(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[  98882096,    2332729]
NotebookOptionsPosition[  98796607,    2331503]
NotebookOutlinePosition[  98797005,    2331519]
CellTagsIndexPosition[  98796962,    2331516]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{
  RowBox[{"FindAllShortestPaths", "[", 
   RowBox[{"graph_Graph", ",", "initialVertex_", ",", "finalVertex_"}], "]"}],
   ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "graphDistance", ",", "vertexIndices", ",", "currentDistance", ",", 
      "currentVertex", ",", "vertexLists"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"graphDistance", "=", 
      RowBox[{"GraphDistance", "[", 
       RowBox[{"graph", ",", "initialVertex", ",", "finalVertex"}], "]"}]}], 
     ";", "\[IndentingNewLine]", " ", 
     RowBox[{"vertexIndices", "=", 
      RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"currentDistance", "=", "graphDistance"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Reap", "[", 
       RowBox[{"Nest", "[", 
        RowBox[{
         RowBox[{"Function", "[", 
          RowBox[{
           RowBox[{"{", "currentVertex", "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"currentDistance", "-=", "1"}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"vertexLists", "=", 
             RowBox[{
              RowBox[{
               RowBox[{"VertexList", "[", 
                RowBox[{"NeighborhoodGraph", "[", 
                 RowBox[{"graph", ",", "#"}], "]"}], "]"}], "&"}], "/@", 
              "currentVertex"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"vertexLists", "=", 
             RowBox[{
              RowBox[{
               RowBox[{"Pick", "[", 
                RowBox[{"#", ",", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"GraphDistance", "[", 
                    RowBox[{"graph", ",", "#", ",", "finalVertex"}], "]"}], 
                   "&"}], "/@", "#"}], ",", "currentDistance"}], "]"}], "&"}],
               "/@", "vertexLists"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"Sow", "/@", 
             RowBox[{"Flatten", "[", 
              RowBox[{"Thread", "/@", 
               RowBox[{"Thread", "[", 
                RowBox[{"currentVertex", "\[UndirectedEdge]", "vertexLists"}],
                 "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"Union", "[", 
             RowBox[{"Flatten", "[", "vertexLists", "]"}], "]"}]}]}], "]"}], 
         ",", 
         RowBox[{"{", "initialVertex", "}"}], ",", "graphDistance"}], "]"}], 
       "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "1"}], "]"}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.833991736172654*^9, 3.8339918131535883`*^9}, {
   3.833991843209202*^9, 3.833991875937828*^9}, {3.8339919159977407`*^9, 
   3.833992036935624*^9}, {3.834855113897382*^9, 3.8348551302563744`*^9}, 
   3.835045316708538*^9},
 CellLabel->"In[1]:=",ExpressionUUID->"eb842e51-9c90-4727-971b-ccfbd0a9b74a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"boundary", "[", 
   RowBox[{"graph_", ",", "r_", ",", "point_"}], "]"}], ":=", 
  RowBox[{"VertexList", "[", 
   RowBox[{"Subgraph", "[", 
    RowBox[{"graph", ",", 
     RowBox[{"Graph", "[", 
      RowBox[{"Complement", "[", 
       RowBox[{
        RowBox[{"EdgeList", "[", 
         RowBox[{"NeighborhoodGraph", "[", 
          RowBox[{"graph", ",", "point", ",", "r"}], "]"}], "]"}], ",", 
        RowBox[{"EdgeList", "[", 
         RowBox[{"NeighborhoodGraph", "[", 
          RowBox[{"graph", ",", "point", ",", 
           RowBox[{"r", "-", "1"}]}], "]"}], "]"}]}], "]"}], "]"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.834252243479707*^9, 3.834252282308005*^9}, {
  3.834252383566807*^9, 3.8342524018095884`*^9}, {3.8342526367659826`*^9, 
  3.8342526370159826`*^9}, {3.8348551188053813`*^9, 3.8348551279243755`*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"ca56adf1-fef5-428b-84e6-2e7b7a90f391"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MeanDeviationfor", "[", 
   RowBox[{"r_", ",", "graph_", ",", "p1_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"lilGraph", "=", 
       RowBox[{"NeighborhoodGraph", "[", 
        RowBox[{"graph", ",", "p1", ",", "r"}], "]"}]}], ",", 
      RowBox[{"b", "=", 
       RowBox[{"boundary", "[", 
        RowBox[{"graph", ",", "r", ",", "p1"}], "]"}]}], ",", "lengths"}], 
     "}"}], ",", "\[IndentingNewLine]", "\t\t\t\t\t\t\t\t\t\t", 
    RowBox[{
     RowBox[{"lengths", "=", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "[", 
           RowBox[{"VertexList", "[", 
            RowBox[{"Subgraph", "[", 
             RowBox[{"lilGraph", ",", 
              RowBox[{"FindAllShortestPaths", "[", 
               RowBox[{"lilGraph", ",", "p1", ",", "#"}], "]"}]}], "]"}], 
            "]"}], "]"}], "&"}], "/@", "b"}], ")"}], "//", "N"}]}], ";", 
     "\[IndentingNewLine]", "\t\t\t\t\t\t\t\t\t\t", 
     RowBox[{"MeanDeviation", "[", "lengths", "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8339978785246325`*^9, 3.8339979059960785`*^9}, {
  3.833997987648875*^9, 3.833998192003763*^9}, {3.8339982658341756`*^9, 
  3.8339984407367086`*^9}, {3.83399854651709*^9, 3.8339985512209206`*^9}, {
  3.833998799576151*^9, 3.833998829269368*^9}, {3.8345731812238684`*^9, 
  3.834573182438945*^9}, {3.834855121788377*^9, 3.8348551256993766`*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"d50c2727-a216-4d46-8186-f28e550509bf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MeanDeviationfor3", "[", 
   RowBox[{"r_", ",", "graph_", ",", "p1_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"lilGraph", "=", 
       RowBox[{"NeighborhoodGraph", "[", 
        RowBox[{"graph", ",", "p1", ",", "r"}], "]"}]}], ",", 
      RowBox[{"b", "=", 
       RowBox[{"boundary", "[", 
        RowBox[{"graph", ",", "r", ",", "p1"}], "]"}]}], ",", "lengths", ",", 
      "meanDeviation"}], "}"}], ",", "\[IndentingNewLine]", 
    "\t\t\t\t\t\t\t\t\t\t", 
    RowBox[{
     RowBox[{"lengths", "=", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "[", 
           RowBox[{"VertexList", "[", 
            RowBox[{"Subgraph", "[", 
             RowBox[{"lilGraph", ",", 
              RowBox[{"FindAllShortestPaths", "[", 
               RowBox[{"lilGraph", ",", "p1", ",", "#"}], "]"}]}], "]"}], 
            "]"}], "]"}], "&"}], "/@", "b"}], ")"}], "//", "N"}]}], ";", 
     "\[IndentingNewLine]", "\t\t\t\t\t\t\t\t\t\t", 
     RowBox[{"meanDeviation", "=", 
      RowBox[{"Mean", "[", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"#", "-", 
            RowBox[{"Mean", "[", "lengths", "]"}]}], ")"}], "3"], "&"}], "/@",
         "lengths"}], "]"}]}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.834565575772172*^9, 3.8345655932602835`*^9}, {
  3.8345660753719983`*^9, 3.8345661456303797`*^9}, {3.834566193442318*^9, 
  3.834566322198615*^9}, {3.8345664463231115`*^9, 3.8345664526580677`*^9}, {
  3.834566501842001*^9, 3.8345665053150187`*^9}, {3.8345732638838096`*^9, 
  3.8345732713268147`*^9}, {3.834638295825879*^9, 3.8346383155357995`*^9}, {
  3.8348540008675003`*^9, 3.834854018823041*^9}, {3.8348541035390654`*^9, 
  3.8348541291955085`*^9}, {3.834855369896048*^9, 3.834855378776806*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"12e46183-5ac1-4f41-b467-2f2fdeac168f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MeanDeviationforMm", "[", 
   RowBox[{"r_", ",", "graph_", ",", "p1_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"lilGraph", "=", 
       RowBox[{"NeighborhoodGraph", "[", 
        RowBox[{"graph", ",", "p1", ",", "r"}], "]"}]}], ",", 
      RowBox[{"b", "=", 
       RowBox[{"boundary", "[", 
        RowBox[{"graph", ",", "r", ",", "p1"}], "]"}]}], ",", "lengths", ",", 
      "meanDeviation"}], "}"}], ",", "\[IndentingNewLine]", 
    "\t\t\t\t\t\t\t\t\t\t", 
    RowBox[{
     RowBox[{"lengths", "=", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "[", 
           RowBox[{"VertexList", "[", 
            RowBox[{"Subgraph", "[", 
             RowBox[{"lilGraph", ",", 
              RowBox[{"FindAllShortestPaths", "[", 
               RowBox[{"lilGraph", ",", "p1", ",", "#"}], "]"}]}], "]"}], 
            "]"}], "]"}], "&"}], "/@", "b"}], ")"}], "//", "N"}]}], ";", 
     "\[IndentingNewLine]", "\t\t\t\t\t\t\t\t\t\t", 
     RowBox[{"meanDeviation", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Max", "[", "#", "]"}], "-", 
          RowBox[{"Min", "[", "#", "]"}]}], ")"}], "&"}], "@", 
       "lengths"}]}]}]}], "]"}]}]], "Input",
 CellLabel->"In[5]:=",ExpressionUUID->"4e3a3c3a-3dcc-44de-a5d8-bb9510c47c82"],

Cell[BoxData[
 RowBox[{
  RowBox[{"meanDeviation3", "[", "l_", "]"}], ":=", 
  RowBox[{"Mean", "[", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"#", "-", 
        RowBox[{"Mean", "[", "l", "]"}]}], ")"}], "3"], "&"}], "/@", "l"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8346626960596094`*^9, 3.834662746405163*^9}, {
  3.834664864499488*^9, 3.8346648653276944`*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"988d43ab-1e6f-4ec1-8823-fe374c6e654d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"allpaths", "[", 
   RowBox[{"r_", ",", "graph_", ",", "p1_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"lilGraph", "=", 
       RowBox[{"NeighborhoodGraph", "[", 
        RowBox[{"graph", ",", "p1", ",", "r"}], "]"}]}], ",", 
      RowBox[{"b", "=", 
       RowBox[{"boundary", "[", 
        RowBox[{"graph", ",", "r", ",", "p1"}], "]"}]}], ",", "lengths"}], 
     "}"}], ",", "\[IndentingNewLine]", "\t\t\t\t\t\t\t\t\t\t", 
    RowBox[{"lengths", "=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", 
         RowBox[{"VertexList", "[", 
          RowBox[{"Subgraph", "[", 
           RowBox[{"lilGraph", ",", 
            RowBox[{"FindAllShortestPaths", "[", 
             RowBox[{"lilGraph", ",", "p1", ",", "#"}], "]"}]}], "]"}], "]"}],
          "]"}], "&"}], "/@", "b"}], ")"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8345826537496595`*^9, 3.8345826918806505`*^9}, 
   3.834582754849231*^9},
 CellLabel->"In[7]:=",ExpressionUUID->"e76ed9f6-95dd-4e08-9045-e451de049a54"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ColorGraph", "[", 
   RowBox[{"graph_", ",", "klist_", ",", 
    RowBox[{"size_", ":", "Medium"}], ",", 
    RowBox[{"radio_", ":", "3"}], ",", 
    RowBox[{"colorMap_", ":", "\"\<TemperatureMap\>\""}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"pk", "=", 
       RowBox[{"Transpose", "[", "klist", "]"}]}], ",", "p", ",", "k", ",", 
      "listv", ",", "liste", ",", 
      RowBox[{"edges", "=", 
       RowBox[{"EdgeList", "[", "graph", "]"}]}]}], "}"}], ",", 
    "\[IndentingNewLine]", "\t\t\t\t\t\t\t\t\t\t\t\t", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"p", ",", "k"}], "}"}], "=", "pk"}], ";", 
     "\[IndentingNewLine]", "\t\t\t\t\t\t\t\t\t\t\t\t", 
     RowBox[{"listv", "=", 
      RowBox[{"Inner", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Rule", "[", 
          RowBox[{"#1", ",", 
           RowBox[{
            RowBox[{"ColorData", "[", "colorMap", "]"}], "[", "#2", "]"}]}], 
          "]"}], "&"}], ",", "p", ",", 
        RowBox[{"Rescale", "[", "k", "]"}], ",", "List"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\t\t\t\t\t\t\t\t\t\t\t\t", 
     RowBox[{"liste", "=", 
      RowBox[{"Inner", "[", 
       RowBox[{"Rule", ",", "edges", ",", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Blend", "[", 
            RowBox[{"#", ",", 
             RowBox[{"1", "/", "2"}]}], "]"}], "&"}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"Map", "[", 
             RowBox[{"VertexList", ",", "edges"}], "]"}], ")"}], "/.", 
           "listv"}]}], "]"}], ",", "List"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\t\t\t\t\t\t\t\t\t\t\t\t", 
     RowBox[{"Graph", "[", 
      RowBox[{"graph", ",", 
       RowBox[{"VertexStyle", "\[Rule]", 
        RowBox[{"Join", "[", 
         RowBox[{"listv", ",", 
          RowBox[{"{", 
           RowBox[{"EdgeForm", "[", "None", "]"}], "}"}]}], "]"}]}], ",", 
       RowBox[{"VertexSize", "\[Rule]", "radio"}], ",", 
       RowBox[{"EdgeStyle", "\[Rule]", "liste"}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "size"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "\t\t\t\t\t\t\t\t\t\t\t\t", "]"}]}]], "Input",
 CellChangeTimes->{{3.834878687249202*^9, 3.834878772034398*^9}, {
   3.8348909372179146`*^9, 3.834891095762106*^9}, {3.8348914884768353`*^9, 
   3.8348914886858153`*^9}, {3.8348919258172135`*^9, 
   3.8348919298337417`*^9}, {3.8348920187536354`*^9, 3.834892034750204*^9}, {
   3.8348931847856455`*^9, 3.8348931972747326`*^9}, {3.8348942171702037`*^9, 
   3.8348942415295877`*^9}, {3.834894367113163*^9, 3.834894370415522*^9}, {
   3.8348946983313646`*^9, 3.834894703062146*^9}, {3.834894738937293*^9, 
   3.8348947540555573`*^9}, {3.8348949224429755`*^9, 3.8348949616703*^9}, {
   3.8348952414387937`*^9, 3.8348953310319786`*^9}, 3.834895378176134*^9, {
   3.834895470869875*^9, 3.8348954781301107`*^9}, {3.8348956377709856`*^9, 
   3.834895647413559*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"25bc23d6-e717-4d25-894a-9fdf6edd995e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ColorGraphb", "[", 
   RowBox[{"graph_", ",", "klist_", ",", 
    RowBox[{"size_", ":", "Medium"}], ",", 
    RowBox[{"radio_", ":", "3"}], ",", 
    RowBox[{"colorMap_", ":", "\"\<TemperatureMap\>\""}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"pk", "=", 
       RowBox[{"Transpose", "[", "klist", "]"}]}], ",", "p", ",", "k", ",", 
      "listv", ",", "liste", ",", 
      RowBox[{"edges", "=", 
       RowBox[{"EdgeList", "[", "graph", "]"}]}]}], "}"}], ",", 
    "\[IndentingNewLine]", "\t\t\t\t\t\t\t\t\t\t\t\t", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"p", ",", "k"}], "}"}], "=", "pk"}], ";", 
     "\[IndentingNewLine]", "\t\t\t\t\t\t\t\t\t\t\t\t", 
     RowBox[{"listv", "=", 
      RowBox[{"Inner", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Rule", "[", 
          RowBox[{"#1", ",", 
           RowBox[{
            RowBox[{"ColorData", "[", "colorMap", "]"}], "[", "#2", "]"}]}], 
          "]"}], "&"}], ",", "p", ",", 
        RowBox[{"Rescale", "[", "k", "]"}], ",", "List"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\t\t\t\t\t\t\t\t\t\t\t\t", 
     RowBox[{"liste", "=", 
      RowBox[{"Inner", "[", 
       RowBox[{
       "Rule", ",", "edges", ",", "\[IndentingNewLine]", "\t\t\t\t\t\t\t\t", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"ColorDistance", "[", 
               RowBox[{"Red", ",", 
                RowBox[{"#", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "<", "0.5"}], " ", 
             ",", 
             RowBox[{"Blend", "[", 
              RowBox[{"#", ",", 
               RowBox[{"1", "/", "3"}]}], "]"}], ",", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"ColorDistance", "[", 
                 RowBox[{"Red", ",", 
                  RowBox[{"#", "[", 
                   RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "<", "0.5"}], ",", 
               RowBox[{"Blend", "[", 
                RowBox[{"#", ",", 
                 RowBox[{"2", "/", "3"}]}], "]"}], ",", 
               RowBox[{"Blend", "[", 
                RowBox[{"#", ",", 
                 RowBox[{"1", "/", "2"}]}], "]"}]}], "]"}]}], "]"}], "&"}], 
          ",", "\[IndentingNewLine]", "\t\t\t\t\t\t\t\t\t\t\t", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"Map", "[", 
             RowBox[{"VertexList", ",", "edges"}], "]"}], ")"}], "/.", 
           "listv"}]}], "]"}], ",", "List"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\t\t\t\t\t\t\t\t\t\t\t\t", 
     RowBox[{"Graph", "[", 
      RowBox[{"graph", ",", 
       RowBox[{"VertexStyle", "\[Rule]", 
        RowBox[{"Join", "[", 
         RowBox[{"listv", ",", 
          RowBox[{"{", 
           RowBox[{"EdgeForm", "[", "None", "]"}], "}"}]}], "]"}]}], ",", 
       RowBox[{"VertexSize", "\[Rule]", "radio"}], ",", 
       RowBox[{"EdgeStyle", "\[Rule]", "liste"}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "size"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "\t\t\t\t\t\t\t\t\t\t\t\t", "]"}]}]], "Input",
 CellChangeTimes->{{3.834878687249202*^9, 3.834878772034398*^9}, {
   3.8348909372179146`*^9, 3.834891095762106*^9}, {3.8348914884768353`*^9, 
   3.8348914886858153`*^9}, {3.8348919258172135`*^9, 
   3.8348919298337417`*^9}, {3.8348920187536354`*^9, 3.834892034750204*^9}, {
   3.8348931847856455`*^9, 3.8348931972747326`*^9}, {3.8348942171702037`*^9, 
   3.8348942415295877`*^9}, {3.834894367113163*^9, 3.834894370415522*^9}, {
   3.8348946983313646`*^9, 3.834894703062146*^9}, {3.834894738937293*^9, 
   3.8348947540555573`*^9}, {3.8348949224429755`*^9, 3.8348949616703*^9}, {
   3.8348952414387937`*^9, 3.8348953310319786`*^9}, 3.834895378176134*^9, {
   3.834895470869875*^9, 3.8348954781301107`*^9}, {3.8348956377709856`*^9, 
   3.834895647413559*^9}, {3.835051526999363*^9, 3.8350515904569592`*^9}},
 CellLabel->
  "In[501]:=",ExpressionUUID->"946b9045-1587-4700-a79d-1a92bb616739"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ColorGraphc", "[", 
   RowBox[{"graph_", ",", "klist_", ",", 
    RowBox[{"size_", ":", "Medium"}], ",", 
    RowBox[{"radio_", ":", "3"}], ",", 
    RowBox[{"colorMap_", ":", "\"\<TemperatureMap\>\""}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"pk", "=", 
       RowBox[{"Transpose", "[", "klist", "]"}]}], ",", "p", ",", "k", ",", 
      "listv", ",", "liste", ",", 
      RowBox[{"edges", "=", 
       RowBox[{"EdgeList", "[", "graph", "]"}]}], ",", "kn", ",", "Q"}], 
     "}"}], ",", "\[IndentingNewLine]", "\t\t\t\t\t\t\t\t\t\t\t\t", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"p", ",", "k"}], "}"}], "=", "pk"}], ";", 
     "\[IndentingNewLine]", "\t\t\t\t\t\t\t\t\t\t\t\t", 
     RowBox[{"Q", "=", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "+", 
         RowBox[{"1.5", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "-", 
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}]}], "&"}], "@", 
       RowBox[{"Quartiles", "[", "k", "]"}]}]}], ";", "\[IndentingNewLine]", 
     "\t\t\t\t\t\t\t\t\t\t\t\t", 
     RowBox[{"kn", "=", 
      RowBox[{"k", "/.", 
       RowBox[{"Flatten", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Inner", "[", 
             RowBox[{"Rule", ",", "#", ",", " ", 
              RowBox[{"Rescale", "[", "#", "]"}], ",", "List"}], "]"}], "&"}],
            "@", 
           RowBox[{"Select", "[", 
            RowBox[{"k", ",", 
             RowBox[{
              RowBox[{"#", "\[LessEqual]", "Q"}], "&"}]}], "]"}]}], ",", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"#", "->", " ", "1"}], "&"}], ",", 
            RowBox[{"Select", "[", 
             RowBox[{"k", ",", 
              RowBox[{
               RowBox[{"#", ">", "Q"}], "&"}]}], "]"}]}], "]"}]}], "}"}], 
        "]"}]}]}], ";", "\[IndentingNewLine]", "\t\t\t\t\t\t\t\t\t\t\t\t", 
     RowBox[{"listv", "=", 
      RowBox[{"Inner", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Rule", "[", 
          RowBox[{"#1", ",", 
           RowBox[{
            RowBox[{"ColorData", "[", "colorMap", "]"}], "[", "#2", "]"}]}], 
          "]"}], "&"}], ",", "p", ",", "kn", ",", "List"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\t\t\t\t\t\t\t\t\t\t\t\t", 
     RowBox[{"liste", "=", 
      RowBox[{"Inner", "[", 
       RowBox[{
       "Rule", ",", "edges", ",", "\[IndentingNewLine]", "\t\t\t\t\t\t\t\t", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"ColorDistance", "[", 
               RowBox[{"Red", ",", 
                RowBox[{"#", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "<", "0.5"}], " ", 
             ",", 
             RowBox[{"Blend", "[", 
              RowBox[{"#", ",", 
               RowBox[{"1", "/", "3"}]}], "]"}], ",", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"ColorDistance", "[", 
                 RowBox[{"Red", ",", 
                  RowBox[{"#", "[", 
                   RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "<", "0.5"}], ",", 
               RowBox[{"Blend", "[", 
                RowBox[{"#", ",", 
                 RowBox[{"2", "/", "3"}]}], "]"}], ",", 
               RowBox[{"Blend", "[", 
                RowBox[{"#", ",", 
                 RowBox[{"1", "/", "2"}]}], "]"}]}], "]"}]}], "]"}], "&"}], 
          ",", "\[IndentingNewLine]", "\t\t\t\t\t\t\t\t\t\t\t", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"Map", "[", 
             RowBox[{"VertexList", ",", "edges"}], "]"}], ")"}], "/.", 
           "listv"}]}], "]"}], ",", "List"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\t\t\t\t\t\t\t\t\t\t\t\t", 
     RowBox[{"Graph", "[", 
      RowBox[{"graph", ",", 
       RowBox[{"VertexStyle", "\[Rule]", 
        RowBox[{"Join", "[", 
         RowBox[{"listv", ",", 
          RowBox[{"{", 
           RowBox[{"EdgeForm", "[", "None", "]"}], "}"}]}], "]"}]}], ",", 
       RowBox[{"VertexSize", "\[Rule]", "radio"}], ",", 
       RowBox[{"EdgeStyle", "\[Rule]", "liste"}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "size"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "\t\t\t\t\t\t\t\t\t\t\t\t", "]"}]}]], "Input",
 CellChangeTimes->{{3.834878687249202*^9, 3.834878772034398*^9}, {
   3.8348909372179146`*^9, 3.834891095762106*^9}, {3.8348914884768353`*^9, 
   3.8348914886858153`*^9}, {3.8348919258172135`*^9, 
   3.8348919298337417`*^9}, {3.8348920187536354`*^9, 3.834892034750204*^9}, {
   3.8348931847856455`*^9, 3.8348931972747326`*^9}, {3.8348942171702037`*^9, 
   3.8348942415295877`*^9}, {3.834894367113163*^9, 3.834894370415522*^9}, {
   3.8348946983313646`*^9, 3.834894703062146*^9}, {3.834894738937293*^9, 
   3.8348947540555573`*^9}, {3.8348949224429755`*^9, 3.8348949616703*^9}, {
   3.8348952414387937`*^9, 3.8348953310319786`*^9}, 3.834895378176134*^9, {
   3.834895470869875*^9, 3.8348954781301107`*^9}, {3.8348956377709856`*^9, 
   3.834895647413559*^9}, {3.835051526999363*^9, 3.8350515904569592`*^9}, {
   3.8350556723512917`*^9, 3.8350557131764307`*^9}, {3.8350557552836757`*^9, 
   3.835055832681972*^9}},
 CellLabel->
  "In[508]:=",ExpressionUUID->"d8b3a842-f55a-444a-92f5-da7c6d65720d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ColorGraphd", "[", 
   RowBox[{"graph_", ",", "klist_", ",", 
    RowBox[{"size_", ":", "Medium"}], ",", 
    RowBox[{"radio_", ":", "3"}], ",", 
    RowBox[{"colorMap_", ":", "\"\<TemperatureMap\>\""}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"pk", "=", 
       RowBox[{"Transpose", "[", "klist", "]"}]}], ",", "p", ",", "k", ",", 
      "listv", ",", "liste", ",", 
      RowBox[{"edges", "=", 
       RowBox[{"EdgeList", "[", "graph", "]"}]}], ",", "kn", ",", "Q"}], 
     "}"}], ",", "\[IndentingNewLine]", "\t\t\t\t\t\t\t\t\t\t\t\t", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"p", ",", "k"}], "}"}], "=", "pk"}], ";", 
     "\[IndentingNewLine]", "\t\t\t\t\t\t\t\t\t\t\t\t", 
     RowBox[{"Q", "=", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "+", 
         RowBox[{"1.5", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "-", 
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}]}], "&"}], "@", 
       RowBox[{"Quartiles", "[", "k", "]"}]}]}], ";", "\[IndentingNewLine]", 
     "\t\t\t\t\t\t\t\t\t\t\t\t", 
     RowBox[{"kn", "=", 
      RowBox[{"k", "/.", 
       RowBox[{"Flatten", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Inner", "[", 
             RowBox[{"Rule", ",", "#", ",", " ", 
              RowBox[{"Rescale", "[", "#", "]"}], ",", "List"}], "]"}], "&"}],
            "@", 
           RowBox[{"Select", "[", 
            RowBox[{"k", ",", 
             RowBox[{
              RowBox[{"#", "\[LessEqual]", "Q"}], "&"}]}], "]"}]}], ",", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"#", "->", " ", "0"}], "&"}], ",", 
            RowBox[{"Select", "[", 
             RowBox[{"k", ",", 
              RowBox[{
               RowBox[{"#", ">", "Q"}], "&"}]}], "]"}]}], "]"}]}], "}"}], 
        "]"}]}]}], ";", "\[IndentingNewLine]", "\t\t\t\t\t\t\t\t\t\t\t\t", 
     RowBox[{"listv", "=", 
      RowBox[{"Inner", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Rule", "[", 
          RowBox[{"#1", ",", 
           RowBox[{
            RowBox[{"ColorData", "[", "colorMap", "]"}], "[", "#2", "]"}]}], 
          "]"}], "&"}], ",", "p", ",", "kn", ",", "List"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\t\t\t\t\t\t\t\t\t\t\t\t", 
     RowBox[{"liste", "=", 
      RowBox[{"Inner", "[", 
       RowBox[{
       "Rule", ",", "edges", ",", "\[IndentingNewLine]", "\t\t\t\t\t\t\t\t", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"ColorDistance", "[", 
               RowBox[{"Red", ",", 
                RowBox[{"#", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "<", "0.5"}], " ", 
             ",", 
             RowBox[{"Blend", "[", 
              RowBox[{"#", ",", 
               RowBox[{"1", "/", "3"}]}], "]"}], ",", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"ColorDistance", "[", 
                 RowBox[{"Red", ",", 
                  RowBox[{"#", "[", 
                   RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "<", "0.5"}], ",", 
               RowBox[{"Blend", "[", 
                RowBox[{"#", ",", 
                 RowBox[{"2", "/", "3"}]}], "]"}], ",", 
               RowBox[{"Blend", "[", 
                RowBox[{"#", ",", 
                 RowBox[{"1", "/", "2"}]}], "]"}]}], "]"}]}], "]"}], "&"}], 
          ",", "\[IndentingNewLine]", "\t\t\t\t\t\t\t\t\t\t\t", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"Map", "[", 
             RowBox[{"VertexList", ",", "edges"}], "]"}], ")"}], "/.", 
           "listv"}]}], "]"}], ",", "List"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\t\t\t\t\t\t\t\t\t\t\t\t", 
     RowBox[{"Graph", "[", 
      RowBox[{"graph", ",", 
       RowBox[{"VertexStyle", "\[Rule]", 
        RowBox[{"Join", "[", 
         RowBox[{"listv", ",", 
          RowBox[{"{", 
           RowBox[{"EdgeForm", "[", "None", "]"}], "}"}]}], "]"}]}], ",", 
       RowBox[{"VertexSize", "\[Rule]", "radio"}], ",", 
       RowBox[{"EdgeStyle", "\[Rule]", "liste"}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "size"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "\t\t\t\t\t\t\t\t\t\t\t\t", "]"}]}]], "Input",
 CellChangeTimes->{{3.834878687249202*^9, 3.834878772034398*^9}, {
   3.8348909372179146`*^9, 3.834891095762106*^9}, {3.8348914884768353`*^9, 
   3.8348914886858153`*^9}, {3.8348919258172135`*^9, 
   3.8348919298337417`*^9}, {3.8348920187536354`*^9, 3.834892034750204*^9}, {
   3.8348931847856455`*^9, 3.8348931972747326`*^9}, {3.8348942171702037`*^9, 
   3.8348942415295877`*^9}, {3.834894367113163*^9, 3.834894370415522*^9}, {
   3.8348946983313646`*^9, 3.834894703062146*^9}, {3.834894738937293*^9, 
   3.8348947540555573`*^9}, {3.8348949224429755`*^9, 3.8348949616703*^9}, {
   3.8348952414387937`*^9, 3.8348953310319786`*^9}, 3.834895378176134*^9, {
   3.834895470869875*^9, 3.8348954781301107`*^9}, {3.8348956377709856`*^9, 
   3.834895647413559*^9}, {3.835051526999363*^9, 3.8350515904569592`*^9}, {
   3.8350556723512917`*^9, 3.8350557131764307`*^9}, {3.8350557552836757`*^9, 
   3.835055832681972*^9}, {3.83505598842598*^9, 3.835055999006797*^9}},
 CellLabel->
  "In[507]:=",ExpressionUUID->"55f830a1-c5b3-4757-91df-3b2d806b1c4c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"getOutliers", "[", 
   RowBox[{"dat_", ",", "iqrCoeff_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Select", "[", 
    RowBox[{
     RowBox[{"!", 
      RowBox[{"IntervalMemberQ", "[", 
       RowBox[{
        RowBox[{"Interval", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "+", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1"}], "}"}], " ", "iqrCoeff", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"#", "[", 
                RowBox[{"[", "3", "]"}], "]"}], "-", 
               RowBox[{"#", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}]}], "&"}], "@", 
          RowBox[{"Quartiles", "[", "dat", "]"}]}], "]"}], ",", "#"}], 
       "]"}]}], "&"}], "]"}], "@", "dat"}]}]], "Input",
 CellChangeTimes->{{3.835052974107357*^9, 3.835052974110357*^9}},
 CellLabel->
  "In[448]:=",ExpressionUUID->"f3053e55-f1fe-4c94-8780-133b44e48b01"],

Cell[CellGroupData[{

Cell["Correlation", "Title",
 CellChangeTimes->{{3.83477755055669*^9, 
  3.8347775529362555`*^9}},ExpressionUUID->"96723d73-c3ad-4131-84fe-\
5c73c110db42"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ECMTG", "=", 
   RowBox[{
   "ResourceFunction", "[", "\"\<ExtrinsicCurvedManifoldToGraph\>\"", "]"}]}],
   ";"}]], "Input",
 CellChangeTimes->{{3.8347722441854935`*^9, 3.834772258812312*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"141bc942-565e-4da6-b8cb-ca7c19defa2a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"KHyperboloid", "=", 
   RowBox[{"4", " ", 
    SuperscriptBox[
     RowBox[{"Sech", "[", "\[Nu]", "]"}], "4"]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8347723374147277`*^9, 3.8347723630865917`*^9}, {
  3.8347934634942217`*^9, 3.834793469603117*^9}},
 CellLabel->"In[67]:=",ExpressionUUID->"e6e824d6-c4d6-44c8-8a2b-289fc311898b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"max", "=", "45"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"I", "'"}], "ve", " ", "tried", " ", "the", " ", "code", " ", 
    "with", " ", "45"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.834774081231894*^9, 3.834774095695593*^9}, 
   3.8347741693974514`*^9, 3.834775717713425*^9, {3.8347757509877872`*^9, 
   3.834775753331542*^9}, {3.8347955508455114`*^9, 3.8347956360335093`*^9}, 
   3.834854164192853*^9, {3.834878816491827*^9, 3.834878817535929*^9}, {
   3.8348797901543655`*^9, 3.834879793707739*^9}, {3.834881336060723*^9, 
   3.834881336242728*^9}, {3.8348833091891537`*^9, 3.8348833354896564`*^9}, {
   3.8348833859001465`*^9, 3.834883388665885*^9}, {3.83488784854051*^9, 
   3.8348878489831944`*^9}},
 Background->RGBColor[
  1, 0.5, 0],ExpressionUUID->"b287ee49-c359-41aa-a815-a645292150c7"],

Cell["\<\
As the hypergraph are defined with a random component, I will save the \
result: \
\>", "Text",
 CellChangeTimes->{{3.834777707537403*^9, 3.834777746682354*^9}, {
  3.834790568459943*^9, 
  3.8347905688059464`*^9}},ExpressionUUID->"fd386e9a-775c-4edd-815c-\
1aa8eb695b02"],

Cell[BoxData[
 RowBox[{
  RowBox[{"run", ":=", 
   RowBox[{"ParallelTable", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"ECMTG", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"x", "^", "2"}], "+", 
          RowBox[{"y", "^", "2"}], "-", 
          RowBox[{"z", "^", "2"}]}], "\[Equal]", "1"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "}"}], ",", 
        RowBox[{"3.5", "-", 
         RowBox[{"n", "/", "max"}], "+", 
         RowBox[{"0.1", "*", 
          RowBox[{"KroneckerDelta", "[", 
           RowBox[{"n", ",", "10"}], "]"}]}]}], ",", 
        RowBox[{"n", "+", "10"}]}], "]"}], "[", "\"\<PureSpatialGraph\>\"", 
      "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "40", ",", "max", ",", "1"}], "}"}]}], "]"}]}], ";", 
  RowBox[{"(*", 
   RowBox[{
   "not", " ", "my", " ", "favorite", " ", "rule", " ", "for", " ", "the", 
    " ", "density", " ", "but", " ", 
    RowBox[{"it", "'"}], "s", " ", "easy", " ", "to", " ", "run"}], "*)"}], 
  RowBox[{"data", "=", "run"}], ";"}]], "Input",
 CellChangeTimes->{{3.83477770380293*^9, 3.834777705115514*^9}, {
   3.834777749276017*^9, 3.834777751854229*^9}, {3.8347778786491213`*^9, 
   3.8347779002914257`*^9}, 3.8347787577565727`*^9, {3.8347841458831544`*^9, 
   3.834784182171951*^9}, {3.834786743505004*^9, 3.8347867513090353`*^9}, {
   3.83478705076488*^9, 3.8347870619677544`*^9}, {3.8347871246815157`*^9, 
   3.8347871298067927`*^9}, {3.834787411857012*^9, 3.83478741306053*^9}, {
   3.834787807917325*^9, 3.834787808592017*^9}, {3.834788266909972*^9, 
   3.8347882869251003`*^9}, 3.834788908559472*^9, {3.834789471958487*^9, 
   3.834789475271352*^9}, {3.8347896943440857`*^9, 3.8347897097307196`*^9}, {
   3.834789893966666*^9, 3.834789972124423*^9}, {3.834790072588895*^9, 
   3.8347900727708893`*^9}, {3.8348534703941975`*^9, 
   3.8348534724562545`*^9}, {3.834881329179191*^9, 3.8348813487257547`*^9}, {
   3.8348814123966064`*^9, 3.834881444801366*^9}, {3.8348826249397097`*^9, 
   3.834882625805616*^9}, {3.834883320861103*^9, 3.834883324374866*^9}, {
   3.834883393165774*^9, 3.834883395665884*^9}},
 CellLabel->"In[64]:=",ExpressionUUID->"6d180ed6-a098-41cf-bcc9-1ff09093beec"],

Cell["Test Subjects", "Text",
 CellChangeTimes->{{3.834781786780091*^9, 
  3.834781789524975*^9}},ExpressionUUID->"27bfa428-5777-4400-a8a3-\
97cd59713f49"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dataindex", "=", 
   RowBox[{"IndexGraph", "/@", "data"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8347789016744475`*^9, 3.834778918525745*^9}, 
   3.834795677240551*^9},
 CellLabel->"In[65]:=",ExpressionUUID->"1ea8880f-e1f5-4036-997e-d00cdc27e8bc"],

Cell[CellGroupData[{

Cell[BoxData["dataindex"], "Input",
 CellChangeTimes->{{3.8348834484527636`*^9, 3.834883452843298*^9}},
 CellLabel->"In[66]:=",ExpressionUUID->"5d69ab60-bf25-43eb-882e-f6a6152f54c9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 
        19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
        36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50}, {
        Null, CompressedData["
1:eJwVxdvZmyAAANAQUFGjAiqIqIlB8QpeRukI/wIdvSu0fTjf6X9+//p5Ph6P
P//8n5xpmd7fm0zTSUxgyDIty5kWxbe4PRlIIqWBwsuCLJPwEAfkKS84N/yG
SSKSI53JXM5yJmu5zuuyricZx3lcxnU8vSqryGa2aVu2ddtO8vl8P9NnS7ui
41336b7dDWlCKaeCHp4LXOYqJ51xcPd2uietaNsDNl6TNbSpGtk0e5RGZTRH
K6nrsZ7quV7qtd7qM2IpI4yVTLKajcywma1sYw5qqrkWWupOa6PvMAlF2IYH
tKmlltnCcittZ7U11t5enuV5lcu8yffcRa9X+ipfsxcHcZzFeVzFMnbBFV/i
kpe+zOUu0rO+7vuxn/ulX/utPyFCIUoQRRwJJFGLOqSRQRZdwAMBiEEGclAB
CQxw4IIDGpKBDnwQgx4GOxzhW7zbN1RIhSpRVHEllFSqVVoNyiirrmf0fD3T
ZwmwhwOMY5zhHFdYYoMdvqDv+T71c7/x979KRzGs
         "]}, {EdgeStyle -> {
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]]}, VertexStyle -> {
           Directive[
            Hue[0.63, 0.26, 0.89], 
            EdgeForm[
             Directive[
              Hue[0.63, 0.7, 0.33], 
              Opacity[0.95]]]]}}]]}, 
      TagBox[GraphicsGroupBox[GraphicsComplexBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAAHst7OsJVA0AQXir5GWYLQCSvE9DH
/xVAeJaHjvKqwz+kisZXHs32P8BnaY31L/w/fbGOXmPB/j+4jUsNmyf0P9X1
yHFkefk/33zN18rqC0BMBscb9VDoP8frPNbUIgdA4PqW5GiuBkBg9Xsc24wL
QEIWcwmT3AFABBqxnYjNCUCEx6nUGzzjP44QbJ8OMeQ/EN412CC4FUCYhQ3r
o13yP5sOSgOAKwFAyII5nGvBDEASTP/cQtsVQFTEXjpjFOM/6FWJMUhk6z/J
1aDLvSDwP6pRFmYz1RBADp4LnwPs6j8yiFAqKlkBQCwkMZACxg5Ah4EBQDAg
E0CiNrI6LcMDQPijeC4HnfQ/aElUaEd7+j+udbKGf0cRQLeOVb7T5ABAahxl
6vkl+z+ZxHUBO18KQPSecLWmMQtAcEB/3zMjxj9CN5r+qsAUQDUMLQ6JyfA/
ruT9BsRaBEAvXTaTvLnvP+AfDyZ11vE/pnGVJ4ac8T80Le+jqvr7P+jzRLm3
9w9ApN64cGpHBkAsPRLQsHQEQO5AxgMXVhZA4HwbyiaXA0BMldoz5P77P6s3
gn7D2vY/0U6XpWVd9j826qlmp4UHQIj8m6400Oo/cFZcujGE2z/fbGXC/6EK
QLAXiYlN3Og/AAAAAAAAAACQkCUQJZm2P5VCoiE0/BJAbhBCsn4i9D92khKK
8zsVQNIQoe1gGgZAFK8J7D9AEEAAAAAAAAAAACUcXeNCPgJAAq/vySaZ9j/0
+MUkEsP4P7d5nbtL8u0/BMnF4sQbFkDyG44GGKwGQC9Q2VPGrghAR5ZxQubd
AUCOGj5SmNkXQKDPt1+HqgBAZ8iYoX1OE0AS0rmdiKv9P1eWg/VAXRhA+oRl
9RztBEDsgoi+ICEWQBDVr2WzlgBAr9L8uc88FECBUBDyJZYCQGg8zDEUreo/
Bm0CXpoyBUDSRrKvaiIGQILtHuuTLvU/A4Us28d3BUDorMx+LTQJQOiVV0I9
xNw/gPiRMrGw8T+UmyQBRtgXQDYTZ1csJwdAVpQDDC0aAUDacPBDxzoDQIRL
tZQsCwlAXPbohD/q2T9G5WNK
         "], {
          {Hue[0.63, 0.7, 0.5], Opacity[0.7], LineBox[CompressedData["
1:eJwVxdvZmyAAANAQUFGjAiqIqIlB8QpeRukI/wIdvSu0fTjf6X9+//p5Ph6P
P//8H3ggABjEIAM5qIAEBjhwPaPn65k+S4igDxNIIYcCKthADQe4QwsPFKIE
UcSRQBIp1KIOaTQggyy6PN/DXuxlXu5VnvQab/ecT/3cb/w9wEEcZIEMTOCC
C8c4wzmusMQGO3yFSShCFbbhOzyiV5RGLCqjOVrjLM7jKpaxi69X+ipfc0IT
kaikTYbkSFlapGXK0y6dU5veWZ5VmcyazBFGJKnJh/RkJIZMZCYLWclGTsqp
oIo2VNOB7tTSg5VMspr1bGSGzWxlG7PM5VUu8ybfc1fwoiu+hS3uci5XrnjH
NR+44ZbfQolWvIUWgzjEVTWVk0o2UksjZ2mlk1fd12M91XO91Gu91adqlVaD
Msqqq9nbd3t0n+7b6c529+f7mT5bP/Zzv/Rrv/Xn99aDNtrqS9+DHY5xHpdx
HU+zGWucuaZl2qZzXpd12ZZz3dZzO+3trr+o+jGs
            "]]}, 
          {Hue[0.63, 0.26, 0.89], EdgeForm[{Hue[0.63, 0.7, 0.33], Opacity[
           0.95]}], DiskBox[1, 0.04894431221572629], 
           DiskBox[2, 0.04894431221572629], DiskBox[3, 0.04894431221572629], 
           DiskBox[4, 0.04894431221572629], DiskBox[5, 0.04894431221572629], 
           DiskBox[6, 0.04894431221572629], DiskBox[7, 0.04894431221572629], 
           DiskBox[8, 0.04894431221572629], DiskBox[9, 0.04894431221572629], 
           DiskBox[10, 0.04894431221572629], DiskBox[11, 0.04894431221572629],
            DiskBox[12, 0.04894431221572629], 
           DiskBox[13, 0.04894431221572629], DiskBox[14, 0.04894431221572629],
            DiskBox[15, 0.04894431221572629], 
           DiskBox[16, 0.04894431221572629], DiskBox[17, 0.04894431221572629],
            DiskBox[18, 0.04894431221572629], 
           DiskBox[19, 0.04894431221572629], DiskBox[20, 0.04894431221572629],
            DiskBox[21, 0.04894431221572629], 
           DiskBox[22, 0.04894431221572629], DiskBox[23, 0.04894431221572629],
            DiskBox[24, 0.04894431221572629], 
           DiskBox[25, 0.04894431221572629], DiskBox[26, 0.04894431221572629],
            DiskBox[27, 0.04894431221572629], 
           DiskBox[28, 0.04894431221572629], DiskBox[29, 0.04894431221572629],
            DiskBox[30, 0.04894431221572629], 
           DiskBox[31, 0.04894431221572629], DiskBox[32, 0.04894431221572629],
            DiskBox[33, 0.04894431221572629], 
           DiskBox[34, 0.04894431221572629], DiskBox[35, 0.04894431221572629],
            DiskBox[36, 0.04894431221572629], 
           DiskBox[37, 0.04894431221572629], DiskBox[38, 0.04894431221572629],
            DiskBox[39, 0.04894431221572629], 
           DiskBox[40, 0.04894431221572629], DiskBox[41, 0.04894431221572629],
            DiskBox[42, 0.04894431221572629], 
           DiskBox[43, 0.04894431221572629], DiskBox[44, 0.04894431221572629],
            DiskBox[45, 0.04894431221572629], 
           DiskBox[46, 0.04894431221572629], DiskBox[47, 0.04894431221572629],
            DiskBox[48, 0.04894431221572629], 
           DiskBox[49, 0.04894431221572629], 
           DiskBox[50, 0.04894431221572629]}}]],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 
        19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
        36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51}, {
        Null, CompressedData["
1:eJwVxV2aqiAAANAQRU0sLfwDNKJAKFHBndwlzAbu/t/mm/Nynj////1Ep9Pp
CU6nv40dDDMNQwwZZOP98YqzzGZf5BrHnHFID5ppbbTVDpWlLk1pEW/4wBnn
mhvuYAwRtHBHR3nowxz2QGEILPCggwkuxJ/sA6f7NL0u98t02SMYxVEWfaL9
9ri9IEU0o1RTQy390iN70/f7G53j83lvNra5LW1SlvLUpRsas5GO43u042f8
Xm/Xx/V1fV+/cE7nZmbz7ObtOT+3qIiLrChoMRbvwhaf4ouqsqqGSlemslWo
jrRruo51z27uXLdBgkhJKkIoYYSTkWhiiCWOBHIgnGJMcIMHzDDHGhvscEiu
yS2ZkkfyQipVWBHVqEExxZXSyiinQtTCNm7PbdG2n3ZHIhVYENGITlDBBBdC
CS1mYYQVTmwiQJ945FNPfOM7Tz3zkxd+9tY7v/mohnVcX+r6Xrf1VO+1h0uy
XJZ6uS/T8lpwX/ZV3w8971Wve9OH/sjLvMp1bvMDrflartVK1n4dVr2a1a7r
gWQqsSSykZ1kkkshpZJaztJIJzfpZQARgCAGCGQgBwUoQQ0IaAEFI9DAAAtW
4MHxC4roPaI=
         "]}, {EdgeStyle -> {
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]]}, VertexStyle -> {
           Directive[
            Hue[0.63, 0.26, 0.89], 
            EdgeForm[
             Directive[
              Hue[0.63, 0.7, 0.33], 
              Opacity[0.95]]]]}}]]}, 
      TagBox[GraphicsGroupBox[GraphicsComplexBox[CompressedData["
1:eJwBQQO+/CFib1JlAgAAADMAAAACAAAAWsUcBsYgA0BDRQjWb6H1P0CrIbiA
hg5ARCUffN8v7T92ExQrGW4JQPHbpDEF6/4/ChIK65hiDUB0skDOMgPlP3Xm
cBs2uxJA/D+wpv0bDUCnJJGgrwP4PxAcjqh4u/8/xscd1Xrq8D/ACXpeimUL
QDvVR8BRtghAyJsK6wU28T+FnnT31KbzP1CVN3zQvOM//itvMdZuEkAAAAAA
AAAAAMm50h0nXgpAJfDjZRlb8z/04ZSMbDbhPwsgfrfFkwVAZvJC+dTr8j/U
YMSKDRfxP4Iz8WRNShVAR4p4bdMh/D9nyX8q1lgUQPhnTauWYQpAkqlJFKut
5T9adfQpOu70P7F29vtFhBBAohxxndi9+z9O6YW5oOgWQKN2a+mzXRFAGmFT
kkc+FkDwxX+Hn6IBQIZtkTdg1fg/gM52NKD3AEBsMFiP6w7qP0vEFNR6dAtA
Kun4dM6uD0AsXJXdgmPmP913c1Uc6/I/B2iBPPnQDkAQE7T8sVfTPyiPw/KG
6Pk/AAAAAAAAAAD7mtDkqvz9P/zdSBdb/wJA6tc6G5tj/j+FBVqcT9/zPz50
rKk+1gdAwL53MbF/3D+fQNhprDMEQJ6QwlOPPAZAvN8V+2zL9z+gyeqJjc0R
QJjvajPCmgVAHOZkknIfGEBQN1Q/+jAQQIEMsonHMvY/0hrmNbivBUCwJ+Nq
QozzP3TzDE3sbhNAPg/prWsP7z8WStN8PcQHQFSMA5fiaBZAaLzfjvNHDEBj
EAfOEnUNQOolVnF+CgJADJMUusNA5j9sTI3ehwAEQNeRFq636/A/9L4bY4hM
/T9cFJ+bCHr8P2ZVejNc5QtAeRN2KZ/u8D81ZpAfwBwAQAFP2zbr0P4/vXCz
Yst5+D+M1mWDbF4LQLCzYbwvocs/rapvy7ulDkBT7nJjvCMAQAc+YHKDwhNA
3lqhIBN1BEDi5OoVb8DxP14e15BGpwZAHgaaJvQ/7z/sKDu0CTf0PzRTZeEo
JPc/IqbhwtegDkC6uhovLkoSQCAQf/RzAO4/YjnajIvvAkBfdC2cM5YGQJDd
j2EpNuE/541/w1B4AUA4Mi2+lZP2P/CV4zkpPPQ/mlZ0ZQ==
         "], {
          {Hue[0.63, 0.7, 0.5], Opacity[0.7], LineBox[CompressedData["
1:eJwVxV2aqiAAANAQRU0sLfwDNKJAKFHBndwlzAbu/t/mm/Nynj////1Ep9Pp
CU6nv0EEIIgBAhnIQQFKUAMCWkDBCDQwwIIVeHBEMIqjLDpHRVRHbfSJdhhD
BGtIYAspnOAMLVzgDn2cxee4iOu4jT/xnlyTWzIlj+SVLIlHGJWoQgRRxBBH
IxJIIoU0Msgih1bkUUBHitMm7VKW8lSkMlXpnLp0S31WZDQbs3dms0/2zcu8
ynVu8zU/zu15L9qCFmPxLmzxKb6Y4Ab3eMAMcyywxAprbLDDoaxKUvalLk1p
y7U8LvXlfpkuy2W/3q6P6+v6vn4rUvXVUOnKVLZaq1Ad9b1u66le6r32t8ft
dZ/uC6GEEU5GIogkimhiiCWOrMSTQI6ma1jDG9HIRjVz45qt8e2n3TvWie7Z
yW7uXLd1vh963qte96Zf+9AfAx/UoAczrEOgIxX0TTU11NIv9fRgnAkmmWKa
zcwwxzbmWeCCS6645oY7Hsb3aMfP+J1e0zL5x0tIoYQWszDCCic24UV4zs9N
KqnlLI10cpNehtfy/iqtjHIqaKOtdnrVQR+zm7fZG2ucWU0wh12tt4fbnHdh
PTb/CxWMPaI=
            "]]}, 
          {Hue[0.63, 0.26, 0.89], EdgeForm[{Hue[0.63, 0.7, 0.33], Opacity[
           0.95]}], DiskBox[1, 0.048635175830869806], 
           DiskBox[2, 0.048635175830869806], DiskBox[3, 0.048635175830869806],
            DiskBox[4, 0.048635175830869806], 
           DiskBox[5, 0.048635175830869806], DiskBox[6, 0.048635175830869806],
            DiskBox[7, 0.048635175830869806], 
           DiskBox[8, 0.048635175830869806], DiskBox[9, 0.048635175830869806],
            DiskBox[10, 0.048635175830869806], 
           DiskBox[11, 0.048635175830869806], 
           DiskBox[12, 0.048635175830869806], 
           DiskBox[13, 0.048635175830869806], 
           DiskBox[14, 0.048635175830869806], 
           DiskBox[15, 0.048635175830869806], 
           DiskBox[16, 0.048635175830869806], 
           DiskBox[17, 0.048635175830869806], 
           DiskBox[18, 0.048635175830869806], 
           DiskBox[19, 0.048635175830869806], 
           DiskBox[20, 0.048635175830869806], 
           DiskBox[21, 0.048635175830869806], 
           DiskBox[22, 0.048635175830869806], 
           DiskBox[23, 0.048635175830869806], 
           DiskBox[24, 0.048635175830869806], 
           DiskBox[25, 0.048635175830869806], 
           DiskBox[26, 0.048635175830869806], 
           DiskBox[27, 0.048635175830869806], 
           DiskBox[28, 0.048635175830869806], 
           DiskBox[29, 0.048635175830869806], 
           DiskBox[30, 0.048635175830869806], 
           DiskBox[31, 0.048635175830869806], 
           DiskBox[32, 0.048635175830869806], 
           DiskBox[33, 0.048635175830869806], 
           DiskBox[34, 0.048635175830869806], 
           DiskBox[35, 0.048635175830869806], 
           DiskBox[36, 0.048635175830869806], 
           DiskBox[37, 0.048635175830869806], 
           DiskBox[38, 0.048635175830869806], 
           DiskBox[39, 0.048635175830869806], 
           DiskBox[40, 0.048635175830869806], 
           DiskBox[41, 0.048635175830869806], 
           DiskBox[42, 0.048635175830869806], 
           DiskBox[43, 0.048635175830869806], 
           DiskBox[44, 0.048635175830869806], 
           DiskBox[45, 0.048635175830869806], 
           DiskBox[46, 0.048635175830869806], 
           DiskBox[47, 0.048635175830869806], 
           DiskBox[48, 0.048635175830869806], 
           DiskBox[49, 0.048635175830869806], 
           DiskBox[50, 0.048635175830869806], 
           DiskBox[51, 0.048635175830869806]}}]],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 
        19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
        36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52}, {
        Null, CompressedData["
1:eJwVxduVoyAAANAICkTUGExURHy/0AkqUsmWMA1stdPP7H7cc9vvv3++we12
+/nn/+/P6/36oL2d8inXq87WTHs6u9ZLX0jKHSIo4e60zuRcjzwbx3W8oFqU
NzhBkAdtMEGMMF6w8rpu6LRTBmXZllN5eT3qZe/VdVcPkCGGGZOsZ4rtXhTV
URcN0RKpqKmbpmsGaJDBhhlplNlNfTZndw6nEwdxnMV5XMZtPMU6viBFFFPK
qKQ9VXSnxtniLdvKrd3GbbvSLB3TNd1SnV7QRz72feozX/q7bx7Vq3pXeVV9
XORKt3e/XvN7ntf5ExVFUwzFUqj7fF9d4QkkRCd6sQrtJl6CkkQkXdInX8np
8Yjzggte84Z3fOALV1xDgggmxCeUMCJJT3ZiHs9n/qw8e7epzaywo53tarW9
7P1Ij+wQx3jMx3ocFodhFPKwCJdQAQgQwIAAH1DAgAQ9UGAH5hcMpy2o
         "]}, {EdgeStyle -> {
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]]}, VertexStyle -> {
           Directive[
            Hue[0.63, 0.26, 0.89], 
            EdgeForm[
             Directive[
              Hue[0.63, 0.7, 0.33], 
              Opacity[0.95]]]]}}]]}, 
      TagBox[GraphicsGroupBox[GraphicsComplexBox[CompressedData["
1:eJwBUQOu/CFib1JlAgAAADQAAAACAAAAChYnqGuS/D8eVFZVF+ELQMt8L11z
3yBAEY+Uok31AkAB2B0nR+8hQHp19O4H1QFAXVTx8W4EHEDnvtvGl3kGQIx4
oPyN1hZABhUebbo4+T9k7CT1ApEfQPmfufqO9wJASufDNiY2IUB1YtesThf6
PxoYkAjwYCFAwyLQ0zj7BEDmC9fUM30JQK4HiBN6afA/LNvVSC9QIkDLDawk
vLADQBUKwR+uSyFAkJe4lFccAkDI7wv0lqbwP8nOxsW1swlA5tfBc9smH0BQ
hpO1H8zlP6o/nb9LUxtAbhQj+F336j8Asm7KyhWhPx/2bdVhl/s/C0TL5jnx
AEBVoNdGfikGQAAAAAAAAAAALt6GYoz09T/y9nIXnAkhQMx+kCDHqQBAGtao
vloVGkBUbyZCaX4BQChmRPOoy+w/kHpp403Vvj8m3LkFVyzyP5TMBgs4itk/
SpzkOU3JCkDxT5ZaUDQDQCjhFebWMAhAuj8DRsdJAkAM3gwn5Gz2P+XuGCFf
4v8/vIMLINqMGUB4COkKJcXyP8Jt7Xjt/hxASJN2TtV63D8ix/YNFzgWQFmr
YHFzcABACARueGjp+j9U324sfIcJQHgLxhH+vCBAAOw31fw7BkDQhTCEdHrg
PxbagQodyes/sB/hyV+6F0Asc0GJ8kfgPzPEFoyXuRlASHrvldFQzT9iw2Ug
xB72Pzq3+WOBLg1AW6bVr+71FkAoKMnuHF3zP4a7oMZifh1AbC2SKkZ1AkAh
34XJLlAZQO6gYyWWJ+I/mMZzZKWgCkBJLTQ2BGMFQMje8R/4KvI/EvTJ3UWc
B0DAPVZmXTEDQF6Z0LZDvuo/znYqpuehHkCF5NuKK/XtP9QB3iJGCSBAp5JN
XqWK9j8w/R6npVoMQIpieGJvFP4/MGDdaBBzA0BosZf2nFgJQIcVGPxiARtA
6mMJvzs5DEAolWcEmuLzPwAAAAAAAAAAFTW238tDEEDcHWReQ+L/P8OO+Pb0
EyJApK/6DmVsBkCpU1vdyBQNQCcExbp4q/k/q21b7qt1GEC3cUV8f9bsP2Zw
X+Bu/CFA6JmlgZMTAEAA8bn7+J0GQNk0X72VhgVAhOzu0dkLD0Ce3ww0icz8
Pzglc54=
         "], {
          {Hue[0.63, 0.7, 0.5], Opacity[0.7], LineBox[CompressedData["
1:eJwVxduVoyAAANAICkTUGExURHy/0AkqUsmWMA1stdPP7H7cc9vvv3++we12
+/nn/07gxE7ptM7kbM4FIEAAAwJ8QAEDEvRAgR0YiCCGBPqQQgYlVHCHxkVu
4gpXur375UVe4nFPeLXXeb03eNqzCCOCfEQRQwkSSKIe7chggn1McYgZXrDC
hviEEkYk6clOzH2+r/fjbn3qM1/6u28oo5L2VNGdmiAO8qAM2mAKo5CHRbiE
KuJREdVRE3XREC2Rejwf+aOKsziPy7iNp3iLdXw982fFJOuZYjsziUi6pE++
kvP1flWv+fV5V+/5/UmzdEzXdEt1eqRXarMxW7Mt09mRXZnNq3zKNS+44DVv
eMcHvnDFddEUQ7EUSnSiF6vQ4hC2bMup3MpL9nKXpvrUTd3VQ302XTM0Zzu1
Wzd0ujuHc1zHbTzGa7TzOn/mY7aLUmbV67Feq90ufWm7m8Ne9heCNi2o
            "]]}, 
          {Hue[0.63, 0.26, 0.89], EdgeForm[{Hue[0.63, 0.7, 0.33], Opacity[
           0.95]}], DiskBox[1, 0.06249796298836899], 
           DiskBox[2, 0.06249796298836899], DiskBox[3, 0.06249796298836899], 
           DiskBox[4, 0.06249796298836899], DiskBox[5, 0.06249796298836899], 
           DiskBox[6, 0.06249796298836899], DiskBox[7, 0.06249796298836899], 
           DiskBox[8, 0.06249796298836899], DiskBox[9, 0.06249796298836899], 
           DiskBox[10, 0.06249796298836899], DiskBox[11, 0.06249796298836899],
            DiskBox[12, 0.06249796298836899], 
           DiskBox[13, 0.06249796298836899], DiskBox[14, 0.06249796298836899],
            DiskBox[15, 0.06249796298836899], 
           DiskBox[16, 0.06249796298836899], DiskBox[17, 0.06249796298836899],
            DiskBox[18, 0.06249796298836899], 
           DiskBox[19, 0.06249796298836899], DiskBox[20, 0.06249796298836899],
            DiskBox[21, 0.06249796298836899], 
           DiskBox[22, 0.06249796298836899], DiskBox[23, 0.06249796298836899],
            DiskBox[24, 0.06249796298836899], 
           DiskBox[25, 0.06249796298836899], DiskBox[26, 0.06249796298836899],
            DiskBox[27, 0.06249796298836899], 
           DiskBox[28, 0.06249796298836899], DiskBox[29, 0.06249796298836899],
            DiskBox[30, 0.06249796298836899], 
           DiskBox[31, 0.06249796298836899], DiskBox[32, 0.06249796298836899],
            DiskBox[33, 0.06249796298836899], 
           DiskBox[34, 0.06249796298836899], DiskBox[35, 0.06249796298836899],
            DiskBox[36, 0.06249796298836899], 
           DiskBox[37, 0.06249796298836899], DiskBox[38, 0.06249796298836899],
            DiskBox[39, 0.06249796298836899], 
           DiskBox[40, 0.06249796298836899], DiskBox[41, 0.06249796298836899],
            DiskBox[42, 0.06249796298836899], 
           DiskBox[43, 0.06249796298836899], DiskBox[44, 0.06249796298836899],
            DiskBox[45, 0.06249796298836899], 
           DiskBox[46, 0.06249796298836899], DiskBox[47, 0.06249796298836899],
            DiskBox[48, 0.06249796298836899], 
           DiskBox[49, 0.06249796298836899], DiskBox[50, 0.06249796298836899],
            DiskBox[51, 0.06249796298836899], 
           DiskBox[52, 0.06249796298836899]}}]],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 
        19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
        36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 
        53}, {Null, CompressedData["
1:eJwVxUmWoyAAANAAiigOoUQ0otFKHDCIlIoX6SPUBfr+u379N//79++fX3i7
3RJwu/1f2awgiliYwSJQxK3OukAQIZSwOMACK2y/fj4rkVKFX6ENf0IHMAgA
ASHIgAAKWOBwH/Sil32vwAKXbCmWxcExG4txXMCJT3E+Po+VHOqwx+Huj/vn
vkLPk+H1vNwFh2wohmEcFkSQRApZdCB3fz/e7897BTves13sw77sdt9PnAZp
KtL++wir6lm56vJmOfczqkkd1lVdr7WtXX0BDjnmGecFF3zgI1+45Ts/uUMd
6R5d9919urU7fOwHfuoLv4cMMY8RxmomWcdmpphlB3PI+AabwBDDjDDS9GY2
yvhJkCRpIpM+mRMDG9R4DWlYI5umb+ZGNQZu3pZtxTZuywZbr5Vt07Zzu4Vx
XMV1/IzX2MUX0EgTHWqmha51p5XWRlt9aAdKXGYlL4tSlOVQjuVS7uUZvuJX
9Xq+XhecvIlNcmqmdprmaQM5zoM8y3Oei7zMbb7nJ6CIYkpoSCmjnApa0Zoq
qqmlOz2oo5cXkShKIhbJqInaqI+maI5UZP4B+mc4KA==
         "]}, {EdgeStyle -> {
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]]}, VertexStyle -> {
           Directive[
            Hue[0.63, 0.26, 0.89], 
            EdgeForm[
             Directive[
              Hue[0.63, 0.7, 0.33], 
              Opacity[0.95]]]]}}]]}, 
      TagBox[GraphicsGroupBox[GraphicsComplexBox[CompressedData["
1:eJwBYQOe/CFib1JlAgAAADUAAAACAAAA8CJ+ILsrEUAAlWZah0IEQEIidrVw
zRZAg2mGwP3j/T+azG4I/1QMQEsOyzG5FvM/+0uh324LFkASsKMATsrqP0Ef
Bxmx7hVABPi3QKBm9T8UzKQ5ZX0TQMrJBjRrQQFAimzHiHdGFEDGdBlQ/lH6
PzTU8CrqOg5AE/JYGK0P9j/thYEqlbQFQMjBx5rksQhAhCD45/N/E0DcZX3z
zvjdP9LbCD+wogxA+1obzXY5AkCi/+VQgGH8Pzj6If149ANAQ//R13zAFUCU
waVKItXaP/QqkRpzUxdAgSOJt/1B9j+8hnf3XcIWQB9DZcf0cwZAAGU55edq
tD84Kg9UeofVP/y9BOcRaBBAQe6ufuJV8j8WUrkSGdwAQNFXOWa94RJAz6S8
pwMPE0DbX/cjy14GQGB12nMo2hNAaP9xnNdaBUBA4imVRgEZQCTVKG+zegVA
RGdUgZ+HEkAlf0oTLJEAQAaEAg/GbhVA5PNj60DDCEAkSL3Z8UcBQHCE4OWL
kwVABBWhVX2w5j9GKzgmLhnlP6lMtCv51AVA9b986Zh+/z/p5xxynYQSQLiX
fKuZh+A/+az9GqBFE0CqzuSwNw/qPzKHcs8trxdAVvzbai0w4j+o5s0jIeTx
Pzq4wWrFeglAmr1efgfTAkCCaACk2UjrP6AFQp5OaBRA7t1brh0C8T/CF9m1
JAYBQAAAAAAAAAAA6Ptzs+Mm+T9SkHyvvg0LQAAAAAAAAAAAGgs1pleT5z8j
ZVztC4wXQMBnEBP/4wlA6KwdHyDsGEB2SkXsnGYHQJIC2ZDIahZAIhxFOjX7
5D+aXn+jGoMUQOBbwD7QSsU/mMucsRL5EEB0p3my1kn3P8i72ya8VhVAFtmB
uhEmBUCUrsLJd5HpP7hpCpXx69Q/g9EZveGLC0DUWj0aNyb8P9770N8hqfU/
Zs39hur78z/cOEp6CTwSQDo7b2AWPPE/WvUMN3M2GUCkniGyktb8P0VSBQ4b
6g5AjskzeLRpAUB+3tJD2sr6P405UccAEBJAE3xQvJvjEkDcOLzZqDsIQC3o
YWsztAhA7EINjQZY8z+KPP2hj1UTQFlSO6GO4ApAwWu3LAWvCUBOFpblDYUB
QO+Bc1K80AFAmju2CGVvB0B/HXmp
         "], {
          {Hue[0.63, 0.7, 0.5], Opacity[0.7], LineBox[CompressedData["
1:eJwVxUmWoyAAANAAiigOoUQ0otFKHDCIlIoX6SPUBfr+u379N//79++fX3i7
3RJwu/0fYBAAAkJAQQZywIEAJVBgARpYsIMTOOjBDDLIYQEb2MIBjnCCC9wQ
QRQxVCOJGtQhhTQyyKIDOS/ymCe9xmu9yZu9zcd+4Cd+6gu/9w0OMMUpzjHH
Ape4xwobbPGOzyAJ0iAPRNAHKjAkIpQwIkhNJGlIRxTRxBBLDuJCGsbhV1iF
dfgKdWjDn9CFV5RELJJRE7VRH03RHKnIUEY5FbSiNVVUU0t3elBHr7iK6/gZ
v+I1dvGVpIlM+mROTCrSPssznhVZmQ3ZmC3Zlu33x/19/9xXVjPJGtaxic1M
Mc0Ms+xg7usn57nIy9zme37yggte8oGPfOGW7/zkriiLoRiLpdhEKXqhhBZG
WLGLsxzKsVzKvTyrunpWr8pV16N7vB+fx1rreq1t7epLNrKVvZzkLJU0Tdv0
zdTMjWpMO7Vzuz1fz6v77j6d7tbu6Ode9eb7eF3vz3sdxmEZ9nEZt2mettko
rYyy6li2ZV/cZ9VGW31otzq728O6/Tycu/4BWrM4KA==
            "]]}, 
          {Hue[0.63, 0.26, 0.89], EdgeForm[{Hue[0.63, 0.7, 0.33], Opacity[
           0.95]}], DiskBox[1, 0.05001586690953075], 
           DiskBox[2, 0.05001586690953075], DiskBox[3, 0.05001586690953075], 
           DiskBox[4, 0.05001586690953075], DiskBox[5, 0.05001586690953075], 
           DiskBox[6, 0.05001586690953075], DiskBox[7, 0.05001586690953075], 
           DiskBox[8, 0.05001586690953075], DiskBox[9, 0.05001586690953075], 
           DiskBox[10, 0.05001586690953075], DiskBox[11, 0.05001586690953075],
            DiskBox[12, 0.05001586690953075], 
           DiskBox[13, 0.05001586690953075], DiskBox[14, 0.05001586690953075],
            DiskBox[15, 0.05001586690953075], 
           DiskBox[16, 0.05001586690953075], DiskBox[17, 0.05001586690953075],
            DiskBox[18, 0.05001586690953075], 
           DiskBox[19, 0.05001586690953075], DiskBox[20, 0.05001586690953075],
            DiskBox[21, 0.05001586690953075], 
           DiskBox[22, 0.05001586690953075], DiskBox[23, 0.05001586690953075],
            DiskBox[24, 0.05001586690953075], 
           DiskBox[25, 0.05001586690953075], DiskBox[26, 0.05001586690953075],
            DiskBox[27, 0.05001586690953075], 
           DiskBox[28, 0.05001586690953075], DiskBox[29, 0.05001586690953075],
            DiskBox[30, 0.05001586690953075], 
           DiskBox[31, 0.05001586690953075], DiskBox[32, 0.05001586690953075],
            DiskBox[33, 0.05001586690953075], 
           DiskBox[34, 0.05001586690953075], DiskBox[35, 0.05001586690953075],
            DiskBox[36, 0.05001586690953075], 
           DiskBox[37, 0.05001586690953075], DiskBox[38, 0.05001586690953075],
            DiskBox[39, 0.05001586690953075], 
           DiskBox[40, 0.05001586690953075], DiskBox[41, 0.05001586690953075],
            DiskBox[42, 0.05001586690953075], 
           DiskBox[43, 0.05001586690953075], DiskBox[44, 0.05001586690953075],
            DiskBox[45, 0.05001586690953075], 
           DiskBox[46, 0.05001586690953075], DiskBox[47, 0.05001586690953075],
            DiskBox[48, 0.05001586690953075], 
           DiskBox[49, 0.05001586690953075], DiskBox[50, 0.05001586690953075],
            DiskBox[51, 0.05001586690953075], 
           DiskBox[52, 0.05001586690953075], 
           DiskBox[53, 0.05001586690953075]}}]],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 
        19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
        36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 
        53, 54}, {Null, CompressedData["
1:eJwVxVuWmyAAANBowhgSRUxAcBQfEKNGRgTRdfR0Cd1A9//X0/tzuz9/f/8J
T6fTr+B0+j+fedvO520yZnuN8RSbePt+gRFMwIBhGIdpMAAhg7Z7fJ8ARhhz
PGDz/Xl9zgc6zHHu4g51uOumznRbd/CynEMelmEbzs/v5+s5Pj+hxJLLUrZS
zoAiiinlVNKBmnOSoAQnNOkSk2zJASDEkEIOWzjAEVhokcWW2sGOdrLGgj7p
Ud/b/rjCa3sdw/26873c213u8x466LCjjrvStU662bk9VFBhRRVXpWqVVGpW
Tu0BCO7BEEyBBRrqRCONNdW9HrQ22uojSEGaDqkNKlDdq7SqumqopspUNmhA
AxvUpE3TN0OjG9scoQDiKqBAAgsquBCNaIUUSgxiFFpY4cQeFrwoykIUbSEL
VcyFK/bL9QIvz8vrMoI1WdGKV7qKtVn7Va9mXe16hAte6MKXYikXsbSLXNQy
L4tb9q/n1/fX6+sTeOChRz711Fde+Mb3fvCT13711vvjHEVxlERdZKItzHFO
85znZS5ymat8yU3uwgxnGc3yjGdFVmYiazOZqWzOlsxle/C+v+N39X5P5zqq
k7rualNv9RE94sejfnQP89jSn5ABdmWQYZYxynLGOCuYYC2TTLGRzUyzhVnm
2H4mEYlJQhDB5EEIJTXpyEQ0MWQlGznA7Zbemlt/+7nZm/8HrSFNUA==
         "]}, {EdgeStyle -> {
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]]}, VertexStyle -> {
           Directive[
            Hue[0.63, 0.26, 0.89], 
            EdgeForm[
             Directive[
              Hue[0.63, 0.7, 0.33], 
              Opacity[0.95]]]]}}]]}, 
      TagBox[GraphicsGroupBox[GraphicsComplexBox[CompressedData["
1:eJwBcQOO/CFib1JlAgAAADYAAAACAAAAd9u2uRJ5F0CJNtIAENQOQGBQ8+Qq
1xBALOQHy1v82T+Go+hAv5QfQEg/2lxFfv0/1cDPvlcNA0C5u/+P7EsGQAHg
HcBohRRAhc9W79LTBUAAOEbNK/uuP8S0cqgQoAtAPSP63ld5H0BVBinudLIC
QBu8l3K5NwpAhxVjD2bT/T/X/P6IUk8RQBC4QPyeagFAgQ6caO/0E0AuaO8l
ZigPQHmqmerakhtAgPYllXi2EUCaMqpN5fAdQCiazV7fRQpAmBKXZ9HcGkCS
1OXMw3v+P/JYFQH1TRhAL8vWkldyAkC2MF2VaxgVQFaYqzZnsA9AIPQngOy3
FUCOF0rNzTT6P0MNfrRUuxJAXHnJwHSP5z9pxScDFdofQBhKuKqDqAVAei1h
O1nX8j+2BuZRGA4KQN8eEfRLextAUJ6aFDWaAUB+j+yfvfYUQFoU3jGzY/s/
6smJ4S6FFECW3OdLjjLtP5tBMIZJZhFAxv3uEZrc9z+Ic6VySRARQBnN0Ut0
O/E/zuqfc8f6DkDAYreJsl7gPwAAAAAAAAAAcDdQ07ifDkCyeTTABW8RQAAA
AAAAAAAAemXIoMyaGEBm1uleJJEMQC3h6mAynRJA5dEFDqix+z/eBkZ1NWke
QIp+3MePwP8/ZjoEtTqAFUCT1Yjx1HQIQKaUkXl2eg5A41GGWGZS8T+58BJ0
WmAcQLBEVN38hARA2XaZK0nKEUC4v6coQkLlP4Vj9y//PBFAhoh4huxp7D9s
9zt4J3b0P5YtcwYEPgxA01u8YIDbF0CClJ0IN44HQG9aopiCmBxALJ0YObXz
EECI+VEI5kEUQGC2pG0YfAdA9DxDbWUOC0DX+2qGNPQFQEh0ch0huRlAczzN
d2ywCkAAfkvS1YHSPyUK91tqShBA8gXZKmwcD0AwEzHPqjTKP80+w0tRRhZA
l8N3otLMAUDNiqyaLlwTQPqMzyfjMhVAvABpLpWiEkBiBnvFy+bgP6NP5T85
rBlA+dRZUv3uAkCm2eP9kXMXQCtfsA+sWQFALi6PzZMYFUAzt5ITp5cFQJIz
3xJLHhJAqCY/fUQj8D/KzVOQPhAeQJz0CCyHRANARm7cjg9EFkBwnZrUvScH
QLD/p7kI+A1A6MRRw/K66D8TjESK9LUaQGvEDfMlIwRARv561A==
         "], {
          {Hue[0.63, 0.7, 0.5], Opacity[0.7], LineBox[CompressedData["
1:eJwVxVuWmyAAANBowhgSRUxAcBQfEKNGRgTRdfR0Cd1A9//X0/tzuz9/f/8J
T6fTr+B0+n8AgnuQBlXQBO9gCKbABj7MwjxkIQ+LsAxF2IYyVOEcLqEL93N0
Ts7kXJ+783Y+LtcLvDwvr8sIILgBBFKAAQUMVECABvRgACOYgAYGrMAC//X8
+v56fX2iOEqiR0SiOuoiE21XeGVXcW2v43WHGFLIIIcCNrCFCg5whBpa6KC/
pbfm1t9+bvbm7/G9ur/vU/yISdzF73iKTbwlKMEJSWhSJ13SJzoxyZpsyYEw
IogigRrUoR5pZNCKLNqQR0dapU06pD+pTT3OMMEU55hhjgXusMQKD1jjBRu8
YotdRrM8YxnPiqzMRNZmMlPZnC2Zy/YHedSP7mEe2/P7+XqOzw+hpCYdmYgm
hqxkIwfNKaOcCiqpogPVdKGGrtRSR33Ocp6XuchlrvIlN7ljnBVMsJZJptjI
ZqbZwixzbOcFL7ngLZdc8Zkv3PG9KAtRtIUsVDEXS+GK/fv1/Sllqcq5XEpX
7lVXvauhmipT2cqLRrRCCiUGMQotFrEKK5zwYq+72tRbfTR9MzS6WRvb+OZo
ZavauV1a1+7d1Jlu6w6p5CwX6eSuZrUop/bX+Pr0ul972/v+eE/DOEyDHsxg
Bz/ayUx28vMyu3nXRq/aaq+PxS27WY01mzlWu/r1sN7t/vgHXGpNUA==
            "]]}, 
          {Hue[0.63, 0.26, 0.89], EdgeForm[{Hue[0.63, 0.7, 0.33], Opacity[
           0.95]}], DiskBox[1, 0.05767655921941052], 
           DiskBox[2, 0.05767655921941052], DiskBox[3, 0.05767655921941052], 
           DiskBox[4, 0.05767655921941052], DiskBox[5, 0.05767655921941052], 
           DiskBox[6, 0.05767655921941052], DiskBox[7, 0.05767655921941052], 
           DiskBox[8, 0.05767655921941052], DiskBox[9, 0.05767655921941052], 
           DiskBox[10, 0.05767655921941052], DiskBox[11, 0.05767655921941052],
            DiskBox[12, 0.05767655921941052], 
           DiskBox[13, 0.05767655921941052], DiskBox[14, 0.05767655921941052],
            DiskBox[15, 0.05767655921941052], 
           DiskBox[16, 0.05767655921941052], DiskBox[17, 0.05767655921941052],
            DiskBox[18, 0.05767655921941052], 
           DiskBox[19, 0.05767655921941052], DiskBox[20, 0.05767655921941052],
            DiskBox[21, 0.05767655921941052], 
           DiskBox[22, 0.05767655921941052], DiskBox[23, 0.05767655921941052],
            DiskBox[24, 0.05767655921941052], 
           DiskBox[25, 0.05767655921941052], DiskBox[26, 0.05767655921941052],
            DiskBox[27, 0.05767655921941052], 
           DiskBox[28, 0.05767655921941052], DiskBox[29, 0.05767655921941052],
            DiskBox[30, 0.05767655921941052], 
           DiskBox[31, 0.05767655921941052], DiskBox[32, 0.05767655921941052],
            DiskBox[33, 0.05767655921941052], 
           DiskBox[34, 0.05767655921941052], DiskBox[35, 0.05767655921941052],
            DiskBox[36, 0.05767655921941052], 
           DiskBox[37, 0.05767655921941052], DiskBox[38, 0.05767655921941052],
            DiskBox[39, 0.05767655921941052], 
           DiskBox[40, 0.05767655921941052], DiskBox[41, 0.05767655921941052],
            DiskBox[42, 0.05767655921941052], 
           DiskBox[43, 0.05767655921941052], DiskBox[44, 0.05767655921941052],
            DiskBox[45, 0.05767655921941052], 
           DiskBox[46, 0.05767655921941052], DiskBox[47, 0.05767655921941052],
            DiskBox[48, 0.05767655921941052], 
           DiskBox[49, 0.05767655921941052], DiskBox[50, 0.05767655921941052],
            DiskBox[51, 0.05767655921941052], 
           DiskBox[52, 0.05767655921941052], DiskBox[53, 0.05767655921941052],
            DiskBox[54, 0.05767655921941052]}}]],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 
        19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
        36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 
        53, 54, 55}, {Null, CompressedData["
1:eJwVxVvaoiAAANBEUQstyWvyo4h4wYS0JPYxS/g3MPt/m2/Oy+l+//75BafT
KXBOp/+vhzv7kz+6POF8Psfx4zEFa3As63Kci7goHhWvluqIr9fi+rhOTuCU
zprkeemLSnAhRh9jgUc8+VGEIxGN0eTY2BaW29k693t+L4EPIoDBAwgwggkg
H6EIYcSRQCOaqn3Z98P9zt9kuA/5UA7BZ/msn8/hZEmW8cx6Zy/2Mq/wuDd7
1qWIJhTTjFJOBR3pTL/UOpfgclm9/tzHfdYXfW9B6qcojVKcpiId08nrzl3c
FV3XdxYwxCKGWcEejAk2MVv9gNqvUR3VuE7rmtWiHuspae5N3pRNM7i32+y2
t5a27dx+AYQ+RDCCGKawhhQyyKGAo6ugQgqrWlHVKq6EGtWs1NcxibmbzOSm
NI3hZjDGupu33Ta6tRvf+m3e1LZ9HR3oTFeaaa6FXvSq9a4PbbR1pCcDmclC
MsmlkFLLQxppq/fPe3nv7+SZP3+ezXN4hkmYhXnYhDwcwmdoIAkJIgnJSEUI
JYxwIogkC1FEk50cxDiv4HV5ra/X5x+i2Dtm
         "]}, {EdgeStyle -> {
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]]}, VertexStyle -> {
           Directive[
            Hue[0.63, 0.26, 0.89], 
            EdgeForm[
             Directive[
              Hue[0.63, 0.7, 0.33], 
              Opacity[0.95]]]]}}]]}, 
      TagBox[GraphicsGroupBox[GraphicsComplexBox[CompressedData["
1:eJwBgQN+/CFib1JlAgAAADcAAAACAAAAeSi3BS2t9D+2rKN2yC73P3Kc4t1b
QBNA4IUsgcm++j8n7m4qbMoMQEGXfczizQ1AMWor8aj4CkDIejfq/qD4P97I
uNIt2BBAZ6nqmEDiAkCVtimYON4UQGJ70fJyhwBAYWbWkf838z/a0/Ra4Iji
P6s3kQuPMfo//LyQ7kgsCUC9FJDTeWINQBAjaak37bE/+AE43DYz4z8AAAAA
AAAAAKVYPaa5ChFAzFSaihwGAUCM4ZDgtNITQFy+OVhbSv4/QPnhEAvzD0B8
+SClQ1jeP2aCPXQz6RNAcP/wLdmFvD/mlV/u5PMPQNIMWnYhaBFALlm6aOHC
/j+s2n2xJrMJQIZ5mqjffRJALk/GcSIsAkC8wolywz/hP05o423VoAZAxkRE
lgOwFEDQ8LR02IcCQKNfvDzk8wJAPjc7sDYlAUC7uNp9g6DwP/44FepDZAtA
rJeg14Y9DkCe+A3/eyfnP4bWJT0Yauk/MgRpIYWjBkDG6k9rMTX6P4zg4XJ3
cABAu+v6LgFTE0Aos4cOSW7kP94kOMoXSxNAbXcwkq8lAUBjTf4ZIvQEQHD+
AqRAbAFAAAAAAAAAAAB6AuB13zYGQK0izwcj7AtAtdXKVh1TBkBkEHBkfNfo
P3mDxW8PVwtAXthZVvnUEEC1HMq0+D8OQHCyYBsOSg9Ax5QknQMn+T8yFRHM
LpoKQFAUGB7U/to/YmSRyLVhB0DM76C61TcEQM56OudpQwtA4P0UEBrQ8j/w
e2UMLfMNQHNbyo84wwBAf0NMLun08D9mQ5e162YNQOpgz4PlABNA/d2HMCn1
BEB5Qe3qupIUQDkbTay7C/Y/kBED1dr8C0ApBYQPBF8JQMadvgF5IQRA+kK+
Zb5N9z/yADs9+g7wP1iqwMnwXfY/QBrzjktY4z9zgUcUYXoOQKiHKtF4Luo/
BMH3fCzn5T9uny0rIgwQQF4r0HfAJQdAMO2be2bRAECfqI6pQdH4P4hRB2mk
H9E/EAsmBrarzT8wOnEvXNUNQAbADTXoFghAG87Zx9iY8j/fZ7TZQjf9PxDt
XyIUF8s/VDhLTOC7/j84ZHC6LIDTP0aiES8Wf+M/Hp5niFFg9z8axbAh/yfy
P15XAhJ2/Po///DlrdVoBEDjmjW24XEPQEw8TNer8w5A5TB+XIl9B0AAUxCP
UEL6P+NGiJk=
         "], {
          {Hue[0.63, 0.7, 0.5], Opacity[0.7], LineBox[CompressedData["
1:eJwVxVvaoiAAANBEUQstyWvyo4h4wYS0JPYxS/g3MPt/m2/Oy+l+//75BafT
KXBOp/87gXNx7k7mlI50Vkc7L8c4FkDgAwQigEEKHqAGDAgwgsm9udRtXe7O
rnI39+udvdjLvMLrPO713uxJb/Ms9CGCEcQwhTUkkEIGORRwhMpHfuRjP/Vr
X/ijPwWXQAZroINX8AmOMAmzMA9J2IQ8HMJnaM7xuTh35/6yXl4oQhilqEYE
UcQQRwKNaEIqwlEa1RGLRDRGU3yNi/gRd3Ef22txfVynW3ubb1uSJXlCEpo0
CU+G5JkYnOIaU8ywwCOesLrn9/Le3Ie7SetUpGM6ZSSjGc/6TGY6M5nNy7zJ
h/yZm+JRsKIr+kIWtmzKoTQVqX4qXolqqXS1V+/qeLDHVLNa1GM91YpQwggn
gkiyEEU02clBzM/z501byqmgI52pohv9UtsMzbMx7dyqdmu/TLCJSaaZ7frO
csFnLrnimm/ccNtvvRWjkEIJPTwHM6pZzdv8na3U8pBG2mVd9LIv7+WzHKte
X+tnPdSmvnrXhzbavj7bd3/vx+cw9h9ukDtm
            "]]}, 
          {Hue[0.63, 0.26, 0.89], EdgeForm[{Hue[0.63, 0.7, 0.33], Opacity[
           0.95]}], DiskBox[1, 0.0442750620937018], 
           DiskBox[2, 0.0442750620937018], DiskBox[3, 0.0442750620937018], 
           DiskBox[4, 0.0442750620937018], DiskBox[5, 0.0442750620937018], 
           DiskBox[6, 0.0442750620937018], DiskBox[7, 0.0442750620937018], 
           DiskBox[8, 0.0442750620937018], DiskBox[9, 0.0442750620937018], 
           DiskBox[10, 0.0442750620937018], DiskBox[11, 0.0442750620937018], 
           DiskBox[12, 0.0442750620937018], DiskBox[13, 0.0442750620937018], 
           DiskBox[14, 0.0442750620937018], DiskBox[15, 0.0442750620937018], 
           DiskBox[16, 0.0442750620937018], DiskBox[17, 0.0442750620937018], 
           DiskBox[18, 0.0442750620937018], DiskBox[19, 0.0442750620937018], 
           DiskBox[20, 0.0442750620937018], DiskBox[21, 0.0442750620937018], 
           DiskBox[22, 0.0442750620937018], DiskBox[23, 0.0442750620937018], 
           DiskBox[24, 0.0442750620937018], DiskBox[25, 0.0442750620937018], 
           DiskBox[26, 0.0442750620937018], DiskBox[27, 0.0442750620937018], 
           DiskBox[28, 0.0442750620937018], DiskBox[29, 0.0442750620937018], 
           DiskBox[30, 0.0442750620937018], DiskBox[31, 0.0442750620937018], 
           DiskBox[32, 0.0442750620937018], DiskBox[33, 0.0442750620937018], 
           DiskBox[34, 0.0442750620937018], DiskBox[35, 0.0442750620937018], 
           DiskBox[36, 0.0442750620937018], DiskBox[37, 0.0442750620937018], 
           DiskBox[38, 0.0442750620937018], DiskBox[39, 0.0442750620937018], 
           DiskBox[40, 0.0442750620937018], DiskBox[41, 0.0442750620937018], 
           DiskBox[42, 0.0442750620937018], DiskBox[43, 0.0442750620937018], 
           DiskBox[44, 0.0442750620937018], DiskBox[45, 0.0442750620937018], 
           DiskBox[46, 0.0442750620937018], DiskBox[47, 0.0442750620937018], 
           DiskBox[48, 0.0442750620937018], DiskBox[49, 0.0442750620937018], 
           DiskBox[50, 0.0442750620937018], DiskBox[51, 0.0442750620937018], 
           DiskBox[52, 0.0442750620937018], DiskBox[53, 0.0442750620937018], 
           DiskBox[54, 0.0442750620937018], 
           DiskBox[55, 0.0442750620937018]}}]],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    FormatType->TraditionalForm,
    FrameTicks->None]}], "}"}]], "Output",
 CellChangeTimes->{3.8348834545157003`*^9, 3.8348835002469926`*^9},
 CellLabel->"Out[66]=",ExpressionUUID->"9060a607-e95a-42ce-bdcf-3c89b813d20b"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"points", "=", 
   RowBox[{"VertexList", "/@", "dataindex"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834784420352569*^9, 3.8347844264642625`*^9}, {
  3.8348756828269844`*^9, 3.8348756865131674`*^9}, {3.834878831782991*^9, 
  3.8348788488376627`*^9}},
 CellLabel->"In[67]:=",ExpressionUUID->"b6aaa058-14be-4398-a579-b0279e22d542"],

Cell[BoxData[
 RowBox[{
  RowBox[{"coordpoints", "=", 
   RowBox[{"VertexList", "/@", "data"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834879134322084*^9, 3.834879146224797*^9}},
 CellLabel->"In[68]:=",ExpressionUUID->"9eff3271-3c87-4db7-8b7f-65ef364be904"],

Cell["Kretchmann \[OpenCurlyDoubleQuote]real\[CloseCurlyDoubleQuote] \
values:", "Text",
 CellChangeTimes->{
  3.8347933561184683`*^9, {3.8347935444076195`*^9, 
   3.834793546974228*^9}},ExpressionUUID->"09d23ad9-c2a2-4dea-ba3d-\
98fceb0d633f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rval", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Sinh", "[", "\[Nu]", "]"}], "\[Equal]", "#"}], ",", 
        RowBox[{"{", "\[Nu]", "}"}]}], "]"}], "&"}], ",", 
     RowBox[{"coordpoints", "\[LeftDoubleBracket]", 
      RowBox[{";;", ",", ";;", ",", "3"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"{", "2", "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834105426841242*^9, 3.8341054487325706`*^9}, {
   3.8341407674337025`*^9, 3.834140799285215*^9}, {3.8341408938375945`*^9, 
   3.834140946496229*^9}, {3.8341410168099756`*^9, 3.8341410671886864`*^9}, {
   3.8341411610986195`*^9, 3.834141210381962*^9}, {3.834141332672348*^9, 
   3.834141336755044*^9}, {3.834141461053176*^9, 3.834141468978607*^9}, {
   3.834141967115094*^9, 3.8341420256686225`*^9}, {3.8341640069512*^9, 
   3.834164012603241*^9}, {3.834164792400744*^9, 3.8341647947633886`*^9}, {
   3.83466546628111*^9, 3.834665483801684*^9}, {3.8347933895124626`*^9, 
   3.834793417249506*^9}, 3.8347960586942053`*^9, 3.834879156483405*^9, {
   3.8348862453609915`*^9, 3.8348862641404076`*^9}, 3.834886374221485*^9},
 CellLabel->
  "In[405]:=",ExpressionUUID->"b80a565a-6097-4f67-ad5c-41af974bbc35"],

Cell[BoxData[
 RowBox[{
  RowBox[{"kr", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"KHyperboloid", "/.", "rval"}], ")"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834792366597866*^9, 3.834792376019791*^9}, {
   3.834793346399704*^9, 3.8347933590872536`*^9}, {3.834793445378667*^9, 
   3.8347934527754736`*^9}, {3.834793487784485*^9, 3.834793489659489*^9}, 
   3.8348550102643666`*^9, {3.8348863808528233`*^9, 3.83488645374378*^9}, {
   3.834886485165092*^9, 3.834886521271514*^9}, 3.8348865820814276`*^9},
 CellLabel->
  "In[406]:=",ExpressionUUID->"e54d1532-357e-4bc4-85ae-ce9901242dc7"],

Cell["Estimated values:", "Text",
 CellChangeTimes->{{3.8347935506105833`*^9, 3.834793553751834*^9}},
 Background->GrayLevel[
  0.5],ExpressionUUID->"c15bc9e0-7f29-4b6a-bba5-1f0f4b00f11c"],

Cell[TextData[{
 "Let\[CloseCurlyQuote]s use a fix radio of 3, to ",
 StyleBox["only",
  FontWeight->"Bold"],
 " variate the density of vertices:"
}], "Text",
 CellChangeTimes->{{3.834793779215767*^9, 3.8347938725231647`*^9}, 
   3.8347966715035477`*^9, {3.834879774160512*^9, 3.8348797758189936`*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"5f423e53-0f38-4c12-9210-37b09147d1bf"],

Cell["Cubic Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.834795179278664*^9}},ExpressionUUID->"de3050bd-45b6-430f-9a22-\
5092b42b49c1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CMD3", "=", 
  RowBox[{"ParallelMap", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Apply", "[", 
       RowBox[{"MeanDeviationfor3", ",", "#"}], "]"}], "/", "3"}], "&"}], ",", 
    RowBox[{"ParallelTable", "[", 
     RowBox[{
      RowBox[{"Thread", "[", 
       RowBox[{"{", 
        RowBox[{"3", ",", 
         RowBox[{"Sequence", "@@", "a"}]}], "}"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"a", ",", 
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"dataindex", ",", "points"}], "}"}], "]"}]}], "}"}]}], 
     "]"}], ",", 
    RowBox[{"{", "2", "}"}]}], "]"}], 
  RowBox[{"(*", 
   RowBox[{
   "too", " ", "slow", " ", "for", " ", "more", " ", "than", " ", "2", " ", 
    "graphs"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.834882121719149*^9, 3.8348821764521933`*^9}, {
   3.8348822463555527`*^9, 3.83488228399026*^9}, {3.8348824012796354`*^9, 
   3.8348824584678416`*^9}, {3.834882605199316*^9, 3.8348826069083853`*^9}, {
   3.8348827738458366`*^9, 3.834882869236432*^9}, {3.8348829858179617`*^9, 
   3.834883003000342*^9}, {3.8348832033232975`*^9, 3.8348832185433016`*^9}, 
   3.834883519669325*^9, {3.8348836516794777`*^9, 3.8348836522560787`*^9}, {
   3.834883798924737*^9, 3.8348838193867736`*^9}, {3.8348845633372416`*^9, 
   3.834884563606303*^9}},
 CellLabel->"In[81]:=",ExpressionUUID->"d7345451-1d7c-446f-937c-0e87df2ad786"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "24.177083333333332`", ",", "0.9697314519799722`", ",", 
     "43.940197530864175`", ",", "8.675011379153387`", ",", 
     "19.579177691837973`", ",", "21.87224169757318`", ",", 
     "3.080478203819797`", ",", "24.177083333333332`", ",", 
     "0.5400795440567466`", ",", "2.58203125`", ",", "18.673128936094585`", 
     ",", "5.499661807580172`", ",", "1.501457725947521`", ",", 
     "6.161408321902152`", ",", "14.6745369428048`", ",", 
     "11.367893814174803`", ",", "43.940197530864175`", ",", 
     "7.78963185574756`", ",", "19.579177691837973`", ",", 
     "5.055890075612499`", ",", "2.58203125`", ",", "23.17724609375`", ",", 
     "20.38529813381884`", ",", "20.466303999999987`", ",", 
     "13.537541915731147`", ",", "0.2677318653284563`", ",", 
     "8.164197530864188`", ",", "2.6527474740693515`", ",", 
     "0.5400795440567466`", ",", "3.0389803383630545`", ",", 
     "6.478134110787174`", ",", "3.35546875`", ",", "0.26813467154509857`", 
     ",", "3.1252391661911294`", ",", "8.60013654984069`", ",", 
     "3.8272161467753745`", ",", 
     RowBox[{"-", "0.2067738578765404`"}], ",", "23.563776000000008`", ",", 
     "1.8994169096209927`", ",", "9.82459305424577`", ",", 
     "5.2455079679588135`", ",", "0.185913393960949`", ",", 
     "3.742621616120495`", ",", "21.87224169757318`", ",", 
     "18.136763376345865`", ",", "34.86612654320987`", ",", 
     "17.13600000000001`", ",", "5.2455079679588135`", ",", 
     "16.126204436426264`", ",", "4.310188932541013`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "2.77560309512972`", ",", "11.85511370262391`", ",", 
     "27.782183991835556`", ",", "11.85511370262391`", ",", 
     "5.368421052631579`", ",", "2.419753086419752`", ",", 
     "38.15542857142857`", ",", "3.0358939186099683`", ",", "9.89453125`", 
     ",", "0.06873600000000074`", ",", "2.2777777777777777`", ",", 
     "2.4957672392537216`", ",", "16.12353515625`", ",", 
     "1.6463464278444917`", ",", "2.7706354268067557`", ",", 
     "9.184641975308647`", ",", "25.423607683651525`", ",", 
     "0.5384615384615384`", ",", "0.7201503200731585`", ",", 
     "2.419753086419752`", ",", "38.15542857142857`", ",", 
     "9.443358600583084`", ",", "11.122904213442197`", ",", "32.450176`", ",",
      "28.18444799999998`", ",", "1.8034698935704905`", ",", 
     "2.2830343364197496`", ",", "2.4957672392537216`", ",", 
     "20.142440589007144`", ",", "7.426447003936442`", ",", 
     "0.5384615384615384`", ",", "18.57062359128475`", ",", 
     "2.6181984453589395`", ",", "2.2830343364197496`", ",", 
     "1.0044539280936169`", ",", "5.35282111094912`", ",", 
     "2.4957672392537216`", ",", "10.35546875`", ",", "12.31486257916239`", 
     ",", "10.35546875`", ",", "2.1068999028182684`", ",", 
     "10.95794677734375`", ",", "5.35282111094912`", ",", 
     "0.5285883668526692`", ",", "2.2830343364197496`", ",", 
     "19.14996337890625`", ",", "11.122904213442197`", ",", 
     "6.892701320750999`", ",", "66.72101644890758`", ",", 
     "2.180323826744469`", ",", "26.40283203125`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "1.7134133930388764`", ",", "1.5228984327294914`", ",", 
     "12.167809785093747`", ",", "5.169530864197534`", ",", 
     "23.539193588780343`", ",", "21.777391975308625`", ",", "13.`", ",", 
     "16.824318413762942`", ",", "0.8679680000000004`", ",", 
     "10.089620484682214`", ",", "1.5228984327294914`", ",", 
     "4.352534093222065`", ",", "12.25060478084381`", ",", 
     "18.253644314868804`", ",", "0.26044703595723967`", ",", 
     "0.9285389167045976`", ",", "0.26044703595723967`", ",", 
     "1.5228984327294914`", ",", "9.307692307692307`", ",", 
     "0.23323615160349911`", ",", "0.23323615160349911`", ",", 
     "3.3949850626028018`", ",", "0.5119999999999998`", ",", 
     "3.4833580246913565`", ",", "17.62798833819241`", ",", "9.51626615184`", 
     ",", "2.6575302522233573`", ",", "1.7134133930388764`", ",", 
     "3.90649291266575`", ",", "0.6852500000000009`", ",", 
     "0.4661937758825703`", ",", "2.436992000000001`", ",", "6.04931640625`", 
     ",", "3.7070330361225388`", ",", "8.653597608024695`", ",", 
     "0.18131124687358974`", ",", "3.0066573518533737`", ",", 
     "4.352534093222065`", ",", "0.78125`", ",", "12.25060478084381`", ",", 
     "17.832271532951793`", ",", "2.8903527226824917`", ",", 
     "1.4402332361516026`", ",", 
     RowBox[{"-", "0.3514880000000006`"}], ",", "0.23323615160349911`", ",", 
     RowBox[{"-", "0.005424508917563664`"}], ",", "4.2006123341595`", ",", 
     "2.5534162301765813`", ",", "2.3033580246913594`", ",", 
     "12.167809785093747`", ",", "0.42457599999999973`", ",", 
     "2.9030000000000027`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "38.511379153390976`", ",", "9.859526835868632`", ",", 
     "19.08139003200732`", ",", "23.47725194330134`", ",", 
     "8.17376708984375`", ",", "10.57581148669061`", ",", 
     "11.482624599908554`", ",", "13.698907601274474`", ",", 
     "2.154320987654323`", ",", "14.693900842536324`", ",", 
     "29.308544000000012`", ",", "11.339696320412568`", ",", 
     "21.927113702623902`", ",", "21.314300025043824`", ",", 
     "19.298697333604714`", ",", "0.47775000000000106`", ",", 
     "49.8431741129871`", ",", "1.2287506662839824`", ",", 
     "14.730824745728563`", ",", "41.41176470588235`", ",", "7.74169921875`", 
     ",", "15.292641975308642`", ",", "30.98127417056788`", ",", 
     "5.764718749999998`", ",", "4.8046647230320705`", ",", "12.11181640625`",
      ",", "17.030915377127318`", ",", "29.09811800401819`", ",", 
     "4.538666666666677`", ",", "1.3599999999999999`", ",", 
     "10.009895387472621`", ",", "29.317561195620996`", ",", 
     "3.970285714285711`", ",", "4.702623906705535`", ",", 
     "0.47775000000000106`", ",", "9.34375`", ",", "7.74169921875`", ",", 
     "23.47725194330134`", ",", "19.23766591535186`", ",", 
     "11.315382140256393`", ",", "23.496913580246915`", ",", 
     "4.8046647230320705`", ",", "12.816372842893196`", ",", 
     "4.1764705882352935`", ",", "13.954952838105466`", ",", 
     "8.46478271484375`", ",", "30.624000000000017`", ",", 
     "1.2287506662839824`", ",", "15.659881945857927`", ",", 
     "14.065292146080292`", ",", "17.33955387082666`", ",", 
     "40.28715134887975`", ",", "5.764718749999998`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "10.692002448028738`", ",", "19.50439453125`", ",", "39.92158024691358`", 
     ",", "8.457833219021484`", ",", "53.84000000000001`", ",", "0.`", ",", 
     "35.60223388671875`", ",", "7.8524963556851315`", ",", 
     "9.381376000000014`", ",", "5.7686046342914405`", ",", 
     "2.916560744597972`", ",", "28.10330864197529`", ",", 
     "27.19794826130914`", ",", "30.015580794620522`", ",", 
     "11.582906250000008`", ",", "1.7696859353664056`", ",", 
     "10.388439461582358`", ",", "22.141748059103442`", ",", 
     "1.5550732300043588`", ",", "22.222641354709076`", ",", 
     "0.6090122894856649`", ",", "18.417441509180627`", ",", 
     "11.007744000000004`", ",", "14.068965517241377`", ",", 
     "26.970109475583246`", ",", "0.`", ",", "10.730047376093262`", ",", 
     "5.321607627188284`", ",", "27.770447530864207`", ",", 
     "16.98504638671875`", ",", "48.26491222181201`", ",", 
     "24.278920896204852`", ",", "17.14112609329446`", ",", 
     "10.388439461582358`", ",", "14.068965517241377`", ",", 
     "1.5550732300043588`", ",", "4.682215743440224`", ",", 
     "2.916560744597972`", ",", "64.76363697945771`", ",", 
     "23.20797492345823`", ",", "8.573509330905782`", ",", "0.`", ",", 
     "44.26036327852718`", ",", "20.726527999999988`", ",", 
     "1.1024787808641954`", ",", "10.388439461582358`", ",", 
     "75.89315361222981`", ",", "29.310344827586206`", ",", 
     "53.84000000000001`", ",", "14.068965517241377`", ",", 
     "16.95301963621522`", ",", "66.0352587463557`", ",", 
     "29.433013260173745`", ",", "16.585710177996678`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "6.073678559510161`", ",", "2.6103856869524398`", ",", 
     "7.596030237518314`", ",", "7.401619492349274`", ",", 
     "4.894162241130836`", ",", "6.379376321707898`", ",", 
     "1.5493287261994753`", ",", "4.382896015549077`", ",", "5.1875`", ",", 
     "2.9912536443148707`", ",", "4.76658950617284`", ",", 
     "3.3979464062108726`", ",", "6.19267177770579`", ",", 
     "10.825517790309743`", ",", 
     RowBox[{"-", "0.35275375512061996`"}], ",", "5.4434062500000024`", ",", 
     "15.800583090379021`", ",", "2.99956362659864`", ",", 
     "6.379376321707898`", ",", "11.59278737791135`", ",", 
     "0.6387871720116607`", ",", "18.768474049999273`", ",", 
     "2.99956362659864`", ",", "6.995536839074257`", ",", 
     "15.661534256559769`", ",", "10.4375`", ",", "9.84573300219559`", ",", 
     "4.197579610289617`", ",", "8.68310546875`", ",", "0.6387871720116607`", 
     ",", "6.39661922725194`", ",", "16.63043212890625`", ",", 
     "3.7891876327250484`", ",", "8.933333333333334`", ",", 
     "6.302197645176038`", ",", "5.670262568695304`", ",", 
     "0.6387871720116607`", ",", "11.110868198445367`", ",", 
     "4.086419753086417`", ",", "7.158246093157335`", ",", 
     "7.809884822860477`", ",", "1.3842500000000002`", ",", 
     "5.358469135802473`", ",", "3.269621313013815`", ",", 
     "12.082637899450443`", ",", "12.947916666666666`", ",", 
     "4.141399416909621`", ",", "16.821007321993513`", ",", 
     "1.5832025605852764`", ",", "2.049079027895681`", ",", 
     "4.133475795183695`", ",", "1.0819343886478743`", ",", 
     "8.071309361250186`", ",", "6.39661922725194`", ",", 
     "30.280749885688124`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.8348824437388287`*^9, 3.8348824691966743`*^9}, {
   3.834882818803832*^9, 3.8348828501843004`*^9}, 3.834882884661211*^9, 
   3.8348832970437517`*^9, 3.834883617597027*^9, 3.8348837551608667`*^9, 
   3.834884641547076*^9},
 CellLabel->"Out[81]=",ExpressionUUID->"93053d74-76b8-41a6-9b84-b6b45edc3018"]
}, Open  ]],

Cell["Absolute Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.8347951985065947`*^9}},ExpressionUUID->"9affb6cb-ecf7-4752-bff4-\
9869904ab722"],

Cell[BoxData[
 RowBox[{
  RowBox[{"AMD3", "=", 
   RowBox[{"ParallelMap", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Apply", "[", 
        RowBox[{"MeanDeviationfor", ",", "#"}], "]"}], "/", "3"}], "&"}], ",", 
     RowBox[{"ParallelTable", "[", 
      RowBox[{
       RowBox[{"Thread", "[", 
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"Sequence", "@@", "a"}]}], "}"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{"dataindex", ",", "points"}], "}"}], "]"}]}], "}"}]}], 
      "]"}], ",", 
     RowBox[{"{", "2", "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834794464023734*^9, 3.834794467301902*^9}, {
   3.8347949155783987`*^9, 3.834794915863781*^9}, 3.8347951136792545`*^9, {
   3.834797166245803*^9, 3.8347971667319508`*^9}, {3.834883830833621*^9, 
   3.8348838357865515`*^9}, 3.8348840006093307`*^9, {3.8348840405182867`*^9, 
   3.8348840453059645`*^9}, {3.8348845664009905`*^9, 
   3.8348845665439935`*^9}, {3.8348859046490126`*^9, 
   3.834885904992747*^9}},ExpressionUUID->"07dc6cab-f372-4688-9dd4-\
987ee4b87a83"],

Cell[CellGroupData[{

Cell[BoxData["AMD3"], "Input",
 CellChangeTimes->{{3.8348841735669785`*^9, 3.834884174780715*^9}, {
  3.8348859089145603`*^9, 3.8348859093052444`*^9}},
 CellLabel->"In[87]:=",ExpressionUUID->"5c60a2bb-3ef0-4843-957d-e294ffe13824"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "0.8333333333333333`", ",", "0.5700197238658776`", ",", 
     "1.2422222222222221`", ",", "0.7850098619329389`", ",", 
     "0.7635524798154556`", ",", "0.8577960676726109`", ",", 
     "0.7719298245614035`", ",", "0.8333333333333333`", ",", 
     "0.5652001585414188`", ",", "0.6119791666666666`", ",", 
     "0.7923058193328464`", ",", "0.6568707482993196`", ",", 
     "0.7210884353741496`", ",", "0.7705761316872428`", ",", 
     "0.7577854671280276`", ",", "0.8356290174471993`", ",", 
     "1.2422222222222221`", ",", "0.7906336088154269`", ",", 
     "0.7635524798154556`", ",", "0.6238130021913806`", ",", 
     "0.6119791666666666`", ",", "1.1184895833333333`", ",", 
     "1.1617357001972386`", ",", "1.2735999999999998`", ",", 
     "0.7663896583564173`", ",", "0.6458550121401319`", ",", 
     "0.7407407407407407`", ",", "0.5182101977107179`", ",", 
     "0.5652001585414188`", ",", "0.742798353909465`", ",", 
     "0.6530612244897958`", ",", "0.59375`", ",", "0.6534859521331946`", ",", 
     "0.5966007630939993`", ",", "0.834319526627219`", ",", 
     "0.8656259565350474`", ",", "0.5848074921956296`", ",", 
     "1.0058666666666665`", ",", "0.5952380952380952`", ",", 
     "0.7316686484344035`", ",", "0.5816186556927297`", ",", 
     "0.6886145404663924`", ",", "0.8494809688581315`", ",", 
     "0.8577960676726109`", ",", "0.9451795841209829`", ",", 
     "1.0416666666666665`", ",", "0.8533333333333332`", ",", 
     "0.5816186556927297`", ",", "0.8450257629805786`", ",", 
     "0.6997808619430241`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.5759368836291914`", ",", "0.8272108843537415`", ",", 
     "0.8550323176361957`", ",", "0.8272108843537415`", ",", 
     "0.9298245614035087`", ",", "0.6984126984126984`", ",", 
     "1.196190476190476`", ",", "0.8220164609053496`", ",", "0.9296875`", ",",
      "0.5045333333333333`", ",", "0.8425925925925926`", ",", 
     "0.7145557655954631`", ",", "1.1197916666666665`", ",", 
     "0.4844290657439446`", ",", "0.5417967395074574`", ",", 
     "1.2044444444444444`", ",", "1.051862673484295`", ",", 
     "0.3076923076923077`", ",", "0.4135802469135803`", ",", 
     "0.6984126984126984`", ",", "1.196190476190476`", ",", 
     "0.8462585034013606`", ",", "0.8781163434903047`", ",", 
     "1.1893333333333331`", ",", "1.1253333333333333`", ",", 
     "0.6463527239150508`", ",", "0.931712962962963`", ",", 
     "0.7145557655954631`", ",", "1.0997229916897506`", ",", 
     "1.0175438596491229`", ",", "0.3076923076923077`", ",", 
     "1.128099173553719`", ",", "0.7626886145404664`", ",", 
     "0.931712962962963`", ",", "0.39963420210333794`", ",", 
     "0.915050784856879`", ",", "0.7145557655954631`", ",", 
     "0.9548611111111112`", ",", "1.0300241069471836`", ",", 
     "0.9548611111111112`", ",", "0.5986394557823129`", ",", "0.86328125`", 
     ",", "0.915050784856879`", ",", "0.7385492000876616`", ",", 
     "0.931712962962963`", ",", "1.1243489583333333`", ",", 
     "0.8781163434903047`", ",", "0.8395422449476504`", ",", 
     "1.251700680272109`", ",", "0.665406427221172`", ",", 
     "1.1341145833333333`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.37600922722029995`", ",", "0.5536332179930796`", ",", 
     "0.6460905349794237`", ",", "0.5829629629629629`", ",", 
     "0.8558310376492193`", ",", "0.8333333333333333`", ",", 
     "0.7777777777777778`", ",", "0.8328716528162512`", ",", 
     "0.46613333333333334`", ",", "0.9506172839506172`", ",", 
     "0.5536332179930796`", ",", "0.629757785467128`", ",", 
     "0.708680142687277`", ",", "0.8435374149659864`", ",", 
     "0.29024943310657597`", ",", "0.37475345167652857`", ",", 
     "0.29024943310657597`", ",", "0.5536332179930796`", ",", 
     "0.7692307692307692`", ",", "0.40816326530612246`", ",", 
     "0.40816326530612246`", ",", "0.5855012140131807`", ",", 
     "0.44266666666666665`", ",", "0.4814814814814814`", ",", 
     "0.8217687074829931`", ",", "0.8559670781893003`", ",", 
     "0.42289935364727604`", ",", "0.37600922722029995`", ",", 
     "0.7880658436213992`", ",", "0.41666666666666663`", ",", 
     "0.48989298454221164`", ",", "0.39893333333333336`", ",", 
     "0.6223958333333333`", ",", "0.6913580246913581`", ",", 
     "0.8530092592592592`", ",", "0.4851367419738406`", ",", 
     "0.6263390044108381`", ",", "0.629757785467128`", ",", 
     "0.46527777777777773`", ",", "0.708680142687277`", ",", 
     "0.7755102040816327`", ",", "0.48344239539956374`", ",", 
     "0.6394557823129252`", ",", "0.3957333333333333`", ",", 
     "0.40816326530612246`", ",", "0.5885318210459987`", ",", 
     "0.9067405355493998`", ",", "0.4854253420582986`", ",", 
     "0.45999999999999996`", ",", "0.6460905349794237`", ",", 
     "0.33919999999999995`", ",", "0.6316666666666666`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "1.1193293885601574`", ",", "0.8196591359492668`", ",", 
     "1.045267489711934`", ",", "0.9434156378600824`", ",", 
     "0.8639322916666666`", ",", "0.8414845646895595`", ",", 
     "0.8950617283950617`", ",", "1.0009861932938855`", ",", 
     "0.8024691358024691`", ",", "0.8824141519250779`", ",", 
     "1.0154666666666665`", ",", "0.7162534435261707`", ",", 
     "1.1530612244897958`", ",", "0.8852157943067034`", ",", 
     "1.1534025374855825`", ",", "0.49499999999999994`", ",", 
     "1.0523759972251128`", ",", "0.5596512088783194`", ",", 
     "0.9753728754769339`", ",", "1.`", ",", "0.92578125`", ",", 
     "0.9185185185185183`", ",", "1.1689734717416378`", ",", 
     "0.6816666666666664`", ",", "0.6020408163265305`", ",", 
     "1.1471354166666665`", ",", "0.8664585501214015`", ",", 
     "1.0202140309155765`", ",", "1.16`", ",", "0.5599999999999999`", ",", 
     "0.9625223081499108`", ",", "1.0471660721363456`", ",", 
     "0.5866666666666667`", ",", "0.8231292517006802`", ",", 
     "0.49499999999999994`", ",", "0.953125`", ",", "0.92578125`", ",", 
     "0.9434156378600824`", ",", "0.8668503213957758`", ",", 
     "1.0132601737540008`", ",", "0.9444444444444444`", ",", 
     "0.6020408163265305`", ",", "0.9501600365797895`", ",", 
     "0.5490196078431372`", ",", "0.9164065209850849`", ",", "1.05859375`", 
     ",", "0.9688888888888887`", ",", "0.5596512088783194`", ",", 
     "0.9469434832756632`", ",", "0.9986119373388855`", ",", 
     "1.0101569713758078`", ",", "1.3744855967078187`", ",", 
     "0.6816666666666664`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "1.0387143900657414`", ",", "1.1953125`", ",", "1.1007407407407406`", ",",
      "1.1424897119341564`", ",", "0.9333333333333332`", ",", 
     "0.14814814814814814`", ",", "1.1575520833333333`", ",", 
     "0.943877551020408`", ",", "0.9759999999999998`", ",", 
     "0.7983343248066627`", ",", "1.0408244153785176`", ",", 
     "1.0533333333333335`", ",", "1.352310988674625`", ",", 
     "1.046373365041617`", ",", "0.9575`", ",", "0.804733727810651`", ",", 
     "1.0572320499479706`", ",", "1.0762167125803488`", ",", 
     "0.5368839914294459`", ",", "1.3729686880697582`", ",", 
     "0.7534516765285996`", ",", "0.9490114464099895`", ",", "0.944`", ",", 
     "1.0344827586206895`", ",", "1.177170035671819`", ",", 
     "0.14814814814814814`", ",", "1.702380952380952`", ",", 
     "0.9993698802772527`", ",", "1.2569444444444444`", ",", "1.09375`", ",", 
     "1.251474158862296`", ",", "1.1906721536351164`", ",", 
     "1.1505102040816326`", ",", "1.0572320499479706`", ",", 
     "1.0344827586206895`", ",", "0.5368839914294459`", ",", 
     "1.1809523809523808`", ",", "1.0408244153785176`", ",", 
     "0.9913122999542752`", ",", "0.8554939981532779`", ",", 
     "1.0216962524654831`", ",", "0.14814814814814814`", ",", 
     "1.6440745144669044`", ",", "0.8309333333333334`", ",", 
     "0.7372685185185186`", ",", "1.0572320499479706`", ",", 
     "1.5715185885318208`", ",", "0.9885057471264368`", ",", 
     "0.9333333333333332`", ",", "1.0344827586206895`", ",", 
     "1.1674318947046218`", ",", "1.3316326530612246`", ",", 
     "1.187928669410151`", ",", "1.2139577594123048`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.743208407693833`", ",", "0.908081859174471`", ",", 
     "0.843148919294071`", ",", "0.8792461100153408`", ",", 
     "0.751400048697346`", ",", "0.9621921609434616`", ",", 
     "0.5978835978835978`", ",", "0.7766439909297052`", ",", 
     "0.6041666666666666`", ",", "0.5731292517006802`", ",", 
     "0.6851851851851851`", ",", "0.9348025711662074`", ",", 
     "0.7808012093726379`", ",", "0.8139003200731595`", ",", 
     "0.5285996055226824`", ",", "0.83375`", ",", "0.982312925170068`", ",", 
     "0.5209850849809227`", ",", "0.9621921609434616`", ",", 
     "1.0284664830119374`", ",", "0.6291156462585032`", ",", 
     "0.9672813801308744`", ",", "0.5209850849809227`", ",", 
     "0.7785336356764927`", ",", "0.8188775510204082`", ",", 
     "0.9583333333333333`", ",", "0.9690098261526834`", ",", 
     "0.5161918675432188`", ",", "0.9231770833333333`", ",", 
     "0.6291156462585032`", ",", "0.9274691358024691`", ",", 
     "0.9270833333333333`", ",", "0.6515495086923658`", ",", 
     "0.9333333333333332`", ",", "0.6615226337448559`", ",", 
     "0.8281430219146482`", ",", "0.6291156462585032`", ",", 
     "0.992283950617284`", ",", "0.7333333333333334`", ",", 
     "0.7863247863247863`", ",", "0.8550323176361957`", ",", 
     "0.7016666666666667`", ",", "0.6933333333333334`", ",", 
     "0.6390532544378698`", ",", "0.7485582468281429`", ",", 
     "0.9027777777777778`", ",", "0.5884353741496599`", ",", 
     "0.8213894367740521`", ",", "0.688724279835391`", ",", 
     "0.6491356221085951`", ",", "0.6717076244486451`", ",", 
     "0.7999206821336506`", ",", "1.0059171597633134`", ",", 
     "0.9274691358024691`", ",", "0.8614540466392319`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.834884175410361*^9, 3.8348847311138706`*^9, 
  3.834885909773882*^9},
 CellLabel->"Out[87]=",ExpressionUUID->"7344f5a7-b64a-424d-9c31-16e7d4710fda"]
}, Open  ]],

Cell["Max-min Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 3.8347951985065947`*^9}, {
  3.8348541942858086`*^9, 
  3.8348541963328104`*^9}},ExpressionUUID->"2aabf405-375f-49d0-9a93-\
cbe14c42bc77"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MMD3", "=", 
   RowBox[{"ParallelMap", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Apply", "[", 
        RowBox[{"MeanDeviationforMm", ",", "#"}], "]"}], "/", "3"}], "&"}], 
     ",", 
     RowBox[{"ParallelTable", "[", 
      RowBox[{
       RowBox[{"Thread", "[", 
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"Sequence", "@@", "a"}]}], "}"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{"dataindex", ",", "points"}], "}"}], "]"}]}], "}"}]}], 
      "]"}], ",", 
     RowBox[{"{", "2", "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834794464023734*^9, 3.834794467301902*^9}, {
   3.8347949155783987`*^9, 3.834794915863781*^9}, 3.8347951136792545`*^9, {
   3.834797166245803*^9, 3.8347971667319508`*^9}, {3.834883830833621*^9, 
   3.8348838357865515`*^9}, 3.8348840006093307`*^9, {3.8348840405182867`*^9, 
   3.8348840453059645`*^9}, {3.8348842068317804`*^9, 
   3.8348842170521555`*^9}, {3.834884578004304*^9, 3.8348845781573052`*^9}, {
   3.8348859195100384`*^9, 
   3.834885919619488*^9}},ExpressionUUID->"3bfdd656-a8c7-4a3e-ba87-\
5a119f295b06"],

Cell[CellGroupData[{

Cell[BoxData["MMD3"], "Input",
 CellChangeTimes->{{3.834884380839446*^9, 3.834884382235055*^9}, {
  3.8348859347900763`*^9, 3.8348859352901073`*^9}},
 CellLabel->"In[89]:=",ExpressionUUID->"f330699c-257d-485d-b9ca-ce0be4094017"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "5.`", ",", "2.`", ",", "5.333333333333333`", ",", "4.`", ",", 
     "4.333333333333333`", ",", "4.`", ",", "3.333333333333333`", ",", "5.`", 
     ",", "2.333333333333333`", ",", "2.6666666666666665`", ",", 
     "4.333333333333333`", ",", "2.6666666666666665`", ",", "3.`", ",", 
     "3.6666666666666665`", ",", "4.`", ",", "3.333333333333333`", ",", 
     "5.333333333333333`", ",", "3.333333333333333`", ",", 
     "4.333333333333333`", ",", "3.`", ",", "2.6666666666666665`", ",", 
     "4.333333333333333`", ",", "4.333333333333333`", ",", "4.`", ",", "4.`", 
     ",", "2.333333333333333`", ",", "4.`", ",", "2.333333333333333`", ",", 
     "2.333333333333333`", ",", "3.333333333333333`", ",", 
     "2.6666666666666665`", ",", "2.6666666666666665`", ",", "2.`", ",", 
     "3.`", ",", "4.`", ",", "3.`", ",", "2.`", ",", "4.333333333333333`", 
     ",", "2.333333333333333`", ",", "3.`", ",", "3.`", ",", 
     "2.6666666666666665`", ",", "2.6666666666666665`", ",", "4.`", ",", 
     "4.`", ",", "5.333333333333333`", ",", "4.`", ",", "3.`", ",", 
     "4.333333333333333`", ",", "3.333333333333333`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "2.333333333333333`", ",", "4.`", ",", "4.666666666666666`", ",", "4.`", 
     ",", "3.`", ",", "2.6666666666666665`", ",", "5.`", ",", "3.`", ",", 
     "3.333333333333333`", ",", "2.333333333333333`", ",", "3.`", ",", 
     "3.6666666666666665`", ",", "4.666666666666666`", ",", "2.`", ",", 
     "2.333333333333333`", ",", "5.`", ",", "4.`", ",", "1.3333333333333333`",
      ",", "1.6666666666666665`", ",", "2.6666666666666665`", ",", "5.`", ",",
      "3.6666666666666665`", ",", "3.6666666666666665`", ",", "6.`", ",", 
     "5.666666666666666`", ",", "2.333333333333333`", ",", "3.`", ",", 
     "3.6666666666666665`", ",", "4.666666666666666`", ",", 
     "3.6666666666666665`", ",", "1.3333333333333333`", ",", "4.`", ",", 
     "2.6666666666666665`", ",", "3.`", ",", "2.333333333333333`", ",", 
     "3.333333333333333`", ",", "3.6666666666666665`", ",", 
     "3.6666666666666665`", ",", "4.`", ",", "3.6666666666666665`", ",", 
     "2.333333333333333`", ",", "4.`", ",", "3.333333333333333`", ",", "3.`", 
     ",", "3.`", ",", "5.`", ",", "3.6666666666666665`", ",", "4.`", ",", 
     "6.333333333333333`", ",", "3.`", ",", "5.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "2.333333333333333`", ",", "2.333333333333333`", ",", 
     "3.6666666666666665`", ",", "3.333333333333333`", ",", "4.`", ",", 
     "4.666666666666666`", ",", "4.`", ",", "4.`", ",", "2.`", ",", 
     "3.333333333333333`", ",", "2.333333333333333`", ",", 
     "2.6666666666666665`", ",", "3.333333333333333`", ",", 
     "4.666666666666666`", ",", "1.`", ",", "1.6666666666666665`", ",", "1.`",
      ",", "2.333333333333333`", ",", "4.`", ",", "1.3333333333333333`", ",", 
     "1.3333333333333333`", ",", "2.6666666666666665`", ",", "2.`", ",", 
     "2.333333333333333`", ",", "4.`", ",", "3.333333333333333`", ",", 
     "2.6666666666666665`", ",", "2.333333333333333`", ",", 
     "3.333333333333333`", ",", "1.6666666666666665`", ",", "2.`", ",", 
     "2.333333333333333`", ",", "2.6666666666666665`", ",", 
     "2.6666666666666665`", ",", "3.333333333333333`", ",", "2.`", ",", 
     "2.6666666666666665`", ",", "2.6666666666666665`", ",", "2.`", ",", 
     "3.333333333333333`", ",", "4.`", ",", "2.6666666666666665`", ",", 
     "2.6666666666666665`", ",", "1.3333333333333333`", ",", 
     "1.3333333333333333`", ",", "1.6666666666666665`", ",", "3.`", ",", 
     "2.333333333333333`", ",", "2.`", ",", "3.6666666666666665`", ",", 
     "1.6666666666666665`", ",", "2.6666666666666665`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "5.`", ",", "3.6666666666666665`", ",", "4.333333333333333`", ",", 
     "4.666666666666666`", ",", "3.6666666666666665`", ",", 
     "3.6666666666666665`", ",", "4.333333333333333`", ",", "4.`", ",", 
     "3.333333333333333`", ",", "4.666666666666666`", ",", "5.`", ",", "4.`", 
     ",", "5.333333333333333`", ",", "5.`", ",", "4.333333333333333`", ",", 
     "1.6666666666666665`", ",", "6.`", ",", "2.`", ",", "4.333333333333333`",
      ",", "5.333333333333333`", ",", "3.6666666666666665`", ",", 
     "4.333333333333333`", ",", "6.`", ",", "3.333333333333333`", ",", 
     "2.6666666666666665`", ",", "4.333333333333333`", ",", "5.`", ",", "5.`",
      ",", "4.`", ",", "2.333333333333333`", ",", "3.6666666666666665`", ",", 
     "5.666666666666666`", ",", "3.`", ",", "3.`", ",", "1.6666666666666665`",
      ",", "4.`", ",", "3.6666666666666665`", ",", "4.666666666666666`", ",", 
     "5.`", ",", "4.`", ",", "4.666666666666666`", ",", "2.6666666666666665`",
      ",", "3.6666666666666665`", ",", "3.333333333333333`", ",", 
     "4.666666666666666`", ",", "4.`", ",", "5.333333333333333`", ",", "2.`", 
     ",", "5.`", ",", "4.`", ",", "4.333333333333333`", ",", 
     "5.666666666666666`", ",", "3.333333333333333`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "5.333333333333333`", ",", "4.666666666666666`", ",", 
     "5.666666666666666`", ",", "3.6666666666666665`", ",", 
     "5.666666666666666`", ",", "0.6666666666666666`", ",", "6.`", ",", "4.`",
      ",", "4.333333333333333`", ",", "4.333333333333333`", ",", 
     "3.6666666666666665`", ",", "5.`", ",", "5.333333333333333`", ",", 
     "5.333333333333333`", ",", "5.`", ",", "3.`", ",", "4.333333333333333`", 
     ",", "5.`", ",", "2.333333333333333`", ",", "5.`", ",", "3.`", ",", 
     "4.333333333333333`", ",", "3.6666666666666665`", ",", 
     "4.666666666666666`", ",", "6.`", ",", "0.6666666666666666`", ",", 
     "5.333333333333333`", ",", "3.6666666666666665`", ",", 
     "5.333333333333333`", ",", "5.333333333333333`", ",", "5.`", ",", "6.`", 
     ",", "4.`", ",", "4.333333333333333`", ",", "4.666666666666666`", ",", 
     "2.333333333333333`", ",", "4.333333333333333`", ",", 
     "3.6666666666666665`", ",", "6.`", ",", "4.666666666666666`", ",", "4.`",
      ",", "0.6666666666666666`", ",", "6.`", ",", "5.333333333333333`", ",", 
     "2.333333333333333`", ",", "4.333333333333333`", ",", "6.`", ",", 
     "5.333333333333333`", ",", "5.666666666666666`", ",", 
     "4.666666666666666`", ",", "4.333333333333333`", ",", "6.`", ",", "6.`", 
     ",", "4.666666666666666`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "3.`", ",", "3.6666666666666665`", ",", "4.`", ",", "4.`", ",", 
     "3.333333333333333`", ",", "4.333333333333333`", ",", 
     "2.6666666666666665`", ",", "3.`", ",", "3.`", ",", 
     "2.6666666666666665`", ",", "3.`", ",", "3.6666666666666665`", ",", 
     "3.6666666666666665`", ",", "3.6666666666666665`", ",", 
     "2.6666666666666665`", ",", "3.`", ",", "4.`", ",", "3.`", ",", 
     "4.333333333333333`", ",", "4.`", ",", "2.333333333333333`", ",", 
     "4.666666666666666`", ",", "3.`", ",", "3.6666666666666665`", ",", "4.`",
      ",", "4.`", ",", "3.6666666666666665`", ",", "3.`", ",", 
     "3.6666666666666665`", ",", "2.333333333333333`", ",", 
     "3.333333333333333`", ",", "5.`", ",", "3.333333333333333`", ",", "4.`", 
     ",", "3.6666666666666665`", ",", "3.6666666666666665`", ",", 
     "2.333333333333333`", ",", "3.6666666666666665`", ",", 
     "3.6666666666666665`", ",", "3.333333333333333`", ",", 
     "3.333333333333333`", ",", "2.6666666666666665`", ",", 
     "3.333333333333333`", ",", "2.6666666666666665`", ",", 
     "4.666666666666666`", ",", "3.333333333333333`", ",", "3.`", ",", "5.`", 
     ",", "2.6666666666666665`", ",", "2.333333333333333`", ",", 
     "2.6666666666666665`", ",", "3.`", ",", "4.`", ",", "3.333333333333333`",
      ",", "4.333333333333333`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8348843825789447`*^9, 3.8348850790431623`*^9, 
  3.834885935852556*^9},
 CellLabel->"Out[89]=",ExpressionUUID->"4a1323dc-6569-40ff-844a-390833342d13"]
}, Open  ]],

Cell[TextData[{
 "Let\[CloseCurlyQuote]s use a fix radio of 6, to ",
 StyleBox["only",
  FontWeight->"Bold"],
 " variate the density of vertices: ",
 StyleBox["(DON\[CloseCurlyQuote]T RUN, THE RADIUS IS TOO BIG FOR MY \
HYPERGRAPHS)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]]
}], "Text",
 CellChangeTimes->{{3.834793779215767*^9, 3.8347938725231647`*^9}, {
   3.8347945213559823`*^9, 3.8347945228699837`*^9}, {3.834885137933446*^9, 
   3.8348851733269405`*^9}, 3.834885945021776*^9},
 Background->GrayLevel[
  0.85],ExpressionUUID->"e592c94b-9186-445c-acf3-9b3dd55e6486"],

Cell["Cubic Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.834795179278664*^9}},ExpressionUUID->"46ad3252-d58f-4830-bba7-\
79f57c83854c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CMD6", "=", 
   RowBox[{"ParallelMap", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Apply", "[", 
        RowBox[{"MeanDeviationfor3", ",", "#"}], "]"}], "/", "6"}], "&"}], 
     ",", 
     RowBox[{"ParallelTable", "[", 
      RowBox[{
       RowBox[{"Thread", "[", 
        RowBox[{"{", 
         RowBox[{"6", ",", 
          RowBox[{"Sequence", "@@", "a"}]}], "}"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{"dataindex", ",", "points"}], "}"}], "]"}]}], "}"}]}], 
      "]"}], ",", 
     RowBox[{"{", "2", "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834793915934081*^9, 3.8347940034022837`*^9}, {
  3.8347940405152583`*^9, 3.8347940594123077`*^9}, {3.8347941029964075`*^9, 
  3.8347941499436474`*^9}, {3.8347943213293486`*^9, 3.83479432764843*^9}, {
  3.83479441541166*^9, 3.8347944309479675`*^9}, {3.834794525419983*^9, 
  3.834794525754984*^9}, {3.8347951235530715`*^9, 3.834795128637863*^9}, {
  3.834795375210432*^9, 3.834795375382306*^9}, {3.8347971692538447`*^9, 
  3.834797170297975*^9}, {3.834884543533572*^9, 3.8348845558761883`*^9}, {
  3.834885100569723*^9, 
  3.834885101428544*^9}},ExpressionUUID->"050bf202-d9b4-4bfe-9aaa-\
40a862e31679"],

Cell["Absolute Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.8347951985065947`*^9}},ExpressionUUID->"38d71bdb-67ed-4d29-8302-\
ed89aa4b88e9"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"AMD6", "=", 
    RowBox[{"ParallelMap", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Apply", "[", 
         RowBox[{"MeanDeviationfor", ",", "#"}], "]"}], "/", "6"}], "&"}], 
      ",", 
      RowBox[{"ParallelTable", "[", 
       RowBox[{
        RowBox[{"Thread", "[", 
         RowBox[{"{", 
          RowBox[{"6", ",", 
           RowBox[{"Sequence", "@@", "a"}]}], "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"a", ",", 
          RowBox[{"Transpose", "[", 
           RowBox[{"{", 
            RowBox[{"dataindex", ",", "points"}], "}"}], "]"}]}], "}"}]}], 
       "]"}], ",", 
      RowBox[{"{", "2", "}"}]}], "]"}]}], ";"}], ";"}]], "Input",
 CellChangeTimes->{{3.834794464023734*^9, 3.834794467301902*^9}, {
  3.8347945290619864`*^9, 3.8347945292379847`*^9}, {3.8347951323192406`*^9, 
  3.834795136258299*^9}, {3.834795379163555*^9, 3.8347953793354445`*^9}, {
  3.834797172805971*^9, 3.834797174076975*^9}, {3.834885115843201*^9, 
  3.8348851175061426`*^9}},ExpressionUUID->"204ceb18-d908-479f-b79a-\
7d4dbd43a572"],

Cell["Max-min Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 3.8347951985065947`*^9}, {
  3.8348541942858086`*^9, 
  3.8348541963328104`*^9}},ExpressionUUID->"df6ade0f-6924-44a2-801f-\
708fbd08c9ae"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"mMD6", "=", 
    RowBox[{"ParallelMap", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Apply", "[", 
         RowBox[{"MeanDeviationforMm", ",", "#"}], "]"}], "/", "6"}], "&"}], 
      ",", 
      RowBox[{"ParallelTable", "[", 
       RowBox[{
        RowBox[{"Thread", "[", 
         RowBox[{"{", 
          RowBox[{"6", ",", 
           RowBox[{"Sequence", "@@", "a"}]}], "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"a", ",", 
          RowBox[{"Transpose", "[", 
           RowBox[{"{", 
            RowBox[{"dataindex", ",", "points"}], "}"}], "]"}]}], "}"}]}], 
       "]"}], ",", 
      RowBox[{"{", "2", "}"}]}], "]"}]}], ";"}], ";"}]], "Input",
 CellChangeTimes->{{3.834794464023734*^9, 3.834794467301902*^9}, {
   3.8347949155783987`*^9, 3.834794915863781*^9}, 3.8347951136792545`*^9, {
   3.834797166245803*^9, 3.8347971667319508`*^9}, {3.834854200731848*^9, 
   3.834854201585847*^9}, {3.8348542603250732`*^9, 3.8348543080010796`*^9}, {
   3.8348851254226832`*^9, 
   3.834885130286486*^9}},ExpressionUUID->"d6eb3c1e-5c53-413b-873c-\
0b761bcc4427"],

Cell["Calculating the correlation coefficient:", "Text",
 CellChangeTimes->{{3.834794936682434*^9, 3.834794940356433*^9}, {
  3.8347949936897945`*^9, 3.8347950232716355`*^9}, {3.834795153884805*^9, 
  3.834795158884449*^9}, {3.834795329061915*^9, 3.834795330380517*^9}},
 Background->GrayLevel[
  0.5],ExpressionUUID->"40fbbb5b-98c6-4994-80f8-39abff86dd66"],

Cell["r = 3 :", "Text",
 CellChangeTimes->{{3.834793779215767*^9, 3.8347938725231647`*^9}, {
  3.8347953347101345`*^9, 3.8347953431477337`*^9}, {3.8348851911359825`*^9, 
  3.83488519180678*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"cd67fcb4-a810-4373-82de-d785f388b89f"],

Cell["Cubic Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.834795179278664*^9}},ExpressionUUID->"907cd8df-b878-4615-8a0c-\
e98bf595b495"],

Cell[BoxData[
 RowBox[{
  RowBox[{"c\[Rho]3", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Correlation", "[", 
       RowBox[{"Sequence", "@@", "#"}], "]"}], "&"}], ",", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"CMD3", ",", "kr"}], "}"}], "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}},
 CellLabel->
  "In[410]:=",ExpressionUUID->"fd9a2ba2-94f0-46b7-9736-2e0386e9449e"],

Cell[CellGroupData[{

Cell[BoxData["c\[Rho]3"], "Input",
 CellChangeTimes->{{3.8348868060196733`*^9, 3.834886810968133*^9}},
 CellLabel->
  "In[120]:=",ExpressionUUID->"a03f8506-213b-4033-8d48-c73aca5d08bd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.18320817086865515`", ",", "0.08677445195522288`", ",", 
   "0.11535036777511382`", ",", "0.41578900455852336`", ",", 
   "0.4467642392802107`", ",", "0.34078946964388684`"}], "}"}]], "Output",
 CellChangeTimes->{3.834886811594611*^9},
 CellLabel->
  "Out[120]=",ExpressionUUID->"b6f31362-8955-406c-ace9-bfdbda86b7c2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cP3", "=", 
  RowBox[{"Inner", "[", 
   RowBox[{"CorrelationTest", ",", 
    RowBox[{"Map", "[", 
     RowBox[{"Transpose", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"CMD3", ",", "kr"}], "}"}], "]"}]}], "]"}], ",", "c\[Rho]3", 
    ",", "List"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.834886914506423*^9, 3.83488692338325*^9}, {
  3.8348871907999315`*^9, 3.834887214360214*^9}, {3.834887246634034*^9, 
  3.8348872810326457`*^9}},
 CellLabel->
  "In[129]:=",ExpressionUUID->"407b0eca-54d6-4bca-8db9-e7d0d3b2d700"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.052253691285198356`", ",", "0.370281836584047`", ",", 
   "0.3386476876228663`", ",", "0.45455773557350987`", ",", 
   "0.14196707255050978`", ",", "0.3637440293192091`"}], "}"}]], "Output",
 CellChangeTimes->{3.8348872864335985`*^9},
 CellLabel->
  "Out[129]=",ExpressionUUID->"b3b93d60-aac0-44a0-909a-9d16ca5757fa"]
}, Closed]],

Cell["Absolute Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.8347951985065947`*^9}},ExpressionUUID->"69f76f62-e11e-4975-88ba-\
f59d54eba41c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a\[Rho]3", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Correlation", "[", 
       RowBox[{"Sequence", "@@", "#"}], "]"}], "&"}], ",", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"AMD3", ",", "kr"}], "}"}], "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.8348873709111376`*^9, 
   3.8348873755217657`*^9}},
 CellLabel->
  "In[130]:=",ExpressionUUID->"3ed6aefe-9f7f-4643-a40a-8987d879b121"],

Cell[CellGroupData[{

Cell[BoxData["a\[Rho]3"], "Input",
 CellChangeTimes->{{3.8347948932365265`*^9, 3.834794921246434*^9}, 
   3.8347949525439262`*^9, {3.8347965955184593`*^9, 3.8347965995696497`*^9}, {
   3.834886009008362*^9, 3.8348860214717894`*^9}, 3.8348873881353216`*^9},
 CellLabel->
  "In[131]:=",ExpressionUUID->"2bd8cd55-3d1e-4cc1-aabb-695032902ad6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.2775998068785234`", ",", 
   RowBox[{"-", "0.10640903079207174`"}], ",", "0.0593756940791127`", ",", 
   "0.3726752927559821`", ",", 
   RowBox[{"-", "0.025639306593844387`"}], ",", "0.40746493330677475`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.8348873886677947`*^9},
 CellLabel->
  "Out[131]=",ExpressionUUID->"9af1dfd6-135f-4f32-8dfd-9689e50f8b6a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"aP3", "=", 
  RowBox[{"Inner", "[", 
   RowBox[{"CorrelationTest", ",", 
    RowBox[{"Map", "[", 
     RowBox[{"Transpose", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"AMD3", ",", "kr"}], "}"}], "]"}]}], "]"}], ",", "a\[Rho]3", 
    ",", "List"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}},
 CellLabel->
  "In[132]:=",ExpressionUUID->"347cf21c-aee0-4ffc-9111-478be5246fc7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.012215440811310777`", ",", "0.00575071811868517`", ",", 
   "0.19611763952023079`", ",", "0.7597526925726972`", ",", 
   "0.40926168366646565`", ",", "0.4255381103548582`"}], "}"}]], "Output",
 CellChangeTimes->{3.834887440036944*^9},
 CellLabel->
  "Out[132]=",ExpressionUUID->"b35ca269-d2db-49fe-a0b2-1d8e621cdab8"]
}, Open  ]],

Cell["Max-min Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 3.8347951985065947`*^9}, {
  3.8348543263190746`*^9, 
  3.834854330052075*^9}},ExpressionUUID->"b055c62e-761c-45e7-af5e-\
64cbbb77b268"],

Cell[BoxData[
 RowBox[{
  RowBox[{"mM\[Rho]3", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Correlation", "[", 
       RowBox[{"Sequence", "@@", "#"}], "]"}], "&"}], ",", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"MMD3", ",", "kr"}], "}"}], "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8348874651734295`*^9, 3.8348874872060013`*^9}},
 CellLabel->
  "In[135]:=",ExpressionUUID->"f9b95048-5620-4a09-9e58-a82fe2afc7f3"],

Cell[CellGroupData[{

Cell[BoxData["mM\[Rho]3"], "Input",
 CellChangeTimes->{{3.8348874770254097`*^9, 3.834887479683816*^9}},
 CellLabel->
  "In[136]:=",ExpressionUUID->"b9c4e705-9b99-4dc7-8b68-828e6d6931c7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.324374367793254`", ",", 
   RowBox[{"-", "0.1106067170283992`"}], ",", "0.08383717704589065`", ",", 
   "0.30390362217575395`", ",", "0.18637903225105854`", ",", 
   "0.2233119839556456`"}], "}"}]], "Output",
 CellChangeTimes->{{3.834887480317543*^9, 3.8348874892398005`*^9}},
 CellLabel->
  "Out[136]=",ExpressionUUID->"916059e9-6622-47ed-924f-6d52d57ed70f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mMP3", "=", 
  RowBox[{"Inner", "[", 
   RowBox[{"CorrelationTest", ",", 
    RowBox[{"Map", "[", 
     RowBox[{"Transpose", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"MMD3", ",", "kr"}], "}"}], "]"}]}], "]"}], ",", "mM\[Rho]3", 
    ",", "List"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8348875260806427`*^9, 
  3.8348875488478312`*^9}},
 CellLabel->
  "In[137]:=",ExpressionUUID->"077ebedc-116d-436d-af49-8313391f447c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.04511606499206313`", ",", "0.14438666075255205`", ",", 
   "0.1315651104845173`", ",", "0.38992524403535317`", ",", 
   "0.6928452181681785`", ",", "0.26999527380645444`"}], "}"}]], "Output",
 CellChangeTimes->{3.834887440036944*^9, 3.8348875533996215`*^9},
 CellLabel->
  "Out[137]=",ExpressionUUID->"4078bb86-c1aa-48d9-a209-f3e4871a8576"]
}, Open  ]],

Cell[TextData[{
 "r = 6 :  ",
 StyleBox["(DON\[CloseCurlyQuote]T RUN, THE RADIUS IS TOO BIG FOR MY \
HYPERGRAPHS)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]]
}], "Text",
 CellChangeTimes->{{3.834793779215767*^9, 3.8347938725231647`*^9}, {
  3.8347953347101345`*^9, 3.8347953580539956`*^9}, {3.834887780344594*^9, 
  3.8348877807699356`*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"63fd89d9-6c69-4bcc-82b3-9f44e7e50a06"],

Cell["Cubic Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.834795179278664*^9}},ExpressionUUID->"0e10dbba-f3f5-4eea-accb-\
7e1341a38eae"],

Cell[BoxData[
 RowBox[{
  RowBox[{"c\[Rho]6", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Correlation", "[", 
       RowBox[{"Sequence", "@@", "#"}], "]"}], "&"}], ",", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"CMD6", ",", "kr"}], "}"}], "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.8348876558873053`*^9, 
   3.8348876596288776`*^9}},ExpressionUUID->"bd1747c4-e661-4670-906c-\
81812e17b7e2"],

Cell[BoxData[
 RowBox[{"cP6", "=", 
  RowBox[{"Inner", "[", 
   RowBox[{"CorrelationTest", ",", 
    RowBox[{"Map", "[", 
     RowBox[{"Transpose", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"CMD6", ",", "kr"}], "}"}], "]"}]}], "]"}], ",", "c\[Rho]6", 
    ",", "List"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.834886914506423*^9, 3.83488692338325*^9}, {
  3.8348871907999315`*^9, 3.834887214360214*^9}, {3.834887246634034*^9, 
  3.8348872810326457`*^9}, {3.834887668374275*^9, 
  3.83488768604194*^9}},ExpressionUUID->"6ba06abc-0936-4518-af3e-\
5c3e79395ccb"],

Cell["Absolute Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.8347951985065947`*^9}},ExpressionUUID->"8225fa37-1831-4a25-b406-\
85c897ff94f6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a\[Rho]6", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Correlation", "[", 
       RowBox[{"Sequence", "@@", "#"}], "]"}], "&"}], ",", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"AMD6", ",", "kr"}], "}"}], "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.8348873709111376`*^9, 
   3.8348873755217657`*^9}, {3.8348876888973618`*^9, 
   3.8348876927865663`*^9}},ExpressionUUID->"20e93da9-81b8-4760-92cc-\
d764bc39cce5"],

Cell[BoxData[
 RowBox[{"aP6", "=", 
  RowBox[{"Inner", "[", 
   RowBox[{"CorrelationTest", ",", 
    RowBox[{"Map", "[", 
     RowBox[{"Transpose", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"AMD6", ",", "kr"}], "}"}], "]"}]}], "]"}], ",", "a\[Rho]6", 
    ",", "List"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8348877379570265`*^9, 
  3.834887747881925*^9}},ExpressionUUID->"d16d09ba-768b-4a3f-9dd0-\
bcaeb2917e24"],

Cell["Max-min Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 3.8347951985065947`*^9}, {
  3.8348543263190746`*^9, 
  3.834854330052075*^9}},ExpressionUUID->"ea2b866c-8b6b-4140-bd36-\
7a953f5dc7ea"],

Cell[BoxData[
 RowBox[{
  RowBox[{"mM\[Rho]6", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Correlation", "[", 
       RowBox[{"Sequence", "@@", "#"}], "]"}], "&"}], ",", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"mMD6", ",", "kr"}], "}"}], "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8348874651734295`*^9, 3.8348874872060013`*^9}, {
  3.8348877160905733`*^9, 
  3.83488772853327*^9}},ExpressionUUID->"9d7cbf19-e215-4b13-a2b8-\
e886884fc450"],

Cell[BoxData[
 RowBox[{"mMP6", "=", 
  RowBox[{"Inner", "[", 
   RowBox[{"CorrelationTest", ",", 
    RowBox[{"Map", "[", 
     RowBox[{"Transpose", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"mMD6", ",", "kr"}], "}"}], "]"}]}], "]"}], ",", "mM\[Rho]6", 
    ",", "List"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8348875260806427`*^9, 
  3.8348875488478312`*^9}, {3.8348877203821526`*^9, 
  3.8348877337193127`*^9}},ExpressionUUID->"aed64eb7-6c18-45d6-92c4-\
fa4dfd52a93e"],

Cell["Some plots", "Text",
 CellChangeTimes->{{3.834887874291253*^9, 3.8348878831399384`*^9}},
 Background->RGBColor[
  1, 0.9, 1],ExpressionUUID->"60dff388-6090-402a-becc-a5557818bbe6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8348892519690175`*^9, 3.8348892639295225`*^9}},
 CellLabel->
  "In[162]:=",ExpressionUUID->"7739a091-2401-46e3-b449-8d383d3dd876"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"dataindex", ",", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"ListPlot", "[", 
          RowBox[{"#", ",", 
           RowBox[{"ImageSize", "\[Rule]", "300"}], ",", 
           RowBox[{"AxesLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"\"\<K AMD\>\"", ",", "\"\<Real K\>\""}], "}"}]}]}], 
          "]"}], "&"}], ",", 
        RowBox[{"Map", "[", 
         RowBox[{"Transpose", ",", 
          RowBox[{"Transpose", "[", 
           RowBox[{"{", 
            RowBox[{"AMD3", ",", "kr"}], "}"}], "]"}]}], "]"}]}], "]"}], ",", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"ListPlot", "[", 
          RowBox[{"#", ",", 
           RowBox[{"ImageSize", "\[Rule]", "300"}], ",", 
           RowBox[{"AxesLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"\"\<K CMD\>\"", ",", "\"\<Real K\>\""}], "}"}]}]}], 
          "]"}], "&"}], ",", 
        RowBox[{"Map", "[", 
         RowBox[{"Transpose", ",", 
          RowBox[{"Transpose", "[", 
           RowBox[{"{", 
            RowBox[{"CMD3", ",", "kr"}], "}"}], "]"}]}], "]"}]}], "]"}], ",", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"ListPlot", "[", 
          RowBox[{"#", ",", 
           RowBox[{"ImageSize", "\[Rule]", "300"}], ",", 
           RowBox[{"AxesLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"\"\<K M-m\>\"", ",", "\"\<Real K\>\""}], "}"}]}]}], 
          "]"}], "&"}], ",", 
        RowBox[{"Map", "[", 
         RowBox[{"Transpose", ",", 
          RowBox[{"Transpose", "[", 
           RowBox[{"{", 
            RowBox[{"MMD3", ",", "kr"}], "}"}], "]"}]}], "]"}]}], "]"}]}], 
     "}"}], "//", "Transpose"}], ",", 
   RowBox[{"Frame", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.83488886361922*^9, 3.8348888645831585`*^9}, {
  3.834888895600374*^9, 3.8348888968158855`*^9}, {3.834888934974758*^9, 
  3.8348890006231575`*^9}, {3.83488903370901*^9, 3.8348890511652946`*^9}},
 CellLabel->
  "In[159]:=",ExpressionUUID->"f593fb36-eb28-4406-a0a2-6391e6ada4d9"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     GraphicsBox[
      NamespaceBox["NetworkGraphics",
       DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50}, {
          Null, CompressedData["
1:eJwVxdvZmyAAANAQUFGjAiqIqIlB8QpeRukI/wIdvSu0fTjf6X9+//p5Ph6P
P//8n5xpmd7fm0zTSUxgyDIty5kWxbe4PRlIIqWBwsuCLJPwEAfkKS84N/yG
SSKSI53JXM5yJmu5zuuyricZx3lcxnU8vSqryGa2aVu2ddtO8vl8P9NnS7ui
41336b7dDWlCKaeCHp4LXOYqJ51xcPd2uietaNsDNl6TNbSpGtk0e5RGZTRH
K6nrsZ7quV7qtd7qM2IpI4yVTLKajcywma1sYw5qqrkWWupOa6PvMAlF2IYH
tKmlltnCcittZ7U11t5enuV5lcu8yffcRa9X+ipfsxcHcZzFeVzFMnbBFV/i
kpe+zOUu0rO+7vuxn/ulX/utPyFCIUoQRRwJJFGLOqSRQRZdwAMBiEEGclAB
CQxw4IIDGpKBDnwQgx4GOxzhW7zbN1RIhSpRVHEllFSqVVoNyiirrmf0fD3T
ZwmwhwOMY5zhHFdYYoMdvqDv+T71c7/x979KRzGs
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]]}, VertexStyle -> {
             Directive[
              Hue[0.63, 0.26, 0.89], 
              EdgeForm[
               Directive[
                Hue[0.63, 0.7, 0.33], 
                Opacity[0.95]]]]}}]]}, 
        TagBox[GraphicsGroupBox[GraphicsComplexBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAAHst7OsJVA0AQXir5GWYLQCSvE9DH
/xVAeJaHjvKqwz+kisZXHs32P8BnaY31L/w/fbGOXmPB/j+4jUsNmyf0P9X1
yHFkefk/33zN18rqC0BMBscb9VDoP8frPNbUIgdA4PqW5GiuBkBg9Xsc24wL
QEIWcwmT3AFABBqxnYjNCUCEx6nUGzzjP44QbJ8OMeQ/EN412CC4FUCYhQ3r
o13yP5sOSgOAKwFAyII5nGvBDEASTP/cQtsVQFTEXjpjFOM/6FWJMUhk6z/J
1aDLvSDwP6pRFmYz1RBADp4LnwPs6j8yiFAqKlkBQCwkMZACxg5Ah4EBQDAg
E0CiNrI6LcMDQPijeC4HnfQ/aElUaEd7+j+udbKGf0cRQLeOVb7T5ABAahxl
6vkl+z+ZxHUBO18KQPSecLWmMQtAcEB/3zMjxj9CN5r+qsAUQDUMLQ6JyfA/
ruT9BsRaBEAvXTaTvLnvP+AfDyZ11vE/pnGVJ4ac8T80Le+jqvr7P+jzRLm3
9w9ApN64cGpHBkAsPRLQsHQEQO5AxgMXVhZA4HwbyiaXA0BMldoz5P77P6s3
gn7D2vY/0U6XpWVd9j826qlmp4UHQIj8m6400Oo/cFZcujGE2z/fbGXC/6EK
QLAXiYlN3Og/AAAAAAAAAACQkCUQJZm2P5VCoiE0/BJAbhBCsn4i9D92khKK
8zsVQNIQoe1gGgZAFK8J7D9AEEAAAAAAAAAAACUcXeNCPgJAAq/vySaZ9j/0
+MUkEsP4P7d5nbtL8u0/BMnF4sQbFkDyG44GGKwGQC9Q2VPGrghAR5ZxQubd
AUCOGj5SmNkXQKDPt1+HqgBAZ8iYoX1OE0AS0rmdiKv9P1eWg/VAXRhA+oRl
9RztBEDsgoi+ICEWQBDVr2WzlgBAr9L8uc88FECBUBDyJZYCQGg8zDEUreo/
Bm0CXpoyBUDSRrKvaiIGQILtHuuTLvU/A4Us28d3BUDorMx+LTQJQOiVV0I9
xNw/gPiRMrGw8T+UmyQBRtgXQDYTZ1csJwdAVpQDDC0aAUDacPBDxzoDQIRL
tZQsCwlAXPbohD/q2T9G5WNK
           "], {
            {Hue[0.63, 0.7, 0.5], Opacity[0.7], LineBox[CompressedData["
1:eJwVxdvZmyAAANAQUFGjAiqIqIlB8QpeRukI/wIdvSu0fTjf6X9+//p5Ph6P
P//8H3ggABjEIAM5qIAEBjhwPaPn65k+S4igDxNIIYcCKthADQe4QwsPFKIE
UcSRQBIp1KIOaTQggyy6PN/DXuxlXu5VnvQab/ecT/3cb/w9wEEcZIEMTOCC
C8c4wzmusMQGO3yFSShCFbbhOzyiV5RGLCqjOVrjLM7jKpaxi69X+ipfc0IT
kaikTYbkSFlapGXK0y6dU5veWZ5VmcyazBFGJKnJh/RkJIZMZCYLWclGTsqp
oIo2VNOB7tTSg5VMspr1bGSGzWxlG7PM5VUu8ybfc1fwoiu+hS3uci5XrnjH
NR+44ZbfQolWvIUWgzjEVTWVk0o2UksjZ2mlk1fd12M91XO91Gu91adqlVaD
Msqqq9nbd3t0n+7b6c529+f7mT5bP/Zzv/Rrv/Xn99aDNtrqS9+DHY5xHpdx
HU+zGWucuaZl2qZzXpd12ZZz3dZzO+3trr+o+jGs
              "]]}, 
            {Hue[0.63, 0.26, 0.89], EdgeForm[{Hue[0.63, 0.7, 0.33], Opacity[
             0.95]}], DiskBox[1, 0.04894431221572629], 
             DiskBox[2, 0.04894431221572629], DiskBox[3, 0.04894431221572629],
              DiskBox[4, 0.04894431221572629], 
             DiskBox[5, 0.04894431221572629], DiskBox[6, 0.04894431221572629],
              DiskBox[7, 0.04894431221572629], 
             DiskBox[8, 0.04894431221572629], DiskBox[9, 0.04894431221572629],
              DiskBox[10, 0.04894431221572629], 
             DiskBox[11, 0.04894431221572629], 
             DiskBox[12, 0.04894431221572629], 
             DiskBox[13, 0.04894431221572629], 
             DiskBox[14, 0.04894431221572629], 
             DiskBox[15, 0.04894431221572629], 
             DiskBox[16, 0.04894431221572629], 
             DiskBox[17, 0.04894431221572629], 
             DiskBox[18, 0.04894431221572629], 
             DiskBox[19, 0.04894431221572629], 
             DiskBox[20, 0.04894431221572629], 
             DiskBox[21, 0.04894431221572629], 
             DiskBox[22, 0.04894431221572629], 
             DiskBox[23, 0.04894431221572629], 
             DiskBox[24, 0.04894431221572629], 
             DiskBox[25, 0.04894431221572629], 
             DiskBox[26, 0.04894431221572629], 
             DiskBox[27, 0.04894431221572629], 
             DiskBox[28, 0.04894431221572629], 
             DiskBox[29, 0.04894431221572629], 
             DiskBox[30, 0.04894431221572629], 
             DiskBox[31, 0.04894431221572629], 
             DiskBox[32, 0.04894431221572629], 
             DiskBox[33, 0.04894431221572629], 
             DiskBox[34, 0.04894431221572629], 
             DiskBox[35, 0.04894431221572629], 
             DiskBox[36, 0.04894431221572629], 
             DiskBox[37, 0.04894431221572629], 
             DiskBox[38, 0.04894431221572629], 
             DiskBox[39, 0.04894431221572629], 
             DiskBox[40, 0.04894431221572629], 
             DiskBox[41, 0.04894431221572629], 
             DiskBox[42, 0.04894431221572629], 
             DiskBox[43, 0.04894431221572629], 
             DiskBox[44, 0.04894431221572629], 
             DiskBox[45, 0.04894431221572629], 
             DiskBox[46, 0.04894431221572629], 
             DiskBox[47, 0.04894431221572629], 
             DiskBox[48, 0.04894431221572629], 
             DiskBox[49, 0.04894431221572629], 
             DiskBox[50, 0.04894431221572629]}}]],
         MouseAppearanceTag["NetworkGraphics"]],
        AllowKernelInitialization->False]],
      DefaultBaseStyle->{
       "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
        Hue[0.8, 1., 0.6]},
      FormatType->TraditionalForm,
      FrameTicks->None], 
     GraphicsBox[{{}, {
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.011000000000000001`], AbsoluteThickness[1.6], 
         PointBox[CompressedData["
1:eJw9knlM0gEUx0FHQoq1FDQtpqVGq9RUMq380qH/qNg8Zkrm2bQ1p822PLqs
dLNGWosOZ2WbRcMDRLLmQUaaaXmVmlo2A5QfEqToyrlll4vP3tvb++v7vm9f
15SsyKMWJBLJ50//neJ/TGOeYPi5pL1DRLEFuXyPCgdkUX2PTRJwZmsy3Cbm
0FNUEvQtbATs/YWkHpYOVbw3c4v0n0jq8qmgZBGgkayZ5LcK2EZubl2dowfN
8n2lvUGGwCu6rY8aCLgYlXlT3W34r+ccEC+QJgyA5XajisVUITl0VJDpIEHM
X4RqMA6XqZfOdqLjS2/ztXgdbhj49PqgRnRUynsYlEkYvm4RpR+tRrvQSGfb
aWEr1QQXtddDeVsYUvqYgIOAd8Zm+wdMJgzzOkFAZSfXXfz+DHGd0tV5rdOQ
DkWfT2wbNPtLzClyknQNYUXK/bHPYTokHy9IFzV/NfuL6XahOmmVIDLSJSHf
1RhqiyYX1L0033s6u2QkM/bF8j45i1O51ufuRCygkZG1NfemCUu2LpvCjw3A
f0GZJk6ah8JINLg314ESPFi+v5jAaPbHmNfvKdwLXqmuI2INaCdm4sItW7Cv
gGZwl2thsmUGHrj8A45fcgTbhBMYH2f+eC7qNv9vC6ePGUaSoWSljE7u0CJb
nrjObbEfOyleoolJDbLyHQSt12tA+ocar0S+vwZPPsXi8NpEvk4D7yrOmpst
DUjZ/bog3kGNE5mhT3bwpOBOsccVsmksZZu+uVes4gYktfhxGvQoF+0yRj0Y
xfO5Wl9Fowr2AdbtZ2vEuH4p9qGV4wy2q3ad4XjacF962/wpNdaLFQz/NRJ8
crx2ZPCYFlr2qyZZ51sE+7Ka7lWoMKGhH1q4W4uKcP5hV9oUNt4t82AJ22ER
lN9o8tRjzM8pgWrVZ87XQS/2LckbOTyk0Xt1QUZsUPLne0PI3OV8zSC1roTS
S1Ih3JmQF/L0WIz47FFKrTfreVAfZjCcxBg2UHNzVuoRHcK/Wn1FjxlPwVB5
2hTif83nCa368Ruuu4Jq
          "]]}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"K AMD\"", TraditionalForm], 
        FormBox["\"Real K\"", TraditionalForm]},
      AxesOrigin->{0.5024729101630248, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImageSize->300,
      Method->{
       "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0.5024729101630248, 1.2735999999999998`}, {
        0, 2.0584016152740534`}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], 
     GraphicsBox[{{}, {
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.011000000000000001`], AbsoluteThickness[1.6], 
         PointBox[CompressedData["
1:eJw9UnswEwAcnmnXPMbJZlnFUIuc5LGQ8vu5cC6hmMwrKXrcTla6kzzqLs6p
aIXeUp1M8xizniTkolEsVuj08AiXUXLZiSl17bv73Xe/v77HfRZ7E4LiiAQC
wfHPLXLIIuxccXqU5syMfQMiIslTlzwJXpLgjtIpMTzmZcVyVd74KjPbY3J7
D2S18ujXwyywOKDtxyxlHnYu2TLvle+EOgQ9E632epD5Rrn7fWSjjnbXLapS
Aqy8skZ5MRmZE03JX2QN8F9vhVt4TlWUHALbdg9zfD9DjF9vTjxdDIRFlC5B
WqRgUJ3eAqkZuXZB5Y6Yr4ygVHs8gOGkbVzhAg2V47bCA3FlINjFyVaRVGBQ
NeSd2VwNY6nmbr53lyM9JyBN3+EdSPNnRyLD7HDAWDp2+ucjMBOo8iLrWFil
4JyKbujW5ItOzGSIXyrAcqscC6zNMYaXckBYO67JFyJjkhkjTTAkTQF3Nyoq
GjhaKZXPNX5T+dk98aGNf/89di6YdFzv5NVAFbB/an+5s9cZ1QbMtf6H5HBU
rZREJzlj/cRozZraSmi+VFrtamyLvfz3Ia1dJJyQ8BQZlnLQOfItzF+7Di5s
G5AYcZg4ZWCyyevMDATFKUVdriTs7zeZeSaUafqzZXeYbCdI4GJJ4nh3IBn5
0uiVq2c7gVurPX99zBQTTtBznl4s/+e3RxdfCJ0Wuo89BK0E/2AzGzlsKGYv
u1RXA98bQmPTCDp4JN7v/saAKuDtp5h6O1mgmj81ueaGId6baz1pddMArwnd
J4Jv90JfRdFbQZLsGdVNrzm9XAQU7ydFwQIXdBhwT2Ov10dHkdccMVYNq0T1
NJdlYmDMCwwdSqxwxPrFE0lLO6TbKPj7f1Hx0xCFqyqsgAuVyQXE9hawKhSw
zAqaYUcQ9drgNwr2OTOiyEs7NPvaYW99WdwmBXuJdJxo5YiWTRHTr320kFus
v7n/sCfuq8wmvSYMwDnPPcOdlg44G/iBdZ5crdFjke8epDFEcMWQPhnA3IAc
n4jcsrNfgRozuO7OFiMMX5hOLljaCb8BrfNh0A==
          "]]}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"K CMD\"", TraditionalForm], 
        FormBox["\"Real K\"", TraditionalForm]},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImageSize->300,
      Method->{
       "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{-0.2067738578765404, 43.940197530864175`}, {
        0, 2.0584016152740534`}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], 
     GraphicsBox[{{}, {
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.011000000000000001`], AbsoluteThickness[1.6], 
         PointBox[CompressedData["
1:eJxTTMoPSmViYGAwAmIQDQEiDl9eiJoopFyyhwo4uGwKPr/i03r7UDAQdTjb
2mn33ucGVF7AYYnf6c+/eP9C5QUdOBm4xRjP7IPLczJfXiDydpP9KjDgclB4
d6jy2akD9jD7pC2jejfEXoTKMzkket/szRWH2cfqIBoz4fG/uuNw86e8jebd
aLcNLv/2jfby9NTVUPM4HPg2PHFtPbIRKs/rIN7rV8tjeB3unkfCW142f9sB
d8+GqyEN8QeuwP0XX9wqtf7kVbh8YnZ1+vLdb+D2h55S4JB6fghu39UDIYzV
6w7D3VNT0HkjN/wgXH15BXf9TP8fcP4/PgV138yLcPfse/dis+rudXD+zYLb
oScuszrAwoOz8EOkL/MeuPwnPjErl67v8PC6e1fs+/7lp+B8bdPzYj4MiPAu
2BIvo/LrAtx9+VXivXsnrYHzjy03/n+lZDs8vg2WmApN27MZ7r/CXO+tZn4b
4Pb/K/j0XnUOvwNMftZy63fBC2/C9YtYch+pW7MK7l/DR9a1pno8cP/Irton
ai60Hm7+c41juzYdPwPnP3jCG/Fj7lq4+5TnTlCTm3oEzr9lIhXLwX4e7p4A
fY3p609vgfOVDkV/OefG6ACLz+R1naznGB7B5X/531Pr59gIt0+NY2mGqBTC
vSFu0X2ru1/Dwy/q/5fKqewX7AEKnRtO
          "]]}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"K M-m\"", TraditionalForm], 
        FormBox["\"Real K\"", TraditionalForm]},
      AxesOrigin->{1.9305555555555558`, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImageSize->300,
      Method->{
       "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{1.9305555555555558`, 5.333333333333333}, {
        0, 2.0584016152740534`}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}]},
    {
     GraphicsBox[
      NamespaceBox["NetworkGraphics",
       DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51}, {
          Null, CompressedData["
1:eJwVxV2aqiAAANAQRU0sLfwDNKJAKFHBndwlzAbu/t/mm/Nynj////1Ep9Pp
CU6nv40dDDMNQwwZZOP98YqzzGZf5BrHnHFID5ppbbTVDpWlLk1pEW/4wBnn
mhvuYAwRtHBHR3nowxz2QGEILPCggwkuxJ/sA6f7NL0u98t02SMYxVEWfaL9
9ri9IEU0o1RTQy390iN70/f7G53j83lvNra5LW1SlvLUpRsas5GO43u042f8
Xm/Xx/V1fV+/cE7nZmbz7ObtOT+3qIiLrChoMRbvwhaf4ouqsqqGSlemslWo
jrRruo51z27uXLdBgkhJKkIoYYSTkWhiiCWOBHIgnGJMcIMHzDDHGhvscEiu
yS2ZkkfyQipVWBHVqEExxZXSyiinQtTCNm7PbdG2n3ZHIhVYENGITlDBBBdC
CS1mYYQVTmwiQJ945FNPfOM7Tz3zkxd+9tY7v/mohnVcX+r6Xrf1VO+1h0uy
XJZ6uS/T8lpwX/ZV3w8971Wve9OH/sjLvMp1bvMDrflartVK1n4dVr2a1a7r
gWQqsSSykZ1kkkshpZJaztJIJzfpZQARgCAGCGQgBwUoQQ0IaAEFI9DAAAtW
4MHxC4roPaI=
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]]}, VertexStyle -> {
             Directive[
              Hue[0.63, 0.26, 0.89], 
              EdgeForm[
               Directive[
                Hue[0.63, 0.7, 0.33], 
                Opacity[0.95]]]]}}]]}, 
        TagBox[GraphicsGroupBox[GraphicsComplexBox[CompressedData["
1:eJwBQQO+/CFib1JlAgAAADMAAAACAAAAWsUcBsYgA0BDRQjWb6H1P0CrIbiA
hg5ARCUffN8v7T92ExQrGW4JQPHbpDEF6/4/ChIK65hiDUB0skDOMgPlP3Xm
cBs2uxJA/D+wpv0bDUCnJJGgrwP4PxAcjqh4u/8/xscd1Xrq8D/ACXpeimUL
QDvVR8BRtghAyJsK6wU28T+FnnT31KbzP1CVN3zQvOM//itvMdZuEkAAAAAA
AAAAAMm50h0nXgpAJfDjZRlb8z/04ZSMbDbhPwsgfrfFkwVAZvJC+dTr8j/U
YMSKDRfxP4Iz8WRNShVAR4p4bdMh/D9nyX8q1lgUQPhnTauWYQpAkqlJFKut
5T9adfQpOu70P7F29vtFhBBAohxxndi9+z9O6YW5oOgWQKN2a+mzXRFAGmFT
kkc+FkDwxX+Hn6IBQIZtkTdg1fg/gM52NKD3AEBsMFiP6w7qP0vEFNR6dAtA
Kun4dM6uD0AsXJXdgmPmP913c1Uc6/I/B2iBPPnQDkAQE7T8sVfTPyiPw/KG
6Pk/AAAAAAAAAAD7mtDkqvz9P/zdSBdb/wJA6tc6G5tj/j+FBVqcT9/zPz50
rKk+1gdAwL53MbF/3D+fQNhprDMEQJ6QwlOPPAZAvN8V+2zL9z+gyeqJjc0R
QJjvajPCmgVAHOZkknIfGEBQN1Q/+jAQQIEMsonHMvY/0hrmNbivBUCwJ+Nq
QozzP3TzDE3sbhNAPg/prWsP7z8WStN8PcQHQFSMA5fiaBZAaLzfjvNHDEBj
EAfOEnUNQOolVnF+CgJADJMUusNA5j9sTI3ehwAEQNeRFq636/A/9L4bY4hM
/T9cFJ+bCHr8P2ZVejNc5QtAeRN2KZ/u8D81ZpAfwBwAQAFP2zbr0P4/vXCz
Yst5+D+M1mWDbF4LQLCzYbwvocs/rapvy7ulDkBT7nJjvCMAQAc+YHKDwhNA
3lqhIBN1BEDi5OoVb8DxP14e15BGpwZAHgaaJvQ/7z/sKDu0CTf0PzRTZeEo
JPc/IqbhwtegDkC6uhovLkoSQCAQf/RzAO4/YjnajIvvAkBfdC2cM5YGQJDd
j2EpNuE/541/w1B4AUA4Mi2+lZP2P/CV4zkpPPQ/mlZ0ZQ==
           "], {
            {Hue[0.63, 0.7, 0.5], Opacity[0.7], LineBox[CompressedData["
1:eJwVxV2aqiAAANAQRU0sLfwDNKJAKFHBndwlzAbu/t/mm/Nynj////1Ep9Pp
CU6nv0EEIIgBAhnIQQFKUAMCWkDBCDQwwIIVeHBEMIqjLDpHRVRHbfSJdhhD
BGtIYAspnOAMLVzgDn2cxee4iOu4jT/xnlyTWzIlj+SVLIlHGJWoQgRRxBBH
IxJIIoU0Msgih1bkUUBHitMm7VKW8lSkMlXpnLp0S31WZDQbs3dms0/2zcu8
ynVu8zU/zu15L9qCFmPxLmzxKb6Y4Ab3eMAMcyywxAprbLDDoaxKUvalLk1p
y7U8LvXlfpkuy2W/3q6P6+v6vn4rUvXVUOnKVLZaq1Ad9b1u66le6r32t8ft
dZ/uC6GEEU5GIogkimhiiCWOrMSTQI6ma1jDG9HIRjVz45qt8e2n3TvWie7Z
yW7uXLd1vh963qte96Zf+9AfAx/UoAczrEOgIxX0TTU11NIv9fRgnAkmmWKa
zcwwxzbmWeCCS6645oY7Hsb3aMfP+J1e0zL5x0tIoYQWszDCCic24UV4zs9N
KqnlLI10cpNehtfy/iqtjHIqaKOtdnrVQR+zm7fZG2ucWU0wh12tt4fbnHdh
PTb/CxWMPaI=
              "]]}, 
            {Hue[0.63, 0.26, 0.89], EdgeForm[{Hue[0.63, 0.7, 0.33], Opacity[
             0.95]}], DiskBox[1, 0.048635175830869806], 
             DiskBox[2, 0.048635175830869806], 
             DiskBox[3, 0.048635175830869806], 
             DiskBox[4, 0.048635175830869806], 
             DiskBox[5, 0.048635175830869806], 
             DiskBox[6, 0.048635175830869806], 
             DiskBox[7, 0.048635175830869806], 
             DiskBox[8, 0.048635175830869806], 
             DiskBox[9, 0.048635175830869806], 
             DiskBox[10, 0.048635175830869806], 
             DiskBox[11, 0.048635175830869806], 
             DiskBox[12, 0.048635175830869806], 
             DiskBox[13, 0.048635175830869806], 
             DiskBox[14, 0.048635175830869806], 
             DiskBox[15, 0.048635175830869806], 
             DiskBox[16, 0.048635175830869806], 
             DiskBox[17, 0.048635175830869806], 
             DiskBox[18, 0.048635175830869806], 
             DiskBox[19, 0.048635175830869806], 
             DiskBox[20, 0.048635175830869806], 
             DiskBox[21, 0.048635175830869806], 
             DiskBox[22, 0.048635175830869806], 
             DiskBox[23, 0.048635175830869806], 
             DiskBox[24, 0.048635175830869806], 
             DiskBox[25, 0.048635175830869806], 
             DiskBox[26, 0.048635175830869806], 
             DiskBox[27, 0.048635175830869806], 
             DiskBox[28, 0.048635175830869806], 
             DiskBox[29, 0.048635175830869806], 
             DiskBox[30, 0.048635175830869806], 
             DiskBox[31, 0.048635175830869806], 
             DiskBox[32, 0.048635175830869806], 
             DiskBox[33, 0.048635175830869806], 
             DiskBox[34, 0.048635175830869806], 
             DiskBox[35, 0.048635175830869806], 
             DiskBox[36, 0.048635175830869806], 
             DiskBox[37, 0.048635175830869806], 
             DiskBox[38, 0.048635175830869806], 
             DiskBox[39, 0.048635175830869806], 
             DiskBox[40, 0.048635175830869806], 
             DiskBox[41, 0.048635175830869806], 
             DiskBox[42, 0.048635175830869806], 
             DiskBox[43, 0.048635175830869806], 
             DiskBox[44, 0.048635175830869806], 
             DiskBox[45, 0.048635175830869806], 
             DiskBox[46, 0.048635175830869806], 
             DiskBox[47, 0.048635175830869806], 
             DiskBox[48, 0.048635175830869806], 
             DiskBox[49, 0.048635175830869806], 
             DiskBox[50, 0.048635175830869806], 
             DiskBox[51, 0.048635175830869806]}}]],
         MouseAppearanceTag["NetworkGraphics"]],
        AllowKernelInitialization->False]],
      DefaultBaseStyle->{
       "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
        Hue[0.8, 1., 0.6]},
      FormatType->TraditionalForm,
      FrameTicks->None], 
     GraphicsBox[{{}, {
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.011000000000000001`], AbsoluteThickness[1.6], 
         PointBox[CompressedData["
1:eJw9Un0s1AEYvszuWlRKM5ZYXcz6oNIc2XquoVRnNX2g1CqdM6K6lpOVlgr5
uMrtjo1EkzmSuzq6lOqaJUQc0xH51rm733WHuyt9Uuv37H33/vFs7/s87/uu
PHE6lG1FoVC8Z3OutmktXvYJw2hh66vlV22ZHX7jptQkDdrdvQXxnXKElHs8
PxWphZ3b2VWMTDP+87pcF2FZjgJL+naccVUQKDLpDp6e6IKIHTEb4/CIEgay
WDTmKbbhbj59Ck4BBp+0gWbcF9nwTCEaDH4MsKfOvAZlDq8InMmolNKdOyBb
2upAdxuEc3a60swXI8arpP6aWQMWd4l69VQDfimzF5b2j+PTW2IdsbUFFXPQ
GCH+fUiUHK1EbEZZwzBlABnpGxPiXlXgKLd8RfTBIdx2nqDJ/GphaK28wQma
gvWdkaKwzAZc/8qZju8yIFF6vJQaNYZl/lJ7f2knZjYHre1iSaD6IQl2SurF
9jJUygUS0l8o4+xJ96H5pD/Z02K/y/IO5Aak1mYv0yK6gLHru2s7LlnWctOd
dGDXhbcLDjcjPqIyKpU2haxtap6AJkPb1otpR+ZNYqLqfFJKXQWY4ki19uEo
Zhxjlz8rpzIXEG6yvHYChXuZ8f6SAdJ/a9BREYNQQMV7uYqXb8STY3WdeZFN
SLG2zJ7EgPe2jblLeUrSz2jYvMfsJglMOju51HYSNnEp3muUQ7hxbvG0kaOG
y542s6r3Ef7PeyMudb5wuBviaKcDBYIe1KTk7E8Lf48NiSeFjsEEghtpWaIv
z0g9LTHSRR/pCoz68kd8+XrkXM3cueWDGqzBbv5MsgEq3T4XYv0YydOsvzD6
PIfR3CDUL/QYAcPT0mj4tpj59x+KtShU3NqUzKkj5xk6Yrg+1XJcLynQb7z3
GcGBDmyVUUHqrW5952qu6cGBOfw04tCVyTfC2iZy//WBu+NK7r5DEr3mUXq/
BlWmajv9hSpYsYd3WajT4O5zLKI8pzJpyoQ4q91jGK+KSOy7+fRfP7dJZL2o
X+n4oB9/ACoOn34=
          "]]}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"K AMD\"", TraditionalForm], 
        FormBox["\"Real K\"", TraditionalForm]},
      AxesOrigin->{0.28802546659689543`, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImageSize->300,
      Method->{
       "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0.28802546659689543`, 1.251700680272109}, {
        0, 1.5534844183762109`}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], 
     GraphicsBox[{{}, {
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.011000000000000001`], AbsoluteThickness[1.6], 
         PointBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQXSrolJpvwuZwOvXd+h3NPA4aztPKLm5Vd7igZjw5
9/IO+8LkE6a2J6wdBFQLlcy7vtnD5N9Mkpu6rPeg/ZTrAXHOlaIO876+Cct/
ecWet3tK4/JoZgeN5KkuPj7sDlqTo0WfCjs7SDp/MGu7f8r+RoHJgSZPDocH
t52F2X4dsmcAgVPKDgUdqzcqy1y0v3Oeb8e6GRvtZXraL33rW2nf99gCiJgc
fIoEX6h8PmL/R6/iQsh3Zod7J97qvLU7Dda/QN7AYeX/qGlVaZfsGVaIR+WH
/7LvaDfMyz6wyt7AUOqFkxabw0SZl+xbLLfZH7s2K6UzTsmBZe7jeeFdR+xl
5s3uLcyxdCjbmLiELfmp/UZhayB6aP/LxFX7is8G+4pE2fUV3M/t3ZbZr94x
eQPcf0HmhSlqDzng/tuyc4Fl/Y6L9obnmZ/9f6TkkDbb3Ou3/AX7HT1Cvm/t
1BxSd0VcmBwN9P+Of7HzLR0cuh1flE9m32LPeOH9b3N9G4eXa0sr6natsjf0
drZnvv3H/pdElvTuFWwOHCD7nJkc5gQ45FpvuA/3/1nXuGnmbw/az8to/1Om
YuKwPWHX5ekxJ+1zOv+2rtsi63Ce5/gkofJLcP88CWfcnHpyg/2jJ3bJIpOM
HLiz64y1Lj20n8V5ik3oE4uDnP+5bzdubbKH2Xds5RKZyuhr9jHMFh52Qh/s
t9b1hrRFnLefW/r5vWemqIPHcfbuae93w91zOmMj323lg5D43Kbi0Nvc5Wl1
/YW9XiXDatOFGg433gTLvdV9CpdnZ3lvfkfvkX1NmkjYu1sMDuZ6349/+Mnv
AJKueKXqMOfgBKOq9F1w+z5czCgyW7/DPmLLVDWjVw/sPVzEUm98PAh37/qz
Z+S/bb0JNj9FzdghqvHTsanbTsLDf6+Ld/bC+Wfs7z5q81aYJO2w9ut6gXeV
a+1f/tZRUl0X4FAULDGPYQ+bw72SkHm+hYwOz9ZGlt3p3wk2TyHdyqF7315F
iTV37QEZvmnL
          "]]}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"K CMD\"", TraditionalForm], 
        FormBox["\"Real K\"", TraditionalForm]},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImageSize->300,
      Method->{
       "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0, 47.19575161829046}, {0, 1.5534844183762109`}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], 
     GraphicsBox[{{}, {
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.011000000000000001`], AbsoluteThickness[1.6], 
         PointBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQvQoMmBxOp75bv6OZx4EBDAQcLqgZT869vMMeIi/k
IKBaqGTe9c0eJv9mktzUZb0HoXwOh3lf34Tlv7xiHwoGrA4ayVNdfHzYoeaJ
OEg6fzBru38Krv7BbWdhtl+HoOZzORR0rN6oLHPRHuYemZ72S9/6VsLV+xQJ
vlD5fARqPq/DvRNvdd7anYa7b+X/qGlVaZeg6hkcOtoN87IPrIKbN1HmJfsW
y232MPewzH08L7zrCNw/ZRsTl7AlP4Wa/9X+l4mr9hWfDVD9v+zdltmv3jF5
A9x/QeaFKWoPOeD+27JzgWX9jotw96XNNvf6LX8Bzk/dFXFhcjTM/xIO3Y4v
yiezb4GaL+bwcm1pRd0uhHt/SWRJ717B5gDz/5wAh1zrDffh5p11jZtm/vYg
3P/bE3Zdnh5zEi5/nuf4JKHyS3D/PAln3Jx6cgPcv9zZdcZalx7C/SPnf+7b
jVub4OF9bOUSmcroa3D3bK3rDWmLOA+PL4/j7N3T3u+G23c6YyPfbeWDcH5v
c5en1fUXcPtuvAmWe6v7FC7PzvLe/I7eI7j55nrfj3/4yQ9Pf3MOTjCqSt8F
t+/DxYwis/U74O7zcBFLvfERkf7Wnz0j/23rTXj8RjV+OjZ1GyI89rp4Zy+c
fwbunrVf1wu8q1wLlZd0KAqWmMewBxHez9ZGlt3p3wk3r3vfXkWJNXftAffL
Nlo=
          "]]}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"K M-m\"", TraditionalForm], 
        FormBox["\"Real K\"", TraditionalForm]},
      AxesOrigin->{1.229166666666667, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImageSize->300,
      Method->{
       "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{1.229166666666667, 6.333333333333333}, {
        0, 1.5534844183762109`}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}]},
    {
     GraphicsBox[
      NamespaceBox["NetworkGraphics",
       DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
          52}, {Null, CompressedData["
1:eJwVxduVoyAAANAICkTUGExURHy/0AkqUsmWMA1stdPP7H7cc9vvv3++we12
+/nn/+/P6/36oL2d8inXq87WTHs6u9ZLX0jKHSIo4e60zuRcjzwbx3W8oFqU
NzhBkAdtMEGMMF6w8rpu6LRTBmXZllN5eT3qZe/VdVcPkCGGGZOsZ4rtXhTV
URcN0RKpqKmbpmsGaJDBhhlplNlNfTZndw6nEwdxnMV5XMZtPMU6viBFFFPK
qKQ9VXSnxtniLdvKrd3GbbvSLB3TNd1SnV7QRz72feozX/q7bx7Vq3pXeVV9
XORKt3e/XvN7ntf5ExVFUwzFUqj7fF9d4QkkRCd6sQrtJl6CkkQkXdInX8np
8Yjzggte84Z3fOALV1xDgggmxCeUMCJJT3ZiHs9n/qw8e7epzaywo53tarW9
7P1Ij+wQx3jMx3ocFodhFPKwCJdQAQgQwIAAH1DAgAQ9UGAH5hcMpy2o
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]]}, VertexStyle -> {
             Directive[
              Hue[0.63, 0.26, 0.89], 
              EdgeForm[
               Directive[
                Hue[0.63, 0.7, 0.33], 
                Opacity[0.95]]]]}}]]}, 
        TagBox[GraphicsGroupBox[GraphicsComplexBox[CompressedData["
1:eJwBUQOu/CFib1JlAgAAADQAAAACAAAAChYnqGuS/D8eVFZVF+ELQMt8L11z
3yBAEY+Uok31AkAB2B0nR+8hQHp19O4H1QFAXVTx8W4EHEDnvtvGl3kGQIx4
oPyN1hZABhUebbo4+T9k7CT1ApEfQPmfufqO9wJASufDNiY2IUB1YtesThf6
PxoYkAjwYCFAwyLQ0zj7BEDmC9fUM30JQK4HiBN6afA/LNvVSC9QIkDLDawk
vLADQBUKwR+uSyFAkJe4lFccAkDI7wv0lqbwP8nOxsW1swlA5tfBc9smH0BQ
hpO1H8zlP6o/nb9LUxtAbhQj+F336j8Asm7KyhWhPx/2bdVhl/s/C0TL5jnx
AEBVoNdGfikGQAAAAAAAAAAALt6GYoz09T/y9nIXnAkhQMx+kCDHqQBAGtao
vloVGkBUbyZCaX4BQChmRPOoy+w/kHpp403Vvj8m3LkFVyzyP5TMBgs4itk/
SpzkOU3JCkDxT5ZaUDQDQCjhFebWMAhAuj8DRsdJAkAM3gwn5Gz2P+XuGCFf
4v8/vIMLINqMGUB4COkKJcXyP8Jt7Xjt/hxASJN2TtV63D8ix/YNFzgWQFmr
YHFzcABACARueGjp+j9U324sfIcJQHgLxhH+vCBAAOw31fw7BkDQhTCEdHrg
PxbagQodyes/sB/hyV+6F0Asc0GJ8kfgPzPEFoyXuRlASHrvldFQzT9iw2Ug
xB72Pzq3+WOBLg1AW6bVr+71FkAoKMnuHF3zP4a7oMZifh1AbC2SKkZ1AkAh
34XJLlAZQO6gYyWWJ+I/mMZzZKWgCkBJLTQ2BGMFQMje8R/4KvI/EvTJ3UWc
B0DAPVZmXTEDQF6Z0LZDvuo/znYqpuehHkCF5NuKK/XtP9QB3iJGCSBAp5JN
XqWK9j8w/R6npVoMQIpieGJvFP4/MGDdaBBzA0BosZf2nFgJQIcVGPxiARtA
6mMJvzs5DEAolWcEmuLzPwAAAAAAAAAAFTW238tDEEDcHWReQ+L/P8OO+Pb0
EyJApK/6DmVsBkCpU1vdyBQNQCcExbp4q/k/q21b7qt1GEC3cUV8f9bsP2Zw
X+Bu/CFA6JmlgZMTAEAA8bn7+J0GQNk0X72VhgVAhOzu0dkLD0Ce3ww0icz8
Pzglc54=
           "], {
            {Hue[0.63, 0.7, 0.5], Opacity[0.7], LineBox[CompressedData["
1:eJwVxduVoyAAANAICkTUGExURHy/0AkqUsmWMA1stdPP7H7cc9vvv3++we12
+/nn/07gxE7ptM7kbM4FIEAAAwJ8QAEDEvRAgR0YiCCGBPqQQgYlVHCHxkVu
4gpXur375UVe4nFPeLXXeb03eNqzCCOCfEQRQwkSSKIe7chggn1McYgZXrDC
hviEEkYk6clOzH2+r/fjbn3qM1/6u28oo5L2VNGdmiAO8qAM2mAKo5CHRbiE
KuJREdVRE3XREC2Rejwf+aOKsziPy7iNp3iLdXw982fFJOuZYjsziUi6pE++
kvP1flWv+fV5V+/5/UmzdEzXdEt1eqRXarMxW7Mt09mRXZnNq3zKNS+44DVv
eMcHvnDFddEUQ7EUSnSiF6vQ4hC2bMup3MpL9nKXpvrUTd3VQ302XTM0Zzu1
Wzd0ujuHc1zHbTzGa7TzOn/mY7aLUmbV67Feq90ufWm7m8Ne9heCNi2o
              "]]}, 
            {Hue[0.63, 0.26, 0.89], EdgeForm[{Hue[0.63, 0.7, 0.33], Opacity[
             0.95]}], DiskBox[1, 0.06249796298836899], 
             DiskBox[2, 0.06249796298836899], DiskBox[3, 0.06249796298836899],
              DiskBox[4, 0.06249796298836899], 
             DiskBox[5, 0.06249796298836899], DiskBox[6, 0.06249796298836899],
              DiskBox[7, 0.06249796298836899], 
             DiskBox[8, 0.06249796298836899], DiskBox[9, 0.06249796298836899],
              DiskBox[10, 0.06249796298836899], 
             DiskBox[11, 0.06249796298836899], 
             DiskBox[12, 0.06249796298836899], 
             DiskBox[13, 0.06249796298836899], 
             DiskBox[14, 0.06249796298836899], 
             DiskBox[15, 0.06249796298836899], 
             DiskBox[16, 0.06249796298836899], 
             DiskBox[17, 0.06249796298836899], 
             DiskBox[18, 0.06249796298836899], 
             DiskBox[19, 0.06249796298836899], 
             DiskBox[20, 0.06249796298836899], 
             DiskBox[21, 0.06249796298836899], 
             DiskBox[22, 0.06249796298836899], 
             DiskBox[23, 0.06249796298836899], 
             DiskBox[24, 0.06249796298836899], 
             DiskBox[25, 0.06249796298836899], 
             DiskBox[26, 0.06249796298836899], 
             DiskBox[27, 0.06249796298836899], 
             DiskBox[28, 0.06249796298836899], 
             DiskBox[29, 0.06249796298836899], 
             DiskBox[30, 0.06249796298836899], 
             DiskBox[31, 0.06249796298836899], 
             DiskBox[32, 0.06249796298836899], 
             DiskBox[33, 0.06249796298836899], 
             DiskBox[34, 0.06249796298836899], 
             DiskBox[35, 0.06249796298836899], 
             DiskBox[36, 0.06249796298836899], 
             DiskBox[37, 0.06249796298836899], 
             DiskBox[38, 0.06249796298836899], 
             DiskBox[39, 0.06249796298836899], 
             DiskBox[40, 0.06249796298836899], 
             DiskBox[41, 0.06249796298836899], 
             DiskBox[42, 0.06249796298836899], 
             DiskBox[43, 0.06249796298836899], 
             DiskBox[44, 0.06249796298836899], 
             DiskBox[45, 0.06249796298836899], 
             DiskBox[46, 0.06249796298836899], 
             DiskBox[47, 0.06249796298836899], 
             DiskBox[48, 0.06249796298836899], 
             DiskBox[49, 0.06249796298836899], 
             DiskBox[50, 0.06249796298836899], 
             DiskBox[51, 0.06249796298836899], 
             DiskBox[52, 0.06249796298836899]}}]],
         MouseAppearanceTag["NetworkGraphics"]],
        AllowKernelInitialization->False]],
      DefaultBaseStyle->{
       "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
        Hue[0.8, 1., 0.6]},
      FormatType->TraditionalForm,
      FrameTicks->None], 
     GraphicsBox[{{}, {
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.011000000000000001`], AbsoluteThickness[1.6], 
         PointBox[CompressedData["
1:eJw9Ugss1AEY90qxK7Q1j3nVqq3ltAhF9ru6Wou0dSQpj4QSlY5uQg9LOdXo
UIodofPahc4z48LqUleRV3e4k7vDdX93Hj3pqVr37fft27fv237ffr9vZdhp
WoSejo7OpoX8U2Nmz+mmm4pgtV12vaa8Gh99yvWCGkex1D+35dcFAbJaHi8T
cBUgC0VDgvBWvLt5e6aoTAaDIsNV64g3oAXVPv0SRmAToaGLQ3UplX9DBU+J
+KBXhBxbMuSbM+RKfCqfvMOgtiM5szdOVqqC69KNfnsdH8HmYuaEfb8EIdu+
eYT4l+EIy2k6PlqDJMtbPmwqT3vP7aHma0YdIuykF76cW6tA2wDTL9mch3rf
K/MpD8YR6FH3inG5Fm2Ru8jbf6qQFOV+fGUZHxyDpkP07B7Q7F8cEBZVwkXW
Nv7p21tUpzWQXxJS7bxqisekuldo+dgvZuL4ea8hSmcvQIkQunRf6NMhMAXz
3QF2g3Ce6jK7X/xQ2zeOxW+gNNQgP4NvfLJFhhkpnZ2dyYfGxTyr1G8Y1wPM
hbrKdixRr6nL7ZaCobd/twVjDA6XYuVqbxVs0wWtfRsnwetRmq0IJ9BItaZq
bGtwjxkY12k6hILyj56aKyaU/34JE0jZ2/q4yAt0HO53e4+qHaF3Xedq8U//
QTQlmxzV7+TB6fJzq+OBIyCJvWVyohEWw9+5dkwxrk2uW126mPtvXyVH87zJ
oXZOJTikrZI8u3FEhNl02liOoTX18/JBbwLJZ4J9WXvUyIl0m08kjYAIypcX
fBYilUi1+GqsQDFLXDe8qkHrDyt6VH224BHOWD9bgAQN+c4nfhS0aP1KS2w+
z+1ogstA2oKCSkwEkA17uvj4EXM6pGlaCnIfk5bzpBe29UvmohkKXD1F6rs7
UwFWydqJh75izBbu/HC4jKPVv1stjLywmYu9zJRqSr8Mi2IGrIu9DCmyGzua
DQzUMOySk1MLOTib6RTvYjYC2oBpVq59L2I9jd+WxErgldAzusiYp/339WPP
HIJTKnHvWK0qrr4fJnZsL1/LTrh2R+mzXRUw+nk4aoNGhN87N7PA
          "]]}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"K AMD\"", TraditionalForm], 
        FormBox["\"Real K\"", TraditionalForm]},
      AxesOrigin->{0.27649176954732535`, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImageSize->300,
      Method->{
       "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0.27649176954732535`, 0.9506172839506172}, {
        0, 1.0021269557978676`}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], 
     GraphicsBox[{{}, {
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.011000000000000001`], AbsoluteThickness[1.6], 
         PointBox[CompressedData["
1:eJw9knswEwAcx+c1FrtxPaTziPxhaokkj9Pvl/UUOqJUXic6kooYh5YuITql
l3CbiDyS1tKww6LCWd6szXCZdtRsTm+69Lra776/+93vfn/8vvf7/CzDT/tF
ahIIBMff+af+WJlCtT7xHdZ4yHI5VY+gfZuboDv4G5APFjT/ZHZAwKiOrSLA
BmlCsbQjogWirz09X/hwBWqXEq2oigHwIPoU6OVsRUeFKl4SpoG3LVZRtTq3
oPu45LBn5BQQ/oYtfq6avcOgt4FL0Yps4tAmdCLb+/tsbILDdoKhiA4FhG7/
7hZ6sBL0MhObZTRrTDW55c2ic9V+bkv5OaR2MWQkZHCXoozwmSjbP82YC+S3
y3fuT7fBI271PYyLTyCLljiiQgdMjXaNsqxsBenjOH3bB/3gt7b7kLC0Bq5M
k6CAp4RHWTzaK8WEel43x82mu1ar97G658+2FvWC+DLrt6wwNH7CN+ylFBZk
nIq60R7YPNdnVF72WN03yBPskMcBuRdXqbTRx/mJeNaNq62wWD0/6B3+BnID
jYUaM20gS5L1vR/XR4ZmwN7VDDns6V16/fyuPZpf7mgZtp+F9JA0kr/eOmyg
m9JV5hzIOZPrXOKhg+yqT+6qSxT8z0uYbHBj+3AtOJXbHT2PFKzbEVbotPAE
qJz4qHylHBrTKMe0urgwoMAYc9E4GEj2yaYUDcCfiaj+zNTCnFmq9X3d2r98
0h1WI3+RcrStogYI9fw5QhUZI8PNusxM5JAUwwws97HEtLiQA/leShCRxhYc
t3SCIrh4iv1FCOLpeyFlZD0sy5fUj1nx1HzyYyaVieymf/zfAa9484kf7GY1
r6wU/rna9kZIiNktoIzY43QgjTjY1wpBxXkQZ6GLtOFsv5svhsDXiqnhoP8V
Mk8ZDBfOV0Ovyi2zkykSfCjZ+TGoskJ9/36l8DjTuRbuhwZnajozBDonRaZl
nkRk50l8Y3sMkdg3RcsoqQBZMvlcZKw2+okMrxesHYJkV/G3XbGa6Jk8OKmz
jKv+9/Xyzg0hF2pgtLKmHzdIgWLB8jxg0gUS73DDQBddJC0FRdupxPALS2CL
4w==
          "]]}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"K CMD\"", TraditionalForm], 
        FormBox["\"Real K\"", TraditionalForm]},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImageSize->300,
      Method->{
       "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{-0.3514880000000006, 23.539193588780343`}, {
        0, 1.0021269557978676`}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], 
     GraphicsBox[{{}, {
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.011000000000000001`], AbsoluteThickness[1.6], 
         PointBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQvQoMmByknB51b1ix3h7G5w2bvud/3TH7UDDgddA9
feP2sZS9UHkuB5aFbEqary/aM4CBgIPJ63dFNxMYHSDyQg62d29GeqU+hst/
XfFmRpnzQTjfjNcwxE9vJ5TP4BDv+Ns6Pmw53Pxqyam+c503wd0z7fauLs5D
N6DuYXU4cK0jpEZ8E1x9lPWWs2XNm+1h9ldnWmUoLt8HNf+DfZDCqfDTC1dB
5X/Zr2/fpnvm9T24/Lr3mzqcrVbC7Zt76mPxvlnn4O6NL7oXmHD0NtT+r/bG
788LLlm0Ec7f/rRE32HbBrj7Pt4rmju5fx/cf90R4qcZXxyEm1/GFOopUfYU
br5c57G9VwzfwP2z3VnG+Z0cwrx5K77Yvmvld4DpP13BM9nxyhq4+nUuCTPN
fm6G+29HDX8y84lNcPt5bno/evx6O9z+rjeaKsvY18DN3/WLP/rg0lVwfmqS
7AlZyadw82sK44In+ryFm/c6dvbjed9Ow9Uvmnhzyx2lbXD+xOyHb0vnIeJ3
22zjrL/z9sDNa6/aVbvm0A64/59H6LJdOr8Prl/3SkfQlCOX4fy2PJ4rMz+u
hIf3p/mun2OWL4XzL7w9nVZnsQbuf9acazKLvNgcIOZzOLCdf6zbMn8p3P9B
1wQmTVe4DHefV8Wlh6xcm+DpXfvpcZ24RkR64Zef6xUseQLuHs5/MZn6727Y
AwCx0V2X
          "]]}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"K M-m\"", TraditionalForm], 
        FormBox["\"Real K\"", TraditionalForm]},
      AxesOrigin->{0.9236111111111115, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImageSize->300,
      Method->{
       "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0.9236111111111115, 4.666666666666666}, {
        0, 1.0021269557978676`}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}]},
    {
     GraphicsBox[
      NamespaceBox["NetworkGraphics",
       DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53}, {Null, CompressedData["
1:eJwVxUmWoyAAANAAiigOoUQ0otFKHDCIlIoX6SPUBfr+u379N//79++fX3i7
3RJwu/1f2awgiliYwSJQxK3OukAQIZSwOMACK2y/fj4rkVKFX6ENf0IHMAgA
ASHIgAAKWOBwH/Sil32vwAKXbCmWxcExG4txXMCJT3E+Po+VHOqwx+Huj/vn
vkLPk+H1vNwFh2wohmEcFkSQRApZdCB3fz/e7897BTves13sw77sdt9PnAZp
KtL++wir6lm56vJmOfczqkkd1lVdr7WtXX0BDjnmGecFF3zgI1+45Ts/uUMd
6R5d9919urU7fOwHfuoLv4cMMY8RxmomWcdmpphlB3PI+AabwBDDjDDS9GY2
yvhJkCRpIpM+mRMDG9R4DWlYI5umb+ZGNQZu3pZtxTZuywZbr5Vt07Zzu4Vx
XMV1/IzX2MUX0EgTHWqmha51p5XWRlt9aAdKXGYlL4tSlOVQjuVS7uUZvuJX
9Xq+XhecvIlNcmqmdprmaQM5zoM8y3Oei7zMbb7nJ6CIYkpoSCmjnApa0Zoq
qqmlOz2oo5cXkShKIhbJqInaqI+maI5UZP4B+mc4KA==
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]]}, VertexStyle -> {
             Directive[
              Hue[0.63, 0.26, 0.89], 
              EdgeForm[
               Directive[
                Hue[0.63, 0.7, 0.33], 
                Opacity[0.95]]]]}}]]}, 
        TagBox[GraphicsGroupBox[GraphicsComplexBox[CompressedData["
1:eJwBYQOe/CFib1JlAgAAADUAAAACAAAA8CJ+ILsrEUAAlWZah0IEQEIidrVw
zRZAg2mGwP3j/T+azG4I/1QMQEsOyzG5FvM/+0uh324LFkASsKMATsrqP0Ef
Bxmx7hVABPi3QKBm9T8UzKQ5ZX0TQMrJBjRrQQFAimzHiHdGFEDGdBlQ/lH6
PzTU8CrqOg5AE/JYGK0P9j/thYEqlbQFQMjBx5rksQhAhCD45/N/E0DcZX3z
zvjdP9LbCD+wogxA+1obzXY5AkCi/+VQgGH8Pzj6If149ANAQ//R13zAFUCU
waVKItXaP/QqkRpzUxdAgSOJt/1B9j+8hnf3XcIWQB9DZcf0cwZAAGU55edq
tD84Kg9UeofVP/y9BOcRaBBAQe6ufuJV8j8WUrkSGdwAQNFXOWa94RJAz6S8
pwMPE0DbX/cjy14GQGB12nMo2hNAaP9xnNdaBUBA4imVRgEZQCTVKG+zegVA
RGdUgZ+HEkAlf0oTLJEAQAaEAg/GbhVA5PNj60DDCEAkSL3Z8UcBQHCE4OWL
kwVABBWhVX2w5j9GKzgmLhnlP6lMtCv51AVA9b986Zh+/z/p5xxynYQSQLiX
fKuZh+A/+az9GqBFE0CqzuSwNw/qPzKHcs8trxdAVvzbai0w4j+o5s0jIeTx
Pzq4wWrFeglAmr1efgfTAkCCaACk2UjrP6AFQp5OaBRA7t1brh0C8T/CF9m1
JAYBQAAAAAAAAAAA6Ptzs+Mm+T9SkHyvvg0LQAAAAAAAAAAAGgs1pleT5z8j
ZVztC4wXQMBnEBP/4wlA6KwdHyDsGEB2SkXsnGYHQJIC2ZDIahZAIhxFOjX7
5D+aXn+jGoMUQOBbwD7QSsU/mMucsRL5EEB0p3my1kn3P8i72ya8VhVAFtmB
uhEmBUCUrsLJd5HpP7hpCpXx69Q/g9EZveGLC0DUWj0aNyb8P9770N8hqfU/
Zs39hur78z/cOEp6CTwSQDo7b2AWPPE/WvUMN3M2GUCkniGyktb8P0VSBQ4b
6g5AjskzeLRpAUB+3tJD2sr6P405UccAEBJAE3xQvJvjEkDcOLzZqDsIQC3o
YWsztAhA7EINjQZY8z+KPP2hj1UTQFlSO6GO4ApAwWu3LAWvCUBOFpblDYUB
QO+Bc1K80AFAmju2CGVvB0B/HXmp
           "], {
            {Hue[0.63, 0.7, 0.5], Opacity[0.7], LineBox[CompressedData["
1:eJwVxUmWoyAAANAAiigOoUQ0otFKHDCIlIoX6SPUBfr+u379N//79++fX3i7
3RJwu/0fYBAAAkJAQQZywIEAJVBgARpYsIMTOOjBDDLIYQEb2MIBjnCCC9wQ
QRQxVCOJGtQhhTQyyKIDOS/ymCe9xmu9yZu9zcd+4Cd+6gu/9w0OMMUpzjHH
Ape4xwobbPGOzyAJ0iAPRNAHKjAkIpQwIkhNJGlIRxTRxBBLDuJCGsbhV1iF
dfgKdWjDn9CFV5RELJJRE7VRH03RHKnIUEY5FbSiNVVUU0t3elBHr7iK6/gZ
v+I1dvGVpIlM+mROTCrSPssznhVZmQ3ZmC3Zlu33x/19/9xXVjPJGtaxic1M
Mc0Ms+xg7usn57nIy9zme37yggte8oGPfOGW7/zkriiLoRiLpdhEKXqhhBZG
WLGLsxzKsVzKvTyrunpWr8pV16N7vB+fx1rreq1t7epLNrKVvZzkLJU0Tdv0
zdTMjWpMO7Vzuz1fz6v77j6d7tbu6Ode9eb7eF3vz3sdxmEZ9nEZt2mettko
rYyy6li2ZV/cZ9VGW31otzq728O6/Tycu/4BWrM4KA==
              "]]}, 
            {Hue[0.63, 0.26, 0.89], EdgeForm[{Hue[0.63, 0.7, 0.33], Opacity[
             0.95]}], DiskBox[1, 0.05001586690953075], 
             DiskBox[2, 0.05001586690953075], DiskBox[3, 0.05001586690953075],
              DiskBox[4, 0.05001586690953075], 
             DiskBox[5, 0.05001586690953075], DiskBox[6, 0.05001586690953075],
              DiskBox[7, 0.05001586690953075], 
             DiskBox[8, 0.05001586690953075], DiskBox[9, 0.05001586690953075],
              DiskBox[10, 0.05001586690953075], 
             DiskBox[11, 0.05001586690953075], 
             DiskBox[12, 0.05001586690953075], 
             DiskBox[13, 0.05001586690953075], 
             DiskBox[14, 0.05001586690953075], 
             DiskBox[15, 0.05001586690953075], 
             DiskBox[16, 0.05001586690953075], 
             DiskBox[17, 0.05001586690953075], 
             DiskBox[18, 0.05001586690953075], 
             DiskBox[19, 0.05001586690953075], 
             DiskBox[20, 0.05001586690953075], 
             DiskBox[21, 0.05001586690953075], 
             DiskBox[22, 0.05001586690953075], 
             DiskBox[23, 0.05001586690953075], 
             DiskBox[24, 0.05001586690953075], 
             DiskBox[25, 0.05001586690953075], 
             DiskBox[26, 0.05001586690953075], 
             DiskBox[27, 0.05001586690953075], 
             DiskBox[28, 0.05001586690953075], 
             DiskBox[29, 0.05001586690953075], 
             DiskBox[30, 0.05001586690953075], 
             DiskBox[31, 0.05001586690953075], 
             DiskBox[32, 0.05001586690953075], 
             DiskBox[33, 0.05001586690953075], 
             DiskBox[34, 0.05001586690953075], 
             DiskBox[35, 0.05001586690953075], 
             DiskBox[36, 0.05001586690953075], 
             DiskBox[37, 0.05001586690953075], 
             DiskBox[38, 0.05001586690953075], 
             DiskBox[39, 0.05001586690953075], 
             DiskBox[40, 0.05001586690953075], 
             DiskBox[41, 0.05001586690953075], 
             DiskBox[42, 0.05001586690953075], 
             DiskBox[43, 0.05001586690953075], 
             DiskBox[44, 0.05001586690953075], 
             DiskBox[45, 0.05001586690953075], 
             DiskBox[46, 0.05001586690953075], 
             DiskBox[47, 0.05001586690953075], 
             DiskBox[48, 0.05001586690953075], 
             DiskBox[49, 0.05001586690953075], 
             DiskBox[50, 0.05001586690953075], 
             DiskBox[51, 0.05001586690953075], 
             DiskBox[52, 0.05001586690953075], 
             DiskBox[53, 0.05001586690953075]}}]],
         MouseAppearanceTag["NetworkGraphics"]],
        AllowKernelInitialization->False]],
      DefaultBaseStyle->{
       "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
        Hue[0.8, 1., 0.6]},
      FormatType->TraditionalForm,
      FrameTicks->None], 
     GraphicsBox[{{}, {
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.011000000000000001`], AbsoluteThickness[1.6], 
         PointBox[CompressedData["
1:eJw9knkw1HEYxldaXUMjxLbKUIxEh9gk49kYJdW0a3Ol0myOUERkMoVqsDon
zQ45ZnQhcs6mlK7NImxpqq1RYlXKHj9fvzJCF5l85n3nnfe/93me11IY6xs2
jcFgOI/3xKw1fk3Jvg7Chef4p6ubIOvy27brriqEcpKiPJvbMNPWPSKqnkCR
a9Tea6bL1eR/+pW4kkKk3iLRmqu18JvguhqR3COi03tr4N1UMStOq4J62EbZ
ki0HSYhOCbymwe+ww7nNPg/RuhCs2dMJVmZ0mx8aM+CKvFofvazoB5t1Rs9J
0Yl5ScfzGtw0yFwjEfLMWzC8/M5IEAjamT76hpn63Gnf4wPOqPsgtn9sJdwl
R8GJHAGJp2Fhs57PyquEXvizedUCDW6lp5AWUTk+jLFc/BNo7LJWzo5gN6Fi
ozLZuLIbpqUqdklUCRiKWo5IQeBZyBd6letwYy72F9/4qoSRjyDIhV+JuAxH
h/WcARyQunYO60vB+AeBX/I7a4mZYnIv0uKhdM7cigVV2KCop9NCtXjz6ZXq
rtVnPAkiGQslNDy2FbjpvHiAZ5G6hZyOz4ihR6x6TZ+jI9BigdrzI1iJ1/Ly
YyUom2AHjf2bb68yrB2E91ld7xl31ZBnBhdtv9KBcPd8us2X4P3eXMO+pW9x
Xjpku/M8jZHBffavDYuh5t9ZlK5WwpzacZJvXYKei2HisXYKxw4eKD/q3AnS
Z8xZ9ZhAL1uc0choRlN2iP2IrBc5duyxmJPVEFP6tkYBKhyrfKL8kVM25dfP
AIsEx9DSSb1pFLblFMldo+um9K8wKe2KrZHi/3+E1PgPKN5IIE4r7HW7r0Zq
PTFb7HAPZfKnW3gcAmfvxCVbwOCe++gyXhTKh0cNwi3lU35ov3X3bPpzA6fi
hMy6CApZfqlB8aeY3Av/UMI6U9DDOy2DB7uqcbVAi5ujuUvIhleT9xACu7WB
69L7q1CWFeG1WGcATqO8uo5Bg6l824Y2N9r41+FSVnL0zq0UvoTsPq5yakZD
moh5+fsATKqfalN+0GAucw/OW0pwSSNb52N6D/Mp1bjCITSkdiUJWqdz/+e5
O65vj6zgOf4CMGChWQ==
          "]]}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"K AMD\"", TraditionalForm], 
        FormBox["\"Real K\"", TraditionalForm]},
      AxesOrigin->{0.4766773834019206, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImageSize->300,
      Method->{
       "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0.4766773834019206, 1.3744855967078187`}, {
        0, 2.6738079770829826`}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], 
     GraphicsBox[{{}, {
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.011000000000000001`], AbsoluteThickness[1.6], 
         PointBox[CompressedData["
1:eJw9kn1QywEYxxeqO6ms6Wptopf9RG96mYXV81S4Xlw2KXnpRW8SW6IWrhqH
yts5qWveLqZTTC9zkyQvraahXbnr7SKVI8RYuWwtCjk9d889/33v+X6+X7v4
tI1Js0gkEvPP/r3tnf79Gf6B6MPxnOrr1wDh1jxEqXPAxBVZqYEtL4AuZeg7
F3hhl4jS+tZ6Nh7ja9xcD7Fwl5FtAev6HfgjQdJFLcZdeLDgVIIUSidjm9oJ
Bn7WEoPKQhUkyriFNloCJ5MEopaQxyBuLWJ1Jznj8rx++v4JM9ybG1U2j22A
NOppI++uXjhSJ9atS3DFfJYsnkNXQkFcxMOfYb7YahhiSs43xapsy8ovlQQW
uzTax0erID29Z+NmNRMXEf5c6sUqGJemaDM5TLx7PFejLJCABbual7XeC6MZ
g3N30p6CqTC1IeP8G7CqGKaVp5bDMTO6nfpzEAZe4cavlRigxiQ180fFd6CE
hG/x4VbBL0P2TTeBK/Lkq3q1pnKQTc8ajDj0iiGz7pr2f1hri4/lJuaVNtWw
42mAc2exG3a/6xiut38P4qlapfeEHwZsuMw2ePkIws6U8C3MrZA/Om7/1qoN
bkkExnoWBamZZRcvpcmm9XClE+4JvedBvjMC52Rj5GFjD1Tlb7u6SdwOLimj
AbZUX3ydICIPLe2B5IUUtmiJBY6PpLh0km+AfMxp+1n5GNC/bj3KZZTDJEGb
RTZ0xJy9PEk2sxcaJIqaUK4vGhUW5zWTWuDGfEsnRpM5liyjTfCP1sDJJ55l
2W0WmFPVNKgruTXD6+fmRRmeiRXT/5Fq7HFDyVXVqt21M/7dLSv60qRy+N+P
WGnkt65uGSS3Jd3uZnuh8L7G2sH1ARQGFzUfvEYgMyjTcT2QMJh6oJ4pZKFE
qzdLtlPN8FB/7x8InroJvg4mpRPXluKJCOGWfScN8R//+cjIDx/gnFJAmIJc
9O2jM97Wixw16zr+9VG9GJetjFp9/FM1+MmUgkelfuit59S2j5jN5PtiLLSZ
iKyFnO2DJq+57vghNubIsHcLCLwGdDw7F7SseabO1Y1CIF9MUkd64IUvitUh
Vg+A52MT1+i4BhuEfVnhz+fg/zxj0ofiFJfb4Df6NHmM
          "]]}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"K CMD\"", TraditionalForm], 
        FormBox["\"Real K\"", TraditionalForm]},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImageSize->300,
      Method->{
       "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0, 49.8431741129871}, {0, 2.6738079770829826`}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], 
     GraphicsBox[{{}, {
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.011000000000000001`], AbsoluteThickness[1.6], 
         PointBox[CompressedData["
1:eJxTTMoPSmViYGAwBWIQDQEiDhYBRv/v3v9gHwoGvA4pZuVZzsdPQ/mCDtdm
CJ95JMHssAoMhBwy2eQ6zBdvgqvPdKjs6E7eCOe//q728MSks3D9/1LLZhz3
2m8PsU/AwaDtvkzxbz6oeVwO0pI9bCbXbtnDzG8335IUIHPCHua+M6xevILt
vA4w/VN1DiolxcLMF3WQV3MMlJy1Dq5+a2vdhxMdq+H2x6o+5EqXPgY1/5e9
+IpX0suzlkPVSzg4zw1Mcl3NCDWfwUHYKzjSInAdXH/uIatb33kPwe0Lrbqt
ukXiGty/+w9x86+VWg9Xf/3JlVe7lJ7CzXfyn2PDeHGfPcy/eZ9+Kj0SPw9V
z+ogWbpk1uz8LXD9Od7bDQU3fYT752x79IKQRRfg/DvJMwSfad6Ah+fPjxk6
VwWXQc1ncpB5F9UcqLoc7r7agtzVNaaw8BVzYJs0te0Iw3Gofg6H6VrSv/Oa
N8D5tesOP/wxfRU8vP6Ey5cYpayA2+c/fcFZq+xtcPP1RVfczd94CB5/8RvD
3l+7vgXu3vqdHySUdXfD9Zt6lKr42DPA09Pq77/40hTPwsPj7ef7Dzz/r4Sb
3xlaH1nUxQpPL6rtwQ8Cuo/C7Vvza4bKB7crcPO1LCOsW1+uh8eXya+AbRc+
8sHj9/RX7yNqYdvg7nseH9f4yuQ4XL/ohpNv6358gsfHzDdHrb3Ed8PDb0/9
3fLgUyxw98QVPks4Oue8PQAIkTzN
          "]]}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"K M-m\"", TraditionalForm], 
        FormBox["\"Real K\"", TraditionalForm]},
      AxesOrigin->{1.5763888888888888`, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImageSize->300,
      Method->{
       "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{1.5763888888888888`, 6.}, {0, 2.6738079770829826`}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}]},
    {
     GraphicsBox[
      NamespaceBox["NetworkGraphics",
       DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54}, {Null, CompressedData["
1:eJwVxVuWmyAAANBowhgSRUxAcBQfEKNGRgTRdfR0Cd1A9//X0/tzuz9/f/8J
T6fTr+B0+j+fedvO520yZnuN8RSbePt+gRFMwIBhGIdpMAAhg7Z7fJ8ARhhz
PGDz/Xl9zgc6zHHu4g51uOumznRbd/CynEMelmEbzs/v5+s5Pj+hxJLLUrZS
zoAiiinlVNKBmnOSoAQnNOkSk2zJASDEkEIOWzjAEVhokcWW2sGOdrLGgj7p
Ud/b/rjCa3sdw/26873c213u8x466LCjjrvStU662bk9VFBhRRVXpWqVVGpW
Tu0BCO7BEEyBBRrqRCONNdW9HrQ22uojSEGaDqkNKlDdq7SqumqopspUNmhA
AxvUpE3TN0OjG9scoQDiKqBAAgsquBCNaIUUSgxiFFpY4cQeFrwoykIUbSEL
VcyFK/bL9QIvz8vrMoI1WdGKV7qKtVn7Va9mXe16hAte6MKXYikXsbSLXNQy
L4tb9q/n1/fX6+sTeOChRz711Fde+Mb3fvCT13711vvjHEVxlERdZKItzHFO
85znZS5ymat8yU3uwgxnGc3yjGdFVmYiazOZqWzOlsxle/C+v+N39X5P5zqq
k7rualNv9RE94sejfnQP89jSn5ABdmWQYZYxynLGOCuYYC2TTLGRzUyzhVnm
2H4mEYlJQhDB5EEIJTXpyEQ0MWQlGznA7Zbemlt/+7nZm/8HrSFNUA==
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]]}, VertexStyle -> {
             Directive[
              Hue[0.63, 0.26, 0.89], 
              EdgeForm[
               Directive[
                Hue[0.63, 0.7, 0.33], 
                Opacity[0.95]]]]}}]]}, 
        TagBox[GraphicsGroupBox[GraphicsComplexBox[CompressedData["
1:eJwBcQOO/CFib1JlAgAAADYAAAACAAAAd9u2uRJ5F0CJNtIAENQOQGBQ8+Qq
1xBALOQHy1v82T+Go+hAv5QfQEg/2lxFfv0/1cDPvlcNA0C5u/+P7EsGQAHg
HcBohRRAhc9W79LTBUAAOEbNK/uuP8S0cqgQoAtAPSP63ld5H0BVBinudLIC
QBu8l3K5NwpAhxVjD2bT/T/X/P6IUk8RQBC4QPyeagFAgQ6caO/0E0AuaO8l
ZigPQHmqmerakhtAgPYllXi2EUCaMqpN5fAdQCiazV7fRQpAmBKXZ9HcGkCS
1OXMw3v+P/JYFQH1TRhAL8vWkldyAkC2MF2VaxgVQFaYqzZnsA9AIPQngOy3
FUCOF0rNzTT6P0MNfrRUuxJAXHnJwHSP5z9pxScDFdofQBhKuKqDqAVAei1h
O1nX8j+2BuZRGA4KQN8eEfRLextAUJ6aFDWaAUB+j+yfvfYUQFoU3jGzY/s/
6smJ4S6FFECW3OdLjjLtP5tBMIZJZhFAxv3uEZrc9z+Ic6VySRARQBnN0Ut0
O/E/zuqfc8f6DkDAYreJsl7gPwAAAAAAAAAAcDdQ07ifDkCyeTTABW8RQAAA
AAAAAAAAemXIoMyaGEBm1uleJJEMQC3h6mAynRJA5dEFDqix+z/eBkZ1NWke
QIp+3MePwP8/ZjoEtTqAFUCT1Yjx1HQIQKaUkXl2eg5A41GGWGZS8T+58BJ0
WmAcQLBEVN38hARA2XaZK0nKEUC4v6coQkLlP4Vj9y//PBFAhoh4huxp7D9s
9zt4J3b0P5YtcwYEPgxA01u8YIDbF0CClJ0IN44HQG9aopiCmBxALJ0YObXz
EECI+VEI5kEUQGC2pG0YfAdA9DxDbWUOC0DX+2qGNPQFQEh0ch0huRlAczzN
d2ywCkAAfkvS1YHSPyUK91tqShBA8gXZKmwcD0AwEzHPqjTKP80+w0tRRhZA
l8N3otLMAUDNiqyaLlwTQPqMzyfjMhVAvABpLpWiEkBiBnvFy+bgP6NP5T85
rBlA+dRZUv3uAkCm2eP9kXMXQCtfsA+sWQFALi6PzZMYFUAzt5ITp5cFQJIz
3xJLHhJAqCY/fUQj8D/KzVOQPhAeQJz0CCyHRANARm7cjg9EFkBwnZrUvScH
QLD/p7kI+A1A6MRRw/K66D8TjESK9LUaQGvEDfMlIwRARv561A==
           "], {
            {Hue[0.63, 0.7, 0.5], Opacity[0.7], LineBox[CompressedData["
1:eJwVxVuWmyAAANBowhgSRUxAcBQfEKNGRgTRdfR0Cd1A9//X0/tzuz9/f/8J
T6fTr+B0+n8AgnuQBlXQBO9gCKbABj7MwjxkIQ+LsAxF2IYyVOEcLqEL93N0
Ts7kXJ+783Y+LtcLvDwvr8sIILgBBFKAAQUMVECABvRgACOYgAYGrMAC//X8
+v56fX2iOEqiR0SiOuoiE21XeGVXcW2v43WHGFLIIIcCNrCFCg5whBpa6KC/
pbfm1t9+bvbm7/G9ur/vU/yISdzF73iKTbwlKMEJSWhSJ13SJzoxyZpsyYEw
IogigRrUoR5pZNCKLNqQR0dapU06pD+pTT3OMMEU55hhjgXusMQKD1jjBRu8
YotdRrM8YxnPiqzMRNZmMlPZnC2Zy/YHedSP7mEe2/P7+XqOzw+hpCYdmYgm
hqxkIwfNKaOcCiqpogPVdKGGrtRSR33Ocp6XuchlrvIlN7ljnBVMsJZJptjI
ZqbZwixzbOcFL7ngLZdc8Zkv3PG9KAtRtIUsVDEXS+GK/fv1/Sllqcq5XEpX
7lVXvauhmipT2cqLRrRCCiUGMQotFrEKK5zwYq+72tRbfTR9MzS6WRvb+OZo
ZavauV1a1+7d1Jlu6w6p5CwX6eSuZrUop/bX+Pr0ul972/v+eE/DOEyDHsxg
Bz/ayUx28vMyu3nXRq/aaq+PxS27WY01mzlWu/r1sN7t/vgHXGpNUA==
              "]]}, 
            {Hue[0.63, 0.26, 0.89], EdgeForm[{Hue[0.63, 0.7, 0.33], Opacity[
             0.95]}], DiskBox[1, 0.05767655921941052], 
             DiskBox[2, 0.05767655921941052], DiskBox[3, 0.05767655921941052],
              DiskBox[4, 0.05767655921941052], 
             DiskBox[5, 0.05767655921941052], DiskBox[6, 0.05767655921941052],
              DiskBox[7, 0.05767655921941052], 
             DiskBox[8, 0.05767655921941052], DiskBox[9, 0.05767655921941052],
              DiskBox[10, 0.05767655921941052], 
             DiskBox[11, 0.05767655921941052], 
             DiskBox[12, 0.05767655921941052], 
             DiskBox[13, 0.05767655921941052], 
             DiskBox[14, 0.05767655921941052], 
             DiskBox[15, 0.05767655921941052], 
             DiskBox[16, 0.05767655921941052], 
             DiskBox[17, 0.05767655921941052], 
             DiskBox[18, 0.05767655921941052], 
             DiskBox[19, 0.05767655921941052], 
             DiskBox[20, 0.05767655921941052], 
             DiskBox[21, 0.05767655921941052], 
             DiskBox[22, 0.05767655921941052], 
             DiskBox[23, 0.05767655921941052], 
             DiskBox[24, 0.05767655921941052], 
             DiskBox[25, 0.05767655921941052], 
             DiskBox[26, 0.05767655921941052], 
             DiskBox[27, 0.05767655921941052], 
             DiskBox[28, 0.05767655921941052], 
             DiskBox[29, 0.05767655921941052], 
             DiskBox[30, 0.05767655921941052], 
             DiskBox[31, 0.05767655921941052], 
             DiskBox[32, 0.05767655921941052], 
             DiskBox[33, 0.05767655921941052], 
             DiskBox[34, 0.05767655921941052], 
             DiskBox[35, 0.05767655921941052], 
             DiskBox[36, 0.05767655921941052], 
             DiskBox[37, 0.05767655921941052], 
             DiskBox[38, 0.05767655921941052], 
             DiskBox[39, 0.05767655921941052], 
             DiskBox[40, 0.05767655921941052], 
             DiskBox[41, 0.05767655921941052], 
             DiskBox[42, 0.05767655921941052], 
             DiskBox[43, 0.05767655921941052], 
             DiskBox[44, 0.05767655921941052], 
             DiskBox[45, 0.05767655921941052], 
             DiskBox[46, 0.05767655921941052], 
             DiskBox[47, 0.05767655921941052], 
             DiskBox[48, 0.05767655921941052], 
             DiskBox[49, 0.05767655921941052], 
             DiskBox[50, 0.05767655921941052], 
             DiskBox[51, 0.05767655921941052], 
             DiskBox[52, 0.05767655921941052], 
             DiskBox[53, 0.05767655921941052], 
             DiskBox[54, 0.05767655921941052]}}]],
         MouseAppearanceTag["NetworkGraphics"]],
        AllowKernelInitialization->False]],
      DefaultBaseStyle->{
       "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
        Hue[0.8, 1., 0.6]},
      FormatType->TraditionalForm,
      FrameTicks->None], 
     GraphicsBox[{{}, {
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.011000000000000001`], AbsoluteThickness[1.6], 
         PointBox[CompressedData["
1:eJw9Un1QywEY3kYkyZzL5xJdX4daErqTnpWPXOjSDXFMMglF6CLGlY9zSRP+
6Jw4WUxmLNGZbjNrCq18tOajVkJZq22//bZhc0px7bnnvffe/56Pd1bqvqQd
NAqFsnBwhvbVw1bnxWsEoosdih0V30AZwkwrCrQxUjfaA2yvEifdKLXgSZJj
T7dYhL4UdbwgjsRUd9+98vkPoPsHI5ZpK6YUHXNjpTPLZKd+KDHauK3xxean
WDeE0yQMwtpqplqFc/ayyugIE95wDXJ+Qy1G3WVs4i42o3/nu2fyVwS8Izwy
bYU9uN+e28GYK0Wajp+3SEjgefOWo5zVUrSyhOOyPxHoYvd1xLyWwZ/e/YEu
sEN3ziwIM2kgD+AOWGQEgk9cs/1m61GetcTjvcCEkKDj3LJDCqgNW8gURQ8u
ZIY3b4ihsWi2jKAMAwG/Hk3p5TYl4sYPjGBGWtCZ6kj1WSmGweSzPii0E56j
pz4SJShB0ltH3Ptph0o2QN2t7kPBG6lkBUOPWEFvl0JPYz0uqGGt4ZgwPUcf
sXijDukXjDwsMMGH95bBDmxHW7N7w5IiAiH5vcE1vi3IuZMISQuJp1e+LZDF
iTCcn+pUZHzoKgmarFGvrVG/IapqsG9Nu42Ncs9CrdOMmmpmTyzxFfX7GYO0
IUdJrFV/NP7vL8+Ccn55MX+2CAXl+aoxo2yYEh7LnXzwK7JM+dH9nlZwPn1U
j6UpMa136fZj6SQUyd6XQmStGM7jS1Rl/cLAly69Xt2z9bdE9a48shfFsiM7
JUgK7RokiRlOv4N16XJXX5IS+lzvwkp4CYouah6b0fojh339hheLVztARqT0
whLmHpVNb0Ha+Yw57ckEhJMsN88km13+w30T1+iYdZAE/5k4K8EJ45XTvyT5
QuSuO5JHLTHgZPG4WiGDBG+MMeBhyXe8eMVp8iduufQrXqbG6d2k0DT23SX8
HThzduVVhsOCTB9no7bMjEReWEegvc31v1kV/dR5Wgpr2C+Lrv+8PLcJ9SOp
ExrFJEybRmo8xHVgEwc8OAl2tHzfS5SSFhj5E44/o1phzFWfPaCqwp091b84
GYO3dwD70K4G/AWuIsGe
          "]]}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"K AMD\"", TraditionalForm], 
        FormBox["\"Real K\"", TraditionalForm]},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImageSize->300,
      Method->{
       "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0, 1.702380952380952}, {0, 2.346099448562091}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], 
     GraphicsBox[{{}, {
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.011000000000000001`], AbsoluteThickness[1.6], 
         PointBox[CompressedData["
1:eJxTTMoPSmViYGAwA2IQLSMkpuqXpOpgN+HngdSVT+yBQgwKjcYOndccd7Iy
bbIXmZgX/u2rs8OuoJ/Zz9autq8qmCub+UrBQZJDPm+f8Sb7t4E75Fpfezm4
XFsp0VvL6sAABexvE8+eiNkPNk/srKPDq+WHt+mfOWJ/r/Hf2S8Z8g4XUl7t
6zt92D7vK99258NKDv/SLx3cd+qD/bXw++K8wuIO6+9V3pfR2Wn/7/C2M7Kh
7A5HL8dWx/nstJ+yNi2/SMrG4WnIm/uO5/faF87fs2eNkbXD3Z73iw3eXbF3
DI+W+sts56DRNO/L75AX9guOKGwo0lJ30FWvS1lYfsBeo4DTeFHAH/uJuUaX
wx2ZHLZ8rO98eEzFQenllTkz7xyyfyV3bqanipnDw6SfSbIea+1n8M8pn/Lw
hz0Pu+TW1X6H7PPMJNn+W5g5HNn7nzHrzBt7qXq3cPbax/ZOi18/PfCCyaHs
TWzR3SwjB+myFybWkXftGatbWb8zqznI1lyUCVG7Z//N5FCRv7KOg27ja43d
8lftS7XNJSJ/WDnsn/3EdK/7antY+B1psfDS895gf3Yz59ETpaoOqzef/hqf
tsL+3urmpmBPUYfd2/RfOn14bN8YsYTH5qi1Q9mhD4Fnbr4F69f5Y+CwpG/J
hD6t1fYq9SeWvFD0cJAwckoRL35s/yFOPibd3cIh7tbNM9xMh+zv+H++pqBi
6HAgQnSy7t7b9rDweGSz8biZ2km4e/meab1Ytvo4PDxKzJ1CLB5usG+Y2H14
2i4hB7lfSsXHMvbB42vDdAEd0e6N9glGi3PvGwQ43P5WFrJgEZ+D2hKzG7am
5g4fDThsSgSu2j9KvMG8WFXRYbnYx6XtEe/h/jeSD/C9q3/M3km3emqwopvD
29mtPzY0Lre/skB/79+dJg7NE3gPL5f5ZH+33fXUgcUf7U+cijun8mEZ3P0H
Tia5v2DdaW+y9Uiu5s8gh/Yuj7kyPz/a63wHecjWIaDG4L7a1zvw9Fuw8h+j
4TUGB5h/HQRePHCtPGdf+9dT4udnA4d3USxXuNYes985/9lax6YAh6vP8z7M
+fTR3krv/5ebebYObyvPdBUd2Wwvmact9XGqgcNbUdWQ8szT9gDR3I0q
          "]]}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"K CMD\"", TraditionalForm], 
        FormBox["\"Real K\"", TraditionalForm]},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImageSize->300,
      Method->{
       "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0, 75.89315361222981}, {0, 2.346099448562091}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], 
     GraphicsBox[{{}, {
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.011000000000000001`], AbsoluteThickness[1.6], 
         PointBox[CompressedData["
1:eJxTTMoPSmViYGAwA2IQHQoGog52E34eSF35xH4VGAg5dF5z3MnKtAnKF3PY
FfQz+9na1fYQ9bwOkhzyefuMEfIu11ZK9NayOkDkn9qzv008eyJmvz0DGEg4
vFp+eJv+mSNQvoDDhZRX+/pOH4aaJ+jwL/3SwX2nPsD56+9V3pfR2Qm37+jl
2Oo4n51Q/SIOT0Pe3Hc8v9ce5v67Pe8XG7y7AudrNM378jvkBVy9rnpdysLy
A1A+h8PEXKPL4Y5MDjD7lF5emTPzziG4+odJP5NkPdZC/cfkwMMuuXW1H0L+
yN7/jFln3sDNc1r8+umBFwjzpMtemFhH3oW7X7bmokyI2j14+Oo2vtbYLX8V
Hj77Zz8x3esOC9+n9kdaLLz0vDfA/bN68+mv8Wkr4Obt3qb/0unDY7h82aEP
gWduvoXzl/QtmdCntRruXgkjpxTx4sdw++Ju3TzDzXQIHh8HIkQn6+69DQ//
RzYbj5upnYS7l++Z1otlq4/Dw6PE3CnE4uEGuHq5X0rFxzL2wd23YbqAjmj3
Rrh9t7+VhSxYxOcAM++jAYdNicBVuP3LxT4ubY94D/e/kXyA7139Y3D9b2e3
/tjQuBzuv+YJvIeXy3yCu+fEqbhzKh+Wwd1z4GSS+wvWnXD97V0ec2V+foTr
D6gxuK/29Q48/Ras/MdoeI0B7j4HgRcPXCvPwc17F8VyhWstwj1Xn+d9mPPp
I8J9lWe6io5shofXW1HVkPLM0/YA9uhSEw==
          "]]}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"K M-m\"", TraditionalForm], 
        FormBox["\"Real K\"", TraditionalForm]},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImageSize->300,
      Method->{
       "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0, 6.}, {0, 2.346099448562091}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}]},
    {
     GraphicsBox[
      NamespaceBox["NetworkGraphics",
       DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55}, {Null, CompressedData["
1:eJwVxVvaoiAAANBEUQstyWvyo4h4wYS0JPYxS/g3MPt/m2/Oy+l+//75BafT
KXBOp/+vhzv7kz+6POF8Psfx4zEFa3As63Kci7goHhWvluqIr9fi+rhOTuCU
zprkeemLSnAhRh9jgUc8+VGEIxGN0eTY2BaW29k693t+L4EPIoDBAwgwggkg
H6EIYcSRQCOaqn3Z98P9zt9kuA/5UA7BZ/msn8/hZEmW8cx6Zy/2Mq/wuDd7
1qWIJhTTjFJOBR3pTL/UOpfgclm9/tzHfdYXfW9B6qcojVKcpiId08nrzl3c
FV3XdxYwxCKGWcEejAk2MVv9gNqvUR3VuE7rmtWiHuspae5N3pRNM7i32+y2
t5a27dx+AYQ+RDCCGKawhhQyyKGAo6ugQgqrWlHVKq6EGtWs1NcxibmbzOSm
NI3hZjDGupu33Ta6tRvf+m3e1LZ9HR3oTFeaaa6FXvSq9a4PbbR1pCcDmclC
MsmlkFLLQxppq/fPe3nv7+SZP3+ezXN4hkmYhXnYhDwcwmdoIAkJIgnJSEUI
JYxwIogkC1FEk50cxDiv4HV5ra/X5x+i2Dtm
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]]}, VertexStyle -> {
             Directive[
              Hue[0.63, 0.26, 0.89], 
              EdgeForm[
               Directive[
                Hue[0.63, 0.7, 0.33], 
                Opacity[0.95]]]]}}]]}, 
        TagBox[GraphicsGroupBox[GraphicsComplexBox[CompressedData["
1:eJwBgQN+/CFib1JlAgAAADcAAAACAAAAeSi3BS2t9D+2rKN2yC73P3Kc4t1b
QBNA4IUsgcm++j8n7m4qbMoMQEGXfczizQ1AMWor8aj4CkDIejfq/qD4P97I
uNIt2BBAZ6nqmEDiAkCVtimYON4UQGJ70fJyhwBAYWbWkf838z/a0/Ra4Iji
P6s3kQuPMfo//LyQ7kgsCUC9FJDTeWINQBAjaak37bE/+AE43DYz4z8AAAAA
AAAAAKVYPaa5ChFAzFSaihwGAUCM4ZDgtNITQFy+OVhbSv4/QPnhEAvzD0B8
+SClQ1jeP2aCPXQz6RNAcP/wLdmFvD/mlV/u5PMPQNIMWnYhaBFALlm6aOHC
/j+s2n2xJrMJQIZ5mqjffRJALk/GcSIsAkC8wolywz/hP05o423VoAZAxkRE
lgOwFEDQ8LR02IcCQKNfvDzk8wJAPjc7sDYlAUC7uNp9g6DwP/44FepDZAtA
rJeg14Y9DkCe+A3/eyfnP4bWJT0Yauk/MgRpIYWjBkDG6k9rMTX6P4zg4XJ3
cABAu+v6LgFTE0Aos4cOSW7kP94kOMoXSxNAbXcwkq8lAUBjTf4ZIvQEQHD+
AqRAbAFAAAAAAAAAAAB6AuB13zYGQK0izwcj7AtAtdXKVh1TBkBkEHBkfNfo
P3mDxW8PVwtAXthZVvnUEEC1HMq0+D8OQHCyYBsOSg9Ax5QknQMn+T8yFRHM
LpoKQFAUGB7U/to/YmSRyLVhB0DM76C61TcEQM56OudpQwtA4P0UEBrQ8j/w
e2UMLfMNQHNbyo84wwBAf0NMLun08D9mQ5e162YNQOpgz4PlABNA/d2HMCn1
BEB5Qe3qupIUQDkbTay7C/Y/kBED1dr8C0ApBYQPBF8JQMadvgF5IQRA+kK+
Zb5N9z/yADs9+g7wP1iqwMnwXfY/QBrzjktY4z9zgUcUYXoOQKiHKtF4Luo/
BMH3fCzn5T9uny0rIgwQQF4r0HfAJQdAMO2be2bRAECfqI6pQdH4P4hRB2mk
H9E/EAsmBrarzT8wOnEvXNUNQAbADTXoFghAG87Zx9iY8j/fZ7TZQjf9PxDt
XyIUF8s/VDhLTOC7/j84ZHC6LIDTP0aiES8Wf+M/Hp5niFFg9z8axbAh/yfy
P15XAhJ2/Po///DlrdVoBEDjmjW24XEPQEw8TNer8w5A5TB+XIl9B0AAUxCP
UEL6P+NGiJk=
           "], {
            {Hue[0.63, 0.7, 0.5], Opacity[0.7], LineBox[CompressedData["
1:eJwVxVvaoiAAANBEUQstyWvyo4h4wYS0JPYxS/g3MPt/m2/Oy+l+//75BafT
KXBOp/87gXNx7k7mlI50Vkc7L8c4FkDgAwQigEEKHqAGDAgwgsm9udRtXe7O
rnI39+udvdjLvMLrPO713uxJb/Ms9CGCEcQwhTUkkEIGORRwhMpHfuRjP/Vr
X/ijPwWXQAZroINX8AmOMAmzMA9J2IQ8HMJnaM7xuTh35/6yXl4oQhilqEYE
UcQQRwKNaEIqwlEa1RGLRDRGU3yNi/gRd3Ef22txfVynW3ubb1uSJXlCEpo0
CU+G5JkYnOIaU8ywwCOesLrn9/Le3Ie7SetUpGM6ZSSjGc/6TGY6M5nNy7zJ
h/yZm+JRsKIr+kIWtmzKoTQVqX4qXolqqXS1V+/qeLDHVLNa1GM91YpQwggn
gkiyEEU02clBzM/z501byqmgI52pohv9UtsMzbMx7dyqdmu/TLCJSaaZ7frO
csFnLrnimm/ccNtvvRWjkEIJPTwHM6pZzdv8na3U8pBG2mVd9LIv7+WzHKte
X+tnPdSmvnrXhzbavj7bd3/vx+cw9h9ukDtm
              "]]}, 
            {Hue[0.63, 0.26, 0.89], EdgeForm[{Hue[0.63, 0.7, 0.33], Opacity[
             0.95]}], DiskBox[1, 0.0442750620937018], 
             DiskBox[2, 0.0442750620937018], DiskBox[3, 0.0442750620937018], 
             DiskBox[4, 0.0442750620937018], DiskBox[5, 0.0442750620937018], 
             DiskBox[6, 0.0442750620937018], DiskBox[7, 0.0442750620937018], 
             DiskBox[8, 0.0442750620937018], DiskBox[9, 0.0442750620937018], 
             DiskBox[10, 0.0442750620937018], DiskBox[11, 0.0442750620937018],
              DiskBox[12, 0.0442750620937018], 
             DiskBox[13, 0.0442750620937018], DiskBox[14, 0.0442750620937018],
              DiskBox[15, 0.0442750620937018], 
             DiskBox[16, 0.0442750620937018], DiskBox[17, 0.0442750620937018],
              DiskBox[18, 0.0442750620937018], 
             DiskBox[19, 0.0442750620937018], DiskBox[20, 0.0442750620937018],
              DiskBox[21, 0.0442750620937018], 
             DiskBox[22, 0.0442750620937018], DiskBox[23, 0.0442750620937018],
              DiskBox[24, 0.0442750620937018], 
             DiskBox[25, 0.0442750620937018], DiskBox[26, 0.0442750620937018],
              DiskBox[27, 0.0442750620937018], 
             DiskBox[28, 0.0442750620937018], DiskBox[29, 0.0442750620937018],
              DiskBox[30, 0.0442750620937018], 
             DiskBox[31, 0.0442750620937018], DiskBox[32, 0.0442750620937018],
              DiskBox[33, 0.0442750620937018], 
             DiskBox[34, 0.0442750620937018], DiskBox[35, 0.0442750620937018],
              DiskBox[36, 0.0442750620937018], 
             DiskBox[37, 0.0442750620937018], DiskBox[38, 0.0442750620937018],
              DiskBox[39, 0.0442750620937018], 
             DiskBox[40, 0.0442750620937018], DiskBox[41, 0.0442750620937018],
              DiskBox[42, 0.0442750620937018], 
             DiskBox[43, 0.0442750620937018], DiskBox[44, 0.0442750620937018],
              DiskBox[45, 0.0442750620937018], 
             DiskBox[46, 0.0442750620937018], DiskBox[47, 0.0442750620937018],
              DiskBox[48, 0.0442750620937018], 
             DiskBox[49, 0.0442750620937018], DiskBox[50, 0.0442750620937018],
              DiskBox[51, 0.0442750620937018], 
             DiskBox[52, 0.0442750620937018], DiskBox[53, 0.0442750620937018],
              DiskBox[54, 0.0442750620937018], 
             DiskBox[55, 0.0442750620937018]}}]],
         MouseAppearanceTag["NetworkGraphics"]],
        AllowKernelInitialization->False]],
      DefaultBaseStyle->{
       "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
        Hue[0.8, 1., 0.6]},
      FormatType->TraditionalForm,
      FrameTicks->None], 
     GraphicsBox[{{}, {
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.011000000000000001`], AbsoluteThickness[1.6], 
         PointBox[CompressedData["
1:eJw9kHtMkwcUxQEf1CICabOhBiwgEZ3UuhnATT3fiMwXTCEwJsEXjrFYModW
IaiAj6GR0GVmCiSajLGtlVZqu0IbKK9BpVAqsMIsjEeBlvZr+VomGEFhE1H5
5d7cf27OOfcGpJyOS3VzcXEJn+/XczPtt/+TNRaM0MoVg9weOAwWiasXBcFN
b/5yjgaheiKD8dIGafRPTaU1rRjsmVJpAseRtFLXnHr+b1jVXL8sDyuY3j3F
NdohMGnPw/a0OfBfvK6QlEvh92Gmpj9gFKLVVHXymU6EySpzd/dZsVTHNq17
oEfCAqNwnylUcixi3HZ4hjASRzBZdq5g2FaBzqORF1ZQZkiPHWwINPRDtnSc
aSEp+NzdLVsZqwRpONIVN2tFbruAE2RX4PIJP0mWhw2m9IwfdjYLMVQfrdxn
M6LRXtcdx/8dFXuGs5kVNmhjH8VfF1og/Mr12trTTsQM+EzF+qlREF1FWkVG
OHTitG/p4sV7DpQOGINCJQjzPRxVwpvAl/0Fj28b6ASn9M9ARYAJW1YkqdYe
l+OXoCrm9KQD3xOtmdn+7Yt6slajfIlcCBPL7Vg9aYV26DPZ++WDKHxWKt21
zYZpYeKti11VKF/AgY+9vdOkLdVIv7LGzHJz4tCanIfT/UsIqVn6+NdrRnAy
J/fXkqI3+zcp3HlyUqOaofAuj6W4L/L+pUrciGpr0D+gUKI9HLJRJHmrTyH+
6Kz/1AYThof+TcrpNSG4zk7//IocAwtQQMKGb076eBLrnZKrWz8wI/HqC5a2
UQfVexna4DwbPmrpeSSQTyz67VV0K/SSWijHrs87OkFOl23bpJYjK/M1FmwV
pRSxd8pRcmvjfJFoDzvXsbymEzHCEFV6sh2pA3Oc3HAvgtdHCDx5Yyhje/Ea
n6jBuTOb0rplDP8sO8Cu9xWA3pXfse6sCYzYbnX29nqwzMJ0zpQFXm2GL/K5
Zmznj0bwR8ex/rv86kK+G1FJm+Ge7x6BvrbD3HRWhFS2e95fe20ILcqTfh3S
BCLhkzx3+hhyI3Ii0u41gHDh+SjVJtTw585E+ovBT3HO/pxjRstzhmvLpyKI
VwVHThaTKKr8gwpn9aJOll20w3cCUeNRp2ICJxb/fSGpqZnoVUJ9qJxB+9EO
rofo2dOnc3gF+IzLuQ==
          "]]}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"K AMD\"", TraditionalForm], 
        FormBox["\"Real K\"", TraditionalForm]},
      AxesOrigin->{0.505519479720954, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImageSize->300,
      Method->{
       "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0.505519479720954, 1.0284664830119374`}, {
        0, 1.7636288453540243`}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], 
     GraphicsBox[{{}, {
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.011000000000000001`], AbsoluteThickness[1.6], 
         PointBox[CompressedData["
1:eJxTTMoPSmViYGAwB2IQfZUnL6XIW8LhEceq7feyr9r/c5R+IviIxWF5l0Af
m8EJ+5euagdCk+QcNvpMObxw90l7Mb8nyk6zZR2ieM4eSS27Zp/xzNpl/mRh
BxGBqzN2n75v/6Tol2V1i6TDv5CzvS+3bLS3qpZ5zXPqh/1qybe7Yoou2NuZ
Lnoi2iHowHJW74n82sv2DCBwQMSB/WfvDoPna+w9/zCliL1jd/i8uLT74at1
9mkPXl77IyDssDHe/4DSjTv2pk8a2/7pcTsIznHZxBO4w14jX+GA91EJh/oz
yw2UX2+3Z/Pud1m1TNXhSU5hv+2RFfa2hkU1LZOv7T/4et+VoL5l9hZxuzx5
jok6nA48FtK+4rm9xsW7bM9m6jv43hX8Eih71N5C8ouZ9H92h3dn16Tnca2B
+8d74d0Hyrrr7Q9YHL7cqK/uEHGn+9zUG1wODPPnnP5Y8MRenzNqj3TCFvvA
SQrbdx0xcmh1OFleJXcGbt6mkw+2MG9ZYc+lFs6U91va4fR9t03iq+7Z25hb
zdsSpO/wY0X4pJqL2yDh8UDFwUpAIH3j8V32r9SbXzFvVHYIkKrb8OMOs0OX
sZF/0CkBB4Pyz157X64Gqz8Qq+gw7XryiT0/39rD3PN8xi2nlbVb7TV5TkQq
T5N0mHk6UkNz9Xqw+pSFBg4hcX/kvqg/sV+2kX22YwCfg+q+11x+TVvs790F
AUUH+1D1jGRBXoega6t9ik0lHcKbfymcPnjW/q/sRP/IdWIOxsevHlu+5QPc
Po/tV7ZfXr/XvuVXzvbDFmoOL38sNtE6usVe/0NJdl2EgIPh6qTperZb7EuD
up25F8k4nDErPc+2+4L9rJt5RUG28g6pd/8a1JvzO9w69z34seo3+8V6/CUH
rx+175hW3SGUL+pwm9Vbb7/EcvvE6bwW+hpcDsKBV45WWe63r5M83uyvpeHA
f+pGWFv2U/tQEHiq6aBS0Lart4/JocHYlun0BAGHy3vPPz1cvNpeaq9up+4l
Awfd6Q0b0zQO2/9q9jI9E/LTvt6iziJ97gH7LzfndjenMDjs7vtb5CS3xr66
5s+DtR0CDse/CzMed1xt/2TCr7xZ/h/tp2/d/NZc4ab9jvcyK5tUFBxc37hm
+Sp9gId3ddThIw43d9g/SKq0vO9u55DNvfrrp09/7QG5IZYz
          "]]}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"K CMD\"", TraditionalForm], 
        FormBox["\"Real K\"", TraditionalForm]},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImageSize->300,
      Method->{
       "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{-0.35275375512061996`, 30.280749885688124`}, {
        0, 1.7636288453540243`}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], 
     GraphicsBox[{{}, {
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.011000000000000001`], AbsoluteThickness[1.6], 
         PointBox[CompressedData["
1:eJxTTMoPSmViYGAwB2IQDQEcDo84Vm2/l33VPhQMeB2Wdwn0sRmcsIfICzhs
9JlyeOHuk3B+FM/ZI6ll1+xXgQGXg4jA1Rm7T9+H6hd0+Bdytvfllo1QPqvD
asm3u2KKLtjD7GM5q/dEfu1lOJ/9Z+8Og+dr4Oo/Ly7tfvhqHVx+Y7z/AaUb
d+DuE5zjsokncAecX39muYHy6+1w/pOcwn7bIyvg5h18ve9KUN8yuHmnA4+F
tK94DveP713BL4GyR+Hy786uSc/jWgP3j/fCuw+UddfD1Ufc6T439QaXA8T/
TA76nFF7pBO2QMNDyKHV4WR5ldwZuHmbTj7YwrxlBdx9p++7bRJfdQ9u3o8V
4ZNqLm6D860EBNI3Ht8FVx8gVbfhxx1mB5h5BuWfvfa+XA2Xn3Y9+cSen2/t
Ye55PuOW08rarfD4mXk6UkNzNcz9Ig4hcX/kvqg/gcur7nvN5de0BW6/fah6
RrIgrwPM/PDmXwqnD56F22d8/Oqx5Vs+wO3z2H5l++X1e+HyL38sNtE6ugXO
N1ydNF3PdgvcvjNmpefZdl+A81Pv/jWoN+d3gMXXYj3+koPXj8Llb7N66+2X
WA6PT+HAK0erLPfDw5v/1I2wtuyncPUqBW27evuY4OF1ee/5p4eLV8P9rzu9
YWOaxmG4efUWdRbpcw/A/bO772+RkxwiPR7/Lsx43HE1PD6nb9381lzhJjy8
XN+4ZvkqfYDbXx11+IjDzR3w9JPNvfrrp09/7QHvg1TT
          "]]}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}, {
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"K M-m\"", TraditionalForm], 
        FormBox["\"Real K\"", TraditionalForm]},
      AxesOrigin->{2.2777777777777777`, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImageSize->300,
      Method->{
       "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{2.2777777777777777`, 5.}, {0, 1.7636288453540243`}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}]}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{
  3.834888897828451*^9, {3.834888939775813*^9, 3.834889002084197*^9}, 
   3.834889052013794*^9},
 CellLabel->
  "Out[159]=",ExpressionUUID->"704a7ace-83b2-4780-98b0-56c0365fc755"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<test.png\>\"", ",", "%"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8348892099793763`*^9, 3.8348892243840446`*^9}, {
  3.8348893213753347`*^9, 
  3.834889323232689*^9}},ExpressionUUID->"c5c81ffc-0022-4803-8bb8-\
145416e531d8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "@", 
  RowBox[{"Inner", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ColorGraph", "[", 
      RowBox[{"#1", ",", "#2", ",", "Medium", ",", "1.2"}], "]"}], "&"}], ",",
     "dataindex", ",", 
    RowBox[{"Map", "[", 
     RowBox[{"Transpose", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"points", ",", "kr"}], "}"}], "]"}]}], "]"}], ",", "List"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
  3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
  3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
  3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
  3.834892116823455*^9}},
 CellLabel->
  "In[261]:=",ExpressionUUID->"b304b022-2421-42e2-b56f-33c1677d25a3"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50}, {
          Null, CompressedData["
1:eJwVxdvZmyAAANAQUFGjAiqIqIlB8QpeRukI/wIdvSu0fTjf6X9+//p5Ph6P
P//8n5xpmd7fm0zTSUxgyDIty5kWxbe4PRlIIqWBwsuCLJPwEAfkKS84N/yG
SSKSI53JXM5yJmu5zuuyricZx3lcxnU8vSqryGa2aVu2ddtO8vl8P9NnS7ui
41336b7dDWlCKaeCHp4LXOYqJ51xcPd2uietaNsDNl6TNbSpGtk0e5RGZTRH
K6nrsZ7quV7qtd7qM2IpI4yVTLKajcywma1sYw5qqrkWWupOa6PvMAlF2IYH
tKmlltnCcittZ7U11t5enuV5lcu8yffcRa9X+ipfsxcHcZzFeVzFMnbBFV/i
kpe+zOUu0rO+7vuxn/ulX/utPyFCIUoQRRwJJFGLOqSRQRZdwAMBiEEGclAB
CQxw4IIDGpKBDnwQgx4GOxzhW7zbN1RIhSpRVHEllFSqVVoNyiirrmf0fD3T
ZwmwhwOMY5zhHFdYYoMdvqDv+T71c7/x979KRzGs
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[25, 38] -> 
             RGBColor[
              0.928418480815333, 0.736683550460736, 0.30369625477339085`], 
             UndirectedEdge[11, 46] -> 
             RGBColor[
              0.29250836660694995`, 0.41710137768232214`, 0.9402502676768472],
              UndirectedEdge[22, 38] -> 
             RGBColor[
              0.8764723768488645, 0.7116918663062373, 0.6020827932904722], 
             UndirectedEdge[20, 34] -> 
             RGBColor[
              0.2019923105566983, 0.3296371038202449, 0.9348145353141348], 
             UndirectedEdge[37, 42] -> 
             RGBColor[
              0.20108210705992569`, 0.32868042223490196`, 0.9347627005715191],
              UndirectedEdge[39, 41] -> 
             RGBColor[
              0.1822363980275108, 0.30887238715486787`, 0.933689465321851], 
             UndirectedEdge[33, 43] -> 
             RGBColor[
              0.22237107596658973`, 0.35105647835439524`, 0.9359750758565464],
              UndirectedEdge[5, 11] -> 
             RGBColor[
              0.19994306409774693`, 0.3274832158621571, 0.934697833759886], 
             UndirectedEdge[27, 38] -> 
             RGBColor[
              0.8678963355894018, 0.7048535637963802, 0.6012648028192222], 
             UndirectedEdge[16, 25] -> 
             RGBColor[
              0.6359449416314518, 0.6885942657346755, 0.6656764311545273], 
             UndirectedEdge[26, 42] -> 
             RGBColor[
              0.21253098905688497`, 0.34071392311475085`, 0.9354146974641429],
              UndirectedEdge[8, 24] -> 
             RGBColor[
              0.22474090438337907`, 0.3535473182762408, 0.9361100340790356], 
             UndirectedEdge[18, 38] -> 
             RGBColor[
              0.7204244872726348, 0.5881598923795166, 0.5874385454539575], 
             UndirectedEdge[11, 24] -> 
             RGBColor[
              0.18790490679815192`, 0.3148303492770259, 0.9340122785105319], 
             UndirectedEdge[35, 49] -> 
             RGBColor[
              0.6817831823804502, 0.38831712236653665`, 0.5608198700027288], 
             UndirectedEdge[12, 21] -> 
             RGBColor[
              0.19630722004081225`, 0.32366171323249104`, 0.9344907778195929],
              UndirectedEdge[24, 28] -> 
             RGBColor[
              0.2121395193469085, 0.34030246362895233`, 0.9353924038432873], 
             UndirectedEdge[6, 19] -> 
             RGBColor[
              0.20282150983239816`, 0.330508644833276, 0.9348617569861956], 
             UndirectedEdge[20, 22] -> 
             RGBColor[
              0.5499527546309395, 0.6278179896650549, 0.9621240956094861], 
             UndirectedEdge[12, 14] -> 
             RGBColor[
              0.24161858869948338`, 0.37128683459945855`, 0.9370711932325413],
              UndirectedEdge[27, 35] -> 
             RGBColor[
              0.8400463296488186, 0.5137716564147881, 0.5754956579512942], 
             UndirectedEdge[10, 14] -> 
             RGBColor[
              0.26759162871248865`, 0.39858614643897766`, 0.9385503194376126],
              UndirectedEdge[1, 38] -> 
             RGBColor[
              0.5731801758391688, 0.46046013605245084`, 0.5773170233569029], 
             UndirectedEdge[17, 47] -> 
             RGBColor[
              0.2398401755658342, 0.369417609638088, 0.9369699152355064], 
             UndirectedEdge[16, 26] -> 
             RGBColor[
              0.2451714289006903, 0.37502109491400637`, 0.937273522226044], 
             UndirectedEdge[37, 41] -> 
             RGBColor[
              0.18052119331285646`, 0.3070695982495061, 0.9335917869507695], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.23871506039501558`, 0.3682350422571356, 0.9369058415909871], 
             UndirectedEdge[10, 12] -> 
             RGBColor[
              0.2059096761573388, 0.33375450344184254`, 0.9350376234898683], 
             UndirectedEdge[16, 40] -> 
             RGBColor[
              0.268221512444003, 0.39924819417773455`, 0.9385861903842929], 
             UndirectedEdge[4, 17] -> 
             RGBColor[
              0.6255501260516165, 0.6970169092349399, 0.9492504864397309], 
             UndirectedEdge[18, 33] -> 
             RGBColor[
              0.37859407497036524`, 0.4881934045995283, 0.9466079209279521], 
             UndirectedEdge[25, 49] -> 
             RGBColor[
              0.7650326572552, 0.7997917654456805, 0.6745289799081917], 
             UndirectedEdge[16, 39] -> 
             RGBColor[
              0.23543775161838537`, 0.3647903829395192, 0.9367192037045018], 
             UndirectedEdge[23, 35] -> 
             RGBColor[
              0.5422728183509562, 0.2661647583470159, 0.5513737668412837], 
             UndirectedEdge[46, 49] -> 
             RGBColor[
              0.4689962659349694, 0.5781194758117435, 0.9518021867701819], 
             UndirectedEdge[7, 11] -> 
             RGBColor[
              0.20211821753818177`, 0.3297694400407477, 0.9348217055304677], 
             UndirectedEdge[3, 22] -> 
             RGBColor[
              0.5951573092957712, 0.6751789475691949, 0.9647039897502256], 
             UndirectedEdge[18, 25] -> 
             RGBColor[
              0.7758239562068014, 0.8085526280770683, 0.6753785104914923], 
             UndirectedEdge[15, 28] -> 
             RGBColor[
              0.21962656391982321`, 0.3481718221811294, 0.9358187799556248], 
             UndirectedEdge[14, 45] -> 
             RGBColor[
              0.6464496961909962, 0.7130426747437464, 0.881310686758882], 
             UndirectedEdge[43, 48] -> 
             RGBColor[
              0.2171554823282761, 0.3455745587527913, 0.9356780555146238], 
             UndirectedEdge[7, 15] -> 
             RGBColor[
              0.20423860280438694`, 0.3319980993957201, 0.9349424583345491], 
             UndirectedEdge[38, 43] -> 
             RGBColor[
              0.5642014882688593, 0.4510229661343835, 0.5768057003825517], 
             UndirectedEdge[22, 27] -> 
             RGBColor[
              0.8713497005571, 0.9002546153394331, 0.9875913063738384], 
             UndirectedEdge[38, 45] -> 
             RGBColor[
              0.9313089315042627, 0.7531288433270417, 0.5188968870366671], 
             UndirectedEdge[4, 49] -> 
             RGBColor[
              0.751403910767931, 0.8048153425191696, 0.9579188676123889], 
             UndirectedEdge[38, 46] -> 
             RGBColor[
              0.6323820894951023, 0.5150112608267989, 0.5809694616353811], 
             UndirectedEdge[32, 43] -> 
             RGBColor[
              0.22527285704339534`, 0.3541064342496646, 0.93614032799607], 
             UndirectedEdge[30, 50] -> 
             RGBColor[
              0.2615601433811843, 0.3922466729375194, 0.9382068352707778], 
             UndirectedEdge[10, 42] -> 
             RGBColor[
              0.22733688499806864`, 0.3562758584969571, 0.936257871334633], 
             UndirectedEdge[26, 41] -> 
             RGBColor[
              0.19197007530981575`, 0.319103099129355, 0.9342437838433932], 
             UndirectedEdge[16, 38] -> 
             RGBColor[
              0.5805454726972852, 0.46820153003712384`, 0.5777364661169925], 
             UndirectedEdge[1, 11] -> 
             RGBColor[
              0.23330645295101632`, 0.362550252907974, 0.936597829398369], 
             UndirectedEdge[10, 18] -> 
             RGBColor[
              0.39985633941722365`, 0.5105413926386053, 0.9478187754334992], 
             UndirectedEdge[9, 13] -> 
             RGBColor[
              0.18455278049618473`, 0.3113070519965754, 0.9338213798766614], 
             UndirectedEdge[26, 40] -> 
             RGBColor[
              0.2253210078312894, 0.35415704378067747`, 0.936143070112208], 
             UndirectedEdge[13, 47] -> 
             RGBColor[
              0.1857133310922968, 0.3125268642562469, 0.9338874715162292], 
             UndirectedEdge[6, 17] -> 
             RGBColor[
              0.2413166588452144, 0.3709694871791634, 0.9370539987740059], 
             UndirectedEdge[5, 15] -> 
             RGBColor[
              0.20206344936395204`, 0.32971187521712947`, 0.9348185865639675],
              UndirectedEdge[16, 41] -> 
             RGBColor[
              0.23487057992252938`, 0.36419424952641205`, 0.9366869041154782],
              UndirectedEdge[24, 46] -> 
             RGBColor[
              0.28714170730024036`, 0.41146067848511747`, 0.939944644368591], 
             UndirectedEdge[3, 35] -> 
             RGBColor[
              0.5638539383874897, 0.28869598864454976`, 0.5526083413276814], 
             UndirectedEdge[26, 43] -> 
             RGBColor[
              0.22882744447226444`, 0.35784253101126595`, 0.9363427564916034],
              UndirectedEdge[9, 47] -> 
             RGBColor[
              0.18398000520728475`, 0.31070502885189066`, 0.9337887611713036],
              UndirectedEdge[2, 10] -> 
             RGBColor[
              0.207685117697551, 0.33562060507010094`, 0.935138732259053], 
             UndirectedEdge[27, 45] -> 
             RGBColor[
              0.9261862552124982, 0.9416915923602376, 0.9044054001200335], 
             UndirectedEdge[6, 44] -> 
             RGBColor[
              0.1895519775834999, 0.31656152510274604`, 0.9341060767551346], 
             UndirectedEdge[2, 21] -> 
             RGBColor[
              0.19808266158102447`, 0.3255278148607494, 0.9345918865887776], 
             UndirectedEdge[10, 21] -> 
             RGBColor[
              0.22228026005381749`, 0.35096102507201016`, 0.9359699040246642],
              UndirectedEdge[3, 23] -> 
             RGBColor[
              0.28880775673844583`, 0.4207337469915656, 0.9397641081689652], 
             UndirectedEdge[39, 43] -> 
             RGBColor[
              0.2190937671899595, 0.34761181903677885`, 0.9357884379700612], 
             UndirectedEdge[11, 49] -> 
             RGBColor[
              0.36975946543288096`, 0.48148914660365194`, 0.9458698209121228],
              UndirectedEdge[4, 30] -> 
             RGBColor[
              0.6105385902232648, 0.6812388332929982, 0.9483956016818833], 
             UndirectedEdge[4, 25] -> 
             RGBColor[
              0.9701892032622306, 0.9620998632317768, 0.6750261075151229], 
             UndirectedEdge[3, 44] -> 
             RGBColor[
              0.25069965478991096`, 0.38067971565043934`, 0.9375939081388809],
              UndirectedEdge[35, 38] -> 
             RGBColor[
              0.8451690059405832, 0.32520890738159214`, 0.189987144867928], 
             UndirectedEdge[14, 18] -> 
             RGBColor[
              0.43556525195936824`, 0.5480737237962212, 0.9498523451761722], 
             UndirectedEdge[13, 27] -> 
             RGBColor[
              0.524529882839417, 0.6032726001152537, 0.9603467030620877], 
             UndirectedEdge[5, 44] -> 
             RGBColor[
              0.19881249744773744`, 0.3262949186309314, 0.9346334496616915], 
             UndirectedEdge[37, 40] -> 
             RGBColor[
              0.21387212583433007`, 0.3421235429008286, 0.9354910732195842], 
             UndirectedEdge[21, 42] -> 
             RGBColor[
              0.21773442888154212`, 0.3461830682876055, 0.9357110256643577], 
             UndirectedEdge[4, 23] -> 
             RGBColor[
              0.6118935467384369, 0.6826629784996489, 0.9484727644509439], 
             UndirectedEdge[5, 19] -> 
             RGBColor[
              0.21208202969663575`, 0.3402420383614614, 0.9353891298927524], 
             UndirectedEdge[23, 29] -> 
             RGBColor[
              0.22693852900496714`, 0.35585716109097865`, 0.9362351855501407],
              UndirectedEdge[41, 43] -> 
             RGBColor[
              0.21852659549410353`, 0.3470156856236717, 0.9357561383810375], 
             UndirectedEdge[25, 28] -> 
             RGBColor[
              0.6127793704759371, 0.6642457816681855, 0.6643571861476121], 
             UndirectedEdge[9, 23] -> 
             RGBColor[
              0.22502304565654246`, 0.35384386664312545`, 0.9361261016071516],
              UndirectedEdge[16, 37] -> 
             RGBColor[
              0.233722546903731, 0.3629875940341575, 0.9366215253334202], 
             UndirectedEdge[42, 43] -> 
             RGBColor[
              0.23908750924117275`, 0.3686265096090675, 0.936927052001787], 
             UndirectedEdge[38, 49] -> 
             RGBColor[
              0.7096331883210334, 0.5793990297481288, 0.5865890148706568], 
             UndirectedEdge[30, 45] -> 
             RGBColor[
              0.6270577873994636, 0.6926605490858146, 0.8802063462409624], 
             UndirectedEdge[2, 14] -> 
             RGBColor[
              0.2433940302396956, 0.3731529362277169, 0.937172302001726], 
             UndirectedEdge[7, 8] -> 
             RGBColor[
              0.23895421512340895`, 0.36848640903996255`, 0.9369194610989714],
              UndirectedEdge[7, 49] -> 
             RGBColor[
              0.37860611686620127`, 0.49078753817016907`, 0.9463736246238025],
              UndirectedEdge[3, 47] -> 
             RGBColor[
              0.2477647162891881, 0.37759490920033084`, 0.9374267677331172], 
             UndirectedEdge[35, 50] -> 
             RGBColor[
              0.5379612815454002, 0.26163305979715423`, 0.5511282311985545], 
             UndirectedEdge[23, 49] -> 
             RGBColor[
              0.4067370007314063, 0.5203548807135525, 0.9479756368440126], 
             UndirectedEdge[5, 8] -> 
             RGBColor[
              0.23677906168297408`, 0.36620018486137196`, 0.9367955893283897],
              UndirectedEdge[15, 19] -> 
             RGBColor[
              0.20753091696995546`, 0.33545853032850725`, 0.9351299507557359],
              UndirectedEdge[5, 6] -> 
             RGBColor[
              0.19735404222639477`, 0.3247619897218983, 0.9345503927944272], 
             UndirectedEdge[40, 42] -> 
             RGBColor[
              0.23558107260019767`, 0.36494102237847903`, 0.9367273656223917],
              UndirectedEdge[17, 36] -> 
             RGBColor[
              0.3070849800420329, 0.43908984731102785`, 0.9408362535069459], 
             UndirectedEdge[33, 48] -> 
             RGBColor[
              0.18414259363831362`, 0.3108759196016039, 0.9337980203419227], 
             UndirectedEdge[19, 28] -> 
             RGBColor[
              0.22964514425250687`, 0.35870198532546127`, 0.9363893232844097],
              UndirectedEdge[27, 29] -> 
             RGBColor[
              0.5247120403028297, 0.6034640591587508, 0.9603570766601512], 
             UndirectedEdge[9, 31] -> 
             RGBColor[
              0.18183717565852314`, 0.3084527791329017, 0.9336667301985339], 
             UndirectedEdge[36, 47] -> 
             RGBColor[
              0.25238536027959546`, 0.38159707878450205`, 0.9377211910823109],
              UndirectedEdge[39, 48] -> 
             RGBColor[
              0.1808652848616834, 0.3074312602839875, 0.9336113824554374], 
             UndirectedEdge[42, 48] -> 
             RGBColor[
              0.20085902691289664`, 0.3284459508562762, 0.9347499964871633], 
             UndirectedEdge[1, 7] -> 
             RGBColor[
              0.24215310438433663`, 0.3718486444744911, 0.9371016331100486], 
             UndirectedEdge[29, 31] -> 
             RGBColor[
              0.18375265900694782`, 0.31046607358075484`, 0.9337758141415229],
              UndirectedEdge[4, 29] -> 
             RGBColor[
              0.5716054390414919, 0.6403176228965957, 0.9461784163185171], 
             UndirectedEdge[17, 27] -> 
             RGBColor[
              0.5786567273129544, 0.6601633454970949, 0.9634291467813649], 
             UndirectedEdge[25, 45] -> 
             RGBColor[
              0.9867084004384294, 0.9735215790245934, 0.606836852074202], 
             UndirectedEdge[6, 28] -> 
             RGBColor[
              0.21491715678226592`, 0.3432219366858982, 0.9355505861860844], 
             UndirectedEdge[30, 34] -> 
             RGBColor[
              0.22426078866982435`, 0.3530426862202004, 0.9360826921994162], 
             UndirectedEdge[16, 18] -> 
             RGBColor[
              0.42795094808875356`, 0.540070607653456, 0.9494187218350939], 
             UndirectedEdge[26, 37] -> 
             RGBColor[
              0.19082204229101737`, 0.3178964436371004, 0.9341784050613353], 
             UndirectedEdge[3, 13] -> 
             RGBColor[
              0.2483374915780881, 0.37819693234501556`, 0.9374593864384748], 
             UndirectedEdge[14, 20] -> 
             RGBColor[
              0.2616401543499747, 0.3923307695387065, 0.9382113917770847], 
             UndirectedEdge[41, 42] -> 
             RGBColor[
              0.20223014007872406`, 0.32988707772715653`, 0.934828079353577], 
             UndirectedEdge[4, 45] -> 
             RGBColor[
              0.9730796539511604, 0.9785451560980825, 0.8902267397783993], 
             UndirectedEdge[4, 36] -> 
             RGBColor[
              0.6380953107653778, 0.709196378381354, 0.9500017622865352], 
             UndirectedEdge[18, 21] -> 
             RGBColor[
              0.3902538833006971, 0.5004486024292537, 0.9472719297632238], 
             UndirectedEdge[33, 40] -> 
             RGBColor[
              0.21886463932561467`, 0.34737099112380676`, 0.935775389477151], 
             UndirectedEdge[33, 42] -> 
             RGBColor[
              0.20607462055121026`, 0.3339278704578801, 0.9350470168290859], 
             UndirectedEdge[37, 48] -> 
             RGBColor[
              0.17915008014702904`, 0.30562847137862575`, 0.9335137040843557],
              UndirectedEdge[5, 28] -> 
             RGBColor[
              0.22417767664650348`, 0.35295533021408354`, 0.9360779590926414],
              UndirectedEdge[3, 45] -> 
             RGBColor[
              0.6499938639511693, 0.7166159245899992, 0.8815180834964206], 
             UndirectedEdge[27, 49] -> 
             RGBColor[
              0.7045105120292688, 0.7679617787813247, 0.972097527954023], 
             UndirectedEdge[15, 24] -> 
             RGBColor[
              0.19002529206435706`, 0.3170590086319983, 0.9341330313146134], 
             UndirectedEdge[11, 25] -> 
             RGBColor[
              0.5885447579271805, 0.6387736673162592, 0.6629770608148569], 
             UndirectedEdge[17, 28] -> 
             RGBColor[
              0.26814029326532307`, 0.3991628276713486, 0.93858156507222], 
             UndirectedEdge[19, 25] -> 
             RGBColor[
              0.6006837235260694, 0.6515324898155634, 0.6636683569477233], 
             UndirectedEdge[2, 12] -> 
             RGBColor[
              0.18171207768454578`, 0.30832129323058177`, 0.9336596060539817],
              UndirectedEdge[8, 15] -> 
             RGBColor[
              0.23222794895629378`, 0.3614166768284178, 0.9365364101913732], 
             UndirectedEdge[41, 48] -> 
             RGBColor[
              0.18029811316582742`, 0.3068351268708803, 0.9335790828664137], 
             UndirectedEdge[32, 39] -> 
             RGBColor[
              0.18898265957680263`, 0.31596313578086077`, 0.9340736549368838],
              UndirectedEdge[9, 29] -> 
             RGBColor[
              0.1847349379595974, 0.3114985110400723, 0.9338317534747249], 
             UndirectedEdge[17, 22] -> 
             RGBColor[
              0.5872327685724172, 0.667001648006952, 0.9642471372526149], 
             UndirectedEdge[35, 45] -> 
             RGBColor[
              0.9034589255636796, 0.5620469359454495, 0.4931277421687392], 
             UndirectedEdge[8, 19] -> 
             RGBColor[
              0.2422465292889775, 0.3719468399727497, 0.9371069535201582], 
             UndirectedEdge[4, 27] -> 
             RGBColor[
              0.9096670580362994, 0.930269876567421, 0.9725946555609544], 
             UndirectedEdge[4, 38] -> 
             RGBColor[
              0.914789734328064, 0.7417071275342251, 0.5870861424775882], 
             UndirectedEdge[18, 46] -> 
             RGBColor[
              0.4797875648865708, 0.5868803384431313, 0.9526517173534825], 
             UndirectedEdge[1, 15] -> 
             RGBColor[
              0.2354268382172215, 0.36477891226294634`, 0.9367185822024504], 
             UndirectedEdge[29, 47] -> 
             RGBColor[
              0.18589548855570945`, 0.3127183232997438, 0.9338978451142927], 
             UndirectedEdge[16, 32] -> 
             RGBColor[
              0.24161684147182122`, 0.37128499815240495`, 0.9370710937305108],
              UndirectedEdge[45, 50] -> 
             RGBColor[
              0.6241012071090798, 0.6895529957426038, 0.8800379733672936], 
             UndirectedEdge[8, 46] -> 
             RGBColor[
              0.3293443641921771, 0.455818346681537, 0.9423480232453508], 
             UndirectedEdge[18, 37] -> 
             RGBColor[
              0.37360156147908063`, 0.48294595637655013`, 0.9463236046703852],
              UndirectedEdge[30, 35] -> 
             RGBColor[
              0.5409178618357842, 0.2647406131403652, 0.5512966040722233], 
             UndirectedEdge[19, 46] -> 
             RGBColor[
              0.3046473322058388, 0.4298602001816264, 0.9409415638097135], 
             UndirectedEdge[13, 17] -> 
             RGBColor[
              0.2404129508547342, 0.3700196327827727, 0.9370025339408643], 
             UndirectedEdge[1, 5] -> 
             RGBColor[
              0.23997795094390176`, 0.3695624202959005, 0.936977761339467], 
             UndirectedEdge[10, 40] -> 
             RGBColor[
              0.24012690377247303`, 0.3697189791628837, 0.9369862439826981], 
             UndirectedEdge[18, 45] -> 
             RGBColor[
              0.7787144068957312, 0.824997920943374, 0.8905791427547687], 
             UndirectedEdge[22, 50] -> 
             RGBColor[
              0.5692646524536816, 0.6481160187217994, 0.9632238796210987], 
             UndirectedEdge[1, 46] -> 
             RGBColor[
              0.33254325345310476`, 0.45918058211606555`, 0.942530195256428], 
             UndirectedEdge[22, 35] -> 
             RGBColor[
              0.8486223709082814, 0.5206099589246451, 0.5763136484225442], 
             UndirectedEdge[8, 49] -> 
             RGBColor[
              0.4065954630181081, 0.5202061156028668, 0.9479675764806266], 
             UndirectedEdge[17, 44] -> 
             RGBColor[
              0.24277511406655705`, 0.37250241608819645`, 0.9371370556412701],
              UndirectedEdge[1, 8] -> 
             RGBColor[
              0.27014245053624353`, 0.4012672219071889, 0.9386955849668728], 
             UndirectedEdge[1, 24] -> 
             RGBColor[
              0.22793979364430678`, 0.3569095537107694, 0.9362922060901129], 
             UndirectedEdge[25, 46] -> 
             RGBColor[
              0.687781558429269, 0.7354039965243506, 0.6689094266729159], 
             UndirectedEdge[20, 45] -> 
             RGBColor[
              0.6047893092863377, 0.6692549666858592, 0.8789381893556811], 
             UndirectedEdge[36, 45] -> 
             RGBColor[
              0.6546145079415766, 0.7206180941741704, 0.8818125068456143], 
             UndirectedEdge[26, 48] -> 
             RGBColor[
              0.19059896214398833`, 0.31766197225847465`, 0.9341657009769795],
              UndirectedEdge[19, 24] -> 
             RGBColor[
              0.20004387239704075`, 0.3275891717763302, 0.9347035746433983], 
             UndirectedEdge[18, 40] -> 
             RGBColor[
              0.4081005270193527, 0.5192065565201273, 0.9482882697212578], 
             UndirectedEdge[5, 25] -> 
             RGBColor[
              0.595216255920066, 0.6457858347041856, 0.6633569927559548], 
             UndirectedEdge[8, 25] -> 
             RGBColor[
              0.6253807555124078, 0.677490636315474, 0.6650748163833606], 
             UndirectedEdge[27, 36] -> 
             RGBColor[
              0.5912019120267157, 0.672342814643509, 0.9641804226281694], 
             UndirectedEdge[3, 6] -> 
             RGBColor[
              0.2492411995685683, 0.3791467867414062, 0.9375108512716166], 
             UndirectedEdge[17, 23] -> 
             RGBColor[
              0.2808832160150919, 0.4125564474293228, 0.9393072556713545], 
             UndirectedEdge[26, 39] -> 
             RGBColor[
              0.1925372470056717, 0.31969923254246213`, 0.9342760834324169], 
             UndirectedEdge[17, 35] -> 
             RGBColor[
              0.5559293976641357, 0.2805186890823069, 0.5521514888300707], 
             UndirectedEdge[19, 44] -> 
             RGBColor[
              0.20427996505374085`, 0.33204157374230914`, 0.9349448138534598],
              UndirectedEdge[12, 40] -> 
             RGBColor[
              0.21415386375946782`, 0.3424196673233646, 0.9355071177776269], 
             UndirectedEdge[16, 42] -> 
             RGBColor[
              0.2554314936695986, 0.3858050735118079, 0.9378578177362278], 
             UndirectedEdge[14, 21] -> 
             RGBColor[
              0.2579891725959621, 0.3884933562296261, 0.9380034737673373], 
             UndirectedEdge[5, 46] -> 
             RGBColor[
              0.29917986459983537`, 0.4241135450702487, 0.9406301996179451], 
             UndirectedEdge[22, 30] -> 
             RGBColor[
              0.5722212327440654, 0.6512235720650104, 0.9633922524947675], 
             UndirectedEdge[8, 38] -> 
             RGBColor[
              0.569981286578241, 0.4570979006179223, 0.5771348513458258], 
             UndirectedEdge[21, 40] -> 
             RGBColor[
              0.23052444765594654`, 0.35962618895353216`, 0.9364393983124228],
              UndirectedEdge[3, 4] -> 
             RGBColor[
              0.6334746667749704, 0.7051942087971828, 0.9497073389373415], 
             UndirectedEdge[1, 25] -> 
             RGBColor[
              0.6285796447733354, 0.6808528717500025, 0.6652569883944378], 
             UndirectedEdge[33, 37] -> 
             RGBColor[
              0.18436567378534266`, 0.31111039098022963`, 0.9338107244262784],
              UndirectedEdge[16, 48] -> 
             RGBColor[
              0.23349946675670197`, 0.3627531226555317, 0.9366088212490644], 
             UndirectedEdge[14, 22] -> 
             RGBColor[
              0.5916131415355981, 0.6716056977229419, 0.964496593012687], 
             UndirectedEdge[25, 40] -> 
             RGBColor[
              0.6160945205620509, 0.6677302146013466, 0.6645459790406913], 
             UndirectedEdge[11, 19] -> 
             RGBColor[
              0.20541053170375032`, 0.33322987097353485`, 0.9350091979516544],
              UndirectedEdge[25, 35] -> 
             RGBColor[
              0.9005684748747498, 0.5456016430791438, 0.2779271099054629], 
             UndirectedEdge[3, 27] -> 
             RGBColor[
              0.5865812680363083, 0.6683406450593378, 0.9638859992789757], 
             UndirectedEdge[28, 44] -> 
             RGBColor[
              0.2163756120036086, 0.3447548655949313, 0.9356336430533487], 
             UndirectedEdge[26, 33] -> 
             RGBColor[
              0.19581455578230195`, 0.3231438918600785, 0.9344627213189022], 
             UndirectedEdge[7, 46] -> 
             RGBColor[
              0.3013550180402702, 0.42639976924883927`, 0.9407540713885267], 
             UndirectedEdge[22, 45] -> 
             RGBColor[
              0.9347622964719611, 0.9485298948700946, 0.9052233905912834], 
             UndirectedEdge[5, 24] -> 
             RGBColor[
              0.19457640479103733`, 0.32184251666495245`, 0.9343922104516299],
              UndirectedEdge[13, 36] -> 
             RGBColor[
              0.25295813556849545`, 0.38219910192918677`, 0.9377538097876685],
              UndirectedEdge[4, 22] -> 
             RGBColor[
              0.9182430992957622, 0.9371081790772782, 0.9734126460322043], 
             UndirectedEdge[4, 13] -> 
             RGBColor[
              0.5714232815780792, 0.6401261638530988, 0.9461680427204535], 
             UndirectedEdge[18, 26] -> 
             RGBColor[
              0.38505044347603995`, 0.494979457256399, 0.946975601563009], 
             UndirectedEdge[13, 29] -> 
             RGBColor[
              0.18646826384460943`, 0.3133203464444285, 0.9339304638196504], 
             UndirectedEdge[7, 25] -> 
             RGBColor[
              0.5973914093605008, 0.6480720588827762, 0.6634808645265365], 
             UndirectedEdge[22, 36] -> 
             RGBColor[
              0.5997779532861784, 0.6791811171533662, 0.9649984130994194], 
             UndirectedEdge[20, 30] -> 
             RGBColor[
              0.24224824555844213`, 0.37194864388077487`, 0.9371070512591652],
              UndirectedEdge[4, 35] -> 
             RGBColor[
              0.8869397283874808, 0.5506252201526329, 0.5613169976096601], 
             UndirectedEdge[3, 28] -> 
             RGBColor[
              0.276064833988677, 0.4073401272335915, 0.9390384175698308], 
             UndirectedEdge[23, 47] -> 
             RGBColor[
              0.2261835962526545, 0.355063678902797, 0.9361921932467194], 
             UndirectedEdge[13, 23] -> 
             RGBColor[
              0.22675637154155448`, 0.3556657020474817, 0.9362248119520773], 
             UndirectedEdge[18, 43] -> 
             RGBColor[
              0.41160696366032773`, 0.5228920437507157, 0.9484879561006532], 
             UndirectedEdge[34, 50] -> 
             RGBColor[
              0.22130420837944048`, 0.3499351328769894, 0.9359143193257474], 
             UndirectedEdge[4, 9] -> 
             RGBColor[
              0.5696899556930671, 0.6383043284487425, 0.946069332375528], 
             UndirectedEdge[8, 11] -> 
             RGBColor[
              0.23010756369008867`, 0.3591880174734454, 0.9364156573872917], 
             UndirectedEdge[32, 34] -> 
             RGBColor[
              0.1895833015491595, 0.3165944485767085, 0.9341078606086393], 
             UndirectedEdge[14, 30] -> 
             RGBColor[
              0.2839086324631007, 0.415736351938662, 0.9394795486623662], 
             UndirectedEdge[15, 46] -> 
             RGBColor[
              0.29462875187315507`, 0.41933003703729455`, 0.9403710204809286],
              UndirectedEdge[11, 15] -> 
             RGBColor[
              0.19539195137106663`, 0.322699707829203, 0.9344386546228696], 
             UndirectedEdge[7, 38] -> 
             RGBColor[
              0.5419919404263343, 0.42767932318522456`, 0.5755408994890017], 
             UndirectedEdge[35, 36] -> 
             RGBColor[
              0.568474582377897, 0.292698158228721, 0.5529027646768752], 
             UndirectedEdge[23, 31] -> 
             RGBColor[
              0.2240407667038929, 0.35281142918380803`, 0.9360701622739498], 
             UndirectedEdge[3, 36] -> 
             RGBColor[
              0.3150095207653868, 0.44726714687327074`, 0.9412931060045565], 
             UndirectedEdge[33, 41] -> 
             RGBColor[
              0.18551370680414103`, 0.31231704647248426`, 0.9338761032083364],
              UndirectedEdge[14, 40] -> 
             RGBColor[
              0.2758358163146177, 0.40725131032049966`, 0.9390198137253712], 
             UndirectedEdge[15, 25] -> 
             RGBColor[
              0.5906651431933857, 0.6410023266712315, 0.6630978136189384], 
             UndirectedEdge[17, 45] -> 
             RGBColor[
              0.6420693232278154, 0.7084386250277563, 0.88106123099881], 
             UndirectedEdge[14, 50] -> 
             RGBColor[
              0.2809520521727168, 0.41262879859545104`, 0.9393111757886974], 
             UndirectedEdge[23, 27] -> 
             RGBColor[
              0.5650001479997748, 0.6458094147618039, 0.9626514247925779], 
             UndirectedEdge[9, 27] -> 
             RGBColor[
              0.522796556954405, 0.6014507647108975, 0.9602479927171621], 
             UndirectedEdge[20, 50] -> 
             RGBColor[
              0.23929166526805826`, 0.3688410905375639, 0.9369386783854964], 
             UndirectedEdge[30, 32] -> 
             RGBColor[
              0.22983923655090333`, 0.35890598863723844`, 0.9364003765536696],
              UndirectedEdge[3, 17] -> 
             RGBColor[
              0.3024643360516255, 0.43508767772685664`, 0.9405418301577522], 
             UndirectedEdge[18, 42] -> 
             RGBColor[
              0.3953105082449483, 0.5057634358542006, 0.9475598970731927], 
             UndirectedEdge[23, 36] -> 
             RGBColor[
              0.2934284007288532, 0.42473591657573684`, 0.9400585315181589], 
             UndirectedEdge[1, 19] -> 
             RGBColor[
              0.24544541854990515`, 0.37530907540727826`, 0.9372891255312354],
              UndirectedEdge[1, 49] -> 
             RGBColor[
              0.4097943522790358, 0.5235683510373954, 0.9481497484917039], 
             UndirectedEdge[16, 43] -> 
             RGBColor[
              0.2717279490849781, 0.40293368140832303`, 0.9387858767636883], 
             UndirectedEdge[25, 27] -> 
             RGBColor[
              0.9232958045235684, 0.9252462994939319, 0.689204767856757]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> Medium, 
           VertexSize -> {1.2}, VertexStyle -> {
             EdgeForm[None], 7 -> 
             RGBColor[
              0.21096486897150207`, 0.33906783160726484`, 0.9353255092421473],
              4 -> RGBColor[
              0.9565604567749616, 0.967123440305266, 0.9584159952193202], 44 -> 
             RGBColor[
              0.19101043280484256`, 0.31809445401177916`, 0.9341891336223989],
              1 -> RGBColor[
              0.2733413397971712, 0.4046294573417174, 0.93887775697795], 36 -> 
             RGBColor[
              0.31963016475579414`, 0.45126931645744195`, 0.9415875293537502],
              17 -> RGBColor[
              0.29453979532827157`, 0.4269103781646138, 0.9400849776601415], 
             33 -> RGBColor[
              0.18935818727662723`, 0.3163578392032078, 0.9340950406838453], 
             15 -> RGBColor[
              0.19751233663727177`, 0.32492836718417534`, 0.934559407426951], 
             20 -> RGBColor[
              0.2199797674453161, 0.34854306148081937`, 0.9358388943738838], 
             24 -> RGBColor[
              0.18253824749144235`, 0.3091896500798213, 0.9337066552022758], 
             31 -> RGBColor[
              0.18085489670587357`, 0.3074203416735843, 0.9336107908653319], 
             19 -> RGBColor[
              0.21754949730263914`, 0.3459886934728391, 0.9357004940845208], 
             18 -> RGBColor[
              0.5678299626641032, 0.6600289699958488, 0.9591208011720589], 5 -> 
             RGBColor[
              0.20661456209063234`, 0.3344953832500836, 0.935077765700984], 
             46 -> RGBColor[
              0.3917451671090384, 0.5137317068904137, 0.9461826335349062], 16 -> 
             RGBColor[
              0.28807193351340393`, 0.4201122453110634, 0.9397166424981289], 
             23 -> RGBColor[
              0.2672266367019122, 0.3982025166940318, 0.9385295336825675], 50 -> 
             RGBColor[
              0.2586035630908004, 0.38913911959430847`, 0.938038462397109], 
             29 -> RGBColor[
              0.1866504213080221, 0.31351180548792545`, 0.9339408374177139], 
             3 -> RGBColor[
              0.3103888767749794, 0.4432649772890995, 0.9409986826553628], 32 -> 
             RGBColor[
              0.19516174943023848`, 0.3224577509937465, 0.9344255449628927], 
             48 -> RGBColor[0.178927, 0.305394, 0.933501], 42 -> 
             RGBColor[
              0.22279105382579328`, 0.3514979017125524, 0.9359989929743265], 
             12 -> RGBColor[
              0.17993663614433356`, 0.30645519160232343`, 0.933558497284797], 
             39 -> RGBColor[
              0.18280356972336678`, 0.309468520567975, 0.9337217649108748], 
             25 -> 
             RGBColor[
              0.9838179497494997, 0.9570762861582877, 0.3916362198109257], 28 -> 
             RGBColor[
              0.24174079120237463`, 0.3714152771780834, 0.9370781524842986], 
             35 -> RGBColor[0.817319, 0.134127, 0.164218], 43 -> 
             RGBColor[
              0.2553839646565522, 0.38575511750558267`, 0.9378551110292476], 
             40 -> RGBColor[
              0.2483710913746021, 0.3783841430444057, 0.9374557382704568], 34 -> 
             RGBColor[
              0.18400485366808053`, 0.3107311461596704, 0.9337901762543859], 
             10 -> RGBColor[
              0.231882716170344, 0.3610538152813617, 0.9365167496949396], 38 -> 
             RGBColor[
              0.8730190118811663, 0.5162908147631843, 0.215756289735856], 26 -> 
             RGBColor[
              0.20227092428797666`, 0.3299299445169493, 0.9348304019539591], 
             6 -> RGBColor[
              0.1880935223621572, 0.315028596193713, 0.9340230198878703], 2 -> 
             RGBColor[
              0.18348751922475798`, 0.31018739485884017`, 0.9337607148231664],
              27 -> RGBColor[
              0.8627736592976373, 0.893416312829576, 0.9867733159025884], 21 -> 
             RGBColor[
              0.21267780393729097`, 0.3408682348626586, 0.9354230583543888], 
             30 -> RGBColor[
              0.26451672367156814`, 0.39535422628073036`, 0.9383752081444465],
              13 -> RGBColor[
              0.18628610638119678`, 0.3131288874009316, 0.933920090221587], 
             49 -> RGBColor[
              0.5462473647609004, 0.6425072447330733, 0.9574217400054577], 45 -> 
             RGBColor[
              0.9895988511273592, 0.989966871890899, 0.8220374843374784], 11 -> 
             RGBColor[
              0.1932715661048615, 0.3204710484742306, 0.934317901818788], 14 -> 
             RGBColor[
              0.30330054125463324`, 0.4361184775965936, 0.9405838891802857], 
             22 -> RGBColor[
              0.8799257418165628, 0.9070929178492902, 0.9884092968450884], 47 -> 
             RGBColor[
              0.1851405558033968, 0.31192484111156216`, 0.9338548528108714], 
             8 -> RGBColor[
              0.2669435612753158, 0.3979049864726603, 0.9385134129557955], 9 -> 
             RGBColor[
              0.1828194546111727, 0.3094852165922191, 0.9337226695317358], 37 -> 
             RGBColor[
              0.1793731602940581, 0.3058629427572515, 0.9335264081687116], 41 -> 
             RGBColor[
              0.18166922633165483`, 0.3082762537417607, 
               0.9336571657328274]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAAHst7OsJVA0AQXir5GWYLQCSvE9DH
/xVAeJaHjvKqwz+kisZXHs32P8BnaY31L/w/fbGOXmPB/j+4jUsNmyf0P9X1
yHFkefk/33zN18rqC0BMBscb9VDoP8frPNbUIgdA4PqW5GiuBkBg9Xsc24wL
QEIWcwmT3AFABBqxnYjNCUCEx6nUGzzjP44QbJ8OMeQ/EN412CC4FUCYhQ3r
o13yP5sOSgOAKwFAyII5nGvBDEASTP/cQtsVQFTEXjpjFOM/6FWJMUhk6z/J
1aDLvSDwP6pRFmYz1RBADp4LnwPs6j8yiFAqKlkBQCwkMZACxg5Ah4EBQDAg
E0CiNrI6LcMDQPijeC4HnfQ/aElUaEd7+j+udbKGf0cRQLeOVb7T5ABAahxl
6vkl+z+ZxHUBO18KQPSecLWmMQtAcEB/3zMjxj9CN5r+qsAUQDUMLQ6JyfA/
ruT9BsRaBEAvXTaTvLnvP+AfDyZ11vE/pnGVJ4ac8T80Le+jqvr7P+jzRLm3
9w9ApN64cGpHBkAsPRLQsHQEQO5AxgMXVhZA4HwbyiaXA0BMldoz5P77P6s3
gn7D2vY/0U6XpWVd9j826qlmp4UHQIj8m6400Oo/cFZcujGE2z/fbGXC/6EK
QLAXiYlN3Og/AAAAAAAAAACQkCUQJZm2P5VCoiE0/BJAbhBCsn4i9D92khKK
8zsVQNIQoe1gGgZAFK8J7D9AEEAAAAAAAAAAACUcXeNCPgJAAq/vySaZ9j/0
+MUkEsP4P7d5nbtL8u0/BMnF4sQbFkDyG44GGKwGQC9Q2VPGrghAR5ZxQubd
AUCOGj5SmNkXQKDPt1+HqgBAZ8iYoX1OE0AS0rmdiKv9P1eWg/VAXRhA+oRl
9RztBEDsgoi+ICEWQBDVr2WzlgBAr9L8uc88FECBUBDyJZYCQGg8zDEUreo/
Bm0CXpoyBUDSRrKvaiIGQILtHuuTLvU/A4Us28d3BUDorMx+LTQJQOiVV0I9
xNw/gPiRMrGw8T+UmyQBRtgXQDYTZ1csJwdAVpQDDC0aAUDacPBDxzoDQIRL
tZQsCwlAXPbohD/q2T9G5WNK
         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 5}], {
             RGBColor[
             0.23997795094390176`, 0.3695624202959005, 0.936977761339467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 7}], {
             RGBColor[
             0.24215310438433663`, 0.3718486444744911, 0.9371016331100486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 8}], {
             RGBColor[
             0.27014245053624353`, 0.4012672219071889, 0.9386955849668728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 11}], {
             RGBColor[
             0.23330645295101632`, 0.362550252907974, 0.936597829398369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 15}], {
             RGBColor[
             0.2354268382172215, 0.36477891226294634`, 0.9367185822024504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 19}], {
             RGBColor[
             0.24544541854990515`, 0.37530907540727826`, 0.9372891255312354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 24}], {
             RGBColor[
             0.22793979364430678`, 0.3569095537107694, 0.9362922060901129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 25}], {
             RGBColor[
             0.6285796447733354, 0.6808528717500025, 0.6652569883944378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 38}], {
             RGBColor[
             0.5731801758391688, 0.46046013605245084`, 0.5773170233569029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 46}], {
             RGBColor[
             0.33254325345310476`, 0.45918058211606555`, 0.942530195256428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 49}], {
             RGBColor[
             0.4097943522790358, 0.5235683510373954, 0.9481497484917039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 10}], {
             RGBColor[
             0.207685117697551, 0.33562060507010094`, 0.935138732259053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 12}], {
             RGBColor[
             0.18171207768454578`, 0.30832129323058177`, 0.9336596060539817]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 14}], {
             RGBColor[
             0.2433940302396956, 0.3731529362277169, 0.937172302001726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 21}], {
             RGBColor[
             0.19808266158102447`, 0.3255278148607494, 0.9345918865887776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 4}], {
             RGBColor[
             0.6334746667749704, 0.7051942087971828, 0.9497073389373415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 6}], {
             RGBColor[
             0.2492411995685683, 0.3791467867414062, 0.9375108512716166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 13}], {
             RGBColor[
             0.2483374915780881, 0.37819693234501556`, 0.9374593864384748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 17}], {
             RGBColor[
             0.3024643360516255, 0.43508767772685664`, 0.9405418301577522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 22}], {
             RGBColor[
             0.5951573092957712, 0.6751789475691949, 0.9647039897502256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 23}], {
             RGBColor[
             0.28880775673844583`, 0.4207337469915656, 0.9397641081689652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 27}], {
             RGBColor[
             0.5865812680363083, 0.6683406450593378, 0.9638859992789757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 28}], {
             RGBColor[
             0.276064833988677, 0.4073401272335915, 0.9390384175698308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 35}], {
             RGBColor[
             0.5638539383874897, 0.28869598864454976`, 0.5526083413276814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 36}], {
             RGBColor[
             0.3150095207653868, 0.44726714687327074`, 0.9412931060045565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 44}], {
             RGBColor[
             0.25069965478991096`, 0.38067971565043934`, 0.9375939081388809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 45}], {
             RGBColor[
             0.6499938639511693, 0.7166159245899992, 0.8815180834964206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 47}], {
             RGBColor[
             0.2477647162891881, 0.37759490920033084`, 0.9374267677331172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 9}], {
             RGBColor[
             0.5696899556930671, 0.6383043284487425, 0.946069332375528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 13}], {
             RGBColor[
             0.5714232815780792, 0.6401261638530988, 0.9461680427204535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 17}], {
             RGBColor[
             0.6255501260516165, 0.6970169092349399, 0.9492504864397309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 22}], {
             RGBColor[
             0.9182430992957622, 0.9371081790772782, 0.9734126460322043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 23}], {
             RGBColor[
             0.6118935467384369, 0.6826629784996489, 0.9484727644509439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 25}], {
             RGBColor[
             0.9701892032622306, 0.9620998632317768, 0.6750261075151229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 27}], {
             RGBColor[
             0.9096670580362994, 0.930269876567421, 0.9725946555609544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 29}], {
             RGBColor[
             0.5716054390414919, 0.6403176228965957, 0.9461784163185171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 30}], {
             RGBColor[
             0.6105385902232648, 0.6812388332929982, 0.9483956016818833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 35}], {
             RGBColor[
             0.8869397283874808, 0.5506252201526329, 0.5613169976096601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 36}], {
             RGBColor[
             0.6380953107653778, 0.709196378381354, 0.9500017622865352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 38}], {
             RGBColor[
             0.914789734328064, 0.7417071275342251, 0.5870861424775882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 45}], {
             RGBColor[
             0.9730796539511604, 0.9785451560980825, 0.8902267397783993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 49}], {
             RGBColor[
             0.751403910767931, 0.8048153425191696, 0.9579188676123889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 6}], {
             RGBColor[
             0.19735404222639477`, 0.3247619897218983, 0.9345503927944272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 8}], {
             RGBColor[
             0.23677906168297408`, 0.36620018486137196`, 0.9367955893283897]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.19994306409774693`, 0.3274832158621571, 0.934697833759886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 15}], {
             RGBColor[
             0.20206344936395204`, 0.32971187521712947`, 0.9348185865639675]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 19}], {
             RGBColor[
             0.21208202969663575`, 0.3402420383614614, 0.9353891298927524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 24}], {
             RGBColor[
             0.19457640479103733`, 0.32184251666495245`, 0.9343922104516299]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 25}], {
             RGBColor[
             0.595216255920066, 0.6457858347041856, 0.6633569927559548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 28}], {
             RGBColor[
             0.22417767664650348`, 0.35295533021408354`, 0.9360779590926414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 44}], {
             RGBColor[
             0.19881249744773744`, 0.3262949186309314, 0.9346334496616915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 46}], {
             RGBColor[
             0.29917986459983537`, 0.4241135450702487, 0.9406301996179451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 17}], {
             RGBColor[
             0.2413166588452144, 0.3709694871791634, 0.9370539987740059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 19}], {
             RGBColor[
             0.20282150983239816`, 0.330508644833276, 0.9348617569861956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 28}], {
             RGBColor[
             0.21491715678226592`, 0.3432219366858982, 0.9355505861860844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 44}], {
             RGBColor[
             0.1895519775834999, 0.31656152510274604`, 0.9341060767551346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 8}], {
             RGBColor[
             0.23895421512340895`, 0.36848640903996255`, 0.9369194610989714]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 11}], {
             RGBColor[
             0.20211821753818177`, 0.3297694400407477, 0.9348217055304677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 15}], {
             RGBColor[
             0.20423860280438694`, 0.3319980993957201, 0.9349424583345491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 25}], {
             RGBColor[
             0.5973914093605008, 0.6480720588827762, 0.6634808645265365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 38}], {
             RGBColor[
             0.5419919404263343, 0.42767932318522456`, 0.5755408994890017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 46}], {
             RGBColor[
             0.3013550180402702, 0.42639976924883927`, 0.9407540713885267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 49}], {
             RGBColor[
             0.37860611686620127`, 0.49078753817016907`, 0.9463736246238025]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 11}], {
             RGBColor[
             0.23010756369008867`, 0.3591880174734454, 0.9364156573872917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 15}], {
             RGBColor[
             0.23222794895629378`, 0.3614166768284178, 0.9365364101913732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 19}], {
             RGBColor[
             0.2422465292889775, 0.3719468399727497, 0.9371069535201582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 24}], {
             RGBColor[
             0.22474090438337907`, 0.3535473182762408, 0.9361100340790356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 25}], {
             RGBColor[
             0.6253807555124078, 0.677490636315474, 0.6650748163833606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 38}], {
             RGBColor[
             0.569981286578241, 0.4570979006179223, 0.5771348513458258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 46}], {
             RGBColor[
             0.3293443641921771, 0.455818346681537, 0.9423480232453508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 49}], {
             RGBColor[
             0.4065954630181081, 0.5202061156028668, 0.9479675764806266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 13}], {
             RGBColor[
             0.18455278049618473`, 0.3113070519965754, 0.9338213798766614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 23}], {
             RGBColor[
             0.22502304565654246`, 0.35384386664312545`, 0.9361261016071516]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 27}], {
             RGBColor[
             0.522796556954405, 0.6014507647108975, 0.9602479927171621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 29}], {
             RGBColor[
             0.1847349379595974, 0.3114985110400723, 0.9338317534747249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 31}], {
             RGBColor[
             0.18183717565852314`, 0.3084527791329017, 0.9336667301985339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 47}], {
             RGBColor[
             0.18398000520728475`, 0.31070502885189066`, 0.9337887611713036]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 12}], {
             RGBColor[
             0.2059096761573388, 0.33375450344184254`, 0.9350376234898683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 14}], {
             RGBColor[
             0.26759162871248865`, 0.39858614643897766`, 0.9385503194376126]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 18}], {
             RGBColor[
             0.39985633941722365`, 0.5105413926386053, 0.9478187754334992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 21}], {
             RGBColor[
             0.22228026005381749`, 0.35096102507201016`, 0.9359699040246642]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 40}], {
             RGBColor[
             0.24012690377247303`, 0.3697189791628837, 0.9369862439826981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 42}], {
             RGBColor[
             0.22733688499806864`, 0.3562758584969571, 0.936257871334633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 15}], {
             RGBColor[
             0.19539195137106663`, 0.322699707829203, 0.9344386546228696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 19}], {
             RGBColor[
             0.20541053170375032`, 0.33322987097353485`, 0.9350091979516544]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 24}], {
             RGBColor[
             0.18790490679815192`, 0.3148303492770259, 0.9340122785105319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 25}], {
             RGBColor[
             0.5885447579271805, 0.6387736673162592, 0.6629770608148569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 46}], {
             RGBColor[
             0.29250836660694995`, 0.41710137768232214`, 0.9402502676768472]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 49}], {
             RGBColor[
             0.36975946543288096`, 0.48148914660365194`, 0.9458698209121228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 14}], {
             RGBColor[
             0.24161858869948338`, 0.37128683459945855`, 0.9370711932325413]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 21}], {
             RGBColor[
             0.19630722004081225`, 0.32366171323249104`, 0.9344907778195929]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 40}], {
             RGBColor[
             0.21415386375946782`, 0.3424196673233646, 0.9355071177776269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 17}], {
             RGBColor[
             0.2404129508547342, 0.3700196327827727, 0.9370025339408643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 23}], {
             RGBColor[
             0.22675637154155448`, 0.3556657020474817, 0.9362248119520773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 27}], {
             RGBColor[
             0.524529882839417, 0.6032726001152537, 0.9603467030620877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 29}], {
             RGBColor[
             0.18646826384460943`, 0.3133203464444285, 0.9339304638196504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 36}], {
             RGBColor[
             0.25295813556849545`, 0.38219910192918677`, 0.9377538097876685]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 47}], {
             RGBColor[
             0.1857133310922968, 0.3125268642562469, 0.9338874715162292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 18}], {
             RGBColor[
             0.43556525195936824`, 0.5480737237962212, 0.9498523451761722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 20}], {
             RGBColor[
             0.2616401543499747, 0.3923307695387065, 0.9382113917770847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 21}], {
             RGBColor[
             0.2579891725959621, 0.3884933562296261, 0.9380034737673373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 22}], {
             RGBColor[
             0.5916131415355981, 0.6716056977229419, 0.964496593012687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 30}], {
             RGBColor[
             0.2839086324631007, 0.415736351938662, 0.9394795486623662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 40}], {
             RGBColor[
             0.2758358163146177, 0.40725131032049966`, 0.9390198137253712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 45}], {
             RGBColor[
             0.6464496961909962, 0.7130426747437464, 0.881310686758882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 50}], {
             RGBColor[
             0.2809520521727168, 0.41262879859545104`, 0.9393111757886974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 19}], {
             RGBColor[
             0.20753091696995546`, 0.33545853032850725`, 0.9351299507557359]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 24}], {
             RGBColor[
             0.19002529206435706`, 0.3170590086319983, 0.9341330313146134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 25}], {
             RGBColor[
             0.5906651431933857, 0.6410023266712315, 0.6630978136189384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 28}], {
             RGBColor[
             0.21962656391982321`, 0.3481718221811294, 0.9358187799556248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 46}], {
             RGBColor[
             0.29462875187315507`, 0.41933003703729455`, 0.9403710204809286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 18}], {
             RGBColor[
             0.42795094808875356`, 0.540070607653456, 0.9494187218350939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 25}], {
             RGBColor[
             0.6359449416314518, 0.6885942657346755, 0.6656764311545273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 26}], {
             RGBColor[
             0.2451714289006903, 0.37502109491400637`, 0.937273522226044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 32}], {
             RGBColor[
             0.24161684147182122`, 0.37128499815240495`, 0.9370710937305108]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.23871506039501558`, 0.3682350422571356, 0.9369058415909871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 37}], {
             RGBColor[
             0.233722546903731, 0.3629875940341575, 0.9366215253334202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 38}], {
             RGBColor[
             0.5805454726972852, 0.46820153003712384`, 0.5777364661169925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 39}], {
             RGBColor[
             0.23543775161838537`, 0.3647903829395192, 0.9367192037045018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 40}], {
             RGBColor[
             0.268221512444003, 0.39924819417773455`, 0.9385861903842929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 41}], {
             RGBColor[
             0.23487057992252938`, 0.36419424952641205`, 0.9366869041154782]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 42}], {
             RGBColor[
             0.2554314936695986, 0.3858050735118079, 0.9378578177362278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 43}], {
             RGBColor[
             0.2717279490849781, 0.40293368140832303`, 0.9387858767636883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 48}], {
             RGBColor[
             0.23349946675670197`, 0.3627531226555317, 0.9366088212490644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 22}], {
             RGBColor[
             0.5872327685724172, 0.667001648006952, 0.9642471372526149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 23}], {
             RGBColor[
             0.2808832160150919, 0.4125564474293228, 0.9393072556713545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 27}], {
             RGBColor[
             0.5786567273129544, 0.6601633454970949, 0.9634291467813649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 28}], {
             RGBColor[
             0.26814029326532307`, 0.3991628276713486, 0.93858156507222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 35}], {
             RGBColor[
             0.5559293976641357, 0.2805186890823069, 0.5521514888300707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 36}], {
             RGBColor[
             0.3070849800420329, 0.43908984731102785`, 0.9408362535069459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 44}], {
             RGBColor[
             0.24277511406655705`, 0.37250241608819645`, 0.9371370556412701]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 45}], {
             RGBColor[
             0.6420693232278154, 0.7084386250277563, 0.88106123099881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 47}], {
             RGBColor[
             0.2398401755658342, 0.369417609638088, 0.9369699152355064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 21}], {
             RGBColor[
             0.3902538833006971, 0.5004486024292537, 0.9472719297632238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 25}], {
             RGBColor[
             0.7758239562068014, 0.8085526280770683, 0.6753785104914923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 26}], {
             RGBColor[
             0.38505044347603995`, 0.494979457256399, 0.946975601563009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 33}], {
             RGBColor[
             0.37859407497036524`, 0.4881934045995283, 0.9466079209279521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 37}], {
             RGBColor[
             0.37360156147908063`, 0.48294595637655013`, 0.9463236046703852]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 38}], {
             RGBColor[
             0.7204244872726348, 0.5881598923795166, 0.5874385454539575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 40}], {
             RGBColor[
             0.4081005270193527, 0.5192065565201273, 0.9482882697212578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 42}], {
             RGBColor[
             0.3953105082449483, 0.5057634358542006, 0.9475598970731927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 43}], {
             RGBColor[
             0.41160696366032773`, 0.5228920437507157, 0.9484879561006532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 45}], {
             RGBColor[
             0.7787144068957312, 0.824997920943374, 0.8905791427547687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 46}], {
             RGBColor[
             0.4797875648865708, 0.5868803384431313, 0.9526517173534825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 24}], {
             RGBColor[
             0.20004387239704075`, 0.3275891717763302, 0.9347035746433983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 25}], {
             RGBColor[
             0.6006837235260694, 0.6515324898155634, 0.6636683569477233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 28}], {
             RGBColor[
             0.22964514425250687`, 0.35870198532546127`, 0.9363893232844097]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 44}], {
             RGBColor[
             0.20427996505374085`, 0.33204157374230914`, 0.9349448138534598]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 46}], {
             RGBColor[
             0.3046473322058388, 0.4298602001816264, 0.9409415638097135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 22}], {
             RGBColor[
             0.5499527546309395, 0.6278179896650549, 0.9621240956094861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 30}], {
             RGBColor[
             0.24224824555844213`, 0.37194864388077487`, 0.9371070512591652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 34}], {
             RGBColor[
             0.2019923105566983, 0.3296371038202449, 0.9348145353141348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 45}], {
             RGBColor[
             0.6047893092863377, 0.6692549666858592, 0.8789381893556811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 50}], {
             RGBColor[
             0.23929166526805826`, 0.3688410905375639, 0.9369386783854964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 40}], {
             RGBColor[
             0.23052444765594654`, 0.35962618895353216`, 0.9364393983124228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 42}], {
             RGBColor[
             0.21773442888154212`, 0.3461830682876055, 0.9357110256643577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 27}], {
             RGBColor[
             0.8713497005571, 0.9002546153394331, 0.9875913063738384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 30}], {
             RGBColor[
             0.5722212327440654, 0.6512235720650104, 0.9633922524947675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 35}], {
             RGBColor[
             0.8486223709082814, 0.5206099589246451, 0.5763136484225442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 36}], {
             RGBColor[
             0.5997779532861784, 0.6791811171533662, 0.9649984130994194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 38}], {
             RGBColor[
             0.8764723768488645, 0.7116918663062373, 0.6020827932904722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 45}], {
             RGBColor[
             0.9347622964719611, 0.9485298948700946, 0.9052233905912834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 50}], {
             RGBColor[
             0.5692646524536816, 0.6481160187217994, 0.9632238796210987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 27}], {
             RGBColor[
             0.5650001479997748, 0.6458094147618039, 0.9626514247925779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 29}], {
             RGBColor[
             0.22693852900496714`, 0.35585716109097865`, 0.9362351855501407]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 31}], {
             RGBColor[
             0.2240407667038929, 0.35281142918380803`, 0.9360701622739498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 35}], {
             RGBColor[
             0.5422728183509562, 0.2661647583470159, 0.5513737668412837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 36}], {
             RGBColor[
             0.2934284007288532, 0.42473591657573684`, 0.9400585315181589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 47}], {
             RGBColor[
             0.2261835962526545, 0.355063678902797, 0.9361921932467194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 49}], {
             RGBColor[
             0.4067370007314063, 0.5203548807135525, 0.9479756368440126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 28}], {
             RGBColor[
             0.2121395193469085, 0.34030246362895233`, 0.9353924038432873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 46}], {
             RGBColor[
             0.28714170730024036`, 0.41146067848511747`, 0.939944644368591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 27}], {
             RGBColor[
             0.9232958045235684, 0.9252462994939319, 0.689204767856757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 28}], {
             RGBColor[
             0.6127793704759371, 0.6642457816681855, 0.6643571861476121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 35}], {
             RGBColor[
             0.9005684748747498, 0.5456016430791438, 0.2779271099054629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 38}], {
             RGBColor[
             0.928418480815333, 0.736683550460736, 0.30369625477339085`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 40}], {
             RGBColor[
             0.6160945205620509, 0.6677302146013466, 0.6645459790406913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 45}], {
             RGBColor[
             0.9867084004384294, 0.9735215790245934, 0.606836852074202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 46}], {
             RGBColor[
             0.687781558429269, 0.7354039965243506, 0.6689094266729159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 49}], {
             RGBColor[
             0.7650326572552, 0.7997917654456805, 0.6745289799081917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 33}], {
             RGBColor[
             0.19581455578230195`, 0.3231438918600785, 0.9344627213189022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 37}], {
             RGBColor[
             0.19082204229101737`, 0.3178964436371004, 0.9341784050613353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 39}], {
             RGBColor[
             0.1925372470056717, 0.31969923254246213`, 0.9342760834324169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 40}], {
             RGBColor[
             0.2253210078312894, 0.35415704378067747`, 0.936143070112208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 41}], {
             RGBColor[
             0.19197007530981575`, 0.319103099129355, 0.9342437838433932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 42}], {
             RGBColor[
             0.21253098905688497`, 0.34071392311475085`, 0.9354146974641429]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 43}], {
             RGBColor[
             0.22882744447226444`, 0.35784253101126595`, 0.9363427564916034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 48}], {
             RGBColor[
             0.19059896214398833`, 0.31766197225847465`, 0.9341657009769795]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 29}], {
             RGBColor[
             0.5247120403028297, 0.6034640591587508, 0.9603570766601512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 35}], {
             RGBColor[
             0.8400463296488186, 0.5137716564147881, 0.5754956579512942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 36}], {
             RGBColor[
             0.5912019120267157, 0.672342814643509, 0.9641804226281694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 38}], {
             RGBColor[
             0.8678963355894018, 0.7048535637963802, 0.6012648028192222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 45}], {
             RGBColor[
             0.9261862552124982, 0.9416915923602376, 0.9044054001200335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 49}], {
             RGBColor[
             0.7045105120292688, 0.7679617787813247, 0.972097527954023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 44}], {
             RGBColor[
             0.2163756120036086, 0.3447548655949313, 0.9356336430533487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 31}], {
             RGBColor[
             0.18375265900694782`, 0.31046607358075484`, 0.9337758141415229]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 47}], {
             RGBColor[
             0.18589548855570945`, 0.3127183232997438, 0.9338978451142927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 32}], {
             RGBColor[
             0.22983923655090333`, 0.35890598863723844`, 0.9364003765536696]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 34}], {
             RGBColor[
             0.22426078866982435`, 0.3530426862202004, 0.9360826921994162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 35}], {
             RGBColor[
             0.5409178618357842, 0.2647406131403652, 0.5512966040722233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 45}], {
             RGBColor[
             0.6270577873994636, 0.6926605490858146, 0.8802063462409624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 50}], {
             RGBColor[
             0.2615601433811843, 0.3922466729375194, 0.9382068352707778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 34}], {
             RGBColor[
             0.1895833015491595, 0.3165944485767085, 0.9341078606086393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 39}], {
             RGBColor[
             0.18898265957680263`, 0.31596313578086077`, 0.9340736549368838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 43}], {
             RGBColor[
             0.22527285704339534`, 0.3541064342496646, 0.93614032799607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 37}], {
             RGBColor[
             0.18436567378534266`, 0.31111039098022963`, 0.9338107244262784]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 40}], {
             RGBColor[
             0.21886463932561467`, 0.34737099112380676`, 0.935775389477151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 41}], {
             RGBColor[
             0.18551370680414103`, 0.31231704647248426`, 0.9338761032083364]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 42}], {
             RGBColor[
             0.20607462055121026`, 0.3339278704578801, 0.9350470168290859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 43}], {
             RGBColor[
             0.22237107596658973`, 0.35105647835439524`, 0.9359750758565464]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 48}], {
             RGBColor[
             0.18414259363831362`, 0.3108759196016039, 0.9337980203419227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 50}], {
             RGBColor[
             0.22130420837944048`, 0.3499351328769894, 0.9359143193257474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 36}], {
             RGBColor[
             0.568474582377897, 0.292698158228721, 0.5529027646768752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 38}], {
             RGBColor[
             0.8451690059405832, 0.32520890738159214`, 0.189987144867928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 45}], {
             RGBColor[
             0.9034589255636796, 0.5620469359454495, 0.4931277421687392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 49}], {
             RGBColor[
             0.6817831823804502, 0.38831712236653665`, 0.5608198700027288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 50}], {
             RGBColor[
             0.5379612815454002, 0.26163305979715423`, 0.5511282311985545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 45}], {
             RGBColor[
             0.6546145079415766, 0.7206180941741704, 0.8818125068456143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 47}], {
             RGBColor[
             0.25238536027959546`, 0.38159707878450205`, 0.9377211910823109]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 40}], {
             RGBColor[
             0.21387212583433007`, 0.3421235429008286, 0.9354910732195842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 41}], {
             RGBColor[
             0.18052119331285646`, 0.3070695982495061, 0.9335917869507695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 42}], {
             RGBColor[
             0.20108210705992569`, 0.32868042223490196`, 0.9347627005715191]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 48}], {
             RGBColor[
             0.17915008014702904`, 0.30562847137862575`, 0.9335137040843557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 43}], {
             RGBColor[
             0.5642014882688593, 0.4510229661343835, 0.5768057003825517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 45}], {
             RGBColor[
             0.9313089315042627, 0.7531288433270417, 0.5188968870366671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 46}], {
             RGBColor[
             0.6323820894951023, 0.5150112608267989, 0.5809694616353811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 49}], {
             RGBColor[
             0.7096331883210334, 0.5793990297481288, 0.5865890148706568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 41}], {
             RGBColor[
             0.1822363980275108, 0.30887238715486787`, 0.933689465321851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 43}], {
             RGBColor[
             0.2190937671899595, 0.34761181903677885`, 0.9357884379700612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 48}], {
             RGBColor[
             0.1808652848616834, 0.3074312602839875, 0.9336113824554374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 42}], {
             RGBColor[
             0.23558107260019767`, 0.36494102237847903`, 0.9367273656223917]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 42}], {
             RGBColor[
             0.20223014007872406`, 0.32988707772715653`, 0.934828079353577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 43}], {
             RGBColor[
             0.21852659549410353`, 0.3470156856236717, 0.9357561383810375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 48}], {
             RGBColor[
             0.18029811316582742`, 0.3068351268708803, 0.9335790828664137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 43}], {
             RGBColor[
             0.23908750924117275`, 0.3686265096090675, 0.936927052001787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 48}], {
             RGBColor[
             0.20085902691289664`, 0.3284459508562762, 0.9347499964871633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 48}], {
             RGBColor[
             0.2171554823282761, 0.3455745587527913, 0.9356780555146238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 50}], {
             RGBColor[
             0.6241012071090798, 0.6895529957426038, 0.8800379733672936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 49}], {
             RGBColor[
             0.4689962659349694, 0.5781194758117435, 0.9518021867701819]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.10403391911817532`], {
             RGBColor[
             0.2733413397971712, 0.4046294573417174, 0.93887775697795]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.10403391911817532`], {
             RGBColor[
             0.18348751922475798`, 0.31018739485884017`, 0.9337607148231664]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.10403391911817532`], {
             RGBColor[
             0.3103888767749794, 0.4432649772890995, 0.9409986826553628]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.10403391911817532`], {
             RGBColor[
             0.9565604567749616, 0.967123440305266, 0.9584159952193202]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.10403391911817532`], {
             RGBColor[
             0.20661456209063234`, 0.3344953832500836, 0.935077765700984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.10403391911817532`], {
             RGBColor[
             0.1880935223621572, 0.315028596193713, 0.9340230198878703]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.10403391911817532`], {
             RGBColor[
             0.21096486897150207`, 0.33906783160726484`, 0.9353255092421473]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.10403391911817532`], {
             RGBColor[
             0.2669435612753158, 0.3979049864726603, 0.9385134129557955]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.10403391911817532`], {
             RGBColor[
             0.1828194546111727, 0.3094852165922191, 0.9337226695317358]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.10403391911817532`], {
             RGBColor[
             0.231882716170344, 0.3610538152813617, 0.9365167496949396]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.10403391911817532`], {
             RGBColor[
             0.1932715661048615, 0.3204710484742306, 0.934317901818788]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.10403391911817532`], {
             RGBColor[
             0.17993663614433356`, 0.30645519160232343`, 0.933558497284797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.10403391911817532`], {
             RGBColor[
             0.18628610638119678`, 0.3131288874009316, 0.933920090221587]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.10403391911817532`], {
             RGBColor[
             0.30330054125463324`, 0.4361184775965936, 0.9405838891802857]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.10403391911817532`], {
             RGBColor[
             0.19751233663727177`, 0.32492836718417534`, 0.934559407426951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.10403391911817532`], {
             RGBColor[
             0.28807193351340393`, 0.4201122453110634, 0.9397166424981289]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.10403391911817532`], {
             RGBColor[
             0.29453979532827157`, 0.4269103781646138, 0.9400849776601415]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.10403391911817532`], {
             RGBColor[
             0.5678299626641032, 0.6600289699958488, 0.9591208011720589]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.10403391911817532`], {
             RGBColor[
             0.21754949730263914`, 0.3459886934728391, 0.9357004940845208]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.10403391911817532`], {
             RGBColor[
             0.2199797674453161, 0.34854306148081937`, 0.9358388943738838]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.10403391911817532`], {
             RGBColor[
             0.21267780393729097`, 0.3408682348626586, 0.9354230583543888]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.10403391911817532`], {
             RGBColor[
             0.8799257418165628, 0.9070929178492902, 0.9884092968450884]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.10403391911817532`], {
             RGBColor[
             0.2672266367019122, 0.3982025166940318, 0.9385295336825675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.10403391911817532`], {
             RGBColor[
             0.18253824749144235`, 0.3091896500798213, 0.9337066552022758]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.10403391911817532`], {
             RGBColor[
             0.9838179497494997, 0.9570762861582877, 0.3916362198109257]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.10403391911817532`], {
             RGBColor[
             0.20227092428797666`, 0.3299299445169493, 0.9348304019539591]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.10403391911817532`], {
             RGBColor[
             0.8627736592976373, 0.893416312829576, 0.9867733159025884]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.10403391911817532`], {
             RGBColor[
             0.24174079120237463`, 0.3714152771780834, 0.9370781524842986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.10403391911817532`], {
             RGBColor[
             0.1866504213080221, 0.31351180548792545`, 0.9339408374177139]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.10403391911817532`], {
             RGBColor[
             0.26451672367156814`, 0.39535422628073036`, 0.9383752081444465]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.10403391911817532`], {
             RGBColor[
             0.18085489670587357`, 0.3074203416735843, 0.9336107908653319]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.10403391911817532`], {
             RGBColor[
             0.19516174943023848`, 0.3224577509937465, 0.9344255449628927]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.10403391911817532`], {
             RGBColor[
             0.18935818727662723`, 0.3163578392032078, 0.9340950406838453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.10403391911817532`], {
             RGBColor[
             0.18400485366808053`, 0.3107311461596704, 0.9337901762543859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.10403391911817532`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.10403391911817532`], {
             RGBColor[
             0.31963016475579414`, 0.45126931645744195`, 0.9415875293537502]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.10403391911817532`], {
             RGBColor[
             0.1793731602940581, 0.3058629427572515, 0.9335264081687116]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.10403391911817532`], {
             RGBColor[
             0.8730190118811663, 0.5162908147631843, 0.215756289735856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.10403391911817532`], {
             RGBColor[
             0.18280356972336678`, 0.309468520567975, 0.9337217649108748]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.10403391911817532`], {
             RGBColor[
             0.2483710913746021, 0.3783841430444057, 0.9374557382704568]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.10403391911817532`], {
             RGBColor[
             0.18166922633165483`, 0.3082762537417607, 0.9336571657328274]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.10403391911817532`], {
             RGBColor[
             0.22279105382579328`, 0.3514979017125524, 0.9359989929743265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.10403391911817532`], {
             RGBColor[
             0.2553839646565522, 0.38575511750558267`, 0.9378551110292476]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.10403391911817532`], {
             RGBColor[
             0.19101043280484256`, 0.31809445401177916`, 0.9341891336223989]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.10403391911817532`], {
             RGBColor[
             0.9895988511273592, 0.989966871890899, 0.8220374843374784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.10403391911817532`], {
             RGBColor[
             0.3917451671090384, 0.5137317068904137, 0.9461826335349062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.10403391911817532`], {
             RGBColor[
             0.1851405558033968, 0.31192484111156216`, 0.9338548528108714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.10403391911817532`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.10403391911817532`], {
             RGBColor[
             0.5462473647609004, 0.6425072447330733, 0.9574217400054577]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.10403391911817532`], {
             RGBColor[
             0.2586035630908004, 0.38913911959430847`, 0.938038462397109]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> Medium, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51}, {
          Null, CompressedData["
1:eJwVxV2aqiAAANAQRU0sLfwDNKJAKFHBndwlzAbu/t/mm/Nynj////1Ep9Pp
CU6nv40dDDMNQwwZZOP98YqzzGZf5BrHnHFID5ppbbTVDpWlLk1pEW/4wBnn
mhvuYAwRtHBHR3nowxz2QGEILPCggwkuxJ/sA6f7NL0u98t02SMYxVEWfaL9
9ri9IEU0o1RTQy390iN70/f7G53j83lvNra5LW1SlvLUpRsas5GO43u042f8
Xm/Xx/V1fV+/cE7nZmbz7ObtOT+3qIiLrChoMRbvwhaf4ouqsqqGSlemslWo
jrRruo51z27uXLdBgkhJKkIoYYSTkWhiiCWOBHIgnGJMcIMHzDDHGhvscEiu
yS2ZkkfyQipVWBHVqEExxZXSyiinQtTCNm7PbdG2n3ZHIhVYENGITlDBBBdC
CS1mYYQVTmwiQJ945FNPfOM7Tz3zkxd+9tY7v/mohnVcX+r6Xrf1VO+1h0uy
XJZ6uS/T8lpwX/ZV3w8971Wve9OH/sjLvMp1bvMDrflartVK1n4dVr2a1a7r
gWQqsSSykZ1kkkshpZJaztJIJzfpZQARgCAGCGQgBwUoQQ0IaAEFI9DAAAtW
4MHxC4roPaI=
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[25, 38] -> 
             RGBColor[
              0.336257727985893, 0.4526830633454931, 0.9433787991614527], 
             UndirectedEdge[20, 34] -> 
             RGBColor[
              0.6186916887325056, 0.6152786659972597, 0.6055204976217563], 
             UndirectedEdge[28, 38] -> 
             RGBColor[
              0.35359334635715617`, 0.47090389739537886`, 0.9443660369819471],
              UndirectedEdge[30, 44] -> 
             RGBColor[
              0.24382585671181548`, 0.37360681322929457`, 0.9371968938804832],
              UndirectedEdge[1, 41] -> 
             RGBColor[
              0.8450918749905807, 0.3248586737520222, 0.1899227849125934], 
             UndirectedEdge[12, 38] -> 
             RGBColor[
              0.36796069088572964`, 0.4860048874371662, 0.9451842359982678], 
             UndirectedEdge[34, 38] -> 
             RGBColor[
              0.39489232387314516`, 0.5143117412710956, 0.9467179526551205], 
             UndirectedEdge[21, 28] -> 
             RGBColor[
              0.2415025961926477, 0.37116491912042454`, 0.9370645876308725], 
             UndirectedEdge[4, 10] -> 
             RGBColor[
              0.1961380543583011, 0.32348390937444804`, 0.934481144084232], 
             UndirectedEdge[13, 41] -> 
             RGBColor[
              0.5450075424175487, 0.26903912673252517`, 0.5515295053312146], 
             UndirectedEdge[23, 34] -> 
             RGBColor[
              0.26879732754127306`, 0.3998534123537512, 0.9386189822022403], 
             UndirectedEdge[32, 37] -> 
             RGBColor[
              0.29954127027323035`, 0.424931418351192, 0.9406347433346658], 
             UndirectedEdge[1, 6] -> 
             RGBColor[
              0.919857536587366, 0.7077154225505051, 0.27067388226687017`], 
             UndirectedEdge[27, 38] -> 
             RGBColor[
              0.42627156186816795`, 0.5425677866941474, 0.9486779783929155], 
             UndirectedEdge[21, 23] -> 
             RGBColor[
              0.2545007871690399, 0.3848268419695203, 0.9378048153778777], 
             UndirectedEdge[6, 29] -> 
             RGBColor[
              0.6021378520586942, 0.6333600024797356, 0.6312762954807829], 
             UndirectedEdge[16, 25] -> 
             RGBColor[
              0.20119418132175831`, 0.32879821939000664`, 0.9347690830349313],
              UndirectedEdge[18, 35] -> 
             RGBColor[
              0.22011593889536263`, 0.34868618630858683`, 0.9358466491365163],
              UndirectedEdge[13, 20] -> 
             RGBColor[
              0.6064906741096194, 0.6024546260395988, 0.6048256678887667], 
             UndirectedEdge[2, 11] -> 
             RGBColor[
              0.21066051465738866`, 0.3387479359259536, 0.9353081767142104], 
             UndirectedEdge[6, 51] -> 
             RGBColor[
              0.6564303562485516, 0.6869795193245103, 0.6344943243216845], 
             UndirectedEdge[38, 50] -> 
             RGBColor[
              0.3456603138425646, 0.46256577723923076`, 0.943914262516111], 
             UndirectedEdge[21, 47] -> 
             RGBColor[
              0.25799401381117926`, 0.38849844465377015`, 0.9380037494673819],
              UndirectedEdge[32, 41] -> 
             RGBColor[
              0.6021633402630506, 0.3218776670626364, 0.5550493825395182], 
             UndirectedEdge[14, 44] -> 
             RGBColor[
              0.19720133399462103`, 0.324601483688043, 0.9345416962865392], 
             UndirectedEdge[12, 21] -> 
             RGBColor[
              0.25586994072122116`, 0.3862659091622119, 0.9378827866471933], 
             UndirectedEdge[1, 2] -> 
             RGBColor[
              0.5351820259633202, 0.4202525072003491, 0.5750931174728616], 
             UndirectedEdge[24, 28] -> 
             RGBColor[
              0.20230251302814176`, 0.3299631462857046, 0.9348322008859802], 
             UndirectedEdge[27, 39] -> 
             RGBColor[
              0.3964965713111768, 0.5178471343977871, 0.9464853888091647], 
             UndirectedEdge[16, 24] -> 
             RGBColor[
              0.2063321536722713, 0.3341985540966582, 0.9350616829593441], 
             UndirectedEdge[40, 46] -> 
             RGBColor[
              0.31524518292559567`, 0.4409774018527399, 0.941545894351479], 
             UndirectedEdge[4, 11] -> 
             RGBColor[
              0.21858541804295029`, 0.3470775118520747, 0.9357594882381741], 
             UndirectedEdge[7, 28] -> 
             RGBColor[
              0.22829296747172917`, 0.3572807617959043, 0.9363123188171107], 
             UndirectedEdge[13, 24] -> 
             RGBColor[
              0.23140047592124452`, 0.3605469502037604, 0.9364892868261638], 
             UndirectedEdge[27, 40] -> 
             RGBColor[
              0.37591883297632056`, 0.5000237317193359, 0.9451741935186472], 
             UndirectedEdge[8, 43] -> 
             RGBColor[
              0.20750950276114938`, 0.33543602263731276`, 0.9351287312482239],
              UndirectedEdge[1, 38] -> 
             RGBColor[
              0.682775641823291, 0.5573072483329317, 0.5844164025035096], 
             UndirectedEdge[46, 51] -> 
             RGBColor[
              0.2922598396364991, 0.42106865277266936`, 0.9400812886022387], 
             UndirectedEdge[34, 47] -> 
             RGBColor[
              0.27229055418341247`, 0.4035250150380011, 0.9388179162917445], 
             UndirectedEdge[1, 9] -> 
             RGBColor[
              0.5688016423732998, 0.45558885565403384`, 0.5770077048916445], 
             UndirectedEdge[11, 36] -> 
             RGBColor[
              0.21305785312116599`, 0.34126769065142126`, 0.935444701593178], 
             UndirectedEdge[16, 40] -> 
             RGBColor[
              0.30727025810943837`, 0.4325952502315209, 0.9410917341810427], 
             UndirectedEdge[4, 17] -> 
             RGBColor[
              0.32466731268133553`, 0.44681214641183215`, 0.9422314388278323],
              UndirectedEdge[7, 32] -> 
             RGBColor[
              0.3145467282103338, 0.44070310604407126`, 0.9414892819655981], 
             UndirectedEdge[13, 46] -> 
             RGBColor[
              0.25560268740228154`, 0.38598500897916727`, 0.9378675669660456],
              UndirectedEdge[20, 26] -> 
             RGBColor[
              0.9580039310410251, 0.8653633823983007, 0.3154988173846851], 
             UndirectedEdge[3, 22] -> 
             RGBColor[
              0.5469084500555053, 0.6302974942255075, 0.9610903579071268], 
             UndirectedEdge[6, 34] -> 
             RGBColor[
              0.6319742186372203, 0.6647199154886689, 0.6329754324184811], 
             UndirectedEdge[34, 49] -> 
             RGBColor[
              0.635887689085936, 0.6779209702387459, 0.648178526114859], 
             UndirectedEdge[12, 34] -> 
             RGBColor[
              0.27016648109345437`, 0.4012924795464428, 0.9386969534715559], 
             UndirectedEdge[6, 37] -> 
             RGBColor[
              0.5894625916069651, 0.6200375000870386, 0.6305544581494242], 
             UndirectedEdge[37, 45] -> 
             RGBColor[
              0.2654397796399679, 0.3953944211554158, 0.9384618265062784], 
             UndirectedEdge[32, 47] -> 
             RGBColor[
              0.3172453374060281, 0.4435395154104514, 0.9416429637670584], 
             UndirectedEdge[38, 45] -> 
             RGBColor[
              0.40574561646249835`, 0.5247892444477695, 0.9473700833020471], 
             UndirectedEdge[21, 34] -> 
             RGBColor[
              0.2828015737086367, 0.4145727629961412, 0.939416503304046], 
             UndirectedEdge[34, 37] -> 
             RGBColor[
              0.2545864870506147, 0.3849169179787417, 0.9378096958593518], 
             UndirectedEdge[38, 46] -> 
             RGBColor[
              0.36559791181744306`, 0.48352145682755154`, 0.9450496792257472],
              UndirectedEdge[3, 39] -> 
             RGBColor[
              0.6341445752938251, 0.7104874364512741, 0.9664794252180962], 
             UndirectedEdge[32, 50] -> 
             RGBColor[
              0.292820887272905, 0.4178678697209577, 0.9402520274647129], 
             UndirectedEdge[26, 41] -> 
             RGBColor[
              0.8965207993489546, 0.531947883091227, 0.262202654827133], 
             UndirectedEdge[10, 48] -> 
             RGBColor[
              0.18043702837123554`, 0.306981135559497, 0.9335869938818551], 
             UndirectedEdge[16, 38] -> 
             RGBColor[
              0.3576229870012857, 0.4751393052063325, 0.944595519055311], 
             UndirectedEdge[1, 40] -> 
             RGBColor[
              0.6324229129314436, 0.51476319335812, 0.5809126176292413], 
             UndirectedEdge[1, 11] -> 
             RGBColor[
              0.5483432386752299, 0.43408577622964883`, 0.5758426290665355], 
             UndirectedEdge[40, 45] -> 
             RGBColor[
              0.35539288757065096`, 0.482245189472958, 0.9438662984277788], 
             UndirectedEdge[1, 22] -> 
             RGBColor[
              0.5657645260279801, 0.45239665381080457`, 0.5768347456087896], 
             UndirectedEdge[22, 48] -> 
             RGBColor[
              0.22030567940863488`, 0.34888561561827935`, 0.9358574545780514],
              UndirectedEdge[28, 32] -> 
             RGBColor[
              0.30075391978749655`, 0.4262059898771058, 0.940703801930549], 
             UndirectedEdge[4, 48] -> 
             RGBColor[
              0.1976480827295366, 0.325071044933945, 0.9345671379660871], 
             UndirectedEdge[9, 13] -> 
             RGBColor[
              0.26871730980026776`, 0.39976930863453686`, 0.9386144253102657],
              UndirectedEdge[1, 13] -> 
             RGBColor[
              0.5727804174081295, 0.45977080048454744`, 0.5772342902438079], 
             UndirectedEdge[45, 47] -> 
             RGBColor[
              0.28314384677276566`, 0.41400251821467515`, 0.939470046938671], 
             UndirectedEdge[14, 48] -> 
             RGBColor[
              0.18089691092665647`, 0.30746450128348257`, 0.933613183513051], 
             UndirectedEdge[26, 40] -> 
             RGBColor[
              0.6838518372898174, 0.721852402697325, 0.6531924875437809], 
             UndirectedEdge[5, 15] -> 
             RGBColor[
              0.24083719976899448`, 0.37046554529059506`, 0.9370266942889113],
              UndirectedEdge[7, 45] -> 
             RGBColor[
              0.28044523757707135`, 0.41116610884829496`, 0.9393163651372107],
              UndirectedEdge[16, 41] -> 
             RGBColor[
              0.5199392201685755, 0.24269073062542304`, 0.5501019014643949], 
             UndirectedEdge[24, 46] -> 
             RGBColor[
              0.21430707848842864`, 0.34258070571787724`, 0.9355158431297803],
              UndirectedEdge[26, 43] -> 
             RGBColor[
              0.5865019013441979, 0.627227099150101, 0.6473667772094565], 
             UndirectedEdge[40, 51] -> 
             RGBColor[
              0.3689957325926291, 0.4940272901321252, 0.9447330596840557], 
             UndirectedEdge[12, 25] -> 
             RGBColor[
              0.2115318852062022, 0.33966380162084037`, 0.9353577999778881], 
             UndirectedEdge[2, 10] -> 
             RGBColor[
              0.18821315097273947`, 0.31515433344832694`, 0.9340298325602683],
              UndirectedEdge[27, 45] -> 
             RGBColor[
              0.3393306446652459, 0.46833288198009815`, 0.9428428265131301], 
             UndirectedEdge[29, 43] -> 
             RGBColor[
              0.21735329245715224`, 0.3457824697401267, 0.9356893205088295], 
             UndirectedEdge[4, 42] -> 
             RGBColor[
              0.20664084885224154`, 0.3345230123032118, 0.9350792626931699], 
             UndirectedEdge[3, 44] -> 
             RGBColor[
              0.524854250457306, 0.6071171321307826, 0.9598344038662738], 
             UndirectedEdge[39, 45] -> 
             RGBColor[
              0.3759706259055072, 0.5000685921514092, 0.9451774937182964], 
             UndirectedEdge[24, 51] -> 
             RGBColor[
              0.2680576281554621, 0.3956305939972625, 0.9387030084623571], 
             UndirectedEdge[27, 28] -> 
             RGBColor[
              0.2871783745599037, 0.4144475349277074, 0.9398387801930301], 
             UndirectedEdge[3, 20] -> 
             RGBColor[
              0.8877189307101766, 0.8361750134737986, 0.6274745597684828], 
             UndirectedEdge[5, 44] -> 
             RGBColor[
              0.2513700816788449, 0.3815362720011326, 0.9376265263316749], 
             UndirectedEdge[37, 40] -> 
             RGBColor[
              0.3020279679510426, 0.42708527089465353`, 0.9407931935117955], 
             UndirectedEdge[7, 23] -> 
             RGBColor[
              0.24129115844812132`, 0.370942684645, 0.937052546564116], 
             UndirectedEdge[2, 3] -> 
             RGBColor[
              0.5163259499908455, 0.598153347615052, 0.9593487297711989], 
             UndirectedEdge[28, 40] -> 
             RGBColor[
              0.3032406174653088, 0.4283598424205673, 0.9408622521076788], 
             UndirectedEdge[5, 30] -> 
             RGBColor[
              0.28064003551226024`, 0.4123008493023123, 0.9392934069014716], 
             UndirectedEdge[13, 40] -> 
             RGBColor[
              0.3323385803584116, 0.45894364633862306`, 0.9425193380478625], 
             UndirectedEdge[8, 41] -> 
             RGBColor[
              0.517528400765906, 0.24015680657843877`, 0.5499646088659005], 
             UndirectedEdge[7, 37] -> 
             RGBColor[
              0.22708031795746292`, 0.35600619026999053`, 0.9362432602212274],
              UndirectedEdge[2, 42] -> 
             RGBColor[
              0.19871594546667992`, 0.32619343637709075`, 0.9346279511692062],
              UndirectedEdge[25, 28] -> 
             RGBColor[
              0.19716454067762873`, 0.32456281157905303`, 0.9345396009615674],
              UndirectedEdge[26, 29] -> 
             RGBColor[
              0.6065739898108634, 0.6483241367724797, 0.648509852953639], 
             UndirectedEdge[20, 46] -> 
             RGBColor[
              0.5893972766768035, 0.5844883815537156, 0.6038522241923832], 
             UndirectedEdge[45, 49] -> 
             RGBColor[
              0.6467409816752892, 0.6883984734154199, 0.6488306567617856], 
             UndirectedEdge[6, 40] -> 
             RGBColor[
              0.6794156995376481, 0.7068882684045807, 0.6359589300709247], 
             UndirectedEdge[12, 50] -> 
             RGBColor[
              0.22093447106287384`, 0.34954651551457805`, 0.9358932633325463],
              UndirectedEdge[2, 4] -> 
             RGBColor[
              0.20542420533104055`, 0.333244242822775, 0.9350099766445004], 
             UndirectedEdge[7, 49] -> 
             RGBColor[
              0.6083815199927843, 0.6490102425299946, 0.6466120904767347], 
             UndirectedEdge[9, 16] -> 
             RGBColor[
              0.24364898755129455`, 0.3734209125274347, 0.937186821443446], 
             UndirectedEdge[16, 51] -> 
             RGBColor[
              0.2842849148203418, 0.41268650115145034`, 0.9396271284318026], 
             UndirectedEdge[23, 49] -> 
             RGBColor[
              0.6075869025463392, 0.648175049212125, 0.6465668381886908], 
             UndirectedEdge[8, 26] -> 
             RGBColor[
              0.5967302001148604, 0.6379776896696658, 0.6479492636930335], 
             UndirectedEdge[20, 38] -> 
             RGBColor[
              0.7164858985247808, 0.6999910738879831, 0.6120077801484682], 
             UndirectedEdge[12, 20] -> 
             RGBColor[
              0.59176005574509, 0.5869718121633303, 0.6039867809649037], 
             UndirectedEdge[1, 17] -> 
             RGBColor[
              0.6544251333136152, 0.5338204107894063, 0.5823145796561937], 
             UndirectedEdge[1, 3] -> 
             RGBColor[
              0.8540086740086867, 0.6934911879187473, 0.599883182123524], 
             UndirectedEdge[16, 50] -> 
             RGBColor[
              0.21059676717842996`, 0.3386809332837444, 0.9353045463895896], 
             UndirectedEdge[3, 48] -> 
             RGBColor[
              0.5085498273893414, 0.5899801497262221, 0.9589058910927857], 
             UndirectedEdge[12, 28] -> 
             RGBColor[
              0.22886750357746538`, 0.35788463567072615`, 0.9363450377983824],
              UndirectedEdge[25, 37] -> 
             RGBColor[
              0.1959518911633625, 0.3232882400531393, 0.934470542365684], 
             UndirectedEdge[11, 22] -> 
             RGBColor[
              0.24124301472204857`, 0.37089208253640904`, 0.9370498048501383],
              UndirectedEdge[20, 27] -> 
             RGBColor[
              0.6500709267275284, 0.6435347114203116, 0.6074805233595513], 
             UndirectedEdge[12, 24] -> 
             RGBColor[
              0.2166698575567152, 0.34506413632749194`, 0.9356503999023009], 
             UndirectedEdge[11, 42] -> 
             RGBColor[
              0.21187715817858965`, 0.34002670540639046`, 0.9353774627628799],
              UndirectedEdge[6, 28] -> 
             RGBColor[
              0.5906752411212313, 0.6213120716129523, 0.6306235167453076], 
             UndirectedEdge[5, 31] -> 
             RGBColor[
              0.23664479051198237`, 0.36605905734737576`, 0.9367879427838381],
              UndirectedEdge[6, 32] -> 
             RGBColor[
              0.676929001859836, 0.7047344158611193, 0.635800479893795], 
             UndirectedEdge[24, 40] -> 
             RGBColor[
              0.2910429714445586, 0.4155393430773331, 0.9401676142115972], 
             UndirectedEdge[5, 35] -> 
             RGBColor[
              0.27203050028951276`, 0.4032516819071433, 0.938803106607202], 
             UndirectedEdge[39, 47] -> 
             RGBColor[
              0.3403097734186966, 0.4635167706323641, 0.9431126092347056], 
             UndirectedEdge[41, 46] -> 
             RGBColor[
              0.5279141449847329, 0.25107288224664204`, 0.5505560616348311], 
             UndirectedEdge[23, 32] -> 
             RGBColor[
              0.31375211076388876`, 0.4398679127262015, 0.9414440296775541], 
             UndirectedEdge[32, 38] -> 
             RGBColor[
              0.4398471070957608, 0.5543262416435458, 0.9495430001304344], 
             UndirectedEdge[17, 48] -> 
             RGBColor[
              0.30896628669426995`, 0.4303093725968812, 0.9413372886254554], 
             UndirectedEdge[18, 31] -> 
             RGBColor[
              0.18473022911783224`, 0.3114935617488193, 0.9338314853131524], 
             UndirectedEdge[6, 27] -> 
             RGBColor[
              0.663353456632243, 0.692975960911721, 0.6349354581562761], 
             UndirectedEdge[36, 43] -> 
             RGBColor[
              0.19978759143176011`, 0.3273198042326686, 0.9346889798215593], 
             UndirectedEdge[9, 41] -> 
             RGBColor[
              0.541028767382719, 0.26485718190201163`, 0.5513029199790511], 
             UndirectedEdge[28, 37] -> 
             RGBColor[
              0.2132875095346257, 0.34150907410302506`, 0.9354577801861783], 
             UndirectedEdge[15, 31] -> 
             RGBColor[
              0.1892977298016872, 0.3162942945638205, 0.9340915977200862], 
             UndirectedEdge[21, 27] -> 
             RGBColor[
              0.3141808117036594, 0.44282880841919314`, 0.941376529041841], 
             UndirectedEdge[27, 49] -> 
             RGBColor[
              0.6672669270809588, 0.7061770156617978, 0.650138551852654], 
             UndirectedEdge[17, 19] -> 
             RGBColor[
              0.3103837936787745, 0.4317992623127292, 0.9414180135512094], 
             UndirectedEdge[27, 50] -> 
             RGBColor[
              0.27924534204531215`, 0.4061094147715593, 0.939387005727194], 
             UndirectedEdge[11, 29] -> 
             RGBColor[
              0.2306235541465581, 0.3597303561588793, 0.9364450422804482], 
             UndirectedEdge[37, 50] -> 
             RGBColor[
              0.20535447702003415`, 0.33317095394687696`, 0.9350060057203422],
              UndirectedEdge[6, 13] -> 
             RGBColor[
              0.619773204014334, 0.6518958755310081, 0.6322806026854912], 
             UndirectedEdge[7, 34] -> 
             RGBColor[
              0.26959194498771816`, 0.40068860567162096`, 0.9386642344902842],
              UndirectedEdge[7, 27] -> 
             RGBColor[
              0.3009711829827409, 0.4289446510946729, 0.9406242602280792], 
             UndirectedEdge[15, 18] -> 
             RGBColor[
              0.18892263837484435`, 0.31590004969203866`, 0.9340702368182255],
              UndirectedEdge[12, 32] -> 
             RGBColor[
              0.31512126431607, 0.4413069799188931, 0.9415220009468698], 
             UndirectedEdge[32, 49] -> 
             RGBColor[
              0.6808424723085518, 0.7179354706111962, 0.6510035735901729], 
             UndirectedEdge[27, 34] -> 
             RGBColor[
              0.3284773520758927, 0.4578553788034241, 0.9421906958662035], 
             UndirectedEdge[6, 45] -> 
             RGBColor[
              0.6428275112265734, 0.675197418665343, 0.6336275630654076], 
             UndirectedEdge[20, 40] -> 
             RGBColor[
              0.6661331696329335, 0.6574470189131715, 0.6085039952742], 
             UndirectedEdge[6, 38] -> 
             RGBColor[
              0.7297684284294955, 0.7494323233793924, 0.639462714945193], 
             UndirectedEdge[32, 39] -> 
             RGBColor[
              0.41007211653876974`, 0.5296055893471854, 0.9473504105466837], 
             UndirectedEdge[17, 22] -> 
             RGBColor[
              0.3473249093604338, 0.4706267170961665, 0.9435217554397966], 
             UndirectedEdge[8, 29] -> 
             RGBColor[
              0.2275815912278149, 0.35653306025969145`, 0.9362718069924066], 
             UndirectedEdge[22, 42] -> 
             RGBColor[
              0.22929844553133982`, 0.35833758298754614`, 0.9363695793051341],
              UndirectedEdge[27, 37] -> 
             RGBColor[
              0.28596572504563744`, 0.41317296340179366`, 0.9397697215971468],
              UndirectedEdge[20, 28] -> 
             RGBColor[
              0.5773927112165166, 0.5718708221215429, 0.603168581948583], 
             UndirectedEdge[15, 36] -> 
             RGBColor[
              0.19789205896586642`, 0.3253274794273145, 0.9345810320518155], 
             UndirectedEdge[3, 26] -> 
             RGBColor[
              0.9054375983670604, 0.9005803972579521, 0.6721630520380637], 
             UndirectedEdge[45, 50] -> 
             RGBColor[
              0.25871939663964255`, 0.3883308725251814, 0.9380791106363255], 
             UndirectedEdge[27, 32] -> 
             RGBColor[
              0.3734321352985083, 0.4978698791758744, 0.9450157433415174], 
             UndirectedEdge[9, 51] -> 
             RGBColor[
              0.30537446203448526`, 0.43485295242803895`, 0.9408281469464589],
              UndirectedEdge[30, 35] -> 
             RGBColor[
              0.2644862753224833, 0.3953222231353053, 0.9383734741560104], 
             UndirectedEdge[32, 40] -> 
             RGBColor[
              0.3894943782039134, 0.5117821866687342, 0.9460392152561661], 
             UndirectedEdge[6, 12] -> 
             RGBColor[
              0.6050425856498047, 0.6364130616547397, 0.6314417157616283], 
             UndirectedEdge[21, 32] -> 
             RGBColor[
              0.3277563569312524, 0.4545872633685915, 0.94224155077936], 
             UndirectedEdge[23, 33] -> 
             RGBColor[
              0.2143951723911135, 0.3426732979950751, 0.935520859947215], 
             UndirectedEdge[1, 46] -> 
             RGBColor[
              0.5556870199753136, 0.4418045559986643, 0.5762608465474244], 
             UndirectedEdge[6, 49] -> 
             RGBColor[
              0.9707637936422864, 0.9130415523470428, 0.3409232884049315], 
             UndirectedEdge[38, 51] -> 
             RGBColor[
              0.41934846148447646`, 0.5365713451069367, 0.948236844558324], 
             UndirectedEdge[8, 36] -> 
             RGBColor[
              0.21001589020242278`, 0.3380703947522333, 0.9352714663051365], 
             UndirectedEdge[17, 44] -> 
             RGBColor[
              0.3252707097622345, 0.4474463550014416, 0.9422658013989436], 
             UndirectedEdge[11, 26] -> 
             RGBColor[
              0.5997721630336037, 0.6411749855688538, 0.6481224989810752], 
             UndirectedEdge[1, 8] -> 
             RGBColor[
              0.5453012757564868, 0.430888480330461, 0.5756693937784939], 
             UndirectedEdge[29, 42] -> 
             RGBColor[
              0.21867898495584934`, 0.3471758566100165, 0.935764816735444], 
             UndirectedEdge[21, 37] -> 
             RGBColor[
              0.24028994667838147`, 0.3698903475945108, 0.9369955290349893], 
             UndirectedEdge[25, 46] -> 
             RGBColor[
              0.20916910613791562`, 0.33718037101122567`, 0.9352232432053675],
              UndirectedEdge[14, 19] -> 
             RGBColor[
              0.182314417911161, 0.3089543909993306, 0.933693908438805], 
             UndirectedEdge[20, 45] -> 
             RGBColor[
              0.6295449813218588, 0.6257561691739337, 0.606172628268683], 
             UndirectedEdge[6, 41] -> 
             RGBColor[
              0.8920846615967853, 0.516983748798483, 0.24496909735427674`], 
             UndirectedEdge[12, 45] -> 
             RGBColor[
              0.28101977368280756`, 0.4117699827231168, 0.9393490841184824], 
             UndirectedEdge[19, 30] -> 
             RGBColor[
              0.22893894062835546`, 0.3579597205405822, 0.9363491060327489], 
             UndirectedEdge[3, 6] -> 
             RGBColor[
              0.9010014606148913, 0.885616262965208, 0.6549294945652073], 
             UndirectedEdge[4, 8] -> 
             RGBColor[
              0.2155434551242071, 0.34388021595288676`, 0.9355862529501326], 
             UndirectedEdge[20, 49] -> 
             RGBColor[
              0.9574812637375718, 0.8636003028556334, 0.3134683536082069], 
             UndirectedEdge[24, 38] -> 
             RGBColor[
              0.341395700336406, 0.45808339805214465`, 0.9436713990858655], 
             UndirectedEdge[11, 41] -> 
             RGBColor[
              0.5205703636846493, 0.24335410247762665`, 0.5501378441539422], 
             UndirectedEdge[12, 37] -> 
             RGBColor[
              0.22765485406319913`, 0.3566100641448124, 0.936275979202499], 
             UndirectedEdge[31, 35] -> 
             RGBColor[
              0.22049103032220543`, 0.3490804311803687, 0.9358680100383769], 
             UndirectedEdge[28, 34] -> 
             RGBColor[
              0.2557991365648809, 0.3861914895046555, 0.9378787544552352], 
             UndirectedEdge[19, 44] -> 
             RGBColor[
              0.19966898679494013`, 0.32719514323940246`, 0.9346822254629522],
              UndirectedEdge[12, 40] -> 
             RGBColor[
              0.31760796199388225`, 0.4434608324623546, 0.9416804511239996], 
             UndirectedEdge[26, 36] -> 
             RGBColor[
              0.5890082887854713, 0.6298614712650217, 0.647509512266369], 
             UndirectedEdge[27, 47] -> 
             RGBColor[
              0.30366979217843526`, 0.431781060461053, 0.9407779420295395], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.5551450654524896, 0.44123492743327486`, 0.5762299830390994], 
             UndirectedEdge[34, 40] -> 
             RGBColor[
              0.34453959498129777`, 0.47176768629628396`, 0.9432141677808522],
              UndirectedEdge[6, 20] -> 
             RGBColor[
              0.953567793288856, 0.8503992481055564, 0.29826525991182884`], 
             UndirectedEdge[5, 18] -> 
             RGBColor[
              0.23626969908513956`, 0.3656648124755939, 0.9367665818819775], 
             UndirectedEdge[24, 50] -> 
             RGBColor[
              0.1943694805135502, 0.3216250261295565, 0.9343804264201441], 
             UndirectedEdge[32, 45] -> 
             RGBColor[
              0.35290618989283873`, 0.48009133692949646`, 0.9437078482506491],
              UndirectedEdge[11, 43] -> 
             RGBColor[
              0.21055146567989258`, 0.3386333185365007, 0.9353019665362655], 
             UndirectedEdge[38, 41] -> 
             RGBColor[
              0.6550027668327102, 0.36657557458090945`, 0.5587116175909161], 
             UndirectedEdge[3, 4] -> 
             RGBColor[
              0.524250853376407, 0.6064829235411731, 0.9598000412951626], 
             UndirectedEdge[17, 49] -> 
             RGBColor[
              0.7053313903685355, 0.7391465405859439, 0.6525639857942551], 
             UndirectedEdge[26, 38] -> 
             RGBColor[
              0.7342045661816647, 0.7643964576721365, 0.6566962724180492], 
             UndirectedEdge[30, 49] -> 
             RGBColor[
              0.6238865373181165, 0.665306998813797, 0.6474950782757947], 
             UndirectedEdge[12, 27] -> 
             RGBColor[
              0.3015457190884771, 0.42954852496949475`, 0.9406569792093509], 
             UndirectedEdge[6, 46] -> 
             RGBColor[
              0.6026798065815182, 0.633929631045125, 0.6313071589891077], 
             UndirectedEdge[10, 22] -> 
             RGBColor[
              0.21879565103739937`, 0.3472984800587824, 0.9357714606961962], 
             UndirectedEdge[20, 29] -> 
             RGBColor[
              0.5888553221539795, 0.5839187529883263, 0.6038213606840581], 
             UndirectedEdge[28, 45] -> 
             RGBColor[
              0.2666524291542341, 0.3966689926813295, 0.9385308851021616], 
             UndirectedEdge[24, 25] -> 
             RGBColor[
              0.18496689465687857`, 0.31174231223581883`, 0.9338449630654858],
              UndirectedEdge[25, 40] -> 
             RGBColor[
              0.2859049990940456, 0.4101390083706815, 0.9398750142871845], 
             UndirectedEdge[21, 45] -> 
             RGBColor[
              0.29365486629798987`, 0.42505026617281527`, 0.9400686339509726],
              UndirectedEdge[3, 30] -> 
             RGBColor[
              0.5541242042907213, 0.6378817094319622, 0.9615012844360706], 
             UndirectedEdge[13, 16] -> 
             RGBColor[
              0.24762776258612423`, 0.37760285735794824`, 0.9374134067956095],
              UndirectedEdge[5, 49] -> 
             RGBColor[
              0.6314307622851459, 0.6732364575856349, 0.6479247107269863], 
             UndirectedEdge[23, 45] -> 
             RGBColor[
              0.27965062013062625`, 0.4103309155304252, 0.9392711128491669], 
             UndirectedEdge[47, 49] -> 
             RGBColor[
              0.6110801291884786, 0.6518466518963748, 0.646765772278195], 
             UndirectedEdge[7, 39] -> 
             RGBColor[
              0.3376111642230023, 0.46068036126598394`, 0.9429589274332454], 
             UndirectedEdge[9, 38] -> 
             RGBColor[
              0.3787125342154293, 0.4973057564829211, 0.9457965375699673], 
             UndirectedEdge[34, 45] -> 
             RGBColor[
              0.3079514066702231, 0.4400768365570462, 0.9408828007753351], 
             UndirectedEdge[15, 43] -> 
             RGBColor[
              0.19538567152459302`, 0.3226931073123939, 0.934438296994903], 
             UndirectedEdge[2, 22] -> 
             RGBColor[
              0.22808180201013883`, 0.35705881350710933`, 0.9363002932564645],
              UndirectedEdge[6, 50] -> 
             RGBColor[
              0.5827422086066397, 0.6129739514568042, 0.6301717422794715], 
             UndirectedEdge[20, 41] -> 
             RGBColor[
              0.8788021316920707, 0.4675424993070736, 0.21751416255755213`], 
             UndirectedEdge[28, 50] -> 
             RGBColor[
              0.20656712653430037`, 0.3344455254727907, 0.9350750643162256], 
             UndirectedEdge[4, 22] -> 
             RGBColor[
              0.23600670539570046`, 0.3653883894332304, 0.9367516047804283], 
             UndirectedEdge[20, 37] -> 
             RGBColor[
              0.5761800617022503, 0.5705962505956292, 0.6030995233526997], 
             UndirectedEdge[3, 41] -> 
             RGBColor[
              0.826235799018106, 0.5027595141667252, 0.5741783972109307], 
             UndirectedEdge[26, 49] -> 
             RGBColor[
              0.9751999313944556, 0.9280056866397868, 0.3581568458777878], 
             UndirectedEdge[9, 46] -> 
             RGBColor[
              0.25162391236745185`, 0.3818030641486537, 0.9376409816138822], 
             UndirectedEdge[40, 41] -> 
             RGBColor[
              0.6046500379408628, 0.3240315196060979, 0.5552078327166479], 
             UndirectedEdge[41, 49] -> 
             RGBColor[
              0.895998132045501, 0.5301848035485598, 0.26017219105065476`], 
             UndirectedEdge[25, 50] -> 
             RGBColor[
              0.1892315081630372, 0.31622469142290494`, 0.9340878264957313], 
             UndirectedEdge[1, 51] -> 
             RGBColor[
              0.609437569642347, 0.49485444427804953`, 0.5794480118800012], 
             UndirectedEdge[2, 48] -> 
             RGBColor[
              0.18972317934397498`, 0.31674146900782396`, 0.9341158264421234],
              UndirectedEdge[29, 36] -> 
             RGBColor[
              0.21985967989842564`, 0.3484168418550473, 0.935832055565742], 
             UndirectedEdge[16, 20] -> 
             RGBColor[
              0.5814223518606462, 0.5761062299324966, 0.603398064021947], 
             UndirectedEdge[7, 21] -> 
             RGBColor[
              0.25529540461548494`, 0.38566203528739, 0.9378500676659216], 
             UndirectedEdge[1, 26] -> 
             RGBColor[
              0.9242936743395352, 0.7226795568432492, 0.28790743973972643`], 
             UndirectedEdge[33, 39] -> 
             RGBColor[
              0.3107151781659945, 0.43241097461605904`, 0.9414272408163444], 
             UndirectedEdge[35, 44] -> 
             RGBColor[
              0.235216321489068, 0.36455764583412553`, 0.9367065935862138], 
             UndirectedEdge[26, 51] -> 
             RGBColor[
              0.6608664940007207, 0.7019436536172543, 0.6517278817945408], 
             UndirectedEdge[23, 47] -> 
             RGBColor[
              0.24398976764381566`, 0.37377909401138015`, 0.9372062283655762],
              UndirectedEdge[7, 47] -> 
             RGBColor[
              0.24478438509026074`, 0.3746142873292499, 0.9372514806536201], 
             UndirectedEdge[1, 20] -> 
             RGBColor[
              0.9065750066826515, 0.6582741730590957, 0.2432189474701455], 
             UndirectedEdge[39, 49] -> 
             RGBColor[
              0.7039069083212202, 0.7379127258331089, 0.6524732190578202], 
             UndirectedEdge[34, 50] -> 
             RGBColor[
              0.24786610405028936`, 0.3778533693485074, 0.9374269799893991], 
             UndirectedEdge[41, 51] -> 
             RGBColor[
              0.5816646946517663, 0.3041227705260273, 0.5537432269674077], 
             UndirectedEdge[16, 46] -> 
             RGBColor[
              0.23053436515330838`, 0.3596366128720651, 0.936439963099226], 
             UndirectedEdge[8, 42] -> 
             RGBColor[
              0.20883519525984648`, 0.3368294095072025, 0.9352042274748384], 
             UndirectedEdge[8, 11] -> 
             RGBColor[
              0.22077976445055525`, 0.3493839090560654, 0.9358844530198427], 
             UndirectedEdge[7, 12] -> 
             RGBColor[
              0.2426603120003026, 0.3723817518376916, 0.9371305178334315], 
             UndirectedEdge[32, 34] -> 
             RGBColor[
              0.34205289730348554`, 0.46961383375282245`, 0.9430557176037224],
              UndirectedEdge[14, 30] -> 
             RGBColor[
              0.22647128782803633`, 0.3553660609892227, 0.936208576856336], 
             UndirectedEdge[33, 47] -> 
             RGBColor[
              0.2178883990332529, 0.346344900679325, 0.9357197940367192], 
             UndirectedEdge[29, 41] -> 
             RGBColor[
              0.5273721904619089, 0.2505032536812527, 0.550525198126506], 
             UndirectedEdge[15, 35] -> 
             RGBColor[
              0.22468343957921755`, 0.35348691912358804`, 0.9361067615434502],
              UndirectedEdge[20, 51] -> 
             RGBColor[
              0.6431478263438369, 0.6375382698331009, 0.60703938952496], 
             UndirectedEdge[13, 38] -> 
             RGBColor[
              0.38269130925025896`, 0.5014877013134347, 0.9460231229221308], 
             UndirectedEdge[21, 39] -> 
             RGBColor[
              0.3508207929439209, 0.4745645185905042, 0.9437111962470073], 
             UndirectedEdge[23, 39] -> 
             RGBColor[
              0.33681654677655726`, 0.4598451679481142, 0.9429136751452014], 
             UndirectedEdge[38, 40] -> 
             RGBColor[
              0.44233380477357304`, 0.5564800941870074, 0.9497014503075641], 
             UndirectedEdge[14, 17] -> 
             RGBColor[
              0.3079161408784554, 0.42920560276136965`, 0.9412774843747963], 
             UndirectedEdge[2, 17] -> 
             RGBColor[
              0.3167424092957739, 0.43848257048571104`, 0.9417801273038686], 
             UndirectedEdge[23, 27] -> 
             RGBColor[
              0.30017656553629585`, 0.42810945777680315`, 0.9405790079400352],
              UndirectedEdge[17, 30] -> 
             RGBColor[
              0.35454066359564984`, 0.4782109323026213, 0.9439326819687404], 
             UndirectedEdge[26, 32] -> 
             RGBColor[
              0.6813651396120051, 0.7196985501538634, 0.6530340373666512], 
             UndirectedEdge[21, 49] -> 
             RGBColor[
              0.6215911487137029, 0.6628943998545149, 0.6473643592904965], 
             UndirectedEdge[13, 51] -> 
             RGBColor[
              0.30935323706931495`, 0.4390348972585525, 0.9410547322986222], 
             UndirectedEdge[6, 16] -> 
             RGBColor[
              0.5947048817653608, 0.625547479423906, 0.6308529988186716], 
             UndirectedEdge[3, 49] -> 
             RGBColor[
              0.9049149310636071, 0.898817317715285, 0.6701325882615854], 
             UndirectedEdge[20, 50] -> 
             RGBColor[
              0.569459678701925, 0.5635327019653948, 0.6027168074827469], 
             UndirectedEdge[6, 26] -> 
             RGBColor[
              0.9712864609457399, 0.91480463188971, 0.3429537521814098], 
             UndirectedEdge[3, 17] -> 
             RGBColor[
              0.6355690573411403, 0.7117212512041092, 0.966570191954531], 
             UndirectedEdge[24, 37] -> 
             RGBColor[
              0.20108986351387553`, 0.32868857475979085`, 0.9347631422900968],
              UndirectedEdge[34, 39] -> 
             RGBColor[
              0.36511733331615404`, 0.48959108897473513`, 0.9445253630713697],
              UndirectedEdge[1, 4] -> 
             RGBColor[
              0.5431069293488818, 0.4285820831264702, 0.5755444289968255], 
             UndirectedEdge[1, 49] -> 
             RGBColor[
              0.9237710070360818, 0.7209164773005821, 0.2858769759632482], 
             UndirectedEdge[20, 32] -> 
             RGBColor[
              0.6636464719551213, 0.6552931663697099, 0.6083455450970703], 
             UndirectedEdge[40, 50] -> 
             RGBColor[
              0.29530758495071724`, 0.4200217222644192, 0.9404104776418427], 
             UndirectedEdge[37, 38] -> 
             RGBColor[
              0.35238069684289, 0.4696293258694651, 0.9442969783860637], 
             UndirectedEdge[2, 8] -> 
             RGBColor[
              0.2076185517386455, 0.3355506400267657, 0.9351349414261688]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> Medium, 
           VertexSize -> {1.2}, VertexStyle -> {
             EdgeForm[None], 7 -> 
             RGBColor[
              0.2420857758945664, 0.37177787796286976`, 0.9370977988521598], 
             4 -> RGBColor[
              0.21334910871660218`, 0.34157381874889603`, 0.9354612881684641],
              44 -> RGBColor[
              0.21455590287840015`, 0.34284223592811486`, 0.9355300133106865],
              1 -> RGBColor[
              0.8728647499811615, 0.5155903475040444, 0.2156275698251868], 36 -> 
             RGBColor[
              0.20229397887303355`, 0.32995417634758917`, 0.9348317148784718],
              17 -> RGBColor[
              0.4359855166460689, 0.5520504740747683, 0.9490015894872007], 33 -> 
             RGBColor[
              0.18829380378055074`, 0.31523910466301996`, 0.934034425618358], 
             15 -> 
             RGBColor[
              0.1934901390586993, 0.3207007825070398, 0.9343303492251593], 20 -> 
             RGBColor[
              0.9402852633841413, 0.8009579986141472, 0.2708103251151042], 24 -> 
             RGBColor[
              0.1901048670073916, 0.3171426469424704, 0.9341375629898986], 31 -> 
             RGBColor[
              0.18510532054467504`, 0.31188780662060117`, 0.9338528462150131],
              19 -> RGBColor[
              0.18478207071148012`, 0.3115480505506901, 0.9338344376152179], 
             18 -> RGBColor[
              0.18435513769098943`, 0.31109931687703746`, 0.9338101244112917],
              5 -> RGBColor[
              0.2881842604792897, 0.4202303080741503, 0.9397230393526632], 46 -> 
             RGBColor[
              0.2385092899694657, 0.36801876449328413`, 0.936894123269662], 
             16 -> RGBColor[
              0.22255944033715105`, 0.3512544612508461, 0.9359858029287897], 
             23 -> RGBColor[
              0.24049654100167628`, 0.3701074913271303, 0.937007294276072], 
             50 -> RGBColor[
              0.19863409401970883`, 0.3261074053166426, 0.9346232898503894], 
             29 -> RGBColor[
              0.23742538092381776`, 0.36687950736250535`, 0.9368323962530122],
              51 -> RGBColor[
              0.3460103893035325, 0.47411854105205464`, 0.9432684539348155], 
             3 -> RGBColor[
              0.8351525980362119, 0.8713920283334502, 0.9841387944218613], 32 -> 
             RGBColor[
              0.38700768052610124`, 0.5096283341252728, 0.9458807650790364], 
             48 -> RGBColor[
              0.18194705674247105`, 0.30856827111899404`, 0.9336729877637102],
              42 -> RGBColor[
              0.1999325889878809, 0.32747220585752757`, 0.9346972372178757], 
             12 -> RGBColor[
              0.24323484810603882`, 0.3729856257125135, 0.9371632368147031], 
             39 -> RGBColor[
              0.43313655255143824`, 0.5495828445690981, 0.948820056014331], 
             25 -> RGBColor[
              0.17982892230636555`, 0.30634197752916725`, 0.933552363141073], 
             28 -> RGBColor[
              0.21450015904889191`, 0.3427836456289388, 0.9355268387820617], 
             35 -> RGBColor[
              0.2558767400997358, 0.38627305574013626`, 0.9378831738617409], 
             43 -> RGBColor[
              0.1972812039904867, 0.32468543211774803`, 0.9345462447646468], 
             40 -> RGBColor[
              0.39198107588172565`, 0.5139360392121958, 0.9461976654332959], 
             34 -> 
             RGBColor[
              0.2970981140808699, 0.42959933338037215`, 0.9402306701284086], 
             10 -> RGBColor[0.178927, 0.305394, 0.933501], 38 -> 
             RGBColor[
              0.4926865336654204, 0.5990241491618189, 0.9532052351818324], 26 -> 
             RGBColor[
              0.975722598697909, 0.9297687661824541, 0.36018730965426604`], 6 -> 
             RGBColor[
              0.9668503231935707, 0.8998404975969658, 0.3257201947085535], 2 -> 
             RGBColor[
              0.19749930194547893`, 0.3249146668966539, 0.9345586651205365], 
             27 -> RGBColor[
              0.3598565900709154, 0.486111424226476, 0.9441507216039985], 21 -> 
             RGBColor[
              0.26850503333640346`, 0.39954619261191027`, 0.9386023364796835],
              30 -> RGBColor[
              0.2730958105452308, 0.40437139053047433`, 0.9388637744502799], 
             13 -> RGBColor[
              0.27269608483509744`, 0.4039512534650504, 0.9388410106624291], 
             49 -> RGBColor[
              0.9746772640910022, 0.9262426070971196, 0.35612638210130954`], 
             45 -> RGBColor[
              0.3188046992595763, 0.4505543397337202, 0.9415349314222617], 11 -> 
             RGBColor[
              0.22382172736929842`, 0.3525812049552533, 0.9360576883078843], 
             14 -> RGBColor[
              0.17984676511084188`, 0.30636073144797105`, 0.9335533792623919],
              22 -> RGBColor[
              0.25866430207479874`, 0.3892029601175647, 0.9380419213923924], 
             47 -> RGBColor[
              0.24748299428595505`, 0.37745069669563003`, 0.9374051624550803],
              8 -> RGBColor[
              0.21773780153181205`, 0.34618661315687754`, 0.9357112177318011],
              9 -> RGBColor[
              0.26473853476543807`, 0.39558736380402326`, 0.9383878399581023],
              37 -> RGBColor[
              0.21207486002035947`, 0.3402345025771113, 0.9353887215902951], 
             41 -> RGBColor[0.817319, 0.134127, 0.164218]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJwBQQO+/CFib1JlAgAAADMAAAACAAAAWsUcBsYgA0BDRQjWb6H1P0CrIbiA
hg5ARCUffN8v7T92ExQrGW4JQPHbpDEF6/4/ChIK65hiDUB0skDOMgPlP3Xm
cBs2uxJA/D+wpv0bDUCnJJGgrwP4PxAcjqh4u/8/xscd1Xrq8D/ACXpeimUL
QDvVR8BRtghAyJsK6wU28T+FnnT31KbzP1CVN3zQvOM//itvMdZuEkAAAAAA
AAAAAMm50h0nXgpAJfDjZRlb8z/04ZSMbDbhPwsgfrfFkwVAZvJC+dTr8j/U
YMSKDRfxP4Iz8WRNShVAR4p4bdMh/D9nyX8q1lgUQPhnTauWYQpAkqlJFKut
5T9adfQpOu70P7F29vtFhBBAohxxndi9+z9O6YW5oOgWQKN2a+mzXRFAGmFT
kkc+FkDwxX+Hn6IBQIZtkTdg1fg/gM52NKD3AEBsMFiP6w7qP0vEFNR6dAtA
Kun4dM6uD0AsXJXdgmPmP913c1Uc6/I/B2iBPPnQDkAQE7T8sVfTPyiPw/KG
6Pk/AAAAAAAAAAD7mtDkqvz9P/zdSBdb/wJA6tc6G5tj/j+FBVqcT9/zPz50
rKk+1gdAwL53MbF/3D+fQNhprDMEQJ6QwlOPPAZAvN8V+2zL9z+gyeqJjc0R
QJjvajPCmgVAHOZkknIfGEBQN1Q/+jAQQIEMsonHMvY/0hrmNbivBUCwJ+Nq
QozzP3TzDE3sbhNAPg/prWsP7z8WStN8PcQHQFSMA5fiaBZAaLzfjvNHDEBj
EAfOEnUNQOolVnF+CgJADJMUusNA5j9sTI3ehwAEQNeRFq636/A/9L4bY4hM
/T9cFJ+bCHr8P2ZVejNc5QtAeRN2KZ/u8D81ZpAfwBwAQAFP2zbr0P4/vXCz
Yst5+D+M1mWDbF4LQLCzYbwvocs/rapvy7ulDkBT7nJjvCMAQAc+YHKDwhNA
3lqhIBN1BEDi5OoVb8DxP14e15BGpwZAHgaaJvQ/7z/sKDu0CTf0PzRTZeEo
JPc/IqbhwtegDkC6uhovLkoSQCAQf/RzAO4/YjnajIvvAkBfdC2cM5YGQJDd
j2EpNuE/541/w1B4AUA4Mi2+lZP2P/CV4zkpPPQ/mlZ0ZQ==
         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 2}], {
             RGBColor[
             0.5351820259633202, 0.4202525072003491, 0.5750931174728616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 3}], {
             RGBColor[
             0.8540086740086867, 0.6934911879187473, 0.599883182123524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 4}], {
             RGBColor[
             0.5431069293488818, 0.4285820831264702, 0.5755444289968255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 6}], {
             RGBColor[
             0.919857536587366, 0.7077154225505051, 0.27067388226687017`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 8}], {
             RGBColor[
             0.5453012757564868, 0.430888480330461, 0.5756693937784939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 9}], {
             RGBColor[
             0.5688016423732998, 0.45558885565403384`, 0.5770077048916445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 11}], {
             RGBColor[
             0.5483432386752299, 0.43408577622964883`, 0.5758426290665355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 13}], {
             RGBColor[
             0.5727804174081295, 0.45977080048454744`, 0.5772342902438079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 17}], {
             RGBColor[
             0.6544251333136152, 0.5338204107894063, 0.5823145796561937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 20}], {
             RGBColor[
             0.9065750066826515, 0.6582741730590957, 0.2432189474701455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 22}], {
             RGBColor[
             0.5657645260279801, 0.45239665381080457`, 0.5768347456087896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 26}], {
             RGBColor[
             0.9242936743395352, 0.7226795568432492, 0.28790743973972643`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.5551450654524896, 0.44123492743327486`, 0.5762299830390994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 38}], {
             RGBColor[
             0.682775641823291, 0.5573072483329317, 0.5844164025035096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 40}], {
             RGBColor[
             0.6324229129314436, 0.51476319335812, 0.5809126176292413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 41}], {
             RGBColor[
             0.8450918749905807, 0.3248586737520222, 0.1899227849125934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 46}], {
             RGBColor[
             0.5556870199753136, 0.4418045559986643, 0.5762608465474244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 49}], {
             RGBColor[
             0.9237710070360818, 0.7209164773005821, 0.2858769759632482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 51}], {
             RGBColor[
             0.609437569642347, 0.49485444427804953`, 0.5794480118800012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 3}], {
             RGBColor[
             0.5163259499908455, 0.598153347615052, 0.9593487297711989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 4}], {
             RGBColor[
             0.20542420533104055`, 0.333244242822775, 0.9350099766445004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 8}], {
             RGBColor[
             0.2076185517386455, 0.3355506400267657, 0.9351349414261688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 10}], {
             RGBColor[
             0.18821315097273947`, 0.31515433344832694`, 0.9340298325602683]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 11}], {
             RGBColor[
             0.21066051465738866`, 0.3387479359259536, 0.9353081767142104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 17}], {
             RGBColor[
             0.3167424092957739, 0.43848257048571104`, 0.9417801273038686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 22}], {
             RGBColor[
             0.22808180201013883`, 0.35705881350710933`, 0.9363002932564645]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 42}], {
             RGBColor[
             0.19871594546667992`, 0.32619343637709075`, 0.9346279511692062]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 48}], {
             RGBColor[
             0.18972317934397498`, 0.31674146900782396`, 0.9341158264421234]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 4}], {
             RGBColor[
             0.524250853376407, 0.6064829235411731, 0.9598000412951626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 6}], {
             RGBColor[
             0.9010014606148913, 0.885616262965208, 0.6549294945652073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 17}], {
             RGBColor[
             0.6355690573411403, 0.7117212512041092, 0.966570191954531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 20}], {
             RGBColor[
             0.8877189307101766, 0.8361750134737986, 0.6274745597684828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 22}], {
             RGBColor[
             0.5469084500555053, 0.6302974942255075, 0.9610903579071268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 26}], {
             RGBColor[
             0.9054375983670604, 0.9005803972579521, 0.6721630520380637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 30}], {
             RGBColor[
             0.5541242042907213, 0.6378817094319622, 0.9615012844360706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 39}], {
             RGBColor[
             0.6341445752938251, 0.7104874364512741, 0.9664794252180962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 41}], {
             RGBColor[
             0.826235799018106, 0.5027595141667252, 0.5741783972109307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 44}], {
             RGBColor[
             0.524854250457306, 0.6071171321307826, 0.9598344038662738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 48}], {
             RGBColor[
             0.5085498273893414, 0.5899801497262221, 0.9589058910927857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 49}], {
             RGBColor[
             0.9049149310636071, 0.898817317715285, 0.6701325882615854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 8}], {
             RGBColor[
             0.2155434551242071, 0.34388021595288676`, 0.9355862529501326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 10}], {
             RGBColor[
             0.1961380543583011, 0.32348390937444804`, 0.934481144084232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 11}], {
             RGBColor[
             0.21858541804295029`, 0.3470775118520747, 0.9357594882381741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 17}], {
             RGBColor[
             0.32466731268133553`, 0.44681214641183215`, 0.9422314388278323]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 22}], {
             RGBColor[
             0.23600670539570046`, 0.3653883894332304, 0.9367516047804283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 42}], {
             RGBColor[
             0.20664084885224154`, 0.3345230123032118, 0.9350792626931699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 48}], {
             RGBColor[
             0.1976480827295366, 0.325071044933945, 0.9345671379660871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 15}], {
             RGBColor[
             0.24083719976899448`, 0.37046554529059506`, 0.9370266942889113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 18}], {
             RGBColor[
             0.23626969908513956`, 0.3656648124755939, 0.9367665818819775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 30}], {
             RGBColor[
             0.28064003551226024`, 0.4123008493023123, 0.9392934069014716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 31}], {
             RGBColor[
             0.23664479051198237`, 0.36605905734737576`, 0.9367879427838381]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 35}], {
             RGBColor[
             0.27203050028951276`, 0.4032516819071433, 0.938803106607202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 44}], {
             RGBColor[
             0.2513700816788449, 0.3815362720011326, 0.9376265263316749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 49}], {
             RGBColor[
             0.6314307622851459, 0.6732364575856349, 0.6479247107269863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 12}], {
             RGBColor[
             0.6050425856498047, 0.6364130616547397, 0.6314417157616283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 13}], {
             RGBColor[
             0.619773204014334, 0.6518958755310081, 0.6322806026854912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 16}], {
             RGBColor[
             0.5947048817653608, 0.625547479423906, 0.6308529988186716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 20}], {
             RGBColor[
             0.953567793288856, 0.8503992481055564, 0.29826525991182884`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 26}], {
             RGBColor[
             0.9712864609457399, 0.91480463188971, 0.3429537521814098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 27}], {
             RGBColor[
             0.663353456632243, 0.692975960911721, 0.6349354581562761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 28}], {
             RGBColor[
             0.5906752411212313, 0.6213120716129523, 0.6306235167453076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 29}], {
             RGBColor[
             0.6021378520586942, 0.6333600024797356, 0.6312762954807829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 32}], {
             RGBColor[
             0.676929001859836, 0.7047344158611193, 0.635800479893795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 34}], {
             RGBColor[
             0.6319742186372203, 0.6647199154886689, 0.6329754324184811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 37}], {
             RGBColor[
             0.5894625916069651, 0.6200375000870386, 0.6305544581494242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 38}], {
             RGBColor[
             0.7297684284294955, 0.7494323233793924, 0.639462714945193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 40}], {
             RGBColor[
             0.6794156995376481, 0.7068882684045807, 0.6359589300709247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 41}], {
             RGBColor[
             0.8920846615967853, 0.516983748798483, 0.24496909735427674`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 45}], {
             RGBColor[
             0.6428275112265734, 0.675197418665343, 0.6336275630654076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 46}], {
             RGBColor[
             0.6026798065815182, 0.633929631045125, 0.6313071589891077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 49}], {
             RGBColor[
             0.9707637936422864, 0.9130415523470428, 0.3409232884049315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 50}], {
             RGBColor[
             0.5827422086066397, 0.6129739514568042, 0.6301717422794715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 51}], {
             RGBColor[
             0.6564303562485516, 0.6869795193245103, 0.6344943243216845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 12}], {
             RGBColor[
             0.2426603120003026, 0.3723817518376916, 0.9371305178334315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 21}], {
             RGBColor[
             0.25529540461548494`, 0.38566203528739, 0.9378500676659216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 23}], {
             RGBColor[
             0.24129115844812132`, 0.370942684645, 0.937052546564116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 27}], {
             RGBColor[
             0.3009711829827409, 0.4289446510946729, 0.9406242602280792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 28}], {
             RGBColor[
             0.22829296747172917`, 0.3572807617959043, 0.9363123188171107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 32}], {
             RGBColor[
             0.3145467282103338, 0.44070310604407126`, 0.9414892819655981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 34}], {
             RGBColor[
             0.26959194498771816`, 0.40068860567162096`, 0.9386642344902842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 37}], {
             RGBColor[
             0.22708031795746292`, 0.35600619026999053`, 0.9362432602212274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 39}], {
             RGBColor[
             0.3376111642230023, 0.46068036126598394`, 0.9429589274332454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 45}], {
             RGBColor[
             0.28044523757707135`, 0.41116610884829496`, 0.9393163651372107]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 47}], {
             RGBColor[
             0.24478438509026074`, 0.3746142873292499, 0.9372514806536201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 49}], {
             RGBColor[
             0.6083815199927843, 0.6490102425299946, 0.6466120904767347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 11}], {
             RGBColor[
             0.22077976445055525`, 0.3493839090560654, 0.9358844530198427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 26}], {
             RGBColor[
             0.5967302001148604, 0.6379776896696658, 0.6479492636930335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 29}], {
             RGBColor[
             0.2275815912278149, 0.35653306025969145`, 0.9362718069924066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 36}], {
             RGBColor[
             0.21001589020242278`, 0.3380703947522333, 0.9352714663051365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 41}], {
             RGBColor[
             0.517528400765906, 0.24015680657843877`, 0.5499646088659005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 42}], {
             RGBColor[
             0.20883519525984648`, 0.3368294095072025, 0.9352042274748384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 43}], {
             RGBColor[
             0.20750950276114938`, 0.33543602263731276`, 0.9351287312482239]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 13}], {
             RGBColor[
             0.26871730980026776`, 0.39976930863453686`, 0.9386144253102657]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 16}], {
             RGBColor[
             0.24364898755129455`, 0.3734209125274347, 0.937186821443446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 38}], {
             RGBColor[
             0.3787125342154293, 0.4973057564829211, 0.9457965375699673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 41}], {
             RGBColor[
             0.541028767382719, 0.26485718190201163`, 0.5513029199790511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 46}], {
             RGBColor[
             0.25162391236745185`, 0.3818030641486537, 0.9376409816138822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 51}], {
             RGBColor[
             0.30537446203448526`, 0.43485295242803895`, 0.9408281469464589]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 22}], {
             RGBColor[
             0.21879565103739937`, 0.3472984800587824, 0.9357714606961962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 48}], {
             RGBColor[
             0.18043702837123554`, 0.306981135559497, 0.9335869938818551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 22}], {
             RGBColor[
             0.24124301472204857`, 0.37089208253640904`, 0.9370498048501383]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 26}], {
             RGBColor[
             0.5997721630336037, 0.6411749855688538, 0.6481224989810752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 29}], {
             RGBColor[
             0.2306235541465581, 0.3597303561588793, 0.9364450422804482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 36}], {
             RGBColor[
             0.21305785312116599`, 0.34126769065142126`, 0.935444701593178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 41}], {
             RGBColor[
             0.5205703636846493, 0.24335410247762665`, 0.5501378441539422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 42}], {
             RGBColor[
             0.21187715817858965`, 0.34002670540639046`, 0.9353774627628799]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 43}], {
             RGBColor[
             0.21055146567989258`, 0.3386333185365007, 0.9353019665362655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 20}], {
             RGBColor[
             0.59176005574509, 0.5869718121633303, 0.6039867809649037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 21}], {
             RGBColor[
             0.25586994072122116`, 0.3862659091622119, 0.9378827866471933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 24}], {
             RGBColor[
             0.2166698575567152, 0.34506413632749194`, 0.9356503999023009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 25}], {
             RGBColor[
             0.2115318852062022, 0.33966380162084037`, 0.9353577999778881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 27}], {
             RGBColor[
             0.3015457190884771, 0.42954852496949475`, 0.9406569792093509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 28}], {
             RGBColor[
             0.22886750357746538`, 0.35788463567072615`, 0.9363450377983824]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 32}], {
             RGBColor[
             0.31512126431607, 0.4413069799188931, 0.9415220009468698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 34}], {
             RGBColor[
             0.27016648109345437`, 0.4012924795464428, 0.9386969534715559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 37}], {
             RGBColor[
             0.22765485406319913`, 0.3566100641448124, 0.936275979202499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 38}], {
             RGBColor[
             0.36796069088572964`, 0.4860048874371662, 0.9451842359982678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 40}], {
             RGBColor[
             0.31760796199388225`, 0.4434608324623546, 0.9416804511239996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 45}], {
             RGBColor[
             0.28101977368280756`, 0.4117699827231168, 0.9393490841184824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 50}], {
             RGBColor[
             0.22093447106287384`, 0.34954651551457805`, 0.9358932633325463]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 16}], {
             RGBColor[
             0.24762776258612423`, 0.37760285735794824`, 0.9374134067956095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 20}], {
             RGBColor[
             0.6064906741096194, 0.6024546260395988, 0.6048256678887667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 24}], {
             RGBColor[
             0.23140047592124452`, 0.3605469502037604, 0.9364892868261638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 38}], {
             RGBColor[
             0.38269130925025896`, 0.5014877013134347, 0.9460231229221308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 40}], {
             RGBColor[
             0.3323385803584116, 0.45894364633862306`, 0.9425193380478625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 41}], {
             RGBColor[
             0.5450075424175487, 0.26903912673252517`, 0.5515295053312146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 46}], {
             RGBColor[
             0.25560268740228154`, 0.38598500897916727`, 0.9378675669660456]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 51}], {
             RGBColor[
             0.30935323706931495`, 0.4390348972585525, 0.9410547322986222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 17}], {
             RGBColor[
             0.3079161408784554, 0.42920560276136965`, 0.9412774843747963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 19}], {
             RGBColor[
             0.182314417911161, 0.3089543909993306, 0.933693908438805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 30}], {
             RGBColor[
             0.22647128782803633`, 0.3553660609892227, 0.936208576856336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 44}], {
             RGBColor[
             0.19720133399462103`, 0.324601483688043, 0.9345416962865392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 48}], {
             RGBColor[
             0.18089691092665647`, 0.30746450128348257`, 0.933613183513051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 18}], {
             RGBColor[
             0.18892263837484435`, 0.31590004969203866`, 0.9340702368182255]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 31}], {
             RGBColor[
             0.1892977298016872, 0.3162942945638205, 0.9340915977200862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 35}], {
             RGBColor[
             0.22468343957921755`, 0.35348691912358804`, 0.9361067615434502]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 36}], {
             RGBColor[
             0.19789205896586642`, 0.3253274794273145, 0.9345810320518155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 43}], {
             RGBColor[
             0.19538567152459302`, 0.3226931073123939, 0.934438296994903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 20}], {
             RGBColor[
             0.5814223518606462, 0.5761062299324966, 0.603398064021947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 24}], {
             RGBColor[
             0.2063321536722713, 0.3341985540966582, 0.9350616829593441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 25}], {
             RGBColor[
             0.20119418132175831`, 0.32879821939000664`, 0.9347690830349313]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 38}], {
             RGBColor[
             0.3576229870012857, 0.4751393052063325, 0.944595519055311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 40}], {
             RGBColor[
             0.30727025810943837`, 0.4325952502315209, 0.9410917341810427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 41}], {
             RGBColor[
             0.5199392201685755, 0.24269073062542304`, 0.5501019014643949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 46}], {
             RGBColor[
             0.23053436515330838`, 0.3596366128720651, 0.936439963099226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 50}], {
             RGBColor[
             0.21059676717842996`, 0.3386809332837444, 0.9353045463895896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 51}], {
             RGBColor[
             0.2842849148203418, 0.41268650115145034`, 0.9396271284318026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 19}], {
             RGBColor[
             0.3103837936787745, 0.4317992623127292, 0.9414180135512094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 22}], {
             RGBColor[
             0.3473249093604338, 0.4706267170961665, 0.9435217554397966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 30}], {
             RGBColor[
             0.35454066359564984`, 0.4782109323026213, 0.9439326819687404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 44}], {
             RGBColor[
             0.3252707097622345, 0.4474463550014416, 0.9422658013989436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 48}], {
             RGBColor[
             0.30896628669426995`, 0.4303093725968812, 0.9413372886254554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 49}], {
             RGBColor[
             0.7053313903685355, 0.7391465405859439, 0.6525639857942551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 31}], {
             RGBColor[
             0.18473022911783224`, 0.3114935617488193, 0.9338314853131524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 35}], {
             RGBColor[
             0.22011593889536263`, 0.34868618630858683`, 0.9358466491365163]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 30}], {
             RGBColor[
             0.22893894062835546`, 0.3579597205405822, 0.9363491060327489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 44}], {
             RGBColor[
             0.19966898679494013`, 0.32719514323940246`, 0.9346822254629522]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 26}], {
             RGBColor[
             0.9580039310410251, 0.8653633823983007, 0.3154988173846851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 27}], {
             RGBColor[
             0.6500709267275284, 0.6435347114203116, 0.6074805233595513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.5773927112165166, 0.5718708221215429, 0.603168581948583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 29}], {
             RGBColor[
             0.5888553221539795, 0.5839187529883263, 0.6038213606840581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 32}], {
             RGBColor[
             0.6636464719551213, 0.6552931663697099, 0.6083455450970703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 34}], {
             RGBColor[
             0.6186916887325056, 0.6152786659972597, 0.6055204976217563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 37}], {
             RGBColor[
             0.5761800617022503, 0.5705962505956292, 0.6030995233526997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 38}], {
             RGBColor[
             0.7164858985247808, 0.6999910738879831, 0.6120077801484682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 40}], {
             RGBColor[
             0.6661331696329335, 0.6574470189131715, 0.6085039952742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 41}], {
             RGBColor[
             0.8788021316920707, 0.4675424993070736, 0.21751416255755213`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 45}], {
             RGBColor[
             0.6295449813218588, 0.6257561691739337, 0.606172628268683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 46}], {
             RGBColor[
             0.5893972766768035, 0.5844883815537156, 0.6038522241923832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 49}], {
             RGBColor[
             0.9574812637375718, 0.8636003028556334, 0.3134683536082069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 50}], {
             RGBColor[
             0.569459678701925, 0.5635327019653948, 0.6027168074827469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 51}], {
             RGBColor[
             0.6431478263438369, 0.6375382698331009, 0.60703938952496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 23}], {
             RGBColor[
             0.2545007871690399, 0.3848268419695203, 0.9378048153778777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 27}], {
             RGBColor[
             0.3141808117036594, 0.44282880841919314`, 0.941376529041841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 28}], {
             RGBColor[
             0.2415025961926477, 0.37116491912042454`, 0.9370645876308725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 32}], {
             RGBColor[
             0.3277563569312524, 0.4545872633685915, 0.94224155077936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 34}], {
             RGBColor[
             0.2828015737086367, 0.4145727629961412, 0.939416503304046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 37}], {
             RGBColor[
             0.24028994667838147`, 0.3698903475945108, 0.9369955290349893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 39}], {
             RGBColor[
             0.3508207929439209, 0.4745645185905042, 0.9437111962470073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 45}], {
             RGBColor[
             0.29365486629798987`, 0.42505026617281527`, 0.9400686339509726]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 47}], {
             RGBColor[
             0.25799401381117926`, 0.38849844465377015`, 0.9380037494673819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 49}], {
             RGBColor[
             0.6215911487137029, 0.6628943998545149, 0.6473643592904965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 42}], {
             RGBColor[
             0.22929844553133982`, 0.35833758298754614`, 0.9363695793051341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.22030567940863488`, 0.34888561561827935`, 0.9358574545780514]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 27}], {
             RGBColor[
             0.30017656553629585`, 0.42810945777680315`, 0.9405790079400352]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 32}], {
             RGBColor[
             0.31375211076388876`, 0.4398679127262015, 0.9414440296775541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 33}], {
             RGBColor[
             0.2143951723911135, 0.3426732979950751, 0.935520859947215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 34}], {
             RGBColor[
             0.26879732754127306`, 0.3998534123537512, 0.9386189822022403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 39}], {
             RGBColor[
             0.33681654677655726`, 0.4598451679481142, 0.9429136751452014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 45}], {
             RGBColor[
             0.27965062013062625`, 0.4103309155304252, 0.9392711128491669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 47}], {
             RGBColor[
             0.24398976764381566`, 0.37377909401138015`, 0.9372062283655762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 49}], {
             RGBColor[
             0.6075869025463392, 0.648175049212125, 0.6465668381886908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 25}], {
             RGBColor[
             0.18496689465687857`, 0.31174231223581883`, 0.9338449630654858]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 28}], {
             RGBColor[
             0.20230251302814176`, 0.3299631462857046, 0.9348322008859802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 37}], {
             RGBColor[
             0.20108986351387553`, 0.32868857475979085`, 0.9347631422900968]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 38}], {
             RGBColor[
             0.341395700336406, 0.45808339805214465`, 0.9436713990858655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 40}], {
             RGBColor[
             0.2910429714445586, 0.4155393430773331, 0.9401676142115972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 46}], {
             RGBColor[
             0.21430707848842864`, 0.34258070571787724`, 0.9355158431297803]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 50}], {
             RGBColor[
             0.1943694805135502, 0.3216250261295565, 0.9343804264201441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 51}], {
             RGBColor[
             0.2680576281554621, 0.3956305939972625, 0.9387030084623571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 28}], {
             RGBColor[
             0.19716454067762873`, 0.32456281157905303`, 0.9345396009615674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 37}], {
             RGBColor[
             0.1959518911633625, 0.3232882400531393, 0.934470542365684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 38}], {
             RGBColor[
             0.336257727985893, 0.4526830633454931, 0.9433787991614527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 40}], {
             RGBColor[
             0.2859049990940456, 0.4101390083706815, 0.9398750142871845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 46}], {
             RGBColor[
             0.20916910613791562`, 0.33718037101122567`, 0.9352232432053675]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 50}], {
             RGBColor[
             0.1892315081630372, 0.31622469142290494`, 0.9340878264957313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 29}], {
             RGBColor[
             0.6065739898108634, 0.6483241367724797, 0.648509852953639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 32}], {
             RGBColor[
             0.6813651396120051, 0.7196985501538634, 0.6530340373666512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 36}], {
             RGBColor[
             0.5890082887854713, 0.6298614712650217, 0.647509512266369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 38}], {
             RGBColor[
             0.7342045661816647, 0.7643964576721365, 0.6566962724180492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 40}], {
             RGBColor[
             0.6838518372898174, 0.721852402697325, 0.6531924875437809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 41}], {
             RGBColor[
             0.8965207993489546, 0.531947883091227, 0.262202654827133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 43}], {
             RGBColor[
             0.5865019013441979, 0.627227099150101, 0.6473667772094565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 49}], {
             RGBColor[
             0.9751999313944556, 0.9280056866397868, 0.3581568458777878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 51}], {
             RGBColor[
             0.6608664940007207, 0.7019436536172543, 0.6517278817945408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 28}], {
             RGBColor[
             0.2871783745599037, 0.4144475349277074, 0.9398387801930301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 32}], {
             RGBColor[
             0.3734321352985083, 0.4978698791758744, 0.9450157433415174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 34}], {
             RGBColor[
             0.3284773520758927, 0.4578553788034241, 0.9421906958662035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 37}], {
             RGBColor[
             0.28596572504563744`, 0.41317296340179366`, 0.9397697215971468]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 38}], {
             RGBColor[
             0.42627156186816795`, 0.5425677866941474, 0.9486779783929155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 39}], {
             RGBColor[
             0.3964965713111768, 0.5178471343977871, 0.9464853888091647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 40}], {
             RGBColor[
             0.37591883297632056`, 0.5000237317193359, 0.9451741935186472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 45}], {
             RGBColor[
             0.3393306446652459, 0.46833288198009815`, 0.9428428265131301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 47}], {
             RGBColor[
             0.30366979217843526`, 0.431781060461053, 0.9407779420295395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 49}], {
             RGBColor[
             0.6672669270809588, 0.7061770156617978, 0.650138551852654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 50}], {
             RGBColor[
             0.27924534204531215`, 0.4061094147715593, 0.939387005727194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 32}], {
             RGBColor[
             0.30075391978749655`, 0.4262059898771058, 0.940703801930549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 34}], {
             RGBColor[
             0.2557991365648809, 0.3861914895046555, 0.9378787544552352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 37}], {
             RGBColor[
             0.2132875095346257, 0.34150907410302506`, 0.9354577801861783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 38}], {
             RGBColor[
             0.35359334635715617`, 0.47090389739537886`, 0.9443660369819471]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 40}], {
             RGBColor[
             0.3032406174653088, 0.4283598424205673, 0.9408622521076788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 45}], {
             RGBColor[
             0.2666524291542341, 0.3966689926813295, 0.9385308851021616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 50}], {
             RGBColor[
             0.20656712653430037`, 0.3344455254727907, 0.9350750643162256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 36}], {
             RGBColor[
             0.21985967989842564`, 0.3484168418550473, 0.935832055565742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 41}], {
             RGBColor[
             0.5273721904619089, 0.2505032536812527, 0.550525198126506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 42}], {
             RGBColor[
             0.21867898495584934`, 0.3471758566100165, 0.935764816735444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 43}], {
             RGBColor[
             0.21735329245715224`, 0.3457824697401267, 0.9356893205088295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 35}], {
             RGBColor[
             0.2644862753224833, 0.3953222231353053, 0.9383734741560104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 44}], {
             RGBColor[
             0.24382585671181548`, 0.37360681322929457`, 0.9371968938804832]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 49}], {
             RGBColor[
             0.6238865373181165, 0.665306998813797, 0.6474950782757947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 35}], {
             RGBColor[
             0.22049103032220543`, 0.3490804311803687, 0.9358680100383769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 34}], {
             RGBColor[
             0.34205289730348554`, 0.46961383375282245`, 0.9430557176037224]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 37}], {
             RGBColor[
             0.29954127027323035`, 0.424931418351192, 0.9406347433346658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 38}], {
             RGBColor[
             0.4398471070957608, 0.5543262416435458, 0.9495430001304344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 39}], {
             RGBColor[
             0.41007211653876974`, 0.5296055893471854, 0.9473504105466837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 40}], {
             RGBColor[
             0.3894943782039134, 0.5117821866687342, 0.9460392152561661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 41}], {
             RGBColor[
             0.6021633402630506, 0.3218776670626364, 0.5550493825395182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 45}], {
             RGBColor[
             0.35290618989283873`, 0.48009133692949646`, 0.9437078482506491]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 47}], {
             RGBColor[
             0.3172453374060281, 0.4435395154104514, 0.9416429637670584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 49}], {
             RGBColor[
             0.6808424723085518, 0.7179354706111962, 0.6510035735901729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 50}], {
             RGBColor[
             0.292820887272905, 0.4178678697209577, 0.9402520274647129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 39}], {
             RGBColor[
             0.3107151781659945, 0.43241097461605904`, 0.9414272408163444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 47}], {
             RGBColor[
             0.2178883990332529, 0.346344900679325, 0.9357197940367192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 37}], {
             RGBColor[
             0.2545864870506147, 0.3849169179787417, 0.9378096958593518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 38}], {
             RGBColor[
             0.39489232387314516`, 0.5143117412710956, 0.9467179526551205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 39}], {
             RGBColor[
             0.36511733331615404`, 0.48959108897473513`, 0.9445253630713697]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 40}], {
             RGBColor[
             0.34453959498129777`, 0.47176768629628396`, 0.9432141677808522]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 45}], {
             RGBColor[
             0.3079514066702231, 0.4400768365570462, 0.9408828007753351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 47}], {
             RGBColor[
             0.27229055418341247`, 0.4035250150380011, 0.9388179162917445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 49}], {
             RGBColor[
             0.635887689085936, 0.6779209702387459, 0.648178526114859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 50}], {
             RGBColor[
             0.24786610405028936`, 0.3778533693485074, 0.9374269799893991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 44}], {
             RGBColor[
             0.235216321489068, 0.36455764583412553`, 0.9367065935862138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 43}], {
             RGBColor[
             0.19978759143176011`, 0.3273198042326686, 0.9346889798215593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 38}], {
             RGBColor[
             0.35238069684289, 0.4696293258694651, 0.9442969783860637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 40}], {
             RGBColor[
             0.3020279679510426, 0.42708527089465353`, 0.9407931935117955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 45}], {
             RGBColor[
             0.2654397796399679, 0.3953944211554158, 0.9384618265062784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 50}], {
             RGBColor[
             0.20535447702003415`, 0.33317095394687696`, 0.9350060057203422]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 40}], {
             RGBColor[
             0.44233380477357304`, 0.5564800941870074, 0.9497014503075641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 41}], {
             RGBColor[
             0.6550027668327102, 0.36657557458090945`, 0.5587116175909161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 45}], {
             RGBColor[
             0.40574561646249835`, 0.5247892444477695, 0.9473700833020471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 46}], {
             RGBColor[
             0.36559791181744306`, 0.48352145682755154`, 0.9450496792257472]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 50}], {
             RGBColor[
             0.3456603138425646, 0.46256577723923076`, 0.943914262516111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 51}], {
             RGBColor[
             0.41934846148447646`, 0.5365713451069367, 0.948236844558324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 45}], {
             RGBColor[
             0.3759706259055072, 0.5000685921514092, 0.9451774937182964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 47}], {
             RGBColor[
             0.3403097734186966, 0.4635167706323641, 0.9431126092347056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 49}], {
             RGBColor[
             0.7039069083212202, 0.7379127258331089, 0.6524732190578202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 41}], {
             RGBColor[
             0.6046500379408628, 0.3240315196060979, 0.5552078327166479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 45}], {
             RGBColor[
             0.35539288757065096`, 0.482245189472958, 0.9438662984277788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 46}], {
             RGBColor[
             0.31524518292559567`, 0.4409774018527399, 0.941545894351479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 50}], {
             RGBColor[
             0.29530758495071724`, 0.4200217222644192, 0.9404104776418427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 51}], {
             RGBColor[
             0.3689957325926291, 0.4940272901321252, 0.9447330596840557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 46}], {
             RGBColor[
             0.5279141449847329, 0.25107288224664204`, 0.5505560616348311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 49}], {
             RGBColor[
             0.895998132045501, 0.5301848035485598, 0.26017219105065476`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 51}], {
             RGBColor[
             0.5816646946517663, 0.3041227705260273, 0.5537432269674077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 47}], {
             RGBColor[
             0.28314384677276566`, 0.41400251821467515`, 0.939470046938671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 49}], {
             RGBColor[
             0.6467409816752892, 0.6883984734154199, 0.6488306567617856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 50}], {
             RGBColor[
             0.25871939663964255`, 0.3883308725251814, 0.9380791106363255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 51}], {
             RGBColor[
             0.2922598396364991, 0.42106865277266936`, 0.9400812886022387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 49}], {
             RGBColor[
             0.6110801291884786, 0.6518466518963748, 0.646765772278195]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.0881122714338556], {
             RGBColor[
             0.8728647499811615, 0.5155903475040444, 0.2156275698251868]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.0881122714338556], {
             RGBColor[
             0.19749930194547893`, 0.3249146668966539, 0.9345586651205365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.0881122714338556], {
             RGBColor[
             0.8351525980362119, 0.8713920283334502, 0.9841387944218613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.0881122714338556], {
             RGBColor[
             0.21334910871660218`, 0.34157381874889603`, 0.9354612881684641]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.0881122714338556], {
             RGBColor[
             0.2881842604792897, 0.4202303080741503, 0.9397230393526632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.0881122714338556], {
             RGBColor[
             0.9668503231935707, 0.8998404975969658, 0.3257201947085535]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.0881122714338556], {
             RGBColor[
             0.2420857758945664, 0.37177787796286976`, 0.9370977988521598]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.0881122714338556], {
             RGBColor[
             0.21773780153181205`, 0.34618661315687754`, 0.9357112177318011]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.0881122714338556], {
             RGBColor[
             0.26473853476543807`, 0.39558736380402326`, 0.9383878399581023]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.0881122714338556], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.0881122714338556], {
             RGBColor[
             0.22382172736929842`, 0.3525812049552533, 0.9360576883078843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.0881122714338556], {
             RGBColor[
             0.24323484810603882`, 0.3729856257125135, 0.9371632368147031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.0881122714338556], {
             RGBColor[
             0.27269608483509744`, 0.4039512534650504, 0.9388410106624291]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.0881122714338556], {
             RGBColor[
             0.17984676511084188`, 0.30636073144797105`, 0.9335533792623919]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.0881122714338556], {
             RGBColor[
             0.1934901390586993, 0.3207007825070398, 0.9343303492251593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.0881122714338556], {
             RGBColor[
             0.22255944033715105`, 0.3512544612508461, 0.9359858029287897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.0881122714338556], {
             RGBColor[
             0.4359855166460689, 0.5520504740747683, 0.9490015894872007]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.0881122714338556], {
             RGBColor[
             0.18435513769098943`, 0.31109931687703746`, 0.9338101244112917]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.0881122714338556], {
             RGBColor[
             0.18478207071148012`, 0.3115480505506901, 0.9338344376152179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.0881122714338556], {
             RGBColor[
             0.9402852633841413, 0.8009579986141472, 0.2708103251151042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.0881122714338556], {
             RGBColor[
             0.26850503333640346`, 0.39954619261191027`, 0.9386023364796835]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.0881122714338556], {
             RGBColor[
             0.25866430207479874`, 0.3892029601175647, 0.9380419213923924]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.0881122714338556], {
             RGBColor[
             0.24049654100167628`, 0.3701074913271303, 0.937007294276072]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.0881122714338556], {
             RGBColor[
             0.1901048670073916, 0.3171426469424704, 0.9341375629898986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.0881122714338556], {
             RGBColor[
             0.17982892230636555`, 0.30634197752916725`, 0.933552363141073]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.0881122714338556], {
             RGBColor[
             0.975722598697909, 0.9297687661824541, 0.36018730965426604`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.0881122714338556], {
             RGBColor[
             0.3598565900709154, 0.486111424226476, 0.9441507216039985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.0881122714338556], {
             RGBColor[
             0.21450015904889191`, 0.3427836456289388, 0.9355268387820617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.0881122714338556], {
             RGBColor[
             0.23742538092381776`, 0.36687950736250535`, 0.9368323962530122]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.0881122714338556], {
             RGBColor[
             0.2730958105452308, 0.40437139053047433`, 0.9388637744502799]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.0881122714338556], {
             RGBColor[
             0.18510532054467504`, 0.31188780662060117`, 0.9338528462150131]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.0881122714338556], {
             RGBColor[
             0.38700768052610124`, 0.5096283341252728, 0.9458807650790364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.0881122714338556], {
             RGBColor[
             0.18829380378055074`, 0.31523910466301996`, 0.934034425618358]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.0881122714338556], {
             RGBColor[
             0.2970981140808699, 0.42959933338037215`, 0.9402306701284086]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.0881122714338556], {
             RGBColor[
             0.2558767400997358, 0.38627305574013626`, 0.9378831738617409]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.0881122714338556], {
             RGBColor[
             0.20229397887303355`, 0.32995417634758917`, 0.9348317148784718]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.0881122714338556], {
             RGBColor[
             0.21207486002035947`, 0.3402345025771113, 0.9353887215902951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.0881122714338556], {
             RGBColor[
             0.4926865336654204, 0.5990241491618189, 0.9532052351818324]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.0881122714338556], {
             RGBColor[
             0.43313655255143824`, 0.5495828445690981, 0.948820056014331]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.0881122714338556], {
             RGBColor[
             0.39198107588172565`, 0.5139360392121958, 0.9461976654332959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.0881122714338556], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.0881122714338556], {
             RGBColor[
             0.1999325889878809, 0.32747220585752757`, 0.9346972372178757]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.0881122714338556], {
             RGBColor[
             0.1972812039904867, 0.32468543211774803`, 0.9345462447646468]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.0881122714338556], {
             RGBColor[
             0.21455590287840015`, 0.34284223592811486`, 0.9355300133106865]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.0881122714338556], {
             RGBColor[
             0.3188046992595763, 0.4505543397337202, 0.9415349314222617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.0881122714338556], {
             RGBColor[
             0.2385092899694657, 0.36801876449328413`, 0.936894123269662]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.0881122714338556], {
             RGBColor[
             0.24748299428595505`, 0.37745069669563003`, 0.9374051624550803]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.0881122714338556], {
             RGBColor[
             0.18194705674247105`, 0.30856827111899404`, 0.9336729877637102]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.0881122714338556], {
             RGBColor[
             0.9746772640910022, 0.9262426070971196, 0.35612638210130954`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.0881122714338556], {
             RGBColor[
             0.19863409401970883`, 0.3261074053166426, 0.9346232898503894]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.0881122714338556], {
             RGBColor[
             0.3460103893035325, 0.47411854105205464`, 0.9432684539348155]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> Medium, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
          52}, {Null, CompressedData["
1:eJwVxduVoyAAANAICkTUGExURHy/0AkqUsmWMA1stdPP7H7cc9vvv3++we12
+/nn/+/P6/36oL2d8inXq87WTHs6u9ZLX0jKHSIo4e60zuRcjzwbx3W8oFqU
NzhBkAdtMEGMMF6w8rpu6LRTBmXZllN5eT3qZe/VdVcPkCGGGZOsZ4rtXhTV
URcN0RKpqKmbpmsGaJDBhhlplNlNfTZndw6nEwdxnMV5XMZtPMU6viBFFFPK
qKQ9VXSnxtniLdvKrd3GbbvSLB3TNd1SnV7QRz72feozX/q7bx7Vq3pXeVV9
XORKt3e/XvN7ntf5ExVFUwzFUqj7fF9d4QkkRCd6sQrtJl6CkkQkXdInX8np
8Yjzggte84Z3fOALV1xDgggmxCeUMCJJT3ZiHs9n/qw8e7epzaywo53tarW9
7P1Ij+wQx3jMx3ocFodhFPKwCJdQAQgQwIAAH1DAgAQ9UGAH5hcMpy2o
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[14, 25] -> 
             RGBColor[
              0.3866479366669813, 0.49718893571584577`, 0.9470182950532346], 
             UndirectedEdge[23, 51] -> 
             RGBColor[
              0.22762215015044834`, 0.3565756902589634, 0.9362741167630491], 
             UndirectedEdge[28, 38] -> 
             RGBColor[
              0.19329689770374764`, 0.3204976735907761, 0.9343193444158698], 
             UndirectedEdge[37, 42] -> 
             RGBColor[
              0.24104517528474395`, 0.37068414074405703`, 0.9370385381868611],
              UndirectedEdge[12, 33] -> 
             RGBColor[
              0.18657023813216803`, 0.3134275278861959, 0.9339362711044694], 
             UndirectedEdge[12, 38] -> 
             RGBColor[
              0.1961670450492758, 0.3235143804287784, 0.9344827950611951], 
             UndirectedEdge[15, 17] -> 
             RGBColor[
              0.182288500478672, 0.30892715013452454`, 0.9336924324793661], 
             UndirectedEdge[37, 51] -> 
             RGBColor[
              0.21694733128173688`, 0.34535577880533996`, 0.9356662016204553],
              UndirectedEdge[6, 47] -> 
             RGBColor[
              0.29702734550211585`, 0.4196892369243038, 0.940586773640577], 
             UndirectedEdge[13, 41] -> 
             RGBColor[
              0.20132993964857746`, 0.32894090999906866`, 0.9347768142708073],
              UndirectedEdge[33, 43] -> 
             RGBColor[
              0.1825740312257846, 0.30922726105343484`, 0.9337086930330092], 
             UndirectedEdge[6, 29] -> 
             RGBColor[
              0.30417850872149055`, 0.4272055628778024, 0.9409940218067224], 
             UndirectedEdge[18, 35] -> 
             RGBColor[
              0.4205403167500906, 0.5304096391650818, 0.9491670916081261], 
             UndirectedEdge[7, 18] -> 
             RGBColor[
              0.2367743194356843, 0.36619520045879456`, 0.9367953192644222], 
             UndirectedEdge[2, 11] -> 
             RGBColor[
              0.2749133425176671, 0.4054685103665695, 0.938997056230279], 
             UndirectedEdge[31, 49] -> 
             RGBColor[
              0.19480101661556698`, 0.32207859793374527`, 0.9344050017627534],
              UndirectedEdge[16, 24] -> 
             RGBColor[
              0.4021275946665424, 0.5227244438047416, 0.9468441926380502], 
             UndirectedEdge[6, 19] -> 
             RGBColor[
              0.37681081696902774`, 0.5007963234213999, 0.945231029949912], 
             UndirectedEdge[7, 10] -> 
             RGBColor[
              0.20325460595593606`, 0.3309638563189946, 0.9348864211697228], 
             UndirectedEdge[14, 34] -> 
             RGBColor[
              0.3243526215968536, 0.4462207249266307, 0.9422230617196314], 
             UndirectedEdge[1, 28] -> 
             RGBColor[
              0.185655888788547, 0.31246648875295346`, 0.9338842002620089], 
             UndirectedEdge[27, 35] -> 
             RGBColor[
              0.7003996546835172, 0.4034308132446863, 0.5622854268968113], 
             UndirectedEdge[1, 38] -> 
             RGBColor[
              0.19440127656290068`, 0.32165844579340985`, 0.9343822371581165],
              UndirectedEdge[3, 10] -> 
             RGBColor[
              0.19924783588626271`, 0.32675248693187264`, 0.9346582415417399],
              UndirectedEdge[46, 51] -> 
             RGBColor[
              0.6067166467229718, 0.6489634157684627, 0.6493246000577031], 
             UndirectedEdge[2, 47] -> 
             RGBColor[
              0.20560599823409068`, 0.3334353186902164, 0.9350203294813906], 
             UndirectedEdge[23, 48] -> 
             RGBColor[
              0.24972004109485973`, 0.37980197472874866`, 0.9375325589614332],
              UndirectedEdge[17, 24] -> 
             RGBColor[
              0.3127982196910958, 0.4336092941005443, 0.9415821555813275], 
             UndirectedEdge[28, 33] -> 
             RGBColor[
              0.18370009078663985`, 0.3104108210481935, 0.9337728204591441], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.27162391387018325`, 0.39804864659686334`, 0.9389548134149506],
              UndirectedEdge[28, 51] -> 
             RGBColor[
              0.21092037821438597`, 0.33902106900065887`, 0.9353229755593477],
              UndirectedEdge[19, 34] -> 
             RGBColor[
              0.38864936710728426`, 0.5110502805283267, 0.9459853718963029], 
             UndirectedEdge[48, 52] -> 
             RGBColor[
              0.3001129642628795, 0.4318440352657169, 0.9404361970971618], 
             UndirectedEdge[7, 11] -> 
             RGBColor[
              0.2667450016526872, 0.3968830662147522, 0.9385318813019958], 
             UndirectedEdge[7, 50] -> 
             RGBColor[
              0.19934302156568184`, 0.32685253311606277`, 0.9346636622253683],
              UndirectedEdge[34, 49] -> 
             RGBColor[
              0.314507250958174, 0.435872616152826, 0.9416623824266793], 
             UndirectedEdge[34, 46] -> 
             RGBColor[
              0.7074744191136552, 0.7428413990741942, 0.6555028938452043], 
             UndirectedEdge[9, 48] -> 
             RGBColor[
              0.23087503757553873`, 0.35999468118770833`, 0.9364593638896923],
              UndirectedEdge[8, 10] -> 
             RGBColor[
              0.19595963786847198`, 0.3232963823313788, 0.9344709835290799], 
             UndirectedEdge[46, 52] -> 
             RGBColor[
              0.6474424735420619, 0.6908447451133962, 0.6516777113575476], 
             UndirectedEdge[14, 41] -> 
             RGBColor[
              0.21002451320353643`, 0.33807945807313367`, 0.9352719573722934],
              UndirectedEdge[31, 36] -> 
             RGBColor[
              0.22437339812400123`, 0.3531610458963921, 0.9360891051412408], 
             UndirectedEdge[26, 41] -> 
             RGBColor[
              0.1986818293468101, 0.3261575781720206, 0.9346260083066498], 
             UndirectedEdge[37, 52] -> 
             RGBColor[
              0.25767315810082697`, 0.38723710815027357`, 0.9380193129202997],
              UndirectedEdge[13, 25] -> 
             RGBColor[
              0.3779533631120223, 0.48805038764178077`, 0.9465231519517487], 
             UndirectedEdge[16, 38] -> 
             RGBColor[
              0.281220720787291, 0.4081354991394459, 0.9395013373716763], 
             UndirectedEdge[37, 43] -> 
             RGBColor[
              0.1894524034358896, 0.31645686636024206`, 0.9341004061547349], 
             UndirectedEdge[22, 48] -> 
             RGBColor[
              0.24562092568417937`, 0.3754935445331955, 0.9372991204028929], 
             UndirectedEdge[10, 18] -> 
             RGBColor[
              0.22408061065339868`, 0.35285330770099094`, 0.9360724313279303],
              UndirectedEdge[3, 11] -> 
             RGBColor[
              0.2627382315830139, 0.39267169682763026`, 0.938303701674013], 
             UndirectedEdge[6, 11] -> 
             RGBColor[
              0.3663346897856923, 0.4917224286006569, 0.9445635003894655], 
             UndirectedEdge[26, 40] -> 
             RGBColor[
              0.19395856680791052`, 0.3211931297714955, 0.9343570254925002], 
             UndirectedEdge[24, 46] -> 
             RGBColor[
              0.7100000400915849, 0.7450289650238755, 0.6556638241805991], 
             UndirectedEdge[10, 29] -> 
             RGBColor[
              0.1918951118061999, 0.3190243077340941, 0.9342395147827609], 
             UndirectedEdge[23, 43] -> 
             RGBColor[
              0.20012722230460106`, 0.3276767778138655, 0.9347083212973287], 
             UndirectedEdge[2, 10] -> 
             RGBColor[
              0.2114229468209159, 0.3395493004708119, 0.9353515960980059], 
             UndirectedEdge[23, 37] -> 
             RGBColor[
              0.2072802349328072, 0.33519504761330526`, 0.9351156747845712], 
             UndirectedEdge[24, 30] -> 
             RGBColor[
              0.31761214173428154`, 0.4386690313882188, 0.9418563013201274], 
             UndirectedEdge[39, 45] -> 
             RGBColor[
              0.19540264547778247`, 0.32271094801340683`, 0.9344392636364265],
              UndirectedEdge[2, 3] -> 
             RGBColor[
              0.22010988553352817`, 0.34867982384149354`, 0.9358463044065151],
              UndirectedEdge[3, 7] -> 
             RGBColor[
              0.21194154466854834`, 0.34009437968967626`, 0.9353811294782319],
              UndirectedEdge[16, 28] -> 
             RGBColor[
              0.2724753330129373, 0.39894354209898947`, 0.9390033004755687], 
             UndirectedEdge[13, 40] -> 
             RGBColor[
              0.19660667710967789`, 0.32397646159854354`, 0.9345078314566577],
              UndirectedEdge[5, 19] -> 
             RGBColor[
              0.6644321472622069, 0.7289470400766473, 0.8760206188506094], 
             UndirectedEdge[27, 42] -> 
             RGBColor[
              0.5514019672526961, 0.2757600726642161, 0.5518936583658723], 
             UndirectedEdge[2, 50] -> 
             RGBColor[
              0.20751136243066168`, 0.33543797726788005`, 0.9351288371536515],
              UndirectedEdge[19, 49] -> 
             RGBColor[
              0.26435182678471353`, 0.3924305086186915, 0.9384665231490465], 
             UndirectedEdge[27, 52] -> 
             RGBColor[
              0.5680299500687791, 0.29231304007043263`, 0.5528744330993111], 
             UndirectedEdge[22, 23] -> 
             RGBColor[
              0.21385593839083833`, 0.3421065288713756, 0.9354901513686246], 
             UndirectedEdge[36, 49] -> 
             RGBColor[
              0.21978209214403752`, 0.3483352922058376, 0.9358276370579104], 
             UndirectedEdge[6, 35] -> 
             RGBColor[
              0.49930400018563303`, 0.6033595501689901, 0.9540127005373882], 
             UndirectedEdge[3, 8] -> 
             RGBColor[
              0.20464657658108426`, 0.33242690570206046`, 0.9349656918375889],
              UndirectedEdge[11, 50] -> 
             RGBColor[
              0.25013970848014744`, 0.37942985025401677`, 0.9375862344211495],
              UndirectedEdge[23, 42] -> 
             RGBColor[
              0.2517199941534554, 0.3819040521976805, 0.9376464533294548], 
             UndirectedEdge[39, 52] -> 
             RGBColor[
              0.2627347960538517, 0.3925572105652846, 0.9383075657137021], 
             UndirectedEdge[29, 35] -> 
             RGBColor[
              0.38835481790289184`, 0.49658063919818496`, 0.9473341750629567],
              UndirectedEdge[18, 29] -> 
             RGBColor[
              0.22541482528594814`, 0.3542556518738941, 0.9361484128774603], 
             UndirectedEdge[22, 37] -> 
             RGBColor[
              0.20318111952212686`, 0.33088661741775216`, 0.9348822362260307],
              UndirectedEdge[25, 26] -> 
             RGBColor[
              0.37530525281025495`, 0.48526705581473273`, 0.9463723459875912],
              UndirectedEdge[25, 32] -> 
             RGBColor[
              0.37366154770399673`, 0.48353941753113233`, 0.9462787394134335],
              UndirectedEdge[2, 6] -> 
             RGBColor[
              0.32370634373620655`, 0.44773055561452024`, 0.9421061031219675],
              UndirectedEdge[18, 47] -> 
             RGBColor[
              0.21826366206657347`, 0.34673932592039547`, 0.9357411647113149],
              UndirectedEdge[30, 45] -> 
             RGBColor[
              0.18772242460868935`, 0.31463854892586174`, 0.9340018864198002],
              UndirectedEdge[3, 18] -> 
             RGBColor[
              0.23276754936601096`, 0.3619838310716726, 0.9365671396364394], 
             UndirectedEdge[7, 8] -> 
             RGBColor[
              0.2086533466507576, 0.3366382750891824, 0.9351938714655716], 
             UndirectedEdge[3, 47] -> 
             RGBColor[
              0.1934308872994375, 0.3206385051512771, 0.9343269749251246], 
             UndirectedEdge[18, 50] -> 
             RGBColor[
              0.22016902626314447`, 0.3487419844980591, 0.9358496723835759], 
             UndirectedEdge[16, 51] -> 
             RGBColor[
              0.2988442012979293, 0.4266588945493287, 0.9405049685151542], 
             UndirectedEdge[6, 10] -> 
             RGBColor[
              0.3028442940889411, 0.4258032187048993, 0.9409180402571924], 
             UndirectedEdge[25, 31] -> 
             RGBColor[
              0.38139387200826547`, 0.4916665806325956, 0.9467190838436129], 
             UndirectedEdge[2, 35] -> 
             RGBColor[
              0.40788265291760784`, 0.5171056319349028, 0.9484462563782018], 
             UndirectedEdge[47, 50] -> 
             RGBColor[
              0.180832364196571, 0.30739665857766363`, 0.933609507672261], 
             UndirectedEdge[12, 28] -> 
             RGBColor[
              0.1874216572749221, 0.31432242338832195`, 0.9339847581650875], 
             UndirectedEdge[5, 36] -> 
             RGBColor[
              0.6198624126215309, 0.6848518236637934, 0.8733817327594733], 
             UndirectedEdge[39, 48] -> 
             RGBColor[
              0.244106860179173, 0.37390216569013623`, 0.9372128966122419], 
             UndirectedEdge[42, 48] -> 
             RGBColor[
              0.28348498144679646`, 0.41529106785950043`, 0.939455422363723], 
             UndirectedEdge[4, 29] -> 
             RGBColor[
              0.2335834203947198, 0.3628413632520565, 0.9366136022845513], 
             UndirectedEdge[20, 39] -> 
             RGBColor[
              0.19815399504508646`, 0.32560279085428145`, 0.9345959489240275],
              UndirectedEdge[12, 24] -> 
             RGBColor[
              0.3170739189285272, 0.4381033250940741, 0.941825650327569], 
             UndirectedEdge[5, 14] -> 
             RGBColor[
              0.6001354017517762, 0.6641174844749513, 0.872258308673938], 
             UndirectedEdge[5, 31] -> 
             RGBColor[
              0.5948813370930603, 0.6585951293917012, 0.8719590974643163], 
             UndirectedEdge[14, 36] -> 
             RGBColor[
              0.22962746278271706`, 0.35868340097964224`, 0.9363883163508626],
              UndirectedEdge[51, 52] -> 
             RGBColor[
              0.27801507331846814`, 0.4086177507959317, 0.9391777548987776], 
             UndirectedEdge[1, 16] -> 
             RGBColor[
              0.27357971187209035`, 0.4001043143016233, 0.9390661932178154], 
             UndirectedEdge[23, 46] -> 
             RGBColor[
              0.5970495503740421, 0.6388026845764279, 0.648774073221819], 
             UndirectedEdge[5, 35] -> 
             RGBColor[
              0.7869253304788122, 0.8315102668242376, 0.8848022894380856], 
             UndirectedEdge[22, 43] -> 
             RGBColor[
              0.1960281068939207, 0.32336834761831235`, 0.9344748827387883], 
             UndirectedEdge[6, 27] -> 
             RGBColor[
              0.6162233455021159, 0.3340557369243038, 0.555945273640577], 
             UndirectedEdge[28, 43] -> 
             RGBColor[
              0.1834254503685387, 0.31012215655556097`, 0.9337571800936273], 
             UndirectedEdge[37, 48] -> 
             RGBColor[
              0.23904522222614827`, 0.3685820632751252, 0.9369246438188394], 
             UndirectedEdge[21, 30] -> 
             RGBColor[
              0.18975303358403067`, 0.31677284770699066`, 0.934117526596929], 
             UndirectedEdge[11, 29] -> 
             RGBColor[
              0.2553855075029511, 0.38494351762985174`, 0.937884974915034], 
             UndirectedEdge[8, 35] -> 
             RGBColor[
              0.3924193439651639, 0.5008527137954697, 0.9475656438092757], 
             UndirectedEdge[15, 24] -> 
             RGBColor[
              0.31334631402418045`, 0.43418537599580415`, 0.9416133687427637],
              UndirectedEdge[25, 34] -> 
             RGBColor[
              0.5011001063508725, 0.6054605988516764, 0.9539764645075388], 
             UndirectedEdge[5, 34] -> 
             RGBColor[
              0.7145875714356673, 0.7723891476107818, 0.8792164781282421], 
             UndirectedEdge[32, 49] -> 
             RGBColor[
              0.18706869231129825`, 0.31395143483228205`, 0.933964657332574], 
             UndirectedEdge[27, 34] -> 
             RGBColor[
              0.6280618956403724, 0.3443096940312306, 0.5566996155869678], 
             UndirectedEdge[27, 48] -> 
             RGBColor[
              0.5494020141941004, 0.2736579951952843, 0.5517797639978508], 
             UndirectedEdge[7, 41] -> 
             RGBColor[
              0.21304844461616612`, 0.34125780171613274`, 0.935444165792737], 
             UndirectedEdge[9, 42] -> 
             RGBColor[
              0.23287499063413442`, 0.36209675865664015`, 0.9365732582577139],
              UndirectedEdge[15, 30] -> 
             RGBColor[
              0.18710242252185783`, 0.31398688742219905`, 0.9339665782181661],
              UndirectedEdge[4, 27] -> 
             RGBColor[
              0.545628257175345, 0.2696915372985579, 0.5515648541184058], 
             UndirectedEdge[8, 29] -> 
             RGBColor[
              0.19729385250102144`, 0.32469872650428194`, 0.9345469650786098],
              UndirectedEdge[22, 42] -> 
             RGBColor[
              0.24762087874277505`, 0.3775956220021274, 0.9374130147709144], 
             UndirectedEdge[10, 11] -> 
             RGBColor[
              0.2540512928704016, 0.3835411734569486, 0.9378089933655039], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.27534548035846546`, 0.4019602489369918, 0.9391667511208941], 
             UndirectedEdge[29, 47] -> 
             RGBColor[
              0.1860781632193747, 0.31291032595349866`, 0.9339082481661455], 
             UndirectedEdge[22, 52] -> 
             RGBColor[
              0.2642488615588581, 0.39414858940834385`, 0.938393789504353], 
             UndirectedEdge[1, 33] -> 
             RGBColor[
              0.18480446964579295`, 0.31157159325082734`, 0.9338357132013908],
              UndirectedEdge[10, 50] -> 
             RGBColor[
              0.18664931278339622`, 0.31351064035825915`, 0.9339407742888765],
              UndirectedEdge[2, 7] -> 
             RGBColor[
              0.22411665560320151`, 0.3528911932286155, 0.9360744840344979], 
             UndirectedEdge[3, 50] -> 
             RGBColor[
              0.1953362514960085, 0.3226411637289408, 0.9344354825973855], 
             UndirectedEdge[4, 19] -> 
             RGBColor[
              0.306215728642257, 0.436432123795654, 0.940850610427741], 
             UndirectedEdge[5, 52] -> 
             RGBColor[
              0.6545556258640741, 0.7203924936499839, 0.8753912956405854], 
             UndirectedEdge[4, 44] -> 
             RGBColor[
              0.22644421934722703`, 0.3553376102996513, 0.936207035346398], 
             UndirectedEdge[11, 47] -> 
             RGBColor[
              0.2482343442835764, 0.3774271916763531, 0.9374777267488885], 
             UndirectedEdge[13, 26] -> 
             RGBColor[
              0.189863194501277, 0.3168886338156221, 0.9341238000981978], 
             UndirectedEdge[22, 51] -> 
             RGBColor[
              0.22352303473976798`, 0.3522672600634103, 0.9360406782045086], 
             UndirectedEdge[2, 29] -> 
             RGBColor[
              0.21275716145346535`, 0.3409516446437151, 0.935427577647536], 
             UndirectedEdge[11, 35] -> 
             RGBColor[
              0.45051099896709357`, 0.5610975049210394, 0.9509036536456998], 
             UndirectedEdge[25, 46] -> 
             RGBColor[
              0.7697697341837829, 0.7938096098634093, 0.6602981271788075], 
             UndirectedEdge[10, 47] -> 
             RGBColor[
              0.18474394858682522`, 0.31150798178059547`, 0.9338322666166154],
              UndirectedEdge[20, 45] -> 
             RGBColor[
              0.18682794855272378`, 0.31369839787798437`, 0.9339509473316717],
              UndirectedEdge[25, 36] -> 
             RGBColor[
              0.40637494753673603`, 0.5179232749046879, 0.94814171913877], 
             UndirectedEdge[16, 23] -> 
             RGBColor[
              0.2891771049489997, 0.416498163357294, 0.9399544416792701], 
             UndirectedEdge[6, 18] -> 
             RGBColor[
              0.33636400756868934`, 0.46103456284469924`, 0.9428269383518918],
              UndirectedEdge[8, 18] -> 
             RGBColor[
              0.22947935134822023`, 0.35852772647117875`, 0.9363798816237792],
              UndirectedEdge[5, 25] -> 
             RGBColor[
              0.7768828865057951, 0.8233573583999969, 0.8840117114618453], 
             UndirectedEdge[3, 6] -> 
             RGBColor[
              0.31153123280155337`, 0.43493374207558094`, 0.9414127485657016],
              UndirectedEdge[25, 41] -> 
             RGBColor[
              0.38677199795755546`, 0.49731933199817935`, 0.9470253601602007],
              UndirectedEdge[9, 39] -> 
             RGBColor[
              0.19349686936651092`, 0.320707856487276, 0.9343307325062327], 
             UndirectedEdge[7, 40] -> 
             RGBColor[
              0.20832518207726652`, 0.3362933533156076, 0.9351751829785874], 
             UndirectedEdge[24, 38] -> 
             RGBColor[
              0.32294915935735274`, 0.4442785752965282, 0.9421602365783512], 
             UndirectedEdge[11, 41] -> 
             RGBColor[
              0.2638451315306317, 0.39383511885408673`, 0.9383667379885181], 
             UndirectedEdge[39, 42] -> 
             RGBColor[
              0.24610681323776867`, 0.3760042431590681, 0.9373267909802635], 
             UndirectedEdge[19, 44] -> 
             RGBColor[
              0.2587224336387938, 0.3865136594981895, 0.9381459375373273], 
             UndirectedEdge[5, 46] -> 
             RGBColor[
              0.9832571992685777, 0.9607381586225148, 0.5855381407995108], 
             UndirectedEdge[26, 36] -> 
             RGBColor[
              0.2182847789259907, 0.3467615210785292, 0.9357423672852191], 
             UndirectedEdge[8, 50] -> 
             RGBColor[
              0.19204805347821777`, 0.31918505912844697`, 0.9342482245847255],
              UndirectedEdge[7, 13] -> 
             RGBColor[
              0.20422980977063301`, 0.33198885735973416`, 0.934941957584285], 
             UndirectedEdge[14, 32] -> 
             RGBColor[
              0.19691406294997776`, 0.3242995436060867, 0.9345253366255262], 
             UndirectedEdge[1, 12] -> 
             RGBColor[
              0.18852603613407515`, 0.3154831955909558, 0.9340476509073342], 
             UndirectedEdge[14, 26] -> 
             RGBColor[
              0.19855776805623598`, 0.3260271818896871, 0.9346189431996839], 
             UndirectedEdge[2, 41] -> 
             RGBColor[
              0.22121678548114596`, 0.34984324586795, 0.9359093407210202], 
             UndirectedEdge[25, 40] -> 
             RGBColor[
              0.38204873541865586`, 0.4923548835976542, 0.946756377346051], 
             UndirectedEdge[21, 45] -> 
             RGBColor[
              0.18610720796076108`, 0.31294085381823866`, 0.9339099022211996],
              UndirectedEdge[2, 18] -> 
             RGBColor[
              0.24494266030066414`, 0.3747806446106119, 0.9372604941927054], 
             UndirectedEdge[31, 34] -> 
             RGBColor[
              0.3190985569381377, 0.44069836984338046`, 0.9419238505100097], 
             UndirectedEdge[31, 32] -> 
             RGBColor[
              0.19165999829126196`, 0.3187771885228365, 0.9342261254159044], 
             UndirectedEdge[13, 14] -> 
             RGBColor[
              0.20120587835800335`, 0.32881051371673514`, 0.9347697491638414],
              UndirectedEdge[6, 50] -> 
             RGBColor[
              0.29893270969868685`, 0.42169189550196745`, 0.940695281312838], 
             UndirectedEdge[9, 52] -> 
             RGBColor[
              0.24950297345021744`, 0.3786497260628567, 0.9375540329911525], 
             UndirectedEdge[3, 41] -> 
             RGBColor[
              0.20904167454649278`, 0.33704643232901077`, 0.9352159861647542],
              UndirectedEdge[34, 36] -> 
             RGBColor[
              0.3440796324666083, 0.4669550641154727, 0.9433464858051668], 
             UndirectedEdge[40, 41] -> 
             RGBColor[
              0.20542531195521097`, 0.3332454059549421, 0.9350100396651098], 
             UndirectedEdge[27, 46] -> 
             RGBColor[
              0.8967315234732828, 0.5326587050429636, 0.2630212782582365], 
             UndirectedEdge[20, 30] -> 
             RGBColor[
              0.19047377417599337`, 0.3175303917667363, 0.9341585717074012], 
             UndirectedEdge[1, 51] -> 
             RGBColor[
              0.21202475707353904`, 0.3401818412032927, 0.9353858683015943], 
             UndirectedEdge[41, 50] -> 
             RGBColor[
              0.19644315144362628`, 0.3238045857553973, 0.9344985189118906], 
             UndirectedEdge[6, 7] -> 
             RGBColor[
              0.3155380028712267, 0.4391451114627029, 0.9416409281936843], 
             UndirectedEdge[19, 35] -> 
             RGBColor[
              0.460987126150429, 0.5701713997417824, 0.9515711832061464], 
             UndirectedEdge[4, 35] -> 
             RGBColor[
              0.4287089118588623, 0.5389953505432442, 0.9496322810152171], 
             UndirectedEdge[6, 8] -> 
             RGBColor[
              0.3082430347837626, 0.4314776374750871, 0.9412254905530413], 
             UndirectedEdge[42, 52] -> 
             RGBColor[
              0.30211291732147516`, 0.4339461127346488, 0.9405500914651834], 
             UndirectedEdge[32, 36] -> 
             RGBColor[
              0.2166410738197325, 0.34503388279492875`, 0.9356487607110615], 
             UndirectedEdge[29, 50] -> 
             RGBColor[
              0.1879835274159457, 0.3149129845311623, 0.9340167558384065], 
             UndirectedEdge[1, 43] -> 
             RGBColor[
              0.18452982922769173`, 0.31128292875819474`, 0.933820072835874], 
             UndirectedEdge[14, 31] -> 
             RGBColor[
              0.2046463872542465, 0.3324267067075499, 0.9349656810557057], 
             UndirectedEdge[8, 47] -> 
             RGBColor[
              0.19014268928164677`, 0.3171824005507833, 0.9341397169124643], 
             UndirectedEdge[16, 46] -> 
             RGBColor[
              0.6682716015215231, 0.7088858888667933, 0.6530049249739242], 
             UndirectedEdge[22, 46] -> 
             RGBColor[
              0.5929504349633617, 0.6344942543808748, 0.6485406346632786], 
             UndirectedEdge[4, 6] -> 
             RGBColor[
              0.34453260267746094`, 0.4696202742228617, 0.9432921277589827], 
             UndirectedEdge[23, 52] -> 
             RGBColor[
              0.26834797696953844`, 0.398457019603897, 0.9386272280628936], 
             UndirectedEdge[8, 11] -> 
             RGBColor[
              0.25945003356522317`, 0.3892155922271364, 0.9381164436613529], 
             UndirectedEdge[32, 34] -> 
             RGBColor[
              0.311366232633869, 0.4325712067419172, 0.9414835060798303], 
             UndirectedEdge[18, 41] -> 
             RGBColor[
              0.23387444931362875`, 0.36314725309812906`, 0.9366301759509446],
              UndirectedEdge[5, 27] -> 
             RGBColor[
              0.9038446757952949, 0.5622064535795512, 0.48673486254127435`], 
             UndirectedEdge[43, 51] -> 
             RGBColor[
              0.2097943186535307, 0.3378375090059002, 0.9352588481332128], 
             UndirectedEdge[21, 39] -> 
             RGBColor[
              0.1974332544531238, 0.32484524679453575`, 0.9345549038135554], 
             UndirectedEdge[14, 40] -> 
             RGBColor[
              0.20530125066463686`, 0.33311500967260854`, 0.9350029745581437],
              UndirectedEdge[42, 51] -> 
             RGBColor[
              0.26138709050238507`, 0.3920647833897152, 0.9381969801653389], 
             UndirectedEdge[3, 29] -> 
             RGBColor[
              0.20058205051881217`, 0.3281548311047758, 0.9347342230912701], 
             UndirectedEdge[11, 18] -> 
             RGBColor[
              0.28757100635014987`, 0.41877251759674855`, 0.9397178914602033],
              UndirectedEdge[17, 30] -> 
             RGBColor[
              0.18655432818877316`, 0.3134108055269392, 0.9339353650567297], 
             UndirectedEdge[42, 46] -> 
             RGBColor[
              0.6308144907259788, 0.6742917777071797, 0.6506969366241089], 
             UndirectedEdge[26, 32] -> 
             RGBColor[
              0.18557137909325144`, 0.31237766370497366`, 0.9338793875598828],
              UndirectedEdge[33, 38] -> 
             RGBColor[
              0.19244547856099356`, 0.31960277808864995`, 0.9342708573552517],
              UndirectedEdge[20, 21] -> 
             RGBColor[
              0.18885855752806507`, 0.3158326966591133, 0.9340665875088006], 
             UndirectedEdge[19, 27] -> 
             RGBColor[
              0.5779064714669119, 0.3008675864970961, 0.553503756309335], 
             UndirectedEdge[16, 43] -> 
             RGBColor[
              0.27134927345208204`, 0.3977599821042308, 0.9389391730494339], 
             UndirectedEdge[25, 27] -> 
             RGBColor[
              0.6903572107105002, 0.3952779048204457, 0.561494848920571], 
             UndirectedEdge[2, 8] -> 
             RGBColor[
              0.21682168751573744`, 0.3452237192409997, 0.9356590463938549]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> Medium, 
           VertexSize -> {1.2}, VertexStyle -> {
             EdgeForm[None], 7 -> 
             RGBColor[
              0.21594831473822168`, 0.34430574907679823`, 0.9356093091062146],
              4 -> RGBColor[
              0.2739375143506902, 0.40525607459711577`, 0.9389117082368117], 
             44 -> RGBColor[
              0.1789509243437639, 0.30541914600218684`, 0.9335023624559845], 
             1 -> RGBColor[
              0.18676026764770007`, 0.31362726095558724`, 0.9339470930042555],
              36 -> RGBColor[
              0.24935447365247176`, 0.37941774016848434`, 0.9375117404363978],
              17 -> RGBColor[
              0.18174040614558737`, 0.30835106823926467`, 0.9336612193179298],
              33 -> RGBColor[
              0.1828486716438858, 0.30951592554606744`, 0.933724333398526], 
             15 -> RGBColor[
              0.18283659481175668`, 0.30950323202978436`, 0.9337236456408023],
              20 -> RGBColor[
              0.18957929812002777`, 0.31659024071885894`, 0.9341076326192728],
              24 -> RGBColor[
              0.44385603323660416`, 0.5588675199618239, 0.9495030918447251], 
             31 -> RGBColor[
              0.1993923225955307, 0.32690435162429976`, 0.9346664698460838], 
             19 -> RGBColor[
              0.3384939429338238, 0.46760817299419216`, 0.9427895126186702], 
             18 -> RGBColor[
              0.25760032413314693`, 0.3880846518407909, 0.9379813294226297], 
             5 -> RGBColor[
              0.99037035159059, 0.9902859071591025, 0.8092517250825487], 46 -> 
             RGBColor[
              0.9761440469465655, 0.9311904100859272, 0.36182455651647305`], 
             16 -> RGBColor[
              0.36039915609648066`, 0.4865813676476593, 0.9441852934313752], 
             23 -> RGBColor[
              0.21795505380151867`, 0.3464149590669287, 0.935723589927165], 
             50 -> RGBColor[
              0.182737728393142, 0.3093993171553273, 0.933718015344522], 29 -> 
             RGBColor[
              0.19322932643874938`, 0.32042665190699726`, 0.9343154963322909],
              52 -> 
             RGBColor[
              0.31874090013755824`, 0.45049908014086526`, 0.941530866198622], 
             51 -> RGBColor[
              0.23728924649937802`, 0.36673642145099816`, 0.9368246435989331],
              3 -> RGBColor[
              0.207934774598875, 0.3358830103025543, 0.9351529498502491], 32 -> 
             RGBColor[
              0.18392767398699322`, 0.3106500254213732, 0.9337857809857251], 
             48 -> RGBColor[
              0.2814850283882008, 0.41318899039056856`, 0.9393415279957015], 
             42 -> RGBColor[
              0.28548493450539214`, 0.41739314532843225`, 0.9395693167317447],
              12 -> RGBColor[
              0.19029180462045026`, 0.3173391302263243, 0.9341482088104129], 
             39 -> RGBColor[
              0.20672869197014518`, 0.3346153409897039, 0.9350842652287823], 
             25 -> RGBColor[
              0.5633954214210003, 0.6564288096408915, 0.958771697841142], 28 -> 
             RGBColor[
              0.18455150992939393`, 0.31130571655031963`, 0.9338213075197622],
              35 -> RGBColor[
              0.5834803093670343, 0.6727346264893727, 0.9603528537936226], 43 -> 
             RGBColor[
              0.18229939080768343`, 0.30893859656080225`, 0.9336930526674925],
              40 -> RGBColor[
              0.2007020494163114, 0.328280957554417, 0.9347410568509601], 34 -> 
             RGBColor[
              0.4388047912807448, 0.5544923880624612, 0.9491812311739356], 10 -> 
             RGBColor[
              0.19056089717365043`, 0.317621963561191, 0.9341635332332309], 
             38 -> RGBColor[
              0.20204228547810132`, 0.32968963063123247`, 0.9348173813119774],
              6 -> RGBColor[
              0.4151276910042317, 0.5339844738486076, 0.9476725472811539], 26 -> 
             RGBColor[
              0.18721508419950966`, 0.31410530198857406`, 0.9339729941340403],
              2 -> RGBColor[
              0.23228499646818135`, 0.36147663738043284`, 0.936539658962781], 
             27 -> RGBColor[0.817319, 0.134127, 0.164218], 21 -> 
             RGBColor[
              0.1881378169361024, 0.3150751525993676, 0.9340255423983285], 30 -> 
             RGBColor[
              0.19136825023195894`, 0.3184705428146137, 0.9342095107955297], 
             13 -> RGBColor[
              0.19251130480304435`, 0.31967196564267014`, 0.9342746060623554],
              49 -> RGBColor[
              0.19020971063560327`, 0.31725284424319083`, 0.934143533679423], 
             45 -> RGBColor[
              0.18407659898541975`, 0.3108065550371098, 0.9337942620440707], 
             11 -> RGBColor[
              0.3175416885671528, 0.4494603833527062, 0.941454453497777], 14 -> 
             RGBColor[
              0.20990045191296233`, 0.33794906179080014`, 0.9352648922653274],
              22 -> RGBColor[
              0.20975682298015796`, 0.33779809867582244`, 0.9352567128100842],
              47 -> RGBColor[0.178927, 0.305394, 0.933501], 8 -> 
             RGBColor[
              0.20135837856329353`, 0.3289708011015666, 0.9347784338249288], 
             9 -> RGBColor[
              0.18026504676287666`, 0.3068003719848481, 0.933577199783683], 
             37 -> RGBColor[
              0.19660541606409573`, 0.3239751361596818, 0.9345077596419774], 
             41 -> RGBColor[
              0.21014857449411056`, 0.33820985435546724`, 
               0.9352790224792593]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJwBUQOu/CFib1JlAgAAADQAAAACAAAAChYnqGuS/D8eVFZVF+ELQMt8L11z
3yBAEY+Uok31AkAB2B0nR+8hQHp19O4H1QFAXVTx8W4EHEDnvtvGl3kGQIx4
oPyN1hZABhUebbo4+T9k7CT1ApEfQPmfufqO9wJASufDNiY2IUB1YtesThf6
PxoYkAjwYCFAwyLQ0zj7BEDmC9fUM30JQK4HiBN6afA/LNvVSC9QIkDLDawk
vLADQBUKwR+uSyFAkJe4lFccAkDI7wv0lqbwP8nOxsW1swlA5tfBc9smH0BQ
hpO1H8zlP6o/nb9LUxtAbhQj+F336j8Asm7KyhWhPx/2bdVhl/s/C0TL5jnx
AEBVoNdGfikGQAAAAAAAAAAALt6GYoz09T/y9nIXnAkhQMx+kCDHqQBAGtao
vloVGkBUbyZCaX4BQChmRPOoy+w/kHpp403Vvj8m3LkFVyzyP5TMBgs4itk/
SpzkOU3JCkDxT5ZaUDQDQCjhFebWMAhAuj8DRsdJAkAM3gwn5Gz2P+XuGCFf
4v8/vIMLINqMGUB4COkKJcXyP8Jt7Xjt/hxASJN2TtV63D8ix/YNFzgWQFmr
YHFzcABACARueGjp+j9U324sfIcJQHgLxhH+vCBAAOw31fw7BkDQhTCEdHrg
PxbagQodyes/sB/hyV+6F0Asc0GJ8kfgPzPEFoyXuRlASHrvldFQzT9iw2Ug
xB72Pzq3+WOBLg1AW6bVr+71FkAoKMnuHF3zP4a7oMZifh1AbC2SKkZ1AkAh
34XJLlAZQO6gYyWWJ+I/mMZzZKWgCkBJLTQ2BGMFQMje8R/4KvI/EvTJ3UWc
B0DAPVZmXTEDQF6Z0LZDvuo/znYqpuehHkCF5NuKK/XtP9QB3iJGCSBAp5JN
XqWK9j8w/R6npVoMQIpieGJvFP4/MGDdaBBzA0BosZf2nFgJQIcVGPxiARtA
6mMJvzs5DEAolWcEmuLzPwAAAAAAAAAAFTW238tDEEDcHWReQ+L/P8OO+Pb0
EyJApK/6DmVsBkCpU1vdyBQNQCcExbp4q/k/q21b7qt1GEC3cUV8f9bsP2Zw
X+Bu/CFA6JmlgZMTAEAA8bn7+J0GQNk0X72VhgVAhOzu0dkLD0Ce3ww0icz8
Pzglc54=
         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 12}], {
             RGBColor[
             0.18852603613407515`, 0.3154831955909558, 0.9340476509073342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 16}], {
             RGBColor[
             0.27357971187209035`, 0.4001043143016233, 0.9390661932178154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 28}], {
             RGBColor[
             0.185655888788547, 0.31246648875295346`, 0.9338842002620089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 33}], {
             RGBColor[
             0.18480446964579295`, 0.31157159325082734`, 0.9338357132013908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 38}], {
             RGBColor[
             0.19440127656290068`, 0.32165844579340985`, 0.9343822371581165]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 43}], {
             RGBColor[
             0.18452982922769173`, 0.31128292875819474`, 0.933820072835874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 51}], {
             RGBColor[
             0.21202475707353904`, 0.3401818412032927, 0.9353858683015943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 3}], {
             RGBColor[
             0.22010988553352817`, 0.34867982384149354`, 0.9358463044065151]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 6}], {
             RGBColor[
             0.32370634373620655`, 0.44773055561452024`, 0.9421061031219675]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 7}], {
             RGBColor[
             0.22411665560320151`, 0.3528911932286155, 0.9360744840344979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 8}], {
             RGBColor[
             0.21682168751573744`, 0.3452237192409997, 0.9356590463938549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 10}], {
             RGBColor[
             0.2114229468209159, 0.3395493004708119, 0.9353515960980059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 11}], {
             RGBColor[
             0.2749133425176671, 0.4054685103665695, 0.938997056230279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 18}], {
             RGBColor[
             0.24494266030066414`, 0.3747806446106119, 0.9372604941927054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 29}], {
             RGBColor[
             0.21275716145346535`, 0.3409516446437151, 0.935427577647536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 35}], {
             RGBColor[
             0.40788265291760784`, 0.5171056319349028, 0.9484462563782018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 41}], {
             RGBColor[
             0.22121678548114596`, 0.34984324586795, 0.9359093407210202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 47}], {
             RGBColor[
             0.20560599823409068`, 0.3334353186902164, 0.9350203294813906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 50}], {
             RGBColor[
             0.20751136243066168`, 0.33543797726788005`, 0.9351288371536515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 6}], {
             RGBColor[
             0.31153123280155337`, 0.43493374207558094`, 0.9414127485657016]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 7}], {
             RGBColor[
             0.21194154466854834`, 0.34009437968967626`, 0.9353811294782319]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 8}], {
             RGBColor[
             0.20464657658108426`, 0.33242690570206046`, 0.9349656918375889]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 10}], {
             RGBColor[
             0.19924783588626271`, 0.32675248693187264`, 0.9346582415417399]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 11}], {
             RGBColor[
             0.2627382315830139, 0.39267169682763026`, 0.938303701674013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 18}], {
             RGBColor[
             0.23276754936601096`, 0.3619838310716726, 0.9365671396364394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 29}], {
             RGBColor[
             0.20058205051881217`, 0.3281548311047758, 0.9347342230912701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 41}], {
             RGBColor[
             0.20904167454649278`, 0.33704643232901077`, 0.9352159861647542]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 47}], {
             RGBColor[
             0.1934308872994375, 0.3206385051512771, 0.9343269749251246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 50}], {
             RGBColor[
             0.1953362514960085, 0.3226411637289408, 0.9344354825973855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 6}], {
             RGBColor[
             0.34453260267746094`, 0.4696202742228617, 0.9432921277589827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 19}], {
             RGBColor[
             0.306215728642257, 0.436432123795654, 0.940850610427741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 27}], {
             RGBColor[
             0.545628257175345, 0.2696915372985579, 0.5515648541184058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 29}], {
             RGBColor[
             0.2335834203947198, 0.3628413632520565, 0.9366136022845513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 35}], {
             RGBColor[
             0.4287089118588623, 0.5389953505432442, 0.9496322810152171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 44}], {
             RGBColor[
             0.22644421934722703`, 0.3553376102996513, 0.936207035346398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 14}], {
             RGBColor[
             0.6001354017517762, 0.6641174844749513, 0.872258308673938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 19}], {
             RGBColor[
             0.6644321472622069, 0.7289470400766473, 0.8760206188506094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 25}], {
             RGBColor[
             0.7768828865057951, 0.8233573583999969, 0.8840117114618453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 27}], {
             RGBColor[
             0.9038446757952949, 0.5622064535795512, 0.48673486254127435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 31}], {
             RGBColor[
             0.5948813370930603, 0.6585951293917012, 0.8719590974643163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 34}], {
             RGBColor[
             0.7145875714356673, 0.7723891476107818, 0.8792164781282421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 35}], {
             RGBColor[
             0.7869253304788122, 0.8315102668242376, 0.8848022894380856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 36}], {
             RGBColor[
             0.6198624126215309, 0.6848518236637934, 0.8733817327594733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 46}], {
             RGBColor[
             0.9832571992685777, 0.9607381586225148, 0.5855381407995108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 52}], {
             RGBColor[
             0.6545556258640741, 0.7203924936499839, 0.8753912956405854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 7}], {
             RGBColor[
             0.3155380028712267, 0.4391451114627029, 0.9416409281936843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 8}], {
             RGBColor[
             0.3082430347837626, 0.4314776374750871, 0.9412254905530413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 10}], {
             RGBColor[
             0.3028442940889411, 0.4258032187048993, 0.9409180402571924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 11}], {
             RGBColor[
             0.3663346897856923, 0.4917224286006569, 0.9445635003894655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 18}], {
             RGBColor[
             0.33636400756868934`, 0.46103456284469924`, 0.9428269383518918]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 19}], {
             RGBColor[
             0.37681081696902774`, 0.5007963234213999, 0.945231029949912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 27}], {
             RGBColor[
             0.6162233455021159, 0.3340557369243038, 0.555945273640577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 29}], {
             RGBColor[
             0.30417850872149055`, 0.4272055628778024, 0.9409940218067224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 35}], {
             RGBColor[
             0.49930400018563303`, 0.6033595501689901, 0.9540127005373882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 47}], {
             RGBColor[
             0.29702734550211585`, 0.4196892369243038, 0.940586773640577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 50}], {
             RGBColor[
             0.29893270969868685`, 0.42169189550196745`, 0.940695281312838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 8}], {
             RGBColor[
             0.2086533466507576, 0.3366382750891824, 0.9351938714655716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 10}], {
             RGBColor[
             0.20325460595593606`, 0.3309638563189946, 0.9348864211697228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 11}], {
             RGBColor[
             0.2667450016526872, 0.3968830662147522, 0.9385318813019958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 13}], {
             RGBColor[
             0.20422980977063301`, 0.33198885735973416`, 0.934941957584285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 18}], {
             RGBColor[
             0.2367743194356843, 0.36619520045879456`, 0.9367953192644222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 40}], {
             RGBColor[
             0.20832518207726652`, 0.3362933533156076, 0.9351751829785874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 41}], {
             RGBColor[
             0.21304844461616612`, 0.34125780171613274`, 0.935444165792737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 50}], {
             RGBColor[
             0.19934302156568184`, 0.32685253311606277`, 0.9346636622253683]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 10}], {
             RGBColor[
             0.19595963786847198`, 0.3232963823313788, 0.9344709835290799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 11}], {
             RGBColor[
             0.25945003356522317`, 0.3892155922271364, 0.9381164436613529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 18}], {
             RGBColor[
             0.22947935134822023`, 0.35852772647117875`, 0.9363798816237792]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 29}], {
             RGBColor[
             0.19729385250102144`, 0.32469872650428194`, 0.9345469650786098]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 35}], {
             RGBColor[
             0.3924193439651639, 0.5008527137954697, 0.9475656438092757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 47}], {
             RGBColor[
             0.19014268928164677`, 0.3171824005507833, 0.9341397169124643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 50}], {
             RGBColor[
             0.19204805347821777`, 0.31918505912844697`, 0.9342482245847255]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 39}], {
             RGBColor[
             0.19349686936651092`, 0.320707856487276, 0.9343307325062327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 42}], {
             RGBColor[
             0.23287499063413442`, 0.36209675865664015`, 0.9365732582577139]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 48}], {
             RGBColor[
             0.23087503757553873`, 0.35999468118770833`, 0.9364593638896923]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 52}], {
             RGBColor[
             0.24950297345021744`, 0.3786497260628567, 0.9375540329911525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 11}], {
             RGBColor[
             0.2540512928704016, 0.3835411734569486, 0.9378089933655039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 18}], {
             RGBColor[
             0.22408061065339868`, 0.35285330770099094`, 0.9360724313279303]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 29}], {
             RGBColor[
             0.1918951118061999, 0.3190243077340941, 0.9342395147827609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 47}], {
             RGBColor[
             0.18474394858682522`, 0.31150798178059547`, 0.9338322666166154]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 50}], {
             RGBColor[
             0.18664931278339622`, 0.31351064035825915`, 0.9339407742888765]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 18}], {
             RGBColor[
             0.28757100635014987`, 0.41877251759674855`, 0.9397178914602033]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 29}], {
             RGBColor[
             0.2553855075029511, 0.38494351762985174`, 0.937884974915034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 35}], {
             RGBColor[
             0.45051099896709357`, 0.5610975049210394, 0.9509036536456998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 41}], {
             RGBColor[
             0.2638451315306317, 0.39383511885408673`, 0.9383667379885181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 47}], {
             RGBColor[
             0.2482343442835764, 0.3774271916763531, 0.9374777267488885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 50}], {
             RGBColor[
             0.25013970848014744`, 0.37942985025401677`, 0.9375862344211495]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.27534548035846546`, 0.4019602489369918, 0.9391667511208941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 24}], {
             RGBColor[
             0.3170739189285272, 0.4381033250940741, 0.941825650327569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 28}], {
             RGBColor[
             0.1874216572749221, 0.31432242338832195`, 0.9339847581650875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 33}], {
             RGBColor[
             0.18657023813216803`, 0.3134275278861959, 0.9339362711044694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 38}], {
             RGBColor[
             0.1961670450492758, 0.3235143804287784, 0.9344827950611951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 14}], {
             RGBColor[
             0.20120587835800335`, 0.32881051371673514`, 0.9347697491638414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 25}], {
             RGBColor[
             0.3779533631120223, 0.48805038764178077`, 0.9465231519517487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 26}], {
             RGBColor[
             0.189863194501277, 0.3168886338156221, 0.9341238000981978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 40}], {
             RGBColor[
             0.19660667710967789`, 0.32397646159854354`, 0.9345078314566577]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 41}], {
             RGBColor[
             0.20132993964857746`, 0.32894090999906866`, 0.9347768142708073]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 25}], {
             RGBColor[
             0.3866479366669813, 0.49718893571584577`, 0.9470182950532346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 26}], {
             RGBColor[
             0.19855776805623598`, 0.3260271818896871, 0.9346189431996839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 31}], {
             RGBColor[
             0.2046463872542465, 0.3324267067075499, 0.9349656810557057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 32}], {
             RGBColor[
             0.19691406294997776`, 0.3242995436060867, 0.9345253366255262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 34}], {
             RGBColor[
             0.3243526215968536, 0.4462207249266307, 0.9422230617196314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 36}], {
             RGBColor[
             0.22962746278271706`, 0.35868340097964224`, 0.9363883163508626]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 40}], {
             RGBColor[
             0.20530125066463686`, 0.33311500967260854`, 0.9350029745581437]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 41}], {
             RGBColor[
             0.21002451320353643`, 0.33807945807313367`, 0.9352719573722934]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 17}], {
             RGBColor[
             0.182288500478672, 0.30892715013452454`, 0.9336924324793661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 24}], {
             RGBColor[
             0.31334631402418045`, 0.43418537599580415`, 0.9416133687427637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 30}], {
             RGBColor[
             0.18710242252185783`, 0.31398688742219905`, 0.9339665782181661]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 23}], {
             RGBColor[
             0.2891771049489997, 0.416498163357294, 0.9399544416792701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 24}], {
             RGBColor[
             0.4021275946665424, 0.5227244438047416, 0.9468441926380502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 28}], {
             RGBColor[
             0.2724753330129373, 0.39894354209898947`, 0.9390033004755687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.27162391387018325`, 0.39804864659686334`, 0.9389548134149506]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 38}], {
             RGBColor[
             0.281220720787291, 0.4081354991394459, 0.9395013373716763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 43}], {
             RGBColor[
             0.27134927345208204`, 0.3977599821042308, 0.9389391730494339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 46}], {
             RGBColor[
             0.6682716015215231, 0.7088858888667933, 0.6530049249739242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 51}], {
             RGBColor[
             0.2988442012979293, 0.4266588945493287, 0.9405049685151542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 24}], {
             RGBColor[
             0.3127982196910958, 0.4336092941005443, 0.9415821555813275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 30}], {
             RGBColor[
             0.18655432818877316`, 0.3134108055269392, 0.9339353650567297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 29}], {
             RGBColor[
             0.22541482528594814`, 0.3542556518738941, 0.9361484128774603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 35}], {
             RGBColor[
             0.4205403167500906, 0.5304096391650818, 0.9491670916081261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 41}], {
             RGBColor[
             0.23387444931362875`, 0.36314725309812906`, 0.9366301759509446]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 47}], {
             RGBColor[
             0.21826366206657347`, 0.34673932592039547`, 0.9357411647113149]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 50}], {
             RGBColor[
             0.22016902626314447`, 0.3487419844980591, 0.9358496723835759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 27}], {
             RGBColor[
             0.5779064714669119, 0.3008675864970961, 0.553503756309335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 34}], {
             RGBColor[
             0.38864936710728426`, 0.5110502805283267, 0.9459853718963029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 35}], {
             RGBColor[
             0.460987126150429, 0.5701713997417824, 0.9515711832061464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 44}], {
             RGBColor[
             0.2587224336387938, 0.3865136594981895, 0.9381459375373273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 49}], {
             RGBColor[
             0.26435182678471353`, 0.3924305086186915, 0.9384665231490465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 21}], {
             RGBColor[
             0.18885855752806507`, 0.3158326966591133, 0.9340665875088006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 30}], {
             RGBColor[
             0.19047377417599337`, 0.3175303917667363, 0.9341585717074012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 39}], {
             RGBColor[
             0.19815399504508646`, 0.32560279085428145`, 0.9345959489240275]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 45}], {
             RGBColor[
             0.18682794855272378`, 0.31369839787798437`, 0.9339509473316717]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 30}], {
             RGBColor[
             0.18975303358403067`, 0.31677284770699066`, 0.934117526596929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 39}], {
             RGBColor[
             0.1974332544531238, 0.32484524679453575`, 0.9345549038135554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 45}], {
             RGBColor[
             0.18610720796076108`, 0.31294085381823866`, 0.9339099022211996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 23}], {
             RGBColor[
             0.21385593839083833`, 0.3421065288713756, 0.9354901513686246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 37}], {
             RGBColor[
             0.20318111952212686`, 0.33088661741775216`, 0.9348822362260307]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 42}], {
             RGBColor[
             0.24762087874277505`, 0.3775956220021274, 0.9374130147709144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 43}], {
             RGBColor[
             0.1960281068939207, 0.32336834761831235`, 0.9344748827387883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 46}], {
             RGBColor[
             0.5929504349633617, 0.6344942543808748, 0.6485406346632786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.24562092568417937`, 0.3754935445331955, 0.9372991204028929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 51}], {
             RGBColor[
             0.22352303473976798`, 0.3522672600634103, 0.9360406782045086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 52}], {
             RGBColor[
             0.2642488615588581, 0.39414858940834385`, 0.938393789504353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 37}], {
             RGBColor[
             0.2072802349328072, 0.33519504761330526`, 0.9351156747845712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 42}], {
             RGBColor[
             0.2517199941534554, 0.3819040521976805, 0.9376464533294548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 43}], {
             RGBColor[
             0.20012722230460106`, 0.3276767778138655, 0.9347083212973287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 46}], {
             RGBColor[
             0.5970495503740421, 0.6388026845764279, 0.648774073221819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 48}], {
             RGBColor[
             0.24972004109485973`, 0.37980197472874866`, 0.9375325589614332]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 51}], {
             RGBColor[
             0.22762215015044834`, 0.3565756902589634, 0.9362741167630491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 52}], {
             RGBColor[
             0.26834797696953844`, 0.398457019603897, 0.9386272280628936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 30}], {
             RGBColor[
             0.31761214173428154`, 0.4386690313882188, 0.9418563013201274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 38}], {
             RGBColor[
             0.32294915935735274`, 0.4442785752965282, 0.9421602365783512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 46}], {
             RGBColor[
             0.7100000400915849, 0.7450289650238755, 0.6556638241805991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 26}], {
             RGBColor[
             0.37530525281025495`, 0.48526705581473273`, 0.9463723459875912]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 27}], {
             RGBColor[
             0.6903572107105002, 0.3952779048204457, 0.561494848920571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 31}], {
             RGBColor[
             0.38139387200826547`, 0.4916665806325956, 0.9467190838436129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 32}], {
             RGBColor[
             0.37366154770399673`, 0.48353941753113233`, 0.9462787394134335]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 34}], {
             RGBColor[
             0.5011001063508725, 0.6054605988516764, 0.9539764645075388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 36}], {
             RGBColor[
             0.40637494753673603`, 0.5179232749046879, 0.94814171913877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 40}], {
             RGBColor[
             0.38204873541865586`, 0.4923548835976542, 0.946756377346051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 41}], {
             RGBColor[
             0.38677199795755546`, 0.49731933199817935`, 0.9470253601602007]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 46}], {
             RGBColor[
             0.7697697341837829, 0.7938096098634093, 0.6602981271788075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 32}], {
             RGBColor[
             0.18557137909325144`, 0.31237766370497366`, 0.9338793875598828]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 36}], {
             RGBColor[
             0.2182847789259907, 0.3467615210785292, 0.9357423672852191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 40}], {
             RGBColor[
             0.19395856680791052`, 0.3211931297714955, 0.9343570254925002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 41}], {
             RGBColor[
             0.1986818293468101, 0.3261575781720206, 0.9346260083066498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 34}], {
             RGBColor[
             0.6280618956403724, 0.3443096940312306, 0.5566996155869678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 35}], {
             RGBColor[
             0.7003996546835172, 0.4034308132446863, 0.5622854268968113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 42}], {
             RGBColor[
             0.5514019672526961, 0.2757600726642161, 0.5518936583658723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 46}], {
             RGBColor[
             0.8967315234732828, 0.5326587050429636, 0.2630212782582365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 48}], {
             RGBColor[
             0.5494020141941004, 0.2736579951952843, 0.5517797639978508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 52}], {
             RGBColor[
             0.5680299500687791, 0.29231304007043263`, 0.5528744330993111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 33}], {
             RGBColor[
             0.18370009078663985`, 0.3104108210481935, 0.9337728204591441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 38}], {
             RGBColor[
             0.19329689770374764`, 0.3204976735907761, 0.9343193444158698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 43}], {
             RGBColor[
             0.1834254503685387, 0.31012215655556097`, 0.9337571800936273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 51}], {
             RGBColor[
             0.21092037821438597`, 0.33902106900065887`, 0.9353229755593477]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 35}], {
             RGBColor[
             0.38835481790289184`, 0.49658063919818496`, 0.9473341750629567]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 47}], {
             RGBColor[
             0.1860781632193747, 0.31291032595349866`, 0.9339082481661455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 50}], {
             RGBColor[
             0.1879835274159457, 0.3149129845311623, 0.9340167558384065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 45}], {
             RGBColor[
             0.18772242460868935`, 0.31463854892586174`, 0.9340018864198002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 32}], {
             RGBColor[
             0.19165999829126196`, 0.3187771885228365, 0.9342261254159044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 34}], {
             RGBColor[
             0.3190985569381377, 0.44069836984338046`, 0.9419238505100097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 36}], {
             RGBColor[
             0.22437339812400123`, 0.3531610458963921, 0.9360891051412408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 49}], {
             RGBColor[
             0.19480101661556698`, 0.32207859793374527`, 0.9344050017627534]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 34}], {
             RGBColor[
             0.311366232633869, 0.4325712067419172, 0.9414835060798303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 36}], {
             RGBColor[
             0.2166410738197325, 0.34503388279492875`, 0.9356487607110615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 49}], {
             RGBColor[
             0.18706869231129825`, 0.31395143483228205`, 0.933964657332574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 38}], {
             RGBColor[
             0.19244547856099356`, 0.31960277808864995`, 0.9342708573552517]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 43}], {
             RGBColor[
             0.1825740312257846, 0.30922726105343484`, 0.9337086930330092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 36}], {
             RGBColor[
             0.3440796324666083, 0.4669550641154727, 0.9433464858051668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 46}], {
             RGBColor[
             0.7074744191136552, 0.7428413990741942, 0.6555028938452043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 49}], {
             RGBColor[
             0.314507250958174, 0.435872616152826, 0.9416623824266793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 49}], {
             RGBColor[
             0.21978209214403752`, 0.3483352922058376, 0.9358276370579104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 42}], {
             RGBColor[
             0.24104517528474395`, 0.37068414074405703`, 0.9370385381868611]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 43}], {
             RGBColor[
             0.1894524034358896, 0.31645686636024206`, 0.9341004061547349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 48}], {
             RGBColor[
             0.23904522222614827`, 0.3685820632751252, 0.9369246438188394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 51}], {
             RGBColor[
             0.21694733128173688`, 0.34535577880533996`, 0.9356662016204553]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 52}], {
             RGBColor[
             0.25767315810082697`, 0.38723710815027357`, 0.9380193129202997]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 42}], {
             RGBColor[
             0.24610681323776867`, 0.3760042431590681, 0.9373267909802635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 45}], {
             RGBColor[
             0.19540264547778247`, 0.32271094801340683`, 0.9344392636364265]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 48}], {
             RGBColor[
             0.244106860179173, 0.37390216569013623`, 0.9372128966122419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 52}], {
             RGBColor[
             0.2627347960538517, 0.3925572105652846, 0.9383075657137021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 41}], {
             RGBColor[
             0.20542531195521097`, 0.3332454059549421, 0.9350100396651098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 50}], {
             RGBColor[
             0.19644315144362628`, 0.3238045857553973, 0.9344985189118906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 46}], {
             RGBColor[
             0.6308144907259788, 0.6742917777071797, 0.6506969366241089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 48}], {
             RGBColor[
             0.28348498144679646`, 0.41529106785950043`, 0.939455422363723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 51}], {
             RGBColor[
             0.26138709050238507`, 0.3920647833897152, 0.9381969801653389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 52}], {
             RGBColor[
             0.30211291732147516`, 0.4339461127346488, 0.9405500914651834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 51}], {
             RGBColor[
             0.2097943186535307, 0.3378375090059002, 0.9352588481332128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 51}], {
             RGBColor[
             0.6067166467229718, 0.6489634157684627, 0.6493246000577031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 52}], {
             RGBColor[
             0.6474424735420619, 0.6908447451133962, 0.6516777113575476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 50}], {
             RGBColor[
             0.180832364196571, 0.30739665857766363`, 0.933609507672261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 52}], {
             RGBColor[
             0.3001129642628795, 0.4318440352657169, 0.9404361970971618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 52}], {
             RGBColor[
             0.27801507331846814`, 0.4086177507959317, 0.9391777548987776]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.13257557723491092`], {
             RGBColor[
             0.18676026764770007`, 0.31362726095558724`, 0.9339470930042555]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.13257557723491092`], {
             RGBColor[
             0.23228499646818135`, 0.36147663738043284`, 0.936539658962781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.13257557723491092`], {
             RGBColor[
             0.207934774598875, 0.3358830103025543, 0.9351529498502491]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.13257557723491092`], {
             RGBColor[
             0.2739375143506902, 0.40525607459711577`, 0.9389117082368117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.13257557723491092`], {
             RGBColor[
             0.99037035159059, 0.9902859071591025, 0.8092517250825487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.13257557723491092`], {
             RGBColor[
             0.4151276910042317, 0.5339844738486076, 0.9476725472811539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.13257557723491092`], {
             RGBColor[
             0.21594831473822168`, 0.34430574907679823`, 0.9356093091062146]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.13257557723491092`], {
             RGBColor[
             0.20135837856329353`, 0.3289708011015666, 0.9347784338249288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.13257557723491092`], {
             RGBColor[
             0.18026504676287666`, 0.3068003719848481, 0.933577199783683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.13257557723491092`], {
             RGBColor[
             0.19056089717365043`, 0.317621963561191, 0.9341635332332309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.13257557723491092`], {
             RGBColor[
             0.3175416885671528, 0.4494603833527062, 0.941454453497777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.13257557723491092`], {
             RGBColor[
             0.19029180462045026`, 0.3173391302263243, 0.9341482088104129]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.13257557723491092`], {
             RGBColor[
             0.19251130480304435`, 0.31967196564267014`, 0.9342746060623554]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.13257557723491092`], {
             RGBColor[
             0.20990045191296233`, 0.33794906179080014`, 0.9352648922653274]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.13257557723491092`], {
             RGBColor[
             0.18283659481175668`, 0.30950323202978436`, 0.9337236456408023]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.13257557723491092`], {
             RGBColor[
             0.36039915609648066`, 0.4865813676476593, 0.9441852934313752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.13257557723491092`], {
             RGBColor[
             0.18174040614558737`, 0.30835106823926467`, 0.9336612193179298]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.13257557723491092`], {
             RGBColor[
             0.25760032413314693`, 0.3880846518407909, 0.9379813294226297]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.13257557723491092`], {
             RGBColor[
             0.3384939429338238, 0.46760817299419216`, 0.9427895126186702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.13257557723491092`], {
             RGBColor[
             0.18957929812002777`, 0.31659024071885894`, 0.9341076326192728]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.13257557723491092`], {
             RGBColor[
             0.1881378169361024, 0.3150751525993676, 0.9340255423983285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.13257557723491092`], {
             RGBColor[
             0.20975682298015796`, 0.33779809867582244`, 0.9352567128100842]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.13257557723491092`], {
             RGBColor[
             0.21795505380151867`, 0.3464149590669287, 0.935723589927165]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.13257557723491092`], {
             RGBColor[
             0.44385603323660416`, 0.5588675199618239, 0.9495030918447251]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.13257557723491092`], {
             RGBColor[
             0.5633954214210003, 0.6564288096408915, 0.958771697841142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.13257557723491092`], {
             RGBColor[
             0.18721508419950966`, 0.31410530198857406`, 0.9339729941340403]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.13257557723491092`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.13257557723491092`], {
             RGBColor[
             0.18455150992939393`, 0.31130571655031963`, 0.9338213075197622]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.13257557723491092`], {
             RGBColor[
             0.19322932643874938`, 0.32042665190699726`, 0.9343154963322909]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.13257557723491092`], {
             RGBColor[
             0.19136825023195894`, 0.3184705428146137, 0.9342095107955297]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.13257557723491092`], {
             RGBColor[
             0.1993923225955307, 0.32690435162429976`, 0.9346664698460838]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.13257557723491092`], {
             RGBColor[
             0.18392767398699322`, 0.3106500254213732, 0.9337857809857251]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.13257557723491092`], {
             RGBColor[
             0.1828486716438858, 0.30951592554606744`, 0.933724333398526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.13257557723491092`], {
             RGBColor[
             0.4388047912807448, 0.5544923880624612, 0.9491812311739356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.13257557723491092`], {
             RGBColor[
             0.5834803093670343, 0.6727346264893727, 0.9603528537936226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.13257557723491092`], {
             RGBColor[
             0.24935447365247176`, 0.37941774016848434`, 0.9375117404363978]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.13257557723491092`], {
             RGBColor[
             0.19660541606409573`, 0.3239751361596818, 0.9345077596419774]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.13257557723491092`], {
             RGBColor[
             0.20204228547810132`, 0.32968963063123247`, 0.9348173813119774]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.13257557723491092`], {
             RGBColor[
             0.20672869197014518`, 0.3346153409897039, 0.9350842652287823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.13257557723491092`], {
             RGBColor[
             0.2007020494163114, 0.328280957554417, 0.9347410568509601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.13257557723491092`], {
             RGBColor[
             0.21014857449411056`, 0.33820985435546724`, 0.9352790224792593]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.13257557723491092`], {
             RGBColor[
             0.28548493450539214`, 0.41739314532843225`, 0.9395693167317447]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.13257557723491092`], {
             RGBColor[
             0.18229939080768343`, 0.30893859656080225`, 0.9336930526674925]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.13257557723491092`], {
             RGBColor[
             0.1789509243437639, 0.30541914600218684`, 0.9335023624559845]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.13257557723491092`], {
             RGBColor[
             0.18407659898541975`, 0.3108065550371098, 0.9337942620440707]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.13257557723491092`], {
             RGBColor[
             0.9761440469465655, 0.9311904100859272, 0.36182455651647305`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.13257557723491092`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.13257557723491092`], {
             RGBColor[
             0.2814850283882008, 0.41318899039056856`, 0.9393415279957015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.13257557723491092`], {
             RGBColor[
             0.19020971063560327`, 0.31725284424319083`, 0.934143533679423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.13257557723491092`], {
             RGBColor[
             0.182737728393142, 0.3093993171553273, 0.933718015344522]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.13257557723491092`], {
             RGBColor[
             0.23728924649937802`, 0.36673642145099816`, 0.9368246435989331]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.13257557723491092`], {
             RGBColor[
             0.31874090013755824`, 0.45049908014086526`, 0.941530866198622]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> Medium, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53}, {Null, CompressedData["
1:eJwVxUmWoyAAANAAiigOoUQ0otFKHDCIlIoX6SPUBfr+u379N//79++fX3i7
3RJwu/1f2awgiliYwSJQxK3OukAQIZSwOMACK2y/fj4rkVKFX6ENf0IHMAgA
ASHIgAAKWOBwH/Sil32vwAKXbCmWxcExG4txXMCJT3E+Po+VHOqwx+Huj/vn
vkLPk+H1vNwFh2wohmEcFkSQRApZdCB3fz/e7897BTves13sw77sdt9PnAZp
KtL++wir6lm56vJmOfczqkkd1lVdr7WtXX0BDjnmGecFF3zgI1+45Ts/uUMd
6R5d9919urU7fOwHfuoLv4cMMY8RxmomWcdmpphlB3PI+AabwBDDjDDS9GY2
yvhJkCRpIpM+mRMDG9R4DWlYI5umb+ZGNQZu3pZtxTZuywZbr5Vt07Zzu4Vx
XMV1/IzX2MUX0EgTHWqmha51p5XWRlt9aAdKXGYlL4tSlOVQjuVS7uUZvuJX
9Xq+XhecvIlNcmqmdprmaQM5zoM8y3Oei7zMbb7nJ6CIYkpoSCmjnApa0Zoq
qqmlOz2oo5cXkShKIhbJqInaqI+maI5UZP4B+mc4KA==
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[3, 40] -> 
             RGBColor[
              0.9905255289853713, 0.98952321757497, 0.7465760826571863], 
             UndirectedEdge[23, 51] -> 
             RGBColor[
              0.20739968721280289`, 0.33532059953329274`, 0.9351224774152032],
              UndirectedEdge[28, 38] -> 
             RGBColor[
              0.255097528924609, 0.3848126918284407, 0.9378622823998515], 
             UndirectedEdge[1, 41] -> 
             RGBColor[
              0.463227845131689, 0.5641693345968175, 0.9528827054761746], 
             UndirectedEdge[15, 37] -> 
             RGBColor[
              0.22622343778870863`, 0.35510555488328915`, 0.9361944621632575],
              UndirectedEdge[6, 47] -> 
             RGBColor[
              0.5366502038759732, 0.262264323658268, 0.5513262981943878], 
             UndirectedEdge[11, 52] -> 
             RGBColor[
              0.9164680222783099, 0.6497173307302895, 0.30543307143246834`], 
             UndirectedEdge[2, 38] -> 
             RGBColor[
              0.22209174597319215`, 0.3507628848207899, 0.9359591684266542], 
             UndirectedEdge[4, 10] -> 
             RGBColor[
              0.21451144911430153`, 0.3427955122035158, 0.9355274817345847], 
             UndirectedEdge[1, 6] -> 
             RGBColor[
              0.4639316258291459, 0.5649090527321182, 0.9529227847457445], 
             UndirectedEdge[27, 38] -> 
             RGBColor[
              0.2308149717185985, 0.3599315481636689, 0.936455943227999], 
             UndirectedEdge[9, 53] -> 
             RGBColor[
              0.29822954002547564`, 0.42839783845886614`, 0.9403826382291485],
              UndirectedEdge[21, 23] -> 
             RGBColor[
              0.19823217967153106`, 0.32568496785386636`, 0.9346004014228397],
              UndirectedEdge[16, 25] -> 
             RGBColor[
              0.1869311695796025, 0.313806889721825, 0.9339568256164507], 
             UndirectedEdge[6, 51] -> 
             RGBColor[
              0.22990781896594553`, 0.3589780731038241, 0.9364042822207477], 
             UndirectedEdge[11, 24] -> 
             RGBColor[
              0.5504667458285053, 0.35243913510161706`, 0.5623818559352285], 
             UndirectedEdge[10, 45] -> 
             RGBColor[
              0.2641438363762507, 0.39496229809093164`, 0.9383539727646155], 
             UndirectedEdge[13, 32] -> 
             RGBColor[
              0.2101006079513616, 0.3381594384777836, 0.9352762908556098], 
             UndirectedEdge[27, 39] -> 
             RGBColor[
              0.2358466233171645, 0.3652201330188991, 0.9367424883428759], 
             UndirectedEdge[6, 19] -> 
             RGBColor[
              0.2370726385884536, 0.36650875280288187`, 0.9368123080988487], 
             UndirectedEdge[20, 22] -> 
             RGBColor[
              0.37284454897064195`, 0.49672209051809535`, 0.9450016943217208],
              UndirectedEdge[19, 47] -> 
             RGBColor[
              0.5183470642902006, 0.24302656346754486`, 0.5502839614720466], 
             UndirectedEdge[20, 52] -> 
             RGBColor[
              0.6470224187389085, 0.7099796123170127, 0.6823663258658558], 
             UndirectedEdge[27, 40] -> 
             RGBColor[
              0.6269226556009109, 0.6934338053090753, 0.9040730352269584], 
             UndirectedEdge[8, 43] -> 
             RGBColor[
              0.8993934351461096, 0.5416379581619916, 0.2733623024473289], 
             UndirectedEdge[19, 51] -> 
             RGBColor[
              0.21160467938017308`, 0.339740312913101, 0.9353619454984065], 
             UndirectedEdge[28, 39] -> 
             RGBColor[
              0.260129180523175, 0.3901012766836709, 0.9381488275147283], 
             UndirectedEdge[17, 47] -> 
             RGBColor[
              0.9054139630267168, 0.5650577396428732, 0.46603611242620246`], 
             UndirectedEdge[3, 31] -> 
             RGBColor[
              0.6622416320696889, 0.7253282147540213, 0.7828939468522256], 
             UndirectedEdge[37, 41] -> 
             RGBColor[
              0.23738349962751154`, 0.36683548746466, 0.9368300111751453], 
             UndirectedEdge[10, 39] -> 
             RGBColor[
              0.22129539141633864`, 0.34992586568974166`, 0.9359138172127424],
              UndirectedEdge[1, 23] -> 
             RGBColor[
              0.44142349407600323`, 0.5412515791615868, 0.9516409799402], 
             UndirectedEdge[1, 9] -> 
             RGBColor[
              0.5035454476852667, 0.6041549958384386, 0.9552662683640423], 
             UndirectedEdge[4, 17] -> 
             RGBColor[
              0.5919554377569086, 0.6547123997424065, 0.8507316221947121], 
             UndirectedEdge[7, 14] -> 
             RGBColor[
              0.1971919867327395, 0.3245916591231548, 0.934541163973803], 
             UndirectedEdge[7, 32] -> 
             RGBColor[
              0.22280538550866225`, 0.35151296521992886`, 0.9359998091424641],
              UndirectedEdge[17, 40] -> 
             RGBColor[
              0.9898154123426921, 0.9900564255188086, 0.8184485045569523], 
             UndirectedEdge[10, 17] -> 
             RGBColor[
              0.6154593078331062, 0.6794164574239245, 0.8520701328246918], 
             UndirectedEdge[36, 37] -> 
             RGBColor[
              0.20890738141682863`, 0.3369052817350575, 0.9352083383696888], 
             UndirectedEdge[3, 52] -> 
             RGBColor[
              0.9932660440977233, 0.9878233542680591, 0.5238807898017294], 
             UndirectedEdge[12, 34] -> 
             RGBColor[
              0.21861705672713244`, 0.34711076611515856`, 0.9357612900144332],
              UndirectedEdge[9, 48] -> 
             RGBColor[
              0.2657442853073524, 0.39425377606600776`, 0.9385326510305791], 
             UndirectedEdge[16, 35] -> 
             RGBColor[
              0.1803843663506722, 0.30692578443692, 0.9335839948576905], 
             UndirectedEdge[8, 10] -> 
             RGBColor[
              0.5276671595952496, 0.250813284942517, 0.5505419961822822], 
             UndirectedEdge[24, 34] -> 
             RGBColor[
              0.22136362956271116`, 0.34999758830812755`, 0.935917703274229], 
             UndirectedEdge[49, 51] -> 
             RGBColor[
              0.21979131518564116`, 0.34834498620733767`, 0.9358281622964855],
              UndirectedEdge[38, 46] -> 
             RGBColor[
              0.19062947051327297`, 0.3176940384889352, 0.9341674383834773], 
             UndirectedEdge[43, 50] -> 
             RGBColor[
              0.863436903239849, 0.8750924830296818, 0.6788826802327284], 
             UndirectedEdge[40, 45] -> 
             RGBColor[
              0.6384999408858367, 0.7056022661858156, 0.9047323444968761], 
             UndirectedEdge[1, 11] -> 
             RGBColor[
              0.7566074798031552, 0.5290632372351152, 0.5773124587085322], 
             UndirectedEdge[1, 40] -> 
             RGBColor[
              0.8296075008468684, 0.8664255492727166, 0.9188068302496923], 
             UndirectedEdge[1, 22] -> 
             RGBColor[
              0.5581701461909538, 0.6514681641668885, 0.9587469058501004], 
             UndirectedEdge[3, 11] -> 
             RGBColor[
              0.9175255079416582, 0.6521609055373685, 0.40508171111602626`], 
             UndirectedEdge[17, 39] -> 
             RGBColor[
              0.5987393800589458, 0.6618427532286324, 0.8511179576728698], 
             UndirectedEdge[28, 32] -> 
             RGBColor[
              0.27508915206047163`, 0.4058251552863489, 0.9390007757624828], 
             UndirectedEdge[6, 22] -> 
             RGBColor[
              0.34961429853603404`, 0.4723056244283752, 0.9436787659255457], 
             UndirectedEdge[6, 11] -> 
             RGBColor[
              0.5480516321482354, 0.3499006974966019, 0.5622443187839776], 
             UndirectedEdge[15, 49] -> 
             RGBColor[
              0.2333954318576619, 0.362643775380447, 0.93660289661547], 
             UndirectedEdge[26, 53] -> 
             RGBColor[
              0.48145282006883466`, 0.5794710594484616, 0.9545307164925945], 
             UndirectedEdge[7, 45] -> 
             RGBColor[
              0.2506938589312777, 0.38082551901844086`, 0.9375880164465829], 
             UndirectedEdge[10, 29] -> 
             RGBColor[
              0.20847115959524953`, 0.33644678494251695`, 0.9351834961822821],
              UndirectedEdge[12, 30] -> 
             RGBColor[
              0.217247411027305, 0.3456711816440869, 0.9356832907180372], 
             UndirectedEdge[5, 13] -> 
             RGBColor[
              0.18736460138149158`, 0.3142624540267739, 0.9339815089163632], 
             UndirectedEdge[26, 43] -> 
             RGBColor[
              0.8412589261327024, 0.8577668787547099, 0.6766721867396674], 
             UndirectedEdge[9, 47] -> 
             RGBColor[
              0.5762640257320939, 0.30151026676458836`, 0.5536697818126854], 
             UndirectedEdge[23, 41] -> 
             RGBColor[
              0.23216386572362652`, 0.3613493212877729, 0.9365327607460755], 
             UndirectedEdge[27, 45] -> 
             RGBColor[
              0.2786950682770766, 0.41025656542008904`, 0.939182643894749], 
             UndirectedEdge[23, 37] -> 
             RGBColor[
              0.21557914857182575`, 0.34391773202942927`, 0.9355882856391708],
              UndirectedEdge[2, 21] -> 
             RGBColor[
              0.21788808808822976`, 0.3463445738563906, 0.93571977632886], 
             UndirectedEdge[10, 32] -> 
             RGBColor[
              0.23625536295363525`, 0.3656497442924196, 0.9367657654604968], 
             UndirectedEdge[11, 49] -> 
             RGBColor[
              0.537935128367931, 0.33926761060011545`, 0.5616681988597154], 
             UndirectedEdge[24, 30] -> 
             RGBColor[
              0.21999398386288377`, 0.34855800383705593`, 0.935839703977833], 
             UndirectedEdge[39, 45] -> 
             RGBColor[
              0.24742390860209026`, 0.3773885938956394, 0.9374017976127935], 
             UndirectedEdge[28, 29] -> 
             RGBColor[
              0.24730494870208594`, 0.3766221959364462, 0.9374185064842682], 
             UndirectedEdge[31, 43] -> 
             RGBColor[
              0.6558138023352627, 0.7047692083784438, 0.6623825345569108], 
             UndirectedEdge[8, 28] -> 
             RGBColor[
              0.566500948702086, 0.2909886959364462, 0.5527770064842682], 
             UndirectedEdge[13, 27] -> 
             RGBColor[
              0.22641179608905126`, 0.3553035313995553, 0.9362051888898109], 
             UndirectedEdge[27, 28] -> 
             RGBColor[
              0.2914003401981613, 0.4229692482081206, 0.9399296737966838], 
             UndirectedEdge[5, 7] -> 
             RGBColor[
              0.20006937893879223`, 0.3276159807689192, 0.9347050272032175], 
             UndirectedEdge[4, 46] -> 
             RGBColor[
              0.18887717980980184`, 0.31585226985793946`, 0.9340676480201964],
              UndirectedEdge[28, 40] -> 
             RGBColor[
              0.6512052128069215, 0.7183149489738472, 0.9054793743988109], 
             UndirectedEdge[8, 52] -> 
             RGBColor[
              0.9047637792171876, 0.55975338973049, 0.2942250750590857], 
             UndirectedEdge[10, 38] -> 
             RGBColor[
              0.21626373981777264`, 0.34463728083451145`, 0.9356272720978654],
              UndirectedEdge[26, 44] -> 
             RGBColor[
              0.46545470013116835`, 0.5626560210545848, 0.9536196472292418], 
             UndirectedEdge[19, 23] -> 
             RGBColor[
              0.21456450683531092`, 0.3428512792323505, 0.9355305032933042], 
             UndirectedEdge[9, 12] -> 
             RGBColor[
              0.294658140875038, 0.4246440715119715, 0.9401792523309427], 
             UndirectedEdge[22, 47] -> 
             RGBColor[
              0.6308887242377812, 0.34882343509303826`, 0.5571504192987435], 
             UndirectedEdge[19, 49] -> 
             RGBColor[
              0.22695613480814922`, 0.3558756659063954, 0.9362361881745865], 
             UndirectedEdge[22, 23] -> 
             RGBColor[
              0.3271061667828914, 0.4486481508578438, 0.9423969611200012], 
             UndirectedEdge[4, 28] -> 
             RGBColor[
              0.2533452382211379, 0.382970923197445, 0.9377624920365706], 
             UndirectedEdge[36, 49] -> 
             RGBColor[
              0.2160793754857819, 0.3444435022322154, 0.9356167728219011], 
             UndirectedEdge[15, 23] -> 
             RGBColor[
              0.2210038038848236, 0.3496193887064021, 0.9358972117341877], 
             UndirectedEdge[3, 8] -> 
             RGBColor[
              0.9058212648805357, 0.5621969645375691, 0.3938737147426436], 
             UndirectedEdge[11, 50] -> 
             RGBColor[
              0.7930667111548618, 0.5575454658674895, 0.580946374158782], 
             UndirectedEdge[9, 24] -> 
             RGBColor[
              0.2974047137106167, 0.4275308937049405, 0.9403356655907384], 
             UndirectedEdge[24, 26] -> 
             RGBColor[
              0.48062799375397575`, 0.578604114694536, 0.9544837438541844], 
             UndirectedEdge[40, 47] -> 
             RGBColor[
              0.9023260788936956, 0.5637808201988664, 0.5172103436983355], 
             UndirectedEdge[12, 26] -> 
             RGBColor[
              0.477881420918397, 0.575717292501567, 0.9543273305943886], 
             UndirectedEdge[19, 20] -> 
             RGBColor[
              0.26030288902306153`, 0.390925218892602, 0.9381352364950238], 
             UndirectedEdge[15, 41] -> 
             RGBColor[
              0.2428081549405094, 0.3725371441416328, 0.9371389372701622], 
             UndirectedEdge[50, 52] -> 
             RGBColor[
              0.868807247310927, 0.8932079145981802, 0.6997454528444851], 
             UndirectedEdge[22, 40] -> 
             RGBColor[
              0.7152901735537565, 0.7738221209689736, 0.9095628114294935], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.5876654540043562, 0.38914664060292226`, 0.5645878024022752], 
             UndirectedEdge[6, 40] -> 
             RGBColor[
              0.6210516531919485, 0.6872630095342034, 0.9037386903251377], 
             UndirectedEdge[21, 41] -> 
             RGBColor[
              0.22003653072721685`, 0.348602723289097, 0.9358421269588143], 
             UndirectedEdge[20, 36] -> 
             RGBColor[
              0.2494261297006942, 0.37949305521842197`, 0.9375158211423384], 
             UndirectedEdge[2, 4] -> 
             RGBColor[
              0.22033945526972104`, 0.3489211161897942, 0.9358593780633733], 
             UndirectedEdge[3, 47] -> 
             RGBColor[
              0.9061240796693959, 0.5645245316990346, 0.39416369052643646`], 
             UndirectedEdge[25, 42] -> 
             RGBColor[
              0.18795630199633884`, 0.3148843688889642, 0.9340152053910362], 
             UndirectedEdge[23, 49] -> 
             RGBColor[
              0.22275114264077903`, 0.3514559525265871, 0.9359967200913832], 
             UndirectedEdge[8, 26] -> 
             RGBColor[
              0.7591844909865928, 0.4502559205927183, 0.5675278842923386], 
             UndirectedEdge[25, 31] -> 
             RGBColor[
              0.26201246704841596`, 0.39074224773682065`, 0.9383050862970239],
              UndirectedEdge[15, 19] -> 
             RGBColor[
              0.2252087960521938, 0.35403910208621037`, 0.9361366798173909], 
             UndirectedEdge[8, 27] -> 
             RGBColor[
              0.5422183914960754, 0.2661075522716744, 0.5513706673124157], 
             UndirectedEdge[5, 6] -> 
             RGBColor[
              0.2221995858756287, 0.35087623139569546`, 0.935965309749563], 
             UndirectedEdge[33, 50] -> 
             RGBColor[
              0.4665191409935649, 0.5577899600608082, 0.954627756067842], 
             UndirectedEdge[1, 47] -> 
             RGBColor[
              0.7452060515308929, 0.4414268633967813, 0.5663944381189424], 
             UndirectedEdge[2, 28] -> 
             RGBColor[
              0.282677114452755, 0.4138005848652416, 0.9394328989953389], 
             UndirectedEdge[27, 29] -> 
             RGBColor[
              0.2230223914960754, 0.3517410522716744, 0.9360121673124157], 
             UndirectedEdge[2, 46] -> 
             RGBColor[
              0.21820905604141894`, 0.34668193152573606`, 0.9357380549789647],
              UndirectedEdge[34, 53] -> 
             RGBColor[
              0.22218845587757008`, 0.3508645330620532, 0.935964675912639], 
             UndirectedEdge[47, 50] -> 
             RGBColor[
              0.7816652828825996, 0.4699090920291557, 0.5700283535691922], 
             UndirectedEdge[13, 45] -> 
             RGBColor[
              0.23798908137397706`, 0.36747199227629557`, 0.9368644981597286],
              UndirectedEdge[16, 44] -> 
             RGBColor[
              0.20492827886491521`, 0.33272299266332317`, 0.9349817343659119],
              UndirectedEdge[11, 22] -> 
             RGBColor[
              0.6422901525100434, 0.43645980893137215`, 0.5680684398883333], 
             UndirectedEdge[1, 7] -> 
             RGBColor[
              0.4418014188923094, 0.5416488021053419, 0.951662502199399], 
             UndirectedEdge[4, 29] -> 
             RGBColor[
              0.184967289519052, 0.31174272726099883`, 0.9338449855523026], 
             UndirectedEdge[12, 24] -> 
             RGBColor[
              0.25745943269918714`, 0.3879365660106663, 0.9379733058638959], 
             UndirectedEdge[17, 27] -> 
             RGBColor[
              0.6300105397339321, 0.694710724753082, 0.8528988039548253], 
             UndirectedEdge[5, 14] -> 
             RGBColor[
              0.18614600137097864`, 0.3129816281520216, 0.9339121114485218], 
             UndirectedEdge[26, 52] -> 
             RGBColor[
              0.8466292702037803, 0.8758823103232083, 0.6975349593514243], 
             UndirectedEdge[30, 34] -> 
             RGBColor[
              0.18115160789082901`, 0.3077322039415481, 0.9336276881283703], 
             UndirectedEdge[2, 20] -> 
             RGBColor[
              0.27575380527239, 0.40716511151531803`, 0.9390151433178409], 
             UndirectedEdge[6, 32] -> 
             RGBColor[
              0.24493559244549873`, 0.37477321584670514`, 0.9372600916888096],
              UndirectedEdge[2, 37] -> 
             RGBColor[
              0.23523505698852443`, 0.3645773380319536, 0.9367076605451912], 
             UndirectedEdge[17, 50] -> 
             RGBColor[
              0.8691546163315961, 0.8961846973490979, 0.871266514427809], 
             UndirectedEdge[22, 43] -> 
             RGBColor[
              0.7126603445950306, 0.7540068260935643, 0.6660047459622797], 
             UndirectedEdge[41, 46] -> 
             RGBColor[
              0.22035749868040602`, 0.3489400809584425, 0.9358604056089189], 
             UndirectedEdge[1, 52] -> 
             RGBColor[
              0.8323480159592205, 0.8647256859658058, 0.6961115373942353], 
             UndirectedEdge[29, 39] -> 
             RGBColor[
              0.1917512318210891, 0.3188730807472247, 0.9342313210304602], 
             UndirectedEdge[17, 38] -> 
             RGBColor[
              0.5937077284603798, 0.6565541683734022, 0.850831412557993], 
             UndirectedEdge[43, 52] -> 
             RGBColor[
              0.9868382143632972, 0.9672643478924816, 0.4033693775064146], 
             UndirectedEdge[17, 31] -> 
             RGBColor[
              0.6615315154270097, 0.7258614226978599, 0.8547663687519915], 
             UndirectedEdge[10, 13] -> 
             RGBColor[
              0.21186056418822544`, 0.3400092640703979, 0.9353765177596773], 
             UndirectedEdge[43, 47] -> 
             RGBColor[
              0.8996962499349697, 0.5439655253234571, 0.2736522782311217], 
             UndirectedEdge[2, 36] -> 
             RGBColor[
              0.22334365592964228`, 0.35207872156069475`, 0.9360304628466392],
              UndirectedEdge[22, 32] -> 
             RGBColor[
              0.3391741128073067, 0.4613323272814754, 0.9430842127931653], 
             UndirectedEdge[3, 45] -> 
             RGBColor[
              0.6422979416615369, 0.7063459776859837, 0.781685691324977], 
             UndirectedEdge[21, 46] -> 
             RGBColor[
              0.1864258126283106, 0.3132757275245359, 0.9339280462856832], 
             UndirectedEdge[17, 28] -> 
             RGBColor[
              0.6542930969399425, 0.7195918684178539, 0.8543051431266777], 
             UndirectedEdge[22, 49] -> 
             RGBColor[
              0.33949779475572966`, 0.46167253753188875`, 0.9431026460012835],
              UndirectedEdge[24, 52] -> 
             RGBColor[
              0.6262072819845705, 0.6881015838323077, 0.6811809346209315], 
             UndirectedEdge[15, 20] -> 
             RGBColor[
              0.26674218607257416`, 0.3976933283666536, 0.9385019449359073], 
             UndirectedEdge[10, 27] -> 
             RGBColor[
              0.2525665510913249, 0.38279383721419136`, 0.9376946634946978], 
             UndirectedEdge[11, 20] -> 
             RGBColor[
              0.5712818825828434, 0.37431716358632205`, 0.5635672471801527], 
             UndirectedEdge[6, 45] -> 
             RGBColor[
              0.2728240658681142, 0.40408576964521714`, 0.9388482989929283], 
             UndirectedEdge[35, 42] -> 
             RGBColor[
              0.18140949876740853`, 0.30800326360405916`, 0.9336423746322762],
              UndirectedEdge[6, 14] -> 
             RGBColor[
              0.219322193669576, 0.3478519097499311, 0.9358014465201487], 
             UndirectedEdge[32, 39] -> 
             RGBColor[
              0.21953543517947482`, 0.34807604009712734`, 0.9358135903086748],
              UndirectedEdge[7, 19] -> 
             RGBColor[
              0.21494243165161708`, 0.3432485021761056, 0.9355520255525032], 
             UndirectedEdge[4, 27] -> 
             RGBColor[
              0.2290626810151274, 0.3580897795326732, 0.9363561528647182], 
             UndirectedEdge[4, 38] -> 
             RGBColor[
              0.1927598697415751, 0.31993322315299333`, 0.9342887614678859], 
             UndirectedEdge[15, 36] -> 
             RGBColor[
              0.21433203672982648`, 0.3426069384120303, 0.9355172644647056], 
             UndirectedEdge[12, 44] -> 
             RGBColor[
              0.24228613907637978`, 0.37198847237071514`, 0.9371092092389532],
              UndirectedEdge[1, 15] -> 
             RGBColor[
              0.4520677832928861, 0.5524394020154467, 0.9522471564642867], 
             UndirectedEdge[3, 26] -> 
             RGBColor[
              0.8476867558671286, 0.8783258851302873, 0.7971835990349821], 
             UndirectedEdge[27, 32] -> 
             RGBColor[
              0.2508065948544611, 0.38094401162157704`, 0.9375944365906304], 
             UndirectedEdge[6, 23] -> 
             RGBColor[
              0.2328676464210834, 0.3620890394230736, 0.9365728400156454], 
             UndirectedEdge[36, 41] -> 
             RGBColor[
              0.2254920985686294, 0.35433687099340117`, 0.9361528134765934], 
             UndirectedEdge[32, 40] -> 
             RGBColor[
              0.6106114674632213, 0.6762897123873035, 0.9031441371927573], 
             UndirectedEdge[3, 50] -> 
             RGBColor[
              0.8698647329742752, 0.8956514894052592, 0.7993940925280429], 
             UndirectedEdge[29, 46] -> 
             RGBColor[
              0.18283689029074987`, 0.3095035425969407, 0.933723662467894], 
             UndirectedEdge[10, 40] -> 
             RGBColor[
              0.612371423700085, 0.6781395379799178, 0.9032443640968248], 
             UndirectedEdge[25, 44] -> 
             RGBColor[
              0.2118623090038384, 0.34001109798223483`, 0.9353766171243453], 
             UndirectedEdge[37, 46] -> 
             RGBColor[
              0.20377278152860526`, 0.33150849170009883`, 0.9349159305020143],
              UndirectedEdge[11, 47] -> 
             RGBColor[
              0.8293260578499826, 0.2264185081612649, 0.1757159721571755], 
             UndirectedEdge[6, 49] -> 
             RGBColor[
              0.2452592743939217, 0.3751134260971185, 0.9372785248969278], 
             UndirectedEdge[11, 26] -> 
             RGBColor[
              0.7708887340477152, 0.5402198615925177, 0.5787358806657212], 
             UndirectedEdge[1, 8] -> 
             RGBColor[
              0.7449032367420328, 0.43909929623531574`, 0.5661044623351495], 
             UndirectedEdge[22, 51] -> 
             RGBColor[
              0.3241463393277535, 0.44553718453859437`, 0.9422284033251034], 
             UndirectedEdge[2, 29] -> 
             RGBColor[
              0.21429916575066904`, 0.3425723889287954, 0.9355153925110709], 
             UndirectedEdge[31, 50] -> 
             RGBColor[
              0.5377828352828925, 0.6307127750841425, 0.9587586098949813], 
             UndirectedEdge[21, 37] -> 
             RGBColor[
              0.20345181357541609`, 0.3311711340307534, 0.9348976518519097], 
             UndirectedEdge[11, 17] -> 
             RGBColor[
              0.916815391298979, 0.652694113481207, 0.47695413301579226`], 
             UndirectedEdge[9, 43] -> 
             RGBColor[
              0.6580356460893433, 0.7066936577651144, 0.6625241084762216], 
             UndirectedEdge[12, 52] -> 
             RGBColor[
              0.6234607091489919, 0.6852147616393387, 0.6810245213611358], 
             UndirectedEdge[31, 33] -> 
             RGBColor[
              0.2588960400889786, 0.3874666854095703, 0.9381276103920244], 
             UndirectedEdge[31, 42] -> 
             RGBColor[
              0.2561035693262291, 0.3845316215850481, 0.9379685833131761], 
             UndirectedEdge[38, 39] -> 
             RGBColor[
              0.1995438120436122, 0.3270635766392192, 0.9346750969460436], 
             UndirectedEdge[19, 22] -> 
             RGBColor[
              0.33131115895026153`, 0.4530678642376521, 0.9426364292032046], 
             UndirectedEdge[5, 22] -> 
             RGBColor[
              0.31643810623743673`, 0.4374353428304657, 0.9417894308539188], 
             UndirectedEdge[20, 49] -> 
             RGBColor[
              0.2684895248285296, 0.39952989218683865`, 0.9386014532931028], 
             UndirectedEdge[7, 40] -> 
             RGBColor[
              0.598921446255112, 0.6640027589074271, 0.9024784077787922], 
             UndirectedEdge[18, 48] -> 
             RGBColor[
              0.19118239032183038`, 0.3182751922648696, 0.934198926348603], 
             UndirectedEdge[17, 26] -> 
             RGBColor[
              0.8469766392244494, 0.878859093074126, 0.8690560209347482], 
             UndirectedEdge[41, 52] -> 
             RGBColor[
              0.6230883876068438, 0.6848234280919918, 0.6810033182001107], 
             UndirectedEdge[16, 42] -> 
             RGBColor[
              0.18102227185741565`, 0.30759626357005254`, 0.933620322632603], 
             UndirectedEdge[9, 26] -> 
             RGBColor[
              0.5178267019298266, 0.6153116201958412, 0.9566896903212312], 
             UndirectedEdge[8, 50] -> 
             RGBColor[
              0.7813624680937394, 0.46758152486769017`, 0.5697383777853994], 
             UndirectedEdge[7, 13] -> 
             RGBColor[
              0.19841058674325243`, 0.3258724849979071, 0.9346105614416447], 
             UndirectedEdge[6, 20] -> 
             RGBColor[
              0.278606028608834, 0.4101629790833251, 0.9391775732173651], 
             UndirectedEdge[52, 53] -> 
             RGBColor[
              0.6270321082994295, 0.6889685285862334, 0.6812279072593417], 
             UndirectedEdge[14, 32] -> 
             RGBColor[
              0.20888200794084866`, 0.3368786126030313, 0.9352068933877684], 
             UndirectedEdge[32, 45] -> 
             RGBColor[
              0.26238388013938685`, 0.3931124724983173, 0.938253745860548], 
             UndirectedEdge[11, 43] -> 
             RGBColor[
              0.911097678207232, 0.6316018991617909, 0.2845702988207115], 
             UndirectedEdge[7, 22] -> 
             RGBColor[
              0.32748409159919756`, 0.4490453738015989, 0.9424184833792002], 
             UndirectedEdge[10, 28] -> 
             RGBColor[
              0.2768491082973355, 0.40767498087896314`, 0.9391010026665503], 
             UndirectedEdge[8, 31] -> 
             RGBColor[
              0.5737393671891531, 0.29725825021645225`, 0.5532382321095819], 
             UndirectedEdge[14, 22] -> 
             RGBColor[
              0.31356071403138397`, 0.4344110211847013, 0.9416255676245044], 
             UndirectedEdge[31, 44] -> 
             RGBColor[
              0.2800095763337287, 0.4096583506783188, 0.9393299950464852], 
             UndirectedEdge[30, 53] -> 
             RGBColor[
              0.22081881017774269`, 0.3494249485909815, 0.935886676616243], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.19156041251653394`, 0.31867251755949455`, 0.9342204541533576],
              UndirectedEdge[29, 38] -> 
             RGBColor[
              0.1867195802225231, 0.3135844958919945, 0.9339447759155833], 
             UndirectedEdge[8, 17] -> 
             RGBColor[
              0.9051111482378567, 0.5627301724814077, 0.4657461366424096], 
             UndirectedEdge[2, 41] -> 
             RGBColor[
              0.2518197741403252, 0.38200892729029723`, 0.9376521356520958], 
             UndirectedEdge[28, 45] -> 
             RGBColor[
              0.3029776254830871, 0.4351377090848609, 0.9405889830666015], 
             UndirectedEdge[12, 53] -> 
             RGBColor[
              0.25828425901404606`, 0.38880351076459196`, 0.938020278502306], 
             UndirectedEdge[47, 49] -> 
             RGBColor[
              0.5265337000956688, 0.25163123676178156`, 0.5507501782701256], 
             UndirectedEdge[25, 35] -> 
             RGBColor[
              0.1873183964895954, 0.31421388975583164`, 0.9339788776161239], 
             UndirectedEdge[3, 27] -> 
             RGBColor[
              0.6307206563766111, 0.6941775168092434, 0.7810263820550593], 
             UndirectedEdge[5, 45] -> 
             RGBColor[
              0.23964787356951683`, 0.36921548804730764`, 0.9369589639213014],
              UndirectedEdge[13, 14] -> 
             RGBColor[
              0.18448720917543884`, 0.31123813238100956`, 0.9338176456869489],
              UndirectedEdge[22, 45] -> 
             RGBColor[
              0.36706258622992216`, 0.4906448810799874, 0.9446724200972841], 
             UndirectedEdge[9, 52] -> 
             RGBColor[
              0.6634059901604215, 0.724809089333613, 0.6833868810879784], 
             UndirectedEdge[20, 41] -> 
             RGBColor[
              0.2779022479113771, 0.40942326094802445`, 0.9391374939477951], 
             UndirectedEdge[43, 45] -> 
             RGBColor[
              0.6358701119271107, 0.6857869713104062, 0.6611742790296622], 
             UndirectedEdge[20, 37] -> 
             RGBColor[
              0.2613175307595763, 0.3919916716896808, 0.9381930188408905], 
             UndirectedEdge[20, 47] -> 
             RGBColor[
              0.5598804543105811, 0.28668078974798816`, 0.5526492265905629], 
             UndirectedEdge[8, 45] -> 
             RGBColor[
              0.5537956767810012, 0.27827601314841466`, 0.5520299765823334], 
             UndirectedEdge[26, 47] -> 
             RGBColor[
              0.759487305775453, 0.4525834877541838, 0.5678178600761314], 
             UndirectedEdge[41, 49] -> 
             RGBColor[
              0.24455549369646482`, 0.3743737079618179, 0.9372384456273578], 
             UndirectedEdge[9, 34] -> 
             RGBColor[
              0.258562337738562, 0.38670509380943274`, 0.9381236497412757], 
             UndirectedEdge[1, 51] -> 
             RGBColor[
              0.43846366662086533`, 0.5381406128423374, 0.9514724221453023], 
             UndirectedEdge[47, 52] -> 
             RGBColor[
              0.9050665940060477, 0.5620809568919556, 0.29451505084287855`], 
             UndirectedEdge[6, 7] -> 
             RGBColor[
              0.2332455712373896, 0.3624862623668287, 0.9365943622748444], 
             UndirectedEdge[11, 53] -> 
             RGBColor[
              0.5512915721433642, 0.3533060798555427, 0.5624288285736385], 
             UndirectedEdge[35, 44] -> 
             RGBColor[
              0.2053155057749081, 0.3331299926973298, 0.9350037863655851], 
             UndirectedEdge[2, 15] -> 
             RGBColor[
              0.24065971230152228`, 0.3702789947089264, 0.937016586640208], 
             UndirectedEdge[17, 43] -> 
             RGBColor[
              0.9871855833839662, 0.9702411306433992, 0.5748904390897385], 
             UndirectedEdge[3, 28] -> 
             RGBColor[
              0.6550032135826217, 0.7190586604740152, 0.7824327212269118], 
             UndirectedEdge[8, 40] -> 
             RGBColor[
              0.9020232641048356, 0.5614532530374009, 0.5169203679145428], 
             UndirectedEdge[1, 43] -> 
             RGBColor[
              0.8269776718881424, 0.8466102543973073, 0.6752487647824784], 
             UndirectedEdge[1, 20] -> 
             RGBColor[
              0.4871618762637538, 0.5893255188218384, 0.9542457131419196], 
             UndirectedEdge[8, 47] -> 
             RGBColor[
              0.8176218147888601, 0.1364545671614655, 0.16450797578379284`], 
             UndirectedEdge[11, 40] -> 
             RGBColor[
              0.9137275071659579, 0.6514171940372002, 0.5281283642879253], 
             UndirectedEdge[13, 39] -> 
             RGBColor[
              0.19514063641406498`, 0.32243555987510564`, 0.9344243426078553],
              UndirectedEdge[8, 11] -> 
             RGBColor[
              0.8290232430611224, 0.2240909409997994, 0.17542599637338263`], 
             UndirectedEdge[15, 21] -> 
             RGBColor[
              0.20887646888841394`, 0.33687279070772624`, 0.9352065779469265],
              UndirectedEdge[15, 46] -> 
             RGBColor[
              0.2091974368416031, 0.33721014837707164`, 0.9352248565970311], 
             UndirectedEdge[44, 52] -> 
             RGBColor[
              0.6110339883617631, 0.6721534901923565, 0.680316837995989], 
             UndirectedEdge[17, 52] -> 
             RGBColor[
              0.9925559274550442, 0.9883565622118977, 0.5957532117014953], 
             UndirectedEdge[20, 51] -> 
             RGBColor[
              0.25313806940055344`, 0.38339453919354427`, 0.9377272106169228],
              UndirectedEdge[40, 43] -> 
             RGBColor[
              0.9840976992509451, 0.9689642111993925, 0.6260646703618716], 
             UndirectedEdge[42, 44] -> 
             RGBColor[
              0.20595341128165154`, 0.33380047183046235`, 0.9350401141404976],
              UndirectedEdge[24, 53] -> 
             RGBColor[
              0.26103083184962483`, 0.39169033295756095`, 0.9381766917621017],
              UndirectedEdge[3, 43] -> 
             RGBColor[
              0.9878957000266453, 0.9697079226995606, 0.5030180171899725], 
             UndirectedEdge[2, 17] -> 
             RGBColor[
              0.6212873139885257, 0.685542061410203, 0.8524020291534804], 
             UndirectedEdge[17, 45] -> 
             RGBColor[
              0.6415878250188578, 0.7068791856298223, 0.853558113224743], 
             UndirectedEdge[20, 23] -> 
             RGBColor[
              0.2560978968556913, 0.3865055055127937, 0.9378957684118205], 
             UndirectedEdge[3, 17] -> 
             RGBColor[
              0.9936134131183925, 0.9908001370189767, 0.6954018513850533], 
             UndirectedEdge[4, 39] -> 
             RGBColor[
              0.1977915213401411, 0.32522180800822353`, 0.9345753065827627], 
             UndirectedEdge[23, 36] -> 
             RGBColor[
              0.2036877475129436, 0.33141911555817044`, 0.9349110879406188], 
             UndirectedEdge[5, 32] -> 
             RGBColor[
              0.2117594001469014, 0.33990293424879564`, 0.9353707566171827], 
             UndirectedEdge[1, 19] -> 
             RGBColor[
              0.44562848624337337`, 0.5456712925413951, 0.9518804480234033], 
             UndirectedEdge[9, 18] -> 
             RGBColor[
              0.26004152690094556`, 0.38825981540510757`, 0.9382078873758093],
              UndirectedEdge[1, 49] -> 
             RGBColor[
              0.4538151220488415, 0.5542759658356318, 0.9523466648214823], 
             UndirectedEdge[20, 21] -> 
             RGBColor[
              0.24397056185928168`, 0.3737589075141179, 0.9372051346245593], 
             UndirectedEdge[40, 50] -> 
             RGBColor[
              0.8660667321985749, 0.8949077779050911, 0.9224407456999422], 
             UndirectedEdge[8, 22] -> 
             RGBColor[
              0.630585909448921, 0.3464958679315727, 0.5568604435149508]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> Medium, 
           VertexSize -> {1.2}, VertexStyle -> {
             EdgeForm[None], 7 -> 
             RGBColor[
              0.21111536430055308`, 0.3392260117400524, 0.9353340797284988], 
             4 -> RGBColor[
              0.19100757903810398`, 0.3180914545219976, 0.934188971104605], 
             44 -> RGBColor[
              0.22985941828915113`, 0.358927200923733, 0.9364015258738065], 1 -> 
             RGBColor[
              0.6724874734840657, 0.7440715924706315, 0.9679909246702991], 36 -> 
             RGBColor[
              0.19701598035794649`, 0.3244066652637987, 0.9345311406711367], 
             17 -> RGBColor[
              0.9929032964757133, 0.9913333449628153, 0.7672742732848192], 33 -> 
             RGBColor[
              0.187632345799651, 0.31454387038623605`, 0.9339967565648851], 
             15 -> RGBColor[
              0.23164809310170648`, 0.36080721156026196`, 0.9365033882582744],
              20 -> RGBColor[
              0.3018362790434419, 0.43457944517304525`, 0.9405005016135402], 
             24 -> RGBColor[
              0.2602060055347659, 0.3908233882036353, 0.9381297191236917], 31 -> 
             RGBColor[
              0.3301597343783062, 0.46038950043290455`, 0.9422584642191638], 
             19 -> RGBColor[
              0.2187694990026811, 0.3472709926121587, 0.9357699713765075], 18 -> 
             RGBColor[
              0.18547963191542358`, 0.3122812316039695, 0.9338741626938332], 
             5 -> RGBColor[
              0.18902339357703138`, 0.31600594979778596`, 0.9340759746779361],
              46 -> RGBColor[
              0.18674678058149974`, 0.3136130851938813, 0.9339463249357878], 
             16 -> RGBColor[
              0.17999713944067933`, 0.30651878440291336`, 0.9335619428580173],
              23 -> RGBColor[
              0.21035951466794073`, 0.3384315658525422, 0.9352910352101009], 
             50 -> RGBColor[
              0.7454059361874789, 0.8010360497353803, 0.9752587555707988], 29 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 52 -> 
             RGBColor[
              0.9922085584343752, 0.9853797794609801, 0.42423215011817145`], 
             51 -> RGBColor[
              0.20443985975766502`, 0.33220963321404323`, 0.9349539196203054],
              3 -> RGBColor[
              0.9943235297610715, 0.9902669290751381, 0.6235294294852872], 32 -> 
             RGBColor[
              0.2344954067167714, 0.3637999186998053, 0.9366655385564293], 48 -> 
             RGBColor[
              0.19688514872823715`, 0.32426915292576974`, 0.9345236900033729],
              42 -> 
             RGBColor[
              0.18204740427415195`, 0.30867374273719167`, 0.9336787024071885],
              12 -> RGBColor[
              0.2547128598636084, 0.3850497438176973, 0.9378168926041001], 39 -> 
             RGBColor[
              0.2045754636421782, 0.3323521614944494, 0.9349616420609204], 25 -> 
             RGBColor[
              0.1938651997185257, 0.3210949950407367, 0.934351708374884], 28 -> 
             RGBColor[
              0.3156828974041719, 0.44785039187289244`, 0.9413360129685363], 
             35 -> RGBColor[
              0.18077159326066508`, 0.30733278447092666`, 0.9336060468573637],
              43 -> RGBColor[
              0.9814678702922192, 0.9491489163239831, 0.38250660489465776`], 
             40 -> RGBColor[
              0.986727528209671, 0.9887795060748018, 0.8696227358290854], 34 -> 
             RGBColor[
              0.18252125359065643`, 0.3091717884126198, 0.9337056874247662], 
             10 -> RGBColor[
              0.2380153191904991, 0.3674995698850339, 0.9368659923645642], 38 -> 
             RGBColor[
              0.1945121604450462, 0.321774991783989, 0.9343885518311666], 26 -> 
             RGBColor[
              0.7010499819731856, 0.7663848411854366, 0.9708377685846771], 6 -> 
             RGBColor[
              0.2553757781742261, 0.38574651299360496`, 0.93785464482119], 2 -> 
             RGBColor[
              0.2496713315013381, 0.3797507778575908, 0.9375297850221416], 27 -> 
             RGBColor[
              0.2671177829921508, 0.39808810454334875`, 0.9385233346248313], 
             21 -> RGBColor[
              0.18610484467512142`, 0.31293836985519047`, 0.9339097676355785],
              53 -> RGBColor[
              0.26185565816448375`, 0.3925572777114866, 0.9382236644005117], 
             30 -> RGBColor[
              0.1797819621910016, 0.3062926194704765, 0.9335496888319743], 13 -> 
             RGBColor[
              0.18570580918595178`, 0.31251895825576187`, 0.9338870431547904],
              49 -> RGBColor[
              0.23514277061361732`, 0.3644803392006321, 0.9367024049726655], 
             45 -> RGBColor[
              0.2902723535620023, 0.4224250262968293, 0.9398419531646668], 11 -> 
             RGBColor[
              0.8407274861222448, 0.3140548819995988, 0.1866339927467653], 14 -> 
             RGBColor[
              0.1832686091649259, 0.30995730650625725`, 0.9337482482191074], 
             22 -> RGBColor[
              0.443852818897842, 0.5588647358631454, 0.9495028870299015], 47 -> 
             RGBColor[
              0.8179246295777203, 0.13878213432293102`, 0.1647979515675857], 
             8 -> RGBColor[0.817319, 0.134127, 0.164218], 9 -> 
             RGBColor[
              0.3346034218864676, 0.4642383992062457, 0.9425416120577853], 37 -> 
             RGBColor[
              0.22079878247571078`, 0.34940389820631634`, 0.9358855360682407],
              41 -> RGBColor[
              0.2539682167793123, 0.38426707672300364`, 
               0.9377744862820501]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJwBYQOe/CFib1JlAgAAADUAAAACAAAA8CJ+ILsrEUAAlWZah0IEQEIidrVw
zRZAg2mGwP3j/T+azG4I/1QMQEsOyzG5FvM/+0uh324LFkASsKMATsrqP0Ef
Bxmx7hVABPi3QKBm9T8UzKQ5ZX0TQMrJBjRrQQFAimzHiHdGFEDGdBlQ/lH6
PzTU8CrqOg5AE/JYGK0P9j/thYEqlbQFQMjBx5rksQhAhCD45/N/E0DcZX3z
zvjdP9LbCD+wogxA+1obzXY5AkCi/+VQgGH8Pzj6If149ANAQ//R13zAFUCU
waVKItXaP/QqkRpzUxdAgSOJt/1B9j+8hnf3XcIWQB9DZcf0cwZAAGU55edq
tD84Kg9UeofVP/y9BOcRaBBAQe6ufuJV8j8WUrkSGdwAQNFXOWa94RJAz6S8
pwMPE0DbX/cjy14GQGB12nMo2hNAaP9xnNdaBUBA4imVRgEZQCTVKG+zegVA
RGdUgZ+HEkAlf0oTLJEAQAaEAg/GbhVA5PNj60DDCEAkSL3Z8UcBQHCE4OWL
kwVABBWhVX2w5j9GKzgmLhnlP6lMtCv51AVA9b986Zh+/z/p5xxynYQSQLiX
fKuZh+A/+az9GqBFE0CqzuSwNw/qPzKHcs8trxdAVvzbai0w4j+o5s0jIeTx
Pzq4wWrFeglAmr1efgfTAkCCaACk2UjrP6AFQp5OaBRA7t1brh0C8T/CF9m1
JAYBQAAAAAAAAAAA6Ptzs+Mm+T9SkHyvvg0LQAAAAAAAAAAAGgs1pleT5z8j
ZVztC4wXQMBnEBP/4wlA6KwdHyDsGEB2SkXsnGYHQJIC2ZDIahZAIhxFOjX7
5D+aXn+jGoMUQOBbwD7QSsU/mMucsRL5EEB0p3my1kn3P8i72ya8VhVAFtmB
uhEmBUCUrsLJd5HpP7hpCpXx69Q/g9EZveGLC0DUWj0aNyb8P9770N8hqfU/
Zs39hur78z/cOEp6CTwSQDo7b2AWPPE/WvUMN3M2GUCkniGyktb8P0VSBQ4b
6g5AjskzeLRpAUB+3tJD2sr6P405UccAEBJAE3xQvJvjEkDcOLzZqDsIQC3o
YWsztAhA7EINjQZY8z+KPP2hj1UTQFlSO6GO4ApAwWu3LAWvCUBOFpblDYUB
QO+Bc1K80AFAmju2CGVvB0B/HXmp
         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 6}], {
             RGBColor[
             0.4639316258291459, 0.5649090527321182, 0.9529227847457445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 7}], {
             RGBColor[
             0.4418014188923094, 0.5416488021053419, 0.951662502199399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 8}], {
             RGBColor[
             0.7449032367420328, 0.43909929623531574`, 0.5661044623351495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 9}], {
             RGBColor[
             0.5035454476852667, 0.6041549958384386, 0.9552662683640423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 11}], {
             RGBColor[
             0.7566074798031552, 0.5290632372351152, 0.5773124587085322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 15}], {
             RGBColor[
             0.4520677832928861, 0.5524394020154467, 0.9522471564642867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 19}], {
             RGBColor[
             0.44562848624337337`, 0.5456712925413951, 0.9518804480234033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 20}], {
             RGBColor[
             0.4871618762637538, 0.5893255188218384, 0.9542457131419196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 22}], {
             RGBColor[
             0.5581701461909538, 0.6514681641668885, 0.9587469058501004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 23}], {
             RGBColor[
             0.44142349407600323`, 0.5412515791615868, 0.9516409799402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 40}], {
             RGBColor[
             0.8296075008468684, 0.8664255492727166, 0.9188068302496923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 41}], {
             RGBColor[
             0.463227845131689, 0.5641693345968175, 0.9528827054761746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 43}], {
             RGBColor[
             0.8269776718881424, 0.8466102543973073, 0.6752487647824784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 47}], {
             RGBColor[
             0.7452060515308929, 0.4414268633967813, 0.5663944381189424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 49}], {
             RGBColor[
             0.4538151220488415, 0.5542759658356318, 0.9523466648214823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 51}], {
             RGBColor[
             0.43846366662086533`, 0.5381406128423374, 0.9514724221453023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 52}], {
             RGBColor[
             0.8323480159592205, 0.8647256859658058, 0.6961115373942353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 4}], {
             RGBColor[
             0.22033945526972104`, 0.3489211161897942, 0.9358593780633733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 15}], {
             RGBColor[
             0.24065971230152228`, 0.3702789947089264, 0.937016586640208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 17}], {
             RGBColor[
             0.6212873139885257, 0.685542061410203, 0.8524020291534804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 20}], {
             RGBColor[
             0.27575380527239, 0.40716511151531803`, 0.9390151433178409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 21}], {
             RGBColor[
             0.21788808808822976`, 0.3463445738563906, 0.93571977632886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 28}], {
             RGBColor[
             0.282677114452755, 0.4138005848652416, 0.9394328989953389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 29}], {
             RGBColor[
             0.21429916575066904`, 0.3425723889287954, 0.9355153925110709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 36}], {
             RGBColor[
             0.22334365592964228`, 0.35207872156069475`, 0.9360304628466392]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 37}], {
             RGBColor[
             0.23523505698852443`, 0.3645773380319536, 0.9367076605451912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 38}], {
             RGBColor[
             0.22209174597319215`, 0.3507628848207899, 0.9359591684266542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 41}], {
             RGBColor[
             0.2518197741403252, 0.38200892729029723`, 0.9376521356520958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 46}], {
             RGBColor[
             0.21820905604141894`, 0.34668193152573606`, 0.9357380549789647]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 8}], {
             RGBColor[
             0.9058212648805357, 0.5621969645375691, 0.3938737147426436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 11}], {
             RGBColor[
             0.9175255079416582, 0.6521609055373685, 0.40508171111602626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 17}], {
             RGBColor[
             0.9936134131183925, 0.9908001370189767, 0.6954018513850533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 26}], {
             RGBColor[
             0.8476867558671286, 0.8783258851302873, 0.7971835990349821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 27}], {
             RGBColor[
             0.6307206563766111, 0.6941775168092434, 0.7810263820550593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 28}], {
             RGBColor[
             0.6550032135826217, 0.7190586604740152, 0.7824327212269118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 31}], {
             RGBColor[
             0.6622416320696889, 0.7253282147540213, 0.7828939468522256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 40}], {
             RGBColor[
             0.9905255289853713, 0.98952321757497, 0.7465760826571863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 43}], {
             RGBColor[
             0.9878957000266453, 0.9697079226995606, 0.5030180171899725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 45}], {
             RGBColor[
             0.6422979416615369, 0.7063459776859837, 0.781685691324977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 47}], {
             RGBColor[
             0.9061240796693959, 0.5645245316990346, 0.39416369052643646`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 50}], {
             RGBColor[
             0.8698647329742752, 0.8956514894052592, 0.7993940925280429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 52}], {
             RGBColor[
             0.9932660440977233, 0.9878233542680591, 0.5238807898017294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 10}], {
             RGBColor[
             0.21451144911430153`, 0.3427955122035158, 0.9355274817345847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 17}], {
             RGBColor[
             0.5919554377569086, 0.6547123997424065, 0.8507316221947121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 27}], {
             RGBColor[
             0.2290626810151274, 0.3580897795326732, 0.9363561528647182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 28}], {
             RGBColor[
             0.2533452382211379, 0.382970923197445, 0.9377624920365706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 29}], {
             RGBColor[
             0.184967289519052, 0.31174272726099883`, 0.9338449855523026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 38}], {
             RGBColor[
             0.1927598697415751, 0.31993322315299333`, 0.9342887614678859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 39}], {
             RGBColor[
             0.1977915213401411, 0.32522180800822353`, 0.9345753065827627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 46}], {
             RGBColor[
             0.18887717980980184`, 0.31585226985793946`, 0.9340676480201964]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 6}], {
             RGBColor[
             0.2221995858756287, 0.35087623139569546`, 0.935965309749563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 7}], {
             RGBColor[
             0.20006937893879223`, 0.3276159807689192, 0.9347050272032175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 13}], {
             RGBColor[
             0.18736460138149158`, 0.3142624540267739, 0.9339815089163632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 14}], {
             RGBColor[
             0.18614600137097864`, 0.3129816281520216, 0.9339121114485218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 22}], {
             RGBColor[
             0.31643810623743673`, 0.4374353428304657, 0.9417894308539188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 32}], {
             RGBColor[
             0.2117594001469014, 0.33990293424879564`, 0.9353707566171827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 45}], {
             RGBColor[
             0.23964787356951683`, 0.36921548804730764`, 0.9369589639213014]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 7}], {
             RGBColor[
             0.2332455712373896, 0.3624862623668287, 0.9365943622748444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 11}], {
             RGBColor[
             0.5480516321482354, 0.3499006974966019, 0.5622443187839776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 14}], {
             RGBColor[
             0.219322193669576, 0.3478519097499311, 0.9358014465201487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 19}], {
             RGBColor[
             0.2370726385884536, 0.36650875280288187`, 0.9368123080988487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 20}], {
             RGBColor[
             0.278606028608834, 0.4101629790833251, 0.9391775732173651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 22}], {
             RGBColor[
             0.34961429853603404`, 0.4723056244283752, 0.9436787659255457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 23}], {
             RGBColor[
             0.2328676464210834, 0.3620890394230736, 0.9365728400156454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 32}], {
             RGBColor[
             0.24493559244549873`, 0.37477321584670514`, 0.9372600916888096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 40}], {
             RGBColor[
             0.6210516531919485, 0.6872630095342034, 0.9037386903251377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 45}], {
             RGBColor[
             0.2728240658681142, 0.40408576964521714`, 0.9388482989929283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 47}], {
             RGBColor[
             0.5366502038759732, 0.262264323658268, 0.5513262981943878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 49}], {
             RGBColor[
             0.2452592743939217, 0.3751134260971185, 0.9372785248969278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 51}], {
             RGBColor[
             0.22990781896594553`, 0.3589780731038241, 0.9364042822207477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 13}], {
             RGBColor[
             0.19841058674325243`, 0.3258724849979071, 0.9346105614416447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 14}], {
             RGBColor[
             0.1971919867327395, 0.3245916591231548, 0.934541163973803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 19}], {
             RGBColor[
             0.21494243165161708`, 0.3432485021761056, 0.9355520255525032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 22}], {
             RGBColor[
             0.32748409159919756`, 0.4490453738015989, 0.9424184833792002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 32}], {
             RGBColor[
             0.22280538550866225`, 0.35151296521992886`, 0.9359998091424641]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 40}], {
             RGBColor[
             0.598921446255112, 0.6640027589074271, 0.9024784077787922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 45}], {
             RGBColor[
             0.2506938589312777, 0.38082551901844086`, 0.9375880164465829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 10}], {
             RGBColor[
             0.5276671595952496, 0.250813284942517, 0.5505419961822822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 11}], {
             RGBColor[
             0.8290232430611224, 0.2240909409997994, 0.17542599637338263`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 17}], {
             RGBColor[
             0.9051111482378567, 0.5627301724814077, 0.4657461366424096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 22}], {
             RGBColor[
             0.630585909448921, 0.3464958679315727, 0.5568604435149508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 26}], {
             RGBColor[
             0.7591844909865928, 0.4502559205927183, 0.5675278842923386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 27}], {
             RGBColor[
             0.5422183914960754, 0.2661075522716744, 0.5513706673124157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 28}], {
             RGBColor[
             0.566500948702086, 0.2909886959364462, 0.5527770064842682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 31}], {
             RGBColor[
             0.5737393671891531, 0.29725825021645225`, 0.5532382321095819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 40}], {
             RGBColor[
             0.9020232641048356, 0.5614532530374009, 0.5169203679145428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 43}], {
             RGBColor[
             0.8993934351461096, 0.5416379581619916, 0.2733623024473289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 45}], {
             RGBColor[
             0.5537956767810012, 0.27827601314841466`, 0.5520299765823334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 47}], {
             RGBColor[
             0.8176218147888601, 0.1364545671614655, 0.16450797578379284`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 50}], {
             RGBColor[
             0.7813624680937394, 0.46758152486769017`, 0.5697383777853994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 52}], {
             RGBColor[
             0.9047637792171876, 0.55975338973049, 0.2942250750590857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.5876654540043562, 0.38914664060292226`, 0.5645878024022752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 12}], {
             RGBColor[
             0.294658140875038, 0.4246440715119715, 0.9401792523309427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 18}], {
             RGBColor[
             0.26004152690094556`, 0.38825981540510757`, 0.9382078873758093]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 24}], {
             RGBColor[
             0.2974047137106167, 0.4275308937049405, 0.9403356655907384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 26}], {
             RGBColor[
             0.5178267019298266, 0.6153116201958412, 0.9566896903212312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 34}], {
             RGBColor[
             0.258562337738562, 0.38670509380943274`, 0.9381236497412757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 43}], {
             RGBColor[
             0.6580356460893433, 0.7066936577651144, 0.6625241084762216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 47}], {
             RGBColor[
             0.5762640257320939, 0.30151026676458836`, 0.5536697818126854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 48}], {
             RGBColor[
             0.2657442853073524, 0.39425377606600776`, 0.9385326510305791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 52}], {
             RGBColor[
             0.6634059901604215, 0.724809089333613, 0.6833868810879784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 53}], {
             RGBColor[
             0.29822954002547564`, 0.42839783845886614`, 0.9403826382291485]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 13}], {
             RGBColor[
             0.21186056418822544`, 0.3400092640703979, 0.9353765177596773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 17}], {
             RGBColor[
             0.6154593078331062, 0.6794164574239245, 0.8520701328246918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 27}], {
             RGBColor[
             0.2525665510913249, 0.38279383721419136`, 0.9376946634946978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 28}], {
             RGBColor[
             0.2768491082973355, 0.40767498087896314`, 0.9391010026665503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 29}], {
             RGBColor[
             0.20847115959524953`, 0.33644678494251695`, 0.9351834961822821]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 32}], {
             RGBColor[
             0.23625536295363525`, 0.3656497442924196, 0.9367657654604968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 38}], {
             RGBColor[
             0.21626373981777264`, 0.34463728083451145`, 0.9356272720978654]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 39}], {
             RGBColor[
             0.22129539141633864`, 0.34992586568974166`, 0.9359138172127424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 40}], {
             RGBColor[
             0.612371423700085, 0.6781395379799178, 0.9032443640968248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 45}], {
             RGBColor[
             0.2641438363762507, 0.39496229809093164`, 0.9383539727646155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 17}], {
             RGBColor[
             0.916815391298979, 0.652694113481207, 0.47695413301579226`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 20}], {
             RGBColor[
             0.5712818825828434, 0.37431716358632205`, 0.5635672471801527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 22}], {
             RGBColor[
             0.6422901525100434, 0.43645980893137215`, 0.5680684398883333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 24}], {
             RGBColor[
             0.5504667458285053, 0.35243913510161706`, 0.5623818559352285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 26}], {
             RGBColor[
             0.7708887340477152, 0.5402198615925177, 0.5787358806657212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 40}], {
             RGBColor[
             0.9137275071659579, 0.6514171940372002, 0.5281283642879253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 43}], {
             RGBColor[
             0.911097678207232, 0.6316018991617909, 0.2845702988207115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 47}], {
             RGBColor[
             0.8293260578499826, 0.2264185081612649, 0.1757159721571755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 49}], {
             RGBColor[
             0.537935128367931, 0.33926761060011545`, 0.5616681988597154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 50}], {
             RGBColor[
             0.7930667111548618, 0.5575454658674895, 0.580946374158782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 52}], {
             RGBColor[
             0.9164680222783099, 0.6497173307302895, 0.30543307143246834`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 53}], {
             RGBColor[
             0.5512915721433642, 0.3533060798555427, 0.5624288285736385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 24}], {
             RGBColor[
             0.25745943269918714`, 0.3879365660106663, 0.9379733058638959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 26}], {
             RGBColor[
             0.477881420918397, 0.575717292501567, 0.9543273305943886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 30}], {
             RGBColor[
             0.217247411027305, 0.3456711816440869, 0.9356832907180372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 34}], {
             RGBColor[
             0.21861705672713244`, 0.34711076611515856`, 0.9357612900144332]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 44}], {
             RGBColor[
             0.24228613907637978`, 0.37198847237071514`, 0.9371092092389532]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 52}], {
             RGBColor[
             0.6234607091489919, 0.6852147616393387, 0.6810245213611358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 53}], {
             RGBColor[
             0.25828425901404606`, 0.38880351076459196`, 0.938020278502306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 14}], {
             RGBColor[
             0.18448720917543884`, 0.31123813238100956`, 0.9338176456869489]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 27}], {
             RGBColor[
             0.22641179608905126`, 0.3553035313995553, 0.9362051888898109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 32}], {
             RGBColor[
             0.2101006079513616, 0.3381594384777836, 0.9352762908556098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 39}], {
             RGBColor[
             0.19514063641406498`, 0.32243555987510564`, 0.9344243426078553]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 45}], {
             RGBColor[
             0.23798908137397706`, 0.36747199227629557`, 0.9368644981597286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 22}], {
             RGBColor[
             0.31356071403138397`, 0.4344110211847013, 0.9416255676245044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 32}], {
             RGBColor[
             0.20888200794084866`, 0.3368786126030313, 0.9352068933877684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 19}], {
             RGBColor[
             0.2252087960521938, 0.35403910208621037`, 0.9361366798173909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 20}], {
             RGBColor[
             0.26674218607257416`, 0.3976933283666536, 0.9385019449359073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 21}], {
             RGBColor[
             0.20887646888841394`, 0.33687279070772624`, 0.9352065779469265]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 23}], {
             RGBColor[
             0.2210038038848236, 0.3496193887064021, 0.9358972117341877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 36}], {
             RGBColor[
             0.21433203672982648`, 0.3426069384120303, 0.9355172644647056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 37}], {
             RGBColor[
             0.22622343778870863`, 0.35510555488328915`, 0.9361944621632575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 41}], {
             RGBColor[
             0.2428081549405094, 0.3725371441416328, 0.9371389372701622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 46}], {
             RGBColor[
             0.2091974368416031, 0.33721014837707164`, 0.9352248565970311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 49}], {
             RGBColor[
             0.2333954318576619, 0.362643775380447, 0.93660289661547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 25}], {
             RGBColor[
             0.1869311695796025, 0.313806889721825, 0.9339568256164507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 35}], {
             RGBColor[
             0.1803843663506722, 0.30692578443692, 0.9335839948576905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 42}], {
             RGBColor[
             0.18102227185741565`, 0.30759626357005254`, 0.933620322632603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 44}], {
             RGBColor[
             0.20492827886491521`, 0.33272299266332317`, 0.9349817343659119]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 26}], {
             RGBColor[
             0.8469766392244494, 0.878859093074126, 0.8690560209347482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 27}], {
             RGBColor[
             0.6300105397339321, 0.694710724753082, 0.8528988039548253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 28}], {
             RGBColor[
             0.6542930969399425, 0.7195918684178539, 0.8543051431266777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 31}], {
             RGBColor[
             0.6615315154270097, 0.7258614226978599, 0.8547663687519915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 38}], {
             RGBColor[
             0.5937077284603798, 0.6565541683734022, 0.850831412557993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 39}], {
             RGBColor[
             0.5987393800589458, 0.6618427532286324, 0.8511179576728698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 40}], {
             RGBColor[
             0.9898154123426921, 0.9900564255188086, 0.8184485045569523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 43}], {
             RGBColor[
             0.9871855833839662, 0.9702411306433992, 0.5748904390897385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 45}], {
             RGBColor[
             0.6415878250188578, 0.7068791856298223, 0.853558113224743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 47}], {
             RGBColor[
             0.9054139630267168, 0.5650577396428732, 0.46603611242620246`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 50}], {
             RGBColor[
             0.8691546163315961, 0.8961846973490979, 0.871266514427809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 52}], {
             RGBColor[
             0.9925559274550442, 0.9883565622118977, 0.5957532117014953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 48}], {
             RGBColor[
             0.19118239032183038`, 0.3182751922648696, 0.934198926348603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 20}], {
             RGBColor[
             0.26030288902306153`, 0.390925218892602, 0.9381352364950238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 22}], {
             RGBColor[
             0.33131115895026153`, 0.4530678642376521, 0.9426364292032046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 23}], {
             RGBColor[
             0.21456450683531092`, 0.3428512792323505, 0.9355305032933042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 47}], {
             RGBColor[
             0.5183470642902006, 0.24302656346754486`, 0.5502839614720466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 49}], {
             RGBColor[
             0.22695613480814922`, 0.3558756659063954, 0.9362361881745865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 51}], {
             RGBColor[
             0.21160467938017308`, 0.339740312913101, 0.9353619454984065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 21}], {
             RGBColor[
             0.24397056185928168`, 0.3737589075141179, 0.9372051346245593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 22}], {
             RGBColor[
             0.37284454897064195`, 0.49672209051809535`, 0.9450016943217208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 23}], {
             RGBColor[
             0.2560978968556913, 0.3865055055127937, 0.9378957684118205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 36}], {
             RGBColor[
             0.2494261297006942, 0.37949305521842197`, 0.9375158211423384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 37}], {
             RGBColor[
             0.2613175307595763, 0.3919916716896808, 0.9381930188408905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 41}], {
             RGBColor[
             0.2779022479113771, 0.40942326094802445`, 0.9391374939477951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 47}], {
             RGBColor[
             0.5598804543105811, 0.28668078974798816`, 0.5526492265905629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 49}], {
             RGBColor[
             0.2684895248285296, 0.39952989218683865`, 0.9386014532931028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 51}], {
             RGBColor[
             0.25313806940055344`, 0.38339453919354427`, 0.9377272106169228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 52}], {
             RGBColor[
             0.6470224187389085, 0.7099796123170127, 0.6823663258658558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 23}], {
             RGBColor[
             0.19823217967153106`, 0.32568496785386636`, 0.9346004014228397]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.19156041251653394`, 0.31867251755949455`, 0.9342204541533576]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 37}], {
             RGBColor[
             0.20345181357541609`, 0.3311711340307534, 0.9348976518519097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 41}], {
             RGBColor[
             0.22003653072721685`, 0.348602723289097, 0.9358421269588143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 46}], {
             RGBColor[
             0.1864258126283106, 0.3132757275245359, 0.9339280462856832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 23}], {
             RGBColor[
             0.3271061667828914, 0.4486481508578438, 0.9423969611200012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 32}], {
             RGBColor[
             0.3391741128073067, 0.4613323272814754, 0.9430842127931653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 40}], {
             RGBColor[
             0.7152901735537565, 0.7738221209689736, 0.9095628114294935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 43}], {
             RGBColor[
             0.7126603445950306, 0.7540068260935643, 0.6660047459622797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 45}], {
             RGBColor[
             0.36706258622992216`, 0.4906448810799874, 0.9446724200972841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 47}], {
             RGBColor[
             0.6308887242377812, 0.34882343509303826`, 0.5571504192987435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 49}], {
             RGBColor[
             0.33949779475572966`, 0.46167253753188875`, 0.9431026460012835]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 51}], {
             RGBColor[
             0.3241463393277535, 0.44553718453859437`, 0.9422284033251034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 36}], {
             RGBColor[
             0.2036877475129436, 0.33141911555817044`, 0.9349110879406188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 37}], {
             RGBColor[
             0.21557914857182575`, 0.34391773202942927`, 0.9355882856391708]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 41}], {
             RGBColor[
             0.23216386572362652`, 0.3613493212877729, 0.9365327607460755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 49}], {
             RGBColor[
             0.22275114264077903`, 0.3514559525265871, 0.9359967200913832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 51}], {
             RGBColor[
             0.20739968721280289`, 0.33532059953329274`, 0.9351224774152032]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 26}], {
             RGBColor[
             0.48062799375397575`, 0.578604114694536, 0.9544837438541844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 30}], {
             RGBColor[
             0.21999398386288377`, 0.34855800383705593`, 0.935839703977833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 34}], {
             RGBColor[
             0.22136362956271116`, 0.34999758830812755`, 0.935917703274229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 52}], {
             RGBColor[
             0.6262072819845705, 0.6881015838323077, 0.6811809346209315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 53}], {
             RGBColor[
             0.26103083184962483`, 0.39169033295756095`, 0.9381766917621017]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 31}], {
             RGBColor[
             0.26201246704841596`, 0.39074224773682065`, 0.9383050862970239]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 35}], {
             RGBColor[
             0.1873183964895954, 0.31421388975583164`, 0.9339788776161239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 42}], {
             RGBColor[
             0.18795630199633884`, 0.3148843688889642, 0.9340152053910362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 44}], {
             RGBColor[
             0.2118623090038384, 0.34001109798223483`, 0.9353766171243453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 43}], {
             RGBColor[
             0.8412589261327024, 0.8577668787547099, 0.6766721867396674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 44}], {
             RGBColor[
             0.46545470013116835`, 0.5626560210545848, 0.9536196472292418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 47}], {
             RGBColor[
             0.759487305775453, 0.4525834877541838, 0.5678178600761314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 52}], {
             RGBColor[
             0.8466292702037803, 0.8758823103232083, 0.6975349593514243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 53}], {
             RGBColor[
             0.48145282006883466`, 0.5794710594484616, 0.9545307164925945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 28}], {
             RGBColor[
             0.2914003401981613, 0.4229692482081206, 0.9399296737966838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 29}], {
             RGBColor[
             0.2230223914960754, 0.3517410522716744, 0.9360121673124157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 32}], {
             RGBColor[
             0.2508065948544611, 0.38094401162157704`, 0.9375944365906304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 38}], {
             RGBColor[
             0.2308149717185985, 0.3599315481636689, 0.936455943227999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 39}], {
             RGBColor[
             0.2358466233171645, 0.3652201330188991, 0.9367424883428759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 40}], {
             RGBColor[
             0.6269226556009109, 0.6934338053090753, 0.9040730352269584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 45}], {
             RGBColor[
             0.2786950682770766, 0.41025656542008904`, 0.939182643894749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 29}], {
             RGBColor[
             0.24730494870208594`, 0.3766221959364462, 0.9374185064842682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 32}], {
             RGBColor[
             0.27508915206047163`, 0.4058251552863489, 0.9390007757624828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 38}], {
             RGBColor[
             0.255097528924609, 0.3848126918284407, 0.9378622823998515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 39}], {
             RGBColor[
             0.260129180523175, 0.3901012766836709, 0.9381488275147283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 40}], {
             RGBColor[
             0.6512052128069215, 0.7183149489738472, 0.9054793743988109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 45}], {
             RGBColor[
             0.3029776254830871, 0.4351377090848609, 0.9405889830666015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 38}], {
             RGBColor[
             0.1867195802225231, 0.3135844958919945, 0.9339447759155833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 39}], {
             RGBColor[
             0.1917512318210891, 0.3188730807472247, 0.9342313210304602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 46}], {
             RGBColor[
             0.18283689029074987`, 0.3095035425969407, 0.933723662467894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 34}], {
             RGBColor[
             0.18115160789082901`, 0.3077322039415481, 0.9336276881283703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 53}], {
             RGBColor[
             0.22081881017774269`, 0.3494249485909815, 0.935886676616243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 33}], {
             RGBColor[
             0.2588960400889786, 0.3874666854095703, 0.9381276103920244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 42}], {
             RGBColor[
             0.2561035693262291, 0.3845316215850481, 0.9379685833131761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 43}], {
             RGBColor[
             0.6558138023352627, 0.7047692083784438, 0.6623825345569108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 44}], {
             RGBColor[
             0.2800095763337287, 0.4096583506783188, 0.9393299950464852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 50}], {
             RGBColor[
             0.5377828352828925, 0.6307127750841425, 0.9587586098949813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 39}], {
             RGBColor[
             0.21953543517947482`, 0.34807604009712734`, 0.9358135903086748]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 40}], {
             RGBColor[
             0.6106114674632213, 0.6762897123873035, 0.9031441371927573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 45}], {
             RGBColor[
             0.26238388013938685`, 0.3931124724983173, 0.938253745860548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 50}], {
             RGBColor[
             0.4665191409935649, 0.5577899600608082, 0.954627756067842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 53}], {
             RGBColor[
             0.22218845587757008`, 0.3508645330620532, 0.935964675912639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 42}], {
             RGBColor[
             0.18140949876740853`, 0.30800326360405916`, 0.9336423746322762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 44}], {
             RGBColor[
             0.2053155057749081, 0.3331299926973298, 0.9350037863655851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 37}], {
             RGBColor[
             0.20890738141682863`, 0.3369052817350575, 0.9352083383696888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 41}], {
             RGBColor[
             0.2254920985686294, 0.35433687099340117`, 0.9361528134765934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 49}], {
             RGBColor[
             0.2160793754857819, 0.3444435022322154, 0.9356167728219011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 41}], {
             RGBColor[
             0.23738349962751154`, 0.36683548746466, 0.9368300111751453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 46}], {
             RGBColor[
             0.20377278152860526`, 0.33150849170009883`, 0.9349159305020143]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 39}], {
             RGBColor[
             0.1995438120436122, 0.3270635766392192, 0.9346750969460436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 46}], {
             RGBColor[
             0.19062947051327297`, 0.3176940384889352, 0.9341674383834773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 45}], {
             RGBColor[
             0.24742390860209026`, 0.3773885938956394, 0.9374017976127935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 43}], {
             RGBColor[
             0.9840976992509451, 0.9689642111993925, 0.6260646703618716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 45}], {
             RGBColor[
             0.6384999408858367, 0.7056022661858156, 0.9047323444968761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 47}], {
             RGBColor[
             0.9023260788936956, 0.5637808201988664, 0.5172103436983355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 50}], {
             RGBColor[
             0.8660667321985749, 0.8949077779050911, 0.9224407456999422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 46}], {
             RGBColor[
             0.22035749868040602`, 0.3489400809584425, 0.9358604056089189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 49}], {
             RGBColor[
             0.24455549369646482`, 0.3743737079618179, 0.9372384456273578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 52}], {
             RGBColor[
             0.6230883876068438, 0.6848234280919918, 0.6810033182001107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 44}], {
             RGBColor[
             0.20595341128165154`, 0.33380047183046235`, 0.9350401141404976]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 45}], {
             RGBColor[
             0.6358701119271107, 0.6857869713104062, 0.6611742790296622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 47}], {
             RGBColor[
             0.8996962499349697, 0.5439655253234571, 0.2736522782311217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 50}], {
             RGBColor[
             0.863436903239849, 0.8750924830296818, 0.6788826802327284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 52}], {
             RGBColor[
             0.9868382143632972, 0.9672643478924816, 0.4033693775064146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 52}], {
             RGBColor[
             0.6110339883617631, 0.6721534901923565, 0.680316837995989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 49}], {
             RGBColor[
             0.5265337000956688, 0.25163123676178156`, 0.5507501782701256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 50}], {
             RGBColor[
             0.7816652828825996, 0.4699090920291557, 0.5700283535691922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 52}], {
             RGBColor[
             0.9050665940060477, 0.5620809568919556, 0.29451505084287855`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 51}], {
             RGBColor[
             0.21979131518564116`, 0.34834498620733767`, 0.9358281622964855]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 52}], {
             RGBColor[
             0.868807247310927, 0.8932079145981802, 0.6997454528444851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 53}], {
             RGBColor[
             0.6270321082994295, 0.6889685285862334, 0.6812279072593417]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.12241145096085318`], {
             RGBColor[
             0.6724874734840657, 0.7440715924706315, 0.9679909246702991]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.12241145096085318`], {
             RGBColor[
             0.2496713315013381, 0.3797507778575908, 0.9375297850221416]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.12241145096085318`], {
             RGBColor[
             0.9943235297610715, 0.9902669290751381, 0.6235294294852872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.12241145096085318`], {
             RGBColor[
             0.19100757903810398`, 0.3180914545219976, 0.934188971104605]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.12241145096085318`], {
             RGBColor[
             0.18902339357703138`, 0.31600594979778596`, 0.9340759746779361]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.12241145096085318`], {
             RGBColor[
             0.2553757781742261, 0.38574651299360496`, 0.93785464482119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.12241145096085318`], {
             RGBColor[
             0.21111536430055308`, 0.3392260117400524, 0.9353340797284988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.12241145096085318`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.12241145096085318`], {
             RGBColor[
             0.3346034218864676, 0.4642383992062457, 0.9425416120577853]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.12241145096085318`], {
             RGBColor[
             0.2380153191904991, 0.3674995698850339, 0.9368659923645642]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.12241145096085318`], {
             RGBColor[
             0.8407274861222448, 0.3140548819995988, 0.1866339927467653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.12241145096085318`], {
             RGBColor[
             0.2547128598636084, 0.3850497438176973, 0.9378168926041001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.12241145096085318`], {
             RGBColor[
             0.18570580918595178`, 0.31251895825576187`, 0.9338870431547904]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.12241145096085318`], {
             RGBColor[
             0.1832686091649259, 0.30995730650625725`, 0.9337482482191074]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.12241145096085318`], {
             RGBColor[
             0.23164809310170648`, 0.36080721156026196`, 0.9365033882582744]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.12241145096085318`], {
             RGBColor[
             0.17999713944067933`, 0.30651878440291336`, 0.9335619428580173]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.12241145096085318`], {
             RGBColor[
             0.9929032964757133, 0.9913333449628153, 0.7672742732848192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.12241145096085318`], {
             RGBColor[
             0.18547963191542358`, 0.3122812316039695, 0.9338741626938332]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.12241145096085318`], {
             RGBColor[
             0.2187694990026811, 0.3472709926121587, 0.9357699713765075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.12241145096085318`], {
             RGBColor[
             0.3018362790434419, 0.43457944517304525`, 0.9405005016135402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.12241145096085318`], {
             RGBColor[
             0.18610484467512142`, 0.31293836985519047`, 0.9339097676355785]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.12241145096085318`], {
             RGBColor[
             0.443852818897842, 0.5588647358631454, 0.9495028870299015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.12241145096085318`], {
             RGBColor[
             0.21035951466794073`, 0.3384315658525422, 0.9352910352101009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.12241145096085318`], {
             RGBColor[
             0.2602060055347659, 0.3908233882036353, 0.9381297191236917]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.12241145096085318`], {
             RGBColor[
             0.1938651997185257, 0.3210949950407367, 0.934351708374884]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.12241145096085318`], {
             RGBColor[
             0.7010499819731856, 0.7663848411854366, 0.9708377685846771]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.12241145096085318`], {
             RGBColor[
             0.2671177829921508, 0.39808810454334875`, 0.9385233346248313]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.12241145096085318`], {
             RGBColor[
             0.3156828974041719, 0.44785039187289244`, 0.9413360129685363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.12241145096085318`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.12241145096085318`], {
             RGBColor[
             0.1797819621910016, 0.3062926194704765, 0.9335496888319743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.12241145096085318`], {
             RGBColor[
             0.3301597343783062, 0.46038950043290455`, 0.9422584642191638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.12241145096085318`], {
             RGBColor[
             0.2344954067167714, 0.3637999186998053, 0.9366655385564293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.12241145096085318`], {
             RGBColor[
             0.187632345799651, 0.31454387038623605`, 0.9339967565648851]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.12241145096085318`], {
             RGBColor[
             0.18252125359065643`, 0.3091717884126198, 0.9337056874247662]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.12241145096085318`], {
             RGBColor[
             0.18077159326066508`, 0.30733278447092666`, 0.9336060468573637]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.12241145096085318`], {
             RGBColor[
             0.19701598035794649`, 0.3244066652637987, 0.9345311406711367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.12241145096085318`], {
             RGBColor[
             0.22079878247571078`, 0.34940389820631634`, 0.9358855360682407]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.12241145096085318`], {
             RGBColor[
             0.1945121604450462, 0.321774991783989, 0.9343885518311666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.12241145096085318`], {
             RGBColor[
             0.2045754636421782, 0.3323521614944494, 0.9349616420609204]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.12241145096085318`], {
             RGBColor[
             0.986727528209671, 0.9887795060748018, 0.8696227358290854]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.12241145096085318`], {
             RGBColor[
             0.2539682167793123, 0.38426707672300364`, 0.9377744862820501]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.12241145096085318`], {
             RGBColor[
             0.18204740427415195`, 0.30867374273719167`, 0.9336787024071885]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.12241145096085318`], {
             RGBColor[
             0.9814678702922192, 0.9491489163239831, 0.38250660489465776`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.12241145096085318`], {
             RGBColor[
             0.22985941828915113`, 0.358927200923733, 0.9364015258738065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.12241145096085318`], {
             RGBColor[
             0.2902723535620023, 0.4224250262968293, 0.9398419531646668]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.12241145096085318`], {
             RGBColor[
             0.18674678058149974`, 0.3136130851938813, 0.9339463249357878]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.12241145096085318`], {
             RGBColor[
             0.8179246295777203, 0.13878213432293102`, 0.1647979515675857]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.12241145096085318`], {
             RGBColor[
             0.19688514872823715`, 0.32426915292576974`, 0.9345236900033729]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.12241145096085318`], {
             RGBColor[
             0.23514277061361732`, 0.3644803392006321, 0.9367024049726655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.12241145096085318`], {
             RGBColor[
             0.7454059361874789, 0.8010360497353803, 0.9752587555707988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.12241145096085318`], {
             RGBColor[
             0.20443985975766502`, 0.33220963321404323`, 0.9349539196203054]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.12241145096085318`], {
             RGBColor[
             0.9922085584343752, 0.9853797794609801, 0.42423215011817145`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.12241145096085318`], {
             RGBColor[
             0.26185565816448375`, 0.3925572777114866, 0.9382236644005117]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> Medium, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54}, {Null, CompressedData["
1:eJwVxVuWmyAAANBowhgSRUxAcBQfEKNGRgTRdfR0Cd1A9//X0/tzuz9/f/8J
T6fTr+B0+j+fedvO520yZnuN8RSbePt+gRFMwIBhGIdpMAAhg7Z7fJ8ARhhz
PGDz/Xl9zgc6zHHu4g51uOumznRbd/CynEMelmEbzs/v5+s5Pj+hxJLLUrZS
zoAiiinlVNKBmnOSoAQnNOkSk2zJASDEkEIOWzjAEVhokcWW2sGOdrLGgj7p
Ud/b/rjCa3sdw/26873c213u8x466LCjjrvStU662bk9VFBhRRVXpWqVVGpW
Tu0BCO7BEEyBBRrqRCONNdW9HrQ22uojSEGaDqkNKlDdq7SqumqopspUNmhA
AxvUpE3TN0OjG9scoQDiKqBAAgsquBCNaIUUSgxiFFpY4cQeFrwoykIUbSEL
VcyFK/bL9QIvz8vrMoI1WdGKV7qKtVn7Va9mXe16hAte6MKXYikXsbSLXNQy
L4tb9q/n1/fX6+sTeOChRz711Fde+Mb3fvCT13711vvjHEVxlERdZKItzHFO
85znZS5ymat8yU3uwgxnGc3yjGdFVmYiazOZqWzOlsxle/C+v+N39X5P5zqq
k7rualNv9RE94sejfnQP89jSn5ABdmWQYZYxynLGOCuYYC2TTLGRzUyzhVnm
2H4mEYlJQhDB5EEIJTXpyEQ0MWQlGznA7Zbemlt/+7nZm/8HrSFNUA==
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[36, 42] -> 
             RGBColor[
              0.20973084724615101`, 0.3377707965324245, 0.93525523353046], 
             UndirectedEdge[17, 32] -> 
             RGBColor[
              0.21976873359857355`, 0.34832125152757426`, 0.9358268763085085],
              UndirectedEdge[2, 32] -> 
             RGBColor[
              0.2039184348889752, 0.33166158261680406`, 0.9349242252454124], 
             UndirectedEdge[44, 48] -> 
             RGBColor[
              0.5364206507730037, 0.6305357007110791, 0.9582473880941107], 
             UndirectedEdge[5, 37] -> 
             RGBColor[
              0.5940812857443645, 0.6387452329417826, 0.6536530603664883], 
             UndirectedEdge[28, 38] -> 
             RGBColor[
              0.3089752197556035, 0.43094089240998523`, 0.9413150181012624], 
             UndirectedEdge[1, 41] -> 
             RGBColor[
              0.5375723805412207, 0.6350924687169155, 0.9568416073029082], 
             UndirectedEdge[37, 49] -> 
             RGBColor[
              0.599731122168885, 0.6637847219545001, 0.8746392122989061], 
             UndirectedEdge[12, 38] -> 
             RGBColor[
              0.19855529182786918`, 0.3260245792166716, 0.9346188021821416], 
             UndirectedEdge[12, 33] -> 
             RGBColor[
              0.27536725604921036`, 0.40365488816501993`, 0.939106780199046], 
             UndirectedEdge[5, 47] -> 
             RGBColor[
              0.8478446557004482, 0.8594302105131614, 0.6722445662632488], 
             UndirectedEdge[5, 9] -> 
             RGBColor[
              0.827056855890692, 0.8431906233086497, 0.6701726326512465], 
             UndirectedEdge[39, 41] -> 
             RGBColor[
              0.7264237258279034, 0.4245583265707439, 0.5643341371066111], 
             UndirectedEdge[10, 49] -> 
             RGBColor[
              0.5955208682904756, 0.6593594781827778, 0.8743994445690431], 
             UndirectedEdge[23, 34] -> 
             RGBColor[
              0.30047281721139046`, 0.4284459763065643, 0.9405949585640968], 
             UndirectedEdge[5, 41] -> 
             RGBColor[
              0.8071550075462053, 0.8275385128333179, 0.6682605421201488], 
             UndirectedEdge[21, 23] -> 
             RGBColor[
              0.6769435963962234, 0.7380489377731914, 0.7826872123841424], 
             UndirectedEdge[26, 42] -> 
             RGBColor[
              0.20925965987992423`, 0.33727554873551563`, 0.9352284001070128],
              UndirectedEdge[7, 18] -> 
             RGBColor[
              0.20569690834517665`, 0.33353087098100176`, 0.9350255066777273],
              UndirectedEdge[13, 20] -> 
             RGBColor[
              0.4414579443225765, 0.5518770606406308, 0.9504055012975847], 
             UndirectedEdge[2, 43] -> 
             RGBColor[
              0.18441246182330562`, 0.3111595681746616, 0.9338133889358238], 
             UndirectedEdge[9, 49] -> 
             RGBColor[
              0.8327066923152127, 0.8682301123213674, 0.8911587845836642], 
             UndirectedEdge[21, 47] -> 
             RGBColor[
              0.8556051265489995, 0.8844975040121474, 0.7968296755224891], 
             UndirectedEdge[10, 45] -> 
             RGBColor[
              0.18994375014765302`, 0.31697330290748627`, 0.9341283876230875],
              UndirectedEdge[14, 44] -> 
             RGBColor[
              0.6129726702603215, 0.6954609953556762, 0.963506573158243], 
             UndirectedEdge[31, 49] -> 
             RGBColor[
              0.7061668667444692, 0.7651609867128231, 0.8810848237619252], 
             UndirectedEdge[16, 24] -> 
             RGBColor[
              0.6456847325441337, 0.7102860473118682, 0.8199134963878978], 
             UndirectedEdge[6, 19] -> 
             RGBColor[
              0.21513607948645913`, 0.34345203832850646`, 0.9355630535102211],
              UndirectedEdge[20, 44] -> 
             RGBColor[
              0.6548044292918647, 0.7294219018367516, 0.9667997224639884], 
             UndirectedEdge[32, 46] -> 
             RGBColor[
              0.2095582825153956, 0.3375894200591647, 0.9352454062243303], 
             UndirectedEdge[13, 54] -> 
             RGBColor[
              0.27186969156143365`, 0.4030826617380699, 0.9387939487880332], 
             UndirectedEdge[1, 28] -> 
             RGBColor[
              0.4344364748330506, 0.5507087719134371, 0.9489028859126392], 
             UndirectedEdge[27, 35] -> 
             RGBColor[
              0.2083539027642204, 0.3363235405785928, 0.9351768185792209], 
             UndirectedEdge[10, 37] -> 
             RGBColor[
              0.20517075417371552`, 0.33297784958669485`, 0.934995542976038], 
             UndirectedEdge[1, 38] -> 
             RGBColor[
              0.31415505434918767`, 0.43542740478889125`, 0.9416450725812177],
              UndirectedEdge[28, 39] -> 
             RGBColor[
              0.6232878201197333, 0.34017462976726554`, 0.5563954157163419], 
             UndirectedEdge[9, 21] -> 
             RGBColor[
              0.8348173267392432, 0.8682579168076358, 0.7947577419104868], 
             UndirectedEdge[5, 40] -> 
             RGBColor[
              0.6373722155124255, 0.6842467449314944, 0.656118414773588], 
             UndirectedEdge[8, 23] -> 
             RGBColor[
              0.291863921614652, 0.4193974811988854, 0.9401046946955822], 
             UndirectedEdge[17, 24] -> 
             RGBColor[
              0.25874405950433915`, 0.3892867902329248, 0.9380464634600142], 
             UndirectedEdge[28, 33] -> 
             RGBColor[
              0.38578718397694467`, 0.5085712013583334, 0.9458029961181669], 
             UndirectedEdge[10, 31] -> 
             RGBColor[
              0.31160649874929963`, 0.4343541143450177, 0.9414411544390572], 
             UndirectedEdge[21, 50] -> 
             RGBColor[
              0.6263929033348619, 0.6896173382991643, 0.7796363211125157], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.6686702566732518, 0.7313413549298745, 0.8213361382706323], 
             UndirectedEdge[18, 33] -> 
             RGBColor[
              0.2631723459508108, 0.39083726444964373`, 0.938412298109695], 
             UndirectedEdge[21, 22] -> 
             RGBColor[
              0.6740744368934871, 0.7355638160200709, 0.7825043920777262], 
             UndirectedEdge[16, 39] -> 
             RGBColor[
              0.9061708928160404, 0.5629447833388066, 0.43192855786880735`], 
             UndirectedEdge[22, 34] -> 
             RGBColor[
              0.29760365770865427`, 0.42596085455344385`, 0.9404121382576806],
              UndirectedEdge[23, 35] -> 
             RGBColor[
              0.29809512371243774`, 0.42594686968469, 0.9404595524368138], 
             UndirectedEdge[15, 39] -> 
             RGBColor[
              0.5153802458254702, 0.2378989595351509, 0.5498422746199532], 
             UndirectedEdge[7, 20] -> 
             RGBColor[
              0.4075903517880637, 0.5162800735574673, 0.9484767920053575], 
             UndirectedEdge[48, 52] -> 
             RGBColor[
              0.5335302312071252, 0.6282776829782125, 0.9579592980842904], 
             UndirectedEdge[15, 28] -> 
             RGBColor[
              0.3213490659452034, 0.44394658930241643`, 0.9420196903362951], 
             UndirectedEdge[34, 46] -> 
             RGBColor[
              0.2210407420750881, 0.34965821308638656`, 0.9358993153094781], 
             UndirectedEdge[8, 9] -> 
             RGBColor[
              0.449737651957672, 0.5496064602333298, 0.9521752242219266], 
             UndirectedEdge[16, 35] -> 
             RGBColor[
              0.6158141726991079, 0.6788901950118653, 0.8182124121942568], 
             UndirectedEdge[28, 52] -> 
             RGBColor[
              0.5726354043092331, 0.6621486184361094, 0.9604510451350099], 
             UndirectedEdge[24, 34] -> 
             RGBColor[
              0.26885381311011375`, 0.39991278226799465`, 0.9386221989718229],
              UndirectedEdge[22, 27] -> 
             RGBColor[
              0.26697430720778675`, 0.393767465164045, 0.9386678420587196], 
             UndirectedEdge[21, 34] -> 
             RGBColor[
              0.6178317259488735, 0.6806189980564931, 0.7791487747255106], 
             UndirectedEdge[27, 53] -> 
             RGBColor[
              0.18618607149369076`, 0.31302374439158454`, 0.9339143933827319],
              UndirectedEdge[32, 43] -> 
             RGBColor[
              0.19889005457898606`, 0.3263764360932798, 0.9346378664255806], 
             UndirectedEdge[32, 50] -> 
             RGBColor[
              0.23843966459033653`, 0.3679455838053154, 0.9368901582073221], 
             UndirectedEdge[43, 50] -> 
             RGBColor[
              0.21893369152466693`, 0.34744356936317294`, 0.9357793218977335],
              UndirectedEdge[14, 16] -> 
             RGBColor[
              0.7495865593209835, 0.8000467722927723, 0.8268734115985621], 
             UndirectedEdge[37, 52] -> 
             RGBColor[
              0.4626975882155624, 0.5577390353480524, 0.9537822847716185], 
             UndirectedEdge[39, 40] -> 
             RGBColor[
              0.5566409337941236, 0.28126655866892036`, 0.5521920097600502], 
             UndirectedEdge[1, 11] -> 
             RGBColor[
              0.32038970340403605`, 0.4419804162451184, 0.9420001266215545], 
             UndirectedEdge[14, 48] -> 
             RGBColor[
              0.4275983135225685, 0.5434056832633345, 0.9488485223953771], 
             UndirectedEdge[2, 23] -> 
             RGBColor[
              0.2745127648960175, 0.4011603153607243, 0.9391165719891921], 
             UndirectedEdge[15, 49] -> 
             RGBColor[
              0.6017613639682927, 0.6659186348104424, 0.8747548315659087], 
             UndirectedEdge[13, 47] -> 
             RGBColor[
              0.5060048927682363, 0.6031371894561769, 0.9562676595117956], 
             UndirectedEdge[5, 15] -> 
             RGBColor[
              0.5961115275437721, 0.640879145797725, 0.653768679633491], 
             UndirectedEdge[23, 43] -> 
             RGBColor[
              0.2694843845860284, 0.3958751688372, 0.9388302131693602], 
             UndirectedEdge[24, 46] -> 
             RGBColor[
              0.24853360842116123`, 0.3785549587645153, 0.9374649933758359], 
             UndirectedEdge[1, 31] -> 
             RGBColor[
              0.430934403314964, 0.547675453583703, 0.9486797370122668], 
             UndirectedEdge[11, 38] -> 
             RGBColor[
              0.19492844832658895`, 0.3222125367416665, 0.9344122588101778], 
             UndirectedEdge[31, 54] -> 
             RGBColor[
              0.3354449213769901, 0.45940980797001174`, 0.9427987173419182], 
             UndirectedEdge[23, 50] -> 
             RGBColor[
              0.30903399459737885`, 0.43744431654923555`, 0.9410825049511018],
              UndirectedEdge[40, 49] -> 
             RGBColor[
              0.6430220519369461, 0.7092862339442121, 0.8771045667060058], 
             UndirectedEdge[13, 33] -> 
             RGBColor[
              0.31870988264330163`, 0.4492107367966575, 0.9415750786639095], 
             UndirectedEdge[22, 24] -> 
             RGBColor[
              0.3250965240547274, 0.4548576002315725, 0.9419778163240384], 
             UndirectedEdge[7, 51] -> 
             RGBColor[
              0.23038703934124513`, 0.35948176410259064`, 0.936431573112178], 
             UndirectedEdge[8, 32] -> 
             RGBColor[
              0.22126959160760973`, 0.34989874845496527`, 0.9359123479518026],
              UndirectedEdge[12, 41] -> 
             RGBColor[
              0.42197261801990227`, 0.5256896431446958, 0.9498153369038321], 
             UndirectedEdge[16, 47] -> 
             RGBColor[
              0.8559652667981865, 0.8852678075893938, 0.8360287191185183], 
             UndirectedEdge[21, 44] -> 
             RGBColor[
              0.8580487563222315, 0.8864064861632704, 0.7970732337012664], 
             UndirectedEdge[13, 37] -> 
             RGBColor[
              0.2522415228121527, 0.38245221188479817`, 0.9376761536150351], 
             UndirectedEdge[3, 20] -> 
             RGBColor[
              0.3852762827383038, 0.4928265721924773, 0.9472060387836806], 
             UndirectedEdge[16, 34] -> 
             RGBColor[
              0.6181918661980605, 0.6813893016337396, 0.8183478183215398], 
             UndirectedEdge[5, 44] -> 
             RGBColor[
              0.8502882854736803, 0.8613391926642844, 0.672488124442026], 
             UndirectedEdge[33, 51] -> 
             RGBColor[
              0.2878624769468793, 0.4167881575712326, 0.9398183645441456], 
             UndirectedEdge[14, 54] -> 
             RGBColor[
              0.3763938392802867, 0.4934974854864461, 0.9457893042557033], 
             UndirectedEdge[19, 26] -> 
             RGBColor[
              0.20302155292659174`, 0.3307189028087383, 0.9348731491444726], 
             UndirectedEdge[3, 7] -> 
             RGBColor[
              0.20505278345339475`, 0.33285385487986197`, 0.9349888247180378],
              UndirectedEdge[46, 50] -> 
             RGBColor[
              0.2296019194610765, 0.3586565533290579, 0.9363868616964831], 
             UndirectedEdge[34, 35] -> 
             RGBColor[
              0.2389832532650879, 0.3685169299679917, 0.936921114778182], 
             UndirectedEdge[20, 33] -> 
             RGBColor[
              0.4650657893936978, 0.5735864670261093, 0.951863583437325], 
             UndirectedEdge[37, 44] -> 
             RGBColor[
              0.46558800778144094`, 0.559997053080919, 0.9540703747814387], 
             UndirectedEdge[12, 51] -> 
             RGBColor[
              0.2209120052816667, 0.34952290255411655`, 0.9358919839395416], 
             UndirectedEdge[23, 29] -> 
             RGBColor[
              0.48355453728279535`, 0.5890653039164037, 0.9531895439383218], 
             UndirectedEdge[22, 47] -> 
             RGBColor[
              0.5353770583087802, 0.6298393605090982, 0.958093039054659], 
             UndirectedEdge[32, 35] -> 
             RGBColor[
              0.22750079370539544`, 0.3564481369407698, 0.9362672056930341], 
             UndirectedEdge[2, 50] -> 
             RGBColor[
              0.22396207183465605`, 0.3527287158866972, 0.9360656807175654], 
             UndirectedEdge[19, 36] -> 
             RGBColor[
              0.2034927402928185, 0.3312141506056471, 0.9348999825679201], 
             UndirectedEdge[22, 23] -> 
             RGBColor[
              0.3567155281560041, 0.48339079427014214`, 0.9439505759163124], 
             UndirectedEdge[14, 29] -> 
             RGBColor[
              0.5558373599583684, 0.6502928348587381, 0.9581766995567123], 
             UndirectedEdge[46, 53] -> 
             RGBColor[
              0.19649521730560576`, 0.32385931027750403`, 0.9345014839857059],
              UndirectedEdge[36, 40] -> 
             RGBColor[
              0.24179489193756837`, 0.3714721404809568, 0.9370812334411329], 
             UndirectedEdge[9, 35] -> 
             RGBColor[
              0.45596885405545773`, 0.5561558487191345, 0.952530081963158], 
             UndirectedEdge[15, 45] -> 
             RGBColor[
              0.19618424582547017`, 0.32353245953515086`, 0.9344837746199532],
              UndirectedEdge[5, 29] -> 
             RGBColor[
              0.7931529751717271, 0.8161710321673463, 0.6671582508404953], 
             UndirectedEdge[9, 24] -> 
             RGBColor[
              0.4858394139004835, 0.5875517010191373, 0.954231166156799], 
             UndirectedEdge[9, 50] -> 
             RGBColor[
              0.4669077249403988, 0.5676532955836799, 0.9531530344774461], 
             UndirectedEdge[39, 52] -> 
             RGBColor[
              0.7666665841894998, 0.4561009886688438, 0.568273629418668], 
             UndirectedEdge[29, 35] -> 
             RGBColor[
              0.42206497333649284`, 0.5291362575778311, 0.9495157001524068], 
             UndirectedEdge[9, 23] -> 
             RGBColor[
              0.5174584180017603, 0.616084895057707, 0.9562039257490729], 
             UndirectedEdge[31, 37] -> 
             RGBColor[
              0.31581675262770914`, 0.43877935811673996`, 0.9416809221689202],
              UndirectedEdge[6, 42] -> 
             RGBColor[
              0.22137418643979162`, 0.3500086842552838, 0.9359183044727613], 
             UndirectedEdge[29, 49] -> 
             RGBColor[
              0.7988028115962478, 0.841210521180064, 0.8881444027729131], 
             UndirectedEdge[31, 52] -> 
             RGBColor[
              0.5691333327911465, 0.6591153001063752, 0.9602278962346377], 
             UndirectedEdge[34, 43] -> 
             RGBColor[
              0.21037251413867852`, 0.3384452291205017, 0.9352917755107284], 
             UndirectedEdge[25, 32] -> 
             RGBColor[
              0.20040695641663314`, 0.3279707961017783, 0.9347242517411795], 
             UndirectedEdge[18, 47] -> 
             RGBColor[
              0.45046735607574556`, 0.544763717109163, 0.953104878957581], 
             UndirectedEdge[47, 54] -> 
             RGBColor[
              0.4827725467574897, 0.5787185207830676, 0.9549446117756595], 
             UndirectedEdge[16, 29] -> 
             RGBColor[
              0.8012735862694655, 0.8420086292435789, 0.8309424036957649], 
             UndirectedEdge[29, 44] -> 
             RGBColor[
              0.6646596972088036, 0.7374228523064827, 0.9675755652554456], 
             UndirectedEdge[29, 52] -> 
             RGBColor[
              0.661769277642925, 0.7351648345736161, 0.9672874752456255], 
             UndirectedEdge[1, 39] -> 
             RGBColor[
              0.6284676547133174, 0.34466114214617155`, 0.5567254701962971], 
             UndirectedEdge[9, 16] -> 
             RGBColor[
              0.8351774669884304, 0.8690282203848823, 0.833956785506516], 
             UndirectedEdge[21, 24] -> 
             RGBColor[
              0.6453245922949467, 0.7095157437346217, 0.7807144527918686], 
             UndirectedEdge[35, 50] -> 
             RGBColor[
              0.2475444306510763, 0.377515270210663, 0.937408661165187], 
             UndirectedEdge[23, 49] -> 
             RGBColor[
              0.6748329619721927, 0.7380211332869229, 0.8790882550573198], 
             UndirectedEdge[17, 25] -> 
             RGBColor[
              0.20177966237055106`, 0.32941359709393037`, 0.9348024253145186],
              UndirectedEdge[12, 20] -> 
             RGBColor[
              0.3981153177284853, 0.5063212120089932, 0.9479372028327213], 
             UndirectedEdge[16, 50] -> 
             RGBColor[
              0.6267530435840489, 0.6903876418764108, 0.8188353647085449], 
             UndirectedEdge[3, 51] -> 
             RGBColor[
              0.20807297029148525`, 0.33602826273760067`, 0.935160819890501], 
             UndirectedEdge[2, 35] -> 
             RGBColor[
              0.213023200949715, 0.3412312690221517, 0.9354427282032772], 
             UndirectedEdge[9, 31] -> 
             RGBColor[
              0.5487923227740368, 0.6432247484836071, 0.9582004944536783], 
             UndirectedEdge[2, 46] -> 
             RGBColor[
              0.19508068975971515`, 0.32237255214054655`, 0.9344209287345734],
              UndirectedEdge[34, 53] -> 
             RGBColor[
              0.21681542199455828`, 0.3452171337809834, 0.9356586895816927], 
             UndirectedEdge[24, 29] -> 
             RGBColor[
              0.45193553318151863`, 0.560532109877834, 0.9512167843460478], 
             UndirectedEdge[52, 54] -> 
             RGBColor[
              0.4823257569648433, 0.5783694852013241, 0.9549000799446166], 
             UndirectedEdge[16, 44] -> 
             RGBColor[
              0.8584088965714187, 0.887176789740517, 0.8362722772972956], 
             UndirectedEdge[29, 31] -> 
             RGBColor[
              0.5148884420550719, 0.6162051573423037, 0.9551861126429271], 
             UndirectedEdge[17, 27] -> 
             RGBColor[
              0.20062184265739852`, 0.3281966551653973, 0.9347364891946953], 
             UndirectedEdge[5, 14] -> 
             RGBColor[
              0.7414659482232451, 0.7742091752165399, 0.6630892587432926], 
             UndirectedEdge[44, 54] -> 
             RGBColor[
              0.48521617653072185`, 0.5806275029341907, 0.9551881699544368], 
             UndirectedEdge[3, 13] -> 
             RGBColor[
              0.2389203759879076, 0.3684508419630256, 0.9369175340102651], 
             UndirectedEdge[5, 31] -> 
             RGBColor[
              0.7005170303199486, 0.7401214977001054, 0.6600986718295074], 
             UndirectedEdge[35, 43] -> 
             RGBColor[
              0.20799482063972585`, 0.33594612249862743`, 0.9351563693834454],
              UndirectedEdge[48, 54] -> 
             RGBColor[
              0.29984181979296876`, 0.42857219084184905`, 0.9405301191915709],
              UndirectedEdge[17, 53] -> 
             RGBColor[
              0.20670566838878368`, 0.3345911417459136, 0.9350829540698842], 
             UndirectedEdge[17, 50] -> 
             RGBColor[
              0.23981237054425442`, 0.3693883847974674, 0.9369683317806614], 
             UndirectedEdge[19, 42] -> 
             RGBColor[
              0.22559667125208, 0.35444678351399883`, 0.9361587687362145], 
             UndirectedEdge[23, 46] -> 
             RGBColor[
              0.28015261252243795`, 0.40708815280308486`, 0.9394377529681099],
              UndirectedEdge[14, 20] -> 
             RGBColor[
              0.5459820920414296, 0.6422918843890071, 0.9574008567652549], 
             UndirectedEdge[39, 47] -> 
             RGBColor[
              0.7671133739821463, 0.45645002425058734`, 0.568318161249711], 
             UndirectedEdge[1, 52] -> 
             RGBColor[
              0.5778152389028173, 0.6666351308150154, 0.9607810996149653], 
             UndirectedEdge[18, 30] -> 
             RGBColor[
              0.18317660237356231`, 0.30986060153496664`, 0.933743008568451], 
             UndirectedEdge[23, 32] -> 
             RGBColor[
              0.288990357651698, 0.41637718327934237`, 0.939941049478949], 
             UndirectedEdge[29, 39] -> 
             RGBColor[
              0.7124216934534252, 0.41319084590477234`, 0.5632318458269574], 
             UndirectedEdge[17, 46] -> 
             RGBColor[
              0.21093098846931352`, 0.33903222105131675`, 0.9353235797976693],
              UndirectedEdge[4, 36] -> 
             RGBColor[
              0.18869002603562418`, 0.3156555593750441, 0.934056989889626], 
             UndirectedEdge[8, 53] -> 
             RGBColor[
              0.2082065263978199, 0.3361686386733046, 0.9351684257131783], 
             UndirectedEdge[23, 25] -> 
             RGBColor[
              0.2710012864236755, 0.3974695288456985, 0.9389165984849591], 
             UndirectedEdge[25, 43] -> 
             RGBColor[
              0.18090098335096355`, 0.30746878165963587`, 0.9336134154315907],
              UndirectedEdge[4, 40] -> 
             RGBColor[
              0.242858001686303, 0.3725895362319281, 0.9371417759685935], 
             UndirectedEdge[5, 21] -> 
             RGBColor[
              0.9865420342851551, 0.9651546660241341, 0.49665591928631597`], 
             UndirectedEdge[24, 32] -> 
             RGBColor[
              0.2573713535504213, 0.3878439892407728, 0.937968289886675], 
             UndirectedEdge[37, 48] -> 
             RGBColor[
              0.28021365104368784`, 0.40794174098857733`, 0.939412324018573], 
             UndirectedEdge[25, 53] -> 
             RGBColor[
              0.1873438912068433, 0.31424068632011765`, 0.933980329502555], 
             UndirectedEdge[15, 31] -> 
             RGBColor[
              0.3178469944271168, 0.4409132709726823, 0.9417965414359228], 
             UndirectedEdge[5, 28] -> 
             RGBColor[
              0.7040191018380352, 0.7431548160298396, 0.6603218207298798], 
             UndirectedEdge[27, 50] -> 
             RGBColor[
              0.2192927736491615, 0.3478209874431384, 0.9357997710935091], 
             UndirectedEdge[30, 47] -> 
             RGBColor[
              0.4496169942621092, 0.5438699329269783, 0.953056452110292], 
             UndirectedEdge[16, 22] -> 
             RGBColor[
              0.6744345771426743, 0.7363341195973174, 0.8217034356737554], 
             UndirectedEdge[21, 46] -> 
             RGBColor[
              0.5975115212599209, 0.6592611745530137, 0.7779915691295237], 
             UndirectedEdge[15, 52] -> 
             RGBColor[
              0.46472783001497, 0.5598729482039947, 0.9538979040386212], 
             UndirectedEdge[35, 46] -> 
             RGBColor[
              0.2186630485761354, 0.3471591064645123, 0.935763909182195], 
             UndirectedEdge[33, 54] -> 
             RGBColor[
              0.29547753663255494`, 0.4247920681235483, 0.9402520309277735], 
             UndirectedEdge[25, 34] -> 
             RGBColor[
              0.21188941597632563`, 0.34003958912900023`, 0.9353781608263273],
              UndirectedEdge[27, 34] -> 
             RGBColor[
              0.2107315962631731, 0.3388226472004671, 0.935312224706504], 
             UndirectedEdge[28, 49] -> 
             RGBColor[
              0.7096689382625558, 0.7681943050425571, 0.8813079726622974], 
             UndirectedEdge[41, 47] -> 
             RGBColor[
              0.6762180998100495, 0.7468813508213312, 0.968434298356322], 
             UndirectedEdge[30, 54] -> 
             RGBColor[
              0.21548179305530646`, 0.3438154052088712, 0.9355827413865296], 
             UndirectedEdge[32, 53] -> 
             RGBColor[
              0.20533296243486582`, 0.33314834075376154`, 0.9350047804965449],
              UndirectedEdge[13, 48] -> 
             RGBColor[
              0.3230741658037155, 0.4529908595149583, 0.941853166927707], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.20720099597312316`, 0.3351117624426372, 0.9351111622430407], 
             UndirectedEdge[9, 29] -> 
             RGBColor[
              0.6414282676258153, 0.719274282950848, 0.9652600734646661], 
             UndirectedEdge[17, 22] -> 
             RGBColor[
              0.28749390410287967`, 0.41533486251837404`, 0.9398364027458719],
              UndirectedEdge[22, 29] -> 
             RGBColor[
              0.48068537778005915`, 0.5865801821632832, 0.9530067236319055], 
             UndirectedEdge[21, 52] -> 
             RGBColor[
              0.855158336756353, 0.8841484684304038, 0.7967851436914462], 
             UndirectedEdge[14, 47] -> 
             RGBColor[
              0.6105290404870894, 0.6935520132045532, 0.9632630149794656], 
             UndirectedEdge[29, 40] -> 
             RGBColor[
              0.4517436272475488, 0.5603304045736928, 0.9512058555870077], 
             UndirectedEdge[8, 29] -> 
             RGBColor[
              0.41583377123870713`, 0.5225868690920265, 0.9491608424111755], 
             UndirectedEdge[21, 35] -> 
             RGBColor[
              0.6154540324499208, 0.6781198914346187, 0.7790133685982276], 
             UndirectedEdge[47, 48] -> 
             RGBColor[
              0.5339770209997715, 0.6286267185599561, 0.9580038299153334], 
             UndirectedEdge[44, 47] -> 
             RGBColor[
              0.7193513777375247, 0.7806820306522977, 0.9726618806781993], 
             UndirectedEdge[2, 53] -> 
             RGBColor[
              0.19085536967918534`, 0.3179314728351434, 0.9341803030067881], 
             UndirectedEdge[1, 15] -> 
             RGBColor[
              0.3265289005387875, 0.44843310168132244`, 0.9423497448162503], 
             UndirectedEdge[13, 44] -> 
             RGBColor[
              0.5084485225414686, 0.6050461716072999, 0.9565112176905728], 
             UndirectedEdge[3, 54] -> 
             RGBColor[
              0.2156880299771609, 0.3440321732899163, 0.935594486274129], 
             UndirectedEdge[21, 29] -> 
             RGBColor[
              0.8009134460202784, 0.8412383256663324, 0.7917433600997357], 
             UndirectedEdge[25, 29] -> 
             RGBColor[
              0.3949711360477305, 0.5006589167388396, 0.9479727462005523], 
             UndirectedEdge[35, 53] -> 
             RGBColor[
              0.2144377284956056, 0.34271802715910915`, 0.9355232834544097], 
             UndirectedEdge[7, 33] -> 
             RGBColor[
              0.2848422901087888, 0.41361374971349396`, 0.9396463693716823], 
             UndirectedEdge[4, 19] -> 
             RGBColor[
              0.20455585004155313`, 0.33233154635661843`, 0.9349605250953805],
              UndirectedEdge[24, 35] -> 
             RGBColor[
              0.266476119611161, 0.3974136756461204, 0.9384867928445397], 
             UndirectedEdge[1, 5] -> 
             RGBColor[
              0.7091989364316194, 0.7476413284087455, 0.660651875209835], 
             UndirectedEdge[29, 46] -> 
             RGBColor[
              0.404122462146493, 0.5102775406962259, 0.948493900683703], 
             UndirectedEdge[5, 52] -> 
             RGBColor[
              0.8473978659078018, 0.8590811749314178, 0.6722000344322059], 
             UndirectedEdge[22, 50] -> 
             RGBColor[
              0.30616483509464265`, 0.4349591947961151, 0.9408996846446855], 
             UndirectedEdge[20, 48] -> 
             RGBColor[
              0.4694300725541116, 0.57736658974441, 0.9521416717011226], 
             UndirectedEdge[10, 52] -> 
             RGBColor[
              0.45848733433715283`, 0.5533137915763301, 0.9535425170417555], 
             UndirectedEdge[18, 51] -> 
             RGBColor[
              0.20871709518326714`, 0.33670527883874035`, 0.9351975018501906],
              UndirectedEdge[16, 49] -> 
             RGBColor[
              0.9925520109588628, 0.9909644586140982, 0.7568411148147629], 
             UndirectedEdge[22, 35] -> 
             RGBColor[
              0.2952259642097016, 0.42346174793156954`, 0.9402767321303975], 
             UndirectedEdge[27, 43] -> 
             RGBColor[
              0.179743163637811, 0.3062518397311028, 0.9335474793117675], 
             UndirectedEdge[2, 29] -> 
             RGBColor[
              0.3984826145200726, 0.5043497032538653, 0.9481727197047853], 
             UndirectedEdge[9, 44] -> 
             RGBColor[
              0.6985635779277685, 0.7644424434477861, 0.9705899470661968], 
             UndirectedEdge[24, 43] -> 
             RGBColor[
              0.23786538048475167`, 0.36734197479863034`, 0.9368574535770864],
              UndirectedEdge[50, 53] -> 
             RGBColor[
              0.22537659938054666`, 0.3542154740236547, 0.9361462359686978], 
             UndirectedEdge[25, 46] -> 
             RGBColor[
              0.19156921128737311`, 0.3186817656255208, 0.9342209552303404], 
             UndirectedEdge[14, 49] -> 
             RGBColor[
              0.7471157846477657, 0.7992486642292573, 0.8840754106757103], 
             UndirectedEdge[2, 24] -> 
             RGBColor[
              0.2428937607947408, 0.3726271213221546, 0.9371438123969182], 
             UndirectedEdge[6, 36] -> 
             RGBColor[
              0.19927025548053015`, 0.3267760513469321, 0.9346595183044667], 
             UndirectedEdge[12, 18] -> 
             RGBColor[
              0.19622187428559823`, 0.3235720094325277, 0.9344859175050911], 
             UndirectedEdge[13, 30] -> 
             RGBColor[
              0.23871413906605315`, 0.3682340738819805, 0.9369057891226656], 
             UndirectedEdge[14, 51] -> 
             RGBColor[
              0.36877877959461103`, 0.4854935749341304, 0.9453556378720753], 
             UndirectedEdge[16, 23] -> 
             RGBColor[
              0.6773037366454104, 0.7388192413504379, 0.8218862559801716], 
             UndirectedEdge[43, 53] -> 
             RGBColor[
              0.18582698936919623`, 0.31264632631161915`, 0.9338939441869563],
              UndirectedEdge[17, 34] -> 
             RGBColor[
              0.23125119315826603`, 0.3603900445547962, 0.9364807853936563], 
             UndirectedEdge[4, 8] -> 
             RGBColor[
              0.2069481456774613, 0.33484600075026183`, 0.9350967627927613], 
             UndirectedEdge[9, 39] -> 
             RGBColor[
              0.7463255741723901, 0.4402104370460757, 0.5662462276377086], 
             UndirectedEdge[17, 23] -> 
             RGBColor[
              0.29036306360561587`, 0.41781998427149447`, 0.9400192230522881],
              UndirectedEdge[21, 48] -> 
             RGBColor[
              0.6726743995844785, 0.7343511740709288, 0.7824151829384005], 
             UndirectedEdge[17, 35] -> 
             RGBColor[
              0.22887349965931333`, 0.35789093793292187`, 0.9363453792663732],
              UndirectedEdge[11, 41] -> 
             RGBColor[
              0.41834577451862204`, 0.5218776006696907, 0.9496087935318684], 
             UndirectedEdge[41, 52] -> 
             RGBColor[
              0.6757713100174032, 0.7465323152395877, 0.968389766525279], 
             UndirectedEdge[14, 21] -> 
             RGBColor[
              0.7492264190717963, 0.7992764687155258, 0.7876743680025329], 
             UndirectedEdge[16, 21] -> 
             RGBColor[
              0.9946626453828935, 0.9909922631003666, 0.6604400721415855], 
             UndirectedEdge[23, 53] -> 
             RGBColor[
              0.2759272924419081, 0.4026470734976817, 0.9391971272403246], 
             UndirectedEdge[26, 36] -> 
             RGBColor[
              0.1871557289206628, 0.3140429158271639, 0.9339696139387182], 
             UndirectedEdge[14, 33] -> 
             RGBColor[
              0.4232340303621547, 0.5396255605450337, 0.9485704341315797], 
             UndirectedEdge[7, 13] -> 
             RGBColor[
              0.26123444503766746`, 0.39190434332801555`, 0.938188287231942], 
             UndirectedEdge[43, 46] -> 
             RGBColor[
              0.190052309449726, 0.3170874056170223, 0.9341345699147415], 
             UndirectedEdge[24, 50] -> 
             RGBColor[
              0.27741499049610213`, 0.4089111225106659, 0.939109745358828], 
             UndirectedEdge[38, 41] -> 
             RGBColor[
              0.41211112546377365`, 0.5153245892134636, 0.9492537394915315], 
             UndirectedEdge[14, 37] -> 
             RGBColor[
              0.3567656705310057, 0.47286703563317434`, 0.9446715090827053], 
             UndirectedEdge[31, 39] -> 
             RGBColor[
              0.6197857486016467, 0.3371413114375314, 0.5561722668159697], 
             UndirectedEdge[16, 48] -> 
             RGBColor[
              0.6730345398336656, 0.7351214776481753, 0.8216142265344297], 
             UndirectedEdge[29, 32] -> 
             RGBColor[
              0.412960207275753, 0.5195665711724835, 0.9489971971945421], 
             UndirectedEdge[23, 24] -> 
             RGBColor[
              0.3279656835574636, 0.45734272198469295`, 0.9421606366304547], 
             UndirectedEdge[31, 44] -> 
             RGBColor[
              0.5720237523570251, 0.6613733178392418, 0.9605159862444579], 
             UndirectedEdge[28, 41] -> 
             RGBColor[
              0.5323925459476366, 0.6306059563380094, 0.9565115528229529], 
             UndirectedEdge[18, 20] -> 
             RGBColor[
              0.38592040763008567`, 0.49350358829361696`, 0.9472427207433702],
              UndirectedEdge[5, 48] -> 
             RGBColor[
              0.6649139287359273, 0.7092838805719428, 0.6578300736791602], 
             UndirectedEdge[47, 51] -> 
             RGBColor[
              0.47515748707181404`, 0.570714610230752, 0.9545109453920315], 
             UndirectedEdge[17, 21] -> 
             RGBColor[
              0.6077219723430989, 0.6699930060214232, 0.778573039213702], 
             UndirectedEdge[24, 25] -> 
             RGBColor[
              0.23938228232239878`, 0.36893633480712884`, 0.9369438388926852],
              UndirectedEdge[3, 30] -> 
             RGBColor[
              0.18253247748178042`, 0.3091835854338269, 0.9337063266087615], 
             UndirectedEdge[13, 16] -> 
             RGBColor[
              0.6450624116021304, 0.709631948544396, 0.819878056130892], 
             UndirectedEdge[5, 49] -> 
             RGBColor[
              0.9844313998611245, 0.9651268615378656, 0.5930569619594934], 
             UndirectedEdge[47, 49] -> 
             RGBColor[
              0.8534944921249688, 0.884469699525879, 0.8932307181956665], 
             UndirectedEdge[12, 47] -> 
             RGBColor[
              0.4626622661741452, 0.5575813408245393, 0.9537993610469321], 
             UndirectedEdge[25, 35] -> 
             RGBColor[
              0.20951172247737293`, 0.3375404825071259, 0.9352427546990443], 
             UndirectedEdge[11, 28] -> 
             RGBColor[
              0.3152098688104519, 0.43749390386621234`, 0.9416700721415993], 
             UndirectedEdge[23, 40] -> 
             RGBColor[
              0.32777377762349375`, 0.4571410166805517, 0.9421497078714145], 
             UndirectedEdge[13, 14] -> 
             RGBColor[
              0.3996261852910334, 0.5179161541595554, 0.9471123519918394], 
             UndirectedEdge[2, 22] -> 
             RGBColor[
              0.2716436053932813, 0.39867519360760384`, 0.9389337516827758], 
             UndirectedEdge[9, 52] -> 
             RGBColor[
              0.6956731583618899, 0.7621844257149195, 0.9703018570563766], 
             UndirectedEdge[20, 41] -> 
             RGBColor[
              0.6116711513643898, 0.6956212220057851, 0.9625721401421112], 
             UndirectedEdge[5, 16] -> 
             RGBColor[
              0.9869021745343423, 0.9659249696013805, 0.5358549628823452], 
             UndirectedEdge[29, 53] -> 
             RGBColor[
              0.39989714206596316`, 0.5058364613908228, 0.9482532749559178], 
             UndirectedEdge[23, 44] -> 
             RGBColor[
              0.5406898475847486, 0.6342334644133417, 0.9585194175398526], 
             UndirectedEdge[13, 21] -> 
             RGBColor[
              0.6447022713529433, 0.7088616449671497, 0.7806790125348628], 
             UndirectedEdge[20, 54] -> 
             RGBColor[
              0.4182255983118298, 0.5274583919675215, 0.9490824535614487], 
             UndirectedEdge[20, 47] -> 
             RGBColor[
              0.6523607995186326, 0.7275129196856286, 0.9665561642852112], 
             UndirectedEdge[7, 30] -> 
             RGBColor[
              0.2048465465315403, 0.3326370867988169, 0.9349770798304384], 
             UndirectedEdge[39, 44] -> 
             RGBColor[
              0.7695570037553784, 0.4583590064017104, 0.5685617194284882], 
             UndirectedEdge[2, 27] -> 
             RGBColor[
              0.18477154394780015`, 0.3115369862546271, 0.9338338381315994], 
             UndirectedEdge[48, 49] -> 
             RGBColor[
              0.6705637651604479, 0.7343233695846603, 0.8788162256115779], 
             UndirectedEdge[44, 49] -> 
             RGBColor[
              0.855938121898201, 0.8863786816770021, 0.8934742763744438], 
             UndirectedEdge[14, 52] -> 
             RGBColor[
              0.610082250694443, 0.6932029776228096, 0.9632184831484227], 
             UndirectedEdge[41, 49] -> 
             RGBColor[
              0.8128048439707258, 0.8525780018460355, 0.8892466940525665], 
             UndirectedEdge[25, 50] -> 
             RGBColor[
              0.22045059336231404`, 0.34903792937167144`, 0.9358657072133323],
              UndirectedEdge[20, 30] -> 
             RGBColor[
              0.3850700458164493, 0.4926098041114322, 0.9471942938960811], 
             UndirectedEdge[27, 46] -> 
             RGBColor[
              0.19041139157422057`, 0.3174648236969877, 0.934155019110517], 
             UndirectedEdge[29, 48] -> 
             RGBColor[
              0.47928534047105054`, 0.5853675402141411, 0.9529175144925799], 
             UndirectedEdge[16, 20] -> 
             RGBColor[
              0.7914183183525266, 0.8340076787738477, 0.8301665609043075], 
             UndirectedEdge[31, 48] -> 
             RGBColor[
              0.3866493956192719, 0.5093180057469001, 0.9458579354815921], 
             UndirectedEdge[5, 23] -> 
             RGBColor[
              0.6691831255476721, 0.7129816442742053, 0.6581021031249021], 
             UndirectedEdge[3, 33] -> 
             RGBColor[
              0.2625282210590289, 0.39016024834850394`, 0.9383756161500054], 
             UndirectedEdge[29, 50] -> 
             RGBColor[
              0.4330038442214339, 0.5406337044423766, 0.9501386526666951], 
             UndirectedEdge[17, 43] -> 
             RGBColor[
              0.20026276053290396`, 0.3278192370854318, 0.9347160399989198], 
             UndirectedEdge[7, 47] -> 
             RGBColor[
              0.4721373002337236, 0.5675402023730134, 0.9543389502195683], 
             UndirectedEdge[8, 40] -> 
             RGBColor[
              0.2600530115794055, 0.39066258185617453`, 0.9381210063442682], 
             UndirectedEdge[14, 31] -> 
             RGBColor[
              0.46320141510658985`, 0.5742433003914972, 0.9511171205457244], 
             UndirectedEdge[39, 49] -> 
             RGBColor[
              0.9037001181428226, 0.5621466752752916, 0.48913055694595553`], 
             UndirectedEdge[34, 50] -> 
             RGBColor[
              0.249922124150029, 0.38001437683253725`, 0.93754406729247], 
             UndirectedEdge[16, 46] -> 
             RGBColor[
              0.5978716615091081, 0.6600314781302601, 0.8171906127255529], 
             UndirectedEdge[22, 46] -> 
             RGBColor[
              0.27728345301970175`, 0.4046030310499644, 0.9392549326616937], 
             UndirectedEdge[4, 9] -> 
             RGBColor[
              0.4325426420645695, 0.5315334146090834, 0.951195993846252], 
             UndirectedEdge[28, 47] -> 
             RGBColor[
              0.5730821941018794, 0.6624976540178529, 0.9604955769660528], 
             UndirectedEdge[30, 33] -> 
             RGBColor[
              0.26232198413717445`, 0.38994348026745884`, 0.938363871262406], 
             UndirectedEdge[11, 12] -> 
             RGBColor[
              0.20478994088271757`, 0.33257759067289877`, 0.9349738562224785],
              UndirectedEdge[7, 12] -> 
             RGBColor[
              0.21789181844357625`, 0.34634849469637796`, 0.9357199887670784],
              UndirectedEdge[32, 34] -> 
             RGBColor[
              0.22987848720434811`, 0.35894724356264407`, 0.9364026118203171],
              UndirectedEdge[9, 32] -> 
             RGBColor[
              0.4468640879947179, 0.5465861623137869, 0.9520115790052932], 
             UndirectedEdge[16, 17] -> 
             RGBColor[
              0.608082112592286, 0.6707633095986697, 0.8177720828097312], 
             UndirectedEdge[5, 39] -> 
             RGBColor[
              0.8980502817183019, 0.537107186262574, 0.2681444050135378], 
             UndirectedEdge[24, 27] -> 
             RGBColor[
              0.23822446260924623`, 0.3677193928785958, 0.9368779027728619], 
             UndirectedEdge[44, 52] -> 
             RGBColor[
              0.7189045879448782, 0.7803329950705542, 0.9726173488471562], 
             UndirectedEdge[33, 47] -> 
             RGBColor[
              0.5296127378393577, 0.6248465958416554, 0.9577257416515359], 
             UndirectedEdge[19, 40] -> 
             RGBColor[
              0.2576607159434973, 0.38814812746253113`, 0.9379847686468874], 
             UndirectedEdge[37, 54] -> 
             RGBColor[
              0.22900917680140598`, 0.3580335432116889, 0.9363531058788991], 
             UndirectedEdge[20, 51] -> 
             RGBColor[
              0.41061053862615415`, 0.5194544814152059, 0.9486487871778208], 
             UndirectedEdge[17, 29] -> 
             RGBColor[
              0.4143329132296709, 0.5210093721646355, 0.9490753707678813], 
             UndirectedEdge[33, 41] -> 
             RGBColor[
              0.48892308968511483`, 0.5929548981618118, 0.953741717508436], 
             UndirectedEdge[21, 39] -> 
             RGBColor[
              0.9058107525668532, 0.56217447976156, 0.39272951427277814`], 
             UndirectedEdge[30, 51] -> 
             RGBColor[
              0.2078667333696308, 0.3358114946565556, 0.9351490750029017], 
             UndirectedEdge[24, 53] -> 
             RGBColor[
              0.2443082883406314, 0.3741138794591121, 0.9372243676480507], 
             UndirectedEdge[29, 34] -> 
             RGBColor[
              0.4244426668354455, 0.5316353641997054, 0.94965110627969], 
             UndirectedEdge[2, 17] -> 
             RGBColor[
              0.20529114084289307`, 0.3331043836089561, 0.9350023988187517], 
             UndirectedEdge[9, 40] -> 
             RGBColor[
              0.4856475079665137, 0.5873499957149961, 0.9542202373977589], 
             UndirectedEdge[21, 49] -> 
             RGBColor[
              0.9921918707096757, 0.9901941550368516, 0.7176420712187337], 
             UndirectedEdge[13, 51] -> 
             RGBColor[
              0.264254631875758, 0.3950787511857542, 0.9383602824044053], 
             UndirectedEdge[49, 52] -> 
             RGBColor[
              0.8530477023323224, 0.8841206639441355, 0.8931861863646235], 
             UndirectedEdge[2, 34] -> 
             RGBColor[
              0.21540089444866767`, 0.343730375644026, 0.9355781343305603], 
             UndirectedEdge[6, 26] -> 
             RGBColor[
              0.19879906811430337`, 0.32628080355002326`, 0.9346326848810194],
              UndirectedEdge[1, 49] -> 
             RGBColor[
              0.7148487728561399, 0.7726808174214632, 0.8816380271422528], 
             UndirectedEdge[5, 10] -> 
             RGBColor[
              0.5898710318659549, 0.6343199891700603, 0.6534132926366254], 
             UndirectedEdge[20, 21] -> 
             RGBColor[
              0.7910581781033394, 0.8332373751966013, 0.7909675173082783], 
             UndirectedEdge[2, 25] -> 
             RGBColor[
              0.1859293636609527, 0.31275392818316017`, 0.9338997742514226], 
             UndirectedEdge[25, 27] -> 
             RGBColor[
              0.18126006547545812`, 0.30784619973960137`, 
               0.9336338646273663]}, GraphLayout -> {"Dimension" -> 2}, 
           ImageSize -> Medium, VertexSize -> {1.2}, VertexStyle -> {
             EdgeForm[None], 7 -> 
             RGBColor[
              0.22736685250315464`, 0.356307356244852, 0.9362595779397147], 4 -> 
             RGBColor[
              0.18975313578435882`, 0.3167729551260154, 0.9341175324170866], 
             44 -> RGBColor[
              0.7217950075107568, 0.7825910128034208, 0.9729054388569764], 1 -> 
             RGBColor[
              0.43961630942663477`, 0.5551952842923431, 0.9492329403925944], 
             36 -> RGBColor[
              0.18762691628688954`, 0.3145381636240728, 0.9339964473621656], 
             17 -> RGBColor[
              0.22114143955249144`, 0.3497640525197263, 0.9359050498818476], 
             33 -> RGBColor[
              0.3423177277144229, 0.47092014318213593`, 0.9430331608036499], 
             15 -> RGBColor[
              0.2134414916509403, 0.3416709190703018, 0.9354665492399064], 20 -> 
             RGBColor[
              0.5878138510729727, 0.6762527908700825, 0.9606940060710003], 24 -> 
             RGBColor[
              0.29634667945618687`, 0.4288095279461233, 0.9401878770381807], 
             31 -> RGBColor[
              0.4222524972032933, 0.5401556228750628, 0.9481265336319393], 19 -> 
             RGBColor[
              0.21935856429874748`, 0.3478901375872214, 0.9358035177736744], 
             18 -> RGBColor[
              0.18402696418719866`, 0.31075438571715147`, 0.9337914354157401],
              5 -> RGBColor[
              0.9787815634366038, 0.9400873725251481, 0.37207081002707565`], 
             46 -> RGBColor[
              0.20072053738613557`, 0.3283003895829072, 0.9347421097134911], 
             16 -> 
             RGBColor[
              0.9950227856320806, 0.9917625666776131, 0.6996391157376147], 23 -> 
             RGBColor[
              0.3595846876587403, 0.4858759160232626, 0.9441333962227286], 50 -> 
             RGBColor[
              0.2584833015360174, 0.3890127170752085, 0.9380316136794751], 29 -> 
             RGBColor[
              0.6075243869068504, 0.6922546918095447, 0.9622456916539149], 52 -> 
             RGBColor[
              0.7160141683789997, 0.7780749773376876, 0.972329258837336], 51 -> 
             RGBColor[
              0.23340722617933563`, 0.3626561719603293, 0.9366035682846412], 
             3 -> RGBColor[
              0.18273871440363487`, 0.309400353514872, 0.9337180714963609], 
             32 -> RGBColor[
              0.21839602764465565`, 0.3468784505354222, 0.9357487027351693], 
             48 -> RGBColor[
              0.3510462940352506, 0.4784803886187375, 0.9435893373312448], 42 -> 
             RGBColor[
              0.23183477820541248`, 0.3610034294407762, 0.9365140196987546], 
             12 -> RGBColor[
              0.20841678438399783`, 0.3363896331479039, 0.9351803995944422], 
             39 -> RGBColor[0.817319, 0.134127, 0.164218], 25 -> 
             RGBColor[
              0.18241788518861066`, 0.3090631416681344, 0.9336998007471896], 
             28 -> RGBColor[
              0.42925664023946647`, 0.5462222595345311, 0.9485728314326838], 
             35 -> RGBColor[
              0.23660555976613523`, 0.36601782334611743`, 0.9367857086508988],
              43 -> RGBColor[
              0.17938408151331647`, 0.3058744216511374, 0.9335270301159919], 
             40 -> RGBColor[
              0.2959628675882472, 0.4284061173378408, 0.9401660195201004], 34 -> 
             RGBColor[
              0.2413609467640406, 0.371016036589866, 0.937056520905465], 10 -> 
             RGBColor[
              0.20096050029530602`, 0.32855260581497253`, 0.934755775246175], 
             38 -> RGBColor[
              0.18869379927174057`, 0.3156595252854394, 0.9340572047698409], 
             26 -> RGBColor[
              0.186684541554436, 0.3135476680302551, 0.9339427805152709], 6 -> 
             RGBColor[
              0.21091359467417076`, 0.33901393906979144`, 0.9353225892467678],
              2 -> RGBColor[
              0.18944084213329473`, 0.3164447146981859, 0.9340997477556556], 
             27 -> RGBColor[
              0.18010224576230557`, 0.30662925781106826`, 0.933567928507543], 
             21 -> RGBColor[
              0.9943025051337063, 0.9902219595231201, 0.6212410285455563], 54 -> 
             RGBColor[
              0.24863734555068695`, 0.3786639930649607, 0.9374709010518971], 
             53 -> RGBColor[
              0.19226989722507595`, 0.31941823097210087`, 0.9342608582579206],
              30 -> RGBColor[
              0.18232624055992597`, 0.3089668173527818, 0.933694581721162], 
             13 -> RGBColor[
              0.29510203757218034`, 0.4275013304111791, 0.9401169965241692], 
             49 -> RGBColor[
              0.990081236285645, 0.9901663505505832, 0.8140431138919111], 45 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 11 -> 
             RGBColor[
              0.20116309738143734`, 0.32876554819789366`, 0.9347673128505147],
              14 -> RGBColor[
              0.5041503330098864, 0.6083309779079316, 0.9541077074595095], 22 -> 
             RGBColor[
              0.3538463686532679, 0.4809056725170217, 0.9437677556098961], 47 -> 
             RGBColor[
              0.7169077479642925, 0.7787730485011747, 0.972418322499422], 8 -> 
             RGBColor[
              0.2241431555705638, 0.35291904637450827`, 0.9360759931684359], 
             9 -> RGBColor[
              0.6753321483447802, 0.7462938740921514, 0.9682744552754172], 37 -> 
             RGBColor[
              0.20938100805212503`, 0.33740309335841717`, 0.935235310705901], 
             41 -> RGBColor[
              0.6355284516558067, 0.7149896531414878, 0.964450274213222]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJwBcQOO/CFib1JlAgAAADYAAAACAAAAd9u2uRJ5F0CJNtIAENQOQGBQ8+Qq
1xBALOQHy1v82T+Go+hAv5QfQEg/2lxFfv0/1cDPvlcNA0C5u/+P7EsGQAHg
HcBohRRAhc9W79LTBUAAOEbNK/uuP8S0cqgQoAtAPSP63ld5H0BVBinudLIC
QBu8l3K5NwpAhxVjD2bT/T/X/P6IUk8RQBC4QPyeagFAgQ6caO/0E0AuaO8l
ZigPQHmqmerakhtAgPYllXi2EUCaMqpN5fAdQCiazV7fRQpAmBKXZ9HcGkCS
1OXMw3v+P/JYFQH1TRhAL8vWkldyAkC2MF2VaxgVQFaYqzZnsA9AIPQngOy3
FUCOF0rNzTT6P0MNfrRUuxJAXHnJwHSP5z9pxScDFdofQBhKuKqDqAVAei1h
O1nX8j+2BuZRGA4KQN8eEfRLextAUJ6aFDWaAUB+j+yfvfYUQFoU3jGzY/s/
6smJ4S6FFECW3OdLjjLtP5tBMIZJZhFAxv3uEZrc9z+Ic6VySRARQBnN0Ut0
O/E/zuqfc8f6DkDAYreJsl7gPwAAAAAAAAAAcDdQ07ifDkCyeTTABW8RQAAA
AAAAAAAAemXIoMyaGEBm1uleJJEMQC3h6mAynRJA5dEFDqix+z/eBkZ1NWke
QIp+3MePwP8/ZjoEtTqAFUCT1Yjx1HQIQKaUkXl2eg5A41GGWGZS8T+58BJ0
WmAcQLBEVN38hARA2XaZK0nKEUC4v6coQkLlP4Vj9y//PBFAhoh4huxp7D9s
9zt4J3b0P5YtcwYEPgxA01u8YIDbF0CClJ0IN44HQG9aopiCmBxALJ0YObXz
EECI+VEI5kEUQGC2pG0YfAdA9DxDbWUOC0DX+2qGNPQFQEh0ch0huRlAczzN
d2ywCkAAfkvS1YHSPyUK91tqShBA8gXZKmwcD0AwEzHPqjTKP80+w0tRRhZA
l8N3otLMAUDNiqyaLlwTQPqMzyfjMhVAvABpLpWiEkBiBnvFy+bgP6NP5T85
rBlA+dRZUv3uAkCm2eP9kXMXQCtfsA+sWQFALi6PzZMYFUAzt5ITp5cFQJIz
3xJLHhJAqCY/fUQj8D/KzVOQPhAeQJz0CCyHRANARm7cjg9EFkBwnZrUvScH
QLD/p7kI+A1A6MRRw/K66D8TjESK9LUaQGvEDfMlIwRARv561A==
         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 5}], {
             RGBColor[
             0.7091989364316194, 0.7476413284087455, 0.660651875209835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 11}], {
             RGBColor[
             0.32038970340403605`, 0.4419804162451184, 0.9420001266215545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 15}], {
             RGBColor[
             0.3265289005387875, 0.44843310168132244`, 0.9423497448162503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 28}], {
             RGBColor[
             0.4344364748330506, 0.5507087719134371, 0.9489028859126392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 31}], {
             RGBColor[
             0.430934403314964, 0.547675453583703, 0.9486797370122668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 38}], {
             RGBColor[
             0.31415505434918767`, 0.43542740478889125`, 0.9416450725812177]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 39}], {
             RGBColor[
             0.6284676547133174, 0.34466114214617155`, 0.5567254701962971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 41}], {
             RGBColor[
             0.5375723805412207, 0.6350924687169155, 0.9568416073029082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 49}], {
             RGBColor[
             0.7148487728561399, 0.7726808174214632, 0.8816380271422528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 52}], {
             RGBColor[
             0.5778152389028173, 0.6666351308150154, 0.9607810996149653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 17}], {
             RGBColor[
             0.20529114084289307`, 0.3331043836089561, 0.9350023988187517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 22}], {
             RGBColor[
             0.2716436053932813, 0.39867519360760384`, 0.9389337516827758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 23}], {
             RGBColor[
             0.2745127648960175, 0.4011603153607243, 0.9391165719891921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 24}], {
             RGBColor[
             0.2428937607947408, 0.3726271213221546, 0.9371438123969182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 25}], {
             RGBColor[
             0.1859293636609527, 0.31275392818316017`, 0.9338997742514226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 27}], {
             RGBColor[
             0.18477154394780015`, 0.3115369862546271, 0.9338338381315994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 29}], {
             RGBColor[
             0.3984826145200726, 0.5043497032538653, 0.9481727197047853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 32}], {
             RGBColor[
             0.2039184348889752, 0.33166158261680406`, 0.9349242252454124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 34}], {
             RGBColor[
             0.21540089444866767`, 0.343730375644026, 0.9355781343305603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 35}], {
             RGBColor[
             0.213023200949715, 0.3412312690221517, 0.9354427282032772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 43}], {
             RGBColor[
             0.18441246182330562`, 0.3111595681746616, 0.9338133889358238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 46}], {
             RGBColor[
             0.19508068975971515`, 0.32237255214054655`, 0.9344209287345734]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 50}], {
             RGBColor[
             0.22396207183465605`, 0.3527287158866972, 0.9360656807175654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 53}], {
             RGBColor[
             0.19085536967918534`, 0.3179314728351434, 0.9341803030067881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 7}], {
             RGBColor[
             0.20505278345339475`, 0.33285385487986197`, 0.9349888247180378]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 13}], {
             RGBColor[
             0.2389203759879076, 0.3684508419630256, 0.9369175340102651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 20}], {
             RGBColor[
             0.3852762827383038, 0.4928265721924773, 0.9472060387836806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 30}], {
             RGBColor[
             0.18253247748178042`, 0.3091835854338269, 0.9337063266087615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 33}], {
             RGBColor[
             0.2625282210590289, 0.39016024834850394`, 0.9383756161500054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 51}], {
             RGBColor[
             0.20807297029148525`, 0.33602826273760067`, 0.935160819890501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 54}], {
             RGBColor[
             0.2156880299771609, 0.3440321732899163, 0.935594486274129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 8}], {
             RGBColor[
             0.2069481456774613, 0.33484600075026183`, 0.9350967627927613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 9}], {
             RGBColor[
             0.4325426420645695, 0.5315334146090834, 0.951195993846252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 19}], {
             RGBColor[
             0.20455585004155313`, 0.33233154635661843`, 0.9349605250953805]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 36}], {
             RGBColor[
             0.18869002603562418`, 0.3156555593750441, 0.934056989889626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 40}], {
             RGBColor[
             0.242858001686303, 0.3725895362319281, 0.9371417759685935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 9}], {
             RGBColor[
             0.827056855890692, 0.8431906233086497, 0.6701726326512465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 10}], {
             RGBColor[
             0.5898710318659549, 0.6343199891700603, 0.6534132926366254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 14}], {
             RGBColor[
             0.7414659482232451, 0.7742091752165399, 0.6630892587432926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 15}], {
             RGBColor[
             0.5961115275437721, 0.640879145797725, 0.653768679633491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 16}], {
             RGBColor[
             0.9869021745343423, 0.9659249696013805, 0.5358549628823452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 21}], {
             RGBColor[
             0.9865420342851551, 0.9651546660241341, 0.49665591928631597`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 23}], {
             RGBColor[
             0.6691831255476721, 0.7129816442742053, 0.6581021031249021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 28}], {
             RGBColor[
             0.7040191018380352, 0.7431548160298396, 0.6603218207298798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.7931529751717271, 0.8161710321673463, 0.6671582508404953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 31}], {
             RGBColor[
             0.7005170303199486, 0.7401214977001054, 0.6600986718295074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 37}], {
             RGBColor[
             0.5940812857443645, 0.6387452329417826, 0.6536530603664883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 39}], {
             RGBColor[
             0.8980502817183019, 0.537107186262574, 0.2681444050135378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 40}], {
             RGBColor[
             0.6373722155124255, 0.6842467449314944, 0.656118414773588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 41}], {
             RGBColor[
             0.8071550075462053, 0.8275385128333179, 0.6682605421201488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 44}], {
             RGBColor[
             0.8502882854736803, 0.8613391926642844, 0.672488124442026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 47}], {
             RGBColor[
             0.8478446557004482, 0.8594302105131614, 0.6722445662632488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 48}], {
             RGBColor[
             0.6649139287359273, 0.7092838805719428, 0.6578300736791602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 49}], {
             RGBColor[
             0.9844313998611245, 0.9651268615378656, 0.5930569619594934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 52}], {
             RGBColor[
             0.8473978659078018, 0.8590811749314178, 0.6722000344322059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 19}], {
             RGBColor[
             0.21513607948645913`, 0.34345203832850646`, 0.9355630535102211]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 26}], {
             RGBColor[
             0.19879906811430337`, 0.32628080355002326`, 0.9346326848810194]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 36}], {
             RGBColor[
             0.19927025548053015`, 0.3267760513469321, 0.9346595183044667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 42}], {
             RGBColor[
             0.22137418643979162`, 0.3500086842552838, 0.9359183044727613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 12}], {
             RGBColor[
             0.21789181844357625`, 0.34634849469637796`, 0.9357199887670784]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 13}], {
             RGBColor[
             0.26123444503766746`, 0.39190434332801555`, 0.938188287231942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 18}], {
             RGBColor[
             0.20569690834517665`, 0.33353087098100176`, 0.9350255066777273]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 20}], {
             RGBColor[
             0.4075903517880637, 0.5162800735574673, 0.9484767920053575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 30}], {
             RGBColor[
             0.2048465465315403, 0.3326370867988169, 0.9349770798304384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 33}], {
             RGBColor[
             0.2848422901087888, 0.41361374971349396`, 0.9396463693716823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 47}], {
             RGBColor[
             0.4721373002337236, 0.5675402023730134, 0.9543389502195683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 51}], {
             RGBColor[
             0.23038703934124513`, 0.35948176410259064`, 0.936431573112178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 9}], {
             RGBColor[
             0.449737651957672, 0.5496064602333298, 0.9521752242219266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 23}], {
             RGBColor[
             0.291863921614652, 0.4193974811988854, 0.9401046946955822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 29}], {
             RGBColor[
             0.41583377123870713`, 0.5225868690920265, 0.9491608424111755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 32}], {
             RGBColor[
             0.22126959160760973`, 0.34989874845496527`, 0.9359123479518026]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 40}], {
             RGBColor[
             0.2600530115794055, 0.39066258185617453`, 0.9381210063442682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 53}], {
             RGBColor[
             0.2082065263978199, 0.3361686386733046, 0.9351684257131783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 16}], {
             RGBColor[
             0.8351774669884304, 0.8690282203848823, 0.833956785506516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 21}], {
             RGBColor[
             0.8348173267392432, 0.8682579168076358, 0.7947577419104868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 23}], {
             RGBColor[
             0.5174584180017603, 0.616084895057707, 0.9562039257490729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 24}], {
             RGBColor[
             0.4858394139004835, 0.5875517010191373, 0.954231166156799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 29}], {
             RGBColor[
             0.6414282676258153, 0.719274282950848, 0.9652600734646661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 31}], {
             RGBColor[
             0.5487923227740368, 0.6432247484836071, 0.9582004944536783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 32}], {
             RGBColor[
             0.4468640879947179, 0.5465861623137869, 0.9520115790052932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 35}], {
             RGBColor[
             0.45596885405545773`, 0.5561558487191345, 0.952530081963158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 39}], {
             RGBColor[
             0.7463255741723901, 0.4402104370460757, 0.5662462276377086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 40}], {
             RGBColor[
             0.4856475079665137, 0.5873499957149961, 0.9542202373977589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 44}], {
             RGBColor[
             0.6985635779277685, 0.7644424434477861, 0.9705899470661968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 49}], {
             RGBColor[
             0.8327066923152127, 0.8682301123213674, 0.8911587845836642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 50}], {
             RGBColor[
             0.4669077249403988, 0.5676532955836799, 0.9531530344774461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 52}], {
             RGBColor[
             0.6956731583618899, 0.7621844257149195, 0.9703018570563766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.20720099597312316`, 0.3351117624426372, 0.9351111622430407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 31}], {
             RGBColor[
             0.31160649874929963`, 0.4343541143450177, 0.9414411544390572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 37}], {
             RGBColor[
             0.20517075417371552`, 0.33297784958669485`, 0.934995542976038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 45}], {
             RGBColor[
             0.18994375014765302`, 0.31697330290748627`, 0.9341283876230875]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 49}], {
             RGBColor[
             0.5955208682904756, 0.6593594781827778, 0.8743994445690431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 52}], {
             RGBColor[
             0.45848733433715283`, 0.5533137915763301, 0.9535425170417555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 12}], {
             RGBColor[
             0.20478994088271757`, 0.33257759067289877`, 0.9349738562224785]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 28}], {
             RGBColor[
             0.3152098688104519, 0.43749390386621234`, 0.9416700721415993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 38}], {
             RGBColor[
             0.19492844832658895`, 0.3222125367416665, 0.9344122588101778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 41}], {
             RGBColor[
             0.41834577451862204`, 0.5218776006696907, 0.9496087935318684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 18}], {
             RGBColor[
             0.19622187428559823`, 0.3235720094325277, 0.9344859175050911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 20}], {
             RGBColor[
             0.3981153177284853, 0.5063212120089932, 0.9479372028327213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 33}], {
             RGBColor[
             0.27536725604921036`, 0.40365488816501993`, 0.939106780199046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 38}], {
             RGBColor[
             0.19855529182786918`, 0.3260245792166716, 0.9346188021821416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 41}], {
             RGBColor[
             0.42197261801990227`, 0.5256896431446958, 0.9498153369038321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 47}], {
             RGBColor[
             0.4626622661741452, 0.5575813408245393, 0.9537993610469321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 51}], {
             RGBColor[
             0.2209120052816667, 0.34952290255411655`, 0.9358919839395416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 14}], {
             RGBColor[
             0.3996261852910334, 0.5179161541595554, 0.9471123519918394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 16}], {
             RGBColor[
             0.6450624116021304, 0.709631948544396, 0.819878056130892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 20}], {
             RGBColor[
             0.4414579443225765, 0.5518770606406308, 0.9504055012975847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 21}], {
             RGBColor[
             0.6447022713529433, 0.7088616449671497, 0.7806790125348628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 30}], {
             RGBColor[
             0.23871413906605315`, 0.3682340738819805, 0.9369057891226656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 33}], {
             RGBColor[
             0.31870988264330163`, 0.4492107367966575, 0.9415750786639095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 37}], {
             RGBColor[
             0.2522415228121527, 0.38245221188479817`, 0.9376761536150351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 44}], {
             RGBColor[
             0.5084485225414686, 0.6050461716072999, 0.9565112176905728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 47}], {
             RGBColor[
             0.5060048927682363, 0.6031371894561769, 0.9562676595117956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 48}], {
             RGBColor[
             0.3230741658037155, 0.4529908595149583, 0.941853166927707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 51}], {
             RGBColor[
             0.264254631875758, 0.3950787511857542, 0.9383602824044053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 54}], {
             RGBColor[
             0.27186969156143365`, 0.4030826617380699, 0.9387939487880332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 16}], {
             RGBColor[
             0.7495865593209835, 0.8000467722927723, 0.8268734115985621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 20}], {
             RGBColor[
             0.5459820920414296, 0.6422918843890071, 0.9574008567652549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 21}], {
             RGBColor[
             0.7492264190717963, 0.7992764687155258, 0.7876743680025329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 29}], {
             RGBColor[
             0.5558373599583684, 0.6502928348587381, 0.9581766995567123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 31}], {
             RGBColor[
             0.46320141510658985`, 0.5742433003914972, 0.9511171205457244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 33}], {
             RGBColor[
             0.4232340303621547, 0.5396255605450337, 0.9485704341315797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 37}], {
             RGBColor[
             0.3567656705310057, 0.47286703563317434`, 0.9446715090827053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 44}], {
             RGBColor[
             0.6129726702603215, 0.6954609953556762, 0.963506573158243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 47}], {
             RGBColor[
             0.6105290404870894, 0.6935520132045532, 0.9632630149794656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 48}], {
             RGBColor[
             0.4275983135225685, 0.5434056832633345, 0.9488485223953771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 49}], {
             RGBColor[
             0.7471157846477657, 0.7992486642292573, 0.8840754106757103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 51}], {
             RGBColor[
             0.36877877959461103`, 0.4854935749341304, 0.9453556378720753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 52}], {
             RGBColor[
             0.610082250694443, 0.6932029776228096, 0.9632184831484227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 54}], {
             RGBColor[
             0.3763938392802867, 0.4934974854864461, 0.9457893042557033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 28}], {
             RGBColor[
             0.3213490659452034, 0.44394658930241643`, 0.9420196903362951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 31}], {
             RGBColor[
             0.3178469944271168, 0.4409132709726823, 0.9417965414359228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 39}], {
             RGBColor[
             0.5153802458254702, 0.2378989595351509, 0.5498422746199532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 45}], {
             RGBColor[
             0.19618424582547017`, 0.32353245953515086`, 0.9344837746199532]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 49}], {
             RGBColor[
             0.6017613639682927, 0.6659186348104424, 0.8747548315659087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 52}], {
             RGBColor[
             0.46472783001497, 0.5598729482039947, 0.9538979040386212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 17}], {
             RGBColor[
             0.608082112592286, 0.6707633095986697, 0.8177720828097312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 20}], {
             RGBColor[
             0.7914183183525266, 0.8340076787738477, 0.8301665609043075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 21}], {
             RGBColor[
             0.9946626453828935, 0.9909922631003666, 0.6604400721415855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 22}], {
             RGBColor[
             0.6744345771426743, 0.7363341195973174, 0.8217034356737554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 23}], {
             RGBColor[
             0.6773037366454104, 0.7388192413504379, 0.8218862559801716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 24}], {
             RGBColor[
             0.6456847325441337, 0.7102860473118682, 0.8199134963878978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 29}], {
             RGBColor[
             0.8012735862694655, 0.8420086292435789, 0.8309424036957649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.6686702566732518, 0.7313413549298745, 0.8213361382706323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 34}], {
             RGBColor[
             0.6181918661980605, 0.6813893016337396, 0.8183478183215398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 35}], {
             RGBColor[
             0.6158141726991079, 0.6788901950118653, 0.8182124121942568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 39}], {
             RGBColor[
             0.9061708928160404, 0.5629447833388066, 0.43192855786880735`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 44}], {
             RGBColor[
             0.8584088965714187, 0.887176789740517, 0.8362722772972956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 46}], {
             RGBColor[
             0.5978716615091081, 0.6600314781302601, 0.8171906127255529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 47}], {
             RGBColor[
             0.8559652667981865, 0.8852678075893938, 0.8360287191185183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 48}], {
             RGBColor[
             0.6730345398336656, 0.7351214776481753, 0.8216142265344297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 49}], {
             RGBColor[
             0.9925520109588628, 0.9909644586140982, 0.7568411148147629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 50}], {
             RGBColor[
             0.6267530435840489, 0.6903876418764108, 0.8188353647085449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 21}], {
             RGBColor[
             0.6077219723430989, 0.6699930060214232, 0.778573039213702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 22}], {
             RGBColor[
             0.28749390410287967`, 0.41533486251837404`, 0.9398364027458719]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 23}], {
             RGBColor[
             0.29036306360561587`, 0.41781998427149447`, 0.9400192230522881]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 24}], {
             RGBColor[
             0.25874405950433915`, 0.3892867902329248, 0.9380464634600142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 25}], {
             RGBColor[
             0.20177966237055106`, 0.32941359709393037`, 0.9348024253145186]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 27}], {
             RGBColor[
             0.20062184265739852`, 0.3281966551653973, 0.9347364891946953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 29}], {
             RGBColor[
             0.4143329132296709, 0.5210093721646355, 0.9490753707678813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 32}], {
             RGBColor[
             0.21976873359857355`, 0.34832125152757426`, 0.9358268763085085]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 34}], {
             RGBColor[
             0.23125119315826603`, 0.3603900445547962, 0.9364807853936563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 35}], {
             RGBColor[
             0.22887349965931333`, 0.35789093793292187`, 0.9363453792663732]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 43}], {
             RGBColor[
             0.20026276053290396`, 0.3278192370854318, 0.9347160399989198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 46}], {
             RGBColor[
             0.21093098846931352`, 0.33903222105131675`, 0.9353235797976693]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 50}], {
             RGBColor[
             0.23981237054425442`, 0.3693883847974674, 0.9369683317806614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 53}], {
             RGBColor[
             0.20670566838878368`, 0.3345911417459136, 0.9350829540698842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 20}], {
             RGBColor[
             0.38592040763008567`, 0.49350358829361696`, 0.9472427207433702]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 30}], {
             RGBColor[
             0.18317660237356231`, 0.30986060153496664`, 0.933743008568451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 33}], {
             RGBColor[
             0.2631723459508108, 0.39083726444964373`, 0.938412298109695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 47}], {
             RGBColor[
             0.45046735607574556`, 0.544763717109163, 0.953104878957581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 51}], {
             RGBColor[
             0.20871709518326714`, 0.33670527883874035`, 0.9351975018501906]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 26}], {
             RGBColor[
             0.20302155292659174`, 0.3307189028087383, 0.9348731491444726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 36}], {
             RGBColor[
             0.2034927402928185, 0.3312141506056471, 0.9348999825679201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 40}], {
             RGBColor[
             0.2576607159434973, 0.38814812746253113`, 0.9379847686468874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 42}], {
             RGBColor[
             0.22559667125208, 0.35444678351399883`, 0.9361587687362145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 21}], {
             RGBColor[
             0.7910581781033394, 0.8332373751966013, 0.7909675173082783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 30}], {
             RGBColor[
             0.3850700458164493, 0.4926098041114322, 0.9471942938960811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 33}], {
             RGBColor[
             0.4650657893936978, 0.5735864670261093, 0.951863583437325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 41}], {
             RGBColor[
             0.6116711513643898, 0.6956212220057851, 0.9625721401421112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 44}], {
             RGBColor[
             0.6548044292918647, 0.7294219018367516, 0.9667997224639884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 47}], {
             RGBColor[
             0.6523607995186326, 0.7275129196856286, 0.9665561642852112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 48}], {
             RGBColor[
             0.4694300725541116, 0.57736658974441, 0.9521416717011226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 51}], {
             RGBColor[
             0.41061053862615415`, 0.5194544814152059, 0.9486487871778208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 54}], {
             RGBColor[
             0.4182255983118298, 0.5274583919675215, 0.9490824535614487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 22}], {
             RGBColor[
             0.6740744368934871, 0.7355638160200709, 0.7825043920777262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 23}], {
             RGBColor[
             0.6769435963962234, 0.7380489377731914, 0.7826872123841424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 24}], {
             RGBColor[
             0.6453245922949467, 0.7095157437346217, 0.7807144527918686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 29}], {
             RGBColor[
             0.8009134460202784, 0.8412383256663324, 0.7917433600997357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 34}], {
             RGBColor[
             0.6178317259488735, 0.6806189980564931, 0.7791487747255106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 35}], {
             RGBColor[
             0.6154540324499208, 0.6781198914346187, 0.7790133685982276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 39}], {
             RGBColor[
             0.9058107525668532, 0.56217447976156, 0.39272951427277814`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 44}], {
             RGBColor[
             0.8580487563222315, 0.8864064861632704, 0.7970732337012664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 46}], {
             RGBColor[
             0.5975115212599209, 0.6592611745530137, 0.7779915691295237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 47}], {
             RGBColor[
             0.8556051265489995, 0.8844975040121474, 0.7968296755224891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 48}], {
             RGBColor[
             0.6726743995844785, 0.7343511740709288, 0.7824151829384005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 49}], {
             RGBColor[
             0.9921918707096757, 0.9901941550368516, 0.7176420712187337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 50}], {
             RGBColor[
             0.6263929033348619, 0.6896173382991643, 0.7796363211125157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 52}], {
             RGBColor[
             0.855158336756353, 0.8841484684304038, 0.7967851436914462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 23}], {
             RGBColor[
             0.3567155281560041, 0.48339079427014214`, 0.9439505759163124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 24}], {
             RGBColor[
             0.3250965240547274, 0.4548576002315725, 0.9419778163240384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 27}], {
             RGBColor[
             0.26697430720778675`, 0.393767465164045, 0.9386678420587196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 29}], {
             RGBColor[
             0.48068537778005915`, 0.5865801821632832, 0.9530067236319055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 34}], {
             RGBColor[
             0.29760365770865427`, 0.42596085455344385`, 0.9404121382576806]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 35}], {
             RGBColor[
             0.2952259642097016, 0.42346174793156954`, 0.9402767321303975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 46}], {
             RGBColor[
             0.27728345301970175`, 0.4046030310499644, 0.9392549326616937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 47}], {
             RGBColor[
             0.5353770583087802, 0.6298393605090982, 0.958093039054659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 50}], {
             RGBColor[
             0.30616483509464265`, 0.4349591947961151, 0.9408996846446855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 24}], {
             RGBColor[
             0.3279656835574636, 0.45734272198469295`, 0.9421606366304547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 25}], {
             RGBColor[
             0.2710012864236755, 0.3974695288456985, 0.9389165984849591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 29}], {
             RGBColor[
             0.48355453728279535`, 0.5890653039164037, 0.9531895439383218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 32}], {
             RGBColor[
             0.288990357651698, 0.41637718327934237`, 0.939941049478949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 34}], {
             RGBColor[
             0.30047281721139046`, 0.4284459763065643, 0.9405949585640968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 35}], {
             RGBColor[
             0.29809512371243774`, 0.42594686968469, 0.9404595524368138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 40}], {
             RGBColor[
             0.32777377762349375`, 0.4571410166805517, 0.9421497078714145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 43}], {
             RGBColor[
             0.2694843845860284, 0.3958751688372, 0.9388302131693602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 44}], {
             RGBColor[
             0.5406898475847486, 0.6342334644133417, 0.9585194175398526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 46}], {
             RGBColor[
             0.28015261252243795`, 0.40708815280308486`, 0.9394377529681099]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 49}], {
             RGBColor[
             0.6748329619721927, 0.7380211332869229, 0.8790882550573198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 50}], {
             RGBColor[
             0.30903399459737885`, 0.43744431654923555`, 0.9410825049511018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 53}], {
             RGBColor[
             0.2759272924419081, 0.4026470734976817, 0.9391971272403246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 25}], {
             RGBColor[
             0.23938228232239878`, 0.36893633480712884`, 0.9369438388926852]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.23822446260924623`, 0.3677193928785958, 0.9368779027728619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 29}], {
             RGBColor[
             0.45193553318151863`, 0.560532109877834, 0.9512167843460478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 32}], {
             RGBColor[
             0.2573713535504213, 0.3878439892407728, 0.937968289886675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 34}], {
             RGBColor[
             0.26885381311011375`, 0.39991278226799465`, 0.9386221989718229]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 35}], {
             RGBColor[
             0.266476119611161, 0.3974136756461204, 0.9384867928445397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 43}], {
             RGBColor[
             0.23786538048475167`, 0.36734197479863034`, 0.9368574535770864]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 46}], {
             RGBColor[
             0.24853360842116123`, 0.3785549587645153, 0.9374649933758359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 50}], {
             RGBColor[
             0.27741499049610213`, 0.4089111225106659, 0.939109745358828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 53}], {
             RGBColor[
             0.2443082883406314, 0.3741138794591121, 0.9372243676480507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 27}], {
             RGBColor[
             0.18126006547545812`, 0.30784619973960137`, 0.9336338646273663]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 29}], {
             RGBColor[
             0.3949711360477305, 0.5006589167388396, 0.9479727462005523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 32}], {
             RGBColor[
             0.20040695641663314`, 0.3279707961017783, 0.9347242517411795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 34}], {
             RGBColor[
             0.21188941597632563`, 0.34003958912900023`, 0.9353781608263273]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 35}], {
             RGBColor[
             0.20951172247737293`, 0.3375404825071259, 0.9352427546990443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[
             0.18090098335096355`, 0.30746878165963587`, 0.9336134154315907]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 46}], {
             RGBColor[
             0.19156921128737311`, 0.3186817656255208, 0.9342209552303404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 50}], {
             RGBColor[
             0.22045059336231404`, 0.34903792937167144`, 0.9358657072133323]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 53}], {
             RGBColor[
             0.1873438912068433, 0.31424068632011765`, 0.933980329502555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 36}], {
             RGBColor[
             0.1871557289206628, 0.3140429158271639, 0.9339696139387182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 42}], {
             RGBColor[
             0.20925965987992423`, 0.33727554873551563`, 0.9352284001070128]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 34}], {
             RGBColor[
             0.2107315962631731, 0.3388226472004671, 0.935312224706504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 35}], {
             RGBColor[
             0.2083539027642204, 0.3363235405785928, 0.9351768185792209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 43}], {
             RGBColor[
             0.179743163637811, 0.3062518397311028, 0.9335474793117675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 46}], {
             RGBColor[
             0.19041139157422057`, 0.3174648236969877, 0.934155019110517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 50}], {
             RGBColor[
             0.2192927736491615, 0.3478209874431384, 0.9357997710935091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 53}], {
             RGBColor[
             0.18618607149369076`, 0.31302374439158454`, 0.9339143933827319]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 33}], {
             RGBColor[
             0.38578718397694467`, 0.5085712013583334, 0.9458029961181669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 38}], {
             RGBColor[
             0.3089752197556035, 0.43094089240998523`, 0.9413150181012624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 39}], {
             RGBColor[
             0.6232878201197333, 0.34017462976726554`, 0.5563954157163419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 41}], {
             RGBColor[
             0.5323925459476366, 0.6306059563380094, 0.9565115528229529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 47}], {
             RGBColor[
             0.5730821941018794, 0.6624976540178529, 0.9604955769660528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 49}], {
             RGBColor[
             0.7096689382625558, 0.7681943050425571, 0.8813079726622974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 52}], {
             RGBColor[
             0.5726354043092331, 0.6621486184361094, 0.9604510451350099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 31}], {
             RGBColor[
             0.5148884420550719, 0.6162051573423037, 0.9551861126429271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 32}], {
             RGBColor[
             0.412960207275753, 0.5195665711724835, 0.9489971971945421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 34}], {
             RGBColor[
             0.4244426668354455, 0.5316353641997054, 0.94965110627969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 35}], {
             RGBColor[
             0.42206497333649284`, 0.5291362575778311, 0.9495157001524068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 39}], {
             RGBColor[
             0.7124216934534252, 0.41319084590477234`, 0.5632318458269574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 40}], {
             RGBColor[
             0.4517436272475488, 0.5603304045736928, 0.9512058555870077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 44}], {
             RGBColor[
             0.6646596972088036, 0.7374228523064827, 0.9675755652554456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 46}], {
             RGBColor[
             0.404122462146493, 0.5102775406962259, 0.948493900683703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 48}], {
             RGBColor[
             0.47928534047105054`, 0.5853675402141411, 0.9529175144925799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 49}], {
             RGBColor[
             0.7988028115962478, 0.841210521180064, 0.8881444027729131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 50}], {
             RGBColor[
             0.4330038442214339, 0.5406337044423766, 0.9501386526666951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 52}], {
             RGBColor[
             0.661769277642925, 0.7351648345736161, 0.9672874752456255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 53}], {
             RGBColor[
             0.39989714206596316`, 0.5058364613908228, 0.9482532749559178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 33}], {
             RGBColor[
             0.26232198413717445`, 0.38994348026745884`, 0.938363871262406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 47}], {
             RGBColor[
             0.4496169942621092, 0.5438699329269783, 0.953056452110292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 51}], {
             RGBColor[
             0.2078667333696308, 0.3358114946565556, 0.9351490750029017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 54}], {
             RGBColor[
             0.21548179305530646`, 0.3438154052088712, 0.9355827413865296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 37}], {
             RGBColor[
             0.31581675262770914`, 0.43877935811673996`, 0.9416809221689202]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 39}], {
             RGBColor[
             0.6197857486016467, 0.3371413114375314, 0.5561722668159697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 44}], {
             RGBColor[
             0.5720237523570251, 0.6613733178392418, 0.9605159862444579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 48}], {
             RGBColor[
             0.3866493956192719, 0.5093180057469001, 0.9458579354815921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 49}], {
             RGBColor[
             0.7061668667444692, 0.7651609867128231, 0.8810848237619252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 52}], {
             RGBColor[
             0.5691333327911465, 0.6591153001063752, 0.9602278962346377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 54}], {
             RGBColor[
             0.3354449213769901, 0.45940980797001174`, 0.9427987173419182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 34}], {
             RGBColor[
             0.22987848720434811`, 0.35894724356264407`, 0.9364026118203171]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 35}], {
             RGBColor[
             0.22750079370539544`, 0.3564481369407698, 0.9362672056930341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 43}], {
             RGBColor[
             0.19889005457898606`, 0.3263764360932798, 0.9346378664255806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 46}], {
             RGBColor[
             0.2095582825153956, 0.3375894200591647, 0.9352454062243303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 50}], {
             RGBColor[
             0.23843966459033653`, 0.3679455838053154, 0.9368901582073221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 53}], {
             RGBColor[
             0.20533296243486582`, 0.33314834075376154`, 0.9350047804965449]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 41}], {
             RGBColor[
             0.48892308968511483`, 0.5929548981618118, 0.953741717508436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 47}], {
             RGBColor[
             0.5296127378393577, 0.6248465958416554, 0.9577257416515359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 51}], {
             RGBColor[
             0.2878624769468793, 0.4167881575712326, 0.9398183645441456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 54}], {
             RGBColor[
             0.29547753663255494`, 0.4247920681235483, 0.9402520309277735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 35}], {
             RGBColor[
             0.2389832532650879, 0.3685169299679917, 0.936921114778182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 43}], {
             RGBColor[
             0.21037251413867852`, 0.3384452291205017, 0.9352917755107284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 46}], {
             RGBColor[
             0.2210407420750881, 0.34965821308638656`, 0.9358993153094781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 50}], {
             RGBColor[
             0.249922124150029, 0.38001437683253725`, 0.93754406729247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 53}], {
             RGBColor[
             0.21681542199455828`, 0.3452171337809834, 0.9356586895816927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 43}], {
             RGBColor[
             0.20799482063972585`, 0.33594612249862743`, 0.9351563693834454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 46}], {
             RGBColor[
             0.2186630485761354, 0.3471591064645123, 0.935763909182195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 50}], {
             RGBColor[
             0.2475444306510763, 0.377515270210663, 0.937408661165187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 53}], {
             RGBColor[
             0.2144377284956056, 0.34271802715910915`, 0.9355232834544097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 40}], {
             RGBColor[
             0.24179489193756837`, 0.3714721404809568, 0.9370812334411329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 42}], {
             RGBColor[
             0.20973084724615101`, 0.3377707965324245, 0.93525523353046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 44}], {
             RGBColor[
             0.46558800778144094`, 0.559997053080919, 0.9540703747814387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 48}], {
             RGBColor[
             0.28021365104368784`, 0.40794174098857733`, 0.939412324018573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 49}], {
             RGBColor[
             0.599731122168885, 0.6637847219545001, 0.8746392122989061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 52}], {
             RGBColor[
             0.4626975882155624, 0.5577390353480524, 0.9537822847716185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 54}], {
             RGBColor[
             0.22900917680140598`, 0.3580335432116889, 0.9363531058788991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 41}], {
             RGBColor[
             0.41211112546377365`, 0.5153245892134636, 0.9492537394915315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 40}], {
             RGBColor[
             0.5566409337941236, 0.28126655866892036`, 0.5521920097600502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 41}], {
             RGBColor[
             0.7264237258279034, 0.4245583265707439, 0.5643341371066111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 44}], {
             RGBColor[
             0.7695570037553784, 0.4583590064017104, 0.5685617194284882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 47}], {
             RGBColor[
             0.7671133739821463, 0.45645002425058734`, 0.568318161249711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 49}], {
             RGBColor[
             0.9037001181428226, 0.5621466752752916, 0.48913055694595553`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 52}], {
             RGBColor[
             0.7666665841894998, 0.4561009886688438, 0.568273629418668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 49}], {
             RGBColor[
             0.6430220519369461, 0.7092862339442121, 0.8771045667060058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 47}], {
             RGBColor[
             0.6762180998100495, 0.7468813508213312, 0.968434298356322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 49}], {
             RGBColor[
             0.8128048439707258, 0.8525780018460355, 0.8892466940525665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 52}], {
             RGBColor[
             0.6757713100174032, 0.7465323152395877, 0.968389766525279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 46}], {
             RGBColor[
             0.190052309449726, 0.3170874056170223, 0.9341345699147415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 50}], {
             RGBColor[
             0.21893369152466693`, 0.34744356936317294`, 0.9357793218977335]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 53}], {
             RGBColor[
             0.18582698936919623`, 0.31264632631161915`, 0.9338939441869563]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 47}], {
             RGBColor[
             0.7193513777375247, 0.7806820306522977, 0.9726618806781993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 48}], {
             RGBColor[
             0.5364206507730037, 0.6305357007110791, 0.9582473880941107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 49}], {
             RGBColor[
             0.855938121898201, 0.8863786816770021, 0.8934742763744438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 52}], {
             RGBColor[
             0.7189045879448782, 0.7803329950705542, 0.9726173488471562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 54}], {
             RGBColor[
             0.48521617653072185`, 0.5806275029341907, 0.9551881699544368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 50}], {
             RGBColor[
             0.2296019194610765, 0.3586565533290579, 0.9363868616964831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 53}], {
             RGBColor[
             0.19649521730560576`, 0.32385931027750403`, 0.9345014839857059]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 48}], {
             RGBColor[
             0.5339770209997715, 0.6286267185599561, 0.9580038299153334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 49}], {
             RGBColor[
             0.8534944921249688, 0.884469699525879, 0.8932307181956665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 51}], {
             RGBColor[
             0.47515748707181404`, 0.570714610230752, 0.9545109453920315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 54}], {
             RGBColor[
             0.4827725467574897, 0.5787185207830676, 0.9549446117756595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 49}], {
             RGBColor[
             0.6705637651604479, 0.7343233695846603, 0.8788162256115779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 52}], {
             RGBColor[
             0.5335302312071252, 0.6282776829782125, 0.9579592980842904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 54}], {
             RGBColor[
             0.29984181979296876`, 0.42857219084184905`, 0.9405301191915709]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 52}], {
             RGBColor[
             0.8530477023323224, 0.8841206639441355, 0.8931861863646235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 53}], {
             RGBColor[
             0.22537659938054666`, 0.3542154740236547, 0.9361462359686978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 54}], {
             RGBColor[
             0.4823257569648433, 0.5783694852013241, 0.9549000799446166]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.08801479198093362], {
             RGBColor[
             0.43961630942663477`, 0.5551952842923431, 0.9492329403925944]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.08801479198093362], {
             RGBColor[
             0.18944084213329473`, 0.3164447146981859, 0.9340997477556556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.08801479198093362], {
             RGBColor[
             0.18273871440363487`, 0.309400353514872, 0.9337180714963609]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.08801479198093362], {
             RGBColor[
             0.18975313578435882`, 0.3167729551260154, 0.9341175324170866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.08801479198093362], {
             RGBColor[
             0.9787815634366038, 0.9400873725251481, 0.37207081002707565`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.08801479198093362], {
             RGBColor[
             0.21091359467417076`, 0.33901393906979144`, 0.9353225892467678]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.08801479198093362], {
             RGBColor[
             0.22736685250315464`, 0.356307356244852, 0.9362595779397147]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.08801479198093362], {
             RGBColor[
             0.2241431555705638, 0.35291904637450827`, 0.9360759931684359]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.08801479198093362], {
             RGBColor[
             0.6753321483447802, 0.7462938740921514, 0.9682744552754172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.08801479198093362], {
             RGBColor[
             0.20096050029530602`, 0.32855260581497253`, 0.934755775246175]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.08801479198093362], {
             RGBColor[
             0.20116309738143734`, 0.32876554819789366`, 0.9347673128505147]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.08801479198093362], {
             RGBColor[
             0.20841678438399783`, 0.3363896331479039, 0.9351803995944422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.08801479198093362], {
             RGBColor[
             0.29510203757218034`, 0.4275013304111791, 0.9401169965241692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.08801479198093362], {
             RGBColor[
             0.5041503330098864, 0.6083309779079316, 0.9541077074595095]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.08801479198093362], {
             RGBColor[
             0.2134414916509403, 0.3416709190703018, 0.9354665492399064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.08801479198093362], {
             RGBColor[
             0.9950227856320806, 0.9917625666776131, 0.6996391157376147]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.08801479198093362], {
             RGBColor[
             0.22114143955249144`, 0.3497640525197263, 0.9359050498818476]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.08801479198093362], {
             RGBColor[
             0.18402696418719866`, 0.31075438571715147`, 0.9337914354157401]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.08801479198093362], {
             RGBColor[
             0.21935856429874748`, 0.3478901375872214, 0.9358035177736744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.08801479198093362], {
             RGBColor[
             0.5878138510729727, 0.6762527908700825, 0.9606940060710003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.08801479198093362], {
             RGBColor[
             0.9943025051337063, 0.9902219595231201, 0.6212410285455563]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.08801479198093362], {
             RGBColor[
             0.3538463686532679, 0.4809056725170217, 0.9437677556098961]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.08801479198093362], {
             RGBColor[
             0.3595846876587403, 0.4858759160232626, 0.9441333962227286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.08801479198093362], {
             RGBColor[
             0.29634667945618687`, 0.4288095279461233, 0.9401878770381807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.08801479198093362], {
             RGBColor[
             0.18241788518861066`, 0.3090631416681344, 0.9336998007471896]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.08801479198093362], {
             RGBColor[
             0.186684541554436, 0.3135476680302551, 0.9339427805152709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.08801479198093362], {
             RGBColor[
             0.18010224576230557`, 0.30662925781106826`, 0.933567928507543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.08801479198093362], {
             RGBColor[
             0.42925664023946647`, 0.5462222595345311, 0.9485728314326838]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.08801479198093362], {
             RGBColor[
             0.6075243869068504, 0.6922546918095447, 0.9622456916539149]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.08801479198093362], {
             RGBColor[
             0.18232624055992597`, 0.3089668173527818, 0.933694581721162]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.08801479198093362], {
             RGBColor[
             0.4222524972032933, 0.5401556228750628, 0.9481265336319393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.08801479198093362], {
             RGBColor[
             0.21839602764465565`, 0.3468784505354222, 0.9357487027351693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.08801479198093362], {
             RGBColor[
             0.3423177277144229, 0.47092014318213593`, 0.9430331608036499]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.08801479198093362], {
             RGBColor[
             0.2413609467640406, 0.371016036589866, 0.937056520905465]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.08801479198093362], {
             RGBColor[
             0.23660555976613523`, 0.36601782334611743`, 0.9367857086508988]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.08801479198093362], {
             RGBColor[
             0.18762691628688954`, 0.3145381636240728, 0.9339964473621656]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.08801479198093362], {
             RGBColor[
             0.20938100805212503`, 0.33740309335841717`, 0.935235310705901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.08801479198093362], {
             RGBColor[
             0.18869379927174057`, 0.3156595252854394, 0.9340572047698409]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.08801479198093362], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.08801479198093362], {
             RGBColor[
             0.2959628675882472, 0.4284061173378408, 0.9401660195201004]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.08801479198093362], {
             RGBColor[
             0.6355284516558067, 0.7149896531414878, 0.964450274213222]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.08801479198093362], {
             RGBColor[
             0.23183477820541248`, 0.3610034294407762, 0.9365140196987546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.08801479198093362], {
             RGBColor[
             0.17938408151331647`, 0.3058744216511374, 0.9335270301159919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.08801479198093362], {
             RGBColor[
             0.7217950075107568, 0.7825910128034208, 0.9729054388569764]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.08801479198093362], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.08801479198093362], {
             RGBColor[
             0.20072053738613557`, 0.3283003895829072, 0.9347421097134911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.08801479198093362], {
             RGBColor[
             0.7169077479642925, 0.7787730485011747, 0.972418322499422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.08801479198093362], {
             RGBColor[
             0.3510462940352506, 0.4784803886187375, 0.9435893373312448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.08801479198093362], {
             RGBColor[
             0.990081236285645, 0.9901663505505832, 0.8140431138919111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.08801479198093362], {
             RGBColor[
             0.2584833015360174, 0.3890127170752085, 0.9380316136794751]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.08801479198093362], {
             RGBColor[
             0.23340722617933563`, 0.3626561719603293, 0.9366035682846412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.08801479198093362], {
             RGBColor[
             0.7160141683789997, 0.7780749773376876, 0.972329258837336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.08801479198093362], {
             RGBColor[
             0.19226989722507595`, 0.31941823097210087`, 0.9342608582579206]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.08801479198093362], {
             RGBColor[
             0.24863734555068695`, 0.3786639930649607, 0.9374709010518971]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> Medium, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55}, {Null, CompressedData["
1:eJwVxVvaoiAAANBEUQstyWvyo4h4wYS0JPYxS/g3MPt/m2/Oy+l+//75BafT
KXBOp/+vhzv7kz+6POF8Psfx4zEFa3As63Kci7goHhWvluqIr9fi+rhOTuCU
zprkeemLSnAhRh9jgUc8+VGEIxGN0eTY2BaW29k693t+L4EPIoDBAwgwggkg
H6EIYcSRQCOaqn3Z98P9zt9kuA/5UA7BZ/msn8/hZEmW8cx6Zy/2Mq/wuDd7
1qWIJhTTjFJOBR3pTL/UOpfgclm9/tzHfdYXfW9B6qcojVKcpiId08nrzl3c
FV3XdxYwxCKGWcEejAk2MVv9gNqvUR3VuE7rmtWiHuspae5N3pRNM7i32+y2
t5a27dx+AYQ+RDCCGKawhhQyyKGAo6ugQgqrWlHVKq6EGtWs1NcxibmbzOSm
NI3hZjDGupu33Ta6tRvf+m3e1LZ9HR3oTFeaaa6FXvSq9a4PbbR1pCcDmclC
MsmlkFLLQxppq/fPe3nv7+SZP3+ezXN4hkmYhXnYhDwcwmdoIAkJIgnJSEUI
JYxwIogkC1FEk50cxDiv4HV5ra/X5x+i2Dtm
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[14, 25] -> 
             RGBColor[
              0.1888999390943334, 0.3158761913090041, 0.9340689441277811], 
             UndirectedEdge[3, 40] -> 
             RGBColor[
              0.25450474788314653`, 0.3848310049311702, 0.9378050409346868], 
             UndirectedEdge[17, 32] -> 
             RGBColor[
              0.3276747195444407, 0.45074809644812713`, 0.9423743305779937], 
             UndirectedEdge[20, 34] -> 
             RGBColor[
              0.8710476787579927, 0.4967074814664401, 0.2136950397745813], 
             UndirectedEdge[2, 32] -> 
             RGBColor[
              0.3325218491257287, 0.4558427369638265, 0.9426503674369624], 
             UndirectedEdge[1, 41] -> 
             RGBColor[
              0.5568042151990069, 0.28143817777809177`, 0.5522013083945051], 
             UndirectedEdge[12, 38] -> 
             RGBColor[
              0.19669585728513517`, 0.3240701956172989, 0.9345129101357197], 
             UndirectedEdge[15, 40] -> 
             RGBColor[
              0.2228106990002401, 0.35151855003647203`, 0.9360001117379488], 
             UndirectedEdge[3, 34] -> 
             RGBColor[
              0.5469801762145448, 0.384996272496024, 0.5670998593124947], 
             UndirectedEdge[7, 44] -> 
             RGBColor[
              0.23764606638694302`, 0.36711146177651655`, 0.9368449639636622],
              UndirectedEdge[3, 15] -> 
             RGBColor[
              0.21062104888290645`, 0.33870645489469814`, 0.935305929196738], 
             UndirectedEdge[2, 38] -> 
             RGBColor[
              0.2156695900720717, 0.34401279178051014`, 0.9355934361488136], 
             UndirectedEdge[1, 18] -> 
             RGBColor[
              0.23977099791697926`, 0.3693448995430252, 0.9369659756707434], 
             UndirectedEdge[40, 48] -> 
             RGBColor[
              0.24413385585835384`, 0.3739305398605802, 0.9372144339762347], 
             UndirectedEdge[11, 34] -> 
             RGBColor[
              0.5993368486787543, 0.4364869814664393, 0.5702110918140775], 
             UndirectedEdge[20, 53] -> 
             RGBColor[
              0.7663484421245242, 0.6579426118061934, 0.5976401925290493], 
             UndirectedEdge[5, 11] -> 
             RGBColor[
              0.3573974848199224, 0.48398147085628956`, 0.9439940295919067], 
             UndirectedEdge[21, 23] -> 
             RGBColor[
              0.18694837378268236`, 0.31382497243007146`, 0.9339578053703648],
              UndirectedEdge[2, 11] -> 
             RGBColor[
              0.2922343206512414, 0.42094770470928367`, 0.9400832817474307], 
             UndirectedEdge[21, 43] -> 
             RGBColor[
              0.18631488774670363`, 0.31315913844092325`, 0.9339217292777744],
              UndirectedEdge[32, 41] -> 
             RGBColor[
              0.6224612498216031, 0.3394586961196564, 0.5563427473878524], 
             UndirectedEdge[24, 28] -> 
             RGBColor[
              0.2714844633715748, 0.39795589279784777`, 0.9389449013924356], 
             UndirectedEdge[45, 48] -> 
             RGBColor[
              0.33346912695791514`, 0.45519621949076033`, 0.9427644412693525],
              UndirectedEdge[6, 19] -> 
             RGBColor[
              0.1873961981598438, 0.31429566424417354`, 0.9339833083061473], 
             UndirectedEdge[53, 55] -> 
             RGBColor[
              0.8055825763190831, 0.8483919242812921, 0.9512382176138312], 
             UndirectedEdge[7, 10] -> 
             RGBColor[
              0.22521243972122862`, 0.35404293181338786`, 0.9361368873189522],
              UndirectedEdge[40, 54] -> 
             RGBColor[
              0.23351316064250563`, 0.36276751579775385`, 0.9366096010956027],
              UndirectedEdge[32, 46] -> 
             RGBColor[
              0.7113345891159812, 0.7683223513070561, 0.8263876220714172], 
             UndirectedEdge[8, 43] -> 
             RGBColor[
              0.2323163656900787, 0.3615096084215705, 0.9365414453935614], 
             UndirectedEdge[31, 45] -> 
             RGBColor[
              0.3157392984250307, 0.43656104556664277`, 0.9417547537633356], 
             UndirectedEdge[4, 41] -> 
             RGBColor[
              0.560088528287322, 0.284890199071388, 0.5523883451661789], 
             UndirectedEdge[22, 25] -> 
             RGBColor[
              0.2234859012296062, 0.35222823038982976`, 0.9360385635060391], 
             UndirectedEdge[3, 31] -> 
             RGBColor[
              0.21421437720813574`, 0.34248327079468877`, 0.9355105639290069],
              UndirectedEdge[36, 46] -> 
             RGBColor[
              0.828529906512468, 0.8638642133144459, 0.8356263980334822], 
             UndirectedEdge[32, 55] -> 
             RGBColor[
              0.6982609354425164, 0.7605651724598694, 0.9429823821314589], 
             UndirectedEdge[1, 23] -> 
             RGBColor[
              0.23845491806439612`, 0.3679616161736781, 0.9368910268701044], 
             UndirectedEdge[11, 36] -> 
             RGBColor[
              0.5045112885652057, 0.6054372219921598, 0.955139185048238], 
             UndirectedEdge[8, 16] -> 
             RGBColor[
              0.38466298294781887`, 0.504593462582444, 0.9460413396713032], 
             UndirectedEdge[11, 27] -> 
             RGBColor[
              0.6703413411158923, 0.7319178563464401, 0.7470073212161956], 
             UndirectedEdge[46, 49] -> 
             RGBColor[
              0.6043085016005248, 0.6668203354256476, 0.8198902767158509], 
             UndirectedEdge[34, 46] -> 
             RGBColor[
              0.9233554666260166, 0.6949139727887255, 0.45069830479932155`], 
             UndirectedEdge[1, 55] -> 
             RGBColor[
              0.6326039008199202, 0.7025446541183049, 0.9388409431381116], 
             UndirectedEdge[24, 34] -> 
             RGBColor[
              0.6057311640625255, 0.4420254160642261, 0.5706185319360604], 
             UndirectedEdge[2, 5] -> 
             RGBColor[
              0.302603362776932, 0.42992884783534613`, 0.9407439879426958], 
             UndirectedEdge[18, 23] -> 
             RGBColor[
              0.18193648558336145`, 0.3085571601605197, 0.9336723857518375], 
             UndirectedEdge[46, 52] -> 
             RGBColor[
              0.657983920326443, 0.722112683484139, 0.822988164632292], 
             UndirectedEdge[38, 45] -> 
             RGBColor[
              0.3196319608677476, 0.4406524806029921, 0.9419764351307702], 
             UndirectedEdge[5, 17] -> 
             RGBColor[
              0.2977562331956441, 0.4248342073196468, 0.940467951083727], 
             UndirectedEdge[27, 41] -> 
             RGBColor[
              0.9054866197687764, 0.5614811924813267, 0.35744965951787483`], 
             UndirectedEdge[20, 55] -> 
             RGBColor[
              0.9296842370472675, 0.7858906402053274, 0.5838992444024311], 
             UndirectedEdge[27, 53] -> 
             RGBColor[
              0.8179505104669463, 0.8546396404224057, 0.7578302423880996], 
             UndirectedEdge[1, 10] -> 
             RGBColor[
              0.2409053701676021, 0.3705371967017846, 0.937030576492263], 
             UndirectedEdge[4, 20] -> 
             RGBColor[
              0.5966540797136763, 0.5155473629365024, 0.5854299548250034], 
             UndirectedEdge[13, 25] -> 
             RGBColor[
              0.19799715375087024`, 0.32543794070974774`, 0.9345870170443478],
              UndirectedEdge[37, 43] -> 
             RGBColor[
              0.19365829242781518`, 0.32087752235951994`, 0.9343399253107699],
              UndirectedEdge[40, 45] -> 
             RGBColor[
              0.3560296691000415, 0.4789087797031241, 0.9440492307690155], 
             UndirectedEdge[17, 39] -> 
             RGBColor[
              0.21040354476915382`, 0.3384778442805868, 0.9352935426592283], 
             UndirectedEdge[4, 48] -> 
             RGBColor[
              0.2622156851454358, 0.39293568889549624`, 0.9382441674044648], 
             UndirectedEdge[9, 13] -> 
             RGBColor[
              0.19139873430423845`, 0.31850258350738125`, 0.934211246818349], 
             UndirectedEdge[6, 11] -> 
             RGBColor[
              0.2680477039419866, 0.39552603702778566`, 0.9387058897067315], 
             UndirectedEdge[6, 17] -> 
             RGBColor[
              0.20840645231770838`, 0.33637877349114287`, 0.935179811198552], 
             UndirectedEdge[24, 46] -> 
             RGBColor[
              0.6774413760252653, 0.7389657536503, 0.8242279765038685], 
             UndirectedEdge[46, 55] -> 
             RGBColor[
              0.9819920249152915, 0.9840971315276128, 0.8209025094271714], 
             UndirectedEdge[11, 38] -> 
             RGBColor[
              0.27046371211506204`, 0.3980654148014535, 0.9388434777980244], 
             UndirectedEdge[31, 54] -> 
             RGBColor[
              0.1932227899674948, 0.3204197816612725, 0.9343151240899228], 
             UndirectedEdge[27, 45] -> 
             RGBColor[
              0.7195095898685778, 0.7745049221479787, 0.7501402785489415], 
             UndirectedEdge[23, 37] -> 
             RGBColor[
              0.19429177846379392`, 0.32154335634866815`, 0.9343760014033603],
              UndirectedEdge[13, 33] -> 
             RGBColor[
              0.19617592925264465`, 0.32352371828981014`, 0.9344833010034341],
              UndirectedEdge[7, 51] -> 
             RGBColor[
              0.2237689951651678, 0.3525257800652972, 0.9360546852868693], 
             UndirectedEdge[19, 39] -> 
             RGBColor[
              0.18939329061128923`, 0.3163947350336175, 0.9340970397668236], 
             UndirectedEdge[29, 54] -> 
             RGBColor[
              0.4002278105060737, 0.507069205229579, 0.9481915305037079], 
             UndirectedEdge[5, 12] -> 
             RGBColor[
              0.28362962998999547`, 0.4099862516721349, 0.939663461929602], 
             UndirectedEdge[7, 52] -> 
             RGBColor[
              0.2929028657846983, 0.42406594118643437`, 0.9400329091699214], 
             UndirectedEdge[16, 34] -> 
             RGBColor[
              0.6678459614187889, 0.4949917761686375, 0.5748069667765074], 
             UndirectedEdge[19, 26] -> 
             RGBColor[
              0.19455187407893437`, 0.32181673333119526`, 0.9343908134638655],
              UndirectedEdge[5, 19] -> 
             RGBColor[
              0.27674597903777953`, 0.4027510980726775, 0.9392714481913222], 
             UndirectedEdge[27, 42] -> 
             RGBColor[
              0.6118487750956456, 0.6739779342105083, 0.7435466586538375], 
             UndirectedEdge[14, 39] -> 
             RGBColor[
              0.1868657712176106, 0.31373815189687587`, 0.9339531012764835], 
             UndirectedEdge[19, 36] -> 
             RGBColor[
              0.4238597827830628, 0.5242068492085477, 0.9504166036476538], 
             UndirectedEdge[27, 52] -> 
             RGBColor[
              0.6572782008008413, 0.7206032207780659, 0.746174949466602], 
             UndirectedEdge[46, 53] -> 
             RGBColor[
              0.8186562299925482, 0.8561491031284788, 0.8346434575537895], 
             UndirectedEdge[9, 35] -> 
             RGBColor[
              0.21947100840306363`, 0.34800832347022564`, 0.9358099212990691],
              UndirectedEdge[5, 29] -> 
             RGBColor[
              0.48394511233661464`, 0.5896045464594732, 0.9531589090396398], 
             UndirectedEdge[22, 33] -> 
             RGBColor[
              0.22166467673138063`, 0.3503140079698921, 0.9359348474651252], 
             UndirectedEdge[20, 46] -> 
             RGBColor[
              0.9427578907207326, 0.793647819052514, 0.46730448434238936`], 
             UndirectedEdge[12, 26] -> 
             RGBColor[
              0.20143552503115036`, 0.3290518869306527, 0.9347828272021452], 
             UndirectedEdge[16, 37] -> 
             RGBColor[
              0.3460049096855553, 0.4639613765203935, 0.9438398195885117], 
             UndirectedEdge[44, 46] -> 
             RGBColor[
              0.6027271209286877, 0.6651582040742212, 0.8198002194260328], 
             UndirectedEdge[25, 32] -> 
             RGBColor[
              0.3123664927446421, 0.4346581794839007, 0.9415025497082372], 
             UndirectedEdge[12, 39] -> 
             RGBColor[
              0.19627694156350523`, 0.32362988863307496`, 0.9344890535051031],
              UndirectedEdge[2, 6] -> 
             RGBColor[
              0.21325358189899632`, 0.3414734140068422, 0.9354558480575208], 
             UndirectedEdge[16, 29] -> 
             RGBColor[
              0.5420851829509588, 0.6391281980356088, 0.9570940778068047], 
             UndirectedEdge[42, 50] -> 
             RGBColor[
              0.20667848007461492`, 0.3345625651038835, 0.9350814057356136], 
             UndirectedEdge[8, 27] -> 
             RGBColor[
              0.6394667686294446, 0.703006196496459, 0.7451194625284274], 
             UndirectedEdge[5, 6] -> 
             RGBColor[
              0.2784167460676773, 0.4045071801538481, 0.9393665959019967], 
             UndirectedEdge[17, 36] -> 
             RGBColor[
              0.4448700369409274, 0.546289958455517, 0.9516131065400585], 
             UndirectedEdge[1, 47] -> 
             RGBColor[
              0.2395389231881016, 0.36910097428858707`, 0.9369527593582576], 
             UndirectedEdge[27, 29] -> 
             RGBColor[
              0.7968889686325846, 0.8375409319496239, 0.7561722006639289], 
             UndirectedEdge[34, 53] -> 
             RGBColor[
              0.7469460180298083, 0.559208765542405, 0.5810340129859815], 
             UndirectedEdge[3, 48] -> 
             RGBColor[
              0.2319442057410202, 0.3611184447188064, 0.9365202514350239], 
             UndirectedEdge[33, 55] -> 
             RGBColor[
              0.5812027040457267, 0.6485187372845197, 0.9359137210230775], 
             UndirectedEdge[5, 36] -> 
             RGBColor[
              0.5148803306908963, 0.6144183651182222, 0.9557998912435032], 
             UndirectedEdge[11, 32] -> 
             RGBColor[
              0.38731597116871896`, 0.50989535998477, 0.9459004090861732], 
             UndirectedEdge[20, 27] -> 
             RGBColor[
              0.9420521711951307, 0.792138356346441, 0.3904912691766994], 
             UndirectedEdge[1, 7] -> 
             RGBColor[
              0.2805964999516404, 0.41225509066778687`, 0.9392909276156993], 
             UndirectedEdge[29, 31] -> 
             RGBColor[
              0.3931186771890374, 0.4995970553682878, 0.9477866758783229], 
             UndirectedEdge[21, 53] -> 
             RGBColor[
              0.41776156161546313`, 0.5204599819755642, 0.9496486697649902], 
             UndirectedEdge[2, 39] -> 
             RGBColor[
              0.21525067435044176`, 0.3435724847962862, 0.9355695795181971], 
             UndirectedEdge[48, 54] -> 
             RGBColor[
              0.21095261850037927`, 0.33905495558539006`, 0.9353248115959398],
              UndirectedEdge[51, 52] -> 
             RGBColor[
              0.2517682914445992, 0.3808308954723414, 0.9376903560144022], 
             UndirectedEdge[33, 35] -> 
             RGBColor[
              0.22424820335146983`, 0.3530294582526545, 0.9360819754841543], 
             UndirectedEdge[41, 46] -> 
             RGBColor[
              0.9061923392943783, 0.5629906551873998, 0.43426287468356484`], 
             UndirectedEdge[18, 30] -> 
             RGBColor[
              0.1891441421788809, 0.31613286423423337`, 0.9340828511321799], 
             UndirectedEdge[17, 38] -> 
             RGBColor[
              0.2108224604907838, 0.33891815126481073`, 0.9353173992898448], 
             UndirectedEdge[24, 49] -> 
             RGBColor[
              0.2866841990370338, 0.4139317787011481, 0.9398105038525897], 
             UndirectedEdge[18, 21] -> 
             RGBColor[
              0.1882644536352655, 0.31520825579941847`, 0.9340327541710036], 
             UndirectedEdge[8, 53] -> 
             RGBColor[
              0.46376303955883824`, 0.5688104519562114, 0.9522683858807772], 
             UndirectedEdge[12, 36] -> 
             RGBColor[
              0.4307434337352788, 0.5314420028080051, 0.9508086173859334], 
             UndirectedEdge[4, 40] -> 
             RGBColor[
              0.28477622728756213`, 0.41664824910786, 0.9395289569041276], 
             UndirectedEdge[25, 39] -> 
             RGBColor[
              0.19509531796935525`, 0.32238792731636035`, 0.9344217617894719],
              UndirectedEdge[22, 55] -> 
             RGBColor[
              0.6093803439274805, 0.6781352233657985, 0.9375183959292608], 
             UndirectedEdge[28, 43] -> 
             RGBColor[
              0.18125264347009812`, 0.30783839874138563`, 0.9336334419551409],
              UndirectedEdge[24, 42] -> 
             RGBColor[
              0.2949301920577562, 0.42259884019208194`, 0.9402801009562664], 
             UndirectedEdge[2, 36] -> 
             RGBColor[
              0.44971716652221533`, 0.5513845989712163, 0.9518891433990273], 
             UndirectedEdge[22, 32] -> 
             RGBColor[
              0.3387229081281703, 0.46236044314524183`, 0.9430035085735067], 
             UndirectedEdge[8, 30] -> 
             RGBColor[
              0.2401575083215769, 0.3697511464844323, 0.9369879868664943], 
             UndirectedEdge[36, 38] -> 
             RGBColor[
              0.427946557986036, 0.5285023090633862, 0.9506493394496209], 
             UndirectedEdge[15, 31] -> 
             RGBColor[
              0.1825203283252293, 0.3091708158999906, 0.933705634732269], 
             UndirectedEdge[19, 38] -> 
             RGBColor[
              0.18981220633291918`, 0.3168350420178414, 0.9341208963974401], 
             UndirectedEdge[21, 30] -> 
             RGBColor[
              0.19415603037820178`, 0.3214006765037851, 0.9343682707507072], 
             UndirectedEdge[3, 45] -> 
             RGBColor[
              0.3438400189827079, 0.4660966845613502, 0.9433550482278046], 
             UndirectedEdge[27, 49] -> 
             RGBColor[
              0.603602782074923, 0.6653108727195746, 0.743077061550161], 
             UndirectedEdge[17, 19] -> 
             RGBColor[
              0.20673568528781058`, 0.33462269140997214`, 0.9350846634878776],
              UndirectedEdge[11, 29] -> 
             RGBColor[
              0.473576070210924, 0.5806234033334107, 0.9524982028443747], 
             UndirectedEdge[4, 34] -> 
             RGBColor[
              0.5772516556189604, 0.4168135166727138, 0.5688237752819356], 
             UndirectedEdge[15, 48] -> 
             RGBColor[
              0.20025015685811376`, 0.32780598982410825`, 0.9347153222382859],
              UndirectedEdge[24, 52] -> 
             RGBColor[
              0.340359617762952, 0.46922412675963954`, 0.9429083917690309], 
             UndirectedEdge[9, 33] -> 
             RGBColor[
              0.1887098419012207, 0.31567638710618445`, 0.9340581183738569], 
             UndirectedEdge[16, 30] -> 
             RGBColor[
              0.3395411935480591, 0.4571676010366117, 0.9434717205166925], 
             UndirectedEdge[5, 34] -> 
             RGBColor[
              0.6097058908044449, 0.44546812459250185`, 0.5708717980093426], 
             UndirectedEdge[12, 32] -> 
             RGBColor[
              0.3135481163387921, 0.4359001408006153, 0.9415698414238686], 
             UndirectedEdge[27, 34] -> 
             RGBColor[
              0.9226497471004148, 0.6934045100826525, 0.3738850896336316], 
             UndirectedEdge[2, 12] -> 
             RGBColor[
              0.21846646582131451`, 0.34695248552512903`, 0.9357527140851261],
              UndirectedEdge[7, 41] -> 
             RGBColor[
              0.5411112847526334, 0.2649439128896951, 0.5513076192211943], 
             UndirectedEdge[34, 48] -> 
             RGBColor[
              0.5366092841897521, 0.374095807425434, 0.5665092523540427], 
             UndirectedEdge[13, 55] -> 
             RGBColor[
              0.5838915964487446, 0.6513449336857164, 0.9360668494675696], 
             UndirectedEdge[6, 38] -> 
             RGBColor[
              0.191482973362817, 0.31859112409901214`, 0.9342160441081144], 
             UndirectedEdge[30, 37] -> 
             RGBColor[
              0.20149943505931334`, 0.3291190604223818, 0.9347864667837027], 
             UndirectedEdge[32, 39] -> 
             RGBColor[
              0.3103323248679194, 0.4325201400717725, 0.9413867068569395], 
             UndirectedEdge[11, 45] -> 
             RGBColor[
              0.39619669144691727`, 0.5175873935317656, 0.9464662807293874], 
             UndirectedEdge[29, 40] -> 
             RGBColor[
              0.4334090478640482, 0.5419447895047691, 0.9500811528840027], 
             UndirectedEdge[9, 22] -> 
             RGBColor[
              0.21688748178297443`, 0.34529287318746327`, 0.9356627932800401],
              UndirectedEdge[34, 41] -> 
             RGBColor[
              0.8344821273316384, 0.2660503176013258, 0.18065343011575674`], 
             UndirectedEdge[1, 53] -> 
             RGBColor[
              0.4692681058971769, 0.5745966257191709, 0.9525818912647299], 
             UndirectedEdge[44, 47] -> 
             RGBColor[
              0.1965884896234042, 0.3239573453973167, 0.9345067957062204], 
             UndirectedEdge[5, 38] -> 
             RGBColor[
              0.2808327542407527, 0.40704655792751604`, 0.9395041839932895], 
             UndirectedEdge[20, 35] -> 
             RGBColor[
              0.5727297363530107, 0.49040136117346217`, 0.5840674988635077], 
             UndirectedEdge[8, 21] -> 
             RGBColor[
              0.2392778197779615, 0.36882653804961746`, 0.936937889905318], 
             UndirectedEdge[23, 30] -> 
             RGBColor[
              0.18782806232629773`, 0.3147495808648863, 0.9340079023315411], 
             UndirectedEdge[3, 54] -> 
             RGBColor[
              0.221323510525172, 0.34995542065597995`, 0.9359154185543919], 
             UndirectedEdge[18, 37] -> 
             RGBColor[
              0.19560785831637706`, 0.3229266397180152, 0.9344509502039993], 
             UndirectedEdge[27, 32] -> 
             RGBColor[
              0.7106288695903795, 0.7668128886009831, 0.7495744069057273], 
             UndirectedEdge[36, 41] -> 
             RGBColor[
              0.7396565672180898, 0.4350005581270462, 0.5655815233499173], 
             UndirectedEdge[35, 48] -> 
             RGBColor[
              0.23829134178477013`, 0.3677896871324561, 0.9368817114429691], 
             UndirectedEdge[6, 12] -> 
             RGBColor[
              0.19427984911205975`, 0.321530817843631, 0.9343753220444269], 
             UndirectedEdge[34, 55] -> 
             RGBColor[
              0.9102818129525516, 0.6871567939415388, 0.5672930648593633], 
             UndirectedEdge[1, 46] -> 
             RGBColor[
              0.6456775544933852, 0.7103018329654915, 0.8222461830780698], 
             UndirectedEdge[40, 55] -> 
             RGBColor[
              0.6178063846211534, 0.686991526376685, 0.9379982464815553], 
             UndirectedEdge[22, 41] -> 
             RGBColor[
              0.5335806583065672, 0.2570287470255854, 0.5508787611856543], 
             UndirectedEdge[22, 35] -> 
             RGBColor[
              0.2524258432332236, 0.3826459443339333, 0.9376866503903375], 
             UndirectedEdge[11, 26] -> 
             RGBColor[
              0.27520337986107724`, 0.4030471061148073, 0.9391133948644499], 
             UndirectedEdge[12, 17] -> 
             RGBColor[
              0.21361933624002655`, 0.3418578450094296, 0.9354766772261573], 
             UndirectedEdge[21, 37] -> 
             RGBColor[
              0.20061974651569797`, 0.3281944519875669, 0.9347363698225264], 
             UndirectedEdge[11, 17] -> 
             RGBColor[
              0.2873871910699535, 0.41585306419358425`, 0.939807244888462], 
             UndirectedEdge[44, 51] -> 
             RGBColor[
              0.19651149204684393`, 0.3238764160624235, 0.934502410808143], 
             UndirectedEdge[10, 47] -> 
             RGBColor[
              0.1841548629576898, 0.31088881543418806`, 0.9337987190615102], 
             UndirectedEdge[24, 36] -> 
             RGBColor[
              0.5109056039489769, 0.6109756565899465, 0.9555466251702209], 
             UndirectedEdge[6, 36] -> 
             RGBColor[
              0.42553054981296057`, 0.5259629312897183, 0.9505117513583281], 
             UndirectedEdge[36, 45] -> 
             RGBColor[
              0.5536795373178912, 0.6480242877936984, 0.9582721423809839], 
             UndirectedEdge[27, 36] -> 
             RGBColor[
              0.8278241869868662, 0.8623547506083729, 0.7588131828677922], 
             UndirectedEdge[16, 27] -> 
             RGBColor[
              0.738850453855927, 0.7904226510486383, 0.7516031961786256], 
             UndirectedEdge[26, 39] -> 
             RGBColor[
              0.1982197335602776, 0.32567188620180987`, 0.9345996926352163], 
             UndirectedEdge[17, 26] -> 
             RGBColor[
              0.215562128236799, 0.3438998425781645, 0.9355873163562702], 
             UndirectedEdge[30, 43] -> 
             RGBColor[
              0.187194576290319, 0.31408374687573815`, 0.9339718262389507], 
             UndirectedEdge[41, 52] -> 
             RGBColor[
              0.5691105810320649, 0.29324902829673927`, 0.5529432899487272], 
             UndirectedEdge[16, 21] -> 
             RGBColor[
              0.33866150500444375`, 0.4562429926017968, 0.9434216235555162], 
             UndirectedEdge[23, 53] -> 
             RGBColor[
              0.4114335935635591, 0.5138088863366654, 0.949288301345824], 
             UndirectedEdge[26, 36] -> 
             RGBColor[
              0.4326862257320512, 0.53348400037674, 0.9509192565160465], 
             UndirectedEdge[16, 53] -> 
             RGBColor[
              0.5631467247853205, 0.6562269065083908, 0.9587521195309754], 
             UndirectedEdge[34, 40] -> 
             RGBColor[
              0.5591698263318785, 0.3978083676377978, 0.5677940418537055], 
             UndirectedEdge[11, 39] -> 
             RGBColor[
              0.2700447963934321, 0.3976251078172296, 0.9388196211674078], 
             UndirectedEdge[24, 50] -> 
             RGBColor[
              0.2715653614786329, 0.3980409218376021, 0.9389495084199546], 
             UndirectedEdge[26, 38] -> 
             RGBColor[
              0.19863864928190758`, 0.3261121931860338, 0.9346235492658328], 
             UndirectedEdge[14, 22] -> 
             RGBColor[
              0.21525635447786157`, 0.3435784549703452, 0.9355699029930507], 
             UndirectedEdge[2, 26] -> 
             RGBColor[
              0.2204092578180869, 0.34899448309386394`, 0.9358633532152391], 
             UndirectedEdge[30, 53] -> 
             RGBColor[
              0.4186412501590785, 0.5213845904103791, 0.9496987667261665], 
             UndirectedEdge[29, 38] -> 
             RGBColor[
              0.39701133963175433`, 0.5036884904046371, 0.9480083572457576], 
             UndirectedEdge[20, 29] -> 
             RGBColor[
              0.7452869002901625, 0.6408439033334115, 0.5959821508048786], 
             UndirectedEdge[47, 51] -> 
             RGBColor[
              0.18271141840162902`, 0.30937166368609736`, 0.9337165170294275],
              UndirectedEdge[12, 19] -> 
             RGBColor[
              0.192609082082162, 0.3197747357624603, 0.9342801743337525], 
             UndirectedEdge[8, 20] -> 
             RGBColor[
              0.5878647002870225, 0.5063091678802467, 0.584929412669377], 
             UndirectedEdge[11, 19] -> 
             RGBColor[
              0.26637693691208886`, 0.39376995494661493`, 0.9386107419960572],
              UndirectedEdge[5, 45] -> 
             RGBColor[
              0.40656573357260795`, 0.5265685366578281, 0.9471269869246526], 
             UndirectedEdge[18, 53] -> 
             RGBColor[
              0.4127496734161422, 0.5151921697060124, 0.9493632501464631], 
             UndirectedEdge[13, 14] -> 
             RGBColor[
              0.1897676069991256, 0.31678816529026327`, 0.9341183565313593], 
             UndirectedEdge[7, 46] -> 
             RGBColor[
              0.6299846240470117, 0.6938075680770948, 0.8213524939047591], 
             UndirectedEdge[34, 45] -> 
             RGBColor[
              0.6485050974314398, 0.4790740472679779, 0.5733440491468234], 
             UndirectedEdge[45, 54] -> 
             RGBColor[
              0.32284843174206695`, 0.44403319542793396`, 0.9421596083887205],
              UndirectedEdge[13, 35] -> 
             RGBColor[
              0.22693709575448762`, 0.3558556546538513, 0.9362351039286463], 
             UndirectedEdge[20, 41] -> 
             RGBColor[
              0.8538845514263543, 0.3647841638651143, 0.19725960965882455`], 
             UndirectedEdge[28, 50] -> 
             RGBColor[
              0.18323275138843348`, 0.3099196177096494, 0.9337462061717829], 
             UndirectedEdge[4, 22] -> 
             RGBColor[
              0.27635018659388927`, 0.40779194609697345`, 0.9390491063518331],
              UndirectedEdge[10, 44] -> 
             RGBColor[
              0.19795493660290472`, 0.3253935678105142, 0.9345846128402258], 
             UndirectedEdge[4, 13] -> 
             RGBColor[
              0.2508614391151533, 0.3810016564168915, 0.9375975598901419], 
             UndirectedEdge[4, 55] -> 
             RGBColor[
              0.6358882139082354, 0.705996675411601, 0.9390279799097854], 
             UndirectedEdge[34, 36] -> 
             RGBColor[
              0.7568196945497282, 0.566923875728372, 0.5820169534656741], 
             UndirectedEdge[37, 53] -> 
             RGBColor[
              0.4251049662965747, 0.5281783658941609, 0.9500668657979858], 
             UndirectedEdge[49, 50] -> 
             RGBColor[
              0.19843248705389244`, 0.3258955036129497, 0.934611808631937], 
             UndirectedEdge[27, 46] -> 
             RGBColor[
              0.9943599590631547, 0.9903448476687264, 0.6274945342014396], 
             UndirectedEdge[29, 48] -> 
             RGBColor[
              0.4108485057219219, 0.5182322292924053, 0.9487963633843399], 
             UndirectedEdge[29, 55] -> 
             RGBColor[
              0.7845210344847214, 0.8312932158085102, 0.9495801758896605], 
             UndirectedEdge[31, 48] -> 
             RGBColor[
              0.20384348518334303`, 0.3315828057240988, 0.9349199569705549], 
             UndirectedEdge[29, 36] -> 
             RGBColor[
              0.631058916081898, 0.7110602975953433, 0.9643040644959713], 
             UndirectedEdge[16, 20] -> 
             RGBColor[
              0.6872483855135049, 0.593725622432426, 0.5914131463195752], 
             UndirectedEdge[4, 35] -> 
             RGBColor[
              0.2789337132139785, 0.4105073963797359, 0.9391962343708621], 
             UndirectedEdge[42, 52] -> 
             RGBColor[
              0.275472736358934, 0.405745770025921, 0.9390402890846898], 
             UndirectedEdge[32, 36] -> 
             RGBColor[
              0.5447988170396929, 0.6403322542467026, 0.9577062707377697], 
             UndirectedEdge[29, 45] -> 
             RGBColor[
              0.5227443189636096, 0.6232104691349493, 0.9556311601771206], 
             UndirectedEdge[7, 47] -> 
             RGBColor[
              0.2238459927417281, 0.35260670940019034`, 0.9360590701849467], 
             UndirectedEdge[31, 40] -> 
             RGBColor[
              0.22640402732546938`, 0.3552953659364626, 0.9362047464702178], 
             UndirectedEdge[1, 20] -> 
             RGBColor[
              0.5933697666253612, 0.5120953416432061, 0.5852429180533296], 
             UndirectedEdge[8, 37] -> 
             RGBColor[
              0.24662122445907303`, 0.3765449219682142, 0.9373560859383135], 
             UndirectedEdge[4, 9] -> 
             RGBColor[
              0.2433953517637293, 0.3731543252332658, 0.9371723772605647], 
             UndirectedEdge[11, 12] -> 
             RGBColor[
              0.27326058786430485`, 0.4010051085460724, 0.9390027557343369], 
             UndirectedEdge[13, 22] -> 
             RGBColor[
              0.2243535691343984, 0.35314020437108895`, 0.9360879759096173], 
             UndirectedEdge[6, 39] -> 
             RGBColor[
              0.19106405764118703`, 0.3181508171147882, 0.9341921874774979], 
             UndirectedEdge[26, 45] -> 
             RGBColor[
              0.3243716286137628, 0.4456341719163459, 0.9422463521971958], 
             UndirectedEdge[24, 27] -> 
             RGBColor[
              0.6767356564996636, 0.7374562909442268, 0.7474147613381785], 
             UndirectedEdge[5, 27] -> 
             RGBColor[
              0.6807103832415828, 0.7408989994725027, 0.7476680274114607], 
             UndirectedEdge[44, 52] -> 
             RGBColor[
              0.26564536266637445`, 0.3954165771835607, 0.9384806346911951], 
             UndirectedEdge[41, 55] -> 
             RGBColor[
              0.8931186856209132, 0.555233476340213, 0.5508576347436065], 
             UndirectedEdge[17, 29] -> 
             RGBColor[
              0.4139348185866457, 0.5214761397967679, 0.9489721243361952], 
             UndirectedEdge[42, 44] -> 
             RGBColor[
              0.2202159369611787, 0.3487912906160031, 0.9358523438784307], 
             UndirectedEdge[42, 51] -> 
             RGBColor[
              0.2063388657394035, 0.3342056089047838, 0.9350620652016377], 
             UndirectedEdge[8, 34] -> 
             RGBColor[
              0.5684622761923066, 0.40757532161645815`, 0.5683232331263093], 
             UndirectedEdge[3, 29] -> 
             RGBColor[
              0.4212193977467146, 0.5291326943629953, 0.949386970342792], 
             UndirectedEdge[29, 34] -> 
             RGBColor[
              0.7258844761954466, 0.5421100570696229, 0.5793759712618107], 
             UndirectedEdge[2, 17] -> 
             RGBColor[
              0.2325930690269631, 0.3618004411726409, 0.9365572032392511], 
             UndirectedEdge[17, 45] -> 
             RGBColor[
              0.336555439822639, 0.45844012999512285`, 0.9429402022212079], 
             UndirectedEdge[41, 53] -> 
             RGBColor[
              0.7297828906981699, 0.4272854479410791, 0.5645985828702248], 
             UndirectedEdge[42, 49] -> 
             RGBColor[
              0.2217973176330158, 0.35045342196742957`, 0.9359424011682488], 
             UndirectedEdge[35, 55] -> 
             RGBColor[
              0.6119638705475696, 0.6808506736485609, 0.9376655239482897], 
             UndirectedEdge[1, 44] -> 
             RGBColor[
              0.2533389968333165, 0.3836057266649132, 0.9377386531369731], 
             UndirectedEdge[42, 46] -> 
             RGBColor[
              0.6125544946212473, 0.6754873969165813, 0.8203598738195275], 
             UndirectedEdge[26, 32] -> 
             RGBColor[
              0.31549090833556453`, 0.43794213836935025`, 0.9416804805539816],
              UndirectedEdge[2, 19] -> 
             RGBColor[
              0.21158281486909852`, 0.33971733192567155`, 0.9353607003468464],
              UndirectedEdge[5, 26] -> 
             RGBColor[
              0.2855724219867679, 0.4120282492408699, 0.9397741010597149], 
             UndirectedEdge[49, 52] -> 
             RGBColor[
              0.2672267433382115, 0.39707870853498717`, 0.9385706919810133], 
             UndirectedEdge[6, 26] -> 
             RGBColor[
              0.1962226411088322, 0.32357281541236593`, 0.93448596117454], 
             UndirectedEdge[5, 32] -> 
             RGBColor[
              0.39768501329440964`, 0.5188765031108324, 0.9465611152814384], 
             UndirectedEdge[4, 33] -> 
             RGBColor[
              0.2481725467121355, 0.3781754600156947, 0.9374444314456498], 
             UndirectedEdge[2, 25] -> 
             RGBColor[
              0.21728484222716454`, 0.3457105242084144, 0.9356854223694947], 
             UndirectedEdge[16, 43] -> 
             RGBColor[
              0.33170005091656096`, 0.4489260629737498, 0.9430251790437596]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> Medium, 
           VertexSize -> {1.2}, VertexStyle -> {
             EdgeForm[None], 7 -> 
             RGBColor[
              0.2649035695052669, 0.3957608257793902, 0.9383972384423885], 4 -> 
             RGBColor[
              0.30285805657464415`, 0.43565339814277604`, 0.9405586903323577],
              44 -> RGBColor[
              0.21038856326861913`, 0.33846209777364283`, 0.9352926894849359],
              1 -> RGBColor[
              0.2962894303980139, 0.4287493555561836, 0.9401846167890102], 36 -> 
             RGBColor[
              0.6619941344361796, 0.7358741162540924, 0.9669450466998346], 17 -> 
             RGBColor[
              0.22774593944567517`, 0.35670580065694146`, 0.9362811663802824],
              33 -> RGBColor[
              0.1934870368496269, 0.32069752188861333`, 0.934330172558942], 
             15 -> RGBColor[0.178927, 0.305394, 0.933501], 20 -> 
             RGBColor[
              0.8904501028527086, 0.5954413277302286, 0.23030121931764908`], 
             24 -> RGBColor[
              0.3598170734617742, 0.4860771969258005, 0.9441482036406073], 31 -> 
             RGBColor[
              0.18611365665045856`, 0.31294763179998125`, 0.9339102694645379],
              19 -> RGBColor[
              0.185725431129946, 0.31253958216300287`, 0.9338881605954729], 
             18 -> RGBColor[
              0.18325256543594462`, 0.30994044352986677`, 0.9337473345524765],
              5 -> RGBColor[
              0.367766526945613, 0.4929626139823521, 0.9446547357871717], 46 -> 
             RGBColor[
              0.9950656785887564, 0.9918543103747994, 0.7043077493671296], 16 -> 
             RGBColor[
              0.4840466681743011, 0.5920099171346234, 0.9525250733215014], 23 -> 
             RGBColor[
              0.1806204057307783, 0.30717387679117264`, 0.9335974369511986], 
             50 -> RGBColor[
              0.1833136494954916, 0.31000464674940365`, 0.9337508131993019], 
             29 -> RGBColor[
              0.6001236977276163, 0.6862464789365943, 0.961663082292108], 52 -> 
             RGBColor[
              0.32090216206412975`, 0.4523710565934786, 0.9416685798974543], 
             51 -> RGBColor[
              0.18263442082506873`, 0.3092907343512042, 0.9337121321313501], 
             3 -> RGBColor[
              0.2423150977658129, 0.3720189097893963, 0.937110858393476], 32 -> 
             RGBColor[
              0.42760349964320626`, 0.5447903922393128, 0.9484674947757049], 
             48 -> RGBColor[
              0.2215733137162275, 0.35021797964821644`, 0.9359296444765718], 
             42 -> RGBColor[
              0.23004331065373826`, 0.3591204834583634, 0.9364119982719254], 
             12 -> 
             RGBColor[
              0.19949273303437795`, 0.32700988936191777`, 0.9346721880720322],
              39 -> RGBColor[
              0.19306115009263247`, 0.32024988790423214`, 0.9343059189381742],
              25 -> RGBColor[
              0.19712948584607803`, 0.32452596672848855`, 0.9345376046407695],
              28 -> RGBColor[
              0.18315185328137537`, 0.30983458866989505`, 0.933741599144264], 
             35 -> RGBColor[
              0.2550093698533128, 0.3853613946166957, 0.9378337784093664], 43 -> 
             RGBColor[
              0.17935343365882084`, 0.30584220881287627`, 0.9335252847660178],
              40 -> RGBColor[
              0.26669439800048017`, 0.397643100072944, 0.9384992234758976], 
             34 -> RGBColor[
              0.8516452546632768, 0.3979736352026516, 0.1970888602315135], 10 -> 
             RGBColor[
              0.18552130993719032`, 0.3123250378473856, 0.9338765361955157], 
             38 -> RGBColor[
              0.19389898153589238`, 0.32113050187268, 0.9343536321994073], 26 -> 
             RGBColor[
              0.20337831702792278`, 0.33109388449938765`, 0.9348934663322582],
              6 -> RGBColor[
              0.1890669651897416, 0.3160517463253442, 0.9340784560168216], 55 -> 
             RGBColor[
              0.9689183712418266, 0.9763399526804261, 0.937497269487213], 2 -> 
             RGBColor[
              0.23744019860825105`, 0.36689508168834023`, 0.9368332400982199],
              27 -> RGBColor[
              0.9936542395375528, 0.9888353849626533, 0.5506813190357497], 21 -> 
             RGBColor[
              0.19327634183458642`, 0.3204760680689702, 0.9343181737895309], 
             54 -> RGBColor[
              0.2003319232845311, 0.3278919315225637, 0.9347199787153078], 53 -> 
             RGBColor[
              0.6422467813963398, 0.7204438958821582, 0.9649791657404495], 30 -> 
             RGBColor[
              0.19503571892181717`, 0.32232528493859997`, 0.9344183677118835],
              13 -> RGBColor[
              0.19886482165566244`, 0.32634991469100694`, 0.9346364294479261],
              49 -> RGBColor[
              0.21355132461229331`, 0.34178636047649574`, 0.9354728040645721],
              45 -> RGBColor[
              0.4453649401996028, 0.5601744593333042, 0.9495992380621333], 11 -> 
             RGBColor[
              0.3470284426942317, 0.47500032773022705`, 0.9433333233966416], 
             14 -> RGBColor[
              0.18067039234258872`, 0.3072264158895196, 0.9336002836147926], 
             22 -> 
             RGBColor[
              0.24984231661313439`, 0.3799304940511709, 0.9375395223713086], 
             47 -> RGBColor[
              0.1827884159781893, 0.30945259302099054`, 0.9337209019275049], 
             8 -> RGBColor[
              0.2852792977213366, 0.4171770080302647, 0.939557606021105], 9 -> 
             RGBColor[
              0.18393264695281447`, 0.31065525232375557`, 0.9337860641887717],
              37 -> RGBColor[
              0.2079631511968095, 0.33591283590616366`, 0.935154565855522], 
             41 -> RGBColor[0.817319, 0.134127, 0.164218]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJwBgQN+/CFib1JlAgAAADcAAAACAAAAeSi3BS2t9D+2rKN2yC73P3Kc4t1b
QBNA4IUsgcm++j8n7m4qbMoMQEGXfczizQ1AMWor8aj4CkDIejfq/qD4P97I
uNIt2BBAZ6nqmEDiAkCVtimYON4UQGJ70fJyhwBAYWbWkf838z/a0/Ra4Iji
P6s3kQuPMfo//LyQ7kgsCUC9FJDTeWINQBAjaak37bE/+AE43DYz4z8AAAAA
AAAAAKVYPaa5ChFAzFSaihwGAUCM4ZDgtNITQFy+OVhbSv4/QPnhEAvzD0B8
+SClQ1jeP2aCPXQz6RNAcP/wLdmFvD/mlV/u5PMPQNIMWnYhaBFALlm6aOHC
/j+s2n2xJrMJQIZ5mqjffRJALk/GcSIsAkC8wolywz/hP05o423VoAZAxkRE
lgOwFEDQ8LR02IcCQKNfvDzk8wJAPjc7sDYlAUC7uNp9g6DwP/44FepDZAtA
rJeg14Y9DkCe+A3/eyfnP4bWJT0Yauk/MgRpIYWjBkDG6k9rMTX6P4zg4XJ3
cABAu+v6LgFTE0Aos4cOSW7kP94kOMoXSxNAbXcwkq8lAUBjTf4ZIvQEQHD+
AqRAbAFAAAAAAAAAAAB6AuB13zYGQK0izwcj7AtAtdXKVh1TBkBkEHBkfNfo
P3mDxW8PVwtAXthZVvnUEEC1HMq0+D8OQHCyYBsOSg9Ax5QknQMn+T8yFRHM
LpoKQFAUGB7U/to/YmSRyLVhB0DM76C61TcEQM56OudpQwtA4P0UEBrQ8j/w
e2UMLfMNQHNbyo84wwBAf0NMLun08D9mQ5e162YNQOpgz4PlABNA/d2HMCn1
BEB5Qe3qupIUQDkbTay7C/Y/kBED1dr8C0ApBYQPBF8JQMadvgF5IQRA+kK+
Zb5N9z/yADs9+g7wP1iqwMnwXfY/QBrzjktY4z9zgUcUYXoOQKiHKtF4Luo/
BMH3fCzn5T9uny0rIgwQQF4r0HfAJQdAMO2be2bRAECfqI6pQdH4P4hRB2mk
H9E/EAsmBrarzT8wOnEvXNUNQAbADTXoFghAG87Zx9iY8j/fZ7TZQjf9PxDt
XyIUF8s/VDhLTOC7/j84ZHC6LIDTP0aiES8Wf+M/Hp5niFFg9z8axbAh/yfy
P15XAhJ2/Po///DlrdVoBEDjmjW24XEPQEw8TNer8w5A5TB+XIl9B0AAUxCP
UEL6P+NGiJk=
         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 7}], {
             RGBColor[
             0.2805964999516404, 0.41225509066778687`, 0.9392909276156993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 10}], {
             RGBColor[
             0.2409053701676021, 0.3705371967017846, 0.937030576492263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 18}], {
             RGBColor[
             0.23977099791697926`, 0.3693448995430252, 0.9369659756707434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 20}], {
             RGBColor[
             0.5933697666253612, 0.5120953416432061, 0.5852429180533296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 23}], {
             RGBColor[
             0.23845491806439612`, 0.3679616161736781, 0.9368910268701044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 41}], {
             RGBColor[
             0.5568042151990069, 0.28143817777809177`, 0.5522013083945051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 44}], {
             RGBColor[
             0.2533389968333165, 0.3836057266649132, 0.9377386531369731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 46}], {
             RGBColor[
             0.6456775544933852, 0.7103018329654915, 0.8222461830780698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 47}], {
             RGBColor[
             0.2395389231881016, 0.36910097428858707`, 0.9369527593582576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 53}], {
             RGBColor[
             0.4692681058971769, 0.5745966257191709, 0.9525818912647299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 55}], {
             RGBColor[
             0.6326039008199202, 0.7025446541183049, 0.9388409431381116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 5}], {
             RGBColor[
             0.302603362776932, 0.42992884783534613`, 0.9407439879426958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 6}], {
             RGBColor[
             0.21325358189899632`, 0.3414734140068422, 0.9354558480575208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 11}], {
             RGBColor[
             0.2922343206512414, 0.42094770470928367`, 0.9400832817474307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 12}], {
             RGBColor[
             0.21846646582131451`, 0.34695248552512903`, 0.9357527140851261]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 17}], {
             RGBColor[
             0.2325930690269631, 0.3618004411726409, 0.9365572032392511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 19}], {
             RGBColor[
             0.21158281486909852`, 0.33971733192567155`, 0.9353607003468464]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 25}], {
             RGBColor[
             0.21728484222716454`, 0.3457105242084144, 0.9356854223694947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 26}], {
             RGBColor[
             0.2204092578180869, 0.34899448309386394`, 0.9358633532152391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 32}], {
             RGBColor[
             0.3325218491257287, 0.4558427369638265, 0.9426503674369624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 36}], {
             RGBColor[
             0.44971716652221533`, 0.5513845989712163, 0.9518891433990273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 38}], {
             RGBColor[
             0.2156695900720717, 0.34401279178051014`, 0.9355934361488136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 39}], {
             RGBColor[
             0.21525067435044176`, 0.3435724847962862, 0.9355695795181971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 15}], {
             RGBColor[
             0.21062104888290645`, 0.33870645489469814`, 0.935305929196738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 29}], {
             RGBColor[
             0.4212193977467146, 0.5291326943629953, 0.949386970342792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 31}], {
             RGBColor[
             0.21421437720813574`, 0.34248327079468877`, 0.9355105639290069]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 34}], {
             RGBColor[
             0.5469801762145448, 0.384996272496024, 0.5670998593124947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 40}], {
             RGBColor[
             0.25450474788314653`, 0.3848310049311702, 0.9378050409346868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 45}], {
             RGBColor[
             0.3438400189827079, 0.4660966845613502, 0.9433550482278046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 48}], {
             RGBColor[
             0.2319442057410202, 0.3611184447188064, 0.9365202514350239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 54}], {
             RGBColor[
             0.221323510525172, 0.34995542065597995`, 0.9359154185543919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 9}], {
             RGBColor[
             0.2433953517637293, 0.3731543252332658, 0.9371723772605647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 13}], {
             RGBColor[
             0.2508614391151533, 0.3810016564168915, 0.9375975598901419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 20}], {
             RGBColor[
             0.5966540797136763, 0.5155473629365024, 0.5854299548250034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 22}], {
             RGBColor[
             0.27635018659388927`, 0.40779194609697345`, 0.9390491063518331]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 33}], {
             RGBColor[
             0.2481725467121355, 0.3781754600156947, 0.9374444314456498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 34}], {
             RGBColor[
             0.5772516556189604, 0.4168135166727138, 0.5688237752819356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 35}], {
             RGBColor[
             0.2789337132139785, 0.4105073963797359, 0.9391962343708621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 40}], {
             RGBColor[
             0.28477622728756213`, 0.41664824910786, 0.9395289569041276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 41}], {
             RGBColor[
             0.560088528287322, 0.284890199071388, 0.5523883451661789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 48}], {
             RGBColor[
             0.2622156851454358, 0.39293568889549624`, 0.9382441674044648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 55}], {
             RGBColor[
             0.6358882139082354, 0.705996675411601, 0.9390279799097854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 6}], {
             RGBColor[
             0.2784167460676773, 0.4045071801538481, 0.9393665959019967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.3573974848199224, 0.48398147085628956`, 0.9439940295919067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 12}], {
             RGBColor[
             0.28362962998999547`, 0.4099862516721349, 0.939663461929602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 17}], {
             RGBColor[
             0.2977562331956441, 0.4248342073196468, 0.940467951083727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 19}], {
             RGBColor[
             0.27674597903777953`, 0.4027510980726775, 0.9392714481913222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 26}], {
             RGBColor[
             0.2855724219867679, 0.4120282492408699, 0.9397741010597149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 27}], {
             RGBColor[
             0.6807103832415828, 0.7408989994725027, 0.7476680274114607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.48394511233661464`, 0.5896045464594732, 0.9531589090396398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 32}], {
             RGBColor[
             0.39768501329440964`, 0.5188765031108324, 0.9465611152814384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 34}], {
             RGBColor[
             0.6097058908044449, 0.44546812459250185`, 0.5708717980093426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 36}], {
             RGBColor[
             0.5148803306908963, 0.6144183651182222, 0.9557998912435032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 38}], {
             RGBColor[
             0.2808327542407527, 0.40704655792751604`, 0.9395041839932895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 45}], {
             RGBColor[
             0.40656573357260795`, 0.5265685366578281, 0.9471269869246526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 11}], {
             RGBColor[
             0.2680477039419866, 0.39552603702778566`, 0.9387058897067315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 12}], {
             RGBColor[
             0.19427984911205975`, 0.321530817843631, 0.9343753220444269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 17}], {
             RGBColor[
             0.20840645231770838`, 0.33637877349114287`, 0.935179811198552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 19}], {
             RGBColor[
             0.1873961981598438, 0.31429566424417354`, 0.9339833083061473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 26}], {
             RGBColor[
             0.1962226411088322, 0.32357281541236593`, 0.93448596117454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 36}], {
             RGBColor[
             0.42553054981296057`, 0.5259629312897183, 0.9505117513583281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 38}], {
             RGBColor[
             0.191482973362817, 0.31859112409901214`, 0.9342160441081144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 39}], {
             RGBColor[
             0.19106405764118703`, 0.3181508171147882, 0.9341921874774979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 10}], {
             RGBColor[
             0.22521243972122862`, 0.35404293181338786`, 0.9361368873189522]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 41}], {
             RGBColor[
             0.5411112847526334, 0.2649439128896951, 0.5513076192211943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 44}], {
             RGBColor[
             0.23764606638694302`, 0.36711146177651655`, 0.9368449639636622]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 46}], {
             RGBColor[
             0.6299846240470117, 0.6938075680770948, 0.8213524939047591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 47}], {
             RGBColor[
             0.2238459927417281, 0.35260670940019034`, 0.9360590701849467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 51}], {
             RGBColor[
             0.2237689951651678, 0.3525257800652972, 0.9360546852868693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 52}], {
             RGBColor[
             0.2929028657846983, 0.42406594118643437`, 0.9400329091699214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 16}], {
             RGBColor[
             0.38466298294781887`, 0.504593462582444, 0.9460413396713032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 20}], {
             RGBColor[
             0.5878647002870225, 0.5063091678802467, 0.584929412669377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.2392778197779615, 0.36882653804961746`, 0.936937889905318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 27}], {
             RGBColor[
             0.6394667686294446, 0.703006196496459, 0.7451194625284274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 30}], {
             RGBColor[
             0.2401575083215769, 0.3697511464844323, 0.9369879868664943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 34}], {
             RGBColor[
             0.5684622761923066, 0.40757532161645815`, 0.5683232331263093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 37}], {
             RGBColor[
             0.24662122445907303`, 0.3765449219682142, 0.9373560859383135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 43}], {
             RGBColor[
             0.2323163656900787, 0.3615096084215705, 0.9365414453935614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 53}], {
             RGBColor[
             0.46376303955883824`, 0.5688104519562114, 0.9522683858807772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 13}], {
             RGBColor[
             0.19139873430423845`, 0.31850258350738125`, 0.934211246818349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 22}], {
             RGBColor[
             0.21688748178297443`, 0.34529287318746327`, 0.9356627932800401]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 33}], {
             RGBColor[
             0.1887098419012207, 0.31567638710618445`, 0.9340581183738569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 35}], {
             RGBColor[
             0.21947100840306363`, 0.34800832347022564`, 0.9358099212990691]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 44}], {
             RGBColor[
             0.19795493660290472`, 0.3253935678105142, 0.9345846128402258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 47}], {
             RGBColor[
             0.1841548629576898, 0.31088881543418806`, 0.9337987190615102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 12}], {
             RGBColor[
             0.27326058786430485`, 0.4010051085460724, 0.9390027557343369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 17}], {
             RGBColor[
             0.2873871910699535, 0.41585306419358425`, 0.939807244888462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 19}], {
             RGBColor[
             0.26637693691208886`, 0.39376995494661493`, 0.9386107419960572]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 26}], {
             RGBColor[
             0.27520337986107724`, 0.4030471061148073, 0.9391133948644499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 27}], {
             RGBColor[
             0.6703413411158923, 0.7319178563464401, 0.7470073212161956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 29}], {
             RGBColor[
             0.473576070210924, 0.5806234033334107, 0.9524982028443747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 32}], {
             RGBColor[
             0.38731597116871896`, 0.50989535998477, 0.9459004090861732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 34}], {
             RGBColor[
             0.5993368486787543, 0.4364869814664393, 0.5702110918140775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 36}], {
             RGBColor[
             0.5045112885652057, 0.6054372219921598, 0.955139185048238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 38}], {
             RGBColor[
             0.27046371211506204`, 0.3980654148014535, 0.9388434777980244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 39}], {
             RGBColor[
             0.2700447963934321, 0.3976251078172296, 0.9388196211674078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 45}], {
             RGBColor[
             0.39619669144691727`, 0.5175873935317656, 0.9464662807293874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 17}], {
             RGBColor[
             0.21361933624002655`, 0.3418578450094296, 0.9354766772261573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 19}], {
             RGBColor[
             0.192609082082162, 0.3197747357624603, 0.9342801743337525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 26}], {
             RGBColor[
             0.20143552503115036`, 0.3290518869306527, 0.9347828272021452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 32}], {
             RGBColor[
             0.3135481163387921, 0.4359001408006153, 0.9415698414238686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 36}], {
             RGBColor[
             0.4307434337352788, 0.5314420028080051, 0.9508086173859334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 38}], {
             RGBColor[
             0.19669585728513517`, 0.3240701956172989, 0.9345129101357197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 39}], {
             RGBColor[
             0.19627694156350523`, 0.32362988863307496`, 0.9344890535051031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 14}], {
             RGBColor[
             0.1897676069991256, 0.31678816529026327`, 0.9341183565313593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 22}], {
             RGBColor[
             0.2243535691343984, 0.35314020437108895`, 0.9360879759096173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 25}], {
             RGBColor[
             0.19799715375087024`, 0.32543794070974774`, 0.9345870170443478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 33}], {
             RGBColor[
             0.19617592925264465`, 0.32352371828981014`, 0.9344833010034341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 35}], {
             RGBColor[
             0.22693709575448762`, 0.3558556546538513, 0.9362351039286463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 55}], {
             RGBColor[
             0.5838915964487446, 0.6513449336857164, 0.9360668494675696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 22}], {
             RGBColor[
             0.21525635447786157`, 0.3435784549703452, 0.9355699029930507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 25}], {
             RGBColor[
             0.1888999390943334, 0.3158761913090041, 0.9340689441277811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 39}], {
             RGBColor[
             0.1868657712176106, 0.31373815189687587`, 0.9339531012764835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 31}], {
             RGBColor[
             0.1825203283252293, 0.3091708158999906, 0.933705634732269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 40}], {
             RGBColor[
             0.2228106990002401, 0.35151855003647203`, 0.9360001117379488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 48}], {
             RGBColor[
             0.20025015685811376`, 0.32780598982410825`, 0.9347153222382859]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 20}], {
             RGBColor[
             0.6872483855135049, 0.593725622432426, 0.5914131463195752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 21}], {
             RGBColor[
             0.33866150500444375`, 0.4562429926017968, 0.9434216235555162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 27}], {
             RGBColor[
             0.738850453855927, 0.7904226510486383, 0.7516031961786256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 29}], {
             RGBColor[
             0.5420851829509588, 0.6391281980356088, 0.9570940778068047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 30}], {
             RGBColor[
             0.3395411935480591, 0.4571676010366117, 0.9434717205166925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 34}], {
             RGBColor[
             0.6678459614187889, 0.4949917761686375, 0.5748069667765074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 37}], {
             RGBColor[
             0.3460049096855553, 0.4639613765203935, 0.9438398195885117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 43}], {
             RGBColor[
             0.33170005091656096`, 0.4489260629737498, 0.9430251790437596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 53}], {
             RGBColor[
             0.5631467247853205, 0.6562269065083908, 0.9587521195309754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 19}], {
             RGBColor[
             0.20673568528781058`, 0.33462269140997214`, 0.9350846634878776]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 26}], {
             RGBColor[
             0.215562128236799, 0.3438998425781645, 0.9355873163562702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 29}], {
             RGBColor[
             0.4139348185866457, 0.5214761397967679, 0.9489721243361952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 32}], {
             RGBColor[
             0.3276747195444407, 0.45074809644812713`, 0.9423743305779937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 36}], {
             RGBColor[
             0.4448700369409274, 0.546289958455517, 0.9516131065400585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 38}], {
             RGBColor[
             0.2108224604907838, 0.33891815126481073`, 0.9353173992898448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 39}], {
             RGBColor[
             0.21040354476915382`, 0.3384778442805868, 0.9352935426592283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 45}], {
             RGBColor[
             0.336555439822639, 0.45844012999512285`, 0.9429402022212079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 21}], {
             RGBColor[
             0.1882644536352655, 0.31520825579941847`, 0.9340327541710036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 23}], {
             RGBColor[
             0.18193648558336145`, 0.3085571601605197, 0.9336723857518375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 30}], {
             RGBColor[
             0.1891441421788809, 0.31613286423423337`, 0.9340828511321799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 37}], {
             RGBColor[
             0.19560785831637706`, 0.3229266397180152, 0.9344509502039993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 53}], {
             RGBColor[
             0.4127496734161422, 0.5151921697060124, 0.9493632501464631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 26}], {
             RGBColor[
             0.19455187407893437`, 0.32181673333119526`, 0.9343908134638655]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 36}], {
             RGBColor[
             0.4238597827830628, 0.5242068492085477, 0.9504166036476538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 38}], {
             RGBColor[
             0.18981220633291918`, 0.3168350420178414, 0.9341208963974401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 39}], {
             RGBColor[
             0.18939329061128923`, 0.3163947350336175, 0.9340970397668236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 27}], {
             RGBColor[
             0.9420521711951307, 0.792138356346441, 0.3904912691766994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 29}], {
             RGBColor[
             0.7452869002901625, 0.6408439033334115, 0.5959821508048786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 34}], {
             RGBColor[
             0.8710476787579927, 0.4967074814664401, 0.2136950397745813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 35}], {
             RGBColor[
             0.5727297363530107, 0.49040136117346217`, 0.5840674988635077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 41}], {
             RGBColor[
             0.8538845514263543, 0.3647841638651143, 0.19725960965882455`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 46}], {
             RGBColor[
             0.9427578907207326, 0.793647819052514, 0.46730448434238936`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 53}], {
             RGBColor[
             0.7663484421245242, 0.6579426118061934, 0.5976401925290493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 55}], {
             RGBColor[
             0.9296842370472675, 0.7858906402053274, 0.5838992444024311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 23}], {
             RGBColor[
             0.18694837378268236`, 0.31382497243007146`, 0.9339578053703648]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 30}], {
             RGBColor[
             0.19415603037820178`, 0.3214006765037851, 0.9343682707507072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 37}], {
             RGBColor[
             0.20061974651569797`, 0.3281944519875669, 0.9347363698225264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 43}], {
             RGBColor[
             0.18631488774670363`, 0.31315913844092325`, 0.9339217292777744]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 53}], {
             RGBColor[
             0.41776156161546313`, 0.5204599819755642, 0.9496486697649902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 25}], {
             RGBColor[
             0.2234859012296062, 0.35222823038982976`, 0.9360385635060391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 32}], {
             RGBColor[
             0.3387229081281703, 0.46236044314524183`, 0.9430035085735067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 33}], {
             RGBColor[
             0.22166467673138063`, 0.3503140079698921, 0.9359348474651252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 35}], {
             RGBColor[
             0.2524258432332236, 0.3826459443339333, 0.9376866503903375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 41}], {
             RGBColor[
             0.5335806583065672, 0.2570287470255854, 0.5508787611856543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 55}], {
             RGBColor[
             0.6093803439274805, 0.6781352233657985, 0.9375183959292608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 30}], {
             RGBColor[
             0.18782806232629773`, 0.3147495808648863, 0.9340079023315411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 37}], {
             RGBColor[
             0.19429177846379392`, 0.32154335634866815`, 0.9343760014033603]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 53}], {
             RGBColor[
             0.4114335935635591, 0.5138088863366654, 0.949288301345824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.6767356564996636, 0.7374562909442268, 0.7474147613381785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 28}], {
             RGBColor[
             0.2714844633715748, 0.39795589279784777`, 0.9389449013924356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 34}], {
             RGBColor[
             0.6057311640625255, 0.4420254160642261, 0.5706185319360604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 36}], {
             RGBColor[
             0.5109056039489769, 0.6109756565899465, 0.9555466251702209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 42}], {
             RGBColor[
             0.2949301920577562, 0.42259884019208194`, 0.9402801009562664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 46}], {
             RGBColor[
             0.6774413760252653, 0.7389657536503, 0.8242279765038685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 49}], {
             RGBColor[
             0.2866841990370338, 0.4139317787011481, 0.9398105038525897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 50}], {
             RGBColor[
             0.2715653614786329, 0.3980409218376021, 0.9389495084199546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 52}], {
             RGBColor[
             0.340359617762952, 0.46922412675963954`, 0.9429083917690309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 32}], {
             RGBColor[
             0.3123664927446421, 0.4346581794839007, 0.9415025497082372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 39}], {
             RGBColor[
             0.19509531796935525`, 0.32238792731636035`, 0.9344217617894719]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 32}], {
             RGBColor[
             0.31549090833556453`, 0.43794213836935025`, 0.9416804805539816]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 36}], {
             RGBColor[
             0.4326862257320512, 0.53348400037674, 0.9509192565160465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 38}], {
             RGBColor[
             0.19863864928190758`, 0.3261121931860338, 0.9346235492658328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 39}], {
             RGBColor[
             0.1982197335602776, 0.32567188620180987`, 0.9345996926352163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 45}], {
             RGBColor[
             0.3243716286137628, 0.4456341719163459, 0.9422463521971958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 29}], {
             RGBColor[
             0.7968889686325846, 0.8375409319496239, 0.7561722006639289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 32}], {
             RGBColor[
             0.7106288695903795, 0.7668128886009831, 0.7495744069057273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 34}], {
             RGBColor[
             0.9226497471004148, 0.6934045100826525, 0.3738850896336316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 36}], {
             RGBColor[
             0.8278241869868662, 0.8623547506083729, 0.7588131828677922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 41}], {
             RGBColor[
             0.9054866197687764, 0.5614811924813267, 0.35744965951787483`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 42}], {
             RGBColor[
             0.6118487750956456, 0.6739779342105083, 0.7435466586538375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 45}], {
             RGBColor[
             0.7195095898685778, 0.7745049221479787, 0.7501402785489415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 46}], {
             RGBColor[
             0.9943599590631547, 0.9903448476687264, 0.6274945342014396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 49}], {
             RGBColor[
             0.603602782074923, 0.6653108727195746, 0.743077061550161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 52}], {
             RGBColor[
             0.6572782008008413, 0.7206032207780659, 0.746174949466602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 53}], {
             RGBColor[
             0.8179505104669463, 0.8546396404224057, 0.7578302423880996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 43}], {
             RGBColor[
             0.18125264347009812`, 0.30783839874138563`, 0.9336334419551409]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 50}], {
             RGBColor[
             0.18323275138843348`, 0.3099196177096494, 0.9337462061717829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 31}], {
             RGBColor[
             0.3931186771890374, 0.4995970553682878, 0.9477866758783229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 34}], {
             RGBColor[
             0.7258844761954466, 0.5421100570696229, 0.5793759712618107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 36}], {
             RGBColor[
             0.631058916081898, 0.7110602975953433, 0.9643040644959713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 38}], {
             RGBColor[
             0.39701133963175433`, 0.5036884904046371, 0.9480083572457576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 40}], {
             RGBColor[
             0.4334090478640482, 0.5419447895047691, 0.9500811528840027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 45}], {
             RGBColor[
             0.5227443189636096, 0.6232104691349493, 0.9556311601771206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 48}], {
             RGBColor[
             0.4108485057219219, 0.5182322292924053, 0.9487963633843399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 54}], {
             RGBColor[
             0.4002278105060737, 0.507069205229579, 0.9481915305037079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 55}], {
             RGBColor[
             0.7845210344847214, 0.8312932158085102, 0.9495801758896605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 37}], {
             RGBColor[
             0.20149943505931334`, 0.3291190604223818, 0.9347864667837027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 43}], {
             RGBColor[
             0.187194576290319, 0.31408374687573815`, 0.9339718262389507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 53}], {
             RGBColor[
             0.4186412501590785, 0.5213845904103791, 0.9496987667261665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[
             0.22640402732546938`, 0.3552953659364626, 0.9362047464702178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 45}], {
             RGBColor[
             0.3157392984250307, 0.43656104556664277`, 0.9417547537633356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 48}], {
             RGBColor[
             0.20384348518334303`, 0.3315828057240988, 0.9349199569705549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 54}], {
             RGBColor[
             0.1932227899674948, 0.3204197816612725, 0.9343151240899228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 36}], {
             RGBColor[
             0.5447988170396929, 0.6403322542467026, 0.9577062707377697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 39}], {
             RGBColor[
             0.3103323248679194, 0.4325201400717725, 0.9413867068569395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 41}], {
             RGBColor[
             0.6224612498216031, 0.3394586961196564, 0.5563427473878524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 46}], {
             RGBColor[
             0.7113345891159812, 0.7683223513070561, 0.8263876220714172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 55}], {
             RGBColor[
             0.6982609354425164, 0.7605651724598694, 0.9429823821314589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 35}], {
             RGBColor[
             0.22424820335146983`, 0.3530294582526545, 0.9360819754841543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 55}], {
             RGBColor[
             0.5812027040457267, 0.6485187372845197, 0.9359137210230775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 36}], {
             RGBColor[
             0.7568196945497282, 0.566923875728372, 0.5820169534656741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 40}], {
             RGBColor[
             0.5591698263318785, 0.3978083676377978, 0.5677940418537055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 41}], {
             RGBColor[
             0.8344821273316384, 0.2660503176013258, 0.18065343011575674`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 45}], {
             RGBColor[
             0.6485050974314398, 0.4790740472679779, 0.5733440491468234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 46}], {
             RGBColor[
             0.9233554666260166, 0.6949139727887255, 0.45069830479932155`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 48}], {
             RGBColor[
             0.5366092841897521, 0.374095807425434, 0.5665092523540427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 53}], {
             RGBColor[
             0.7469460180298083, 0.559208765542405, 0.5810340129859815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 55}], {
             RGBColor[
             0.9102818129525516, 0.6871567939415388, 0.5672930648593633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 48}], {
             RGBColor[
             0.23829134178477013`, 0.3677896871324561, 0.9368817114429691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 55}], {
             RGBColor[
             0.6119638705475696, 0.6808506736485609, 0.9376655239482897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 38}], {
             RGBColor[
             0.427946557986036, 0.5285023090633862, 0.9506493394496209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 41}], {
             RGBColor[
             0.7396565672180898, 0.4350005581270462, 0.5655815233499173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 45}], {
             RGBColor[
             0.5536795373178912, 0.6480242877936984, 0.9582721423809839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 46}], {
             RGBColor[
             0.828529906512468, 0.8638642133144459, 0.8356263980334822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 43}], {
             RGBColor[
             0.19365829242781518`, 0.32087752235951994`, 0.9343399253107699]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 53}], {
             RGBColor[
             0.4251049662965747, 0.5281783658941609, 0.9500668657979858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 45}], {
             RGBColor[
             0.3196319608677476, 0.4406524806029921, 0.9419764351307702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 45}], {
             RGBColor[
             0.3560296691000415, 0.4789087797031241, 0.9440492307690155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 48}], {
             RGBColor[
             0.24413385585835384`, 0.3739305398605802, 0.9372144339762347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 54}], {
             RGBColor[
             0.23351316064250563`, 0.36276751579775385`, 0.9366096010956027]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 55}], {
             RGBColor[
             0.6178063846211534, 0.686991526376685, 0.9379982464815553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 46}], {
             RGBColor[
             0.9061923392943783, 0.5629906551873998, 0.43426287468356484`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 52}], {
             RGBColor[
             0.5691105810320649, 0.29324902829673927`, 0.5529432899487272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 53}], {
             RGBColor[
             0.7297828906981699, 0.4272854479410791, 0.5645985828702248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 55}], {
             RGBColor[
             0.8931186856209132, 0.555233476340213, 0.5508576347436065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 44}], {
             RGBColor[
             0.2202159369611787, 0.3487912906160031, 0.9358523438784307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 46}], {
             RGBColor[
             0.6125544946212473, 0.6754873969165813, 0.8203598738195275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 49}], {
             RGBColor[
             0.2217973176330158, 0.35045342196742957`, 0.9359424011682488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 50}], {
             RGBColor[
             0.20667848007461492`, 0.3345625651038835, 0.9350814057356136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 51}], {
             RGBColor[
             0.2063388657394035, 0.3342056089047838, 0.9350620652016377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 52}], {
             RGBColor[
             0.275472736358934, 0.405745770025921, 0.9390402890846898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 46}], {
             RGBColor[
             0.6027271209286877, 0.6651582040742212, 0.8198002194260328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 47}], {
             RGBColor[
             0.1965884896234042, 0.3239573453973167, 0.9345067957062204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 51}], {
             RGBColor[
             0.19651149204684393`, 0.3238764160624235, 0.934502410808143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 52}], {
             RGBColor[
             0.26564536266637445`, 0.3954165771835607, 0.9384806346911951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 48}], {
             RGBColor[
             0.33346912695791514`, 0.45519621949076033`, 0.9427644412693525]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 54}], {
             RGBColor[
             0.32284843174206695`, 0.44403319542793396`, 0.9421596083887205]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 49}], {
             RGBColor[
             0.6043085016005248, 0.6668203354256476, 0.8198902767158509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 52}], {
             RGBColor[
             0.657983920326443, 0.722112683484139, 0.822988164632292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 53}], {
             RGBColor[
             0.8186562299925482, 0.8561491031284788, 0.8346434575537895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 55}], {
             RGBColor[
             0.9819920249152915, 0.9840971315276128, 0.8209025094271714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 51}], {
             RGBColor[
             0.18271141840162902`, 0.30937166368609736`, 0.9337165170294275]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 54}], {
             RGBColor[
             0.21095261850037927`, 0.33905495558539006`, 0.9353248115959398]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 50}], {
             RGBColor[
             0.19843248705389244`, 0.3258955036129497, 0.934611808631937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 52}], {
             RGBColor[
             0.2672267433382115, 0.39707870853498717`, 0.9385706919810133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 52}], {
             RGBColor[
             0.2517682914445992, 0.3808308954723414, 0.9376903560144022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 55}], {
             RGBColor[
             0.8055825763190831, 0.8483919242812921, 0.9512382176138312]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.14260380665845326`], {
             RGBColor[
             0.2962894303980139, 0.4287493555561836, 0.9401846167890102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.14260380665845326`], {
             RGBColor[
             0.23744019860825105`, 0.36689508168834023`, 0.9368332400982199]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.14260380665845326`], {
             RGBColor[
             0.2423150977658129, 0.3720189097893963, 0.937110858393476]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.14260380665845326`], {
             RGBColor[
             0.30285805657464415`, 0.43565339814277604`, 0.9405586903323577]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.14260380665845326`], {
             RGBColor[
             0.367766526945613, 0.4929626139823521, 0.9446547357871717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.14260380665845326`], {
             RGBColor[
             0.1890669651897416, 0.3160517463253442, 0.9340784560168216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.14260380665845326`], {
             RGBColor[
             0.2649035695052669, 0.3957608257793902, 0.9383972384423885]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.14260380665845326`], {
             RGBColor[
             0.2852792977213366, 0.4171770080302647, 0.939557606021105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.14260380665845326`], {
             RGBColor[
             0.18393264695281447`, 0.31065525232375557`, 0.9337860641887717]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.14260380665845326`], {
             RGBColor[
             0.18552130993719032`, 0.3123250378473856, 0.9338765361955157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.14260380665845326`], {
             RGBColor[
             0.3470284426942317, 0.47500032773022705`, 0.9433333233966416]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.14260380665845326`], {
             RGBColor[
             0.19949273303437795`, 0.32700988936191777`, 0.9346721880720322]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.14260380665845326`], {
             RGBColor[
             0.19886482165566244`, 0.32634991469100694`, 0.9346364294479261]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.14260380665845326`], {
             RGBColor[
             0.18067039234258872`, 0.3072264158895196, 0.9336002836147926]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.14260380665845326`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.14260380665845326`], {
             RGBColor[
             0.4840466681743011, 0.5920099171346234, 0.9525250733215014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.14260380665845326`], {
             RGBColor[
             0.22774593944567517`, 0.35670580065694146`, 0.9362811663802824]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.14260380665845326`], {
             RGBColor[
             0.18325256543594462`, 0.30994044352986677`, 0.9337473345524765]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.14260380665845326`], {
             RGBColor[
             0.185725431129946, 0.31253958216300287`, 0.9338881605954729]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.14260380665845326`], {
             RGBColor[
             0.8904501028527086, 0.5954413277302286, 0.23030121931764908`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.14260380665845326`], {
             RGBColor[
             0.19327634183458642`, 0.3204760680689702, 0.9343181737895309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.14260380665845326`], {
             RGBColor[
             0.24984231661313439`, 0.3799304940511709, 0.9375395223713086]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.14260380665845326`], {
             RGBColor[
             0.1806204057307783, 0.30717387679117264`, 0.9335974369511986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.14260380665845326`], {
             RGBColor[
             0.3598170734617742, 0.4860771969258005, 0.9441482036406073]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.14260380665845326`], {
             RGBColor[
             0.19712948584607803`, 0.32452596672848855`, 0.9345376046407695]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.14260380665845326`], {
             RGBColor[
             0.20337831702792278`, 0.33109388449938765`, 0.9348934663322582]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.14260380665845326`], {
             RGBColor[
             0.9936542395375528, 0.9888353849626533, 0.5506813190357497]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.14260380665845326`], {
             RGBColor[
             0.18315185328137537`, 0.30983458866989505`, 0.933741599144264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.14260380665845326`], {
             RGBColor[
             0.6001236977276163, 0.6862464789365943, 0.961663082292108]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.14260380665845326`], {
             RGBColor[
             0.19503571892181717`, 0.32232528493859997`, 0.9344183677118835]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.14260380665845326`], {
             RGBColor[
             0.18611365665045856`, 0.31294763179998125`, 0.9339102694645379]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.14260380665845326`], {
             RGBColor[
             0.42760349964320626`, 0.5447903922393128, 0.9484674947757049]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.14260380665845326`], {
             RGBColor[
             0.1934870368496269, 0.32069752188861333`, 0.934330172558942]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.14260380665845326`], {
             RGBColor[
             0.8516452546632768, 0.3979736352026516, 0.1970888602315135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.14260380665845326`], {
             RGBColor[
             0.2550093698533128, 0.3853613946166957, 0.9378337784093664]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.14260380665845326`], {
             RGBColor[
             0.6619941344361796, 0.7358741162540924, 0.9669450466998346]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.14260380665845326`], {
             RGBColor[
             0.2079631511968095, 0.33591283590616366`, 0.935154565855522]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.14260380665845326`], {
             RGBColor[
             0.19389898153589238`, 0.32113050187268, 0.9343536321994073]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.14260380665845326`], {
             RGBColor[
             0.19306115009263247`, 0.32024988790423214`, 0.9343059189381742]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.14260380665845326`], {
             RGBColor[
             0.26669439800048017`, 0.397643100072944, 0.9384992234758976]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.14260380665845326`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.14260380665845326`], {
             RGBColor[
             0.23004331065373826`, 0.3591204834583634, 0.9364119982719254]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.14260380665845326`], {
             RGBColor[
             0.17935343365882084`, 0.30584220881287627`, 0.9335252847660178]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.14260380665845326`], {
             RGBColor[
             0.21038856326861913`, 0.33846209777364283`, 0.9352926894849359]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.14260380665845326`], {
             RGBColor[
             0.4453649401996028, 0.5601744593333042, 0.9495992380621333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.14260380665845326`], {
             RGBColor[
             0.9950656785887564, 0.9918543103747994, 0.7043077493671296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.14260380665845326`], {
             RGBColor[
             0.1827884159781893, 0.30945259302099054`, 0.9337209019275049]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.14260380665845326`], {
             RGBColor[
             0.2215733137162275, 0.35021797964821644`, 0.9359296444765718]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.14260380665845326`], {
             RGBColor[
             0.21355132461229331`, 0.34178636047649574`, 0.9354728040645721]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.14260380665845326`], {
             RGBColor[
             0.1833136494954916, 0.31000464674940365`, 0.9337508131993019]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.14260380665845326`], {
             RGBColor[
             0.18263442082506873`, 0.3092907343512042, 0.9337121321313501]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.14260380665845326`], {
             RGBColor[
             0.32090216206412975`, 0.4523710565934786, 0.9416685798974543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.14260380665845326`], {
             RGBColor[
             0.6422467813963398, 0.7204438958821582, 0.9649791657404495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.14260380665845326`], {
             RGBColor[
             0.2003319232845311, 0.3278919315225637, 0.9347199787153078]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.14260380665845326`], {
             RGBColor[
             0.9689183712418266, 0.9763399526804261, 0.937497269487213]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> Medium, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{{3.834891358332164*^9, 3.8348913811449647`*^9}, 
   3.834891493295659*^9, {3.834891827712037*^9, 3.834891833280736*^9}, {
   3.834891941059944*^9, 3.8348919515515313`*^9}, {3.83489205077415*^9, 
   3.8348921177260017`*^9}, 3.834892564626336*^9, 3.83489433716844*^9, 
   3.834895351371936*^9, 3.834895385498823*^9, 3.834895685114671*^9},
 CellLabel->
  "Out[261]=",ExpressionUUID->"cbb0a006-bf6a-4467-98f4-6de31b39edd7"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1st imported file", "Subsection",
 CellChangeTimes->{{3.834947473073307*^9, 3.8349474798089457`*^9}, {
   3.8349497159535103`*^9, 3.8349497173354855`*^9}, {3.834956622993673*^9, 
   3.834956623710862*^9}, {3.834959567930995*^9, 3.834959570918262*^9}, 
   3.835201581170309*^9},
 Background->RGBColor[
  1, 1, 0],ExpressionUUID->"35910b46-0e33-4a62-8978-124eb0f8f870"],

Cell["Dividing stuff", "Text",
 CellChangeTimes->{{3.83494752022309*^9, 
  3.834947523245259*^9}},ExpressionUUID->"9a2a03f0-1a0f-42a3-9aee-\
220676d17efa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data1", "=", 
   RowBox[{"StringSplit", "[", 
    RowBox[{
     RowBox[{"Import", "[", "\"\<ariadnaComputation.txt\>\"", "]"}], ",", 
     "\"\<]\n{\>\""}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8349434033501863`*^9, 3.834943479535334*^9}, {
   3.834943567297134*^9, 3.8349435736474867`*^9}, {3.8349441109152327`*^9, 
   3.8349441401892223`*^9}, 3.834944204627252*^9},
 CellLabel->"In[91]:=",ExpressionUUID->"1062c643-a12b-4e1a-a457-7285e5d16a8b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"graphi1", "=", 
   RowBox[{"ToExpression", "@", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"data1", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
       "<>", "\"\<]\>\""}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834944474381714*^9, 3.83494454689666*^9}, 
   3.8349475108233376`*^9},
 CellLabel->"In[92]:=",ExpressionUUID->"ff0736ee-c140-4c92-bb2e-208e38cf404f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"otheri1", "=", 
   RowBox[{"ToExpression", "@", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "<>", "\"\<}}\>\""}], "&"}], ",", 
      RowBox[{"StringSplit", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\"\<{\>\"", "<>", 
          RowBox[{
          "data1", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
         ")"}], ",", "\"\<}}\>\""}], "]"}]}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834944518155362*^9, 3.8349445533517303`*^9}, 
   3.8349446259294133`*^9, {3.8349447635371876`*^9, 3.8349447780382657`*^9}, {
   3.834944820013957*^9, 3.8349448816359477`*^9}, {3.834944915595456*^9, 
   3.834944918286141*^9}, {3.8349449615053425`*^9, 3.834944967406804*^9}, {
   3.834945029266304*^9, 3.834945031628281*^9}, {3.834945108799203*^9, 
   3.8349451822852197`*^9}, 3.834945584171259*^9},
 CellLabel->"In[93]:=",ExpressionUUID->"f1dbdc51-73ea-4bd3-9da4-e7ad3896591e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "CMDi3100", "}"}], ",", 
     RowBox[{"{", "AMDi3100", "}"}], ",", 
     RowBox[{"{", "mMDi3100", "}"}], ",", 
     RowBox[{"{", "CMDi6100", "}"}], ",", 
     RowBox[{"{", "AMDi6100", "}"}], ",", 
     RowBox[{"{", "mMDi6100", "}"}]}], "}"}], "=", "otheri1"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.834945694541313*^9, 3.834945753140644*^9}, {
  3.8349459487260857`*^9, 3.8349459670133495`*^9}, {3.8349471029719105`*^9, 
  3.8349471182020655`*^9}},
 CellLabel->"In[94]:=",ExpressionUUID->"213a6478-951d-43c0-9194-978822bf61ba"],

Cell["\[OpenCurlyDoubleQuote]Cleaning\[CloseCurlyDoubleQuote] the graph:", \
"Text",
 CellChangeTimes->{{3.8349477786156034`*^9, 
  3.8349478283202667`*^9}},ExpressionUUID->"77e03dd1-be11-4a97-beca-\
9999486e630e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"graphin1", "=", 
   RowBox[{"IndexGraph", "@", "graphi1"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834946654863307*^9, 3.834946693639777*^9}},
 CellLabel->"In[95]:=",ExpressionUUID->"8e952ef1-570e-4c57-aed1-7c63cc965bf1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pointsi1", "=", 
   RowBox[{"VertexList", "@", "graphin1"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834784420352569*^9, 3.8347844264642625`*^9}, {
  3.8348756828269844`*^9, 3.8348756865131674`*^9}, {3.834878831782991*^9, 
  3.8348788488376627`*^9}, {3.8349467020325813`*^9, 3.834946739879963*^9}},
 CellLabel->"In[96]:=",ExpressionUUID->"40ea1032-7945-4fb8-8b9e-466c8cac1399"],

Cell[BoxData[
 RowBox[{
  RowBox[{"coordpointsi1", "=", 
   RowBox[{"VertexList", "@", "graphi1"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834879134322084*^9, 3.834879146224797*^9}, {
  3.834946724882841*^9, 3.834946736706849*^9}},
 CellLabel->"In[97]:=",ExpressionUUID->"3d251297-19f2-4012-a4f1-e1dc00472d12"],

Cell["Kretchmann \[OpenCurlyDoubleQuote]real\[CloseCurlyDoubleQuote] \
values:", "Text",
 CellChangeTimes->{
  3.8347933561184683`*^9, {3.8347935444076195`*^9, 
   3.834793546974228*^9}},ExpressionUUID->"3d98004a-ebf4-4041-bc7d-\
f3b87de611e6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rvali1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Sinh", "[", "\[Nu]", "]"}], "\[Equal]", "#"}], ",", 
       RowBox[{"{", "\[Nu]", "}"}]}], "]"}], "&"}], "/@", 
    RowBox[{"coordpointsi1", "\[LeftDoubleBracket]", 
     RowBox[{";;", ",", "3"}], "\[RightDoubleBracket]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834105426841242*^9, 3.8341054487325706`*^9}, {
   3.8341407674337025`*^9, 3.834140799285215*^9}, {3.8341408938375945`*^9, 
   3.834140946496229*^9}, {3.8341410168099756`*^9, 3.8341410671886864`*^9}, {
   3.8341411610986195`*^9, 3.834141210381962*^9}, {3.834141332672348*^9, 
   3.834141336755044*^9}, {3.834141461053176*^9, 3.834141468978607*^9}, {
   3.834141967115094*^9, 3.8341420256686225`*^9}, {3.8341640069512*^9, 
   3.834164012603241*^9}, {3.834164792400744*^9, 3.8341647947633886`*^9}, {
   3.83466546628111*^9, 3.834665483801684*^9}, {3.8347933895124626`*^9, 
   3.834793417249506*^9}, 3.8347960586942053`*^9, 3.834879156483405*^9, {
   3.8348862453609915`*^9, 3.8348862641404076`*^9}, 3.834886374221485*^9, {
   3.834946768449996*^9, 3.8349467823353415`*^9}, {3.8349468446168528`*^9, 
   3.834946857637892*^9}, 3.8349474594107084`*^9},
 CellLabel->"In[98]:=",ExpressionUUID->"c8b456ee-481e-40d5-b7ec-1e7e1e2c5ca1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"kri1", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"KHyperboloid", "/.", "rvali1"}], ")"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834792366597866*^9, 3.834792376019791*^9}, {
   3.834793346399704*^9, 3.8347933590872536`*^9}, {3.834793445378667*^9, 
   3.8347934527754736`*^9}, {3.834793487784485*^9, 3.834793489659489*^9}, 
   3.8348550102643666`*^9, {3.8348863808528233`*^9, 3.83488645374378*^9}, {
   3.834886485165092*^9, 3.834886521271514*^9}, 3.8348865820814276`*^9, {
   3.83494679091998*^9, 3.8349467979310513`*^9}, {3.8349468742957215`*^9, 
   3.834946904080855*^9}, 3.8349474644429636`*^9},
 CellLabel->"In[99]:=",ExpressionUUID->"dab664d0-01e0-487e-9ece-2aafe111d8bc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraphb", "[", 
     RowBox[{"graphin1", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsi1", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}], 
     "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"CMDi3100", ",", "kri1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, 3.835051653741506*^9},
 CellLabel->
  "In[394]:=",ExpressionUUID->"c6da0dc2-952a-470f-a059-4b6812657503"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100}, {
          Null, CompressedData["
1:eJwVxVmDagoAAOCTRmhBx9Jp1aDdVNSk6LRrVKZFCxnaeL///+3e+/J9769/
zBfw69ev5X/8//3x+5KpJwaZQX0A9jP9er8/ePjtef7C+rl77tGYg07fGTgJ
gmCJAeEgOSSPXJA78ognWMvyO387LxBFHfQVP7VP81Pn++936dq4tq+IzMqy
Jd/lh+wncJzAWXyAO/gLGeVG8mh0Hz1GPoihGIZjBOZgr4SCK4SSV1glvAz/
LH/iq/ZqvlqdkFQql5JTo9Q99QhLuERIrCTJkiJZko8d88fGUTkeX+AW3Wbs
ut23B7btxBftxXyxWC1Omc/656f9+8+fS2KP74l9ff+5H+yV/d4O99ie1OtZ
PR80UAMzSkbDSPfSVtpH+BSf41mel/kRf+cfvJ84E+fMuX7+PA/O+/PZRgq5
Qr5Q4AtKYVS4IOvUOrfm16P1+r5+oDqml/SGrhv6FayiVaxa7VeN6rbqhFVc
ZVVJ7amyqqiqpfqJA34gDuxhcFAO+8PhfLAPTtjETdaUzJ6pmkvTtEwficXy
sUJMiR1jF4SKUVSeKlA8JVMKNaKO1AUIA2mABSSgB6jAEjABC/BjIi4SIiWy
oiiJsqiIqngQTdEvloqNYruoF68AF+ZYjhM5ietxKrfkTM7ifFBABUzABUKo
CkJfGAgHwRac8Kwzmy1nP+gNu+E34ibc9JtxO96c2+31Pntfvv8AMJyGWZiD
eViEJbgHy7AKm7AFP2A/nky2k/PkIrlKnhIBFuABEbCBEIjBIFCCfXAI7MAJ
bgHooi7mVt2GK7i6a7hH1725L7SCVfBKvlLpVIzKseJWbpUXBEMIREEpKAcV
IBbiIRGSoRG0hizoDj0gP4JGsEgxUoo0InrEiFwjbqRVbJVaLb11BTfoprrZ
bAEtrEEarKU1VuM0UZO0niZrqqaZmqX5b+9vnbcZ+PW1+TK+tgATZmAmzTAs
wzES02NURmOWjMlYjB8ZFoeNYXs4nA/14Wp4BWuZWrVWE2r9ml1zwB2+I3bV
XW0n7Pq7wW5n75xdkPmof3x8fpw/7Gg8moy2o/PoIrqKnkKREBoqhkqhRqgV
+grpISN0DbnRZ/yZfM6fi+fqeXqGyAiJkmSRLJENskUOSZ00yCN5JV2IhmmE
pmg6RRdoluZpkZZomVZolR7RGm3Rd/pB+8gkNvk9oSa5SX5SmEzWkwvooV7V
q3mC1/e+vI1neFtv5zme60W7yW672x12591Fd9U9dZ+hbCRLZrPFbCnbyLay
w6yevYLT6rQ27U+nm+l2upt6wDg8ZsbvY248no2XY3P8E2tiTaqZbxaalWaz
05w0j81L89Z8vZXLlXKn/Lc8K3+XX/8C/Ovksg==
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[65, 78] -> 
             RGBColor[
              0.7304328020703003, 0.7873743236426081, 0.9451175467398159], 
             UndirectedEdge[27, 32] -> 
             RGBColor[
              0.9691274689795426, 0.9037370660611412, 0.39557320618311054`], 
             UndirectedEdge[6, 47] -> 
             RGBColor[
              0.9254905844891624, 0.9411228429409848, 0.9037293608316697], 
             UndirectedEdge[33, 63] -> 
             RGBColor[
              0.6945931249761694, 0.7529084916032946, 0.7472670905805976], 
             UndirectedEdge[55, 59] -> 
             RGBColor[
              0.9233260783609099, 0.9394042001471264, 0.9038388416636519], 
             UndirectedEdge[23, 96] -> 
             RGBColor[
              0.9773580535957678, 0.9796156246189538, 0.7473776796416916], 
             UndirectedEdge[2, 69] -> 
             RGBColor[
              0.7346217107042923, 0.7872642411917495, 0.7737825555924269], 
             UndirectedEdge[23, 95] -> 
             RGBColor[
              0.6130125629513787, 0.6831427915105732, 0.9445452558879142], 
             UndirectedEdge[27, 60] -> 
             RGBColor[
              0.8070781218855261, 0.7804224341524815, 0.6211009906880485], 
             UndirectedEdge[31, 63] -> 
             RGBColor[
              0.6193843980462164, 0.681885495982717, 0.7426901883617569], 
             UndirectedEdge[16, 94] -> 
             RGBColor[
              0.6482106091529766, 0.7120154608324591, 0.7275102121182888], 
             UndirectedEdge[25, 99] -> 
             RGBColor[
              0.7726630709694242, 0.8226332792168142, 0.9778948864870312], 
             UndirectedEdge[16, 80] -> 
             RGBColor[
              0.3193406093827931, 0.4504964950206479, 0.9415881929652692], 
             UndirectedEdge[12, 13] -> 
             RGBColor[
              0.82239115968923, 0.8609591492962203, 0.9258441859098856], 
             UndirectedEdge[23, 28] -> 
             RGBColor[
              0.8974215721049099, 0.9203880112466283, 0.9673477667260846], 
             UndirectedEdge[13, 19] -> 
             RGBColor[
              0.6831923953052683, 0.7524343587577742, 0.9690578912342546], 
             UndirectedEdge[52, 68] -> 
             RGBColor[
              0.8843038182053278, 0.9104813171635049, 0.9852710635368477], 
             UndirectedEdge[81, 85] -> 
             RGBColor[
              0.8739575020310063, 0.4190810514861012, 0.39655226676176986`], 
             UndirectedEdge[72, 94] -> 
             RGBColor[
              0.9254428883954429, 0.9386929876972518, 0.7503622089376597], 
             UndirectedEdge[24, 86] -> 
             RGBColor[
              0.407556943092808, 0.5143364118369672, 0.9486486172540981], 
             UndirectedEdge[36, 95] -> 
             RGBColor[
              0.34775235075339883`, 0.471573704155124, 0.9435278736620936], 
             UndirectedEdge[42, 56] -> 
             RGBColor[
              0.9581375995135409, 0.8725218207033227, 0.5607025864762096], 
             UndirectedEdge[45, 85] -> 
             RGBColor[
              0.6714836452855582, 0.2572168693036657, 0.4246194407702545], 
             UndirectedEdge[31, 35] -> 
             RGBColor[
              0.6197256496914357, 0.6826153987460073, 0.7798333239828474], 
             UndirectedEdge[71, 75] -> 
             RGBColor[
              0.9715819221839017, 0.9766789230003987, 0.8592100843032537], 
             UndirectedEdge[52, 97] -> 
             RGBColor[
              0.9653674052122234, 0.9725508476131046, 0.892420755287109], 
             UndirectedEdge[92, 93] -> 
             RGBColor[
              0.6610814600651864, 0.6805213217992623, 0.618807650299678], 
             UndirectedEdge[55, 99] -> 
             RGBColor[
              0.8386979051292529, 0.8729926955161651, 0.895483329894214], 
             UndirectedEdge[2, 31] -> 
             RGBColor[
              0.36015670638002095`, 0.47989691864615447`, 0.9445491549588532],
              UndirectedEdge[11, 58] -> 
             RGBColor[
              0.6992381964544587, 0.7636616921713781, 0.9717052421872012], 
             UndirectedEdge[22, 99] -> 
             RGBColor[
              0.5812333739738029, 0.6702149514783942, 0.9606514919123779], 
             UndirectedEdge[7, 8] -> 
             RGBColor[
              0.8984795700817574, 0.9197247987621473, 0.9028117582444901], 
             UndirectedEdge[35, 49] -> 
             RGBColor[
              0.9809888861535536, 0.9828247886155828, 0.7810072429027262], 
             UndirectedEdge[39, 98] -> 
             RGBColor[
              0.7868179139076612, 0.8300827015664649, 0.8142187853250639], 
             UndirectedEdge[65, 75] -> 
             RGBColor[
              0.9591023264684103, 0.9690191625607104, 0.954113272854104], 
             UndirectedEdge[50, 55] -> 
             RGBColor[
              0.8253174912444339, 0.8625398144944324, 0.8941496952852521], 
             UndirectedEdge[74, 95] -> 
             RGBColor[
              0.3379595731232288, 0.4630916923711857, 0.9429038865309125], 
             UndirectedEdge[38, 39] -> 
             RGBColor[
              0.6404640978299082, 0.7046429466428203, 0.8040274537817531], 
             UndirectedEdge[44, 94] -> 
             RGBColor[
              0.9746340365513677, 0.9773945408601297, 0.7369514215722104], 
             UndirectedEdge[12, 84] -> 
             RGBColor[
              0.9623078399043976, 0.9711431726403856, 0.936745747722554], 
             UndirectedEdge[3, 59] -> 
             RGBColor[
              0.8898394157225106, 0.9149978123223834, 0.9893548719122789], 
             UndirectedEdge[43, 92] -> 
             RGBColor[
              0.896593784113809, 0.6124219568563198, 0.2374777128016691], 
             UndirectedEdge[1, 92] -> 
             RGBColor[
              0.7458522640887054, 0.7517760077239832, 0.6248086168666267], 
             UndirectedEdge[53, 80] -> 
             RGBColor[
              0.5965728886252595, 0.6771740218854406, 0.9644401897846401], 
             UndirectedEdge[55, 95] -> 
             RGBColor[
              0.6272682711300975, 0.6928705450224478, 0.8799252580658656], 
             UndirectedEdge[35, 59] -> 
             RGBColor[
              0.9256655827342186, 0.9395357946620322, 0.8043096800263305], 
             UndirectedEdge[28, 64] -> 
             RGBColor[
              0.5684878883590084, 0.6531605117952217, 0.9622917548006573], 
             UndirectedEdge[72, 92] -> 
             RGBColor[
              0.9080245311119143, 0.8804418357785987, 0.6397487593803545], 
             UndirectedEdge[83, 92] -> 
             RGBColor[
              0.8897722320572029, 0.8658879479578312, 0.6380078388024963], 
             UndirectedEdge[55, 69] -> 
             RGBColor[
              0.9918511496423983, 0.9898511267766967, 0.7085958862537426], 
             UndirectedEdge[54, 59] -> 
             RGBColor[
              0.5584677896696733, 0.6396735627947245, 0.9621688159456745], 
             UndirectedEdge[38, 98] -> 
             RGBColor[
              0.432545818296652, 0.5435760732496548, 0.9498009147353266], 
             UndirectedEdge[5, 40] -> 
             RGBColor[
              0.3849530976493758, 0.5078487577037911, 0.9457498488749277], 
             UndirectedEdge[11, 86] -> 
             RGBColor[
              0.37215613313893403`, 0.48559643952809795`, 0.9458617358170894],
              UndirectedEdge[15, 46] -> 
             RGBColor[
              0.5141419004567431, 0.6164425824762738, 0.9548942802492435], 
             UndirectedEdge[49, 50] -> 
             RGBColor[
              0.8143327743829618, 0.8552515609512037, 0.9532327580183702], 
             UndirectedEdge[20, 60] -> 
             RGBColor[
              0.7803711069683852, 0.8289291415142886, 0.9785903644110022], 
             UndirectedEdge[30, 46] -> 
             RGBColor[
              0.752404002324623, 0.8057877894366445, 0.9623031674563055], 
             UndirectedEdge[52, 84] -> 
             RGBColor[
              0.9392473955803918, 0.9542113876138918, 0.9877224918521837], 
             UndirectedEdge[80, 100] -> 
             RGBColor[
              0.6063288770444596, 0.4998999639116951, 0.5808729021947368], 
             UndirectedEdge[6, 14] -> 
             RGBColor[
              0.643497381128667, 0.7176888833366606, 0.9674894593717128], 
             UndirectedEdge[30, 64] -> 
             RGBColor[
              0.6274773696468703, 0.6997845160560479, 0.9536128842492972], 
             UndirectedEdge[42, 85] -> 
             RGBColor[
              0.8545292888913528, 0.34142364265190056`, 0.19670853294873786`],
              UndirectedEdge[78, 93] -> 
             RGBColor[
              0.42769725976966055`, 0.5438290005425895, 0.9487615431286736], 
             UndirectedEdge[2, 25] -> 
             RGBColor[
              0.6663698255437822, 0.7370351457596076, 0.9690515677384313], 
             UndirectedEdge[71, 78] -> 
             RGBColor[
              0.7429123977857917, 0.7950340840822965, 0.8502143581889656], 
             UndirectedEdge[21, 49] -> 
             RGBColor[
              0.7490603702895113, 0.8025460527045732, 0.947899029577611], 
             UndirectedEdge[8, 50] -> 
             RGBColor[
              0.825235321772712, 0.8625058353062163, 0.8955114560794608], 
             UndirectedEdge[7, 96] -> 
             RGBColor[
              0.9005414026862489, 0.9191207084372861, 0.7627543374629948], 
             UndirectedEdge[80, 81] -> 
             RGBColor[
              0.6614079265107391, 0.7270372915919903, 0.9019123624310128], 
             UndirectedEdge[14, 72] -> 
             RGBColor[
              0.6416250156420291, 0.7161959099216227, 0.9673108714801169], 
             UndirectedEdge[3, 50] -> 
             RGBColor[
              0.7918308286060346, 0.8381334266696894, 0.9796657255338792], 
             UndirectedEdge[26, 53] -> 
             RGBColor[
              0.630434282555966, 0.7065030593850741, 0.9665978078634497], 
             UndirectedEdge[26, 88] -> 
             RGBColor[
              0.5404504516204373, 0.6359032581279132, 0.9577096660889313], 
             UndirectedEdge[67, 84] -> 
             RGBColor[
              0.7529563835478676, 0.8066616042000012, 0.9737555745725412], 
             UndirectedEdge[68, 73] -> 
             RGBColor[
              0.9112514649006789, 0.9275448930696386, 0.7626078890366028], 
             UndirectedEdge[56, 93] -> 
             RGBColor[
              0.6755018102908137, 0.7392241502687376, 0.9020549054687086], 
             UndirectedEdge[5, 41] -> 
             RGBColor[
              0.712264033530497, 0.7705804306319498, 0.8865596859634558], 
             UndirectedEdge[51, 77] -> 
             RGBColor[
              0.46086504347881, 0.5694032594073464, 0.9517464268744718], 
             UndirectedEdge[79, 88] -> 
             RGBColor[
              0.6335740933510177, 0.7128632193563118, 0.9646654825838514], 
             UndirectedEdge[75, 78] -> 
             RGBColor[
              0.7203857557088272, 0.77988125291675, 0.9621245755404236], 
             UndirectedEdge[25, 87] -> 
             RGBColor[
              0.5718782162704793, 0.6536994666856072, 0.9629430190922901], 
             UndirectedEdge[56, 65] -> 
             RGBColor[
              0.9782373525914534, 0.9827694733687561, 0.8984109090798509], 
             UndirectedEdge[41, 65] -> 
             RGBColor[
              0.9793095662640782, 0.983212861277021, 0.8806415537244215], 
             UndirectedEdge[39, 51] -> 
             RGBColor[
              0.6542951721796102, 0.7187079992709671, 0.804832405615522], 
             UndirectedEdge[92, 94] -> 
             RGBColor[
              0.9759029891852977, 0.9298722084306466, 0.40383451332544995`], 
             UndirectedEdge[43, 67] -> 
             RGBColor[
              0.7661302848511069, 0.541692135095623, 0.45942498289666733`], 
             UndirectedEdge[76, 93] -> 
             RGBColor[
              0.6214703677628918, 0.6979928059453577, 0.9663701340264556], 
             UndirectedEdge[22, 36] -> 
             RGBColor[
              0.4526536471095681, 0.5659068627388111, 0.9502241194213216], 
             UndirectedEdge[10, 52] -> 
             RGBColor[
              0.8259746863334378, 0.8648418368917743, 0.9794765520635618], 
             UndirectedEdge[8, 34] -> 
             RGBColor[
              0.6810250578992585, 0.7435228000567393, 0.8845691660597748], 
             UndirectedEdge[79, 100] -> 
             RGBColor[
              0.7333139127057466, 0.6061889626397273, 0.5899863367684666], 
             UndirectedEdge[15, 83] -> 
             RGBColor[
              0.6481175264890708, 0.7224812579388402, 0.9673106471605732], 
             UndirectedEdge[67, 73] -> 
             RGBColor[
              0.7803327928415383, 0.8240449505499272, 0.7503666168325369], 
             UndirectedEdge[31, 34] -> 
             RGBColor[
              0.3088592740473905, 0.4360591358321514, 0.9411165490788055], 
             UndirectedEdge[35, 99] -> 
             RGBColor[
              0.8410374095025617, 0.8731242900310707, 0.7959541682568925], 
             UndirectedEdge[41, 56] -> 
             RGBColor[
              0.9883975460256482, 0.9894701013592087, 0.8419462187507762], 
             UndirectedEdge[11, 21] -> 
             RGBColor[
              0.5317124169123406, 0.6307071192776738, 0.9562774956675506], 
             UndirectedEdge[65, 79] -> 
             RGBColor[
              0.7793503955404584, 0.8270878297341551, 0.9489685188888359], 
             UndirectedEdge[1, 47] -> 
             RGBColor[
              0.7614459519793157, 0.8109640414713315, 0.888610630426346], 
             UndirectedEdge[9, 95] -> 
             RGBColor[
              0.5799031039496374, 0.6573978143978356, 0.9641175441617835], 
             UndirectedEdge[39, 46] -> 
             RGBColor[
              0.7739223867944494, 0.8196135317190834, 0.8132036021928396], 
             UndirectedEdge[7, 21] -> 
             RGBColor[
              0.6689727280627458, 0.7396116365542597, 0.9688126224878449], 
             UndirectedEdge[57, 100] -> 
             RGBColor[
              0.8147018064065017, 0.6705787485713991, 0.5975452414204467], 
             UndirectedEdge[90, 93] -> 
             RGBColor[
              0.5196499744692419, 0.617970815219337, 0.9563487739967675], 
             UndirectedEdge[8, 25] -> 
             RGBColor[
              0.9235170950101663, 0.9395880521563387, 0.9052266591939555], 
             UndirectedEdge[84, 97] -> 
             RGBColor[
              0.9649386426139039, 0.9722310771693122, 0.8931465385268683], 
             UndirectedEdge[63, 66] -> 
             RGBColor[
              0.6611641994145131, 0.7239540364684403, 0.745137029003847], 
             UndirectedEdge[62, 74] -> 
             RGBColor[
              0.2949718513139897, 0.41790887117069075`, 0.9404557993685116], 
             UndirectedEdge[31, 69] -> 
             RGBColor[
              0.6196031963188083, 0.6823534833638927, 0.7665050300669818], 
             UndirectedEdge[38, 51] -> 
             RGBColor[
              0.30002307656860105`, 0.43220137095415706`, 0.9404145350257849],
              UndirectedEdge[5, 65] -> 
             RGBColor[
              0.7021038400963022, 0.7638798026414972, 0.9430243762925306], 
             UndirectedEdge[22, 69] -> 
             RGBColor[
              0.7343866184869483, 0.7870733827389259, 0.7737640482719065], 
             UndirectedEdge[55, 96] -> 
             RGBColor[
              0.9916137617744866, 0.9893433781308285, 0.682757681819643], 
             UndirectedEdge[3, 63] -> 
             RGBColor[
              0.958145688731407, 0.9649767515707781, 0.7702970747971447], 
             UndirectedEdge[51, 98] -> 
             RGBColor[
              0.446376892646354, 0.5576411258778016, 0.9506058665690955], 
             UndirectedEdge[1, 89] -> 
             RGBColor[
              0.7608701048177773, 0.8107259138714384, 0.8981539081377221], 
             UndirectedEdge[18, 86] -> 
             RGBColor[
              0.49641668844257403`, 0.5843454487353871, 0.9571011684642035], 
             UndirectedEdge[12, 17] -> 
             RGBColor[
              0.7632119156931905, 0.813169466316062, 0.9210112438481586], 
             UndirectedEdge[26, 41] -> 
             RGBColor[
              0.6963869472440727, 0.7568284964962089, 0.885548012064841], 
             UndirectedEdge[50, 87] -> 
             RGBColor[
              0.473596443033025, 0.5766172498354847, 0.9532278159777954], 
             UndirectedEdge[35, 54] -> 
             RGBColor[
              0.6271153143237891, 0.6903824048064096, 0.7802541544516308], 
             UndirectedEdge[30, 62] -> 
             RGBColor[
              0.5653132122506322, 0.6344460451973762, 0.9500727274492111], 
             UndirectedEdge[57, 81] -> 
             RGBColor[
              0.8697808558727811, 0.8977160762516943, 0.9185847016567227], 
             UndirectedEdge[22, 95] -> 
             RGBColor[
              0.36980373997464744`, 0.490092800984677, 0.9450934200840295], 
             UndirectedEdge[15, 90] -> 
             RGBColor[
              0.5753984407376924, 0.6656638599130771, 0.960064995823311], 
             UndirectedEdge[14, 40] -> 
             RGBColor[
              0.38026674444901454`, 0.5037896741045987, 0.9454512385929801], 
             UndirectedEdge[16, 44] -> 
             RGBColor[
              0.629523299235518, 0.7012866413432892, 0.950013670807744], 
             UndirectedEdge[61, 77] -> 
             RGBColor[
              0.797224100590324, 0.8406276980191767, 0.9172346067844044], 
             UndirectedEdge[37, 76] -> 
             RGBColor[
              0.8163530775342875, 0.8569396213951234, 0.9822029583733685], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.7139362612226139, 0.7753815300491653, 0.9731071567259052], 
             UndirectedEdge[5, 44] -> 
             RGBColor[
              0.6955025169983151, 0.758956546683693, 0.9541986943966152], 
             UndirectedEdge[5, 71] -> 
             RGBColor[
              0.7145834358117937, 0.7715395630811857, 0.8481211877416802], 
             UndirectedEdge[11, 29] -> 
             RGBColor[
              0.4862990041781473, 0.5934667833182059, 0.9528050822098784], 
             UndirectedEdge[54, 99] -> 
             RGBColor[
              0.47383961643801636`, 0.5732620581637632, 0.9538133041762366], 
             UndirectedEdge[5, 15] -> 
             RGBColor[
              0.45511676406411306`, 0.5680275242352187, 0.9503845945079316], 
             UndirectedEdge[19, 81] -> 
             RGBColor[
              0.8473170120759091, 0.8801671507460416, 0.9163457156436061], 
             UndirectedEdge[19, 90] -> 
             RGBColor[
              0.6915105893843397, 0.7589325951929613, 0.9698869710821132], 
             UndirectedEdge[58, 100] -> 
             RGBColor[
              0.871292020952473, 0.71515540486841, 0.6030879823670576], 
             UndirectedEdge[49, 100] -> 
             RGBColor[
              0.9223705360396164, 0.7550597198275807, 0.5793806735429616], 
             UndirectedEdge[36, 62] -> 
             RGBColor[
              0.3047646289441598, 0.426390882954629, 0.9410797864996929], 
             UndirectedEdge[62, 96] -> 
             RGBColor[
              0.586260212453628, 0.6470496543088755, 0.7387815109161782], 
             UndirectedEdge[22, 49] -> 
             RGBColor[
              0.7211848506247948, 0.7799154500629062, 0.9457045665582114], 
             UndirectedEdge[10, 73] -> 
             RGBColor[
              0.852922333028789, 0.881905412797908, 0.7568133775633169], 
             UndirectedEdge[39, 76] -> 
             RGBColor[
              0.9369993203690485, 0.9488567998819073, 0.8283956777965951], 
             UndirectedEdge[22, 58] -> 
             RGBColor[
              0.6701063355376515, 0.7400111351037355, 0.9694118753823076], 
             UndirectedEdge[69, 87] -> 
             RGBColor[
              0.6401301014309895, 0.703928562117749, 0.7676740069462857], 
             UndirectedEdge[9, 23] -> 
             RGBColor[
              0.928013223282538, 0.9447809635074189, 0.9702656257248963], 
             UndirectedEdge[28, 62] -> 
             RGBColor[
              0.5063237309627704, 0.5878220409365501, 0.9587515980005712], 
             UndirectedEdge[8, 36] -> 
             RGBColor[
              0.7100360087932962, 0.7686506275883658, 0.8864177181973663], 
             UndirectedEdge[7, 55] -> 
             RGBColor[
              0.8985617395534793, 0.9197587779503634, 0.9014499974502815], 
             UndirectedEdge[15, 39] -> 
             RGBColor[
              0.7349557071032111, 0.7879786257168209, 0.8101360024278943], 
             UndirectedEdge[15, 44] -> 
             RGBColor[
              0.715560973699707, 0.7757366989224855, 0.9556407803729818], 
             UndirectedEdge[16, 58] -> 
             RGBColor[
              0.5843037532908066, 0.6657519359773627, 0.9638032731375901], 
             UndirectedEdge[1, 43] -> 
             RGBColor[
              0.7548388722384332, 0.532525257664313, 0.45853608153399045`], 
             UndirectedEdge[7, 36] -> 
             RGBColor[
              0.6190458191767806, 0.6984619370830396, 0.9650526130465096], 
             UndirectedEdge[38, 61] -> 
             RGBColor[
              0.6363821336801151, 0.7034258095659873, 0.9059027149357175], 
             UndirectedEdge[32, 89] -> 
             RGBColor[
              0.9909307706134847, 0.98884337672835, 0.6782617883483393], 
             UndirectedEdge[57, 80] -> 
             RGBColor[
              0.5439542762905014, 0.6357642133853811, 0.9592762638024259], 
             UndirectedEdge[34, 59] -> 
             RGBColor[
              0.6147992070901734, 0.6929795317481762, 0.9655929051222885], 
             UndirectedEdge[40, 92] -> 
             RGBColor[
              0.6466662599188997, 0.6680355999615747, 0.6178891264932177], 
             UndirectedEdge[59, 82] -> 
             RGBColor[
              0.5584677896696733, 0.6396735627947245, 0.9621688159456745], 
             UndirectedEdge[3, 69] -> 
             RGBColor[
              0.958364487003999, 0.9654447389519537, 0.7941119165023696], 
             UndirectedEdge[16, 50] -> 
             RGBColor[
              0.4820503778421389, 0.5855028713302888, 0.9537092550586985], 
             UndirectedEdge[58, 83] -> 
             RGBColor[
              0.8432837334785616, 0.877875575021388, 0.9849143493791028], 
             UndirectedEdge[74, 96] -> 
             RGBColor[
              0.7023050637676178, 0.7595645254795663, 0.7457363102846899], 
             UndirectedEdge[31, 99] -> 
             RGBColor[
              0.46644995180566295`, 0.565495052103361, 0.9533924737074532], 
             UndirectedEdge[13, 57] -> 
             RGBColor[
              0.7056562391021404, 0.7699832842634269, 0.9712968772473711], 
             UndirectedEdge[8, 87] -> 
             RGBColor[
              0.637830880958586, 0.7040249037967419, 0.8818932232936814], 
             UndirectedEdge[7, 34] -> 
             RGBColor[
              0.5900348682827428, 0.6733341095514132, 0.9632040609089181], 
             UndirectedEdge[27, 72] -> 
             RGBColor[
              0.9012390702070441, 0.854285431258845, 0.630405468486221], 
             UndirectedEdge[75, 93] -> 
             RGBColor[
              0.6563667841677706, 0.7254738394606919, 0.9577572692429617], 
             UndirectedEdge[68, 84] -> 
             RGBColor[
              0.8838750556070083, 0.9101615467197126, 0.985996846776607], 
             UndirectedEdge[46, 64] -> 
             RGBColor[
              0.42818194747022875`, 0.5420742150979398, 0.9492715968071805], 
             UndirectedEdge[34, 49] -> 
             RGBColor[
              0.6701225105095083, 0.7362685257017267, 0.9422904679986841], 
             UndirectedEdge[48, 52] -> 
             RGBColor[
              0.7716028493124447, 0.8217713267723366, 0.9744639556596753], 
             UndirectedEdge[9, 22] -> 
             RGBColor[
              0.6848044003058067, 0.7517309729815227, 0.9708137899210114], 
             UndirectedEdge[29, 39] -> 
             RGBColor[
              0.7171827218163904, 0.7731780339461964, 0.808839544669101], 
             UndirectedEdge[2, 35] -> 
             RGBColor[
              0.7347441640769197, 0.7875261565738643, 0.7871108495082926], 
             UndirectedEdge[27, 47] -> 
             RGBColor[
              0.9672928588875092, 0.904652685739588, 0.5476797864337306], 
             UndirectedEdge[23, 36] -> 
             RGBColor[
              0.6958624700862994, 0.7589568532647073, 0.9496759552252063], 
             UndirectedEdge[34, 69] -> 
             RGBColor[
              0.6833242783716619, 0.7434264583777465, 0.7703499497123791], 
             UndirectedEdge[35, 50] -> 
             RGBColor[
              0.8276569956177426, 0.8626714090093381, 0.7946205336479308], 
             UndirectedEdge[15, 76] -> 
             RGBColor[
              0.6772188340313423, 0.7456858506390978, 0.970086355852999], 
             UndirectedEdge[90, 94] -> 
             RGBColor[
              0.8344715035893531, 0.8673217018507212, 0.7413756370225393], 
             UndirectedEdge[13, 85] -> 
             RGBColor[
              0.7645410908505791, 0.33392585682725623`, 0.4316937171555355], 
             UndirectedEdge[17, 97] -> 
             RGBColor[
              0.7658427184026968, 0.8142573708449887, 0.8774120346524729], 
             UndirectedEdge[36, 99] -> 
             RGBColor[
              0.5591819847525543, 0.6516958546488412, 0.9590859454904419], 
             UndirectedEdge[34, 87] -> 
             RGBColor[
              0.3293861791595715, 0.4576342145860077, 0.9422855259581093], 
             UndirectedEdge[70, 91] -> 
             RGBColor[
              0.46249571338113826`, 0.5724083449259125, 0.951410269155254], 
             UndirectedEdge[37, 47] -> 
             RGBColor[
              0.8715578577271925, 0.8986561709963762, 0.8984424882063105], 
             UndirectedEdge[1, 6] -> 
             RGBColor[
              0.6972645287854884, 0.7620897604056264, 0.9715149003704324], 
             UndirectedEdge[6, 89] -> 
             RGBColor[
              0.924914737327624, 0.9408847153410915, 0.9132726385430457], 
             UndirectedEdge[35, 70] -> 
             RGBColor[
              0.6850429120507009, 0.74507090491492, 0.7837799508259226], 
             UndirectedEdge[9, 21] -> 
             RGBColor[
              0.7126799199705234, 0.7743615756231897, 0.9730082529404109], 
             UndirectedEdge[11, 46] -> 
             RGBColor[
              0.5430386691562062, 0.6399022810910928, 0.9571691397336168], 
             UndirectedEdge[21, 22] -> 
             RGBColor[
              0.5025805559955334, 0.6070565622100311, 0.9539841288626569], 
             UndirectedEdge[37, 72] -> 
             RGBColor[
              0.8055040690467274, 0.8482889165156332, 0.9811681702588009], 
             UndirectedEdge[9, 62] -> 
             RGBColor[
              0.5369153821403984, 0.6122149931973406, 0.9616694569993828], 
             UndirectedEdge[22, 30] -> 
             RGBColor[
              0.7132022304160406, 0.7739620249815583, 0.9592170603708399], 
             UndirectedEdge[6, 43] -> 
             RGBColor[
              0.864201960578331, 0.6192977919774152, 0.46861523513753955`], 
             UndirectedEdge[26, 45] -> 
             RGBColor[
              0.39155853532327356`, 0.5135700558179705, 0.9461707415225493], 
             UndirectedEdge[34, 99] -> 
             RGBColor[
              0.5301710338585165, 0.6265680271172147, 0.9572373933528505], 
             UndirectedEdge[35, 87] -> 
             RGBColor[
              0.6402525548036168, 0.7041904774998637, 0.7810023008621514], 
             UndirectedEdge[47, 72] -> 
             RGBColor[
              0.9236182190025246, 0.939629869525947, 0.9035507729400738], 
             UndirectedEdge[32, 47] -> 
             RGBColor[
              0.9915066177750231, 0.989081504328243, 0.6687185106369632], 
             UndirectedEdge[35, 82] -> 
             RGBColor[
              0.6271153143237891, 0.6903824048064096, 0.7802541544516308], 
             UndirectedEdge[14, 15] -> 
             RGBColor[
              0.45043041086375185`, 0.5639684406360264, 0.9500859842259839], 
             UndirectedEdge[3, 91] -> 
             RGBColor[
              0.7359397417070637, 0.793044094345061, 0.9750705287475667], 
             UndirectedEdge[18, 24] -> 
             RGBColor[
              0.6926301234219451, 0.7592160552198077, 0.9704027135371676], 
             UndirectedEdge[6, 60] -> 
             RGBColor[
              0.7652758474871793, 0.816892591353878, 0.9771505650859875], 
             UndirectedEdge[81, 100] -> 
             RGBColor[
              0.9321554566267394, 0.7618518267780082, 0.5401813400490336], 
             UndirectedEdge[34, 81] -> 
             RGBColor[
              0.6799074310966313, 0.7430606326521543, 0.9030911345047562], 
             UndirectedEdge[25, 69] -> 
             RGBColor[
              0.9258163154825696, 0.9394917104773459, 0.7910074428465599], 
             UndirectedEdge[14, 76] -> 
             RGBColor[
              0.6524740241295892, 0.7248466148011129, 0.9683456595946847], 
             UndirectedEdge[79, 90] -> 
             RGBColor[
              0.6325865394804566, 0.7120917347669422, 0.9645670524432495], 
             UndirectedEdge[9, 28] -> 
             RGBColor[
              0.8643121131031687, 0.8946430341338907, 0.9869200549999539], 
             UndirectedEdge[60, 89] -> 
             RGBColor[
              0.8288814235194681, 0.8655287448196901, 0.9037895728532772], 
             UndirectedEdge[1, 14] -> 
             RGBColor[
              0.4794527486188203, 0.5875300818670073, 0.9523707289663892], 
             UndirectedEdge[7, 69] -> 
             RGBColor[
              0.9007787905541607, 0.9196284570831544, 0.7885925418970945], 
             UndirectedEdge[66, 91] -> 
             RGBColor[
              0.43895825239016983`, 0.5520213792427231, 0.949910482954269], 
             UndirectedEdge[44, 79] -> 
             RGBColor[
              0.7727490724424713, 0.8221645737763507, 0.9601428369929206], 
             UndirectedEdge[41, 79] -> 
             RGBColor[
              0.7895105889746532, 0.8337884577246075, 0.8925038285597612], 
             UndirectedEdge[22, 50] -> 
             RGBColor[
              0.5678529600889839, 0.6597620704566616, 0.959317857303416], 
             UndirectedEdge[3, 82] -> 
             RGBColor[
              0.5912891473120809, 0.6658444224667608, 0.9652993463375792], 
             UndirectedEdge[95, 96] -> 
             RGBColor[
              0.6292479342628672, 0.6922324755093705, 0.7412295980785789], 
             UndirectedEdge[2, 63] -> 
             RGBColor[
              0.7344029124317003, 0.7867962538105739, 0.7499677138872021], 
             UndirectedEdge[7, 23] -> 
             RGBColor[
              0.8843060313747604, 0.9100310244384888, 0.9660699952723302], 
             UndirectedEdge[44, 57] -> 
             RGBColor[
              0.8541369661432263, 0.8865543597080224, 0.9677017416449006], 
             UndirectedEdge[13, 58] -> 
             RGBColor[
              0.7622464536481117, 0.8145599405604378, 0.976839618193982], 
             UndirectedEdge[8, 54] -> 
             RGBColor[
              0.6246936404787584, 0.6902168311032877, 0.8811450768831608], 
             UndirectedEdge[54, 69] -> 
             RGBColor[
              0.6269928609511617, 0.6901204894242949, 0.7669258605357652], 
             UndirectedEdge[3, 66] -> 
             RGBColor[
              0.6256792840480244, 0.7001459568920819, 0.9673253565108859], 
             UndirectedEdge[34, 82] -> 
             RGBColor[
              0.31624893867974385`, 0.44382614189255354`, 0.9415373795475889],
              UndirectedEdge[17, 67] -> 
             RGBColor[
              0.5538604593366605, 0.6486878978756776, 0.9580210706981458], 
             UndirectedEdge[57, 88] -> 
             RGBColor[
              0.7149619870517727, 0.7772530052879836, 0.9722243872358316], 
             UndirectedEdge[8, 69] -> 
             RGBColor[
              0.9917689801706764, 0.9898171475884806, 0.7099576470479512], 
             UndirectedEdge[62, 99] -> 
             RGBColor[
              0.43334435580839453`, 0.5306989716942122, 0.9515071589907491], 
             UndirectedEdge[69, 99] -> 
             RGBColor[
              0.8409149561299344, 0.8728623746489561, 0.7826258743410268], 
             UndirectedEdge[49, 59] -> 
             RGBColor[
              0.9123413614994378, 0.9321159466038977, 0.9629219043967698], 
             UndirectedEdge[46, 94] -> 
             RGBColor[
              0.7732149633084038, 0.8181004244139181, 0.736204921448472], 
             UndirectedEdge[42, 53] -> 
             RGBColor[
              0.8932571484980589, 0.8226397715004528, 0.6239830269193889], 
             UndirectedEdge[28, 74] -> 
             RGBColor[
              0.6223685822767601, 0.7003369121072408, 0.9657063973690829], 
             UndirectedEdge[31, 70] -> 
             RGBColor[
              0.3104554543538021, 0.4374416669872102, 0.9412182562764833], 
             UndirectedEdge[50, 54] -> 
             RGBColor[
              0.46045920255319733`, 0.5628091771420305, 0.9524796695672748], 
             UndirectedEdge[15, 100] -> 
             RGBColor[
              0.6761258139629824, 0.5597610877858622, 0.585484280148528], 
             UndirectedEdge[33, 91] -> 
             RGBColor[
              0.4723871779518262, 0.5809758343775775, 0.9520405445310196], 
             UndirectedEdge[45, 88] -> 
             RGBColor[
              0.5287048521538383, 0.6257298102209397, 0.9569612468771453], 
             UndirectedEdge[16, 59] -> 
             RGBColor[
              0.5800589649586149, 0.6623672569829828, 0.9633984014370983], 
             UndirectedEdge[80, 85] -> 
             RGBColor[
              0.6567397823094865, 0.24444647624189242`, 0.4236799748589053], 
             UndirectedEdge[2, 3] -> 
             RGBColor[
              0.6989179970652115, 0.7629881742342155, 0.9721560413942409], 
             UndirectedEdge[83, 94] -> 
             RGBColor[
              0.9071905893407315, 0.9241390998764843, 0.7486212883598016], 
             UndirectedEdge[73, 84] -> 
             RGBColor[
              0.966195042275743, 0.9712749635200255, 0.7650593173519389], 
             UndirectedEdge[42, 80] -> 
             RGBColor[
              0.6322656068012589, 0.6105511783406894, 0.6021467617114648], 
             UndirectedEdge[17, 48] -> 
             RGBColor[
              0.5720781625029181, 0.6634778500042207, 0.9594552350250392], 
             UndirectedEdge[6, 92] -> 
             RGBColor[
              0.9098968965985521, 0.8819348091936365, 0.6399273472719503], 
             UndirectedEdge[19, 100] -> 
             RGBColor[
              0.7922379626096296, 0.6530298230657464, 0.5953062554073303], 
             UndirectedEdge[35, 63] -> 
             RGBColor[
              0.9939718557431151, 0.9895147339104268, 0.5852518829111963], 
             UndirectedEdge[19, 79] -> 
             RGBColor[
              0.6484754681549165, 0.7245042866077607, 0.9661507123630392], 
             UndirectedEdge[50, 69] -> 
             RGBColor[
              0.8275345422451154, 0.8624094936272234, 0.7812922397320652], 
             UndirectedEdge[52, 73] -> 
             RGBColor[
              0.9666238048740625, 0.9715947339638179, 0.7643335341121795], 
             UndirectedEdge[59, 99] -> 
             RGBColor[
              0.772389884848446, 0.8224154480193857, 0.9778688297509361], 
             UndirectedEdge[44, 56] -> 
             RGBColor[
              0.9716360294934663, 0.9778462174109517, 0.9095852271839355], 
             UndirectedEdge[14, 75] -> 
             RGBColor[
              0.687370440534468, 0.7523276483164469, 0.9597327948111907], 
             UndirectedEdge[14, 20] -> 
             RGBColor[
              0.6585926406098729, 0.7297254334970711, 0.9689292586967275], 
             UndirectedEdge[62, 95] -> 
             RGBColor[
              0.2219147218092391, 0.35057682120049494`, 0.9359490871624008], 
             UndirectedEdge[39, 83] -> 
             RGBColor[
              0.9078980128267771, 0.9256522071816498, 0.8256199691041692], 
             UndirectedEdge[48, 73] -> 
             RGBColor[
              0.798550496007796, 0.8388349026784703, 0.7518007811594303], 
             UndirectedEdge[20, 76] -> 
             RGBColor[
              0.8853810637774633, 0.9114428435001425, 0.9889296303237425], 
             UndirectedEdge[8, 49] -> 
             RGBColor[
              0.978567212308523, 0.9826592149124609, 0.8818981653342561], 
             UndirectedEdge[49, 55] -> 
             RGBColor[
              0.9786493817802449, 0.982693194100677, 0.8805364045400476], 
             UndirectedEdge[2, 34] -> 
             RGBColor[
              0.42387778843287444`, 0.5409698936600082, 0.9483940746042505], 
             UndirectedEdge[1, 71] -> 
             RGBColor[
              0.7636642302682539, 0.8118813565509592, 0.8518480184584521], 
             UndirectedEdge[40, 79] -> 
             RGBColor[
              0.46219965309353184`, 0.5710567847964488, 0.9516939914712331], 
             UndirectedEdge[94, 98] -> 
             RGBColor[
              0.7861104904216156, 0.8285695942612994, 0.7372201045806963], 
             UndirectedEdge[44, 81] -> 
             RGBColor[
              0.9715906163634639, 0.9778274379146316, 0.9103378402734875], 
             UndirectedEdge[16, 82] -> 
             RGBColor[
              0.2815086965481853, 0.4132138671273603, 0.9393428758623987], 
             UndirectedEdge[21, 30] -> 
             RGBColor[
              0.7410777500807573, 0.7965926276232254, 0.9614115233902394], 
             UndirectedEdge[96, 99] -> 
             RGBColor[
              0.8406775682620227, 0.8723546260030878, 0.7567876699069273], 
             UndirectedEdge[94, 100] -> 
             RGBColor[
              0.9351988768146431, 0.7614189297235063, 0.36679492134775643`], 
             UndirectedEdge[21, 46] -> 
             RGBColor[
              0.5417823279041156, 0.6388823266651174, 0.9570702359481227], 
             UndirectedEdge[9, 86] -> 
             RGBColor[
              0.5531236361971168, 0.6292508958736139, 0.9625924930899498], 
             UndirectedEdge[14, 94] -> 
             RGBColor[
              0.7095034737154126, 0.7656262825736706, 0.7313966254252124], 
             UndirectedEdge[46, 83] -> 
             RGBColor[
              0.6870842061803091, 0.7541161639411027, 0.9703782469255184], 
             UndirectedEdge[58, 59] -> 
             RGBColor[
              0.8612628464122947, 0.892211631644727, 0.9866292132208658], 
             UndirectedEdge[10, 97] -> 
             RGBColor[
              0.8516659333669498, 0.8828615264471946, 0.8849005987382463], 
             UndirectedEdge[21, 64] -> 
             RGBColor[
              0.41685569522636307`, 0.5328790532845207, 0.9483799527411144], 
             UndirectedEdge[4, 38] -> 
             RGBColor[
              0.6352486182981196, 0.7029570718255157, 0.924687998259156], 
             UndirectedEdge[63, 70] -> 
             RGBColor[
              0.6847016604054815, 0.7443410021516297, 0.7466368152048319], 
             UndirectedEdge[39, 94] -> 
             RGBColor[
              0.9940287699548718, 0.989636467654465, 0.5914466436271228], 
             UndirectedEdge[27, 37] -> 
             RGBColor[
              0.849178708931712, 0.8133117327292743, 0.6252971837524577], 
             UndirectedEdge[57, 85] -> 
             RGBColor[
              0.7956550685508479, 0.3582323326816951, 0.43479486767604525`], 
             UndirectedEdge[22, 34] -> 
             RGBColor[
              0.42364269621553036`, 0.5407790352071846, 0.9483755672837302], 
             UndirectedEdge[31, 87] -> 
             RGBColor[
              0.26566509710671804`, 0.39656123957215395`, 0.938440606312712], 
             UndirectedEdge[10, 48] -> 
             RGBColor[
              0.6579013774671713, 0.7320820056064266, 0.9669437991108127], 
             UndirectedEdge[63, 82] -> 
             RGBColor[
              0.6267740626785697, 0.6896525020431192, 0.7431110188305403], 
             UndirectedEdge[4, 66] -> 
             RGBColor[
              0.6565015145542354, 0.7234505335573826, 0.9259658620219422], 
             UndirectedEdge[10, 68] -> 
             RGBColor[
              0.7706023463600542, 0.820791995997595, 0.9777509069879851], 
             UndirectedEdge[9, 64] -> 
             RGBColor[
              0.5990795395366364, 0.6775534640560124, 0.965209613799469], 
             UndirectedEdge[22, 55] -> 
             RGBColor[
              0.7321695674862668, 0.7872037036061349, 0.8866215038250935], 
             UndirectedEdge[7, 87] -> 
             RGBColor[
              0.5468406913420704, 0.6338362132914157, 0.9605281181428247], 
             UndirectedEdge[35, 69] -> 
             RGBColor[
              0.994190654015707, 0.9899827212916024, 0.6090667246164212], 
             UndirectedEdge[8, 99] -> 
             RGBColor[
              0.838615735657531, 0.8729587163279489, 0.8968450906884224], 
             UndirectedEdge[31, 50] -> 
             RGBColor[
              0.4530695379208439, 0.5550421710816283, 0.9520588390984914], 
             UndirectedEdge[19, 58] -> 
             RGBColor[
              0.7864535764016429, 0.8334707288364434, 0.9792523579616301], 
             UndirectedEdge[58, 81] -> 
             RGBColor[
              0.9263710704187526, 0.9422927325487052, 0.9241274426033336], 
             UndirectedEdge[9, 30] -> 
             RGBColor[
              0.9233015943910305, 0.9412670383947169, 0.9782411844485939], 
             UndirectedEdge[5, 56] -> 
             RGBColor[
              0.7111918198578724, 0.7701370427236849, 0.9043290413188851], 
             UndirectedEdge[7, 22] -> 
             RGBColor[
              0.6410972083980292, 0.7169810339125926, 0.9666181594684454], 
             UndirectedEdge[7, 95] -> 
             RGBColor[
              0.5361959120418599, 0.6226478753289055, 0.9599219137092174], 
             UndirectedEdge[34, 50] -> 
             RGBColor[
              0.5167906199736975, 0.6161151460954821, 0.9559037587438888], 
             UndirectedEdge[42, 88] -> 
             RGBColor[
              0.8032733175625302, 0.7520399702432918, 0.6150948851448704], 
             UndirectedEdge[60, 72] -> 
             RGBColor[
              0.7634034820005415, 0.8153996179388403, 0.9769719771943917], 
             UndirectedEdge[50, 99] -> 
             RGBColor[
              0.67438129773197, 0.7455510623666917, 0.9681796833725365], 
             UndirectedEdge[44, 88] -> 
             RGBColor[
              0.8167717475424555, 0.857364366950921, 0.9639775258525964], 
             UndirectedEdge[26, 42] -> 
             RGBColor[
              0.6661270007319655, 0.639880215840323, 0.6043043797902744], 
             UndirectedEdge[67, 97] -> 
             RGBColor[
              0.7790763931796991, 0.825001064199214, 0.8784538380074665], 
             UndirectedEdge[12, 68] -> 
             RGBColor[
              0.9073642625293334, 0.9274131021899987, 0.934294319407218], 
             UndirectedEdge[79, 93] -> 
             RGBColor[
              0.47661485323981867`, 0.5835425066341364, 0.9526125152776935], 
             UndirectedEdge[26, 57] -> 
             RGBColor[
              0.577815670221208, 0.6650932508850147, 0.9614338818812356], 
             UndirectedEdge[17, 84] -> 
             RGBColor[
              0.7397227087708652, 0.7959179108457759, 0.9727137712175477], 
             UndirectedEdge[71, 76] -> 
             RGBColor[
              0.9366855057790229, 0.9491978894850648, 0.8678229490867476], 
             UndirectedEdge[3, 31] -> 
             RGBColor[
              0.5838994826797277, 0.6580774164063586, 0.9648785158687958], 
             UndirectedEdge[15, 72] -> 
             RGBColor[
              0.6663698255437822, 0.7370351457596076, 0.9690515677384313], 
             UndirectedEdge[10, 84] -> 
             RGBColor[
              0.8255459237351184, 0.8645220664479818, 0.9802023353033211], 
             UndirectedEdge[4, 51] -> 
             RGBColor[
              0.6490796926478217, 0.7170221244536624, 0.925492950092925], 
             UndirectedEdge[1, 37] -> 
             RGBColor[
              0.6433318020235186, 0.7196230884610177, 0.966228027745073], 
             UndirectedEdge[7, 28] -> 
             RGBColor[
              0.8206049211953912, 0.8598930950649606, 0.9827244245473878], 
             UndirectedEdge[28, 36] -> 
             RGBColor[
              0.6321613599069301, 0.7088189238911791, 0.966330384500264], 
             UndirectedEdge[16, 39] -> 
             RGBColor[
              0.648918032639022, 0.7135285681376244, 0.8045088928626565], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.6246936404787584, 0.6902168311032877, 0.8811450768831608], 
             UndirectedEdge[30, 36] -> 
             RGBColor[
              0.691150841194792, 0.7554429281520053, 0.9576515139489039], 
             UndirectedEdge[52, 60] -> 
             RGBColor[
              0.8044593459288674, 0.8480338894450804, 0.9773321040043217], 
             UndirectedEdge[59, 69] -> 
             RGBColor[
              0.9255431293615913, 0.9392738792799175, 0.7909813861104649], 
             UndirectedEdge[10, 12] -> 
             RGBColor[
              0.8490351306574435, 0.8817736219182681, 0.9284998079339322], 
             UndirectedEdge[38, 66] -> 
             RGBColor[
              0.30744489847501477`, 0.4386297800578772, 0.9408874469548021], 
             UndirectedEdge[41, 90] -> 
             RGBColor[
              0.8325457102040765, 0.8682167663098082, 0.8962400872788352], 
             UndirectedEdge[5, 93] -> 
             RGBColor[
              0.3993682977956626, 0.5203344795414787, 0.9466683726813881], 
             UndirectedEdge[5, 90] -> 
             RGBColor[
              0.5553399840363006, 0.6488837076742845, 0.9586229098469441], 
             UndirectedEdge[34, 58] -> 
             RGBColor[
              0.6190439954223652, 0.6963642107425561, 0.9659977768227802], 
             UndirectedEdge[72, 76] -> 
             RGBColor[
              0.8684134388096196, 0.8979133199246941, 0.9873112431071319], 
             UndirectedEdge[6, 76] -> 
             RGBColor[
              0.8702858042962573, 0.899406293339732, 0.9874898309987279], 
             UndirectedEdge[2, 59] -> 
             RGBColor[
              0.6660966394228038, 0.7368173145621792, 0.9690255110023362], 
             UndirectedEdge[1, 72] -> 
             RGBColor[
              0.6953921632988507, 0.7605967869905885, 0.9713363124788364], 
             UndirectedEdge[66, 70] -> 
             RGBColor[
              0.3522352557220989, 0.4795102074729335, 0.9436650969185733], 
             UndirectedEdge[54, 87] -> 
             RGBColor[
              0.2730547617390714, 0.4043282456325562, 0.9388614367814954], 
             UndirectedEdge[43, 89] -> 
             RGBColor[
              0.9066056779331902, 0.6517218942879566, 0.41970790698239935`], 
             UndirectedEdge[22, 23] -> 
             RGBColor[
              0.717913859307548, 0.7774759500942603, 0.9512415016471422], 
             UndirectedEdge[20, 83] -> 
             RGBColor[
              0.8562797562351918, 0.8882382507998849, 0.9861539216313167], 
             UndirectedEdge[2, 54] -> 
             RGBColor[
              0.3675463710123743, 0.4876639247065567, 0.9449699854276365], 
             UndirectedEdge[11, 83] -> 
             RGBColor[
              0.677014295188534, 0.7459409565536592, 0.9695855066449465], 
             UndirectedEdge[54, 82] -> 
             RGBColor[
              0.2599175212592437, 0.390520172939102, 0.9381132903709749], 
             UndirectedEdge[19, 80] -> 
             RGBColor[
              0.5214904324936294, 0.6182152878797285, 0.9570372777893094], 
             UndirectedEdge[6, 72] -> 
             RGBColor[
              0.8594367958086973, 0.8907555884602418, 0.9864550428841601], 
             UndirectedEdge[1, 20] -> 
             RGBColor[
              0.7123597882666943, 0.774126310566037, 0.972954699695447], 
             UndirectedEdge[48, 67] -> 
             RGBColor[
              0.5853118372799206, 0.674221543358446, 0.9604970383800328], 
             UndirectedEdge[30, 58] -> 
             RGBColor[
              0.9086035296228754, 0.9295472005169297, 0.9768392699098899], 
             UndirectedEdge[50, 82] -> 
             RGBColor[
              0.46045920255319733`, 0.5628091771420305, 0.9524796695672748], 
             UndirectedEdge[55, 62] -> 
             RGBColor[
              0.5842805493208585, 0.6476877238219528, 0.8774771709034648], 
             UndirectedEdge[10, 17] -> 
             RGBColor[
              0.6264499995239112, 0.7065483601236583, 0.9644678314289257], 
             UndirectedEdge[8, 59] -> 
             RGBColor[
              0.923243908889188, 0.9393702209589103, 0.9052006024578605], 
             UndirectedEdge[14, 44] -> 
             RGBColor[
              0.690816163797954, 0.7548974630845007, 0.9539000841146675], 
             UndirectedEdge[27, 43] -> 
             RGBColor[
              0.8920701435105621, 0.5949843538431507, 0.23124885220558022`], 
             UndirectedEdge[40, 56] -> 
             RGBColor[
              0.661086610144527, 0.7267384284310499, 0.9011363816622482], 
             UndirectedEdge[8, 55] -> 
             RGBColor[
              0.989551929169995, 0.9899474684556896, 0.8228151026011382], 
             UndirectedEdge[82, 99] -> 
             RGBColor[
              0.47383961643801636`, 0.5732620581637632, 0.9538133041762366], 
             UndirectedEdge[19, 44] -> 
             RGBColor[
              0.8316731223463543, 0.8690054342023698, 0.9654627556317841], 
             UndirectedEdge[46, 51] -> 
             RGBColor[
              0.4334813655331422, 0.5471719560304201, 0.9495906834368713], 
             UndirectedEdge[50, 58] -> 
             RGBColor[
              0.7632542592958187, 0.815347245992033, 0.9769400668424661], 
             UndirectedEdge[19, 94] -> 
             RGBColor[
              0.850360432263813, 0.8797342536915397, 0.742959296942329], 
             UndirectedEdge[30, 86] -> 
             RGBColor[
              0.5815214663073507, 0.6514819478736495, 0.9509957635397781], 
             UndirectedEdge[23, 55] -> 
             RGBColor[
              0.975378390462998, 0.980253694132031, 0.8860733396289783], 
             UndirectedEdge[76, 92] -> 
             RGBColor[
              0.9188735395994744, 0.8890925406580888, 0.6407835474949222], 
             UndirectedEdge[28, 96] -> 
             RGBColor[
              0.9136569434163985, 0.9294776952454257, 0.7640321089167493], 
             UndirectedEdge[46, 98] -> 
             RGBColor[
              0.5660041072611932, 0.6585466583259179, 0.9589770631464131], 
             UndirectedEdge[21, 86] -> 
             RGBColor[
              0.3708997918868434, 0.48457648510212237`, 0.9457628320315952], 
             UndirectedEdge[6, 32] -> 
             RGBColor[
              0.9273251945811958, 0.9402072232625379, 0.7516227805810496], 
             UndirectedEdge[9, 74] -> 
             RGBColor[
              0.652960233454388, 0.7247298643680313, 0.9686242563678944], 
             UndirectedEdge[1, 27] -> 
             RGBColor[
              0.7390668031838352, 0.7256196032042297, 0.6154653259724934], 
             UndirectedEdge[88, 90] -> 
             RGBColor[
              0.676609214580441, 0.7472915279415124, 0.9684017413029253], 
             UndirectedEdge[42, 45] -> 
             RGBColor[
              0.6543814012653666, 0.6297067679333493, 0.6035559605784885], 
             UndirectedEdge[81, 88] -> 
             RGBColor[
              0.8324156372720104, 0.8685260834945927, 0.9148604858644185], 
             UndirectedEdge[5, 76] -> 
             RGBColor[
              0.6571603773299505, 0.7289056984003053, 0.9686442698766322], 
             UndirectedEdge[7, 49] -> 
             RGBColor[
              0.8875770226920072, 0.9124705244071347, 0.9605330601833995], 
             UndirectedEdge[1, 76] -> 
             RGBColor[
              0.7062411717864108, 0.7692474918700787, 0.9723711005934041], 
             UndirectedEdge[6, 15] -> 
             RGBColor[
              0.6682421910304199, 0.7385281191746454, 0.9692301556300271], 
             UndirectedEdge[43, 60] -> 
             RGBColor[
              0.8001797513728938, 0.5690604782964809, 0.46229319134436053`], 
             UndirectedEdge[32, 37] -> 
             RGBColor[
              0.8733924678192259, 0.8977405513179293, 0.7463359079556902], 
             UndirectedEdge[37, 89] -> 
             RGBColor[
              0.870982010565654, 0.898418043396483, 0.9079857659176864], 
             UndirectedEdge[29, 58] -> 
             RGBColor[
              0.6525684424681749, 0.7254014017859347, 0.9681339249440346], 
             UndirectedEdge[20, 89] -> 
             RGBColor[
              0.9400099968088299, 0.9529212655015021, 0.9147124378680604], 
             UndirectedEdge[17, 73] -> 
             RGBColor[
              0.7670991180645359, 0.8133012571957019, 0.7493248134775434], 
             UndirectedEdge[16, 90] -> 
             RGBColor[
              0.4893607662735034, 0.5912138023338807, 0.9544378862580729], 
             UndirectedEdge[32, 60] -> 
             RGBColor[
              0.83129188077304, 0.8648512527411365, 0.742139714891281], 
             UndirectedEdge[21, 62] -> 
             RGBColor[
              0.35469153783012497`, 0.46754058242584906`, 0.9448397959410282],
              UndirectedEdge[20, 43] -> 
             RGBColor[
              0.874265466899135, 0.6273221587510223, 0.469575101354216], 
             UndirectedEdge[14, 92] -> 
             RGBColor[
              0.692085116431884, 0.7073751306550174, 0.6207831758679071], 
             UndirectedEdge[40, 76] -> 
             RGBColor[
              0.6070551676166049, 0.6855070841076701, 0.9654516102199951], 
             UndirectedEdge[49, 69] -> 
             RGBColor[
              0.9808664327809262, 0.982562873233468, 0.7676789489868605], 
             UndirectedEdge[2, 82] -> 
             RGBColor[
              0.3675463710123743, 0.4876639247065567, 0.9449699854276365], 
             UndirectedEdge[5, 75] -> 
             RGBColor[
              0.6920567937348292, 0.7563867319156392, 0.9600314050931382], 
             UndirectedEdge[2, 87] -> 
             RGBColor[
              0.380683611492202, 0.5014719974000108, 0.9457181318381571], 
             UndirectedEdge[3, 54] -> 
             RGBColor[
              0.5912891473120809, 0.6658444224667608, 0.9652993463375792], 
             UndirectedEdge[8, 35] -> 
             RGBColor[
              0.9918914335433038, 0.9900790629705953, 0.7232859409638168], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.6519986303829568, 0.7204811883488622, 0.9398317166358935], 
             UndirectedEdge[23, 74] -> 
             RGBColor[
              0.6860696924561293, 0.7504748414807689, 0.9490519680940251], 
             UndirectedEdge[34, 36] -> 
             RGBColor[
              0.40159130699428175`, 0.5222599383776316, 0.9468100208617942], 
             UndirectedEdge[34, 54] -> 
             RGBColor[
              0.31624893867974385`, 0.44382614189255354`, 0.9415373795475889],
              UndirectedEdge[2, 99] -> 
             RGBColor[
              0.5814684661911469, 0.6704058099312178, 0.9606699992328982], 
             UndirectedEdge[16, 98] -> 
             RGBColor[
              0.4409997531057659, 0.5524616947444589, 0.9502823538162299], 
             UndirectedEdge[1, 32] -> 
             RGBColor[
              0.7632805620713492, 0.8100484217928847, 0.7365040501757258], 
             UndirectedEdge[68, 97] -> 
             RGBColor[
              0.9099950652388398, 0.9285010067189254, 0.8906951102115322], 
             UndirectedEdge[52, 67] -> 
             RGBColor[
              0.7533851461461871, 0.8069813746437935, 0.9730297913327819], 
             UndirectedEdge[14, 78] -> 
             RGBColor[
              0.458700916136358, 0.5706828093983447, 0.9507370686969026], 
             UndirectedEdge[3, 70] -> 
             RGBColor[
              0.6492167450389927, 0.7205329225752712, 0.9688251427118709], 
             UndirectedEdge[16, 81] -> 
             RGBColor[
              0.6451671889650727, 0.7124483578869609, 0.9008966308195661], 
             UndirectedEdge[19, 85] -> 
             RGBColor[
              0.7806791726862665, 0.3465330490112599, 0.43330221033396765`], 
             UndirectedEdge[13, 80] -> 
             RGBColor[
              0.49728330974009827`, 0.5993044996037229, 0.9546245380216611], 
             UndirectedEdge[72, 89] -> 
             RGBColor[
              0.9230423718409861, 0.9393917419260538, 0.9130940506514498], 
             UndirectedEdge[14, 39] -> 
             RGBColor[
              0.710210897201458, 0.7671393898788359, 0.80839530616958], 
             UndirectedEdge[29, 83] -> 
             RGBColor[
              0.6303445412022501, 0.7076806661682158, 0.96601418940178], 
             UndirectedEdge[25, 31] -> 
             RGBColor[
              0.5513513111582983, 0.6321243879317509, 0.9617740422129861], 
             UndirectedEdge[43, 72] -> 
             RGBColor[
              0.8629537169205724, 0.61830247636739, 0.46849617654314224`], 
             UndirectedEdge[33, 66] -> 
             RGBColor[
              0.3621267202927869, 0.48807769692459857`, 0.9442953722943388], 
             UndirectedEdge[43, 76] -> 
             RGBColor[
              0.8701863892456125, 0.6240696129537168, 0.4691860352861874], 
             UndirectedEdge[16, 57] -> 
             RGBColor[
              0.5277135387448352, 0.6211752796803518, 0.9582605321909792], 
             UndirectedEdge[71, 93] -> 
             RGBColor[
              0.678893426244735, 0.7406266706262382, 0.8458470518915036], 
             UndirectedEdge[58, 80] -> 
             RGBColor[
              0.6005444908364728, 0.680340869682392, 0.9648190047490368], 
             UndirectedEdge[8, 31] -> 
             RGBColor[
              0.617303975846405, 0.6824498250428855, 0.8807242464143774], 
             UndirectedEdge[28, 30] -> 
             RGBColor[
              0.8927099432134027, 0.9168740861339264, 0.9753233254497823], 
             UndirectedEdge[15, 98] -> 
             RGBColor[
              0.527037427569955, 0.6269117523236554, 0.9559094633814678], 
             UndirectedEdge[34, 55] -> 
             RGBColor[
              0.6811072273709804, 0.7435567792449554, 0.8832074052655663], 
             UndirectedEdge[23, 62] -> 
             RGBColor[
              0.5700248411421396, 0.6379599703100782, 0.9420971687255135], 
             UndirectedEdge[26, 85] -> 
             RGBColor[
              0.6793140449299575, 0.26399916790831474`, 0.4251183869114451], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.8335332640746376, 0.8689882508991777, 0.896338517419437], 
             UndirectedEdge[7, 62] -> 
             RGBColor[
              0.49320819023262086`, 0.5774650541284105, 0.9574738265468168], 
             UndirectedEdge[67, 68] -> 
             RGBColor[
              0.6980128061728035, 0.7629315337496143, 0.9713041462572052], 
             UndirectedEdge[32, 48] -> 
             RGBColor[
              0.7984353841566174, 0.8385886900683925, 0.7392715665466345], 
             UndirectedEdge[22, 87] -> 
             RGBColor[
              0.3804485192748579, 0.5012811389471872, 0.9456996245176367], 
             UndirectedEdge[5, 78] -> 
             RGBColor[
              0.46338726933671925`, 0.574741892997537, 0.9510356789788501], 
             UndirectedEdge[40, 93] -> 
             RGBColor[
              0.3492630880823171, 0.4769358652488437, 0.9434757130247511], 
             UndirectedEdge[7, 30] -> 
             RGBColor[
              0.8795944024832532, 0.9065170993257868, 0.9740455539960278], 
             UndirectedEdge[40, 90] -> 
             RGBColor[
              0.5052347743229552, 0.6054850933816495, 0.9554302501903071], 
             UndirectedEdge[53, 88] -> 
             RGBColor[
              0.7675805993865308, 0.8186628137880431, 0.9773883132180458], 
             UndirectedEdge[31, 59] -> 
             RGBColor[
              0.5510781250373199, 0.6319065567343224, 0.9617479854768911], 
             UndirectedEdge[70, 82] -> 
             RGBColor[
              0.31784511898615553`, 0.44520867304761247`, 0.9416390867452666],
              UndirectedEdge[12, 97] -> 
             RGBColor[
              0.9884278495362291, 0.9894826326395985, 0.8414440111574792], 
             UndirectedEdge[16, 100] -> 
             RGBColor[
              0.5900881394987934, 0.4853110302066658, 0.57985717058329], 
             UndirectedEdge[15, 40] -> 
             RGBColor[
              0.40501155435076763`, 0.5246289099425837, 0.9471919348512945], 
             UndirectedEdge[43, 83] -> 
             RGBColor[
              0.8507855175507649, 0.6085998844868783, 0.4673355628245702], 
             UndirectedEdge[13, 100] -> 
             RGBColor[
              0.7680308398560985, 0.6341190347897409, 0.592893515639682], 
             UndirectedEdge[39, 92] -> 
             RGBColor[
              0.9766104126713432, 0.9313853157358118, 0.4808331940698175], 
             UndirectedEdge[57, 90] -> 
             RGBColor[
              0.7139744331812117, 0.776481520698614, 0.9721259570952296], 
             UndirectedEdge[64, 86] -> 
             RGBColor[
              0.25729941145295654`, 0.38776837353494487`, 0.9379641928906532],
              UndirectedEdge[50, 59] -> 
             RGBColor[
              0.7590094709636269, 0.8119625669976531, 0.9765351951419745], 
             UndirectedEdge[14, 93] -> 
             RGBColor[
              0.39468194459530137`, 0.5162753959422863, 0.9463697623994405], 
             UndirectedEdge[16, 34] -> 
             RGBColor[
              0.3378401139686854, 0.4665198360808118, 0.9427669650390127], 
             UndirectedEdge[29, 46] -> 
             RGBColor[
              0.49636891516992243`, 0.6016419907056494, 0.9535978224904502], 
             UndirectedEdge[57, 79] -> 
             RGBColor[
              0.6709393119517885, 0.7420532121134134, 0.9683896983761557], 
             UndirectedEdge[29, 30] -> 
             RGBColor[
              0.6956643373465641, 0.7593522916637575, 0.9579391099325669], 
             UndirectedEdge[28, 95] -> 
             RGBColor[
              0.5493114527720094, 0.633004862137045, 0.9611996851629719], 
             UndirectedEdge[38, 77] -> 
             RGBColor[
              0.44703396912910803`, 0.5553382067791997, 0.9509414750407028], 
             UndirectedEdge[20, 27] -> 
             RGBColor[
              0.9182066951748877, 0.8678149548342935, 0.6320238557028317], 
             UndirectedEdge[15, 16] -> 
             RGBColor[
              0.38913754630131586`, 0.5103576188948149, 0.9461995709190604], 
             UndirectedEdge[31, 54] -> 
             RGBColor[
              0.25252785662689037`, 0.3827531668786998, 0.9376924599021915], 
             UndirectedEdge[44, 90] -> 
             RGBColor[
              0.8157841936718945, 0.8565928823615513, 0.9638790957119945], 
             UndirectedEdge[11, 49] -> 
             RGBColor[
              0.750316711541602, 0.8035660071305488, 0.9479979333631052], 
             UndirectedEdge[47, 89] -> 
             RGBColor[
              0.9890961605214513, 0.9897589964067968, 0.8303683685989593], 
             UndirectedEdge[8, 22] -> 
             RGBColor[
              0.7320873980145448, 0.7871697244179188, 0.8879832646193021], 
             UndirectedEdge[92, 98] -> 
             RGBColor[
              0.7686921331380869, 0.7703184423426463, 0.6266066550233911], 
             UndirectedEdge[80, 88] -> 
             RGBColor[
              0.5065890576897307, 0.6065742206282797, 0.9555520480101216], 
             UndirectedEdge[21, 55] -> 
             RGBColor[
              0.7600450871509834, 0.809834306247802, 0.888815966844493], 
             UndirectedEdge[40, 41] -> 
             RGBColor[
              0.6621588238171516, 0.7271818163393147, 0.8833670263068187], 
             UndirectedEdge[32, 43] -> 
             RGBColor[
              0.9082126494355715, 0.6512702329022542, 0.31194133500773524`], 
             UndirectedEdge[5, 79] -> 
             RGBColor[
              0.5123048628068774, 0.6144553990890839, 0.9548866511278702], 
             UndirectedEdge[55, 87] -> 
             RGBColor[
              0.637913050430308, 0.704058882984958, 0.8805314624994728], 
             UndirectedEdge[42, 57] -> 
             RGBColor[
              0.840638536163301, 0.7812299630003934, 0.6188191009371746], 
             UndirectedEdge[9, 29] -> 
             RGBColor[
              0.6672665072363301, 0.7371212396637219, 0.9695358394827387], 
             UndirectedEdge[46, 86] -> 
             RGBColor[
              0.38222604413070915`, 0.49377164691554143`, 0.9466544760976614],
              UndirectedEdge[51, 61] -> 
             RGBColor[
              0.6502132080298171, 0.717490862194134, 0.9067076667694864], 
             UndirectedEdge[14, 90] -> 
             RGBColor[
              0.5506536308359393, 0.6448246240750921, 0.9583242995649965], 
             UndirectedEdge[41, 44] -> 
             RGBColor[
              0.972708243166091, 0.9782896053192166, 0.8918158718285061], 
             UndirectedEdge[14, 98] -> 
             RGBColor[
              0.5022926176682019, 0.6060725164856704, 0.9541687671231535], 
             UndirectedEdge[5, 92] -> 
             RGBColor[
              0.6967714696322451, 0.7114342142542098, 0.6210817861498548], 
             UndirectedEdge[15, 94] -> 
             RGBColor[
              0.7342482836171655, 0.7864655184116555, 0.7331373216835267], 
             UndirectedEdge[8, 96] -> 
             RGBColor[
              0.9915315923027646, 0.9893093989426123, 0.6841194426138515], 
             UndirectedEdge[21, 83] -> 
             RGBColor[
              0.6757579539364433, 0.7449210021276836, 0.9694866028594522], 
             UndirectedEdge[27, 89] -> 
             RGBColor[
              0.9667170117259707, 0.904414558139695, 0.5572230641451068], 
             UndirectedEdge[4, 33] -> 
             RGBColor[
              0.6899304401158918, 0.752404988692237, 0.9280959235986928], 
             UndirectedEdge[17, 52] -> 
             RGBColor[
              0.7401514713691847, 0.7962376812895682, 0.9719879879777883], 
             UndirectedEdge[26, 56] -> 
             RGBColor[
              0.695314733571448, 0.7563851085879439, 0.9033173674202704], 
             UndirectedEdge[20, 92] -> 
             RGBColor[
              0.924992156079758, 0.893971359354047, 0.641367146596965], 
             UndirectedEdge[48, 68] -> 
             RGBColor[
              0.7162305093390612, 0.7777214858781574, 0.9727383105840985], 
             UndirectedEdge[15, 19] -> 
             RGBColor[
              0.5912873694121522, 0.6780764117538955, 0.9616486557431005], 
             UndirectedEdge[19, 34] -> 
             RGBColor[
              0.5399899370795218, 0.6342386289398925, 0.9582160498630528], 
             UndirectedEdge[36, 55] -> 
             RGBColor[
              0.7101181782650182, 0.7686846067765819, 0.8850559574031577], 
             UndirectedEdge[20, 32] -> 
             RGBColor[
              0.9424204540624017, 0.9522437734229485, 0.7530625799060642], 
             UndirectedEdge[83, 98] -> 
             RGBColor[
              0.6999797332935209, 0.7645853337884843, 0.9713934300577427], 
             UndirectedEdge[2, 8] -> 
             RGBColor[
              0.732322490231889, 0.7873605828707424, 0.8880017719398225], 
             UndirectedEdge[22, 62] -> 
             RGBColor[
              0.3268160181654084, 0.444909979784182, 0.9426453329216287], 
             UndirectedEdge[7, 9] -> 
             RGBColor[
              0.8511965723730192, 0.8842860473257512, 0.9856422835461995], 
             UndirectedEdge[44, 92] -> 
             RGBColor[
              0.957215679267839, 0.9191433889414766, 0.626337972014905], 
             UndirectedEdge[6, 20] -> 
             RGBColor[
              0.876404420776541, 0.9042851120356901, 0.9880734301007708], 
             UndirectedEdge[11, 30] -> 
             RGBColor[
              0.7423340913328478, 0.7976125820492009, 0.9615104271757335], 
             UndirectedEdge[7, 74] -> 
             RGBColor[
              0.6092530415466105, 0.6899799252991012, 0.9644286259153284], 
             UndirectedEdge[20, 72] -> 
             RGBColor[
              0.8745320552899032, 0.9027921386206523, 0.9878948422091748], 
             UndirectedEdge[29, 86] -> 
             RGBColor[
              0.3254863791526502, 0.4473361491426545, 0.9422904185739229], 
             UndirectedEdge[12, 73] -> 
             RGBColor[
              0.9896842491980683, 0.9885265189903117, 0.7133567899825497], 
             UndirectedEdge[65, 93] -> 
             RGBColor[
              0.6664138305292436, 0.7329669101865499, 0.9407502404423539], 
             UndirectedEdge[36, 96] -> 
             RGBColor[
              0.7120978413977879, 0.7680465372635046, 0.746360297415871], 
             UndirectedEdge[2, 70] -> 
             RGBColor[
              0.4254739687392861, 0.5423524248150671, 0.9484957818019283], 
             UndirectedEdge[31, 82] -> 
             RGBColor[
              0.25252785662689037`, 0.3827531668786998, 0.9376924599021915], 
             UndirectedEdge[48, 89] -> 
             RGBColor[
              0.7960249269030455, 0.8392661821469463, 0.9009214245086308], 
             UndirectedEdge[49, 82] -> 
             RGBColor[
              0.6137910930890083, 0.6829625567482751, 0.9388663788220701], 
             UndirectedEdge[40, 75] -> 
             RGBColor[
              0.6419515840214838, 0.7129881176230042, 0.9568387454365013], 
             UndirectedEdge[19, 49] -> 
             RGBColor[
              0.8375320914887862, 0.873375043795614, 0.9555450491375341], 
             UndirectedEdge[53, 85] -> 
             RGBColor[
              0.8307341434406865, 0.3858388716817347, 0.43823748499752146`], 
             UndirectedEdge[69, 82] -> 
             RGBColor[
              0.6269928609511617, 0.6901204894242949, 0.7669258605357652], 
             UndirectedEdge[63, 91] -> 
             RGBColor[
              0.7714246570735525, 0.8168521739214193, 0.7528822012405277], 
             UndirectedEdge[9, 96] -> 
             RGBColor[
              0.9442485945940264, 0.9538706475062162, 0.7669499679155609], 
             UndirectedEdge[18, 64] -> 
             RGBColor[
              0.5423725917820936, 0.6326480169177855, 0.9597182891737227], 
             UndirectedEdge[59, 87] -> 
             RGBColor[
              0.571605030149501, 0.6534816354881787, 0.9629169623561951], 
             UndirectedEdge[51, 66] -> 
             RGBColor[
              0.32127597282471676`, 0.45269483268602395`, 0.941692398788571], 
             UndirectedEdge[49, 81] -> 
             RGBColor[
              0.9774495855058958, 0.9821970475078758, 0.9004201337792375], 
             UndirectedEdge[3, 35] -> 
             RGBColor[
              0.9584869403766263, 0.9657066543340684, 0.8074402104182352], 
             UndirectedEdge[9, 36] -> 
             RGBColor[
              0.6627530110845581, 0.7332118761519697, 0.9692482434990757], 
             UndirectedEdge[56, 57] -> 
             RGBColor[
              0.8698262690027835, 0.8977348557480145, 0.9178320885671707], 
             UndirectedEdge[49, 58] -> 
             RGBColor[
              0.9165861498316296, 0.9355006255982776, 0.9633267760972615], 
             UndirectedEdge[21, 58] -> 
             RGBColor[
              0.6979818552023682, 0.7626417377454026, 0.9716063384017071], 
             UndirectedEdge[48, 60] -> 
             RGBColor[
              0.6363860370626009, 0.7152740581597328, 0.9647993510515727], 
             UndirectedEdge[21, 29] -> 
             RGBColor[
              0.48504266292605674`, 0.5924468288922303, 0.9527061784243841], 
             UndirectedEdge[34, 100] -> 
             RGBColor[
              0.6248283816303519, 0.5159233049718591, 0.5820516742684803], 
             UndirectedEdge[11, 64] -> 
             RGBColor[
              0.41811203647845363`, 0.5338990077104964, 0.9484788565266087], 
             UndirectedEdge[73, 97] -> 
             RGBColor[
              0.9923150519075745, 0.9896144235192383, 0.6697575807868641], 
             UndirectedEdge[64, 74] -> 
             RGBColor[
              0.35713600871022777`, 0.48324734202936237`, 0.9439959561685979],
              UndirectedEdge[40, 78] -> 
             RGBColor[
              0.4132820596233737, 0.531343278704902, 0.9478430193222132], 
             UndirectedEdge[49, 99] -> 
             RGBColor[
              0.8277131882677808, 0.8657044419729363, 0.9545663926273318], 
             UndirectedEdge[82, 87] -> 
             RGBColor[
              0.2730547617390714, 0.4043282456325562, 0.9388614367814954], 
             UndirectedEdge[44, 100] -> 
             RGBColor[
              0.9165115668971844, 0.7506901102343364, 0.5892983800372116], 
             UndirectedEdge[16, 49] -> 
             RGBColor[
              0.6353822683779498, 0.7056562509365334, 0.940095964313494], 
             UndirectedEdge[41, 93] -> 
             RGBColor[
              0.6765740239634385, 0.7396675381770024, 0.8842855501132791], 
             UndirectedEdge[17, 68] -> 
             RGBColor[
              0.6847791313958012, 0.752187840395389, 0.9702623429022116], 
             UndirectedEdge[25, 54] -> 
             RGBColor[
              0.5587409757906516, 0.639891393992153, 0.9621948726817695], 
             UndirectedEdge[22, 96] -> 
             RGBColor[
              0.7341492306190365, 0.7865656340930576, 0.7479258438378069], 
             UndirectedEdge[88, 100] -> 
             RGBColor[
              0.777336587805731, 0.6413887558142977, 0.5938210256281424], 
             UndirectedEdge[13, 16] -> 
             RGBColor[
              0.481042572194432, 0.5847155658986936, 0.9536088064102144], 
             UndirectedEdge[60, 73] -> 
             RGBColor[
              0.8314069926242186, 0.8650974653512141, 0.7546689295040768], 
             UndirectedEdge[81, 90] -> 
             RGBColor[
              0.8314280834014494, 0.8677545989052231, 0.9147620557238165], 
             UndirectedEdge[19, 57] -> 
             RGBColor[
              0.7298633618556716, 0.7888940725394324, 0.9737096170150192], 
             UndirectedEdge[10, 67] -> 
             RGBColor[
              0.6396836743009136, 0.7172920534778836, 0.9655096347839194], 
             UndirectedEdge[85, 88] -> 
             RGBColor[
              0.7707449228170007, 0.338772337510294, 0.4323120571478424], 
             UndirectedEdge[9, 55] -> 
             RGBColor[
              0.9422689314612568, 0.9545087170192935, 0.9056456279028475], 
             UndirectedEdge[22, 59] -> 
             RGBColor[
              0.6658615472054599, 0.7366264561093556, 0.9690070036818158], 
             UndirectedEdge[56, 88] -> 
             RGBColor[
              0.8324610504020127, 0.8685448629909129, 0.9141078727748664], 
             UndirectedEdge[33, 70] -> 
             RGBColor[
              0.38566418128375524`, 0.5084646626077879, 0.9457951584953238], 
             UndirectedEdge[87, 99] -> 
             RGBColor[
              0.48697685691784404`, 0.5870701308572174, 0.954561450586757], 
             UndirectedEdge[16, 19] -> 
             RGBColor[
              0.5052496949479632, 0.6036263541746991, 0.9560215461778626], 
             UndirectedEdge[5, 14] -> 
             RGBColor[
              0.43037195416236007`, 0.5471882883972339, 0.9486438982496173], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.48052916677428476`, 0.5885374653804781, 0.9524185824407211], 
             UndirectedEdge[36, 74] -> 
             RGBColor[
              0.42080948025814946`, 0.5389057541253197, 0.9480345858682045], 
             UndirectedEdge[6, 27] -> 
             RGBColor[
              0.9031114356936818, 0.8557784046738829, 0.630584056377817], 
             UndirectedEdge[60, 67] -> 
             RGBColor[
              0.6181683338963432, 0.7004841060311897, 0.9633651867246793], 
             UndirectedEdge[20, 47] -> 
             RGBColor[
              0.9405858439703684, 0.9531593931013953, 0.9051691601566844], 
             UndirectedEdge[19, 50] -> 
             RGBColor[
              0.6842002009529753, 0.7532216641893694, 0.9691583398827388], 
             UndirectedEdge[29, 64] -> 
             RGBColor[
              0.3714422824921698, 0.4956387173250529, 0.9449075392834421], 
             UndirectedEdge[20, 37] -> 
             RGBColor[
              0.8224716940145711, 0.8618184400910816, 0.9827865574754113], 
             UndirectedEdge[15, 92] -> 
             RGBColor[
              0.716829926333637, 0.7282143664930023, 0.6225238721262215], 
             UndirectedEdge[48, 84] -> 
             RGBColor[
              0.7711740867141252, 0.8214515563285442, 0.9751897388994346], 
             UndirectedEdge[32, 72] -> 
             RGBColor[
              0.9254528290945581, 0.9387142498475001, 0.7514441926894536], 
             UndirectedEdge[44, 93] -> 
             RGBColor[
              0.6598125074312564, 0.7280436542287455, 0.9519245585464384], 
             UndirectedEdge[2, 50] -> 
             RGBColor[
              0.5680880523063279, 0.6599529289094852, 0.9593363646239366], 
             UndirectedEdge[76, 94] -> 
             RGBColor[
              0.936291896883003, 0.947343692576742, 0.7513969970522274], 
             UndirectedEdge[56, 79] -> 
             RGBColor[
              0.7884383753020284, 0.8333450698163427, 0.9102731839151905], 
             UndirectedEdge[6, 37] -> 
             RGBColor[
              0.8073764345333652, 0.849781889930671, 0.9813467581503967], 
             UndirectedEdge[40, 44] -> 
             RGBColor[
              0.6453973072849697, 0.7155579323910579, 0.951006034739978], 
             UndirectedEdge[56, 90] -> 
             RGBColor[
              0.8314734965314516, 0.8677733784015433, 0.9140094426342645], 
             UndirectedEdge[16, 79] -> 
             RGBColor[
              0.4463256450440801, 0.55678549374868, 0.950701627538999], 
             UndirectedEdge[13, 81] -> 
             RGBColor[
              0.823109889322378, 0.861256362470036, 0.913932975875958], 
             UndirectedEdge[90, 100] -> 
             RGBColor[
              0.77634903393517, 0.640617271224928, 0.5937225954875406], 
             UndirectedEdge[34, 35] -> 
             RGBColor[
              0.6834467317442892, 0.7436883737598611, 0.7836782436282448], 
             UndirectedEdge[7, 99] -> 
             RGBColor[
              0.7476255460410153, 0.8027700258226227, 0.9754799855375658], 
             UndirectedEdge[45, 53] -> 
             RGBColor[
              0.6186886830893671, 0.6963296114781006, 0.9658493886516638]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 25 -> 
             RGBColor[
              0.8575644303220595, 0.889262615045204, 0.9862764549925642], 55 -> 
             RGBColor[
              0.9896340986417169, 0.9899814476439057, 0.8214533418069296], 90 -> 
             RGBColor[
              0.67562166070988, 0.7465200433521428, 0.9683033111623235], 27 -> 
             RGBColor[
              0.9449137100920286, 0.8193082474724862, 0.274534481979878], 15 -> 
             RGBColor[
              0.4751752207655049, 0.5848076764740113, 0.9518266804842983], 98 -> 
             RGBColor[
              0.578899634374405, 0.6690158281732993, 0.9599922462786373], 38 -> 
             RGBColor[
              0.28619200221889907`, 0.41813631832601034`, 0.9396095831920159],
              99 -> RGBColor[
              0.687761711616789, 0.7560039433884244, 0.9695133179814982], 71 -> 
             RGBColor[
              0.9941085642608661, 0.9918317541659452, 0.7472998669517956], 41 -> 
             RGBColor[
              0.989469759698273, 0.9899134892674735, 0.8241768633953468], 75 -> 
             RGBColor[
              0.9490552801069373, 0.9615260918348524, 0.9711203016547117], 64 -> 
             RGBColor[
              0.30325531479247614`, 0.4360709417173433, 0.9405813136001724], 
             63 -> RGBColor[
              0.9936306040978957, 0.9887848311471364, 0.5481087472901057], 85 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 3 -> 
             RGBColor[
              0.9226607733649183, 0.9411686719944197, 0.9924854023041836], 86 -> 
             RGBColor[
              0.21134350811343688`, 0.3394658053525465, 0.935347072181134], 
             94 -> RGBColor[
              0.9933213464688263, 0.9881233603492996, 0.5144479628827552], 61 -> 
             RGBColor[
              0.9865722651413311, 0.9887153008059644, 0.8721958466794191], 84 -> 
             RGBColor[
              0.9388186329820724, 0.9538916171700994, 0.9884482750919431], 76 -> 
             RGBColor[
              0.8792624472971797, 0.9065640248041843, 0.9883460312216996], 21 -> 
             RGBColor[
              0.53045607566025, 0.6296871648516982, 0.9561785918820565], 87 -> 
             RGBColor[
              0.28619200221889907`, 0.41813631832601034`, 0.9396095831920159],
              95 -> RGBColor[
              0.2649024436184782, 0.39575964240098993`, 0.9383971743248015], 
             72 -> RGBColor[
              0.8575644303220595, 0.889262615045204, 0.9862764549925642], 42 -> 
             RGBColor[
              0.9289498666740584, 0.7560169279557016, 0.26168959884621357`], 
             66 -> RGBColor[
              0.32869779473113053`, 0.4591232417897442, 0.9421653107175882], 
             1 -> 
             RGBColor[
              0.5332198962756418, 0.6319309589359732, 0.9563961699651087], 24 -> 
             RGBColor[
              0.603770378072179, 0.6892070183213879, 0.9619501623270622], 54 -> 
             RGBColor[
              0.2599175212592437, 0.390520172939102, 0.9381132903709749], 4 -> 
             RGBColor[
              0.9843052343773403, 0.987777825325021, 0.909766413326296], 7 -> 
             RGBColor[
              0.8074893804652417, 0.8495361082568211, 0.9814466530936334], 
             100 -> RGBColor[
              0.8770764071604599, 0.5347144990977131, 0.2191418798127577], 12 -> 
             RGBColor[
              0.9857970468267229, 0.9883947281106719, 0.885043220353165], 65 -> 
             RGBColor[
              0.9691493728298833, 0.9765122332865684, 0.9371062440534963], 8 -> 
             RGBColor[
              0.989469759698273, 0.9899134892674735, 0.8241768633953468], 57 -> 
             RGBColor[
              0.7523272056525435, 0.8064429980450851, 0.9759486030281358], 74 -> 
             RGBColor[
              0.41101670262797935`, 0.5304237423413815, 0.9474105987370234], 
             37 -> RGBColor[
              0.7534437077713952, 0.8073152179860624, 0.9760598855250374], 43 -> 
             RGBColor[
              0.8656483602198289, 0.482822407028483, 0.2096060373184313], 39 -> 
             RGBColor[
              0.9947361934409173, 0.9911495749596304, 0.6684453243714904], 58 -> 
             RGBColor[
              0.8655076347444863, 0.8955963106391069, 0.9870340849213576], 11 -> 
             RGBColor[
              0.5329687581644311, 0.6317270737036493, 0.9563763994530449], 51 -> 
             RGBColor[
              0.31385415091830304`, 0.4462664235823038, 0.9412194868595538], 
             48 -> RGBColor[
              0.6035295404461782, 0.6890114954869889, 0.9619312027069261], 20 -> 
             RGBColor[
              0.891499680257747, 0.9163216621961007, 0.9895132294257853], 33 -> 
             RGBColor[
              0.39555564585444325`, 0.517032152059453, 0.9464254338710893], 
             45 -> RGBColor[
              0.3798129358566747, 0.503396607910997, 0.9454223223107634], 23 -> 
             RGBColor[
              0.9611226822842792, 0.9705259406201564, 0.9506933374510269], 22 -> 
             RGBColor[
              0.47470503633081673`, 0.5844259595683641, 0.9517896658432574], 
             2 -> RGBColor[
              0.4751752207655049, 0.5848076764740113, 0.9518266804842983], 60 -> 
             RGBColor[
              0.6692425336790234, 0.7415366208324766, 0.9676674993962191], 16 -> 
             RGBColor[
              0.30309987183712683`, 0.4359075613156186, 0.9405724613538224], 
             79 -> RGBColor[
              0.5895514182510334, 0.6776634261817416, 0.9608307937241756], 89 -> 
             RGBColor[
              0.9885203133599129, 0.9895208688069036, 0.8399116463103354], 36 -> 
             RGBColor[
              0.4306022578883195, 0.5473877659092581, 0.9486585729993857], 52 -> 
             RGBColor[
              0.9396761581787113, 0.9545311580576842, 0.9869967086124244], 32 -> 
             RGBColor[
              0.9933412278670565, 0.9881658846497963, 0.516611930386343], 31 -> 
             RGBColor[
              0.24513819199453699`, 0.3749861608182976, 0.9372716294334081], 
             68 -> RGBColor[
              0.8289314782319441, 0.8664314762693257, 0.983545418461271], 73 -> 
             RGBColor[
              0.9935714515694137, 0.9886583098699516, 0.5416703596119345], 82 -> 
             RGBColor[
              0.2599175212592437, 0.390520172939102, 0.9381132903709749], 35 -> 
             RGBColor[
              0.9943131073883344, 0.9902446366737171, 0.6223950185322868], 88 -> 
             RGBColor[
              0.677596768451002, 0.7480630125308821, 0.9685001714435273], 50 -> 
             RGBColor[
              0.6610008838471509, 0.7350981813449591, 0.9668460487635747], 19 -> 
             RGBColor[
              0.7073995180587995, 0.7713451470337798, 0.9714706310019028], 17 -> 
             RGBColor[
              0.5406267845596581, 0.6379442045214523, 0.9569792673431522], 96 -> 
             RGBColor[
              0.9935934249072562, 0.9887053086177512, 0.5440620218323563], 14 -> 
             RGBColor[
              0.4256856009619988, 0.5431292047980415, 0.9483452879676696], 5 -> 
             RGBColor[
              0.4350583073627213, 0.5512473719964261, 0.9489425085315648], 34 -> 
             RGBColor[
              0.372580356100244, 0.4971321108460051, 0.9449614687242028], 97 -> 
             RGBColor[
              0.9910586522457354, 0.9905705371685251, 0.7978448019617935], 93 -> 
             RGBColor[
              0.3636782882286039, 0.4894215870865313, 0.9443942368312115], 81 -> 
             RGBColor[
              0.9872345060930188, 0.9889891544583034, 0.8612208002853096], 69 -> 
             RGBColor[
              0.9940682006430798, 0.9897208059094877, 0.5957384307005555], 9 -> 
             RGBColor[
              0.8949037642807967, 0.9190359863946813, 0.9898379139987655], 13 -> 
             RGBColor[
              0.6589852725517372, 0.7335235704817686, 0.9666451514666063], 30 -> 
             RGBColor[
              0.9516994245012645, 0.9634980903947525, 0.9666444548984222], 59 -> 
             RGBColor[
              0.8570180580801029, 0.8888269526503472, 0.9862243415203742], 28 -> 
             RGBColor[
              0.8337204619255407, 0.8702500818731002, 0.9840021960011424], 80 -> 
             RGBColor[
              0.3355813469284593, 0.4650854287256772, 0.9426039245767159], 47 -> 
             RGBColor[
              0.9896720076829898, 0.9899971240066899, 0.8208250908875834], 62 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 77 -> 
             RGBColor[
              0.607875936039317, 0.692540095232389, 0.9622733668893897], 78 -> 
             RGBColor[
              0.4917162313107172, 0.5982364139986478, 0.9531288494261355], 40 -> 
             RGBColor[
              0.3348478879360303, 0.46445014341115604`, 0.9425571892182907], 
             67 -> RGBColor[
              0.5670941341136629, 0.6594315912299029, 0.9590628740531394], 56 -> 
             RGBColor[
              0.9873253323530234, 0.9890267134509437, 0.8597155741062056], 10 -> 
             RGBColor[
              0.7122732144881643, 0.7751525157258643, 0.9719563955146993], 53 -> 
             RGBColor[
              0.8575644303220595, 0.889262615045204, 0.9862764549925642], 26 -> 
             RGBColor[
              0.4033041347898725, 0.5237435037249442, 0.9469191607343352], 18 -> 
             RGBColor[
              0.7814898687717111, 0.8292250921182276, 0.978855264747273], 29 -> 
             RGBColor[
              0.4396292501918635, 0.5552064929327625, 0.9492337649667117], 92 -> 
             RGBColor[
              0.958484631901769, 0.8716210565119934, 0.29322106376814466`], 
             46 -> RGBColor[
              0.5531085801479814, 0.6480774884785364, 0.9579618800141888], 49 -> 
             RGBColor[
              0.9676646649187728, 0.9754049405574483, 0.9396194672731655], 83 -> 
             RGBColor[
              0.8210598322126368, 0.8601548394036691, 0.9827946138368481], 70 -> 
             RGBColor[
              0.3757727167130673, 0.49989717315612286`, 0.9451648831195583], 
             44 -> RGBColor[
              0.955946726633909, 0.9666657213709597, 0.9594548802616655], 91 -> 
             RGBColor[
              0.5492187100492092, 0.6449195166957021, 0.9576556551909498], 6 -> 
             RGBColor[
              0.8613091612953351, 0.8922485618752796, 0.986633630775756]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9k4031PkCh8f7eJ1hxozXMb8Zqt0oHV0lbd9PRdeWRZRI7GxRYazaZKuh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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 6}], {
             RGBColor[
             0.6972645287854884, 0.7620897604056264, 0.9715149003704324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 14}], {
             RGBColor[
             0.4794527486188203, 0.5875300818670073, 0.9523707289663892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 20}], {
             RGBColor[
             0.7123597882666943, 0.774126310566037, 0.972954699695447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 27}], {
             RGBColor[
             0.7390668031838352, 0.7256196032042297, 0.6154653259724934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 32}], {
             RGBColor[
             0.7632805620713492, 0.8100484217928847, 0.7365040501757258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 37}], {
             RGBColor[
             0.6433318020235186, 0.7196230884610177, 0.966228027745073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 43}], {
             RGBColor[
             0.7548388722384332, 0.532525257664313, 0.45853608153399045`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 47}], {
             RGBColor[
             0.7614459519793157, 0.8109640414713315, 0.888610630426346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 71}], {
             RGBColor[
             0.7636642302682539, 0.8118813565509592, 0.8518480184584521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 72}], {
             RGBColor[
             0.6953921632988507, 0.7605967869905885, 0.9713363124788364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 76}], {
             RGBColor[
             0.7062411717864108, 0.7692474918700787, 0.9723711005934041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 89}], {
             RGBColor[
             0.7608701048177773, 0.8107259138714384, 0.8981539081377221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 92}], {
             RGBColor[
             0.7458522640887054, 0.7517760077239832, 0.6248086168666267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 3}], {
             RGBColor[
             0.6989179970652115, 0.7629881742342155, 0.9721560413942409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 8}], {
             RGBColor[
             0.732322490231889, 0.7873605828707424, 0.8880017719398225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 25}], {
             RGBColor[
             0.6663698255437822, 0.7370351457596076, 0.9690515677384313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 31}], {
             RGBColor[
             0.36015670638002095`, 0.47989691864615447`, 0.9445491549588532]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 34}], {
             RGBColor[
             0.42387778843287444`, 0.5409698936600082, 0.9483940746042505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 35}], {
             RGBColor[
             0.7347441640769197, 0.7875261565738643, 0.7871108495082926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 50}], {
             RGBColor[
             0.5680880523063279, 0.6599529289094852, 0.9593363646239366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 54}], {
             RGBColor[
             0.3675463710123743, 0.4876639247065567, 0.9449699854276365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 59}], {
             RGBColor[
             0.6660966394228038, 0.7368173145621792, 0.9690255110023362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 63}], {
             RGBColor[
             0.7344029124317003, 0.7867962538105739, 0.7499677138872021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 69}], {
             RGBColor[
             0.7346217107042923, 0.7872642411917495, 0.7737825555924269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 70}], {
             RGBColor[
             0.4254739687392861, 0.5423524248150671, 0.9484957818019283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 82}], {
             RGBColor[
             0.3675463710123743, 0.4876639247065567, 0.9449699854276365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 87}], {
             RGBColor[
             0.380683611492202, 0.5014719974000108, 0.9457181318381571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 99}], {
             RGBColor[
             0.5814684661911469, 0.6704058099312178, 0.9606699992328982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 31}], {
             RGBColor[
             0.5838994826797277, 0.6580774164063586, 0.9648785158687958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 35}], {
             RGBColor[
             0.9584869403766263, 0.9657066543340684, 0.8074402104182352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 50}], {
             RGBColor[
             0.7918308286060346, 0.8381334266696894, 0.9796657255338792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 54}], {
             RGBColor[
             0.5912891473120809, 0.6658444224667608, 0.9652993463375792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 59}], {
             RGBColor[
             0.8898394157225106, 0.9149978123223834, 0.9893548719122789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 63}], {
             RGBColor[
             0.958145688731407, 0.9649767515707781, 0.7702970747971447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 66}], {
             RGBColor[
             0.6256792840480244, 0.7001459568920819, 0.9673253565108859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 69}], {
             RGBColor[
             0.958364487003999, 0.9654447389519537, 0.7941119165023696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 70}], {
             RGBColor[
             0.6492167450389927, 0.7205329225752712, 0.9688251427118709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 82}], {
             RGBColor[
             0.5912891473120809, 0.6658444224667608, 0.9652993463375792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 91}], {
             RGBColor[
             0.7359397417070637, 0.793044094345061, 0.9750705287475667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 33}], {
             RGBColor[
             0.6899304401158918, 0.752404988692237, 0.9280959235986928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 38}], {
             RGBColor[
             0.6352486182981196, 0.7029570718255157, 0.924687998259156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 51}], {
             RGBColor[
             0.6490796926478217, 0.7170221244536624, 0.925492950092925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 66}], {
             RGBColor[
             0.6565015145542354, 0.7234505335573826, 0.9259658620219422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 14}], {
             RGBColor[
             0.43037195416236007`, 0.5471882883972339, 0.9486438982496173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 15}], {
             RGBColor[
             0.45511676406411306`, 0.5680275242352187, 0.9503845945079316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 40}], {
             RGBColor[
             0.3849530976493758, 0.5078487577037911, 0.9457498488749277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 41}], {
             RGBColor[
             0.712264033530497, 0.7705804306319498, 0.8865596859634558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 44}], {
             RGBColor[
             0.6955025169983151, 0.758956546683693, 0.9541986943966152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 56}], {
             RGBColor[
             0.7111918198578724, 0.7701370427236849, 0.9043290413188851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 65}], {
             RGBColor[
             0.7021038400963022, 0.7638798026414972, 0.9430243762925306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 71}], {
             RGBColor[
             0.7145834358117937, 0.7715395630811857, 0.8481211877416802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 75}], {
             RGBColor[
             0.6920567937348292, 0.7563867319156392, 0.9600314050931382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 76}], {
             RGBColor[
             0.6571603773299505, 0.7289056984003053, 0.9686442698766322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 78}], {
             RGBColor[
             0.46338726933671925`, 0.574741892997537, 0.9510356789788501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 79}], {
             RGBColor[
             0.5123048628068774, 0.6144553990890839, 0.9548866511278702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 90}], {
             RGBColor[
             0.5553399840363006, 0.6488837076742845, 0.9586229098469441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 92}], {
             RGBColor[
             0.6967714696322451, 0.7114342142542098, 0.6210817861498548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 93}], {
             RGBColor[
             0.3993682977956626, 0.5203344795414787, 0.9466683726813881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 14}], {
             RGBColor[
             0.643497381128667, 0.7176888833366606, 0.9674894593717128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 15}], {
             RGBColor[
             0.6682421910304199, 0.7385281191746454, 0.9692301556300271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 20}], {
             RGBColor[
             0.876404420776541, 0.9042851120356901, 0.9880734301007708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 27}], {
             RGBColor[
             0.9031114356936818, 0.8557784046738829, 0.630584056377817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 32}], {
             RGBColor[
             0.9273251945811958, 0.9402072232625379, 0.7516227805810496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 37}], {
             RGBColor[
             0.8073764345333652, 0.849781889930671, 0.9813467581503967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 43}], {
             RGBColor[
             0.864201960578331, 0.6192977919774152, 0.46861523513753955`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 47}], {
             RGBColor[
             0.9254905844891624, 0.9411228429409848, 0.9037293608316697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 60}], {
             RGBColor[
             0.7652758474871793, 0.816892591353878, 0.9771505650859875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 72}], {
             RGBColor[
             0.8594367958086973, 0.8907555884602418, 0.9864550428841601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 76}], {
             RGBColor[
             0.8702858042962573, 0.899406293339732, 0.9874898309987279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 89}], {
             RGBColor[
             0.924914737327624, 0.9408847153410915, 0.9132726385430457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 92}], {
             RGBColor[
             0.9098968965985521, 0.8819348091936365, 0.6399273472719503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 8}], {
             RGBColor[
             0.8984795700817574, 0.9197247987621473, 0.9028117582444901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 9}], {
             RGBColor[
             0.8511965723730192, 0.8842860473257512, 0.9856422835461995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 21}], {
             RGBColor[
             0.6689727280627458, 0.7396116365542597, 0.9688126224878449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 22}], {
             RGBColor[
             0.6410972083980292, 0.7169810339125926, 0.9666181594684454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 23}], {
             RGBColor[
             0.8843060313747604, 0.9100310244384888, 0.9660699952723302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 28}], {
             RGBColor[
             0.8206049211953912, 0.8598930950649606, 0.9827244245473878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 30}], {
             RGBColor[
             0.8795944024832532, 0.9065170993257868, 0.9740455539960278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 34}], {
             RGBColor[
             0.5900348682827428, 0.6733341095514132, 0.9632040609089181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 36}], {
             RGBColor[
             0.6190458191767806, 0.6984619370830396, 0.9650526130465096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 49}], {
             RGBColor[
             0.8875770226920072, 0.9124705244071347, 0.9605330601833995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 55}], {
             RGBColor[
             0.8985617395534793, 0.9197587779503634, 0.9014499974502815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 62}], {
             RGBColor[
             0.49320819023262086`, 0.5774650541284105, 0.9574738265468168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 69}], {
             RGBColor[
             0.9007787905541607, 0.9196284570831544, 0.7885925418970945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 74}], {
             RGBColor[
             0.6092530415466105, 0.6899799252991012, 0.9644286259153284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 87}], {
             RGBColor[
             0.5468406913420704, 0.6338362132914157, 0.9605281181428247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 95}], {
             RGBColor[
             0.5361959120418599, 0.6226478753289055, 0.9599219137092174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 96}], {
             RGBColor[
             0.9005414026862489, 0.9191207084372861, 0.7627543374629948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 99}], {
             RGBColor[
             0.7476255460410153, 0.8027700258226227, 0.9754799855375658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 22}], {
             RGBColor[
             0.7320873980145448, 0.7871697244179188, 0.8879832646193021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 25}], {
             RGBColor[
             0.9235170950101663, 0.9395880521563387, 0.9052266591939555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 31}], {
             RGBColor[
             0.617303975846405, 0.6824498250428855, 0.8807242464143774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 34}], {
             RGBColor[
             0.6810250578992585, 0.7435228000567393, 0.8845691660597748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 35}], {
             RGBColor[
             0.9918914335433038, 0.9900790629705953, 0.7232859409638168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 36}], {
             RGBColor[
             0.7100360087932962, 0.7686506275883658, 0.8864177181973663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 49}], {
             RGBColor[
             0.978567212308523, 0.9826592149124609, 0.8818981653342561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 50}], {
             RGBColor[
             0.825235321772712, 0.8625058353062163, 0.8955114560794608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 54}], {
             RGBColor[
             0.6246936404787584, 0.6902168311032877, 0.8811450768831608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 55}], {
             RGBColor[
             0.989551929169995, 0.9899474684556896, 0.8228151026011382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 59}], {
             RGBColor[
             0.923243908889188, 0.9393702209589103, 0.9052006024578605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 69}], {
             RGBColor[
             0.9917689801706764, 0.9898171475884806, 0.7099576470479512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.6246936404787584, 0.6902168311032877, 0.8811450768831608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 87}], {
             RGBColor[
             0.637830880958586, 0.7040249037967419, 0.8818932232936814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 96}], {
             RGBColor[
             0.9915315923027646, 0.9893093989426123, 0.6841194426138515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 99}], {
             RGBColor[
             0.838615735657531, 0.8729587163279489, 0.8968450906884224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.7139362612226139, 0.7753815300491653, 0.9731071567259052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 21}], {
             RGBColor[
             0.7126799199705234, 0.7743615756231897, 0.9730082529404109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 22}], {
             RGBColor[
             0.6848044003058067, 0.7517309729815227, 0.9708137899210114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 23}], {
             RGBColor[
             0.928013223282538, 0.9447809635074189, 0.9702656257248963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 28}], {
             RGBColor[
             0.8643121131031687, 0.8946430341338907, 0.9869200549999539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 29}], {
             RGBColor[
             0.6672665072363301, 0.7371212396637219, 0.9695358394827387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 30}], {
             RGBColor[
             0.9233015943910305, 0.9412670383947169, 0.9782411844485939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 36}], {
             RGBColor[
             0.6627530110845581, 0.7332118761519697, 0.9692482434990757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 55}], {
             RGBColor[
             0.9422689314612568, 0.9545087170192935, 0.9056456279028475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 62}], {
             RGBColor[
             0.5369153821403984, 0.6122149931973406, 0.9616694569993828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 64}], {
             RGBColor[
             0.5990795395366364, 0.6775534640560124, 0.965209613799469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 74}], {
             RGBColor[
             0.652960233454388, 0.7247298643680313, 0.9686242563678944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 86}], {
             RGBColor[
             0.5531236361971168, 0.6292508958736139, 0.9625924930899498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 95}], {
             RGBColor[
             0.5799031039496374, 0.6573978143978356, 0.9641175441617835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 96}], {
             RGBColor[
             0.9442485945940264, 0.9538706475062162, 0.7669499679155609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 12}], {
             RGBColor[
             0.8490351306574435, 0.8817736219182681, 0.9284998079339322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 17}], {
             RGBColor[
             0.6264499995239112, 0.7065483601236583, 0.9644678314289257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 48}], {
             RGBColor[
             0.6579013774671713, 0.7320820056064266, 0.9669437991108127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 52}], {
             RGBColor[
             0.8259746863334378, 0.8648418368917743, 0.9794765520635618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 67}], {
             RGBColor[
             0.6396836743009136, 0.7172920534778836, 0.9655096347839194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 68}], {
             RGBColor[
             0.7706023463600542, 0.820791995997595, 0.9777509069879851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 73}], {
             RGBColor[
             0.852922333028789, 0.881905412797908, 0.7568133775633169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 84}], {
             RGBColor[
             0.8255459237351184, 0.8645220664479818, 0.9802023353033211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 97}], {
             RGBColor[
             0.8516659333669498, 0.8828615264471946, 0.8849005987382463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 21}], {
             RGBColor[
             0.5317124169123406, 0.6307071192776738, 0.9562774956675506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 29}], {
             RGBColor[
             0.4862990041781473, 0.5934667833182059, 0.9528050822098784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 30}], {
             RGBColor[
             0.7423340913328478, 0.7976125820492009, 0.9615104271757335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 46}], {
             RGBColor[
             0.5430386691562062, 0.6399022810910928, 0.9571691397336168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 49}], {
             RGBColor[
             0.750316711541602, 0.8035660071305488, 0.9479979333631052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 58}], {
             RGBColor[
             0.6992381964544587, 0.7636616921713781, 0.9717052421872012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 64}], {
             RGBColor[
             0.41811203647845363`, 0.5338990077104964, 0.9484788565266087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 83}], {
             RGBColor[
             0.677014295188534, 0.7459409565536592, 0.9695855066449465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 86}], {
             RGBColor[
             0.37215613313893403`, 0.48559643952809795`, 0.9458617358170894]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 13}], {
             RGBColor[
             0.82239115968923, 0.8609591492962203, 0.9258441859098856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 17}], {
             RGBColor[
             0.7632119156931905, 0.813169466316062, 0.9210112438481586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 68}], {
             RGBColor[
             0.9073642625293334, 0.9274131021899987, 0.934294319407218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 73}], {
             RGBColor[
             0.9896842491980683, 0.9885265189903117, 0.7133567899825497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 84}], {
             RGBColor[
             0.9623078399043976, 0.9711431726403856, 0.936745747722554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 97}], {
             RGBColor[
             0.9884278495362291, 0.9894826326395985, 0.8414440111574792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 16}], {
             RGBColor[
             0.481042572194432, 0.5847155658986936, 0.9536088064102144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 19}], {
             RGBColor[
             0.6831923953052683, 0.7524343587577742, 0.9690578912342546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 57}], {
             RGBColor[
             0.7056562391021404, 0.7699832842634269, 0.9712968772473711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 58}], {
             RGBColor[
             0.7622464536481117, 0.8145599405604378, 0.976839618193982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 80}], {
             RGBColor[
             0.49728330974009827`, 0.5993044996037229, 0.9546245380216611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 81}], {
             RGBColor[
             0.823109889322378, 0.861256362470036, 0.913932975875958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 85}], {
             RGBColor[
             0.7645410908505791, 0.33392585682725623`, 0.4316937171555355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 100}], {
             RGBColor[
             0.7680308398560985, 0.6341190347897409, 0.592893515639682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 15}], {
             RGBColor[
             0.45043041086375185`, 0.5639684406360264, 0.9500859842259839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 20}], {
             RGBColor[
             0.6585926406098729, 0.7297254334970711, 0.9689292586967275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 39}], {
             RGBColor[
             0.710210897201458, 0.7671393898788359, 0.80839530616958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 40}], {
             RGBColor[
             0.38026674444901454`, 0.5037896741045987, 0.9454512385929801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 44}], {
             RGBColor[
             0.690816163797954, 0.7548974630845007, 0.9539000841146675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 72}], {
             RGBColor[
             0.6416250156420291, 0.7161959099216227, 0.9673108714801169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 75}], {
             RGBColor[
             0.687370440534468, 0.7523276483164469, 0.9597327948111907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 76}], {
             RGBColor[
             0.6524740241295892, 0.7248466148011129, 0.9683456595946847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 78}], {
             RGBColor[
             0.458700916136358, 0.5706828093983447, 0.9507370686969026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 90}], {
             RGBColor[
             0.5506536308359393, 0.6448246240750921, 0.9583242995649965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 92}], {
             RGBColor[
             0.692085116431884, 0.7073751306550174, 0.6207831758679071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 93}], {
             RGBColor[
             0.39468194459530137`, 0.5162753959422863, 0.9463697623994405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 94}], {
             RGBColor[
             0.7095034737154126, 0.7656262825736706, 0.7313966254252124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 98}], {
             RGBColor[
             0.5022926176682019, 0.6060725164856704, 0.9541687671231535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 16}], {
             RGBColor[
             0.38913754630131586`, 0.5103576188948149, 0.9461995709190604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 19}], {
             RGBColor[
             0.5912873694121522, 0.6780764117538955, 0.9616486557431005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 39}], {
             RGBColor[
             0.7349557071032111, 0.7879786257168209, 0.8101360024278943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 40}], {
             RGBColor[
             0.40501155435076763`, 0.5246289099425837, 0.9471919348512945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 44}], {
             RGBColor[
             0.715560973699707, 0.7757366989224855, 0.9556407803729818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 46}], {
             RGBColor[
             0.5141419004567431, 0.6164425824762738, 0.9548942802492435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 72}], {
             RGBColor[
             0.6663698255437822, 0.7370351457596076, 0.9690515677384313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 76}], {
             RGBColor[
             0.6772188340313423, 0.7456858506390978, 0.970086355852999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 83}], {
             RGBColor[
             0.6481175264890708, 0.7224812579388402, 0.9673106471605732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 90}], {
             RGBColor[
             0.5753984407376924, 0.6656638599130771, 0.960064995823311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 92}], {
             RGBColor[
             0.716829926333637, 0.7282143664930023, 0.6225238721262215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 94}], {
             RGBColor[
             0.7342482836171655, 0.7864655184116555, 0.7331373216835267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 98}], {
             RGBColor[
             0.527037427569955, 0.6269117523236554, 0.9559094633814678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 100}], {
             RGBColor[
             0.6761258139629824, 0.5597610877858622, 0.585484280148528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 19}], {
             RGBColor[
             0.5052496949479632, 0.6036263541746991, 0.9560215461778626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 34}], {
             RGBColor[
             0.3378401139686854, 0.4665198360808118, 0.9427669650390127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 39}], {
             RGBColor[
             0.648918032639022, 0.7135285681376244, 0.8045088928626565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 44}], {
             RGBColor[
             0.629523299235518, 0.7012866413432892, 0.950013670807744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 49}], {
             RGBColor[
             0.6353822683779498, 0.7056562509365334, 0.940095964313494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 50}], {
             RGBColor[
             0.4820503778421389, 0.5855028713302888, 0.9537092550586985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 57}], {
             RGBColor[
             0.5277135387448352, 0.6211752796803518, 0.9582605321909792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 58}], {
             RGBColor[
             0.5843037532908066, 0.6657519359773627, 0.9638032731375901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 59}], {
             RGBColor[
             0.5800589649586149, 0.6623672569829828, 0.9633984014370983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 79}], {
             RGBColor[
             0.4463256450440801, 0.55678549374868, 0.950701627538999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 80}], {
             RGBColor[
             0.3193406093827931, 0.4504964950206479, 0.9415881929652692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 81}], {
             RGBColor[
             0.6451671889650727, 0.7124483578869609, 0.9008966308195661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 82}], {
             RGBColor[
             0.2815086965481853, 0.4132138671273603, 0.9393428758623987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 90}], {
             RGBColor[
             0.4893607662735034, 0.5912138023338807, 0.9544378862580729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 94}], {
             RGBColor[
             0.6482106091529766, 0.7120154608324591, 0.7275102121182888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 98}], {
             RGBColor[
             0.4409997531057659, 0.5524616947444589, 0.9502823538162299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 100}], {
             RGBColor[
             0.5900881394987934, 0.4853110302066658, 0.57985717058329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 48}], {
             RGBColor[
             0.5720781625029181, 0.6634778500042207, 0.9594552350250392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 52}], {
             RGBColor[
             0.7401514713691847, 0.7962376812895682, 0.9719879879777883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 67}], {
             RGBColor[
             0.5538604593366605, 0.6486878978756776, 0.9580210706981458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 68}], {
             RGBColor[
             0.6847791313958012, 0.752187840395389, 0.9702623429022116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 73}], {
             RGBColor[
             0.7670991180645359, 0.8133012571957019, 0.7493248134775434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 84}], {
             RGBColor[
             0.7397227087708652, 0.7959179108457759, 0.9727137712175477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 97}], {
             RGBColor[
             0.7658427184026968, 0.8142573708449887, 0.8774120346524729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 24}], {
             RGBColor[
             0.6926301234219451, 0.7592160552198077, 0.9704027135371676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 64}], {
             RGBColor[
             0.5423725917820936, 0.6326480169177855, 0.9597182891737227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 86}], {
             RGBColor[
             0.49641668844257403`, 0.5843454487353871, 0.9571011684642035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 34}], {
             RGBColor[
             0.5399899370795218, 0.6342386289398925, 0.9582160498630528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 44}], {
             RGBColor[
             0.8316731223463543, 0.8690054342023698, 0.9654627556317841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 49}], {
             RGBColor[
             0.8375320914887862, 0.873375043795614, 0.9555450491375341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 50}], {
             RGBColor[
             0.6842002009529753, 0.7532216641893694, 0.9691583398827388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 57}], {
             RGBColor[
             0.7298633618556716, 0.7888940725394324, 0.9737096170150192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 58}], {
             RGBColor[
             0.7864535764016429, 0.8334707288364434, 0.9792523579616301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 79}], {
             RGBColor[
             0.6484754681549165, 0.7245042866077607, 0.9661507123630392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 80}], {
             RGBColor[
             0.5214904324936294, 0.6182152878797285, 0.9570372777893094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 81}], {
             RGBColor[
             0.8473170120759091, 0.8801671507460416, 0.9163457156436061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 85}], {
             RGBColor[
             0.7806791726862665, 0.3465330490112599, 0.43330221033396765`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 90}], {
             RGBColor[
             0.6915105893843397, 0.7589325951929613, 0.9698869710821132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 94}], {
             RGBColor[
             0.850360432263813, 0.8797342536915397, 0.742959296942329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 100}], {
             RGBColor[
             0.7922379626096296, 0.6530298230657464, 0.5953062554073303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 27}], {
             RGBColor[
             0.9182066951748877, 0.8678149548342935, 0.6320238557028317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 32}], {
             RGBColor[
             0.9424204540624017, 0.9522437734229485, 0.7530625799060642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 37}], {
             RGBColor[
             0.8224716940145711, 0.8618184400910816, 0.9827865574754113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 43}], {
             RGBColor[
             0.874265466899135, 0.6273221587510223, 0.469575101354216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 47}], {
             RGBColor[
             0.9405858439703684, 0.9531593931013953, 0.9051691601566844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 60}], {
             RGBColor[
             0.7803711069683852, 0.8289291415142886, 0.9785903644110022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 72}], {
             RGBColor[
             0.8745320552899032, 0.9027921386206523, 0.9878948422091748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 76}], {
             RGBColor[
             0.8853810637774633, 0.9114428435001425, 0.9889296303237425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 83}], {
             RGBColor[
             0.8562797562351918, 0.8882382507998849, 0.9861539216313167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 89}], {
             RGBColor[
             0.9400099968088299, 0.9529212655015021, 0.9147124378680604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 92}], {
             RGBColor[
             0.924992156079758, 0.893971359354047, 0.641367146596965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 22}], {
             RGBColor[
             0.5025805559955334, 0.6070565622100311, 0.9539841288626569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 29}], {
             RGBColor[
             0.48504266292605674`, 0.5924468288922303, 0.9527061784243841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 30}], {
             RGBColor[
             0.7410777500807573, 0.7965926276232254, 0.9614115233902394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.48052916677428476`, 0.5885374653804781, 0.9524185824407211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 46}], {
             RGBColor[
             0.5417823279041156, 0.6388823266651174, 0.9570702359481227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 49}], {
             RGBColor[
             0.7490603702895113, 0.8025460527045732, 0.947899029577611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 55}], {
             RGBColor[
             0.7600450871509834, 0.809834306247802, 0.888815966844493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 58}], {
             RGBColor[
             0.6979818552023682, 0.7626417377454026, 0.9716063384017071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 62}], {
             RGBColor[
             0.35469153783012497`, 0.46754058242584906`, 0.9448397959410282]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 64}], {
             RGBColor[
             0.41685569522636307`, 0.5328790532845207, 0.9483799527411144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 83}], {
             RGBColor[
             0.6757579539364433, 0.7449210021276836, 0.9694866028594522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 86}], {
             RGBColor[
             0.3708997918868434, 0.48457648510212237`, 0.9457628320315952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 23}], {
             RGBColor[
             0.717913859307548, 0.7774759500942603, 0.9512415016471422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 30}], {
             RGBColor[
             0.7132022304160406, 0.7739620249815583, 0.9592170603708399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 34}], {
             RGBColor[
             0.42364269621553036`, 0.5407790352071846, 0.9483755672837302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 36}], {
             RGBColor[
             0.4526536471095681, 0.5659068627388111, 0.9502241194213216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 49}], {
             RGBColor[
             0.7211848506247948, 0.7799154500629062, 0.9457045665582114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 50}], {
             RGBColor[
             0.5678529600889839, 0.6597620704566616, 0.959317857303416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 55}], {
             RGBColor[
             0.7321695674862668, 0.7872037036061349, 0.8866215038250935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 58}], {
             RGBColor[
             0.6701063355376515, 0.7400111351037355, 0.9694118753823076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 59}], {
             RGBColor[
             0.6658615472054599, 0.7366264561093556, 0.9690070036818158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 62}], {
             RGBColor[
             0.3268160181654084, 0.444909979784182, 0.9426453329216287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 69}], {
             RGBColor[
             0.7343866184869483, 0.7870733827389259, 0.7737640482719065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 87}], {
             RGBColor[
             0.3804485192748579, 0.5012811389471872, 0.9456996245176367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 95}], {
             RGBColor[
             0.36980373997464744`, 0.490092800984677, 0.9450934200840295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 96}], {
             RGBColor[
             0.7341492306190365, 0.7865656340930576, 0.7479258438378069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 99}], {
             RGBColor[
             0.5812333739738029, 0.6702149514783942, 0.9606514919123779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 28}], {
             RGBColor[
             0.8974215721049099, 0.9203880112466283, 0.9673477667260846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 36}], {
             RGBColor[
             0.6958624700862994, 0.7589568532647073, 0.9496759552252063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 55}], {
             RGBColor[
             0.975378390462998, 0.980253694132031, 0.8860733396289783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 62}], {
             RGBColor[
             0.5700248411421396, 0.6379599703100782, 0.9420971687255135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 74}], {
             RGBColor[
             0.6860696924561293, 0.7504748414807689, 0.9490519680940251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 95}], {
             RGBColor[
             0.6130125629513787, 0.6831427915105732, 0.9445452558879142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 96}], {
             RGBColor[
             0.9773580535957678, 0.9796156246189538, 0.7473776796416916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 86}], {
             RGBColor[
             0.407556943092808, 0.5143364118369672, 0.9486486172540981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 31}], {
             RGBColor[
             0.5513513111582983, 0.6321243879317509, 0.9617740422129861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 54}], {
             RGBColor[
             0.5587409757906516, 0.639891393992153, 0.9621948726817695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 69}], {
             RGBColor[
             0.9258163154825696, 0.9394917104773459, 0.7910074428465599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 87}], {
             RGBColor[
             0.5718782162704793, 0.6536994666856072, 0.9629430190922901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 99}], {
             RGBColor[
             0.7726630709694242, 0.8226332792168142, 0.9778948864870312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 41}], {
             RGBColor[
             0.6963869472440727, 0.7568284964962089, 0.885548012064841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 42}], {
             RGBColor[
             0.6661270007319655, 0.639880215840323, 0.6043043797902744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 45}], {
             RGBColor[
             0.39155853532327356`, 0.5135700558179705, 0.9461707415225493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 53}], {
             RGBColor[
             0.630434282555966, 0.7065030593850741, 0.9665978078634497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 56}], {
             RGBColor[
             0.695314733571448, 0.7563851085879439, 0.9033173674202704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 57}], {
             RGBColor[
             0.577815670221208, 0.6650932508850147, 0.9614338818812356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 85}], {
             RGBColor[
             0.6793140449299575, 0.26399916790831474`, 0.4251183869114451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 88}], {
             RGBColor[
             0.5404504516204373, 0.6359032581279132, 0.9577096660889313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 32}], {
             RGBColor[
             0.9691274689795426, 0.9037370660611412, 0.39557320618311054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 37}], {
             RGBColor[
             0.849178708931712, 0.8133117327292743, 0.6252971837524577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 43}], {
             RGBColor[
             0.8920701435105621, 0.5949843538431507, 0.23124885220558022`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 47}], {
             RGBColor[
             0.9672928588875092, 0.904652685739588, 0.5476797864337306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 60}], {
             RGBColor[
             0.8070781218855261, 0.7804224341524815, 0.6211009906880485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 72}], {
             RGBColor[
             0.9012390702070441, 0.854285431258845, 0.630405468486221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 89}], {
             RGBColor[
             0.9667170117259707, 0.904414558139695, 0.5572230641451068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 30}], {
             RGBColor[
             0.8927099432134027, 0.9168740861339264, 0.9753233254497823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 36}], {
             RGBColor[
             0.6321613599069301, 0.7088189238911791, 0.966330384500264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 62}], {
             RGBColor[
             0.5063237309627704, 0.5878220409365501, 0.9587515980005712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 64}], {
             RGBColor[
             0.5684878883590084, 0.6531605117952217, 0.9622917548006573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 74}], {
             RGBColor[
             0.6223685822767601, 0.7003369121072408, 0.9657063973690829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 95}], {
             RGBColor[
             0.5493114527720094, 0.633004862137045, 0.9611996851629719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 96}], {
             RGBColor[
             0.9136569434163985, 0.9294776952454257, 0.7640321089167493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 30}], {
             RGBColor[
             0.6956643373465641, 0.7593522916637575, 0.9579391099325669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 39}], {
             RGBColor[
             0.7171827218163904, 0.7731780339461964, 0.808839544669101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 46}], {
             RGBColor[
             0.49636891516992243`, 0.6016419907056494, 0.9535978224904502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 58}], {
             RGBColor[
             0.6525684424681749, 0.7254014017859347, 0.9681339249440346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 64}], {
             RGBColor[
             0.3714422824921698, 0.4956387173250529, 0.9449075392834421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 83}], {
             RGBColor[
             0.6303445412022501, 0.7076806661682158, 0.96601418940178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 86}], {
             RGBColor[
             0.3254863791526502, 0.4473361491426545, 0.9422904185739229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 36}], {
             RGBColor[
             0.691150841194792, 0.7554429281520053, 0.9576515139489039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 46}], {
             RGBColor[
             0.752404002324623, 0.8057877894366445, 0.9623031674563055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 58}], {
             RGBColor[
             0.9086035296228754, 0.9295472005169297, 0.9768392699098899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 62}], {
             RGBColor[
             0.5653132122506322, 0.6344460451973762, 0.9500727274492111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 64}], {
             RGBColor[
             0.6274773696468703, 0.6997845160560479, 0.9536128842492972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 86}], {
             RGBColor[
             0.5815214663073507, 0.6514819478736495, 0.9509957635397781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 34}], {
             RGBColor[
             0.3088592740473905, 0.4360591358321514, 0.9411165490788055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 35}], {
             RGBColor[
             0.6197256496914357, 0.6826153987460073, 0.7798333239828474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 50}], {
             RGBColor[
             0.4530695379208439, 0.5550421710816283, 0.9520588390984914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 54}], {
             RGBColor[
             0.25252785662689037`, 0.3827531668786998, 0.9376924599021915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 59}], {
             RGBColor[
             0.5510781250373199, 0.6319065567343224, 0.9617479854768911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 63}], {
             RGBColor[
             0.6193843980462164, 0.681885495982717, 0.7426901883617569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 69}], {
             RGBColor[
             0.6196031963188083, 0.6823534833638927, 0.7665050300669818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 70}], {
             RGBColor[
             0.3104554543538021, 0.4374416669872102, 0.9412182562764833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 82}], {
             RGBColor[
             0.25252785662689037`, 0.3827531668786998, 0.9376924599021915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 87}], {
             RGBColor[
             0.26566509710671804`, 0.39656123957215395`, 0.938440606312712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 99}], {
             RGBColor[
             0.46644995180566295`, 0.565495052103361, 0.9533924737074532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 37}], {
             RGBColor[
             0.8733924678192259, 0.8977405513179293, 0.7463359079556902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 43}], {
             RGBColor[
             0.9082126494355715, 0.6512702329022542, 0.31194133500773524`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 47}], {
             RGBColor[
             0.9915066177750231, 0.989081504328243, 0.6687185106369632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 48}], {
             RGBColor[
             0.7984353841566174, 0.8385886900683925, 0.7392715665466345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 60}], {
             RGBColor[
             0.83129188077304, 0.8648512527411365, 0.742139714891281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 72}], {
             RGBColor[
             0.9254528290945581, 0.9387142498475001, 0.7514441926894536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 89}], {
             RGBColor[
             0.9909307706134847, 0.98884337672835, 0.6782617883483393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 63}], {
             RGBColor[
             0.6945931249761694, 0.7529084916032946, 0.7472670905805976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 66}], {
             RGBColor[
             0.3621267202927869, 0.48807769692459857`, 0.9442953722943388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 70}], {
             RGBColor[
             0.38566418128375524`, 0.5084646626077879, 0.9457951584953238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 91}], {
             RGBColor[
             0.4723871779518262, 0.5809758343775775, 0.9520405445310196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 35}], {
             RGBColor[
             0.6834467317442892, 0.7436883737598611, 0.7836782436282448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 36}], {
             RGBColor[
             0.40159130699428175`, 0.5222599383776316, 0.9468100208617942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 49}], {
             RGBColor[
             0.6701225105095083, 0.7362685257017267, 0.9422904679986841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 50}], {
             RGBColor[
             0.5167906199736975, 0.6161151460954821, 0.9559037587438888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 54}], {
             RGBColor[
             0.31624893867974385`, 0.44382614189255354`, 0.9415373795475889]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 55}], {
             RGBColor[
             0.6811072273709804, 0.7435567792449554, 0.8832074052655663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 58}], {
             RGBColor[
             0.6190439954223652, 0.6963642107425561, 0.9659977768227802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 59}], {
             RGBColor[
             0.6147992070901734, 0.6929795317481762, 0.9655929051222885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 69}], {
             RGBColor[
             0.6833242783716619, 0.7434264583777465, 0.7703499497123791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 81}], {
             RGBColor[
             0.6799074310966313, 0.7430606326521543, 0.9030911345047562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 82}], {
             RGBColor[
             0.31624893867974385`, 0.44382614189255354`, 0.9415373795475889]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 87}], {
             RGBColor[
             0.3293861791595715, 0.4576342145860077, 0.9422855259581093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 99}], {
             RGBColor[
             0.5301710338585165, 0.6265680271172147, 0.9572373933528505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 100}], {
             RGBColor[
             0.6248283816303519, 0.5159233049718591, 0.5820516742684803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 49}], {
             RGBColor[
             0.9809888861535536, 0.9828247886155828, 0.7810072429027262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 50}], {
             RGBColor[
             0.8276569956177426, 0.8626714090093381, 0.7946205336479308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 54}], {
             RGBColor[
             0.6271153143237891, 0.6903824048064096, 0.7802541544516308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 59}], {
             RGBColor[
             0.9256655827342186, 0.9395357946620322, 0.8043096800263305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 63}], {
             RGBColor[
             0.9939718557431151, 0.9895147339104268, 0.5852518829111963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 69}], {
             RGBColor[
             0.994190654015707, 0.9899827212916024, 0.6090667246164212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 70}], {
             RGBColor[
             0.6850429120507009, 0.74507090491492, 0.7837799508259226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 82}], {
             RGBColor[
             0.6271153143237891, 0.6903824048064096, 0.7802541544516308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 87}], {
             RGBColor[
             0.6402525548036168, 0.7041904774998637, 0.7810023008621514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 99}], {
             RGBColor[
             0.8410374095025617, 0.8731242900310707, 0.7959541682568925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 55}], {
             RGBColor[
             0.7101181782650182, 0.7686846067765819, 0.8850559574031577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 62}], {
             RGBColor[
             0.3047646289441598, 0.426390882954629, 0.9410797864996929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 74}], {
             RGBColor[
             0.42080948025814946`, 0.5389057541253197, 0.9480345858682045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 95}], {
             RGBColor[
             0.34775235075339883`, 0.471573704155124, 0.9435278736620936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 96}], {
             RGBColor[
             0.7120978413977879, 0.7680465372635046, 0.746360297415871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 99}], {
             RGBColor[
             0.5591819847525543, 0.6516958546488412, 0.9590859454904419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 47}], {
             RGBColor[
             0.8715578577271925, 0.8986561709963762, 0.8984424882063105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 72}], {
             RGBColor[
             0.8055040690467274, 0.8482889165156332, 0.9811681702588009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 76}], {
             RGBColor[
             0.8163530775342875, 0.8569396213951234, 0.9822029583733685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 89}], {
             RGBColor[
             0.870982010565654, 0.898418043396483, 0.9079857659176864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 39}], {
             RGBColor[
             0.6404640978299082, 0.7046429466428203, 0.8040274537817531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 51}], {
             RGBColor[
             0.30002307656860105`, 0.43220137095415706`, 0.9404145350257849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 61}], {
             RGBColor[
             0.6363821336801151, 0.7034258095659873, 0.9059027149357175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 66}], {
             RGBColor[
             0.30744489847501477`, 0.4386297800578772, 0.9408874469548021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 77}], {
             RGBColor[
             0.44703396912910803`, 0.5553382067791997, 0.9509414750407028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 98}], {
             RGBColor[
             0.432545818296652, 0.5435760732496548, 0.9498009147353266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 46}], {
             RGBColor[
             0.7739223867944494, 0.8196135317190834, 0.8132036021928396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 51}], {
             RGBColor[
             0.6542951721796102, 0.7187079992709671, 0.804832405615522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 76}], {
             RGBColor[
             0.9369993203690485, 0.9488567998819073, 0.8283956777965951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 83}], {
             RGBColor[
             0.9078980128267771, 0.9256522071816498, 0.8256199691041692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 92}], {
             RGBColor[
             0.9766104126713432, 0.9313853157358118, 0.4808331940698175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 94}], {
             RGBColor[
             0.9940287699548718, 0.989636467654465, 0.5914466436271228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 98}], {
             RGBColor[
             0.7868179139076612, 0.8300827015664649, 0.8142187853250639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 41}], {
             RGBColor[
             0.6621588238171516, 0.7271818163393147, 0.8833670263068187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 44}], {
             RGBColor[
             0.6453973072849697, 0.7155579323910579, 0.951006034739978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 56}], {
             RGBColor[
             0.661086610144527, 0.7267384284310499, 0.9011363816622482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.6519986303829568, 0.7204811883488622, 0.9398317166358935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 75}], {
             RGBColor[
             0.6419515840214838, 0.7129881176230042, 0.9568387454365013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 76}], {
             RGBColor[
             0.6070551676166049, 0.6855070841076701, 0.9654516102199951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 78}], {
             RGBColor[
             0.4132820596233737, 0.531343278704902, 0.9478430193222132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 79}], {
             RGBColor[
             0.46219965309353184`, 0.5710567847964488, 0.9516939914712331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 90}], {
             RGBColor[
             0.5052347743229552, 0.6054850933816495, 0.9554302501903071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 92}], {
             RGBColor[
             0.6466662599188997, 0.6680355999615747, 0.6178891264932177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 93}], {
             RGBColor[
             0.3492630880823171, 0.4769358652488437, 0.9434757130247511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 44}], {
             RGBColor[
             0.972708243166091, 0.9782896053192166, 0.8918158718285061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 56}], {
             RGBColor[
             0.9883975460256482, 0.9894701013592087, 0.8419462187507762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 65}], {
             RGBColor[
             0.9793095662640782, 0.983212861277021, 0.8806415537244215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 79}], {
             RGBColor[
             0.7895105889746532, 0.8337884577246075, 0.8925038285597612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.8335332640746376, 0.8689882508991777, 0.896338517419437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 90}], {
             RGBColor[
             0.8325457102040765, 0.8682167663098082, 0.8962400872788352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 93}], {
             RGBColor[
             0.6765740239634385, 0.7396675381770024, 0.8842855501132791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 45}], {
             RGBColor[
             0.6543814012653666, 0.6297067679333493, 0.6035559605784885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 53}], {
             RGBColor[
             0.8932571484980589, 0.8226397715004528, 0.6239830269193889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 56}], {
             RGBColor[
             0.9581375995135409, 0.8725218207033227, 0.5607025864762096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 57}], {
             RGBColor[
             0.840638536163301, 0.7812299630003934, 0.6188191009371746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 80}], {
             RGBColor[
             0.6322656068012589, 0.6105511783406894, 0.6021467617114648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 85}], {
             RGBColor[
             0.8545292888913528, 0.34142364265190056`, 0.19670853294873786`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 88}], {
             RGBColor[
             0.8032733175625302, 0.7520399702432918, 0.6150948851448704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 60}], {
             RGBColor[
             0.8001797513728938, 0.5690604782964809, 0.46229319134436053`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 67}], {
             RGBColor[
             0.7661302848511069, 0.541692135095623, 0.45942498289666733`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 72}], {
             RGBColor[
             0.8629537169205724, 0.61830247636739, 0.46849617654314224`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 76}], {
             RGBColor[
             0.8701863892456125, 0.6240696129537168, 0.4691860352861874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 83}], {
             RGBColor[
             0.8507855175507649, 0.6085998844868783, 0.4673355628245702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 89}], {
             RGBColor[
             0.9066056779331902, 0.6517218942879566, 0.41970790698239935`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 92}], {
             RGBColor[
             0.896593784113809, 0.6124219568563198, 0.2374777128016691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 56}], {
             RGBColor[
             0.9716360294934663, 0.9778462174109517, 0.9095852271839355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 57}], {
             RGBColor[
             0.8541369661432263, 0.8865543597080224, 0.9677017416449006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 79}], {
             RGBColor[
             0.7727490724424713, 0.8221645737763507, 0.9601428369929206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 81}], {
             RGBColor[
             0.9715906163634639, 0.9778274379146316, 0.9103378402734875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 88}], {
             RGBColor[
             0.8167717475424555, 0.857364366950921, 0.9639775258525964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 90}], {
             RGBColor[
             0.8157841936718945, 0.8565928823615513, 0.9638790957119945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 92}], {
             RGBColor[
             0.957215679267839, 0.9191433889414766, 0.626337972014905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 93}], {
             RGBColor[
             0.6598125074312564, 0.7280436542287455, 0.9519245585464384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 94}], {
             RGBColor[
             0.9746340365513677, 0.9773945408601297, 0.7369514215722104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 100}], {
             RGBColor[
             0.9165115668971844, 0.7506901102343364, 0.5892983800372116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 53}], {
             RGBColor[
             0.6186886830893671, 0.6963296114781006, 0.9658493886516638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 85}], {
             RGBColor[
             0.6714836452855582, 0.2572168693036657, 0.4246194407702545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 88}], {
             RGBColor[
             0.5287048521538383, 0.6257298102209397, 0.9569612468771453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 51}], {
             RGBColor[
             0.4334813655331422, 0.5471719560304201, 0.9495906834368713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 64}], {
             RGBColor[
             0.42818194747022875`, 0.5420742150979398, 0.9492715968071805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 83}], {
             RGBColor[
             0.6870842061803091, 0.7541161639411027, 0.9703782469255184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 86}], {
             RGBColor[
             0.38222604413070915`, 0.49377164691554143`, 0.9466544760976614]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 94}], {
             RGBColor[
             0.7732149633084038, 0.8181004244139181, 0.736204921448472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 98}], {
             RGBColor[
             0.5660041072611932, 0.6585466583259179, 0.9589770631464131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 72}], {
             RGBColor[
             0.9236182190025246, 0.939629869525947, 0.9035507729400738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 89}], {
             RGBColor[
             0.9890961605214513, 0.9897589964067968, 0.8303683685989593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 52}], {
             RGBColor[
             0.7716028493124447, 0.8217713267723366, 0.9744639556596753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 60}], {
             RGBColor[
             0.6363860370626009, 0.7152740581597328, 0.9647993510515727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 67}], {
             RGBColor[
             0.5853118372799206, 0.674221543358446, 0.9604970383800328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 68}], {
             RGBColor[
             0.7162305093390612, 0.7777214858781574, 0.9727383105840985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 73}], {
             RGBColor[
             0.798550496007796, 0.8388349026784703, 0.7518007811594303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 84}], {
             RGBColor[
             0.7711740867141252, 0.8214515563285442, 0.9751897388994346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 89}], {
             RGBColor[
             0.7960249269030455, 0.8392661821469463, 0.9009214245086308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 50}], {
             RGBColor[
             0.8143327743829618, 0.8552515609512037, 0.9532327580183702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 55}], {
             RGBColor[
             0.9786493817802449, 0.982693194100677, 0.8805364045400476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 58}], {
             RGBColor[
             0.9165861498316296, 0.9355006255982776, 0.9633267760972615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 59}], {
             RGBColor[
             0.9123413614994378, 0.9321159466038977, 0.9629219043967698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 69}], {
             RGBColor[
             0.9808664327809262, 0.982562873233468, 0.7676789489868605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 81}], {
             RGBColor[
             0.9774495855058958, 0.9821970475078758, 0.9004201337792375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 82}], {
             RGBColor[
             0.6137910930890083, 0.6829625567482751, 0.9388663788220701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 99}], {
             RGBColor[
             0.8277131882677808, 0.8657044419729363, 0.9545663926273318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 100}], {
             RGBColor[
             0.9223705360396164, 0.7550597198275807, 0.5793806735429616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 54}], {
             RGBColor[
             0.46045920255319733`, 0.5628091771420305, 0.9524796695672748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 55}], {
             RGBColor[
             0.8253174912444339, 0.8625398144944324, 0.8941496952852521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 58}], {
             RGBColor[
             0.7632542592958187, 0.815347245992033, 0.9769400668424661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 59}], {
             RGBColor[
             0.7590094709636269, 0.8119625669976531, 0.9765351951419745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 69}], {
             RGBColor[
             0.8275345422451154, 0.8624094936272234, 0.7812922397320652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 82}], {
             RGBColor[
             0.46045920255319733`, 0.5628091771420305, 0.9524796695672748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 87}], {
             RGBColor[
             0.473596443033025, 0.5766172498354847, 0.9532278159777954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 99}], {
             RGBColor[
             0.67438129773197, 0.7455510623666917, 0.9681796833725365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 61}], {
             RGBColor[
             0.6502132080298171, 0.717490862194134, 0.9067076667694864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 66}], {
             RGBColor[
             0.32127597282471676`, 0.45269483268602395`, 0.941692398788571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 77}], {
             RGBColor[
             0.46086504347881, 0.5694032594073464, 0.9517464268744718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 98}], {
             RGBColor[
             0.446376892646354, 0.5576411258778016, 0.9506058665690955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 60}], {
             RGBColor[
             0.8044593459288674, 0.8480338894450804, 0.9773321040043217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 67}], {
             RGBColor[
             0.7533851461461871, 0.8069813746437935, 0.9730297913327819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 68}], {
             RGBColor[
             0.8843038182053278, 0.9104813171635049, 0.9852710635368477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 73}], {
             RGBColor[
             0.9666238048740625, 0.9715947339638179, 0.7643335341121795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 84}], {
             RGBColor[
             0.9392473955803918, 0.9542113876138918, 0.9877224918521837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 97}], {
             RGBColor[
             0.9653674052122234, 0.9725508476131046, 0.892420755287109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 80}], {
             RGBColor[
             0.5965728886252595, 0.6771740218854406, 0.9644401897846401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 85}], {
             RGBColor[
             0.8307341434406865, 0.3858388716817347, 0.43823748499752146`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 88}], {
             RGBColor[
             0.7675805993865308, 0.8186628137880431, 0.9773883132180458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 59}], {
             RGBColor[
             0.5584677896696733, 0.6396735627947245, 0.9621688159456745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 69}], {
             RGBColor[
             0.6269928609511617, 0.6901204894242949, 0.7669258605357652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 82}], {
             RGBColor[
             0.2599175212592437, 0.390520172939102, 0.9381132903709749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 87}], {
             RGBColor[
             0.2730547617390714, 0.4043282456325562, 0.9388614367814954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 99}], {
             RGBColor[
             0.47383961643801636`, 0.5732620581637632, 0.9538133041762366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 59}], {
             RGBColor[
             0.9233260783609099, 0.9394042001471264, 0.9038388416636519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 62}], {
             RGBColor[
             0.5842805493208585, 0.6476877238219528, 0.8774771709034648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 69}], {
             RGBColor[
             0.9918511496423983, 0.9898511267766967, 0.7085958862537426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 87}], {
             RGBColor[
             0.637913050430308, 0.704058882984958, 0.8805314624994728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 95}], {
             RGBColor[
             0.6272682711300975, 0.6928705450224478, 0.8799252580658656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 96}], {
             RGBColor[
             0.9916137617744866, 0.9893433781308285, 0.682757681819643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 99}], {
             RGBColor[
             0.8386979051292529, 0.8729926955161651, 0.895483329894214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 57}], {
             RGBColor[
             0.8698262690027835, 0.8977348557480145, 0.9178320885671707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 65}], {
             RGBColor[
             0.9782373525914534, 0.9827694733687561, 0.8984109090798509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 79}], {
             RGBColor[
             0.7884383753020284, 0.8333450698163427, 0.9102731839151905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 88}], {
             RGBColor[
             0.8324610504020127, 0.8685448629909129, 0.9141078727748664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 90}], {
             RGBColor[
             0.8314734965314516, 0.8677733784015433, 0.9140094426342645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 93}], {
             RGBColor[
             0.6755018102908137, 0.7392241502687376, 0.9020549054687086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 79}], {
             RGBColor[
             0.6709393119517885, 0.7420532121134134, 0.9683896983761557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 80}], {
             RGBColor[
             0.5439542762905014, 0.6357642133853811, 0.9592762638024259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 81}], {
             RGBColor[
             0.8697808558727811, 0.8977160762516943, 0.9185847016567227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 85}], {
             RGBColor[
             0.7956550685508479, 0.3582323326816951, 0.43479486767604525`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 88}], {
             RGBColor[
             0.7149619870517727, 0.7772530052879836, 0.9722243872358316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 90}], {
             RGBColor[
             0.7139744331812117, 0.776481520698614, 0.9721259570952296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 100}], {
             RGBColor[
             0.8147018064065017, 0.6705787485713991, 0.5975452414204467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 59}], {
             RGBColor[
             0.8612628464122947, 0.892211631644727, 0.9866292132208658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 80}], {
             RGBColor[
             0.6005444908364728, 0.680340869682392, 0.9648190047490368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 81}], {
             RGBColor[
             0.9263710704187526, 0.9422927325487052, 0.9241274426033336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 83}], {
             RGBColor[
             0.8432837334785616, 0.877875575021388, 0.9849143493791028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 100}], {
             RGBColor[
             0.871292020952473, 0.71515540486841, 0.6030879823670576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 69}], {
             RGBColor[
             0.9255431293615913, 0.9392738792799175, 0.7909813861104649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 82}], {
             RGBColor[
             0.5584677896696733, 0.6396735627947245, 0.9621688159456745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 87}], {
             RGBColor[
             0.571605030149501, 0.6534816354881787, 0.9629169623561951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 99}], {
             RGBColor[
             0.772389884848446, 0.8224154480193857, 0.9778688297509361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 67}], {
             RGBColor[
             0.6181683338963432, 0.7004841060311897, 0.9633651867246793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 72}], {
             RGBColor[
             0.7634034820005415, 0.8153996179388403, 0.9769719771943917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 73}], {
             RGBColor[
             0.8314069926242186, 0.8650974653512141, 0.7546689295040768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 89}], {
             RGBColor[
             0.8288814235194681, 0.8655287448196901, 0.9037895728532772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 77}], {
             RGBColor[
             0.797224100590324, 0.8406276980191767, 0.9172346067844044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 74}], {
             RGBColor[
             0.2949718513139897, 0.41790887117069075`, 0.9404557993685116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 95}], {
             RGBColor[
             0.2219147218092391, 0.35057682120049494`, 0.9359490871624008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 96}], {
             RGBColor[
             0.586260212453628, 0.6470496543088755, 0.7387815109161782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 99}], {
             RGBColor[
             0.43334435580839453`, 0.5306989716942122, 0.9515071589907491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 66}], {
             RGBColor[
             0.6611641994145131, 0.7239540364684403, 0.745137029003847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 70}], {
             RGBColor[
             0.6847016604054815, 0.7443410021516297, 0.7466368152048319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 82}], {
             RGBColor[
             0.6267740626785697, 0.6896525020431192, 0.7431110188305403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 91}], {
             RGBColor[
             0.7714246570735525, 0.8168521739214193, 0.7528822012405277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 74}], {
             RGBColor[
             0.35713600871022777`, 0.48324734202936237`, 0.9439959561685979]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 86}], {
             RGBColor[
             0.25729941145295654`, 0.38776837353494487`, 0.9379641928906532]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 75}], {
             RGBColor[
             0.9591023264684103, 0.9690191625607104, 0.954113272854104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 78}], {
             RGBColor[
             0.7304328020703003, 0.7873743236426081, 0.9451175467398159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 79}], {
             RGBColor[
             0.7793503955404584, 0.8270878297341551, 0.9489685188888359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 93}], {
             RGBColor[
             0.6664138305292436, 0.7329669101865499, 0.9407502404423539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 70}], {
             RGBColor[
             0.3522352557220989, 0.4795102074729335, 0.9436650969185733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 91}], {
             RGBColor[
             0.43895825239016983`, 0.5520213792427231, 0.949910482954269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 68}], {
             RGBColor[
             0.6980128061728035, 0.7629315337496143, 0.9713041462572052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 73}], {
             RGBColor[
             0.7803327928415383, 0.8240449505499272, 0.7503666168325369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 84}], {
             RGBColor[
             0.7529563835478676, 0.8066616042000012, 0.9737555745725412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 97}], {
             RGBColor[
             0.7790763931796991, 0.825001064199214, 0.8784538380074665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 73}], {
             RGBColor[
             0.9112514649006789, 0.9275448930696386, 0.7626078890366028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 84}], {
             RGBColor[
             0.8838750556070083, 0.9101615467197126, 0.985996846776607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 97}], {
             RGBColor[
             0.9099950652388398, 0.9285010067189254, 0.8906951102115322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 82}], {
             RGBColor[
             0.6269928609511617, 0.6901204894242949, 0.7669258605357652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 87}], {
             RGBColor[
             0.6401301014309895, 0.703928562117749, 0.7676740069462857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 99}], {
             RGBColor[
             0.8409149561299344, 0.8728623746489561, 0.7826258743410268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 82}], {
             RGBColor[
             0.31784511898615553`, 0.44520867304761247`, 0.9416390867452666]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 91}], {
             RGBColor[
             0.46249571338113826`, 0.5724083449259125, 0.951410269155254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 75}], {
             RGBColor[
             0.9715819221839017, 0.9766789230003987, 0.8592100843032537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 76}], {
             RGBColor[
             0.9366855057790229, 0.9491978894850648, 0.8678229490867476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 78}], {
             RGBColor[
             0.7429123977857917, 0.7950340840822965, 0.8502143581889656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 93}], {
             RGBColor[
             0.678893426244735, 0.7406266706262382, 0.8458470518915036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 76}], {
             RGBColor[
             0.8684134388096196, 0.8979133199246941, 0.9873112431071319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 89}], {
             RGBColor[
             0.9230423718409861, 0.9393917419260538, 0.9130940506514498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 92}], {
             RGBColor[
             0.9080245311119143, 0.8804418357785987, 0.6397487593803545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 94}], {
             RGBColor[
             0.9254428883954429, 0.9386929876972518, 0.7503622089376597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 84}], {
             RGBColor[
             0.966195042275743, 0.9712749635200255, 0.7650593173519389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 97}], {
             RGBColor[
             0.9923150519075745, 0.9896144235192383, 0.6697575807868641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 95}], {
             RGBColor[
             0.3379595731232288, 0.4630916923711857, 0.9429038865309125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 96}], {
             RGBColor[
             0.7023050637676178, 0.7595645254795663, 0.7457363102846899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 78}], {
             RGBColor[
             0.7203857557088272, 0.77988125291675, 0.9621245755404236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 93}], {
             RGBColor[
             0.6563667841677706, 0.7254738394606919, 0.9577572692429617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 92}], {
             RGBColor[
             0.9188735395994744, 0.8890925406580888, 0.6407835474949222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 93}], {
             RGBColor[
             0.6214703677628918, 0.6979928059453577, 0.9663701340264556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 94}], {
             RGBColor[
             0.936291896883003, 0.947343692576742, 0.7513969970522274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 93}], {
             RGBColor[
             0.42769725976966055`, 0.5438290005425895, 0.9487615431286736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 88}], {
             RGBColor[
             0.6335740933510177, 0.7128632193563118, 0.9646654825838514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 90}], {
             RGBColor[
             0.6325865394804566, 0.7120917347669422, 0.9645670524432495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 93}], {
             RGBColor[
             0.47661485323981867`, 0.5835425066341364, 0.9526125152776935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 100}], {
             RGBColor[
             0.7333139127057466, 0.6061889626397273, 0.5899863367684666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 81}], {
             RGBColor[
             0.6614079265107391, 0.7270372915919903, 0.9019123624310128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 85}], {
             RGBColor[
             0.6567397823094865, 0.24444647624189242`, 0.4236799748589053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 88}], {
             RGBColor[
             0.5065890576897307, 0.6065742206282797, 0.9555520480101216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 100}], {
             RGBColor[
             0.6063288770444596, 0.4998999639116951, 0.5808729021947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 85}], {
             RGBColor[
             0.8739575020310063, 0.4190810514861012, 0.39655226676176986`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 88}], {
             RGBColor[
             0.8324156372720104, 0.8685260834945927, 0.9148604858644185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 90}], {
             RGBColor[
             0.8314280834014494, 0.8677545989052231, 0.9147620557238165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 100}], {
             RGBColor[
             0.9321554566267394, 0.7618518267780082, 0.5401813400490336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 87}], {
             RGBColor[
             0.2730547617390714, 0.4043282456325562, 0.9388614367814954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 99}], {
             RGBColor[
             0.47383961643801636`, 0.5732620581637632, 0.9538133041762366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 92}], {
             RGBColor[
             0.8897722320572029, 0.8658879479578312, 0.6380078388024963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 94}], {
             RGBColor[
             0.9071905893407315, 0.9241390998764843, 0.7486212883598016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 98}], {
             RGBColor[
             0.6999797332935209, 0.7645853337884843, 0.9713934300577427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 97}], {
             RGBColor[
             0.9649386426139039, 0.9722310771693122, 0.8931465385268683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 88}], {
             RGBColor[
             0.7707449228170007, 0.338772337510294, 0.4323120571478424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 99}], {
             RGBColor[
             0.48697685691784404`, 0.5870701308572174, 0.954561450586757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 90}], {
             RGBColor[
             0.676609214580441, 0.7472915279415124, 0.9684017413029253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 100}], {
             RGBColor[
             0.777336587805731, 0.6413887558142977, 0.5938210256281424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 93}], {
             RGBColor[
             0.5196499744692419, 0.617970815219337, 0.9563487739967675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 94}], {
             RGBColor[
             0.8344715035893531, 0.8673217018507212, 0.7413756370225393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 100}], {
             RGBColor[
             0.77634903393517, 0.640617271224928, 0.5937225954875406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 93}], {
             RGBColor[
             0.6610814600651864, 0.6805213217992623, 0.618807650299678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 94}], {
             RGBColor[
             0.9759029891852977, 0.9298722084306466, 0.40383451332544995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 98}], {
             RGBColor[
             0.7686921331380869, 0.7703184423426463, 0.6266066550233911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 98}], {
             RGBColor[
             0.7861104904216156, 0.8285695942612994, 0.7372201045806963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 100}], {
             RGBColor[
             0.9351988768146431, 0.7614189297235063, 0.36679492134775643`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 96}], {
             RGBColor[
             0.6292479342628672, 0.6922324755093705, 0.7412295980785789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 99}], {
             RGBColor[
             0.8406775682620227, 0.8723546260030878, 0.7567876699069273]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.07669400150882427], {
             RGBColor[
             0.5332198962756418, 0.6319309589359732, 0.9563961699651087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.07669400150882427], {
             RGBColor[
             0.4751752207655049, 0.5848076764740113, 0.9518266804842983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.07669400150882427], {
             RGBColor[
             0.9226607733649183, 0.9411686719944197, 0.9924854023041836]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.07669400150882427], {
             RGBColor[
             0.9843052343773403, 0.987777825325021, 0.909766413326296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.07669400150882427], {
             RGBColor[
             0.4350583073627213, 0.5512473719964261, 0.9489425085315648]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.07669400150882427], {
             RGBColor[
             0.8613091612953351, 0.8922485618752796, 0.986633630775756]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.07669400150882427], {
             RGBColor[
             0.8074893804652417, 0.8495361082568211, 0.9814466530936334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.07669400150882427], {
             RGBColor[
             0.989469759698273, 0.9899134892674735, 0.8241768633953468]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.07669400150882427], {
             RGBColor[
             0.8949037642807967, 0.9190359863946813, 0.9898379139987655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.07669400150882427], {
             RGBColor[
             0.7122732144881643, 0.7751525157258643, 0.9719563955146993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.07669400150882427], {
             RGBColor[
             0.5329687581644311, 0.6317270737036493, 0.9563763994530449]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.07669400150882427], {
             RGBColor[
             0.9857970468267229, 0.9883947281106719, 0.885043220353165]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.07669400150882427], {
             RGBColor[
             0.6589852725517372, 0.7335235704817686, 0.9666451514666063]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.07669400150882427], {
             RGBColor[
             0.4256856009619988, 0.5431292047980415, 0.9483452879676696]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.07669400150882427], {
             RGBColor[
             0.4751752207655049, 0.5848076764740113, 0.9518266804842983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.07669400150882427], {
             RGBColor[
             0.30309987183712683`, 0.4359075613156186, 0.9405724613538224]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.07669400150882427], {
             RGBColor[
             0.5406267845596581, 0.6379442045214523, 0.9569792673431522]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.07669400150882427], {
             RGBColor[
             0.7814898687717111, 0.8292250921182276, 0.978855264747273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.07669400150882427], {
             RGBColor[
             0.7073995180587995, 0.7713451470337798, 0.9714706310019028]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.07669400150882427], {
             RGBColor[
             0.891499680257747, 0.9163216621961007, 0.9895132294257853]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.07669400150882427], {
             RGBColor[
             0.53045607566025, 0.6296871648516982, 0.9561785918820565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.07669400150882427], {
             RGBColor[
             0.47470503633081673`, 0.5844259595683641, 0.9517896658432574]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.07669400150882427], {
             RGBColor[
             0.9611226822842792, 0.9705259406201564, 0.9506933374510269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.07669400150882427], {
             RGBColor[
             0.603770378072179, 0.6892070183213879, 0.9619501623270622]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.07669400150882427], {
             RGBColor[
             0.8575644303220595, 0.889262615045204, 0.9862764549925642]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.07669400150882427], {
             RGBColor[
             0.4033041347898725, 0.5237435037249442, 0.9469191607343352]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.07669400150882427], {
             RGBColor[
             0.9449137100920286, 0.8193082474724862, 0.274534481979878]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.07669400150882427], {
             RGBColor[
             0.8337204619255407, 0.8702500818731002, 0.9840021960011424]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.07669400150882427], {
             RGBColor[
             0.4396292501918635, 0.5552064929327625, 0.9492337649667117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.07669400150882427], {
             RGBColor[
             0.9516994245012645, 0.9634980903947525, 0.9666444548984222]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.07669400150882427], {
             RGBColor[
             0.24513819199453699`, 0.3749861608182976, 0.9372716294334081]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.07669400150882427], {
             RGBColor[
             0.9933412278670565, 0.9881658846497963, 0.516611930386343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.07669400150882427], {
             RGBColor[
             0.39555564585444325`, 0.517032152059453, 0.9464254338710893]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.07669400150882427], {
             RGBColor[
             0.372580356100244, 0.4971321108460051, 0.9449614687242028]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.07669400150882427], {
             RGBColor[
             0.9943131073883344, 0.9902446366737171, 0.6223950185322868]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.07669400150882427], {
             RGBColor[
             0.4306022578883195, 0.5473877659092581, 0.9486585729993857]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.07669400150882427], {
             RGBColor[
             0.7534437077713952, 0.8073152179860624, 0.9760598855250374]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.07669400150882427], {
             RGBColor[
             0.28619200221889907`, 0.41813631832601034`, 0.9396095831920159]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.07669400150882427], {
             RGBColor[
             0.9947361934409173, 0.9911495749596304, 0.6684453243714904]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.07669400150882427], {
             RGBColor[
             0.3348478879360303, 0.46445014341115604`, 0.9425571892182907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.07669400150882427], {
             RGBColor[
             0.989469759698273, 0.9899134892674735, 0.8241768633953468]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.07669400150882427], {
             RGBColor[
             0.9289498666740584, 0.7560169279557016, 0.26168959884621357`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.07669400150882427], {
             RGBColor[
             0.8656483602198289, 0.482822407028483, 0.2096060373184313]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.07669400150882427], {
             RGBColor[
             0.955946726633909, 0.9666657213709597, 0.9594548802616655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.07669400150882427], {
             RGBColor[
             0.3798129358566747, 0.503396607910997, 0.9454223223107634]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.07669400150882427], {
             RGBColor[
             0.5531085801479814, 0.6480774884785364, 0.9579618800141888]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.07669400150882427], {
             RGBColor[
             0.9896720076829898, 0.9899971240066899, 0.8208250908875834]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.07669400150882427], {
             RGBColor[
             0.6035295404461782, 0.6890114954869889, 0.9619312027069261]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.07669400150882427], {
             RGBColor[
             0.9676646649187728, 0.9754049405574483, 0.9396194672731655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.07669400150882427], {
             RGBColor[
             0.6610008838471509, 0.7350981813449591, 0.9668460487635747]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.07669400150882427], {
             RGBColor[
             0.31385415091830304`, 0.4462664235823038, 0.9412194868595538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.07669400150882427], {
             RGBColor[
             0.9396761581787113, 0.9545311580576842, 0.9869967086124244]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.07669400150882427], {
             RGBColor[
             0.8575644303220595, 0.889262615045204, 0.9862764549925642]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.07669400150882427], {
             RGBColor[
             0.2599175212592437, 0.390520172939102, 0.9381132903709749]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.07669400150882427], {
             RGBColor[
             0.9896340986417169, 0.9899814476439057, 0.8214533418069296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.07669400150882427], {
             RGBColor[
             0.9873253323530234, 0.9890267134509437, 0.8597155741062056]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.07669400150882427], {
             RGBColor[
             0.7523272056525435, 0.8064429980450851, 0.9759486030281358]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.07669400150882427], {
             RGBColor[
             0.8655076347444863, 0.8955963106391069, 0.9870340849213576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.07669400150882427], {
             RGBColor[
             0.8570180580801029, 0.8888269526503472, 0.9862243415203742]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.07669400150882427], {
             RGBColor[
             0.6692425336790234, 0.7415366208324766, 0.9676674993962191]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.07669400150882427], {
             RGBColor[
             0.9865722651413311, 0.9887153008059644, 0.8721958466794191]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.07669400150882427], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.07669400150882427], {
             RGBColor[
             0.9936306040978957, 0.9887848311471364, 0.5481087472901057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.07669400150882427], {
             RGBColor[
             0.30325531479247614`, 0.4360709417173433, 0.9405813136001724]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.07669400150882427], {
             RGBColor[
             0.9691493728298833, 0.9765122332865684, 0.9371062440534963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.07669400150882427], {
             RGBColor[
             0.32869779473113053`, 0.4591232417897442, 0.9421653107175882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.07669400150882427], {
             RGBColor[
             0.5670941341136629, 0.6594315912299029, 0.9590628740531394]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.07669400150882427], {
             RGBColor[
             0.8289314782319441, 0.8664314762693257, 0.983545418461271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.07669400150882427], {
             RGBColor[
             0.9940682006430798, 0.9897208059094877, 0.5957384307005555]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.07669400150882427], {
             RGBColor[
             0.3757727167130673, 0.49989717315612286`, 0.9451648831195583]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.07669400150882427], {
             RGBColor[
             0.9941085642608661, 0.9918317541659452, 0.7472998669517956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.07669400150882427], {
             RGBColor[
             0.8575644303220595, 0.889262615045204, 0.9862764549925642]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.07669400150882427], {
             RGBColor[
             0.9935714515694137, 0.9886583098699516, 0.5416703596119345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.07669400150882427], {
             RGBColor[
             0.41101670262797935`, 0.5304237423413815, 0.9474105987370234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.07669400150882427], {
             RGBColor[
             0.9490552801069373, 0.9615260918348524, 0.9711203016547117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.07669400150882427], {
             RGBColor[
             0.8792624472971797, 0.9065640248041843, 0.9883460312216996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.07669400150882427], {
             RGBColor[
             0.607875936039317, 0.692540095232389, 0.9622733668893897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.07669400150882427], {
             RGBColor[
             0.4917162313107172, 0.5982364139986478, 0.9531288494261355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.07669400150882427], {
             RGBColor[
             0.5895514182510334, 0.6776634261817416, 0.9608307937241756]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.07669400150882427], {
             RGBColor[
             0.3355813469284593, 0.4650854287256772, 0.9426039245767159]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.07669400150882427], {
             RGBColor[
             0.9872345060930188, 0.9889891544583034, 0.8612208002853096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.07669400150882427], {
             RGBColor[
             0.2599175212592437, 0.390520172939102, 0.9381132903709749]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.07669400150882427], {
             RGBColor[
             0.8210598322126368, 0.8601548394036691, 0.9827946138368481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.07669400150882427], {
             RGBColor[
             0.9388186329820724, 0.9538916171700994, 0.9884482750919431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.07669400150882427], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.07669400150882427], {
             RGBColor[
             0.21134350811343688`, 0.3394658053525465, 0.935347072181134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.07669400150882427], {
             RGBColor[
             0.28619200221889907`, 0.41813631832601034`, 0.9396095831920159]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.07669400150882427], {
             RGBColor[
             0.677596768451002, 0.7480630125308821, 0.9685001714435273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.07669400150882427], {
             RGBColor[
             0.9885203133599129, 0.9895208688069036, 0.8399116463103354]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.07669400150882427], {
             RGBColor[
             0.67562166070988, 0.7465200433521428, 0.9683033111623235]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.07669400150882427], {
             RGBColor[
             0.5492187100492092, 0.6449195166957021, 0.9576556551909498]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.07669400150882427], {
             RGBColor[
             0.958484631901769, 0.8716210565119934, 0.29322106376814466`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.07669400150882427], {
             RGBColor[
             0.3636782882286039, 0.4894215870865313, 0.9443942368312115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.07669400150882427], {
             RGBColor[
             0.9933213464688263, 0.9881233603492996, 0.5144479628827552]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.07669400150882427], {
             RGBColor[
             0.2649024436184782, 0.39575964240098993`, 0.9383971743248015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.07669400150882427], {
             RGBColor[
             0.9935934249072562, 0.9887053086177512, 0.5440620218323563]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.07669400150882427], {
             RGBColor[
             0.9910586522457354, 0.9905705371685251, 0.7978448019617935]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.07669400150882427], {
             RGBColor[
             0.578899634374405, 0.6690158281732993, 0.9599922462786373]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.07669400150882427], {
             RGBColor[
             0.687761711616789, 0.7560039433884244, 0.9695133179814982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.07669400150882427], {
             RGBColor[
             0.8770764071604599, 0.5347144990977131, 0.2191418798127577]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100}, {
          Null, CompressedData["
1:eJwVxVmDagoAAOCTRmhBx9Jp1aDdVNSk6LRrVKZFCxnaeL///+3e+/J9769/
zBfw69ev5X/8//3x+5KpJwaZQX0A9jP9er8/ePjtef7C+rl77tGYg07fGTgJ
gmCJAeEgOSSPXJA78ognWMvyO387LxBFHfQVP7VP81Pn++936dq4tq+IzMqy
Jd/lh+wncJzAWXyAO/gLGeVG8mh0Hz1GPoihGIZjBOZgr4SCK4SSV1glvAz/
LH/iq/ZqvlqdkFQql5JTo9Q99QhLuERIrCTJkiJZko8d88fGUTkeX+AW3Wbs
ut23B7btxBftxXyxWC1Omc/656f9+8+fS2KP74l9ff+5H+yV/d4O99ie1OtZ
PR80UAMzSkbDSPfSVtpH+BSf41mel/kRf+cfvJ84E+fMuX7+PA/O+/PZRgq5
Qr5Q4AtKYVS4IOvUOrfm16P1+r5+oDqml/SGrhv6FayiVaxa7VeN6rbqhFVc
ZVVJ7amyqqiqpfqJA34gDuxhcFAO+8PhfLAPTtjETdaUzJ6pmkvTtEwficXy
sUJMiR1jF4SKUVSeKlA8JVMKNaKO1AUIA2mABSSgB6jAEjABC/BjIi4SIiWy
oiiJsqiIqngQTdEvloqNYruoF68AF+ZYjhM5ietxKrfkTM7ifFBABUzABUKo
CkJfGAgHwRac8Kwzmy1nP+gNu+E34ibc9JtxO96c2+31Pntfvv8AMJyGWZiD
eViEJbgHy7AKm7AFP2A/nky2k/PkIrlKnhIBFuABEbCBEIjBIFCCfXAI7MAJ
bgHooi7mVt2GK7i6a7hH1725L7SCVfBKvlLpVIzKseJWbpUXBEMIREEpKAcV
IBbiIRGSoRG0hizoDj0gP4JGsEgxUoo0InrEiFwjbqRVbJVaLb11BTfoprrZ
bAEtrEEarKU1VuM0UZO0niZrqqaZmqX5b+9vnbcZ+PW1+TK+tgATZmAmzTAs
wzES02NURmOWjMlYjB8ZFoeNYXs4nA/14Wp4BWuZWrVWE2r9ml1zwB2+I3bV
XW0n7Pq7wW5n75xdkPmof3x8fpw/7Gg8moy2o/PoIrqKnkKREBoqhkqhRqgV
+grpISN0DbnRZ/yZfM6fi+fqeXqGyAiJkmSRLJENskUOSZ00yCN5JV2IhmmE
pmg6RRdoluZpkZZomVZolR7RGm3Rd/pB+8gkNvk9oSa5SX5SmEzWkwvooV7V
q3mC1/e+vI1neFtv5zme60W7yW672x12591Fd9U9dZ+hbCRLZrPFbCnbyLay
w6yevYLT6rQ27U+nm+l2upt6wDg8ZsbvY248no2XY3P8E2tiTaqZbxaalWaz
05w0j81L89Z8vZXLlXKn/Lc8K3+XX/8C/Ovksg==
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[65, 78] -> 
             RGBColor[
              0.18290629963313676`, 0.3095764962165958, 0.9337276152272609], 
             UndirectedEdge[27, 32] -> 
             RGBColor[
              0.1921184870580793, 0.31925908928662833`, 0.9342522356729014], 
             UndirectedEdge[6, 47] -> 
             RGBColor[
              0.22384081560300342`, 0.3526012678991412, 0.9360587753545553], 
             UndirectedEdge[33, 63] -> 
             RGBColor[
              0.19930680897803732`, 0.32681447139043773`, 0.9346615999720737],
              UndirectedEdge[55, 59] -> 
             RGBColor[
              0.28819019131998347`, 0.41643773195509054`, 0.9398624701412919],
              UndirectedEdge[23, 96] -> 
             RGBColor[
              0.18747907929674051`, 0.31438277757401956`, 0.9339880282642818],
              UndirectedEdge[2, 69] -> 
             RGBColor[
              0.2431710002789047, 0.3729185175980094, 0.9371596007754022], 
             UndirectedEdge[23, 95] -> 
             RGBColor[
              0.18713508027302572`, 0.3140212127892975, 0.9339684380287823], 
             UndirectedEdge[27, 60] -> 
             RGBColor[
              0.21905402795395212`, 0.347570050580122, 0.9357861748793594], 
             UndirectedEdge[31, 63] -> 
             RGBColor[
              0.21200507517518904`, 0.3401611542802224, 0.9353847474466], 
             UndirectedEdge[16, 94] -> 
             RGBColor[
              0.8398007371302382, 0.30693148314303814`, 0.1857465368654065], 
             UndirectedEdge[25, 99] -> 
             RGBColor[
              0.19720051937466027`, 0.3246006274708143, 0.9345416498951375], 
             UndirectedEdge[16, 80] -> 
             RGBColor[
              0.6819553926856974, 0.3711799734786655, 0.43903419902351026`], 
             UndirectedEdge[12, 13] -> 
             RGBColor[
              0.32127656696796114`, 0.4420975360854687, 0.9420804744301899], 
             UndirectedEdge[23, 28] -> 
             RGBColor[
              0.18742014259908113`, 0.31432083136797706`, 0.9339846719065392],
              UndirectedEdge[13, 19] -> 
             RGBColor[
              0.7170638157235125, 0.7755917913654835, 0.9182556284955311], 
             UndirectedEdge[52, 68] -> 
             RGBColor[
              0.18784490005447374`, 0.3147672783847729, 0.9340088612152515], 
             UndirectedEdge[81, 85] -> 
             RGBColor[
              0.49141875740375146`, 0.5807970271555756, 0.95654666136112], 
             UndirectedEdge[72, 94] -> 
             RGBColor[
              0.6519399219645001, 0.3353068708330537, 0.4361392635263973], 
             UndirectedEdge[24, 86] -> 
             RGBColor[
              0.21228006908112512`, 0.3404501903109819, 0.935400407942726], 
             UndirectedEdge[36, 95] -> 
             RGBColor[
              0.20069162691808956`, 0.32827000284796126`, 0.9347404633051051],
              UndirectedEdge[42, 56] -> 
             RGBColor[
              0.19610082990908984`, 0.3234447841181606, 0.9344790242069181], 
             UndirectedEdge[45, 85] -> 
             RGBColor[
              0.19784556933797645`, 0.32527861588078943`, 0.9345783845362825],
              UndirectedEdge[31, 35] -> 
             RGBColor[
              0.2324023237312408, 0.3615999557728864, 0.9365463405768422], 
             UndirectedEdge[71, 75] -> 
             RGBColor[
              0.18763170465412526`, 0.31454319650163753`, 0.9339967200525959],
              UndirectedEdge[52, 97] -> 
             RGBColor[
              0.1875507566423647, 0.31445811500887677`, 0.933992110183078], 
             UndirectedEdge[92, 93] -> 
             RGBColor[
              0.36042124083456856`, 0.4781140519200437, 0.9447518165794666], 
             UndirectedEdge[55, 99] -> 
             RGBColor[
              0.2201364089826432, 0.3487077016681972, 0.9358478148777043], 
             UndirectedEdge[2, 31] -> 
             RGBColor[
              0.20364898495874117`, 0.3313783736560158, 0.934908880470501], 
             UndirectedEdge[11, 58] -> 
             RGBColor[
              0.8222143233632868, 0.4319525847340926, 0.44402347124128594`], 
             UndirectedEdge[22, 99] -> 
             RGBColor[
              0.2371714131358813, 0.36661257111489637`, 0.9368179331632009], 
             UndirectedEdge[7, 8] -> 
             RGBColor[
              0.22036751462209056`, 0.34895060834820024`, 0.9358609760019805],
              UndirectedEdge[35, 49] -> 
             RGBColor[
              0.5899224888588381, 0.6646767233799711, 0.9651808040517968], 
             UndirectedEdge[39, 98] -> 
             RGBColor[
              0.8988235848595115, 0.5908517839964968, 0.3704475713541428], 
             UndirectedEdge[65, 75] -> 
             RGBColor[
              0.18710118921222496`, 0.31398559113557856`, 0.933966507983007], 
             UndirectedEdge[50, 55] -> 
             RGBColor[
              0.3509959105414218, 0.4702360940061918, 0.9440303965456369], 
             UndirectedEdge[74, 95] -> 
             RGBColor[
              0.18415739136148795`, 0.31089147294689, 0.9337988630503662], 
             UndirectedEdge[38, 39] -> 
             RGBColor[
              0.6486469668748682, 0.3849687430769146, 0.44316238194817426`], 
             UndirectedEdge[44, 94] -> 
             RGBColor[
              0.6868282260480878, 0.36738543292603887`, 0.43829420926089435`],
              UndirectedEdge[12, 84] -> 
             RGBColor[
              0.1935679769119246, 0.3207825950259845, 0.9343347819757498], 
             UndirectedEdge[3, 59] -> 
             RGBColor[
              0.2826045728190182, 0.4105668927619084, 0.9395443774308441], 
             UndirectedEdge[43, 92] -> 
             RGBColor[
              0.41179250958273794`, 0.5300343878660122, 0.9477532782009283], 
             UndirectedEdge[1, 92] -> 
             RGBColor[
              0.3522179650715156, 0.4694918889753511, 0.9442846521604198], 
             UndirectedEdge[53, 80] -> 
             RGBColor[
              0.2739248648169684, 0.4000334364374093, 0.9391017274193396], 
             UndirectedEdge[55, 95] -> 
             RGBColor[
              0.2066434645494383, 0.33452576156681035`, 0.9350794116532557], 
             UndirectedEdge[35, 59] -> 
             RGBColor[
              0.30456814063231075`, 0.4336519951043093, 0.9407951701256243], 
             UndirectedEdge[28, 64] -> 
             RGBColor[
              0.21372188885173682`, 0.34196563430654825`, 0.9354825174456812],
              UndirectedEdge[72, 92] -> 
             RGBColor[
              0.385487127657241, 0.5044598882396888, 0.9461792817523613], 
             UndirectedEdge[83, 92] -> 
             RGBColor[
              0.7090145270047958, 0.28901668638097916`, 0.42720637251999316`],
              UndirectedEdge[55, 69] -> 
             RGBColor[
              0.25554638973907706`, 0.3859258365656613, 0.937864360897411], 
             UndirectedEdge[54, 59] -> 
             RGBColor[
              0.27113535830736296`, 0.3985120211199582, 0.9388912226315876], 
             UndirectedEdge[38, 98] -> 
             RGBColor[
              0.6199366608715083, 0.6833204451594262, 0.8281728494436293], 
             UndirectedEdge[5, 40] -> 
             RGBColor[
              0.24092972685563074`, 0.3705627971252059, 0.9370319635696137], 
             UndirectedEdge[11, 86] -> 
             RGBColor[
              0.5258921810935405, 0.6116153730533249, 0.959367210421854], 
             UndirectedEdge[15, 46] -> 
             RGBColor[
              0.9657830139849344, 0.9721163309487307, 0.8568978296891643], 
             UndirectedEdge[49, 50] -> 
             RGBColor[
              0.6979934560531296, 0.762252921224359, 0.9720656124002875], 
             UndirectedEdge[20, 60] -> 
             RGBColor[
              0.26706217277062405`, 0.3980296546746324, 0.9385201677049833], 
             UndirectedEdge[30, 46] -> 
             RGBColor[
              0.6408275812057826, 0.7127793820224738, 0.9679292151786314], 
             UndirectedEdge[52, 84] -> 
             RGBColor[
              0.19436048626883334`, 0.32161557260809104`, 0.9343799142112132],
              UndirectedEdge[80, 100] -> 
             RGBColor[
              0.6351554173641354, 0.7089534228285144, 0.9676530853407227], 
             UndirectedEdge[6, 14] -> 
             RGBColor[
              0.31755924669394786`, 0.4456881138847494, 0.9415942503883985], 
             UndirectedEdge[30, 64] -> 
             RGBColor[
              0.29272168507154284`, 0.4216188695447302, 0.9401052178127753], 
             UndirectedEdge[42, 85] -> 
             RGBColor[
              0.2063053600849079, 0.33417039233752777`, 0.9350601571041814], 
             UndirectedEdge[78, 93] -> 
             RGBColor[
              0.20679147733060788`, 0.3346813323843719, 0.935087840762178], 
             UndirectedEdge[2, 25] -> 
             RGBColor[
              0.19123571496664776`, 0.3183312398475505, 0.9342019631082386], 
             UndirectedEdge[71, 78] -> 
             RGBColor[
              0.18343681507503706`, 0.31013410158265475`, 0.9337578272968499],
              UndirectedEdge[21, 49] -> 
             RGBColor[
              0.7064048022469269, 0.7690816309913114, 0.9727277843844396], 
             UndirectedEdge[8, 50] -> 
             RGBColor[
              0.3450713521941504, 0.46400900754451446`, 0.9436930017123585], 
             UndirectedEdge[7, 96] -> 
             RGBColor[
              0.206732542507712, 0.33461938814882475`, 0.9350844845112003], 
             UndirectedEdge[80, 81] -> 
             RGBColor[
              0.5669725360193991, 0.6549994961691269, 0.9610400768362422], 
             UndirectedEdge[14, 72] -> 
             RGBColor[
              0.3229529934720847, 0.4513572837318689, 0.9419014162880801], 
             UndirectedEdge[3, 50] -> 
             RGBColor[
              0.34541029204045653`, 0.4643652548130097, 0.9437123038351891], 
             UndirectedEdge[26, 53] -> 
             RGBColor[
              0.18250075787953074`, 0.30915024612072356`, 0.9337045202243384],
              UndirectedEdge[26, 88] -> 
             RGBColor[
              0.19550264674767992`, 0.3228160556885158, 0.9344449585608086], 
             UndirectedEdge[67, 84] -> 
             RGBColor[
              0.2010083932435165, 0.32860294434013004`, 0.9347585026787244], 
             UndirectedEdge[68, 73] -> 
             RGBColor[
              0.19600658059736395`, 0.32334572211578516`, 0.9344736568480447],
              UndirectedEdge[56, 93] -> 
             RGBColor[
              0.21100489776744946`, 0.3391099044097778, 0.9353277888228592], 
             UndirectedEdge[5, 41] -> 
             RGBColor[
              0.2141840124722679, 0.34245135553205625`, 0.9355088347022198], 
             UndirectedEdge[51, 77] -> 
             RGBColor[
              0.22634403669110006`, 0.3552323119761146, 0.9362013300923386], 
             UndirectedEdge[79, 88] -> 
             RGBColor[
              0.24574557647575745`, 0.3756245604184607, 0.9373062190810688], 
             UndirectedEdge[75, 78] -> 
             RGBColor[
              0.1893409435855542, 0.3163397149905769, 0.9340940586811484], 
             UndirectedEdge[25, 87] -> 
             RGBColor[
              0.1887673495541914, 0.31573683129565244`, 0.9340613933496187], 
             UndirectedEdge[56, 65] -> 
             RGBColor[
              0.18711972006997832`, 0.3140050682420016, 0.9339675632879421], 
             UndirectedEdge[41, 65] -> 
             RGBColor[
              0.185507033592541, 0.3123100325039866, 0.9338757231788078], 
             UndirectedEdge[39, 51] -> 
             RGBColor[
              0.6583434133707539, 0.3951603231343067, 0.4437145802315078], 
             UndirectedEdge[92, 94] -> 
             RGBColor[
              0.7232188908692644, 0.39819765143521957`, 0.4408084873981428], 
             UndirectedEdge[43, 67] -> 
             RGBColor[
              0.2700909231890912, 0.39913893876339046`, 0.9387685944239152], 
             UndirectedEdge[76, 93] -> 
             RGBColor[
              0.2703392839451005, 0.40115090797957687`, 0.9387186282120497], 
             UndirectedEdge[22, 36] -> 
             RGBColor[
              0.23763016055669245`, 0.3670947437404353, 0.93684405815016], 
             UndirectedEdge[10, 52] -> 
             RGBColor[
              0.19371851369622117`, 0.32094081873086366`, 0.9343433548229163],
              UndirectedEdge[8, 34] -> 
             RGBColor[
              0.3978440089897182, 0.5068522277122526, 0.947847458567917], 
             UndirectedEdge[79, 100] -> 
             RGBColor[
              0.5939742401547752, 0.6708787372417735, 0.9651171386659816], 
             UndirectedEdge[15, 83] -> 
             RGBColor[
              0.8766195059047, 0.4201464985357575, 0.3498656775348218], 
             UndirectedEdge[67, 73] -> 
             RGBColor[
              0.21051618179530102`, 0.3385962329366675, 0.9352999571712358], 
             UndirectedEdge[31, 34] -> 
             RGBColor[
              0.3932459477211001, 0.5020193737850124, 0.9475856057808912], 
             UndirectedEdge[35, 99] -> 
             RGBColor[
              0.23651435829497044`, 0.36592196481741596`, 0.9367805148620365],
              UndirectedEdge[41, 56] -> 
             RGBColor[
              0.19196020840271177`, 0.31909272838439073`, 0.9342432219376304],
              UndirectedEdge[11, 21] -> 
             RGBColor[
              0.6506293241287362, 0.7246966300102036, 0.9673842910909733], 
             UndirectedEdge[65, 79] -> 
             RGBColor[
              0.23169685165208387`, 0.3608584598881792, 0.9365061649855866], 
             UndirectedEdge[1, 47] -> 
             RGBColor[
              0.19596539979541489`, 0.3233024384819231, 0.9344713116622951], 
             UndirectedEdge[9, 95] -> 
             RGBColor[
              0.2227469590499585, 0.3514515553073798, 0.9359964818420752], 
             UndirectedEdge[39, 46] -> 
             RGBColor[
              0.8792048923286101, 0.57748583724696, 0.46162556909456987`], 
             UndirectedEdge[7, 21] -> 
             RGBColor[
              0.3591523356697781, 0.47679686557043666`, 0.9446780511522341], 
             UndirectedEdge[57, 100] -> 
             RGBColor[
              0.6372968908915713, 0.7108082595643903, 0.9677895381402603], 
             UndirectedEdge[90, 93] -> 
             RGBColor[
              0.2946768186179643, 0.42223085727315157`, 0.9402693944005678], 
             UndirectedEdge[8, 25] -> 
             RGBColor[
              0.19768654607954875`, 0.325111472353525, 0.9345693283969689], 
             UndirectedEdge[84, 97] -> 
             RGBColor[
              0.18620464863347033`, 0.3130432701433516, 0.9339154513233598], 
             UndirectedEdge[63, 66] -> 
             RGBColor[
              0.2167774985639212, 0.34517727385089947`, 0.9356565298984206], 
             UndirectedEdge[62, 74] -> 
             RGBColor[
              0.1935600424302069, 0.32077425538262405`, 0.934334330118754], 
             UndirectedEdge[31, 69] -> 
             RGBColor[
              0.24502377012318755`, 0.3748658961767437, 0.9372651132771068], 
             UndirectedEdge[38, 51] -> 
             RGBColor[
              0.2592164036383718, 0.38978325386614093`, 0.9380733627596768], 
             UndirectedEdge[5, 65] -> 
             RGBColor[
              0.20934352413953444`, 0.3373636953896671, 0.9352331760525314], 
             UndirectedEdge[22, 69] -> 
             RGBColor[
              0.27258139389231517`, 0.4038307060123605, 0.9388344791829076], 
             UndirectedEdge[55, 96] -> 
             RGBColor[
              0.2069874635731531, 0.3348873263515324, 0.9350990018887553], 
             UndirectedEdge[3, 63] -> 
             RGBColor[
              0.21694207629011328`, 0.3453502554759579, 0.9356659023564564], 
             UndirectedEdge[51, 98] -> 
             RGBColor[
              0.6344813306153367, 0.6986078152455144, 0.8290011468686297], 
             UndirectedEdge[1, 89] -> 
             RGBColor[
              0.21140317066932124`, 0.3395285144816055, 0.9353504698754288], 
             UndirectedEdge[18, 86] -> 
             RGBColor[
              0.21600318035589844`, 0.3443634163196576, 0.9356124336219749], 
             UndirectedEdge[12, 17] -> 
             RGBColor[
              0.18741833919831424`, 0.3143189358794289, 0.9339845692055334], 
             UndirectedEdge[26, 41] -> 
             RGBColor[
              0.18629441025673982`, 0.31313761530062345`, 0.9339205631150146],
              UndirectedEdge[50, 87] -> 
             RGBColor[
              0.3361521556687931, 0.4546343664866419, 0.9431850666650082], 
             UndirectedEdge[35, 54] -> 
             RGBColor[
              0.22587011033450982`, 0.35473418532667167`, 0.9361743406874421],
              UndirectedEdge[30, 62] -> 
             RGBColor[
              0.2754274446786539, 0.4034415263736312, 0.9391203364069362], 
             UndirectedEdge[57, 81] -> 
             RGBColor[
              0.569114009546835, 0.6568543329050028, 0.9611765296357797], 
             UndirectedEdge[22, 95] -> 
             RGBColor[
              0.22367846870267644`, 0.3524306310135095, 0.9360495299387523], 
             UndirectedEdge[15, 90] -> 
             RGBColor[
              0.6780686271476394, 0.7396075827282129, 0.8326896529033235], 
             UndirectedEdge[14, 40] -> 
             RGBColor[
              0.3055881316680375, 0.43310571297998635`, 0.9409125130973505], 
             UndirectedEdge[16, 44] -> 
             RGBColor[
              0.6880034173816231, 0.37641846848771643`, 0.43941957380907637`],
              UndirectedEdge[61, 77] -> 
             RGBColor[
              0.19409901234894075`, 0.3213407469398799, 0.9343650236582913], 
             UndirectedEdge[37, 76] -> 
             RGBColor[
              0.24826266203441094`, 0.37794697861276794`, 0.9374613972536713],
              UndirectedEdge[9, 11] -> 
             RGBColor[
              0.5338725559288404, 0.620003252990214, 0.9598216809628177], 
             UndirectedEdge[5, 44] -> 
             RGBColor[
              0.31062704478505954`, 0.4369322110165661, 0.9412532853620887], 
             UndirectedEdge[5, 71] -> 
             RGBColor[
              0.20987403958143475`, 0.33792130075572613`, 0.9352633881221204],
              UndirectedEdge[11, 29] -> 
             RGBColor[
              0.7125643176379728, 0.7749782478806632, 0.9722600406553771], 
             UndirectedEdge[54, 99] -> 
             RGBColor[
              0.20308157597002263`, 0.33078199083306487`, 0.934876567368], 
             UndirectedEdge[5, 15] -> 
             RGBColor[
              0.6166205103666806, 0.6798452570125046, 0.8290136600902044], 
             UndirectedEdge[19, 81] -> 
             RGBColor[
              0.8772758163253653, 0.9038540233097221, 0.9321563058058178], 
             UndirectedEdge[19, 90] -> 
             RGBColor[
              0.673306404828096, 0.737691321359293, 0.9154674449664344], 
             UndirectedEdge[58, 100] -> 
             RGBColor[
              0.8542910545110711, 0.45747046526145335`, 0.4470986974261949], 
             UndirectedEdge[49, 100] -> 
             RGBColor[
              0.9128817036617044, 0.9333711072588528, 0.9915526659060124], 
             UndirectedEdge[36, 62] -> 
             RGBColor[
              0.2100942779868085, 0.33815278528369536`, 0.935275930373493], 
             UndirectedEdge[62, 96] -> 
             RGBColor[
              0.19648658515650724`, 0.32385023734149165`, 0.9345009923975848],
              UndirectedEdge[22, 49] -> 
             RGBColor[
              0.590579543699749, 0.6653673296774516, 0.9652182223529613], 
             UndirectedEdge[10, 73] -> 
             RGBColor[
              0.20188019423911135`, 0.3295192624618759, 0.9348081504557095], 
             UndirectedEdge[39, 76] -> 
             RGBColor[
              0.6711702779885043, 0.4084267055708983, 0.4444529404449973], 
             UndirectedEdge[22, 58] -> 
             RGBColor[
              0.6394229478697675, 0.27880128020718586`, 0.4295424017241608], 
             UndirectedEdge[69, 87] -> 
             RGBColor[
              0.24070263486644833`, 0.37032410904611146`, 0.9370190310167823],
              UndirectedEdge[9, 23] -> 
             RGBColor[
              0.2231421042589107, 0.35186687797564187`, 0.9360189847771601], 
             UndirectedEdge[28, 62] -> 
             RGBColor[
              0.19642764845884786`, 0.32378829113544916`, 0.934497636039842], 
             UndirectedEdge[8, 36] -> 
             RGBColor[
              0.2146705980561829, 0.3429627878320588, 0.935536545031385], 
             UndirectedEdge[7, 55] -> 
             RGBColor[
              0.226292072969362, 0.3551776948098776, 0.936198370835259], 
             UndirectedEdge[15, 39] -> 
             RGBColor[
              0.8988298948147204, 0.5908652803526545, 0.37113437103810387`], 
             UndirectedEdge[15, 44] -> 
             RGBColor[
              0.6892270521324788, 0.7492724496113339, 0.8334006578763498], 
             UndirectedEdge[16, 58] -> 
             RGBColor[
              0.836534195409341, 0.28182341206851363`, 0.1826184928244442], 
             UndirectedEdge[1, 43] -> 
             RGBColor[
              0.2716048936398662, 0.40073021769842576`, 0.9388548128013683], 
             UndirectedEdge[7, 36] -> 
             RGBColor[
              0.22034023533801322`, 0.3489219360910285, 0.9358594224871084], 
             UndirectedEdge[38, 61] -> 
             RGBColor[
              0.22697137929621247`, 0.35589168882990624`, 0.9362370563256295],
              UndirectedEdge[32, 89] -> 
             RGBColor[
              0.2052962404972837, 0.33310974366905743`, 0.9350026892365249], 
             UndirectedEdge[57, 80] -> 
             RGBColor[
              0.3672309859905165, 0.4924987553241186, 0.9446206115910732], 
             UndirectedEdge[34, 59] -> 
             RGBColor[
              0.46541176462217004`, 0.5740714131164353, 0.9518344353296734], 
             UndirectedEdge[40, 92] -> 
             RGBColor[
              0.36812226585319374`, 0.48620831748780624`, 0.9451903785616318],
              UndirectedEdge[59, 82] -> 
             RGBColor[
              0.3267558333627557, 0.4569726669449779, 0.9420587264028731], 
             UndirectedEdge[3, 69] -> 
             RGBColor[
              0.24996077123811178`, 0.38005499737247916`, 0.9375462681869631],
              UndirectedEdge[16, 50] -> 
             RGBColor[
              0.7187404975473507, 0.4026408522825174, 0.441488781052485], 
             UndirectedEdge[58, 83] -> 
             RGBColor[
              0.8249902804226744, 0.19309182290519136`, 0.17156402679622504`],
              UndirectedEdge[74, 96] -> 
             RGBColor[
              0.18450139038520275`, 0.31125303773161206`, 0.9338184532858658],
              UndirectedEdge[31, 99] -> 
             RGBColor[
              0.20961378936675365`, 0.33764776127927965`, 0.9352485672574], 
             UndirectedEdge[13, 57] -> 
             RGBColor[
              0.40890200894498224`, 0.5285921009607644, 0.947275852325493], 
             UndirectedEdge[8, 87] -> 
             RGBColor[
              0.20577868081490291`, 0.33361681903135804`, 0.9350301634989068],
              UndirectedEdge[7, 34] -> 
             RGBColor[
              0.4035136462715485, 0.5128113759712223, 0.9481703360236404], 
             UndirectedEdge[27, 72] -> 
             RGBColor[
              0.23149457981584223`, 0.3606458593635141, 0.936494645903747], 
             UndirectedEdge[75, 93] -> 
             RGBColor[
              0.21098636690969608`, 0.33909042730335476`, 0.9353267335179241],
              UndirectedEdge[68, 84] -> 
             RGBColor[
              0.1864987920455794, 0.3133524335192477, 0.9339322023555332], 
             UndirectedEdge[46, 64] -> 
             RGBColor[
              0.5882396141215291, 0.6608866538124454, 0.9648106294080073], 
             UndirectedEdge[34, 49] -> 
             RGBColor[
              0.7507661128486974, 0.8050961413920971, 0.976220069255846], 
             UndirectedEdge[48, 52] -> 
             RGBColor[
              0.19110962270421483`, 0.3181987088850222, 0.9341947823404299], 
             UndirectedEdge[9, 22] -> 
             RGBColor[
              0.25968549268856145`, 0.3902762961998539, 0.9381000766871301], 
             UndirectedEdge[29, 39] -> 
             RGBColor[
              0.7724688910613899, 0.4932191852417712, 0.45172194282847256`], 
             UndirectedEdge[2, 35] -> 
             RGBColor[
              0.23054955388695797`, 0.3596525771941521, 0.9364408280751375], 
             UndirectedEdge[27, 47] -> 
             RGBColor[
              0.18216046789688783`, 0.3087925797733348, 0.9336851412132408], 
             UndirectedEdge[23, 36] -> 
             RGBColor[
              0.20108677212704174`, 0.3286853255162233, 0.93476296624019], 
             UndirectedEdge[34, 69] -> 
             RGBColor[
              0.43276796304126364`, 0.5435595177270061, 0.9498363260857925], 
             UndirectedEdge[35, 50] -> 
             RGBColor[
              0.3673738598537491, 0.4874503571554106, 0.9449630965299693], 
             UndirectedEdge[15, 76] -> 
             RGBColor[
              0.6537310924747756, 0.7185276334346382, 0.8311388867148055], 
             UndirectedEdge[90, 94] -> 
             RGBColor[
              0.6793892760581949, 0.36094218833729147`, 0.4378202059455436], 
             UndirectedEdge[13, 85] -> 
             RGBColor[
              0.3312067568018987, 0.4525347952113371, 0.9426459840508332], 
             UndirectedEdge[17, 97] -> 
             RGBColor[
              0.18005501091985998`, 0.306579610996796, 0.9335652385531434], 
             UndirectedEdge[36, 99] -> 
             RGBColor[
              0.21418457135129443`, 0.3424519429493481, 0.9355088665295537], 
             UndirectedEdge[34, 87] -> 
             RGBColor[
              0.3889248124643609, 0.49747758665438, 0.9473395235205667], 
             UndirectedEdge[70, 91] -> 
             RGBColor[
              0.19734519612949952`, 0.32475269191318645`, 0.9345498890222956],
              UndirectedEdge[37, 47] -> 
             RGBColor[
              0.1820920536477783, 0.30872067205980674`, 0.9336812451229637], 
             UndirectedEdge[1, 6] -> 
             RGBColor[
              0.23990576493623242`, 0.36948654822498284`, 0.9369736504531199],
              UndirectedEdge[6, 89] -> 
             RGBColor[
              0.23927858647690978`, 0.36882734389882366`, 0.9369379335676888],
              UndirectedEdge[35, 70] -> 
             RGBColor[
              0.2351771060337347, 0.36451642790416683`, 0.9367043603240466], 
             UndirectedEdge[9, 21] -> 
             RGBColor[
              0.3755107512357394, 0.49399059751371377`, 0.9456096387186085], 
             UndirectedEdge[11, 46] -> 
             RGBColor[
              0.872668319538803, 0.9013782258884464, 0.987115480054523], 
             UndirectedEdge[21, 22] -> 
             RGBColor[
              0.37644226088845734`, 0.4949696732198435, 0.9456626868152858], 
             UndirectedEdge[37, 72] -> 
             RGBColor[
              0.2314261655667327, 0.36057395164998607`, 0.93649074981347], 
             UndirectedEdge[9, 62] -> 
             RGBColor[
              0.23214961011867746`, 0.3613343377431139, 0.9365319489104629], 
             UndirectedEdge[22, 30] -> 
             RGBColor[
              0.3029633272485378, 0.43238348483037115`, 0.9406884641836033], 
             UndirectedEdge[6, 43] -> 
             RGBColor[
              0.29948030944745474`, 0.4300290471156439, 0.9404422764936284], 
             UndirectedEdge[26, 45] -> 
             RGBColor[
              0.1819752410161864, 0.308597894577655, 0.9336745928164034], 
             UndirectedEdge[34, 99] -> 
             RGBColor[
              0.39735798228482977`, 0.5063413828295419, 0.9478197800660857], 
             UndirectedEdge[35, 87] -> 
             RGBColor[
              0.2280811884745016, 0.35705816864225415`, 0.9363002583165176], 
             UndirectedEdge[47, 72] -> 
             RGBColor[
              0.2292345623811403, 0.3582704377462608, 0.9363659412542369], 
             UndirectedEdge[32, 47] -> 
             RGBColor[
              0.18985846962337735`, 0.316883667669375, 0.9341235310233913], 
             UndirectedEdge[35, 82] -> 
             RGBColor[
              0.28149058538990257`, 0.41319483115169137`, 0.9393418444587276],
              UndirectedEdge[14, 15] -> 
             RGBColor[
              0.6812789151790875, 0.7423881728672851, 0.8328942096179411], 
             UndirectedEdge[3, 91] -> 
             RGBColor[
              0.19950741494192983`, 0.3270253209776415, 0.9346730241849475], 
             UndirectedEdge[18, 24] -> 
             RGBColor[
              0.18549001607177976`, 0.3122921460106934, 0.9338747540561756], 
             UndirectedEdge[6, 60] -> 
             RGBColor[
              0.26073437566006774`, 0.39137873870592843`, 0.938159809020674], 
             UndirectedEdge[81, 100] -> 
             RGBColor[
              0.8370384409204539, 0.8733090004093986, 0.9842090033854292], 
             UndirectedEdge[34, 81] -> 
             RGBColor[
              0.6749228501074469, 0.7450340345426429, 0.9688764067352628], 
             UndirectedEdge[25, 69] -> 
             RGBColor[
              0.23261050013109416`, 0.3618187623682784, 0.9365581959148443], 
             UndirectedEdge[14, 76] -> 
             RGBColor[
              0.339789489939763, 0.4687303106946508, 0.9428720637282814], 
             UndirectedEdge[79, 90] -> 
             RGBColor[
              0.32182194731276953`, 0.45076210863195715`, 0.9418152693221177],
              UndirectedEdge[9, 28] -> 
             RGBColor[
              0.2230320213760139, 0.3517511738860594, 0.936012715719832], 
             UndirectedEdge[60, 89] -> 
             RGBColor[
              0.23223178139315653`, 0.3614207049625511, 0.936536628442983], 
             UndirectedEdge[1, 14] -> 
             RGBColor[
              0.28968383088635935`, 0.4163892844675312, 0.9400067866961384], 
             UndirectedEdge[7, 69] -> 
             RGBColor[
              0.25529146867363595`, 0.38565789836295367`, 0.937849843519856], 
             UndirectedEdge[66, 91] -> 
             RGBColor[
              0.19934283721573776`, 0.3268523393525831, 0.9346636517269117], 
             UndirectedEdge[44, 79] -> 
             RGBColor[
              0.33298037229760896`, 0.4604269755150782, 0.9425262742951439], 
             UndirectedEdge[41, 79] -> 
             RGBColor[
              0.23653733998481735`, 0.36594612003056837`, 0.936781823635275], 
             UndirectedEdge[22, 50] -> 
             RGBColor[
              0.36803091469466, 0.488140963452891, 0.9450005148311336], 
             UndirectedEdge[3, 82] -> 
             RGBColor[
              0.25952701757661, 0.3901097288092905, 0.9380910517639474], 
             UndirectedEdge[95, 96] -> 
             RGBColor[
              0.1870839340877883, 0.3139674549057575, 0.933965525329197], 
             UndirectedEdge[2, 63] -> 
             RGBColor[
              0.21015230533090618`, 0.33821377570148814`, 0.9352792349448955],
              UndirectedEdge[7, 23] -> 
             RGBColor[
              0.20678368869294939`, 0.33467314603236475`, 0.9350873972107856],
              UndirectedEdge[44, 57] -> 
             RGBColor[
              0.3763030230344051, 0.500356497837695, 0.9451986737694225], 
             UndirectedEdge[13, 58] -> 
             RGBColor[
              0.7020277998800117, 0.3359930261923694, 0.4334229068830169], 
             UndirectedEdge[8, 54] -> 
             RGBColor[
              0.20356760267491114`, 0.3312928357157756, 0.9349042458698312], 
             UndirectedEdge[54, 69] -> 
             RGBColor[
              0.23849155672645656`, 0.368000125730529, 0.9368931133877068], 
             UndirectedEdge[3, 66] -> 
             RGBColor[
              0.21521117930668043`, 0.34353097300116264`, 0.9355673303338825],
              UndirectedEdge[34, 82] -> 
             RGBColor[
              0.44233420937976187`, 0.5536142491638173, 0.9503811096627767], 
             UndirectedEdge[17, 67] -> 
             RGBColor[
              0.1948587555299061, 0.3221392851935744, 0.934408289908508], 
             UndirectedEdge[57, 88] -> 
             RGBColor[
              0.28906822721255354`, 0.41555408274107747`, 0.9399786185553474],
              UndirectedEdge[8, 69] -> 
             RGBColor[
              0.24962183139180566`, 0.379698750103984, 0.9375269660641325], 
             UndirectedEdge[62, 99] -> 
             RGBColor[
              0.20963553056599735`, 0.3376706126581564, 0.9352498053865337], 
             UndirectedEdge[69, 99] -> 
             RGBColor[
              0.24913580468691718`, 0.37918790522127327`, 0.9374992875623012],
              UndirectedEdge[49, 59] -> 
             RGBColor[
              0.6351877368316913, 0.7084545591732576, 0.9678976859959425], 
             UndirectedEdge[46, 94] -> 
             RGBColor[
              0.8711988672830582, 0.5159480204843034, 0.45395899046943744`], 
             UndirectedEdge[42, 53] -> 
             RGBColor[
              0.19069449105444342`, 0.3177623792002457, 0.9341711412071076], 
             UndirectedEdge[28, 74] -> 
             RGBColor[
              0.18444245368754336`, 0.31119109152556956`, 0.9338150969281231],
              UndirectedEdge[31, 70] -> 
             RGBColor[
              0.2082765371055179, 0.33624222436603046`, 0.9351724127194101], 
             UndirectedEdge[50, 54] -> 
             RGBColor[
              0.3339410775288013, 0.4523103831710595, 0.9430591490359327], 
             UndirectedEdge[15, 100] -> 
             RGBColor[
              0.950220919989645, 0.9597242113380292, 0.8559915222471874], 
             UndirectedEdge[33, 91] -> 
             RGBColor[
              0.18187214762985388`, 0.30848953689212133`, 0.9336687218005647],
              UndirectedEdge[45, 88] -> 
             RGBColor[
              0.19523658917566114`, 0.32253641231129965`, 0.9344298069756789],
              UndirectedEdge[16, 59] -> 
             RGBColor[
              0.6768700180663918, 0.36677527758178324`, 0.43871016344958824`],
              UndirectedEdge[80, 85] -> 
             RGBColor[
              0.2895357338474329, 0.4164414495746913, 0.9399907433164134], 
             UndirectedEdge[2, 3] -> 
             RGBColor[
              0.2085859860736654, 0.33656747485175126`, 0.9351900353803573], 
             UndirectedEdge[83, 94] -> 
             RGBColor[
              0.8244211819322343, 0.18871748252712017`, 0.1710190574390748], 
             UndirectedEdge[73, 84] -> 
             RGBColor[
              0.20252216681172355`, 0.33019401633910334`, 0.9348447098440065],
              UndirectedEdge[42, 80] -> 
             RGBColor[
              0.28185913870055557`, 0.40837286135107903`, 0.9395535725793036],
              UndirectedEdge[17, 48] -> 
             RGBColor[
              0.1836138769817101, 0.31032020487294143`, 0.9337679107104953], 
             UndirectedEdge[6, 92] -> 
             RGBColor[
              0.38009338087910416`, 0.4987907183925693, 0.9458721158526797], 
             UndirectedEdge[19, 100] -> 
             RGBColor[
              0.9454586976701016, 0.9578079499691095, 0.9387693143102983], 
             UndirectedEdge[35, 63] -> 
             RGBColor[
              0.23890564410340584`, 0.3684353578183588, 0.9369166950512366], 
             UndirectedEdge[19, 79] -> 
             RGBColor[
              0.6342116155596866, 0.701423760142097, 0.9130644410863702], 
             UndirectedEdge[50, 69] -> 
             RGBColor[
              0.37999530624569583`, 0.5007162975592678, 0.945681869230234], 
             UndirectedEdge[52, 73] -> 
             RGBColor[
              0.20386827482061792`, 0.3316088612046285, 0.9349213687037247], 
             UndirectedEdge[59, 99] -> 
             RGBColor[
              0.2817796062678236, 0.4096998006107025, 0.9394973968061822], 
             UndirectedEdge[44, 56] -> 
             RGBColor[
              0.2884032407155034, 0.4135735838689006, 0.9399876725974994], 
             UndirectedEdge[14, 75] -> 
             RGBColor[
              0.28043657290435864`, 0.4066698300184287, 0.9394801690341557], 
             UndirectedEdge[14, 20] -> 
             RGBColor[
              0.32388704380450417`, 0.45233902985345337`, 0.9419546090727077],
              UndirectedEdge[62, 95] -> 
             RGBColor[
              0.19614258613279245`, 0.32348867255676955`, 0.9344814021620852],
              UndirectedEdge[39, 83] -> 
             RGBColor[
              0.8395293889100205, 0.30484578181689703`, 0.18548669350328206`],
              UndirectedEdge[48, 73] -> 
             RGBColor[
              0.199271303247105, 0.3267771526160345, 0.9346595779732231], 
             UndirectedEdge[20, 76] -> 
             RGBColor[
              0.2963392211001924, 0.42847849042080643`, 0.940199286169572], 
             UndirectedEdge[8, 49] -> 
             RGBColor[
              0.5676199811992395, 0.641235373769075, 0.9639107092341861], 
             UndirectedEdge[49, 55] -> 
             RGBColor[
              0.5735445395465109, 0.6474624602307524, 0.9642481040674646], 
             UndirectedEdge[2, 34] -> 
             RGBColor[
              0.39139317787681727`, 0.5000719952062781, 0.9474800932791867], 
             UndirectedEdge[1, 71] -> 
             RGBColor[
              0.19687896263612603`, 0.32426265095074003`, 0.9345233377145786],
              UndirectedEdge[40, 79] -> 
             RGBColor[
              0.2632830543681802, 0.39405756162371797`, 0.9383049525026688], 
             UndirectedEdge[94, 98] -> 
             RGBColor[
              0.8908175598139597, 0.5293139672338403, 0.3627809927290103], 
             UndirectedEdge[44, 81] -> 
             RGBColor[
              0.5760445730632877, 0.6628572386827033, 0.9616181390145914], 
             UndirectedEdge[16, 82] -> 
             RGBColor[
              0.6614849812381197, 0.35313716828003794`, 0.4377412796716571], 
             UndirectedEdge[21, 30] -> 
             RGBColor[
              0.4187885857957158, 0.536097786144231, 0.9481980262150818], 
             UndirectedEdge[96, 99] -> 
             RGBColor[
              0.2005768785209932, 0.32814939500714435`, 0.9347339285536456], 
             UndirectedEdge[94, 100] -> 
             RGBColor[
              0.8608241379528653, 0.5076866074105023, 0.4533547855081195], 
             UndirectedEdge[21, 46] -> 
             RGBColor[
              0.7143065148457021, 0.7753655704119462, 0.9729034378103137], 
             UndirectedEdge[9, 86] -> 
             RGBColor[
              0.2507736082005437, 0.3809093405568351, 0.937592558049489], 
             UndirectedEdge[14, 94] -> 
             RGBColor[
              0.6815294680791602, 0.36279591509667297`, 0.437956577088622], 
             UndirectedEdge[46, 83] -> 
             RGBColor[
              0.8569945034185896, 0.4067670554300631, 0.4403568755912878], 
             UndirectedEdge[58, 59] -> 
             RGBColor[
              0.6691617432910624, 0.3075260998710566, 0.4313287108194816], 
             UndirectedEdge[10, 97] -> 
             RGBColor[
              0.18556267606085813`, 0.31236851626612416`, 0.9338788919350629],
              UndirectedEdge[21, 64] -> 
             RGBColor[
              0.3662006187114623, 0.48420505793420254`, 0.9450794404444577], 
             UndirectedEdge[4, 38] -> 
             RGBColor[
              0.21418086201799924`, 0.3424480442048695, 0.9355086552885099], 
             UndirectedEdge[63, 70] -> 
             RGBColor[
              0.21477985747768297`, 0.3430776264115028, 0.9355427671938046], 
             UndirectedEdge[39, 94] -> 
             RGBColor[
              0.8466315708422548, 0.35943626434401715`, 0.19228775094235687`],
              UndirectedEdge[27, 37] -> 
             RGBColor[
              0.18435207108248025`, 0.3110960936770601, 0.9338099497724739], 
             UndirectedEdge[57, 85] -> 
             RGBColor[
              0.2916772073748689, 0.41829628631056726`, 0.940127196115951], 
             UndirectedEdge[22, 34] -> 
             RGBColor[
              0.42080357149022773`, 0.530984183620629, 0.949154971686692], 
             UndirectedEdge[31, 87] -> 
             RGBColor[
              0.2011806195462848, 0.3287839651041178, 0.934768310711881], 
             UndirectedEdge[10, 48] -> 
             RGBColor[
              0.18912154212270826`, 0.3161091101422696, 0.9340815640924147], 
             UndirectedEdge[63, 82] -> 
             RGBColor[
              0.26109333683385083`, 0.39175602965902734`, 0.9381802513284855],
              UndirectedEdge[4, 66] -> 
             RGBColor[
              0.19936829586097168`, 0.3268790980028953, 0.934665101559095], 
             UndirectedEdge[10, 68] -> 
             RGBColor[
              0.18585681947296723`, 0.3126776796420203, 0.9338956429672363], 
             UndirectedEdge[9, 64] -> 
             RGBColor[
              0.24944385051156642`, 0.37951168091421295`, 0.9375168303163021],
              UndirectedEdge[22, 55] -> 
             RGBColor[
              0.24358199818804122`, 0.3733505024592844, 0.9371830064983107], 
             UndirectedEdge[7, 87] -> 
             RGBColor[
              0.2114483180967332, 0.3395759672903277, 0.9353530409546302], 
             UndirectedEdge[35, 69] -> 
             RGBColor[
              0.27192433905140434`, 0.4031400997148801, 0.9387970608817433], 
             UndirectedEdge[8, 99] -> 
             RGBColor[
              0.21421185063537176`, 0.34248061520651985`, 0.9355104200444258],
              UndirectedEdge[31, 50] -> 
             RGBColor[
              0.3404732909255323, 0.45917615361727426`, 0.9434311489253328], 
             UndirectedEdge[19, 58] -> 
             RGBColor[
              0.8811159714476788, 0.477833813861669, 0.4123968990397874], 
             UndirectedEdge[58, 81] -> 
             RGBColor[
              0.8088358002812469, 0.4215011808218617, 0.44269002508987454`], 
             UndirectedEdge[9, 30] -> 
             RGBColor[
              0.30203181759581993`, 0.4314044091242414, 0.9406354160869261], 
             UndirectedEdge[5, 56] -> 
             RGBColor[
              0.2157966989497052, 0.34414639127007124`, 0.9356006748113541], 
             UndirectedEdge[7, 22] -> 
             RGBColor[
              0.2433270771226001, 0.37308256425657677`, 0.9371684891207557], 
             UndirectedEdge[7, 95] -> 
             RGBColor[
              0.2063885434839972, 0.3342578233641027, 0.9350648942757007], 
             UndirectedEdge[34, 50] -> 
             RGBColor[
              0.5282174838436084, 0.6278697751675365, 0.9560023617340184], 
             UndirectedEdge[42, 88] -> 
             RGBColor[
              0.2036963799225926, 0.3314281887680379, 0.9349115795435778], 
             UndirectedEdge[60, 72] -> 
             RGBColor[
              0.2661281224382046, 0.39704790855304795`, 0.9384669749203556], 
             UndirectedEdge[50, 99] -> 
             RGBColor[
              0.3445853254892619, 0.46349816266180377`, 0.9436653232105272], 
             UndirectedEdge[44, 88] -> 
             RGBColor[
              0.2959987907290062, 0.42155698851877793`, 0.9404202279341591], 
             UndirectedEdge[26, 42] -> 
             RGBColor[
              0.19043503176311785`, 0.3174896710343933, 0.9341563653843022], 
             UndirectedEdge[67, 97] -> 
             RGBColor[
              0.1941986636170478, 0.3214454867409158, 0.9343706986505892], 
             UndirectedEdge[12, 68] -> 
             RGBColor[
              0.187052390697565, 0.3139343008026664, 0.933963728979788], 
             UndirectedEdge[79, 93] -> 
             RGBColor[
              0.255582029349555, 0.3859632960559554, 0.9378663905205036], 
             UndirectedEdge[26, 57] -> 
             RGBColor[
              0.2758068790530788, 0.40161556500743284`, 0.9392234043960719], 
             UndirectedEdge[17, 84] -> 
             RGBColor[
              0.18686474054632862`, 0.31373706859601025`, 0.9339530425812786],
              UndirectedEdge[71, 76] -> 
             RGBColor[
              0.24698462168952967`, 0.3766036771778597, 0.9373886147467216], 
             UndirectedEdge[3, 31] -> 
             RGBColor[
              0.21043875591794825`, 0.33851485343048554`, 0.9352955478820619],
              UndirectedEdge[15, 72] -> 
             RGBColor[
              0.6368945960070973, 0.7011546064718562, 0.8301682392746041], 
             UndirectedEdge[10, 84] -> 
             RGBColor[
              0.19237240568732683`, 0.31952597386533843`, 0.9342666959631981],
              UndirectedEdge[4, 51] -> 
             RGBColor[
              0.22872553176182758`, 0.35773541429095773`, 0.9363369527135103],
              UndirectedEdge[1, 37] -> 
             RGBColor[
              0.1981570029810073, 0.3256059523856484, 0.9345961202215283], 
             UndirectedEdge[7, 28] -> 
             RGBColor[
              0.20667360581005262`, 0.3345574419427823, 0.9350811281534577], 
             UndirectedEdge[28, 36] -> 
             RGBColor[
              0.20097668924414497`, 0.32856962142664087`, 0.934756697182862], 
             UndirectedEdge[16, 39] -> 
             RGBColor[
              0.8438037496530141, 0.33770039152436643`, 0.18957982617797273`],
              UndirectedEdge[8, 82] -> 
             RGBColor[
              0.2591880777303039, 0.38975348154079525`, 0.9380717496411167], 
             UndirectedEdge[30, 36] -> 
             RGBColor[
              0.27997648546395093`, 0.40822285666482283`, 0.939379397549956], 
             UndirectedEdge[52, 60] -> 
             RGBColor[
              0.22469708242702108`, 0.35350125862163606`, 0.9361075384834499],
              UndirectedEdge[59, 69] -> 
             RGBColor[
              0.3171895870242575, 0.4469179355081666, 0.941513942825889], 
             UndirectedEdge[10, 12] -> 
             RGBColor[
              0.1929260043393124, 0.3201078411487571, 0.9342982225874529], 
             UndirectedEdge[38, 66] -> 
             RGBColor[
              0.2298591677375159, 0.3589269375780785, 0.9364015116052615], 
             UndirectedEdge[41, 90] -> 
             RGBColor[
              0.27563212925322667`, 0.4022136812477645, 0.9391848275153389], 
             UndirectedEdge[5, 93] -> 
             RGBColor[
              0.23322870183700556`, 0.3624685315574433, 0.9365934015874486], 
             UndirectedEdge[5, 90] -> 
             RGBColor[
              0.2994686198002201, 0.427267344133445, 0.9405422803890626], 
             UndirectedEdge[34, 58] -> 
             RGBColor[
              0.7462139939690664, 0.3719538213502829, 0.4368769663260841], 
             UndirectedEdge[72, 76] -> 
             RGBColor[
              0.29540517076777295`, 0.427496744299222, 0.9401460933849444], 
             UndirectedEdge[6, 76] -> 
             RGBColor[
              0.2900114239896361, 0.4218275744521024, 0.9398389274852628], 
             UndirectedEdge[2, 59] -> 
             RGBColor[
              0.2758148018598111, 0.40343041298743865`, 0.9391577100192832], 
             UndirectedEdge[1, 72] -> 
             RGBColor[
              0.24529951171436928`, 0.37515571807210235`, 0.9372808163528015],
              UndirectedEdge[66, 70] -> 
             RGBColor[
              0.2130489604942501, 0.3412583439367075, 0.9354441951712307], 
             UndirectedEdge[54, 87] -> 
             RGBColor[
              0.19464840614955378`, 0.32191819465790306`, 0.934396310822481], 
             UndirectedEdge[43, 89] -> 
             RGBColor[
              0.2709777151805436, 0.4000710133722666, 0.9388190959159373], 
             UndirectedEdge[22, 23] -> 
             RGBColor[
              0.2240736139116286, 0.3528459536817715, 0.9360720328738372], 
             UndirectedEdge[20, 83] -> 
             RGBColor[
              0.6383582583216445, 0.226780403193203, 0.4225726105046661], 
             UndirectedEdge[2, 54] -> 
             RGBColor[
              0.19711677156201016`, 0.324512603209801, 0.934536880581101], 
             UndirectedEdge[11, 83] -> 
             RGBColor[
              0.8145430429406124, 0.37298776182890125`, 0.43667744444506085`],
              UndirectedEdge[54, 82] -> 
             RGBColor[
              0.24805780306495478`, 0.3780548571673403, 0.9374378969646909], 
             UndirectedEdge[19, 80] -> 
             RGBColor[
              0.6753927927690468, 0.7394984457288378, 0.9156003877611113], 
             UndirectedEdge[6, 72] -> 
             RGBColor[
              0.2731749275219578, 0.4044545474893205, 0.9388682800450615], 
             UndirectedEdge[1, 20] -> 
             RGBColor[
              0.24623356204678873`, 0.3761374641936868, 0.9373340091374291], 
             UndirectedEdge[48, 67] -> 
             RGBColor[
              0.19775752967889793`, 0.3251860806170612, 0.934573370807941], 
             UndirectedEdge[30, 58] -> 
             RGBColor[
              0.6676538311412732, 0.30622002215677757`, 0.4312326279906915], 
             UndirectedEdge[50, 82] -> 
             RGBColor[
              0.38956155258419406`, 0.5107710289960792, 0.9462266528072182], 
             UndirectedEdge[55, 62] -> 
             RGBColor[
              0.21604611561815723`, 0.34440854400254445`, 0.9356148787216435],
              UndirectedEdge[10, 17] -> 
             RGBColor[
              0.18622276797371645`, 0.31306231471878276`, 0.9339164831929817],
              UndirectedEdge[8, 59] -> 
             RGBColor[
              0.28226563297271207`, 0.41021064549341324`, 0.9395250753080134],
              UndirectedEdge[14, 44] -> 
             RGBColor[
              0.37528544959746624`, 0.4994751268713466, 0.9451338348898255], 
             UndirectedEdge[27, 43] -> 
             RGBColor[
              0.2577999617413391, 0.3862203589898375, 0.9380686423523139], 
             UndirectedEdge[40, 56] -> 
             RGBColor[
              0.21870592278607465`, 0.34720416997754033`, 0.9357663508050242],
              UndirectedEdge[8, 55] -> 
             RGBColor[
              0.22062243568753165`, 0.3492185465509079, 0.9358754933795355], 
             UndirectedEdge[82, 99] -> 
             RGBColor[
              0.25870205102541544`, 0.38924263665808456`, 0.9380440711392855],
              UndirectedEdge[19, 44] -> 
             RGBColor[
              0.6844648298129354, 0.7473561882424142, 0.9161784499394605], 
             UndirectedEdge[46, 51] -> 
             RGBColor[
              0.6050532918189845, 0.6785588951212091, 0.9657681434792702], 
             UndirectedEdge[50, 58] -> 
             RGBColor[
              0.7110322227720213, 0.3433916745717908, 0.4341073284223784], 
             UndirectedEdge[19, 94] -> 
             RGBColor[
              0.887649054889473, 0.528049956010718, 0.41865298712171195`], 
             UndirectedEdge[30, 86] -> 
             RGBColor[
              0.2940514427605201, 0.4230165291873524, 0.9401809455459623], 
             UndirectedEdge[23, 55] -> 
             RGBColor[
              0.2070386097583905, 0.3349410842350724, 0.9351019145883406], 
             UndirectedEdge[76, 92] -> 
             RGBColor[
              0.40232362412491923`, 0.5218329152024708, 0.9471499291925627], 
             UndirectedEdge[28, 96] -> 
             RGBColor[
              0.18736899641384372`, 0.31426707348443716`, 0.9339817592069539],
              UndirectedEdge[46, 98] -> 
             RGBColor[
              0.9657735490521211, 0.9720960864144944, 0.8558676301632229], 
             UndirectedEdge[21, 86] -> 
             RGBColor[
              0.36753037640043956`, 0.4856027175768247, 0.9451551681776447], 
             UndirectedEdge[6, 32] -> 
             RGBColor[
              0.23379883476419488`, 0.36306777741243473`, 0.9366258698142159],
              UndirectedEdge[9, 74] -> 
             RGBColor[
              0.22016441534737297`, 0.34873713813323437`, 0.935849409798744], 
             UndirectedEdge[1, 27] -> 
             RGBColor[
              0.19822541723011683`, 0.32567786009917643`, 0.9346000163118053],
              UndirectedEdge[88, 90] -> 
             RGBColor[
              0.28484036574416677`, 0.41189212163565686`, 0.9397092229611329],
              UndirectedEdge[42, 45] -> 
             RGBColor[
              0.19016897419109907`, 0.31721002765717715`, 0.9341412137991727],
              UndirectedEdge[81, 88] -> 
             RGBColor[
              0.48880977724143615`, 0.5780548235860858, 0.9563980838005164], 
             UndirectedEdge[5, 76] -> 
             RGBColor[
              0.27513108512735623`, 0.4061873948398703, 0.9389915142005446], 
             UndirectedEdge[7, 49] -> 
             RGBColor[
              0.5732896184810699, 0.6471945220280447, 0.9642335866899097], 
             UndirectedEdge[1, 76] -> 
             RGBColor[
              0.2621360081820475, 0.3925287450348843, 0.9382514637930028], 
             UndirectedEdge[6, 15] -> 
             RGBColor[
              0.6315008492289604, 0.6954854366247367, 0.8298610733749225], 
             UndirectedEdge[43, 60] -> 
             RGBColor[
              0.2924335043637015, 0.42262240817937136`, 0.9400409713689225], 
             UndirectedEdge[32, 37] -> 
             RGBColor[
              0.19205007280896977`, 0.3191871815731003, 0.9342483395826244], 
             UndirectedEdge[37, 89] -> 
             RGBColor[
              0.19752982452168466`, 0.3249467480594892, 0.9345604033360972], 
             UndirectedEdge[29, 58] -> 
             RGBColor[
              0.7579297825740439, 0.3814652263300655, 0.43779927612141567`], 
             UndirectedEdge[20, 89] -> 
             RGBColor[
              0.2456063835874661, 0.3754782598675277, 0.9372982922519981], 
             UndirectedEdge[17, 73] -> 
             RGBColor[
              0.1963725290981132, 0.3237303571925477, 0.9344944970737901], 
             UndirectedEdge[16, 90] -> 
             RGBColor[
              0.6805644673917302, 0.36997522389896903`, 0.4389455704937256], 
             UndirectedEdge[32, 60] -> 
             RGBColor[
              0.22675202968044164`, 0.3556611384761622, 0.93622456468951], 
             UndirectedEdge[21, 62] -> 
             RGBColor[
              0.34890637831857335`, 0.4660277147631035, 0.9440945590386185], 
             UndirectedEdge[20, 43] -> 
             RGBColor[
              0.30580810655801105`, 0.43667996308434787`, 0.9408026351779376],
              UndirectedEdge[14, 92] -> 
             RGBColor[
              0.42987144682923106`, 0.5456934546351176, 0.9489052520956983], 
             UndirectedEdge[40, 76] -> 
             RGBColor[
              0.27804030896372567`, 0.40924517354733947`, 0.9391571901942148],
              UndirectedEdge[49, 69] -> 
             RGBColor[
              0.6025439352507849, 0.6779426637838284, 0.9658995767520615], 
             UndirectedEdge[2, 82] -> 
             RGBColor[
              0.25273724661740293`, 0.3829732490348208, 0.9377043843523865], 
             UndirectedEdge[5, 75] -> 
             RGBColor[
              0.21577816809195188`, 0.3441269141636482, 0.9355996195064189], 
             UndirectedEdge[2, 87] -> 
             RGBColor[
              0.19932784970200193`, 0.3268365865253835, 0.9346627982101765], 
             UndirectedEdge[3, 54] -> 
             RGBColor[
              0.20390654252121726`, 0.33164908298427076`, 0.9349235479926619],
              UndirectedEdge[8, 35] -> 
             RGBColor[
              0.23700038499985893`, 0.3664328097001267, 0.9368081933638679], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.21225274797590385`, 0.3404214740971362, 0.9353988520462018], 
             UndirectedEdge[23, 74] -> 
             RGBColor[
              0.18455253657044016`, 0.311306795615152, 0.9338213659854511], 
             UndirectedEdge[34, 36] -> 
             RGBColor[
              0.39781672970564086`, 0.5068235554550808, 0.9478459050530449], 
             UndirectedEdge[34, 54] -> 
             RGBColor[
              0.3867137343243691, 0.4951536033387976, 0.9472136058914912], 
             UndirectedEdge[2, 99] -> 
             RGBColor[
              0.20776101952247078`, 0.33570038270054536`, 0.9351430547556955],
              UndirectedEdge[16, 98] -> 
             RGBColor[
              0.8919927511474949, 0.5383470027955178, 0.36390635727719245`], 
             UndirectedEdge[1, 32] -> 
             RGBColor[
              0.20592341895660635`, 0.3337689479952166, 0.9350384061219559], 
             UndirectedEdge[68, 97] -> 
             RGBColor[
              0.17968906241911073`, 0.3061949759200334, 0.9335443983273981], 
             UndirectedEdge[52, 67] -> 
             RGBColor[
              0.20235450125241083`, 0.3300177892056552, 0.9348351615384426], 
             UndirectedEdge[14, 78] -> 
             RGBColor[
              0.27624168332527044`, 0.40226073509944593`, 0.9392412762784097],
              UndirectedEdge[3, 70] -> 
             RGBColor[
              0.21321353822044214`, 0.3414313255617659, 0.9354535676292663], 
             UndirectedEdge[16, 81] -> 
             RGBColor[
              0.8165440750565763, 0.4807503585325883, 0.45007147771998124`], 
             UndirectedEdge[19, 85] -> 
             RGBColor[
              0.5998390141533992, 0.6652959767152865, 0.911106972285989], 
             UndirectedEdge[13, 80] -> 
             RGBColor[
              0.4067605354175463, 0.5267372642248884, 0.9471393995259555], 
             UndirectedEdge[72, 89] -> 
             RGBColor[
              0.24467233325504664`, 0.3744965137459432, 0.9372450994673704], 
             UndirectedEdge[14, 39] -> 
             RGBColor[
              0.6895354931247121, 0.4243337318593296, 0.44562315571375444`], 
             UndirectedEdge[29, 83] -> 
             RGBColor[
              0.7502585021513695, 0.3225004034248742, 0.4304532493251906], 
             UndirectedEdge[25, 31] -> 
             RGBColor[
              0.19308848481093063`, 0.3202786184262848, 0.9343074756099432], 
             UndirectedEdge[43, 72] -> 
             RGBColor[
              0.3048740562255916, 0.43569821696276345`, 0.94074944239331], 
             UndirectedEdge[33, 66] -> 
             RGBColor[
              0.19757591199460448`, 0.3249951889156425, 0.9345630279494997], 
             UndirectedEdge[43, 76] -> 
             RGBColor[
              0.32171055269326987`, 0.4530712439255453, 0.9417200898335113], 
             UndirectedEdge[16, 57] -> 
             RGBColor[
              0.683383041703988, 0.3724165313025828, 0.4391251675565353], 
             UndirectedEdge[71, 93] -> 
             RGBColor[
              0.20508223839917897`, 0.3328848138954327, 0.9349905021336256], 
             UndirectedEdge[58, 80] -> 
             RGBColor[
              0.674247117910368, 0.3119307957679389, 0.43165274639340356`], 
             UndirectedEdge[8, 31] -> 
             RGBColor[
              0.21009981607164213`, 0.33815860616199034`, 0.9352762457592313],
              UndirectedEdge[28, 30] -> 
             RGBColor[
              0.2663098559359903, 0.3938583625165767, 0.9386011032163053], 
             UndirectedEdge[15, 98] -> 
             RGBColor[
              0.9952110527812865, 0.9921652510730361, 0.7201308330785238], 
             UndirectedEdge[34, 55] -> 
             RGBColor[
              0.4037685673369896, 0.5130793141739299, 0.9481848534011954], 
             UndirectedEdge[23, 62] -> 
             RGBColor[
              0.19653773134174465`, 0.32390399522503155`, 0.9345039050971701],
              UndirectedEdge[26, 85] -> 
             RGBColor[
              0.19811162690999523`, 0.32555825925800563`, 0.9345935361214122],
              UndirectedEdge[41, 88] -> 
             RGBColor[
              0.1995557584162146, 0.3270761330342681, 0.9346757772742902], 
             UndirectedEdge[7, 62] -> 
             RGBColor[
              0.21579119455271614`, 0.3441406057998368, 0.9356003613440885], 
             UndirectedEdge[67, 68] -> 
             RGBColor[
              0.1944928070291569, 0.32175465011681187`, 0.9343874496827627], 
             UndirectedEdge[32, 48] -> 
             RGBColor[
              0.19316456995763537`, 0.32035858873954837`, 0.9343118085464901],
              UndirectedEdge[22, 87] -> 
             RGBColor[
              0.22873824331541243`, 0.35774877493973456`, 0.9363376766176819],
              UndirectedEdge[5, 78] -> 
             RGBColor[
              0.21158327851286368`, 0.3397178192446654, 0.9353607267506729], 
             UndirectedEdge[40, 93] -> 
             RGBColor[
              0.236137925673375, 0.36552631026491245`, 0.9367590775811188], 
             UndirectedEdge[7, 30] -> 
             RGBColor[
              0.2856734020298586, 0.41421067718096427`, 0.9397038285205517], 
             UndirectedEdge[40, 90] -> 
             RGBColor[
              0.3023778436365895, 0.4303251228409142, 0.9407079563827329], 
             UndirectedEdge[53, 88] -> 
             RGBColor[
              0.1957621060390055, 0.3230887638543682, 0.9344597343836138], 
             UndirectedEdge[31, 59] -> 
             RGBColor[
              0.27766757170409395`, 0.40537779156617293`, 0.9392632225209877],
              UndirectedEdge[70, 82] -> 
             RGBColor[
              0.25736479876417967`, 0.3878370997448354, 0.9379679166012955], 
             UndirectedEdge[12, 97] -> 
             RGBColor[
              0.18675824728545593`, 0.31362513742677023`, 0.9339469779476146],
              UndirectedEdge[16, 100] -> 
             RGBColor[
              0.8619993292864006, 0.5167196429721799, 0.4544801500563016], 
             UndirectedEdge[15, 40] -> 
             RGBColor[
              0.61952973420305, 0.6829030357199737, 0.8291793360838746], 
             UndirectedEdge[43, 83] -> 
             RGBColor[
              0.6552724793836961, 0.24317557219636227`, 0.423586479613959], 
             UndirectedEdge[13, 100] -> 
             RGBColor[
              0.6768264403186011, 0.74504676846516, 0.9703083260751425], 
             UndirectedEdge[39, 92] -> 
             RGBColor[
              0.7312249159148163, 0.45973546819787614`, 0.44847506602327525`],
              UndirectedEdge[57, 90] -> 
             RGBColor[
              0.36514459804956567`, 0.4906916309545739, 0.9444876687963963], 
             UndirectedEdge[64, 86] -> 
             RGBColor[
              0.24146347567626655`, 0.37112380097732395`, 0.9370623597753382],
              UndirectedEdge[50, 59] -> 
             RGBColor[
              0.41263910782660224`, 0.531228192948697, 0.9476799784741149], 
             UndirectedEdge[14, 93] -> 
             RGBColor[
              0.2978871066494123, 0.4250114474122238, 0.9404739511151854], 
             UndirectedEdge[16, 34] -> 
             RGBColor[
              0.7539222687443959, 0.43120299906100945`, 0.44425841895619067`],
              UndirectedEdge[29, 46] -> 
             RGBColor[
              0.7762415083549385, 0.8256471882824058, 0.9777791873747175], 
             UndirectedEdge[57, 79] -> 
             RGBColor[
              0.3260498087811563, 0.45442406973737776`, 0.9420846649163321], 
             UndirectedEdge[29, 30] -> 
             RGBColor[
              0.48072357930495235`, 0.5863794040146906, 0.9530737757794854], 
             UndirectedEdge[28, 95] -> 
             RGBColor[
              0.18702499739012893`, 0.31390550869971506`, 0.9339621689714543],
              UndirectedEdge[38, 77] -> 
             RGBColor[
              0.21179936694727172`, 0.33994494189002633`, 0.9353730326673382],
              UndirectedEdge[20, 27] -> 
             RGBColor[
              0.23242863014826168`, 0.36162760548509854`, 0.9365478386883745],
              UndirectedEdge[15, 16] -> 
             RGBColor[
              0.8919990611027038, 0.5383604991516755, 0.36459315696115346`], 
             UndirectedEdge[31, 54] -> 
             RGBColor[
              0.19896954140629303`, 0.3264599817885353, 0.9346423930828055], 
             UndirectedEdge[44, 90] -> 
             RGBColor[
              0.3720751615660183, 0.49669453673227437`, 0.9449292781752079], 
             UndirectedEdge[11, 49] -> 
             RGBColor[
              0.8647666069400279, 0.8950942864678116, 0.9869398266286489], 
             UndirectedEdge[47, 89] -> 
             RGBColor[
              0.19533822133609224`, 0.3226432341557639, 0.9344355947768641], 
             UndirectedEdge[8, 22] -> 
             RGBColor[
              0.23765743984076979`, 0.3671234159976071, 0.9368456116650321], 
             UndirectedEdge[92, 98] -> 
             RGBColor[
              0.7438035844314304, 0.7954705328408687, 0.836141875556281], 
             UndirectedEdge[80, 88] -> 
             RGBColor[
              0.28692675368511766`, 0.4136992460052015, 0.9398421657558098], 
             UndirectedEdge[21, 55] -> 
             RGBColor[
              0.35940725673521917`, 0.4770648037731443, 0.9446925685297891], 
             UndirectedEdge[40, 41] -> 
             RGBColor[
              0.2170932363086373, 0.34550913423952534`, 0.9356745106958901], 
             UndirectedEdge[32, 43] -> 
             RGBColor[
              0.26549796346782867`, 0.39431144688587766`, 0.9385070321624644],
              UndirectedEdge[5, 79] -> 
             RGBColor[
              0.2603738305318108, 0.3909997829162489, 0.9381392765089985], 
             UndirectedEdge[55, 87] -> 
             RGBColor[
              0.21170323916217432`, 0.33984390549303534`, 0.9353675583321852],
              UndirectedEdge[42, 57] -> 
             RGBColor[
              0.2840006122279915, 0.410227698086955, 0.9396900253788412], 
             UndirectedEdge[9, 29] -> 
             RGBColor[
              0.43744574474497594`, 0.5442722153841734, 0.9504853882830122], 
             UndirectedEdge[46, 86] -> 
             RGBColor[
              0.5895693718105064, 0.6622843134550676, 0.9648863571411943], 
             UndirectedEdge[51, 61] -> 
             RGBColor[
              0.24151604904004081`, 0.37117905891599445`, 0.9370653537506299],
              UndirectedEdge[14, 90] -> 
             RGBColor[
              0.3641270246126268, 0.4898102599882255, 0.9444228299167994], 
             UndirectedEdge[41, 44] -> 
             RGBColor[
              0.2867905542380661, 0.4118785481308856, 0.9398958324883652], 
             UndirectedEdge[14, 98] -> 
             RGBColor[
              0.6812694502462739, 0.7423679283330488, 0.8318640100919996], 
             UndirectedEdge[5, 92] -> 
             RGBColor[
              0.36521304201682436`, 0.48315053878033715`, 0.9450247025679616],
              UndirectedEdge[15, 94] -> 
             RGBColor[
              0.8908238697691686, 0.5293274635899978, 0.3634677924129714], 
             UndirectedEdge[8, 96] -> 
             RGBColor[
              0.20106290522588166`, 0.3286602398898551, 0.9347616070554767], 
             UndirectedEdge[21, 83] -> 
             RGBColor[
              0.7089685064785451, 0.2889793248445678, 0.427202749615588], 
             UndirectedEdge[27, 89] -> 
             RGBColor[
              0.1975982387707942, 0.32501865577301725`, 0.9345642994263743], 
             UndirectedEdge[4, 33] -> 
             RGBColor[
              0.1818976062750878, 0.30851629554243354`, 0.933670171632748], 
             UndirectedEdge[17, 52] -> 
             RGBColor[
              0.188210848555223, 0.3151519134615354, 0.9340297014409968], 
             UndirectedEdge[26, 56] -> 
             RGBColor[
              0.18790709673417716`, 0.31483265103863844`, 0.9340124032241488],
              UndirectedEdge[20, 92] -> 
             RGBColor[
              0.38642117798966047`, 0.5054416343612733, 0.946232474536989], 
             UndirectedEdge[48, 68] -> 
             RGBColor[
              0.18324792848096086`, 0.30993556979617887`, 0.9337470704847499],
              UndirectedEdge[15, 19] -> 
             RGBColor[
              0.9904582953945565, 0.9902692342383527, 0.803938824667576], 
             UndirectedEdge[19, 34] -> 
             RGBColor[
              0.7833431068570946, 0.8295329841023538, 0.9234367176601319], 
             UndirectedEdge[36, 55] -> 
             RGBColor[
              0.22059515640345434`, 0.34918987429373616`, 0.9358739398646634],
              UndirectedEdge[20, 32] -> 
             RGBColor[
              0.2401266318747512, 0.3697186933811387, 0.9369862284985251], 
             UndirectedEdge[83, 98] -> 
             RGBColor[
              0.876613195949491, 0.4201330021795999, 0.34917887785086077`], 
             UndirectedEdge[2, 8] -> 
             RGBColor[
              0.2082470462273593, 0.33621122758325606`, 0.9351707332575268], 
             UndirectedEdge[22, 62] -> 
             RGBColor[
              0.23308111977139537`, 0.3623134134492436, 0.9365849970071402], 
             UndirectedEdge[7, 9] -> 
             RGBColor[
              0.2423955674698822, 0.37210348855044706`, 0.9371154410240785], 
             UndirectedEdge[44, 92] -> 
             RGBColor[
              0.43781958378262253`, 0.5525777313791664, 0.9494117003541069], 
             UndirectedEdge[6, 20] -> 
             RGBColor[
              0.27410897785437727`, 0.40543629361090494`, 0.9389214728296891],
              UndirectedEdge[11, 30] -> 
             RGBColor[
              0.5771503904888168, 0.6621104416207312, 0.9624100684592909], 
             UndirectedEdge[7, 74] -> 
             RGBColor[
              0.20380599978141165`, 0.33154340618995726`, 0.9349178222323695],
              UndirectedEdge[20, 72] -> 
             RGBColor[
              0.27950272463251413`, 0.41110546345802457`, 0.9392286387293707],
              UndirectedEdge[29, 86] -> 
             RGBColor[
              0.4294653699096761, 0.5358843354472843, 0.9500309177420485], 
             UndirectedEdge[12, 73] -> 
             RGBColor[
              0.20307576546370915`, 0.33077588362252197`, 0.9348762364682612],
              UndirectedEdge[65, 93] -> 
             RGBColor[
              0.20455172295727864`, 0.33232720852937364`, 0.9349602900640366],
              UndirectedEdge[36, 96] -> 
             RGBColor[
              0.20103562594180435`, 0.3286315676326833, 0.9347600535406047], 
             UndirectedEdge[2, 70] -> 
             RGBColor[
              0.20642376726123507`, 0.3342948457872962, 0.9350669002177054], 
             UndirectedEdge[31, 82] -> 
             RGBColor[
              0.2545900164616858, 0.38492062761355506`, 0.937809896854091], 
             UndirectedEdge[48, 89] -> 
             RGBColor[
              0.19864432167035026`, 0.3261181552259373, 0.934623872299963], 
             UndirectedEdge[49, 82] -> 
             RGBColor[
              0.6121101815892831, 0.6879973952206397, 0.9664443603290458], 
             UndirectedEdge[40, 75] -> 
             RGBColor[
              0.2186873919283213, 0.3471846928711173, 0.9357652955000892], 
             UndirectedEdge[19, 49] -> 
             RGBColor[
              0.953119079066616, 0.9639161301591762, 0.939499968326401], 
             UndirectedEdge[53, 85] -> 
             RGBColor[
              0.19837108620132082`, 0.325830967423858, 0.9346083119442175], 
             UndirectedEdge[69, 82] -> 
             RGBColor[
              0.2941120317818493, 0.4264607715555487, 0.9400606171589923], 
             UndirectedEdge[63, 91] -> 
             RGBColor[
              0.20107373419917063`, 0.3286716218273784, 0.9347622237494856], 
             UndirectedEdge[9, 96] -> 
             RGBColor[
              0.2230909580736733, 0.35181312009210186`, 0.9360160720775748], 
             UndirectedEdge[18, 64] -> 
             RGBColor[
              0.2146734226669212, 0.34296575667703544`, 0.9355367058887878], 
             UndirectedEdge[59, 87] -> 
             RGBColor[
              0.27334643644735473`, 0.4008360044355407, 0.9390171402606632], 
             UndirectedEdge[51, 66] -> 
             RGBColor[
              0.24440383748134425`, 0.3742143076641667, 0.937229809030262], 
             UndirectedEdge[49, 81] -> 
             RGBColor[
              0.8446988223169681, 0.8794171805994653, 0.9849396574015319], 
             UndirectedEdge[3, 35] -> 
             RGBColor[
              0.23733932484616505`, 0.36678905696862185`, 0.9368274954866984],
              UndirectedEdge[9, 36] -> 
             RGBColor[
              0.23669865090397454`, 0.3661156680343056, 0.9367910100534829], 
             UndirectedEdge[56, 57] -> 
             RGBColor[
              0.2814726771990508, 0.4075706780912001, 0.9395460632186877], 
             UndirectedEdge[49, 58] -> 
             RGBColor[
              0.8593979754420806, 0.4615425853881645, 0.44758580010359683`], 
             UndirectedEdge[21, 58] -> 
             RGBColor[
              0.7166397869012195, 0.3479441477497591, 0.4345487764118131], 
             UndirectedEdge[48, 60] -> 
             RGBColor[
              0.2201001108535082, 0.348669550033042, 0.9358457477529483], 
             UndirectedEdge[21, 29] -> 
             RGBColor[
              0.5542025129448718, 0.648965592404163, 0.9580479984111678], 
             UndirectedEdge[34, 100] -> 
             RGBColor[
              0.7431057314521832, 0.7989879612020303, 0.9754894152397433], 
             UndirectedEdge[11, 64] -> 
             RGBColor[
              0.5245624234045633, 0.6102177134107027, 0.9592914826886669], 
             UndirectedEdge[73, 97] -> 
             RGBColor[
              0.19571243718525488`, 0.32303655873988907`, 0.9344569058158713],
              UndirectedEdge[64, 74] -> 
             RGBColor[
              0.21085428282309587`, 0.33895159855372314`, 0.9353192115245932],
              UndirectedEdge[40, 78] -> 
             RGBColor[
              0.2144925023492331, 0.3427755979521345, 0.9355264027443431], 
             UndirectedEdge[49, 99] -> 
             RGBColor[
              0.567133954494351, 0.6407245288863643, 0.9638830307323548], 
             UndirectedEdge[82, 87] -> 
             RGBColor[
              0.25026888120494656`, 0.3803788404829227, 0.9375638145937665], 
             UndirectedEdge[44, 100] -> 
             RGBColor[
              0.644227454408024, 0.7168111653420908, 0.9682311475190719], 
             UndirectedEdge[16, 49] -> 
             RGBColor[
              0.8671062502174101, 0.5207917630988911, 0.4549672527337034], 
             UndirectedEdge[41, 93] -> 
             RGBColor[
              0.20939221129001212`, 0.3374148686717628, 0.935235948713725], 
             UndirectedEdge[17, 68] -> 
             RGBColor[
              0.18034915433196902`, 0.3068887743726921, 0.9335819895853168], 
             UndirectedEdge[25, 54] -> 
             RGBColor[
              0.18655627141419961`, 0.31341284798007, 0.9339354757205431], 
             UndirectedEdge[22, 96] -> 
             RGBColor[
              0.22402246772639123`, 0.3527921957982316, 0.9360691201742519], 
             UndirectedEdge[88, 100] -> 
             RGBColor[
              0.5569926585861724, 0.6320087502454732, 0.9630110923049968], 
             UndirectedEdge[13, 16] -> 
             RGBColor[
              0.7097360746553412, 0.39524220390309606`, 0.44080435951312347`],
              UndirectedEdge[60, 73] -> 
             RGBColor[
              0.2328587629699113, 0.3620797023526483, 0.9365723341162431], 
             UndirectedEdge[81, 90] -> 
             RGBColor[
              0.5648861480784482, 0.6531923717995822, 0.9609071340415651], 
             UndirectedEdge[19, 57] -> 
             RGBColor[
              0.6775342662964828, 0.7413532824647138, 0.9157368405606489], 
             UndirectedEdge[10, 67] -> 
             RGBColor[
              0.2003664206709043, 0.32792819046290256`, 0.9347219432904275], 
             UndirectedEdge[85, 88] -> 
             RGBColor[
              0.21137297506947, 0.33949677699165026`, 0.9353487502806876], 
             UndirectedEdge[9, 55] -> 
             RGBColor[
              0.24265048853532328`, 0.3723714267531547, 0.9371299584016335], 
             UndirectedEdge[22, 59] -> 
             RGBColor[
              0.3052251954732216, 0.4343426014017897, 0.9408325884267885], 
             UndirectedEdge[56, 88] -> 
             RGBColor[
              0.2011684448936519, 0.3287711687722831, 0.9347676173834243], 
             UndirectedEdge[33, 70] -> 
             RGBColor[
              0.19557827090836621`, 0.3228955414762458, 0.9344492652448837], 
             UndirectedEdge[87, 99] -> 
             RGBColor[
              0.2052926541100144, 0.3331059741486473, 0.9350024849970755], 
             UndirectedEdge[16, 19] -> 
             RGBColor[
              0.8888242462230083, 0.5370829915723956, 0.41977835166989397`], 
             UndirectedEdge[5, 14] -> 
             RGBColor[
              0.30267890783166806`, 0.43004793427251725`, 0.9407468371036802],
              UndirectedEdge[21, 36] -> 
             RGBColor[
              0.35345541910387046`, 0.4708090450542952, 0.9443536201816385], 
             UndirectedEdge[36, 74] -> 
             RGBColor[
              0.198109083215504, 0.3255555856738158, 0.9345933912617739], 
             UndirectedEdge[6, 27] -> 
             RGBColor[
              0.22610083303770537`, 0.35497668951639455`, 0.9361874800040654],
              UndirectedEdge[60, 67] -> 
             RGBColor[
              0.23134498940170423`, 0.360488630353675, 0.936486126950961], 
             UndirectedEdge[20, 47] -> 
             RGBColor[
              0.23016861271355973`, 0.3592521838678452, 0.9364191340388645], 
             UndirectedEdge[19, 50] -> 
             RGBColor[
              0.7305704500615269, 0.7866897639346156, 0.9192822608045734], 
             UndirectedEdge[29, 64] -> 
             RGBColor[
              0.42813561222069885`, 0.5344866758046621, 0.9499551900088614], 
             UndirectedEdge[20, 37] -> 
             RGBColor[
              0.23236021589915215`, 0.3615556977715705, 0.9365439425980976], 
             UndirectedEdge[15, 92] -> 
             RGBColor[
              0.7438130493642436, 0.795490777375105, 0.8371720750822225], 
             UndirectedEdge[48, 84] -> 
             RGBColor[
              0.18976351469532046`, 0.31678386401949704`, 0.9341181234807117],
              UndirectedEdge[32, 72] -> 
             RGBColor[
              0.23919258154233175`, 0.3687369472595543, 0.9369330357138975], 
             UndirectedEdge[44, 93] -> 
             RGBColor[
              0.30583524360280373`, 0.43189572415627264`, 0.9409803993735939],
              UndirectedEdge[2, 50] -> 
             RGBColor[
              0.3386205210812494, 0.45722877503854, 0.9433256364236282], 
             UndirectedEdge[76, 94] -> 
             RGBColor[
              0.6631642529429523, 0.34688888880824165`, 0.43678636181986485`],
              UndirectedEdge[56, 79] -> 
             RGBColor[
              0.23815002646225467`, 0.36764115576858336`, 0.9368736637444091],
              UndirectedEdge[6, 37] -> 
             RGBColor[
              0.22603241878859584`, 0.3549047818028665, 0.9361835839137884], 
             UndirectedEdge[40, 44] -> 
             RGBColor[
              0.3135362686214289, 0.43998998972403525`, 0.9414189613557591], 
             UndirectedEdge[56, 90] -> 
             RGBColor[
              0.27724481573066395`, 0.4039087169857795, 0.9392766676244733], 
             UndirectedEdge[16, 79] -> 
             RGBColor[
              0.654501274546124, 0.34579684975417163`, 0.43734356790701623`], 
             UndirectedEdge[13, 81] -> 
             RGBColor[
              0.6086435589738648, 0.6910928418057727, 0.963695317570662], 
             UndirectedEdge[90, 100] -> 
             RGBColor[
              0.6330690294231844, 0.7071462984589696, 0.9675201425460458], 
             UndirectedEdge[34, 35] -> 
             RGBColor[
              0.4201465166493169, 0.5302935773231487, 0.9491175533855278], 
             UndirectedEdge[7, 99] -> 
             RGBColor[
              0.21988148791720208`, 0.34843976346548955`, 0.9358332975001493],
              UndirectedEdge[45, 53] -> 
             RGBColor[
              0.18223470030751196`, 0.3088706027435074, 0.9336893686392087]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 25 -> 
             RGBColor[
              0.18067521481883725`, 0.30723148461781946`, 0.9336005582476807],
              55 -> RGBColor[
              0.22654699403480308`, 0.35544563301258525`, 0.936212888212814], 
             90 -> RGBColor[
              0.36091673658117884`, 0.4870296698491533, 0.9442182732021818], 
             27 -> RGBColor[
              0.18442048533158978`, 0.31116800139058814`, 0.9338138458627508],
              15 -> RGBColor[
              0.9952205177140999, 0.9921854956072724, 0.7211610326044653], 98 -> 
             RGBColor[
              0.9952015878484732, 0.9921450065387998, 0.7191006335525822], 38 -> 
             RGBColor[
              0.24467173389454344`, 0.3744958837800527, 0.9372450653346764], 
             99 -> RGBColor[
              0.21372582393048328`, 0.34196977032380915`, 0.9354827415425945],
              71 -> RGBColor[
              0.18172757614360815`, 0.30833758309371545`, 0.9336604886682974],
              41 -> RGBColor[
              0.19034752192527446`, 0.31739769264637574`, 0.9341513818284962],
              75 -> RGBColor[
              0.1935358331646424, 0.3207488099095597, 0.9343329514368944], 64 -> 
             RGBColor[
              0.2401337179872893, 0.3697261413347018, 0.9369866320421513], 63 -> 
             RGBColor[
              0.21850839554735407`, 0.34699655632569476`, 0.9357551019209945],
              85 -> RGBColor[
              0.21398195523178531`, 0.34223898056114005`, 0.9354973278412912],
              3 -> RGBColor[
              0.21537575703287248`, 0.343703954626221, 0.9355767027919182], 
             86 -> RGBColor[
              0.2427932333652438, 0.3725214606199461, 0.9371380875085253], 94 -> 
             RGBColor[
              0.8386255457967029, 0.2978984475813605, 0.18462117231722439`], 
             61 -> RGBColor[
              0.2092710246978815, 0.33728749387975976`, 0.9352290473165826], 
             84 -> RGBColor[
              0.193014378259939, 0.32020072774256586`, 0.934303255351495], 76 -> 
             RGBColor[
              0.31224166723545116`, 0.4448697712620039, 0.9411167408251457], 
             21 -> 
             RGBColor[
              0.4922675194356353, 0.5986839745337034, 0.9531722488467641], 87 -> 
             RGBColor[
              0.19685948428954556`, 0.3242421779734855, 0.9345222284515565], 
             95 -> RGBColor[
              0.18673993506407352`, 0.31360589012103546`, 0.9339459350936974],
              72 -> RGBColor[
              0.2785686743000947, 0.4101237173364401, 0.9391754459447431], 42 -> 
             RGBColor[
              0.19862876493803053`, 0.32610180411391543`, 0.9346229863670715],
              66 -> RGBColor[
              0.21504660158048836`, 0.34335799137610423`, 0.9355579578758467],
              1 -> RGBColor[
              0.21203034912864388`, 0.34018771880776466`, 0.9353861867608598],
              24 -> RGBColor[
              0.1817669047970064, 0.30837892000201766`, 0.9336627283769269], 
             54 -> RGBColor[
              0.192437328009562, 0.3195942113423206, 0.9342703931934054], 4 -> 
             RGBColor[
              0.183689990141455, 0.3104002046296863, 0.9337722452423434], 7 -> 
             RGBColor[
              0.22603715190392087`, 0.35490975660716995`, 0.936183853457704], 
             100 -> RGBColor[
              0.9052213222651901, 0.927262927068786, 0.9908220118899097], 12 -> 
             RGBColor[
              0.1941215755639102, 0.3213644623094032, 0.9343663086000046], 65 -> 
             RGBColor[
              0.18066654525980752`, 0.30722237236159744`, 0.9336000645291195],
              8 -> RGBColor[
              0.21469787734026025`, 0.3429914600892306, 0.935538098546257], 
             57 -> RGBColor[
              0.36937245951795245`, 0.4943535920599945, 0.9447570643906108], 
             74 -> RGBColor[
              0.18157484765890242`, 0.3081770557727445, 0.933651791007035], 
             37 -> RGBColor[
              0.18428365683337072`, 0.31102418596353204`, 0.9338060536821968],
              43 -> RGBColor[
              0.3311794381510885, 0.4612727165890868, 0.9423234388418769], 39 -> 
             RGBColor[
              0.8506345833650307, 0.3902051727253455, 0.1961210402549231], 58 -> 
             RGBColor[
              0.8288259206340116, 0.22257423435778703`, 0.17523704019433756`],
              11 -> RGBColor[
              0.8089911288218372, 0.8507092854867038, 0.9815963333351826], 51 -> 
             RGBColor[
              0.2737610733822001, 0.40507062395222915`, 0.9389016601846771], 
             48 -> RGBColor[
              0.18651265113070192`, 0.3133670002964282, 0.9339329916099283], 
             20 -> 
             RGBColor[
              0.2804367749649336, 0.412087209579609, 0.9392818315139984], 33 -> 
             RGBColor[
              0.1801052224087206, 0.3066323864551807, 0.9335680980231528], 45 -> 
             RGBColor[
              0.1817091834441676, 0.3083182512004389, 0.9336594412312738], 23 -> 
             RGBColor[
              0.1875302254819779, 0.3144365354575595, 0.9339909409638671], 22 -> 
             RGBColor[
              0.2606170023412793, 0.3912553719059836, 0.9381531247838073], 2 -> 
             RGBColor[
              0.2017962151144583, 0.3294309950772815, 0.9348033679687965], 60 -> 
             RGBColor[
              0.25368757057631447`, 0.38397209976965585`, 0.9377585038959682],
              16 -> RGBColor[
              0.8403883327970058, 0.3114480009238769, 0.18630921913949752`], 
             79 -> RGBColor[
              0.2827271580443602, 0.414494547414761, 0.9394122654420536], 89 -> 
             RGBColor[
              0.2107759922099986, 0.33886931015544636`, 0.9353147529899978], 
             36 -> RGBColor[
              0.21464331877210557`, 0.34293411557488707`, 0.9355349915165129],
              52 -> RGBColor[
              0.1957065942777277, 0.32303041747361627`, 0.9344565730709314], 
             32 -> RGBColor[
              0.1998164887845688, 0.3273501771826685, 0.9346906254830519], 31 -> 
             RGBColor[
              0.20550175480302402`, 0.3333257522347501, 0.9350143929722056], 
             68 -> RGBColor[
              0.1799832058312198, 0.30650413929592957`, 0.9335611493595715], 
             73 -> RGBColor[
              0.2120299553635081, 0.3401873049356408, 0.9353861643365179], 82 -> 
             RGBColor[
              0.30367827812034753`, 0.43651550299235997`, 0.9406054007359764],
              35 -> RGBColor[
              0.2593028926594576, 0.38987415931102276`, 0.9380782881814786], 
             88 -> RGBColor[
              0.2087639949071547, 0.3367545734221604, 0.935200172720084], 50 -> 
             RGBColor[
              0.4754448270480406, 0.5850265549997984, 0.9518479048784599], 19 -> 
             RGBColor[
              0.9856960730750132, 0.9883529728694329, 0.8867166167306869], 17 -> 
             RGBColor[
              0.18071510283271827`, 0.3072734094494546, 0.9336028298110622], 
             96 -> RGBColor[
              0.1874279331115031, 0.3143290196904796, 0.9339851155646965], 14 -> 
             RGBColor[
              0.3673373126440748, 0.49259085012729775`, 0.944627386631417], 5 -> 
             RGBColor[
              0.23802050301926134`, 0.36750501841773675`, 0.9368662875759435],
              34 -> RGBColor[
              0.5809901406391762, 0.6707129953352746, 0.9601568185895769], 97 -> 
             RGBColor[
              0.17939491900700166`, 0.3058858125441373, 0.9335276472952246], 
             93 -> RGBColor[
              0.22843690065474978`, 0.35743204469714984`, 0.9363205155989537],
              81 -> RGBColor[
              0.7688555595757176, 0.8193550737500112, 0.9775959948809486], 69 -> 
             RGBColor[
              0.2845457854433511, 0.4164060401187374, 0.939515833582008], 9 -> 
             RGBColor[
              0.2587539830358435, 0.38929722049372417`, 0.9380470285904529], 
             13 -> RGBColor[
              0.44843155837201204`, 0.5628306098615342, 0.9497946402603753], 
             30 -> RGBColor[
              0.34530965215579634`, 0.47351159775475865`, 0.9432238035833993],
              59 -> RGBColor[
              0.3498333886051639, 0.47742983089759583`, 0.9435120520697698], 
             28 -> RGBColor[
              0.18731005971618434`, 0.31420512727839467`, 0.9339784028492112],
              80 -> RGBColor[
              0.3650895124630806, 0.49064391858824263`, 0.9444841587915357], 
             47 -> RGBColor[
              0.1799004504621859, 0.30641715815608145`, 0.9335564365637306], 
             62 -> RGBColor[
              0.2055452372015114, 0.33337145499250365`, 0.935016869230473], 
             77 -> RGBColor[0.178927, 0.305394, 0.933501], 78 -> 
             RGBColor[
              0.185146054006466, 0.31193062007159406`, 0.9338551659254023], 
             40 -> RGBColor[
              0.24383895069200018`, 0.373620575832675, 0.937197639563284], 67 -> 
             RGBColor[
              0.20900240822709396`, 0.33700516093769417`, 0.9352137500059537],
              56 -> RGBColor[
              0.19357289488014912`, 0.3207877641224057, 0.9343350620467646], 
             10 -> RGBColor[
              0.19173043311471463`, 0.318851219988111, 0.9342301365749012], 
             53 -> RGBColor[
              0.18276021717085633`, 0.30942295428657596`, 0.9337192960471437],
              26 -> RGBColor[
              0.18224129858820518`, 0.30887753795487116`, 0.933689744401533], 
             18 -> RGBColor[
              0.1892131273465531, 0.3162053720193691, 0.9340867797354244], 29 -> 
             RGBColor[
              0.6161375064541084, 0.6992472102746226, 0.9629237479755716], 92 -> 
             RGBColor[
              0.4924055810143873, 0.5987960591429375, 0.9531831175599796], 46 -> 
             RGBColor[
              0.9363455102557688, 0.952047166290189, 0.9926346267738634], 49 -> 
             RGBColor[
              0.9205420850582187, 0.9394792874489195, 0.9922833199221152], 83 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 70 -> 
             RGBColor[
              0.21105131940801183`, 0.33915869649731084`, 0.9353304324666145],
              44 -> RGBColor[
              0.3832335865508577, 0.5063594036153954, 0.9456402831482341], 91 -> 
             RGBColor[
              0.18363907285098718`, 0.310346687329062, 0.9337693455779766], 6 -> 
             RGBColor[
              0.26778118074382096`, 0.39878537764220096`, 
               0.9385611141453799]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9k4031PkCh8f7eJ1hxozXMb8Zqt0oHV0lbd9PRdeWRZRI7GxRYazaZKuh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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 6}], {
             RGBColor[
             0.23990576493623242`, 0.36948654822498284`, 0.9369736504531199]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 14}], {
             RGBColor[
             0.28968383088635935`, 0.4163892844675312, 0.9400067866961384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 20}], {
             RGBColor[
             0.24623356204678873`, 0.3761374641936868, 0.9373340091374291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 27}], {
             RGBColor[
             0.19822541723011683`, 0.32567786009917643`, 0.9346000163118053]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 32}], {
             RGBColor[
             0.20592341895660635`, 0.3337689479952166, 0.9350384061219559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 37}], {
             RGBColor[
             0.1981570029810073, 0.3256059523856484, 0.9345961202215283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 43}], {
             RGBColor[
             0.2716048936398662, 0.40073021769842576`, 0.9388548128013683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 47}], {
             RGBColor[
             0.19596539979541489`, 0.3233024384819231, 0.9344713116622951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 71}], {
             RGBColor[
             0.19687896263612603`, 0.32426265095074003`, 0.9345233377145786]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 72}], {
             RGBColor[
             0.24529951171436928`, 0.37515571807210235`, 0.9372808163528015]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 76}], {
             RGBColor[
             0.2621360081820475, 0.3925287450348843, 0.9382514637930028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 89}], {
             RGBColor[
             0.21140317066932124`, 0.3395285144816055, 0.9353504698754288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 92}], {
             RGBColor[
             0.3522179650715156, 0.4694918889753511, 0.9442846521604198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 3}], {
             RGBColor[
             0.2085859860736654, 0.33656747485175126`, 0.9351900353803573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 8}], {
             RGBColor[
             0.2082470462273593, 0.33621122758325606`, 0.9351707332575268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 25}], {
             RGBColor[
             0.19123571496664776`, 0.3183312398475505, 0.9342019631082386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 31}], {
             RGBColor[
             0.20364898495874117`, 0.3313783736560158, 0.934908880470501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 34}], {
             RGBColor[
             0.39139317787681727`, 0.5000719952062781, 0.9474800932791867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 35}], {
             RGBColor[
             0.23054955388695797`, 0.3596525771941521, 0.9364408280751375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 50}], {
             RGBColor[
             0.3386205210812494, 0.45722877503854, 0.9433256364236282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 54}], {
             RGBColor[
             0.19711677156201016`, 0.324512603209801, 0.934536880581101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 59}], {
             RGBColor[
             0.2758148018598111, 0.40343041298743865`, 0.9391577100192832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 63}], {
             RGBColor[
             0.21015230533090618`, 0.33821377570148814`, 0.9352792349448955]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 69}], {
             RGBColor[
             0.2431710002789047, 0.3729185175980094, 0.9371596007754022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 70}], {
             RGBColor[
             0.20642376726123507`, 0.3342948457872962, 0.9350669002177054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 82}], {
             RGBColor[
             0.25273724661740293`, 0.3829732490348208, 0.9377043843523865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 87}], {
             RGBColor[
             0.19932784970200193`, 0.3268365865253835, 0.9346627982101765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 99}], {
             RGBColor[
             0.20776101952247078`, 0.33570038270054536`, 0.9351430547556955]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 31}], {
             RGBColor[
             0.21043875591794825`, 0.33851485343048554`, 0.9352955478820619]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 35}], {
             RGBColor[
             0.23733932484616505`, 0.36678905696862185`, 0.9368274954866984]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 50}], {
             RGBColor[
             0.34541029204045653`, 0.4643652548130097, 0.9437123038351891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 54}], {
             RGBColor[
             0.20390654252121726`, 0.33164908298427076`, 0.9349235479926619]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 59}], {
             RGBColor[
             0.2826045728190182, 0.4105668927619084, 0.9395443774308441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 63}], {
             RGBColor[
             0.21694207629011328`, 0.3453502554759579, 0.9356659023564564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 66}], {
             RGBColor[
             0.21521117930668043`, 0.34353097300116264`, 0.9355673303338825]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 69}], {
             RGBColor[
             0.24996077123811178`, 0.38005499737247916`, 0.9375462681869631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 70}], {
             RGBColor[
             0.21321353822044214`, 0.3414313255617659, 0.9354535676292663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 82}], {
             RGBColor[
             0.25952701757661, 0.3901097288092905, 0.9380910517639474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 91}], {
             RGBColor[
             0.19950741494192983`, 0.3270253209776415, 0.9346730241849475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 33}], {
             RGBColor[
             0.1818976062750878, 0.30851629554243354`, 0.933670171632748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 38}], {
             RGBColor[
             0.21418086201799924`, 0.3424480442048695, 0.9355086552885099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 51}], {
             RGBColor[
             0.22872553176182758`, 0.35773541429095773`, 0.9363369527135103]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 66}], {
             RGBColor[
             0.19936829586097168`, 0.3268790980028953, 0.934665101559095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 14}], {
             RGBColor[
             0.30267890783166806`, 0.43004793427251725`, 0.9407468371036802]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 15}], {
             RGBColor[
             0.6166205103666806, 0.6798452570125046, 0.8290136600902044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 40}], {
             RGBColor[
             0.24092972685563074`, 0.3705627971252059, 0.9370319635696137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 41}], {
             RGBColor[
             0.2141840124722679, 0.34245135553205625`, 0.9355088347022198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 44}], {
             RGBColor[
             0.31062704478505954`, 0.4369322110165661, 0.9412532853620887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 56}], {
             RGBColor[
             0.2157966989497052, 0.34414639127007124`, 0.9356006748113541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 65}], {
             RGBColor[
             0.20934352413953444`, 0.3373636953896671, 0.9352331760525314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 71}], {
             RGBColor[
             0.20987403958143475`, 0.33792130075572613`, 0.9352633881221204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 75}], {
             RGBColor[
             0.21577816809195188`, 0.3441269141636482, 0.9355996195064189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 76}], {
             RGBColor[
             0.27513108512735623`, 0.4061873948398703, 0.9389915142005446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 78}], {
             RGBColor[
             0.21158327851286368`, 0.3397178192446654, 0.9353607267506729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 79}], {
             RGBColor[
             0.2603738305318108, 0.3909997829162489, 0.9381392765089985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 90}], {
             RGBColor[
             0.2994686198002201, 0.427267344133445, 0.9405422803890626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 92}], {
             RGBColor[
             0.36521304201682436`, 0.48315053878033715`, 0.9450247025679616]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 93}], {
             RGBColor[
             0.23322870183700556`, 0.3624685315574433, 0.9365934015874486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 14}], {
             RGBColor[
             0.31755924669394786`, 0.4456881138847494, 0.9415942503883985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 15}], {
             RGBColor[
             0.6315008492289604, 0.6954854366247367, 0.8298610733749225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 20}], {
             RGBColor[
             0.27410897785437727`, 0.40543629361090494`, 0.9389214728296891]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 27}], {
             RGBColor[
             0.22610083303770537`, 0.35497668951639455`, 0.9361874800040654]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 32}], {
             RGBColor[
             0.23379883476419488`, 0.36306777741243473`, 0.9366258698142159]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 37}], {
             RGBColor[
             0.22603241878859584`, 0.3549047818028665, 0.9361835839137884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 43}], {
             RGBColor[
             0.29948030944745474`, 0.4300290471156439, 0.9404422764936284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 47}], {
             RGBColor[
             0.22384081560300342`, 0.3526012678991412, 0.9360587753545553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 60}], {
             RGBColor[
             0.26073437566006774`, 0.39137873870592843`, 0.938159809020674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 72}], {
             RGBColor[
             0.2731749275219578, 0.4044545474893205, 0.9388682800450615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 76}], {
             RGBColor[
             0.2900114239896361, 0.4218275744521024, 0.9398389274852628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 89}], {
             RGBColor[
             0.23927858647690978`, 0.36882734389882366`, 0.9369379335676888]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 92}], {
             RGBColor[
             0.38009338087910416`, 0.4987907183925693, 0.9458721158526797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 8}], {
             RGBColor[
             0.22036751462209056`, 0.34895060834820024`, 0.9358609760019805]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 9}], {
             RGBColor[
             0.2423955674698822, 0.37210348855044706`, 0.9371154410240785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 21}], {
             RGBColor[
             0.3591523356697781, 0.47679686557043666`, 0.9446780511522341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 22}], {
             RGBColor[
             0.2433270771226001, 0.37308256425657677`, 0.9371684891207557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 23}], {
             RGBColor[
             0.20678368869294939`, 0.33467314603236475`, 0.9350873972107856]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 28}], {
             RGBColor[
             0.20667360581005262`, 0.3345574419427823, 0.9350811281534577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 30}], {
             RGBColor[
             0.2856734020298586, 0.41421067718096427`, 0.9397038285205517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 34}], {
             RGBColor[
             0.4035136462715485, 0.5128113759712223, 0.9481703360236404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 36}], {
             RGBColor[
             0.22034023533801322`, 0.3489219360910285, 0.9358594224871084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 49}], {
             RGBColor[
             0.5732896184810699, 0.6471945220280447, 0.9642335866899097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 55}], {
             RGBColor[
             0.226292072969362, 0.3551776948098776, 0.936198370835259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 62}], {
             RGBColor[
             0.21579119455271614`, 0.3441406057998368, 0.9356003613440885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 69}], {
             RGBColor[
             0.25529146867363595`, 0.38565789836295367`, 0.937849843519856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 74}], {
             RGBColor[
             0.20380599978141165`, 0.33154340618995726`, 0.9349178222323695]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 87}], {
             RGBColor[
             0.2114483180967332, 0.3395759672903277, 0.9353530409546302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 95}], {
             RGBColor[
             0.2063885434839972, 0.3342578233641027, 0.9350648942757007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 96}], {
             RGBColor[
             0.206732542507712, 0.33461938814882475`, 0.9350844845112003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 99}], {
             RGBColor[
             0.21988148791720208`, 0.34843976346548955`, 0.9358332975001493]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 22}], {
             RGBColor[
             0.23765743984076979`, 0.3671234159976071, 0.9368456116650321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 25}], {
             RGBColor[
             0.19768654607954875`, 0.325111472353525, 0.9345693283969689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 31}], {
             RGBColor[
             0.21009981607164213`, 0.33815860616199034`, 0.9352762457592313]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 34}], {
             RGBColor[
             0.3978440089897182, 0.5068522277122526, 0.947847458567917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 35}], {
             RGBColor[
             0.23700038499985893`, 0.3664328097001267, 0.9368081933638679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 36}], {
             RGBColor[
             0.2146705980561829, 0.3429627878320588, 0.935536545031385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 49}], {
             RGBColor[
             0.5676199811992395, 0.641235373769075, 0.9639107092341861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 50}], {
             RGBColor[
             0.3450713521941504, 0.46400900754451446`, 0.9436930017123585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 54}], {
             RGBColor[
             0.20356760267491114`, 0.3312928357157756, 0.9349042458698312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 55}], {
             RGBColor[
             0.22062243568753165`, 0.3492185465509079, 0.9358754933795355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 59}], {
             RGBColor[
             0.28226563297271207`, 0.41021064549341324`, 0.9395250753080134]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 69}], {
             RGBColor[
             0.24962183139180566`, 0.379698750103984, 0.9375269660641325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.2591880777303039, 0.38975348154079525`, 0.9380717496411167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 87}], {
             RGBColor[
             0.20577868081490291`, 0.33361681903135804`, 0.9350301634989068]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 96}], {
             RGBColor[
             0.20106290522588166`, 0.3286602398898551, 0.9347616070554767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 99}], {
             RGBColor[
             0.21421185063537176`, 0.34248061520651985`, 0.9355104200444258]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.5338725559288404, 0.620003252990214, 0.9598216809628177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 21}], {
             RGBColor[
             0.3755107512357394, 0.49399059751371377`, 0.9456096387186085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 22}], {
             RGBColor[
             0.25968549268856145`, 0.3902762961998539, 0.9381000766871301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 23}], {
             RGBColor[
             0.2231421042589107, 0.35186687797564187`, 0.9360189847771601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 28}], {
             RGBColor[
             0.2230320213760139, 0.3517511738860594, 0.936012715719832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 29}], {
             RGBColor[
             0.43744574474497594`, 0.5442722153841734, 0.9504853882830122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 30}], {
             RGBColor[
             0.30203181759581993`, 0.4314044091242414, 0.9406354160869261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 36}], {
             RGBColor[
             0.23669865090397454`, 0.3661156680343056, 0.9367910100534829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 55}], {
             RGBColor[
             0.24265048853532328`, 0.3723714267531547, 0.9371299584016335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 62}], {
             RGBColor[
             0.23214961011867746`, 0.3613343377431139, 0.9365319489104629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 64}], {
             RGBColor[
             0.24944385051156642`, 0.37951168091421295`, 0.9375168303163021]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 74}], {
             RGBColor[
             0.22016441534737297`, 0.34873713813323437`, 0.935849409798744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 86}], {
             RGBColor[
             0.2507736082005437, 0.3809093405568351, 0.937592558049489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 95}], {
             RGBColor[
             0.2227469590499585, 0.3514515553073798, 0.9359964818420752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 96}], {
             RGBColor[
             0.2230909580736733, 0.35181312009210186`, 0.9360160720775748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 12}], {
             RGBColor[
             0.1929260043393124, 0.3201078411487571, 0.9342982225874529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 17}], {
             RGBColor[
             0.18622276797371645`, 0.31306231471878276`, 0.9339164831929817]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 48}], {
             RGBColor[
             0.18912154212270826`, 0.3161091101422696, 0.9340815640924147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 52}], {
             RGBColor[
             0.19371851369622117`, 0.32094081873086366`, 0.9343433548229163]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 67}], {
             RGBColor[
             0.2003664206709043, 0.32792819046290256`, 0.9347219432904275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 68}], {
             RGBColor[
             0.18585681947296723`, 0.3126776796420203, 0.9338956429672363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 73}], {
             RGBColor[
             0.20188019423911135`, 0.3295192624618759, 0.9348081504557095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 84}], {
             RGBColor[
             0.19237240568732683`, 0.31952597386533843`, 0.9342666959631981]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 97}], {
             RGBColor[
             0.18556267606085813`, 0.31236851626612416`, 0.9338788919350629]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 21}], {
             RGBColor[
             0.6506293241287362, 0.7246966300102036, 0.9673842910909733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 29}], {
             RGBColor[
             0.7125643176379728, 0.7749782478806632, 0.9722600406553771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 30}], {
             RGBColor[
             0.5771503904888168, 0.6621104416207312, 0.9624100684592909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 46}], {
             RGBColor[
             0.872668319538803, 0.9013782258884464, 0.987115480054523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 49}], {
             RGBColor[
             0.8647666069400279, 0.8950942864678116, 0.9869398266286489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 58}], {
             RGBColor[
             0.8222143233632868, 0.4319525847340926, 0.44402347124128594`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 64}], {
             RGBColor[
             0.5245624234045633, 0.6102177134107027, 0.9592914826886669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 83}], {
             RGBColor[
             0.8145430429406124, 0.37298776182890125`, 0.43667744444506085`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 86}], {
             RGBColor[
             0.5258921810935405, 0.6116153730533249, 0.959367210421854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 13}], {
             RGBColor[
             0.32127656696796114`, 0.4420975360854687, 0.9420804744301899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 17}], {
             RGBColor[
             0.18741833919831424`, 0.3143189358794289, 0.9339845692055334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 68}], {
             RGBColor[
             0.187052390697565, 0.3139343008026664, 0.933963728979788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 73}], {
             RGBColor[
             0.20307576546370915`, 0.33077588362252197`, 0.9348762364682612]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 84}], {
             RGBColor[
             0.1935679769119246, 0.3207825950259845, 0.9343347819757498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 97}], {
             RGBColor[
             0.18675824728545593`, 0.31362513742677023`, 0.9339469779476146]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 16}], {
             RGBColor[
             0.7097360746553412, 0.39524220390309606`, 0.44080435951312347`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 19}], {
             RGBColor[
             0.7170638157235125, 0.7755917913654835, 0.9182556284955311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 57}], {
             RGBColor[
             0.40890200894498224`, 0.5285921009607644, 0.947275852325493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 58}], {
             RGBColor[
             0.7020277998800117, 0.3359930261923694, 0.4334229068830169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 80}], {
             RGBColor[
             0.4067605354175463, 0.5267372642248884, 0.9471393995259555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 81}], {
             RGBColor[
             0.6086435589738648, 0.6910928418057727, 0.963695317570662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 85}], {
             RGBColor[
             0.3312067568018987, 0.4525347952113371, 0.9426459840508332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 100}], {
             RGBColor[
             0.6768264403186011, 0.74504676846516, 0.9703083260751425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 15}], {
             RGBColor[
             0.6812789151790875, 0.7423881728672851, 0.8328942096179411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 20}], {
             RGBColor[
             0.32388704380450417`, 0.45233902985345337`, 0.9419546090727077]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 39}], {
             RGBColor[
             0.6895354931247121, 0.4243337318593296, 0.44562315571375444`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 40}], {
             RGBColor[
             0.3055881316680375, 0.43310571297998635`, 0.9409125130973505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 44}], {
             RGBColor[
             0.37528544959746624`, 0.4994751268713466, 0.9451338348898255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 72}], {
             RGBColor[
             0.3229529934720847, 0.4513572837318689, 0.9419014162880801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 75}], {
             RGBColor[
             0.28043657290435864`, 0.4066698300184287, 0.9394801690341557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 76}], {
             RGBColor[
             0.339789489939763, 0.4687303106946508, 0.9428720637282814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 78}], {
             RGBColor[
             0.27624168332527044`, 0.40226073509944593`, 0.9392412762784097]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 90}], {
             RGBColor[
             0.3641270246126268, 0.4898102599882255, 0.9444228299167994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 92}], {
             RGBColor[
             0.42987144682923106`, 0.5456934546351176, 0.9489052520956983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 93}], {
             RGBColor[
             0.2978871066494123, 0.4250114474122238, 0.9404739511151854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 94}], {
             RGBColor[
             0.6815294680791602, 0.36279591509667297`, 0.437956577088622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 98}], {
             RGBColor[
             0.6812694502462739, 0.7423679283330488, 0.8318640100919996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 16}], {
             RGBColor[
             0.8919990611027038, 0.5383604991516755, 0.36459315696115346`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 19}], {
             RGBColor[
             0.9904582953945565, 0.9902692342383527, 0.803938824667576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 39}], {
             RGBColor[
             0.8988298948147204, 0.5908652803526545, 0.37113437103810387`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 40}], {
             RGBColor[
             0.61952973420305, 0.6829030357199737, 0.8291793360838746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 44}], {
             RGBColor[
             0.6892270521324788, 0.7492724496113339, 0.8334006578763498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 46}], {
             RGBColor[
             0.9657830139849344, 0.9721163309487307, 0.8568978296891643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 72}], {
             RGBColor[
             0.6368945960070973, 0.7011546064718562, 0.8301682392746041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 76}], {
             RGBColor[
             0.6537310924747756, 0.7185276334346382, 0.8311388867148055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 83}], {
             RGBColor[
             0.8766195059047, 0.4201464985357575, 0.3498656775348218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 90}], {
             RGBColor[
             0.6780686271476394, 0.7396075827282129, 0.8326896529033235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 92}], {
             RGBColor[
             0.7438130493642436, 0.795490777375105, 0.8371720750822225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 94}], {
             RGBColor[
             0.8908238697691686, 0.5293274635899978, 0.3634677924129714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 98}], {
             RGBColor[
             0.9952110527812865, 0.9921652510730361, 0.7201308330785238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 100}], {
             RGBColor[
             0.950220919989645, 0.9597242113380292, 0.8559915222471874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 19}], {
             RGBColor[
             0.8888242462230083, 0.5370829915723956, 0.41977835166989397`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 34}], {
             RGBColor[
             0.7539222687443959, 0.43120299906100945`, 0.44425841895619067`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 39}], {
             RGBColor[
             0.8438037496530141, 0.33770039152436643`, 0.18957982617797273`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 44}], {
             RGBColor[
             0.6880034173816231, 0.37641846848771643`, 0.43941957380907637`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 49}], {
             RGBColor[
             0.8671062502174101, 0.5207917630988911, 0.4549672527337034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 50}], {
             RGBColor[
             0.7187404975473507, 0.4026408522825174, 0.441488781052485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 57}], {
             RGBColor[
             0.683383041703988, 0.3724165313025828, 0.4391251675565353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 58}], {
             RGBColor[
             0.836534195409341, 0.28182341206851363`, 0.1826184928244442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 59}], {
             RGBColor[
             0.6768700180663918, 0.36677527758178324`, 0.43871016344958824`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 79}], {
             RGBColor[
             0.654501274546124, 0.34579684975417163`, 0.43734356790701623`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 80}], {
             RGBColor[
             0.6819553926856974, 0.3711799734786655, 0.43903419902351026`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 81}], {
             RGBColor[
             0.8165440750565763, 0.4807503585325883, 0.45007147771998124`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 82}], {
             RGBColor[
             0.6614849812381197, 0.35313716828003794`, 0.4377412796716571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 90}], {
             RGBColor[
             0.6805644673917302, 0.36997522389896903`, 0.4389455704937256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 94}], {
             RGBColor[
             0.8398007371302382, 0.30693148314303814`, 0.1857465368654065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 98}], {
             RGBColor[
             0.8919927511474949, 0.5383470027955178, 0.36390635727719245`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 100}], {
             RGBColor[
             0.8619993292864006, 0.5167196429721799, 0.4544801500563016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 48}], {
             RGBColor[
             0.1836138769817101, 0.31032020487294143`, 0.9337679107104953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 52}], {
             RGBColor[
             0.188210848555223, 0.3151519134615354, 0.9340297014409968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 67}], {
             RGBColor[
             0.1948587555299061, 0.3221392851935744, 0.934408289908508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 68}], {
             RGBColor[
             0.18034915433196902`, 0.3068887743726921, 0.9335819895853168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 73}], {
             RGBColor[
             0.1963725290981132, 0.3237303571925477, 0.9344944970737901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 84}], {
             RGBColor[
             0.18686474054632862`, 0.31373706859601025`, 0.9339530425812786]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 97}], {
             RGBColor[
             0.18005501091985998`, 0.306579610996796, 0.9335652385531434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 24}], {
             RGBColor[
             0.18549001607177976`, 0.3122921460106934, 0.9338747540561756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 64}], {
             RGBColor[
             0.2146734226669212, 0.34296575667703544`, 0.9355367058887878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 86}], {
             RGBColor[
             0.21600318035589844`, 0.3443634163196576, 0.9356124336219749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 34}], {
             RGBColor[
             0.7833431068570946, 0.8295329841023538, 0.9234367176601319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 44}], {
             RGBColor[
             0.6844648298129354, 0.7473561882424142, 0.9161784499394605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 49}], {
             RGBColor[
             0.953119079066616, 0.9639161301591762, 0.939499968326401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 50}], {
             RGBColor[
             0.7305704500615269, 0.7866897639346156, 0.9192822608045734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 57}], {
             RGBColor[
             0.6775342662964828, 0.7413532824647138, 0.9157368405606489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 58}], {
             RGBColor[
             0.8811159714476788, 0.477833813861669, 0.4123968990397874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 79}], {
             RGBColor[
             0.6342116155596866, 0.701423760142097, 0.9130644410863702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 80}], {
             RGBColor[
             0.6753927927690468, 0.7394984457288378, 0.9156003877611113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 81}], {
             RGBColor[
             0.8772758163253653, 0.9038540233097221, 0.9321563058058178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 85}], {
             RGBColor[
             0.5998390141533992, 0.6652959767152865, 0.911106972285989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 90}], {
             RGBColor[
             0.673306404828096, 0.737691321359293, 0.9154674449664344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 94}], {
             RGBColor[
             0.887649054889473, 0.528049956010718, 0.41865298712171195`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 100}], {
             RGBColor[
             0.9454586976701016, 0.9578079499691095, 0.9387693143102983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 27}], {
             RGBColor[
             0.23242863014826168`, 0.36162760548509854`, 0.9365478386883745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 32}], {
             RGBColor[
             0.2401266318747512, 0.3697186933811387, 0.9369862284985251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 37}], {
             RGBColor[
             0.23236021589915215`, 0.3615556977715705, 0.9365439425980976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 43}], {
             RGBColor[
             0.30580810655801105`, 0.43667996308434787`, 0.9408026351779376]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 47}], {
             RGBColor[
             0.23016861271355973`, 0.3592521838678452, 0.9364191340388645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 60}], {
             RGBColor[
             0.26706217277062405`, 0.3980296546746324, 0.9385201677049833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 72}], {
             RGBColor[
             0.27950272463251413`, 0.41110546345802457`, 0.9392286387293707]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 76}], {
             RGBColor[
             0.2963392211001924, 0.42847849042080643`, 0.940199286169572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 83}], {
             RGBColor[
             0.6383582583216445, 0.226780403193203, 0.4225726105046661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 89}], {
             RGBColor[
             0.2456063835874661, 0.3754782598675277, 0.9372982922519981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 92}], {
             RGBColor[
             0.38642117798966047`, 0.5054416343612733, 0.946232474536989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 22}], {
             RGBColor[
             0.37644226088845734`, 0.4949696732198435, 0.9456626868152858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 29}], {
             RGBColor[
             0.5542025129448718, 0.648965592404163, 0.9580479984111678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 30}], {
             RGBColor[
             0.4187885857957158, 0.536097786144231, 0.9481980262150818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.35345541910387046`, 0.4708090450542952, 0.9443536201816385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 46}], {
             RGBColor[
             0.7143065148457021, 0.7753655704119462, 0.9729034378103137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 49}], {
             RGBColor[
             0.7064048022469269, 0.7690816309913114, 0.9727277843844396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 55}], {
             RGBColor[
             0.35940725673521917`, 0.4770648037731443, 0.9446925685297891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 58}], {
             RGBColor[
             0.7166397869012195, 0.3479441477497591, 0.4345487764118131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 62}], {
             RGBColor[
             0.34890637831857335`, 0.4660277147631035, 0.9440945590386185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 64}], {
             RGBColor[
             0.3662006187114623, 0.48420505793420254`, 0.9450794404444577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 83}], {
             RGBColor[
             0.7089685064785451, 0.2889793248445678, 0.427202749615588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 86}], {
             RGBColor[
             0.36753037640043956`, 0.4856027175768247, 0.9451551681776447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 23}], {
             RGBColor[
             0.2240736139116286, 0.3528459536817715, 0.9360720328738372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 30}], {
             RGBColor[
             0.3029633272485378, 0.43238348483037115`, 0.9406884641836033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 34}], {
             RGBColor[
             0.42080357149022773`, 0.530984183620629, 0.949154971686692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 36}], {
             RGBColor[
             0.23763016055669245`, 0.3670947437404353, 0.93684405815016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 49}], {
             RGBColor[
             0.590579543699749, 0.6653673296774516, 0.9652182223529613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 50}], {
             RGBColor[
             0.36803091469466, 0.488140963452891, 0.9450005148311336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 55}], {
             RGBColor[
             0.24358199818804122`, 0.3733505024592844, 0.9371830064983107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 58}], {
             RGBColor[
             0.6394229478697675, 0.27880128020718586`, 0.4295424017241608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 59}], {
             RGBColor[
             0.3052251954732216, 0.4343426014017897, 0.9408325884267885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 62}], {
             RGBColor[
             0.23308111977139537`, 0.3623134134492436, 0.9365849970071402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 69}], {
             RGBColor[
             0.27258139389231517`, 0.4038307060123605, 0.9388344791829076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 87}], {
             RGBColor[
             0.22873824331541243`, 0.35774877493973456`, 0.9363376766176819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 95}], {
             RGBColor[
             0.22367846870267644`, 0.3524306310135095, 0.9360495299387523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 96}], {
             RGBColor[
             0.22402246772639123`, 0.3527921957982316, 0.9360691201742519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 99}], {
             RGBColor[
             0.2371714131358813, 0.36661257111489637`, 0.9368179331632009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 28}], {
             RGBColor[
             0.18742014259908113`, 0.31432083136797706`, 0.9339846719065392]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 36}], {
             RGBColor[
             0.20108677212704174`, 0.3286853255162233, 0.93476296624019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 55}], {
             RGBColor[
             0.2070386097583905, 0.3349410842350724, 0.9351019145883406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 62}], {
             RGBColor[
             0.19653773134174465`, 0.32390399522503155`, 0.9345039050971701]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 74}], {
             RGBColor[
             0.18455253657044016`, 0.311306795615152, 0.9338213659854511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 95}], {
             RGBColor[
             0.18713508027302572`, 0.3140212127892975, 0.9339684380287823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 96}], {
             RGBColor[
             0.18747907929674051`, 0.31438277757401956`, 0.9339880282642818]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 86}], {
             RGBColor[
             0.21228006908112512`, 0.3404501903109819, 0.935400407942726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 31}], {
             RGBColor[
             0.19308848481093063`, 0.3202786184262848, 0.9343074756099432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 54}], {
             RGBColor[
             0.18655627141419961`, 0.31341284798007, 0.9339354757205431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 69}], {
             RGBColor[
             0.23261050013109416`, 0.3618187623682784, 0.9365581959148443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 87}], {
             RGBColor[
             0.1887673495541914, 0.31573683129565244`, 0.9340613933496187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 99}], {
             RGBColor[
             0.19720051937466027`, 0.3246006274708143, 0.9345416498951375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 41}], {
             RGBColor[
             0.18629441025673982`, 0.31313761530062345`, 0.9339205631150146]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 42}], {
             RGBColor[
             0.19043503176311785`, 0.3174896710343933, 0.9341563653843022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 45}], {
             RGBColor[
             0.1819752410161864, 0.308597894577655, 0.9336745928164034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 53}], {
             RGBColor[
             0.18250075787953074`, 0.30915024612072356`, 0.9337045202243384]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 56}], {
             RGBColor[
             0.18790709673417716`, 0.31483265103863844`, 0.9340124032241488]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 57}], {
             RGBColor[
             0.2758068790530788, 0.40161556500743284`, 0.9392234043960719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 85}], {
             RGBColor[
             0.19811162690999523`, 0.32555825925800563`, 0.9345935361214122]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 88}], {
             RGBColor[
             0.19550264674767992`, 0.3228160556885158, 0.9344449585608086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 32}], {
             RGBColor[
             0.1921184870580793, 0.31925908928662833`, 0.9342522356729014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 37}], {
             RGBColor[
             0.18435207108248025`, 0.3110960936770601, 0.9338099497724739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 43}], {
             RGBColor[
             0.2577999617413391, 0.3862203589898375, 0.9380686423523139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 47}], {
             RGBColor[
             0.18216046789688783`, 0.3087925797733348, 0.9336851412132408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 60}], {
             RGBColor[
             0.21905402795395212`, 0.347570050580122, 0.9357861748793594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 72}], {
             RGBColor[
             0.23149457981584223`, 0.3606458593635141, 0.936494645903747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 89}], {
             RGBColor[
             0.1975982387707942, 0.32501865577301725`, 0.9345642994263743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 30}], {
             RGBColor[
             0.2663098559359903, 0.3938583625165767, 0.9386011032163053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 36}], {
             RGBColor[
             0.20097668924414497`, 0.32856962142664087`, 0.934756697182862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 62}], {
             RGBColor[
             0.19642764845884786`, 0.32378829113544916`, 0.934497636039842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 64}], {
             RGBColor[
             0.21372188885173682`, 0.34196563430654825`, 0.9354825174456812]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 74}], {
             RGBColor[
             0.18444245368754336`, 0.31119109152556956`, 0.9338150969281231]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 95}], {
             RGBColor[
             0.18702499739012893`, 0.31390550869971506`, 0.9339621689714543]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 96}], {
             RGBColor[
             0.18736899641384372`, 0.31426707348443716`, 0.9339817592069539]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 30}], {
             RGBColor[
             0.48072357930495235`, 0.5863794040146906, 0.9530737757794854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 39}], {
             RGBColor[
             0.7724688910613899, 0.4932191852417712, 0.45172194282847256`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 46}], {
             RGBColor[
             0.7762415083549385, 0.8256471882824058, 0.9777791873747175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 58}], {
             RGBColor[
             0.7579297825740439, 0.3814652263300655, 0.43779927612141567`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 64}], {
             RGBColor[
             0.42813561222069885`, 0.5344866758046621, 0.9499551900088614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 83}], {
             RGBColor[
             0.7502585021513695, 0.3225004034248742, 0.4304532493251906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 86}], {
             RGBColor[
             0.4294653699096761, 0.5358843354472843, 0.9500309177420485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 36}], {
             RGBColor[
             0.27997648546395093`, 0.40822285666482283`, 0.939379397549956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 46}], {
             RGBColor[
             0.6408275812057826, 0.7127793820224738, 0.9679292151786314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 58}], {
             RGBColor[
             0.6676538311412732, 0.30622002215677757`, 0.4312326279906915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 62}], {
             RGBColor[
             0.2754274446786539, 0.4034415263736312, 0.9391203364069362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 64}], {
             RGBColor[
             0.29272168507154284`, 0.4216188695447302, 0.9401052178127753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 86}], {
             RGBColor[
             0.2940514427605201, 0.4230165291873524, 0.9401809455459623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 34}], {
             RGBColor[
             0.3932459477211001, 0.5020193737850124, 0.9475856057808912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 35}], {
             RGBColor[
             0.2324023237312408, 0.3615999557728864, 0.9365463405768422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 50}], {
             RGBColor[
             0.3404732909255323, 0.45917615361727426`, 0.9434311489253328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 54}], {
             RGBColor[
             0.19896954140629303`, 0.3264599817885353, 0.9346423930828055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 59}], {
             RGBColor[
             0.27766757170409395`, 0.40537779156617293`, 0.9392632225209877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 63}], {
             RGBColor[
             0.21200507517518904`, 0.3401611542802224, 0.9353847474466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 69}], {
             RGBColor[
             0.24502377012318755`, 0.3748658961767437, 0.9372651132771068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 70}], {
             RGBColor[
             0.2082765371055179, 0.33624222436603046`, 0.9351724127194101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 82}], {
             RGBColor[
             0.2545900164616858, 0.38492062761355506`, 0.937809896854091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 87}], {
             RGBColor[
             0.2011806195462848, 0.3287839651041178, 0.934768310711881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 99}], {
             RGBColor[
             0.20961378936675365`, 0.33764776127927965`, 0.9352485672574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 37}], {
             RGBColor[
             0.19205007280896977`, 0.3191871815731003, 0.9342483395826244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 43}], {
             RGBColor[
             0.26549796346782867`, 0.39431144688587766`, 0.9385070321624644]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 47}], {
             RGBColor[
             0.18985846962337735`, 0.316883667669375, 0.9341235310233913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 48}], {
             RGBColor[
             0.19316456995763537`, 0.32035858873954837`, 0.9343118085464901]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 60}], {
             RGBColor[
             0.22675202968044164`, 0.3556611384761622, 0.93622456468951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 72}], {
             RGBColor[
             0.23919258154233175`, 0.3687369472595543, 0.9369330357138975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 89}], {
             RGBColor[
             0.2052962404972837, 0.33310974366905743`, 0.9350026892365249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 63}], {
             RGBColor[
             0.19930680897803732`, 0.32681447139043773`, 0.9346615999720737]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 66}], {
             RGBColor[
             0.19757591199460448`, 0.3249951889156425, 0.9345630279494997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 70}], {
             RGBColor[
             0.19557827090836621`, 0.3228955414762458, 0.9344492652448837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 91}], {
             RGBColor[
             0.18187214762985388`, 0.30848953689212133`, 0.9336687218005647]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 35}], {
             RGBColor[
             0.4201465166493169, 0.5302935773231487, 0.9491175533855278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 36}], {
             RGBColor[
             0.39781672970564086`, 0.5068235554550808, 0.9478459050530449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 49}], {
             RGBColor[
             0.7507661128486974, 0.8050961413920971, 0.976220069255846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 50}], {
             RGBColor[
             0.5282174838436084, 0.6278697751675365, 0.9560023617340184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 54}], {
             RGBColor[
             0.3867137343243691, 0.4951536033387976, 0.9472136058914912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 55}], {
             RGBColor[
             0.4037685673369896, 0.5130793141739299, 0.9481848534011954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 58}], {
             RGBColor[
             0.7462139939690664, 0.3719538213502829, 0.4368769663260841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 59}], {
             RGBColor[
             0.46541176462217004`, 0.5740714131164353, 0.9518344353296734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 69}], {
             RGBColor[
             0.43276796304126364`, 0.5435595177270061, 0.9498363260857925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 81}], {
             RGBColor[
             0.6749228501074469, 0.7450340345426429, 0.9688764067352628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 82}], {
             RGBColor[
             0.44233420937976187`, 0.5536142491638173, 0.9503811096627767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 87}], {
             RGBColor[
             0.3889248124643609, 0.49747758665438, 0.9473395235205667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 99}], {
             RGBColor[
             0.39735798228482977`, 0.5063413828295419, 0.9478197800660857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 100}], {
             RGBColor[
             0.7431057314521832, 0.7989879612020303, 0.9754894152397433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 49}], {
             RGBColor[
             0.5899224888588381, 0.6646767233799711, 0.9651808040517968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 50}], {
             RGBColor[
             0.3673738598537491, 0.4874503571554106, 0.9449630965299693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 54}], {
             RGBColor[
             0.22587011033450982`, 0.35473418532667167`, 0.9361743406874421]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 59}], {
             RGBColor[
             0.30456814063231075`, 0.4336519951043093, 0.9407951701256243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 63}], {
             RGBColor[
             0.23890564410340584`, 0.3684353578183588, 0.9369166950512366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 69}], {
             RGBColor[
             0.27192433905140434`, 0.4031400997148801, 0.9387970608817433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 70}], {
             RGBColor[
             0.2351771060337347, 0.36451642790416683`, 0.9367043603240466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 82}], {
             RGBColor[
             0.28149058538990257`, 0.41319483115169137`, 0.9393418444587276]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 87}], {
             RGBColor[
             0.2280811884745016, 0.35705816864225415`, 0.9363002583165176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 99}], {
             RGBColor[
             0.23651435829497044`, 0.36592196481741596`, 0.9367805148620365]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 55}], {
             RGBColor[
             0.22059515640345434`, 0.34918987429373616`, 0.9358739398646634]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 62}], {
             RGBColor[
             0.2100942779868085, 0.33815278528369536`, 0.935275930373493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 74}], {
             RGBColor[
             0.198109083215504, 0.3255555856738158, 0.9345933912617739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 95}], {
             RGBColor[
             0.20069162691808956`, 0.32827000284796126`, 0.9347404633051051]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 96}], {
             RGBColor[
             0.20103562594180435`, 0.3286315676326833, 0.9347600535406047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 99}], {
             RGBColor[
             0.21418457135129443`, 0.3424519429493481, 0.9355088665295537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 47}], {
             RGBColor[
             0.1820920536477783, 0.30872067205980674`, 0.9336812451229637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 72}], {
             RGBColor[
             0.2314261655667327, 0.36057395164998607`, 0.93649074981347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 76}], {
             RGBColor[
             0.24826266203441094`, 0.37794697861276794`, 0.9374613972536713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 89}], {
             RGBColor[
             0.19752982452168466`, 0.3249467480594892, 0.9345604033360972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 39}], {
             RGBColor[
             0.6486469668748682, 0.3849687430769146, 0.44316238194817426`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 51}], {
             RGBColor[
             0.2592164036383718, 0.38978325386614093`, 0.9380733627596768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 61}], {
             RGBColor[
             0.22697137929621247`, 0.35589168882990624`, 0.9362370563256295]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 66}], {
             RGBColor[
             0.2298591677375159, 0.3589269375780785, 0.9364015116052615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 77}], {
             RGBColor[
             0.21179936694727172`, 0.33994494189002633`, 0.9353730326673382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 98}], {
             RGBColor[
             0.6199366608715083, 0.6833204451594262, 0.8281728494436293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 46}], {
             RGBColor[
             0.8792048923286101, 0.57748583724696, 0.46162556909456987`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 51}], {
             RGBColor[
             0.6583434133707539, 0.3951603231343067, 0.4437145802315078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 76}], {
             RGBColor[
             0.6711702779885043, 0.4084267055708983, 0.4444529404449973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 83}], {
             RGBColor[
             0.8395293889100205, 0.30484578181689703`, 0.18548669350328206`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 92}], {
             RGBColor[
             0.7312249159148163, 0.45973546819787614`, 0.44847506602327525`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 94}], {
             RGBColor[
             0.8466315708422548, 0.35943626434401715`, 0.19228775094235687`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 98}], {
             RGBColor[
             0.8988235848595115, 0.5908517839964968, 0.3704475713541428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 41}], {
             RGBColor[
             0.2170932363086373, 0.34550913423952534`, 0.9356745106958901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 44}], {
             RGBColor[
             0.3135362686214289, 0.43998998972403525`, 0.9414189613557591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 56}], {
             RGBColor[
             0.21870592278607465`, 0.34720416997754033`, 0.9357663508050242]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.21225274797590385`, 0.3404214740971362, 0.9353988520462018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 75}], {
             RGBColor[
             0.2186873919283213, 0.3471846928711173, 0.9357652955000892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 76}], {
             RGBColor[
             0.27804030896372567`, 0.40924517354733947`, 0.9391571901942148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 78}], {
             RGBColor[
             0.2144925023492331, 0.3427755979521345, 0.9355264027443431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 79}], {
             RGBColor[
             0.2632830543681802, 0.39405756162371797`, 0.9383049525026688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 90}], {
             RGBColor[
             0.3023778436365895, 0.4303251228409142, 0.9407079563827329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 92}], {
             RGBColor[
             0.36812226585319374`, 0.48620831748780624`, 0.9451903785616318]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 93}], {
             RGBColor[
             0.236137925673375, 0.36552631026491245`, 0.9367590775811188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 44}], {
             RGBColor[
             0.2867905542380661, 0.4118785481308856, 0.9398958324883652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 56}], {
             RGBColor[
             0.19196020840271177`, 0.31909272838439073`, 0.9342432219376304]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 65}], {
             RGBColor[
             0.185507033592541, 0.3123100325039866, 0.9338757231788078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 79}], {
             RGBColor[
             0.23653733998481735`, 0.36594612003056837`, 0.936781823635275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.1995557584162146, 0.3270761330342681, 0.9346757772742902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 90}], {
             RGBColor[
             0.27563212925322667`, 0.4022136812477645, 0.9391848275153389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 93}], {
             RGBColor[
             0.20939221129001212`, 0.3374148686717628, 0.935235948713725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 45}], {
             RGBColor[
             0.19016897419109907`, 0.31721002765717715`, 0.9341412137991727]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 53}], {
             RGBColor[
             0.19069449105444342`, 0.3177623792002457, 0.9341711412071076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 56}], {
             RGBColor[
             0.19610082990908984`, 0.3234447841181606, 0.9344790242069181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 57}], {
             RGBColor[
             0.2840006122279915, 0.410227698086955, 0.9396900253788412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 80}], {
             RGBColor[
             0.28185913870055557`, 0.40837286135107903`, 0.9395535725793036]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 85}], {
             RGBColor[
             0.2063053600849079, 0.33417039233752777`, 0.9350601571041814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 88}], {
             RGBColor[
             0.2036963799225926, 0.3314281887680379, 0.9349115795435778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 60}], {
             RGBColor[
             0.2924335043637015, 0.42262240817937136`, 0.9400409713689225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 67}], {
             RGBColor[
             0.2700909231890912, 0.39913893876339046`, 0.9387685944239152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 72}], {
             RGBColor[
             0.3048740562255916, 0.43569821696276345`, 0.94074944239331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 76}], {
             RGBColor[
             0.32171055269326987`, 0.4530712439255453, 0.9417200898335113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 83}], {
             RGBColor[
             0.6552724793836961, 0.24317557219636227`, 0.423586479613959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 89}], {
             RGBColor[
             0.2709777151805436, 0.4000710133722666, 0.9388190959159373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 92}], {
             RGBColor[
             0.41179250958273794`, 0.5300343878660122, 0.9477532782009283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 56}], {
             RGBColor[
             0.2884032407155034, 0.4135735838689006, 0.9399876725974994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 57}], {
             RGBColor[
             0.3763030230344051, 0.500356497837695, 0.9451986737694225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 79}], {
             RGBColor[
             0.33298037229760896`, 0.4604269755150782, 0.9425262742951439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 81}], {
             RGBColor[
             0.5760445730632877, 0.6628572386827033, 0.9616181390145914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 88}], {
             RGBColor[
             0.2959987907290062, 0.42155698851877793`, 0.9404202279341591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 90}], {
             RGBColor[
             0.3720751615660183, 0.49669453673227437`, 0.9449292781752079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 92}], {
             RGBColor[
             0.43781958378262253`, 0.5525777313791664, 0.9494117003541069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 93}], {
             RGBColor[
             0.30583524360280373`, 0.43189572415627264`, 0.9409803993735939]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 94}], {
             RGBColor[
             0.6868282260480878, 0.36738543292603887`, 0.43829420926089435`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 100}], {
             RGBColor[
             0.644227454408024, 0.7168111653420908, 0.9682311475190719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 53}], {
             RGBColor[
             0.18223470030751196`, 0.3088706027435074, 0.9336893686392087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 85}], {
             RGBColor[
             0.19784556933797645`, 0.32527861588078943`, 0.9345783845362825]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 88}], {
             RGBColor[
             0.19523658917566114`, 0.32253641231129965`, 0.9344298069756789]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 51}], {
             RGBColor[
             0.6050532918189845, 0.6785588951212091, 0.9657681434792702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 64}], {
             RGBColor[
             0.5882396141215291, 0.6608866538124454, 0.9648106294080073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 83}], {
             RGBColor[
             0.8569945034185896, 0.4067670554300631, 0.4403568755912878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 86}], {
             RGBColor[
             0.5895693718105064, 0.6622843134550676, 0.9648863571411943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 94}], {
             RGBColor[
             0.8711988672830582, 0.5159480204843034, 0.45395899046943744`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 98}], {
             RGBColor[
             0.9657735490521211, 0.9720960864144944, 0.8558676301632229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 72}], {
             RGBColor[
             0.2292345623811403, 0.3582704377462608, 0.9363659412542369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 89}], {
             RGBColor[
             0.19533822133609224`, 0.3226432341557639, 0.9344355947768641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 52}], {
             RGBColor[
             0.19110962270421483`, 0.3181987088850222, 0.9341947823404299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 60}], {
             RGBColor[
             0.2201001108535082, 0.348669550033042, 0.9358457477529483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 67}], {
             RGBColor[
             0.19775752967889793`, 0.3251860806170612, 0.934573370807941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 68}], {
             RGBColor[
             0.18324792848096086`, 0.30993556979617887`, 0.9337470704847499]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 73}], {
             RGBColor[
             0.199271303247105, 0.3267771526160345, 0.9346595779732231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 84}], {
             RGBColor[
             0.18976351469532046`, 0.31678386401949704`, 0.9341181234807117]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 89}], {
             RGBColor[
             0.19864432167035026`, 0.3261181552259373, 0.934623872299963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 50}], {
             RGBColor[
             0.6979934560531296, 0.762252921224359, 0.9720656124002875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 55}], {
             RGBColor[
             0.5735445395465109, 0.6474624602307524, 0.9642481040674646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 58}], {
             RGBColor[
             0.8593979754420806, 0.4615425853881645, 0.44758580010359683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 59}], {
             RGBColor[
             0.6351877368316913, 0.7084545591732576, 0.9678976859959425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 69}], {
             RGBColor[
             0.6025439352507849, 0.6779426637838284, 0.9658995767520615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 81}], {
             RGBColor[
             0.8446988223169681, 0.8794171805994653, 0.9849396574015319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 82}], {
             RGBColor[
             0.6121101815892831, 0.6879973952206397, 0.9664443603290458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 99}], {
             RGBColor[
             0.567133954494351, 0.6407245288863643, 0.9638830307323548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 100}], {
             RGBColor[
             0.9128817036617044, 0.9333711072588528, 0.9915526659060124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 54}], {
             RGBColor[
             0.3339410775288013, 0.4523103831710595, 0.9430591490359327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 55}], {
             RGBColor[
             0.3509959105414218, 0.4702360940061918, 0.9440303965456369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 58}], {
             RGBColor[
             0.7110322227720213, 0.3433916745717908, 0.4341073284223784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 59}], {
             RGBColor[
             0.41263910782660224`, 0.531228192948697, 0.9476799784741149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 69}], {
             RGBColor[
             0.37999530624569583`, 0.5007162975592678, 0.945681869230234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 82}], {
             RGBColor[
             0.38956155258419406`, 0.5107710289960792, 0.9462266528072182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 87}], {
             RGBColor[
             0.3361521556687931, 0.4546343664866419, 0.9431850666650082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 99}], {
             RGBColor[
             0.3445853254892619, 0.46349816266180377`, 0.9436653232105272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 61}], {
             RGBColor[
             0.24151604904004081`, 0.37117905891599445`, 0.9370653537506299]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 66}], {
             RGBColor[
             0.24440383748134425`, 0.3742143076641667, 0.937229809030262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 77}], {
             RGBColor[
             0.22634403669110006`, 0.3552323119761146, 0.9362013300923386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 98}], {
             RGBColor[
             0.6344813306153367, 0.6986078152455144, 0.8290011468686297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 60}], {
             RGBColor[
             0.22469708242702108`, 0.35350125862163606`, 0.9361075384834499]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 67}], {
             RGBColor[
             0.20235450125241083`, 0.3300177892056552, 0.9348351615384426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 68}], {
             RGBColor[
             0.18784490005447374`, 0.3147672783847729, 0.9340088612152515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 73}], {
             RGBColor[
             0.20386827482061792`, 0.3316088612046285, 0.9349213687037247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 84}], {
             RGBColor[
             0.19436048626883334`, 0.32161557260809104`, 0.9343799142112132]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 97}], {
             RGBColor[
             0.1875507566423647, 0.31445811500887677`, 0.933992110183078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 80}], {
             RGBColor[
             0.2739248648169684, 0.4000334364374093, 0.9391017274193396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 85}], {
             RGBColor[
             0.19837108620132082`, 0.325830967423858, 0.9346083119442175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 88}], {
             RGBColor[
             0.1957621060390055, 0.3230887638543682, 0.9344597343836138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 59}], {
             RGBColor[
             0.27113535830736296`, 0.3985120211199582, 0.9388912226315876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 69}], {
             RGBColor[
             0.23849155672645656`, 0.368000125730529, 0.9368931133877068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 82}], {
             RGBColor[
             0.24805780306495478`, 0.3780548571673403, 0.9374378969646909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 87}], {
             RGBColor[
             0.19464840614955378`, 0.32191819465790306`, 0.934396310822481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 99}], {
             RGBColor[
             0.20308157597002263`, 0.33078199083306487`, 0.934876567368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 59}], {
             RGBColor[
             0.28819019131998347`, 0.41643773195509054`, 0.9398624701412919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 62}], {
             RGBColor[
             0.21604611561815723`, 0.34440854400254445`, 0.9356148787216435]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 69}], {
             RGBColor[
             0.25554638973907706`, 0.3859258365656613, 0.937864360897411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 87}], {
             RGBColor[
             0.21170323916217432`, 0.33984390549303534`, 0.9353675583321852]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 95}], {
             RGBColor[
             0.2066434645494383, 0.33452576156681035`, 0.9350794116532557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 96}], {
             RGBColor[
             0.2069874635731531, 0.3348873263515324, 0.9350990018887553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 99}], {
             RGBColor[
             0.2201364089826432, 0.3487077016681972, 0.9358478148777043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 57}], {
             RGBColor[
             0.2814726771990508, 0.4075706780912001, 0.9395460632186877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 65}], {
             RGBColor[
             0.18711972006997832`, 0.3140050682420016, 0.9339675632879421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 79}], {
             RGBColor[
             0.23815002646225467`, 0.36764115576858336`, 0.9368736637444091]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 88}], {
             RGBColor[
             0.2011684448936519, 0.3287711687722831, 0.9347676173834243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 90}], {
             RGBColor[
             0.27724481573066395`, 0.4039087169857795, 0.9392766676244733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 93}], {
             RGBColor[
             0.21100489776744946`, 0.3391099044097778, 0.9353277888228592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 79}], {
             RGBColor[
             0.3260498087811563, 0.45442406973737776`, 0.9420846649163321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 80}], {
             RGBColor[
             0.3672309859905165, 0.4924987553241186, 0.9446206115910732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 81}], {
             RGBColor[
             0.569114009546835, 0.6568543329050028, 0.9611765296357797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 85}], {
             RGBColor[
             0.2916772073748689, 0.41829628631056726`, 0.940127196115951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 88}], {
             RGBColor[
             0.28906822721255354`, 0.41555408274107747`, 0.9399786185553474]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 90}], {
             RGBColor[
             0.36514459804956567`, 0.4906916309545739, 0.9444876687963963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 100}], {
             RGBColor[
             0.6372968908915713, 0.7108082595643903, 0.9677895381402603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 59}], {
             RGBColor[
             0.6691617432910624, 0.3075260998710566, 0.4313287108194816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 80}], {
             RGBColor[
             0.674247117910368, 0.3119307957679389, 0.43165274639340356`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 81}], {
             RGBColor[
             0.8088358002812469, 0.4215011808218617, 0.44269002508987454`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 83}], {
             RGBColor[
             0.8249902804226744, 0.19309182290519136`, 0.17156402679622504`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 100}], {
             RGBColor[
             0.8542910545110711, 0.45747046526145335`, 0.4470986974261949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 69}], {
             RGBColor[
             0.3171895870242575, 0.4469179355081666, 0.941513942825889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 82}], {
             RGBColor[
             0.3267558333627557, 0.4569726669449779, 0.9420587264028731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 87}], {
             RGBColor[
             0.27334643644735473`, 0.4008360044355407, 0.9390171402606632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 99}], {
             RGBColor[
             0.2817796062678236, 0.4096998006107025, 0.9394973968061822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 67}], {
             RGBColor[
             0.23134498940170423`, 0.360488630353675, 0.936486126950961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 72}], {
             RGBColor[
             0.2661281224382046, 0.39704790855304795`, 0.9384669749203556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 73}], {
             RGBColor[
             0.2328587629699113, 0.3620797023526483, 0.9365723341162431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 89}], {
             RGBColor[
             0.23223178139315653`, 0.3614207049625511, 0.936536628442983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 77}], {
             RGBColor[
             0.19409901234894075`, 0.3213407469398799, 0.9343650236582913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 74}], {
             RGBColor[
             0.1935600424302069, 0.32077425538262405`, 0.934334330118754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 95}], {
             RGBColor[
             0.19614258613279245`, 0.32348867255676955`, 0.9344814021620852]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 96}], {
             RGBColor[
             0.19648658515650724`, 0.32385023734149165`, 0.9345009923975848]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 99}], {
             RGBColor[
             0.20963553056599735`, 0.3376706126581564, 0.9352498053865337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 66}], {
             RGBColor[
             0.2167774985639212, 0.34517727385089947`, 0.9356565298984206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 70}], {
             RGBColor[
             0.21477985747768297`, 0.3430776264115028, 0.9355427671938046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 82}], {
             RGBColor[
             0.26109333683385083`, 0.39175602965902734`, 0.9381802513284855]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 91}], {
             RGBColor[
             0.20107373419917063`, 0.3286716218273784, 0.9347622237494856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 74}], {
             RGBColor[
             0.21085428282309587`, 0.33895159855372314`, 0.9353192115245932]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 86}], {
             RGBColor[
             0.24146347567626655`, 0.37112380097732395`, 0.9370623597753382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 75}], {
             RGBColor[
             0.18710118921222496`, 0.31398559113557856`, 0.933966507983007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 78}], {
             RGBColor[
             0.18290629963313676`, 0.3095764962165958, 0.9337276152272609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 79}], {
             RGBColor[
             0.23169685165208387`, 0.3608584598881792, 0.9365061649855866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 93}], {
             RGBColor[
             0.20455172295727864`, 0.33232720852937364`, 0.9349602900640366]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 70}], {
             RGBColor[
             0.2130489604942501, 0.3412583439367075, 0.9354441951712307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 91}], {
             RGBColor[
             0.19934283721573776`, 0.3268523393525831, 0.9346636517269117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 68}], {
             RGBColor[
             0.1944928070291569, 0.32175465011681187`, 0.9343874496827627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 73}], {
             RGBColor[
             0.21051618179530102`, 0.3385962329366675, 0.9352999571712358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 84}], {
             RGBColor[
             0.2010083932435165, 0.32860294434013004`, 0.9347585026787244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 97}], {
             RGBColor[
             0.1941986636170478, 0.3214454867409158, 0.9343706986505892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 73}], {
             RGBColor[
             0.19600658059736395`, 0.32334572211578516`, 0.9344736568480447]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 84}], {
             RGBColor[
             0.1864987920455794, 0.3133524335192477, 0.9339322023555332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 97}], {
             RGBColor[
             0.17968906241911073`, 0.3061949759200334, 0.9335443983273981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 82}], {
             RGBColor[
             0.2941120317818493, 0.4264607715555487, 0.9400606171589923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 87}], {
             RGBColor[
             0.24070263486644833`, 0.37032410904611146`, 0.9370190310167823]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 99}], {
             RGBColor[
             0.24913580468691718`, 0.37918790522127327`, 0.9374992875623012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 82}], {
             RGBColor[
             0.25736479876417967`, 0.3878370997448354, 0.9379679166012955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 91}], {
             RGBColor[
             0.19734519612949952`, 0.32475269191318645`, 0.9345498890222956]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 75}], {
             RGBColor[
             0.18763170465412526`, 0.31454319650163753`, 0.9339967200525959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 76}], {
             RGBColor[
             0.24698462168952967`, 0.3766036771778597, 0.9373886147467216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 78}], {
             RGBColor[
             0.18343681507503706`, 0.31013410158265475`, 0.9337578272968499]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 93}], {
             RGBColor[
             0.20508223839917897`, 0.3328848138954327, 0.9349905021336256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 76}], {
             RGBColor[
             0.29540517076777295`, 0.427496744299222, 0.9401460933849444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 89}], {
             RGBColor[
             0.24467233325504664`, 0.3744965137459432, 0.9372450994673704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 92}], {
             RGBColor[
             0.385487127657241, 0.5044598882396888, 0.9461792817523613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 94}], {
             RGBColor[
             0.6519399219645001, 0.3353068708330537, 0.4361392635263973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 84}], {
             RGBColor[
             0.20252216681172355`, 0.33019401633910334`, 0.9348447098440065]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 97}], {
             RGBColor[
             0.19571243718525488`, 0.32303655873988907`, 0.9344569058158713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 95}], {
             RGBColor[
             0.18415739136148795`, 0.31089147294689, 0.9337988630503662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 96}], {
             RGBColor[
             0.18450139038520275`, 0.31125303773161206`, 0.9338184532858658]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 78}], {
             RGBColor[
             0.1893409435855542, 0.3163397149905769, 0.9340940586811484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 93}], {
             RGBColor[
             0.21098636690969608`, 0.33909042730335476`, 0.9353267335179241]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 92}], {
             RGBColor[
             0.40232362412491923`, 0.5218329152024708, 0.9471499291925627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 93}], {
             RGBColor[
             0.2703392839451005, 0.40115090797957687`, 0.9387186282120497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 94}], {
             RGBColor[
             0.6631642529429523, 0.34688888880824165`, 0.43678636181986485`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 93}], {
             RGBColor[
             0.20679147733060788`, 0.3346813323843719, 0.935087840762178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 88}], {
             RGBColor[
             0.24574557647575745`, 0.3756245604184607, 0.9373062190810688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 90}], {
             RGBColor[
             0.32182194731276953`, 0.45076210863195715`, 0.9418152693221177]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 93}], {
             RGBColor[
             0.255582029349555, 0.3859632960559554, 0.9378663905205036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 100}], {
             RGBColor[
             0.5939742401547752, 0.6708787372417735, 0.9651171386659816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 81}], {
             RGBColor[
             0.5669725360193991, 0.6549994961691269, 0.9610400768362422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 85}], {
             RGBColor[
             0.2895357338474329, 0.4164414495746913, 0.9399907433164134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 88}], {
             RGBColor[
             0.28692675368511766`, 0.4136992460052015, 0.9398421657558098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 100}], {
             RGBColor[
             0.6351554173641354, 0.7089534228285144, 0.9676530853407227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 85}], {
             RGBColor[
             0.49141875740375146`, 0.5807970271555756, 0.95654666136112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 88}], {
             RGBColor[
             0.48880977724143615`, 0.5780548235860858, 0.9563980838005164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 90}], {
             RGBColor[
             0.5648861480784482, 0.6531923717995822, 0.9609071340415651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 100}], {
             RGBColor[
             0.8370384409204539, 0.8733090004093986, 0.9842090033854292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 87}], {
             RGBColor[
             0.25026888120494656`, 0.3803788404829227, 0.9375638145937665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 99}], {
             RGBColor[
             0.25870205102541544`, 0.38924263665808456`, 0.9380440711392855]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 92}], {
             RGBColor[
             0.7090145270047958, 0.28901668638097916`, 0.42720637251999316`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 94}], {
             RGBColor[
             0.8244211819322343, 0.18871748252712017`, 0.1710190574390748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 98}], {
             RGBColor[
             0.876613195949491, 0.4201330021795999, 0.34917887785086077`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 97}], {
             RGBColor[
             0.18620464863347033`, 0.3130432701433516, 0.9339154513233598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 88}], {
             RGBColor[
             0.21137297506947, 0.33949677699165026`, 0.9353487502806876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 99}], {
             RGBColor[
             0.2052926541100144, 0.3331059741486473, 0.9350024849970755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 90}], {
             RGBColor[
             0.28484036574416677`, 0.41189212163565686`, 0.9397092229611329]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 100}], {
             RGBColor[
             0.5569926585861724, 0.6320087502454732, 0.9630110923049968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 93}], {
             RGBColor[
             0.2946768186179643, 0.42223085727315157`, 0.9402693944005678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 94}], {
             RGBColor[
             0.6793892760581949, 0.36094218833729147`, 0.4378202059455436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 100}], {
             RGBColor[
             0.6330690294231844, 0.7071462984589696, 0.9675201425460458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 93}], {
             RGBColor[
             0.36042124083456856`, 0.4781140519200437, 0.9447518165794666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 94}], {
             RGBColor[
             0.7232188908692644, 0.39819765143521957`, 0.4408084873981428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 98}], {
             RGBColor[
             0.7438035844314304, 0.7954705328408687, 0.836141875556281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 98}], {
             RGBColor[
             0.8908175598139597, 0.5293139672338403, 0.3627809927290103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 100}], {
             RGBColor[
             0.8608241379528653, 0.5076866074105023, 0.4533547855081195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 96}], {
             RGBColor[
             0.1870839340877883, 0.3139674549057575, 0.933965525329197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 99}], {
             RGBColor[
             0.2005768785209932, 0.32814939500714435`, 0.9347339285536456]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.07669400150882427], {
             RGBColor[
             0.21203034912864388`, 0.34018771880776466`, 0.9353861867608598]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.07669400150882427], {
             RGBColor[
             0.2017962151144583, 0.3294309950772815, 0.9348033679687965]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.07669400150882427], {
             RGBColor[
             0.21537575703287248`, 0.343703954626221, 0.9355767027919182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.07669400150882427], {
             RGBColor[
             0.183689990141455, 0.3104002046296863, 0.9337722452423434]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.07669400150882427], {
             RGBColor[
             0.23802050301926134`, 0.36750501841773675`, 0.9368662875759435]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.07669400150882427], {
             RGBColor[
             0.26778118074382096`, 0.39878537764220096`, 0.9385611141453799]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.07669400150882427], {
             RGBColor[
             0.22603715190392087`, 0.35490975660716995`, 0.936183853457704]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.07669400150882427], {
             RGBColor[
             0.21469787734026025`, 0.3429914600892306, 0.935538098546257]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.07669400150882427], {
             RGBColor[
             0.2587539830358435, 0.38929722049372417`, 0.9380470285904529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.07669400150882427], {
             RGBColor[
             0.19173043311471463`, 0.318851219988111, 0.9342301365749012]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.07669400150882427], {
             RGBColor[
             0.8089911288218372, 0.8507092854867038, 0.9815963333351826]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.07669400150882427], {
             RGBColor[
             0.1941215755639102, 0.3213644623094032, 0.9343663086000046]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.07669400150882427], {
             RGBColor[
             0.44843155837201204`, 0.5628306098615342, 0.9497946402603753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.07669400150882427], {
             RGBColor[
             0.3673373126440748, 0.49259085012729775`, 0.944627386631417]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.07669400150882427], {
             RGBColor[
             0.9952205177140999, 0.9921854956072724, 0.7211610326044653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.07669400150882427], {
             RGBColor[
             0.8403883327970058, 0.3114480009238769, 0.18630921913949752`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.07669400150882427], {
             RGBColor[
             0.18071510283271827`, 0.3072734094494546, 0.9336028298110622]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.07669400150882427], {
             RGBColor[
             0.1892131273465531, 0.3162053720193691, 0.9340867797354244]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.07669400150882427], {
             RGBColor[
             0.9856960730750132, 0.9883529728694329, 0.8867166167306869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.07669400150882427], {
             RGBColor[
             0.2804367749649336, 0.412087209579609, 0.9392818315139984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.07669400150882427], {
             RGBColor[
             0.4922675194356353, 0.5986839745337034, 0.9531722488467641]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.07669400150882427], {
             RGBColor[
             0.2606170023412793, 0.3912553719059836, 0.9381531247838073]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.07669400150882427], {
             RGBColor[
             0.1875302254819779, 0.3144365354575595, 0.9339909409638671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.07669400150882427], {
             RGBColor[
             0.1817669047970064, 0.30837892000201766`, 0.9336627283769269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.07669400150882427], {
             RGBColor[
             0.18067521481883725`, 0.30723148461781946`, 0.9336005582476807]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.07669400150882427], {
             RGBColor[
             0.18224129858820518`, 0.30887753795487116`, 0.933689744401533]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.07669400150882427], {
             RGBColor[
             0.18442048533158978`, 0.31116800139058814`, 0.9338138458627508]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.07669400150882427], {
             RGBColor[
             0.18731005971618434`, 0.31420512727839467`, 0.9339784028492112]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.07669400150882427], {
             RGBColor[
             0.6161375064541084, 0.6992472102746226, 0.9629237479755716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.07669400150882427], {
             RGBColor[
             0.34530965215579634`, 0.47351159775475865`, 0.9432238035833993]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.07669400150882427], {
             RGBColor[
             0.20550175480302402`, 0.3333257522347501, 0.9350143929722056]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.07669400150882427], {
             RGBColor[
             0.1998164887845688, 0.3273501771826685, 0.9346906254830519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.07669400150882427], {
             RGBColor[
             0.1801052224087206, 0.3066323864551807, 0.9335680980231528]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.07669400150882427], {
             RGBColor[
             0.5809901406391762, 0.6707129953352746, 0.9601568185895769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.07669400150882427], {
             RGBColor[
             0.2593028926594576, 0.38987415931102276`, 0.9380782881814786]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.07669400150882427], {
             RGBColor[
             0.21464331877210557`, 0.34293411557488707`, 0.9355349915165129]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.07669400150882427], {
             RGBColor[
             0.18428365683337072`, 0.31102418596353204`, 0.9338060536821968]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.07669400150882427], {
             RGBColor[
             0.24467173389454344`, 0.3744958837800527, 0.9372450653346764]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.07669400150882427], {
             RGBColor[
             0.8506345833650307, 0.3902051727253455, 0.1961210402549231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.07669400150882427], {
             RGBColor[
             0.24383895069200018`, 0.373620575832675, 0.937197639563284]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.07669400150882427], {
             RGBColor[
             0.19034752192527446`, 0.31739769264637574`, 0.9341513818284962]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.07669400150882427], {
             RGBColor[
             0.19862876493803053`, 0.32610180411391543`, 0.9346229863670715]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.07669400150882427], {
             RGBColor[
             0.3311794381510885, 0.4612727165890868, 0.9423234388418769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.07669400150882427], {
             RGBColor[
             0.3832335865508577, 0.5063594036153954, 0.9456402831482341]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.07669400150882427], {
             RGBColor[
             0.1817091834441676, 0.3083182512004389, 0.9336594412312738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.07669400150882427], {
             RGBColor[
             0.9363455102557688, 0.952047166290189, 0.9926346267738634]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.07669400150882427], {
             RGBColor[
             0.1799004504621859, 0.30641715815608145`, 0.9335564365637306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.07669400150882427], {
             RGBColor[
             0.18651265113070192`, 0.3133670002964282, 0.9339329916099283]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.07669400150882427], {
             RGBColor[
             0.9205420850582187, 0.9394792874489195, 0.9922833199221152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.07669400150882427], {
             RGBColor[
             0.4754448270480406, 0.5850265549997984, 0.9518479048784599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.07669400150882427], {
             RGBColor[
             0.2737610733822001, 0.40507062395222915`, 0.9389016601846771]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.07669400150882427], {
             RGBColor[
             0.1957065942777277, 0.32303041747361627`, 0.9344565730709314]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.07669400150882427], {
             RGBColor[
             0.18276021717085633`, 0.30942295428657596`, 0.9337192960471437]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.07669400150882427], {
             RGBColor[
             0.192437328009562, 0.3195942113423206, 0.9342703931934054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.07669400150882427], {
             RGBColor[
             0.22654699403480308`, 0.35544563301258525`, 0.936212888212814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.07669400150882427], {
             RGBColor[
             0.19357289488014912`, 0.3207877641224057, 0.9343350620467646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.07669400150882427], {
             RGBColor[
             0.36937245951795245`, 0.4943535920599945, 0.9447570643906108]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.07669400150882427], {
             RGBColor[
             0.8288259206340116, 0.22257423435778703`, 0.17523704019433756`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.07669400150882427], {
             RGBColor[
             0.3498333886051639, 0.47742983089759583`, 0.9435120520697698]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.07669400150882427], {
             RGBColor[
             0.25368757057631447`, 0.38397209976965585`, 0.9377585038959682]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.07669400150882427], {
             RGBColor[
             0.2092710246978815, 0.33728749387975976`, 0.9352290473165826]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.07669400150882427], {
             RGBColor[
             0.2055452372015114, 0.33337145499250365`, 0.935016869230473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.07669400150882427], {
             RGBColor[
             0.21850839554735407`, 0.34699655632569476`, 0.9357551019209945]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.07669400150882427], {
             RGBColor[
             0.2401337179872893, 0.3697261413347018, 0.9369866320421513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.07669400150882427], {
             RGBColor[
             0.18066654525980752`, 0.30722237236159744`, 0.9336000645291195]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.07669400150882427], {
             RGBColor[
             0.21504660158048836`, 0.34335799137610423`, 0.9355579578758467]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.07669400150882427], {
             RGBColor[
             0.20900240822709396`, 0.33700516093769417`, 0.9352137500059537]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.07669400150882427], {
             RGBColor[
             0.1799832058312198, 0.30650413929592957`, 0.9335611493595715]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.07669400150882427], {
             RGBColor[
             0.2845457854433511, 0.4164060401187374, 0.939515833582008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.07669400150882427], {
             RGBColor[
             0.21105131940801183`, 0.33915869649731084`, 0.9353304324666145]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.07669400150882427], {
             RGBColor[
             0.18172757614360815`, 0.30833758309371545`, 0.9336604886682974]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.07669400150882427], {
             RGBColor[
             0.2785686743000947, 0.4101237173364401, 0.9391754459447431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.07669400150882427], {
             RGBColor[
             0.2120299553635081, 0.3401873049356408, 0.9353861643365179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.07669400150882427], {
             RGBColor[
             0.18157484765890242`, 0.3081770557727445, 0.933651791007035]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.07669400150882427], {
             RGBColor[
             0.1935358331646424, 0.3207488099095597, 0.9343329514368944]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.07669400150882427], {
             RGBColor[
             0.31224166723545116`, 0.4448697712620039, 0.9411167408251457]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.07669400150882427], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.07669400150882427], {
             RGBColor[
             0.185146054006466, 0.31193062007159406`, 0.9338551659254023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.07669400150882427], {
             RGBColor[
             0.2827271580443602, 0.414494547414761, 0.9394122654420536]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.07669400150882427], {
             RGBColor[
             0.3650895124630806, 0.49064391858824263`, 0.9444841587915357]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.07669400150882427], {
             RGBColor[
             0.7688555595757176, 0.8193550737500112, 0.9775959948809486]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.07669400150882427], {
             RGBColor[
             0.30367827812034753`, 0.43651550299235997`, 0.9406054007359764]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.07669400150882427], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.07669400150882427], {
             RGBColor[
             0.193014378259939, 0.32020072774256586`, 0.934303255351495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.07669400150882427], {
             RGBColor[
             0.21398195523178531`, 0.34223898056114005`, 0.9354973278412912]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.07669400150882427], {
             RGBColor[
             0.2427932333652438, 0.3725214606199461, 0.9371380875085253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.07669400150882427], {
             RGBColor[
             0.19685948428954556`, 0.3242421779734855, 0.9345222284515565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.07669400150882427], {
             RGBColor[
             0.2087639949071547, 0.3367545734221604, 0.935200172720084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.07669400150882427], {
             RGBColor[
             0.2107759922099986, 0.33886931015544636`, 0.9353147529899978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.07669400150882427], {
             RGBColor[
             0.36091673658117884`, 0.4870296698491533, 0.9442182732021818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.07669400150882427], {
             RGBColor[
             0.18363907285098718`, 0.310346687329062, 0.9337693455779766]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.07669400150882427], {
             RGBColor[
             0.4924055810143873, 0.5987960591429375, 0.9531831175599796]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.07669400150882427], {
             RGBColor[
             0.22843690065474978`, 0.35743204469714984`, 0.9363205155989537]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.07669400150882427], {
             RGBColor[
             0.8386255457967029, 0.2978984475813605, 0.18462117231722439`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.07669400150882427], {
             RGBColor[
             0.18673993506407352`, 0.31360589012103546`, 0.9339459350936974]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.07669400150882427], {
             RGBColor[
             0.1874279331115031, 0.3143290196904796, 0.9339851155646965]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.07669400150882427], {
             RGBColor[
             0.17939491900700166`, 0.3058858125441373, 0.9335276472952246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.07669400150882427], {
             RGBColor[
             0.9952015878484732, 0.9921450065387998, 0.7191006335525822]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.07669400150882427], {
             RGBColor[
             0.21372582393048328`, 0.34196977032380915`, 0.9354827415425945]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.07669400150882427], {
             RGBColor[
             0.9052213222651901, 0.927262927068786, 0.9908220118899097]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{{3.834946926643799*^9, 3.8349469478612347`*^9}, 
   3.834947050298876*^9, {3.8349471234738255`*^9, 3.8349471300172663`*^9}, {
   3.8349471617829676`*^9, 3.834947218900016*^9}, {3.8349472753220577`*^9, 
   3.834947307624898*^9}, 3.8350238580988164`*^9, 3.8350516551153965`*^9},
 CellLabel->
  "Out[394]=",ExpressionUUID->"fca6a772-da3c-4e08-bac0-aa6cab11c10d"]
}, Open  ]],

Cell["r = 3 :", "Text",
 CellChangeTimes->{{3.834793779215767*^9, 3.8347938725231647`*^9}, {
  3.8347953347101345`*^9, 3.8347953431477337`*^9}, {3.8348851911359825`*^9, 
  3.83488519180678*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"34eae93b-ab06-4a23-924e-329b1b19416f"],

Cell["Cubic Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.834795179278664*^9}},ExpressionUUID->"5a0b6d9d-8792-4690-b69c-\
7b5725350eb3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c\[Rho]3i1", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"CMDi3100", ",", "kri1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.834947911760502*^9, 
   3.834947914304406*^9}, {3.834947957535968*^9, 3.8349479704802837`*^9}, {
   3.8349480487781425`*^9, 3.834948105065866*^9}},
 CellLabel->
  "In[101]:=",ExpressionUUID->"48060b61-747a-4722-b281-55dd0db787af"],

Cell[BoxData["0.0474248031360021`"], "Output",
 CellChangeTimes->{
  3.834948013482303*^9, {3.834948049945756*^9, 3.834948058990469*^9}, 
   3.8349481059508953`*^9, 3.8350238584048147`*^9},
 CellLabel->
  "Out[101]=",ExpressionUUID->"a1c56629-e4f7-4148-be04-fa6fbd7c1810"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CP3i1", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"CMDi3100", ",", "kri1"}], "}"}], "]"}], ",", "c\[Rho]3i1"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8349481210775223`*^9, 3.834948150679065*^9}, {
  3.8349481924167476`*^9, 3.8349481986802473`*^9}},
 CellLabel->
  "In[102]:=",ExpressionUUID->"1c45c115-eacb-4fdd-b668-84d7667ef12c"],

Cell[BoxData["0.4716972721989238`"], "Output",
 CellChangeTimes->{3.8349481513130674`*^9, 3.8349482002632475`*^9, 
  3.835023858565814*^9},
 CellLabel->
  "Out[102]=",ExpressionUUID->"18bcb3db-68cd-4f48-89bb-a046b9b07d42"]
}, Open  ]],

Cell["Absolute Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.8347951985065947`*^9}},ExpressionUUID->"7f3e9411-fb17-45ea-acb3-\
35cf87df2cdd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a\[Rho]3i1", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"AMDi3100", ",", "kri1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.8348873709111376`*^9, 
   3.8348873755217657`*^9}, {3.8349481641806583`*^9, 3.8349481824982553`*^9}},
 CellLabel->
  "In[103]:=",ExpressionUUID->"1a39d084-04d8-4444-a67d-c4ed4418d41e"],

Cell[BoxData["0.09644215730564351`"], "Output",
 CellChangeTimes->{3.834948182946122*^9, 3.8350238587128143`*^9},
 CellLabel->
  "Out[103]=",ExpressionUUID->"e039c451-d5b6-43ca-9744-21bbbf02bba8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"aP3i1", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"AMDi3100", ",", "kri1"}], "}"}], "]"}], ",", "a\[Rho]3i1"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8349482041094093`*^9, 
  3.8349482202691827`*^9}},
 CellLabel->
  "In[104]:=",ExpressionUUID->"248e3156-d3d3-430d-bc17-912f95c2f2c6"],

Cell[BoxData["0.5190197895143842`"], "Output",
 CellChangeTimes->{3.834887440036944*^9, 3.8349482220989213`*^9, 
  3.8350238588618135`*^9},
 CellLabel->
  "Out[104]=",ExpressionUUID->"2025f610-84e1-4702-a9e7-7e21fb3fb4bb"]
}, Open  ]],

Cell["Max-min Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 3.8347951985065947`*^9}, {
  3.8348543263190746`*^9, 
  3.834854330052075*^9}},ExpressionUUID->"1511cf4d-e3f8-4873-b6f3-\
ed833dd4bd81"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mM\[Rho]3i1", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"mMDi3100", ",", "kri1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8348874651734295`*^9, 3.8348874872060013`*^9}, {
  3.8349482319487157`*^9, 3.834948245258479*^9}},
 CellLabel->
  "In[105]:=",ExpressionUUID->"4a90530d-d97e-4525-bd15-28d1f96b7328"],

Cell[BoxData["0.07079189486014038`"], "Output",
 CellChangeTimes->{3.834948246413353*^9, 3.835023858997735*^9},
 CellLabel->
  "Out[105]=",ExpressionUUID->"b7a4dbb7-8173-4cc0-ad25-2cf732697f8d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mMP3i1", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"mMDi3100", ",", "kri1"}], "}"}], "]"}], ",", "mM\[Rho]3i1"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8348875260806427`*^9, 
  3.8348875488478312`*^9}, {3.8349482525846663`*^9, 3.8349482707073736`*^9}},
 CellLabel->
  "In[106]:=",ExpressionUUID->"63e2c75b-b88f-4156-a304-11becd1efad3"],

Cell[BoxData["0.5442825713093566`"], "Output",
 CellChangeTimes->{3.834887440036944*^9, 3.8348875533996215`*^9, 
  3.834948277702903*^9, 3.8350238591463633`*^9},
 CellLabel->
  "Out[106]=",ExpressionUUID->"82c2e2c1-ae4e-49b3-a495-5ef49b779d00"]
}, Open  ]],

Cell["r = 6 :", "Text",
 CellChangeTimes->{{3.834793779215767*^9, 3.8347938725231647`*^9}, {
  3.8347953347101345`*^9, 3.8347953431477337`*^9}, {3.8348851911359825`*^9, 
  3.83488519180678*^9}, {3.834948305866973*^9, 3.8349483068980722`*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"5a9b4640-64d8-4399-a768-e61bb29493f3"],

Cell["Cubic Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.834795179278664*^9}},ExpressionUUID->"c492f684-1cc9-4d45-8ff0-\
babbd4d67601"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c\[Rho]6i1", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"CMDi6100", ",", "kri1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.834947911760502*^9, 
   3.834947914304406*^9}, {3.834947957535968*^9, 3.8349479704802837`*^9}, {
   3.8349480487781425`*^9, 3.834948105065866*^9}, {3.8349483158342133`*^9, 
   3.8349483193845987`*^9}},
 CellLabel->
  "In[107]:=",ExpressionUUID->"b180caaf-1706-49b2-892b-7ad6163a12be"],

Cell[BoxData[
 RowBox[{"-", "0.07410596008124802`"}]], "Output",
 CellChangeTimes->{
  3.834948013482303*^9, {3.834948049945756*^9, 3.834948058990469*^9}, 
   3.8349481059508953`*^9, 3.834948360850016*^9, 3.835023859295019*^9},
 CellLabel->
  "Out[107]=",ExpressionUUID->"28ba0099-943f-4b99-9562-b5f236b8f763"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CP6i1", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"CMDi6100", ",", "kri1"}], "}"}], "]"}], ",", "c\[Rho]6i1"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8349481210775223`*^9, 3.834948150679065*^9}, {
  3.8349481924167476`*^9, 3.8349481986802473`*^9}, {3.8349483230197706`*^9, 
  3.834948338654296*^9}},
 CellLabel->
  "In[108]:=",ExpressionUUID->"5d3bcd3b-35a3-41c0-a8b4-d0e5b1f3b493"],

Cell[BoxData["0.8638748382086572`"], "Output",
 CellChangeTimes->{3.8349481513130674`*^9, 3.8349482002632475`*^9, 
  3.834948361143017*^9, 3.835023859477827*^9},
 CellLabel->
  "Out[108]=",ExpressionUUID->"ff6b8177-69ce-439f-bad2-231f498e3c46"]
}, Open  ]],

Cell["Absolute Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.8347951985065947`*^9}},ExpressionUUID->"21eb980c-116d-4c63-a590-\
3561b68ad906"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a\[Rho]6i1", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"AMDi6100", ",", "kri1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.8348873709111376`*^9, 
   3.8348873755217657`*^9}, {3.8349481641806583`*^9, 
   3.8349481824982553`*^9}, {3.834948329127375*^9, 3.834948332212267*^9}},
 CellLabel->
  "In[109]:=",ExpressionUUID->"3467270c-2374-47ac-b320-af615cae09c5"],

Cell[BoxData[
 RowBox[{"-", "0.12371546700549275`"}]], "Output",
 CellChangeTimes->{3.834948182946122*^9, 3.8349483612910123`*^9, 
  3.835023859623679*^9},
 CellLabel->
  "Out[109]=",ExpressionUUID->"e5f4fd5e-12e5-4746-afda-bf50caedabf6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"aP6i1", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"AMDi6100", ",", "kri1"}], "}"}], "]"}], ",", "a\[Rho]6i1"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8349482041094093`*^9, 
  3.8349482202691827`*^9}, {3.834948340881687*^9, 3.834948354997751*^9}},
 CellLabel->
  "In[110]:=",ExpressionUUID->"52cf3c58-f8f0-4e87-8936-bf59c9ffef65"],

Cell[BoxData["0.7599043212900367`"], "Output",
 CellChangeTimes->{3.834887440036944*^9, 3.8349482220989213`*^9, 
  3.834948361458013*^9, 3.835023859754854*^9},
 CellLabel->
  "Out[110]=",ExpressionUUID->"facbb898-cdb0-4dbe-851b-15561a7e798e"]
}, Open  ]],

Cell["Max-min Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 3.8347951985065947`*^9}, {
  3.8348543263190746`*^9, 
  3.834854330052075*^9}},ExpressionUUID->"768728da-458e-4adf-92e6-\
7cb009a5fee1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mM\[Rho]6i1", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"mMDi3100", ",", "kri1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8348874651734295`*^9, 3.8348874872060013`*^9}, {
   3.8349482319487157`*^9, 3.834948245258479*^9}, 3.8349483527075925`*^9},
 CellLabel->
  "In[111]:=",ExpressionUUID->"21f80d1c-4d88-4ce0-8433-b5e71fc26292"],

Cell[BoxData["0.07079189486014038`"], "Output",
 CellChangeTimes->{3.834948246413353*^9, 3.8349483615970154`*^9, 
  3.8350238598956223`*^9},
 CellLabel->
  "Out[111]=",ExpressionUUID->"b6d9a6b7-8814-4a44-936c-eb69c0ac8f6b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mMP6i1", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"mMDi6100", ",", "kri1"}], "}"}], "]"}], ",", "mM\[Rho]6i1"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8348875260806427`*^9, 
  3.8348875488478312`*^9}, {3.8349482525846663`*^9, 3.8349482707073736`*^9}, {
  3.83494834565068*^9, 3.8349483504716325`*^9}},
 CellLabel->
  "In[112]:=",ExpressionUUID->"65a51a04-a46b-482a-8f5f-378480feaa8f"],

Cell[BoxData["0.1310409843427414`"], "Output",
 CellChangeTimes->{3.834887440036944*^9, 3.8348875533996215`*^9, 
  3.834948277702903*^9, 3.8349483617580156`*^9, 3.835023860046625*^9},
 CellLabel->
  "Out[112]=",ExpressionUUID->"5a4e32e2-ca36-4208-bfcb-07114b835e95"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2nd imported file", "Subsection",
 CellChangeTimes->{{3.834947473073307*^9, 3.8349474798089457`*^9}, {
   3.8349497159535103`*^9, 3.8349497173354855`*^9}, {3.834956622993673*^9, 
   3.834956623710862*^9}, {3.83495955651396*^9, 3.834959556949829*^9}, 
   3.8352015877485085`*^9},
 Background->RGBColor[
  1, 1, 0],ExpressionUUID->"a09adbe8-368a-48d5-9da1-67a165bf0caf"],

Cell["Dividing stuff", "Text",
 CellChangeTimes->{{3.83494752022309*^9, 
  3.834947523245259*^9}},ExpressionUUID->"f1e1a62b-b6eb-445f-a593-\
9a204635ada9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data2", "=", 
   RowBox[{"StringSplit", "[", 
    RowBox[{
     RowBox[{"Import", "[", "\"\<ariadnaComputation2.txt\>\"", "]"}], ",", 
     "\"\<]\n{\>\""}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8349434033501863`*^9, 3.834943479535334*^9}, {
   3.834943567297134*^9, 3.8349435736474867`*^9}, {3.8349441109152327`*^9, 
   3.8349441401892223`*^9}, 3.834944204627252*^9, {3.834949720382628*^9, 
   3.8349497230261507`*^9}},
 CellLabel->
  "In[113]:=",ExpressionUUID->"8a2dbd7c-de30-446e-8144-a29f2263ac25"],

Cell[BoxData[
 RowBox[{
  RowBox[{"graphi2", "=", 
   RowBox[{"ToExpression", "@", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"data2", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
       "<>", "\"\<]\>\""}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834944474381714*^9, 3.83494454689666*^9}, 
   3.8349475108233376`*^9, {3.834949726505718*^9, 3.8349497324197383`*^9}},
 CellLabel->
  "In[114]:=",ExpressionUUID->"81f83003-159b-4cf1-90bd-2dbd96860c67"],

Cell[BoxData[
 RowBox[{
  RowBox[{"otheri2", "=", 
   RowBox[{"ToExpression", "@", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "<>", "\"\<}}\>\""}], "&"}], ",", 
      RowBox[{"StringSplit", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\"\<{\>\"", "<>", 
          RowBox[{
          "data2", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
         ")"}], ",", "\"\<}}\>\""}], "]"}]}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834944518155362*^9, 3.8349445533517303`*^9}, 
   3.8349446259294133`*^9, {3.8349447635371876`*^9, 3.8349447780382657`*^9}, {
   3.834944820013957*^9, 3.8349448816359477`*^9}, {3.834944915595456*^9, 
   3.834944918286141*^9}, {3.8349449615053425`*^9, 3.834944967406804*^9}, {
   3.834945029266304*^9, 3.834945031628281*^9}, {3.834945108799203*^9, 
   3.8349451822852197`*^9}, 3.834945584171259*^9, {3.834949734758335*^9, 
   3.8349497379503355`*^9}},
 CellLabel->
  "In[115]:=",ExpressionUUID->"3b656c4d-db49-4353-a7f0-80932b07cfde"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "CMDi3200", "}"}], ",", 
     RowBox[{"{", "AMDi3200", "}"}], ",", 
     RowBox[{"{", "mMDi3200", "}"}], ",", 
     RowBox[{"{", "CMDi6200", "}"}], ",", 
     RowBox[{"{", "AMDi6200", "}"}], ",", 
     RowBox[{"{", "mMDi6200", "}"}]}], "}"}], "=", "otheri2"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.834945694541313*^9, 3.834945753140644*^9}, {
  3.8349459487260857`*^9, 3.8349459670133495`*^9}, {3.8349471029719105`*^9, 
  3.8349471182020655`*^9}, {3.83494974203613*^9, 3.8349497544188104`*^9}},
 CellLabel->
  "In[116]:=",ExpressionUUID->"871600bb-d766-47c3-8c76-2b04ca13f90d"],

Cell["\[OpenCurlyDoubleQuote]Cleaning\[CloseCurlyDoubleQuote] the graph:", \
"Text",
 CellChangeTimes->{{3.8349477786156034`*^9, 
  3.8349478283202667`*^9}},ExpressionUUID->"c4a9b967-1491-4b2d-bdc8-\
768fc055f8ff"],

Cell[BoxData[
 RowBox[{
  RowBox[{"graphin2", "=", 
   RowBox[{"IndexGraph", "@", "graphi2"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834946654863307*^9, 3.834946693639777*^9}, {
  3.834949757637121*^9, 3.834949759707878*^9}},
 CellLabel->
  "In[117]:=",ExpressionUUID->"fe770572-de94-4cd5-b307-ee7c2c512c0b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pointsi2", "=", 
   RowBox[{"VertexList", "@", "graphin2"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834784420352569*^9, 3.8347844264642625`*^9}, {
  3.8348756828269844`*^9, 3.8348756865131674`*^9}, {3.834878831782991*^9, 
  3.8348788488376627`*^9}, {3.8349467020325813`*^9, 3.834946739879963*^9}, {
  3.8349497621629615`*^9, 3.8349497641865125`*^9}},
 CellLabel->
  "In[118]:=",ExpressionUUID->"56201248-fadf-438f-92c2-e3b40e4a2d01"],

Cell[BoxData[
 RowBox[{
  RowBox[{"coordpointsi2", "=", 
   RowBox[{"VertexList", "@", "graphi2"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834879134322084*^9, 3.834879146224797*^9}, {
  3.834946724882841*^9, 3.834946736706849*^9}, {3.834949767417904*^9, 
  3.8349497706963253`*^9}},
 CellLabel->
  "In[119]:=",ExpressionUUID->"1074ed44-022d-4e08-9170-28dccbf0a4d7"],

Cell["Kretchmann \[OpenCurlyDoubleQuote]real\[CloseCurlyDoubleQuote] \
values:", "Text",
 CellChangeTimes->{
  3.8347933561184683`*^9, {3.8347935444076195`*^9, 
   3.834793546974228*^9}},ExpressionUUID->"bc61090f-8d1f-4b70-921e-\
f6e4d909cc4e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rvali2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Sinh", "[", "\[Nu]", "]"}], "\[Equal]", "#"}], ",", 
       RowBox[{"{", "\[Nu]", "}"}]}], "]"}], "&"}], "/@", 
    RowBox[{"coordpointsi2", "\[LeftDoubleBracket]", 
     RowBox[{";;", ",", "3"}], "\[RightDoubleBracket]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834105426841242*^9, 3.8341054487325706`*^9}, {
   3.8341407674337025`*^9, 3.834140799285215*^9}, {3.8341408938375945`*^9, 
   3.834140946496229*^9}, {3.8341410168099756`*^9, 3.8341410671886864`*^9}, {
   3.8341411610986195`*^9, 3.834141210381962*^9}, {3.834141332672348*^9, 
   3.834141336755044*^9}, {3.834141461053176*^9, 3.834141468978607*^9}, {
   3.834141967115094*^9, 3.8341420256686225`*^9}, {3.8341640069512*^9, 
   3.834164012603241*^9}, {3.834164792400744*^9, 3.8341647947633886`*^9}, {
   3.83466546628111*^9, 3.834665483801684*^9}, {3.8347933895124626`*^9, 
   3.834793417249506*^9}, 3.8347960586942053`*^9, 3.834879156483405*^9, {
   3.8348862453609915`*^9, 3.8348862641404076`*^9}, 3.834886374221485*^9, {
   3.834946768449996*^9, 3.8349467823353415`*^9}, {3.8349468446168528`*^9, 
   3.834946857637892*^9}, 3.8349474594107084`*^9, {3.834949773350379*^9, 
   3.8349497766098785`*^9}},
 CellLabel->
  "In[120]:=",ExpressionUUID->"d0aecc3c-a02c-4974-8719-0c804eb00af8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"kri2", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"KHyperboloid", "/.", "rvali2"}], ")"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834792366597866*^9, 3.834792376019791*^9}, {
   3.834793346399704*^9, 3.8347933590872536`*^9}, {3.834793445378667*^9, 
   3.8347934527754736`*^9}, {3.834793487784485*^9, 3.834793489659489*^9}, 
   3.8348550102643666`*^9, {3.8348863808528233`*^9, 3.83488645374378*^9}, {
   3.834886485165092*^9, 3.834886521271514*^9}, 3.8348865820814276`*^9, {
   3.83494679091998*^9, 3.8349467979310513`*^9}, {3.8349468742957215`*^9, 
   3.834946904080855*^9}, 3.8349474644429636`*^9, {3.834949779141443*^9, 
   3.834949781745859*^9}},
 CellLabel->
  "In[121]:=",ExpressionUUID->"d17f6295-5925-4c0d-8956-0ac5e847e7a3"],

Cell["Estimated with cubic Mean Deviation v Calculated: (r=3)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 
  3.8349503319477153`*^9}},ExpressionUUID->"2c36343d-e58f-4e66-85f1-\
dc73b3b215dc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphin2", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsi2", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}], 
     "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"CMDi3200", ",", "kri2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 3.8349497932388773`*^9}, 
   3.8350516713054113`*^9, 3.835128751065734*^9, {3.835189451672152*^9, 
   3.8351895247490115`*^9}, {3.8351895885814776`*^9, 
   3.8351896103022194`*^9}, {3.8351896731267796`*^9, 3.835189719654523*^9}, {
   3.835189752269187*^9, 3.8351897746576805`*^9}},
 CellLabel->
  "In[657]:=",ExpressionUUID->"ede69581-bc23-4b45-83bd-d7f4b437ba83"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
          103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
          129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 
          142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 
          155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 
          168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 
          181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 
          194, 195, 196, 197, 198, 199, 200}, {Null, CompressedData["
1:eJwVxfk/Gg4DAOBN5QibNGP1lWNDwghlmCNXuqiMigzJGcNQUi05SwdqhpKc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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[21, 55] -> 
             RGBColor[
              0.2385306414176846, 0.36804120621912223`, 0.9368953392030515], 
             UndirectedEdge[64, 132] -> 
             RGBColor[
              0.320253422735556, 0.45142184914464745`, 0.9416414238263554], 
             UndirectedEdge[42, 188] -> 
             RGBColor[
              0.32196634291106635`, 0.45187403111194935`, 0.941788336512897], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.4253486538322264, 0.5427770190033808, 0.9483404898748904], 
             UndirectedEdge[33, 68] -> 
             RGBColor[
              0.3808943840469553, 0.5043333039782516, 0.9454912312331609], 
             UndirectedEdge[168, 188] -> 
             RGBColor[
              0.3278806759096875, 0.4569967290923352, 0.9421651925817298], 
             UndirectedEdge[41, 161] -> 
             RGBColor[
              0.24554419633275684`, 0.3753498329944873, 0.9372970598663999], 
             UndirectedEdge[44, 68] -> 
             RGBColor[
              0.33368953442914073`, 0.45962135142463395`, 0.9426234496805838],
              UndirectedEdge[26, 136] -> 
             RGBColor[
              0.396326892631635, 0.5176398281275594, 0.9464912489141244], 
             UndirectedEdge[9, 32] -> 
             RGBColor[
              0.4284645804026117, 0.5454899978303611, 0.9485351326060316], 
             UndirectedEdge[71, 141] -> 
             RGBColor[
              0.3744463753531817, 0.4983888278564797, 0.9450935341613598], 
             UndirectedEdge[52, 100] -> 
             RGBColor[
              0.3898136590594897, 0.512058731698312, 0.9460595595499546], 
             UndirectedEdge[172, 180] -> 
             RGBColor[
              0.4097725145208436, 0.5278038648479323, 0.9477574413373501], 
             UndirectedEdge[168, 197] -> 
             RGBColor[
              0.49734716752199737`, 0.6003381527924743, 0.954254525277201], 
             UndirectedEdge[125, 137] -> 
             RGBColor[
              0.6774222700673801, 0.745839907137788, 0.9701151493274485], 
             UndirectedEdge[17, 147] -> 
             RGBColor[
              0.5262849541184198, 0.6180277464949461, 0.9584397623913299], 
             UndirectedEdge[10, 71] -> 
             RGBColor[
              0.4965853717489068, 0.5970948477720717, 0.9551204264559573], 
             UndirectedEdge[27, 129] -> 
             RGBColor[
              0.614671959877483, 0.6919780832715674, 0.9659950807014296], 
             UndirectedEdge[67, 166] -> 
             RGBColor[
              0.41751269818917613`, 0.5360502471982599, 0.9478245178299995], 
             UndirectedEdge[3, 49] -> 
             RGBColor[
              0.33264389355175783`, 0.45861465500124915`, 0.9425605210170234],
              UndirectedEdge[151, 183] -> 
             RGBColor[
              0.8058428582576103, 0.8161929713223273, 0.6528813020246652], 
             UndirectedEdge[125, 136] -> 
             RGBColor[
              0.6089551234711906, 0.6870999696305238, 0.9655969623954417], 
             UndirectedEdge[139, 194] -> 
             RGBColor[
              0.31908742122483685`, 0.45028879400912436`, 0.9415716353858001],
              UndirectedEdge[24, 108] -> 
             RGBColor[
              0.24622841720540087`, 0.37613205663918636`, 0.9373337161463231],
              UndirectedEdge[21, 192] -> 
             RGBColor[
              0.30560069544860846`, 0.4280793752466986, 0.9410977509444254], 
             UndirectedEdge[16, 52] -> 
             RGBColor[
              0.47144326611681014`, 0.5808629510534893, 0.951785692554705], 
             UndirectedEdge[44, 166] -> 
             RGBColor[
              0.3312635833875747, 0.45752011456427416`, 0.9424688702253995], 
             UndirectedEdge[78, 187] -> 
             RGBColor[
              0.5008029838914068, 0.6017205741168228, 0.9551165084319082], 
             UndirectedEdge[99, 162] -> 
             RGBColor[
              0.6527243851179991, 0.7174789368098209, 0.8159692466294814], 
             UndirectedEdge[93, 150] -> 
             RGBColor[
              0.4004716056935939, 0.5212901093887995, 0.9467386744850275], 
             UndirectedEdge[118, 155] -> 
             RGBColor[
              0.41656938769136703`, 0.5338977895283674, 0.9481333885508934], 
             UndirectedEdge[16, 125] -> 
             RGBColor[
              0.7020311917341827, 0.7658185383661857, 0.9720524537865095], 
             UndirectedEdge[61, 179] -> 
             RGBColor[
              0.4864458632098799, 0.5877329087884215, 0.9543379271125387], 
             UndirectedEdge[51, 197] -> 
             RGBColor[
              0.8135603754758085, 0.8522541911827584, 0.8501281550782016], 
             UndirectedEdge[80, 120] -> 
             RGBColor[
              0.7058426996904781, 0.7668631750710964, 0.939540455256016], 
             UndirectedEdge[21, 183] -> 
             RGBColor[
              0.41514417918737, 0.5178662950693322, 0.949485290916211], 
             UndirectedEdge[182, 199] -> 
             RGBColor[
              0.6726983596085703, 0.735910131124311, 0.8693180700660716], 
             UndirectedEdge[17, 189] -> 
             RGBColor[
              0.32926314875370444`, 0.45769884411478556`, 0.9422714183813651],
              UndirectedEdge[116, 136] -> 
             RGBColor[
              0.2675139209422993, 0.3958816976041766, 0.9386419266640746], 
             UndirectedEdge[119, 123] -> 
             RGBColor[
              0.3264330085218576, 0.4563492696664105, 0.9420507438555104], 
             UndirectedEdge[71, 89] -> 
             RGBColor[
              0.32808761350149673`, 0.45823519839967036`, 0.9421395948496138],
              UndirectedEdge[7, 61] -> 
             RGBColor[
              0.4562174048076092, 0.555960882412675, 0.9526164611255261], 
             UndirectedEdge[3, 27] -> 
             RGBColor[
              0.3063433740954796, 0.43583446695076483`, 0.9408846751739055], 
             UndirectedEdge[41, 108] -> 
             RGBColor[
              0.29240619691709335`, 0.42460476683107173`, 0.9399657814735606],
              UndirectedEdge[66, 98] -> 
             RGBColor[
              0.9810647712000207, 0.9840490135095168, 0.8564940632684488], 
             UndirectedEdge[119, 127] -> 
             RGBColor[
              0.5201545453485867, 0.6148464767539237, 0.9575741939411502], 
             UndirectedEdge[15, 167] -> 
             RGBColor[
              0.2766154170389401, 0.4079977639756383, 0.9390668821148167], 
             UndirectedEdge[12, 96] -> 
             RGBColor[
              0.198260641278491, 0.3257148828073513, 0.9346020222692509], 
             UndirectedEdge[7, 52] -> 
             RGBColor[
              0.3266711922218496, 0.45043137572393455`, 0.9422901575512674], 
             UndirectedEdge[163, 165] -> 
             RGBColor[
              0.36932621978759966`, 0.4943135415296393, 0.9447541180358809], 
             UndirectedEdge[71, 73] -> 
             RGBColor[
              0.2767825360171184, 0.408246372753324, 0.9390737280118824], 
             UndirectedEdge[60, 165] -> 
             RGBColor[
              0.7032147410144377, 0.7637451298543046, 0.9228390841161516], 
             UndirectedEdge[120, 124] -> 
             RGBColor[
              0.35419384004910826`, 0.4776326148778476, 0.943920758556211], 
             UndirectedEdge[43, 163] -> 
             RGBColor[
              0.3392960350865395, 0.46830290490255067`, 0.9428406212213789], 
             UndirectedEdge[146, 194] -> 
             RGBColor[
              0.6468478565721663, 0.7077779862644693, 0.679029670192905], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.8571631654767262, 0.8857896644787382, 0.8029927743526823], 
             UndirectedEdge[81, 157] -> 
             RGBColor[
              0.5701393724882217, 0.6619038529287951, 0.9593026063730604], 
             UndirectedEdge[59, 114] -> 
             RGBColor[
              0.3351741100834504, 0.4647327006388494, 0.9425779758050573], 
             UndirectedEdge[31, 185] -> 
             RGBColor[
              0.5898607425715623, 0.6249890109700116, 0.6380493680397606], 
             UndirectedEdge[58, 198] -> 
             RGBColor[
              0.30686106021855786`, 0.4324049345946818, 0.9410596515453051], 
             UndirectedEdge[30, 142] -> 
             RGBColor[
              0.3682682295067342, 0.49339716352449137`, 0.9446867038307283], 
             UndirectedEdge[26, 96] -> 
             RGBColor[
              0.32137315509834286`, 0.44148147068000243`, 0.9421267118767052],
              UndirectedEdge[25, 111] -> 
             RGBColor[
              0.6455110467359535, 0.7135507383015306, 0.9202435239012898], 
             UndirectedEdge[89, 107] -> 
             RGBColor[
              0.3876197178923099, 0.5101584501299902, 0.9459197635588077], 
             UndirectedEdge[51, 189] -> 
             RGBColor[
              0.6826348187739969, 0.743713753622241, 0.8404426687219229], 
             UndirectedEdge[81, 158] -> 
             RGBColor[
              0.4294523588591312, 0.543959916201365, 0.9492572339854759], 
             UndirectedEdge[93, 159] -> 
             RGBColor[
              0.3484773590907184, 0.47231620131972263`, 0.9435698769972781], 
             UndirectedEdge[191, 195] -> 
             RGBColor[
              0.33749044231736275`, 0.46608062557797425`, 0.942749676437169], 
             UndirectedEdge[17, 131] -> 
             RGBColor[
              0.35385072390936945`, 0.4789953659071626, 0.943838116928345], 
             UndirectedEdge[18, 32] -> 
             RGBColor[
              0.39575935157887343`, 0.5172085917194069, 0.9464384138197202], 
             UndirectedEdge[59, 184] -> 
             RGBColor[
              0.30311857202820636`, 0.43586415227666253`, 0.9405758353885997],
              UndirectedEdge[156, 175] -> 
             RGBColor[
              0.5574398978040562, 0.28210632050060364`, 0.5522375095784545], 
             UndirectedEdge[2, 82] -> 
             RGBColor[
              0.5662705167923778, 0.6564700711528089, 0.96011557058695], 
             UndirectedEdge[12, 44] -> 
             RGBColor[
              0.23834265942606392`, 0.3678436252271823, 0.9368846339067232], 
             UndirectedEdge[115, 175] -> 
             RGBColor[
              0.328182891654489, 0.4576431100549091, 0.9421703667938917], 
             UndirectedEdge[30, 131] -> 
             RGBColor[
              0.41021393731288713`, 0.5297284273736065, 0.9473594472410032], 
             UndirectedEdge[53, 65] -> 
             RGBColor[
              0.4236058578189971, 0.535079982042602, 0.9492098395625905], 
             UndirectedEdge[17, 51] -> 
             RGBColor[
              0.6414152637106783, 0.7060973678676783, 0.8378862789276909], 
             UndirectedEdge[109, 128] -> 
             RGBColor[
              0.6935626592535193, 0.7540851863605718, 0.8744497648812094], 
             UndirectedEdge[101, 135] -> 
             RGBColor[
              0.6389945318726584, 0.7027003479759073, 0.7641433781017509], 
             UndirectedEdge[54, 195] -> 
             RGBColor[
              0.6268836160113165, 0.7026419733696517, 0.9667332528636343], 
             UndirectedEdge[122, 192] -> 
             RGBColor[
              0.35518512848044803`, 0.48019575819779553`, 0.9439215110519934],
              UndirectedEdge[155, 195] -> 
             RGBColor[
              0.43792789072135735`, 0.5523974513433692, 0.9494943334773818], 
             UndirectedEdge[42, 87] -> 
             RGBColor[
              0.29621994711081867`, 0.42481293671011144`, 0.9403221173604522],
              UndirectedEdge[31, 153] -> 
             RGBColor[
              0.2553762262419974, 0.38574698394124174`, 0.9378546703379866], 
             UndirectedEdge[64, 199] -> 
             RGBColor[
              0.6635946480054403, 0.7280249536995294, 0.8687379896128163], 
             UndirectedEdge[107, 188] -> 
             RGBColor[
              0.35866118116212997`, 0.48365725566882367`, 0.9441264991582834],
              UndirectedEdge[27, 189] -> 
             RGBColor[
              0.3584459557598485, 0.4848896036867719, 0.9440608372330723], 
             UndirectedEdge[14, 176] -> 
             RGBColor[
              0.33624369080855043`, 0.4637731602847058, 0.9427151826827875], 
             UndirectedEdge[123, 146] -> 
             RGBColor[
              0.6716882218798977, 0.7298038874618493, 0.6805937871349279], 
             UndirectedEdge[30, 130] -> 
             RGBColor[
              0.3972061958832199, 0.5184617755353228, 0.9465306054593989], 
             UndirectedEdge[72, 143] -> 
             RGBColor[
              0.2728576846818415, 0.40271257146353767`, 0.9389017868527698], 
             UndirectedEdge[68, 155] -> 
             RGBColor[
              0.45125453680613864`, 0.5639403223652987, 0.9503434955816136], 
             UndirectedEdge[32, 39] -> 
             RGBColor[
              0.6191526556622756, 0.697459417760141, 0.965543843390962], 
             UndirectedEdge[184, 194] -> 
             RGBColor[
              0.30001718195006466`, 0.43266745879048846`, 0.9403969067251853],
              UndirectedEdge[74, 152] -> 
             RGBColor[
              0.4360011545346787, 0.5504276341035571, 0.9494547238945819], 
             UndirectedEdge[71, 147] -> 
             RGBColor[
              0.5346918170465305, 0.6268638924582861, 0.9589185207982465], 
             UndirectedEdge[39, 173] -> 
             RGBColor[
              0.5698108418661225, 0.654211593360698, 0.9624185158170371], 
             UndirectedEdge[139, 171] -> 
             RGBColor[
              0.2894196190606113, 0.4191060528872219, 0.9398820979421276], 
             UndirectedEdge[73, 189] -> 
             RGBColor[
              0.3095952281523263, 0.4370266125445467, 0.9411513593991977], 
             UndirectedEdge[20, 22] -> 
             RGBColor[
              0.2943543909174071, 0.42671550637347666`, 0.940074419153224], 
             UndirectedEdge[17, 168] -> 
             RGBColor[
              0.3252020557568672, 0.4541813294773942, 0.9420126491266901], 
             UndirectedEdge[13, 132] -> 
             RGBColor[
              0.2991095251418835, 0.4317134539363246, 0.9403452170127173], 
             UndirectedEdge[99, 109] -> 
             RGBColor[
              0.6506441614049128, 0.7169113406705325, 0.8717150361496337], 
             UndirectedEdge[119, 195] -> 
             RGBColor[
              0.3366578239136528, 0.46520549084461915`, 0.9427022600508264], 
             UndirectedEdge[10, 188] -> 
             RGBColor[
              0.4908571289736165, 0.5910741014236727, 0.9547942115040803], 
             UndirectedEdge[182, 185] -> 
             RGBColor[
              0.6624558627380442, 0.6970925026195223, 0.642337283408849], 
             UndirectedEdge[98, 187] -> 
             RGBColor[
              0.8330968063496879, 0.8681240171075324, 0.8725677454294714], 
             UndirectedEdge[10, 167] -> 
             RGBColor[
              0.49892425358839526`, 0.5994802047433826, 0.9552562935981617], 
             UndirectedEdge[113, 187] -> 
             RGBColor[
              0.5567830758094766, 0.6502077160950248, 0.9586835103876761], 
             UndirectedEdge[83, 170] -> 
             RGBColor[
              0.6083698646844383, 0.5959572162574165, 0.60275849766709], 
             UndirectedEdge[39, 41] -> 
             RGBColor[
              0.5729122319442641, 0.6574082868468721, 0.9625974444804515], 
             UndirectedEdge[138, 145] -> 
             RGBColor[
              0.4313210135888975, 0.5449470767508109, 0.9494891842852626], 
             UndirectedEdge[75, 155] -> 
             RGBColor[
              0.4437485360125626, 0.5574390017404725, 0.9498652198483428], 
             UndirectedEdge[90, 163] -> 
             RGBColor[
              0.29838048518832827`, 0.4301598312803955, 0.940332528205529], 
             UndirectedEdge[2, 66] -> 
             RGBColor[
              0.6912205837056664, 0.7544133107438707, 0.9417476794740489], 
             UndirectedEdge[88, 200] -> 
             RGBColor[
              0.34956314083205486`, 0.47719575585957685`, 0.9434948321206381],
              UndirectedEdge[67, 170] -> 
             RGBColor[
              0.6871688666630038, 0.666656807949956, 0.6076898723678724], 
             UndirectedEdge[124, 136] -> 
             RGBColor[
              0.30360172439537714`, 0.43381226713225457`, 0.9406970736836066],
              UndirectedEdge[129, 155] -> 
             RGBColor[
              0.6927174098037759, 0.7582417197904978, 0.9713370453895289], 
             UndirectedEdge[149, 167] -> 
             RGBColor[
              0.3714174584603295, 0.49612486735924605`, 0.9448873699148974], 
             UndirectedEdge[172, 173] -> 
             RGBColor[
              0.4066711244427019, 0.5246071713617583, 0.9475785126739357], 
             UndirectedEdge[143, 160] -> 
             RGBColor[
              0.37745381865296757`, 0.5013532591618242, 0.9452720014486287], 
             UndirectedEdge[27, 89] -> 
             RGBColor[
              0.34886355757953025`, 0.4765898120083166, 0.9434502552944044], 
             UndirectedEdge[172, 191] -> 
             RGBColor[
              0.4058710735721366, 0.5237662671706391, 0.9475329509604262], 
             UndirectedEdge[11, 182] -> 
             RGBColor[
              0.3189590347271991, 0.44837796460016305`, 0.9416293478893465], 
             UndirectedEdge[159, 164] -> 
             RGBColor[
              0.2939185829127177, 0.42506013159816225`, 0.9400934400236474], 
             UndirectedEdge[151, 156] -> 
             RGBColor[
              0.894036726358372, 0.5235685216059169, 0.2525525003365422], 
             UndirectedEdge[94, 196] -> 
             RGBColor[
              0.6100534719512064, 0.6929472778888902, 0.9633750668724068], 
             UndirectedEdge[69, 139] -> 
             RGBColor[
              0.32610572742172517`, 0.4568781233674283, 0.9420001464807082], 
             UndirectedEdge[53, 127] -> 
             RGBColor[
              0.6558605586785738, 0.7299950899611748, 0.9670771912209681], 
             UndirectedEdge[171, 196] -> 
             RGBColor[
              0.48753533243968317`, 0.5817986564053907, 0.955520736341704], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.6122399560765823, 0.6206689674332546, 0.6082764683311799], 
             UndirectedEdge[74, 162] -> 
             RGBColor[
              0.6766801542973673, 0.7382282200210213, 0.8174956870583359], 
             UndirectedEdge[34, 153] -> 
             RGBColor[
              0.33486113403130835`, 0.4638180633388521, 0.9425815968820017], 
             UndirectedEdge[98, 109] -> 
             RGBColor[
              0.9915492110572557, 0.9907733958438751, 0.7897149729293931], 
             UndirectedEdge[77, 183] -> 
             RGBColor[
              0.6989917786109261, 0.7647550859782384, 0.9706475794974614], 
             UndirectedEdge[2, 78] -> 
             RGBColor[
              0.37017806716101376`, 0.49505136890939677`, 0.9448083969972558],
              UndirectedEdge[113, 193] -> 
             RGBColor[
              0.7017189080330328, 0.7223187968191056, 0.6314552322663549], 
             UndirectedEdge[100, 120] -> 
             RGBColor[
              0.3991521184321054, 0.5201472358422562, 0.9466545979235022], 
             UndirectedEdge[1, 35] -> 
             RGBColor[
              0.7671469806738682, 0.6004551170830494, 0.5863612172823525], 
             UndirectedEdge[154, 176] -> 
             RGBColor[
              0.25077980911135483`, 0.38091585810725814`, 0.9375929111821864],
              UndirectedEdge[13, 31] -> 
             RGBColor[
              0.2513145433960602, 0.3814778977445954, 0.9376233635086317], 
             UndirectedEdge[92, 196] -> 
             RGBColor[
              0.566426942749559, 0.6561270113634069, 0.9603280821435995], 
             UndirectedEdge[66, 124] -> 
             RGBColor[
              0.6199516862522221, 0.6891097539508059, 0.9373373507251558], 
             UndirectedEdge[141, 167] -> 
             RGBColor[
              0.37678525719267014`, 0.5007741848277907, 0.9452294013035641], 
             UndirectedEdge[76, 158] -> 
             RGBColor[
              0.2805787407713114, 0.4115636164222032, 0.9393145510614576], 
             UndirectedEdge[101, 134] -> 
             RGBColor[
              0.8597844158958734, 0.8875600838642536, 0.7810420070383024], 
             UndirectedEdge[139, 141] -> 
             RGBColor[
              0.38949248056051433`, 0.5117805430254002, 0.9460390943400068], 
             UndirectedEdge[88, 93] -> 
             RGBColor[
              0.381420711698351, 0.5047891825358936, 0.9455247683656947], 
             UndirectedEdge[17, 130] -> 
             RGBColor[
              0.34084298247970224`, 0.4677287140688789, 0.9430092751467407], 
             UndirectedEdge[32, 117] -> 
             RGBColor[
              0.6239512807023152, 0.7012857111118618, 0.9660015405310641], 
             UndirectedEdge[32, 103] -> 
             RGBColor[
              0.42997182373987497`, 0.54671364587209, 0.9486537883227553], 
             UndirectedEdge[148, 150] -> 
             RGBColor[
              0.3932017560028461, 0.5149933309799435, 0.9462754460912086], 
             UndirectedEdge[77, 156] -> 
             RGBColor[
              0.7871856467116878, 0.47213063626182805`, 0.5703187778093384], 
             UndirectedEdge[76, 89] -> 
             RGBColor[
              0.2982261953079399, 0.4268489545549755, 0.9404390312595001], 
             UndirectedEdge[42, 51] -> 
             RGBColor[
              0.6726593927785385, 0.7350735410044638, 0.839807043398415], 
             UndirectedEdge[82, 124] -> 
             RGBColor[
              0.49500161933893344`, 0.591166514359744, 0.9557052418380568], 
             UndirectedEdge[15, 114] -> 
             RGBColor[
              0.30230793918725607`, 0.43025133531679893`, 0.9407039869071021],
              UndirectedEdge[41, 173] -> 
             RGBColor[
              0.30632670256654304`, 0.4392361008796787, 0.9407585336767541], 
             UndirectedEdge[41, 133] -> 
             RGBColor[
              0.3259545691616138, 0.4567471976799549, 0.9419905148100378], 
             UndirectedEdge[27, 147] -> 
             RGBColor[
              0.5554677611245639, 0.6452185060669324, 0.960229181243037], 
             UndirectedEdge[19, 88] -> 
             RGBColor[
              0.6510050005428394, 0.719570446370153, 0.9390370807526922], 
             UndirectedEdge[127, 172] -> 
             RGBColor[
              0.6252330265771626, 0.7051302796466515, 0.9646660797015983], 
             UndirectedEdge[69, 174] -> 
             RGBColor[
              0.2788465798957732, 0.40962845829679095`, 0.9392201011969412], 
             UndirectedEdge[117, 121] -> 
             RGBColor[
              0.5791883448777698, 0.6625143059512124, 0.963149285842634], 
             UndirectedEdge[69, 196] -> 
             RGBColor[
              0.524221440800797, 0.619570726885597, 0.9576387848802845], 
             UndirectedEdge[92, 195] -> 
             RGBColor[
              0.3875143013335784, 0.5100671436052072, 0.9459130465089016], 
             UndirectedEdge[144, 158] -> 
             RGBColor[
              0.262197042164774, 0.39224328571972655`, 0.9382677405191014], 
             UndirectedEdge[81, 168] -> 
             RGBColor[
              0.45262111857924087`, 0.5640275313752012, 0.9507335268675114], 
             UndirectedEdge[87, 188] -> 
             RGBColor[
              0.2676544381957788, 0.3986521631882669, 0.9385538963447677], 
             UndirectedEdge[74, 88] -> 
             RGBColor[
              0.34522271010439654`, 0.4734362929196707, 0.943218263712764], 
             UndirectedEdge[74, 140] -> 
             RGBColor[
              0.5745086628806405, 0.6606034089339275, 0.9619111417992843], 
             UndirectedEdge[152, 178] -> 
             RGBColor[
              0.7166898076408572, 0.7774368689694522, 0.973531234021269], 
             UndirectedEdge[63, 153] -> 
             RGBColor[
              0.6481576136707295, 0.7126170624963941, 0.7932395350557073], 
             UndirectedEdge[154, 158] -> 
             RGBColor[
              0.2646174324091668, 0.39478726932818836`, 0.9384055781628731], 
             UndirectedEdge[23, 90] -> 
             RGBColor[
              0.2292130227472393, 0.35824779822533914`, 0.9363647146039512], 
             UndirectedEdge[51, 131] -> 
             RGBColor[
              0.7072223939296619, 0.765010275414618, 0.8420093672689027], 
             UndirectedEdge[21, 83] -> 
             RGBColor[
              0.23581371151179964`, 0.36518554062473163`, 0.9367406140642489],
              UndirectedEdge[57, 178] -> 
             RGBColor[
              0.5922137668635299, 0.6671797885774571, 0.9652969294058784], 
             UndirectedEdge[17, 197] -> 
             RGBColor[
              0.46018870545551605`, 0.566239281675303, 0.9519569047376439], 
             UndirectedEdge[64, 156] -> 
             RGBColor[
              0.5766344247765425, 0.29976580358882365`, 0.5534227026190515], 
             UndirectedEdge[40, 123] -> 
             RGBColor[
              0.65077312010943, 0.6570868682643141, 0.6106203699039177], 
             UndirectedEdge[26, 99] -> 
             RGBColor[
              0.38302311074976536`, 0.5061167609290036, 0.9456435436966841], 
             UndirectedEdge[114, 167] -> 
             RGBColor[
              0.3352276053739, 0.46477903557068545`, 0.9425813844776607], 
             UndirectedEdge[75, 168] -> 
             RGBColor[
              0.37367874114660693`, 0.4980834767667271, 0.9450314568480933], 
             UndirectedEdge[55, 111] -> 
             RGBColor[
              0.2969081156996599, 0.4293996330351273, 0.9402198500016761], 
             UndirectedEdge[67, 122] -> 
             RGBColor[
              0.3641971465222047, 0.48800151526836805`, 0.9444957488725996], 
             UndirectedEdge[127, 129] -> 
             RGBColor[
              0.8116419144048073, 0.8532889065011153, 0.9817255170904884], 
             UndirectedEdge[96, 198] -> 
             RGBColor[
              0.2057702541331046, 0.33360796205450555`, 0.9350296836118446], 
             UndirectedEdge[154, 181] -> 
             RGBColor[
              0.26962703837812885`, 0.39912633822838617`, 0.9387247858253948],
              UndirectedEdge[9, 91] -> 
             RGBColor[
              0.3488031689381661, 0.4703743539080196, 0.9436831487987227], 
             UndirectedEdge[39, 152] -> 
             RGBColor[
              0.6749905820727509, 0.744187038396769, 0.9695539246612448], 
             UndirectedEdge[54, 65] -> 
             RGBColor[
              0.5781256365866737, 0.6573678513603836, 0.9637378350955805], 
             UndirectedEdge[116, 128] -> 
             RGBColor[
              0.2971286369090362, 0.42153247609566014`, 0.9405289501782101], 
             UndirectedEdge[74, 95] -> 
             RGBColor[
              0.5960654892101602, 0.3725034958571408, 0.5619881903277077], 
             UndirectedEdge[152, 200] -> 
             RGBColor[
              0.4403415852623371, 0.5541870970434633, 0.9497312923024561], 
             UndirectedEdge[140, 191] -> 
             RGBColor[
              0.5461125101704263, 0.635349723068827, 0.9601258700487403], 
             UndirectedEdge[109, 193] -> 
             RGBColor[
              0.9772657725168508, 0.9399179790097358, 0.5580484224483246], 
             UndirectedEdge[80, 137] -> 
             RGBColor[
              0.7237177306329364, 0.7817827648327675, 0.9408349573154182], 
             UndirectedEdge[118, 199] -> 
             RGBColor[
              0.660939057142635, 0.725724814368045, 0.8685687777112852], 
             UndirectedEdge[45, 64] -> 
             RGBColor[
              0.29706469909633587`, 0.42704903034983077`, 0.9403208603197443],
              UndirectedEdge[125, 170] -> 
             RGBColor[
              0.9076330531456096, 0.8428437212580413, 0.6273115578940806], 
             UndirectedEdge[70, 145] -> 
             RGBColor[
              0.5619497436733223, 0.655255143318286, 0.9586578887931527], 
             UndirectedEdge[17, 142] -> 
             RGBColor[
              0.31190501610321647`, 0.4426641020580474, 0.9411653735180701], 
             UndirectedEdge[95, 180] -> 
             RGBColor[
              0.5715707774486529, 0.35128740766933336`, 0.5604274089540877], 
             UndirectedEdge[41, 121] -> 
             RGBColor[
              0.31090558053815076`, 0.4437125201184723, 0.9410316065622488], 
             UndirectedEdge[5, 10] -> 
             RGBColor[
              0.7900310498594411, 0.6788863946524621, 0.6004765439498903], 
             UndirectedEdge[167, 194] -> 
             RGBColor[
              0.30638019785699266`, 0.4392824358115147, 0.9407619423493575], 
             UndirectedEdge[78, 100] -> 
             RGBColor[
              0.34386744809056646`, 0.47226243308074056`, 0.9431319076156538],
              UndirectedEdge[106, 157] -> 
             RGBColor[
              0.3881620128206551, 0.49471342185087663`, 0.9474747143386726], 
             UndirectedEdge[24, 115] -> 
             RGBColor[
              0.2879387604610827, 0.4153439765453465, 0.939878523058284], 
             UndirectedEdge[74, 164] -> 
             RGBColor[
              0.34005674158365296`, 0.46896179063613014`, 0.9428890927667087],
              UndirectedEdge[46, 135] -> 
             RGBColor[
              0.6384278325098356, 0.7014882353409241, 0.7024616497215617], 
             UndirectedEdge[126, 190] -> 
             RGBColor[
              0.5303398004040601, 0.6226696186433824, 0.9586105248066853], 
             UndirectedEdge[21, 177] -> 
             RGBColor[
              0.5820774885462776, 0.6485407866339752, 0.9308198844889263], 
             UndirectedEdge[24, 133] -> 
             RGBColor[
              0.27977678944992135`, 0.4082744874880696, 0.9393584494828005], 
             UndirectedEdge[30, 188] -> 
             RGBColor[
              0.34708542724672387`, 0.47363091944160773`, 0.943388902354831], 
             UndirectedEdge[80, 98] -> 
             RGBColor[
              0.9828518518072202, 0.9853818153002902, 0.8534690019457306], 
             UndirectedEdge[12, 102] -> 
             RGBColor[
              0.2978242528201228, 0.4231890761926991, 0.9405346787168244], 
             UndirectedEdge[51, 168] -> 
             RGBColor[
              0.6785737257771597, 0.7401962389848495, 0.8401838994672479], 
             UndirectedEdge[42, 189] -> 
             RGBColor[
              0.3605072778215646, 0.48667501725157114`, 0.9441921828520894], 
             UndirectedEdge[52, 187] -> 
             RGBColor[
              0.54674919486033, 0.6415168727343943, 0.958044160366209], 
             UndirectedEdge[10, 89] -> 
             RGBColor[
              0.5198156657037964, 0.6175752958848391, 0.9565874759046047], 
             UndirectedEdge[148, 193] -> 
             RGBColor[
              0.690011510003476, 0.7121784370768378, 0.6307092472163572], 
             UndirectedEdge[4, 92] -> 
             RGBColor[
              0.3095059697373863, 0.43404904688419765`, 0.9412518644566964], 
             UndirectedEdge[28, 97] -> 
             RGBColor[
              0.627049846842938, 0.7057806203500994, 0.9653729144723786], 
             UndirectedEdge[60, 169] -> 
             RGBColor[
              0.7316806031684281, 0.7877219052042936, 0.9248404923257008], 
             UndirectedEdge[44, 198] -> 
             RGBColor[
              0.24585227228067752`, 0.3757367044743365, 0.9373122952493167], 
             UndirectedEdge[13, 64] -> 
             RGBColor[
              0.3148059519594123, 0.4456962119693245, 0.9413311984244648], 
             UndirectedEdge[42, 106] -> 
             RGBColor[
              0.26472942591305315`, 0.3917144023168969, 0.9385287787642909], 
             UndirectedEdge[43, 90] -> 
             RGBColor[
              0.3204145953926898, 0.44924467007283353`, 0.9417365222237524], 
             UndirectedEdge[166, 192] -> 
             RGBColor[
              0.40850068014741947`, 0.5282444901276874, 0.9472502800093935], 
             UndirectedEdge[5, 89] -> 
             RGBColor[
              0.621533291612031, 0.5400267452800608, 0.5874957123435468], 
             UndirectedEdge[114, 184] -> 
             RGBColor[
              0.328864589466972, 0.45816405854965914`, 0.9422163488534885], 
             UndirectedEdge[58, 192] -> 
             RGBColor[
              0.40561598749898914`, 0.5257459143444853, 0.947066469944669], 
             UndirectedEdge[17, 157] -> 
             RGBColor[
              0.44272030966584797`, 0.552057651030988, 0.9505817286322391], 
             UndirectedEdge[38, 111] -> 
             RGBColor[
              0.2861266209830213, 0.41806759850169306`, 0.9396058598273556], 
             UndirectedEdge[3, 191] -> 
             RGBColor[
              0.28395137561777795`, 0.4157812777043003, 0.9394819828217922], 
             UndirectedEdge[40, 195] -> 
             RGBColor[
              0.6609979355012252, 0.6659430894425228, 0.6112718860992337], 
             UndirectedEdge[113, 136] -> 
             RGBColor[
              0.38840107880296454`, 0.5108352256784578, 0.9459695511851043], 
             UndirectedEdge[53, 141] -> 
             RGBColor[
              0.5077037158797907, 0.6109637306925575, 0.9544570831475121], 
             UndirectedEdge[142, 176] -> 
             RGBColor[
              0.3120570951517762, 0.44282394678045234`, 0.9411740341949046], 
             UndirectedEdge[99, 128] -> 
             RGBColor[
              0.3534244756575697, 0.48054025000910644`, 0.9437408729612755], 
             UndirectedEdge[41, 151] -> 
             RGBColor[
              0.6400912726807143, 0.6777214187888434, 0.6409122315066265], 
             UndirectedEdge[5, 157] -> 
             RGBColor[
              0.7445728507044929, 0.6426853438747185, 0.5964166045330888], 
             UndirectedEdge[39, 74] -> 
             RGBColor[
              0.5974069437057714, 0.6786243750346795, 0.9641582258540716], 
             UndirectedEdge[86, 171] -> 
             RGBColor[
              0.5398341352166218, 0.32484460490699985`, 0.5595477139029971], 
             UndirectedEdge[162, 180] -> 
             RGBColor[
              0.65218544253586, 0.7170121318332138, 0.8159349056847158], 
             UndirectedEdge[27, 127] -> 
             RGBColor[
              0.5433791622299984, 0.6357748007337434, 0.9590243026796063], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.32072799834288923`, 0.45222020473186325`, 0.9416574823391438],
              UndirectedEdge[155, 191] -> 
             RGBColor[
              0.40206265915126527`, 0.5206744247766613, 0.9472331386265335], 
             UndirectedEdge[46, 105] -> 
             RGBColor[
              0.6609508247187013, 0.7232858813131294, 0.7038129701054376], 
             UndirectedEdge[30, 168] -> 
             RGBColor[
              0.3815652691603849, 0.504914390943838, 0.9455339794393484], 
             UndirectedEdge[161, 180] -> 
             RGBColor[
              0.24554419633275684`, 0.3753498329944873, 0.9372970598663999], 
             UndirectedEdge[125, 192] -> 
             RGBColor[
              0.6513205008453161, 0.7237947301662111, 0.9682964467794888], 
             UndirectedEdge[33, 140] -> 
             RGBColor[
              0.5761898058152375, 0.6620595304471748, 0.9620182627405005], 
             UndirectedEdge[12, 58] -> 
             RGBColor[
              0.29935144736394426`, 0.42451185534752756`, 0.9406319902027116],
              UndirectedEdge[127, 155] -> 
             RGBColor[
              0.6214246121562912, 0.7020384372526737, 0.9643662673677056], 
             UndirectedEdge[78, 120] -> 
             RGBColor[
              0.3830131025386259, 0.506168431445849, 0.945626234101941], 
             UndirectedEdge[45, 183] -> 
             RGBColor[
              0.44955540621903184`, 0.5540346764774173, 0.9514449593888158], 
             UndirectedEdge[98, 136] -> 
             RGBColor[
              0.6647148093431758, 0.7287515266909655, 0.8598537862268996], 
             UndirectedEdge[59, 92] -> 
             RGBColor[
              0.35555051071219335`, 0.4823817147157925, 0.9438763420349772], 
             UndirectedEdge[81, 89] -> 
             RGBColor[
              0.44709981339575977`, 0.5592452543341373, 0.9503817141835185], 
             UndirectedEdge[161, 200] -> 
             RGBColor[
              0.27437933882192245`, 0.400325384122201, 0.9391344096478942], 
             UndirectedEdge[125, 198] -> 
             RGBColor[
              0.5525655735648849, 0.6304537504164076, 0.962289628380125], 
             UndirectedEdge[159, 173] -> 
             RGBColor[
              0.28468325565711505`, 0.41655053002951825`, 0.9395236623073129],
              UndirectedEdge[54, 151] -> 
             RGBColor[
              0.9255830054259611, 0.9102451689032277, 0.6646713175561678], 
             UndirectedEdge[61, 192] -> 
             RGBColor[
              0.5502787878137032, 0.6443686495422551, 0.9583559891219431], 
             UndirectedEdge[59, 194] -> 
             RGBColor[
              0.30632670256654304`, 0.4392361008796787, 0.9407585336767541], 
             UndirectedEdge[80, 82] -> 
             RGBColor[
              0.8466504789803032, 0.8803970745529928, 0.9513249385378617], 
             UndirectedEdge[157, 168] -> 
             RGBColor[
              0.47987877173232935`, 0.5861565221481595, 0.9528793491717962], 
             UndirectedEdge[122, 170] -> 
             RGBColor[
              0.6114976807807415, 0.5992447492896258, 0.6029366221665853], 
             UndirectedEdge[26, 67] -> 
             RGBColor[
              0.44770428804751716`, 0.5621403457338191, 0.9497649711187774], 
             UndirectedEdge[160, 181] -> 
             RGBColor[
              0.3784846734306062, 0.5022461337579471, 0.9453376866035107], 
             UndirectedEdge[42, 168] -> 
             RGBColor[
              0.3564461848247274, 0.4831575026141797, 0.9439334135974145], 
             UndirectedEdge[61, 67] -> 
             RGBColor[
              0.5592908058554599, 0.6521744066128277, 0.958930226942549], 
             UndirectedEdge[9, 39] -> 
             RGBColor[
              0.6457082959841797, 0.7204143593981116, 0.9672487158358042], 
             UndirectedEdge[118, 171] -> 
             RGBColor[
              0.28726418799371223`, 0.41723912683218933`, 0.9397447557805176],
              UndirectedEdge[97, 134] -> 
             RGBColor[
              0.5927415211728128, 0.678978695583665, 0.9619533811991124], 
             UndirectedEdge[79, 190] -> 
             RGBColor[
              0.3118183018662756, 0.4435991595041556, 0.9411228610759783], 
             UndirectedEdge[47, 50] -> 
             RGBColor[
              0.6976793383087514, 0.7620705939437212, 0.9719572217429397], 
             UndirectedEdge[36, 145] -> 
             RGBColor[
              0.7685975550758537, 0.817982667396995, 0.9380499992558908], 
             UndirectedEdge[170, 179] -> 
             RGBColor[
              0.6143239240174239, 0.6022153101255499, 0.6030975725378621], 
             UndirectedEdge[26, 198] -> 
             RGBColor[
              0.3399373427253293, 0.46099360891344315`, 0.9431839148988076], 
             UndirectedEdge[5, 141] -> 
             RGBColor[
              0.6678920534637159, 0.5801803747368701, 0.5904496516552927], 
             UndirectedEdge[18, 39] -> 
             RGBColor[
              0.6130030671604414, 0.6921329532871574, 0.9651519970494927], 
             UndirectedEdge[19, 180] -> 
             RGBColor[
              0.6397050948446348, 0.7097830360041425, 0.9383170607537169], 
             UndirectedEdge[170, 198] -> 
             RGBColor[
              0.5794019213408158, 0.56551007112958, 0.6011088161479026], 
             UndirectedEdge[12, 172] -> 
             RGBColor[
              0.3597160762239332, 0.4752544385618248, 0.9449044921416456], 
             UndirectedEdge[47, 101] -> 
             RGBColor[
              0.9522507093840517, 0.9605270374913202, 0.7900640435558817], 
             UndirectedEdge[53, 54] -> 
             RGBColor[
              0.7258917793675017, 0.7851924252768399, 0.9739276389062612], 
             UndirectedEdge[57, 121] -> 
             RGBColor[
              0.2885078898893101, 0.42023419127637396`, 0.9397537821276517], 
             UndirectedEdge[19, 121] -> 
             RGBColor[
              0.6411825827381009, 0.711062761756762, 0.9384112049757973], 
             UndirectedEdge[170, 192] -> 
             RGBColor[
              0.6781568486212471, 0.6588510508793834, 0.6071156345472664], 
             UndirectedEdge[7, 137] -> 
             RGBColor[
              0.35388468253692357`, 0.47343946962955, 0.9441796979842174], 
             UndirectedEdge[111, 115] -> 
             RGBColor[
              0.3324585154205397, 0.46213706172323255`, 0.9424138572421498], 
             UndirectedEdge[140, 162] -> 
             RGBColor[
              0.8927713010103084, 0.9139666582134811, 0.8353478037702116], 
             UndirectedEdge[8, 79] -> 
             RGBColor[
              0.6595401042348998, 0.72304522338912, 0.7875880715446362], 
             UndirectedEdge[2, 52] -> 
             RGBColor[
              0.4161242781299371, 0.5348476675269682, 0.9477360489315565], 
             UndirectedEdge[18, 152] -> 
             RGBColor[
              0.4515972779893487, 0.563936212356035, 0.950448495090003], 
             UndirectedEdge[4, 195] -> 
             RGBColor[
              0.29534734229126275`, 0.4217855554236726, 0.9403496892358121], 
             UndirectedEdge[81, 107] -> 
             RGBColor[
              0.48340162383168334`, 0.5906880579516898, 0.952694833444065], 
             UndirectedEdge[108, 175] -> 
             RGBColor[
              0.2864725483988072, 0.41843119014874897`, 0.9396255598819309], 
             UndirectedEdge[49, 191] -> 
             RGBColor[
              0.35031772868125055`, 0.4771909763082152, 0.943567019781552], 
             UndirectedEdge[77, 192] -> 
             RGBColor[
              0.5894482948721645, 0.6749681661556046, 0.9622600395256756], 
             UndirectedEdge[21, 166] -> 
             RGBColor[
              0.2922570792750743, 0.4165218055868328, 0.9402475075211443], 
             UndirectedEdge[8, 192] -> 
             RGBColor[
              0.7081286479072955, 0.7651301777869359, 0.7906840905822791], 
             UndirectedEdge[108, 165] -> 
             RGBColor[
              0.34838740794126166`, 0.4730928781227283, 0.9435328547377794], 
             UndirectedEdge[29, 194] -> 
             RGBColor[
              0.32431746730146416`, 0.45481879705093975`, 0.9419048892970546],
              UndirectedEdge[106, 131] -> 
             RGBColor[
              0.29929242706417647`, 0.4216511367270511, 0.9407311026347784], 
             UndirectedEdge[12, 68] -> 
             RGBColor[
              0.3046620910539406, 0.42911166799108946`, 0.9409703797226203], 
             UndirectedEdge[71, 168] -> 
             RGBColor[
              0.33360891868497783`, 0.46301747544073424`, 0.9424914075336068],
              UndirectedEdge[49, 146] -> 
             RGBColor[
              0.6947403236355807, 0.749770459370299, 0.6820626466746268], 
             UndirectedEdge[112, 134] -> 
             RGBColor[
              0.6356818006246531, 0.7138395488802136, 0.9653337972929878], 
             UndirectedEdge[84, 126] -> 
             RGBColor[
              0.8650945819503355, 0.8948926540809297, 0.957562447281403], 
             UndirectedEdge[10, 62] -> 
             RGBColor[
              0.48219949538404205`, 0.5819743795953558, 0.9543011720789751], 
             UndirectedEdge[34, 182] -> 
             RGBColor[
              0.3610470603821736, 0.48714254977531024`, 0.9442265773195404], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.3014242641641167, 0.42349762687377124`, 0.9408669414096771], 
             UndirectedEdge[67, 79] -> 
             RGBColor[
              0.38226777069031465`, 0.5055228624603096, 0.9455787422156378], 
             UndirectedEdge[33, 96] -> 
             RGBColor[
              0.2744929342715057, 0.4009365187945134, 0.9391228737797916], 
             UndirectedEdge[12, 140] -> 
             RGBColor[
              0.4999575128222228, 0.5868378944600127, 0.9574974112299598], 
             UndirectedEdge[26, 124] -> 
             RGBColor[
              0.3628150754543096, 0.4850395565436353, 0.9444867679331505], 
             UndirectedEdge[13, 70] -> 
             RGBColor[
              0.43044360811088317`, 0.5427628911074439, 0.9495540903239077], 
             UndirectedEdge[53, 146] -> 
             RGBColor[
              0.7809212006278781, 0.8212105605472462, 0.6884396893728709], 
             UndirectedEdge[87, 147] -> 
             RGBColor[
              0.5032171784709925, 0.5937820517080492, 0.9571260866939247], 
             UndirectedEdge[93, 200] -> 
             RGBColor[
              0.3989559484893121, 0.5199773232975967, 0.9466420981482137], 
             UndirectedEdge[9, 117] -> 
             RGBColor[
              0.6505069210242193, 0.7242406527498324, 0.9677064129759063], 
             UndirectedEdge[99, 116] -> 
             RGBColor[
              0.25421013906042966`, 0.38435863040562085`, 0.9377942214466344],
              UndirectedEdge[71, 155] -> 
             RGBColor[
              0.4036787135509335, 0.5223730004144795, 0.9473251705338563], 
             UndirectedEdge[54, 140] -> 
             RGBColor[
              0.83550568386438, 0.8719110708605045, 0.9841094464752056], 
             UndirectedEdge[76, 154] -> 
             RGBColor[
              0.22917317479734894`, 0.35820591550349845`, 0.9363624453221546],
              UndirectedEdge[33, 128] -> 
             RGBColor[
              0.3790613877715347, 0.5027456547335538, 0.9453744343313462], 
             UndirectedEdge[109, 148] -> 
             RGBColor[
              0.7035280824874875, 0.7627167350890997, 0.8750847528376001], 
             UndirectedEdge[27, 142] -> 
             RGBColor[
              0.3410878231093606, 0.46985486163003376`, 0.9429547923697772], 
             UndirectedEdge[49, 69] -> 
             RGBColor[
              0.3581360857487042, 0.48462120985763835`, 0.9440410925899694], 
             UndirectedEdge[60, 90] -> 
             RGBColor[
              0.6322690064151663, 0.6995914196050608, 0.9184174942857998], 
             UndirectedEdge[40, 191] -> 
             RGBColor[
              0.6251327039311332, 0.6342200628758149, 0.6090106912483852], 
             UndirectedEdge[58, 166] -> 
             RGBColor[
              0.392272371325455, 0.5141883446846195, 0.9462162265213879], 
             UndirectedEdge[38, 60] -> 
             RGBColor[
              0.6255900830808414, 0.6925714477124876, 0.9180371394824915], 
             UndirectedEdge[54, 119] -> 
             RGBColor[
              0.5901857660375145, 0.6700438120695889, 0.9644246416264433], 
             UndirectedEdge[3, 146] -> 
             RGBColor[
              0.6283739705721081, 0.688360760766384, 0.677977609714867], 
             UndirectedEdge[115, 163] -> 
             RGBColor[
              0.33803345629152176`, 0.46720932260936177`, 0.942760170817015], 
             UndirectedEdge[137, 170] -> 
             RGBColor[
              0.7042586178433111, 0.6808962278509605, 0.608934337095226], 
             UndirectedEdge[58, 99] -> 
             RGBColor[
              0.34994682824299395`, 0.47752808661024226`, 0.9435192803431817],
              UndirectedEdge[40, 64] -> 
             RGBColor[
              0.6422950233340402, 0.6497435669590054, 0.6100801530742764], 
             UndirectedEdge[77, 96] -> 
             RGBColor[
              0.4721291799647468, 0.5621150481723605, 0.9551960181042094], 
             UndirectedEdge[141, 195] -> 
             RGBColor[
              0.40869555252360557`, 0.5284132787853693, 0.9472626971048852], 
             UndirectedEdge[138, 182] -> 
             RGBColor[
              0.33006248722326076`, 0.4600483971730731, 0.9422616730829112], 
             UndirectedEdge[33, 102] -> 
             RGBColor[
              0.3740565458131375, 0.4984107121798612, 0.9450555302273651], 
             UndirectedEdge[137, 198] -> 
             RGBColor[
              0.3491911382625863, 0.4685062570093267, 0.9439124075812705], 
             UndirectedEdge[69, 171] -> 
             RGBColor[
              0.28057581652106406`, 0.41144599562990625`, 0.9393185786645752],
              UndirectedEdge[20, 46] -> 
             RGBColor[
              0.6438833464504825, 0.707222326392106, 0.702772333169772], 
             UndirectedEdge[76, 157] -> 
             RGBColor[
              0.4212657544004018, 0.5295075531496333, 0.9493599234490421], 
             UndirectedEdge[10, 168] -> 
             RGBColor[
              0.5253369708872775, 0.622357572925903, 0.9569392885885977], 
             UndirectedEdge[82, 100] -> 
             RGBColor[
              0.5399598977219305, 0.6336811353241527, 0.958439081205348], 
             UndirectedEdge[9, 57] -> 
             RGBColor[
              0.3598264660357595, 0.48196053807499384`, 0.944310909260924], 
             UndirectedEdge[27, 71] -> 
             RGBColor[
              0.3256332636246406, 0.4561093638955492, 0.9419832058457569], 
             UndirectedEdge[122, 125] -> 
             RGBColor[
              0.5846613330048106, 0.6641884285764534, 0.9641174343988077], 
             UndirectedEdge[5, 147] -> 
             RGBColor[
              0.8281374951570646, 0.7086554393386766, 0.6042746382921795], 
             UndirectedEdge[5, 71] -> 
             RGBColor[
              0.5983029976571413, 0.5195462971672933, 0.5860286628948994], 
             UndirectedEdge[61, 84] -> 
             RGBColor[
              0.8235961185776961, 0.8624737390942208, 0.9534262682776073], 
             UndirectedEdge[62, 149] -> 
             RGBColor[
              0.3546927002559762, 0.4786190422112193, 0.9439322483957109], 
             UndirectedEdge[36, 138] -> 
             RGBColor[
              0.6432442431741332, 0.7119574229651198, 0.9292965949918368], 
             UndirectedEdge[33, 162] -> 
             RGBColor[
              0.6783612972319641, 0.7396843415342684, 0.8176028079995521], 
             UndirectedEdge[63, 145] -> 
             RGBColor[
              0.7756020663872316, 0.82084022851059, 0.8021120266955974], 
             UndirectedEdge[93, 173] -> 
             RGBColor[
              0.36701941592200477`, 0.49180507868370904`, 0.944625819703305], 
             UndirectedEdge[23, 55] -> 
             RGBColor[
              0.23331559412955297`, 0.3625598608662002, 0.9365983499749635], 
             UndirectedEdge[23, 165] -> 
             RGBColor[
              0.3001587573465107, 0.422401508474583, 0.940786304434303], 
             UndirectedEdge[54, 64] -> 
             RGBColor[
              0.6081807038441316, 0.6864424508861344, 0.9655415198386771], 
             UndirectedEdge[72, 158] -> 
             RGBColor[
              0.26887893349051806`, 0.3992663771594628, 0.9386482643451302], 
             UndirectedEdge[73, 149] -> 
             RGBColor[
              0.3410037930913523, 0.46423113285435624`, 0.943152685383609], 
             UndirectedEdge[10, 197] -> 
             RGBColor[
              0.6603236205859264, 0.7344155251238118, 0.9668835441995514], 
             UndirectedEdge[37, 135] -> 
             RGBColor[
              0.5195605785214127, 0.6122269394142161, 0.9578562442676151], 
             UndirectedEdge[58, 96] -> 
             RGBColor[
              0.28829687259157144`, 0.4128927963612411, 0.9400024485232028], 
             UndirectedEdge[112, 156] -> 
             RGBColor[
              0.6815591249599124, 0.3881352224588723, 0.5608022313818347], 
             UndirectedEdge[2, 187] -> 
             RGBColor[
              0.5432526188553336, 0.6384883143418862, 0.9578213616350714], 
             UndirectedEdge[43, 169] -> 
             RGBColor[
              0.4198261921459516, 0.5373751556720664, 0.9481595202636532], 
             UndirectedEdge[44, 96] -> 
             RGBColor[
              0.2272880846536911, 0.35622456624089577`, 0.9362550922272144], 
             UndirectedEdge[88, 161] -> 
             RGBColor[
              0.25684410203096136`, 0.3851372433604978, 0.9380170798653752], 
             UndirectedEdge[129, 146] -> 
             RGBColor[
              0.9367025563541116, 0.9445043770871866, 0.7030880152423911], 
             UndirectedEdge[23, 111] -> 
             RGBColor[
              0.24251952157010692`, 0.3722337721689271, 0.9371225000267126], 
             UndirectedEdge[174, 196] -> 
             RGBColor[
              0.48580609581439227`, 0.5799811190722755, 0.9554222588740701], 
             UndirectedEdge[66, 100] -> 
             RGBColor[
              0.6649099646352191, 0.7316243749152145, 0.940071190092447], 
             UndirectedEdge[10, 73] -> 
             RGBColor[
              0.4685105882194181, 0.5675864702384927, 0.9535216090668732], 
             UndirectedEdge[147, 188] -> 
             RGBColor[
              0.5289635742712401, 0.6208431461098871, 0.9585923058463695], 
             UndirectedEdge[62, 189] -> 
             RGBColor[
              0.3232841353169502, 0.4514145219014098, 0.9419309224112996], 
             UndirectedEdge[42, 89] -> 
             RGBColor[
              0.3509248796412463, 0.47837522557311585`, 0.9435816009134215], 
             UndirectedEdge[119, 140] -> 
             RGBColor[
              0.5452798917667163, 0.6344745883354719, 0.9600784536623976], 
             UndirectedEdge[140, 151] -> 
             RGBColor[
              0.8806771311551629, 0.8746759451691107, 0.6603251295921222], 
             UndirectedEdge[1, 86] -> 
             RGBColor[
              0.7552686192365228, 0.5109305789791029, 0.5750560973057011], 
             UndirectedEdge[76, 181] -> 
             RGBColor[
              0.28558834674027345`, 0.415902685322401, 0.9396337587239791], 
             UndirectedEdge[122, 166] -> 
             RGBColor[
              0.34184151230691395`, 0.46863818853792977`, 0.9430712676287123],
              UndirectedEdge[10, 189] -> 
             RGBColor[
              0.5293980638841147, 0.6258750875632944, 0.9571980578432726], 
             UndirectedEdge[102, 162] -> 
             RGBColor[
              0.6906380410082085, 0.7503178399461676, 0.8183850712570762], 
             UndirectedEdge[156, 183] -> 
             RGBColor[
              0.7291251318992384, 0.42675144971641027`, 0.564546801688123], 
             UndirectedEdge[31, 199] -> 
             RGBColor[
              0.6001032394420882, 0.6638066394748003, 0.8650301546969833], 
             UndirectedEdge[73, 130] -> 
             RGBColor[
              0.3211750618783241, 0.44705648249864005`, 0.9418892161645733], 
             UndirectedEdge[4, 199] -> 
             RGBColor[
              0.6042892285764333, 0.6682063794620372, 0.8652685405855682], 
             UndirectedEdge[6, 83] -> 
             RGBColor[
              0.5303188337756529, 0.6204000693766514, 0.9589651449220067], 
             UndirectedEdge[73, 89] -> 
             RGBColor[
              0.300012829972008, 0.4287268208660915, 0.9405407774605298], 
             UndirectedEdge[60, 111] -> 
             RGBColor[
              0.6455755052380339, 0.7135773935486488, 0.9191752797085612], 
             UndirectedEdge[166, 179] -> 
             RGBColor[
              0.3446677555435962, 0.4716087493738538, 0.9432322179999892], 
             UndirectedEdge[30, 197] -> 
             RGBColor[
              0.5165519188590337, 0.6169723431417469, 0.9554782350503022], 
             UndirectedEdge[26, 58] -> 
             RGBColor[
              0.4224639611837961, 0.5402784432201787, 0.9481566798101659], 
             UndirectedEdge[11, 35] -> 
             RGBColor[
              0.571648040921519, 0.4353226640226543, 0.5719881336336907], 
             UndirectedEdge[137, 187] -> 
             RGBColor[
              0.573962685175404, 0.6645249666400097, 0.959933700799159], 
             UndirectedEdge[13, 153] -> 
             RGBColor[
              0.297723737211677, 0.43025690295764796`, 0.9402662984401815], 
             UndirectedEdge[71, 75] -> 
             RGBColor[
              0.34492714200823626`, 0.4728207516128958, 0.9432125947154529], 
             UndirectedEdge[16, 67] -> 
             RGBColor[
              0.4815670052515768, 0.5896316250581003, 0.9524307682603014], 
             UndirectedEdge[156, 170] -> 
             RGBColor[
              0.8758942004607704, 0.4560135209856069, 0.21517437283092905`], 
             UndirectedEdge[96, 128] -> 
             RGBColor[
              0.2917745200061472, 0.4159049597601053, 0.9402240411412968], 
             UndirectedEdge[62, 114] -> 
             RGBColor[
              0.3185028471695468, 0.44727321042265866`, 0.9416262629584742], 
             UndirectedEdge[101, 105] -> 
             RGBColor[
              0.661517524081524, 0.7244979939481128, 0.7654946984856268], 
             UndirectedEdge[30, 89] -> 
             RGBColor[
              0.3760439639769038, 0.5001321139027742, 0.9451821667553554], 
             UndirectedEdge[53, 191] -> 
             RGBColor[
              0.43649860567354787`, 0.5486310774851624, 0.949944062479796], 
             UndirectedEdge[72, 81] -> 
             RGBColor[
              0.38230829396652, 0.4950813231139347, 0.9465478144284301], 
             UndirectedEdge[163, 175] -> 
             RGBColor[
              0.30741136024514515`, 0.43965185355565994`, 0.9408468231800324],
              UndirectedEdge[82, 125] -> 
             RGBColor[
              0.800355018414747, 0.8444542168580133, 0.980605130549892], 
             UndirectedEdge[113, 148] -> 
             RGBColor[
              0.4279812180036696, 0.5451175528984693, 0.9484915626556305], 
             UndirectedEdge[33, 44] -> 
             RGBColor[
              0.3145749524190786, 0.44306526121434436`, 0.9414054854172638], 
             UndirectedEdge[21, 179] -> 
             RGBColor[
              0.24176777084478515`, 0.371443634492865, 0.937079688935021], 
             UndirectedEdge[75, 188] -> 
             RGBColor[
              0.3391988992329459, 0.4668000052644967, 0.9428863797635759], 
             UndirectedEdge[85, 88] -> 
             RGBColor[
              0.35150222260898034`, 0.4788752910336657, 0.943618388696801], 
             UndirectedEdge[13, 185] -> 
             RGBColor[
              0.6322082535412419, 0.6694989299864178, 0.6404609961419556], 
             UndirectedEdge[93, 161] -> 
             RGBColor[
              0.3062369096882186, 0.4279188107985177, 0.9411643458929507], 
             UndirectedEdge[146, 196] -> 
             RGBColor[
              0.8608256786876736, 0.8847199763982576, 0.6956603389649418], 
             UndirectedEdge[19, 162] -> 
             RGBColor[
              0.9824624447358101, 0.9843623734715035, 0.8133145040982642], 
             UndirectedEdge[140, 172] -> 
             RGBColor[
              0.6503583729952922, 0.7247583912281996, 0.9671703394228457], 
             UndirectedEdge[71, 142] -> 
             RGBColor[
              0.3203118790313271, 0.45150024802138744`, 0.9416441319249866], 
             UndirectedEdge[87, 142] -> 
             RGBColor[
              0.28883724045578907`, 0.41841840727115054`, 0.9398516978206649],
              UndirectedEdge[89, 147] -> 
             RGBColor[
              0.5579221110014201, 0.6473443405710535, 0.960385570246894], 
             UndirectedEdge[30, 42] -> 
             RGBColor[
              0.37565093616176376`, 0.49979169296345227`, 0.9451571233705156],
              UndirectedEdge[8, 125] -> 
             RGBColor[
              0.937604852431658, 0.9491228481655938, 0.8108800139290933], 
             UndirectedEdge[29, 168] -> 
             RGBColor[
              0.35388506996893776`, 0.4809391936514702, 0.9437702216235084], 
             UndirectedEdge[158, 160] -> 
             RGBColor[
              0.3734750674616441, 0.4979070648577493, 0.945018478940989], 
             UndirectedEdge[138, 153] -> 
             RGBColor[
              0.30387656087239556`, 0.436723910736615, 0.9406166926453725], 
             UndirectedEdge[26, 122] -> 
             RGBColor[
              0.372033102165255, 0.494728287073489, 0.9450117209174903], 
             UndirectedEdge[53, 195] -> 
             RGBColor[
              0.47236383724363995`, 0.5803541040518703, 0.9522052573306443], 
             UndirectedEdge[19, 93] -> 
             RGBColor[
              0.7003978082000966, 0.7623520138081727, 0.9421843467802677], 
             UndirectedEdge[11, 196] -> 
             RGBColor[
              0.5074708767072349, 0.6027521774170985, 0.9566560360957462], 
             UndirectedEdge[87, 168] -> 
             RGBColor[
              0.3021342801094398, 0.4299356346904973, 0.940698973429285], 
             UndirectedEdge[78, 124] -> 
             RGBColor[
              0.2989091697075693, 0.4297478121163319, 0.9403980682483626], 
             UndirectedEdge[39, 117] -> 
             RGBColor[
              0.8411949962838832, 0.8762100726796123, 0.9847151237608367], 
             UndirectedEdge[42, 130] -> 
             RGBColor[
              0.3720871115475624, 0.4967048872056644, 0.9449300396174649], 
             UndirectedEdge[11, 94] -> 
             RGBColor[
              0.3863433919390252, 0.5057760676449072, 0.9461901604107398], 
             UndirectedEdge[27, 168] -> 
             RGBColor[
              0.3543848627630113, 0.4813720890493805, 0.9438020679783974], 
             UndirectedEdge[30, 51] -> 
             RGBColor[
              0.697778477114196, 0.7568304293341221, 0.8414076092403491], 
             UndirectedEdge[6, 58] -> 
             RGBColor[
              0.5838775088904973, 0.6692377585555505, 0.9622882283141774], 
             UndirectedEdge[6, 156] -> 
             RGBColor[
              0.797843169551985, 0.48045637410484177`, 0.5713810200858457], 
             UndirectedEdge[19, 173] -> 
             RGBColor[
              0.6366037047664932, 0.7065863425179684, 0.9381381320903025], 
             UndirectedEdge[57, 200] -> 
             RGBColor[
              0.31586554448500964`, 0.44393001665146803`, 0.9414969876870656],
              UndirectedEdge[37, 50] -> 
             RGBColor[
              0.6199991560357196, 0.7006546627765344, 0.9644089266072209], 
             UndirectedEdge[49, 171] -> 
             RGBColor[
              0.32144997738759035`, 0.446849139377432, 0.941923044051389], 
             UndirectedEdge[5, 127] -> 
             RGBColor[
              0.8160488962624991, 0.6992117340054875, 0.6030697597287488], 
             UndirectedEdge[85, 152] -> 
             RGBColor[
              0.4422806670392625, 0.5558666322175521, 0.949854848878619], 
             UndirectedEdge[130, 131] -> 
             RGBColor[
              0.4066501126986858, 0.5266416216158186, 0.9471323634879527], 
             UndirectedEdge[33, 58] -> 
             RGBColor[
              0.37558374035695896`, 0.4997334913346897, 0.9451528417132522], 
             UndirectedEdge[82, 98] -> 
             RGBColor[
              0.8561147042867321, 0.886105773918455, 0.8748619543813498], 
             UndirectedEdge[74, 173] -> 
             RGBColor[
              0.3308214143280503, 0.4604521890674862, 0.9423193150503741], 
             UndirectedEdge[118, 146] -> 
             RGBColor[
              0.6605545342417026, 0.7201604468250563, 0.6798843584037555], 
             UndirectedEdge[23, 115] -> 
             RGBColor[
              0.2688659938504328, 0.39529728955430543`, 0.9387923572154372], 
             UndirectedEdge[49, 65] -> 
             RGBColor[
              0.3374249808266998, 0.4636398808656549, 0.9428327968643465], 
             UndirectedEdge[21, 23] -> 
             RGBColor[
              0.18414204728813163`, 0.31087534535292205`, 0.9337979892280881],
              UndirectedEdge[40, 171] -> 
             RGBColor[
              0.5962649526374729, 0.6038782259450317, 0.6073667155182223], 
             UndirectedEdge[104, 158] -> 
             RGBColor[
              0.30962415543576527`, 0.44209218882019885`, 0.9409686444577579],
              UndirectedEdge[53, 155] -> 
             RGBColor[
              0.5369360540775425, 0.6349479032505573, 0.9566887195200088], 
             UndirectedEdge[164, 200] -> 
             RGBColor[
              0.3443971723113114, 0.4727212535760363, 0.9431656611745829], 
             UndirectedEdge[81, 142] -> 
             RGBColor[
              0.4393240789255901, 0.5525103039558544, 0.9498862512588914], 
             UndirectedEdge[39, 85] -> 
             RGBColor[
              0.6036864562103552, 0.6840633731486746, 0.9645583508381088], 
             UndirectedEdge[107, 142] -> 
             RGBColor[
              0.3798439834221403, 0.5034234997517073, 0.9454243006341806], 
             UndirectedEdge[121, 161] -> 
             RGBColor[
              0.2470216842262229, 0.3766295587471069, 0.9373912040884802], 
             UndirectedEdge[1, 196] -> 
             RGBColor[
              0.7029698164595841, 0.7678846304774937, 0.971029119744408], 
             UndirectedEdge[88, 121] -> 
             RGBColor[
              0.3222054862363553, 0.4534999304844828, 0.9417516265612242], 
             UndirectedEdge[85, 133] -> 
             RGBColor[
              0.3567287934277049, 0.4834022839817574, 0.9439514211676951], 
             UndirectedEdge[118, 127] -> 
             RGBColor[
              0.5354938922923984, 0.6289449762389849, 0.9585218602518528], 
             UndirectedEdge[100, 187] -> 
             RGBColor[
              0.5169419997848863, 0.6156993785132301, 0.9561448722534693], 
             UndirectedEdge[26, 116] -> 
             RGBColor[
              0.32672727200123186`, 0.4471089870155573, 0.9424316209136185], 
             UndirectedEdge[131, 147] -> 
             RGBColor[
              0.5920920843374033, 0.6769406540418859, 0.9625628507325418], 
             UndirectedEdge[134, 160] -> 
             RGBColor[
              0.5782457439348202, 0.6666024061556441, 0.9609802029010541], 
             UndirectedEdge[3, 5] -> 
             RGBColor[
              0.5790131081279803, 0.499271400222509, 0.584930132223048], 
             UndirectedEdge[16, 100] -> 
             RGBColor[
              0.4416360710413664, 0.5550454568323251, 0.9498864044419655], 
             UndirectedEdge[75, 147] -> 
             RGBColor[
              0.5747616395081595, 0.661929893784279, 0.961458570112733], 
             UndirectedEdge[72, 76] -> 
             RGBColor[
              0.2334346758787002, 0.3626850233347729, 0.9366051315044117], 
             UndirectedEdge[40, 69] -> 
             RGBColor[
              0.6329510609985868, 0.641650296425238, 0.6094847640568029], 
             UndirectedEdge[177, 179] -> 
             RGBColor[
              0.6344881648147995, 0.7036277304209961, 0.9338045949677714], 
             UndirectedEdge[98, 100] -> 
             RGBColor[
              0.6761612705488476, 0.7386658760714502, 0.8605831446132168], 
             UndirectedEdge[136, 187] -> 
             RGBColor[
              0.5054955385792146, 0.6057850291327455, 0.9554155138671522], 
             UndirectedEdge[54, 199] -> 
             RGBColor[
              0.935825502296487, 0.9490627974080164, 0.8916521042133905], 
             UndirectedEdge[166, 198] -> 
             RGBColor[
              0.3097457528669882, 0.43490351037788394`, 0.9412434616100296], 
             UndirectedEdge[48, 104] -> 
             RGBColor[
              0.33082831737856416`, 0.4604581681428839, 0.9423197549066489], 
             UndirectedEdge[187, 198] -> 
             RGBColor[
              0.4491059886729088, 0.5491388099186293, 0.9521081798518354], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.3107475944657022, 0.44055600032092307`, 0.9411321051138859], 
             UndirectedEdge[103, 117] -> 
             RGBColor[
              0.6520141643614825, 0.7254643007915613, 0.96782506869263], 
             UndirectedEdge[85, 140] -> 
             RGBColor[
              0.5807881753852243, 0.6660424070479226, 0.9623112667833215], 
             UndirectedEdge[36, 70] -> 
             RGBColor[
              0.773872973258558, 0.8222654895325952, 0.9384652994997268], 
             UndirectedEdge[54, 171] -> 
             RGBColor[
              0.5621506331475643, 0.6405771098721607, 0.962828082282623], 
             UndirectedEdge[120, 125] -> 
             RGBColor[
              0.6595472391249217, 0.7309203173761167, 0.9688206472680463], 
             UndirectedEdge[81, 104] -> 
             RGBColor[
              0.42305351591176726`, 0.5379071347746708, 0.9488681945410578], 
             UndirectedEdge[93, 162] -> 
             RGBColor[
              0.7128781558913218, 0.769581109637244, 0.8198021917112667], 
             UndirectedEdge[73, 168] -> 
             RGBColor[
              0.3055341351554891, 0.4335090979071553, 0.9408925901445228], 
             UndirectedEdge[119, 199] -> 
             RGBColor[
              0.6455997101988233, 0.7116263148829838, 0.8676211114005825], 
             UndirectedEdge[17, 107] -> 
             RGBColor[
              0.3559825610093097, 0.4808418560538827, 0.9439739557032436], 
             UndirectedEdge[14, 48] -> 
             RGBColor[
              0.3712854760491613, 0.496010550828321, 0.9448789601123653], 
             UndirectedEdge[64, 182] -> 
             RGBColor[
              0.3450535611562147, 0.473289784602429, 0.9432074856913584], 
             UndirectedEdge[71, 129] -> 
             RGBColor[
              0.5938960157994495, 0.6736234696629212, 0.9646844202566391], 
             UndirectedEdge[80, 100] -> 
             RGBColor[
              0.6666970452424186, 0.7329571767059879, 0.9370461287697287], 
             UndirectedEdge[18, 178] -> 
             RGBColor[
              0.6547022927285477, 0.7253827838598407, 0.9691293064095168], 
             UndirectedEdge[174, 186] -> 
             RGBColor[
              0.6173812326295667, 0.6809813413997159, 0.8403066444040519], 
             UndirectedEdge[115, 165] -> 
             RGBColor[
              0.3900977511969435, 0.5123047980288884, 0.9460776616497402], 
             UndirectedEdge[113, 198] -> 
             RGBColor[
              0.3320115288966588, 0.45418900646434174`, 0.9426622171697876], 
             UndirectedEdge[67, 100] -> 
             RGBColor[
              0.39993739819425644`, 0.520827405702923, 0.9467046352555508], 
             UndirectedEdge[106, 147] -> 
             RGBColor[
              0.4717266572732269, 0.5606835173148346, 0.9553327480977634], 
             UndirectedEdge[75, 129] -> 
             RGBColor[
              0.6339658382610787, 0.708689470988914, 0.9672244695711256], 
             UndirectedEdge[175, 183] -> 
             RGBColor[
              0.4692460297032946, 0.5747307702170139, 0.9525663112665775], 
             UndirectedEdge[105, 144] -> 
             RGBColor[
              0.2687008268236007, 0.3978765371014805, 0.9386821559264908], 
             UndirectedEdge[44, 128] -> 
             RGBColor[
              0.3318565381537201, 0.4580337021799362, 0.9425066527787689], 
             UndirectedEdge[70, 138] -> 
             RGBColor[
              0.43659643177160173`, 0.5492298988864109, 0.9499044845290987], 
             UndirectedEdge[110, 145] -> 
             RGBColor[
              0.4289000102680846, 0.5424024487601602, 0.9493513117276959], 
             UndirectedEdge[49, 118] -> 
             RGBColor[
              0.36482445722135237`, 0.49041434105992143`, 0.9444672697059119],
              UndirectedEdge[70, 185] -> 
             RGBColor[
              0.7689898072863852, 0.7862740043328601, 0.6499800948550365], 
             UndirectedEdge[11, 138] -> 
             RGBColor[
              0.2948642491911153, 0.42725139974602555`, 0.9401034548276439], 
             UndirectedEdge[120, 187] -> 
             RGBColor[
              0.5560876542329457, 0.6496053768783385, 0.9586391987397567], 
             UndirectedEdge[71, 127] -> 
             RGBColor[
              0.5226032181519649, 0.617420187125097, 0.9577136422348158], 
             UndirectedEdge[4, 182] -> 
             RGBColor[
              0.28574814172720764`, 0.41347121036493684`, 0.9397380366641103],
              UndirectedEdge[29, 71] -> 
             RGBColor[
              0.32513347083056704`, 0.4556764684976389, 0.941951359490868], 
             UndirectedEdge[63, 185] -> 
             RGBColor[
              0.9826421300002944, 0.951859089525164, 0.4934342327574813], 
             UndirectedEdge[83, 175] -> 
             RGBColor[
              0.2899155620277242, 0.42205001577241325`, 0.9398216344146155], 
             UndirectedEdge[79, 126] -> 
             RGBColor[
              0.543188707513947, 0.6347026101311481, 0.9593961490880958], 
             UndirectedEdge[107, 154] -> 
             RGBColor[
              0.31856669738171894`, 0.4415154110785131, 0.9418431776214622], 
             UndirectedEdge[34, 64] -> 
             RGBColor[
              0.35194334877904365`, 0.4792573723505287, 0.943646496866285], 
             UndirectedEdge[159, 180] -> 
             RGBColor[
              0.28778464573525675`, 0.41974722351569227`, 0.9397025909707273],
              UndirectedEdge[3, 123] -> 
             RGBColor[
              0.30959179179607477`, 0.43864808309279946`, 0.9410916614773245],
              UndirectedEdge[50, 97] -> 
             RGBColor[
              0.4723902146639045, 0.582546683057637, 0.9516074346021668], 
             UndirectedEdge[87, 89] -> 
             RGBColor[
              0.29661297492595873`, 0.4251533576494334, 0.940347160745292], 
             UndirectedEdge[123, 191] -> 
             RGBColor[
              0.32726562692556754`, 0.4572244043997655, 0.942098160241853], 
             UndirectedEdge[108, 151] -> 
             RGBColor[
              0.6230693769531228, 0.6598933912540623, 0.6399405506400185], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.5985716068422067, 0.6845035978684073, 0.96187100525822], 
             UndirectedEdge[19, 33] -> 
             RGBColor[
              0.6658809495407391, 0.7324552457051972, 0.9399849630685532], 
             UndirectedEdge[156, 199] -> 
             RGBColor[
              0.9042792232288979, 0.5623861501107057, 0.47953328699376485`], 
             UndirectedEdge[47, 144] -> 
             RGBColor[
              0.5594340121261283, 0.6339055806446879, 0.9632515009967457], 
             UndirectedEdge[123, 127] -> 
             RGBColor[
              0.5466275799305935, 0.6385884168757779, 0.9592312889830252], 
             UndirectedEdge[82, 120] -> 
             RGBColor[
              0.57910555216999, 0.6675871336892611, 0.9609334076916353], 
             UndirectedEdge[120, 137] -> 
             RGBColor[
              0.4561728038226232, 0.5689728239690359, 0.9504434264691918], 
             UndirectedEdge[122, 179] -> 
             RGBColor[
              0.29135220387662475`, 0.423560017443962, 0.9399034490425893], 
             UndirectedEdge[52, 124] -> 
             RGBColor[
              0.34485538067649263`, 0.46954411073390334`, 0.9433257201826634],
              UndirectedEdge[17, 106] -> 
             RGBColor[
              0.23348529684519292`, 0.36273822918011145`, 0.9366080142935665],
              UndirectedEdge[125, 166] -> 
             RGBColor[
              0.637976884671782, 0.7122371605063453, 0.9674462033562077], 
             UndirectedEdge[7, 79] -> 
             RGBColor[
              0.279194369642464, 0.4093093382601571, 0.9392649763986148], 
             UndirectedEdge[49, 127] -> 
             RGBColor[
              0.5696796816862766, 0.6585549887842277, 0.9607001485227241], 
             UndirectedEdge[121, 200] -> 
             RGBColor[
              0.3397407230273164, 0.46868807124618594`, 0.9428689563437431], 
             UndirectedEdge[56, 193] -> 
             RGBColor[
              0.67868129185288, 0.7023647715881138, 0.6299872957347197], 
             UndirectedEdge[149, 194] -> 
             RGBColor[
              0.36826257309173815`, 0.492881838941236, 0.9447050325788797], 
             UndirectedEdge[108, 133] -> 
             RGBColor[
              0.3089326734340224, 0.4389191701451739, 0.9410188339434299], 
             UndirectedEdge[41, 140] -> 
             RGBColor[
              0.5500139511191333, 0.6393873207461201, 0.9603503604256642], 
             UndirectedEdge[36, 185] -> 
             RGBColor[
              0.9756376186889166, 0.9490015284115689, 0.6293722053177746], 
             UndirectedEdge[108, 111] -> 
             RGBColor[
              0.2907481721648579, 0.4229251418170724, 0.939869050330189], 
             UndirectedEdge[72, 154] -> 
             RGBColor[
              0.2174733675165556, 0.34590867624075816`, 0.9356961586058273], 
             UndirectedEdge[63, 110] -> 
             RGBColor[
              0.647827751164698, 0.7122703560880641, 0.7932207498739766], 
             UndirectedEdge[15, 186] -> 
             RGBColor[
              0.6190134906010305, 0.682696948018857, 0.8403995990808175], 
             UndirectedEdge[54, 155] -> 
             RGBColor[
              0.691455832845219, 0.7572357725683387, 0.9712167150529987], 
             UndirectedEdge[18, 108] -> 
             RGBColor[
              0.33249703213327053`, 0.459329433271357, 0.9425203340426018], 
             UndirectedEdge[44, 102] -> 
             RGBColor[
              0.32685169619532295`, 0.45369875962624356`, 0.9421877486747878],
              UndirectedEdge[8, 122] -> 
             RGBColor[
              0.6414694800667899, 0.7055238761971783, 0.7865050782015979], 
             UndirectedEdge[42, 197] -> 
             RGBColor[
              0.4914328345233762, 0.5952154548120885, 0.9538776692083681], 
             UndirectedEdge[48, 147] -> 
             RGBColor[
              0.5614788184075903, 0.6504249817609662, 0.9606122004977422], 
             UndirectedEdge[34, 54] -> 
             RGBColor[
              0.6241742030700903, 0.7002952160590157, 0.9665606114668591], 
             UndirectedEdge[5, 75] -> 
             RGBColor[
              0.6383728201187705, 0.5546122984932862, 0.5885687122093859], 
             UndirectedEdge[55, 115] -> 
             RGBColor[
              0.32325458797998574`, 0.45246315042050567`, 0.9418897071904007],
              UndirectedEdge[49, 155] -> 
             RGBColor[
              0.45075517708524515`, 0.5635078020736102, 0.9503116768217648], 
             UndirectedEdge[66, 136] -> 
             RGBColor[
              0.6534635034295474, 0.72171002553473, 0.9393418317061297], 
             UndirectedEdge[136, 148] -> 
             RGBColor[
              0.3766936807734076, 0.5006948659361901, 0.9452235661351066], 
             UndirectedEdge[130, 189] -> 
             RGBColor[
              0.3820625375430208, 0.5053450998234417, 0.9455656649409727], 
             UndirectedEdge[48, 76] -> 
             RGBColor[
              0.30178290271411023`, 0.4299295957448882, 0.9406656615103486], 
             UndirectedEdge[29, 141] -> 
             RGBColor[
              0.39472252663714164`, 0.5163105460672157, 0.9463723482512613], 
             UndirectedEdge[133, 163] -> 
             RGBColor[
              0.3298714852803604, 0.4601398335520849, 0.9422400972415315], 
             UndirectedEdge[111, 169] -> 
             RGBColor[
              0.392217141070608, 0.5132180559934991, 0.9464092126705648], 
             UndirectedEdge[76, 142] -> 
             RGBColor[
              0.2904504608377703, 0.42011400417669265`, 0.939943568334873], 
             UndirectedEdge[78, 98] -> 
             RGBColor[
              0.660022254655368, 0.7246870716750429, 0.8595547807916557], 
             UndirectedEdge[21, 170] -> 
             RGBColor[
              0.561913247748902, 0.5471283663385289, 0.600112862059017], 
             UndirectedEdge[92, 139] -> 
             RGBColor[
              0.36831122937048716`, 0.4934344078452382, 0.9446894437440232], 
             UndirectedEdge[63, 70] -> 
             RGBColor[
              0.7808774845699358, 0.8251230506461901, 0.8025273269394334], 
             UndirectedEdge[71, 197] -> 
             RGBColor[
              0.46859556838362665`, 0.5750754276386429, 0.9524356631445605], 
             UndirectedEdge[127, 141] -> 
             RGBColor[
              0.5921922739585395, 0.6780542646946739, 0.962134630995209], 
             UndirectedEdge[64, 138] -> 
             RGBColor[
              0.32095877562013087`, 0.45216321974829154`, 0.9416815926296558],
              UndirectedEdge[39, 108] -> 
             RGBColor[
              0.5558903362166727, 0.6395802593120911, 0.9616257636138437], 
             UndirectedEdge[24, 165] -> 
             RGBColor[
              0.3192315239571606, 0.4424481954656241, 0.9418724702771499], 
             UndirectedEdge[132, 182] -> 
             RGBColor[
              0.3293571343386859, 0.4593070265694291, 0.9422215042796107], 
             UndirectedEdge[77, 181] -> 
             RGBColor[
              0.5415472518722144, 0.6334786902854724, 0.959207827422948], 
             UndirectedEdge[20, 47] -> 
             RGBColor[
              0.6026962747350915, 0.6793769616325849, 0.9657152228515441], 
             UndirectedEdge[191, 199] -> 
             RGBColor[
              0.6464323286025333, 0.7125014496163389, 0.8676685277869252], 
             UndirectedEdge[89, 154] -> 
             RGBColor[
              0.2822648869457953, 0.41007260746096075`, 0.9395300583609157], 
             UndirectedEdge[93, 164] -> 
             RGBColor[
              0.37625474317760743`, 0.500314680252353, 0.9451955974196395], 
             UndirectedEdge[26, 187] -> 
             RGBColor[
              0.564708889638147, 0.6570123185441261, 0.9592052081166961], 
             UndirectedEdge[5, 188] -> 
             RGBColor[
              0.592574754881851, 0.5135255508188943, 0.5857024479430224], 
             UndirectedEdge[7, 16] -> 
             RGBColor[
              0.37849360420372613`, 0.4934181008579477, 0.9461170024432785], 
             UndirectedEdge[154, 160] -> 
             RGBColor[
              0.32206950148768165`, 0.44454936393904465`, 0.9420663732016862],
              UndirectedEdge[88, 152] -> 
             RGBColor[
              0.422806348471376, 0.5389989562817601, 0.948613962519937], 
             UndirectedEdge[9, 18] -> 
             RGBColor[
              0.4223149919007775, 0.5401635333573775, 0.9481432862645623], 
             UndirectedEdge[9, 200] -> 
             RGBColor[
              0.4110592991737658, 0.5304144180448058, 0.9474260834770154], 
             UndirectedEdge[55, 183] -> 
             RGBColor[
              0.46431772602879134`, 0.5695508105826105, 0.9522856516630864], 
             UndirectedEdge[72, 104] -> 
             RGBColor[
              0.26248009054315413`, 0.3932135957327686, 0.938259224900712], 
             UndirectedEdge[112, 181] -> 
             RGBColor[
              0.4359207301204391, 0.5494832764825166, 0.9496912809954443], 
             UndirectedEdge[136, 193] -> 
             RGBColor[
              0.6504313708027709, 0.6778961098568264, 0.6281872357458311], 
             UndirectedEdge[80, 198] -> 
             RGBColor[
              0.5988610341304411, 0.6663966081113872, 0.9330094363680947], 
             UndirectedEdge[42, 131] -> 
             RGBColor[
              0.3850948529772296, 0.5079715390439481, 0.9457588813990693], 
             UndirectedEdge[65, 156] -> 
             RGBColor[
              0.5465793575190846, 0.27069120406307284`, 0.5516190178759549], 
             UndirectedEdge[26, 192] -> 
             RGBColor[
              0.43869227000576055`, 0.5543345886632466, 0.9491907332981715], 
             UndirectedEdge[65, 155] -> 
             RGBColor[
              0.3891699112967145, 0.5071233293341009, 0.946498915709328], 
             UndirectedEdge[59, 62] -> 
             RGBColor[
              0.2927568297307811, 0.424973304149662, 0.9399857494935853], 
             UndirectedEdge[82, 187] -> 
             RGBColor[
              0.6968954335227708, 0.7631392763602349, 0.9704236820216025], 
             UndirectedEdge[4, 86] -> 
             RGBColor[
              0.5265587864841821, 0.31089137168348147`, 0.5587917024318032], 
             UndirectedEdge[73, 167] -> 
             RGBColor[
              0.2791214178566068, 0.4106317297246349, 0.9392095951540869], 
             UndirectedEdge[74, 159] -> 
             RGBColor[
              0.31227935749676394`, 0.4409633117034998, 0.9412633723443473], 
             UndirectedEdge[25, 60] -> 
             RGBColor[
              0.9849745088337736, 0.9880545875123251, 0.8986748035564258], 
             UndirectedEdge[159, 162] -> 
             RGBColor[
              0.630541995626432, 0.6943265609830533, 0.8147000343152746], 
             UndirectedEdge[10, 147] -> 
             RGBColor[
              0.7264198692488302, 0.7862039899434549, 0.9733664018532373], 
             UndirectedEdge[23, 163] -> 
             RGBColor[
              0.24809446244108896`, 0.3773060330550563, 0.9374688136015779], 
             UndirectedEdge[40, 54] -> 
             RGBColor[
              0.9145258776250869, 0.8707814106674925, 0.6329942676748506], 
             UndirectedEdge[123, 129] -> 
             RGBColor[
              0.6179203775780782, 0.6947916994136021, 0.9662020670048486], 
             UndirectedEdge[25, 165] -> 
             RGBColor[
              0.7031502825123572, 0.7637184746071864, 0.9239073283088803], 
             UndirectedEdge[39, 178] -> 
             RGBColor[
              0.8780955968119499, 0.9056336099005747, 0.9882347359807586], 
             UndirectedEdge[76, 107] -> 
             RGBColor[
              0.33452800574386354`, 0.4582917581725279, 0.9427521505200467], 
             UndirectedEdge[63, 138] -> 
             RGBColor[
              0.6502487544855109, 0.7148149840787148, 0.7933586224315434], 
             UndirectedEdge[71, 81] -> 
             RGBColor[
              0.42386951944087015`, 0.5387648062213699, 0.9489146647348712], 
             UndirectedEdge[8, 83] -> 
             RGBColor[
              0.6383416639704866, 0.702236343164969, 0.7863269537021027], 
             UndirectedEdge[10, 149] -> 
             RGBColor[
              0.5608066288231408, 0.6530796078731038, 0.9591993838276839], 
             UndirectedEdge[119, 172] -> 
             RGBColor[
              0.4050384551684266, 0.522891132437284, 0.9474855345740835], 
             UndirectedEdge[106, 130] -> 
             RGBColor[
              0.28628468563450926`, 0.41038448488876744`, 0.9399022608531742],
              UndirectedEdge[147, 176] -> 
             RGBColor[
              0.5264370331669795, 0.6181875912173509, 0.9584484230681645], 
             UndirectedEdge[27, 197] -> 
             RGBColor[
              0.4893715124616601, 0.5934300412472893, 0.9537463235893511], 
             UndirectedEdge[72, 176] -> 
             RGBColor[
              0.2550413101927061, 0.3853949659385326, 0.9378355973644434], 
             UndirectedEdge[92, 118] -> 
             RGBColor[
              0.3661557983035881, 0.49156748179020554`, 0.9445521015824132], 
             UndirectedEdge[123, 171] -> 
             RGBColor[
              0.29839787563190734`, 0.4268825674689823, 0.94045418451169], 
             UndirectedEdge[66, 113] -> 
             RGBColor[
              0.7047510406598094, 0.7661327124970092, 0.9426098282266535], 
             UndirectedEdge[67, 179] -> 
             RGBColor[
              0.36702338975888693`, 0.49097207610429205`, 0.9446566992438764],
              UndirectedEdge[130, 197] -> 
             RGBColor[
              0.5129880942448324, 0.613885537383959, 0.9552511512972515], 
             UndirectedEdge[15, 194] -> 
             RGBColor[
              0.2734605316703488, 0.40475473555762825`, 0.9388845447787988], 
             UndirectedEdge[47, 135] -> 
             RGBColor[
              0.5972407607944445, 0.6736428705814029, 0.9654045394033339], 
             UndirectedEdge[8, 170] -> 
             RGBColor[
              0.964441200207589, 0.8841791688787662, 0.44969920169687083`], 
             UndirectedEdge[17, 149] -> 
             RGBColor[
              0.36067171369273043`, 0.4849033644245951, 0.9442727443657764], 
             UndirectedEdge[13, 97] -> 
             RGBColor[
              0.37679037269094195`, 0.4992047775428245, 0.9453303110933727], 
             UndirectedEdge[11, 86] -> 
             RGBColor[
              0.5597696794841736, 0.3457981259187077, 0.5606830136570393], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.25989065883458684`, 0.3904919388276116, 0.9381117605956301], 
             UndirectedEdge[37, 160] -> 
             RGBColor[
              0.5930318551499666, 0.6781534286155239, 0.9624539442829145], 
             UndirectedEdge[46, 50] -> 
             RGBColor[
              0.7388664100241424, 0.7899159587032423, 0.7090143320611677], 
             UndirectedEdge[49, 53] -> 
             RGBColor[
              0.4851911236075278, 0.5914644547821113, 0.9530226006750273], 
             UndirectedEdge[52, 120] -> 
             RGBColor[
              0.42895931350754923`, 0.5459647300634204, 0.9485538860362418], 
             UndirectedEdge[81, 147] -> 
             RGBColor[
              0.6537040169407935, 0.7278739483927531, 0.9671606401321512], 
             UndirectedEdge[49, 123] -> 
             RGBColor[
              0.3759581448595475, 0.5000577816967144, 0.9451766984370843], 
             UndirectedEdge[127, 140] -> 
             RGBColor[
              0.7654744631754522, 0.8167137355448393, 0.9772589987899125], 
             UndirectedEdge[31, 132] -> 
             RGBColor[
              0.2567620141722039, 0.3872035349199183, 0.9379335889105224], 
             UndirectedEdge[146, 186] -> 
             RGBColor[
              0.992400815502848, 0.985720198725698, 0.5805447244949238], 
             UndirectedEdge[98, 124] -> 
             RGBColor[
              0.6312029921658504, 0.6961512551070415, 0.8578493052459257], 
             UndirectedEdge[4, 53] -> 
             RGBColor[
              0.3943555056474479, 0.5043360073308607, 0.9475440752784391], 
             UndirectedEdge[82, 137] -> 
             RGBColor[
              0.5969805831124484, 0.6825067234509323, 0.9622279097510376], 
             UndirectedEdge[42, 107] -> 
             RGBColor[
              0.38722669007716987`, 0.5098180291906682, 0.9458947201739679], 
             UndirectedEdge[99, 102] -> 
             RGBColor[
              0.3484196336991725, 0.4762053074554138, 0.9434219688572945], 
             UndirectedEdge[57, 88] -> 
             RGBColor[
              0.29833030769404856`, 0.42874187588976487`, 0.9403796579045467],
              UndirectedEdge[40, 49] -> 
             RGBColor[
              0.6738252218651131, 0.6770534401727637, 0.6120892294436165], 
             UndirectedEdge[21, 90] -> 
             RGBColor[
              0.23442807003537092`, 0.3637291435782612, 0.9366617038320393], 
             UndirectedEdge[143, 158] -> 
             RGBColor[
              0.32000174957445265`, 0.4515911645509679, 0.9416112064098157], 
             UndirectedEdge[24, 111] -> 
             RGBColor[
              0.26159228818075686`, 0.3922804591599682, 0.9382086658695594], 
             UndirectedEdge[139, 155] -> 
             RGBColor[
              0.4187248187582661, 0.5357647155834001, 0.9482707307125033], 
             UndirectedEdge[94, 174] -> 
             RGBColor[
              0.3646786110461826, 0.48300500930008416`, 0.9449563831890636], 
             UndirectedEdge[4, 118] -> 
             RGBColor[
              0.27398883926127243`, 0.4032858936086709, 0.9389887443093237], 
             UndirectedEdge[121, 159] -> 
             RGBColor[
              0.2892621336287228, 0.42102694926831186`, 0.9397967351928076], 
             UndirectedEdge[5, 76] -> 
             RGBColor[
              0.5684415794635845, 0.4881600533225985, 0.5843280993047858], 
             UndirectedEdge[27, 194] -> 
             RGBColor[
              0.3248172600955377, 0.45525169244885005`, 0.9419367356519436], 
             UndirectedEdge[77, 160] -> 
             RGBColor[
              0.5939897149817672, 0.6789017159961308, 0.9625494147992394], 
             UndirectedEdge[2, 80] -> 
             RGBColor[
              0.693007664312866, 0.7557461125346442, 0.9387226181513306], 
             UndirectedEdge[74, 85] -> 
             RGBColor[
              0.36469702867228304`, 0.4903039688554627, 0.9444591500714459], 
             UndirectedEdge[35, 110] -> 
             RGBColor[
              0.5803304900967676, 0.4444484686049137, 0.5724825862696887], 
             UndirectedEdge[143, 154] -> 
             RGBColor[
              0.2685961836004902, 0.39823346363226325`, 0.9386591006705127], 
             UndirectedEdge[53, 129] -> 
             RGBColor[
              0.7271533563260586, 0.7861983724989989, 0.9740479692427915], 
             UndirectedEdge[80, 187] -> 
             RGBColor[
              0.823632581043259, 0.8624153177420701, 0.9490307295859832], 
             UndirectedEdge[30, 87] -> 
             RGBColor[
              0.3213390314464762, 0.44656982503976983`, 0.9419226832023861], 
             UndirectedEdge[29, 197] -> 
             RGBColor[
              0.4888717196675866, 0.592997145849379, 0.9537144772344621], 
             UndirectedEdge[74, 121] -> 
             RGBColor[
              0.33540029229965806`, 0.4649286083062798, 0.942592387935869], 
             UndirectedEdge[127, 199] -> 
             RGBColor[
              0.8657942816075592, 0.8938654620923513, 0.8848016565280974], 
             UndirectedEdge[52, 80] -> 
             RGBColor[
              0.6965042403178624, 0.7587746709271521, 0.9389454168824682], 
             UndirectedEdge[125, 187] -> 
             RGBColor[
              0.7773371204777026, 0.8264724600470906, 0.9783109215980135], 
             UndirectedEdge[57, 152] -> 
             RGBColor[
              0.3891087521243307, 0.5057332170736513, 0.9466161180863646], 
             UndirectedEdge[128, 193] -> 
             RGBColor[
              0.6800460867695077, 0.7035468883483098, 0.6300742592599665], 
             UndirectedEdge[151, 172] -> 
             RGBColor[
              0.7404356945568732, 0.763092489270923, 0.647732210503808], 
             UndirectedEdge[5, 27] -> 
             RGBColor[
              0.6190789417351749, 0.5379009107759396, 0.58733932333969], 
             UndirectedEdge[65, 118] -> 
             RGBColor[
              0.3032391914328217, 0.43402986832041224`, 0.9406545085934752], 
             UndirectedEdge[78, 80] -> 
             RGBColor[
              0.650558029348939, 0.7189783723095806, 0.9360177649481676], 
             UndirectedEdge[40, 199] -> 
             RGBColor[
              0.9699398217863957, 0.9123639134808874, 0.5361907374489898], 
             UndirectedEdge[5, 42] -> 
             RGBColor[
              0.6211402637968909, 0.5396863243407388, 0.587470668958707], 
             UndirectedEdge[123, 196] -> 
             RGBColor[
              0.5420434999116402, 0.6350072987246731, 0.9587743907273993], 
             UndirectedEdge[80, 124] -> 
             RGBColor[
              0.6217387668594214, 0.6904425557415793, 0.9343122894024376], 
             UndirectedEdge[22, 48] -> 
             RGBColor[
              0.32612224646959814`, 0.45551178923543123`, 0.9420517511303912],
              UndirectedEdge[69, 86] -> 
             RGBColor[
              0.5765202435777357, 0.3626166753872062, 0.5616657624415775], 
             UndirectedEdge[81, 143] -> 
             RGBColor[
              0.43343111005045465`, 0.5474061105054399, 0.9495107564931156], 
             UndirectedEdge[80, 116] -> 
             RGBColor[
              0.5856509634063437, 0.6525119862135014, 0.9322571423829057], 
             UndirectedEdge[90, 169] -> 
             RGBColor[
              0.3789106422477404, 0.49923208204991115`, 0.9456514272478034], 
             UndirectedEdge[121, 173] -> 
             RGBColor[
              0.30780419046000906`, 0.44051582663229827`, 0.9408526778988344],
              UndirectedEdge[8, 179] -> 
             RGBColor[
              0.6442957233034722, 0.7084944370331023, 0.7866660285728748], 
             UndirectedEdge[29, 167] -> 
             RGBColor[
              0.3274723526700555, 0.4580618254689498, 0.9420872266330724], 
             UndirectedEdge[76, 87] -> 
             RGBColor[
              0.24352126277751232`, 0.3732866656919711, 0.937179547706531], 
             UndirectedEdge[111, 163] -> 
             RGBColor[
              0.3116869840111959, 0.4441458052239834, 0.9410903136282904], 
             UndirectedEdge[130, 149] -> 
             RGBColor[
              0.41347110248204677`, 0.5325496201332511, 0.947566990925384], 
             UndirectedEdge[7, 122] -> 
             RGBColor[
              0.261123745474354, 0.39178799106821544`, 0.9381819830555767], 
             UndirectedEdge[89, 142] -> 
             RGBColor[
              0.3435421729862167, 0.47198069613415494`, 0.9431111813736341], 
             UndirectedEdge[44, 172] -> 
             RGBColor[
              0.3887435195991333, 0.5057641219953692, 0.9465575620996092], 
             UndirectedEdge[7, 179] -> 
             RGBColor[
              0.2639499887110363, 0.39475855190413944`, 0.9383429334268535], 
             UndirectedEdge[73, 188] -> 
             RGBColor[
              0.27105429324182806`, 0.402225626404925, 0.9387475130600054], 
             UndirectedEdge[16, 120] -> 
             RGBColor[
              0.48078172548942577`, 0.5889514551974335, 0.9523807309282528], 
             UndirectedEdge[98, 116] -> 
             RGBColor[
              0.5951151887127726, 0.6582206855789635, 0.8557941582263938], 
             UndirectedEdge[5, 81] -> 
             RGBColor[
              0.7173151975514044, 0.6205563531017604, 0.5942707822288041], 
             UndirectedEdge[76, 106] -> 
             RGBColor[
              0.21203074157974677`, 0.34018813129875664`, 0.9353862091103695],
              UndirectedEdge[135, 144] -> 
             RGBColor[
              0.24617783461473502`, 0.3760788911292751, 0.937330835542615], 
             UndirectedEdge[194, 197] -> 
             RGBColor[
              0.46777956485452377`, 0.5742177561919439, 0.9523891929507472], 
             UndirectedEdge[27, 29] -> 
             RGBColor[
              0.3459094149086005, 0.4740310821062852, 0.9432620199356585], 
             UndirectedEdge[44, 58] -> 
             RGBColor[
              0.3283788907391444, 0.45502153878107204`, 0.942285060160675], 
             UndirectedEdge[53, 92] -> 
             RGBColor[
              0.4865224646897635, 0.5926175955123953, 0.9531074325515286], 
             UndirectedEdge[83, 122] -> 
             RGBColor[
              0.28539814454363926`, 0.41730192357582857`, 0.9395643741718172],
              UndirectedEdge[9, 178] -> 
             RGBColor[
              0.687407521552286, 0.7536641899707948, 0.9712260251958282], 
             UndirectedEdge[12, 99] -> 
             RGBColor[
              0.2599105969299135, 0.39035017305635245`, 0.9381188540892298], 
             UndirectedEdge[7, 126] -> 
             RGBColor[
              0.49771586818024854`, 0.588379797399384, 0.9567526401293218], 
             UndirectedEdge[139, 146] -> 
             RGBColor[
              0.6627099653086017, 0.722027372880089, 0.6800217005653655], 
             UndirectedEdge[100, 198] -> 
             RGBColor[
              0.2921704528720685, 0.41968066888254707`, 0.9401235790355809], 
             UndirectedEdge[56, 109] -> 
             RGBColor[
              0.6921978643368916, 0.7529030696003758, 0.8743628013559626], 
             UndirectedEdge[9, 159] -> 
             RGBColor[
              0.3605807097751722, 0.48275329606693174`, 0.9443538623260799], 
             UndirectedEdge[2, 98] -> 
             RGBColor[
              0.7024718896192949, 0.7614548119001063, 0.8622596339948188], 
             UndirectedEdge[95, 164] -> 
             RGBColor[
              0.577704714626114, 0.3566003157518033, 0.5608182580070078], 
             UndirectedEdge[108, 163] -> 
             RGBColor[
              0.2963231130358399, 0.42799740270320163`, 0.9402153639050541], 
             UndirectedEdge[85, 121] -> 
             RGBColor[
              0.34167980480424187`, 0.47036760642027475`, 0.9429925129199062],
              UndirectedEdge[55, 177] -> 
             RGBColor[
              0.631251035387699, 0.7002253021472533, 0.9336202452358018], 
             UndirectedEdge[118, 141] -> 
             RGBColor[
              0.38733704949361525`, 0.5099136169703676, 0.9459017521783968], 
             UndirectedEdge[58, 77] -> 
             RGBColor[
              0.5732199860502001, 0.6609120207125367, 0.9612259860376701], 
             UndirectedEdge[142, 154] -> 
             RGBColor[
              0.2744891524756257, 0.4033376570826779, 0.9390345954362886], 
             UndirectedEdge[103, 178] -> 
             RGBColor[
              0.6889147648895494, 0.7548878380125237, 0.9713446809125519], 
             UndirectedEdge[48, 154] -> 
             RGBColor[
              0.28582159435196564`, 0.4131532486508734, 0.9397566886117641], 
             UndirectedEdge[72, 181] -> 
             RGBColor[
              0.2738885394594801, 0.40360544605966064`, 0.9389674720076518], 
             UndirectedEdge[45, 132] -> 
             RGBColor[
              0.28136827227880706`, 0.41306627231683085`, 0.9393348789079967],
              UndirectedEdge[103, 200] -> 
             RGBColor[
              0.4125665425110292, 0.5316380660865347, 0.947544739193739], 
             UndirectedEdge[21, 61] -> 
             RGBColor[
              0.43403518694135806`, 0.5326459650014006, 0.9513532166336938], 
             UndirectedEdge[51, 73] -> 
             RGBColor[
              0.6217473431093002, 0.6854251362974394, 0.8367662199455235], 
             UndirectedEdge[18, 41] -> 
             RGBColor[
              0.34951892786086197`, 0.4771574608061381, 0.9434920149092096], 
             UndirectedEdge[27, 42] -> 
             RGBColor[
              0.3484705297643902, 0.47624939106899467`, 0.9434252119095645], 
             UndirectedEdge[90, 165] -> 
             RGBColor[
              0.35044478009375, 0.47525530669992216`, 0.9436500190382542], 
             UndirectedEdge[50, 135] -> 
             RGBColor[
              0.3844231607973581, 0.5042439044283084, 0.946036556288809], 
             UndirectedEdge[93, 121] -> 
             RGBColor[
              0.37159829389361254`, 0.49628149792250265`, 0.9448988925887998],
              UndirectedEdge[23, 175] -> 
             RGBColor[
              0.23824389780405622`, 0.3677398205006036, 0.9368790095784545], 
             UndirectedEdge[57, 164] -> 
             RGBColor[
              0.293164339173305, 0.42426737360622435`, 0.9400504869584915], 
             UndirectedEdge[54, 172] -> 
             RGBColor[
              0.6952642472660904, 0.7603276149623166, 0.9715165273868914], 
             UndirectedEdge[99, 198] -> 
             RGBColor[
              0.2674202097845271, 0.3982432523035067, 0.9385465154318233], 
             UndirectedEdge[45, 112] -> 
             RGBColor[
              0.40198939927970584`, 0.5154184492198793, 0.9477003890825275], 
             UndirectedEdge[88, 173] -> 
             RGBColor[
              0.31762660826474753`, 0.4490235112456892, 0.9414785536757294], 
             UndirectedEdge[14, 22] -> 
             RGBColor[
              0.33897640025003245`, 0.46664541117148917`, 0.9428708064427986],
              UndirectedEdge[7, 67] -> 
             RGBColor[
              0.3367949313566162, 0.45920004972854556`, 0.9429352332568638], 
             UndirectedEdge[105, 135] -> 
             RGBColor[
              0.3065075754919169, 0.4376138270381955, 0.940835194333079], 
             UndirectedEdge[104, 176] -> 
             RGBColor[
              0.29578653213795336`, 0.42822077759926863`, 0.9401559774770711],
              UndirectedEdge[57, 91] -> 
             RGBColor[
              0.25360941424940986`, 0.38388995251468183`, 0.9377540530087729],
              UndirectedEdge[34, 185] -> 
             RGBColor[
              0.6693456503608732, 0.703060090367622, 0.6427762945837757], 
             UndirectedEdge[65, 172] -> 
             RGBColor[
              0.39297832571758584`, 0.5102151717280787, 0.9467987280432207], 
             UndirectedEdge[66, 120] -> 
             RGBColor[
              0.7040556190832786, 0.7655303732803229, 0.9425655165787342], 
             UndirectedEdge[91, 117] -> 
             RGBColor[
              0.5442898692378697, 0.6261700671895203, 0.9611495567237552], 
             UndirectedEdge[27, 141] -> 
             RGBColor[
              0.3952223194312152, 0.516743441465126, 0.9464041946061502], 
             UndirectedEdge[13, 145] -> 
             RGBColor[
              0.42516818992817895`, 0.5384800689718439, 0.9491387900800716], 
             UndirectedEdge[1, 174] -> 
             RGBColor[
              0.45759495555456037`, 0.5579423618886876, 0.9526104360610648], 
             UndirectedEdge[182, 196] -> 
             RGBColor[
              0.5426691147393803, 0.6355491748441461, 0.9588142543510134], 
             UndirectedEdge[96, 137] -> 
             RGBColor[
              0.3306269506355999, 0.44899411877588596`, 0.942855204559168], 
             UndirectedEdge[89, 157] -> 
             RGBColor[
              0.47435746654884825`, 0.5813742451070956, 0.9525275364878032], 
             UndirectedEdge[119, 191] -> 
             RGBColor[
              0.3007925923435607, 0.4334824642779113, 0.9404410651999779], 
             UndirectedEdge[51, 157] -> 
             RGBColor[
              0.7960919796861405, 0.8380725605384435, 0.8487529789727968], 
             UndirectedEdge[127, 195] -> 
             RGBColor[
              0.5568523953223887, 0.6474446380539867, 0.9598828051783412], 
             UndirectedEdge[27, 62] -> 
             RGBColor[
              0.3112473872597758, 0.4409888957188334, 0.9411639514687749], 
             UndirectedEdge[4, 40] -> 
             RGBColor[
              0.5829896039050332, 0.5899249927215132, 0.6066107040470283], 
             UndirectedEdge[161, 164] -> 
             RGBColor[
              0.25167813351021784`, 0.3806627410769573, 0.93768790891932], 
             UndirectedEdge[20, 101] -> 
             RGBColor[
              0.6444500458133053, 0.7084344390270892, 0.7644540615499611], 
             UndirectedEdge[13, 36] -> 
             RGBColor[
              0.6370914195134145, 0.7054904151861527, 0.9289462007866458], 
             UndirectedEdge[182, 195] -> 
             RGBColor[
              0.3637564733233997, 0.48948930708594635`, 0.9443992187163155], 
             UndirectedEdge[184, 186] -> 
             RGBColor[
              0.6455701408807464, 0.7106096712517173, 0.8419119610272039], 
             UndirectedEdge[96, 166] -> 
             RGBColor[
              0.29118156524000177`, 0.4153913721444432, 0.9401862585879273], 
             UndirectedEdge[38, 43] -> 
             RGBColor[
              0.3137356720583649, 0.44222469818026033`, 0.9413561674204441], 
             UndirectedEdge[30, 176] -> 
             RGBColor[
              0.3445588861424633, 0.47097536454907163`, 0.943245019576626], 
             UndirectedEdge[171, 174] -> 
             RGBColor[
              0.24216047153465936`, 0.3718563878165846, 0.9371020526583609], 
             UndirectedEdge[100, 125] -> 
             RGBColor[
              0.6204015846768622, 0.6970143190110084, 0.966326320781759], 
             UndirectedEdge[17, 188] -> 
             RGBColor[
              0.2907222138432062, 0.4228978579751638, 0.9398675720421727], 
             UndirectedEdge[87, 107] -> 
             RGBColor[
              0.3329147853618823, 0.45659616126698577`, 0.9426602800058386], 
             UndirectedEdge[62, 184] -> 
             RGBColor[
              0.2864473091143027, 0.4184046620604718, 0.9396241225420165], 
             UndirectedEdge[12, 33] -> 
             RGBColor[
              0.2855475090438785, 0.4125555777807999, 0.9397524154593004], 
             UndirectedEdge[32, 57] -> 
             RGBColor[
              0.33327082571385547`, 0.4590055964370233, 0.9426060368160818], 
             UndirectedEdge[17, 87] -> 
             RGBColor[
              0.26497581804295844`, 0.3958367635733259, 0.9384013528897279], 
             UndirectedEdge[42, 149] -> 
             RGBColor[
              0.3919158427605906, 0.5138795375613806, 0.9461935088365006], 
             UndirectedEdge[87, 130] -> 
             RGBColor[
              0.31777520683227484`, 0.44348301928198197`, 0.9416955994493357],
              UndirectedEdge[58, 170] -> 
             RGBColor[
              0.6619285397992827, 0.6447949054363156, 0.6060815810592608], 
             UndirectedEdge[118, 196] -> 
             RGBColor[
              0.5309098122734451, 0.6253638580878802, 0.9580649619962269], 
             UndirectedEdge[41, 159] -> 
             RGBColor[
              0.28778464573525675`, 0.41974722351569227`, 0.9397025909707273],
              UndirectedEdge[107, 157] -> 
             RGBColor[
              0.5106592769847718, 0.6128170487246479, 0.9548406557483496], 
             UndirectedEdge[161, 173] -> 
             RGBColor[
              0.24244280625461515`, 0.3721531395083133, 0.9371181312029855], 
             UndirectedEdge[15, 184] -> 
             RGBColor[
              0.2702524011320121, 0.40138278695461205`, 0.9387018464906445], 
             UndirectedEdge[106, 142] -> 
             RGBColor[
              0.25734671925802355`, 0.385319872877936, 0.9380583592245035], 
             UndirectedEdge[24, 39] -> 
             RGBColor[
              0.5267344522325716, 0.6089355766549869, 0.9599653791532141], 
             UndirectedEdge[45, 134] -> 
             RGBColor[
              0.49187194998453415`, 0.5871145531823483, 0.9556477236118459], 
             UndirectedEdge[5, 73] -> 
             RGBColor[
              0.5702282141276527, 0.49003791963371446`, 0.5844298455058153], 
             UndirectedEdge[147, 154] -> 
             RGBColor[
              0.48886909049082905`, 0.5787013015195765, 0.9563089843095485], 
             UndirectedEdge[76, 143] -> 
             RGBColor[
              0.2845574919626348, 0.41500981072627807`, 0.9395680735690972], 
             UndirectedEdge[5, 197] -> 
             RGBColor[
              0.7620412464941608, 0.6568669745190334, 0.5977917806384936], 
             UndirectedEdge[152, 159] -> 
             RGBColor[
              0.3898629958637434, 0.5065259750655892, 0.9466590711515206], 
             UndirectedEdge[108, 115] -> 
             RGBColor[
              0.31709464444518376`, 0.4459886592024508, 0.9415389075189136], 
             UndirectedEdge[65, 123] -> 
             RGBColor[
              0.3143728790710168, 0.4436733089572052, 0.9413639373246476], 
             UndirectedEdge[8, 67] -> 
             RGBColor[
              0.717140665949052, 0.7729359348575084, 0.7912583284028851], 
             UndirectedEdge[9, 41] -> 
             RGBColor[
              0.3822241566846002, 0.5054388669170922, 0.9455887336955211], 
             UndirectedEdge[111, 165] -> 
             RGBColor[
              0.3637512789166176, 0.48924128064351013`, 0.9444078044610156], 
             UndirectedEdge[146, 195] -> 
             RGBColor[
              0.681913037271693, 0.7386601086400579, 0.6812453033302439], 
             UndirectedEdge[104, 188] -> 
             RGBColor[
              0.2983130732422139, 0.43087633249180474`, 0.9402998602552761], 
             UndirectedEdge[37, 105] -> 
             RGBColor[
              0.5420835707302784, 0.6340245853864215, 0.9592075646514909], 
             UndirectedEdge[3, 75] -> 
             RGBColor[
              0.32563725247907527`, 0.4525458546681114, 0.9421140640436014], 
             UndirectedEdge[40, 132] -> 
             RGBColor[
              0.6265985965165114, 0.6357608089260055, 0.6090941716625289], 
             UndirectedEdge[154, 157] -> 
             RGBColor[
              0.4053044460382572, 0.5127312060556185, 0.9484509505504577], 
             UndirectedEdge[116, 148] -> 
             RGBColor[
              0.30709406014300444`, 0.43016402482418803`, 0.9411639381346009],
              UndirectedEdge[132, 185] -> 
             RGBColor[
              0.6376557243173855, 0.6752245671617407, 0.6407712215438461], 
             UndirectedEdge[92, 123] -> 
             RGBColor[
              0.3772894859417832, 0.5012109224269985, 0.9452615303135856], 
             UndirectedEdge[53, 139] -> 
             RGBColor[
              0.4531607652805487, 0.5637213682919012, 0.9509816545657659], 
             UndirectedEdge[40, 196] -> 
             RGBColor[
              0.8399105769172058, 0.8120029572007225, 0.6256869217339316], 
             UndirectedEdge[27, 73] -> 
             RGBColor[
              0.29755848009515184`, 0.4266009863619703, 0.9403843884566729], 
             UndirectedEdge[57, 103] -> 
             RGBColor[
              0.3613337093730228, 0.48318418611672276`, 0.9444295649776476], 
             UndirectedEdge[44, 77] -> 
             RGBColor[
              0.5122111981123197, 0.6042437905921914, 0.9574786297416816], 
             UndirectedEdge[88, 91] -> 
             RGBColor[
              0.28730701059645514`, 0.41715569172279066`, 0.9397518974423453],
              UndirectedEdge[69, 146] -> 
             RGBColor[
              0.6538661627690545, 0.7143673156227732, 0.6794581812878131], 
             UndirectedEdge[65, 199] -> 
             RGBColor[
              0.6335395807479824, 0.6989503541737785, 0.8669343048697198], 
             UndirectedEdge[27, 75] -> 
             RGBColor[
              0.3657030860862697, 0.49117536522154204`, 0.9445232551602434], 
             UndirectedEdge[4, 65] -> 
             RGBColor[
              0.24658936286661992`, 0.37651143341440435`, 0.9373542714677583],
              UndirectedEdge[58, 102] -> 
             RGBColor[
              0.3878604841332033, 0.5103669897465889, 0.9459351049707763], 
             UndirectedEdge[107, 168] -> 
             RGBColor[
              0.393141023075791, 0.514940727171054, 0.9462715762428007], 
             UndirectedEdge[9, 85] -> 
             RGBColor[
              0.4129983809506913, 0.5320939532188946, 0.9475496400531784], 
             UndirectedEdge[22, 144] -> 
             RGBColor[
              0.2510921283084441, 0.3812441253855797, 0.9376106972984257], 
             UndirectedEdge[110, 138] -> 
             RGBColor[
              0.303546698366364, 0.43637720432828503`, 0.9405979074636419], 
             UndirectedEdge[34, 132] -> 
             RGBColor[
              0.33624692196151484`, 0.46527461431752876`, 0.9426605154545374],
              UndirectedEdge[48, 158] -> 
             RGBColor[
              0.3372271603259281, 0.46651094956957806`, 0.942708794351067], 
             UndirectedEdge[19, 95] -> 
             RGBColor[
              0.9018477796486031, 0.6186376493076231, 0.557807007367636], 
             UndirectedEdge[122, 137] -> 
             RGBColor[
              0.381286897702512, 0.5022409351693725, 0.9457402135999532], 
             UndirectedEdge[8, 198] -> 
             RGBColor[
              0.6093737206268641, 0.6717891980371324, 0.7846772721829152], 
             UndirectedEdge[92, 174] -> 
             RGBColor[
              0.3210520818445352, 0.44618474277460085`, 0.9419093984602565], 
             UndirectedEdge[39, 133] -> 
             RGBColor[
              0.5894387084611933, 0.6717226901609743, 0.9636504969503208], 
             UndirectedEdge[120, 198] -> 
             RGBColor[
              0.33131610732012795`, 0.45358666724765545`, 0.9426179055218682],
              UndirectedEdge[4, 34] -> 
             RGBColor[
              0.29263792935003663`, 0.41943879811303647`, 0.940177047839037], 
             UndirectedEdge[31, 34] -> 
             RGBColor[
              0.2884519402156916, 0.41503905812579955`, 0.939938661950452], 
             UndirectedEdge[41, 152] -> 
             RGBColor[
              0.41150644277317144`, 0.5292115459157496, 0.9478939425209618], 
             UndirectedEdge[95, 121] -> 
             RGBColor[
              0.5730482653421191, 0.3525671334219529, 0.560521553176168], 
             UndirectedEdge[3, 129] -> 
             RGBColor[
              0.5746061262702886, 0.6533485727181368, 0.9635858895847876], 
             UndirectedEdge[49, 199] -> 
             RGBColor[
              0.6951248465365132, 0.7553348269132878, 0.8707470659821565], 
             UndirectedEdge[171, 182] -> 
             RGBColor[
              0.29902349045964743`, 0.4274244435884552, 0.9404940481353042], 
             UndirectedEdge[56, 150] -> 
             RGBColor[
              0.38187153785225014`, 0.5051796654912197, 0.9455534946095712], 
             UndirectedEdge[179, 183] -> 
             RGBColor[
              0.4675548554558919, 0.5729532388563533, 0.952470001395056], 
             UndirectedEdge[31, 156] -> 
             RGBColor[
              0.5131430162131903, 0.23554748936409456`, 0.5497148677032184], 
             UndirectedEdge[132, 153] -> 
             RGBColor[
              0.3031712079878207, 0.435982540132971, 0.9405765238420721], 
             UndirectedEdge[78, 136] -> 
             RGBColor[
              0.33242098688489474`, 0.46234808370025593`, 0.9424025492293366],
              UndirectedEdge[27, 167] -> 
             RGBColor[
              0.327972145464129, 0.4584947208668601, 0.9421190729879614], 
             UndirectedEdge[35, 174] -> 
             RGBColor[
              0.5499832600286763, 0.4125516056778312, 0.5707543564120146], 
             UndirectedEdge[61, 190] -> 
             RGBColor[
              0.48884133703142085`, 0.5902507036566735, 0.9544743458028896], 
             UndirectedEdge[18, 103] -> 
             RGBColor[
              0.42382223523804075`, 0.5413871813991065, 0.948261941981286], 
             UndirectedEdge[146, 155] -> 
             RGBColor[
              0.7464852541055955, 0.793253907838745, 0.6857287655196083], 
             UndirectedEdge[77, 166] -> 
             RGBColor[
              0.5761046786986304, 0.6634105964957389, 0.9614097961023945], 
             UndirectedEdge[85, 159] -> 
             RGBColor[
              0.31855887000134775`, 0.44640230981749474`, 0.9416634973283846],
              UndirectedEdge[39, 88] -> 
             RGBColor[
              0.5842121376424687, 0.6671956972128826, 0.9633174644794269], 
             UndirectedEdge[66, 80] -> 
             RGBColor[
              0.9716005458935918, 0.9783403141440546, 0.9329570474249607], 
             UndirectedEdge[62, 141] -> 
             RGBColor[
              0.36006049898831693`, 0.4832683596797639, 0.9442742797843775], 
             UndirectedEdge[91, 103] -> 
             RGBColor[
              0.3503104122754294, 0.47159800194974855`, 0.9438018045154464], 
             UndirectedEdge[149, 189] -> 
             RGBColor[
              0.40189126875604897`, 0.5225197501791579, 0.9468291341600084], 
             UndirectedEdge[4, 69] -> 
             RGBColor[
              0.2673004677886243, 0.3974927624063878, 0.9385625671933813], 
             UndirectedEdge[23, 169] -> 
             RGBColor[
              0.32862461950050115`, 0.446378283824572, 0.9427877126438522], 
             UndirectedEdge[32, 152] -> 
             RGBColor[
              0.4577468664911829, 0.5692626768290185, 0.9508403414314722], 
             UndirectedEdge[100, 124] -> 
             RGBColor[
              0.31504818560104886`, 0.44372661651273915`, 0.9414264320699237],
              UndirectedEdge[129, 139] -> 
             RGBColor[
              0.6089421210067822, 0.6870151848318418, 0.9656299804352861], 
             UndirectedEdge[29, 73] -> 
             RGBColor[
              0.2970586873010783, 0.42616809096406, 0.940352542101784], 
             UndirectedEdge[32, 178] -> 
             RGBColor[
              0.6608518812303821, 0.7307092483328244, 0.9695211527509862], 
             UndirectedEdge[8, 61] -> 
             RGBColor[
              0.836563139400045, 0.8696967675416379, 0.8009395562715476], 
             UndirectedEdge[10, 27] -> 
             RGBColor[
              0.5173613158269403, 0.615449461380718, 0.9564310869007477], 
             UndirectedEdge[72, 160] -> 
             RGBColor[
              0.32633100256903297`, 0.4490284717703191, 0.9423090593839433], 
             UndirectedEdge[72, 144] -> 
             RGBColor[
              0.21505297727216288`, 0.34336469263229635`, 0.9355583209620557],
              UndirectedEdge[134, 135] -> 
             RGBColor[
              0.5047744673062663, 0.6006759169543363, 0.9563825028857547], 
             UndirectedEdge[95, 150] -> 
             RGBColor[
              0.6019215771421005, 0.37757574488824974`, 0.5623613350723957], 
             UndirectedEdge[68, 71] -> 
             RGBColor[
              0.35243314280181226`, 0.47932207223772205`, 0.9436908704487237],
              UndirectedEdge[118, 123] -> 
             RGBColor[
              0.3417723554656693, 0.47044776915147174`, 0.942998410166213], 
             UndirectedEdge[89, 168] -> 
             RGBColor[
              0.35683921263986745`, 0.4834979235535017, 0.9439584569822542], 
             UndirectedEdge[44, 99] -> 
             RGBColor[
              0.2889380403051136, 0.42085985648989693`, 0.9397719240471932], 
             UndirectedEdge[121, 180] -> 
             RGBColor[
              0.31090558053815076`, 0.4437125201184723, 0.9410316065622488], 
             UndirectedEdge[10, 141] -> 
             RGBColor[
              0.5661744275554814, 0.6577289253416485, 0.9595414152163506], 
             UndirectedEdge[6, 170] -> 
             RGBColor[
              0.8564183700127552, 0.8023428950904486, 0.6223373929167748], 
             UndirectedEdge[12, 77] -> 
             RGBColor[
              0.4831837547371196, 0.5737341071586469, 0.9558255597837182], 
             UndirectedEdge[112, 143] -> 
             RGBColor[
              0.43488987534280044`, 0.5485904018863936, 0.9496255958405624], 
             UndirectedEdge[67, 125] -> 
             RGBColor[
              0.6603325188870728, 0.7316004872367836, 0.9688706846000948], 
             UndirectedEdge[3, 10] -> 
             RGBColor[
              0.4772954822197458, 0.5768199508272873, 0.9540218957841058], 
             UndirectedEdge[124, 125] -> 
             RGBColor[
              0.5754433062938652, 0.6544996980465998, 0.9635924814144678], 
             UndirectedEdge[11, 174] -> 
             RGBColor[
              0.2620960158022111, 0.3928099088282924, 0.938237352412403], 
             UndirectedEdge[71, 87] -> 
             RGBColor[
              0.2733826809710691, 0.40467290953666596`, 0.9388801112966447], 
             UndirectedEdge[7, 192] -> 
             RGBColor[
              0.3277829133148596, 0.45139429265797304`, 0.9423609954362577], 
             UndirectedEdge[56, 148] -> 
             RGBColor[
              0.40494360182351663`, 0.5251635276674776, 0.9470236261239953], 
             UndirectedEdge[30, 71] -> 
             RGBColor[
              0.3528136700220142, 0.4796516657900068, 0.943715117306708], 
             UndirectedEdge[35, 86] -> 
             RGBColor[
              0.8476569237106388, 0.3655398227682465, 0.19320001765665085`], 
             UndirectedEdge[68, 127] -> 
             RGBColor[
              0.57017904140717, 0.6589875090759162, 0.9607319672825729], 
             UndirectedEdge[10, 30] -> 
             RGBColor[
              0.5445417222243139, 0.6389917632751756, 0.9581629983616988], 
             UndirectedEdge[89, 176] -> 
             RGBColor[
              0.3198328296219458, 0.4495588971587352, 0.9416694971195319], 
             UndirectedEdge[71, 76] -> 
             RGBColor[
              0.2749959013530503, 0.4063685064422081, 0.9389719818108528], 
             UndirectedEdge[49, 119] -> 
             RGBColor[
              0.3494851102775406, 0.4763158415748602, 0.9435196033952092], 
             UndirectedEdge[87, 106] -> 
             RGBColor[
              0.21041752119776555`, 0.3384925343932145, 0.9352943385961614], 
             UndirectedEdge[86, 196] -> 
             RGBColor[
              0.7834797594963547, 0.5329693361626906, 0.5778679201187064], 
             UndirectedEdge[53, 123] -> 
             RGBColor[
              0.46213902185184474`, 0.5714978828736615, 0.9515537411353283], 
             UndirectedEdge[68, 102] -> 
             RGBColor[
              0.39317112782319963`, 0.5149668023901508, 0.946273494490685], 
             UndirectedEdge[107, 130] -> 
             RGBColor[
              0.40878194979862603`, 0.5284881117625387, 0.9472682022628514], 
             UndirectedEdge[42, 157] -> 
             RGBColor[
              0.4739644387337082, 0.5810338241677736, 0.9525024931029633], 
             UndirectedEdge[96, 99] -> 
             RGBColor[
              0.24885602215754066`, 0.378731114070066, 0.937489312409721], 
             UndirectedEdge[62, 194] -> 
             RGBColor[
              0.2896554396526394, 0.4217766106634879, 0.9398068208301709], 
             UndirectedEdge[57, 117] -> 
             RGBColor[
              0.555313166335463, 0.6377562513564945, 0.9617773171859565], 
             UndirectedEdge[102, 128] -> 
             RGBColor[
              0.391338131547779, 0.513379153145453, 0.9461566975888702], 
             UndirectedEdge[46, 47] -> 
             RGBColor[
              0.9516840100212289, 0.9593149248563368, 0.7283823151756925], 
             UndirectedEdge[28, 105] -> 
             RGBColor[
              0.5616057851852572, 0.6492754876929762, 0.9611533565428967], 
             UndirectedEdge[40, 182] -> 
             RGBColor[
              0.6513987349371702, 0.657628744383787, 0.6106602335275317], 
             UndirectedEdge[79, 179] -> 
             RGBColor[
              0.30942282804473475`, 0.44108136463590364`, 0.9409864423856275],
              UndirectedEdge[36, 63] -> 
             RGBColor[
              0.9875252959724672, 0.9878505747248989, 0.7819194374021715], 
             UndirectedEdge[118, 129] -> 
             RGBColor[
              0.606786689939883, 0.6851482587768092, 0.9654926382736762], 
             UndirectedEdge[74, 161] -> 
             RGBColor[
              0.2700389080942641, 0.39656592118229483`, 0.9388578412400199], 
             UndirectedEdge[66, 187] -> 
             RGBColor[
              0.8218455004360594, 0.8610825159512967, 0.9520557909087014], 
             UndirectedEdge[10, 29] -> 
             RGBColor[
              0.5168615230328668, 0.6150165659828076, 0.9563992405458588], 
             UndirectedEdge[30, 147] -> 
             RGBColor[
              0.5826481675219375, 0.66876080796139, 0.9619610927039881], 
             UndirectedEdge[109, 116] -> 
             RGBColor[
              0.5943483226563793, 0.6579035667570862, 0.8685031133665682], 
             UndirectedEdge[81, 154] -> 
             RGBColor[
              0.37804679288516874`, 0.4906022152826603, 0.946305128246173], 
             UndirectedEdge[89, 188] -> 
             RGBColor[
              0.3223593707262064, 0.4522144520512713, 0.9418133798977368], 
             UndirectedEdge[24, 163] -> 
             RGBColor[
              0.26716722905173884`, 0.39735272004609734`, 0.9385549794444247],
              UndirectedEdge[91, 159] -> 
             RGBColor[
              0.2543636579888226, 0.38468271050661973`, 0.9377970060739289], 
             UndirectedEdge[121, 164] -> 
             RGBColor[
              0.3170395177156118, 0.44902542820094227`, 0.941422455615169], 
             UndirectedEdge[4, 54] -> 
             RGBColor[
              0.5488752844151245, 0.6266238766486423, 0.962072070811429], 
             UndirectedEdge[51, 130] -> 
             RGBColor[
              0.6942146524999947, 0.7537436235763343, 0.8411805254872984], 
             UndirectedEdge[69, 186] -> 
             RGBColor[
              0.6557965776159713, 0.7205709492130374, 0.8425231704102664], 
             UndirectedEdge[137, 179] -> 
             RGBColor[
              0.3841131409391943, 0.5052114960052966, 0.94590116397123], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.32103260435209124`, 0.4524840391470909, 0.9416768915646976], 
             UndirectedEdge[22, 176] -> 
             RGBColor[
              0.29108046122898734`, 0.423274398691816, 0.9398879737008135], 
             UndirectedEdge[128, 198] -> 
             RGBColor[
              0.3103387076331336, 0.435417097993546, 0.9412812441633991], 
             UndirectedEdge[107, 131] -> 
             RGBColor[
              0.42178969122829324`, 0.5397547636008224, 0.9480970440444556], 
             UndirectedEdge[26, 125] -> 
             RGBColor[
              0.6681684745301231, 0.7383272590419045, 0.9693866566449856], 
             UndirectedEdge[47, 105] -> 
             RGBColor[
              0.6197637530033101, 0.6954405165536084, 0.9667558597872098], 
             UndirectedEdge[23, 60] -> 
             RGBColor[
              0.5819829836679269, 0.6467376213797216, 0.9155537796818486], 
             UndirectedEdge[43, 111] -> 
             RGBColor[
              0.33372109421555746`, 0.4632306440164215, 0.9424943076465138], 
             UndirectedEdge[73, 142] -> 
             RGBColor[
              0.2922370955018384, 0.42199187048780856`, 0.9400453145359027], 
             UndirectedEdge[43, 115] -> 
             RGBColor[
              0.36006756649588334`, 0.4862941614017998, 0.9441641648352384], 
             UndirectedEdge[61, 122] -> 
             RGBColor[
              0.4836196199731977, 0.5847623479524975, 0.9541769767412619], 
             UndirectedEdge[64, 65] -> 
             RGBColor[
              0.305894782295627, 0.43633000765189656`, 0.9408237204950064], 
             UndirectedEdge[147, 157] -> 
             RGBColor[
              0.6809616700938819, 0.7500029391657113, 0.9693064624364358], 
             UndirectedEdge[53, 69] -> 
             RGBColor[
              0.4443169627410015, 0.5560613110345856, 0.9504181352882135], 
             UndirectedEdge[27, 188] -> 
             RGBColor[
              0.31990502084935024`, 0.4500886175471501, 0.9416569908938799], 
             UndirectedEdge[88, 159] -> 
             RGBColor[
              0.29908455143346124`, 0.42953463388170277`, 0.9404226109697026],
              UndirectedEdge[16, 61] -> 
             RGBColor[
              0.6009894787025698, 0.6863924577422298, 0.9621119961289637], 
             UndirectedEdge[138, 185] -> 
             RGBColor[
              0.6383610772019603, 0.6759659377653848, 0.6408113903471466], 
             UndirectedEdge[26, 128] -> 
             RGBColor[
              0.4259416085983718, 0.5432906066190428, 0.9483782724282598], 
             UndirectedEdge[68, 75] -> 
             RGBColor[
              0.3925029652634414, 0.514388073563715, 0.9462309197632102], 
             UndirectedEdge[10, 107] -> 
             RGBColor[
              0.5561174761397201, 0.6490180995023915, 0.9589005951651512], 
             UndirectedEdge[69, 123] -> 
             RGBColor[
              0.3350839839930212, 0.46465463794918865`, 0.9425722330502706], 
             UndirectedEdge[109, 113] -> 
             RGBColor[
              0.7152354805170444, 0.7728570948313676, 0.8758307378875978], 
             UndirectedEdge[49, 196] -> 
             RGBColor[
              0.5650956016673233, 0.6549738706331227, 0.9602432502670982], 
             UndirectedEdge[8, 26] -> 
             RGBColor[
              0.7249766215921024, 0.7796627066626294, 0.791774300447776], 
             UndirectedEdge[30, 73] -> 
             RGBColor[
              0.32473888649252547`, 0.4501432882564279, 0.9421162999176239], 
             UndirectedEdge[46, 144] -> 
             RGBColor[
              0.6006210838415194, 0.6617509454042091, 0.7003086113149737], 
             UndirectedEdge[81, 176] -> 
             RGBColor[
              0.4156147355613192, 0.5300885049804347, 0.9484445670047892], 
             UndirectedEdge[104, 181] -> 
             RGBColor[
              0.3146337614047273, 0.4464312577203967, 0.9412878521202794], 
             UndirectedEdge[65, 171] -> 
             RGBColor[
              0.2598647115990597, 0.3904646666379228, 0.9381102829389523], 
             UndirectedEdge[67, 82] -> 
             RGBColor[
              0.579890831932141, 0.6682673035499278, 0.9609834450236838], 
             UndirectedEdge[13, 63] -> 
             RGBColor[
              0.6440959308247924, 0.7083479762997478, 0.7930082282263524], 
             UndirectedEdge[153, 182] -> 
             RGBColor[
              0.32797134640847936`, 0.4578504755907525, 0.9421425857070751], 
             UndirectedEdge[87, 157] -> 
             RGBColor[
              0.4196525340184206, 0.5278119562440912, 0.949268052934834], 
             UndirectedEdge[30, 157] -> 
             RGBColor[
              0.4990835230693657, 0.602790712497432, 0.9541030589448973], 
             UndirectedEdge[64, 185] -> 
             RGBColor[
              0.6533521511349143, 0.6892073251947407, 0.6417572029555937], 
             UndirectedEdge[9, 103] -> 
             RGBColor[
              0.456527464061779, 0.5696685875100606, 0.9503586607675975], 
             UndirectedEdge[18, 117] -> 
             RGBColor[
              0.617801692200481, 0.6959592466388782, 0.9656096941895949], 
             UndirectedEdge[52, 66] -> 
             RGBColor[
              0.694717159710663, 0.7574418691363787, 0.9419704782051865], 
             UndirectedEdge[128, 162] -> 
             RGBColor[
              0.6956428829666057, 0.7546527824998602, 0.8187039753610572], 
             UndirectedEdge[23, 177] -> 
             RGBColor[
              0.576862441258146, 0.6430594412810531, 0.9305228952608382], 
             UndirectedEdge[11, 110] -> 
             RGBColor[
              0.29244324587030235`, 0.42470677175537497`, 0.9399655822700772],
              UndirectedEdge[79, 177] -> 
             RGBColor[
              0.6497325457462272, 0.7181785167770137, 0.9347266379395327], 
             UndirectedEdge[8, 166] -> 
             RGBColor[
              0.6947850317337614, 0.7535726081270702, 0.789833847158998], 
             UndirectedEdge[162, 173] -> 
             RGBColor[
              0.6490840524577183, 0.7138154383470396, 0.8157559770213014], 
             UndirectedEdge[100, 137] -> 
             RGBColor[
              0.41702714937456375`, 0.5350668256039275, 0.9479490999829046], 
             UndirectedEdge[88, 117] -> 
             RGBColor[
              0.5890107626825083, 0.6710219905646034, 0.9637751616195289], 
             UndirectedEdge[149, 168] -> 
             RGBColor[
              0.39783017575921176`, 0.5190022355417665, 0.9465703649053334], 
             UndirectedEdge[36, 110] -> 
             RGBColor[
              0.6408232398533202, 0.7094127949744692, 0.92915872243427], 
             UndirectedEdge[76, 104] -> 
             RGBColor[
              0.27417989782394747`, 0.405510834995509, 0.9389255116170394], 
             UndirectedEdge[4, 196] -> 
             RGBColor[
              0.4742599837072434, 0.5678454231818723, 0.95476472487051], 
             UndirectedEdge[61, 79] -> 
             RGBColor[
              0.5016902441413076, 0.6022836951444392, 0.9552599700843001], 
             UndirectedEdge[76, 147] -> 
             RGBColor[
              0.5048303988529736, 0.5954776486135913, 0.9572179572081329], 
             UndirectedEdge[2, 120] -> 
             RGBColor[
              0.4254627375025527, 0.5429361716709125, 0.9483310873051042], 
             UndirectedEdge[87, 176] -> 
             RGBColor[
              0.2651278970915182, 0.3959966082957308, 0.9384100135665627], 
             UndirectedEdge[142, 157] -> 
             RGBColor[
              0.4665817320786786, 0.5746392947288127, 0.952032073563176], 
             UndirectedEdge[65, 191] -> 
             RGBColor[
              0.2887324628927199, 0.420806503568706, 0.9397542586691152], 
             UndirectedEdge[73, 147] -> 
             RGBColor[
              0.5066170335170417, 0.5973555149247072, 0.9573197034091625], 
             UndirectedEdge[26, 120] -> 
             RGBColor[
              0.4469190082853662, 0.5614601758731523, 0.9497149337867289], 
             UndirectedEdge[113, 116] -> 
             RGBColor[
              0.31880145817256134`, 0.4403043845664559, 0.9419099231845985], 
             UndirectedEdge[35, 94] -> 
             RGBColor[
              0.6742306361654904, 0.525517764494446, 0.5787071644103513], 
             UndirectedEdge[31, 45] -> 
             RGBColor[
              0.23357329053298378`, 0.36283071612510165`, 0.9366130254039112],
              UndirectedEdge[52, 82] -> 
             RGBColor[
              0.5697670927973744, 0.6594986295453169, 0.9603383693180876], 
             UndirectedEdge[95, 162] -> 
             RGBColor[
              0.9143281273398283, 0.6258667451366944, 0.435424852298635], 
             UndirectedEdge[17, 73] -> 
             RGBColor[
              0.2683756730890078, 0.39941022678998395`, 0.9385949696049657], 
             UndirectedEdge[103, 152] -> 
             RGBColor[
              0.4858097501503502, 0.593441266508718, 0.9526638695930381], 
             UndirectedEdge[88, 103] -> 
             RGBColor[
              0.39503130572006806`, 0.5164499253248316, 0.9464274094112202], 
             UndirectedEdge[26, 170] -> 
             RGBColor[
              0.6950048223060541, 0.6733835797550769, 0.6082058444127632], 
             UndirectedEdge[89, 106] -> 
             RGBColor[
              0.2651224537281932, 0.3920548232562189, 0.9385538221491306], 
             UndirectedEdge[19, 74] -> 
             RGBColor[
              0.6641998066061421, 0.7309991241919499, 0.939877842127337], 
             UndirectedEdge[117, 152] -> 
             RGBColor[
              0.6797892071127905, 0.7480133317484898, 0.9700116218013469], 
             UndirectedEdge[157, 176] -> 
             RGBColor[
              0.4428723887144077, 0.552217495753393, 0.9505903893090737], 
             UndirectedEdge[49, 139] -> 
             RGBColor[
              0.36697988828825145`, 0.492281267114954, 0.9446046118675219], 
             UndirectedEdge[48, 106] -> 
             RGBColor[
              0.2686791611343635, 0.39513546444613157`, 0.938780452399979], 
             UndirectedEdge[69, 118] -> 
             RGBColor[
              0.3239502963548261, 0.4550111973123957, 0.9418628043190982], 
             UndirectedEdge[117, 200] -> 
             RGBColor[
              0.6065459994734694, 0.6862101313263065, 0.964892491402048], 
             UndirectedEdge[64, 153] -> 
             RGBColor[
              0.3188676348053495, 0.44996529816597086`, 0.9415625052538197], 
             UndirectedEdge[73, 87] -> 
             RGBColor[
              0.24530789744158038`, 0.3751645320030871, 0.9372812939075605], 
             UndirectedEdge[132, 138] -> 
             RGBColor[
              0.30526234880260206`, 0.4381804617152916, 0.9406956112179083], 
             UndirectedEdge[6, 96] -> 
             RGBColor[
              0.482786702805044, 0.5704407860153742, 0.9562582603807168], 
             UndirectedEdge[34, 65] -> 
             RGBColor[
              0.3218882815215859, 0.4501827728247778, 0.9418428121231884], 
             UndirectedEdge[2, 16] -> 
             RGBColor[
              0.46794669011181367`, 0.5778343926609814, 0.9515628938235674], 
             UndirectedEdge[21, 122] -> 
             RGBColor[
              0.2389415276081029, 0.368473073656941, 0.9369187385637442], 
             UndirectedEdge[90, 175] -> 
             RGBColor[
              0.2885299205512955, 0.4205936187259428, 0.9397427241824057], 
             UndirectedEdge[6, 179] -> 
             RGBColor[
              0.5362728931086385, 0.6266581632447847, 0.9593042197927788], 
             UndirectedEdge[8, 137] -> 
             RGBColor[
              0.7342304171293594, 0.787175354758513, 0.7925027931302389], 
             UndirectedEdge[3, 127] -> 
             RGBColor[
              0.5033133286228039, 0.5971452901803127, 0.9566151115629643], 
             UndirectedEdge[31, 65] -> 
             RGBColor[
              0.2424033737322749, 0.37211169342716743`, 0.9371158855791734], 
             UndirectedEdge[3, 71] -> 
             RGBColor[
              0.2855674300174461, 0.41747985334211857`, 0.939574014729115], 
             UndirectedEdge[146, 184] -> 
             RGBColor[
              0.6436397260338296, 0.704406037661453, 0.6788469719047507], 
             UndirectedEdge[33, 99] -> 
             RGBColor[
              0.3361428899229282, 0.4655718090435146, 0.9426397055997704], 
             UndirectedEdge[10, 130] -> 
             RGBColor[
              0.5409778976101125, 0.6359049575173876, 0.9579359146086482], 
             UndirectedEdge[112, 160] -> 
             RGBColor[
              0.4883631932299919, 0.5949063021931751, 0.9530328683717357], 
             UndirectedEdge[73, 157] -> 
             RGBColor[
              0.4230523890644699, 0.5313854194607492, 0.9494616696500717], 
             UndirectedEdge[157, 188] -> 
             RGBColor[
              0.4453989298186683, 0.5548730506459291, 0.9507342720872787], 
             UndirectedEdge[70, 132] -> 
             RGBColor[
              0.4358910788870269, 0.548488528282767, 0.9498643157257982], 
             UndirectedEdge[141, 191] -> 
             RGBColor[
              0.3728303209535135, 0.4966902522186614, 0.9450015022540368], 
             UndirectedEdge[26, 80] -> 
             RGBColor[
              0.7144639350956794, 0.7742701167368841, 0.9401064646329553], 
             UndirectedEdge[171, 199] -> 
             RGBColor[
              0.617564577308873, 0.6821596126855556, 0.8660245520567622], 
             UndirectedEdge[23, 43] -> 
             RGBColor[
              0.27012857264545054`, 0.3963908718474944, 0.9388728076198012], 
             UndirectedEdge[75, 81] -> 
             RGBColor[
              0.4639393419024993, 0.5738308075473628, 0.9514547140493577], 
             UndirectedEdge[33, 172] -> 
             RGBColor[
              0.43594836921694785`, 0.550476074548987, 0.9494253436521863], 
             UndirectedEdge[156, 166] -> 
             RGBColor[
              0.6062380319869427, 0.3254069602339108, 0.5553090182930562], 
             UndirectedEdge[151, 175] -> 
             RGBColor[
              0.6341576241624282, 0.6715478421065206, 0.6405720099149967], 
             UndirectedEdge[34, 199] -> 
             RGBColor[
              0.6795881472313992, 0.7418777188724106, 0.8697570812409984], 
             UndirectedEdge[38, 169] -> 
             RGBColor[
              0.37223171891341544`, 0.4922121101573379, 0.9452710724444953], 
             UndirectedEdge[10, 142] -> 
             RGBColor[
              0.5120399312336268, 0.6108403455065562, 0.9560920129799775], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.3145836362560368, 0.44547950167298844`, 0.9413179169731096], 
             UndirectedEdge[12, 128] -> 
             RGBColor[
              0.30282909477852, 0.4275240187463918, 0.9408535828208056], 
             UndirectedEdge[19, 172] -> 
             RGBColor[
              0.7400495167207937, 0.795154106486222, 0.9451370397508985], 
             UndirectedEdge[109, 124] -> 
             RGBColor[
              0.6304361261094571, 0.6958341362851641, 0.8705582603861001], 
             UndirectedEdge[75, 127] -> 
             RGBColor[
              0.562673040613594, 0.65248618845109, 0.9602536915493023], 
             UndirectedEdge[4, 191] -> 
             RGBColor[
              0.25948211072117067`, 0.3900625288569647, 0.9380884943849638], 
             UndirectedEdge[68, 172] -> 
             RGBColor[
              0.45506295122700996`, 0.5670321647592765, 0.9506433079155063], 
             UndirectedEdge[97, 105] -> 
             RGBColor[
              0.3944746293584633, 0.5159166056675242, 0.9464060726464368], 
             UndirectedEdge[120, 136] -> 
             RGBColor[
              0.3877056572264337, 0.5102328864617716, 0.945925239537185], 
             UndirectedEdge[117, 159] -> 
             RGBColor[
              0.5560674100748757, 0.6385490093484325, 0.9618202702511125], 
             UndirectedEdge[183, 192] -> 
             RGBColor[
              0.5313877800597152, 0.6295889796101868, 0.9564880634044604], 
             UndirectedEdge[71, 188] -> 
             RGBColor[
              0.2991290767713168, 0.43173400393850386`, 0.9403463304490894], 
             UndirectedEdge[14, 106] -> 
             RGBColor[
              0.2815333149147978, 0.4062690863821895, 0.9395995077123864], 
             UndirectedEdge[141, 194] -> 
             RGBColor[
              0.3736303718240788, 0.4975311564097806, 0.9450470639675463], 
             UndirectedEdge[50, 105] -> 
             RGBColor[
              0.4069461530062237, 0.5260415504005138, 0.9473878766726849], 
             UndirectedEdge[98, 125] -> 
             RGBColor[
              0.9365563912416639, 0.9494389576053107, 0.8827491939577609], 
             UndirectedEdge[118, 119] -> 
             RGBColor[
              0.31529932088366247`, 0.44670582902961753`, 0.9413413151243379],
              UndirectedEdge[137, 166] -> 
             RGBColor[
              0.43460244936948345`, 0.5502896670992643, 0.9490689825573533], 
             UndirectedEdge[6, 112] -> 
             RGBColor[
              0.6620832945118973, 0.734464596563714, 0.9679652514676804], 
             UndirectedEdge[65, 119] -> 
             RGBColor[
              0.28789984448900996`, 0.419931368835351, 0.9397068422827726], 
             UndirectedEdge[170, 183] -> 
             RGBColor[
              0.7877003323600087, 0.7486379707020172, 0.615503174519052], 
             UndirectedEdge[14, 131] -> 
             RGBColor[
              0.4018987419789743, 0.5225262231092407, 0.9468296103471648], 
             UndirectedEdge[9, 164] -> 
             RGBColor[
              0.3883580938620612, 0.5107517749995621, 0.9459795827484413], 
             UndirectedEdge[96, 170] -> 
             RGBColor[
              0.5608377337138294, 0.5459979328961393, 0.6000516131258001], 
             UndirectedEdge[117, 178] -> 
             RGBColor[
              0.8828942218519895, 0.9094599032522955, 0.9886924331208609], 
             UndirectedEdge[18, 24] -> 
             RGBColor[
              0.3033411481491695, 0.4286847506142527, 0.9408599495819723], 
             UndirectedEdge[18, 133] -> 
             RGBColor[
              0.3660454043777911, 0.49147186412024024`, 0.944545067379079], 
             UndirectedEdge[49, 129] -> 
             RGBColor[
              0.6409724793337612, 0.7147582713220517, 0.9676709265445474], 
             UndirectedEdge[124, 198] -> 
             RGBColor[
              0.24721217448907135`, 0.3771660479181384, 0.9373897396682898], 
             UndirectedEdge[113, 124] -> 
             RGBColor[
              0.35488926162563916`, 0.47823495409453387`, 0.9439650702041305],
              UndirectedEdge[176, 188] -> 
             RGBColor[
              0.2908742928917659, 0.4230577026975687, 0.9398762327190074], 
             UndirectedEdge[37, 97] -> 
             RGBColor[
              0.6075276323879591, 0.6905297180435448, 0.9634271225809729], 
             UndirectedEdge[77, 143] -> 
             RGBColor[
              0.5405163970945758, 0.6325858156893495, 0.9591421422680659], 
             UndirectedEdge[79, 84] -> 
             RGBColor[
              0.6465730834125509, 0.7158221949417027, 0.940074783550696], 
             UndirectedEdge[151, 199] -> 
             RGBColor[
              0.9809969495872699, 0.9518276717166227, 0.5678677873303071], 
             UndirectedEdge[48, 87] -> 
             RGBColor[
              0.30016968233212904`, 0.42823399883934604`, 0.9405737909961405],
              UndirectedEdge[27, 30] -> 
             RGBColor[
              0.37358961410004765`, 0.49800627939865305`, 0.9450257777514985],
              UndirectedEdge[5, 87] -> 
             RGBColor[
              0.5668283590816033, 0.4864644564170564, 0.5842362287905777], 
             UndirectedEdge[68, 81] -> 
             RGBColor[
              0.4714453426960753, 0.580332128172189, 0.9519329897826283], 
             UndirectedEdge[155, 172] -> 
             RGBColor[
              0.5063085219761312, 0.610083092936034, 0.954277608000639], 
             UndirectedEdge[143, 188] -> 
             RGBColor[
              0.3086906673809013, 0.4403753082225738, 0.9409424222073338], 
             UndirectedEdge[102, 180] -> 
             RGBColor[
              0.3478806911170333, 0.47573850247880656`, 0.9433876279125288], 
             UndirectedEdge[80, 136] -> 
             RGBColor[
              0.6552505840367469, 0.7230428273255034, 0.9363167703834114], 
             UndirectedEdge[66, 78] -> 
             RGBColor[
              0.6487709487417397, 0.7176455705188072, 0.9390428262708859], 
             UndirectedEdge[50, 101] -> 
             RGBColor[
              0.7394331093869653, 0.7911280713382256, 0.7706960604413569], 
             UndirectedEdge[41, 85] -> 
             RGBColor[
              0.3402023169107758, 0.4690878806676552, 0.9428983686978258], 
             UndirectedEdge[5, 30] -> 
             RGBColor[
              0.6462593481325485, 0.5614432126703972, 0.5890712348006409], 
             UndirectedEdge[32, 133] -> 
             RGBColor[
              0.3721949928796253, 0.4967983285932238, 0.9449369137205483], 
             UndirectedEdge[159, 161] -> 
             RGBColor[
              0.22390074942332883`, 0.3526642621443269, 0.9360621884969587], 
             UndirectedEdge[3, 195] -> 
             RGBColor[
              0.31981660718787, 0.4475043042710082, 0.9417431776726404], 
             UndirectedEdge[173, 180] -> 
             RGBColor[
              0.30632670256654304`, 0.4392361008796787, 0.9407585336767541], 
             UndirectedEdge[129, 141] -> 
             RGBColor[
              0.6634850716060241, 0.7342575472324979, 0.9691054090170323], 
             UndirectedEdge[53, 199] -> 
             RGBColor[
              0.7813057235288104, 0.8267749280902349, 0.8771241086804005], 
             UndirectedEdge[88, 95] -> 
             RGBColor[
              0.5828706831468575, 0.36107481803534386`, 0.5611474289530629], 
             UndirectedEdge[93, 95] -> 
             RGBColor[
              0.6322634908041147, 0.40385638547336367`, 0.5642946949806384], 
             UndirectedEdge[3, 29] -> 
             RGBColor[
              0.3058435813014061, 0.4354015715528545, 0.9408528288190166], 
             UndirectedEdge[52, 125] -> 
             RGBColor[
              0.6502087797523062, 0.7228318132321725, 0.9682256088944985], 
             UndirectedEdge[82, 136] -> 
             RGBColor[
              0.5285134365162588, 0.6237667859436681, 0.9577097228190308], 
             UndirectedEdge[116, 193] -> 
             RGBColor[
              0.5808317501723677, 0.6073652687448243, 0.6241276077453253], 
             UndirectedEdge[19, 159] -> 
             RGBColor[
              0.6180616479352068, 0.6870974651539821, 0.9370821893842757], 
             UndirectedEdge[77, 99] -> 
             RGBColor[
              0.5337791356161693, 0.6267503384213616, 0.9587128499241883], 
             UndirectedEdge[53, 196] -> 
             RGBColor[
              0.6512764786596206, 0.72641397181007, 0.9666202929653422], 
             UndirectedEdge[58, 137] -> 
             RGBColor[
              0.4317177567210531, 0.5477910913160622, 0.9488851724926288], 
             UndirectedEdge[159, 200] -> 
             RGBColor[
              0.3166197882244224, 0.4447227746434059, 0.9415399407522216], 
             UndirectedEdge[3, 62] -> 
             RGBColor[
              0.27118155365258134`, 0.4023593851654027, 0.9387547603521329], 
             UndirectedEdge[48, 157] -> 
             RGBColor[
              0.47791417395501856`, 0.5844548862970083, 0.9527541667386514], 
             UndirectedEdge[130, 168] -> 
             RGBColor[
              0.37800144454618356`, 0.5018275851860503, 0.9453068956862978], 
             UndirectedEdge[140, 180] -> 
             RGBColor[
              0.5500139511191333, 0.6393873207461201, 0.9603503604256642], 
             UndirectedEdge[146, 171] -> 
             RGBColor[
              0.6171800544079407, 0.6765952451425669, 0.6773401327492325], 
             UndirectedEdge[26, 100] -> 
             RGBColor[
              0.40777335383730673`, 0.5275541775080439, 0.9472206073004417], 
             UndirectedEdge[45, 153] -> 
             RGBColor[
              0.2799824843486005, 0.4116097213381542, 0.939255960335461], 
             UndirectedEdge[165, 177] -> 
             RGBColor[
              0.6980941986046567, 0.760066949755636, 0.9378081996951413], 
             UndirectedEdge[123, 139] -> 
             RGBColor[
              0.3439277865325684, 0.4723146952065044, 0.943135752327823], 
             UndirectedEdge[13, 34] -> 
             RGBColor[
              0.33079945118537113`, 0.4595489771422058, 0.9423502900526468], 
             UndirectedEdge[48, 72] -> 
             RGBColor[
              0.29008309543331695`, 0.4176323564821478, 0.9399993747940212], 
             UndirectedEdge[127, 191] -> 
             RGBColor[
              0.5209871637522967, 0.6157216114872788, 0.9576216103274928], 
             UndirectedEdge[58, 125] -> 
             RGBColor[
              0.6350921920233517, 0.7097385847231432, 0.9672623932914832], 
             UndirectedEdge[165, 169] -> 
             RGBColor[
              0.44985637684701185`, 0.563385792299155, 0.9500730170781553], 
             UndirectedEdge[119, 156] -> 
             RGBColor[
              0.5586394869699254, 0.28336716477227814`, 0.5523058244068176], 
             UndirectedEdge[139, 191] -> 
             RGBColor[
              0.3182873703542715, 0.4494478898180052, 0.9415260736722906], 
             UndirectedEdge[48, 81] -> 
             RGBColor[
              0.4506565208019301, 0.56232589552405, 0.9506083444343669], 
             UndirectedEdge[85, 161] -> 
             RGBColor[
              0.2763184205988479, 0.4020049192962898, 0.9392579662240572], 
             UndirectedEdge[30, 106] -> 
             RGBColor[
              0.2898485102487106, 0.4134712906465553, 0.9401293446062248], 
             UndirectedEdge[118, 195] -> 
             RGBColor[
              0.3519971708574645, 0.4793039903296804, 0.943649926361529], 
             UndirectedEdge[132, 145] -> 
             RGBColor[
              0.43061566070432267`, 0.5442057061471668, 0.9494490154819623], 
             UndirectedEdge[124, 137] -> 
             RGBColor[
              0.3720688709915666, 0.4925522046395188, 0.9452152606156133], 
             UndirectedEdge[53, 182] -> 
             RGBColor[
              0.46276463667958484`, 0.5720397589931345, 0.9515936047589425], 
             UndirectedEdge[31, 40] -> 
             RGBColor[
              0.5788036147706881, 0.5855252527342762, 0.6063723181584434], 
             UndirectedEdge[130, 157] -> 
             RGBColor[
              0.49551969845516436`, 0.5997039067396441, 0.9538759751918466], 
             UndirectedEdge[83, 166] -> 
             RGBColor[
              0.3387136962106107, 0.4653506555057204, 0.9428931431292171], 
             UndirectedEdge[76, 176] -> 
             RGBColor[
              0.26674111747349943`, 0.3976922052012729, 0.9385018840807708], 
             UndirectedEdge[100, 113] -> 
             RGBColor[
              0.39984754000863626`, 0.5207495750589425, 0.9466989095714216], 
             UndirectedEdge[53, 118] -> 
             RGBColor[
              0.45100533421364963`, 0.5618544422368685, 0.9508443124041559], 
             UndirectedEdge[18, 85] -> 
             RGBColor[
              0.380293152126953, 0.5038125471079405, 0.945452921266867], 
             UndirectedEdge[90, 177] -> 
             RGBColor[
              0.6271484640053853, 0.6959132395063923, 0.9333866098647894], 
             UndirectedEdge[55, 165] -> 
             RGBColor[
              0.35454735147606364`, 0.4795673693407832, 0.9438836544092666], 
             UndirectedEdge[9, 121] -> 
             RGBColor[
              0.38370164457806627`, 0.5067185926697118, 0.9456828779176015], 
             UndirectedEdge[70, 110] -> 
             RGBColor[
              0.4341754284507888, 0.5466852708957604, 0.9497666119715319], 
             UndirectedEdge[51, 147] -> 
             RGBColor[
              0.8796566241387123, 0.9040426560024015, 0.8566110127318876], 
             UndirectedEdge[81, 188] -> 
             RGBColor[
              0.4181412766655798, 0.5327440598729709, 0.9485884497829942], 
             UndirectedEdge[63, 132] -> 
             RGBColor[
              0.649543401600936, 0.7140736134750707, 0.7933184536282429], 
             UndirectedEdge[68, 143] -> 
             RGBColor[
              0.36199473341139676`, 0.487963376521792, 0.9442869622069681], 
             UndirectedEdge[76, 81] -> 
             RGBColor[
              0.39400810124731334`, 0.5073785623766751, 0.9472141011447575], 
             UndirectedEdge[55, 163] -> 
             RGBColor[
              0.3024830565706419, 0.4344718939212565, 0.9405661635765413], 
             UndirectedEdge[86, 94] -> 
             RGBColor[
              0.6623522747281451, 0.4359932263904994, 0.5674020444336999], 
             UndirectedEdge[3, 167] -> 
             RGBColor[
              0.2879063118569346, 0.4198652103134295, 0.9397098818713194], 
             UndirectedEdge[16, 82] -> 
             RGBColor[
              0.621589504779251, 0.7024853546793299, 0.9641652142100985], 
             UndirectedEdge[51, 107] -> 
             RGBColor[
              0.7093542310296022, 0.7668567655613381, 0.8421452060438014], 
             UndirectedEdge[53, 171] -> 
             RGBColor[
              0.40763085437988766`, 0.5182892405543791, 0.9483000867496331], 
             UndirectedEdge[78, 82] -> 
             RGBColor[
              0.5238208818284511, 0.6197023309277454, 0.9574107173837869], 
             UndirectedEdge[92, 186] -> 
             RGBColor[
              0.6980020795647335, 0.7571272336908472, 0.8452124676735815], 
             UndirectedEdge[75, 118] -> 
             RGBColor[
              0.3578178161486698, 0.4843455407267837, 0.9440208127324901], 
             UndirectedEdge[77, 83] -> 
             RGBColor[
              0.5196613109353557, 0.6120743315336377, 0.9579029026454993], 
             UndirectedEdge[42, 176] -> 
             RGBColor[
              0.31943980180680576`, 0.44921847621941324`, 0.941644453734692], 
             UndirectedEdge[20, 144] -> 
             RGBColor[
              0.25163334855538194`, 0.381812982180457, 0.9376415189908252], 
             UndirectedEdge[26, 98] -> 
             RGBColor[
              0.7239281604021084, 0.7799788161023462, 0.8636434804764435], 
             UndirectedEdge[16, 84] -> 
             RGBColor[
              0.7458723179738131, 0.7999309575394934, 0.9469268095953596], 
             UndirectedEdge[55, 175] -> 
             RGBColor[
              0.2926324919336092, 0.42490568136680384`, 0.9399763595534181], 
             UndirectedEdge[113, 128] -> 
             RGBColor[
              0.4180157947697014, 0.5364860041699415, 0.9478565746992398], 
             UndirectedEdge[142, 147] -> 
             RGBColor[
              0.5501463765312504, 0.6406093901927706, 0.9598901073222668], 
             UndirectedEdge[10, 42] -> 
             RGBColor[
              0.5194226378886564, 0.6172348749455172, 0.9565624325197648], 
             UndirectedEdge[98, 120] -> 
             RGBColor[
              0.715306924996907, 0.7725718744365586, 0.8630774710995042], 
             UndirectedEdge[195, 199] -> 
             RGBColor[
              0.6822975601726253, 0.7442244761830468, 0.8699297226377736], 
             UndirectedEdge[49, 195] -> 
             RGBColor[
              0.3861829602513427, 0.508914002874923, 0.9458282146324002], 
             UndirectedEdge[25, 43] -> 
             RGBColor[
              0.6731200978112971, 0.7377078379800979, 0.9219938314943783], 
             UndirectedEdge[91, 121] -> 
             RGBColor[
              0.27748459279171667`, 0.40864800710939975`, 0.9391260216654505],
              UndirectedEdge[8, 21] -> 
             RGBColor[
              0.5918850470349503, 0.6534074932460814, 0.7836813180940299], 
             UndirectedEdge[2, 124] -> 
             RGBColor[
              0.34135880467149615`, 0.4665155523413954, 0.9431029214515257], 
             UndirectedEdge[80, 125] -> 
             RGBColor[
              0.9270921659352349, 0.9437302582398486, 0.9592121781142727], 
             UndirectedEdge[33, 180] -> 
             RGBColor[
              0.33560394734078897`, 0.46510500406690736`, 0.9426053646550048],
              UndirectedEdge[5, 155] -> 
             RGBColor[
              0.6971243916614678, 0.60416454729487, 0.5926812880277893], 
             UndirectedEdge[179, 192] -> 
             RGBColor[
              0.3580113717171303, 0.48316631903371954`, 0.9440824614232703], 
             UndirectedEdge[59, 146] -> 
             RGBColor[
              0.6499492466503078, 0.7109746797506433, 0.6792085988563195], 
             UndirectedEdge[3, 68] -> 
             RGBColor[
              0.33314325327265126`, 0.4590471752929377, 0.9425923397768723], 
             UndirectedEdge[131, 157] -> 
             RGBColor[
              0.5085274398848316, 0.6109705585779278, 0.954704816973451], 
             UndirectedEdge[85, 200] -> 
             RGBColor[
              0.3690374593999414, 0.4940634317953688, 0.9447357184793201], 
             UndirectedEdge[23, 38] -> 
             RGBColor[
              0.22253409941291435`, 0.35122782633276595`, 0.935984359800643], 
             UndirectedEdge[92, 191] -> 
             RGBColor[
              0.3516490697634863, 0.47834411703849933`, 0.9436518516580533], 
             UndirectedEdge[97, 153] -> 
             RGBColor[
              0.3808520555368791, 0.5034738637394709, 0.9455616179227275], 
             UndirectedEdge[95, 161] -> 
             RGBColor[
              0.5076868811367251, 0.2842044462979679, 0.5567870064803191], 
             UndirectedEdge[139, 196] -> 
             RGBColor[
              0.5330652433403442, 0.6272307841429128, 0.9582023041578369], 
             UndirectedEdge[1, 94] -> 
             RGBColor[
              0.5818423316913746, 0.6709085207053024, 0.9605632440594015], 
             UndirectedEdge[189, 194] -> 
             RGBColor[
              0.33685400815271216`, 0.4656773186314265, 0.9427037065944683], 
             UndirectedEdge[42, 76] -> 
             RGBColor[
              0.29783316749279987`, 0.42650853361565355`, 0.9404139878746604],
              UndirectedEdge[84, 190] -> 
             RGBColor[
              0.6337241763026642, 0.7037892034539373, 0.9392891592692855], 
             UndirectedEdge[37, 134] -> 
             RGBColor[
              0.7403504625446278, 0.7970866753025623, 0.9747548732041665], 
             UndirectedEdge[140, 161] -> 
             RGBColor[
              0.4861300548072054, 0.5723043593747548, 0.9567099579518956], 
             UndirectedEdge[10, 51] -> 
             RGBColor[
              0.8415501788410886, 0.8742736113161871, 0.8528129183895983], 
             UndirectedEdge[146, 191] -> 
             RGBColor[
              0.6460478057016008, 0.70693708207335, 0.6789841084793955], 
             UndirectedEdge[21, 175] -> 
             RGBColor[
              0.24345894509218785`, 0.37322116585352566`, 0.9371759988065426],
              UndirectedEdge[49, 141] -> 
             RGBColor[
              0.4215228388874934, 0.5395236295156103, 0.9480800404492681], 
             UndirectedEdge[111, 177] -> 
             RGBColor[
              0.640454962828253, 0.7098992134499802, 0.9341443952875508], 
             UndirectedEdge[69, 191] -> 
             RGBColor[
              0.30944356781472426`, 0.4417878325606895, 0.9409625543947382], 
             UndirectedEdge[111, 175] -> 
             RGBColor[
              0.30183641937416317`, 0.4345795926695307, 0.9405005096051671], 
             UndirectedEdge[77, 170] -> 
             RGBColor[
              0.845760847172458, 0.7940171572474349, 0.6212751506402674], 
             UndirectedEdge[104, 154] -> 
             RGBColor[
              0.25821858946180287`, 0.3887344879014942, 0.9380165387184549], 
             UndirectedEdge[13, 138] -> 
             RGBColor[
              0.29981487802645834`, 0.43245482453996864`, 0.9403853858160177],
              UndirectedEdge[21, 67] -> 
             RGBColor[
              0.31461271349036507`, 0.4358851323172711, 0.9416719887650313], 
             UndirectedEdge[73, 197] -> 
             RGBColor[
              0.4405207848541379, 0.5455670501050641, 0.9508368457554766], 
             UndirectedEdge[67, 192] -> 
             RGBColor[
              0.4308563143627102, 0.5476078168581257, 0.9486747612532807], 
             UndirectedEdge[37, 101] -> 
             RGBColor[
              0.8745705271110198, 0.8991111063241333, 0.7825157484201628], 
             UndirectedEdge[6, 44] -> 
             RGBColor[
              0.5228687209526169, 0.6125695284352051, 0.9585408720181889], 
             UndirectedEdge[75, 89] -> 
             RGBColor[
              0.3681574359631259, 0.4933011997256632, 0.9446796441641003], 
             UndirectedEdge[76, 188] -> 
             RGBColor[
              0.26926765857776, 0.400347760093809, 0.9386457668589758], 
             UndirectedEdge[42, 71] -> 
             RGBColor[
              0.3276945856863567, 0.4578947774603484, 0.942114551464774], 
             UndirectedEdge[6, 192] -> 
             RGBColor[
              0.6001058177124617, 0.6832939039986183, 0.9633222818021829], 
             UndirectedEdge[2, 100] -> 
             RGBColor[
              0.3863170830544933, 0.509030173305804, 0.945836760818817], 
             UndirectedEdge[7, 8] -> 
             RGBColor[
              0.6140672649012013, 0.6767224106573558, 0.7849445625858622], 
             UndirectedEdge[69, 92] -> 
             RGBColor[
              0.3594674268309399, 0.48577435058792245`, 0.9441259244664708], 
             UndirectedEdge[104, 160] -> 
             RGBColor[
              0.3670762245142802, 0.49185428343105514`, 0.9446294394965709], 
             UndirectedEdge[17, 30] -> 
             RGBColor[
              0.3444068070939036, 0.47081551982666675`, 0.9432363588997913], 
             UndirectedEdge[88, 164] -> 
             RGBColor[
              0.32686193552035026`, 0.4575331128143332, 0.942048331392064], 
             UndirectedEdge[43, 60] -> 
             RGBColor[
              0.6731845563133776, 0.7377344932272161, 0.9209255873016498], 
             UndirectedEdge[149, 197] -> 
             RGBColor[
              0.5328168254578606, 0.6310601877396752, 0.9565146205162871], 
             UndirectedEdge[167, 197] -> 
             RGBColor[
              0.4709344502231151, 0.577460784609954, 0.952571530286765], 
             UndirectedEdge[54, 127] -> 
             RGBColor[
              0.8103803374462504, 0.8522829592789563, 0.9816051867539581], 
             UndirectedEdge[107, 147] -> 
             RGBColor[
              0.5942239214373436, 0.678787144188606, 0.9626986895074404], 
             UndirectedEdge[78, 113] -> 
             RGBColor[
              0.38370852411515677`, 0.5067707706625353, 0.9456705457498604], 
             UndirectedEdge[81, 87] -> 
             RGBColor[
              0.39239488086533214`, 0.505682965471133, 0.9471222306305493], 
             UndirectedEdge[83, 179] -> 
             RGBColor[
              0.28822438778032156`, 0.4202724844117526, 0.939725324543094], 
             UndirectedEdge[82, 198] -> 
             RGBColor[
              0.4721238866099531, 0.5671205667295519, 0.954402388803714], 
             UndirectedEdge[30, 107] -> 
             RGBColor[
              0.4123457744128274, 0.5315749175203266, 0.9474952860159018], 
             UndirectedEdge[47, 134] -> 
             RGBColor[
              0.8180306448176595, 0.8585026064697492, 0.9823031683398854], 
             UndirectedEdge[5, 142] -> 
             RGBColor[
              0.6137575571418613, 0.5332917949017779, 0.5870002494189197], 
             UndirectedEdge[169, 190] -> 
             RGBColor[
              0.38864581687869554`, 0.509464367832767, 0.9462058310411361], 
             UndirectedEdge[121, 152] -> 
             RGBColor[
              0.4129839306666375, 0.5304912716683692, 0.9479880867430421], 
             UndirectedEdge[31, 64] -> 
             RGBColor[
              0.2724584409897327, 0.40118629295291824`, 0.9389195703222699], 
             UndirectedEdge[105, 134] -> 
             RGBColor[
              0.527297459515132, 0.6224735629265418, 0.9577338232696305], 
             UndirectedEdge[83, 192] -> 
             RGBColor[
              0.35205731238414484`, 0.4769082251655862, 0.9437433865524982], 
             UndirectedEdge[77, 112] -> 
             RGBColor[
              0.6514257716716001, 0.7261388587207003, 0.966903009191173], 
             UndirectedEdge[195, 196] -> 
             RGBColor[
              0.5522683153034355, 0.6438635199028818, 0.9594259069227153], 
             UndirectedEdge[92, 171] -> 
             RGBColor[
              0.3227813184698261, 0.4480022801077161, 0.9420078759278904], 
             UndirectedEdge[166, 183] -> 
             RGBColor[
              0.518044163886181, 0.618031409950321, 0.9556378199811792], 
             UndirectedEdge[139, 195] -> 
             RGBColor[
              0.3541526019243636, 0.48117091638471304`, 0.943787268523139], 
             UndirectedEdge[177, 190] -> 
             RGBColor[
              0.6368836386363403, 0.7061455252892481, 0.9339410136581221], 
             UndirectedEdge[29, 149] -> 
             RGBColor[
              0.38935472790480097`, 0.5116612285986711, 0.9460303168625945], 
             UndirectedEdge[119, 155] -> 
             RGBColor[
              0.4012300407475553, 0.5197992900433062, 0.9471857222401907], 
             UndirectedEdge[12, 162] -> 
             RGBColor[
              0.6021290042389496, 0.6644627055471062, 0.8130819564890115], 
             UndirectedEdge[85, 173] -> 
             RGBColor[
              0.3371009268326341, 0.46589118718148115`, 0.9427194400344114], 
             UndirectedEdge[92, 141] -> 
             RGBColor[
              0.4228541799697291, 0.5406767702458943, 0.9481648723257694], 
             UndirectedEdge[5, 29] -> 
             RGBColor[
              0.6185791489411012, 0.5374680153780294, 0.587307476984801], 
             UndirectedEdge[51, 87] -> 
             RGBColor[
              0.6183474880632509, 0.6818516730807813, 0.8365726032302857], 
             UndirectedEdge[145, 153] -> 
             RGBColor[
              0.4292298727741162, 0.5427491551684902, 0.9493700969094265], 
             UndirectedEdge[118, 191] -> 
             RGBColor[
              0.31613193928737243`, 0.4475809637629726, 0.9413887315106806], 
             UndirectedEdge[117, 164] -> 
             RGBColor[
              0.5838447941617647, 0.6665474882810628, 0.9634459906734738], 
             UndirectedEdge[145, 185] -> 
             RGBColor[
              0.7637143891036811, 0.78199118219726, 0.6495647946112005], 
             UndirectedEdge[99, 137] -> 
             RGBColor[
              0.3922769062870224, 0.5136294090248872, 0.946372036379147], 
             UndirectedEdge[48, 176] -> 
             RGBColor[
              0.3233895370281161, 0.45263953834864784`, 0.9418961273703802], 
             UndirectedEdge[50, 144] -> 
             RGBColor[
              0.34661641212904193`, 0.46450661449159336`, 0.9438835178822209],
              UndirectedEdge[3, 53] -> 
             RGBColor[
              0.4188247705440551, 0.5300547561781963, 0.9489375637152675], 
             UndirectedEdge[169, 177] -> 
             RGBColor[
              0.7265600607586471, 0.7840437251056251, 0.9398096079046905], 
             UndirectedEdge[20, 135] -> 
             RGBColor[
              0.2894400972236981, 0.421550272117172, 0.9397945573974134], 
             UndirectedEdge[166, 170] -> 
             RGBColor[
              0.664813232447713, 0.6472934812195177, 0.6062653911239853], 
             UndirectedEdge[17, 42] -> 
             RGBColor[
              0.319287722758246, 0.44905863149700836`, 0.9416357930578574], 
             UndirectedEdge[129, 195] -> 
             RGBColor[
              0.6281451929698734, 0.7036479205918108, 0.9668535832001646], 
             UndirectedEdge[74, 93] -> 
             RGBColor[
              0.3946155177616537, 0.5162178603576906, 0.9463655297403395], 
             UndirectedEdge[37, 45] -> 
             RGBColor[
              0.5066580611996805, 0.5986655756422281, 0.9571214649937063], 
             UndirectedEdge[49, 92] -> 
             RGBColor[
              0.4003415876974662, 0.5211774943354481, 0.9467303898532846], 
             UndirectedEdge[163, 177] -> 
             RGBColor[
              0.646029903699235, 0.7149714743361094, 0.9344907088624161], 
             UndirectedEdge[6, 45] -> 
             RGBColor[
              0.5182734438717784, 0.6077396008658489, 0.9582791777865385], 
             UndirectedEdge[6, 166] -> 
             RGBColor[
              0.5867622015389276, 0.6717363343387526, 0.9624720383789018], 
             UndirectedEdge[65, 127] -> 
             RGBColor[
              0.5080944158977458, 0.6021705160447184, 0.9568873874102874], 
             UndirectedEdge[15, 59] -> 
             RGBColor[
              0.2765619217484905, 0.4079514290438023, 0.9390634734422132], 
             UndirectedEdge[100, 136] -> 
             RGBColor[
              0.34856000277837423`, 0.47632688809666324`, 0.9434309130508978],
              UndirectedEdge[83, 183] -> 
             RGBColor[
              0.4616007961229064, 0.5666951449882198, 0.9521309265242839], 
             UndirectedEdge[53, 119] -> 
             RGBColor[
              0.4356659872698379, 0.5477559427518073, 0.9498966460934533], 
             UndirectedEdge[5, 68] -> 
             RGBColor[
              0.6458788209123465, 0.5611136191181125, 0.5890469879426566], 
             UndirectedEdge[49, 54] -> 
             RGBColor[
              0.6397109023752043, 0.7137523240998928, 0.9675505962080172], 
             UndirectedEdge[153, 185] -> 
             RGBColor[
              0.6362699363871791, 0.6737680161830641, 0.6406923029713104], 
             UndirectedEdge[101, 144] -> 
             RGBColor[
              0.6011877832043422, 0.6629630580391923, 0.7619903396951628], 
             UndirectedEdge[19, 102] -> 
             RGBColor[
              0.6781576933169834, 0.7430887441170964, 0.9407672263260771], 
             UndirectedEdge[102, 172] -> 
             RGBColor[
              0.4482251129931922, 0.5611095729608861, 0.9502076069097103], 
             UndirectedEdge[102, 140] -> 
             RGBColor[
              0.5884665495914818, 0.672693028859074, 0.9628005259980245], 
             UndirectedEdge[71, 107] -> 
             RGBColor[
              0.3643894239374203, 0.4896780020172227, 0.9444527141101604], 
             UndirectedEdge[5, 168] -> 
             RGBColor[
              0.6270545967955121, 0.5448090223211246, 0.5878475250275398], 
             UndirectedEdge[79, 122] -> 
             RGBColor[
              0.30659658480805246`, 0.4381108037999796, 0.9408254920143506], 
             UndirectedEdge[136, 198] -> 
             RGBColor[
              0.2807239916663968, 0.40976631950206244`, 0.9393942206492637], 
             UndirectedEdge[97, 135] -> 
             RGBColor[
              0.37195163714959767`, 0.4941189596953187, 0.945054752262561], 
             UndirectedEdge[19, 164] -> 
             RGBColor[
              0.6458390320220958, 0.7150959440866124, 0.9387079098066371], 
             UndirectedEdge[118, 139] -> 
             RGBColor[
              0.3327940988943733, 0.46267125456971137`, 0.9424263235966506], 
             UndirectedEdge[26, 137] -> 
             RGBColor[
              0.46479403922782453`, 0.5763797656348235, 0.9510094358461312], 
             UndirectedEdge[142, 168] -> 
             RGBColor[
              0.34906347816969785`, 0.47676297317521876`, 0.9434629940576271],
              UndirectedEdge[3, 194] -> 
             RGBColor[
              0.2847514264883433, 0.41662218189541944`, 0.9395275445353016], 
             UndirectedEdge[65, 195] -> 
             RGBColor[
              0.324597694462812, 0.45252953013541386`, 0.9420154535199636], 
             UndirectedEdge[73, 107] -> 
             RGBColor[
              0.3363146404079316, 0.46016962448364385`, 0.9428538967210762], 
             UndirectedEdge[162, 172] -> 
             RGBColor[
              0.7525298644120189, 0.8023832023152933, 0.8227548846818974], 
             UndirectedEdge[68, 140] -> 
             RGBColor[
              0.5953043878252996, 0.6786156206574643, 0.9632362270038204], 
             UndirectedEdge[38, 165] -> 
             RGBColor[
              0.34376585675942506`, 0.4682353348073489, 0.9432696642349461], 
             UndirectedEdge[86, 92] -> 
             RGBColor[
              0.6187257455264976, 0.3991729598650161, 0.5643550597048926], 
             UndirectedEdge[90, 115] -> 
             RGBColor[
              0.3191520165976721, 0.44815108777964463`, 0.9416560718193884], 
             UndirectedEdge[11, 70] -> 
             RGBColor[
              0.4254929792755401, 0.5375594663135008, 0.949272159335534], 
             UndirectedEdge[54, 123] -> 
             RGBColor[
              0.6166588006195213, 0.693785752191443, 0.9660817366683183], 
             UndirectedEdge[107, 176] -> 
             RGBColor[
              0.35613464005786943`, 0.48100170077628757`, 0.9439826163800784],
              UndirectedEdge[30, 76] -> 
             RGBColor[
              0.32295225182845744`, 0.44826542194531194`, 0.9420145537165943],
              UndirectedEdge[129, 191] -> 
             RGBColor[
              0.5922799613997813, 0.6719248940251029, 0.9645923883493162], 
             UndirectedEdge[7, 125] -> 
             RGBColor[
              0.5572591178392221, 0.6353869630366309, 0.9625569187830719], 
             UndirectedEdge[3, 155] -> 
             RGBColor[
              0.38438882402177255`, 0.5020981034696952, 0.946226639862005], 
             UndirectedEdge[54, 118] -> 
             RGBColor[
              0.6055251129813262, 0.6841423115546501, 0.9653723079371459], 
             UndirectedEdge[4, 171] -> 
             RGBColor[
              0.23061435942751046`, 0.35972069192618145`, 0.9364445186548008],
              UndirectedEdge[167, 189] -> 
             RGBColor[
              0.3400088935213035, 0.4689203470494365, 0.9428860439304863], 
             UndirectedEdge[42, 81] -> 
             RGBColor[
              0.4467067855806197, 0.5589048333948154, 0.9503566707986787], 
             UndirectedEdge[5, 129] -> 
             RGBColor[
              0.8873416939099839, 0.7554150165433116, 0.6100405377505721], 
             UndirectedEdge[115, 133] -> 
             RGBColor[
              0.35064301668970427`, 0.47813109005133403`, 0.9435636408553907],
              UndirectedEdge[92, 146] -> 
             RGBColor[
              0.6960716647178165, 0.750923600100583, 0.6821474785511282], 
             UndirectedEdge[65, 151] -> 
             RGBColor[
              0.6232970838774565, 0.6601327256689898, 0.6399535182124971], 
             UndirectedEdge[45, 156] -> 
             RGBColor[
              0.5377492743197935, 0.26141022676100706`, 0.5511161577006928], 
             UndirectedEdge[74, 172] -> 
             RGBColor[
              0.43426722628235087`, 0.5490199530357398, 0.9493182227109702], 
             UndirectedEdge[31, 138] -> 
             RGBColor[
              0.25746736705677875`, 0.3879449055235624, 0.9379737577138227], 
             UndirectedEdge[116, 198] -> 
             RGBColor[
              0.21112437103599357`, 0.3392354783900604, 0.935334592648758], 
             UndirectedEdge[42, 142] -> 
             RGBColor[
              0.34314914517107664`, 0.471640275194833, 0.9430861379887943], 
             UndirectedEdge[10, 129] -> 
             RGBColor[0.7856240680017492, 0.83296356714809, 0.97913230131163],
              UndirectedEdge[3, 141] -> 
             RGBColor[
              0.3551564858240207, 0.47811393091169535`, 0.9439950034895083], 
             UndirectedEdge[161, 162] -> 
             RGBColor[
              0.588301546223932, 0.6499291704618484, 0.8122945032109472], 
             UndirectedEdge[6, 77] -> 
             RGBColor[
              0.7677098162636726, 0.8184600103666698, 0.977481797895184], 
             UndirectedEdge[98, 113] -> 
             RGBColor[
              0.7160023465734379, 0.7731742136532449, 0.8631217827474235], 
             UndirectedEdge[3, 139] -> 
             RGBColor[
              0.30061353522477874`, 0.43087156851103914`, 0.9405195749077621],
              UndirectedEdge[34, 138] -> 
             RGBColor[
              0.3369522748460897, 0.4660159849211728, 0.9427006842578378], 
             UndirectedEdge[22, 72] -> 
             RGBColor[
              0.2577740196341881, 0.38826721682531595`, 0.9379912211244545], 
             UndirectedEdge[34, 40] -> 
             RGBColor[
              0.658288522559999, 0.6635963321318867, 0.6110992447024585], 
             UndirectedEdge[41, 74] -> 
             RGBColor[
              0.333922804406192, 0.4636488825536602, 0.9424982437137885], 
             UndirectedEdge[141, 146] -> 
             RGBColor[
              0.7172529159078437, 0.7692697352807452, 0.6834971291471117], 
             UndirectedEdge[90, 111] -> 
             RGBColor[
              0.2928055443173462, 0.42508757039426626`, 0.9399862146306638], 
             UndirectedEdge[66, 82] -> 
             RGBColor[
              0.8448633983731038, 0.8790642727622193, 0.95434999986058], 
             UndirectedEdge[119, 151] -> 
             RGBColor[
              0.6353572133282973, 0.6728086863781951, 0.6406403247433599], 
             UndirectedEdge[4, 139] -> 
             RGBColor[
              0.2761442703281715, 0.40515281966370353`, 0.9391260864709337], 
             UndirectedEdge[165, 175] -> 
             RGBColor[
              0.3594756551505669, 0.48474732897518663`, 0.9441643140127576], 
             UndirectedEdge[127, 139] -> 
             RGBColor[
              0.5376493233592975, 0.6308119022940176, 0.9586592024134628], 
             UndirectedEdge[85, 117] -> 
             RGBColor[
              0.6084850812503948, 0.6878896665003954, 0.965016047978211], 
             UndirectedEdge[141, 155] -> 
             RGBColor[
              0.4732677693575081, 0.5830070779840564, 0.9517461592942495], 
             UndirectedEdge[168, 189] -> 
             RGBColor[
              0.36642161082018576`, 0.4917977152319569, 0.9445690389209221], 
             UndirectedEdge[24, 175] -> 
             RGBColor[
              0.25731666441470613`, 0.38778650749164467`, 0.9379651754213014],
              UndirectedEdge[106, 176] -> 
             RGBColor[
              0.23363737589375266`, 0.36289807390251627`, 0.9366166749704012],
              UndirectedEdge[40, 53] -> 
             RGBColor[
              0.7600060988574103, 0.7484935413497109, 0.6184662721418606], 
             UndirectedEdge[27, 155] -> 
             RGBColor[
              0.42445465762896695`, 0.5407276140231259, 0.9486358309786469], 
             UndirectedEdge[33, 77] -> 
             RGBColor[
              0.5594160477301343, 0.6489557431458091, 0.9603464112942588], 
             UndirectedEdge[67, 137] -> 
             RGBColor[
              0.4569580835847742, 0.5696529938297026, 0.9504934638012403], 
             UndirectedEdge[68, 129] -> 
             RGBColor[
              0.6414718390546548, 0.7151907916137403, 0.9677027453043963], 
             UndirectedEdge[137, 192] -> 
             RGBColor[
              0.4479460655430176, 0.5618472367591301, 0.9499192259806344], 
             UndirectedEdge[58, 128] -> 
             RGBColor[
              0.3928653260916004, 0.5147019323002815, 0.9462540090747573], 
             UndirectedEdge[55, 90] -> 
             RGBColor[
              0.28360161687679225`, 0.4154136590915394, 0.9394620645789147], 
             UndirectedEdge[26, 82] -> 
             RGBColor[
              0.5877267875751914, 0.6749940753550487, 0.9614994170685747], 
             UndirectedEdge[43, 165] -> 
             RGBColor[
              0.39136032999196124`, 0.5133983803220774, 0.9461581120541042], 
             UndirectedEdge[123, 199] -> 
             RGBColor[
              0.6720727447808301, 0.735368255004838, 0.8692782064424576], 
             UndirectedEdge[34, 45] -> 
             RGBColor[
              0.31305819832229476`, 0.440901795522712, 0.9413399519479263], 
             UndirectedEdge[133, 178] -> 
             RGBColor[
              0.6311379340292997, 0.7049725207336576, 0.967627806310345], 
             UndirectedEdge[29, 189] -> 
             RGBColor[
              0.35794616296577497`, 0.4844567082888616, 0.9440289908781834], 
             UndirectedEdge[91, 164] -> 
             RGBColor[
              0.2821410420757116, 0.41268118943925014`, 0.9394227264962902], 
             UndirectedEdge[116, 124] -> 
             RGBColor[
              0.23400210376497393`, 0.36328142602025254`, 0.9366374456831008],
              UndirectedEdge[80, 113] -> 
             RGBColor[
              0.7065381212670089, 0.7674655142877826, 0.9395847669039353], 
             UndirectedEdge[10, 75] -> 
             RGBColor[
              0.536655194210536, 0.6321608490980646, 0.9576604757704438], 
             UndirectedEdge[74, 180] -> 
             RGBColor[
              0.333922804406192, 0.4636488825536602, 0.9424982437137885], 
             UndirectedEdge[27, 149] -> 
             RGBColor[
              0.3898545206988745, 0.5120941239965814, 0.9460621632174835], 
             UndirectedEdge[4, 49] -> 
             RGBColor[
              0.3081746286551506, 0.43289590615391355`, 0.9411670325801951], 
             UndirectedEdge[9, 152] -> 
             RGBColor[
              0.48430250681308695`, 0.5922176184669891, 0.9525452138763144], 
             UndirectedEdge[19, 85] -> 
             RGBColor[
              0.6704793191107259, 0.736438122305945, 0.9402779671113741], 
             UndirectedEdge[189, 197] -> 
             RGBColor[
              0.5014082605188346, 0.6038556674298657, 0.9545132945318759], 
             UndirectedEdge[69, 195] -> 
             RGBColor[
              0.3453087993848164, 0.4735108591273973, 0.9432237492455865], 
             UndirectedEdge[75, 191] -> 
             RGBColor[
              0.343311087608568, 0.4711221759750775, 0.9431205628081301], 
             UndirectedEdge[73, 75] -> 
             RGBColor[
              0.3168523584787475, 0.4433123740793169, 0.9416137773263689], 
             UndirectedEdge[68, 188] -> 
             RGBColor[
              0.34670490002652193`, 0.473301325889323, 0.9433646554968467], 
             UndirectedEdge[4, 123] -> 
             RGBColor[
              0.28512252689946754`, 0.41292933424546385`, 0.9396981730404961],
              UndirectedEdge[7, 84] -> 
             RGBColor[
              0.6011002440788524, 0.6694993822099387, 0.937431274591922], 
             UndirectedEdge[171, 195] -> 
             RGBColor[
              0.30862269102370254`, 0.43573878864719096`, 0.941105700707006], 
             UndirectedEdge[62, 167] -> 
             RGBColor[
              0.2928103250212307, 0.425019639081498, 0.9399891581661888], 
             UndirectedEdge[91, 152] -> 
             RGBColor[
              0.3780854550267373, 0.49414703290667705`, 0.9459883576241633], 
             UndirectedEdge[38, 90] -> 
             RGBColor[
              0.2728201221601536, 0.4040816245581051, 0.9388480744045942], 
             UndirectedEdge[3, 118] -> 
             RGBColor[
              0.29845810415787966`, 0.4290046424560065, 0.9403822327461521], 
             UndirectedEdge[143, 181] -> 
             RGBColor[
              0.32501135554341476`, 0.4559302334511658, 0.9419304140723372], 
             UndirectedEdge[20, 50] -> 
             RGBColor[
              0.38987867473800497`, 0.5099779954794903, 0.9463472397370192], 
             UndirectedEdge[128, 136] -> 
             RGBColor[
              0.3667282575394394, 0.49206331720766217`, 0.9445885781787159], 
             UndirectedEdge[19, 161] -> 
             RGBColor[
              0.575821198532707, 0.6427000746327771, 0.9346766582799483], 
             UndirectedEdge[19, 140] -> 
             RGBColor[
              0.8802909533190834, 0.9067375623844098, 0.9577299588392125], 
             UndirectedEdge[39, 159] -> 
             RGBColor[
              0.5512687850348361, 0.6347227159967117, 0.9613625731110103], 
             UndirectedEdge[87, 154] -> 
             RGBColor[
              0.22755995441536772`, 0.35651031859795634`, 0.9362705748079465],
              UndirectedEdge[104, 143] -> 
             RGBColor[
              0.31360290662708873`, 0.44553838312427374`, 0.9412221669653975],
              UndirectedEdge[6, 183] -> 
             RGBColor[
              0.7096493014512233, 0.7730808238212521, 0.9717098217739687], 
             UndirectedEdge[17, 89] -> 
             RGBColor[
              0.3196807505733861, 0.4493990524363303, 0.9416608364426972], 
             UndirectedEdge[131, 176] -> 
             RGBColor[
              0.3540028029579292, 0.47915521062956745`, 0.9438467776051798], 
             UndirectedEdge[44, 143] -> 
             RGBColor[
              0.2956753017835201, 0.42669533375788476`, 0.9402012163910709], 
             UndirectedEdge[140, 173] -> 
             RGBColor[
              0.5469125610409915, 0.636190627259946, 0.9601714317622498], 
             UndirectedEdge[123, 195] -> 
             RGBColor[
              0.3631308584956596, 0.4889474309664734, 0.9443593550927014], 
             UndirectedEdge[96, 125] -> 
             RGBColor[
              0.5340013859378985, 0.6109416121829669, 0.9612324253580226], 
             UndirectedEdge[95, 159] -> 
             RGBColor[
              0.5499273305392249, 0.3286018368191729, 0.5591925375846465], 
             UndirectedEdge[171, 191] -> 
             RGBColor[
              0.27275745945361046`, 0.4040157620804831, 0.9388445058561578], 
             UndirectedEdge[124, 187] -> 
             RGBColor[
              0.47198372140188916`, 0.5731847575488214, 0.9534110328861782], 
             UndirectedEdge[54, 191] -> 
             RGBColor[
              0.5910183844412245, 0.670918946802944, 0.9644720580127859], 
             UndirectedEdge[24, 55] -> 
             RGBColor[
              0.2523883607402029, 0.38260654785724124`, 0.9376845158178103], 
             UndirectedEdge[61, 126] -> 
             RGBColor[
              0.7202117426790922, 0.7813541542836661, 0.9727476338150072], 
             UndirectedEdge[46, 101] -> 
             RGBColor[
              0.9934377810994428, 0.9883724022508413, 0.5271211538741096], 
             UndirectedEdge[158, 176] -> 
             RGBColor[
              0.3021853750853173, 0.4342735590259628, 0.9405450169214893], 
             UndirectedEdge[91, 200] -> 
             RGBColor[
              0.3048422473874163, 0.4323438324844938, 0.9408692272248644], 
             UndirectedEdge[29, 129] -> 
             RGBColor[
              0.6141721670834095, 0.6915451878736572, 0.9659632343465406], 
             UndirectedEdge[37, 47] -> 
             RGBColor[
              0.8328167560328059, 0.870053628929629, 0.9837769097217458], 
             UndirectedEdge[25, 38] -> 
             RGBColor[
              0.6255256245787609, 0.6925447924653694, 0.9191053836752203], 
             UndirectedEdge[95, 173] -> 
             RGBColor[
              0.5684693873705113, 0.3480907141831593, 0.5602484802906733], 
             UndirectedEdge[86, 174] -> 
             RGBColor[
              0.5381048985913309, 0.3230270675738846, 0.5594492364353632], 
             UndirectedEdge[4, 146] -> 
             RGBColor[
              0.6039047056755009, 0.6626420119190484, 0.6765841212780387], 
             UndirectedEdge[114, 186] -> 
             RGBColor[
              0.6776256789359905, 0.7394782196139043, 0.8439141014436615], 
             UndirectedEdge[155, 199] -> 
             RGBColor[
              0.7468697770065278, 0.7988182753817338, 0.8744131848271379], 
             UndirectedEdge[114, 194] -> 
             RGBColor[
              0.3320727200053087, 0.4615360071526754, 0.9423990471416429], 
             UndirectedEdge[59, 186] -> 
             RGBColor[
              0.6518796614972249, 0.7171783133409075, 0.8422735879787728], 
             UndirectedEdge[99, 193] -> 
             RGBColor[
              0.6371275889209012, 0.6663730426582706, 0.6273395305283908], 
             UndirectedEdge[109, 136] -> 
             RGBColor[
              0.6639479432867824, 0.7284344078690882, 0.872562741367074], 
             UndirectedEdge[50, 134] -> 
             RGBColor[
              0.6052130448205733, 0.6891036403166546, 0.9629351852253605], 
             UndirectedEdge[112, 183] -> 
             RGBColor[
              0.5933652568591508, 0.6807596721752825, 0.9611310330699577], 
             UndirectedEdge[42, 73] -> 
             RGBColor[
              0.29961980215686795`, 0.4283863999267695, 0.94051573407569], 
             UndirectedEdge[42, 147] -> 
             RGBColor[
              0.55752908318628, 0.6470039196317316, 0.9603605268620541], 
             UndirectedEdge[87, 131] -> 
             RGBColor[
              0.33078294826194204`, 0.45474967112026565`, 0.9425244412309399],
              UndirectedEdge[1, 11] -> 
             RGBColor[
              0.47925973644740294`, 0.5807134202335107, 0.9538442132827409], 
             UndirectedEdge[30, 81] -> 
             RGBColor[
              0.47182586991627723`, 0.5806617217244738, 0.9519572366406126], 
             UndirectedEdge[154, 188] -> 
             RGBColor[
              0.25330635021561543`, 0.38357141299979425`, 0.9377367939603913],
              UndirectedEdge[83, 156] -> 
             RGBColor[
              0.549794664223668, 0.2740706952718096, 0.5518021248361609], 
             UndirectedEdge[5, 107] -> 
             RGBColor[
              0.6578351020479545, 0.5714695488976131, 0.5898088316040934], 
             UndirectedEdge[93, 180] -> 
             RGBColor[
              0.37012080600014646`, 0.49500177216988306`, 0.9448047483667193],
              UndirectedEdge[10, 17] -> 
             RGBColor[
              0.48817850882079616`, 0.5882587018087316, 0.9546416680490406], 
             UndirectedEdge[75, 141] -> 
             RGBColor[
              0.41451619781481086`, 0.5334548291824726, 0.9476335834758463], 
             UndirectedEdge[123, 141] -> 
             RGBColor[
              0.39847073713181036`, 0.5195570576071606, 0.9466111809095692], 
             UndirectedEdge[40, 119] -> 
             RGBColor[
              0.6243000855274232, 0.6333449281424599, 0.6089632748620426], 
             UndirectedEdge[16, 80] -> 
             RGBColor[
              0.7483266522997389, 0.8017613960611653, 0.9427722617744793], 
             UndirectedEdge[88, 180] -> 
             RGBColor[
              0.32072799834288923`, 0.45222020473186325`, 0.9416574823391438],
              UndirectedEdge[24, 41] -> 
             RGBColor[
              0.2632503129329923, 0.39396008417396744`, 0.9383053970129311], 
             UndirectedEdge[4, 119] -> 
             RGBColor[
              0.2586494923174607, 0.38918739412360964`, 0.938041077998621], 
             UndirectedEdge[99, 136] -> 
             RGBColor[
              0.3238097596908328, 0.4548894715176229, 0.9418538494471402], 
             UndirectedEdge[10, 194] -> 
             RGBColor[
              0.49576936821980394`, 0.5962371763253725, 0.955073956262144], 
             UndirectedEdge[96, 102] -> 
             RGBColor[
              0.28676967804775, 0.4115700172064126, 0.9399051370373156], 
             UndirectedEdge[9, 88] -> 
             RGBColor[
              0.39352406238280474`, 0.5152262772831027, 0.9463087536944965], 
             UndirectedEdge[55, 108] -> 
             RGBColor[
              0.28154424472430395`, 0.41325123051434554`, 0.9393449002784398],
              UndirectedEdge[62, 197] -> 
             RGBColor[
              0.4542096920187618, 0.5599549594619272, 0.9516164087675785], 
             UndirectedEdge[147, 168] -> 
             RGBColor[
              0.5634434161849011, 0.6521266176121174, 0.960737382930887], 
             UndirectedEdge[51, 106] -> 
             RGBColor[
              0.5868569668654854, 0.6487531386875668, 0.8347792646341243], 
             UndirectedEdge[123, 155] -> 
             RGBColor[
              0.42770307532956214`, 0.5435412301651604, 0.9488428172820658], 
             UndirectedEdge[75, 142] -> 
             RGBColor[
              0.36038170149295623`, 0.48656624934738035`, 0.9441841812394731],
              UndirectedEdge[31, 182] -> 
             RGBColor[
              0.28156215259286266`, 0.40907147037769986`, 0.9394996507755253],
              UndirectedEdge[65, 140] -> 
             RGBColor[
              0.5332197623158754, 0.6217986276262666, 0.9593916471315349]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 71 -> 
             RGBColor[
              0.3048573195466071, 0.4377547502869029, 0.9406725454009665], 10 -> 
             RGBColor[
              0.6883134239512065, 0.7564349452572404, 0.9695683075109481], 68 -> 
             RGBColor[
              0.4000089660570174, 0.5208893941885412, 0.9467091954964809], 
             155 -> RGBColor[
              0.5025001075552599, 0.6069912505420562, 0.9539777956667462], 
             132 -> 
             RGBColor[
              0.3045569959180272, 0.4374390911116476, 0.9406554424146079], 26 -> 
             RGBColor[
              0.4555402436905675, 0.56886711753894, 0.9502809431636683], 29 -> 
             RGBColor[
              0.34540962211452697`, 0.4735981867083749, 0.9432301735807695], 
             113 -> RGBColor[
              0.43968861603322656`, 0.5552579126407372, 0.9492375477056282], 
             50 -> RGBColor[
              0.484861738311665, 0.5926716277906267, 0.9525892386284149], 173 -> 
             RGBColor[
              0.30322531248840134`, 0.43603940739350466`, 0.9405796050133397],
              192 -> RGBColor[
              0.4218442963209536, 0.5398020597875531, 0.9481005234326746], 
             165 -> RGBColor[
              0.4213905146930214, 0.539409016949166, 0.9480716088686061], 92 -> 
             RGBColor[
              0.40167292877970195`, 0.5223306350657323, 0.9468152217297859], 
             11 -> RGBColor[
              0.28376079669505366`, 0.4155809671731155, 0.9394711296340792], 
             137 -> RGBColor[
              0.47404783476508155`, 0.5838924137307071, 0.9517379285285941], 
             120 -> RGBColor[
              0.43829777288016486`, 0.5540532342073646, 0.9491489244097895], 
             51 -> RGBColor[
              0.9947869337309708, 0.9921122773751336, 0.7360575292682485], 72 -> 
             RGBColor[
              0.2217348685979069, 0.3503877840720326, 0.9359388447880844], 64 -> 
             RGBColor[
              0.3359498495530848, 0.46540460717764737`, 0.942627405238103], 
             41 -> RGBColor[
              0.30942809264468474`, 0.44243279436585276`, 0.9409374623401685],
              103 -> RGBColor[
              0.45803470739904234`, 0.5708922355517895, 0.9504773164843211], 
             162 -> RGBColor[
              0.9949427924270352, 0.9915914693005747, 0.6909323490292631], 
             196 -> RGBColor[
              0.7311809567194161, 0.7899233876610815, 0.9738409425574133], 
             179 -> RGBColor[
              0.29417844711330704`, 0.426530578279886, 0.9400643994138661], 
             160 -> RGBColor[
              0.430927136540159, 0.5476691594686056, 0.9486792739798021], 123 -> 
             RGBColor[
              0.3529060431038644, 0.4800912097882647, 0.9437078388973854], 
             150 -> RGBColor[
              0.37012969203157964`, 0.49500946880368557`, 0.9448053145767846],
              188 -> RGBColor[
              0.29340083399602646`, 0.4257132575901048, 0.9400201154972124], 
             46 -> 
             RGBColor[
              0.99287108173662, 0.987160289615858, 0.46543942549392037`], 182 -> 
             RGBColor[
              0.3541572727593446, 0.4811749620272106, 0.9437875661446137], 6 -> 
             RGBColor[
              0.7783673391039698, 0.8267857482096835, 0.9785440401716914], 
             131 -> RGBColor[
              0.419657854128353, 0.5379082734541023, 0.947961205269557], 45 -> 
             RGBColor[
              0.2581795486395869, 0.3886934535220141, 0.9380143154013856], 
             195 -> RGBColor[
              0.37335567388745483`, 0.4978036521446821, 0.9450108712880173], 
             148 -> RGBColor[
              0.41627381997411267`, 0.5349771931562015, 0.9477455776056327], 
             161 -> RGBColor[
              0.18166030002082895`, 0.30826687162312194`, 0.9336566573926313],
              1 -> RGBColor[
              0.6747586761997523, 0.7458458732939058, 0.9682172969314027], 
             101 -> RGBColor[
              0.9940044804622655, 0.9895845148858246, 0.5888028822542988], 12 -> 
             RGBColor[
              0.2093152160508638, 0.3373339417936378, 0.9352315639487597], 39 -> 
             RGBColor[
              0.8363963712438436, 0.8723837793278915, 0.9842574266207346], 48 -> 
             RGBColor[
              0.358431322268727, 0.4848769288922631, 0.9440599047999579], 77 -> 
             RGBColor[
              0.7570522934233754, 0.8101342725236561, 0.9764195556186767], 56 -> 
             RGBColor[
              0.3936133836729206, 0.5153498621787538, 0.9463016746423577], 
             110 -> RGBColor[
              0.3011256950455511, 0.4338325763376344, 0.9404600349060751], 73 -> 
             RGBColor[
              0.24870775248762966`, 0.3787379952197451, 0.9374749106227983], 
             37 -> RGBColor[
              0.7551365737597742, 0.8086376977624421, 0.9762286145860269], 
             130 -> RGBColor[
              0.3936423712690186, 0.5153749697775349, 0.9463035217063483], 
             107 -> RGBColor[
              0.4239215283282335, 0.5416012537475425, 0.9482328828193543], 59 -> 
             RGBColor[
              0.30942809264468474`, 0.44243279436585276`, 0.9409374623401685],
              47 -> RGBColor[
              0.9104969383058378, 0.9314695600968158, 0.9913252048574647], 
             159 -> RGBColor[
              0.2661411988258287, 0.39706165266553184`, 0.938467719601286], 
             55 -> RGBColor[
              0.28770418825910593`, 0.4197257217324004, 0.939695699949927], 
             49 -> RGBColor[
              0.3990102466152305, 0.5200243536051641, 0.9466455579767832], 82 -> 
             RGBColor[
              0.7199133314598152, 0.7811210331711576, 0.972717890973481], 199 -> 
             RGBColor[
              0.9912394464577958, 0.9906453002214114, 0.7948485739875297], 89 -> 
             RGBColor[
              0.35131790745638636`, 0.4787156465124378, 0.9436066442982612], 
             144 -> RGBColor[
              0.20837108594641887`, 0.3363416011925601, 0.9351777971360269], 
             78 -> RGBColor[
              0.32772843219708697`, 0.45828362868433326`, 0.9421035437940927],
              42 -> RGBColor[
              0.35053185182610624`, 0.4780348046337939, 0.9435565575285816], 
             154 -> RGBColor[
              0.21321186643520434`, 0.3414295684094837, 0.9354534724235702], 
             168 -> RGBColor[
              0.36236051782334855`, 0.48828020059456556`, 0.9443102696662472],
              121 -> RGBColor[
              0.31238306843161684`, 0.4449922458710919, 0.9411257507843293], 
             128 -> RGBColor[
              0.3963429735061762, 0.5177140956991457, 0.9464756016928513], 
             115 -> RGBColor[
              0.3588049877008656, 0.4852005791086109, 0.9440837144308744], 61 -> 
             RGBColor[
              0.6787132793064529, 0.7489352392969572, 0.9686114548112115], 93 -> 
             RGBColor[
              0.4308135193556082, 0.5475707499739134, 0.9486720343932702], 88 -> 
             RGBColor[
              0.3320279040410938, 0.46200761509787375`, 0.9423775023381191], 
             21 -> RGBColor[
              0.18935709457626326`, 0.31635669070584405`, 0.9340949784561761],
              62 -> RGBColor[
              0.2760855668168775, 0.40751381393347125`, 0.9390340366470021], 
             136 -> RGBColor[
              0.3371135415727025, 0.4664125387161786, 0.9427015546645805], 
             190 -> RGBColor[
              0.29896939475638884`, 0.43156616801639003`, 0.9403372367945677],
              57 -> RGBColor[
              0.2646327113470033, 0.39547613668165604`, 0.9383818134709742], 
             111 -> RGBColor[
              0.30611204314021384`, 0.4390735443378542, 0.9407440000534252], 
             63 -> RGBColor[
              0.994529807283845, 0.9907081358384939, 0.6459814648418781], 75 -> 
             RGBColor[
              0.38499696446986537`, 0.5078867529388886, 0.9457526440299394], 
             30 -> RGBColor[
              0.4007700204974213, 0.5215485812931107, 0.9467576892124495], 5 -> 
             RGBColor[
              0.8917486757676756, 0.6013378440476838, 0.2313847803888324], 
             171 -> RGBColor[
              0.24388970815995023`, 0.3736739251496999, 0.9372005301259948], 
             102 -> RGBColor[
              0.38633328958938185`, 0.5090442105917604, 0.9458377934848891], 
             31 -> RGBColor[
              0.20896703242638065`, 0.3369679787281891, 0.9352117354064369], 
             96 -> RGBColor[
              0.18720606650611818`, 0.3140958238210648, 0.9339724805897421], 
             70 -> RGBColor[
              0.5672251618560266, 0.6595379654538862, 0.9590731890369887], 52 -> 
             RGBColor[
              0.41962085413493355`, 0.5378762259194761, 0.9479588476626941], 
             183 -> RGBColor[
              0.6409312637984768, 0.7193758994328205, 0.964875603376246], 158 -> 
             RGBColor[
              0.3160229983831292, 0.44814497024689304`, 0.941357683902176], 
             13 -> RGBColor[
              0.2936620543657398, 0.4259878167610016, 0.9400349916108267], 
             170 -> RGBColor[
              0.9344694009215406, 0.7779000419712138, 0.2661307456618581], 86 -> 
             RGBColor[
              0.8357785622732934, 0.27601528466429986`, 0.18189489767999942`],
              18 -> RGBColor[
              0.3896097630770392, 0.5118821272464233, 0.9460465674782509], 
             153 -> RGBColor[
              0.30178542005761416`, 0.43452598915429436`, 0.9404976052695364],
              58 -> RGBColor[
              0.3893876786770247, 0.5116897689014174, 0.9460324164566635], 22 -> 
             RGBColor[
              0.2938131706704693, 0.4261466495785994, 0.9400435974608246], 66 -> 
             RGBColor[
              0.9698134652863923, 0.9770075123532812, 0.935982108747679], 143 -> 
             RGBColor[
              0.3239805007657761, 0.4550373588550428, 0.9418647289174552], 
             119 -> RGBColor[
              0.29995997393985074`, 0.4326073295445563, 0.9403936488136353], 
             145 -> RGBColor[
              0.5566743254906181, 0.650972321182686, 0.9582425885493167], 91 -> 
             RGBColor[
              0.2425861171518165, 0.3723037683477076, 0.9371262925465716], 
             177 -> RGBColor[
              0.974797882516292, 0.9807248825621062, 0.9275447905216765], 200 -> 
             RGBColor[
              0.367098377623016, 0.49238389662127996`, 0.9446121619031571], 
             114 -> RGBColor[
              0.360920127522216, 0.4870326069118461, 0.9442184892699461], 24 -> 
             RGBColor[
              0.21707253322129982`, 0.3454873739820821, 0.9356733316856937], 
             176 -> RGBColor[
              0.2883477517875053, 0.4204021478050326, 0.9397323499408025], 79 -> 
             RGBColor[
              0.3246672089761624, 0.4556321509919212, 0.9419084853573888], 
             109 -> RGBColor[
              0.9907823450008624, 0.9904562770219978, 0.8024239280695675], 
             135 -> RGBColor[
              0.2839845832830512, 0.4158161810659901, 0.9394838739492031], 
             108 -> RGBColor[
              0.2753843011895019, 0.40677673929629066`, 0.9389941006069527], 
             191 -> RGBColor[
              0.30162521074727067`, 0.43435759901126636`, 0.9404884815863207],
              14 -> RGBColor[
              0.3841396298295956, 0.507144172764379, 0.9456980154247727], 185 -> 
             RGBColor[
              0.9707544527167439, 0.913010043211834, 0.3408870006730844], 32 -> 
             RGBColor[
              0.40190894008070766`, 0.5225350561923906, 0.9468302601611894], 
             122 -> RGBColor[
              0.2885259606399425, 0.4205894566080379, 0.9397424986713123], 
             187 -> RGBColor[
              0.6738775355857266, 0.7451575195493123, 0.9681294730697239], 
             193 -> RGBColor[
              0.9637492000328393, 0.889379680997474, 0.3136729168270817], 100 -> 
             RGBColor[
              0.36000646398404595`, 0.4862412374771478, 0.9441602714372149], 
             180 -> RGBColor[
              0.30942809264468474`, 0.44243279436585276`, 0.9409374623401685],
              7 -> RGBColor[
              0.23372153030876558`, 0.36298652552839294`, 0.9366214674398409],
              175 -> RGBColor[
              0.29756079560811244`, 0.4300856410012073, 0.9402570191569091], 
             9 -> RGBColor[
              0.4550202207245157, 0.5684449394683316, 0.9502400050508738], 90 -> 
             RGBColor[
              0.27949904549447857`, 0.41110159645067834`, 0.9392284292079024],
              174 -> RGBColor[
              0.24043123490936846`, 0.37003885048346935`, 0.9370035751907269],
              142 -> RGBColor[
              0.3357664385160471, 0.465245745755872, 0.9426157184490069], 134 -> 
             RGBColor[
              0.7255643513294814, 0.7855356528426826, 0.9732811318223061], 
             105 -> RGBColor[
              0.3290305677007825, 0.4594114730104009, 0.9421865147169549], 16 -> 
             RGBColor[
              0.5232656780986867, 0.6238496761875024, 0.955612537446716], 139 -> 
             RGBColor[
              0.33494952996127236`, 0.464538180624744, 0.9425636657582606], 
             146 -> RGBColor[
              0.9904704006559311, 0.9795165651354338, 0.41747973537247046`], 
             126 -> RGBColor[
              0.7617102060517315, 0.813773069270375, 0.9768838128188029], 198 -> 
             RGBColor[
              0.224334441760091, 0.35312010028794627`, 0.9360868866339469], 
             40 -> RGBColor[
              0.9486401971149956, 0.8340825267403634, 0.2775329009104499], 
             104 -> RGBColor[
              0.30322531248840134`, 0.43603940739350466`, 0.9405796050133397],
              181 -> RGBColor[
              0.32604221032105335`, 0.4568231080472887, 0.9419960992272193], 
             127 -> RGBColor[
              0.7403491167573226, 0.7970856239632912, 0.974754739068665], 76 -> 
             RGBColor[
              0.24513448315949354`, 0.37498226259751327`, 0.9372714182207391],
              172 -> RGBColor[
              0.5101169363970025, 0.6131749353300119, 0.9545774203345316], 84 -> 
             RGBColor[
              0.9684789578489394, 0.9760122388914844, 0.9382410817440032], 
             184 -> RGBColor[
              0.296809051411728, 0.42929551018747225`, 0.9402142084370309], 
             151 -> RGBColor[
              0.9707544527167439, 0.913010043211834, 0.3408870006730844], 35 -> 
             RGBColor[
              0.8595352851479842, 0.4550643608721931, 0.20450513763330225`], 
             36 -> RGBColor[
              0.9805207846610894, 0.984993013611304, 0.9178574099624649], 34 -> 
             RGBColor[
              0.36793684800500254`, 0.49311013752340993`, 0.944665588494467], 
             38 -> RGBColor[
              0.2661411988258287, 0.39706165266553184`, 0.938467719601286], 
             54 -> RGBColor[
              0.8804115581351782, 0.9074802945946214, 0.9884556344392512], 60 -> 
             RGBColor[
              0.9850389673358539, 0.9880812427594433, 0.8976065593636972], 87 -> 
             RGBColor[
              0.2419080423955311, 0.371591068786429, 0.9370876771923229], 141 -> 
             RGBColor[
              0.4440354311597563, 0.5590229054260565, 0.949514522921753], 67 -> 
             RGBColor[
              0.4398683324044669, 0.5554135739286982, 0.9492489990738867], 
             133 -> RGBColor[
              0.34248104567854293`, 0.4710616009940571, 0.9430435672799071], 
             98 -> RGBColor[
              0.9923160771136491, 0.9910905146657525, 0.7770060177892187], 3 -> 
             RGBColor[
              0.26627754048828517`, 0.3972049563973342, 0.9384754840572636], 
             27 -> RGBColor[
              0.3464092077026741, 0.47446397750419544`, 0.9432938662905475], 
             163 -> RGBColor[
              0.3172619248821779, 0.4492180661101126, 0.9414366272031557], 85 -> 
             RGBColor[
              0.37097654117686685`, 0.4957429669694577, 0.9448592750554831], 
             83 -> RGBColor[
              0.282270328447336, 0.4140143905436192, 0.9393862496723219], 28 -> 
             RGBColor[
              0.7941810026697319, 0.8391395023755515, 0.9801201983688385], 44 -> 
             RGBColor[
              0.26737010280126405`, 0.3983533086607267, 0.9385377038646866], 
             189 -> RGBColor[
              0.370482703817023, 0.49531522986934834`, 0.9448278081755971], 
             15 -> RGBColor[
              0.24369575085229617`, 0.37347006372175184`, 0.937189484544258], 
             80 -> RGBColor[
              0.9733876265007912, 0.9796731159348281, 0.9299319861022425], 
             112 -> RGBColor[
              0.5457992499198248, 0.6421434449177446, 0.9573864627636695], 
             169 -> RGBColor[
              0.47832223900100224`, 0.587362567649144, 0.9520744252877044], 
             69 -> RGBColor[
              0.3172619248821779, 0.4492180661101126, 0.9414366272031557], 20 -> 
             RGBColor[
              0.294895611164345, 0.42728436316835394`, 0.9401052408456235], 8 -> 
             RGBColor[
              0.9944129994936373, 0.9904582957863187, 0.6332676577318835], 
             116 -> RGBColor[
              0.19791430031189616`, 0.32535085649217454`, 0.9345822986635689],
              97 -> RGBColor[
              0.4599186910161441, 0.5724217383246474, 0.9506256305759188], 
             118 -> RGBColor[
              0.3306386678274742, 0.4608043285146788, 0.9422889814350406], 
             178 -> RGBColor[
              0.9197948223800564, 0.938883440473258, 0.9922120453407828], 81 -> 
             RGBColor[
              0.5428817193351332, 0.6397748621558369, 0.9571567840687758], 
             166 -> RGBColor[
              0.3951570639738854, 0.5166869204678216, 0.9464000365861124], 
             125 -> RGBColor[
              0.8807967053696787, 0.907787400544869, 0.988492370126303], 95 -> 
             RGBColor[
              0.8337134622526212, 0.26014202097281397`, 0.1799173555680068], 
             157 -> RGBColor[
              0.5973970256413101, 0.6840328437017533, 0.961448428677345], 74 -> 
             RGBColor[
              0.35841751616769923`, 0.48486497074146767`, 0.9440590250874087],
              19 -> RGBColor[
              0.9699820970445849, 0.9771332776424322, 0.9356966591672653], 
             156 -> RGBColor[0.817319, 0.134127, 0.164218], 167 -> 
             RGBColor[
              0.309535083225584, 0.44252546422952477`, 0.9409442796853753], 
             33 -> RGBColor[
              0.3617798020368932, 0.487777213767962, 0.944273266969841], 43 -> 
             RGBColor[
              0.3613301452909011, 0.4873877436949888, 0.9442446152396022], 
             140 -> RGBColor[
              0.7905998095935818, 0.8363418471263875, 0.9797632585111599], 
             186 -> RGBColor[
              0.9943312303497649, 0.9919238323159623, 0.743609713617377], 117 -> 
             RGBColor[
              0.8459936213239228, 0.8800363660313331, 0.9851728209009388], 4 -> 
             RGBColor[
              0.2173390106950707, 0.345767458702663, 0.9356885071836069], 106 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 65 -> 
             RGBColor[
              0.2758397150381692, 0.4072554081261457, 0.9390200357519098], 53 -> 
             RGBColor[
              0.5713720005998251, 0.6629045559590584, 0.9593996433732713], 2 -> 
             RGBColor[
              0.4126277021249406, 0.5318191091344603, 0.9475132502004189], 
             147 -> RGBColor[
              0.7645263145464537, 0.8159730346296693, 0.9771644961955266], 94 -> 
             RGBColor[
              0.48892598718299674`, 0.5959711681166989, 0.9529091911874004], 
             23 -> RGBColor[0.178927, 0.305394, 0.933501], 194 -> 
             RGBColor[
              0.30322531248840134`, 0.43603940739350466`, 0.9405796050133397],
              129 -> RGBColor[
              0.882934712052292, 0.9094921890389395, 0.9886962951123117], 99 -> 
             RGBColor[
              0.31050597780896316`, 0.44336640431906715`, 0.9410061442296999],
              25 -> RGBColor[
              0.9849100503316931, 0.9880279322652069, 0.8997430477491545], 
             138 -> RGBColor[
              0.3059677016871769, 0.43892183231893567`, 0.9407357800212087], 
             124 -> RGBColor[
              0.2700899072180517, 0.40121199554833054`, 0.9386925927026326], 
             197 -> RGBColor[
              0.6323338172206462, 0.7123961049903831, 0.9641987808881547], 
             164 -> RGBColor[
              0.32169596699960673`, 0.4530586105307926, 0.9417191604460088], 
             152 -> RGBColor[
              0.5135847929016581, 0.6159902974656465, 0.954850422701755], 17 -> R\
GBColor[0.28804359369038585`, 0.42008245836022284`, 0.9397150285871331], 149 -> 
             RGBColor[
              0.43329983369507497`, 0.5497242704889673, 
               0.9488304601444196]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw1Vnk41Iv7HWbGjH3MjDGYYWbMlDYVokV9jgp1K023DRVaCFlSpNQNyVKW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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 11}], {
             RGBColor[
             0.47925973644740294`, 0.5807134202335107, 0.9538442132827409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 35}], {
             RGBColor[
             0.7671469806738682, 0.6004551170830494, 0.5863612172823525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 86}], {
             RGBColor[
             0.7552686192365228, 0.5109305789791029, 0.5750560973057011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 94}], {
             RGBColor[
             0.5818423316913746, 0.6709085207053024, 0.9605632440594015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 174}], {
             RGBColor[
             0.45759495555456037`, 0.5579423618886876, 0.9526104360610648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 196}], {
             RGBColor[
             0.7029698164595841, 0.7678846304774937, 0.971029119744408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 16}], {
             RGBColor[
             0.46794669011181367`, 0.5778343926609814, 0.9515628938235674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 52}], {
             RGBColor[
             0.4161242781299371, 0.5348476675269682, 0.9477360489315565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[
             0.6912205837056664, 0.7544133107438707, 0.9417476794740489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 78}], {
             RGBColor[
             0.37017806716101376`, 0.49505136890939677`, 0.9448083969972558]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 80}], {
             RGBColor[
             0.693007664312866, 0.7557461125346442, 0.9387226181513306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 82}], {
             RGBColor[
             0.5662705167923778, 0.6564700711528089, 0.96011557058695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 98}], {
             RGBColor[
             0.7024718896192949, 0.7614548119001063, 0.8622596339948188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 100}], {
             RGBColor[
             0.3863170830544933, 0.509030173305804, 0.945836760818817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 120}], {
             RGBColor[
             0.4254627375025527, 0.5429361716709125, 0.9483310873051042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 124}], {
             RGBColor[
             0.34135880467149615`, 0.4665155523413954, 0.9431029214515257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 187}], {
             RGBColor[
             0.5432526188553336, 0.6384883143418862, 0.9578213616350714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 5}], {
             RGBColor[
             0.5790131081279803, 0.499271400222509, 0.584930132223048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 10}], {
             RGBColor[
             0.4772954822197458, 0.5768199508272873, 0.9540218957841058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 27}], {
             RGBColor[
             0.3063433740954796, 0.43583446695076483`, 0.9408846751739055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 29}], {
             RGBColor[
             0.3058435813014061, 0.4354015715528545, 0.9408528288190166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 49}], {
             RGBColor[
             0.33264389355175783`, 0.45861465500124915`, 0.9425605210170234]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 53}], {
             RGBColor[
             0.4188247705440551, 0.5300547561781963, 0.9489375637152675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 62}], {
             RGBColor[
             0.27118155365258134`, 0.4023593851654027, 0.9387547603521329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 68}], {
             RGBColor[
             0.33314325327265126`, 0.4590471752929377, 0.9425923397768723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 71}], {
             RGBColor[
             0.2855674300174461, 0.41747985334211857`, 0.939574014729115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 75}], {
             RGBColor[
             0.32563725247907527`, 0.4525458546681114, 0.9421140640436014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 118}], {
             RGBColor[
             0.29845810415787966`, 0.4290046424560065, 0.9403822327461521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[
             0.30959179179607477`, 0.43864808309279946`, 0.9410916614773245]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 127}], {
             RGBColor[
             0.5033133286228039, 0.5971452901803127, 0.9566151115629643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 129}], {
             RGBColor[
             0.5746061262702886, 0.6533485727181368, 0.9635858895847876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 139}], {
             RGBColor[
             0.30061353522477874`, 0.43087156851103914`, 0.9405195749077621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 141}], {
             RGBColor[
             0.3551564858240207, 0.47811393091169535`, 0.9439950034895083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 146}], {
             RGBColor[
             0.6283739705721081, 0.688360760766384, 0.677977609714867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 155}], {
             RGBColor[
             0.38438882402177255`, 0.5020981034696952, 0.946226639862005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 167}], {
             RGBColor[
             0.2879063118569346, 0.4198652103134295, 0.9397098818713194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 191}], {
             RGBColor[
             0.28395137561777795`, 0.4157812777043003, 0.9394819828217922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 194}], {
             RGBColor[
             0.2847514264883433, 0.41662218189541944`, 0.9395275445353016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 195}], {
             RGBColor[
             0.31981660718787, 0.4475043042710082, 0.9417431776726404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 34}], {
             RGBColor[
             0.29263792935003663`, 0.41943879811303647`, 0.940177047839037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 40}], {
             RGBColor[
             0.5829896039050332, 0.5899249927215132, 0.6066107040470283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 49}], {
             RGBColor[
             0.3081746286551506, 0.43289590615391355`, 0.9411670325801951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 53}], {
             RGBColor[
             0.3943555056474479, 0.5043360073308607, 0.9475440752784391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 54}], {
             RGBColor[
             0.5488752844151245, 0.6266238766486423, 0.962072070811429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 65}], {
             RGBColor[
             0.24658936286661992`, 0.37651143341440435`, 0.9373542714677583]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 69}], {
             RGBColor[
             0.2673004677886243, 0.3974927624063878, 0.9385625671933813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 86}], {
             RGBColor[
             0.5265587864841821, 0.31089137168348147`, 0.5587917024318032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 92}], {
             RGBColor[
             0.3095059697373863, 0.43404904688419765`, 0.9412518644566964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 118}], {
             RGBColor[
             0.27398883926127243`, 0.4032858936086709, 0.9389887443093237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 119}], {
             RGBColor[
             0.2586494923174607, 0.38918739412360964`, 0.938041077998621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 123}], {
             RGBColor[
             0.28512252689946754`, 0.41292933424546385`, 0.9396981730404961]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 139}], {
             RGBColor[
             0.2761442703281715, 0.40515281966370353`, 0.9391260864709337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 146}], {
             RGBColor[
             0.6039047056755009, 0.6626420119190484, 0.6765841212780387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 171}], {
             RGBColor[
             0.23061435942751046`, 0.35972069192618145`, 0.9364445186548008]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 182}], {
             RGBColor[
             0.28574814172720764`, 0.41347121036493684`, 0.9397380366641103]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 191}], {
             RGBColor[
             0.25948211072117067`, 0.3900625288569647, 0.9380884943849638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 195}], {
             RGBColor[
             0.29534734229126275`, 0.4217855554236726, 0.9403496892358121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 196}], {
             RGBColor[
             0.4742599837072434, 0.5678454231818723, 0.95476472487051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 199}], {
             RGBColor[
             0.6042892285764333, 0.6682063794620372, 0.8652685405855682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 10}], {
             RGBColor[
             0.7900310498594411, 0.6788863946524621, 0.6004765439498903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 27}], {
             RGBColor[
             0.6190789417351749, 0.5379009107759396, 0.58733932333969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.6185791489411012, 0.5374680153780294, 0.587307476984801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 30}], {
             RGBColor[
             0.6462593481325485, 0.5614432126703972, 0.5890712348006409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 42}], {
             RGBColor[
             0.6211402637968909, 0.5396863243407388, 0.587470668958707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 68}], {
             RGBColor[
             0.6458788209123465, 0.5611136191181125, 0.5890469879426566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 71}], {
             RGBColor[
             0.5983029976571413, 0.5195462971672933, 0.5860286628948994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 73}], {
             RGBColor[
             0.5702282141276527, 0.49003791963371446`, 0.5844298455058153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 75}], {
             RGBColor[
             0.6383728201187705, 0.5546122984932862, 0.5885687122093859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 76}], {
             RGBColor[
             0.5684415794635845, 0.4881600533225985, 0.5843280993047858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 81}], {
             RGBColor[
             0.7173151975514044, 0.6205563531017604, 0.5942707822288041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 87}], {
             RGBColor[
             0.5668283590816033, 0.4864644564170564, 0.5842362287905777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 89}], {
             RGBColor[
             0.621533291612031, 0.5400267452800608, 0.5874957123435468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 107}], {
             RGBColor[
             0.6578351020479545, 0.5714695488976131, 0.5898088316040934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 127}], {
             RGBColor[
             0.8160488962624991, 0.6992117340054875, 0.6030697597287488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 129}], {
             RGBColor[
             0.8873416939099839, 0.7554150165433116, 0.6100405377505721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 141}], {
             RGBColor[
             0.6678920534637159, 0.5801803747368701, 0.5904496516552927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 142}], {
             RGBColor[
             0.6137575571418613, 0.5332917949017779, 0.5870002494189197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 147}], {
             RGBColor[
             0.8281374951570646, 0.7086554393386766, 0.6042746382921795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 155}], {
             RGBColor[
             0.6971243916614678, 0.60416454729487, 0.5926812880277893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 157}], {
             RGBColor[
             0.7445728507044929, 0.6426853438747185, 0.5964166045330888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 168}], {
             RGBColor[
             0.6270545967955121, 0.5448090223211246, 0.5878475250275398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 188}], {
             RGBColor[
             0.592574754881851, 0.5135255508188943, 0.5857024479430224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 197}], {
             RGBColor[
             0.7620412464941608, 0.6568669745190334, 0.5977917806384936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 44}], {
             RGBColor[
             0.5228687209526169, 0.6125695284352051, 0.9585408720181889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 45}], {
             RGBColor[
             0.5182734438717784, 0.6077396008658489, 0.9582791777865385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 58}], {
             RGBColor[
             0.5838775088904973, 0.6692377585555505, 0.9622882283141774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 77}], {
             RGBColor[
             0.7677098162636726, 0.8184600103666698, 0.977481797895184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 83}], {
             RGBColor[
             0.5303188337756529, 0.6204000693766514, 0.9589651449220067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 96}], {
             RGBColor[
             0.482786702805044, 0.5704407860153742, 0.9562582603807168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 112}], {
             RGBColor[
             0.6620832945118973, 0.734464596563714, 0.9679652514676804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 156}], {
             RGBColor[
             0.797843169551985, 0.48045637410484177`, 0.5713810200858457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 166}], {
             RGBColor[
             0.5867622015389276, 0.6717363343387526, 0.9624720383789018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 170}], {
             RGBColor[
             0.8564183700127552, 0.8023428950904486, 0.6223373929167748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 179}], {
             RGBColor[
             0.5362728931086385, 0.6266581632447847, 0.9593042197927788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 183}], {
             RGBColor[
             0.7096493014512233, 0.7730808238212521, 0.9717098217739687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 192}], {
             RGBColor[
             0.6001058177124617, 0.6832939039986183, 0.9633222818021829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 8}], {
             RGBColor[
             0.6140672649012013, 0.6767224106573558, 0.7849445625858622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 16}], {
             RGBColor[
             0.37849360420372613`, 0.4934181008579477, 0.9461170024432785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 52}], {
             RGBColor[
             0.3266711922218496, 0.45043137572393455`, 0.9422901575512674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.4562174048076092, 0.555960882412675, 0.9526164611255261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 67}], {
             RGBColor[
             0.3367949313566162, 0.45920004972854556`, 0.9429352332568638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 79}], {
             RGBColor[
             0.279194369642464, 0.4093093382601571, 0.9392649763986148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.6011002440788524, 0.6694993822099387, 0.937431274591922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 122}], {
             RGBColor[
             0.261123745474354, 0.39178799106821544`, 0.9381819830555767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 125}], {
             RGBColor[
             0.5572591178392221, 0.6353869630366309, 0.9625569187830719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 126}], {
             RGBColor[
             0.49771586818024854`, 0.588379797399384, 0.9567526401293218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 137}], {
             RGBColor[
             0.35388468253692357`, 0.47343946962955, 0.9441796979842174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 179}], {
             RGBColor[
             0.2639499887110363, 0.39475855190413944`, 0.9383429334268535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 192}], {
             RGBColor[
             0.3277829133148596, 0.45139429265797304`, 0.9423609954362577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.5918850470349503, 0.6534074932460814, 0.7836813180940299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 26}], {
             RGBColor[
             0.7249766215921024, 0.7796627066626294, 0.791774300447776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 61}], {
             RGBColor[
             0.836563139400045, 0.8696967675416379, 0.8009395562715476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 67}], {
             RGBColor[
             0.717140665949052, 0.7729359348575084, 0.7912583284028851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 79}], {
             RGBColor[
             0.6595401042348998, 0.72304522338912, 0.7875880715446362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.8571631654767262, 0.8857896644787382, 0.8029927743526823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 83}], {
             RGBColor[
             0.6383416639704866, 0.702236343164969, 0.7863269537021027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 122}], {
             RGBColor[
             0.6414694800667899, 0.7055238761971783, 0.7865050782015979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 125}], {
             RGBColor[
             0.937604852431658, 0.9491228481655938, 0.8108800139290933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 137}], {
             RGBColor[
             0.7342304171293594, 0.787175354758513, 0.7925027931302389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 166}], {
             RGBColor[
             0.6947850317337614, 0.7535726081270702, 0.789833847158998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 170}], {
             RGBColor[
             0.964441200207589, 0.8841791688787662, 0.44969920169687083`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 179}], {
             RGBColor[
             0.6442957233034722, 0.7084944370331023, 0.7866660285728748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 192}], {
             RGBColor[
             0.7081286479072955, 0.7651301777869359, 0.7906840905822791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 198}], {
             RGBColor[
             0.6093737206268641, 0.6717891980371324, 0.7846772721829152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 18}], {
             RGBColor[
             0.4223149919007775, 0.5401635333573775, 0.9481432862645623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 32}], {
             RGBColor[
             0.4284645804026117, 0.5454899978303611, 0.9485351326060316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 39}], {
             RGBColor[
             0.6457082959841797, 0.7204143593981116, 0.9672487158358042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 41}], {
             RGBColor[
             0.3822241566846002, 0.5054388669170922, 0.9455887336955211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 57}], {
             RGBColor[
             0.3598264660357595, 0.48196053807499384`, 0.944310909260924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 85}], {
             RGBColor[
             0.4129983809506913, 0.5320939532188946, 0.9475496400531784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 88}], {
             RGBColor[
             0.39352406238280474`, 0.5152262772831027, 0.9463087536944965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 91}], {
             RGBColor[
             0.3488031689381661, 0.4703743539080196, 0.9436831487987227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 103}], {
             RGBColor[
             0.456527464061779, 0.5696685875100606, 0.9503586607675975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 117}], {
             RGBColor[
             0.6505069210242193, 0.7242406527498324, 0.9677064129759063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 121}], {
             RGBColor[
             0.38370164457806627`, 0.5067185926697118, 0.9456828779176015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 152}], {
             RGBColor[
             0.48430250681308695`, 0.5922176184669891, 0.9525452138763144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 159}], {
             RGBColor[
             0.3605807097751722, 0.48275329606693174`, 0.9443538623260799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 164}], {
             RGBColor[
             0.3883580938620612, 0.5107517749995621, 0.9459795827484413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 178}], {
             RGBColor[
             0.687407521552286, 0.7536641899707948, 0.9712260251958282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 200}], {
             RGBColor[
             0.4110592991737658, 0.5304144180448058, 0.9474260834770154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 17}], {
             RGBColor[
             0.48817850882079616`, 0.5882587018087316, 0.9546416680490406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 27}], {
             RGBColor[
             0.5173613158269403, 0.615449461380718, 0.9564310869007477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 29}], {
             RGBColor[
             0.5168615230328668, 0.6150165659828076, 0.9563992405458588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 30}], {
             RGBColor[
             0.5445417222243139, 0.6389917632751756, 0.9581629983616988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 42}], {
             RGBColor[
             0.5194226378886564, 0.6172348749455172, 0.9565624325197648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 51}], {
             RGBColor[
             0.8415501788410886, 0.8742736113161871, 0.8528129183895983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 62}], {
             RGBColor[
             0.48219949538404205`, 0.5819743795953558, 0.9543011720789751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 71}], {
             RGBColor[
             0.4965853717489068, 0.5970948477720717, 0.9551204264559573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 73}], {
             RGBColor[
             0.4685105882194181, 0.5675864702384927, 0.9535216090668732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 75}], {
             RGBColor[
             0.536655194210536, 0.6321608490980646, 0.9576604757704438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 89}], {
             RGBColor[
             0.5198156657037964, 0.6175752958848391, 0.9565874759046047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 107}], {
             RGBColor[
             0.5561174761397201, 0.6490180995023915, 0.9589005951651512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.7856240680017492, 0.83296356714809, 0.97913230131163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 130}], {
             RGBColor[
             0.5409778976101125, 0.6359049575173876, 0.9579359146086482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 141}], {
             RGBColor[
             0.5661744275554814, 0.6577289253416485, 0.9595414152163506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 142}], {
             RGBColor[
             0.5120399312336268, 0.6108403455065562, 0.9560920129799775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 147}], {
             RGBColor[
             0.7264198692488302, 0.7862039899434549, 0.9733664018532373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 149}], {
             RGBColor[
             0.5608066288231408, 0.6530796078731038, 0.9591993838276839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 167}], {
             RGBColor[
             0.49892425358839526`, 0.5994802047433826, 0.9552562935981617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 168}], {
             RGBColor[
             0.5253369708872775, 0.622357572925903, 0.9569392885885977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 188}], {
             RGBColor[
             0.4908571289736165, 0.5910741014236727, 0.9547942115040803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.5293980638841147, 0.6258750875632944, 0.9571980578432726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 194}], {
             RGBColor[
             0.49576936821980394`, 0.5962371763253725, 0.955073956262144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 197}], {
             RGBColor[
             0.6603236205859264, 0.7344155251238118, 0.9668835441995514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 35}], {
             RGBColor[
             0.571648040921519, 0.4353226640226543, 0.5719881336336907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 70}], {
             RGBColor[
             0.4254929792755401, 0.5375594663135008, 0.949272159335534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 86}], {
             RGBColor[
             0.5597696794841736, 0.3457981259187077, 0.5606830136570393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 94}], {
             RGBColor[
             0.3863433919390252, 0.5057760676449072, 0.9461901604107398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 110}], {
             RGBColor[
             0.29244324587030235`, 0.42470677175537497`, 0.9399655822700772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 138}], {
             RGBColor[
             0.2948642491911153, 0.42725139974602555`, 0.9401034548276439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 174}], {
             RGBColor[
             0.2620960158022111, 0.3928099088282924, 0.938237352412403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 182}], {
             RGBColor[
             0.3189590347271991, 0.44837796460016305`, 0.9416293478893465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 196}], {
             RGBColor[
             0.5074708767072349, 0.6027521774170985, 0.9566560360957462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 33}], {
             RGBColor[
             0.2855475090438785, 0.4125555777807999, 0.9397524154593004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 44}], {
             RGBColor[
             0.23834265942606392`, 0.3678436252271823, 0.9368846339067232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 58}], {
             RGBColor[
             0.29935144736394426`, 0.42451185534752756`, 0.9406319902027116]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 68}], {
             RGBColor[
             0.3046620910539406, 0.42911166799108946`, 0.9409703797226203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 77}], {
             RGBColor[
             0.4831837547371196, 0.5737341071586469, 0.9558255597837182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 96}], {
             RGBColor[
             0.198260641278491, 0.3257148828073513, 0.9346020222692509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 99}], {
             RGBColor[
             0.2599105969299135, 0.39035017305635245`, 0.9381188540892298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 102}], {
             RGBColor[
             0.2978242528201228, 0.4231890761926991, 0.9405346787168244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 128}], {
             RGBColor[
             0.30282909477852, 0.4275240187463918, 0.9408535828208056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 140}], {
             RGBColor[
             0.4999575128222228, 0.5868378944600127, 0.9574974112299598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 162}], {
             RGBColor[
             0.6021290042389496, 0.6644627055471062, 0.8130819564890115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 172}], {
             RGBColor[
             0.3597160762239332, 0.4752544385618248, 0.9449044921416456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 31}], {
             RGBColor[
             0.2513145433960602, 0.3814778977445954, 0.9376233635086317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 34}], {
             RGBColor[
             0.33079945118537113`, 0.4595489771422058, 0.9423502900526468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 36}], {
             RGBColor[
             0.6370914195134145, 0.7054904151861527, 0.9289462007866458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 63}], {
             RGBColor[
             0.6440959308247924, 0.7083479762997478, 0.7930082282263524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 64}], {
             RGBColor[
             0.3148059519594123, 0.4456962119693245, 0.9413311984244648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 70}], {
             RGBColor[
             0.43044360811088317`, 0.5427628911074439, 0.9495540903239077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 97}], {
             RGBColor[
             0.37679037269094195`, 0.4992047775428245, 0.9453303110933727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 132}], {
             RGBColor[
             0.2991095251418835, 0.4317134539363246, 0.9403452170127173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 138}], {
             RGBColor[
             0.29981487802645834`, 0.43245482453996864`, 0.9403853858160177]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 145}], {
             RGBColor[
             0.42516818992817895`, 0.5384800689718439, 0.9491387900800716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 153}], {
             RGBColor[
             0.297723737211677, 0.43025690295764796`, 0.9402662984401815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 185}], {
             RGBColor[
             0.6322082535412419, 0.6694989299864178, 0.6404609961419556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 22}], {
             RGBColor[
             0.33897640025003245`, 0.46664541117148917`, 0.9428708064427986]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 48}], {
             RGBColor[
             0.3712854760491613, 0.496010550828321, 0.9448789601123653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 106}], {
             RGBColor[
             0.2815333149147978, 0.4062690863821895, 0.9395995077123864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 131}], {
             RGBColor[
             0.4018987419789743, 0.5225262231092407, 0.9468296103471648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 176}], {
             RGBColor[
             0.33624369080855043`, 0.4637731602847058, 0.9427151826827875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 59}], {
             RGBColor[
             0.2765619217484905, 0.4079514290438023, 0.9390634734422132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.25989065883458684`, 0.3904919388276116, 0.9381117605956301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 114}], {
             RGBColor[
             0.30230793918725607`, 0.43025133531679893`, 0.9407039869071021]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 167}], {
             RGBColor[
             0.2766154170389401, 0.4079977639756383, 0.9390668821148167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 184}], {
             RGBColor[
             0.2702524011320121, 0.40138278695461205`, 0.9387018464906445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 186}], {
             RGBColor[
             0.6190134906010305, 0.682696948018857, 0.8403995990808175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 194}], {
             RGBColor[
             0.2734605316703488, 0.40475473555762825`, 0.9388845447787988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 52}], {
             RGBColor[
             0.47144326611681014`, 0.5808629510534893, 0.951785692554705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 61}], {
             RGBColor[
             0.6009894787025698, 0.6863924577422298, 0.9621119961289637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 67}], {
             RGBColor[
             0.4815670052515768, 0.5896316250581003, 0.9524307682603014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 80}], {
             RGBColor[
             0.7483266522997389, 0.8017613960611653, 0.9427722617744793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 82}], {
             RGBColor[
             0.621589504779251, 0.7024853546793299, 0.9641652142100985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 84}], {
             RGBColor[
             0.7458723179738131, 0.7999309575394934, 0.9469268095953596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 100}], {
             RGBColor[
             0.4416360710413664, 0.5550454568323251, 0.9498864044419655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 120}], {
             RGBColor[
             0.48078172548942577`, 0.5889514551974335, 0.9523807309282528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 125}], {
             RGBColor[
             0.7020311917341827, 0.7658185383661857, 0.9720524537865095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.5985716068422067, 0.6845035978684073, 0.96187100525822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 30}], {
             RGBColor[
             0.3444068070939036, 0.47081551982666675`, 0.9432363588997913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[
             0.319287722758246, 0.44905863149700836`, 0.9416357930578574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 51}], {
             RGBColor[
             0.6414152637106783, 0.7060973678676783, 0.8378862789276909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 73}], {
             RGBColor[
             0.2683756730890078, 0.39941022678998395`, 0.9385949696049657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 87}], {
             RGBColor[
             0.26497581804295844`, 0.3958367635733259, 0.9384013528897279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 89}], {
             RGBColor[
             0.3196807505733861, 0.4493990524363303, 0.9416608364426972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 106}], {
             RGBColor[
             0.23348529684519292`, 0.36273822918011145`, 0.9366080142935665]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 107}], {
             RGBColor[
             0.3559825610093097, 0.4808418560538827, 0.9439739557032436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 130}], {
             RGBColor[
             0.34084298247970224`, 0.4677287140688789, 0.9430092751467407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 131}], {
             RGBColor[
             0.35385072390936945`, 0.4789953659071626, 0.943838116928345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 142}], {
             RGBColor[
             0.31190501610321647`, 0.4426641020580474, 0.9411653735180701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 147}], {
             RGBColor[
             0.5262849541184198, 0.6180277464949461, 0.9584397623913299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 149}], {
             RGBColor[
             0.36067171369273043`, 0.4849033644245951, 0.9442727443657764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 157}], {
             RGBColor[
             0.44272030966584797`, 0.552057651030988, 0.9505817286322391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 168}], {
             RGBColor[
             0.3252020557568672, 0.4541813294773942, 0.9420126491266901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 188}], {
             RGBColor[
             0.2907222138432062, 0.4228978579751638, 0.9398675720421727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 189}], {
             RGBColor[
             0.32926314875370444`, 0.45769884411478556`, 0.9422714183813651]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 197}], {
             RGBColor[
             0.46018870545551605`, 0.566239281675303, 0.9519569047376439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 24}], {
             RGBColor[
             0.3033411481491695, 0.4286847506142527, 0.9408599495819723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 32}], {
             RGBColor[
             0.39575935157887343`, 0.5172085917194069, 0.9464384138197202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 39}], {
             RGBColor[
             0.6130030671604414, 0.6921329532871574, 0.9651519970494927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 41}], {
             RGBColor[
             0.34951892786086197`, 0.4771574608061381, 0.9434920149092096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 85}], {
             RGBColor[
             0.380293152126953, 0.5038125471079405, 0.945452921266867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 103}], {
             RGBColor[
             0.42382223523804075`, 0.5413871813991065, 0.948261941981286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 108}], {
             RGBColor[
             0.33249703213327053`, 0.459329433271357, 0.9425203340426018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 117}], {
             RGBColor[
             0.617801692200481, 0.6959592466388782, 0.9656096941895949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 133}], {
             RGBColor[
             0.3660454043777911, 0.49147186412024024`, 0.944545067379079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 152}], {
             RGBColor[
             0.4515972779893487, 0.563936212356035, 0.950448495090003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 178}], {
             RGBColor[
             0.6547022927285477, 0.7253827838598407, 0.9691293064095168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 33}], {
             RGBColor[
             0.6658809495407391, 0.7324552457051972, 0.9399849630685532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 74}], {
             RGBColor[
             0.6641998066061421, 0.7309991241919499, 0.939877842127337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 85}], {
             RGBColor[
             0.6704793191107259, 0.736438122305945, 0.9402779671113741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 88}], {
             RGBColor[
             0.6510050005428394, 0.719570446370153, 0.9390370807526922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 93}], {
             RGBColor[
             0.7003978082000966, 0.7623520138081727, 0.9421843467802677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 95}], {
             RGBColor[
             0.9018477796486031, 0.6186376493076231, 0.557807007367636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 102}], {
             RGBColor[
             0.6781576933169834, 0.7430887441170964, 0.9407672263260771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 121}], {
             RGBColor[
             0.6411825827381009, 0.711062761756762, 0.9384112049757973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 140}], {
             RGBColor[
             0.8802909533190834, 0.9067375623844098, 0.9577299588392125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 159}], {
             RGBColor[
             0.6180616479352068, 0.6870974651539821, 0.9370821893842757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 161}], {
             RGBColor[
             0.575821198532707, 0.6427000746327771, 0.9346766582799483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 162}], {
             RGBColor[
             0.9824624447358101, 0.9843623734715035, 0.8133145040982642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 164}], {
             RGBColor[
             0.6458390320220958, 0.7150959440866124, 0.9387079098066371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 172}], {
             RGBColor[
             0.7400495167207937, 0.795154106486222, 0.9451370397508985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 173}], {
             RGBColor[
             0.6366037047664932, 0.7065863425179684, 0.9381381320903025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 180}], {
             RGBColor[
             0.6397050948446348, 0.7097830360041425, 0.9383170607537169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 22}], {
             RGBColor[
             0.2943543909174071, 0.42671550637347666`, 0.940074419153224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 46}], {
             RGBColor[
             0.6438833464504825, 0.707222326392106, 0.702772333169772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 47}], {
             RGBColor[
             0.6026962747350915, 0.6793769616325849, 0.9657152228515441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 50}], {
             RGBColor[
             0.38987867473800497`, 0.5099779954794903, 0.9463472397370192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 101}], {
             RGBColor[
             0.6444500458133053, 0.7084344390270892, 0.7644540615499611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 135}], {
             RGBColor[
             0.2894400972236981, 0.421550272117172, 0.9397945573974134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 144}], {
             RGBColor[
             0.25163334855538194`, 0.381812982180457, 0.9376415189908252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 23}], {
             RGBColor[
             0.18414204728813163`, 0.31087534535292205`, 0.9337979892280881]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 55}], {
             RGBColor[
             0.2385306414176846, 0.36804120621912223`, 0.9368953392030515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 61}], {
             RGBColor[
             0.43403518694135806`, 0.5326459650014006, 0.9513532166336938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 67}], {
             RGBColor[
             0.31461271349036507`, 0.4358851323172711, 0.9416719887650313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 83}], {
             RGBColor[
             0.23581371151179964`, 0.36518554062473163`, 0.9367406140642489]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 90}], {
             RGBColor[
             0.23442807003537092`, 0.3637291435782612, 0.9366617038320393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 122}], {
             RGBColor[
             0.2389415276081029, 0.368473073656941, 0.9369187385637442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 166}], {
             RGBColor[
             0.2922570792750743, 0.4165218055868328, 0.9402475075211443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 170}], {
             RGBColor[
             0.561913247748902, 0.5471283663385289, 0.600112862059017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 175}], {
             RGBColor[
             0.24345894509218785`, 0.37322116585352566`, 0.9371759988065426]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 177}], {
             RGBColor[
             0.5820774885462776, 0.6485407866339752, 0.9308198844889263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 179}], {
             RGBColor[
             0.24176777084478515`, 0.371443634492865, 0.937079688935021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 183}], {
             RGBColor[
             0.41514417918737, 0.5178662950693322, 0.949485290916211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 192}], {
             RGBColor[
             0.30560069544860846`, 0.4280793752466986, 0.9410977509444254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.32612224646959814`, 0.45551178923543123`, 0.9420517511303912]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 72}], {
             RGBColor[
             0.2577740196341881, 0.38826721682531595`, 0.9379912211244545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 144}], {
             RGBColor[
             0.2510921283084441, 0.3812441253855797, 0.9376106972984257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 176}], {
             RGBColor[
             0.29108046122898734`, 0.423274398691816, 0.9398879737008135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 38}], {
             RGBColor[
             0.22253409941291435`, 0.35122782633276595`, 0.935984359800643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 43}], {
             RGBColor[
             0.27012857264545054`, 0.3963908718474944, 0.9388728076198012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 55}], {
             RGBColor[
             0.23331559412955297`, 0.3625598608662002, 0.9365983499749635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 60}], {
             RGBColor[
             0.5819829836679269, 0.6467376213797216, 0.9155537796818486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 90}], {
             RGBColor[
             0.2292130227472393, 0.35824779822533914`, 0.9363647146039512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 111}], {
             RGBColor[
             0.24251952157010692`, 0.3722337721689271, 0.9371225000267126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 115}], {
             RGBColor[
             0.2688659938504328, 0.39529728955430543`, 0.9387923572154372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 163}], {
             RGBColor[
             0.24809446244108896`, 0.3773060330550563, 0.9374688136015779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 165}], {
             RGBColor[
             0.3001587573465107, 0.422401508474583, 0.940786304434303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 169}], {
             RGBColor[
             0.32862461950050115`, 0.446378283824572, 0.9427877126438522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 175}], {
             RGBColor[
             0.23824389780405622`, 0.3677398205006036, 0.9368790095784545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 177}], {
             RGBColor[
             0.576862441258146, 0.6430594412810531, 0.9305228952608382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 39}], {
             RGBColor[
             0.5267344522325716, 0.6089355766549869, 0.9599653791532141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 41}], {
             RGBColor[
             0.2632503129329923, 0.39396008417396744`, 0.9383053970129311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 55}], {
             RGBColor[
             0.2523883607402029, 0.38260654785724124`, 0.9376845158178103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 108}], {
             RGBColor[
             0.24622841720540087`, 0.37613205663918636`, 0.9373337161463231]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 111}], {
             RGBColor[
             0.26159228818075686`, 0.3922804591599682, 0.9382086658695594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 115}], {
             RGBColor[
             0.2879387604610827, 0.4153439765453465, 0.939878523058284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 133}], {
             RGBColor[
             0.27977678944992135`, 0.4082744874880696, 0.9393584494828005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 163}], {
             RGBColor[
             0.26716722905173884`, 0.39735272004609734`, 0.9385549794444247]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 165}], {
             RGBColor[
             0.3192315239571606, 0.4424481954656241, 0.9418724702771499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 175}], {
             RGBColor[
             0.25731666441470613`, 0.38778650749164467`, 0.9379651754213014]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 38}], {
             RGBColor[
             0.6255256245787609, 0.6925447924653694, 0.9191053836752203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[
             0.6731200978112971, 0.7377078379800979, 0.9219938314943783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 60}], {
             RGBColor[
             0.9849745088337736, 0.9880545875123251, 0.8986748035564258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 111}], {
             RGBColor[
             0.6455110467359535, 0.7135507383015306, 0.9202435239012898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 165}], {
             RGBColor[
             0.7031502825123572, 0.7637184746071864, 0.9239073283088803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 58}], {
             RGBColor[
             0.4224639611837961, 0.5402784432201787, 0.9481566798101659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 67}], {
             RGBColor[
             0.44770428804751716`, 0.5621403457338191, 0.9497649711187774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 80}], {
             RGBColor[
             0.7144639350956794, 0.7742701167368841, 0.9401064646329553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 82}], {
             RGBColor[
             0.5877267875751914, 0.6749940753550487, 0.9614994170685747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 96}], {
             RGBColor[
             0.32137315509834286`, 0.44148147068000243`, 0.9421267118767052]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 98}], {
             RGBColor[
             0.7239281604021084, 0.7799788161023462, 0.8636434804764435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 99}], {
             RGBColor[
             0.38302311074976536`, 0.5061167609290036, 0.9456435436966841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[
             0.40777335383730673`, 0.5275541775080439, 0.9472206073004417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 116}], {
             RGBColor[
             0.32672727200123186`, 0.4471089870155573, 0.9424316209136185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 120}], {
             RGBColor[
             0.4469190082853662, 0.5614601758731523, 0.9497149337867289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 122}], {
             RGBColor[
             0.372033102165255, 0.494728287073489, 0.9450117209174903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 124}], {
             RGBColor[
             0.3628150754543096, 0.4850395565436353, 0.9444867679331505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 125}], {
             RGBColor[
             0.6681684745301231, 0.7383272590419045, 0.9693866566449856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 128}], {
             RGBColor[
             0.4259416085983718, 0.5432906066190428, 0.9483782724282598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 136}], {
             RGBColor[
             0.396326892631635, 0.5176398281275594, 0.9464912489141244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 137}], {
             RGBColor[
             0.46479403922782453`, 0.5763797656348235, 0.9510094358461312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.4253486538322264, 0.5427770190033808, 0.9483404898748904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 170}], {
             RGBColor[
             0.6950048223060541, 0.6733835797550769, 0.6082058444127632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 187}], {
             RGBColor[
             0.564708889638147, 0.6570123185441261, 0.9592052081166961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 192}], {
             RGBColor[
             0.43869227000576055`, 0.5543345886632466, 0.9491907332981715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 198}], {
             RGBColor[
             0.3399373427253293, 0.46099360891344315`, 0.9431839148988076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 29}], {
             RGBColor[
             0.3459094149086005, 0.4740310821062852, 0.9432620199356585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 30}], {
             RGBColor[
             0.37358961410004765`, 0.49800627939865305`, 0.9450257777514985]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 42}], {
             RGBColor[
             0.3484705297643902, 0.47624939106899467`, 0.9434252119095645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 62}], {
             RGBColor[
             0.3112473872597758, 0.4409888957188334, 0.9411639514687749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 71}], {
             RGBColor[
             0.3256332636246406, 0.4561093638955492, 0.9419832058457569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 73}], {
             RGBColor[
             0.29755848009515184`, 0.4266009863619703, 0.9403843884566729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 75}], {
             RGBColor[
             0.3657030860862697, 0.49117536522154204`, 0.9445232551602434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 89}], {
             RGBColor[
             0.34886355757953025`, 0.4765898120083166, 0.9434502552944044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 127}], {
             RGBColor[
             0.5433791622299984, 0.6357748007337434, 0.9590243026796063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 129}], {
             RGBColor[
             0.614671959877483, 0.6919780832715674, 0.9659950807014296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 141}], {
             RGBColor[
             0.3952223194312152, 0.516743441465126, 0.9464041946061502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 142}], {
             RGBColor[
             0.3410878231093606, 0.46985486163003376`, 0.9429547923697772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 147}], {
             RGBColor[
             0.5554677611245639, 0.6452185060669324, 0.960229181243037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 149}], {
             RGBColor[
             0.3898545206988745, 0.5120941239965814, 0.9460621632174835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 155}], {
             RGBColor[
             0.42445465762896695`, 0.5407276140231259, 0.9486358309786469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 167}], {
             RGBColor[
             0.327972145464129, 0.4584947208668601, 0.9421190729879614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 168}], {
             RGBColor[
             0.3543848627630113, 0.4813720890493805, 0.9438020679783974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 188}], {
             RGBColor[
             0.31990502084935024`, 0.4500886175471501, 0.9416569908938799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 189}], {
             RGBColor[
             0.3584459557598485, 0.4848896036867719, 0.9440608372330723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[
             0.3248172600955377, 0.45525169244885005`, 0.9419367356519436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 197}], {
             RGBColor[
             0.4893715124616601, 0.5934300412472893, 0.9537463235893511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 97}], {
             RGBColor[
             0.627049846842938, 0.7057806203500994, 0.9653729144723786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 105}], {
             RGBColor[
             0.5616057851852572, 0.6492754876929762, 0.9611533565428967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.3107475944657022, 0.44055600032092307`, 0.9411321051138859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 71}], {
             RGBColor[
             0.32513347083056704`, 0.4556764684976389, 0.941951359490868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 73}], {
             RGBColor[
             0.2970586873010783, 0.42616809096406, 0.940352542101784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 129}], {
             RGBColor[
             0.6141721670834095, 0.6915451878736572, 0.9659632343465406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 141}], {
             RGBColor[
             0.39472252663714164`, 0.5163105460672157, 0.9463723482512613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 149}], {
             RGBColor[
             0.38935472790480097`, 0.5116612285986711, 0.9460303168625945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 167}], {
             RGBColor[
             0.3274723526700555, 0.4580618254689498, 0.9420872266330724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 168}], {
             RGBColor[
             0.35388506996893776`, 0.4809391936514702, 0.9437702216235084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 189}], {
             RGBColor[
             0.35794616296577497`, 0.4844567082888616, 0.9440289908781834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 194}], {
             RGBColor[
             0.32431746730146416`, 0.45481879705093975`, 0.9419048892970546]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 197}], {
             RGBColor[
             0.4888717196675866, 0.592997145849379, 0.9537144772344621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 42}], {
             RGBColor[
             0.37565093616176376`, 0.49979169296345227`, 0.9451571233705156]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 51}], {
             RGBColor[
             0.697778477114196, 0.7568304293341221, 0.8414076092403491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 71}], {
             RGBColor[
             0.3528136700220142, 0.4796516657900068, 0.943715117306708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 73}], {
             RGBColor[
             0.32473888649252547`, 0.4501432882564279, 0.9421162999176239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 76}], {
             RGBColor[
             0.32295225182845744`, 0.44826542194531194`, 0.9420145537165943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 81}], {
             RGBColor[
             0.47182586991627723`, 0.5806617217244738, 0.9519572366406126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 87}], {
             RGBColor[
             0.3213390314464762, 0.44656982503976983`, 0.9419226832023861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 89}], {
             RGBColor[
             0.3760439639769038, 0.5001321139027742, 0.9451821667553554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 106}], {
             RGBColor[
             0.2898485102487106, 0.4134712906465553, 0.9401293446062248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 107}], {
             RGBColor[
             0.4123457744128274, 0.5315749175203266, 0.9474952860159018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 130}], {
             RGBColor[
             0.3972061958832199, 0.5184617755353228, 0.9465306054593989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 131}], {
             RGBColor[
             0.41021393731288713`, 0.5297284273736065, 0.9473594472410032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 142}], {
             RGBColor[
             0.3682682295067342, 0.49339716352449137`, 0.9446867038307283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 147}], {
             RGBColor[
             0.5826481675219375, 0.66876080796139, 0.9619610927039881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 157}], {
             RGBColor[
             0.4990835230693657, 0.602790712497432, 0.9541030589448973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 168}], {
             RGBColor[
             0.3815652691603849, 0.504914390943838, 0.9455339794393484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 176}], {
             RGBColor[
             0.3445588861424633, 0.47097536454907163`, 0.943245019576626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 188}], {
             RGBColor[
             0.34708542724672387`, 0.47363091944160773`, 0.943388902354831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 197}], {
             RGBColor[
             0.5165519188590337, 0.6169723431417469, 0.9554782350503022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 34}], {
             RGBColor[
             0.2884519402156916, 0.41503905812579955`, 0.939938661950452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[
             0.5788036147706881, 0.5855252527342762, 0.6063723181584434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 45}], {
             RGBColor[
             0.23357329053298378`, 0.36283071612510165`, 0.9366130254039112]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 64}], {
             RGBColor[
             0.2724584409897327, 0.40118629295291824`, 0.9389195703222699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 65}], {
             RGBColor[
             0.2424033737322749, 0.37211169342716743`, 0.9371158855791734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 132}], {
             RGBColor[
             0.2567620141722039, 0.3872035349199183, 0.9379335889105224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 138}], {
             RGBColor[
             0.25746736705677875`, 0.3879449055235624, 0.9379737577138227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 153}], {
             RGBColor[
             0.2553762262419974, 0.38574698394124174`, 0.9378546703379866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 156}], {
             RGBColor[
             0.5131430162131903, 0.23554748936409456`, 0.5497148677032184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 182}], {
             RGBColor[
             0.28156215259286266`, 0.40907147037769986`, 0.9394996507755253]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 185}], {
             RGBColor[
             0.5898607425715623, 0.6249890109700116, 0.6380493680397606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 199}], {
             RGBColor[
             0.6001032394420882, 0.6638066394748003, 0.8650301546969833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 39}], {
             RGBColor[
             0.6191526556622756, 0.697459417760141, 0.965543843390962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 57}], {
             RGBColor[
             0.33327082571385547`, 0.4590055964370233, 0.9426060368160818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 103}], {
             RGBColor[
             0.42997182373987497`, 0.54671364587209, 0.9486537883227553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 117}], {
             RGBColor[
             0.6239512807023152, 0.7012857111118618, 0.9660015405310641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 133}], {
             RGBColor[
             0.3721949928796253, 0.4967983285932238, 0.9449369137205483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 152}], {
             RGBColor[
             0.4577468664911829, 0.5692626768290185, 0.9508403414314722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 178}], {
             RGBColor[
             0.6608518812303821, 0.7307092483328244, 0.9695211527509862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 44}], {
             RGBColor[
             0.3145749524190786, 0.44306526121434436`, 0.9414054854172638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 58}], {
             RGBColor[
             0.37558374035695896`, 0.4997334913346897, 0.9451528417132522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 68}], {
             RGBColor[
             0.3808943840469553, 0.5043333039782516, 0.9454912312331609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 77}], {
             RGBColor[
             0.5594160477301343, 0.6489557431458091, 0.9603464112942588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 96}], {
             RGBColor[
             0.2744929342715057, 0.4009365187945134, 0.9391228737797916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 99}], {
             RGBColor[
             0.3361428899229282, 0.4655718090435146, 0.9426397055997704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 102}], {
             RGBColor[
             0.3740565458131375, 0.4984107121798612, 0.9450555302273651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 128}], {
             RGBColor[
             0.3790613877715347, 0.5027456547335538, 0.9453744343313462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 140}], {
             RGBColor[
             0.5761898058152375, 0.6620595304471748, 0.9620182627405005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 162}], {
             RGBColor[
             0.6783612972319641, 0.7396843415342684, 0.8176028079995521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 172}], {
             RGBColor[
             0.43594836921694785`, 0.550476074548987, 0.9494253436521863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 180}], {
             RGBColor[
             0.33560394734078897`, 0.46510500406690736`, 0.9426053646550048]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 40}], {
             RGBColor[
             0.658288522559999, 0.6635963321318867, 0.6110992447024585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 45}], {
             RGBColor[
             0.31305819832229476`, 0.440901795522712, 0.9413399519479263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 54}], {
             RGBColor[
             0.6241742030700903, 0.7002952160590157, 0.9665606114668591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 64}], {
             RGBColor[
             0.35194334877904365`, 0.4792573723505287, 0.943646496866285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 65}], {
             RGBColor[
             0.3218882815215859, 0.4501827728247778, 0.9418428121231884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 132}], {
             RGBColor[
             0.33624692196151484`, 0.46527461431752876`, 0.9426605154545374]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 138}], {
             RGBColor[
             0.3369522748460897, 0.4660159849211728, 0.9427006842578378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 153}], {
             RGBColor[
             0.33486113403130835`, 0.4638180633388521, 0.9425815968820017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 182}], {
             RGBColor[
             0.3610470603821736, 0.48714254977531024`, 0.9442265773195404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 185}], {
             RGBColor[
             0.6693456503608732, 0.703060090367622, 0.6427762945837757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 199}], {
             RGBColor[
             0.6795881472313992, 0.7418777188724106, 0.8697570812409984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 86}], {
             RGBColor[
             0.8476569237106388, 0.3655398227682465, 0.19320001765665085`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.6742306361654904, 0.525517764494446, 0.5787071644103513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 110}], {
             RGBColor[
             0.5803304900967676, 0.4444484686049137, 0.5724825862696887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 174}], {
             RGBColor[
             0.5499832600286763, 0.4125516056778312, 0.5707543564120146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 63}], {
             RGBColor[
             0.9875252959724672, 0.9878505747248989, 0.7819194374021715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 70}], {
             RGBColor[
             0.773872973258558, 0.8222654895325952, 0.9384652994997268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 110}], {
             RGBColor[
             0.6408232398533202, 0.7094127949744692, 0.92915872243427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 138}], {
             RGBColor[
             0.6432442431741332, 0.7119574229651198, 0.9292965949918368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 145}], {
             RGBColor[
             0.7685975550758537, 0.817982667396995, 0.9380499992558908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 185}], {
             RGBColor[
             0.9756376186889166, 0.9490015284115689, 0.6293722053177746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 45}], {
             RGBColor[
             0.5066580611996805, 0.5986655756422281, 0.9571214649937063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 47}], {
             RGBColor[
             0.8328167560328059, 0.870053628929629, 0.9837769097217458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 50}], {
             RGBColor[
             0.6199991560357196, 0.7006546627765344, 0.9644089266072209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 97}], {
             RGBColor[
             0.6075276323879591, 0.6905297180435448, 0.9634271225809729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 101}], {
             RGBColor[
             0.8745705271110198, 0.8991111063241333, 0.7825157484201628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 105}], {
             RGBColor[
             0.5420835707302784, 0.6340245853864215, 0.9592075646514909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 134}], {
             RGBColor[
             0.7403504625446278, 0.7970866753025623, 0.9747548732041665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 135}], {
             RGBColor[
             0.5195605785214127, 0.6122269394142161, 0.9578562442676151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 160}], {
             RGBColor[
             0.5930318551499666, 0.6781534286155239, 0.9624539442829145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 43}], {
             RGBColor[
             0.3137356720583649, 0.44222469818026033`, 0.9413561674204441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 60}], {
             RGBColor[
             0.6255900830808414, 0.6925714477124876, 0.9180371394824915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 90}], {
             RGBColor[
             0.2728201221601536, 0.4040816245581051, 0.9388480744045942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 111}], {
             RGBColor[
             0.2861266209830213, 0.41806759850169306`, 0.9396058598273556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 165}], {
             RGBColor[
             0.34376585675942506`, 0.4682353348073489, 0.9432696642349461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 169}], {
             RGBColor[
             0.37223171891341544`, 0.4922121101573379, 0.9452710724444953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 41}], {
             RGBColor[
             0.5729122319442641, 0.6574082868468721, 0.9625974444804515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 74}], {
             RGBColor[
             0.5974069437057714, 0.6786243750346795, 0.9641582258540716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 85}], {
             RGBColor[
             0.6036864562103552, 0.6840633731486746, 0.9645583508381088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 88}], {
             RGBColor[
             0.5842121376424687, 0.6671956972128826, 0.9633174644794269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 108}], {
             RGBColor[
             0.5558903362166727, 0.6395802593120911, 0.9616257636138437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 117}], {
             RGBColor[
             0.8411949962838832, 0.8762100726796123, 0.9847151237608367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 133}], {
             RGBColor[
             0.5894387084611933, 0.6717226901609743, 0.9636504969503208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 152}], {
             RGBColor[
             0.6749905820727509, 0.744187038396769, 0.9695539246612448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 159}], {
             RGBColor[
             0.5512687850348361, 0.6347227159967117, 0.9613625731110103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 173}], {
             RGBColor[
             0.5698108418661225, 0.654211593360698, 0.9624185158170371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 178}], {
             RGBColor[
             0.8780955968119499, 0.9056336099005747, 0.9882347359807586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 49}], {
             RGBColor[
             0.6738252218651131, 0.6770534401727637, 0.6120892294436165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 53}], {
             RGBColor[
             0.7600060988574103, 0.7484935413497109, 0.6184662721418606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 54}], {
             RGBColor[
             0.9145258776250869, 0.8707814106674925, 0.6329942676748506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 64}], {
             RGBColor[
             0.6422950233340402, 0.6497435669590054, 0.6100801530742764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.6122399560765823, 0.6206689674332546, 0.6082764683311799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 69}], {
             RGBColor[
             0.6329510609985868, 0.641650296425238, 0.6094847640568029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 119}], {
             RGBColor[
             0.6243000855274232, 0.6333449281424599, 0.6089632748620426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 123}], {
             RGBColor[
             0.65077312010943, 0.6570868682643141, 0.6106203699039177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 132}], {
             RGBColor[
             0.6265985965165114, 0.6357608089260055, 0.6090941716625289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 171}], {
             RGBColor[
             0.5962649526374729, 0.6038782259450317, 0.6073667155182223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 182}], {
             RGBColor[
             0.6513987349371702, 0.657628744383787, 0.6106602335275317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 191}], {
             RGBColor[
             0.6251327039311332, 0.6342200628758149, 0.6090106912483852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 195}], {
             RGBColor[
             0.6609979355012252, 0.6659430894425228, 0.6112718860992337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 196}], {
             RGBColor[
             0.8399105769172058, 0.8120029572007225, 0.6256869217339316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 199}], {
             RGBColor[
             0.9699398217863957, 0.9123639134808874, 0.5361907374489898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 74}], {
             RGBColor[
             0.333922804406192, 0.4636488825536602, 0.9424982437137885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 85}], {
             RGBColor[
             0.3402023169107758, 0.4690878806676552, 0.9428983686978258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.32072799834288923`, 0.45222020473186325`, 0.9416574823391438]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 108}], {
             RGBColor[
             0.29240619691709335`, 0.42460476683107173`, 0.9399657814735606]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 121}], {
             RGBColor[
             0.31090558053815076`, 0.4437125201184723, 0.9410316065622488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 133}], {
             RGBColor[
             0.3259545691616138, 0.4567471976799549, 0.9419905148100378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 140}], {
             RGBColor[
             0.5500139511191333, 0.6393873207461201, 0.9603503604256642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 151}], {
             RGBColor[
             0.6400912726807143, 0.6777214187888434, 0.6409122315066265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 152}], {
             RGBColor[
             0.41150644277317144`, 0.5292115459157496, 0.9478939425209618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 159}], {
             RGBColor[
             0.28778464573525675`, 0.41974722351569227`, 0.9397025909707273]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 161}], {
             RGBColor[
             0.24554419633275684`, 0.3753498329944873, 0.9372970598663999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 173}], {
             RGBColor[
             0.30632670256654304`, 0.4392361008796787, 0.9407585336767541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 51}], {
             RGBColor[
             0.6726593927785385, 0.7350735410044638, 0.839807043398415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 71}], {
             RGBColor[
             0.3276945856863567, 0.4578947774603484, 0.942114551464774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 73}], {
             RGBColor[
             0.29961980215686795`, 0.4283863999267695, 0.94051573407569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 76}], {
             RGBColor[
             0.29783316749279987`, 0.42650853361565355`, 0.9404139878746604]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 81}], {
             RGBColor[
             0.4467067855806197, 0.5589048333948154, 0.9503566707986787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 87}], {
             RGBColor[
             0.29621994711081867`, 0.42481293671011144`, 0.9403221173604522]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 89}], {
             RGBColor[
             0.3509248796412463, 0.47837522557311585`, 0.9435816009134215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 106}], {
             RGBColor[
             0.26472942591305315`, 0.3917144023168969, 0.9385287787642909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 107}], {
             RGBColor[
             0.38722669007716987`, 0.5098180291906682, 0.9458947201739679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 130}], {
             RGBColor[
             0.3720871115475624, 0.4967048872056644, 0.9449300396174649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 131}], {
             RGBColor[
             0.3850948529772296, 0.5079715390439481, 0.9457588813990693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 142}], {
             RGBColor[
             0.34314914517107664`, 0.471640275194833, 0.9430861379887943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 147}], {
             RGBColor[
             0.55752908318628, 0.6470039196317316, 0.9603605268620541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 149}], {
             RGBColor[
             0.3919158427605906, 0.5138795375613806, 0.9461935088365006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 157}], {
             RGBColor[
             0.4739644387337082, 0.5810338241677736, 0.9525024931029633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 168}], {
             RGBColor[
             0.3564461848247274, 0.4831575026141797, 0.9439334135974145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 176}], {
             RGBColor[
             0.31943980180680576`, 0.44921847621941324`, 0.941644453734692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 188}], {
             RGBColor[
             0.32196634291106635`, 0.45187403111194935`, 0.941788336512897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 189}], {
             RGBColor[
             0.3605072778215646, 0.48667501725157114`, 0.9441921828520894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 197}], {
             RGBColor[
             0.4914328345233762, 0.5952154548120885, 0.9538776692083681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 60}], {
             RGBColor[
             0.6731845563133776, 0.7377344932272161, 0.9209255873016498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[
             0.3204145953926898, 0.44924467007283353`, 0.9417365222237524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 111}], {
             RGBColor[
             0.33372109421555746`, 0.4632306440164215, 0.9424943076465138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 115}], {
             RGBColor[
             0.36006756649588334`, 0.4862941614017998, 0.9441641648352384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 163}], {
             RGBColor[
             0.3392960350865395, 0.46830290490255067`, 0.9428406212213789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 165}], {
             RGBColor[
             0.39136032999196124`, 0.5133983803220774, 0.9461581120541042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 169}], {
             RGBColor[
             0.4198261921459516, 0.5373751556720664, 0.9481595202636532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 58}], {
             RGBColor[
             0.3283788907391444, 0.45502153878107204`, 0.942285060160675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 68}], {
             RGBColor[
             0.33368953442914073`, 0.45962135142463395`, 0.9426234496805838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 77}], {
             RGBColor[
             0.5122111981123197, 0.6042437905921914, 0.9574786297416816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 96}], {
             RGBColor[
             0.2272880846536911, 0.35622456624089577`, 0.9362550922272144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 99}], {
             RGBColor[
             0.2889380403051136, 0.42085985648989693`, 0.9397719240471932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 102}], {
             RGBColor[
             0.32685169619532295`, 0.45369875962624356`, 0.9421877486747878]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[
             0.3318565381537201, 0.4580337021799362, 0.9425066527787689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 143}], {
             RGBColor[
             0.2956753017835201, 0.42669533375788476`, 0.9402012163910709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 166}], {
             RGBColor[
             0.3312635833875747, 0.45752011456427416`, 0.9424688702253995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 172}], {
             RGBColor[
             0.3887435195991333, 0.5057641219953692, 0.9465575620996092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 198}], {
             RGBColor[
             0.24585227228067752`, 0.3757367044743365, 0.9373122952493167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 64}], {
             RGBColor[
             0.29706469909633587`, 0.42704903034983077`, 0.9403208603197443]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 112}], {
             RGBColor[
             0.40198939927970584`, 0.5154184492198793, 0.9477003890825275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 132}], {
             RGBColor[
             0.28136827227880706`, 0.41306627231683085`, 0.9393348789079967]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 134}], {
             RGBColor[
             0.49187194998453415`, 0.5871145531823483, 0.9556477236118459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 153}], {
             RGBColor[
             0.2799824843486005, 0.4116097213381542, 0.939255960335461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 156}], {
             RGBColor[
             0.5377492743197935, 0.26141022676100706`, 0.5511161577006928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 183}], {
             RGBColor[
             0.44955540621903184`, 0.5540346764774173, 0.9514449593888158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 47}], {
             RGBColor[
             0.9516840100212289, 0.9593149248563368, 0.7283823151756925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 50}], {
             RGBColor[
             0.7388664100241424, 0.7899159587032423, 0.7090143320611677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 101}], {
             RGBColor[
             0.9934377810994428, 0.9883724022508413, 0.5271211538741096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 105}], {
             RGBColor[
             0.6609508247187013, 0.7232858813131294, 0.7038129701054376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 135}], {
             RGBColor[
             0.6384278325098356, 0.7014882353409241, 0.7024616497215617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 144}], {
             RGBColor[
             0.6006210838415194, 0.6617509454042091, 0.7003086113149737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 50}], {
             RGBColor[
             0.6976793383087514, 0.7620705939437212, 0.9719572217429397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 101}], {
             RGBColor[
             0.9522507093840517, 0.9605270374913202, 0.7900640435558817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 105}], {
             RGBColor[
             0.6197637530033101, 0.6954405165536084, 0.9667558597872098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 134}], {
             RGBColor[
             0.8180306448176595, 0.8585026064697492, 0.9823031683398854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 135}], {
             RGBColor[
             0.5972407607944445, 0.6736428705814029, 0.9654045394033339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 144}], {
             RGBColor[
             0.5594340121261283, 0.6339055806446879, 0.9632515009967457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 72}], {
             RGBColor[
             0.29008309543331695`, 0.4176323564821478, 0.9399993747940212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 76}], {
             RGBColor[
             0.30178290271411023`, 0.4299295957448882, 0.9406656615103486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 81}], {
             RGBColor[
             0.4506565208019301, 0.56232589552405, 0.9506083444343669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 87}], {
             RGBColor[
             0.30016968233212904`, 0.42823399883934604`, 0.9405737909961405]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 104}], {
             RGBColor[
             0.33082831737856416`, 0.4604581681428839, 0.9423197549066489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 106}], {
             RGBColor[
             0.2686791611343635, 0.39513546444613157`, 0.938780452399979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 147}], {
             RGBColor[
             0.5614788184075903, 0.6504249817609662, 0.9606122004977422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 154}], {
             RGBColor[
             0.28582159435196564`, 0.4131532486508734, 0.9397566886117641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 157}], {
             RGBColor[
             0.47791417395501856`, 0.5844548862970083, 0.9527541667386514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 158}], {
             RGBColor[
             0.3372271603259281, 0.46651094956957806`, 0.942708794351067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 176}], {
             RGBColor[
             0.3233895370281161, 0.45263953834864784`, 0.9418961273703802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 53}], {
             RGBColor[
             0.4851911236075278, 0.5914644547821113, 0.9530226006750273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 54}], {
             RGBColor[
             0.6397109023752043, 0.7137523240998928, 0.9675505962080172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 65}], {
             RGBColor[
             0.3374249808266998, 0.4636398808656549, 0.9428327968643465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 69}], {
             RGBColor[
             0.3581360857487042, 0.48462120985763835`, 0.9440410925899694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 92}], {
             RGBColor[
             0.4003415876974662, 0.5211774943354481, 0.9467303898532846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 118}], {
             RGBColor[
             0.36482445722135237`, 0.49041434105992143`, 0.9444672697059119]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 119}], {
             RGBColor[
             0.3494851102775406, 0.4763158415748602, 0.9435196033952092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 123}], {
             RGBColor[
             0.3759581448595475, 0.5000577816967144, 0.9451766984370843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 127}], {
             RGBColor[
             0.5696796816862766, 0.6585549887842277, 0.9607001485227241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[
             0.6409724793337612, 0.7147582713220517, 0.9676709265445474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 139}], {
             RGBColor[
             0.36697988828825145`, 0.492281267114954, 0.9446046118675219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 141}], {
             RGBColor[
             0.4215228388874934, 0.5395236295156103, 0.9480800404492681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 146}], {
             RGBColor[
             0.6947403236355807, 0.749770459370299, 0.6820626466746268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 155}], {
             RGBColor[
             0.45075517708524515`, 0.5635078020736102, 0.9503116768217648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 171}], {
             RGBColor[
             0.32144997738759035`, 0.446849139377432, 0.941923044051389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 191}], {
             RGBColor[
             0.35031772868125055`, 0.4771909763082152, 0.943567019781552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 195}], {
             RGBColor[
             0.3861829602513427, 0.508914002874923, 0.9458282146324002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 196}], {
             RGBColor[
             0.5650956016673233, 0.6549738706331227, 0.9602432502670982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 199}], {
             RGBColor[
             0.6951248465365132, 0.7553348269132878, 0.8707470659821565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 97}], {
             RGBColor[
             0.4723902146639045, 0.582546683057637, 0.9516074346021668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 101}], {
             RGBColor[
             0.7394331093869653, 0.7911280713382256, 0.7706960604413569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 105}], {
             RGBColor[
             0.4069461530062237, 0.5260415504005138, 0.9473878766726849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 134}], {
             RGBColor[
             0.6052130448205733, 0.6891036403166546, 0.9629351852253605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 135}], {
             RGBColor[
             0.3844231607973581, 0.5042439044283084, 0.946036556288809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 144}], {
             RGBColor[
             0.34661641212904193`, 0.46450661449159336`, 0.9438835178822209]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 73}], {
             RGBColor[
             0.6217473431093002, 0.6854251362974394, 0.8367662199455235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 87}], {
             RGBColor[
             0.6183474880632509, 0.6818516730807813, 0.8365726032302857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 106}], {
             RGBColor[
             0.5868569668654854, 0.6487531386875668, 0.8347792646341243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[
             0.7093542310296022, 0.7668567655613381, 0.8421452060438014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 130}], {
             RGBColor[
             0.6942146524999947, 0.7537436235763343, 0.8411805254872984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 131}], {
             RGBColor[
             0.7072223939296619, 0.765010275414618, 0.8420093672689027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 147}], {
             RGBColor[
             0.8796566241387123, 0.9040426560024015, 0.8566110127318876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 157}], {
             RGBColor[
             0.7960919796861405, 0.8380725605384435, 0.8487529789727968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 168}], {
             RGBColor[
             0.6785737257771597, 0.7401962389848495, 0.8401838994672479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 189}], {
             RGBColor[
             0.6826348187739969, 0.743713753622241, 0.8404426687219229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 197}], {
             RGBColor[
             0.8135603754758085, 0.8522541911827584, 0.8501281550782016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 66}], {
             RGBColor[
             0.694717159710663, 0.7574418691363787, 0.9419704782051865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 80}], {
             RGBColor[
             0.6965042403178624, 0.7587746709271521, 0.9389454168824682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 82}], {
             RGBColor[
             0.5697670927973744, 0.6594986295453169, 0.9603383693180876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 100}], {
             RGBColor[
             0.3898136590594897, 0.512058731698312, 0.9460595595499546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 120}], {
             RGBColor[
             0.42895931350754923`, 0.5459647300634204, 0.9485538860362418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 124}], {
             RGBColor[
             0.34485538067649263`, 0.46954411073390334`, 0.9433257201826634]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 125}], {
             RGBColor[
             0.6502087797523062, 0.7228318132321725, 0.9682256088944985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 187}], {
             RGBColor[
             0.54674919486033, 0.6415168727343943, 0.958044160366209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 54}], {
             RGBColor[
             0.7258917793675017, 0.7851924252768399, 0.9739276389062612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 65}], {
             RGBColor[
             0.4236058578189971, 0.535079982042602, 0.9492098395625905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 69}], {
             RGBColor[
             0.4443169627410015, 0.5560613110345856, 0.9504181352882135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 92}], {
             RGBColor[
             0.4865224646897635, 0.5926175955123953, 0.9531074325515286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 118}], {
             RGBColor[
             0.45100533421364963`, 0.5618544422368685, 0.9508443124041559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 119}], {
             RGBColor[
             0.4356659872698379, 0.5477559427518073, 0.9498966460934533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 123}], {
             RGBColor[
             0.46213902185184474`, 0.5714978828736615, 0.9515537411353283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 127}], {
             RGBColor[
             0.6558605586785738, 0.7299950899611748, 0.9670771912209681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 129}], {
             RGBColor[
             0.7271533563260586, 0.7861983724989989, 0.9740479692427915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 139}], {
             RGBColor[
             0.4531607652805487, 0.5637213682919012, 0.9509816545657659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 141}], {
             RGBColor[
             0.5077037158797907, 0.6109637306925575, 0.9544570831475121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 146}], {
             RGBColor[
             0.7809212006278781, 0.8212105605472462, 0.6884396893728709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 155}], {
             RGBColor[
             0.5369360540775425, 0.6349479032505573, 0.9566887195200088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 171}], {
             RGBColor[
             0.40763085437988766`, 0.5182892405543791, 0.9483000867496331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 182}], {
             RGBColor[
             0.46276463667958484`, 0.5720397589931345, 0.9515936047589425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 191}], {
             RGBColor[
             0.43649860567354787`, 0.5486310774851624, 0.949944062479796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 195}], {
             RGBColor[
             0.47236383724363995`, 0.5803541040518703, 0.9522052573306443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 196}], {
             RGBColor[
             0.6512764786596206, 0.72641397181007, 0.9666202929653422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 199}], {
             RGBColor[
             0.7813057235288104, 0.8267749280902349, 0.8771241086804005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 64}], {
             RGBColor[
             0.6081807038441316, 0.6864424508861344, 0.9655415198386771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 65}], {
             RGBColor[
             0.5781256365866737, 0.6573678513603836, 0.9637378350955805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 118}], {
             RGBColor[
             0.6055251129813262, 0.6841423115546501, 0.9653723079371459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 119}], {
             RGBColor[
             0.5901857660375145, 0.6700438120695889, 0.9644246416264433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 123}], {
             RGBColor[
             0.6166588006195213, 0.693785752191443, 0.9660817366683183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 127}], {
             RGBColor[
             0.8103803374462504, 0.8522829592789563, 0.9816051867539581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 140}], {
             RGBColor[
             0.83550568386438, 0.8719110708605045, 0.9841094464752056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 151}], {
             RGBColor[
             0.9255830054259611, 0.9102451689032277, 0.6646713175561678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 155}], {
             RGBColor[
             0.691455832845219, 0.7572357725683387, 0.9712167150529987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 171}], {
             RGBColor[
             0.5621506331475643, 0.6405771098721607, 0.962828082282623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 172}], {
             RGBColor[
             0.6952642472660904, 0.7603276149623166, 0.9715165273868914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 191}], {
             RGBColor[
             0.5910183844412245, 0.670918946802944, 0.9644720580127859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 195}], {
             RGBColor[
             0.6268836160113165, 0.7026419733696517, 0.9667332528636343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 199}], {
             RGBColor[
             0.935825502296487, 0.9490627974080164, 0.8916521042133905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 90}], {
             RGBColor[
             0.28360161687679225`, 0.4154136590915394, 0.9394620645789147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 108}], {
             RGBColor[
             0.28154424472430395`, 0.41325123051434554`, 0.9393449002784398]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 111}], {
             RGBColor[
             0.2969081156996599, 0.4293996330351273, 0.9402198500016761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 115}], {
             RGBColor[
             0.32325458797998574`, 0.45246315042050567`, 0.9418897071904007]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 163}], {
             RGBColor[
             0.3024830565706419, 0.4344718939212565, 0.9405661635765413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.35454735147606364`, 0.4795673693407832, 0.9438836544092666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 175}], {
             RGBColor[
             0.2926324919336092, 0.42490568136680384`, 0.9399763595534181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 177}], {
             RGBColor[
             0.631251035387699, 0.7002253021472533, 0.9336202452358018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 183}], {
             RGBColor[
             0.46431772602879134`, 0.5695508105826105, 0.9522856516630864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 109}], {
             RGBColor[
             0.6921978643368916, 0.7529030696003758, 0.8743628013559626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 148}], {
             RGBColor[
             0.40494360182351663`, 0.5251635276674776, 0.9470236261239953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 150}], {
             RGBColor[
             0.38187153785225014`, 0.5051796654912197, 0.9455534946095712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 193}], {
             RGBColor[
             0.67868129185288, 0.7023647715881138, 0.6299872957347197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 88}], {
             RGBColor[
             0.29833030769404856`, 0.42874187588976487`, 0.9403796579045467]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 91}], {
             RGBColor[
             0.25360941424940986`, 0.38388995251468183`, 0.9377540530087729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 103}], {
             RGBColor[
             0.3613337093730228, 0.48318418611672276`, 0.9444295649776476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 117}], {
             RGBColor[
             0.555313166335463, 0.6377562513564945, 0.9617773171859565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 121}], {
             RGBColor[
             0.2885078898893101, 0.42023419127637396`, 0.9397537821276517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 152}], {
             RGBColor[
             0.3891087521243307, 0.5057332170736513, 0.9466161180863646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 164}], {
             RGBColor[
             0.293164339173305, 0.42426737360622435`, 0.9400504869584915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 178}], {
             RGBColor[
             0.5922137668635299, 0.6671797885774571, 0.9652969294058784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 200}], {
             RGBColor[
             0.31586554448500964`, 0.44393001665146803`, 0.9414969876870656]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 77}], {
             RGBColor[
             0.5732199860502001, 0.6609120207125367, 0.9612259860376701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 96}], {
             RGBColor[
             0.28829687259157144`, 0.4128927963612411, 0.9400024485232028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 99}], {
             RGBColor[
             0.34994682824299395`, 0.47752808661024226`, 0.9435192803431817]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 102}], {
             RGBColor[
             0.3878604841332033, 0.5103669897465889, 0.9459351049707763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 125}], {
             RGBColor[
             0.6350921920233517, 0.7097385847231432, 0.9672623932914832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 128}], {
             RGBColor[
             0.3928653260916004, 0.5147019323002815, 0.9462540090747573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 137}], {
             RGBColor[
             0.4317177567210531, 0.5477910913160622, 0.9488851724926288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 166}], {
             RGBColor[
             0.392272371325455, 0.5141883446846195, 0.9462162265213879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 170}], {
             RGBColor[
             0.6619285397992827, 0.6447949054363156, 0.6060815810592608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 192}], {
             RGBColor[
             0.40561598749898914`, 0.5257459143444853, 0.947066469944669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 198}], {
             RGBColor[
             0.30686106021855786`, 0.4324049345946818, 0.9410596515453051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 62}], {
             RGBColor[
             0.2927568297307811, 0.424973304149662, 0.9399857494935853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 92}], {
             RGBColor[
             0.35555051071219335`, 0.4823817147157925, 0.9438763420349772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 114}], {
             RGBColor[
             0.3351741100834504, 0.4647327006388494, 0.9425779758050573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 146}], {
             RGBColor[
             0.6499492466503078, 0.7109746797506433, 0.6792085988563195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 184}], {
             RGBColor[
             0.30311857202820636`, 0.43586415227666253`, 0.9405758353885997]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 186}], {
             RGBColor[
             0.6518796614972249, 0.7171783133409075, 0.8422735879787728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[
             0.30632670256654304`, 0.4392361008796787, 0.9407585336767541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 90}], {
             RGBColor[
             0.6322690064151663, 0.6995914196050608, 0.9184174942857998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 111}], {
             RGBColor[
             0.6455755052380339, 0.7135773935486488, 0.9191752797085612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 165}], {
             RGBColor[
             0.7032147410144377, 0.7637451298543046, 0.9228390841161516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 169}], {
             RGBColor[
             0.7316806031684281, 0.7877219052042936, 0.9248404923257008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 67}], {
             RGBColor[
             0.5592908058554599, 0.6521744066128277, 0.958930226942549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 79}], {
             RGBColor[
             0.5016902441413076, 0.6022836951444392, 0.9552599700843001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 84}], {
             RGBColor[
             0.8235961185776961, 0.8624737390942208, 0.9534262682776073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 122}], {
             RGBColor[
             0.4836196199731977, 0.5847623479524975, 0.9541769767412619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 126}], {
             RGBColor[
             0.7202117426790922, 0.7813541542836661, 0.9727476338150072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 179}], {
             RGBColor[
             0.4864458632098799, 0.5877329087884215, 0.9543379271125387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 190}], {
             RGBColor[
             0.48884133703142085`, 0.5902507036566735, 0.9544743458028896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 192}], {
             RGBColor[
             0.5502787878137032, 0.6443686495422551, 0.9583559891219431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 114}], {
             RGBColor[
             0.3185028471695468, 0.44727321042265866`, 0.9416262629584742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 141}], {
             RGBColor[
             0.36006049898831693`, 0.4832683596797639, 0.9442742797843775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 149}], {
             RGBColor[
             0.3546927002559762, 0.4786190422112193, 0.9439322483957109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 167}], {
             RGBColor[
             0.2928103250212307, 0.425019639081498, 0.9399891581661888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 184}], {
             RGBColor[
             0.2864473091143027, 0.4184046620604718, 0.9396241225420165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 189}], {
             RGBColor[
             0.3232841353169502, 0.4514145219014098, 0.9419309224112996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 194}], {
             RGBColor[
             0.2896554396526394, 0.4217766106634879, 0.9398068208301709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 197}], {
             RGBColor[
             0.4542096920187618, 0.5599549594619272, 0.9516164087675785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 70}], {
             RGBColor[
             0.7808774845699358, 0.8251230506461901, 0.8025273269394334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 110}], {
             RGBColor[
             0.647827751164698, 0.7122703560880641, 0.7932207498739766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 132}], {
             RGBColor[
             0.649543401600936, 0.7140736134750707, 0.7933184536282429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 138}], {
             RGBColor[
             0.6502487544855109, 0.7148149840787148, 0.7933586224315434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 145}], {
             RGBColor[
             0.7756020663872316, 0.82084022851059, 0.8021120266955974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 153}], {
             RGBColor[
             0.6481576136707295, 0.7126170624963941, 0.7932395350557073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 185}], {
             RGBColor[
             0.9826421300002944, 0.951859089525164, 0.4934342327574813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 65}], {
             RGBColor[
             0.305894782295627, 0.43633000765189656`, 0.9408237204950064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 132}], {
             RGBColor[
             0.320253422735556, 0.45142184914464745`, 0.9416414238263554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 138}], {
             RGBColor[
             0.32095877562013087`, 0.45216321974829154`, 0.9416815926296558]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 153}], {
             RGBColor[
             0.3188676348053495, 0.44996529816597086`, 0.9415625052538197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 156}], {
             RGBColor[
             0.5766344247765425, 0.29976580358882365`, 0.5534227026190515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 182}], {
             RGBColor[
             0.3450535611562147, 0.473289784602429, 0.9432074856913584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 185}], {
             RGBColor[
             0.6533521511349143, 0.6892073251947407, 0.6417572029555937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 199}], {
             RGBColor[
             0.6635946480054403, 0.7280249536995294, 0.8687379896128163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 118}], {
             RGBColor[
             0.3032391914328217, 0.43402986832041224`, 0.9406545085934752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 119}], {
             RGBColor[
             0.28789984448900996`, 0.419931368835351, 0.9397068422827726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 123}], {
             RGBColor[
             0.3143728790710168, 0.4436733089572052, 0.9413639373246476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 127}], {
             RGBColor[
             0.5080944158977458, 0.6021705160447184, 0.9568873874102874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 140}], {
             RGBColor[
             0.5332197623158754, 0.6217986276262666, 0.9593916471315349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 151}], {
             RGBColor[
             0.6232970838774565, 0.6601327256689898, 0.6399535182124971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 155}], {
             RGBColor[
             0.3891699112967145, 0.5071233293341009, 0.946498915709328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 156}], {
             RGBColor[
             0.5465793575190846, 0.27069120406307284`, 0.5516190178759549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 171}], {
             RGBColor[
             0.2598647115990597, 0.3904646666379228, 0.9381102829389523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 172}], {
             RGBColor[
             0.39297832571758584`, 0.5102151717280787, 0.9467987280432207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 191}], {
             RGBColor[
             0.2887324628927199, 0.420806503568706, 0.9397542586691152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 195}], {
             RGBColor[
             0.324597694462812, 0.45252953013541386`, 0.9420154535199636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 199}], {
             RGBColor[
             0.6335395807479824, 0.6989503541737785, 0.8669343048697198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 78}], {
             RGBColor[
             0.6487709487417397, 0.7176455705188072, 0.9390428262708859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 80}], {
             RGBColor[
             0.9716005458935918, 0.9783403141440546, 0.9329570474249607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 82}], {
             RGBColor[
             0.8448633983731038, 0.8790642727622193, 0.95434999986058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[
             0.9810647712000207, 0.9840490135095168, 0.8564940632684488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 100}], {
             RGBColor[
             0.6649099646352191, 0.7316243749152145, 0.940071190092447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 113}], {
             RGBColor[
             0.7047510406598094, 0.7661327124970092, 0.9426098282266535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 120}], {
             RGBColor[
             0.7040556190832786, 0.7655303732803229, 0.9425655165787342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 124}], {
             RGBColor[
             0.6199516862522221, 0.6891097539508059, 0.9373373507251558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 136}], {
             RGBColor[
             0.6534635034295474, 0.72171002553473, 0.9393418317061297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 187}], {
             RGBColor[
             0.8218455004360594, 0.8610825159512967, 0.9520557909087014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 79}], {
             RGBColor[
             0.38226777069031465`, 0.5055228624603096, 0.9455787422156378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 82}], {
             RGBColor[
             0.579890831932141, 0.6682673035499278, 0.9609834450236838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 100}], {
             RGBColor[
             0.39993739819425644`, 0.520827405702923, 0.9467046352555508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 122}], {
             RGBColor[
             0.3641971465222047, 0.48800151526836805`, 0.9444957488725996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 125}], {
             RGBColor[
             0.6603325188870728, 0.7316004872367836, 0.9688706846000948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 137}], {
             RGBColor[
             0.4569580835847742, 0.5696529938297026, 0.9504934638012403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 166}], {
             RGBColor[
             0.41751269818917613`, 0.5360502471982599, 0.9478245178299995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 170}], {
             RGBColor[
             0.6871688666630038, 0.666656807949956, 0.6076898723678724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 179}], {
             RGBColor[
             0.36702338975888693`, 0.49097207610429205`, 0.9446566992438764]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 192}], {
             RGBColor[
             0.4308563143627102, 0.5476078168581257, 0.9486747612532807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 71}], {
             RGBColor[
             0.35243314280181226`, 0.47932207223772205`, 0.9436908704487237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 75}], {
             RGBColor[
             0.3925029652634414, 0.514388073563715, 0.9462309197632102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 81}], {
             RGBColor[
             0.4714453426960753, 0.580332128172189, 0.9519329897826283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 102}], {
             RGBColor[
             0.39317112782319963`, 0.5149668023901508, 0.946273494490685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 127}], {
             RGBColor[
             0.57017904140717, 0.6589875090759162, 0.9607319672825729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 129}], {
             RGBColor[
             0.6414718390546548, 0.7151907916137403, 0.9677027453043963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 140}], {
             RGBColor[
             0.5953043878252996, 0.6786156206574643, 0.9632362270038204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 143}], {
             RGBColor[
             0.36199473341139676`, 0.487963376521792, 0.9442869622069681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 155}], {
             RGBColor[
             0.45125453680613864`, 0.5639403223652987, 0.9503434955816136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 172}], {
             RGBColor[
             0.45506295122700996`, 0.5670321647592765, 0.9506433079155063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 188}], {
             RGBColor[
             0.34670490002652193`, 0.473301325889323, 0.9433646554968467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 86}], {
             RGBColor[
             0.5765202435777357, 0.3626166753872062, 0.5616657624415775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 92}], {
             RGBColor[
             0.3594674268309399, 0.48577435058792245`, 0.9441259244664708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 118}], {
             RGBColor[
             0.3239502963548261, 0.4550111973123957, 0.9418628043190982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 123}], {
             RGBColor[
             0.3350839839930212, 0.46465463794918865`, 0.9425722330502706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 139}], {
             RGBColor[
             0.32610572742172517`, 0.4568781233674283, 0.9420001464807082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 146}], {
             RGBColor[
             0.6538661627690545, 0.7143673156227732, 0.6794581812878131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 171}], {
             RGBColor[
             0.28057581652106406`, 0.41144599562990625`, 0.9393185786645752]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 174}], {
             RGBColor[
             0.2788465798957732, 0.40962845829679095`, 0.9392201011969412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 186}], {
             RGBColor[
             0.6557965776159713, 0.7205709492130374, 0.8425231704102664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 191}], {
             RGBColor[
             0.30944356781472426`, 0.4417878325606895, 0.9409625543947382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 195}], {
             RGBColor[
             0.3453087993848164, 0.4735108591273973, 0.9432237492455865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 196}], {
             RGBColor[
             0.524221440800797, 0.619570726885597, 0.9576387848802845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 110}], {
             RGBColor[
             0.4341754284507888, 0.5466852708957604, 0.9497666119715319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 132}], {
             RGBColor[
             0.4358910788870269, 0.548488528282767, 0.9498643157257982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 138}], {
             RGBColor[
             0.43659643177160173`, 0.5492298988864109, 0.9499044845290987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.5619497436733223, 0.655255143318286, 0.9586578887931527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 185}], {
             RGBColor[
             0.7689898072863852, 0.7862740043328601, 0.6499800948550365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 73}], {
             RGBColor[
             0.2767825360171184, 0.408246372753324, 0.9390737280118824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 75}], {
             RGBColor[
             0.34492714200823626`, 0.4728207516128958, 0.9432125947154529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 76}], {
             RGBColor[
             0.2749959013530503, 0.4063685064422081, 0.9389719818108528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 81}], {
             RGBColor[
             0.42386951944087015`, 0.5387648062213699, 0.9489146647348712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 87}], {
             RGBColor[
             0.2733826809710691, 0.40467290953666596`, 0.9388801112966447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 89}], {
             RGBColor[
             0.32808761350149673`, 0.45823519839967036`, 0.9421395948496138]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 107}], {
             RGBColor[
             0.3643894239374203, 0.4896780020172227, 0.9444527141101604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 127}], {
             RGBColor[
             0.5226032181519649, 0.617420187125097, 0.9577136422348158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 129}], {
             RGBColor[
             0.5938960157994495, 0.6736234696629212, 0.9646844202566391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 141}], {
             RGBColor[
             0.3744463753531817, 0.4983888278564797, 0.9450935341613598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 142}], {
             RGBColor[
             0.3203118790313271, 0.45150024802138744`, 0.9416441319249866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 147}], {
             RGBColor[
             0.5346918170465305, 0.6268638924582861, 0.9589185207982465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 155}], {
             RGBColor[
             0.4036787135509335, 0.5223730004144795, 0.9473251705338563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 168}], {
             RGBColor[
             0.33360891868497783`, 0.46301747544073424`, 0.9424914075336068]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 188}], {
             RGBColor[
             0.2991290767713168, 0.43173400393850386`, 0.9403463304490894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 197}], {
             RGBColor[
             0.46859556838362665`, 0.5750754276386429, 0.9524356631445605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 76}], {
             RGBColor[
             0.2334346758787002, 0.3626850233347729, 0.9366051315044117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 81}], {
             RGBColor[
             0.38230829396652, 0.4950813231139347, 0.9465478144284301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 104}], {
             RGBColor[
             0.26248009054315413`, 0.3932135957327686, 0.938259224900712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 143}], {
             RGBColor[
             0.2728576846818415, 0.40271257146353767`, 0.9389017868527698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 144}], {
             RGBColor[
             0.21505297727216288`, 0.34336469263229635`, 0.9355583209620557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 154}], {
             RGBColor[
             0.2174733675165556, 0.34590867624075816`, 0.9356961586058273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 158}], {
             RGBColor[
             0.26887893349051806`, 0.3992663771594628, 0.9386482643451302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 160}], {
             RGBColor[
             0.32633100256903297`, 0.4490284717703191, 0.9423090593839433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 176}], {
             RGBColor[
             0.2550413101927061, 0.3853949659385326, 0.9378355973644434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 181}], {
             RGBColor[
             0.2738885394594801, 0.40360544605966064`, 0.9389674720076518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 75}], {
             RGBColor[
             0.3168523584787475, 0.4433123740793169, 0.9416137773263689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 87}], {
             RGBColor[
             0.24530789744158038`, 0.3751645320030871, 0.9372812939075605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.300012829972008, 0.4287268208660915, 0.9405407774605298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 107}], {
             RGBColor[
             0.3363146404079316, 0.46016962448364385`, 0.9428538967210762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 130}], {
             RGBColor[
             0.3211750618783241, 0.44705648249864005`, 0.9418892161645733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 142}], {
             RGBColor[
             0.2922370955018384, 0.42199187048780856`, 0.9400453145359027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 147}], {
             RGBColor[
             0.5066170335170417, 0.5973555149247072, 0.9573197034091625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 149}], {
             RGBColor[
             0.3410037930913523, 0.46423113285435624`, 0.943152685383609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 157}], {
             RGBColor[
             0.4230523890644699, 0.5313854194607492, 0.9494616696500717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 167}], {
             RGBColor[
             0.2791214178566068, 0.4106317297246349, 0.9392095951540869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 168}], {
             RGBColor[
             0.3055341351554891, 0.4335090979071553, 0.9408925901445228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 188}], {
             RGBColor[
             0.27105429324182806`, 0.402225626404925, 0.9387475130600054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 189}], {
             RGBColor[
             0.3095952281523263, 0.4370266125445467, 0.9411513593991977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 197}], {
             RGBColor[
             0.4405207848541379, 0.5455670501050641, 0.9508368457554766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 85}], {
             RGBColor[
             0.36469702867228304`, 0.4903039688554627, 0.9444591500714459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 88}], {
             RGBColor[
             0.34522271010439654`, 0.4734362929196707, 0.943218263712764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 93}], {
             RGBColor[
             0.3946155177616537, 0.5162178603576906, 0.9463655297403395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 95}], {
             RGBColor[
             0.5960654892101602, 0.3725034958571408, 0.5619881903277077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 121}], {
             RGBColor[
             0.33540029229965806`, 0.4649286083062798, 0.942592387935869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 140}], {
             RGBColor[
             0.5745086628806405, 0.6606034089339275, 0.9619111417992843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 152}], {
             RGBColor[
             0.4360011545346787, 0.5504276341035571, 0.9494547238945819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 159}], {
             RGBColor[
             0.31227935749676394`, 0.4409633117034998, 0.9412633723443473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 161}], {
             RGBColor[
             0.2700389080942641, 0.39656592118229483`, 0.9388578412400199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 162}], {
             RGBColor[
             0.6766801542973673, 0.7382282200210213, 0.8174956870583359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 164}], {
             RGBColor[
             0.34005674158365296`, 0.46896179063613014`, 0.9428890927667087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 172}], {
             RGBColor[
             0.43426722628235087`, 0.5490199530357398, 0.9493182227109702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 173}], {
             RGBColor[
             0.3308214143280503, 0.4604521890674862, 0.9423193150503741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 180}], {
             RGBColor[
             0.333922804406192, 0.4636488825536602, 0.9424982437137885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 81}], {
             RGBColor[
             0.4639393419024993, 0.5738308075473628, 0.9514547140493577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 89}], {
             RGBColor[
             0.3681574359631259, 0.4933011997256632, 0.9446796441641003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 118}], {
             RGBColor[
             0.3578178161486698, 0.4843455407267837, 0.9440208127324901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 127}], {
             RGBColor[
             0.562673040613594, 0.65248618845109, 0.9602536915493023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 129}], {
             RGBColor[
             0.6339658382610787, 0.708689470988914, 0.9672244695711256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 141}], {
             RGBColor[
             0.41451619781481086`, 0.5334548291824726, 0.9476335834758463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 142}], {
             RGBColor[
             0.36038170149295623`, 0.48656624934738035`, 0.9441841812394731]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 147}], {
             RGBColor[
             0.5747616395081595, 0.661929893784279, 0.961458570112733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 155}], {
             RGBColor[
             0.4437485360125626, 0.5574390017404725, 0.9498652198483428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 168}], {
             RGBColor[
             0.37367874114660693`, 0.4980834767667271, 0.9450314568480933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 188}], {
             RGBColor[
             0.3391988992329459, 0.4668000052644967, 0.9428863797635759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 191}], {
             RGBColor[
             0.343311087608568, 0.4711221759750775, 0.9431205628081301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 81}], {
             RGBColor[
             0.39400810124731334`, 0.5073785623766751, 0.9472141011447575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 87}], {
             RGBColor[
             0.24352126277751232`, 0.3732866656919711, 0.937179547706531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 89}], {
             RGBColor[
             0.2982261953079399, 0.4268489545549755, 0.9404390312595001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[
             0.27417989782394747`, 0.405510834995509, 0.9389255116170394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 106}], {
             RGBColor[
             0.21203074157974677`, 0.34018813129875664`, 0.9353862091103695]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 107}], {
             RGBColor[
             0.33452800574386354`, 0.4582917581725279, 0.9427521505200467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 142}], {
             RGBColor[
             0.2904504608377703, 0.42011400417669265`, 0.939943568334873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 143}], {
             RGBColor[
             0.2845574919626348, 0.41500981072627807`, 0.9395680735690972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 147}], {
             RGBColor[
             0.5048303988529736, 0.5954776486135913, 0.9572179572081329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 154}], {
             RGBColor[
             0.22917317479734894`, 0.35820591550349845`, 0.9363624453221546]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[
             0.4212657544004018, 0.5295075531496333, 0.9493599234490421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 158}], {
             RGBColor[
             0.2805787407713114, 0.4115636164222032, 0.9393145510614576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 176}], {
             RGBColor[
             0.26674111747349943`, 0.3976922052012729, 0.9385018840807708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 181}], {
             RGBColor[
             0.28558834674027345`, 0.415902685322401, 0.9396337587239791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 188}], {
             RGBColor[
             0.26926765857776, 0.400347760093809, 0.9386457668589758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 83}], {
             RGBColor[
             0.5196613109353557, 0.6120743315336377, 0.9579029026454993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 96}], {
             RGBColor[
             0.4721291799647468, 0.5621150481723605, 0.9551960181042094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 99}], {
             RGBColor[
             0.5337791356161693, 0.6267503384213616, 0.9587128499241883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 112}], {
             RGBColor[
             0.6514257716716001, 0.7261388587207003, 0.966903009191173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 143}], {
             RGBColor[
             0.5405163970945758, 0.6325858156893495, 0.9591421422680659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 156}], {
             RGBColor[
             0.7871856467116878, 0.47213063626182805`, 0.5703187778093384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 160}], {
             RGBColor[
             0.5939897149817672, 0.6789017159961308, 0.9625494147992394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 166}], {
             RGBColor[
             0.5761046786986304, 0.6634105964957389, 0.9614097961023945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 170}], {
             RGBColor[
             0.845760847172458, 0.7940171572474349, 0.6212751506402674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 181}], {
             RGBColor[
             0.5415472518722144, 0.6334786902854724, 0.959207827422948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 183}], {
             RGBColor[
             0.6989917786109261, 0.7647550859782384, 0.9706475794974614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 192}], {
             RGBColor[
             0.5894482948721645, 0.6749681661556046, 0.9622600395256756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 80}], {
             RGBColor[
             0.650558029348939, 0.7189783723095806, 0.9360177649481676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 82}], {
             RGBColor[
             0.5238208818284511, 0.6197023309277454, 0.9574107173837869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 98}], {
             RGBColor[
             0.660022254655368, 0.7246870716750429, 0.8595547807916557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 100}], {
             RGBColor[
             0.34386744809056646`, 0.47226243308074056`, 0.9431319076156538]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 113}], {
             RGBColor[
             0.38370852411515677`, 0.5067707706625353, 0.9456705457498604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 120}], {
             RGBColor[
             0.3830131025386259, 0.506168431445849, 0.945626234101941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 124}], {
             RGBColor[
             0.2989091697075693, 0.4297478121163319, 0.9403980682483626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 136}], {
             RGBColor[
             0.33242098688489474`, 0.46234808370025593`, 0.9424025492293366]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 187}], {
             RGBColor[
             0.5008029838914068, 0.6017205741168228, 0.9551165084319082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 84}], {
             RGBColor[
             0.6465730834125509, 0.7158221949417027, 0.940074783550696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 122}], {
             RGBColor[
             0.30659658480805246`, 0.4381108037999796, 0.9408254920143506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 126}], {
             RGBColor[
             0.543188707513947, 0.6347026101311481, 0.9593961490880958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 177}], {
             RGBColor[
             0.6497325457462272, 0.7181785167770137, 0.9347266379395327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 179}], {
             RGBColor[
             0.30942282804473475`, 0.44108136463590364`, 0.9409864423856275]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 190}], {
             RGBColor[
             0.3118183018662756, 0.4435991595041556, 0.9411228610759783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 82}], {
             RGBColor[
             0.8466504789803032, 0.8803970745529928, 0.9513249385378617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 98}], {
             RGBColor[
             0.9828518518072202, 0.9853818153002902, 0.8534690019457306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 100}], {
             RGBColor[
             0.6666970452424186, 0.7329571767059879, 0.9370461287697287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 113}], {
             RGBColor[
             0.7065381212670089, 0.7674655142877826, 0.9395847669039353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 116}], {
             RGBColor[
             0.5856509634063437, 0.6525119862135014, 0.9322571423829057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 120}], {
             RGBColor[
             0.7058426996904781, 0.7668631750710964, 0.939540455256016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 124}], {
             RGBColor[
             0.6217387668594214, 0.6904425557415793, 0.9343122894024376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 125}], {
             RGBColor[
             0.9270921659352349, 0.9437302582398486, 0.9592121781142727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 136}], {
             RGBColor[
             0.6552505840367469, 0.7230428273255034, 0.9363167703834114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 137}], {
             RGBColor[
             0.7237177306329364, 0.7817827648327675, 0.9408349573154182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 187}], {
             RGBColor[
             0.823632581043259, 0.8624153177420701, 0.9490307295859832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 198}], {
             RGBColor[
             0.5988610341304411, 0.6663966081113872, 0.9330094363680947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 87}], {
             RGBColor[
             0.39239488086533214`, 0.505682965471133, 0.9471222306305493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 89}], {
             RGBColor[
             0.44709981339575977`, 0.5592452543341373, 0.9503817141835185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 104}], {
             RGBColor[
             0.42305351591176726`, 0.5379071347746708, 0.9488681945410578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 107}], {
             RGBColor[
             0.48340162383168334`, 0.5906880579516898, 0.952694833444065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 142}], {
             RGBColor[
             0.4393240789255901, 0.5525103039558544, 0.9498862512588914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 143}], {
             RGBColor[
             0.43343111005045465`, 0.5474061105054399, 0.9495107564931156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 147}], {
             RGBColor[
             0.6537040169407935, 0.7278739483927531, 0.9671606401321512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 154}], {
             RGBColor[
             0.37804679288516874`, 0.4906022152826603, 0.946305128246173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 157}], {
             RGBColor[
             0.5701393724882217, 0.6619038529287951, 0.9593026063730604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 158}], {
             RGBColor[
             0.4294523588591312, 0.543959916201365, 0.9492572339854759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 168}], {
             RGBColor[
             0.45262111857924087`, 0.5640275313752012, 0.9507335268675114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 176}], {
             RGBColor[
             0.4156147355613192, 0.5300885049804347, 0.9484445670047892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 188}], {
             RGBColor[
             0.4181412766655798, 0.5327440598729709, 0.9485884497829942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 98}], {
             RGBColor[
             0.8561147042867321, 0.886105773918455, 0.8748619543813498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 100}], {
             RGBColor[
             0.5399598977219305, 0.6336811353241527, 0.958439081205348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 120}], {
             RGBColor[
             0.57910555216999, 0.6675871336892611, 0.9609334076916353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 124}], {
             RGBColor[
             0.49500161933893344`, 0.591166514359744, 0.9557052418380568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 125}], {
             RGBColor[
             0.800355018414747, 0.8444542168580133, 0.980605130549892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 136}], {
             RGBColor[
             0.5285134365162588, 0.6237667859436681, 0.9577097228190308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 137}], {
             RGBColor[
             0.5969805831124484, 0.6825067234509323, 0.9622279097510376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 187}], {
             RGBColor[
             0.6968954335227708, 0.7631392763602349, 0.9704236820216025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 198}], {
             RGBColor[
             0.4721238866099531, 0.5671205667295519, 0.954402388803714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 122}], {
             RGBColor[
             0.28539814454363926`, 0.41730192357582857`, 0.9395643741718172]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 156}], {
             RGBColor[
             0.549794664223668, 0.2740706952718096, 0.5518021248361609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 166}], {
             RGBColor[
             0.3387136962106107, 0.4653506555057204, 0.9428931431292171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 170}], {
             RGBColor[
             0.6083698646844383, 0.5959572162574165, 0.60275849766709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 175}], {
             RGBColor[
             0.2899155620277242, 0.42205001577241325`, 0.9398216344146155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 179}], {
             RGBColor[
             0.28822438778032156`, 0.4202724844117526, 0.939725324543094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 183}], {
             RGBColor[
             0.4616007961229064, 0.5666951449882198, 0.9521309265242839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 192}], {
             RGBColor[
             0.35205731238414484`, 0.4769082251655862, 0.9437433865524982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 126}], {
             RGBColor[
             0.8650945819503355, 0.8948926540809297, 0.957562447281403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 190}], {
             RGBColor[
             0.6337241763026642, 0.7037892034539373, 0.9392891592692855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 88}], {
             RGBColor[
             0.35150222260898034`, 0.4788752910336657, 0.943618388696801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 117}], {
             RGBColor[
             0.6084850812503948, 0.6878896665003954, 0.965016047978211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[
             0.34167980480424187`, 0.47036760642027475`, 0.9429925129199062]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 133}], {
             RGBColor[
             0.3567287934277049, 0.4834022839817574, 0.9439514211676951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 140}], {
             RGBColor[
             0.5807881753852243, 0.6660424070479226, 0.9623112667833215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 152}], {
             RGBColor[
             0.4422806670392625, 0.5558666322175521, 0.949854848878619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 159}], {
             RGBColor[
             0.31855887000134775`, 0.44640230981749474`, 0.9416634973283846]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 161}], {
             RGBColor[
             0.2763184205988479, 0.4020049192962898, 0.9392579662240572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 173}], {
             RGBColor[
             0.3371009268326341, 0.46589118718148115`, 0.9427194400344114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 200}], {
             RGBColor[
             0.3690374593999414, 0.4940634317953688, 0.9447357184793201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 92}], {
             RGBColor[
             0.6187257455264976, 0.3991729598650161, 0.5643550597048926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[
             0.6623522747281451, 0.4359932263904994, 0.5674020444336999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 171}], {
             RGBColor[
             0.5398341352166218, 0.32484460490699985`, 0.5595477139029971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 174}], {
             RGBColor[
             0.5381048985913309, 0.3230270675738846, 0.5594492364353632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 196}], {
             RGBColor[
             0.7834797594963547, 0.5329693361626906, 0.5778679201187064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 89}], {
             RGBColor[
             0.29661297492595873`, 0.4251533576494334, 0.940347160745292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 106}], {
             RGBColor[
             0.21041752119776555`, 0.3384925343932145, 0.9352943385961614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 107}], {
             RGBColor[
             0.3329147853618823, 0.45659616126698577`, 0.9426602800058386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 130}], {
             RGBColor[
             0.31777520683227484`, 0.44348301928198197`, 0.9416955994493357]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 131}], {
             RGBColor[
             0.33078294826194204`, 0.45474967112026565`, 0.9425244412309399]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 142}], {
             RGBColor[
             0.28883724045578907`, 0.41841840727115054`, 0.9398516978206649]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 147}], {
             RGBColor[
             0.5032171784709925, 0.5937820517080492, 0.9571260866939247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[
             0.22755995441536772`, 0.35651031859795634`, 0.9362705748079465]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 157}], {
             RGBColor[
             0.4196525340184206, 0.5278119562440912, 0.949268052934834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 168}], {
             RGBColor[
             0.3021342801094398, 0.4299356346904973, 0.940698973429285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 176}], {
             RGBColor[
             0.2651278970915182, 0.3959966082957308, 0.9384100135665627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 188}], {
             RGBColor[
             0.2676544381957788, 0.3986521631882669, 0.9385538963447677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 91}], {
             RGBColor[
             0.28730701059645514`, 0.41715569172279066`, 0.9397518974423453]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 93}], {
             RGBColor[
             0.381420711698351, 0.5047891825358936, 0.9455247683656947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 95}], {
             RGBColor[
             0.5828706831468575, 0.36107481803534386`, 0.5611474289530629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 103}], {
             RGBColor[
             0.39503130572006806`, 0.5164499253248316, 0.9464274094112202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 117}], {
             RGBColor[
             0.5890107626825083, 0.6710219905646034, 0.9637751616195289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 121}], {
             RGBColor[
             0.3222054862363553, 0.4534999304844828, 0.9417516265612242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 152}], {
             RGBColor[
             0.422806348471376, 0.5389989562817601, 0.948613962519937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 159}], {
             RGBColor[
             0.29908455143346124`, 0.42953463388170277`, 0.9404226109697026]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 161}], {
             RGBColor[
             0.25684410203096136`, 0.3851372433604978, 0.9380170798653752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 164}], {
             RGBColor[
             0.32686193552035026`, 0.4575331128143332, 0.942048331392064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 173}], {
             RGBColor[
             0.31762660826474753`, 0.4490235112456892, 0.9414785536757294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 180}], {
             RGBColor[
             0.32072799834288923`, 0.45222020473186325`, 0.9416574823391438]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 200}], {
             RGBColor[
             0.34956314083205486`, 0.47719575585957685`, 0.9434948321206381]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 106}], {
             RGBColor[
             0.2651224537281932, 0.3920548232562189, 0.9385538221491306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 107}], {
             RGBColor[
             0.3876197178923099, 0.5101584501299902, 0.9459197635588077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 142}], {
             RGBColor[
             0.3435421729862167, 0.47198069613415494`, 0.9431111813736341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 147}], {
             RGBColor[
             0.5579221110014201, 0.6473443405710535, 0.960385570246894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 154}], {
             RGBColor[
             0.2822648869457953, 0.41007260746096075`, 0.9395300583609157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 157}], {
             RGBColor[
             0.47435746654884825`, 0.5813742451070956, 0.9525275364878032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 168}], {
             RGBColor[
             0.35683921263986745`, 0.4834979235535017, 0.9439584569822542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 176}], {
             RGBColor[
             0.3198328296219458, 0.4495588971587352, 0.9416694971195319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 188}], {
             RGBColor[
             0.3223593707262064, 0.4522144520512713, 0.9418133798977368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 111}], {
             RGBColor[
             0.2928055443173462, 0.42508757039426626`, 0.9399862146306638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 115}], {
             RGBColor[
             0.3191520165976721, 0.44815108777964463`, 0.9416560718193884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 163}], {
             RGBColor[
             0.29838048518832827`, 0.4301598312803955, 0.940332528205529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 165}], {
             RGBColor[
             0.35044478009375, 0.47525530669992216`, 0.9436500190382542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 169}], {
             RGBColor[
             0.3789106422477404, 0.49923208204991115`, 0.9456514272478034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 175}], {
             RGBColor[
             0.2885299205512955, 0.4205936187259428, 0.9397427241824057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 177}], {
             RGBColor[
             0.6271484640053853, 0.6959132395063923, 0.9333866098647894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 103}], {
             RGBColor[
             0.3503104122754294, 0.47159800194974855`, 0.9438018045154464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 117}], {
             RGBColor[
             0.5442898692378697, 0.6261700671895203, 0.9611495567237552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 121}], {
             RGBColor[
             0.27748459279171667`, 0.40864800710939975`, 0.9391260216654505]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 152}], {
             RGBColor[
             0.3780854550267373, 0.49414703290667705`, 0.9459883576241633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 159}], {
             RGBColor[
             0.2543636579888226, 0.38468271050661973`, 0.9377970060739289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 164}], {
             RGBColor[
             0.2821410420757116, 0.41268118943925014`, 0.9394227264962902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 200}], {
             RGBColor[
             0.3048422473874163, 0.4323438324844938, 0.9408692272248644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 118}], {
             RGBColor[
             0.3661557983035881, 0.49156748179020554`, 0.9445521015824132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 123}], {
             RGBColor[
             0.3772894859417832, 0.5012109224269985, 0.9452615303135856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 139}], {
             RGBColor[
             0.36831122937048716`, 0.4934344078452382, 0.9446894437440232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 141}], {
             RGBColor[
             0.4228541799697291, 0.5406767702458943, 0.9481648723257694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 146}], {
             RGBColor[
             0.6960716647178165, 0.750923600100583, 0.6821474785511282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 171}], {
             RGBColor[
             0.3227813184698261, 0.4480022801077161, 0.9420078759278904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 174}], {
             RGBColor[
             0.3210520818445352, 0.44618474277460085`, 0.9419093984602565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 186}], {
             RGBColor[
             0.6980020795647335, 0.7571272336908472, 0.8452124676735815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 191}], {
             RGBColor[
             0.3516490697634863, 0.47834411703849933`, 0.9436518516580533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 195}], {
             RGBColor[
             0.3875143013335784, 0.5100671436052072, 0.9459130465089016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 196}], {
             RGBColor[
             0.566426942749559, 0.6561270113634069, 0.9603280821435995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 95}], {
             RGBColor[
             0.6322634908041147, 0.40385638547336367`, 0.5642946949806384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 121}], {
             RGBColor[
             0.37159829389361254`, 0.49628149792250265`, 0.9448988925887998]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 150}], {
             RGBColor[
             0.4004716056935939, 0.5212901093887995, 0.9467386744850275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 159}], {
             RGBColor[
             0.3484773590907184, 0.47231620131972263`, 0.9435698769972781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 161}], {
             RGBColor[
             0.3062369096882186, 0.4279188107985177, 0.9411643458929507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 162}], {
             RGBColor[
             0.7128781558913218, 0.769581109637244, 0.8198021917112667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 164}], {
             RGBColor[
             0.37625474317760743`, 0.500314680252353, 0.9451955974196395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 173}], {
             RGBColor[
             0.36701941592200477`, 0.49180507868370904`, 0.944625819703305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 180}], {
             RGBColor[
             0.37012080600014646`, 0.49500177216988306`, 0.9448047483667193]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 200}], {
             RGBColor[
             0.3989559484893121, 0.5199773232975967, 0.9466420981482137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 174}], {
             RGBColor[
             0.3646786110461826, 0.48300500930008416`, 0.9449563831890636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 196}], {
             RGBColor[
             0.6100534719512064, 0.6929472778888902, 0.9633750668724068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 121}], {
             RGBColor[
             0.5730482653421191, 0.3525671334219529, 0.560521553176168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 150}], {
             RGBColor[
             0.6019215771421005, 0.37757574488824974`, 0.5623613350723957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 159}], {
             RGBColor[
             0.5499273305392249, 0.3286018368191729, 0.5591925375846465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 161}], {
             RGBColor[
             0.5076868811367251, 0.2842044462979679, 0.5567870064803191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 162}], {
             RGBColor[
             0.9143281273398283, 0.6258667451366944, 0.435424852298635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 164}], {
             RGBColor[
             0.577704714626114, 0.3566003157518033, 0.5608182580070078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 173}], {
             RGBColor[
             0.5684693873705113, 0.3480907141831593, 0.5602484802906733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 180}], {
             RGBColor[
             0.5715707774486529, 0.35128740766933336`, 0.5604274089540877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 99}], {
             RGBColor[
             0.24885602215754066`, 0.378731114070066, 0.937489312409721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 102}], {
             RGBColor[
             0.28676967804775, 0.4115700172064126, 0.9399051370373156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 125}], {
             RGBColor[
             0.5340013859378985, 0.6109416121829669, 0.9612324253580226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 128}], {
             RGBColor[
             0.2917745200061472, 0.4159049597601053, 0.9402240411412968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 137}], {
             RGBColor[
             0.3306269506355999, 0.44899411877588596`, 0.942855204559168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 166}], {
             RGBColor[
             0.29118156524000177`, 0.4153913721444432, 0.9401862585879273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 170}], {
             RGBColor[
             0.5608377337138294, 0.5459979328961393, 0.6000516131258001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 198}], {
             RGBColor[
             0.2057702541331046, 0.33360796205450555`, 0.9350296836118446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 105}], {
             RGBColor[
             0.3944746293584633, 0.5159166056675242, 0.9464060726464368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 134}], {
             RGBColor[
             0.5927415211728128, 0.678978695583665, 0.9619533811991124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 135}], {
             RGBColor[
             0.37195163714959767`, 0.4941189596953187, 0.945054752262561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 153}], {
             RGBColor[
             0.3808520555368791, 0.5034738637394709, 0.9455616179227275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 100}], {
             RGBColor[
             0.6761612705488476, 0.7386658760714502, 0.8605831446132168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 109}], {
             RGBColor[
             0.9915492110572557, 0.9907733958438751, 0.7897149729293931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 113}], {
             RGBColor[
             0.7160023465734379, 0.7731742136532449, 0.8631217827474235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 116}], {
             RGBColor[
             0.5951151887127726, 0.6582206855789635, 0.8557941582263938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 120}], {
             RGBColor[
             0.715306924996907, 0.7725718744365586, 0.8630774710995042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 124}], {
             RGBColor[
             0.6312029921658504, 0.6961512551070415, 0.8578493052459257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 125}], {
             RGBColor[
             0.9365563912416639, 0.9494389576053107, 0.8827491939577609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 136}], {
             RGBColor[
             0.6647148093431758, 0.7287515266909655, 0.8598537862268996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 187}], {
             RGBColor[
             0.8330968063496879, 0.8681240171075324, 0.8725677454294714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 102}], {
             RGBColor[
             0.3484196336991725, 0.4762053074554138, 0.9434219688572945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 109}], {
             RGBColor[
             0.6506441614049128, 0.7169113406705325, 0.8717150361496337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 116}], {
             RGBColor[
             0.25421013906042966`, 0.38435863040562085`, 0.9377942214466344]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 128}], {
             RGBColor[
             0.3534244756575697, 0.48054025000910644`, 0.9437408729612755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 136}], {
             RGBColor[
             0.3238097596908328, 0.4548894715176229, 0.9418538494471402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 137}], {
             RGBColor[
             0.3922769062870224, 0.5136294090248872, 0.946372036379147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 162}], {
             RGBColor[
             0.6527243851179991, 0.7174789368098209, 0.8159692466294814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 193}], {
             RGBColor[
             0.6371275889209012, 0.6663730426582706, 0.6273395305283908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 198}], {
             RGBColor[
             0.2674202097845271, 0.3982432523035067, 0.9385465154318233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 113}], {
             RGBColor[
             0.39984754000863626`, 0.5207495750589425, 0.9466989095714216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 120}], {
             RGBColor[
             0.3991521184321054, 0.5201472358422562, 0.9466545979235022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 124}], {
             RGBColor[
             0.31504818560104886`, 0.44372661651273915`, 0.9414264320699237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 125}], {
             RGBColor[
             0.6204015846768622, 0.6970143190110084, 0.966326320781759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 136}], {
             RGBColor[
             0.34856000277837423`, 0.47632688809666324`, 0.9434309130508978]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 137}], {
             RGBColor[
             0.41702714937456375`, 0.5350668256039275, 0.9479490999829046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 187}], {
             RGBColor[
             0.5169419997848863, 0.6156993785132301, 0.9561448722534693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 198}], {
             RGBColor[
             0.2921704528720685, 0.41968066888254707`, 0.9401235790355809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 105}], {
             RGBColor[
             0.661517524081524, 0.7244979939481128, 0.7654946984856268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 134}], {
             RGBColor[
             0.8597844158958734, 0.8875600838642536, 0.7810420070383024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 135}], {
             RGBColor[
             0.6389945318726584, 0.7027003479759073, 0.7641433781017509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 144}], {
             RGBColor[
             0.6011877832043422, 0.6629630580391923, 0.7619903396951628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 128}], {
             RGBColor[
             0.391338131547779, 0.513379153145453, 0.9461566975888702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 140}], {
             RGBColor[
             0.5884665495914818, 0.672693028859074, 0.9628005259980245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 162}], {
             RGBColor[
             0.6906380410082085, 0.7503178399461676, 0.8183850712570762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 172}], {
             RGBColor[
             0.4482251129931922, 0.5611095729608861, 0.9502076069097103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 180}], {
             RGBColor[
             0.3478806911170333, 0.47573850247880656`, 0.9433876279125288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 117}], {
             RGBColor[
             0.6520141643614825, 0.7254643007915613, 0.96782506869263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 152}], {
             RGBColor[
             0.4858097501503502, 0.593441266508718, 0.9526638695930381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 178}], {
             RGBColor[
             0.6889147648895494, 0.7548878380125237, 0.9713446809125519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 200}], {
             RGBColor[
             0.4125665425110292, 0.5316380660865347, 0.947544739193739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 143}], {
             RGBColor[
             0.31360290662708873`, 0.44553838312427374`, 0.9412221669653975]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 154}], {
             RGBColor[
             0.25821858946180287`, 0.3887344879014942, 0.9380165387184549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 158}], {
             RGBColor[
             0.30962415543576527`, 0.44209218882019885`, 0.9409686444577579]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 160}], {
             RGBColor[
             0.3670762245142802, 0.49185428343105514`, 0.9446294394965709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 176}], {
             RGBColor[
             0.29578653213795336`, 0.42822077759926863`, 0.9401559774770711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 181}], {
             RGBColor[
             0.3146337614047273, 0.4464312577203967, 0.9412878521202794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 188}], {
             RGBColor[
             0.2983130732422139, 0.43087633249180474`, 0.9402998602552761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 134}], {
             RGBColor[
             0.527297459515132, 0.6224735629265418, 0.9577338232696305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 135}], {
             RGBColor[
             0.3065075754919169, 0.4376138270381955, 0.940835194333079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 144}], {
             RGBColor[
             0.2687008268236007, 0.3978765371014805, 0.9386821559264908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.3014242641641167, 0.42349762687377124`, 0.9408669414096771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 130}], {
             RGBColor[
             0.28628468563450926`, 0.41038448488876744`, 0.9399022608531742]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 131}], {
             RGBColor[
             0.29929242706417647`, 0.4216511367270511, 0.9407311026347784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 142}], {
             RGBColor[
             0.25734671925802355`, 0.385319872877936, 0.9380583592245035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 147}], {
             RGBColor[
             0.4717266572732269, 0.5606835173148346, 0.9553327480977634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 157}], {
             RGBColor[
             0.3881620128206551, 0.49471342185087663`, 0.9474747143386726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 176}], {
             RGBColor[
             0.23363737589375266`, 0.36289807390251627`, 0.9366166749704012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 130}], {
             RGBColor[
             0.40878194979862603`, 0.5284881117625387, 0.9472682022628514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 131}], {
             RGBColor[
             0.42178969122829324`, 0.5397547636008224, 0.9480970440444556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 142}], {
             RGBColor[
             0.3798439834221403, 0.5034234997517073, 0.9454243006341806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[
             0.5942239214373436, 0.678787144188606, 0.9626986895074404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 154}], {
             RGBColor[
             0.31856669738171894`, 0.4415154110785131, 0.9418431776214622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.5106592769847718, 0.6128170487246479, 0.9548406557483496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 168}], {
             RGBColor[
             0.393141023075791, 0.514940727171054, 0.9462715762428007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 176}], {
             RGBColor[
             0.35613464005786943`, 0.48100170077628757`, 0.9439826163800784]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 188}], {
             RGBColor[
             0.35866118116212997`, 0.48365725566882367`, 0.9441264991582834]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 111}], {
             RGBColor[
             0.2907481721648579, 0.4229251418170724, 0.939869050330189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 115}], {
             RGBColor[
             0.31709464444518376`, 0.4459886592024508, 0.9415389075189136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 133}], {
             RGBColor[
             0.3089326734340224, 0.4389191701451739, 0.9410188339434299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 151}], {
             RGBColor[
             0.6230693769531228, 0.6598933912540623, 0.6399405506400185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 163}], {
             RGBColor[
             0.2963231130358399, 0.42799740270320163`, 0.9402153639050541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 165}], {
             RGBColor[
             0.34838740794126166`, 0.4730928781227283, 0.9435328547377794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 175}], {
             RGBColor[
             0.2864725483988072, 0.41843119014874897`, 0.9396255598819309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 113}], {
             RGBColor[
             0.7152354805170444, 0.7728570948313676, 0.8758307378875978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 116}], {
             RGBColor[
             0.5943483226563793, 0.6579035667570862, 0.8685031133665682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 124}], {
             RGBColor[
             0.6304361261094571, 0.6958341362851641, 0.8705582603861001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 128}], {
             RGBColor[
             0.6935626592535193, 0.7540851863605718, 0.8744497648812094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 136}], {
             RGBColor[
             0.6639479432867824, 0.7284344078690882, 0.872562741367074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 148}], {
             RGBColor[
             0.7035280824874875, 0.7627167350890997, 0.8750847528376001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 193}], {
             RGBColor[
             0.9772657725168508, 0.9399179790097358, 0.5580484224483246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 138}], {
             RGBColor[
             0.303546698366364, 0.43637720432828503`, 0.9405979074636419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 145}], {
             RGBColor[
             0.4289000102680846, 0.5424024487601602, 0.9493513117276959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 115}], {
             RGBColor[
             0.3324585154205397, 0.46213706172323255`, 0.9424138572421498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 163}], {
             RGBColor[
             0.3116869840111959, 0.4441458052239834, 0.9410903136282904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 165}], {
             RGBColor[
             0.3637512789166176, 0.48924128064351013`, 0.9444078044610156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 169}], {
             RGBColor[
             0.392217141070608, 0.5132180559934991, 0.9464092126705648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 175}], {
             RGBColor[
             0.30183641937416317`, 0.4345795926695307, 0.9405005096051671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 177}], {
             RGBColor[
             0.640454962828253, 0.7098992134499802, 0.9341443952875508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 134}], {
             RGBColor[
             0.6356818006246531, 0.7138395488802136, 0.9653337972929878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 143}], {
             RGBColor[
             0.43488987534280044`, 0.5485904018863936, 0.9496255958405624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 156}], {
             RGBColor[
             0.6815591249599124, 0.3881352224588723, 0.5608022313818347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 160}], {
             RGBColor[
             0.4883631932299919, 0.5949063021931751, 0.9530328683717357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 181}], {
             RGBColor[
             0.4359207301204391, 0.5494832764825166, 0.9496912809954443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 183}], {
             RGBColor[
             0.5933652568591508, 0.6807596721752825, 0.9611310330699577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 116}], {
             RGBColor[
             0.31880145817256134`, 0.4403043845664559, 0.9419099231845985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 124}], {
             RGBColor[
             0.35488926162563916`, 0.47823495409453387`, 0.9439650702041305]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 128}], {
             RGBColor[
             0.4180157947697014, 0.5364860041699415, 0.9478565746992398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 136}], {
             RGBColor[
             0.38840107880296454`, 0.5108352256784578, 0.9459695511851043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 148}], {
             RGBColor[
             0.4279812180036696, 0.5451175528984693, 0.9484915626556305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 187}], {
             RGBColor[
             0.5567830758094766, 0.6502077160950248, 0.9586835103876761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 193}], {
             RGBColor[
             0.7017189080330328, 0.7223187968191056, 0.6314552322663549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 198}], {
             RGBColor[
             0.3320115288966588, 0.45418900646434174`, 0.9426622171697876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 167}], {
             RGBColor[
             0.3352276053739, 0.46477903557068545`, 0.9425813844776607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 184}], {
             RGBColor[
             0.328864589466972, 0.45816405854965914`, 0.9422163488534885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 186}], {
             RGBColor[
             0.6776256789359905, 0.7394782196139043, 0.8439141014436615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 194}], {
             RGBColor[
             0.3320727200053087, 0.4615360071526754, 0.9423990471416429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 133}], {
             RGBColor[
             0.35064301668970427`, 0.47813109005133403`, 0.9435636408553907]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 163}], {
             RGBColor[
             0.33803345629152176`, 0.46720932260936177`, 0.942760170817015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 165}], {
             RGBColor[
             0.3900977511969435, 0.5123047980288884, 0.9460776616497402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 175}], {
             RGBColor[
             0.328182891654489, 0.4576431100549091, 0.9421703667938917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 124}], {
             RGBColor[
             0.23400210376497393`, 0.36328142602025254`, 0.9366374456831008]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 128}], {
             RGBColor[
             0.2971286369090362, 0.42153247609566014`, 0.9405289501782101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 136}], {
             RGBColor[
             0.2675139209422993, 0.3958816976041766, 0.9386419266640746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 148}], {
             RGBColor[
             0.30709406014300444`, 0.43016402482418803`, 0.9411639381346009]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 193}], {
             RGBColor[
             0.5808317501723677, 0.6073652687448243, 0.6241276077453253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 198}], {
             RGBColor[
             0.21112437103599357`, 0.3392354783900604, 0.935334592648758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 121}], {
             RGBColor[
             0.5791883448777698, 0.6625143059512124, 0.963149285842634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 152}], {
             RGBColor[
             0.6797892071127905, 0.7480133317484898, 0.9700116218013469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 159}], {
             RGBColor[
             0.5560674100748757, 0.6385490093484325, 0.9618202702511125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 164}], {
             RGBColor[
             0.5838447941617647, 0.6665474882810628, 0.9634459906734738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 178}], {
             RGBColor[
             0.8828942218519895, 0.9094599032522955, 0.9886924331208609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 200}], {
             RGBColor[
             0.6065459994734694, 0.6862101313263065, 0.964892491402048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 119}], {
             RGBColor[
             0.31529932088366247`, 0.44670582902961753`, 0.9413413151243379]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 123}], {
             RGBColor[
             0.3417723554656693, 0.47044776915147174`, 0.942998410166213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 127}], {
             RGBColor[
             0.5354938922923984, 0.6289449762389849, 0.9585218602518528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 129}], {
             RGBColor[
             0.606786689939883, 0.6851482587768092, 0.9654926382736762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 139}], {
             RGBColor[
             0.3327940988943733, 0.46267125456971137`, 0.9424263235966506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[
             0.38733704949361525`, 0.5099136169703676, 0.9459017521783968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 146}], {
             RGBColor[
             0.6605545342417026, 0.7201604468250563, 0.6798843584037555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 155}], {
             RGBColor[
             0.41656938769136703`, 0.5338977895283674, 0.9481333885508934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 171}], {
             RGBColor[
             0.28726418799371223`, 0.41723912683218933`, 0.9397447557805176]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 191}], {
             RGBColor[
             0.31613193928737243`, 0.4475809637629726, 0.9413887315106806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.3519971708574645, 0.4793039903296804, 0.943649926361529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 196}], {
             RGBColor[
             0.5309098122734451, 0.6253638580878802, 0.9580649619962269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[
             0.660939057142635, 0.725724814368045, 0.8685687777112852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 123}], {
             RGBColor[
             0.3264330085218576, 0.4563492696664105, 0.9420507438555104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 127}], {
             RGBColor[
             0.5201545453485867, 0.6148464767539237, 0.9575741939411502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 140}], {
             RGBColor[
             0.5452798917667163, 0.6344745883354719, 0.9600784536623976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 151}], {
             RGBColor[
             0.6353572133282973, 0.6728086863781951, 0.6406403247433599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 155}], {
             RGBColor[
             0.4012300407475553, 0.5197992900433062, 0.9471857222401907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 156}], {
             RGBColor[
             0.5586394869699254, 0.28336716477227814`, 0.5523058244068176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 172}], {
             RGBColor[
             0.4050384551684266, 0.522891132437284, 0.9474855345740835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 191}], {
             RGBColor[
             0.3007925923435607, 0.4334824642779113, 0.9404410651999779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 195}], {
             RGBColor[
             0.3366578239136528, 0.46520549084461915`, 0.9427022600508264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 199}], {
             RGBColor[
             0.6455997101988233, 0.7116263148829838, 0.8676211114005825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 124}], {
             RGBColor[
             0.35419384004910826`, 0.4776326148778476, 0.943920758556211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 125}], {
             RGBColor[
             0.6595472391249217, 0.7309203173761167, 0.9688206472680463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 136}], {
             RGBColor[
             0.3877056572264337, 0.5102328864617716, 0.945925239537185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 137}], {
             RGBColor[
             0.4561728038226232, 0.5689728239690359, 0.9504434264691918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 187}], {
             RGBColor[
             0.5560876542329457, 0.6496053768783385, 0.9586391987397567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 198}], {
             RGBColor[
             0.33131610732012795`, 0.45358666724765545`, 0.9426179055218682]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 152}], {
             RGBColor[
             0.4129839306666375, 0.5304912716683692, 0.9479880867430421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 159}], {
             RGBColor[
             0.2892621336287228, 0.42102694926831186`, 0.9397967351928076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 161}], {
             RGBColor[
             0.2470216842262229, 0.3766295587471069, 0.9373912040884802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 164}], {
             RGBColor[
             0.3170395177156118, 0.44902542820094227`, 0.941422455615169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 173}], {
             RGBColor[
             0.30780419046000906`, 0.44051582663229827`, 0.9408526778988344]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 180}], {
             RGBColor[
             0.31090558053815076`, 0.4437125201184723, 0.9410316065622488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[
             0.3397407230273164, 0.46868807124618594`, 0.9428689563437431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 125}], {
             RGBColor[
             0.5846613330048106, 0.6641884285764534, 0.9641174343988077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 137}], {
             RGBColor[
             0.381286897702512, 0.5022409351693725, 0.9457402135999532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 166}], {
             RGBColor[
             0.34184151230691395`, 0.46863818853792977`, 0.9430712676287123]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 170}], {
             RGBColor[
             0.6114976807807415, 0.5992447492896258, 0.6029366221665853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 179}], {
             RGBColor[
             0.29135220387662475`, 0.423560017443962, 0.9399034490425893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 192}], {
             RGBColor[
             0.35518512848044803`, 0.48019575819779553`, 0.9439215110519934]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 127}], {
             RGBColor[
             0.5466275799305935, 0.6385884168757779, 0.9592312889830252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 129}], {
             RGBColor[
             0.6179203775780782, 0.6947916994136021, 0.9662020670048486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 139}], {
             RGBColor[
             0.3439277865325684, 0.4723146952065044, 0.943135752327823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 141}], {
             RGBColor[
             0.39847073713181036`, 0.5195570576071606, 0.9466111809095692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 146}], {
             RGBColor[
             0.6716882218798977, 0.7298038874618493, 0.6805937871349279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 155}], {
             RGBColor[
             0.42770307532956214`, 0.5435412301651604, 0.9488428172820658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 171}], {
             RGBColor[
             0.29839787563190734`, 0.4268825674689823, 0.94045418451169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 191}], {
             RGBColor[
             0.32726562692556754`, 0.4572244043997655, 0.942098160241853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 195}], {
             RGBColor[
             0.3631308584956596, 0.4889474309664734, 0.9443593550927014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 196}], {
             RGBColor[
             0.5420434999116402, 0.6350072987246731, 0.9587743907273993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 199}], {
             RGBColor[
             0.6720727447808301, 0.735368255004838, 0.8692782064424576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 125}], {
             RGBColor[
             0.5754433062938652, 0.6544996980465998, 0.9635924814144678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 136}], {
             RGBColor[
             0.30360172439537714`, 0.43381226713225457`, 0.9406970736836066]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.3720688709915666, 0.4925522046395188, 0.9452152606156133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 187}], {
             RGBColor[
             0.47198372140188916`, 0.5731847575488214, 0.9534110328861782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 198}], {
             RGBColor[
             0.24721217448907135`, 0.3771660479181384, 0.9373897396682898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 136}], {
             RGBColor[
             0.6089551234711906, 0.6870999696305238, 0.9655969623954417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 137}], {
             RGBColor[
             0.6774222700673801, 0.745839907137788, 0.9701151493274485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 166}], {
             RGBColor[
             0.637976884671782, 0.7122371605063453, 0.9674462033562077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[
             0.9076330531456096, 0.8428437212580413, 0.6273115578940806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 187}], {
             RGBColor[
             0.7773371204777026, 0.8264724600470906, 0.9783109215980135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 192}], {
             RGBColor[
             0.6513205008453161, 0.7237947301662111, 0.9682964467794888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 198}], {
             RGBColor[
             0.5525655735648849, 0.6304537504164076, 0.962289628380125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 190}], {
             RGBColor[
             0.5303398004040601, 0.6226696186433824, 0.9586105248066853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 129}], {
             RGBColor[
             0.8116419144048073, 0.8532889065011153, 0.9817255170904884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 139}], {
             RGBColor[
             0.5376493233592975, 0.6308119022940176, 0.9586592024134628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 140}], {
             RGBColor[
             0.7654744631754522, 0.8167137355448393, 0.9772589987899125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 141}], {
             RGBColor[
             0.5921922739585395, 0.6780542646946739, 0.962134630995209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 155}], {
             RGBColor[
             0.6214246121562912, 0.7020384372526737, 0.9643662673677056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 172}], {
             RGBColor[
             0.6252330265771626, 0.7051302796466515, 0.9646660797015983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 191}], {
             RGBColor[
             0.5209871637522967, 0.6157216114872788, 0.9576216103274928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 195}], {
             RGBColor[
             0.5568523953223887, 0.6474446380539867, 0.9598828051783412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 199}], {
             RGBColor[
             0.8657942816075592, 0.8938654620923513, 0.8848016565280974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 136}], {
             RGBColor[
             0.3667282575394394, 0.49206331720766217`, 0.9445885781787159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 162}], {
             RGBColor[
             0.6956428829666057, 0.7546527824998602, 0.8187039753610572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 193}], {
             RGBColor[
             0.6800460867695077, 0.7035468883483098, 0.6300742592599665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 198}], {
             RGBColor[
             0.3103387076331336, 0.435417097993546, 0.9412812441633991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 139}], {
             RGBColor[
             0.6089421210067822, 0.6870151848318418, 0.9656299804352861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 141}], {
             RGBColor[
             0.6634850716060241, 0.7342575472324979, 0.9691054090170323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 146}], {
             RGBColor[
             0.9367025563541116, 0.9445043770871866, 0.7030880152423911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 155}], {
             RGBColor[
             0.6927174098037759, 0.7582417197904978, 0.9713370453895289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 191}], {
             RGBColor[
             0.5922799613997813, 0.6719248940251029, 0.9645923883493162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 195}], {
             RGBColor[
             0.6281451929698734, 0.7036479205918108, 0.9668535832001646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 131}], {
             RGBColor[
             0.4066501126986858, 0.5266416216158186, 0.9471323634879527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 149}], {
             RGBColor[
             0.41347110248204677`, 0.5325496201332511, 0.947566990925384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 157}], {
             RGBColor[
             0.49551969845516436`, 0.5997039067396441, 0.9538759751918466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 168}], {
             RGBColor[
             0.37800144454618356`, 0.5018275851860503, 0.9453068956862978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 189}], {
             RGBColor[
             0.3820625375430208, 0.5053450998234417, 0.9455656649409727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 197}], {
             RGBColor[
             0.5129880942448324, 0.613885537383959, 0.9552511512972515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 147}], {
             RGBColor[
             0.5920920843374033, 0.6769406540418859, 0.9625628507325418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 157}], {
             RGBColor[
             0.5085274398848316, 0.6109705585779278, 0.954704816973451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 176}], {
             RGBColor[
             0.3540028029579292, 0.47915521062956745`, 0.9438467776051798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 138}], {
             RGBColor[
             0.30526234880260206`, 0.4381804617152916, 0.9406956112179083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 145}], {
             RGBColor[
             0.43061566070432267`, 0.5442057061471668, 0.9494490154819623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 153}], {
             RGBColor[
             0.3031712079878207, 0.435982540132971, 0.9405765238420721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 182}], {
             RGBColor[
             0.3293571343386859, 0.4593070265694291, 0.9422215042796107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 185}], {
             RGBColor[
             0.6376557243173855, 0.6752245671617407, 0.6407712215438461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 163}], {
             RGBColor[
             0.3298714852803604, 0.4601398335520849, 0.9422400972415315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 178}], {
             RGBColor[
             0.6311379340292997, 0.7049725207336576, 0.967627806310345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 135}], {
             RGBColor[
             0.5047744673062663, 0.6006759169543363, 0.9563825028857547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 160}], {
             RGBColor[
             0.5782457439348202, 0.6666024061556441, 0.9609802029010541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 144}], {
             RGBColor[
             0.24617783461473502`, 0.3760788911292751, 0.937330835542615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 148}], {
             RGBColor[
             0.3766936807734076, 0.5006948659361901, 0.9452235661351066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 187}], {
             RGBColor[
             0.5054955385792146, 0.6057850291327455, 0.9554155138671522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 193}], {
             RGBColor[
             0.6504313708027709, 0.6778961098568264, 0.6281872357458311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 198}], {
             RGBColor[
             0.2807239916663968, 0.40976631950206244`, 0.9393942206492637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 166}], {
             RGBColor[
             0.43460244936948345`, 0.5502896670992643, 0.9490689825573533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 170}], {
             RGBColor[
             0.7042586178433111, 0.6808962278509605, 0.608934337095226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 179}], {
             RGBColor[
             0.3841131409391943, 0.5052114960052966, 0.94590116397123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 187}], {
             RGBColor[
             0.573962685175404, 0.6645249666400097, 0.959933700799159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 192}], {
             RGBColor[
             0.4479460655430176, 0.5618472367591301, 0.9499192259806344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 198}], {
             RGBColor[
             0.3491911382625863, 0.4685062570093267, 0.9439124075812705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 145}], {
             RGBColor[
             0.4313210135888975, 0.5449470767508109, 0.9494891842852626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 153}], {
             RGBColor[
             0.30387656087239556`, 0.436723910736615, 0.9406166926453725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 182}], {
             RGBColor[
             0.33006248722326076`, 0.4600483971730731, 0.9422616730829112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 185}], {
             RGBColor[
             0.6383610772019603, 0.6759659377653848, 0.6408113903471466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 141}], {
             RGBColor[
             0.38949248056051433`, 0.5117805430254002, 0.9460390943400068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 146}], {
             RGBColor[
             0.6627099653086017, 0.722027372880089, 0.6800217005653655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 155}], {
             RGBColor[
             0.4187248187582661, 0.5357647155834001, 0.9482707307125033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 171}], {
             RGBColor[
             0.2894196190606113, 0.4191060528872219, 0.9398820979421276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 191}], {
             RGBColor[
             0.3182873703542715, 0.4494478898180052, 0.9415260736722906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 194}], {
             RGBColor[
             0.31908742122483685`, 0.45028879400912436`, 0.9415716353858001]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 195}], {
             RGBColor[
             0.3541526019243636, 0.48117091638471304`, 0.943787268523139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 196}], {
             RGBColor[
             0.5330652433403442, 0.6272307841429128, 0.9582023041578369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 151}], {
             RGBColor[
             0.8806771311551629, 0.8746759451691107, 0.6603251295921222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 161}], {
             RGBColor[
             0.4861300548072054, 0.5723043593747548, 0.9567099579518956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 162}], {
             RGBColor[
             0.8927713010103084, 0.9139666582134811, 0.8353478037702116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 172}], {
             RGBColor[
             0.6503583729952922, 0.7247583912281996, 0.9671703394228457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 173}], {
             RGBColor[
             0.5469125610409915, 0.636190627259946, 0.9601714317622498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 180}], {
             RGBColor[
             0.5500139511191333, 0.6393873207461201, 0.9603503604256642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 191}], {
             RGBColor[
             0.5461125101704263, 0.635349723068827, 0.9601258700487403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 146}], {
             RGBColor[
             0.7172529159078437, 0.7692697352807452, 0.6834971291471117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 155}], {
             RGBColor[
             0.4732677693575081, 0.5830070779840564, 0.9517461592942495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 167}], {
             RGBColor[
             0.37678525719267014`, 0.5007741848277907, 0.9452294013035641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 191}], {
             RGBColor[
             0.3728303209535135, 0.4966902522186614, 0.9450015022540368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 194}], {
             RGBColor[
             0.3736303718240788, 0.4975311564097806, 0.9450470639675463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 195}], {
             RGBColor[
             0.40869555252360557`, 0.5284132787853693, 0.9472626971048852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 147}], {
             RGBColor[
             0.5501463765312504, 0.6406093901927706, 0.9598901073222668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 154}], {
             RGBColor[
             0.2744891524756257, 0.4033376570826779, 0.9390345954362886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 157}], {
             RGBColor[
             0.4665817320786786, 0.5746392947288127, 0.952032073563176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 168}], {
             RGBColor[
             0.34906347816969785`, 0.47676297317521876`, 0.9434629940576271]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 176}], {
             RGBColor[
             0.3120570951517762, 0.44282394678045234`, 0.9411740341949046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.3145836362560368, 0.44547950167298844`, 0.9413179169731096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 154}], {
             RGBColor[
             0.2685961836004902, 0.39823346363226325`, 0.9386591006705127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 158}], {
             RGBColor[
             0.32000174957445265`, 0.4515911645509679, 0.9416112064098157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 160}], {
             RGBColor[
             0.37745381865296757`, 0.5013532591618242, 0.9452720014486287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 181}], {
             RGBColor[
             0.32501135554341476`, 0.4559302334511658, 0.9419304140723372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 188}], {
             RGBColor[
             0.3086906673809013, 0.4403753082225738, 0.9409424222073338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 158}], {
             RGBColor[
             0.262197042164774, 0.39224328571972655`, 0.9382677405191014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 153}], {
             RGBColor[
             0.4292298727741162, 0.5427491551684902, 0.9493700969094265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 185}], {
             RGBColor[
             0.7637143891036811, 0.78199118219726, 0.6495647946112005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 155}], {
             RGBColor[
             0.7464852541055955, 0.793253907838745, 0.6857287655196083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 171}], {
             RGBColor[
             0.6171800544079407, 0.6765952451425669, 0.6773401327492325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 184}], {
             RGBColor[
             0.6436397260338296, 0.704406037661453, 0.6788469719047507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 186}], {
             RGBColor[
             0.992400815502848, 0.985720198725698, 0.5805447244949238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 191}], {
             RGBColor[
             0.6460478057016008, 0.70693708207335, 0.6789841084793955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 194}], {
             RGBColor[
             0.6468478565721663, 0.7077779862644693, 0.679029670192905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 195}], {
             RGBColor[
             0.681913037271693, 0.7386601086400579, 0.6812453033302439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 196}], {
             RGBColor[
             0.8608256786876736, 0.8847199763982576, 0.6956603389649418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 154}], {
             RGBColor[
             0.48886909049082905`, 0.5787013015195765, 0.9563089843095485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 157}], {
             RGBColor[
             0.6809616700938819, 0.7500029391657113, 0.9693064624364358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 168}], {
             RGBColor[
             0.5634434161849011, 0.6521266176121174, 0.960737382930887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 176}], {
             RGBColor[
             0.5264370331669795, 0.6181875912173509, 0.9584484230681645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 188}], {
             RGBColor[
             0.5289635742712401, 0.6208431461098871, 0.9585923058463695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 150}], {
             RGBColor[
             0.3932017560028461, 0.5149933309799435, 0.9462754460912086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 193}], {
             RGBColor[
             0.690011510003476, 0.7121784370768378, 0.6307092472163572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 167}], {
             RGBColor[
             0.3714174584603295, 0.49612486735924605`, 0.9448873699148974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 168}], {
             RGBColor[
             0.39783017575921176`, 0.5190022355417665, 0.9465703649053334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 189}], {
             RGBColor[
             0.40189126875604897`, 0.5225197501791579, 0.9468291341600084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 194}], {
             RGBColor[
             0.36826257309173815`, 0.492881838941236, 0.9447050325788797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.5328168254578606, 0.6310601877396752, 0.9565146205162871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 156}], {
             RGBColor[
             0.894036726358372, 0.5235685216059169, 0.2525525003365422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 172}], {
             RGBColor[
             0.7404356945568732, 0.763092489270923, 0.647732210503808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 175}], {
             RGBColor[
             0.6341576241624282, 0.6715478421065206, 0.6405720099149967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 183}], {
             RGBColor[
             0.8058428582576103, 0.8161929713223273, 0.6528813020246652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 199}], {
             RGBColor[
             0.9809969495872699, 0.9518276717166227, 0.5678677873303071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 159}], {
             RGBColor[
             0.3898629958637434, 0.5065259750655892, 0.9466590711515206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 178}], {
             RGBColor[
             0.7166898076408572, 0.7774368689694522, 0.973531234021269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 200}], {
             RGBColor[
             0.4403415852623371, 0.5541870970434633, 0.9497312923024561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 182}], {
             RGBColor[
             0.32797134640847936`, 0.4578504755907525, 0.9421425857070751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 185}], {
             RGBColor[
             0.6362699363871791, 0.6737680161830641, 0.6406923029713104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 157}], {
             RGBColor[
             0.4053044460382572, 0.5127312060556185, 0.9484509505504577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 158}], {
             RGBColor[
             0.2646174324091668, 0.39478726932818836`, 0.9384055781628731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 160}], {
             RGBColor[
             0.32206950148768165`, 0.44454936393904465`, 0.9420663732016862]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 176}], {
             RGBColor[
             0.25077980911135483`, 0.38091585810725814`, 0.9375929111821864]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 181}], {
             RGBColor[
             0.26962703837812885`, 0.39912633822838617`, 0.9387247858253948]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 188}], {
             RGBColor[
             0.25330635021561543`, 0.38357141299979425`, 0.9377367939603913]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 172}], {
             RGBColor[
             0.5063085219761312, 0.610083092936034, 0.954277608000639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 191}], {
             RGBColor[
             0.40206265915126527`, 0.5206744247766613, 0.9472331386265335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 195}], {
             RGBColor[
             0.43792789072135735`, 0.5523974513433692, 0.9494943334773818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 199}], {
             RGBColor[
             0.7468697770065278, 0.7988182753817338, 0.8744131848271379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 166}], {
             RGBColor[
             0.6062380319869427, 0.3254069602339108, 0.5553090182930562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 170}], {
             RGBColor[
             0.8758942004607704, 0.4560135209856069, 0.21517437283092905`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 175}], {
             RGBColor[
             0.5574398978040562, 0.28210632050060364`, 0.5522375095784545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 183}], {
             RGBColor[
             0.7291251318992384, 0.42675144971641027`, 0.564546801688123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 199}], {
             RGBColor[
             0.9042792232288979, 0.5623861501107057, 0.47953328699376485`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 168}], {
             RGBColor[
             0.47987877173232935`, 0.5861565221481595, 0.9528793491717962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 176}], {
             RGBColor[
             0.4428723887144077, 0.552217495753393, 0.9505903893090737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 188}], {
             RGBColor[
             0.4453989298186683, 0.5548730506459291, 0.9507342720872787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 160}], {
             RGBColor[
             0.3734750674616441, 0.4979070648577493, 0.945018478940989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 176}], {
             RGBColor[
             0.3021853750853173, 0.4342735590259628, 0.9405450169214893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.32103260435209124`, 0.4524840391470909, 0.9416768915646976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 161}], {
             RGBColor[
             0.22390074942332883`, 0.3526642621443269, 0.9360621884969587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 162}], {
             RGBColor[
             0.630541995626432, 0.6943265609830533, 0.8147000343152746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 164}], {
             RGBColor[
             0.2939185829127177, 0.42506013159816225`, 0.9400934400236474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 173}], {
             RGBColor[
             0.28468325565711505`, 0.41655053002951825`, 0.9395236623073129]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 180}], {
             RGBColor[
             0.28778464573525675`, 0.41974722351569227`, 0.9397025909707273]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 200}], {
             RGBColor[
             0.3166197882244224, 0.4447227746434059, 0.9415399407522216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[
             0.3784846734306062, 0.5022461337579471, 0.9453376866035107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 162}], {
             RGBColor[
             0.588301546223932, 0.6499291704618484, 0.8122945032109472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 164}], {
             RGBColor[
             0.25167813351021784`, 0.3806627410769573, 0.93768790891932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 173}], {
             RGBColor[
             0.24244280625461515`, 0.3721531395083133, 0.9371181312029855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 180}], {
             RGBColor[
             0.24554419633275684`, 0.3753498329944873, 0.9372970598663999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 200}], {
             RGBColor[
             0.27437933882192245`, 0.400325384122201, 0.9391344096478942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 172}], {
             RGBColor[
             0.7525298644120189, 0.8023832023152933, 0.8227548846818974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 173}], {
             RGBColor[
             0.6490840524577183, 0.7138154383470396, 0.8157559770213014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 180}], {
             RGBColor[
             0.65218544253586, 0.7170121318332138, 0.8159349056847158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 165}], {
             RGBColor[
             0.36932621978759966`, 0.4943135415296393, 0.9447541180358809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 175}], {
             RGBColor[
             0.30741136024514515`, 0.43965185355565994`, 0.9408468231800324]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 177}], {
             RGBColor[
             0.646029903699235, 0.7149714743361094, 0.9344907088624161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 200}], {
             RGBColor[
             0.3443971723113114, 0.4727212535760363, 0.9431656611745829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 169}], {
             RGBColor[
             0.44985637684701185`, 0.563385792299155, 0.9500730170781553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 175}], {
             RGBColor[
             0.3594756551505669, 0.48474732897518663`, 0.9441643140127576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 177}], {
             RGBColor[
             0.6980941986046567, 0.760066949755636, 0.9378081996951413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 170}], {
             RGBColor[
             0.664813232447713, 0.6472934812195177, 0.6062653911239853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 179}], {
             RGBColor[
             0.3446677555435962, 0.4716087493738538, 0.9432322179999892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 183}], {
             RGBColor[
             0.518044163886181, 0.618031409950321, 0.9556378199811792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 192}], {
             RGBColor[
             0.40850068014741947`, 0.5282444901276874, 0.9472502800093935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 198}], {
             RGBColor[
             0.3097457528669882, 0.43490351037788394`, 0.9412434616100296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 189}], {
             RGBColor[
             0.3400088935213035, 0.4689203470494365, 0.9428860439304863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 194}], {
             RGBColor[
             0.30638019785699266`, 0.4392824358115147, 0.9407619423493575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 197}], {
             RGBColor[
             0.4709344502231151, 0.577460784609954, 0.952571530286765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 188}], {
             RGBColor[
             0.3278806759096875, 0.4569967290923352, 0.9421651925817298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 189}], {
             RGBColor[
             0.36642161082018576`, 0.4917977152319569, 0.9445690389209221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 197}], {
             RGBColor[
             0.49734716752199737`, 0.6003381527924743, 0.954254525277201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 177}], {
             RGBColor[
             0.7265600607586471, 0.7840437251056251, 0.9398096079046905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 190}], {
             RGBColor[
             0.38864581687869554`, 0.509464367832767, 0.9462058310411361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 179}], {
             RGBColor[
             0.6143239240174239, 0.6022153101255499, 0.6030975725378621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 183}], {
             RGBColor[
             0.7877003323600087, 0.7486379707020172, 0.615503174519052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[
             0.6781568486212471, 0.6588510508793834, 0.6071156345472664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 198}], {
             RGBColor[
             0.5794019213408158, 0.56551007112958, 0.6011088161479026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 174}], {
             RGBColor[
             0.24216047153465936`, 0.3718563878165846, 0.9371020526583609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 182}], {
             RGBColor[
             0.29902349045964743`, 0.4274244435884552, 0.9404940481353042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 191}], {
             RGBColor[
             0.27275745945361046`, 0.4040157620804831, 0.9388445058561578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 195}], {
             RGBColor[
             0.30862269102370254`, 0.43573878864719096`, 0.941105700707006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 196}], {
             RGBColor[
             0.48753533243968317`, 0.5817986564053907, 0.955520736341704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 199}], {
             RGBColor[
             0.617564577308873, 0.6821596126855556, 0.8660245520567622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 173}], {
             RGBColor[
             0.4066711244427019, 0.5246071713617583, 0.9475785126739357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 180}], {
             RGBColor[
             0.4097725145208436, 0.5278038648479323, 0.9477574413373501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 191}], {
             RGBColor[
             0.4058710735721366, 0.5237662671706391, 0.9475329509604262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 180}], {
             RGBColor[
             0.30632670256654304`, 0.4392361008796787, 0.9407585336767541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 186}], {
             RGBColor[
             0.6173812326295667, 0.6809813413997159, 0.8403066444040519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 196}], {
             RGBColor[
             0.48580609581439227`, 0.5799811190722755, 0.9554222588740701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 183}], {
             RGBColor[
             0.4692460297032946, 0.5747307702170139, 0.9525663112665775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 188}], {
             RGBColor[
             0.2908742928917659, 0.4230577026975687, 0.9398762327190074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 179}], {
             RGBColor[
             0.6344881648147995, 0.7036277304209961, 0.9338045949677714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 190}], {
             RGBColor[
             0.6368836386363403, 0.7061455252892481, 0.9339410136581221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 183}], {
             RGBColor[
             0.4675548554558919, 0.5729532388563533, 0.952470001395056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 192}], {
             RGBColor[
             0.3580113717171303, 0.48316631903371954`, 0.9440824614232703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 185}], {
             RGBColor[
             0.6624558627380442, 0.6970925026195223, 0.642337283408849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 195}], {
             RGBColor[
             0.3637564733233997, 0.48948930708594635`, 0.9443992187163155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 196}], {
             RGBColor[
             0.5426691147393803, 0.6355491748441461, 0.9588142543510134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 199}], {
             RGBColor[
             0.6726983596085703, 0.735910131124311, 0.8693180700660716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 192}], {
             RGBColor[
             0.5313877800597152, 0.6295889796101868, 0.9564880634044604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 186}], {
             RGBColor[
             0.6455701408807464, 0.7106096712517173, 0.8419119610272039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 194}], {
             RGBColor[
             0.30001718195006466`, 0.43266745879048846`, 0.9403969067251853]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 198}], {
             RGBColor[
             0.4491059886729088, 0.5491388099186293, 0.9521081798518354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 194}], {
             RGBColor[
             0.33685400815271216`, 0.4656773186314265, 0.9427037065944683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 197}], {
             RGBColor[
             0.5014082605188346, 0.6038556674298657, 0.9545132945318759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 195}], {
             RGBColor[
             0.33749044231736275`, 0.46608062557797425`, 0.942749676437169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 199}], {
             RGBColor[
             0.6464323286025333, 0.7125014496163389, 0.8676685277869252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 197}], {
             RGBColor[
             0.46777956485452377`, 0.5742177561919439, 0.9523891929507472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 196}], {
             RGBColor[
             0.5522683153034355, 0.6438635199028818, 0.9594259069227153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 199}], {
             RGBColor[
             0.6822975601726253, 0.7442244761830468, 0.8699297226377736]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.04610843439966642], {
             RGBColor[
             0.6747586761997523, 0.7458458732939058, 0.9682172969314027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.04610843439966642], {
             RGBColor[
             0.4126277021249406, 0.5318191091344603, 0.9475132502004189]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.04610843439966642], {
             RGBColor[
             0.26627754048828517`, 0.3972049563973342, 0.9384754840572636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.04610843439966642], {
             RGBColor[
             0.2173390106950707, 0.345767458702663, 0.9356885071836069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.04610843439966642], {
             RGBColor[
             0.8917486757676756, 0.6013378440476838, 0.2313847803888324]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.04610843439966642], {
             RGBColor[
             0.7783673391039698, 0.8267857482096835, 0.9785440401716914]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.04610843439966642], {
             RGBColor[
             0.23372153030876558`, 0.36298652552839294`, 0.9366214674398409]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.04610843439966642], {
             RGBColor[
             0.9944129994936373, 0.9904582957863187, 0.6332676577318835]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.04610843439966642], {
             RGBColor[
             0.4550202207245157, 0.5684449394683316, 0.9502400050508738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.04610843439966642], {
             RGBColor[
             0.6883134239512065, 0.7564349452572404, 0.9695683075109481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.04610843439966642], {
             RGBColor[
             0.28376079669505366`, 0.4155809671731155, 0.9394711296340792]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.04610843439966642], {
             RGBColor[
             0.2093152160508638, 0.3373339417936378, 0.9352315639487597]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.04610843439966642], {
             RGBColor[
             0.2936620543657398, 0.4259878167610016, 0.9400349916108267]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.04610843439966642], {
             RGBColor[
             0.3841396298295956, 0.507144172764379, 0.9456980154247727]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.04610843439966642], {
             RGBColor[
             0.24369575085229617`, 0.37347006372175184`, 0.937189484544258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.04610843439966642], {
             RGBColor[
             0.5232656780986867, 0.6238496761875024, 0.955612537446716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.04610843439966642], {
             RGBColor[
             0.28804359369038585`, 0.42008245836022284`, 0.9397150285871331]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.04610843439966642], {
             RGBColor[
             0.3896097630770392, 0.5118821272464233, 0.9460465674782509]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.04610843439966642], {
             RGBColor[
             0.9699820970445849, 0.9771332776424322, 0.9356966591672653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.04610843439966642], {
             RGBColor[
             0.294895611164345, 0.42728436316835394`, 0.9401052408456235]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.04610843439966642], {
             RGBColor[
             0.18935709457626326`, 0.31635669070584405`, 0.9340949784561761]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.04610843439966642], {
             RGBColor[
             0.2938131706704693, 0.4261466495785994, 0.9400435974608246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.04610843439966642], {
             RGBColor[
             0.21707253322129982`, 0.3454873739820821, 0.9356733316856937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.04610843439966642], {
             RGBColor[
             0.9849100503316931, 0.9880279322652069, 0.8997430477491545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.04610843439966642], {
             RGBColor[
             0.4555402436905675, 0.56886711753894, 0.9502809431636683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.04610843439966642], {
             RGBColor[
             0.3464092077026741, 0.47446397750419544`, 0.9432938662905475]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.04610843439966642], {
             RGBColor[
             0.7941810026697319, 0.8391395023755515, 0.9801201983688385]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.04610843439966642], {
             RGBColor[
             0.34540962211452697`, 0.4735981867083749, 0.9432301735807695]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.04610843439966642], {
             RGBColor[
             0.4007700204974213, 0.5215485812931107, 0.9467576892124495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.04610843439966642], {
             RGBColor[
             0.20896703242638065`, 0.3369679787281891, 0.9352117354064369]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.04610843439966642], {
             RGBColor[
             0.40190894008070766`, 0.5225350561923906, 0.9468302601611894]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.04610843439966642], {
             RGBColor[
             0.3617798020368932, 0.487777213767962, 0.944273266969841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.04610843439966642], {
             RGBColor[
             0.36793684800500254`, 0.49311013752340993`, 0.944665588494467]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.04610843439966642], {
             RGBColor[
             0.8595352851479842, 0.4550643608721931, 0.20450513763330225`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.04610843439966642], {
             RGBColor[
             0.9805207846610894, 0.984993013611304, 0.9178574099624649]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.04610843439966642], {
             RGBColor[
             0.7551365737597742, 0.8086376977624421, 0.9762286145860269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.04610843439966642], {
             RGBColor[
             0.2661411988258287, 0.39706165266553184`, 0.938467719601286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.04610843439966642], {
             RGBColor[
             0.8363963712438436, 0.8723837793278915, 0.9842574266207346]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.04610843439966642], {
             RGBColor[
             0.9486401971149956, 0.8340825267403634, 0.2775329009104499]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.04610843439966642], {
             RGBColor[
             0.30942809264468474`, 0.44243279436585276`, 0.9409374623401685]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.04610843439966642], {
             RGBColor[
             0.35053185182610624`, 0.4780348046337939, 0.9435565575285816]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.04610843439966642], {
             RGBColor[
             0.3613301452909011, 0.4873877436949888, 0.9442446152396022]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.04610843439966642], {
             RGBColor[
             0.26737010280126405`, 0.3983533086607267, 0.9385377038646866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.04610843439966642], {
             RGBColor[
             0.2581795486395869, 0.3886934535220141, 0.9380143154013856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.04610843439966642], {
             RGBColor[
             0.99287108173662, 0.987160289615858, 0.46543942549392037`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.04610843439966642], {
             RGBColor[
             0.9104969383058378, 0.9314695600968158, 0.9913252048574647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.04610843439966642], {
             RGBColor[
             0.358431322268727, 0.4848769288922631, 0.9440599047999579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.04610843439966642], {
             RGBColor[
             0.3990102466152305, 0.5200243536051641, 0.9466455579767832]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.04610843439966642], {
             RGBColor[
             0.484861738311665, 0.5926716277906267, 0.9525892386284149]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.04610843439966642], {
             RGBColor[
             0.9947869337309708, 0.9921122773751336, 0.7360575292682485]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.04610843439966642], {
             RGBColor[
             0.41962085413493355`, 0.5378762259194761, 0.9479588476626941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.04610843439966642], {
             RGBColor[
             0.5713720005998251, 0.6629045559590584, 0.9593996433732713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.04610843439966642], {
             RGBColor[
             0.8804115581351782, 0.9074802945946214, 0.9884556344392512]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.04610843439966642], {
             RGBColor[
             0.28770418825910593`, 0.4197257217324004, 0.939695699949927]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.04610843439966642], {
             RGBColor[
             0.3936133836729206, 0.5153498621787538, 0.9463016746423577]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.04610843439966642], {
             RGBColor[
             0.2646327113470033, 0.39547613668165604`, 0.9383818134709742]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.04610843439966642], {
             RGBColor[
             0.3893876786770247, 0.5116897689014174, 0.9460324164566635]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.04610843439966642], {
             RGBColor[
             0.30942809264468474`, 0.44243279436585276`, 0.9409374623401685]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.04610843439966642], {
             RGBColor[
             0.9850389673358539, 0.9880812427594433, 0.8976065593636972]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.04610843439966642], {
             RGBColor[
             0.6787132793064529, 0.7489352392969572, 0.9686114548112115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.04610843439966642], {
             RGBColor[
             0.2760855668168775, 0.40751381393347125`, 0.9390340366470021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.04610843439966642], {
             RGBColor[
             0.994529807283845, 0.9907081358384939, 0.6459814648418781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.04610843439966642], {
             RGBColor[
             0.3359498495530848, 0.46540460717764737`, 0.942627405238103]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.04610843439966642], {
             RGBColor[
             0.2758397150381692, 0.4072554081261457, 0.9390200357519098]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.04610843439966642], {
             RGBColor[
             0.9698134652863923, 0.9770075123532812, 0.935982108747679]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.04610843439966642], {
             RGBColor[
             0.4398683324044669, 0.5554135739286982, 0.9492489990738867]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.04610843439966642], {
             RGBColor[
             0.4000089660570174, 0.5208893941885412, 0.9467091954964809]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.04610843439966642], {
             RGBColor[
             0.3172619248821779, 0.4492180661101126, 0.9414366272031557]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.04610843439966642], {
             RGBColor[
             0.5672251618560266, 0.6595379654538862, 0.9590731890369887]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.04610843439966642], {
             RGBColor[
             0.3048573195466071, 0.4377547502869029, 0.9406725454009665]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.04610843439966642], {
             RGBColor[
             0.2217348685979069, 0.3503877840720326, 0.9359388447880844]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.04610843439966642], {
             RGBColor[
             0.24870775248762966`, 0.3787379952197451, 0.9374749106227983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.04610843439966642], {
             RGBColor[
             0.35841751616769923`, 0.48486497074146767`, 0.9440590250874087]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.04610843439966642], {
             RGBColor[
             0.38499696446986537`, 0.5078867529388886, 0.9457526440299394]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.04610843439966642], {
             RGBColor[
             0.24513448315949354`, 0.37498226259751327`, 0.9372714182207391]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.04610843439966642], {
             RGBColor[
             0.7570522934233754, 0.8101342725236561, 0.9764195556186767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.04610843439966642], {
             RGBColor[
             0.32772843219708697`, 0.45828362868433326`, 0.9421035437940927]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.04610843439966642], {
             RGBColor[
             0.3246672089761624, 0.4556321509919212, 0.9419084853573888]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.04610843439966642], {
             RGBColor[
             0.9733876265007912, 0.9796731159348281, 0.9299319861022425]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.04610843439966642], {
             RGBColor[
             0.5428817193351332, 0.6397748621558369, 0.9571567840687758]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.04610843439966642], {
             RGBColor[
             0.7199133314598152, 0.7811210331711576, 0.972717890973481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.04610843439966642], {
             RGBColor[
             0.282270328447336, 0.4140143905436192, 0.9393862496723219]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.04610843439966642], {
             RGBColor[
             0.9684789578489394, 0.9760122388914844, 0.9382410817440032]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.04610843439966642], {
             RGBColor[
             0.37097654117686685`, 0.4957429669694577, 0.9448592750554831]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.04610843439966642], {
             RGBColor[
             0.8357785622732934, 0.27601528466429986`, 0.18189489767999942`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.04610843439966642], {
             RGBColor[
             0.2419080423955311, 0.371591068786429, 0.9370876771923229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.04610843439966642], {
             RGBColor[
             0.3320279040410938, 0.46200761509787375`, 0.9423775023381191]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.04610843439966642], {
             RGBColor[
             0.35131790745638636`, 0.4787156465124378, 0.9436066442982612]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.04610843439966642], {
             RGBColor[
             0.27949904549447857`, 0.41110159645067834`, 0.9392284292079024]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.04610843439966642], {
             RGBColor[
             0.2425861171518165, 0.3723037683477076, 0.9371262925465716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.04610843439966642], {
             RGBColor[
             0.40167292877970195`, 0.5223306350657323, 0.9468152217297859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.04610843439966642], {
             RGBColor[
             0.4308135193556082, 0.5475707499739134, 0.9486720343932702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.04610843439966642], {
             RGBColor[
             0.48892598718299674`, 0.5959711681166989, 0.9529091911874004]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.04610843439966642], {
             RGBColor[
             0.8337134622526212, 0.26014202097281397`, 0.1799173555680068]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.04610843439966642], {
             RGBColor[
             0.18720606650611818`, 0.3140958238210648, 0.9339724805897421]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.04610843439966642], {
             RGBColor[
             0.4599186910161441, 0.5724217383246474, 0.9506256305759188]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.04610843439966642], {
             RGBColor[
             0.9923160771136491, 0.9910905146657525, 0.7770060177892187]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.04610843439966642], {
             RGBColor[
             0.31050597780896316`, 0.44336640431906715`, 0.9410061442296999]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.04610843439966642], {
             RGBColor[
             0.36000646398404595`, 0.4862412374771478, 0.9441602714372149]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.04610843439966642], {
             RGBColor[
             0.9940044804622655, 0.9895845148858246, 0.5888028822542988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.04610843439966642], {
             RGBColor[
             0.38633328958938185`, 0.5090442105917604, 0.9458377934848891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.04610843439966642], {
             RGBColor[
             0.45803470739904234`, 0.5708922355517895, 0.9504773164843211]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.04610843439966642], {
             RGBColor[
             0.30322531248840134`, 0.43603940739350466`, 0.9405796050133397]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.04610843439966642], {
             RGBColor[
             0.3290305677007825, 0.4594114730104009, 0.9421865147169549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.04610843439966642], {
             RGBColor[
             0.4239215283282335, 0.5416012537475425, 0.9482328828193543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.04610843439966642], {
             RGBColor[
             0.2753843011895019, 0.40677673929629066`, 0.9389941006069527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.04610843439966642], {
             RGBColor[
             0.9907823450008624, 0.9904562770219978, 0.8024239280695675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.04610843439966642], {
             RGBColor[
             0.3011256950455511, 0.4338325763376344, 0.9404600349060751]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.04610843439966642], {
             RGBColor[
             0.30611204314021384`, 0.4390735443378542, 0.9407440000534252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.04610843439966642], {
             RGBColor[
             0.5457992499198248, 0.6421434449177446, 0.9573864627636695]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.04610843439966642], {
             RGBColor[
             0.43968861603322656`, 0.5552579126407372, 0.9492375477056282]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.04610843439966642], {
             RGBColor[
             0.360920127522216, 0.4870326069118461, 0.9442184892699461]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.04610843439966642], {
             RGBColor[
             0.3588049877008656, 0.4852005791086109, 0.9440837144308744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.04610843439966642], {
             RGBColor[
             0.19791430031189616`, 0.32535085649217454`, 0.9345822986635689]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.04610843439966642], {
             RGBColor[
             0.8459936213239228, 0.8800363660313331, 0.9851728209009388]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.04610843439966642], {
             RGBColor[
             0.3306386678274742, 0.4608043285146788, 0.9422889814350406]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.04610843439966642], {
             RGBColor[
             0.29995997393985074`, 0.4326073295445563, 0.9403936488136353]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.04610843439966642], {
             RGBColor[
             0.43829777288016486`, 0.5540532342073646, 0.9491489244097895]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.04610843439966642], {
             RGBColor[
             0.31238306843161684`, 0.4449922458710919, 0.9411257507843293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.04610843439966642], {
             RGBColor[
             0.2885259606399425, 0.4205894566080379, 0.9397424986713123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.04610843439966642], {
             RGBColor[
             0.3529060431038644, 0.4800912097882647, 0.9437078388973854]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.04610843439966642], {
             RGBColor[
             0.2700899072180517, 0.40121199554833054`, 0.9386925927026326]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.04610843439966642], {
             RGBColor[
             0.8807967053696787, 0.907787400544869, 0.988492370126303]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.04610843439966642], {
             RGBColor[
             0.7617102060517315, 0.813773069270375, 0.9768838128188029]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.04610843439966642], {
             RGBColor[
             0.7403491167573226, 0.7970856239632912, 0.974754739068665]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.04610843439966642], {
             RGBColor[
             0.3963429735061762, 0.5177140956991457, 0.9464756016928513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.04610843439966642], {
             RGBColor[
             0.882934712052292, 0.9094921890389395, 0.9886962951123117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.04610843439966642], {
             RGBColor[
             0.3936423712690186, 0.5153749697775349, 0.9463035217063483]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.04610843439966642], {
             RGBColor[
             0.419657854128353, 0.5379082734541023, 0.947961205269557]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.04610843439966642], {
             RGBColor[
             0.3045569959180272, 0.4374390911116476, 0.9406554424146079]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.04610843439966642], {
             RGBColor[
             0.34248104567854293`, 0.4710616009940571, 0.9430435672799071]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.04610843439966642], {
             RGBColor[
             0.7255643513294814, 0.7855356528426826, 0.9732811318223061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.04610843439966642], {
             RGBColor[
             0.2839845832830512, 0.4158161810659901, 0.9394838739492031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.04610843439966642], {
             RGBColor[
             0.3371135415727025, 0.4664125387161786, 0.9427015546645805]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.04610843439966642], {
             RGBColor[
             0.47404783476508155`, 0.5838924137307071, 0.9517379285285941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.04610843439966642], {
             RGBColor[
             0.3059677016871769, 0.43892183231893567`, 0.9407357800212087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.04610843439966642], {
             RGBColor[
             0.33494952996127236`, 0.464538180624744, 0.9425636657582606]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.04610843439966642], {
             RGBColor[
             0.7905998095935818, 0.8363418471263875, 0.9797632585111599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.04610843439966642], {
             RGBColor[
             0.4440354311597563, 0.5590229054260565, 0.949514522921753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.04610843439966642], {
             RGBColor[
             0.3357664385160471, 0.465245745755872, 0.9426157184490069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.04610843439966642], {
             RGBColor[
             0.3239805007657761, 0.4550373588550428, 0.9418647289174552]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.04610843439966642], {
             RGBColor[
             0.20837108594641887`, 0.3363416011925601, 0.9351777971360269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.04610843439966642], {
             RGBColor[
             0.5566743254906181, 0.650972321182686, 0.9582425885493167]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.04610843439966642], {
             RGBColor[
             0.9904704006559311, 0.9795165651354338, 0.41747973537247046`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.04610843439966642], {
             RGBColor[
             0.7645263145464537, 0.8159730346296693, 0.9771644961955266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.04610843439966642], {
             RGBColor[
             0.41627381997411267`, 0.5349771931562015, 0.9477455776056327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.04610843439966642], {
             RGBColor[
             0.43329983369507497`, 0.5497242704889673, 0.9488304601444196]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.04610843439966642], {
             RGBColor[
             0.37012969203157964`, 0.49500946880368557`, 0.9448053145767846]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.04610843439966642], {
             RGBColor[
             0.9707544527167439, 0.913010043211834, 0.3408870006730844]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.04610843439966642], {
             RGBColor[
             0.5135847929016581, 0.6159902974656465, 0.954850422701755]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.04610843439966642], {
             RGBColor[
             0.30178542005761416`, 0.43452598915429436`, 0.9404976052695364]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.04610843439966642], {
             RGBColor[
             0.21321186643520434`, 0.3414295684094837, 0.9354534724235702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.04610843439966642], {
             RGBColor[
             0.5025001075552599, 0.6069912505420562, 0.9539777956667462]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.04610843439966642], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.04610843439966642], {
             RGBColor[
             0.5973970256413101, 0.6840328437017533, 0.961448428677345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.04610843439966642], {
             RGBColor[
             0.3160229983831292, 0.44814497024689304`, 0.941357683902176]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.04610843439966642], {
             RGBColor[
             0.2661411988258287, 0.39706165266553184`, 0.938467719601286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.04610843439966642], {
             RGBColor[
             0.430927136540159, 0.5476691594686056, 0.9486792739798021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.04610843439966642], {
             RGBColor[
             0.18166030002082895`, 0.30826687162312194`, 0.9336566573926313]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.04610843439966642], {
             RGBColor[
             0.9949427924270352, 0.9915914693005747, 0.6909323490292631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.04610843439966642], {
             RGBColor[
             0.3172619248821779, 0.4492180661101126, 0.9414366272031557]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.04610843439966642], {
             RGBColor[
             0.32169596699960673`, 0.4530586105307926, 0.9417191604460088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.04610843439966642], {
             RGBColor[
             0.4213905146930214, 0.539409016949166, 0.9480716088686061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.04610843439966642], {
             RGBColor[
             0.3951570639738854, 0.5166869204678216, 0.9464000365861124]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.04610843439966642], {
             RGBColor[
             0.309535083225584, 0.44252546422952477`, 0.9409442796853753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.04610843439966642], {
             RGBColor[
             0.36236051782334855`, 0.48828020059456556`, 0.9443102696662472]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.04610843439966642], {
             RGBColor[
             0.47832223900100224`, 0.587362567649144, 0.9520744252877044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.04610843439966642], {
             RGBColor[
             0.9344694009215406, 0.7779000419712138, 0.2661307456618581]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.04610843439966642], {
             RGBColor[
             0.24388970815995023`, 0.3736739251496999, 0.9372005301259948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.04610843439966642], {
             RGBColor[
             0.5101169363970025, 0.6131749353300119, 0.9545774203345316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.04610843439966642], {
             RGBColor[
             0.30322531248840134`, 0.43603940739350466`, 0.9405796050133397]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.04610843439966642], {
             RGBColor[
             0.24043123490936846`, 0.37003885048346935`, 0.9370035751907269]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.04610843439966642], {
             RGBColor[
             0.29756079560811244`, 0.4300856410012073, 0.9402570191569091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.04610843439966642], {
             RGBColor[
             0.2883477517875053, 0.4204021478050326, 0.9397323499408025]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.04610843439966642], {
             RGBColor[
             0.974797882516292, 0.9807248825621062, 0.9275447905216765]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.04610843439966642], {
             RGBColor[
             0.9197948223800564, 0.938883440473258, 0.9922120453407828]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.04610843439966642], {
             RGBColor[
             0.29417844711330704`, 0.426530578279886, 0.9400643994138661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.04610843439966642], {
             RGBColor[
             0.30942809264468474`, 0.44243279436585276`, 0.9409374623401685]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.04610843439966642], {
             RGBColor[
             0.32604221032105335`, 0.4568231080472887, 0.9419960992272193]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.04610843439966642], {
             RGBColor[
             0.3541572727593446, 0.4811749620272106, 0.9437875661446137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.04610843439966642], {
             RGBColor[
             0.6409312637984768, 0.7193758994328205, 0.964875603376246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.04610843439966642], {
             RGBColor[
             0.296809051411728, 0.42929551018747225`, 0.9402142084370309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.04610843439966642], {
             RGBColor[
             0.9707544527167439, 0.913010043211834, 0.3408870006730844]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.04610843439966642], {
             RGBColor[
             0.9943312303497649, 0.9919238323159623, 0.743609713617377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.04610843439966642], {
             RGBColor[
             0.6738775355857266, 0.7451575195493123, 0.9681294730697239]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.04610843439966642], {
             RGBColor[
             0.29340083399602646`, 0.4257132575901048, 0.9400201154972124]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.04610843439966642], {
             RGBColor[
             0.370482703817023, 0.49531522986934834`, 0.9448278081755971]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.04610843439966642], {
             RGBColor[
             0.29896939475638884`, 0.43156616801639003`, 0.9403372367945677]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.04610843439966642], {
             RGBColor[
             0.30162521074727067`, 0.43435759901126636`, 0.9404884815863207]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.04610843439966642], {
             RGBColor[
             0.4218442963209536, 0.5398020597875531, 0.9481005234326746]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.04610843439966642], {
             RGBColor[
             0.9637492000328393, 0.889379680997474, 0.3136729168270817]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.04610843439966642], {
             RGBColor[
             0.30322531248840134`, 0.43603940739350466`, 0.9405796050133397]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.04610843439966642], {
             RGBColor[
             0.37335567388745483`, 0.4978036521446821, 0.9450108712880173]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.04610843439966642], {
             RGBColor[
             0.7311809567194161, 0.7899233876610815, 0.9738409425574133]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.04610843439966642], {
             RGBColor[
             0.6323338172206462, 0.7123961049903831, 0.9641987808881547]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.04610843439966642], {
             RGBColor[
             0.224334441760091, 0.35312010028794627`, 0.9360868866339469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.04610843439966642], {
             RGBColor[
             0.9912394464577958, 0.9906453002214114, 0.7948485739875297]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.04610843439966642], {
             RGBColor[
             0.367098377623016, 0.49238389662127996`, 0.9446121619031571]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
          103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
          129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 
          142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 
          155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 
          168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 
          181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 
          194, 195, 196, 197, 198, 199, 200}, {Null, CompressedData["
1:eJwVxfk/Gg4DAOBN5QibNGP1lWNDwghlmCNXuqiMigzJGcNQUi05SwdqhpKc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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[21, 55] -> 
             RGBColor[
              0.34859095953566543`, 0.47635370128389704`, 0.9434328855880982],
              UndirectedEdge[64, 132] -> 
             RGBColor[
              0.4650482384089718, 0.5716822037632778, 0.9522031318796592], 
             UndirectedEdge[42, 188] -> 
             RGBColor[
              0.2579862693567474, 0.38807828505832953`, 0.9380183944910747], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.5482557857976138, 0.6358309000327967, 0.9605283874597037], 
             UndirectedEdge[33, 68] -> 
             RGBColor[
              0.9768074272678445, 0.9356471682387506, 0.5374347809068445], 
             UndirectedEdge[168, 188] -> 
             RGBColor[
              0.2612998708737691, 0.39156109034719, 0.938207099195435], 
             UndirectedEdge[41, 161] -> 
             RGBColor[
              0.2872671394725109, 0.41926635574719545`, 0.9396708106680862], 
             UndirectedEdge[44, 68] -> 
             RGBColor[
              0.9298826077939246, 0.7566572199616033, 0.27010292258186963`], 
             UndirectedEdge[26, 136] -> 
             RGBColor[
              0.2577972163446346, 0.3882915980387517, 0.9379925421427979], 
             UndirectedEdge[9, 32] -> 
             RGBColor[
              0.18966018913671598`, 0.3166752623061849, 0.9341122392430056], 
             UndirectedEdge[71, 141] -> 
             RGBColor[
              0.3537772547746116, 0.4808458095490941, 0.9437633517346631], 
             UndirectedEdge[52, 100] -> 
             RGBColor[
              0.1956898688928864, 0.3230128380336974, 0.9344556205850076], 
             UndirectedEdge[172, 180] -> 
             RGBColor[
              0.6056868100783286, 0.4851310394922843, 0.577851031637082], 
             UndirectedEdge[168, 197] -> 
             RGBColor[
              0.20505165545148296`, 0.3328526692783333, 0.9349887604799977], 
             UndirectedEdge[125, 137] -> 
             RGBColor[
              0.29408774568202667`, 0.42503485891778914`, 0.9401105091078588],
              UndirectedEdge[17, 147] -> 
             RGBColor[
              0.22049695582396892`, 0.34908665925842064`, 0.9358683474869365],
              UndirectedEdge[10, 71] -> 
             RGBColor[
              0.2908445212370684, 0.4179419677193835, 0.9400607036352882], 
             UndirectedEdge[27, 129] -> 
             RGBColor[
              0.36049570993893, 0.4827296556793453, 0.9443430413040212], 
             UndirectedEdge[67, 166] -> 
             RGBColor[
              0.5298097305765306, 0.6164429264479874, 0.9594779119033563], 
             UndirectedEdge[3, 49] -> 
             RGBColor[
              0.42052372581365627`, 0.5386582479879358, 0.9480163778476842], 
             UndirectedEdge[151, 183] -> 
             RGBColor[
              0.9651436444656913, 0.888619018725243, 0.5091874749108671], 
             UndirectedEdge[125, 136] -> 
             RGBColor[
              0.24354766177349693`, 0.373314412710544, 0.9371810510902985], 
             UndirectedEdge[139, 194] -> 
             RGBColor[
              0.2435950267958037, 0.37336419635210427`, 0.9371837484582486], 
             UndirectedEdge[24, 108] -> 
             RGBColor[
              0.28258697373339425`, 0.41434720481573717`, 0.9394042821529283],
              UndirectedEdge[21, 192] -> 
             RGBColor[
              0.4135089355037963, 0.532245803699352, 0.9476624011874208], 
             UndirectedEdge[16, 52] -> 
             RGBColor[
              0.18638226183152043`, 0.31322995287582944`, 0.9339255661322337],
              UndirectedEdge[44, 166] -> 
             RGBColor[
              0.8512516278317916, 0.7399182542257667, 0.6091593456597434], 
             UndirectedEdge[78, 187] -> 
             RGBColor[
              0.19320618779608617`, 0.3204023317264835, 0.9343141786208218], 
             UndirectedEdge[99, 162] -> 
             RGBColor[
              0.5016163434350541, 0.6062220183620153, 0.9539225219304044], 
             UndirectedEdge[93, 150] -> 
             RGBColor[
              0.21197440955790398`, 0.3401289227721434, 0.9353830010850614], 
             UndirectedEdge[118, 155] -> 
             RGBColor[
              0.5320287520312512, 0.6287959624909311, 0.9570938290152922], 
             UndirectedEdge[16, 125] -> 
             RGBColor[
              0.22572938407249296`, 0.3545862731027316, 0.936166326535006], 
             UndirectedEdge[61, 179] -> 
             RGBColor[
              0.2879403991921272, 0.41444560530367136`, 0.9399115732194068], 
             UndirectedEdge[51, 197] -> 
             RGBColor[
              0.1914512391651612, 0.3185577694452115, 0.9342142368925045], 
             UndirectedEdge[80, 120] -> 
             RGBColor[
              0.20786563933481106`, 0.33581034475659416`, 0.9351490126992371],
              UndirectedEdge[21, 183] -> 
             RGBColor[
              0.6488438964095984, 0.6364280199535685, 0.605957146255827], 
             UndirectedEdge[182, 199] -> 
             RGBColor[
              0.668046802775716, 0.7309711261041182, 0.8355721890992451], 
             UndirectedEdge[17, 189] -> 
             RGBColor[
              0.19295037100619816`, 0.32013345206058996`, 0.9342996102330847],
              UndirectedEdge[116, 136] -> 
             RGBColor[
              0.23171997218972168`, 0.36088276103916334`, 0.9365074816660013],
              UndirectedEdge[119, 123] -> 
             RGBColor[
              0.6489751309922214, 0.46304637074551996`, 0.5712200187466816], 
             UndirectedEdge[71, 89] -> 
             RGBColor[
              0.315626713124748, 0.4439896226750534, 0.9414720128013241], 
             UndirectedEdge[7, 61] -> 
             RGBColor[
              0.2079174287175954, 0.335864778681537, 0.9351519620279711], 
             UndirectedEdge[3, 27] -> 
             RGBColor[
              0.3426067292683088, 0.4672664245880422, 0.9431945216539286], 
             UndirectedEdge[41, 108] -> 
             RGBColor[
              0.29936649893310274`, 0.4319835496839754, 0.9403598512899686], 
             UndirectedEdge[66, 98] -> 
             RGBColor[
              0.18802367047876978`, 0.3149551774354076, 0.9340190419264479], 
             UndirectedEdge[119, 127] -> 
             RGBColor[
              0.8608066453023939, 0.6319627472541103, 0.5901965057147129], 
             UndirectedEdge[15, 167] -> 
             RGBColor[
              0.18913040232451964`, 0.31611842277614255`, 0.9340820686678004],
              UndirectedEdge[12, 96] -> 
             RGBColor[
              0.9432592874949708, 0.8959893159471047, 0.6356118637427102], 
             UndirectedEdge[7, 52] -> 
             RGBColor[
              0.19704159904264756`, 0.32443359212573797`, 0.934532599617331], 
             UndirectedEdge[163, 165] -> 
             RGBColor[
              0.24378292836413576`, 0.3735616928140688, 0.9371944491745896], 
             UndirectedEdge[71, 73] -> 
             RGBColor[
              0.29060892456725834`, 0.41769434068172157`, 0.9400472867534765],
              UndirectedEdge[60, 165] -> 
             RGBColor[
              0.1933919500064047, 0.32059757958753266`, 0.9343247575038889], 
             UndirectedEdge[120, 124] -> 
             RGBColor[
              0.20998768265750406`, 0.3380407468340621, 0.9352698599271827], 
             UndirectedEdge[43, 163] -> 
             RGBColor[
              0.2357550055079826, 0.36512383689254435`, 0.9367372708441793], 
             UndirectedEdge[146, 194] -> 
             RGBColor[
              0.22346288152433108`, 0.352204035220052, 0.9360372525678782], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.24761466346370808`, 0.37758908934975655`, 0.9374126608199662],
              UndirectedEdge[81, 157] -> 
             RGBColor[
              0.25622740358141927`, 0.3866416252927345, 0.9379031436282628], 
             UndirectedEdge[59, 114] -> 
             RGBColor[
              0.1828190891221793, 0.3094848324401137, 0.9337226487176782], 
             UndirectedEdge[31, 185] -> 
             RGBColor[
              0.38200599992585305`, 0.49606971836717273`, 0.9464117075671216],
              UndirectedEdge[58, 198] -> 
             RGBColor[
              0.6531000789032383, 0.7219510755774461, 0.9474306913916395], 
             UndirectedEdge[30, 142] -> 
             RGBColor[
              0.23578204115771023`, 0.3651522530745672, 0.9367388104844356], 
             UndirectedEdge[26, 96] -> 
             RGBColor[
              0.6145993386243387, 0.6885815666825401, 0.9662497087986179], 
             UndirectedEdge[25, 111] -> 
             RGBColor[
              0.19983749274486573`, 0.32737225367666856`, 0.9346918216275183],
              UndirectedEdge[89, 107] -> 
             RGBColor[
              0.24257389966697504`, 0.37229092699650596`, 0.9371255967788841],
              UndirectedEdge[51, 189] -> 
             RGBColor[
              0.18831403886767445`, 0.3152603730225656, 0.9340355779766345], 
             UndirectedEdge[81, 158] -> 
             RGBColor[
              0.3111871249613185, 0.44370525612704076`, 0.9410587411898188], 
             UndirectedEdge[93, 159] -> 
             RGBColor[
              0.24313944261504272`, 0.37288534849241906`, 0.9371578036131307],
              UndirectedEdge[191, 195] -> 
             RGBColor[
              0.6555677203865065, 0.728688801139147, 0.9677847110498968], 
             UndirectedEdge[17, 131] -> 
             RGBColor[
              0.18648216780881113`, 0.31333496039236675`, 0.9339312556298427],
              UndirectedEdge[18, 32] -> 
             RGBColor[
              0.20453729510132862`, 0.33231204393799124`, 0.9349594684189844],
              UndirectedEdge[59, 184] -> 
             RGBColor[
              0.1830159493280225, 0.30969174499811286`, 0.9337338596151724], 
             UndirectedEdge[156, 175] -> 
             RGBColor[
              0.6596444744105936, 0.3751515803022144, 0.5596916614795366], 
             UndirectedEdge[2, 82] -> 
             RGBColor[
              0.19716931432443496`, 0.3245678289845131, 0.934539872813691], 
             UndirectedEdge[12, 44] -> 
             RGBColor[
              0.9244380104653778, 0.7365581580535521, 0.25797799946440303`], 
             UndirectedEdge[115, 175] -> 
             RGBColor[
              0.4077982725568444, 0.5263530627871394, 0.9475600302171414], 
             UndirectedEdge[30, 131] -> 
             RGBColor[
              0.19553065372363834`, 0.3228454927959929, 0.9344465535166567], 
             UndirectedEdge[53, 65] -> 
             RGBColor[
              0.7940608836370591, 0.7881654857639895, 0.6245197254205552], 
             UndirectedEdge[17, 51] -> 
             RGBColor[
              0.18683289480672916`, 0.31370359670455467`, 0.9339512290135199],
              UndirectedEdge[109, 128] -> 
             RGBColor[
              0.32435782382982603`, 0.44691944921604004`, 0.9421979744658333],
              UndirectedEdge[101, 135] -> 
             RGBColor[
              0.1965653140451214, 0.3239329863951249, 0.9345054758913225], 
             UndirectedEdge[54, 195] -> 
             RGBColor[
              0.7447123095700184, 0.789153733450638, 0.681635360097179], 
             UndirectedEdge[122, 192] -> 
             RGBColor[
              0.3718189687016956, 0.49328632243521403`, 0.9451102958483188], 
             UndirectedEdge[155, 195] -> 
             RGBColor[
              0.5871109616069528, 0.6752098608899229, 0.9609615810995339], 
             UndirectedEdge[42, 87] -> 
             RGBColor[
              0.20973659970745412`, 0.3377768427339811, 0.9352555611246214], 
             UndirectedEdge[31, 153] -> 
             RGBColor[
              0.4071092490619125, 0.522454824847095, 0.9478413004684911], 
             UndirectedEdge[64, 199] -> 
             RGBColor[
              0.8123958459095635, 0.8512144164818124, 0.8460919805023865], 
             UndirectedEdge[107, 188] -> 
             RGBColor[
              0.2654176677513521, 0.39588915594893126`, 0.9384416016358788], 
             UndirectedEdge[27, 189] -> 
             RGBColor[
              0.23047600087590087`, 0.35957526831600095`, 0.9364366393399698],
              UndirectedEdge[14, 176] -> 
             RGBColor[
              0.20667251283261232`, 0.3345562931541938, 0.9350810659100094], 
             UndirectedEdge[123, 146] -> 
             RGBColor[
              0.34826410267529395`, 0.47021417637892043`, 0.9436264907064373],
              UndirectedEdge[30, 130] -> 
             RGBColor[
              0.1969307686942434, 0.3243171024025152, 0.9345262879929481], 
             UndirectedEdge[72, 143] -> 
             RGBColor[
              0.5544319884729032, 0.6356036049331575, 0.9619129375714212], 
             UndirectedEdge[68, 155] -> 
             RGBColor[
              0.817090690205986, 0.812348570970784, 0.6355099976070364], 
             UndirectedEdge[32, 39] -> 
             RGBColor[
              0.2190345544466123, 0.34754958268921615`, 0.9357850658919249], 
             UndirectedEdge[184, 194] -> 
             RGBColor[
              0.19166541671322765`, 0.3187828836278702, 0.9342264339870195], 
             UndirectedEdge[74, 152] -> 
             RGBColor[
              0.2730580915689248, 0.4008937800418094, 0.9389875071669056], 
             UndirectedEdge[71, 147] -> 
             RGBColor[
              0.3066316503071229, 0.4345352413338067, 0.9409597572808632], 
             UndirectedEdge[39, 173] -> 
             RGBColor[
              0.3099077362629189, 0.437607436708477, 0.9411599161992759], 
             UndirectedEdge[139, 171] -> 
             RGBColor[
              0.2967091465842705, 0.42919050387948254`, 0.940208519004903], 
             UndirectedEdge[73, 189] -> 
             RGBColor[
              0.20595537414504966`, 0.3338025349243465, 0.9350402259226642], 
             UndirectedEdge[20, 22] -> 
             RGBColor[
              0.1854064647205249, 0.3122043282430629, 0.9338699959303249], 
             UndirectedEdge[17, 168] -> 
             RGBColor[
              0.2004333110930509, 0.32799849653767643`, 0.9347257526010131], 
             UndirectedEdge[13, 132] -> 
             RGBColor[
              0.26083574153477407`, 0.39148528066721244`, 0.9381655816572811],
              UndirectedEdge[99, 109] -> 
             RGBColor[
              0.38461485844464394`, 0.49643648481667146`, 0.9467764936235569],
              UndirectedEdge[119, 195] -> 
             RGBColor[
              0.6739288625041259, 0.48336449574698853`, 0.5731680108502653], 
             UndirectedEdge[10, 188] -> 
             RGBColor[
              0.26557638653463256`, 0.3960559794535111, 0.9384506404357832], 
             UndirectedEdge[182, 185] -> 
             RGBColor[
              0.28644155976238705`, 0.41543196640215296`, 0.9397324188136974],
              UndirectedEdge[98, 187] -> 
             RGBColor[
              0.1979911315151781, 0.3254316109582035, 0.9345866740869342], 
             UndirectedEdge[10, 167] -> 
             RGBColor[
              0.2086421156058076, 0.33662647054885053`, 0.9351932318741767], 
             UndirectedEdge[113, 187] -> 
             RGBColor[
              0.20396723113485943`, 0.331712870565089, 0.934927004119428], 
             UndirectedEdge[83, 170] -> 
             RGBColor[
              0.7907969761749707, 0.8373558827785927, 0.9795546906537492], 
             UndirectedEdge[39, 41] -> 
             RGBColor[
              0.2713842645263738, 0.40257244714637036`, 0.9387663044365115], 
             UndirectedEdge[138, 145] -> 
             RGBColor[
              0.20603341116594734`, 0.3338845567811428, 0.935044670015559], 
             UndirectedEdge[75, 155] -> 
             RGBColor[
              0.5876661844347633, 0.6756606157940428, 0.9610052902743873], 
             UndirectedEdge[90, 163] -> 
             RGBColor[
              0.2545166466581612, 0.38484351129813643`, 0.9378057185523212], 
             UndirectedEdge[2, 66] -> 
             RGBColor[
              0.1829598466238134, 0.3096327774988722, 0.9337306646491643], 
             UndirectedEdge[88, 200] -> 
             RGBColor[
              0.20358824889509092`, 0.3313145362022305, 0.9349054216415271], 
             UndirectedEdge[67, 170] -> 
             RGBColor[
              0.45554903905121463`, 0.5584299098262512, 0.952076300177731], 
             UndirectedEdge[124, 136] -> 
             RGBColor[
              0.22442474851543817`, 0.35321501841359515`, 0.9360920294700671],
              UndirectedEdge[129, 155] -> 
             RGBColor[
              0.5638305008231241, 0.6563097340528043, 0.959128857947493], 
             UndirectedEdge[149, 167] -> 
             RGBColor[
              0.19241882352516138`, 0.31957476195596346`, 0.9342693393903937],
              UndirectedEdge[172, 173] -> 
             RGBColor[
              0.6185469880325928, 0.49626987926492994`, 0.5786704708045187], 
             UndirectedEdge[143, 160] -> 
             RGBColor[
              0.6494266978782655, 0.7230187336619522, 0.967777881154406], 
             UndirectedEdge[27, 89] -> 
             RGBColor[
              0.2670176485112967, 0.3979828568550783, 0.9385176321142823], 
             UndirectedEdge[172, 191] -> 
             RGBColor[
              0.8397221650752837, 0.6755835027616839, 0.59719713282006], 
             UndirectedEdge[11, 182] -> 
             RGBColor[
              0.27189457932291083`, 0.4001421676284322, 0.9389039897979983], 
             UndirectedEdge[159, 164] -> 
             RGBColor[
              0.22503263737217588`, 0.35385394814440607`, 0.9361266478411673],
              UndirectedEdge[151, 156] -> 
             RGBColor[
              0.9063104280310577, 0.5683123234196433, 0.4581304793295804], 
             UndirectedEdge[94, 196] -> 
             RGBColor[
              0.21169845343388266`, 0.3398388753891681, 0.9353672857920389], 
             UndirectedEdge[69, 139] -> 
             RGBColor[
              0.2677410752801248, 0.398743224257023, 0.938558830198553], 
             UndirectedEdge[53, 127] -> 
             RGBColor[
              0.7532853090466265, 0.8074724235406385, 0.9760373166313029], 
             UndirectedEdge[171, 196] -> 
             RGBColor[
              0.2703681630861383, 0.4015044601081305, 0.9387084389626774], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.7310843955752011, 0.737038335696917, 0.6195619855898489], 
             UndirectedEdge[74, 162] -> 
             RGBColor[
              0.39867126833608224`, 0.5197307476573095, 0.9466239585805827], 
             UndirectedEdge[34, 153] -> 
             RGBColor[
              0.3561569436366287, 0.48045786172119975`, 0.9440046574916221], 
             UndirectedEdge[98, 109] -> 
             RGBColor[
              0.2049550918267402, 0.33275117478624117`, 0.9349832613244216], 
             UndirectedEdge[77, 183] -> 
             RGBColor[
              0.8768515535875127, 0.45980910711412243`, 0.21594468162867203`],
              UndirectedEdge[2, 78] -> 
             RGBColor[
              0.1826523965739446, 0.3093096280030011, 0.9337131558236558], 
             UndirectedEdge[113, 193] -> 
             RGBColor[
              0.21695734101669506`, 0.34536629967143495`, 0.9356667716600531],
              UndirectedEdge[100, 120] -> 
             RGBColor[
              0.199864476631129, 0.3274006154520085, 0.934693358319922], 
             UndirectedEdge[1, 35] -> 
             RGBColor[
              0.1803467482579951, 0.30688624543639154`, 0.9335818525629636], 
             UndirectedEdge[154, 176] -> 
             RGBColor[
              0.28297932105843965`, 0.41262153691639003`, 0.9395049102298585],
              UndirectedEdge[13, 31] -> 
             RGBColor[
              0.37653388192589077`, 0.49031817539689215`, 0.9461000785422968],
              UndirectedEdge[92, 196] -> 
             RGBColor[
              0.23871657724306206`, 0.3682366365606061, 0.9369059279732393], 
             UndirectedEdge[66, 124] -> 
             RGBColor[
              0.2047917303558609, 0.33257947152263156`, 0.9349739581303267], 
             UndirectedEdge[141, 167] -> 
             RGBColor[
              0.27157484914335084`, 0.3995303123785612, 0.9388958799735516], 
             UndirectedEdge[76, 158] -> 
             RGBColor[
              0.2902964087900912, 0.4217477888831733, 0.9398690458089125], 
             UndirectedEdge[101, 134] -> 
             RGBColor[
              0.22153377048940157`, 0.350176417209637, 0.9359273925483029], 
             UndirectedEdge[139, 141] -> 
             RGBColor[
              0.31474199889707277`, 0.4449017237250964, 0.9413541852919508], 
             UndirectedEdge[88, 93] -> 
             RGBColor[
              0.22397479227765688`, 0.3527420858788138, 0.936066405127976], 
             UndirectedEdge[17, 130] -> 
             RGBColor[
              0.18788228277941618`, 0.31480656999888906`, 0.9340109901061341],
              UndirectedEdge[32, 117] -> 
             RGBColor[
              0.1856648230786062, 0.31247587925827236`, 0.9338847090566107], 
             UndirectedEdge[32, 103] -> 
             RGBColor[
              0.1835438669532831, 0.31024661989417246`, 0.9337639237429469], 
             UndirectedEdge[148, 150] -> 
             RGBColor[
              0.19306951159997304`, 0.3202586763785973, 0.9343063951136474], 
             UndirectedEdge[77, 156] -> 
             RGBColor[
              0.8180183371528791, 0.13950241180852277`, 0.1648876860473853], 
             UndirectedEdge[76, 89] -> 
             RGBColor[
              0.2658816302529869, 0.396788829637877, 0.93845293755506], 
             UndirectedEdge[42, 51] -> 
             RGBColor[
              0.1924833774375055, 0.31964261221079154`, 0.9342730156402028], 
             UndirectedEdge[82, 124] -> 
             RGBColor[
              0.21900119805648247`, 0.34751452300827246`, 0.9357831662948535],
              UndirectedEdge[15, 114] -> 
             RGBColor[
              0.1801710817898224, 0.3067016088404447, 0.9335718486174763], 
             UndirectedEdge[41, 173] -> 
             RGBColor[
              0.32922976019022715`, 0.45791610894315266`, 0.9422602768775632],
              UndirectedEdge[41, 133] -> 
             RGBColor[
              0.2699147403652278, 0.4010278840797926, 0.9386826172095004], 
             UndirectedEdge[27, 147] -> 
             RGBColor[
              0.25802258569367165`, 0.38852847551383163`, 0.9380053765938214],
              UndirectedEdge[19, 88] -> 
             RGBColor[
              0.28388973519432037`, 0.4117897874343075, 0.939622248296642], 
             UndirectedEdge[127, 172] -> 
             RGBColor[
              0.8720640822479042, 0.7012922099091854, 0.6003031260629946], 
             UndirectedEdge[69, 174] -> 
             RGBColor[
              0.21992361240255348`, 0.34848403897044045`, 0.9358356964272725],
              UndirectedEdge[117, 121] -> 
             RGBColor[
              0.2013378942582586, 0.3289492707981949, 0.9347772672740609], 
             UndirectedEdge[69, 196] -> 
             RGBColor[
              0.24140009178199262`, 0.37105718048567105`, 0.9370587501563274],
              UndirectedEdge[92, 195] -> 
             RGBColor[
              0.372739436043382, 0.49002947459904367`, 0.9455472387434574], 
             UndirectedEdge[144, 158] -> 
             RGBColor[
              0.2574165112915451, 0.3871889319062931, 0.9379965842878197], 
             UndirectedEdge[81, 168] -> 
             RGBColor[
              0.2577136388756711, 0.38820375281975344`, 0.9379877825295823], 
             UndirectedEdge[87, 188] -> 
             RGBColor[
              0.264952676857396, 0.39540042103725787`, 0.9384151210923604], 
             UndirectedEdge[74, 88] -> 
             RGBColor[
              0.2812466810785635, 0.40950050680300143`, 0.9394538352255469], 
             UndirectedEdge[74, 140] -> 
             RGBColor[
              0.6698268935487197, 0.7315161778042003, 0.7507274751968138], 
             UndirectedEdge[152, 178] -> 
             RGBColor[
              0.19191650879429833`, 0.319046797325233, 0.9342407333095791], 
             UndirectedEdge[63, 153] -> 
             RGBColor[
              0.23696466171985112`, 0.36639526226785174`, 0.9368061589759192],
              UndirectedEdge[154, 158] -> 
             RGBColor[
              0.3241076056222659, 0.45514745069325846`, 0.9418728279265163], 
             UndirectedEdge[23, 90] -> 
             RGBColor[
              0.22545415356299398`, 0.354296988386626, 0.936150652564657], 
             UndirectedEdge[51, 131] -> 
             RGBColor[
              0.18184583567028742`, 0.3084618813543424, 0.9336672233733925], 
             UndirectedEdge[21, 83] -> 
             RGBColor[
              0.6438448345050425, 0.715751939504987, 0.9685418227069613], 
             UndirectedEdge[57, 178] -> 
             RGBColor[
              0.1827435050835432, 0.30940538882320234`, 0.9337183443184945], 
             UndirectedEdge[17, 197] -> 
             RGBColor[
              0.19608757130368493`, 0.3234308484832359, 0.9344782691489546], 
             UndirectedEdge[64, 156] -> 
             RGBColor[
              0.724124328038114, 0.42749923026133874`, 0.5647677517545815], 
             UndirectedEdge[40, 123] -> 
             RGBColor[
              0.4784773066745961, 0.5874288969649759, 0.9521030898325651], 
             UndirectedEdge[26, 99] -> 
             RGBColor[
              0.42230145847218425`, 0.5360474909140672, 0.9489226897427967], 
             UndirectedEdge[114, 167] -> 
             RGBColor[
              0.19037448411434205`, 0.3174260316165872, 0.9341529172852767], 
             UndirectedEdge[75, 168] -> 
             RGBColor[
              0.3557698478286644, 0.47206054196027025`, 0.9445929358550735], 
             UndirectedEdge[55, 111] -> 
             RGBColor[
              0.27800719710349053`, 0.40702500884009835`, 0.9392353213324036],
              UndirectedEdge[67, 122] -> 
             RGBColor[
              0.26690693057918574`, 0.3978664852885073, 0.9385113268918411], 
             UndirectedEdge[127, 129] -> 
             RGBColor[
              0.6646291767752983, 0.7354973814495299, 0.9690579811407907], 
             UndirectedEdge[96, 198] -> 
             RGBColor[
              0.6410199693439192, 0.7129417496474699, 0.9678791658783956], 
             UndirectedEdge[154, 181] -> 
             RGBColor[
              0.3850218870849109, 0.5079083396553941, 0.9457542320769319], 
             UndirectedEdge[9, 91] -> 
             RGBColor[
              0.1897739422401799, 0.3167948240302888, 0.9341187173139652], 
             UndirectedEdge[39, 152] -> 
             RGBColor[
              0.22612393827552923`, 0.3550009745863041, 0.9361887958131783], 
             UndirectedEdge[54, 65] -> 
             RGBColor[
              0.9723656669587191, 0.9184450471811106, 0.347146263750879], 
             UndirectedEdge[116, 128] -> 
             RGBColor[
              0.33596717970245343`, 0.45912161831384746`, 0.9428591101082765],
              UndirectedEdge[74, 95] -> 
             RGBColor[
              0.29756419393855826`, 0.4266512474089263, 0.9403830934433266], 
             UndirectedEdge[152, 200] -> 
             RGBColor[
              0.19539965938545223`, 0.3227078094410386, 0.9344390935828858], 
             UndirectedEdge[140, 191] -> 
             RGBColor[
              0.9019134129618684, 0.9202806576422312, 0.7699493982996792], 
             UndirectedEdge[109, 193] -> 
             RGBColor[
              0.223435169075761, 0.3521749076795341, 0.936035674384929], 
             UndirectedEdge[80, 137] -> 
             RGBColor[
              0.2728427891012749, 0.40270506254337235`, 0.9389006402596817], 
             UndirectedEdge[118, 199] -> 
             RGBColor[
              0.6930640728290565, 0.752639828019768, 0.8371662674251406], 
             UndirectedEdge[45, 64] -> 
             RGBColor[
              0.6702869821102313, 0.7421560430065834, 0.9679059544483493], 
             UndirectedEdge[125, 170] -> 
             RGBColor[
              0.4597455397011603, 0.5628406980828529, 0.952315284681579], 
             UndirectedEdge[70, 145] -> 
             RGBColor[
              0.19062187863577218`, 0.31768605894432894`, 0.9341670060372848],
              UndirectedEdge[17, 142] -> 
             RGBColor[
              0.22673355524288302`, 0.35564172067094113`, 0.9362235125976215],
              UndirectedEdge[95, 180] -> 
             RGBColor[
              0.2956153583547517, 0.42496326397755757`, 0.9402589153632142], 
             UndirectedEdge[41, 121] -> 
             RGBColor[
              0.25402964955357293`, 0.38433164646381435`, 0.9377779847876626],
              UndirectedEdge[5, 10] -> 
             RGBColor[
              0.28614225358776674`, 0.41386909982440245`, 0.9397610792987268],
              UndirectedEdge[167, 194] -> 
             RGBColor[
              0.2004278770420817, 0.327992785005569, 0.9347254431398494], 
             UndirectedEdge[78, 100] -> 
             RGBColor[
              0.1943610742796171, 0.3216161906447068, 0.9343799476975574], 
             UndirectedEdge[106, 157] -> 
             RGBColor[
              0.1957274974930852, 0.3230523880782974, 0.9344577634781225], 
             UndirectedEdge[24, 115] -> 
             RGBColor[
              0.28608625432626233`, 0.41744460911573256`, 0.9396248182053492],
              UndirectedEdge[74, 164] -> 
             RGBColor[
              0.2705518531420833, 0.3982595645505048, 0.9388447805961444], 
             UndirectedEdge[46, 135] -> 
             RGBColor[
              0.18995764910618526`, 0.3169879115941485, 0.9341291791482143], 
             UndirectedEdge[126, 190] -> 
             RGBColor[
              0.18192592123823295`, 0.3085460563639715, 0.933671784128011], 
             UndirectedEdge[21, 177] -> 
             RGBColor[
              0.28934680274084895`, 0.4165928965590511, 0.9399671678191333], 
             UndirectedEdge[24, 133] -> 
             RGBColor[
              0.2531352151655193, 0.3833915392115544, 0.93772704807246], 
             UndirectedEdge[30, 188] -> 
             RGBColor[
              0.2613842726407983, 0.39164980195571875`, 0.938211905751206], 
             UndirectedEdge[80, 98] -> 
             RGBColor[
              0.2071471807023911, 0.33505519918101245`, 0.9351080975429851], 
             UndirectedEdge[12, 102] -> 
             RGBColor[
              0.9596388825040008, 0.9082051910857141, 0.6078854818749925], 
             UndirectedEdge[51, 168] -> 
             RGBColor[
              0.1957969789545272, 0.32312541749965207`, 0.934461720344563], 
             UndirectedEdge[42, 189] -> 
             RGBColor[
              0.19860085363697447`, 0.32607246756682684`, 0.9346213968597675],
              UndirectedEdge[52, 187] -> 
             RGBColor[
              0.19453498240935546`, 0.32179897911547406`, 0.934389851508272], 
             UndirectedEdge[10, 89] -> 
             RGBColor[
              0.2427326184502555, 0.3724577505010858, 0.9371346355787884], 
             UndirectedEdge[148, 193] -> 
             RGBColor[
              0.21151914615710812`, 0.33965041207254015`, 0.9353570745078879],
              UndirectedEdge[4, 92] -> 
             RGBColor[
              0.28937728391046563`, 0.41912091134823404`, 0.9398775137264412],
              UndirectedEdge[28, 97] -> 
             RGBColor[
              0.19804503866908396`, 0.3254882707948695, 0.9345897440196007], 
             UndirectedEdge[60, 169] -> 
             RGBColor[
              0.18653686033276015`, 0.3133924457027435, 0.9339343702881713], 
             UndirectedEdge[44, 198] -> 
             RGBColor[
              0.6221986923143263, 0.5535105917539171, 0.5902453016000886], 
             UndirectedEdge[13, 64] -> 
             RGBColor[
              0.4253184848962721, 0.5299237138095665, 0.9499405811920143], 
             UndirectedEdge[42, 106] -> 
             RGBColor[
              0.19390013127031533`, 0.3211317103164559, 0.9343536976750818], 
             UndirectedEdge[43, 90] -> 
             RGBColor[
              0.20850897767362986`, 0.33648653414069934`, 0.935185649865899], 
             UndirectedEdge[166, 192] -> 
             RGBColor[
              0.6347217686990404, 0.711862763594694, 0.9660768808598341], 
             UndirectedEdge[5, 89] -> 
             RGBColor[
              0.31092444547544634`, 0.4399167547800723, 0.9411723884647626], 
             UndirectedEdge[114, 184] -> 
             RGBColor[
              0.18161202378548802`, 0.3082161302388885, 0.9336539081324469], 
             UndirectedEdge[58, 192] -> 
             RGBColor[
              0.7131454310850844, 0.7736227561744136, 0.951349727711992], 
             UndirectedEdge[17, 157] -> 
             RGBColor[
              0.19894707579879906`, 0.3264363690106574, 0.9346411136996936], 
             UndirectedEdge[38, 111] -> 
             RGBColor[
              0.200630301320241, 0.32820554575635497`, 0.9347369709030307], 
             UndirectedEdge[3, 191] -> 
             RGBColor[
              0.6143982789320568, 0.6943254432107253, 0.9648034682477634], 
             UndirectedEdge[40, 195] -> 
             RGBColor[
              0.5034310381865006, 0.6077470219664445, 0.9540510819361487], 
             UndirectedEdge[113, 136] -> 
             RGBColor[
              0.21363278825802834`, 0.3418719839332567, 0.9354774432986821], 
             UndirectedEdge[53, 141] -> 
             RGBColor[
              0.4877995456867602, 0.5920834332461721, 0.9536420283584146], 
             UndirectedEdge[142, 176] -> 
             RGBColor[
              0.24804284091250217`, 0.37803913099645736`, 0.9374370448922433],
              UndirectedEdge[99, 128] -> 
             RGBColor[
              0.49156366276898256`, 0.5975148916314856, 0.9532819740075988], 
             UndirectedEdge[41, 151] -> 
             RGBColor[
              0.6423047351050197, 0.7073139713016436, 0.8452851258395946], 
             UndirectedEdge[5, 157] -> 
             RGBColor[
              0.28037950263265143`, 0.40781208319106244`, 0.939432899157059], 
             UndirectedEdge[39, 74] -> 
             RGBColor[
              0.29899639389246113`, 0.42815658036720006`, 0.9404646551119514],
              UndirectedEdge[86, 171] -> 
             RGBColor[
              0.25492345163412733`, 0.3852710891208021, 0.9378288854938884], 
             UndirectedEdge[162, 180] -> 
             RGBColor[
              0.3967224327522758, 0.5180427642259409, 0.9464997805004701], 
             UndirectedEdge[27, 127] -> 
             RGBColor[
              0.5706539535210267, 0.6502280340235855, 0.9632042593205097], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.2536345517124762, 0.3839163735821717, 0.937755484550107], 
             UndirectedEdge[155, 191] -> 
             RGBColor[
              0.7416468272326004, 0.7980994052495431, 0.9748840827210469], 
             UndirectedEdge[46, 105] -> 
             RGBColor[
              0.19436779950481975`, 0.32162325928279867`, 0.9343803306891837],
              UndirectedEdge[30, 168] -> 
             RGBColor[
              0.2094817970078781, 0.3375090289413025, 0.9352410504878272], 
             UndirectedEdge[161, 180] -> 
             RGBColor[
              0.31293043325479175`, 0.4431625055366565, 0.9412449832634135], 
             UndirectedEdge[125, 192] -> 
             RGBColor[
              0.364998647890857, 0.48611773282970705`, 0.9447218886679021], 
             UndirectedEdge[33, 140] -> 
             RGBColor[
              0.9931733912441731, 0.9901003146609737, 0.6650510516491244], 
             UndirectedEdge[12, 58] -> 
             RGBColor[
              0.9553393970542898, 0.9049986418770809, 0.615163389255954], 
             UndirectedEdge[127, 155] -> 
             RGBColor[
              0.7739887444052208, 0.8238081123970447, 0.9779900759639816], 
             UndirectedEdge[78, 120] -> 
             RGBColor[
              0.188434679061321, 0.31538717351511814`, 0.9340424482571915], 
             UndirectedEdge[45, 183] -> 
             RGBColor[
              0.823713544812509, 0.7798413316678898, 0.6197525703698252], 
             UndirectedEdge[98, 136] -> 
             RGBColor[
              0.20765668863834705`, 0.33559072432637116`, 0.9351371132661883],
              UndirectedEdge[59, 92] -> 
             RGBColor[
              0.21433501599530952`, 0.3426100698089493, 0.9355174341294674], 
             UndirectedEdge[81, 89] -> 
             RGBColor[
              0.2867723464242142, 0.41874629688174436`, 0.9396426329359664], 
             UndirectedEdge[161, 200] -> 
             RGBColor[
              0.23722083665512567`, 0.36666451836725433`, 0.9368207477595063],
              UndirectedEdge[125, 198] -> 
             RGBColor[
              0.30495329570901086`, 0.43444605223273947`, 0.9408028523475496],
              UndirectedEdge[159, 173] -> 
             RGBColor[
              0.3113226737864071, 0.4390946257578836, 0.941240494798026], 
             UndirectedEdge[54, 151] -> 
             RGBColor[
              0.9911479730677677, 0.9821275166719952, 0.580056048665182], 
             UndirectedEdge[61, 192] -> 
             RGBColor[
              0.33652735532483224`, 0.4561925991586039, 0.9431004906757697], 
             UndirectedEdge[59, 194] -> 
             RGBColor[
              0.19287248204991897`, 0.32005158582909543`, 0.934295174572251], 
             UndirectedEdge[80, 82] -> 
             RGBColor[
              0.2168791547337895, 0.3452841209308045, 0.9356623190669078], 
             UndirectedEdge[157, 168] -> 
             RGBColor[
              0.2079111599465971, 0.33585818980575477`, 0.9351516050307367], 
             UndirectedEdge[122, 170] -> 
             RGBColor[
              0.4665658605119989, 0.5700092876883599, 0.9527036918619959], 
             UndirectedEdge[26, 67] -> 
             RGBColor[
              0.2743361643394848, 0.4056750810112081, 0.9389344107639237], 
             UndirectedEdge[160, 181] -> 
             RGBColor[
              0.4406818300512263, 0.5561181847027405, 0.9493008344245906], 
             UndirectedEdge[42, 168] -> 
             RGBColor[
              0.20608379372382724`, 0.3339375120439133, 0.935047539227696], 
             UndirectedEdge[61, 67] -> 
             RGBColor[
              0.2316153172023224, 0.36077276201189723`, 0.936501521719292], 
             UndirectedEdge[9, 39] -> 
             RGBColor[
              0.22268787528916928`, 0.3513894545286635, 0.9359931171093048], 
             UndirectedEdge[118, 171] -> 
             RGBColor[
              0.3493088123107567, 0.4768833997475762, 0.9434819976486537], 
             UndirectedEdge[97, 134] -> 
             RGBColor[
              0.23183626588337625`, 0.3610049930846403, 0.9365141044198138], 
             UndirectedEdge[79, 190] -> 
             RGBColor[
              0.18918203979750087`, 0.31617269703425077`, 0.9340850093454959],
              UndirectedEdge[47, 50] -> 
             RGBColor[
              0.2000038325739316, 0.3275470873835711, 0.9347012944347058], 
             UndirectedEdge[36, 145] -> 
             RGBColor[
              0.1863723647153286, 0.3132195503791984, 0.9339250025061079], 
             UndirectedEdge[170, 179] -> 
             RGBColor[
              0.5118741210410194, 0.6121027531180253, 0.9554863516778458], 
             UndirectedEdge[26, 198] -> 
             RGBColor[
              0.3192028502801486, 0.44942323756094715`, 0.9416143434000489], 
             UndirectedEdge[5, 141] -> 
             RGBColor[
              0.34907498712530993`, 0.4767729416541131, 0.9434637273981017], 
             UndirectedEdge[18, 39] -> 
             RGBColor[
              0.2375649812537819, 0.3670262361604698, 0.9368403462852835], 
             UndirectedEdge[19, 180] -> 
             RGBColor[
              0.3466247657178071, 0.47465068302264285`, 0.9433076014566613], 
             UndirectedEdge[170, 198] -> 
             RGBColor[
              0.5004157249918784, 0.6021780663759904, 0.9547562328138562], 
             UndirectedEdge[12, 172] -> 
             RGBColor[
              0.9097214307201227, 0.6697336065748736, 0.2456981245885829], 
             UndirectedEdge[47, 101] -> 
             RGBColor[
              0.19622767860092072`, 0.3235781101359464, 0.934486248052262], 
             UndirectedEdge[53, 54] -> 
             RGBColor[
              0.810087981057518, 0.842228648704628, 0.6867819724356502], 
             UndirectedEdge[57, 121] -> 
             RGBColor[
              0.1995963195919732, 0.32711876540171747`, 0.9346780871732447], 
             UndirectedEdge[19, 121] -> 
             RGBColor[
              0.28428483303541713`, 0.41220506031595017`, 0.9396447485341975],
              UndirectedEdge[170, 192] -> 
             RGBColor[
              0.5604610771737245, 0.6538497469729578, 0.9586752691342088], 
             UndirectedEdge[7, 137] -> 
             RGBColor[
              0.266193356547354, 0.39571608733082725`, 0.9385219649126898], 
             UndirectedEdge[111, 115] -> 
             RGBColor[
              0.26758071568904057`, 0.3979941146890951, 0.9385709551564505], 
             UndirectedEdge[140, 162] -> 
             RGBColor[
              0.7225676146989453, 0.7771975396388044, 0.7540880673117176], 
             UndirectedEdge[8, 79] -> 
             RGBColor[
              0.2387210212797669, 0.3682413075249512, 0.9369061810545554], 
             UndirectedEdge[2, 52] -> 
             RGBColor[
              0.1839811911872139, 0.31070627539199164`, 0.933788828711106], 
             UndirectedEdge[18, 152] -> 
             RGBColor[
              0.21162667893024556`, 0.3397634358350792, 0.9353631983402376], 
             UndirectedEdge[4, 195] -> 
             RGBColor[
              0.41766970262794245`, 0.5348906935287172, 0.9481924844113676], 
             UndirectedEdge[81, 107] -> 
             RGBColor[
              0.26183143575325407`, 0.39253181842149465`, 0.938222284970026], 
             UndirectedEdge[108, 175] -> 
             RGBColor[
              0.4042989919639763, 0.5232556584871441, 0.9473394941647204], 
             UndirectedEdge[49, 191] -> 
             RGBColor[
              0.6162290328937537, 0.6959111502759776, 0.9649201222713306], 
             UndirectedEdge[77, 192] -> 
             RGBColor[
              0.6415165926817106, 0.355626890859906, 0.5576499365602658], 
             UndirectedEdge[21, 166] -> 
             RGBColor[
              0.5825165188394155, 0.666981785574234, 0.9626574089267232], 
             UndirectedEdge[8, 192] -> 
             RGBColor[
              0.37448920004002384`, 0.4960929048742423, 0.9452623615727833], 
             UndirectedEdge[108, 165] -> 
             RGBColor[
              0.25691494582414054`, 0.38736427578253046`, 0.937942298141858], 
             UndirectedEdge[29, 194] -> 
             RGBColor[
              0.2042163465061234, 0.3319747066151143, 0.9349411908712882], 
             UndirectedEdge[106, 131] -> 
             RGBColor[
              0.18326258950309726`, 0.3099509794600067, 0.9337479054082716], 
             UndirectedEdge[12, 68] -> 
             RGBColor[
              0.9555467146303788, 0.8599776150331977, 0.2908341193259223], 
             UndirectedEdge[71, 168] -> 
             RGBColor[
              0.2865680055762049, 0.4134470786130624, 0.93981716239494], 
             UndirectedEdge[49, 146] -> 
             RGBColor[
              0.3338791466944457, 0.45775465051721964`, 0.9427098940314549], 
             UndirectedEdge[112, 134] -> 
             RGBColor[
              0.5941420485372255, 0.6663173396662936, 0.9607153178159171], 
             UndirectedEdge[84, 126] -> 
             RGBColor[
              0.1804502852518648, 0.30699506938157317`, 0.9335877488415951], 
             UndirectedEdge[10, 62] -> 
             RGBColor[
              0.2089259147709481, 0.3369247614653196, 0.9352093938167881], 
             UndirectedEdge[34, 182] -> 
             RGBColor[
              0.3854450302409573, 0.5082748449893679, 0.9457811943846643], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.20133152966492007`, 0.3289425812070576, 0.9347769048198857], 
             UndirectedEdge[67, 79] -> 
             RGBColor[
              0.22503396848065443`, 0.3538553472238142, 0.9361267236458259], 
             UndirectedEdge[33, 96] -> 
             RGBColor[
              0.9645200001324366, 0.9716588691526575, 0.8822125253236324], 
             UndirectedEdge[12, 140] -> 
             RGBColor[
              0.9719126786067074, 0.9144307614554209, 0.4184503900682022], 
             UndirectedEdge[26, 124] -> 
             RGBColor[
              0.25940975173137165`, 0.3899864749708609, 0.9380843736475403], 
             UndirectedEdge[13, 70] -> 
             RGBColor[
              0.20607827017508945`, 0.33393170644397663`, 0.9350472246697668],
              UndirectedEdge[53, 146] -> 
             RGBColor[
              0.438593505674698, 0.543607216634379, 0.9507210951484925], 
             UndirectedEdge[87, 147] -> 
             RGBColor[
              0.23311384595539386`, 0.3623478107435859, 0.9365868607149048], 
             UndirectedEdge[93, 200] -> 
             RGBColor[
              0.21100022620147757`, 0.339104994297747, 0.935327522784088], 
             UndirectedEdge[9, 117] -> 
             RGBColor[
              0.1893181439211632, 0.3163157510977197, 0.9340927602739904], 
             UndirectedEdge[99, 116] -> 
             RGBColor[
              0.39622421431727134`, 0.5086386539144789, 0.9474376292660001], 
             UndirectedEdge[71, 155] -> 
             RGBColor[
              0.5184643421823038, 0.6170471524468351, 0.9562295168142538], 
             UndirectedEdge[54, 140] -> 
             RGBColor[
              0.9910580021453803, 0.9807455899537222, 0.48380004734696136`], 
             UndirectedEdge[76, 154] -> 
             RGBColor[
              0.29805964700021337`, 0.42847191562908343`, 0.9403637124828994],
              UndirectedEdge[33, 128] -> 
             RGBColor[
              0.7119650853654641, 0.7696077577835532, 0.8603069871100877], 
             UndirectedEdge[109, 148] -> 
             RGBColor[
              0.20549299658683456`, 0.33331654679423195`, 0.9350138942047502],
              UndirectedEdge[27, 142] -> 
             RGBColor[
              0.2642591851125857, 0.3950835369263521, 0.9383605417045067], 
             UndirectedEdge[49, 69] -> 
             RGBColor[
              0.33608426308955985`, 0.46007236766093923`, 0.9428354721479792],
              UndirectedEdge[60, 90] -> 
             RGBColor[
              0.2041256683004301, 0.33187939807160033`, 0.9349360268816205], 
             UndirectedEdge[40, 191] -> 
             RGBColor[
              0.6579669038121483, 0.7306365663260646, 0.9679735835576617], 
             UndirectedEdge[58, 166] -> 
             RGBColor[
              0.8821530144207035, 0.9083587380492957, 0.9663447354512944], 
             UndirectedEdge[38, 60] -> 
             RGBColor[
              0.18105257981885614`, 0.3076281191591622, 0.9336220486261704], 
             UndirectedEdge[54, 119] -> 
             RGBColor[
              0.9176093173132854, 0.6667189724180997, 0.30094116151906036`], 
             UndirectedEdge[3, 146] -> 
             RGBColor[
              0.33204839273274867`, 0.4561689434519673, 0.9425932400078877], 
             UndirectedEdge[115, 163] -> 
             RGBColor[
              0.2983939725453868, 0.4303808013184385, 0.9403257245502908], 
             UndirectedEdge[137, 170] -> 
             RGBColor[
              0.48955017496489417`, 0.59276687306104, 0.9540638895741654], 
             UndirectedEdge[58, 99] -> 
             RGBColor[
              0.7561986870952739, 0.8085753289305662, 0.9547390377343874], 
             UndirectedEdge[40, 64] -> 
             RGBColor[
              0.5676806016913061, 0.6599077120294969, 0.959109042929153], 
             UndirectedEdge[77, 96] -> 
             RGBColor[
              0.8768677288440547, 0.5431135393845314, 0.5783662656384824], 
             UndirectedEdge[141, 195] -> 
             RGBColor[
              0.42242387419926064`, 0.539008517992182, 0.9484954160199432], 
             UndirectedEdge[138, 182] -> 
             RGBColor[
              0.28135325644561493`, 0.4100838369991616, 0.9394426474672775], 
             UndirectedEdge[33, 102] -> 
             RGBColor[
              0.9808995951414665, 0.9838747442912669, 0.8544861434559147], 
             UndirectedEdge[137, 198] -> 
             RGBColor[
              0.3347579309727448, 0.4643722272109265, 0.9425514572401359], 
             UndirectedEdge[69, 171] -> 
             RGBColor[
              0.27878211770791206`, 0.41034805989114986`, 0.939187601231057], 
             UndirectedEdge[20, 46] -> 
             RGBColor[
              0.182651270158183, 0.3093084440686167, 0.9337130916759446], 
             UndirectedEdge[76, 157] -> 
             RGBColor[
              0.23533668741019195`, 0.36468415804886706`, 0.9367134482473564],
              UndirectedEdge[10, 168] -> 
             RGBColor[
              0.21367391090171242`, 0.3419152064390949, 0.9354797851724044], 
             UndirectedEdge[82, 100] -> 
             RGBColor[
              0.20887799203010743`, 0.3368743916262188, 0.9352066646875926], 
             UndirectedEdge[9, 57] -> 
             RGBColor[
              0.18757656925487778`, 0.3144852457012422, 0.9339935801731742], 
             UndirectedEdge[27, 71] -> 
             RGBColor[
              0.3151295512981096, 0.44346707407337604`, 0.941443700170782], 
             UndirectedEdge[122, 125] -> 
             RGBColor[
              0.2711034312291314, 0.40227727354510906`, 0.9387503113956892], 
             UndirectedEdge[5, 147] -> 
             RGBColor[
              0.30192938265782127`, 0.43046237343882565`, 0.9406601329443018],
              UndirectedEdge[5, 71] -> 
             RGBColor[
              0.35903634826225916`, 0.48540097199837007`, 0.9440984565212622],
              UndirectedEdge[61, 84] -> 
             RGBColor[
              0.19428775253280067`, 0.3215391248399355, 0.9343757721325461], 
             UndirectedEdge[62, 149] -> 
             RGBColor[
              0.19270262269030192`, 0.3198730528724325, 0.9342855013330051], 
             UndirectedEdge[36, 138] -> 
             RGBColor[
              0.20221257093783607`, 0.32986861144613544`, 0.9348270788169946],
              UndirectedEdge[33, 162] -> 
             RGBColor[
              0.7220177660315357, 0.778314884514083, 0.8609475350328932], 
             UndirectedEdge[63, 145] -> 
             RGBColor[
              0.1909329030445121, 0.31801296531800116`, 0.9341847184172432], 
             UndirectedEdge[93, 173] -> 
             RGBColor[
              0.29957000075540785`, 0.42674182123979476`, 0.9405711974554323],
              UndirectedEdge[23, 55] -> 
             RGBColor[
              0.27975796086466953`, 0.40886517255793126`, 0.9393350247385799],
              UndirectedEdge[23, 165] -> 
             RGBColor[
              0.21472043526896856`, 0.3430151699025583, 0.9355393831869255], 
             UndirectedEdge[54, 64] -> 
             RGBColor[
              0.8089618730748239, 0.8413144235136905, 0.6866933210901831], 
             UndirectedEdge[72, 158] -> 
             RGBColor[
              0.284772839183219, 0.41594216701181014`, 0.93955448669119], 
             UndirectedEdge[73, 149] -> 
             RGBColor[
              0.2014915378121197, 0.32911075991486693`, 0.934786017047158], 
             UndirectedEdge[10, 197] -> 
             RGBColor[
              0.20932817111234645`, 0.33734755838465436`, 0.9352323017203459],
              UndirectedEdge[37, 135] -> 
             RGBColor[
              0.21639131765151565`, 0.3447713732266772, 0.9356345374667627], 
             UndirectedEdge[58, 96] -> 
             RGBColor[
              0.9484965672474285, 0.961109404699039, 0.9720660567902085], 
             UndirectedEdge[112, 156] -> 
             RGBColor[
              0.880064299434007, 0.550351383801579, 0.5748087868596949], 
             UndirectedEdge[2, 187] -> 
             RGBColor[
              0.1929273076602217, 0.3201092110216681, 0.9342982968096505], 
             UndirectedEdge[43, 169] -> 
             RGBColor[
              0.19092016970595993`, 0.3179995817718425, 0.9341839932724498], 
             UndirectedEdge[44, 96] -> 
             RGBColor[
              0.9175951806585165, 0.7926689208755102, 0.6148806669986575], 
             UndirectedEdge[88, 161] -> 
             RGBColor[
              0.25019540273130497`, 0.38030160994832113`, 0.9375596301033943],
              UndirectedEdge[129, 146] -> 
             RGBColor[
              0.3499373734033699, 0.4716321745432704, 0.9437417596579802], 
             UndirectedEdge[23, 111] -> 
             RGBColor[
              0.2218869245410005, 0.3505476045091276, 0.935947504149097], 
             UndirectedEdge[174, 196] -> 
             RGBColor[
              0.21150965778077974`, 0.33964043918742115`, 0.9353565341588927],
              UndirectedEdge[66, 100] -> 
             RGBColor[
              0.1946685243294859, 0.3219393401405779, 0.9343974565230659], 
             UndirectedEdge[10, 73] -> 
             RGBColor[
              0.2177148298927659, 0.346162468507754, 0.9357099095309409], 
             UndirectedEdge[147, 188] -> 
             RGBColor[
              0.2813635156046871, 0.41264925306793426`, 0.9393496940813583], 
             UndirectedEdge[62, 189] -> 
             RGBColor[
              0.19716645902323188`, 0.3245648278819121, 0.9345397102085116], 
             UndirectedEdge[42, 89] -> 
             RGBColor[
              0.2351425012723703, 0.3644800561059042, 0.93670238963408], 
             UndirectedEdge[119, 140] -> 
             RGBColor[
              0.9202745550794877, 0.6749563522500728, 0.37533269810004777`], 
             UndirectedEdge[140, 151] -> 
             RGBColor[
              0.9938132108339699, 0.9903648965039682, 0.6544475852461695], 
             UndirectedEdge[1, 86] -> 
             RGBColor[
              0.19100632204633058`, 0.3180901333439459, 0.934188899520783], 
             UndirectedEdge[76, 181] -> 
             RGBColor[
              0.3512106902527362, 0.4745086778453089, 0.9437504499593281], 
             UndirectedEdge[122, 166] -> 
             RGBColor[
              0.5408265520373148, 0.6280223043100961, 0.9601053035876213], 
             UndirectedEdge[10, 189] -> 
             RGBColor[
              0.20619097081485965`, 0.33405016196200843`, 0.935053642804476], 
             UndirectedEdge[102, 162] -> 
             RGBColor[
              0.7102938185962386, 0.7709719692690975, 0.9435231591185078], 
             UndirectedEdge[156, 183] -> 
             RGBColor[
              0.8775508907403917, 0.4651845189226452, 0.21661436767605732`], 
             UndirectedEdge[31, 199] -> 
             RGBColor[
              0.763611242939182, 0.811608878069138, 0.8422514778526693], 
             UndirectedEdge[73, 130] -> 
             RGBColor[
              0.20088728591826768`, 0.3284756528626456, 0.9347516057957137], 
             UndirectedEdge[4, 199] -> 
             RGBColor[
              0.6647841302718416, 0.7281451631679503, 0.8353642944923663], 
             UndirectedEdge[6, 83] -> 
             RGBColor[
              0.8789095063816696, 0.593376334043407, 0.5852871633250518], 
             UndirectedEdge[73, 89] -> 
             RGBColor[
              0.2424970217804455, 0.37221012346342386`, 0.9371212186969768], 
             UndirectedEdge[60, 111] -> 
             RGBColor[
              0.20055843927843664`, 0.3281300141941019, 0.9347328784660603], 
             UndirectedEdge[166, 179] -> 
             RGBColor[
              0.5861348125663353, 0.6701157697397615, 0.962887963403471], 
             UndirectedEdge[30, 197] -> 
             RGBColor[
              0.20513605721851214`, 0.33294138088686204`, 0.9349935670357687],
              UndirectedEdge[26, 58] -> 
             RGBColor[
              0.6266794481836577, 0.6975908926125163, 0.9458012343118618], 
             UndirectedEdge[11, 35] -> 
             RGBColor[
              0.19186691491128627`, 0.3189946710097535, 0.9342379090113091], 
             UndirectedEdge[137, 187] -> 
             RGBColor[
              0.2636867399140619, 0.3930814743205634, 0.9383792168036308], 
             UndirectedEdge[13, 153] -> 
             RGBColor[
              0.2516813551580962, 0.3818634401637041, 0.9376442528958304], 
             UndirectedEdge[71, 75] -> 
             RGBColor[
              0.4329404581640204, 0.5480873032405589, 0.9491738543179573], 
             UndirectedEdge[16, 67] -> 
             RGBColor[
              0.22153288342254734`, 0.3501754848461299, 0.935927342031158], 
             UndirectedEdge[156, 170] -> 
             RGBColor[
              0.7369628216448929, 0.4377252679215747, 0.5659130186213281], 
             UndirectedEdge[96, 128] -> 
             RGBColor[
              0.683861542921137, 0.7500489673999585, 0.97060899306342], 
             UndirectedEdge[62, 114] -> 
             RGBColor[
              0.19065828327948256`, 0.31772432253305627`, 0.9341690792278882],
              UndirectedEdge[101, 105] -> 
             RGBColor[
              0.20097546444375586`, 0.32856833408377506`, 0.9347566274322918],
              UndirectedEdge[30, 89] -> 
             RGBColor[
              0.2385405045564212, 0.3680515730032935, 0.9368959008942113], 
             UndirectedEdge[53, 191] -> 
             RGBColor[
              0.720943391874006, 0.781763716393137, 0.9729313233883682], 
             UndirectedEdge[72, 81] -> 
             RGBColor[
              0.2796155967323937, 0.4112240991915025, 0.9392350666284796], 
             UndirectedEdge[163, 175] -> 
             RGBColor[
              0.39116697450397153`, 0.5094530755186824, 0.9465916451974521], 
             UndirectedEdge[82, 125] -> 
             RGBColor[
              0.23812411131454123`, 0.3676139173052213, 0.9368721879150849], 
             UndirectedEdge[113, 148] -> 
             RGBColor[
              0.19901516852776863`, 0.3265079387861328, 0.9346449914798742], 
             UndirectedEdge[33, 44] -> 
             RGBColor[
              0.9456987231028435, 0.812227711259105, 0.5045786610453252], 
             UndirectedEdge[21, 179] -> 
             RGBColor[
              0.3649219793710912, 0.49049880984441946`, 0.9444734837310578], 
             UndirectedEdge[75, 188] -> 
             RGBColor[
              0.40767232346158455`, 0.5262013149746865, 0.9475637911184522], 
             UndirectedEdge[85, 88] -> 
             RGBColor[
              0.24351738394062986`, 0.3732825887884752, 0.9371793268125088], 
             UndirectedEdge[13, 185] -> 
             RGBColor[
              0.22657810602203676`, 0.3554783336837818, 0.936214659994461], 
             UndirectedEdge[93, 161] -> 
             RGBColor[
              0.2576073800376916, 0.38809206804383756`, 0.9379817312459552], 
             UndirectedEdge[146, 196] -> 
             RGBColor[
              0.23919497538687848`, 0.3687394633419514, 0.9369331720398031], 
             UndirectedEdge[19, 162] -> 
             RGBColor[
              0.4013143224518391, 0.5220200282886156, 0.9467923716516777], 
             UndirectedEdge[140, 172] -> 
             RGBColor[
              0.931531992024998, 0.7442858149051479, 0.38543931844832946`], 
             UndirectedEdge[71, 142] -> 
             RGBColor[
              0.312868249726037, 0.44109030274632716`, 0.9413149223915483], 
             UndirectedEdge[87, 142] -> 
             RGBColor[
              0.23935044537430794`, 0.3689028721561064, 0.9369420258255899], 
             UndirectedEdge[89, 147] -> 
             RGBColor[
              0.25851974752031004`, 0.38905102411550896`, 0.9380336892243635],
              UndirectedEdge[30, 42] -> 
             RGBColor[
              0.2061681954908564, 0.33402622365244206`, 0.935052345783467], 
             UndirectedEdge[8, 125] -> 
             RGBColor[
              0.2737736625674596, 0.4050838559841373, 0.9389023771201537], 
             UndirectedEdge[29, 168] -> 
             RGBColor[
              0.2081540694089858, 0.33611350305207477`, 0.9351654383652672], 
             UndirectedEdge[158, 160] -> 
             RGBColor[
              0.3797675485885813, 0.503357295740605, 0.945419430274175], 
             UndirectedEdge[138, 153] -> 
             RGBColor[
              0.25206516984128635`, 0.38226685373099345`, 0.9376661105742352],
              UndirectedEdge[26, 122] -> 
             RGBColor[
              0.285352985800269, 0.4172544588733168, 0.9395618024481885], 
             UndirectedEdge[53, 195] -> 
             RGBColor[
              0.5664075262483584, 0.658874172033517, 0.9590088217668552], 
             UndirectedEdge[19, 93] -> 
             RGBColor[
              0.291301712500707, 0.4195802455298239, 0.9400443494392029], 
             UndirectedEdge[11, 196] -> 
             RGBColor[
              0.21797120015163274`, 0.34643192990463634`, 0.9357245094379176],
              UndirectedEdge[87, 168] -> 
             RGBColor[
              0.21305020122447582`, 0.34125964802284164`, 0.9354442658289815],
              UndirectedEdge[78, 124] -> 
             RGBColor[
              0.20448428030599214`, 0.3322563220267605, 0.9349564493048182], 
             UndirectedEdge[39, 117] -> 
             RGBColor[
              0.21869250923105948`, 0.34719007148075093`, 0.9357655869229098],
              UndirectedEdge[42, 130] -> 
             RGBColor[
              0.1935327654101925, 0.32074558550512594`, 0.9343327767328169], 
             UndirectedEdge[11, 94] -> 
             RGBColor[
              0.19668351642529655`, 0.32405722459115277`, 0.9345122073420087],
              UndirectedEdge[27, 168] -> 
             RGBColor[
              0.23795894096275363`, 0.36744031279308736`, 0.9368627817078983],
              UndirectedEdge[30, 51] -> 
             RGBColor[
              0.19588138072155636`, 0.3232141291081808, 0.934466526900334], 
             UndirectedEdge[6, 58] -> 
             RGBColor[
              0.8960048531020866, 0.6063661726923737, 0.5646755963969717], 
             UndirectedEdge[6, 156] -> 
             RGBColor[
              0.8250753518515919, 0.1937457191863889, 0.17164549129263085`], 
             UndirectedEdge[19, 173] -> 
             RGBColor[
              0.35948494367207134`, 0.4857895227952885, 0.9441270406240982], 
             UndirectedEdge[57, 200] -> 
             RGBColor[
              0.1862266556746971, 0.31306640093900795`, 0.9339167045918012], 
             UndirectedEdge[37, 50] -> 
             RGBColor[
              0.21979652604601302`, 0.3483504631519761, 0.935828459047275], 
             UndirectedEdge[49, 171] -> 
             RGBColor[
              0.36505233439370555`, 0.4905196472833987, 0.9444851609543292], 
             UndirectedEdge[5, 127] -> 
             RGBColor[
              0.6145607504851762, 0.6921619319485797, 0.9658590156709901], 
             UndirectedEdge[85, 152] -> 
             RGBColor[
              0.2353287944309912, 0.36467586202728325`, 0.9367129987538674], 
             UndirectedEdge[130, 131] -> 
             RGBColor[
              0.18289522364297445`, 0.3095648546486768, 0.9337269844660065], 
             UndirectedEdge[33, 58] -> 
             RGBColor[
              0.9766001096917556, 0.9806681950826337, 0.8617640508368762], 
             UndirectedEdge[82, 98] -> 
             RGBColor[
              0.20223313817939134`, 0.32989022892104847`, 0.9348282500909746],
              UndirectedEdge[74, 173] -> 
             RGBColor[
              0.35684188955631446`, 0.48350024216398235`, 0.9439586275530032],
              UndirectedEdge[118, 146] -> 
             RGBColor[
              0.3181356246114969, 0.44411840298139715`, 0.9417067307257794], 
             UndirectedEdge[23, 115] -> 
             RGBColor[
              0.26933147945021957`, 0.39983427840692803`, 0.9386706585626268],
              UndirectedEdge[49, 65] -> 
             RGBColor[
              0.6893465246568067, 0.7023129196468301, 0.6165085243035178], 
             UndirectedEdge[21, 23] -> 
             RGBColor[
              0.2924706869731754, 0.4198762969529263, 0.9401450684047916], 
             UndirectedEdge[40, 171] -> 
             RGBColor[
              0.40679020531210003`, 0.5252450633334856, 0.9475386222406603], 
             UndirectedEdge[104, 158] -> 
             RGBColor[
              0.3417223041341413, 0.47040441720375525`, 0.9429952209396267], 
             UndirectedEdge[53, 155] -> 
             RGBColor[
              0.6524866330944523, 0.728284776143913, 0.9661081934380052], 
             UndirectedEdge[164, 200] -> 
             RGBColor[
              0.19289342095861073`, 0.320073593949734, 0.9342963670121247], 
             UndirectedEdge[81, 142] -> 
             RGBColor[
              0.28401388302550323`, 0.4158469769530182, 0.9394855425261907], 
             UndirectedEdge[39, 85] -> 
             RGBColor[
              0.26126709675452753`, 0.3919386623526739, 0.9381901466989133], 
             UndirectedEdge[107, 142] -> 
             RGBColor[
              0.23981543626826407`, 0.36939160706777974`, 0.9369685063691083],
              UndirectedEdge[121, 161] -> 
             RGBColor[
              0.25059050057240173`, 0.38071688282996385`, 0.9375821303409498],
              UndirectedEdge[1, 196] -> 
             RGBColor[
              0.20645103349834157`, 0.33432350433127433`, 0.935068452989572], 
             UndirectedEdge[88, 121] -> 
             RGBColor[
              0.21695791281236698`, 0.34536690066494, 0.9356668042229707], 
             UndirectedEdge[85, 133] -> 
             RGBColor[
              0.25979757259338154`, 0.39039409928609614`, 0.9381064594719022],
              UndirectedEdge[118, 127] -> 
             RGBColor[
              0.6328274279834254, 0.7079836098876566, 0.9670229522085898], 
             UndirectedEdge[100, 187] -> 
             RGBColor[
              0.2046359853658942, 0.3324157736633738, 0.9349650886835521], 
             UndirectedEdge[26, 116] -> 
             RGBColor[
              0.2667049754056552, 0.39765421759642916`, 0.9384998258434745], 
             UndirectedEdge[131, 147] -> 
             RGBColor[
              0.21550989668752718`, 0.3438449439082084, 0.9355843418468089], 
             UndirectedEdge[134, 160] -> 
             RGBColor[
              0.3450319511386071, 0.4675505014401682, 0.9434155666515178], 
             UndirectedEdge[3, 5] -> 
             RGBColor[
              0.38651352623245844`, 0.5092003225130362, 0.945849278004409], 
             UndirectedEdge[16, 100] -> 
             RGBColor[
              0.19648326478805916`, 0.32384674742372915`, 0.9345008033075137],
              UndirectedEdge[75, 147] -> 
             RGBColor[
              0.3758334925595824, 0.4931487046810145, 0.9457355307409967], 
             UndirectedEdge[72, 76] -> 
             RGBColor[
              0.25872488056116644`, 0.3892666319476351, 0.9380453712475731], 
             UndirectedEdge[40, 69] -> 
             RGBColor[
              0.37782213400795434`, 0.4947977837110262, 0.9458889334343104], 
             UndirectedEdge[177, 179] -> 
             RGBColor[
              0.2929650964677688, 0.41972688072457853`, 0.940197722295881], 
             UndirectedEdge[98, 100] -> 
             RGBColor[
              0.19914601799870904`, 0.3266454698764268, 0.9346524431636698], 
             UndirectedEdge[136, 187] -> 
             RGBColor[
              0.2131466560055322, 0.3413610281133182, 0.9354497587860706], 
             UndirectedEdge[54, 199] -> 
             RGBColor[
              0.9918267372139176, 0.9824082030898711, 0.5688071701781774], 
             UndirectedEdge[166, 198] -> 
             RGBColor[
              0.5746764165171943, 0.6601910829977264, 0.9621578445394816], 
             UndirectedEdge[48, 104] -> 
             RGBColor[
              0.28879698411440874`, 0.4154790711874804, 0.939955479525905], 
             UndirectedEdge[187, 198] -> 
             RGBColor[
              0.2745522899410462, 0.4024926676355137, 0.9390715600433216], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.20340607327822147`, 0.3311230580782995, 0.9348950470096511], 
             UndirectedEdge[103, 117] -> 
             RGBColor[
              0.1832018217377303, 0.30988710868570724`, 0.9337444447739318], 
             UndirectedEdge[85, 140] -> 
             RGBColor[
              0.632097596410786, 0.6952982597896742, 0.7484529667837756], 
             UndirectedEdge[36, 70] -> 
             RGBColor[
              0.18680103840766088`, 0.3136701136093215, 0.9339494148387204], 
             UndirectedEdge[54, 171] -> 
             RGBColor[
              0.6480714766956179, 0.7066517748176793, 0.6751229004016905], 
             UndirectedEdge[120, 125] -> 
             RGBColor[
              0.22911059591556282`, 0.35814014113101095`, 0.9363588815474142],
              UndirectedEdge[81, 104] -> 
             RGBColor[
              0.336565061683316, 0.46568634938344766`, 0.9426758008769163], 
             UndirectedEdge[93, 162] -> 
             RGBColor[
              0.34139937953517563`, 0.46297232673312194`, 0.9432365284830118],
              UndirectedEdge[73, 168] -> 
             RGBColor[
              0.2134383142319024, 0.3416675794014329, 0.9354663682905927], 
             UndirectedEdge[119, 199] -> 
             RGBColor[
              0.921043290148025, 0.6766189653862216, 0.46033982093126385`], 
             UndirectedEdge[17, 107] -> 
             RGBColor[
              0.20455110797063392`, 0.33232656213941764`, 0.9349602550414569],
              UndirectedEdge[14, 48] -> 
             RGBColor[
              0.19487547737670605`, 0.3221568609147874, 0.9344092421929455], 
             UndirectedEdge[64, 182] -> 
             RGBColor[
              0.48518193863662246`, 0.5898773465279377, 0.9534583400112507], 
             UndirectedEdge[71, 129] -> 
             RGBColor[
              0.40910477455238126`, 0.5287364214993203, 0.947297421991063], 
             UndirectedEdge[80, 100] -> 
             RGBColor[
              0.2137920345531072, 0.3420393618861828, 0.935486512139603], 
             UndirectedEdge[18, 178] -> 
             RGBColor[
              0.20335755177255102`, 0.3310720588993987, 0.9348922837816843], 
             UndirectedEdge[174, 186] -> 
             RGBColor[
              0.18655058120662976`, 0.3134068672111341, 0.9339351516716399], 
             UndirectedEdge[115, 165] -> 
             RGBColor[
              0.2604142264170086, 0.39046168008252585`, 0.9381628341942789], 
             UndirectedEdge[113, 198] -> 
             RGBColor[
              0.2750384221935423, 0.4030036234554522, 0.939099244555933], 
             UndirectedEdge[67, 100] -> 
             RGBColor[
              0.2308404904839133, 0.3599583700039979, 0.936457396483932], 
             UndirectedEdge[106, 147] -> 
             RGBColor[
              0.21727737751825504`, 0.3457026783260606, 0.9356849972653654], 
             UndirectedEdge[75, 129] -> 
             RGBColor[
              0.47830661680484077`, 0.5873498848465282, 0.9520731954511965], 
             UndirectedEdge[175, 183] -> 
             RGBColor[
              0.7184776908452273, 0.695458275607814, 0.6107486570608233], 
             UndirectedEdge[105, 144] -> 
             RGBColor[
              0.20212260779592514`, 0.3297740544799944, 0.9348219555491514], 
             UndirectedEdge[44, 128] -> 
             RGBColor[
              0.6650402658915442, 0.5906178095064059, 0.5929751287851128], 
             UndirectedEdge[70, 138] -> 
             RGBColor[
              0.2064620848582796, 0.334335120011266, 0.9350690823481714], 
             UndirectedEdge[110, 145] -> 
             RGBColor[
              0.18515978669395372`, 0.31194505399684636`, 0.9338559479816391],
              UndirectedEdge[49, 118] -> 
             RGBColor[
              0.4066109576924045, 0.5266077075173656, 0.9471298685655758], 
             UndirectedEdge[70, 185] -> 
             RGBColor[
              0.21155038817505178`, 0.3396832494142572, 0.9353588536945914], 
             UndirectedEdge[11, 138] -> 
             RGBColor[
              0.2124149402657507, 0.3405919484773504, 0.9354080886571665], 
             UndirectedEdge[120, 187] -> 
             RGBColor[
              0.1987095901475981, 0.32618675653378515`, 0.9346275892431862], 
             UndirectedEdge[71, 127] -> 
             RGBColor[
              0.6192630181344778, 0.6962347998435606, 0.9661586400075515], 
             UndirectedEdge[4, 182] -> 
             RGBColor[
              0.33757022299890055`, 0.4668080932140755, 0.9427306540012304], 
             UndirectedEdge[29, 71] -> 
             RGBColor[
              0.2853246797443417, 0.4121402643323634, 0.939746356828151], 
             UndirectedEdge[63, 185] -> 
             RGBColor[
              0.2118614125837917, 0.3400101557879294, 0.9353765660745497], 
             UndirectedEdge[83, 175] -> 
             RGBColor[
              0.7134786289406714, 0.7747821951592325, 0.9733333335119576], 
             UndirectedEdge[79, 126] -> 
             RGBColor[
              0.1869217092836395, 0.3137969463509505, 0.9339562868665908], 
             UndirectedEdge[107, 154] -> 
             RGBColor[
              0.27475191641420155`, 0.4039740129877124, 0.9390363717067235], 
             UndirectedEdge[34, 64] -> 
             RGBColor[
              0.5297940733748047, 0.6285181353670621, 0.956300985787806], 
             UndirectedEdge[159, 180] -> 
             RGBColor[
              0.29846249583214285`, 0.427955785985238, 0.9404210556305891], 
             UndirectedEdge[3, 123] -> 
             RGBColor[
              0.4349086817945046, 0.5511177738496366, 0.9489329745226667], 
             UndirectedEdge[50, 97] -> 
             RGBColor[
              0.21027301783359342`, 0.33834065219542714`, 0.9352861093433454],
              UndirectedEdge[87, 89] -> 
             RGBColor[
              0.24210890877301894`, 0.37180219208483256`, 0.9370991162353657],
              UndirectedEdge[123, 191] -> 
             RGBColor[
              0.6306139888746021, 0.7083706761376785, 0.9658367189463131], 
             UndirectedEdge[108, 151] -> 
             RGBColor[
              0.6509649455844404, 0.716416401604573, 0.8457783120147642], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.19532837830452823`, 0.32263288850550587`, 0.9344350342307781],
              UndirectedEdge[19, 33] -> 
             RGBColor[
              0.6719200989970671, 0.734922803310785, 0.8577553559890845], 
             UndirectedEdge[156, 199] -> 
             RGBColor[
              0.9069891921772075, 0.5685930098375191, 0.4468816008425758], 
             UndirectedEdge[47, 144] -> 
             RGBColor[
              0.19737482195309003`, 0.32478383053216575`, 0.9345515761691217],
              UndirectedEdge[123, 127] -> 
             RGBColor[
              0.6629559060472224, 0.73407938328518, 0.9689427121892478], 
             UndirectedEdge[82, 120] -> 
             RGBColor[
              0.2029515968118113, 0.3306453744966301, 0.9348691652472267], 
             UndirectedEdge[120, 137] -> 
             RGBColor[
              0.2589152311792967, 0.38806631610919806`, 0.9381074864400005], 
             UndirectedEdge[122, 179] -> 
             RGBColor[
              0.32323201256899053`, 0.45153932858028145`, 0.9419213783919558],
              UndirectedEdge[52, 124] -> 
             RGBColor[
              0.20581307491926143`, 0.333652969415751, 0.9350321221922685], 
             UndirectedEdge[17, 106] -> 
             RGBColor[
              0.18824964863953902`, 0.315192694810219, 0.934031911048399], 
             UndirectedEdge[125, 166] -> 
             RGBColor[
              0.5340062312264762, 0.620853714704589, 0.9597168964072044], 
             UndirectedEdge[7, 79] -> 
             RGBColor[
              0.20133607999592745`, 0.328947363893454, 0.934777163954505], 
             UndirectedEdge[49, 127] -> 
             RGBColor[
              0.6485709500663741, 0.7216198574234791, 0.9680261155142653], 
             UndirectedEdge[121, 200] -> 
             RGBColor[
              0.20398334673618768`, 0.33172980908387323`, 0.9349279218790827],
              UndirectedEdge[56, 193] -> 
             RGBColor[
              0.2060154437903921, 0.33386567193023686`, 0.9350436468001014], 
             UndirectedEdge[149, 194] -> 
             RGBColor[
              0.1935128959182038, 0.3207247014092473, 0.9343316451946424], 
             UndirectedEdge[108, 133] -> 
             RGBColor[
              0.27857495084464845`, 0.41013031438272207`, 0.9391758033846701],
              UndirectedEdge[41, 140] -> 
             RGBColor[
              0.6422147641826323, 0.7059320445833706, 0.7490291245213738], 
             UndirectedEdge[36, 185] -> 
             RGBColor[
              0.2073008742546082, 0.33521674084912667`, 0.9351168501634146], 
             UndirectedEdge[108, 111] -> 
             RGBColor[
              0.26408143509617243`, 0.39489671038909974`, 0.9383504191040295],
              UndirectedEdge[72, 154] -> 
             RGBColor[
              0.2925360773933412, 0.42266629375772025`, 0.940049153365177], 
             UndirectedEdge[63, 110] -> 
             RGBColor[
              0.18589948479502594`, 0.3127225236006417, 0.9338980726942099], 
             UndirectedEdge[15, 186] -> 
             RGBColor[
              0.18099749200595946`, 0.30757021837503873`, 0.933618911456721], 
             UndirectedEdge[54, 155] -> 
             RGBColor[
              0.8307914164161123, 0.8585643375610341, 0.688734731768329], 
             UndirectedEdge[18, 108] -> 
             RGBColor[
              0.2655472156605108, 0.39643733869807485`, 0.9384338931387406], 
             UndirectedEdge[44, 102] -> 
             RGBColor[
              0.9339747756675465, 0.8048847960141194, 0.5871542851309398], 
             UndirectedEdge[8, 122] -> 
             RGBColor[
              0.2805939833782982, 0.4122524455896443, 0.9392907843005704], 
             UndirectedEdge[42, 197] -> 
             RGBColor[
              0.20173805393446126`, 0.32936986398947277`, 0.9348000557756375],
              UndirectedEdge[48, 147] -> 
             RGBColor[
              0.2300092060376818, 0.3590846373445305, 0.9364100560644943], 
             UndirectedEdge[34, 54] -> 
             RGBColor[
              0.7092249646791587, 0.7597119219751208, 0.6790161754635967], 
             UndirectedEdge[5, 75] -> 
             RGBColor[
              0.42823819051471873`, 0.5440144353455778, 0.9488742299813958], 
             UndirectedEdge[55, 115] -> 
             RGBColor[
              0.3254517520127096, 0.4563116827378988, 0.9419584757459334], 
             UndirectedEdge[49, 155] -> 
             RGBColor[
              0.5477722741141999, 0.6424322100267535, 0.9580969923209677], 
             UndirectedEdge[66, 136] -> 
             RGBColor[
              0.2031791949691239, 0.33088459459052233`, 0.9348821266255843], 
             UndirectedEdge[136, 148] -> 
             RGBColor[
              0.2081945933984414, 0.33615609633436194`, 0.9351677461465169], 
             UndirectedEdge[130, 189] -> 
             RGBColor[
              0.18936342684036145`, 0.3163633463169, 0.9340953390692487], 
             UndirectedEdge[48, 76] -> 
             RGBColor[
              0.23737108877035865`, 0.36682244286689847`, 0.9368293043951907],
              UndirectedEdge[29, 141] -> 
             RGBColor[
              0.2753633186073925, 0.40351223398810643`, 0.9391116277049905], 
             UndirectedEdge[133, 163] -> 
             RGBColor[
              0.26544293338464375`, 0.39632773141426036`, 0.9384279544174017],
              UndirectedEdge[111, 169] -> 
             RGBColor[
              0.20611458183414505`, 0.33396987229993624`, 0.9350492925650316],
              UndirectedEdge[76, 142] -> 
             RGBColor[
              0.26312316685427595`, 0.39388950970915076`, 0.9382958471452842],
              UndirectedEdge[78, 98] -> 
             RGBColor[
              0.18771622042890102`, 0.3146320279395365, 0.9340015331009395], 
             UndirectedEdge[21, 170] -> 
             RGBColor[
              0.5082558273140996, 0.6089687689524979, 0.9552557972010979], 
             UndirectedEdge[92, 139] -> 
             RGBColor[
              0.26505756074119424`, 0.3959226803319581, 0.938406008015465], 
             UndirectedEdge[63, 70] -> 
             RGBColor[
              0.1913615767368444, 0.3184635285481242, 0.9342091307498555], 
             UndirectedEdge[71, 197] -> 
             RGBColor[
              0.2822222657868389, 0.40887943055862197`, 0.9395696789428815], 
             UndirectedEdge[127, 141] -> 
             RGBColor[
              0.6093016569975287, 0.6876067694993037, 0.9655239108843909], 
             UndirectedEdge[64, 138] -> 
             RGBColor[
              0.4257022995794623, 0.5303271273768558, 0.949962438870419], 
             UndirectedEdge[39, 108] -> 
             RGBColor[
              0.2800444750057945, 0.41167487744929976`, 0.9392594906116811], 
             UndirectedEdge[24, 165] -> 
             RGBColor[
              0.23147521014501135`, 0.3606255006113628, 0.9364935428296479], 
             UndirectedEdge[132, 182] -> 
             RGBColor[
              0.3206991952751244, 0.45143891338558356`, 0.9416833404765177], 
             UndirectedEdge[77, 181] -> 
             RGBColor[
              0.627745965168717, 0.3440360509358098, 0.5566794847766803], 
             UndirectedEdge[20, 47] -> 
             RGBColor[
              0.189292245231432, 0.3162885299327404, 0.9340912853819239], 
             UndirectedEdge[191, 199] -> 
             RGBColor[
              0.9026821480304056, 0.9219432707783801, 0.8549565211308954], 
             UndirectedEdge[89, 154] -> 
             RGBColor[
              0.29969282708516165`, 0.4301884914479621, 0.9404567196726639], 
             UndirectedEdge[93, 164] -> 
             RGBColor[
              0.2132799643411767, 0.3415011436263172, 0.9354573504985735], 
             UndirectedEdge[26, 187] -> 
             RGBColor[
              0.24813165922146568`, 0.378132484670584, 0.9374421029635438], 
             UndirectedEdge[5, 188] -> 
             RGBColor[
              0.33376821355982345`, 0.4635149837324976, 0.9424883933217574], 
             UndirectedEdge[7, 16] -> 
             RGBColor[
              0.19783499493782034`, 0.3252675015157697, 0.9345777823398371], 
             UndirectedEdge[154, 160] -> 
             RGBColor[
              0.38753078679870345`, 0.510081422486515, 0.9459140969481619], 
             UndirectedEdge[88, 152] -> 
             RGBColor[
              0.20837422546163153`, 0.3363449010221054, 0.9351779759267738], 
             UndirectedEdge[9, 18] -> 
             RGBColor[
              0.2081906159438856, 0.3361519157774386, 0.935167519636364], 
             UndirectedEdge[9, 200] -> 
             RGBColor[
              0.19196359639909227`, 0.31909628938339796`, 0.9342434148790122],
              UndirectedEdge[55, 183] -> 
             RGBColor[
              0.6361311703010923, 0.6254168955585735, 0.6051471025896153], 
             UndirectedEdge[72, 104] -> 
             RGBColor[
              0.31015077590521656`, 0.43792326026821704`, 0.9411715463782875],
              UndirectedEdge[112, 181] -> 
             RGBColor[
              0.6897919274498447, 0.754885022928866, 0.9666005855889899], 
             UndirectedEdge[136, 193] -> 
             RGBColor[
              0.22613676588736786`, 0.35501445721966407`, 0.9361895263266957],
              UndirectedEdge[80, 198] -> 
             RGBColor[
              0.28370833912825916`, 0.4121162558583227, 0.9395929834993725], 
             UndirectedEdge[42, 131] -> 
             RGBColor[
              0.19213265043958744`, 0.3192739758986036, 0.9342530422565254], 
             UndirectedEdge[65, 156] -> 
             RGBColor[
              0.887528121922009, 0.5046298539287588, 0.2252206944152773], 
             UndirectedEdge[26, 192] -> 
             RGBColor[
              0.37924820246199464`, 0.5010949181579147, 0.9455333797204014], 
             UndirectedEdge[65, 155] -> 
             RGBColor[
              0.8147643189956533, 0.8045011746203956, 0.6264724847532339], 
             UndirectedEdge[59, 62] -> 
             RGBColor[
              0.19206220882201708`, 0.3191999372922807, 0.9342490307106137], 
             UndirectedEdge[82, 187] -> 
             RGBColor[
              0.2077231055465765, 0.3356605327079955, 0.9351408956108569], 
             UndirectedEdge[4, 86] -> 
             RGBColor[
              0.26820213237561147`, 0.3968644845029512, 0.9386716201723606], 
             UndirectedEdge[73, 167] -> 
             RGBColor[
              0.20840651893599757`, 0.33637884351118863`, 0.9351798149923649],
              UndirectedEdge[74, 159] -> 
             RGBColor[
              0.30041133141594933`, 0.42964376941660665`, 0.9405452337107016],
              UndirectedEdge[25, 60] -> 
             RGBColor[
              0.18025977124348086`, 0.3067948270794758, 0.9335768993506579], 
             UndirectedEdge[159, 162] -> 
             RGBColor[
              0.3531520525661749, 0.4753251312512108, 0.9439058258256054], 
             UndirectedEdge[10, 147] -> 
             RGBColor[
              0.23373755563263043`, 0.3630033691598391, 0.9366223800583277], 
             UndirectedEdge[23, 163] -> 
             RGBColor[
              0.2527001813973467, 0.382934291138471, 0.9377022735429374], 
             UndirectedEdge[40, 54] -> 
             RGBColor[
              0.7471114929956602, 0.7911014986375555, 0.6818242326049438], 
             UndirectedEdge[123, 129] -> 
             RGBColor[
              0.45279766246512576`, 0.5665810049409397, 0.9500814941727593], 
             UndirectedEdge[25, 165] -> 
             RGBColor[
              0.19267100347283378`, 0.3198398190700993, 0.9342837006653468], 
             UndirectedEdge[39, 178] -> 
             RGBColor[
              0.21785481111783467`, 0.34630959765062364`, 0.935717881254625], 
             UndirectedEdge[76, 107] -> 
             RGBColor[
              0.2409407195820268, 0.37057435117762727`, 0.9370325895891196], 
             UndirectedEdge[63, 138] -> 
             RGBColor[
              0.20677310926701956`, 0.33466202638493814`, 0.9350867947281298],
              UndirectedEdge[71, 81] -> 
             RGBColor[
              0.334884249211027, 0.4642305141000421, 0.942568700992466], 
             UndirectedEdge[8, 83] -> 
             RGBColor[
              0.60482509904127, 0.6795990406798771, 0.9661417830923238], 
             UndirectedEdge[10, 149] -> 
             RGBColor[
              0.2017271344819297, 0.32935838695252884`, 0.9347994339289696], 
             UndirectedEdge[119, 172] -> 
             RGBColor[
              0.858083307192903, 0.43025919736952545`, 0.20258043262042846`], 
             UndirectedEdge[106, 130] -> 
             RGBColor[
              0.1846627044737023, 0.31142258906652903`, 0.933827639884563], 
             UndirectedEdge[147, 176] -> 
             RGBColor[
              0.24180624149358806`, 0.37148406958393687`, 0.9370818797815581],
              UndirectedEdge[27, 197] -> 
             RGBColor[
              0.23361320117338766`, 0.3628726647386469, 0.9366152982558398], 
             UndirectedEdge[72, 176] -> 
             RGBColor[
              0.2436445546193927, 0.37341625323494165`, 0.9371865689945322], 
             UndirectedEdge[92, 118] -> 
             RGBColor[
              0.31765722646768046`, 0.4436155762000519, 0.9416794866592155], 
             UndirectedEdge[123, 171] -> 
             RGBColor[
              0.3794372903745538, 0.5029791731450995, 0.9454017576293117], 
             UndirectedEdge[66, 113] -> 
             RGBColor[
              0.1939997700984511, 0.32123643704229315`, 0.9343593719589416], 
             UndirectedEdge[67, 179] -> 
             RGBColor[
              0.3122151911082063, 0.43995995071817273`, 0.941293986707691], 
             UndirectedEdge[130, 197] -> 
             RGBColor[
              0.19250062713784824`, 0.3196607427395459, 0.9342739979851187], 
             UndirectedEdge[15, 194] -> 
             RGBColor[
              0.19022447471756204`, 0.31726836222942645`, 0.934144374472049], 
             UndirectedEdge[47, 135] -> 
             RGBColor[
              0.19659862417943424`, 0.3239679974582722, 0.9345073728541936], 
             UndirectedEdge[8, 170] -> 
             RGBColor[
              0.4692360918503271, 0.5728158701273882, 0.9528557575864605], 
             UndirectedEdge[17, 149] -> 
             RGBColor[
              0.1884865346732682, 0.31544167705111037`, 0.9340454013575784], 
             UndirectedEdge[13, 97] -> 
             RGBColor[
              0.21895267363831583`, 0.3474635207681535, 0.9357804029010244], 
             UndirectedEdge[11, 86] -> 
             RGBColor[
              0.20252648869962175`, 0.33019855891730787`, 0.9348449559691285],
              UndirectedEdge[15, 62] -> 
             RGBColor[
              0.18941420148966015`, 0.3164167136926116, 0.9340982306104119], 
             UndirectedEdge[37, 160] -> 
             RGBColor[
              0.33951855272220766`, 0.4617555701348826, 0.9431015867680459], 
             UndirectedEdge[46, 50] -> 
             RGBColor[
              0.1933628575006826, 0.3205670015194474, 0.9343231007287265], 
             UndirectedEdge[49, 53] -> 
             RGBColor[
              0.5270688387556056, 0.6260965211703475, 0.956144232988289], 
             UndirectedEdge[52, 120] -> 
             RGBColor[
              0.1897634736745903, 0.3167838209041087, 0.9341181211446418], 
             UndirectedEdge[81, 147] -> 
             RGBColor[
              0.2777772836065891, 0.4092919155404977, 0.9391303774155055], 
             UndirectedEdge[49, 123] -> 
             RGBColor[
              0.43673943575620155`, 0.552703480914889, 0.949049628546234], 
             UndirectedEdge[127, 140] -> 
             RGBColor[
              0.9342553301344888, 0.9459893647897327, 0.7730553915426139], 
             UndirectedEdge[31, 132] -> 
             RGBColor[
              0.4162636354385904, 0.5320766653506034, 0.9483626292299419], 
             UndirectedEdge[146, 186] -> 
             RGBColor[
              0.2142358988127285, 0.34250589136566434`, 0.9355117895525502], 
             UndirectedEdge[98, 124] -> 
             RGBColor[
              0.20926922402508408`, 0.3372856012584804, 0.9352289447709307], 
             UndirectedEdge[4, 53] -> 
             RGBColor[
              0.483045374115442, 0.5879656087827072, 0.953339096749839], 
             UndirectedEdge[82, 137] -> 
             RGBColor[
              0.26792874657827515`, 0.39754009228340836`, 0.9386207928076713],
              UndirectedEdge[42, 107] -> 
             RGBColor[
              0.21020159060141025`, 0.3382655776456545, 0.9352820416681398], 
             UndirectedEdge[99, 102] -> 
             RGBColor[
              0.7604981725449849, 0.8117818781391992, 0.9474611303534258], 
             UndirectedEdge[57, 88] -> 
             RGBColor[
              0.1992012217508764, 0.32670349252007475`, 0.9346555869356892], 
             UndirectedEdge[40, 49] -> 
             RGBColor[
              0.46409235069374777`, 0.5749693711032751, 0.9511864931575826], 
             UndirectedEdge[21, 90] -> 
             RGBColor[
              0.29428715223398993`, 0.42178551711259177`, 0.9402485134141754],
              UndirectedEdge[143, 158] -> 
             RGBColor[
              0.5860035167018279, 0.6680847618686957, 0.9637366121327604], 
             UndirectedEdge[24, 111] -> 
             RGBColor[
              0.2386416994170433, 0.36815793521793205`, 0.9369016637918195], 
             UndirectedEdge[139, 155] -> 
             RGBColor[
              0.47942908630476494`, 0.5811030666228374, 0.9538203503715414], 
             UndirectedEdge[94, 174] -> 
             RGBColor[
              0.19022197405444352`, 0.31726573387393764`, 0.9341442320629838],
              UndirectedEdge[4, 118] -> 
             RGBColor[
              0.3625874930522409, 0.48847679512972536`, 0.9443247323271259], 
             UndirectedEdge[121, 159] -> 
             RGBColor[
              0.23612256314975283`, 0.36551016327854535`, 0.9367582027081254],
              UndirectedEdge[5, 76] -> 
             RGBColor[
              0.3092912653904981, 0.4382001789611937, 0.9410793812749982], 
             UndirectedEdge[27, 194] -> 
             RGBColor[
              0.23402121805989123`, 0.3633015163561269, 0.9366385342139192], 
             UndirectedEdge[77, 160] -> 
             RGBColor[
              0.6302548648825095, 0.34620913376693074`, 0.5568393496479103], 
             UndirectedEdge[2, 80] -> 
             RGBColor[
              0.20208335684743473`, 0.32973279924447707`, 0.9348197202657014],
              UndirectedEdge[74, 85] -> 
             RGBColor[
              0.3082012500479231, 0.4378314678081793, 0.9409888580526407], 
             UndirectedEdge[35, 110] -> 
             RGBColor[
              0.18045196756199675`, 0.30699683759618646`, 0.9335878446466683],
              UndirectedEdge[143, 154] -> 
             RGBColor[
              0.5937667549119501, 0.6748088886146058, 0.9642312788067474], 
             UndirectedEdge[53, 129] -> 
             RGBColor[
              0.5431270654645298, 0.6399740451963982, 0.9571760986148143], 
             UndirectedEdge[80, 187] -> 
             RGBColor[
              0.21263714806957626`, 0.34082550296795955`, 0.9354207430628674],
              UndirectedEdge[30, 87] -> 
             RGBColor[
              0.213134602991505, 0.3413483596313704, 0.9354490723847526], 
             UndirectedEdge[29, 197] -> 
             RGBColor[
              0.2038083296196198, 0.3315458549976343, 0.9349179549132087], 
             UndirectedEdge[74, 121] -> 
             RGBColor[
              0.28164177891966025`, 0.4099157796846441, 0.9394763354631025], 
             UndirectedEdge[127, 199] -> 
             RGBColor[
              0.935024065203026, 0.9476519779258816, 0.8580625143738301], 
             UndirectedEdge[52, 80] -> 
             RGBColor[
              0.20369103159656846`, 0.33142256733828307`, 0.9349112749643229],
              UndirectedEdge[125, 187] -> 
             RGBColor[
              0.233882104650328, 0.36315529934237634`, 0.9366306119110444], 
             UndirectedEdge[57, 152] -> 
             RGBColor[
              0.19101263224123774`, 0.3180967657588828, 0.9341892588770478], 
             UndirectedEdge[128, 193] -> 
             RGBColor[
              0.3303839734000996, 0.45325331449434825`, 0.942541154768971], 
             UndirectedEdge[151, 172] -> 
             RGBColor[
              0.9316219629473853, 0.7456677416234209, 0.4816953197665501], 
             UndirectedEdge[5, 27] -> 
             RGBColor[
              0.31042728364880795`, 0.439394206178395, 0.9411440758342206], 
             UndirectedEdge[65, 118] -> 
             RGBColor[
              0.6736030025738579, 0.6886766721110076, 0.6155053609978421], 
             UndirectedEdge[78, 80] -> 
             RGBColor[
              0.20236223698329917`, 0.33002591994929253`, 0.9348356020768727],
              UndirectedEdge[40, 199] -> 
             RGBColor[
              0.7505454658303996, 0.8010014916056775, 0.8412228920171474], 
             UndirectedEdge[5, 42] -> 
             RGBColor[
              0.2785521364098815, 0.40589140542922086`, 0.9393288333540183], 
             UndirectedEdge[123, 196] -> 
             RGBColor[
              0.3420552644486344, 0.4636882937396207, 0.9432729065545822], 
             UndirectedEdge[80, 124] -> 
             RGBColor[
              0.22391524057948223`, 0.35267949326823644`, 0.9360630137468638],
              UndirectedEdge[22, 48] -> 
             RGBColor[
              0.19949157754304903`, 0.3270086748672687, 0.9346721222685106], 
             UndirectedEdge[69, 86] -> 
             RGBColor[
              0.22595538032998164`, 0.3548238094983426, 0.9361791966875385], 
             UndirectedEdge[81, 143] -> 
             RGBColor[
              0.5808462742510027, 0.663366694048388, 0.9634171920700499], 
             UndirectedEdge[80, 116] -> 
             RGBColor[
              0.23121046425376574`, 0.3603472358938047, 0.936478465942798], 
             UndirectedEdge[90, 169] -> 
             RGBColor[
              0.20968181085613852`, 0.3377192561774346, 0.9352524409805917], 
             UndirectedEdge[121, 173] -> 
             RGBColor[
              0.292553121290118, 0.41936663602592106`, 0.9401715965504269], 
             UndirectedEdge[8, 179] -> 
             RGBColor[
              0.32590224390731876`, 0.4543459110193097, 0.9420734441164204], 
             UndirectedEdge[29, 167] -> 
             RGBColor[
              0.20312227411308098`, 0.33082476716183046`, 0.9348788850670395],
              UndirectedEdge[76, 87] -> 
             RGBColor[
              0.2404757286880707, 0.37008561626595393`, 0.9370061090456012], 
             UndirectedEdge[111, 163] -> 
             RGBColor[
              0.25094941763616774`, 0.3810941274206381, 0.9376025701367612], 
             UndirectedEdge[130, 149] -> 
             RGBColor[
              0.1848995905074315, 0.3116715713074204, 0.9338411301937424], 
             UndirectedEdge[7, 122] -> 
             RGBColor[
              0.24320904209445873`, 0.37295850195814717`, 0.9371617672005202],
              UndirectedEdge[89, 142] -> 
             RGBColor[
              0.2647563469392241, 0.39560608552802945`, 0.9383888543350487], 
             UndirectedEdge[44, 172] -> 
             RGBColor[
              0.8840573238836684, 0.5664132115032791, 0.22496692784453026`], 
             UndirectedEdge[7, 179] -> 
             RGBColor[
              0.2885173026234793, 0.4150519673878126, 0.9399444270163702], 
             UndirectedEdge[73, 188] -> 
             RGBColor[
              0.26534078986482257`, 0.3958083524158491, 0.9384372235539715], 
             UndirectedEdge[16, 120] -> 
             RGBColor[
              0.19055686956976303`, 0.31761773029414053`, 0.9341633038671477],
              UndirectedEdge[98, 116] -> 
             RGBColor[
              0.21656444769936758`, 0.34495334388404864`, 0.9356443969668649],
              UndirectedEdge[5, 81] -> 
             RGBColor[
              0.3301819815617254, 0.46015764620506105`, 0.9422690766559045], 
             UndirectedEdge[76, 106] -> 
             RGBColor[
              0.2246392602509319, 0.35344048384842863`, 0.9361042455960618], 
             UndirectedEdge[135, 144] -> 
             RGBColor[
              0.19771245739729065`, 0.32513870679134427`, 0.9345708040081819],
              UndirectedEdge[194, 197] -> 
             RGBColor[
              0.20111393254862053`, 0.3287138728413728, 0.9347645129860187], 
             UndirectedEdge[27, 29] -> 
             RGBColor[
              0.2367156151308905, 0.36613349851238836`, 0.9367919761411093], 
             UndirectedEdge[44, 58] -> 
             RGBColor[
              0.9296752902178356, 0.8016782468054864, 0.5944321925119014], 
             UndirectedEdge[53, 92] -> 
             RGBColor[
              0.4381151075308816, 0.5431043898530338, 0.9506938510819287], 
             UndirectedEdge[83, 122] -> 
             RGBColor[
              0.6021548677029418, 0.6767924582408489, 0.9659897173678593], 
             UndirectedEdge[9, 178] -> 
             RGBColor[
              0.18848044580793838`, 0.31543527726759235`, 0.9340450546057055],
              UndirectedEdge[12, 99] -> 
             RGBColor[
              0.7509614073428162, 0.7434552401786318, 0.618284844686889], 
             UndirectedEdge[7, 126] -> 
             RGBColor[
              0.19407996143665954`, 0.32132072322317473`, 0.9343639387370202],
              UndirectedEdge[139, 146] -> 
             RGBColor[
              0.2655359588850107, 0.39642550711330343`, 0.9384332520820287], 
             UndirectedEdge[100, 198] -> 
             RGBColor[
              0.2757071764245771, 0.40370652655373696`, 0.9391373291200573], 
             UndirectedEdge[56, 109] -> 
             RGBColor[
              0.19998929422011852`, 0.3275318066519287, 0.9347004664969638], 
             UndirectedEdge[9, 159] -> 
             RGBColor[
              0.22410281281265743`, 0.3528766435780701, 0.9360736957080549], 
             UndirectedEdge[2, 98] -> 
             RGBColor[
              0.18743734029303655`, 0.314338907234721, 0.9339856512897682], 
             UndirectedEdge[95, 164] -> 
             RGBColor[
              0.22218549989478478`, 0.35086142613672566`, 0.9359645075737923],
              UndirectedEdge[108, 163] -> 
             RGBColor[
              0.29489469195251866`, 0.4272833970184431, 0.94010518849787], 
             UndirectedEdge[85, 121] -> 
             RGBColor[
              0.24391248178172664`, 0.37369786167011787`, 0.9372018270500644],
              UndirectedEdge[55, 177] -> 
             RGBColor[
              0.2766340766323431, 0.4055817721640561, 0.9391571241529215], 
             UndirectedEdge[118, 141] -> 
             RGBColor[
              0.36734166462355905`, 0.4925946195931902, 0.9446276639357014], 
             UndirectedEdge[58, 77] -> 
             RGBColor[
              0.8889478384033738, 0.5521228653145076, 0.5579177911517261], 
             UndirectedEdge[142, 154] -> 
             RGBColor[
              0.29693436368645065`, 0.4272891715192359, 0.9402996292628881], 
             UndirectedEdge[103, 178] -> 
             RGBColor[
              0.1823641236245055, 0.3090066348555799, 0.933696739105647], 
             UndirectedEdge[48, 154] -> 
             RGBColor[
              0.2711822856025334, 0.4002221046769836, 0.9388330865127945], 
             UndirectedEdge[72, 181] -> 
             RGBColor[
              0.345687120645864, 0.46870305597394574`, 0.9434358908416056], 
             UndirectedEdge[45, 132] -> 
             RGBColor[
              0.5058042387487333, 0.6037176098642293, 0.9561309549136163], 
             UndirectedEdge[103, 200] -> 
             RGBColor[
              0.18584727421565939`, 0.3126676469713855, 0.9338950993789537], 
             UndirectedEdge[21, 61] -> 
             RGBColor[
              0.2843221054652073, 0.4113116211381439, 0.9396810187426589], 
             UndirectedEdge[51, 73] -> 
             RGBColor[
              0.19983789794558066`, 0.3273726795683112, 0.9346918447030995], 
             UndirectedEdge[18, 41] -> 
             RGBColor[
              0.25688700518109014`, 0.38733490839514545`, 0.9379407069635708],
              UndirectedEdge[27, 42] -> 
             RGBColor[
              0.2346453394457319, 0.36395750750422684`, 0.936674077003538], 
             UndirectedEdge[90, 165] -> 
             RGBColor[
              0.21653690052978303`, 0.3449243900622238, 0.9356428281963094], 
             UndirectedEdge[50, 135] -> 
             RGBColor[
              0.20034146801813224`, 0.3279019636427496, 0.9347205222737662], 
             UndirectedEdge[93, 121] -> 
             RGBColor[
              0.22436989011875363`, 0.3531573587604565, 0.9360889053655316], 
             UndirectedEdge[23, 175] -> 
             RGBColor[
              0.36210448140880436`, 0.4789065526071719, 0.9449365792097879], 
             UndirectedEdge[57, 164] -> 
             RGBColor[
              0.1885063938143962, 0.3154625502675782, 0.9340465323062868], 
             UndirectedEdge[54, 172] -> 
             RGBColor[
              0.9288667542587956, 0.7360484350731749, 0.311047781867342], 
             UndirectedEdge[99, 198] -> 
             RGBColor[
              0.44872208919176476`, 0.5604076738789969, 0.9505521468225746], 
             UndirectedEdge[45, 112] -> 
             RGBColor[
              0.8262269535061243, 0.8650081965468237, 0.9779469895534628], 
             UndirectedEdge[88, 173] -> 
             RGBColor[
              0.2921580234490212, 0.41895136314427833`, 0.9401490963128714], 
             UndirectedEdge[14, 22] -> 
             RGBColor[
              0.18387332754707644`, 0.31059290386725735`, 0.9337826860363703],
              UndirectedEdge[7, 67] -> 
             RGBColor[
              0.23219222063367448`, 0.36137912409603845`, 0.9365343755162554],
              UndirectedEdge[105, 135] -> 
             RGBColor[
              0.20134641002226938`, 0.32895822140610087`, 0.9347777522342233],
              UndirectedEdge[104, 176] -> 
             RGBColor[
              0.300594019570315, 0.4278785034268868, 0.9406273032429688], 
             UndirectedEdge[57, 91] -> 
             RGBColor[
              0.18403700151578473`, 0.31076493558589874`, 0.9337920070267542],
              UndirectedEdge[34, 185] -> 
             RGBColor[
              0.3310536945005693, 0.45407275524127744`, 0.9425750645902526], 
             UndirectedEdge[65, 172] -> 
             RGBColor[
              0.9128396568383367, 0.6819852721325363, 0.24878553485224705`], 
             UndirectedEdge[66, 120] -> 
             RGBColor[
              0.18874212911118976`, 0.3157103230109893, 0.9340599570827], 
             UndirectedEdge[91, 117] -> 
             RGBColor[
              0.1857785761820701, 0.31259544098237624`, 0.9338911871275704], 
             UndirectedEdge[27, 141] -> 
             RGBColor[
              0.30516819016116037`, 0.4348390437291191, 0.9408089710476214], 
             UndirectedEdge[13, 145] -> 
             RGBColor[
              0.20564959648275716`, 0.3334811432138535, 0.9350228123371542], 
             UndirectedEdge[1, 174] -> 
             RGBColor[
              0.1849745541189024, 0.31175036281604385`, 0.9338453992605169], 
             UndirectedEdge[182, 196] -> 
             RGBColor[
              0.28690951633149697`, 0.41592381842644754`, 0.9397590682480286],
              UndirectedEdge[96, 137] -> 
             RGBColor[
              0.630154419316935, 0.7035305563325196, 0.9671868226387048], 
             UndirectedEdge[89, 157] -> 
             RGBColor[
              0.23696986749514018`, 0.36640073386774574`, 0.9368064554371207],
              UndirectedEdge[119, 191] -> 
             RGBColor[
              0.8284647281297735, 0.6062540401066088, 0.5870905124717782], 
             UndirectedEdge[51, 157] -> 
             RGBColor[
              0.19431074366027534`, 0.32156328997263306`, 0.9343770814432435],
              UndirectedEdge[127, 195] -> 
             RGBColor[
              0.6879096375591269, 0.7543975082866485, 0.9708907042928315], 
             UndirectedEdge[27, 62] -> 
             RGBColor[
              0.23321094483198931`, 0.3624498678193121, 0.9365923903522819], 
             UndirectedEdge[4, 40] -> 
             RGBColor[
              0.42006888605358417`, 0.5368384587156347, 0.9483813569191326], 
             UndirectedEdge[161, 164] -> 
             RGBColor[
              0.23950057479482478`, 0.3690606676958246, 0.9369505754739917], 
             UndirectedEdge[20, 101] -> 
             RGBColor[
              0.18925893509711914`, 0.3162535188695931, 0.9340893884190526], 
             UndirectedEdge[13, 36] -> 
             RGBColor[
              0.20182875625464586`, 0.3294651978788461, 0.9348052211385899], 
             UndirectedEdge[182, 195] -> 
             RGBColor[
              0.42093237513181697`, 0.5377166564648852, 0.9484003790182465], 
             UndirectedEdge[184, 186] -> 
             RGBColor[
              0.18243843400162507`, 0.3090847397734826, 0.9337009709716915], 
             UndirectedEdge[96, 166] -> 
             RGBColor[
              0.8700729048613844, 0.8993494121193195, 0.9867932099380505], 
             UndirectedEdge[38, 43] -> 
             RGBColor[
              0.1854358891920559, 0.31223525522826123`, 0.9338716716104489], 
             UndirectedEdge[30, 176] -> 
             RGBColor[
              0.22182699852969923`, 0.3504846184717214, 0.9359440914514059], 
             UndirectedEdge[171, 174] -> 
             RGBColor[
              0.24889168370669917`, 0.37893131859289997`, 0.9374853852336225],
              UndirectedEdge[100, 125] -> 
             RGBColor[
              0.23503699113385892`, 0.36436915826059957`, 0.9366963809877801],
              UndirectedEdge[17, 188] -> 
             RGBColor[
              0.25233578672597107`, 0.38213926955209265`, 0.937696607864392], 
             UndirectedEdge[87, 107] -> 
             RGBColor[
              0.21716799810205883`, 0.34558771362458285`, 0.9356787682694253],
              UndirectedEdge[62, 184] -> 
             RGBColor[
              0.19085514348532573`, 0.3179312350910555, 0.9341802901253824], 
             UndirectedEdge[12, 33] -> 
             RGBColor[
              0.9713628299392978, 0.9155481063306994, 0.5253098577893779], 
             UndirectedEdge[32, 57] -> 
             RGBColor[
              0.1839232484123208, 0.31064537386179486`, 0.9337855289557946], 
             UndirectedEdge[17, 87] -> 
             RGBColor[
              0.2040861170766778, 0.33183782722774424`, 0.9349337744979385], 
             UndirectedEdge[42, 149] -> 
             RGBColor[
              0.1941370173040445, 0.32138069255734725`, 0.9343671879842612], 
             UndirectedEdge[87, 130] -> 
             RGBColor[
              0.20049917291084113`, 0.3280677214840543, 0.9347295033341025], 
             UndirectedEdge[58, 170] -> 
             RGBColor[
              0.8078923228953876, 0.8503457214275595, 0.9589431237256691], 
             UndirectedEdge[118, 196] -> 
             RGBColor[
              0.3119267863848373, 0.4375925203420974, 0.941353146573924], 
             UndirectedEdge[41, 159] -> 
             RGBColor[
              0.27279920204986197`, 0.40405963619577695`, 0.9388468830352616],
              UndirectedEdge[107, 157] -> 
             RGBColor[
              0.2120289568241801, 0.34018625540749603`, 0.9353861074711805], 
             UndirectedEdge[161, 173] -> 
             RGBColor[
              0.32579061120905595`, 0.4543013453093021, 0.9420644224308505], 
             UndirectedEdge[15, 184] -> 
             RGBColor[
              0.18036794199566558`, 0.3069085213984438, 0.9335830595149706], 
             UndirectedEdge[106, 142] -> 
             RGBColor[
              0.22351397693716918`, 0.3522577397385811, 0.9360401623760504], 
             UndirectedEdge[24, 39] -> 
             RGBColor[
              0.25460473932666533`, 0.38493610227813213`, 0.9378107352994711],
              UndirectedEdge[45, 134] -> 
             RGBColor[
              0.478958077481094, 0.5755005922270049, 0.9546021057447607], 
             UndirectedEdge[5, 73] -> 
             RGBColor[
              0.2859066569179567, 0.41362147278674055`, 0.939747662416915], 
             UndirectedEdge[147, 154] -> 
             RGBColor[
              0.2906977642675366, 0.42073411010671546`, 0.939944464152203], 
             UndirectedEdge[76, 143] -> 
             RGBColor[
              0.5599555580797754, 0.6414092268045206, 0.9622274966891435], 
             UndirectedEdge[5, 197] -> 
             RGBColor[
              0.27751999813753725`, 0.4048065626636409, 0.93927005460632], 
             UndirectedEdge[152, 159] -> 
             RGBColor[
              0.22753887579901738`, 0.3564881636357107, 0.9362693744119284], 
             UndirectedEdge[108, 115] -> 
             RGBColor[
              0.3115259900053915, 0.4441833842869002, 0.9410735735175593], 
             UndirectedEdge[65, 123] -> 
             RGBColor[
              0.7037314806376549, 0.7147724455085309, 0.6174251209785002], 
             UndirectedEdge[8, 67] -> 
             RGBColor[
              0.26957716191751396`, 0.4006730677275356, 0.9386633926163057], 
             UndirectedEdge[9, 41] -> 
             RGBColor[
              0.24200989921647753`, 0.37169812676333913`, 0.9370934777875921],
              UndirectedEdge[111, 165] -> 
             RGBColor[
              0.21296967150778956`, 0.3411750061847254, 0.9354396797807493], 
             UndirectedEdge[146, 195] -> 
             RGBColor[
              0.37321783418719845`, 0.490532301380389, 0.9455744828100211], 
             UndirectedEdge[104, 188] -> 
             RGBColor[
              0.34015129368141406`, 0.46904368691088416`, 0.9428951175427689],
              UndirectedEdge[37, 105] -> 
             RGBColor[
              0.22080146805015013`, 0.3494067209153274, 0.9358856890077321], 
             UndirectedEdge[3, 75] -> 
             RGBColor[
              0.4604176361342196, 0.5718866537552251, 0.9509246758011038], 
             UndirectedEdge[40, 132] -> 
             RGBColor[
              0.40319785832980803`, 0.5214692788871429, 0.94733404339442], 
             UndirectedEdge[154, 157] -> 
             RGBColor[
              0.2691478842423667, 0.3980838198589522, 0.9387172303649602], 
             UndirectedEdge[116, 148] -> 
             RGBColor[
              0.21710235245946194`, 0.3455187158920394, 0.9356750298471934], 
             UndirectedEdge[132, 185] -> 
             RGBColor[
              0.26630785953473646`, 0.397236823637493, 0.9384772106821059], 
             UndirectedEdge[92, 123] -> 
             RGBColor[
              0.34778570453147756`, 0.4697113495975751, 0.9435992466398737], 
             UndirectedEdge[53, 139] -> 
             RGBColor[
              0.4587256509461706, 0.5647673777664313, 0.9518675910388628], 
             UndirectedEdge[40, 196] -> 
             RGBColor[
              0.3694081793861806, 0.4859541839280068, 0.9454097711659308], 
             UndirectedEdge[27, 73] -> 
             RGBColor[
              0.2419998599538071, 0.37168757486174653`, 0.9370929060664348], 
             UndirectedEdge[57, 103] -> 
             RGBColor[
              0.1814602470714449, 0.3080566032892297, 0.9336452646731157], 
             UndirectedEdge[44, 77] -> 
             RGBColor[
              0.8580464518144618, 0.3836823814909788, 0.2007324013601752], 
             UndirectedEdge[88, 91] -> 
             RGBColor[
              0.20139859473617852`, 0.32901307084912135`, 0.93478072407648], 
             UndirectedEdge[69, 146] -> 
             RGBColor[
              0.24760893000865222`, 0.37758306312497075`, 0.9374123343081827],
              UndirectedEdge[65, 199] -> 
             RGBColor[
              0.9757996397934585, 0.9283450401492326, 0.5065449231630825], 
             UndirectedEdge[27, 75] -> 
             RGBColor[
              0.3843313935505691, 0.5020805374205839, 0.9462194736309155], 
             UndirectedEdge[4, 65] -> 
             RGBColor[
              0.6453230600166431, 0.6641820072591899, 0.6137033880650677], 
             UndirectedEdge[58, 102] -> 
             RGBColor[
              0.9648761622564584, 0.9733252798376484, 0.9443396749224908], 
             UndirectedEdge[107, 168] -> 
             RGBColor[
              0.21351519211843195`, 0.34174838293451504`, 0.9354707463724999],
              UndirectedEdge[9, 85] -> 
             RGBColor[
              0.23189273144463124`, 0.36106434196964265`, 0.9365173200499939],
              UndirectedEdge[22, 144] -> 
             RGBColor[
              0.19348904144218293`, 0.3206996288424882, 0.9343302867175226], 
             UndirectedEdge[110, 138] -> 
             RGBColor[
              0.20099999291646117`, 0.32859411506378333`, 0.9347580242925257],
              UndirectedEdge[34, 132] -> 
             RGBColor[
              0.3653113300133066, 0.4900797022247081, 0.9445259862530728], 
             UndirectedEdge[48, 158] -> 
             RGBColor[
              0.2634190473924112, 0.39349797793107355`, 0.9383384198388076], 
             UndirectedEdge[19, 95] -> 
             RGBColor[
              0.3002072480543151, 0.4289405280402324, 0.9405515065144217], 
             UndirectedEdge[122, 137] -> 
             RGBColor[
              0.3009080664928653, 0.4322034485232962, 0.9404989162882755], 
             UndirectedEdge[8, 198] -> 
             RGBColor[
              0.31444384785817775`, 0.4444212242772747, 0.9413433252524308], 
             UndirectedEdge[92, 174] -> 
             RGBColor[
              0.2172400978636229, 0.3456634950453756, 0.9356828742441843], 
             UndirectedEdge[39, 133] -> 
             RGBColor[
              0.2505927164379196, 0.38071921184511703`, 0.9375822565312131], 
             UndirectedEdge[120, 198] -> 
             RGBColor[
              0.26978078120628096`, 0.39747750942414833`, 0.9387998296796913],
              UndirectedEdge[4, 34] -> 
             RGBColor[
              0.38218235773708276`, 0.5054488820532, 0.9455732997777855], 
             UndirectedEdge[31, 34] -> 
             RGBColor[
              0.48100947040442327`, 0.5889125969543878, 0.9524604831380885], 
             UndirectedEdge[41, 152] -> 
             RGBColor[
              0.2454459622028375, 0.3753096468209797, 0.9372891564914656], 
             UndirectedEdge[95, 121] -> 
             RGBColor[
              0.23327542567236176`, 0.36251764127086494`, 0.9365960624407503],
              UndirectedEdge[3, 129] -> 
             RGBColor[
              0.4365819525225805, 0.5525357720139865, 0.9490482434742096], 
             UndirectedEdge[49, 199] -> 
             RGBColor[
              0.7088075949120052, 0.7662760755555905, 0.8381694307308162], 
             UndirectedEdge[171, 182] -> 
             RGBColor[
              0.3242915422574164, 0.45521469783192636`, 0.9418879193227581], 
             UndirectedEdge[56, 150] -> 
             RGBColor[
              0.18756580923325702`, 0.31447393623629405`, 0.933992967405861], 
             UndirectedEdge[179, 183] -> 
             RGBColor[
              0.6524621901365182, 0.6395620041190959, 0.6061877007325749], 
             UndirectedEdge[31, 156] -> 
             RGBColor[
              0.6753397250677327, 0.3878936918486643, 0.560927249104864], 
             UndirectedEdge[132, 153] -> 
             RGBColor[
              0.29141110867079584`, 0.42362193011741534`, 0.9399068035834754],
              UndirectedEdge[78, 136] -> 
             RGBColor[
              0.2028717449192551, 0.3305614450946512, 0.9348646178000759], 
             UndirectedEdge[27, 167] -> 
             RGBColor[
              0.2329271456668488, 0.36215157690284305`, 0.9365762284096705], 
             UndirectedEdge[35, 174] -> 
             RGBColor[
              0.18540537254043327`, 0.31220318029253835`, 0.9338699337322844],
              UndirectedEdge[61, 190] -> 
             RGBColor[
              0.1957633885191688, 0.3230901118223337, 0.9344598074189618], 
             UndirectedEdge[18, 103] -> 
             RGBColor[
              0.20207429376045272`, 0.32972327336542606`, 0.9348192041363055],
              UndirectedEdge[146, 155] -> 
             RGBColor[
              0.4592969410332923, 0.5599429054907851, 0.9526738544811711], 
             UndirectedEdge[77, 166] -> 
             RGBColor[
              0.8105241760173298, 0.490362872734788, 0.5726449442995682], 
             UndirectedEdge[85, 159] -> 
             RGBColor[
              0.26268203427801573`, 0.3934258514020805, 0.9382707252976634], 
             UndirectedEdge[39, 88] -> 
             RGBColor[
              0.2343125277851679, 0.36360770134749604`, 0.9366551238718196], 
             UndirectedEdge[66, 80] -> 
             RGBColor[
              0.20266968703316796`, 0.3303490694451636, 0.9348531109023811], 
             UndirectedEdge[62, 141] -> 
             RGBColor[
              0.2718586483084913, 0.3998286032950302, 0.9389120419161632], 
             UndirectedEdge[91, 103] -> 
             RGBColor[
              0.18365762005674702`, 0.31036618161827634`, 0.9337704018139066],
              UndirectedEdge[149, 189] -> 
             RGBColor[
              0.18996767873421347`, 0.31699845336912136`, 0.934129750320693], 
             UndirectedEdge[4, 69] -> 
             RGBColor[
              0.2920607984493962, 0.42194145527329896`, 0.9400303359095292], 
             UndirectedEdge[23, 169] -> 
             RGBColor[
              0.20786534559532402`, 0.33581003601776915`, 0.9351489959712078],
              UndirectedEdge[32, 152] -> 
             RGBColor[
              0.19309625212307593`, 0.3202867823638255, 0.9343079179468792], 
             UndirectedEdge[100, 124] -> 
             RGBColor[
              0.21591407787580016`, 0.3442697639636507, 0.9356073593675487], 
             UndirectedEdge[129, 139] -> 
             RGBColor[
              0.3700695186748425, 0.49279233567532266`, 0.9448882555483507], 
             UndirectedEdge[29, 73] -> 
             RGBColor[
              0.21219498840003925`, 0.3403607651207339, 0.9353955627238038], 
             UndirectedEdge[32, 178] -> 
             RGBColor[
              0.1848271249653814, 0.311595405428145, 0.9338370033883259], 
             UndirectedEdge[8, 61] -> 
             RGBColor[
              0.24530237000143487`, 0.37515872231303415`, 0.9372809791280214],
              UndirectedEdge[10, 27] -> 
             RGBColor[
              0.24223545662361712`, 0.37193520189940843`, 0.9371063229482464],
              UndirectedEdge[72, 160] -> 
             RGBColor[
              0.3481960203596565, 0.4708761388050667, 0.9435957557128356], 
             UndirectedEdge[72, 144] -> 
             RGBColor[
              0.22584498306262032`, 0.3547077749707548, 0.9361729097264804], 
             UndirectedEdge[134, 135] -> 
             RGBColor[
              0.22190471606791506`, 0.3505663045319628, 0.9359485173502345], 
             UndirectedEdge[95, 150] -> 
             RGBColor[
              0.2208799451115121, 0.3494892052825519, 0.9358901581602801], 
             UndirectedEdge[68, 71] -> 
             RGBColor[
              0.6623649639352431, 0.6847752584173, 0.6236785616506062], 
             UndirectedEdge[118, 123] -> 
             RGBColor[
              0.42099591367325284`, 0.5390672333790665, 0.9480464652405584], 
             UndirectedEdge[89, 168] -> 
             RGBColor[
              0.23845610278939203`, 0.36796286139476475`, 0.9368910943384403],
              UndirectedEdge[44, 99] -> 
             RGBColor[
              0.7252973005063621, 0.6401348451070372, 0.5975536479428364], 
             UndirectedEdge[121, 180] -> 
             RGBColor[
              0.27969294333585376`, 0.40822779625327543`, 0.9393521573829899],
              UndirectedEdge[10, 141] -> 
             RGBColor[
              0.28088316010011916`, 0.40931393737512656`, 0.9394259745121276],
              UndirectedEdge[6, 170] -> 
             RGBColor[
              0.7433204991907267, 0.48659316349091797`, 0.5720011378191884], 
             UndirectedEdge[12, 77] -> 
             RGBColor[
              0.883710558650916, 0.4870027765625733, 0.22146359810422783`], 
             UndirectedEdge[112, 143] -> 
             RGBColor[
              0.8985367952768839, 0.9217855718880776, 0.9850776323188054], 
             UndirectedEdge[67, 125] -> 
             RGBColor[
              0.2600866097683471, 0.39069789568300034`, 0.9381229197114243], 
             UndirectedEdge[3, 10] -> 
             RGBColor[
              0.3183216992072676, 0.4417413182340497, 0.9418115251184348], 
             UndirectedEdge[124, 125] -> 
             RGBColor[
              0.24516019716023396`, 0.37500928964265323`, 0.9372728825950409],
              UndirectedEdge[11, 174] -> 
             RGBColor[
              0.1964947207721936, 0.32385878838940574`, 0.9345014557088626], 
             UndirectedEdge[71, 87] -> 
             RGBColor[
              0.29022081155983176`, 0.4172864093031303, 0.9400251842918653], 
             UndirectedEdge[7, 192] -> 
             RGBColor[
              0.3371042587561843, 0.4567989612427451, 0.9431333444727331], 
             UndirectedEdge[56, 148] -> 
             RGBColor[
              0.18807327130146562`, 0.31500731104493473`, 0.9340218666199227],
              UndirectedEdge[30, 71] -> 
             RGBColor[
              0.28665240734323405`, 0.41353579022159115`, 0.939821968950711], 
             UndirectedEdge[35, 86] -> 
             RGBColor[
              0.19143714046786142`, 0.31854295082044043`, 0.9342134339925504],
              UndirectedEdge[68, 127] -> 
             RGBColor[
              0.9178893661581602, 0.8915362183675095, 0.645439120800334], 
             UndirectedEdge[10, 30] -> 
             RGBColor[
              0.2137583126687416, 0.34200391804762365`, 0.9354845917281754], 
             UndirectedEdge[89, 176] -> 
             RGBColor[
              0.25080130431121317`, 0.3809384509251836, 0.937594135302019], 
             UndirectedEdge[71, 76] -> 
             RGBColor[
              0.3139935330397997, 0.4422730468561747, 0.9413790056115596], 
             UndirectedEdge[49, 119] -> 
             RGBColor[
              0.634590175011373, 0.45058684488381917`, 0.5703034220716992], 
             UndirectedEdge[87, 106] -> 
             RGBColor[
              0.20086653877096394`, 0.3284538462953842, 0.9347504242763673], 
             UndirectedEdge[86, 196] -> 
             RGBColor[
              0.2175414257082079, 0.3459802097153233, 0.9357000344191588], 
             UndirectedEdge[53, 123] -> 
             RGBColor[
              0.5414537947364539, 0.6385560470320484, 0.9570608296632714], 
             UndirectedEdge[68, 102] -> 
             RGBColor[
              0.9650834798325474, 0.9283042529937652, 0.6200104049924591], 
             UndirectedEdge[107, 130] -> 
             RGBColor[
              0.20096416380479723`, 0.32855645639572767`, 0.9347559838776209],
              UndirectedEdge[42, 157] -> 
             RGBColor[
              0.2045975584295754, 0.3323753845168943, 0.9349629003263764], 
             UndirectedEdge[96, 99] -> 
             RGBColor[
              0.7441185775359549, 0.79956600300059, 0.9751875122211435], 
             UndirectedEdge[62, 194] -> 
             RGBColor[
              0.2007116762072222, 0.32829107592203804`, 0.9347416050824608], 
             UndirectedEdge[57, 117] -> 
             RGBColor[
              0.18358120319676802`, 0.31028586265332964`, 0.9337660499867794],
              UndirectedEdge[102, 128] -> 
             RGBColor[
              0.700241137930167, 0.7622648425385679, 0.9428826111957023], 
             UndirectedEdge[46, 47] -> 
             RGBColor[
              0.1896200136619846, 0.31663303533497, 0.934109951309154], 
             UndirectedEdge[28, 105] -> 
             RGBColor[
              0.19252363925225727`, 0.3196849299308422, 0.9342753084909909], 
             UndirectedEdge[40, 182] -> 
             RGBColor[
              0.4233315585574587, 0.5396644216518027, 0.9485892515260115], 
             UndirectedEdge[79, 179] -> 
             RGBColor[
              0.2813590504704592, 0.4075281905155883, 0.9395367751459407], 
             UndirectedEdge[36, 63] -> 
             RGBColor[
              0.1871120628164008, 0.3139970199829937, 0.9339671272186787], 
             UndirectedEdge[118, 129] -> 
             RGBColor[
              0.4226691844013287, 0.5404852315434163, 0.9481617341921013], 
             UndirectedEdge[74, 161] -> 
             RGBColor[
              0.31487926883859824`, 0.44485048896802515`, 0.9413691613435261],
              UndirectedEdge[66, 187] -> 
             RGBColor[
              0.19351363784595493`, 0.32072548122235467`, 0.9343316874463302],
              UndirectedEdge[10, 29] -> 
             RGBColor[
              0.2124305850698493, 0.3406083921583959, 0.9354089796056155], 
             UndirectedEdge[30, 147] -> 
             RGBColor[
              0.22954544173879612`, 0.3585971916620468, 0.9363836453737505], 
             UndirectedEdge[109, 116] -> 
             RGBColor[
              0.2290183753781148, 0.3580432114990334, 0.9363536297242345], 
             UndirectedEdge[81, 154] -> 
             RGBColor[
              0.31895036317144065`, 0.45042938287295087`, 0.9415534078638058],
              UndirectedEdge[89, 188] -> 
             RGBColor[
              0.29035857842231216`, 0.42210363440918097`, 0.939861949601819], 
             UndirectedEdge[24, 163] -> 
             RGBColor[
              0.2694549562733895, 0.40054462184727546`, 0.9386564331856598], 
             UndirectedEdge[91, 159] -> 
             RGBColor[
              0.22056324507356437`, 0.3491563334627266, 0.9358721225616348], 
             UndirectedEdge[121, 164] -> 
             RGBColor[
              0.2062630848758868, 0.3341259584124435, 0.9350577495935681], 
             UndirectedEdge[4, 54] -> 
             RGBColor[
              0.661350157437102, 0.7182451701998284, 0.6759656350801627], 
             UndirectedEdge[51, 130] -> 
             RGBColor[
              0.18324595064089247`, 0.3099334909608647, 0.933746957849684], 
             UndirectedEdge[69, 186] -> 
             RGBColor[
              0.21644101520784265`, 0.3448236085093839, 0.9356373676690746], 
             UndirectedEdge[137, 179] -> 
             RGBColor[
              0.3462163270218858, 0.4742969139529616, 0.9432815761041253], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.37725864887478877`, 0.501184212909484, 0.945259565402945], 
             UndirectedEdge[22, 176] -> 
             RGBColor[
              0.2112886129989553, 0.33940810710667507`, 0.9353439459855744], 
             UndirectedEdge[128, 198] -> 
             RGBColor[
              0.38846505457694686`, 0.5108906382783656, 0.9459736276648509], 
             UndirectedEdge[107, 131] -> 
             RGBColor[
              0.19956404883419218`, 0.32708484678920535`, 0.9346762494013294],
              UndirectedEdge[26, 125] -> 
             RGBColor[
              0.2785326649894304, 0.41008586926780977`, 0.9391733952677717], 
             UndirectedEdge[47, 105] -> 
             RGBColor[
              0.2010087745780687, 0.32860334514692235`, 0.934758524395163], 
             UndirectedEdge[23, 60] -> 
             RGBColor[
              0.2023092030396156, 0.32997017791193484`, 0.9348325818722366], 
             UndirectedEdge[43, 111] -> 
             RGBColor[
              0.2049417486516364, 0.33273715026320094`, 0.934982501450339], 
             UndirectedEdge[73, 142] -> 
             RGBColor[
              0.23973855838173452`, 0.36931080353469764`, 0.9369641282872011],
              UndirectedEdge[43, 115] -> 
             RGBColor[
              0.25238630356085545`, 0.3820238241610014, 0.9377056558638687], 
             UndirectedEdge[61, 122] -> 
             RGBColor[
              0.24263213866310665`, 0.37235213987400595`, 0.9371289134035569],
              UndirectedEdge[64, 65] -> 
             RGBColor[
              0.792934775654365, 0.787251260573052, 0.6244310740750881], 
             UndirectedEdge[147, 157] -> 
             RGBColor[
              0.2279748046775151, 0.3569463525264991, 0.9362941999166599], 
             UndirectedEdge[53, 69] -> 
             RGBColor[
              0.4407986220698122, 0.5459249337780987, 0.9508466732650168], 
             UndirectedEdge[27, 188] -> 
             RGBColor[
              0.28986141659567377`, 0.4215810858075036, 0.939833636971277], 
             UndirectedEdge[88, 159] -> 
             RGBColor[
              0.23572746530865607`, 0.3650948903969026, 0.9367357024705698], 
             UndirectedEdge[16, 61] -> 
             RGBColor[
              0.19725809150646825`, 0.3246611394316285, 0.9345449285428737], 
             UndirectedEdge[138, 185] -> 
             RGBColor[
              0.22696192070522694`, 0.35588174725107113`, 0.9362365176728656],
              UndirectedEdge[26, 128] -> 
             RGBColor[
              0.36204442385736635`, 0.48653045531343586`, 0.9443441705850733],
              UndirectedEdge[68, 75] -> 
             RGBColor[
              0.7315668061877028, 0.7433887217645079, 0.6284543351107399], 
             UndirectedEdge[10, 107] -> 
             RGBColor[
              0.21779170777929543`, 0.3462432720408361, 0.9357142876128481], 
             UndirectedEdge[69, 123] -> 
             RGBColor[
              0.3504692190704081, 0.47253189352264, 0.9437520688229617], 
             UndirectedEdge[109, 113] -> 
             RGBColor[
              0.2109311914464215, 0.33903243439312675`, 0.9353235913569153], 
             UndirectedEdge[49, 196] -> 
             RGBColor[
              0.3276703084677861, 0.4512287678779199, 0.9423563098795996], 
             UndirectedEdge[8, 26] -> 
             RGBColor[
              0.28802321713859724`, 0.420061041312345, 0.9397138681726531], 
             UndirectedEdge[30, 73] -> 
             RGBColor[
              0.21352271599893158`, 0.34175629100996163`, 0.9354711748463638],
              UndirectedEdge[46, 144] -> 
             RGBColor[
              0.19073384687984102`, 0.31780374466804207`, 0.9341733824631423],
              UndirectedEdge[81, 176] -> 
             RGBColor[
              0.2700588403974922, 0.4011793423501723, 0.938690823493161], 
             UndirectedEdge[104, 181] -> 
             RGBColor[
              0.4026365855967863, 0.5231653061658909, 0.9468766250900423], 
             UndirectedEdge[65, 171] -> 
             RGBColor[
              0.6320443792751589, 0.6525886118770408, 0.6128606533865955], 
             UndirectedEdge[67, 82] -> 
             RGBColor[
              0.2339276106645956, 0.3632031290486195, 0.9366332034112368], 
             UndirectedEdge[13, 63] -> 
             RGBColor[
              0.20638929458382937`, 0.3342586128176488, 0.935064937049725], 
             UndirectedEdge[153, 182] -> 
             RGBColor[
              0.3115448088984465, 0.4418170728820753, 0.941162011715067], 
             UndirectedEdge[87, 157] -> 
             RGBColor[
              0.21156396593022397`, 0.3396975204958227, 0.9353596269276621], 
             UndirectedEdge[30, 157] -> 
             RGBColor[
              0.20799556171362626`, 0.3359469014142835, 0.9351564115865076], 
             UndirectedEdge[64, 185] -> 
             RGBColor[
              0.4307906028962345, 0.5356752567798472, 0.9502522102168389], 
             UndirectedEdge[9, 103] -> 
             RGBColor[
              0.18719718779584008`, 0.3140864917336198, 0.9339719749603267], 
             UndirectedEdge[18, 117] -> 
             RGBColor[
              0.2041952498857758, 0.331952532729526, 0.9349399894499691], 
             UndirectedEdge[52, 66] -> 
             RGBColor[
              0.18456752137294713`, 0.3113225455926782, 0.9338222193477858], 
             UndirectedEdge[128, 162] -> 
             RGBColor[
              0.4413593088202362, 0.5567049827613839, 0.9493440027726809], 
             UndirectedEdge[23, 177] -> 
             RGBColor[
              0.22051380406985302`, 0.3491043678330853, 0.9358693069696149], 
             UndirectedEdge[11, 110] -> 
             RGBColor[
              0.1915413157937571, 0.3186524456930539, 0.9342193666232466], 
             UndirectedEdge[79, 177] -> 
             RGBColor[
              0.20578387384021699`, 0.33362227723022, 0.9350304592340161], 
             UndirectedEdge[8, 166] -> 
             RGBColor[
              0.543496783375643, 0.6308288867491243, 0.9602573693120857], 
             UndirectedEdge[162, 173] -> 
             RGBColor[
              0.40958261070654, 0.5291816039985865, 0.947319219667907], 
             UndirectedEdge[100, 137] -> 
             RGBColor[
              0.26484162639759284`, 0.3942953332387867, 0.9384449858803665], 
             UndirectedEdge[88, 117] -> 
             RGBColor[
              0.2009427964171618, 0.32853399791655225`, 0.9347547670365053], 
             UndirectedEdge[149, 168] -> 
             RGBColor[
              0.19745061882106624`, 0.32486349784620777`, 0.9345558926886215],
              UndirectedEdge[36, 110] -> 
             RGBColor[
              0.18133894646584242`, 0.3079291086618389, 0.9336383567830746], 
             UndirectedEdge[76, 104] -> 
             RGBColor[
              0.3156743455120887, 0.4437288821395802, 0.9414861054960099], 
             UndirectedEdge[4, 196] -> 
             RGBColor[
              0.28364684382762245`, 0.41309785549027966`, 0.9395511736411497],
              UndirectedEdge[61, 79] -> 
             RGBColor[
              0.20075917656457537`, 0.3283410018093128, 0.9347443101575417], 
             UndirectedEdge[76, 147] -> 
             RGBColor[
              0.2568865674353618, 0.38733444829663033`, 0.9379406820345992], 
             UndirectedEdge[2, 120] -> 
             RGBColor[
              0.18815579892545653`, 0.3150940528103027, 0.9340265664460203], 
             UndirectedEdge[87, 176] -> 
             RGBColor[
              0.22539540274629694`, 0.3542352375532605, 0.9361473067925603], 
             UndirectedEdge[142, 157] -> 
             RGBColor[
              0.2342114040964292, 0.3635014139390195, 0.9366493650273451], 
             UndirectedEdge[65, 191] -> 
             RGBColor[
              0.8832210777752071, 0.8579801148696197, 0.6332956147035969], 
             UndirectedEdge[73, 147] -> 
             RGBColor[
              0.23350195896282042`, 0.3627557421221772, 0.936608963176516], 
             UndirectedEdge[26, 120] -> 
             RGBColor[
              0.2433601504867005, 0.3731173264592187, 0.9371703725999135], 
             UndirectedEdge[113, 116] -> 
             RGBColor[
              0.22254054731904888`, 0.35123460349093416`, 0.9359847269993585],
              UndirectedEdge[35, 94] -> 
             RGBColor[
              0.1855941681935362, 0.31240161649428533`, 0.9338806853654305], 
             UndirectedEdge[31, 45] -> 
             RGBColor[0.62150237913985, 0.702550504593909, 0.964065451798632],
              UndirectedEdge[52, 82] -> 
             RGBColor[
              0.1987769890735687, 0.32625759707831903`, 0.9346314275123124], 
             UndirectedEdge[95, 162] -> 
             RGBColor[
              0.35030491508878375`, 0.4723326092435304, 0.9437436855582304], 
             UndirectedEdge[17, 73] -> 
             RGBColor[
              0.20447423008410437`, 0.33224575860633554`, 0.9349558769595496],
              UndirectedEdge[103, 152] -> 
             RGBColor[
              0.19063325078220003`, 0.31769801179126034`, 0.9341676536642003],
              UndirectedEdge[88, 103] -> 
             RGBColor[
              0.1988218402918387, 0.32630473855245234`, 0.9346339817228415], 
             UndirectedEdge[26, 170] -> 
             RGBColor[
              0.4739950942722979, 0.5778178834110607, 0.9531267757340784], 
             UndirectedEdge[89, 106] -> 
             RGBColor[
              0.22627244033588012`, 0.3551570596673073, 0.9361972527858261], 
             UndirectedEdge[19, 74] -> 
             RGBColor[
              0.34857360130161363`, 0.4763386664540116, 0.9434317795367738], 
             UndirectedEdge[117, 152] -> 
             RGBColor[
              0.19275420690752315`, 0.3199272711553603, 0.934288438977864], 
             UndirectedEdge[157, 176] -> 
             RGBColor[
              0.2202563614684182, 0.34883377933617365`, 0.9358546459943153], 
             UndirectedEdge[49, 139] -> 
             RGBColor[
              0.3540112919659183, 0.4789148116492719, 0.9438563899218253], 
             UndirectedEdge[48, 106] -> 
             RGBColor[
              0.1977618988532519, 0.32519067289632886`, 0.9345736196259569], 
             UndirectedEdge[69, 118] -> 
             RGBColor[
              0.32034074100661103`, 0.44643612012511674`, 0.9418323088423037],
              UndirectedEdge[117, 200] -> 
             RGBColor[
              0.1879682303409825, 0.3148969063354854, 0.9340158846926173], 
             UndirectedEdge[64, 153] -> 
             RGBColor[
              0.4558938520322939, 0.5620603632597695, 0.9516818031182084], 
             UndirectedEdge[73, 87] -> 
             RGBColor[
              0.2170911202155293, 0.3455069100915008, 0.9356743901875181], 
             UndirectedEdge[132, 138] -> 
             RGBColor[
              0.2612195562179643, 0.3918886942345018, 0.9381874393356859], 
             UndirectedEdge[6, 96] -> 
             RGBColor[
              0.8839247435427675, 0.5973568467623975, 0.5851240708837279], 
             UndirectedEdge[34, 65] -> 
             RGBColor[
              0.6931978672586998, 0.7056487590344823, 0.6167539284485017], 
             UndirectedEdge[2, 16] -> 
             RGBColor[
              0.1847745870823867, 0.3115401847820234, 0.9338340114336121], 
             UndirectedEdge[21, 122] -> 
             RGBColor[
              0.3196137188420707, 0.44840534441475405`, 0.941690823915208], 
             UndirectedEdge[90, 175] -> 
             RGBColor[
              0.36392094666961883`, 0.4808157727668374, 0.9450400242191717], 
             UndirectedEdge[6, 179] -> 
             RGBColor[
              0.5999866512477183, 0.3681232043828395, 0.5612188243491484], 
             UndirectedEdge[8, 137] -> 
             RGBColor[
              0.3035782978311935, 0.4350100309623244, 0.94065098201274], 
             UndirectedEdge[3, 127] -> 
             RGBColor[
              0.6467401961046771, 0.7200341503582268, 0.9679094614906981], 
             UndirectedEdge[31, 65] -> 
             RGBColor[
              0.7441501726839835, 0.7476457221603776, 0.6205905714253708], 
             UndirectedEdge[3, 71] -> 
             RGBColor[
              0.3912157938817601, 0.5132731904080172, 0.9461489023409704], 
             UndirectedEdge[146, 184] -> 
             RGBColor[
              0.21360634880243462`, 0.34184419438906943`, 0.9354759376107997],
              UndirectedEdge[33, 99] -> 
             RGBColor[
              0.772222119980282, 0.8191247933841846, 0.8648855062678112], 
             UndirectedEdge[10, 130] -> 
             RGBColor[
              0.2011228825880777, 0.32872327990030753`, 0.9347650226775253], 
             UndirectedEdge[112, 160] -> 
             RGBColor[
              0.6923008271636373, 0.757058105759987, 0.9667604504602199], 
             UndirectedEdge[73, 157] -> 
             RGBColor[
              0.21195207893765056`, 0.34010545187441393`, 0.9353817293892732],
              UndirectedEdge[157, 188] -> 
             RGBColor[
              0.25981363557951725`, 0.389998962820171, 0.9381224602941154], 
             UndirectedEdge[70, 132] -> 
             RGBColor[
              0.2458080236877891, 0.37569019639768786`, 0.9373097753574117], 
             UndirectedEdge[141, 191] -> 
             RGBColor[
              0.5769597398249082, 0.6618980623518022, 0.9624179176414562], 
             UndirectedEdge[26, 80] -> 
             RGBColor[
              0.25728770840867865`, 0.387756072893393, 0.9379635264195947], 
             UndirectedEdge[171, 199] -> 
             RGBColor[
              0.6515054495303574, 0.7165517677858011, 0.834521559813894], 
             UndirectedEdge[23, 43] -> 
             RGBColor[
              0.2066925124128154, 0.33457731398103385`, 0.9350822048565153], 
             UndirectedEdge[75, 81] -> 
             RGBColor[
              0.40408609146348656`, 0.52284397744725, 0.9473444744525996], 
             UndirectedEdge[33, 172] -> 
             RGBColor[
              0.9309821433575884, 0.7454031597804265, 0.49229878616950506`], 
             UndirectedEdge[156, 166] -> 
             RGBColor[
              0.8112235131702088, 0.49573828454331076`, 0.5733146303469535], 
             UndirectedEdge[151, 175] -> 
             RGBColor[
              0.7472372281358932, 0.7985860801048122, 0.8522647687143463], 
             UndirectedEdge[34, 199] -> 
             RGBColor[
              0.7126589375138983, 0.7696119149432428, 0.8384148348758003], 
             UndirectedEdge[38, 169] -> 
             RGBColor[
              0.18660872237456455`, 0.31346797726499653`, 0.9339384627251416],
              UndirectedEdge[10, 142] -> 
             RGBColor[
              0.23997415505154454`, 0.3695584305723596, 0.9369775451690128], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.2876001150236012, 0.4192043144804547, 0.9397048591920434], 
             UndirectedEdge[12, 128] -> 
             RGBColor[
              0.6907043727279983, 0.6939382045780004, 0.6137063255291655], 
             UndirectedEdge[19, 172] -> 
             RGBColor[
              0.610278699777892, 0.48910830355495916`, 0.5781436227882895], 
             UndirectedEdge[109, 124] -> 
             RGBColor[
              0.22172315170383133`, 0.35037546887346516`, 0.9359381775283004],
              UndirectedEdge[75, 127] -> 
             RGBColor[
              0.6884648603869374, 0.7548482631907685, 0.9709344134676849], 
             UndirectedEdge[4, 191] -> 
             RGBColor[
              0.57220556825359, 0.6577802378883374, 0.9621149860328806], 
             UndirectedEdge[68, 172] -> 
             RGBColor[
              0.9151660280486694, 0.6898326684829248, 0.25782304770604947`], 
             UndirectedEdge[97, 105] -> 
             RGBColor[
              0.21127795983773054`, 0.3393969099587784, 0.9353433393038026], 
             UndirectedEdge[120, 136] -> 
             RGBColor[
              0.208375147270767, 0.3363458699019528, 0.9351780284224404], 
             UndirectedEdge[117, 159] -> 
             RGBColor[
              0.22010744675454766`, 0.3486772605301575, 0.9358461655216599], 
             UndirectedEdge[183, 192] -> 
             RGBColor[
              0.7010491462692232, 0.6813089979740284, 0.609376618188938], 
             UndirectedEdge[71, 188] -> 
             RGBColor[
              0.33847048120912504`, 0.4675878516274786, 0.9427880176583188], 
             UndirectedEdge[14, 106] -> 
             RGBColor[
              0.1821436488572793, 0.3087749018963175, 0.9336841833938165], 
             UndirectedEdge[141, 194] -> 
             RGBColor[
              0.2726689215363932, 0.40068025183184497`, 0.9389581857778003], 
             UndirectedEdge[50, 105] -> 
             RGBColor[
              0.2047516184167667, 0.33253731133139974`, 0.9349716738147356], 
             UndirectedEdge[98, 125] -> 
             RGBColor[
              0.22839213728314284`, 0.35738499555542924`, 0.936317966391162], 
             UndirectedEdge[118, 119] -> 
             RGBColor[
              0.6188466529284243, 0.4369505973479967, 0.5693002587660235], 
             UndirectedEdge[137, 166] -> 
             RGBColor[
              0.5638108664902101, 0.6507798896827761, 0.9614655012997908], 
             UndirectedEdge[6, 112] -> 
             RGBColor[
              0.8864219769798407, 0.5992192793709223, 0.5808969060575552], 
             UndirectedEdge[65, 119] -> 
             RGBColor[
              0.9015822198928265, 0.6126558094774612, 0.23867891450396542`], 
             UndirectedEdge[170, 183] -> 
             RGBColor[
              0.7957960380795266, 0.7580319632271744, 0.6169700142026149], 
             UndirectedEdge[14, 131] -> 
             RGBColor[
              0.18037616802655143`, 0.3069171674784653, 0.9335835279752602], 
             UndirectedEdge[9, 164] -> 
             RGBColor[
              0.1942433345387914, 0.32149243871196825`, 0.9343732425934977], 
             UndirectedEdge[96, 170] -> 
             RGBColor[
              0.7958122133360686, 0.8413363954975833, 0.9793915982124253], 
             UndirectedEdge[117, 178] -> 
             RGBColor[
              0.18448507974982858`, 0.3112358942196798, 0.9338175244193107], 
             UndirectedEdge[18, 24] -> 
             RGBColor[
              0.24010747998138166`, 0.3696985635269072, 0.9369851378265305], 
             UndirectedEdge[18, 133] -> 
             RGBColor[
              0.2360954570926359, 0.3654816730938921, 0.9367566590582723], 
             UndirectedEdge[49, 129] -> 
             RGBColor[
              0.4384127064842775, 0.5541214790792388, 0.9491648974977769], 
             UndirectedEdge[124, 198] -> 
             RGBColor[
              0.28583038245095216`, 0.4143466579357906, 0.9397138307273181], 
             UndirectedEdge[113, 124] -> 
             RGBColor[
              0.2152453236447654, 0.343566860865366, 0.9355692748034243], 
             UndirectedEdge[176, 188] -> 
             RGBColor[
              0.2736450723955902, 0.4045366798776089, 0.9389101401590136], 
             UndirectedEdge[37, 97] -> 
             RGBColor[
              0.22632286746697683`, 0.35521006177935477`, 0.9362001245363418],
              UndirectedEdge[77, 143] -> 
             RGBColor[
              0.8364908329957561, 0.5109365998950215, 0.5751565315064958], 
             UndirectedEdge[79, 84] -> 
             RGBColor[
              0.1877064038111327, 0.31462171005185247`, 0.93400097405908], 
             UndirectedEdge[151, 199] -> 
             RGBColor[
              0.9945819459025071, 0.992027509640117, 0.7394547080773856], 
             UndirectedEdge[48, 87] -> 
             RGBColor[
              0.21359836729039067`, 0.3418358053138541, 0.9354754830754963], 
             UndirectedEdge[27, 30] -> 
             RGBColor[
              0.2380433427297828, 0.3675290244016161, 0.9368675882636692], 
             UndirectedEdge[5, 87] -> 
             RGBColor[
              0.28551854391053016`, 0.41321354140814925`, 0.9397255599553038],
              UndirectedEdge[68, 81] -> 
             RGBColor[
              0.6335105972347094, 0.659531932623991, 0.6218491817852485], 
             UndirectedEdge[155, 172] -> 
             RGBColor[
              0.77126540629573, 0.6221045625124598, 0.590374002869697], 
             UndirectedEdge[143, 188] -> 
             RGBColor[
              0.5844325062491007, 0.6667240315758246, 0.9636365087359027], 
             UndirectedEdge[102, 180] -> 
             RGBColor[
              0.6556042618622065, 0.7236026240031248, 0.9400383889234916], 
             UndirectedEdge[80, 136] -> 
             RGBColor[
              0.2223027051927452, 0.3509846163361272, 0.9359711822421215], 
             UndirectedEdge[66, 78] -> 
             RGBColor[
              0.18323872675967784`, 0.30992589820368766`, 0.9337465464603355],
              UndirectedEdge[50, 101] -> 
             RGBColor[
              0.19997052243961871`, 0.3275120763204238, 0.9346993974718347], 
             UndirectedEdge[41, 85] -> 
             RGBColor[
              0.2805891206818358, 0.4122473345873495, 0.9392905073772007], 
             UndirectedEdge[5, 30] -> 
             RGBColor[
              0.28195013969393246`, 0.40946292232661013`, 0.9395223446141496],
              UndirectedEdge[32, 133] -> 
             RGBColor[
              0.21756503028546625`, 0.3460050196226384, 0.9357013786649139], 
             UndirectedEdge[159, 161] -> 
             RGBColor[
              0.2693600530686908, 0.4004448725619264, 0.938651028588549], 
             UndirectedEdge[3, 195] -> 
             RGBColor[
              0.4598624133064091, 0.5714358988511051, 0.9508809666262504], 
             UndirectedEdge[173, 180] -> 
             RGBColor[
              0.35489305397250803`, 0.4818122587326137, 0.9438344494728906], 
             UndirectedEdge[129, 141] -> 
             RGBColor[
              0.399143413415432, 0.5201083911550634, 0.9466626928679024], 
             UndirectedEdge[53, 199] -> 
             RGBColor[
              0.8135219538922576, 0.8521286416727499, 0.8461806318478537], 
             UndirectedEdge[88, 95] -> 
             RGBColor[
              0.23288032783126497`, 0.3621023683892223, 0.9365735622031948], 
             UndirectedEdge[93, 95] -> 
             RGBColor[
              0.24029230513765162`, 0.36989282648473865`, 0.9369956633457557],
              UndirectedEdge[3, 29] -> 
             RGBColor[
              0.312801857714541, 0.4359396148470296, 0.9414971783112978], 
             UndirectedEdge[52, 125] -> 
             RGBColor[
              0.2249359881773202, 0.35375236371269986`, 0.9361211438124999], 
             UndirectedEdge[82, 136] -> 
             RGBColor[
              0.21738866266974544`, 0.34581964607616317`, 0.935691334790111], 
             UndirectedEdge[116, 193] -> 
             RGBColor[
              0.2350445249483884, 0.36437707677734155`, 0.9366968100273723], 
             UndirectedEdge[19, 159] -> 
             RGBColor[
              0.30305438553170616`, 0.43193305004791277`, 0.9407136467817967],
              UndirectedEdge[77, 99] -> 
             RGBColor[
              0.6845698486919003, 0.3905794636160585, 0.5610392465826612], 
             UndirectedEdge[53, 196] -> 
             RGBColor[
              0.43238466744803844`, 0.5370813339950793, 0.9503675109966372], 
             UndirectedEdge[58, 137] -> 
             RGBColor[
              0.6422345288762541, 0.7125398822624958, 0.9467383481519487], 
             UndirectedEdge[159, 200] -> 
             RGBColor[
              0.22275289923247676`, 0.35145779881583583`, 0.9359968201266817],
              UndirectedEdge[3, 62] -> 
             RGBColor[
              0.30929718741563983`, 0.43225598415395333`, 0.9412975925224704],
              UndirectedEdge[48, 157] -> 
             RGBColor[
              0.20845932601251194`, 0.33643434709676723`, 0.9351828222772515],
              UndirectedEdge[130, 168] -> 
             RGBColor[
              0.19684636692721422`, 0.32422839079398647`, 0.9345214814371772],
              UndirectedEdge[140, 180] -> 
             RGBColor[
              0.6678780579649132, 0.7298281943728316, 0.7506032971167013], 
             UndirectedEdge[146, 171] -> 
             RGBColor[
              0.27657700131279794`, 0.4080303427474302, 0.9390620231145327], 
             UndirectedEdge[26, 100] -> 
             RGBColor[
              0.24928654570499661`, 0.3793463435888073, 0.9375078720402794], 
             UndirectedEdge[45, 153] -> 
             RGBColor[
              0.49664985237205533`, 0.594095769360721, 0.9556096261521655], 
             UndirectedEdge[165, 177] -> 
             RGBColor[
              0.2115965510366421, 0.3397317695086831, 0.9353614826012671], 
             UndirectedEdge[123, 139] -> 
             RGBColor[
              0.36839624794676656`, 0.4913743375109727, 0.9447729865968078], 
             UndirectedEdge[13, 34] -> 
             RGBColor[
              0.32558157650060693`, 0.44832121227099686`, 0.9422634355654279],
              UndirectedEdge[48, 72] -> 
             RGBColor[
              0.23184751916348642`, 0.3610168209955353, 0.9365147452774683], 
             UndirectedEdge[127, 191] -> 
             RGBColor[
              0.8424455031847746, 0.8772870526462687, 0.9848132059143445], 
             UndirectedEdge[58, 125] -> 
             RGBColor[
              0.6124298936125201, 0.6826137072843086, 0.9449897432593624], 
             UndirectedEdge[165, 169] -> 
             RGBColor[
              0.1989480925621131, 0.32643743769336697`, 0.9346411716028602], 
             UndirectedEdge[119, 156] -> 
             RGBColor[
              0.8327717722765755, 0.2529037791657479, 0.17901559218345872`], 
             UndirectedEdge[139, 191] -> 
             RGBColor[
              0.5478858450843187, 0.6345820068720615, 0.9606434803219044], 
             UndirectedEdge[48, 81] -> 
             RGBColor[
              0.2582618049415859, 0.3887799101107659, 0.938018999776097], 
             UndirectedEdge[85, 161] -> 
             RGBColor[
              0.2771499717006646, 0.408632570953499, 0.939094652930488], 
             UndirectedEdge[30, 106] -> 
             RGBColor[
              0.19729813455436623`, 0.32470322721384515`, 0.9345472089352131],
              UndirectedEdge[118, 195] -> 
             RGBColor[
              0.44594964518515734`, 0.559385358380535, 0.9499944573441421], 
             UndirectedEdge[132, 145] -> 
             RGBColor[
              0.24537934999545682`, 0.37523963316756476`, 0.9372853630247993],
              UndirectedEdge[124, 137] -> 
             RGBColor[
              0.27496483242396785`, 0.4049354646208403, 0.9390214874876273], 
             UndirectedEdge[53, 182] -> 
             RGBColor[
              0.48630804661931654`, 0.5907915717188752, 0.9535469913567178], 
             UndirectedEdge[31, 40] -> 
             RGBColor[
              0.5188959987209247, 0.6203021736168226, 0.9552685402794356], 
             UndirectedEdge[130, 157] -> 
             RGBColor[
              0.19536013163296237`, 0.32266626326696746`, 0.9344368425358576],
              UndirectedEdge[83, 166] -> 
             RGBColor[
              0.8650576677002866, 0.8953688994003288, 0.9869563023793746], 
             UndirectedEdge[76, 176] -> 
             RGBColor[
              0.24916812422626491`, 0.3792218751063049, 0.9375011281122546], 
             UndirectedEdge[100, 113] -> 
             RGBColor[
              0.20512211761839033`, 0.33292672948331237`, 0.9349927731961636],
              UndirectedEdge[53, 118] -> 
             RGBColor[
              0.5113253166726569, 0.612460273634525, 0.9551410696826135], 
             UndirectedEdge[18, 85] -> 
             RGBColor[
              0.24676983740924385`, 0.376701123601449, 0.9373645492259726], 
             UndirectedEdge[90, 177] -> 
             RGBColor[
              0.22233026933066752`, 0.35101358799275084`, 0.9359727519789987],
              UndirectedEdge[55, 165] -> 
             RGBColor[
              0.2708407078314586, 0.3994925742335291, 0.9388272003702323], 
             UndirectedEdge[9, 121] -> 
             RGBColor[
              0.20533326031636837`, 0.3331486538461075, 0.9350047974604558], 
             UndirectedEdge[70, 110] -> 
             RGBColor[
              0.185588460386286, 0.31239561722696946`, 0.9338803603142515], 
             UndirectedEdge[51, 147] -> 
             RGBColor[
              0.2158606236854452, 0.3442135802203963, 0.9356043152304863], 
             UndirectedEdge[81, 188] -> 
             RGBColor[
              0.3096161145085913, 0.44234452583416967`, 0.9409586377929611], 
             UndirectedEdge[63, 132] -> 
             RGBColor[
              0.24611904809652904`, 0.37601710277136, 0.9373274877373701], 
             UndirectedEdge[68, 143] -> 
             RGBColor[
              0.9083269889752188, 0.8839114383656459, 0.6445270527281901], 
             UndirectedEdge[76, 81] -> 
             RGBColor[
              0.28513916633926595`, 0.41702972106286573`, 0.9395496257462019],
              UndirectedEdge[55, 163] -> 
             RGBColor[
              0.3088204539598367, 0.4394116954694417, 0.9409900907262441], 
             UndirectedEdge[86, 94] -> 
             RGBColor[
              0.19625374198187168`, 0.3236055044018397, 0.9344877323232499], 
             UndirectedEdge[3, 167] -> 
             RGBColor[
              0.3090133882504993, 0.4319576932374843, 0.9412814305798589], 
             UndirectedEdge[16, 82] -> 
             RGBColor[
              0.19957038496874147`, 0.32709150646835083`, 0.9346766102348185],
              UndirectedEdge[51, 107] -> 
             RGBColor[
              0.1999147758321102, 0.3274534831013933, 0.9346962227850067], 
             UndirectedEdge[53, 171] -> 
             RGBColor[
              0.4697666933739579, 0.5763722134005581, 0.9524963620713668], 
             UndirectedEdge[78, 82] -> 
             RGBColor[
              0.1974481944602994, 0.3248609496893285, 0.9345557546248622], 
             UndirectedEdge[92, 186] -> 
             RGBColor[
              0.21375750066891208`, 0.34200306458431906`, 0.9354845454859864],
              UndirectedEdge[75, 118] -> 
             RGBColor[
              0.44650486801296785`, 0.559836113284655, 0.9500381665189955], 
             UndirectedEdge[77, 83] -> 
             RGBColor[
              0.8718524916829569, 0.5391330266655409, 0.5785293580798063], 
             UndirectedEdge[42, 176] -> 
             RGBColor[
              0.21842899524564835`, 0.34691310157433214`, 0.9357505801912747],
              UndirectedEdge[20, 144] -> 
             RGBColor[
              0.19040607844928842`, 0.31745923926581243`, 0.9341547165359123],
              UndirectedEdge[26, 98] -> 
             RGBColor[
              0.24264169185428053`, 0.372362180883637, 0.9371294574436615], 
             UndirectedEdge[16, 84] -> 
             RGBColor[
              0.1842053187530256, 0.3109418476741682, 0.933801592444412], 
             UndirectedEdge[55, 175] -> 
             RGBColor[
              0.4182247539712943, 0.5353839569381427, 0.9482243963930945], 
             UndirectedEdge[113, 128] -> 
             RGBColor[
              0.3178799957707601, 0.44011084120794086`, 0.9418290717409573], 
             UndirectedEdge[142, 147] -> 
             RGBColor[
              0.25576128412159904`, 0.3861517041867828, 0.9378765988145878], 
             UndirectedEdge[10, 42] -> 
             RGBColor[
              0.2103603093846907, 0.3384324011502344, 0.9352910804680441], 
             UndirectedEdge[98, 120] -> 
             RGBColor[
              0.19321962278041294`, 0.32041645274683817`, 0.9343149437233039],
              UndirectedEdge[195, 199] -> 
             RGBColor[
              0.748146282404758, 0.7990537264187598, 0.8410340195093824], 
             UndirectedEdge[49, 195] -> 
             RGBColor[
              0.46169316726810605`, 0.5730216059163575, 0.9509976206498176], 
             UndirectedEdge[25, 43] -> 
             RGBColor[
              0.1846430806166806, 0.3114019631485748, 0.9338265223349365], 
             UndirectedEdge[91, 121] -> 
             RGBColor[
              0.2017936925772753, 0.329428343730764, 0.9348032243140356], 
             UndirectedEdge[8, 21] -> 
             RGBColor[
              0.3222839501803989, 0.4512119268537823, 0.9418428896396724], 
             UndirectedEdge[2, 124] -> 
             RGBColor[
              0.20420540017012767`, 0.331963201321945, 0.9349405674936471], 
             UndirectedEdge[80, 125] -> 
             RGBColor[
              0.243038153837541, 0.3727788875651853, 0.9371520353670952], 
             UndirectedEdge[33, 180] -> 
             RGBColor[
              0.6673282092975037, 0.7309455392481101, 0.857462764837877], 
             UndirectedEdge[5, 155] -> 
             RGBColor[
              0.513762074533002, 0.612974284551854, 0.9559298924776924], 
             UndirectedEdge[179, 192] -> 
             RGBColor[
              0.41712722923071616`, 0.5353797878648794, 0.9478929556641686], 
             UndirectedEdge[59, 146] -> 
             RGBColor[
              0.21481341413912597`, 0.34311289659029465`, 0.935544678196031], 
             UndirectedEdge[3, 68] -> 
             RGBColor[
              0.6898421419054424, 0.7085746089319662, 0.625429383133753], 
             UndirectedEdge[131, 157] -> 
             RGBColor[
              0.19396001666235732`, 0.3211946536604452, 0.9343571080595661], 
             UndirectedEdge[85, 200] -> 
             RGBColor[
              0.23054281786445055`, 0.35964549720740835`, 0.9364404444686207],
              UndirectedEdge[23, 38] -> 
             RGBColor[
              0.20238106508142, 0.3300457094741879, 0.9348366743092069], 
             UndirectedEdge[92, 191] -> 
             RGBColor[
              0.5272753016690297, 0.6129190189586639, 0.9594697403649703], 
             UndirectedEdge[97, 153] -> 
             RGBColor[
              0.24952804077433757`, 0.37960017021835646`, 0.9375216248272185],
              UndirectedEdge[95, 161] -> 
             RGBColor[
              0.26651291559129975`, 0.397452350554246, 0.9384888883211739], 
             UndirectedEdge[139, 196] -> 
             RGBColor[
              0.25932712065835106`, 0.3898996244740037, 0.9380796679301735], 
             UndirectedEdge[1, 94] -> 
             RGBColor[
              0.18516334977200538`, 0.3119487990177908, 0.933856150893663], 
             UndirectedEdge[189, 194] -> 
             RGBColor[
              0.19797673225113377`, 0.32541647641872684`, 0.9345858540701487],
              UndirectedEdge[42, 76] -> 
             RGBColor[
              0.23350932118742207`, 0.36276348028702554`, 0.9366093824443157],
              UndirectedEdge[84, 190] -> 
             RGBColor[
              0.18271061576572617`, 0.30937082006487343`, 0.9337164713205002],
              UndirectedEdge[37, 134] -> 
             RGBColor[
              0.24135977409579584`, 0.37101480404118925`, 0.9370564541237432],
              UndirectedEdge[140, 161] -> 
             RGBColor[
              0.6387756152014612, 0.7023172809495201, 0.7488332700746612], 
             UndirectedEdge[10, 51] -> 
             RGBColor[
              0.20007349461539067`, 0.32762030660597313`, 0.9347052615849112],
              UndirectedEdge[146, 191] -> 
             RGBColor[
              0.527753699812846, 0.6134218457400091, 0.9594969844315341], 
             UndirectedEdge[21, 175] -> 
             RGBColor[
              0.43093748007980026`, 0.5463950813331377, 0.9490344400593063], 
             UndirectedEdge[49, 141] -> 
             RGBColor[
              0.3830851867065078, 0.5062308671290127, 0.9456308272413769], 
             UndirectedEdge[111, 177] -> 
             RGBColor[
              0.21876304030867405`, 0.3472642041152524, 0.9357696035634386], 
             UndirectedEdge[69, 191] -> 
             RGBColor[
              0.5299588162079603, 0.6157395628837288, 0.9596225625480584], 
             UndirectedEdge[111, 175] -> 
             RGBColor[
              0.36035371764762536`, 0.477066388889339, 0.9448368758036116], 
             UndirectedEdge[77, 170] -> 
             RGBColor[
              0.736263484492014, 0.4323498561130519, 0.5652433325739429], 
             UndirectedEdge[104, 154] -> 
             RGBColor[
              0.3494855423442635, 0.47712854394966536`, 0.9434898876136137], 
             UndirectedEdge[13, 138] -> 
             RGBColor[
              0.2214898027052646, 0.35013020428079056`, 0.9359248886480409], 
             UndirectedEdge[21, 67] -> 
             RGBColor[
              0.30859689738128643`, 0.43682596655264533`, 0.9410634322309431],
              UndirectedEdge[73, 197] -> 
             RGBColor[
              0.20909257444253643`, 0.33709993134699245`, 0.9352188848385342],
              UndirectedEdge[67, 192] -> 
             RGBColor[
              0.36080214724091136`, 0.4817069445731053, 0.944482904164054], 
             UndirectedEdge[37, 101] -> 
             RGBColor[
              0.21602037207300215`, 0.3443814859043514, 0.9356134126648311], 
             UndirectedEdge[6, 44] -> 
             RGBColor[
              0.8651034665131747, 0.43792568886884486`, 0.20749020660542072`],
              UndirectedEdge[75, 89] -> 
             RGBColor[
              0.3848285553772075, 0.5026030860222612, 0.9462477862614576], 
             UndirectedEdge[76, 188] -> 
             RGBColor[
              0.288725398337364, 0.42038705859030223`, 0.9397689424120548], 
             UndirectedEdge[42, 71] -> 
             RGBColor[
              0.2832544040591832, 0.40996427332420193`, 0.9396284576905798], 
             UndirectedEdge[6, 192] -> 
             RGBColor[
              0.6485736073804235, 0.40987019823777215`, 0.5644077418055113], 
             UndirectedEdge[2, 100] -> 
             RGBColor[
              0.19408219414375266`, 0.32132306993989135`, 0.9343640658863862],
              UndirectedEdge[7, 8] -> 
             RGBColor[
              0.24587927343278695`, 0.3757650843971754, 0.9373138329249848], 
             UndirectedEdge[69, 92] -> 
             RGBColor[
              0.2471305318648358, 0.3770802363436254, 0.937385090241619], 
             UndirectedEdge[104, 160] -> 
             RGBColor[
              0.4051454853105788, 0.5253383889970118, 0.9470364899612722], 
             UndirectedEdge[17, 30] -> 
             RGBColor[
              0.20051771286008008`, 0.3280872081462052, 0.9347305591567843], 
             UndirectedEdge[88, 164] -> 
             RGBColor[
              0.20586798703479003`, 0.3337106855308008, 0.9350352493560126], 
             UndirectedEdge[43, 60] -> 
             RGBColor[
              0.18536402715025152`, 0.3121597236660082, 0.9338675791734785], 
             UndirectedEdge[149, 197] -> 
             RGBColor[
              0.19310487903170026`, 0.3202958497917673, 0.934308409236563], 
             UndirectedEdge[167, 197] -> 
             RGBColor[
              0.20001986015557813`, 0.327563933388089, 0.9347022071817699], 
             UndirectedEdge[54, 127] -> 
             RGBColor[
              0.9315900923682865, 0.9377519849577597, 0.6986638549616266], 
             UndirectedEdge[107, 147] -> 
             RGBColor[
              0.23357883684934996`, 0.36283654565525925`, 0.9366133412584232],
              UndirectedEdge[78, 113] -> 
             RGBColor[
              0.19369232004858233`, 0.320913287546422, 0.9343418631334333], 
             UndirectedEdge[81, 87] -> 
             RGBColor[
              0.261366444859298, 0.3920430835098213, 0.9381958044265076], 
             UndirectedEdge[83, 179] -> 
             RGBColor[
              0.6474631282319623, 0.7188859236705143, 0.9687723771837091], 
             UndirectedEdge[82, 198] -> 
             RGBColor[
              0.2787942966052594, 0.4069512855983587, 0.9393131360473621], 
             UndirectedEdge[30, 107] -> 
             RGBColor[
              0.21359959388546113`, 0.3418370945430438, 0.935475552928271], 
             UndirectedEdge[47, 134] -> 
             RGBColor[
              0.22156708062371444`, 0.3502114282727843, 0.9359292895111742], 
             UndirectedEdge[5, 142] -> 
             RGBColor[
              0.3081659820767354, 0.43701743485134614`, 0.9410152980549868], 
             UndirectedEdge[169, 190] -> 
             RGBColor[
              0.18813962732028144`, 0.31507705542792475`, 0.9340256454970293],
              UndirectedEdge[121, 152] -> 
             RGBColor[
              0.20876932330272832`, 0.33676017390374813`, 0.9352004761643293],
              UndirectedEdge[31, 64] -> 
             RGBColor[
              0.5807463788000884, 0.6705150984929575, 0.9601376287646749], 
             UndirectedEdge[105, 134] -> 
             RGBColor[
              0.22631486646654955`, 0.35520165222061295`, 0.936199668891204], 
             UndirectedEdge[83, 192] -> 
             RGBColor[
              0.6960500843646674, 0.7606329175254469, 0.9719612946400722], 
             UndirectedEdge[77, 112] -> 
             RGBColor[
              0.8793649622811279, 0.5449759719930563, 0.5741391008123097], 
             UndirectedEdge[195, 196] -> 
             RGBColor[
              0.3670089959605389, 0.4840064187410893, 0.9452208986581658], 
             UndirectedEdge[92, 171] -> 
             RGBColor[
              0.2760986031689815, 0.40752751596608494`, 0.939034779047969], 
             UndirectedEdge[166, 183] -> 
             RGBColor[
              0.8700567296048425, 0.8160449798489104, 0.6243716259282402], 
             UndirectedEdge[139, 195] -> 
             RGBColor[
              0.39334997945867106`, 0.5116924625124413, 0.9467209787003914], 
             UndirectedEdge[177, 190] -> 
             RGBColor[
              0.20078808579481044`, 0.3283713872432409, 0.9347459564954362], 
             UndirectedEdge[29, 149] -> 
             RGBColor[
              0.19620729298920309`, 0.32355668356550876`, 0.9344850871218325],
              UndirectedEdge[119, 155] -> 
             RGBColor[
              0.7600079693502197, 0.5527750998573846, 0.5802673825214153], 
             UndirectedEdge[12, 162] -> 
             RGBColor[
              0.7007570533940699, 0.7026453313085301, 0.614346873451971], 
             UndirectedEdge[85, 173] -> 
             RGBColor[
              0.31911259241838086`, 0.4472823241494562, 0.941684119139965], 
             UndirectedEdge[92, 141] -> 
             RGBColor[
              0.29413145548178377`, 0.42323873581169885`, 0.9401804453350167],
              UndirectedEdge[5, 29] -> 
             RGBColor[
              0.28062241209504013`, 0.4080673964373824, 0.9394467324915896], 
             UndirectedEdge[51, 87] -> 
             RGBColor[
              0.19944978493815407`, 0.3269647481897199, 0.9346697422414884], 
             UndirectedEdge[145, 153] -> 
             RGBColor[
              0.2362249636187789, 0.3656177926640565, 0.9367640342633485], 
             UndirectedEdge[118, 191] -> 
             RGBColor[
              0.6004855108108049, 0.6822749027401551, 0.9639169589656551], 
             UndirectedEdge[117, 164] -> 
             RGBColor[
              0.19024796848068162`, 0.3172930556640557, 0.9341457124071029], 
             UndirectedEdge[145, 185] -> 
             RGBColor[
              0.2111217144827195, 0.33923268618413416`, 0.935334441361979], 
             UndirectedEdge[99, 137] -> 
             RGBColor[
              0.4378565391647805, 0.5509964805640466, 0.9498598035828838], 
             UndirectedEdge[48, 176] -> 
             RGBColor[
              0.2222907628285849, 0.3509720641542051, 0.9359705021421497], 
             UndirectedEdge[50, 144] -> 
             RGBColor[
              0.20111766579178803`, 0.32871779671664314`, 0.9347647255886942],
              UndirectedEdge[3, 53] -> 
             RGBColor[
              0.5252380847939087, 0.6245108141050952, 0.9560275789647218], 
             UndirectedEdge[169, 177] -> 
             RGBColor[
              0.20474146136299756`, 0.33252663562389395`, 0.9349710953855495],
              UndirectedEdge[20, 135] -> 
             RGBColor[
              0.18962988067563263`, 0.3166434061919189, 0.9341105132209843], 
             UndirectedEdge[166, 170] -> 
             RGBColor[
              0.7294686605093437, 0.78858572884784, 0.973670276873511], 
             UndirectedEdge[17, 42] -> 
             RGBColor[
              0.1971197095760292, 0.3245156912488159, 0.9345370478966529], 
             UndirectedEdge[129, 195] -> 
             RGBColor[
              0.47775139397703026`, 0.5868991299424082, 0.952029486276343], 
             UndirectedEdge[74, 93] -> 
             RGBColor[
              0.28865865838495014`, 0.4172909648985178, 0.9398759363681078], 
             UndirectedEdge[37, 45] -> 
             RGBColor[
              0.47344467906469456`, 0.5697056609217193, 0.9542881258612889], 
             UndirectedEdge[49, 92] -> 
             RGBColor[
              0.33340074855062923`, 0.45725182373587436`, 0.9426826499648912],
              UndirectedEdge[163, 177] -> 
             RGBColor[
              0.24957629716502022`, 0.3796508907445958, 0.937524372957279], 
             UndirectedEdge[6, 45] -> 
             RGBColor[
              0.7712380059237092, 0.5084025319316335, 0.5747836939863987], 
             UndirectedEdge[6, 166] -> 
             RGBColor[
              0.8175811907160426, 0.5446061801126542, 0.5794027495448137], 
             UndirectedEdge[65, 127] -> 
             RGBColor[
              0.9155629949478274, 0.8836888220171212, 0.6364016079465316], 
             UndirectedEdge[15, 59] -> 
             RGBColor[
              0.18157500733235693`, 0.30817722359966904`, 0.9336518001002019],
              UndirectedEdge[100, 136] -> 
             RGBColor[
              0.21430154248906313`, 0.3425748870315415, 0.9355155278628062], 
             UndirectedEdge[83, 183] -> 
             RGBColor[
              0.9313850452704695, 0.8648151337796632, 0.6302560397084783], 
             UndirectedEdge[53, 119] -> 
             RGBColor[
              0.7393045339916254, 0.5364394110009786, 0.5783146231887367], 
             UndirectedEdge[5, 68] -> 
             RGBColor[
              0.6576626962859415, 0.680702390522319, 0.6233789373140448], 
             UndirectedEdge[49, 54] -> 
             RGBColor[
              0.7053736220772657, 0.7563760825874686, 0.6787707713186126], 
             UndirectedEdge[153, 185] -> 
             RGBColor[
              0.2571534731580585, 0.38761498313398474`, 0.937955881920655], 
             UndirectedEdge[101, 144] -> 
             RGBColor[
              0.19734151181877715`, 0.32474881946901846`, 0.9345496792062504],
              UndirectedEdge[19, 102] -> 
             RGBColor[
              0.6601961515617699, 0.7275798880657995, 0.9403309800746991], 
             UndirectedEdge[102, 172] -> 
             RGBColor[
              0.9192581959222914, 0.7380602445354411, 0.5748744102551196], 
             UndirectedEdge[102, 140] -> 
             RGBColor[
              0.981449443808876, 0.9827573994159884, 0.747626675734739], 
             UndirectedEdge[71, 107] -> 
             RGBColor[
              0.2906858024537879, 0.41777514421480366`, 0.9400516648353837], 
             UndirectedEdge[5, 168] -> 
             RGBColor[
              0.2818657379269033, 0.4093742107180814, 0.9395175380583785], 
             UndirectedEdge[79, 122] -> 
             RGBColor[
              0.2360507899414387, 0.3654347250859229, 0.9367541153300909], 
             UndirectedEdge[136, 198] -> 
             RGBColor[
              0.2842178470642151, 0.4126517810036814, 0.9396219992225757], 
             UndirectedEdge[97, 135] -> 
             RGBColor[
              0.20686780943909605`, 0.33476156227012827`, 0.9350921877628332],
              UndirectedEdge[19, 164] -> 
             RGBColor[
              0.2731949072578401, 0.40054884518181094`, 0.9390131936672395], 
             UndirectedEdge[118, 139] -> 
             RGBColor[
              0.33826776988296947`, 0.4652785641134494, 0.9428532266161497], 
             UndirectedEdge[26, 137] -> 
             RGBColor[
              0.3083373002531643, 0.4400120442459969, 0.9409220001603581], 
             UndirectedEdge[142, 168] -> 
             RGBColor[
              0.23569763939068106`, 0.3650635414660385, 0.9367340039286646], 
             UndirectedEdge[3, 194] -> 
             RGBColor[
              0.3101074606435417, 0.43310763269076813`, 0.9413437363841075], 
             UndirectedEdge[65, 195] -> 
             RGBColor[
              0.7286852121495595, 0.7350905705099995, 0.6193731130820839], 
             UndirectedEdge[73, 107] -> 
             RGBColor[
              0.21755611110948542`, 0.34599564500317415`, 0.9357008707310365],
              UndirectedEdge[162, 172] -> 
             RGBColor[
              0.6603763668123606, 0.5325003847582571, 0.5813358018320983], 
             UndirectedEdge[68, 140] -> 
             RGBColor[
              0.977357275935254, 0.934529823363472, 0.4305753131856688], 
             UndirectedEdge[38, 165] -> 
             RGBColor[
              0.19346381204820906`, 0.3206731111497857, 0.9343288499408593], 
             UndirectedEdge[86, 92] -> 
             RGBColor[
              0.22327186579105107`, 0.35200326557327766`, 0.9360263745044504],
              UndirectedEdge[90, 115] -> 
             RGBColor[
              0.27114794471103404`, 0.4017434985665935, 0.9387741035720105], 
             UndirectedEdge[11, 70] -> 
             RGBColor[
              0.19700340773557554`, 0.3243934506405365, 0.9345304246788922], 
             UndirectedEdge[54, 123] -> 
             RGBColor[
              0.7197585780581139, 0.7688356084491694, 0.6796873679935951], 
             UndirectedEdge[107, 176] -> 
             RGBColor[
              0.22586039364025307`, 0.35472397246493387`, 0.9361737873360787],
              UndirectedEdge[30, 76] -> 
             RGBColor[
              0.23690732447147297`, 0.36633499718441476`, 0.936802893704447], 
             UndirectedEdge[129, 191] -> 
             RGBColor[
              0.632287259602678, 0.7097886743020284, 0.965951987897856], 
             UndirectedEdge[7, 125] -> 
             RGBColor[
              0.2363887212836201, 0.36578991235264013`, 0.9367733600201034], 
             UndirectedEdge[3, 155] -> 
             RGBColor[
              0.545941520152503, 0.6408465029615011, 0.9579803382974005], 
             UndirectedEdge[54, 118] -> 
             RGBColor[
              0.6896300999943169, 0.7427398350516461, 0.6777676080129371], 
             UndirectedEdge[4, 171] -> 
             RGBColor[
              0.3210288697535419, 0.4523887348957585, 0.9416800247158792], 
             UndirectedEdge[167, 189] -> 
             RGBColor[
              0.19688265985809134`, 0.32426653696544305`, 0.9345235482659], 
             UndirectedEdge[42, 81] -> 
             RGBColor[
              0.25440003735864936`, 0.3847209475308929, 0.9377990778252221], 
             UndirectedEdge[5, 129] -> 
             RGBColor[
              0.40440250690307966`, 0.5246635536043394, 0.9469977976545015], 
             UndirectedEdge[115, 133] -> 
             RGBColor[
              0.2820742314375166, 0.41322771868271746`, 0.939396339437091], 
             UndirectedEdge[92, 146] -> 
             RGBColor[
              0.24492541546972163`, 0.3747625191999059, 0.9372595121250946], 
             UndirectedEdge[65, 151] -> 
             RGBColor[
              0.9751208756473086, 0.9280643537313567, 0.5177938016500871], 
             UndirectedEdge[45, 156] -> 
             RGBColor[
              0.7648803283778755, 0.4595346363622902, 0.5686955747885385], 
             UndirectedEdge[74, 172] -> 
             RGBColor[
              0.607635645662135, 0.48681902292365303`, 0.5779752097171944], 
             UndirectedEdge[31, 138] -> 
             RGBColor[
              0.3769176966090809, 0.4907215889641815, 0.9461219362207016], 
             UndirectedEdge[116, 198] -> 
             RGBColor[
              0.29312560612523564`, 0.42201440056135886`, 0.9401292829232522],
              UndirectedEdge[42, 142] -> 
             RGBColor[
              0.23238403787365935`, 0.361580736177178, 0.9365452992243044], 
             UndirectedEdge[10, 129] -> 
             RGBColor[
              0.3362106798778888, 0.4572045493253528, 0.9429600447685274], 
             UndirectedEdge[3, 141] -> 
             RGBColor[
              0.38125443274481086`, 0.5046451600637603, 0.9455141732178098], 
             UndirectedEdge[161, 162] -> 
             RGBColor[
              0.3676199899888237, 0.4905318508026293, 0.94472975345843], 
             UndirectedEdge[6, 77] -> 
             RGBColor[
              0.8243760146987129, 0.18837030737786614`, 0.17097580524524553`],
              UndirectedEdge[98, 113] -> 
             RGBColor[
              0.19847726376767427`, 0.32594256677814204`, 0.9346143585995457],
              UndirectedEdge[3, 139] -> 
             RGBColor[
              0.3521805380042213, 0.47732910458401956`, 0.943739735898258], 
             UndirectedEdge[34, 138] -> 
             RGBColor[
              0.32596539118379714`, 0.4487246258382862, 0.9422852932438326], 
             UndirectedEdge[22, 72] -> 
             RGBColor[
              0.22084536933385682`, 0.34945286394800523`, 0.935888189120893], 
             UndirectedEdge[34, 40] -> 
             RGBColor[
              0.4679436932956409, 0.5783052104909272, 0.9514318973025666], 
             UndirectedEdge[41, 74] -> 
             RGBColor[
              0.31831841781976944`, 0.44846525260187575`, 0.9415650157902389],
              UndirectedEdge[141, 146] -> 
             RGBColor[
              0.2946098536256002, 0.4237415625930442, 0.9402076894015805], 
             UndirectedEdge[90, 111] -> 
             RGBColor[
              0.22370338980181498`, 0.3524568246687931, 0.9360509491584807], 
             UndirectedEdge[66, 82] -> 
             RGBColor[
              0.1977556445101682, 0.32518409918519964`, 0.9345732634503707], 
             UndirectedEdge[119, 151] -> 
             RGBColor[
              0.9203645260018751, 0.6763382789683456, 0.4715886994182685], 
             UndirectedEdge[4, 139] -> 
             RGBColor[
              0.30998782732575464`, 0.44078389926163164`, 0.9410512536833753],
              UndirectedEdge[165, 175] -> 
             RGBColor[
              0.35318722837559335`, 0.4695339542827697, 0.9444287548414402], 
             UndirectedEdge[127, 139] -> 
             RGBColor[
              0.5802277622569392, 0.660290714019563, 0.9637494735648391], 
             UndirectedEdge[85, 117] -> 
             RGBColor[
              0.22789736538652144`, 0.3568649589217301, 0.9362897898635989], 
             UndirectedEdge[141, 155] -> 
             RGBColor[
              0.5085029810453545, 0.6084191221025781, 0.9555947876910933], 
             UndirectedEdge[168, 189] -> 
             RGBColor[
              0.2019144551539962, 0.3295552728556873, 0.9348101015641277], 
             UndirectedEdge[24, 175] -> 
             RGBColor[
              0.3788592562848471, 0.49651688331597643`, 0.9458907388525104], 
             UndirectedEdge[106, 176] -> 
             RGBColor[
              0.20955893430915817`, 0.33759010513573523`, 0.9352454433430207],
              UndirectedEdge[40, 53] -> 
             RGBColor[
              0.5688067096740002, 0.6608219372204345, 0.9591976942746201], 
             UndirectedEdge[27, 155] -> 
             RGBColor[
              0.4698552775688525, 0.57104038662686, 0.953275136127212], 
             UndirectedEdge[33, 77] -> 
             RGBColor[
              0.9049712712883817, 0.5626723297681262, 0.46806425968515003`], 
             UndirectedEdge[67, 137] -> 
             RGBColor[
              0.289891245032081, 0.42062407066118745`, 0.9398715246040107], 
             UndirectedEdge[68, 129] -> 
             RGBColor[
              0.7077311225760636, 0.7240378400232692, 0.6265779027838456], 
             UndirectedEdge[137, 192] -> 
             RGBColor[
              0.3948032831545909, 0.5160439078078941, 0.9464704935604884], 
             UndirectedEdge[58, 128] -> 
             RGBColor[
              0.695941652480456, 0.7590582933299347, 0.9501605185766638], 
             UndirectedEdge[55, 90] -> 
             RGBColor[
              0.281574426125484, 0.41077439271759675`, 0.9394384697479637], 
             UndirectedEdge[26, 82] -> 
             RGBColor[
              0.2523736658856789, 0.382591102633429, 0.9376836789675842], 
             UndirectedEdge[43, 165] -> 
             RGBColor[
              0.19777525937960444`, 0.32520471565663167`, 0.9345743804881674],
              UndirectedEdge[123, 199] -> 
             RGBColor[
              0.7231925508928534, 0.7787356014172913, 0.8390860274057987], 
             UndirectedEdge[34, 45] -> 
             RGBColor[
              0.5705500737145661, 0.6605535414680137, 0.960228808821763], 
             UndirectedEdge[133, 178] -> 
             RGBColor[
              0.21638528695668868`, 0.3447650345840459, 0.9356341940276138], 
             UndirectedEdge[29, 189] -> 
             RGBColor[
              0.20067112932213305`, 0.3282484585749883, 0.9347392959973388], 
             UndirectedEdge[91, 164] -> 
             RGBColor[
              0.19070376679969833`, 0.3177721285966248, 0.9341716694470776], 
             UndirectedEdge[116, 124] -> 
             RGBColor[
              0.2333325075764587, 0.3625776379712726, 0.9365993131707435], 
             UndirectedEdge[80, 113] -> 
             RGBColor[
              0.2131232803220724, 0.34133645878789803`, 0.9354484275754789], 
             UndirectedEdge[10, 75] -> 
             RGBColor[
              0.3600463634895279, 0.4765554310665914, 0.9448364770954216], 
             UndirectedEdge[74, 180] -> 
             RGBColor[
              0.34398171160205027`, 0.4723614023913367, 0.9431391883855662], 
             UndirectedEdge[27, 149] -> 
             RGBColor[
              0.2260121645429709, 0.35488349330652136`, 0.9361824304644635], 
             UndirectedEdge[4, 49] -> 
             RGBColor[
              0.37833101513518963`, 0.5021130426655478, 0.9453278956328015], 
             UndirectedEdge[9, 152] -> 
             RGBColor[
              0.19674957296563292`, 0.32412665420327286`, 0.9345159691642588],
              UndirectedEdge[19, 85] -> 
             RGBColor[
              0.31084430416368, 0.44012074843948534`, 0.9411572711237357], 
             UndirectedEdge[189, 197] -> 
             RGBColor[
              0.19756871536463022`, 0.3249876248012469, 0.9345626181120692], 
             UndirectedEdge[69, 195] -> 
             RGBColor[
              0.3754229505823126, 0.4928500185241086, 0.9457000609265455], 
             UndirectedEdge[75, 191] -> 
             RGBColor[
              0.656122943214317, 0.729139556043267, 0.9678284202247502], 
             UndirectedEdge[73, 75] -> 
             RGBColor[
              0.3598107668197179, 0.47630780402892936`, 0.9448230602136101], 
             UndirectedEdge[68, 188] -> 
             RGBColor[
              0.6370968292328074, 0.6628892701514275, 0.6220684984511013], 
             UndirectedEdge[4, 123] -> 
             RGBColor[
              0.39271597111603795`, 0.5145725685272486, 0.946244492307784], 
             UndirectedEdge[7, 84] -> 
             RGBColor[
              0.19486465596415276`, 0.32214548692407674`, 0.9344086259295095],
              UndirectedEdge[171, 195] -> 
             RGBColor[
              0.4043910218864583, 0.5232972981465681, 0.9473497497328954], 
             UndirectedEdge[62, 167] -> 
             RGBColor[
              0.19961760381417978`, 0.3271411364687542, 0.9346792992782123], 
             UndirectedEdge[91, 152] -> 
             RGBColor[
              0.19321000522653986`, 0.3204063440879294, 0.9343143960178388], 
             UndirectedEdge[38, 90] -> 
             RGBColor[
              0.20419753034223448`, 0.33195492963385337`, 0.9349401193185908],
              UndirectedEdge[3, 118] -> 
             RGBColor[
              0.40478020373070756`, 0.5250220004521133, 0.9470132145420087], 
             UndirectedEdge[143, 181] -> 
             RGBColor[
              0.6469177981644729, 0.7208456508308313, 0.967618016283176], 
             UndirectedEdge[20, 50] -> 
             RGBColor[
              0.19303508907013, 0.32022249611721776`, 0.9343044348014965], 
             UndirectedEdge[128, 136] -> 
             RGBColor[
              0.3270594206414329, 0.44975899875617, 0.9423518264076001], 
             UndirectedEdge[19, 161] -> 
             RGBColor[
              0.3175223229543551, 0.44713976959933127`, 0.9415375744146212], 
             UndirectedEdge[19, 140] -> 
             RGBColor[
              0.6724699476644765, 0.7338054584355065, 0.7508958882679089], 
             UndirectedEdge[39, 159] -> 
             RGBColor[
              0.25347717812255377`, 0.3837509639611013, 0.9377465223569743], 
             UndirectedEdge[87, 154] -> 
             RGBColor[
              0.2742869255202454, 0.40348527807603907`, 0.9390098911632051], 
             UndirectedEdge[104, 143] -> 
             RGBColor[
              0.6113814534238254, 0.6900658551251025, 0.9653536718198579], 
             UndirectedEdge[6, 183] -> 
             RGBColor[
              0.8839085682862255, 0.5140524144919886, 0.22270248687391753`], 
             UndirectedEdge[17, 89] -> 
             RGBColor[
              0.229492018641594, 0.35854104059966735`, 0.9363806030073972], 
             UndirectedEdge[131, 176] -> 
             RGBColor[
              0.20779145347843028`, 0.335732370717883, 0.9351447879244643], 
             UndirectedEdge[44, 143] -> 
             RGBColor[
              0.8772182848102179, 0.7604919813860003, 0.611670932866671], 
             UndirectedEdge[140, 173] -> 
             RGBColor[
              0.6807382359191774, 0.7409670341454773, 0.7514227362841381], 
             UndirectedEdge[123, 195] -> 
             RGBColor[
              0.4760781232489544, 0.5854811317780583, 0.9519142173248001], 
             UndirectedEdge[96, 125] -> 
             RGBColor[
              0.600349784053201, 0.6736043813543324, 0.9654382177461185], 
             UndirectedEdge[95, 159] -> 
             RGBColor[
              0.2520449781686508, 0.3822456310028275, 0.9376649606883494], 
             UndirectedEdge[171, 191] -> 
             RGBColor[
              0.558926887512106, 0.6461868425061883, 0.9612722513544084], 
             UndirectedEdge[124, 187] -> 
             RGBColor[
              0.21475919139226923`, 0.3430559050454275, 0.935541590290813], 
             UndirectedEdge[54, 191] -> 
             RGBColor[
              0.899248175195666, 0.9120432778102582, 0.6955578617186919], 
             UndirectedEdge[24, 55] -> 
             RGBColor[
              0.29651273574071235`, 0.4264755032667358, 0.9402891843813024], 
             UndirectedEdge[61, 126] -> 
             RGBColor[
              0.19350305800530745`, 0.3207143611390335, 0.9343310849400568], 
             UndirectedEdge[46, 101] -> 
             RGBColor[
              0.18958670352767176`, 0.3165980242718227, 0.9341080543462827], 
             UndirectedEdge[158, 176] -> 
             RGBColor[
              0.27521608284831744`, 0.40589741017048, 0.9390102435558715], 
             UndirectedEdge[91, 200] -> 
             RGBColor[
              0.18842402865999922`, 0.3153759792680545, 0.9340418417325922], 
             UndirectedEdge[29, 129] -> 
             RGBColor[
              0.33069083838516217`, 0.4514028459383327, 0.9426456979613903], 
             UndirectedEdge[37, 47] -> 
             RGBColor[
              0.21605368220731502`, 0.34441649696749876`, 0.9356153096277022],
              UndirectedEdge[25, 38] -> 
             RGBColor[
              0.18033163328528526`, 0.30687035864172885`, 0.9335809917876283],
              UndirectedEdge[95, 173] -> 
             RGBColor[
              0.308475536309016, 0.4361021037502032, 0.9410783545306509], 
             UndirectedEdge[86, 174] -> 
             RGBColor[
              0.19606494632876875`, 0.3234070682000927, 0.9344769806901039], 
             UndirectedEdge[4, 146] -> 
             RGBColor[
              0.289855682054282, 0.41962373812957937`, 0.9399047577930049], 
             UndirectedEdge[114, 186] -> 
             RGBColor[
              0.18224157379578187`, 0.3088778272154834, 0.9336897600741974], 
             UndirectedEdge[155, 199] -> 
             RGBColor[
              0.8342253892508518, 0.868464330529156, 0.8481333911805324], 
             UndirectedEdge[114, 194] -> 
             RGBColor[
              0.19146855650738448`, 0.3185759710698711, 0.9342152230895253], 
             UndirectedEdge[59, 186] -> 
             RGBColor[
              0.18364549933831636`, 0.3103534419747078, 0.9337697115569229], 
             UndirectedEdge[99, 193] -> 
             RGBColor[
              0.3906410080149175, 0.5027703500949796, 0.9471196739266945], 
             UndirectedEdge[109, 136] -> 
             RGBColor[
              0.22011061631709428`, 0.3486805919413559, 0.935846346023558], 
             UndirectedEdge[50, 134] -> 
             RGBColor[
              0.22530992446241244`, 0.3541453944572617, 0.9361424389307468], 
             UndirectedEdge[112, 183] -> 
             RGBColor[
              0.9388975158686406, 0.8706580791071786, 0.6258657824409817], 
             UndirectedEdge[42, 73] -> 
             RGBColor[
              0.2101247127148807, 0.3381847741125724, 0.9352776635862325], 
             UndirectedEdge[42, 147] -> 
             RGBColor[
              0.22614743845474522`, 0.3550256747646575, 0.9361901341136192], 
             UndirectedEdge[87, 131] -> 
             RGBColor[
              0.19909905794023608`, 0.326596111877532, 0.934649768857811], 
             UndirectedEdge[1, 11] -> 
             RGBColor[
              0.19143609648975546`, 0.318541853533259, 0.9342133745395418], 
             UndirectedEdge[30, 81] -> 
             RGBColor[
              0.2577980406427003, 0.3882924644282822, 0.9379925890853533], 
             UndirectedEdge[154, 188] -> 
             RGBColor[
              0.3225365951695387, 0.45378672040038737`, 0.9417727245296585], 
             UndirectedEdge[83, 156] -> 
             RGBColor[
              0.8725518288358358, 0.5445084384740636, 0.5791990441271917], 
             UndirectedEdge[5, 107] -> 
             RGBColor[
              0.28598353480448624`, 0.4137022763198226, 0.9397520404988222], 
             UndirectedEdge[93, 180] -> 
             RGBColor[
              0.28670982280114365`, 0.41560298146714914`, 0.9397517582879953],
              UndirectedEdge[10, 17] -> 
             RGBColor[
              0.2047098267539144, 0.3324933856439975, 0.9349692938413614], 
             UndirectedEdge[75, 141] -> 
             RGBColor[
              0.42297909702707115`, 0.5394592728963019, 0.9485391251947967], 
             UndirectedEdge[123, 141] -> 
             RGBColor[
              0.39747014268735614`, 0.5186903929907134, 0.9465474239163595], 
             UndirectedEdge[40, 119] -> 
             RGBColor[
              0.6763280459297676, 0.4853122609339061, 0.5733568833580303], 
             UndirectedEdge[16, 80] -> 
             RGBColor[
              0.20448442749174123`, 0.3322564767283148, 0.934956457686829], 
             UndirectedEdge[88, 180] -> 
             RGBColor[
              0.279297845494757, 0.4078125233716327, 0.9393296571454344], 
             UndirectedEdge[24, 41] -> 
             RGBColor[
              0.2739267632539736, 0.4052447745128077, 0.9389110959777585], 
             UndirectedEdge[4, 119] -> 
             RGBColor[
              0.5905667103712094, 0.4124559324961789, 0.5674982858332491], 
             UndirectedEdge[99, 136] -> 
             RGBColor[
              0.3873164552562508, 0.49927603435680146`, 0.9469303455653235], 
             UndirectedEdge[10, 194] -> 
             RGBColor[
              0.20973618799885002`, 0.33777641000213443`, 0.9352555376784253],
              UndirectedEdge[96, 102] -> 
             RGBColor[
              0.9527960526971394, 0.9643159539076722, 0.964788149409247], 
             UndirectedEdge[9, 88] -> 
             RGBColor[
              0.20493816247527158`, 0.3327333809644648, 0.9349822972229003], 
             UndirectedEdge[55, 108] -> 
             RGBColor[
              0.3219524714198415, 0.4532142784379034, 0.9417379396935124], 
             UndirectedEdge[62, 197] -> 
             RGBColor[
              0.20030365932071864`, 0.327862224304558, 0.9347183691243814], 
             UndirectedEdge[147, 168] -> 
             RGBColor[
              0.22946103997176695`, 0.35850848005351804`, 0.9363788388179795],
              UndirectedEdge[51, 106] -> 
             RGBColor[
              0.1836133165010153, 0.31031961577219463`, 0.9337678787919488], 
             UndirectedEdge[123, 155] -> 
             RGBColor[
              0.5621572300950483, 0.6548917358884543, 0.9590135889959501], 
             UndirectedEdge[75, 142] -> 
             RGBColor[
              0.3820700919784965, 0.49970376609353495`, 0.9460906958516819], 
             UndirectedEdge[31, 182] -> 
             RGBColor[
              0.43639733566624106`, 0.5502718081152633, 0.9496178373615334], 
             UndirectedEdge[65, 140] -> 
             RGBColor[
              0.9750309047249213, 0.9266824270130837, 0.4215378003318664]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 71 -> 
             RGBColor[
              0.3637386159115608, 0.4894738398933511, 0.9443980808578237], 10 -> 
             RGBColor[
              0.2179504265625759, 0.34641009554541596`, 0.9357233264127526], 
             68 -> RGBColor[
              0.9609913119589255, 0.8800766769412489, 0.30295904244338884`], 
             155 -> RGBColor[
              0.6731900684530466, 0.744620465000319, 0.9680609527706839], 132 -> 
             RGBColor[
              0.30056549504747376`, 0.4332437706209237, 0.9404281323449262], 
             26 -> RGBColor[
              0.2927822195605681, 0.4250630545960175, 0.9399848863202711], 29 -> 
             RGBColor[
              0.20691074357712266`, 0.33480668877137576`, 0.9350946327984784],
              113 -> RGBColor[
              0.20445336338735556`, 0.33222382638502757`, 0.9349546886320393],
              50 -> RGBColor[
              0.20374667641262958`, 0.33148105356804847`, 0.9349144438542785],
              173 -> RGBColor[
              0.36775323192677223`, 0.4929510985052593, 0.9446538886403275], 
             192 -> 
             RGBColor[
              0.46571418536342124`, 0.577126781719812, 0.9510818731205317], 
             165 -> RGBColor[
              0.2058031822357576, 0.33364257157815613`, 0.9350315588185778], 
             92 -> RGBColor[
              0.2444470173259052, 0.37425969241856055`, 0.9372322680585309], 
             11 -> RGBColor[
              0.20295626314304663`, 0.3306502791066209, 0.9348694309878873], 
             137 -> RGBColor[
              0.32389238094576056`, 0.45496103389597625`, 0.9418591140004451],
              120 -> RGBColor[
              0.1939380814128329, 0.3211715983224198, 0.934355858879556], 51 -> 
             RGBColor[
              0.18219656266820544`, 0.3088305176665303, 0.9336871967570698], 
             72 -> RGBColor[
              0.2532013109542942, 0.38346101007627187`, 0.9377308121298508], 
             64 -> RGBColor[
              0.6295309817704698, 0.7101206369056319, 0.9639781314143923], 41 -> 
             RGBColor[
              0.29070628845368207`, 0.422881119381046, 0.9398666651147989], 
             103 -> RGBColor[
              0.1810808656124072, 0.3076578493216073, 0.933623659460268], 162 -> 
             RGBColor[
              0.4514119894863078, 0.5654121094919137, 0.9499845506954865], 
             196 -> RGBColor[
              0.23298613716021888`, 0.3622135807026517, 0.9365795878879478], 
             179 -> RGBColor[
              0.3685402730980111, 0.49363279400994686`, 0.9447040382078057], 
             160 -> RGBColor[
              0.44319072976501883`, 0.5582912675338615, 0.9494606992958204], 
             123 -> RGBColor[
              0.4511243917370499, 0.5651630067765897, 0.9499662252212164], 
             150 -> RGBColor[
              0.19256204953176445`, 0.3197253015699566, 0.9342774958995859], 
             188 -> RGBColor[
              0.31320234650668927`, 0.4457018633616062, 0.9411779544588138], 
             46 -> RGBColor[
              0.18297903858873563`, 0.3096529494708463, 0.9337317576031746], 
             182 -> RGBColor[
              0.34083289550277507`, 0.46963405615024345`, 0.9429385486081092],
              6 -> RGBColor[
              0.8314330293974257, 0.24261361475573226`, 0.17773361049049105`],
              131 -> RGBColor[
              0.1814951086723694, 0.3080932450421545, 0.9336472499897152], 45 -> 
             RGBColor[
              0.7110429824499928, 0.7741914491075349, 0.9718337774823064], 
             195 -> RGBColor[
              0.5010318547608589, 0.6057992567795268, 0.9538622094283838], 
             148 -> 
             RGBColor[
              0.19357697366818166`, 0.320792051187238, 0.9343352943277091], 
             161 -> RGBColor[
              0.2838279904913397, 0.4156515921133449, 0.9394749562213734], 1 -> 
             RGBColor[
              0.17991592983646426`, 0.30643342795989703`, 0.9335573180911961],
              101 -> RGBColor[
              0.19619436846660787`, 0.3235430990727991, 0.9344843510893909], 
             12 -> RGBColor[
              0.950102117301832, 0.8398785531251466, 0.2787091962084557], 39 -> 
             RGBColor[
              0.25206224059906557`, 0.3822637749116947, 0.9376659437582241], 
             48 -> RGBColor[
              0.21049372737267863`, 0.3385726319147987, 0.9352986784250858], 
             77 -> RGBColor[0.817319, 0.134127, 0.164218], 56 -> 
             RGBColor[
              0.1825695689347496, 0.30922257090263144`, 0.9337084389121362], 
             110 -> RGBColor[
              0.18012636844446756`, 0.30665461227948687`, 0.9335693022586058],
              73 -> RGBColor[
              0.21747923322295587`, 0.34591484147009205`, 0.9356964926491292],
              37 -> RGBColor[
              0.23584637567939642`, 0.36521987273590373`, 0.9367424742402714],
              130 -> RGBColor[
              0.1842953386135795, 0.3110364642551991, 0.933806718942298], 107 -> 
             RGBColor[
              0.21763298899601496`, 0.34607644853625624`, 0.9357052488129437],
              59 -> RGBColor[
              0.18422301466471383`, 0.3109604471993381, 0.9338026002004038], 
             47 -> RGBColor[
              0.1962609887352336, 0.32361312119909375`, 0.9344881450151332], 
             159 -> RGBColor[
              0.2548921156460419, 0.3852381530105079, 0.9378271009557244], 55 -> 
             RGBColor[
              0.33587823342715956`, 0.465342576888902, 0.9426228419218866], 
             49 -> RGBColor[
              0.4223544797753533, 0.5402439550531881, 0.9481330318712514], 82 -> 
             RGBColor[
              0.21196511221078973`, 0.3401191506708405, 0.9353824716148974], 
             199 -> RGBColor[
              0.995260710048657, 0.9923081960579929, 0.7282058295903809], 89 -> 
             RGBColor[
              0.2675148103379351, 0.39850540545675567`, 0.9385459447448243], 
             144 -> RGBColor[
              0.19848865517094644`, 0.32595453986523776`, 0.93461500732311], 
             78 -> RGBColor[
              0.18293127670980908`, 0.3096027487078165, 0.9337290376348271], 
             42 -> RGBColor[
              0.2027701922068055, 0.3304547067550528, 0.9348588345233357], 
             154 -> RGBColor[
              0.33187084383238813`, 0.46187157743916857`, 0.9423674946005033],
              168 -> RGBColor[
              0.20939739524084894`, 0.3374203173327738, 0.9352362439320562], 
             121 -> RGBColor[
              0.21735301065346377`, 0.34578217354658275`, 0.9356893044605262],
              128 -> RGBColor[
              0.43130662815416465`, 0.5479978560308542, 0.9487034548498753], 
             115 -> RGBColor[
              0.31502527059825963`, 0.4472807885868956, 0.9412941095699802], 
             61 -> RGBColor[
              0.2073405252862433, 0.3352584165973958, 0.9351191082310077], 93 -> 
             RGBColor[
              0.23138676958404353`, 0.3605325439743302, 0.9364885062705369], 
             88 -> RGBColor[
              0.21656281497127022`, 0.34495162778329735`, 0.9356443039854151],
              21 -> RGBColor[
              0.36130368564417137`, 0.48736482567889206`, 0.94424292925431], 
             62 -> RGBColor[
              0.1999014029793203, 0.32743942738522325`, 0.9346954612208237], 
             136 -> RGBColor[
              0.22281221312870114`, 0.35152014148148586`, 0.9360001979653247],
              190 -> RGBColor[
              0.1841862517520943, 0.3109218070472717, 0.933800506606916], 57 -> 
             RGBColor[
              0.1818396285304826, 0.30845535725685214`, 0.9336668698859633], 
             111 -> RGBColor[
              0.2201361607798215, 0.3487074407912947, 0.9358478007429207], 63 -> 
             RGBColor[
              0.19167260114558432`, 0.31879043492179643`, 0.9342268431298139],
              75 -> RGBColor[
              0.5021423004164799, 0.6067007665877667, 0.9539496277780908], 30 -> 
             RGBColor[
              0.2095661987749073, 0.33759774054983127`, 0.9352458570435983], 
             5 -> RGBColor[
              0.35433408061295757`, 0.481328104103389, 0.9437988321847008], 
             171 -> RGBColor[
              0.30775018901205775`, 0.44079533951360933`, 0.940837290037407], 
             102 -> RGBColor[
              0.9691756477061694, 0.9765318290462814, 0.9370617675415293], 31 -> 
             RGBColor[
              0.531961775829707, 0.6309095600802831, 0.9562971261149575], 96 -> 
             RGBColor[
              0.9364164576881094, 0.9521000787690629, 0.9925145312769647], 70 -> 
             RGBColor[
              0.19105055232810444`, 0.31813662217445204`, 0.9341914183698972],
              52 -> 
             RGBColor[
              0.18558886593634766`, 0.31239604348579764`, 0.9338803834097276],
              183 -> RGBColor[
              0.9363841071750253, 0.7854912142282449, 0.26767136325734403`], 
             158 -> RGBColor[
              0.3163443674121438, 0.4484233239473484, 0.9413781612525294], 13 -> 
             RGBColor[
              0.22110598802207443`, 0.3497267907135012, 0.9359030309696362], 
             170 -> RGBColor[
              0.6552079689840278, 0.7305727122261038, 0.9662686651478858], 86 -> 
             RGBColor[
              0.2020967142561969, 0.3297468387279948, 0.9348204809503698], 18 -> 
             RGBColor[
              0.22306772190849825`, 0.3517886974092449, 0.9360147488123428], 
             153 -> RGBColor[
              0.2822567222941179, 0.41400008961390705`, 0.9393854748220246], 
             58 -> RGBColor[
              0.9605766768067475, 0.9701187306290152, 0.9516175823034524], 22 -> 
             RGBColor[
              0.18848942771341942`, 0.31544471781973865`, 0.9340455661119352],
              66 -> RGBColor[
              0.18354617680954663`, 0.31024904769955874`, 0.9337640552858439],
              143 -> RGBColor[
              0.8556626659915121, 0.887746199790043, 0.9860950630129915], 119 -> 
             RGBColor[
              0.8468258702473929, 0.3609297347144502, 0.19247381227214683`], 
             145 -> RGBColor[
              0.1901932049434399, 0.31723549571420584`, 0.9341425937046723], 
             91 -> RGBColor[
              0.18623437450108682`, 0.31307451391494534`, 0.9339171441675451],
              177 -> RGBColor[
              0.21738991983752656`, 0.34582096743921015`, 0.9356914063839564],
              200 -> RGBColor[
              0.1906136828189116, 0.3176774446211637, 0.9341665392976392], 
             114 -> RGBColor[
              0.18141516357964482`, 0.30800921768088935`, 0.9336426972349526],
              24 -> RGBColor[
              0.2571472380542651, 0.3876084296445695, 0.9379555268407181], 
             176 -> RGBColor[
              0.23408779828449117`, 0.3633714963936115, 0.9366423258592136], 
             79 -> RGBColor[
              0.1941778278429074, 0.3214235870212298, 0.9343695120840757], 
             109 -> RGBColor[
              0.21740901950548744`, 0.34584104240122593`, 0.9356924940817913],
              135 -> RGBColor[
              0.1969362596236349, 0.3243228737174507, 0.934526600693254], 108 -> 
             RGBColor[
              0.3080267094125234, 0.4410859799869048, 0.9408530374651383], 
             191 -> 
             RGBColor[
              0.8101035860121542, 0.8515783454987672, 0.9817072126714098], 14 -> 
             RGBColor[
              0.17925722738073346`, 0.3057410899147761, 0.9335198059608052], 
             185 -> RGBColor[
              0.2320502240219991, 0.3612298766540624, 0.9365262890192856], 32 -> 
             RGBColor[
              0.186006868294159, 0.3128353904667376, 0.9339041880256258], 122 -> 
             RGBColor[
              0.27792375203997, 0.40944586315061604`, 0.939138718576106], 187 -> 
             RGBColor[
              0.20348109888236326`, 0.33120191474515054`, 0.9348993196068165],
              193 -> RGBColor[
              0.22946131864603458`, 0.3585087729578423, 0.9363788546880667], 
             100 -> RGBColor[
              0.20579087184942513`, 0.3336296325815971, 0.9350308577602878], 
             180 -> RGBColor[
              0.3420328760182438, 0.47067341895996806`, 0.9430150103054538], 
             7 -> RGBColor[
              0.20849433214894747`, 0.33647114076567824`, 0.9351848158249345],
              175 -> RGBColor[
              0.5005712745154292, 0.6054253369873833, 0.9538259508643026], 9 -> 
             RGBColor[
              0.19331350997927296`, 0.32051513414563226`, 0.9343202904603853],
              90 -> RGBColor[
              0.22727061882380845`, 0.3562062085462915, 0.9362540975740409], 
             174 -> RGBColor[
              0.19003317840134057`, 0.3170672976721906, 0.9341334804298378], 
             142 -> RGBColor[
              0.2619978835405132, 0.39270676559930323`, 0.938231763925273], 
             134 -> RGBColor[
              0.24687317251219526`, 0.37680973534647483`, 0.9373704340072151],
              105 -> RGBColor[
              0.20575656042090384`, 0.333593569094751, 0.9350289037751928], 
             16 -> RGBColor[
              0.1871756577266932, 0.3140638622658612, 0.9339707488547396], 
             139 -> RGBColor[
              0.28566810415648325`, 0.4175856682453557, 0.9395797479723991], 
             146 -> RGBColor[
              0.24540381361353808`, 0.37526534598125116`, 0.9372867561916584],
              126 -> RGBColor[
              0.1796655907243716, 0.3061703056806712, 0.9335430616491059], 
             198 -> RGBColor[
              0.34562348099972906`, 0.47378342052587685`, 0.9432438004798267],
              40 -> RGBColor[
              0.5058302216121423, 0.609694787153362, 0.9542399544439137], 104 -> 
             RGBColor[
              0.36710024085613885`, 0.49238551046016216`, 0.9446122806267241],
              181 -> 
             RGBColor[
              0.43817293033743376`, 0.5539451018716196, 0.9491409695533606], 
             127 -> RGBColor[
              0.874787420357395, 0.9029957597937702, 0.9879191991572792], 76 -> 
             RGBColor[
              0.26424845016803866`, 0.3950722538189983, 0.9383599303652956], 
             172 -> RGBColor[
              0.8693407441384133, 0.4995886600246006, 0.2126870529687101], 84 -> 
             RGBColor[
              0.181234979779358, 0.3078198330824752, 0.9336324360340843], 184 -> 
             RGBColor[
              0.1818088839913312, 0.30842304279688765`, 0.933665119029941], 
             151 -> RGBColor[
              0.9939031817563573, 0.9917468232222412, 0.7507035865643902], 35 -> 
             RGBColor[
              0.18077756667952594`, 0.30733906291288604`, 0.933606387034731], 
             36 -> RGBColor[
              0.18255152448721731`, 0.309203605044191, 0.9337074113075435], 
             34 -> RGBColor[
              0.4300571649791395, 0.5469156338284925, 0.9486238401612196], 38 -> 
             RGBColor[
              0.18112444186066054`, 0.30770365072141526`, 0.9336261410631407],
              54 -> RGBColor[
              0.988392764379178, 0.9725082101217492, 0.4094085107659739], 60 -> 
             RGBColor[
              0.18098071777705174`, 0.3075525875969092, 0.9336179561892], 87 -> 
             RGBColor[
              0.21670300720810273`, 0.3450989787129095, 0.9356522877259069], 
             141 -> RGBColor[
              0.34381589363766235`, 0.47221777920483715`, 0.9431286226115025],
              67 -> RGBColor[
              0.2558901091184015, 0.3862871074263986, 0.9378839352075763], 
             133 -> RGBColor[
              0.24912319227677354`, 0.3791746487785393, 0.937498569304202], 
             98 -> RGBColor[
              0.19250116414799295`, 0.31966130717125646`, 0.9342740285670519],
              3 -> RGBColor[
              0.4186929718519593, 0.5370725409226834, 0.947899723824117], 27 -> 
             RGBColor[
              0.26652048668465833`, 0.39746030825340095`, 0.9384893194837403],
              163 -> RGBColor[
              0.2817626744925139, 0.41348081404998144`, 0.9393573395306015], 
             85 -> RGBColor[
              0.2704719529099895, 0.40161354979365305`, 0.9387143496396024], 
             83 -> RGBColor[
              0.9263859833659136, 0.9441390533310817, 0.9928407161596127], 28 -> 
             RGBColor[
              0.1792907180836107, 0.3057762907669333, 0.933521713206789], 44 -> 
             RGBColor[
              0.8987739036289236, 0.6332377629819576, 0.2372468027203504], 
             189 -> RGBColor[
              0.19443151506714343`, 0.3216902283786009, 0.9343839591961993], 
             15 -> RGBColor[0.178927, 0.305394, 0.933501], 80 -> 
             RGBColor[
              0.22179319725678925`, 0.3504490911907685, 0.9359421665189183], 
             112 -> RGBColor[
              0.9414109245622558, 0.9558249439861124, 0.9840602016246193], 
             169 -> RGBColor[
              0.19209300288846856`, 0.31923230380857776`, 0.9342507843871425],
              69 -> RGBColor[
              0.24981404640376637`, 0.37990078026869034`, 0.9375379124247071],
              20 -> RGBColor[
              0.1823235017276304, 0.3089639386663871, 0.9336944257487145], 8 -> 
             RGBColor[
              0.28326421471662644`, 0.41505902802867256`, 0.939442850025035], 
             116 -> RGBColor[
              0.24062773125074222`, 0.3702453805968408, 0.9370147653666777], 
             97 -> RGBColor[
              0.21679935925455723`, 0.3452002508228058, 0.9356577748324124], 
             118 -> RGBColor[
              0.39086743560945575`, 0.5129714599815431, 0.9461267052599003], 
             178 -> RGBColor[
              0.1836473816366038, 0.3103554203895525, 0.9337698187510258], 81 -> 
             RGBColor[
              0.30602988251049323`, 0.4389871883067331, 0.9407393211271083], 
             166 -> RGBColor[
              0.8037293520346596, 0.846598745469576, 0.9810718885991364], 125 -> 
             RGBColor[
              0.2642831104182927, 0.3951086839396021, 0.9383619042152723], 95 -> 
             RGBColor[
              0.24919784069125972`, 0.37925310899514714`, 0.9375028204209744],
              157 -> RGBColor[
              0.20642492465234524`, 0.3342960622787358, 0.9350669661294171], 
             74 -> RGBColor[
              0.34593054718585675`, 0.47404938582270545`, 0.9432633664656788],
              19 -> RGBColor[
              0.35121665541737046`, 0.47862794708531764`, 0.9436001926078689],
              156 -> RGBColor[
              0.8187176743057581, 0.14487782361704554`, 0.16555737209477062`],
              167 -> RGBColor[
              0.19933380464903927`, 0.32684284555228516`, 0.9346631373356007],
              33 -> RGBColor[
              0.9926235425767636, 0.9912176595362523, 0.7719105193703001], 43 -> 
             RGBColor[
              0.18974733652345127`, 0.3167668597351072, 0.9341172021577572], 
             140 -> RGBColor[
              0.9937232399115826, 0.9889829697856952, 0.5581915839279488], 
             186 -> RGBColor[
              0.18306798401191893`, 0.3097464367500775, 0.933736822913442], 
             117 -> RGBColor[
              0.1853227778630534, 0.31211636804980714`, 0.9338652300875955], 
             4 -> RGBColor[
              0.33430755049502603`, 0.4639821302779076, 0.9425227593943515], 
             106 -> RGBColor[
              0.18503007033382515`, 0.31180871387785897`, 0.9338485608268279],
              65 -> RGBColor[
              0.95633856953826, 0.8643818842404721, 0.284884016735784], 53 -> 
             RGBColor[
              0.631783197735858, 0.7119490872875069, 0.9641554341053266], 2 -> 
             RGBColor[
              0.18237351643808017`, 0.30901650729818564`, 0.9336972740124846],
              147 -> RGBColor[
              0.24952468470268496`, 0.3795966427742623, 0.9375214337039027], 
             94 -> RGBColor[
              0.19041076970754647`, 0.3174641700756846, 0.9341549836961299], 
             23 -> RGBColor[
              0.22363768830217948`, 0.3523877682269605, 0.9360472075552733], 
             194 -> RGBColor[
              0.2015219494351241, 0.32914272445885284`, 0.9347877489440981], 
             129 -> RGBColor[
              0.4544709331932017, 0.5679990031052896, 0.9501967631243022], 99 -> 
             RGBColor[
              0.5518206973838005, 0.647031927232117, 0.9578604931653224], 25 -> 
             RGBColor[
              0.17953882470990998`, 0.3060370665620425, 0.9335358425121159], 
             138 -> RGBColor[
              0.2218736173884548, 0.35053361784807985`, 0.9359467463264457], 
             124 -> RGBColor[
              0.2260372839021752, 0.3549098953457044, 0.9361838609748094], 
             197 -> RGBColor[
              0.20070591566211698`, 0.3282850212238928, 0.9347412770279392], 
             164 -> RGBColor[
              0.19517315909830985`, 0.32246974327830424`, 0.9344261947266101],
              152 -> RGBColor[
              0.20018563595199287`, 0.32773817426091345`, 0.9347116478681324],
              17 -> RGBColor[
              0.19146922694525287`, 0.31857667574257903`, 0.9342152612699701],
              149 -> RGBColor[
              0.1855038424012835, 0.31230667835964177`, 
               0.9338755414451867]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw1Vnk41Iv7HWbGjH3MjDGYYWbMlDYVokV9jgp1K023DRVaCFlSpNQNyVKW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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 11}], {
             RGBColor[
             0.19143609648975546`, 0.318541853533259, 0.9342133745395418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 35}], {
             RGBColor[
             0.1803467482579951, 0.30688624543639154`, 0.9335818525629636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 86}], {
             RGBColor[
             0.19100632204633058`, 0.3180901333439459, 0.934188899520783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 94}], {
             RGBColor[
             0.18516334977200538`, 0.3119487990177908, 0.933856150893663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 174}], {
             RGBColor[
             0.1849745541189024, 0.31175036281604385`, 0.9338453992605169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 196}], {
             RGBColor[
             0.20645103349834157`, 0.33432350433127433`, 0.935068452989572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 16}], {
             RGBColor[
             0.1847745870823867, 0.3115401847820234, 0.9338340114336121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 52}], {
             RGBColor[
             0.1839811911872139, 0.31070627539199164`, 0.933788828711106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[
             0.1829598466238134, 0.3096327774988722, 0.9337306646491643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 78}], {
             RGBColor[
             0.1826523965739446, 0.3093096280030011, 0.9337131558236558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 80}], {
             RGBColor[
             0.20208335684743473`, 0.32973279924447707`, 0.9348197202657014]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 82}], {
             RGBColor[
             0.19716931432443496`, 0.3245678289845131, 0.934539872813691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 98}], {
             RGBColor[
             0.18743734029303655`, 0.314338907234721, 0.9339856512897682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 100}], {
             RGBColor[
             0.19408219414375266`, 0.32132306993989135`, 0.9343640658863862]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 120}], {
             RGBColor[
             0.18815579892545653`, 0.3150940528103027, 0.9340265664460203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 124}], {
             RGBColor[
             0.20420540017012767`, 0.331963201321945, 0.9349405674936471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 187}], {
             RGBColor[
             0.1929273076602217, 0.3201092110216681, 0.9342982968096505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 5}], {
             RGBColor[
             0.38651352623245844`, 0.5092003225130362, 0.945849278004409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 10}], {
             RGBColor[
             0.3183216992072676, 0.4417413182340497, 0.9418115251184348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 27}], {
             RGBColor[
             0.3426067292683088, 0.4672664245880422, 0.9431945216539286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 29}], {
             RGBColor[
             0.312801857714541, 0.4359396148470296, 0.9414971783112978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 49}], {
             RGBColor[
             0.42052372581365627`, 0.5386582479879358, 0.9480163778476842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 53}], {
             RGBColor[
             0.5252380847939087, 0.6245108141050952, 0.9560275789647218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 62}], {
             RGBColor[
             0.30929718741563983`, 0.43225598415395333`, 0.9412975925224704]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 68}], {
             RGBColor[
             0.6898421419054424, 0.7085746089319662, 0.625429383133753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 71}], {
             RGBColor[
             0.3912157938817601, 0.5132731904080172, 0.9461489023409704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 75}], {
             RGBColor[
             0.4604176361342196, 0.5718866537552251, 0.9509246758011038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 118}], {
             RGBColor[
             0.40478020373070756`, 0.5250220004521133, 0.9470132145420087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[
             0.4349086817945046, 0.5511177738496366, 0.9489329745226667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 127}], {
             RGBColor[
             0.6467401961046771, 0.7200341503582268, 0.9679094614906981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 129}], {
             RGBColor[
             0.4365819525225805, 0.5525357720139865, 0.9490482434742096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 139}], {
             RGBColor[
             0.3521805380042213, 0.47732910458401956`, 0.943739735898258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 141}], {
             RGBColor[
             0.38125443274481086`, 0.5046451600637603, 0.9455141732178098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 146}], {
             RGBColor[
             0.33204839273274867`, 0.4561689434519673, 0.9425932400078877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 155}], {
             RGBColor[
             0.545941520152503, 0.6408465029615011, 0.9579803382974005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 167}], {
             RGBColor[
             0.3090133882504993, 0.4319576932374843, 0.9412814305798589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 191}], {
             RGBColor[
             0.6143982789320568, 0.6943254432107253, 0.9648034682477634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 194}], {
             RGBColor[
             0.3101074606435417, 0.43310763269076813`, 0.9413437363841075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 195}], {
             RGBColor[
             0.4598624133064091, 0.5714358988511051, 0.9508809666262504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 34}], {
             RGBColor[
             0.38218235773708276`, 0.5054488820532, 0.9455732997777855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 40}], {
             RGBColor[
             0.42006888605358417`, 0.5368384587156347, 0.9483813569191326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 49}], {
             RGBColor[
             0.37833101513518963`, 0.5021130426655478, 0.9453278956328015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 53}], {
             RGBColor[
             0.483045374115442, 0.5879656087827072, 0.953339096749839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 54}], {
             RGBColor[
             0.661350157437102, 0.7182451701998284, 0.6759656350801627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 65}], {
             RGBColor[
             0.6453230600166431, 0.6641820072591899, 0.6137033880650677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 69}], {
             RGBColor[
             0.2920607984493962, 0.42194145527329896`, 0.9400303359095292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 86}], {
             RGBColor[
             0.26820213237561147`, 0.3968644845029512, 0.9386716201723606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 92}], {
             RGBColor[
             0.28937728391046563`, 0.41912091134823404`, 0.9398775137264412]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 118}], {
             RGBColor[
             0.3625874930522409, 0.48847679512972536`, 0.9443247323271259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 119}], {
             RGBColor[
             0.5905667103712094, 0.4124559324961789, 0.5674982858332491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 123}], {
             RGBColor[
             0.39271597111603795`, 0.5145725685272486, 0.946244492307784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 139}], {
             RGBColor[
             0.30998782732575464`, 0.44078389926163164`, 0.9410512536833753]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 146}], {
             RGBColor[
             0.289855682054282, 0.41962373812957937`, 0.9399047577930049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 171}], {
             RGBColor[
             0.3210288697535419, 0.4523887348957585, 0.9416800247158792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 182}], {
             RGBColor[
             0.33757022299890055`, 0.4668080932140755, 0.9427306540012304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 191}], {
             RGBColor[
             0.57220556825359, 0.6577802378883374, 0.9621149860328806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 195}], {
             RGBColor[
             0.41766970262794245`, 0.5348906935287172, 0.9481924844113676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 196}], {
             RGBColor[
             0.28364684382762245`, 0.41309785549027966`, 0.9395511736411497]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 199}], {
             RGBColor[
             0.6647841302718416, 0.7281451631679503, 0.8353642944923663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 10}], {
             RGBColor[
             0.28614225358776674`, 0.41386909982440245`, 0.9397610792987268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 27}], {
             RGBColor[
             0.31042728364880795`, 0.439394206178395, 0.9411440758342206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.28062241209504013`, 0.4080673964373824, 0.9394467324915896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 30}], {
             RGBColor[
             0.28195013969393246`, 0.40946292232661013`, 0.9395223446141496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 42}], {
             RGBColor[
             0.2785521364098815, 0.40589140542922086`, 0.9393288333540183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 68}], {
             RGBColor[
             0.6576626962859415, 0.680702390522319, 0.6233789373140448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 71}], {
             RGBColor[
             0.35903634826225916`, 0.48540097199837007`, 0.9440984565212622]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 73}], {
             RGBColor[
             0.2859066569179567, 0.41362147278674055`, 0.939747662416915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 75}], {
             RGBColor[
             0.42823819051471873`, 0.5440144353455778, 0.9488742299813958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 76}], {
             RGBColor[
             0.3092912653904981, 0.4382001789611937, 0.9410793812749982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 81}], {
             RGBColor[
             0.3301819815617254, 0.46015764620506105`, 0.9422690766559045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 87}], {
             RGBColor[
             0.28551854391053016`, 0.41321354140814925`, 0.9397255599553038]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 89}], {
             RGBColor[
             0.31092444547544634`, 0.4399167547800723, 0.9411723884647626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 107}], {
             RGBColor[
             0.28598353480448624`, 0.4137022763198226, 0.9397520404988222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 127}], {
             RGBColor[
             0.6145607504851762, 0.6921619319485797, 0.9658590156709901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 129}], {
             RGBColor[
             0.40440250690307966`, 0.5246635536043394, 0.9469977976545015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 141}], {
             RGBColor[
             0.34907498712530993`, 0.4767729416541131, 0.9434637273981017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 142}], {
             RGBColor[
             0.3081659820767354, 0.43701743485134614`, 0.9410152980549868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 147}], {
             RGBColor[
             0.30192938265782127`, 0.43046237343882565`, 0.9406601329443018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 155}], {
             RGBColor[
             0.513762074533002, 0.612974284551854, 0.9559298924776924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 157}], {
             RGBColor[
             0.28037950263265143`, 0.40781208319106244`, 0.939432899157059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 168}], {
             RGBColor[
             0.2818657379269033, 0.4093742107180814, 0.9395175380583785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 188}], {
             RGBColor[
             0.33376821355982345`, 0.4635149837324976, 0.9424883933217574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 197}], {
             RGBColor[
             0.27751999813753725`, 0.4048065626636409, 0.93927005460632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 44}], {
             RGBColor[
             0.8651034665131747, 0.43792568886884486`, 0.20749020660542072`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 45}], {
             RGBColor[
             0.7712380059237092, 0.5084025319316335, 0.5747836939863987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 58}], {
             RGBColor[
             0.8960048531020866, 0.6063661726923737, 0.5646755963969717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 77}], {
             RGBColor[
             0.8243760146987129, 0.18837030737786614`, 0.17097580524524553`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 83}], {
             RGBColor[
             0.8789095063816696, 0.593376334043407, 0.5852871633250518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 96}], {
             RGBColor[
             0.8839247435427675, 0.5973568467623975, 0.5851240708837279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 112}], {
             RGBColor[
             0.8864219769798407, 0.5992192793709223, 0.5808969060575552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 156}], {
             RGBColor[
             0.8250753518515919, 0.1937457191863889, 0.17164549129263085`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 166}], {
             RGBColor[
             0.8175811907160426, 0.5446061801126542, 0.5794027495448137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 170}], {
             RGBColor[
             0.7433204991907267, 0.48659316349091797`, 0.5720011378191884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 179}], {
             RGBColor[
             0.5999866512477183, 0.3681232043828395, 0.5612188243491484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 183}], {
             RGBColor[
             0.8839085682862255, 0.5140524144919886, 0.22270248687391753`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 192}], {
             RGBColor[
             0.6485736073804235, 0.40987019823777215`, 0.5644077418055113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 8}], {
             RGBColor[
             0.24587927343278695`, 0.3757650843971754, 0.9373138329249848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 16}], {
             RGBColor[
             0.19783499493782034`, 0.3252675015157697, 0.9345777823398371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 52}], {
             RGBColor[
             0.19704159904264756`, 0.32443359212573797`, 0.934532599617331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.2079174287175954, 0.335864778681537, 0.9351519620279711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 67}], {
             RGBColor[
             0.23219222063367448`, 0.36137912409603845`, 0.9365343755162554]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 79}], {
             RGBColor[
             0.20133607999592745`, 0.328947363893454, 0.934777163954505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.19486465596415276`, 0.32214548692407674`, 0.9344086259295095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 122}], {
             RGBColor[
             0.24320904209445873`, 0.37295850195814717`, 0.9371617672005202]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 125}], {
             RGBColor[
             0.2363887212836201, 0.36578991235264013`, 0.9367733600201034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 126}], {
             RGBColor[
             0.19407996143665954`, 0.32132072322317473`, 0.9343639387370202]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 137}], {
             RGBColor[
             0.266193356547354, 0.39571608733082725`, 0.9385219649126898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 179}], {
             RGBColor[
             0.2885173026234793, 0.4150519673878126, 0.9399444270163702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 192}], {
             RGBColor[
             0.3371042587561843, 0.4567989612427451, 0.9431333444727331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.3222839501803989, 0.4512119268537823, 0.9418428896396724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 26}], {
             RGBColor[
             0.28802321713859724`, 0.420061041312345, 0.9397138681726531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 61}], {
             RGBColor[
             0.24530237000143487`, 0.37515872231303415`, 0.9372809791280214]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 67}], {
             RGBColor[
             0.26957716191751396`, 0.4006730677275356, 0.9386633926163057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 79}], {
             RGBColor[
             0.2387210212797669, 0.3682413075249512, 0.9369061810545554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.24761466346370808`, 0.37758908934975655`, 0.9374126608199662]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 83}], {
             RGBColor[
             0.60482509904127, 0.6795990406798771, 0.9661417830923238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 122}], {
             RGBColor[
             0.2805939833782982, 0.4122524455896443, 0.9392907843005704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 125}], {
             RGBColor[
             0.2737736625674596, 0.4050838559841373, 0.9389023771201537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 137}], {
             RGBColor[
             0.3035782978311935, 0.4350100309623244, 0.94065098201274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 166}], {
             RGBColor[
             0.543496783375643, 0.6308288867491243, 0.9602573693120857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 170}], {
             RGBColor[
             0.4692360918503271, 0.5728158701273882, 0.9528557575864605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 179}], {
             RGBColor[
             0.32590224390731876`, 0.4543459110193097, 0.9420734441164204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 192}], {
             RGBColor[
             0.37448920004002384`, 0.4960929048742423, 0.9452623615727833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 198}], {
             RGBColor[
             0.31444384785817775`, 0.4444212242772747, 0.9413433252524308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 18}], {
             RGBColor[
             0.2081906159438856, 0.3361519157774386, 0.935167519636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 32}], {
             RGBColor[
             0.18966018913671598`, 0.3166752623061849, 0.9341122392430056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 39}], {
             RGBColor[
             0.22268787528916928`, 0.3513894545286635, 0.9359931171093048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 41}], {
             RGBColor[
             0.24200989921647753`, 0.37169812676333913`, 0.9370934777875921]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 57}], {
             RGBColor[
             0.18757656925487778`, 0.3144852457012422, 0.9339935801731742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 85}], {
             RGBColor[
             0.23189273144463124`, 0.36106434196964265`, 0.9365173200499939]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 88}], {
             RGBColor[
             0.20493816247527158`, 0.3327333809644648, 0.9349822972229003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 91}], {
             RGBColor[
             0.1897739422401799, 0.3167948240302888, 0.9341187173139652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 103}], {
             RGBColor[
             0.18719718779584008`, 0.3140864917336198, 0.9339719749603267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 117}], {
             RGBColor[
             0.1893181439211632, 0.3163157510977197, 0.9340927602739904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 121}], {
             RGBColor[
             0.20533326031636837`, 0.3331486538461075, 0.9350047974604558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 152}], {
             RGBColor[
             0.19674957296563292`, 0.32412665420327286`, 0.9345159691642588]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 159}], {
             RGBColor[
             0.22410281281265743`, 0.3528766435780701, 0.9360736957080549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 164}], {
             RGBColor[
             0.1942433345387914, 0.32149243871196825`, 0.9343732425934977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 178}], {
             RGBColor[
             0.18848044580793838`, 0.31543527726759235`, 0.9340450546057055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 200}], {
             RGBColor[
             0.19196359639909227`, 0.31909628938339796`, 0.9342434148790122]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 17}], {
             RGBColor[
             0.2047098267539144, 0.3324933856439975, 0.9349692938413614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 27}], {
             RGBColor[
             0.24223545662361712`, 0.37193520189940843`, 0.9371063229482464]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 29}], {
             RGBColor[
             0.2124305850698493, 0.3406083921583959, 0.9354089796056155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 30}], {
             RGBColor[
             0.2137583126687416, 0.34200391804762365`, 0.9354845917281754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 42}], {
             RGBColor[
             0.2103603093846907, 0.3384324011502344, 0.9352910804680441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 51}], {
             RGBColor[
             0.20007349461539067`, 0.32762030660597313`, 0.9347052615849112]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 62}], {
             RGBColor[
             0.2089259147709481, 0.3369247614653196, 0.9352093938167881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 71}], {
             RGBColor[
             0.2908445212370684, 0.4179419677193835, 0.9400607036352882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 73}], {
             RGBColor[
             0.2177148298927659, 0.346162468507754, 0.9357099095309409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 75}], {
             RGBColor[
             0.3600463634895279, 0.4765554310665914, 0.9448364770954216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 89}], {
             RGBColor[
             0.2427326184502555, 0.3724577505010858, 0.9371346355787884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 107}], {
             RGBColor[
             0.21779170777929543`, 0.3462432720408361, 0.9357142876128481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.3362106798778888, 0.4572045493253528, 0.9429600447685274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 130}], {
             RGBColor[
             0.2011228825880777, 0.32872327990030753`, 0.9347650226775253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 141}], {
             RGBColor[
             0.28088316010011916`, 0.40931393737512656`, 0.9394259745121276]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 142}], {
             RGBColor[
             0.23997415505154454`, 0.3695584305723596, 0.9369775451690128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 147}], {
             RGBColor[
             0.23373755563263043`, 0.3630033691598391, 0.9366223800583277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 149}], {
             RGBColor[
             0.2017271344819297, 0.32935838695252884`, 0.9347994339289696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 167}], {
             RGBColor[
             0.2086421156058076, 0.33662647054885053`, 0.9351932318741767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 168}], {
             RGBColor[
             0.21367391090171242`, 0.3419152064390949, 0.9354797851724044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 188}], {
             RGBColor[
             0.26557638653463256`, 0.3960559794535111, 0.9384506404357832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.20619097081485965`, 0.33405016196200843`, 0.935053642804476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 194}], {
             RGBColor[
             0.20973618799885002`, 0.33777641000213443`, 0.9352555376784253]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 197}], {
             RGBColor[
             0.20932817111234645`, 0.33734755838465436`, 0.9352323017203459]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 35}], {
             RGBColor[
             0.19186691491128627`, 0.3189946710097535, 0.9342379090113091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 70}], {
             RGBColor[
             0.19700340773557554`, 0.3243934506405365, 0.9345304246788922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 86}], {
             RGBColor[
             0.20252648869962175`, 0.33019855891730787`, 0.9348449559691285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 94}], {
             RGBColor[
             0.19668351642529655`, 0.32405722459115277`, 0.9345122073420087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 110}], {
             RGBColor[
             0.1915413157937571, 0.3186524456930539, 0.9342193666232466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 138}], {
             RGBColor[
             0.2124149402657507, 0.3405919484773504, 0.9354080886571665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 174}], {
             RGBColor[
             0.1964947207721936, 0.32385878838940574`, 0.9345014557088626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 182}], {
             RGBColor[
             0.27189457932291083`, 0.4001421676284322, 0.9389039897979983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 196}], {
             RGBColor[
             0.21797120015163274`, 0.34643192990463634`, 0.9357245094379176]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 33}], {
             RGBColor[
             0.9713628299392978, 0.9155481063306994, 0.5253098577893779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 44}], {
             RGBColor[
             0.9244380104653778, 0.7365581580535521, 0.25797799946440303`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 58}], {
             RGBColor[
             0.9553393970542898, 0.9049986418770809, 0.615163389255954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 68}], {
             RGBColor[
             0.9555467146303788, 0.8599776150331977, 0.2908341193259223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 77}], {
             RGBColor[
             0.883710558650916, 0.4870027765625733, 0.22146359810422783`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 96}], {
             RGBColor[
             0.9432592874949708, 0.8959893159471047, 0.6356118637427102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 99}], {
             RGBColor[
             0.7509614073428162, 0.7434552401786318, 0.618284844686889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 102}], {
             RGBColor[
             0.9596388825040008, 0.9082051910857141, 0.6078854818749925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 128}], {
             RGBColor[
             0.6907043727279983, 0.6939382045780004, 0.6137063255291655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 140}], {
             RGBColor[
             0.9719126786067074, 0.9144307614554209, 0.4184503900682022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 162}], {
             RGBColor[
             0.7007570533940699, 0.7026453313085301, 0.614346873451971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 172}], {
             RGBColor[
             0.9097214307201227, 0.6697336065748736, 0.2456981245885829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 31}], {
             RGBColor[
             0.37653388192589077`, 0.49031817539689215`, 0.9461000785422968]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 34}], {
             RGBColor[
             0.32558157650060693`, 0.44832121227099686`, 0.9422634355654279]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 36}], {
             RGBColor[
             0.20182875625464586`, 0.3294651978788461, 0.9348052211385899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 63}], {
             RGBColor[
             0.20638929458382937`, 0.3342586128176488, 0.935064937049725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 64}], {
             RGBColor[
             0.4253184848962721, 0.5299237138095665, 0.9499405811920143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 70}], {
             RGBColor[
             0.20607827017508945`, 0.33393170644397663`, 0.9350472246697668]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 97}], {
             RGBColor[
             0.21895267363831583`, 0.3474635207681535, 0.9357804029010244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 132}], {
             RGBColor[
             0.26083574153477407`, 0.39148528066721244`, 0.9381655816572811]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 138}], {
             RGBColor[
             0.2214898027052646, 0.35013020428079056`, 0.9359248886480409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 145}], {
             RGBColor[
             0.20564959648275716`, 0.3334811432138535, 0.9350228123371542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 153}], {
             RGBColor[
             0.2516813551580962, 0.3818634401637041, 0.9376442528958304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 185}], {
             RGBColor[
             0.22657810602203676`, 0.3554783336837818, 0.936214659994461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 22}], {
             RGBColor[
             0.18387332754707644`, 0.31059290386725735`, 0.9337826860363703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 48}], {
             RGBColor[
             0.19487547737670605`, 0.3221568609147874, 0.9344092421929455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 106}], {
             RGBColor[
             0.1821436488572793, 0.3087749018963175, 0.9336841833938165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 131}], {
             RGBColor[
             0.18037616802655143`, 0.3069171674784653, 0.9335835279752602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 176}], {
             RGBColor[
             0.20667251283261232`, 0.3345562931541938, 0.9350810659100094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 59}], {
             RGBColor[
             0.18157500733235693`, 0.30817722359966904`, 0.9336518001002019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.18941420148966015`, 0.3164167136926116, 0.9340982306104119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 114}], {
             RGBColor[
             0.1801710817898224, 0.3067016088404447, 0.9335718486174763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 167}], {
             RGBColor[
             0.18913040232451964`, 0.31611842277614255`, 0.9340820686678004]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 184}], {
             RGBColor[
             0.18036794199566558`, 0.3069085213984438, 0.9335830595149706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 186}], {
             RGBColor[
             0.18099749200595946`, 0.30757021837503873`, 0.933618911456721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 194}], {
             RGBColor[
             0.19022447471756204`, 0.31726836222942645`, 0.934144374472049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 52}], {
             RGBColor[
             0.18638226183152043`, 0.31322995287582944`, 0.9339255661322337]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 61}], {
             RGBColor[
             0.19725809150646825`, 0.3246611394316285, 0.9345449285428737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 67}], {
             RGBColor[
             0.22153288342254734`, 0.3501754848461299, 0.935927342031158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 80}], {
             RGBColor[
             0.20448442749174123`, 0.3322564767283148, 0.934956457686829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 82}], {
             RGBColor[
             0.19957038496874147`, 0.32709150646835083`, 0.9346766102348185]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 84}], {
             RGBColor[
             0.1842053187530256, 0.3109418476741682, 0.933801592444412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 100}], {
             RGBColor[
             0.19648326478805916`, 0.32384674742372915`, 0.9345008033075137]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 120}], {
             RGBColor[
             0.19055686956976303`, 0.31761773029414053`, 0.9341633038671477]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 125}], {
             RGBColor[
             0.22572938407249296`, 0.3545862731027316, 0.936166326535006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.19532837830452823`, 0.32263288850550587`, 0.9344350342307781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 30}], {
             RGBColor[
             0.20051771286008008`, 0.3280872081462052, 0.9347305591567843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[
             0.1971197095760292, 0.3245156912488159, 0.9345370478966529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 51}], {
             RGBColor[
             0.18683289480672916`, 0.31370359670455467`, 0.9339512290135199]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 73}], {
             RGBColor[
             0.20447423008410437`, 0.33224575860633554`, 0.9349558769595496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 87}], {
             RGBColor[
             0.2040861170766778, 0.33183782722774424`, 0.9349337744979385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 89}], {
             RGBColor[
             0.229492018641594, 0.35854104059966735`, 0.9363806030073972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 106}], {
             RGBColor[
             0.18824964863953902`, 0.315192694810219, 0.934031911048399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 107}], {
             RGBColor[
             0.20455110797063392`, 0.33232656213941764`, 0.9349602550414569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 130}], {
             RGBColor[
             0.18788228277941618`, 0.31480656999888906`, 0.9340109901061341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 131}], {
             RGBColor[
             0.18648216780881113`, 0.31333496039236675`, 0.9339312556298427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 142}], {
             RGBColor[
             0.22673355524288302`, 0.35564172067094113`, 0.9362235125976215]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 147}], {
             RGBColor[
             0.22049695582396892`, 0.34908665925842064`, 0.9358683474869365]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 149}], {
             RGBColor[
             0.1884865346732682, 0.31544167705111037`, 0.9340454013575784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 157}], {
             RGBColor[
             0.19894707579879906`, 0.3264363690106574, 0.9346411136996936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 168}], {
             RGBColor[
             0.2004333110930509, 0.32799849653767643`, 0.9347257526010131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 188}], {
             RGBColor[
             0.25233578672597107`, 0.38213926955209265`, 0.937696607864392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 189}], {
             RGBColor[
             0.19295037100619816`, 0.32013345206058996`, 0.9342996102330847]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 197}], {
             RGBColor[
             0.19608757130368493`, 0.3234308484832359, 0.9344782691489546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 24}], {
             RGBColor[
             0.24010747998138166`, 0.3696985635269072, 0.9369851378265305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 32}], {
             RGBColor[
             0.20453729510132862`, 0.33231204393799124`, 0.9349594684189844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 39}], {
             RGBColor[
             0.2375649812537819, 0.3670262361604698, 0.9368403462852835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 41}], {
             RGBColor[
             0.25688700518109014`, 0.38733490839514545`, 0.9379407069635708]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 85}], {
             RGBColor[
             0.24676983740924385`, 0.376701123601449, 0.9373645492259726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 103}], {
             RGBColor[
             0.20207429376045272`, 0.32972327336542606`, 0.9348192041363055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 108}], {
             RGBColor[
             0.2655472156605108, 0.39643733869807485`, 0.9384338931387406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 117}], {
             RGBColor[
             0.2041952498857758, 0.331952532729526, 0.9349399894499691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 133}], {
             RGBColor[
             0.2360954570926359, 0.3654816730938921, 0.9367566590582723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 152}], {
             RGBColor[
             0.21162667893024556`, 0.3397634358350792, 0.9353631983402376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 178}], {
             RGBColor[
             0.20335755177255102`, 0.3310720588993987, 0.9348922837816843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 33}], {
             RGBColor[
             0.6719200989970671, 0.734922803310785, 0.8577553559890845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 74}], {
             RGBColor[
             0.34857360130161363`, 0.4763386664540116, 0.9434317795367738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 85}], {
             RGBColor[
             0.31084430416368, 0.44012074843948534`, 0.9411572711237357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 88}], {
             RGBColor[
             0.28388973519432037`, 0.4117897874343075, 0.939622248296642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 93}], {
             RGBColor[
             0.291301712500707, 0.4195802455298239, 0.9400443494392029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 95}], {
             RGBColor[
             0.3002072480543151, 0.4289405280402324, 0.9405515065144217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 102}], {
             RGBColor[
             0.6601961515617699, 0.7275798880657995, 0.9403309800746991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 121}], {
             RGBColor[
             0.28428483303541713`, 0.41220506031595017`, 0.9396447485341975]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 140}], {
             RGBColor[
             0.6724699476644765, 0.7338054584355065, 0.7508958882679089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 159}], {
             RGBColor[
             0.30305438553170616`, 0.43193305004791277`, 0.9407136467817967]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 161}], {
             RGBColor[
             0.3175223229543551, 0.44713976959933127`, 0.9415375744146212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 162}], {
             RGBColor[
             0.4013143224518391, 0.5220200282886156, 0.9467923716516777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 164}], {
             RGBColor[
             0.2731949072578401, 0.40054884518181094`, 0.9390131936672395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 172}], {
             RGBColor[
             0.610278699777892, 0.48910830355495916`, 0.5781436227882895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 173}], {
             RGBColor[
             0.35948494367207134`, 0.4857895227952885, 0.9441270406240982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 180}], {
             RGBColor[
             0.3466247657178071, 0.47465068302264285`, 0.9433076014566613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 22}], {
             RGBColor[
             0.1854064647205249, 0.3122043282430629, 0.9338699959303249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 46}], {
             RGBColor[
             0.182651270158183, 0.3093084440686167, 0.9337130916759446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 47}], {
             RGBColor[
             0.189292245231432, 0.3162885299327404, 0.9340912853819239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 50}], {
             RGBColor[
             0.19303508907013, 0.32022249611721776`, 0.9343044348014965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 101}], {
             RGBColor[
             0.18925893509711914`, 0.3162535188695931, 0.9340893884190526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 135}], {
             RGBColor[
             0.18962988067563263`, 0.3166434061919189, 0.9341105132209843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 144}], {
             RGBColor[
             0.19040607844928842`, 0.31745923926581243`, 0.9341547165359123]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 23}], {
             RGBColor[
             0.2924706869731754, 0.4198762969529263, 0.9401450684047916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 55}], {
             RGBColor[
             0.34859095953566543`, 0.47635370128389704`, 0.9434328855880982]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 61}], {
             RGBColor[
             0.2843221054652073, 0.4113116211381439, 0.9396810187426589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 67}], {
             RGBColor[
             0.30859689738128643`, 0.43682596655264533`, 0.9410634322309431]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 83}], {
             RGBColor[
             0.6438448345050425, 0.715751939504987, 0.9685418227069613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 90}], {
             RGBColor[
             0.29428715223398993`, 0.42178551711259177`, 0.9402485134141754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 122}], {
             RGBColor[
             0.3196137188420707, 0.44840534441475405`, 0.941690823915208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 166}], {
             RGBColor[
             0.5825165188394155, 0.666981785574234, 0.9626574089267232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 170}], {
             RGBColor[
             0.5082558273140996, 0.6089687689524979, 0.9552557972010979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 175}], {
             RGBColor[
             0.43093748007980026`, 0.5463950813331377, 0.9490344400593063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 177}], {
             RGBColor[
             0.28934680274084895`, 0.4165928965590511, 0.9399671678191333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 179}], {
             RGBColor[
             0.3649219793710912, 0.49049880984441946`, 0.9444734837310578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 183}], {
             RGBColor[
             0.6488438964095984, 0.6364280199535685, 0.605957146255827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 192}], {
             RGBColor[
             0.4135089355037963, 0.532245803699352, 0.9476624011874208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.19949157754304903`, 0.3270086748672687, 0.9346721222685106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 72}], {
             RGBColor[
             0.22084536933385682`, 0.34945286394800523`, 0.935888189120893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 144}], {
             RGBColor[
             0.19348904144218293`, 0.3206996288424882, 0.9343302867175226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 176}], {
             RGBColor[
             0.2112886129989553, 0.33940810710667507`, 0.9353439459855744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 38}], {
             RGBColor[
             0.20238106508142, 0.3300457094741879, 0.9348366743092069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 43}], {
             RGBColor[
             0.2066925124128154, 0.33457731398103385`, 0.9350822048565153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 55}], {
             RGBColor[
             0.27975796086466953`, 0.40886517255793126`, 0.9393350247385799]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 60}], {
             RGBColor[
             0.2023092030396156, 0.32997017791193484`, 0.9348325818722366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 90}], {
             RGBColor[
             0.22545415356299398`, 0.354296988386626, 0.936150652564657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 111}], {
             RGBColor[
             0.2218869245410005, 0.3505476045091276, 0.935947504149097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 115}], {
             RGBColor[
             0.26933147945021957`, 0.39983427840692803`, 0.9386706585626268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 163}], {
             RGBColor[
             0.2527001813973467, 0.382934291138471, 0.9377022735429374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 165}], {
             RGBColor[
             0.21472043526896856`, 0.3430151699025583, 0.9355393831869255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 169}], {
             RGBColor[
             0.20786534559532402`, 0.33581003601776915`, 0.9351489959712078]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 175}], {
             RGBColor[
             0.36210448140880436`, 0.4789065526071719, 0.9449365792097879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 177}], {
             RGBColor[
             0.22051380406985302`, 0.3491043678330853, 0.9358693069696149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 39}], {
             RGBColor[
             0.25460473932666533`, 0.38493610227813213`, 0.9378107352994711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 41}], {
             RGBColor[
             0.2739267632539736, 0.4052447745128077, 0.9389110959777585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 55}], {
             RGBColor[
             0.29651273574071235`, 0.4264755032667358, 0.9402891843813024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 108}], {
             RGBColor[
             0.28258697373339425`, 0.41434720481573717`, 0.9394042821529283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 111}], {
             RGBColor[
             0.2386416994170433, 0.36815793521793205`, 0.9369016637918195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 115}], {
             RGBColor[
             0.28608625432626233`, 0.41744460911573256`, 0.9396248182053492]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 133}], {
             RGBColor[
             0.2531352151655193, 0.3833915392115544, 0.93772704807246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 163}], {
             RGBColor[
             0.2694549562733895, 0.40054462184727546`, 0.9386564331856598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 165}], {
             RGBColor[
             0.23147521014501135`, 0.3606255006113628, 0.9364935428296479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 175}], {
             RGBColor[
             0.3788592562848471, 0.49651688331597643`, 0.9458907388525104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 38}], {
             RGBColor[
             0.18033163328528526`, 0.30687035864172885`, 0.9335809917876283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[
             0.1846430806166806, 0.3114019631485748, 0.9338265223349365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 60}], {
             RGBColor[
             0.18025977124348086`, 0.3067948270794758, 0.9335768993506579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 111}], {
             RGBColor[
             0.19983749274486573`, 0.32737225367666856`, 0.9346918216275183]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 165}], {
             RGBColor[
             0.19267100347283378`, 0.3198398190700993, 0.9342837006653468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 58}], {
             RGBColor[
             0.6266794481836577, 0.6975908926125163, 0.9458012343118618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 67}], {
             RGBColor[
             0.2743361643394848, 0.4056750810112081, 0.9389344107639237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 80}], {
             RGBColor[
             0.25728770840867865`, 0.387756072893393, 0.9379635264195947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 82}], {
             RGBColor[
             0.2523736658856789, 0.382591102633429, 0.9376836789675842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 96}], {
             RGBColor[
             0.6145993386243387, 0.6885815666825401, 0.9662497087986179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 98}], {
             RGBColor[
             0.24264169185428053`, 0.372362180883637, 0.9371294574436615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 99}], {
             RGBColor[
             0.42230145847218425`, 0.5360474909140672, 0.9489226897427967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[
             0.24928654570499661`, 0.3793463435888073, 0.9375078720402794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 116}], {
             RGBColor[
             0.2667049754056552, 0.39765421759642916`, 0.9384998258434745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 120}], {
             RGBColor[
             0.2433601504867005, 0.3731173264592187, 0.9371703725999135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 122}], {
             RGBColor[
             0.285352985800269, 0.4172544588733168, 0.9395618024481885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 124}], {
             RGBColor[
             0.25940975173137165`, 0.3899864749708609, 0.9380843736475403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 125}], {
             RGBColor[
             0.2785326649894304, 0.41008586926780977`, 0.9391733952677717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 128}], {
             RGBColor[
             0.36204442385736635`, 0.48653045531343586`, 0.9443441705850733]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 136}], {
             RGBColor[
             0.2577972163446346, 0.3882915980387517, 0.9379925421427979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 137}], {
             RGBColor[
             0.3083373002531643, 0.4400120442459969, 0.9409220001603581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.5482557857976138, 0.6358309000327967, 0.9605283874597037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 170}], {
             RGBColor[
             0.4739950942722979, 0.5778178834110607, 0.9531267757340784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 187}], {
             RGBColor[
             0.24813165922146568`, 0.378132484670584, 0.9374421029635438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 192}], {
             RGBColor[
             0.37924820246199464`, 0.5010949181579147, 0.9455333797204014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 198}], {
             RGBColor[
             0.3192028502801486, 0.44942323756094715`, 0.9416143434000489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 29}], {
             RGBColor[
             0.2367156151308905, 0.36613349851238836`, 0.9367919761411093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 30}], {
             RGBColor[
             0.2380433427297828, 0.3675290244016161, 0.9368675882636692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 42}], {
             RGBColor[
             0.2346453394457319, 0.36395750750422684`, 0.936674077003538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 62}], {
             RGBColor[
             0.23321094483198931`, 0.3624498678193121, 0.9365923903522819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 71}], {
             RGBColor[
             0.3151295512981096, 0.44346707407337604`, 0.941443700170782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 73}], {
             RGBColor[
             0.2419998599538071, 0.37168757486174653`, 0.9370929060664348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 75}], {
             RGBColor[
             0.3843313935505691, 0.5020805374205839, 0.9462194736309155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 89}], {
             RGBColor[
             0.2670176485112967, 0.3979828568550783, 0.9385176321142823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 127}], {
             RGBColor[
             0.5706539535210267, 0.6502280340235855, 0.9632042593205097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 129}], {
             RGBColor[
             0.36049570993893, 0.4827296556793453, 0.9443430413040212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 141}], {
             RGBColor[
             0.30516819016116037`, 0.4348390437291191, 0.9408089710476214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 142}], {
             RGBColor[
             0.2642591851125857, 0.3950835369263521, 0.9383605417045067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 147}], {
             RGBColor[
             0.25802258569367165`, 0.38852847551383163`, 0.9380053765938214]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 149}], {
             RGBColor[
             0.2260121645429709, 0.35488349330652136`, 0.9361824304644635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 155}], {
             RGBColor[
             0.4698552775688525, 0.57104038662686, 0.953275136127212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 167}], {
             RGBColor[
             0.2329271456668488, 0.36215157690284305`, 0.9365762284096705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 168}], {
             RGBColor[
             0.23795894096275363`, 0.36744031279308736`, 0.9368627817078983]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 188}], {
             RGBColor[
             0.28986141659567377`, 0.4215810858075036, 0.939833636971277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 189}], {
             RGBColor[
             0.23047600087590087`, 0.35957526831600095`, 0.9364366393399698]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[
             0.23402121805989123`, 0.3633015163561269, 0.9366385342139192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 197}], {
             RGBColor[
             0.23361320117338766`, 0.3628726647386469, 0.9366152982558398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 97}], {
             RGBColor[
             0.19804503866908396`, 0.3254882707948695, 0.9345897440196007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 105}], {
             RGBColor[
             0.19252363925225727`, 0.3196849299308422, 0.9342753084909909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.20340607327822147`, 0.3311230580782995, 0.9348950470096511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 71}], {
             RGBColor[
             0.2853246797443417, 0.4121402643323634, 0.939746356828151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 73}], {
             RGBColor[
             0.21219498840003925`, 0.3403607651207339, 0.9353955627238038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 129}], {
             RGBColor[
             0.33069083838516217`, 0.4514028459383327, 0.9426456979613903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 141}], {
             RGBColor[
             0.2753633186073925, 0.40351223398810643`, 0.9391116277049905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 149}], {
             RGBColor[
             0.19620729298920309`, 0.32355668356550876`, 0.9344850871218325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 167}], {
             RGBColor[
             0.20312227411308098`, 0.33082476716183046`, 0.9348788850670395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 168}], {
             RGBColor[
             0.2081540694089858, 0.33611350305207477`, 0.9351654383652672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 189}], {
             RGBColor[
             0.20067112932213305`, 0.3282484585749883, 0.9347392959973388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 194}], {
             RGBColor[
             0.2042163465061234, 0.3319747066151143, 0.9349411908712882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 197}], {
             RGBColor[
             0.2038083296196198, 0.3315458549976343, 0.9349179549132087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 42}], {
             RGBColor[
             0.2061681954908564, 0.33402622365244206`, 0.935052345783467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 51}], {
             RGBColor[
             0.19588138072155636`, 0.3232141291081808, 0.934466526900334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 71}], {
             RGBColor[
             0.28665240734323405`, 0.41353579022159115`, 0.939821968950711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 73}], {
             RGBColor[
             0.21352271599893158`, 0.34175629100996163`, 0.9354711748463638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 76}], {
             RGBColor[
             0.23690732447147297`, 0.36633499718441476`, 0.936802893704447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 81}], {
             RGBColor[
             0.2577980406427003, 0.3882924644282822, 0.9379925890853533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 87}], {
             RGBColor[
             0.213134602991505, 0.3413483596313704, 0.9354490723847526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 89}], {
             RGBColor[
             0.2385405045564212, 0.3680515730032935, 0.9368959008942113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 106}], {
             RGBColor[
             0.19729813455436623`, 0.32470322721384515`, 0.9345472089352131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 107}], {
             RGBColor[
             0.21359959388546113`, 0.3418370945430438, 0.935475552928271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 130}], {
             RGBColor[
             0.1969307686942434, 0.3243171024025152, 0.9345262879929481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 131}], {
             RGBColor[
             0.19553065372363834`, 0.3228454927959929, 0.9344465535166567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 142}], {
             RGBColor[
             0.23578204115771023`, 0.3651522530745672, 0.9367388104844356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 147}], {
             RGBColor[
             0.22954544173879612`, 0.3585971916620468, 0.9363836453737505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 157}], {
             RGBColor[
             0.20799556171362626`, 0.3359469014142835, 0.9351564115865076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 168}], {
             RGBColor[
             0.2094817970078781, 0.3375090289413025, 0.9352410504878272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 176}], {
             RGBColor[
             0.22182699852969923`, 0.3504846184717214, 0.9359440914514059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 188}], {
             RGBColor[
             0.2613842726407983, 0.39164980195571875`, 0.938211905751206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 197}], {
             RGBColor[
             0.20513605721851214`, 0.33294138088686204`, 0.9349935670357687]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 34}], {
             RGBColor[
             0.48100947040442327`, 0.5889125969543878, 0.9524604831380885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[
             0.5188959987209247, 0.6203021736168226, 0.9552685402794356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 45}], {
             RGBColor[
             0.62150237913985, 0.702550504593909, 0.964065451798632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 64}], {
             RGBColor[
             0.5807463788000884, 0.6705150984929575, 0.9601376287646749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 65}], {
             RGBColor[
             0.7441501726839835, 0.7476457221603776, 0.6205905714253708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 132}], {
             RGBColor[
             0.4162636354385904, 0.5320766653506034, 0.9483626292299419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 138}], {
             RGBColor[
             0.3769176966090809, 0.4907215889641815, 0.9461219362207016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 153}], {
             RGBColor[
             0.4071092490619125, 0.522454824847095, 0.9478413004684911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 156}], {
             RGBColor[
             0.6753397250677327, 0.3878936918486643, 0.560927249104864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 182}], {
             RGBColor[
             0.43639733566624106`, 0.5502718081152633, 0.9496178373615334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 185}], {
             RGBColor[
             0.38200599992585305`, 0.49606971836717273`, 0.9464117075671216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 199}], {
             RGBColor[
             0.763611242939182, 0.811608878069138, 0.8422514778526693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 39}], {
             RGBColor[
             0.2190345544466123, 0.34754958268921615`, 0.9357850658919249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 57}], {
             RGBColor[
             0.1839232484123208, 0.31064537386179486`, 0.9337855289557946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 103}], {
             RGBColor[
             0.1835438669532831, 0.31024661989417246`, 0.9337639237429469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 117}], {
             RGBColor[
             0.1856648230786062, 0.31247587925827236`, 0.9338847090566107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 133}], {
             RGBColor[
             0.21756503028546625`, 0.3460050196226384, 0.9357013786649139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 152}], {
             RGBColor[
             0.19309625212307593`, 0.3202867823638255, 0.9343079179468792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 178}], {
             RGBColor[
             0.1848271249653814, 0.311595405428145, 0.9338370033883259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 44}], {
             RGBColor[
             0.9456987231028435, 0.812227711259105, 0.5045786610453252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 58}], {
             RGBColor[
             0.9766001096917556, 0.9806681950826337, 0.8617640508368762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 68}], {
             RGBColor[
             0.9768074272678445, 0.9356471682387506, 0.5374347809068445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 77}], {
             RGBColor[
             0.9049712712883817, 0.5626723297681262, 0.46806425968515003`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 96}], {
             RGBColor[
             0.9645200001324366, 0.9716588691526575, 0.8822125253236324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 99}], {
             RGBColor[
             0.772222119980282, 0.8191247933841846, 0.8648855062678112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 102}], {
             RGBColor[
             0.9808995951414665, 0.9838747442912669, 0.8544861434559147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 128}], {
             RGBColor[
             0.7119650853654641, 0.7696077577835532, 0.8603069871100877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 140}], {
             RGBColor[
             0.9931733912441731, 0.9901003146609737, 0.6650510516491244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 162}], {
             RGBColor[
             0.7220177660315357, 0.778314884514083, 0.8609475350328932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 172}], {
             RGBColor[
             0.9309821433575884, 0.7454031597804265, 0.49229878616950506`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 180}], {
             RGBColor[
             0.6673282092975037, 0.7309455392481101, 0.857462764837877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 40}], {
             RGBColor[
             0.4679436932956409, 0.5783052104909272, 0.9514318973025666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 45}], {
             RGBColor[
             0.5705500737145661, 0.6605535414680137, 0.960228808821763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 54}], {
             RGBColor[
             0.7092249646791587, 0.7597119219751208, 0.6790161754635967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 64}], {
             RGBColor[
             0.5297940733748047, 0.6285181353670621, 0.956300985787806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 65}], {
             RGBColor[
             0.6931978672586998, 0.7056487590344823, 0.6167539284485017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 132}], {
             RGBColor[
             0.3653113300133066, 0.4900797022247081, 0.9445259862530728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 138}], {
             RGBColor[
             0.32596539118379714`, 0.4487246258382862, 0.9422852932438326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 153}], {
             RGBColor[
             0.3561569436366287, 0.48045786172119975`, 0.9440046574916221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 182}], {
             RGBColor[
             0.3854450302409573, 0.5082748449893679, 0.9457811943846643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 185}], {
             RGBColor[
             0.3310536945005693, 0.45407275524127744`, 0.9425750645902526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 199}], {
             RGBColor[
             0.7126589375138983, 0.7696119149432428, 0.8384148348758003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 86}], {
             RGBColor[
             0.19143714046786142`, 0.31854295082044043`, 0.9342134339925504]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.1855941681935362, 0.31240161649428533`, 0.9338806853654305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 110}], {
             RGBColor[
             0.18045196756199675`, 0.30699683759618646`, 0.9335878446466683]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 174}], {
             RGBColor[
             0.18540537254043327`, 0.31220318029253835`, 0.9338699337322844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 63}], {
             RGBColor[
             0.1871120628164008, 0.3139970199829937, 0.9339671272186787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 70}], {
             RGBColor[
             0.18680103840766088`, 0.3136701136093215, 0.9339494148387204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 110}], {
             RGBColor[
             0.18133894646584242`, 0.3079291086618389, 0.9336383567830746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 138}], {
             RGBColor[
             0.20221257093783607`, 0.32986861144613544`, 0.9348270788169946]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 145}], {
             RGBColor[
             0.1863723647153286, 0.3132195503791984, 0.9339250025061079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 185}], {
             RGBColor[
             0.2073008742546082, 0.33521674084912667`, 0.9351168501634146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 45}], {
             RGBColor[
             0.47344467906469456`, 0.5697056609217193, 0.9542881258612889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 47}], {
             RGBColor[
             0.21605368220731502`, 0.34441649696749876`, 0.9356153096277022]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 50}], {
             RGBColor[
             0.21979652604601302`, 0.3483504631519761, 0.935828459047275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 97}], {
             RGBColor[
             0.22632286746697683`, 0.35521006177935477`, 0.9362001245363418]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 101}], {
             RGBColor[
             0.21602037207300215`, 0.3443814859043514, 0.9356134126648311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 105}], {
             RGBColor[
             0.22080146805015013`, 0.3494067209153274, 0.9358856890077321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 134}], {
             RGBColor[
             0.24135977409579584`, 0.37101480404118925`, 0.9370564541237432]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 135}], {
             RGBColor[
             0.21639131765151565`, 0.3447713732266772, 0.9356345374667627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 160}], {
             RGBColor[
             0.33951855272220766`, 0.4617555701348826, 0.9431015867680459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 43}], {
             RGBColor[
             0.1854358891920559, 0.31223525522826123`, 0.9338716716104489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 60}], {
             RGBColor[
             0.18105257981885614`, 0.3076281191591622, 0.9336220486261704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 90}], {
             RGBColor[
             0.20419753034223448`, 0.33195492963385337`, 0.9349401193185908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 111}], {
             RGBColor[
             0.200630301320241, 0.32820554575635497`, 0.9347369709030307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 165}], {
             RGBColor[
             0.19346381204820906`, 0.3206731111497857, 0.9343288499408593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 169}], {
             RGBColor[
             0.18660872237456455`, 0.31346797726499653`, 0.9339384627251416]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 41}], {
             RGBColor[
             0.2713842645263738, 0.40257244714637036`, 0.9387663044365115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 74}], {
             RGBColor[
             0.29899639389246113`, 0.42815658036720006`, 0.9404646551119514]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 85}], {
             RGBColor[
             0.26126709675452753`, 0.3919386623526739, 0.9381901466989133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 88}], {
             RGBColor[
             0.2343125277851679, 0.36360770134749604`, 0.9366551238718196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 108}], {
             RGBColor[
             0.2800444750057945, 0.41167487744929976`, 0.9392594906116811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 117}], {
             RGBColor[
             0.21869250923105948`, 0.34719007148075093`, 0.9357655869229098]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 133}], {
             RGBColor[
             0.2505927164379196, 0.38071921184511703`, 0.9375822565312131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 152}], {
             RGBColor[
             0.22612393827552923`, 0.3550009745863041, 0.9361887958131783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 159}], {
             RGBColor[
             0.25347717812255377`, 0.3837509639611013, 0.9377465223569743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 173}], {
             RGBColor[
             0.3099077362629189, 0.437607436708477, 0.9411599161992759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 178}], {
             RGBColor[
             0.21785481111783467`, 0.34630959765062364`, 0.935717881254625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 49}], {
             RGBColor[
             0.46409235069374777`, 0.5749693711032751, 0.9511864931575826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 53}], {
             RGBColor[
             0.5688067096740002, 0.6608219372204345, 0.9591976942746201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 54}], {
             RGBColor[
             0.7471114929956602, 0.7911014986375555, 0.6818242326049438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 64}], {
             RGBColor[
             0.5676806016913061, 0.6599077120294969, 0.959109042929153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.7310843955752011, 0.737038335696917, 0.6195619855898489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 69}], {
             RGBColor[
             0.37782213400795434`, 0.4947977837110262, 0.9458889334343104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 119}], {
             RGBColor[
             0.6763280459297676, 0.4853122609339061, 0.5733568833580303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 123}], {
             RGBColor[
             0.4784773066745961, 0.5874288969649759, 0.9521030898325651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 132}], {
             RGBColor[
             0.40319785832980803`, 0.5214692788871429, 0.94733404339442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 171}], {
             RGBColor[
             0.40679020531210003`, 0.5252450633334856, 0.9475386222406603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 182}], {
             RGBColor[
             0.4233315585574587, 0.5396644216518027, 0.9485892515260115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 191}], {
             RGBColor[
             0.6579669038121483, 0.7306365663260646, 0.9679735835576617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 195}], {
             RGBColor[
             0.5034310381865006, 0.6077470219664445, 0.9540510819361487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 196}], {
             RGBColor[
             0.3694081793861806, 0.4859541839280068, 0.9454097711659308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 199}], {
             RGBColor[
             0.7505454658303996, 0.8010014916056775, 0.8412228920171474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 74}], {
             RGBColor[
             0.31831841781976944`, 0.44846525260187575`, 0.9415650157902389]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 85}], {
             RGBColor[
             0.2805891206818358, 0.4122473345873495, 0.9392905073772007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.2536345517124762, 0.3839163735821717, 0.937755484550107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 108}], {
             RGBColor[
             0.29936649893310274`, 0.4319835496839754, 0.9403598512899686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 121}], {
             RGBColor[
             0.25402964955357293`, 0.38433164646381435`, 0.9377779847876626]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 133}], {
             RGBColor[
             0.2699147403652278, 0.4010278840797926, 0.9386826172095004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 140}], {
             RGBColor[
             0.6422147641826323, 0.7059320445833706, 0.7490291245213738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 151}], {
             RGBColor[
             0.6423047351050197, 0.7073139713016436, 0.8452851258395946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 152}], {
             RGBColor[
             0.2454459622028375, 0.3753096468209797, 0.9372891564914656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 159}], {
             RGBColor[
             0.27279920204986197`, 0.40405963619577695`, 0.9388468830352616]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 161}], {
             RGBColor[
             0.2872671394725109, 0.41926635574719545`, 0.9396708106680862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 173}], {
             RGBColor[
             0.32922976019022715`, 0.45791610894315266`, 0.9422602768775632]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 51}], {
             RGBColor[
             0.1924833774375055, 0.31964261221079154`, 0.9342730156402028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 71}], {
             RGBColor[
             0.2832544040591832, 0.40996427332420193`, 0.9396284576905798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 73}], {
             RGBColor[
             0.2101247127148807, 0.3381847741125724, 0.9352776635862325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 76}], {
             RGBColor[
             0.23350932118742207`, 0.36276348028702554`, 0.9366093824443157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 81}], {
             RGBColor[
             0.25440003735864936`, 0.3847209475308929, 0.9377990778252221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 87}], {
             RGBColor[
             0.20973659970745412`, 0.3377768427339811, 0.9352555611246214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 89}], {
             RGBColor[
             0.2351425012723703, 0.3644800561059042, 0.93670238963408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 106}], {
             RGBColor[
             0.19390013127031533`, 0.3211317103164559, 0.9343536976750818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 107}], {
             RGBColor[
             0.21020159060141025`, 0.3382655776456545, 0.9352820416681398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 130}], {
             RGBColor[
             0.1935327654101925, 0.32074558550512594`, 0.9343327767328169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 131}], {
             RGBColor[
             0.19213265043958744`, 0.3192739758986036, 0.9342530422565254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 142}], {
             RGBColor[
             0.23238403787365935`, 0.361580736177178, 0.9365452992243044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 147}], {
             RGBColor[
             0.22614743845474522`, 0.3550256747646575, 0.9361901341136192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 149}], {
             RGBColor[
             0.1941370173040445, 0.32138069255734725`, 0.9343671879842612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 157}], {
             RGBColor[
             0.2045975584295754, 0.3323753845168943, 0.9349629003263764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 168}], {
             RGBColor[
             0.20608379372382724`, 0.3339375120439133, 0.935047539227696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 176}], {
             RGBColor[
             0.21842899524564835`, 0.34691310157433214`, 0.9357505801912747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 188}], {
             RGBColor[
             0.2579862693567474, 0.38807828505832953`, 0.9380183944910747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 189}], {
             RGBColor[
             0.19860085363697447`, 0.32607246756682684`, 0.9346213968597675]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 197}], {
             RGBColor[
             0.20173805393446126`, 0.32936986398947277`, 0.9348000557756375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 60}], {
             RGBColor[
             0.18536402715025152`, 0.3121597236660082, 0.9338675791734785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[
             0.20850897767362986`, 0.33648653414069934`, 0.935185649865899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 111}], {
             RGBColor[
             0.2049417486516364, 0.33273715026320094`, 0.934982501450339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 115}], {
             RGBColor[
             0.25238630356085545`, 0.3820238241610014, 0.9377056558638687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 163}], {
             RGBColor[
             0.2357550055079826, 0.36512383689254435`, 0.9367372708441793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 165}], {
             RGBColor[
             0.19777525937960444`, 0.32520471565663167`, 0.9345743804881674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 169}], {
             RGBColor[
             0.19092016970595993`, 0.3179995817718425, 0.9341839932724498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 58}], {
             RGBColor[
             0.9296752902178356, 0.8016782468054864, 0.5944321925119014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 68}], {
             RGBColor[
             0.9298826077939246, 0.7566572199616033, 0.27010292258186963`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 77}], {
             RGBColor[
             0.8580464518144618, 0.3836823814909788, 0.2007324013601752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 96}], {
             RGBColor[
             0.9175951806585165, 0.7926689208755102, 0.6148806669986575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 99}], {
             RGBColor[
             0.7252973005063621, 0.6401348451070372, 0.5975536479428364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 102}], {
             RGBColor[
             0.9339747756675465, 0.8048847960141194, 0.5871542851309398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[
             0.6650402658915442, 0.5906178095064059, 0.5929751287851128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 143}], {
             RGBColor[
             0.8772182848102179, 0.7604919813860003, 0.611670932866671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 166}], {
             RGBColor[
             0.8512516278317916, 0.7399182542257667, 0.6091593456597434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 172}], {
             RGBColor[
             0.8840573238836684, 0.5664132115032791, 0.22496692784453026`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 198}], {
             RGBColor[
             0.6221986923143263, 0.5535105917539171, 0.5902453016000886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 64}], {
             RGBColor[
             0.6702869821102313, 0.7421560430065834, 0.9679059544483493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 112}], {
             RGBColor[
             0.8262269535061243, 0.8650081965468237, 0.9779469895534628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 132}], {
             RGBColor[
             0.5058042387487333, 0.6037176098642293, 0.9561309549136163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 134}], {
             RGBColor[
             0.478958077481094, 0.5755005922270049, 0.9546021057447607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 153}], {
             RGBColor[
             0.49664985237205533`, 0.594095769360721, 0.9556096261521655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 156}], {
             RGBColor[
             0.7648803283778755, 0.4595346363622902, 0.5686955747885385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 183}], {
             RGBColor[
             0.823713544812509, 0.7798413316678898, 0.6197525703698252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 47}], {
             RGBColor[
             0.1896200136619846, 0.31663303533497, 0.934109951309154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 50}], {
             RGBColor[
             0.1933628575006826, 0.3205670015194474, 0.9343231007287265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 101}], {
             RGBColor[
             0.18958670352767176`, 0.3165980242718227, 0.9341080543462827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 105}], {
             RGBColor[
             0.19436779950481975`, 0.32162325928279867`, 0.9343803306891837]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 135}], {
             RGBColor[
             0.18995764910618526`, 0.3169879115941485, 0.9341291791482143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 144}], {
             RGBColor[
             0.19073384687984102`, 0.31780374466804207`, 0.9341733824631423]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 50}], {
             RGBColor[
             0.2000038325739316, 0.3275470873835711, 0.9347012944347058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 101}], {
             RGBColor[
             0.19622767860092072`, 0.3235781101359464, 0.934486248052262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 105}], {
             RGBColor[
             0.2010087745780687, 0.32860334514692235`, 0.934758524395163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 134}], {
             RGBColor[
             0.22156708062371444`, 0.3502114282727843, 0.9359292895111742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 135}], {
             RGBColor[
             0.19659862417943424`, 0.3239679974582722, 0.9345073728541936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 144}], {
             RGBColor[
             0.19737482195309003`, 0.32478383053216575`, 0.9345515761691217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 72}], {
             RGBColor[
             0.23184751916348642`, 0.3610168209955353, 0.9365147452774683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 76}], {
             RGBColor[
             0.23737108877035865`, 0.36682244286689847`, 0.9368293043951907]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 81}], {
             RGBColor[
             0.2582618049415859, 0.3887799101107659, 0.938018999776097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 87}], {
             RGBColor[
             0.21359836729039067`, 0.3418358053138541, 0.9354754830754963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 104}], {
             RGBColor[
             0.28879698411440874`, 0.4154790711874804, 0.939955479525905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 106}], {
             RGBColor[
             0.1977618988532519, 0.32519067289632886`, 0.9345736196259569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 147}], {
             RGBColor[
             0.2300092060376818, 0.3590846373445305, 0.9364100560644943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 154}], {
             RGBColor[
             0.2711822856025334, 0.4002221046769836, 0.9388330865127945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 157}], {
             RGBColor[
             0.20845932601251194`, 0.33643434709676723`, 0.9351828222772515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 158}], {
             RGBColor[
             0.2634190473924112, 0.39349797793107355`, 0.9383384198388076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 176}], {
             RGBColor[
             0.2222907628285849, 0.3509720641542051, 0.9359705021421497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 53}], {
             RGBColor[
             0.5270688387556056, 0.6260965211703475, 0.956144232988289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 54}], {
             RGBColor[
             0.7053736220772657, 0.7563760825874686, 0.6787707713186126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 65}], {
             RGBColor[
             0.6893465246568067, 0.7023129196468301, 0.6165085243035178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 69}], {
             RGBColor[
             0.33608426308955985`, 0.46007236766093923`, 0.9428354721479792]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 92}], {
             RGBColor[
             0.33340074855062923`, 0.45725182373587436`, 0.9426826499648912]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 118}], {
             RGBColor[
             0.4066109576924045, 0.5266077075173656, 0.9471298685655758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 119}], {
             RGBColor[
             0.634590175011373, 0.45058684488381917`, 0.5703034220716992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 123}], {
             RGBColor[
             0.43673943575620155`, 0.552703480914889, 0.949049628546234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 127}], {
             RGBColor[
             0.6485709500663741, 0.7216198574234791, 0.9680261155142653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[
             0.4384127064842775, 0.5541214790792388, 0.9491648974977769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 139}], {
             RGBColor[
             0.3540112919659183, 0.4789148116492719, 0.9438563899218253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 141}], {
             RGBColor[
             0.3830851867065078, 0.5062308671290127, 0.9456308272413769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 146}], {
             RGBColor[
             0.3338791466944457, 0.45775465051721964`, 0.9427098940314549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 155}], {
             RGBColor[
             0.5477722741141999, 0.6424322100267535, 0.9580969923209677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 171}], {
             RGBColor[
             0.36505233439370555`, 0.4905196472833987, 0.9444851609543292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 191}], {
             RGBColor[
             0.6162290328937537, 0.6959111502759776, 0.9649201222713306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 195}], {
             RGBColor[
             0.46169316726810605`, 0.5730216059163575, 0.9509976206498176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 196}], {
             RGBColor[
             0.3276703084677861, 0.4512287678779199, 0.9423563098795996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 199}], {
             RGBColor[
             0.7088075949120052, 0.7662760755555905, 0.8381694307308162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 97}], {
             RGBColor[
             0.21027301783359342`, 0.33834065219542714`, 0.9352861093433454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 101}], {
             RGBColor[
             0.19997052243961871`, 0.3275120763204238, 0.9346993974718347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 105}], {
             RGBColor[
             0.2047516184167667, 0.33253731133139974`, 0.9349716738147356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 134}], {
             RGBColor[
             0.22530992446241244`, 0.3541453944572617, 0.9361424389307468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 135}], {
             RGBColor[
             0.20034146801813224`, 0.3279019636427496, 0.9347205222737662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 144}], {
             RGBColor[
             0.20111766579178803`, 0.32871779671664314`, 0.9347647255886942]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 73}], {
             RGBColor[
             0.19983789794558066`, 0.3273726795683112, 0.9346918447030995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 87}], {
             RGBColor[
             0.19944978493815407`, 0.3269647481897199, 0.9346697422414884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 106}], {
             RGBColor[
             0.1836133165010153, 0.31031961577219463`, 0.9337678787919488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[
             0.1999147758321102, 0.3274534831013933, 0.9346962227850067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 130}], {
             RGBColor[
             0.18324595064089247`, 0.3099334909608647, 0.933746957849684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 131}], {
             RGBColor[
             0.18184583567028742`, 0.3084618813543424, 0.9336672233733925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 147}], {
             RGBColor[
             0.2158606236854452, 0.3442135802203963, 0.9356043152304863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 157}], {
             RGBColor[
             0.19431074366027534`, 0.32156328997263306`, 0.9343770814432435]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 168}], {
             RGBColor[
             0.1957969789545272, 0.32312541749965207`, 0.934461720344563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 189}], {
             RGBColor[
             0.18831403886767445`, 0.3152603730225656, 0.9340355779766345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 197}], {
             RGBColor[
             0.1914512391651612, 0.3185577694452115, 0.9342142368925045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 66}], {
             RGBColor[
             0.18456752137294713`, 0.3113225455926782, 0.9338222193477858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 80}], {
             RGBColor[
             0.20369103159656846`, 0.33142256733828307`, 0.9349112749643229]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 82}], {
             RGBColor[
             0.1987769890735687, 0.32625759707831903`, 0.9346314275123124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 100}], {
             RGBColor[
             0.1956898688928864, 0.3230128380336974, 0.9344556205850076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 120}], {
             RGBColor[
             0.1897634736745903, 0.3167838209041087, 0.9341181211446418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 124}], {
             RGBColor[
             0.20581307491926143`, 0.333652969415751, 0.9350321221922685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 125}], {
             RGBColor[
             0.2249359881773202, 0.35375236371269986`, 0.9361211438124999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 187}], {
             RGBColor[
             0.19453498240935546`, 0.32179897911547406`, 0.934389851508272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 54}], {
             RGBColor[
             0.810087981057518, 0.842228648704628, 0.6867819724356502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 65}], {
             RGBColor[
             0.7940608836370591, 0.7881654857639895, 0.6245197254205552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 69}], {
             RGBColor[
             0.4407986220698122, 0.5459249337780987, 0.9508466732650168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 92}], {
             RGBColor[
             0.4381151075308816, 0.5431043898530338, 0.9506938510819287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 118}], {
             RGBColor[
             0.5113253166726569, 0.612460273634525, 0.9551410696826135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 119}], {
             RGBColor[
             0.7393045339916254, 0.5364394110009786, 0.5783146231887367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 123}], {
             RGBColor[
             0.5414537947364539, 0.6385560470320484, 0.9570608296632714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 127}], {
             RGBColor[
             0.7532853090466265, 0.8074724235406385, 0.9760373166313029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 129}], {
             RGBColor[
             0.5431270654645298, 0.6399740451963982, 0.9571760986148143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 139}], {
             RGBColor[
             0.4587256509461706, 0.5647673777664313, 0.9518675910388628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 141}], {
             RGBColor[
             0.4877995456867602, 0.5920834332461721, 0.9536420283584146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 146}], {
             RGBColor[
             0.438593505674698, 0.543607216634379, 0.9507210951484925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 155}], {
             RGBColor[
             0.6524866330944523, 0.728284776143913, 0.9661081934380052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 171}], {
             RGBColor[
             0.4697666933739579, 0.5763722134005581, 0.9524963620713668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 182}], {
             RGBColor[
             0.48630804661931654`, 0.5907915717188752, 0.9535469913567178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 191}], {
             RGBColor[
             0.720943391874006, 0.781763716393137, 0.9729313233883682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 195}], {
             RGBColor[
             0.5664075262483584, 0.658874172033517, 0.9590088217668552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 196}], {
             RGBColor[
             0.43238466744803844`, 0.5370813339950793, 0.9503675109966372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 199}], {
             RGBColor[
             0.8135219538922576, 0.8521286416727499, 0.8461806318478537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 64}], {
             RGBColor[
             0.8089618730748239, 0.8413144235136905, 0.6866933210901831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 65}], {
             RGBColor[
             0.9723656669587191, 0.9184450471811106, 0.347146263750879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 118}], {
             RGBColor[
             0.6896300999943169, 0.7427398350516461, 0.6777676080129371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 119}], {
             RGBColor[
             0.9176093173132854, 0.6667189724180997, 0.30094116151906036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 123}], {
             RGBColor[
             0.7197585780581139, 0.7688356084491694, 0.6796873679935951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 127}], {
             RGBColor[
             0.9315900923682865, 0.9377519849577597, 0.6986638549616266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 140}], {
             RGBColor[
             0.9910580021453803, 0.9807455899537222, 0.48380004734696136`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 151}], {
             RGBColor[
             0.9911479730677677, 0.9821275166719952, 0.580056048665182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 155}], {
             RGBColor[
             0.8307914164161123, 0.8585643375610341, 0.688734731768329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 171}], {
             RGBColor[
             0.6480714766956179, 0.7066517748176793, 0.6751229004016905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 172}], {
             RGBColor[
             0.9288667542587956, 0.7360484350731749, 0.311047781867342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 191}], {
             RGBColor[
             0.899248175195666, 0.9120432778102582, 0.6955578617186919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 195}], {
             RGBColor[
             0.7447123095700184, 0.789153733450638, 0.681635360097179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 199}], {
             RGBColor[
             0.9918267372139176, 0.9824082030898711, 0.5688071701781774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 90}], {
             RGBColor[
             0.281574426125484, 0.41077439271759675`, 0.9394384697479637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 108}], {
             RGBColor[
             0.3219524714198415, 0.4532142784379034, 0.9417379396935124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 111}], {
             RGBColor[
             0.27800719710349053`, 0.40702500884009835`, 0.9392353213324036]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 115}], {
             RGBColor[
             0.3254517520127096, 0.4563116827378988, 0.9419584757459334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 163}], {
             RGBColor[
             0.3088204539598367, 0.4394116954694417, 0.9409900907262441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.2708407078314586, 0.3994925742335291, 0.9388272003702323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 175}], {
             RGBColor[
             0.4182247539712943, 0.5353839569381427, 0.9482243963930945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 177}], {
             RGBColor[
             0.2766340766323431, 0.4055817721640561, 0.9391571241529215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 183}], {
             RGBColor[
             0.6361311703010923, 0.6254168955585735, 0.6051471025896153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 109}], {
             RGBColor[
             0.19998929422011852`, 0.3275318066519287, 0.9347004664969638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 148}], {
             RGBColor[
             0.18807327130146562`, 0.31500731104493473`, 0.9340218666199227]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 150}], {
             RGBColor[
             0.18756580923325702`, 0.31447393623629405`, 0.933992967405861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 193}], {
             RGBColor[
             0.2060154437903921, 0.33386567193023686`, 0.9350436468001014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 88}], {
             RGBColor[
             0.1992012217508764, 0.32670349252007475`, 0.9346555869356892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 91}], {
             RGBColor[
             0.18403700151578473`, 0.31076493558589874`, 0.9337920070267542]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 103}], {
             RGBColor[
             0.1814602470714449, 0.3080566032892297, 0.9336452646731157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 117}], {
             RGBColor[
             0.18358120319676802`, 0.31028586265332964`, 0.9337660499867794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 121}], {
             RGBColor[
             0.1995963195919732, 0.32711876540171747`, 0.9346780871732447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 152}], {
             RGBColor[
             0.19101263224123774`, 0.3180967657588828, 0.9341892588770478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 164}], {
             RGBColor[
             0.1885063938143962, 0.3154625502675782, 0.9340465323062868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 178}], {
             RGBColor[
             0.1827435050835432, 0.30940538882320234`, 0.9337183443184945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 200}], {
             RGBColor[
             0.1862266556746971, 0.31306640093900795`, 0.9339167045918012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 77}], {
             RGBColor[
             0.8889478384033738, 0.5521228653145076, 0.5579177911517261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 96}], {
             RGBColor[
             0.9484965672474285, 0.961109404699039, 0.9720660567902085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 99}], {
             RGBColor[
             0.7561986870952739, 0.8085753289305662, 0.9547390377343874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 102}], {
             RGBColor[
             0.9648761622564584, 0.9733252798376484, 0.9443396749224908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 125}], {
             RGBColor[
             0.6124298936125201, 0.6826137072843086, 0.9449897432593624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 128}], {
             RGBColor[
             0.695941652480456, 0.7590582933299347, 0.9501605185766638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 137}], {
             RGBColor[
             0.6422345288762541, 0.7125398822624958, 0.9467383481519487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 166}], {
             RGBColor[
             0.8821530144207035, 0.9083587380492957, 0.9663447354512944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 170}], {
             RGBColor[
             0.8078923228953876, 0.8503457214275595, 0.9589431237256691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 192}], {
             RGBColor[
             0.7131454310850844, 0.7736227561744136, 0.951349727711992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 198}], {
             RGBColor[
             0.6531000789032383, 0.7219510755774461, 0.9474306913916395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 62}], {
             RGBColor[
             0.19206220882201708`, 0.3191999372922807, 0.9342490307106137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 92}], {
             RGBColor[
             0.21433501599530952`, 0.3426100698089493, 0.9355174341294674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 114}], {
             RGBColor[
             0.1828190891221793, 0.3094848324401137, 0.9337226487176782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 146}], {
             RGBColor[
             0.21481341413912597`, 0.34311289659029465`, 0.935544678196031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 184}], {
             RGBColor[
             0.1830159493280225, 0.30969174499811286`, 0.9337338596151724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 186}], {
             RGBColor[
             0.18364549933831636`, 0.3103534419747078, 0.9337697115569229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[
             0.19287248204991897`, 0.32005158582909543`, 0.934295174572251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 90}], {
             RGBColor[
             0.2041256683004301, 0.33187939807160033`, 0.9349360268816205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 111}], {
             RGBColor[
             0.20055843927843664`, 0.3281300141941019, 0.9347328784660603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 165}], {
             RGBColor[
             0.1933919500064047, 0.32059757958753266`, 0.9343247575038889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 169}], {
             RGBColor[
             0.18653686033276015`, 0.3133924457027435, 0.9339343702881713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 67}], {
             RGBColor[
             0.2316153172023224, 0.36077276201189723`, 0.936501521719292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 79}], {
             RGBColor[
             0.20075917656457537`, 0.3283410018093128, 0.9347443101575417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 84}], {
             RGBColor[
             0.19428775253280067`, 0.3215391248399355, 0.9343757721325461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 122}], {
             RGBColor[
             0.24263213866310665`, 0.37235213987400595`, 0.9371289134035569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 126}], {
             RGBColor[
             0.19350305800530745`, 0.3207143611390335, 0.9343310849400568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 179}], {
             RGBColor[
             0.2879403991921272, 0.41444560530367136`, 0.9399115732194068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 190}], {
             RGBColor[
             0.1957633885191688, 0.3230901118223337, 0.9344598074189618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 192}], {
             RGBColor[
             0.33652735532483224`, 0.4561925991586039, 0.9431004906757697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 114}], {
             RGBColor[
             0.19065828327948256`, 0.31772432253305627`, 0.9341690792278882]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 141}], {
             RGBColor[
             0.2718586483084913, 0.3998286032950302, 0.9389120419161632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 149}], {
             RGBColor[
             0.19270262269030192`, 0.3198730528724325, 0.9342855013330051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 167}], {
             RGBColor[
             0.19961760381417978`, 0.3271411364687542, 0.9346792992782123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 184}], {
             RGBColor[
             0.19085514348532573`, 0.3179312350910555, 0.9341802901253824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 189}], {
             RGBColor[
             0.19716645902323188`, 0.3245648278819121, 0.9345397102085116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 194}], {
             RGBColor[
             0.2007116762072222, 0.32829107592203804`, 0.9347416050824608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 197}], {
             RGBColor[
             0.20030365932071864`, 0.327862224304558, 0.9347183691243814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 70}], {
             RGBColor[
             0.1913615767368444, 0.3184635285481242, 0.9342091307498555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 110}], {
             RGBColor[
             0.18589948479502594`, 0.3127225236006417, 0.9338980726942099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 132}], {
             RGBColor[
             0.24611904809652904`, 0.37601710277136, 0.9373274877373701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 138}], {
             RGBColor[
             0.20677310926701956`, 0.33466202638493814`, 0.9350867947281298]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 145}], {
             RGBColor[
             0.1909329030445121, 0.31801296531800116`, 0.9341847184172432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 153}], {
             RGBColor[
             0.23696466171985112`, 0.36639526226785174`, 0.9368061589759192]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 185}], {
             RGBColor[
             0.2118614125837917, 0.3400101557879294, 0.9353765660745497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 65}], {
             RGBColor[
             0.792934775654365, 0.787251260573052, 0.6244310740750881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 132}], {
             RGBColor[
             0.4650482384089718, 0.5716822037632778, 0.9522031318796592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 138}], {
             RGBColor[
             0.4257022995794623, 0.5303271273768558, 0.949962438870419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 153}], {
             RGBColor[
             0.4558938520322939, 0.5620603632597695, 0.9516818031182084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 156}], {
             RGBColor[
             0.724124328038114, 0.42749923026133874`, 0.5647677517545815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 182}], {
             RGBColor[
             0.48518193863662246`, 0.5898773465279377, 0.9534583400112507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 185}], {
             RGBColor[
             0.4307906028962345, 0.5356752567798472, 0.9502522102168389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 199}], {
             RGBColor[
             0.8123958459095635, 0.8512144164818124, 0.8460919805023865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 118}], {
             RGBColor[
             0.6736030025738579, 0.6886766721110076, 0.6155053609978421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 119}], {
             RGBColor[
             0.9015822198928265, 0.6126558094774612, 0.23867891450396542`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 123}], {
             RGBColor[
             0.7037314806376549, 0.7147724455085309, 0.6174251209785002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 127}], {
             RGBColor[
             0.9155629949478274, 0.8836888220171212, 0.6364016079465316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 140}], {
             RGBColor[
             0.9750309047249213, 0.9266824270130837, 0.4215378003318664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 151}], {
             RGBColor[
             0.9751208756473086, 0.9280643537313567, 0.5177938016500871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 155}], {
             RGBColor[
             0.8147643189956533, 0.8045011746203956, 0.6264724847532339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 156}], {
             RGBColor[
             0.887528121922009, 0.5046298539287588, 0.2252206944152773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 171}], {
             RGBColor[
             0.6320443792751589, 0.6525886118770408, 0.6128606533865955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 172}], {
             RGBColor[
             0.9128396568383367, 0.6819852721325363, 0.24878553485224705`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 191}], {
             RGBColor[
             0.8832210777752071, 0.8579801148696197, 0.6332956147035969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 195}], {
             RGBColor[
             0.7286852121495595, 0.7350905705099995, 0.6193731130820839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 199}], {
             RGBColor[
             0.9757996397934585, 0.9283450401492326, 0.5065449231630825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 78}], {
             RGBColor[
             0.18323872675967784`, 0.30992589820368766`, 0.9337465464603355]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 80}], {
             RGBColor[
             0.20266968703316796`, 0.3303490694451636, 0.9348531109023811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 82}], {
             RGBColor[
             0.1977556445101682, 0.32518409918519964`, 0.9345732634503707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[
             0.18802367047876978`, 0.3149551774354076, 0.9340190419264479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 100}], {
             RGBColor[
             0.1946685243294859, 0.3219393401405779, 0.9343974565230659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 113}], {
             RGBColor[
             0.1939997700984511, 0.32123643704229315`, 0.9343593719589416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 120}], {
             RGBColor[
             0.18874212911118976`, 0.3157103230109893, 0.9340599570827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 124}], {
             RGBColor[
             0.2047917303558609, 0.33257947152263156`, 0.9349739581303267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 136}], {
             RGBColor[
             0.2031791949691239, 0.33088459459052233`, 0.9348821266255843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 187}], {
             RGBColor[
             0.19351363784595493`, 0.32072548122235467`, 0.9343316874463302]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 79}], {
             RGBColor[
             0.22503396848065443`, 0.3538553472238142, 0.9361267236458259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 82}], {
             RGBColor[
             0.2339276106645956, 0.3632031290486195, 0.9366332034112368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 100}], {
             RGBColor[
             0.2308404904839133, 0.3599583700039979, 0.936457396483932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 122}], {
             RGBColor[
             0.26690693057918574`, 0.3978664852885073, 0.9385113268918411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 125}], {
             RGBColor[
             0.2600866097683471, 0.39069789568300034`, 0.9381229197114243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 137}], {
             RGBColor[
             0.289891245032081, 0.42062407066118745`, 0.9398715246040107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 166}], {
             RGBColor[
             0.5298097305765306, 0.6164429264479874, 0.9594779119033563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 170}], {
             RGBColor[
             0.45554903905121463`, 0.5584299098262512, 0.952076300177731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 179}], {
             RGBColor[
             0.3122151911082063, 0.43995995071817273`, 0.941293986707691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 192}], {
             RGBColor[
             0.36080214724091136`, 0.4817069445731053, 0.944482904164054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 71}], {
             RGBColor[
             0.6623649639352431, 0.6847752584173, 0.6236785616506062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 75}], {
             RGBColor[
             0.7315668061877028, 0.7433887217645079, 0.6284543351107399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 81}], {
             RGBColor[
             0.6335105972347094, 0.659531932623991, 0.6218491817852485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 102}], {
             RGBColor[
             0.9650834798325474, 0.9283042529937652, 0.6200104049924591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 127}], {
             RGBColor[
             0.9178893661581602, 0.8915362183675095, 0.645439120800334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 129}], {
             RGBColor[
             0.7077311225760636, 0.7240378400232692, 0.6265779027838456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 140}], {
             RGBColor[
             0.977357275935254, 0.934529823363472, 0.4305753131856688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 143}], {
             RGBColor[
             0.9083269889752188, 0.8839114383656459, 0.6445270527281901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 155}], {
             RGBColor[
             0.817090690205986, 0.812348570970784, 0.6355099976070364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 172}], {
             RGBColor[
             0.9151660280486694, 0.6898326684829248, 0.25782304770604947`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 188}], {
             RGBColor[
             0.6370968292328074, 0.6628892701514275, 0.6220684984511013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 86}], {
             RGBColor[
             0.22595538032998164`, 0.3548238094983426, 0.9361791966875385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 92}], {
             RGBColor[
             0.2471305318648358, 0.3770802363436254, 0.937385090241619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 118}], {
             RGBColor[
             0.32034074100661103`, 0.44643612012511674`, 0.9418323088423037]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 123}], {
             RGBColor[
             0.3504692190704081, 0.47253189352264, 0.9437520688229617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 139}], {
             RGBColor[
             0.2677410752801248, 0.398743224257023, 0.938558830198553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 146}], {
             RGBColor[
             0.24760893000865222`, 0.37758306312497075`, 0.9374123343081827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 171}], {
             RGBColor[
             0.27878211770791206`, 0.41034805989114986`, 0.939187601231057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 174}], {
             RGBColor[
             0.21992361240255348`, 0.34848403897044045`, 0.9358356964272725]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 186}], {
             RGBColor[
             0.21644101520784265`, 0.3448236085093839, 0.9356373676690746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 191}], {
             RGBColor[
             0.5299588162079603, 0.6157395628837288, 0.9596225625480584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 195}], {
             RGBColor[
             0.3754229505823126, 0.4928500185241086, 0.9457000609265455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 196}], {
             RGBColor[
             0.24140009178199262`, 0.37105718048567105`, 0.9370587501563274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 110}], {
             RGBColor[
             0.185588460386286, 0.31239561722696946`, 0.9338803603142515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 132}], {
             RGBColor[
             0.2458080236877891, 0.37569019639768786`, 0.9373097753574117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 138}], {
             RGBColor[
             0.2064620848582796, 0.334335120011266, 0.9350690823481714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.19062187863577218`, 0.31768605894432894`, 0.9341670060372848]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 185}], {
             RGBColor[
             0.21155038817505178`, 0.3396832494142572, 0.9353588536945914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 73}], {
             RGBColor[
             0.29060892456725834`, 0.41769434068172157`, 0.9400472867534765]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 75}], {
             RGBColor[
             0.4329404581640204, 0.5480873032405589, 0.9491738543179573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 76}], {
             RGBColor[
             0.3139935330397997, 0.4422730468561747, 0.9413790056115596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 81}], {
             RGBColor[
             0.334884249211027, 0.4642305141000421, 0.942568700992466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 87}], {
             RGBColor[
             0.29022081155983176`, 0.4172864093031303, 0.9400251842918653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 89}], {
             RGBColor[
             0.315626713124748, 0.4439896226750534, 0.9414720128013241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 107}], {
             RGBColor[
             0.2906858024537879, 0.41777514421480366`, 0.9400516648353837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 127}], {
             RGBColor[
             0.6192630181344778, 0.6962347998435606, 0.9661586400075515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 129}], {
             RGBColor[
             0.40910477455238126`, 0.5287364214993203, 0.947297421991063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 141}], {
             RGBColor[
             0.3537772547746116, 0.4808458095490941, 0.9437633517346631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 142}], {
             RGBColor[
             0.312868249726037, 0.44109030274632716`, 0.9413149223915483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 147}], {
             RGBColor[
             0.3066316503071229, 0.4345352413338067, 0.9409597572808632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 155}], {
             RGBColor[
             0.5184643421823038, 0.6170471524468351, 0.9562295168142538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 168}], {
             RGBColor[
             0.2865680055762049, 0.4134470786130624, 0.93981716239494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 188}], {
             RGBColor[
             0.33847048120912504`, 0.4675878516274786, 0.9427880176583188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 197}], {
             RGBColor[
             0.2822222657868389, 0.40887943055862197`, 0.9395696789428815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 76}], {
             RGBColor[
             0.25872488056116644`, 0.3892666319476351, 0.9380453712475731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 81}], {
             RGBColor[
             0.2796155967323937, 0.4112240991915025, 0.9392350666284796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 104}], {
             RGBColor[
             0.31015077590521656`, 0.43792326026821704`, 0.9411715463782875]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 143}], {
             RGBColor[
             0.5544319884729032, 0.6356036049331575, 0.9619129375714212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 144}], {
             RGBColor[
             0.22584498306262032`, 0.3547077749707548, 0.9361729097264804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 154}], {
             RGBColor[
             0.2925360773933412, 0.42266629375772025`, 0.940049153365177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 158}], {
             RGBColor[
             0.284772839183219, 0.41594216701181014`, 0.93955448669119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 160}], {
             RGBColor[
             0.3481960203596565, 0.4708761388050667, 0.9435957557128356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 176}], {
             RGBColor[
             0.2436445546193927, 0.37341625323494165`, 0.9371865689945322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 181}], {
             RGBColor[
             0.345687120645864, 0.46870305597394574`, 0.9434358908416056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 75}], {
             RGBColor[
             0.3598107668197179, 0.47630780402892936`, 0.9448230602136101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 87}], {
             RGBColor[
             0.2170911202155293, 0.3455069100915008, 0.9356743901875181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.2424970217804455, 0.37221012346342386`, 0.9371212186969768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 107}], {
             RGBColor[
             0.21755611110948542`, 0.34599564500317415`, 0.9357008707310365]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 130}], {
             RGBColor[
             0.20088728591826768`, 0.3284756528626456, 0.9347516057957137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 142}], {
             RGBColor[
             0.23973855838173452`, 0.36931080353469764`, 0.9369641282872011]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 147}], {
             RGBColor[
             0.23350195896282042`, 0.3627557421221772, 0.936608963176516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 149}], {
             RGBColor[
             0.2014915378121197, 0.32911075991486693`, 0.934786017047158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 157}], {
             RGBColor[
             0.21195207893765056`, 0.34010545187441393`, 0.9353817293892732]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 167}], {
             RGBColor[
             0.20840651893599757`, 0.33637884351118863`, 0.9351798149923649]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 168}], {
             RGBColor[
             0.2134383142319024, 0.3416675794014329, 0.9354663682905927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 188}], {
             RGBColor[
             0.26534078986482257`, 0.3958083524158491, 0.9384372235539715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 189}], {
             RGBColor[
             0.20595537414504966`, 0.3338025349243465, 0.9350402259226642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 197}], {
             RGBColor[
             0.20909257444253643`, 0.33709993134699245`, 0.9352188848385342]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 85}], {
             RGBColor[
             0.3082012500479231, 0.4378314678081793, 0.9409888580526407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 88}], {
             RGBColor[
             0.2812466810785635, 0.40950050680300143`, 0.9394538352255469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 93}], {
             RGBColor[
             0.28865865838495014`, 0.4172909648985178, 0.9398759363681078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 95}], {
             RGBColor[
             0.29756419393855826`, 0.4266512474089263, 0.9403830934433266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 121}], {
             RGBColor[
             0.28164177891966025`, 0.4099157796846441, 0.9394763354631025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 140}], {
             RGBColor[
             0.6698268935487197, 0.7315161778042003, 0.7507274751968138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 152}], {
             RGBColor[
             0.2730580915689248, 0.4008937800418094, 0.9389875071669056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 159}], {
             RGBColor[
             0.30041133141594933`, 0.42964376941660665`, 0.9405452337107016]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 161}], {
             RGBColor[
             0.31487926883859824`, 0.44485048896802515`, 0.9413691613435261]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 162}], {
             RGBColor[
             0.39867126833608224`, 0.5197307476573095, 0.9466239585805827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 164}], {
             RGBColor[
             0.2705518531420833, 0.3982595645505048, 0.9388447805961444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 172}], {
             RGBColor[
             0.607635645662135, 0.48681902292365303`, 0.5779752097171944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 173}], {
             RGBColor[
             0.35684188955631446`, 0.48350024216398235`, 0.9439586275530032]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 180}], {
             RGBColor[
             0.34398171160205027`, 0.4723614023913367, 0.9431391883855662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 81}], {
             RGBColor[
             0.40408609146348656`, 0.52284397744725, 0.9473444744525996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 89}], {
             RGBColor[
             0.3848285553772075, 0.5026030860222612, 0.9462477862614576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 118}], {
             RGBColor[
             0.44650486801296785`, 0.559836113284655, 0.9500381665189955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 127}], {
             RGBColor[
             0.6884648603869374, 0.7548482631907685, 0.9709344134676849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 129}], {
             RGBColor[
             0.47830661680484077`, 0.5873498848465282, 0.9520731954511965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 141}], {
             RGBColor[
             0.42297909702707115`, 0.5394592728963019, 0.9485391251947967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 142}], {
             RGBColor[
             0.3820700919784965, 0.49970376609353495`, 0.9460906958516819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 147}], {
             RGBColor[
             0.3758334925595824, 0.4931487046810145, 0.9457355307409967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 155}], {
             RGBColor[
             0.5876661844347633, 0.6756606157940428, 0.9610052902743873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 168}], {
             RGBColor[
             0.3557698478286644, 0.47206054196027025`, 0.9445929358550735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 188}], {
             RGBColor[
             0.40767232346158455`, 0.5262013149746865, 0.9475637911184522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 191}], {
             RGBColor[
             0.656122943214317, 0.729139556043267, 0.9678284202247502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 81}], {
             RGBColor[
             0.28513916633926595`, 0.41702972106286573`, 0.9395496257462019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 87}], {
             RGBColor[
             0.2404757286880707, 0.37008561626595393`, 0.9370061090456012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 89}], {
             RGBColor[
             0.2658816302529869, 0.396788829637877, 0.93845293755506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[
             0.3156743455120887, 0.4437288821395802, 0.9414861054960099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 106}], {
             RGBColor[
             0.2246392602509319, 0.35344048384842863`, 0.9361042455960618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 107}], {
             RGBColor[
             0.2409407195820268, 0.37057435117762727`, 0.9370325895891196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 142}], {
             RGBColor[
             0.26312316685427595`, 0.39388950970915076`, 0.9382958471452842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 143}], {
             RGBColor[
             0.5599555580797754, 0.6414092268045206, 0.9622274966891435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 147}], {
             RGBColor[
             0.2568865674353618, 0.38733444829663033`, 0.9379406820345992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 154}], {
             RGBColor[
             0.29805964700021337`, 0.42847191562908343`, 0.9403637124828994]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[
             0.23533668741019195`, 0.36468415804886706`, 0.9367134482473564]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 158}], {
             RGBColor[
             0.2902964087900912, 0.4217477888831733, 0.9398690458089125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 176}], {
             RGBColor[
             0.24916812422626491`, 0.3792218751063049, 0.9375011281122546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 181}], {
             RGBColor[
             0.3512106902527362, 0.4745086778453089, 0.9437504499593281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 188}], {
             RGBColor[
             0.288725398337364, 0.42038705859030223`, 0.9397689424120548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 83}], {
             RGBColor[
             0.8718524916829569, 0.5391330266655409, 0.5785293580798063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 96}], {
             RGBColor[
             0.8768677288440547, 0.5431135393845314, 0.5783662656384824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 99}], {
             RGBColor[
             0.6845698486919003, 0.3905794636160585, 0.5610392465826612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 112}], {
             RGBColor[
             0.8793649622811279, 0.5449759719930563, 0.5741391008123097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 143}], {
             RGBColor[
             0.8364908329957561, 0.5109365998950215, 0.5751565315064958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 156}], {
             RGBColor[
             0.8180183371528791, 0.13950241180852277`, 0.1648876860473853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 160}], {
             RGBColor[
             0.6302548648825095, 0.34620913376693074`, 0.5568393496479103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 166}], {
             RGBColor[
             0.8105241760173298, 0.490362872734788, 0.5726449442995682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 170}], {
             RGBColor[
             0.736263484492014, 0.4323498561130519, 0.5652433325739429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 181}], {
             RGBColor[
             0.627745965168717, 0.3440360509358098, 0.5566794847766803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 183}], {
             RGBColor[
             0.8768515535875127, 0.45980910711412243`, 0.21594468162867203`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 192}], {
             RGBColor[
             0.6415165926817106, 0.355626890859906, 0.5576499365602658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 80}], {
             RGBColor[
             0.20236223698329917`, 0.33002591994929253`, 0.9348356020768727]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 82}], {
             RGBColor[
             0.1974481944602994, 0.3248609496893285, 0.9345557546248622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 98}], {
             RGBColor[
             0.18771622042890102`, 0.3146320279395365, 0.9340015331009395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 100}], {
             RGBColor[
             0.1943610742796171, 0.3216161906447068, 0.9343799476975574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 113}], {
             RGBColor[
             0.19369232004858233`, 0.320913287546422, 0.9343418631334333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 120}], {
             RGBColor[
             0.188434679061321, 0.31538717351511814`, 0.9340424482571915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 124}], {
             RGBColor[
             0.20448428030599214`, 0.3322563220267605, 0.9349564493048182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 136}], {
             RGBColor[
             0.2028717449192551, 0.3305614450946512, 0.9348646178000759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 187}], {
             RGBColor[
             0.19320618779608617`, 0.3204023317264835, 0.9343141786208218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 84}], {
             RGBColor[
             0.1877064038111327, 0.31462171005185247`, 0.93400097405908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 122}], {
             RGBColor[
             0.2360507899414387, 0.3654347250859229, 0.9367541153300909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 126}], {
             RGBColor[
             0.1869217092836395, 0.3137969463509505, 0.9339562868665908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 177}], {
             RGBColor[
             0.20578387384021699`, 0.33362227723022, 0.9350304592340161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 179}], {
             RGBColor[
             0.2813590504704592, 0.4075281905155883, 0.9395367751459407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 190}], {
             RGBColor[
             0.18918203979750087`, 0.31617269703425077`, 0.9340850093454959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 82}], {
             RGBColor[
             0.2168791547337895, 0.3452841209308045, 0.9356623190669078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 98}], {
             RGBColor[
             0.2071471807023911, 0.33505519918101245`, 0.9351080975429851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 100}], {
             RGBColor[
             0.2137920345531072, 0.3420393618861828, 0.935486512139603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 113}], {
             RGBColor[
             0.2131232803220724, 0.34133645878789803`, 0.9354484275754789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 116}], {
             RGBColor[
             0.23121046425376574`, 0.3603472358938047, 0.936478465942798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 120}], {
             RGBColor[
             0.20786563933481106`, 0.33581034475659416`, 0.9351490126992371]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 124}], {
             RGBColor[
             0.22391524057948223`, 0.35267949326823644`, 0.9360630137468638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 125}], {
             RGBColor[
             0.243038153837541, 0.3727788875651853, 0.9371520353670952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 136}], {
             RGBColor[
             0.2223027051927452, 0.3509846163361272, 0.9359711822421215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 137}], {
             RGBColor[
             0.2728427891012749, 0.40270506254337235`, 0.9389006402596817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 187}], {
             RGBColor[
             0.21263714806957626`, 0.34082550296795955`, 0.9354207430628674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 198}], {
             RGBColor[
             0.28370833912825916`, 0.4121162558583227, 0.9395929834993725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 87}], {
             RGBColor[
             0.261366444859298, 0.3920430835098213, 0.9381958044265076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 89}], {
             RGBColor[
             0.2867723464242142, 0.41874629688174436`, 0.9396426329359664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 104}], {
             RGBColor[
             0.336565061683316, 0.46568634938344766`, 0.9426758008769163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 107}], {
             RGBColor[
             0.26183143575325407`, 0.39253181842149465`, 0.938222284970026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 142}], {
             RGBColor[
             0.28401388302550323`, 0.4158469769530182, 0.9394855425261907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 143}], {
             RGBColor[
             0.5808462742510027, 0.663366694048388, 0.9634171920700499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 147}], {
             RGBColor[
             0.2777772836065891, 0.4092919155404977, 0.9391303774155055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 154}], {
             RGBColor[
             0.31895036317144065`, 0.45042938287295087`, 0.9415534078638058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 157}], {
             RGBColor[
             0.25622740358141927`, 0.3866416252927345, 0.9379031436282628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 158}], {
             RGBColor[
             0.3111871249613185, 0.44370525612704076`, 0.9410587411898188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 168}], {
             RGBColor[
             0.2577136388756711, 0.38820375281975344`, 0.9379877825295823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 176}], {
             RGBColor[
             0.2700588403974922, 0.4011793423501723, 0.938690823493161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 188}], {
             RGBColor[
             0.3096161145085913, 0.44234452583416967`, 0.9409586377929611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 98}], {
             RGBColor[
             0.20223313817939134`, 0.32989022892104847`, 0.9348282500909746]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 100}], {
             RGBColor[
             0.20887799203010743`, 0.3368743916262188, 0.9352066646875926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 120}], {
             RGBColor[
             0.2029515968118113, 0.3306453744966301, 0.9348691652472267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 124}], {
             RGBColor[
             0.21900119805648247`, 0.34751452300827246`, 0.9357831662948535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 125}], {
             RGBColor[
             0.23812411131454123`, 0.3676139173052213, 0.9368721879150849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 136}], {
             RGBColor[
             0.21738866266974544`, 0.34581964607616317`, 0.935691334790111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 137}], {
             RGBColor[
             0.26792874657827515`, 0.39754009228340836`, 0.9386207928076713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 187}], {
             RGBColor[
             0.2077231055465765, 0.3356605327079955, 0.9351408956108569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 198}], {
             RGBColor[
             0.2787942966052594, 0.4069512855983587, 0.9393131360473621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 122}], {
             RGBColor[
             0.6021548677029418, 0.6767924582408489, 0.9659897173678593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 156}], {
             RGBColor[
             0.8725518288358358, 0.5445084384740636, 0.5791990441271917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 166}], {
             RGBColor[
             0.8650576677002866, 0.8953688994003288, 0.9869563023793746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 170}], {
             RGBColor[
             0.7907969761749707, 0.8373558827785927, 0.9795546906537492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 175}], {
             RGBColor[
             0.7134786289406714, 0.7747821951592325, 0.9733333335119576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 179}], {
             RGBColor[
             0.6474631282319623, 0.7188859236705143, 0.9687723771837091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 183}], {
             RGBColor[
             0.9313850452704695, 0.8648151337796632, 0.6302560397084783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 192}], {
             RGBColor[
             0.6960500843646674, 0.7606329175254469, 0.9719612946400722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 126}], {
             RGBColor[
             0.1804502852518648, 0.30699506938157317`, 0.9335877488415951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 190}], {
             RGBColor[
             0.18271061576572617`, 0.30937082006487343`, 0.9337164713205002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 88}], {
             RGBColor[
             0.24351738394062986`, 0.3732825887884752, 0.9371793268125088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 117}], {
             RGBColor[
             0.22789736538652144`, 0.3568649589217301, 0.9362897898635989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[
             0.24391248178172664`, 0.37369786167011787`, 0.9372018270500644]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 133}], {
             RGBColor[
             0.25979757259338154`, 0.39039409928609614`, 0.9381064594719022]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 140}], {
             RGBColor[
             0.632097596410786, 0.6952982597896742, 0.7484529667837756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 152}], {
             RGBColor[
             0.2353287944309912, 0.36467586202728325`, 0.9367129987538674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 159}], {
             RGBColor[
             0.26268203427801573`, 0.3934258514020805, 0.9382707252976634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 161}], {
             RGBColor[
             0.2771499717006646, 0.408632570953499, 0.939094652930488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 173}], {
             RGBColor[
             0.31911259241838086`, 0.4472823241494562, 0.941684119139965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 200}], {
             RGBColor[
             0.23054281786445055`, 0.35964549720740835`, 0.9364404444686207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 92}], {
             RGBColor[
             0.22327186579105107`, 0.35200326557327766`, 0.9360263745044504]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[
             0.19625374198187168`, 0.3236055044018397, 0.9344877323232499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 171}], {
             RGBColor[
             0.25492345163412733`, 0.3852710891208021, 0.9378288854938884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 174}], {
             RGBColor[
             0.19606494632876875`, 0.3234070682000927, 0.9344769806901039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 196}], {
             RGBColor[
             0.2175414257082079, 0.3459802097153233, 0.9357000344191588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 89}], {
             RGBColor[
             0.24210890877301894`, 0.37180219208483256`, 0.9370991162353657]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 106}], {
             RGBColor[
             0.20086653877096394`, 0.3284538462953842, 0.9347504242763673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 107}], {
             RGBColor[
             0.21716799810205883`, 0.34558771362458285`, 0.9356787682694253]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 130}], {
             RGBColor[
             0.20049917291084113`, 0.3280677214840543, 0.9347295033341025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 131}], {
             RGBColor[
             0.19909905794023608`, 0.326596111877532, 0.934649768857811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 142}], {
             RGBColor[
             0.23935044537430794`, 0.3689028721561064, 0.9369420258255899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 147}], {
             RGBColor[
             0.23311384595539386`, 0.3623478107435859, 0.9365868607149048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[
             0.2742869255202454, 0.40348527807603907`, 0.9390098911632051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 157}], {
             RGBColor[
             0.21156396593022397`, 0.3396975204958227, 0.9353596269276621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 168}], {
             RGBColor[
             0.21305020122447582`, 0.34125964802284164`, 0.9354442658289815]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 176}], {
             RGBColor[
             0.22539540274629694`, 0.3542352375532605, 0.9361473067925603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 188}], {
             RGBColor[
             0.264952676857396, 0.39540042103725787`, 0.9384151210923604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 91}], {
             RGBColor[
             0.20139859473617852`, 0.32901307084912135`, 0.93478072407648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 93}], {
             RGBColor[
             0.22397479227765688`, 0.3527420858788138, 0.936066405127976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 95}], {
             RGBColor[
             0.23288032783126497`, 0.3621023683892223, 0.9365735622031948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 103}], {
             RGBColor[
             0.1988218402918387, 0.32630473855245234`, 0.9346339817228415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 117}], {
             RGBColor[
             0.2009427964171618, 0.32853399791655225`, 0.9347547670365053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 121}], {
             RGBColor[
             0.21695791281236698`, 0.34536690066494, 0.9356668042229707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 152}], {
             RGBColor[
             0.20837422546163153`, 0.3363449010221054, 0.9351779759267738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 159}], {
             RGBColor[
             0.23572746530865607`, 0.3650948903969026, 0.9367357024705698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 161}], {
             RGBColor[
             0.25019540273130497`, 0.38030160994832113`, 0.9375596301033943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 164}], {
             RGBColor[
             0.20586798703479003`, 0.3337106855308008, 0.9350352493560126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 173}], {
             RGBColor[
             0.2921580234490212, 0.41895136314427833`, 0.9401490963128714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 180}], {
             RGBColor[
             0.279297845494757, 0.4078125233716327, 0.9393296571454344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 200}], {
             RGBColor[
             0.20358824889509092`, 0.3313145362022305, 0.9349054216415271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 106}], {
             RGBColor[
             0.22627244033588012`, 0.3551570596673073, 0.9361972527858261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 107}], {
             RGBColor[
             0.24257389966697504`, 0.37229092699650596`, 0.9371255967788841]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 142}], {
             RGBColor[
             0.2647563469392241, 0.39560608552802945`, 0.9383888543350487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 147}], {
             RGBColor[
             0.25851974752031004`, 0.38905102411550896`, 0.9380336892243635]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 154}], {
             RGBColor[
             0.29969282708516165`, 0.4301884914479621, 0.9404567196726639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 157}], {
             RGBColor[
             0.23696986749514018`, 0.36640073386774574`, 0.9368064554371207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 168}], {
             RGBColor[
             0.23845610278939203`, 0.36796286139476475`, 0.9368910943384403]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 176}], {
             RGBColor[
             0.25080130431121317`, 0.3809384509251836, 0.937594135302019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 188}], {
             RGBColor[
             0.29035857842231216`, 0.42210363440918097`, 0.939861949601819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 111}], {
             RGBColor[
             0.22370338980181498`, 0.3524568246687931, 0.9360509491584807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 115}], {
             RGBColor[
             0.27114794471103404`, 0.4017434985665935, 0.9387741035720105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 163}], {
             RGBColor[
             0.2545166466581612, 0.38484351129813643`, 0.9378057185523212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 165}], {
             RGBColor[
             0.21653690052978303`, 0.3449243900622238, 0.9356428281963094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 169}], {
             RGBColor[
             0.20968181085613852`, 0.3377192561774346, 0.9352524409805917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 175}], {
             RGBColor[
             0.36392094666961883`, 0.4808157727668374, 0.9450400242191717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 177}], {
             RGBColor[
             0.22233026933066752`, 0.35101358799275084`, 0.9359727519789987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 103}], {
             RGBColor[
             0.18365762005674702`, 0.31036618161827634`, 0.9337704018139066]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 117}], {
             RGBColor[
             0.1857785761820701, 0.31259544098237624`, 0.9338911871275704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 121}], {
             RGBColor[
             0.2017936925772753, 0.329428343730764, 0.9348032243140356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 152}], {
             RGBColor[
             0.19321000522653986`, 0.3204063440879294, 0.9343143960178388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 159}], {
             RGBColor[
             0.22056324507356437`, 0.3491563334627266, 0.9358721225616348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 164}], {
             RGBColor[
             0.19070376679969833`, 0.3177721285966248, 0.9341716694470776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 200}], {
             RGBColor[
             0.18842402865999922`, 0.3153759792680545, 0.9340418417325922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 118}], {
             RGBColor[
             0.31765722646768046`, 0.4436155762000519, 0.9416794866592155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 123}], {
             RGBColor[
             0.34778570453147756`, 0.4697113495975751, 0.9435992466398737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 139}], {
             RGBColor[
             0.26505756074119424`, 0.3959226803319581, 0.938406008015465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 141}], {
             RGBColor[
             0.29413145548178377`, 0.42323873581169885`, 0.9401804453350167]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 146}], {
             RGBColor[
             0.24492541546972163`, 0.3747625191999059, 0.9372595121250946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 171}], {
             RGBColor[
             0.2760986031689815, 0.40752751596608494`, 0.939034779047969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 174}], {
             RGBColor[
             0.2172400978636229, 0.3456634950453756, 0.9356828742441843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 186}], {
             RGBColor[
             0.21375750066891208`, 0.34200306458431906`, 0.9354845454859864]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 191}], {
             RGBColor[
             0.5272753016690297, 0.6129190189586639, 0.9594697403649703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 195}], {
             RGBColor[
             0.372739436043382, 0.49002947459904367`, 0.9455472387434574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 196}], {
             RGBColor[
             0.23871657724306206`, 0.3682366365606061, 0.9369059279732393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 95}], {
             RGBColor[
             0.24029230513765162`, 0.36989282648473865`, 0.9369956633457557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 121}], {
             RGBColor[
             0.22436989011875363`, 0.3531573587604565, 0.9360889053655316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 150}], {
             RGBColor[
             0.21197440955790398`, 0.3401289227721434, 0.9353830010850614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 159}], {
             RGBColor[
             0.24313944261504272`, 0.37288534849241906`, 0.9371578036131307]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 161}], {
             RGBColor[
             0.2576073800376916, 0.38809206804383756`, 0.9379817312459552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 162}], {
             RGBColor[
             0.34139937953517563`, 0.46297232673312194`, 0.9432365284830118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 164}], {
             RGBColor[
             0.2132799643411767, 0.3415011436263172, 0.9354573504985735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 173}], {
             RGBColor[
             0.29957000075540785`, 0.42674182123979476`, 0.9405711974554323]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 180}], {
             RGBColor[
             0.28670982280114365`, 0.41560298146714914`, 0.9397517582879953]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 200}], {
             RGBColor[
             0.21100022620147757`, 0.339104994297747, 0.935327522784088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 174}], {
             RGBColor[
             0.19022197405444352`, 0.31726573387393764`, 0.9341442320629838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 196}], {
             RGBColor[
             0.21169845343388266`, 0.3398388753891681, 0.9353672857920389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 121}], {
             RGBColor[
             0.23327542567236176`, 0.36251764127086494`, 0.9365960624407503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 150}], {
             RGBColor[
             0.2208799451115121, 0.3494892052825519, 0.9358901581602801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 159}], {
             RGBColor[
             0.2520449781686508, 0.3822456310028275, 0.9376649606883494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 161}], {
             RGBColor[
             0.26651291559129975`, 0.397452350554246, 0.9384888883211739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 162}], {
             RGBColor[
             0.35030491508878375`, 0.4723326092435304, 0.9437436855582304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 164}], {
             RGBColor[
             0.22218549989478478`, 0.35086142613672566`, 0.9359645075737923]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 173}], {
             RGBColor[
             0.308475536309016, 0.4361021037502032, 0.9410783545306509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 180}], {
             RGBColor[
             0.2956153583547517, 0.42496326397755757`, 0.9402589153632142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 99}], {
             RGBColor[
             0.7441185775359549, 0.79956600300059, 0.9751875122211435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 102}], {
             RGBColor[
             0.9527960526971394, 0.9643159539076722, 0.964788149409247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 125}], {
             RGBColor[
             0.600349784053201, 0.6736043813543324, 0.9654382177461185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 128}], {
             RGBColor[
             0.683861542921137, 0.7500489673999585, 0.97060899306342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 137}], {
             RGBColor[
             0.630154419316935, 0.7035305563325196, 0.9671868226387048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 166}], {
             RGBColor[
             0.8700729048613844, 0.8993494121193195, 0.9867932099380505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 170}], {
             RGBColor[
             0.7958122133360686, 0.8413363954975833, 0.9793915982124253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 198}], {
             RGBColor[
             0.6410199693439192, 0.7129417496474699, 0.9678791658783956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 105}], {
             RGBColor[
             0.21127795983773054`, 0.3393969099587784, 0.9353433393038026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 134}], {
             RGBColor[
             0.23183626588337625`, 0.3610049930846403, 0.9365141044198138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 135}], {
             RGBColor[
             0.20686780943909605`, 0.33476156227012827`, 0.9350921877628332]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 153}], {
             RGBColor[
             0.24952804077433757`, 0.37960017021835646`, 0.9375216248272185]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 100}], {
             RGBColor[
             0.19914601799870904`, 0.3266454698764268, 0.9346524431636698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 109}], {
             RGBColor[
             0.2049550918267402, 0.33275117478624117`, 0.9349832613244216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 113}], {
             RGBColor[
             0.19847726376767427`, 0.32594256677814204`, 0.9346143585995457]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 116}], {
             RGBColor[
             0.21656444769936758`, 0.34495334388404864`, 0.9356443969668649]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 120}], {
             RGBColor[
             0.19321962278041294`, 0.32041645274683817`, 0.9343149437233039]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 124}], {
             RGBColor[
             0.20926922402508408`, 0.3372856012584804, 0.9352289447709307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 125}], {
             RGBColor[
             0.22839213728314284`, 0.35738499555542924`, 0.936317966391162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 136}], {
             RGBColor[
             0.20765668863834705`, 0.33559072432637116`, 0.9351371132661883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 187}], {
             RGBColor[
             0.1979911315151781, 0.3254316109582035, 0.9345866740869342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 102}], {
             RGBColor[
             0.7604981725449849, 0.8117818781391992, 0.9474611303534258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 109}], {
             RGBColor[
             0.38461485844464394`, 0.49643648481667146`, 0.9467764936235569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 116}], {
             RGBColor[
             0.39622421431727134`, 0.5086386539144789, 0.9474376292660001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 128}], {
             RGBColor[
             0.49156366276898256`, 0.5975148916314856, 0.9532819740075988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 136}], {
             RGBColor[
             0.3873164552562508, 0.49927603435680146`, 0.9469303455653235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 137}], {
             RGBColor[
             0.4378565391647805, 0.5509964805640466, 0.9498598035828838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 162}], {
             RGBColor[
             0.5016163434350541, 0.6062220183620153, 0.9539225219304044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 193}], {
             RGBColor[
             0.3906410080149175, 0.5027703500949796, 0.9471196739266945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 198}], {
             RGBColor[
             0.44872208919176476`, 0.5604076738789969, 0.9505521468225746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 113}], {
             RGBColor[
             0.20512211761839033`, 0.33292672948331237`, 0.9349927731961636]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 120}], {
             RGBColor[
             0.199864476631129, 0.3274006154520085, 0.934693358319922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 124}], {
             RGBColor[
             0.21591407787580016`, 0.3442697639636507, 0.9356073593675487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 125}], {
             RGBColor[
             0.23503699113385892`, 0.36436915826059957`, 0.9366963809877801]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 136}], {
             RGBColor[
             0.21430154248906313`, 0.3425748870315415, 0.9355155278628062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 137}], {
             RGBColor[
             0.26484162639759284`, 0.3942953332387867, 0.9384449858803665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 187}], {
             RGBColor[
             0.2046359853658942, 0.3324157736633738, 0.9349650886835521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 198}], {
             RGBColor[
             0.2757071764245771, 0.40370652655373696`, 0.9391373291200573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 105}], {
             RGBColor[
             0.20097546444375586`, 0.32856833408377506`, 0.9347566274322918]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 134}], {
             RGBColor[
             0.22153377048940157`, 0.350176417209637, 0.9359273925483029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 135}], {
             RGBColor[
             0.1965653140451214, 0.3239329863951249, 0.9345054758913225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 144}], {
             RGBColor[
             0.19734151181877715`, 0.32474881946901846`, 0.9345496792062504]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 128}], {
             RGBColor[
             0.700241137930167, 0.7622648425385679, 0.9428826111957023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 140}], {
             RGBColor[
             0.981449443808876, 0.9827573994159884, 0.747626675734739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 162}], {
             RGBColor[
             0.7102938185962386, 0.7709719692690975, 0.9435231591185078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 172}], {
             RGBColor[
             0.9192581959222914, 0.7380602445354411, 0.5748744102551196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 180}], {
             RGBColor[
             0.6556042618622065, 0.7236026240031248, 0.9400383889234916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 117}], {
             RGBColor[
             0.1832018217377303, 0.30988710868570724`, 0.9337444447739318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 152}], {
             RGBColor[
             0.19063325078220003`, 0.31769801179126034`, 0.9341676536642003]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 178}], {
             RGBColor[
             0.1823641236245055, 0.3090066348555799, 0.933696739105647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 200}], {
             RGBColor[
             0.18584727421565939`, 0.3126676469713855, 0.9338950993789537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 143}], {
             RGBColor[
             0.6113814534238254, 0.6900658551251025, 0.9653536718198579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 154}], {
             RGBColor[
             0.3494855423442635, 0.47712854394966536`, 0.9434898876136137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 158}], {
             RGBColor[
             0.3417223041341413, 0.47040441720375525`, 0.9429952209396267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 160}], {
             RGBColor[
             0.4051454853105788, 0.5253383889970118, 0.9470364899612722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 176}], {
             RGBColor[
             0.300594019570315, 0.4278785034268868, 0.9406273032429688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 181}], {
             RGBColor[
             0.4026365855967863, 0.5231653061658909, 0.9468766250900423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 188}], {
             RGBColor[
             0.34015129368141406`, 0.46904368691088416`, 0.9428951175427689]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 134}], {
             RGBColor[
             0.22631486646654955`, 0.35520165222061295`, 0.936199668891204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 135}], {
             RGBColor[
             0.20134641002226938`, 0.32895822140610087`, 0.9347777522342233]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 144}], {
             RGBColor[
             0.20212260779592514`, 0.3297740544799944, 0.9348219555491514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.20133152966492007`, 0.3289425812070576, 0.9347769048198857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 130}], {
             RGBColor[
             0.1846627044737023, 0.31142258906652903`, 0.933827639884563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 131}], {
             RGBColor[
             0.18326258950309726`, 0.3099509794600067, 0.9337479054082716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 142}], {
             RGBColor[
             0.22351397693716918`, 0.3522577397385811, 0.9360401623760504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 147}], {
             RGBColor[
             0.21727737751825504`, 0.3457026783260606, 0.9356849972653654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 157}], {
             RGBColor[
             0.1957274974930852, 0.3230523880782974, 0.9344577634781225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 176}], {
             RGBColor[
             0.20955893430915817`, 0.33759010513573523`, 0.9352454433430207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 130}], {
             RGBColor[
             0.20096416380479723`, 0.32855645639572767`, 0.9347559838776209]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 131}], {
             RGBColor[
             0.19956404883419218`, 0.32708484678920535`, 0.9346762494013294]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 142}], {
             RGBColor[
             0.23981543626826407`, 0.36939160706777974`, 0.9369685063691083]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[
             0.23357883684934996`, 0.36283654565525925`, 0.9366133412584232]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 154}], {
             RGBColor[
             0.27475191641420155`, 0.4039740129877124, 0.9390363717067235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.2120289568241801, 0.34018625540749603`, 0.9353861074711805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 168}], {
             RGBColor[
             0.21351519211843195`, 0.34174838293451504`, 0.9354707463724999]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 176}], {
             RGBColor[
             0.22586039364025307`, 0.35472397246493387`, 0.9361737873360787]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 188}], {
             RGBColor[
             0.2654176677513521, 0.39588915594893126`, 0.9384416016358788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 111}], {
             RGBColor[
             0.26408143509617243`, 0.39489671038909974`, 0.9383504191040295]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 115}], {
             RGBColor[
             0.3115259900053915, 0.4441833842869002, 0.9410735735175593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 133}], {
             RGBColor[
             0.27857495084464845`, 0.41013031438272207`, 0.9391758033846701]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 151}], {
             RGBColor[
             0.6509649455844404, 0.716416401604573, 0.8457783120147642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 163}], {
             RGBColor[
             0.29489469195251866`, 0.4272833970184431, 0.94010518849787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 165}], {
             RGBColor[
             0.25691494582414054`, 0.38736427578253046`, 0.937942298141858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 175}], {
             RGBColor[
             0.4042989919639763, 0.5232556584871441, 0.9473394941647204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 113}], {
             RGBColor[
             0.2109311914464215, 0.33903243439312675`, 0.9353235913569153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 116}], {
             RGBColor[
             0.2290183753781148, 0.3580432114990334, 0.9363536297242345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 124}], {
             RGBColor[
             0.22172315170383133`, 0.35037546887346516`, 0.9359381775283004]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 128}], {
             RGBColor[
             0.32435782382982603`, 0.44691944921604004`, 0.9421979744658333]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 136}], {
             RGBColor[
             0.22011061631709428`, 0.3486805919413559, 0.935846346023558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 148}], {
             RGBColor[
             0.20549299658683456`, 0.33331654679423195`, 0.9350138942047502]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 193}], {
             RGBColor[
             0.223435169075761, 0.3521749076795341, 0.936035674384929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 138}], {
             RGBColor[
             0.20099999291646117`, 0.32859411506378333`, 0.9347580242925257]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 145}], {
             RGBColor[
             0.18515978669395372`, 0.31194505399684636`, 0.9338559479816391]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 115}], {
             RGBColor[
             0.26758071568904057`, 0.3979941146890951, 0.9385709551564505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 163}], {
             RGBColor[
             0.25094941763616774`, 0.3810941274206381, 0.9376025701367612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 165}], {
             RGBColor[
             0.21296967150778956`, 0.3411750061847254, 0.9354396797807493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 169}], {
             RGBColor[
             0.20611458183414505`, 0.33396987229993624`, 0.9350492925650316]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 175}], {
             RGBColor[
             0.36035371764762536`, 0.477066388889339, 0.9448368758036116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 177}], {
             RGBColor[
             0.21876304030867405`, 0.3472642041152524, 0.9357696035634386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 134}], {
             RGBColor[
             0.5941420485372255, 0.6663173396662936, 0.9607153178159171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 143}], {
             RGBColor[
             0.8985367952768839, 0.9217855718880776, 0.9850776323188054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 156}], {
             RGBColor[
             0.880064299434007, 0.550351383801579, 0.5748087868596949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 160}], {
             RGBColor[
             0.6923008271636373, 0.757058105759987, 0.9667604504602199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 181}], {
             RGBColor[
             0.6897919274498447, 0.754885022928866, 0.9666005855889899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 183}], {
             RGBColor[
             0.9388975158686406, 0.8706580791071786, 0.6258657824409817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 116}], {
             RGBColor[
             0.22254054731904888`, 0.35123460349093416`, 0.9359847269993585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 124}], {
             RGBColor[
             0.2152453236447654, 0.343566860865366, 0.9355692748034243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 128}], {
             RGBColor[
             0.3178799957707601, 0.44011084120794086`, 0.9418290717409573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 136}], {
             RGBColor[
             0.21363278825802834`, 0.3418719839332567, 0.9354774432986821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 148}], {
             RGBColor[
             0.19901516852776863`, 0.3265079387861328, 0.9346449914798742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 187}], {
             RGBColor[
             0.20396723113485943`, 0.331712870565089, 0.934927004119428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 193}], {
             RGBColor[
             0.21695734101669506`, 0.34536629967143495`, 0.9356667716600531]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 198}], {
             RGBColor[
             0.2750384221935423, 0.4030036234554522, 0.939099244555933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 167}], {
             RGBColor[
             0.19037448411434205`, 0.3174260316165872, 0.9341529172852767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 184}], {
             RGBColor[
             0.18161202378548802`, 0.3082161302388885, 0.9336539081324469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 186}], {
             RGBColor[
             0.18224157379578187`, 0.3088778272154834, 0.9336897600741974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 194}], {
             RGBColor[
             0.19146855650738448`, 0.3185759710698711, 0.9342152230895253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 133}], {
             RGBColor[
             0.2820742314375166, 0.41322771868271746`, 0.939396339437091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 163}], {
             RGBColor[
             0.2983939725453868, 0.4303808013184385, 0.9403257245502908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 165}], {
             RGBColor[
             0.2604142264170086, 0.39046168008252585`, 0.9381628341942789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 175}], {
             RGBColor[
             0.4077982725568444, 0.5263530627871394, 0.9475600302171414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 124}], {
             RGBColor[
             0.2333325075764587, 0.3625776379712726, 0.9365993131707435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 128}], {
             RGBColor[
             0.33596717970245343`, 0.45912161831384746`, 0.9428591101082765]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 136}], {
             RGBColor[
             0.23171997218972168`, 0.36088276103916334`, 0.9365074816660013]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 148}], {
             RGBColor[
             0.21710235245946194`, 0.3455187158920394, 0.9356750298471934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 193}], {
             RGBColor[
             0.2350445249483884, 0.36437707677734155`, 0.9366968100273723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 198}], {
             RGBColor[
             0.29312560612523564`, 0.42201440056135886`, 0.9401292829232522]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 121}], {
             RGBColor[
             0.2013378942582586, 0.3289492707981949, 0.9347772672740609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 152}], {
             RGBColor[
             0.19275420690752315`, 0.3199272711553603, 0.934288438977864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 159}], {
             RGBColor[
             0.22010744675454766`, 0.3486772605301575, 0.9358461655216599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 164}], {
             RGBColor[
             0.19024796848068162`, 0.3172930556640557, 0.9341457124071029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 178}], {
             RGBColor[
             0.18448507974982858`, 0.3112358942196798, 0.9338175244193107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 200}], {
             RGBColor[
             0.1879682303409825, 0.3148969063354854, 0.9340158846926173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 119}], {
             RGBColor[
             0.6188466529284243, 0.4369505973479967, 0.5693002587660235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 123}], {
             RGBColor[
             0.42099591367325284`, 0.5390672333790665, 0.9480464652405584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 127}], {
             RGBColor[
             0.6328274279834254, 0.7079836098876566, 0.9670229522085898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 129}], {
             RGBColor[
             0.4226691844013287, 0.5404852315434163, 0.9481617341921013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 139}], {
             RGBColor[
             0.33826776988296947`, 0.4652785641134494, 0.9428532266161497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[
             0.36734166462355905`, 0.4925946195931902, 0.9446276639357014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 146}], {
             RGBColor[
             0.3181356246114969, 0.44411840298139715`, 0.9417067307257794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 155}], {
             RGBColor[
             0.5320287520312512, 0.6287959624909311, 0.9570938290152922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 171}], {
             RGBColor[
             0.3493088123107567, 0.4768833997475762, 0.9434819976486537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 191}], {
             RGBColor[
             0.6004855108108049, 0.6822749027401551, 0.9639169589656551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.44594964518515734`, 0.559385358380535, 0.9499944573441421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 196}], {
             RGBColor[
             0.3119267863848373, 0.4375925203420974, 0.941353146573924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[
             0.6930640728290565, 0.752639828019768, 0.8371662674251406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 123}], {
             RGBColor[
             0.6489751309922214, 0.46304637074551996`, 0.5712200187466816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 127}], {
             RGBColor[
             0.8608066453023939, 0.6319627472541103, 0.5901965057147129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 140}], {
             RGBColor[
             0.9202745550794877, 0.6749563522500728, 0.37533269810004777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 151}], {
             RGBColor[
             0.9203645260018751, 0.6763382789683456, 0.4715886994182685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 155}], {
             RGBColor[
             0.7600079693502197, 0.5527750998573846, 0.5802673825214153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 156}], {
             RGBColor[
             0.8327717722765755, 0.2529037791657479, 0.17901559218345872`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 172}], {
             RGBColor[
             0.858083307192903, 0.43025919736952545`, 0.20258043262042846`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 191}], {
             RGBColor[
             0.8284647281297735, 0.6062540401066088, 0.5870905124717782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 195}], {
             RGBColor[
             0.6739288625041259, 0.48336449574698853`, 0.5731680108502653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 199}], {
             RGBColor[
             0.921043290148025, 0.6766189653862216, 0.46033982093126385`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 124}], {
             RGBColor[
             0.20998768265750406`, 0.3380407468340621, 0.9352698599271827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 125}], {
             RGBColor[
             0.22911059591556282`, 0.35814014113101095`, 0.9363588815474142]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 136}], {
             RGBColor[
             0.208375147270767, 0.3363458699019528, 0.9351780284224404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 137}], {
             RGBColor[
             0.2589152311792967, 0.38806631610919806`, 0.9381074864400005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 187}], {
             RGBColor[
             0.1987095901475981, 0.32618675653378515`, 0.9346275892431862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 198}], {
             RGBColor[
             0.26978078120628096`, 0.39747750942414833`, 0.9387998296796913]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 152}], {
             RGBColor[
             0.20876932330272832`, 0.33676017390374813`, 0.9352004761643293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 159}], {
             RGBColor[
             0.23612256314975283`, 0.36551016327854535`, 0.9367582027081254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 161}], {
             RGBColor[
             0.25059050057240173`, 0.38071688282996385`, 0.9375821303409498]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 164}], {
             RGBColor[
             0.2062630848758868, 0.3341259584124435, 0.9350577495935681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 173}], {
             RGBColor[
             0.292553121290118, 0.41936663602592106`, 0.9401715965504269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 180}], {
             RGBColor[
             0.27969294333585376`, 0.40822779625327543`, 0.9393521573829899]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[
             0.20398334673618768`, 0.33172980908387323`, 0.9349279218790827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 125}], {
             RGBColor[
             0.2711034312291314, 0.40227727354510906`, 0.9387503113956892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 137}], {
             RGBColor[
             0.3009080664928653, 0.4322034485232962, 0.9404989162882755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 166}], {
             RGBColor[
             0.5408265520373148, 0.6280223043100961, 0.9601053035876213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 170}], {
             RGBColor[
             0.4665658605119989, 0.5700092876883599, 0.9527036918619959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 179}], {
             RGBColor[
             0.32323201256899053`, 0.45153932858028145`, 0.9419213783919558]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 192}], {
             RGBColor[
             0.3718189687016956, 0.49328632243521403`, 0.9451102958483188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 127}], {
             RGBColor[
             0.6629559060472224, 0.73407938328518, 0.9689427121892478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 129}], {
             RGBColor[
             0.45279766246512576`, 0.5665810049409397, 0.9500814941727593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 139}], {
             RGBColor[
             0.36839624794676656`, 0.4913743375109727, 0.9447729865968078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 141}], {
             RGBColor[
             0.39747014268735614`, 0.5186903929907134, 0.9465474239163595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 146}], {
             RGBColor[
             0.34826410267529395`, 0.47021417637892043`, 0.9436264907064373]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 155}], {
             RGBColor[
             0.5621572300950483, 0.6548917358884543, 0.9590135889959501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 171}], {
             RGBColor[
             0.3794372903745538, 0.5029791731450995, 0.9454017576293117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 191}], {
             RGBColor[
             0.6306139888746021, 0.7083706761376785, 0.9658367189463131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 195}], {
             RGBColor[
             0.4760781232489544, 0.5854811317780583, 0.9519142173248001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 196}], {
             RGBColor[
             0.3420552644486344, 0.4636882937396207, 0.9432729065545822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 199}], {
             RGBColor[
             0.7231925508928534, 0.7787356014172913, 0.8390860274057987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 125}], {
             RGBColor[
             0.24516019716023396`, 0.37500928964265323`, 0.9372728825950409]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 136}], {
             RGBColor[
             0.22442474851543817`, 0.35321501841359515`, 0.9360920294700671]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.27496483242396785`, 0.4049354646208403, 0.9390214874876273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 187}], {
             RGBColor[
             0.21475919139226923`, 0.3430559050454275, 0.935541590290813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 198}], {
             RGBColor[
             0.28583038245095216`, 0.4143466579357906, 0.9397138307273181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 136}], {
             RGBColor[
             0.24354766177349693`, 0.373314412710544, 0.9371810510902985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 137}], {
             RGBColor[
             0.29408774568202667`, 0.42503485891778914`, 0.9401105091078588]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 166}], {
             RGBColor[
             0.5340062312264762, 0.620853714704589, 0.9597168964072044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[
             0.4597455397011603, 0.5628406980828529, 0.952315284681579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 187}], {
             RGBColor[
             0.233882104650328, 0.36315529934237634`, 0.9366306119110444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 192}], {
             RGBColor[
             0.364998647890857, 0.48611773282970705`, 0.9447218886679021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 198}], {
             RGBColor[
             0.30495329570901086`, 0.43444605223273947`, 0.9408028523475496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 190}], {
             RGBColor[
             0.18192592123823295`, 0.3085460563639715, 0.933671784128011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 129}], {
             RGBColor[
             0.6646291767752983, 0.7354973814495299, 0.9690579811407907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 139}], {
             RGBColor[
             0.5802277622569392, 0.660290714019563, 0.9637494735648391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 140}], {
             RGBColor[
             0.9342553301344888, 0.9459893647897327, 0.7730553915426139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 141}], {
             RGBColor[
             0.6093016569975287, 0.6876067694993037, 0.9655239108843909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 155}], {
             RGBColor[
             0.7739887444052208, 0.8238081123970447, 0.9779900759639816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 172}], {
             RGBColor[
             0.8720640822479042, 0.7012922099091854, 0.6003031260629946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 191}], {
             RGBColor[
             0.8424455031847746, 0.8772870526462687, 0.9848132059143445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 195}], {
             RGBColor[
             0.6879096375591269, 0.7543975082866485, 0.9708907042928315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 199}], {
             RGBColor[
             0.935024065203026, 0.9476519779258816, 0.8580625143738301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 136}], {
             RGBColor[
             0.3270594206414329, 0.44975899875617, 0.9423518264076001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 162}], {
             RGBColor[
             0.4413593088202362, 0.5567049827613839, 0.9493440027726809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 193}], {
             RGBColor[
             0.3303839734000996, 0.45325331449434825`, 0.942541154768971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 198}], {
             RGBColor[
             0.38846505457694686`, 0.5108906382783656, 0.9459736276648509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 139}], {
             RGBColor[
             0.3700695186748425, 0.49279233567532266`, 0.9448882555483507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 141}], {
             RGBColor[
             0.399143413415432, 0.5201083911550634, 0.9466626928679024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 146}], {
             RGBColor[
             0.3499373734033699, 0.4716321745432704, 0.9437417596579802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 155}], {
             RGBColor[
             0.5638305008231241, 0.6563097340528043, 0.959128857947493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 191}], {
             RGBColor[
             0.632287259602678, 0.7097886743020284, 0.965951987897856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 195}], {
             RGBColor[
             0.47775139397703026`, 0.5868991299424082, 0.952029486276343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 131}], {
             RGBColor[
             0.18289522364297445`, 0.3095648546486768, 0.9337269844660065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 149}], {
             RGBColor[
             0.1848995905074315, 0.3116715713074204, 0.9338411301937424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 157}], {
             RGBColor[
             0.19536013163296237`, 0.32266626326696746`, 0.9344368425358576]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 168}], {
             RGBColor[
             0.19684636692721422`, 0.32422839079398647`, 0.9345214814371772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 189}], {
             RGBColor[
             0.18936342684036145`, 0.3163633463169, 0.9340953390692487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 197}], {
             RGBColor[
             0.19250062713784824`, 0.3196607427395459, 0.9342739979851187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 147}], {
             RGBColor[
             0.21550989668752718`, 0.3438449439082084, 0.9355843418468089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 157}], {
             RGBColor[
             0.19396001666235732`, 0.3211946536604452, 0.9343571080595661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 176}], {
             RGBColor[
             0.20779145347843028`, 0.335732370717883, 0.9351447879244643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 138}], {
             RGBColor[
             0.2612195562179643, 0.3918886942345018, 0.9381874393356859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 145}], {
             RGBColor[
             0.24537934999545682`, 0.37523963316756476`, 0.9372853630247993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 153}], {
             RGBColor[
             0.29141110867079584`, 0.42362193011741534`, 0.9399068035834754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 182}], {
             RGBColor[
             0.3206991952751244, 0.45143891338558356`, 0.9416833404765177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 185}], {
             RGBColor[
             0.26630785953473646`, 0.397236823637493, 0.9384772106821059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 163}], {
             RGBColor[
             0.26544293338464375`, 0.39632773141426036`, 0.9384279544174017]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 178}], {
             RGBColor[
             0.21638528695668868`, 0.3447650345840459, 0.9356341940276138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 135}], {
             RGBColor[
             0.22190471606791506`, 0.3505663045319628, 0.9359485173502345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 160}], {
             RGBColor[
             0.3450319511386071, 0.4675505014401682, 0.9434155666515178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 144}], {
             RGBColor[
             0.19771245739729065`, 0.32513870679134427`, 0.9345708040081819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 148}], {
             RGBColor[
             0.2081945933984414, 0.33615609633436194`, 0.9351677461465169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 187}], {
             RGBColor[
             0.2131466560055322, 0.3413610281133182, 0.9354497587860706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 193}], {
             RGBColor[
             0.22613676588736786`, 0.35501445721966407`, 0.9361895263266957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 198}], {
             RGBColor[
             0.2842178470642151, 0.4126517810036814, 0.9396219992225757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 166}], {
             RGBColor[
             0.5638108664902101, 0.6507798896827761, 0.9614655012997908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 170}], {
             RGBColor[
             0.48955017496489417`, 0.59276687306104, 0.9540638895741654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 179}], {
             RGBColor[
             0.3462163270218858, 0.4742969139529616, 0.9432815761041253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 187}], {
             RGBColor[
             0.2636867399140619, 0.3930814743205634, 0.9383792168036308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 192}], {
             RGBColor[
             0.3948032831545909, 0.5160439078078941, 0.9464704935604884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 198}], {
             RGBColor[
             0.3347579309727448, 0.4643722272109265, 0.9425514572401359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 145}], {
             RGBColor[
             0.20603341116594734`, 0.3338845567811428, 0.935044670015559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 153}], {
             RGBColor[
             0.25206516984128635`, 0.38226685373099345`, 0.9376661105742352]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 182}], {
             RGBColor[
             0.28135325644561493`, 0.4100838369991616, 0.9394426474672775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 185}], {
             RGBColor[
             0.22696192070522694`, 0.35588174725107113`, 0.9362365176728656]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 141}], {
             RGBColor[
             0.31474199889707277`, 0.4449017237250964, 0.9413541852919508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 146}], {
             RGBColor[
             0.2655359588850107, 0.39642550711330343`, 0.9384332520820287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 155}], {
             RGBColor[
             0.47942908630476494`, 0.5811030666228374, 0.9538203503715414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 171}], {
             RGBColor[
             0.2967091465842705, 0.42919050387948254`, 0.940208519004903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 191}], {
             RGBColor[
             0.5478858450843187, 0.6345820068720615, 0.9606434803219044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 194}], {
             RGBColor[
             0.2435950267958037, 0.37336419635210427`, 0.9371837484582486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 195}], {
             RGBColor[
             0.39334997945867106`, 0.5116924625124413, 0.9467209787003914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 196}], {
             RGBColor[
             0.25932712065835106`, 0.3898996244740037, 0.9380796679301735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 151}], {
             RGBColor[
             0.9938132108339699, 0.9903648965039682, 0.6544475852461695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 161}], {
             RGBColor[
             0.6387756152014612, 0.7023172809495201, 0.7488332700746612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 162}], {
             RGBColor[
             0.7225676146989453, 0.7771975396388044, 0.7540880673117176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 172}], {
             RGBColor[
             0.931531992024998, 0.7442858149051479, 0.38543931844832946`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 173}], {
             RGBColor[
             0.6807382359191774, 0.7409670341454773, 0.7514227362841381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 180}], {
             RGBColor[
             0.6678780579649132, 0.7298281943728316, 0.7506032971167013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 191}], {
             RGBColor[
             0.9019134129618684, 0.9202806576422312, 0.7699493982996792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 146}], {
             RGBColor[
             0.2946098536256002, 0.4237415625930442, 0.9402076894015805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 155}], {
             RGBColor[
             0.5085029810453545, 0.6084191221025781, 0.9555947876910933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 167}], {
             RGBColor[
             0.27157484914335084`, 0.3995303123785612, 0.9388958799735516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 191}], {
             RGBColor[
             0.5769597398249082, 0.6618980623518022, 0.9624179176414562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 194}], {
             RGBColor[
             0.2726689215363932, 0.40068025183184497`, 0.9389581857778003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 195}], {
             RGBColor[
             0.42242387419926064`, 0.539008517992182, 0.9484954160199432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 147}], {
             RGBColor[
             0.25576128412159904`, 0.3861517041867828, 0.9378765988145878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 154}], {
             RGBColor[
             0.29693436368645065`, 0.4272891715192359, 0.9402996292628881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 157}], {
             RGBColor[
             0.2342114040964292, 0.3635014139390195, 0.9366493650273451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 168}], {
             RGBColor[
             0.23569763939068106`, 0.3650635414660385, 0.9367340039286646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 176}], {
             RGBColor[
             0.24804284091250217`, 0.37803913099645736`, 0.9374370448922433]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.2876001150236012, 0.4192043144804547, 0.9397048591920434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 154}], {
             RGBColor[
             0.5937667549119501, 0.6748088886146058, 0.9642312788067474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 158}], {
             RGBColor[
             0.5860035167018279, 0.6680847618686957, 0.9637366121327604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 160}], {
             RGBColor[
             0.6494266978782655, 0.7230187336619522, 0.967777881154406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 181}], {
             RGBColor[
             0.6469177981644729, 0.7208456508308313, 0.967618016283176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 188}], {
             RGBColor[
             0.5844325062491007, 0.6667240315758246, 0.9636365087359027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 158}], {
             RGBColor[
             0.2574165112915451, 0.3871889319062931, 0.9379965842878197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 153}], {
             RGBColor[
             0.2362249636187789, 0.3656177926640565, 0.9367640342633485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 185}], {
             RGBColor[
             0.2111217144827195, 0.33923268618413416`, 0.935334441361979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 155}], {
             RGBColor[
             0.4592969410332923, 0.5599429054907851, 0.9526738544811711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 171}], {
             RGBColor[
             0.27657700131279794`, 0.4080303427474302, 0.9390620231145327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 184}], {
             RGBColor[
             0.21360634880243462`, 0.34184419438906943`, 0.9354759376107997]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 186}], {
             RGBColor[
             0.2142358988127285, 0.34250589136566434`, 0.9355117895525502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 191}], {
             RGBColor[
             0.527753699812846, 0.6134218457400091, 0.9594969844315341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 194}], {
             RGBColor[
             0.22346288152433108`, 0.352204035220052, 0.9360372525678782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 195}], {
             RGBColor[
             0.37321783418719845`, 0.490532301380389, 0.9455744828100211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 196}], {
             RGBColor[
             0.23919497538687848`, 0.3687394633419514, 0.9369331720398031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 154}], {
             RGBColor[
             0.2906977642675366, 0.42073411010671546`, 0.939944464152203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 157}], {
             RGBColor[
             0.2279748046775151, 0.3569463525264991, 0.9362941999166599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 168}], {
             RGBColor[
             0.22946103997176695`, 0.35850848005351804`, 0.9363788388179795]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 176}], {
             RGBColor[
             0.24180624149358806`, 0.37148406958393687`, 0.9370818797815581]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 188}], {
             RGBColor[
             0.2813635156046871, 0.41264925306793426`, 0.9393496940813583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 150}], {
             RGBColor[
             0.19306951159997304`, 0.3202586763785973, 0.9343063951136474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 193}], {
             RGBColor[
             0.21151914615710812`, 0.33965041207254015`, 0.9353570745078879]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 167}], {
             RGBColor[
             0.19241882352516138`, 0.31957476195596346`, 0.9342693393903937]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 168}], {
             RGBColor[
             0.19745061882106624`, 0.32486349784620777`, 0.9345558926886215]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 189}], {
             RGBColor[
             0.18996767873421347`, 0.31699845336912136`, 0.934129750320693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 194}], {
             RGBColor[
             0.1935128959182038, 0.3207247014092473, 0.9343316451946424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.19310487903170026`, 0.3202958497917673, 0.934308409236563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 156}], {
             RGBColor[
             0.9063104280310577, 0.5683123234196433, 0.4581304793295804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 172}], {
             RGBColor[
             0.9316219629473853, 0.7456677416234209, 0.4816953197665501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 175}], {
             RGBColor[
             0.7472372281358932, 0.7985860801048122, 0.8522647687143463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 183}], {
             RGBColor[
             0.9651436444656913, 0.888619018725243, 0.5091874749108671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 199}], {
             RGBColor[
             0.9945819459025071, 0.992027509640117, 0.7394547080773856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 159}], {
             RGBColor[
             0.22753887579901738`, 0.3564881636357107, 0.9362693744119284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 178}], {
             RGBColor[
             0.19191650879429833`, 0.319046797325233, 0.9342407333095791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 200}], {
             RGBColor[
             0.19539965938545223`, 0.3227078094410386, 0.9344390935828858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 182}], {
             RGBColor[
             0.3115448088984465, 0.4418170728820753, 0.941162011715067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 185}], {
             RGBColor[
             0.2571534731580585, 0.38761498313398474`, 0.937955881920655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 157}], {
             RGBColor[
             0.2691478842423667, 0.3980838198589522, 0.9387172303649602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 158}], {
             RGBColor[
             0.3241076056222659, 0.45514745069325846`, 0.9418728279265163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 160}], {
             RGBColor[
             0.38753078679870345`, 0.510081422486515, 0.9459140969481619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 176}], {
             RGBColor[
             0.28297932105843965`, 0.41262153691639003`, 0.9395049102298585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 181}], {
             RGBColor[
             0.3850218870849109, 0.5079083396553941, 0.9457542320769319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 188}], {
             RGBColor[
             0.3225365951695387, 0.45378672040038737`, 0.9417727245296585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 172}], {
             RGBColor[
             0.77126540629573, 0.6221045625124598, 0.590374002869697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 191}], {
             RGBColor[
             0.7416468272326004, 0.7980994052495431, 0.9748840827210469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 195}], {
             RGBColor[
             0.5871109616069528, 0.6752098608899229, 0.9609615810995339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 199}], {
             RGBColor[
             0.8342253892508518, 0.868464330529156, 0.8481333911805324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 166}], {
             RGBColor[
             0.8112235131702088, 0.49573828454331076`, 0.5733146303469535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 170}], {
             RGBColor[
             0.7369628216448929, 0.4377252679215747, 0.5659130186213281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 175}], {
             RGBColor[
             0.6596444744105936, 0.3751515803022144, 0.5596916614795366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 183}], {
             RGBColor[
             0.8775508907403917, 0.4651845189226452, 0.21661436767605732`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 199}], {
             RGBColor[
             0.9069891921772075, 0.5685930098375191, 0.4468816008425758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 168}], {
             RGBColor[
             0.2079111599465971, 0.33585818980575477`, 0.9351516050307367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 176}], {
             RGBColor[
             0.2202563614684182, 0.34883377933617365`, 0.9358546459943153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 188}], {
             RGBColor[
             0.25981363557951725`, 0.389998962820171, 0.9381224602941154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 160}], {
             RGBColor[
             0.3797675485885813, 0.503357295740605, 0.945419430274175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 176}], {
             RGBColor[
             0.27521608284831744`, 0.40589741017048, 0.9390102435558715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.37725864887478877`, 0.501184212909484, 0.945259565402945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 161}], {
             RGBColor[
             0.2693600530686908, 0.4004448725619264, 0.938651028588549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 162}], {
             RGBColor[
             0.3531520525661749, 0.4753251312512108, 0.9439058258256054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 164}], {
             RGBColor[
             0.22503263737217588`, 0.35385394814440607`, 0.9361266478411673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 173}], {
             RGBColor[
             0.3113226737864071, 0.4390946257578836, 0.941240494798026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 180}], {
             RGBColor[
             0.29846249583214285`, 0.427955785985238, 0.9404210556305891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 200}], {
             RGBColor[
             0.22275289923247676`, 0.35145779881583583`, 0.9359968201266817]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[
             0.4406818300512263, 0.5561181847027405, 0.9493008344245906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 162}], {
             RGBColor[
             0.3676199899888237, 0.4905318508026293, 0.94472975345843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 164}], {
             RGBColor[
             0.23950057479482478`, 0.3690606676958246, 0.9369505754739917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 173}], {
             RGBColor[
             0.32579061120905595`, 0.4543013453093021, 0.9420644224308505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 180}], {
             RGBColor[
             0.31293043325479175`, 0.4431625055366565, 0.9412449832634135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 200}], {
             RGBColor[
             0.23722083665512567`, 0.36666451836725433`, 0.9368207477595063]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 172}], {
             RGBColor[
             0.6603763668123606, 0.5325003847582571, 0.5813358018320983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 173}], {
             RGBColor[
             0.40958261070654, 0.5291816039985865, 0.947319219667907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 180}], {
             RGBColor[
             0.3967224327522758, 0.5180427642259409, 0.9464997805004701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 165}], {
             RGBColor[
             0.24378292836413576`, 0.3735616928140688, 0.9371944491745896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 175}], {
             RGBColor[
             0.39116697450397153`, 0.5094530755186824, 0.9465916451974521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 177}], {
             RGBColor[
             0.24957629716502022`, 0.3796508907445958, 0.937524372957279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 200}], {
             RGBColor[
             0.19289342095861073`, 0.320073593949734, 0.9342963670121247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 169}], {
             RGBColor[
             0.1989480925621131, 0.32643743769336697`, 0.9346411716028602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 175}], {
             RGBColor[
             0.35318722837559335`, 0.4695339542827697, 0.9444287548414402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 177}], {
             RGBColor[
             0.2115965510366421, 0.3397317695086831, 0.9353614826012671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 170}], {
             RGBColor[
             0.7294686605093437, 0.78858572884784, 0.973670276873511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 179}], {
             RGBColor[
             0.5861348125663353, 0.6701157697397615, 0.962887963403471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 183}], {
             RGBColor[
             0.8700567296048425, 0.8160449798489104, 0.6243716259282402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 192}], {
             RGBColor[
             0.6347217686990404, 0.711862763594694, 0.9660768808598341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 198}], {
             RGBColor[
             0.5746764165171943, 0.6601910829977264, 0.9621578445394816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 189}], {
             RGBColor[
             0.19688265985809134`, 0.32426653696544305`, 0.9345235482659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 194}], {
             RGBColor[
             0.2004278770420817, 0.327992785005569, 0.9347254431398494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 197}], {
             RGBColor[
             0.20001986015557813`, 0.327563933388089, 0.9347022071817699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 188}], {
             RGBColor[
             0.2612998708737691, 0.39156109034719, 0.938207099195435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 189}], {
             RGBColor[
             0.2019144551539962, 0.3295552728556873, 0.9348101015641277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 197}], {
             RGBColor[
             0.20505165545148296`, 0.3328526692783333, 0.9349887604799977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 177}], {
             RGBColor[
             0.20474146136299756`, 0.33252663562389395`, 0.9349710953855495]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 190}], {
             RGBColor[
             0.18813962732028144`, 0.31507705542792475`, 0.9340256454970293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 179}], {
             RGBColor[
             0.5118741210410194, 0.6121027531180253, 0.9554863516778458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 183}], {
             RGBColor[
             0.7957960380795266, 0.7580319632271744, 0.6169700142026149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[
             0.5604610771737245, 0.6538497469729578, 0.9586752691342088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 198}], {
             RGBColor[
             0.5004157249918784, 0.6021780663759904, 0.9547562328138562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 174}], {
             RGBColor[
             0.24889168370669917`, 0.37893131859289997`, 0.9374853852336225]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 182}], {
             RGBColor[
             0.3242915422574164, 0.45521469783192636`, 0.9418879193227581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 191}], {
             RGBColor[
             0.558926887512106, 0.6461868425061883, 0.9612722513544084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 195}], {
             RGBColor[
             0.4043910218864583, 0.5232972981465681, 0.9473497497328954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 196}], {
             RGBColor[
             0.2703681630861383, 0.4015044601081305, 0.9387084389626774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 199}], {
             RGBColor[
             0.6515054495303574, 0.7165517677858011, 0.834521559813894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 173}], {
             RGBColor[
             0.6185469880325928, 0.49626987926492994`, 0.5786704708045187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 180}], {
             RGBColor[
             0.6056868100783286, 0.4851310394922843, 0.577851031637082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 191}], {
             RGBColor[
             0.8397221650752837, 0.6755835027616839, 0.59719713282006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 180}], {
             RGBColor[
             0.35489305397250803`, 0.4818122587326137, 0.9438344494728906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 186}], {
             RGBColor[
             0.18655058120662976`, 0.3134068672111341, 0.9339351516716399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 196}], {
             RGBColor[
             0.21150965778077974`, 0.33964043918742115`, 0.9353565341588927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 183}], {
             RGBColor[
             0.7184776908452273, 0.695458275607814, 0.6107486570608233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 188}], {
             RGBColor[
             0.2736450723955902, 0.4045366798776089, 0.9389101401590136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 179}], {
             RGBColor[
             0.2929650964677688, 0.41972688072457853`, 0.940197722295881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 190}], {
             RGBColor[
             0.20078808579481044`, 0.3283713872432409, 0.9347459564954362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 183}], {
             RGBColor[
             0.6524621901365182, 0.6395620041190959, 0.6061877007325749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 192}], {
             RGBColor[
             0.41712722923071616`, 0.5353797878648794, 0.9478929556641686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 185}], {
             RGBColor[
             0.28644155976238705`, 0.41543196640215296`, 0.9397324188136974]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 195}], {
             RGBColor[
             0.42093237513181697`, 0.5377166564648852, 0.9484003790182465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 196}], {
             RGBColor[
             0.28690951633149697`, 0.41592381842644754`, 0.9397590682480286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 199}], {
             RGBColor[
             0.668046802775716, 0.7309711261041182, 0.8355721890992451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 192}], {
             RGBColor[
             0.7010491462692232, 0.6813089979740284, 0.609376618188938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 186}], {
             RGBColor[
             0.18243843400162507`, 0.3090847397734826, 0.9337009709716915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 194}], {
             RGBColor[
             0.19166541671322765`, 0.3187828836278702, 0.9342264339870195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 198}], {
             RGBColor[
             0.2745522899410462, 0.4024926676355137, 0.9390715600433216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 194}], {
             RGBColor[
             0.19797673225113377`, 0.32541647641872684`, 0.9345858540701487]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 197}], {
             RGBColor[
             0.19756871536463022`, 0.3249876248012469, 0.9345626181120692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 195}], {
             RGBColor[
             0.6555677203865065, 0.728688801139147, 0.9677847110498968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 199}], {
             RGBColor[
             0.9026821480304056, 0.9219432707783801, 0.8549565211308954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 197}], {
             RGBColor[
             0.20111393254862053`, 0.3287138728413728, 0.9347645129860187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 196}], {
             RGBColor[
             0.3670089959605389, 0.4840064187410893, 0.9452208986581658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 199}], {
             RGBColor[
             0.748146282404758, 0.7990537264187598, 0.8410340195093824]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.04610843439966642], {
             RGBColor[
             0.17991592983646426`, 0.30643342795989703`, 0.9335573180911961]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.04610843439966642], {
             RGBColor[
             0.18237351643808017`, 0.30901650729818564`, 0.9336972740124846]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.04610843439966642], {
             RGBColor[
             0.4186929718519593, 0.5370725409226834, 0.947899723824117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.04610843439966642], {
             RGBColor[
             0.33430755049502603`, 0.4639821302779076, 0.9425227593943515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.04610843439966642], {
             RGBColor[
             0.35433408061295757`, 0.481328104103389, 0.9437988321847008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.04610843439966642], {
             RGBColor[
             0.8314330293974257, 0.24261361475573226`, 0.17773361049049105`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.04610843439966642], {
             RGBColor[
             0.20849433214894747`, 0.33647114076567824`, 0.9351848158249345]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.04610843439966642], {
             RGBColor[
             0.28326421471662644`, 0.41505902802867256`, 0.939442850025035]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.04610843439966642], {
             RGBColor[
             0.19331350997927296`, 0.32051513414563226`, 0.9343202904603853]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.04610843439966642], {
             RGBColor[
             0.2179504265625759, 0.34641009554541596`, 0.9357233264127526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.04610843439966642], {
             RGBColor[
             0.20295626314304663`, 0.3306502791066209, 0.9348694309878873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.04610843439966642], {
             RGBColor[
             0.950102117301832, 0.8398785531251466, 0.2787091962084557]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.04610843439966642], {
             RGBColor[
             0.22110598802207443`, 0.3497267907135012, 0.9359030309696362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.04610843439966642], {
             RGBColor[
             0.17925722738073346`, 0.3057410899147761, 0.9335198059608052]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.04610843439966642], {
             RGBColor[
             0.1871756577266932, 0.3140638622658612, 0.9339707488547396]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.04610843439966642], {
             RGBColor[
             0.19146922694525287`, 0.31857667574257903`, 0.9342152612699701]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.04610843439966642], {
             RGBColor[
             0.22306772190849825`, 0.3517886974092449, 0.9360147488123428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.04610843439966642], {
             RGBColor[
             0.35121665541737046`, 0.47862794708531764`, 0.9436001926078689]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.04610843439966642], {
             RGBColor[
             0.1823235017276304, 0.3089639386663871, 0.9336944257487145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.04610843439966642], {
             RGBColor[
             0.36130368564417137`, 0.48736482567889206`, 0.94424292925431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.04610843439966642], {
             RGBColor[
             0.18848942771341942`, 0.31544471781973865`, 0.9340455661119352]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.04610843439966642], {
             RGBColor[
             0.22363768830217948`, 0.3523877682269605, 0.9360472075552733]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.04610843439966642], {
             RGBColor[
             0.2571472380542651, 0.3876084296445695, 0.9379555268407181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.04610843439966642], {
             RGBColor[
             0.17953882470990998`, 0.3060370665620425, 0.9335358425121159]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.04610843439966642], {
             RGBColor[
             0.2927822195605681, 0.4250630545960175, 0.9399848863202711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.04610843439966642], {
             RGBColor[
             0.26652048668465833`, 0.39746030825340095`, 0.9384893194837403]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.04610843439966642], {
             RGBColor[
             0.1792907180836107, 0.3057762907669333, 0.933521713206789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.04610843439966642], {
             RGBColor[
             0.20691074357712266`, 0.33480668877137576`, 0.9350946327984784]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.04610843439966642], {
             RGBColor[
             0.2095661987749073, 0.33759774054983127`, 0.9352458570435983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.04610843439966642], {
             RGBColor[
             0.531961775829707, 0.6309095600802831, 0.9562971261149575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.04610843439966642], {
             RGBColor[
             0.186006868294159, 0.3128353904667376, 0.9339041880256258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.04610843439966642], {
             RGBColor[
             0.9926235425767636, 0.9912176595362523, 0.7719105193703001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.04610843439966642], {
             RGBColor[
             0.4300571649791395, 0.5469156338284925, 0.9486238401612196]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.04610843439966642], {
             RGBColor[
             0.18077756667952594`, 0.30733906291288604`, 0.933606387034731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.04610843439966642], {
             RGBColor[
             0.18255152448721731`, 0.309203605044191, 0.9337074113075435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.04610843439966642], {
             RGBColor[
             0.23584637567939642`, 0.36521987273590373`, 0.9367424742402714]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.04610843439966642], {
             RGBColor[
             0.18112444186066054`, 0.30770365072141526`, 0.9336261410631407]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.04610843439966642], {
             RGBColor[
             0.25206224059906557`, 0.3822637749116947, 0.9376659437582241]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.04610843439966642], {
             RGBColor[
             0.5058302216121423, 0.609694787153362, 0.9542399544439137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.04610843439966642], {
             RGBColor[
             0.29070628845368207`, 0.422881119381046, 0.9398666651147989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.04610843439966642], {
             RGBColor[
             0.2027701922068055, 0.3304547067550528, 0.9348588345233357]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.04610843439966642], {
             RGBColor[
             0.18974733652345127`, 0.3167668597351072, 0.9341172021577572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.04610843439966642], {
             RGBColor[
             0.8987739036289236, 0.6332377629819576, 0.2372468027203504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.04610843439966642], {
             RGBColor[
             0.7110429824499928, 0.7741914491075349, 0.9718337774823064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.04610843439966642], {
             RGBColor[
             0.18297903858873563`, 0.3096529494708463, 0.9337317576031746]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.04610843439966642], {
             RGBColor[
             0.1962609887352336, 0.32361312119909375`, 0.9344881450151332]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.04610843439966642], {
             RGBColor[
             0.21049372737267863`, 0.3385726319147987, 0.9352986784250858]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.04610843439966642], {
             RGBColor[
             0.4223544797753533, 0.5402439550531881, 0.9481330318712514]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.04610843439966642], {
             RGBColor[
             0.20374667641262958`, 0.33148105356804847`, 0.9349144438542785]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.04610843439966642], {
             RGBColor[
             0.18219656266820544`, 0.3088305176665303, 0.9336871967570698]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.04610843439966642], {
             RGBColor[
             0.18558886593634766`, 0.31239604348579764`, 0.9338803834097276]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.04610843439966642], {
             RGBColor[
             0.631783197735858, 0.7119490872875069, 0.9641554341053266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.04610843439966642], {
             RGBColor[
             0.988392764379178, 0.9725082101217492, 0.4094085107659739]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.04610843439966642], {
             RGBColor[
             0.33587823342715956`, 0.465342576888902, 0.9426228419218866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.04610843439966642], {
             RGBColor[
             0.1825695689347496, 0.30922257090263144`, 0.9337084389121362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.04610843439966642], {
             RGBColor[
             0.1818396285304826, 0.30845535725685214`, 0.9336668698859633]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.04610843439966642], {
             RGBColor[
             0.9605766768067475, 0.9701187306290152, 0.9516175823034524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.04610843439966642], {
             RGBColor[
             0.18422301466471383`, 0.3109604471993381, 0.9338026002004038]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.04610843439966642], {
             RGBColor[
             0.18098071777705174`, 0.3075525875969092, 0.9336179561892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.04610843439966642], {
             RGBColor[
             0.2073405252862433, 0.3352584165973958, 0.9351191082310077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.04610843439966642], {
             RGBColor[
             0.1999014029793203, 0.32743942738522325`, 0.9346954612208237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.04610843439966642], {
             RGBColor[
             0.19167260114558432`, 0.31879043492179643`, 0.9342268431298139]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.04610843439966642], {
             RGBColor[
             0.6295309817704698, 0.7101206369056319, 0.9639781314143923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.04610843439966642], {
             RGBColor[
             0.95633856953826, 0.8643818842404721, 0.284884016735784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.04610843439966642], {
             RGBColor[
             0.18354617680954663`, 0.31024904769955874`, 0.9337640552858439]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.04610843439966642], {
             RGBColor[
             0.2558901091184015, 0.3862871074263986, 0.9378839352075763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.04610843439966642], {
             RGBColor[
             0.9609913119589255, 0.8800766769412489, 0.30295904244338884`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.04610843439966642], {
             RGBColor[
             0.24981404640376637`, 0.37990078026869034`, 0.9375379124247071]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.04610843439966642], {
             RGBColor[
             0.19105055232810444`, 0.31813662217445204`, 0.9341914183698972]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.04610843439966642], {
             RGBColor[
             0.3637386159115608, 0.4894738398933511, 0.9443980808578237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.04610843439966642], {
             RGBColor[
             0.2532013109542942, 0.38346101007627187`, 0.9377308121298508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.04610843439966642], {
             RGBColor[
             0.21747923322295587`, 0.34591484147009205`, 0.9356964926491292]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.04610843439966642], {
             RGBColor[
             0.34593054718585675`, 0.47404938582270545`, 0.9432633664656788]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.04610843439966642], {
             RGBColor[
             0.5021423004164799, 0.6067007665877667, 0.9539496277780908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.04610843439966642], {
             RGBColor[
             0.26424845016803866`, 0.3950722538189983, 0.9383599303652956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.04610843439966642], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.04610843439966642], {
             RGBColor[
             0.18293127670980908`, 0.3096027487078165, 0.9337290376348271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.04610843439966642], {
             RGBColor[
             0.1941778278429074, 0.3214235870212298, 0.9343695120840757]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.04610843439966642], {
             RGBColor[
             0.22179319725678925`, 0.3504490911907685, 0.9359421665189183]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.04610843439966642], {
             RGBColor[
             0.30602988251049323`, 0.4389871883067331, 0.9407393211271083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.04610843439966642], {
             RGBColor[
             0.21196511221078973`, 0.3401191506708405, 0.9353824716148974]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.04610843439966642], {
             RGBColor[
             0.9263859833659136, 0.9441390533310817, 0.9928407161596127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.04610843439966642], {
             RGBColor[
             0.181234979779358, 0.3078198330824752, 0.9336324360340843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.04610843439966642], {
             RGBColor[
             0.2704719529099895, 0.40161354979365305`, 0.9387143496396024]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.04610843439966642], {
             RGBColor[
             0.2020967142561969, 0.3297468387279948, 0.9348204809503698]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.04610843439966642], {
             RGBColor[
             0.21670300720810273`, 0.3450989787129095, 0.9356522877259069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.04610843439966642], {
             RGBColor[
             0.21656281497127022`, 0.34495162778329735`, 0.9356443039854151]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.04610843439966642], {
             RGBColor[
             0.2675148103379351, 0.39850540545675567`, 0.9385459447448243]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.04610843439966642], {
             RGBColor[
             0.22727061882380845`, 0.3562062085462915, 0.9362540975740409]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.04610843439966642], {
             RGBColor[
             0.18623437450108682`, 0.31307451391494534`, 0.9339171441675451]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.04610843439966642], {
             RGBColor[
             0.2444470173259052, 0.37425969241856055`, 0.9372322680585309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.04610843439966642], {
             RGBColor[
             0.23138676958404353`, 0.3605325439743302, 0.9364885062705369]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.04610843439966642], {
             RGBColor[
             0.19041076970754647`, 0.3174641700756846, 0.9341549836961299]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.04610843439966642], {
             RGBColor[
             0.24919784069125972`, 0.37925310899514714`, 0.9375028204209744]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.04610843439966642], {
             RGBColor[
             0.9364164576881094, 0.9521000787690629, 0.9925145312769647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.04610843439966642], {
             RGBColor[
             0.21679935925455723`, 0.3452002508228058, 0.9356577748324124]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.04610843439966642], {
             RGBColor[
             0.19250116414799295`, 0.31966130717125646`, 0.9342740285670519]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.04610843439966642], {
             RGBColor[
             0.5518206973838005, 0.647031927232117, 0.9578604931653224]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.04610843439966642], {
             RGBColor[
             0.20579087184942513`, 0.3336296325815971, 0.9350308577602878]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.04610843439966642], {
             RGBColor[
             0.19619436846660787`, 0.3235430990727991, 0.9344843510893909]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.04610843439966642], {
             RGBColor[
             0.9691756477061694, 0.9765318290462814, 0.9370617675415293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.04610843439966642], {
             RGBColor[
             0.1810808656124072, 0.3076578493216073, 0.933623659460268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.04610843439966642], {
             RGBColor[
             0.36710024085613885`, 0.49238551046016216`, 0.9446122806267241]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.04610843439966642], {
             RGBColor[
             0.20575656042090384`, 0.333593569094751, 0.9350289037751928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.04610843439966642], {
             RGBColor[
             0.18503007033382515`, 0.31180871387785897`, 0.9338485608268279]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.04610843439966642], {
             RGBColor[
             0.21763298899601496`, 0.34607644853625624`, 0.9357052488129437]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.04610843439966642], {
             RGBColor[
             0.3080267094125234, 0.4410859799869048, 0.9408530374651383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.04610843439966642], {
             RGBColor[
             0.21740901950548744`, 0.34584104240122593`, 0.9356924940817913]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.04610843439966642], {
             RGBColor[
             0.18012636844446756`, 0.30665461227948687`, 0.9335693022586058]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.04610843439966642], {
             RGBColor[
             0.2201361607798215, 0.3487074407912947, 0.9358478007429207]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.04610843439966642], {
             RGBColor[
             0.9414109245622558, 0.9558249439861124, 0.9840602016246193]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.04610843439966642], {
             RGBColor[
             0.20445336338735556`, 0.33222382638502757`, 0.9349546886320393]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.04610843439966642], {
             RGBColor[
             0.18141516357964482`, 0.30800921768088935`, 0.9336426972349526]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.04610843439966642], {
             RGBColor[
             0.31502527059825963`, 0.4472807885868956, 0.9412941095699802]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.04610843439966642], {
             RGBColor[
             0.24062773125074222`, 0.3702453805968408, 0.9370147653666777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.04610843439966642], {
             RGBColor[
             0.1853227778630534, 0.31211636804980714`, 0.9338652300875955]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.04610843439966642], {
             RGBColor[
             0.39086743560945575`, 0.5129714599815431, 0.9461267052599003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.04610843439966642], {
             RGBColor[
             0.8468258702473929, 0.3609297347144502, 0.19247381227214683`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.04610843439966642], {
             RGBColor[
             0.1939380814128329, 0.3211715983224198, 0.934355858879556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.04610843439966642], {
             RGBColor[
             0.21735301065346377`, 0.34578217354658275`, 0.9356893044605262]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.04610843439966642], {
             RGBColor[
             0.27792375203997, 0.40944586315061604`, 0.939138718576106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.04610843439966642], {
             RGBColor[
             0.4511243917370499, 0.5651630067765897, 0.9499662252212164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.04610843439966642], {
             RGBColor[
             0.2260372839021752, 0.3549098953457044, 0.9361838609748094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.04610843439966642], {
             RGBColor[
             0.2642831104182927, 0.3951086839396021, 0.9383619042152723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.04610843439966642], {
             RGBColor[
             0.1796655907243716, 0.3061703056806712, 0.9335430616491059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.04610843439966642], {
             RGBColor[
             0.874787420357395, 0.9029957597937702, 0.9879191991572792]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.04610843439966642], {
             RGBColor[
             0.43130662815416465`, 0.5479978560308542, 0.9487034548498753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.04610843439966642], {
             RGBColor[
             0.4544709331932017, 0.5679990031052896, 0.9501967631243022]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.04610843439966642], {
             RGBColor[
             0.1842953386135795, 0.3110364642551991, 0.933806718942298]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.04610843439966642], {
             RGBColor[
             0.1814951086723694, 0.3080932450421545, 0.9336472499897152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.04610843439966642], {
             RGBColor[
             0.30056549504747376`, 0.4332437706209237, 0.9404281323449262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.04610843439966642], {
             RGBColor[
             0.24912319227677354`, 0.3791746487785393, 0.937498569304202]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.04610843439966642], {
             RGBColor[
             0.24687317251219526`, 0.37680973534647483`, 0.9373704340072151]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.04610843439966642], {
             RGBColor[
             0.1969362596236349, 0.3243228737174507, 0.934526600693254]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.04610843439966642], {
             RGBColor[
             0.22281221312870114`, 0.35152014148148586`, 0.9360001979653247]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.04610843439966642], {
             RGBColor[
             0.32389238094576056`, 0.45496103389597625`, 0.9418591140004451]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.04610843439966642], {
             RGBColor[
             0.2218736173884548, 0.35053361784807985`, 0.9359467463264457]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.04610843439966642], {
             RGBColor[
             0.28566810415648325`, 0.4175856682453557, 0.9395797479723991]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.04610843439966642], {
             RGBColor[
             0.9937232399115826, 0.9889829697856952, 0.5581915839279488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.04610843439966642], {
             RGBColor[
             0.34381589363766235`, 0.47221777920483715`, 0.9431286226115025]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.04610843439966642], {
             RGBColor[
             0.2619978835405132, 0.39270676559930323`, 0.938231763925273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.04610843439966642], {
             RGBColor[
             0.8556626659915121, 0.887746199790043, 0.9860950630129915]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.04610843439966642], {
             RGBColor[
             0.19848865517094644`, 0.32595453986523776`, 0.93461500732311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.04610843439966642], {
             RGBColor[
             0.1901932049434399, 0.31723549571420584`, 0.9341425937046723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.04610843439966642], {
             RGBColor[
             0.24540381361353808`, 0.37526534598125116`, 0.9372867561916584]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.04610843439966642], {
             RGBColor[
             0.24952468470268496`, 0.3795966427742623, 0.9375214337039027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.04610843439966642], {
             RGBColor[
             0.19357697366818166`, 0.320792051187238, 0.9343352943277091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.04610843439966642], {
             RGBColor[
             0.1855038424012835, 0.31230667835964177`, 0.9338755414451867]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.04610843439966642], {
             RGBColor[
             0.19256204953176445`, 0.3197253015699566, 0.9342774958995859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.04610843439966642], {
             RGBColor[
             0.9939031817563573, 0.9917468232222412, 0.7507035865643902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.04610843439966642], {
             RGBColor[
             0.20018563595199287`, 0.32773817426091345`, 0.9347116478681324]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.04610843439966642], {
             RGBColor[
             0.2822567222941179, 0.41400008961390705`, 0.9393854748220246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.04610843439966642], {
             RGBColor[
             0.33187084383238813`, 0.46187157743916857`, 0.9423674946005033]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.04610843439966642], {
             RGBColor[
             0.6731900684530466, 0.744620465000319, 0.9680609527706839]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.04610843439966642], {
             RGBColor[
             0.8187176743057581, 0.14487782361704554`, 0.16555737209477062`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.04610843439966642], {
             RGBColor[
             0.20642492465234524`, 0.3342960622787358, 0.9350669661294171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.04610843439966642], {
             RGBColor[
             0.3163443674121438, 0.4484233239473484, 0.9413781612525294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.04610843439966642], {
             RGBColor[
             0.2548921156460419, 0.3852381530105079, 0.9378271009557244]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.04610843439966642], {
             RGBColor[
             0.44319072976501883`, 0.5582912675338615, 0.9494606992958204]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.04610843439966642], {
             RGBColor[
             0.2838279904913397, 0.4156515921133449, 0.9394749562213734]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.04610843439966642], {
             RGBColor[
             0.4514119894863078, 0.5654121094919137, 0.9499845506954865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.04610843439966642], {
             RGBColor[
             0.2817626744925139, 0.41348081404998144`, 0.9393573395306015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.04610843439966642], {
             RGBColor[
             0.19517315909830985`, 0.32246974327830424`, 0.9344261947266101]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.04610843439966642], {
             RGBColor[
             0.2058031822357576, 0.33364257157815613`, 0.9350315588185778]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.04610843439966642], {
             RGBColor[
             0.8037293520346596, 0.846598745469576, 0.9810718885991364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.04610843439966642], {
             RGBColor[
             0.19933380464903927`, 0.32684284555228516`, 0.9346631373356007]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.04610843439966642], {
             RGBColor[
             0.20939739524084894`, 0.3374203173327738, 0.9352362439320562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.04610843439966642], {
             RGBColor[
             0.19209300288846856`, 0.31923230380857776`, 0.9342507843871425]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.04610843439966642], {
             RGBColor[
             0.6552079689840278, 0.7305727122261038, 0.9662686651478858]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.04610843439966642], {
             RGBColor[
             0.30775018901205775`, 0.44079533951360933`, 0.940837290037407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.04610843439966642], {
             RGBColor[
             0.8693407441384133, 0.4995886600246006, 0.2126870529687101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.04610843439966642], {
             RGBColor[
             0.36775323192677223`, 0.4929510985052593, 0.9446538886403275]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.04610843439966642], {
             RGBColor[
             0.19003317840134057`, 0.3170672976721906, 0.9341334804298378]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.04610843439966642], {
             RGBColor[
             0.5005712745154292, 0.6054253369873833, 0.9538259508643026]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.04610843439966642], {
             RGBColor[
             0.23408779828449117`, 0.3633714963936115, 0.9366423258592136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.04610843439966642], {
             RGBColor[
             0.21738991983752656`, 0.34582096743921015`, 0.9356914063839564]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.04610843439966642], {
             RGBColor[
             0.1836473816366038, 0.3103554203895525, 0.9337698187510258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.04610843439966642], {
             RGBColor[
             0.3685402730980111, 0.49363279400994686`, 0.9447040382078057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.04610843439966642], {
             RGBColor[
             0.3420328760182438, 0.47067341895996806`, 0.9430150103054538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.04610843439966642], {
             RGBColor[
             0.43817293033743376`, 0.5539451018716196, 0.9491409695533606]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.04610843439966642], {
             RGBColor[
             0.34083289550277507`, 0.46963405615024345`, 0.9429385486081092]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.04610843439966642], {
             RGBColor[
             0.9363841071750253, 0.7854912142282449, 0.26767136325734403`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.04610843439966642], {
             RGBColor[
             0.1818088839913312, 0.30842304279688765`, 0.933665119029941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.04610843439966642], {
             RGBColor[
             0.2320502240219991, 0.3612298766540624, 0.9365262890192856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.04610843439966642], {
             RGBColor[
             0.18306798401191893`, 0.3097464367500775, 0.933736822913442]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.04610843439966642], {
             RGBColor[
             0.20348109888236326`, 0.33120191474515054`, 0.9348993196068165]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.04610843439966642], {
             RGBColor[
             0.31320234650668927`, 0.4457018633616062, 0.9411779544588138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.04610843439966642], {
             RGBColor[
             0.19443151506714343`, 0.3216902283786009, 0.9343839591961993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.04610843439966642], {
             RGBColor[
             0.1841862517520943, 0.3109218070472717, 0.933800506606916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.04610843439966642], {
             RGBColor[
             0.8101035860121542, 0.8515783454987672, 0.9817072126714098]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.04610843439966642], {
             RGBColor[
             0.46571418536342124`, 0.577126781719812, 0.9510818731205317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.04610843439966642], {
             RGBColor[
             0.22946131864603458`, 0.3585087729578423, 0.9363788546880667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.04610843439966642], {
             RGBColor[
             0.2015219494351241, 0.32914272445885284`, 0.9347877489440981]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.04610843439966642], {
             RGBColor[
             0.5010318547608589, 0.6057992567795268, 0.9538622094283838]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.04610843439966642], {
             RGBColor[
             0.23298613716021888`, 0.3622135807026517, 0.9365795878879478]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.04610843439966642], {
             RGBColor[
             0.20070591566211698`, 0.3282850212238928, 0.9347412770279392]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.04610843439966642], {
             RGBColor[
             0.34562348099972906`, 0.47378342052587685`, 0.9432438004798267]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.04610843439966642], {
             RGBColor[
             0.995260710048657, 0.9923081960579929, 0.7282058295903809]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.04610843439966642], {
             RGBColor[
             0.1906136828189116, 0.3176774446211637, 0.9341665392976392]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{{3.834946926643799*^9, 3.8349469478612347`*^9}, 
   3.834947050298876*^9, {3.8349471234738255`*^9, 3.8349471300172663`*^9}, {
   3.8349471617829676`*^9, 3.834947218900016*^9}, {3.8349472753220577`*^9, 
   3.834947307624898*^9}, 3.83494993428115*^9, 3.8350238632088137`*^9, 
   3.835051673751299*^9, 3.8351287543730435`*^9, 3.835189808982761*^9},
 CellLabel->
  "Out[657]=",ExpressionUUID->"c7ef3228-60b7-4144-af21-23a062e3f179"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<test2.png\>\"", ",", "%"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8348892099793763`*^9, 3.8348892243840446`*^9}, {
   3.8348893213753347`*^9, 3.834889323232689*^9}, 3.8351901300895967`*^9},
 CellLabel->
  "In[658]:=",ExpressionUUID->"79f74856-e8b0-4888-b6d5-0178e2c5212e"],

Cell["Estimated with cubic Mean Deviation v Calculated: (r=6)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 
  3.834950339812094*^9}},ExpressionUUID->"24b3222c-c9fb-4db4-aa24-\
715d17478432"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraphb", "[", 
     RowBox[{"graphin2", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsi2", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}], 
     "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"CMDi6200", ",", "kri2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.834950273560528*^9, 3.834950273964845*^9}, 
   3.8350516848507423`*^9},
 CellLabel->
  "In[396]:=",ExpressionUUID->"3af7c070-1ca5-461d-bfd1-c2c85993289f"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
          103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
          129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 
          142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 
          155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 
          168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 
          181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 
          194, 195, 196, 197, 198, 199, 200}, {Null, CompressedData["
1:eJwVxfk/Gg4DAOBN5QibNGP1lWNDwghlmCNXuqiMigzJGcNQUi05SwdqhpKc
SYXco6zo8me9n/f55UnhjNA5Ia9evdoAvXr1/zG1GAHGW+sVeHN7YjOzTsqP
Yy/fDJb/rTZ/zv3ck4REYpC1SAHSW9PbO0M4Jliyjo5Ojs4RBMQgwvJ5NXe1
Z3V1B6EhaAY1Gkv5z5/HP/9++fP6e9b4+NH4uUav38Hwa/l8Ad+bu9izWFYd
u5m5uXn5+uPH73AEvBxOgGvgx3BLeFl4dbi5d39mv+NPx37HIVyKkdZI+VKB
VOrtuO693r+GqzHqcjVfLVWrj9XeTFWNqlclUElVqn3VdXhcXFlcdZw57nzK
+SYvbzBPn7eTtLy8hqDl0WpoNA1NT9uhWcBwMAJcDiaA1WAN+BhsySQSO4gq
4iZxn3hIvEYw8hgEBo3BGGRoGHqG5fNA7kDPwMDiwOrb8rc/3x6//bv5cvgC
foQ/lj8SHo8fLY9AJBADrAXygQKgN6+f1t+v799J2lreWtsCgUFwEAJUAyKA
aCAGSApSgzQgSzi9mk6fojvBs4hZwixjdnB21jL7GJuRkZlBzNjMuAz3xHnK
PNUeswdoQ9owtlob32bzZu4R9zr2VHt7+3uHe9d7L7FDGUOZQ0PjQ0dD55kb
QxuCDdXGxnl0UvRy9Fr0VmxyckbyZvIlGAJBQAgQBmQQMgvRQCyQx/Ss9KP0
E5AMLIPLMLIaGV8mlcnUMm/sZPJkxuTk5uTh5OXkS6aQKOwQTgqFm8I94aHw
WvhCpVOnqM7oyqRKZGXlcuUWEJeEQ+IwuEocjo8T4KQ4FW4DZ8N5qWK6eEos
dmacZp4STztOhaeq073T/dPT6/DGssbqxlBzqKeB2kBvmGoQNzhx9ho70d5r
F9ildpV9w75vt5/ar+Pi49Pjs+LH44/iT+LPGzhUDp3DmeKIOU4QC8yCsOAs
BIvAorEYLNYgS8PSsyzhimoFVUFXTCnECoVZ4VR4YhMSMhIyE4YSxhOOEs6B
waQgMogJVgZxQX5QEJQGN4K2oDcYWlLSWzJToigxl3hARogRYcwzEow0I8PI
Mg4aZ40ao95otABAADAADsAAygE1AD5ACpAB1IBjgDd0dHQxpCGEGkIP4YRM
hYhDnKFN4U1xTU3mpvMmT9xF/EXjxdHFycXb0tLy0p+lf1+ffTyrPft+ZjtL
Li6eLBYWbxYfFl8Wv0TX1S3XrRW3tU22Cds22w7bXqLnk+aR85XzdfPzy/Nr
81vhkhJJtYQqoUs4kimJWCJRSMwSp8Tz7vO73Hc971ZBLrAL4oK7EK4aF8FF
czFcLFe/S+PSu4wui6vsW+M3Ynt7R7uw/U/7Xvt++2H7aft1+8vrFmDLx5ba
lpbvLbaWM5Af7If44X6Ev9xP8M/6j/0W/6M//iDhIOtg6GD84ODo4PzgIvo+
6b7yvu5+/n75fu1+6z6uKL4ooahoqGi86KDoqOi86CK0s6Szs7dT0jnTqeg0
h8TElMVUx1Bj6DHfYqZiJDFOgAFkgBswBpyhxsA3CAxSg8ygNhjsBq8hCOKB
eRAegkfg0XgMHos3yOPN8jQ8Pc/Is/BcbxwIR56D5mA4WI5+x6CD59A49A6j
Y8fhcIVmZ5dk12R3Zvdmz2Sbs+0ANBCNRKMxaBy6Fs1HC9BStAytRhvQNrQX
HXy39Hkpd6lnaWBpcWlptf9m9EZ/s3MTehd3V3TXdDd6t3Fnvju/u/P0747u
Lu7qd3d2d2/A65B1+Hr5OmF9dn39eN2y/rjuB2iBWrQWoy3V1mr5WplWrdUa
tDbtX60XoAQq0UqMslbJV0qVMqVSrdQqDUqb0gslQtuhHdBeqBCqgu5B96GH
UDv0FHodP5Iwkj6SNVI0MjQyMj5yMHI0cjJyPnIBcAPdSDfajXHj3LVuvlvg
lrplbqVb5Va7tW6D2+a2u91edxBERpDzyGQamUFmkfvJg2QeWUPWk43kHbKD
fEN2NYxRxzhjY+KxmTHn24fSh9qHnw/ah7OHvw+xfcl9xX1tfX2TfZt9l30v
4TBYCawaRoXRYZ0wDmwKJoZJYDMwBcwMc8I8Zf8a/337d/Lv4l/4dNw0bLps
unq6cbppeloyrZg2T3tiFxIWkhcyFjIXhhbGFxYOFi4jYiOSIzIiMiOKI9oi
+iImI4QRmxGHEZcRLx/SP2R9GPlwBLxNukXeYm4rb+dvl2+3bm23t/e33tsg
TN4gp8rpco58TD4lF8sl8hm53BnBhDIzmJnMYiaRyWxjtjM7mH3MSaaQucnc
Yx4yT5nXzJeQqqqGKmoVvYpTNVY1VSWuklc5wwOwQHagJEAN0AOdgbHAVEAc
kARmAvKAImAOOAPRXV0DXYtdS11bwNTo1KTUVGRqZSoudT51OXUr9Tb1PjX4
5v279+/z3q++d4RwY7gwbhW3mtvApXLpXA6XO8ad4oq5Eq6cq+A6uYFQSjal
hEJponRSRim7FDPlhnJH8QDZaDaGXcquZbew2Xy2kq1ma9k29hn7ge1me0Eo
MAqCgqMQKBQBRUbRUAwUCzWI4qFmURrUOsqIsqAcKBfqEeWP/vSp7tPyp7VP
9xEmqCnDlGkimpimNlO7qcM0aRKaNk2mPdO+6dB0aro2vQBEQBFShBZhRDhR
rYgt4osEIpFUJBMpRWqRVmQQ2URukVcU/DLMGR4eGxYPzwzLs1dqVsgrlBXa
Sv/K6MqKfmVnZXflZsX1Zg4yh5hDzTHmBud4c7Nzc8Y5x7v8z/m5+fld+T35
A/mL+Uv5q+ACSAGiAFVQQChgFAwW8ApmC+YKjAWWgscCf0RzbDO0OaM5s5nY
3MxsnmwWNi80q5o3m03Ne82nzS8hhTGFhVWF1EJ6IbdwqlBcKCl0hoWHxYQV
hpWFVYc1hn0Lmw6ThCnCPEBsKhaJRWMxWGwlFoflYwVYEVaKVWE3sAasDWvH
urFebBCQCEoEJ8ITE8sTCYmyRHXieuJxoiXxMdH/8cenH3U/fiz/WPvyNPw0
9jTzJH8C4EF4MB6OT8Qj8Ch8DR5PwJPxNDwDz8Lz8FK8DK/Ga/AGvAXvwvtf
+4A+pA/tw/hqfS0+tu+7j+8T+ZQ+rc/mO/Pd+ry+0O2k7cpt3DZlu2l7dFuw
vbG9bd4+377bDob9KvvV+Ovbr1//4lrjW9Nbs1qLWltHWsdbD1qPWk9az1sv
orKjSqJqoihRnVG9UTNRqqj9KPuX38O/x37Lf//+8/spuuJTRUVdxY+K+Yrl
irWKrYp72AR1gjMxPDE2MSGemJmQT/yeeJoIRKVAU1KyU0pSalIoKZ0pvSkz
KaqU/RR7ynWoNdwaZ4VZS6zVVoq1ydppnbZKrArrttVstd5ZPdZAVDesO6U7
u7ukm9Ld2d3d2z3cPdE90y3vVnTvdz91BwAkEAlMgpNqSHgSgUSikVgkPklK
kpHUJA3JQLKQXCQ3SAfWQXRwHUKH0uXpCnR4HUFH0pF1NB1Dx9IN6ni6OZ1G
p9PrjDqLzqFzxX/98DX9a9bXr61fR74efT15HRn5MbIusiXye+SPyOXIs8jb
SB/gGfz89hn+nPhc+lz+/PNZ+ax+1j6vPx8//31+fH72p+Wm5ad1pfWkDaQt
pi2l7b6vz6uvJ9fT6vvrV+pX6/X1O/W79Y76m9CrsKvwq7irsqvqq8arpqvp
K8WV+cp6dXF1dXflCc1JyknNScvJqcwZzZnPWczZytnOufuv67+B/wGjzX/m

           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[21, 55] -> 
             RGBColor[
              0.9357166251286451, 0.9512170765955623, 0.9811807042190566], 
             UndirectedEdge[64, 132] -> 
             RGBColor[
              0.7251997209539491, 0.7814038324674086, 0.8801602433254545], 
             UndirectedEdge[42, 188] -> 
             RGBColor[
              0.739566712095358, 0.7965842279063562, 0.9746476122619301], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.7074099182241105, 0.769810629884339, 0.9729070456677087], 
             UndirectedEdge[33, 68] -> 
             RGBColor[
              0.7113786086707126, 0.6655262884009212, 0.604625250307222], 
             UndirectedEdge[168, 188] -> 
             RGBColor[
              0.5135686115231186, 0.6139801224126471, 0.9554209242393723], 
             UndirectedEdge[41, 161] -> 
             RGBColor[
              0.7757790026741023, 0.825353837475999, 0.9782454524643998], 
             UndirectedEdge[44, 68] -> 
             RGBColor[
              0.9136140873384946, 0.8263654821052989, 0.6231241784498978], 
             UndirectedEdge[26, 136] -> 
             RGBColor[
              0.6622889007798062, 0.7338323553516417, 0.9686033627438632], 
             UndirectedEdge[9, 32] -> 
             RGBColor[
              0.5572909129159673, 0.6514728946315315, 0.9582911285700744], 
             UndirectedEdge[71, 141] -> 
             RGBColor[
              0.9134464032697369, 0.9305350702158559, 0.8598488785910869], 
             UndirectedEdge[52, 100] -> 
             RGBColor[
              0.9034172247528394, 0.9255533704492764, 0.9812535631501438], 
             UndirectedEdge[172, 180] -> 
             RGBColor[
              0.6544373243550103, 0.7248952198330634, 0.9692312228526274], 
             UndirectedEdge[168, 197] -> 
             RGBColor[
              0.6728743101425336, 0.7388621029418864, 0.9455321953298607], 
             UndirectedEdge[125, 137] -> 
             RGBColor[
              0.6941536922815776, 0.7593541085717752, 0.9715118650171983], 
             UndirectedEdge[17, 147] -> 
             RGBColor[
              0.6578802584065009, 0.7292192105935151, 0.9688328558965884], 
             UndirectedEdge[10, 71] -> 
             RGBColor[
              0.7267270807161301, 0.7862201954456836, 0.9735909735261735], 
             UndirectedEdge[27, 129] -> 
             RGBColor[
              0.6843350285690695, 0.7365261396750653, 0.6749499067821539], 
             UndirectedEdge[67, 166] -> 
             RGBColor[
              0.7947199116488899, 0.8404704531027549, 0.9799324387792843], 
             UndirectedEdge[3, 49] -> 
             RGBColor[
              0.7986786294241082, 0.8392297808876095, 0.775649190145432], 
             UndirectedEdge[151, 183] -> 
             RGBColor[
              0.870066185976173, 0.39915872153943976`, 0.22933127062133907`], 
             UndirectedEdge[125, 136] -> 
             RGBColor[
              0.8663359889113547, 0.8962568177666929, 0.987113094081274], 
             UndirectedEdge[139, 194] -> 
             RGBColor[
              0.7301160386102202, 0.7888573022901917, 0.9739892089344835], 
             UndirectedEdge[24, 108] -> 
             RGBColor[
              0.7126279028602569, 0.7746696328598233, 0.9726009839698236], 
             UndirectedEdge[21, 192] -> 
             RGBColor[
              0.6753637853569509, 0.7432133109337914, 0.9704759545761799], 
             UndirectedEdge[16, 52] -> 
             RGBColor[
              0.8250117754646028, 0.8639739460603852, 0.9735260122499669], 
             UndirectedEdge[44, 166] -> 
             RGBColor[
              0.9193702873539071, 0.9385449277671029, 0.9921715528110018], 
             UndirectedEdge[78, 187] -> 
             RGBColor[
              0.5208700107067673, 0.6196840309476026, 0.9561486594745437], 
             UndirectedEdge[99, 162] -> 
             RGBColor[
              0.3815755100901777, 0.5049232611225005, 0.945534631982339], 
             UndirectedEdge[93, 150] -> 
             RGBColor[
              0.7004076435981383, 0.7650087320935182, 0.9713715164590693], 
             UndirectedEdge[118, 155] -> 
             RGBColor[
              0.5894278640714201, 0.6772230546754889, 0.9610535711499467], 
             UndirectedEdge[16, 125] -> 
             RGBColor[
              0.7970818541765854, 0.8419744031969203, 0.9802584037326818], 
             UndirectedEdge[61, 179] -> 
             RGBColor[
              0.5486323639387901, 0.6443392108962066, 0.9576599684968539], 
             UndirectedEdge[51, 197] -> 
             RGBColor[
              0.7569871502039283, 0.8090966725471727, 0.9516156344202591], 
             UndirectedEdge[80, 120] -> 
             RGBColor[
              0.714664650871332, 0.7770207240039846, 0.9721947515441298], 
             UndirectedEdge[21, 183] -> 
             RGBColor[
              0.8521117290939109, 0.4028847782025117, 0.440276498201122], 
             UndirectedEdge[182, 199] -> 
             RGBColor[
              0.3815755100901777, 0.5049232611225005, 0.945534631982339], 
             UndirectedEdge[17, 189] -> 
             RGBColor[
              0.9156668955940248, 0.9354022186730996, 0.985240434088533], 
             UndirectedEdge[116, 136] -> 
             RGBColor[
              0.8639397111373783, 0.8943460909149515, 0.9868845349680098], 
             UndirectedEdge[119, 123] -> 
             RGBColor[
              0.7687553988461635, 0.8141080956860589, 0.7053768075172346], 
             UndirectedEdge[71, 89] -> 
             RGBColor[
              0.6659402318658589, 0.7368706931326994, 0.9688056101151159], 
             UndirectedEdge[7, 61] -> 
             RGBColor[
              0.4689639985576357, 0.5797140058818974, 0.9513518350913543], 
             UndirectedEdge[3, 27] -> 
             RGBColor[
              0.6877926533469615, 0.7472595733487031, 0.7674580717146449], 
             UndirectedEdge[41, 108] -> 
             RGBColor[
              0.7530297345994257, 0.8068849568101288, 0.9764545467482465], 
             UndirectedEdge[66, 98] -> 
             RGBColor[
              0.4851706426336314, 0.5909744334319968, 0.9531517885029139], 
             UndirectedEdge[119, 127] -> 
             RGBColor[
              0.8462825757892418, 0.8761681629130662, 0.7120816831886145], 
             UndirectedEdge[15, 167] -> 
             RGBColor[
              0.8815271671823419, 0.908369850966429, 0.9885620422260857], 
             UndirectedEdge[12, 96] -> 
             RGBColor[
              0.9768478388567567, 0.9795436991595539, 0.7727267841051503], 
             UndirectedEdge[7, 52] -> 
             RGBColor[
              0.7163507535781728, 0.7766994574318042, 0.9643281617958008], 
             UndirectedEdge[163, 165] -> 
             RGBColor[
              0.9914283995635995, 0.9885125235023517, 0.6310070467806849], 
             UndirectedEdge[71, 73] -> 
             RGBColor[
              0.6404152383166737, 0.7160239707873742, 0.9668305564308093], 
             UndirectedEdge[60, 165] -> 
             RGBColor[
              0.6858565664809455, 0.7475564644877462, 0.8793216371096466], 
             UndirectedEdge[120, 124] -> 
             RGBColor[
              0.701308331038623, 0.7664472466788822, 0.970958839772758], 
             UndirectedEdge[43, 163] -> 
             RGBColor[
              0.8399243848921889, 0.8711727535427978, 0.7091778828411957], 
             UndirectedEdge[146, 194] -> 
             RGBColor[
              0.9171519800474259, 0.9350964061372793, 0.9299668548780369], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.6858274210939951, 0.7475444121212398, 0.8798046515972575], 
             UndirectedEdge[81, 157] -> 
             RGBColor[
              0.6688258765353138, 0.7385405258223217, 0.9696036028836056], 
             UndirectedEdge[59, 114] -> 
             RGBColor[
              0.8061475531330733, 0.8493552508609372, 0.9810827340963915], 
             UndirectedEdge[31, 185] -> 
             RGBColor[
              0.9135492236101765, 0.9068396897160599, 0.6726297249965809], 
             UndirectedEdge[58, 198] -> 
             RGBColor[
              0.8226142421609544, 0.8622345762276913, 0.9827198870459641], 
             UndirectedEdge[30, 142] -> 
             RGBColor[
              0.5852422946936071, 0.6741650855540189, 0.9604915637328952], 
             UndirectedEdge[26, 96] -> 
             RGBColor[
              0.7209569915175377, 0.7799948302006517, 0.9527772991669547], 
             UndirectedEdge[25, 111] -> 
             RGBColor[
              0.7259522987492619, 0.7793309080205625, 0.6997366781088699], 
             UndirectedEdge[89, 107] -> 
             RGBColor[
              0.4406812890333651, 0.554855971956761, 0.9496494236176289], 
             UndirectedEdge[51, 189] -> 
             RGBColor[
              0.7464287552204385, 0.8012222388562711, 0.9694882430568612], 
             UndirectedEdge[81, 158] -> 
             RGBColor[
              0.8586873436785399, 0.8901579956749904, 0.9863835594709419], 
             UndirectedEdge[93, 159] -> 
             RGBColor[
              0.8760192703453868, 0.9039931427399932, 0.9873041223884624], 
             UndirectedEdge[191, 195] -> 
             RGBColor[
              0.6587760756302696, 0.7312313284125287, 0.9680797836917621], 
             UndirectedEdge[17, 131] -> 
             RGBColor[
              0.8530727280133954, 0.8856981565092443, 0.9858434938166034], 
             UndirectedEdge[18, 32] -> 
             RGBColor[
              0.4338271865795682, 0.5492915028109718, 0.9491098435650616], 
             UndirectedEdge[59, 184] -> 
             RGBColor[
              0.9191476287794682, 0.9383673858637513, 0.9921503154374021], 
             UndirectedEdge[156, 175] -> 
             RGBColor[
              0.8142321176778045, 0.854803585813976, 0.9821187061245199], 
             UndirectedEdge[2, 82] -> 
             RGBColor[
              0.5985531788040335, 0.6803707122791316, 0.9638913916799992], 
             UndirectedEdge[12, 44] -> 
             RGBColor[
              0.9501059755427972, 0.9588383314439024, 0.7915979997546178], 
             UndirectedEdge[115, 175] -> 
             RGBColor[
              0.6694658696848933, 0.7399793303860108, 0.9688737747379019], 
             UndirectedEdge[30, 131] -> 
             RGBColor[
              0.711892005285519, 0.774296452309464, 0.9723000854797094], 
             UndirectedEdge[53, 65] -> 
             RGBColor[
              0.8816813272268005, 0.9081674769062913, 0.9752687961374844], 
             UndirectedEdge[17, 51] -> 
             RGBColor[
              0.7190393305865534, 0.7795723801499017, 0.9734537011948077], 
             UndirectedEdge[109, 128] -> 
             RGBColor[
              0.7573334433729477, 0.7027527561104301, 0.6082241641791246], 
             UndirectedEdge[101, 135] -> 
             RGBColor[
              0.6714668467954925, 0.6931187409600255, 0.6249594505440303], 
             UndirectedEdge[54, 195] -> 
             RGBColor[
              0.6131917098761048, 0.695620475431364, 0.9635363601235046], 
             UndirectedEdge[122, 192] -> 
             RGBColor[
              0.6519451488091159, 0.7245399258325026, 0.9682422641161837], 
             UndirectedEdge[155, 195] -> 
             RGBColor[
              0.5839745315324234, 0.6727957936505002, 0.9606242648362616], 
             UndirectedEdge[42, 87] -> 
             RGBColor[0.68213289022648, 0.7500059254267664, 0.9700926678171], 
             UndirectedEdge[31, 153] -> 
             RGBColor[
              0.9222770442890728, 0.9359639480974069, 0.7334681066726386], 
             UndirectedEdge[64, 199] -> 
             RGBColor[
              0.4208153454210207, 0.5387279039816988, 0.9480855037651159], 
             UndirectedEdge[107, 188] -> 
             RGBColor[
              0.5135686115231186, 0.6139801224126471, 0.9554209242393723], 
             UndirectedEdge[27, 189] -> 
             RGBColor[
              0.6623159151590436, 0.7309876692509847, 0.9634048039664628], 
             UndirectedEdge[14, 176] -> 
             RGBColor[
              0.7229824430393347, 0.777725186715752, 0.7685025960911627], 
             UndirectedEdge[123, 146] -> 
             RGBColor[
              0.7655890956403069, 0.8149736438085686, 0.915942616033907], 
             UndirectedEdge[30, 130] -> 
             RGBColor[
              0.6061976841868986, 0.6911776147742115, 0.9621412487559282], 
             UndirectedEdge[72, 143] -> 
             RGBColor[
              0.7535921744798543, 0.8019672870769402, 0.7180654609499326], 
             UndirectedEdge[68, 155] -> 
             RGBColor[
              0.7928054786879635, 0.7312922250624267, 0.6112679758548172], 
             UndirectedEdge[32, 39] -> 
             RGBColor[
              0.33250293153447935`, 0.44952687224972154`, 0.943093027573892], 
             UndirectedEdge[184, 194] -> 
             RGBColor[
              0.8794358792180552, 0.9067023147102062, 0.9883625733131371], 
             UndirectedEdge[74, 152] -> 
             RGBColor[
              0.6646637960238602, 0.7355412555490966, 0.9690425570863224], 
             UndirectedEdge[71, 147] -> 
             RGBColor[
              0.6297882208040135, 0.7068193823473388, 0.9661534122720051], 
             UndirectedEdge[39, 173] -> 
             RGBColor[
              0.5134013197485086, 0.593465518118268, 0.959426664737193], 
             UndirectedEdge[139, 171] -> 
             RGBColor[
              0.5627609449743094, 0.6559137130786296, 0.9587217495310947], 
             UndirectedEdge[73, 189] -> 
             RGBColor[
              0.6958967005530459, 0.76007365773992, 0.965544541917446], 
             UndirectedEdge[20, 22] -> 
             RGBColor[
              0.9163387580571192, 0.7059562472407482, 0.25153920604496], 
             UndirectedEdge[17, 168] -> 
             RGBColor[
              0.6349264905251588, 0.7093378105446153, 0.9673702621044091], 
             UndirectedEdge[13, 132] -> 
             RGBColor[
              0.870652784880382, 0.8978255334920254, 0.8927482871392297], 
             UndirectedEdge[99, 109] -> 
             RGBColor[
              0.6512881685772185, 0.6147124479428859, 0.6004141234852838], 
             UndirectedEdge[119, 195] -> 
             RGBColor[
              0.7480758550210413, 0.7973195104059918, 0.703748838075656], 
             UndirectedEdge[10, 188] -> 
             RGBColor[
              0.6334612393165773, 0.7132623355598917, 0.96432107928572], 
             UndirectedEdge[182, 185] -> 
             RGBColor[
              0.6785680340093483, 0.7170727128704099, 0.6525462219231781], 
             UndirectedEdge[98, 187] -> 
             RGBColor[
              0.3815755100901777, 0.5049232611225005, 0.945534631982339], 
             UndirectedEdge[10, 167] -> 
             RGBColor[
              0.7249403500878575, 0.7847955049422097, 0.9734205535638156], 
             UndirectedEdge[113, 187] -> 
             RGBColor[
              0.5745723235997573, 0.6616366859323011, 0.9615012041470701], 
             UndirectedEdge[83, 170] -> 
             RGBColor[
              0.8553453265457894, 0.724332416309899, 0.6058891180555557], 
             UndirectedEdge[39, 41] -> 
             RGBColor[
              0.5531130693099215, 0.6251305892718131, 0.9632144068614579], 
             UndirectedEdge[138, 145] -> 
             RGBColor[
              0.5278344530307169, 0.6275588134982897, 0.9559722081453395], 
             UndirectedEdge[75, 155] -> 
             RGBColor[
              0.6306770540363095, 0.7107110053438175, 0.9643008584847443], 
             UndirectedEdge[90, 163] -> 
             RGBColor[
              0.9930195740972327, 0.9874778997603277, 0.48160190255798435`], 
             UndirectedEdge[2, 66] -> 
             RGBColor[
              0.7021483113474871, 0.7664218845886279, 0.9715085482005741], 
             UndirectedEdge[88, 200] -> 
             RGBColor[
              0.7443460599640983, 0.8001387452347632, 0.9754215133609674], 
             UndirectedEdge[67, 170] -> 
             RGBColor[
              0.7728238722616083, 0.6598504000274179, 0.5976682981578896], 
             UndirectedEdge[124, 136] -> 
             RGBColor[
              0.7377904217766786, 0.7951278914016626, 0.9745471190479214], 
             UndirectedEdge[129, 155] -> 
             RGBColor[
              0.8258264135401369, 0.8530031322548249, 0.6857828991757615], 
             UndirectedEdge[149, 167] -> 
             RGBColor[
              0.8624034817112884, 0.7440243841192394, 0.6093389292801232], 
             UndirectedEdge[172, 173] -> 
             RGBColor[
              0.6147255747935974, 0.6932301486795183, 0.9654434807283625], 
             UndirectedEdge[143, 160] -> 
             RGBColor[
              0.8026284410925276, 0.8417771373717451, 0.7219257754834454], 
             UndirectedEdge[27, 89] -> 
             RGBColor[
              0.4406812890333651, 0.554855971956761, 0.9496494236176289], 
             UndirectedEdge[172, 191] -> 
             RGBColor[
              0.5978684391590913, 0.6798357884642887, 0.963823143231447], 
             UndirectedEdge[11, 182] -> 
             RGBColor[
              0.6833878584579236, 0.7465355902773243, 0.9202345178626834], 
             UndirectedEdge[159, 164] -> 
             RGBColor[
              0.7317513501763553, 0.7895227177920778, 0.9741331086461158], 
             UndirectedEdge[151, 156] -> 
             RGBColor[
              0.8972016661961605, 0.8938138152779029, 0.671068032583964], 
             UndirectedEdge[94, 196] -> 
             RGBColor[
              0.5654946757730425, 0.6576953437223423, 0.9592362407612537], 
             UndirectedEdge[69, 139] -> 
             RGBColor[
              0.8025378069894546, 0.8415064737477795, 0.7057657698594981], 
             UndirectedEdge[53, 127] -> 
             RGBColor[
              0.7563001362253984, 0.80954668160399, 0.9763445876184909], 
             UndirectedEdge[171, 196] -> 
             RGBColor[
              0.5920498115097083, 0.6792539992085995, 0.9613267583211114], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.8220216519316915, 0.8615608851354262, 0.9693224772554317], 
             UndirectedEdge[74, 162] -> 
             RGBColor[
              0.4191474223498675, 0.5373738088934585, 0.9479541987511513], 
             UndirectedEdge[34, 153] -> 
             RGBColor[
              0.8246857782825863, 0.8594698710317572, 0.7238088006531471], 
             UndirectedEdge[98, 109] -> 
             RGBColor[
              0.6512881685772185, 0.6147124479428859, 0.6004141234852838], 
             UndirectedEdge[77, 183] -> 
             RGBColor[
              0.8759836967212382, 0.41878656698250205`, 0.2806617716744517], 
             UndirectedEdge[2, 78] -> 
             RGBColor[
              0.737847679420623, 0.7951314821042337, 0.9745054191722038], 
             UndirectedEdge[113, 193] -> 
             RGBColor[
              0.6200226481417528, 0.7004832837124635, 0.9645409883903207], 
             UndirectedEdge[100, 120] -> 
             RGBColor[
              0.8149922663012426, 0.8557259111973852, 0.9821072990910186], 
             UndirectedEdge[1, 35] -> 
             RGBColor[
              0.5608444132029027, 0.6509123379942949, 0.9601329343333282], 
             UndirectedEdge[154, 176] -> 
             RGBColor[
              0.4829393953454898, 0.5910745748830086, 0.9524479644665513], 
             UndirectedEdge[13, 31] -> 
             RGBColor[
              0.8012495989482817, 0.8449165818519657, 0.980757050652294], 
             UndirectedEdge[92, 196] -> 
             RGBColor[
              0.5787134500188268, 0.6684269401540635, 0.9602768710918475], 
             UndirectedEdge[66, 124] -> 
             RGBColor[
              0.6110117881223056, 0.6950859212218857, 0.9625202326523672], 
             UndirectedEdge[141, 167] -> 
             RGBColor[
              0.9116596726414643, 0.9291103797123822, 0.8596784586287289], 
             UndirectedEdge[76, 158] -> 
             RGBColor[
              0.7419529881916838, 0.7983748142029496, 0.974904982678227], 
             UndirectedEdge[101, 134] -> 
             RGBColor[
              0.5391188594501471, 0.6339401702823182, 0.9579675341720965], 
             UndirectedEdge[139, 141] -> 
             RGBColor[
              0.8035779242538661, 0.8441475026505909, 0.849238420299721], 
             UndirectedEdge[88, 93] -> 
             RGBColor[
              0.70943915488118, 0.772340919818038, 0.9720825101107862], 
             UndirectedEdge[17, 130] -> 
             RGBColor[
              0.7473784069147749, 0.8025793189739917, 0.9756846570928224], 
             UndirectedEdge[32, 117] -> 
             RGBColor[
              0.7388649242479473, 0.7922376133303315, 0.8703566816939774], 
             UndirectedEdge[32, 103] -> 
             RGBColor[
              0.4338271865795682, 0.5492915028109718, 0.9491098435650616], 
             UndirectedEdge[148, 150] -> 
             RGBColor[
              0.5852844396783876, 0.6741993007512735, 0.9604948815404794], 
             UndirectedEdge[77, 156] -> 
             RGBColor[
              0.9060779323137583, 0.9232555834424965, 0.7480637841636331], 
             UndirectedEdge[76, 89] -> 
             RGBColor[
              0.5796130676361733, 0.6693333805879074, 0.96022729836933], 
             UndirectedEdge[42, 51] -> 
             RGBColor[
              0.6916864507238116, 0.757761936221496, 0.9708447590952952], 
             UndirectedEdge[82, 124] -> 
             RGBColor[
              0.507416655578852, 0.6090347489123894, 0.9549030761317923], 
             UndirectedEdge[15, 114] -> 
             RGBColor[
              0.8097651837561837, 0.8522398513218381, 0.9814277869347208], 
             UndirectedEdge[41, 173] -> 
             RGBColor[
              0.88758738905843, 0.9132021073900811, 0.9891400715986509], 
             UndirectedEdge[41, 133] -> 
             RGBColor[
              0.7099614646764784, 0.7719201950832306, 0.9730640547756411], 
             UndirectedEdge[27, 147] -> 
             RGBColor[
              0.4045292779715197, 0.5248046611714002, 0.9469972257745182], 
             UndirectedEdge[19, 88] -> 
             RGBColor[
              0.7838878630035805, 0.830927457037338, 0.9535073595428587], 
             UndirectedEdge[127, 172] -> 
             RGBColor[
              0.5406898673295565, 0.6351674535778149, 0.9581241175556126], 
             UndirectedEdge[69, 174] -> 
             RGBColor[
              0.9938256470122919, 0.9892020082191662, 0.5693379648567796], 
             UndirectedEdge[117, 121] -> 
             RGBColor[
              0.8713061470158325, 0.8980957155256752, 0.8819203857078071], 
             UndirectedEdge[69, 196] -> 
             RGBColor[
              0.8318266735248535, 0.8648467598777496, 0.7083707786495149], 
             UndirectedEdge[92, 195] -> 
             RGBColor[
              0.4949417561379834, 0.6008550403616602, 0.9533827745560247], 
             UndirectedEdge[144, 158] -> 
             RGBColor[
              0.9087180615958099, 0.9251208674240918, 0.7296200559780959], 
             UndirectedEdge[81, 168] -> 
             RGBColor[
              0.637241644179842, 0.7111838512256878, 0.9675910835267549], 
             UndirectedEdge[87, 188] -> 
             RGBColor[
              0.5881278910871817, 0.6764586812232039, 0.9607522720515757], 
             UndirectedEdge[74, 88] -> 
             RGBColor[
              0.5300333984270141, 0.629344016432365, 0.9561453171819384], 
             UndirectedEdge[74, 140] -> 
             RGBColor[
              0.647943728403611, 0.7222091274828548, 0.9674477821105225], 
             UndirectedEdge[152, 178] -> 
             RGBColor[
              0.8045835565172668, 0.8476913987855399, 0.9810441549554134], 
             UndirectedEdge[63, 153] -> 
             RGBColor[
              0.9651731454677703, 0.9701260734311705, 0.7361012812554109], 
             UndirectedEdge[154, 158] -> 
             RGBColor[
              0.6691842945184371, 0.7395595553338135, 0.9689974765408269], 
             UndirectedEdge[23, 90] -> 
             RGBColor[
              0.9673111649165189, 0.971932197755838, 0.7492711652333546], 
             UndirectedEdge[51, 131] -> 
             RGBColor[
              0.683834587639809, 0.7515181766924158, 0.9700913027849317], 
             UndirectedEdge[21, 83] -> 
             RGBColor[
              0.8718074208867175, 0.9006195891057828, 0.9876349641474891], 
             UndirectedEdge[57, 178] -> 
             RGBColor[
              0.8657737644760213, 0.8929071235524798, 0.8351515831126437], 
             UndirectedEdge[17, 197] -> 
             RGBColor[
              0.9262252905775147, 0.9432766523640013, 0.9673678254519309], 
             UndirectedEdge[64, 156] -> 
             RGBColor[
              0.6394489776078329, 0.715469006389192, 0.9666073144259019], 
             UndirectedEdge[40, 123] -> 
             RGBColor[
              0.6191132839872111, 0.7008800226061176, 0.9636933930650582], 
             UndirectedEdge[26, 99] -> 
             RGBColor[
              0.4319151345819796, 0.5477392128623685, 0.9489593198277341], 
             UndirectedEdge[114, 167] -> 
             RGBColor[
              0.7567579510724616, 0.8099733228228392, 0.976371909761232], 
             UndirectedEdge[75, 168] -> 
             RGBColor[
              0.4891856690652421, 0.594234012764058, 0.9534678660911369], 
             UndirectedEdge[55, 111] -> 
             RGBColor[
              0.9712276196155216, 0.9744345988676506, 0.7094366825795813], 
             UndirectedEdge[67, 122] -> 
             RGBColor[
              0.7658673300547015, 0.8174641877220129, 0.977180453789827], 
             UndirectedEdge[127, 129] -> 
             RGBColor[
              0.8434493858084482, 0.8667703321303797, 0.6875393923554276], 
             UndirectedEdge[96, 198] -> 
             RGBColor[
              0.8378402172168979, 0.8737574872368603, 0.9627502756940922], 
             UndirectedEdge[154, 181] -> 
             RGBColor[
              0.7448018555056275, 0.7988233778567877, 0.9404448360422593], 
             UndirectedEdge[9, 91] -> 
             RGBColor[
              0.5552320882505638, 0.6498014480191626, 0.9581290503506905], 
             UndirectedEdge[39, 152] -> 
             RGBColor[
              0.5257676287190816, 0.6033260772168882, 0.9606061743263405], 
             UndirectedEdge[54, 65] -> 
             RGBColor[
              0.8367796216457075, 0.8730899232407395, 0.9707934137554568], 
             UndirectedEdge[116, 128] -> 
             RGBColor[
              0.7396112197352809, 0.7962932565932226, 0.9750505327457215], 
             UndirectedEdge[74, 95] -> 
             RGBColor[
              0.7046127613825217, 0.3369589286761489, 0.433445849395387], 
             UndirectedEdge[152, 200] -> 
             RGBColor[
              0.8789764575609443, 0.9063359843514947, 0.9883187532653515], 
             UndirectedEdge[140, 191] -> 
             RGBColor[
              0.8266647452128348, 0.864671107053685, 0.9833167265908183], 
             UndirectedEdge[109, 193] -> 
             RGBColor[
              0.696738493119214, 0.6535590457230485, 0.6034539077285341], 
             UndirectedEdge[80, 137] -> 
             RGBColor[
              0.5789644449796105, 0.6687986595318474, 0.9601818017552175], 
             UndirectedEdge[118, 199] -> 
             RGBColor[
              0.4479364791003527, 0.5607460620957294, 0.9502205787563391], 
             UndirectedEdge[45, 64] -> 
             RGBColor[
              0.5558375000373351, 0.6501510846403536, 0.9582737037353566], 
             UndirectedEdge[125, 170] -> 
             RGBColor[
              0.8895609669683774, 0.7516150392240531, 0.6091526363837247], 
             UndirectedEdge[70, 145] -> 
             RGBColor[
              0.750823012806825, 0.8050464900585363, 0.9763348647916976], 
             UndirectedEdge[17, 142] -> 
             RGBColor[
              0.7264230174214835, 0.7855667897537992, 0.9740349720697894], 
             UndirectedEdge[95, 180] -> 
             RGBColor[
              0.861472696052617, 0.46197320263588537`, 0.4476305321297043], 
             UndirectedEdge[41, 121] -> 
             RGBColor[
              0.8391302236122864, 0.8751215637168784, 0.9843701384491796], 
             UndirectedEdge[5, 10] -> 
             RGBColor[
              0.8079189130798434, 0.8470415015905614, 0.8017876215580133], 
             UndirectedEdge[167, 194] -> 
             RGBColor[
              0.8381977869978184, 0.873820179351983, 0.9844292472634915], 
             UndirectedEdge[78, 100] -> 
             RGBColor[
              0.7603950914580611, 0.8130741832559945, 0.9766655629422575], 
             UndirectedEdge[106, 157] -> 
             RGBColor[
              0.6930231663475898, 0.7576902927292501, 0.9669018236855982], 
             UndirectedEdge[24, 115] -> 
             RGBColor[
              0.6879028768097428, 0.7545967428622856, 0.9706545393483724], 
             UndirectedEdge[74, 164] -> 
             RGBColor[
              0.4918571708946917, 0.5983508351021742, 0.9531399447064648], 
             UndirectedEdge[46, 135] -> 
             RGBColor[
              0.7786049058365717, 0.782046220607314, 0.6328555192166658], 
             UndirectedEdge[126, 190] -> 
             RGBColor[
              0.6117818481577911, 0.6941983639636233, 0.9636151140960763], 
             UndirectedEdge[21, 177] -> 
             RGBColor[
              0.9572779842527608, 0.9637671573351101, 0.7282470425927972], 
             UndirectedEdge[24, 133] -> 
             RGBColor[
              0.6695596329373097, 0.739704871132925, 0.9692104919972182], 
             UndirectedEdge[30, 188] -> 
             RGBColor[
              0.6257388692302234, 0.7069929676349817, 0.9637131460245485], 
             UndirectedEdge[80, 98] -> 
             RGBColor[
              0.520772975411561, 0.6196082262374918, 0.956138987903164], 
             UndirectedEdge[12, 102] -> 
             RGBColor[
              0.7662900663025056, 0.812952973992908, 0.7745491275903801], 
             UndirectedEdge[51, 168] -> 
             RGBColor[
              0.4656883501515724, 0.5751578307277869, 0.9516180710727374], 
             UndirectedEdge[42, 189] -> 
             RGBColor[
              0.888314015731283, 0.9135917747446939, 0.9826314919890206], 
             UndirectedEdge[52, 187] -> 
             RGBColor[
              0.6638921440015455, 0.7321632181408846, 0.96073665968243], 
             UndirectedEdge[10, 89] -> 
             RGBColor[
              0.5605739168268238, 0.6541381851040056, 0.9585495786639766], 
             UndirectedEdge[148, 193] -> 
             RGBColor[
              0.5288802994262781, 0.6284078787170495, 0.9560545410046597], 
             UndirectedEdge[4, 92] -> 
             RGBColor[
              0.645467580956354, 0.7205757745926455, 0.966930299010879], 
             UndirectedEdge[28, 97] -> 
             RGBColor[
              0.6965120678289178, 0.7584389081015082, 0.9339467054678507], 
             UndirectedEdge[60, 169] -> 
             RGBColor[
              0.46183700959225815`, 0.5720311389608206, 0.9513148794359829], 
             UndirectedEdge[44, 198] -> 
             RGBColor[
              0.8110983539029384, 0.8530521195212089, 0.9816214913435597], 
             UndirectedEdge[13, 64] -> 
             RGBColor[
              0.6055082446782967, 0.688954247865514, 0.9632244193616681], 
             UndirectedEdge[42, 106] -> 
             RGBColor[
              0.8874370345643572, 0.9129377236263254, 0.9841159923513052], 
             UndirectedEdge[43, 90] -> 
             RGBColor[
              0.8402247827339357, 0.8718152741514138, 0.7418743340747647], 
             UndirectedEdge[166, 192] -> 
             RGBColor[
              0.6807977304033043, 0.7475461912132446, 0.9709942491056411], 
             UndirectedEdge[5, 89] -> 
             RGBColor[
              0.7471320642295722, 0.7976919992775773, 0.7970022581469558], 
             UndirectedEdge[114, 184] -> 
             RGBColor[
              0.7979960432926984, 0.8428554581810623, 0.9803052358108777], 
             UndirectedEdge[58, 192] -> 
             RGBColor[
              0.6791188286407878, 0.7462074805203884, 0.970834113956759], 
             UndirectedEdge[17, 157] -> 
             RGBColor[
              0.6665107228806306, 0.7366944851412491, 0.9693827814612599], 
             UndirectedEdge[38, 111] -> 
             RGBColor[
              0.9646134347141851, 0.9695017505979677, 0.7206327723618406], 
             UndirectedEdge[3, 191] -> 
             RGBColor[
              0.9040855824158751, 0.9221721006904912, 0.7857465829637529], 
             UndirectedEdge[40, 195] -> 
             RGBColor[
              0.598433740162089, 0.6840914373260507, 0.9620654236234796], 
             UndirectedEdge[113, 136] -> 
             RGBColor[
              0.8049460897975839, 0.8477298284215742, 0.9811452470631992], 
             UndirectedEdge[53, 141] -> 
             RGBColor[
              0.9037977293330851, 0.9228995770660926, 0.8589131621564783], 
             UndirectedEdge[142, 176] -> 
             RGBColor[
              0.5082728373122531, 0.6116414043301821, 0.9544423058176306], 
             UndirectedEdge[99, 128] -> 
             RGBColor[
              0.4876207848859069, 0.5929635692900447, 0.9533446726761798], 
             UndirectedEdge[41, 151] -> 
             RGBColor[
              0.951429848274181, 0.9370446715809726, 0.6762428127934665], 
             UndirectedEdge[5, 157] -> 
             RGBColor[
              0.7196105176418566, 0.7751159630399506, 0.7948999858685164], 
             UndirectedEdge[39, 74] -> 
             RGBColor[
              0.31782316730477866`, 0.43760917833220836`, 0.9419373827599817],
              UndirectedEdge[86, 171] -> 
             RGBColor[
              0.7475907773464796, 0.8008790384982877, 0.9350718188123591], 
             UndirectedEdge[162, 180] -> 
             RGBColor[
              0.6544373243550103, 0.7248952198330634, 0.9692312228526274], 
             UndirectedEdge[27, 127] -> 
             RGBColor[
              0.5406898673295565, 0.6351674535778149, 0.9581241175556126], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.765323300432157, 0.8168654273719698, 0.9774223412834145], 
             UndirectedEdge[155, 191] -> 
             RGBColor[
              0.7393598241301587, 0.7963127810440482, 0.9746561356250546], 
             UndirectedEdge[46, 105] -> 
             RGBColor[
              0.658072439199517, 0.7320980245082068, 0.9670412635266155], 
             UndirectedEdge[30, 168] -> 
             RGBColor[
              0.4937457677972824, 0.5979361063448351, 0.9538268537675151], 
             UndirectedEdge[161, 180] -> 
             RGBColor[
              0.7757790026741023, 0.825353837475999, 0.9782454524643998], 
             UndirectedEdge[125, 192] -> 
             RGBColor[
              0.6596896593845236, 0.7307151883461933, 0.9689809424484723], 
             UndirectedEdge[33, 140] -> 
             RGBColor[
              0.6704363310977377, 0.740469635630151, 0.9692184821877226], 
             UndirectedEdge[12, 58] -> 
             RGBColor[
              0.9616218638008132, 0.9680207881503848, 0.7926963954570221], 
             UndirectedEdge[127, 155] -> 
             RGBColor[
              0.6821812523006239, 0.7516444461575744, 0.9689571099492202], 
             UndirectedEdge[78, 120] -> 
             RGBColor[
              0.7147616861665382, 0.7770965287140954, 0.9722044231155096], 
             UndirectedEdge[45, 183] -> 
             RGBColor[
              0.7620859397742689, 0.3320078741466034, 0.4314490106409401], 
             UndirectedEdge[98, 136] -> 
             RGBColor[
              0.6119492762880043, 0.6910164036117736, 0.9651786748984681], 
             UndirectedEdge[59, 92] -> 
             RGBColor[
              0.7068959339316377, 0.7694314591239828, 0.9728227249659981], 
             UndirectedEdge[81, 89] -> 
             RGBColor[
              0.6963474231230293, 0.7611165620599483, 0.9717058751620449], 
             UndirectedEdge[161, 200] -> 
             RGBColor[
              0.7548017622060434, 0.8086271553387925, 0.9762446245419527], 
             UndirectedEdge[125, 198] -> 
             RGBColor[
              0.8031850729046902, 0.8467422840534962, 0.9808667155376775], 
             UndirectedEdge[159, 173] -> 
             RGBColor[
              0.8921916663349507, 0.9168525791403799, 0.9888562114368259], 
             UndirectedEdge[54, 151] -> 
             RGBColor[
              0.8492765973240972, 0.8563743872310332, 0.6662913096040287], 
             UndirectedEdge[61, 192] -> 
             RGBColor[
              0.44023282565200395`, 0.5557292796597515, 0.9492722242613111], 
             UndirectedEdge[59, 194] -> 
             RGBColor[
              0.88758738905843, 0.9132021073900811, 0.9891400715986509], 
             UndirectedEdge[80, 82] -> 
             RGBColor[
              0.520772975411561, 0.6196082262374918, 0.956138987903164], 
             UndirectedEdge[157, 168] -> 
             RGBColor[
              0.41315974244564957`, 0.5322799357191343, 0.9475471513391897], 
             UndirectedEdge[122, 170] -> 
             RGBColor[
              0.8818164563929697, 0.7454397767103624, 0.6084139580514363], 
             UndirectedEdge[26, 67] -> 
             RGBColor[
              0.5695647524985608, 0.6612149878206524, 0.9594094007847047], 
             UndirectedEdge[160, 181] -> 
             RGBColor[
              0.7939713569803492, 0.8387413942147655, 0.9443156393121679], 
             UndirectedEdge[42, 168] -> 
             RGBColor[
              0.607573610662417, 0.6875273666162096, 0.9647613200048968], 
             UndirectedEdge[61, 67] -> 
             RGBColor[
              0.5541550068975896, 0.6486535415492618, 0.9582104139349543], 
             UndirectedEdge[9, 39] -> 
             RGBColor[
              0.403714981381488, 0.5073400223818099, 0.9486991009961823], 
             UndirectedEdge[118, 171] -> 
             RGBColor[
              0.5137314501678616, 0.6161093604411849, 0.9548619680989738], 
             UndirectedEdge[97, 134] -> 
             RGBColor[
              0.8378711054931068, 0.8734377799175987, 0.9453483576275779], 
             UndirectedEdge[79, 190] -> 
             RGBColor[
              0.647774269192785, 0.7223159168286919, 0.9672025022565465], 
             UndirectedEdge[47, 50] -> 
             RGBColor[
              0.5894280631649884, 0.6774262631027552, 0.9609147626212291], 
             UndirectedEdge[36, 145] -> 
             RGBColor[
              0.7811870324152301, 0.8253649045272078, 0.8017770929478256], 
             UndirectedEdge[170, 179] -> 
             RGBColor[
              0.7673012293028089, 0.6555360693743628, 0.5971178527197892], 
             UndirectedEdge[26, 198] -> 
             RGBColor[
              0.5991379847731417, 0.684317821638445, 0.9623569842002666], 
             UndirectedEdge[5, 141] -> 
             RGBColor[
              0.9946382356334502, 0.9913563763607338, 0.6880455266229267], 
             UndirectedEdge[18, 39] -> 
             RGBColor[
              0.28025125504508885`, 0.40515863056125023`, 0.9395178159911695],
              UndirectedEdge[19, 180] -> 
             RGBColor[
              0.9458637011912666, 0.9589292082089942, 0.9690128319823601], 
             UndirectedEdge[170, 198] -> 
             RGBColor[
              0.8023971045361893, 0.6829532338452105, 0.6006158815734515], 
             UndirectedEdge[12, 172] -> 
             RGBColor[
              0.6878059819211987, 0.7472880818212706, 0.7689088047659296], 
             UndirectedEdge[47, 101] -> 
             RGBColor[
              0.4545640835232324, 0.5661266499363998, 0.9507423280542232], 
             UndirectedEdge[53, 54] -> 
             RGBColor[
              0.7678943423007685, 0.818604163509299, 0.9775001897260679], 
             UndirectedEdge[57, 121] -> 
             RGBColor[
              0.8729749909802009, 0.8985327764288934, 0.8358693340712924], 
             UndirectedEdge[19, 121] -> 
             RGBColor[
              0.8576947861837099, 0.8891835933822465, 0.9604551567086238], 
             UndirectedEdge[170, 192] -> 
             RGBColor[
              0.6589016910160227, 0.5669261381379076, 0.5887301084842465], 
             UndirectedEdge[7, 137] -> 
             RGBColor[
              0.4922255892348546, 0.5986499337077756, 0.9531689479477632], 
             UndirectedEdge[111, 115] -> 
             RGBColor[
              0.7610147273667328, 0.8077961671166342, 0.7024969209275451], 
             UndirectedEdge[140, 162] -> 
             RGBColor[
              0.6103718161439212, 0.6897585797118968, 0.9650282153417102], 
             UndirectedEdge[8, 79] -> 
             RGBColor[
              0.9015866729714571, 0.9220400267849691, 0.8980399708914186], 
             UndirectedEdge[2, 52] -> 
             RGBColor[
              0.8808698127154012, 0.9076106692975157, 0.9790934193800902], 
             UndirectedEdge[18, 152] -> 
             RGBColor[
              0.6270918837641704, 0.7030907077781384, 0.9666229903175101], 
             UndirectedEdge[4, 195] -> 
             RGBColor[
              0.653916607850905, 0.7274350752499661, 0.9675954373578233], 
             UndirectedEdge[81, 107] -> 
             RGBColor[
              0.637241644179842, 0.7111838512256878, 0.9675910835267549], 
             UndirectedEdge[108, 175] -> 
             RGBColor[
              0.6941908957354075, 0.7600522203835485, 0.9708202193593531], 
             UndirectedEdge[49, 191] -> 
             RGBColor[
              0.7087544152362378, 0.7718059960031951, 0.9720142616622341], 
             UndirectedEdge[77, 192] -> 
             RGBColor[
              0.7111717367979418, 0.767065994103777, 0.7310538647861746], 
             UndirectedEdge[21, 166] -> 
             RGBColor[
              0.9271311323280862, 0.9447332148869882, 0.9929117891328271], 
             UndirectedEdge[8, 192] -> 
             RGBColor[
              0.7095548577649907, 0.7680959251900135, 0.881316542880585], 
             UndirectedEdge[108, 165] -> 
             RGBColor[
              0.7844489767253606, 0.8295462014648116, 0.8865449610052658], 
             UndirectedEdge[29, 194] -> 
             RGBColor[
              0.7318262522579203, 0.7902457307736415, 0.9741238432175494], 
             UndirectedEdge[106, 131] -> 
             RGBColor[
              0.8795851714803544, 0.9066939640972453, 0.9833625360409417], 
             UndirectedEdge[12, 68] -> 
             RGBColor[
              0.9575445655479171, 0.8571800531814372, 0.4238091562448002], 
             UndirectedEdge[71, 168] -> 
             RGBColor[
              0.6068344529226715, 0.6869379822984389, 0.964690818479826], 
             UndirectedEdge[49, 146] -> 
             RGBColor[
              0.7948878914211529, 0.838759726119168, 0.9182491245628004], 
             UndirectedEdge[112, 134] -> 
             RGBColor[
              0.7281803148270941, 0.7875792634090766, 0.9735418666161795], 
             UndirectedEdge[84, 126] -> 
             RGBColor[
              0.5613423409326458, 0.6513013229211613, 0.9601825631160298], 
             UndirectedEdge[10, 62] -> 
             RGBColor[
              0.7894562979393764, 0.8356752462003303, 0.960036400337279], 
             UndirectedEdge[34, 182] -> 
             RGBColor[
              0.5189654336845193, 0.618196160902501, 0.9559588290362503], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.661438933992118, 0.7303336181326163, 0.9648893043287474], 
             UndirectedEdge[67, 79] -> 
             RGBColor[
              0.7349843798842209, 0.7928946507445138, 0.9742200322334708], 
             UndirectedEdge[33, 96] -> 
             RGBColor[
              0.7306818819795522, 0.787889934379038, 0.9535428781675721], 
             UndirectedEdge[12, 140] -> 
             RGBColor[
              0.9166022879749423, 0.9321234004106669, 0.7884023881253008], 
             UndirectedEdge[26, 124] -> 
             RGBColor[
              0.5577562800706539, 0.6518507006522574, 0.9583277639771872], 
             UndirectedEdge[13, 70] -> 
             RGBColor[
              0.8423744165413366, 0.877708395097232, 0.9846795724668775], 
             UndirectedEdge[53, 146] -> 
             RGBColor[
              0.8996121842398482, 0.9211687466064367, 0.9282784761948917], 
             UndirectedEdge[87, 147] -> 
             RGBColor[
              0.4790885575355828, 0.587283219981957, 0.9523285735867215], 
             UndirectedEdge[93, 200] -> 
             RGBColor[
              0.8504377526008073, 0.8836159888524879, 0.9855871546278404], 
             UndirectedEdge[9, 117] -> 
             RGBColor[
              0.8100769740949558, 0.8500507634624197, 0.8759627551162676], 
             UndirectedEdge[99, 116] -> 
             RGBColor[
              0.6335659449395517, 0.7082529484256783, 0.9672404920518807], 
             UndirectedEdge[71, 155] -> 
             RGBColor[
              0.7483258378937389, 0.8034149748781986, 0.9755238108734335], 
             UndirectedEdge[54, 140] -> 
             RGBColor[
              0.78108037945867, 0.8290602540725202, 0.9787733030225607], 
             UndirectedEdge[76, 154] -> 
             RGBColor[
              0.5866703736225471, 0.6750628195156574, 0.960782875348341], 
             UndirectedEdge[33, 128] -> 
             RGBColor[
              0.5476852998397232, 0.6436746252082988, 0.9575349395221924], 
             UndirectedEdge[109, 148] -> 
             RGBColor[
              0.7531426333713235, 0.6993504677572724, 0.6078942482643539], 
             UndirectedEdge[27, 142] -> 
             RGBColor[
              0.47307203698650246`, 0.5811522403316843, 0.9521993419477193], 
             UndirectedEdge[49, 69] -> 
             RGBColor[
              0.7980333192499783, 0.8378495276760126, 0.7054111600841644], 
             UndirectedEdge[60, 90] -> 
             RGBColor[
              0.6874477410145787, 0.7465218407457221, 0.7299164928869462], 
             UndirectedEdge[40, 191] -> 
             RGBColor[
              0.7538190327598242, 0.8076084247195987, 0.9760972944122726], 
             UndirectedEdge[58, 166] -> 
             RGBColor[
              0.9308861756119231, 0.9477273844735853, 0.9932699485134062], 
             UndirectedEdge[38, 60] -> 
             RGBColor[
              0.6590416016315311, 0.7285456915833621, 0.9689473626908024], 
             UndirectedEdge[54, 119] -> 
             RGBColor[
              0.8578767818646118, 0.8852256448183751, 0.7132372852961916], 
             UndirectedEdge[3, 146] -> 
             RGBColor[
              0.9902190586007902, 0.9891258308064641, 0.7319814458643192], 
             UndirectedEdge[115, 163] -> 
             RGBColor[
              0.7610147273667328, 0.8077961671166342, 0.7024969209275451], 
             UndirectedEdge[137, 170] -> 
             RGBColor[
              0.6933657239130766, 0.5955650583634895, 0.5912610310529725], 
             UndirectedEdge[58, 99] -> 
             RGBColor[
              0.6553913919697921, 0.7256559674516148, 0.9693222226734315], 
             UndirectedEdge[40, 64] -> 
             RGBColor[
              0.5767659390217537, 0.6665005402370089, 0.9603596549459416], 
             UndirectedEdge[77, 96] -> 
             RGBColor[
              0.9764861570625043, 0.9787700983732865, 0.7333599528420678], 
             UndirectedEdge[141, 195] -> 
             RGBColor[
              0.7490950969084216, 0.7999158889881576, 0.844949332553915], 
             UndirectedEdge[138, 182] -> 
             RGBColor[
              0.43469295750795256`, 0.5499943746531701, 0.9491780002239674], 
             UndirectedEdge[33, 102] -> 
             RGBColor[
              0.5201241094253011, 0.6212992092123921, 0.9553652216528019], 
             UndirectedEdge[137, 198] -> 
             RGBColor[
              0.6069898298493894, 0.6906923031929326, 0.9629751102069251], 
             UndirectedEdge[69, 171] -> 
             RGBColor[
              0.7529423142403405, 0.8012426184825618, 0.7018614309960118], 
             UndirectedEdge[20, 46] -> 
             RGBColor[
              0.7622584102557204, 0.7188332547483928, 0.611393656260877], 
             UndirectedEdge[76, 157] -> 
             RGBColor[
              0.5520915210484576, 0.6467573443502808, 0.9581250260908907], 
             UndirectedEdge[10, 168] -> 
             RGBColor[
              0.5014681378836364, 0.6042054742697451, 0.9544347870286866], 
             UndirectedEdge[82, 100] -> 
             RGBColor[
              0.6211005908414715, 0.6983134134308924, 0.9660515354500527], 
             UndirectedEdge[9, 57] -> 
             RGBColor[
              0.8117458180593242, 0.850487824365638, 0.8299117034797531], 
             UndirectedEdge[27, 71] -> 
             RGBColor[
              0.6068344529226715, 0.6869379822984389, 0.964690818479826], 
             UndirectedEdge[122, 125] -> 
             RGBColor[
              0.8826044247614706, 0.9092288269186481, 0.9886647920156622], 
             UndirectedEdge[5, 147] -> 
             RGBColor[
              0.7109800531677268, 0.7676406884922164, 0.7943500603038449], 
             UndirectedEdge[5, 71] -> 
             RGBColor[
              0.9132852281188786, 0.9297740096192553, 0.8120436530091527], 
             UndirectedEdge[61, 84] -> 
             RGBColor[
              0.4165053889810083, 0.5351777665909778, 0.9477603329779836], 
             UndirectedEdge[62, 149] -> 
             RGBColor[
              0.9269194295628075, 0.79490412537736, 0.5959547760535866], 
             UndirectedEdge[36, 138] -> 
             RGBColor[
              0.7411629843102407, 0.7928715792127579, 0.7986262532680819], 
             UndirectedEdge[33, 162] -> 
             RGBColor[
              0.44164002504399413`, 0.5556343170407547, 0.9497248988283514], 
             UndirectedEdge[63, 145] -> 
             RGBColor[
              0.7525942963924677, 0.8064168021470337, 0.9750455175598862], 
             UndirectedEdge[93, 173] -> 
             RGBColor[
              0.8317032435074532, 0.8686775998361493, 0.9838002404260227], 
             UndirectedEdge[23, 55] -> 
             RGBColor[
              0.9455192104348078, 0.9588888968631608, 0.9771059452549515], 
             UndirectedEdge[23, 165] -> 
             RGBColor[
              0.9657199903828857, 0.972966821497862, 0.8986763094560551], 
             UndirectedEdge[54, 64] -> 
             RGBColor[
              0.5915239087357695, 0.6780295783423222, 0.9618305914459666], 
             UndirectedEdge[72, 158] -> 
             RGBColor[
              0.6693175293804854, 0.7396677213969864, 0.9690079652772228], 
             UndirectedEdge[73, 149] -> 
             RGBColor[
              0.6725120549010696, 0.5925203419357099, 0.5924929006959774], 
             UndirectedEdge[10, 197] -> 
             RGBColor[
              0.7927669379359923, 0.8381443160891309, 0.9544323503762082], 
             UndirectedEdge[37, 135] -> 
             RGBColor[
              0.7067742341822802, 0.723700225313572, 0.6272092060472197], 
             UndirectedEdge[58, 96] -> 
             RGBColor[
              0.9444332489053502, 0.957911584789898, 0.9731402020126523], 
             UndirectedEdge[112, 156] -> 
             RGBColor[
              0.7892705976539368, 0.835303456656752, 0.9796307750872079], 
             UndirectedEdge[2, 187] -> 
             RGBColor[
              0.5985531788040335, 0.6803707122791316, 0.9638913916799992], 
             UndirectedEdge[43, 169] -> 
             RGBColor[
              0.6146140513116153, 0.6973245723665122, 0.9632727206238014], 
             UndirectedEdge[44, 96] -> 
             RGBColor[
              0.9329173606473343, 0.9487291280834156, 0.9720418063102478], 
             UndirectedEdge[88, 161] -> 
             RGBColor[
              0.6138031644864161, 0.6973520863043428, 0.9627399800248985], 
             UndirectedEdge[129, 146] -> 
             RGBColor[
              0.986761433822898, 0.9783923971328264, 0.6394732809318282], 
             UndirectedEdge[23, 111] -> 
             RGBColor[
              0.967010767074772, 0.9712896771472219, 0.7165747139997857], 
             UndirectedEdge[174, 196] -> 
             RGBColor[
              0.8329331442816597, 0.8672133889452038, 0.8288032921818791], 
             UndirectedEdge[66, 100] -> 
             RGBColor[
              0.7246957233849252, 0.7843645857403887, 0.9736686919706277], 
             UndirectedEdge[10, 73] -> 
             RGBColor[
              0.5350489232776385, 0.6332914627586803, 0.9565745249796698], 
             UndirectedEdge[147, 188] -> 
             RGBColor[
              0.5365223794044607, 0.6338615224615468, 0.9568835180315516], 
             UndirectedEdge[62, 189] -> 
             RGBColor[
              0.9503040752147838, 0.9624574411815701, 0.9690064172750552], 
             UndirectedEdge[42, 89] -> 
             RGBColor[
              0.6666793896056045, 0.73746007745047, 0.9688761116401867], 
             UndirectedEdge[119, 140] -> 
             RGBColor[
              0.9159645246036066, 0.9307592890471481, 0.7189857809747122], 
             UndirectedEdge[140, 151] -> 
             RGBColor[
              0.9073643400630919, 0.9019080314598061, 0.6720398052825493], 
             UndirectedEdge[1, 86] -> 
             RGBColor[
              0.6817958062789709, 0.7455157401528321, 0.9304304294697244], 
             UndirectedEdge[76, 181] -> 
             RGBColor[
              0.8175705491788742, 0.8576386367259237, 0.9463523421796592], 
             UndirectedEdge[122, 166] -> 
             RGBColor[
              0.9037124957802513, 0.9260598297856995, 0.990678098672831], 
             UndirectedEdge[10, 189] -> 
             RGBColor[
              0.7822085429525024, 0.8302698823982293, 0.9723049590128103], 
             UndirectedEdge[102, 162] -> 
             RGBColor[
              0.4600595944714846, 0.5705881532941379, 0.9511749548067895], 
             UndirectedEdge[156, 183] -> 
             RGBColor[
              0.8178269248212674, 0.3755531553124956, 0.43700475110130366`], 
             UndirectedEdge[31, 199] -> 
             RGBColor[
              0.6165566996910059, 0.6946902379681505, 0.9656181350557418], 
             UndirectedEdge[73, 130] -> 
             RGBColor[
              0.527608211873796, 0.6272507580408121, 0.9559887649217353], 
             UndirectedEdge[4, 199] -> 
             RGBColor[
              0.5930089713797266, 0.676039535301726, 0.9633387968975082], 
             UndirectedEdge[6, 83] -> 
             RGBColor[
              0.6246682182876903, 0.7027346213887273, 0.9656660792138818], 
             UndirectedEdge[73, 89] -> 
             RGBColor[
              0.47426207442736734`, 0.5839419604456961, 0.9517891615686123], 
             UndirectedEdge[60, 111] -> 
             RGBColor[
              0.6871473431728317, 0.7458793201371061, 0.6972200416533771], 
             UndirectedEdge[166, 179] -> 
             RGBColor[
              0.7891972686900904, 0.8361561224496998, 0.9793819933411839], 
             UndirectedEdge[30, 197] -> 
             RGBColor[
              0.7850445678496383, 0.8318749481642209, 0.9538244171150367], 
             UndirectedEdge[26, 58] -> 
             RGBColor[
              0.705731016461594, 0.7684719191914827, 0.9727469105188267], 
             UndirectedEdge[11, 35] -> 
             RGBColor[
              0.8626567615706486, 0.8925246671491187, 0.9348328202136726], 
             UndirectedEdge[137, 187] -> 
             RGBColor[
              0.4397669796582273, 0.5541136944168561, 0.9495774458343925], 
             UndirectedEdge[13, 153] -> 
             RGBColor[
              0.8719887539455204, 0.8964233151355719, 0.728523519195788], 
             UndirectedEdge[71, 75] -> 
             RGBColor[
              0.7144446118977359, 0.7762487339399964, 0.9726240525886238], 
             UndirectedEdge[16, 67] -> 
             RGBColor[
              0.6803447594698162, 0.7502097640002852, 0.9687740655068466], 
             UndirectedEdge[156, 170] -> 
             RGBColor[
              0.8538078865318393, 0.7231157274766271, 0.6057400278617049], 
             UndirectedEdge[96, 128] -> 
             RGBColor[
              0.7766626418214649, 0.8252191866283279, 0.9571626520154006], 
             UndirectedEdge[62, 114] -> 
             RGBColor[
              0.8212738989239806, 0.8608530640809597, 0.9629877565346955], 
             UndirectedEdge[101, 105] -> 
             RGBColor[
              0.5509343801584378, 0.6431705448609182, 0.9591451948539801], 
             UndirectedEdge[30, 89] -> 
             RGBColor[
              0.5528515467404699, 0.6478688171790955, 0.9579416454028051], 
             UndirectedEdge[53, 191] -> 
             RGBColor[
              0.8134787080549332, 0.8542150164904638, 0.9820436132943253], 
             UndirectedEdge[72, 81] -> 
             RGBColor[
              0.7035379639714516, 0.7669541670508713, 0.9722719408774517], 
             UndirectedEdge[163, 175] -> 
             RGBColor[
              0.9011703185736463, 0.9190185424210885, 0.7152823051347722], 
             UndirectedEdge[82, 125] -> 
             RGBColor[
              0.635962222713528, 0.7101636752774196, 0.9674690511651449], 
             UndirectedEdge[113, 148] -> 
             RGBColor[
              0.6764267883938622, 0.7462747057466876, 0.9689813289261403], 
             UndirectedEdge[33, 44] -> 
             RGBColor[
              0.7039400186655926, 0.7671845666633865, 0.9724140938170396], 
             UndirectedEdge[21, 179] -> 
             RGBColor[
              0.7837633236437369, 0.8318232421702465, 0.9788636988117227], 
             UndirectedEdge[75, 188] -> 
             RGBColor[
              0.621178770498183, 0.7032908740542045, 0.9633541583481702], 
             UndirectedEdge[85, 88] -> 
             RGBColor[
              0.581455159720907, 0.6710905187746946, 0.9601934265951118], 
             UndirectedEdge[13, 185] -> 
             RGBColor[
              0.8632609332666242, 0.8672990567542249, 0.6676851375197302], 
             UndirectedEdge[93, 161] -> 
             RGBColor[
              0.7198948571231252, 0.7808293299220673, 0.9729056212917715], 
             UndirectedEdge[146, 196] -> 
             RGBColor[
              0.8286812456960281, 0.865756958320905, 0.921208743128151], 
             UndirectedEdge[19, 162] -> 
             RGBColor[
              0.6730018869264339, 0.7389572494984314, 0.9453162411120717], 
             UndirectedEdge[140, 172] -> 
             RGBColor[
              0.6103718161439212, 0.6897585797118968, 0.9650282153417102], 
             UndirectedEdge[71, 142] -> 
             RGBColor[
              0.6983309798189963, 0.7631669615076229, 0.9713555284452062], 
             UndirectedEdge[87, 142] -> 
             RGBColor[
              0.5476313165505655, 0.6436307991422411, 0.9575306897599225], 
             UndirectedEdge[89, 147] -> 
             RGBColor[
              0.4636350569147072, 0.5747373720056607, 0.9511120174098082], 
             UndirectedEdge[30, 42] -> 
             RGBColor[
              0.7197438683695216, 0.7805402118385443, 0.9730535417900729], 
             UndirectedEdge[8, 125] -> 
             RGBColor[
              0.9402141337173454, 0.952784826276159, 0.9017390707800634], 
             UndirectedEdge[29, 168] -> 
             RGBColor[
              0.4986761875545006, 0.6019388432166237, 0.9542149944715259], 
             UndirectedEdge[158, 160] -> 
             RGBColor[
              0.7183537959931587, 0.7794775716917913, 0.9728682798107356], 
             UndirectedEdge[138, 153] -> 
             RGBColor[
              0.7404133021060195, 0.7912680847824265, 0.7170279718408641], 
             UndirectedEdge[26, 122] -> 
             RGBColor[
              0.6785573366299222, 0.7468043645035969, 0.9701550606782514], 
             UndirectedEdge[53, 195] -> 
             RGBColor[
              0.658093415457198, 0.7306980290969157, 0.9680117425055323], 
             UndirectedEdge[19, 93] -> 
             RGBColor[
              0.8899795556402896, 0.9144047006550625, 0.9636730008097317], 
             UndirectedEdge[11, 196] -> 
             RGBColor[
              0.8280671888099453, 0.8655030300179677, 0.9313852548588211], 
             UndirectedEdge[87, 168] -> 
             RGBColor[
              0.4561347896542408, 0.5674018199330573, 0.9508659797945422], 
             UndirectedEdge[78, 124] -> 
             RGBColor[
              0.6467111561954415, 0.7237955187374914, 0.9655171036239969], 
             UndirectedEdge[39, 117] -> 
             RGBColor[
              0.5852889927134679, 0.6481047410806098, 0.8607646541200854], 
             UndirectedEdge[42, 130] -> 
             RGBColor[
              0.720025527052033, 0.780768875045586, 0.9730757149933099], 
             UndirectedEdge[11, 94] -> 
             RGBColor[
              0.7226276937887667, 0.7803402331365226, 0.9227853896454603], 
             UndirectedEdge[27, 168] -> 
             RGBColor[
              0.3815755100901777, 0.5049232611225005, 0.945534631982339], 
             UndirectedEdge[30, 51] -> 
             RGBColor[
              0.5778586078586772, 0.6681706759501214, 0.9599102928579135], 
             UndirectedEdge[6, 58] -> 
             RGBColor[
              0.6783130279665424, 0.7455095364770765, 0.9707827690503377], 
             UndirectedEdge[6, 156] -> 
             RGBColor[
              0.6231307782737401, 0.7015179325554555, 0.965516989020031], 
             UndirectedEdge[19, 173] -> 
             RGBColor[
              0.9061519516298535, 0.9272641370554492, 0.9652250898580952], 
             UndirectedEdge[57, 200] -> 
             RGBColor[
              0.940166665519699, 0.9515517091184346, 0.8424261814225815], 
             UndirectedEdge[37, 50] -> 
             RGBColor[
              0.5517468771187214, 0.6468043586424026, 0.9579568220525342], 
             UndirectedEdge[49, 171] -> 
             RGBColor[
              0.5582564572348331, 0.6522567670068626, 0.9583671397557608], 
             UndirectedEdge[5, 127] -> 
             RGBColor[
              0.8471406425257635, 0.8780034808986312, 0.8054769520849394], 
             UndirectedEdge[85, 152] -> 
             RGBColor[
              0.7160855573177531, 0.7772877578914261, 0.9730906664994958], 
             UndirectedEdge[130, 131] -> 
             RGBColor[
              0.7121736639680304, 0.7745251155165058, 0.9723222586829464], 
             UndirectedEdge[33, 58] -> 
             RGBColor[
              0.7154559069236086, 0.776367023369869, 0.973512489519444], 
             UndirectedEdge[82, 98] -> 
             RGBColor[
              0.3815755100901777, 0.5049232611225005, 0.945534631982339], 
             UndirectedEdge[74, 173] -> 
             RGBColor[
              0.6522974870532872, 0.7256806964504763, 0.9678630474971748], 
             UndirectedEdge[118, 146] -> 
             RGBColor[
              0.7503628843541814, 0.8026123195534904, 0.9147439529060135], 
             UndirectedEdge[23, 115] -> 
             RGBColor[
              0.735306318186019, 0.7922504651121443, 0.9701661836029154], 
             UndirectedEdge[49, 65] -> 
             RGBColor[
              0.7769570344081052, 0.8257584564190226, 0.9652394445053933], 
             UndirectedEdge[21, 23] -> 
             RGBColor[
              0.9314997725878954, 0.9480721548751336, 0.9883187356392609], 
             UndirectedEdge[40, 171] -> 
             RGBColor[
              0.6033210747584195, 0.6880591957232662, 0.9624501725057992], 
             UndirectedEdge[104, 158] -> 
             RGBColor[
              0.8361712742922953, 0.8722042931288209, 0.9842359566725495], 
             UndirectedEdge[53, 155] -> 
             RGBColor[
              0.738677163957087, 0.7957794817284352, 0.9745880944388249], 
             UndirectedEdge[164, 200] -> 
             RGBColor[
              0.7061698324317758, 0.7691455639045726, 0.9724161408854938], 
             UndirectedEdge[81, 142] -> 
             RGBColor[
              0.7287381710761667, 0.7874128304348716, 0.9742557934921352], 
             UndirectedEdge[39, 85] -> 
             RGBColor[
              0.36924492859867153`, 0.47935568067453793`, 0.9459854921731552],
              UndirectedEdge[107, 142] -> 
             RGBColor[
              0.47307203698650246`, 0.5811522403316843, 0.9521993419477193], 
             UndirectedEdge[121, 161] -> 
             RGBColor[
              0.6876100876665454, 0.7556082226492513, 0.9696877771906636], 
             UndirectedEdge[1, 196] -> 
             RGBColor[
              0.5262548404421995, 0.623890700863144, 0.9566853689784767], 
             UndirectedEdge[88, 121] -> 
             RGBColor[
              0.6771543854246003, 0.7471198125452221, 0.9688646660096782], 
             UndirectedEdge[85, 133] -> 
             RGBColor[
              0.5260933239652283, 0.6261452864859556, 0.9558351400873384], 
             UndirectedEdge[118, 127] -> 
             RGBColor[
              0.6070508363397316, 0.6909902545510438, 0.9628100643296127], 
             UndirectedEdge[100, 187] -> 
             RGBColor[
              0.6211005908414715, 0.6983134134308924, 0.9660515354500527], 
             UndirectedEdge[26, 116] -> 
             RGBColor[
              0.6839055694313536, 0.7510689001655464, 0.9706651798972756], 
             UndirectedEdge[131, 147] -> 
             RGBColor[
              0.6226755154597563, 0.7011650071360291, 0.9654704574867125], 
             UndirectedEdge[134, 160] -> 
             RGBColor[
              0.6544514458544302, 0.7295203364023064, 0.9665087060563061], 
             UndirectedEdge[3, 5] -> 
             RGBColor[
              0.9942434285431685, 0.9900956006695193, 0.6148109062439716], 
             UndirectedEdge[16, 100] -> 
             RGBColor[
              0.7822202223045289, 0.830124141350393, 0.9788408880175896], 
             UndirectedEdge[75, 147] -> 
             RGBColor[
              0.5121394369465841, 0.6141154128129577, 0.9549304598833159], 
             UndirectedEdge[72, 76] -> 
             RGBColor[
              0.5868036084845955, 0.6751709855788304, 0.9607933640847368], 
             UndirectedEdge[40, 69] -> 
             RGBColor[
              0.8430979367735647, 0.8736519563924162, 0.7094941928342028], 
             UndirectedEdge[177, 179] -> 
             RGBColor[
              0.8193441206147651, 0.8551900648978216, 0.714717246801154], 
             UndirectedEdge[98, 100] -> 
             RGBColor[
              0.6211005908414715, 0.6983134134308924, 0.9660515354500527], 
             UndirectedEdge[136, 187] -> 
             RGBColor[
              0.6119492762880043, 0.6910164036117736, 0.9651786748984681], 
             UndirectedEdge[54, 199] -> 
             RGBColor[
              0.5522840734049266, 0.6442249354831239, 0.9592797196631896], 
             UndirectedEdge[166, 198] -> 
             RGBColor[
              0.8242931439234709, 0.8635732869205476, 0.9828800221948462], 
             UndirectedEdge[48, 104] -> 
             RGBColor[
              0.6701757002309612, 0.7401950353124374, 0.969270485928574], 
             UndirectedEdge[187, 198] -> 
             RGBColor[
              0.5487983602813399, 0.641501869898577, 0.9589322963548716], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.7866643476102406, 0.8334086151472089, 0.9598166077801185], 
             UndirectedEdge[103, 117] -> 
             RGBColor[
              0.6866132477585567, 0.7478693716418601, 0.8667814701112548], 
             UndirectedEdge[85, 140] -> 
             RGBColor[
              0.6993654896975039, 0.7639556298251844, 0.9714958915236959], 
             UndirectedEdge[36, 70] -> 
             RGBColor[
              0.9641515440863488, 0.9703592557730045, 0.81898890991444], 
             UndirectedEdge[54, 171] -> 
             RGBColor[
              0.6180790444724353, 0.6995882338285795, 0.9639211090058243], 
             UndirectedEdge[120, 125] -> 
             RGBColor[
              0.829853898173299, 0.8675761730439124, 0.9835248148061106], 
             UndirectedEdge[81, 104] -> 
             RGBColor[
              0.8703917088832616, 0.8994907387827056, 0.9874999322727784], 
             UndirectedEdge[93, 162] -> 
             RGBColor[
              0.5985531788040335, 0.6803707122791316, 0.9638913916799992], 
             UndirectedEdge[73, 168] -> 
             RGBColor[
              0.41515629548417987`, 0.5340092496114357, 0.9476743699333223], 
             UndirectedEdge[119, 199] -> 
             RGBColor[
              0.687168218549863, 0.7459239704577518, 0.699492197615341], 
             UndirectedEdge[17, 107] -> 
             RGBColor[
              0.6349264905251588, 0.7093378105446153, 0.9673702621044091], 
             UndirectedEdge[14, 48] -> 
             RGBColor[
              0.7432317681509477, 0.7942009093501734, 0.7700866374214629], 
             UndirectedEdge[64, 182] -> 
             RGBColor[
              0.4208153454210207, 0.5387279039816988, 0.9480855037651159], 
             UndirectedEdge[71, 129] -> 
             RGBColor[
              0.9095939714015633, 0.9185408608510038, 0.6941060932796409], 
             UndirectedEdge[80, 100] -> 
             RGBColor[
              0.7602980561628548, 0.8129983785458836, 0.9766558913708777], 
             UndirectedEdge[18, 178] -> 
             RGBColor[
              0.5590671828432741, 0.6495239521299021, 0.9599557966202423], 
             UndirectedEdge[174, 186] -> 
             RGBColor[
              0.9601580557020191, 0.9674543656022553, 0.8412578119368648], 
             UndirectedEdge[115, 165] -> 
             RGBColor[
              0.7597239506748465, 0.8094733114672741, 0.8845985163838146], 
             UndirectedEdge[113, 198] -> 
             RGBColor[
              0.7417951737909194, 0.7982152947083776, 0.9748988685196027], 
             UndirectedEdge[67, 100] -> 
             RGBColor[
              0.7587502087580528, 0.8117891883891764, 0.9765016164070235], 
             UndirectedEdge[106, 147] -> 
             RGBColor[
              0.6843927018734599, 0.750215018181516, 0.9663518981209267], 
             UndirectedEdge[75, 129] -> 
             RGBColor[
              0.7919451875441339, 0.8258368913166227, 0.6828831408909517], 
             UndirectedEdge[175, 183] -> 
             RGBColor[
              0.8147531536306023, 0.37315190189682174`, 0.436698386315043], 
             UndirectedEdge[105, 144] -> 
             RGBColor[0.856631232165372, 0.884394006713207, 0.72443814290555],
              UndirectedEdge[44, 128] -> 
             RGBColor[
              0.7499207785075054, 0.8045138189126765, 0.9760338676648681], 
             UndirectedEdge[70, 138] -> 
             RGBColor[
              0.7107989647018356, 0.7725531647440864, 0.9731840251119538], 
             UndirectedEdge[110, 145] -> 
             RGBColor[
              0.5678521463590245, 0.6600469797187499, 0.9591225475537846], 
             UndirectedEdge[49, 118] -> 
             RGBColor[
              0.5588224551774994, 0.6527162696346358, 0.9584116971871263], 
             UndirectedEdge[70, 185] -> 
             RGBColor[
              0.9546740412032313, 0.9396315029613261, 0.6765522468111645], 
             UndirectedEdge[11, 138] -> 
             RGBColor[
              0.7365053058756985, 0.7916067038079939, 0.9238778861043118], 
             UndirectedEdge[120, 187] -> 
             RGBColor[
              0.5754671855499487, 0.6623357588889933, 0.9615903956233048], 
             UndirectedEdge[71, 127] -> 
             RGBColor[
              0.7659488101620502, 0.8171821747537533, 0.9772803040530995], 
             UndirectedEdge[4, 182] -> 
             RGBColor[
              0.5930089713797266, 0.676039535301726, 0.9633387968975082], 
             UndirectedEdge[29, 71] -> 
             RGBColor[
              0.7239351303869944, 0.7839535643925621, 0.9733711809690129], 
             UndirectedEdge[63, 185] -> 
             RGBColor[
              0.956445324788874, 0.9410018150498235, 0.6752628995793531], 
             UndirectedEdge[83, 175] -> 
             RGBColor[
              0.8157695576917545, 0.8560202746472478, 0.9822677963183707], 
             UndirectedEdge[79, 126] -> 
             RGBColor[
              0.7771015928101078, 0.8257969375848906, 0.9784178824101908], 
             UndirectedEdge[107, 154] -> 
             RGBColor[
              0.4477385950197391, 0.560585410884511, 0.95020500059664], 
             UndirectedEdge[34, 64] -> 
             RGBColor[
              0.5582052690153624, 0.6520008037616993, 0.9585097008190273], 
             UndirectedEdge[159, 180] -> 
             RGBColor[
              0.9319034158963638, 0.948517650293925, 0.9926439535610908], 
             UndirectedEdge[3, 123] -> 
             RGBColor[
              0.769379833643262, 0.8154436985770102, 0.7733426816165385], 
             UndirectedEdge[50, 97] -> 
             RGBColor[
              0.8151917357748932, 0.8557204839241364, 0.9430878900048263], 
             UndirectedEdge[87, 89] -> 
             RGBColor[
              0.5152405685974282, 0.6173345307673177, 0.9549807714298323], 
             UndirectedEdge[123, 191] -> 
             RGBColor[
              0.6794556194553918, 0.7480199136925958, 0.9697077531333407], 
             UndirectedEdge[108, 151] -> 
             RGBColor[
              0.7771604442537635, 0.7990624498474754, 0.6597695458187972], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.5426951415532351, 0.6367339890420012, 0.9583239845498759], 
             UndirectedEdge[19, 33] -> 
             RGBColor[
              0.7330664018802504, 0.7896683054166855, 0.949506507958084], 
             UndirectedEdge[156, 199] -> 
             RGBColor[
              0.6002091422769898, 0.6816643635299937, 0.9640564426431248], 
             UndirectedEdge[47, 144] -> 
             RGBColor[
              0.7602609355301666, 0.8073501117886885, 0.7160352761057931], 
             UndirectedEdge[123, 127] -> 
             RGBColor[
              0.622277047625857, 0.703351578806122, 0.9640087274575062], 
             UndirectedEdge[82, 120] -> 
             RGBColor[
              0.5754671855499487, 0.6623357588889933, 0.9615903956233048], 
             UndirectedEdge[120, 137] -> 
             RGBColor[
              0.6336586551179983, 0.7115261921833489, 0.9656332094753584], 
             UndirectedEdge[122, 179] -> 
             RGBColor[
              0.7603446870959021, 0.8131498570689577, 0.9766300083517265], 
             UndirectedEdge[52, 124] -> 
             RGBColor[
              0.7897332894902198, 0.8362747059307736, 0.9701051038318833], 
             UndirectedEdge[17, 106] -> 
             RGBColor[
              0.914789914427099, 0.9347481675547311, 0.9867249344508177], 
             UndirectedEdge[125, 166] -> 
             RGBColor[
              0.911457006355659, 0.9322350922993903, 0.9914167770051194], 
             UndirectedEdge[7, 79] -> 
             RGBColor[
              0.6497933715442671, 0.7239551150771494, 0.9673614533898707], 
             UndirectedEdge[49, 127] -> 
             RGBColor[
              0.651575843406703, 0.7271376611167213, 0.9663152359863998], 
             UndirectedEdge[121, 200] -> 
             RGBColor[
              0.8181529831442276, 0.8583948815796719, 0.9823693105267325], 
             UndirectedEdge[56, 193] -> 
             RGBColor[
              0.42365783663458567`, 0.5408526683176541, 0.9483598103713868], 
             UndirectedEdge[149, 194] -> 
             RGBColor[
              0.8720813342104872, 0.7517412410037925, 0.6102620114910176], 
             UndirectedEdge[108, 133] -> 
             RGBColor[
              0.5356920606560608, 0.6339379733497335, 0.9565907878009717], 
             UndirectedEdge[41, 140] -> 
             RGBColor[
              0.883233630408754, 0.9097305384224597, 0.9887248062119987], 
             UndirectedEdge[36, 185] -> 
             RGBColor[
              0.9850380608116365, 0.9599499174299977, 0.5019944749672927], 
             UndirectedEdge[108, 111] -> 
             RGBColor[
              0.785739753417247, 0.8278690571141718, 0.7044433655489963], 
             UndirectedEdge[72, 154] -> 
             RGBColor[
              0.5140349148113488, 0.6163557267096943, 0.9548858579473367], 
             UndirectedEdge[63, 110] -> 
             RGBColor[
              0.752587941615786, 0.8064116430530441, 0.9750450172885876], 
             UndirectedEdge[15, 186] -> 
             RGBColor[
              0.9299591967505021, 0.9469882366916591, 0.9931815324420801], 
             UndirectedEdge[54, 155] -> 
             RGBColor[
              0.6937754583759939, 0.7607019280628835, 0.9701127120567972], 
             UndirectedEdge[18, 108] -> 
             RGBColor[
              0.4801679203345929, 0.5869129980995661, 0.9527579558779581], 
             UndirectedEdge[44, 102] -> 
             RGBColor[
              0.7223595880930831, 0.7821384029167697, 0.9738641497954776], 
             UndirectedEdge[8, 122] -> 
             RGBColor[
              0.9324696231419377, 0.9466095637624683, 0.9010003924477749], 
             UndirectedEdge[42, 197] -> 
             RGBColor[
              0.8988724107147729, 0.9214662084355956, 0.9647588833524184], 
             UndirectedEdge[48, 147] -> 
             RGBColor[
              0.45997940340888355`, 0.5717695478043194, 0.9508242309747297], 
             UndirectedEdge[34, 54] -> 
             RGBColor[
              0.6896739969992682, 0.7574978352631243, 0.9697039167171009], 
             UndirectedEdge[5, 75] -> 
             RGBColor[
              0.7956364442614492, 0.8370700400848743, 0.8008207006204635], 
             UndirectedEdge[55, 115] -> 
             RGBColor[
              0.7395231707267687, 0.7953953868325729, 0.963028152182711], 
             UndirectedEdge[49, 155] -> 
             RGBColor[
              0.6339528711383917, 0.7133704612411665, 0.9645587428067337], 
             UndirectedEdge[66, 136] -> 
             RGBColor[0.715544408831458, 0.77706757592127, 0.972795831419043],
              UndirectedEdge[136, 148] -> 
             RGBColor[
              0.7138037410821092, 0.7756544234261602, 0.9726587996775382], 
             UndirectedEdge[130, 189] -> 
             RGBColor[
              0.7747678315486599, 0.8242291776803611, 0.9717191989548759], 
             UndirectedEdge[48, 76] -> 
             RGBColor[
              0.5759574141303496, 0.6663655563865661, 0.9599395119342515], 
             UndirectedEdge[29, 141] -> 
             RGBColor[
              0.8052881379015662, 0.8455359311340407, 0.8493730545827869], 
             UndirectedEdge[133, 163] -> 
             RGBColor[
              0.7426714834942996, 0.7929042953872736, 0.7010528735763908], 
             UndirectedEdge[111, 169] -> 
             RGBColor[
              0.7674088426749122, 0.8129871979754262, 0.7030002891070211], 
             UndirectedEdge[76, 142] -> 
             RGBColor[
              0.6120038155893105, 0.6956296489628309, 0.9627772166994202], 
             UndirectedEdge[78, 98] -> 
             RGBColor[
              0.5208700107067673, 0.6196840309476026, 0.9561486594745437], 
             UndirectedEdge[21, 170] -> 
             RGBColor[
              0.9052350929408046, 0.7641131618116512, 0.6106476485114324], 
             UndirectedEdge[92, 139] -> 
             RGBColor[
              0.5494245834834279, 0.6450866540240935, 0.9576718623018307], 
             UndirectedEdge[63, 70] -> 
             RGBColor[
              0.9355588080635864, 0.9514111533928304, 0.9922573345265004], 
             UndirectedEdge[71, 197] -> 
             RGBColor[
              0.8981332529750274, 0.9208768241178249, 0.9646883818273476], 
             UndirectedEdge[127, 141] -> 
             RGBColor[
              0.8473018176766219, 0.8787645414952319, 0.8532821776668735], 
             UndirectedEdge[64, 138] -> 
             RGBColor[
              0.47393279283879564`, 0.5837990175123684, 0.9517288720067443], 
             UndirectedEdge[39, 108] -> 
             RGBColor[
              0.3788436652895041, 0.4871483675383158, 0.9467411398867887], 
             UndirectedEdge[24, 165] -> 
             RGBColor[
              0.9183165490066095, 0.9353130992480032, 0.8991646652015122], 
             UndirectedEdge[132, 182] -> 
             RGBColor[
              0.6859598856231061, 0.7475991896082104, 0.8776093715426776], 
             UndirectedEdge[77, 181] -> 
             RGBColor[
              0.9845075606128346, 0.98475244800728, 0.7197818089484664], 
             UndirectedEdge[20, 47] -> 
             RGBColor[
              0.7281089246476958, 0.6911091639150034, 0.6087052836601258], 
             UndirectedEdge[191, 199] -> 
             RGBColor[
              0.5978684391590913, 0.6798357884642887, 0.963823143231447], 
             UndirectedEdge[89, 154] -> 
             RGBColor[
              0.5068443739629265, 0.6105181217187714, 0.95431979223193], 
             UndirectedEdge[93, 164] -> 
             RGBColor[
              0.6712629273488576, 0.7413477384878473, 0.9690771376353126], 
             UndirectedEdge[26, 187] -> 
             RGBColor[
              0.4319151345819796, 0.5477392128623685, 0.9489593198277341], 
             UndirectedEdge[5, 188] -> 
             RGBColor[
              0.8200193867193257, 0.8568161497334634, 0.8027737587686992], 
             UndirectedEdge[7, 16] -> 
             RGBColor[
              0.5951537511298624, 0.6812702283329207, 0.9619154866632466], 
             UndirectedEdge[154, 160] -> 
             RGBColor[
              0.5630711814240221, 0.6561655770044992, 0.9587461724808497], 
             UndirectedEdge[88, 152] -> 
             RGBColor[
              0.7379778598413169, 0.7950609153170449, 0.9748141087482972], 
             UndirectedEdge[9, 18] -> 
             RGBColor[
              0.5050392364265769, 0.6071046529430602, 0.9547159169873518], 
             UndirectedEdge[9, 200] -> 
             RGBColor[
              0.7569238102233509, 0.8103499295164165, 0.9764116799351932], 
             UndirectedEdge[55, 183] -> 
             RGBColor[
              0.8614580209918524, 0.41009593952786316`, 0.4328013046115824], 
             UndirectedEdge[72, 104] -> 
             RGBColor[
              0.6810218945852071, 0.7490004645047017, 0.9701243380790593], 
             UndirectedEdge[112, 181] -> 
             RGBColor[
              0.8677002259530131, 0.8968003212215356, 0.9513487998720412], 
             UndirectedEdge[136, 193] -> 
             RGBColor[
              0.6573996008299998, 0.7298630013919362, 0.9682184591417186], 
             UndirectedEdge[80, 198] -> 
             RGBColor[
              0.6879958256027232, 0.7561868350135683, 0.9695366522756965], 
             UndirectedEdge[42, 131] -> 
             RGBColor[
              0.8257198481506536, 0.8638877125808386, 0.9832345517170911], 
             UndirectedEdge[65, 156] -> 
             RGBColor[
              0.8847046905177708, 0.9105293512876094, 0.9755701367353921], 
             UndirectedEdge[26, 192] -> 
             RGBColor[
              0.45564257125297525`, 0.568290725931142, 0.9504712111110616], 
             UndirectedEdge[65, 155] -> 
             RGBColor[
              0.807562443302026, 0.8502652414598757, 0.9678813184682138], 
             UndirectedEdge[59, 62] -> 
             RGBColor[
              0.9424254844107505, 0.9563649917636485, 0.9748328361612199], 
             UndirectedEdge[82, 187] -> 
             RGBColor[
              0.3815755100901777, 0.5049232611225005, 0.945534631982339], 
             UndirectedEdge[4, 86] -> 
             RGBColor[
              0.8932292675685197, 0.9166320143320575, 0.9482345943848938], 
             UndirectedEdge[73, 167] -> 
             RGBColor[
              0.638628507688401, 0.7145992802839005, 0.9666601364684513], 
             UndirectedEdge[74, 159] -> 
             RGBColor[
              0.696613513891221, 0.7609962393543201, 0.9713669294596147], 
             UndirectedEdge[25, 60] -> 
             RGBColor[
              0.4203804656666079, 0.5383748490059568, 0.9480512684378316], 
             UndirectedEdge[159, 162] -> 
             RGBColor[
              0.6590416016315311, 0.7285456915833621, 0.9689473626908024], 
             UndirectedEdge[10, 147] -> 
             RGBColor[
              0.5244219057649784, 0.6240868743186447, 0.9558973808208657], 
             UndirectedEdge[23, 163] -> 
             RGBColor[
              0.967010767074772, 0.9712896771472219, 0.7165747139997857], 
             UndirectedEdge[40, 54] -> 
             RGBColor[
              0.7082346670056594, 0.771997571738434, 0.9715538708440152], 
             UndirectedEdge[123, 129] -> 
             RGBColor[
              0.7659222088653701, 0.8047102649033724, 0.6808345166840476], 
             UndirectedEdge[25, 165] -> 
             RGBColor[
              0.7246615220573758, 0.7810080523712024, 0.8818382735651393], 
             UndirectedEdge[39, 178] -> 
             RGBColor[
              0.4577429277981852, 0.5497593215686518, 0.9539389806290729], 
             UndirectedEdge[76, 107] -> 
             RGBColor[
              0.5205072886929858, 0.6194006697536469, 0.9561125067340399], 
             UndirectedEdge[63, 138] -> 
             RGBColor[
              0.7125702482874783, 0.7739234768325838, 0.9718946778801425], 
             UndirectedEdge[71, 81] -> 
             RGBColor[
              0.8625005870123357, 0.8931985724016263, 0.9867472700242419], 
             UndirectedEdge[8, 83] -> 
             RGBColor[
              0.9059984932947575, 0.9255022033620048, 0.8984755524518943], 
             UndirectedEdge[10, 149] -> 
             RGBColor[
              0.7588238973005261, 0.6627165665940193, 0.5992533177913417], 
             UndirectedEdge[119, 172] -> 
             RGBColor[
              0.687168218549863, 0.7459239704577518, 0.699492197615341], 
             UndirectedEdge[106, 130] -> 
             RGBColor[
              0.7738908503817341, 0.8235751265619926, 0.9732036993171607], 
             UndirectedEdge[147, 176] -> 
             RGBColor[
              0.4397300782972704, 0.555293825169898, 0.9492401896444295], 
             UndirectedEdge[27, 197] -> 
             RGBColor[
              0.6728743101425336, 0.7388621029418864, 0.9455321953298607], 
             UndirectedEdge[72, 176] -> 
             RGBColor[
              0.4830726302075381, 0.5911827409461816, 0.9524584532029471], 
             UndirectedEdge[92, 118] -> 
             RGBColor[
              0.5003950886769801, 0.6052823013866488, 0.9538120808697098], 
             UndirectedEdge[123, 171] -> 
             RGBColor[
              0.528957661453987, 0.6284706846962632, 0.9560606312268674], 
             UndirectedEdge[66, 113] -> 
             RGBColor[
              0.678167456143211, 0.7476878582417974, 0.9691183606676451], 
             UndirectedEdge[67, 179] -> 
             RGBColor[
              0.6513521029645407, 0.7275604803860132, 0.96588434845818], 
             UndirectedEdge[130, 197] -> 
             RGBColor[
              0.7853262265321497, 0.8321036113712628, 0.9538465903182738], 
             UndirectedEdge[15, 194] -> 
             RGBColor[
              0.8912050196815405, 0.916086707850982, 0.9894851244369802], 
             UndirectedEdge[47, 135] -> 
             RGBColor[
              0.7444554202285472, 0.7543221297739247, 0.6301671466159147], 
             UndirectedEdge[8, 170] -> 
             RGBColor[
              0.9394261653488445, 0.7889957760678733, 0.5214882368158376], 
             UndirectedEdge[17, 149] -> 
             RGBColor[
              0.8922822499420485, 0.7678489028688895, 0.6121887928670643], 
             UndirectedEdge[13, 97] -> 
             RGBColor[
              0.8650206553904133, 0.8946472146415961, 0.9480543710343726], 
             UndirectedEdge[11, 86] -> 
             RGBColor[
              0.9836081546467167, 0.9871280693076558, 0.9051303153500688], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.9460431150338608, 0.9592495922245495, 0.975177888999549], 
             UndirectedEdge[37, 160] -> 
             RGBColor[
              0.5322154838812485, 0.6310849115960353, 0.956325559369738], 
             UndirectedEdge[46, 50] -> 
             RGBColor[
              0.6235775487730129, 0.7051503539361446, 0.9636031352219803], 
             UndirectedEdge[49, 53] -> 
             RGBColor[
              0.7080717550631662, 0.771272696687582, 0.9719462204760044], 
             UndirectedEdge[52, 120] -> 
             RGBColor[
              0.8577838194613165, 0.8895757159073774, 0.976792423323396], 
             UndirectedEdge[81, 147] -> 
             RGBColor[
              0.6601954120611839, 0.7310652512745875, 0.9690536773189341], 
             UndirectedEdge[49, 123] -> 
             RGBColor[
              0.5740486664636248, 0.665077593889714, 0.9596103603150198], 
             UndirectedEdge[127, 140] -> 
             RGBColor[
              0.7694861733833, 0.8200027721672112, 0.9776177009149838], 
             UndirectedEdge[31, 132] -> 
             RGBColor[
              0.9209410752239342, 0.9373661664538604, 0.8976928746160804], 
             UndirectedEdge[146, 186] -> 
             RGBColor[
              0.9559061571163876, 0.9659979349779564, 0.9336632628831367], 
             UndirectedEdge[98, 124] -> 
             RGBColor[
              0.507416655578852, 0.6090347489123894, 0.9549030761317923], 
             UndirectedEdge[4, 53] -> 
             RGBColor[
              0.8086192402755685, 0.8504187633279011, 0.9815592669603865], 
             UndirectedEdge[82, 137] -> 
             RGBColor[
              0.4397669796582273, 0.5541136944168561, 0.9495774458343925], 
             UndirectedEdge[42, 107] -> 
             RGBColor[
              0.607573610662417, 0.6875273666162096, 0.9647613200048968], 
             UndirectedEdge[99, 102] -> 
             RGBColor[
              0.4600595944714846, 0.5705881532941379, 0.9511749548067895], 
             UndirectedEdge[57, 88] -> 
             RGBColor[
              0.7991680678000717, 0.8402766400839847, 0.8289215369055274], 
             UndirectedEdge[40, 49] -> 
             RGBColor[
              0.6484120797680573, 0.724666104916717, 0.9659999015939518], 
             UndirectedEdge[21, 90] -> 
             RGBColor[
              0.9575085796103562, 0.9642603774882395, 0.7533459241974596], 
             UndirectedEdge[143, 158] -> 
             RGBColor[
              0.9087415541869426, 0.9251711157010594, 0.7321770795434228], 
             UndirectedEdge[24, 111] -> 
             RGBColor[
              0.9196073256984958, 0.9336359548973633, 0.7170630697452427], 
             UndirectedEdge[139, 155] -> 
             RGBColor[
              0.6384573588778679, 0.7170274073129335, 0.9649133525820676], 
             UndirectedEdge[94, 174] -> 
             RGBColor[
              0.7274936492604809, 0.7820505920637588, 0.8202034269685183], 
             UndirectedEdge[4, 118] -> 
             RGBColor[
              0.6593699403899017, 0.7318623362749548, 0.9680247436715084], 
             UndirectedEdge[121, 159] -> 
             RGBColor[
              0.8437345008888071, 0.8787720354671773, 0.9840862782873545], 
             UndirectedEdge[5, 76] -> 
             RGBColor[
              0.8269580638891928, 0.8622366970744633, 0.8034653412633668], 
             UndirectedEdge[27, 194] -> 
             RGBColor[
              0.6147255747935974, 0.6932301486795183, 0.9654434807283625], 
             UndirectedEdge[77, 160] -> 
             RGBColor[
              0.8027768865312293, 0.8420946471549915, 0.7380831453870568], 
             UndirectedEdge[2, 80] -> 
             RGBColor[
              0.7377506441254167, 0.7950556773941229, 0.974495747600824], 
             UndirectedEdge[74, 85] -> 
             RGBColor[
              0.5081410959034502, 0.6115708590067462, 0.954421874933137], 
             UndirectedEdge[35, 110] -> 
             RGBColor[
              0.6539795539489852, 0.7284716177454249, 0.9669266419834017], 
             UndirectedEdge[143, 154] -> 
             RGBColor[
              0.753458939617806, 0.8018591210137672, 0.7180549722135368], 
             UndirectedEdge[53, 129] -> 
             RGBColor[
              0.8999452974649114, 0.9109053677012404, 0.6931703768450322], 
             UndirectedEdge[80, 187] -> 
             RGBColor[
              0.520772975411561, 0.6196082262374918, 0.956138987903164], 
             UndirectedEdge[30, 87] -> 
             RGBColor[
              0.5683050473613456, 0.6604146651553918, 0.9591582015797184], 
             UndirectedEdge[29, 197] -> 
             RGBColor[
              0.7899749876068565, 0.8358776850360095, 0.9542125578190477], 
             UndirectedEdge[74, 121] -> 
             RGBColor[
              0.6038403216071434, 0.6876001527772737, 0.9630931143477035], 
             UndirectedEdge[127, 199] -> 
             RGBColor[
              0.5406898673295565, 0.6351674535778149, 0.9581241175556126], 
             UndirectedEdge[52, 80] -> 
             RGBColor[
              0.8030896093229287, 0.846848183255876, 0.9713410156032551], 
             UndirectedEdge[125, 187] -> 
             RGBColor[
              0.635962222713528, 0.7101636752774196, 0.9674690511651449], 
             UndirectedEdge[57, 152] -> 
             RGBColor[
              0.9337984653969177, 0.9464738792007161, 0.8418187768099114], 
             UndirectedEdge[128, 193] -> 
             RGBColor[
              0.5330711094279024, 0.6318101670702072, 0.9563844569194304], 
             UndirectedEdge[151, 172] -> 
             RGBColor[
              0.6785680340093483, 0.7170727128704099, 0.6525462219231781], 
             UndirectedEdge[5, 27] -> 
             RGBColor[
              0.6880262852863848, 0.7477592884433168, 0.7928874665116658], 
             UndirectedEdge[65, 118] -> 
             RGBColor[
              0.7324320273411337, 0.7896110498533451, 0.9617342728486062], 
             UndirectedEdge[78, 80] -> 
             RGBColor[
              0.6600674760281506, 0.7343689960625939, 0.9667530153953687], 
             UndirectedEdge[40, 199] -> 
             RGBColor[
              0.5375261036909106, 0.6326958973778105, 0.9578087831631645], 
             UndirectedEdge[5, 42] -> 
             RGBColor[
              0.914024385858624, 0.9303633939370259, 0.8121141545342235], 
             UndirectedEdge[123, 196] -> 
             RGBColor[
              0.6078420207385, 0.6920748260914511, 0.9625699788803703], 
             UndirectedEdge[80, 124] -> 
             RGBColor[
              0.6466141209002353, 0.7237197140273808, 0.9655074320526171], 
             UndirectedEdge[22, 48] -> 
             RGBColor[
              0.6982440423700196, 0.6279386198950638, 0.597403255639269], 
             UndirectedEdge[69, 86] -> 
             RGBColor[
              0.9873676393616249, 0.9864717991674377, 0.6821158391407627], 
             UndirectedEdge[81, 143] -> 
             RGBColor[
              0.9429619887779088, 0.9524575613549442, 0.7354410551436517], 
             UndirectedEdge[80, 116] -> 
             RGBColor[
              0.772763410260935, 0.8229379135406697, 0.9778448479727055], 
             UndirectedEdge[90, 169] -> 
             RGBColor[
              0.767709240516659, 0.8136297185840422, 0.7356967403405901], 
             UndirectedEdge[121, 173] -> 
             RGBColor[
              0.7994184740508733, 0.8434564925633334, 0.9805823963249147], 
             UndirectedEdge[8, 179] -> 
             RGBColor[
              0.8179543960517769, 0.8567058564264687, 0.8897042871161278], 
             UndirectedEdge[29, 167] -> 
             RGBColor[
              0.7221483997587217, 0.7825288738890883, 0.973200761006655], 
             UndirectedEdge[76, 87] -> 
             RGBColor[
              0.5950665682570488, 0.6818792285642037, 0.9614438545462433], 
             UndirectedEdge[111, 163] -> 
             RGBColor[
              0.9927191762554858, 0.9868353791517118, 0.4489054513244154], 
             UndirectedEdge[130, 149] -> 
             RGBColor[
              0.7513831858966835, 0.656675861876151, 0.5986675577334073], 
             UndirectedEdge[7, 122] -> 
             RGBColor[
              0.6806763217147477, 0.7485246520546485, 0.970321874946227], 
             UndirectedEdge[89, 142] -> 
             RGBColor[
              0.5321778159296899, 0.6310849511659448, 0.9563141335830092], 
             UndirectedEdge[44, 172] -> 
             RGBColor[
              0.6438755037117763, 0.7164735107451323, 0.9682238269710272], 
             UndirectedEdge[7, 179] -> 
             RGBColor[
              0.5661610946245869, 0.6586209447186488, 0.95902576961458], 
             UndirectedEdge[73, 188] -> 
             RGBColor[
              0.5471493969171208, 0.6430661109015823, 0.9575606621903556], 
             UndirectedEdge[16, 120] -> 
             RGBColor[
              0.7365868170130061, 0.794146486808494, 0.9743797481908417], 
             UndirectedEdge[98, 116] -> 
             RGBColor[
              0.6335659449395517, 0.7082529484256783, 0.9672404920518807], 
             UndirectedEdge[5, 81] -> 
             RGBColor[
              0.943692419376049, 0.9540198785465042, 0.8149439180560817], 
             UndirectedEdge[76, 106] -> 
             RGBColor[
              0.800370712594926, 0.8448110267637627, 0.9754671790804484], 
             UndirectedEdge[135, 144] -> 
             RGBColor[
              0.9771636988024266, 0.9343422028123142, 0.39025239859560024`], 
             UndirectedEdge[194, 197] -> 
             RGBColor[
              0.9060243748459533, 0.9271689904989041, 0.9654410440758842], 
             UndirectedEdge[27, 29] -> 
             RGBColor[
              0.4986761875545006, 0.6019388432166237, 0.9542149944715259], 
             UndirectedEdge[44, 58] -> 
             RGBColor[
              0.9176913855913906, 0.9372062170742466, 0.9920114176621198], 
             UndirectedEdge[53, 92] -> 
             RGBColor[
              0.649644388562647, 0.7238387284395952, 0.967346604158588], 
             UndirectedEdge[83, 122] -> 
             RGBColor[
              0.8483887843388827, 0.881946204004494, 0.985401273687493], 
             UndirectedEdge[9, 178] -> 
             RGBColor[
              0.6825309091796732, 0.7517053439504617, 0.9691370816252551], 
             UndirectedEdge[12, 99] -> 
             RGBColor[
              0.6878059819211987, 0.7472880818212706, 0.7689088047659296], 
             UndirectedEdge[7, 126] -> 
             RGBColor[
              0.6138009505092732, 0.6958375622120807, 0.9637740652294005], 
             UndirectedEdge[139, 146] -> 
             RGBColor[
              0.7993923791606292, 0.842416672190935, 0.9186037343381344], 
             UndirectedEdge[100, 198] -> 
             RGBColor[
              0.7883234410326337, 0.8348920222069689, 0.9794491998225854], 
             UndirectedEdge[56, 109] -> 
             RGBColor[
              0.647920170579631, 0.611795257357877, 0.6001995176310811], 
             UndirectedEdge[9, 159] -> 
             RGBColor[
              0.7825053279679303, 0.8307270834039218, 0.9781286476958152], 
             UndirectedEdge[2, 98] -> 
             RGBColor[
              0.5985531788040335, 0.6803707122791316, 0.9638913916799992], 
             UndirectedEdge[95, 164] -> 
             RGBColor[
              0.7280379855726113, 0.3559765809679873, 0.4352899688530544], 
             UndirectedEdge[108, 163] -> 
             RGBColor[
              0.785739753417247, 0.8278690571141718, 0.7044433655489963], 
             UndirectedEdge[85, 121] -> 
             RGBColor[
              0.6552620829010363, 0.7293466551196033, 0.9671412237608769], 
             UndirectedEdge[55, 177] -> 
             RGBColor[
              0.9712974220996732, 0.9745838993231373, 0.7170342522084878], 
             UndirectedEdge[118, 141] -> 
             RGBColor[
              0.7545484294474183, 0.8043431500131464, 0.8453786388676001], 
             UndirectedEdge[58, 77] -> 
             RGBColor[
              0.9612601820065606, 0.9672471873641175, 0.7533295641939397], 
             UndirectedEdge[142, 154] -> 
             RGBColor[
              0.5392351219160638, 0.6368143900936947, 0.9568697105620202], 
             UndirectedEdge[103, 178] -> 
             RGBColor[
              0.5590671828432741, 0.6495239521299021, 0.9599557966202423], 
             UndirectedEdge[48, 154] -> 
             RGBColor[
              0.5031887204571028, 0.6075502975174301, 0.9540320057968514], 
             UndirectedEdge[72, 181] -> 
             RGBColor[
              0.7449350903676758, 0.7989315439199607, 0.9404553247786551], 
             UndirectedEdge[45, 132] -> 
             RGBColor[
              0.8209820402394203, 0.8590223702668651, 0.8877975715129183], 
             UndirectedEdge[103, 200] -> 
             RGBColor[
              0.6334600838869517, 0.7081685376958569, 0.9672303949301804], 
             UndirectedEdge[21, 61] -> 
             RGBColor[
              0.6865662275767859, 0.7529163033334951, 0.971189764288497], 
             UndirectedEdge[51, 73] -> 
             RGBColor[
              0.4992691355455746, 0.6042438192167221, 0.9537578090237206], 
             UndirectedEdge[18, 41] -> 
             RGBColor[
              0.6544373243550103, 0.7248952198330634, 0.9692312228526274], 
             UndirectedEdge[27, 42] -> 
             RGBColor[
              0.607573610662417, 0.6875273666162096, 0.9647613200048968], 
             UndirectedEdge[90, 165] -> 
             RGBColor[
              0.9917287974053464, 0.9891550441109678, 0.6637034980142538], 
             UndirectedEdge[50, 135] -> 
             RGBColor[
              0.8063308264372484, 0.8044183541263807, 0.6351318851110362], 
             UndirectedEdge[93, 121] -> 
             RGBColor[
              0.7832460780613093, 0.8305970561629468, 0.9790303072765513], 
             UndirectedEdge[23, 175] -> 
             RGBColor[
              0.8754619093929324, 0.9034728404165986, 0.9829515678101425], 
             UndirectedEdge[57, 164] -> 
             RGBColor[
              0.7609918402677491, 0.809283458753794, 0.8259161644300537], 
             UndirectedEdge[54, 172] -> 
             RGBColor[
              0.5522840734049266, 0.6442249354831239, 0.9592797196631896], 
             UndirectedEdge[99, 198] -> 
             RGBColor[
              0.5487983602813399, 0.641501869898577, 0.9589322963548716], 
             UndirectedEdge[45, 112] -> 
             RGBColor[
              0.705659120083439, 0.7699855349079137, 0.9712971643966626], 
             UndirectedEdge[88, 173] -> 
             RGBColor[
              0.7256115508707439, 0.7852003562184247, 0.9736345991591496], 
             UndirectedEdge[14, 22] -> 
             RGBColor[
              0.949000049556062, 0.8232864948568983, 0.4143012506779698], 
             UndirectedEdge[7, 67] -> 
             RGBColor[
              0.5716837375833863, 0.6629352753717039, 0.9595762150526803], 
             UndirectedEdge[105, 135] -> 
             RGBColor[
              0.8408257168637525, 0.8313660246984431, 0.6385700134156715], 
             UndirectedEdge[104, 176] -> 
             RGBColor[
              0.649926375119348, 0.723719312678016, 0.9676864445982738], 
             UndirectedEdge[57, 91] -> 
             RGBColor[
              0.738474943546912, 0.7910032276211807, 0.824143551838079], 
             UndirectedEdge[34, 185] -> 
             RGBColor[
              0.8159579576036899, 0.8303456126504103, 0.6629704189770894], 
             UndirectedEdge[65, 172] -> 
             RGBColor[
              0.6660710583309586, 0.7337882488801162, 0.9570483260746061], 
             UndirectedEdge[66, 120] -> 
             RGBColor[
              0.6790623180934023, 0.7483869311984896, 0.9692075521438799], 
             UndirectedEdge[91, 117] -> 
             RGBColor[
              0.7368060995825436, 0.7905661667179626, 0.8701946034745935], 
             UndirectedEdge[27, 141] -> 
             RGBColor[
              0.6881874604372431, 0.7485203490399175, 0.8406926920936], 
             UndirectedEdge[13, 145] -> 
             RGBColor[
              0.6594099048702178, 0.7327140438514351, 0.9674677555002633], 
             UndirectedEdge[1, 174] -> 
             RGBColor[
              0.6882538139296379, 0.7482459492045604, 0.8176525551857414], 
             UndirectedEdge[182, 196] -> 
             RGBColor[
              0.5262548404421995, 0.623890700863144, 0.9566853689784767], 
             UndirectedEdge[96, 137] -> 
             RGBColor[
              0.7288088365937854, 0.7863693117551394, 0.9533954251736132], 
             UndirectedEdge[89, 157] -> 
             RGBColor[
              0.472265521388837, 0.5822126465533948, 0.9516619429744797], 
             UndirectedEdge[119, 191] -> 
             RGBColor[
              0.9034611476187766, 0.9208364977995399, 0.717780708864449], 
             UndirectedEdge[51, 157] -> 
             RGBColor[
              0.49727258250704426`, 0.6025145053244206, 0.9536305904295881], 
             UndirectedEdge[127, 195] -> 
             RGBColor[
              0.6015975038007348, 0.686562993526055, 0.9623807580159276], 
             UndirectedEdge[27, 62] -> 
             RGBColor[
              0.6695636701459178, 0.7363930330530858, 0.9511362452909314], 
             UndirectedEdge[4, 40] -> 
             RGBColor[
              0.7489595649804596, 0.8038121715570361, 0.9756129480783339], 
             UndirectedEdge[161, 164] -> 
             RGBColor[
              0.5756269369540936, 0.666358904974152, 0.9597346075494249], 
             UndirectedEdge[20, 101] -> 
             RGBColor[
              0.6551203512146411, 0.6299057751011041, 0.6034975875882416], 
             UndirectedEdge[13, 36] -> 
             RGBColor[
              0.8727384361497418, 0.8980268095659034, 0.8101218006230058], 
             UndirectedEdge[182, 195] -> 
             RGBColor[
              0.442483146561356, 0.5563188010707406, 0.949791272442654], 
             UndirectedEdge[184, 186] -> 
             RGBColor[
              0.9181900562870167, 0.9376038435508833, 0.992058981318237], 
             UndirectedEdge[96, 166] -> 
             RGBColor[
              0.9461121506678667, 0.9592502954827543, 0.9733003371615343], 
             UndirectedEdge[38, 43] -> 
             RGBColor[
              0.8118186433508883, 0.8538391249890538, 0.9809052038786209], 
             UndirectedEdge[30, 176] -> 
             RGBColor[
              0.5289465681230331, 0.6284252703433328, 0.9560698176374264], 
             UndirectedEdge[171, 174] -> 
             RGBColor[
              0.7540487849971467, 0.8036092475500161, 0.8222939445283761], 
             UndirectedEdge[100, 125] -> 
             RGBColor[
              0.8754873034648218, 0.9035538275858115, 0.9879859546328587], 
             UndirectedEdge[17, 188] -> 
             RGBColor[
              0.7669195919580998, 0.8183946718347619, 0.9772565543614425], 
             UndirectedEdge[87, 107] -> 
             RGBColor[
              0.4561347896542408, 0.5674018199330573, 0.9508659797945422], 
             UndirectedEdge[62, 184] -> 
             RGBColor[
              0.9342739745703755, 0.9498651990837738, 0.9740553378757062], 
             UndirectedEdge[12, 33] -> 
             RGBColor[
              0.7478704968750152, 0.7979991377395248, 0.773099071611942], 
             UndirectedEdge[32, 57] -> 
             RGBColor[
              0.7405337682123154, 0.7926746742335495, 0.8243056300574627], 
             UndirectedEdge[17, 87] -> 
             RGBColor[
              0.7094857700892219, 0.7718163693551721, 0.9727016099166125], 
             UndirectedEdge[42, 149] -> 
             RGBColor[
              0.8649293700793067, 0.7460384589404838, 0.609579850767552], 
             UndirectedEdge[87, 130] -> 
             RGBColor[
              0.568586706043857, 0.6606433283624336, 0.9591803747829555], 
             UndirectedEdge[58, 170] -> 
             RGBColor[
              0.9089901362246415, 0.7671073313982482, 0.6110058078920115], 
             UndirectedEdge[118, 196] -> 
             RGBColor[
              0.5926158094523746, 0.6797135018363728, 0.9613713157524768], 
             UndirectedEdge[41, 159] -> 
             RGBColor[
              0.9319034158963638, 0.948517650293925, 0.9926439535610908], 
             UndirectedEdge[107, 157] -> 
             RGBColor[
              0.41315974244564957`, 0.5322799357191343, 0.9475471513391897], 
             UndirectedEdge[161, 173] -> 
             RGBColor[
              0.7360672531126892, 0.793688766322454, 0.9744577103401348], 
             UndirectedEdge[15, 184] -> 
             RGBColor[
              0.9227652594025786, 0.9412519863246522, 0.9924953682757314], 
             UndirectedEdge[106, 142] -> 
             RGBColor[
              0.7529354608884427, 0.8065625973418001, 0.9715540142941277], 
             UndirectedEdge[24, 39] -> 
             RGBColor[
              0.5127112375707529, 0.5929152653215074, 0.959360844083035], 
             UndirectedEdge[45, 134] -> 
             RGBColor[
              0.6741410140664615, 0.7453633509409731, 0.9681557341423371], 
             UndirectedEdge[5, 73] -> 
             RGBColor[
              0.7216070706803869, 0.776845276932252, 0.795027204462649], 
             UndirectedEdge[147, 154] -> 
             RGBColor[
              0.47069236290108113`, 0.5804668109334106, 0.9516675943888191], 
             UndirectedEdge[76, 143] -> 
             RGBColor[
              0.8262276332910526, 0.8606743798829033, 0.7239624783509367], 
             UndirectedEdge[5, 197] -> 
             RGBColor[
              0.9793250853387406, 0.9816981302627026, 0.7928850298591874], 
             UndirectedEdge[152, 159] -> 
             RGBColor[0.9045579753055237, 0.926713138239, 0.9900357210259735],
              UndirectedEdge[108, 115] -> 
             RGBColor[
              0.554035304528494, 0.6488298450790941, 0.958034835152126], 
             UndirectedEdge[65, 123] -> 
             RGBColor[
              0.7476582386272592, 0.8019723741084233, 0.9629329359764998], 
             UndirectedEdge[8, 67] -> 
             RGBColor[
              0.8234770390105763, 0.8610201870795238, 0.8902547325542283], 
             UndirectedEdge[9, 41] -> 
             RGBColor[
              0.7779010506914096, 0.827076611653623, 0.9784125078576402], 
             UndirectedEdge[111, 165] -> 
             RGBColor[
              0.9914283995635995, 0.9885125235023517, 0.6310070467806849], 
             UndirectedEdge[146, 195] -> 
             RGBColor[
              0.7449095518151847, 0.7981850585285017, 0.9143146465923284], 
             UndirectedEdge[104, 188] -> 
             RGBColor[
              0.7467186762265383, 0.8022870099696648, 0.9753297729853958], 
             UndirectedEdge[37, 105] -> 
             RGBColor[
              0.5862417675452255, 0.6737520292144648, 0.9613949503571695], 
             UndirectedEdge[3, 75] -> 
             RGBColor[
              0.7954028123220259, 0.8365703249902605, 0.7753913058234427], 
             UndirectedEdge[40, 132] -> 
             RGBColor[
              0.841910479223839, 0.8753718258635204, 0.8898835227235031], 
             UndirectedEdge[154, 157] -> 
             RGBColor[
              0.4793228273752109, 0.5879420854811447, 0.9522175199534906], 
             UndirectedEdge[116, 148] -> 
             RGBColor[
              0.7354204097336566, 0.7928909682400649, 0.9747206168309508], 
             UndirectedEdge[132, 185] -> 
             RGBColor[
              0.9829524095422766, 0.9597486413561196, 0.5846209614835166], 
             UndirectedEdge[92, 123] -> 
             RGBColor[
              0.5156212999631056, 0.6176436256417271, 0.9550107439976033], 
             UndirectedEdge[53, 139] -> 
             RGBColor[
              0.7125762428026425, 0.7749296427593491, 0.9723008302513383], 
             UndirectedEdge[40, 196] -> 
             RGBColor[
              0.6822054340429324, 0.751663337118454, 0.9689595201593023], 
             UndirectedEdge[27, 73] -> 
             RGBColor[
              0.41515629548417987`, 0.5340092496114357, 0.9476743699333223], 
             UndirectedEdge[57, 103] -> 
             RGBColor[
              0.688282091722925, 0.7483064325450783, 0.8207304184747403], 
             UndirectedEdge[44, 77] -> 
             RGBColor[
              0.9497442937485447, 0.9580647306576351, 0.7522311684915353], 
             UndirectedEdge[88, 91] -> 
             RGBColor[
              0.5426543379913112, 0.6395902637375095, 0.9571388837764648], 
             UndirectedEdge[69, 146] -> 
             RGBColor[
              0.9895737484266603, 0.9877455775948673, 0.6617434158030515], 
             UndirectedEdge[65, 199] -> 
             RGBColor[
              0.6660710583309586, 0.7337882488801162, 0.9570483260746061], 
             UndirectedEdge[27, 75] -> 
             RGBColor[
              0.4891856690652421, 0.594234012764058, 0.9534678660911369], 
             UndirectedEdge[4, 65] -> 
             RGBColor[
              0.8775045196205076, 0.9049045230593417, 0.9748524909897754], 
             UndirectedEdge[58, 102] -> 
             RGBColor[
              0.7338754763510991, 0.7913208596232522, 0.9749625454978821], 
             UndirectedEdge[107, 168] -> 
             RGBColor[
              0.3815755100901777, 0.5049232611225005, 0.945534631982339], 
             UndirectedEdge[9, 85] -> 
             RGBColor[
              0.5940329099801596, 0.6813017030563477, 0.9611835931693375], 
             UndirectedEdge[22, 144] -> 
             RGBColor[
              0.9484907689395901, 0.8221971951144333, 0.35886919849062726`], 
             UndirectedEdge[110, 138] -> 
             RGBColor[
              0.5278280982540351, 0.6275536544043001, 0.9559717078740408], 
             UndirectedEdge[34, 132] -> 
             RGBColor[
              0.8233498092174476, 0.8608720893882107, 0.8880335685965888], 
             UndirectedEdge[48, 158] -> 
             RGBColor[
              0.6584713350262394, 0.7308622922047223, 0.9681541131267375], 
             UndirectedEdge[19, 95] -> 
             RGBColor[
              0.8738490711002327, 0.47134788907946423`, 0.4316872109693338], 
             UndirectedEdge[122, 137] -> 
             RGBColor[
              0.6864091817061699, 0.7531788460580846, 0.9707731866849099], 
             UndirectedEdge[8, 198] -> 
             RGBColor[
              0.8530502712851573, 0.8841230208973163, 0.8932023159697902], 
             UndirectedEdge[92, 174] -> 
             RGBColor[
              0.7407124235062652, 0.79278218849548, 0.821244057299112], 
             UndirectedEdge[39, 133] -> 
             RGBColor[
              0.33577539536655676`, 0.4521836058114176, 0.9433506479141831], 
             UndirectedEdge[120, 198] -> 
             RGBColor[
              0.7426900357411109, 0.7989143676650698, 0.9749880599958374], 
             UndirectedEdge[4, 34] -> 
             RGBColor[
              0.7303988949740683, 0.7893124350817264, 0.9737629939514196], 
             UndirectedEdge[31, 34] -> 
             RGBColor[
              0.7539466232853476, 0.807963137748151, 0.9760423321096532], 
             UndirectedEdge[41, 152] -> 
             RGBColor[
              0.899953698029003, 0.9230626664887012, 0.9903195811877985], 
             UndirectedEdge[95, 121] -> 
             RGBColor[
              0.8026934193809124, 0.4154761260847203, 0.44192541528054685`], 
             UndirectedEdge[3, 129] -> 
             RGBColor[
              0.9905521718258533, 0.9788624519012679, 0.4968733465144598], 
             UndirectedEdge[49, 199] -> 
             RGBColor[
              0.4924614861673243, 0.5968934686614069, 0.9537257504131261], 
             UndirectedEdge[171, 182] -> 
             RGBColor[
              0.4473704811576865, 0.5602865594679561, 0.9501760213249737], 
             UndirectedEdge[56, 150] -> 
             RGBColor[
              0.48006197688669516`, 0.5866440903518781, 0.9528001509072066], 
             UndirectedEdge[179, 183] -> 
             RGBColor[
              0.7601558200019137, 0.330500049910986, 0.4312566343400266], 
             UndirectedEdge[31, 156] -> 
             RGBColor[
              0.835190331877818, 0.8714313403756437, 0.9841399457165277], 
             UndirectedEdge[132, 153] -> 
             RGBColor[
              0.9916802302211729, 0.9888728997374666, 0.6454593431595743], 
             UndirectedEdge[78, 136] -> 
             RGBColor[
              0.7512437769045939, 0.8057771734368757, 0.9757927023906728], 
             UndirectedEdge[27, 167] -> 
             RGBColor[
              0.6050477222943987, 0.6855132917949652, 0.964520398517468], 
             UndirectedEdge[35, 174] -> 
             RGBColor[
              0.8675227170423627, 0.8942350260763549, 0.8322508575367306], 
             UndirectedEdge[61, 190] -> 
             RGBColor[
              0.46694489620615365`, 0.5780748076334399, 0.95119288395803], 
             UndirectedEdge[18, 103] -> 
             RGBColor[
              0.3815755100901777, 0.5049232611225005, 0.945534631982339], 
             UndirectedEdge[146, 155] -> 
             RGBColor[
              0.8254933003150737, 0.8632665111600212, 0.9208909985256208], 
             UndirectedEdge[77, 166] -> 
             RGBColor[
              0.9629390837690771, 0.9685858980569739, 0.7534896993428217], 
             UndirectedEdge[85, 159] -> 
             RGBColor[
              0.7480352751851138, 0.8027427416966497, 0.975415038872788], 
             UndirectedEdge[39, 88] -> 
             RGBColor[
              0.3911372311222354, 0.49712883810015673`, 0.9477089344219567], 
             UndirectedEdge[66, 80] -> 
             RGBColor[
              0.6243681079550147, 0.7056593985469881, 0.963756144423739], 
             UndirectedEdge[62, 141] -> 
             RGBColor[
              0.9761756204929832, 0.9799901209705028, 0.8462943054021924], 
             UndirectedEdge[91, 103] -> 
             RGBColor[
              0.4317683619141647, 0.547620056198603, 0.9489477653456777], 
             UndirectedEdge[149, 189] -> 
             RGBColor[
              0.9196716745759335, 0.7894987615752589, 0.6082233347291179], 
             UndirectedEdge[4, 69] -> 
             RGBColor[
              0.8985808044623806, 0.9169955943163317, 0.7150242065685465], 
             UndirectedEdge[23, 169] -> 
             RGBColor[
              0.7417004334941983, 0.7974414959709364, 0.9706695517823913], 
             UndirectedEdge[32, 152] -> 
             RGBColor[
              0.6793435602535609, 0.7474589494666097, 0.9701982019002326], 
             UndirectedEdge[100, 124] -> 
             RGBColor[
              0.7469417363301458, 0.8024249012207813, 0.975419979599506], 
             UndirectedEdge[129, 139] -> 
             RGBColor[
              0.7997254923856923, 0.8321532932857387, 0.6834956349882749], 
             UndirectedEdge[29, 73] -> 
             RGBColor[
              0.5322569729485028, 0.6310248317055589, 0.9563547324225092], 
             UndirectedEdge[32, 178] -> 
             RGBColor[
              0.6113188593326645, 0.6938921938183733, 0.9635310082029649], 
             UndirectedEdge[8, 61] -> 
             RGBColor[
              0.7207572999848257, 0.7777989175897171, 0.8820303525929022], 
             UndirectedEdge[10, 27] -> 
             RGBColor[
              0.5014681378836364, 0.6042054742697451, 0.9544347870286866], 
             UndirectedEdge[72, 160] -> 
             RGBColor[
              0.5632044162860704, 0.6562737430676722, 0.9587566612172455], 
             UndirectedEdge[72, 144] -> 
             RGBColor[
              0.7535686818887216, 0.8019170387999727, 0.7155084373846057], 
             UndirectedEdge[134, 135] -> 
             RGBColor[
              0.8290101961554619, 0.8221356501198431, 0.6373923527337879], 
             UndirectedEdge[95, 150] -> 
             RGBColor[
              0.7474677964054651, 0.37175057670510114`, 0.4368195547355588], 
             UndirectedEdge[68, 71] -> 
             RGBColor[
              0.8765730365493899, 0.7968299536586056, 0.6195911699586965], 
             UndirectedEdge[118, 123] -> 
             RGBColor[
              0.5295236593966532, 0.6289301873240365, 0.9561051886582328], 
             UndirectedEdge[89, 168] -> 
             RGBColor[
              0.4406812890333651, 0.554855971956761, 0.9496494236176289], 
             UndirectedEdge[44, 99] -> 
             RGBColor[
              0.6438755037117763, 0.7164735107451323, 0.9682238269710272], 
             UndirectedEdge[121, 180] -> 
             RGBColor[
              0.8391302236122864, 0.8751215637168784, 0.9843701384491796], 
             UndirectedEdge[10, 141] -> 
             RGBColor[
              0.8080800882307019, 0.8478025621871621, 0.8495928471399475], 
             UndirectedEdge[6, 170] -> 
             RGBColor[
              0.6580958903417773, 0.5662281940945957, 0.588678763577825], 
             UndirectedEdge[12, 77] -> 
             RGBColor[
              0.993674771957967, 0.9888793017337734, 0.5529161462864377], 
             UndirectedEdge[112, 143] -> 
             RGBColor[
              0.8763573100651916, 0.8998360643785152, 0.7289589360433187], 
             UndirectedEdge[67, 125] -> 
             RGBColor[
              0.7736118406301092, 0.8236394502357036, 0.9779191321221156], 
             UndirectedEdge[3, 10] -> 
             RGBColor[
              0.8076852811404203, 0.8465417864959476, 0.7763582267609924], 
             UndirectedEdge[124, 125] -> 
             RGBColor[
              0.7618033682022023, 0.8142751630673086, 0.9768374953145981], 
             UndirectedEdge[11, 174] -> 
             RGBColor[
              0.9900661622973838, 0.9898582783593841, 0.7923524410660858], 
             UndirectedEdge[71, 87] -> 
             RGBColor[
              0.6813937324867345, 0.7494165411089957, 0.9700221662920292], 
             UndirectedEdge[7, 192] -> 
             RGBColor[
              0.4577615563378007, 0.5700110134821936, 0.9506380253790372], 
             UndirectedEdge[56, 148] -> 
             RGBColor[
              0.48006197688669516`, 0.5866440903518781, 0.9528001509072066], 
             UndirectedEdge[30, 71] -> 
             RGBColor[
              0.7190047106297762, 0.7799508275207736, 0.972983040265002], 
             UndirectedEdge[35, 86] -> 
             RGBColor[
              0.8610647093916957, 0.8915048170246265, 0.9450287318207136], 
             UndirectedEdge[68, 127] -> 
             RGBColor[
              0.8104284509562749, 0.7450594249379815, 0.6130244690344833], 
             UndirectedEdge[10, 30] -> 
             RGBColor[
              0.6136383955907412, 0.6972183194920796, 0.9627270088138626], 
             UndirectedEdge[89, 176] -> 
             RGBColor[
              0.4758820893591158, 0.5853451359552587, 0.9518923874875402], 
             UndirectedEdge[71, 76] -> 
             RGBColor[
              0.7457662315254796, 0.8014153909295855, 0.9752686932315269], 
             UndirectedEdge[49, 119] -> 
             RGBColor[
              0.7980541946270097, 0.8378941779966582, 0.7076833160461281], 
             UndirectedEdge[87, 106] -> 
             RGBColor[
              0.735998213556181, 0.7928121769431731, 0.9702206521409508], 
             UndirectedEdge[86, 196] -> 
             RGBColor[
              0.8264751366309926, 0.8644831798934756, 0.9415811664658622], 
             UndirectedEdge[53, 123] -> 
             RGBColor[
              0.6787729592823202, 0.7474866143769827, 0.969639711947111], 
             UndirectedEdge[68, 102] -> 
             RGBColor[
              0.729798178098203, 0.6804801246543045, 0.6060753062856601], 
             UndirectedEdge[107, 130] -> 
             RGBColor[
              0.4940274264797938, 0.5981647695518768, 0.9538490269707521], 
             UndirectedEdge[42, 157] -> 
             RGBColor[
              0.6391578430178888, 0.7148840412128434, 0.9667738393617474], 
             UndirectedEdge[96, 99] -> 
             RGBColor[
              0.6706173670257358, 0.7371788784607838, 0.9493526113215597], 
             UndirectedEdge[62, 194] -> 
             RGBColor[
              0.9027137348493375, 0.9246999206101035, 0.9710450940369549], 
             UndirectedEdge[57, 117] -> 
             RGBColor[
              0.9933198293913039, 0.9912525430644379, 0.7419772566036562], 
             UndirectedEdge[102, 128] -> 
             RGBColor[
              0.5661048692672137, 0.6586284614616821, 0.9589849955006304], 
             UndirectedEdge[46, 47] -> 
             RGBColor[
              0.5617021425643117, 0.6550541295836885, 0.9586383967268586], 
             UndirectedEdge[28, 105] -> 
             RGBColor[
              0.5671186918542181, 0.6571885822046454, 0.9601764448840103], 
             UndirectedEdge[40, 182] -> 
             RGBColor[
              0.5375261036909106, 0.6326958973778105, 0.9578087831631645], 
             UndirectedEdge[79, 179] -> 
             RGBColor[
              0.7294617369254215, 0.7885803200914586, 0.9736695867953704], 
             UndirectedEdge[36, 63] -> 
             RGBColor[
              0.9659228276719916, 0.9717295678615019, 0.8176995626826287], 
             UndirectedEdge[118, 129] -> 
             RGBColor[
              0.7506959975792445, 0.7923489406482942, 0.6796358535561541], 
             UndirectedEdge[74, 161] -> 
             RGBColor[
              0.5404891006689593, 0.6378324265363944, 0.9569684283629236], 
             UndirectedEdge[66, 187] -> 
             RGBColor[
              0.4851706426336314, 0.5909744334319968, 0.9531517885029139], 
             UndirectedEdge[10, 29] -> 
             RGBColor[
              0.6185688153479594, 0.7012210563638682, 0.9631151495178736], 
             UndirectedEdge[30, 147] -> 
             RGBColor[
              0.5166995356786245, 0.6178175063937348, 0.9552894475596942], 
             UndirectedEdge[109, 116] -> 
             RGBColor[
              0.9032786034265925, 0.8180421352460638, 0.6221199835548253], 
             UndirectedEdge[81, 154] -> 
             RGBColor[
              0.7034047291094033, 0.7668460009876983, 0.972261452141056], 
             UndirectedEdge[89, 188] -> 
             RGBColor[
              0.5726743904663061, 0.6639128332469075, 0.9595357158746624], 
             UndirectedEdge[24, 163] -> 
             RGBColor[
              0.9196073256984958, 0.9336359548973633, 0.7170630697452427], 
             UndirectedEdge[91, 159] -> 
             RGBColor[
              0.709234453455518, 0.7712424866594646, 0.9723604960541411], 
             UndirectedEdge[121, 164] -> 
             RGBColor[
              0.6389781578922777, 0.7161266312150314, 0.9658592935342046], 
             UndirectedEdge[4, 54] -> 
             RGBColor[
              0.7637175346944756, 0.8153412096623494, 0.9770838845783589], 
             UndirectedEdge[51, 130] -> 
             RGBColor[
              0.5781402665411886, 0.6683993391571632, 0.9599324660611506], 
             UndirectedEdge[69, 186] -> 
             RGBColor[
              0.959051584945213, 0.965087736534801, 0.7208252984045005], 
             UndirectedEdge[137, 179] -> 
             RGBColor[
              0.5718939546160091, 0.6632751387220849, 0.9594770813532628], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.9000844700747641, 0.9221353725440798, 0.9545669433721453], 
             UndirectedEdge[22, 176] -> 
             RGBColor[
              0.6779947172584064, 0.6114628972606424, 0.5958192143089687], 
             UndirectedEdge[128, 198] -> 
             RGBColor[
              0.654843635077069, 0.7295421780661212, 0.9667423370487125], 
             UndirectedEdge[107, 131] -> 
             RGBColor[
              0.5997217475784142, 0.6812836070871295, 0.9640078636945333], 
             UndirectedEdge[26, 125] -> 
             RGBColor[
              0.6863018472053299, 0.7529796270172877, 0.9708937390105399], 
             UndirectedEdge[47, 105] -> 
             RGBColor[
              0.6239229535914925, 0.7043739336748175, 0.9643528909258643], 
             UndirectedEdge[23, 60] -> 
             RGBColor[
              0.661438933992118, 0.7303336181326163, 0.9648893043287474], 
             UndirectedEdge[43, 111] -> 
             RGBColor[
              0.8399243848921889, 0.8711727535427978, 0.7091778828411957], 
             UndirectedEdge[73, 142] -> 
             RGBColor[
              0.5066528223805046, 0.6102382288206196, 0.9543390798987025], 
             UndirectedEdge[43, 115] -> 
             RGBColor[
              0.6082199360034359, 0.6921335415077201, 0.9627693524443254], 
             UndirectedEdge[61, 122] -> 
             RGBColor[
              0.6631475910289509, 0.7342429182322063, 0.9689560738285009], 
             UndirectedEdge[64, 65] -> 
             RGBColor[
              0.7053108936618017, 0.7675928917393144, 0.9595991978573831], 
             UndirectedEdge[147, 157] -> 
             RGBColor[
              0.4361135103269916, 0.552161335768034, 0.9490097451313688], 
             UndirectedEdge[53, 69] -> 
             RGBColor[
              0.9027576120686737, 0.9202585481632812, 0.7154405117162554], 
             UndirectedEdge[27, 188] -> 
             RGBColor[
              0.5135686115231186, 0.6139801224126471, 0.9554209242393723], 
             UndirectedEdge[88, 159] -> 
             RGBColor[
              0.7699275777086777, 0.8205158991222685, 0.9771384811215895], 
             UndirectedEdge[16, 61] -> 
             RGBColor[
              0.5776250204440656, 0.6669884945104785, 0.9605496855455204], 
             UndirectedEdge[138, 185] -> 
             RGBColor[
              0.7316854814271232, 0.7621438264010795, 0.6561895901648065], 
             UndirectedEdge[26, 128] -> 
             RGBColor[
              0.5379604093777087, 0.6357795210299126, 0.956769360521575], 
             UndirectedEdge[68, 75] -> 
             RGBColor[
              0.7589242526919605, 0.7041259841242246, 0.6083682175700074], 
             UndirectedEdge[10, 107] -> 
             RGBColor[
              0.5014681378836364, 0.6042054742697451, 0.9544347870286866], 
             UndirectedEdge[69, 123] -> 
             RGBColor[
              0.7687345234691323, 0.8140634453654132, 0.7031046515552708], 
             UndirectedEdge[109, 113] -> 
             RGBColor[
              0.8442849820867981, 0.7714258727526865, 0.6163806956500149], 
             UndirectedEdge[49, 196] -> 
             RGBColor[
              0.6371408165193461, 0.7158609084020504, 0.9648764874092639], 
             UndirectedEdge[8, 26] -> 
             RGBColor[
              0.7361670455857969, 0.7903603638611079, 0.8832293394426527], 
             UndirectedEdge[30, 73] -> 
             RGBColor[
              0.5273265531912846, 0.6270220948337704, 0.9559665917184983], 
             UndirectedEdge[46, 144] -> 
             RGBColor[
              0.7944104211381913, 0.8350742026220779, 0.7187236487065443], 
             UndirectedEdge[81, 176] -> 
             RGBColor[
              0.6724424445055927, 0.7416730152241856, 0.9698340473966662], 
             UndirectedEdge[104, 181] -> 
             RGBColor[
              0.9117888352794858, 0.931468115651795, 0.9556833161739817], 
             UndirectedEdge[65, 171] -> 
             RGBColor[
              0.7318660293984673, 0.7891515472255718, 0.9616897154172408], 
             UndirectedEdge[67, 82] -> 
             RGBColor[
              0.5192251280067589, 0.6183990360807845, 0.9559847129393098], 
             UndirectedEdge[13, 63] -> 
             RGBColor[
              0.8441457001269794, 0.8790787071857293, 0.9833902252350663], 
             UndirectedEdge[153, 182] -> 
             RGBColor[
              0.6872958546882446, 0.7461969712517569, 0.7133846035992357], 
             UndirectedEdge[87, 157] -> 
             RGBColor[
              0.4877190220097126, 0.5947584945296911, 0.952878499151393], 
             UndirectedEdge[30, 157] -> 
             RGBColor[
              0.5253300001527543, 0.6252927809414688, 0.9558393731243657], 
             UndirectedEdge[64, 185] -> 
             RGBColor[
              0.7178078693401913, 0.7508773557296082, 0.655097093705955], 
             UndirectedEdge[9, 103] -> 
             RGBColor[
              0.5050392364265769, 0.6071046529430602, 0.9547159169873518], 
             UndirectedEdge[18, 117] -> 
             RGBColor[
              0.6866132477585567, 0.7478693716418601, 0.8667814701112548], 
             UndirectedEdge[52, 66] -> 
             RGBColor[
              0.7674872765449992, 0.8182143904503809, 0.9683538162030051], 
             UndirectedEdge[128, 162] -> 
             RGBColor[
              0.4876207848859069, 0.5929635692900447, 0.9533446726761798], 
             UndirectedEdge[23, 177] -> 
             RGBColor[
              0.9670805695589235, 0.9714389776027086, 0.7241722836286921], 
             UndirectedEdge[11, 110] -> 
             RGBColor[
              0.7765229992040061, 0.8240948700284542, 0.9270282255127569], 
             UndirectedEdge[79, 177] -> 
             RGBColor[
              0.9029763975344454, 0.9205242352563221, 0.7230529305764447], 
             UndirectedEdge[8, 166] -> 
             RGBColor[
              0.9613222047361261, 0.9696158291432104, 0.9037523774372322], 
             UndirectedEdge[162, 173] -> 
             RGBColor[
              0.6147255747935974, 0.6932301486795183, 0.9654434807283625], 
             UndirectedEdge[100, 137] -> 
             RGBColor[
              0.6792920604095212, 0.747503846725248, 0.9700943493021063], 
             UndirectedEdge[88, 117] -> 
             RGBColor[
              0.7974992238357033, 0.8398395791807666, 0.8749725885420421], 
             UndirectedEdge[149, 168] -> 
             RGBColor[
              0.6389312695070675, 0.5634343534467747, 0.590353162744994], 
             UndirectedEdge[36, 110] -> 
             RGBColor[
              0.7811806776385484, 0.8253597454332182, 0.801776592676527], 
             UndirectedEdge[76, 104] -> 
             RGBColor[
              0.7536573533964055, 0.8077075573106647, 0.9760213554800634], 
             UndirectedEdge[4, 196] -> 
             RGBColor[
              0.7376883017317484, 0.7950069750423694, 0.974489533893646], 
             UndirectedEdge[61, 79] -> 
             RGBColor[
              0.6322646408584703, 0.7096733812547071, 0.9659956522721447], 
             UndirectedEdge[76, 147] -> 
             RGBColor[
              0.5434610565743279, 0.6392820698025468, 0.9575751005262192], 
             UndirectedEdge[2, 120] -> 
             RGBColor[
              0.7924448542638045, 0.8377832100456244, 0.9799471553209649], 
             UndirectedEdge[87, 176] -> 
             RGBColor[
              0.4913355899799915, 0.597890983931555, 0.9531089436644535], 
             UndirectedEdge[142, 157] -> 
             RGBColor[
              0.5046562693419743, 0.608508914928318, 0.9542118613045698], 
             UndirectedEdge[65, 191] -> 
             RGBColor[
              0.8823639873998721, 0.9087007762219044, 0.9753368373237141], 
             UndirectedEdge[73, 147] -> 
             RGBColor[
              0.43811006336552194`, 0.5538906496603355, 0.9491369637255014], 
             UndirectedEdge[26, 120] -> 
             RGBColor[
              0.6258068100417506, 0.7051517106288613, 0.9650150834686999], 
             UndirectedEdge[113, 116] -> 
             RGBColor[
              0.8265627584491313, 0.8649663732354789, 0.9832070642166117], 
             UndirectedEdge[35, 94] -> 
             RGBColor[
              0.6000842485337456, 0.6847169808534932, 0.9626838061161052], 
             UndirectedEdge[31, 45] -> 
             RGBColor[
              0.7515788543073203, 0.8061134186268053, 0.9758063350259825], 
             UndirectedEdge[52, 82] -> 
             RGBColor[
              0.6638921440015455, 0.7321632181408846, 0.96073665968243], 
             UndirectedEdge[95, 162] -> 
             RGBColor[
              0.6795648198760619, 0.31532523016217684`, 0.43183280488284537`],
              UndirectedEdge[17, 73] -> 
             RGBColor[
              0.6685072759191609, 0.7384237990335506, 0.9695100000553925], 
             UndirectedEdge[103, 152] -> 
             RGBColor[
              0.6270918837641704, 0.7030907077781384, 0.9666229903175101], 
             UndirectedEdge[88, 103] -> 
             RGBColor[
              0.4924614861673243, 0.5968934686614069, 0.9537257504131261], 
             UndirectedEdge[26, 170] -> 
             RGBColor[
              0.6855138788368289, 0.589190576809002, 0.590642905046314], 
             UndirectedEdge[89, 106] -> 
             RGBColor[
              0.7205447129353053, 0.7802663289668768, 0.9690040959640375], 
             UndirectedEdge[19, 74] -> 
             RGBColor[
              0.7105737991861237, 0.7714077972693896, 0.947735807880884], 
             UndirectedEdge[117, 152] -> 
             RGBColor[
              0.9321296214325494, 0.9460368182974981, 0.8878698284464259], 
             UndirectedEdge[157, 176] -> 
             RGBColor[
              0.44836054277140025`, 0.562769099717632, 0.949790115209101], 
             UndirectedEdge[49, 139] -> 
             RGBColor[
              0.6078519499839472, 0.6925206222720803, 0.9622714786192471], 
             UndirectedEdge[48, 106] -> 
             RGBColor[
              0.7168890594294817, 0.7772985047655354, 0.968716309528959], 
             UndirectedEdge[69, 118] -> 
             RGBColor[
              0.7535083121830068, 0.801702121110335, 0.7019059884273773], 
             UndirectedEdge[117, 200] -> 
             RGBColor[
              0.9384978215553306, 0.9511146482152164, 0.8884772330590962], 
             UndirectedEdge[64, 153] -> 
             RGBColor[
              0.7265356900190876, 0.7800016141109551, 0.7159354753820127], 
             UndirectedEdge[73, 87] -> 
             RGBColor[
              0.4897155750482429, 0.5964878084219924, 0.9530057177455256], 
             UndirectedEdge[132, 138] -> 
             RGBColor[
              0.7390773330408809, 0.79267030313888, 0.881252739784306], 
             UndirectedEdge[6, 96] -> 
             RGBColor[
              0.693539003022486, 0.7570324474862455, 0.9508131576984657], 
             UndirectedEdge[34, 65] -> 
             RGBColor[
              0.8034609819253002, 0.8470611486601166, 0.9674725231285175], 
             UndirectedEdge[2, 16] -> 
             RGBColor[
              0.7596728102670908, 0.8121814401986323, 0.976680744247536], 
             UndirectedEdge[21, 122] -> 
             RGBColor[
              0.8982785507338977, 0.9217269495062462, 0.9901598041433697], 
             UndirectedEdge[90, 175] -> 
             RGBColor[
              0.9014707164153932, 0.9196610630297044, 0.7479787563683411], 
             UndirectedEdge[6, 179] -> 
             RGBColor[
              0.5366241210447097, 0.6339382744531911, 0.9568948138781154], 
             UndirectedEdge[8, 137] -> 
             RGBColor[
              0.7440188906620446, 0.7967348454155954, 0.8838474654493111], 
             UndirectedEdge[3, 127] -> 
             RGBColor[
              0.8469070105863403, 0.8775037658040175, 0.7800475572879184], 
             UndirectedEdge[31, 65] -> 
             RGBColor[
              0.9010522479317868, 0.9235552257257662, 0.977131829148009], 
             UndirectedEdge[3, 71] -> 
             RGBColor[
              0.9130515961794553, 0.9292742945246415, 0.7866142582121318], 
             UndirectedEdge[146, 184] -> 
             RGBColor[
              0.9487122197684641, 0.9602616846109495, 0.932977098716788], 
             UndirectedEdge[33, 99] -> 
             RGBColor[
              0.44164002504399413`, 0.5556343170407547, 0.9497248988283514], 
             UndirectedEdge[10, 130] -> 
             RGBColor[
              0.6139200542732526, 0.6974469826991214, 0.9627491820170997], 
             UndirectedEdge[112, 160] -> 
             RGBColor[
              0.6859695518714077, 0.7541425203692471, 0.9696501363106316], 
             UndirectedEdge[73, 157] -> 
             RGBColor[
              0.4467405278396517, 0.5613659242080695, 0.9496868892901729], 
             UndirectedEdge[157, 188] -> 
             RGBColor[
              0.5451528438785904, 0.6413367970092809, 0.9574334435962231], 
             UndirectedEdge[70, 132] -> 
             RGBColor[
              0.962065892816989, 0.9701579796991266, 0.9016153964306639], 
             UndirectedEdge[141, 191] -> 
             RGBColor[
              0.9044803895061567, 0.9234328763817057, 0.858981203342708], 
             UndirectedEdge[26, 80] -> 
             RGBColor[
              0.5711125999033628, 0.6624241779773599, 0.959563675748559], 
             UndirectedEdge[171, 199] -> 
             RGBColor[
              0.4473704811576865, 0.5602865594679561, 0.9501760213249737], 
             UndirectedEdge[23, 43] -> 
             RGBColor[
              0.8142159757114751, 0.855627051538308, 0.9768471455165659], 
             UndirectedEdge[75, 81] -> 
             RGBColor[
              0.7448518031549063, 0.8004946028672453, 0.9755243176355528], 
             UndirectedEdge[33, 172] -> 
             RGBColor[
              0.44164002504399413`, 0.5556343170407547, 0.9497248988283514], 
             UndirectedEdge[156, 166] -> 
             RGBColor[
              0.8757039259191208, 0.9037357805519641, 0.9880041684830996], 
             UndirectedEdge[151, 175] -> 
             RGBColor[
              0.8925910094101628, 0.8902119351543922, 0.6706084854045731], 
             UndirectedEdge[34, 199] -> 
             RGBColor[
              0.5189654336845193, 0.618196160902501, 0.9559588290362503], 
             UndirectedEdge[38, 169] -> 
             RGBColor[
              0.7393031011336115, 0.7956535694216822, 0.9747276101444463], 
             UndirectedEdge[10, 142] -> 
             RGBColor[
              0.5929646647799611, 0.6804344534789288, 0.9610994969940667], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.6050651384194434, 0.6902091016218309, 0.9620856342047526], 
             UndirectedEdge[12, 128] -> 
             RGBColor[
              0.7938512567169278, 0.8353283899888148, 0.7767188454597704], 
             UndirectedEdge[19, 172] -> 
             RGBColor[
              0.6730018869264339, 0.7389572494984314, 0.9453162411120717], 
             UndirectedEdge[109, 124] -> 
             RGBColor[
              0.7771293140658928, 0.7188239357327748, 0.6097825676347369], 
             UndirectedEdge[75, 127] -> 
             RGBColor[
              0.6483000263046208, 0.7244782052193723, 0.9660573516644104], 
             UndirectedEdge[4, 191] -> 
             RGBColor[
              0.8093019004486401, 0.8509520626435141, 0.9816273081466163], 
             UndirectedEdge[68, 172] -> 
             RGBColor[
              0.6513140937168961, 0.6148152324826671, 0.6004349834612095], 
             UndirectedEdge[97, 105] -> 
             RGBColor[
              0.8496866262013973, 0.8826681544961987, 0.9465260183094615], 
             UndirectedEdge[120, 136] -> 
             RGBColor[
              0.8058409517477754, 0.8484289013782664, 0.9812344385394339], 
             UndirectedEdge[117, 159] -> 
             RGBColor[
              0.9640793392999101, 0.9714918021027217, 0.8901942008197183], 
             UndirectedEdge[183, 192] -> 
             RGBColor[
              0.6878894611440564, 0.2714267624200159, 0.4256648048496646], 
             UndirectedEdge[71, 188] -> 
             RGBColor[
              0.7388275543556124, 0.7959948435885855, 0.9745771107368593], 
             UndirectedEdge[14, 106] -> 
             RGBColor[
              0.9676450666155242, 0.97264637972737, 0.7856143045676598], 
             UndirectedEdge[141, 194] -> 
             RGBColor[
              0.9213375251406628, 0.9368272365969352, 0.8606015408396235], 
             UndirectedEdge[50, 105] -> 
             RGBColor[
              0.6857983598001937, 0.7544701580272736, 0.969317629420986], 
             UndirectedEdge[98, 125] -> 
             RGBColor[
              0.635962222713528, 0.7101636752774196, 0.9674690511651449], 
             UndirectedEdge[118, 119] -> 
             RGBColor[
              0.7535291875600381, 0.8017467714309806, 0.7041781443893411], 
             UndirectedEdge[137, 166] -> 
             RGBColor[
              0.7152617633003582, 0.7761851114388266, 0.9735251716743671], 
             UndirectedEdge[6, 112] -> 
             RGBColor[
              0.5935586014638748, 0.6784159232747207, 0.9625695108033281], 
             UndirectedEdge[65, 119] -> 
             RGBColor[
              0.9716637667906439, 0.9747889582153675, 0.7110058917076081], 
             UndirectedEdge[170, 183] -> 
             RGBColor[
              0.8411369995332921, 0.28535999633858916`, 0.1857792674731663], 
             UndirectedEdge[14, 131] -> 
             RGBColor[
              0.9059278802018205, 0.9235963686818831, 0.7847328639334457], 
             UndirectedEdge[9, 164] -> 
             RGBColor[
              0.577748984971401, 0.6680816791517759, 0.9599016629426653], 
             UndirectedEdge[96, 170] -> 
             RGBColor[
              0.9242161112805851, 0.7786302424074172, 0.5910361965401396], 
             UndirectedEdge[117, 178] -> 
             RGBColor[
              0.864104920511653, 0.8924700626492617, 0.8812026347491583], 
             UndirectedEdge[18, 24] -> 
             RGBColor[
              0.6140354926158418, 0.6926798958827576, 0.9653776600742046], 
             UndirectedEdge[18, 133] -> 
             RGBColor[
              0.4370996504116456, 0.5519482363726679, 0.9493674639053526], 
             UndirectedEdge[49, 129] -> 
             RGBColor[
              0.795221004646216, 0.8284963472139718, 0.6831410252129411], 
             UndirectedEdge[124, 198] -> 
             RGBColor[
              0.6746395057700142, 0.7456133576884659, 0.9683007405043248], 
             UndirectedEdge[113, 124] -> 
             RGBColor[
              0.7004134690884316, 0.76574817372219, 0.9708696482965233], 
             UndirectedEdge[176, 188] -> 
             RGBColor[
              0.5487694118488693, 0.6444692864111449, 0.9576638881092836], 
             UndirectedEdge[37, 97] -> 
             RGBColor[
              0.7156351435199251, 0.7750023551113276, 0.9351652109410098], 
             UndirectedEdge[77, 143] -> 
             RGBColor[
              0.9931646447250131, 0.9877881911642596, 0.4973919451197439], 
             UndirectedEdge[79, 84] -> 
             RGBColor[
              0.5973347619676397, 0.6794188757862298, 0.9637699512765001], 
             UndirectedEdge[151, 199] -> 
             RGBColor[
              0.6785680340093483, 0.7170727128704099, 0.6525462219231781], 
             UndirectedEdge[48, 87] -> 
             RGBColor[
              0.5115849150916045, 0.6143667065659764, 0.9546929849947539], 
             UndirectedEdge[27, 30] -> 
             RGBColor[
              0.4937457677972824, 0.5979361063448351, 0.9538268537675151], 
             UndirectedEdge[5, 87] -> 
             RGBColor[
              0.7625855648504478, 0.8102378472538736, 0.7982188143238691], 
             UndirectedEdge[68, 81] -> 
             RGBColor[
              0.9069802278065604, 0.8210758225858544, 0.6224914350056254], 
             UndirectedEdge[155, 172] -> 
             RGBColor[
              0.523066895061245, 0.62140025370226, 0.9563676243759466], 
             UndirectedEdge[143, 188] -> 
             RGBColor[
              0.8192889561211856, 0.8552538325419035, 0.7232708958562691], 
             UndirectedEdge[102, 180] -> 
             RGBColor[
              0.7329214087363174, 0.7905601120047008, 0.9748715456770779], 
             UndirectedEdge[80, 136] -> 
             RGBColor[
              0.7511467416093875, 0.805701368726765, 0.9757830308192931], 
             UndirectedEdge[66, 78] -> 
             RGBColor[
              0.624465143250221, 0.7057352032570989, 0.9637658159951188], 
             UndirectedEdge[50, 101] -> 
             RGBColor[
              0.5164394897319337, 0.6162228742888559, 0.9557070665493448], 
             UndirectedEdge[41, 85] -> 
             RGBColor[
              0.7434309979085931, 0.799092269946351, 0.9756988990346132], 
             UndirectedEdge[5, 30] -> 
             RGBColor[
              0.8001965429934894, 0.8407721336656513, 0.8011796882968418], 
             UndirectedEdge[32, 133] -> 
             RGBColor[
              0.4893513269010361, 0.5963164780611392, 0.9529426754880752], 
             UndirectedEdge[159, 161] -> 
             RGBColor[
              0.780383279950623, 0.8290043092262979, 0.9779615923025747], 
             UndirectedEdge[3, 195] -> 
             RGBColor[
              0.7487002898181399, 0.798655113296943, 0.7717147121749599], 
             UndirectedEdge[173, 180] -> 
             RGBColor[
              0.88758738905843, 0.9132021073900811, 0.9891400715986509], 
             UndirectedEdge[129, 141] -> 
             RGBColor[
              0.9909469789161349, 0.9801232275924823, 0.5701079668934149], 
             UndirectedEdge[53, 199] -> 
             RGBColor[
              0.5971857789860197, 0.6793024891486756, 0.9637551020452173], 
             UndirectedEdge[88, 95] -> 
             RGBColor[
              0.753488803927493, 0.37663870185478115`, 0.43729355050337015`], 
             UndirectedEdge[93, 95] -> 
             RGBColor[
              0.8242165990186323, 0.4322901975999309, 0.44407064468128554`], 
             UndirectedEdge[3, 29] -> 
             RGBColor[
              0.8048933308112844, 0.8442751554428262, 0.7761384342038318], 
             UndirectedEdge[52, 125] -> 
             RGBColor[
              0.9182788566248958, 0.9374036322958038, 0.982671078865236], 
             UndirectedEdge[82, 136] -> 
             RGBColor[
              0.6119492762880043, 0.6910164036117736, 0.9651786748984681], 
             UndirectedEdge[116, 193] -> 
             RGBColor[
              0.6790162694815471, 0.7470995462058408, 0.970280276295131], 
             UndirectedEdge[19, 159] -> 
             RGBColor[
              0.9504679784677873, 0.962579679959293, 0.968728971820535], 
             UndirectedEdge[77, 99] -> 
             RGBColor[
              0.6874443001269461, 0.7465144810350033, 0.7295419735028471], 
             UndirectedEdge[53, 196] -> 
             RGBColor[
              0.7418651093380414, 0.7982699288893191, 0.974905839041355], 
             UndirectedEdge[58, 137] -> 
             RGBColor[
              0.7135828615378417, 0.7748464007459703, 0.9733650365254851], 
             UndirectedEdge[159, 200] -> 
             RGBColor[
              0.9109261754283051, 0.9317909681567185, 0.9906431256386437], 
             UndirectedEdge[3, 62] -> 
             RGBColor[
              0.9757808134027015, 0.9787293452792882, 0.7730596850232373], 
             UndirectedEdge[48, 157] -> 
             RGBColor[
              0.46860986788301334`, 0.5792448223520534, 0.9513741565394012], 
             UndirectedEdge[130, 168] -> 
             RGBColor[
              0.4940274264797938, 0.5981647695518768, 0.9538490269707521], 
             UndirectedEdge[140, 180] -> 
             RGBColor[
              0.883233630408754, 0.9097305384224597, 0.9887248062119987], 
             UndirectedEdge[146, 171] -> 
             RGBColor[
              0.7497968864115151, 0.8021528169257173, 0.9146993954746481], 
             UndirectedEdge[26, 100] -> 
             RGBColor[
              0.6714402153332735, 0.7411293651707603, 0.9694762232954478], 
             UndirectedEdge[45, 153] -> 
             RGBColor[
              0.822318009304559, 0.8576201519104116, 0.7235728035694764], 
             UndirectedEdge[165, 177] -> 
             RGBColor[
              0.9914982020477512, 0.9886618239578384, 0.6386046164095913], 
             UndirectedEdge[123, 139] -> 
             RGBColor[
              0.578553154203101, 0.668734539961481, 0.9599649700903536], 
             UndirectedEdge[13, 34] -> 
             RGBColor[
              0.7036583329417953, 0.768422504786316, 0.9710977446328024], 
             UndirectedEdge[48, 72] -> 
             RGBColor[
              0.5033219553191512, 0.607658463580603, 0.9540424945332473], 
             UndirectedEdge[127, 191] -> 
             RGBColor[
              0.75698279639847, 0.8100799809196031, 0.9764126288047206], 
             UndirectedEdge[58, 125] -> 
             RGBColor[
              0.9097781045931425, 0.9308963816065339, 0.9912566418562374], 
             UndirectedEdge[165, 169] -> 
             RGBColor[
              0.7661180659830259, 0.8146643423260661, 0.8851018845632905], 
             UndirectedEdge[119, 156] -> 
             RGBColor[
              0.9058018507366752, 0.9226650728652449, 0.7180140082761268], 
             UndirectedEdge[139, 191] -> 
             RGBColor[
              0.7132589029757141, 0.7754629420749621, 0.972368871437568], 
             UndirectedEdge[48, 81] -> 
             RGBColor[
              0.6926917696172057, 0.7581487378586069, 0.9714180887269664], 
             UndirectedEdge[85, 161] -> 
             RGBColor[
              0.5919108619628521, 0.679578928878724, 0.9610165377760971], 
             UndirectedEdge[30, 106] -> 
             RGBColor[
              0.7736091916992227, 0.8233464633549509, 0.9731815261139236], 
             UndirectedEdge[118, 195] -> 
             RGBColor[
              0.5088441155715311, 0.6121416020439694, 0.9544772192166542], 
             UndirectedEdge[132, 145] -> 
             RGBColor[
              0.7791013811458702, 0.8251636284533298, 0.8844035794640497], 
             UndirectedEdge[124, 137] -> 
             RGBColor[
              0.5656081251469016, 0.658225182206745, 0.9589458899838457], 
             UndirectedEdge[53, 182] -> 
             RGBColor[
              0.5971857789860197, 0.6793024891486756, 0.9637551020452173], 
             UndirectedEdge[31, 40] -> 
             RGBColor[
              0.7725072932917387, 0.8224628742234605, 0.9778922862365674], 
             UndirectedEdge[130, 157] -> 
             RGBColor[
              0.5256116588352657, 0.6255214441485106, 0.9558615463276028], 
             UndirectedEdge[83, 166] -> 
             RGBColor[
              0.877241365933071, 0.904952469385236, 0.9881532586769504], 
             UndirectedEdge[76, 176] -> 
             RGBColor[
              0.5557080890187365, 0.6498898337521448, 0.9583554706039512], 
             UndirectedEdge[100, 113] -> 
             RGBColor[
              0.8140974043510512, 0.8550268382406929, 0.9820181076147838], 
             UndirectedEdge[53, 118] -> 
             RGBColor[
              0.6635467479961947, 0.7351252901219045, 0.9684410488192174], 
             UndirectedEdge[18, 85] -> 
             RGBColor[
              0.47056918364376044`, 0.5791203112357881, 0.9520023081643247], 
             UndirectedEdge[90, 177] -> 
             RGBColor[
              0.9930893765813843, 0.9876272002158144, 0.4891994721868908], 
             UndirectedEdge[55, 165] -> 
             RGBColor[
              0.9699368429236352, 0.9761117432182906, 0.8915382780358507], 
             UndirectedEdge[9, 121] -> 
             RGBColor[
              0.6897321356838528, 0.7573309968268753, 0.969854832583904], 
             UndirectedEdge[70, 110] -> 
             RGBColor[
              0.7508166580301432, 0.8050413309645468, 0.9763343645203989], 
             UndirectedEdge[51, 147] -> 
             RGBColor[
              0.48864211803291446`, 0.5950392307766865, 0.9530806648649166], 
             UndirectedEdge[81, 188] -> 
             RGBColor[
              0.7692347456127828, 0.8202407125158344, 0.9774773757837882], 
             UndirectedEdge[63, 132] -> 
             RGBColor[
              0.9638371764026318, 0.971528291787624, 0.9003260491988526], 
             UndirectedEdge[68, 143] -> 
             RGBColor[
              0.9570344383149629, 0.8560889426119234, 0.3682849550781063], 
             UndirectedEdge[76, 81] -> 
             RGBColor[
              0.77617342278265, 0.8256612598568343, 0.9781689582784558], 
             UndirectedEdge[55, 163] -> 
             RGBColor[
              0.9712276196155216, 0.9744345988676506, 0.7094366825795813], 
             UndirectedEdge[86, 94] -> 
             RGBColor[
              0.7210356416098138, 0.7793203830120303, 0.9329813012525014], 
             UndirectedEdge[3, 167] -> 
             RGBColor[
              0.9112648655511826, 0.9278496040211677, 0.7864438382497738], 
             UndirectedEdge[16, 82] -> 
             RGBColor[
              0.5426951415532351, 0.6367339890420012, 0.9583239845498759], 
             UndirectedEdge[51, 107] -> 
             RGBColor[
              0.4656883501515724, 0.5751578307277869, 0.9516180710727374], 
             UndirectedEdge[53, 171] -> 
             RGBColor[
              0.6629807500535284, 0.7346657874941313, 0.968396491387852], 
             UndirectedEdge[78, 82] -> 
             RGBColor[
              0.5208700107067673, 0.6196840309476026, 0.9561486594745437], 
             UndirectedEdge[92, 186] -> 
             RGBColor[
              0.7059383614391863, 0.7686679168111149, 0.972731390846833], 
             UndirectedEdge[75, 118] -> 
             RGBColor[
              0.5555466380754172, 0.6500568137372869, 0.958153812865137], 
             UndirectedEdge[77, 83] -> 
             RGBColor[
              0.9076153723277085, 0.9244722722757683, 0.7482128743574838], 
             UndirectedEdge[42, 176] -> 
             RGBColor[
              0.6427744109881677, 0.7180165306147075, 0.9670042838748081], 
             UndirectedEdge[20, 144] -> 
             RGBColor[
              0.9608172032215754, 0.871129236953393, 0.3687905356398114], 
             UndirectedEdge[26, 98] -> 
             RGBColor[
              0.4319151345819796, 0.5477392128623685, 0.9489593198277341], 
             UndirectedEdge[16, 84] -> 
             RGBColor[
              0.5426951415532351, 0.6367339890420012, 0.9583239845498759], 
             UndirectedEdge[55, 175] -> 
             RGBColor[
              0.8796787619336821, 0.9066177621370273, 0.9758135363899381], 
             UndirectedEdge[113, 128] -> 
             RGBColor[
              0.6806175983954864, 0.7496769940998452, 0.969311244840911], 
             UndirectedEdge[142, 147] -> 
             RGBColor[
              0.4960258048678445, 0.601033640380584, 0.9536619357398983], 
             UndirectedEdge[10, 42] -> 
             RGBColor[
              0.7274662384558757, 0.7868095797634542, 0.9736614750512443], 
             UndirectedEdge[98, 120] -> 
             RGBColor[
              0.5754671855499487, 0.6623357588889933, 0.9615903956233048], 
             UndirectedEdge[195, 199] -> 
             RGBColor[
              0.442483146561356, 0.5563188010707406, 0.949791272442654], 
             UndirectedEdge[49, 195] -> 
             RGBColor[
              0.5533691226385027, 0.6482890086096471, 0.9579823908734412], 
             UndirectedEdge[25, 43] -> 
             RGBColor[
              0.5731575073859652, 0.6636682824116484, 0.9600091096256501], 
             UndirectedEdge[91, 121] -> 
             RGBColor[
              0.6164612611714406, 0.697846400082418, 0.9640866809422299], 
             UndirectedEdge[8, 21] -> 
             RGBColor[
              0.9558882596897726, 0.9652829488637571, 0.903234082907771], 
             UndirectedEdge[2, 124] -> 
             RGBColor[
              0.7243943242927078, 0.7844822000690205, 0.9732598358294523], 
             UndirectedEdge[80, 125] -> 
             RGBColor[
              0.7751596880349113, 0.824848640392411, 0.9780734070859698], 
             UndirectedEdge[33, 180] -> 
             RGBColor[
              0.7145018393088269, 0.7756062757513175, 0.9734214896986398], 
             UndirectedEdge[5, 155] -> 
             RGBColor[
              0.829517670257452, 0.8642362810230764, 0.8037204589052733], 
             UndirectedEdge[179, 192] -> 
             RGBColor[
              0.5374299217189551, 0.6346362184965029, 0.9569461587845367], 
             UndirectedEdge[59, 146] -> 
             RGBColor[
              0.956863729608839, 0.9667614772908244, 0.9337545970023018], 
             UndirectedEdge[3, 68] -> 
             RGBColor[
              0.9575312369736799, 0.8571515447088696, 0.42235842319351546`], 
             UndirectedEdge[131, 157] -> 
             RGBColor[
              0.631305979933886, 0.7086402816837633, 0.9660203830513839], 
             UndirectedEdge[85, 200] -> 
             RGBColor[
              0.7224537574405343, 0.7823655878091444, 0.973698071112166], 
             UndirectedEdge[23, 38] -> 
             RGBColor[
              0.9389050255334713, 0.9539560485934779, 0.9883020350372109], 
             UndirectedEdge[92, 191] -> 
             RGBColor[
              0.6503270487357186, 0.7243720277552081, 0.9674146453448177], 
             UndirectedEdge[97, 153] -> 
             RGBColor[
              0.9860481007312043, 0.9856945808870373, 0.7007654270547172], 
             UndirectedEdge[95, 161] -> 
             RGBColor[
              0.7604592720887897, 0.38229764192413396`, 0.43784229129069363`],
              UndirectedEdge[139, 196] -> 
             RGBColor[
              0.6416453042588224, 0.7195178544738174, 0.9652310971845977], 
             UndirectedEdge[1, 94] -> 
             RGBColor[
              0.4208153454210207, 0.5387279039816988, 0.9480855037651159], 
             UndirectedEdge[189, 194] -> 
             RGBColor[
              0.8954659798624633, 0.9192945568080024, 0.9833136527124863], 
             UndirectedEdge[42, 76] -> 
             RGBColor[
              0.746505389265225, 0.8020047752473561, 0.9753391947565977], 
             UndirectedEdge[84, 190] -> 
             RGBColor[
              0.432015017315323, 0.5478203021649626, 0.9489671829623854], 
             UndirectedEdge[37, 134] -> 
             RGBColor[
              0.5744262468369349, 0.6645216546358649, 0.9602172896752859], 
             UndirectedEdge[140, 161] -> 
             RGBColor[
              0.731713494463013, 0.7902171973548325, 0.9740424449534826], 
             UndirectedEdge[10, 51] -> 
             RGBColor[
              0.5855809779450312, 0.6744400438750314, 0.960518226119085], 
             UndirectedEdge[146, 191] -> 
             RGBColor[
              0.9002948444129198, 0.9217020459220497, 0.9283465173811214], 
             UndirectedEdge[21, 175] -> 
             RGBColor[
              0.8656593240867697, 0.8958010201490001, 0.9870263267742474], 
             UndirectedEdge[49, 141] -> 
             RGBColor[
              0.7990734365143898, 0.8404905565788239, 0.8488838105243871], 
             UndirectedEdge[111, 177] -> 
             RGBColor[
              0.9927889787396373, 0.9869846796071984, 0.45650302095332185`], 
             UndirectedEdge[69, 191] -> 
             RGBColor[
              0.9034402722417453, 0.9207918474788943, 0.7155085529024852], 
             UndirectedEdge[111, 175] -> 
             RGBColor[
              0.9011703185736463, 0.9190185424210885, 0.7152823051347722], 
             UndirectedEdge[77, 170] -> 
             RGBColor[
              0.9410430443817955, 0.7879658449816368, 0.37122555872142704`], 
             UndirectedEdge[104, 154] -> 
             RGBColor[
              0.6808886597231587, 0.7488922984415287, 0.9701138493426635], 
             UndirectedEdge[13, 138] -> 
             RGBColor[
              0.6193858567652285, 0.7002207185369853, 0.9643169158205196], 
             UndirectedEdge[21, 67] -> 
             RGBColor[
              0.7892859666025365, 0.8361375728233017, 0.9794141442498232], 
             UndirectedEdge[73, 197] -> 
             RGBColor[
              0.7064550955365358, 0.7679480914308217, 0.9476719332808439], 
             UndirectedEdge[67, 192] -> 
             RGBColor[
              0.5429525646777545, 0.6389505491495581, 0.9574966042226372], 
             UndirectedEdge[37, 101] -> 
             RGBColor[
              0.41688289747696544`, 0.5355047454760471, 0.9477843874855283], 
             UndirectedEdge[6, 44] -> 
             RGBColor[
              0.6667971397085264, 0.7363270797705941, 0.9696843733479332], 
             UndirectedEdge[75, 89] -> 
             RGBColor[
              0.5482914480084295, 0.6441667235983184, 0.9575826577264268], 
             UndirectedEdge[76, 188] -> 
             RGBColor[
              0.6525003901259268, 0.7284575310437935, 0.9659987989910733], 
             UndirectedEdge[42, 71] -> 
             RGBColor[
              0.8328325534949108, 0.8695420877921481, 0.9839175065023837], 
             UndirectedEdge[6, 192] -> 
             RGBColor[
              0.4282245827579235, 0.545328343216736, 0.9485070696425726], 
             UndirectedEdge[2, 100] -> 
             RGBColor[
              0.8380782595553273, 0.8737608645875234, 0.9844082951477129], 
             UndirectedEdge[7, 8] -> 
             RGBColor[
              0.7382860306706225, 0.7920806514121594, 0.8833961537106283], 
             UndirectedEdge[69, 92] -> 
             RGBColor[
              0.7396059527494591, 0.7904155594280258, 0.7008115437667479], 
             UndirectedEdge[104, 160] -> 
             RGBColor[
              0.7300581611978805, 0.7888103147995065, 0.9739846526125722], 
             UndirectedEdge[17, 30] -> 
             RGBColor[
              0.7470967482322635, 0.80235065576695, 0.9756624838895853], 
             UndirectedEdge[88, 164] -> 
             RGBColor[
              0.5651712347121485, 0.6578704948701226, 0.9589114963684395], 
             UndirectedEdge[43, 60] -> 
             RGBColor[
              0.5343525518095349, 0.6302166945281922, 0.9574924731701575], 
             UndirectedEdge[149, 197] -> 
             RGBColor[
              0.9302300695594233, 0.7973731952661606, 0.5903507260925158], 
             UndirectedEdge[167, 197] -> 
             RGBColor[
              0.8963465223467546, 0.9194521336143511, 0.9645179618649897], 
             UndirectedEdge[54, 127] -> 
             RGBColor[
              0.7113984306443053, 0.7744691279384383, 0.9718692052364633], 
             UndirectedEdge[107, 147] -> 
             RGBColor[
              0.4045292779715197, 0.5248046611714002, 0.9469972257745182], 
             UndirectedEdge[78, 113] -> 
             RGBColor[
              0.7138668242163468, 0.7763974557574032, 0.9721152316392749], 
             UndirectedEdge[81, 87] -> 
             RGBColor[
              0.711800923743905, 0.7736624100362446, 0.9729224313389582], 
             UndirectedEdge[83, 179] -> 
             RGBColor[
              0.7338735572487218, 0.7920424966684942, 0.9741051683558459], 
             UndirectedEdge[82, 198] -> 
             RGBColor[
              0.5487983602813399, 0.641501869898577, 0.9589322963548716], 
             UndirectedEdge[30, 107] -> 
             RGBColor[
              0.4937457677972824, 0.5979361063448351, 0.9538268537675151], 
             UndirectedEdge[47, 134] -> 
             RGBColor[
              0.6121074328832019, 0.6951435590962176, 0.9631752302439807], 
             UndirectedEdge[5, 142] -> 
             RGBColor[
              0.7795228121827095, 0.8239882676525006, 0.7995521764770459], 
             UndirectedEdge[169, 190] -> 
             RGBColor[
              0.5122765168174035, 0.6149281800032826, 0.9547474304160293], 
             UndirectedEdge[121, 152] -> 
             RGBColor[
              0.8117847830214463, 0.8533170516619535, 0.9817619059140623], 
             UndirectedEdge[31, 64] -> 
             RGBColor[
              0.6557965350218489, 0.7284948808273488, 0.9681690068385188], 
             UndirectedEdge[105, 134] -> 
             RGBColor[
              0.7084777295184073, 0.7721874540207359, 0.9715780970437375], 
             UndirectedEdge[83, 192] -> 
             RGBColor[
              0.6254740189619357, 0.7034325654320391, 0.9657174241203031], 
             UndirectedEdge[77, 112] -> 
             RGBColor[
              0.8765057555038931, 0.9001535741617617, 0.7451163059469301], 
             UndirectedEdge[195, 196] -> 
             RGBColor[
              0.5871624769133779, 0.675286240811384, 0.9609420094387917], 
             UndirectedEdge[92, 171] -> 
             RGBColor[
              0.4998290907343138, 0.6048227987588757, 0.9537675234383444], 
             UndirectedEdge[166, 183] -> 
             RGBColor[
              0.8557343591248132, 0.40577336505548056`, 0.44062202788742943`],
              UndirectedEdge[139, 195] -> 
             RGBColor[
              0.5578736103779789, 0.651945954681414, 0.958337000648775], 
             UndirectedEdge[177, 190] -> 
             RGBColor[
              0.7376566528821287, 0.7889256616350548, 0.7082501622623301], 
             UndirectedEdge[29, 149] -> 
             RGBColor[
              0.7560319469713903, 0.6604499355408979, 0.5990335252341811], 
             UndirectedEdge[119, 155] -> 
             RGBColor[
              0.8286596035209304, 0.8624009630375113, 0.7103251900089484], 
             UndirectedEdge[12, 162] -> 
             RGBColor[
              0.6878059819211987, 0.7472880818212706, 0.7689088047659296], 
             UndirectedEdge[85, 173] -> 
             RGBColor[
              0.7037192483471801, 0.7674271987928059, 0.9719111569103482], 
             UndirectedEdge[92, 141] -> 
             RGBColor[
              0.7406460700138706, 0.793056588330837, 0.8442841942069707], 
             UndirectedEdge[5, 29] -> 
             RGBColor[
              0.8051269627507076, 0.8447748705374399, 0.8015678290008528], 
             UndirectedEdge[51, 87] -> 
             RGBColor[
              0.5402476297156356, 0.6376363895383437, 0.9569494188849408], 
             UndirectedEdge[145, 153] -> 
             RGBColor[
              0.7804373502110088, 0.8237614100968763, 0.7201788115206079], 
             UndirectedEdge[118, 191] -> 
             RGBColor[
              0.6642294081692663, 0.7356585894375175, 0.9685090900054472], 
             UndirectedEdge[117, 164] -> 
             RGBColor[
              0.7593229963033808, 0.8088463978505758, 0.8719672160665684], 
             UndirectedEdge[145, 185] -> 
             RGBColor[
              0.7717095295321126, 0.7946371517155293, 0.6593404298445502], 
             UndirectedEdge[99, 137] -> 
             RGBColor[
              0.4397669796582273, 0.5541136944168561, 0.9495774458343925], 
             UndirectedEdge[48, 176] -> 
             RGBColor[
              0.47222643585329216`, 0.5823773117539175, 0.9516046010524618], 
             UndirectedEdge[50, 144] -> 
             RGBColor[
              0.8221363417388678, 0.8574463361411446, 0.7210000146009147], 
             UndirectedEdge[3, 53] -> 
             RGBColor[
              0.9034029222428035, 0.9216388013748782, 0.7856785417775232], 
             UndirectedEdge[169, 177] -> 
             RGBColor[
              0.7674786451590638, 0.8131364984309128, 0.7105978587359276], 
             UndirectedEdge[20, 135] -> 
             RGBColor[
              0.9450116879199558, 0.8181012549386291, 0.28292240614993297`], 
             UndirectedEdge[166, 170] -> 
             RGBColor[
              0.910669037987158, 0.7684460420911046, 0.6111659430408936], 
             UndirectedEdge[17, 42] -> 
             RGBColor[
              0.860924591097398, 0.8919419160383245, 0.9865969501269669], 
             UndirectedEdge[129, 195] -> 
             RGBColor[
              0.7452426650402478, 0.7879216796233055, 0.679206547242469], 
             UndirectedEdge[74, 93] -> 
             RGBColor[
              0.6361250910637233, 0.7128212600500896, 0.9663109584488114], 
             UndirectedEdge[37, 45] -> 
             RGBColor[
              0.5519050520932798, 0.646927926134702, 0.957972587455769], 
             UndirectedEdge[49, 92] -> 
             RGBColor[
              0.5449200957439516, 0.6414297079523266, 0.9573172525264968], 
             UndirectedEdge[163, 177] -> 
             RGBColor[
              0.9927889787396373, 0.9869846796071984, 0.45650302095332185`], 
             UndirectedEdge[6, 45] -> 
             RGBColor[
              0.5395193007032423, 0.636200010806617, 0.9571833783294857], 
             UndirectedEdge[6, 166] -> 
             RGBColor[
              0.6799919297290589, 0.7468482471699328, 0.9709429041992197], 
             UndirectedEdge[65, 127] -> 
             RGBColor[
              0.8251854155703373, 0.8640324413354306, 0.9696378116478798], 
             UndirectedEdge[15, 59] -> 
             RGBColor[
              0.9309167692429536, 0.9477517790045271, 0.9932728665612451], 
             UndirectedEdge[100, 136] -> 
             RGBColor[
              0.8514743570392982, 0.8844065559201655, 0.9856955783661818], 
             UndirectedEdge[83, 183] -> 
             RGBColor[
              0.8188518848305675, 0.3763642812013435, 0.4371041445638708], 
             UndirectedEdge[53, 119] -> 
             RGBColor[
              0.902778487445705, 0.9203031984839269, 0.7177126676782193], 
             UndirectedEdge[5, 68] -> 
             RGBColor[
              0.9577648689131031, 0.8576512598034833, 0.44778781799053635`], 
             UndirectedEdge[49, 54] -> 
             RGBColor[
              0.6631700494820731, 0.7361951430220304, 0.9674708380939767], 
             UndirectedEdge[153, 185] -> 
             RGBColor[
              0.9842883786074152, 0.9583464229996661, 0.42039619354007485`], 
             UndirectedEdge[101, 144] -> 
             RGBColor[
              0.687272362097112, 0.7461467229747893, 0.7108275800339088], 
             UndirectedEdge[19, 102] -> 
             RGBColor[
              0.7514859713077409, 0.8046221416700688, 0.9509565639365221], 
             UndirectedEdge[102, 172] -> 
             RGBColor[
              0.4600595944714846, 0.5705881532941379, 0.9511749548067895], 
             UndirectedEdge[102, 140] -> 
             RGBColor[
              0.6888559005252282, 0.7554234718835342, 0.9706685381661606], 
             UndirectedEdge[71, 107] -> 
             RGBColor[
              0.6068344529226715, 0.6869379822984389, 0.964690818479826], 
             UndirectedEdge[5, 168] -> 
             RGBColor[
              0.6880262852863848, 0.7477592884433168, 0.7928874665116658], 
             UndirectedEdge[79, 122] -> 
             RGBColor[
              0.8439769640155823, 0.8784840274274583, 0.9849656921270173], 
             UndirectedEdge[136, 198] -> 
             RGBColor[
              0.7791721264791664, 0.8275950123878502, 0.9785763392710007], 
             UndirectedEdge[97, 135] -> 
             RGBColor[
              0.9702190928384521, 0.9326163505953059, 0.6123402739995119], 
             UndirectedEdge[19, 164] -> 
             RGBColor[
              0.7457116354712581, 0.7999342757071471, 0.9505019870673851], 
             UndirectedEdge[118, 139] -> 
             RGBColor[
              0.5633269429169756, 0.6563732157064028, 0.9587663069624601], 
             UndirectedEdge[26, 137] -> 
             RGBColor[
              0.49010660415002916`, 0.5969296461567241, 0.9530021336797876], 
             UndirectedEdge[142, 168] -> 
             RGBColor[
              0.47307203698650246`, 0.5811522403316843, 0.9521993419477193], 
             UndirectedEdge[3, 194] -> 
             RGBColor[
              0.9209427180503812, 0.9355664609057208, 0.7873669204606684], 
             UndirectedEdge[65, 195] -> 
             RGBColor[
              0.726978694802137, 0.7851837888283563, 0.9613049665349211], 
             UndirectedEdge[73, 107] -> 
             RGBColor[
              0.41515629548417987`, 0.5340092496114357, 0.9476743699333223], 
             UndirectedEdge[162, 172] -> 
             RGBColor[
              0.3815755100901777, 0.5049232611225005, 0.945534631982339], 
             UndirectedEdge[68, 140] -> 
             RGBColor[
              0.8801103997706397, 0.7996505510720634, 0.6199285668205807], 
             UndirectedEdge[38, 165] -> 
             RGBColor[
              0.9633226580222989, 0.9711788949486078, 0.9027343678181101], 
             UndirectedEdge[86, 92] -> 
             RGBColor[
              0.7342544158555981, 0.7900519794437516, 0.9340219315830951], 
             UndirectedEdge[90, 115] -> 
             RGBColor[
              0.7613151252084798, 0.8084386877252501, 0.735193372161114], 
             UndirectedEdge[11, 70] -> 
             RGBColor[
              0.9594938656518066, 0.9690943803682406, 0.9442405427506698], 
             UndirectedEdge[54, 123] -> 
             RGBColor[
              0.6338712537012271, 0.712409060711431, 0.9651643295650832], 
             UndirectedEdge[107, 176] -> 
             RGBColor[
              0.4167763104159284, 0.5354124251209983, 0.9477775958522503], 
             UndirectedEdge[30, 76] -> 
             RGBColor[
              0.6326775464000904, 0.7124135149759816, 0.9644047285192161], 
             UndirectedEdge[129, 191] -> 
             RGBColor[
              0.900627957637983, 0.9114386670168535, 0.693238418031262], 
             UndirectedEdge[7, 125] -> 
             RGBColor[
              0.6884208322901554, 0.7546999145683393, 0.9710605532785155], 
             UndirectedEdge[3, 155] -> 
             RGBColor[
              0.8292840383180289, 0.8637365659284626, 0.7782910641082524], 
             UndirectedEdge[54, 118] -> 
             RGBColor[
              0.6186450424151015, 0.7000477364563527, 0.9639656664371897], 
             UndirectedEdge[4, 171] -> 
             RGBColor[
              0.6588039424472354, 0.7314028336471816, 0.9679801862401429], 
             UndirectedEdge[167, 189] -> 
             RGBColor[
              0.8857881273632648, 0.9115776999234495, 0.9823905705015918], 
             UndirectedEdge[42, 81] -> 
             RGBColor[
              0.8632397447520812, 0.8937879567193969, 0.9868177715493127], 
             UndirectedEdge[5, 129] -> 
             RGBColor[
              0.9907858037652766, 0.9793621669958816, 0.5223027413114807], 
             UndirectedEdge[115, 133] -> 
             RGBColor[
              0.5109670346055467, 0.6138650833521959, 0.9546443431795205], 
             UndirectedEdge[92, 146] -> 
             RGBColor[
              0.7364605249206336, 0.7913257578711812, 0.9136495082453839], 
             UndirectedEdge[65, 151] -> 
             RGBColor[
              0.9630635822501292, 0.9459377006280255, 0.6640599160154452], 
             UndirectedEdge[45, 156] -> 
             RGBColor[
              0.7352312968933042, 0.7930875441886485, 0.9742446426133655], 
             UndirectedEdge[74, 172] -> 
             RGBColor[
              0.4191474223498675, 0.5373738088934585, 0.9479541987511513], 
             UndirectedEdge[31, 138] -> 
             RGBColor[
              0.6696741471087808, 0.7397613514988202, 0.9692615032973702], 
             UndirectedEdge[116, 198] -> 
             RGBColor[
              0.8007887951307139, 0.8448315572017548, 0.9806381564244132], 
             UndirectedEdge[42, 142] -> 
             RGBColor[
              0.6990701375587417, 0.7637563458253935, 0.971426029970277], 
             UndirectedEdge[10, 129] -> 
             RGBColor[
              0.8042276563625281, 0.8358083528223099, 0.6838500618285015], 
             UndirectedEdge[3, 141] -> 
             RGBColor[
              0.9944046036940271, 0.99085666126612, 0.6626161318259058], 
             UndirectedEdge[161, 162] -> 
             RGBColor[
              0.5029171884092695, 0.6053818787654363, 0.9545488615941113], 
             UndirectedEdge[6, 77] -> 
             RGBColor[
              0.7103659361236964, 0.766368050060465, 0.7310025198797532], 
             UndirectedEdge[98, 113] -> 
             RGBColor[
              0.5745723235997573, 0.6616366859323011, 0.9615012041470701], 
             UndirectedEdge[3, 139] -> 
             RGBColor[
              0.8031831171635844, 0.8428867269593765, 0.7760037999207658], 
             UndirectedEdge[34, 138] -> 
             RGBColor[
              0.5720828811022942, 0.6632672744331706, 0.9596021972778787], 
             UndirectedEdge[22, 72] -> 
             RGBColor[
              0.7090902367242655, 0.636744049087328, 0.5982571077897543], 
             UndirectedEdge[34, 40] -> 
             RGBColor[
              0.6749160272852522, 0.7459687971578111, 0.9682329802170759], 
             UndirectedEdge[41, 74] -> 
             RGBColor[
              0.6920092366147003, 0.7573457676040214, 0.9716507896214397], 
             UndirectedEdge[141, 146] -> 
             RGBColor[
              0.9906138656910718, 0.9903866064976785, 0.8052160662432744], 
             UndirectedEdge[90, 111] -> 
             RGBColor[
              0.9930195740972327, 0.9874778997603277, 0.48160190255798435`], 
             UndirectedEdge[66, 82] -> 
             RGBColor[
              0.4851706426336314, 0.5909744334319968, 0.9531517885029139], 
             UndirectedEdge[119, 151] -> 
             RGBColor[
              0.9841607424690336, 0.958073422205661, 0.40650378755618005`], 
             UndirectedEdge[4, 139] -> 
             RGBColor[
              0.7083994351963495, 0.7716666889123994, 0.9718845251036292], 
             UndirectedEdge[165, 175] -> 
             RGBColor[
              0.89987954188176, 0.9206956867717284, 0.8973839005910417], 
             UndirectedEdge[127, 139] -> 
             RGBColor[
              0.6560803311461794, 0.7307946071884883, 0.9666698457617335], 
             UndirectedEdge[85, 117] -> 
             RGBColor[
              0.7756069213121394, 0.8220664217551478, 0.8732491462932406], 
             UndirectedEdge[141, 155] -> 
             RGBColor[
              0.8296788454083106, 0.864997341619677, 0.8515256844872076], 
             UndirectedEdge[168, 189] -> 
             RGBColor[
              0.6623159151590436, 0.7309876692509847, 0.9634048039664628], 
             UndirectedEdge[24, 175] -> 
             RGBColor[
              0.8280584680166563, 0.86581911816674, 0.9834399235555995], 
             UndirectedEdge[106, 176] -> 
             RGBColor[
              0.6966397343178686, 0.7608227821311141, 0.9671322681986587], 
             UndirectedEdge[40, 53] -> 
             RGBColor[
              0.7531363725867526, 0.8070751254039856, 0.9760292532260428], 
             UndirectedEdge[27, 155] -> 
             RGBColor[
              0.523066895061245, 0.62140025370226, 0.9563676243759466], 
             UndirectedEdge[33, 77] -> 
             RGBColor[
              0.7475088150807626, 0.7972255369532575, 0.7337322403488595], 
             UndirectedEdge[67, 137] -> 
             RGBColor[
              0.5774165975748085, 0.6675894693751401, 0.9600275267913632], 
             UndirectedEdge[68, 129] -> 
             RGBColor[
              0.9540736121957879, 0.846418111035232, 0.32985025826102454`], 
             UndirectedEdge[137, 192] -> 
             RGBColor[
              0.46349441632922295`, 0.5746652074856298, 0.95108933711772], 
             UndirectedEdge[58, 128] -> 
             RGBColor[
              0.7614366667655212, 0.8136962756191589, 0.9771322633672724], 
             UndirectedEdge[55, 90] -> 
             RGBColor[
              0.9715280174572685, 0.9750771194762666, 0.7421331338131503], 
             UndirectedEdge[26, 82] -> 
             RGBColor[
              0.4319151345819796, 0.5477392128623685, 0.9489593198277341], 
             UndirectedEdge[43, 165] -> 
             RGBColor[
              0.8386336082003026, 0.8728498978934378, 0.8912794782974651], 
             UndirectedEdge[123, 199] -> 
             RGBColor[
              0.4631626903864783, 0.5731073863508076, 0.9514192418842327], 
             UndirectedEdge[34, 45] -> 
             RGBColor[
              0.6539875883008337, 0.7296193415611558, 0.966147029006491], 
             UndirectedEdge[133, 178] -> 
             RGBColor[
              0.614591323164742, 0.6965489273800693, 0.963788628543256], 
             UndirectedEdge[29, 189] -> 
             RGBColor[
              0.7794165926233667, 0.8280032513451079, 0.9720851664556498], 
             UndirectedEdge[91, 164] -> 
             RGBColor[
              0.5044781104589888, 0.6085970824073187, 0.9541335113009912], 
             UndirectedEdge[116, 124] -> 
             RGBColor[
              0.759407090428226, 0.8123644362155673, 0.9766089362013338], 
             UndirectedEdge[80, 113] -> 
             RGBColor[
              0.7137697889211405, 0.7763216510472923, 0.9721055600678952], 
             UndirectedEdge[10, 75] -> 
             RGBColor[
              0.6090782968587007, 0.6935162259113026, 0.9623680211374843], 
             UndirectedEdge[74, 180] -> 
             RGBColor[
              0.6920092366147003, 0.7573457676040214, 0.9716507896214397], 
             UndirectedEdge[27, 149] -> 
             RGBColor[
              0.6389312695070675, 0.5634343534467747, 0.5903531627449942], 
             UndirectedEdge[4, 49] -> 
             RGBColor[
              0.7038949474568732, 0.7680097428406325, 0.9715299153282955], 
             UndirectedEdge[9, 152] -> 
             RGBColor[
              0.7505556101005695, 0.805272099598698, 0.9758042753225229], 
             UndirectedEdge[19, 85] -> 
             RGBColor[
              0.7619955604800166, 0.8131542996117191, 0.9517839172940573], 
             UndirectedEdge[189, 197] -> 
             RGBColor[
              0.9536147152113996, 0.9649265110703706, 0.9634023673139844], 
             UndirectedEdge[69, 195] -> 
             RGBColor[
              0.7480549796440101, 0.7972748600853463, 0.7014766821136922], 
             UndirectedEdge[75, 191] -> 
             RGBColor[
              0.7054785981341556, 0.7691465401058462, 0.9717563773402449], 
             UndirectedEdge[73, 75] -> 
             RGBColor[
              0.5227664544592443, 0.6233200012529931, 0.9556076040421201], 
             UndirectedEdge[68, 188] -> 
             RGBColor[
              0.783307195149837, 0.7238720937728137, 0.610321275718243], 
             UndirectedEdge[4, 123] -> 
             RGBColor[
              0.6745961516760273, 0.7442236605300331, 0.9692234067994019], 
             UndirectedEdge[7, 84] -> 
             RGBColor[
              0.43403411966680505`, 0.5494595004134201, 0.9491261340957097], 
             UndirectedEdge[171, 195] -> 
             RGBColor[
              0.5082781176288649, 0.6116820994161962, 0.9544326617852887], 
             UndirectedEdge[62, 167] -> 
             RGBColor[
              0.8930358823501388, 0.9169830637255505, 0.9701220118260605], 
             UndirectedEdge[91, 152] -> 
             RGBColor[
              0.6772847355881573, 0.7457875028542409, 0.9700361236808488], 
             UndirectedEdge[38, 90] -> 
             RGBColor[
              0.9649138325559321, 0.9701442712065838, 0.7533292235954095], 
             UndirectedEdge[3, 118] -> 
             RGBColor[
              0.7541536223571366, 0.8030823743219319, 0.772144018488645], 
             UndirectedEdge[143, 181] -> 
             RGBColor[
              0.984359115174133, 0.9844349382240336, 0.703624439044855], 
             UndirectedEdge[20, 50] -> 
             RGBColor[
              0.789984330856397, 0.7412053882674595, 0.6136700221552474], 
             UndirectedEdge[128, 136] -> 
             RGBColor[
              0.7179945510837334, 0.7790567117793179, 0.9729887155923089], 
             UndirectedEdge[19, 161] -> 
             RGBColor[
              0.7943435652455257, 0.8394158671413672, 0.954330470723844], 
             UndirectedEdge[19, 140] -> 
             RGBColor[
              0.9017981929801775, 0.9237925680878277, 0.9648098244714428], 
             UndirectedEdge[39, 159] -> 
             RGBColor[
              0.5577173465864422, 0.6287810610221118, 0.962930546699633], 
             UndirectedEdge[87, 154] -> 
             RGBColor[
              0.5222978745838022, 0.6230639696950677, 0.9555363484088433], 
             UndirectedEdge[104, 143] -> 
             RGBColor[
              0.9204459193916643, 0.9345038588087746, 0.7332934523452592], 
             UndirectedEdge[6, 183] -> 
             RGBColor[
              0.6873522606945593, 0.2709614663911414, 0.42563057491205036`], 
             UndirectedEdge[17, 89] -> 
             RGBColor[
              0.6940322694683463, 0.7592705213788757, 0.9714850537396992], 
             UndirectedEdge[131, 176] -> 
             RGBColor[
              0.6349225479041649, 0.7117727710856272, 0.9662508275644446], 
             UndirectedEdge[44, 143] -> 
             RGBColor[
              0.9495958483098431, 0.9577472208743887, 0.736073798587924], 
             UndirectedEdge[140, 173] -> 
             RGBColor[
              0.8435218808473409, 0.8780654672689145, 0.9849370640877337], 
             UndirectedEdge[123, 195] -> 
             RGBColor[
              0.5240703268576565, 0.6245029262990477, 0.9556758823445477], 
             UndirectedEdge[96, 125] -> 
             RGBColor[
              0.9250040796490862, 0.9424192926157029, 0.9712870305043655], 
             UndirectedEdge[95, 159] -> 
             RGBColor[
              0.8645422142369641, 0.4644068504694179, 0.4474412920218209], 
             UndirectedEdge[171, 191] -> 
             RGBColor[
              0.6636634102266, 0.7351990868097442, 0.9684645325740817], 
             UndirectedEdge[124, 187] -> 
             RGBColor[
              0.507416655578852, 0.6090347489123894, 0.9549030761317923], 
             UndirectedEdge[54, 191] -> 
             RGBColor[
              0.7685770024738401, 0.819137462824912, 0.9775682309122976], 
             UndirectedEdge[24, 55] -> 
             RGBColor[
              0.8981157690585315, 0.9212351746133021, 0.9775943010004087], 
             UndirectedEdge[61, 126] -> 
             RGBColor[
              0.5962722198234764, 0.6815558283896386, 0.9624082641116745], 
             UndirectedEdge[46, 101] -> 
             RGBColor[
              0.48871356913125696`, 0.5938507407697892, 0.9534307006549745], 
             UndirectedEdge[158, 176] -> 
             RGBColor[
              0.6382220099146264, 0.7143865695703009, 0.9665700717964373], 
             UndirectedEdge[91, 200] -> 
             RGBColor[
              0.6836529357109387, 0.7508653327719592, 0.9706435282935191], 
             UndirectedEdge[29, 129] -> 
             RGBColor[
              0.8014357060333924, 0.8335417217691885, 0.683630269271341], 
             UndirectedEdge[37, 47] -> 
             RGBColor[
              0.48987147091002015`, 0.5967081342899465, 0.9529920835574126], 
             UndirectedEdge[25, 38] -> 
             RGBColor[
              0.6978465572079613, 0.7619972794668184, 0.971463999146295], 
             UndirectedEdge[95, 173] -> 
             RGBColor[
              0.8349981963450083, 0.44086315520018865`, 0.44510537071352774`],
              UndirectedEdge[86, 174] -> 
             RGBColor[
              0.9884741101184309, 0.988838428234892, 0.8025483526731267], 
             UndirectedEdge[4, 146] -> 
             RGBColor[
              0.8954353766335552, 0.9179057927594871, 0.9278621710471826], 
             UndirectedEdge[114, 186] -> 
             RGBColor[
              0.8051899806406217, 0.8485917085480692, 0.9809913999772264], 
             UndirectedEdge[155, 199] -> 
             RGBColor[
              0.523066895061245, 0.62140025370226, 0.9563676243759466], 
             UndirectedEdge[114, 194] -> 
             RGBColor[
              0.7664358035716603, 0.8176901797073921, 0.9772949919721265], 
             UndirectedEdge[59, 186] -> 
             RGBColor[
              0.9263415661273917, 0.9441036362307582, 0.9928364796037508], 
             UndirectedEdge[99, 193] -> 
             RGBColor[
              0.42702583463217314`, 0.5437698589026629, 0.9485744162255895], 
             UndirectedEdge[109, 136] -> 
             RGBColor[
              0.8816619347750452, 0.8008055904321592, 0.6200581664014129], 
             UndirectedEdge[50, 134] -> 
             RGBColor[
              0.6739828390919032, 0.7452397834486737, 0.9681399687391024], 
             UndirectedEdge[112, 183] -> 
             RGBColor[
              0.7981121402813572, 0.3601518157920057, 0.43503976562350166`], 
             UndirectedEdge[42, 73] -> 
             RGBColor[
              0.6411543960564191, 0.7166133551051449, 0.9669010579558801], 
             UndirectedEdge[42, 147] -> 
             RGBColor[
              0.6305273785437591, 0.7074087666651094, 0.966223913797076], 
             UndirectedEdge[87, 131] -> 
             RGBColor[
              0.6742810271424773, 0.7437621658976863, 0.9693392115067365], 
             UndirectedEdge[1, 11] -> 
             RGBColor[
              0.6833878584579236, 0.7465355902773243, 0.9202345178626834], 
             UndirectedEdge[30, 81] -> 
             RGBColor[
              0.7494119018869467, 0.8041966964480224, 0.975883305311931], 
             UndirectedEdge[154, 188] -> 
             RGBColor[
              0.57973169645268, 0.6696422721746575, 0.9600912928536733], 
             UndirectedEdge[83, 156] -> 
             RGBColor[
              0.8203802144777522, 0.8596221547707587, 0.9827273434977616], 
             UndirectedEdge[5, 107] -> 
             RGBColor[
              0.6880262852863848, 0.7477592884433168, 0.7928874665116658], 
             UndirectedEdge[93, 180] -> 
             RGBColor[
              0.8714149930688662, 0.9003426709896944, 0.9875879825502876], 
             UndirectedEdge[10, 17] -> 
             RGBColor[
              0.7548191183186175, 0.8086200236918599, 0.9762704171507568], 
             UndirectedEdge[75, 141] -> 
             RGBColor[
              0.7957976194123075, 0.8378311006814749, 0.8486259262023979], 
             UndirectedEdge[123, 141] -> 
             RGBColor[
              0.7697746407335437, 0.8167044742682246, 0.8465773019954936], 
             UndirectedEdge[40, 119] -> 
             RGBColor[
              0.8431188121505959, 0.8736966067130618, 0.7117663487961665], 
             UndirectedEdge[16, 80] -> 
             RGBColor[
              0.6818926068746183, 0.7514189541569924, 0.9689283404707009], 
             UndirectedEdge[88, 180] -> 
             RGBColor[
              0.765323300432157, 0.8168654273719698, 0.9774223412834145], 
             UndirectedEdge[24, 41] -> 
             RGBColor[
              0.8868973068806745, 0.9126518545933204, 0.989074250944493], 
             UndirectedEdge[4, 119] -> 
             RGBColor[
              0.898601679839412, 0.9170402446369772, 0.7172963625305102], 
             UndirectedEdge[99, 136] -> 
             RGBColor[
              0.6119492762880043, 0.6910164036117736, 0.9651786748984681], 
             UndirectedEdge[10, 194] -> 
             RGBColor[
              0.734618202587056, 0.7925123618267629, 0.9743436357747101], 
             UndirectedEdge[96, 102] -> 
             RGBColor[
              0.7491014514070427, 0.8028437706324212, 0.9549929341460102], 
             UndirectedEdge[9, 88] -> 
             RGBColor[
              0.6159252125037235, 0.6990748604819665, 0.9629070354181389], 
             UndirectedEdge[55, 108] -> 
             RGBColor[
              0.7642481967772827, 0.8154682768301106, 0.9649745968041622], 
             UndirectedEdge[62, 197] -> 
             RGBColor[
              0.9608624701982736, 0.9703318748724716, 0.9511338086384531], 
             UndirectedEdge[147, 168] -> 
             RGBColor[
              0.4045292779715197, 0.5248046611714002, 0.9469972257745182], 
             UndirectedEdge[51, 106] -> 
             RGBColor[
              0.7455517740535127, 0.8005681877379027, 0.970972743419146], 
             UndirectedEdge[123, 155] -> 
             RGBColor[
              0.6046540753575456, 0.6895843789305671, 0.9622522342778402], 
             UndirectedEdge[75, 142] -> 
             RGBColor[
              0.5806821959615669, 0.6704629919732418, 0.960132576056517], 
             UndirectedEdge[31, 182] -> 
             RGBColor[
              0.6165566996910059, 0.6946902379681505, 0.9656181350557418], 
             UndirectedEdge[65, 140] -> 
             RGBColor[
              0.8948673643847022, 0.9186235674695125, 0.9765419094339773]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 71 -> 
             RGBColor[
              0.8320933957551653, 0.8689527034743775, 0.9838470049773129], 10 -> 
             RGBColor[
              0.6213607656770951, 0.7034876874169896, 0.9633349420750341], 68 -> 
             RGBColor[
              0.9210526773436145, 0.7247072038428337, 0.25533533494008015`], 
             155 -> RGBColor[
              0.6645582800323124, 0.7378772462820197, 0.9672006167695542], 
             132 -> RGBColor[
              0.9903442611560344, 0.9902751180939201, 0.8096841111030161], 26 -> 
             RGBColor[
              0.48225475907378146`, 0.5905551646022364, 0.9523840076731291], 
             29 -> RGBColor[
              0.6157768650188236, 0.6989544253107468, 0.9628953569607129], 
             113 -> RGBColor[
              0.7675691371093368, 0.8183501107421016, 0.9774677763118013], 50 -> 
             RGBColor[
              0.6513034693736895, 0.7275224874552113, 0.9658795011163507], 
             173 -> RGBColor[
              0.847875639497017, 0.881537036236536, 0.985352329474386], 192 -> 
             RGBColor[
              0.429030383432169, 0.5460262872600478, 0.9485584145489939], 165 -> 
             RGBColor[
              0.9901376228717133, 0.9901896678529917, 0.8131086422369543], 
             92 -> 
             RGBColor[
              0.4864927292434324, 0.5939957397043396, 0.9527176362090803], 11 -> 
             RGBColor[
              0.9852002068256696, 0.988147919432148, 0.8949344037430278], 137 -> 
             RGBColor[
              0.49795844922627686`, 0.6033041277112117, 0.953620259686446], 
             120 -> RGBColor[
              0.7693588610097197, 0.8197482566554861, 0.9776461592642707], 51 -> 
             RGBColor[
              0.5498011902129671, 0.6453924003330732, 0.9577015101631359], 72 -> 
             RGBColor[
              0.5141681496733971, 0.6164638927728673, 0.9548963466837326], 64 -> 
             RGBColor[
              0.46005518075186375`, 0.5725325468408972, 0.9506363755478929], 
             41 -> RGBColor[
              0.9272991386198431, 0.9448671785436261, 0.9929278137229158], 
             103 -> RGBColor[
              0.3815755100901777, 0.5049232611225005, 0.945534631982339], 162 -> 
             RGBColor[
              0.3815755100901777, 0.5049232611225005, 0.945534631982339], 196 -> 
             RGBColor[
              0.6709341707942212, 0.7428581406037874, 0.9678361059746144], 
             179 -> RGBColor[
              0.6458294600057413, 0.7232461497329581, 0.9653339030200796], 
             160 -> RGBColor[
              0.6122406828987438, 0.6960835933624769, 0.9626169757507583], 
             123 -> RGBColor[
              0.5447498706827788, 0.6412915115791147, 0.9573038517861263], 
             150 -> RGBColor[
              0.5852844396783876, 0.6741993007512735, 0.9604948815404794], 
             188 -> RGBColor[
              0.6455617129560596, 0.7230369837027937, 0.9653072164964057], 46 -> 
             RGBColor[
              0.5958516281723363, 0.6827782204170778, 0.9613267693276099], 
             182 -> RGBColor[
              0.3815755100901777, 0.5049232611225005, 0.945534631982339], 6 -> 
             RGBColor[
              0.4274187820836781, 0.544630399173424, 0.9484557247361511], 131 -> 
             RGBColor[
              0.8178679850666508, 0.8576439530517584, 0.9824810954067276], 45 -> 
             RGBColor[
              0.6516198193228064, 0.7277696224398101, 0.9659110319228204], 
             195 -> RGBColor[
              0.5033907830325344, 0.6077143410189807, 0.9540479129029691], 
             148 -> RGBColor[
              0.5852844396783876, 0.6741993007512735, 0.9604948815404794], 
             161 -> RGBColor[
              0.6242588667283613, 0.705840496408372, 0.9635630912058837], 1 -> 
             RGBColor[
              0.3815755100901777, 0.5049232611225005, 0.945534631982339], 101 -> 
             RGBColor[
              0.3815755100901777, 0.5049232611225005, 0.945534631982339], 12 -> 
             RGBColor[
              0.9940364537522196, 0.9896529025200407, 0.5922829775495202], 39 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 48 -> 
             RGBColor[
              0.4924757609649053, 0.5988530343883388, 0.953188642382762], 77 -> 
             RGBColor[
              0.9933130901637146, 0.9881057009475062, 0.5135493150233552], 56 -> 
             RGBColor[
              0.3748395140950027, 0.4990888799524827, 0.9451054202739338], 
             110 -> RGBColor[
              0.5678457915823428, 0.6600418206247604, 0.959122047282486], 73 -> 
             RGBColor[
              0.44873708087818204`, 0.563095238100371, 0.9498141078843055], 
             37 -> RGBColor[
              0.4521902848637532, 0.5660862298295938, 0.9500341429887177], 
             130 -> RGBColor[
              0.60647934286941, 0.6914062779812532, 0.9621634219591653], 107 -> 
             RGBColor[
              0.3815755100901777, 0.5049232611225005, 0.945534631982339], 59 -> 
             RGBColor[
              0.9272991386198431, 0.9448671785436261, 0.9929278137229158], 47 -> 
             RGBColor[
              0.5275526569562872, 0.6273300387502991, 0.9559500241261074], 
             159 -> RGBColor[
              0.9365076931728845, 0.9521681220442237, 0.9923600933992658], 55 -> 
             RGBColor[
              0.9497360629755573, 0.9620338185835895, 0.9699679138347472], 49 -> 
             RGBColor[
              0.6033474622444709, 0.6888636762003134, 0.9619168688439133], 82 -> 
             RGBColor[
              0.3815755100901777, 0.5049232611225005, 0.945534631982339], 199 -> 
             RGBColor[
              0.3815755100901777, 0.5049232611225005, 0.945534631982339], 89 -> 
             RGBColor[
              0.4997870679765526, 0.6047886827910214, 0.953764215252919], 144 -> 
             RGBColor[
              0.9929692141040461, 0.9873701848270781, 0.47612052808547867`], 
             78 -> RGBColor[
              0.6601645113233569, 0.7344448007727046, 0.9667626869667485], 42 -> 
             RGBColor[
              0.8335717112346562, 0.8701314721099188, 0.9839880080274546], 
             154 -> RGBColor[
              0.5139016799493005, 0.6162475606465213, 0.954875369210941], 168 -> 
             RGBColor[
              0.3815755100901777, 0.5049232611225005, 0.945534631982339], 121 -> 
             RGBColor[
              0.7509613086047295, 0.8053759488901308, 0.9758124631754433], 
             128 -> RGBColor[
              0.593666059681636, 0.6810038774575888, 0.9611547133700208], 115 -> 
             RGBColor[
              0.5293102784779798, 0.6287569550815565, 0.9560883905306747], 61 -> 
             RGBColor[
              0.45143526787183896`, 0.5654322720594551, 0.9499860339736282], 
             93 -> RGBColor[
              0.8155308475178892, 0.8558181634357627, 0.9822481513776592], 88 -> 
             RGBColor[
              0.6033474622444709, 0.6888636762003134, 0.9619168688439133], 21 -> 
             RGBColor[
              0.9216971872817327, 0.940400334607535, 0.9923934946033659], 62 -> 
             RGBColor[
              0.9575518302016578, 0.967862804983671, 0.9567378585995239], 136 -> 
             RGBColor[
              0.8423230424858309, 0.8771095461010469, 0.9848227178145972], 
             190 -> RGBColor[
              0.48245452454046833`, 0.5907173432074246, 0.9523997339424318], 
             57 -> RGBColor[
              0.9949886733556723, 0.991689603967656, 0.6959262049671415], 111 -> 
             RGBColor[
              0.9927191762554858, 0.9868353791517118, 0.4489054513244154], 63 -> 
             RGBColor[
              0.9373300916492292, 0.9527814654813278, 0.9909679872946892], 75 -> 
             RGBColor[
              0.5967958280403065, 0.6835447644056154, 0.9614011001999346], 30 -> 
             RGBColor[
              0.6059160255043872, 0.6909489515671696, 0.9621190755526912], 5 -> 
             RGBColor[
              0.9944770604825918, 0.9905953157641331, 0.6402403010409925], 
             171 -> RGBColor[
              0.5131654522251953, 0.6156498578134117, 0.9548174106676084], 
             102 -> RGBColor[
              0.5385436788527915, 0.6362530454657753, 0.95681527763124], 31 -> 
             RGBColor[
              0.851537889291834, 0.8844572148138006, 0.9857016381291447], 96 -> 
             RGBColor[
              0.9596592239612939, 0.969434495799067, 0.9531705906607804], 70 -> 
             RGBColor[
              0.9337875244779437, 0.9500408413043331, 0.9935466817583118], 52 -> 
             RGBColor[
              0.9462087779129132, 0.9594031751592688, 0.9759386873825212], 
             183 -> RGBColor[0.817319, 0.134127, 0.164218], 158 -> 
             RGBColor[
              0.8244669090875737, 0.8628715500211057, 0.983119583870713], 13 -> 
             RGBColor[
              0.7509613086047295, 0.8053759488901308, 0.9758124631754433], 
             170 -> 
             RGBColor[
              0.8887729985998765, 0.5878259890157674, 0.22890180241949887`], 
             86 -> RGBColor[
              0.9820161024677638, 0.9861082191831636, 0.9153262269571099], 18 -> 
             RGBColor[
              0.3815755100901777, 0.5049232611225005, 0.945534631982339], 153 -> 
             RGBColor[
              0.9930161992863115, 0.9874706813810131, 0.48123457521613255`], 
             58 -> RGBColor[
              0.9292072738494066, 0.946388673780729, 0.9931098133645241], 22 -> 
             RGBColor[
              0.9040123237751339, 0.6570242054017887, 0.24161786889577586`], 
             66 -> RGBColor[
              0.5887657751770851, 0.6770256057414932, 0.960768945023489], 143 -> 
             RGBColor[
              0.9930161992863115, 0.9874706813810131, 0.48123457521613255`], 
             119 -> RGBColor[
              0.9927609270095483, 0.986924679793003, 0.4534497632483429], 145 -> 
             RGBColor[
              0.5678585011357061, 0.6600521388127395, 0.9591230478250833], 91 -> 
             RGBColor[
              0.4819612137381516, 0.5903168512747055, 0.9523608987090164], 
             177 -> RGBColor[
              0.992858781223789, 0.987133980062685, 0.4641005905822283], 200 -> 
             RGBColor[
              0.8853446576837256, 0.9114138142692131, 0.9889261578780216], 
             114 -> RGBColor[
              0.6849959676463034, 0.7538433231782483, 0.9692376544698671], 24 -> 
             RGBColor[
              0.8464954751415058, 0.8804365306430147, 0.9852206881660701], 
             176 -> RGBColor[
              0.45197711074167907`, 0.5659015891194961, 0.9500205597221616], 
             79 -> RGBColor[
              0.8130940138451017, 0.8539144904499592, 0.9820052705706611], 
             109 -> RGBColor[
              0.9210008270642593, 0.7245016347632713, 0.25529361498822845`], 
             135 -> RGBColor[
              0.9613581835008072, 0.8813142207975503, 0.3043842691057218], 
             108 -> RGBColor[
              0.5787603305790081, 0.6689027350766317, 0.9599812797735772], 
             191 -> RGBColor[
              0.8141613682280048, 0.8547483158060768, 0.982111654480555], 14 -> 
             RGBColor[
              0.9939877753369902, 0.9895487843120079, 0.5869846324601637], 
             185 -> RGBColor[
              0.9755605579285189, 0.9292221646183192, 0.3595578118640172], 32 -> 
             RGBColor[
              0.4860788630689587, 0.5936597444994431, 0.952685055147784], 122 -> 
             RGBColor[
              0.8748599141860629, 0.9030535644049574, 0.9879261136833736], 
             187 -> RGBColor[
              0.3815755100901777, 0.5049232611225005, 0.945534631982339], 193 -> 
             RGBColor[
              0.47247615917416863`, 0.5826164566828255, 0.9516142004688399], 
             100 -> RGBColor[
              0.8606256715927654, 0.8917035657392842, 0.9865684389177665], 
             180 -> RGBColor[
              0.9272991386198431, 0.9448671785436261, 0.9929278137229158], 7 -> 
             RGBColor[
              0.4864927292434324, 0.5939957397043396, 0.9527176362090803], 
             175 -> RGBColor[
              0.8096214608918068, 0.8512017056904652, 0.981659158945129], 9 -> 
             RGBColor[
              0.628502962762976, 0.7092860447636198, 0.9638972019923646], 90 -> 
             RGBColor[
              0.9933199719389796, 0.9881204203689438, 0.5142983537915533], 
             174 -> RGBColor[
              0.994932117769098, 0.9915686372866204, 0.6897704783891437], 142 -> 
             RGBColor[
              0.5645685638828272, 0.6573812195408681, 0.9588640519130994], 
             134 -> RGBColor[
              0.6966622088101166, 0.762957079442136, 0.9704004363618539], 105 -> 
             RGBColor[
              0.7202932502266978, 0.7814178285993358, 0.9727557577256212], 16 -> 
             RGBColor[
              0.7038147730162924, 0.7685447169615018, 0.9711133371174128], 
             139 -> RGBColor[
              0.6123564377234234, 0.6961775683438474, 0.962626088394581], 146 -> 
             RGBColor[
              0.9864283205978349, 0.9886557760380227, 0.8745813802816876], 
             126 -> RGBColor[
              0.7411091717751139, 0.7976793847198219, 0.9748304942497206], 
             198 -> RGBColor[
              0.7160212104725021, 0.7780804786746536, 0.9723299607274042], 40 -> 
             RGBColor[
              0.6934766972916435, 0.7604685336331206, 0.9700829343439902], 
             104 -> RGBColor[
              0.847875639497017, 0.881537036236536, 0.985352329474386], 181 -> 
             RGBColor[
              0.9757020310619545, 0.981399195067054, 0.9260143028735776], 127 -> 
             RGBColor[
              0.6998042245689352, 0.7654116460331293, 0.9707136031288862], 76 -> 
             RGBColor[
              0.6594390672957938, 0.7338780783847935, 0.9666903814857409], 
             172 -> RGBColor[
              0.3815755100901777, 0.5049232611225005, 0.945534631982339], 84 -> 
             RGBColor[
              0.3815755100901777, 0.5049232611225005, 0.945534631982339], 184 -> 
             RGBColor[
              0.9109961189390933, 0.9318675931838765, 0.9913728171518884], 
             151 -> RGBColor[
              0.9755605579285189, 0.9292221646183192, 0.3595578118640172], 35 -> 
             RGBColor[
              0.7401133163156276, 0.7969014148660893, 0.9747312366843174], 36 -> 
             RGBColor[
              0.994515563694754, 0.9906776702416761, 0.6444311380705681], 34 -> 
             RGBColor[
              0.656355357278861, 0.7314690606825014, 0.9663830260901616], 38 -> 
             RGBColor[
              0.9365076931728845, 0.9521681220442237, 0.9923600933992658], 54 -> 
             RGBColor[
              0.7229926367196754, 0.7835266098437472, 0.9730248073440402], 60 -> 
             RGBColor[
              0.3815755100901777, 0.5049232611225005, 0.945534631982339], 87 -> 
             RGBColor[
              0.5306940692183039, 0.629880378743614, 0.9561973276067456], 141 -> 
             RGBColor[
              0.9947994107843087, 0.9921174369573345, 0.735850752204861], 67 -> 
             RGBColor[
              0.6568747459233402, 0.7318748110390684, 0.9664347938962804], 
             133 -> RGBColor[
              0.4926237907331135, 0.5989732116228352, 0.9532002958283663], 98 -> 
             RGBColor[
              0.3815755100901777, 0.5049232611225005, 0.945534631982339], 3 -> 
             RGBColor[
              0.9940097966037453, 0.9895958855749055, 0.5893815114469507], 27 -> 
             RGBColor[
              0.3815755100901777, 0.5049232611225005, 0.945534631982339], 163 -> 
             RGBColor[
              0.9927191762554858, 0.9868353791517118, 0.4489054513244154], 85 -> 
             RGBColor[
              0.5595628571973431, 0.6533173613490758, 0.9584699843463104], 83 -> 
             RGBColor[
              0.8219176544917024, 0.8608388436040305, 0.9828764336916124], 28 -> 
             RGBColor[
              0.41394413348173864`, 0.5329593358099549, 0.9475971320423995], 
             44 -> RGBColor[
              0.9061754973333748, 0.9280237603677641, 0.9909130219597153], 
             189 -> RGBColor[
              0.9430563202279098, 0.957052077379469, 0.9812749759505865], 15 -> 
             RGBColor[
              0.934534399866064, 0.950636379465428, 0.9936179193995743], 80 -> 
             RGBColor[
              0.6599704407329443, 0.7342931913524832, 0.966743343823989], 112 -> 
             RGBColor[
              0.7596984208440716, 0.8122014473760172, 0.9766832968705049], 
             169 -> RGBColor[
              0.5420985090943385, 0.6391390167991405, 0.9570951268896268], 69 -> 
             RGBColor[
              0.9927191762554858, 0.9868353791517118, 0.4489054513244154], 20 -> 
             RGBColor[
              0.9286651923391045, 0.7548882890797077, 0.26146054319414413`], 
             8 -> RGBColor[
              0.9900793320978125, 0.9901655631199792, 0.8140746712121761], 
             116 -> RGBColor[
              0.8855563797889257, 0.9115826357288562, 0.9889463521214222], 97 -> 
             RGBColor[
              0.979080002176097, 0.9839184803930615, 0.9202962788933019], 118 -> 
             RGBColor[
              0.5142974481105278, 0.6165688630689582, 0.9549065255303393], 
             178 -> RGBColor[
              0.7365588555963704, 0.7941246431373036, 0.9743769612581458], 81 -> 
             RGBColor[
              0.8929077782695062, 0.9174444413288751, 0.9896475350711709], 
             166 -> RGBColor[
              0.9325650773744396, 0.9490660951664416, 0.9934300836622882], 
             125 -> RGBColor[
              0.8903489353368783, 0.9154040894323389, 0.9894034703479507], 95 -> 
             RGBColor[
              0.8285594747690039, 0.220526214682015, 0.17498189133309858`], 
             157 -> RGBColor[
              0.4447439748011214, 0.5596366103157681, 0.9495596706960403], 74 -> 
             RGBColor[
              0.4567193346095573, 0.5698243566644167, 0.9503737655199636], 19 -> 
             RGBColor[
              0.9644282637626901, 0.9729912378743624, 0.9450978502418043], 
             156 -> RGBColor[
              0.818842774463802, 0.8584054659374868, 0.9825782533039108], 167 -> 
             RGBColor[
              0.8285199344986198, 0.8661033224674299, 0.983506165052597], 33 -> 
             RGBColor[
              0.5017045399978106, 0.6063453729590088, 0.9539151656743639], 43 -> 
             RGBColor[
              0.687129593528892, 0.7555101279338838, 0.969450314357976], 140 -> 
             RGBColor[
              0.8391681221976648, 0.8745938983012931, 0.9845217987010814], 
             186 -> RGBColor[
              0.9253839936349402, 0.9433400939178902, 0.9927451454845857], 
             117 -> RGBColor[
              0.9916509854269356, 0.9908154821612197, 0.7880283082401708], 4 -> 
             RGBColor[
              0.8044424326692756, 0.8471558094809515, 0.9811429618126776], 
             106 -> RGBColor[
              0.9413023578940581, 0.9557439751427321, 0.984243976675156], 65 -> 
             RGBColor[
              0.9505666065717395, 0.9626532366377318, 0.9685620201668733], 53 -> 
             RGBColor[
              0.8127960478818615, 0.8536817171748508, 0.9819755721080956], 2 -> 
             RGBColor[
              0.8155308475178892, 0.8558181634357627, 0.9822481513776592], 
             147 -> RGBColor[
              0.4274830458528618, 0.5446860612202999, 0.9484598195666973], 94 -> 
             RGBColor[
              0.46005518075186375`, 0.5725325468408972, 0.9506363755478929], 
             23 -> RGBColor[
              0.9413023578940581, 0.9557439751427321, 0.984243976675156], 194 -> 
             RGBColor[
              0.847875639497017, 0.881537036236536, 0.985352329474386], 129 -> 
             RGBColor[
              0.9870945470479613, 0.9681290182276302, 0.4043651815819689], 99 -> 
             RGBColor[
              0.3815755100901777, 0.5049232611225005, 0.945534631982339], 25 -> 
             RGBColor[
              0.4591854212430382, 0.5718264368894131, 0.9505679048933242], 
             138 -> RGBColor[
              0.48781040492572747`, 0.5950654881838398, 0.9528213684655957], 
             124 -> RGBColor[
              0.6332578010675263, 0.7131462367022783, 0.9642715202812454], 
             197 -> RGBColor[
              0.9641731101948895, 0.9728009447612722, 0.9455297586773823], 
             164 -> RGBColor[
              0.5269950071798261, 0.6268773135399319, 0.9559061238929659], 
             152 -> RGBColor[
              0.8726082574381631, 0.9012581544337763, 0.9877113486526812], 17 -> 
             RGBColor[
              0.8882774709601399, 0.9137523599667302, 0.9892058922264794], 
             149 -> RGBColor[
              0.8962870289239572, 0.6219454457710489, 
               0.23517169350764927`]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw1Vnk41Iv7HWbGjH3MjDGYYWbMlDYVokV9jgp1K023DRVaCFlSpNQNyVKW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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 11}], {
             RGBColor[
             0.6833878584579236, 0.7465355902773243, 0.9202345178626834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 35}], {
             RGBColor[
             0.5608444132029027, 0.6509123379942949, 0.9601329343333282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 86}], {
             RGBColor[
             0.6817958062789709, 0.7455157401528321, 0.9304304294697244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 94}], {
             RGBColor[
             0.4208153454210207, 0.5387279039816988, 0.9480855037651159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 174}], {
             RGBColor[
             0.6882538139296379, 0.7482459492045604, 0.8176525551857414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 196}], {
             RGBColor[
             0.5262548404421995, 0.623890700863144, 0.9566853689784767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 16}], {
             RGBColor[
             0.7596728102670908, 0.8121814401986323, 0.976680744247536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 52}], {
             RGBColor[
             0.8808698127154012, 0.9076106692975157, 0.9790934193800902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[
             0.7021483113474871, 0.7664218845886279, 0.9715085482005741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 78}], {
             RGBColor[
             0.737847679420623, 0.7951314821042337, 0.9745054191722038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 80}], {
             RGBColor[
             0.7377506441254167, 0.7950556773941229, 0.974495747600824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 82}], {
             RGBColor[
             0.5985531788040335, 0.6803707122791316, 0.9638913916799992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 98}], {
             RGBColor[
             0.5985531788040335, 0.6803707122791316, 0.9638913916799992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 100}], {
             RGBColor[
             0.8380782595553273, 0.8737608645875234, 0.9844082951477129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 120}], {
             RGBColor[
             0.7924448542638045, 0.8377832100456244, 0.9799471553209649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 124}], {
             RGBColor[
             0.7243943242927078, 0.7844822000690205, 0.9732598358294523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 187}], {
             RGBColor[
             0.5985531788040335, 0.6803707122791316, 0.9638913916799992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 5}], {
             RGBColor[
             0.9942434285431685, 0.9900956006695193, 0.6148109062439716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 10}], {
             RGBColor[
             0.8076852811404203, 0.8465417864959476, 0.7763582267609924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 27}], {
             RGBColor[
             0.6877926533469615, 0.7472595733487031, 0.7674580717146449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 29}], {
             RGBColor[
             0.8048933308112844, 0.8442751554428262, 0.7761384342038318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 49}], {
             RGBColor[
             0.7986786294241082, 0.8392297808876095, 0.775649190145432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 53}], {
             RGBColor[
             0.9034029222428035, 0.9216388013748782, 0.7856785417775232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 62}], {
             RGBColor[
             0.9757808134027015, 0.9787293452792882, 0.7730596850232373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 68}], {
             RGBColor[
             0.9575312369736799, 0.8571515447088696, 0.42235842319351546`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 71}], {
             RGBColor[
             0.9130515961794553, 0.9292742945246415, 0.7866142582121318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 75}], {
             RGBColor[
             0.7954028123220259, 0.8365703249902605, 0.7753913058234427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 118}], {
             RGBColor[
             0.7541536223571366, 0.8030823743219319, 0.772144018488645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[
             0.769379833643262, 0.8154436985770102, 0.7733426816165385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 127}], {
             RGBColor[
             0.8469070105863403, 0.8775037658040175, 0.7800475572879184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 129}], {
             RGBColor[
             0.9905521718258533, 0.9788624519012679, 0.4968733465144598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 139}], {
             RGBColor[
             0.8031831171635844, 0.8428867269593765, 0.7760037999207658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 141}], {
             RGBColor[
             0.9944046036940271, 0.99085666126612, 0.6626161318259058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 146}], {
             RGBColor[
             0.9902190586007902, 0.9891258308064641, 0.7319814458643192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 155}], {
             RGBColor[
             0.8292840383180289, 0.8637365659284626, 0.7782910641082524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 167}], {
             RGBColor[
             0.9112648655511826, 0.9278496040211677, 0.7864438382497738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 191}], {
             RGBColor[
             0.9040855824158751, 0.9221721006904912, 0.7857465829637529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 194}], {
             RGBColor[
             0.9209427180503812, 0.9355664609057208, 0.7873669204606684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 195}], {
             RGBColor[
             0.7487002898181399, 0.798655113296943, 0.7717147121749599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 34}], {
             RGBColor[
             0.7303988949740683, 0.7893124350817264, 0.9737629939514196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 40}], {
             RGBColor[
             0.7489595649804596, 0.8038121715570361, 0.9756129480783339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 49}], {
             RGBColor[
             0.7038949474568732, 0.7680097428406325, 0.9715299153282955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 53}], {
             RGBColor[
             0.8086192402755685, 0.8504187633279011, 0.9815592669603865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 54}], {
             RGBColor[
             0.7637175346944756, 0.8153412096623494, 0.9770838845783589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 65}], {
             RGBColor[
             0.8775045196205076, 0.9049045230593417, 0.9748524909897754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 69}], {
             RGBColor[
             0.8985808044623806, 0.9169955943163317, 0.7150242065685465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 86}], {
             RGBColor[
             0.8932292675685197, 0.9166320143320575, 0.9482345943848938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 92}], {
             RGBColor[
             0.645467580956354, 0.7205757745926455, 0.966930299010879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 118}], {
             RGBColor[
             0.6593699403899017, 0.7318623362749548, 0.9680247436715084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 119}], {
             RGBColor[
             0.898601679839412, 0.9170402446369772, 0.7172963625305102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 123}], {
             RGBColor[
             0.6745961516760273, 0.7442236605300331, 0.9692234067994019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 139}], {
             RGBColor[
             0.7083994351963495, 0.7716666889123994, 0.9718845251036292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 146}], {
             RGBColor[
             0.8954353766335552, 0.9179057927594871, 0.9278621710471826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 171}], {
             RGBColor[
             0.6588039424472354, 0.7314028336471816, 0.9679801862401429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 182}], {
             RGBColor[
             0.5930089713797266, 0.676039535301726, 0.9633387968975082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 191}], {
             RGBColor[
             0.8093019004486401, 0.8509520626435141, 0.9816273081466163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 195}], {
             RGBColor[
             0.653916607850905, 0.7274350752499661, 0.9675954373578233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 196}], {
             RGBColor[
             0.7376883017317484, 0.7950069750423694, 0.974489533893646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 199}], {
             RGBColor[
             0.5930089713797266, 0.676039535301726, 0.9633387968975082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 10}], {
             RGBColor[
             0.8079189130798434, 0.8470415015905614, 0.8017876215580133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 27}], {
             RGBColor[
             0.6880262852863848, 0.7477592884433168, 0.7928874665116658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.8051269627507076, 0.8447748705374399, 0.8015678290008528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 30}], {
             RGBColor[
             0.8001965429934894, 0.8407721336656513, 0.8011796882968418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 42}], {
             RGBColor[
             0.914024385858624, 0.9303633939370259, 0.8121141545342235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 68}], {
             RGBColor[
             0.9577648689131031, 0.8576512598034833, 0.44778781799053635`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 71}], {
             RGBColor[
             0.9132852281188786, 0.9297740096192553, 0.8120436530091527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 73}], {
             RGBColor[
             0.7216070706803869, 0.776845276932252, 0.795027204462649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 75}], {
             RGBColor[
             0.7956364442614492, 0.8370700400848743, 0.8008207006204635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 76}], {
             RGBColor[
             0.8269580638891928, 0.8622366970744633, 0.8034653412633668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 81}], {
             RGBColor[
             0.943692419376049, 0.9540198785465042, 0.8149439180560817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 87}], {
             RGBColor[
             0.7625855648504478, 0.8102378472538736, 0.7982188143238691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 89}], {
             RGBColor[
             0.7471320642295722, 0.7976919992775773, 0.7970022581469558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 107}], {
             RGBColor[
             0.6880262852863848, 0.7477592884433168, 0.7928874665116658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 127}], {
             RGBColor[
             0.8471406425257635, 0.8780034808986312, 0.8054769520849394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 129}], {
             RGBColor[
             0.9907858037652766, 0.9793621669958816, 0.5223027413114807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 141}], {
             RGBColor[
             0.9946382356334502, 0.9913563763607338, 0.6880455266229267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 142}], {
             RGBColor[
             0.7795228121827095, 0.8239882676525006, 0.7995521764770459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 147}], {
             RGBColor[
             0.7109800531677268, 0.7676406884922164, 0.7943500603038449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 155}], {
             RGBColor[
             0.829517670257452, 0.8642362810230764, 0.8037204589052733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 157}], {
             RGBColor[
             0.7196105176418566, 0.7751159630399506, 0.7948999858685164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 168}], {
             RGBColor[
             0.6880262852863848, 0.7477592884433168, 0.7928874665116658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 188}], {
             RGBColor[
             0.8200193867193257, 0.8568161497334634, 0.8027737587686992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 197}], {
             RGBColor[
             0.9793250853387406, 0.9816981302627026, 0.7928850298591874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 44}], {
             RGBColor[
             0.6667971397085264, 0.7363270797705941, 0.9696843733479332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 45}], {
             RGBColor[
             0.5395193007032423, 0.636200010806617, 0.9571833783294857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 58}], {
             RGBColor[
             0.6783130279665424, 0.7455095364770765, 0.9707827690503377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 77}], {
             RGBColor[
             0.7103659361236964, 0.766368050060465, 0.7310025198797532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 83}], {
             RGBColor[
             0.6246682182876903, 0.7027346213887273, 0.9656660792138818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 96}], {
             RGBColor[
             0.693539003022486, 0.7570324474862455, 0.9508131576984657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 112}], {
             RGBColor[
             0.5935586014638748, 0.6784159232747207, 0.9625695108033281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 156}], {
             RGBColor[
             0.6231307782737401, 0.7015179325554555, 0.965516989020031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 166}], {
             RGBColor[
             0.6799919297290589, 0.7468482471699328, 0.9709429041992197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 170}], {
             RGBColor[
             0.6580958903417773, 0.5662281940945957, 0.588678763577825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 179}], {
             RGBColor[
             0.5366241210447097, 0.6339382744531911, 0.9568948138781154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 183}], {
             RGBColor[
             0.6873522606945593, 0.2709614663911414, 0.42563057491205036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 192}], {
             RGBColor[
             0.4282245827579235, 0.545328343216736, 0.9485070696425726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 8}], {
             RGBColor[
             0.7382860306706225, 0.7920806514121594, 0.8833961537106283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 16}], {
             RGBColor[
             0.5951537511298624, 0.6812702283329207, 0.9619154866632466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 52}], {
             RGBColor[
             0.7163507535781728, 0.7766994574318042, 0.9643281617958008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.4689639985576357, 0.5797140058818974, 0.9513518350913543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 67}], {
             RGBColor[
             0.5716837375833863, 0.6629352753717039, 0.9595762150526803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 79}], {
             RGBColor[
             0.6497933715442671, 0.7239551150771494, 0.9673614533898707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.43403411966680505`, 0.5494595004134201, 0.9491261340957097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 122}], {
             RGBColor[
             0.6806763217147477, 0.7485246520546485, 0.970321874946227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 125}], {
             RGBColor[
             0.6884208322901554, 0.7546999145683393, 0.9710605532785155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 126}], {
             RGBColor[
             0.6138009505092732, 0.6958375622120807, 0.9637740652294005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 137}], {
             RGBColor[
             0.4922255892348546, 0.5986499337077756, 0.9531689479477632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 179}], {
             RGBColor[
             0.5661610946245869, 0.6586209447186488, 0.95902576961458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 192}], {
             RGBColor[
             0.4577615563378007, 0.5700110134821936, 0.9506380253790372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.9558882596897726, 0.9652829488637571, 0.903234082907771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 26}], {
             RGBColor[
             0.7361670455857969, 0.7903603638611079, 0.8832293394426527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 61}], {
             RGBColor[
             0.7207572999848257, 0.7777989175897171, 0.8820303525929022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 67}], {
             RGBColor[
             0.8234770390105763, 0.8610201870795238, 0.8902547325542283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 79}], {
             RGBColor[
             0.9015866729714571, 0.9220400267849691, 0.8980399708914186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.6858274210939951, 0.7475444121212398, 0.8798046515972575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 83}], {
             RGBColor[
             0.9059984932947575, 0.9255022033620048, 0.8984755524518943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 122}], {
             RGBColor[
             0.9324696231419377, 0.9466095637624683, 0.9010003924477749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 125}], {
             RGBColor[
             0.9402141337173454, 0.952784826276159, 0.9017390707800634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 137}], {
             RGBColor[
             0.7440188906620446, 0.7967348454155954, 0.8838474654493111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 166}], {
             RGBColor[
             0.9613222047361261, 0.9696158291432104, 0.9037523774372322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 170}], {
             RGBColor[
             0.9394261653488445, 0.7889957760678733, 0.5214882368158376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 179}], {
             RGBColor[
             0.8179543960517769, 0.8567058564264687, 0.8897042871161278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 192}], {
             RGBColor[
             0.7095548577649907, 0.7680959251900135, 0.881316542880585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 198}], {
             RGBColor[
             0.8530502712851573, 0.8841230208973163, 0.8932023159697902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 18}], {
             RGBColor[
             0.5050392364265769, 0.6071046529430602, 0.9547159169873518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 32}], {
             RGBColor[
             0.5572909129159673, 0.6514728946315315, 0.9582911285700744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 39}], {
             RGBColor[
             0.403714981381488, 0.5073400223818099, 0.9486991009961823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 41}], {
             RGBColor[
             0.7779010506914096, 0.827076611653623, 0.9784125078576402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 57}], {
             RGBColor[
             0.8117458180593242, 0.850487824365638, 0.8299117034797531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 85}], {
             RGBColor[
             0.5940329099801596, 0.6813017030563477, 0.9611835931693375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 88}], {
             RGBColor[
             0.6159252125037235, 0.6990748604819665, 0.9629070354181389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 91}], {
             RGBColor[
             0.5552320882505638, 0.6498014480191626, 0.9581290503506905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 103}], {
             RGBColor[
             0.5050392364265769, 0.6071046529430602, 0.9547159169873518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 117}], {
             RGBColor[
             0.8100769740949558, 0.8500507634624197, 0.8759627551162676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 121}], {
             RGBColor[
             0.6897321356838528, 0.7573309968268753, 0.969854832583904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 152}], {
             RGBColor[
             0.7505556101005695, 0.805272099598698, 0.9758042753225229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 159}], {
             RGBColor[
             0.7825053279679303, 0.8307270834039218, 0.9781286476958152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 164}], {
             RGBColor[
             0.577748984971401, 0.6680816791517759, 0.9599016629426653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 178}], {
             RGBColor[
             0.6825309091796732, 0.7517053439504617, 0.9691370816252551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 200}], {
             RGBColor[
             0.7569238102233509, 0.8103499295164165, 0.9764116799351932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 17}], {
             RGBColor[
             0.7548191183186175, 0.8086200236918599, 0.9762704171507568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 27}], {
             RGBColor[
             0.5014681378836364, 0.6042054742697451, 0.9544347870286866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 29}], {
             RGBColor[
             0.6185688153479594, 0.7012210563638682, 0.9631151495178736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 30}], {
             RGBColor[
             0.6136383955907412, 0.6972183194920796, 0.9627270088138626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 42}], {
             RGBColor[
             0.7274662384558757, 0.7868095797634542, 0.9736614750512443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 51}], {
             RGBColor[
             0.5855809779450312, 0.6744400438750314, 0.960518226119085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 62}], {
             RGBColor[
             0.7894562979393764, 0.8356752462003303, 0.960036400337279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 71}], {
             RGBColor[
             0.7267270807161301, 0.7862201954456836, 0.9735909735261735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 73}], {
             RGBColor[
             0.5350489232776385, 0.6332914627586803, 0.9565745249796698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 75}], {
             RGBColor[
             0.6090782968587007, 0.6935162259113026, 0.9623680211374843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 89}], {
             RGBColor[
             0.5605739168268238, 0.6541381851040056, 0.9585495786639766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 107}], {
             RGBColor[
             0.5014681378836364, 0.6042054742697451, 0.9544347870286866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.8042276563625281, 0.8358083528223099, 0.6838500618285015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 130}], {
             RGBColor[
             0.6139200542732526, 0.6974469826991214, 0.9627491820170997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 141}], {
             RGBColor[
             0.8080800882307019, 0.8478025621871621, 0.8495928471399475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 142}], {
             RGBColor[
             0.5929646647799611, 0.6804344534789288, 0.9610994969940667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 147}], {
             RGBColor[
             0.5244219057649784, 0.6240868743186447, 0.9558973808208657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 149}], {
             RGBColor[
             0.7588238973005261, 0.6627165665940193, 0.5992533177913417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 167}], {
             RGBColor[
             0.7249403500878575, 0.7847955049422097, 0.9734205535638156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 168}], {
             RGBColor[
             0.5014681378836364, 0.6042054742697451, 0.9544347870286866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 188}], {
             RGBColor[
             0.6334612393165773, 0.7132623355598917, 0.96432107928572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.7822085429525024, 0.8302698823982293, 0.9723049590128103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 194}], {
             RGBColor[
             0.734618202587056, 0.7925123618267629, 0.9743436357747101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 197}], {
             RGBColor[
             0.7927669379359923, 0.8381443160891309, 0.9544323503762082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 35}], {
             RGBColor[
             0.8626567615706486, 0.8925246671491187, 0.9348328202136726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 70}], {
             RGBColor[
             0.9594938656518066, 0.9690943803682406, 0.9442405427506698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 86}], {
             RGBColor[
             0.9836081546467167, 0.9871280693076558, 0.9051303153500688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 94}], {
             RGBColor[
             0.7226276937887667, 0.7803402331365226, 0.9227853896454603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 110}], {
             RGBColor[
             0.7765229992040061, 0.8240948700284542, 0.9270282255127569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 138}], {
             RGBColor[
             0.7365053058756985, 0.7916067038079939, 0.9238778861043118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 174}], {
             RGBColor[
             0.9900661622973838, 0.9898582783593841, 0.7923524410660858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 182}], {
             RGBColor[
             0.6833878584579236, 0.7465355902773243, 0.9202345178626834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 196}], {
             RGBColor[
             0.8280671888099453, 0.8655030300179677, 0.9313852548588211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 33}], {
             RGBColor[
             0.7478704968750152, 0.7979991377395248, 0.773099071611942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 44}], {
             RGBColor[
             0.9501059755427972, 0.9588383314439024, 0.7915979997546178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 58}], {
             RGBColor[
             0.9616218638008132, 0.9680207881503848, 0.7926963954570221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 68}], {
             RGBColor[
             0.9575445655479171, 0.8571800531814372, 0.4238091562448002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 77}], {
             RGBColor[
             0.993674771957967, 0.9888793017337734, 0.5529161462864377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 96}], {
             RGBColor[
             0.9768478388567567, 0.9795436991595539, 0.7727267841051503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 99}], {
             RGBColor[
             0.6878059819211987, 0.7472880818212706, 0.7689088047659296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 102}], {
             RGBColor[
             0.7662900663025056, 0.812952973992908, 0.7745491275903801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 128}], {
             RGBColor[
             0.7938512567169278, 0.8353283899888148, 0.7767188454597704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 140}], {
             RGBColor[
             0.9166022879749423, 0.9321234004106669, 0.7884023881253008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 162}], {
             RGBColor[
             0.6878059819211987, 0.7472880818212706, 0.7689088047659296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 172}], {
             RGBColor[
             0.6878059819211987, 0.7472880818212706, 0.7689088047659296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 31}], {
             RGBColor[
             0.8012495989482817, 0.8449165818519657, 0.980757050652294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 34}], {
             RGBColor[
             0.7036583329417953, 0.768422504786316, 0.9710977446328024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 36}], {
             RGBColor[
             0.8727384361497418, 0.8980268095659034, 0.8101218006230058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 63}], {
             RGBColor[
             0.8441457001269794, 0.8790787071857293, 0.9833902252350663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 64}], {
             RGBColor[
             0.6055082446782967, 0.688954247865514, 0.9632244193616681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 70}], {
             RGBColor[
             0.8423744165413366, 0.877708395097232, 0.9846795724668775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 97}], {
             RGBColor[
             0.8650206553904133, 0.8946472146415961, 0.9480543710343726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 132}], {
             RGBColor[
             0.870652784880382, 0.8978255334920254, 0.8927482871392297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 138}], {
             RGBColor[
             0.6193858567652285, 0.7002207185369853, 0.9643169158205196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 145}], {
             RGBColor[
             0.6594099048702178, 0.7327140438514351, 0.9674677555002633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 153}], {
             RGBColor[
             0.8719887539455204, 0.8964233151355719, 0.728523519195788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 185}], {
             RGBColor[
             0.8632609332666242, 0.8672990567542249, 0.6676851375197302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 22}], {
             RGBColor[
             0.949000049556062, 0.8232864948568983, 0.4143012506779698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 48}], {
             RGBColor[
             0.7432317681509477, 0.7942009093501734, 0.7700866374214629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 106}], {
             RGBColor[
             0.9676450666155242, 0.97264637972737, 0.7856143045676598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 131}], {
             RGBColor[
             0.9059278802018205, 0.9235963686818831, 0.7847328639334457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 176}], {
             RGBColor[
             0.7229824430393347, 0.777725186715752, 0.7685025960911627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 59}], {
             RGBColor[
             0.9309167692429536, 0.9477517790045271, 0.9932728665612451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.9460431150338608, 0.9592495922245495, 0.975177888999549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 114}], {
             RGBColor[
             0.8097651837561837, 0.8522398513218381, 0.9814277869347208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 167}], {
             RGBColor[
             0.8815271671823419, 0.908369850966429, 0.9885620422260857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 184}], {
             RGBColor[
             0.9227652594025786, 0.9412519863246522, 0.9924953682757314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 186}], {
             RGBColor[
             0.9299591967505021, 0.9469882366916591, 0.9931815324420801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 194}], {
             RGBColor[
             0.8912050196815405, 0.916086707850982, 0.9894851244369802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 52}], {
             RGBColor[
             0.8250117754646028, 0.8639739460603852, 0.9735260122499669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 61}], {
             RGBColor[
             0.5776250204440656, 0.6669884945104785, 0.9605496855455204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 67}], {
             RGBColor[
             0.6803447594698162, 0.7502097640002852, 0.9687740655068466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 80}], {
             RGBColor[
             0.6818926068746183, 0.7514189541569924, 0.9689283404707009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 82}], {
             RGBColor[
             0.5426951415532351, 0.6367339890420012, 0.9583239845498759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 84}], {
             RGBColor[
             0.5426951415532351, 0.6367339890420012, 0.9583239845498759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 100}], {
             RGBColor[
             0.7822202223045289, 0.830124141350393, 0.9788408880175896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 120}], {
             RGBColor[
             0.7365868170130061, 0.794146486808494, 0.9743797481908417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 125}], {
             RGBColor[
             0.7970818541765854, 0.8419744031969203, 0.9802584037326818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.5426951415532351, 0.6367339890420012, 0.9583239845498759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 30}], {
             RGBColor[
             0.7470967482322635, 0.80235065576695, 0.9756624838895853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[
             0.860924591097398, 0.8919419160383245, 0.9865969501269669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 51}], {
             RGBColor[
             0.7190393305865534, 0.7795723801499017, 0.9734537011948077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 73}], {
             RGBColor[
             0.6685072759191609, 0.7384237990335506, 0.9695100000553925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 87}], {
             RGBColor[
             0.7094857700892219, 0.7718163693551721, 0.9727016099166125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 89}], {
             RGBColor[
             0.6940322694683463, 0.7592705213788757, 0.9714850537396992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 106}], {
             RGBColor[
             0.914789914427099, 0.9347481675547311, 0.9867249344508177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 107}], {
             RGBColor[
             0.6349264905251588, 0.7093378105446153, 0.9673702621044091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 130}], {
             RGBColor[
             0.7473784069147749, 0.8025793189739917, 0.9756846570928224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 131}], {
             RGBColor[
             0.8530727280133954, 0.8856981565092443, 0.9858434938166034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 142}], {
             RGBColor[
             0.7264230174214835, 0.7855667897537992, 0.9740349720697894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 147}], {
             RGBColor[
             0.6578802584065009, 0.7292192105935151, 0.9688328558965884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 149}], {
             RGBColor[
             0.8922822499420485, 0.7678489028688895, 0.6121887928670643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 157}], {
             RGBColor[
             0.6665107228806306, 0.7366944851412491, 0.9693827814612599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 168}], {
             RGBColor[
             0.6349264905251588, 0.7093378105446153, 0.9673702621044091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 188}], {
             RGBColor[
             0.7669195919580998, 0.8183946718347619, 0.9772565543614425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 189}], {
             RGBColor[
             0.9156668955940248, 0.9354022186730996, 0.985240434088533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 197}], {
             RGBColor[
             0.9262252905775147, 0.9432766523640013, 0.9673678254519309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 24}], {
             RGBColor[
             0.6140354926158418, 0.6926798958827576, 0.9653776600742046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 32}], {
             RGBColor[
             0.4338271865795682, 0.5492915028109718, 0.9491098435650616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 39}], {
             RGBColor[
             0.28025125504508885`, 0.40515863056125023`, 0.9395178159911695]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 41}], {
             RGBColor[
             0.6544373243550103, 0.7248952198330634, 0.9692312228526274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 85}], {
             RGBColor[
             0.47056918364376044`, 0.5791203112357881, 0.9520023081643247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 103}], {
             RGBColor[
             0.3815755100901777, 0.5049232611225005, 0.945534631982339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 108}], {
             RGBColor[
             0.4801679203345929, 0.5869129980995661, 0.9527579558779581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 117}], {
             RGBColor[
             0.6866132477585567, 0.7478693716418601, 0.8667814701112548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 133}], {
             RGBColor[
             0.4370996504116456, 0.5519482363726679, 0.9493674639053526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 152}], {
             RGBColor[
             0.6270918837641704, 0.7030907077781384, 0.9666229903175101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 178}], {
             RGBColor[
             0.5590671828432741, 0.6495239521299021, 0.9599557966202423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 33}], {
             RGBColor[
             0.7330664018802504, 0.7896683054166855, 0.949506507958084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 74}], {
             RGBColor[
             0.7105737991861237, 0.7714077972693896, 0.947735807880884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 85}], {
             RGBColor[
             0.7619955604800166, 0.8131542996117191, 0.9517839172940573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 88}], {
             RGBColor[
             0.7838878630035805, 0.830927457037338, 0.9535073595428587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 93}], {
             RGBColor[
             0.8899795556402896, 0.9144047006550625, 0.9636730008097317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 95}], {
             RGBColor[
             0.8738490711002327, 0.47134788907946423`, 0.4316872109693338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 102}], {
             RGBColor[
             0.7514859713077409, 0.8046221416700688, 0.9509565639365221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 121}], {
             RGBColor[
             0.8576947861837099, 0.8891835933822465, 0.9604551567086238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 140}], {
             RGBColor[
             0.9017981929801775, 0.9237925680878277, 0.9648098244714428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 159}], {
             RGBColor[
             0.9504679784677873, 0.962579679959293, 0.968728971820535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 161}], {
             RGBColor[
             0.7943435652455257, 0.8394158671413672, 0.954330470723844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 162}], {
             RGBColor[
             0.6730018869264339, 0.7389572494984314, 0.9453162411120717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 164}], {
             RGBColor[
             0.7457116354712581, 0.7999342757071471, 0.9505019870673851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 172}], {
             RGBColor[
             0.6730018869264339, 0.7389572494984314, 0.9453162411120717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 173}], {
             RGBColor[
             0.9061519516298535, 0.9272641370554492, 0.9652250898580952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 180}], {
             RGBColor[
             0.9458637011912666, 0.9589292082089942, 0.9690128319823601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 22}], {
             RGBColor[
             0.9163387580571192, 0.7059562472407482, 0.25153920604496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 46}], {
             RGBColor[
             0.7622584102557204, 0.7188332547483928, 0.611393656260877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 47}], {
             RGBColor[
             0.7281089246476958, 0.6911091639150034, 0.6087052836601258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 50}], {
             RGBColor[
             0.789984330856397, 0.7412053882674595, 0.6136700221552474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 101}], {
             RGBColor[
             0.6551203512146411, 0.6299057751011041, 0.6034975875882416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 135}], {
             RGBColor[
             0.9450116879199558, 0.8181012549386291, 0.28292240614993297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 144}], {
             RGBColor[
             0.9608172032215754, 0.871129236953393, 0.3687905356398114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 23}], {
             RGBColor[
             0.9314997725878954, 0.9480721548751336, 0.9883187356392609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 55}], {
             RGBColor[
             0.9357166251286451, 0.9512170765955623, 0.9811807042190566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 61}], {
             RGBColor[
             0.6865662275767859, 0.7529163033334951, 0.971189764288497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 67}], {
             RGBColor[
             0.7892859666025365, 0.8361375728233017, 0.9794141442498232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 83}], {
             RGBColor[
             0.8718074208867175, 0.9006195891057828, 0.9876349641474891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 90}], {
             RGBColor[
             0.9575085796103562, 0.9642603774882395, 0.7533459241974596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 122}], {
             RGBColor[
             0.8982785507338977, 0.9217269495062462, 0.9901598041433697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 166}], {
             RGBColor[
             0.9271311323280862, 0.9447332148869882, 0.9929117891328271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 170}], {
             RGBColor[
             0.9052350929408046, 0.7641131618116512, 0.6106476485114324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 175}], {
             RGBColor[
             0.8656593240867697, 0.8958010201490001, 0.9870263267742474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 177}], {
             RGBColor[
             0.9572779842527608, 0.9637671573351101, 0.7282470425927972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 179}], {
             RGBColor[
             0.7837633236437369, 0.8318232421702465, 0.9788636988117227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 183}], {
             RGBColor[
             0.8521117290939109, 0.4028847782025117, 0.440276498201122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 192}], {
             RGBColor[
             0.6753637853569509, 0.7432133109337914, 0.9704759545761799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.6982440423700196, 0.6279386198950638, 0.597403255639269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 72}], {
             RGBColor[
             0.7090902367242655, 0.636744049087328, 0.5982571077897543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 144}], {
             RGBColor[
             0.9484907689395901, 0.8221971951144333, 0.35886919849062726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 176}], {
             RGBColor[
             0.6779947172584064, 0.6114628972606424, 0.5958192143089687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 38}], {
             RGBColor[
             0.9389050255334713, 0.9539560485934779, 0.9883020350372109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 43}], {
             RGBColor[
             0.8142159757114751, 0.855627051538308, 0.9768471455165659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 55}], {
             RGBColor[
             0.9455192104348078, 0.9588888968631608, 0.9771059452549515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 60}], {
             RGBColor[
             0.661438933992118, 0.7303336181326163, 0.9648893043287474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 90}], {
             RGBColor[
             0.9673111649165189, 0.971932197755838, 0.7492711652333546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 111}], {
             RGBColor[
             0.967010767074772, 0.9712896771472219, 0.7165747139997857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 115}], {
             RGBColor[
             0.735306318186019, 0.7922504651121443, 0.9701661836029154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 163}], {
             RGBColor[
             0.967010767074772, 0.9712896771472219, 0.7165747139997857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 165}], {
             RGBColor[
             0.9657199903828857, 0.972966821497862, 0.8986763094560551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 169}], {
             RGBColor[
             0.7417004334941983, 0.7974414959709364, 0.9706695517823913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 175}], {
             RGBColor[
             0.8754619093929324, 0.9034728404165986, 0.9829515678101425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 177}], {
             RGBColor[
             0.9670805695589235, 0.9714389776027086, 0.7241722836286921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 39}], {
             RGBColor[
             0.5127112375707529, 0.5929152653215074, 0.959360844083035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 41}], {
             RGBColor[
             0.8868973068806745, 0.9126518545933204, 0.989074250944493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 55}], {
             RGBColor[
             0.8981157690585315, 0.9212351746133021, 0.9775943010004087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 108}], {
             RGBColor[
             0.7126279028602569, 0.7746696328598233, 0.9726009839698236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 111}], {
             RGBColor[
             0.9196073256984958, 0.9336359548973633, 0.7170630697452427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 115}], {
             RGBColor[
             0.6879028768097428, 0.7545967428622856, 0.9706545393483724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 133}], {
             RGBColor[
             0.6695596329373097, 0.739704871132925, 0.9692104919972182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 163}], {
             RGBColor[
             0.9196073256984958, 0.9336359548973633, 0.7170630697452427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 165}], {
             RGBColor[
             0.9183165490066095, 0.9353130992480032, 0.8991646652015122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 175}], {
             RGBColor[
             0.8280584680166563, 0.86581911816674, 0.9834399235555995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 38}], {
             RGBColor[
             0.6978465572079613, 0.7619972794668184, 0.971463999146295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[
             0.5731575073859652, 0.6636682824116484, 0.9600091096256501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 60}], {
             RGBColor[
             0.4203804656666079, 0.5383748490059568, 0.9480512684378316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 111}], {
             RGBColor[
             0.7259522987492619, 0.7793309080205625, 0.6997366781088699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 165}], {
             RGBColor[
             0.7246615220573758, 0.7810080523712024, 0.8818382735651393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 58}], {
             RGBColor[
             0.705731016461594, 0.7684719191914827, 0.9727469105188267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 67}], {
             RGBColor[
             0.5695647524985608, 0.6612149878206524, 0.9594094007847047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 80}], {
             RGBColor[
             0.5711125999033628, 0.6624241779773599, 0.959563675748559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 82}], {
             RGBColor[
             0.4319151345819796, 0.5477392128623685, 0.9489593198277341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 96}], {
             RGBColor[
             0.7209569915175377, 0.7799948302006517, 0.9527772991669547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 98}], {
             RGBColor[
             0.4319151345819796, 0.5477392128623685, 0.9489593198277341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 99}], {
             RGBColor[
             0.4319151345819796, 0.5477392128623685, 0.9489593198277341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[
             0.6714402153332735, 0.7411293651707603, 0.9694762232954478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 116}], {
             RGBColor[
             0.6839055694313536, 0.7510689001655464, 0.9706651798972756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 120}], {
             RGBColor[
             0.6258068100417506, 0.7051517106288613, 0.9650150834686999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 122}], {
             RGBColor[
             0.6785573366299222, 0.7468043645035969, 0.9701550606782514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 124}], {
             RGBColor[
             0.5577562800706539, 0.6518507006522574, 0.9583277639771872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 125}], {
             RGBColor[
             0.6863018472053299, 0.7529796270172877, 0.9708937390105399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 128}], {
             RGBColor[
             0.5379604093777087, 0.6357795210299126, 0.956769360521575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 136}], {
             RGBColor[
             0.6622889007798062, 0.7338323553516417, 0.9686033627438632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 137}], {
             RGBColor[
             0.49010660415002916`, 0.5969296461567241, 0.9530021336797876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.7074099182241105, 0.769810629884339, 0.9729070456677087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 170}], {
             RGBColor[
             0.6855138788368289, 0.589190576809002, 0.590642905046314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 187}], {
             RGBColor[
             0.4319151345819796, 0.5477392128623685, 0.9489593198277341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 192}], {
             RGBColor[
             0.45564257125297525`, 0.568290725931142, 0.9504712111110616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 198}], {
             RGBColor[
             0.5991379847731417, 0.684317821638445, 0.9623569842002666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 29}], {
             RGBColor[
             0.4986761875545006, 0.6019388432166237, 0.9542149944715259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 30}], {
             RGBColor[
             0.4937457677972824, 0.5979361063448351, 0.9538268537675151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 42}], {
             RGBColor[
             0.607573610662417, 0.6875273666162096, 0.9647613200048968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 62}], {
             RGBColor[
             0.6695636701459178, 0.7363930330530858, 0.9511362452909314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 71}], {
             RGBColor[
             0.6068344529226715, 0.6869379822984389, 0.964690818479826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 73}], {
             RGBColor[
             0.41515629548417987`, 0.5340092496114357, 0.9476743699333223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 75}], {
             RGBColor[
             0.4891856690652421, 0.594234012764058, 0.9534678660911369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 89}], {
             RGBColor[
             0.4406812890333651, 0.554855971956761, 0.9496494236176289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 127}], {
             RGBColor[
             0.5406898673295565, 0.6351674535778149, 0.9581241175556126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 129}], {
             RGBColor[
             0.6843350285690695, 0.7365261396750653, 0.6749499067821539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 141}], {
             RGBColor[
             0.6881874604372431, 0.7485203490399175, 0.8406926920936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 142}], {
             RGBColor[
             0.47307203698650246`, 0.5811522403316843, 0.9521993419477193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 147}], {
             RGBColor[
             0.4045292779715197, 0.5248046611714002, 0.9469972257745182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 149}], {
             RGBColor[
             0.6389312695070675, 0.5634343534467747, 0.5903531627449942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 155}], {
             RGBColor[
             0.523066895061245, 0.62140025370226, 0.9563676243759466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 167}], {
             RGBColor[
             0.6050477222943987, 0.6855132917949652, 0.964520398517468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 168}], {
             RGBColor[
             0.3815755100901777, 0.5049232611225005, 0.945534631982339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 188}], {
             RGBColor[
             0.5135686115231186, 0.6139801224126471, 0.9554209242393723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 189}], {
             RGBColor[
             0.6623159151590436, 0.7309876692509847, 0.9634048039664628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[
             0.6147255747935974, 0.6932301486795183, 0.9654434807283625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 197}], {
             RGBColor[
             0.6728743101425336, 0.7388621029418864, 0.9455321953298607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 97}], {
             RGBColor[
             0.6965120678289178, 0.7584389081015082, 0.9339467054678507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 105}], {
             RGBColor[
             0.5671186918542181, 0.6571885822046454, 0.9601764448840103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.7866643476102406, 0.8334086151472089, 0.9598166077801185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 71}], {
             RGBColor[
             0.7239351303869944, 0.7839535643925621, 0.9733711809690129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 73}], {
             RGBColor[
             0.5322569729485028, 0.6310248317055589, 0.9563547324225092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 129}], {
             RGBColor[
             0.8014357060333924, 0.8335417217691885, 0.683630269271341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 141}], {
             RGBColor[
             0.8052881379015662, 0.8455359311340407, 0.8493730545827869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 149}], {
             RGBColor[
             0.7560319469713903, 0.6604499355408979, 0.5990335252341811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 167}], {
             RGBColor[
             0.7221483997587217, 0.7825288738890883, 0.973200761006655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 168}], {
             RGBColor[
             0.4986761875545006, 0.6019388432166237, 0.9542149944715259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 189}], {
             RGBColor[
             0.7794165926233667, 0.8280032513451079, 0.9720851664556498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 194}], {
             RGBColor[
             0.7318262522579203, 0.7902457307736415, 0.9741238432175494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 197}], {
             RGBColor[
             0.7899749876068565, 0.8358776850360095, 0.9542125578190477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 42}], {
             RGBColor[
             0.7197438683695216, 0.7805402118385443, 0.9730535417900729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 51}], {
             RGBColor[
             0.5778586078586772, 0.6681706759501214, 0.9599102928579135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 71}], {
             RGBColor[
             0.7190047106297762, 0.7799508275207736, 0.972983040265002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 73}], {
             RGBColor[
             0.5273265531912846, 0.6270220948337704, 0.9559665917184983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 76}], {
             RGBColor[
             0.6326775464000904, 0.7124135149759816, 0.9644047285192161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 81}], {
             RGBColor[
             0.7494119018869467, 0.8041966964480224, 0.975883305311931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 87}], {
             RGBColor[
             0.5683050473613456, 0.6604146651553918, 0.9591582015797184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 89}], {
             RGBColor[
             0.5528515467404699, 0.6478688171790955, 0.9579416454028051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 106}], {
             RGBColor[
             0.7736091916992227, 0.8233464633549509, 0.9731815261139236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 107}], {
             RGBColor[
             0.4937457677972824, 0.5979361063448351, 0.9538268537675151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 130}], {
             RGBColor[
             0.6061976841868986, 0.6911776147742115, 0.9621412487559282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 131}], {
             RGBColor[
             0.711892005285519, 0.774296452309464, 0.9723000854797094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 142}], {
             RGBColor[
             0.5852422946936071, 0.6741650855540189, 0.9604915637328952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 147}], {
             RGBColor[
             0.5166995356786245, 0.6178175063937348, 0.9552894475596942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 157}], {
             RGBColor[
             0.5253300001527543, 0.6252927809414688, 0.9558393731243657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 168}], {
             RGBColor[
             0.4937457677972824, 0.5979361063448351, 0.9538268537675151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 176}], {
             RGBColor[
             0.5289465681230331, 0.6284252703433328, 0.9560698176374264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 188}], {
             RGBColor[
             0.6257388692302234, 0.7069929676349817, 0.9637131460245485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 197}], {
             RGBColor[
             0.7850445678496383, 0.8318749481642209, 0.9538244171150367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 34}], {
             RGBColor[
             0.7539466232853476, 0.807963137748151, 0.9760423321096532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[
             0.7725072932917387, 0.8224628742234605, 0.9778922862365674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 45}], {
             RGBColor[
             0.7515788543073203, 0.8061134186268053, 0.9758063350259825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 64}], {
             RGBColor[
             0.6557965350218489, 0.7284948808273488, 0.9681690068385188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 65}], {
             RGBColor[
             0.9010522479317868, 0.9235552257257662, 0.977131829148009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 132}], {
             RGBColor[
             0.9209410752239342, 0.9373661664538604, 0.8976928746160804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 138}], {
             RGBColor[
             0.6696741471087808, 0.7397613514988202, 0.9692615032973702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 153}], {
             RGBColor[
             0.9222770442890728, 0.9359639480974069, 0.7334681066726386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 156}], {
             RGBColor[
             0.835190331877818, 0.8714313403756437, 0.9841399457165277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 182}], {
             RGBColor[
             0.6165566996910059, 0.6946902379681505, 0.9656181350557418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 185}], {
             RGBColor[
             0.9135492236101765, 0.9068396897160599, 0.6726297249965809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 199}], {
             RGBColor[
             0.6165566996910059, 0.6946902379681505, 0.9656181350557418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 39}], {
             RGBColor[
             0.33250293153447935`, 0.44952687224972154`, 0.943093027573892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 57}], {
             RGBColor[
             0.7405337682123154, 0.7926746742335495, 0.8243056300574627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 103}], {
             RGBColor[
             0.4338271865795682, 0.5492915028109718, 0.9491098435650616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 117}], {
             RGBColor[
             0.7388649242479473, 0.7922376133303315, 0.8703566816939774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 133}], {
             RGBColor[
             0.4893513269010361, 0.5963164780611392, 0.9529426754880752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 152}], {
             RGBColor[
             0.6793435602535609, 0.7474589494666097, 0.9701982019002326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 178}], {
             RGBColor[
             0.6113188593326645, 0.6938921938183733, 0.9635310082029649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 44}], {
             RGBColor[
             0.7039400186655926, 0.7671845666633865, 0.9724140938170396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 58}], {
             RGBColor[
             0.7154559069236086, 0.776367023369869, 0.973512489519444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 68}], {
             RGBColor[
             0.7113786086707126, 0.6655262884009212, 0.604625250307222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 77}], {
             RGBColor[
             0.7475088150807626, 0.7972255369532575, 0.7337322403488595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 96}], {
             RGBColor[
             0.7306818819795522, 0.787889934379038, 0.9535428781675721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 99}], {
             RGBColor[
             0.44164002504399413`, 0.5556343170407547, 0.9497248988283514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 102}], {
             RGBColor[
             0.5201241094253011, 0.6212992092123921, 0.9553652216528019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 128}], {
             RGBColor[
             0.5476852998397232, 0.6436746252082988, 0.9575349395221924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 140}], {
             RGBColor[
             0.6704363310977377, 0.740469635630151, 0.9692184821877226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 162}], {
             RGBColor[
             0.44164002504399413`, 0.5556343170407547, 0.9497248988283514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 172}], {
             RGBColor[
             0.44164002504399413`, 0.5556343170407547, 0.9497248988283514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 180}], {
             RGBColor[
             0.7145018393088269, 0.7756062757513175, 0.9734214896986398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 40}], {
             RGBColor[
             0.6749160272852522, 0.7459687971578111, 0.9682329802170759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 45}], {
             RGBColor[
             0.6539875883008337, 0.7296193415611558, 0.966147029006491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 54}], {
             RGBColor[
             0.6896739969992682, 0.7574978352631243, 0.9697039167171009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 64}], {
             RGBColor[
             0.5582052690153624, 0.6520008037616993, 0.9585097008190273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 65}], {
             RGBColor[
             0.8034609819253002, 0.8470611486601166, 0.9674725231285175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 132}], {
             RGBColor[
             0.8233498092174476, 0.8608720893882107, 0.8880335685965888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 138}], {
             RGBColor[
             0.5720828811022942, 0.6632672744331706, 0.9596021972778787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 153}], {
             RGBColor[
             0.8246857782825863, 0.8594698710317572, 0.7238088006531471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 182}], {
             RGBColor[
             0.5189654336845193, 0.618196160902501, 0.9559588290362503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 185}], {
             RGBColor[
             0.8159579576036899, 0.8303456126504103, 0.6629704189770894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 199}], {
             RGBColor[
             0.5189654336845193, 0.618196160902501, 0.9559588290362503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 86}], {
             RGBColor[
             0.8610647093916957, 0.8915048170246265, 0.9450287318207136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.6000842485337456, 0.6847169808534932, 0.9626838061161052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 110}], {
             RGBColor[
             0.6539795539489852, 0.7284716177454249, 0.9669266419834017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 174}], {
             RGBColor[
             0.8675227170423627, 0.8942350260763549, 0.8322508575367306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 63}], {
             RGBColor[
             0.9659228276719916, 0.9717295678615019, 0.8176995626826287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 70}], {
             RGBColor[
             0.9641515440863488, 0.9703592557730045, 0.81898890991444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 110}], {
             RGBColor[
             0.7811806776385484, 0.8253597454332182, 0.801776592676527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 138}], {
             RGBColor[
             0.7411629843102407, 0.7928715792127579, 0.7986262532680819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 145}], {
             RGBColor[
             0.7811870324152301, 0.8253649045272078, 0.8017770929478256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 185}], {
             RGBColor[
             0.9850380608116365, 0.9599499174299977, 0.5019944749672927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 45}], {
             RGBColor[
             0.5519050520932798, 0.646927926134702, 0.957972587455769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 47}], {
             RGBColor[
             0.48987147091002015`, 0.5967081342899465, 0.9529920835574126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 50}], {
             RGBColor[
             0.5517468771187214, 0.6468043586424026, 0.9579568220525342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 97}], {
             RGBColor[
             0.7156351435199251, 0.7750023551113276, 0.9351652109410098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 101}], {
             RGBColor[
             0.41688289747696544`, 0.5355047454760471, 0.9477843874855283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 105}], {
             RGBColor[
             0.5862417675452255, 0.6737520292144648, 0.9613949503571695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 134}], {
             RGBColor[
             0.5744262468369349, 0.6645216546358649, 0.9602172896752859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 135}], {
             RGBColor[
             0.7067742341822802, 0.723700225313572, 0.6272092060472197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 160}], {
             RGBColor[
             0.5322154838812485, 0.6310849115960353, 0.956325559369738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 43}], {
             RGBColor[
             0.8118186433508883, 0.8538391249890538, 0.9809052038786209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 60}], {
             RGBColor[
             0.6590416016315311, 0.7285456915833621, 0.9689473626908024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 90}], {
             RGBColor[
             0.9649138325559321, 0.9701442712065838, 0.7533292235954095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 111}], {
             RGBColor[
             0.9646134347141851, 0.9695017505979677, 0.7206327723618406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 165}], {
             RGBColor[
             0.9633226580222989, 0.9711788949486078, 0.9027343678181101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 169}], {
             RGBColor[
             0.7393031011336115, 0.7956535694216822, 0.9747276101444463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 41}], {
             RGBColor[
             0.5531130693099215, 0.6251305892718131, 0.9632144068614579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 74}], {
             RGBColor[
             0.31782316730477866`, 0.43760917833220836`, 0.9419373827599817]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 85}], {
             RGBColor[
             0.36924492859867153`, 0.47935568067453793`, 0.9459854921731552]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 88}], {
             RGBColor[
             0.3911372311222354, 0.49712883810015673`, 0.9477089344219567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 108}], {
             RGBColor[
             0.3788436652895041, 0.4871483675383158, 0.9467411398867887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 117}], {
             RGBColor[
             0.5852889927134679, 0.6481047410806098, 0.8607646541200854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 133}], {
             RGBColor[
             0.33577539536655676`, 0.4521836058114176, 0.9433506479141831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 152}], {
             RGBColor[
             0.5257676287190816, 0.6033260772168882, 0.9606061743263405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 159}], {
             RGBColor[
             0.5577173465864422, 0.6287810610221118, 0.962930546699633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 173}], {
             RGBColor[
             0.5134013197485086, 0.593465518118268, 0.959426664737193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 178}], {
             RGBColor[
             0.4577429277981852, 0.5497593215686518, 0.9539389806290729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 49}], {
             RGBColor[
             0.6484120797680573, 0.724666104916717, 0.9659999015939518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 53}], {
             RGBColor[
             0.7531363725867526, 0.8070751254039856, 0.9760292532260428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 54}], {
             RGBColor[
             0.7082346670056594, 0.771997571738434, 0.9715538708440152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 64}], {
             RGBColor[
             0.5767659390217537, 0.6665005402370089, 0.9603596549459416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.8220216519316915, 0.8615608851354262, 0.9693224772554317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 69}], {
             RGBColor[
             0.8430979367735647, 0.8736519563924162, 0.7094941928342028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 119}], {
             RGBColor[
             0.8431188121505959, 0.8736966067130618, 0.7117663487961665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 123}], {
             RGBColor[
             0.6191132839872111, 0.7008800226061176, 0.9636933930650582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 132}], {
             RGBColor[
             0.841910479223839, 0.8753718258635204, 0.8898835227235031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 171}], {
             RGBColor[
             0.6033210747584195, 0.6880591957232662, 0.9624501725057992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 182}], {
             RGBColor[
             0.5375261036909106, 0.6326958973778105, 0.9578087831631645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 191}], {
             RGBColor[
             0.7538190327598242, 0.8076084247195987, 0.9760972944122726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 195}], {
             RGBColor[
             0.598433740162089, 0.6840914373260507, 0.9620654236234796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 196}], {
             RGBColor[
             0.6822054340429324, 0.751663337118454, 0.9689595201593023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 199}], {
             RGBColor[
             0.5375261036909106, 0.6326958973778105, 0.9578087831631645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 74}], {
             RGBColor[
             0.6920092366147003, 0.7573457676040214, 0.9716507896214397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 85}], {
             RGBColor[
             0.7434309979085931, 0.799092269946351, 0.9756988990346132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.765323300432157, 0.8168654273719698, 0.9774223412834145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 108}], {
             RGBColor[
             0.7530297345994257, 0.8068849568101288, 0.9764545467482465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 121}], {
             RGBColor[
             0.8391302236122864, 0.8751215637168784, 0.9843701384491796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 133}], {
             RGBColor[
             0.7099614646764784, 0.7719201950832306, 0.9730640547756411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 140}], {
             RGBColor[
             0.883233630408754, 0.9097305384224597, 0.9887248062119987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 151}], {
             RGBColor[
             0.951429848274181, 0.9370446715809726, 0.6762428127934665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 152}], {
             RGBColor[
             0.899953698029003, 0.9230626664887012, 0.9903195811877985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 159}], {
             RGBColor[
             0.9319034158963638, 0.948517650293925, 0.9926439535610908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 161}], {
             RGBColor[
             0.7757790026741023, 0.825353837475999, 0.9782454524643998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 173}], {
             RGBColor[
             0.88758738905843, 0.9132021073900811, 0.9891400715986509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 51}], {
             RGBColor[
             0.6916864507238116, 0.757761936221496, 0.9708447590952952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 71}], {
             RGBColor[
             0.8328325534949108, 0.8695420877921481, 0.9839175065023837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 73}], {
             RGBColor[
             0.6411543960564191, 0.7166133551051449, 0.9669010579558801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 76}], {
             RGBColor[
             0.746505389265225, 0.8020047752473561, 0.9753391947565977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 81}], {
             RGBColor[
             0.8632397447520812, 0.8937879567193969, 0.9868177715493127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 87}], {
             RGBColor[0.68213289022648, 0.7500059254267664, 0.9700926678171]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 89}], {
             RGBColor[
             0.6666793896056045, 0.73746007745047, 0.9688761116401867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 106}], {
             RGBColor[
             0.8874370345643572, 0.9129377236263254, 0.9841159923513052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 107}], {
             RGBColor[
             0.607573610662417, 0.6875273666162096, 0.9647613200048968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 130}], {
             RGBColor[
             0.720025527052033, 0.780768875045586, 0.9730757149933099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 131}], {
             RGBColor[
             0.8257198481506536, 0.8638877125808386, 0.9832345517170911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 142}], {
             RGBColor[
             0.6990701375587417, 0.7637563458253935, 0.971426029970277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 147}], {
             RGBColor[
             0.6305273785437591, 0.7074087666651094, 0.966223913797076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 149}], {
             RGBColor[
             0.8649293700793067, 0.7460384589404838, 0.609579850767552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 157}], {
             RGBColor[
             0.6391578430178888, 0.7148840412128434, 0.9667738393617474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 168}], {
             RGBColor[
             0.607573610662417, 0.6875273666162096, 0.9647613200048968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 176}], {
             RGBColor[
             0.6427744109881677, 0.7180165306147075, 0.9670042838748081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 188}], {
             RGBColor[
             0.739566712095358, 0.7965842279063562, 0.9746476122619301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 189}], {
             RGBColor[
             0.888314015731283, 0.9135917747446939, 0.9826314919890206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 197}], {
             RGBColor[
             0.8988724107147729, 0.9214662084355956, 0.9647588833524184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 60}], {
             RGBColor[
             0.5343525518095349, 0.6302166945281922, 0.9574924731701575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[
             0.8402247827339357, 0.8718152741514138, 0.7418743340747647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 111}], {
             RGBColor[
             0.8399243848921889, 0.8711727535427978, 0.7091778828411957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 115}], {
             RGBColor[
             0.6082199360034359, 0.6921335415077201, 0.9627693524443254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 163}], {
             RGBColor[
             0.8399243848921889, 0.8711727535427978, 0.7091778828411957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 165}], {
             RGBColor[
             0.8386336082003026, 0.8728498978934378, 0.8912794782974651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 169}], {
             RGBColor[
             0.6146140513116153, 0.6973245723665122, 0.9632727206238014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 58}], {
             RGBColor[
             0.9176913855913906, 0.9372062170742466, 0.9920114176621198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 68}], {
             RGBColor[
             0.9136140873384946, 0.8263654821052989, 0.6231241784498978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 77}], {
             RGBColor[
             0.9497442937485447, 0.9580647306576351, 0.7522311684915353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 96}], {
             RGBColor[
             0.9329173606473343, 0.9487291280834156, 0.9720418063102478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 99}], {
             RGBColor[
             0.6438755037117763, 0.7164735107451323, 0.9682238269710272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 102}], {
             RGBColor[
             0.7223595880930831, 0.7821384029167697, 0.9738641497954776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[
             0.7499207785075054, 0.8045138189126765, 0.9760338676648681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 143}], {
             RGBColor[
             0.9495958483098431, 0.9577472208743887, 0.736073798587924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 166}], {
             RGBColor[
             0.9193702873539071, 0.9385449277671029, 0.9921715528110018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 172}], {
             RGBColor[
             0.6438755037117763, 0.7164735107451323, 0.9682238269710272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 198}], {
             RGBColor[
             0.8110983539029384, 0.8530521195212089, 0.9816214913435597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 64}], {
             RGBColor[
             0.5558375000373351, 0.6501510846403536, 0.9582737037353566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 112}], {
             RGBColor[
             0.705659120083439, 0.7699855349079137, 0.9712971643966626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 132}], {
             RGBColor[
             0.8209820402394203, 0.8590223702668651, 0.8877975715129183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 134}], {
             RGBColor[
             0.6741410140664615, 0.7453633509409731, 0.9681557341423371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 153}], {
             RGBColor[
             0.822318009304559, 0.8576201519104116, 0.7235728035694764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 156}], {
             RGBColor[
             0.7352312968933042, 0.7930875441886485, 0.9742446426133655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 183}], {
             RGBColor[
             0.7620859397742689, 0.3320078741466034, 0.4314490106409401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 47}], {
             RGBColor[
             0.5617021425643117, 0.6550541295836885, 0.9586383967268586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 50}], {
             RGBColor[
             0.6235775487730129, 0.7051503539361446, 0.9636031352219803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 101}], {
             RGBColor[
             0.48871356913125696`, 0.5938507407697892, 0.9534307006549745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 105}], {
             RGBColor[
             0.658072439199517, 0.7320980245082068, 0.9670412635266155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 135}], {
             RGBColor[
             0.7786049058365717, 0.782046220607314, 0.6328555192166658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 144}], {
             RGBColor[
             0.7944104211381913, 0.8350742026220779, 0.7187236487065443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 50}], {
             RGBColor[
             0.5894280631649884, 0.6774262631027552, 0.9609147626212291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 101}], {
             RGBColor[
             0.4545640835232324, 0.5661266499363998, 0.9507423280542232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 105}], {
             RGBColor[
             0.6239229535914925, 0.7043739336748175, 0.9643528909258643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 134}], {
             RGBColor[
             0.6121074328832019, 0.6951435590962176, 0.9631752302439807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 135}], {
             RGBColor[
             0.7444554202285472, 0.7543221297739247, 0.6301671466159147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 144}], {
             RGBColor[
             0.7602609355301666, 0.8073501117886885, 0.7160352761057931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 72}], {
             RGBColor[
             0.5033219553191512, 0.607658463580603, 0.9540424945332473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 76}], {
             RGBColor[
             0.5759574141303496, 0.6663655563865661, 0.9599395119342515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 81}], {
             RGBColor[
             0.6926917696172057, 0.7581487378586069, 0.9714180887269664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 87}], {
             RGBColor[
             0.5115849150916045, 0.6143667065659764, 0.9546929849947539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 104}], {
             RGBColor[
             0.6701757002309612, 0.7401950353124374, 0.969270485928574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 106}], {
             RGBColor[
             0.7168890594294817, 0.7772985047655354, 0.968716309528959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 147}], {
             RGBColor[
             0.45997940340888355`, 0.5717695478043194, 0.9508242309747297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 154}], {
             RGBColor[
             0.5031887204571028, 0.6075502975174301, 0.9540320057968514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 157}], {
             RGBColor[
             0.46860986788301334`, 0.5792448223520534, 0.9513741565394012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 158}], {
             RGBColor[
             0.6584713350262394, 0.7308622922047223, 0.9681541131267375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 176}], {
             RGBColor[
             0.47222643585329216`, 0.5823773117539175, 0.9516046010524618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 53}], {
             RGBColor[
             0.7080717550631662, 0.771272696687582, 0.9719462204760044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 54}], {
             RGBColor[
             0.6631700494820731, 0.7361951430220304, 0.9674708380939767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 65}], {
             RGBColor[
             0.7769570344081052, 0.8257584564190226, 0.9652394445053933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 69}], {
             RGBColor[
             0.7980333192499783, 0.8378495276760126, 0.7054111600841644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 92}], {
             RGBColor[
             0.5449200957439516, 0.6414297079523266, 0.9573172525264968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 118}], {
             RGBColor[
             0.5588224551774994, 0.6527162696346358, 0.9584116971871263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 119}], {
             RGBColor[
             0.7980541946270097, 0.8378941779966582, 0.7076833160461281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 123}], {
             RGBColor[
             0.5740486664636248, 0.665077593889714, 0.9596103603150198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 127}], {
             RGBColor[
             0.651575843406703, 0.7271376611167213, 0.9663152359863998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[
             0.795221004646216, 0.8284963472139718, 0.6831410252129411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 139}], {
             RGBColor[
             0.6078519499839472, 0.6925206222720803, 0.9622714786192471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 141}], {
             RGBColor[
             0.7990734365143898, 0.8404905565788239, 0.8488838105243871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 146}], {
             RGBColor[
             0.7948878914211529, 0.838759726119168, 0.9182491245628004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 155}], {
             RGBColor[
             0.6339528711383917, 0.7133704612411665, 0.9645587428067337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 171}], {
             RGBColor[
             0.5582564572348331, 0.6522567670068626, 0.9583671397557608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 191}], {
             RGBColor[
             0.7087544152362378, 0.7718059960031951, 0.9720142616622341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 195}], {
             RGBColor[
             0.5533691226385027, 0.6482890086096471, 0.9579823908734412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 196}], {
             RGBColor[
             0.6371408165193461, 0.7158609084020504, 0.9648764874092639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 199}], {
             RGBColor[
             0.4924614861673243, 0.5968934686614069, 0.9537257504131261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 97}], {
             RGBColor[
             0.8151917357748932, 0.8557204839241364, 0.9430878900048263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 101}], {
             RGBColor[
             0.5164394897319337, 0.6162228742888559, 0.9557070665493448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 105}], {
             RGBColor[
             0.6857983598001937, 0.7544701580272736, 0.969317629420986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 134}], {
             RGBColor[
             0.6739828390919032, 0.7452397834486737, 0.9681399687391024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 135}], {
             RGBColor[
             0.8063308264372484, 0.8044183541263807, 0.6351318851110362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 144}], {
             RGBColor[
             0.8221363417388678, 0.8574463361411446, 0.7210000146009147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 73}], {
             RGBColor[
             0.4992691355455746, 0.6042438192167221, 0.9537578090237206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 87}], {
             RGBColor[
             0.5402476297156356, 0.6376363895383437, 0.9569494188849408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 106}], {
             RGBColor[
             0.7455517740535127, 0.8005681877379027, 0.970972743419146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[
             0.4656883501515724, 0.5751578307277869, 0.9516180710727374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 130}], {
             RGBColor[
             0.5781402665411886, 0.6683993391571632, 0.9599324660611506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 131}], {
             RGBColor[
             0.683834587639809, 0.7515181766924158, 0.9700913027849317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 147}], {
             RGBColor[
             0.48864211803291446`, 0.5950392307766865, 0.9530806648649166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 157}], {
             RGBColor[
             0.49727258250704426`, 0.6025145053244206, 0.9536305904295881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 168}], {
             RGBColor[
             0.4656883501515724, 0.5751578307277869, 0.9516180710727374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 189}], {
             RGBColor[
             0.7464287552204385, 0.8012222388562711, 0.9694882430568612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 197}], {
             RGBColor[
             0.7569871502039283, 0.8090966725471727, 0.9516156344202591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 66}], {
             RGBColor[
             0.7674872765449992, 0.8182143904503809, 0.9683538162030051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 80}], {
             RGBColor[
             0.8030896093229287, 0.846848183255876, 0.9713410156032551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 82}], {
             RGBColor[
             0.6638921440015455, 0.7321632181408846, 0.96073665968243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 100}], {
             RGBColor[
             0.9034172247528394, 0.9255533704492764, 0.9812535631501438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 120}], {
             RGBColor[
             0.8577838194613165, 0.8895757159073774, 0.976792423323396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 124}], {
             RGBColor[
             0.7897332894902198, 0.8362747059307736, 0.9701051038318833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 125}], {
             RGBColor[
             0.9182788566248958, 0.9374036322958038, 0.982671078865236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 187}], {
             RGBColor[
             0.6638921440015455, 0.7321632181408846, 0.96073665968243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 54}], {
             RGBColor[
             0.7678943423007685, 0.818604163509299, 0.9775001897260679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 65}], {
             RGBColor[
             0.8816813272268005, 0.9081674769062913, 0.9752687961374844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 69}], {
             RGBColor[
             0.9027576120686737, 0.9202585481632812, 0.7154405117162554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 92}], {
             RGBColor[
             0.649644388562647, 0.7238387284395952, 0.967346604158588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 118}], {
             RGBColor[
             0.6635467479961947, 0.7351252901219045, 0.9684410488192174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 119}], {
             RGBColor[
             0.902778487445705, 0.9203031984839269, 0.7177126676782193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 123}], {
             RGBColor[
             0.6787729592823202, 0.7474866143769827, 0.969639711947111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 127}], {
             RGBColor[
             0.7563001362253984, 0.80954668160399, 0.9763445876184909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 129}], {
             RGBColor[
             0.8999452974649114, 0.9109053677012404, 0.6931703768450322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 139}], {
             RGBColor[
             0.7125762428026425, 0.7749296427593491, 0.9723008302513383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 141}], {
             RGBColor[
             0.9037977293330851, 0.9228995770660926, 0.8589131621564783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 146}], {
             RGBColor[
             0.8996121842398482, 0.9211687466064367, 0.9282784761948917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 155}], {
             RGBColor[
             0.738677163957087, 0.7957794817284352, 0.9745880944388249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 171}], {
             RGBColor[
             0.6629807500535284, 0.7346657874941313, 0.968396491387852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 182}], {
             RGBColor[
             0.5971857789860197, 0.6793024891486756, 0.9637551020452173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 191}], {
             RGBColor[
             0.8134787080549332, 0.8542150164904638, 0.9820436132943253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 195}], {
             RGBColor[
             0.658093415457198, 0.7306980290969157, 0.9680117425055323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 196}], {
             RGBColor[
             0.7418651093380414, 0.7982699288893191, 0.974905839041355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 199}], {
             RGBColor[
             0.5971857789860197, 0.6793024891486756, 0.9637551020452173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 64}], {
             RGBColor[
             0.5915239087357695, 0.6780295783423222, 0.9618305914459666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 65}], {
             RGBColor[
             0.8367796216457075, 0.8730899232407395, 0.9707934137554568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 118}], {
             RGBColor[
             0.6186450424151015, 0.7000477364563527, 0.9639656664371897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 119}], {
             RGBColor[
             0.8578767818646118, 0.8852256448183751, 0.7132372852961916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 123}], {
             RGBColor[
             0.6338712537012271, 0.712409060711431, 0.9651643295650832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 127}], {
             RGBColor[
             0.7113984306443053, 0.7744691279384383, 0.9718692052364633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 140}], {
             RGBColor[
             0.78108037945867, 0.8290602540725202, 0.9787733030225607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 151}], {
             RGBColor[
             0.8492765973240972, 0.8563743872310332, 0.6662913096040287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 155}], {
             RGBColor[
             0.6937754583759939, 0.7607019280628835, 0.9701127120567972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 171}], {
             RGBColor[
             0.6180790444724353, 0.6995882338285795, 0.9639211090058243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 172}], {
             RGBColor[
             0.5522840734049266, 0.6442249354831239, 0.9592797196631896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 191}], {
             RGBColor[
             0.7685770024738401, 0.819137462824912, 0.9775682309122976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 195}], {
             RGBColor[
             0.6131917098761048, 0.695620475431364, 0.9635363601235046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 199}], {
             RGBColor[
             0.5522840734049266, 0.6442249354831239, 0.9592797196631896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 90}], {
             RGBColor[
             0.9715280174572685, 0.9750771194762666, 0.7421331338131503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 108}], {
             RGBColor[
             0.7642481967772827, 0.8154682768301106, 0.9649745968041622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 111}], {
             RGBColor[
             0.9712276196155216, 0.9744345988676506, 0.7094366825795813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 115}], {
             RGBColor[
             0.7395231707267687, 0.7953953868325729, 0.963028152182711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 163}], {
             RGBColor[
             0.9712276196155216, 0.9744345988676506, 0.7094366825795813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.9699368429236352, 0.9761117432182906, 0.8915382780358507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 175}], {
             RGBColor[
             0.8796787619336821, 0.9066177621370273, 0.9758135363899381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 177}], {
             RGBColor[
             0.9712974220996732, 0.9745838993231373, 0.7170342522084878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 183}], {
             RGBColor[
             0.8614580209918524, 0.41009593952786316`, 0.4328013046115824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 109}], {
             RGBColor[
             0.647920170579631, 0.611795257357877, 0.6001995176310811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 148}], {
             RGBColor[
             0.48006197688669516`, 0.5866440903518781, 0.9528001509072066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 150}], {
             RGBColor[
             0.48006197688669516`, 0.5866440903518781, 0.9528001509072066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 193}], {
             RGBColor[
             0.42365783663458567`, 0.5408526683176541, 0.9483598103713868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 88}], {
             RGBColor[
             0.7991680678000717, 0.8402766400839847, 0.8289215369055274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 91}], {
             RGBColor[
             0.738474943546912, 0.7910032276211807, 0.824143551838079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 103}], {
             RGBColor[
             0.688282091722925, 0.7483064325450783, 0.8207304184747403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 117}], {
             RGBColor[
             0.9933198293913039, 0.9912525430644379, 0.7419772566036562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 121}], {
             RGBColor[
             0.8729749909802009, 0.8985327764288934, 0.8358693340712924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 152}], {
             RGBColor[
             0.9337984653969177, 0.9464738792007161, 0.8418187768099114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 164}], {
             RGBColor[
             0.7609918402677491, 0.809283458753794, 0.8259161644300537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 178}], {
             RGBColor[
             0.8657737644760213, 0.8929071235524798, 0.8351515831126437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 200}], {
             RGBColor[
             0.940166665519699, 0.9515517091184346, 0.8424261814225815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 77}], {
             RGBColor[
             0.9612601820065606, 0.9672471873641175, 0.7533295641939397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 96}], {
             RGBColor[
             0.9444332489053502, 0.957911584789898, 0.9731402020126523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 99}], {
             RGBColor[
             0.6553913919697921, 0.7256559674516148, 0.9693222226734315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 102}], {
             RGBColor[
             0.7338754763510991, 0.7913208596232522, 0.9749625454978821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 125}], {
             RGBColor[
             0.9097781045931425, 0.9308963816065339, 0.9912566418562374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 128}], {
             RGBColor[
             0.7614366667655212, 0.8136962756191589, 0.9771322633672724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 137}], {
             RGBColor[
             0.7135828615378417, 0.7748464007459703, 0.9733650365254851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 166}], {
             RGBColor[
             0.9308861756119231, 0.9477273844735853, 0.9932699485134062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 170}], {
             RGBColor[
             0.9089901362246415, 0.7671073313982482, 0.6110058078920115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 192}], {
             RGBColor[
             0.6791188286407878, 0.7462074805203884, 0.970834113956759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 198}], {
             RGBColor[
             0.8226142421609544, 0.8622345762276913, 0.9827198870459641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 62}], {
             RGBColor[
             0.9424254844107505, 0.9563649917636485, 0.9748328361612199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 92}], {
             RGBColor[
             0.7068959339316377, 0.7694314591239828, 0.9728227249659981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 114}], {
             RGBColor[
             0.8061475531330733, 0.8493552508609372, 0.9810827340963915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 146}], {
             RGBColor[
             0.956863729608839, 0.9667614772908244, 0.9337545970023018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 184}], {
             RGBColor[
             0.9191476287794682, 0.9383673858637513, 0.9921503154374021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 186}], {
             RGBColor[
             0.9263415661273917, 0.9441036362307582, 0.9928364796037508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[
             0.88758738905843, 0.9132021073900811, 0.9891400715986509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 90}], {
             RGBColor[
             0.6874477410145787, 0.7465218407457221, 0.7299164928869462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 111}], {
             RGBColor[
             0.6871473431728317, 0.7458793201371061, 0.6972200416533771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 165}], {
             RGBColor[
             0.6858565664809455, 0.7475564644877462, 0.8793216371096466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 169}], {
             RGBColor[
             0.46183700959225815`, 0.5720311389608206, 0.9513148794359829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 67}], {
             RGBColor[
             0.5541550068975896, 0.6486535415492618, 0.9582104139349543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 79}], {
             RGBColor[
             0.6322646408584703, 0.7096733812547071, 0.9659956522721447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 84}], {
             RGBColor[
             0.4165053889810083, 0.5351777665909778, 0.9477603329779836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 122}], {
             RGBColor[
             0.6631475910289509, 0.7342429182322063, 0.9689560738285009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 126}], {
             RGBColor[
             0.5962722198234764, 0.6815558283896386, 0.9624082641116745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 179}], {
             RGBColor[
             0.5486323639387901, 0.6443392108962066, 0.9576599684968539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 190}], {
             RGBColor[
             0.46694489620615365`, 0.5780748076334399, 0.95119288395803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 192}], {
             RGBColor[
             0.44023282565200395`, 0.5557292796597515, 0.9492722242613111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 114}], {
             RGBColor[
             0.8212738989239806, 0.8608530640809597, 0.9629877565346955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 141}], {
             RGBColor[
             0.9761756204929832, 0.9799901209705028, 0.8462943054021924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 149}], {
             RGBColor[
             0.9269194295628075, 0.79490412537736, 0.5959547760535866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 167}], {
             RGBColor[
             0.8930358823501388, 0.9169830637255505, 0.9701220118260605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 184}], {
             RGBColor[
             0.9342739745703755, 0.9498651990837738, 0.9740553378757062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 189}], {
             RGBColor[
             0.9503040752147838, 0.9624574411815701, 0.9690064172750552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 194}], {
             RGBColor[
             0.9027137348493375, 0.9246999206101035, 0.9710450940369549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 197}], {
             RGBColor[
             0.9608624701982736, 0.9703318748724716, 0.9511338086384531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 70}], {
             RGBColor[
             0.9355588080635864, 0.9514111533928304, 0.9922573345265004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 110}], {
             RGBColor[
             0.752587941615786, 0.8064116430530441, 0.9750450172885876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 132}], {
             RGBColor[
             0.9638371764026318, 0.971528291787624, 0.9003260491988526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 138}], {
             RGBColor[
             0.7125702482874783, 0.7739234768325838, 0.9718946778801425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 145}], {
             RGBColor[
             0.7525942963924677, 0.8064168021470337, 0.9750455175598862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 153}], {
             RGBColor[
             0.9651731454677703, 0.9701260734311705, 0.7361012812554109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 185}], {
             RGBColor[
             0.956445324788874, 0.9410018150498235, 0.6752628995793531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 65}], {
             RGBColor[
             0.7053108936618017, 0.7675928917393144, 0.9595991978573831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 132}], {
             RGBColor[
             0.7251997209539491, 0.7814038324674086, 0.8801602433254545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 138}], {
             RGBColor[
             0.47393279283879564`, 0.5837990175123684, 0.9517288720067443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 153}], {
             RGBColor[
             0.7265356900190876, 0.7800016141109551, 0.7159354753820127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 156}], {
             RGBColor[
             0.6394489776078329, 0.715469006389192, 0.9666073144259019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 182}], {
             RGBColor[
             0.4208153454210207, 0.5387279039816988, 0.9480855037651159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 185}], {
             RGBColor[
             0.7178078693401913, 0.7508773557296082, 0.655097093705955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 199}], {
             RGBColor[
             0.4208153454210207, 0.5387279039816988, 0.9480855037651159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 118}], {
             RGBColor[
             0.7324320273411337, 0.7896110498533451, 0.9617342728486062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 119}], {
             RGBColor[
             0.9716637667906439, 0.9747889582153675, 0.7110058917076081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 123}], {
             RGBColor[
             0.7476582386272592, 0.8019723741084233, 0.9629329359764998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 127}], {
             RGBColor[
             0.8251854155703373, 0.8640324413354306, 0.9696378116478798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 140}], {
             RGBColor[
             0.8948673643847022, 0.9186235674695125, 0.9765419094339773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 151}], {
             RGBColor[
             0.9630635822501292, 0.9459377006280255, 0.6640599160154452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 155}], {
             RGBColor[
             0.807562443302026, 0.8502652414598757, 0.9678813184682138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 156}], {
             RGBColor[
             0.8847046905177708, 0.9105293512876094, 0.9755701367353921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 171}], {
             RGBColor[
             0.7318660293984673, 0.7891515472255718, 0.9616897154172408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 172}], {
             RGBColor[
             0.6660710583309586, 0.7337882488801162, 0.9570483260746061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 191}], {
             RGBColor[
             0.8823639873998721, 0.9087007762219044, 0.9753368373237141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 195}], {
             RGBColor[
             0.726978694802137, 0.7851837888283563, 0.9613049665349211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 199}], {
             RGBColor[
             0.6660710583309586, 0.7337882488801162, 0.9570483260746061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 78}], {
             RGBColor[
             0.624465143250221, 0.7057352032570989, 0.9637658159951188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 80}], {
             RGBColor[
             0.6243681079550147, 0.7056593985469881, 0.963756144423739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 82}], {
             RGBColor[
             0.4851706426336314, 0.5909744334319968, 0.9531517885029139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[
             0.4851706426336314, 0.5909744334319968, 0.9531517885029139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 100}], {
             RGBColor[
             0.7246957233849252, 0.7843645857403887, 0.9736686919706277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 113}], {
             RGBColor[
             0.678167456143211, 0.7476878582417974, 0.9691183606676451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 120}], {
             RGBColor[
             0.6790623180934023, 0.7483869311984896, 0.9692075521438799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 124}], {
             RGBColor[
             0.6110117881223056, 0.6950859212218857, 0.9625202326523672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 136}], {
             RGBColor[
             0.715544408831458, 0.77706757592127, 0.972795831419043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 187}], {
             RGBColor[
             0.4851706426336314, 0.5909744334319968, 0.9531517885029139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 79}], {
             RGBColor[
             0.7349843798842209, 0.7928946507445138, 0.9742200322334708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 82}], {
             RGBColor[
             0.5192251280067589, 0.6183990360807845, 0.9559847129393098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 100}], {
             RGBColor[
             0.7587502087580528, 0.8117891883891764, 0.9765016164070235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 122}], {
             RGBColor[
             0.7658673300547015, 0.8174641877220129, 0.977180453789827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 125}], {
             RGBColor[
             0.7736118406301092, 0.8236394502357036, 0.9779191321221156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 137}], {
             RGBColor[
             0.5774165975748085, 0.6675894693751401, 0.9600275267913632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 166}], {
             RGBColor[
             0.7947199116488899, 0.8404704531027549, 0.9799324387792843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 170}], {
             RGBColor[
             0.7728238722616083, 0.6598504000274179, 0.5976682981578896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 179}], {
             RGBColor[
             0.6513521029645407, 0.7275604803860132, 0.96588434845818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 192}], {
             RGBColor[
             0.5429525646777545, 0.6389505491495581, 0.9574966042226372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 71}], {
             RGBColor[
             0.8765730365493899, 0.7968299536586056, 0.6195911699586965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 75}], {
             RGBColor[
             0.7589242526919605, 0.7041259841242246, 0.6083682175700074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 81}], {
             RGBColor[
             0.9069802278065604, 0.8210758225858544, 0.6224914350056254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 102}], {
             RGBColor[
             0.729798178098203, 0.6804801246543045, 0.6060753062856601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 127}], {
             RGBColor[
             0.8104284509562749, 0.7450594249379815, 0.6130244690344833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 129}], {
             RGBColor[
             0.9540736121957879, 0.846418111035232, 0.32985025826102454`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 140}], {
             RGBColor[
             0.8801103997706397, 0.7996505510720634, 0.6199285668205807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 143}], {
             RGBColor[
             0.9570344383149629, 0.8560889426119234, 0.3682849550781063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 155}], {
             RGBColor[
             0.7928054786879635, 0.7312922250624267, 0.6112679758548172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 172}], {
             RGBColor[
             0.6513140937168961, 0.6148152324826671, 0.6004349834612095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 188}], {
             RGBColor[
             0.783307195149837, 0.7238720937728137, 0.610321275718243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 86}], {
             RGBColor[
             0.9873676393616249, 0.9864717991674377, 0.6821158391407627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 92}], {
             RGBColor[
             0.7396059527494591, 0.7904155594280258, 0.7008115437667479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 118}], {
             RGBColor[
             0.7535083121830068, 0.801702121110335, 0.7019059884273773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 123}], {
             RGBColor[
             0.7687345234691323, 0.8140634453654132, 0.7031046515552708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 139}], {
             RGBColor[
             0.8025378069894546, 0.8415064737477795, 0.7057657698594981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 146}], {
             RGBColor[
             0.9895737484266603, 0.9877455775948673, 0.6617434158030515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 171}], {
             RGBColor[
             0.7529423142403405, 0.8012426184825618, 0.7018614309960118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 174}], {
             RGBColor[
             0.9938256470122919, 0.9892020082191662, 0.5693379648567796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 186}], {
             RGBColor[
             0.959051584945213, 0.965087736534801, 0.7208252984045005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 191}], {
             RGBColor[
             0.9034402722417453, 0.9207918474788943, 0.7155085529024852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 195}], {
             RGBColor[
             0.7480549796440101, 0.7972748600853463, 0.7014766821136922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 196}], {
             RGBColor[
             0.8318266735248535, 0.8648467598777496, 0.7083707786495149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 110}], {
             RGBColor[
             0.7508166580301432, 0.8050413309645468, 0.9763343645203989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 132}], {
             RGBColor[
             0.962065892816989, 0.9701579796991266, 0.9016153964306639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 138}], {
             RGBColor[
             0.7107989647018356, 0.7725531647440864, 0.9731840251119538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.750823012806825, 0.8050464900585363, 0.9763348647916976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 185}], {
             RGBColor[
             0.9546740412032313, 0.9396315029613261, 0.6765522468111645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 73}], {
             RGBColor[
             0.6404152383166737, 0.7160239707873742, 0.9668305564308093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 75}], {
             RGBColor[
             0.7144446118977359, 0.7762487339399964, 0.9726240525886238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 76}], {
             RGBColor[
             0.7457662315254796, 0.8014153909295855, 0.9752686932315269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 81}], {
             RGBColor[
             0.8625005870123357, 0.8931985724016263, 0.9867472700242419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 87}], {
             RGBColor[
             0.6813937324867345, 0.7494165411089957, 0.9700221662920292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 89}], {
             RGBColor[
             0.6659402318658589, 0.7368706931326994, 0.9688056101151159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 107}], {
             RGBColor[
             0.6068344529226715, 0.6869379822984389, 0.964690818479826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 127}], {
             RGBColor[
             0.7659488101620502, 0.8171821747537533, 0.9772803040530995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 129}], {
             RGBColor[
             0.9095939714015633, 0.9185408608510038, 0.6941060932796409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 141}], {
             RGBColor[
             0.9134464032697369, 0.9305350702158559, 0.8598488785910869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 142}], {
             RGBColor[
             0.6983309798189963, 0.7631669615076229, 0.9713555284452062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 147}], {
             RGBColor[
             0.6297882208040135, 0.7068193823473388, 0.9661534122720051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 155}], {
             RGBColor[
             0.7483258378937389, 0.8034149748781986, 0.9755238108734335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 168}], {
             RGBColor[
             0.6068344529226715, 0.6869379822984389, 0.964690818479826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 188}], {
             RGBColor[
             0.7388275543556124, 0.7959948435885855, 0.9745771107368593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 197}], {
             RGBColor[
             0.8981332529750274, 0.9208768241178249, 0.9646883818273476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 76}], {
             RGBColor[
             0.5868036084845955, 0.6751709855788304, 0.9607933640847368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 81}], {
             RGBColor[
             0.7035379639714516, 0.7669541670508713, 0.9722719408774517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 104}], {
             RGBColor[
             0.6810218945852071, 0.7490004645047017, 0.9701243380790593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 143}], {
             RGBColor[
             0.7535921744798543, 0.8019672870769402, 0.7180654609499326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 144}], {
             RGBColor[
             0.7535686818887216, 0.8019170387999727, 0.7155084373846057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 154}], {
             RGBColor[
             0.5140349148113488, 0.6163557267096943, 0.9548858579473367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 158}], {
             RGBColor[
             0.6693175293804854, 0.7396677213969864, 0.9690079652772228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 160}], {
             RGBColor[
             0.5632044162860704, 0.6562737430676722, 0.9587566612172455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 176}], {
             RGBColor[
             0.4830726302075381, 0.5911827409461816, 0.9524584532029471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 181}], {
             RGBColor[
             0.7449350903676758, 0.7989315439199607, 0.9404553247786551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 75}], {
             RGBColor[
             0.5227664544592443, 0.6233200012529931, 0.9556076040421201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 87}], {
             RGBColor[
             0.4897155750482429, 0.5964878084219924, 0.9530057177455256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.47426207442736734`, 0.5839419604456961, 0.9517891615686123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 107}], {
             RGBColor[
             0.41515629548417987`, 0.5340092496114357, 0.9476743699333223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 130}], {
             RGBColor[
             0.527608211873796, 0.6272507580408121, 0.9559887649217353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 142}], {
             RGBColor[
             0.5066528223805046, 0.6102382288206196, 0.9543390798987025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 147}], {
             RGBColor[
             0.43811006336552194`, 0.5538906496603355, 0.9491369637255014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 149}], {
             RGBColor[
             0.6725120549010696, 0.5925203419357099, 0.5924929006959774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 157}], {
             RGBColor[
             0.4467405278396517, 0.5613659242080695, 0.9496868892901729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 167}], {
             RGBColor[
             0.638628507688401, 0.7145992802839005, 0.9666601364684513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 168}], {
             RGBColor[
             0.41515629548417987`, 0.5340092496114357, 0.9476743699333223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 188}], {
             RGBColor[
             0.5471493969171208, 0.6430661109015823, 0.9575606621903556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 189}], {
             RGBColor[
             0.6958967005530459, 0.76007365773992, 0.965544541917446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 197}], {
             RGBColor[
             0.7064550955365358, 0.7679480914308217, 0.9476719332808439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 85}], {
             RGBColor[
             0.5081410959034502, 0.6115708590067462, 0.954421874933137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 88}], {
             RGBColor[
             0.5300333984270141, 0.629344016432365, 0.9561453171819384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 93}], {
             RGBColor[
             0.6361250910637233, 0.7128212600500896, 0.9663109584488114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 95}], {
             RGBColor[
             0.7046127613825217, 0.3369589286761489, 0.433445849395387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 121}], {
             RGBColor[
             0.6038403216071434, 0.6876001527772737, 0.9630931143477035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 140}], {
             RGBColor[
             0.647943728403611, 0.7222091274828548, 0.9674477821105225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 152}], {
             RGBColor[
             0.6646637960238602, 0.7355412555490966, 0.9690425570863224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 159}], {
             RGBColor[
             0.696613513891221, 0.7609962393543201, 0.9713669294596147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 161}], {
             RGBColor[
             0.5404891006689593, 0.6378324265363944, 0.9569684283629236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 162}], {
             RGBColor[
             0.4191474223498675, 0.5373738088934585, 0.9479541987511513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 164}], {
             RGBColor[
             0.4918571708946917, 0.5983508351021742, 0.9531399447064648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 172}], {
             RGBColor[
             0.4191474223498675, 0.5373738088934585, 0.9479541987511513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 173}], {
             RGBColor[
             0.6522974870532872, 0.7256806964504763, 0.9678630474971748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 180}], {
             RGBColor[
             0.6920092366147003, 0.7573457676040214, 0.9716507896214397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 81}], {
             RGBColor[
             0.7448518031549063, 0.8004946028672453, 0.9755243176355528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 89}], {
             RGBColor[
             0.5482914480084295, 0.6441667235983184, 0.9575826577264268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 118}], {
             RGBColor[
             0.5555466380754172, 0.6500568137372869, 0.958153812865137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 127}], {
             RGBColor[
             0.6483000263046208, 0.7244782052193723, 0.9660573516644104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 129}], {
             RGBColor[
             0.7919451875441339, 0.8258368913166227, 0.6828831408909517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 141}], {
             RGBColor[
             0.7957976194123075, 0.8378311006814749, 0.8486259262023979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 142}], {
             RGBColor[
             0.5806821959615669, 0.6704629919732418, 0.960132576056517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 147}], {
             RGBColor[
             0.5121394369465841, 0.6141154128129577, 0.9549304598833159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 155}], {
             RGBColor[
             0.6306770540363095, 0.7107110053438175, 0.9643008584847443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 168}], {
             RGBColor[
             0.4891856690652421, 0.594234012764058, 0.9534678660911369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 188}], {
             RGBColor[
             0.621178770498183, 0.7032908740542045, 0.9633541583481702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 191}], {
             RGBColor[
             0.7054785981341556, 0.7691465401058462, 0.9717563773402449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 81}], {
             RGBColor[
             0.77617342278265, 0.8256612598568343, 0.9781689582784558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 87}], {
             RGBColor[
             0.5950665682570488, 0.6818792285642037, 0.9614438545462433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 89}], {
             RGBColor[
             0.5796130676361733, 0.6693333805879074, 0.96022729836933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[
             0.7536573533964055, 0.8077075573106647, 0.9760213554800634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 106}], {
             RGBColor[
             0.800370712594926, 0.8448110267637627, 0.9754671790804484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 107}], {
             RGBColor[
             0.5205072886929858, 0.6194006697536469, 0.9561125067340399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 142}], {
             RGBColor[
             0.6120038155893105, 0.6956296489628309, 0.9627772166994202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 143}], {
             RGBColor[
             0.8262276332910526, 0.8606743798829033, 0.7239624783509367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 147}], {
             RGBColor[
             0.5434610565743279, 0.6392820698025468, 0.9575751005262192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 154}], {
             RGBColor[
             0.5866703736225471, 0.6750628195156574, 0.960782875348341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[
             0.5520915210484576, 0.6467573443502808, 0.9581250260908907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 158}], {
             RGBColor[
             0.7419529881916838, 0.7983748142029496, 0.974904982678227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 176}], {
             RGBColor[
             0.5557080890187365, 0.6498898337521448, 0.9583554706039512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 181}], {
             RGBColor[
             0.8175705491788742, 0.8576386367259237, 0.9463523421796592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 188}], {
             RGBColor[
             0.6525003901259268, 0.7284575310437935, 0.9659987989910733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 83}], {
             RGBColor[
             0.9076153723277085, 0.9244722722757683, 0.7482128743574838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 96}], {
             RGBColor[
             0.9764861570625043, 0.9787700983732865, 0.7333599528420678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 99}], {
             RGBColor[
             0.6874443001269461, 0.7465144810350033, 0.7295419735028471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 112}], {
             RGBColor[
             0.8765057555038931, 0.9001535741617617, 0.7451163059469301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 143}], {
             RGBColor[
             0.9931646447250131, 0.9877881911642596, 0.4973919451197439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 156}], {
             RGBColor[
             0.9060779323137583, 0.9232555834424965, 0.7480637841636331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 160}], {
             RGBColor[
             0.8027768865312293, 0.8420946471549915, 0.7380831453870568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 166}], {
             RGBColor[
             0.9629390837690771, 0.9685858980569739, 0.7534896993428217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 170}], {
             RGBColor[
             0.9410430443817955, 0.7879658449816368, 0.37122555872142704`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 181}], {
             RGBColor[
             0.9845075606128346, 0.98475244800728, 0.7197818089484664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 183}], {
             RGBColor[
             0.8759836967212382, 0.41878656698250205`, 0.2806617716744517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 192}], {
             RGBColor[
             0.7111717367979418, 0.767065994103777, 0.7310538647861746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 80}], {
             RGBColor[
             0.6600674760281506, 0.7343689960625939, 0.9667530153953687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 82}], {
             RGBColor[
             0.5208700107067673, 0.6196840309476026, 0.9561486594745437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 98}], {
             RGBColor[
             0.5208700107067673, 0.6196840309476026, 0.9561486594745437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 100}], {
             RGBColor[
             0.7603950914580611, 0.8130741832559945, 0.9766655629422575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 113}], {
             RGBColor[
             0.7138668242163468, 0.7763974557574032, 0.9721152316392749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 120}], {
             RGBColor[
             0.7147616861665382, 0.7770965287140954, 0.9722044231155096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 124}], {
             RGBColor[
             0.6467111561954415, 0.7237955187374914, 0.9655171036239969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 136}], {
             RGBColor[
             0.7512437769045939, 0.8057771734368757, 0.9757927023906728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 187}], {
             RGBColor[
             0.5208700107067673, 0.6196840309476026, 0.9561486594745437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 84}], {
             RGBColor[
             0.5973347619676397, 0.6794188757862298, 0.9637699512765001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 122}], {
             RGBColor[
             0.8439769640155823, 0.8784840274274583, 0.9849656921270173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 126}], {
             RGBColor[
             0.7771015928101078, 0.8257969375848906, 0.9784178824101908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 177}], {
             RGBColor[
             0.9029763975344454, 0.9205242352563221, 0.7230529305764447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 179}], {
             RGBColor[
             0.7294617369254215, 0.7885803200914586, 0.9736695867953704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 190}], {
             RGBColor[
             0.647774269192785, 0.7223159168286919, 0.9672025022565465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 82}], {
             RGBColor[
             0.520772975411561, 0.6196082262374918, 0.956138987903164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 98}], {
             RGBColor[
             0.520772975411561, 0.6196082262374918, 0.956138987903164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 100}], {
             RGBColor[
             0.7602980561628548, 0.8129983785458836, 0.9766558913708777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 113}], {
             RGBColor[
             0.7137697889211405, 0.7763216510472923, 0.9721055600678952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 116}], {
             RGBColor[
             0.772763410260935, 0.8229379135406697, 0.9778448479727055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 120}], {
             RGBColor[
             0.714664650871332, 0.7770207240039846, 0.9721947515441298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 124}], {
             RGBColor[
             0.6466141209002353, 0.7237197140273808, 0.9655074320526171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 125}], {
             RGBColor[
             0.7751596880349113, 0.824848640392411, 0.9780734070859698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 136}], {
             RGBColor[
             0.7511467416093875, 0.805701368726765, 0.9757830308192931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 137}], {
             RGBColor[
             0.5789644449796105, 0.6687986595318474, 0.9601818017552175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 187}], {
             RGBColor[
             0.520772975411561, 0.6196082262374918, 0.956138987903164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 198}], {
             RGBColor[
             0.6879958256027232, 0.7561868350135683, 0.9695366522756965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 87}], {
             RGBColor[
             0.711800923743905, 0.7736624100362446, 0.9729224313389582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 89}], {
             RGBColor[
             0.6963474231230293, 0.7611165620599483, 0.9717058751620449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 104}], {
             RGBColor[
             0.8703917088832616, 0.8994907387827056, 0.9874999322727784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 107}], {
             RGBColor[
             0.637241644179842, 0.7111838512256878, 0.9675910835267549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 142}], {
             RGBColor[
             0.7287381710761667, 0.7874128304348716, 0.9742557934921352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 143}], {
             RGBColor[
             0.9429619887779088, 0.9524575613549442, 0.7354410551436517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 147}], {
             RGBColor[
             0.6601954120611839, 0.7310652512745875, 0.9690536773189341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 154}], {
             RGBColor[
             0.7034047291094033, 0.7668460009876983, 0.972261452141056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 157}], {
             RGBColor[
             0.6688258765353138, 0.7385405258223217, 0.9696036028836056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 158}], {
             RGBColor[
             0.8586873436785399, 0.8901579956749904, 0.9863835594709419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 168}], {
             RGBColor[
             0.637241644179842, 0.7111838512256878, 0.9675910835267549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 176}], {
             RGBColor[
             0.6724424445055927, 0.7416730152241856, 0.9698340473966662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 188}], {
             RGBColor[
             0.7692347456127828, 0.8202407125158344, 0.9774773757837882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 98}], {
             RGBColor[
             0.3815755100901777, 0.5049232611225005, 0.945534631982339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 100}], {
             RGBColor[
             0.6211005908414715, 0.6983134134308924, 0.9660515354500527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 120}], {
             RGBColor[
             0.5754671855499487, 0.6623357588889933, 0.9615903956233048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 124}], {
             RGBColor[
             0.507416655578852, 0.6090347489123894, 0.9549030761317923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 125}], {
             RGBColor[
             0.635962222713528, 0.7101636752774196, 0.9674690511651449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 136}], {
             RGBColor[
             0.6119492762880043, 0.6910164036117736, 0.9651786748984681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 137}], {
             RGBColor[
             0.4397669796582273, 0.5541136944168561, 0.9495774458343925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 187}], {
             RGBColor[
             0.3815755100901777, 0.5049232611225005, 0.945534631982339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 198}], {
             RGBColor[
             0.5487983602813399, 0.641501869898577, 0.9589322963548716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 122}], {
             RGBColor[
             0.8483887843388827, 0.881946204004494, 0.985401273687493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 156}], {
             RGBColor[
             0.8203802144777522, 0.8596221547707587, 0.9827273434977616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 166}], {
             RGBColor[
             0.877241365933071, 0.904952469385236, 0.9881532586769504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 170}], {
             RGBColor[
             0.8553453265457894, 0.724332416309899, 0.6058891180555557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 175}], {
             RGBColor[
             0.8157695576917545, 0.8560202746472478, 0.9822677963183707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 179}], {
             RGBColor[
             0.7338735572487218, 0.7920424966684942, 0.9741051683558459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 183}], {
             RGBColor[
             0.8188518848305675, 0.3763642812013435, 0.4371041445638708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 192}], {
             RGBColor[
             0.6254740189619357, 0.7034325654320391, 0.9657174241203031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 126}], {
             RGBColor[
             0.5613423409326458, 0.6513013229211613, 0.9601825631160298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 190}], {
             RGBColor[
             0.432015017315323, 0.5478203021649626, 0.9489671829623854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 88}], {
             RGBColor[
             0.581455159720907, 0.6710905187746946, 0.9601934265951118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 117}], {
             RGBColor[
             0.7756069213121394, 0.8220664217551478, 0.8732491462932406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[
             0.6552620829010363, 0.7293466551196033, 0.9671412237608769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 133}], {
             RGBColor[
             0.5260933239652283, 0.6261452864859556, 0.9558351400873384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 140}], {
             RGBColor[
             0.6993654896975039, 0.7639556298251844, 0.9714958915236959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 152}], {
             RGBColor[
             0.7160855573177531, 0.7772877578914261, 0.9730906664994958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 159}], {
             RGBColor[
             0.7480352751851138, 0.8027427416966497, 0.975415038872788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 161}], {
             RGBColor[
             0.5919108619628521, 0.679578928878724, 0.9610165377760971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 173}], {
             RGBColor[
             0.7037192483471801, 0.7674271987928059, 0.9719111569103482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 200}], {
             RGBColor[
             0.7224537574405343, 0.7823655878091444, 0.973698071112166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 92}], {
             RGBColor[
             0.7342544158555981, 0.7900519794437516, 0.9340219315830951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[
             0.7210356416098138, 0.7793203830120303, 0.9329813012525014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 171}], {
             RGBColor[
             0.7475907773464796, 0.8008790384982877, 0.9350718188123591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 174}], {
             RGBColor[
             0.9884741101184309, 0.988838428234892, 0.8025483526731267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 196}], {
             RGBColor[
             0.8264751366309926, 0.8644831798934756, 0.9415811664658622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 89}], {
             RGBColor[
             0.5152405685974282, 0.6173345307673177, 0.9549807714298323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 106}], {
             RGBColor[
             0.735998213556181, 0.7928121769431731, 0.9702206521409508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 107}], {
             RGBColor[
             0.4561347896542408, 0.5674018199330573, 0.9508659797945422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 130}], {
             RGBColor[
             0.568586706043857, 0.6606433283624336, 0.9591803747829555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 131}], {
             RGBColor[
             0.6742810271424773, 0.7437621658976863, 0.9693392115067365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 142}], {
             RGBColor[
             0.5476313165505655, 0.6436307991422411, 0.9575306897599225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 147}], {
             RGBColor[
             0.4790885575355828, 0.587283219981957, 0.9523285735867215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[
             0.5222978745838022, 0.6230639696950677, 0.9555363484088433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 157}], {
             RGBColor[
             0.4877190220097126, 0.5947584945296911, 0.952878499151393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 168}], {
             RGBColor[
             0.4561347896542408, 0.5674018199330573, 0.9508659797945422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 176}], {
             RGBColor[
             0.4913355899799915, 0.597890983931555, 0.9531089436644535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 188}], {
             RGBColor[
             0.5881278910871817, 0.6764586812232039, 0.9607522720515757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 91}], {
             RGBColor[
             0.5426543379913112, 0.6395902637375095, 0.9571388837764648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 93}], {
             RGBColor[
             0.70943915488118, 0.772340919818038, 0.9720825101107862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 95}], {
             RGBColor[
             0.753488803927493, 0.37663870185478115`, 0.43729355050337015`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 103}], {
             RGBColor[
             0.4924614861673243, 0.5968934686614069, 0.9537257504131261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 117}], {
             RGBColor[
             0.7974992238357033, 0.8398395791807666, 0.8749725885420421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 121}], {
             RGBColor[
             0.6771543854246003, 0.7471198125452221, 0.9688646660096782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 152}], {
             RGBColor[
             0.7379778598413169, 0.7950609153170449, 0.9748141087482972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 159}], {
             RGBColor[
             0.7699275777086777, 0.8205158991222685, 0.9771384811215895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 161}], {
             RGBColor[
             0.6138031644864161, 0.6973520863043428, 0.9627399800248985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 164}], {
             RGBColor[
             0.5651712347121485, 0.6578704948701226, 0.9589114963684395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 173}], {
             RGBColor[
             0.7256115508707439, 0.7852003562184247, 0.9736345991591496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 180}], {
             RGBColor[
             0.765323300432157, 0.8168654273719698, 0.9774223412834145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 200}], {
             RGBColor[
             0.7443460599640983, 0.8001387452347632, 0.9754215133609674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 106}], {
             RGBColor[
             0.7205447129353053, 0.7802663289668768, 0.9690040959640375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 107}], {
             RGBColor[
             0.4406812890333651, 0.554855971956761, 0.9496494236176289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 142}], {
             RGBColor[
             0.5321778159296899, 0.6310849511659448, 0.9563141335830092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 147}], {
             RGBColor[
             0.4636350569147072, 0.5747373720056607, 0.9511120174098082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 154}], {
             RGBColor[
             0.5068443739629265, 0.6105181217187714, 0.95431979223193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 157}], {
             RGBColor[
             0.472265521388837, 0.5822126465533948, 0.9516619429744797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 168}], {
             RGBColor[
             0.4406812890333651, 0.554855971956761, 0.9496494236176289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 176}], {
             RGBColor[
             0.4758820893591158, 0.5853451359552587, 0.9518923874875402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 188}], {
             RGBColor[
             0.5726743904663061, 0.6639128332469075, 0.9595357158746624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 111}], {
             RGBColor[
             0.9930195740972327, 0.9874778997603277, 0.48160190255798435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 115}], {
             RGBColor[
             0.7613151252084798, 0.8084386877252501, 0.735193372161114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 163}], {
             RGBColor[
             0.9930195740972327, 0.9874778997603277, 0.48160190255798435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 165}], {
             RGBColor[
             0.9917287974053464, 0.9891550441109678, 0.6637034980142538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 169}], {
             RGBColor[
             0.767709240516659, 0.8136297185840422, 0.7356967403405901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 175}], {
             RGBColor[
             0.9014707164153932, 0.9196610630297044, 0.7479787563683411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 177}], {
             RGBColor[
             0.9930893765813843, 0.9876272002158144, 0.4891994721868908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 103}], {
             RGBColor[
             0.4317683619141647, 0.547620056198603, 0.9489477653456777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 117}], {
             RGBColor[
             0.7368060995825436, 0.7905661667179626, 0.8701946034745935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 121}], {
             RGBColor[
             0.6164612611714406, 0.697846400082418, 0.9640866809422299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 152}], {
             RGBColor[
             0.6772847355881573, 0.7457875028542409, 0.9700361236808488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 159}], {
             RGBColor[
             0.709234453455518, 0.7712424866594646, 0.9723604960541411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 164}], {
             RGBColor[
             0.5044781104589888, 0.6085970824073187, 0.9541335113009912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 200}], {
             RGBColor[
             0.6836529357109387, 0.7508653327719592, 0.9706435282935191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 118}], {
             RGBColor[
             0.5003950886769801, 0.6052823013866488, 0.9538120808697098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 123}], {
             RGBColor[
             0.5156212999631056, 0.6176436256417271, 0.9550107439976033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 139}], {
             RGBColor[
             0.5494245834834279, 0.6450866540240935, 0.9576718623018307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 141}], {
             RGBColor[
             0.7406460700138706, 0.793056588330837, 0.8442841942069707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 146}], {
             RGBColor[
             0.7364605249206336, 0.7913257578711812, 0.9136495082453839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 171}], {
             RGBColor[
             0.4998290907343138, 0.6048227987588757, 0.9537675234383444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 174}], {
             RGBColor[
             0.7407124235062652, 0.79278218849548, 0.821244057299112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 186}], {
             RGBColor[
             0.7059383614391863, 0.7686679168111149, 0.972731390846833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 191}], {
             RGBColor[
             0.6503270487357186, 0.7243720277552081, 0.9674146453448177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 195}], {
             RGBColor[
             0.4949417561379834, 0.6008550403616602, 0.9533827745560247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 196}], {
             RGBColor[
             0.5787134500188268, 0.6684269401540635, 0.9602768710918475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 95}], {
             RGBColor[
             0.8242165990186323, 0.4322901975999309, 0.44407064468128554`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 121}], {
             RGBColor[
             0.7832460780613093, 0.8305970561629468, 0.9790303072765513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 150}], {
             RGBColor[
             0.7004076435981383, 0.7650087320935182, 0.9713715164590693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 159}], {
             RGBColor[
             0.8760192703453868, 0.9039931427399932, 0.9873041223884624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 161}], {
             RGBColor[
             0.7198948571231252, 0.7808293299220673, 0.9729056212917715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 162}], {
             RGBColor[
             0.5985531788040335, 0.6803707122791316, 0.9638913916799992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 164}], {
             RGBColor[
             0.6712629273488576, 0.7413477384878473, 0.9690771376353126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 173}], {
             RGBColor[
             0.8317032435074532, 0.8686775998361493, 0.9838002404260227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 180}], {
             RGBColor[
             0.8714149930688662, 0.9003426709896944, 0.9875879825502876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 200}], {
             RGBColor[
             0.8504377526008073, 0.8836159888524879, 0.9855871546278404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 174}], {
             RGBColor[
             0.7274936492604809, 0.7820505920637588, 0.8202034269685183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 196}], {
             RGBColor[
             0.5654946757730425, 0.6576953437223423, 0.9592362407612537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 121}], {
             RGBColor[
             0.8026934193809124, 0.4154761260847203, 0.44192541528054685`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 150}], {
             RGBColor[
             0.7474677964054651, 0.37175057670510114`, 0.4368195547355588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 159}], {
             RGBColor[
             0.8645422142369641, 0.4644068504694179, 0.4474412920218209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 161}], {
             RGBColor[
             0.7604592720887897, 0.38229764192413396`, 0.43784229129069363`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 162}], {
             RGBColor[
             0.6795648198760619, 0.31532523016217684`, 0.43183280488284537`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 164}], {
             RGBColor[
             0.7280379855726113, 0.3559765809679873, 0.4352899688530544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 173}], {
             RGBColor[
             0.8349981963450083, 0.44086315520018865`, 0.44510537071352774`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 180}], {
             RGBColor[
             0.861472696052617, 0.46197320263588537`, 0.4476305321297043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 99}], {
             RGBColor[
             0.6706173670257358, 0.7371788784607838, 0.9493526113215597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 102}], {
             RGBColor[
             0.7491014514070427, 0.8028437706324212, 0.9549929341460102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 125}], {
             RGBColor[
             0.9250040796490862, 0.9424192926157029, 0.9712870305043655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 128}], {
             RGBColor[
             0.7766626418214649, 0.8252191866283279, 0.9571626520154006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 137}], {
             RGBColor[
             0.7288088365937854, 0.7863693117551394, 0.9533954251736132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 166}], {
             RGBColor[
             0.9461121506678667, 0.9592502954827543, 0.9733003371615343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 170}], {
             RGBColor[
             0.9242161112805851, 0.7786302424074172, 0.5910361965401396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 198}], {
             RGBColor[
             0.8378402172168979, 0.8737574872368603, 0.9627502756940922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 105}], {
             RGBColor[
             0.8496866262013973, 0.8826681544961987, 0.9465260183094615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 134}], {
             RGBColor[
             0.8378711054931068, 0.8734377799175987, 0.9453483576275779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 135}], {
             RGBColor[
             0.9702190928384521, 0.9326163505953059, 0.6123402739995119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 153}], {
             RGBColor[
             0.9860481007312043, 0.9856945808870373, 0.7007654270547172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 100}], {
             RGBColor[
             0.6211005908414715, 0.6983134134308924, 0.9660515354500527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 109}], {
             RGBColor[
             0.6512881685772185, 0.6147124479428859, 0.6004141234852838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 113}], {
             RGBColor[
             0.5745723235997573, 0.6616366859323011, 0.9615012041470701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 116}], {
             RGBColor[
             0.6335659449395517, 0.7082529484256783, 0.9672404920518807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 120}], {
             RGBColor[
             0.5754671855499487, 0.6623357588889933, 0.9615903956233048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 124}], {
             RGBColor[
             0.507416655578852, 0.6090347489123894, 0.9549030761317923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 125}], {
             RGBColor[
             0.635962222713528, 0.7101636752774196, 0.9674690511651449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 136}], {
             RGBColor[
             0.6119492762880043, 0.6910164036117736, 0.9651786748984681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 187}], {
             RGBColor[
             0.3815755100901777, 0.5049232611225005, 0.945534631982339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 102}], {
             RGBColor[
             0.4600595944714846, 0.5705881532941379, 0.9511749548067895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 109}], {
             RGBColor[
             0.6512881685772185, 0.6147124479428859, 0.6004141234852838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 116}], {
             RGBColor[
             0.6335659449395517, 0.7082529484256783, 0.9672404920518807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 128}], {
             RGBColor[
             0.4876207848859069, 0.5929635692900447, 0.9533446726761798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 136}], {
             RGBColor[
             0.6119492762880043, 0.6910164036117736, 0.9651786748984681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 137}], {
             RGBColor[
             0.4397669796582273, 0.5541136944168561, 0.9495774458343925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 162}], {
             RGBColor[
             0.3815755100901777, 0.5049232611225005, 0.945534631982339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 193}], {
             RGBColor[
             0.42702583463217314`, 0.5437698589026629, 0.9485744162255895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 198}], {
             RGBColor[
             0.5487983602813399, 0.641501869898577, 0.9589322963548716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 113}], {
             RGBColor[
             0.8140974043510512, 0.8550268382406929, 0.9820181076147838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 120}], {
             RGBColor[
             0.8149922663012426, 0.8557259111973852, 0.9821072990910186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 124}], {
             RGBColor[
             0.7469417363301458, 0.8024249012207813, 0.975419979599506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 125}], {
             RGBColor[
             0.8754873034648218, 0.9035538275858115, 0.9879859546328587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 136}], {
             RGBColor[
             0.8514743570392982, 0.8844065559201655, 0.9856955783661818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 137}], {
             RGBColor[
             0.6792920604095212, 0.747503846725248, 0.9700943493021063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 187}], {
             RGBColor[
             0.6211005908414715, 0.6983134134308924, 0.9660515354500527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 198}], {
             RGBColor[
             0.7883234410326337, 0.8348920222069689, 0.9794491998225854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 105}], {
             RGBColor[
             0.5509343801584378, 0.6431705448609182, 0.9591451948539801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 134}], {
             RGBColor[
             0.5391188594501471, 0.6339401702823182, 0.9579675341720965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 135}], {
             RGBColor[
             0.6714668467954925, 0.6931187409600255, 0.6249594505440303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 144}], {
             RGBColor[
             0.687272362097112, 0.7461467229747893, 0.7108275800339088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 128}], {
             RGBColor[
             0.5661048692672137, 0.6586284614616821, 0.9589849955006304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 140}], {
             RGBColor[
             0.6888559005252282, 0.7554234718835342, 0.9706685381661606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 162}], {
             RGBColor[
             0.4600595944714846, 0.5705881532941379, 0.9511749548067895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 172}], {
             RGBColor[
             0.4600595944714846, 0.5705881532941379, 0.9511749548067895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 180}], {
             RGBColor[
             0.7329214087363174, 0.7905601120047008, 0.9748715456770779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 117}], {
             RGBColor[
             0.6866132477585567, 0.7478693716418601, 0.8667814701112548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 152}], {
             RGBColor[
             0.6270918837641704, 0.7030907077781384, 0.9666229903175101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 178}], {
             RGBColor[
             0.5590671828432741, 0.6495239521299021, 0.9599557966202423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 200}], {
             RGBColor[
             0.6334600838869517, 0.7081685376958569, 0.9672303949301804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 143}], {
             RGBColor[
             0.9204459193916643, 0.9345038588087746, 0.7332934523452592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 154}], {
             RGBColor[
             0.6808886597231587, 0.7488922984415287, 0.9701138493426635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 158}], {
             RGBColor[
             0.8361712742922953, 0.8722042931288209, 0.9842359566725495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 160}], {
             RGBColor[
             0.7300581611978805, 0.7888103147995065, 0.9739846526125722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 176}], {
             RGBColor[
             0.649926375119348, 0.723719312678016, 0.9676864445982738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 181}], {
             RGBColor[
             0.9117888352794858, 0.931468115651795, 0.9556833161739817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 188}], {
             RGBColor[
             0.7467186762265383, 0.8022870099696648, 0.9753297729853958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 134}], {
             RGBColor[
             0.7084777295184073, 0.7721874540207359, 0.9715780970437375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 135}], {
             RGBColor[
             0.8408257168637525, 0.8313660246984431, 0.6385700134156715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 144}], {
             RGBColor[
             0.856631232165372, 0.884394006713207, 0.72443814290555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.661438933992118, 0.7303336181326163, 0.9648893043287474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 130}], {
             RGBColor[
             0.7738908503817341, 0.8235751265619926, 0.9732036993171607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 131}], {
             RGBColor[
             0.8795851714803544, 0.9066939640972453, 0.9833625360409417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 142}], {
             RGBColor[
             0.7529354608884427, 0.8065625973418001, 0.9715540142941277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 147}], {
             RGBColor[
             0.6843927018734599, 0.750215018181516, 0.9663518981209267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 157}], {
             RGBColor[
             0.6930231663475898, 0.7576902927292501, 0.9669018236855982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 176}], {
             RGBColor[
             0.6966397343178686, 0.7608227821311141, 0.9671322681986587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 130}], {
             RGBColor[
             0.4940274264797938, 0.5981647695518768, 0.9538490269707521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 131}], {
             RGBColor[
             0.5997217475784142, 0.6812836070871295, 0.9640078636945333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 142}], {
             RGBColor[
             0.47307203698650246`, 0.5811522403316843, 0.9521993419477193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[
             0.4045292779715197, 0.5248046611714002, 0.9469972257745182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 154}], {
             RGBColor[
             0.4477385950197391, 0.560585410884511, 0.95020500059664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.41315974244564957`, 0.5322799357191343, 0.9475471513391897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 168}], {
             RGBColor[
             0.3815755100901777, 0.5049232611225005, 0.945534631982339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 176}], {
             RGBColor[
             0.4167763104159284, 0.5354124251209983, 0.9477775958522503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 188}], {
             RGBColor[
             0.5135686115231186, 0.6139801224126471, 0.9554209242393723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 111}], {
             RGBColor[
             0.785739753417247, 0.8278690571141718, 0.7044433655489963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 115}], {
             RGBColor[
             0.554035304528494, 0.6488298450790941, 0.958034835152126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 133}], {
             RGBColor[
             0.5356920606560608, 0.6339379733497335, 0.9565907878009717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 151}], {
             RGBColor[
             0.7771604442537635, 0.7990624498474754, 0.6597695458187972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 163}], {
             RGBColor[
             0.785739753417247, 0.8278690571141718, 0.7044433655489963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 165}], {
             RGBColor[
             0.7844489767253606, 0.8295462014648116, 0.8865449610052658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 175}], {
             RGBColor[
             0.6941908957354075, 0.7600522203835485, 0.9708202193593531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 113}], {
             RGBColor[
             0.8442849820867981, 0.7714258727526865, 0.6163806956500149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 116}], {
             RGBColor[
             0.9032786034265925, 0.8180421352460638, 0.6221199835548253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 124}], {
             RGBColor[
             0.7771293140658928, 0.7188239357327748, 0.6097825676347369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 128}], {
             RGBColor[
             0.7573334433729477, 0.7027527561104301, 0.6082241641791246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 136}], {
             RGBColor[
             0.8816619347750452, 0.8008055904321592, 0.6200581664014129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 148}], {
             RGBColor[
             0.7531426333713235, 0.6993504677572724, 0.6078942482643539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 193}], {
             RGBColor[
             0.696738493119214, 0.6535590457230485, 0.6034539077285341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 138}], {
             RGBColor[
             0.5278280982540351, 0.6275536544043001, 0.9559717078740408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 145}], {
             RGBColor[
             0.5678521463590245, 0.6600469797187499, 0.9591225475537846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 115}], {
             RGBColor[
             0.7610147273667328, 0.8077961671166342, 0.7024969209275451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 163}], {
             RGBColor[
             0.9927191762554858, 0.9868353791517118, 0.4489054513244154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 165}], {
             RGBColor[
             0.9914283995635995, 0.9885125235023517, 0.6310070467806849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 169}], {
             RGBColor[
             0.7674088426749122, 0.8129871979754262, 0.7030002891070211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 175}], {
             RGBColor[
             0.9011703185736463, 0.9190185424210885, 0.7152823051347722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 177}], {
             RGBColor[
             0.9927889787396373, 0.9869846796071984, 0.45650302095332185`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 134}], {
             RGBColor[
             0.7281803148270941, 0.7875792634090766, 0.9735418666161795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 143}], {
             RGBColor[
             0.8763573100651916, 0.8998360643785152, 0.7289589360433187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 156}], {
             RGBColor[
             0.7892705976539368, 0.835303456656752, 0.9796307750872079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 160}], {
             RGBColor[
             0.6859695518714077, 0.7541425203692471, 0.9696501363106316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 181}], {
             RGBColor[
             0.8677002259530131, 0.8968003212215356, 0.9513487998720412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 183}], {
             RGBColor[
             0.7981121402813572, 0.3601518157920057, 0.43503976562350166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 116}], {
             RGBColor[
             0.8265627584491313, 0.8649663732354789, 0.9832070642166117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 124}], {
             RGBColor[
             0.7004134690884316, 0.76574817372219, 0.9708696482965233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 128}], {
             RGBColor[
             0.6806175983954864, 0.7496769940998452, 0.969311244840911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 136}], {
             RGBColor[
             0.8049460897975839, 0.8477298284215742, 0.9811452470631992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 148}], {
             RGBColor[
             0.6764267883938622, 0.7462747057466876, 0.9689813289261403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 187}], {
             RGBColor[
             0.5745723235997573, 0.6616366859323011, 0.9615012041470701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 193}], {
             RGBColor[
             0.6200226481417528, 0.7004832837124635, 0.9645409883903207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 198}], {
             RGBColor[
             0.7417951737909194, 0.7982152947083776, 0.9748988685196027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 167}], {
             RGBColor[
             0.7567579510724616, 0.8099733228228392, 0.976371909761232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 184}], {
             RGBColor[
             0.7979960432926984, 0.8428554581810623, 0.9803052358108777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 186}], {
             RGBColor[
             0.8051899806406217, 0.8485917085480692, 0.9809913999772264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 194}], {
             RGBColor[
             0.7664358035716603, 0.8176901797073921, 0.9772949919721265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 133}], {
             RGBColor[
             0.5109670346055467, 0.6138650833521959, 0.9546443431795205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 163}], {
             RGBColor[
             0.7610147273667328, 0.8077961671166342, 0.7024969209275451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 165}], {
             RGBColor[
             0.7597239506748465, 0.8094733114672741, 0.8845985163838146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 175}], {
             RGBColor[
             0.6694658696848933, 0.7399793303860108, 0.9688737747379019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 124}], {
             RGBColor[
             0.759407090428226, 0.8123644362155673, 0.9766089362013338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 128}], {
             RGBColor[
             0.7396112197352809, 0.7962932565932226, 0.9750505327457215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 136}], {
             RGBColor[
             0.8639397111373783, 0.8943460909149515, 0.9868845349680098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 148}], {
             RGBColor[
             0.7354204097336566, 0.7928909682400649, 0.9747206168309508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 193}], {
             RGBColor[
             0.6790162694815471, 0.7470995462058408, 0.970280276295131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 198}], {
             RGBColor[
             0.8007887951307139, 0.8448315572017548, 0.9806381564244132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 121}], {
             RGBColor[
             0.8713061470158325, 0.8980957155256752, 0.8819203857078071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 152}], {
             RGBColor[
             0.9321296214325494, 0.9460368182974981, 0.8878698284464259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 159}], {
             RGBColor[
             0.9640793392999101, 0.9714918021027217, 0.8901942008197183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 164}], {
             RGBColor[
             0.7593229963033808, 0.8088463978505758, 0.8719672160665684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 178}], {
             RGBColor[
             0.864104920511653, 0.8924700626492617, 0.8812026347491583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 200}], {
             RGBColor[
             0.9384978215553306, 0.9511146482152164, 0.8884772330590962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 119}], {
             RGBColor[
             0.7535291875600381, 0.8017467714309806, 0.7041781443893411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 123}], {
             RGBColor[
             0.5295236593966532, 0.6289301873240365, 0.9561051886582328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 127}], {
             RGBColor[
             0.6070508363397316, 0.6909902545510438, 0.9628100643296127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 129}], {
             RGBColor[
             0.7506959975792445, 0.7923489406482942, 0.6796358535561541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 139}], {
             RGBColor[
             0.5633269429169756, 0.6563732157064028, 0.9587663069624601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[
             0.7545484294474183, 0.8043431500131464, 0.8453786388676001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 146}], {
             RGBColor[
             0.7503628843541814, 0.8026123195534904, 0.9147439529060135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 155}], {
             RGBColor[
             0.5894278640714201, 0.6772230546754889, 0.9610535711499467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 171}], {
             RGBColor[
             0.5137314501678616, 0.6161093604411849, 0.9548619680989738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 191}], {
             RGBColor[
             0.6642294081692663, 0.7356585894375175, 0.9685090900054472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.5088441155715311, 0.6121416020439694, 0.9544772192166542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 196}], {
             RGBColor[
             0.5926158094523746, 0.6797135018363728, 0.9613713157524768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[
             0.4479364791003527, 0.5607460620957294, 0.9502205787563391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 123}], {
             RGBColor[
             0.7687553988461635, 0.8141080956860589, 0.7053768075172346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 127}], {
             RGBColor[
             0.8462825757892418, 0.8761681629130662, 0.7120816831886145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 140}], {
             RGBColor[
             0.9159645246036066, 0.9307592890471481, 0.7189857809747122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 151}], {
             RGBColor[
             0.9841607424690336, 0.958073422205661, 0.40650378755618005`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 155}], {
             RGBColor[
             0.8286596035209304, 0.8624009630375113, 0.7103251900089484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 156}], {
             RGBColor[
             0.9058018507366752, 0.9226650728652449, 0.7180140082761268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 172}], {
             RGBColor[
             0.687168218549863, 0.7459239704577518, 0.699492197615341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 191}], {
             RGBColor[
             0.9034611476187766, 0.9208364977995399, 0.717780708864449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 195}], {
             RGBColor[
             0.7480758550210413, 0.7973195104059918, 0.703748838075656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 199}], {
             RGBColor[
             0.687168218549863, 0.7459239704577518, 0.699492197615341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 124}], {
             RGBColor[
             0.701308331038623, 0.7664472466788822, 0.970958839772758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 125}], {
             RGBColor[
             0.829853898173299, 0.8675761730439124, 0.9835248148061106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 136}], {
             RGBColor[
             0.8058409517477754, 0.8484289013782664, 0.9812344385394339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 137}], {
             RGBColor[
             0.6336586551179983, 0.7115261921833489, 0.9656332094753584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 187}], {
             RGBColor[
             0.5754671855499487, 0.6623357588889933, 0.9615903956233048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 198}], {
             RGBColor[
             0.7426900357411109, 0.7989143676650698, 0.9749880599958374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 152}], {
             RGBColor[
             0.8117847830214463, 0.8533170516619535, 0.9817619059140623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 159}], {
             RGBColor[
             0.8437345008888071, 0.8787720354671773, 0.9840862782873545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 161}], {
             RGBColor[
             0.6876100876665454, 0.7556082226492513, 0.9696877771906636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 164}], {
             RGBColor[
             0.6389781578922777, 0.7161266312150314, 0.9658592935342046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 173}], {
             RGBColor[
             0.7994184740508733, 0.8434564925633334, 0.9805823963249147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 180}], {
             RGBColor[
             0.8391302236122864, 0.8751215637168784, 0.9843701384491796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[
             0.8181529831442276, 0.8583948815796719, 0.9823693105267325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 125}], {
             RGBColor[
             0.8826044247614706, 0.9092288269186481, 0.9886647920156622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 137}], {
             RGBColor[
             0.6864091817061699, 0.7531788460580846, 0.9707731866849099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 166}], {
             RGBColor[
             0.9037124957802513, 0.9260598297856995, 0.990678098672831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 170}], {
             RGBColor[
             0.8818164563929697, 0.7454397767103624, 0.6084139580514363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 179}], {
             RGBColor[
             0.7603446870959021, 0.8131498570689577, 0.9766300083517265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 192}], {
             RGBColor[
             0.6519451488091159, 0.7245399258325026, 0.9682422641161837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 127}], {
             RGBColor[
             0.622277047625857, 0.703351578806122, 0.9640087274575062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 129}], {
             RGBColor[
             0.7659222088653701, 0.8047102649033724, 0.6808345166840476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 139}], {
             RGBColor[
             0.578553154203101, 0.668734539961481, 0.9599649700903536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 141}], {
             RGBColor[
             0.7697746407335437, 0.8167044742682246, 0.8465773019954936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 146}], {
             RGBColor[
             0.7655890956403069, 0.8149736438085686, 0.915942616033907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 155}], {
             RGBColor[
             0.6046540753575456, 0.6895843789305671, 0.9622522342778402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 171}], {
             RGBColor[
             0.528957661453987, 0.6284706846962632, 0.9560606312268674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 191}], {
             RGBColor[
             0.6794556194553918, 0.7480199136925958, 0.9697077531333407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 195}], {
             RGBColor[
             0.5240703268576565, 0.6245029262990477, 0.9556758823445477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 196}], {
             RGBColor[
             0.6078420207385, 0.6920748260914511, 0.9625699788803703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 199}], {
             RGBColor[
             0.4631626903864783, 0.5731073863508076, 0.9514192418842327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 125}], {
             RGBColor[
             0.7618033682022023, 0.8142751630673086, 0.9768374953145981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 136}], {
             RGBColor[
             0.7377904217766786, 0.7951278914016626, 0.9745471190479214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.5656081251469016, 0.658225182206745, 0.9589458899838457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 187}], {
             RGBColor[
             0.507416655578852, 0.6090347489123894, 0.9549030761317923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 198}], {
             RGBColor[
             0.6746395057700142, 0.7456133576884659, 0.9683007405043248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 136}], {
             RGBColor[
             0.8663359889113547, 0.8962568177666929, 0.987113094081274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 137}], {
             RGBColor[
             0.6941536922815776, 0.7593541085717752, 0.9715118650171983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 166}], {
             RGBColor[
             0.911457006355659, 0.9322350922993903, 0.9914167770051194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[
             0.8895609669683774, 0.7516150392240531, 0.6091526363837247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 187}], {
             RGBColor[
             0.635962222713528, 0.7101636752774196, 0.9674690511651449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 192}], {
             RGBColor[
             0.6596896593845236, 0.7307151883461933, 0.9689809424484723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 198}], {
             RGBColor[
             0.8031850729046902, 0.8467422840534962, 0.9808667155376775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 190}], {
             RGBColor[
             0.6117818481577911, 0.6941983639636233, 0.9636151140960763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 129}], {
             RGBColor[
             0.8434493858084482, 0.8667703321303797, 0.6875393923554276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 139}], {
             RGBColor[
             0.6560803311461794, 0.7307946071884883, 0.9666698457617335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 140}], {
             RGBColor[
             0.7694861733833, 0.8200027721672112, 0.9776177009149838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 141}], {
             RGBColor[
             0.8473018176766219, 0.8787645414952319, 0.8532821776668735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 155}], {
             RGBColor[
             0.6821812523006239, 0.7516444461575744, 0.9689571099492202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 172}], {
             RGBColor[
             0.5406898673295565, 0.6351674535778149, 0.9581241175556126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 191}], {
             RGBColor[
             0.75698279639847, 0.8100799809196031, 0.9764126288047206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 195}], {
             RGBColor[
             0.6015975038007348, 0.686562993526055, 0.9623807580159276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 199}], {
             RGBColor[
             0.5406898673295565, 0.6351674535778149, 0.9581241175556126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 136}], {
             RGBColor[
             0.7179945510837334, 0.7790567117793179, 0.9729887155923089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 162}], {
             RGBColor[
             0.4876207848859069, 0.5929635692900447, 0.9533446726761798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 193}], {
             RGBColor[
             0.5330711094279024, 0.6318101670702072, 0.9563844569194304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 198}], {
             RGBColor[
             0.654843635077069, 0.7295421780661212, 0.9667423370487125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 139}], {
             RGBColor[
             0.7997254923856923, 0.8321532932857387, 0.6834956349882749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 141}], {
             RGBColor[
             0.9909469789161349, 0.9801232275924823, 0.5701079668934149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 146}], {
             RGBColor[
             0.986761433822898, 0.9783923971328264, 0.6394732809318282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 155}], {
             RGBColor[
             0.8258264135401369, 0.8530031322548249, 0.6857828991757615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 191}], {
             RGBColor[
             0.900627957637983, 0.9114386670168535, 0.693238418031262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 195}], {
             RGBColor[
             0.7452426650402478, 0.7879216796233055, 0.679206547242469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 131}], {
             RGBColor[
             0.7121736639680304, 0.7745251155165058, 0.9723222586829464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 149}], {
             RGBColor[
             0.7513831858966835, 0.656675861876151, 0.5986675577334073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 157}], {
             RGBColor[
             0.5256116588352657, 0.6255214441485106, 0.9558615463276028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 168}], {
             RGBColor[
             0.4940274264797938, 0.5981647695518768, 0.9538490269707521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 189}], {
             RGBColor[
             0.7747678315486599, 0.8242291776803611, 0.9717191989548759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 197}], {
             RGBColor[
             0.7853262265321497, 0.8321036113712628, 0.9538465903182738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 147}], {
             RGBColor[
             0.6226755154597563, 0.7011650071360291, 0.9654704574867125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 157}], {
             RGBColor[
             0.631305979933886, 0.7086402816837633, 0.9660203830513839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 176}], {
             RGBColor[
             0.6349225479041649, 0.7117727710856272, 0.9662508275644446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 138}], {
             RGBColor[
             0.7390773330408809, 0.79267030313888, 0.881252739784306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 145}], {
             RGBColor[
             0.7791013811458702, 0.8251636284533298, 0.8844035794640497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 153}], {
             RGBColor[
             0.9916802302211729, 0.9888728997374666, 0.6454593431595743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 182}], {
             RGBColor[
             0.6859598856231061, 0.7475991896082104, 0.8776093715426776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 185}], {
             RGBColor[
             0.9829524095422766, 0.9597486413561196, 0.5846209614835166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 163}], {
             RGBColor[
             0.7426714834942996, 0.7929042953872736, 0.7010528735763908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 178}], {
             RGBColor[
             0.614591323164742, 0.6965489273800693, 0.963788628543256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 135}], {
             RGBColor[
             0.8290101961554619, 0.8221356501198431, 0.6373923527337879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 160}], {
             RGBColor[
             0.6544514458544302, 0.7295203364023064, 0.9665087060563061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 144}], {
             RGBColor[
             0.9771636988024266, 0.9343422028123142, 0.39025239859560024`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 148}], {
             RGBColor[
             0.7138037410821092, 0.7756544234261602, 0.9726587996775382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 187}], {
             RGBColor[
             0.6119492762880043, 0.6910164036117736, 0.9651786748984681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 193}], {
             RGBColor[
             0.6573996008299998, 0.7298630013919362, 0.9682184591417186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 198}], {
             RGBColor[
             0.7791721264791664, 0.8275950123878502, 0.9785763392710007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 166}], {
             RGBColor[
             0.7152617633003582, 0.7761851114388266, 0.9735251716743671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 170}], {
             RGBColor[
             0.6933657239130766, 0.5955650583634895, 0.5912610310529725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 179}], {
             RGBColor[
             0.5718939546160091, 0.6632751387220849, 0.9594770813532628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 187}], {
             RGBColor[
             0.4397669796582273, 0.5541136944168561, 0.9495774458343925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 192}], {
             RGBColor[
             0.46349441632922295`, 0.5746652074856298, 0.95108933711772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 198}], {
             RGBColor[
             0.6069898298493894, 0.6906923031929326, 0.9629751102069251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 145}], {
             RGBColor[
             0.5278344530307169, 0.6275588134982897, 0.9559722081453395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 153}], {
             RGBColor[
             0.7404133021060195, 0.7912680847824265, 0.7170279718408641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 182}], {
             RGBColor[
             0.43469295750795256`, 0.5499943746531701, 0.9491780002239674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 185}], {
             RGBColor[
             0.7316854814271232, 0.7621438264010795, 0.6561895901648065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 141}], {
             RGBColor[
             0.8035779242538661, 0.8441475026505909, 0.849238420299721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 146}], {
             RGBColor[
             0.7993923791606292, 0.842416672190935, 0.9186037343381344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 155}], {
             RGBColor[
             0.6384573588778679, 0.7170274073129335, 0.9649133525820676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 171}], {
             RGBColor[
             0.5627609449743094, 0.6559137130786296, 0.9587217495310947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 191}], {
             RGBColor[
             0.7132589029757141, 0.7754629420749621, 0.972368871437568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 194}], {
             RGBColor[
             0.7301160386102202, 0.7888573022901917, 0.9739892089344835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 195}], {
             RGBColor[
             0.5578736103779789, 0.651945954681414, 0.958337000648775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 196}], {
             RGBColor[
             0.6416453042588224, 0.7195178544738174, 0.9652310971845977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 151}], {
             RGBColor[
             0.9073643400630919, 0.9019080314598061, 0.6720398052825493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 161}], {
             RGBColor[
             0.731713494463013, 0.7902171973548325, 0.9740424449534826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 162}], {
             RGBColor[
             0.6103718161439212, 0.6897585797118968, 0.9650282153417102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 172}], {
             RGBColor[
             0.6103718161439212, 0.6897585797118968, 0.9650282153417102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 173}], {
             RGBColor[
             0.8435218808473409, 0.8780654672689145, 0.9849370640877337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 180}], {
             RGBColor[
             0.883233630408754, 0.9097305384224597, 0.9887248062119987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 191}], {
             RGBColor[
             0.8266647452128348, 0.864671107053685, 0.9833167265908183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 146}], {
             RGBColor[
             0.9906138656910718, 0.9903866064976785, 0.8052160662432744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 155}], {
             RGBColor[
             0.8296788454083106, 0.864997341619677, 0.8515256844872076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 167}], {
             RGBColor[
             0.9116596726414643, 0.9291103797123822, 0.8596784586287289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 191}], {
             RGBColor[
             0.9044803895061567, 0.9234328763817057, 0.858981203342708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 194}], {
             RGBColor[
             0.9213375251406628, 0.9368272365969352, 0.8606015408396235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 195}], {
             RGBColor[
             0.7490950969084216, 0.7999158889881576, 0.844949332553915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 147}], {
             RGBColor[
             0.4960258048678445, 0.601033640380584, 0.9536619357398983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 154}], {
             RGBColor[
             0.5392351219160638, 0.6368143900936947, 0.9568697105620202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 157}], {
             RGBColor[
             0.5046562693419743, 0.608508914928318, 0.9542118613045698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 168}], {
             RGBColor[
             0.47307203698650246`, 0.5811522403316843, 0.9521993419477193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 176}], {
             RGBColor[
             0.5082728373122531, 0.6116414043301821, 0.9544423058176306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.6050651384194434, 0.6902091016218309, 0.9620856342047526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 154}], {
             RGBColor[
             0.753458939617806, 0.8018591210137672, 0.7180549722135368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 158}], {
             RGBColor[
             0.9087415541869426, 0.9251711157010594, 0.7321770795434228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 160}], {
             RGBColor[
             0.8026284410925276, 0.8417771373717451, 0.7219257754834454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 181}], {
             RGBColor[
             0.984359115174133, 0.9844349382240336, 0.703624439044855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 188}], {
             RGBColor[
             0.8192889561211856, 0.8552538325419035, 0.7232708958562691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 158}], {
             RGBColor[
             0.9087180615958099, 0.9251208674240918, 0.7296200559780959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 153}], {
             RGBColor[
             0.7804373502110088, 0.8237614100968763, 0.7201788115206079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 185}], {
             RGBColor[
             0.7717095295321126, 0.7946371517155293, 0.6593404298445502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 155}], {
             RGBColor[
             0.8254933003150737, 0.8632665111600212, 0.9208909985256208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 171}], {
             RGBColor[
             0.7497968864115151, 0.8021528169257173, 0.9146993954746481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 184}], {
             RGBColor[
             0.9487122197684641, 0.9602616846109495, 0.932977098716788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 186}], {
             RGBColor[
             0.9559061571163876, 0.9659979349779564, 0.9336632628831367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 191}], {
             RGBColor[
             0.9002948444129198, 0.9217020459220497, 0.9283465173811214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 194}], {
             RGBColor[
             0.9171519800474259, 0.9350964061372793, 0.9299668548780369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 195}], {
             RGBColor[
             0.7449095518151847, 0.7981850585285017, 0.9143146465923284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 196}], {
             RGBColor[
             0.8286812456960281, 0.865756958320905, 0.921208743128151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 154}], {
             RGBColor[
             0.47069236290108113`, 0.5804668109334106, 0.9516675943888191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 157}], {
             RGBColor[
             0.4361135103269916, 0.552161335768034, 0.9490097451313688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 168}], {
             RGBColor[
             0.4045292779715197, 0.5248046611714002, 0.9469972257745182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 176}], {
             RGBColor[
             0.4397300782972704, 0.555293825169898, 0.9492401896444295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 188}], {
             RGBColor[
             0.5365223794044607, 0.6338615224615468, 0.9568835180315516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 150}], {
             RGBColor[
             0.5852844396783876, 0.6741993007512735, 0.9604948815404794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 193}], {
             RGBColor[
             0.5288802994262781, 0.6284078787170495, 0.9560545410046597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 167}], {
             RGBColor[
             0.8624034817112884, 0.7440243841192394, 0.6093389292801232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 168}], {
             RGBColor[
             0.6389312695070675, 0.5634343534467747, 0.590353162744994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 189}], {
             RGBColor[
             0.9196716745759335, 0.7894987615752589, 0.6082233347291179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 194}], {
             RGBColor[
             0.8720813342104872, 0.7517412410037925, 0.6102620114910176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.9302300695594233, 0.7973731952661606, 0.5903507260925158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 156}], {
             RGBColor[
             0.8972016661961605, 0.8938138152779029, 0.671068032583964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 172}], {
             RGBColor[
             0.6785680340093483, 0.7170727128704099, 0.6525462219231781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 175}], {
             RGBColor[
             0.8925910094101628, 0.8902119351543922, 0.6706084854045731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 183}], {
             RGBColor[
             0.870066185976173, 0.39915872153943976`, 0.22933127062133907`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 199}], {
             RGBColor[
             0.6785680340093483, 0.7170727128704099, 0.6525462219231781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 159}], {
             RGBColor[
             0.9045579753055237, 0.926713138239, 0.9900357210259735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 178}], {
             RGBColor[
             0.8045835565172668, 0.8476913987855399, 0.9810441549554134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 200}], {
             RGBColor[
             0.8789764575609443, 0.9063359843514947, 0.9883187532653515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 182}], {
             RGBColor[
             0.6872958546882446, 0.7461969712517569, 0.7133846035992357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 185}], {
             RGBColor[
             0.9842883786074152, 0.9583464229996661, 0.42039619354007485`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 157}], {
             RGBColor[
             0.4793228273752109, 0.5879420854811447, 0.9522175199534906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 158}], {
             RGBColor[
             0.6691842945184371, 0.7395595553338135, 0.9689974765408269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 160}], {
             RGBColor[
             0.5630711814240221, 0.6561655770044992, 0.9587461724808497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 176}], {
             RGBColor[
             0.4829393953454898, 0.5910745748830086, 0.9524479644665513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 181}], {
             RGBColor[
             0.7448018555056275, 0.7988233778567877, 0.9404448360422593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 188}], {
             RGBColor[
             0.57973169645268, 0.6696422721746575, 0.9600912928536733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 172}], {
             RGBColor[
             0.523066895061245, 0.62140025370226, 0.9563676243759466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 191}], {
             RGBColor[
             0.7393598241301587, 0.7963127810440482, 0.9746561356250546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 195}], {
             RGBColor[
             0.5839745315324234, 0.6727957936505002, 0.9606242648362616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 199}], {
             RGBColor[
             0.523066895061245, 0.62140025370226, 0.9563676243759466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 166}], {
             RGBColor[
             0.8757039259191208, 0.9037357805519641, 0.9880041684830996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 170}], {
             RGBColor[
             0.8538078865318393, 0.7231157274766271, 0.6057400278617049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 175}], {
             RGBColor[
             0.8142321176778045, 0.854803585813976, 0.9821187061245199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 183}], {
             RGBColor[
             0.8178269248212674, 0.3755531553124956, 0.43700475110130366`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 199}], {
             RGBColor[
             0.6002091422769898, 0.6816643635299937, 0.9640564426431248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 168}], {
             RGBColor[
             0.41315974244564957`, 0.5322799357191343, 0.9475471513391897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 176}], {
             RGBColor[
             0.44836054277140025`, 0.562769099717632, 0.949790115209101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 188}], {
             RGBColor[
             0.5451528438785904, 0.6413367970092809, 0.9574334435962231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 160}], {
             RGBColor[
             0.7183537959931587, 0.7794775716917913, 0.9728682798107356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 176}], {
             RGBColor[
             0.6382220099146264, 0.7143865695703009, 0.9665700717964373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.9000844700747641, 0.9221353725440798, 0.9545669433721453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 161}], {
             RGBColor[
             0.780383279950623, 0.8290043092262979, 0.9779615923025747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 162}], {
             RGBColor[
             0.6590416016315311, 0.7285456915833621, 0.9689473626908024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 164}], {
             RGBColor[
             0.7317513501763553, 0.7895227177920778, 0.9741331086461158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 173}], {
             RGBColor[
             0.8921916663349507, 0.9168525791403799, 0.9888562114368259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 180}], {
             RGBColor[
             0.9319034158963638, 0.948517650293925, 0.9926439535610908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 200}], {
             RGBColor[
             0.9109261754283051, 0.9317909681567185, 0.9906431256386437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[
             0.7939713569803492, 0.8387413942147655, 0.9443156393121679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 162}], {
             RGBColor[
             0.5029171884092695, 0.6053818787654363, 0.9545488615941113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 164}], {
             RGBColor[
             0.5756269369540936, 0.666358904974152, 0.9597346075494249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 173}], {
             RGBColor[
             0.7360672531126892, 0.793688766322454, 0.9744577103401348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 180}], {
             RGBColor[
             0.7757790026741023, 0.825353837475999, 0.9782454524643998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 200}], {
             RGBColor[
             0.7548017622060434, 0.8086271553387925, 0.9762446245419527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 172}], {
             RGBColor[
             0.3815755100901777, 0.5049232611225005, 0.945534631982339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 173}], {
             RGBColor[
             0.6147255747935974, 0.6932301486795183, 0.9654434807283625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 180}], {
             RGBColor[
             0.6544373243550103, 0.7248952198330634, 0.9692312228526274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 165}], {
             RGBColor[
             0.9914283995635995, 0.9885125235023517, 0.6310070467806849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 175}], {
             RGBColor[
             0.9011703185736463, 0.9190185424210885, 0.7152823051347722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 177}], {
             RGBColor[
             0.9927889787396373, 0.9869846796071984, 0.45650302095332185`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 200}], {
             RGBColor[
             0.7061698324317758, 0.7691455639045726, 0.9724161408854938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 169}], {
             RGBColor[
             0.7661180659830259, 0.8146643423260661, 0.8851018845632905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 175}], {
             RGBColor[
             0.89987954188176, 0.9206956867717284, 0.8973839005910417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 177}], {
             RGBColor[
             0.9914982020477512, 0.9886618239578384, 0.6386046164095913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 170}], {
             RGBColor[
             0.910669037987158, 0.7684460420911046, 0.6111659430408936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 179}], {
             RGBColor[
             0.7891972686900904, 0.8361561224496998, 0.9793819933411839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 183}], {
             RGBColor[
             0.8557343591248132, 0.40577336505548056`, 0.44062202788742943`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 192}], {
             RGBColor[
             0.6807977304033043, 0.7475461912132446, 0.9709942491056411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 198}], {
             RGBColor[
             0.8242931439234709, 0.8635732869205476, 0.9828800221948462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 189}], {
             RGBColor[
             0.8857881273632648, 0.9115776999234495, 0.9823905705015918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 194}], {
             RGBColor[
             0.8381977869978184, 0.873820179351983, 0.9844292472634915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 197}], {
             RGBColor[
             0.8963465223467546, 0.9194521336143511, 0.9645179618649897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 188}], {
             RGBColor[
             0.5135686115231186, 0.6139801224126471, 0.9554209242393723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 189}], {
             RGBColor[
             0.6623159151590436, 0.7309876692509847, 0.9634048039664628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 197}], {
             RGBColor[
             0.6728743101425336, 0.7388621029418864, 0.9455321953298607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 177}], {
             RGBColor[
             0.7674786451590638, 0.8131364984309128, 0.7105978587359276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 190}], {
             RGBColor[
             0.5122765168174035, 0.6149281800032826, 0.9547474304160293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 179}], {
             RGBColor[
             0.7673012293028089, 0.6555360693743628, 0.5971178527197892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 183}], {
             RGBColor[
             0.8411369995332921, 0.28535999633858916`, 0.1857792674731663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[
             0.6589016910160227, 0.5669261381379076, 0.5887301084842465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 198}], {
             RGBColor[
             0.8023971045361893, 0.6829532338452105, 0.6006158815734515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 174}], {
             RGBColor[
             0.7540487849971467, 0.8036092475500161, 0.8222939445283761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 182}], {
             RGBColor[
             0.4473704811576865, 0.5602865594679561, 0.9501760213249737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 191}], {
             RGBColor[
             0.6636634102266, 0.7351990868097442, 0.9684645325740817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 195}], {
             RGBColor[
             0.5082781176288649, 0.6116820994161962, 0.9544326617852887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 196}], {
             RGBColor[
             0.5920498115097083, 0.6792539992085995, 0.9613267583211114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 199}], {
             RGBColor[
             0.4473704811576865, 0.5602865594679561, 0.9501760213249737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 173}], {
             RGBColor[
             0.6147255747935974, 0.6932301486795183, 0.9654434807283625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 180}], {
             RGBColor[
             0.6544373243550103, 0.7248952198330634, 0.9692312228526274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 191}], {
             RGBColor[
             0.5978684391590913, 0.6798357884642887, 0.963823143231447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 180}], {
             RGBColor[
             0.88758738905843, 0.9132021073900811, 0.9891400715986509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 186}], {
             RGBColor[
             0.9601580557020191, 0.9674543656022553, 0.8412578119368648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 196}], {
             RGBColor[
             0.8329331442816597, 0.8672133889452038, 0.8288032921818791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 183}], {
             RGBColor[
             0.8147531536306023, 0.37315190189682174`, 0.436698386315043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 188}], {
             RGBColor[
             0.5487694118488693, 0.6444692864111449, 0.9576638881092836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 179}], {
             RGBColor[
             0.8193441206147651, 0.8551900648978216, 0.714717246801154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 190}], {
             RGBColor[
             0.7376566528821287, 0.7889256616350548, 0.7082501622623301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 183}], {
             RGBColor[
             0.7601558200019137, 0.330500049910986, 0.4312566343400266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 192}], {
             RGBColor[
             0.5374299217189551, 0.6346362184965029, 0.9569461587845367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 185}], {
             RGBColor[
             0.6785680340093483, 0.7170727128704099, 0.6525462219231781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 195}], {
             RGBColor[
             0.442483146561356, 0.5563188010707406, 0.949791272442654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 196}], {
             RGBColor[
             0.5262548404421995, 0.623890700863144, 0.9566853689784767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 199}], {
             RGBColor[
             0.3815755100901777, 0.5049232611225005, 0.945534631982339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 192}], {
             RGBColor[
             0.6878894611440564, 0.2714267624200159, 0.4256648048496646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 186}], {
             RGBColor[
             0.9181900562870167, 0.9376038435508833, 0.992058981318237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 194}], {
             RGBColor[
             0.8794358792180552, 0.9067023147102062, 0.9883625733131371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 198}], {
             RGBColor[
             0.5487983602813399, 0.641501869898577, 0.9589322963548716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 194}], {
             RGBColor[
             0.8954659798624633, 0.9192945568080024, 0.9833136527124863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 197}], {
             RGBColor[
             0.9536147152113996, 0.9649265110703706, 0.9634023673139844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 195}], {
             RGBColor[
             0.6587760756302696, 0.7312313284125287, 0.9680797836917621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 199}], {
             RGBColor[
             0.5978684391590913, 0.6798357884642887, 0.963823143231447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 197}], {
             RGBColor[
             0.9060243748459533, 0.9271689904989041, 0.9654410440758842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 196}], {
             RGBColor[
             0.5871624769133779, 0.675286240811384, 0.9609420094387917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 199}], {
             RGBColor[
             0.442483146561356, 0.5563188010707406, 0.949791272442654]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.04610843439966642], {
             RGBColor[
             0.3815755100901777, 0.5049232611225005, 0.945534631982339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.04610843439966642], {
             RGBColor[
             0.8155308475178892, 0.8558181634357627, 0.9822481513776592]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.04610843439966642], {
             RGBColor[
             0.9940097966037453, 0.9895958855749055, 0.5893815114469507]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.04610843439966642], {
             RGBColor[
             0.8044424326692756, 0.8471558094809515, 0.9811429618126776]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.04610843439966642], {
             RGBColor[
             0.9944770604825918, 0.9905953157641331, 0.6402403010409925]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.04610843439966642], {
             RGBColor[
             0.4274187820836781, 0.544630399173424, 0.9484557247361511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.04610843439966642], {
             RGBColor[
             0.4864927292434324, 0.5939957397043396, 0.9527176362090803]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.04610843439966642], {
             RGBColor[
             0.9900793320978125, 0.9901655631199792, 0.8140746712121761]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.04610843439966642], {
             RGBColor[
             0.628502962762976, 0.7092860447636198, 0.9638972019923646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.04610843439966642], {
             RGBColor[
             0.6213607656770951, 0.7034876874169896, 0.9633349420750341]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.04610843439966642], {
             RGBColor[
             0.9852002068256696, 0.988147919432148, 0.8949344037430278]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.04610843439966642], {
             RGBColor[
             0.9940364537522196, 0.9896529025200407, 0.5922829775495202]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.04610843439966642], {
             RGBColor[
             0.7509613086047295, 0.8053759488901308, 0.9758124631754433]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.04610843439966642], {
             RGBColor[
             0.9939877753369902, 0.9895487843120079, 0.5869846324601637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.04610843439966642], {
             RGBColor[
             0.934534399866064, 0.950636379465428, 0.9936179193995743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.04610843439966642], {
             RGBColor[
             0.7038147730162924, 0.7685447169615018, 0.9711133371174128]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.04610843439966642], {
             RGBColor[
             0.8882774709601399, 0.9137523599667302, 0.9892058922264794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.04610843439966642], {
             RGBColor[
             0.3815755100901777, 0.5049232611225005, 0.945534631982339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.04610843439966642], {
             RGBColor[
             0.9644282637626901, 0.9729912378743624, 0.9450978502418043]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.04610843439966642], {
             RGBColor[
             0.9286651923391045, 0.7548882890797077, 0.26146054319414413`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.04610843439966642], {
             RGBColor[
             0.9216971872817327, 0.940400334607535, 0.9923934946033659]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.04610843439966642], {
             RGBColor[
             0.9040123237751339, 0.6570242054017887, 0.24161786889577586`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.04610843439966642], {
             RGBColor[
             0.9413023578940581, 0.9557439751427321, 0.984243976675156]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.04610843439966642], {
             RGBColor[
             0.8464954751415058, 0.8804365306430147, 0.9852206881660701]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.04610843439966642], {
             RGBColor[
             0.4591854212430382, 0.5718264368894131, 0.9505679048933242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.04610843439966642], {
             RGBColor[
             0.48225475907378146`, 0.5905551646022364, 0.9523840076731291]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.04610843439966642], {
             RGBColor[
             0.3815755100901777, 0.5049232611225005, 0.945534631982339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.04610843439966642], {
             RGBColor[
             0.41394413348173864`, 0.5329593358099549, 0.9475971320423995]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.04610843439966642], {
             RGBColor[
             0.6157768650188236, 0.6989544253107468, 0.9628953569607129]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.04610843439966642], {
             RGBColor[
             0.6059160255043872, 0.6909489515671696, 0.9621190755526912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.04610843439966642], {
             RGBColor[
             0.851537889291834, 0.8844572148138006, 0.9857016381291447]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.04610843439966642], {
             RGBColor[
             0.4860788630689587, 0.5936597444994431, 0.952685055147784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.04610843439966642], {
             RGBColor[
             0.5017045399978106, 0.6063453729590088, 0.9539151656743639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.04610843439966642], {
             RGBColor[
             0.656355357278861, 0.7314690606825014, 0.9663830260901616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.04610843439966642], {
             RGBColor[
             0.7401133163156276, 0.7969014148660893, 0.9747312366843174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.04610843439966642], {
             RGBColor[
             0.994515563694754, 0.9906776702416761, 0.6444311380705681]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.04610843439966642], {
             RGBColor[
             0.4521902848637532, 0.5660862298295938, 0.9500341429887177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.04610843439966642], {
             RGBColor[
             0.9365076931728845, 0.9521681220442237, 0.9923600933992658]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.04610843439966642], {
             RGBColor[
             0.6934766972916435, 0.7604685336331206, 0.9700829343439902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.04610843439966642], {
             RGBColor[
             0.9272991386198431, 0.9448671785436261, 0.9929278137229158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.04610843439966642], {
             RGBColor[
             0.8335717112346562, 0.8701314721099188, 0.9839880080274546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.04610843439966642], {
             RGBColor[
             0.687129593528892, 0.7555101279338838, 0.969450314357976]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.04610843439966642], {
             RGBColor[
             0.9061754973333748, 0.9280237603677641, 0.9909130219597153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.04610843439966642], {
             RGBColor[
             0.6516198193228064, 0.7277696224398101, 0.9659110319228204]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.04610843439966642], {
             RGBColor[
             0.5958516281723363, 0.6827782204170778, 0.9613267693276099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.04610843439966642], {
             RGBColor[
             0.5275526569562872, 0.6273300387502991, 0.9559500241261074]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.04610843439966642], {
             RGBColor[
             0.4924757609649053, 0.5988530343883388, 0.953188642382762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.04610843439966642], {
             RGBColor[
             0.6033474622444709, 0.6888636762003134, 0.9619168688439133]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.04610843439966642], {
             RGBColor[
             0.6513034693736895, 0.7275224874552113, 0.9658795011163507]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.04610843439966642], {
             RGBColor[
             0.5498011902129671, 0.6453924003330732, 0.9577015101631359]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.04610843439966642], {
             RGBColor[
             0.9462087779129132, 0.9594031751592688, 0.9759386873825212]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.04610843439966642], {
             RGBColor[
             0.8127960478818615, 0.8536817171748508, 0.9819755721080956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.04610843439966642], {
             RGBColor[
             0.7229926367196754, 0.7835266098437472, 0.9730248073440402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.04610843439966642], {
             RGBColor[
             0.9497360629755573, 0.9620338185835895, 0.9699679138347472]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.04610843439966642], {
             RGBColor[
             0.3748395140950027, 0.4990888799524827, 0.9451054202739338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.04610843439966642], {
             RGBColor[
             0.9949886733556723, 0.991689603967656, 0.6959262049671415]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.04610843439966642], {
             RGBColor[
             0.9292072738494066, 0.946388673780729, 0.9931098133645241]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.04610843439966642], {
             RGBColor[
             0.9272991386198431, 0.9448671785436261, 0.9929278137229158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.04610843439966642], {
             RGBColor[
             0.3815755100901777, 0.5049232611225005, 0.945534631982339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.04610843439966642], {
             RGBColor[
             0.45143526787183896`, 0.5654322720594551, 0.9499860339736282]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.04610843439966642], {
             RGBColor[
             0.9575518302016578, 0.967862804983671, 0.9567378585995239]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.04610843439966642], {
             RGBColor[
             0.9373300916492292, 0.9527814654813278, 0.9909679872946892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.04610843439966642], {
             RGBColor[
             0.46005518075186375`, 0.5725325468408972, 0.9506363755478929]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.04610843439966642], {
             RGBColor[
             0.9505666065717395, 0.9626532366377318, 0.9685620201668733]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.04610843439966642], {
             RGBColor[
             0.5887657751770851, 0.6770256057414932, 0.960768945023489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.04610843439966642], {
             RGBColor[
             0.6568747459233402, 0.7318748110390684, 0.9664347938962804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.04610843439966642], {
             RGBColor[
             0.9210526773436145, 0.7247072038428337, 0.25533533494008015`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.04610843439966642], {
             RGBColor[
             0.9927191762554858, 0.9868353791517118, 0.4489054513244154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.04610843439966642], {
             RGBColor[
             0.9337875244779437, 0.9500408413043331, 0.9935466817583118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.04610843439966642], {
             RGBColor[
             0.8320933957551653, 0.8689527034743775, 0.9838470049773129]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.04610843439966642], {
             RGBColor[
             0.5141681496733971, 0.6164638927728673, 0.9548963466837326]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.04610843439966642], {
             RGBColor[
             0.44873708087818204`, 0.563095238100371, 0.9498141078843055]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.04610843439966642], {
             RGBColor[
             0.4567193346095573, 0.5698243566644167, 0.9503737655199636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.04610843439966642], {
             RGBColor[
             0.5967958280403065, 0.6835447644056154, 0.9614011001999346]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.04610843439966642], {
             RGBColor[
             0.6594390672957938, 0.7338780783847935, 0.9666903814857409]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.04610843439966642], {
             RGBColor[
             0.9933130901637146, 0.9881057009475062, 0.5135493150233552]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.04610843439966642], {
             RGBColor[
             0.6601645113233569, 0.7344448007727046, 0.9667626869667485]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.04610843439966642], {
             RGBColor[
             0.8130940138451017, 0.8539144904499592, 0.9820052705706611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.04610843439966642], {
             RGBColor[
             0.6599704407329443, 0.7342931913524832, 0.966743343823989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.04610843439966642], {
             RGBColor[
             0.8929077782695062, 0.9174444413288751, 0.9896475350711709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.04610843439966642], {
             RGBColor[
             0.3815755100901777, 0.5049232611225005, 0.945534631982339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.04610843439966642], {
             RGBColor[
             0.8219176544917024, 0.8608388436040305, 0.9828764336916124]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.04610843439966642], {
             RGBColor[
             0.3815755100901777, 0.5049232611225005, 0.945534631982339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.04610843439966642], {
             RGBColor[
             0.5595628571973431, 0.6533173613490758, 0.9584699843463104]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.04610843439966642], {
             RGBColor[
             0.9820161024677638, 0.9861082191831636, 0.9153262269571099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.04610843439966642], {
             RGBColor[
             0.5306940692183039, 0.629880378743614, 0.9561973276067456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.04610843439966642], {
             RGBColor[
             0.6033474622444709, 0.6888636762003134, 0.9619168688439133]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.04610843439966642], {
             RGBColor[
             0.4997870679765526, 0.6047886827910214, 0.953764215252919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.04610843439966642], {
             RGBColor[
             0.9933199719389796, 0.9881204203689438, 0.5142983537915533]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.04610843439966642], {
             RGBColor[
             0.4819612137381516, 0.5903168512747055, 0.9523608987090164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.04610843439966642], {
             RGBColor[
             0.4864927292434324, 0.5939957397043396, 0.9527176362090803]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.04610843439966642], {
             RGBColor[
             0.8155308475178892, 0.8558181634357627, 0.9822481513776592]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.04610843439966642], {
             RGBColor[
             0.46005518075186375`, 0.5725325468408972, 0.9506363755478929]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.04610843439966642], {
             RGBColor[
             0.8285594747690039, 0.220526214682015, 0.17498189133309858`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.04610843439966642], {
             RGBColor[
             0.9596592239612939, 0.969434495799067, 0.9531705906607804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.04610843439966642], {
             RGBColor[
             0.979080002176097, 0.9839184803930615, 0.9202962788933019]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.04610843439966642], {
             RGBColor[
             0.3815755100901777, 0.5049232611225005, 0.945534631982339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.04610843439966642], {
             RGBColor[
             0.3815755100901777, 0.5049232611225005, 0.945534631982339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.04610843439966642], {
             RGBColor[
             0.8606256715927654, 0.8917035657392842, 0.9865684389177665]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.04610843439966642], {
             RGBColor[
             0.3815755100901777, 0.5049232611225005, 0.945534631982339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.04610843439966642], {
             RGBColor[
             0.5385436788527915, 0.6362530454657753, 0.95681527763124]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.04610843439966642], {
             RGBColor[
             0.3815755100901777, 0.5049232611225005, 0.945534631982339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.04610843439966642], {
             RGBColor[
             0.847875639497017, 0.881537036236536, 0.985352329474386]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.04610843439966642], {
             RGBColor[
             0.7202932502266978, 0.7814178285993358, 0.9727557577256212]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.04610843439966642], {
             RGBColor[
             0.9413023578940581, 0.9557439751427321, 0.984243976675156]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.04610843439966642], {
             RGBColor[
             0.3815755100901777, 0.5049232611225005, 0.945534631982339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.04610843439966642], {
             RGBColor[
             0.5787603305790081, 0.6689027350766317, 0.9599812797735772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.04610843439966642], {
             RGBColor[
             0.9210008270642593, 0.7245016347632713, 0.25529361498822845`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.04610843439966642], {
             RGBColor[
             0.5678457915823428, 0.6600418206247604, 0.959122047282486]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.04610843439966642], {
             RGBColor[
             0.9927191762554858, 0.9868353791517118, 0.4489054513244154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.04610843439966642], {
             RGBColor[
             0.7596984208440716, 0.8122014473760172, 0.9766832968705049]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.04610843439966642], {
             RGBColor[
             0.7675691371093368, 0.8183501107421016, 0.9774677763118013]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.04610843439966642], {
             RGBColor[
             0.6849959676463034, 0.7538433231782483, 0.9692376544698671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.04610843439966642], {
             RGBColor[
             0.5293102784779798, 0.6287569550815565, 0.9560883905306747]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.04610843439966642], {
             RGBColor[
             0.8855563797889257, 0.9115826357288562, 0.9889463521214222]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.04610843439966642], {
             RGBColor[
             0.9916509854269356, 0.9908154821612197, 0.7880283082401708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.04610843439966642], {
             RGBColor[
             0.5142974481105278, 0.6165688630689582, 0.9549065255303393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.04610843439966642], {
             RGBColor[
             0.9927609270095483, 0.986924679793003, 0.4534497632483429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.04610843439966642], {
             RGBColor[
             0.7693588610097197, 0.8197482566554861, 0.9776461592642707]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.04610843439966642], {
             RGBColor[
             0.7509613086047295, 0.8053759488901308, 0.9758124631754433]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.04610843439966642], {
             RGBColor[
             0.8748599141860629, 0.9030535644049574, 0.9879261136833736]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.04610843439966642], {
             RGBColor[
             0.5447498706827788, 0.6412915115791147, 0.9573038517861263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.04610843439966642], {
             RGBColor[
             0.6332578010675263, 0.7131462367022783, 0.9642715202812454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.04610843439966642], {
             RGBColor[
             0.8903489353368783, 0.9154040894323389, 0.9894034703479507]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.04610843439966642], {
             RGBColor[
             0.7411091717751139, 0.7976793847198219, 0.9748304942497206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.04610843439966642], {
             RGBColor[
             0.6998042245689352, 0.7654116460331293, 0.9707136031288862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.04610843439966642], {
             RGBColor[
             0.593666059681636, 0.6810038774575888, 0.9611547133700208]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.04610843439966642], {
             RGBColor[
             0.9870945470479613, 0.9681290182276302, 0.4043651815819689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.04610843439966642], {
             RGBColor[
             0.60647934286941, 0.6914062779812532, 0.9621634219591653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.04610843439966642], {
             RGBColor[
             0.8178679850666508, 0.8576439530517584, 0.9824810954067276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.04610843439966642], {
             RGBColor[
             0.9903442611560344, 0.9902751180939201, 0.8096841111030161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.04610843439966642], {
             RGBColor[
             0.4926237907331135, 0.5989732116228352, 0.9532002958283663]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.04610843439966642], {
             RGBColor[
             0.6966622088101166, 0.762957079442136, 0.9704004363618539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.04610843439966642], {
             RGBColor[
             0.9613581835008072, 0.8813142207975503, 0.3043842691057218]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.04610843439966642], {
             RGBColor[
             0.8423230424858309, 0.8771095461010469, 0.9848227178145972]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.04610843439966642], {
             RGBColor[
             0.49795844922627686`, 0.6033041277112117, 0.953620259686446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.04610843439966642], {
             RGBColor[
             0.48781040492572747`, 0.5950654881838398, 0.9528213684655957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.04610843439966642], {
             RGBColor[
             0.6123564377234234, 0.6961775683438474, 0.962626088394581]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.04610843439966642], {
             RGBColor[
             0.8391681221976648, 0.8745938983012931, 0.9845217987010814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.04610843439966642], {
             RGBColor[
             0.9947994107843087, 0.9921174369573345, 0.735850752204861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.04610843439966642], {
             RGBColor[
             0.5645685638828272, 0.6573812195408681, 0.9588640519130994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.04610843439966642], {
             RGBColor[
             0.9930161992863115, 0.9874706813810131, 0.48123457521613255`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.04610843439966642], {
             RGBColor[
             0.9929692141040461, 0.9873701848270781, 0.47612052808547867`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.04610843439966642], {
             RGBColor[
             0.5678585011357061, 0.6600521388127395, 0.9591230478250833]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.04610843439966642], {
             RGBColor[
             0.9864283205978349, 0.9886557760380227, 0.8745813802816876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.04610843439966642], {
             RGBColor[
             0.4274830458528618, 0.5446860612202999, 0.9484598195666973]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.04610843439966642], {
             RGBColor[
             0.5852844396783876, 0.6741993007512735, 0.9604948815404794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.04610843439966642], {
             RGBColor[
             0.8962870289239572, 0.6219454457710489, 0.23517169350764927`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.04610843439966642], {
             RGBColor[
             0.5852844396783876, 0.6741993007512735, 0.9604948815404794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.04610843439966642], {
             RGBColor[
             0.9755605579285189, 0.9292221646183192, 0.3595578118640172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.04610843439966642], {
             RGBColor[
             0.8726082574381631, 0.9012581544337763, 0.9877113486526812]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.04610843439966642], {
             RGBColor[
             0.9930161992863115, 0.9874706813810131, 0.48123457521613255`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.04610843439966642], {
             RGBColor[
             0.5139016799493005, 0.6162475606465213, 0.954875369210941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.04610843439966642], {
             RGBColor[
             0.6645582800323124, 0.7378772462820197, 0.9672006167695542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.04610843439966642], {
             RGBColor[
             0.818842774463802, 0.8584054659374868, 0.9825782533039108]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.04610843439966642], {
             RGBColor[
             0.4447439748011214, 0.5596366103157681, 0.9495596706960403]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.04610843439966642], {
             RGBColor[
             0.8244669090875737, 0.8628715500211057, 0.983119583870713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.04610843439966642], {
             RGBColor[
             0.9365076931728845, 0.9521681220442237, 0.9923600933992658]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.04610843439966642], {
             RGBColor[
             0.6122406828987438, 0.6960835933624769, 0.9626169757507583]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.04610843439966642], {
             RGBColor[
             0.6242588667283613, 0.705840496408372, 0.9635630912058837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.04610843439966642], {
             RGBColor[
             0.3815755100901777, 0.5049232611225005, 0.945534631982339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.04610843439966642], {
             RGBColor[
             0.9927191762554858, 0.9868353791517118, 0.4489054513244154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.04610843439966642], {
             RGBColor[
             0.5269950071798261, 0.6268773135399319, 0.9559061238929659]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.04610843439966642], {
             RGBColor[
             0.9901376228717133, 0.9901896678529917, 0.8131086422369543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.04610843439966642], {
             RGBColor[
             0.9325650773744396, 0.9490660951664416, 0.9934300836622882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.04610843439966642], {
             RGBColor[
             0.8285199344986198, 0.8661033224674299, 0.983506165052597]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.04610843439966642], {
             RGBColor[
             0.3815755100901777, 0.5049232611225005, 0.945534631982339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.04610843439966642], {
             RGBColor[
             0.5420985090943385, 0.6391390167991405, 0.9570951268896268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.04610843439966642], {
             RGBColor[
             0.8887729985998765, 0.5878259890157674, 0.22890180241949887`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.04610843439966642], {
             RGBColor[
             0.5131654522251953, 0.6156498578134117, 0.9548174106676084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.04610843439966642], {
             RGBColor[
             0.3815755100901777, 0.5049232611225005, 0.945534631982339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.04610843439966642], {
             RGBColor[
             0.847875639497017, 0.881537036236536, 0.985352329474386]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.04610843439966642], {
             RGBColor[
             0.994932117769098, 0.9915686372866204, 0.6897704783891437]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.04610843439966642], {
             RGBColor[
             0.8096214608918068, 0.8512017056904652, 0.981659158945129]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.04610843439966642], {
             RGBColor[
             0.45197711074167907`, 0.5659015891194961, 0.9500205597221616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.04610843439966642], {
             RGBColor[
             0.992858781223789, 0.987133980062685, 0.4641005905822283]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.04610843439966642], {
             RGBColor[
             0.7365588555963704, 0.7941246431373036, 0.9743769612581458]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.04610843439966642], {
             RGBColor[
             0.6458294600057413, 0.7232461497329581, 0.9653339030200796]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.04610843439966642], {
             RGBColor[
             0.9272991386198431, 0.9448671785436261, 0.9929278137229158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.04610843439966642], {
             RGBColor[
             0.9757020310619545, 0.981399195067054, 0.9260143028735776]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.04610843439966642], {
             RGBColor[
             0.3815755100901777, 0.5049232611225005, 0.945534631982339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.04610843439966642], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.04610843439966642], {
             RGBColor[
             0.9109961189390933, 0.9318675931838765, 0.9913728171518884]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.04610843439966642], {
             RGBColor[
             0.9755605579285189, 0.9292221646183192, 0.3595578118640172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.04610843439966642], {
             RGBColor[
             0.9253839936349402, 0.9433400939178902, 0.9927451454845857]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.04610843439966642], {
             RGBColor[
             0.3815755100901777, 0.5049232611225005, 0.945534631982339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.04610843439966642], {
             RGBColor[
             0.6455617129560596, 0.7230369837027937, 0.9653072164964057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.04610843439966642], {
             RGBColor[
             0.9430563202279098, 0.957052077379469, 0.9812749759505865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.04610843439966642], {
             RGBColor[
             0.48245452454046833`, 0.5907173432074246, 0.9523997339424318]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.04610843439966642], {
             RGBColor[
             0.8141613682280048, 0.8547483158060768, 0.982111654480555]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.04610843439966642], {
             RGBColor[
             0.429030383432169, 0.5460262872600478, 0.9485584145489939]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.04610843439966642], {
             RGBColor[
             0.47247615917416863`, 0.5826164566828255, 0.9516142004688399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.04610843439966642], {
             RGBColor[
             0.847875639497017, 0.881537036236536, 0.985352329474386]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.04610843439966642], {
             RGBColor[
             0.5033907830325344, 0.6077143410189807, 0.9540479129029691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.04610843439966642], {
             RGBColor[
             0.6709341707942212, 0.7428581406037874, 0.9678361059746144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.04610843439966642], {
             RGBColor[
             0.9641731101948895, 0.9728009447612722, 0.9455297586773823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.04610843439966642], {
             RGBColor[
             0.7160212104725021, 0.7780804786746536, 0.9723299607274042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.04610843439966642], {
             RGBColor[
             0.3815755100901777, 0.5049232611225005, 0.945534631982339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.04610843439966642], {
             RGBColor[
             0.8853446576837256, 0.9114138142692131, 0.9889261578780216]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
          103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
          129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 
          142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 
          155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 
          168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 
          181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 
          194, 195, 196, 197, 198, 199, 200}, {Null, CompressedData["
1:eJwVxfk/Gg4DAOBN5QibNGP1lWNDwghlmCNXuqiMigzJGcNQUi05SwdqhpKc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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[21, 55] -> 
             RGBColor[
              0.34859095953566543`, 0.47635370128389704`, 0.9434328855880982],
              UndirectedEdge[64, 132] -> 
             RGBColor[
              0.4650482384089718, 0.5716822037632778, 0.9522031318796592], 
             UndirectedEdge[42, 188] -> 
             RGBColor[
              0.2579862693567474, 0.38807828505832953`, 0.9380183944910747], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.5482557857976138, 0.6358309000327967, 0.9605283874597037], 
             UndirectedEdge[33, 68] -> 
             RGBColor[
              0.9768074272678445, 0.9356471682387506, 0.5374347809068445], 
             UndirectedEdge[168, 188] -> 
             RGBColor[
              0.2612998708737691, 0.39156109034719, 0.938207099195435], 
             UndirectedEdge[41, 161] -> 
             RGBColor[
              0.2872671394725109, 0.41926635574719545`, 0.9396708106680862], 
             UndirectedEdge[44, 68] -> 
             RGBColor[
              0.9298826077939246, 0.7566572199616033, 0.27010292258186963`], 
             UndirectedEdge[26, 136] -> 
             RGBColor[
              0.2577972163446346, 0.3882915980387517, 0.9379925421427979], 
             UndirectedEdge[9, 32] -> 
             RGBColor[
              0.18966018913671598`, 0.3166752623061849, 0.9341122392430056], 
             UndirectedEdge[71, 141] -> 
             RGBColor[
              0.3537772547746116, 0.4808458095490941, 0.9437633517346631], 
             UndirectedEdge[52, 100] -> 
             RGBColor[
              0.1956898688928864, 0.3230128380336974, 0.9344556205850076], 
             UndirectedEdge[172, 180] -> 
             RGBColor[
              0.6056868100783286, 0.4851310394922843, 0.577851031637082], 
             UndirectedEdge[168, 197] -> 
             RGBColor[
              0.20505165545148296`, 0.3328526692783333, 0.9349887604799977], 
             UndirectedEdge[125, 137] -> 
             RGBColor[
              0.29408774568202667`, 0.42503485891778914`, 0.9401105091078588],
              UndirectedEdge[17, 147] -> 
             RGBColor[
              0.22049695582396892`, 0.34908665925842064`, 0.9358683474869365],
              UndirectedEdge[10, 71] -> 
             RGBColor[
              0.2908445212370684, 0.4179419677193835, 0.9400607036352882], 
             UndirectedEdge[27, 129] -> 
             RGBColor[
              0.36049570993893, 0.4827296556793453, 0.9443430413040212], 
             UndirectedEdge[67, 166] -> 
             RGBColor[
              0.5298097305765306, 0.6164429264479874, 0.9594779119033563], 
             UndirectedEdge[3, 49] -> 
             RGBColor[
              0.42052372581365627`, 0.5386582479879358, 0.9480163778476842], 
             UndirectedEdge[151, 183] -> 
             RGBColor[
              0.9651436444656913, 0.888619018725243, 0.5091874749108671], 
             UndirectedEdge[125, 136] -> 
             RGBColor[
              0.24354766177349693`, 0.373314412710544, 0.9371810510902985], 
             UndirectedEdge[139, 194] -> 
             RGBColor[
              0.2435950267958037, 0.37336419635210427`, 0.9371837484582486], 
             UndirectedEdge[24, 108] -> 
             RGBColor[
              0.28258697373339425`, 0.41434720481573717`, 0.9394042821529283],
              UndirectedEdge[21, 192] -> 
             RGBColor[
              0.4135089355037963, 0.532245803699352, 0.9476624011874208], 
             UndirectedEdge[16, 52] -> 
             RGBColor[
              0.18638226183152043`, 0.31322995287582944`, 0.9339255661322337],
              UndirectedEdge[44, 166] -> 
             RGBColor[
              0.8512516278317916, 0.7399182542257667, 0.6091593456597434], 
             UndirectedEdge[78, 187] -> 
             RGBColor[
              0.19320618779608617`, 0.3204023317264835, 0.9343141786208218], 
             UndirectedEdge[99, 162] -> 
             RGBColor[
              0.5016163434350541, 0.6062220183620153, 0.9539225219304044], 
             UndirectedEdge[93, 150] -> 
             RGBColor[
              0.21197440955790398`, 0.3401289227721434, 0.9353830010850614], 
             UndirectedEdge[118, 155] -> 
             RGBColor[
              0.5320287520312512, 0.6287959624909311, 0.9570938290152922], 
             UndirectedEdge[16, 125] -> 
             RGBColor[
              0.22572938407249296`, 0.3545862731027316, 0.936166326535006], 
             UndirectedEdge[61, 179] -> 
             RGBColor[
              0.2879403991921272, 0.41444560530367136`, 0.9399115732194068], 
             UndirectedEdge[51, 197] -> 
             RGBColor[
              0.1914512391651612, 0.3185577694452115, 0.9342142368925045], 
             UndirectedEdge[80, 120] -> 
             RGBColor[
              0.20786563933481106`, 0.33581034475659416`, 0.9351490126992371],
              UndirectedEdge[21, 183] -> 
             RGBColor[
              0.6488438964095984, 0.6364280199535685, 0.605957146255827], 
             UndirectedEdge[182, 199] -> 
             RGBColor[
              0.668046802775716, 0.7309711261041182, 0.8355721890992451], 
             UndirectedEdge[17, 189] -> 
             RGBColor[
              0.19295037100619816`, 0.32013345206058996`, 0.9342996102330847],
              UndirectedEdge[116, 136] -> 
             RGBColor[
              0.23171997218972168`, 0.36088276103916334`, 0.9365074816660013],
              UndirectedEdge[119, 123] -> 
             RGBColor[
              0.7149253774106119, 0.4290074920684967, 0.44497128325517005`], 
             UndirectedEdge[71, 89] -> 
             RGBColor[
              0.315626713124748, 0.4439896226750534, 0.9414720128013241], 
             UndirectedEdge[7, 61] -> 
             RGBColor[
              0.2079174287175954, 0.335864778681537, 0.9351519620279711], 
             UndirectedEdge[3, 27] -> 
             RGBColor[
              0.3426067292683088, 0.4672664245880422, 0.9431945216539286], 
             UndirectedEdge[41, 108] -> 
             RGBColor[
              0.29936649893310274`, 0.4319835496839754, 0.9403598512899686], 
             UndirectedEdge[66, 98] -> 
             RGBColor[
              0.18802367047876978`, 0.3149551774354076, 0.9340190419264479], 
             UndirectedEdge[119, 127] -> 
             RGBColor[
              0.8561463869507269, 0.5416184097408903, 0.4576222745671909], 
             UndirectedEdge[15, 167] -> 
             RGBColor[
              0.18913040232451964`, 0.31611842277614255`, 0.9340820686678004],
              UndirectedEdge[12, 96] -> 
             RGBColor[
              0.9432592874949708, 0.8959893159471047, 0.6356118637427102], 
             UndirectedEdge[7, 52] -> 
             RGBColor[
              0.19704159904264756`, 0.32443359212573797`, 0.934532599617331], 
             UndirectedEdge[163, 165] -> 
             RGBColor[
              0.24378292836413576`, 0.3735616928140688, 0.9371944491745896], 
             UndirectedEdge[71, 73] -> 
             RGBColor[
              0.29060892456725834`, 0.41769434068172157`, 0.9400472867534765],
              UndirectedEdge[60, 165] -> 
             RGBColor[
              0.1933919500064047, 0.32059757958753266`, 0.9343247575038889], 
             UndirectedEdge[120, 124] -> 
             RGBColor[
              0.20998768265750406`, 0.3380407468340621, 0.9352698599271827], 
             UndirectedEdge[43, 163] -> 
             RGBColor[
              0.2357550055079826, 0.36512383689254435`, 0.9367372708441793], 
             UndirectedEdge[146, 194] -> 
             RGBColor[
              0.22346288152433108`, 0.352204035220052, 0.9360372525678782], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.24761466346370808`, 0.37758908934975655`, 0.9374126608199662],
              UndirectedEdge[81, 157] -> 
             RGBColor[
              0.25622740358141927`, 0.3866416252927345, 0.9379031436282628], 
             UndirectedEdge[59, 114] -> 
             RGBColor[
              0.1828190891221793, 0.3094848324401137, 0.9337226487176782], 
             UndirectedEdge[31, 185] -> 
             RGBColor[
              0.38200599992585305`, 0.49606971836717273`, 0.9464117075671216],
              UndirectedEdge[58, 198] -> 
             RGBColor[
              0.6531000789032383, 0.7219510755774461, 0.9474306913916395], 
             UndirectedEdge[30, 142] -> 
             RGBColor[
              0.23578204115771023`, 0.3651522530745672, 0.9367388104844356], 
             UndirectedEdge[26, 96] -> 
             RGBColor[
              0.6145993386243387, 0.6885815666825401, 0.9662497087986179], 
             UndirectedEdge[25, 111] -> 
             RGBColor[
              0.19983749274486573`, 0.32737225367666856`, 0.9346918216275183],
              UndirectedEdge[89, 107] -> 
             RGBColor[
              0.24257389966697504`, 0.37229092699650596`, 0.9371255967788841],
              UndirectedEdge[51, 189] -> 
             RGBColor[
              0.18831403886767445`, 0.3152603730225656, 0.9340355779766345], 
             UndirectedEdge[81, 158] -> 
             RGBColor[
              0.3111871249613185, 0.44370525612704076`, 0.9410587411898188], 
             UndirectedEdge[93, 159] -> 
             RGBColor[
              0.24313944261504272`, 0.37288534849241906`, 0.9371578036131307],
              UndirectedEdge[191, 195] -> 
             RGBColor[
              0.6555677203865065, 0.728688801139147, 0.9677847110498968], 
             UndirectedEdge[17, 131] -> 
             RGBColor[
              0.18648216780881113`, 0.31333496039236675`, 0.9339312556298427],
              UndirectedEdge[18, 32] -> 
             RGBColor[
              0.20453729510132862`, 0.33231204393799124`, 0.9349594684189844],
              UndirectedEdge[59, 184] -> 
             RGBColor[
              0.1830159493280225, 0.30969174499811286`, 0.9337338596151724], 
             UndirectedEdge[156, 175] -> 
             RGBColor[
              0.7126688743756485, 0.2983936614071581, 0.42831356501794793`], 
             UndirectedEdge[2, 82] -> 
             RGBColor[
              0.19716931432443496`, 0.3245678289845131, 0.934539872813691], 
             UndirectedEdge[12, 44] -> 
             RGBColor[
              0.9244380104653778, 0.7365581580535521, 0.25797799946440303`], 
             UndirectedEdge[115, 175] -> 
             RGBColor[
              0.4077982725568444, 0.5263530627871394, 0.9475600302171414], 
             UndirectedEdge[30, 131] -> 
             RGBColor[
              0.19553065372363834`, 0.3228454927959929, 0.9344465535166567], 
             UndirectedEdge[53, 65] -> 
             RGBColor[
              0.7940608836370591, 0.7881654857639895, 0.6245197254205552], 
             UndirectedEdge[17, 51] -> 
             RGBColor[
              0.18683289480672916`, 0.31370359670455467`, 0.9339512290135199],
              UndirectedEdge[109, 128] -> 
             RGBColor[
              0.32435782382982603`, 0.44691944921604004`, 0.9421979744658333],
              UndirectedEdge[101, 135] -> 
             RGBColor[
              0.1965653140451214, 0.3239329863951249, 0.9345054758913225], 
             UndirectedEdge[54, 195] -> 
             RGBColor[
              0.7447123095700184, 0.789153733450638, 0.681635360097179], 
             UndirectedEdge[122, 192] -> 
             RGBColor[
              0.3718189687016956, 0.49328632243521403`, 0.9451102958483188], 
             UndirectedEdge[155, 195] -> 
             RGBColor[
              0.5871109616069528, 0.6752098608899229, 0.9609615810995339], 
             UndirectedEdge[42, 87] -> 
             RGBColor[
              0.20973659970745412`, 0.3377768427339811, 0.9352555611246214], 
             UndirectedEdge[31, 153] -> 
             RGBColor[
              0.4071092490619125, 0.522454824847095, 0.9478413004684911], 
             UndirectedEdge[64, 199] -> 
             RGBColor[
              0.8123958459095635, 0.8512144164818124, 0.8460919805023865], 
             UndirectedEdge[107, 188] -> 
             RGBColor[
              0.2654176677513521, 0.39588915594893126`, 0.9384416016358788], 
             UndirectedEdge[27, 189] -> 
             RGBColor[
              0.23047600087590087`, 0.35957526831600095`, 0.9364366393399698],
              UndirectedEdge[14, 176] -> 
             RGBColor[
              0.20667251283261232`, 0.3345562931541938, 0.9350810659100094], 
             UndirectedEdge[123, 146] -> 
             RGBColor[
              0.34826410267529395`, 0.47021417637892043`, 0.9436264907064373],
              UndirectedEdge[30, 130] -> 
             RGBColor[
              0.1969307686942434, 0.3243171024025152, 0.9345262879929481], 
             UndirectedEdge[72, 143] -> 
             RGBColor[
              0.5544319884729032, 0.6356036049331575, 0.9619129375714212], 
             UndirectedEdge[68, 155] -> 
             RGBColor[
              0.817090690205986, 0.812348570970784, 0.6355099976070364], 
             UndirectedEdge[32, 39] -> 
             RGBColor[
              0.2190345544466123, 0.34754958268921615`, 0.9357850658919249], 
             UndirectedEdge[184, 194] -> 
             RGBColor[
              0.19166541671322765`, 0.3187828836278702, 0.9342264339870195], 
             UndirectedEdge[74, 152] -> 
             RGBColor[
              0.2730580915689248, 0.4008937800418094, 0.9389875071669056], 
             UndirectedEdge[71, 147] -> 
             RGBColor[
              0.3066316503071229, 0.4345352413338067, 0.9409597572808632], 
             UndirectedEdge[39, 173] -> 
             RGBColor[
              0.3099077362629189, 0.437607436708477, 0.9411599161992759], 
             UndirectedEdge[139, 171] -> 
             RGBColor[
              0.2967091465842705, 0.42919050387948254`, 0.940208519004903], 
             UndirectedEdge[73, 189] -> 
             RGBColor[
              0.20595537414504966`, 0.3338025349243465, 0.9350402259226642], 
             UndirectedEdge[20, 22] -> 
             RGBColor[
              0.1854064647205249, 0.3122043282430629, 0.9338699959303249], 
             UndirectedEdge[17, 168] -> 
             RGBColor[
              0.2004333110930509, 0.32799849653767643`, 0.9347257526010131], 
             UndirectedEdge[13, 132] -> 
             RGBColor[
              0.26083574153477407`, 0.39148528066721244`, 0.9381655816572811],
              UndirectedEdge[99, 109] -> 
             RGBColor[
              0.38461485844464394`, 0.49643648481667146`, 0.9467764936235569],
              UndirectedEdge[119, 195] -> 
             RGBColor[
              0.7315611984185482, 0.4425529087361424, 0.44626994465755915`], 
             UndirectedEdge[10, 188] -> 
             RGBColor[
              0.26557638653463256`, 0.3960559794535111, 0.9384506404357832], 
             UndirectedEdge[182, 185] -> 
             RGBColor[
              0.28644155976238705`, 0.41543196640215296`, 0.9397324188136974],
              UndirectedEdge[98, 187] -> 
             RGBColor[
              0.1979911315151781, 0.3254316109582035, 0.9345866740869342], 
             UndirectedEdge[10, 167] -> 
             RGBColor[
              0.2086421156058076, 0.33662647054885053`, 0.9351932318741767], 
             UndirectedEdge[113, 187] -> 
             RGBColor[
              0.20396723113485943`, 0.331712870565089, 0.934927004119428], 
             UndirectedEdge[83, 170] -> 
             RGBColor[
              0.7907969761749707, 0.8373558827785927, 0.9795546906537492], 
             UndirectedEdge[39, 41] -> 
             RGBColor[
              0.2713842645263738, 0.40257244714637036`, 0.9387663044365115], 
             UndirectedEdge[138, 145] -> 
             RGBColor[
              0.20603341116594734`, 0.3338845567811428, 0.935044670015559], 
             UndirectedEdge[75, 155] -> 
             RGBColor[
              0.5876661844347633, 0.6756606157940428, 0.9610052902743873], 
             UndirectedEdge[90, 163] -> 
             RGBColor[
              0.2545166466581612, 0.38484351129813643`, 0.9378057185523212], 
             UndirectedEdge[2, 66] -> 
             RGBColor[
              0.1829598466238134, 0.3096327774988722, 0.9337306646491643], 
             UndirectedEdge[88, 200] -> 
             RGBColor[
              0.20358824889509092`, 0.3313145362022305, 0.9349054216415271], 
             UndirectedEdge[67, 170] -> 
             RGBColor[
              0.45554903905121463`, 0.5584299098262512, 0.952076300177731], 
             UndirectedEdge[124, 136] -> 
             RGBColor[
              0.22442474851543817`, 0.35321501841359515`, 0.9360920294700671],
              UndirectedEdge[129, 155] -> 
             RGBColor[
              0.5638305008231241, 0.6563097340528043, 0.959128857947493], 
             UndirectedEdge[149, 167] -> 
             RGBColor[
              0.19241882352516138`, 0.31957476195596346`, 0.9342693393903937],
              UndirectedEdge[172, 173] -> 
             RGBColor[
              0.6185469880325928, 0.49626987926492994`, 0.5786704708045187], 
             UndirectedEdge[143, 160] -> 
             RGBColor[
              0.6494266978782655, 0.7230187336619522, 0.967777881154406], 
             UndirectedEdge[27, 89] -> 
             RGBColor[
              0.2670176485112967, 0.3979828568550783, 0.9385176321142823], 
             UndirectedEdge[172, 191] -> 
             RGBColor[
              0.8397221650752837, 0.6755835027616839, 0.59719713282006], 
             UndirectedEdge[11, 182] -> 
             RGBColor[
              0.27189457932291083`, 0.4001421676284322, 0.9389039897979983], 
             UndirectedEdge[159, 164] -> 
             RGBColor[
              0.22503263737217588`, 0.35385394814440607`, 0.9361266478411673],
              UndirectedEdge[151, 156] -> 
             RGBColor[
              0.8771128434559579, 0.42716749015211075`, 0.3606061102513105], 
             UndirectedEdge[94, 196] -> 
             RGBColor[
              0.21169845343388266`, 0.3398388753891681, 0.9353672857920389], 
             UndirectedEdge[69, 139] -> 
             RGBColor[
              0.2677410752801248, 0.398743224257023, 0.938558830198553], 
             UndirectedEdge[53, 127] -> 
             RGBColor[
              0.7532853090466265, 0.8074724235406385, 0.9760373166313029], 
             UndirectedEdge[171, 196] -> 
             RGBColor[
              0.2703681630861383, 0.4015044601081305, 0.9387084389626774], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.7310843955752011, 0.737038335696917, 0.6195619855898489], 
             UndirectedEdge[74, 162] -> 
             RGBColor[
              0.39867126833608224`, 0.5197307476573095, 0.9466239585805827], 
             UndirectedEdge[34, 153] -> 
             RGBColor[
              0.3561569436366287, 0.48045786172119975`, 0.9440046574916221], 
             UndirectedEdge[98, 109] -> 
             RGBColor[
              0.2049550918267402, 0.33275117478624117`, 0.9349832613244216], 
             UndirectedEdge[77, 183] -> 
             RGBColor[
              0.8570073690583417, 0.35124840474274827`, 0.19870245441911466`],
              UndirectedEdge[2, 78] -> 
             RGBColor[
              0.1826523965739446, 0.3093096280030011, 0.9337131558236558], 
             UndirectedEdge[113, 193] -> 
             RGBColor[
              0.21695734101669506`, 0.34536629967143495`, 0.9356667716600531],
              UndirectedEdge[100, 120] -> 
             RGBColor[
              0.199864476631129, 0.3274006154520085, 0.934693358319922], 
             UndirectedEdge[1, 35] -> 
             RGBColor[
              0.1803467482579951, 0.30688624543639154`, 0.9335818525629636], 
             UndirectedEdge[154, 176] -> 
             RGBColor[
              0.28297932105843965`, 0.41262153691639003`, 0.9395049102298585],
              UndirectedEdge[13, 31] -> 
             RGBColor[
              0.37653388192589077`, 0.49031817539689215`, 0.9461000785422968],
              UndirectedEdge[92, 196] -> 
             RGBColor[
              0.23871657724306206`, 0.3682366365606061, 0.9369059279732393], 
             UndirectedEdge[66, 124] -> 
             RGBColor[
              0.2047917303558609, 0.33257947152263156`, 0.9349739581303267], 
             UndirectedEdge[141, 167] -> 
             RGBColor[
              0.27157484914335084`, 0.3995303123785612, 0.9388958799735516], 
             UndirectedEdge[76, 158] -> 
             RGBColor[
              0.2902964087900912, 0.4217477888831733, 0.9398690458089125], 
             UndirectedEdge[101, 134] -> 
             RGBColor[
              0.22153377048940157`, 0.350176417209637, 0.9359273925483029], 
             UndirectedEdge[139, 141] -> 
             RGBColor[
              0.31474199889707277`, 0.4449017237250964, 0.9413541852919508], 
             UndirectedEdge[88, 93] -> 
             RGBColor[
              0.22397479227765688`, 0.3527420858788138, 0.936066405127976], 
             UndirectedEdge[17, 130] -> 
             RGBColor[
              0.18788228277941618`, 0.31480656999888906`, 0.9340109901061341],
              UndirectedEdge[32, 117] -> 
             RGBColor[
              0.1856648230786062, 0.31247587925827236`, 0.9338847090566107], 
             UndirectedEdge[32, 103] -> 
             RGBColor[
              0.1835438669532831, 0.31024661989417246`, 0.9337639237429469], 
             UndirectedEdge[148, 150] -> 
             RGBColor[
              0.19306951159997304`, 0.3202586763785973, 0.9343063951136474], 
             UndirectedEdge[77, 156] -> 
             RGBColor[
              0.8177852247685861, 0.1377106078723485, 0.16466445736492355`], 
             UndirectedEdge[76, 89] -> 
             RGBColor[
              0.2658816302529869, 0.396788829637877, 0.93845293755506], 
             UndirectedEdge[42, 51] -> 
             RGBColor[
              0.1924833774375055, 0.31964261221079154`, 0.9342730156402028], 
             UndirectedEdge[82, 124] -> 
             RGBColor[
              0.21900119805648247`, 0.34751452300827246`, 0.9357831662948535],
              UndirectedEdge[15, 114] -> 
             RGBColor[
              0.1801710817898224, 0.3067016088404447, 0.9335718486174763], 
             UndirectedEdge[41, 173] -> 
             RGBColor[
              0.32922976019022715`, 0.45791610894315266`, 0.9422602768775632],
              UndirectedEdge[41, 133] -> 
             RGBColor[
              0.2699147403652278, 0.4010278840797926, 0.9386826172095004], 
             UndirectedEdge[27, 147] -> 
             RGBColor[
              0.25802258569367165`, 0.38852847551383163`, 0.9380053765938214],
              UndirectedEdge[19, 88] -> 
             RGBColor[
              0.28388973519432037`, 0.4117897874343075, 0.939622248296642], 
             UndirectedEdge[127, 172] -> 
             RGBColor[
              0.8720640822479042, 0.7012922099091854, 0.6003031260629946], 
             UndirectedEdge[69, 174] -> 
             RGBColor[
              0.21992361240255348`, 0.34848403897044045`, 0.9358356964272725],
              UndirectedEdge[117, 121] -> 
             RGBColor[
              0.2013378942582586, 0.3289492707981949, 0.9347772672740609], 
             UndirectedEdge[69, 196] -> 
             RGBColor[
              0.24140009178199262`, 0.37105718048567105`, 0.9370587501563274],
              UndirectedEdge[92, 195] -> 
             RGBColor[
              0.372739436043382, 0.49002947459904367`, 0.9455472387434574], 
             UndirectedEdge[144, 158] -> 
             RGBColor[
              0.2574165112915451, 0.3871889319062931, 0.9379965842878197], 
             UndirectedEdge[81, 168] -> 
             RGBColor[
              0.2577136388756711, 0.38820375281975344`, 0.9379877825295823], 
             UndirectedEdge[87, 188] -> 
             RGBColor[
              0.264952676857396, 0.39540042103725787`, 0.9384151210923604], 
             UndirectedEdge[74, 88] -> 
             RGBColor[
              0.2812466810785635, 0.40950050680300143`, 0.9394538352255469], 
             UndirectedEdge[74, 140] -> 
             RGBColor[
              0.6698268935487197, 0.7315161778042003, 0.7507274751968138], 
             UndirectedEdge[152, 178] -> 
             RGBColor[
              0.19191650879429833`, 0.319046797325233, 0.9342407333095791], 
             UndirectedEdge[63, 153] -> 
             RGBColor[
              0.23696466171985112`, 0.36639526226785174`, 0.9368061589759192],
              UndirectedEdge[154, 158] -> 
             RGBColor[
              0.3241076056222659, 0.45514745069325846`, 0.9418728279265163], 
             UndirectedEdge[23, 90] -> 
             RGBColor[
              0.22545415356299398`, 0.354296988386626, 0.936150652564657], 
             UndirectedEdge[51, 131] -> 
             RGBColor[
              0.18184583567028742`, 0.3084618813543424, 0.9336672233733925], 
             UndirectedEdge[21, 83] -> 
             RGBColor[
              0.6438448345050425, 0.715751939504987, 0.9685418227069613], 
             UndirectedEdge[57, 178] -> 
             RGBColor[
              0.1827435050835432, 0.30940538882320234`, 0.9337183443184945], 
             UndirectedEdge[17, 197] -> 
             RGBColor[
              0.19608757130368493`, 0.3234308484832359, 0.9344782691489546], 
             UndirectedEdge[64, 156] -> 
             RGBColor[
              0.755655443460662, 0.33329209471324106`, 0.43169762520131116`], 
             UndirectedEdge[40, 123] -> 
             RGBColor[
              0.4784773066745961, 0.5874288969649759, 0.9521030898325651], 
             UndirectedEdge[26, 99] -> 
             RGBColor[
              0.42230145847218425`, 0.5360474909140672, 0.9489226897427967], 
             UndirectedEdge[114, 167] -> 
             RGBColor[
              0.19037448411434205`, 0.3174260316165872, 0.9341529172852767], 
             UndirectedEdge[75, 168] -> 
             RGBColor[
              0.3557698478286644, 0.47206054196027025`, 0.9445929358550735], 
             UndirectedEdge[55, 111] -> 
             RGBColor[
              0.27800719710349053`, 0.40702500884009835`, 0.9392353213324036],
              UndirectedEdge[67, 122] -> 
             RGBColor[
              0.26690693057918574`, 0.3978664852885073, 0.9385113268918411], 
             UndirectedEdge[127, 129] -> 
             RGBColor[
              0.6646291767752983, 0.7354973814495299, 0.9690579811407907], 
             UndirectedEdge[96, 198] -> 
             RGBColor[
              0.6410199693439192, 0.7129417496474699, 0.9678791658783956], 
             UndirectedEdge[154, 181] -> 
             RGBColor[
              0.3850218870849109, 0.5079083396553941, 0.9457542320769319], 
             UndirectedEdge[9, 91] -> 
             RGBColor[
              0.1897739422401799, 0.3167948240302888, 0.9341187173139652], 
             UndirectedEdge[39, 152] -> 
             RGBColor[
              0.22612393827552923`, 0.3550009745863041, 0.9361887958131783], 
             UndirectedEdge[54, 65] -> 
             RGBColor[
              0.9723656669587191, 0.9184450471811106, 0.347146263750879], 
             UndirectedEdge[116, 128] -> 
             RGBColor[
              0.33596717970245343`, 0.45912161831384746`, 0.9428591101082765],
              UndirectedEdge[74, 95] -> 
             RGBColor[
              0.29756419393855826`, 0.4266512474089263, 0.9403830934433266], 
             UndirectedEdge[152, 200] -> 
             RGBColor[
              0.19539965938545223`, 0.3227078094410386, 0.9344390935828858], 
             UndirectedEdge[140, 191] -> 
             RGBColor[
              0.9019134129618684, 0.9202806576422312, 0.7699493982996792], 
             UndirectedEdge[109, 193] -> 
             RGBColor[
              0.223435169075761, 0.3521749076795341, 0.936035674384929], 
             UndirectedEdge[80, 137] -> 
             RGBColor[
              0.2728427891012749, 0.40270506254337235`, 0.9389006402596817], 
             UndirectedEdge[118, 199] -> 
             RGBColor[
              0.6930640728290565, 0.752639828019768, 0.8371662674251406], 
             UndirectedEdge[45, 64] -> 
             RGBColor[
              0.6702869821102313, 0.7421560430065834, 0.9679059544483493], 
             UndirectedEdge[125, 170] -> 
             RGBColor[
              0.4597455397011603, 0.5628406980828529, 0.952315284681579], 
             UndirectedEdge[70, 145] -> 
             RGBColor[
              0.19062187863577218`, 0.31768605894432894`, 0.9341670060372848],
              UndirectedEdge[17, 142] -> 
             RGBColor[
              0.22673355524288302`, 0.35564172067094113`, 0.9362235125976215],
              UndirectedEdge[95, 180] -> 
             RGBColor[
              0.2956153583547517, 0.42496326397755757`, 0.9402589153632142], 
             UndirectedEdge[41, 121] -> 
             RGBColor[
              0.25402964955357293`, 0.38433164646381435`, 0.9377779847876626],
              UndirectedEdge[5, 10] -> 
             RGBColor[
              0.28614225358776674`, 0.41386909982440245`, 0.9397610792987268],
              UndirectedEdge[167, 194] -> 
             RGBColor[
              0.2004278770420817, 0.327992785005569, 0.9347254431398494], 
             UndirectedEdge[78, 100] -> 
             RGBColor[
              0.1943610742796171, 0.3216161906447068, 0.9343799476975574], 
             UndirectedEdge[106, 157] -> 
             RGBColor[
              0.1957274974930852, 0.3230523880782974, 0.9344577634781225], 
             UndirectedEdge[24, 115] -> 
             RGBColor[
              0.28608625432626233`, 0.41744460911573256`, 0.9396248182053492],
              UndirectedEdge[74, 164] -> 
             RGBColor[
              0.2705518531420833, 0.3982595645505048, 0.9388447805961444], 
             UndirectedEdge[46, 135] -> 
             RGBColor[
              0.18995764910618526`, 0.3169879115941485, 0.9341291791482143], 
             UndirectedEdge[126, 190] -> 
             RGBColor[
              0.18192592123823295`, 0.3085460563639715, 0.933671784128011], 
             UndirectedEdge[21, 177] -> 
             RGBColor[
              0.28934680274084895`, 0.4165928965590511, 0.9399671678191333], 
             UndirectedEdge[24, 133] -> 
             RGBColor[
              0.2531352151655193, 0.3833915392115544, 0.93772704807246], 
             UndirectedEdge[30, 188] -> 
             RGBColor[
              0.2613842726407983, 0.39164980195571875`, 0.938211905751206], 
             UndirectedEdge[80, 98] -> 
             RGBColor[
              0.2071471807023911, 0.33505519918101245`, 0.9351080975429851], 
             UndirectedEdge[12, 102] -> 
             RGBColor[
              0.9596388825040008, 0.9082051910857141, 0.6078854818749925], 
             UndirectedEdge[51, 168] -> 
             RGBColor[
              0.1957969789545272, 0.32312541749965207`, 0.934461720344563], 
             UndirectedEdge[42, 189] -> 
             RGBColor[
              0.19860085363697447`, 0.32607246756682684`, 0.9346213968597675],
              UndirectedEdge[52, 187] -> 
             RGBColor[
              0.19453498240935546`, 0.32179897911547406`, 0.934389851508272], 
             UndirectedEdge[10, 89] -> 
             RGBColor[
              0.2427326184502555, 0.3724577505010858, 0.9371346355787884], 
             UndirectedEdge[148, 193] -> 
             RGBColor[
              0.21151914615710812`, 0.33965041207254015`, 0.9353570745078879],
              UndirectedEdge[4, 92] -> 
             RGBColor[
              0.28937728391046563`, 0.41912091134823404`, 0.9398775137264412],
              UndirectedEdge[28, 97] -> 
             RGBColor[
              0.19804503866908396`, 0.3254882707948695, 0.9345897440196007], 
             UndirectedEdge[60, 169] -> 
             RGBColor[
              0.18653686033276015`, 0.3133924457027435, 0.9339343702881713], 
             UndirectedEdge[44, 198] -> 
             RGBColor[
              0.6221986923143263, 0.5535105917539171, 0.5902453016000886], 
             UndirectedEdge[13, 64] -> 
             RGBColor[
              0.4253184848962721, 0.5299237138095665, 0.9499405811920143], 
             UndirectedEdge[42, 106] -> 
             RGBColor[
              0.19390013127031533`, 0.3211317103164559, 0.9343536976750818], 
             UndirectedEdge[43, 90] -> 
             RGBColor[
              0.20850897767362986`, 0.33648653414069934`, 0.935185649865899], 
             UndirectedEdge[166, 192] -> 
             RGBColor[
              0.6347217686990404, 0.711862763594694, 0.9660768808598341], 
             UndirectedEdge[5, 89] -> 
             RGBColor[
              0.31092444547544634`, 0.4399167547800723, 0.9411723884647626], 
             UndirectedEdge[114, 184] -> 
             RGBColor[
              0.18161202378548802`, 0.3082161302388885, 0.9336539081324469], 
             UndirectedEdge[58, 192] -> 
             RGBColor[
              0.7131454310850844, 0.7736227561744136, 0.951349727711992], 
             UndirectedEdge[17, 157] -> 
             RGBColor[
              0.19894707579879906`, 0.3264363690106574, 0.9346411136996936], 
             UndirectedEdge[38, 111] -> 
             RGBColor[
              0.200630301320241, 0.32820554575635497`, 0.9347369709030307], 
             UndirectedEdge[3, 191] -> 
             RGBColor[
              0.6143982789320568, 0.6943254432107253, 0.9648034682477634], 
             UndirectedEdge[40, 195] -> 
             RGBColor[
              0.5034310381865006, 0.6077470219664445, 0.9540510819361487], 
             UndirectedEdge[113, 136] -> 
             RGBColor[
              0.21363278825802834`, 0.3418719839332567, 0.9354774432986821], 
             UndirectedEdge[53, 141] -> 
             RGBColor[
              0.4877995456867602, 0.5920834332461721, 0.9536420283584146], 
             UndirectedEdge[142, 176] -> 
             RGBColor[
              0.24804284091250217`, 0.37803913099645736`, 0.9374370448922433],
              UndirectedEdge[99, 128] -> 
             RGBColor[
              0.49156366276898256`, 0.5975148916314856, 0.9532819740075988], 
             UndirectedEdge[41, 151] -> 
             RGBColor[
              0.6423047351050197, 0.7073139713016436, 0.8452851258395946], 
             UndirectedEdge[5, 157] -> 
             RGBColor[
              0.28037950263265143`, 0.40781208319106244`, 0.939432899157059], 
             UndirectedEdge[39, 74] -> 
             RGBColor[
              0.29899639389246113`, 0.42815658036720006`, 0.9404646551119514],
              UndirectedEdge[86, 171] -> 
             RGBColor[
              0.25492345163412733`, 0.3852710891208021, 0.9378288854938884], 
             UndirectedEdge[162, 180] -> 
             RGBColor[
              0.3967224327522758, 0.5180427642259409, 0.9464997805004701], 
             UndirectedEdge[27, 127] -> 
             RGBColor[
              0.5706539535210267, 0.6502280340235855, 0.9632042593205097], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.2536345517124762, 0.3839163735821717, 0.937755484550107], 
             UndirectedEdge[155, 191] -> 
             RGBColor[
              0.7416468272326004, 0.7980994052495431, 0.9748840827210469], 
             UndirectedEdge[46, 105] -> 
             RGBColor[
              0.19436779950481975`, 0.32162325928279867`, 0.9343803306891837],
              UndirectedEdge[30, 168] -> 
             RGBColor[
              0.2094817970078781, 0.3375090289413025, 0.9352410504878272], 
             UndirectedEdge[161, 180] -> 
             RGBColor[
              0.31293043325479175`, 0.4431625055366565, 0.9412449832634135], 
             UndirectedEdge[125, 192] -> 
             RGBColor[
              0.364998647890857, 0.48611773282970705`, 0.9447218886679021], 
             UndirectedEdge[33, 140] -> 
             RGBColor[
              0.9931733912441731, 0.9901003146609737, 0.6650510516491244], 
             UndirectedEdge[12, 58] -> 
             RGBColor[
              0.9553393970542898, 0.9049986418770809, 0.615163389255954], 
             UndirectedEdge[127, 155] -> 
             RGBColor[
              0.7739887444052208, 0.8238081123970447, 0.9779900759639816], 
             UndirectedEdge[78, 120] -> 
             RGBColor[
              0.188434679061321, 0.31538717351511814`, 0.9340424482571915], 
             UndirectedEdge[45, 183] -> 
             RGBColor[
              0.823713544812509, 0.7798413316678898, 0.6197525703698252], 
             UndirectedEdge[98, 136] -> 
             RGBColor[
              0.20765668863834705`, 0.33559072432637116`, 0.9351371132661883],
              UndirectedEdge[59, 92] -> 
             RGBColor[
              0.21433501599530952`, 0.3426100698089493, 0.9355174341294674], 
             UndirectedEdge[81, 89] -> 
             RGBColor[
              0.2867723464242142, 0.41874629688174436`, 0.9396426329359664], 
             UndirectedEdge[161, 200] -> 
             RGBColor[
              0.23722083665512567`, 0.36666451836725433`, 0.9368207477595063],
              UndirectedEdge[125, 198] -> 
             RGBColor[
              0.30495329570901086`, 0.43444605223273947`, 0.9408028523475496],
              UndirectedEdge[159, 173] -> 
             RGBColor[
              0.3113226737864071, 0.4390946257578836, 0.941240494798026], 
             UndirectedEdge[54, 151] -> 
             RGBColor[
              0.9911479730677677, 0.9821275166719952, 0.580056048665182], 
             UndirectedEdge[61, 192] -> 
             RGBColor[
              0.33652735532483224`, 0.4561925991586039, 0.9431004906757697], 
             UndirectedEdge[59, 194] -> 
             RGBColor[
              0.19287248204991897`, 0.32005158582909543`, 0.934295174572251], 
             UndirectedEdge[80, 82] -> 
             RGBColor[
              0.2168791547337895, 0.3452841209308045, 0.9356623190669078], 
             UndirectedEdge[157, 168] -> 
             RGBColor[
              0.2079111599465971, 0.33585818980575477`, 0.9351516050307367], 
             UndirectedEdge[122, 170] -> 
             RGBColor[
              0.4665658605119989, 0.5700092876883599, 0.9527036918619959], 
             UndirectedEdge[26, 67] -> 
             RGBColor[
              0.2743361643394848, 0.4056750810112081, 0.9389344107639237], 
             UndirectedEdge[160, 181] -> 
             RGBColor[
              0.4406818300512263, 0.5561181847027405, 0.9493008344245906], 
             UndirectedEdge[42, 168] -> 
             RGBColor[
              0.20608379372382724`, 0.3339375120439133, 0.935047539227696], 
             UndirectedEdge[61, 67] -> 
             RGBColor[
              0.2316153172023224, 0.36077276201189723`, 0.936501521719292], 
             UndirectedEdge[9, 39] -> 
             RGBColor[
              0.22268787528916928`, 0.3513894545286635, 0.9359931171093048], 
             UndirectedEdge[118, 171] -> 
             RGBColor[
              0.3493088123107567, 0.4768833997475762, 0.9434819976486537], 
             UndirectedEdge[97, 134] -> 
             RGBColor[
              0.23183626588337625`, 0.3610049930846403, 0.9365141044198138], 
             UndirectedEdge[79, 190] -> 
             RGBColor[
              0.18918203979750087`, 0.31617269703425077`, 0.9340850093454959],
              UndirectedEdge[47, 50] -> 
             RGBColor[
              0.2000038325739316, 0.3275470873835711, 0.9347012944347058], 
             UndirectedEdge[36, 145] -> 
             RGBColor[
              0.1863723647153286, 0.3132195503791984, 0.9339250025061079], 
             UndirectedEdge[170, 179] -> 
             RGBColor[
              0.5118741210410194, 0.6121027531180253, 0.9554863516778458], 
             UndirectedEdge[26, 198] -> 
             RGBColor[
              0.3192028502801486, 0.44942323756094715`, 0.9416143434000489], 
             UndirectedEdge[5, 141] -> 
             RGBColor[
              0.34907498712530993`, 0.4767729416541131, 0.9434637273981017], 
             UndirectedEdge[18, 39] -> 
             RGBColor[
              0.2375649812537819, 0.3670262361604698, 0.9368403462852835], 
             UndirectedEdge[19, 180] -> 
             RGBColor[
              0.3466247657178071, 0.47465068302264285`, 0.9433076014566613], 
             UndirectedEdge[170, 198] -> 
             RGBColor[
              0.5004157249918784, 0.6021780663759904, 0.9547562328138562], 
             UndirectedEdge[12, 172] -> 
             RGBColor[
              0.9097214307201227, 0.6697336065748736, 0.2456981245885829], 
             UndirectedEdge[47, 101] -> 
             RGBColor[
              0.19622767860092072`, 0.3235781101359464, 0.934486248052262], 
             UndirectedEdge[53, 54] -> 
             RGBColor[
              0.810087981057518, 0.842228648704628, 0.6867819724356502], 
             UndirectedEdge[57, 121] -> 
             RGBColor[
              0.1995963195919732, 0.32711876540171747`, 0.9346780871732447], 
             UndirectedEdge[19, 121] -> 
             RGBColor[
              0.28428483303541713`, 0.41220506031595017`, 0.9396447485341975],
              UndirectedEdge[170, 192] -> 
             RGBColor[
              0.5604610771737245, 0.6538497469729578, 0.9586752691342088], 
             UndirectedEdge[7, 137] -> 
             RGBColor[
              0.266193356547354, 0.39571608733082725`, 0.9385219649126898], 
             UndirectedEdge[111, 115] -> 
             RGBColor[
              0.26758071568904057`, 0.3979941146890951, 0.9385709551564505], 
             UndirectedEdge[140, 162] -> 
             RGBColor[
              0.7225676146989453, 0.7771975396388044, 0.7540880673117176], 
             UndirectedEdge[8, 79] -> 
             RGBColor[
              0.2387210212797669, 0.3682413075249512, 0.9369061810545554], 
             UndirectedEdge[2, 52] -> 
             RGBColor[
              0.1839811911872139, 0.31070627539199164`, 0.933788828711106], 
             UndirectedEdge[18, 152] -> 
             RGBColor[
              0.21162667893024556`, 0.3397634358350792, 0.9353631983402376], 
             UndirectedEdge[4, 195] -> 
             RGBColor[
              0.41766970262794245`, 0.5348906935287172, 0.9481924844113676], 
             UndirectedEdge[81, 107] -> 
             RGBColor[
              0.26183143575325407`, 0.39253181842149465`, 0.938222284970026], 
             UndirectedEdge[108, 175] -> 
             RGBColor[
              0.4042989919639763, 0.5232556584871441, 0.9473394941647204], 
             UndirectedEdge[49, 191] -> 
             RGBColor[
              0.6162290328937537, 0.6959111502759776, 0.9649201222713306], 
             UndirectedEdge[77, 192] -> 
             RGBColor[
              0.7001173951211405, 0.28179359390660397`, 0.42650595770684385`],
              UndirectedEdge[21, 166] -> 
             RGBColor[
              0.5825165188394155, 0.666981785574234, 0.9626574089267232], 
             UndirectedEdge[8, 192] -> 
             RGBColor[
              0.37448920004002384`, 0.4960929048742423, 0.9452623615727833], 
             UndirectedEdge[108, 165] -> 
             RGBColor[
              0.25691494582414054`, 0.38736427578253046`, 0.937942298141858], 
             UndirectedEdge[29, 194] -> 
             RGBColor[
              0.2042163465061234, 0.3319747066151143, 0.9349411908712882], 
             UndirectedEdge[106, 131] -> 
             RGBColor[
              0.18326258950309726`, 0.3099509794600067, 0.9337479054082716], 
             UndirectedEdge[12, 68] -> 
             RGBColor[
              0.9555467146303788, 0.8599776150331977, 0.2908341193259223], 
             UndirectedEdge[71, 168] -> 
             RGBColor[
              0.2865680055762049, 0.4134470786130624, 0.93981716239494], 
             UndirectedEdge[49, 146] -> 
             RGBColor[
              0.3338791466944457, 0.45775465051721964`, 0.9427098940314549], 
             UndirectedEdge[112, 134] -> 
             RGBColor[
              0.5941420485372255, 0.6663173396662936, 0.9607153178159171], 
             UndirectedEdge[84, 126] -> 
             RGBColor[
              0.1804502852518648, 0.30699506938157317`, 0.9335877488415951], 
             UndirectedEdge[10, 62] -> 
             RGBColor[
              0.2089259147709481, 0.3369247614653196, 0.9352093938167881], 
             UndirectedEdge[34, 182] -> 
             RGBColor[
              0.3854450302409573, 0.5082748449893679, 0.9457811943846643], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.20133152966492007`, 0.3289425812070576, 0.9347769048198857], 
             UndirectedEdge[67, 79] -> 
             RGBColor[
              0.22503396848065443`, 0.3538553472238142, 0.9361267236458259], 
             UndirectedEdge[33, 96] -> 
             RGBColor[
              0.9645200001324366, 0.9716588691526575, 0.8822125253236324], 
             UndirectedEdge[12, 140] -> 
             RGBColor[
              0.9719126786067074, 0.9144307614554209, 0.4184503900682022], 
             UndirectedEdge[26, 124] -> 
             RGBColor[
              0.25940975173137165`, 0.3899864749708609, 0.9380843736475403], 
             UndirectedEdge[13, 70] -> 
             RGBColor[
              0.20607827017508945`, 0.33393170644397663`, 0.9350472246697668],
              UndirectedEdge[53, 146] -> 
             RGBColor[
              0.438593505674698, 0.543607216634379, 0.9507210951484925], 
             UndirectedEdge[87, 147] -> 
             RGBColor[
              0.23311384595539386`, 0.3623478107435859, 0.9365868607149048], 
             UndirectedEdge[93, 200] -> 
             RGBColor[
              0.21100022620147757`, 0.339104994297747, 0.935327522784088], 
             UndirectedEdge[9, 117] -> 
             RGBColor[
              0.1893181439211632, 0.3163157510977197, 0.9340927602739904], 
             UndirectedEdge[99, 116] -> 
             RGBColor[
              0.39622421431727134`, 0.5086386539144789, 0.9474376292660001], 
             UndirectedEdge[71, 155] -> 
             RGBColor[
              0.5184643421823038, 0.6170471524468351, 0.9562295168142538], 
             UndirectedEdge[54, 140] -> 
             RGBColor[
              0.9910580021453803, 0.9807455899537222, 0.48380004734696136`], 
             UndirectedEdge[76, 154] -> 
             RGBColor[
              0.29805964700021337`, 0.42847191562908343`, 0.9403637124828994],
              UndirectedEdge[33, 128] -> 
             RGBColor[
              0.7119650853654641, 0.7696077577835532, 0.8603069871100877], 
             UndirectedEdge[109, 148] -> 
             RGBColor[
              0.20549299658683456`, 0.33331654679423195`, 0.9350138942047502],
              UndirectedEdge[27, 142] -> 
             RGBColor[
              0.2642591851125857, 0.3950835369263521, 0.9383605417045067], 
             UndirectedEdge[49, 69] -> 
             RGBColor[
              0.33608426308955985`, 0.46007236766093923`, 0.9428354721479792],
              UndirectedEdge[60, 90] -> 
             RGBColor[
              0.2041256683004301, 0.33187939807160033`, 0.9349360268816205], 
             UndirectedEdge[40, 191] -> 
             RGBColor[
              0.6579669038121483, 0.7306365663260646, 0.9679735835576617], 
             UndirectedEdge[58, 166] -> 
             RGBColor[
              0.8821530144207035, 0.9083587380492957, 0.9663447354512944], 
             UndirectedEdge[38, 60] -> 
             RGBColor[
              0.18105257981885614`, 0.3076281191591622, 0.9336220486261704], 
             UndirectedEdge[54, 119] -> 
             RGBColor[
              0.894014834957988, 0.5647892265168832, 0.26478537843675587`], 
             UndirectedEdge[3, 146] -> 
             RGBColor[
              0.33204839273274867`, 0.4561689434519673, 0.9425932400078877], 
             UndirectedEdge[115, 163] -> 
             RGBColor[
              0.2983939725453868, 0.4303808013184385, 0.9403257245502908], 
             UndirectedEdge[137, 170] -> 
             RGBColor[
              0.48955017496489417`, 0.59276687306104, 0.9540638895741654], 
             UndirectedEdge[58, 99] -> 
             RGBColor[
              0.7561986870952739, 0.8085753289305662, 0.9547390377343874], 
             UndirectedEdge[40, 64] -> 
             RGBColor[
              0.5676806016913061, 0.6599077120294969, 0.959109042929153], 
             UndirectedEdge[77, 96] -> 
             RGBColor[
              0.8570181525627032, 0.40678469292302094`, 0.44031684375898816`],
              UndirectedEdge[141, 195] -> 
             RGBColor[
              0.42242387419926064`, 0.539008517992182, 0.9484954160199432], 
             UndirectedEdge[138, 182] -> 
             RGBColor[
              0.28135325644561493`, 0.4100838369991616, 0.9394426474672775], 
             UndirectedEdge[33, 102] -> 
             RGBColor[
              0.9808995951414665, 0.9838747442912669, 0.8544861434559147], 
             UndirectedEdge[137, 198] -> 
             RGBColor[
              0.3347579309727448, 0.4643722272109265, 0.9425514572401359], 
             UndirectedEdge[69, 171] -> 
             RGBColor[
              0.27878211770791206`, 0.41034805989114986`, 0.939187601231057], 
             UndirectedEdge[20, 46] -> 
             RGBColor[
              0.182651270158183, 0.3093084440686167, 0.9337130916759446], 
             UndirectedEdge[76, 157] -> 
             RGBColor[
              0.23533668741019195`, 0.36468415804886706`, 0.9367134482473564],
              UndirectedEdge[10, 168] -> 
             RGBColor[
              0.21367391090171242`, 0.3419152064390949, 0.9354797851724044], 
             UndirectedEdge[82, 100] -> 
             RGBColor[
              0.20887799203010743`, 0.3368743916262188, 0.9352066646875926], 
             UndirectedEdge[9, 57] -> 
             RGBColor[
              0.18757656925487778`, 0.3144852457012422, 0.9339935801731742], 
             UndirectedEdge[27, 71] -> 
             RGBColor[
              0.3151295512981096, 0.44346707407337604`, 0.941443700170782], 
             UndirectedEdge[122, 125] -> 
             RGBColor[
              0.2711034312291314, 0.40227727354510906`, 0.9387503113956892], 
             UndirectedEdge[5, 147] -> 
             RGBColor[
              0.30192938265782127`, 0.43046237343882565`, 0.9406601329443018],
              UndirectedEdge[5, 71] -> 
             RGBColor[
              0.35903634826225916`, 0.48540097199837007`, 0.9440984565212622],
              UndirectedEdge[61, 84] -> 
             RGBColor[
              0.19428775253280067`, 0.3215391248399355, 0.9343757721325461], 
             UndirectedEdge[62, 149] -> 
             RGBColor[
              0.19270262269030192`, 0.3198730528724325, 0.9342855013330051], 
             UndirectedEdge[36, 138] -> 
             RGBColor[
              0.20221257093783607`, 0.32986861144613544`, 0.9348270788169946],
              UndirectedEdge[33, 162] -> 
             RGBColor[
              0.7220177660315357, 0.778314884514083, 0.8609475350328932], 
             UndirectedEdge[63, 145] -> 
             RGBColor[
              0.1909329030445121, 0.31801296531800116`, 0.9341847184172432], 
             UndirectedEdge[93, 173] -> 
             RGBColor[
              0.29957000075540785`, 0.42674182123979476`, 0.9405711974554323],
              UndirectedEdge[23, 55] -> 
             RGBColor[
              0.27975796086466953`, 0.40886517255793126`, 0.9393350247385799],
              UndirectedEdge[23, 165] -> 
             RGBColor[
              0.21472043526896856`, 0.3430151699025583, 0.9355393831869255], 
             UndirectedEdge[54, 64] -> 
             RGBColor[
              0.8089618730748239, 0.8413144235136905, 0.6866933210901831], 
             UndirectedEdge[72, 158] -> 
             RGBColor[
              0.284772839183219, 0.41594216701181014`, 0.93955448669119], 
             UndirectedEdge[73, 149] -> 
             RGBColor[
              0.2014915378121197, 0.32911075991486693`, 0.934786017047158], 
             UndirectedEdge[10, 197] -> 
             RGBColor[
              0.20932817111234645`, 0.33734755838465436`, 0.9352323017203459],
              UndirectedEdge[37, 135] -> 
             RGBColor[
              0.21639131765151565`, 0.3447713732266772, 0.9356345374667627], 
             UndirectedEdge[58, 96] -> 
             RGBColor[
              0.9484965672474285, 0.961109404699039, 0.9720660567902085], 
             UndirectedEdge[112, 156] -> 
             RGBColor[
              0.8596154243912574, 0.41519353040673457`, 0.43839164860472024`],
              UndirectedEdge[2, 187] -> 
             RGBColor[
              0.1929273076602217, 0.3201092110216681, 0.9342982968096505], 
             UndirectedEdge[43, 169] -> 
             RGBColor[
              0.19092016970595993`, 0.3179995817718425, 0.9341839932724498], 
             UndirectedEdge[44, 96] -> 
             RGBColor[
              0.9175951806585165, 0.7926689208755102, 0.6148806669986575], 
             UndirectedEdge[88, 161] -> 
             RGBColor[
              0.25019540273130497`, 0.38030160994832113`, 0.9375596301033943],
              UndirectedEdge[129, 146] -> 
             RGBColor[
              0.3499373734033699, 0.4716321745432704, 0.9437417596579802], 
             UndirectedEdge[23, 111] -> 
             RGBColor[
              0.2218869245410005, 0.3505476045091276, 0.935947504149097], 
             UndirectedEdge[174, 196] -> 
             RGBColor[
              0.21150965778077974`, 0.33964043918742115`, 0.9353565341588927],
              UndirectedEdge[66, 100] -> 
             RGBColor[
              0.1946685243294859, 0.3219393401405779, 0.9343974565230659], 
             UndirectedEdge[10, 73] -> 
             RGBColor[
              0.2177148298927659, 0.346162468507754, 0.9357099095309409], 
             UndirectedEdge[147, 188] -> 
             RGBColor[
              0.2813635156046871, 0.41264925306793426`, 0.9393496940813583], 
             UndirectedEdge[62, 189] -> 
             RGBColor[
              0.19716645902323188`, 0.3245648278819121, 0.9345397102085116], 
             UndirectedEdge[42, 89] -> 
             RGBColor[
              0.2351425012723703, 0.3644800561059042, 0.93670238963408], 
             UndirectedEdge[119, 140] -> 
             RGBColor[
              0.8957916601354561, 0.5702808130715319, 0.3143797361574141], 
             UndirectedEdge[140, 151] -> 
             RGBColor[
              0.9938132108339699, 0.9903648965039682, 0.6544475852461695], 
             UndirectedEdge[1, 86] -> 
             RGBColor[
              0.19100632204633058`, 0.3180901333439459, 0.934188899520783], 
             UndirectedEdge[76, 181] -> 
             RGBColor[
              0.3512106902527362, 0.4745086778453089, 0.9437504499593281], 
             UndirectedEdge[122, 166] -> 
             RGBColor[
              0.5408265520373148, 0.6280223043100961, 0.9601053035876213], 
             UndirectedEdge[10, 189] -> 
             RGBColor[
              0.20619097081485965`, 0.33405016196200843`, 0.935053642804476], 
             UndirectedEdge[102, 162] -> 
             RGBColor[
              0.7102938185962386, 0.7709719692690975, 0.9435231591185078], 
             UndirectedEdge[156, 183] -> 
             RGBColor[
              0.8579398185955138, 0.3584156204874453, 0.19959536914896175`], 
             UndirectedEdge[31, 199] -> 
             RGBColor[
              0.763611242939182, 0.811608878069138, 0.8422514778526693], 
             UndirectedEdge[73, 130] -> 
             RGBColor[
              0.20088728591826768`, 0.3284756528626456, 0.9347516057957137], 
             UndirectedEdge[4, 199] -> 
             RGBColor[
              0.6647841302718416, 0.7281451631679503, 0.8353642944923663], 
             UndirectedEdge[6, 83] -> 
             RGBColor[
              0.8630840140535884, 0.476455427614182, 0.44943597904686494`], 
             UndirectedEdge[73, 89] -> 
             RGBColor[
              0.2424970217804455, 0.37221012346342386`, 0.9371212186969768], 
             UndirectedEdge[60, 111] -> 
             RGBColor[
              0.20055843927843664`, 0.3281300141941019, 0.9347328784660603], 
             UndirectedEdge[166, 179] -> 
             RGBColor[
              0.5861348125663353, 0.6701157697397615, 0.962887963403471], 
             UndirectedEdge[30, 197] -> 
             RGBColor[
              0.20513605721851214`, 0.33294138088686204`, 0.9349935670357687],
              UndirectedEdge[26, 58] -> 
             RGBColor[
              0.6266794481836577, 0.6975908926125163, 0.9458012343118618], 
             UndirectedEdge[11, 35] -> 
             RGBColor[
              0.19186691491128627`, 0.3189946710097535, 0.9342379090113091], 
             UndirectedEdge[137, 187] -> 
             RGBColor[
              0.2636867399140619, 0.3930814743205634, 0.9383792168036308], 
             UndirectedEdge[13, 153] -> 
             RGBColor[
              0.2516813551580962, 0.3818634401637041, 0.9376442528958304], 
             UndirectedEdge[71, 75] -> 
             RGBColor[
              0.4329404581640204, 0.5480873032405589, 0.9491738543179573], 
             UndirectedEdge[16, 67] -> 
             RGBColor[
              0.22153288342254734`, 0.3501754848461299, 0.935927342031158], 
             UndirectedEdge[156, 170] -> 
             RGBColor[
              0.7642144391985147, 0.3401094531533983, 0.43246113644580897`], 
             UndirectedEdge[96, 128] -> 
             RGBColor[
              0.683861542921137, 0.7500489673999585, 0.97060899306342], 
             UndirectedEdge[62, 114] -> 
             RGBColor[
              0.19065828327948256`, 0.31772432253305627`, 0.9341690792278882],
              UndirectedEdge[101, 105] -> 
             RGBColor[
              0.20097546444375586`, 0.32856833408377506`, 0.9347566274322918],
              UndirectedEdge[30, 89] -> 
             RGBColor[
              0.2385405045564212, 0.3680515730032935, 0.9368959008942113], 
             UndirectedEdge[53, 191] -> 
             RGBColor[
              0.720943391874006, 0.781763716393137, 0.9729313233883682], 
             UndirectedEdge[72, 81] -> 
             RGBColor[
              0.2796155967323937, 0.4112240991915025, 0.9392350666284796], 
             UndirectedEdge[163, 175] -> 
             RGBColor[
              0.39116697450397153`, 0.5094530755186824, 0.9465916451974521], 
             UndirectedEdge[82, 125] -> 
             RGBColor[
              0.23812411131454123`, 0.3676139173052213, 0.9368721879150849], 
             UndirectedEdge[113, 148] -> 
             RGBColor[
              0.19901516852776863`, 0.3265079387861328, 0.9346449914798742], 
             UndirectedEdge[33, 44] -> 
             RGBColor[
              0.9456987231028435, 0.812227711259105, 0.5045786610453252], 
             UndirectedEdge[21, 179] -> 
             RGBColor[
              0.3649219793710912, 0.49049880984441946`, 0.9444734837310578], 
             UndirectedEdge[75, 188] -> 
             RGBColor[
              0.40767232346158455`, 0.5262013149746865, 0.9475637911184522], 
             UndirectedEdge[85, 88] -> 
             RGBColor[
              0.24351738394062986`, 0.3732825887884752, 0.9371793268125088], 
             UndirectedEdge[13, 185] -> 
             RGBColor[
              0.22657810602203676`, 0.3554783336837818, 0.936214659994461], 
             UndirectedEdge[93, 161] -> 
             RGBColor[
              0.2576073800376916, 0.38809206804383756`, 0.9379817312459552], 
             UndirectedEdge[146, 196] -> 
             RGBColor[
              0.23919497538687848`, 0.3687394633419514, 0.9369331720398031], 
             UndirectedEdge[19, 162] -> 
             RGBColor[
              0.4013143224518391, 0.5220200282886156, 0.9467923716516777], 
             UndirectedEdge[140, 172] -> 
             RGBColor[
              0.931531992024998, 0.7442858149051479, 0.38543931844832946`], 
             UndirectedEdge[71, 142] -> 
             RGBColor[
              0.312868249726037, 0.44109030274632716`, 0.9413149223915483], 
             UndirectedEdge[87, 142] -> 
             RGBColor[
              0.23935044537430794`, 0.3689028721561064, 0.9369420258255899], 
             UndirectedEdge[89, 147] -> 
             RGBColor[
              0.25851974752031004`, 0.38905102411550896`, 0.9380336892243635],
              UndirectedEdge[30, 42] -> 
             RGBColor[
              0.2061681954908564, 0.33402622365244206`, 0.935052345783467], 
             UndirectedEdge[8, 125] -> 
             RGBColor[
              0.2737736625674596, 0.4050838559841373, 0.9389023771201537], 
             UndirectedEdge[29, 168] -> 
             RGBColor[
              0.2081540694089858, 0.33611350305207477`, 0.9351654383652672], 
             UndirectedEdge[158, 160] -> 
             RGBColor[
              0.3797675485885813, 0.503357295740605, 0.945419430274175], 
             UndirectedEdge[138, 153] -> 
             RGBColor[
              0.25206516984128635`, 0.38226685373099345`, 0.9376661105742352],
              UndirectedEdge[26, 122] -> 
             RGBColor[
              0.285352985800269, 0.4172544588733168, 0.9395618024481885], 
             UndirectedEdge[53, 195] -> 
             RGBColor[
              0.5664075262483584, 0.658874172033517, 0.9590088217668552], 
             UndirectedEdge[19, 93] -> 
             RGBColor[
              0.291301712500707, 0.4195802455298239, 0.9400443494392029], 
             UndirectedEdge[11, 196] -> 
             RGBColor[
              0.21797120015163274`, 0.34643192990463634`, 0.9357245094379176],
              UndirectedEdge[87, 168] -> 
             RGBColor[
              0.21305020122447582`, 0.34125964802284164`, 0.9354442658289815],
              UndirectedEdge[78, 124] -> 
             RGBColor[
              0.20448428030599214`, 0.3322563220267605, 0.9349564493048182], 
             UndirectedEdge[39, 117] -> 
             RGBColor[
              0.21869250923105948`, 0.34719007148075093`, 0.9357655869229098],
              UndirectedEdge[42, 130] -> 
             RGBColor[
              0.1935327654101925, 0.32074558550512594`, 0.9343327767328169], 
             UndirectedEdge[11, 94] -> 
             RGBColor[
              0.19668351642529655`, 0.32405722459115277`, 0.9345122073420087],
              UndirectedEdge[27, 168] -> 
             RGBColor[
              0.23795894096275363`, 0.36744031279308736`, 0.9368627817078983],
              UndirectedEdge[30, 51] -> 
             RGBColor[
              0.19588138072155636`, 0.3232141291081808, 0.934466526900334], 
             UndirectedEdge[6, 58] -> 
             RGBColor[
              0.8744809118671997, 0.48511532004682656`, 0.4356949344281448], 
             UndirectedEdge[6, 156] -> 
             RGBColor[
              0.8271945777002032, 0.21003501770950336`, 0.17367486435858423`],
              UndirectedEdge[19, 173] -> 
             RGBColor[
              0.35948494367207134`, 0.4857895227952885, 0.9441270406240982], 
             UndirectedEdge[57, 200] -> 
             RGBColor[
              0.1862266556746971, 0.31306640093900795`, 0.9339167045918012], 
             UndirectedEdge[37, 50] -> 
             RGBColor[
              0.21979652604601302`, 0.3483504631519761, 0.935828459047275], 
             UndirectedEdge[49, 171] -> 
             RGBColor[
              0.36505233439370555`, 0.4905196472833987, 0.9444851609543292], 
             UndirectedEdge[5, 127] -> 
             RGBColor[
              0.6145607504851762, 0.6921619319485797, 0.9658590156709901], 
             UndirectedEdge[85, 152] -> 
             RGBColor[
              0.2353287944309912, 0.36467586202728325`, 0.9367129987538674], 
             UndirectedEdge[130, 131] -> 
             RGBColor[
              0.18289522364297445`, 0.3095648546486768, 0.9337269844660065], 
             UndirectedEdge[33, 58] -> 
             RGBColor[
              0.9766001096917556, 0.9806681950826337, 0.8617640508368762], 
             UndirectedEdge[82, 98] -> 
             RGBColor[
              0.20223313817939134`, 0.32989022892104847`, 0.9348282500909746],
              UndirectedEdge[74, 173] -> 
             RGBColor[
              0.35684188955631446`, 0.48350024216398235`, 0.9439586275530032],
              UndirectedEdge[118, 146] -> 
             RGBColor[
              0.3181356246114969, 0.44411840298139715`, 0.9417067307257794], 
             UndirectedEdge[23, 115] -> 
             RGBColor[
              0.26933147945021957`, 0.39983427840692803`, 0.9386706585626268],
              UndirectedEdge[49, 65] -> 
             RGBColor[
              0.6893465246568067, 0.7023129196468301, 0.6165085243035178], 
             UndirectedEdge[21, 23] -> 
             RGBColor[
              0.2924706869731754, 0.4198762969529263, 0.9401450684047916], 
             UndirectedEdge[40, 171] -> 
             RGBColor[
              0.40679020531210003`, 0.5252450633334856, 0.9475386222406603], 
             UndirectedEdge[104, 158] -> 
             RGBColor[
              0.3417223041341413, 0.47040441720375525`, 0.9429952209396267], 
             UndirectedEdge[53, 155] -> 
             RGBColor[
              0.6524866330944523, 0.728284776143913, 0.9661081934380052], 
             UndirectedEdge[164, 200] -> 
             RGBColor[
              0.19289342095861073`, 0.320073593949734, 0.9342963670121247], 
             UndirectedEdge[81, 142] -> 
             RGBColor[
              0.28401388302550323`, 0.4158469769530182, 0.9394855425261907], 
             UndirectedEdge[39, 85] -> 
             RGBColor[
              0.26126709675452753`, 0.3919386623526739, 0.9381901466989133], 
             UndirectedEdge[107, 142] -> 
             RGBColor[
              0.23981543626826407`, 0.36939160706777974`, 0.9369685063691083],
              UndirectedEdge[121, 161] -> 
             RGBColor[
              0.25059050057240173`, 0.38071688282996385`, 0.9375821303409498],
              UndirectedEdge[1, 196] -> 
             RGBColor[
              0.20645103349834157`, 0.33432350433127433`, 0.935068452989572], 
             UndirectedEdge[88, 121] -> 
             RGBColor[
              0.21695791281236698`, 0.34536690066494, 0.9356668042229707], 
             UndirectedEdge[85, 133] -> 
             RGBColor[
              0.25979757259338154`, 0.39039409928609614`, 0.9381064594719022],
              UndirectedEdge[118, 127] -> 
             RGBColor[
              0.6328274279834254, 0.7079836098876566, 0.9670229522085898], 
             UndirectedEdge[100, 187] -> 
             RGBColor[
              0.2046359853658942, 0.3324157736633738, 0.9349650886835521], 
             UndirectedEdge[26, 116] -> 
             RGBColor[
              0.2667049754056552, 0.39765421759642916`, 0.9384998258434745], 
             UndirectedEdge[131, 147] -> 
             RGBColor[
              0.21550989668752718`, 0.3438449439082084, 0.9355843418468089], 
             UndirectedEdge[134, 160] -> 
             RGBColor[
              0.3450319511386071, 0.4675505014401682, 0.9434155666515178], 
             UndirectedEdge[3, 5] -> 
             RGBColor[
              0.38651352623245844`, 0.5092003225130362, 0.945849278004409], 
             UndirectedEdge[16, 100] -> 
             RGBColor[
              0.19648326478805916`, 0.32384674742372915`, 0.9345008033075137],
              UndirectedEdge[75, 147] -> 
             RGBColor[
              0.3758334925595824, 0.4931487046810145, 0.9457355307409967], 
             UndirectedEdge[72, 76] -> 
             RGBColor[
              0.25872488056116644`, 0.3892666319476351, 0.9380453712475731], 
             UndirectedEdge[40, 69] -> 
             RGBColor[
              0.37782213400795434`, 0.4947977837110262, 0.9458889334343104], 
             UndirectedEdge[177, 179] -> 
             RGBColor[
              0.2929650964677688, 0.41972688072457853`, 0.940197722295881], 
             UndirectedEdge[98, 100] -> 
             RGBColor[
              0.19914601799870904`, 0.3266454698764268, 0.9346524431636698], 
             UndirectedEdge[136, 187] -> 
             RGBColor[
              0.2131466560055322, 0.3413610281133182, 0.9354497587860706], 
             UndirectedEdge[54, 199] -> 
             RGBColor[
              0.9918267372139176, 0.9824082030898711, 0.5688071701781774], 
             UndirectedEdge[166, 198] -> 
             RGBColor[
              0.5746764165171943, 0.6601910829977264, 0.9621578445394816], 
             UndirectedEdge[48, 104] -> 
             RGBColor[
              0.28879698411440874`, 0.4154790711874804, 0.939955479525905], 
             UndirectedEdge[187, 198] -> 
             RGBColor[
              0.2745522899410462, 0.4024926676355137, 0.9390715600433216], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.20340607327822147`, 0.3311230580782995, 0.9348950470096511], 
             UndirectedEdge[103, 117] -> 
             RGBColor[
              0.1832018217377303, 0.30988710868570724`, 0.9337444447739318], 
             UndirectedEdge[85, 140] -> 
             RGBColor[
              0.632097596410786, 0.6952982597896742, 0.7484529667837756], 
             UndirectedEdge[36, 70] -> 
             RGBColor[
              0.18680103840766088`, 0.3136701136093215, 0.9339494148387204], 
             UndirectedEdge[54, 171] -> 
             RGBColor[
              0.6480714766956179, 0.7066517748176793, 0.6751229004016905], 
             UndirectedEdge[120, 125] -> 
             RGBColor[
              0.22911059591556282`, 0.35814014113101095`, 0.9363588815474142],
              UndirectedEdge[81, 104] -> 
             RGBColor[
              0.336565061683316, 0.46568634938344766`, 0.9426758008769163], 
             UndirectedEdge[93, 162] -> 
             RGBColor[
              0.34139937953517563`, 0.46297232673312194`, 0.9432365284830118],
              UndirectedEdge[73, 168] -> 
             RGBColor[
              0.2134383142319024, 0.3416675794014329, 0.9354663682905927], 
             UndirectedEdge[119, 199] -> 
             RGBColor[
              0.8963041501811476, 0.5713892218289645, 0.37105115137822486`], 
             UndirectedEdge[17, 107] -> 
             RGBColor[
              0.20455110797063392`, 0.33232656213941764`, 0.9349602550414569],
              UndirectedEdge[14, 48] -> 
             RGBColor[
              0.19487547737670605`, 0.3221568609147874, 0.9344092421929455], 
             UndirectedEdge[64, 182] -> 
             RGBColor[
              0.48518193863662246`, 0.5898773465279377, 0.9534583400112507], 
             UndirectedEdge[71, 129] -> 
             RGBColor[
              0.40910477455238126`, 0.5287364214993203, 0.947297421991063], 
             UndirectedEdge[80, 100] -> 
             RGBColor[
              0.2137920345531072, 0.3420393618861828, 0.935486512139603], 
             UndirectedEdge[18, 178] -> 
             RGBColor[
              0.20335755177255102`, 0.3310720588993987, 0.9348922837816843], 
             UndirectedEdge[174, 186] -> 
             RGBColor[
              0.18655058120662976`, 0.3134068672111341, 0.9339351516716399], 
             UndirectedEdge[115, 165] -> 
             RGBColor[
              0.2604142264170086, 0.39046168008252585`, 0.9381628341942789], 
             UndirectedEdge[113, 198] -> 
             RGBColor[
              0.2750384221935423, 0.4030036234554522, 0.939099244555933], 
             UndirectedEdge[67, 100] -> 
             RGBColor[
              0.2308404904839133, 0.3599583700039979, 0.936457396483932], 
             UndirectedEdge[106, 147] -> 
             RGBColor[
              0.21727737751825504`, 0.3457026783260606, 0.9356849972653654], 
             UndirectedEdge[75, 129] -> 
             RGBColor[
              0.47830661680484077`, 0.5873498848465282, 0.9520731954511965], 
             UndirectedEdge[175, 183] -> 
             RGBColor[
              0.7184776908452273, 0.695458275607814, 0.6107486570608233], 
             UndirectedEdge[105, 144] -> 
             RGBColor[
              0.20212260779592514`, 0.3297740544799944, 0.9348219555491514], 
             UndirectedEdge[44, 128] -> 
             RGBColor[
              0.6650402658915442, 0.5906178095064059, 0.5929751287851128], 
             UndirectedEdge[70, 138] -> 
             RGBColor[
              0.2064620848582796, 0.334335120011266, 0.9350690823481714], 
             UndirectedEdge[110, 145] -> 
             RGBColor[
              0.18515978669395372`, 0.31194505399684636`, 0.9338559479816391],
              UndirectedEdge[49, 118] -> 
             RGBColor[
              0.4066109576924045, 0.5266077075173656, 0.9471298685655758], 
             UndirectedEdge[70, 185] -> 
             RGBColor[
              0.21155038817505178`, 0.3396832494142572, 0.9353588536945914], 
             UndirectedEdge[11, 138] -> 
             RGBColor[
              0.2124149402657507, 0.3405919484773504, 0.9354080886571665], 
             UndirectedEdge[120, 187] -> 
             RGBColor[
              0.1987095901475981, 0.32618675653378515`, 0.9346275892431862], 
             UndirectedEdge[71, 127] -> 
             RGBColor[
              0.6192630181344778, 0.6962347998435606, 0.9661586400075515], 
             UndirectedEdge[4, 182] -> 
             RGBColor[
              0.33757022299890055`, 0.4668080932140755, 0.9427306540012304], 
             UndirectedEdge[29, 71] -> 
             RGBColor[
              0.2853246797443417, 0.4121402643323634, 0.939746356828151], 
             UndirectedEdge[63, 185] -> 
             RGBColor[
              0.2118614125837917, 0.3400101557879294, 0.9353765660745497], 
             UndirectedEdge[83, 175] -> 
             RGBColor[
              0.7134786289406714, 0.7747821951592325, 0.9733333335119576], 
             UndirectedEdge[79, 126] -> 
             RGBColor[
              0.1869217092836395, 0.3137969463509505, 0.9339562868665908], 
             UndirectedEdge[107, 154] -> 
             RGBColor[
              0.27475191641420155`, 0.4039740129877124, 0.9390363717067235], 
             UndirectedEdge[34, 64] -> 
             RGBColor[
              0.5297940733748047, 0.6285181353670621, 0.956300985787806], 
             UndirectedEdge[159, 180] -> 
             RGBColor[
              0.29846249583214285`, 0.427955785985238, 0.9404210556305891], 
             UndirectedEdge[3, 123] -> 
             RGBColor[
              0.4349086817945046, 0.5511177738496366, 0.9489329745226667], 
             UndirectedEdge[50, 97] -> 
             RGBColor[
              0.21027301783359342`, 0.33834065219542714`, 0.9352861093433454],
              UndirectedEdge[87, 89] -> 
             RGBColor[
              0.24210890877301894`, 0.37180219208483256`, 0.9370991162353657],
              UndirectedEdge[123, 191] -> 
             RGBColor[
              0.6306139888746021, 0.7083706761376785, 0.9658367189463131], 
             UndirectedEdge[108, 151] -> 
             RGBColor[
              0.6509649455844404, 0.716416401604573, 0.8457783120147642], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.19532837830452823`, 0.32263288850550587`, 0.9344350342307781],
              UndirectedEdge[19, 33] -> 
             RGBColor[
              0.6719200989970671, 0.734922803310785, 0.8577553559890845], 
             UndirectedEdge[156, 199] -> 
             RGBColor[
              0.8775653528867244, 0.4273546144306946, 0.3531068579266407], 
             UndirectedEdge[47, 144] -> 
             RGBColor[
              0.19737482195309003`, 0.32478383053216575`, 0.9345515761691217],
              UndirectedEdge[123, 127] -> 
             RGBColor[
              0.6629559060472224, 0.73407938328518, 0.9689427121892478], 
             UndirectedEdge[82, 120] -> 
             RGBColor[
              0.2029515968118113, 0.3306453744966301, 0.9348691652472267], 
             UndirectedEdge[120, 137] -> 
             RGBColor[
              0.2589152311792967, 0.38806631610919806`, 0.9381074864400005], 
             UndirectedEdge[122, 179] -> 
             RGBColor[
              0.32323201256899053`, 0.45153932858028145`, 0.9419213783919558],
              UndirectedEdge[52, 124] -> 
             RGBColor[
              0.20581307491926143`, 0.333652969415751, 0.9350321221922685], 
             UndirectedEdge[17, 106] -> 
             RGBColor[
              0.18824964863953902`, 0.315192694810219, 0.934031911048399], 
             UndirectedEdge[125, 166] -> 
             RGBColor[
              0.5340062312264762, 0.620853714704589, 0.9597168964072044], 
             UndirectedEdge[7, 79] -> 
             RGBColor[
              0.20133607999592745`, 0.328947363893454, 0.934777163954505], 
             UndirectedEdge[49, 127] -> 
             RGBColor[
              0.6485709500663741, 0.7216198574234791, 0.9680261155142653], 
             UndirectedEdge[121, 200] -> 
             RGBColor[
              0.20398334673618768`, 0.33172980908387323`, 0.9349279218790827],
              UndirectedEdge[56, 193] -> 
             RGBColor[
              0.2060154437903921, 0.33386567193023686`, 0.9350436468001014], 
             UndirectedEdge[149, 194] -> 
             RGBColor[
              0.1935128959182038, 0.3207247014092473, 0.9343316451946424], 
             UndirectedEdge[108, 133] -> 
             RGBColor[
              0.27857495084464845`, 0.41013031438272207`, 0.9391758033846701],
              UndirectedEdge[41, 140] -> 
             RGBColor[
              0.6422147641826323, 0.7059320445833706, 0.7490291245213738], 
             UndirectedEdge[36, 185] -> 
             RGBColor[
              0.2073008742546082, 0.33521674084912667`, 0.9351168501634146], 
             UndirectedEdge[108, 111] -> 
             RGBColor[
              0.26408143509617243`, 0.39489671038909974`, 0.9383504191040295],
              UndirectedEdge[72, 154] -> 
             RGBColor[
              0.2925360773933412, 0.42266629375772025`, 0.940049153365177], 
             UndirectedEdge[63, 110] -> 
             RGBColor[
              0.18589948479502594`, 0.3127225236006417, 0.9338980726942099], 
             UndirectedEdge[15, 186] -> 
             RGBColor[
              0.18099749200595946`, 0.30757021837503873`, 0.933618911456721], 
             UndirectedEdge[54, 155] -> 
             RGBColor[
              0.8307914164161123, 0.8585643375610341, 0.688734731768329], 
             UndirectedEdge[18, 108] -> 
             RGBColor[
              0.2655472156605108, 0.39643733869807485`, 0.9384338931387406], 
             UndirectedEdge[44, 102] -> 
             RGBColor[
              0.9339747756675465, 0.8048847960141194, 0.5871542851309398], 
             UndirectedEdge[8, 122] -> 
             RGBColor[
              0.2805939833782982, 0.4122524455896443, 0.9392907843005704], 
             UndirectedEdge[42, 197] -> 
             RGBColor[
              0.20173805393446126`, 0.32936986398947277`, 0.9348000557756375],
              UndirectedEdge[48, 147] -> 
             RGBColor[
              0.2300092060376818, 0.3590846373445305, 0.9364100560644943], 
             UndirectedEdge[34, 54] -> 
             RGBColor[
              0.7092249646791587, 0.7597119219751208, 0.6790161754635967], 
             UndirectedEdge[5, 75] -> 
             RGBColor[
              0.42823819051471873`, 0.5440144353455778, 0.9488742299813958], 
             UndirectedEdge[55, 115] -> 
             RGBColor[
              0.3254517520127096, 0.4563116827378988, 0.9419584757459334], 
             UndirectedEdge[49, 155] -> 
             RGBColor[
              0.5477722741141999, 0.6424322100267535, 0.9580969923209677], 
             UndirectedEdge[66, 136] -> 
             RGBColor[
              0.2031791949691239, 0.33088459459052233`, 0.9348821266255843], 
             UndirectedEdge[136, 148] -> 
             RGBColor[
              0.2081945933984414, 0.33615609633436194`, 0.9351677461465169], 
             UndirectedEdge[130, 189] -> 
             RGBColor[
              0.18936342684036145`, 0.3163633463169, 0.9340953390692487], 
             UndirectedEdge[48, 76] -> 
             RGBColor[
              0.23737108877035865`, 0.36682244286689847`, 0.9368293043951907],
              UndirectedEdge[29, 141] -> 
             RGBColor[
              0.2753633186073925, 0.40351223398810643`, 0.9391116277049905], 
             UndirectedEdge[133, 163] -> 
             RGBColor[
              0.26544293338464375`, 0.39632773141426036`, 0.9384279544174017],
              UndirectedEdge[111, 169] -> 
             RGBColor[
              0.20611458183414505`, 0.33396987229993624`, 0.9350492925650316],
              UndirectedEdge[76, 142] -> 
             RGBColor[
              0.26312316685427595`, 0.39388950970915076`, 0.9382958471452842],
              UndirectedEdge[78, 98] -> 
             RGBColor[
              0.18771622042890102`, 0.3146320279395365, 0.9340015331009395], 
             UndirectedEdge[21, 170] -> 
             RGBColor[
              0.5082558273140996, 0.6089687689524979, 0.9552557972010979], 
             UndirectedEdge[92, 139] -> 
             RGBColor[
              0.26505756074119424`, 0.3959226803319581, 0.938406008015465], 
             UndirectedEdge[63, 70] -> 
             RGBColor[
              0.1913615767368444, 0.3184635285481242, 0.9342091307498555], 
             UndirectedEdge[71, 197] -> 
             RGBColor[
              0.2822222657868389, 0.40887943055862197`, 0.9395696789428815], 
             UndirectedEdge[127, 141] -> 
             RGBColor[
              0.6093016569975287, 0.6876067694993037, 0.9655239108843909], 
             UndirectedEdge[64, 138] -> 
             RGBColor[
              0.4257022995794623, 0.5303271273768558, 0.949962438870419], 
             UndirectedEdge[39, 108] -> 
             RGBColor[
              0.2800444750057945, 0.41167487744929976`, 0.9392594906116811], 
             UndirectedEdge[24, 165] -> 
             RGBColor[
              0.23147521014501135`, 0.3606255006113628, 0.9364935428296479], 
             UndirectedEdge[132, 182] -> 
             RGBColor[
              0.3206991952751244, 0.45143891338558356`, 0.9416833404765177], 
             UndirectedEdge[77, 181] -> 
             RGBColor[
              0.6909369767791447, 0.27406636729053985`, 0.42585898985112014`],
              UndirectedEdge[20, 47] -> 
             RGBColor[
              0.189292245231432, 0.3162885299327404, 0.9340912853819239], 
             UndirectedEdge[191, 199] -> 
             RGBColor[
              0.9026821480304056, 0.9219432707783801, 0.8549565211308954], 
             UndirectedEdge[89, 154] -> 
             RGBColor[
              0.29969282708516165`, 0.4301884914479621, 0.9404567196726639], 
             UndirectedEdge[93, 164] -> 
             RGBColor[
              0.2132799643411767, 0.3415011436263172, 0.9354573504985735], 
             UndirectedEdge[26, 187] -> 
             RGBColor[
              0.24813165922146568`, 0.378132484670584, 0.9374421029635438], 
             UndirectedEdge[5, 188] -> 
             RGBColor[
              0.33376821355982345`, 0.4635149837324976, 0.9424883933217574], 
             UndirectedEdge[7, 16] -> 
             RGBColor[
              0.19783499493782034`, 0.3252675015157697, 0.9345777823398371], 
             UndirectedEdge[154, 160] -> 
             RGBColor[
              0.38753078679870345`, 0.510081422486515, 0.9459140969481619], 
             UndirectedEdge[88, 152] -> 
             RGBColor[
              0.20837422546163153`, 0.3363449010221054, 0.9351779759267738], 
             UndirectedEdge[9, 18] -> 
             RGBColor[
              0.2081906159438856, 0.3361519157774386, 0.935167519636364], 
             UndirectedEdge[9, 200] -> 
             RGBColor[
              0.19196359639909227`, 0.31909628938339796`, 0.9342434148790122],
              UndirectedEdge[55, 183] -> 
             RGBColor[
              0.6361311703010923, 0.6254168955585735, 0.6051471025896153], 
             UndirectedEdge[72, 104] -> 
             RGBColor[
              0.31015077590521656`, 0.43792326026821704`, 0.9411715463782875],
              UndirectedEdge[112, 181] -> 
             RGBColor[
              0.6897919274498447, 0.754885022928866, 0.9666005855889899], 
             UndirectedEdge[136, 193] -> 
             RGBColor[
              0.22613676588736786`, 0.35501445721966407`, 0.9361895263266957],
              UndirectedEdge[80, 198] -> 
             RGBColor[
              0.28370833912825916`, 0.4121162558583227, 0.9395929834993725], 
             UndirectedEdge[42, 131] -> 
             RGBColor[
              0.19213265043958744`, 0.3192739758986036, 0.9342530422565254], 
             UndirectedEdge[65, 156] -> 
             RGBColor[
              0.8645913060499254, 0.38471251049152105`, 0.20533292030844175`],
              UndirectedEdge[26, 192] -> 
             RGBColor[
              0.37924820246199464`, 0.5010949181579147, 0.9455333797204014], 
             UndirectedEdge[65, 155] -> 
             RGBColor[
              0.8147643189956533, 0.8045011746203956, 0.6264724847532339], 
             UndirectedEdge[59, 62] -> 
             RGBColor[
              0.19206220882201708`, 0.3191999372922807, 0.9342490307106137], 
             UndirectedEdge[82, 187] -> 
             RGBColor[
              0.2077231055465765, 0.3356605327079955, 0.9351408956108569], 
             UndirectedEdge[4, 86] -> 
             RGBColor[
              0.26820213237561147`, 0.3968644845029512, 0.9386716201723606], 
             UndirectedEdge[73, 167] -> 
             RGBColor[
              0.20840651893599757`, 0.33637884351118863`, 0.9351798149923649],
              UndirectedEdge[74, 159] -> 
             RGBColor[
              0.30041133141594933`, 0.42964376941660665`, 0.9405452337107016],
              UndirectedEdge[25, 60] -> 
             RGBColor[
              0.18025977124348086`, 0.3067948270794758, 0.9335768993506579], 
             UndirectedEdge[159, 162] -> 
             RGBColor[
              0.3531520525661749, 0.4753251312512108, 0.9439058258256054], 
             UndirectedEdge[10, 147] -> 
             RGBColor[
              0.23373755563263043`, 0.3630033691598391, 0.9366223800583277], 
             UndirectedEdge[23, 163] -> 
             RGBColor[
              0.2527001813973467, 0.382934291138471, 0.9377022735429374], 
             UndirectedEdge[40, 54] -> 
             RGBColor[
              0.7471114929956602, 0.7911014986375555, 0.6818242326049438], 
             UndirectedEdge[123, 129] -> 
             RGBColor[
              0.45279766246512576`, 0.5665810049409397, 0.9500814941727593], 
             UndirectedEdge[25, 165] -> 
             RGBColor[
              0.19267100347283378`, 0.3198398190700993, 0.9342837006653468], 
             UndirectedEdge[39, 178] -> 
             RGBColor[
              0.21785481111783467`, 0.34630959765062364`, 0.935717881254625], 
             UndirectedEdge[76, 107] -> 
             RGBColor[
              0.2409407195820268, 0.37057435117762727`, 0.9370325895891196], 
             UndirectedEdge[63, 138] -> 
             RGBColor[
              0.20677310926701956`, 0.33466202638493814`, 0.9350867947281298],
              UndirectedEdge[71, 81] -> 
             RGBColor[
              0.334884249211027, 0.4642305141000421, 0.942568700992466], 
             UndirectedEdge[8, 83] -> 
             RGBColor[
              0.60482509904127, 0.6795990406798771, 0.9661417830923238], 
             UndirectedEdge[10, 149] -> 
             RGBColor[
              0.2017271344819297, 0.32935838695252884`, 0.9347994339289696], 
             UndirectedEdge[119, 172] -> 
             RGBColor[
              0.8543308282110663, 0.40714937648450034`, 0.19921155917100125`],
              UndirectedEdge[106, 130] -> 
             RGBColor[
              0.1846627044737023, 0.31142258906652903`, 0.933827639884563], 
             UndirectedEdge[147, 176] -> 
             RGBColor[
              0.24180624149358806`, 0.37148406958393687`, 0.9370818797815581],
              UndirectedEdge[27, 197] -> 
             RGBColor[
              0.23361320117338766`, 0.3628726647386469, 0.9366152982558398], 
             UndirectedEdge[72, 176] -> 
             RGBColor[
              0.2436445546193927, 0.37341625323494165`, 0.9371865689945322], 
             UndirectedEdge[92, 118] -> 
             RGBColor[
              0.31765722646768046`, 0.4436155762000519, 0.9416794866592155], 
             UndirectedEdge[123, 171] -> 
             RGBColor[
              0.3794372903745538, 0.5029791731450995, 0.9454017576293117], 
             UndirectedEdge[66, 113] -> 
             RGBColor[
              0.1939997700984511, 0.32123643704229315`, 0.9343593719589416], 
             UndirectedEdge[67, 179] -> 
             RGBColor[
              0.3122151911082063, 0.43995995071817273`, 0.941293986707691], 
             UndirectedEdge[130, 197] -> 
             RGBColor[
              0.19250062713784824`, 0.3196607427395459, 0.9342739979851187], 
             UndirectedEdge[15, 194] -> 
             RGBColor[
              0.19022447471756204`, 0.31726836222942645`, 0.934144374472049], 
             UndirectedEdge[47, 135] -> 
             RGBColor[
              0.19659862417943424`, 0.3239679974582722, 0.9345073728541936], 
             UndirectedEdge[8, 170] -> 
             RGBColor[
              0.4692360918503271, 0.5728158701273882, 0.9528557575864605], 
             UndirectedEdge[17, 149] -> 
             RGBColor[
              0.1884865346732682, 0.31544167705111037`, 0.9340454013575784], 
             UndirectedEdge[13, 97] -> 
             RGBColor[
              0.21895267363831583`, 0.3474635207681535, 0.9357804029010244], 
             UndirectedEdge[11, 86] -> 
             RGBColor[
              0.20252648869962175`, 0.33019855891730787`, 0.9348449559691285],
              UndirectedEdge[15, 62] -> 
             RGBColor[
              0.18941420148966015`, 0.3164167136926116, 0.9340982306104119], 
             UndirectedEdge[37, 160] -> 
             RGBColor[
              0.33951855272220766`, 0.4617555701348826, 0.9431015867680459], 
             UndirectedEdge[46, 50] -> 
             RGBColor[
              0.1933628575006826, 0.3205670015194474, 0.9343231007287265], 
             UndirectedEdge[49, 53] -> 
             RGBColor[
              0.5270688387556056, 0.6260965211703475, 0.956144232988289], 
             UndirectedEdge[52, 120] -> 
             RGBColor[
              0.1897634736745903, 0.3167838209041087, 0.9341181211446418], 
             UndirectedEdge[81, 147] -> 
             RGBColor[
              0.2777772836065891, 0.4092919155404977, 0.9391303774155055], 
             UndirectedEdge[49, 123] -> 
             RGBColor[
              0.43673943575620155`, 0.552703480914889, 0.949049628546234], 
             UndirectedEdge[127, 140] -> 
             RGBColor[
              0.9342553301344888, 0.9459893647897327, 0.7730553915426139], 
             UndirectedEdge[31, 132] -> 
             RGBColor[
              0.4162636354385904, 0.5320766653506034, 0.9483626292299419], 
             UndirectedEdge[146, 186] -> 
             RGBColor[
              0.2142358988127285, 0.34250589136566434`, 0.9355117895525502], 
             UndirectedEdge[98, 124] -> 
             RGBColor[
              0.20926922402508408`, 0.3372856012584804, 0.9352289447709307], 
             UndirectedEdge[4, 53] -> 
             RGBColor[
              0.483045374115442, 0.5879656087827072, 0.953339096749839], 
             UndirectedEdge[82, 137] -> 
             RGBColor[
              0.26792874657827515`, 0.39754009228340836`, 0.9386207928076713],
              UndirectedEdge[42, 107] -> 
             RGBColor[
              0.21020159060141025`, 0.3382655776456545, 0.9352820416681398], 
             UndirectedEdge[99, 102] -> 
             RGBColor[
              0.7604981725449849, 0.8117818781391992, 0.9474611303534258], 
             UndirectedEdge[57, 88] -> 
             RGBColor[
              0.1992012217508764, 0.32670349252007475`, 0.9346555869356892], 
             UndirectedEdge[40, 49] -> 
             RGBColor[
              0.46409235069374777`, 0.5749693711032751, 0.9511864931575826], 
             UndirectedEdge[21, 90] -> 
             RGBColor[
              0.29428715223398993`, 0.42178551711259177`, 0.9402485134141754],
              UndirectedEdge[143, 158] -> 
             RGBColor[
              0.5860035167018279, 0.6680847618686957, 0.9637366121327604], 
             UndirectedEdge[24, 111] -> 
             RGBColor[
              0.2386416994170433, 0.36815793521793205`, 0.9369016637918195], 
             UndirectedEdge[139, 155] -> 
             RGBColor[
              0.47942908630476494`, 0.5811030666228374, 0.9538203503715414], 
             UndirectedEdge[94, 174] -> 
             RGBColor[
              0.19022197405444352`, 0.31726573387393764`, 0.9341442320629838],
              UndirectedEdge[4, 118] -> 
             RGBColor[
              0.3625874930522409, 0.48847679512972536`, 0.9443247323271259], 
             UndirectedEdge[121, 159] -> 
             RGBColor[
              0.23612256314975283`, 0.36551016327854535`, 0.9367582027081254],
              UndirectedEdge[5, 76] -> 
             RGBColor[
              0.3092912653904981, 0.4382001789611937, 0.9410793812749982], 
             UndirectedEdge[27, 194] -> 
             RGBColor[
              0.23402121805989123`, 0.3633015163561269, 0.9366385342139192], 
             UndirectedEdge[77, 160] -> 
             RGBColor[
              0.6926095765883397, 0.2755150891779538, 0.42596556643194017`], 
             UndirectedEdge[2, 80] -> 
             RGBColor[
              0.20208335684743473`, 0.32973279924447707`, 0.9348197202657014],
              UndirectedEdge[74, 85] -> 
             RGBColor[
              0.3082012500479231, 0.4378314678081793, 0.9409888580526407], 
             UndirectedEdge[35, 110] -> 
             RGBColor[
              0.18045196756199675`, 0.30699683759618646`, 0.9335878446466683],
              UndirectedEdge[143, 154] -> 
             RGBColor[
              0.5937667549119501, 0.6748088886146058, 0.9642312788067474], 
             UndirectedEdge[53, 129] -> 
             RGBColor[
              0.5431270654645298, 0.6399740451963982, 0.9571760986148143], 
             UndirectedEdge[80, 187] -> 
             RGBColor[
              0.21263714806957626`, 0.34082550296795955`, 0.9354207430628674],
              UndirectedEdge[30, 87] -> 
             RGBColor[
              0.213134602991505, 0.3413483596313704, 0.9354490723847526], 
             UndirectedEdge[29, 197] -> 
             RGBColor[
              0.2038083296196198, 0.3315458549976343, 0.9349179549132087], 
             UndirectedEdge[74, 121] -> 
             RGBColor[
              0.28164177891966025`, 0.4099157796846441, 0.9394763354631025], 
             UndirectedEdge[127, 199] -> 
             RGBColor[
              0.935024065203026, 0.9476519779258816, 0.8580625143738301], 
             UndirectedEdge[52, 80] -> 
             RGBColor[
              0.20369103159656846`, 0.33142256733828307`, 0.9349112749643229],
              UndirectedEdge[125, 187] -> 
             RGBColor[
              0.233882104650328, 0.36315529934237634`, 0.9366306119110444], 
             UndirectedEdge[57, 152] -> 
             RGBColor[
              0.19101263224123774`, 0.3180967657588828, 0.9341892588770478], 
             UndirectedEdge[128, 193] -> 
             RGBColor[
              0.3303839734000996, 0.45325331449434825`, 0.942541154768971], 
             UndirectedEdge[151, 172] -> 
             RGBColor[
              0.9316219629473853, 0.7456677416234209, 0.4816953197665501], 
             UndirectedEdge[5, 27] -> 
             RGBColor[
              0.31042728364880795`, 0.439394206178395, 0.9411440758342206], 
             UndirectedEdge[65, 118] -> 
             RGBColor[
              0.6736030025738579, 0.6886766721110076, 0.6155053609978421], 
             UndirectedEdge[78, 80] -> 
             RGBColor[
              0.20236223698329917`, 0.33002591994929253`, 0.9348356020768727],
              UndirectedEdge[40, 199] -> 
             RGBColor[
              0.7505454658303996, 0.8010014916056775, 0.8412228920171474], 
             UndirectedEdge[5, 42] -> 
             RGBColor[
              0.2785521364098815, 0.40589140542922086`, 0.9393288333540183], 
             UndirectedEdge[123, 196] -> 
             RGBColor[
              0.3420552644486344, 0.4636882937396207, 0.9432729065545822], 
             UndirectedEdge[80, 124] -> 
             RGBColor[
              0.22391524057948223`, 0.35267949326823644`, 0.9360630137468638],
              UndirectedEdge[22, 48] -> 
             RGBColor[
              0.19949157754304903`, 0.3270086748672687, 0.9346721222685106], 
             UndirectedEdge[69, 86] -> 
             RGBColor[
              0.22595538032998164`, 0.3548238094983426, 0.9361791966875385], 
             UndirectedEdge[81, 143] -> 
             RGBColor[
              0.5808462742510027, 0.663366694048388, 0.9634171920700499], 
             UndirectedEdge[80, 116] -> 
             RGBColor[
              0.23121046425376574`, 0.3603472358938047, 0.936478465942798], 
             UndirectedEdge[90, 169] -> 
             RGBColor[
              0.20968181085613852`, 0.3377192561774346, 0.9352524409805917], 
             UndirectedEdge[121, 173] -> 
             RGBColor[
              0.292553121290118, 0.41936663602592106`, 0.9401715965504269], 
             UndirectedEdge[8, 179] -> 
             RGBColor[
              0.32590224390731876`, 0.4543459110193097, 0.9420734441164204], 
             UndirectedEdge[29, 167] -> 
             RGBColor[
              0.20312227411308098`, 0.33082476716183046`, 0.9348788850670395],
              UndirectedEdge[76, 87] -> 
             RGBColor[
              0.2404757286880707, 0.37008561626595393`, 0.9370061090456012], 
             UndirectedEdge[111, 163] -> 
             RGBColor[
              0.25094941763616774`, 0.3810941274206381, 0.9376025701367612], 
             UndirectedEdge[130, 149] -> 
             RGBColor[
              0.1848995905074315, 0.3116715713074204, 0.9338411301937424], 
             UndirectedEdge[7, 122] -> 
             RGBColor[
              0.24320904209445873`, 0.37295850195814717`, 0.9371617672005202],
              UndirectedEdge[89, 142] -> 
             RGBColor[
              0.2647563469392241, 0.39560608552802945`, 0.9383888543350487], 
             UndirectedEdge[44, 172] -> 
             RGBColor[
              0.8840573238836684, 0.5664132115032791, 0.22496692784453026`], 
             UndirectedEdge[7, 179] -> 
             RGBColor[
              0.2885173026234793, 0.4150519673878126, 0.9399444270163702], 
             UndirectedEdge[73, 188] -> 
             RGBColor[
              0.26534078986482257`, 0.3958083524158491, 0.9384372235539715], 
             UndirectedEdge[16, 120] -> 
             RGBColor[
              0.19055686956976303`, 0.31761773029414053`, 0.9341633038671477],
              UndirectedEdge[98, 116] -> 
             RGBColor[
              0.21656444769936758`, 0.34495334388404864`, 0.9356443969668649],
              UndirectedEdge[5, 81] -> 
             RGBColor[
              0.3301819815617254, 0.46015764620506105`, 0.9422690766559045], 
             UndirectedEdge[76, 106] -> 
             RGBColor[
              0.2246392602509319, 0.35344048384842863`, 0.9361042455960618], 
             UndirectedEdge[135, 144] -> 
             RGBColor[
              0.19771245739729065`, 0.32513870679134427`, 0.9345708040081819],
              UndirectedEdge[194, 197] -> 
             RGBColor[
              0.20111393254862053`, 0.3287138728413728, 0.9347645129860187], 
             UndirectedEdge[27, 29] -> 
             RGBColor[
              0.2367156151308905, 0.36613349851238836`, 0.9367919761411093], 
             UndirectedEdge[44, 58] -> 
             RGBColor[
              0.9296752902178356, 0.8016782468054864, 0.5944321925119014], 
             UndirectedEdge[53, 92] -> 
             RGBColor[
              0.4381151075308816, 0.5431043898530338, 0.9506938510819287], 
             UndirectedEdge[83, 122] -> 
             RGBColor[
              0.6021548677029418, 0.6767924582408489, 0.9659897173678593], 
             UndirectedEdge[9, 178] -> 
             RGBColor[
              0.18848044580793838`, 0.31543527726759235`, 0.9340450546057055],
              UndirectedEdge[12, 99] -> 
             RGBColor[
              0.7509614073428162, 0.7434552401786318, 0.618284844686889], 
             UndirectedEdge[7, 126] -> 
             RGBColor[
              0.19407996143665954`, 0.32132072322317473`, 0.9343639387370202],
              UndirectedEdge[139, 146] -> 
             RGBColor[
              0.2655359588850107, 0.39642550711330343`, 0.9384332520820287], 
             UndirectedEdge[100, 198] -> 
             RGBColor[
              0.2757071764245771, 0.40370652655373696`, 0.9391373291200573], 
             UndirectedEdge[56, 109] -> 
             RGBColor[
              0.19998929422011852`, 0.3275318066519287, 0.9347004664969638], 
             UndirectedEdge[9, 159] -> 
             RGBColor[
              0.22410281281265743`, 0.3528766435780701, 0.9360736957080549], 
             UndirectedEdge[2, 98] -> 
             RGBColor[
              0.18743734029303655`, 0.314338907234721, 0.9339856512897682], 
             UndirectedEdge[95, 164] -> 
             RGBColor[
              0.22218549989478478`, 0.35086142613672566`, 0.9359645075737923],
              UndirectedEdge[108, 163] -> 
             RGBColor[
              0.29489469195251866`, 0.4272833970184431, 0.94010518849787], 
             UndirectedEdge[85, 121] -> 
             RGBColor[
              0.24391248178172664`, 0.37369786167011787`, 0.9372018270500644],
              UndirectedEdge[55, 177] -> 
             RGBColor[
              0.2766340766323431, 0.4055817721640561, 0.9391571241529215], 
             UndirectedEdge[118, 141] -> 
             RGBColor[
              0.36734166462355905`, 0.4925946195931902, 0.9446276639357014], 
             UndirectedEdge[58, 77] -> 
             RGBColor[
              0.8650715589355825, 0.41279091020967174`, 0.42668452743448415`],
              UndirectedEdge[142, 154] -> 
             RGBColor[
              0.29693436368645065`, 0.4272891715192359, 0.9402996292628881], 
             UndirectedEdge[103, 178] -> 
             RGBColor[
              0.1823641236245055, 0.3090066348555799, 0.933696739105647], 
             UndirectedEdge[48, 154] -> 
             RGBColor[
              0.2711822856025334, 0.4002221046769836, 0.9388330865127945], 
             UndirectedEdge[72, 181] -> 
             RGBColor[
              0.345687120645864, 0.46870305597394574`, 0.9434358908416056], 
             UndirectedEdge[45, 132] -> 
             RGBColor[
              0.5058042387487333, 0.6037176098642293, 0.9561309549136163], 
             UndirectedEdge[103, 200] -> 
             RGBColor[
              0.18584727421565939`, 0.3126676469713855, 0.9338950993789537], 
             UndirectedEdge[21, 61] -> 
             RGBColor[
              0.2843221054652073, 0.4113116211381439, 0.9396810187426589], 
             UndirectedEdge[51, 73] -> 
             RGBColor[
              0.19983789794558066`, 0.3273726795683112, 0.9346918447030995], 
             UndirectedEdge[18, 41] -> 
             RGBColor[
              0.25688700518109014`, 0.38733490839514545`, 0.9379407069635708],
              UndirectedEdge[27, 42] -> 
             RGBColor[
              0.2346453394457319, 0.36395750750422684`, 0.936674077003538], 
             UndirectedEdge[90, 165] -> 
             RGBColor[
              0.21653690052978303`, 0.3449243900622238, 0.9356428281963094], 
             UndirectedEdge[50, 135] -> 
             RGBColor[
              0.20034146801813224`, 0.3279019636427496, 0.9347205222737662], 
             UndirectedEdge[93, 121] -> 
             RGBColor[
              0.22436989011875363`, 0.3531573587604565, 0.9360889053655316], 
             UndirectedEdge[23, 175] -> 
             RGBColor[
              0.36210448140880436`, 0.4789065526071719, 0.9449365792097879], 
             UndirectedEdge[57, 164] -> 
             RGBColor[
              0.1885063938143962, 0.3154625502675782, 0.9340465323062868], 
             UndirectedEdge[54, 172] -> 
             RGBColor[
              0.9288667542587956, 0.7360484350731749, 0.311047781867342], 
             UndirectedEdge[99, 198] -> 
             RGBColor[
              0.44872208919176476`, 0.5604076738789969, 0.9505521468225746], 
             UndirectedEdge[45, 112] -> 
             RGBColor[
              0.8262269535061243, 0.8650081965468237, 0.9779469895534628], 
             UndirectedEdge[88, 173] -> 
             RGBColor[
              0.2921580234490212, 0.41895136314427833`, 0.9401490963128714], 
             UndirectedEdge[14, 22] -> 
             RGBColor[
              0.18387332754707644`, 0.31059290386725735`, 0.9337826860363703],
              UndirectedEdge[7, 67] -> 
             RGBColor[
              0.23219222063367448`, 0.36137912409603845`, 0.9365343755162554],
              UndirectedEdge[105, 135] -> 
             RGBColor[
              0.20134641002226938`, 0.32895822140610087`, 0.9347777522342233],
              UndirectedEdge[104, 176] -> 
             RGBColor[
              0.300594019570315, 0.4278785034268868, 0.9406273032429688], 
             UndirectedEdge[57, 91] -> 
             RGBColor[
              0.18403700151578473`, 0.31076493558589874`, 0.9337920070267542],
              UndirectedEdge[34, 185] -> 
             RGBColor[
              0.3310536945005693, 0.45407275524127744`, 0.9425750645902526], 
             UndirectedEdge[65, 172] -> 
             RGBColor[
              0.9128396568383367, 0.6819852721325363, 0.24878553485224705`], 
             UndirectedEdge[66, 120] -> 
             RGBColor[
              0.18874212911118976`, 0.3157103230109893, 0.9340599570827], 
             UndirectedEdge[91, 117] -> 
             RGBColor[
              0.1857785761820701, 0.31259544098237624`, 0.9338911871275704], 
             UndirectedEdge[27, 141] -> 
             RGBColor[
              0.30516819016116037`, 0.4348390437291191, 0.9408089710476214], 
             UndirectedEdge[13, 145] -> 
             RGBColor[
              0.20564959648275716`, 0.3334811432138535, 0.9350228123371542], 
             UndirectedEdge[1, 174] -> 
             RGBColor[
              0.1849745541189024, 0.31175036281604385`, 0.9338453992605169], 
             UndirectedEdge[182, 196] -> 
             RGBColor[
              0.28690951633149697`, 0.41592381842644754`, 0.9397590682480286],
              UndirectedEdge[96, 137] -> 
             RGBColor[
              0.630154419316935, 0.7035305563325196, 0.9671868226387048], 
             UndirectedEdge[89, 157] -> 
             RGBColor[
              0.23696986749514018`, 0.36640073386774574`, 0.9368064554371207],
              UndirectedEdge[119, 191] -> 
             RGBColor[
              0.8345851088356466, 0.5244792716425559, 0.45555161240523445`], 
             UndirectedEdge[51, 157] -> 
             RGBColor[
              0.19431074366027534`, 0.32156328997263306`, 0.9343770814432435],
              UndirectedEdge[127, 195] -> 
             RGBColor[
              0.6879096375591269, 0.7543975082866485, 0.9708907042928315], 
             UndirectedEdge[27, 62] -> 
             RGBColor[
              0.23321094483198931`, 0.3624498678193121, 0.9365923903522819], 
             UndirectedEdge[4, 40] -> 
             RGBColor[
              0.42006888605358417`, 0.5368384587156347, 0.9483813569191326], 
             UndirectedEdge[161, 164] -> 
             RGBColor[
              0.23950057479482478`, 0.3690606676958246, 0.9369505754739917], 
             UndirectedEdge[20, 101] -> 
             RGBColor[
              0.18925893509711914`, 0.3162535188695931, 0.9340893884190526], 
             UndirectedEdge[13, 36] -> 
             RGBColor[
              0.20182875625464586`, 0.3294651978788461, 0.9348052211385899], 
             UndirectedEdge[182, 195] -> 
             RGBColor[
              0.42093237513181697`, 0.5377166564648852, 0.9484003790182465], 
             UndirectedEdge[184, 186] -> 
             RGBColor[
              0.18243843400162507`, 0.3090847397734826, 0.9337009709716915], 
             UndirectedEdge[96, 166] -> 
             RGBColor[
              0.8700729048613844, 0.8993494121193195, 0.9867932099380505], 
             UndirectedEdge[38, 43] -> 
             RGBColor[
              0.1854358891920559, 0.31223525522826123`, 0.9338716716104489], 
             UndirectedEdge[30, 176] -> 
             RGBColor[
              0.22182699852969923`, 0.3504846184717214, 0.9359440914514059], 
             UndirectedEdge[171, 174] -> 
             RGBColor[
              0.24889168370669917`, 0.37893131859289997`, 0.9374853852336225],
              UndirectedEdge[100, 125] -> 
             RGBColor[
              0.23503699113385892`, 0.36436915826059957`, 0.9366963809877801],
              UndirectedEdge[17, 188] -> 
             RGBColor[
              0.25233578672597107`, 0.38213926955209265`, 0.937696607864392], 
             UndirectedEdge[87, 107] -> 
             RGBColor[
              0.21716799810205883`, 0.34558771362458285`, 0.9356787682694253],
              UndirectedEdge[62, 184] -> 
             RGBColor[
              0.19085514348532573`, 0.3179312350910555, 0.9341802901253824], 
             UndirectedEdge[12, 33] -> 
             RGBColor[
              0.9713628299392978, 0.9155481063306994, 0.5253098577893779], 
             UndirectedEdge[32, 57] -> 
             RGBColor[
              0.1839232484123208, 0.31064537386179486`, 0.9337855289557946], 
             UndirectedEdge[17, 87] -> 
             RGBColor[
              0.2040861170766778, 0.33183782722774424`, 0.9349337744979385], 
             UndirectedEdge[42, 149] -> 
             RGBColor[
              0.1941370173040445, 0.32138069255734725`, 0.9343671879842612], 
             UndirectedEdge[87, 130] -> 
             RGBColor[
              0.20049917291084113`, 0.3280677214840543, 0.9347295033341025], 
             UndirectedEdge[58, 170] -> 
             RGBColor[
              0.8078923228953876, 0.8503457214275595, 0.9589431237256691], 
             UndirectedEdge[118, 196] -> 
             RGBColor[
              0.3119267863848373, 0.4375925203420974, 0.941353146573924], 
             UndirectedEdge[41, 159] -> 
             RGBColor[
              0.27279920204986197`, 0.40405963619577695`, 0.9388468830352616],
              UndirectedEdge[107, 157] -> 
             RGBColor[
              0.2120289568241801, 0.34018625540749603`, 0.9353861074711805], 
             UndirectedEdge[161, 173] -> 
             RGBColor[
              0.32579061120905595`, 0.4543013453093021, 0.9420644224308505], 
             UndirectedEdge[15, 184] -> 
             RGBColor[
              0.18036794199566558`, 0.3069085213984438, 0.9335830595149706], 
             UndirectedEdge[106, 142] -> 
             RGBColor[
              0.22351397693716918`, 0.3522577397385811, 0.9360401623760504], 
             UndirectedEdge[24, 39] -> 
             RGBColor[
              0.25460473932666533`, 0.38493610227813213`, 0.9378107352994711],
              UndirectedEdge[45, 134] -> 
             RGBColor[
              0.478958077481094, 0.5755005922270049, 0.9546021057447607], 
             UndirectedEdge[5, 73] -> 
             RGBColor[
              0.2859066569179567, 0.41362147278674055`, 0.939747662416915], 
             UndirectedEdge[147, 154] -> 
             RGBColor[
              0.2906977642675366, 0.42073411010671546`, 0.939944464152203], 
             UndirectedEdge[76, 143] -> 
             RGBColor[
              0.5599555580797754, 0.6414092268045206, 0.9622274966891435], 
             UndirectedEdge[5, 197] -> 
             RGBColor[
              0.27751999813753725`, 0.4048065626636409, 0.93927005460632], 
             UndirectedEdge[152, 159] -> 
             RGBColor[
              0.22753887579901738`, 0.3564881636357107, 0.9362693744119284], 
             UndirectedEdge[108, 115] -> 
             RGBColor[
              0.3115259900053915, 0.4441833842869002, 0.9410735735175593], 
             UndirectedEdge[65, 123] -> 
             RGBColor[
              0.7037314806376549, 0.7147724455085309, 0.6174251209785002], 
             UndirectedEdge[8, 67] -> 
             RGBColor[
              0.26957716191751396`, 0.4006730677275356, 0.9386633926163057], 
             UndirectedEdge[9, 41] -> 
             RGBColor[
              0.24200989921647753`, 0.37169812676333913`, 0.9370934777875921],
              UndirectedEdge[111, 165] -> 
             RGBColor[
              0.21296967150778956`, 0.3411750061847254, 0.9354396797807493], 
             UndirectedEdge[146, 195] -> 
             RGBColor[
              0.37321783418719845`, 0.490532301380389, 0.9455744828100211], 
             UndirectedEdge[104, 188] -> 
             RGBColor[
              0.34015129368141406`, 0.46904368691088416`, 0.9428951175427689],
              UndirectedEdge[37, 105] -> 
             RGBColor[
              0.22080146805015013`, 0.3494067209153274, 0.9358856890077321], 
             UndirectedEdge[3, 75] -> 
             RGBColor[
              0.4604176361342196, 0.5718866537552251, 0.9509246758011038], 
             UndirectedEdge[40, 132] -> 
             RGBColor[
              0.40319785832980803`, 0.5214692788871429, 0.94733404339442], 
             UndirectedEdge[154, 157] -> 
             RGBColor[
              0.2691478842423667, 0.3980838198589522, 0.9387172303649602], 
             UndirectedEdge[116, 148] -> 
             RGBColor[
              0.21710235245946194`, 0.3455187158920394, 0.9356750298471934], 
             UndirectedEdge[132, 185] -> 
             RGBColor[
              0.26630785953473646`, 0.397236823637493, 0.9384772106821059], 
             UndirectedEdge[92, 123] -> 
             RGBColor[
              0.34778570453147756`, 0.4697113495975751, 0.9435992466398737], 
             UndirectedEdge[53, 139] -> 
             RGBColor[
              0.4587256509461706, 0.5647673777664313, 0.9518675910388628], 
             UndirectedEdge[40, 196] -> 
             RGBColor[
              0.3694081793861806, 0.4859541839280068, 0.9454097711659308], 
             UndirectedEdge[27, 73] -> 
             RGBColor[
              0.2419998599538071, 0.37168757486174653`, 0.9370929060664348], 
             UndirectedEdge[57, 103] -> 
             RGBColor[
              0.1814602470714449, 0.3080566032892297, 0.9336452646731157], 
             UndirectedEdge[44, 77] -> 
             RGBColor[
              0.8444706345429746, 0.3004972543273192, 0.1885609342401168], 
             UndirectedEdge[88, 91] -> 
             RGBColor[
              0.20139859473617852`, 0.32901307084912135`, 0.93478072407648], 
             UndirectedEdge[69, 146] -> 
             RGBColor[
              0.24760893000865222`, 0.37758306312497075`, 0.9374123343081827],
              UndirectedEdge[65, 199] -> 
             RGBColor[
              0.9757996397934585, 0.9283450401492326, 0.5065449231630825], 
             UndirectedEdge[27, 75] -> 
             RGBColor[
              0.3843313935505691, 0.5020805374205839, 0.9462194736309155], 
             UndirectedEdge[4, 65] -> 
             RGBColor[
              0.6453230600166431, 0.6641820072591899, 0.6137033880650677], 
             UndirectedEdge[58, 102] -> 
             RGBColor[
              0.9648761622564584, 0.9733252798376484, 0.9443396749224908], 
             UndirectedEdge[107, 168] -> 
             RGBColor[
              0.21351519211843195`, 0.34174838293451504`, 0.9354707463724999],
              UndirectedEdge[9, 85] -> 
             RGBColor[
              0.23189273144463124`, 0.36106434196964265`, 0.9365173200499939],
              UndirectedEdge[22, 144] -> 
             RGBColor[
              0.19348904144218293`, 0.3206996288424882, 0.9343302867175226], 
             UndirectedEdge[110, 138] -> 
             RGBColor[
              0.20099999291646117`, 0.32859411506378333`, 0.9347580242925257],
              UndirectedEdge[34, 132] -> 
             RGBColor[
              0.3653113300133066, 0.4900797022247081, 0.9445259862530728], 
             UndirectedEdge[48, 158] -> 
             RGBColor[
              0.2634190473924112, 0.39349797793107355`, 0.9383384198388076], 
             UndirectedEdge[19, 95] -> 
             RGBColor[
              0.3002072480543151, 0.4289405280402324, 0.9405515065144217], 
             UndirectedEdge[122, 137] -> 
             RGBColor[
              0.3009080664928653, 0.4322034485232962, 0.9404989162882755], 
             UndirectedEdge[8, 198] -> 
             RGBColor[
              0.31444384785817775`, 0.4444212242772747, 0.9413433252524308], 
             UndirectedEdge[92, 174] -> 
             RGBColor[
              0.2172400978636229, 0.3456634950453756, 0.9356828742441843], 
             UndirectedEdge[39, 133] -> 
             RGBColor[
              0.2505927164379196, 0.38071921184511703`, 0.9375822565312131], 
             UndirectedEdge[120, 198] -> 
             RGBColor[
              0.26978078120628096`, 0.39747750942414833`, 0.9387998296796913],
              UndirectedEdge[4, 34] -> 
             RGBColor[
              0.38218235773708276`, 0.5054488820532, 0.9455732997777855], 
             UndirectedEdge[31, 34] -> 
             RGBColor[
              0.48100947040442327`, 0.5889125969543878, 0.9524604831380885], 
             UndirectedEdge[41, 152] -> 
             RGBColor[
              0.2454459622028375, 0.3753096468209797, 0.9372891564914656], 
             UndirectedEdge[95, 121] -> 
             RGBColor[
              0.23327542567236176`, 0.36251764127086494`, 0.9365960624407503],
              UndirectedEdge[3, 129] -> 
             RGBColor[
              0.4365819525225805, 0.5525357720139865, 0.9490482434742096], 
             UndirectedEdge[49, 199] -> 
             RGBColor[
              0.7088075949120052, 0.7662760755555905, 0.8381694307308162], 
             UndirectedEdge[171, 182] -> 
             RGBColor[
              0.3242915422574164, 0.45521469783192636`, 0.9418879193227581], 
             UndirectedEdge[56, 150] -> 
             RGBColor[
              0.18756580923325702`, 0.31447393623629405`, 0.933992967405861], 
             UndirectedEdge[179, 183] -> 
             RGBColor[
              0.6524621901365182, 0.6395620041190959, 0.6061877007325749], 
             UndirectedEdge[31, 156] -> 
             RGBColor[
              0.723132374813741, 0.30688840243812476`, 0.4291372901014996], 
             UndirectedEdge[132, 153] -> 
             RGBColor[
              0.29141110867079584`, 0.42362193011741534`, 0.9399068035834754],
              UndirectedEdge[78, 136] -> 
             RGBColor[
              0.2028717449192551, 0.3305614450946512, 0.9348646178000759], 
             UndirectedEdge[27, 167] -> 
             RGBColor[
              0.2329271456668488, 0.36215157690284305`, 0.9365762284096705], 
             UndirectedEdge[35, 174] -> 
             RGBColor[
              0.18540537254043327`, 0.31220318029253835`, 0.9338699337322844],
              UndirectedEdge[61, 190] -> 
             RGBColor[
              0.1957633885191688, 0.3230901118223337, 0.9344598074189618], 
             UndirectedEdge[18, 103] -> 
             RGBColor[
              0.20207429376045272`, 0.32972327336542606`, 0.9348192041363055],
              UndirectedEdge[146, 155] -> 
             RGBColor[
              0.4592969410332923, 0.5599429054907851, 0.9526738544811711], 
             UndirectedEdge[77, 166] -> 
             RGBColor[
              0.8127891173448866, 0.371617581823192, 0.4365026295330454], 
             UndirectedEdge[85, 159] -> 
             RGBColor[
              0.26268203427801573`, 0.3934258514020805, 0.9382707252976634], 
             UndirectedEdge[39, 88] -> 
             RGBColor[
              0.2343125277851679, 0.36360770134749604`, 0.9366551238718196], 
             UndirectedEdge[66, 80] -> 
             RGBColor[
              0.20266968703316796`, 0.3303490694451636, 0.9348531109023811], 
             UndirectedEdge[62, 141] -> 
             RGBColor[
              0.2718586483084913, 0.3998286032950302, 0.9389120419161632], 
             UndirectedEdge[91, 103] -> 
             RGBColor[
              0.18365762005674702`, 0.31036618161827634`, 0.9337704018139066],
              UndirectedEdge[149, 189] -> 
             RGBColor[
              0.18996767873421347`, 0.31699845336912136`, 0.934129750320693], 
             UndirectedEdge[4, 69] -> 
             RGBColor[
              0.2920607984493962, 0.42194145527329896`, 0.9400303359095292], 
             UndirectedEdge[23, 169] -> 
             RGBColor[
              0.20786534559532402`, 0.33581003601776915`, 0.9351489959712078],
              UndirectedEdge[32, 152] -> 
             RGBColor[
              0.19309625212307593`, 0.3202867823638255, 0.9343079179468792], 
             UndirectedEdge[100, 124] -> 
             RGBColor[
              0.21591407787580016`, 0.3442697639636507, 0.9356073593675487], 
             UndirectedEdge[129, 139] -> 
             RGBColor[
              0.3700695186748425, 0.49279233567532266`, 0.9448882555483507], 
             UndirectedEdge[29, 73] -> 
             RGBColor[
              0.21219498840003925`, 0.3403607651207339, 0.9353955627238038], 
             UndirectedEdge[32, 178] -> 
             RGBColor[
              0.1848271249653814, 0.311595405428145, 0.9338370033883259], 
             UndirectedEdge[8, 61] -> 
             RGBColor[
              0.24530237000143487`, 0.37515872231303415`, 0.9372809791280214],
              UndirectedEdge[10, 27] -> 
             RGBColor[
              0.24223545662361712`, 0.37193520189940843`, 0.9371063229482464],
              UndirectedEdge[72, 160] -> 
             RGBColor[
              0.3481960203596565, 0.4708761388050667, 0.9435957557128356], 
             UndirectedEdge[72, 144] -> 
             RGBColor[
              0.22584498306262032`, 0.3547077749707548, 0.9361729097264804], 
             UndirectedEdge[134, 135] -> 
             RGBColor[
              0.22190471606791506`, 0.3505663045319628, 0.9359485173502345], 
             UndirectedEdge[95, 150] -> 
             RGBColor[
              0.2208799451115121, 0.3494892052825519, 0.9358901581602801], 
             UndirectedEdge[68, 71] -> 
             RGBColor[
              0.6623649639352431, 0.6847752584173, 0.6236785616506062], 
             UndirectedEdge[118, 123] -> 
             RGBColor[
              0.42099591367325284`, 0.5390672333790665, 0.9480464652405584], 
             UndirectedEdge[89, 168] -> 
             RGBColor[
              0.23845610278939203`, 0.36796286139476475`, 0.9368910943384403],
              UndirectedEdge[44, 99] -> 
             RGBColor[
              0.7252973005063621, 0.6401348451070372, 0.5975536479428364], 
             UndirectedEdge[121, 180] -> 
             RGBColor[
              0.27969294333585376`, 0.40822779625327543`, 0.9393521573829899],
              UndirectedEdge[10, 141] -> 
             RGBColor[
              0.28088316010011916`, 0.40931393737512656`, 0.9394259745121276],
              UndirectedEdge[6, 170] -> 
             RGBColor[
              0.7726913425929597, 0.40526664724585604`, 0.4405786287096226], 
             UndirectedEdge[12, 77] -> 
             RGBColor[
              0.8615800391006107, 0.36937751770838223`, 0.20238173206948523`],
              UndirectedEdge[112, 143] -> 
             RGBColor[
              0.8985367952768839, 0.9217855718880776, 0.9850776323188054], 
             UndirectedEdge[67, 125] -> 
             RGBColor[
              0.2600866097683471, 0.39069789568300034`, 0.9381229197114243], 
             UndirectedEdge[3, 10] -> 
             RGBColor[
              0.3183216992072676, 0.4417413182340497, 0.9418115251184348], 
             UndirectedEdge[124, 125] -> 
             RGBColor[
              0.24516019716023396`, 0.37500928964265323`, 0.9372728825950409],
              UndirectedEdge[11, 174] -> 
             RGBColor[
              0.1964947207721936, 0.32385878838940574`, 0.9345014557088626], 
             UndirectedEdge[71, 87] -> 
             RGBColor[
              0.29022081155983176`, 0.4172864093031303, 0.9400251842918653], 
             UndirectedEdge[7, 192] -> 
             RGBColor[
              0.3371042587561843, 0.4567989612427451, 0.9431333444727331], 
             UndirectedEdge[56, 148] -> 
             RGBColor[
              0.18807327130146562`, 0.31500731104493473`, 0.9340218666199227],
              UndirectedEdge[30, 71] -> 
             RGBColor[
              0.28665240734323405`, 0.41353579022159115`, 0.939821968950711], 
             UndirectedEdge[35, 86] -> 
             RGBColor[
              0.19143714046786142`, 0.31854295082044043`, 0.9342134339925504],
              UndirectedEdge[68, 127] -> 
             RGBColor[
              0.9178893661581602, 0.8915362183675095, 0.645439120800334], 
             UndirectedEdge[10, 30] -> 
             RGBColor[
              0.2137583126687416, 0.34200391804762365`, 0.9354845917281754], 
             UndirectedEdge[89, 176] -> 
             RGBColor[
              0.25080130431121317`, 0.3809384509251836, 0.937594135302019], 
             UndirectedEdge[71, 76] -> 
             RGBColor[
              0.3139935330397997, 0.4422730468561747, 0.9413790056115596], 
             UndirectedEdge[49, 119] -> 
             RGBColor[
              0.705335406756713, 0.42070114149402954`, 0.44436021880518173`], 
             UndirectedEdge[87, 106] -> 
             RGBColor[
              0.20086653877096394`, 0.3284538462953842, 0.9347504242763673], 
             UndirectedEdge[86, 196] -> 
             RGBColor[
              0.2175414257082079, 0.3459802097153233, 0.9357000344191588], 
             UndirectedEdge[53, 123] -> 
             RGBColor[
              0.5414537947364539, 0.6385560470320484, 0.9570608296632714], 
             UndirectedEdge[68, 102] -> 
             RGBColor[
              0.9650834798325474, 0.9283042529937652, 0.6200104049924591], 
             UndirectedEdge[107, 130] -> 
             RGBColor[
              0.20096416380479723`, 0.32855645639572767`, 0.9347559838776209],
              UndirectedEdge[42, 157] -> 
             RGBColor[
              0.2045975584295754, 0.3323753845168943, 0.9349629003263764], 
             UndirectedEdge[96, 99] -> 
             RGBColor[
              0.7441185775359549, 0.79956600300059, 0.9751875122211435], 
             UndirectedEdge[62, 194] -> 
             RGBColor[
              0.2007116762072222, 0.32829107592203804`, 0.9347416050824608], 
             UndirectedEdge[57, 117] -> 
             RGBColor[
              0.18358120319676802`, 0.31028586265332964`, 0.9337660499867794],
              UndirectedEdge[102, 128] -> 
             RGBColor[
              0.700241137930167, 0.7622648425385679, 0.9428826111957023], 
             UndirectedEdge[46, 47] -> 
             RGBColor[
              0.1896200136619846, 0.31663303533497, 0.934109951309154], 
             UndirectedEdge[28, 105] -> 
             RGBColor[
              0.19252363925225727`, 0.3196849299308422, 0.9342753084909909], 
             UndirectedEdge[40, 182] -> 
             RGBColor[
              0.4233315585574587, 0.5396644216518027, 0.9485892515260115], 
             UndirectedEdge[79, 179] -> 
             RGBColor[
              0.2813590504704592, 0.4075281905155883, 0.9395367751459407], 
             UndirectedEdge[36, 63] -> 
             RGBColor[
              0.1871120628164008, 0.3139970199829937, 0.9339671272186787], 
             UndirectedEdge[118, 129] -> 
             RGBColor[
              0.4226691844013287, 0.5404852315434163, 0.9481617341921013], 
             UndirectedEdge[74, 161] -> 
             RGBColor[
              0.31487926883859824`, 0.44485048896802515`, 0.9413691613435261],
              UndirectedEdge[66, 187] -> 
             RGBColor[
              0.19351363784595493`, 0.32072548122235467`, 0.9343316874463302],
              UndirectedEdge[10, 29] -> 
             RGBColor[
              0.2124305850698493, 0.3406083921583959, 0.9354089796056155], 
             UndirectedEdge[30, 147] -> 
             RGBColor[
              0.22954544173879612`, 0.3585971916620468, 0.9363836453737505], 
             UndirectedEdge[109, 116] -> 
             RGBColor[
              0.2290183753781148, 0.3580432114990334, 0.9363536297242345], 
             UndirectedEdge[81, 154] -> 
             RGBColor[
              0.31895036317144065`, 0.45042938287295087`, 0.9415534078638058],
              UndirectedEdge[89, 188] -> 
             RGBColor[
              0.29035857842231216`, 0.42210363440918097`, 0.939861949601819], 
             UndirectedEdge[24, 163] -> 
             RGBColor[
              0.2694549562733895, 0.40054462184727546`, 0.9386564331856598], 
             UndirectedEdge[91, 159] -> 
             RGBColor[
              0.22056324507356437`, 0.3491563334627266, 0.9358721225616348], 
             UndirectedEdge[121, 164] -> 
             RGBColor[
              0.2062630848758868, 0.3341259584124435, 0.9350577495935681], 
             UndirectedEdge[4, 54] -> 
             RGBColor[
              0.661350157437102, 0.7182451701998284, 0.6759656350801627], 
             UndirectedEdge[51, 130] -> 
             RGBColor[
              0.18324595064089247`, 0.3099334909608647, 0.933746957849684], 
             UndirectedEdge[69, 186] -> 
             RGBColor[
              0.21644101520784265`, 0.3448236085093839, 0.9356373676690746], 
             UndirectedEdge[137, 179] -> 
             RGBColor[
              0.3462163270218858, 0.4742969139529616, 0.9432815761041253], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.37725864887478877`, 0.501184212909484, 0.945259565402945], 
             UndirectedEdge[22, 176] -> 
             RGBColor[
              0.2112886129989553, 0.33940810710667507`, 0.9353439459855744], 
             UndirectedEdge[128, 198] -> 
             RGBColor[
              0.38846505457694686`, 0.5108906382783656, 0.9459736276648509], 
             UndirectedEdge[107, 131] -> 
             RGBColor[
              0.19956404883419218`, 0.32708484678920535`, 0.9346762494013294],
              UndirectedEdge[26, 125] -> 
             RGBColor[
              0.2785326649894304, 0.41008586926780977`, 0.9391733952677717], 
             UndirectedEdge[47, 105] -> 
             RGBColor[
              0.2010087745780687, 0.32860334514692235`, 0.934758524395163], 
             UndirectedEdge[23, 60] -> 
             RGBColor[
              0.2023092030396156, 0.32997017791193484`, 0.9348325818722366], 
             UndirectedEdge[43, 111] -> 
             RGBColor[
              0.2049417486516364, 0.33273715026320094`, 0.934982501450339], 
             UndirectedEdge[73, 142] -> 
             RGBColor[
              0.23973855838173452`, 0.36931080353469764`, 0.9369641282872011],
              UndirectedEdge[43, 115] -> 
             RGBColor[
              0.25238630356085545`, 0.3820238241610014, 0.9377056558638687], 
             UndirectedEdge[61, 122] -> 
             RGBColor[
              0.24263213866310665`, 0.37235213987400595`, 0.9371289134035569],
              UndirectedEdge[64, 65] -> 
             RGBColor[
              0.792934775654365, 0.787251260573052, 0.6244310740750881], 
             UndirectedEdge[147, 157] -> 
             RGBColor[
              0.2279748046775151, 0.3569463525264991, 0.9362941999166599], 
             UndirectedEdge[53, 69] -> 
             RGBColor[
              0.4407986220698122, 0.5459249337780987, 0.9508466732650168], 
             UndirectedEdge[27, 188] -> 
             RGBColor[
              0.28986141659567377`, 0.4215810858075036, 0.939833636971277], 
             UndirectedEdge[88, 159] -> 
             RGBColor[
              0.23572746530865607`, 0.3650948903969026, 0.9367357024705698], 
             UndirectedEdge[16, 61] -> 
             RGBColor[
              0.19725809150646825`, 0.3246611394316285, 0.9345449285428737], 
             UndirectedEdge[138, 185] -> 
             RGBColor[
              0.22696192070522694`, 0.35588174725107113`, 0.9362365176728656],
              UndirectedEdge[26, 128] -> 
             RGBColor[
              0.36204442385736635`, 0.48653045531343586`, 0.9443441705850733],
              UndirectedEdge[68, 75] -> 
             RGBColor[
              0.7315668061877028, 0.7433887217645079, 0.6284543351107399], 
             UndirectedEdge[10, 107] -> 
             RGBColor[
              0.21779170777929543`, 0.3462432720408361, 0.9357142876128481], 
             UndirectedEdge[69, 123] -> 
             RGBColor[
              0.3504692190704081, 0.47253189352264, 0.9437520688229617], 
             UndirectedEdge[109, 113] -> 
             RGBColor[
              0.2109311914464215, 0.33903243439312675`, 0.9353235913569153], 
             UndirectedEdge[49, 196] -> 
             RGBColor[
              0.3276703084677861, 0.4512287678779199, 0.9423563098795996], 
             UndirectedEdge[8, 26] -> 
             RGBColor[
              0.28802321713859724`, 0.420061041312345, 0.9397138681726531], 
             UndirectedEdge[30, 73] -> 
             RGBColor[
              0.21352271599893158`, 0.34175629100996163`, 0.9354711748463638],
              UndirectedEdge[46, 144] -> 
             RGBColor[
              0.19073384687984102`, 0.31780374466804207`, 0.9341733824631423],
              UndirectedEdge[81, 176] -> 
             RGBColor[
              0.2700588403974922, 0.4011793423501723, 0.938690823493161], 
             UndirectedEdge[104, 181] -> 
             RGBColor[
              0.4026365855967863, 0.5231653061658909, 0.9468766250900423], 
             UndirectedEdge[65, 171] -> 
             RGBColor[
              0.6320443792751589, 0.6525886118770408, 0.6128606533865955], 
             UndirectedEdge[67, 82] -> 
             RGBColor[
              0.2339276106645956, 0.3632031290486195, 0.9366332034112368], 
             UndirectedEdge[13, 63] -> 
             RGBColor[
              0.20638929458382937`, 0.3342586128176488, 0.935064937049725], 
             UndirectedEdge[153, 182] -> 
             RGBColor[
              0.3115448088984465, 0.4418170728820753, 0.941162011715067], 
             UndirectedEdge[87, 157] -> 
             RGBColor[
              0.21156396593022397`, 0.3396975204958227, 0.9353596269276621], 
             UndirectedEdge[30, 157] -> 
             RGBColor[
              0.20799556171362626`, 0.3359469014142835, 0.9351564115865076], 
             UndirectedEdge[64, 185] -> 
             RGBColor[
              0.4307906028962345, 0.5356752567798472, 0.9502522102168389], 
             UndirectedEdge[9, 103] -> 
             RGBColor[
              0.18719718779584008`, 0.3140864917336198, 0.9339719749603267], 
             UndirectedEdge[18, 117] -> 
             RGBColor[
              0.2041952498857758, 0.331952532729526, 0.9349399894499691], 
             UndirectedEdge[52, 66] -> 
             RGBColor[
              0.18456752137294713`, 0.3113225455926782, 0.9338222193477858], 
             UndirectedEdge[128, 162] -> 
             RGBColor[
              0.4413593088202362, 0.5567049827613839, 0.9493440027726809], 
             UndirectedEdge[23, 177] -> 
             RGBColor[
              0.22051380406985302`, 0.3491043678330853, 0.9358693069696149], 
             UndirectedEdge[11, 110] -> 
             RGBColor[
              0.1915413157937571, 0.3186524456930539, 0.9342193666232466], 
             UndirectedEdge[79, 177] -> 
             RGBColor[
              0.20578387384021699`, 0.33362227723022, 0.9350304592340161], 
             UndirectedEdge[8, 166] -> 
             RGBColor[
              0.543496783375643, 0.6308288867491243, 0.9602573693120857], 
             UndirectedEdge[162, 173] -> 
             RGBColor[
              0.40958261070654, 0.5291816039985865, 0.947319219667907], 
             UndirectedEdge[100, 137] -> 
             RGBColor[
              0.26484162639759284`, 0.3942953332387867, 0.9384449858803665], 
             UndirectedEdge[88, 117] -> 
             RGBColor[
              0.2009427964171618, 0.32853399791655225`, 0.9347547670365053], 
             UndirectedEdge[149, 168] -> 
             RGBColor[
              0.19745061882106624`, 0.32486349784620777`, 0.9345558926886215],
              UndirectedEdge[36, 110] -> 
             RGBColor[
              0.18133894646584242`, 0.3079291086618389, 0.9336383567830746], 
             UndirectedEdge[76, 104] -> 
             RGBColor[
              0.3156743455120887, 0.4437288821395802, 0.9414861054960099], 
             UndirectedEdge[4, 196] -> 
             RGBColor[
              0.28364684382762245`, 0.41309785549027966`, 0.9395511736411497],
              UndirectedEdge[61, 79] -> 
             RGBColor[
              0.20075917656457537`, 0.3283410018093128, 0.9347443101575417], 
             UndirectedEdge[76, 147] -> 
             RGBColor[
              0.2568865674353618, 0.38733444829663033`, 0.9379406820345992], 
             UndirectedEdge[2, 120] -> 
             RGBColor[
              0.18815579892545653`, 0.3150940528103027, 0.9340265664460203], 
             UndirectedEdge[87, 176] -> 
             RGBColor[
              0.22539540274629694`, 0.3542352375532605, 0.9361473067925603], 
             UndirectedEdge[142, 157] -> 
             RGBColor[
              0.2342114040964292, 0.3635014139390195, 0.9366493650273451], 
             UndirectedEdge[65, 191] -> 
             RGBColor[
              0.8832210777752071, 0.8579801148696197, 0.6332956147035969], 
             UndirectedEdge[73, 147] -> 
             RGBColor[
              0.23350195896282042`, 0.3627557421221772, 0.936608963176516], 
             UndirectedEdge[26, 120] -> 
             RGBColor[
              0.2433601504867005, 0.3731173264592187, 0.9371703725999135], 
             UndirectedEdge[113, 116] -> 
             RGBColor[
              0.22254054731904888`, 0.35123460349093416`, 0.9359847269993585],
              UndirectedEdge[35, 94] -> 
             RGBColor[
              0.1855941681935362, 0.31240161649428533`, 0.9338806853654305], 
             UndirectedEdge[31, 45] -> 
             RGBColor[0.62150237913985, 0.702550504593909, 0.964065451798632],
              UndirectedEdge[52, 82] -> 
             RGBColor[
              0.1987769890735687, 0.32625759707831903`, 0.9346314275123124], 
             UndirectedEdge[95, 162] -> 
             RGBColor[
              0.35030491508878375`, 0.4723326092435304, 0.9437436855582304], 
             UndirectedEdge[17, 73] -> 
             RGBColor[
              0.20447423008410437`, 0.33224575860633554`, 0.9349558769595496],
              UndirectedEdge[103, 152] -> 
             RGBColor[
              0.19063325078220003`, 0.31769801179126034`, 0.9341676536642003],
              UndirectedEdge[88, 103] -> 
             RGBColor[
              0.1988218402918387, 0.32630473855245234`, 0.9346339817228415], 
             UndirectedEdge[26, 170] -> 
             RGBColor[
              0.4739950942722979, 0.5778178834110607, 0.9531267757340784], 
             UndirectedEdge[89, 106] -> 
             RGBColor[
              0.22627244033588012`, 0.3551570596673073, 0.9361972527858261], 
             UndirectedEdge[19, 74] -> 
             RGBColor[
              0.34857360130161363`, 0.4763386664540116, 0.9434317795367738], 
             UndirectedEdge[117, 152] -> 
             RGBColor[
              0.19275420690752315`, 0.3199272711553603, 0.934288438977864], 
             UndirectedEdge[157, 176] -> 
             RGBColor[
              0.2202563614684182, 0.34883377933617365`, 0.9358546459943153], 
             UndirectedEdge[49, 139] -> 
             RGBColor[
              0.3540112919659183, 0.4789148116492719, 0.9438563899218253], 
             UndirectedEdge[48, 106] -> 
             RGBColor[
              0.1977618988532519, 0.32519067289632886`, 0.9345736196259569], 
             UndirectedEdge[69, 118] -> 
             RGBColor[
              0.32034074100661103`, 0.44643612012511674`, 0.9418323088423037],
              UndirectedEdge[117, 200] -> 
             RGBColor[
              0.1879682303409825, 0.3148969063354854, 0.9340158846926173], 
             UndirectedEdge[64, 153] -> 
             RGBColor[
              0.4558938520322939, 0.5620603632597695, 0.9516818031182084], 
             UndirectedEdge[73, 87] -> 
             RGBColor[
              0.2170911202155293, 0.3455069100915008, 0.9356743901875181], 
             UndirectedEdge[132, 138] -> 
             RGBColor[
              0.2612195562179643, 0.3918886942345018, 0.9381874393356859], 
             UndirectedEdge[6, 96] -> 
             RGBColor[
              0.8664275054943202, 0.4791091027601758, 0.4493272507526489], 
             UndirectedEdge[34, 65] -> 
             RGBColor[
              0.6931978672586998, 0.7056487590344823, 0.6167539284485017], 
             UndirectedEdge[2, 16] -> 
             RGBColor[
              0.1847745870823867, 0.3115401847820234, 0.9338340114336121], 
             UndirectedEdge[21, 122] -> 
             RGBColor[
              0.3196137188420707, 0.44840534441475405`, 0.941690823915208], 
             UndirectedEdge[90, 175] -> 
             RGBColor[
              0.36392094666961883`, 0.4808157727668374, 0.9450400242191717], 
             UndirectedEdge[6, 179] -> 
             RGBColor[
              0.6771354439642875, 0.3262866745071371, 0.4333904197295959], 
             UndirectedEdge[8, 137] -> 
             RGBColor[
              0.3035782978311935, 0.4350100309623244, 0.94065098201274], 
             UndirectedEdge[3, 127] -> 
             RGBColor[
              0.6467401961046771, 0.7200341503582268, 0.9679094614906981], 
             UndirectedEdge[31, 65] -> 
             RGBColor[
              0.7441501726839835, 0.7476457221603776, 0.6205905714253708], 
             UndirectedEdge[3, 71] -> 
             RGBColor[
              0.3912157938817601, 0.5132731904080172, 0.9461489023409704], 
             UndirectedEdge[146, 184] -> 
             RGBColor[
              0.21360634880243462`, 0.34184419438906943`, 0.9354759376107997],
              UndirectedEdge[33, 99] -> 
             RGBColor[
              0.772222119980282, 0.8191247933841846, 0.8648855062678112], 
             UndirectedEdge[10, 130] -> 
             RGBColor[
              0.2011228825880777, 0.32872327990030753`, 0.9347650226775253], 
             UndirectedEdge[112, 160] -> 
             RGBColor[
              0.6923008271636373, 0.757058105759987, 0.9667604504602199], 
             UndirectedEdge[73, 157] -> 
             RGBColor[
              0.21195207893765056`, 0.34010545187441393`, 0.9353817293892732],
              UndirectedEdge[157, 188] -> 
             RGBColor[
              0.25981363557951725`, 0.389998962820171, 0.9381224602941154], 
             UndirectedEdge[70, 132] -> 
             RGBColor[
              0.2458080236877891, 0.37569019639768786`, 0.9373097753574117], 
             UndirectedEdge[141, 191] -> 
             RGBColor[
              0.5769597398249082, 0.6618980623518022, 0.9624179176414562], 
             UndirectedEdge[26, 80] -> 
             RGBColor[
              0.25728770840867865`, 0.387756072893393, 0.9379635264195947], 
             UndirectedEdge[171, 199] -> 
             RGBColor[
              0.6515054495303574, 0.7165517677858011, 0.834521559813894], 
             UndirectedEdge[23, 43] -> 
             RGBColor[
              0.2066925124128154, 0.33457731398103385`, 0.9350822048565153], 
             UndirectedEdge[75, 81] -> 
             RGBColor[
              0.40408609146348656`, 0.52284397744725, 0.9473444744525996], 
             UndirectedEdge[33, 172] -> 
             RGBColor[
              0.9309821433575884, 0.7454031597804265, 0.49229878616950506`], 
             UndirectedEdge[156, 166] -> 
             RGBColor[
              0.8137215668820587, 0.378784797567889, 0.4373955442628925], 
             UndirectedEdge[151, 175] -> 
             RGBColor[
              0.7472372281358932, 0.7985860801048122, 0.8522647687143463], 
             UndirectedEdge[34, 199] -> 
             RGBColor[
              0.7126589375138983, 0.7696119149432428, 0.8384148348758003], 
             UndirectedEdge[38, 169] -> 
             RGBColor[
              0.18660872237456455`, 0.31346797726499653`, 0.9339384627251416],
              UndirectedEdge[10, 142] -> 
             RGBColor[
              0.23997415505154454`, 0.3695584305723596, 0.9369775451690128], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.2876001150236012, 0.4192043144804547, 0.9397048591920434], 
             UndirectedEdge[12, 128] -> 
             RGBColor[
              0.6907043727279983, 0.6939382045780004, 0.6137063255291655], 
             UndirectedEdge[19, 172] -> 
             RGBColor[
              0.610278699777892, 0.48910830355495916`, 0.5781436227882895], 
             UndirectedEdge[109, 124] -> 
             RGBColor[
              0.22172315170383133`, 0.35037546887346516`, 0.9359381775283004],
              UndirectedEdge[75, 127] -> 
             RGBColor[
              0.6884648603869374, 0.7548482631907685, 0.9709344134676849], 
             UndirectedEdge[4, 191] -> 
             RGBColor[
              0.57220556825359, 0.6577802378883374, 0.9621149860328806], 
             UndirectedEdge[68, 172] -> 
             RGBColor[
              0.9151660280486694, 0.6898326684829248, 0.25782304770604947`], 
             UndirectedEdge[97, 105] -> 
             RGBColor[
              0.21127795983773054`, 0.3393969099587784, 0.9353433393038026], 
             UndirectedEdge[120, 136] -> 
             RGBColor[
              0.208375147270767, 0.3363458699019528, 0.9351780284224404], 
             UndirectedEdge[117, 159] -> 
             RGBColor[
              0.22010744675454766`, 0.3486772605301575, 0.9358461655216599], 
             UndirectedEdge[183, 192] -> 
             RGBColor[
              0.7010491462692232, 0.6813089979740284, 0.609376618188938], 
             UndirectedEdge[71, 188] -> 
             RGBColor[
              0.33847048120912504`, 0.4675878516274786, 0.9427880176583188], 
             UndirectedEdge[14, 106] -> 
             RGBColor[
              0.1821436488572793, 0.3087749018963175, 0.9336841833938165], 
             UndirectedEdge[141, 194] -> 
             RGBColor[
              0.2726689215363932, 0.40068025183184497`, 0.9389581857778003], 
             UndirectedEdge[50, 105] -> 
             RGBColor[
              0.2047516184167667, 0.33253731133139974`, 0.9349716738147356], 
             UndirectedEdge[98, 125] -> 
             RGBColor[
              0.22839213728314284`, 0.35738499555542924`, 0.936317966391162], 
             UndirectedEdge[118, 119] -> 
             RGBColor[
              0.6948397253680805, 0.41161030980348123`, 0.44369144326806464`],
              UndirectedEdge[137, 166] -> 
             RGBColor[
              0.5638108664902101, 0.6507798896827761, 0.9614655012997908], 
             UndirectedEdge[6, 112] -> 
             RGBColor[
              0.8680923277857024, 0.48035072449919225`, 0.44650914086853377`],
              UndirectedEdge[65, 119] -> 
             RGBColor[
              0.8833301033443486, 0.5287471178897909, 0.2232772137600259], 
             UndirectedEdge[170, 183] -> 
             RGBColor[
              0.7957960380795266, 0.7580319632271744, 0.6169700142026149], 
             UndirectedEdge[14, 131] -> 
             RGBColor[
              0.18037616802655143`, 0.3069171674784653, 0.9335835279752602], 
             UndirectedEdge[9, 164] -> 
             RGBColor[
              0.1942433345387914, 0.32149243871196825`, 0.9343732425934977], 
             UndirectedEdge[96, 170] -> 
             RGBColor[
              0.7958122133360686, 0.8413363954975833, 0.9793915982124253], 
             UndirectedEdge[117, 178] -> 
             RGBColor[
              0.18448507974982858`, 0.3112358942196798, 0.9338175244193107], 
             UndirectedEdge[18, 24] -> 
             RGBColor[
              0.24010747998138166`, 0.3696985635269072, 0.9369851378265305], 
             UndirectedEdge[18, 133] -> 
             RGBColor[
              0.2360954570926359, 0.3654816730938921, 0.9367566590582723], 
             UndirectedEdge[49, 129] -> 
             RGBColor[
              0.4384127064842775, 0.5541214790792388, 0.9491648974977769], 
             UndirectedEdge[124, 198] -> 
             RGBColor[
              0.28583038245095216`, 0.4143466579357906, 0.9397138307273181], 
             UndirectedEdge[113, 124] -> 
             RGBColor[
              0.2152453236447654, 0.343566860865366, 0.9355692748034243], 
             UndirectedEdge[176, 188] -> 
             RGBColor[
              0.2736450723955902, 0.4045366798776089, 0.9389101401590136], 
             UndirectedEdge[37, 97] -> 
             RGBColor[
              0.22632286746697683`, 0.35521006177935477`, 0.9362001245363418],
              UndirectedEdge[77, 143] -> 
             RGBColor[
              0.8301002219971707, 0.3853333999300143, 0.43817702100433054`], 
             UndirectedEdge[79, 84] -> 
             RGBColor[
              0.1877064038111327, 0.31462171005185247`, 0.93400097405908], 
             UndirectedEdge[151, 199] -> 
             RGBColor[
              0.9945819459025071, 0.992027509640117, 0.7394547080773856], 
             UndirectedEdge[48, 87] -> 
             RGBColor[
              0.21359836729039067`, 0.3418358053138541, 0.9354754830754963], 
             UndirectedEdge[27, 30] -> 
             RGBColor[
              0.2380433427297828, 0.3675290244016161, 0.9368675882636692], 
             UndirectedEdge[5, 87] -> 
             RGBColor[
              0.28551854391053016`, 0.41321354140814925`, 0.9397255599553038],
              UndirectedEdge[68, 81] -> 
             RGBColor[
              0.6335105972347094, 0.659531932623991, 0.6218491817852485], 
             UndirectedEdge[155, 172] -> 
             RGBColor[
              0.77126540629573, 0.6221045625124598, 0.590374002869697], 
             UndirectedEdge[143, 188] -> 
             RGBColor[
              0.5844325062491007, 0.6667240315758246, 0.9636365087359027], 
             UndirectedEdge[102, 180] -> 
             RGBColor[
              0.6556042618622065, 0.7236026240031248, 0.9400383889234916], 
             UndirectedEdge[80, 136] -> 
             RGBColor[
              0.2223027051927452, 0.3509846163361272, 0.9359711822421215], 
             UndirectedEdge[66, 78] -> 
             RGBColor[
              0.18323872675967784`, 0.30992589820368766`, 0.9337465464603355],
              UndirectedEdge[50, 101] -> 
             RGBColor[
              0.19997052243961871`, 0.3275120763204238, 0.9346993974718347], 
             UndirectedEdge[41, 85] -> 
             RGBColor[
              0.2805891206818358, 0.4122473345873495, 0.9392905073772007], 
             UndirectedEdge[5, 30] -> 
             RGBColor[
              0.28195013969393246`, 0.40946292232661013`, 0.9395223446141496],
              UndirectedEdge[32, 133] -> 
             RGBColor[
              0.21756503028546625`, 0.3460050196226384, 0.9357013786649139], 
             UndirectedEdge[159, 161] -> 
             RGBColor[
              0.2693600530686908, 0.4004448725619264, 0.938651028588549], 
             UndirectedEdge[3, 195] -> 
             RGBColor[
              0.4598624133064091, 0.5714358988511051, 0.9508809666262504], 
             UndirectedEdge[173, 180] -> 
             RGBColor[
              0.35489305397250803`, 0.4818122587326137, 0.9438344494728906], 
             UndirectedEdge[129, 141] -> 
             RGBColor[
              0.399143413415432, 0.5201083911550634, 0.9466626928679024], 
             UndirectedEdge[53, 199] -> 
             RGBColor[
              0.8135219538922576, 0.8521286416727499, 0.8461806318478537], 
             UndirectedEdge[88, 95] -> 
             RGBColor[
              0.23288032783126497`, 0.3621023683892223, 0.9365735622031948], 
             UndirectedEdge[93, 95] -> 
             RGBColor[
              0.24029230513765162`, 0.36989282648473865`, 0.9369956633457557],
              UndirectedEdge[3, 29] -> 
             RGBColor[
              0.312801857714541, 0.4359396148470296, 0.9414971783112978], 
             UndirectedEdge[52, 125] -> 
             RGBColor[
              0.2249359881773202, 0.35375236371269986`, 0.9361211438124999], 
             UndirectedEdge[82, 136] -> 
             RGBColor[
              0.21738866266974544`, 0.34581964607616317`, 0.935691334790111], 
             UndirectedEdge[116, 193] -> 
             RGBColor[
              0.2350445249483884, 0.36437707677734155`, 0.9366968100273723], 
             UndirectedEdge[19, 159] -> 
             RGBColor[
              0.30305438553170616`, 0.43193305004791277`, 0.9407136467817967],
              UndirectedEdge[77, 99] -> 
             RGBColor[
              0.7288195657946002, 0.3050953090773723, 0.4287654977217741], 
             UndirectedEdge[53, 196] -> 
             RGBColor[
              0.43238466744803844`, 0.5370813339950793, 0.9503675109966372], 
             UndirectedEdge[58, 137] -> 
             RGBColor[
              0.6422345288762541, 0.7125398822624958, 0.9467383481519487], 
             UndirectedEdge[159, 200] -> 
             RGBColor[
              0.22275289923247676`, 0.35145779881583583`, 0.9359968201266817],
              UndirectedEdge[3, 62] -> 
             RGBColor[
              0.30929718741563983`, 0.43225598415395333`, 0.9412975925224704],
              UndirectedEdge[48, 157] -> 
             RGBColor[
              0.20845932601251194`, 0.33643434709676723`, 0.9351828222772515],
              UndirectedEdge[130, 168] -> 
             RGBColor[
              0.19684636692721422`, 0.32422839079398647`, 0.9345214814371772],
              UndirectedEdge[140, 180] -> 
             RGBColor[
              0.6678780579649132, 0.7298281943728316, 0.7506032971167013], 
             UndirectedEdge[146, 171] -> 
             RGBColor[
              0.27657700131279794`, 0.4080303427474302, 0.9390620231145327], 
             UndirectedEdge[26, 100] -> 
             RGBColor[
              0.24928654570499661`, 0.3793463435888073, 0.9375078720402794], 
             UndirectedEdge[45, 153] -> 
             RGBColor[
              0.49664985237205533`, 0.594095769360721, 0.9556096261521655], 
             UndirectedEdge[165, 177] -> 
             RGBColor[
              0.2115965510366421, 0.3397317695086831, 0.9353614826012671], 
             UndirectedEdge[123, 139] -> 
             RGBColor[
              0.36839624794676656`, 0.4913743375109727, 0.9447729865968078], 
             UndirectedEdge[13, 34] -> 
             RGBColor[
              0.32558157650060693`, 0.44832121227099686`, 0.9422634355654279],
              UndirectedEdge[48, 72] -> 
             RGBColor[
              0.23184751916348642`, 0.3610168209955353, 0.9365147452774683], 
             UndirectedEdge[127, 191] -> 
             RGBColor[
              0.8424455031847746, 0.8772870526462687, 0.9848132059143445], 
             UndirectedEdge[58, 125] -> 
             RGBColor[
              0.6124298936125201, 0.6826137072843086, 0.9449897432593624], 
             UndirectedEdge[165, 169] -> 
             RGBColor[
              0.1989480925621131, 0.32643743769336697`, 0.9346411716028602], 
             UndirectedEdge[119, 156] -> 
             RGBColor[
              0.8374564716001813, 0.28891243101531533`, 0.18350166554635475`],
              UndirectedEdge[139, 191] -> 
             RGBColor[
              0.5478858450843187, 0.6345820068720615, 0.9606434803219044], 
             UndirectedEdge[48, 81] -> 
             RGBColor[
              0.2582618049415859, 0.3887799101107659, 0.938018999776097], 
             UndirectedEdge[85, 161] -> 
             RGBColor[
              0.2771499717006646, 0.408632570953499, 0.939094652930488], 
             UndirectedEdge[30, 106] -> 
             RGBColor[
              0.19729813455436623`, 0.32470322721384515`, 0.9345472089352131],
              UndirectedEdge[118, 195] -> 
             RGBColor[
              0.44594964518515734`, 0.559385358380535, 0.9499944573441421], 
             UndirectedEdge[132, 145] -> 
             RGBColor[
              0.24537934999545682`, 0.37523963316756476`, 0.9372853630247993],
              UndirectedEdge[124, 137] -> 
             RGBColor[
              0.27496483242396785`, 0.4049354646208403, 0.9390214874876273], 
             UndirectedEdge[53, 182] -> 
             RGBColor[
              0.48630804661931654`, 0.5907915717188752, 0.9535469913567178], 
             UndirectedEdge[31, 40] -> 
             RGBColor[
              0.5188959987209247, 0.6203021736168226, 0.9552685402794356], 
             UndirectedEdge[130, 157] -> 
             RGBColor[
              0.19536013163296237`, 0.32266626326696746`, 0.9344368425358576],
              UndirectedEdge[83, 166] -> 
             RGBColor[
              0.8650576677002866, 0.8953688994003288, 0.9869563023793746], 
             UndirectedEdge[76, 176] -> 
             RGBColor[
              0.24916812422626491`, 0.3792218751063049, 0.9375011281122546], 
             UndirectedEdge[100, 113] -> 
             RGBColor[
              0.20512211761839033`, 0.33292672948331237`, 0.9349927731961636],
              UndirectedEdge[53, 118] -> 
             RGBColor[
              0.5113253166726569, 0.612460273634525, 0.9551410696826135], 
             UndirectedEdge[18, 85] -> 
             RGBColor[
              0.24676983740924385`, 0.376701123601449, 0.9373645492259726], 
             UndirectedEdge[90, 177] -> 
             RGBColor[
              0.22233026933066752`, 0.35101358799275084`, 0.9359727519789987],
              UndirectedEdge[55, 165] -> 
             RGBColor[
              0.2708407078314586, 0.3994925742335291, 0.9388272003702323], 
             UndirectedEdge[9, 121] -> 
             RGBColor[
              0.20533326031636837`, 0.3331486538461075, 0.9350047974604558], 
             UndirectedEdge[70, 110] -> 
             RGBColor[
              0.185588460386286, 0.31239561722696946`, 0.9338803603142515], 
             UndirectedEdge[51, 147] -> 
             RGBColor[
              0.2158606236854452, 0.3442135802203963, 0.9356043152304863], 
             UndirectedEdge[81, 188] -> 
             RGBColor[
              0.3096161145085913, 0.44234452583416967`, 0.9409586377929611], 
             UndirectedEdge[63, 132] -> 
             RGBColor[
              0.24611904809652904`, 0.37601710277136, 0.9373274877373701], 
             UndirectedEdge[68, 143] -> 
             RGBColor[
              0.9083269889752188, 0.8839114383656459, 0.6445270527281901], 
             UndirectedEdge[76, 81] -> 
             RGBColor[
              0.28513916633926595`, 0.41702972106286573`, 0.9395496257462019],
              UndirectedEdge[55, 163] -> 
             RGBColor[
              0.3088204539598367, 0.4394116954694417, 0.9409900907262441], 
             UndirectedEdge[86, 94] -> 
             RGBColor[
              0.19625374198187168`, 0.3236055044018397, 0.9344877323232499], 
             UndirectedEdge[3, 167] -> 
             RGBColor[
              0.3090133882504993, 0.4319576932374843, 0.9412814305798589], 
             UndirectedEdge[16, 82] -> 
             RGBColor[
              0.19957038496874147`, 0.32709150646835083`, 0.9346766102348185],
              UndirectedEdge[51, 107] -> 
             RGBColor[
              0.1999147758321102, 0.3274534831013933, 0.9346962227850067], 
             UndirectedEdge[53, 171] -> 
             RGBColor[
              0.4697666933739579, 0.5763722134005581, 0.9524963620713668], 
             UndirectedEdge[78, 82] -> 
             RGBColor[
              0.1974481944602994, 0.3248609496893285, 0.9345557546248622], 
             UndirectedEdge[92, 186] -> 
             RGBColor[
              0.21375750066891208`, 0.34200306458431906`, 0.9354845454859864],
              UndirectedEdge[75, 118] -> 
             RGBColor[
              0.44650486801296785`, 0.559836113284655, 0.9500381665189955], 
             UndirectedEdge[77, 83] -> 
             RGBColor[
              0.8536746611219712, 0.4041310177770272, 0.4404255720532042], 
             UndirectedEdge[42, 176] -> 
             RGBColor[
              0.21842899524564835`, 0.34691310157433214`, 0.9357505801912747],
              UndirectedEdge[20, 144] -> 
             RGBColor[
              0.19040607844928842`, 0.31745923926581243`, 0.9341547165359123],
              UndirectedEdge[26, 98] -> 
             RGBColor[
              0.24264169185428053`, 0.372362180883637, 0.9371294574436615], 
             UndirectedEdge[16, 84] -> 
             RGBColor[
              0.1842053187530256, 0.3109418476741682, 0.933801592444412], 
             UndirectedEdge[55, 175] -> 
             RGBColor[
              0.4182247539712943, 0.5353839569381427, 0.9482243963930945], 
             UndirectedEdge[113, 128] -> 
             RGBColor[
              0.3178799957707601, 0.44011084120794086`, 0.9418290717409573], 
             UndirectedEdge[142, 147] -> 
             RGBColor[
              0.25576128412159904`, 0.3861517041867828, 0.9378765988145878], 
             UndirectedEdge[10, 42] -> 
             RGBColor[
              0.2103603093846907, 0.3384324011502344, 0.9352910804680441], 
             UndirectedEdge[98, 120] -> 
             RGBColor[
              0.19321962278041294`, 0.32041645274683817`, 0.9343149437233039],
              UndirectedEdge[195, 199] -> 
             RGBColor[
              0.748146282404758, 0.7990537264187598, 0.8410340195093824], 
             UndirectedEdge[49, 195] -> 
             RGBColor[
              0.46169316726810605`, 0.5730216059163575, 0.9509976206498176], 
             UndirectedEdge[25, 43] -> 
             RGBColor[
              0.1846430806166806, 0.3114019631485748, 0.9338265223349365], 
             UndirectedEdge[91, 121] -> 
             RGBColor[
              0.2017936925772753, 0.329428343730764, 0.9348032243140356], 
             UndirectedEdge[8, 21] -> 
             RGBColor[
              0.3222839501803989, 0.4512119268537823, 0.9418428896396724], 
             UndirectedEdge[2, 124] -> 
             RGBColor[
              0.20420540017012767`, 0.331963201321945, 0.9349405674936471], 
             UndirectedEdge[80, 125] -> 
             RGBColor[
              0.243038153837541, 0.3727788875651853, 0.9371520353670952], 
             UndirectedEdge[33, 180] -> 
             RGBColor[
              0.6673282092975037, 0.7309455392481101, 0.857462764837877], 
             UndirectedEdge[5, 155] -> 
             RGBColor[
              0.513762074533002, 0.612974284551854, 0.9559298924776924], 
             UndirectedEdge[179, 192] -> 
             RGBColor[
              0.41712722923071616`, 0.5353797878648794, 0.9478929556641686], 
             UndirectedEdge[59, 146] -> 
             RGBColor[
              0.21481341413912597`, 0.34311289659029465`, 0.935544678196031], 
             UndirectedEdge[3, 68] -> 
             RGBColor[
              0.6898421419054424, 0.7085746089319662, 0.625429383133753], 
             UndirectedEdge[131, 157] -> 
             RGBColor[
              0.19396001666235732`, 0.3211946536604452, 0.9343571080595661], 
             UndirectedEdge[85, 200] -> 
             RGBColor[
              0.23054281786445055`, 0.35964549720740835`, 0.9364404444686207],
              UndirectedEdge[23, 38] -> 
             RGBColor[
              0.20238106508142, 0.3300457094741879, 0.9348366743092069], 
             UndirectedEdge[92, 191] -> 
             RGBColor[
              0.5272753016690297, 0.6129190189586639, 0.9594697403649703], 
             UndirectedEdge[97, 153] -> 
             RGBColor[
              0.24952804077433757`, 0.37960017021835646`, 0.9375216248272185],
              UndirectedEdge[95, 161] -> 
             RGBColor[
              0.26651291559129975`, 0.397452350554246, 0.9384888883211739], 
             UndirectedEdge[139, 196] -> 
             RGBColor[
              0.25932712065835106`, 0.3898996244740037, 0.9380796679301735], 
             UndirectedEdge[1, 94] -> 
             RGBColor[
              0.18516334977200538`, 0.3119487990177908, 0.933856150893663], 
             UndirectedEdge[189, 194] -> 
             RGBColor[
              0.19797673225113377`, 0.32541647641872684`, 0.9345858540701487],
              UndirectedEdge[42, 76] -> 
             RGBColor[
              0.23350932118742207`, 0.36276348028702554`, 0.9366093824443157],
              UndirectedEdge[84, 190] -> 
             RGBColor[
              0.18271061576572617`, 0.30937082006487343`, 0.9337164713205002],
              UndirectedEdge[37, 134] -> 
             RGBColor[
              0.24135977409579584`, 0.37101480404118925`, 0.9370564541237432],
              UndirectedEdge[140, 161] -> 
             RGBColor[
              0.6387756152014612, 0.7023172809495201, 0.7488332700746612], 
             UndirectedEdge[10, 51] -> 
             RGBColor[
              0.20007349461539067`, 0.32762030660597313`, 0.9347052615849112],
              UndirectedEdge[146, 191] -> 
             RGBColor[
              0.527753699812846, 0.6134218457400091, 0.9594969844315341], 
             UndirectedEdge[21, 175] -> 
             RGBColor[
              0.43093748007980026`, 0.5463950813331377, 0.9490344400593063], 
             UndirectedEdge[49, 141] -> 
             RGBColor[
              0.3830851867065078, 0.5062308671290127, 0.9456308272413769], 
             UndirectedEdge[111, 177] -> 
             RGBColor[
              0.21876304030867405`, 0.3472642041152524, 0.9357696035634386], 
             UndirectedEdge[69, 191] -> 
             RGBColor[
              0.5299588162079603, 0.6157395628837288, 0.9596225625480584], 
             UndirectedEdge[111, 175] -> 
             RGBColor[
              0.36035371764762536`, 0.477066388889339, 0.9448368758036116], 
             UndirectedEdge[77, 170] -> 
             RGBColor[
              0.7632819896613426, 0.3329422374087012, 0.4315682217159619], 
             UndirectedEdge[104, 154] -> 
             RGBColor[
              0.3494855423442635, 0.47712854394966536`, 0.9434898876136137], 
             UndirectedEdge[13, 138] -> 
             RGBColor[
              0.2214898027052646, 0.35013020428079056`, 0.9359248886480409], 
             UndirectedEdge[21, 67] -> 
             RGBColor[
              0.30859689738128643`, 0.43682596655264533`, 0.9410634322309431],
              UndirectedEdge[73, 197] -> 
             RGBColor[
              0.20909257444253643`, 0.33709993134699245`, 0.9352188848385342],
              UndirectedEdge[67, 192] -> 
             RGBColor[
              0.36080214724091136`, 0.4817069445731053, 0.944482904164054], 
             UndirectedEdge[37, 101] -> 
             RGBColor[
              0.21602037207300215`, 0.3443814859043514, 0.9356134126648311], 
             UndirectedEdge[6, 44] -> 
             RGBColor[
              0.8538799874745917, 0.37282166416447404`, 0.1975713412337775], 
             UndirectedEdge[75, 89] -> 
             RGBColor[
              0.3848285553772075, 0.5026030860222612, 0.9462477862614576], 
             UndirectedEdge[76, 188] -> 
             RGBColor[
              0.288725398337364, 0.42038705859030223`, 0.9397689424120548], 
             UndirectedEdge[42, 71] -> 
             RGBColor[
              0.2832544040591832, 0.40996427332420193`, 0.9396284576905798], 
             UndirectedEdge[6, 192] -> 
             RGBColor[
              0.7095267480527575, 0.35411800374375885`, 0.4355163647005046], 
             UndirectedEdge[2, 100] -> 
             RGBColor[
              0.19408219414375266`, 0.32132306993989135`, 0.9343640658863862],
              UndirectedEdge[7, 8] -> 
             RGBColor[
              0.24587927343278695`, 0.3757650843971754, 0.9373138329249848], 
             UndirectedEdge[69, 92] -> 
             RGBColor[
              0.2471305318648358, 0.3770802363436254, 0.937385090241619], 
             UndirectedEdge[104, 160] -> 
             RGBColor[
              0.4051454853105788, 0.5253383889970118, 0.9470364899612722], 
             UndirectedEdge[17, 30] -> 
             RGBColor[
              0.20051771286008008`, 0.3280872081462052, 0.9347305591567843], 
             UndirectedEdge[88, 164] -> 
             RGBColor[
              0.20586798703479003`, 0.3337106855308008, 0.9350352493560126], 
             UndirectedEdge[43, 60] -> 
             RGBColor[
              0.18536402715025152`, 0.3121597236660082, 0.9338675791734785], 
             UndirectedEdge[149, 197] -> 
             RGBColor[
              0.19310487903170026`, 0.3202958497917673, 0.934308409236563], 
             UndirectedEdge[167, 197] -> 
             RGBColor[
              0.20001986015557813`, 0.327563933388089, 0.9347022071817699], 
             UndirectedEdge[54, 127] -> 
             RGBColor[
              0.9315900923682865, 0.9377519849577597, 0.6986638549616266], 
             UndirectedEdge[107, 147] -> 
             RGBColor[
              0.23357883684934996`, 0.36283654565525925`, 0.9366133412584232],
              UndirectedEdge[78, 113] -> 
             RGBColor[
              0.19369232004858233`, 0.320913287546422, 0.9343418631334333], 
             UndirectedEdge[81, 87] -> 
             RGBColor[
              0.261366444859298, 0.3920430835098213, 0.9381958044265076], 
             UndirectedEdge[83, 179] -> 
             RGBColor[
              0.6474631282319623, 0.7188859236705143, 0.9687723771837091], 
             UndirectedEdge[82, 198] -> 
             RGBColor[
              0.2787942966052594, 0.4069512855983587, 0.9393131360473621], 
             UndirectedEdge[30, 107] -> 
             RGBColor[
              0.21359959388546113`, 0.3418370945430438, 0.935475552928271], 
             UndirectedEdge[47, 134] -> 
             RGBColor[
              0.22156708062371444`, 0.3502114282727843, 0.9359292895111742], 
             UndirectedEdge[5, 142] -> 
             RGBColor[
              0.3081659820767354, 0.43701743485134614`, 0.9410152980549868], 
             UndirectedEdge[169, 190] -> 
             RGBColor[
              0.18813962732028144`, 0.31507705542792475`, 0.9340256454970293],
              UndirectedEdge[121, 152] -> 
             RGBColor[
              0.20876932330272832`, 0.33676017390374813`, 0.9352004761643293],
              UndirectedEdge[31, 64] -> 
             RGBColor[
              0.5807463788000884, 0.6705150984929575, 0.9601376287646749], 
             UndirectedEdge[105, 134] -> 
             RGBColor[
              0.22631486646654955`, 0.35520165222061295`, 0.936199668891204], 
             UndirectedEdge[83, 192] -> 
             RGBColor[
              0.6960500843646674, 0.7606329175254469, 0.9719612946400722], 
             UndirectedEdge[77, 112] -> 
             RGBColor[
              0.8586829748540853, 0.4080263146620374, 0.43749873387487304`], 
             UndirectedEdge[195, 196] -> 
             RGBColor[
              0.3670089959605389, 0.4840064187410893, 0.9452208986581658], 
             UndirectedEdge[92, 171] -> 
             RGBColor[
              0.2760986031689815, 0.40752751596608494`, 0.939034779047969], 
             UndirectedEdge[166, 183] -> 
             RGBColor[
              0.8700567296048425, 0.8160449798489104, 0.6243716259282402], 
             UndirectedEdge[139, 195] -> 
             RGBColor[
              0.39334997945867106`, 0.5116924625124413, 0.9467209787003914], 
             UndirectedEdge[177, 190] -> 
             RGBColor[
              0.20078808579481044`, 0.3283713872432409, 0.9347459564954362], 
             UndirectedEdge[29, 149] -> 
             RGBColor[
              0.19620729298920309`, 0.32355668356550876`, 0.9344850871218325],
              UndirectedEdge[119, 155] -> 
             RGBColor[
              0.7889472696492774, 0.4888266448097398, 0.4510028591049925], 
             UndirectedEdge[12, 162] -> 
             RGBColor[
              0.7007570533940699, 0.7026453313085301, 0.614346873451971], 
             UndirectedEdge[85, 173] -> 
             RGBColor[
              0.31911259241838086`, 0.4472823241494562, 0.941684119139965], 
             UndirectedEdge[92, 141] -> 
             RGBColor[
              0.29413145548178377`, 0.42323873581169885`, 0.9401804453350167],
              UndirectedEdge[5, 29] -> 
             RGBColor[
              0.28062241209504013`, 0.4080673964373824, 0.9394467324915896], 
             UndirectedEdge[51, 87] -> 
             RGBColor[
              0.19944978493815407`, 0.3269647481897199, 0.9346697422414884], 
             UndirectedEdge[145, 153] -> 
             RGBColor[
              0.2362249636187789, 0.3656177926640565, 0.9367640342633485], 
             UndirectedEdge[118, 191] -> 
             RGBColor[
              0.6004855108108049, 0.6822749027401551, 0.9639169589656551], 
             UndirectedEdge[117, 164] -> 
             RGBColor[
              0.19024796848068162`, 0.3172930556640557, 0.9341457124071029], 
             UndirectedEdge[145, 185] -> 
             RGBColor[
              0.2111217144827195, 0.33923268618413416`, 0.935334441361979], 
             UndirectedEdge[99, 137] -> 
             RGBColor[
              0.4378565391647805, 0.5509964805640466, 0.9498598035828838], 
             UndirectedEdge[48, 176] -> 
             RGBColor[
              0.2222907628285849, 0.3509720641542051, 0.9359705021421497], 
             UndirectedEdge[50, 144] -> 
             RGBColor[
              0.20111766579178803`, 0.32871779671664314`, 0.9347647255886942],
              UndirectedEdge[3, 53] -> 
             RGBColor[
              0.5252380847939087, 0.6245108141050952, 0.9560275789647218], 
             UndirectedEdge[169, 177] -> 
             RGBColor[
              0.20474146136299756`, 0.33252663562389395`, 0.9349710953855495],
              UndirectedEdge[20, 135] -> 
             RGBColor[
              0.18962988067563263`, 0.3166434061919189, 0.9341105132209843], 
             UndirectedEdge[166, 170] -> 
             RGBColor[
              0.7294686605093437, 0.78858572884784, 0.973670276873511], 
             UndirectedEdge[17, 42] -> 
             RGBColor[
              0.1971197095760292, 0.3245156912488159, 0.9345370478966529], 
             UndirectedEdge[129, 195] -> 
             RGBColor[
              0.47775139397703026`, 0.5868991299424082, 0.952029486276343], 
             UndirectedEdge[74, 93] -> 
             RGBColor[
              0.28865865838495014`, 0.4172909648985178, 0.9398759363681078], 
             UndirectedEdge[37, 45] -> 
             RGBColor[
              0.47344467906469456`, 0.5697056609217193, 0.9542881258612889], 
             UndirectedEdge[49, 92] -> 
             RGBColor[
              0.33340074855062923`, 0.45725182373587436`, 0.9426826499648912],
              UndirectedEdge[163, 177] -> 
             RGBColor[
              0.24957629716502022`, 0.3796508907445958, 0.937524372957279], 
             UndirectedEdge[6, 45] -> 
             RGBColor[
              0.7913030137482814, 0.4198062262063331, 0.4424336661544295], 
             UndirectedEdge[6, 166] -> 
             RGBColor[
              0.8221984702765036, 0.44394199166034687`, 0.44551303652670615`],
              UndirectedEdge[65, 127] -> 
             RGBColor[
              0.9155629949478274, 0.8836888220171212, 0.6364016079465316], 
             UndirectedEdge[15, 59] -> 
             RGBColor[
              0.18157500733235693`, 0.30817722359966904`, 0.9336518001002019],
              UndirectedEdge[100, 136] -> 
             RGBColor[
              0.21430154248906313`, 0.3425748870315415, 0.9355155278628062], 
             UndirectedEdge[83, 183] -> 
             RGBColor[
              0.9313850452704695, 0.8648151337796632, 0.6302560397084783], 
             UndirectedEdge[53, 119] -> 
             RGBColor[
              0.7751449794102145, 0.4779361855721358, 0.4497010195498735], 
             UndirectedEdge[5, 68] -> 
             RGBColor[
              0.6576626962859415, 0.680702390522319, 0.6233789373140448], 
             UndirectedEdge[49, 54] -> 
             RGBColor[
              0.7053736220772657, 0.7563760825874686, 0.6787707713186126], 
             UndirectedEdge[153, 185] -> 
             RGBColor[
              0.2571534731580585, 0.38761498313398474`, 0.937955881920655], 
             UndirectedEdge[101, 144] -> 
             RGBColor[
              0.19734151181877715`, 0.32474881946901846`, 0.9345496792062504],
              UndirectedEdge[19, 102] -> 
             RGBColor[
              0.6601961515617699, 0.7275798880657995, 0.9403309800746991], 
             UndirectedEdge[102, 172] -> 
             RGBColor[
              0.9192581959222914, 0.7380602445354411, 0.5748744102551196], 
             UndirectedEdge[102, 140] -> 
             RGBColor[
              0.981449443808876, 0.9827573994159884, 0.747626675734739], 
             UndirectedEdge[71, 107] -> 
             RGBColor[
              0.2906858024537879, 0.41777514421480366`, 0.9400516648353837], 
             UndirectedEdge[5, 168] -> 
             RGBColor[
              0.2818657379269033, 0.4093742107180814, 0.9395175380583785], 
             UndirectedEdge[79, 122] -> 
             RGBColor[
              0.2360507899414387, 0.3654347250859229, 0.9367541153300909], 
             UndirectedEdge[136, 198] -> 
             RGBColor[
              0.2842178470642151, 0.4126517810036814, 0.9396219992225757], 
             UndirectedEdge[97, 135] -> 
             RGBColor[
              0.20686780943909605`, 0.33476156227012827`, 0.9350921877628332],
              UndirectedEdge[19, 164] -> 
             RGBColor[
              0.2731949072578401, 0.40054884518181094`, 0.9390131936672395], 
             UndirectedEdge[118, 139] -> 
             RGBColor[
              0.33826776988296947`, 0.4652785641134494, 0.9428532266161497], 
             UndirectedEdge[26, 137] -> 
             RGBColor[
              0.3083373002531643, 0.4400120442459969, 0.9409220001603581], 
             UndirectedEdge[142, 168] -> 
             RGBColor[
              0.23569763939068106`, 0.3650635414660385, 0.9367340039286646], 
             UndirectedEdge[3, 194] -> 
             RGBColor[
              0.3101074606435417, 0.43310763269076813`, 0.9413437363841075], 
             UndirectedEdge[65, 195] -> 
             RGBColor[
              0.7286852121495595, 0.7350905705099995, 0.6193731130820839], 
             UndirectedEdge[73, 107] -> 
             RGBColor[
              0.21755611110948542`, 0.34599564500317415`, 0.9357008707310365],
              UndirectedEdge[162, 172] -> 
             RGBColor[
              0.6603763668123606, 0.5325003847582571, 0.5813358018320983], 
             UndirectedEdge[68, 140] -> 
             RGBColor[
              0.977357275935254, 0.934529823363472, 0.4305753131856688], 
             UndirectedEdge[38, 165] -> 
             RGBColor[
              0.19346381204820906`, 0.3206731111497857, 0.9343288499408593], 
             UndirectedEdge[86, 92] -> 
             RGBColor[
              0.22327186579105107`, 0.35200326557327766`, 0.9360263745044504],
              UndirectedEdge[90, 115] -> 
             RGBColor[
              0.27114794471103404`, 0.4017434985665935, 0.9387741035720105], 
             UndirectedEdge[11, 70] -> 
             RGBColor[
              0.19700340773557554`, 0.3243934506405365, 0.9345304246788922], 
             UndirectedEdge[54, 123] -> 
             RGBColor[
              0.7197585780581139, 0.7688356084491694, 0.6796873679935951], 
             UndirectedEdge[107, 176] -> 
             RGBColor[
              0.22586039364025307`, 0.35472397246493387`, 0.9361737873360787],
              UndirectedEdge[30, 76] -> 
             RGBColor[
              0.23690732447147297`, 0.36633499718441476`, 0.936802893704447], 
             UndirectedEdge[129, 191] -> 
             RGBColor[
              0.632287259602678, 0.7097886743020284, 0.965951987897856], 
             UndirectedEdge[7, 125] -> 
             RGBColor[
              0.2363887212836201, 0.36578991235264013`, 0.9367733600201034], 
             UndirectedEdge[3, 155] -> 
             RGBColor[
              0.545941520152503, 0.6408465029615011, 0.9579803382974005], 
             UndirectedEdge[54, 118] -> 
             RGBColor[
              0.6896300999943169, 0.7427398350516461, 0.6777676080129371], 
             UndirectedEdge[4, 171] -> 
             RGBColor[
              0.3210288697535419, 0.4523887348957585, 0.9416800247158792], 
             UndirectedEdge[167, 189] -> 
             RGBColor[
              0.19688265985809134`, 0.32426653696544305`, 0.9345235482659], 
             UndirectedEdge[42, 81] -> 
             RGBColor[
              0.25440003735864936`, 0.3847209475308929, 0.9377990778252221], 
             UndirectedEdge[5, 129] -> 
             RGBColor[
              0.40440250690307966`, 0.5246635536043394, 0.9469977976545015], 
             UndirectedEdge[115, 133] -> 
             RGBColor[
              0.2820742314375166, 0.41322771868271746`, 0.939396339437091], 
             UndirectedEdge[92, 146] -> 
             RGBColor[
              0.24492541546972163`, 0.3747625191999059, 0.9372595121250946], 
             UndirectedEdge[65, 151] -> 
             RGBColor[
              0.9751208756473086, 0.9280643537313567, 0.5177938016500871], 
             UndirectedEdge[45, 156] -> 
             RGBColor[
              0.7828261103538363, 0.35464903211387533`, 0.43431617389061594`],
              UndirectedEdge[74, 172] -> 
             RGBColor[
              0.607635645662135, 0.48681902292365303`, 0.5779752097171944], 
             UndirectedEdge[31, 138] -> 
             RGBColor[
              0.3769176966090809, 0.4907215889641815, 0.9461219362207016], 
             UndirectedEdge[116, 198] -> 
             RGBColor[
              0.29312560612523564`, 0.42201440056135886`, 0.9401292829232522],
              UndirectedEdge[42, 142] -> 
             RGBColor[
              0.23238403787365935`, 0.361580736177178, 0.9365452992243044], 
             UndirectedEdge[10, 129] -> 
             RGBColor[
              0.3362106798778888, 0.4572045493253528, 0.9429600447685274], 
             UndirectedEdge[3, 141] -> 
             RGBColor[
              0.38125443274481086`, 0.5046451600637603, 0.9455141732178098], 
             UndirectedEdge[161, 162] -> 
             RGBColor[
              0.3676199899888237, 0.4905318508026293, 0.94472975345843], 
             UndirectedEdge[6, 77] -> 
             RGBColor[
              0.8267283529316172, 0.20645140983715485`, 0.1732284069936607], 
             UndirectedEdge[98, 113] -> 
             RGBColor[
              0.19847726376767427`, 0.32594256677814204`, 0.9346143585995457],
              UndirectedEdge[3, 139] -> 
             RGBColor[
              0.3521805380042213, 0.47732910458401956`, 0.943739735898258], 
             UndirectedEdge[34, 138] -> 
             RGBColor[
              0.32596539118379714`, 0.4487246258382862, 0.9422852932438326], 
             UndirectedEdge[22, 72] -> 
             RGBColor[
              0.22084536933385682`, 0.34945286394800523`, 0.935888189120893], 
             UndirectedEdge[34, 40] -> 
             RGBColor[
              0.4679436932956409, 0.5783052104909272, 0.9514318973025666], 
             UndirectedEdge[41, 74] -> 
             RGBColor[
              0.31831841781976944`, 0.44846525260187575`, 0.9415650157902389],
              UndirectedEdge[141, 146] -> 
             RGBColor[
              0.2946098536256002, 0.4237415625930442, 0.9402076894015805], 
             UndirectedEdge[90, 111] -> 
             RGBColor[
              0.22370338980181498`, 0.3524568246687931, 0.9360509491584807], 
             UndirectedEdge[66, 82] -> 
             RGBColor[
              0.1977556445101682, 0.32518409918519964`, 0.9345732634503707], 
             UndirectedEdge[119, 151] -> 
             RGBColor[
              0.895851640750381, 0.5712020975503805, 0.3785504037028946], 
             UndirectedEdge[4, 139] -> 
             RGBColor[
              0.30998782732575464`, 0.44078389926163164`, 0.9410512536833753],
              UndirectedEdge[165, 175] -> 
             RGBColor[
              0.35318722837559335`, 0.4695339542827697, 0.9444287548414402], 
             UndirectedEdge[127, 139] -> 
             RGBColor[
              0.5802277622569392, 0.660290714019563, 0.9637494735648391], 
             UndirectedEdge[85, 117] -> 
             RGBColor[
              0.22789736538652144`, 0.3568649589217301, 0.9362897898635989], 
             UndirectedEdge[141, 155] -> 
             RGBColor[
              0.5085029810453545, 0.6084191221025781, 0.9555947876910933], 
             UndirectedEdge[168, 189] -> 
             RGBColor[
              0.2019144551539962, 0.3295552728556873, 0.9348101015641277], 
             UndirectedEdge[24, 175] -> 
             RGBColor[
              0.3788592562848471, 0.49651688331597643`, 0.9458907388525104], 
             UndirectedEdge[106, 176] -> 
             RGBColor[
              0.20955893430915817`, 0.33759010513573523`, 0.9352454433430207],
              UndirectedEdge[40, 53] -> 
             RGBColor[
              0.5688067096740002, 0.6608219372204345, 0.9591976942746201], 
             UndirectedEdge[27, 155] -> 
             RGBColor[
              0.4698552775688525, 0.57104038662686, 0.953275136127212], 
             UndirectedEdge[33, 77] -> 
             RGBColor[
              0.8757538475255878, 0.41982388651208413`, 0.36678217312343336`],
              UndirectedEdge[67, 137] -> 
             RGBColor[
              0.289891245032081, 0.42062407066118745`, 0.9398715246040107], 
             UndirectedEdge[68, 129] -> 
             RGBColor[
              0.7077311225760636, 0.7240378400232692, 0.6265779027838456], 
             UndirectedEdge[137, 192] -> 
             RGBColor[
              0.3948032831545909, 0.5160439078078941, 0.9464704935604884], 
             UndirectedEdge[58, 128] -> 
             RGBColor[
              0.695941652480456, 0.7590582933299347, 0.9501605185766638], 
             UndirectedEdge[55, 90] -> 
             RGBColor[
              0.281574426125484, 0.41077439271759675`, 0.9394384697479637], 
             UndirectedEdge[26, 82] -> 
             RGBColor[
              0.2523736658856789, 0.382591102633429, 0.9376836789675842], 
             UndirectedEdge[43, 165] -> 
             RGBColor[
              0.19777525937960444`, 0.32520471565663167`, 0.9345743804881674],
              UndirectedEdge[123, 199] -> 
             RGBColor[
              0.7231925508928534, 0.7787356014172913, 0.8390860274057987], 
             UndirectedEdge[34, 45] -> 
             RGBColor[
              0.5705500737145661, 0.6605535414680137, 0.960228808821763], 
             UndirectedEdge[133, 178] -> 
             RGBColor[
              0.21638528695668868`, 0.3447650345840459, 0.9356341940276138], 
             UndirectedEdge[29, 189] -> 
             RGBColor[
              0.20067112932213305`, 0.3282484585749883, 0.9347392959973388], 
             UndirectedEdge[91, 164] -> 
             RGBColor[
              0.19070376679969833`, 0.3177721285966248, 0.9341716694470776], 
             UndirectedEdge[116, 124] -> 
             RGBColor[
              0.2333325075764587, 0.3625776379712726, 0.9365993131707435], 
             UndirectedEdge[80, 113] -> 
             RGBColor[
              0.2131232803220724, 0.34133645878789803`, 0.9354484275754789], 
             UndirectedEdge[10, 75] -> 
             RGBColor[
              0.3600463634895279, 0.4765554310665914, 0.9448364770954216], 
             UndirectedEdge[74, 180] -> 
             RGBColor[
              0.34398171160205027`, 0.4723614023913367, 0.9431391883855662], 
             UndirectedEdge[27, 149] -> 
             RGBColor[
              0.2260121645429709, 0.35488349330652136`, 0.9361824304644635], 
             UndirectedEdge[4, 49] -> 
             RGBColor[
              0.37833101513518963`, 0.5021130426655478, 0.9453278956328015], 
             UndirectedEdge[9, 152] -> 
             RGBColor[
              0.19674957296563292`, 0.32412665420327286`, 0.9345159691642588],
              UndirectedEdge[19, 85] -> 
             RGBColor[
              0.31084430416368, 0.44012074843948534`, 0.9411572711237357], 
             UndirectedEdge[189, 197] -> 
             RGBColor[
              0.19756871536463022`, 0.3249876248012469, 0.9345626181120692], 
             UndirectedEdge[69, 195] -> 
             RGBColor[
              0.3754229505823126, 0.4928500185241086, 0.9457000609265455], 
             UndirectedEdge[75, 191] -> 
             RGBColor[
              0.656122943214317, 0.729139556043267, 0.9678284202247502], 
             UndirectedEdge[73, 75] -> 
             RGBColor[
              0.3598107668197179, 0.47630780402892936`, 0.9448230602136101], 
             UndirectedEdge[68, 188] -> 
             RGBColor[
              0.6370968292328074, 0.6628892701514275, 0.6220684984511013], 
             UndirectedEdge[4, 123] -> 
             RGBColor[
              0.39271597111603795`, 0.5145725685272486, 0.946244492307784], 
             UndirectedEdge[7, 84] -> 
             RGBColor[
              0.19486465596415276`, 0.32214548692407674`, 0.9344086259295095],
              UndirectedEdge[171, 195] -> 
             RGBColor[
              0.4043910218864583, 0.5232972981465681, 0.9473497497328954], 
             UndirectedEdge[62, 167] -> 
             RGBColor[
              0.19961760381417978`, 0.3271411364687542, 0.9346792992782123], 
             UndirectedEdge[91, 152] -> 
             RGBColor[
              0.19321000522653986`, 0.3204063440879294, 0.9343143960178388], 
             UndirectedEdge[38, 90] -> 
             RGBColor[
              0.20419753034223448`, 0.33195492963385337`, 0.9349401193185908],
              UndirectedEdge[3, 118] -> 
             RGBColor[
              0.40478020373070756`, 0.5250220004521133, 0.9470132145420087], 
             UndirectedEdge[143, 181] -> 
             RGBColor[
              0.6469177981644729, 0.7208456508308313, 0.967618016283176], 
             UndirectedEdge[20, 50] -> 
             RGBColor[
              0.19303508907013, 0.32022249611721776`, 0.9343044348014965], 
             UndirectedEdge[128, 136] -> 
             RGBColor[
              0.3270594206414329, 0.44975899875617, 0.9423518264076001], 
             UndirectedEdge[19, 161] -> 
             RGBColor[
              0.3175223229543551, 0.44713976959933127`, 0.9415375744146212], 
             UndirectedEdge[19, 140] -> 
             RGBColor[
              0.6724699476644765, 0.7338054584355065, 0.7508958882679089], 
             UndirectedEdge[39, 159] -> 
             RGBColor[
              0.25347717812255377`, 0.3837509639611013, 0.9377465223569743], 
             UndirectedEdge[87, 154] -> 
             RGBColor[
              0.2742869255202454, 0.40348527807603907`, 0.9390098911632051], 
             UndirectedEdge[104, 143] -> 
             RGBColor[
              0.6113814534238254, 0.6900658551251025, 0.9653536718198579], 
             UndirectedEdge[6, 183] -> 
             RGBColor[
              0.8664167219899589, 0.42357281457990315`, 0.20771286141277537`],
              UndirectedEdge[17, 89] -> 
             RGBColor[
              0.229492018641594, 0.35854104059966735`, 0.9363806030073972], 
             UndirectedEdge[131, 176] -> 
             RGBColor[
              0.20779145347843028`, 0.335732370717883, 0.9351447879244643], 
             UndirectedEdge[44, 143] -> 
             RGBColor[
              0.8772182848102179, 0.7604919813860003, 0.611670932866671], 
             UndirectedEdge[140, 173] -> 
             RGBColor[
              0.6807382359191774, 0.7409670341454773, 0.7514227362841381], 
             UndirectedEdge[123, 195] -> 
             RGBColor[
              0.4760781232489544, 0.5854811317780583, 0.9519142173248001], 
             UndirectedEdge[96, 125] -> 
             RGBColor[
              0.600349784053201, 0.6736043813543324, 0.9654382177461185], 
             UndirectedEdge[95, 159] -> 
             RGBColor[
              0.2520449781686508, 0.3822456310028275, 0.9376649606883494], 
             UndirectedEdge[171, 191] -> 
             RGBColor[
              0.558926887512106, 0.6461868425061883, 0.9612722513544084], 
             UndirectedEdge[124, 187] -> 
             RGBColor[
              0.21475919139226923`, 0.3430559050454275, 0.935541590290813], 
             UndirectedEdge[54, 191] -> 
             RGBColor[
              0.899248175195666, 0.9120432778102582, 0.6955578617186919], 
             UndirectedEdge[24, 55] -> 
             RGBColor[
              0.29651273574071235`, 0.4264755032667358, 0.9402891843813024], 
             UndirectedEdge[61, 126] -> 
             RGBColor[
              0.19350305800530745`, 0.3207143611390335, 0.9343310849400568], 
             UndirectedEdge[46, 101] -> 
             RGBColor[
              0.18958670352767176`, 0.3165980242718227, 0.9341080543462827], 
             UndirectedEdge[158, 176] -> 
             RGBColor[
              0.27521608284831744`, 0.40589741017048, 0.9390102435558715], 
             UndirectedEdge[91, 200] -> 
             RGBColor[
              0.18842402865999922`, 0.3153759792680545, 0.9340418417325922], 
             UndirectedEdge[29, 129] -> 
             RGBColor[
              0.33069083838516217`, 0.4514028459383327, 0.9426456979613903], 
             UndirectedEdge[37, 47] -> 
             RGBColor[
              0.21605368220731502`, 0.34441649696749876`, 0.9356153096277022],
              UndirectedEdge[25, 38] -> 
             RGBColor[
              0.18033163328528526`, 0.30687035864172885`, 0.9335809917876283],
              UndirectedEdge[95, 173] -> 
             RGBColor[
              0.308475536309016, 0.4361021037502032, 0.9410783545306509], 
             UndirectedEdge[86, 174] -> 
             RGBColor[
              0.19606494632876875`, 0.3234070682000927, 0.9344769806901039], 
             UndirectedEdge[4, 146] -> 
             RGBColor[
              0.289855682054282, 0.41962373812957937`, 0.9399047577930049], 
             UndirectedEdge[114, 186] -> 
             RGBColor[
              0.18224157379578187`, 0.3088778272154834, 0.9336897600741974], 
             UndirectedEdge[155, 199] -> 
             RGBColor[
              0.8342253892508518, 0.868464330529156, 0.8481333911805324], 
             UndirectedEdge[114, 194] -> 
             RGBColor[
              0.19146855650738448`, 0.3185759710698711, 0.9342152230895253], 
             UndirectedEdge[59, 186] -> 
             RGBColor[
              0.18364549933831636`, 0.3103534419747078, 0.9337697115569229], 
             UndirectedEdge[99, 193] -> 
             RGBColor[
              0.3906410080149175, 0.5027703500949796, 0.9471196739266945], 
             UndirectedEdge[109, 136] -> 
             RGBColor[
              0.22011061631709428`, 0.3486805919413559, 0.935846346023558], 
             UndirectedEdge[50, 134] -> 
             RGBColor[
              0.22530992446241244`, 0.3541453944572617, 0.9361424389307468], 
             UndirectedEdge[112, 183] -> 
             RGBColor[
              0.9388975158686406, 0.8706580791071786, 0.6258657824409817], 
             UndirectedEdge[42, 73] -> 
             RGBColor[
              0.2101247127148807, 0.3381847741125724, 0.9352776635862325], 
             UndirectedEdge[42, 147] -> 
             RGBColor[
              0.22614743845474522`, 0.3550256747646575, 0.9361901341136192], 
             UndirectedEdge[87, 131] -> 
             RGBColor[
              0.19909905794023608`, 0.326596111877532, 0.934649768857811], 
             UndirectedEdge[1, 11] -> 
             RGBColor[
              0.19143609648975546`, 0.318541853533259, 0.9342133745395418], 
             UndirectedEdge[30, 81] -> 
             RGBColor[
              0.2577980406427003, 0.3882924644282822, 0.9379925890853533], 
             UndirectedEdge[154, 188] -> 
             RGBColor[
              0.3225365951695387, 0.45378672040038737`, 0.9417727245296585], 
             UndirectedEdge[83, 156] -> 
             RGBColor[
              0.8546071106591433, 0.41129823352172423`, 0.4413184867830513], 
             UndirectedEdge[5, 107] -> 
             RGBColor[
              0.28598353480448624`, 0.4137022763198226, 0.9397520404988222], 
             UndirectedEdge[93, 180] -> 
             RGBColor[
              0.28670982280114365`, 0.41560298146714914`, 0.9397517582879953],
              UndirectedEdge[10, 17] -> 
             RGBColor[
              0.2047098267539144, 0.3324933856439975, 0.9349692938413614], 
             UndirectedEdge[75, 141] -> 
             RGBColor[
              0.42297909702707115`, 0.5394592728963019, 0.9485391251947967], 
             UndirectedEdge[123, 141] -> 
             RGBColor[
              0.39747014268735614`, 0.5186903929907134, 0.9465474239163595], 
             UndirectedEdge[40, 119] -> 
             RGBColor[
              0.7331606540356427, 0.4438514188607542, 0.44639585966273576`], 
             UndirectedEdge[16, 80] -> 
             RGBColor[
              0.20448442749174123`, 0.3322564767283148, 0.934956457686829], 
             UndirectedEdge[88, 180] -> 
             RGBColor[
              0.279297845494757, 0.4078125233716327, 0.9393296571454344], 
             UndirectedEdge[24, 41] -> 
             RGBColor[
              0.2739267632539736, 0.4052447745128077, 0.9389110959777585], 
             UndirectedEdge[4, 119] -> 
             RGBColor[
              0.6759864303299372, 0.3952805332356027, 0.44249012797954834`], 
             UndirectedEdge[99, 136] -> 
             RGBColor[
              0.3873164552562508, 0.49927603435680146`, 0.9469303455653235], 
             UndirectedEdge[10, 194] -> 
             RGBColor[
              0.20973618799885002`, 0.33777641000213443`, 0.9352555376784253],
              UndirectedEdge[96, 102] -> 
             RGBColor[
              0.9527960526971394, 0.9643159539076722, 0.964788149409247], 
             UndirectedEdge[9, 88] -> 
             RGBColor[
              0.20493816247527158`, 0.3327333809644648, 0.9349822972229003], 
             UndirectedEdge[55, 108] -> 
             RGBColor[
              0.3219524714198415, 0.4532142784379034, 0.9417379396935124], 
             UndirectedEdge[62, 197] -> 
             RGBColor[
              0.20030365932071864`, 0.327862224304558, 0.9347183691243814], 
             UndirectedEdge[147, 168] -> 
             RGBColor[
              0.22946103997176695`, 0.35850848005351804`, 0.9363788388179795],
              UndirectedEdge[51, 106] -> 
             RGBColor[
              0.1836133165010153, 0.31031961577219463`, 0.9337678787919488], 
             UndirectedEdge[123, 155] -> 
             RGBColor[
              0.5621572300950483, 0.6548917358884543, 0.9590135889959501], 
             UndirectedEdge[75, 142] -> 
             RGBColor[
              0.3820700919784965, 0.49970376609353495`, 0.9460906958516819], 
             UndirectedEdge[31, 182] -> 
             RGBColor[
              0.43639733566624106`, 0.5502718081152633, 0.9496178373615334], 
             UndirectedEdge[65, 140] -> 
             RGBColor[
              0.9750309047249213, 0.9266824270130837, 0.4215378003318664]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 71 -> 
             RGBColor[
              0.3637386159115608, 0.4894738398933511, 0.9443980808578237], 10 -> 
             RGBColor[
              0.2179504265625759, 0.34641009554541596`, 0.9357233264127526], 
             68 -> RGBColor[
              0.9609913119589255, 0.8800766769412489, 0.30295904244338884`], 
             155 -> RGBColor[
              0.6731900684530466, 0.744620465000319, 0.9680609527706839], 132 -> 
             RGBColor[
              0.30056549504747376`, 0.4332437706209237, 0.9404281323449262], 
             26 -> RGBColor[
              0.2927822195605681, 0.4250630545960175, 0.9399848863202711], 29 -> 
             RGBColor[
              0.20691074357712266`, 0.33480668877137576`, 0.9350946327984784],
              113 -> RGBColor[
              0.20445336338735556`, 0.33222382638502757`, 0.9349546886320393],
              50 -> RGBColor[
              0.20374667641262958`, 0.33148105356804847`, 0.9349144438542785],
              173 -> RGBColor[
              0.36775323192677223`, 0.4929510985052593, 0.9446538886403275], 
             192 -> RGBColor[
              0.46571418536342124`, 0.577126781719812, 0.9510818731205317], 
             165 -> RGBColor[
              0.2058031822357576, 0.33364257157815613`, 0.9350315588185778], 
             92 -> RGBColor[
              0.2444470173259052, 0.37425969241856055`, 0.9372322680585309], 
             11 -> RGBColor[
              0.20295626314304663`, 0.3306502791066209, 0.9348694309878873], 
             137 -> RGBColor[
              0.32389238094576056`, 0.45496103389597625`, 0.9418591140004451],
              120 -> RGBColor[
              0.1939380814128329, 0.3211715983224198, 0.934355858879556], 51 -> 
             RGBColor[
              0.18219656266820544`, 0.3088305176665303, 0.9336871967570698], 
             72 -> RGBColor[
              0.2532013109542942, 0.38346101007627187`, 0.9377308121298508], 
             64 -> RGBColor[
              0.6295309817704698, 0.7101206369056319, 0.9639781314143923], 41 -> 
             RGBColor[
              0.29070628845368207`, 0.422881119381046, 0.9398666651147989], 
             103 -> RGBColor[
              0.1810808656124072, 0.3076578493216073, 0.933623659460268], 162 -> 
             RGBColor[
              0.4514119894863078, 0.5654121094919137, 0.9499845506954865], 
             196 -> RGBColor[
              0.23298613716021888`, 0.3622135807026517, 0.9365795878879478], 
             179 -> RGBColor[
              0.3685402730980111, 0.49363279400994686`, 0.9447040382078057], 
             160 -> RGBColor[
              0.44319072976501883`, 0.5582912675338615, 0.9494606992958204], 
             123 -> RGBColor[
              0.4511243917370499, 0.5651630067765897, 0.9499662252212164], 
             150 -> RGBColor[
              0.19256204953176445`, 0.3197253015699566, 0.9342774958995859], 
             188 -> RGBColor[
              0.31320234650668927`, 0.4457018633616062, 0.9411779544588138], 
             46 -> RGBColor[
              0.18297903858873563`, 0.3096529494708463, 0.9337317576031746], 
             182 -> RGBColor[
              0.34083289550277507`, 0.46963405615024345`, 0.9429385486081092],
              6 -> RGBColor[
              0.8314330293974257, 0.24261361475573226`, 0.17773361049049105`],
              131 -> RGBColor[
              0.1814951086723694, 0.3080932450421545, 0.9336472499897152], 45 -> 
             RGBColor[
              0.7110429824499928, 0.7741914491075349, 0.9718337774823064], 
             195 -> RGBColor[
              0.5010318547608589, 0.6057992567795268, 0.9538622094283838], 
             148 -> RGBColor[
              0.19357697366818166`, 0.320792051187238, 0.9343352943277091], 
             161 -> RGBColor[
              0.2838279904913397, 0.4156515921133449, 0.9394749562213734], 1 -> 
             RGBColor[
              0.17991592983646426`, 0.30643342795989703`, 0.9335573180911961],
              101 -> RGBColor[
              0.19619436846660787`, 0.3235430990727991, 0.9344843510893909], 
             12 -> RGBColor[
              0.950102117301832, 0.8398785531251466, 0.2787091962084557], 39 -> 
             RGBColor[
              0.25206224059906557`, 0.3822637749116947, 0.9376659437582241], 
             48 -> RGBColor[
              0.21049372737267863`, 0.3385726319147987, 0.9352986784250858], 
             77 -> RGBColor[0.817319, 0.134127, 0.164218], 56 -> 
             RGBColor[
              0.1825695689347496, 0.30922257090263144`, 0.9337084389121362], 
             110 -> RGBColor[
              0.18012636844446756`, 0.30665461227948687`, 0.9335693022586058],
              73 -> RGBColor[
              0.21747923322295587`, 0.34591484147009205`, 0.9356964926491292],
              37 -> RGBColor[
              0.23584637567939642`, 0.36521987273590373`, 0.9367424742402714],
              130 -> RGBColor[
              0.1842953386135795, 0.3110364642551991, 0.933806718942298], 107 -> 
             RGBColor[
              0.21763298899601496`, 0.34607644853625624`, 0.9357052488129437],
              59 -> RGBColor[
              0.18422301466471383`, 0.3109604471993381, 0.9338026002004038], 
             47 -> RGBColor[
              0.1962609887352336, 0.32361312119909375`, 0.9344881450151332], 
             159 -> RGBColor[
              0.2548921156460419, 0.3852381530105079, 0.9378271009557244], 55 -> 
             RGBColor[
              0.33587823342715956`, 0.465342576888902, 0.9426228419218866], 
             49 -> RGBColor[
              0.4223544797753533, 0.5402439550531881, 0.9481330318712514], 82 -> 
             RGBColor[
              0.21196511221078973`, 0.3401191506708405, 0.9353824716148974], 
             199 -> RGBColor[
              0.995260710048657, 0.9923081960579929, 0.7282058295903809], 89 -> 
             RGBColor[
              0.2675148103379351, 0.39850540545675567`, 0.9385459447448243], 
             144 -> RGBColor[
              0.19848865517094644`, 0.32595453986523776`, 0.93461500732311], 
             78 -> RGBColor[
              0.18293127670980908`, 0.3096027487078165, 0.9337290376348271], 
             42 -> RGBColor[
              0.2027701922068055, 0.3304547067550528, 0.9348588345233357], 
             154 -> RGBColor[
              0.33187084383238813`, 0.46187157743916857`, 0.9423674946005033],
              168 -> RGBColor[
              0.20939739524084894`, 0.3374203173327738, 0.9352362439320562], 
             121 -> RGBColor[
              0.21735301065346377`, 0.34578217354658275`, 0.9356893044605262],
              128 -> RGBColor[
              0.43130662815416465`, 0.5479978560308542, 0.9487034548498753], 
             115 -> RGBColor[
              0.31502527059825963`, 0.4472807885868956, 0.9412941095699802], 
             61 -> RGBColor[
              0.2073405252862433, 0.3352584165973958, 0.9351191082310077], 93 -> 
             RGBColor[
              0.23138676958404353`, 0.3605325439743302, 0.9364885062705369], 
             88 -> RGBColor[
              0.21656281497127022`, 0.34495162778329735`, 0.9356443039854151],
              21 -> RGBColor[
              0.36130368564417137`, 0.48736482567889206`, 0.94424292925431], 
             62 -> RGBColor[
              0.1999014029793203, 0.32743942738522325`, 0.9346954612208237], 
             136 -> 
             RGBColor[
              0.22281221312870114`, 0.35152014148148586`, 0.9360001979653247],
              190 -> RGBColor[
              0.1841862517520943, 0.3109218070472717, 0.933800506606916], 57 -> 
             RGBColor[
              0.1818396285304826, 0.30845535725685214`, 0.9336668698859633], 
             111 -> RGBColor[
              0.2201361607798215, 0.3487074407912947, 0.9358478007429207], 63 -> 
             RGBColor[
              0.19167260114558432`, 0.31879043492179643`, 0.9342268431298139],
              75 -> RGBColor[
              0.5021423004164799, 0.6067007665877667, 0.9539496277780908], 30 -> 
             RGBColor[
              0.2095661987749073, 0.33759774054983127`, 0.9352458570435983], 
             5 -> RGBColor[
              0.35433408061295757`, 0.481328104103389, 0.9437988321847008], 
             171 -> RGBColor[
              0.30775018901205775`, 0.44079533951360933`, 0.940837290037407], 
             102 -> RGBColor[
              0.9691756477061694, 0.9765318290462814, 0.9370617675415293], 31 -> 
             RGBColor[
              0.531961775829707, 0.6309095600802831, 0.9562971261149575], 96 -> 
             RGBColor[
              0.9364164576881094, 0.9521000787690629, 0.9925145312769647], 70 -> 
             RGBColor[
              0.19105055232810444`, 0.31813662217445204`, 0.9341914183698972],
              52 -> RGBColor[
              0.18558886593634766`, 0.31239604348579764`, 0.9338803834097276],
              183 -> RGBColor[
              0.9363841071750253, 0.7854912142282449, 0.26767136325734403`], 
             158 -> RGBColor[
              0.3163443674121438, 0.4484233239473484, 0.9413781612525294], 13 -> 
             RGBColor[
              0.22110598802207443`, 0.3497267907135012, 0.9359030309696362], 
             170 -> RGBColor[
              0.6552079689840278, 0.7305727122261038, 0.9662686651478858], 86 -> 
             RGBColor[
              0.2020967142561969, 0.3297468387279948, 0.9348204809503698], 18 -> 
             RGBColor[
              0.22306772190849825`, 0.3517886974092449, 0.9360147488123428], 
             153 -> RGBColor[
              0.2822567222941179, 0.41400008961390705`, 0.9393854748220246], 
             58 -> RGBColor[
              0.9605766768067475, 0.9701187306290152, 0.9516175823034524], 22 -> 
             RGBColor[
              0.18848942771341942`, 0.31544471781973865`, 0.9340455661119352],
              66 -> RGBColor[
              0.18354617680954663`, 0.31024904769955874`, 0.9337640552858439],
              143 -> 
             RGBColor[
              0.8556626659915121, 0.887746199790043, 0.9860950630129915], 119 -> 
             RGBColor[
              0.8468258702473929, 0.3609297347144502, 0.19247381227214683`], 
             145 -> RGBColor[
              0.1901932049434399, 0.31723549571420584`, 0.9341425937046723], 
             91 -> RGBColor[
              0.18623437450108682`, 0.31307451391494534`, 0.9339171441675451],
              177 -> RGBColor[
              0.21738991983752656`, 0.34582096743921015`, 0.9356914063839564],
              200 -> RGBColor[
              0.1906136828189116, 0.3176774446211637, 0.9341665392976392], 
             114 -> RGBColor[
              0.18141516357964482`, 0.30800921768088935`, 0.9336426972349526],
              24 -> RGBColor[
              0.2571472380542651, 0.3876084296445695, 0.9379555268407181], 
             176 -> RGBColor[
              0.23408779828449117`, 0.3633714963936115, 0.9366423258592136], 
             79 -> RGBColor[
              0.1941778278429074, 0.3214235870212298, 0.9343695120840757], 
             109 -> RGBColor[
              0.21740901950548744`, 0.34584104240122593`, 0.9356924940817913],
              135 -> RGBColor[
              0.1969362596236349, 0.3243228737174507, 0.934526600693254], 108 -> 
             RGBColor[
              0.3080267094125234, 0.4410859799869048, 0.9408530374651383], 
             191 -> RGBColor[
              0.8101035860121542, 0.8515783454987672, 0.9817072126714098], 14 -> 
             RGBColor[
              0.17925722738073346`, 0.3057410899147761, 0.9335198059608052], 
             185 -> RGBColor[
              0.2320502240219991, 0.3612298766540624, 0.9365262890192856], 32 -> 
             RGBColor[
              0.186006868294159, 0.3128353904667376, 0.9339041880256258], 122 -> 
             RGBColor[
              0.27792375203997, 0.40944586315061604`, 0.939138718576106], 187 -> 
             RGBColor[
              0.20348109888236326`, 0.33120191474515054`, 0.9348993196068165],
              193 -> RGBColor[
              0.22946131864603458`, 0.3585087729578423, 0.9363788546880667], 
             100 -> RGBColor[
              0.20579087184942513`, 0.3336296325815971, 0.9350308577602878], 
             180 -> RGBColor[
              0.3420328760182438, 0.47067341895996806`, 0.9430150103054538], 
             7 -> RGBColor[
              0.20849433214894747`, 0.33647114076567824`, 0.9351848158249345],
              175 -> RGBColor[
              0.5005712745154292, 0.6054253369873833, 0.9538259508643026], 9 -> 
             RGBColor[
              0.19331350997927296`, 0.32051513414563226`, 0.9343202904603853],
              90 -> RGBColor[
              0.22727061882380845`, 0.3562062085462915, 0.9362540975740409], 
             174 -> RGBColor[
              0.19003317840134057`, 0.3170672976721906, 0.9341334804298378], 
             142 -> RGBColor[
              0.2619978835405132, 0.39270676559930323`, 0.938231763925273], 
             134 -> RGBColor[
              0.24687317251219526`, 0.37680973534647483`, 0.9373704340072151],
              105 -> RGBColor[
              0.20575656042090384`, 0.333593569094751, 0.9350289037751928], 
             16 -> RGBColor[
              0.1871756577266932, 0.3140638622658612, 0.9339707488547396], 
             139 -> RGBColor[
              0.28566810415648325`, 0.4175856682453557, 0.9395797479723991], 
             146 -> RGBColor[
              0.24540381361353808`, 0.37526534598125116`, 0.9372867561916584],
              126 -> RGBColor[
              0.1796655907243716, 0.3061703056806712, 0.9335430616491059], 
             198 -> RGBColor[
              0.34562348099972906`, 0.47378342052587685`, 0.9432438004798267],
              40 -> RGBColor[
              0.5058302216121423, 0.609694787153362, 0.9542399544439137], 104 -> 
             RGBColor[
              0.36710024085613885`, 0.49238551046016216`, 0.9446122806267241],
              181 -> RGBColor[
              0.43817293033743376`, 0.5539451018716196, 0.9491409695533606], 
             127 -> RGBColor[
              0.874787420357395, 0.9029957597937702, 0.9879191991572792], 76 -> 
             RGBColor[
              0.26424845016803866`, 0.3950722538189983, 0.9383599303652956], 
             172 -> RGBColor[
              0.8693407441384133, 0.4995886600246006, 0.2126870529687101], 84 -> 
             RGBColor[
              0.181234979779358, 0.3078198330824752, 0.9336324360340843], 184 -> 
             RGBColor[
              0.1818088839913312, 0.30842304279688765`, 0.933665119029941], 
             151 -> RGBColor[
              0.9939031817563573, 0.9917468232222412, 0.7507035865643902], 35 -> 
             RGBColor[
              0.18077756667952594`, 0.30733906291288604`, 0.933606387034731], 
             36 -> RGBColor[
              0.18255152448721731`, 0.309203605044191, 0.9337074113075435], 
             34 -> RGBColor[
              0.4300571649791395, 0.5469156338284925, 0.9486238401612196], 38 -> 
             RGBColor[
              0.18112444186066054`, 0.30770365072141526`, 0.9336261410631407],
              54 -> 
             RGBColor[
              0.988392764379178, 0.9725082101217492, 0.4094085107659739], 60 -> 
             RGBColor[
              0.18098071777705174`, 0.3075525875969092, 0.9336179561892], 87 -> 
             RGBColor[
              0.21670300720810273`, 0.3450989787129095, 0.9356522877259069], 
             141 -> RGBColor[
              0.34381589363766235`, 0.47221777920483715`, 0.9431286226115025],
              67 -> RGBColor[
              0.2558901091184015, 0.3862871074263986, 0.9378839352075763], 
             133 -> RGBColor[
              0.24912319227677354`, 0.3791746487785393, 0.937498569304202], 
             98 -> RGBColor[
              0.19250116414799295`, 0.31966130717125646`, 0.9342740285670519],
              3 -> RGBColor[
              0.4186929718519593, 0.5370725409226834, 0.947899723824117], 27 -> 
             RGBColor[
              0.26652048668465833`, 0.39746030825340095`, 0.9384893194837403],
              163 -> RGBColor[
              0.2817626744925139, 0.41348081404998144`, 0.9393573395306015], 
             85 -> RGBColor[
              0.2704719529099895, 0.40161354979365305`, 0.9387143496396024], 
             83 -> RGBColor[
              0.9263859833659136, 0.9441390533310817, 0.9928407161596127], 28 -> 
             RGBColor[
              0.1792907180836107, 0.3057762907669333, 0.933521713206789], 44 -> 
             RGBColor[
              0.8987739036289236, 0.6332377629819576, 0.2372468027203504], 
             189 -> RGBColor[
              0.19443151506714343`, 0.3216902283786009, 0.9343839591961993], 
             15 -> RGBColor[0.178927, 0.305394, 0.933501], 80 -> 
             RGBColor[
              0.22179319725678925`, 0.3504490911907685, 0.9359421665189183], 
             112 -> RGBColor[
              0.9414109245622558, 0.9558249439861124, 0.9840602016246193], 
             169 -> RGBColor[
              0.19209300288846856`, 0.31923230380857776`, 0.9342507843871425],
              69 -> RGBColor[
              0.24981404640376637`, 0.37990078026869034`, 0.9375379124247071],
              20 -> RGBColor[
              0.1823235017276304, 0.3089639386663871, 0.9336944257487145], 8 -> 
             RGBColor[
              0.28326421471662644`, 0.41505902802867256`, 0.939442850025035], 
             116 -> RGBColor[
              0.24062773125074222`, 0.3702453805968408, 0.9370147653666777], 
             97 -> RGBColor[
              0.21679935925455723`, 0.3452002508228058, 0.9356577748324124], 
             118 -> RGBColor[
              0.39086743560945575`, 0.5129714599815431, 0.9461267052599003], 
             178 -> RGBColor[
              0.1836473816366038, 0.3103554203895525, 0.9337698187510258], 81 -> 
             RGBColor[
              0.30602988251049323`, 0.4389871883067331, 0.9407393211271083], 
             166 -> RGBColor[
              0.8037293520346596, 0.846598745469576, 0.9810718885991364], 125 -> 
             RGBColor[
              0.2642831104182927, 0.3951086839396021, 0.9383619042152723], 95 -> 
             RGBColor[
              0.24919784069125972`, 0.37925310899514714`, 0.9375028204209744],
              157 -> RGBColor[
              0.20642492465234524`, 0.3342960622787358, 0.9350669661294171], 
             74 -> RGBColor[
              0.34593054718585675`, 0.47404938582270545`, 0.9432633664656788],
              19 -> RGBColor[
              0.35121665541737046`, 0.47862794708531764`, 0.9436001926078689],
              156 -> RGBColor[
              0.8187176743057581, 0.14487782361704554`, 0.16555737209477062`],
              167 -> RGBColor[
              0.19933380464903927`, 0.32684284555228516`, 0.9346631373356007],
              33 -> RGBColor[
              0.9926235425767636, 0.9912176595362523, 0.7719105193703001], 43 -> 
             RGBColor[
              0.18974733652345127`, 0.3167668597351072, 0.9341172021577572], 
             140 -> RGBColor[
              0.9937232399115826, 0.9889829697856952, 0.5581915839279488], 
             186 -> RGBColor[
              0.18306798401191893`, 0.3097464367500775, 0.933736822913442], 
             117 -> RGBColor[
              0.1853227778630534, 0.31211636804980714`, 0.9338652300875955], 
             4 -> RGBColor[
              0.33430755049502603`, 0.4639821302779076, 0.9425227593943515], 
             106 -> RGBColor[
              0.18503007033382515`, 0.31180871387785897`, 0.9338485608268279],
              65 -> RGBColor[
              0.95633856953826, 0.8643818842404721, 0.284884016735784], 53 -> 
             RGBColor[
              0.631783197735858, 0.7119490872875069, 0.9641554341053266], 2 -> 
             RGBColor[
              0.18237351643808017`, 0.30901650729818564`, 0.9336972740124846],
              147 -> RGBColor[
              0.24952468470268496`, 0.3795966427742623, 0.9375214337039027], 
             94 -> RGBColor[
              0.19041076970754647`, 0.3174641700756846, 0.9341549836961299], 
             23 -> RGBColor[
              0.22363768830217948`, 0.3523877682269605, 0.9360472075552733], 
             194 -> 
             RGBColor[
              0.2015219494351241, 0.32914272445885284`, 0.9347877489440981], 
             129 -> RGBColor[
              0.4544709331932017, 0.5679990031052896, 0.9501967631243022], 99 -> 
             RGBColor[
              0.5518206973838005, 0.647031927232117, 0.9578604931653224], 25 -> 
             RGBColor[
              0.17953882470990998`, 0.3060370665620425, 0.9335358425121159], 
             138 -> RGBColor[
              0.2218736173884548, 0.35053361784807985`, 0.9359467463264457], 
             124 -> RGBColor[
              0.2260372839021752, 0.3549098953457044, 0.9361838609748094], 
             197 -> RGBColor[
              0.20070591566211698`, 0.3282850212238928, 0.9347412770279392], 
             164 -> RGBColor[
              0.19517315909830985`, 0.32246974327830424`, 0.9344261947266101],
              152 -> RGBColor[
              0.20018563595199287`, 0.32773817426091345`, 0.9347116478681324],
              17 -> RGBColor[
              0.19146922694525287`, 0.31857667574257903`, 0.9342152612699701],
              149 -> RGBColor[
              0.1855038424012835, 0.31230667835964177`, 
               0.9338755414451867]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw1Vnk41Iv7HWbGjH3MjDGYYWbMlDYVokV9jgp1K023DRVaCFlSpNQNyVKW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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 11}], {
             RGBColor[
             0.19143609648975546`, 0.318541853533259, 0.9342133745395418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 35}], {
             RGBColor[
             0.1803467482579951, 0.30688624543639154`, 0.9335818525629636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 86}], {
             RGBColor[
             0.19100632204633058`, 0.3180901333439459, 0.934188899520783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 94}], {
             RGBColor[
             0.18516334977200538`, 0.3119487990177908, 0.933856150893663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 174}], {
             RGBColor[
             0.1849745541189024, 0.31175036281604385`, 0.9338453992605169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 196}], {
             RGBColor[
             0.20645103349834157`, 0.33432350433127433`, 0.935068452989572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 16}], {
             RGBColor[
             0.1847745870823867, 0.3115401847820234, 0.9338340114336121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 52}], {
             RGBColor[
             0.1839811911872139, 0.31070627539199164`, 0.933788828711106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[
             0.1829598466238134, 0.3096327774988722, 0.9337306646491643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 78}], {
             RGBColor[
             0.1826523965739446, 0.3093096280030011, 0.9337131558236558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 80}], {
             RGBColor[
             0.20208335684743473`, 0.32973279924447707`, 0.9348197202657014]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 82}], {
             RGBColor[
             0.19716931432443496`, 0.3245678289845131, 0.934539872813691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 98}], {
             RGBColor[
             0.18743734029303655`, 0.314338907234721, 0.9339856512897682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 100}], {
             RGBColor[
             0.19408219414375266`, 0.32132306993989135`, 0.9343640658863862]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 120}], {
             RGBColor[
             0.18815579892545653`, 0.3150940528103027, 0.9340265664460203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 124}], {
             RGBColor[
             0.20420540017012767`, 0.331963201321945, 0.9349405674936471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 187}], {
             RGBColor[
             0.1929273076602217, 0.3201092110216681, 0.9342982968096505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 5}], {
             RGBColor[
             0.38651352623245844`, 0.5092003225130362, 0.945849278004409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 10}], {
             RGBColor[
             0.3183216992072676, 0.4417413182340497, 0.9418115251184348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 27}], {
             RGBColor[
             0.3426067292683088, 0.4672664245880422, 0.9431945216539286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 29}], {
             RGBColor[
             0.312801857714541, 0.4359396148470296, 0.9414971783112978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 49}], {
             RGBColor[
             0.42052372581365627`, 0.5386582479879358, 0.9480163778476842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 53}], {
             RGBColor[
             0.5252380847939087, 0.6245108141050952, 0.9560275789647218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 62}], {
             RGBColor[
             0.30929718741563983`, 0.43225598415395333`, 0.9412975925224704]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 68}], {
             RGBColor[
             0.6898421419054424, 0.7085746089319662, 0.625429383133753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 71}], {
             RGBColor[
             0.3912157938817601, 0.5132731904080172, 0.9461489023409704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 75}], {
             RGBColor[
             0.4604176361342196, 0.5718866537552251, 0.9509246758011038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 118}], {
             RGBColor[
             0.40478020373070756`, 0.5250220004521133, 0.9470132145420087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[
             0.4349086817945046, 0.5511177738496366, 0.9489329745226667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 127}], {
             RGBColor[
             0.6467401961046771, 0.7200341503582268, 0.9679094614906981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 129}], {
             RGBColor[
             0.4365819525225805, 0.5525357720139865, 0.9490482434742096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 139}], {
             RGBColor[
             0.3521805380042213, 0.47732910458401956`, 0.943739735898258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 141}], {
             RGBColor[
             0.38125443274481086`, 0.5046451600637603, 0.9455141732178098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 146}], {
             RGBColor[
             0.33204839273274867`, 0.4561689434519673, 0.9425932400078877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 155}], {
             RGBColor[
             0.545941520152503, 0.6408465029615011, 0.9579803382974005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 167}], {
             RGBColor[
             0.3090133882504993, 0.4319576932374843, 0.9412814305798589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 191}], {
             RGBColor[
             0.6143982789320568, 0.6943254432107253, 0.9648034682477634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 194}], {
             RGBColor[
             0.3101074606435417, 0.43310763269076813`, 0.9413437363841075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 195}], {
             RGBColor[
             0.4598624133064091, 0.5714358988511051, 0.9508809666262504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 34}], {
             RGBColor[
             0.38218235773708276`, 0.5054488820532, 0.9455732997777855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 40}], {
             RGBColor[
             0.42006888605358417`, 0.5368384587156347, 0.9483813569191326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 49}], {
             RGBColor[
             0.37833101513518963`, 0.5021130426655478, 0.9453278956328015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 53}], {
             RGBColor[
             0.483045374115442, 0.5879656087827072, 0.953339096749839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 54}], {
             RGBColor[
             0.661350157437102, 0.7182451701998284, 0.6759656350801627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 65}], {
             RGBColor[
             0.6453230600166431, 0.6641820072591899, 0.6137033880650677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 69}], {
             RGBColor[
             0.2920607984493962, 0.42194145527329896`, 0.9400303359095292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 86}], {
             RGBColor[
             0.26820213237561147`, 0.3968644845029512, 0.9386716201723606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 92}], {
             RGBColor[
             0.28937728391046563`, 0.41912091134823404`, 0.9398775137264412]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 118}], {
             RGBColor[
             0.3625874930522409, 0.48847679512972536`, 0.9443247323271259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 119}], {
             RGBColor[
             0.6759864303299372, 0.3952805332356027, 0.44249012797954834`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 123}], {
             RGBColor[
             0.39271597111603795`, 0.5145725685272486, 0.946244492307784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 139}], {
             RGBColor[
             0.30998782732575464`, 0.44078389926163164`, 0.9410512536833753]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 146}], {
             RGBColor[
             0.289855682054282, 0.41962373812957937`, 0.9399047577930049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 171}], {
             RGBColor[
             0.3210288697535419, 0.4523887348957585, 0.9416800247158792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 182}], {
             RGBColor[
             0.33757022299890055`, 0.4668080932140755, 0.9427306540012304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 191}], {
             RGBColor[
             0.57220556825359, 0.6577802378883374, 0.9621149860328806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 195}], {
             RGBColor[
             0.41766970262794245`, 0.5348906935287172, 0.9481924844113676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 196}], {
             RGBColor[
             0.28364684382762245`, 0.41309785549027966`, 0.9395511736411497]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 199}], {
             RGBColor[
             0.6647841302718416, 0.7281451631679503, 0.8353642944923663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 10}], {
             RGBColor[
             0.28614225358776674`, 0.41386909982440245`, 0.9397610792987268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 27}], {
             RGBColor[
             0.31042728364880795`, 0.439394206178395, 0.9411440758342206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.28062241209504013`, 0.4080673964373824, 0.9394467324915896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 30}], {
             RGBColor[
             0.28195013969393246`, 0.40946292232661013`, 0.9395223446141496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 42}], {
             RGBColor[
             0.2785521364098815, 0.40589140542922086`, 0.9393288333540183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 68}], {
             RGBColor[
             0.6576626962859415, 0.680702390522319, 0.6233789373140448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 71}], {
             RGBColor[
             0.35903634826225916`, 0.48540097199837007`, 0.9440984565212622]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 73}], {
             RGBColor[
             0.2859066569179567, 0.41362147278674055`, 0.939747662416915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 75}], {
             RGBColor[
             0.42823819051471873`, 0.5440144353455778, 0.9488742299813958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 76}], {
             RGBColor[
             0.3092912653904981, 0.4382001789611937, 0.9410793812749982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 81}], {
             RGBColor[
             0.3301819815617254, 0.46015764620506105`, 0.9422690766559045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 87}], {
             RGBColor[
             0.28551854391053016`, 0.41321354140814925`, 0.9397255599553038]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 89}], {
             RGBColor[
             0.31092444547544634`, 0.4399167547800723, 0.9411723884647626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 107}], {
             RGBColor[
             0.28598353480448624`, 0.4137022763198226, 0.9397520404988222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 127}], {
             RGBColor[
             0.6145607504851762, 0.6921619319485797, 0.9658590156709901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 129}], {
             RGBColor[
             0.40440250690307966`, 0.5246635536043394, 0.9469977976545015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 141}], {
             RGBColor[
             0.34907498712530993`, 0.4767729416541131, 0.9434637273981017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 142}], {
             RGBColor[
             0.3081659820767354, 0.43701743485134614`, 0.9410152980549868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 147}], {
             RGBColor[
             0.30192938265782127`, 0.43046237343882565`, 0.9406601329443018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 155}], {
             RGBColor[
             0.513762074533002, 0.612974284551854, 0.9559298924776924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 157}], {
             RGBColor[
             0.28037950263265143`, 0.40781208319106244`, 0.939432899157059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 168}], {
             RGBColor[
             0.2818657379269033, 0.4093742107180814, 0.9395175380583785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 188}], {
             RGBColor[
             0.33376821355982345`, 0.4635149837324976, 0.9424883933217574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 197}], {
             RGBColor[
             0.27751999813753725`, 0.4048065626636409, 0.93927005460632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 44}], {
             RGBColor[
             0.8538799874745917, 0.37282166416447404`, 0.1975713412337775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 45}], {
             RGBColor[
             0.7913030137482814, 0.4198062262063331, 0.4424336661544295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 58}], {
             RGBColor[
             0.8744809118671997, 0.48511532004682656`, 0.4356949344281448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 77}], {
             RGBColor[
             0.8267283529316172, 0.20645140983715485`, 0.1732284069936607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 83}], {
             RGBColor[
             0.8630840140535884, 0.476455427614182, 0.44943597904686494`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 96}], {
             RGBColor[
             0.8664275054943202, 0.4791091027601758, 0.4493272507526489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 112}], {
             RGBColor[
             0.8680923277857024, 0.48035072449919225`, 0.44650914086853377`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 156}], {
             RGBColor[
             0.8271945777002032, 0.21003501770950336`, 0.17367486435858423`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 166}], {
             RGBColor[
             0.8221984702765036, 0.44394199166034687`, 0.44551303652670615`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 170}], {
             RGBColor[
             0.7726913425929597, 0.40526664724585604`, 0.4405786287096226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 179}], {
             RGBColor[
             0.6771354439642875, 0.3262866745071371, 0.4333904197295959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 183}], {
             RGBColor[
             0.8664167219899589, 0.42357281457990315`, 0.20771286141277537`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 192}], {
             RGBColor[
             0.7095267480527575, 0.35411800374375885`, 0.4355163647005046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 8}], {
             RGBColor[
             0.24587927343278695`, 0.3757650843971754, 0.9373138329249848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 16}], {
             RGBColor[
             0.19783499493782034`, 0.3252675015157697, 0.9345777823398371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 52}], {
             RGBColor[
             0.19704159904264756`, 0.32443359212573797`, 0.934532599617331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.2079174287175954, 0.335864778681537, 0.9351519620279711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 67}], {
             RGBColor[
             0.23219222063367448`, 0.36137912409603845`, 0.9365343755162554]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 79}], {
             RGBColor[
             0.20133607999592745`, 0.328947363893454, 0.934777163954505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.19486465596415276`, 0.32214548692407674`, 0.9344086259295095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 122}], {
             RGBColor[
             0.24320904209445873`, 0.37295850195814717`, 0.9371617672005202]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 125}], {
             RGBColor[
             0.2363887212836201, 0.36578991235264013`, 0.9367733600201034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 126}], {
             RGBColor[
             0.19407996143665954`, 0.32132072322317473`, 0.9343639387370202]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 137}], {
             RGBColor[
             0.266193356547354, 0.39571608733082725`, 0.9385219649126898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 179}], {
             RGBColor[
             0.2885173026234793, 0.4150519673878126, 0.9399444270163702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 192}], {
             RGBColor[
             0.3371042587561843, 0.4567989612427451, 0.9431333444727331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.3222839501803989, 0.4512119268537823, 0.9418428896396724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 26}], {
             RGBColor[
             0.28802321713859724`, 0.420061041312345, 0.9397138681726531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 61}], {
             RGBColor[
             0.24530237000143487`, 0.37515872231303415`, 0.9372809791280214]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 67}], {
             RGBColor[
             0.26957716191751396`, 0.4006730677275356, 0.9386633926163057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 79}], {
             RGBColor[
             0.2387210212797669, 0.3682413075249512, 0.9369061810545554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.24761466346370808`, 0.37758908934975655`, 0.9374126608199662]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 83}], {
             RGBColor[
             0.60482509904127, 0.6795990406798771, 0.9661417830923238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 122}], {
             RGBColor[
             0.2805939833782982, 0.4122524455896443, 0.9392907843005704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 125}], {
             RGBColor[
             0.2737736625674596, 0.4050838559841373, 0.9389023771201537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 137}], {
             RGBColor[
             0.3035782978311935, 0.4350100309623244, 0.94065098201274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 166}], {
             RGBColor[
             0.543496783375643, 0.6308288867491243, 0.9602573693120857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 170}], {
             RGBColor[
             0.4692360918503271, 0.5728158701273882, 0.9528557575864605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 179}], {
             RGBColor[
             0.32590224390731876`, 0.4543459110193097, 0.9420734441164204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 192}], {
             RGBColor[
             0.37448920004002384`, 0.4960929048742423, 0.9452623615727833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 198}], {
             RGBColor[
             0.31444384785817775`, 0.4444212242772747, 0.9413433252524308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 18}], {
             RGBColor[
             0.2081906159438856, 0.3361519157774386, 0.935167519636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 32}], {
             RGBColor[
             0.18966018913671598`, 0.3166752623061849, 0.9341122392430056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 39}], {
             RGBColor[
             0.22268787528916928`, 0.3513894545286635, 0.9359931171093048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 41}], {
             RGBColor[
             0.24200989921647753`, 0.37169812676333913`, 0.9370934777875921]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 57}], {
             RGBColor[
             0.18757656925487778`, 0.3144852457012422, 0.9339935801731742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 85}], {
             RGBColor[
             0.23189273144463124`, 0.36106434196964265`, 0.9365173200499939]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 88}], {
             RGBColor[
             0.20493816247527158`, 0.3327333809644648, 0.9349822972229003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 91}], {
             RGBColor[
             0.1897739422401799, 0.3167948240302888, 0.9341187173139652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 103}], {
             RGBColor[
             0.18719718779584008`, 0.3140864917336198, 0.9339719749603267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 117}], {
             RGBColor[
             0.1893181439211632, 0.3163157510977197, 0.9340927602739904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 121}], {
             RGBColor[
             0.20533326031636837`, 0.3331486538461075, 0.9350047974604558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 152}], {
             RGBColor[
             0.19674957296563292`, 0.32412665420327286`, 0.9345159691642588]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 159}], {
             RGBColor[
             0.22410281281265743`, 0.3528766435780701, 0.9360736957080549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 164}], {
             RGBColor[
             0.1942433345387914, 0.32149243871196825`, 0.9343732425934977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 178}], {
             RGBColor[
             0.18848044580793838`, 0.31543527726759235`, 0.9340450546057055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 200}], {
             RGBColor[
             0.19196359639909227`, 0.31909628938339796`, 0.9342434148790122]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 17}], {
             RGBColor[
             0.2047098267539144, 0.3324933856439975, 0.9349692938413614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 27}], {
             RGBColor[
             0.24223545662361712`, 0.37193520189940843`, 0.9371063229482464]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 29}], {
             RGBColor[
             0.2124305850698493, 0.3406083921583959, 0.9354089796056155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 30}], {
             RGBColor[
             0.2137583126687416, 0.34200391804762365`, 0.9354845917281754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 42}], {
             RGBColor[
             0.2103603093846907, 0.3384324011502344, 0.9352910804680441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 51}], {
             RGBColor[
             0.20007349461539067`, 0.32762030660597313`, 0.9347052615849112]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 62}], {
             RGBColor[
             0.2089259147709481, 0.3369247614653196, 0.9352093938167881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 71}], {
             RGBColor[
             0.2908445212370684, 0.4179419677193835, 0.9400607036352882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 73}], {
             RGBColor[
             0.2177148298927659, 0.346162468507754, 0.9357099095309409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 75}], {
             RGBColor[
             0.3600463634895279, 0.4765554310665914, 0.9448364770954216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 89}], {
             RGBColor[
             0.2427326184502555, 0.3724577505010858, 0.9371346355787884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 107}], {
             RGBColor[
             0.21779170777929543`, 0.3462432720408361, 0.9357142876128481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.3362106798778888, 0.4572045493253528, 0.9429600447685274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 130}], {
             RGBColor[
             0.2011228825880777, 0.32872327990030753`, 0.9347650226775253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 141}], {
             RGBColor[
             0.28088316010011916`, 0.40931393737512656`, 0.9394259745121276]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 142}], {
             RGBColor[
             0.23997415505154454`, 0.3695584305723596, 0.9369775451690128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 147}], {
             RGBColor[
             0.23373755563263043`, 0.3630033691598391, 0.9366223800583277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 149}], {
             RGBColor[
             0.2017271344819297, 0.32935838695252884`, 0.9347994339289696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 167}], {
             RGBColor[
             0.2086421156058076, 0.33662647054885053`, 0.9351932318741767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 168}], {
             RGBColor[
             0.21367391090171242`, 0.3419152064390949, 0.9354797851724044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 188}], {
             RGBColor[
             0.26557638653463256`, 0.3960559794535111, 0.9384506404357832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.20619097081485965`, 0.33405016196200843`, 0.935053642804476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 194}], {
             RGBColor[
             0.20973618799885002`, 0.33777641000213443`, 0.9352555376784253]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 197}], {
             RGBColor[
             0.20932817111234645`, 0.33734755838465436`, 0.9352323017203459]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 35}], {
             RGBColor[
             0.19186691491128627`, 0.3189946710097535, 0.9342379090113091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 70}], {
             RGBColor[
             0.19700340773557554`, 0.3243934506405365, 0.9345304246788922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 86}], {
             RGBColor[
             0.20252648869962175`, 0.33019855891730787`, 0.9348449559691285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 94}], {
             RGBColor[
             0.19668351642529655`, 0.32405722459115277`, 0.9345122073420087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 110}], {
             RGBColor[
             0.1915413157937571, 0.3186524456930539, 0.9342193666232466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 138}], {
             RGBColor[
             0.2124149402657507, 0.3405919484773504, 0.9354080886571665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 174}], {
             RGBColor[
             0.1964947207721936, 0.32385878838940574`, 0.9345014557088626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 182}], {
             RGBColor[
             0.27189457932291083`, 0.4001421676284322, 0.9389039897979983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 196}], {
             RGBColor[
             0.21797120015163274`, 0.34643192990463634`, 0.9357245094379176]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 33}], {
             RGBColor[
             0.9713628299392978, 0.9155481063306994, 0.5253098577893779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 44}], {
             RGBColor[
             0.9244380104653778, 0.7365581580535521, 0.25797799946440303`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 58}], {
             RGBColor[
             0.9553393970542898, 0.9049986418770809, 0.615163389255954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 68}], {
             RGBColor[
             0.9555467146303788, 0.8599776150331977, 0.2908341193259223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 77}], {
             RGBColor[
             0.8615800391006107, 0.36937751770838223`, 0.20238173206948523`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 96}], {
             RGBColor[
             0.9432592874949708, 0.8959893159471047, 0.6356118637427102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 99}], {
             RGBColor[
             0.7509614073428162, 0.7434552401786318, 0.618284844686889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 102}], {
             RGBColor[
             0.9596388825040008, 0.9082051910857141, 0.6078854818749925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 128}], {
             RGBColor[
             0.6907043727279983, 0.6939382045780004, 0.6137063255291655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 140}], {
             RGBColor[
             0.9719126786067074, 0.9144307614554209, 0.4184503900682022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 162}], {
             RGBColor[
             0.7007570533940699, 0.7026453313085301, 0.614346873451971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 172}], {
             RGBColor[
             0.9097214307201227, 0.6697336065748736, 0.2456981245885829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 31}], {
             RGBColor[
             0.37653388192589077`, 0.49031817539689215`, 0.9461000785422968]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 34}], {
             RGBColor[
             0.32558157650060693`, 0.44832121227099686`, 0.9422634355654279]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 36}], {
             RGBColor[
             0.20182875625464586`, 0.3294651978788461, 0.9348052211385899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 63}], {
             RGBColor[
             0.20638929458382937`, 0.3342586128176488, 0.935064937049725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 64}], {
             RGBColor[
             0.4253184848962721, 0.5299237138095665, 0.9499405811920143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 70}], {
             RGBColor[
             0.20607827017508945`, 0.33393170644397663`, 0.9350472246697668]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 97}], {
             RGBColor[
             0.21895267363831583`, 0.3474635207681535, 0.9357804029010244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 132}], {
             RGBColor[
             0.26083574153477407`, 0.39148528066721244`, 0.9381655816572811]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 138}], {
             RGBColor[
             0.2214898027052646, 0.35013020428079056`, 0.9359248886480409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 145}], {
             RGBColor[
             0.20564959648275716`, 0.3334811432138535, 0.9350228123371542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 153}], {
             RGBColor[
             0.2516813551580962, 0.3818634401637041, 0.9376442528958304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 185}], {
             RGBColor[
             0.22657810602203676`, 0.3554783336837818, 0.936214659994461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 22}], {
             RGBColor[
             0.18387332754707644`, 0.31059290386725735`, 0.9337826860363703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 48}], {
             RGBColor[
             0.19487547737670605`, 0.3221568609147874, 0.9344092421929455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 106}], {
             RGBColor[
             0.1821436488572793, 0.3087749018963175, 0.9336841833938165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 131}], {
             RGBColor[
             0.18037616802655143`, 0.3069171674784653, 0.9335835279752602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 176}], {
             RGBColor[
             0.20667251283261232`, 0.3345562931541938, 0.9350810659100094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 59}], {
             RGBColor[
             0.18157500733235693`, 0.30817722359966904`, 0.9336518001002019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.18941420148966015`, 0.3164167136926116, 0.9340982306104119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 114}], {
             RGBColor[
             0.1801710817898224, 0.3067016088404447, 0.9335718486174763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 167}], {
             RGBColor[
             0.18913040232451964`, 0.31611842277614255`, 0.9340820686678004]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 184}], {
             RGBColor[
             0.18036794199566558`, 0.3069085213984438, 0.9335830595149706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 186}], {
             RGBColor[
             0.18099749200595946`, 0.30757021837503873`, 0.933618911456721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 194}], {
             RGBColor[
             0.19022447471756204`, 0.31726836222942645`, 0.934144374472049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 52}], {
             RGBColor[
             0.18638226183152043`, 0.31322995287582944`, 0.9339255661322337]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 61}], {
             RGBColor[
             0.19725809150646825`, 0.3246611394316285, 0.9345449285428737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 67}], {
             RGBColor[
             0.22153288342254734`, 0.3501754848461299, 0.935927342031158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 80}], {
             RGBColor[
             0.20448442749174123`, 0.3322564767283148, 0.934956457686829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 82}], {
             RGBColor[
             0.19957038496874147`, 0.32709150646835083`, 0.9346766102348185]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 84}], {
             RGBColor[
             0.1842053187530256, 0.3109418476741682, 0.933801592444412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 100}], {
             RGBColor[
             0.19648326478805916`, 0.32384674742372915`, 0.9345008033075137]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 120}], {
             RGBColor[
             0.19055686956976303`, 0.31761773029414053`, 0.9341633038671477]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 125}], {
             RGBColor[
             0.22572938407249296`, 0.3545862731027316, 0.936166326535006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.19532837830452823`, 0.32263288850550587`, 0.9344350342307781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 30}], {
             RGBColor[
             0.20051771286008008`, 0.3280872081462052, 0.9347305591567843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[
             0.1971197095760292, 0.3245156912488159, 0.9345370478966529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 51}], {
             RGBColor[
             0.18683289480672916`, 0.31370359670455467`, 0.9339512290135199]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 73}], {
             RGBColor[
             0.20447423008410437`, 0.33224575860633554`, 0.9349558769595496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 87}], {
             RGBColor[
             0.2040861170766778, 0.33183782722774424`, 0.9349337744979385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 89}], {
             RGBColor[
             0.229492018641594, 0.35854104059966735`, 0.9363806030073972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 106}], {
             RGBColor[
             0.18824964863953902`, 0.315192694810219, 0.934031911048399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 107}], {
             RGBColor[
             0.20455110797063392`, 0.33232656213941764`, 0.9349602550414569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 130}], {
             RGBColor[
             0.18788228277941618`, 0.31480656999888906`, 0.9340109901061341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 131}], {
             RGBColor[
             0.18648216780881113`, 0.31333496039236675`, 0.9339312556298427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 142}], {
             RGBColor[
             0.22673355524288302`, 0.35564172067094113`, 0.9362235125976215]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 147}], {
             RGBColor[
             0.22049695582396892`, 0.34908665925842064`, 0.9358683474869365]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 149}], {
             RGBColor[
             0.1884865346732682, 0.31544167705111037`, 0.9340454013575784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 157}], {
             RGBColor[
             0.19894707579879906`, 0.3264363690106574, 0.9346411136996936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 168}], {
             RGBColor[
             0.2004333110930509, 0.32799849653767643`, 0.9347257526010131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 188}], {
             RGBColor[
             0.25233578672597107`, 0.38213926955209265`, 0.937696607864392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 189}], {
             RGBColor[
             0.19295037100619816`, 0.32013345206058996`, 0.9342996102330847]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 197}], {
             RGBColor[
             0.19608757130368493`, 0.3234308484832359, 0.9344782691489546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 24}], {
             RGBColor[
             0.24010747998138166`, 0.3696985635269072, 0.9369851378265305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 32}], {
             RGBColor[
             0.20453729510132862`, 0.33231204393799124`, 0.9349594684189844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 39}], {
             RGBColor[
             0.2375649812537819, 0.3670262361604698, 0.9368403462852835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 41}], {
             RGBColor[
             0.25688700518109014`, 0.38733490839514545`, 0.9379407069635708]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 85}], {
             RGBColor[
             0.24676983740924385`, 0.376701123601449, 0.9373645492259726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 103}], {
             RGBColor[
             0.20207429376045272`, 0.32972327336542606`, 0.9348192041363055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 108}], {
             RGBColor[
             0.2655472156605108, 0.39643733869807485`, 0.9384338931387406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 117}], {
             RGBColor[
             0.2041952498857758, 0.331952532729526, 0.9349399894499691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 133}], {
             RGBColor[
             0.2360954570926359, 0.3654816730938921, 0.9367566590582723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 152}], {
             RGBColor[
             0.21162667893024556`, 0.3397634358350792, 0.9353631983402376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 178}], {
             RGBColor[
             0.20335755177255102`, 0.3310720588993987, 0.9348922837816843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 33}], {
             RGBColor[
             0.6719200989970671, 0.734922803310785, 0.8577553559890845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 74}], {
             RGBColor[
             0.34857360130161363`, 0.4763386664540116, 0.9434317795367738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 85}], {
             RGBColor[
             0.31084430416368, 0.44012074843948534`, 0.9411572711237357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 88}], {
             RGBColor[
             0.28388973519432037`, 0.4117897874343075, 0.939622248296642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 93}], {
             RGBColor[
             0.291301712500707, 0.4195802455298239, 0.9400443494392029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 95}], {
             RGBColor[
             0.3002072480543151, 0.4289405280402324, 0.9405515065144217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 102}], {
             RGBColor[
             0.6601961515617699, 0.7275798880657995, 0.9403309800746991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 121}], {
             RGBColor[
             0.28428483303541713`, 0.41220506031595017`, 0.9396447485341975]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 140}], {
             RGBColor[
             0.6724699476644765, 0.7338054584355065, 0.7508958882679089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 159}], {
             RGBColor[
             0.30305438553170616`, 0.43193305004791277`, 0.9407136467817967]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 161}], {
             RGBColor[
             0.3175223229543551, 0.44713976959933127`, 0.9415375744146212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 162}], {
             RGBColor[
             0.4013143224518391, 0.5220200282886156, 0.9467923716516777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 164}], {
             RGBColor[
             0.2731949072578401, 0.40054884518181094`, 0.9390131936672395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 172}], {
             RGBColor[
             0.610278699777892, 0.48910830355495916`, 0.5781436227882895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 173}], {
             RGBColor[
             0.35948494367207134`, 0.4857895227952885, 0.9441270406240982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 180}], {
             RGBColor[
             0.3466247657178071, 0.47465068302264285`, 0.9433076014566613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 22}], {
             RGBColor[
             0.1854064647205249, 0.3122043282430629, 0.9338699959303249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 46}], {
             RGBColor[
             0.182651270158183, 0.3093084440686167, 0.9337130916759446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 47}], {
             RGBColor[
             0.189292245231432, 0.3162885299327404, 0.9340912853819239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 50}], {
             RGBColor[
             0.19303508907013, 0.32022249611721776`, 0.9343044348014965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 101}], {
             RGBColor[
             0.18925893509711914`, 0.3162535188695931, 0.9340893884190526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 135}], {
             RGBColor[
             0.18962988067563263`, 0.3166434061919189, 0.9341105132209843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 144}], {
             RGBColor[
             0.19040607844928842`, 0.31745923926581243`, 0.9341547165359123]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 23}], {
             RGBColor[
             0.2924706869731754, 0.4198762969529263, 0.9401450684047916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 55}], {
             RGBColor[
             0.34859095953566543`, 0.47635370128389704`, 0.9434328855880982]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 61}], {
             RGBColor[
             0.2843221054652073, 0.4113116211381439, 0.9396810187426589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 67}], {
             RGBColor[
             0.30859689738128643`, 0.43682596655264533`, 0.9410634322309431]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 83}], {
             RGBColor[
             0.6438448345050425, 0.715751939504987, 0.9685418227069613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 90}], {
             RGBColor[
             0.29428715223398993`, 0.42178551711259177`, 0.9402485134141754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 122}], {
             RGBColor[
             0.3196137188420707, 0.44840534441475405`, 0.941690823915208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 166}], {
             RGBColor[
             0.5825165188394155, 0.666981785574234, 0.9626574089267232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 170}], {
             RGBColor[
             0.5082558273140996, 0.6089687689524979, 0.9552557972010979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 175}], {
             RGBColor[
             0.43093748007980026`, 0.5463950813331377, 0.9490344400593063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 177}], {
             RGBColor[
             0.28934680274084895`, 0.4165928965590511, 0.9399671678191333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 179}], {
             RGBColor[
             0.3649219793710912, 0.49049880984441946`, 0.9444734837310578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 183}], {
             RGBColor[
             0.6488438964095984, 0.6364280199535685, 0.605957146255827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 192}], {
             RGBColor[
             0.4135089355037963, 0.532245803699352, 0.9476624011874208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.19949157754304903`, 0.3270086748672687, 0.9346721222685106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 72}], {
             RGBColor[
             0.22084536933385682`, 0.34945286394800523`, 0.935888189120893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 144}], {
             RGBColor[
             0.19348904144218293`, 0.3206996288424882, 0.9343302867175226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 176}], {
             RGBColor[
             0.2112886129989553, 0.33940810710667507`, 0.9353439459855744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 38}], {
             RGBColor[
             0.20238106508142, 0.3300457094741879, 0.9348366743092069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 43}], {
             RGBColor[
             0.2066925124128154, 0.33457731398103385`, 0.9350822048565153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 55}], {
             RGBColor[
             0.27975796086466953`, 0.40886517255793126`, 0.9393350247385799]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 60}], {
             RGBColor[
             0.2023092030396156, 0.32997017791193484`, 0.9348325818722366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 90}], {
             RGBColor[
             0.22545415356299398`, 0.354296988386626, 0.936150652564657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 111}], {
             RGBColor[
             0.2218869245410005, 0.3505476045091276, 0.935947504149097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 115}], {
             RGBColor[
             0.26933147945021957`, 0.39983427840692803`, 0.9386706585626268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 163}], {
             RGBColor[
             0.2527001813973467, 0.382934291138471, 0.9377022735429374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 165}], {
             RGBColor[
             0.21472043526896856`, 0.3430151699025583, 0.9355393831869255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 169}], {
             RGBColor[
             0.20786534559532402`, 0.33581003601776915`, 0.9351489959712078]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 175}], {
             RGBColor[
             0.36210448140880436`, 0.4789065526071719, 0.9449365792097879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 177}], {
             RGBColor[
             0.22051380406985302`, 0.3491043678330853, 0.9358693069696149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 39}], {
             RGBColor[
             0.25460473932666533`, 0.38493610227813213`, 0.9378107352994711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 41}], {
             RGBColor[
             0.2739267632539736, 0.4052447745128077, 0.9389110959777585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 55}], {
             RGBColor[
             0.29651273574071235`, 0.4264755032667358, 0.9402891843813024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 108}], {
             RGBColor[
             0.28258697373339425`, 0.41434720481573717`, 0.9394042821529283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 111}], {
             RGBColor[
             0.2386416994170433, 0.36815793521793205`, 0.9369016637918195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 115}], {
             RGBColor[
             0.28608625432626233`, 0.41744460911573256`, 0.9396248182053492]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 133}], {
             RGBColor[
             0.2531352151655193, 0.3833915392115544, 0.93772704807246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 163}], {
             RGBColor[
             0.2694549562733895, 0.40054462184727546`, 0.9386564331856598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 165}], {
             RGBColor[
             0.23147521014501135`, 0.3606255006113628, 0.9364935428296479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 175}], {
             RGBColor[
             0.3788592562848471, 0.49651688331597643`, 0.9458907388525104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 38}], {
             RGBColor[
             0.18033163328528526`, 0.30687035864172885`, 0.9335809917876283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[
             0.1846430806166806, 0.3114019631485748, 0.9338265223349365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 60}], {
             RGBColor[
             0.18025977124348086`, 0.3067948270794758, 0.9335768993506579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 111}], {
             RGBColor[
             0.19983749274486573`, 0.32737225367666856`, 0.9346918216275183]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 165}], {
             RGBColor[
             0.19267100347283378`, 0.3198398190700993, 0.9342837006653468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 58}], {
             RGBColor[
             0.6266794481836577, 0.6975908926125163, 0.9458012343118618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 67}], {
             RGBColor[
             0.2743361643394848, 0.4056750810112081, 0.9389344107639237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 80}], {
             RGBColor[
             0.25728770840867865`, 0.387756072893393, 0.9379635264195947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 82}], {
             RGBColor[
             0.2523736658856789, 0.382591102633429, 0.9376836789675842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 96}], {
             RGBColor[
             0.6145993386243387, 0.6885815666825401, 0.9662497087986179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 98}], {
             RGBColor[
             0.24264169185428053`, 0.372362180883637, 0.9371294574436615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 99}], {
             RGBColor[
             0.42230145847218425`, 0.5360474909140672, 0.9489226897427967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[
             0.24928654570499661`, 0.3793463435888073, 0.9375078720402794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 116}], {
             RGBColor[
             0.2667049754056552, 0.39765421759642916`, 0.9384998258434745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 120}], {
             RGBColor[
             0.2433601504867005, 0.3731173264592187, 0.9371703725999135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 122}], {
             RGBColor[
             0.285352985800269, 0.4172544588733168, 0.9395618024481885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 124}], {
             RGBColor[
             0.25940975173137165`, 0.3899864749708609, 0.9380843736475403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 125}], {
             RGBColor[
             0.2785326649894304, 0.41008586926780977`, 0.9391733952677717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 128}], {
             RGBColor[
             0.36204442385736635`, 0.48653045531343586`, 0.9443441705850733]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 136}], {
             RGBColor[
             0.2577972163446346, 0.3882915980387517, 0.9379925421427979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 137}], {
             RGBColor[
             0.3083373002531643, 0.4400120442459969, 0.9409220001603581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.5482557857976138, 0.6358309000327967, 0.9605283874597037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 170}], {
             RGBColor[
             0.4739950942722979, 0.5778178834110607, 0.9531267757340784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 187}], {
             RGBColor[
             0.24813165922146568`, 0.378132484670584, 0.9374421029635438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 192}], {
             RGBColor[
             0.37924820246199464`, 0.5010949181579147, 0.9455333797204014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 198}], {
             RGBColor[
             0.3192028502801486, 0.44942323756094715`, 0.9416143434000489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 29}], {
             RGBColor[
             0.2367156151308905, 0.36613349851238836`, 0.9367919761411093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 30}], {
             RGBColor[
             0.2380433427297828, 0.3675290244016161, 0.9368675882636692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 42}], {
             RGBColor[
             0.2346453394457319, 0.36395750750422684`, 0.936674077003538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 62}], {
             RGBColor[
             0.23321094483198931`, 0.3624498678193121, 0.9365923903522819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 71}], {
             RGBColor[
             0.3151295512981096, 0.44346707407337604`, 0.941443700170782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 73}], {
             RGBColor[
             0.2419998599538071, 0.37168757486174653`, 0.9370929060664348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 75}], {
             RGBColor[
             0.3843313935505691, 0.5020805374205839, 0.9462194736309155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 89}], {
             RGBColor[
             0.2670176485112967, 0.3979828568550783, 0.9385176321142823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 127}], {
             RGBColor[
             0.5706539535210267, 0.6502280340235855, 0.9632042593205097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 129}], {
             RGBColor[
             0.36049570993893, 0.4827296556793453, 0.9443430413040212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 141}], {
             RGBColor[
             0.30516819016116037`, 0.4348390437291191, 0.9408089710476214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 142}], {
             RGBColor[
             0.2642591851125857, 0.3950835369263521, 0.9383605417045067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 147}], {
             RGBColor[
             0.25802258569367165`, 0.38852847551383163`, 0.9380053765938214]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 149}], {
             RGBColor[
             0.2260121645429709, 0.35488349330652136`, 0.9361824304644635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 155}], {
             RGBColor[
             0.4698552775688525, 0.57104038662686, 0.953275136127212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 167}], {
             RGBColor[
             0.2329271456668488, 0.36215157690284305`, 0.9365762284096705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 168}], {
             RGBColor[
             0.23795894096275363`, 0.36744031279308736`, 0.9368627817078983]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 188}], {
             RGBColor[
             0.28986141659567377`, 0.4215810858075036, 0.939833636971277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 189}], {
             RGBColor[
             0.23047600087590087`, 0.35957526831600095`, 0.9364366393399698]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[
             0.23402121805989123`, 0.3633015163561269, 0.9366385342139192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 197}], {
             RGBColor[
             0.23361320117338766`, 0.3628726647386469, 0.9366152982558398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 97}], {
             RGBColor[
             0.19804503866908396`, 0.3254882707948695, 0.9345897440196007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 105}], {
             RGBColor[
             0.19252363925225727`, 0.3196849299308422, 0.9342753084909909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.20340607327822147`, 0.3311230580782995, 0.9348950470096511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 71}], {
             RGBColor[
             0.2853246797443417, 0.4121402643323634, 0.939746356828151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 73}], {
             RGBColor[
             0.21219498840003925`, 0.3403607651207339, 0.9353955627238038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 129}], {
             RGBColor[
             0.33069083838516217`, 0.4514028459383327, 0.9426456979613903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 141}], {
             RGBColor[
             0.2753633186073925, 0.40351223398810643`, 0.9391116277049905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 149}], {
             RGBColor[
             0.19620729298920309`, 0.32355668356550876`, 0.9344850871218325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 167}], {
             RGBColor[
             0.20312227411308098`, 0.33082476716183046`, 0.9348788850670395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 168}], {
             RGBColor[
             0.2081540694089858, 0.33611350305207477`, 0.9351654383652672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 189}], {
             RGBColor[
             0.20067112932213305`, 0.3282484585749883, 0.9347392959973388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 194}], {
             RGBColor[
             0.2042163465061234, 0.3319747066151143, 0.9349411908712882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 197}], {
             RGBColor[
             0.2038083296196198, 0.3315458549976343, 0.9349179549132087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 42}], {
             RGBColor[
             0.2061681954908564, 0.33402622365244206`, 0.935052345783467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 51}], {
             RGBColor[
             0.19588138072155636`, 0.3232141291081808, 0.934466526900334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 71}], {
             RGBColor[
             0.28665240734323405`, 0.41353579022159115`, 0.939821968950711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 73}], {
             RGBColor[
             0.21352271599893158`, 0.34175629100996163`, 0.9354711748463638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 76}], {
             RGBColor[
             0.23690732447147297`, 0.36633499718441476`, 0.936802893704447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 81}], {
             RGBColor[
             0.2577980406427003, 0.3882924644282822, 0.9379925890853533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 87}], {
             RGBColor[
             0.213134602991505, 0.3413483596313704, 0.9354490723847526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 89}], {
             RGBColor[
             0.2385405045564212, 0.3680515730032935, 0.9368959008942113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 106}], {
             RGBColor[
             0.19729813455436623`, 0.32470322721384515`, 0.9345472089352131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 107}], {
             RGBColor[
             0.21359959388546113`, 0.3418370945430438, 0.935475552928271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 130}], {
             RGBColor[
             0.1969307686942434, 0.3243171024025152, 0.9345262879929481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 131}], {
             RGBColor[
             0.19553065372363834`, 0.3228454927959929, 0.9344465535166567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 142}], {
             RGBColor[
             0.23578204115771023`, 0.3651522530745672, 0.9367388104844356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 147}], {
             RGBColor[
             0.22954544173879612`, 0.3585971916620468, 0.9363836453737505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 157}], {
             RGBColor[
             0.20799556171362626`, 0.3359469014142835, 0.9351564115865076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 168}], {
             RGBColor[
             0.2094817970078781, 0.3375090289413025, 0.9352410504878272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 176}], {
             RGBColor[
             0.22182699852969923`, 0.3504846184717214, 0.9359440914514059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 188}], {
             RGBColor[
             0.2613842726407983, 0.39164980195571875`, 0.938211905751206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 197}], {
             RGBColor[
             0.20513605721851214`, 0.33294138088686204`, 0.9349935670357687]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 34}], {
             RGBColor[
             0.48100947040442327`, 0.5889125969543878, 0.9524604831380885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[
             0.5188959987209247, 0.6203021736168226, 0.9552685402794356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 45}], {
             RGBColor[
             0.62150237913985, 0.702550504593909, 0.964065451798632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 64}], {
             RGBColor[
             0.5807463788000884, 0.6705150984929575, 0.9601376287646749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 65}], {
             RGBColor[
             0.7441501726839835, 0.7476457221603776, 0.6205905714253708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 132}], {
             RGBColor[
             0.4162636354385904, 0.5320766653506034, 0.9483626292299419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 138}], {
             RGBColor[
             0.3769176966090809, 0.4907215889641815, 0.9461219362207016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 153}], {
             RGBColor[
             0.4071092490619125, 0.522454824847095, 0.9478413004684911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 156}], {
             RGBColor[
             0.723132374813741, 0.30688840243812476`, 0.4291372901014996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 182}], {
             RGBColor[
             0.43639733566624106`, 0.5502718081152633, 0.9496178373615334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 185}], {
             RGBColor[
             0.38200599992585305`, 0.49606971836717273`, 0.9464117075671216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 199}], {
             RGBColor[
             0.763611242939182, 0.811608878069138, 0.8422514778526693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 39}], {
             RGBColor[
             0.2190345544466123, 0.34754958268921615`, 0.9357850658919249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 57}], {
             RGBColor[
             0.1839232484123208, 0.31064537386179486`, 0.9337855289557946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 103}], {
             RGBColor[
             0.1835438669532831, 0.31024661989417246`, 0.9337639237429469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 117}], {
             RGBColor[
             0.1856648230786062, 0.31247587925827236`, 0.9338847090566107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 133}], {
             RGBColor[
             0.21756503028546625`, 0.3460050196226384, 0.9357013786649139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 152}], {
             RGBColor[
             0.19309625212307593`, 0.3202867823638255, 0.9343079179468792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 178}], {
             RGBColor[
             0.1848271249653814, 0.311595405428145, 0.9338370033883259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 44}], {
             RGBColor[
             0.9456987231028435, 0.812227711259105, 0.5045786610453252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 58}], {
             RGBColor[
             0.9766001096917556, 0.9806681950826337, 0.8617640508368762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 68}], {
             RGBColor[
             0.9768074272678445, 0.9356471682387506, 0.5374347809068445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 77}], {
             RGBColor[
             0.8757538475255878, 0.41982388651208413`, 0.36678217312343336`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 96}], {
             RGBColor[
             0.9645200001324366, 0.9716588691526575, 0.8822125253236324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 99}], {
             RGBColor[
             0.772222119980282, 0.8191247933841846, 0.8648855062678112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 102}], {
             RGBColor[
             0.9808995951414665, 0.9838747442912669, 0.8544861434559147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 128}], {
             RGBColor[
             0.7119650853654641, 0.7696077577835532, 0.8603069871100877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 140}], {
             RGBColor[
             0.9931733912441731, 0.9901003146609737, 0.6650510516491244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 162}], {
             RGBColor[
             0.7220177660315357, 0.778314884514083, 0.8609475350328932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 172}], {
             RGBColor[
             0.9309821433575884, 0.7454031597804265, 0.49229878616950506`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 180}], {
             RGBColor[
             0.6673282092975037, 0.7309455392481101, 0.857462764837877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 40}], {
             RGBColor[
             0.4679436932956409, 0.5783052104909272, 0.9514318973025666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 45}], {
             RGBColor[
             0.5705500737145661, 0.6605535414680137, 0.960228808821763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 54}], {
             RGBColor[
             0.7092249646791587, 0.7597119219751208, 0.6790161754635967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 64}], {
             RGBColor[
             0.5297940733748047, 0.6285181353670621, 0.956300985787806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 65}], {
             RGBColor[
             0.6931978672586998, 0.7056487590344823, 0.6167539284485017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 132}], {
             RGBColor[
             0.3653113300133066, 0.4900797022247081, 0.9445259862530728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 138}], {
             RGBColor[
             0.32596539118379714`, 0.4487246258382862, 0.9422852932438326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 153}], {
             RGBColor[
             0.3561569436366287, 0.48045786172119975`, 0.9440046574916221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 182}], {
             RGBColor[
             0.3854450302409573, 0.5082748449893679, 0.9457811943846643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 185}], {
             RGBColor[
             0.3310536945005693, 0.45407275524127744`, 0.9425750645902526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 199}], {
             RGBColor[
             0.7126589375138983, 0.7696119149432428, 0.8384148348758003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 86}], {
             RGBColor[
             0.19143714046786142`, 0.31854295082044043`, 0.9342134339925504]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.1855941681935362, 0.31240161649428533`, 0.9338806853654305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 110}], {
             RGBColor[
             0.18045196756199675`, 0.30699683759618646`, 0.9335878446466683]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 174}], {
             RGBColor[
             0.18540537254043327`, 0.31220318029253835`, 0.9338699337322844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 63}], {
             RGBColor[
             0.1871120628164008, 0.3139970199829937, 0.9339671272186787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 70}], {
             RGBColor[
             0.18680103840766088`, 0.3136701136093215, 0.9339494148387204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 110}], {
             RGBColor[
             0.18133894646584242`, 0.3079291086618389, 0.9336383567830746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 138}], {
             RGBColor[
             0.20221257093783607`, 0.32986861144613544`, 0.9348270788169946]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 145}], {
             RGBColor[
             0.1863723647153286, 0.3132195503791984, 0.9339250025061079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 185}], {
             RGBColor[
             0.2073008742546082, 0.33521674084912667`, 0.9351168501634146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 45}], {
             RGBColor[
             0.47344467906469456`, 0.5697056609217193, 0.9542881258612889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 47}], {
             RGBColor[
             0.21605368220731502`, 0.34441649696749876`, 0.9356153096277022]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 50}], {
             RGBColor[
             0.21979652604601302`, 0.3483504631519761, 0.935828459047275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 97}], {
             RGBColor[
             0.22632286746697683`, 0.35521006177935477`, 0.9362001245363418]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 101}], {
             RGBColor[
             0.21602037207300215`, 0.3443814859043514, 0.9356134126648311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 105}], {
             RGBColor[
             0.22080146805015013`, 0.3494067209153274, 0.9358856890077321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 134}], {
             RGBColor[
             0.24135977409579584`, 0.37101480404118925`, 0.9370564541237432]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 135}], {
             RGBColor[
             0.21639131765151565`, 0.3447713732266772, 0.9356345374667627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 160}], {
             RGBColor[
             0.33951855272220766`, 0.4617555701348826, 0.9431015867680459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 43}], {
             RGBColor[
             0.1854358891920559, 0.31223525522826123`, 0.9338716716104489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 60}], {
             RGBColor[
             0.18105257981885614`, 0.3076281191591622, 0.9336220486261704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 90}], {
             RGBColor[
             0.20419753034223448`, 0.33195492963385337`, 0.9349401193185908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 111}], {
             RGBColor[
             0.200630301320241, 0.32820554575635497`, 0.9347369709030307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 165}], {
             RGBColor[
             0.19346381204820906`, 0.3206731111497857, 0.9343288499408593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 169}], {
             RGBColor[
             0.18660872237456455`, 0.31346797726499653`, 0.9339384627251416]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 41}], {
             RGBColor[
             0.2713842645263738, 0.40257244714637036`, 0.9387663044365115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 74}], {
             RGBColor[
             0.29899639389246113`, 0.42815658036720006`, 0.9404646551119514]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 85}], {
             RGBColor[
             0.26126709675452753`, 0.3919386623526739, 0.9381901466989133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 88}], {
             RGBColor[
             0.2343125277851679, 0.36360770134749604`, 0.9366551238718196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 108}], {
             RGBColor[
             0.2800444750057945, 0.41167487744929976`, 0.9392594906116811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 117}], {
             RGBColor[
             0.21869250923105948`, 0.34719007148075093`, 0.9357655869229098]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 133}], {
             RGBColor[
             0.2505927164379196, 0.38071921184511703`, 0.9375822565312131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 152}], {
             RGBColor[
             0.22612393827552923`, 0.3550009745863041, 0.9361887958131783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 159}], {
             RGBColor[
             0.25347717812255377`, 0.3837509639611013, 0.9377465223569743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 173}], {
             RGBColor[
             0.3099077362629189, 0.437607436708477, 0.9411599161992759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 178}], {
             RGBColor[
             0.21785481111783467`, 0.34630959765062364`, 0.935717881254625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 49}], {
             RGBColor[
             0.46409235069374777`, 0.5749693711032751, 0.9511864931575826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 53}], {
             RGBColor[
             0.5688067096740002, 0.6608219372204345, 0.9591976942746201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 54}], {
             RGBColor[
             0.7471114929956602, 0.7911014986375555, 0.6818242326049438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 64}], {
             RGBColor[
             0.5676806016913061, 0.6599077120294969, 0.959109042929153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.7310843955752011, 0.737038335696917, 0.6195619855898489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 69}], {
             RGBColor[
             0.37782213400795434`, 0.4947977837110262, 0.9458889334343104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 119}], {
             RGBColor[
             0.7331606540356427, 0.4438514188607542, 0.44639585966273576`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 123}], {
             RGBColor[
             0.4784773066745961, 0.5874288969649759, 0.9521030898325651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 132}], {
             RGBColor[
             0.40319785832980803`, 0.5214692788871429, 0.94733404339442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 171}], {
             RGBColor[
             0.40679020531210003`, 0.5252450633334856, 0.9475386222406603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 182}], {
             RGBColor[
             0.4233315585574587, 0.5396644216518027, 0.9485892515260115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 191}], {
             RGBColor[
             0.6579669038121483, 0.7306365663260646, 0.9679735835576617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 195}], {
             RGBColor[
             0.5034310381865006, 0.6077470219664445, 0.9540510819361487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 196}], {
             RGBColor[
             0.3694081793861806, 0.4859541839280068, 0.9454097711659308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 199}], {
             RGBColor[
             0.7505454658303996, 0.8010014916056775, 0.8412228920171474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 74}], {
             RGBColor[
             0.31831841781976944`, 0.44846525260187575`, 0.9415650157902389]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 85}], {
             RGBColor[
             0.2805891206818358, 0.4122473345873495, 0.9392905073772007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.2536345517124762, 0.3839163735821717, 0.937755484550107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 108}], {
             RGBColor[
             0.29936649893310274`, 0.4319835496839754, 0.9403598512899686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 121}], {
             RGBColor[
             0.25402964955357293`, 0.38433164646381435`, 0.9377779847876626]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 133}], {
             RGBColor[
             0.2699147403652278, 0.4010278840797926, 0.9386826172095004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 140}], {
             RGBColor[
             0.6422147641826323, 0.7059320445833706, 0.7490291245213738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 151}], {
             RGBColor[
             0.6423047351050197, 0.7073139713016436, 0.8452851258395946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 152}], {
             RGBColor[
             0.2454459622028375, 0.3753096468209797, 0.9372891564914656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 159}], {
             RGBColor[
             0.27279920204986197`, 0.40405963619577695`, 0.9388468830352616]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 161}], {
             RGBColor[
             0.2872671394725109, 0.41926635574719545`, 0.9396708106680862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 173}], {
             RGBColor[
             0.32922976019022715`, 0.45791610894315266`, 0.9422602768775632]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 51}], {
             RGBColor[
             0.1924833774375055, 0.31964261221079154`, 0.9342730156402028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 71}], {
             RGBColor[
             0.2832544040591832, 0.40996427332420193`, 0.9396284576905798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 73}], {
             RGBColor[
             0.2101247127148807, 0.3381847741125724, 0.9352776635862325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 76}], {
             RGBColor[
             0.23350932118742207`, 0.36276348028702554`, 0.9366093824443157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 81}], {
             RGBColor[
             0.25440003735864936`, 0.3847209475308929, 0.9377990778252221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 87}], {
             RGBColor[
             0.20973659970745412`, 0.3377768427339811, 0.9352555611246214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 89}], {
             RGBColor[
             0.2351425012723703, 0.3644800561059042, 0.93670238963408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 106}], {
             RGBColor[
             0.19390013127031533`, 0.3211317103164559, 0.9343536976750818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 107}], {
             RGBColor[
             0.21020159060141025`, 0.3382655776456545, 0.9352820416681398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 130}], {
             RGBColor[
             0.1935327654101925, 0.32074558550512594`, 0.9343327767328169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 131}], {
             RGBColor[
             0.19213265043958744`, 0.3192739758986036, 0.9342530422565254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 142}], {
             RGBColor[
             0.23238403787365935`, 0.361580736177178, 0.9365452992243044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 147}], {
             RGBColor[
             0.22614743845474522`, 0.3550256747646575, 0.9361901341136192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 149}], {
             RGBColor[
             0.1941370173040445, 0.32138069255734725`, 0.9343671879842612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 157}], {
             RGBColor[
             0.2045975584295754, 0.3323753845168943, 0.9349629003263764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 168}], {
             RGBColor[
             0.20608379372382724`, 0.3339375120439133, 0.935047539227696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 176}], {
             RGBColor[
             0.21842899524564835`, 0.34691310157433214`, 0.9357505801912747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 188}], {
             RGBColor[
             0.2579862693567474, 0.38807828505832953`, 0.9380183944910747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 189}], {
             RGBColor[
             0.19860085363697447`, 0.32607246756682684`, 0.9346213968597675]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 197}], {
             RGBColor[
             0.20173805393446126`, 0.32936986398947277`, 0.9348000557756375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 60}], {
             RGBColor[
             0.18536402715025152`, 0.3121597236660082, 0.9338675791734785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[
             0.20850897767362986`, 0.33648653414069934`, 0.935185649865899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 111}], {
             RGBColor[
             0.2049417486516364, 0.33273715026320094`, 0.934982501450339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 115}], {
             RGBColor[
             0.25238630356085545`, 0.3820238241610014, 0.9377056558638687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 163}], {
             RGBColor[
             0.2357550055079826, 0.36512383689254435`, 0.9367372708441793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 165}], {
             RGBColor[
             0.19777525937960444`, 0.32520471565663167`, 0.9345743804881674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 169}], {
             RGBColor[
             0.19092016970595993`, 0.3179995817718425, 0.9341839932724498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 58}], {
             RGBColor[
             0.9296752902178356, 0.8016782468054864, 0.5944321925119014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 68}], {
             RGBColor[
             0.9298826077939246, 0.7566572199616033, 0.27010292258186963`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 77}], {
             RGBColor[
             0.8444706345429746, 0.3004972543273192, 0.1885609342401168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 96}], {
             RGBColor[
             0.9175951806585165, 0.7926689208755102, 0.6148806669986575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 99}], {
             RGBColor[
             0.7252973005063621, 0.6401348451070372, 0.5975536479428364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 102}], {
             RGBColor[
             0.9339747756675465, 0.8048847960141194, 0.5871542851309398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[
             0.6650402658915442, 0.5906178095064059, 0.5929751287851128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 143}], {
             RGBColor[
             0.8772182848102179, 0.7604919813860003, 0.611670932866671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 166}], {
             RGBColor[
             0.8512516278317916, 0.7399182542257667, 0.6091593456597434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 172}], {
             RGBColor[
             0.8840573238836684, 0.5664132115032791, 0.22496692784453026`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 198}], {
             RGBColor[
             0.6221986923143263, 0.5535105917539171, 0.5902453016000886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 64}], {
             RGBColor[
             0.6702869821102313, 0.7421560430065834, 0.9679059544483493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 112}], {
             RGBColor[
             0.8262269535061243, 0.8650081965468237, 0.9779469895534628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 132}], {
             RGBColor[
             0.5058042387487333, 0.6037176098642293, 0.9561309549136163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 134}], {
             RGBColor[
             0.478958077481094, 0.5755005922270049, 0.9546021057447607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 153}], {
             RGBColor[
             0.49664985237205533`, 0.594095769360721, 0.9556096261521655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 156}], {
             RGBColor[
             0.7828261103538363, 0.35464903211387533`, 0.43431617389061594`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 183}], {
             RGBColor[
             0.823713544812509, 0.7798413316678898, 0.6197525703698252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 47}], {
             RGBColor[
             0.1896200136619846, 0.31663303533497, 0.934109951309154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 50}], {
             RGBColor[
             0.1933628575006826, 0.3205670015194474, 0.9343231007287265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 101}], {
             RGBColor[
             0.18958670352767176`, 0.3165980242718227, 0.9341080543462827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 105}], {
             RGBColor[
             0.19436779950481975`, 0.32162325928279867`, 0.9343803306891837]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 135}], {
             RGBColor[
             0.18995764910618526`, 0.3169879115941485, 0.9341291791482143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 144}], {
             RGBColor[
             0.19073384687984102`, 0.31780374466804207`, 0.9341733824631423]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 50}], {
             RGBColor[
             0.2000038325739316, 0.3275470873835711, 0.9347012944347058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 101}], {
             RGBColor[
             0.19622767860092072`, 0.3235781101359464, 0.934486248052262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 105}], {
             RGBColor[
             0.2010087745780687, 0.32860334514692235`, 0.934758524395163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 134}], {
             RGBColor[
             0.22156708062371444`, 0.3502114282727843, 0.9359292895111742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 135}], {
             RGBColor[
             0.19659862417943424`, 0.3239679974582722, 0.9345073728541936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 144}], {
             RGBColor[
             0.19737482195309003`, 0.32478383053216575`, 0.9345515761691217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 72}], {
             RGBColor[
             0.23184751916348642`, 0.3610168209955353, 0.9365147452774683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 76}], {
             RGBColor[
             0.23737108877035865`, 0.36682244286689847`, 0.9368293043951907]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 81}], {
             RGBColor[
             0.2582618049415859, 0.3887799101107659, 0.938018999776097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 87}], {
             RGBColor[
             0.21359836729039067`, 0.3418358053138541, 0.9354754830754963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 104}], {
             RGBColor[
             0.28879698411440874`, 0.4154790711874804, 0.939955479525905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 106}], {
             RGBColor[
             0.1977618988532519, 0.32519067289632886`, 0.9345736196259569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 147}], {
             RGBColor[
             0.2300092060376818, 0.3590846373445305, 0.9364100560644943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 154}], {
             RGBColor[
             0.2711822856025334, 0.4002221046769836, 0.9388330865127945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 157}], {
             RGBColor[
             0.20845932601251194`, 0.33643434709676723`, 0.9351828222772515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 158}], {
             RGBColor[
             0.2634190473924112, 0.39349797793107355`, 0.9383384198388076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 176}], {
             RGBColor[
             0.2222907628285849, 0.3509720641542051, 0.9359705021421497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 53}], {
             RGBColor[
             0.5270688387556056, 0.6260965211703475, 0.956144232988289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 54}], {
             RGBColor[
             0.7053736220772657, 0.7563760825874686, 0.6787707713186126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 65}], {
             RGBColor[
             0.6893465246568067, 0.7023129196468301, 0.6165085243035178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 69}], {
             RGBColor[
             0.33608426308955985`, 0.46007236766093923`, 0.9428354721479792]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 92}], {
             RGBColor[
             0.33340074855062923`, 0.45725182373587436`, 0.9426826499648912]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 118}], {
             RGBColor[
             0.4066109576924045, 0.5266077075173656, 0.9471298685655758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 119}], {
             RGBColor[
             0.705335406756713, 0.42070114149402954`, 0.44436021880518173`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 123}], {
             RGBColor[
             0.43673943575620155`, 0.552703480914889, 0.949049628546234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 127}], {
             RGBColor[
             0.6485709500663741, 0.7216198574234791, 0.9680261155142653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[
             0.4384127064842775, 0.5541214790792388, 0.9491648974977769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 139}], {
             RGBColor[
             0.3540112919659183, 0.4789148116492719, 0.9438563899218253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 141}], {
             RGBColor[
             0.3830851867065078, 0.5062308671290127, 0.9456308272413769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 146}], {
             RGBColor[
             0.3338791466944457, 0.45775465051721964`, 0.9427098940314549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 155}], {
             RGBColor[
             0.5477722741141999, 0.6424322100267535, 0.9580969923209677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 171}], {
             RGBColor[
             0.36505233439370555`, 0.4905196472833987, 0.9444851609543292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 191}], {
             RGBColor[
             0.6162290328937537, 0.6959111502759776, 0.9649201222713306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 195}], {
             RGBColor[
             0.46169316726810605`, 0.5730216059163575, 0.9509976206498176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 196}], {
             RGBColor[
             0.3276703084677861, 0.4512287678779199, 0.9423563098795996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 199}], {
             RGBColor[
             0.7088075949120052, 0.7662760755555905, 0.8381694307308162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 97}], {
             RGBColor[
             0.21027301783359342`, 0.33834065219542714`, 0.9352861093433454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 101}], {
             RGBColor[
             0.19997052243961871`, 0.3275120763204238, 0.9346993974718347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 105}], {
             RGBColor[
             0.2047516184167667, 0.33253731133139974`, 0.9349716738147356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 134}], {
             RGBColor[
             0.22530992446241244`, 0.3541453944572617, 0.9361424389307468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 135}], {
             RGBColor[
             0.20034146801813224`, 0.3279019636427496, 0.9347205222737662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 144}], {
             RGBColor[
             0.20111766579178803`, 0.32871779671664314`, 0.9347647255886942]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 73}], {
             RGBColor[
             0.19983789794558066`, 0.3273726795683112, 0.9346918447030995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 87}], {
             RGBColor[
             0.19944978493815407`, 0.3269647481897199, 0.9346697422414884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 106}], {
             RGBColor[
             0.1836133165010153, 0.31031961577219463`, 0.9337678787919488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[
             0.1999147758321102, 0.3274534831013933, 0.9346962227850067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 130}], {
             RGBColor[
             0.18324595064089247`, 0.3099334909608647, 0.933746957849684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 131}], {
             RGBColor[
             0.18184583567028742`, 0.3084618813543424, 0.9336672233733925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 147}], {
             RGBColor[
             0.2158606236854452, 0.3442135802203963, 0.9356043152304863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 157}], {
             RGBColor[
             0.19431074366027534`, 0.32156328997263306`, 0.9343770814432435]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 168}], {
             RGBColor[
             0.1957969789545272, 0.32312541749965207`, 0.934461720344563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 189}], {
             RGBColor[
             0.18831403886767445`, 0.3152603730225656, 0.9340355779766345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 197}], {
             RGBColor[
             0.1914512391651612, 0.3185577694452115, 0.9342142368925045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 66}], {
             RGBColor[
             0.18456752137294713`, 0.3113225455926782, 0.9338222193477858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 80}], {
             RGBColor[
             0.20369103159656846`, 0.33142256733828307`, 0.9349112749643229]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 82}], {
             RGBColor[
             0.1987769890735687, 0.32625759707831903`, 0.9346314275123124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 100}], {
             RGBColor[
             0.1956898688928864, 0.3230128380336974, 0.9344556205850076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 120}], {
             RGBColor[
             0.1897634736745903, 0.3167838209041087, 0.9341181211446418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 124}], {
             RGBColor[
             0.20581307491926143`, 0.333652969415751, 0.9350321221922685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 125}], {
             RGBColor[
             0.2249359881773202, 0.35375236371269986`, 0.9361211438124999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 187}], {
             RGBColor[
             0.19453498240935546`, 0.32179897911547406`, 0.934389851508272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 54}], {
             RGBColor[
             0.810087981057518, 0.842228648704628, 0.6867819724356502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 65}], {
             RGBColor[
             0.7940608836370591, 0.7881654857639895, 0.6245197254205552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 69}], {
             RGBColor[
             0.4407986220698122, 0.5459249337780987, 0.9508466732650168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 92}], {
             RGBColor[
             0.4381151075308816, 0.5431043898530338, 0.9506938510819287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 118}], {
             RGBColor[
             0.5113253166726569, 0.612460273634525, 0.9551410696826135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 119}], {
             RGBColor[
             0.7751449794102145, 0.4779361855721358, 0.4497010195498735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 123}], {
             RGBColor[
             0.5414537947364539, 0.6385560470320484, 0.9570608296632714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 127}], {
             RGBColor[
             0.7532853090466265, 0.8074724235406385, 0.9760373166313029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 129}], {
             RGBColor[
             0.5431270654645298, 0.6399740451963982, 0.9571760986148143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 139}], {
             RGBColor[
             0.4587256509461706, 0.5647673777664313, 0.9518675910388628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 141}], {
             RGBColor[
             0.4877995456867602, 0.5920834332461721, 0.9536420283584146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 146}], {
             RGBColor[
             0.438593505674698, 0.543607216634379, 0.9507210951484925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 155}], {
             RGBColor[
             0.6524866330944523, 0.728284776143913, 0.9661081934380052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 171}], {
             RGBColor[
             0.4697666933739579, 0.5763722134005581, 0.9524963620713668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 182}], {
             RGBColor[
             0.48630804661931654`, 0.5907915717188752, 0.9535469913567178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 191}], {
             RGBColor[
             0.720943391874006, 0.781763716393137, 0.9729313233883682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 195}], {
             RGBColor[
             0.5664075262483584, 0.658874172033517, 0.9590088217668552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 196}], {
             RGBColor[
             0.43238466744803844`, 0.5370813339950793, 0.9503675109966372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 199}], {
             RGBColor[
             0.8135219538922576, 0.8521286416727499, 0.8461806318478537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 64}], {
             RGBColor[
             0.8089618730748239, 0.8413144235136905, 0.6866933210901831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 65}], {
             RGBColor[
             0.9723656669587191, 0.9184450471811106, 0.347146263750879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 118}], {
             RGBColor[
             0.6896300999943169, 0.7427398350516461, 0.6777676080129371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 119}], {
             RGBColor[
             0.894014834957988, 0.5647892265168832, 0.26478537843675587`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 123}], {
             RGBColor[
             0.7197585780581139, 0.7688356084491694, 0.6796873679935951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 127}], {
             RGBColor[
             0.9315900923682865, 0.9377519849577597, 0.6986638549616266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 140}], {
             RGBColor[
             0.9910580021453803, 0.9807455899537222, 0.48380004734696136`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 151}], {
             RGBColor[
             0.9911479730677677, 0.9821275166719952, 0.580056048665182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 155}], {
             RGBColor[
             0.8307914164161123, 0.8585643375610341, 0.688734731768329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 171}], {
             RGBColor[
             0.6480714766956179, 0.7066517748176793, 0.6751229004016905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 172}], {
             RGBColor[
             0.9288667542587956, 0.7360484350731749, 0.311047781867342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 191}], {
             RGBColor[
             0.899248175195666, 0.9120432778102582, 0.6955578617186919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 195}], {
             RGBColor[
             0.7447123095700184, 0.789153733450638, 0.681635360097179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 199}], {
             RGBColor[
             0.9918267372139176, 0.9824082030898711, 0.5688071701781774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 90}], {
             RGBColor[
             0.281574426125484, 0.41077439271759675`, 0.9394384697479637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 108}], {
             RGBColor[
             0.3219524714198415, 0.4532142784379034, 0.9417379396935124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 111}], {
             RGBColor[
             0.27800719710349053`, 0.40702500884009835`, 0.9392353213324036]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 115}], {
             RGBColor[
             0.3254517520127096, 0.4563116827378988, 0.9419584757459334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 163}], {
             RGBColor[
             0.3088204539598367, 0.4394116954694417, 0.9409900907262441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.2708407078314586, 0.3994925742335291, 0.9388272003702323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 175}], {
             RGBColor[
             0.4182247539712943, 0.5353839569381427, 0.9482243963930945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 177}], {
             RGBColor[
             0.2766340766323431, 0.4055817721640561, 0.9391571241529215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 183}], {
             RGBColor[
             0.6361311703010923, 0.6254168955585735, 0.6051471025896153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 109}], {
             RGBColor[
             0.19998929422011852`, 0.3275318066519287, 0.9347004664969638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 148}], {
             RGBColor[
             0.18807327130146562`, 0.31500731104493473`, 0.9340218666199227]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 150}], {
             RGBColor[
             0.18756580923325702`, 0.31447393623629405`, 0.933992967405861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 193}], {
             RGBColor[
             0.2060154437903921, 0.33386567193023686`, 0.9350436468001014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 88}], {
             RGBColor[
             0.1992012217508764, 0.32670349252007475`, 0.9346555869356892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 91}], {
             RGBColor[
             0.18403700151578473`, 0.31076493558589874`, 0.9337920070267542]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 103}], {
             RGBColor[
             0.1814602470714449, 0.3080566032892297, 0.9336452646731157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 117}], {
             RGBColor[
             0.18358120319676802`, 0.31028586265332964`, 0.9337660499867794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 121}], {
             RGBColor[
             0.1995963195919732, 0.32711876540171747`, 0.9346780871732447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 152}], {
             RGBColor[
             0.19101263224123774`, 0.3180967657588828, 0.9341892588770478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 164}], {
             RGBColor[
             0.1885063938143962, 0.3154625502675782, 0.9340465323062868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 178}], {
             RGBColor[
             0.1827435050835432, 0.30940538882320234`, 0.9337183443184945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 200}], {
             RGBColor[
             0.1862266556746971, 0.31306640093900795`, 0.9339167045918012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 77}], {
             RGBColor[
             0.8650715589355825, 0.41279091020967174`, 0.42668452743448415`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 96}], {
             RGBColor[
             0.9484965672474285, 0.961109404699039, 0.9720660567902085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 99}], {
             RGBColor[
             0.7561986870952739, 0.8085753289305662, 0.9547390377343874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 102}], {
             RGBColor[
             0.9648761622564584, 0.9733252798376484, 0.9443396749224908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 125}], {
             RGBColor[
             0.6124298936125201, 0.6826137072843086, 0.9449897432593624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 128}], {
             RGBColor[
             0.695941652480456, 0.7590582933299347, 0.9501605185766638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 137}], {
             RGBColor[
             0.6422345288762541, 0.7125398822624958, 0.9467383481519487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 166}], {
             RGBColor[
             0.8821530144207035, 0.9083587380492957, 0.9663447354512944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 170}], {
             RGBColor[
             0.8078923228953876, 0.8503457214275595, 0.9589431237256691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 192}], {
             RGBColor[
             0.7131454310850844, 0.7736227561744136, 0.951349727711992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 198}], {
             RGBColor[
             0.6531000789032383, 0.7219510755774461, 0.9474306913916395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 62}], {
             RGBColor[
             0.19206220882201708`, 0.3191999372922807, 0.9342490307106137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 92}], {
             RGBColor[
             0.21433501599530952`, 0.3426100698089493, 0.9355174341294674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 114}], {
             RGBColor[
             0.1828190891221793, 0.3094848324401137, 0.9337226487176782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 146}], {
             RGBColor[
             0.21481341413912597`, 0.34311289659029465`, 0.935544678196031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 184}], {
             RGBColor[
             0.1830159493280225, 0.30969174499811286`, 0.9337338596151724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 186}], {
             RGBColor[
             0.18364549933831636`, 0.3103534419747078, 0.9337697115569229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[
             0.19287248204991897`, 0.32005158582909543`, 0.934295174572251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 90}], {
             RGBColor[
             0.2041256683004301, 0.33187939807160033`, 0.9349360268816205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 111}], {
             RGBColor[
             0.20055843927843664`, 0.3281300141941019, 0.9347328784660603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 165}], {
             RGBColor[
             0.1933919500064047, 0.32059757958753266`, 0.9343247575038889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 169}], {
             RGBColor[
             0.18653686033276015`, 0.3133924457027435, 0.9339343702881713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 67}], {
             RGBColor[
             0.2316153172023224, 0.36077276201189723`, 0.936501521719292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 79}], {
             RGBColor[
             0.20075917656457537`, 0.3283410018093128, 0.9347443101575417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 84}], {
             RGBColor[
             0.19428775253280067`, 0.3215391248399355, 0.9343757721325461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 122}], {
             RGBColor[
             0.24263213866310665`, 0.37235213987400595`, 0.9371289134035569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 126}], {
             RGBColor[
             0.19350305800530745`, 0.3207143611390335, 0.9343310849400568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 179}], {
             RGBColor[
             0.2879403991921272, 0.41444560530367136`, 0.9399115732194068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 190}], {
             RGBColor[
             0.1957633885191688, 0.3230901118223337, 0.9344598074189618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 192}], {
             RGBColor[
             0.33652735532483224`, 0.4561925991586039, 0.9431004906757697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 114}], {
             RGBColor[
             0.19065828327948256`, 0.31772432253305627`, 0.9341690792278882]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 141}], {
             RGBColor[
             0.2718586483084913, 0.3998286032950302, 0.9389120419161632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 149}], {
             RGBColor[
             0.19270262269030192`, 0.3198730528724325, 0.9342855013330051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 167}], {
             RGBColor[
             0.19961760381417978`, 0.3271411364687542, 0.9346792992782123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 184}], {
             RGBColor[
             0.19085514348532573`, 0.3179312350910555, 0.9341802901253824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 189}], {
             RGBColor[
             0.19716645902323188`, 0.3245648278819121, 0.9345397102085116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 194}], {
             RGBColor[
             0.2007116762072222, 0.32829107592203804`, 0.9347416050824608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 197}], {
             RGBColor[
             0.20030365932071864`, 0.327862224304558, 0.9347183691243814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 70}], {
             RGBColor[
             0.1913615767368444, 0.3184635285481242, 0.9342091307498555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 110}], {
             RGBColor[
             0.18589948479502594`, 0.3127225236006417, 0.9338980726942099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 132}], {
             RGBColor[
             0.24611904809652904`, 0.37601710277136, 0.9373274877373701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 138}], {
             RGBColor[
             0.20677310926701956`, 0.33466202638493814`, 0.9350867947281298]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 145}], {
             RGBColor[
             0.1909329030445121, 0.31801296531800116`, 0.9341847184172432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 153}], {
             RGBColor[
             0.23696466171985112`, 0.36639526226785174`, 0.9368061589759192]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 185}], {
             RGBColor[
             0.2118614125837917, 0.3400101557879294, 0.9353765660745497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 65}], {
             RGBColor[
             0.792934775654365, 0.787251260573052, 0.6244310740750881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 132}], {
             RGBColor[
             0.4650482384089718, 0.5716822037632778, 0.9522031318796592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 138}], {
             RGBColor[
             0.4257022995794623, 0.5303271273768558, 0.949962438870419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 153}], {
             RGBColor[
             0.4558938520322939, 0.5620603632597695, 0.9516818031182084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 156}], {
             RGBColor[
             0.755655443460662, 0.33329209471324106`, 0.43169762520131116`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 182}], {
             RGBColor[
             0.48518193863662246`, 0.5898773465279377, 0.9534583400112507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 185}], {
             RGBColor[
             0.4307906028962345, 0.5356752567798472, 0.9502522102168389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 199}], {
             RGBColor[
             0.8123958459095635, 0.8512144164818124, 0.8460919805023865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 118}], {
             RGBColor[
             0.6736030025738579, 0.6886766721110076, 0.6155053609978421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 119}], {
             RGBColor[
             0.8833301033443486, 0.5287471178897909, 0.2232772137600259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 123}], {
             RGBColor[
             0.7037314806376549, 0.7147724455085309, 0.6174251209785002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 127}], {
             RGBColor[
             0.9155629949478274, 0.8836888220171212, 0.6364016079465316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 140}], {
             RGBColor[
             0.9750309047249213, 0.9266824270130837, 0.4215378003318664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 151}], {
             RGBColor[
             0.9751208756473086, 0.9280643537313567, 0.5177938016500871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 155}], {
             RGBColor[
             0.8147643189956533, 0.8045011746203956, 0.6264724847532339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 156}], {
             RGBColor[
             0.8645913060499254, 0.38471251049152105`, 0.20533292030844175`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 171}], {
             RGBColor[
             0.6320443792751589, 0.6525886118770408, 0.6128606533865955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 172}], {
             RGBColor[
             0.9128396568383367, 0.6819852721325363, 0.24878553485224705`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 191}], {
             RGBColor[
             0.8832210777752071, 0.8579801148696197, 0.6332956147035969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 195}], {
             RGBColor[
             0.7286852121495595, 0.7350905705099995, 0.6193731130820839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 199}], {
             RGBColor[
             0.9757996397934585, 0.9283450401492326, 0.5065449231630825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 78}], {
             RGBColor[
             0.18323872675967784`, 0.30992589820368766`, 0.9337465464603355]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 80}], {
             RGBColor[
             0.20266968703316796`, 0.3303490694451636, 0.9348531109023811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 82}], {
             RGBColor[
             0.1977556445101682, 0.32518409918519964`, 0.9345732634503707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[
             0.18802367047876978`, 0.3149551774354076, 0.9340190419264479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 100}], {
             RGBColor[
             0.1946685243294859, 0.3219393401405779, 0.9343974565230659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 113}], {
             RGBColor[
             0.1939997700984511, 0.32123643704229315`, 0.9343593719589416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 120}], {
             RGBColor[
             0.18874212911118976`, 0.3157103230109893, 0.9340599570827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 124}], {
             RGBColor[
             0.2047917303558609, 0.33257947152263156`, 0.9349739581303267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 136}], {
             RGBColor[
             0.2031791949691239, 0.33088459459052233`, 0.9348821266255843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 187}], {
             RGBColor[
             0.19351363784595493`, 0.32072548122235467`, 0.9343316874463302]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 79}], {
             RGBColor[
             0.22503396848065443`, 0.3538553472238142, 0.9361267236458259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 82}], {
             RGBColor[
             0.2339276106645956, 0.3632031290486195, 0.9366332034112368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 100}], {
             RGBColor[
             0.2308404904839133, 0.3599583700039979, 0.936457396483932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 122}], {
             RGBColor[
             0.26690693057918574`, 0.3978664852885073, 0.9385113268918411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 125}], {
             RGBColor[
             0.2600866097683471, 0.39069789568300034`, 0.9381229197114243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 137}], {
             RGBColor[
             0.289891245032081, 0.42062407066118745`, 0.9398715246040107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 166}], {
             RGBColor[
             0.5298097305765306, 0.6164429264479874, 0.9594779119033563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 170}], {
             RGBColor[
             0.45554903905121463`, 0.5584299098262512, 0.952076300177731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 179}], {
             RGBColor[
             0.3122151911082063, 0.43995995071817273`, 0.941293986707691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 192}], {
             RGBColor[
             0.36080214724091136`, 0.4817069445731053, 0.944482904164054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 71}], {
             RGBColor[
             0.6623649639352431, 0.6847752584173, 0.6236785616506062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 75}], {
             RGBColor[
             0.7315668061877028, 0.7433887217645079, 0.6284543351107399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 81}], {
             RGBColor[
             0.6335105972347094, 0.659531932623991, 0.6218491817852485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 102}], {
             RGBColor[
             0.9650834798325474, 0.9283042529937652, 0.6200104049924591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 127}], {
             RGBColor[
             0.9178893661581602, 0.8915362183675095, 0.645439120800334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 129}], {
             RGBColor[
             0.7077311225760636, 0.7240378400232692, 0.6265779027838456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 140}], {
             RGBColor[
             0.977357275935254, 0.934529823363472, 0.4305753131856688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 143}], {
             RGBColor[
             0.9083269889752188, 0.8839114383656459, 0.6445270527281901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 155}], {
             RGBColor[
             0.817090690205986, 0.812348570970784, 0.6355099976070364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 172}], {
             RGBColor[
             0.9151660280486694, 0.6898326684829248, 0.25782304770604947`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 188}], {
             RGBColor[
             0.6370968292328074, 0.6628892701514275, 0.6220684984511013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 86}], {
             RGBColor[
             0.22595538032998164`, 0.3548238094983426, 0.9361791966875385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 92}], {
             RGBColor[
             0.2471305318648358, 0.3770802363436254, 0.937385090241619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 118}], {
             RGBColor[
             0.32034074100661103`, 0.44643612012511674`, 0.9418323088423037]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 123}], {
             RGBColor[
             0.3504692190704081, 0.47253189352264, 0.9437520688229617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 139}], {
             RGBColor[
             0.2677410752801248, 0.398743224257023, 0.938558830198553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 146}], {
             RGBColor[
             0.24760893000865222`, 0.37758306312497075`, 0.9374123343081827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 171}], {
             RGBColor[
             0.27878211770791206`, 0.41034805989114986`, 0.939187601231057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 174}], {
             RGBColor[
             0.21992361240255348`, 0.34848403897044045`, 0.9358356964272725]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 186}], {
             RGBColor[
             0.21644101520784265`, 0.3448236085093839, 0.9356373676690746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 191}], {
             RGBColor[
             0.5299588162079603, 0.6157395628837288, 0.9596225625480584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 195}], {
             RGBColor[
             0.3754229505823126, 0.4928500185241086, 0.9457000609265455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 196}], {
             RGBColor[
             0.24140009178199262`, 0.37105718048567105`, 0.9370587501563274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 110}], {
             RGBColor[
             0.185588460386286, 0.31239561722696946`, 0.9338803603142515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 132}], {
             RGBColor[
             0.2458080236877891, 0.37569019639768786`, 0.9373097753574117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 138}], {
             RGBColor[
             0.2064620848582796, 0.334335120011266, 0.9350690823481714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.19062187863577218`, 0.31768605894432894`, 0.9341670060372848]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 185}], {
             RGBColor[
             0.21155038817505178`, 0.3396832494142572, 0.9353588536945914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 73}], {
             RGBColor[
             0.29060892456725834`, 0.41769434068172157`, 0.9400472867534765]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 75}], {
             RGBColor[
             0.4329404581640204, 0.5480873032405589, 0.9491738543179573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 76}], {
             RGBColor[
             0.3139935330397997, 0.4422730468561747, 0.9413790056115596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 81}], {
             RGBColor[
             0.334884249211027, 0.4642305141000421, 0.942568700992466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 87}], {
             RGBColor[
             0.29022081155983176`, 0.4172864093031303, 0.9400251842918653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 89}], {
             RGBColor[
             0.315626713124748, 0.4439896226750534, 0.9414720128013241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 107}], {
             RGBColor[
             0.2906858024537879, 0.41777514421480366`, 0.9400516648353837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 127}], {
             RGBColor[
             0.6192630181344778, 0.6962347998435606, 0.9661586400075515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 129}], {
             RGBColor[
             0.40910477455238126`, 0.5287364214993203, 0.947297421991063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 141}], {
             RGBColor[
             0.3537772547746116, 0.4808458095490941, 0.9437633517346631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 142}], {
             RGBColor[
             0.312868249726037, 0.44109030274632716`, 0.9413149223915483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 147}], {
             RGBColor[
             0.3066316503071229, 0.4345352413338067, 0.9409597572808632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 155}], {
             RGBColor[
             0.5184643421823038, 0.6170471524468351, 0.9562295168142538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 168}], {
             RGBColor[
             0.2865680055762049, 0.4134470786130624, 0.93981716239494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 188}], {
             RGBColor[
             0.33847048120912504`, 0.4675878516274786, 0.9427880176583188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 197}], {
             RGBColor[
             0.2822222657868389, 0.40887943055862197`, 0.9395696789428815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 76}], {
             RGBColor[
             0.25872488056116644`, 0.3892666319476351, 0.9380453712475731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 81}], {
             RGBColor[
             0.2796155967323937, 0.4112240991915025, 0.9392350666284796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 104}], {
             RGBColor[
             0.31015077590521656`, 0.43792326026821704`, 0.9411715463782875]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 143}], {
             RGBColor[
             0.5544319884729032, 0.6356036049331575, 0.9619129375714212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 144}], {
             RGBColor[
             0.22584498306262032`, 0.3547077749707548, 0.9361729097264804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 154}], {
             RGBColor[
             0.2925360773933412, 0.42266629375772025`, 0.940049153365177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 158}], {
             RGBColor[
             0.284772839183219, 0.41594216701181014`, 0.93955448669119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 160}], {
             RGBColor[
             0.3481960203596565, 0.4708761388050667, 0.9435957557128356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 176}], {
             RGBColor[
             0.2436445546193927, 0.37341625323494165`, 0.9371865689945322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 181}], {
             RGBColor[
             0.345687120645864, 0.46870305597394574`, 0.9434358908416056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 75}], {
             RGBColor[
             0.3598107668197179, 0.47630780402892936`, 0.9448230602136101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 87}], {
             RGBColor[
             0.2170911202155293, 0.3455069100915008, 0.9356743901875181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.2424970217804455, 0.37221012346342386`, 0.9371212186969768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 107}], {
             RGBColor[
             0.21755611110948542`, 0.34599564500317415`, 0.9357008707310365]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 130}], {
             RGBColor[
             0.20088728591826768`, 0.3284756528626456, 0.9347516057957137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 142}], {
             RGBColor[
             0.23973855838173452`, 0.36931080353469764`, 0.9369641282872011]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 147}], {
             RGBColor[
             0.23350195896282042`, 0.3627557421221772, 0.936608963176516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 149}], {
             RGBColor[
             0.2014915378121197, 0.32911075991486693`, 0.934786017047158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 157}], {
             RGBColor[
             0.21195207893765056`, 0.34010545187441393`, 0.9353817293892732]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 167}], {
             RGBColor[
             0.20840651893599757`, 0.33637884351118863`, 0.9351798149923649]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 168}], {
             RGBColor[
             0.2134383142319024, 0.3416675794014329, 0.9354663682905927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 188}], {
             RGBColor[
             0.26534078986482257`, 0.3958083524158491, 0.9384372235539715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 189}], {
             RGBColor[
             0.20595537414504966`, 0.3338025349243465, 0.9350402259226642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 197}], {
             RGBColor[
             0.20909257444253643`, 0.33709993134699245`, 0.9352188848385342]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 85}], {
             RGBColor[
             0.3082012500479231, 0.4378314678081793, 0.9409888580526407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 88}], {
             RGBColor[
             0.2812466810785635, 0.40950050680300143`, 0.9394538352255469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 93}], {
             RGBColor[
             0.28865865838495014`, 0.4172909648985178, 0.9398759363681078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 95}], {
             RGBColor[
             0.29756419393855826`, 0.4266512474089263, 0.9403830934433266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 121}], {
             RGBColor[
             0.28164177891966025`, 0.4099157796846441, 0.9394763354631025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 140}], {
             RGBColor[
             0.6698268935487197, 0.7315161778042003, 0.7507274751968138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 152}], {
             RGBColor[
             0.2730580915689248, 0.4008937800418094, 0.9389875071669056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 159}], {
             RGBColor[
             0.30041133141594933`, 0.42964376941660665`, 0.9405452337107016]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 161}], {
             RGBColor[
             0.31487926883859824`, 0.44485048896802515`, 0.9413691613435261]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 162}], {
             RGBColor[
             0.39867126833608224`, 0.5197307476573095, 0.9466239585805827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 164}], {
             RGBColor[
             0.2705518531420833, 0.3982595645505048, 0.9388447805961444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 172}], {
             RGBColor[
             0.607635645662135, 0.48681902292365303`, 0.5779752097171944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 173}], {
             RGBColor[
             0.35684188955631446`, 0.48350024216398235`, 0.9439586275530032]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 180}], {
             RGBColor[
             0.34398171160205027`, 0.4723614023913367, 0.9431391883855662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 81}], {
             RGBColor[
             0.40408609146348656`, 0.52284397744725, 0.9473444744525996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 89}], {
             RGBColor[
             0.3848285553772075, 0.5026030860222612, 0.9462477862614576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 118}], {
             RGBColor[
             0.44650486801296785`, 0.559836113284655, 0.9500381665189955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 127}], {
             RGBColor[
             0.6884648603869374, 0.7548482631907685, 0.9709344134676849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 129}], {
             RGBColor[
             0.47830661680484077`, 0.5873498848465282, 0.9520731954511965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 141}], {
             RGBColor[
             0.42297909702707115`, 0.5394592728963019, 0.9485391251947967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 142}], {
             RGBColor[
             0.3820700919784965, 0.49970376609353495`, 0.9460906958516819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 147}], {
             RGBColor[
             0.3758334925595824, 0.4931487046810145, 0.9457355307409967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 155}], {
             RGBColor[
             0.5876661844347633, 0.6756606157940428, 0.9610052902743873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 168}], {
             RGBColor[
             0.3557698478286644, 0.47206054196027025`, 0.9445929358550735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 188}], {
             RGBColor[
             0.40767232346158455`, 0.5262013149746865, 0.9475637911184522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 191}], {
             RGBColor[
             0.656122943214317, 0.729139556043267, 0.9678284202247502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 81}], {
             RGBColor[
             0.28513916633926595`, 0.41702972106286573`, 0.9395496257462019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 87}], {
             RGBColor[
             0.2404757286880707, 0.37008561626595393`, 0.9370061090456012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 89}], {
             RGBColor[
             0.2658816302529869, 0.396788829637877, 0.93845293755506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[
             0.3156743455120887, 0.4437288821395802, 0.9414861054960099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 106}], {
             RGBColor[
             0.2246392602509319, 0.35344048384842863`, 0.9361042455960618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 107}], {
             RGBColor[
             0.2409407195820268, 0.37057435117762727`, 0.9370325895891196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 142}], {
             RGBColor[
             0.26312316685427595`, 0.39388950970915076`, 0.9382958471452842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 143}], {
             RGBColor[
             0.5599555580797754, 0.6414092268045206, 0.9622274966891435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 147}], {
             RGBColor[
             0.2568865674353618, 0.38733444829663033`, 0.9379406820345992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 154}], {
             RGBColor[
             0.29805964700021337`, 0.42847191562908343`, 0.9403637124828994]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[
             0.23533668741019195`, 0.36468415804886706`, 0.9367134482473564]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 158}], {
             RGBColor[
             0.2902964087900912, 0.4217477888831733, 0.9398690458089125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 176}], {
             RGBColor[
             0.24916812422626491`, 0.3792218751063049, 0.9375011281122546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 181}], {
             RGBColor[
             0.3512106902527362, 0.4745086778453089, 0.9437504499593281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 188}], {
             RGBColor[
             0.288725398337364, 0.42038705859030223`, 0.9397689424120548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 83}], {
             RGBColor[
             0.8536746611219712, 0.4041310177770272, 0.4404255720532042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 96}], {
             RGBColor[
             0.8570181525627032, 0.40678469292302094`, 0.44031684375898816`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 99}], {
             RGBColor[
             0.7288195657946002, 0.3050953090773723, 0.4287654977217741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 112}], {
             RGBColor[
             0.8586829748540853, 0.4080263146620374, 0.43749873387487304`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 143}], {
             RGBColor[
             0.8301002219971707, 0.3853333999300143, 0.43817702100433054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 156}], {
             RGBColor[
             0.8177852247685861, 0.1377106078723485, 0.16466445736492355`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 160}], {
             RGBColor[
             0.6926095765883397, 0.2755150891779538, 0.42596556643194017`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 166}], {
             RGBColor[
             0.8127891173448866, 0.371617581823192, 0.4365026295330454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 170}], {
             RGBColor[
             0.7632819896613426, 0.3329422374087012, 0.4315682217159619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 181}], {
             RGBColor[
             0.6909369767791447, 0.27406636729053985`, 0.42585898985112014`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 183}], {
             RGBColor[
             0.8570073690583417, 0.35124840474274827`, 0.19870245441911466`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 192}], {
             RGBColor[
             0.7001173951211405, 0.28179359390660397`, 0.42650595770684385`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 80}], {
             RGBColor[
             0.20236223698329917`, 0.33002591994929253`, 0.9348356020768727]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 82}], {
             RGBColor[
             0.1974481944602994, 0.3248609496893285, 0.9345557546248622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 98}], {
             RGBColor[
             0.18771622042890102`, 0.3146320279395365, 0.9340015331009395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 100}], {
             RGBColor[
             0.1943610742796171, 0.3216161906447068, 0.9343799476975574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 113}], {
             RGBColor[
             0.19369232004858233`, 0.320913287546422, 0.9343418631334333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 120}], {
             RGBColor[
             0.188434679061321, 0.31538717351511814`, 0.9340424482571915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 124}], {
             RGBColor[
             0.20448428030599214`, 0.3322563220267605, 0.9349564493048182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 136}], {
             RGBColor[
             0.2028717449192551, 0.3305614450946512, 0.9348646178000759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 187}], {
             RGBColor[
             0.19320618779608617`, 0.3204023317264835, 0.9343141786208218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 84}], {
             RGBColor[
             0.1877064038111327, 0.31462171005185247`, 0.93400097405908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 122}], {
             RGBColor[
             0.2360507899414387, 0.3654347250859229, 0.9367541153300909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 126}], {
             RGBColor[
             0.1869217092836395, 0.3137969463509505, 0.9339562868665908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 177}], {
             RGBColor[
             0.20578387384021699`, 0.33362227723022, 0.9350304592340161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 179}], {
             RGBColor[
             0.2813590504704592, 0.4075281905155883, 0.9395367751459407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 190}], {
             RGBColor[
             0.18918203979750087`, 0.31617269703425077`, 0.9340850093454959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 82}], {
             RGBColor[
             0.2168791547337895, 0.3452841209308045, 0.9356623190669078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 98}], {
             RGBColor[
             0.2071471807023911, 0.33505519918101245`, 0.9351080975429851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 100}], {
             RGBColor[
             0.2137920345531072, 0.3420393618861828, 0.935486512139603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 113}], {
             RGBColor[
             0.2131232803220724, 0.34133645878789803`, 0.9354484275754789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 116}], {
             RGBColor[
             0.23121046425376574`, 0.3603472358938047, 0.936478465942798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 120}], {
             RGBColor[
             0.20786563933481106`, 0.33581034475659416`, 0.9351490126992371]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 124}], {
             RGBColor[
             0.22391524057948223`, 0.35267949326823644`, 0.9360630137468638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 125}], {
             RGBColor[
             0.243038153837541, 0.3727788875651853, 0.9371520353670952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 136}], {
             RGBColor[
             0.2223027051927452, 0.3509846163361272, 0.9359711822421215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 137}], {
             RGBColor[
             0.2728427891012749, 0.40270506254337235`, 0.9389006402596817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 187}], {
             RGBColor[
             0.21263714806957626`, 0.34082550296795955`, 0.9354207430628674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 198}], {
             RGBColor[
             0.28370833912825916`, 0.4121162558583227, 0.9395929834993725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 87}], {
             RGBColor[
             0.261366444859298, 0.3920430835098213, 0.9381958044265076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 89}], {
             RGBColor[
             0.2867723464242142, 0.41874629688174436`, 0.9396426329359664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 104}], {
             RGBColor[
             0.336565061683316, 0.46568634938344766`, 0.9426758008769163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 107}], {
             RGBColor[
             0.26183143575325407`, 0.39253181842149465`, 0.938222284970026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 142}], {
             RGBColor[
             0.28401388302550323`, 0.4158469769530182, 0.9394855425261907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 143}], {
             RGBColor[
             0.5808462742510027, 0.663366694048388, 0.9634171920700499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 147}], {
             RGBColor[
             0.2777772836065891, 0.4092919155404977, 0.9391303774155055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 154}], {
             RGBColor[
             0.31895036317144065`, 0.45042938287295087`, 0.9415534078638058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 157}], {
             RGBColor[
             0.25622740358141927`, 0.3866416252927345, 0.9379031436282628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 158}], {
             RGBColor[
             0.3111871249613185, 0.44370525612704076`, 0.9410587411898188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 168}], {
             RGBColor[
             0.2577136388756711, 0.38820375281975344`, 0.9379877825295823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 176}], {
             RGBColor[
             0.2700588403974922, 0.4011793423501723, 0.938690823493161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 188}], {
             RGBColor[
             0.3096161145085913, 0.44234452583416967`, 0.9409586377929611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 98}], {
             RGBColor[
             0.20223313817939134`, 0.32989022892104847`, 0.9348282500909746]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 100}], {
             RGBColor[
             0.20887799203010743`, 0.3368743916262188, 0.9352066646875926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 120}], {
             RGBColor[
             0.2029515968118113, 0.3306453744966301, 0.9348691652472267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 124}], {
             RGBColor[
             0.21900119805648247`, 0.34751452300827246`, 0.9357831662948535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 125}], {
             RGBColor[
             0.23812411131454123`, 0.3676139173052213, 0.9368721879150849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 136}], {
             RGBColor[
             0.21738866266974544`, 0.34581964607616317`, 0.935691334790111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 137}], {
             RGBColor[
             0.26792874657827515`, 0.39754009228340836`, 0.9386207928076713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 187}], {
             RGBColor[
             0.2077231055465765, 0.3356605327079955, 0.9351408956108569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 198}], {
             RGBColor[
             0.2787942966052594, 0.4069512855983587, 0.9393131360473621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 122}], {
             RGBColor[
             0.6021548677029418, 0.6767924582408489, 0.9659897173678593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 156}], {
             RGBColor[
             0.8546071106591433, 0.41129823352172423`, 0.4413184867830513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 166}], {
             RGBColor[
             0.8650576677002866, 0.8953688994003288, 0.9869563023793746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 170}], {
             RGBColor[
             0.7907969761749707, 0.8373558827785927, 0.9795546906537492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 175}], {
             RGBColor[
             0.7134786289406714, 0.7747821951592325, 0.9733333335119576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 179}], {
             RGBColor[
             0.6474631282319623, 0.7188859236705143, 0.9687723771837091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 183}], {
             RGBColor[
             0.9313850452704695, 0.8648151337796632, 0.6302560397084783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 192}], {
             RGBColor[
             0.6960500843646674, 0.7606329175254469, 0.9719612946400722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 126}], {
             RGBColor[
             0.1804502852518648, 0.30699506938157317`, 0.9335877488415951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 190}], {
             RGBColor[
             0.18271061576572617`, 0.30937082006487343`, 0.9337164713205002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 88}], {
             RGBColor[
             0.24351738394062986`, 0.3732825887884752, 0.9371793268125088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 117}], {
             RGBColor[
             0.22789736538652144`, 0.3568649589217301, 0.9362897898635989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[
             0.24391248178172664`, 0.37369786167011787`, 0.9372018270500644]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 133}], {
             RGBColor[
             0.25979757259338154`, 0.39039409928609614`, 0.9381064594719022]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 140}], {
             RGBColor[
             0.632097596410786, 0.6952982597896742, 0.7484529667837756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 152}], {
             RGBColor[
             0.2353287944309912, 0.36467586202728325`, 0.9367129987538674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 159}], {
             RGBColor[
             0.26268203427801573`, 0.3934258514020805, 0.9382707252976634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 161}], {
             RGBColor[
             0.2771499717006646, 0.408632570953499, 0.939094652930488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 173}], {
             RGBColor[
             0.31911259241838086`, 0.4472823241494562, 0.941684119139965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 200}], {
             RGBColor[
             0.23054281786445055`, 0.35964549720740835`, 0.9364404444686207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 92}], {
             RGBColor[
             0.22327186579105107`, 0.35200326557327766`, 0.9360263745044504]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[
             0.19625374198187168`, 0.3236055044018397, 0.9344877323232499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 171}], {
             RGBColor[
             0.25492345163412733`, 0.3852710891208021, 0.9378288854938884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 174}], {
             RGBColor[
             0.19606494632876875`, 0.3234070682000927, 0.9344769806901039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 196}], {
             RGBColor[
             0.2175414257082079, 0.3459802097153233, 0.9357000344191588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 89}], {
             RGBColor[
             0.24210890877301894`, 0.37180219208483256`, 0.9370991162353657]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 106}], {
             RGBColor[
             0.20086653877096394`, 0.3284538462953842, 0.9347504242763673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 107}], {
             RGBColor[
             0.21716799810205883`, 0.34558771362458285`, 0.9356787682694253]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 130}], {
             RGBColor[
             0.20049917291084113`, 0.3280677214840543, 0.9347295033341025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 131}], {
             RGBColor[
             0.19909905794023608`, 0.326596111877532, 0.934649768857811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 142}], {
             RGBColor[
             0.23935044537430794`, 0.3689028721561064, 0.9369420258255899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 147}], {
             RGBColor[
             0.23311384595539386`, 0.3623478107435859, 0.9365868607149048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[
             0.2742869255202454, 0.40348527807603907`, 0.9390098911632051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 157}], {
             RGBColor[
             0.21156396593022397`, 0.3396975204958227, 0.9353596269276621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 168}], {
             RGBColor[
             0.21305020122447582`, 0.34125964802284164`, 0.9354442658289815]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 176}], {
             RGBColor[
             0.22539540274629694`, 0.3542352375532605, 0.9361473067925603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 188}], {
             RGBColor[
             0.264952676857396, 0.39540042103725787`, 0.9384151210923604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 91}], {
             RGBColor[
             0.20139859473617852`, 0.32901307084912135`, 0.93478072407648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 93}], {
             RGBColor[
             0.22397479227765688`, 0.3527420858788138, 0.936066405127976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 95}], {
             RGBColor[
             0.23288032783126497`, 0.3621023683892223, 0.9365735622031948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 103}], {
             RGBColor[
             0.1988218402918387, 0.32630473855245234`, 0.9346339817228415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 117}], {
             RGBColor[
             0.2009427964171618, 0.32853399791655225`, 0.9347547670365053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 121}], {
             RGBColor[
             0.21695791281236698`, 0.34536690066494, 0.9356668042229707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 152}], {
             RGBColor[
             0.20837422546163153`, 0.3363449010221054, 0.9351779759267738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 159}], {
             RGBColor[
             0.23572746530865607`, 0.3650948903969026, 0.9367357024705698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 161}], {
             RGBColor[
             0.25019540273130497`, 0.38030160994832113`, 0.9375596301033943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 164}], {
             RGBColor[
             0.20586798703479003`, 0.3337106855308008, 0.9350352493560126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 173}], {
             RGBColor[
             0.2921580234490212, 0.41895136314427833`, 0.9401490963128714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 180}], {
             RGBColor[
             0.279297845494757, 0.4078125233716327, 0.9393296571454344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 200}], {
             RGBColor[
             0.20358824889509092`, 0.3313145362022305, 0.9349054216415271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 106}], {
             RGBColor[
             0.22627244033588012`, 0.3551570596673073, 0.9361972527858261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 107}], {
             RGBColor[
             0.24257389966697504`, 0.37229092699650596`, 0.9371255967788841]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 142}], {
             RGBColor[
             0.2647563469392241, 0.39560608552802945`, 0.9383888543350487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 147}], {
             RGBColor[
             0.25851974752031004`, 0.38905102411550896`, 0.9380336892243635]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 154}], {
             RGBColor[
             0.29969282708516165`, 0.4301884914479621, 0.9404567196726639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 157}], {
             RGBColor[
             0.23696986749514018`, 0.36640073386774574`, 0.9368064554371207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 168}], {
             RGBColor[
             0.23845610278939203`, 0.36796286139476475`, 0.9368910943384403]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 176}], {
             RGBColor[
             0.25080130431121317`, 0.3809384509251836, 0.937594135302019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 188}], {
             RGBColor[
             0.29035857842231216`, 0.42210363440918097`, 0.939861949601819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 111}], {
             RGBColor[
             0.22370338980181498`, 0.3524568246687931, 0.9360509491584807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 115}], {
             RGBColor[
             0.27114794471103404`, 0.4017434985665935, 0.9387741035720105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 163}], {
             RGBColor[
             0.2545166466581612, 0.38484351129813643`, 0.9378057185523212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 165}], {
             RGBColor[
             0.21653690052978303`, 0.3449243900622238, 0.9356428281963094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 169}], {
             RGBColor[
             0.20968181085613852`, 0.3377192561774346, 0.9352524409805917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 175}], {
             RGBColor[
             0.36392094666961883`, 0.4808157727668374, 0.9450400242191717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 177}], {
             RGBColor[
             0.22233026933066752`, 0.35101358799275084`, 0.9359727519789987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 103}], {
             RGBColor[
             0.18365762005674702`, 0.31036618161827634`, 0.9337704018139066]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 117}], {
             RGBColor[
             0.1857785761820701, 0.31259544098237624`, 0.9338911871275704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 121}], {
             RGBColor[
             0.2017936925772753, 0.329428343730764, 0.9348032243140356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 152}], {
             RGBColor[
             0.19321000522653986`, 0.3204063440879294, 0.9343143960178388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 159}], {
             RGBColor[
             0.22056324507356437`, 0.3491563334627266, 0.9358721225616348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 164}], {
             RGBColor[
             0.19070376679969833`, 0.3177721285966248, 0.9341716694470776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 200}], {
             RGBColor[
             0.18842402865999922`, 0.3153759792680545, 0.9340418417325922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 118}], {
             RGBColor[
             0.31765722646768046`, 0.4436155762000519, 0.9416794866592155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 123}], {
             RGBColor[
             0.34778570453147756`, 0.4697113495975751, 0.9435992466398737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 139}], {
             RGBColor[
             0.26505756074119424`, 0.3959226803319581, 0.938406008015465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 141}], {
             RGBColor[
             0.29413145548178377`, 0.42323873581169885`, 0.9401804453350167]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 146}], {
             RGBColor[
             0.24492541546972163`, 0.3747625191999059, 0.9372595121250946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 171}], {
             RGBColor[
             0.2760986031689815, 0.40752751596608494`, 0.939034779047969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 174}], {
             RGBColor[
             0.2172400978636229, 0.3456634950453756, 0.9356828742441843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 186}], {
             RGBColor[
             0.21375750066891208`, 0.34200306458431906`, 0.9354845454859864]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 191}], {
             RGBColor[
             0.5272753016690297, 0.6129190189586639, 0.9594697403649703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 195}], {
             RGBColor[
             0.372739436043382, 0.49002947459904367`, 0.9455472387434574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 196}], {
             RGBColor[
             0.23871657724306206`, 0.3682366365606061, 0.9369059279732393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 95}], {
             RGBColor[
             0.24029230513765162`, 0.36989282648473865`, 0.9369956633457557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 121}], {
             RGBColor[
             0.22436989011875363`, 0.3531573587604565, 0.9360889053655316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 150}], {
             RGBColor[
             0.21197440955790398`, 0.3401289227721434, 0.9353830010850614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 159}], {
             RGBColor[
             0.24313944261504272`, 0.37288534849241906`, 0.9371578036131307]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 161}], {
             RGBColor[
             0.2576073800376916, 0.38809206804383756`, 0.9379817312459552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 162}], {
             RGBColor[
             0.34139937953517563`, 0.46297232673312194`, 0.9432365284830118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 164}], {
             RGBColor[
             0.2132799643411767, 0.3415011436263172, 0.9354573504985735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 173}], {
             RGBColor[
             0.29957000075540785`, 0.42674182123979476`, 0.9405711974554323]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 180}], {
             RGBColor[
             0.28670982280114365`, 0.41560298146714914`, 0.9397517582879953]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 200}], {
             RGBColor[
             0.21100022620147757`, 0.339104994297747, 0.935327522784088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 174}], {
             RGBColor[
             0.19022197405444352`, 0.31726573387393764`, 0.9341442320629838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 196}], {
             RGBColor[
             0.21169845343388266`, 0.3398388753891681, 0.9353672857920389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 121}], {
             RGBColor[
             0.23327542567236176`, 0.36251764127086494`, 0.9365960624407503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 150}], {
             RGBColor[
             0.2208799451115121, 0.3494892052825519, 0.9358901581602801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 159}], {
             RGBColor[
             0.2520449781686508, 0.3822456310028275, 0.9376649606883494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 161}], {
             RGBColor[
             0.26651291559129975`, 0.397452350554246, 0.9384888883211739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 162}], {
             RGBColor[
             0.35030491508878375`, 0.4723326092435304, 0.9437436855582304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 164}], {
             RGBColor[
             0.22218549989478478`, 0.35086142613672566`, 0.9359645075737923]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 173}], {
             RGBColor[
             0.308475536309016, 0.4361021037502032, 0.9410783545306509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 180}], {
             RGBColor[
             0.2956153583547517, 0.42496326397755757`, 0.9402589153632142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 99}], {
             RGBColor[
             0.7441185775359549, 0.79956600300059, 0.9751875122211435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 102}], {
             RGBColor[
             0.9527960526971394, 0.9643159539076722, 0.964788149409247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 125}], {
             RGBColor[
             0.600349784053201, 0.6736043813543324, 0.9654382177461185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 128}], {
             RGBColor[
             0.683861542921137, 0.7500489673999585, 0.97060899306342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 137}], {
             RGBColor[
             0.630154419316935, 0.7035305563325196, 0.9671868226387048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 166}], {
             RGBColor[
             0.8700729048613844, 0.8993494121193195, 0.9867932099380505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 170}], {
             RGBColor[
             0.7958122133360686, 0.8413363954975833, 0.9793915982124253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 198}], {
             RGBColor[
             0.6410199693439192, 0.7129417496474699, 0.9678791658783956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 105}], {
             RGBColor[
             0.21127795983773054`, 0.3393969099587784, 0.9353433393038026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 134}], {
             RGBColor[
             0.23183626588337625`, 0.3610049930846403, 0.9365141044198138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 135}], {
             RGBColor[
             0.20686780943909605`, 0.33476156227012827`, 0.9350921877628332]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 153}], {
             RGBColor[
             0.24952804077433757`, 0.37960017021835646`, 0.9375216248272185]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 100}], {
             RGBColor[
             0.19914601799870904`, 0.3266454698764268, 0.9346524431636698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 109}], {
             RGBColor[
             0.2049550918267402, 0.33275117478624117`, 0.9349832613244216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 113}], {
             RGBColor[
             0.19847726376767427`, 0.32594256677814204`, 0.9346143585995457]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 116}], {
             RGBColor[
             0.21656444769936758`, 0.34495334388404864`, 0.9356443969668649]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 120}], {
             RGBColor[
             0.19321962278041294`, 0.32041645274683817`, 0.9343149437233039]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 124}], {
             RGBColor[
             0.20926922402508408`, 0.3372856012584804, 0.9352289447709307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 125}], {
             RGBColor[
             0.22839213728314284`, 0.35738499555542924`, 0.936317966391162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 136}], {
             RGBColor[
             0.20765668863834705`, 0.33559072432637116`, 0.9351371132661883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 187}], {
             RGBColor[
             0.1979911315151781, 0.3254316109582035, 0.9345866740869342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 102}], {
             RGBColor[
             0.7604981725449849, 0.8117818781391992, 0.9474611303534258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 109}], {
             RGBColor[
             0.38461485844464394`, 0.49643648481667146`, 0.9467764936235569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 116}], {
             RGBColor[
             0.39622421431727134`, 0.5086386539144789, 0.9474376292660001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 128}], {
             RGBColor[
             0.49156366276898256`, 0.5975148916314856, 0.9532819740075988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 136}], {
             RGBColor[
             0.3873164552562508, 0.49927603435680146`, 0.9469303455653235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 137}], {
             RGBColor[
             0.4378565391647805, 0.5509964805640466, 0.9498598035828838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 162}], {
             RGBColor[
             0.5016163434350541, 0.6062220183620153, 0.9539225219304044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 193}], {
             RGBColor[
             0.3906410080149175, 0.5027703500949796, 0.9471196739266945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 198}], {
             RGBColor[
             0.44872208919176476`, 0.5604076738789969, 0.9505521468225746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 113}], {
             RGBColor[
             0.20512211761839033`, 0.33292672948331237`, 0.9349927731961636]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 120}], {
             RGBColor[
             0.199864476631129, 0.3274006154520085, 0.934693358319922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 124}], {
             RGBColor[
             0.21591407787580016`, 0.3442697639636507, 0.9356073593675487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 125}], {
             RGBColor[
             0.23503699113385892`, 0.36436915826059957`, 0.9366963809877801]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 136}], {
             RGBColor[
             0.21430154248906313`, 0.3425748870315415, 0.9355155278628062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 137}], {
             RGBColor[
             0.26484162639759284`, 0.3942953332387867, 0.9384449858803665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 187}], {
             RGBColor[
             0.2046359853658942, 0.3324157736633738, 0.9349650886835521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 198}], {
             RGBColor[
             0.2757071764245771, 0.40370652655373696`, 0.9391373291200573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 105}], {
             RGBColor[
             0.20097546444375586`, 0.32856833408377506`, 0.9347566274322918]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 134}], {
             RGBColor[
             0.22153377048940157`, 0.350176417209637, 0.9359273925483029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 135}], {
             RGBColor[
             0.1965653140451214, 0.3239329863951249, 0.9345054758913225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 144}], {
             RGBColor[
             0.19734151181877715`, 0.32474881946901846`, 0.9345496792062504]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 128}], {
             RGBColor[
             0.700241137930167, 0.7622648425385679, 0.9428826111957023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 140}], {
             RGBColor[
             0.981449443808876, 0.9827573994159884, 0.747626675734739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 162}], {
             RGBColor[
             0.7102938185962386, 0.7709719692690975, 0.9435231591185078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 172}], {
             RGBColor[
             0.9192581959222914, 0.7380602445354411, 0.5748744102551196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 180}], {
             RGBColor[
             0.6556042618622065, 0.7236026240031248, 0.9400383889234916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 117}], {
             RGBColor[
             0.1832018217377303, 0.30988710868570724`, 0.9337444447739318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 152}], {
             RGBColor[
             0.19063325078220003`, 0.31769801179126034`, 0.9341676536642003]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 178}], {
             RGBColor[
             0.1823641236245055, 0.3090066348555799, 0.933696739105647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 200}], {
             RGBColor[
             0.18584727421565939`, 0.3126676469713855, 0.9338950993789537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 143}], {
             RGBColor[
             0.6113814534238254, 0.6900658551251025, 0.9653536718198579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 154}], {
             RGBColor[
             0.3494855423442635, 0.47712854394966536`, 0.9434898876136137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 158}], {
             RGBColor[
             0.3417223041341413, 0.47040441720375525`, 0.9429952209396267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 160}], {
             RGBColor[
             0.4051454853105788, 0.5253383889970118, 0.9470364899612722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 176}], {
             RGBColor[
             0.300594019570315, 0.4278785034268868, 0.9406273032429688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 181}], {
             RGBColor[
             0.4026365855967863, 0.5231653061658909, 0.9468766250900423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 188}], {
             RGBColor[
             0.34015129368141406`, 0.46904368691088416`, 0.9428951175427689]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 134}], {
             RGBColor[
             0.22631486646654955`, 0.35520165222061295`, 0.936199668891204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 135}], {
             RGBColor[
             0.20134641002226938`, 0.32895822140610087`, 0.9347777522342233]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 144}], {
             RGBColor[
             0.20212260779592514`, 0.3297740544799944, 0.9348219555491514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.20133152966492007`, 0.3289425812070576, 0.9347769048198857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 130}], {
             RGBColor[
             0.1846627044737023, 0.31142258906652903`, 0.933827639884563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 131}], {
             RGBColor[
             0.18326258950309726`, 0.3099509794600067, 0.9337479054082716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 142}], {
             RGBColor[
             0.22351397693716918`, 0.3522577397385811, 0.9360401623760504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 147}], {
             RGBColor[
             0.21727737751825504`, 0.3457026783260606, 0.9356849972653654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 157}], {
             RGBColor[
             0.1957274974930852, 0.3230523880782974, 0.9344577634781225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 176}], {
             RGBColor[
             0.20955893430915817`, 0.33759010513573523`, 0.9352454433430207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 130}], {
             RGBColor[
             0.20096416380479723`, 0.32855645639572767`, 0.9347559838776209]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 131}], {
             RGBColor[
             0.19956404883419218`, 0.32708484678920535`, 0.9346762494013294]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 142}], {
             RGBColor[
             0.23981543626826407`, 0.36939160706777974`, 0.9369685063691083]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[
             0.23357883684934996`, 0.36283654565525925`, 0.9366133412584232]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 154}], {
             RGBColor[
             0.27475191641420155`, 0.4039740129877124, 0.9390363717067235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.2120289568241801, 0.34018625540749603`, 0.9353861074711805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 168}], {
             RGBColor[
             0.21351519211843195`, 0.34174838293451504`, 0.9354707463724999]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 176}], {
             RGBColor[
             0.22586039364025307`, 0.35472397246493387`, 0.9361737873360787]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 188}], {
             RGBColor[
             0.2654176677513521, 0.39588915594893126`, 0.9384416016358788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 111}], {
             RGBColor[
             0.26408143509617243`, 0.39489671038909974`, 0.9383504191040295]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 115}], {
             RGBColor[
             0.3115259900053915, 0.4441833842869002, 0.9410735735175593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 133}], {
             RGBColor[
             0.27857495084464845`, 0.41013031438272207`, 0.9391758033846701]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 151}], {
             RGBColor[
             0.6509649455844404, 0.716416401604573, 0.8457783120147642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 163}], {
             RGBColor[
             0.29489469195251866`, 0.4272833970184431, 0.94010518849787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 165}], {
             RGBColor[
             0.25691494582414054`, 0.38736427578253046`, 0.937942298141858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 175}], {
             RGBColor[
             0.4042989919639763, 0.5232556584871441, 0.9473394941647204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 113}], {
             RGBColor[
             0.2109311914464215, 0.33903243439312675`, 0.9353235913569153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 116}], {
             RGBColor[
             0.2290183753781148, 0.3580432114990334, 0.9363536297242345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 124}], {
             RGBColor[
             0.22172315170383133`, 0.35037546887346516`, 0.9359381775283004]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 128}], {
             RGBColor[
             0.32435782382982603`, 0.44691944921604004`, 0.9421979744658333]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 136}], {
             RGBColor[
             0.22011061631709428`, 0.3486805919413559, 0.935846346023558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 148}], {
             RGBColor[
             0.20549299658683456`, 0.33331654679423195`, 0.9350138942047502]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 193}], {
             RGBColor[
             0.223435169075761, 0.3521749076795341, 0.936035674384929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 138}], {
             RGBColor[
             0.20099999291646117`, 0.32859411506378333`, 0.9347580242925257]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 145}], {
             RGBColor[
             0.18515978669395372`, 0.31194505399684636`, 0.9338559479816391]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 115}], {
             RGBColor[
             0.26758071568904057`, 0.3979941146890951, 0.9385709551564505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 163}], {
             RGBColor[
             0.25094941763616774`, 0.3810941274206381, 0.9376025701367612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 165}], {
             RGBColor[
             0.21296967150778956`, 0.3411750061847254, 0.9354396797807493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 169}], {
             RGBColor[
             0.20611458183414505`, 0.33396987229993624`, 0.9350492925650316]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 175}], {
             RGBColor[
             0.36035371764762536`, 0.477066388889339, 0.9448368758036116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 177}], {
             RGBColor[
             0.21876304030867405`, 0.3472642041152524, 0.9357696035634386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 134}], {
             RGBColor[
             0.5941420485372255, 0.6663173396662936, 0.9607153178159171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 143}], {
             RGBColor[
             0.8985367952768839, 0.9217855718880776, 0.9850776323188054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 156}], {
             RGBColor[
             0.8596154243912574, 0.41519353040673457`, 0.43839164860472024`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 160}], {
             RGBColor[
             0.6923008271636373, 0.757058105759987, 0.9667604504602199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 181}], {
             RGBColor[
             0.6897919274498447, 0.754885022928866, 0.9666005855889899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 183}], {
             RGBColor[
             0.9388975158686406, 0.8706580791071786, 0.6258657824409817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 116}], {
             RGBColor[
             0.22254054731904888`, 0.35123460349093416`, 0.9359847269993585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 124}], {
             RGBColor[
             0.2152453236447654, 0.343566860865366, 0.9355692748034243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 128}], {
             RGBColor[
             0.3178799957707601, 0.44011084120794086`, 0.9418290717409573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 136}], {
             RGBColor[
             0.21363278825802834`, 0.3418719839332567, 0.9354774432986821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 148}], {
             RGBColor[
             0.19901516852776863`, 0.3265079387861328, 0.9346449914798742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 187}], {
             RGBColor[
             0.20396723113485943`, 0.331712870565089, 0.934927004119428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 193}], {
             RGBColor[
             0.21695734101669506`, 0.34536629967143495`, 0.9356667716600531]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 198}], {
             RGBColor[
             0.2750384221935423, 0.4030036234554522, 0.939099244555933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 167}], {
             RGBColor[
             0.19037448411434205`, 0.3174260316165872, 0.9341529172852767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 184}], {
             RGBColor[
             0.18161202378548802`, 0.3082161302388885, 0.9336539081324469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 186}], {
             RGBColor[
             0.18224157379578187`, 0.3088778272154834, 0.9336897600741974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 194}], {
             RGBColor[
             0.19146855650738448`, 0.3185759710698711, 0.9342152230895253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 133}], {
             RGBColor[
             0.2820742314375166, 0.41322771868271746`, 0.939396339437091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 163}], {
             RGBColor[
             0.2983939725453868, 0.4303808013184385, 0.9403257245502908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 165}], {
             RGBColor[
             0.2604142264170086, 0.39046168008252585`, 0.9381628341942789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 175}], {
             RGBColor[
             0.4077982725568444, 0.5263530627871394, 0.9475600302171414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 124}], {
             RGBColor[
             0.2333325075764587, 0.3625776379712726, 0.9365993131707435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 128}], {
             RGBColor[
             0.33596717970245343`, 0.45912161831384746`, 0.9428591101082765]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 136}], {
             RGBColor[
             0.23171997218972168`, 0.36088276103916334`, 0.9365074816660013]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 148}], {
             RGBColor[
             0.21710235245946194`, 0.3455187158920394, 0.9356750298471934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 193}], {
             RGBColor[
             0.2350445249483884, 0.36437707677734155`, 0.9366968100273723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 198}], {
             RGBColor[
             0.29312560612523564`, 0.42201440056135886`, 0.9401292829232522]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 121}], {
             RGBColor[
             0.2013378942582586, 0.3289492707981949, 0.9347772672740609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 152}], {
             RGBColor[
             0.19275420690752315`, 0.3199272711553603, 0.934288438977864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 159}], {
             RGBColor[
             0.22010744675454766`, 0.3486772605301575, 0.9358461655216599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 164}], {
             RGBColor[
             0.19024796848068162`, 0.3172930556640557, 0.9341457124071029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 178}], {
             RGBColor[
             0.18448507974982858`, 0.3112358942196798, 0.9338175244193107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 200}], {
             RGBColor[
             0.1879682303409825, 0.3148969063354854, 0.9340158846926173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 119}], {
             RGBColor[
             0.6948397253680805, 0.41161030980348123`, 0.44369144326806464`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 123}], {
             RGBColor[
             0.42099591367325284`, 0.5390672333790665, 0.9480464652405584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 127}], {
             RGBColor[
             0.6328274279834254, 0.7079836098876566, 0.9670229522085898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 129}], {
             RGBColor[
             0.4226691844013287, 0.5404852315434163, 0.9481617341921013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 139}], {
             RGBColor[
             0.33826776988296947`, 0.4652785641134494, 0.9428532266161497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[
             0.36734166462355905`, 0.4925946195931902, 0.9446276639357014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 146}], {
             RGBColor[
             0.3181356246114969, 0.44411840298139715`, 0.9417067307257794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 155}], {
             RGBColor[
             0.5320287520312512, 0.6287959624909311, 0.9570938290152922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 171}], {
             RGBColor[
             0.3493088123107567, 0.4768833997475762, 0.9434819976486537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 191}], {
             RGBColor[
             0.6004855108108049, 0.6822749027401551, 0.9639169589656551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.44594964518515734`, 0.559385358380535, 0.9499944573441421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 196}], {
             RGBColor[
             0.3119267863848373, 0.4375925203420974, 0.941353146573924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[
             0.6930640728290565, 0.752639828019768, 0.8371662674251406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 123}], {
             RGBColor[
             0.7149253774106119, 0.4290074920684967, 0.44497128325517005`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 127}], {
             RGBColor[
             0.8561463869507269, 0.5416184097408903, 0.4576222745671909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 140}], {
             RGBColor[
             0.8957916601354561, 0.5702808130715319, 0.3143797361574141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 151}], {
             RGBColor[
             0.895851640750381, 0.5712020975503805, 0.3785504037028946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 155}], {
             RGBColor[
             0.7889472696492774, 0.4888266448097398, 0.4510028591049925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 156}], {
             RGBColor[
             0.8374564716001813, 0.28891243101531533`, 0.18350166554635475`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 172}], {
             RGBColor[
             0.8543308282110663, 0.40714937648450034`, 0.19921155917100125`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 191}], {
             RGBColor[
             0.8345851088356466, 0.5244792716425559, 0.45555161240523445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 195}], {
             RGBColor[
             0.7315611984185482, 0.4425529087361424, 0.44626994465755915`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 199}], {
             RGBColor[
             0.8963041501811476, 0.5713892218289645, 0.37105115137822486`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 124}], {
             RGBColor[
             0.20998768265750406`, 0.3380407468340621, 0.9352698599271827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 125}], {
             RGBColor[
             0.22911059591556282`, 0.35814014113101095`, 0.9363588815474142]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 136}], {
             RGBColor[
             0.208375147270767, 0.3363458699019528, 0.9351780284224404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 137}], {
             RGBColor[
             0.2589152311792967, 0.38806631610919806`, 0.9381074864400005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 187}], {
             RGBColor[
             0.1987095901475981, 0.32618675653378515`, 0.9346275892431862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 198}], {
             RGBColor[
             0.26978078120628096`, 0.39747750942414833`, 0.9387998296796913]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 152}], {
             RGBColor[
             0.20876932330272832`, 0.33676017390374813`, 0.9352004761643293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 159}], {
             RGBColor[
             0.23612256314975283`, 0.36551016327854535`, 0.9367582027081254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 161}], {
             RGBColor[
             0.25059050057240173`, 0.38071688282996385`, 0.9375821303409498]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 164}], {
             RGBColor[
             0.2062630848758868, 0.3341259584124435, 0.9350577495935681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 173}], {
             RGBColor[
             0.292553121290118, 0.41936663602592106`, 0.9401715965504269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 180}], {
             RGBColor[
             0.27969294333585376`, 0.40822779625327543`, 0.9393521573829899]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[
             0.20398334673618768`, 0.33172980908387323`, 0.9349279218790827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 125}], {
             RGBColor[
             0.2711034312291314, 0.40227727354510906`, 0.9387503113956892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 137}], {
             RGBColor[
             0.3009080664928653, 0.4322034485232962, 0.9404989162882755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 166}], {
             RGBColor[
             0.5408265520373148, 0.6280223043100961, 0.9601053035876213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 170}], {
             RGBColor[
             0.4665658605119989, 0.5700092876883599, 0.9527036918619959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 179}], {
             RGBColor[
             0.32323201256899053`, 0.45153932858028145`, 0.9419213783919558]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 192}], {
             RGBColor[
             0.3718189687016956, 0.49328632243521403`, 0.9451102958483188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 127}], {
             RGBColor[
             0.6629559060472224, 0.73407938328518, 0.9689427121892478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 129}], {
             RGBColor[
             0.45279766246512576`, 0.5665810049409397, 0.9500814941727593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 139}], {
             RGBColor[
             0.36839624794676656`, 0.4913743375109727, 0.9447729865968078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 141}], {
             RGBColor[
             0.39747014268735614`, 0.5186903929907134, 0.9465474239163595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 146}], {
             RGBColor[
             0.34826410267529395`, 0.47021417637892043`, 0.9436264907064373]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 155}], {
             RGBColor[
             0.5621572300950483, 0.6548917358884543, 0.9590135889959501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 171}], {
             RGBColor[
             0.3794372903745538, 0.5029791731450995, 0.9454017576293117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 191}], {
             RGBColor[
             0.6306139888746021, 0.7083706761376785, 0.9658367189463131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 195}], {
             RGBColor[
             0.4760781232489544, 0.5854811317780583, 0.9519142173248001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 196}], {
             RGBColor[
             0.3420552644486344, 0.4636882937396207, 0.9432729065545822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 199}], {
             RGBColor[
             0.7231925508928534, 0.7787356014172913, 0.8390860274057987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 125}], {
             RGBColor[
             0.24516019716023396`, 0.37500928964265323`, 0.9372728825950409]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 136}], {
             RGBColor[
             0.22442474851543817`, 0.35321501841359515`, 0.9360920294700671]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.27496483242396785`, 0.4049354646208403, 0.9390214874876273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 187}], {
             RGBColor[
             0.21475919139226923`, 0.3430559050454275, 0.935541590290813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 198}], {
             RGBColor[
             0.28583038245095216`, 0.4143466579357906, 0.9397138307273181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 136}], {
             RGBColor[
             0.24354766177349693`, 0.373314412710544, 0.9371810510902985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 137}], {
             RGBColor[
             0.29408774568202667`, 0.42503485891778914`, 0.9401105091078588]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 166}], {
             RGBColor[
             0.5340062312264762, 0.620853714704589, 0.9597168964072044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[
             0.4597455397011603, 0.5628406980828529, 0.952315284681579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 187}], {
             RGBColor[
             0.233882104650328, 0.36315529934237634`, 0.9366306119110444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 192}], {
             RGBColor[
             0.364998647890857, 0.48611773282970705`, 0.9447218886679021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 198}], {
             RGBColor[
             0.30495329570901086`, 0.43444605223273947`, 0.9408028523475496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 190}], {
             RGBColor[
             0.18192592123823295`, 0.3085460563639715, 0.933671784128011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 129}], {
             RGBColor[
             0.6646291767752983, 0.7354973814495299, 0.9690579811407907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 139}], {
             RGBColor[
             0.5802277622569392, 0.660290714019563, 0.9637494735648391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 140}], {
             RGBColor[
             0.9342553301344888, 0.9459893647897327, 0.7730553915426139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 141}], {
             RGBColor[
             0.6093016569975287, 0.6876067694993037, 0.9655239108843909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 155}], {
             RGBColor[
             0.7739887444052208, 0.8238081123970447, 0.9779900759639816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 172}], {
             RGBColor[
             0.8720640822479042, 0.7012922099091854, 0.6003031260629946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 191}], {
             RGBColor[
             0.8424455031847746, 0.8772870526462687, 0.9848132059143445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 195}], {
             RGBColor[
             0.6879096375591269, 0.7543975082866485, 0.9708907042928315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 199}], {
             RGBColor[
             0.935024065203026, 0.9476519779258816, 0.8580625143738301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 136}], {
             RGBColor[
             0.3270594206414329, 0.44975899875617, 0.9423518264076001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 162}], {
             RGBColor[
             0.4413593088202362, 0.5567049827613839, 0.9493440027726809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 193}], {
             RGBColor[
             0.3303839734000996, 0.45325331449434825`, 0.942541154768971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 198}], {
             RGBColor[
             0.38846505457694686`, 0.5108906382783656, 0.9459736276648509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 139}], {
             RGBColor[
             0.3700695186748425, 0.49279233567532266`, 0.9448882555483507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 141}], {
             RGBColor[
             0.399143413415432, 0.5201083911550634, 0.9466626928679024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 146}], {
             RGBColor[
             0.3499373734033699, 0.4716321745432704, 0.9437417596579802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 155}], {
             RGBColor[
             0.5638305008231241, 0.6563097340528043, 0.959128857947493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 191}], {
             RGBColor[
             0.632287259602678, 0.7097886743020284, 0.965951987897856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 195}], {
             RGBColor[
             0.47775139397703026`, 0.5868991299424082, 0.952029486276343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 131}], {
             RGBColor[
             0.18289522364297445`, 0.3095648546486768, 0.9337269844660065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 149}], {
             RGBColor[
             0.1848995905074315, 0.3116715713074204, 0.9338411301937424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 157}], {
             RGBColor[
             0.19536013163296237`, 0.32266626326696746`, 0.9344368425358576]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 168}], {
             RGBColor[
             0.19684636692721422`, 0.32422839079398647`, 0.9345214814371772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 189}], {
             RGBColor[
             0.18936342684036145`, 0.3163633463169, 0.9340953390692487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 197}], {
             RGBColor[
             0.19250062713784824`, 0.3196607427395459, 0.9342739979851187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 147}], {
             RGBColor[
             0.21550989668752718`, 0.3438449439082084, 0.9355843418468089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 157}], {
             RGBColor[
             0.19396001666235732`, 0.3211946536604452, 0.9343571080595661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 176}], {
             RGBColor[
             0.20779145347843028`, 0.335732370717883, 0.9351447879244643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 138}], {
             RGBColor[
             0.2612195562179643, 0.3918886942345018, 0.9381874393356859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 145}], {
             RGBColor[
             0.24537934999545682`, 0.37523963316756476`, 0.9372853630247993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 153}], {
             RGBColor[
             0.29141110867079584`, 0.42362193011741534`, 0.9399068035834754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 182}], {
             RGBColor[
             0.3206991952751244, 0.45143891338558356`, 0.9416833404765177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 185}], {
             RGBColor[
             0.26630785953473646`, 0.397236823637493, 0.9384772106821059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 163}], {
             RGBColor[
             0.26544293338464375`, 0.39632773141426036`, 0.9384279544174017]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 178}], {
             RGBColor[
             0.21638528695668868`, 0.3447650345840459, 0.9356341940276138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 135}], {
             RGBColor[
             0.22190471606791506`, 0.3505663045319628, 0.9359485173502345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 160}], {
             RGBColor[
             0.3450319511386071, 0.4675505014401682, 0.9434155666515178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 144}], {
             RGBColor[
             0.19771245739729065`, 0.32513870679134427`, 0.9345708040081819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 148}], {
             RGBColor[
             0.2081945933984414, 0.33615609633436194`, 0.9351677461465169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 187}], {
             RGBColor[
             0.2131466560055322, 0.3413610281133182, 0.9354497587860706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 193}], {
             RGBColor[
             0.22613676588736786`, 0.35501445721966407`, 0.9361895263266957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 198}], {
             RGBColor[
             0.2842178470642151, 0.4126517810036814, 0.9396219992225757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 166}], {
             RGBColor[
             0.5638108664902101, 0.6507798896827761, 0.9614655012997908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 170}], {
             RGBColor[
             0.48955017496489417`, 0.59276687306104, 0.9540638895741654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 179}], {
             RGBColor[
             0.3462163270218858, 0.4742969139529616, 0.9432815761041253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 187}], {
             RGBColor[
             0.2636867399140619, 0.3930814743205634, 0.9383792168036308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 192}], {
             RGBColor[
             0.3948032831545909, 0.5160439078078941, 0.9464704935604884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 198}], {
             RGBColor[
             0.3347579309727448, 0.4643722272109265, 0.9425514572401359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 145}], {
             RGBColor[
             0.20603341116594734`, 0.3338845567811428, 0.935044670015559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 153}], {
             RGBColor[
             0.25206516984128635`, 0.38226685373099345`, 0.9376661105742352]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 182}], {
             RGBColor[
             0.28135325644561493`, 0.4100838369991616, 0.9394426474672775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 185}], {
             RGBColor[
             0.22696192070522694`, 0.35588174725107113`, 0.9362365176728656]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 141}], {
             RGBColor[
             0.31474199889707277`, 0.4449017237250964, 0.9413541852919508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 146}], {
             RGBColor[
             0.2655359588850107, 0.39642550711330343`, 0.9384332520820287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 155}], {
             RGBColor[
             0.47942908630476494`, 0.5811030666228374, 0.9538203503715414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 171}], {
             RGBColor[
             0.2967091465842705, 0.42919050387948254`, 0.940208519004903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 191}], {
             RGBColor[
             0.5478858450843187, 0.6345820068720615, 0.9606434803219044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 194}], {
             RGBColor[
             0.2435950267958037, 0.37336419635210427`, 0.9371837484582486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 195}], {
             RGBColor[
             0.39334997945867106`, 0.5116924625124413, 0.9467209787003914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 196}], {
             RGBColor[
             0.25932712065835106`, 0.3898996244740037, 0.9380796679301735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 151}], {
             RGBColor[
             0.9938132108339699, 0.9903648965039682, 0.6544475852461695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 161}], {
             RGBColor[
             0.6387756152014612, 0.7023172809495201, 0.7488332700746612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 162}], {
             RGBColor[
             0.7225676146989453, 0.7771975396388044, 0.7540880673117176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 172}], {
             RGBColor[
             0.931531992024998, 0.7442858149051479, 0.38543931844832946`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 173}], {
             RGBColor[
             0.6807382359191774, 0.7409670341454773, 0.7514227362841381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 180}], {
             RGBColor[
             0.6678780579649132, 0.7298281943728316, 0.7506032971167013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 191}], {
             RGBColor[
             0.9019134129618684, 0.9202806576422312, 0.7699493982996792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 146}], {
             RGBColor[
             0.2946098536256002, 0.4237415625930442, 0.9402076894015805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 155}], {
             RGBColor[
             0.5085029810453545, 0.6084191221025781, 0.9555947876910933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 167}], {
             RGBColor[
             0.27157484914335084`, 0.3995303123785612, 0.9388958799735516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 191}], {
             RGBColor[
             0.5769597398249082, 0.6618980623518022, 0.9624179176414562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 194}], {
             RGBColor[
             0.2726689215363932, 0.40068025183184497`, 0.9389581857778003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 195}], {
             RGBColor[
             0.42242387419926064`, 0.539008517992182, 0.9484954160199432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 147}], {
             RGBColor[
             0.25576128412159904`, 0.3861517041867828, 0.9378765988145878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 154}], {
             RGBColor[
             0.29693436368645065`, 0.4272891715192359, 0.9402996292628881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 157}], {
             RGBColor[
             0.2342114040964292, 0.3635014139390195, 0.9366493650273451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 168}], {
             RGBColor[
             0.23569763939068106`, 0.3650635414660385, 0.9367340039286646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 176}], {
             RGBColor[
             0.24804284091250217`, 0.37803913099645736`, 0.9374370448922433]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.2876001150236012, 0.4192043144804547, 0.9397048591920434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 154}], {
             RGBColor[
             0.5937667549119501, 0.6748088886146058, 0.9642312788067474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 158}], {
             RGBColor[
             0.5860035167018279, 0.6680847618686957, 0.9637366121327604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 160}], {
             RGBColor[
             0.6494266978782655, 0.7230187336619522, 0.967777881154406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 181}], {
             RGBColor[
             0.6469177981644729, 0.7208456508308313, 0.967618016283176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 188}], {
             RGBColor[
             0.5844325062491007, 0.6667240315758246, 0.9636365087359027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 158}], {
             RGBColor[
             0.2574165112915451, 0.3871889319062931, 0.9379965842878197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 153}], {
             RGBColor[
             0.2362249636187789, 0.3656177926640565, 0.9367640342633485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 185}], {
             RGBColor[
             0.2111217144827195, 0.33923268618413416`, 0.935334441361979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 155}], {
             RGBColor[
             0.4592969410332923, 0.5599429054907851, 0.9526738544811711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 171}], {
             RGBColor[
             0.27657700131279794`, 0.4080303427474302, 0.9390620231145327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 184}], {
             RGBColor[
             0.21360634880243462`, 0.34184419438906943`, 0.9354759376107997]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 186}], {
             RGBColor[
             0.2142358988127285, 0.34250589136566434`, 0.9355117895525502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 191}], {
             RGBColor[
             0.527753699812846, 0.6134218457400091, 0.9594969844315341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 194}], {
             RGBColor[
             0.22346288152433108`, 0.352204035220052, 0.9360372525678782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 195}], {
             RGBColor[
             0.37321783418719845`, 0.490532301380389, 0.9455744828100211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 196}], {
             RGBColor[
             0.23919497538687848`, 0.3687394633419514, 0.9369331720398031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 154}], {
             RGBColor[
             0.2906977642675366, 0.42073411010671546`, 0.939944464152203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 157}], {
             RGBColor[
             0.2279748046775151, 0.3569463525264991, 0.9362941999166599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 168}], {
             RGBColor[
             0.22946103997176695`, 0.35850848005351804`, 0.9363788388179795]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 176}], {
             RGBColor[
             0.24180624149358806`, 0.37148406958393687`, 0.9370818797815581]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 188}], {
             RGBColor[
             0.2813635156046871, 0.41264925306793426`, 0.9393496940813583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 150}], {
             RGBColor[
             0.19306951159997304`, 0.3202586763785973, 0.9343063951136474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 193}], {
             RGBColor[
             0.21151914615710812`, 0.33965041207254015`, 0.9353570745078879]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 167}], {
             RGBColor[
             0.19241882352516138`, 0.31957476195596346`, 0.9342693393903937]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 168}], {
             RGBColor[
             0.19745061882106624`, 0.32486349784620777`, 0.9345558926886215]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 189}], {
             RGBColor[
             0.18996767873421347`, 0.31699845336912136`, 0.934129750320693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 194}], {
             RGBColor[
             0.1935128959182038, 0.3207247014092473, 0.9343316451946424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.19310487903170026`, 0.3202958497917673, 0.934308409236563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 156}], {
             RGBColor[
             0.8771128434559579, 0.42716749015211075`, 0.3606061102513105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 172}], {
             RGBColor[
             0.9316219629473853, 0.7456677416234209, 0.4816953197665501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 175}], {
             RGBColor[
             0.7472372281358932, 0.7985860801048122, 0.8522647687143463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 183}], {
             RGBColor[
             0.9651436444656913, 0.888619018725243, 0.5091874749108671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 199}], {
             RGBColor[
             0.9945819459025071, 0.992027509640117, 0.7394547080773856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 159}], {
             RGBColor[
             0.22753887579901738`, 0.3564881636357107, 0.9362693744119284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 178}], {
             RGBColor[
             0.19191650879429833`, 0.319046797325233, 0.9342407333095791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 200}], {
             RGBColor[
             0.19539965938545223`, 0.3227078094410386, 0.9344390935828858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 182}], {
             RGBColor[
             0.3115448088984465, 0.4418170728820753, 0.941162011715067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 185}], {
             RGBColor[
             0.2571534731580585, 0.38761498313398474`, 0.937955881920655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 157}], {
             RGBColor[
             0.2691478842423667, 0.3980838198589522, 0.9387172303649602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 158}], {
             RGBColor[
             0.3241076056222659, 0.45514745069325846`, 0.9418728279265163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 160}], {
             RGBColor[
             0.38753078679870345`, 0.510081422486515, 0.9459140969481619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 176}], {
             RGBColor[
             0.28297932105843965`, 0.41262153691639003`, 0.9395049102298585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 181}], {
             RGBColor[
             0.3850218870849109, 0.5079083396553941, 0.9457542320769319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 188}], {
             RGBColor[
             0.3225365951695387, 0.45378672040038737`, 0.9417727245296585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 172}], {
             RGBColor[
             0.77126540629573, 0.6221045625124598, 0.590374002869697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 191}], {
             RGBColor[
             0.7416468272326004, 0.7980994052495431, 0.9748840827210469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 195}], {
             RGBColor[
             0.5871109616069528, 0.6752098608899229, 0.9609615810995339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 199}], {
             RGBColor[
             0.8342253892508518, 0.868464330529156, 0.8481333911805324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 166}], {
             RGBColor[
             0.8137215668820587, 0.378784797567889, 0.4373955442628925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 170}], {
             RGBColor[
             0.7642144391985147, 0.3401094531533983, 0.43246113644580897`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 175}], {
             RGBColor[
             0.7126688743756485, 0.2983936614071581, 0.42831356501794793`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 183}], {
             RGBColor[
             0.8579398185955138, 0.3584156204874453, 0.19959536914896175`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 199}], {
             RGBColor[
             0.8775653528867244, 0.4273546144306946, 0.3531068579266407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 168}], {
             RGBColor[
             0.2079111599465971, 0.33585818980575477`, 0.9351516050307367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 176}], {
             RGBColor[
             0.2202563614684182, 0.34883377933617365`, 0.9358546459943153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 188}], {
             RGBColor[
             0.25981363557951725`, 0.389998962820171, 0.9381224602941154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 160}], {
             RGBColor[
             0.3797675485885813, 0.503357295740605, 0.945419430274175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 176}], {
             RGBColor[
             0.27521608284831744`, 0.40589741017048, 0.9390102435558715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.37725864887478877`, 0.501184212909484, 0.945259565402945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 161}], {
             RGBColor[
             0.2693600530686908, 0.4004448725619264, 0.938651028588549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 162}], {
             RGBColor[
             0.3531520525661749, 0.4753251312512108, 0.9439058258256054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 164}], {
             RGBColor[
             0.22503263737217588`, 0.35385394814440607`, 0.9361266478411673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 173}], {
             RGBColor[
             0.3113226737864071, 0.4390946257578836, 0.941240494798026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 180}], {
             RGBColor[
             0.29846249583214285`, 0.427955785985238, 0.9404210556305891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 200}], {
             RGBColor[
             0.22275289923247676`, 0.35145779881583583`, 0.9359968201266817]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[
             0.4406818300512263, 0.5561181847027405, 0.9493008344245906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 162}], {
             RGBColor[
             0.3676199899888237, 0.4905318508026293, 0.94472975345843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 164}], {
             RGBColor[
             0.23950057479482478`, 0.3690606676958246, 0.9369505754739917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 173}], {
             RGBColor[
             0.32579061120905595`, 0.4543013453093021, 0.9420644224308505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 180}], {
             RGBColor[
             0.31293043325479175`, 0.4431625055366565, 0.9412449832634135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 200}], {
             RGBColor[
             0.23722083665512567`, 0.36666451836725433`, 0.9368207477595063]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 172}], {
             RGBColor[
             0.6603763668123606, 0.5325003847582571, 0.5813358018320983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 173}], {
             RGBColor[
             0.40958261070654, 0.5291816039985865, 0.947319219667907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 180}], {
             RGBColor[
             0.3967224327522758, 0.5180427642259409, 0.9464997805004701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 165}], {
             RGBColor[
             0.24378292836413576`, 0.3735616928140688, 0.9371944491745896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 175}], {
             RGBColor[
             0.39116697450397153`, 0.5094530755186824, 0.9465916451974521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 177}], {
             RGBColor[
             0.24957629716502022`, 0.3796508907445958, 0.937524372957279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 200}], {
             RGBColor[
             0.19289342095861073`, 0.320073593949734, 0.9342963670121247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 169}], {
             RGBColor[
             0.1989480925621131, 0.32643743769336697`, 0.9346411716028602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 175}], {
             RGBColor[
             0.35318722837559335`, 0.4695339542827697, 0.9444287548414402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 177}], {
             RGBColor[
             0.2115965510366421, 0.3397317695086831, 0.9353614826012671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 170}], {
             RGBColor[
             0.7294686605093437, 0.78858572884784, 0.973670276873511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 179}], {
             RGBColor[
             0.5861348125663353, 0.6701157697397615, 0.962887963403471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 183}], {
             RGBColor[
             0.8700567296048425, 0.8160449798489104, 0.6243716259282402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 192}], {
             RGBColor[
             0.6347217686990404, 0.711862763594694, 0.9660768808598341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 198}], {
             RGBColor[
             0.5746764165171943, 0.6601910829977264, 0.9621578445394816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 189}], {
             RGBColor[
             0.19688265985809134`, 0.32426653696544305`, 0.9345235482659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 194}], {
             RGBColor[
             0.2004278770420817, 0.327992785005569, 0.9347254431398494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 197}], {
             RGBColor[
             0.20001986015557813`, 0.327563933388089, 0.9347022071817699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 188}], {
             RGBColor[
             0.2612998708737691, 0.39156109034719, 0.938207099195435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 189}], {
             RGBColor[
             0.2019144551539962, 0.3295552728556873, 0.9348101015641277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 197}], {
             RGBColor[
             0.20505165545148296`, 0.3328526692783333, 0.9349887604799977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 177}], {
             RGBColor[
             0.20474146136299756`, 0.33252663562389395`, 0.9349710953855495]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 190}], {
             RGBColor[
             0.18813962732028144`, 0.31507705542792475`, 0.9340256454970293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 179}], {
             RGBColor[
             0.5118741210410194, 0.6121027531180253, 0.9554863516778458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 183}], {
             RGBColor[
             0.7957960380795266, 0.7580319632271744, 0.6169700142026149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[
             0.5604610771737245, 0.6538497469729578, 0.9586752691342088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 198}], {
             RGBColor[
             0.5004157249918784, 0.6021780663759904, 0.9547562328138562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 174}], {
             RGBColor[
             0.24889168370669917`, 0.37893131859289997`, 0.9374853852336225]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 182}], {
             RGBColor[
             0.3242915422574164, 0.45521469783192636`, 0.9418879193227581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 191}], {
             RGBColor[
             0.558926887512106, 0.6461868425061883, 0.9612722513544084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 195}], {
             RGBColor[
             0.4043910218864583, 0.5232972981465681, 0.9473497497328954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 196}], {
             RGBColor[
             0.2703681630861383, 0.4015044601081305, 0.9387084389626774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 199}], {
             RGBColor[
             0.6515054495303574, 0.7165517677858011, 0.834521559813894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 173}], {
             RGBColor[
             0.6185469880325928, 0.49626987926492994`, 0.5786704708045187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 180}], {
             RGBColor[
             0.6056868100783286, 0.4851310394922843, 0.577851031637082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 191}], {
             RGBColor[
             0.8397221650752837, 0.6755835027616839, 0.59719713282006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 180}], {
             RGBColor[
             0.35489305397250803`, 0.4818122587326137, 0.9438344494728906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 186}], {
             RGBColor[
             0.18655058120662976`, 0.3134068672111341, 0.9339351516716399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 196}], {
             RGBColor[
             0.21150965778077974`, 0.33964043918742115`, 0.9353565341588927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 183}], {
             RGBColor[
             0.7184776908452273, 0.695458275607814, 0.6107486570608233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 188}], {
             RGBColor[
             0.2736450723955902, 0.4045366798776089, 0.9389101401590136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 179}], {
             RGBColor[
             0.2929650964677688, 0.41972688072457853`, 0.940197722295881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 190}], {
             RGBColor[
             0.20078808579481044`, 0.3283713872432409, 0.9347459564954362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 183}], {
             RGBColor[
             0.6524621901365182, 0.6395620041190959, 0.6061877007325749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 192}], {
             RGBColor[
             0.41712722923071616`, 0.5353797878648794, 0.9478929556641686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 185}], {
             RGBColor[
             0.28644155976238705`, 0.41543196640215296`, 0.9397324188136974]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 195}], {
             RGBColor[
             0.42093237513181697`, 0.5377166564648852, 0.9484003790182465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 196}], {
             RGBColor[
             0.28690951633149697`, 0.41592381842644754`, 0.9397590682480286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 199}], {
             RGBColor[
             0.668046802775716, 0.7309711261041182, 0.8355721890992451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 192}], {
             RGBColor[
             0.7010491462692232, 0.6813089979740284, 0.609376618188938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 186}], {
             RGBColor[
             0.18243843400162507`, 0.3090847397734826, 0.9337009709716915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 194}], {
             RGBColor[
             0.19166541671322765`, 0.3187828836278702, 0.9342264339870195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 198}], {
             RGBColor[
             0.2745522899410462, 0.4024926676355137, 0.9390715600433216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 194}], {
             RGBColor[
             0.19797673225113377`, 0.32541647641872684`, 0.9345858540701487]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 197}], {
             RGBColor[
             0.19756871536463022`, 0.3249876248012469, 0.9345626181120692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 195}], {
             RGBColor[
             0.6555677203865065, 0.728688801139147, 0.9677847110498968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 199}], {
             RGBColor[
             0.9026821480304056, 0.9219432707783801, 0.8549565211308954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 197}], {
             RGBColor[
             0.20111393254862053`, 0.3287138728413728, 0.9347645129860187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 196}], {
             RGBColor[
             0.3670089959605389, 0.4840064187410893, 0.9452208986581658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 199}], {
             RGBColor[
             0.748146282404758, 0.7990537264187598, 0.8410340195093824]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.04610843439966642], {
             RGBColor[
             0.17991592983646426`, 0.30643342795989703`, 0.9335573180911961]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.04610843439966642], {
             RGBColor[
             0.18237351643808017`, 0.30901650729818564`, 0.9336972740124846]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.04610843439966642], {
             RGBColor[
             0.4186929718519593, 0.5370725409226834, 0.947899723824117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.04610843439966642], {
             RGBColor[
             0.33430755049502603`, 0.4639821302779076, 0.9425227593943515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.04610843439966642], {
             RGBColor[
             0.35433408061295757`, 0.481328104103389, 0.9437988321847008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.04610843439966642], {
             RGBColor[
             0.8314330293974257, 0.24261361475573226`, 0.17773361049049105`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.04610843439966642], {
             RGBColor[
             0.20849433214894747`, 0.33647114076567824`, 0.9351848158249345]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.04610843439966642], {
             RGBColor[
             0.28326421471662644`, 0.41505902802867256`, 0.939442850025035]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.04610843439966642], {
             RGBColor[
             0.19331350997927296`, 0.32051513414563226`, 0.9343202904603853]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.04610843439966642], {
             RGBColor[
             0.2179504265625759, 0.34641009554541596`, 0.9357233264127526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.04610843439966642], {
             RGBColor[
             0.20295626314304663`, 0.3306502791066209, 0.9348694309878873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.04610843439966642], {
             RGBColor[
             0.950102117301832, 0.8398785531251466, 0.2787091962084557]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.04610843439966642], {
             RGBColor[
             0.22110598802207443`, 0.3497267907135012, 0.9359030309696362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.04610843439966642], {
             RGBColor[
             0.17925722738073346`, 0.3057410899147761, 0.9335198059608052]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.04610843439966642], {
             RGBColor[
             0.1871756577266932, 0.3140638622658612, 0.9339707488547396]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.04610843439966642], {
             RGBColor[
             0.19146922694525287`, 0.31857667574257903`, 0.9342152612699701]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.04610843439966642], {
             RGBColor[
             0.22306772190849825`, 0.3517886974092449, 0.9360147488123428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.04610843439966642], {
             RGBColor[
             0.35121665541737046`, 0.47862794708531764`, 0.9436001926078689]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.04610843439966642], {
             RGBColor[
             0.1823235017276304, 0.3089639386663871, 0.9336944257487145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.04610843439966642], {
             RGBColor[
             0.36130368564417137`, 0.48736482567889206`, 0.94424292925431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.04610843439966642], {
             RGBColor[
             0.18848942771341942`, 0.31544471781973865`, 0.9340455661119352]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.04610843439966642], {
             RGBColor[
             0.22363768830217948`, 0.3523877682269605, 0.9360472075552733]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.04610843439966642], {
             RGBColor[
             0.2571472380542651, 0.3876084296445695, 0.9379555268407181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.04610843439966642], {
             RGBColor[
             0.17953882470990998`, 0.3060370665620425, 0.9335358425121159]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.04610843439966642], {
             RGBColor[
             0.2927822195605681, 0.4250630545960175, 0.9399848863202711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.04610843439966642], {
             RGBColor[
             0.26652048668465833`, 0.39746030825340095`, 0.9384893194837403]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.04610843439966642], {
             RGBColor[
             0.1792907180836107, 0.3057762907669333, 0.933521713206789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.04610843439966642], {
             RGBColor[
             0.20691074357712266`, 0.33480668877137576`, 0.9350946327984784]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.04610843439966642], {
             RGBColor[
             0.2095661987749073, 0.33759774054983127`, 0.9352458570435983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.04610843439966642], {
             RGBColor[
             0.531961775829707, 0.6309095600802831, 0.9562971261149575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.04610843439966642], {
             RGBColor[
             0.186006868294159, 0.3128353904667376, 0.9339041880256258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.04610843439966642], {
             RGBColor[
             0.9926235425767636, 0.9912176595362523, 0.7719105193703001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.04610843439966642], {
             RGBColor[
             0.4300571649791395, 0.5469156338284925, 0.9486238401612196]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.04610843439966642], {
             RGBColor[
             0.18077756667952594`, 0.30733906291288604`, 0.933606387034731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.04610843439966642], {
             RGBColor[
             0.18255152448721731`, 0.309203605044191, 0.9337074113075435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.04610843439966642], {
             RGBColor[
             0.23584637567939642`, 0.36521987273590373`, 0.9367424742402714]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.04610843439966642], {
             RGBColor[
             0.18112444186066054`, 0.30770365072141526`, 0.9336261410631407]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.04610843439966642], {
             RGBColor[
             0.25206224059906557`, 0.3822637749116947, 0.9376659437582241]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.04610843439966642], {
             RGBColor[
             0.5058302216121423, 0.609694787153362, 0.9542399544439137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.04610843439966642], {
             RGBColor[
             0.29070628845368207`, 0.422881119381046, 0.9398666651147989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.04610843439966642], {
             RGBColor[
             0.2027701922068055, 0.3304547067550528, 0.9348588345233357]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.04610843439966642], {
             RGBColor[
             0.18974733652345127`, 0.3167668597351072, 0.9341172021577572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.04610843439966642], {
             RGBColor[
             0.8987739036289236, 0.6332377629819576, 0.2372468027203504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.04610843439966642], {
             RGBColor[
             0.7110429824499928, 0.7741914491075349, 0.9718337774823064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.04610843439966642], {
             RGBColor[
             0.18297903858873563`, 0.3096529494708463, 0.9337317576031746]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.04610843439966642], {
             RGBColor[
             0.1962609887352336, 0.32361312119909375`, 0.9344881450151332]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.04610843439966642], {
             RGBColor[
             0.21049372737267863`, 0.3385726319147987, 0.9352986784250858]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.04610843439966642], {
             RGBColor[
             0.4223544797753533, 0.5402439550531881, 0.9481330318712514]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.04610843439966642], {
             RGBColor[
             0.20374667641262958`, 0.33148105356804847`, 0.9349144438542785]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.04610843439966642], {
             RGBColor[
             0.18219656266820544`, 0.3088305176665303, 0.9336871967570698]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.04610843439966642], {
             RGBColor[
             0.18558886593634766`, 0.31239604348579764`, 0.9338803834097276]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.04610843439966642], {
             RGBColor[
             0.631783197735858, 0.7119490872875069, 0.9641554341053266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.04610843439966642], {
             RGBColor[
             0.988392764379178, 0.9725082101217492, 0.4094085107659739]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.04610843439966642], {
             RGBColor[
             0.33587823342715956`, 0.465342576888902, 0.9426228419218866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.04610843439966642], {
             RGBColor[
             0.1825695689347496, 0.30922257090263144`, 0.9337084389121362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.04610843439966642], {
             RGBColor[
             0.1818396285304826, 0.30845535725685214`, 0.9336668698859633]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.04610843439966642], {
             RGBColor[
             0.9605766768067475, 0.9701187306290152, 0.9516175823034524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.04610843439966642], {
             RGBColor[
             0.18422301466471383`, 0.3109604471993381, 0.9338026002004038]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.04610843439966642], {
             RGBColor[
             0.18098071777705174`, 0.3075525875969092, 0.9336179561892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.04610843439966642], {
             RGBColor[
             0.2073405252862433, 0.3352584165973958, 0.9351191082310077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.04610843439966642], {
             RGBColor[
             0.1999014029793203, 0.32743942738522325`, 0.9346954612208237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.04610843439966642], {
             RGBColor[
             0.19167260114558432`, 0.31879043492179643`, 0.9342268431298139]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.04610843439966642], {
             RGBColor[
             0.6295309817704698, 0.7101206369056319, 0.9639781314143923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.04610843439966642], {
             RGBColor[
             0.95633856953826, 0.8643818842404721, 0.284884016735784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.04610843439966642], {
             RGBColor[
             0.18354617680954663`, 0.31024904769955874`, 0.9337640552858439]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.04610843439966642], {
             RGBColor[
             0.2558901091184015, 0.3862871074263986, 0.9378839352075763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.04610843439966642], {
             RGBColor[
             0.9609913119589255, 0.8800766769412489, 0.30295904244338884`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.04610843439966642], {
             RGBColor[
             0.24981404640376637`, 0.37990078026869034`, 0.9375379124247071]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.04610843439966642], {
             RGBColor[
             0.19105055232810444`, 0.31813662217445204`, 0.9341914183698972]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.04610843439966642], {
             RGBColor[
             0.3637386159115608, 0.4894738398933511, 0.9443980808578237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.04610843439966642], {
             RGBColor[
             0.2532013109542942, 0.38346101007627187`, 0.9377308121298508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.04610843439966642], {
             RGBColor[
             0.21747923322295587`, 0.34591484147009205`, 0.9356964926491292]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.04610843439966642], {
             RGBColor[
             0.34593054718585675`, 0.47404938582270545`, 0.9432633664656788]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.04610843439966642], {
             RGBColor[
             0.5021423004164799, 0.6067007665877667, 0.9539496277780908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.04610843439966642], {
             RGBColor[
             0.26424845016803866`, 0.3950722538189983, 0.9383599303652956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.04610843439966642], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.04610843439966642], {
             RGBColor[
             0.18293127670980908`, 0.3096027487078165, 0.9337290376348271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.04610843439966642], {
             RGBColor[
             0.1941778278429074, 0.3214235870212298, 0.9343695120840757]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.04610843439966642], {
             RGBColor[
             0.22179319725678925`, 0.3504490911907685, 0.9359421665189183]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.04610843439966642], {
             RGBColor[
             0.30602988251049323`, 0.4389871883067331, 0.9407393211271083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.04610843439966642], {
             RGBColor[
             0.21196511221078973`, 0.3401191506708405, 0.9353824716148974]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.04610843439966642], {
             RGBColor[
             0.9263859833659136, 0.9441390533310817, 0.9928407161596127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.04610843439966642], {
             RGBColor[
             0.181234979779358, 0.3078198330824752, 0.9336324360340843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.04610843439966642], {
             RGBColor[
             0.2704719529099895, 0.40161354979365305`, 0.9387143496396024]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.04610843439966642], {
             RGBColor[
             0.2020967142561969, 0.3297468387279948, 0.9348204809503698]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.04610843439966642], {
             RGBColor[
             0.21670300720810273`, 0.3450989787129095, 0.9356522877259069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.04610843439966642], {
             RGBColor[
             0.21656281497127022`, 0.34495162778329735`, 0.9356443039854151]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.04610843439966642], {
             RGBColor[
             0.2675148103379351, 0.39850540545675567`, 0.9385459447448243]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.04610843439966642], {
             RGBColor[
             0.22727061882380845`, 0.3562062085462915, 0.9362540975740409]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.04610843439966642], {
             RGBColor[
             0.18623437450108682`, 0.31307451391494534`, 0.9339171441675451]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.04610843439966642], {
             RGBColor[
             0.2444470173259052, 0.37425969241856055`, 0.9372322680585309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.04610843439966642], {
             RGBColor[
             0.23138676958404353`, 0.3605325439743302, 0.9364885062705369]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.04610843439966642], {
             RGBColor[
             0.19041076970754647`, 0.3174641700756846, 0.9341549836961299]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.04610843439966642], {
             RGBColor[
             0.24919784069125972`, 0.37925310899514714`, 0.9375028204209744]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.04610843439966642], {
             RGBColor[
             0.9364164576881094, 0.9521000787690629, 0.9925145312769647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.04610843439966642], {
             RGBColor[
             0.21679935925455723`, 0.3452002508228058, 0.9356577748324124]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.04610843439966642], {
             RGBColor[
             0.19250116414799295`, 0.31966130717125646`, 0.9342740285670519]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.04610843439966642], {
             RGBColor[
             0.5518206973838005, 0.647031927232117, 0.9578604931653224]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.04610843439966642], {
             RGBColor[
             0.20579087184942513`, 0.3336296325815971, 0.9350308577602878]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.04610843439966642], {
             RGBColor[
             0.19619436846660787`, 0.3235430990727991, 0.9344843510893909]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.04610843439966642], {
             RGBColor[
             0.9691756477061694, 0.9765318290462814, 0.9370617675415293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.04610843439966642], {
             RGBColor[
             0.1810808656124072, 0.3076578493216073, 0.933623659460268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.04610843439966642], {
             RGBColor[
             0.36710024085613885`, 0.49238551046016216`, 0.9446122806267241]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.04610843439966642], {
             RGBColor[
             0.20575656042090384`, 0.333593569094751, 0.9350289037751928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.04610843439966642], {
             RGBColor[
             0.18503007033382515`, 0.31180871387785897`, 0.9338485608268279]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.04610843439966642], {
             RGBColor[
             0.21763298899601496`, 0.34607644853625624`, 0.9357052488129437]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.04610843439966642], {
             RGBColor[
             0.3080267094125234, 0.4410859799869048, 0.9408530374651383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.04610843439966642], {
             RGBColor[
             0.21740901950548744`, 0.34584104240122593`, 0.9356924940817913]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.04610843439966642], {
             RGBColor[
             0.18012636844446756`, 0.30665461227948687`, 0.9335693022586058]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.04610843439966642], {
             RGBColor[
             0.2201361607798215, 0.3487074407912947, 0.9358478007429207]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.04610843439966642], {
             RGBColor[
             0.9414109245622558, 0.9558249439861124, 0.9840602016246193]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.04610843439966642], {
             RGBColor[
             0.20445336338735556`, 0.33222382638502757`, 0.9349546886320393]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.04610843439966642], {
             RGBColor[
             0.18141516357964482`, 0.30800921768088935`, 0.9336426972349526]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.04610843439966642], {
             RGBColor[
             0.31502527059825963`, 0.4472807885868956, 0.9412941095699802]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.04610843439966642], {
             RGBColor[
             0.24062773125074222`, 0.3702453805968408, 0.9370147653666777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.04610843439966642], {
             RGBColor[
             0.1853227778630534, 0.31211636804980714`, 0.9338652300875955]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.04610843439966642], {
             RGBColor[
             0.39086743560945575`, 0.5129714599815431, 0.9461267052599003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.04610843439966642], {
             RGBColor[
             0.8468258702473929, 0.3609297347144502, 0.19247381227214683`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.04610843439966642], {
             RGBColor[
             0.1939380814128329, 0.3211715983224198, 0.934355858879556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.04610843439966642], {
             RGBColor[
             0.21735301065346377`, 0.34578217354658275`, 0.9356893044605262]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.04610843439966642], {
             RGBColor[
             0.27792375203997, 0.40944586315061604`, 0.939138718576106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.04610843439966642], {
             RGBColor[
             0.4511243917370499, 0.5651630067765897, 0.9499662252212164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.04610843439966642], {
             RGBColor[
             0.2260372839021752, 0.3549098953457044, 0.9361838609748094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.04610843439966642], {
             RGBColor[
             0.2642831104182927, 0.3951086839396021, 0.9383619042152723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.04610843439966642], {
             RGBColor[
             0.1796655907243716, 0.3061703056806712, 0.9335430616491059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.04610843439966642], {
             RGBColor[
             0.874787420357395, 0.9029957597937702, 0.9879191991572792]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.04610843439966642], {
             RGBColor[
             0.43130662815416465`, 0.5479978560308542, 0.9487034548498753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.04610843439966642], {
             RGBColor[
             0.4544709331932017, 0.5679990031052896, 0.9501967631243022]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.04610843439966642], {
             RGBColor[
             0.1842953386135795, 0.3110364642551991, 0.933806718942298]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.04610843439966642], {
             RGBColor[
             0.1814951086723694, 0.3080932450421545, 0.9336472499897152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.04610843439966642], {
             RGBColor[
             0.30056549504747376`, 0.4332437706209237, 0.9404281323449262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.04610843439966642], {
             RGBColor[
             0.24912319227677354`, 0.3791746487785393, 0.937498569304202]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.04610843439966642], {
             RGBColor[
             0.24687317251219526`, 0.37680973534647483`, 0.9373704340072151]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.04610843439966642], {
             RGBColor[
             0.1969362596236349, 0.3243228737174507, 0.934526600693254]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.04610843439966642], {
             RGBColor[
             0.22281221312870114`, 0.35152014148148586`, 0.9360001979653247]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.04610843439966642], {
             RGBColor[
             0.32389238094576056`, 0.45496103389597625`, 0.9418591140004451]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.04610843439966642], {
             RGBColor[
             0.2218736173884548, 0.35053361784807985`, 0.9359467463264457]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.04610843439966642], {
             RGBColor[
             0.28566810415648325`, 0.4175856682453557, 0.9395797479723991]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.04610843439966642], {
             RGBColor[
             0.9937232399115826, 0.9889829697856952, 0.5581915839279488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.04610843439966642], {
             RGBColor[
             0.34381589363766235`, 0.47221777920483715`, 0.9431286226115025]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.04610843439966642], {
             RGBColor[
             0.2619978835405132, 0.39270676559930323`, 0.938231763925273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.04610843439966642], {
             RGBColor[
             0.8556626659915121, 0.887746199790043, 0.9860950630129915]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.04610843439966642], {
             RGBColor[
             0.19848865517094644`, 0.32595453986523776`, 0.93461500732311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.04610843439966642], {
             RGBColor[
             0.1901932049434399, 0.31723549571420584`, 0.9341425937046723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.04610843439966642], {
             RGBColor[
             0.24540381361353808`, 0.37526534598125116`, 0.9372867561916584]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.04610843439966642], {
             RGBColor[
             0.24952468470268496`, 0.3795966427742623, 0.9375214337039027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.04610843439966642], {
             RGBColor[
             0.19357697366818166`, 0.320792051187238, 0.9343352943277091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.04610843439966642], {
             RGBColor[
             0.1855038424012835, 0.31230667835964177`, 0.9338755414451867]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.04610843439966642], {
             RGBColor[
             0.19256204953176445`, 0.3197253015699566, 0.9342774958995859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.04610843439966642], {
             RGBColor[
             0.9939031817563573, 0.9917468232222412, 0.7507035865643902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.04610843439966642], {
             RGBColor[
             0.20018563595199287`, 0.32773817426091345`, 0.9347116478681324]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.04610843439966642], {
             RGBColor[
             0.2822567222941179, 0.41400008961390705`, 0.9393854748220246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.04610843439966642], {
             RGBColor[
             0.33187084383238813`, 0.46187157743916857`, 0.9423674946005033]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.04610843439966642], {
             RGBColor[
             0.6731900684530466, 0.744620465000319, 0.9680609527706839]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.04610843439966642], {
             RGBColor[
             0.8187176743057581, 0.14487782361704554`, 0.16555737209477062`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.04610843439966642], {
             RGBColor[
             0.20642492465234524`, 0.3342960622787358, 0.9350669661294171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.04610843439966642], {
             RGBColor[
             0.3163443674121438, 0.4484233239473484, 0.9413781612525294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.04610843439966642], {
             RGBColor[
             0.2548921156460419, 0.3852381530105079, 0.9378271009557244]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.04610843439966642], {
             RGBColor[
             0.44319072976501883`, 0.5582912675338615, 0.9494606992958204]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.04610843439966642], {
             RGBColor[
             0.2838279904913397, 0.4156515921133449, 0.9394749562213734]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.04610843439966642], {
             RGBColor[
             0.4514119894863078, 0.5654121094919137, 0.9499845506954865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.04610843439966642], {
             RGBColor[
             0.2817626744925139, 0.41348081404998144`, 0.9393573395306015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.04610843439966642], {
             RGBColor[
             0.19517315909830985`, 0.32246974327830424`, 0.9344261947266101]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.04610843439966642], {
             RGBColor[
             0.2058031822357576, 0.33364257157815613`, 0.9350315588185778]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.04610843439966642], {
             RGBColor[
             0.8037293520346596, 0.846598745469576, 0.9810718885991364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.04610843439966642], {
             RGBColor[
             0.19933380464903927`, 0.32684284555228516`, 0.9346631373356007]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.04610843439966642], {
             RGBColor[
             0.20939739524084894`, 0.3374203173327738, 0.9352362439320562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.04610843439966642], {
             RGBColor[
             0.19209300288846856`, 0.31923230380857776`, 0.9342507843871425]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.04610843439966642], {
             RGBColor[
             0.6552079689840278, 0.7305727122261038, 0.9662686651478858]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.04610843439966642], {
             RGBColor[
             0.30775018901205775`, 0.44079533951360933`, 0.940837290037407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.04610843439966642], {
             RGBColor[
             0.8693407441384133, 0.4995886600246006, 0.2126870529687101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.04610843439966642], {
             RGBColor[
             0.36775323192677223`, 0.4929510985052593, 0.9446538886403275]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.04610843439966642], {
             RGBColor[
             0.19003317840134057`, 0.3170672976721906, 0.9341334804298378]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.04610843439966642], {
             RGBColor[
             0.5005712745154292, 0.6054253369873833, 0.9538259508643026]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.04610843439966642], {
             RGBColor[
             0.23408779828449117`, 0.3633714963936115, 0.9366423258592136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.04610843439966642], {
             RGBColor[
             0.21738991983752656`, 0.34582096743921015`, 0.9356914063839564]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.04610843439966642], {
             RGBColor[
             0.1836473816366038, 0.3103554203895525, 0.9337698187510258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.04610843439966642], {
             RGBColor[
             0.3685402730980111, 0.49363279400994686`, 0.9447040382078057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.04610843439966642], {
             RGBColor[
             0.3420328760182438, 0.47067341895996806`, 0.9430150103054538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.04610843439966642], {
             RGBColor[
             0.43817293033743376`, 0.5539451018716196, 0.9491409695533606]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.04610843439966642], {
             RGBColor[
             0.34083289550277507`, 0.46963405615024345`, 0.9429385486081092]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.04610843439966642], {
             RGBColor[
             0.9363841071750253, 0.7854912142282449, 0.26767136325734403`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.04610843439966642], {
             RGBColor[
             0.1818088839913312, 0.30842304279688765`, 0.933665119029941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.04610843439966642], {
             RGBColor[
             0.2320502240219991, 0.3612298766540624, 0.9365262890192856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.04610843439966642], {
             RGBColor[
             0.18306798401191893`, 0.3097464367500775, 0.933736822913442]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.04610843439966642], {
             RGBColor[
             0.20348109888236326`, 0.33120191474515054`, 0.9348993196068165]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.04610843439966642], {
             RGBColor[
             0.31320234650668927`, 0.4457018633616062, 0.9411779544588138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.04610843439966642], {
             RGBColor[
             0.19443151506714343`, 0.3216902283786009, 0.9343839591961993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.04610843439966642], {
             RGBColor[
             0.1841862517520943, 0.3109218070472717, 0.933800506606916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.04610843439966642], {
             RGBColor[
             0.8101035860121542, 0.8515783454987672, 0.9817072126714098]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.04610843439966642], {
             RGBColor[
             0.46571418536342124`, 0.577126781719812, 0.9510818731205317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.04610843439966642], {
             RGBColor[
             0.22946131864603458`, 0.3585087729578423, 0.9363788546880667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.04610843439966642], {
             RGBColor[
             0.2015219494351241, 0.32914272445885284`, 0.9347877489440981]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.04610843439966642], {
             RGBColor[
             0.5010318547608589, 0.6057992567795268, 0.9538622094283838]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.04610843439966642], {
             RGBColor[
             0.23298613716021888`, 0.3622135807026517, 0.9365795878879478]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.04610843439966642], {
             RGBColor[
             0.20070591566211698`, 0.3282850212238928, 0.9347412770279392]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.04610843439966642], {
             RGBColor[
             0.34562348099972906`, 0.47378342052587685`, 0.9432438004798267]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.04610843439966642], {
             RGBColor[
             0.995260710048657, 0.9923081960579929, 0.7282058295903809]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.04610843439966642], {
             RGBColor[
             0.1906136828189116, 0.3176774446211637, 0.9341665392976392]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{3.834950276960332*^9, 3.8350238655218115`*^9, 
  3.835051687451545*^9},
 CellLabel->
  "Out[396]=",ExpressionUUID->"ab5bb37a-ae35-4225-9bbb-dc5c5f34b0c7"]
}, Open  ]],

Cell["Estimated with absolute Mean Deviation v Calculated: (r=3)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 
  3.8349503756793146`*^9}},ExpressionUUID->"29b2ba4b-56b9-4558-b139-\
7fcbc6c1e21c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraphb", "[", 
     RowBox[{"graphin2", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsi2", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}], 
     "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"AMDi3200", ",", "kri2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502409842243`*^9}, {3.835051696716497*^9, 3.835051710692178*^9}},
 CellLabel->
  "In[399]:=",ExpressionUUID->"ab3bd2c6-dc0f-49ec-8ddd-d36483b11b20"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
          103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
          129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 
          142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 
          155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 
          168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 
          181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 
          194, 195, 196, 197, 198, 199, 200}, {Null, CompressedData["
1:eJwVxfk/Gg4DAOBN5QibNGP1lWNDwghlmCNXuqiMigzJGcNQUi05SwdqhpKc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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[21, 55] -> 
             RGBColor[
              0.48066837816587427`, 0.5854404586507955, 0.953342807341025], 
             UndirectedEdge[64, 132] -> 
             RGBColor[
              0.5555014986630993, 0.6500201675288597, 0.9581502593252482], 
             UndirectedEdge[42, 188] -> 
             RGBColor[
              0.43688191571033064`, 0.5477404645133989, 0.9500836334818032], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.7549447022154396, 0.8084878062537303, 0.9762094906236292], 
             UndirectedEdge[33, 68] -> 
             RGBColor[
              0.4962253631322169, 0.6018841401470345, 0.9534874140311349], 
             UndirectedEdge[168, 188] -> 
             RGBColor[
              0.5033527509965328, 0.6069015084988894, 0.9542609757649234], 
             UndirectedEdge[41, 161] -> 
             RGBColor[
              0.5049145050114772, 0.5948940872005494, 0.9573291284255319], 
             UndirectedEdge[44, 68] -> 
             RGBColor[
              0.4300398189030058, 0.5469006095291846, 0.9486227348845868], 
             UndirectedEdge[26, 136] -> 
             RGBColor[
              0.7730476985559296, 0.822630004582789, 0.9780138281167301], 
             UndirectedEdge[9, 32] -> 
             RGBColor[
              0.5697900622814771, 0.6614206326991535, 0.9594115985697951], 
             UndirectedEdge[71, 141] -> 
             RGBColor[
              0.6801749761910262, 0.749678917795876, 0.9690294015962584], 
             UndirectedEdge[52, 100] -> 
             RGBColor[
              0.6890977602672842, 0.7551622598667014, 0.9712142267723101], 
             UndirectedEdge[172, 180] -> 
             RGBColor[
              0.6705726220070842, 0.7414923522330963, 0.9685407581817971], 
             UndirectedEdge[168, 197] -> 
             RGBColor[
              0.7098311962135442, 0.7670695500012832, 0.8305107345246006], 
             UndirectedEdge[125, 137] -> 
             RGBColor[
              0.8636619361071235, 0.8941246006458287, 0.9868580405376514], 
             UndirectedEdge[17, 147] -> 
             RGBColor[
              0.7739615329201059, 0.8214538311930853, 0.9033526247393023], 
             UndirectedEdge[10, 71] -> 
             RGBColor[
              0.8058189170567076, 0.8486164113038825, 0.9811779149802472], 
             UndirectedEdge[27, 129] -> 
             RGBColor[
              0.7420617867969734, 0.6933225412120447, 0.6077052711279489], 
             UndirectedEdge[67, 166] -> 
             RGBColor[
              0.749934806412925, 0.8045740375761875, 0.9757101510301727], 
             UndirectedEdge[3, 49] -> 
             RGBColor[
              0.5492152285162643, 0.6435514195376859, 0.958244214353939], 
             UndirectedEdge[151, 183] -> 
             RGBColor[
              0.9677329343400352, 0.9173133416709458, 0.5965674831578203], 
             UndirectedEdge[125, 136] -> 
             RGBColor[
              0.8246098587719892, 0.8631178301470415, 0.9830981112677012], 
             UndirectedEdge[139, 194] -> 
             RGBColor[
              0.6492683276937596, 0.7181019254707335, 0.9394474106125429], 
             UndirectedEdge[24, 108] -> 
             RGBColor[
              0.4748275835494312, 0.5821330512402743, 0.9524603398165841], 
             UndirectedEdge[21, 192] -> 
             RGBColor[
              0.4876697246710411, 0.5909099637528361, 0.954040636129357], 
             UndirectedEdge[16, 52] -> 
             RGBColor[
              0.6108194869601655, 0.6933445258379897, 0.9635889562954418], 
             UndirectedEdge[44, 166] -> 
             RGBColor[
              0.5873250644123198, 0.6726892247185683, 0.9623109381968833], 
             UndirectedEdge[78, 187] -> 
             RGBColor[
              0.7238351598776431, 0.7841847953381647, 0.9731087821785998], 
             UndirectedEdge[99, 162] -> 
             RGBColor[
              0.888465279443732, 0.9104284981608423, 0.8209610186315847], 
             UndirectedEdge[93, 150] -> 
             RGBColor[
              0.6444939859996034, 0.7212880485723694, 0.9658262620049681], 
             UndirectedEdge[118, 155] -> 
             RGBColor[
              0.7649211403720777, 0.8168051508332239, 0.9770842730554132], 
             UndirectedEdge[16, 125] -> 
             RGBColor[
              0.7957244277252966, 0.8405523118759584, 0.9802190814506673], 
             UndirectedEdge[61, 179] -> 
             RGBColor[
              0.6634748089682118, 0.7338860648049476, 0.9692716767709861], 
             UndirectedEdge[51, 197] -> 
             RGBColor[
              0.9417444643383133, 0.7889529329618257, 0.47064787295387156`], 
             UndirectedEdge[80, 120] -> 
             RGBColor[
              0.7590713947317111, 0.8118504341851497, 0.9765839610471998], 
             UndirectedEdge[21, 183] -> 
             RGBColor[
              0.6491073236620415, 0.717116018258622, 0.9270836538337025], 
             UndirectedEdge[182, 199] -> 
             RGBColor[
              0.8448131004105621, 0.8782956762475178, 0.9199322870680855], 
             UndirectedEdge[17, 189] -> 
             RGBColor[
              0.4598705655932407, 0.5698444598236757, 0.9513231564310074], 
             UndirectedEdge[116, 136] -> 
             RGBColor[
              0.7910136665909806, 0.8366651553581852, 0.979804507908947], 
             UndirectedEdge[119, 123] -> 
             RGBColor[
              0.41422754051616745`, 0.5332048087387253, 0.9476151904880263], 
             UndirectedEdge[71, 89] -> 
             RGBColor[
              0.6980636563733282, 0.7640519009299129, 0.9705401195576828], 
             UndirectedEdge[7, 61] -> 
             RGBColor[
              0.7255431134759784, 0.7848148070451817, 0.9740090223581577], 
             UndirectedEdge[3, 27] -> 
             RGBColor[
              0.4917026105000795, 0.5973794853983438, 0.9533614937165669], 
             UndirectedEdge[41, 108] -> 
             RGBColor[
              0.6769769047982884, 0.7466916375126478, 0.9690449267827814], 
             UndirectedEdge[66, 98] -> 
             RGBColor[
              0.9753046913084995, 0.9385373272520691, 0.5866109075503985], 
             UndirectedEdge[119, 127] -> 
             RGBColor[
              0.7111975670307442, 0.7697400217815837, 0.8895538415316557], 
             UndirectedEdge[15, 167] -> 
             RGBColor[
              0.5055577665858522, 0.6084438991083261, 0.9545030140747088], 
             UndirectedEdge[12, 96] -> 
             RGBColor[
              0.39952041091677465`, 0.519171517448755, 0.9469819374307888], 
             UndirectedEdge[7, 52] -> 
             RGBColor[
              0.5167006181101985, 0.6185198647362657, 0.9550957118758152], 
             UndirectedEdge[163, 165] -> 
             RGBColor[
              0.887704572221851, 0.9132955460637406, 0.9891512486333887], 
             UndirectedEdge[71, 73] -> 
             RGBColor[
              0.5301748786328475, 0.6241834537328386, 0.958248312288771], 
             UndirectedEdge[60, 165] -> 
             RGBColor[
              0.936195894080819, 0.9486212949568282, 0.859691173878155], 
             UndirectedEdge[120, 124] -> 
             RGBColor[
              0.7336181880963841, 0.7918273713364136, 0.9740838630038473], 
             UndirectedEdge[43, 163] -> 
             RGBColor[
              0.6725134622482614, 0.7415561105136298, 0.9699207075961264], 
             UndirectedEdge[146, 194] -> 
             RGBColor[
              0.9644250756618611, 0.9258031868768869, 0.6168579995820571], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.9631875918445146, 0.9515951791680612, 0.6756634257538993], 
             UndirectedEdge[81, 157] -> 
             RGBColor[
              0.6193314623774882, 0.6978417570628734, 0.9654505217425644], 
             UndirectedEdge[59, 114] -> 
             RGBColor[
              0.6545725316680276, 0.7285027580999945, 0.9672811724600444], 
             UndirectedEdge[31, 185] -> 
             RGBColor[
              0.6688565648392633, 0.6779715056123925, 0.6130212139195694], 
             UndirectedEdge[58, 198] -> 
             RGBColor[
              0.5639324864359018, 0.6428921858892005, 0.9628625605968061], 
             UndirectedEdge[30, 142] -> 
             RGBColor[
              0.7343161953085189, 0.7920659718113703, 0.9745514461086693], 
             UndirectedEdge[26, 96] -> 
             RGBColor[
              0.617602315943993, 0.6989026928075981, 0.9640876730131213], 
             UndirectedEdge[25, 111] -> 
             RGBColor[
              0.9513543316662867, 0.9612033305272079, 0.8826363372187218], 
             UndirectedEdge[89, 107] -> 
             RGBColor[
              0.6361444946464502, 0.715339931279898, 0.9646012269031643], 
             UndirectedEdge[51, 189] -> 
             RGBColor[
              0.6240917132808466, 0.5359903735181136, 0.5863473800582018], 
             UndirectedEdge[81, 158] -> 
             RGBColor[
              0.6314402251266942, 0.7074969557954814, 0.9666054663432038], 
             UndirectedEdge[93, 159] -> 
             RGBColor[
              0.5864727730616236, 0.6751640433255934, 0.9605884314974162], 
             UndirectedEdge[191, 195] -> 
             RGBColor[
              0.42228382179443585`, 0.5352089831101965, 0.948996324178453], 
             UndirectedEdge[17, 131] -> 
             RGBColor[
              0.7706978295072389, 0.8196556830391091, 0.937354863767255], 
             UndirectedEdge[18, 32] -> 
             RGBColor[
              0.6340666055741792, 0.7116339568392347, 0.9658180837067635], 
             UndirectedEdge[59, 184] -> 
             RGBColor[
              0.7399007336403625, 0.796735343664484, 0.9747100484299449], 
             UndirectedEdge[156, 175] -> 
             RGBColor[
              0.7972059553813173, 0.8384314697857883, 0.8080936033389075], 
             UndirectedEdge[2, 82] -> 
             RGBColor[
              0.7611402543057435, 0.813049380314975, 0.9675266247854558], 
             UndirectedEdge[12, 44] -> 
             RGBColor[
              0.35677778961375844`, 0.48322000775403284`, 0.943962771051247], 
             UndirectedEdge[115, 175] -> 
             RGBColor[
              0.5823485418440294, 0.6718158066286514, 0.9602637569084105], 
             UndirectedEdge[30, 131] -> 
             RGBColor[
              0.9285869551247156, 0.9447131660749035, 0.952108712946464], 
             UndirectedEdge[53, 65] -> 
             RGBColor[
              0.8314846403128888, 0.8684672984089324, 0.9837889413397862], 
             UndirectedEdge[17, 51] -> 
             RGBColor[
              0.724124534776274, 0.6197397325499883, 0.5935210157339519], 
             UndirectedEdge[109, 128] -> 
             RGBColor[
              0.84935111239437, 0.7002093895112116, 0.6014984917985637], 
             UndirectedEdge[101, 135] -> 
             RGBColor[
              0.9668510209891087, 0.9747922583481203, 0.9407339777164965], 
             UndirectedEdge[54, 195] -> 
             RGBColor[
              0.6960927240095015, 0.7613395987304794, 0.9711911175673709], 
             UndirectedEdge[122, 192] -> 
             RGBColor[
              0.5290263647394399, 0.6267310067349139, 0.9566758446642745], 
             UndirectedEdge[155, 195] -> 
             RGBColor[
              0.7245926869008862, 0.7840646955291856, 0.9739094694701684], 
             UndirectedEdge[42, 87] -> 
             RGBColor[
              0.23525223782096866`, 0.36459539617618014`, 0.936708638968182], 
             UndirectedEdge[31, 153] -> 
             RGBColor[
              0.6351648262099764, 0.7096697738103037, 0.9673276608073942], 
             UndirectedEdge[64, 199] -> 
             RGBColor[
              0.7451828044257999, 0.7983379873947907, 0.9114554533260232], 
             UndirectedEdge[107, 188] -> 
             RGBColor[
              0.6011669913930474, 0.6870934717340353, 0.9617452141911613], 
             UndirectedEdge[27, 189] -> 
             RGBColor[
              0.46053886513002495`, 0.5703870154941882, 0.951375767418605], 
             UndirectedEdge[14, 176] -> 
             RGBColor[
              0.6776113594576407, 0.7461867199753996, 0.9699075485956137], 
             UndirectedEdge[123, 146] -> 
             RGBColor[
              0.6773114320315736, 0.6958031791434196, 0.6217077430905937], 
             UndirectedEdge[30, 130] -> 
             RGBColor[
              0.7706899818982721, 0.8212383216860148, 0.9776593681549598], 
             UndirectedEdge[72, 143] -> 
             RGBColor[
              0.6928812510223062, 0.7582350983518468, 0.9715106610334587], 
             UndirectedEdge[68, 155] -> 
             RGBColor[
              0.6716744212324314, 0.7410902733204523, 0.9697471389812702], 
             UndirectedEdge[32, 39] -> 
             RGBColor[
              0.7211222607349304, 0.7801819650989841, 0.9542108207017572], 
             UndirectedEdge[184, 194] -> 
             RGBColor[
              0.8398419322742092, 0.8751489825757329, 0.9542300312664833], 
             UndirectedEdge[74, 152] -> 
             RGBColor[
              0.4539898380138191, 0.5637292176208446, 0.9512307270363562], 
             UndirectedEdge[71, 147] -> 
             RGBColor[
              0.8660028146063353, 0.8946202948121418, 0.9116628410179821], 
             UndirectedEdge[39, 173] -> 
             RGBColor[
              0.9637221612391802, 0.9724646277684654, 0.9462930976330739], 
             UndirectedEdge[139, 171] -> 
             RGBColor[
              0.5213488513968751, 0.6178314434063336, 0.9571388145304229], 
             UndirectedEdge[73, 189] -> 
             RGBColor[
              0.3381007754511906, 0.46726763108190755`, 0.9427644603343411], 
             UndirectedEdge[20, 22] -> 
             RGBColor[
              0.9684258329986373, 0.9759726184651127, 0.9383310082583849], 
             UndirectedEdge[17, 168] -> 
             RGBColor[
              0.4922112666515049, 0.5978563495894458, 0.953383877304681], 
             UndirectedEdge[13, 132] -> 
             RGBColor[
              0.587346139514886, 0.6758730815570622, 0.9606571861038639], 
             UndirectedEdge[99, 109] -> 
             RGBColor[
              0.8303413909839278, 0.6853565882207426, 0.5996043808077625], 
             UndirectedEdge[119, 195] -> 
             RGBColor[
              0.4959848052094401, 0.601158122412519, 0.9536151164934603], 
             UndirectedEdge[10, 188] -> 
             RGBColor[
              0.724919119715506, 0.7844951065942698, 0.97374479716181], 
             UndirectedEdge[182, 185] -> 
             RGBColor[
              0.8274312516907298, 0.8076188256502057, 0.6256310960680469], 
             UndirectedEdge[98, 187] -> 
             RGBColor[
              0.8835869980457827, 0.9084995828486444, 0.919872048369009], 
             UndirectedEdge[10, 167] -> 
             RGBColor[
              0.7316861793035648, 0.7899889104204163, 0.974277524881138], 
             UndirectedEdge[113, 187] -> 
             RGBColor[
              0.7436374328663462, 0.7996544814997883, 0.9750824876873514], 
             UndirectedEdge[83, 170] -> 
             RGBColor[
              0.8275192162886169, 0.8659065106788232, 0.9724462886202252], 
             UndirectedEdge[39, 41] -> 
             RGBColor[
              0.8637809626053334, 0.8940509888572165, 0.9667731147965356], 
             UndirectedEdge[138, 145] -> 
             RGBColor[
              0.5737099964319443, 0.661534400882064, 0.9611734239404197], 
             UndirectedEdge[75, 155] -> 
             RGBColor[
              0.8839662612647116, 0.9103147183802653, 0.988794685197067], 
             UndirectedEdge[90, 163] -> 
             RGBColor[
              0.8338344152184889, 0.8707484002872787, 0.9839049388988247], 
             UndirectedEdge[2, 66] -> 
             RGBColor[
              0.769533089447255, 0.7772504495170178, 0.6359589537686497], 
             UndirectedEdge[88, 200] -> 
             RGBColor[
              0.6712292356194376, 0.7428038883859814, 0.9680602066319948], 
             UndirectedEdge[67, 170] -> 
             RGBColor[
              0.8400759773956716, 0.8757159478905734, 0.9736978292177723], 
             UndirectedEdge[124, 136] -> 
             RGBColor[
              0.7949346500100671, 0.8397282574057533, 0.9801953148924882], 
             UndirectedEdge[129, 155] -> 
             RGBColor[
              0.9066964244642092, 0.8237490406938819, 0.6231136452870727], 
             UndirectedEdge[149, 167] -> 
             RGBColor[
              0.5474799182056251, 0.6435078871454007, 0.9575187711276183], 
             UndirectedEdge[172, 173] -> 
             RGBColor[
              0.770513820640931, 0.8199059911443451, 0.9480607410183355], 
             UndirectedEdge[143, 160] -> 
             RGBColor[
              0.8832124951020246, 0.9097136857025762, 0.988722790307575], 
             UndirectedEdge[27, 89] -> 
             RGBColor[
              0.6066906742238831, 0.691427992981369, 0.9622825142666005], 
             UndirectedEdge[172, 191] -> 
             RGBColor[
              0.4287651511932876, 0.5404708182967464, 0.9495065581706226], 
             UndirectedEdge[11, 182] -> 
             RGBColor[
              0.7571013964700424, 0.8101726321969094, 0.9764244497514744], 
             UndirectedEdge[159, 164] -> 
             RGBColor[
              0.484559145739251, 0.5904029775157028, 0.9531243761478552], 
             UndirectedEdge[151, 156] -> 
             RGBColor[
              0.9733095754644505, 0.9191608299860863, 0.4673970839892819], 
             UndirectedEdge[94, 196] -> 
             RGBColor[
              0.8143614347941701, 0.6630870861394591, 0.5960991410511405], 
             UndirectedEdge[69, 139] -> 
             RGBColor[
              0.6136219195145717, 0.6905472161727108, 0.9661681905688821], 
             UndirectedEdge[53, 127] -> 
             RGBColor[
              0.9137564102126212, 0.9318757986730339, 0.9073636139610699], 
             UndirectedEdge[171, 196] -> 
             RGBColor[
              0.7933911917796106, 0.6467049729167353, 0.594009023205512], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.9088250555522916, 0.9252885517705942, 0.7363074621982428], 
             UndirectedEdge[74, 162] -> 
             RGBColor[
              0.796108058115454, 0.8375916122590198, 0.81222522996958], 
             UndirectedEdge[34, 153] -> 
             RGBColor[
              0.7059190687262261, 0.7689471745922447, 0.9723904239965737], 
             UndirectedEdge[98, 109] -> 
             RGBColor[
              0.9328417295929456, 0.764946069148124, 0.5406613525678003], 
             UndirectedEdge[77, 183] -> 
             RGBColor[
              0.9646887297103468, 0.9731854929516508, 0.9446569493328205], 
             UndirectedEdge[2, 78] -> 
             RGBColor[
              0.6217217089544468, 0.7033918903216332, 0.9636292000694754], 
             UndirectedEdge[113, 193] -> 
             RGBColor[
              0.8475812400062792, 0.8709337788391165, 0.6893174905738508], 
             UndirectedEdge[100, 120] -> 
             RGBColor[
              0.7916924450145058, 0.8378615742058289, 0.9796953859443281], 
             UndirectedEdge[1, 35] -> 
             RGBColor[
              0.869852125372916, 0.41635624883117595`, 0.41859227542749433`], 
             UndirectedEdge[154, 176] -> 
             RGBColor[
              0.4518442851840011, 0.5644880757925868, 0.9503708663591542], 
             UndirectedEdge[13, 31] -> 
             RGBColor[
              0.4764915348986416, 0.5840404003216196, 0.9524375755177064], 
             UndirectedEdge[92, 196] -> 
             RGBColor[
              0.8442615580183752, 0.6864452896515613, 0.5990793059015913], 
             UndirectedEdge[66, 124] -> 
             RGBColor[
              0.8748087344927699, 0.8605136846154702, 0.6457537138355027], 
             UndirectedEdge[141, 167] -> 
             RGBColor[
              0.6060422384378834, 0.6910514169124098, 0.9621290114971491], 
             UndirectedEdge[76, 158] -> 
             RGBColor[
              0.7093757305216124, 0.771975074493584, 0.9724074574586903], 
             UndirectedEdge[101, 134] -> 
             RGBColor[
              0.9844490417006685, 0.9878372933488968, 0.9073831538173243], 
             UndirectedEdge[139, 141] -> 
             RGBColor[
              0.4727558935646754, 0.5794720452110436, 0.9525677811206451], 
             UndirectedEdge[88, 93] -> 
             RGBColor[
              0.6032050283091913, 0.6887480419150778, 0.9619056559227753], 
             UndirectedEdge[17, 130] -> 
             RGBColor[
              0.6128008562807954, 0.6961808386502204, 0.9629055189757507], 
             UndirectedEdge[32, 117] -> 
             RGBColor[
              0.7250902319772421, 0.7831412715545435, 0.9474940804011696], 
             UndirectedEdge[32, 103] -> 
             RGBColor[
              0.6596037379112848, 0.731705276222347, 0.9683311393887002], 
             UndirectedEdge[148, 150] -> 
             RGBColor[
              0.6935403970680433, 0.7605182963825803, 0.9700892833423935], 
             UndirectedEdge[77, 156] -> 
             RGBColor[
              0.9702653708347622, 0.9750329812667912, 0.8154865501642821], 
             UndirectedEdge[76, 89] -> 
             RGBColor[
              0.6084467651625771, 0.692853666716396, 0.9624207601780677], 
             UndirectedEdge[42, 51] -> 
             RGBColor[
              0.5899615790529087, 0.5048412192983932, 0.5842307586487552], 
             UndirectedEdge[82, 124] -> 
             RGBColor[
              0.8664158993512584, 0.8963126154134273, 0.9773213848523088], 
             UndirectedEdge[15, 114] -> 
             RGBColor[
              0.4775168243207588, 0.58567899894747, 0.9522955283822447], 
             UndirectedEdge[41, 173] -> 
             RGBColor[
              0.8694476715452473, 0.89827721110622, 0.9571808546756568], 
             UndirectedEdge[41, 133] -> 
             RGBColor[
              0.5529635853273264, 0.6428380022047117, 0.9601591395537721], 
             UndirectedEdge[27, 147] -> 
             RGBColor[
              0.7746298324568901, 0.8219963868635978, 0.9034052357268998], 
             UndirectedEdge[19, 88] -> 
             RGBColor[
              0.8062405001930313, 0.839512597639577, 0.6870846184838326], 
             UndirectedEdge[127, 172] -> 
             RGBColor[
              0.7803702035252201, 0.8264411964537364, 0.8948491355705015], 
             UndirectedEdge[69, 174] -> 
             RGBColor[
              0.6101289972969723, 0.6875218225072014, 0.9659456246538466], 
             UndirectedEdge[117, 121] -> 
             RGBColor[
              0.7993958696074017, 0.8434659356135352, 0.9533436923859349], 
             UndirectedEdge[69, 196] -> 
             RGBColor[
              0.8856642598973072, 0.7194207456831125, 0.6030383992439712], 
             UndirectedEdge[92, 195] -> 
             RGBColor[
              0.6869833811839592, 0.7541139906282213, 0.9703121936401253], 
             UndirectedEdge[144, 158] -> 
             RGBColor[
              0.607731452177091, 0.686961608304112, 0.9650947642956998], 
             UndirectedEdge[81, 168] -> 
             RGBColor[
              0.416700151732065, 0.5353464602968826, 0.947772743088259], 
             UndirectedEdge[87, 188] -> 
             RGBColor[
              0.380556677889362, 0.4885390683372187, 0.9468759945136214], 
             UndirectedEdge[74, 88] -> 
             RGBColor[
              0.610650036416634, 0.6947922348904928, 0.9624917542329565], 
             UndirectedEdge[74, 140] -> 
             RGBColor[
              0.7635138466880872, 0.721164792388743, 0.6117946344227261], 
             UndirectedEdge[152, 178] -> 
             RGBColor[
              0.6217326304990989, 0.6963714771193678, 0.9672378055653044], 
             UndirectedEdge[63, 153] -> 
             RGBColor[0.893831519816026, 0.7817160709871, 0.6148304151143191],
              UndirectedEdge[154, 158] -> 
             RGBColor[
              0.6282741695117857, 0.7047546775524299, 0.966403728079055], 
             UndirectedEdge[23, 90] -> 
             RGBColor[
              0.5390279960853721, 0.6307405830197006, 0.9592732575936791], 
             UndirectedEdge[51, 131] -> 
             RGBColor[
              0.9349189771948447, 0.785801596733547, 0.5723790873944494], 
             UndirectedEdge[21, 83] -> 
             RGBColor[
              0.5110527118836732, 0.6091769310806292, 0.9563712337682728], 
             UndirectedEdge[57, 178] -> 
             RGBColor[
              0.6400201261362128, 0.7122111866839793, 0.9684030686163039], 
             UndirectedEdge[17, 197] -> 
             RGBColor[
              0.7775233166507074, 0.8228070192673878, 0.8356236493266771], 
             UndirectedEdge[64, 156] -> 
             RGBColor[
              0.7490999046720422, 0.7993768106671111, 0.8043065188088032], 
             UndirectedEdge[40, 123] -> 
             RGBColor[
              0.6941267989374473, 0.7521618389918372, 0.7179434837758971], 
             UndirectedEdge[26, 99] -> 
             RGBColor[
              0.7623619021049459, 0.8142821791802196, 0.9769487677909414], 
             UndirectedEdge[114, 167] -> 
             RGBColor[
              0.5676795326897481, 0.6599068441658742, 0.9591089587734345], 
             UndirectedEdge[75, 168] -> 
             RGBColor[
              0.6509712036235283, 0.7236081939618112, 0.9682207852482692], 
             UndirectedEdge[55, 111] -> 
             RGBColor[
              0.7783935179986354, 0.827535459982321, 0.9783531260931102], 
             UndirectedEdge[67, 122] -> 
             RGBColor[
              0.5649661130591267, 0.6548074112744573, 0.9602579829007374], 
             UndirectedEdge[127, 129] -> 
             RGBColor[
              0.9559926116896913, 0.8608637064318827, 0.5435430773952363], 
             UndirectedEdge[96, 198] -> 
             RGBColor[
              0.3718325644685624, 0.4900698353208256, 0.9454051555360614], 
             UndirectedEdge[154, 181] -> 
             RGBColor[
              0.5736876233015391, 0.661836319829706, 0.961036010044654], 
             UndirectedEdge[9, 91] -> 
             RGBColor[
              0.48464527209744845`, 0.58851071684934, 0.9537546446197376], 
             UndirectedEdge[39, 152] -> 
             RGBColor[
              0.6342525496088324, 0.7057780094261974, 0.9484439563145586], 
             UndirectedEdge[54, 65] -> 
             RGBColor[
              0.8290337159310732, 0.8665129978354427, 0.9835551699842826], 
             UndirectedEdge[116, 128] -> 
             RGBColor[
              0.799337591550439, 0.8431701312460846, 0.9806335585739597], 
             UndirectedEdge[74, 95] -> 
             RGBColor[
              0.7836541449052208, 0.7969289701156914, 0.6492767891143234], 
             UndirectedEdge[152, 200] -> 
             RGBColor[
              0.5145690372166227, 0.6117408711163332, 0.9567991794353946], 
             UndirectedEdge[140, 191] -> 
             RGBColor[
              0.6076945977753712, 0.5880046335955005, 0.6008614207323367], 
             UndirectedEdge[109, 193] -> 
             RGBColor[
              0.9331273857948303, 0.7557313937689325, 0.31372398378167543`], 
             UndirectedEdge[80, 137] -> 
             RGBColor[
              0.8594399339805285, 0.8907580907532766, 0.9864553422057909], 
             UndirectedEdge[118, 199] -> 
             RGBColor[
              0.8130536715927439, 0.8534386149086381, 0.9167984966085834], 
             UndirectedEdge[45, 64] -> 
             RGBColor[
              0.5087406774494831, 0.6120576263166566, 0.9544690761887803], 
             UndirectedEdge[125, 170] -> 
             RGBColor[
              0.8966480334142457, 0.9201175421323686, 0.9792814519622], 
             UndirectedEdge[70, 145] -> 
             RGBColor[
              0.8709821749960964, 0.8982246338791922, 0.8992099489212575], 
             UndirectedEdge[17, 142] -> 
             RGBColor[
              0.5764270696910421, 0.6670084887755758, 0.9597975969294602], 
             UndirectedEdge[95, 180] -> 
             RGBColor[
              0.8696423668063014, 0.8647903452587988, 0.6573777754351086], 
             UndirectedEdge[41, 121] -> 
             RGBColor[
              0.7011534086711572, 0.7663192124957303, 0.9709481897291055], 
             UndirectedEdge[5, 10] -> 
             RGBColor[
              0.8858496997036067, 0.777245040238414, 0.6144429196213628], 
             UndirectedEdge[167, 194] -> 
             RGBColor[
              0.7825546725669678, 0.8296812971720997, 0.9490086409890469], 
             UndirectedEdge[78, 100] -> 
             RGBColor[
              0.7850716109180833, 0.8326893282895008, 0.9790354830768091], 
             UndirectedEdge[106, 157] -> 
             RGBColor[
              0.5691324915298362, 0.6543376353707949, 0.9622527773128989], 
             UndirectedEdge[24, 115] -> 
             RGBColor[
              0.4650507638848177, 0.5741957885958344, 0.9516906727589153], 
             UndirectedEdge[74, 164] -> 
             RGBColor[
              0.48817139367942436`, 0.5933355631234507, 0.9534087455378057], 
             UndirectedEdge[46, 135] -> 
             RGBColor[
              0.9625105646784053, 0.9455066709050561, 0.6649565672004616], 
             UndirectedEdge[126, 190] -> 
             RGBColor[
              0.7621503412046404, 0.8143664459606448, 0.9770839634477313], 
             UndirectedEdge[21, 177] -> 
             RGBColor[
              0.6408298447882415, 0.6735297689422577, 0.6335957267759134], 
             UndirectedEdge[24, 133] -> 
             RGBColor[
              0.35081426407846916`, 0.47827941593233814`, 0.9435745525875747],
              UndirectedEdge[30, 188] -> 
             RGBColor[
              0.7289339970511728, 0.7876964608007884, 0.9741277397462091], 
             UndirectedEdge[80, 98] -> 
             RGBColor[
              0.9122023988034282, 0.9309929757793014, 0.9226873243700899], 
             UndirectedEdge[12, 102] -> 
             RGBColor[
              0.5169043690898418, 0.6131649551747613, 0.9571144854505652], 
             UndirectedEdge[51, 168] -> 
             RGBColor[
              0.6564324143391107, 0.5640022632838837, 0.5884081009318753], 
             UndirectedEdge[42, 189] -> 
             RGBColor[
              0.32570760986987524`, 0.4549459465720807, 0.9420328993458107], 
             UndirectedEdge[52, 187] -> 
             RGBColor[
              0.6278613092268439, 0.7066577269153652, 0.9652875258741007], 
             UndirectedEdge[10, 89] -> 
             RGBColor[
              0.7598966229689088, 0.8127415661401325, 0.9766008098738128], 
             UndirectedEdge[148, 193] -> 
             RGBColor[
              0.8342746482094172, 0.8605385681935647, 0.6879912138607099], 
             UndirectedEdge[4, 92] -> 
             RGBColor[
              0.6058557889584774, 0.6867060675977696, 0.9643523898075415], 
             UndirectedEdge[28, 97] -> 
             RGBColor[
              0.5920962593829082, 0.6783440864601948, 0.9619706482011888], 
             UndirectedEdge[60, 169] -> 
             RGBColor[
              0.8665448352544083, 0.8937459887369046, 0.8528719713307817], 
             UndirectedEdge[44, 198] -> 
             RGBColor[
              0.3290899431655462, 0.45411832562610344`, 0.9423859891565196], 
             UndirectedEdge[13, 64] -> 
             RGBColor[
              0.5354359257653459, 0.6337300315067058, 0.9565706239241216], 
             UndirectedEdge[42, 106] -> 
             RGBColor[
              0.30003034559821096`, 0.4326812946193137, 0.9403976563754733], 
             UndirectedEdge[43, 90] -> 
             RGBColor[
              0.6082518236460323, 0.6907230793794852, 0.9636832490700773], 
             UndirectedEdge[166, 192] -> 
             RGBColor[
              0.7139950580932382, 0.7764976330366442, 0.9721280127937098], 
             UndirectedEdge[5, 89] -> 
             RGBColor[
              0.7780944390202273, 0.6926805298644443, 0.6038051241987983], 
             UndirectedEdge[114, 184] -> 
             RGBColor[
              0.6249667923969897, 0.7053745295695075, 0.9643303490508708], 
             UndirectedEdge[58, 192] -> 
             RGBColor[
              0.7687525937891309, 0.8197348701588869, 0.9774636002439465], 
             UndirectedEdge[17, 157] -> 
             RGBColor[
              0.694842577296928, 0.7603516463554365, 0.9710616559589864], 
             UndirectedEdge[38, 111] -> 
             RGBColor[
              0.7502576090184019, 0.8047580813240589, 0.9760939833900225], 
             UndirectedEdge[3, 191] -> 
             RGBColor[
              0.35402838306086487`, 0.47895027246119193`, 0.9438567225839752],
              UndirectedEdge[40, 195] -> 
             RGBColor[
              0.7758840636307199, 0.820115152665631, 0.7239434097813312], 
             UndirectedEdge[113, 136] -> 
             RGBColor[
              0.7554810416463603, 0.8089067986934961, 0.9762629479257264], 
             UndirectedEdge[53, 141] -> 
             RGBColor[
              0.7273875931992476, 0.7867107131039528, 0.9736955899170061], 
             UndirectedEdge[142, 176] -> 
             RGBColor[
              0.5470451383207233, 0.6431549132482268, 0.9574845436624277], 
             UndirectedEdge[99, 128] -> 
             RGBColor[
              0.8012541931762374, 0.8446673950028702, 0.9808245875123588], 
             UndirectedEdge[41, 151] -> 
             RGBColor[
              0.8607585497048882, 0.8336543641557125, 0.628952849672791], 
             UndirectedEdge[5, 157] -> 
             RGBColor[
              0.8669146416300566, 0.7621467389090244, 0.6126368768787818], 
             UndirectedEdge[39, 74] -> 
             RGBColor[
              0.7777927407042529, 0.8261896137141092, 0.9586721284757505], 
             UndirectedEdge[86, 171] -> 
             RGBColor[
              0.8541187984982992, 0.8841105595259442, 0.8548930377777664], 
             UndirectedEdge[162, 180] -> 
             RGBColor[
              0.8820962800165346, 0.9054529874021271, 0.8203262162903653], 
             UndirectedEdge[27, 127] -> 
             RGBColor[
              0.7751708110549546, 0.8222200954164133, 0.89443982034924], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.6966382583177144, 0.7626536100336001, 0.9705927405537418], 
             UndirectedEdge[155, 191] -> 
             RGBColor[
              0.5882003963902578, 0.6666762167412603, 0.9645056171084848], 
             UndirectedEdge[46, 105] -> 
             RGBColor[
              0.7423653926668481, 0.7707961366522584, 0.6570034223663889], 
             UndirectedEdge[30, 168] -> 
             RGBColor[
              0.6501003922689816, 0.7229138326252402, 0.9681377264838901], 
             UndirectedEdge[161, 180] -> 
             RGBColor[
              0.5049145050114772, 0.5948940872005494, 0.9573291284255319], 
             UndirectedEdge[125, 192] -> 
             RGBColor[
              0.7530918485379547, 0.8072474169952043, 0.975969864381377], 
             UndirectedEdge[33, 140] -> 
             RGBColor[
              0.7345544047816069, 0.6976542128410717, 0.6095148410739168], 
             UndirectedEdge[12, 58] -> 
             RGBColor[
              0.5916203328841141, 0.6719938680171298, 0.9644393424915336], 
             UndirectedEdge[127, 155] -> 
             RGBColor[
              0.9398054487221903, 0.9526465948982503, 0.9098481945083639], 
             UndirectedEdge[78, 120] -> 
             RGBColor[
              0.6743623067439743, 0.7455362264625327, 0.968177790528334], 
             UndirectedEdge[45, 183] -> 
             RGBColor[
              0.7486726560835506, 0.8017098311901238, 0.933882297020616], 
             UndirectedEdge[98, 136] -> 
             RGBColor[
              0.8954306068257968, 0.9177519000423522, 0.921052508607384], 
             UndirectedEdge[59, 92] -> 
             RGBColor[
              0.7923985614871274, 0.837747045776646, 0.9799425412896163], 
             UndirectedEdge[81, 89] -> 
             RGBColor[
              0.5305112597676589, 0.6283755480182934, 0.9566187690625811], 
             UndirectedEdge[161, 200] -> 
             RGBColor[
              0.47950548231320034`, 0.5750443655529307, 0.9547965945037851], 
             UndirectedEdge[125, 198] -> 
             RGBColor[
              0.5482717411847255, 0.6304047327255178, 0.9613688247342366], 
             UndirectedEdge[159, 173] -> 
             RGBColor[
              0.7798472017039935, 0.8274832503553647, 0.948795498964921], 
             UndirectedEdge[54, 151] -> 
             RGBColor[
              0.8927599811061573, 0.8587634458396455, 0.6321134430505343], 
             UndirectedEdge[61, 192] -> 
             RGBColor[
              0.7770294031386035, 0.8263345732661516, 0.978253049708494], 
             UndirectedEdge[59, 194] -> 
             RGBColor[
              0.8694476715452473, 0.89827721110622, 0.9571808546756568], 
             UndirectedEdge[80, 82] -> 
             RGBColor[
              0.8918691059865854, 0.9163356782621634, 0.9798214828956613], 
             UndirectedEdge[157, 168] -> 
             RGBColor[
              0.6271504568597648, 0.7046141770893319, 0.9659487411569098], 
             UndirectedEdge[122, 170] -> 
             RGBColor[
              0.6725825496157309, 0.7396011318720783, 0.9599874322450974], 
             UndirectedEdge[26, 67] -> 
             RGBColor[
              0.7374694366415819, 0.7948359959704951, 0.9744677194668687], 
             UndirectedEdge[160, 181] -> 
             RGBColor[
              0.8045097283608376, 0.8475657083458479, 0.9810548456301289], 
             UndirectedEdge[42, 168] -> 
             RGBColor[
              0.3580483109281395, 0.4829578363378507, 0.9440936202194842], 
             UndirectedEdge[61, 67] -> 
             RGBColor[
              0.8129691514582903, 0.854410977805695, 0.981835187944957], 
             UndirectedEdge[9, 39] -> 
             RGBColor[
              0.8067232538458129, 0.8494770731196313, 0.9610861356219906], 
             UndirectedEdge[118, 171] -> 
             RGBColor[
              0.6764414684163862, 0.7471141291974337, 0.9684167145292908], 
             UndirectedEdge[97, 134] -> 
             RGBColor[
              0.7186481279748875, 0.7771960828613649, 0.9268852609142748], 
             UndirectedEdge[79, 190] -> 
             RGBColor[
              0.3998559597684265, 0.5057795307807124, 0.9482521717745671], 
             UndirectedEdge[47, 50] -> 
             RGBColor[
              0.9197235232378638, 0.9382112514664703, 0.9708711244807564], 
             UndirectedEdge[36, 145] -> 
             RGBColor[
              0.82627005904673, 0.7229870178442226, 0.607174531936164], 
             UndirectedEdge[170, 179] -> 
             RGBColor[
              0.6905816349055931, 0.7551910348898261, 0.9611343180438012], 
             UndirectedEdge[26, 198] -> 
             RGBColor[
              0.496709580968666, 0.5899169071612653, 0.9562845415832655], 
             UndirectedEdge[5, 141] -> 
             RGBColor[
              0.7602057588379253, 0.6783075467304075, 0.6022944062373738], 
             UndirectedEdge[18, 39] -> 
             RGBColor[
              0.870999797138515, 0.8996903972597126, 0.9674926207589589], 
             UndirectedEdge[19, 180] -> 
             RGBColor[
              0.8791087147867174, 0.896722559800948, 0.6941527497692095], 
             UndirectedEdge[170, 198] -> 
             RGBColor[
              0.5993161217227556, 0.6707968590813436, 0.9555146513341689], 
             UndirectedEdge[12, 172] -> 
             RGBColor[
              0.4389771467462139, 0.5512042731007866, 0.9500881162100681], 
             UndirectedEdge[47, 101] -> 
             RGBColor[
              0.9718941934207642, 0.978553448090212, 0.9321972022597321], 
             UndirectedEdge[53, 54] -> 
             RGBColor[
              0.8359602600957543, 0.8720360361363269, 0.9842158299501088], 
             UndirectedEdge[57, 121] -> 
             RGBColor[
              0.48991249131177, 0.5938859426293229, 0.9537842942981278], 
             UndirectedEdge[19, 121] -> 
             RGBColor[
              0.8107556505464741, 0.8431782001017072, 0.6874400676591963], 
             UndirectedEdge[170, 192] -> 
             RGBColor[
              0.8041362290759848, 0.8476395433510301, 0.9701156909813093], 
             UndirectedEdge[7, 137] -> 
             RGBColor[
              0.7196638421062375, 0.7801268356435201, 0.9734482522064243], 
             UndirectedEdge[111, 115] -> 
             RGBColor[
              0.7375516910819301, 0.7944428447481511, 0.9750937269867525], 
             UndirectedEdge[140, 162] -> 
             RGBColor[
              0.9620918756943018, 0.8746155827390065, 0.462560965194758], 
             UndirectedEdge[8, 79] -> 
             RGBColor[
              0.5859350348567725, 0.6313615748145178, 0.6551318926292404], 
             UndirectedEdge[2, 52] -> 
             RGBColor[
              0.5257478583036477, 0.6258648218988336, 0.9558079437649762], 
             UndirectedEdge[18, 152] -> 
             RGBColor[
              0.5471968944480812, 0.637230001166448, 0.9600512193195649], 
             UndirectedEdge[4, 195] -> 
             RGBColor[
              0.47754852007958243`, 0.58518953886767, 0.9524403727075527], 
             UndirectedEdge[81, 107] -> 
             RGBColor[
              0.5145143921285795, 0.6155384235320287, 0.9552569815144969], 
             UndirectedEdge[108, 175] -> 
             RGBColor[
              0.5921253615086429, 0.6797530692730913, 0.9610334239660794], 
             UndirectedEdge[49, 191] -> 
             RGBColor[
              0.4810783767392068, 0.5824216513987653, 0.9539799635867332], 
             UndirectedEdge[77, 192] -> 
             RGBColor[
              0.8032511307193465, 0.8469794384458648, 0.9716139316284751], 
             UndirectedEdge[21, 166] -> 
             RGBColor[
              0.5410847385645856, 0.6326381785756146, 0.9593645455225803], 
             UndirectedEdge[8, 192] -> 
             RGBColor[
              0.8201883322692889, 0.8391404080085498, 0.6714091089077545], 
             UndirectedEdge[108, 165] -> 
             RGBColor[
              0.7308802136540802, 0.7892646817681912, 0.974294540784174], 
             UndirectedEdge[29, 194] -> 
             RGBColor[
              0.7256634826013929, 0.7834944662391449, 0.9445299581156614], 
             UndirectedEdge[106, 131] -> 
             RGBColor[
              0.644987743740147, 0.7136416720544674, 0.9285459851211675], 
             UndirectedEdge[12, 68] -> 
             RGBColor[
              0.3795775516789073, 0.5029680157055034, 0.9454155517290004], 
             UndirectedEdge[71, 168] -> 
             RGBColor[
              0.5842525483377343, 0.6710228132085021, 0.9616940935833607], 
             UndirectedEdge[49, 146] -> 
             RGBColor[
              0.8178632516696172, 0.8109691611057821, 0.632691308504308], 
             UndirectedEdge[112, 134] -> 
             RGBColor[
              0.9633347714264713, 0.9720961730486493, 0.9433868824051554], 
             UndirectedEdge[84, 126] -> 
             RGBColor[
              0.951897753120144, 0.962666441419831, 0.9274057004488117], 
             UndirectedEdge[10, 62] -> 
             RGBColor[
              0.8446942235751307, 0.8790002615376585, 0.985048883183673], 
             UndirectedEdge[34, 182] -> 
             RGBColor[
              0.615031432547867, 0.6974225759280854, 0.9634702456703325], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.4643154212809277, 0.5720343018399501, 0.9520592370848313], 
             UndirectedEdge[67, 79] -> 
             RGBColor[
              0.4622664951068642, 0.5550669895593769, 0.9541090253584351], 
             UndirectedEdge[33, 96] -> 
             RGBColor[
              0.5161682223700842, 0.6180876418902861, 0.9550537997329235], 
             UndirectedEdge[12, 140] -> 
             RGBColor[
              0.6179065933282974, 0.5987380883995407, 0.6014429787717823], 
             UndirectedEdge[26, 124] -> 
             RGBColor[
              0.7643662838982341, 0.8158480174710021, 0.9771485458360836], 
             UndirectedEdge[13, 70] -> 
             RGBColor[
              0.7784268133858447, 0.8247695760978778, 0.8907712291022236], 
             UndirectedEdge[53, 146] -> 
             RGBColor[
              0.898936232811099, 0.8744529302230607, 0.6407323814787657], 
             UndirectedEdge[87, 147] -> 
             RGBColor[
              0.5834733393757718, 0.6473539217653101, 0.8908547286859236], 
             UndirectedEdge[93, 200] -> 
             RGBColor[
              0.6506642202046006, 0.72610828242883, 0.9664412532864053], 
             UndirectedEdge[9, 117] -> 
             RGBColor[
              0.8106912250881246, 0.8524363795751908, 0.954369395321403], 
             UndirectedEdge[99, 116] -> 
             RGBColor[
              0.7803278701399968, 0.8283173299556157, 0.9787394475831583], 
             UndirectedEdge[71, 155] -> 
             RGBColor[
              0.8172476059789175, 0.8577293376269562, 0.9822679935321587], 
             UndirectedEdge[54, 140] -> 
             RGBColor[
              0.8815034999904368, 0.8141352492157834, 0.6230562141212546], 
             UndirectedEdge[76, 154] -> 
             RGBColor[
              0.48365060702979823`, 0.5903098807254752, 0.9528747765252513], 
             UndirectedEdge[33, 128] -> 
             RGBColor[
              0.6799375299414794, 0.7483199295533765, 0.9698090055015449], 
             UndirectedEdge[109, 148] -> 
             RGBColor[
              0.7795855726166472, 0.6457057571537161, 0.5945455151730019], 
             UndirectedEdge[27, 142] -> 
             RGBColor[
              0.5770953692278264, 0.6675510444460883, 0.9598502079170577], 
             UndirectedEdge[49, 69] -> 
             RGBColor[
              0.787180638007662, 0.8343021149483414, 0.9792549263907854], 
             UndirectedEdge[60, 90] -> 
             RGBColor[
              0.8823257370774569, 0.9060741491803663, 0.854444864143591], 
             UndirectedEdge[40, 191] -> 
             RGBColor[
              0.6394917731200915, 0.7027266738777057, 0.7145395574196476], 
             UndirectedEdge[58, 166] -> 
             RGBColor[
              0.8221676076826754, 0.8614630849816654, 0.9827875096371699], 
             UndirectedEdge[38, 60] -> 
             RGBColor[
              0.7926921153837735, 0.8352542899504296, 0.8460562041660267], 
             UndirectedEdge[54, 119] -> 
             RGBColor[
              0.6334014169138773, 0.7099002592448767, 0.9664060575206946], 
             UndirectedEdge[3, 146] -> 
             RGBColor[
              0.6908132579912754, 0.7074977821682087, 0.6225680675015499], 
             UndirectedEdge[115, 163] -> 
             RGBColor[
              0.7314948755883337, 0.7896133044814341, 0.9745160225179903], 
             UndirectedEdge[137, 170] -> 
             RGBColor[
              0.9147063166451537, 0.9345167270016544, 0.9810038671375837], 
             UndirectedEdge[58, 99] -> 
             RGBColor[
              0.8295848075721817, 0.8672574579081547, 0.983526786804482], 
             UndirectedEdge[40, 64] -> 
             RGBColor[
              0.7483416499349674, 0.7977549804558217, 0.7217751700840158], 
             UndirectedEdge[77, 96] -> 
             RGBColor[
              0.7193237583414442, 0.779122539822511, 0.9648160234111904], 
             UndirectedEdge[141, 195] -> 
             RGBColor[
              0.5875200571129948, 0.6760142756981053, 0.9606708775342682], 
             UndirectedEdge[138, 182] -> 
             RGBColor[
              0.5489402899546683, 0.6421841179252743, 0.9587046110848324], 
             UndirectedEdge[33, 102] -> 
             RGBColor[
              0.6335521805431514, 0.7120810796162924, 0.9651863477526998], 
             UndirectedEdge[137, 198] -> 
             RGBColor[
              0.5663300244156334, 0.6448039175948037, 0.9630912399096203], 
             UndirectedEdge[69, 171] -> 
             RGBColor[
              0.8058229857030215, 0.8488656586550463, 0.9811130213864145], 
             UndirectedEdge[20, 46] -> 
             RGBColor[
              0.9731024783412046, 0.9534061027721048, 0.6470272201828606], 
             UndirectedEdge[76, 157] -> 
             RGBColor[
              0.6972669677724064, 0.7623198757609762, 0.9712525128580509], 
             UndirectedEdge[10, 168] -> 
             RGBColor[
              0.6460855149333149, 0.7197124784187217, 0.9677547838994909], 
             UndirectedEdge[82, 100] -> 
             RGBColor[
              0.92449015626938, 0.9423468182828427, 0.9829329077927895], 
             UndirectedEdge[9, 57] -> 
             RGBColor[
              0.501207846792493, 0.6028563865909785, 0.9548099972335959], 
             UndirectedEdge[27, 71] -> 
             RGBColor[
              0.6526129683116819, 0.7273028381451192, 0.9668596193730348], 
             UndirectedEdge[122, 125] -> 
             RGBColor[
              0.6215381690777009, 0.6992090055162525, 0.9658416056451651], 
             UndirectedEdge[5, 147] -> 
             RGBColor[
              0.9460335972532344, 0.8232489237466731, 0.5449278456590976], 
             UndirectedEdge[5, 71] -> 
             RGBColor[
              0.8240167331080261, 0.7285553750281946, 0.6083822293052326], 
             UndirectedEdge[61, 84] -> 
             RGBColor[
              0.9403060280353561, 0.9534235144862165, 0.9263000713621694], 
             UndirectedEdge[62, 149] -> 
             RGBColor[
              0.6604879624771911, 0.7325192382626431, 0.9682901294301534], 
             UndirectedEdge[36, 138] -> 
             RGBColor[
              0.6475887656410386, 0.5780283576287497, 0.5923929655357786], 
             UndirectedEdge[33, 162] -> 
             RGBColor[
              0.7671486162089738, 0.8140810327113485, 0.8099454366207708], 
             UndirectedEdge[63, 145] -> 
             RGBColor[
              0.8277135901149428, 0.7295417552797303, 0.6083790496436652], 
             UndirectedEdge[93, 173] -> 
             RGBColor[
              0.7760144415367242, 0.8243716429876976, 0.9484937700446905], 
             UndirectedEdge[23, 55] -> 
             RGBColor[
              0.4775302833719223, 0.5826981024480258, 0.9531437403192025], 
             UndirectedEdge[23, 165] -> 
             RGBColor[
              0.5928981530887343, 0.6732877287961625, 0.9645195673282432], 
             UndirectedEdge[54, 64] -> 
             RGBColor[
              0.668550310313749, 0.7389794265206703, 0.9690228778700556], 
             UndirectedEdge[72, 158] -> 
             RGBColor[
              0.6687650304913659, 0.7390054787178424, 0.9692104343904135], 
             UndirectedEdge[73, 149] -> 
             RGBColor[
              0.40780158413048845`, 0.5263920956680426, 0.9475502488513816], 
             UndirectedEdge[10, 197] -> 
             RGBColor[
              0.9313975649325175, 0.9446631480966636, 0.849994555921487], 
             UndirectedEdge[37, 135] -> 
             RGBColor[
              0.9512230039874187, 0.9631427767555933, 0.9674509105579928], 
             UndirectedEdge[58, 96] -> 
             RGBColor[
              0.6848252214112287, 0.7518779715355333, 0.9706656920266619], 
             UndirectedEdge[112, 156] -> 
             RGBColor[
              0.9683036518313994, 0.9735699344461033, 0.8188072287387165], 
             UndirectedEdge[2, 187] -> 
             RGBColor[
              0.677815396184538, 0.7472127051135933, 0.9692200945872602], 
             UndirectedEdge[43, 169] -> 
             RGBColor[
              0.5924709218229836, 0.6783949189360234, 0.9621103562572679], 
             UndirectedEdge[44, 96] -> 
             RGBColor[
              0.4499826781408731, 0.5631041112724362, 0.9501891205863754], 
             UndirectedEdge[88, 161] -> 
             RGBColor[
              0.4320462904177911, 0.5376841250391785, 0.9502609971401551], 
             UndirectedEdge[129, 146] -> 
             RGBColor[
              0.9411724342881693, 0.8034408379819096, 0.2769118449129321], 
             UndirectedEdge[23, 111] -> 
             RGBColor[
              0.6093464501811977, 0.6864031544205622, 0.9660884205884904], 
             UndirectedEdge[174, 196] -> 
             RGBColor[
              0.5976972033735615, 0.4853611367688905, 0.578841626472944], 
             UndirectedEdge[66, 100] -> 
             RGBColor[
              0.9328829914108915, 0.9065478874848856, 0.6513652367759835], 
             UndirectedEdge[10, 73] -> 
             RGBColor[
              0.5920078452284281, 0.672873118943058, 0.9643090026049012], 
             UndirectedEdge[147, 188] -> 
             RGBColor[
              0.7851030172651339, 0.8304989901025289, 0.9042297231995449], 
             UndirectedEdge[62, 189] -> 
             RGBColor[
              0.5907871537978933, 0.673394773676508, 0.963504340913113], 
             UndirectedEdge[42, 89] -> 
             RGBColor[
              0.4718594189637334, 0.5759869240592616, 0.9529396461938062], 
             UndirectedEdge[119, 140] -> 
             RGBColor[
              0.6813955811903754, 0.653953772897823, 0.605480213047344], 
             UndirectedEdge[140, 151] -> 
             RGBColor[
              0.9407541453826553, 0.8028169594925918, 0.27118759857718366`], 
             UndirectedEdge[1, 86] -> 
             RGBColor[
              0.9848030277650108, 0.9864429898283735, 0.8325216282450301], 
             UndirectedEdge[76, 181] -> 
             RGBColor[
              0.6547891843113657, 0.7290567167708601, 0.9670397394242894], 
             UndirectedEdge[122, 166] -> 
             RGBColor[
              0.5824413786329843, 0.6684592215576923, 0.9619997540574978], 
             UndirectedEdge[10, 189] -> 
             RGBColor[
              0.6137448138750508, 0.6917005886529516, 0.9656940630258173], 
             UndirectedEdge[102, 162] -> 
             RGBColor[
              0.8610896514558462, 0.8890424495142272, 0.8182324718735409], 
             UndirectedEdge[156, 183] -> 
             RGBColor[
              0.9890318833061098, 0.9890290155405782, 0.7837197396406389], 
             UndirectedEdge[31, 199] -> 
             RGBColor[
              0.6862384135590955, 0.7486483562097045, 0.9073224049196079], 
             UndirectedEdge[73, 130] -> 
             RGBColor[
              0.49103106613874525`, 0.5936040099084522, 0.9543468228790843], 
             UndirectedEdge[4, 199] -> 
             RGBColor[
              0.6915976258960705, 0.7532902365741481, 0.9076638891907545], 
             UndirectedEdge[6, 83] -> 
             RGBColor[
              0.8506746508904959, 0.8804426534191563, 0.780068930769096], 
             UndirectedEdge[73, 89] -> 
             RGBColor[
              0.48425258454504877`, 0.5883086085690884, 0.9536712071823368], 
             UndirectedEdge[60, 111] -> 
             RGBColor[
              0.9526441911732825, 0.9617367205812279, 0.8612600271384023], 
             UndirectedEdge[166, 179] -> 
             RGBColor[
              0.6004404639228466, 0.6840491245754401, 0.9631466398562016], 
             UndirectedEdge[30, 197] -> 
             RGBColor[
              0.9354124422681842, 0.9478645023031822, 0.8503774985058863], 
             UndirectedEdge[26, 58] -> 
             RGBColor[
              0.8097022379113323, 0.851725043375973, 0.9815450780738659], 
             UndirectedEdge[11, 35] -> 
             RGBColor[
              0.815329638685667, 0.37360225640328704`, 0.43675584495777275`], 
             UndirectedEdge[137, 187] -> 
             RGBColor[
              0.8308245332228829, 0.8682646978226196, 0.9836400662047099], 
             UndirectedEdge[13, 153] -> 
             RGBColor[
              0.7259538579284673, 0.7852123190235922, 0.9739676359924251], 
             UndirectedEdge[71, 75] -> 
             RGBColor[
              0.810704605746921, 0.8525121268469722, 0.9816439163290256], 
             UndirectedEdge[16, 67] -> 
             RGBColor[
              0.7391523717067224, 0.7961507176341631, 0.9746354587062396], 
             UndirectedEdge[156, 170] -> 
             RGBColor[
              0.9711504691914006, 0.9756930861719565, 0.8139883095171163], 
             UndirectedEdge[96, 128] -> 
             RGBColor[
              0.6564946070152844, 0.7292879086302488, 0.9679634927345386], 
             UndirectedEdge[62, 114] -> 
             RGBColor[
              0.680687576961314, 0.7489181952831165, 0.9698803170759694], 
             UndirectedEdge[101, 105] -> 
             RGBColor[
              0.7467058489775513, 0.8000817240953226, 0.9327808328824239], 
             UndirectedEdge[30, 89] -> 
             RGBColor[
              0.7639115003045756, 0.8159429203466511, 0.9769837524582121], 
             UndirectedEdge[53, 191] -> 
             RGBColor[
              0.5621513578806887, 0.6459054205160439, 0.962021036561191], 
             UndirectedEdge[72, 81] -> 
             RGBColor[
              0.44620596261446016`, 0.560082563192785, 0.9498794917211234], 
             UndirectedEdge[163, 175] -> 
             RGBColor[
              0.7489497200764137, 0.8037839335686408, 0.975890131815294], 
             UndirectedEdge[82, 125] -> 
             RGBColor[
              0.8960911081131804, 0.9197021881547156, 0.9802241812275216], 
             UndirectedEdge[113, 148] -> 
             RGBColor[
              0.694039426828096, 0.7609081422239001, 0.9701390219651773], 
             UndirectedEdge[33, 44] -> 
             RGBColor[
              0.473425601067068, 0.5821361321955638, 0.9520346333533817], 
             UndirectedEdge[21, 179] -> 
             RGBColor[
              0.37411513050064943`, 0.498461455291632, 0.945059263191849], 
             UndirectedEdge[75, 188] -> 
             RGBColor[
              0.7298048084057196, 0.7883908221373594, 0.9742107985105883], 
             UndirectedEdge[85, 88] -> 
             RGBColor[
              0.7054420286529512, 0.7695311823306199, 0.9714702181048468], 
             UndirectedEdge[13, 185] -> 
             RGBColor[
              0.7596455965577542, 0.753514050825681, 0.6196611891046003], 
             UndirectedEdge[93, 161] -> 
             RGBColor[
              0.41148127500295406`, 0.520988519082027, 0.9486420437945655], 
             UndirectedEdge[146, 196] -> 
             RGBColor[
              0.9163468735592624, 0.6960877918405532, 0.25647478135749374`], 
             UndirectedEdge[19, 162] -> 
             RGBColor[
              0.9916985218918515, 0.982311975008104, 0.5368180942204561], 
             UndirectedEdge[140, 172] -> 
             RGBColor[
              0.7505682176848514, 0.7106549475699756, 0.6107755070861898], 
             UndirectedEdge[71, 142] -> 
             RGBColor[
              0.6684683513772716, 0.7401749523946322, 0.96810781320814], 
             UndirectedEdge[87, 142] -> 
             RGBColor[
              0.3859388761467081, 0.49290857934780063`, 0.9472997008760815], 
             UndirectedEdge[89, 147] -> 
             RGBColor[
              0.8200805205185366, 0.8587454496483915, 0.9070857359115478], 
             UndirectedEdge[30, 42] -> 
             RGBColor[
              0.5836295569827795, 0.6637527886397498, 0.9639603842007699], 
             UndirectedEdge[8, 125] -> 
             RGBColor[
              0.9127001366075498, 0.9116184067898885, 0.6805748698886451], 
             UndirectedEdge[29, 168] -> 
             RGBColor[
              0.4532286206190167, 0.5662084813920809, 0.9503150206108659], 
             UndirectedEdge[158, 160] -> 
             RGBColor[
              0.8590962745710842, 0.8904840660685718, 0.9864225636645297], 
             UndirectedEdge[138, 153] -> 
             RGBColor[
              0.6398279261330275, 0.7137087165894338, 0.9676247894110737], 
             UndirectedEdge[26, 122] -> 
             RGBColor[
              0.5699760088616412, 0.6587211799520001, 0.9607573224941939], 
             UndirectedEdge[53, 195] -> 
             RGBColor[
              0.6985436483913171, 0.7632938993039691, 0.9714248889228745], 
             UndirectedEdge[19, 93] -> 
             RGBColor[
              0.7856754847781944, 0.8228169916824255, 0.6854656651382431], 
             UndirectedEdge[11, 196] -> 
             RGBColor[
              0.8422916910154487, 0.6849064145773314, 0.5988829679681934], 
             UndirectedEdge[87, 168] -> 
             RGBColor[
              0.30172307310717084`, 0.4237564401616706, 0.9408859812513022], 
             UndirectedEdge[78, 124] -> 
             RGBColor[
              0.7269973539999617, 0.7866551254200855, 0.9734239601363284], 
             UndirectedEdge[39, 117] -> 
             RGBColor[
              0.9620234235415779, 0.9711977119750212, 0.949168617453365], 
             UndirectedEdge[42, 130] -> 
             RGBColor[
              0.47863790055742994`, 0.5812823253986253, 0.9536152618905539], 
             UndirectedEdge[11, 94] -> 
             RGBColor[
              0.7834206598357224, 0.8307334407719889, 0.9790477079562654], 
             UndirectedEdge[27, 168] -> 
             RGBColor[
              0.49287956618828915`, 0.5983989052599582, 0.9534364882922785], 
             UndirectedEdge[30, 51] -> 
             RGBColor[
              0.8820136603937507, 0.7447972155857827, 0.6082748649131611], 
             UndirectedEdge[6, 58] -> 
             RGBColor[
              0.9354642132673009, 0.9471411380363843, 0.7883978299736403], 
             UndirectedEdge[6, 156] -> 
             RGBColor[
              0.9943059037932794, 0.9902292289122896, 0.6216109516659871], 
             UndirectedEdge[19, 173] -> 
             RGBColor[
              0.9790499134205641, 0.9751361987121969, 0.6736727326057479], 
             UndirectedEdge[57, 200] -> 
             RGBColor[
              0.5328565328537365, 0.6275805806809449, 0.957964442486394], 
             UndirectedEdge[37, 50] -> 
             RGBColor[
              0.9164286325960774, 0.9357539274207143, 0.9764485148921904], 
             UndirectedEdge[49, 171] -> 
             RGBColor[
              0.6949075698899655, 0.7615863421819642, 0.9702255503523263], 
             UndirectedEdge[5, 127] -> 
             RGBColor[
              0.9465745758512989, 0.8234726322994885, 0.5359624302814379], 
             UndirectedEdge[85, 152] -> 
             RGBColor[
              0.5487818302501364, 0.6384681650609718, 0.9602091909082466], 
             UndirectedEdge[130, 131] -> 
             RGBColor[
              0.823595298699366, 0.8622427028337791, 0.941763590636248], 
             UndirectedEdge[33, 58] -> 
             RGBColor[
              0.7082681443374236, 0.7709099924586609, 0.9725112047936681], 
             UndirectedEdge[82, 98] -> 
             RGBColor[
              0.966911856166988, 0.9743362580500262, 0.9181785785672045], 
             UndirectedEdge[74, 173] -> 
             RGBColor[
              0.7834594496441668, 0.8304158359631126, 0.9490798683548717], 
             UndirectedEdge[118, 146] -> 
             RGBColor[
              0.7993971501960379, 0.7964969481212516, 0.6308824726812725], 
             UndirectedEdge[23, 115] -> 
             RGBColor[
              0.4366884564552169, 0.5496054872138558, 0.9498843412128447], 
             UndirectedEdge[49, 65] -> 
             RGBColor[
              0.750411659171407, 0.8049835292916538, 0.9757478683653285], 
             UndirectedEdge[21, 23] -> 
             RGBColor[
              0.31162131034843654`, 0.4443081530890367, 0.9410781018364052], 
             UndirectedEdge[40, 171] -> 
             RGBColor[
              0.8533209662708502, 0.8818913646609046, 0.7307851441852405], 
             UndirectedEdge[104, 158] -> 
             RGBColor[
              0.911694081591347, 0.9315553606690039, 0.9613186232623445], 
             UndirectedEdge[53, 155] -> 
             RGBColor[
              0.864460222987139, 0.8947611329350329, 0.9869341818529063], 
             UndirectedEdge[164, 200] -> 
             RGBColor[
              0.548750592882228, 0.6413472166189393, 0.9589771979368441], 
             UndirectedEdge[81, 142] -> 
             RGBColor[
              0.5009159547716022, 0.6044985994830127, 0.9541864627130383], 
             UndirectedEdge[39, 85] -> 
             RGBColor[
              0.8725847329405703, 0.9009285611542363, 0.9676505923476406], 
             UndirectedEdge[107, 142] -> 
             RGBColor[
              0.6065491896503934, 0.6914629827446173, 0.9621689205536215], 
             UndirectedEdge[121, 161] -> 
             RGBColor[
              0.4365614407712338, 0.5413497275013087, 0.9506164463155189], 
             UndirectedEdge[1, 196] -> 
             RGBColor[
              0.9240754210463222, 0.7490374032191647, 0.5716376136727758], 
             UndirectedEdge[88, 121] -> 
             RGBColor[
              0.6282851940774711, 0.7091092503343595, 0.9638800584437286], 
             UndirectedEdge[85, 133] -> 
             RGBColor[
              0.5617673556625632, 0.6497155745017315, 0.9610366171048772], 
             UndirectedEdge[118, 127] -> 
             RGBColor[
              0.8142173275975599, 0.8539198165712248, 0.8975137051635769], 
             UndirectedEdge[100, 187] -> 
             RGBColor[
              0.8411652981481745, 0.876510143081461, 0.984626377594594], 
             UndirectedEdge[26, 116] -> 
             RGBColor[
              0.7604453004791475, 0.812784915423434, 0.9767577388525424], 
             UndirectedEdge[131, 147] -> 
             RGBColor[
              0.9847559753386765, 0.9875156953766441, 0.8822106963997998], 
             UndirectedEdge[134, 160] -> 
             RGBColor[
              0.9244320098796188, 0.9412386209387077, 0.9453086830607721], 
             UndirectedEdge[3, 5] -> 
             RGBColor[
              0.6631063752964238, 0.5986320222814192, 0.5948841036487647], 
             UndirectedEdge[16, 100] -> 
             RGBColor[
              0.8241234758814961, 0.8631969420040855, 0.9829278080159352], 
             UndirectedEdge[75, 147] -> 
             RGBColor[
              0.9327214698921293, 0.9472056755654508, 0.9181895326828906], 
             UndirectedEdge[72, 76] -> 
             RGBColor[
              0.5241414680093783, 0.6245606818908878, 0.9556814828366099], 
             UndirectedEdge[40, 69] -> 
             RGBColor[
              0.9455940343885467, 0.9546071374272818, 0.7398145202236996], 
             UndirectedEdge[177, 179] -> 
             RGBColor[
              0.7001855701465023, 0.7249407149420832, 0.6373778211095347], 
             UndirectedEdge[98, 100] -> 
             RGBColor[
              0.9448234490862228, 0.9570041157999806, 0.9257987492672184], 
             UndirectedEdge[136, 187] -> 
             RGBColor[
              0.7917724558877486, 0.8372579273238325, 0.9798801369347597], 
             UndirectedEdge[54, 199] -> 
             RGBColor[
              0.9101418298259896, 0.9294402964369575, 0.9264146340505728], 
             UndirectedEdge[166, 198] -> 
             RGBColor[
              0.5091749507400091, 0.5996549487669578, 0.9575269731465693], 
             UndirectedEdge[48, 104] -> 
             RGBColor[
              0.84884904721899, 0.8821854092272046, 0.9551277763079042], 
             UndirectedEdge[187, 198] -> 
             RGBColor[
              0.5154343383004849, 0.6045448299023088, 0.9581508504012951], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.6518373292608325, 0.7254962645110179, 0.967609119895048], 
             UndirectedEdge[103, 117] -> 
             RGBColor[
              0.9005049007179323, 0.9227210230983842, 0.963288936140308], 
             UndirectedEdge[85, 140] -> 
             RGBColor[
              0.8583058389244045, 0.7959037398288702, 0.6207730982946164], 
             UndirectedEdge[36, 70] -> 
             RGBColor[
              0.9448609442051907, 0.8147185906258779, 0.5304294905166165], 
             UndirectedEdge[54, 171] -> 
             RGBColor[
              0.7735296266496318, 0.823115810725753, 0.9780328519712803], 
             UndirectedEdge[120, 125] -> 
             RGBColor[
              0.7632933968583062, 0.8152169440777017, 0.9769866593790603], 
             UndirectedEdge[81, 104] -> 
             RGBColor[
              0.6891350137144412, 0.7526324451439466, 0.9419876805930545], 
             UndirectedEdge[93, 162] -> 
             RGBColor[
              0.7886630500080114, 0.8315474192836048, 0.8116391316593988], 
             UndirectedEdge[73, 168] -> 
             RGBColor[
              0.3704414765094548, 0.49527952084767757`, 0.9448251812080146], 
             UndirectedEdge[119, 199] -> 
             RGBColor[
              0.7100339110259282, 0.769258820118997, 0.9088386329766622], 
             UndirectedEdge[17, 107] -> 
             RGBColor[
              0.5900255070480195, 0.6780483128245918, 0.9608681157309188], 
             UndirectedEdge[14, 48] -> 
             RGBColor[
              0.7911962094130682, 0.8370833702934435, 0.979749563361074], 
             UndirectedEdge[64, 182] -> 
             RGBColor[
              0.6032215808983216, 0.6878348063312305, 0.9625405308875683], 
             UndirectedEdge[71, 129] -> 
             RGBColor[
              0.8334347689464187, 0.7659464491605887, 0.6159628764190312], 
             UndirectedEdge[80, 100] -> 
             RGBColor[
              0.8697806989058202, 0.8990035360121178, 0.987441653595675], 
             UndirectedEdge[18, 178] -> 
             RGBColor[
              0.8584798780287816, 0.8902838649528828, 0.9862864700097048], 
             UndirectedEdge[174, 186] -> 
             RGBColor[
              0.658166087001347, 0.7217006284438368, 0.7742964499697783], 
             UndirectedEdge[115, 165] -> 
             RGBColor[
              0.7211033939894667, 0.7813274191237513, 0.9735248737265052], 
             UndirectedEdge[113, 198] -> 
             RGBColor[
              0.47914292405909664`, 0.5761937012719724, 0.9545336613922618], 
             UndirectedEdge[67, 100] -> 
             RGBColor[
              0.8174306450138411, 0.8579684516628747, 0.9822607291831078], 
             UndirectedEdge[106, 147] -> 
             RGBColor[
              0.6482514471530141, 0.7154398202084438, 0.8945437460932149], 
             UndirectedEdge[75, 129] -> 
             RGBColor[
              0.9001534242322127, 0.8185318299138977, 0.6224895680839396], 
             UndirectedEdge[175, 183] -> 
             RGBColor[
              0.791629314256902, 0.8365839814706479, 0.9372640025074459], 
             UndirectedEdge[105, 144] -> 
             RGBColor[
              0.43532399476250844`, 0.5499605939206738, 0.9493785627570417], 
             UndirectedEdge[44, 128] -> 
             RGBColor[
              0.6137519857122682, 0.6933363989355266, 0.9649443263549968], 
             UndirectedEdge[70, 138] -> 
             RGBColor[
              0.6923008815904049, 0.7532659736637193, 0.8844283825208722], 
             UndirectedEdge[110, 145] -> 
             RGBColor[
              0.5126692518280486, 0.6053541335233, 0.9574051512136623], 
             UndirectedEdge[49, 118] -> 
             RGBColor[
              0.6577991207210268, 0.7325505854907288, 0.9665586195336616], 
             UndirectedEdge[70, 185] -> 
             RGBColor[
              0.9707918433264664, 0.9187006813886507, 0.5513548675040867], 
             UndirectedEdge[11, 138] -> 
             RGBColor[
              0.6031898095416268, 0.684564254938226, 0.9641116962066762], 
             UndirectedEdge[120, 187] -> 
             RGBColor[
              0.7304559939740656, 0.7893570412544928, 0.9737686850461188], 
             UndirectedEdge[71, 127] -> 
             RGBColor[
              0.8665437932043998, 0.8948440033649572, 0.9026974256403222], 
             UndirectedEdge[4, 182] -> 
             RGBColor[
              0.5496364023685922, 0.6427870555105879, 0.9587489667522996], 
             UndirectedEdge[29, 71] -> 
             RGBColor[
              0.6129620227424094, 0.695112414277242, 0.9637381516916224], 
             UndirectedEdge[63, 185] -> 
             RGBColor[
              0.9275232584453129, 0.7500178027891888, 0.26052396822649426`], 
             UndirectedEdge[83, 175] -> 
             RGBColor[
              0.6535747024785337, 0.728644894292655, 0.9665515824420162], 
             UndirectedEdge[79, 126] -> 
             RGBColor[
              0.5543678308108749, 0.6277986670057341, 0.9630814625166222], 
             UndirectedEdge[107, 154] -> 
             RGBColor[
              0.5113483365136712, 0.6127961452889772, 0.955055243250348], 
             UndirectedEdge[34, 64] -> 
             RGBColor[
              0.5154011365631047, 0.6174648870753583, 0.9549934119282701], 
             UndirectedEdge[159, 180] -> 
             RGBColor[
              0.6799060030701467, 0.7490696114441158, 0.9692755161283827], 
             UndirectedEdge[3, 123] -> 
             RGBColor[
              0.40866340887822067`, 0.5283854375753234, 0.9472606489402248], 
             UndirectedEdge[50, 97] -> 
             RGBColor[
              0.6662557358719865, 0.7367621985257093, 0.9692336891476447], 
             UndirectedEdge[87, 89] -> 
             RGBColor[
              0.41553418114276475`, 0.5167855278830814, 0.9497320072256242], 
             UndirectedEdge[123, 191] -> 
             RGBColor[
              0.3405265571011632, 0.4672556694364029, 0.942996398173019], 
             UndirectedEdge[108, 151] -> 
             RGBColor[
              0.7682289815917761, 0.7604824294733892, 0.6203369046164539], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.762887024841056, 0.8146924090527493, 0.9770011071177258], 
             UndirectedEdge[19, 33] -> 
             RGBColor[
              0.7641610509791568, 0.8053506051101693, 0.683771970099615], 
             UndirectedEdge[156, 199] -> 
             RGBColor[
              0.9906914241842828, 0.9898376805833982, 0.7616982749893204], 
             UndirectedEdge[47, 144] -> 
             RGBColor[
              0.6605123392057213, 0.7284323179155632, 0.9487949321343501], 
             UndirectedEdge[123, 127] -> 
             RGBColor[
              0.6921316094330957, 0.7532260475933928, 0.8883389755728979], 
             UndirectedEdge[82, 120] -> 
             RGBColor[
              0.813780852095271, 0.8551937164558745, 0.9720752152443144], 
             UndirectedEdge[120, 137] -> 
             RGBColor[
              0.7813516800892141, 0.8296161289469877, 0.978709074554444], 
             UndirectedEdge[122, 179] -> 
             RGBColor[
              0.41547177056904816`, 0.5342824982737099, 0.9476944717267664], 
             UndirectedEdge[52, 124] -> 
             RGBColor[
              0.6310235033491626, 0.709128056997286, 0.9656027038318292], 
             UndirectedEdge[17, 106] -> 
             RGBColor[
              0.43419330132157635`, 0.5475798078709087, 0.9496879134606702], 
             UndirectedEdge[125, 166] -> 
             RGBColor[
              0.8065068624314992, 0.8489756318179827, 0.9812937737746004], 
             UndirectedEdge[7, 79] -> 
             RGBColor[
              0.3748404571245523, 0.48547081879886367`, 0.9462828597716357], 
             UndirectedEdge[49, 127] -> 
             RGBColor[
              0.8326834290711393, 0.8683920295557552, 0.8993225409866121], 
             UndirectedEdge[121, 200] -> 
             RGBColor[
              0.6757443859728803, 0.7464694908481116, 0.9684156558073586], 
             UndirectedEdge[56, 193] -> 
             RGBColor[
              0.8447894393215475, 0.868752802925733, 0.6890392299724575], 
             UndirectedEdge[149, 194] -> 
             RGBColor[
              0.7343141158177515, 0.7905174399907701, 0.9452109676507667], 
             UndirectedEdge[108, 133] -> 
             RGBColor[
              0.4604340172142143, 0.5696660675223884, 0.9515431944974351], 
             UndirectedEdge[41, 140] -> 
             RGBColor[
              0.8495020685891677, 0.7890261675318504, 0.6198956207435113], 
             UndirectedEdge[36, 185] -> 
             RGBColor[
              0.9260797273771001, 0.7434630653536811, 0.25931945051899313`], 
             UndirectedEdge[108, 111] -> 
             RGBColor[
              0.7473285107465436, 0.8023801073925909, 0.9758633940444212], 
             UndirectedEdge[72, 154] -> 
             RGBColor[
              0.44303990699955176`, 0.5573402849497335, 0.9496777534569745], 
             UndirectedEdge[63, 110] -> 
             RGBColor[
              0.5879915521053557, 0.5284028277054934, 0.5898292105165224], 
             UndirectedEdge[15, 186] -> 
             RGBColor[
              0.7047826457231652, 0.7620775485923081, 0.7772668158701281], 
             UndirectedEdge[54, 155] -> 
             RGBColor[
              0.8620092986053234, 0.8928068323615432, 0.9867004104974026], 
             UndirectedEdge[18, 108] -> 
             RGBColor[
              0.68419573933147, 0.7523310459151439, 0.9697644327452049], 
             UndirectedEdge[44, 102] -> 
             RGBColor[
              0.5673666363139402, 0.6570975489984425, 0.9603216686061518], 
             UndirectedEdge[8, 122] -> 
             RGBColor[
              0.688634652809035, 0.7311019965295981, 0.6612808501715426], 
             UndirectedEdge[42, 197] -> 
             RGBColor[
              0.643360360927342, 0.7079085060157928, 0.8263333922414804], 
             UndirectedEdge[48, 147] -> 
             RGBColor[
              0.8581644515052147, 0.8884969059837804, 0.9108815862377302], 
             UndirectedEdge[34, 54] -> 
             RGBColor[
              0.6803601619632944, 0.7485671961175251, 0.9699525926528199], 
             UndirectedEdge[5, 75] -> 
             RGBColor[
              0.8907353883938202, 0.7811407557815035, 0.614908920970141], 
             UndirectedEdge[55, 115] -> 
             RGBColor[
              0.6057355242726548, 0.6907377927756146, 0.9621490467174645], 
             UndirectedEdge[49, 155] -> 
             RGBColor[
              0.7833872418456571, 0.8312773638177544, 0.9788931088784486], 
             UndirectedEdge[66, 136] -> 
             RGBColor[
              0.8834901491504654, 0.8672956717272571, 0.6466189961161493], 
             UndirectedEdge[136, 148] -> 
             RGBColor[
              0.7421744498494984, 0.7985115880479442, 0.9749366712125855], 
             UndirectedEdge[130, 189] -> 
             RGBColor[
              0.5127680347853678, 0.6124314796183458, 0.9557318833000006], 
             UndirectedEdge[48, 76] -> 
             RGBColor[
              0.6465306961492554, 0.7226051230517849, 0.96621661050425], 
             UndirectedEdge[29, 141] -> 
             RGBColor[
              0.5491510484723086, 0.644864585979455, 0.9576503286237636], 
             UndirectedEdge[133, 163] -> 
             RGBColor[
              0.6172583757819852, 0.6936969318179378, 0.9663999023466497], 
             UndirectedEdge[111, 169] -> 
             RGBColor[
              0.8241103288890366, 0.8632497801105341, 0.9829097505547776], 
             UndirectedEdge[76, 142] -> 
             RGBColor[
              0.5788514601665204, 0.6689767181811153, 0.9599884538285248], 
             UndirectedEdge[78, 98] -> 
             RGBColor[
              0.8274933108156914, 0.8646787680566843, 0.9142811538512241], 
             UndirectedEdge[21, 170] -> 
             RGBColor[
              0.6312259095473323, 0.7037800888900003, 0.9573522237101799], 
             UndirectedEdge[92, 139] -> 
             RGBColor[
              0.5722192176356398, 0.6575717601411595, 0.9622090972265023], 
             UndirectedEdge[63, 70] -> 
             RGBColor[
              0.9463044752734036, 0.8212733280613855, 0.5316340082241175], 
             UndirectedEdge[71, 197] -> 
             RGBColor[
              0.8695645983369369, 0.8959734828864441, 0.843933865605357], 
             UndirectedEdge[127, 141] -> 
             RGBColor[
              0.8027328189342988, 0.8445961750671702, 0.8966096025724635], 
             UndirectedEdge[64, 138] -> 
             RGBColor[
              0.44930999396990606`, 0.5622264290725473, 0.9502277773427701], 
             UndirectedEdge[39, 108] -> 
             RGBColor[
              0.7712513944922212, 0.8208790541748932, 0.9581571697401985], 
             UndirectedEdge[24, 165] -> 
             RGBColor[
              0.621260460518335, 0.6978780301781409, 0.9663258988743137], 
             UndirectedEdge[132, 182] -> 
             RGBColor[
              0.6551317946478616, 0.7299778563815869, 0.9666270930673104], 
             UndirectedEdge[77, 181] -> 
             RGBColor[
              0.845374208911053, 0.8798863072764773, 0.975812366400078], 
             UndirectedEdge[20, 47] -> 
             RGBColor[
              0.9651098082920041, 0.973499532668398, 0.9439441731289577], 
             UndirectedEdge[191, 199] -> 
             RGBColor[
              0.636332927610924, 0.7033096808166746, 0.9042198406616548], 
             UndirectedEdge[89, 154] -> 
             RGBColor[
              0.5273452041527505, 0.6256332697752419, 0.9564170307984321], 
             UndirectedEdge[93, 164] -> 
             RGBColor[
              0.4807263855719817, 0.5872913701480357, 0.9528226472276247], 
             UndirectedEdge[26, 187] -> 
             RGBColor[
              0.7612040897759155, 0.8133776873890814, 0.976833367878355], 
             UndirectedEdge[5, 188] -> 
             RGBColor[
              0.7431169357668246, 0.6644340703185817, 0.6009491114867953], 
             UndirectedEdge[7, 16] -> 
             RGBColor[
              0.6517263337244106, 0.7265545468736498, 0.9668092931194403], 
             UndirectedEdge[154, 160] -> 
             RGBColor[
              0.6333711510792701, 0.7088188723004629, 0.9668898827310908], 
             UndirectedEdge[88, 152] -> 
             RGBColor[
              0.46710984532121347`, 0.5743806306025812, 0.9522635820717646], 
             UndirectedEdge[9, 18] -> 
             RGBColor[
              0.7196675986850617, 0.780929064859882, 0.972693398626997], 
             UndirectedEdge[9, 200] -> 
             RGBColor[
              0.6870397414536032, 0.7554399348097672, 0.9694413587428267], 
             UndirectedEdge[55, 183] -> 
             RGBColor[
              0.8150162966855272, 0.8555059676176112, 0.9391492923164998], 
             UndirectedEdge[72, 104] -> 
             RGBColor[
              0.726459819079113, 0.7841409680663075, 0.9445926486402642], 
             UndirectedEdge[112, 181] -> 
             RGBColor[
              0.84341248990769, 0.8784232604557894, 0.9791330449745123], 
             UndirectedEdge[136, 193] -> 
             RGBColor[
              0.8957162630276816, 0.9085372246631607, 0.694115139821259], 
             UndirectedEdge[80, 198] -> 
             RGBColor[
              0.5440497390581305, 0.6270382228329657, 0.9609661264023761], 
             UndirectedEdge[42, 131] -> 
             RGBColor[
              0.6365348737838734, 0.7047571697875141, 0.9280646066820581], 
             UndirectedEdge[65, 156] -> 
             RGBColor[
              0.9095833102893665, 0.9269103819818835, 0.8188388109230302], 
             UndirectedEdge[26, 192] -> 
             RGBColor[
              0.7015296883218951, 0.7667595914309518, 0.9708855812304058], 
             UndirectedEdge[65, 155] -> 
             RGBColor[
              0.8575336788224579, 0.8892380946341489, 0.9862735218870801], 
             UndirectedEdge[59, 62] -> 
             RGBColor[
              0.7956215182046869, 0.840279009378093, 0.9802600164550436], 
             UndirectedEdge[82, 187] -> 
             RGBColor[
              0.8632537052289397, 0.8938422853315067, 0.9770062068945802], 
             UndirectedEdge[4, 86] -> 
             RGBColor[
              0.695554303632687, 0.7549264245002187, 0.8420914995412729], 
             UndirectedEdge[73, 167] -> 
             RGBColor[
              0.45604214087970474`, 0.5655559528493722, 0.9513479221896618], 
             UndirectedEdge[74, 159] -> 
             RGBColor[
              0.5939177811690662, 0.6812082363010085, 0.9611745298075975], 
             UndirectedEdge[25, 60] -> 
             RGBColor[
              0.9937888380316584, 0.9916995391535786, 0.7525985579947259], 
             UndirectedEdge[159, 162] -> 
             RGBColor[
              0.7924958101752808, 0.8346590266512719, 0.8119408605796294], 
             UndirectedEdge[10, 147] -> 
             RGBColor[
              0.9278357812019159, 0.9433099600223612, 0.9177235313341122], 
             UndirectedEdge[23, 163] -> 
             RGBColor[
              0.6032896346876013, 0.6815736141538453, 0.9655107161197283], 
             UndirectedEdge[40, 54] -> 
             RGBColor[
              0.9133006753351571, 0.9288572894979885, 0.7367343508085654], 
             UndirectedEdge[123, 129] -> 
             RGBColor[
              0.6590225851751146, 0.6243284933890243, 0.6016044263516069], 
             UndirectedEdge[25, 165] -> 
             RGBColor[
              0.9349060345738233, 0.9480879049028081, 0.8810674839584745], 
             UndirectedEdge[39, 178] -> 
             RGBColor[
              0.9455355331895328, 0.9588318732126322, 0.9746792070046986], 
             UndirectedEdge[76, 107] -> 
             RGBColor[
              0.5924498975234977, 0.6800165422301313, 0.9610589726299834], 
             UndirectedEdge[63, 138] -> 
             RGBColor[
              0.6490322967092514, 0.5845830950642574, 0.5935974832432798], 
             UndirectedEdge[71, 81] -> 
             RGBColor[
              0.5764335538554577, 0.6642503931820436, 0.9611958741690154], 
             UndirectedEdge[8, 83] -> 
             RGBColor[
              0.843571319481921, 0.8574073753363429, 0.6737397065466704], 
             UndirectedEdge[10, 149] -> 
             RGBColor[
              0.6834456225543486, 0.7508250532390867, 0.9704798515428577], 
             UndirectedEdge[119, 172] -> 
             RGBColor[
              0.5024661346082919, 0.6064199575990689, 0.9541253504856299], 
             UndirectedEdge[106, 130] -> 
             RGBColor[
              0.48709077051370353`, 0.5901668276655787, 0.9540966403296632], 
             UndirectedEdge[147, 176] -> 
             RGBColor[
              0.7445796015497872, 0.7976002556657364, 0.9010395714722699], 
             UndirectedEdge[27, 197] -> 
             RGBColor[
              0.7781916161874918, 0.8233495749379003, 0.8356762603142747], 
             UndirectedEdge[72, 176] -> 
             RGBColor[
              0.4923351461635813, 0.5987388769579993, 0.9531775726705128], 
             UndirectedEdge[92, 118] -> 
             RGBColor[
              0.7273118346551508, 0.7868544459322597, 0.9734869972253701], 
             UndirectedEdge[123, 171] -> 
             RGBColor[
              0.5543557502519219, 0.6464203602196017, 0.959241984938612], 
             UndirectedEdge[66, 113] -> 
             RGBColor[
              0.835355126129063, 0.829692225903213, 0.6418213468687408], 
             UndirectedEdge[67, 179] -> 
             RGBColor[
              0.5829651983489889, 0.6703973142922051, 0.9614048686994412], 
             UndirectedEdge[130, 197] -> 
             RGBColor[
              0.8304207858428346, 0.8653940390620578, 0.8400323761956703], 
             UndirectedEdge[15, 194] -> 
             RGBColor[
              0.6923919641979784, 0.7554534519536954, 0.9421952105978573], 
             UndirectedEdge[47, 135] -> 
             RGBColor[
              0.954517894629205, 0.9656001008013493, 0.9618735201465587], 
             UndirectedEdge[8, 170] -> 
             RGBColor[
              0.96374451714558, 0.9520105331457143, 0.6747206964885775], 
             UndirectedEdge[17, 149] -> 
             RGBColor[
              0.5295713742725385, 0.6289689244098108, 0.9561089449480478], 
             UndirectedEdge[13, 97] -> 
             RGBColor[
              0.5099530294731193, 0.6130230650984136, 0.9545697123631542], 
             UndirectedEdge[11, 86] -> 
             RGBColor[
              0.9030192977341372, 0.9223120011865401, 0.8597669825404477], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.618565810857418, 0.6974552502255684, 0.9652743723772439], 
             UndirectedEdge[37, 160] -> 
             RGBColor[
              0.9085822709579282, 0.9294974516342669, 0.9757001219146141], 
             UndirectedEdge[46, 50] -> 
             RGBColor[
              0.9277161932870641, 0.9181178215701773, 0.6739541715346592], 
             UndirectedEdge[49, 53] -> 
             RGBColor[
              0.757338203336088, 0.8105065675925379, 0.9764085283311548], 
             UndirectedEdge[52, 120] -> 
             RGBColor[
              0.5783884560931751, 0.6680091580397332, 0.9603565342238348], 
             UndirectedEdge[81, 147] -> 
             RGBColor[
              0.698450418000666, 0.7589439419005222, 0.8977414905228804], 
             UndirectedEdge[49, 123] -> 
             RGBColor[
              0.5357134025565626, 0.6318568165128968, 0.9573838899429827], 
             UndirectedEdge[127, 140] -> 
             RGBColor[
              0.9592996501073037, 0.8739750117524905, 0.5462039981322158], 
             UndirectedEdge[31, 132] -> 
             RGBColor[
              0.496557107796395, 0.6003305363437736, 0.954017210918833], 
             UndirectedEdge[146, 186] -> 
             RGBColor[
              0.9768157571870479, 0.9324272835154996, 0.45192960485432804`], 
             UndirectedEdge[98, 124] -> 
             RGBColor[
              0.8867491921681012, 0.9109699129305653, 0.9201872263267374], 
             UndirectedEdge[4, 53] -> 
             RGBColor[
              0.6174160561658353, 0.6958859762735174, 0.9654650850902906], 
             UndirectedEdge[82, 137] -> 
             RGBColor[
              0.9141493913440883, 0.9341013730240014, 0.9819465964029055], 
             UndirectedEdge[42, 107] -> 
             RGBColor[
              0.45586255132465403`, 0.5631497995729967, 0.951577858645722], 
             UndirectedEdge[99, 102] -> 
             RGBColor[
              0.7548688437779094, 0.8084285450657862, 0.9762019297635136], 
             UndirectedEdge[57, 88] -> 
             RGBColor[
              0.48539734095832726`, 0.5902203401671927, 0.9534288451227642], 
             UndirectedEdge[40, 49] -> 
             RGBColor[
              0.8346786185754909, 0.8673278209541997, 0.7289270491896114], 
             UndirectedEdge[21, 90] -> 
             RGBColor[
              0.5421660908793241, 0.6334829392224702, 0.9594723246155017], 
             UndirectedEdge[143, 158] -> 
             RGBColor[
              0.8781155135345402, 0.9056494909545432, 0.9882366356555392], 
             UndirectedEdge[24, 111] -> 
             RGBColor[
              0.6377087576107985, 0.7109934558025407, 0.967894752134561], 
             UndirectedEdge[139, 155] -> 
             RGBColor[
              0.6098285233525667, 0.6875224650421237, 0.9658063730565454], 
             UndirectedEdge[94, 174] -> 
             RGBColor[
              0.5388261721938352, 0.631188162963548, 0.959006366461016], 
             UndirectedEdge[4, 118] -> 
             RGBColor[
              0.517876973550774, 0.6179299941717084, 0.9556151762927975], 
             UndirectedEdge[121, 159] -> 
             RGBColor[
              0.6115529388299034, 0.6955252517448751, 0.9625628340183696], 
             UndirectedEdge[5, 76] -> 
             RGBColor[
              0.734399841897275, 0.6573571408146777, 0.6002628699256174], 
             UndirectedEdge[27, 194] -> 
             RGBColor[
              0.7653144281706654, 0.8156848901070222, 0.9476514257970738], 
             UndirectedEdge[77, 160] -> 
             RGBColor[
              0.905057736688784, 0.9268688597472343, 0.9816662390865147], 
             UndirectedEdge[2, 80] -> 
             RGBColor[
              0.7064307969421837, 0.7697060980442502, 0.9720353705883413], 
             UndirectedEdge[74, 85] -> 
             RGBColor[
              0.6923220213455569, 0.7588797693488836, 0.9704373630694384], 
             UndirectedEdge[35, 110] -> 
             RGBColor[
              0.6358617379394872, 0.22415640198302103`, 0.42243043736217323`],
              UndirectedEdge[143, 154] -> 
             RGBColor[
              0.652390390042726, 0.7239842971864343, 0.9687039547221001], 
             UndirectedEdge[53, 129] -> 
             RGBColor[
              0.8806473859546401, 0.8029782444686654, 0.6206290647397789], 
             UndirectedEdge[80, 187] -> 
             RGBColor[
              0.8085442478653799, 0.8504990030607817, 0.9815149526974657], 
             UndirectedEdge[30, 87] -> 
             RGBColor[
              0.5273043191618109, 0.6045513924635697, 0.9607527452325879], 
             UndirectedEdge[29, 197] -> 
             RGBColor[
              0.7385406706182193, 0.791159151070023, 0.8325547926328621], 
             UndirectedEdge[74, 121] -> 
             RGBColor[
              0.6151651867700767, 0.698457837352623, 0.9628472034083202], 
             UndirectedEdge[127, 199] -> 
             RGBColor[
              0.9879379799428565, 0.9892800589736646, 0.8495624180615339], 
             UndirectedEdge[52, 80] -> 
             RGBColor[
              0.6564767099844896, 0.7291511198460221, 0.9681028018751817], 
             UndirectedEdge[125, 187] -> 
             RGBColor[
              0.812766249991975, 0.8538655129533339, 0.9819176510293262], 
             UndirectedEdge[57, 152] -> 
             RGBColor[
              0.32873714255551234`, 0.4591573228975446, 0.9421678179261639], 
             UndirectedEdge[128, 193] -> 
             RGBColor[
              0.90404018798714, 0.9150422005510601, 0.6949441904862719], 
             UndirectedEdge[151, 172] -> 
             RGBColor[
              0.7618246988005719, 0.7552831441938377, 0.6198327360154694], 
             UndirectedEdge[5, 27] -> 
             RGBColor[
              0.732643750958581, 0.6559314670796506, 0.6001246240141505], 
             UndirectedEdge[65, 118] -> 
             RGBColor[
              0.7319455576978275, 0.7905113163071233, 0.9739390325422931], 
             UndirectedEdge[78, 80] -> 
             RGBColor[
              0.7524505606352887, 0.8066781882688216, 0.9759240581796809], 
             UndirectedEdge[40, 199] -> 
             RGBColor[
              0.989933169447208, 0.988215850372109, 0.679166926264533], 
             UndirectedEdge[5, 42] -> 
             RGBColor[
              0.5978124956984313, 0.5404903981575431, 0.5907817559413562], 
             UndirectedEdge[123, 196] -> 
             RGBColor[
              0.6341970244462076, 0.516975447247668, 0.5811673627961685], 
             UndirectedEdge[80, 124] -> 
             RGBColor[
              0.8117064419876986, 0.8529693331427025, 0.9818301306551942], 
             UndirectedEdge[22, 48] -> 
             RGBColor[
              0.8472511703665063, 0.8809937152869055, 0.957832565026131], 
             UndirectedEdge[69, 86] -> 
             RGBColor[
              0.9463918666159958, 0.9568263322923214, 0.8639224138162256], 
             UndirectedEdge[81, 143] -> 
             RGBColor[
              0.6555564456576344, 0.7267265754294858, 0.9689056929862492], 
             UndirectedEdge[80, 116] -> 
             RGBColor[
              0.807785458568612, 0.8499062310951344, 0.981439323671653], 
             UndirectedEdge[90, 169] -> 
             RGBColor[
              0.7537918747932111, 0.8075872087096725, 0.9760945875599663], 
             UndirectedEdge[121, 173] -> 
             RGBColor[
              0.8010946073050039, 0.8447328514069793, 0.9504681725656439], 
             UndirectedEdge[8, 179] -> 
             RGBColor[
              0.7066337380988972, 0.7466918995473458, 0.6624277359702465], 
             UndirectedEdge[29, 167] -> 
             RGBColor[
              0.5388292849892666, 0.6364849133937756, 0.956837761592513], 
             UndirectedEdge[76, 87] -> 
             RGBColor[
              0.37183958401981243`, 0.4814621388333147, 0.9461897529524435], 
             UndirectedEdge[111, 163] -> 
             RGBColor[
              0.9041528693143144, 0.9264109716881404, 0.990720101893636], 
             UndirectedEdge[130, 149] -> 
             RGBColor[
              0.5824688434646657, 0.6715559442044808, 0.960517671817041], 
             UndirectedEdge[7, 122] -> 
             RGBColor[
              0.4775400750768148, 0.585211240513944, 0.9524318173139381], 
             UndirectedEdge[89, 142] -> 
             RGBColor[
              0.6225460572894728, 0.704300107230882, 0.9635307081017057], 
             UndirectedEdge[44, 172] -> 
             RGBColor[
              0.4894394139703124, 0.5951368669244678, 0.9532952993656546], 
             UndirectedEdge[7, 179] -> 
             RGBColor[
              0.495539160366677, 0.6008011435316918, 0.9535787031126419], 
             UndirectedEdge[73, 188] -> 
             RGBColor[
              0.449275081291646, 0.5600621490232257, 0.9508151944703338], 
             UndirectedEdge[16, 120] -> 
             RGBColor[
              0.7134141717073872, 0.7760438401771173, 0.97207011546746], 
             UndirectedEdge[98, 116] -> 
             RGBColor[
              0.8828282087490147, 0.9079068108829971, 0.9197964193431962], 
             UndirectedEdge[5, 81] -> 
             RGBColor[
              0.6564643365023568, 0.592879022116575, 0.5944608788101309], 
             UndirectedEdge[76, 106] -> 
             RGBColor[
              0.4366176917970547, 0.5495480372764483, 0.9498787703597347], 
             UndirectedEdge[135, 144] -> 
             RGBColor[
              0.6554691667740657, 0.7246711281734715, 0.9573317075911144], 
             UndirectedEdge[194, 197] -> 
             RGBColor[
              0.9822660581959204, 0.984355534848347, 0.8247256720293961], 
             UndirectedEdge[27, 29] -> 
             RGBColor[
              0.5215890405929642, 0.622488506328698, 0.95548054640054], 
             UndirectedEdge[44, 58] -> 
             RGBColor[
              0.6420826001082125, 0.715926461840811, 0.9676465256471201], 
             UndirectedEdge[53, 92] -> 
             RGBColor[
              0.8268509172702121, 0.8648104280340687, 0.9833369060228633], 
             UndirectedEdge[83, 122] -> 
             RGBColor[
              0.552409351952072, 0.644997974062707, 0.9590064423031903], 
             UndirectedEdge[9, 178] -> 
             RGBColor[
              0.7942033347360795, 0.8400705408128017, 0.9798799848727364], 
             UndirectedEdge[12, 99] -> 
             RGBColor[
              0.5442799970777277, 0.6345510038213764, 0.959843032208609], 
             UndirectedEdge[7, 126] -> 
             RGBColor[
              0.7371348385607662, 0.7940577339787962, 0.9751146514447999], 
             UndirectedEdge[139, 146] -> 
             RGBColor[
              0.6443045331765269, 0.6672142623301515, 0.6196045726824047], 
             UndirectedEdge[100, 198] -> 
             RGBColor[
              0.5766707893409251, 0.6530493628536449, 0.9640775512995045], 
             UndirectedEdge[56, 109] -> 
             RGBColor[
              0.7901003637287773, 0.6539199918858846, 0.5955935312847495], 
             UndirectedEdge[9, 159] -> 
             RGBColor[
              0.6228482943106263, 0.7044956957065307, 0.9635885369538377], 
             UndirectedEdge[2, 98] -> 
             RGBColor[
              0.7814735471225862, 0.8277066778321129, 0.9103924662598846], 
             UndirectedEdge[95, 164] -> 
             RGBColor[
              0.6742955094754056, 0.7061237113303858, 0.641226635454581], 
             UndirectedEdge[108, 163] -> 
             RGBColor[
              0.7412716952529472, 0.797550567125874, 0.9752856895756591], 
             UndirectedEdge[85, 121] -> 
             RGBColor[
              0.709957179006394, 0.7731967847927501, 0.9718256672802106], 
             UndirectedEdge[55, 177] -> 
             RGBColor[
              0.8067388178117272, 0.8119197183012468, 0.6456613652587107], 
             UndirectedEdge[118, 141] -> 
             RGBColor[
              0.6278485105841864, 0.7087547310021438, 0.963845681119513], 
             UndirectedEdge[58, 77] -> 
             RGBColor[
              0.9114236803087836, 0.9319448903908859, 0.9822734284719352], 
             UndirectedEdge[142, 154] -> 
             RGBColor[
              0.4977498991566939, 0.6017563212399611, 0.9539847244488894], 
             UndirectedEdge[103, 178] -> 
             RGBColor[
              0.8840170103658872, 0.9103551843359952, 0.9887995256916415], 
             UndirectedEdge[48, 154] -> 
             RGBColor[
              0.5654291351394287, 0.6553847261106307, 0.9602128811246146], 
             UndirectedEdge[72, 181] -> 
             RGBColor[
              0.6141784842811193, 0.6960871209951185, 0.9638427163560126], 
             UndirectedEdge[45, 132] -> 
             RGBColor[
              0.5606508911990231, 0.654200676367013, 0.9585556383685225], 
             UndirectedEdge[103, 200] -> 
             RGBColor[
              0.7768534170834109, 0.8257245783329608, 0.9783608995617317], 
             UndirectedEdge[21, 61] -> 
             RGBColor[
              0.6041190836099508, 0.6824751188051219, 0.9654895824373648], 
             UndirectedEdge[51, 73] -> 
             RGBColor[
              0.6023547446342239, 0.51716290380822, 0.5849623196372857], 
             UndirectedEdge[18, 41] -> 
             RGBColor[
              0.7767253074445821, 0.8255029805974672, 0.9783803778015419], 
             UndirectedEdge[27, 42] -> 
             RGBColor[
              0.426408730902087, 0.5392378612744678, 0.9492591460091583], 
             UndirectedEdge[90, 165] -> 
             RGBColor[
              0.8234429336196218, 0.8624625149295959, 0.9829137901073396], 
             UndirectedEdge[50, 135] -> 
             RGBColor[
              0.9146803508062082, 0.9344500617243786, 0.9794078999375206], 
             UndirectedEdge[93, 121] -> 
             RGBColor[
              0.6077201786626341, 0.692413644377208, 0.9622611050981391], 
             UndirectedEdge[23, 175] -> 
             RGBColor[
              0.454143300943297, 0.5637761163010626, 0.9512584505101485], 
             UndirectedEdge[57, 164] -> 
             RGBColor[
              0.36291869822111766`, 0.4887636684001506, 0.9443458364276134], 
             UndirectedEdge[54, 172] -> 
             RGBColor[
              0.7025740534083533, 0.7666014339170293, 0.9717013515595404], 
             UndirectedEdge[99, 198] -> 
             RGBColor[
              0.5165921506295154, 0.6054493216934471, 0.9582662503138815], 
             UndirectedEdge[45, 112] -> 
             RGBColor[
              0.7279444246088402, 0.7862507500956488, 0.9689697861186934], 
             UndirectedEdge[88, 173] -> 
             RGBColor[
              0.7965794569515612, 0.8410672489448491, 0.9501127233902801], 
             UndirectedEdge[14, 22] -> 
             RGBColor[
              0.9101381555206887, 0.9303971171434087, 0.9640274132835918], 
             UndirectedEdge[7, 67] -> 
             RGBColor[
              0.6450335028567555, 0.7213260565324391, 0.966142214286613], 
             UndirectedEdge[105, 135] -> 
             RGBColor[
              0.7293295501859921, 0.7871283768064599, 0.9624571507692503], 
             UndirectedEdge[104, 176] -> 
             RGBColor[
              0.7352641972635623, 0.7912887589091607, 0.9452857615424439], 
             UndirectedEdge[57, 91] -> 
             RGBColor[
              0.33046206349758167`, 0.46065136272051765`, 0.9422777283633049],
              UndirectedEdge[34, 185] -> 
             RGBColor[
              0.739610807355513, 0.7372489063943335, 0.6180839771087488], 
             UndirectedEdge[65, 172] -> 
             RGBColor[
              0.6980984336254877, 0.763032696189635, 0.9712744629492178], 
             UndirectedEdge[66, 120] -> 
             RGBColor[
              0.8221736872367824, 0.8193947856579173, 0.6405075442275083], 
             UndirectedEdge[91, 117] -> 
             RGBColor[
              0.6399454417932133, 0.71023135570473, 0.9418371264511118], 
             UndirectedEdge[27, 141] -> 
             RGBColor[
              0.588801994041581, 0.6770550098473322, 0.9607717963051761], 
             UndirectedEdge[13, 145] -> 
             RGBColor[
              0.6598359282273841, 0.7330380033162225, 0.9675162705217711], 
             UndirectedEdge[1, 174] -> 
             RGBColor[
              0.6485401584459873, 0.7171384800432535, 0.9345448390826512], 
             UndirectedEdge[182, 196] -> 
             RGBColor[
              0.7880421714284901, 0.6425262775643796, 0.5934758828463496], 
             UndirectedEdge[96, 137] -> 
             RGBColor[
              0.6872227593909603, 0.7537897032411365, 0.9708943713394762], 
             UndirectedEdge[89, 157] -> 
             RGBColor[
              0.7409615648953587, 0.7976432648107428, 0.9747947671312318], 
             UndirectedEdge[119, 191] -> 
             RGBColor[
              0.35959251469881165`, 0.4837696436245938, 0.9442112641317768], 
             UndirectedEdge[51, 157] -> 
             RGBColor[
              0.8590637249845339, 0.7264975600498744, 0.6060858795861808], 
             UndirectedEdge[127, 195] -> 
             RGBColor[
              0.7738888741263683, 0.8211793612671865, 0.8943389015783321], 
             UndirectedEdge[27, 62] -> 
             RGBColor[
              0.691488274830105, 0.7576866883788951, 0.9707305875764606], 
             UndirectedEdge[4, 40] -> 
             RGBColor[
              0.6947564714052381, 0.7527072296351791, 0.7179836059487472], 
             UndirectedEdge[161, 164] -> 
             RGBColor[
              0.3095676476805815, 0.4362274532721364, 0.9411779884450044], 
             UndirectedEdge[20, 101] -> 
             RGBColor[
              0.9774429346519078, 0.982691690215169, 0.9228046306988955], 
             UndirectedEdge[13, 36] -> 
             RGBColor[
              0.7337146974364784, 0.6495319600629083, 0.5987358121171301], 
             UndirectedEdge[182, 195] -> 
             RGBColor[
              0.6307639945940741, 0.7101949785410397, 0.9647087705848836], 
             UndirectedEdge[184, 186] -> 
             RGBColor[
              0.8522326137993961, 0.8817730792143457, 0.7893016365387543], 
             UndirectedEdge[96, 166] -> 
             RGBColor[
              0.630067685715336, 0.7086407344132906, 0.9653301045764251], 
             UndirectedEdge[38, 43] -> 
             RGBColor[
              0.5186182019523488, 0.6199032201495484, 0.9552945890925129], 
             UndirectedEdge[30, 176] -> 
             RGBColor[
              0.6884105813358261, 0.754797726363996, 0.9709375880189342], 
             UndirectedEdge[171, 174] -> 
             RGBColor[
              0.5178559291792757, 0.6148060497408242, 0.9569162486153875], 
             UndirectedEdge[100, 125] -> 
             RGBColor[
              0.8740027010324152, 0.90237004590467, 0.9878443519275355], 
             UndirectedEdge[17, 188] -> 
             RGBColor[
              0.5710448714336961, 0.6626389777649939, 0.9593738905670001], 
             UndirectedEdge[87, 107] -> 
             RGBColor[
              0.3995373135036854, 0.5039484033968166, 0.9483702196775401], 
             UndirectedEdge[62, 184] -> 
             RGBColor[
              0.7660157789336488, 0.817150780847606, 0.9773091930458699], 
             UndirectedEdge[12, 33] -> 
             RGBColor[
              0.4229633338429695, 0.5382035383718826, 0.9488274501977951], 
             UndirectedEdge[32, 57] -> 
             RGBColor[
              0.4156068536816104, 0.5335612785703312, 0.9479346823133625], 
             UndirectedEdge[17, 87] -> 
             RGBColor[
              0.36941519354433405`, 0.47949390942777514`, 0.9459988960533787],
              UndirectedEdge[42, 149] -> 
             RGBColor[
              0.3954084185491731, 0.5140704111582157, 0.9468186878628511], 
             UndirectedEdge[87, 130] -> 
             RGBColor[
              0.4223126627364613, 0.5220809292224452, 0.9504076229223719], 
             UndirectedEdge[58, 170] -> 
             RGBColor[
              0.912308778665422, 0.9326049952960512, 0.9807751878247695], 
             UndirectedEdge[118, 196] -> 
             RGBColor[0.756282742610672, 0.6176692162255, 0.5903420923868474],
              UndirectedEdge[41, 159] -> 
             RGBColor[
              0.6799060030701467, 0.7490696114441158, 0.9692755161283827], 
             UndirectedEdge[107, 157] -> 
             RGBColor[
              0.7249646972562793, 0.7848061403244779, 0.9734329795831476], 
             UndirectedEdge[161, 173] -> 
             RGBColor[
              0.6048557036453239, 0.6733077261117983, 0.9368491112620703], 
             UndirectedEdge[15, 184] -> 
             RGBColor[
              0.5628450262930937, 0.6539115845119594, 0.9597244043521453], 
             UndirectedEdge[106, 142] -> 
             RGBColor[
              0.4507169839239503, 0.5609944777909341, 0.9509887182833727], 
             UndirectedEdge[24, 39] -> 
             RGBColor[
              0.6616316413564762, 0.7294924025848429, 0.9501885278303382], 
             UndirectedEdge[45, 134] -> 
             RGBColor[
              0.749280416803038, 0.8020835581078101, 0.9292915515185166], 
             UndirectedEdge[5, 73] -> 
             RGBColor[
              0.6102056612797466, 0.5528120826673699, 0.5915133169298865], 
             UndirectedEdge[147, 154] -> 
             RGBColor[
              0.6952843623857576, 0.7562016636574707, 0.8975397522587315], 
             UndirectedEdge[76, 143] -> 
             RGBColor[
              0.7334919510525526, 0.7912046941275884, 0.9747076841017357], 
             UndirectedEdge[5, 197] -> 
             RGBColor[
              0.949595380983836, 0.8246021118209755, 0.47719887024647245`], 
             UndirectedEdge[152, 159] -> 
             RGBColor[
              0.45037759007364575`, 0.5607966320130968, 0.9509463576464057], 
             UndirectedEdge[108, 115] -> 
             RGBColor[
              0.5746705170205628, 0.6655824401858846, 0.9596593146687755], 
             UndirectedEdge[65, 123] -> 
             RGBColor[
              0.6098598395333633, 0.6898175473292913, 0.9647643029516142], 
             UndirectedEdge[8, 67] -> 
             RGBColor[
              0.8561280805889757, 0.8672168125480932, 0.6749912471442174], 
             UndirectedEdge[9, 41] -> 
             RGBColor[
              0.7124487641518801, 0.7752896564573859, 0.9719738926645736], 
             UndirectedEdge[111, 165] -> 
             RGBColor[
              0.8937613877154473, 0.9181250863304575, 0.9897289531021509], 
             UndirectedEdge[146, 195] -> 
             RGBColor[
              0.7590686967248463, 0.7637564928172134, 0.6277076690960277], 
             UndirectedEdge[104, 188] -> 
             RGBColor[
              0.775787612978909, 0.8241874933459532, 0.9484759132697189], 
             UndirectedEdge[37, 105] -> 
             RGBColor[
              0.7310778319758613, 0.7884322425027956, 0.9594977657239201], 
             UndirectedEdge[3, 75] -> 
             RGBColor[
              0.6497942479353187, 0.7225887741001968, 0.9681457906725575], 
             UndirectedEdge[40, 132] -> 
             RGBColor[
              0.8002518636845075, 0.8398980305061781, 0.725861732263758], 
             UndirectedEdge[154, 157] -> 
             RGBColor[
              0.6161654067625798, 0.6950994788198219, 0.9652487834784156], 
             UndirectedEdge[116, 148] -> 
             RGBColor[
              0.7295720517727162, 0.7886664988885892, 0.9736805819483978], 
             UndirectedEdge[132, 185] -> 
             RGBColor[
              0.7797111694555077, 0.7698041868478349, 0.6212408245057269], 
             UndirectedEdge[92, 123] -> 
             RGBColor[
              0.6052261164906866, 0.6861606769544277, 0.9643122676346914], 
             UndirectedEdge[53, 139] -> 
             RGBColor[
              0.5837794848429977, 0.6667516688169073, 0.9633217925092514], 
             UndirectedEdge[40, 196] -> 
             RGBColor[
              0.933162240465136, 0.7524464516889708, 0.3527105220427971], 
             UndirectedEdge[27, 73] -> 
             RGBColor[
              0.43880189648340234`, 0.5515595457842947, 0.9499907069976887], 
             UndirectedEdge[57, 103] -> 
             RGBColor[
              0.5910215224223005, 0.673141030114172, 0.9637295380525011], 
             UndirectedEdge[44, 77] -> 
             RGBColor[
              0.676581137038428, 0.743171030127789, 0.9617968570316486], 
             UndirectedEdge[88, 91] -> 
             RGBColor[
              0.4688347662632828, 0.5758746704255542, 0.9523734925089057], 
             UndirectedEdge[69, 146] -> 
             RGBColor[
              0.9287786674826731, 0.8982484775788642, 0.6435787795383963], 
             UndirectedEdge[65, 199] -> 
             RGBColor[
              0.9056662100431241, 0.9258715587095632, 0.9259877454402501], 
             UndirectedEdge[27, 75] -> 
             RGBColor[
              0.7193316235974758, 0.7798882188984283, 0.9733863110379433], 
             UndirectedEdge[4, 65] -> 
             RGBColor[
              0.6104895120011541, 0.6903629379726333, 0.9648044251244643], 
             UndirectedEdge[58, 102] -> 
             RGBColor[
              0.8022091795842958, 0.8458714092615396, 0.9807982400464382], 
             UndirectedEdge[107, 168] -> 
             RGBColor[
              0.5223333866108562, 0.6223108435584872, 0.9557552009288421], 
             UndirectedEdge[9, 85] -> 
             RGBColor[
              0.7212525344871169, 0.7821672287544057, 0.9728513702156787], 
             UndirectedEdge[22, 144] -> 
             RGBColor[
              0.6638283639123544, 0.730905403712278, 0.9431817672637772], 
             UndirectedEdge[110, 138] -> 
             RGBColor[
              0.3339879584223571, 0.4603954733078271, 0.9426235848132769], 
             UndirectedEdge[34, 132] -> 
             RGBColor[
              0.5673113503126448, 0.6596079371257146, 0.9590799741080125], 
             UndirectedEdge[48, 158] -> 
             RGBColor[
              0.7911542586312429, 0.8370499198787396, 0.9797455620580535], 
             UndirectedEdge[19, 95] -> 
             RGBColor[
              0.9792446086816182, 0.9416493328647757, 0.3738696533651995], 
             UndirectedEdge[122, 137] -> 
             RGBColor[
              0.6395964523086086, 0.7136081903855382, 0.9675640208205488], 
             UndirectedEdge[8, 198] -> 
             RGBColor[
              0.6153682249160597, 0.6622977237388634, 0.6568080692606142], 
             UndirectedEdge[92, 174] -> 
             RGBColor[
              0.5687262954180403, 0.6545463664756501, 0.9619865313114668], 
             UndirectedEdge[39, 133] -> 
             RGBColor[
              0.6472380750212592, 0.717025418866957, 0.9492713825111891], 
             UndirectedEdge[120, 198] -> 
             RGBColor[
              0.4659614851668161, 0.5658962610266768, 0.9532198587510292], 
             UndirectedEdge[4, 34] -> 
             RGBColor[
              0.46181595803337533`, 0.5724171362547157, 0.9512018477930015], 
             UndirectedEdge[31, 34] -> 
             RGBColor[
              0.4564567456964004, 0.5677752558902721, 0.9508603635218549], 
             UndirectedEdge[41, 152] -> 
             RGBColor[
              0.5399780599148996, 0.631590592763952, 0.9593317133571415], 
             UndirectedEdge[95, 121] -> 
             RGBColor[
              0.8012893025660579, 0.8112459855595581, 0.6506650933250955], 
             UndirectedEdge[3, 129] -> 
             RGBColor[
              0.6725244111348163, 0.6360230964138134, 0.6024647507625631], 
             UndirectedEdge[49, 199] -> 
             RGBColor[
              0.8315197730663233, 0.8679108278931686, 0.9186073324316186], 
             UndirectedEdge[171, 182] -> 
             RGBColor[
              0.7082008972342043, 0.7719711905363134, 0.9715505049887929], 
             UndirectedEdge[56, 150] -> 
             RGBColor[
              0.7040551881801735, 0.7687325311147487, 0.971137299454141], 
             UndirectedEdge[179, 183] -> 
             RGBColor[
              0.7084630490203023, 0.7685269642584478, 0.9308657481673238], 
             UndirectedEdge[31, 156] -> 
             RGBColor[
              0.6901555138053379, 0.7496871794820248, 0.800173470402388], 
             UndirectedEdge[132, 153] -> 
             RGBColor[
              0.7460194308262207, 0.8015024550457462, 0.9755472713935517], 
             UndirectedEdge[78, 136] -> 
             RGBColor[
              0.7356787686576574, 0.7934371125318724, 0.9742892424169749], 
             UndirectedEdge[27, 167] -> 
             RGBColor[
              0.578480230558539, 0.6686753372616528, 0.9599592292739256], 
             UndirectedEdge[35, 174] -> 
             RGBColor[
              0.6522666469244089, 0.24057207119765978`, 0.42339495062760646`],
              UndirectedEdge[61, 190] -> 
             RGBColor[
              0.7505586161198526, 0.8051235190270303, 0.975978334361089], 
             UndirectedEdge[18, 103] -> 
             RGBColor[
              0.8094812743148694, 0.8512137083830755, 0.9816129394459019], 
             UndirectedEdge[146, 155] -> 
             RGBColor[
              0.9249852713206681, 0.8952237264482772, 0.6432169620260595], 
             UndirectedEdge[77, 166] -> 
             RGBColor[
              0.8566661446128909, 0.8887076532686432, 0.9769378410216984], 
             UndirectedEdge[85, 159] -> 
             RGBColor[
              0.6887097734053835, 0.7559471837411356, 0.9701529936794877], 
             UndirectedEdge[39, 88] -> 
             RGBColor[
              0.7909127480116473, 0.8368410266958455, 0.9597049835111588], 
             UndirectedEdge[66, 80] -> 
             RGBColor[
              0.9002619411280969, 0.8805367474642063, 0.6482538118788552], 
             UndirectedEdge[62, 141] -> 
             RGBColor[
              0.7190502827094493, 0.780062768029652, 0.9729003697996841], 
             UndirectedEdge[91, 103] -> 
             RGBColor[
              0.5744589477272561, 0.6587953603725334, 0.9626741854386425], 
             UndirectedEdge[149, 189] -> 
             RGBColor[
              0.42953855277711106`, 0.5452195653779361, 0.9489353092722976], 
             UndirectedEdge[4, 69] -> 
             RGBColor[
              0.6472584908374093, 0.7196815236293208, 0.9683114831499212], 
             UndirectedEdge[23, 169] -> 
             RGBColor[
              0.5232470942623235, 0.6184124225762389, 0.9577003647808698], 
             UndirectedEdge[32, 152] -> 
             RGBColor[
              0.3973193580444966, 0.5177215690057195, 0.946769419262363], 
             UndirectedEdge[100, 124] -> 
             RGBColor[
              0.8443274922704932, 0.8789804731633817, 0.9849415555523225], 
             UndirectedEdge[129, 139] -> 
             RGBColor[
              0.6260156863200679, 0.5957395765757562, 0.5995012559434179], 
             UndirectedEdge[29, 73] -> 
             RGBColor[
              0.3991509509141299, 0.5193691219164174, 0.9468692393162763], 
             UndirectedEdge[32, 178] -> 
             RGBColor[
              0.708602341625197, 0.7707754327921543, 0.973004669952503], 
             UndirectedEdge[8, 61] -> 
             RGBColor[
              0.9366376912081986, 0.9307055630608357, 0.6828580552157624], 
             UndirectedEdge[10, 27] -> 
             RGBColor[
              0.7144459349072625, 0.7759925033553388, 0.972920309689165], 
             UndirectedEdge[72, 160] -> 
             RGBColor[
              0.6738620120588503, 0.7430696734658755, 0.9696965890424494], 
             UndirectedEdge[72, 144] -> 
             RGBColor[
              0.42249718966485705`, 0.5395472157014157, 0.9483687896736195], 
             UndirectedEdge[134, 135] -> 
             RGBColor[
              0.9670727429091093, 0.974883946060034, 0.9370594717041508], 
             UndirectedEdge[95, 150] -> 
             RGBColor[
              0.8380631099030273, 0.8401203897547194, 0.6542302502319246], 
             UndirectedEdge[68, 71] -> 
             RGBColor[
              0.5984127657146409, 0.6832876817871592, 0.9625963701132286], 
             UndirectedEdge[118, 123] -> 
             RGBColor[
              0.5172473010829832, 0.6173846035283664, 0.9555750541199474], 
             UndirectedEdge[89, 168] -> 
             RGBColor[
              0.5383302542499355, 0.6351479680447519, 0.9571169884769264], 
             UndirectedEdge[44, 99] -> 
             RGBColor[
              0.5947422643018261, 0.6784835976450576, 0.9630502153641955], 
             UndirectedEdge[121, 180] -> 
             RGBColor[
              0.7011534086711572, 0.7663192124957303, 0.9709481897291055], 
             UndirectedEdge[10, 141] -> 
             RGBColor[
              0.7420079427866068, 0.7983685830060956, 0.9750900919123885], 
             UndirectedEdge[6, 170] -> 
             RGBColor[
              0.9708478485541547, 0.9750458112285276, 0.7810499207110031], 
             UndirectedEdge[12, 77] -> 
             RGBColor[
              0.6261188698143296, 0.6992384363041078, 0.9585896738760622], 
             UndirectedEdge[112, 143] -> 
             RGBColor[
              0.9221152566488771, 0.9405712378125177, 0.9868009896519585], 
             UndirectedEdge[67, 125] -> 
             RGBColor[
              0.7890315968576416, 0.8353238215347476, 0.9795520026178399], 
             UndirectedEdge[3, 10] -> 
             RGBColor[
              0.6449085592451053, 0.7186930585571073, 0.9676797893237792], 
             UndirectedEdge[124, 125] -> 
             RGBColor[
              0.8159284441142935, 0.8563358430352546, 0.9822328289870547], 
             UndirectedEdge[11, 174] -> 
             RGBColor[
              0.5667564284151138, 0.6530074914014201, 0.9617901933780688], 
             UndirectedEdge[71, 87] -> 
             RGBColor[
              0.46145647523056355`, 0.5526603730468316, 0.9543091123320586], 
             UndirectedEdge[7, 192] -> 
             RGBColor[
              0.6090937545370687, 0.6932496519928958, 0.9625600760501499], 
             UndirectedEdge[56, 148] -> 
             RGBColor[
              0.6912476261433642, 0.7587271663105166, 0.969860761363784], 
             UndirectedEdge[30, 71] -> 
             RGBColor[
              0.8098337943923744, 0.8518177655104012, 0.9815608575646464], 
             UndirectedEdge[35, 86] -> 
             RGBColor[
              0.8764418931370912, 0.4201084110544064, 0.3553794767358591], 
             UndirectedEdge[68, 127] -> 
             RGBColor[
              0.7209706084579135, 0.7782049390584532, 0.8901765710894338], 
             UndirectedEdge[10, 30] -> 
             RGBColor[
              0.8716667609879549, 0.9005074307206207, 0.9876215478807766], 
             UndirectedEdge[89, 176] -> 
             RGBColor[
              0.5766404433167801, 0.6670318617835076, 0.9599168500119706], 
             UndirectedEdge[71, 76] -> 
             RGBColor[
              0.6543690592503759, 0.7287285118801463, 0.9669978652845019], 
             UndirectedEdge[49, 119] -> 
             RGBColor[
              0.554779360154211, 0.6483707907010878, 0.9585987559017406], 
             UndirectedEdge[87, 106] -> 
             RGBColor[
              0.24370510777724227`, 0.37347989844313356`, 0.9371900174072914],
              UndirectedEdge[86, 196] -> 
             RGBColor[
              0.933960072692585, 0.7546656465540105, 0.47681841563532296`], 
             UndirectedEdge[53, 123] -> 
             RGBColor[
              0.6167863836980445, 0.6953405856301755, 0.9654249629174405], 
             UndirectedEdge[68, 102] -> 
             RGBColor[
              0.5901663983790891, 0.6768455569499132, 0.961774449283905], 
             UndirectedEdge[107, 130] -> 
             RGBColor[
              0.6429229762401467, 0.7206353326192618, 0.9652768425999119], 
             UndirectedEdge[42, 157] -> 
             RGBColor[
              0.5606796215735625, 0.6454531331038416, 0.9617713988737896], 
             UndirectedEdge[96, 99] -> 
             RGBColor[
              0.6374848856048423, 0.7144351073397799, 0.9660693817437374], 
             UndirectedEdge[62, 194] -> 
             RGBColor[
              0.8955627168385336, 0.9186926482893419, 0.9597799992915819], 
             UndirectedEdge[57, 117] -> 
             RGBColor[
              0.656508016488258, 0.7245770254463685, 0.9428924790649704], 
             UndirectedEdge[102, 128] -> 
             RGBColor[
              0.7738785651883516, 0.8232813463562552, 0.978096040754315], 
             UndirectedEdge[46, 47] -> 
             RGBColor[
              0.9675537371100609, 0.9492678606471479, 0.6564197917436971], 
             UndirectedEdge[28, 105] -> 
             RGBColor[
              0.6203757023055727, 0.7013214154060663, 0.9641917141569921], 
             UndirectedEdge[40, 182] -> 
             RGBColor[
              0.8479719459197297, 0.8777126693085489, 0.7302520038260781], 
             UndirectedEdge[79, 179] -> 
             RGBColor[
              0.3127721526167857, 0.43454207655862964`, 0.9415455141844642], 
             UndirectedEdge[36, 63] -> 
             RGBColor[
              0.9015923593240371, 0.646035712026416, 0.23959859123902405`], 
             UndirectedEdge[118, 129] -> 
             RGBColor[
              0.7811083033395789, 0.7250222623668563, 0.6107791559422857], 
             UndirectedEdge[74, 161] -> 
             RGBColor[
              0.4189262831103967, 0.5270327120574421, 0.9492281421047467], 
             UndirectedEdge[66, 187] -> 
             RGBColor[
              0.8716465403704512, 0.8580433545335495, 0.6454385358777741], 
             UndirectedEdge[10, 29] -> 
             RGBColor[
              0.67479498933799, 0.7438020794874615, 0.9697988420077523], 
             UndirectedEdge[30, 147] -> 
             RGBColor[
              0.9318506585375826, 0.9465113142288799, 0.9181064739185114], 
             UndirectedEdge[109, 116] -> 
             RGBColor[
              0.8284247893581294, 0.683859324463957, 0.5994133518693634], 
             UndirectedEdge[81, 154] -> 
             RGBColor[
              0.40571510163488, 0.5258317620273726, 0.9470727854097648], 
             UndirectedEdge[89, 188] -> 
             RGBColor[
              0.6171638590321268, 0.6999305962203002, 0.9631070017392456], 
             UndirectedEdge[24, 163] -> 
             RGBColor[
              0.631651942117202, 0.7061639155358237, 0.9673170476657988], 
             UndirectedEdge[91, 159] -> 
             RGBColor[
              0.4521025110157151, 0.5622906718360698, 0.9510562680835466], 
             UndirectedEdge[121, 164] -> 
             RGBColor[
              0.5058065513402614, 0.6076525785673174, 0.9547970497485779], 
             UndirectedEdge[4, 54] -> 
             RGBColor[
              0.6149651317840197, 0.6939316757000277, 0.965231313734787], 
             UndirectedEdge[51, 130] -> 
             RGBColor[
              0.7770220039684013, 0.6623267523446583, 0.5979297426029451], 
             UndirectedEdge[69, 186] -> 
             RGBColor[
              0.9461331435250928, 0.9557602373580589, 0.7984932227408055], 
             UndirectedEdge[137, 179] -> 
             RGBColor[
              0.6575955375984709, 0.729198093403286, 0.9687109066192527], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.7994127467933532, 0.8435015135978149, 0.9805686909780931], 
             UndirectedEdge[22, 176] -> 
             RGBColor[
              0.7336663204110787, 0.7900970649688617, 0.9479905502606707], 
             UndirectedEdge[128, 198] -> 
             RGBColor[
              0.5356018720399575, 0.6203021229839161, 0.9601603613046829], 
             UndirectedEdge[107, 131] -> 
             RGBColor[
              0.8008199494665902, 0.8441101770081505, 0.9397261873914162], 
             UndirectedEdge[26, 125] -> 
             RGBColor[
              0.7940414926601561, 0.8392375902122904, 0.9800513422112964], 
             UndirectedEdge[47, 105] -> 
             RGBColor[
              0.7343727226176476, 0.7908895665485516, 0.9539203753124861], 
             UndirectedEdge[23, 60] -> 
             RGBColor[
              0.6517809565465693, 0.7168993630469328, 0.8360506413644946], 
             UndirectedEdge[43, 111] -> 
             RGBColor[
              0.6785702777418577, 0.7463856507803468, 0.9704984120648885], 
             UndirectedEdge[73, 142] -> 
             RGBColor[
              0.45465727954899204`, 0.5644316600338076, 0.9512389008327939], 
             UndirectedEdge[43, 115] -> 
             RGBColor[
              0.505912284015877, 0.6095879835736404, 0.9542943326892428], 
             UndirectedEdge[61, 122] -> 
             RGBColor[
              0.6454757236783496, 0.7182961617871998, 0.9681247909722822], 
             UndirectedEdge[64, 65] -> 
             RGBColor[
              0.6640746905308834, 0.7354106887932759, 0.9685959892597329], 
             UndirectedEdge[147, 157] -> 
             RGBColor[
              0.9089007231283658, 0.9282116586929716, 0.9159174885915311], 
             UndirectedEdge[53, 69] -> 
             RGBColor[
              0.8682536191491439, 0.89778588406562, 0.987295999365243], 
             UndirectedEdge[27, 188] -> 
             RGBColor[
              0.5717131709704804, 0.6631815334355065, 0.9594265015545975], 
             UndirectedEdge[88, 159] -> 
             RGBColor[
              0.6070377884764606, 0.6918596492827449, 0.9622073848430059], 
             UndirectedEdge[16, 61] -> 
             RGBColor[
              0.8196619823259453, 0.8596394681469056, 0.9825022667777845], 
             UndirectedEdge[138, 185] -> 
             RGBColor[
              0.6735196647623143, 0.6820104483915225, 0.6133183425232488], 
             UndirectedEdge[26, 128] -> 
             RGBColor[
              0.781371623515388, 0.8291349804706886, 0.9788428787817427], 
             UndirectedEdge[68, 75] -> 
             RGBColor[
              0.6651314210004349, 0.7358730625404682, 0.969123061778137], 
             UndirectedEdge[10, 107] -> 
             RGBColor[
              0.7438997553298294, 0.7999044416538676, 0.9752390223257287], 
             UndirectedEdge[69, 123] -> 
             RGBColor[
              0.6466288183696185, 0.7191361329859789, 0.9682713609770711], 
             UndirectedEdge[109, 113] -> 
             RGBColor[
              0.7928921644135092, 0.656100967799268, 0.5958717918861427], 
             UndirectedEdge[49, 196] -> 
             RGBColor[
              0.7747488440842513, 0.6321414292100305, 0.5921509282098828], 
             UndirectedEdge[8, 26] -> 
             RGBColor[
              0.8611379763914904, 0.871130581225636, 0.675490586737674], 
             UndirectedEdge[30, 73] -> 
             RGBColor[
              0.5960227225640948, 0.6760744731495767, 0.9646919451893003], 
             UndirectedEdge[46, 144] -> 
             RGBColor[
              0.6685050092549217, 0.70833888801927, 0.651877979188253], 
             UndirectedEdge[81, 176] -> 
             RGBColor[
              0.4550103407989095, 0.5672303540356383, 0.9505726046233032], 
             UndirectedEdge[104, 181] -> 
             RGBColor[
              0.8571075353811003, 0.88863700294628, 0.9559509052279437], 
             UndirectedEdge[65, 171] -> 
             RGBColor[
              0.7690540068667662, 0.8195470729983587, 0.9776059633609577], 
             UndirectedEdge[67, 82] -> 
             RGBColor[
              0.8395190520946063, 0.8753005939129204, 0.9746405584830939], 
             UndirectedEdge[13, 63] -> 
             RGBColor[
              0.7351582285046913, 0.6560866974984159, 0.5999403298246312], 
             UndirectedEdge[153, 182] -> 
             RGBColor[
              0.793739513061443, 0.839317093848117, 0.9799375429558717], 
             UndirectedEdge[87, 157] -> 
             RGBColor[
              0.5043543837525939, 0.5862517369276614, 0.9585637599056076], 
             UndirectedEdge[30, 157] -> 
             RGBColor[
              0.8527317029144048, 0.8854091293912311, 0.9858155051381955], 
             UndirectedEdge[64, 185] -> 
             RGBColor[
              0.7278009557059676, 0.7276611367974787, 0.6171542623259847], 
             UndirectedEdge[9, 103] -> 
             RGBColor[
              0.7452047310221673, 0.8010003842429942, 0.9752064543089336], 
             UndirectedEdge[18, 117] -> 
             RGBColor[
              0.8749677683808267, 0.902649703715272, 0.9607758804583713], 
             UndirectedEdge[52, 66] -> 
             RGBColor[
              0.7195790024895609, 0.7366954713187899, 0.6320263850554902], 
             UndirectedEdge[128, 162] -> 
             RGBColor[
              0.9074750008541741, 0.9252812994513112, 0.822855129622386], 
             UndirectedEdge[23, 177] -> 
             RGBColor[
              0.6376917499942893, 0.6707874127394879, 0.6333966597540908], 
             UndirectedEdge[11, 110] -> 
             RGBColor[
              0.5421490649377312, 0.6283839875794621, 0.9603434234799189], 
             UndirectedEdge[79, 177] -> 
             RGBColor[
              0.5794868669043776, 0.6096103902092553, 0.6300819777685285], 
             UndirectedEdge[8, 166] -> 
             RGBColor[
              0.8736033461628334, 0.8808686228313283, 0.6767330183009779], 
             UndirectedEdge[162, 173] -> 
             RGBColor[
              0.9820374786503814, 0.9838666263133761, 0.7998461991269036], 
             UndirectedEdge[100, 137] -> 
             RGBColor[
              0.8920609842633231, 0.9167692307739558, 0.9895667671029192], 
             UndirectedEdge[88, 117] -> 
             RGBColor[
              0.794880719253959, 0.839800333151405, 0.9529882432105712], 
             UndirectedEdge[149, 168] -> 
             RGBColor[
              0.46187925383537526`, 0.5732314551437061, 0.9509960301459712], 
             UndirectedEdge[36, 110] -> 
             RGBColor[
              0.5865480210371429, 0.5218480902699858, 0.5886246928090213], 
             UndirectedEdge[76, 104] -> 
             RGBColor[
              0.7670705191093594, 0.8171105638420492, 0.947789671708541], 
             UndirectedEdge[4, 196] -> 
             RGBColor[
              0.6348266969139984, 0.5175208378910099, 0.5812074849690186], 
             UndirectedEdge[61, 79] -> 
             RGBColor[
              0.5427761057260871, 0.6185557400721196, 0.9619758334299799], 
             UndirectedEdge[76, 147] -> 
             RGBColor[
              0.7763859233955842, 0.8234220605986249, 0.903543481638367], 
             UndirectedEdge[2, 120] -> 
             RGBColor[
              0.6283425430508692, 0.7085641362379612, 0.9642891029369944], 
             UndirectedEdge[87, 176] -> 
             RGBColor[
              0.3400332621740153, 0.45564033390042624`, 0.9436858427863464], 
             UndirectedEdge[142, 157] -> 
             RGBColor[
              0.711366259899302, 0.773766316275462, 0.972362460781689], 
             UndirectedEdge[65, 191] -> 
             RGBColor[
              0.5552248137160075, 0.6403823822151599, 0.9613603765953647], 
             UndirectedEdge[73, 147] -> 
             RGBColor[
              0.6521917427780558, 0.7188770024513171, 0.8947939286426361], 
             UndirectedEdge[26, 120] -> 
             RGBColor[
              0.7117312366422467, 0.7747291185134493, 0.9719023762280892], 
             UndirectedEdge[113, 116] -> 
             RGBColor[
              0.7428786435695782, 0.799061709534141, 0.9750068586615387], 
             UndirectedEdge[35, 94] -> 
             RGBColor[
              0.7967094678714813, 0.3590560374447055, 0.4348999603464041], 
             UndirectedEdge[31, 45] -> 
             RGBColor[
              0.4497962865827788, 0.5623679951315704, 0.950336027782365], 
             UndirectedEdge[52, 82] -> 
             RGBColor[
              0.7111861673480494, 0.772494402116747, 0.9635940560722962], 
             UndirectedEdge[95, 162] -> 
             RGBColor[
              0.9822321739114354, 0.9503797604659548, 0.5000431198863553], 
             UndirectedEdge[17, 73] -> 
             RGBColor[
              0.4381335969466181, 0.5510169901137821, 0.9499380960100913], 
             UndirectedEdge[103, 152] -> 
             RGBColor[
              0.5727340267851868, 0.6573013205495604, 0.9625642750015015], 
             UndirectedEdge[88, 103] -> 
             RGBColor[
              0.7293942251880017, 0.7883643378192084, 0.9738253021981018], 
             UndirectedEdge[26, 170] -> 
             RGBColor[
              0.8450858731981863, 0.8796297165681162, 0.9741971688112288], 
             UndirectedEdge[89, 106] -> 
             RGBColor[
              0.48031228892000705`, 0.5848714263262149, 0.9534210246329156], 
             UndirectedEdge[19, 74] -> 
             RGBColor[
              0.793120492885637, 0.8288611846578406, 0.6860517634484242], 
             UndirectedEdge[117, 152] -> 
             RGBColor[
              0.6382205208511441, 0.7087373158817569, 0.9417272160139709], 
             UndirectedEdge[157, 176] -> 
             RGBColor[
              0.6654606459266093, 0.7364980708280877, 0.9687486026919538], 
             UndirectedEdge[49, 139] -> 
             RGBColor[
              0.5027065037015158, 0.6032678996996287, 0.9552807195347938], 
             UndirectedEdge[48, 106] -> 
             RGBColor[
              0.5183962199066852, 0.6146228826616037, 0.9572168749590979], 
             UndirectedEdge[69, 118] -> 
             RGBColor[
              0.7687145365340827, 0.8198299019638109, 0.97744609056775], 
             UndirectedEdge[117, 200] -> 
             RGBColor[
              0.8423399111493682, 0.8771605736651572, 0.957523840574201], 
             UndirectedEdge[64, 153] -> 
             RGBColor[
              0.6941092170766807, 0.75935940499539, 0.9714607092138094], 
             UndirectedEdge[73, 87] -> 
             RGBColor[
              0.247645403402284, 0.376917080686007, 0.9374401999567126], 
             UndirectedEdge[132, 138] -> 
             RGBColor[
              0.5012202077194461, 0.6043694791229035, 0.9543143395225124], 
             UndirectedEdge[6, 96] -> 
             RGBColor[
              0.7433642912999615, 0.7943187874680095, 0.7709404249128955], 
             UndirectedEdge[34, 65] -> 
             RGBColor[
              0.6758845421804289, 0.7449984583901308, 0.9695257040424972], 
             UndirectedEdge[2, 16] -> 
             RGBColor[
              0.6607735739178595, 0.7338995040362177, 0.9675215250086014], 
             UndirectedEdge[21, 122] -> 
             RGBColor[
              0.3561160452107872, 0.48287155227388423`, 0.943912377393145], 
             UndirectedEdge[90, 175] -> 
             RGBColor[
              0.6846880814741847, 0.752950902434496, 0.969652673289245], 
             UndirectedEdge[6, 179] -> 
             RGBColor[
              0.7137370695074721, 0.7697271776301592, 0.768756960192672], 
             UndirectedEdge[8, 137] -> 
             RGBColor[
              0.9307584198384578, 0.9260175916591742, 0.682297285064029], 
             UndirectedEdge[3, 127] -> 
             RGBColor[
              0.7056334353927973, 0.7649206506181818, 0.8891992999838543], 
             UndirectedEdge[31, 65] -> 
             RGBColor[
              0.6051302996641792, 0.6857210576081898, 0.9644629408533176], 
             UndirectedEdge[3, 71] -> 
             RGBColor[
              0.5830755926495247, 0.6700033933468879, 0.9616190990076491], 
             UndirectedEdge[146, 184] -> 
             RGBColor[
              0.8348781377569764, 0.8242613194351509, 0.6343871933363452], 
             UndirectedEdge[33, 99] -> 
             RGBColor[
              0.6609278085310372, 0.7334671282629075, 0.9679148945107436], 
             UndirectedEdge[10, 130] -> 
             RGBColor[
              0.7666751045626053, 0.8180369674794963, 0.9772764255705606], 
             UndirectedEdge[112, 160] -> 
             RGBColor[
              0.903096017685421, 0.9254058129265463, 0.9849869176609489], 
             UndirectedEdge[73, 157] -> 
             RGBColor[
              0.573072787154878, 0.6577748176136684, 0.96250295986232], 
             UndirectedEdge[157, 188] -> 
             RGBColor[
              0.7059840616419559, 0.7693968052648801, 0.9719387544192288], 
             UndirectedEdge[70, 132] -> 
             RGBColor[
              0.7984923862835982, 0.8410597121200318, 0.8923508645033502], 
             UndirectedEdge[141, 191] -> 
             RGBColor[
              0.45112776660236636`, 0.5586257969101802, 0.9512670251725845], 
             UndirectedEdge[26, 80] -> 
             RGBColor[
              0.7898194905335612, 0.8358710803197382, 0.9796486438794361], 
             UndirectedEdge[171, 199] -> 
             RGBColor[
              0.8501621207616826, 0.8824743715998735, 0.9204654274272479], 
             UndirectedEdge[23, 43] -> 
             RGBColor[
              0.3777070431151446, 0.5015482932460515, 0.9452890262909808], 
             UndirectedEdge[75, 81] -> 
             RGBColor[
              0.6431522091412517, 0.7168357739353527, 0.9677225658339239], 
             UndirectedEdge[33, 172] -> 
             RGBColor[
              0.5556249581995234, 0.6501203975423175, 0.9581599785122027], 
             UndirectedEdge[156, 166] -> 
             RGBColor[
              0.8810092982086539, 0.9045511758575706, 0.8160006313295167], 
             UndirectedEdge[151, 175] -> 
             RGBColor[
              0.7759070064152427, 0.7667157959161559, 0.6209413468560889], 
             UndirectedEdge[34, 199] -> 
             RGBColor[
              0.7569926560753453, 0.8079257569916455, 0.9123851681087873], 
             UndirectedEdge[38, 169] -> 
             RGBColor[
              0.6641582530995276, 0.7367673494797357, 0.9677059275824019], 
             UndirectedEdge[10, 142] -> 
             RGBColor[
              0.7303013179728521, 0.7888646176048517, 0.9741685035242701], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.58756855403607, 0.6760536476850194, 0.9606746953897027], 
             UndirectedEdge[12, 128] -> 
             RGBColor[
              0.5632897184881698, 0.6494038051118454, 0.9617371431994104], 
             UndirectedEdge[19, 172] -> 
             RGBColor[
              0.7801748638824011, 0.8183513398390732, 0.6850326361118879], 
             UndirectedEdge[109, 124] -> 
             RGBColor[
              0.8323457727772159, 0.6869224265115252, 0.5998041588529046], 
             UndirectedEdge[75, 127] -> 
             RGBColor[
              0.9332624484901937, 0.9474293841182663, 0.9092241173052307], 
             UndirectedEdge[4, 191] -> 
             RGBColor[
              0.341156229568954, 0.4678010600797448, 0.943036520345869], 
             UndirectedEdge[68, 172] -> 
             RGBColor[
              0.5122391760354612, 0.6148848748759383, 0.9547480800434078], 
             UndirectedEdge[97, 105] -> 
             RGBColor[
              0.48090493525177036`, 0.5894405136077907, 0.9522829399793744], 
             UndirectedEdge[120, 136] -> 
             RGBColor[
              0.7422996027540798, 0.7986093584482005, 0.9749491452844938], 
             UndirectedEdge[117, 159] -> 
             RGBColor[
              0.7781484640063913, 0.8262163345619207, 0.9516710187852121], 
             UndirectedEdge[183, 192] -> 
             RGBColor[
              0.822017643190694, 0.8609754727196518, 0.9398471211048318], 
             UndirectedEdge[71, 188] -> 
             RGBColor[
              0.6630861531199255, 0.7358054413840502, 0.9676841068456798], 
             UndirectedEdge[14, 106] -> 
             RGBColor[
              0.5812832050608676, 0.6640262845181069, 0.9634117232165587], 
             UndirectedEdge[141, 194] -> 
             RGBColor[
              0.7928764360500097, 0.838060969757779, 0.9498212080202975], 
             UndirectedEdge[50, 105] -> 
             RGBColor[
              0.6945351787946509, 0.7597395274715809, 0.971454755103448], 
             UndirectedEdge[98, 125] -> 
             RGBColor[
              0.9164244009300233, 0.9343594856718535, 0.9230900227019505], 
             UndirectedEdge[118, 119] -> 
             RGBColor[
              0.5363132586806316, 0.6338985777165573, 0.9567899200787051], 
             UndirectedEdge[137, 166] -> 
             RGBColor[
              0.824565145662407, 0.8633748166872686, 0.9830161889499841], 
             UndirectedEdge[6, 112] -> 
             RGBColor[
              0.9680010311941536, 0.9729226595026743, 0.7858688399326031], 
             UndirectedEdge[65, 119] -> 
             RGBColor[
              0.6289257971310118, 0.7063315215174824, 0.965979168910372], 
             UndirectedEdge[170, 183] -> 
             RGBColor[
              0.9655738280669851, 0.9738455978568161, 0.9431587086856548], 
             UndirectedEdge[14, 131] -> 
             RGBColor[
              0.9177877332465301, 0.9361021596863073, 0.9510786735231436], 
             UndirectedEdge[9, 164] -> 
             RGBColor[
              0.5171019068209843, 0.6166230225289729, 0.955822752684046], 
             UndirectedEdge[96, 170] -> 
             RGBColor[
              0.7202088566980827, 0.7797826447276763, 0.9633177827640247], 
             UndirectedEdge[117, 178] -> 
             RGBColor[
              0.9495035044318445, 0.9617911796681917, 0.9679624667041109], 
             UndirectedEdge[18, 24] -> 
             RGBColor[
              0.5745759861957249, 0.6609443943250937, 0.9617957908353445], 
             UndirectedEdge[18, 133] -> 
             RGBColor[
              0.560182419860508, 0.6484774106072076, 0.9608786455161955], 
             UndirectedEdge[49, 129] -> 
             RGBColor[
              0.7995744048131582, 0.7394944753513868, 0.6125879917653212], 
             UndirectedEdge[124, 198] -> 
             RGBColor[
              0.5185965324228035, 0.6070151599842296, 0.9584660283590236], 
             UndirectedEdge[113, 124] -> 
             RGBColor[
              0.7467996269886648, 0.8021248115817092, 0.9753976656450799], 
             UndirectedEdge[176, 188] -> 
             RGBColor[
              0.5416629400633773, 0.638785402237645, 0.9570608372999676], 
             UndirectedEdge[37, 97] -> 
             RGBColor[
              0.7027983890531969, 0.7654549135569241, 0.9572766997681168], 
             UndirectedEdge[77, 143] -> 
             RGBColor[
              0.9240769756522399, 0.9420342846332056, 0.9834803110775241], 
             UndirectedEdge[79, 84] -> 
             RGBColor[
              0.5896033716839301, 0.6540795262398986, 0.8985739087756475], 
             UndirectedEdge[151, 199] -> 
             RGBColor[
              0.9693924752182081, 0.9181220067137659, 0.5745460185065019], 
             UndirectedEdge[48, 87] -> 
             RGBColor[
              0.4536181121294429, 0.5465369842184702, 0.9535278575518067], 
             UndirectedEdge[27, 30] -> 
             RGBColor[
              0.7184608122429292, 0.7791938575618573, 0.9733032522735642], 
             UndirectedEdge[5, 87] -> 
             RGBColor[
              0.5414872578774627, 0.48128900198136293`, 0.5875741169731741], 
             UndirectedEdge[68, 81] -> 
             RGBColor[
              0.4308603691089715, 0.5476113288755396, 0.948675019618127], 
             UndirectedEdge[155, 172] -> 
             RGBColor[
              0.731074016299738, 0.7893265307157354, 0.9744197034623379], 
             UndirectedEdge[143, 188] -> 
             RGBColor[
              0.7422090449221023, 0.7982816236314925, 0.9753939256629136], 
             UndirectedEdge[102, 180] -> 
             RGBColor[
              0.748499844350712, 0.8034530343070712, 0.9755671274222941], 
             UndirectedEdge[80, 136] -> 
             RGBColor[
              0.8203878566453942, 0.8597513202544894, 0.9826954129358407], 
             UndirectedEdge[66, 78] -> 
             RGBColor[
              0.81555285314036, 0.8142225397415893, 0.6398476413599894], 
             UndirectedEdge[50, 101] -> 
             RGBColor[
              0.9320566495977675, 0.9474034090132415, 0.9497315820506942], 
             UndirectedEdge[41, 85] -> 
             RGBColor[
              0.7783102432466373, 0.8267411444919909, 0.9785383493902235], 
             UndirectedEdge[5, 30] -> 
             RGBColor[
              0.8898645770392735, 0.7804463944449327, 0.6148258622057621], 
             UndirectedEdge[32, 133] -> 
             RGBColor[
              0.4103048834569234, 0.5289689784464792, 0.9475968454589937], 
             UndirectedEdge[159, 161] -> 
             RGBColor[
              0.41531403517022336`, 0.5241001264496942, 0.948943772714796], 
             UndirectedEdge[3, 195] -> 
             RGBColor[
              0.4904206735714933, 0.5963387512491172, 0.9532605749456589], 
             UndirectedEdge[173, 180] -> 
             RGBColor[
              0.8694476715452473, 0.89827721110622, 0.9571808546756568], 
             UndirectedEdge[129, 141] -> 
             RGBColor[
              0.7696237946763178, 0.7156986208628017, 0.6098750533511725], 
             UndirectedEdge[53, 199] -> 
             RGBColor[
              0.9125927542078052, 0.9313945970104471, 0.9266484054060764], 
             UndirectedEdge[88, 95] -> 
             RGBColor[
              0.7967741522126153, 0.8075803830974279, 0.6503096441497318], 
             UndirectedEdge[93, 95] -> 
             RGBColor[
              0.7762091367977781, 0.7908847771402764, 0.6486906908041421], 
             UndirectedEdge[3, 29] -> 
             RGBColor[
              0.45205166493080706`, 0.5651890615304667, 0.9502400260351542], 
             UndirectedEdge[52, 125] -> 
             RGBColor[
              0.6606987121110846, 0.7325176297385743, 0.9685055002070422], 
             UndirectedEdge[82, 136] -> 
             RGBColor[
              0.875097314008954, 0.9030946025252142, 0.9781866671329553], 
             UndirectedEdge[116, 193] -> 
             RGBColor[
              0.8831138649508994, 0.8986921355038056, 0.6928590505570713], 
             UndirectedEdge[19, 159] -> 
             RGBColor[
              0.7895082449454636, 0.8259285990500926, 0.6857673940584736], 
             UndirectedEdge[77, 99] -> 
             RGBColor[
              0.8640833445023972, 0.8945020261951325, 0.9776771181890106], 
             UndirectedEdge[53, 196] -> 
             RGBColor[
              0.8558218252257331, 0.6956251983273091, 0.6001920011843405], 
             UndirectedEdge[58, 137] -> 
             RGBColor[
              0.8793226813582997, 0.9066120538095113, 0.9883517764002209], 
             UndirectedEdge[159, 200] -> 
             RGBColor[
              0.6544969803718699, 0.7292198897964971, 0.9667429822066358], 
             UndirectedEdge[3, 62] -> 
             RGBColor[
              0.6219508991679478, 0.7003872435806637, 0.9654900672110749], 
             UndirectedEdge[48, 157] -> 
             RGBColor[
              0.779045495882037, 0.8273947211461316, 0.9785906174574142], 
             UndirectedEdge[130, 168] -> 
             RGBColor[
              0.5451087358436321, 0.6404433693841158, 0.9577926041736741], 
             UndirectedEdge[140, 180] -> 
             RGBColor[
              0.8495020685891677, 0.7890261675318504, 0.6198956207435113], 
             UndirectedEdge[146, 171] -> 
             RGBColor[
              0.8365055993649766, 0.825532704812487, 0.6345494034999372], 
             UndirectedEdge[26, 100] -> 
             RGBColor[
              0.8224405408163558, 0.8618822203404175, 0.9827600687765643], 
             UndirectedEdge[45, 153] -> 
             RGBColor[
              0.6992586096126046, 0.763539913833543, 0.9718660882570838], 
             UndirectedEdge[165, 177] -> 
             RGBColor[
              0.9221066875285391, 0.9025093446493834, 0.6570371922677513], 
             UndirectedEdge[123, 139] -> 
             RGBColor[
              0.3621546840634722, 0.4881019177372662, 0.9442971541210795], 
             UndirectedEdge[13, 34] -> 
             RGBColor[
              0.5472457774148913, 0.6433178011035606, 0.9575003387068859], 
             UndirectedEdge[48, 72] -> 
             RGBColor[
              0.6059199961190089, 0.6896355272760433, 0.9630195874359732], 
             UndirectedEdge[127, 191] -> 
             RGBColor[
              0.6374965836157399, 0.7037908824792614, 0.8849350492166483], 
             UndirectedEdge[58, 125] -> 
             RGBColor[
              0.8612643981273919, 0.8922128689402254, 0.9866293612248371], 
             UndirectedEdge[165, 169] -> 
             RGBColor[
              0.8076620317965731, 0.8501343544861343, 0.9813408972945303], 
             UndirectedEdge[119, 156] -> 
             RGBColor[
              0.7139510112721705, 0.7702976433913173, 0.8016896984594423], 
             UndirectedEdge[139, 191] -> 
             RGBColor[
              0.3075196582461164, 0.4386667526231347, 0.94089322776483], 
             UndirectedEdge[48, 81] -> 
             RGBColor[
              0.5685951907543372, 0.6581270043536822, 0.9604146193887635], 
             UndirectedEdge[85, 161] -> 
             RGBColor[
              0.513718275346714, 0.6017716594975692, 0.958206605976637], 
             UndirectedEdge[30, 106] -> 
             RGBColor[
              0.5920824269390531, 0.6726372909067032, 0.9644417626398792], 
             UndirectedEdge[118, 195] -> 
             RGBColor[
              0.5990045657762559, 0.6853379172021601, 0.9615749801253815], 
             UndirectedEdge[132, 145] -> 
             RGBColor[
              0.6799015011251375, 0.7493281393383765, 0.9690959059228977], 
             UndirectedEdge[124, 137] -> 
             RGBColor[
              0.8339867273452015, 0.8707350279045405, 0.9839552441624384], 
             UndirectedEdge[53, 182] -> 
             RGBColor[
              0.7706315306803269, 0.8208914159468871, 0.9777334829676214], 
             UndirectedEdge[31, 40] -> 
             RGBColor[
              0.6893972590682631, 0.7480653492707356, 0.7176421216776006], 
             UndirectedEdge[130, 157] -> 
             RGBColor[
              0.7477400464890552, 0.8029386661501066, 0.9754703828279795], 
             UndirectedEdge[83, 166] -> 
             RGBColor[
              0.7373780453058703, 0.7947646003644373, 0.9744586104326256], 
             UndirectedEdge[76, 176] -> 
             RGBColor[
              0.5329458461938277, 0.631708472733741, 0.9563745957387897], 
             UndirectedEdge[100, 113] -> 
             RGBColor[
              0.8048738839067864, 0.8481590144511245, 0.9810091885855607], 
             UndirectedEdge[53, 118] -> 
             RGBColor[
              0.7388721018625086, 0.7960343546080075, 0.9745996925081193], 
             UndirectedEdge[18, 85] -> 
             RGBColor[
              0.785529077779819, 0.832380552894487, 0.979257855352647], 
             UndirectedEdge[90, 177] -> 
             RGBColor[
              0.868236530525177, 0.8599621988729216, 0.6517908825331873], 
             UndirectedEdge[55, 165] -> 
             RGBColor[
              0.761945220906172, 0.8144200343579212, 0.9767842728328628], 
             UndirectedEdge[9, 121] -> 
             RGBColor[
              0.6440956999116367, 0.7217452967581452, 0.9652612105545605], 
             UndirectedEdge[70, 110] -> 
             RGBColor[
              0.6312601369865092, 0.6970857063049554, 0.8806601097941149], 
             UndirectedEdge[51, 147] -> 
             RGBColor[
              0.9381826806077118, 0.7875997448875233, 0.5383768483664968], 
             UndirectedEdge[81, 188] -> 
             RGBColor[
              0.4955337565142562, 0.6001290884724308, 0.9537627563505782], 
             UndirectedEdge[63, 132] -> 
             RGBColor[
              0.7552238014024446, 0.6723768335205699, 0.6015199652257579], 
             UndirectedEdge[68, 143] -> 
             RGBColor[
              0.6775356575168175, 0.7457638640346014, 0.9703061889304623], 
             UndirectedEdge[76, 81] -> 
             RGBColor[
              0.4868166626447066, 0.5930521589685267, 0.9530765147894003], 
             UndirectedEdge[55, 163] -> 
             RGBColor[
              0.772336702505039, 0.822705919715604, 0.9777754216243479], 
             UndirectedEdge[86, 94] -> 
             RGBColor[
              0.8750890415128587, 0.900492672748668, 0.8569831556233949], 
             UndirectedEdge[3, 167] -> 
             RGBColor[
              0.5089428548963819, 0.6113758924634214, 0.9547187089085398], 
             UndirectedEdge[16, 82] -> 
             RGBColor[
              0.8462118829622614, 0.8805290842541311, 0.9753076373159214], 
             UndirectedEdge[51, 107] -> 
             RGBColor[
              0.7542466547356254, 0.6441942265190297, 0.5958923393581133], 
             UndirectedEdge[53, 171] -> 
             RGBColor[
              0.7759805510314474, 0.8250701112992428, 0.9782666233267839], 
             UndirectedEdge[78, 82] -> 
             RGBColor[
              0.8071600179988485, 0.8500214705395465, 0.9714153123767953], 
             UndirectedEdge[92, 186] -> 
             RGBColor[
              0.9047304416461609, 0.9227847813265075, 0.7945341293984256], 
             UndirectedEdge[75, 118] -> 
             RGBColor[
              0.7583781401400813, 0.8115879400532399, 0.97646019585228], 
             UndirectedEdge[77, 83] -> 
             RGBColor[
              0.8266341179319786, 0.8652464057736579, 0.973944529267391], 
             UndirectedEdge[42, 176] -> 
             RGBColor[
              0.39635849999498396`, 0.5148417300766064, 0.9468934817545283], 
             UndirectedEdge[20, 144] -> 
             RGBColor[
              0.666061080436865, 0.7325705600405201, 0.9394023605735135], 
             UndirectedEdge[26, 98] -> 
             RGBColor[
              0.8648622407139637, 0.893871660107601, 0.9180057395509793], 
             UndirectedEdge[16, 84] -> 
             RGBColor[
              0.8664892482837883, 0.8951632543146847, 0.919100342123452], 
             UndirectedEdge[55, 175] -> 
             RGBColor[
              0.6231903687607347, 0.7049084218628213, 0.9635231560147683], 
             UndirectedEdge[113, 128] -> 
             RGBColor[
              0.7638049666058188, 0.8154117745813956, 0.9770919985907391], 
             UndirectedEdge[142, 147] -> 
             RGBColor[
              0.7904852155224799, 0.8348685011131107, 0.904653429562005], 
             UndirectedEdge[10, 42] -> 
             RGBColor[
              0.5796146796471128, 0.6605514344332312, 0.9635774416163707], 
             UndirectedEdge[98, 120] -> 
             RGBColor[
              0.8341141449121139, 0.8698510139730125, 0.914941056718743], 
             UndirectedEdge[195, 199] -> 
             RGBColor[
              0.7727252181215524, 0.8206981596045998, 0.9136236930233386], 
             UndirectedEdge[49, 195] -> 
             RGBColor[
              0.6174706672498352, 0.6998101301866906, 0.9633838159484168], 
             UndirectedEdge[25, 43] -> 
             RGBColor[
              0.7197149246002337, 0.7763484693526973, 0.8618369429212122], 
             UndirectedEdge[91, 121] -> 
             RGBColor[
              0.47334991661672554`, 0.5795402728876844, 0.9527289416842695], 
             UndirectedEdge[8, 21] -> 
             RGBColor[
              0.6472780127406362, 0.6952809535475202, 0.6586456416366252], 
             UndirectedEdge[2, 124] -> 
             RGBColor[
              0.6809775903068567, 0.749683035195514, 0.9695352725449888], 
             UndirectedEdge[80, 125] -> 
             RGBColor[
              0.8413816507496206, 0.8763589058839907, 0.9847329270304072], 
             UndirectedEdge[33, 180] -> 
             RGBColor[
              0.6545588091038398, 0.7284916175041924, 0.9672800921695242], 
             UndirectedEdge[5, 155] -> 
             RGBColor[
              0.8972783886258167, 0.7863579665614877, 0.6155329981732742], 
             UndirectedEdge[179, 192] -> 
             RGBColor[
              0.547025450029302, 0.6423209097526617, 0.9578227304629783], 
             UndirectedEdge[59, 146] -> 
             RGBColor[
              0.8644838770280143, 0.8473895479656379, 0.6373380167455187], 
             UndirectedEdge[3, 68] -> 
             RGBColor[
              0.4375024079030385, 0.5533643290403838, 0.9490982444567606], 
             UndirectedEdge[131, 157] -> 
             RGBColor[
              0.9056370197154987, 0.9264135105389952, 0.9499197276194837], 
             UndirectedEdge[85, 200] -> 
             RGBColor[
              0.7529012205483605, 0.8068914228443722, 0.9760058154684768], 
             UndirectedEdge[23, 38] -> 
             RGBColor[
              0.4493943743916887, 0.5599207237897639, 0.9508845976161148], 
             UndirectedEdge[92, 191] -> 
             RGBColor[
              0.5505910906733308, 0.6367255118402961, 0.9609083412784418], 
             UndirectedEdge[97, 153] -> 
             RGBColor[
              0.668626320784454, 0.7386524385870978, 0.9694597976528421], 
             UndirectedEdge[95, 161] -> 
             RGBColor[
              0.605050398906378, 0.6398208602643771, 0.6370460320215219], 
             UndirectedEdge[139, 196] -> 
             RGBColor[
              0.6011901255911609, 0.48838653043439983`, 0.5790641923879796], 
             UndirectedEdge[1, 94] -> 
             RGBColor[
              0.865204389866596, 0.8948644294138222, 0.9518023536608478], 
             UndirectedEdge[189, 194] -> 
             RGBColor[
              0.6646133071384537, 0.731392975404635, 0.9404251791337263], 
             UndirectedEdge[42, 76] -> 
             RGBColor[
              0.4281648218407811, 0.5406635350094948, 0.9493973919206253], 
             UndirectedEdge[84, 190] -> 
             RGBColor[
              0.7973858820776956, 0.8406473051948093, 0.9125764097067566], 
             UndirectedEdge[37, 134] -> 
             RGBColor[
              0.9688210246989785, 0.9761878117563698, 0.9341000866588206], 
             UndirectedEdge[140, 161] -> 
             RGBColor[
              0.5849101006892443, 0.5640566825374287, 0.5995638773299247], 
             UndirectedEdge[10, 51] -> 
             RGBColor[
              0.877998783058084, 0.7415958613792641, 0.6078919223287618], 
             UndirectedEdge[146, 191] -> 
             RGBColor[
              0.6226764062142178, 0.6463680140292881, 0.6183038167343442], 
             UndirectedEdge[21, 175] -> 
             RGBColor[
              0.457281395737249, 0.5665184725038321, 0.951457517531971], 
             UndirectedEdge[49, 141] -> 
             RGBColor[
              0.6463146120577657, 0.7232269439866742, 0.9656545169425483], 
             UndirectedEdge[111, 177] -> 
             RGBColor[
              0.9385549846210026, 0.9156247702737832, 0.6586060455279985], 
             UndirectedEdge[69, 191] -> 
             RGBColor[
              0.5919937925522627, 0.6697009678718474, 0.9648674346208216], 
             UndirectedEdge[111, 175] -> 
             RGBColor[
              0.7550065355700102, 0.8086134738353576, 0.9764678362840562], 
             UndirectedEdge[77, 170] -> 
             RGBColor[
              0.9468073155956376, 0.9598495635830291, 0.974925519209298], 
             UndirectedEdge[104, 154] -> 
             RGBColor[
              0.6859689580995328, 0.749890166900895, 0.9417859423289056], 
             UndirectedEdge[13, 138] -> 
             RGBColor[
              0.4811546348216927, 0.5880793431007496, 0.9527347041213858], 
             UndirectedEdge[21, 67] -> 
             RGBColor[
              0.5236094729907279, 0.6189863682923793, 0.9576227743658199], 
             UndirectedEdge[73, 197] -> 
             RGBColor[
              0.6557535265086574, 0.7202301905256197, 0.827064953230011], 
             UndirectedEdge[67, 192] -> 
             RGBColor[
              0.6965197925193806, 0.7628458227534091, 0.9703862416369493], 
             UndirectedEdge[37, 101] -> 
             RGBColor[
              0.9685993027789779, 0.9760961240444561, 0.9377745926711663], 
             UndirectedEdge[6, 44] -> 
             RGBColor[
              0.7006216699969453, 0.7583672777732874, 0.7679212585333537], 
             UndirectedEdge[75, 89] -> 
             RGBColor[
              0.7647823116591224, 0.816637281683222, 0.9770668112225912], 
             UndirectedEdge[76, 188] -> 
             RGBColor[
              0.5734692619091744, 0.6646072071705335, 0.9595647474660647], 
             UndirectedEdge[42, 71] -> 
             RGBColor[
              0.5177817130515322, 0.6118617692230117, 0.9575167513002405], 
             UndirectedEdge[6, 192] -> 
             RGBColor[
              0.8272916636778638, 0.8621756860913632, 0.7777383331301801], 
             UndirectedEdge[2, 100] -> 
             RGBColor[
              0.7390518472249783, 0.7957172380649293, 0.9751467954854696], 
             UndirectedEdge[7, 8] -> 
             RGBColor[
              0.7687020426066637, 0.79762064178758, 0.6671650815574182], 
             UndirectedEdge[69, 92] -> 
             RGBColor[
              0.8566933519417861, 0.8886059753898722, 0.9861833040824939], 
             UndirectedEdge[104, 160] -> 
             RGBColor[
              0.9167910631588313, 0.9356195554170369, 0.9618047779143803], 
             UndirectedEdge[17, 30] -> 
             RGBColor[
              0.7177925127061449, 0.7786513018913448, 0.9732506412859667], 
             UndirectedEdge[88, 164] -> 
             RGBColor[
              0.5012914009868188, 0.6039869761051871, 0.9544416005732141], 
             UndirectedEdge[43, 60] -> 
             RGBColor[
              0.7210047841072293, 0.7768818594067173, 0.8404606328408927], 
             UndirectedEdge[149, 197] -> 
             RGBColor[
              0.7471913038345779, 0.7981821248216482, 0.8332358021679674], 
             UndirectedEdge[167, 197] -> 
             RGBColor[
              0.7954318605837941, 0.8373459820029778, 0.8370334755062476], 
             UndirectedEdge[54, 127] -> 
             RGBColor[
              0.9113054858308056, 0.9299214980995442, 0.9071298426055663], 
             UndirectedEdge[107, 147] -> 
             RGBColor[
              0.8040836528794573, 0.8459083251621268, 0.9057239483634636], 
             UndirectedEdge[78, 113] -> 
             RGBColor[
              0.687543745636255, 0.7558336667078283, 0.9694915931695665], 
             UndirectedEdge[81, 87] -> 
             RGBColor[
              0.2939040786248942, 0.4169840201352121, 0.9403877618369569], 
             UndirectedEdge[83, 179] -> 
             RGBColor[
              0.5704084372419341, 0.6605878770804547, 0.9601533281018941], 
             UndirectedEdge[82, 198] -> 
             RGBColor[
              0.5987591964216903, 0.6703815051036905, 0.9564573805994907], 
             UndirectedEdge[30, 107] -> 
             RGBColor[
              0.7479146326654962, 0.8031057958603862, 0.9756219649101279], 
             UndirectedEdge[47, 134] -> 
             RGBColor[
              0.9721159153407648, 0.9786451358021258, 0.9285226962473865], 
             UndirectedEdge[5, 142] -> 
             RGBColor[
              0.7484991340241707, 0.6688035813291635, 0.6013728178492554], 
             UndirectedEdge[169, 190] -> 
             RGBColor[
              0.6728247215661772, 0.743803179000917, 0.9683881837264166], 
             UndirectedEdge[121, 152] -> 
             RGBColor[
              0.4716249956746562, 0.5780462330647114, 0.9526190312471284], 
             UndirectedEdge[31, 64] -> 
             RGBColor[
              0.444646894046855, 0.5581874862934173, 0.9499306487390907], 
             UndirectedEdge[105, 134] -> 
             RGBColor[
              0.7469275708975519, 0.8001734118072363, 0.9291063268700781], 
             UndirectedEdge[83, 192] -> 
             RGBColor[
              0.6839630314123258, 0.7530363855416589, 0.9691347010394022], 
             UndirectedEdge[77, 112] -> 
             RGBColor[
              0.9439604982356364, 0.9577264118571758, 0.9797444384308981], 
             UndirectedEdge[195, 196] -> 
             RGBColor[
              0.7159542891394803, 0.5849287609214617, 0.5871672888016026], 
             UndirectedEdge[92, 171] -> 
             RGBColor[
              0.7644202838240894, 0.815890202623495, 0.9771539280440348], 
             UndirectedEdge[166, 183] -> 
             RGBColor[
              0.8754326570842386, 0.9027036875424302, 0.9451710304980552], 
             UndirectedEdge[139, 195] -> 
             RGBColor[
              0.4439119487567449, 0.5560552314110598, 0.9502970801265136], 
             UndirectedEdge[177, 190] -> 
             RGBColor[
              0.7872693772981432, 0.7961781691641661, 0.6440844786996376], 
             UndirectedEdge[29, 149] -> 
             RGBColor[
              0.49058872824005034`, 0.597321056212446, 0.9530400882542328], 
             UndirectedEdge[119, 155] -> 
             RGBColor[
              0.661901379805262, 0.7326253560435828, 0.9691244094234921], 
             UndirectedEdge[12, 162] -> 
             RGBColor[
              0.6505008047556643, 0.7151649082698175, 0.8018735743186363], 
             UndirectedEdge[85, 173] -> 
             RGBColor[
              0.8782514418804841, 0.9051547834032398, 0.958058332226762], 
             UndirectedEdge[92, 141] -> 
             RGBColor[
              0.7158273259918897, 0.777530804428205, 0.972582894634257], 
             UndirectedEdge[5, 29] -> 
             RGBColor[
              0.6929928053893085, 0.6237410432117734, 0.5970031563327378], 
             UndirectedEdge[51, 87] -> 
             RGBColor[
              0.5336363412319399, 0.44563982312221306`, 0.5810231196805732], 
             UndirectedEdge[145, 153] -> 
             RGBColor[
              0.8185092195387189, 0.8586673768049067, 0.982406355811459], 
             UndirectedEdge[118, 191] -> 
             RGBColor[
              0.4626122752656274, 0.567949438414235, 0.9521711277636978], 
             UndirectedEdge[117, 164] -> 
             RGBColor[
              0.6724020765167493, 0.7383436613843629, 0.9439052345154204], 
             UndirectedEdge[145, 185] -> 
             RGBColor[
              0.8522009581680058, 0.8269691086069955, 0.6280999089236342], 
             UndirectedEdge[99, 137] -> 
             RGBColor[
              0.8319823455519133, 0.8691691896137579, 0.9837554661172963], 
             UndirectedEdge[48, 176] -> 
             RGBColor[
              0.6147243743034583, 0.6967833181188965, 0.9637127003381529], 
             UndirectedEdge[50, 144] -> 
             RGBColor[
              0.6206747953827245, 0.6972822788385925, 0.966329311925312], 
             UndirectedEdge[3, 53] -> 
             RGBColor[
              0.6302882096577461, 0.7070351886549645, 0.9662852873283967], 
             UndirectedEdge[169, 177] -> 
             RGBColor[
              0.8524556287021283, 0.8476340384294598, 0.6502179897203779], 
             UndirectedEdge[20, 135] -> 
             RGBColor[
              0.9600666358603486, 0.9697383429263062, 0.9524809485857221], 
             UndirectedEdge[166, 170] -> 
             RGBColor[
              0.8575512429695293, 0.8893677581738085, 0.9754396003745327], 
             UndirectedEdge[17, 42] -> 
             RGBColor[
              0.4257404313653027, 0.5386953056039553, 0.9492065350215608], 
             UndirectedEdge[129, 195] -> 
             RGBColor[
              0.7407798498683873, 0.692281807062818, 0.6076043523570409], 
             UndirectedEdge[74, 93] -> 
             RGBColor[
              0.5900850210017969, 0.6780966289333413, 0.9608728008873669], 
             UndirectedEdge[37, 45] -> 
             RGBColor[
              0.7334306778813474, 0.7903423888033694, 0.9596829903723586], 
             UndirectedEdge[49, 92] -> 
             RGBColor[
              0.7457779361287302, 0.8013266589167901, 0.9752958330484056], 
             UndirectedEdge[163, 177] -> 
             RGBColor[
              0.9324981691274061, 0.9107952300070662, 0.6580283410592364], 
             UndirectedEdge[6, 45] -> 
             RGBColor[
              0.7539466765707203, 0.8029100445618352, 0.7717735090459643], 
             UndirectedEdge[6, 166] -> 
             RGBColor[
              0.8807066775714082, 0.9039039009141416, 0.7830622425234035], 
             UndirectedEdge[65, 127] -> 
             RGBColor[
              0.90682986604794, 0.9263527603721498, 0.9067029539952436], 
             UndirectedEdge[15, 59] -> 
             RGBColor[
              0.5924507655641317, 0.6770398130424464, 0.9626752277613189], 
             UndirectedEdge[100, 136] -> 
             RGBColor[
              0.8530089069281888, 0.8857624602751686, 0.9858068378329691], 
             UndirectedEdge[83, 183] -> 
             RGBColor[
              0.8454006304033261, 0.8792424400474449, 0.9421777187437477], 
             UndirectedEdge[53, 119] -> 
             RGBColor[
              0.6358523412956929, 0.7118545598183663, 0.9666398288761983], 
             UndirectedEdge[5, 68] -> 
             RGBColor[
              0.67844354836154, 0.6119163107216905, 0.5958613747543442], 
             UndirectedEdge[49, 54] -> 
             RGBColor[
              0.7548872789542724, 0.8085522670190481, 0.9761747569756511], 
             UndirectedEdge[153, 185] -> 
             RGBColor[
              0.918318887869089, 0.8791434243143652, 0.6345512743942882], 
             UndirectedEdge[101, 144] -> 
             RGBColor[
              0.6728454655656251, 0.7376244754623342, 0.9276553897042878], 
             UndirectedEdge[19, 102] -> 
             RGBColor[
              0.858102086226029, 0.880312021913048, 0.6920590053523852], 
             UndirectedEdge[102, 172] -> 
             RGBColor[
              0.6495659934463958, 0.7250818143451963, 0.9664470137649728], 
             UndirectedEdge[102, 140] -> 
             RGBColor[
              0.8284954400284792, 0.7726156296439504, 0.6178018763266869], 
             UndirectedEdge[71, 107] -> 
             RGBColor[
              0.6820667887342489, 0.7512147764436481, 0.9691783320095986], 
             UndirectedEdge[5, 168] -> 
             RGBColor[
              0.6642833309846334, 0.5996514421430335, 0.5949590982244763], 
             UndirectedEdge[79, 122] -> 
             RGBColor[
              0.2947730673269235, 0.4189521735408819, 0.9403986283857603], 
             UndirectedEdge[136, 198] -> 
             RGBColor[
              0.527277947080499, 0.6137971470960165, 0.9593313106396701], 
             UndirectedEdge[97, 135] -> 
             RGBColor[
              0.7010501072633277, 0.7641510478605884, 0.960236084813447], 
             UndirectedEdge[19, 164] -> 
             RGBColor[
              0.6837618574558217, 0.738055925872535, 0.6780016097886818], 
             UndirectedEdge[118, 139] -> 
             RGBColor[
              0.4842404022279364, 0.5887956867150982, 0.9534718837117584], 
             UndirectedEdge[26, 137] -> 
             RGBColor[
              0.812099775891064, 0.8536367750815762, 0.9817737573866803], 
             UndirectedEdge[142, 168] -> 
             RGBColor[
              0.5087349492538789, 0.6112710195094712, 0.9546846821273836], 
             UndirectedEdge[3, 194] -> 
             RGBColor[
              0.6957770525085082, 0.7583854453087907, 0.9424109054316882], 
             UndirectedEdge[65, 195] -> 
             RGBColor[
              0.6916171042266359, 0.7577708610030851, 0.9707642289570483], 
             UndirectedEdge[73, 107] -> 
             RGBColor[
              0.4682557169059694, 0.5754714840828236, 0.9523094196342525], 
             UndirectedEdge[162, 172] -> 
             RGBColor[
              0.7831624291122182, 0.8270817674402524, 0.8112061026330437], 
             UndirectedEdge[68, 140] -> 
             RGBColor[
              0.6911686226175447, 0.6624186901746925, 0.6061029426051221], 
             UndirectedEdge[38, 165] -> 
             RGBColor[
              0.7338093119259383, 0.7916426556996592, 0.9745251301297753], 
             UndirectedEdge[86, 92] -> 
             RGBColor[
              0.9049891647370638, 0.92385087626077, 0.8599633204738457], 
             UndirectedEdge[90, 115] -> 
             RGBColor[
              0.6672332369861045, 0.7387802733472895, 0.9682785639919411], 
             UndirectedEdge[11, 70] -> 
             RGBColor[
              0.9004619881057789, 0.9212544879353542, 0.9021482211875141], 
             UndirectedEdge[54, 123] -> 
             RGBColor[
              0.6143354593162289, 0.6933862850566858, 0.9651911915619369], 
             UndirectedEdge[107, 176] -> 
             RGBColor[
              0.5606435756777007, 0.6541947372972429, 0.9585550624638863], 
             UndirectedEdge[30, 76] -> 
             RGBColor[
              0.7202169031816232, 0.7806195312968844, 0.9734414981850312], 
             UndirectedEdge[129, 191] -> 
             RGBColor[
              0.6043875593577588, 0.5748933282748928, 0.5982004999953574], 
             UndirectedEdge[7, 125] -> 
             RGBColor[
              0.7016055588753296, 0.7657276507742343, 0.9717258370310407], 
             UndirectedEdge[3, 155] -> 
             RGBColor[
              0.6563372481673152, 0.727805984880181, 0.9687698678756906], 
             UndirectedEdge[54, 118] -> 
             RGBColor[
              0.736421177480693, 0.7940800540345178, 0.9743659211526157], 
             UndirectedEdge[4, 171] -> 
             RGBColor[
              0.5549854227197126, 0.6469657508629436, 0.9592821071114621], 
             UndirectedEdge[167, 189] -> 
             RGBColor[
              0.47777910952632735`, 0.5843834225592658, 0.9527329826105779], 
             UndirectedEdge[42, 81] -> 
             RGBColor[
              0.35022931644586286`, 0.4761854163113922, 0.9435954008051388], 
             UndirectedEdge[5, 129] -> 
             RGBColor[
              0.9134655515933178, 0.6945750780951201, 0.24922788106014673`], 
             UndirectedEdge[115, 133] -> 
             RGBColor[
              0.45065719754960076`, 0.5617288048779484, 0.9507735274397662], 
             UndirectedEdge[92, 146] -> 
             RGBColor[
              0.8873759656037412, 0.8652730215473129, 0.6396196861960165], 
             UndirectedEdge[65, 151] -> 
             RGBColor[
              0.8882843613232918, 0.8551947081122511, 0.6316865544402116], 
             UndirectedEdge[45, 156] -> 
             RGBColor[
              0.7542492972079661, 0.8035573195052641, 0.8047118978520775], 
             UndirectedEdge[74, 172] -> 
             RGBColor[
              0.5845844001060037, 0.6736309770899889, 0.9604397718610118], 
             UndirectedEdge[31, 138] -> 
             RGBColor[
              0.39036560310320173`, 0.5125367978874611, 0.9460947289363548], 
             UndirectedEdge[116, 198] -> 
             RGBColor[
              0.5146755490037169, 0.6039520579366615, 0.9580752213754824], 
             UndirectedEdge[42, 142] -> 
             RGBColor[
              0.44226411396767673`, 0.5521099755239808, 0.9505073398442634], 
             UndirectedEdge[10, 129] -> 
             RGBColor[
              0.8952677355419992, 0.8146361143708082, 0.6220235667351612], 
             UndirectedEdge[3, 141] -> 
             RGBColor[
              0.5192646183794238, 0.6197555650491008, 0.9555312759397904], 
             UndirectedEdge[161, 162] -> 
             RGBColor[
              0.6175043121166113, 0.6804835024077054, 0.7999944728767786], 
             UndirectedEdge[6, 77] -> 
             RGBColor[
              0.9699627501975165, 0.9743857063233623, 0.7825481613581688], 
             UndirectedEdge[98, 113] -> 
             RGBColor[
              0.8472955838043944, 0.880148454218308, 0.9162548593599757], 
             UndirectedEdge[3, 139] -> 
             RGBColor[
              0.3756565100231739, 0.4997965207620553, 0.9451574785320358], 
             UndirectedEdge[34, 138] -> 
             RGBColor[
              0.46111984561945146`, 0.5718141986694021, 0.9511574921255344], 
             UndirectedEdge[22, 72] -> 
             RGBColor[
              0.7248619422266294, 0.7829492741260085, 0.9472974373584909], 
             UndirectedEdge[34, 40] -> 
             RGBColor[
              0.7601515015845128, 0.8073427500526766, 0.7227048848667801], 
             UndirectedEdge[41, 74] -> 
             RGBColor[
              0.68351825101032, 0.7520021970518638, 0.9695598855183334], 
             UndirectedEdge[141, 146] -> 
             RGBColor[
              0.7879126415327768, 0.787173306617197, 0.6299783700901593], 
             UndirectedEdge[90, 111] -> 
             RGBColor[
              0.8398912307120854, 0.8755779405539957, 0.9844826433675868], 
             UndirectedEdge[66, 82] -> 
             RGBColor[
              0.9549713984916567, 0.9238800297349312, 0.6437450660759698], 
             UndirectedEdge[119, 151] -> 
             RGBColor[
              0.6926520623060959, 0.698581969521685, 0.6145374419766237], 
             UndirectedEdge[4, 139] -> 
             RGBColor[
              0.36278435653126295`, 0.4886473083806081, 0.9443372762939296], 
             UndirectedEdge[165, 175] -> 
             RGBColor[
              0.7385582384775466, 0.7954980482109579, 0.974898983023809], 
             UndirectedEdge[127, 139] -> 
             RGBColor[
              0.6591247105780489, 0.7246371307801246, 0.886235805164709], 
             UndirectedEdge[85, 117] -> 
             RGBColor[
              0.8765527041828819, 0.9038878676097957, 0.960933852047053], 
             UndirectedEdge[141, 155] -> 
             RGBColor[
              0.7534366317088167, 0.8074815093291692, 0.9761801704643], 
             UndirectedEdge[168, 189] -> 
             RGBColor[
              0.3921784451560774, 0.5141069905575711, 0.9462102416289309], 
             UndirectedEdge[24, 175] -> 
             RGBColor[
              0.4825056083728978, 0.588366417683041, 0.953064782056219], 
             UndirectedEdge[106, 176] -> 
             RGBColor[
              0.4048113699512576, 0.5237262323435599, 0.9473748601936376], 
             UndirectedEdge[40, 53] -> 
             RGBColor[
              0.9157515997169727, 0.9308115900714783, 0.736968122164069], 
             UndirectedEdge[27, 155] -> 
             RGBColor[
              0.7258746238294724, 0.7851054296784123, 0.9740103882410764], 
             UndirectedEdge[33, 77] -> 
             RGBColor[
              0.7427666812676392, 0.7981545607456387, 0.9666615361781967], 
             UndirectedEdge[67, 137] -> 
             RGBColor[
              0.8070898800885493, 0.8497230064040334, 0.9812744177932237], 
             UndirectedEdge[68, 129] -> 
             RGBColor[
              0.6878615841999325, 0.6493073848540847, 0.6034420218681427], 
             UndirectedEdge[137, 192] -> 
             RGBColor[
              0.7711501317688625, 0.8216466018644901, 0.9776922795567606], 
             UndirectedEdge[58, 128] -> 
             RGBColor[
              0.8485945289826238, 0.8821102591986236, 0.9854208977952834], 
             UndirectedEdge[55, 90] -> 
             RGBColor[
              0.7080750639028099, 0.7718728885814594, 0.971537963098299], 
             UndirectedEdge[26, 82] -> 
             RGBColor[
              0.844528947897121, 0.8792143625904631, 0.9751398980765505], 
             UndirectedEdge[43, 165] -> 
             RGBColor[
              0.6621219806493943, 0.733270225155947, 0.9689295588046413], 
             UndirectedEdge[123, 199] -> 
             RGBColor[
              0.6909679534282798, 0.7527448459308062, 0.9076237670179044], 
             UndirectedEdge[34, 45] -> 
             RGBColor[
              0.5205505290990285, 0.6216453959135114, 0.9553987909715445], 
             UndirectedEdge[133, 178] -> 
             RGBColor[
              0.6347181559115258, 0.7076188865601274, 0.968065231761935], 
             UndirectedEdge[29, 189] -> 
             RGBColor[
              0.4208879195607525, 0.538196591626311, 0.9482542997371923], 
             UndirectedEdge[91, 164] -> 
             RGBColor[
              0.34635612352607315`, 0.4744179986585121, 0.943290483813755], 
             UndirectedEdge[116, 124] -> 
             RGBColor[
              0.7823322519332849, 0.8298831682463983, 0.9789392256283005], 
             UndirectedEdge[80, 113] -> 
             RGBColor[
              0.7722528336239918, 0.8221478744304453, 0.9778977636884324], 
             UndirectedEdge[10, 75] -> 
             RGBColor[
              0.8725375723425016, 0.9012017920571918, 0.9877046066451556], 
             UndirectedEdge[74, 180] -> 
             RGBColor[
              0.68351825101032, 0.7520021970518638, 0.9695598855183334], 
             UndirectedEdge[27, 149] -> 
             RGBColor[
              0.5302396738093228, 0.6295114800803232, 0.9561615559356453], 
             UndirectedEdge[4, 49] -> 
             RGBColor[
              0.5363430750243534, 0.6324022071562387, 0.9574240121158328], 
             UndirectedEdge[9, 152] -> 
             RGBColor[
              0.4829203511553791, 0.587016677026367, 0.9536447341825965], 
             UndirectedEdge[19, 85] -> 
             RGBColor[
              0.8879124851219542, 0.9036001320979677, 0.6950302273203146], 
             UndirectedEdge[189, 197] -> 
             RGBColor[
              0.67749049515528, 0.7390576602355132, 0.828450013650927], 
             UndirectedEdge[69, 195] -> 
             RGBColor[
              0.7283860830628912, 0.7870894466597727, 0.9742712869825052], 
             UndirectedEdge[75, 191] -> 
             RGBColor[
              0.5816573961582612, 0.6614590059612764, 0.9638815399053517], 
             UndirectedEdge[73, 75] -> 
             RGBColor[
              0.5968935339186415, 0.6767688344861477, 0.9647750039536795], 
             UndirectedEdge[68, 188] -> 
             RGBColor[
              0.5175129683734393, 0.6191663770775464, 0.9551632522947914], 
             UndirectedEdge[4, 123] -> 
             RGBColor[
              0.39579125538630977`, 0.5172362251938764, 0.9464404467021186], 
             UndirectedEdge[7, 84] -> 
             RGBColor[
              0.7723703794338214, 0.8203385932129608, 0.9106070977038253], 
             UndirectedEdge[171, 195] -> 
             RGBColor[
              0.6361130149451946, 0.7143736738933955, 0.965241910944046], 
             UndirectedEdge[62, 167] -> 
             RGBColor[
              0.7087285192264073, 0.7716830954439726, 0.9720878027684337], 
             UndirectedEdge[91, 152] -> 
             RGBColor[
              0.3121745678604679, 0.44481165315590604`, 0.9411124653123055], 
             UndirectedEdge[38, 90] -> 
             RGBColor[
              0.6799391549225764, 0.7490955099231973, 0.9692788203952112], 
             UndirectedEdge[3, 118] -> 
             RGBColor[
              0.530749127042685, 0.6290792065531554, 0.9564353785309037], 
             UndirectedEdge[143, 181] -> 
             RGBColor[
              0.8235289673242936, 0.8627311332318193, 0.9828689176211383], 
             UndirectedEdge[20, 50] -> 
             RGBColor[
              0.9252722644690073, 0.9423494935914273, 0.9614785529199197], 
             UndirectedEdge[128, 136] -> 
             RGBColor[
              0.8119399896272211, 0.8530152204054398, 0.9818896478381475], 
             UndirectedEdge[19, 161] -> 
             RGBColor[
              0.614516746886794, 0.6717530748065262, 0.6738210063556229], 
             UndirectedEdge[19, 140] -> 
             RGBColor[
              0.9591043104644845, 0.8658851551378273, 0.3363874986736022], 
             UndirectedEdge[39, 159] -> 
             RGBColor[
              0.7741804927640796, 0.8232570281063611, 0.9583877590857998], 
             UndirectedEdge[87, 154] -> 
             RGBColor[
              0.2907380230099858, 0.41424174189216056`, 0.9401860235728079], 
             UndirectedEdge[104, 143] -> 
             RGBColor[
              0.9358103021222872, 0.9507849803030082, 0.9636188499053899], 
             UndirectedEdge[6, 183] -> 
             RGBColor[
              0.988729262668864, 0.9883817405971493, 0.7507813508345256], 
             UndirectedEdge[17, 89] -> 
             RGBColor[
              0.6060223746870989, 0.6908854373108566, 0.9622299032790029], 
             UndirectedEdge[131, 176] -> 
             RGBColor[
              0.7413158981369201, 0.7958021075117602, 0.9350418105002225], 
             UndirectedEdge[44, 143] -> 
             RGBColor[
              0.6547358954516687, 0.7260158560831307, 0.968853408252709], 
             UndirectedEdge[140, 173] -> 
             RGBColor[
              0.9494432672230144, 0.8674398064430993, 0.5994156035800496], 
             UndirectedEdge[123, 195] -> 
             RGBColor[
              0.47691884761179165`, 0.5846441482243281, 0.9524002505347026], 
             UndirectedEdge[96, 125] -> 
             RGBColor[
              0.6691644761600525, 0.7393905183718505, 0.9691719561640924], 
             UndirectedEdge[95, 159] -> 
             RGBColor[
              0.7800418969650476, 0.7939963845079435, 0.6489924197243727], 
             UndirectedEdge[171, 191] -> 
             RGBColor[
              0.4997207244345661, 0.5969851951054702, 0.9558380585823625], 
             UndirectedEdge[124, 187] -> 
             RGBColor[
              0.7830910412300529, 0.8304759402120456, 0.9790148546541132], 
             UndirectedEdge[54, 191] -> 
             RGBColor[
              0.5597004334988731, 0.6439511199425543, 0.9617872652056874], 
             UndirectedEdge[24, 55] -> 
             RGBColor[
              0.5058925908015232, 0.6072884038300044, 0.954950071865273], 
             UndirectedEdge[61, 126] -> 
             RGBColor[
              0.905070487162301, 0.927142655252052, 0.9908076251031441], 
             UndirectedEdge[46, 101] -> 
             RGBColor[
              0.9798868634699647, 0.958460018193919, 0.6352802493136349], 
             UndirectedEdge[158, 176] -> 
             RGBColor[
              0.6775694086758153, 0.7461532695606956, 0.9699035472925932], 
             UndirectedEdge[91, 200] -> 
             RGBColor[
              0.5162939581586921, 0.6132349109393064, 0.9569090898725356], 
             UndirectedEdge[29, 129] -> 
             RGBColor[
              0.702410841227701, 0.6611321173441675, 0.6045838034465364], 
             UndirectedEdge[37, 47] -> 
             RGBColor[
              0.9562661764190742, 0.9669039664976851, 0.9589141351012285], 
             UndirectedEdge[25, 38] -> 
             RGBColor[
              0.7914022558767777, 0.8347208998964095, 0.8674325142463462], 
             UndirectedEdge[95, 173] -> 
             RGBColor[
              0.9695835654401481, 0.9432039841700477, 0.6368977582716469], 
             UndirectedEdge[86, 174] -> 
             RGBColor[
              0.6584248100922501, 0.7227667233780992, 0.8397256410451983], 
             UndirectedEdge[4, 146] -> 
             RGBColor[
              0.6779411044993644, 0.6963485697867615, 0.6217478652634438], 
             UndirectedEdge[114, 186] -> 
             RGBColor[
              0.7669044118270611, 0.8135404936498561, 0.7818727605688538], 
             UndirectedEdge[155, 199] -> 
             RGBColor[
              0.9386417927173742, 0.9521653932356636, 0.9291329859533703], 
             UndirectedEdge[114, 194] -> 
             RGBColor[
              0.7545137303018744, 0.8069163970112434, 0.9468011552965827], 
             UndirectedEdge[59, 186] -> 
             RGBColor[
              0.8818383530704341, 0.9049013077448327, 0.7922524599479279], 
             UndirectedEdge[99, 193] -> 
             RGBColor[
              0.8850304665766979, 0.9001893992605912, 0.6930500794954704], 
             UndirectedEdge[109, 136] -> 
             RGBColor[
              0.8410271874349116, 0.6937044136233121, 0.6006694411335511], 
             UndirectedEdge[50, 134] -> 
             RGBColor[
              0.932278371517768, 0.9474950967251551, 0.9460570760383484], 
             UndirectedEdge[112, 183] -> 
             RGBColor[
              0.962727010706984, 0.9717224461309628, 0.9479776279072549], 
             UndirectedEdge[42, 73] -> 
             RGBColor[
              0.3039706412232527, 0.43611847686218713`, 0.9406478389248945], 
             UndirectedEdge[42, 147] -> 
             RGBColor[
              0.6397985771967405, 0.7065553179414903, 0.8940623676541055], 
             UndirectedEdge[87, 131] -> 
             RGBColor[
              0.5802096359629048, 0.645555773611334, 0.9248569677138763], 
             UndirectedEdge[1, 11] -> 
             RGBColor[
              0.8931346460878744, 0.9166837578516944, 0.9545861805779006], 
             UndirectedEdge[30, 81] -> 
             RGBColor[
              0.642281397786705, 0.7161414125987817, 0.9676395070695447], 
             UndirectedEdge[154, 188] -> 
             RGBColor[
              0.4923677008993478, 0.5973868102293793, 0.9535610180864292], 
             UndirectedEdge[83, 156] -> 
             RGBColor[
              0.8509772715277415, 0.8810899283625853, 0.8130073195752092], 
             UndirectedEdge[5, 107] -> 
             RGBColor[
              0.762097571381148, 0.6798434053781796, 0.602443336650714], 
             UndirectedEdge[93, 180] -> 
             RGBColor[
              0.6760732429028774, 0.7459580040764486, 0.9689737872081521], 
             UndirectedEdge[10, 17] -> 
             RGBColor[
              0.7137776353704781, 0.7754499476848262, 0.9728676987015674], 
             UndirectedEdge[75, 141] -> 
             RGBColor[
              0.7468936314768202, 0.8022642985491852, 0.9755560932611669], 
             UndirectedEdge[123, 141] -> 
             RGBColor[
              0.5057627924197221, 0.6080609620243118, 0.9546709515288341], 
             UndirectedEdge[40, 119] -> 
             RGBColor[
              0.7131927565350957, 0.7686758131800282, 0.7191583497346549], 
             UndirectedEdge[16, 80] -> 
             RGBColor[
              0.7915024255987015, 0.8371858019834062, 0.9798163831188069], 
             UndirectedEdge[88, 180] -> 
             RGBColor[
              0.6966382583177144, 0.7626536100336001, 0.9705927405537418], 
             UndirectedEdge[24, 41] -> 
             RGBColor[
              0.5673571516625433, 0.6553049859225976, 0.9610762848729212], 
             UndirectedEdge[4, 119] -> 
             RGBColor[
              0.4148572129839582, 0.5337501993820672, 0.9476553126608764], 
             UndirectedEdge[99, 136] -> 
             RGBColor[
              0.7929302682167789, 0.8381624191149708, 0.9799955368473461], 
             UndirectedEdge[10, 194] -> 
             RGBColor[
              0.9185203769156911, 0.9369984632657855, 0.9619697214042863], 
             UndirectedEdge[96, 102] -> 
             RGBColor[
              0.6101092576169564, 0.6930490586931648, 0.9633408349856936], 
             UndirectedEdge[9, 88] -> 
             RGBColor[
              0.639580549558194, 0.718079694296015, 0.9649057613791967], 
             UndirectedEdge[55, 108] -> 
             RGBColor[
              0.6155123439372683, 0.6986750554200546, 0.9629187137751334], 
             UndirectedEdge[62, 197] -> 
             RGBColor[
              0.90843990485536, 0.9263573331202201, 0.8478048338087827], 
             UndirectedEdge[147, 168] -> 
             RGBColor[
              0.7062694124829426, 0.7657163619269807, 0.8982397099372257], 
             UndirectedEdge[51, 106] -> 
             RGBColor[
              0.5984144490091823, 0.5137257215653466, 0.5847121370878645], 
             UndirectedEdge[123, 155] -> 
             RGBColor[
              0.6428354222076136, 0.7161113818553919, 0.9679095434647343], 
             UndirectedEdge[75, 142] -> 
             RGBColor[
              0.7351870066630656, 0.7927603331479413, 0.9746345048730485], 
             UndirectedEdge[31, 182] -> 
             RGBColor[
              0.5442771900316172, 0.6381451751461444, 0.958407482481153], 
             UndirectedEdge[65, 140] -> 
             RGBColor[
              0.8770278802075713, 0.8105665114883891, 0.622629325510932]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 71 -> 
             RGBColor[
              0.743985950461127, 0.7999267460936631, 0.9751172246641171], 10 -> 
             RGBColor[
              0.8676518836522882, 0.8973060765141021, 0.9872386052963773], 68 -> 
             RGBColor[
              0.45283958096815463`, 0.5666486174806552, 0.9500755155623402], 
             155 -> RGBColor[
              0.8905092614967081, 0.9155319291602494, 0.9894187624002002], 
             132 -> RGBColor[
              0.6074117124126394, 0.6921632175792161, 0.9622368215049905], 26 -> 
             RGBColor[
              0.7424793324440966, 0.7987497646480379, 0.9749670590603253], 29 -> 
             RGBColor[
              0.4819380950236918, 0.5902980824608208, 0.9523590787191275], 
             113 -> RGBColor[
              0.7073460186249579, 0.771303352869452, 0.9714652986783181], 50 -> 
             RGBColor[
              0.879885979414867, 0.9070612123894997, 0.9884055042717184], 173 -> 
             RGBColor[
              0.969388870179094, 0.9766908500174689, 0.9367008375121952], 192 -> 
             RGBColor[
              0.6605800441996937, 0.7347694182138658, 0.9668041034004863], 
             165 -> RGBColor[
              0.8773130906229839, 0.9050096607060578, 0.9881600998419036], 92 -> 
             RGBColor[
              0.8152906500628542, 0.8556305193583209, 0.9822242107401141], 11 -> 
             RGBColor[
              0.8113509160570009, 0.852552769209861, 0.9818315348733182], 137 -> 
             RGBColor[
              0.8817202193380314, 0.9085237855151145, 0.9885804557130351], 
             120 -> RGBColor[
              0.6809831408403968, 0.7507084723788607, 0.9688376933958529], 51 -> 
             RGBColor[
              0.8883456824638799, 0.5858856462444262, 0.22854523936114635`], 
             72 -> RGBColor[
              0.48353076797913197`, 0.5915910861151461, 0.9524844597683331], 
             64 -> RGBColor[
              0.5035912849135593, 0.6078771174785035, 0.954063697145506], 41 -> 
             RGBColor[
              0.7695064729114005, 0.8198635721949711, 0.9776608718391185], 
             103 -> RGBColor[
              0.835018406651975, 0.8712850277661878, 0.9841259951278386], 162 -> 
             RGBColor[
              0.9946860871216686, 0.9910424026092832, 0.6629915607416119], 
             196 -> RGBColor[
              0.8732324659738964, 0.5172600599448016, 0.21593440106306858`], 
             179 -> RGBColor[
              0.4334708558589104, 0.5498724012914576, 0.9488413575254703], 
             160 -> RGBColor[
              0.8641932561385686, 0.8945482608166049, 0.9869087183165656], 
             123 -> RGBColor[
              0.395161582918519, 0.5166908345505344, 0.9464003245292685], 150 -> 
             RGBColor[
              0.7063479591048525, 0.7705236611868124, 0.9713658214327505], 
             188 -> RGBColor[
              0.582186355778724, 0.6716841366744375, 0.9602509890272426], 46 -> 
             RGBColor[
              0.9755464071592613, 0.9291744307508548, 0.35950283879760003`], 
             182 -> RGBColor[
              0.7028518768830838, 0.7677924951839576, 0.9710173646296305], 6 -> 
             RGBColor[
              0.9940032831560337, 0.9895819539688607, 0.5886725628598739], 
             131 -> RGBColor[
              0.9814922719258095, 0.9857175472226678, 0.9162129354277524], 45 -> 
             RGBColor[
              0.513890069985407, 0.6162381351548097, 0.9548744552320546], 195 -> 
             RGBColor[
              0.5586761123050643, 0.6525974618981217, 0.9584001765401367], 
             148 -> RGBColor[
              0.680732835031234, 0.7505129315783482, 0.9688127452520364], 161 -> 
             RGBColor[
              0.24032253711155382`, 0.3699246022061277, 0.9369973850119453], 
             1 -> RGBColor[
              0.974918376118748, 0.9808147464935277, 0.9273408262824829], 101 -> 
             RGBColor[
              0.9842273197806679, 0.9877456056369832, 0.9110576598296699], 12 -> 
             RGBColor[
              0.30631552238966, 0.43928741393035164`, 0.9407555878956606], 39 -> 
             RGBColor[
              0.9580554522992663, 0.9682384055194618, 0.9558853577539527], 48 -> 
             RGBColor[
              0.7283092242588859, 0.7876799684369403, 0.9735547151036132], 77 -> 
             RGBColor[
              0.9459222172389993, 0.9591894586778638, 0.9764237598564638], 56 -> 
             RGBColor[
              0.7017624172554945, 0.766941401042685, 0.9709087774755314], 110 -> 
             RGBColor[
              0.27294721381846143`, 0.4042152059490631, 0.9388553120865196], 
             73 -> RGBColor[
              0.316363806804568, 0.448440161372014, 0.941379399913425], 37 -> 
             RGBColor[
              0.9529712857772878, 0.964446642451929, 0.9644915255126626], 130 -> 
             RGBColor[
              0.6656983254729225, 0.7387678584448905, 0.9673142458447438], 
             107 -> RGBColor[
              0.6201476270073708, 0.7025028067936332, 0.96323943935508], 59 -> 
             RGBColor[
              0.7695064729114005, 0.8198635721949711, 0.9776608718391185], 47 -> 
             RGBColor[
              0.9595610670608605, 0.969361290543441, 0.9533367446897943], 159 -> 
             RGBColor[
              0.5903055332288929, 0.6782756506932606, 0.9608901604176469], 55 -> 
             RGBColor[
              0.6465773511893601, 0.7238304080097846, 0.9654084458238222], 49 -> 
             RGBColor[
              0.6762652221946062, 0.7470227984752593, 0.968367455356697], 82 -> 
             RGBColor[
              0.9465785633501452, 0.9596789605328884, 0.9753127370927758], 
             199 -> RGBColor[
              0.9867743239380404, 0.9887988573110779, 0.8688472095065404], 89 -> 
             RGBColor[
              0.6521413622855295, 0.7281770557661628, 0.9659630144512484], 
             144 -> RGBColor[
              0.36146361135058214`, 0.4875033452876853, 0.9442531195789058], 
             78 -> RGBColor[
              0.6677414726475519, 0.7403639805462046, 0.9675178876608149], 42 -> 
             RGBColor[
              0.2915774756419373, 0.4237967923523603, 0.939916277936364], 154 -> 
             RGBColor[
              0.4025490460199716, 0.5230894837843211, 0.9468710471456159], 
             168 -> RGBColor[
              0.4245191462143416, 0.5421188803233411, 0.9482709625026043], 
             121 -> RGBColor[
              0.6328003444309138, 0.7127748527964897, 0.9642355076190924], 
             128 -> 
             RGBColor[
              0.8202639145866796, 0.8595201962933392, 0.9827186985031602], 
             115 -> RGBColor[
              0.5648936973559493, 0.6576451775414447, 0.9588896476111067], 61 -> 
             RGBColor[
              0.8934787620775132, 0.9178997283184375, 0.9897019960165019], 93 -> 
             RGBColor[
              0.5826400128943543, 0.6720524359579263, 0.9602867025771857], 88 -> 
             RGBColor[
              0.6237700437240283, 0.7054436478722292, 0.9635246092683649], 21 -> 
             RGBColor[
              0.3147594051423885, 0.44705050929180634`, 0.9412771688582277], 
             62 -> RGBColor[
              0.8217365634979732, 0.860694446561215, 0.9828591610709686], 136 -> 
             RGBColor[
              0.8036160646677627, 0.8465102445175402, 0.9810605971731348], 
             190 -> RGBColor[
              0.6076384701621921, 0.6923473097356232, 0.9622546727056762], 57 -> 
             RGBColor[
              0.3470246381926262, 0.4749970324621562, 0.9433330809771634], 
             111 -> RGBColor[
              0.9102096848079109, 0.9312405119548574, 0.9912978063623982], 63 -> 
             RGBColor[
              0.90303589039225, 0.6525904494619237, 0.24080310894652518`], 75 -> 
             RGBColor[
              0.8774232610327151, 0.9050975076002813, 0.988170607993934], 30 -> 
             RGBColor[
              0.8756816383236217, 0.9037087849271394, 0.9880044904651758], 5 -> 
             RGBColor[
              0.9040475157549253, 0.6571840039627259, 0.24164723394634818`], 
             171 -> RGBColor[
              0.7135499175853248, 0.7761498858886691, 0.9720836453479554], 
             102 -> RGBColor[
              0.7274932157900237, 0.7870424964191711, 0.9734733830054698], 31 -> 
             RGBColor[
              0.38570250318015065`, 0.5084978551083311, 0.9457976003326755], 
             96 -> RGBColor[
              0.4927252994438893, 0.5990556209671584, 0.9532082869659172], 70 -> 
             RGBColor[
              0.989573060154557, 0.9899562066608475, 0.8224649075017101], 52 -> 
             RGBColor[
              0.4757937713459536, 0.5853098437006056, 0.9518753750518167], 
             183 -> RGBColor[
              0.9834552421816943, 0.9871815272254378, 0.9128901388091774], 
             158 -> RGBColor[
              0.8539992930035999, 0.8864198713205388, 0.9859364090124939], 13 -> 
             RGBColor[
              0.5672805666171326, 0.6595829455349081, 0.9590775507027373], 
             170 -> RGBColor[
              0.9476924139522759, 0.9605096684881944, 0.9734272785621323], 86 -> 
             RGBColor[
              0.9946876794112736, 0.9920712331632192, 0.7377024302075773], 18 -> 
             RGBColor[
              0.7839441419777637, 0.8311423889999632, 0.9790998837639653], 
             153 -> RGBColor[
              0.8846271492398021, 0.9108416925122764, 0.9888577212821129], 58 -> 
             RGBColor[
              0.8769251433785681, 0.904700322103908, 0.9881230970874066], 22 -> 
             RGBColor[
              0.9661931164741268, 0.9743074621368707, 0.9421104149486488], 66 -> 
             RGBColor[
              0.9633642336331681, 0.8880810989369741, 0.3121773950591637], 
             143 -> RGBColor[
              0.9022317340654805, 0.9248791105885474, 0.9905368622985845], 
             119 -> RGBColor[
              0.4332934981138159, 0.5497187829269162, 0.9488300564467841], 
             145 -> RGBColor[
              0.7523912898376357, 0.8064930610975369, 0.975954990340805], 91 -> 
             RGBColor[
              0.3138994888025372, 0.4463056929788791, 0.9412223757494464], 
             177 -> RGBColor[
              0.9669002844340943, 0.9000090285927089, 0.32591428469359895`], 
             200 -> RGBColor[
              0.7186884275148469, 0.7801641288997336, 0.9725958039956247], 
             114 -> RGBColor[
              0.5396385904246548, 0.637141944005018, 0.9569014730809703], 24 -> 
             RGBColor[
              0.36520783041368615`, 0.49074639965022404`, 0.9444916979067238],
              176 -> RGBColor[
              0.5011395243480307, 0.6058866678008525, 0.9538706855726926], 79 -> 
             RGBColor[
              0.19207344937466098`, 0.3192117518258016, 0.934249670843458], 
             109 -> RGBColor[
              0.8784383102020603, 0.5408985827290841, 0.22027828509396746`], 
             135 -> RGBColor[
              0.9494747221975495, 0.9618389110592576, 0.970410295603323], 108 -> 
             RGBColor[
              0.5844473366851763, 0.6735197028303246, 0.9604289817264444], 
             191 -> RGBColor[
              0.2858915312838074, 0.41782050432227136`, 0.9395924718167694], 
             14 -> RGBColor[
              0.8540831945672507, 0.8864867721499468, 0.9859444116185347], 
             185 -> RGBColor[
              0.9520106264983759, 0.8474451561164539, 0.28024482750646335`], 
             32 -> RGBColor[
              0.48418906917059457`, 0.5921255246785062, 0.9525362836495617], 
             122 -> RGBColor[
              0.397472685279186, 0.5186925952559621, 0.9465475859280625], 187 -> 
             RGBColor[
              0.7799288471077344, 0.8280056101301249, 0.9786996766963847], 
             193 -> RGBColor[
              0.9878164613876005, 0.970564204808781, 0.40716968246938345`], 
             100 -> RGBColor[
              0.9024017491886148, 0.9250146760327971, 0.9905530784928034], 
             180 -> RGBColor[
              0.7695064729114005, 0.8198635721949711, 0.9776608718391185], 7 -> 
             RGBColor[
              0.5576074648744436, 0.6517298857719258, 0.9583160486998136], 
             175 -> RGBColor[
              0.5998033863321095, 0.685986435715858, 0.9616378662057143], 9 -> 
             RGBColor[
              0.6553910553923596, 0.7307157407198008, 0.9662869134900286], 90 -> 
             RGBColor[
              0.7695727766162598, 0.8199153691531341, 0.9776674803727756], 
             174 -> RGBColor[
              0.3221619407732266, 0.45346221359297934`, 0.9417488518828194], 
             142 -> RGBColor[
              0.5929507522934161, 0.6804231586956012, 0.9610984017521629], 
             134 -> RGBColor[
              0.9846707636206691, 0.9879289810608105, 0.9037086478049786], 
             105 -> RGBColor[
              0.5091843781744347, 0.6124178425536622, 0.9545040059351777], 16 -> 
             RGBColor[
              0.7458452025743775, 0.8013792079753738, 0.975302537539067], 139 -> 
             RGBColor[
              0.3291477852084254, 0.459513000923998, 0.9421939837128905], 146 -> 
             RGBColor[
              0.9594612811446283, 0.8749155237363049, 0.2970151616519189], 
             126 -> RGBColor[
              0.9166622122470889, 0.9363855821856665, 0.9919132541897863], 
             198 -> RGBColor[
              0.2509398294932354, 0.38108404967449283`, 0.9376020241062055], 
             40 -> RGBColor[
              0.9930920149563756, 0.9876328434331401, 0.4894866430225257], 
             104 -> RGBColor[
              0.969388870179094, 0.9766908500174689, 0.9367008375121952], 181 -> 
             RGBColor[
              0.7448262005831066, 0.800583155875091, 0.9752009729436921], 127 -> 
             RGBColor[
              0.9891016359476724, 0.9897612606362512, 0.8302776266165274], 76 -> 
             RGBColor[
              0.5647521680396248, 0.6575302776666294, 0.9588785059048868], 
             172 -> RGBColor[
              0.5716387711027678, 0.6631211322712215, 0.9594206445244756], 84 -> 
             RGBColor[
              0.9871332939931992, 0.9889473006539956, 0.862898146707837], 184 -> 
             RGBColor[
              0.7102949943693245, 0.7736071151339969, 0.9717592250207714], 
             151 -> RGBColor[
              0.9520106264983759, 0.8474451561164539, 0.28024482750646335`], 
             35 -> RGBColor[0.817319, 0.134127, 0.164218], 36 -> 
             RGBColor[
              0.9001488282558243, 0.6394809745909084, 0.23839407353152295`], 
             34 -> RGBColor[
              0.5272109882126501, 0.6270526566722131, 0.9559231267110344], 38 -> 
             RGBColor[
              0.5903055332288929, 0.6782756506932606, 0.9608901604176469], 54 -> 
             RGBColor[
              0.8335093357139387, 0.8700817355628371, 0.9839820585946052], 60 -> 
             RGBColor[
              0.9950786975386541, 0.9922329292075985, 0.7312222479144064], 87 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 141 -> 
             RGBColor[
              0.6163640019209253, 0.6994310894980891, 0.9629415785283997], 67 -> 
             RGBColor[
              0.7324595408390674, 0.7909222272929524, 0.9739683798734122], 
             133 -> RGBColor[
              0.3364206977432522, 0.4658124322144522, 0.9426574072684257], 98 -> 
             RGBColor[
              0.9872451489838309, 0.9889935555671641, 0.8610444200416333], 3 -> 
             RGBColor[
              0.42216523483792234`, 0.5400800406001125, 0.9481209733511811], 
             27 -> RGBColor[
              0.5612399861622367, 0.6546789301965753, 0.9586020140819526], 
             163 -> RGBColor[
              0.898096053820718, 0.9215814314214235, 0.9901423974248738], 85 -> 
             RGBColor[
              0.7871140135818742, 0.8336187167890107, 0.9794158269413287], 83 -> 
             RGBColor[
              0.7073460186249579, 0.771303352869452, 0.9714652986783181], 28 -> 
             RGBColor[
              0.7315670264367106, 0.7902249882584705, 0.9738794223788065], 44 -> 
             RGBColor[
              0.4072400568378569, 0.527152601577714, 0.9471699542068336], 189 -> 
             RGBColor[
              0.3598377440978132, 0.4860951007918011, 0.9441495207552573], 15 -> 
             RGBColor[
              0.41539505821686284`, 0.5342160538899219, 0.9476895836835192], 
             80 -> RGBColor[
              0.8371596486230256, 0.8729923959914386, 0.9843302286985467], 
             112 -> RGBColor[
              0.9419987792322736, 0.9562633650364879, 0.9830651170053324], 
             169 -> RGBColor[
              0.7380109729701624, 0.7952590482662107, 0.974521694747157], 69 -> 
             RGBColor[
              0.898096053820718, 0.9215814314214235, 0.9901423974248738], 20 -> 
             RGBColor[
              0.9706585495231477, 0.9776377747933549, 0.9345516015681211], 8 -> 
             RGBColor[
              0.979796620338884, 0.943511397803234, 0.37601411441502275`], 
             116 -> RGBColor[
              0.7784112685141984, 0.8268200661988301, 0.9785484186447593], 97 -> 
             RGBColor[
              0.452625492329106, 0.5664631846619191, 0.9500618740235711], 118 -> 
             RGBColor[
              0.6393330192474475, 0.7180783725061984, 0.9647497837106263], 
             178 -> RGBColor[
              0.9330156140797994, 0.9494253409058026, 0.9934730562554444], 81 -> 
             RGBColor[
              0.40888115724978835`, 0.5285740402704241, 0.9472745236739137], 
             166 -> RGBColor[
              0.7674100719867827, 0.8182258478594227, 0.9774519221869331], 
             125 -> RGBColor[
              0.8456036528762156, 0.8797254157765428, 0.9851356253622676], 95 -> 
             RGBColor[
              0.9697782607012021, 0.9097171183226265, 0.3370946790310986], 
             157 -> RGBColor[
              0.829781767505188, 0.8671094738553228, 0.9836265198112152], 74 -> 
             RGBColor[
              0.5975300291092396, 0.6841408219087564, 0.9614588991975481], 19 -> 
             RGBColor[
              0.9887109566620343, 0.9735815474069248, 0.4106446276993004], 
             156 -> RGBColor[
              0.9946085244305252, 0.9908765038557186, 0.6545493404721004], 
             167 -> RGBColor[
              0.5957204749548415, 0.6826717443267304, 0.9613164444658986], 33 -> 
             RGBColor[
              0.5396111452962791, 0.6371196628134137, 0.9568993124999298], 43 -> 
             RGBColor[
              0.44693087067580467`, 0.5615307896058361, 0.949699017767379], 
             140 -> RGBColor[
              0.9294976642669348, 0.7581887628687297, 0.26213036964790404`], 
             186 -> RGBColor[
              0.9941702332294676, 0.9899390432946943, 0.6068440480567372], 
             117 -> RGBColor[
              0.9659913947838896, 0.9741570184305808, 0.9424518771527773], 4 -> 
             RGBColor[
              0.39642092785410055`, 0.5177816158372183, 0.9464805688749687], 
             106 -> RGBColor[
              0.30848321555448455`, 0.44156579688626707`, 0.9408790348145827],
              65 -> RGBColor[
              0.8245580961482076, 0.8629442601080484, 0.9831282813739599], 53 -> 
             RGBColor[
              0.8384111844775699, 0.8739903367098165, 0.9844496013056124], 2 -> 
             RGBColor[
              0.5757019452613417, 0.6664198000970617, 0.9597405124781359], 
             147 -> RGBColor[
              0.9880196787515436, 0.9893138435306204, 0.8482084573718471], 94 -> 
             RGBColor[
              0.7554904036144439, 0.8089141123341166, 0.9762638810392125], 23 -> 
             RGBColor[
              0.30848321555448455`, 0.44156579688626707`, 0.9408790348145827],
              194 -> RGBColor[
              0.969388870179094, 0.9766908500174689, 0.9367008375121952], 129 -> 
             RGBColor[
              0.9228835874317103, 0.7319661522275143, 0.2568085281739453], 99 -> 
             RGBColor[
              0.7822444717657953, 0.8298145937124013, 0.9789304765215574], 25 -> 
             RGBColor[
              0.9924989785246626, 0.9911661490995585, 0.7739748680750453], 
             138 -> RGBColor[
              0.3950287030262528, 0.5165757406665911, 0.9463918575400343], 
             124 -> RGBColor[
              0.7862532353523716, 0.8329462702939664, 0.9793300326118417], 
             197 -> RGBColor[
              0.9951432462127467, 0.9920202196792252, 0.7127505065465968], 
             164 -> RGBColor[
              0.37881275824960914`, 0.502530304338145, 0.9453585918780635], 
             152 -> RGBColor[
              0.31044964691839855`, 0.44331761333293296`, 0.9410025548751645],
              17 -> RGBColor[
              0.5599033870886682, 0.6535938188555503, 0.9584967921067575], 
             149 -> RGBColor[
              0.4992393614564089, 0.6043440299640712, 
               0.9537210977893381]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw1Vnk41Iv7HWbGjH3MjDGYYWbMlDYVokV9jgp1K023DRVaCFlSpNQNyVKW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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 11}], {
             RGBColor[
             0.8931346460878744, 0.9166837578516944, 0.9545861805779006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 35}], {
             RGBColor[
             0.869852125372916, 0.41635624883117595`, 0.41859227542749433`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 86}], {
             RGBColor[
             0.9848030277650108, 0.9864429898283735, 0.8325216282450301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 94}], {
             RGBColor[
             0.865204389866596, 0.8948644294138222, 0.9518023536608478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 174}], {
             RGBColor[
             0.6485401584459873, 0.7171384800432535, 0.9345448390826512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 196}], {
             RGBColor[
             0.9240754210463222, 0.7490374032191647, 0.5716376136727758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 16}], {
             RGBColor[
             0.6607735739178595, 0.7338995040362177, 0.9675215250086014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 52}], {
             RGBColor[
             0.5257478583036477, 0.6258648218988336, 0.9558079437649762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[
             0.769533089447255, 0.7772504495170178, 0.6359589537686497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 78}], {
             RGBColor[
             0.6217217089544468, 0.7033918903216332, 0.9636292000694754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 80}], {
             RGBColor[
             0.7064307969421837, 0.7697060980442502, 0.9720353705883413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 82}], {
             RGBColor[
             0.7611402543057435, 0.813049380314975, 0.9675266247854558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 98}], {
             RGBColor[
             0.7814735471225862, 0.8277066778321129, 0.9103924662598846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 100}], {
             RGBColor[
             0.7390518472249783, 0.7957172380649293, 0.9751467954854696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 120}], {
             RGBColor[
             0.6283425430508692, 0.7085641362379612, 0.9642891029369944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 124}], {
             RGBColor[
             0.6809775903068567, 0.749683035195514, 0.9695352725449888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 187}], {
             RGBColor[
             0.677815396184538, 0.7472127051135933, 0.9692200945872602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 5}], {
             RGBColor[
             0.6631063752964238, 0.5986320222814192, 0.5948841036487647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 10}], {
             RGBColor[
             0.6449085592451053, 0.7186930585571073, 0.9676797893237792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 27}], {
             RGBColor[
             0.4917026105000795, 0.5973794853983438, 0.9533614937165669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 29}], {
             RGBColor[
             0.45205166493080706`, 0.5651890615304667, 0.9502400260351542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 49}], {
             RGBColor[
             0.5492152285162643, 0.6435514195376859, 0.958244214353939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 53}], {
             RGBColor[
             0.6302882096577461, 0.7070351886549645, 0.9662852873283967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 62}], {
             RGBColor[
             0.6219508991679478, 0.7003872435806637, 0.9654900672110749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 68}], {
             RGBColor[
             0.4375024079030385, 0.5533643290403838, 0.9490982444567606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 71}], {
             RGBColor[
             0.5830755926495247, 0.6700033933468879, 0.9616190990076491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 75}], {
             RGBColor[
             0.6497942479353187, 0.7225887741001968, 0.9681457906725575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 118}], {
             RGBColor[
             0.530749127042685, 0.6290792065531554, 0.9564353785309037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[
             0.40866340887822067`, 0.5283854375753234, 0.9472606489402248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 127}], {
             RGBColor[
             0.7056334353927973, 0.7649206506181818, 0.8891992999838543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 129}], {
             RGBColor[
             0.6725244111348163, 0.6360230964138134, 0.6024647507625631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 139}], {
             RGBColor[
             0.3756565100231739, 0.4997965207620553, 0.9451574785320358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 141}], {
             RGBColor[
             0.5192646183794238, 0.6197555650491008, 0.9555312759397904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 146}], {
             RGBColor[
             0.6908132579912754, 0.7074977821682087, 0.6225680675015499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 155}], {
             RGBColor[
             0.6563372481673152, 0.727805984880181, 0.9687698678756906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 167}], {
             RGBColor[
             0.5089428548963819, 0.6113758924634214, 0.9547187089085398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 191}], {
             RGBColor[
             0.35402838306086487`, 0.47895027246119193`, 0.9438567225839752]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 194}], {
             RGBColor[
             0.6957770525085082, 0.7583854453087907, 0.9424109054316882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 195}], {
             RGBColor[
             0.4904206735714933, 0.5963387512491172, 0.9532605749456589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 34}], {
             RGBColor[
             0.46181595803337533`, 0.5724171362547157, 0.9512018477930015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 40}], {
             RGBColor[
             0.6947564714052381, 0.7527072296351791, 0.7179836059487472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 49}], {
             RGBColor[
             0.5363430750243534, 0.6324022071562387, 0.9574240121158328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 53}], {
             RGBColor[
             0.6174160561658353, 0.6958859762735174, 0.9654650850902906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 54}], {
             RGBColor[
             0.6149651317840197, 0.6939316757000277, 0.965231313734787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 65}], {
             RGBColor[
             0.6104895120011541, 0.6903629379726333, 0.9648044251244643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 69}], {
             RGBColor[
             0.6472584908374093, 0.7196815236293208, 0.9683114831499212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 86}], {
             RGBColor[
             0.695554303632687, 0.7549264245002187, 0.8420914995412729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 92}], {
             RGBColor[
             0.6058557889584774, 0.6867060675977696, 0.9643523898075415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 118}], {
             RGBColor[
             0.517876973550774, 0.6179299941717084, 0.9556151762927975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 119}], {
             RGBColor[
             0.4148572129839582, 0.5337501993820672, 0.9476553126608764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 123}], {
             RGBColor[
             0.39579125538630977`, 0.5172362251938764, 0.9464404467021186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 139}], {
             RGBColor[
             0.36278435653126295`, 0.4886473083806081, 0.9443372762939296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 146}], {
             RGBColor[
             0.6779411044993644, 0.6963485697867615, 0.6217478652634438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 171}], {
             RGBColor[
             0.5549854227197126, 0.6469657508629436, 0.9592821071114621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 182}], {
             RGBColor[
             0.5496364023685922, 0.6427870555105879, 0.9587489667522996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 191}], {
             RGBColor[
             0.341156229568954, 0.4678010600797448, 0.943036520345869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 195}], {
             RGBColor[
             0.47754852007958243`, 0.58518953886767, 0.9524403727075527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 196}], {
             RGBColor[
             0.6348266969139984, 0.5175208378910099, 0.5812074849690186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 199}], {
             RGBColor[
             0.6915976258960705, 0.7532902365741481, 0.9076638891907545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 10}], {
             RGBColor[
             0.8858496997036067, 0.777245040238414, 0.6144429196213628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 27}], {
             RGBColor[
             0.732643750958581, 0.6559314670796506, 0.6001246240141505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.6929928053893085, 0.6237410432117734, 0.5970031563327378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 30}], {
             RGBColor[
             0.8898645770392735, 0.7804463944449327, 0.6148258622057621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 42}], {
             RGBColor[
             0.5978124956984313, 0.5404903981575431, 0.5907817559413562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 68}], {
             RGBColor[
             0.67844354836154, 0.6119163107216905, 0.5958613747543442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 71}], {
             RGBColor[
             0.8240167331080261, 0.7285553750281946, 0.6083822293052326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 73}], {
             RGBColor[
             0.6102056612797466, 0.5528120826673699, 0.5915133169298865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 75}], {
             RGBColor[
             0.8907353883938202, 0.7811407557815035, 0.614908920970141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 76}], {
             RGBColor[
             0.734399841897275, 0.6573571408146777, 0.6002628699256174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 81}], {
             RGBColor[
             0.6564643365023568, 0.592879022116575, 0.5944608788101309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 87}], {
             RGBColor[
             0.5414872578774627, 0.48128900198136293`, 0.5875741169731741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 89}], {
             RGBColor[
             0.7780944390202273, 0.6926805298644443, 0.6038051241987983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 107}], {
             RGBColor[
             0.762097571381148, 0.6798434053781796, 0.602443336650714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 127}], {
             RGBColor[
             0.9465745758512989, 0.8234726322994885, 0.5359624302814379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 129}], {
             RGBColor[
             0.9134655515933178, 0.6945750780951201, 0.24922788106014673`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 141}], {
             RGBColor[
             0.7602057588379253, 0.6783075467304075, 0.6022944062373738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 142}], {
             RGBColor[
             0.7484991340241707, 0.6688035813291635, 0.6013728178492554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 147}], {
             RGBColor[
             0.9460335972532344, 0.8232489237466731, 0.5449278456590976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 155}], {
             RGBColor[
             0.8972783886258167, 0.7863579665614877, 0.6155329981732742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 157}], {
             RGBColor[
             0.8669146416300566, 0.7621467389090244, 0.6126368768787818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 168}], {
             RGBColor[
             0.6642833309846334, 0.5996514421430335, 0.5949590982244763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 188}], {
             RGBColor[
             0.7431169357668246, 0.6644340703185817, 0.6009491114867953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 197}], {
             RGBColor[
             0.949595380983836, 0.8246021118209755, 0.47719887024647245`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 44}], {
             RGBColor[
             0.7006216699969453, 0.7583672777732874, 0.7679212585333537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 45}], {
             RGBColor[
             0.7539466765707203, 0.8029100445618352, 0.7717735090459643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 58}], {
             RGBColor[
             0.9354642132673009, 0.9471411380363843, 0.7883978299736403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 77}], {
             RGBColor[
             0.9699627501975165, 0.9743857063233623, 0.7825481613581688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 83}], {
             RGBColor[
             0.8506746508904959, 0.8804426534191563, 0.780068930769096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 96}], {
             RGBColor[
             0.7433642912999615, 0.7943187874680095, 0.7709404249128955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 112}], {
             RGBColor[
             0.9680010311941536, 0.9729226595026743, 0.7858688399326031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 156}], {
             RGBColor[
             0.9943059037932794, 0.9902292289122896, 0.6216109516659871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 166}], {
             RGBColor[
             0.8807066775714082, 0.9039039009141416, 0.7830622425234035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 170}], {
             RGBColor[
             0.9708478485541547, 0.9750458112285276, 0.7810499207110031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 179}], {
             RGBColor[
             0.7137370695074721, 0.7697271776301592, 0.768756960192672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 183}], {
             RGBColor[
             0.988729262668864, 0.9883817405971493, 0.7507813508345256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 192}], {
             RGBColor[
             0.8272916636778638, 0.8621756860913632, 0.7777383331301801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 8}], {
             RGBColor[
             0.7687020426066637, 0.79762064178758, 0.6671650815574182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 16}], {
             RGBColor[
             0.6517263337244106, 0.7265545468736498, 0.9668092931194403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 52}], {
             RGBColor[
             0.5167006181101985, 0.6185198647362657, 0.9550957118758152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.7255431134759784, 0.7848148070451817, 0.9740090223581577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 67}], {
             RGBColor[
             0.6450335028567555, 0.7213260565324391, 0.966142214286613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 79}], {
             RGBColor[
             0.3748404571245523, 0.48547081879886367`, 0.9462828597716357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.7723703794338214, 0.8203385932129608, 0.9106070977038253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 122}], {
             RGBColor[
             0.4775400750768148, 0.585211240513944, 0.9524318173139381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 125}], {
             RGBColor[
             0.7016055588753296, 0.7657276507742343, 0.9717258370310407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 126}], {
             RGBColor[
             0.7371348385607662, 0.7940577339787962, 0.9751146514447999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 137}], {
             RGBColor[
             0.7196638421062375, 0.7801268356435201, 0.9734482522064243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 179}], {
             RGBColor[
             0.495539160366677, 0.6008011435316918, 0.9535787031126419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 192}], {
             RGBColor[
             0.6090937545370687, 0.6932496519928958, 0.9625600760501499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.6472780127406362, 0.6952809535475202, 0.6586456416366252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 26}], {
             RGBColor[
             0.8611379763914904, 0.871130581225636, 0.675490586737674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 61}], {
             RGBColor[
             0.9366376912081986, 0.9307055630608357, 0.6828580552157624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 67}], {
             RGBColor[
             0.8561280805889757, 0.8672168125480932, 0.6749912471442174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 79}], {
             RGBColor[
             0.5859350348567725, 0.6313615748145178, 0.6551318926292404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.9631875918445146, 0.9515951791680612, 0.6756634257538993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 83}], {
             RGBColor[
             0.843571319481921, 0.8574073753363429, 0.6737397065466704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 122}], {
             RGBColor[
             0.688634652809035, 0.7311019965295981, 0.6612808501715426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 125}], {
             RGBColor[
             0.9127001366075498, 0.9116184067898885, 0.6805748698886451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 137}], {
             RGBColor[
             0.9307584198384578, 0.9260175916591742, 0.682297285064029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 166}], {
             RGBColor[
             0.8736033461628334, 0.8808686228313283, 0.6767330183009779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 170}], {
             RGBColor[
             0.96374451714558, 0.9520105331457143, 0.6747206964885775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 179}], {
             RGBColor[
             0.7066337380988972, 0.7466918995473458, 0.6624277359702465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 192}], {
             RGBColor[
             0.8201883322692889, 0.8391404080085498, 0.6714091089077545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 198}], {
             RGBColor[
             0.6153682249160597, 0.6622977237388634, 0.6568080692606142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 18}], {
             RGBColor[
             0.7196675986850617, 0.780929064859882, 0.972693398626997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 32}], {
             RGBColor[
             0.5697900622814771, 0.6614206326991535, 0.9594115985697951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 39}], {
             RGBColor[
             0.8067232538458129, 0.8494770731196313, 0.9610861356219906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 41}], {
             RGBColor[
             0.7124487641518801, 0.7752896564573859, 0.9719738926645736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 57}], {
             RGBColor[
             0.501207846792493, 0.6028563865909785, 0.9548099972335959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 85}], {
             RGBColor[
             0.7212525344871169, 0.7821672287544057, 0.9728513702156787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 88}], {
             RGBColor[
             0.639580549558194, 0.718079694296015, 0.9649057613791967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 91}], {
             RGBColor[
             0.48464527209744845`, 0.58851071684934, 0.9537546446197376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 103}], {
             RGBColor[
             0.7452047310221673, 0.8010003842429942, 0.9752064543089336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 117}], {
             RGBColor[
             0.8106912250881246, 0.8524363795751908, 0.954369395321403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 121}], {
             RGBColor[
             0.6440956999116367, 0.7217452967581452, 0.9652612105545605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 152}], {
             RGBColor[
             0.4829203511553791, 0.587016677026367, 0.9536447341825965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 159}], {
             RGBColor[
             0.6228482943106263, 0.7044956957065307, 0.9635885369538377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 164}], {
             RGBColor[
             0.5171019068209843, 0.6166230225289729, 0.955822752684046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 178}], {
             RGBColor[
             0.7942033347360795, 0.8400705408128017, 0.9798799848727364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 200}], {
             RGBColor[
             0.6870397414536032, 0.7554399348097672, 0.9694413587428267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 17}], {
             RGBColor[
             0.7137776353704781, 0.7754499476848262, 0.9728676987015674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 27}], {
             RGBColor[
             0.7144459349072625, 0.7759925033553388, 0.972920309689165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 29}], {
             RGBColor[
             0.67479498933799, 0.7438020794874615, 0.9697988420077523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 30}], {
             RGBColor[
             0.8716667609879549, 0.9005074307206207, 0.9876215478807766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 42}], {
             RGBColor[
             0.5796146796471128, 0.6605514344332312, 0.9635774416163707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 51}], {
             RGBColor[
             0.877998783058084, 0.7415958613792641, 0.6078919223287618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 62}], {
             RGBColor[
             0.8446942235751307, 0.8790002615376585, 0.985048883183673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 71}], {
             RGBColor[
             0.8058189170567076, 0.8486164113038825, 0.9811779149802472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 73}], {
             RGBColor[
             0.5920078452284281, 0.672873118943058, 0.9643090026049012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 75}], {
             RGBColor[
             0.8725375723425016, 0.9012017920571918, 0.9877046066451556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 89}], {
             RGBColor[
             0.7598966229689088, 0.8127415661401325, 0.9766008098738128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 107}], {
             RGBColor[
             0.7438997553298294, 0.7999044416538676, 0.9752390223257287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.8952677355419992, 0.8146361143708082, 0.6220235667351612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 130}], {
             RGBColor[
             0.7666751045626053, 0.8180369674794963, 0.9772764255705606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 141}], {
             RGBColor[
             0.7420079427866068, 0.7983685830060956, 0.9750900919123885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 142}], {
             RGBColor[
             0.7303013179728521, 0.7888646176048517, 0.9741685035242701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 147}], {
             RGBColor[
             0.9278357812019159, 0.9433099600223612, 0.9177235313341122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 149}], {
             RGBColor[
             0.6834456225543486, 0.7508250532390867, 0.9704798515428577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 167}], {
             RGBColor[
             0.7316861793035648, 0.7899889104204163, 0.974277524881138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 168}], {
             RGBColor[
             0.6460855149333149, 0.7197124784187217, 0.9677547838994909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 188}], {
             RGBColor[
             0.724919119715506, 0.7844951065942698, 0.97374479716181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.6137448138750508, 0.6917005886529516, 0.9656940630258173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 194}], {
             RGBColor[
             0.9185203769156911, 0.9369984632657855, 0.9619697214042863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 197}], {
             RGBColor[
             0.9313975649325175, 0.9446631480966636, 0.849994555921487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 35}], {
             RGBColor[
             0.815329638685667, 0.37360225640328704`, 0.43675584495777275`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 70}], {
             RGBColor[
             0.9004619881057789, 0.9212544879353542, 0.9021482211875141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 86}], {
             RGBColor[
             0.9030192977341372, 0.9223120011865401, 0.8597669825404477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 94}], {
             RGBColor[
             0.7834206598357224, 0.8307334407719889, 0.9790477079562654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 110}], {
             RGBColor[
             0.5421490649377312, 0.6283839875794621, 0.9603434234799189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 138}], {
             RGBColor[
             0.6031898095416268, 0.684564254938226, 0.9641116962066762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 174}], {
             RGBColor[
             0.5667564284151138, 0.6530074914014201, 0.9617901933780688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 182}], {
             RGBColor[
             0.7571013964700424, 0.8101726321969094, 0.9764244497514744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 196}], {
             RGBColor[
             0.8422916910154487, 0.6849064145773314, 0.5988829679681934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 33}], {
             RGBColor[
             0.4229633338429695, 0.5382035383718826, 0.9488274501977951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 44}], {
             RGBColor[
             0.35677778961375844`, 0.48322000775403284`, 0.943962771051247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 58}], {
             RGBColor[
             0.5916203328841141, 0.6719938680171298, 0.9644393424915336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 68}], {
             RGBColor[
             0.3795775516789073, 0.5029680157055034, 0.9454155517290004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 77}], {
             RGBColor[
             0.6261188698143296, 0.6992384363041078, 0.9585896738760622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 96}], {
             RGBColor[
             0.39952041091677465`, 0.519171517448755, 0.9469819374307888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 99}], {
             RGBColor[
             0.5442799970777277, 0.6345510038213764, 0.959843032208609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 102}], {
             RGBColor[
             0.5169043690898418, 0.6131649551747613, 0.9571144854505652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 128}], {
             RGBColor[
             0.5632897184881698, 0.6494038051118454, 0.9617371431994104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 140}], {
             RGBColor[
             0.6179065933282974, 0.5987380883995407, 0.6014429787717823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 162}], {
             RGBColor[
             0.6505008047556643, 0.7151649082698175, 0.8018735743186363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 172}], {
             RGBColor[
             0.4389771467462139, 0.5512042731007866, 0.9500881162100681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 31}], {
             RGBColor[
             0.4764915348986416, 0.5840404003216196, 0.9524375755177064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 34}], {
             RGBColor[
             0.5472457774148913, 0.6433178011035606, 0.9575003387068859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 36}], {
             RGBColor[
             0.7337146974364784, 0.6495319600629083, 0.5987358121171301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 63}], {
             RGBColor[
             0.7351582285046913, 0.6560866974984159, 0.5999403298246312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 64}], {
             RGBColor[
             0.5354359257653459, 0.6337300315067058, 0.9565706239241216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 70}], {
             RGBColor[
             0.7784268133858447, 0.8247695760978778, 0.8907712291022236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 97}], {
             RGBColor[
             0.5099530294731193, 0.6130230650984136, 0.9545697123631542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 132}], {
             RGBColor[
             0.587346139514886, 0.6758730815570622, 0.9606571861038639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 138}], {
             RGBColor[
             0.4811546348216927, 0.5880793431007496, 0.9527347041213858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 145}], {
             RGBColor[
             0.6598359282273841, 0.7330380033162225, 0.9675162705217711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 153}], {
             RGBColor[
             0.7259538579284673, 0.7852123190235922, 0.9739676359924251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 185}], {
             RGBColor[
             0.7596455965577542, 0.753514050825681, 0.6196611891046003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 22}], {
             RGBColor[
             0.9101381555206887, 0.9303971171434087, 0.9640274132835918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 48}], {
             RGBColor[
             0.7911962094130682, 0.8370833702934435, 0.979749563361074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 106}], {
             RGBColor[
             0.5812832050608676, 0.6640262845181069, 0.9634117232165587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 131}], {
             RGBColor[
             0.9177877332465301, 0.9361021596863073, 0.9510786735231436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 176}], {
             RGBColor[
             0.6776113594576407, 0.7461867199753996, 0.9699075485956137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 59}], {
             RGBColor[
             0.5924507655641317, 0.6770398130424464, 0.9626752277613189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.618565810857418, 0.6974552502255684, 0.9652743723772439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 114}], {
             RGBColor[
             0.4775168243207588, 0.58567899894747, 0.9522955283822447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 167}], {
             RGBColor[
             0.5055577665858522, 0.6084438991083261, 0.9545030140747088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 184}], {
             RGBColor[
             0.5628450262930937, 0.6539115845119594, 0.9597244043521453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 186}], {
             RGBColor[
             0.7047826457231652, 0.7620775485923081, 0.7772668158701281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 194}], {
             RGBColor[
             0.6923919641979784, 0.7554534519536954, 0.9421952105978573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 52}], {
             RGBColor[
             0.6108194869601655, 0.6933445258379897, 0.9635889562954418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 61}], {
             RGBColor[
             0.8196619823259453, 0.8596394681469056, 0.9825022667777845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 67}], {
             RGBColor[
             0.7391523717067224, 0.7961507176341631, 0.9746354587062396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 80}], {
             RGBColor[
             0.7915024255987015, 0.8371858019834062, 0.9798163831188069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 82}], {
             RGBColor[
             0.8462118829622614, 0.8805290842541311, 0.9753076373159214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 84}], {
             RGBColor[
             0.8664892482837883, 0.8951632543146847, 0.919100342123452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 100}], {
             RGBColor[
             0.8241234758814961, 0.8631969420040855, 0.9829278080159352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 120}], {
             RGBColor[
             0.7134141717073872, 0.7760438401771173, 0.97207011546746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 125}], {
             RGBColor[
             0.7957244277252966, 0.8405523118759584, 0.9802190814506673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.762887024841056, 0.8146924090527493, 0.9770011071177258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 30}], {
             RGBColor[
             0.7177925127061449, 0.7786513018913448, 0.9732506412859667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[
             0.4257404313653027, 0.5386953056039553, 0.9492065350215608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 51}], {
             RGBColor[
             0.724124534776274, 0.6197397325499883, 0.5935210157339519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 73}], {
             RGBColor[
             0.4381335969466181, 0.5510169901137821, 0.9499380960100913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 87}], {
             RGBColor[
             0.36941519354433405`, 0.47949390942777514`, 0.9459988960533787]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 89}], {
             RGBColor[
             0.6060223746870989, 0.6908854373108566, 0.9622299032790029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 106}], {
             RGBColor[
             0.43419330132157635`, 0.5475798078709087, 0.9496879134606702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 107}], {
             RGBColor[
             0.5900255070480195, 0.6780483128245918, 0.9608681157309188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 130}], {
             RGBColor[
             0.6128008562807954, 0.6961808386502204, 0.9629055189757507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 131}], {
             RGBColor[
             0.7706978295072389, 0.8196556830391091, 0.937354863767255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 142}], {
             RGBColor[
             0.5764270696910421, 0.6670084887755758, 0.9597975969294602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 147}], {
             RGBColor[
             0.7739615329201059, 0.8214538311930853, 0.9033526247393023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 149}], {
             RGBColor[
             0.5295713742725385, 0.6289689244098108, 0.9561089449480478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 157}], {
             RGBColor[
             0.694842577296928, 0.7603516463554365, 0.9710616559589864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 168}], {
             RGBColor[
             0.4922112666515049, 0.5978563495894458, 0.953383877304681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 188}], {
             RGBColor[
             0.5710448714336961, 0.6626389777649939, 0.9593738905670001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 189}], {
             RGBColor[
             0.4598705655932407, 0.5698444598236757, 0.9513231564310074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 197}], {
             RGBColor[
             0.7775233166507074, 0.8228070192673878, 0.8356236493266771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 24}], {
             RGBColor[
             0.5745759861957249, 0.6609443943250937, 0.9617957908353445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 32}], {
             RGBColor[
             0.6340666055741792, 0.7116339568392347, 0.9658180837067635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 39}], {
             RGBColor[
             0.870999797138515, 0.8996903972597126, 0.9674926207589589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 41}], {
             RGBColor[
             0.7767253074445821, 0.8255029805974672, 0.9783803778015419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 85}], {
             RGBColor[
             0.785529077779819, 0.832380552894487, 0.979257855352647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 103}], {
             RGBColor[
             0.8094812743148694, 0.8512137083830755, 0.9816129394459019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 108}], {
             RGBColor[
             0.68419573933147, 0.7523310459151439, 0.9697644327452049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 117}], {
             RGBColor[
             0.8749677683808267, 0.902649703715272, 0.9607758804583713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 133}], {
             RGBColor[
             0.560182419860508, 0.6484774106072076, 0.9608786455161955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 152}], {
             RGBColor[
             0.5471968944480812, 0.637230001166448, 0.9600512193195649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 178}], {
             RGBColor[
             0.8584798780287816, 0.8902838649528828, 0.9862864700097048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 33}], {
             RGBColor[
             0.7641610509791568, 0.8053506051101693, 0.683771970099615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 74}], {
             RGBColor[
             0.793120492885637, 0.8288611846578406, 0.6860517634484242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 85}], {
             RGBColor[
             0.8879124851219542, 0.9036001320979677, 0.6950302273203146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 88}], {
             RGBColor[
             0.8062405001930313, 0.839512597639577, 0.6870846184838326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 93}], {
             RGBColor[
             0.7856754847781944, 0.8228169916824255, 0.6854656651382431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 95}], {
             RGBColor[
             0.9792446086816182, 0.9416493328647757, 0.3738696533651995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 102}], {
             RGBColor[
             0.858102086226029, 0.880312021913048, 0.6920590053523852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 121}], {
             RGBColor[
             0.8107556505464741, 0.8431782001017072, 0.6874400676591963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 140}], {
             RGBColor[
             0.9591043104644845, 0.8658851551378273, 0.3363874986736022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 159}], {
             RGBColor[
             0.7895082449454636, 0.8259285990500926, 0.6857673940584736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 161}], {
             RGBColor[
             0.614516746886794, 0.6717530748065262, 0.6738210063556229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 162}], {
             RGBColor[
             0.9916985218918515, 0.982311975008104, 0.5368180942204561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 164}], {
             RGBColor[
             0.6837618574558217, 0.738055925872535, 0.6780016097886818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 172}], {
             RGBColor[
             0.7801748638824011, 0.8183513398390732, 0.6850326361118879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 173}], {
             RGBColor[
             0.9790499134205641, 0.9751361987121969, 0.6736727326057479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 180}], {
             RGBColor[
             0.8791087147867174, 0.896722559800948, 0.6941527497692095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 22}], {
             RGBColor[
             0.9684258329986373, 0.9759726184651127, 0.9383310082583849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 46}], {
             RGBColor[
             0.9731024783412046, 0.9534061027721048, 0.6470272201828606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 47}], {
             RGBColor[
             0.9651098082920041, 0.973499532668398, 0.9439441731289577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 50}], {
             RGBColor[
             0.9252722644690073, 0.9423494935914273, 0.9614785529199197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 101}], {
             RGBColor[
             0.9774429346519078, 0.982691690215169, 0.9228046306988955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 135}], {
             RGBColor[
             0.9600666358603486, 0.9697383429263062, 0.9524809485857221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 144}], {
             RGBColor[
             0.666061080436865, 0.7325705600405201, 0.9394023605735135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 23}], {
             RGBColor[
             0.31162131034843654`, 0.4443081530890367, 0.9410781018364052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 55}], {
             RGBColor[
             0.48066837816587427`, 0.5854404586507955, 0.953342807341025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 61}], {
             RGBColor[
             0.6041190836099508, 0.6824751188051219, 0.9654895824373648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 67}], {
             RGBColor[
             0.5236094729907279, 0.6189863682923793, 0.9576227743658199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 83}], {
             RGBColor[
             0.5110527118836732, 0.6091769310806292, 0.9563712337682728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 90}], {
             RGBColor[
             0.5421660908793241, 0.6334829392224702, 0.9594723246155017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 122}], {
             RGBColor[
             0.3561160452107872, 0.48287155227388423`, 0.943912377393145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 166}], {
             RGBColor[
             0.5410847385645856, 0.6326381785756146, 0.9593645455225803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 170}], {
             RGBColor[
             0.6312259095473323, 0.7037800888900003, 0.9573522237101799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 175}], {
             RGBColor[
             0.457281395737249, 0.5665184725038321, 0.951457517531971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 177}], {
             RGBColor[
             0.6408298447882415, 0.6735297689422577, 0.6335957267759134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 179}], {
             RGBColor[
             0.37411513050064943`, 0.498461455291632, 0.945059263191849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 183}], {
             RGBColor[
             0.6491073236620415, 0.717116018258622, 0.9270836538337025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 192}], {
             RGBColor[
             0.4876697246710411, 0.5909099637528361, 0.954040636129357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.8472511703665063, 0.8809937152869055, 0.957832565026131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 72}], {
             RGBColor[
             0.7248619422266294, 0.7829492741260085, 0.9472974373584909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 144}], {
             RGBColor[
             0.6638283639123544, 0.730905403712278, 0.9431817672637772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 176}], {
             RGBColor[
             0.7336663204110787, 0.7900970649688617, 0.9479905502606707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 38}], {
             RGBColor[
             0.4493943743916887, 0.5599207237897639, 0.9508845976161148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 43}], {
             RGBColor[
             0.3777070431151446, 0.5015482932460515, 0.9452890262909808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 55}], {
             RGBColor[
             0.4775302833719223, 0.5826981024480258, 0.9531437403192025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 60}], {
             RGBColor[
             0.6517809565465693, 0.7168993630469328, 0.8360506413644946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 90}], {
             RGBColor[
             0.5390279960853721, 0.6307405830197006, 0.9592732575936791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 111}], {
             RGBColor[
             0.6093464501811977, 0.6864031544205622, 0.9660884205884904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 115}], {
             RGBColor[
             0.4366884564552169, 0.5496054872138558, 0.9498843412128447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 163}], {
             RGBColor[
             0.6032896346876013, 0.6815736141538453, 0.9655107161197283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 165}], {
             RGBColor[
             0.5928981530887343, 0.6732877287961625, 0.9645195673282432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 169}], {
             RGBColor[
             0.5232470942623235, 0.6184124225762389, 0.9577003647808698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 175}], {
             RGBColor[
             0.454143300943297, 0.5637761163010626, 0.9512584505101485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 177}], {
             RGBColor[
             0.6376917499942893, 0.6707874127394879, 0.6333966597540908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 39}], {
             RGBColor[
             0.6616316413564762, 0.7294924025848429, 0.9501885278303382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 41}], {
             RGBColor[
             0.5673571516625433, 0.6553049859225976, 0.9610762848729212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 55}], {
             RGBColor[
             0.5058925908015232, 0.6072884038300044, 0.954950071865273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 108}], {
             RGBColor[
             0.4748275835494312, 0.5821330512402743, 0.9524603398165841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 111}], {
             RGBColor[
             0.6377087576107985, 0.7109934558025407, 0.967894752134561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 115}], {
             RGBColor[
             0.4650507638848177, 0.5741957885958344, 0.9516906727589153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 133}], {
             RGBColor[
             0.35081426407846916`, 0.47827941593233814`, 0.9435745525875747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 163}], {
             RGBColor[
             0.631651942117202, 0.7061639155358237, 0.9673170476657988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 165}], {
             RGBColor[
             0.621260460518335, 0.6978780301781409, 0.9663258988743137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 175}], {
             RGBColor[
             0.4825056083728978, 0.588366417683041, 0.953064782056219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 38}], {
             RGBColor[
             0.7914022558767777, 0.8347208998964095, 0.8674325142463462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[
             0.7197149246002337, 0.7763484693526973, 0.8618369429212122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 60}], {
             RGBColor[
             0.9937888380316584, 0.9916995391535786, 0.7525985579947259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 111}], {
             RGBColor[
             0.9513543316662867, 0.9612033305272079, 0.8826363372187218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 165}], {
             RGBColor[
             0.9349060345738233, 0.9480879049028081, 0.8810674839584745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 58}], {
             RGBColor[
             0.8097022379113323, 0.851725043375973, 0.9815450780738659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 67}], {
             RGBColor[
             0.7374694366415819, 0.7948359959704951, 0.9744677194668687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 80}], {
             RGBColor[
             0.7898194905335612, 0.8358710803197382, 0.9796486438794361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 82}], {
             RGBColor[
             0.844528947897121, 0.8792143625904631, 0.9751398980765505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 96}], {
             RGBColor[
             0.617602315943993, 0.6989026928075981, 0.9640876730131213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 98}], {
             RGBColor[
             0.8648622407139637, 0.893871660107601, 0.9180057395509793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 99}], {
             RGBColor[
             0.7623619021049459, 0.8142821791802196, 0.9769487677909414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[
             0.8224405408163558, 0.8618822203404175, 0.9827600687765643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 116}], {
             RGBColor[
             0.7604453004791475, 0.812784915423434, 0.9767577388525424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 120}], {
             RGBColor[
             0.7117312366422467, 0.7747291185134493, 0.9719023762280892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 122}], {
             RGBColor[
             0.5699760088616412, 0.6587211799520001, 0.9607573224941939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 124}], {
             RGBColor[
             0.7643662838982341, 0.8158480174710021, 0.9771485458360836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 125}], {
             RGBColor[
             0.7940414926601561, 0.8392375902122904, 0.9800513422112964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 128}], {
             RGBColor[
             0.781371623515388, 0.8291349804706886, 0.9788428787817427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 136}], {
             RGBColor[
             0.7730476985559296, 0.822630004582789, 0.9780138281167301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 137}], {
             RGBColor[
             0.812099775891064, 0.8536367750815762, 0.9817737573866803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.7549447022154396, 0.8084878062537303, 0.9762094906236292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 170}], {
             RGBColor[
             0.8450858731981863, 0.8796297165681162, 0.9741971688112288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 187}], {
             RGBColor[
             0.7612040897759155, 0.8133776873890814, 0.976833367878355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 192}], {
             RGBColor[
             0.7015296883218951, 0.7667595914309518, 0.9708855812304058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 198}], {
             RGBColor[
             0.496709580968666, 0.5899169071612653, 0.9562845415832655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 29}], {
             RGBColor[
             0.5215890405929642, 0.622488506328698, 0.95548054640054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 30}], {
             RGBColor[
             0.7184608122429292, 0.7791938575618573, 0.9733032522735642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 42}], {
             RGBColor[
             0.426408730902087, 0.5392378612744678, 0.9492591460091583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 62}], {
             RGBColor[
             0.691488274830105, 0.7576866883788951, 0.9707305875764606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 71}], {
             RGBColor[
             0.6526129683116819, 0.7273028381451192, 0.9668596193730348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 73}], {
             RGBColor[
             0.43880189648340234`, 0.5515595457842947, 0.9499907069976887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 75}], {
             RGBColor[
             0.7193316235974758, 0.7798882188984283, 0.9733863110379433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 89}], {
             RGBColor[
             0.6066906742238831, 0.691427992981369, 0.9622825142666005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 127}], {
             RGBColor[
             0.7751708110549546, 0.8222200954164133, 0.89443982034924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 129}], {
             RGBColor[
             0.7420617867969734, 0.6933225412120447, 0.6077052711279489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 141}], {
             RGBColor[
             0.588801994041581, 0.6770550098473322, 0.9607717963051761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 142}], {
             RGBColor[
             0.5770953692278264, 0.6675510444460883, 0.9598502079170577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 147}], {
             RGBColor[
             0.7746298324568901, 0.8219963868635978, 0.9034052357268998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 149}], {
             RGBColor[
             0.5302396738093228, 0.6295114800803232, 0.9561615559356453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 155}], {
             RGBColor[
             0.7258746238294724, 0.7851054296784123, 0.9740103882410764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 167}], {
             RGBColor[
             0.578480230558539, 0.6686753372616528, 0.9599592292739256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 168}], {
             RGBColor[
             0.49287956618828915`, 0.5983989052599582, 0.9534364882922785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 188}], {
             RGBColor[
             0.5717131709704804, 0.6631815334355065, 0.9594265015545975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 189}], {
             RGBColor[
             0.46053886513002495`, 0.5703870154941882, 0.951375767418605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[
             0.7653144281706654, 0.8156848901070222, 0.9476514257970738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 197}], {
             RGBColor[
             0.7781916161874918, 0.8233495749379003, 0.8356762603142747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 97}], {
             RGBColor[
             0.5920962593829082, 0.6783440864601948, 0.9619706482011888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 105}], {
             RGBColor[
             0.6203757023055727, 0.7013214154060663, 0.9641917141569921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.6518373292608325, 0.7254962645110179, 0.967609119895048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 71}], {
             RGBColor[
             0.6129620227424094, 0.695112414277242, 0.9637381516916224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 73}], {
             RGBColor[
             0.3991509509141299, 0.5193691219164174, 0.9468692393162763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 129}], {
             RGBColor[
             0.702410841227701, 0.6611321173441675, 0.6045838034465364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 141}], {
             RGBColor[
             0.5491510484723086, 0.644864585979455, 0.9576503286237636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 149}], {
             RGBColor[
             0.49058872824005034`, 0.597321056212446, 0.9530400882542328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 167}], {
             RGBColor[
             0.5388292849892666, 0.6364849133937756, 0.956837761592513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 168}], {
             RGBColor[
             0.4532286206190167, 0.5662084813920809, 0.9503150206108659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 189}], {
             RGBColor[
             0.4208879195607525, 0.538196591626311, 0.9482542997371923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 194}], {
             RGBColor[
             0.7256634826013929, 0.7834944662391449, 0.9445299581156614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 197}], {
             RGBColor[
             0.7385406706182193, 0.791159151070023, 0.8325547926328621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 42}], {
             RGBColor[
             0.5836295569827795, 0.6637527886397498, 0.9639603842007699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 51}], {
             RGBColor[
             0.8820136603937507, 0.7447972155857827, 0.6082748649131611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 71}], {
             RGBColor[
             0.8098337943923744, 0.8518177655104012, 0.9815608575646464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 73}], {
             RGBColor[
             0.5960227225640948, 0.6760744731495767, 0.9646919451893003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 76}], {
             RGBColor[
             0.7202169031816232, 0.7806195312968844, 0.9734414981850312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 81}], {
             RGBColor[
             0.642281397786705, 0.7161414125987817, 0.9676395070695447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 87}], {
             RGBColor[
             0.5273043191618109, 0.6045513924635697, 0.9607527452325879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 89}], {
             RGBColor[
             0.7639115003045756, 0.8159429203466511, 0.9769837524582121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 106}], {
             RGBColor[
             0.5920824269390531, 0.6726372909067032, 0.9644417626398792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 107}], {
             RGBColor[
             0.7479146326654962, 0.8031057958603862, 0.9756219649101279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 130}], {
             RGBColor[
             0.7706899818982721, 0.8212383216860148, 0.9776593681549598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 131}], {
             RGBColor[
             0.9285869551247156, 0.9447131660749035, 0.952108712946464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 142}], {
             RGBColor[
             0.7343161953085189, 0.7920659718113703, 0.9745514461086693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 147}], {
             RGBColor[
             0.9318506585375826, 0.9465113142288799, 0.9181064739185114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 157}], {
             RGBColor[
             0.8527317029144048, 0.8854091293912311, 0.9858155051381955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 168}], {
             RGBColor[
             0.6501003922689816, 0.7229138326252402, 0.9681377264838901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 176}], {
             RGBColor[
             0.6884105813358261, 0.754797726363996, 0.9709375880189342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 188}], {
             RGBColor[
             0.7289339970511728, 0.7876964608007884, 0.9741277397462091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 197}], {
             RGBColor[
             0.9354124422681842, 0.9478645023031822, 0.8503774985058863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 34}], {
             RGBColor[
             0.4564567456964004, 0.5677752558902721, 0.9508603635218549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[
             0.6893972590682631, 0.7480653492707356, 0.7176421216776006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 45}], {
             RGBColor[
             0.4497962865827788, 0.5623679951315704, 0.950336027782365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 64}], {
             RGBColor[
             0.444646894046855, 0.5581874862934173, 0.9499306487390907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 65}], {
             RGBColor[
             0.6051302996641792, 0.6857210576081898, 0.9644629408533176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 132}], {
             RGBColor[
             0.496557107796395, 0.6003305363437736, 0.954017210918833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 138}], {
             RGBColor[
             0.39036560310320173`, 0.5125367978874611, 0.9460947289363548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 153}], {
             RGBColor[
             0.6351648262099764, 0.7096697738103037, 0.9673276608073942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 156}], {
             RGBColor[
             0.6901555138053379, 0.7496871794820248, 0.800173470402388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 182}], {
             RGBColor[
             0.5442771900316172, 0.6381451751461444, 0.958407482481153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 185}], {
             RGBColor[
             0.6688565648392633, 0.6779715056123925, 0.6130212139195694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 199}], {
             RGBColor[
             0.6862384135590955, 0.7486483562097045, 0.9073224049196079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 39}], {
             RGBColor[
             0.7211222607349304, 0.7801819650989841, 0.9542108207017572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 57}], {
             RGBColor[
             0.4156068536816104, 0.5335612785703312, 0.9479346823133625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 103}], {
             RGBColor[
             0.6596037379112848, 0.731705276222347, 0.9683311393887002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 117}], {
             RGBColor[
             0.7250902319772421, 0.7831412715545435, 0.9474940804011696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 133}], {
             RGBColor[
             0.4103048834569234, 0.5289689784464792, 0.9475968454589937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 152}], {
             RGBColor[
             0.3973193580444966, 0.5177215690057195, 0.946769419262363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 178}], {
             RGBColor[
             0.708602341625197, 0.7707754327921543, 0.973004669952503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 44}], {
             RGBColor[
             0.473425601067068, 0.5821361321955638, 0.9520346333533817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 58}], {
             RGBColor[
             0.7082681443374236, 0.7709099924586609, 0.9725112047936681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 68}], {
             RGBColor[
             0.4962253631322169, 0.6018841401470345, 0.9534874140311349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 77}], {
             RGBColor[
             0.7427666812676392, 0.7981545607456387, 0.9666615361781967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 96}], {
             RGBColor[
             0.5161682223700842, 0.6180876418902861, 0.9550537997329235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 99}], {
             RGBColor[
             0.6609278085310372, 0.7334671282629075, 0.9679148945107436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 102}], {
             RGBColor[
             0.6335521805431514, 0.7120810796162924, 0.9651863477526998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 128}], {
             RGBColor[
             0.6799375299414794, 0.7483199295533765, 0.9698090055015449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 140}], {
             RGBColor[
             0.7345544047816069, 0.6976542128410717, 0.6095148410739168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 162}], {
             RGBColor[
             0.7671486162089738, 0.8140810327113485, 0.8099454366207708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 172}], {
             RGBColor[
             0.5556249581995234, 0.6501203975423175, 0.9581599785122027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 180}], {
             RGBColor[
             0.6545588091038398, 0.7284916175041924, 0.9672800921695242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 40}], {
             RGBColor[
             0.7601515015845128, 0.8073427500526766, 0.7227048848667801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 45}], {
             RGBColor[
             0.5205505290990285, 0.6216453959135114, 0.9553987909715445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 54}], {
             RGBColor[
             0.6803601619632944, 0.7485671961175251, 0.9699525926528199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 64}], {
             RGBColor[
             0.5154011365631047, 0.6174648870753583, 0.9549934119282701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 65}], {
             RGBColor[
             0.6758845421804289, 0.7449984583901308, 0.9695257040424972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 132}], {
             RGBColor[
             0.5673113503126448, 0.6596079371257146, 0.9590799741080125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 138}], {
             RGBColor[
             0.46111984561945146`, 0.5718141986694021, 0.9511574921255344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 153}], {
             RGBColor[
             0.7059190687262261, 0.7689471745922447, 0.9723904239965737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 182}], {
             RGBColor[
             0.615031432547867, 0.6974225759280854, 0.9634702456703325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 185}], {
             RGBColor[
             0.739610807355513, 0.7372489063943335, 0.6180839771087488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 199}], {
             RGBColor[
             0.7569926560753453, 0.8079257569916455, 0.9123851681087873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 86}], {
             RGBColor[
             0.8764418931370912, 0.4201084110544064, 0.3553794767358591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.7967094678714813, 0.3590560374447055, 0.4348999603464041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 110}], {
             RGBColor[
             0.6358617379394872, 0.22415640198302103`, 0.42243043736217323`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 174}], {
             RGBColor[
             0.6522666469244089, 0.24057207119765978`, 0.42339495062760646`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 63}], {
             RGBColor[
             0.9015923593240371, 0.646035712026416, 0.23959859123902405`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 70}], {
             RGBColor[
             0.9448609442051907, 0.8147185906258779, 0.5304294905166165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 110}], {
             RGBColor[
             0.5865480210371429, 0.5218480902699858, 0.5886246928090213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 138}], {
             RGBColor[
             0.6475887656410386, 0.5780283576287497, 0.5923929655357786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 145}], {
             RGBColor[
             0.82627005904673, 0.7229870178442226, 0.607174531936164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 185}], {
             RGBColor[
             0.9260797273771001, 0.7434630653536811, 0.25931945051899313`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 45}], {
             RGBColor[
             0.7334306778813474, 0.7903423888033694, 0.9596829903723586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 47}], {
             RGBColor[
             0.9562661764190742, 0.9669039664976851, 0.9589141351012285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 50}], {
             RGBColor[
             0.9164286325960774, 0.9357539274207143, 0.9764485148921904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 97}], {
             RGBColor[
             0.7027983890531969, 0.7654549135569241, 0.9572766997681168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 101}], {
             RGBColor[
             0.9685993027789779, 0.9760961240444561, 0.9377745926711663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 105}], {
             RGBColor[
             0.7310778319758613, 0.7884322425027956, 0.9594977657239201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 134}], {
             RGBColor[
             0.9688210246989785, 0.9761878117563698, 0.9341000866588206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 135}], {
             RGBColor[
             0.9512230039874187, 0.9631427767555933, 0.9674509105579928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 160}], {
             RGBColor[
             0.9085822709579282, 0.9294974516342669, 0.9757001219146141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 43}], {
             RGBColor[
             0.5186182019523488, 0.6199032201495484, 0.9552945890925129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 60}], {
             RGBColor[
             0.7926921153837735, 0.8352542899504296, 0.8460562041660267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 90}], {
             RGBColor[
             0.6799391549225764, 0.7490955099231973, 0.9692788203952112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 111}], {
             RGBColor[
             0.7502576090184019, 0.8047580813240589, 0.9760939833900225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 165}], {
             RGBColor[
             0.7338093119259383, 0.7916426556996592, 0.9745251301297753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 169}], {
             RGBColor[
             0.6641582530995276, 0.7367673494797357, 0.9677059275824019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 41}], {
             RGBColor[
             0.8637809626053334, 0.8940509888572165, 0.9667731147965356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 74}], {
             RGBColor[
             0.7777927407042529, 0.8261896137141092, 0.9586721284757505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 85}], {
             RGBColor[
             0.8725847329405703, 0.9009285611542363, 0.9676505923476406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 88}], {
             RGBColor[
             0.7909127480116473, 0.8368410266958455, 0.9597049835111588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 108}], {
             RGBColor[
             0.7712513944922212, 0.8208790541748932, 0.9581571697401985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 117}], {
             RGBColor[
             0.9620234235415779, 0.9711977119750212, 0.949168617453365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 133}], {
             RGBColor[
             0.6472380750212592, 0.717025418866957, 0.9492713825111891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 152}], {
             RGBColor[
             0.6342525496088324, 0.7057780094261974, 0.9484439563145586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 159}], {
             RGBColor[
             0.7741804927640796, 0.8232570281063611, 0.9583877590857998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 173}], {
             RGBColor[
             0.9637221612391802, 0.9724646277684654, 0.9462930976330739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 178}], {
             RGBColor[
             0.9455355331895328, 0.9588318732126322, 0.9746792070046986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 49}], {
             RGBColor[
             0.8346786185754909, 0.8673278209541997, 0.7289270491896114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 53}], {
             RGBColor[
             0.9157515997169727, 0.9308115900714783, 0.736968122164069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 54}], {
             RGBColor[
             0.9133006753351571, 0.9288572894979885, 0.7367343508085654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 64}], {
             RGBColor[
             0.7483416499349674, 0.7977549804558217, 0.7217751700840158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.9088250555522916, 0.9252885517705942, 0.7363074621982428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 69}], {
             RGBColor[
             0.9455940343885467, 0.9546071374272818, 0.7398145202236996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 119}], {
             RGBColor[
             0.7131927565350957, 0.7686758131800282, 0.7191583497346549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 123}], {
             RGBColor[
             0.6941267989374473, 0.7521618389918372, 0.7179434837758971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 132}], {
             RGBColor[
             0.8002518636845075, 0.8398980305061781, 0.725861732263758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 171}], {
             RGBColor[
             0.8533209662708502, 0.8818913646609046, 0.7307851441852405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 182}], {
             RGBColor[
             0.8479719459197297, 0.8777126693085489, 0.7302520038260781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 191}], {
             RGBColor[
             0.6394917731200915, 0.7027266738777057, 0.7145395574196476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 195}], {
             RGBColor[
             0.7758840636307199, 0.820115152665631, 0.7239434097813312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 196}], {
             RGBColor[
             0.933162240465136, 0.7524464516889708, 0.3527105220427971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 199}], {
             RGBColor[
             0.989933169447208, 0.988215850372109, 0.679166926264533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 74}], {
             RGBColor[
             0.68351825101032, 0.7520021970518638, 0.9695598855183334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 85}], {
             RGBColor[
             0.7783102432466373, 0.8267411444919909, 0.9785383493902235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.6966382583177144, 0.7626536100336001, 0.9705927405537418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 108}], {
             RGBColor[
             0.6769769047982884, 0.7466916375126478, 0.9690449267827814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 121}], {
             RGBColor[
             0.7011534086711572, 0.7663192124957303, 0.9709481897291055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 133}], {
             RGBColor[
             0.5529635853273264, 0.6428380022047117, 0.9601591395537721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 140}], {
             RGBColor[
             0.8495020685891677, 0.7890261675318504, 0.6198956207435113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 151}], {
             RGBColor[
             0.8607585497048882, 0.8336543641557125, 0.628952849672791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 152}], {
             RGBColor[
             0.5399780599148996, 0.631590592763952, 0.9593317133571415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 159}], {
             RGBColor[
             0.6799060030701467, 0.7490696114441158, 0.9692755161283827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 161}], {
             RGBColor[
             0.5049145050114772, 0.5948940872005494, 0.9573291284255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 173}], {
             RGBColor[
             0.8694476715452473, 0.89827721110622, 0.9571808546756568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 51}], {
             RGBColor[
             0.5899615790529087, 0.5048412192983932, 0.5842307586487552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 71}], {
             RGBColor[
             0.5177817130515322, 0.6118617692230117, 0.9575167513002405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 73}], {
             RGBColor[
             0.3039706412232527, 0.43611847686218713`, 0.9406478389248945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 76}], {
             RGBColor[
             0.4281648218407811, 0.5406635350094948, 0.9493973919206253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 81}], {
             RGBColor[
             0.35022931644586286`, 0.4761854163113922, 0.9435954008051388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 87}], {
             RGBColor[
             0.23525223782096866`, 0.36459539617618014`, 0.936708638968182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 89}], {
             RGBColor[
             0.4718594189637334, 0.5759869240592616, 0.9529396461938062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 106}], {
             RGBColor[
             0.30003034559821096`, 0.4326812946193137, 0.9403976563754733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 107}], {
             RGBColor[
             0.45586255132465403`, 0.5631497995729967, 0.951577858645722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 130}], {
             RGBColor[
             0.47863790055742994`, 0.5812823253986253, 0.9536152618905539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 131}], {
             RGBColor[
             0.6365348737838734, 0.7047571697875141, 0.9280646066820581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 142}], {
             RGBColor[
             0.44226411396767673`, 0.5521099755239808, 0.9505073398442634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 147}], {
             RGBColor[
             0.6397985771967405, 0.7065553179414903, 0.8940623676541055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 149}], {
             RGBColor[
             0.3954084185491731, 0.5140704111582157, 0.9468186878628511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 157}], {
             RGBColor[
             0.5606796215735625, 0.6454531331038416, 0.9617713988737896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 168}], {
             RGBColor[
             0.3580483109281395, 0.4829578363378507, 0.9440936202194842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 176}], {
             RGBColor[
             0.39635849999498396`, 0.5148417300766064, 0.9468934817545283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 188}], {
             RGBColor[
             0.43688191571033064`, 0.5477404645133989, 0.9500836334818032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 189}], {
             RGBColor[
             0.32570760986987524`, 0.4549459465720807, 0.9420328993458107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 197}], {
             RGBColor[
             0.643360360927342, 0.7079085060157928, 0.8263333922414804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 60}], {
             RGBColor[
             0.7210047841072293, 0.7768818594067173, 0.8404606328408927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[
             0.6082518236460323, 0.6907230793794852, 0.9636832490700773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 111}], {
             RGBColor[
             0.6785702777418577, 0.7463856507803468, 0.9704984120648885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 115}], {
             RGBColor[
             0.505912284015877, 0.6095879835736404, 0.9542943326892428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 163}], {
             RGBColor[
             0.6725134622482614, 0.7415561105136298, 0.9699207075961264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 165}], {
             RGBColor[
             0.6621219806493943, 0.733270225155947, 0.9689295588046413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 169}], {
             RGBColor[
             0.5924709218229836, 0.6783949189360234, 0.9621103562572679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 58}], {
             RGBColor[
             0.6420826001082125, 0.715926461840811, 0.9676465256471201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 68}], {
             RGBColor[
             0.4300398189030058, 0.5469006095291846, 0.9486227348845868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 77}], {
             RGBColor[
             0.676581137038428, 0.743171030127789, 0.9617968570316486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 96}], {
             RGBColor[
             0.4499826781408731, 0.5631041112724362, 0.9501891205863754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 99}], {
             RGBColor[
             0.5947422643018261, 0.6784835976450576, 0.9630502153641955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 102}], {
             RGBColor[
             0.5673666363139402, 0.6570975489984425, 0.9603216686061518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[
             0.6137519857122682, 0.6933363989355266, 0.9649443263549968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 143}], {
             RGBColor[
             0.6547358954516687, 0.7260158560831307, 0.968853408252709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 166}], {
             RGBColor[
             0.5873250644123198, 0.6726892247185683, 0.9623109381968833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 172}], {
             RGBColor[
             0.4894394139703124, 0.5951368669244678, 0.9532952993656546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 198}], {
             RGBColor[
             0.3290899431655462, 0.45411832562610344`, 0.9423859891565196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 64}], {
             RGBColor[
             0.5087406774494831, 0.6120576263166566, 0.9544690761887803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 112}], {
             RGBColor[
             0.7279444246088402, 0.7862507500956488, 0.9689697861186934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 132}], {
             RGBColor[
             0.5606508911990231, 0.654200676367013, 0.9585556383685225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 134}], {
             RGBColor[
             0.749280416803038, 0.8020835581078101, 0.9292915515185166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 153}], {
             RGBColor[
             0.6992586096126046, 0.763539913833543, 0.9718660882570838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 156}], {
             RGBColor[
             0.7542492972079661, 0.8035573195052641, 0.8047118978520775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 183}], {
             RGBColor[
             0.7486726560835506, 0.8017098311901238, 0.933882297020616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 47}], {
             RGBColor[
             0.9675537371100609, 0.9492678606471479, 0.6564197917436971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 50}], {
             RGBColor[
             0.9277161932870641, 0.9181178215701773, 0.6739541715346592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 101}], {
             RGBColor[
             0.9798868634699647, 0.958460018193919, 0.6352802493136349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 105}], {
             RGBColor[
             0.7423653926668481, 0.7707961366522584, 0.6570034223663889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 135}], {
             RGBColor[
             0.9625105646784053, 0.9455066709050561, 0.6649565672004616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 144}], {
             RGBColor[
             0.6685050092549217, 0.70833888801927, 0.651877979188253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 50}], {
             RGBColor[
             0.9197235232378638, 0.9382112514664703, 0.9708711244807564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 101}], {
             RGBColor[
             0.9718941934207642, 0.978553448090212, 0.9321972022597321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 105}], {
             RGBColor[
             0.7343727226176476, 0.7908895665485516, 0.9539203753124861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 134}], {
             RGBColor[
             0.9721159153407648, 0.9786451358021258, 0.9285226962473865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 135}], {
             RGBColor[
             0.954517894629205, 0.9656001008013493, 0.9618735201465587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 144}], {
             RGBColor[
             0.6605123392057213, 0.7284323179155632, 0.9487949321343501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 72}], {
             RGBColor[
             0.6059199961190089, 0.6896355272760433, 0.9630195874359732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 76}], {
             RGBColor[
             0.6465306961492554, 0.7226051230517849, 0.96621661050425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 81}], {
             RGBColor[
             0.5685951907543372, 0.6581270043536822, 0.9604146193887635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 87}], {
             RGBColor[
             0.4536181121294429, 0.5465369842184702, 0.9535278575518067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 104}], {
             RGBColor[
             0.84884904721899, 0.8821854092272046, 0.9551277763079042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 106}], {
             RGBColor[
             0.5183962199066852, 0.6146228826616037, 0.9572168749590979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 147}], {
             RGBColor[
             0.8581644515052147, 0.8884969059837804, 0.9108815862377302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 154}], {
             RGBColor[
             0.5654291351394287, 0.6553847261106307, 0.9602128811246146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 157}], {
             RGBColor[
             0.779045495882037, 0.8273947211461316, 0.9785906174574142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 158}], {
             RGBColor[
             0.7911542586312429, 0.8370499198787396, 0.9797455620580535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 176}], {
             RGBColor[
             0.6147243743034583, 0.6967833181188965, 0.9637127003381529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 53}], {
             RGBColor[
             0.757338203336088, 0.8105065675925379, 0.9764085283311548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 54}], {
             RGBColor[
             0.7548872789542724, 0.8085522670190481, 0.9761747569756511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 65}], {
             RGBColor[
             0.750411659171407, 0.8049835292916538, 0.9757478683653285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 69}], {
             RGBColor[
             0.787180638007662, 0.8343021149483414, 0.9792549263907854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 92}], {
             RGBColor[
             0.7457779361287302, 0.8013266589167901, 0.9752958330484056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 118}], {
             RGBColor[
             0.6577991207210268, 0.7325505854907288, 0.9665586195336616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 119}], {
             RGBColor[
             0.554779360154211, 0.6483707907010878, 0.9585987559017406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 123}], {
             RGBColor[
             0.5357134025565626, 0.6318568165128968, 0.9573838899429827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 127}], {
             RGBColor[
             0.8326834290711393, 0.8683920295557552, 0.8993225409866121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[
             0.7995744048131582, 0.7394944753513868, 0.6125879917653212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 139}], {
             RGBColor[
             0.5027065037015158, 0.6032678996996287, 0.9552807195347938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 141}], {
             RGBColor[
             0.6463146120577657, 0.7232269439866742, 0.9656545169425483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 146}], {
             RGBColor[
             0.8178632516696172, 0.8109691611057821, 0.632691308504308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 155}], {
             RGBColor[
             0.7833872418456571, 0.8312773638177544, 0.9788931088784486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 171}], {
             RGBColor[
             0.6949075698899655, 0.7615863421819642, 0.9702255503523263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 191}], {
             RGBColor[
             0.4810783767392068, 0.5824216513987653, 0.9539799635867332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 195}], {
             RGBColor[
             0.6174706672498352, 0.6998101301866906, 0.9633838159484168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 196}], {
             RGBColor[
             0.7747488440842513, 0.6321414292100305, 0.5921509282098828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 199}], {
             RGBColor[
             0.8315197730663233, 0.8679108278931686, 0.9186073324316186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 97}], {
             RGBColor[
             0.6662557358719865, 0.7367621985257093, 0.9692336891476447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 101}], {
             RGBColor[
             0.9320566495977675, 0.9474034090132415, 0.9497315820506942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 105}], {
             RGBColor[
             0.6945351787946509, 0.7597395274715809, 0.971454755103448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 134}], {
             RGBColor[
             0.932278371517768, 0.9474950967251551, 0.9460570760383484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 135}], {
             RGBColor[
             0.9146803508062082, 0.9344500617243786, 0.9794078999375206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 144}], {
             RGBColor[
             0.6206747953827245, 0.6972822788385925, 0.966329311925312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 73}], {
             RGBColor[
             0.6023547446342239, 0.51716290380822, 0.5849623196372857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 87}], {
             RGBColor[
             0.5336363412319399, 0.44563982312221306`, 0.5810231196805732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 106}], {
             RGBColor[
             0.5984144490091823, 0.5137257215653466, 0.5847121370878645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[
             0.7542466547356254, 0.6441942265190297, 0.5958923393581133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 130}], {
             RGBColor[
             0.7770220039684013, 0.6623267523446583, 0.5979297426029451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 131}], {
             RGBColor[
             0.9349189771948447, 0.785801596733547, 0.5723790873944494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 147}], {
             RGBColor[
             0.9381826806077118, 0.7875997448875233, 0.5383768483664968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 157}], {
             RGBColor[
             0.8590637249845339, 0.7264975600498744, 0.6060858795861808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 168}], {
             RGBColor[
             0.6564324143391107, 0.5640022632838837, 0.5884081009318753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 189}], {
             RGBColor[
             0.6240917132808466, 0.5359903735181136, 0.5863473800582018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 197}], {
             RGBColor[
             0.9417444643383133, 0.7889529329618257, 0.47064787295387156`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 66}], {
             RGBColor[
             0.7195790024895609, 0.7366954713187899, 0.6320263850554902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 80}], {
             RGBColor[
             0.6564767099844896, 0.7291511198460221, 0.9681028018751817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 82}], {
             RGBColor[
             0.7111861673480494, 0.772494402116747, 0.9635940560722962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 100}], {
             RGBColor[
             0.6890977602672842, 0.7551622598667014, 0.9712142267723101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 120}], {
             RGBColor[
             0.5783884560931751, 0.6680091580397332, 0.9603565342238348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 124}], {
             RGBColor[
             0.6310235033491626, 0.709128056997286, 0.9656027038318292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 125}], {
             RGBColor[
             0.6606987121110846, 0.7325176297385743, 0.9685055002070422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 187}], {
             RGBColor[
             0.6278613092268439, 0.7066577269153652, 0.9652875258741007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 54}], {
             RGBColor[
             0.8359602600957543, 0.8720360361363269, 0.9842158299501088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 65}], {
             RGBColor[
             0.8314846403128888, 0.8684672984089324, 0.9837889413397862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 69}], {
             RGBColor[
             0.8682536191491439, 0.89778588406562, 0.987295999365243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 92}], {
             RGBColor[
             0.8268509172702121, 0.8648104280340687, 0.9833369060228633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 118}], {
             RGBColor[
             0.7388721018625086, 0.7960343546080075, 0.9745996925081193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 119}], {
             RGBColor[
             0.6358523412956929, 0.7118545598183663, 0.9666398288761983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 123}], {
             RGBColor[
             0.6167863836980445, 0.6953405856301755, 0.9654249629174405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 127}], {
             RGBColor[
             0.9137564102126212, 0.9318757986730339, 0.9073636139610699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 129}], {
             RGBColor[
             0.8806473859546401, 0.8029782444686654, 0.6206290647397789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 139}], {
             RGBColor[
             0.5837794848429977, 0.6667516688169073, 0.9633217925092514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 141}], {
             RGBColor[
             0.7273875931992476, 0.7867107131039528, 0.9736955899170061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 146}], {
             RGBColor[
             0.898936232811099, 0.8744529302230607, 0.6407323814787657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 155}], {
             RGBColor[
             0.864460222987139, 0.8947611329350329, 0.9869341818529063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 171}], {
             RGBColor[
             0.7759805510314474, 0.8250701112992428, 0.9782666233267839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 182}], {
             RGBColor[
             0.7706315306803269, 0.8208914159468871, 0.9777334829676214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 191}], {
             RGBColor[
             0.5621513578806887, 0.6459054205160439, 0.962021036561191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 195}], {
             RGBColor[
             0.6985436483913171, 0.7632938993039691, 0.9714248889228745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 196}], {
             RGBColor[
             0.8558218252257331, 0.6956251983273091, 0.6001920011843405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 199}], {
             RGBColor[
             0.9125927542078052, 0.9313945970104471, 0.9266484054060764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 64}], {
             RGBColor[
             0.668550310313749, 0.7389794265206703, 0.9690228778700556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 65}], {
             RGBColor[
             0.8290337159310732, 0.8665129978354427, 0.9835551699842826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 118}], {
             RGBColor[
             0.736421177480693, 0.7940800540345178, 0.9743659211526157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 119}], {
             RGBColor[
             0.6334014169138773, 0.7099002592448767, 0.9664060575206946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 123}], {
             RGBColor[
             0.6143354593162289, 0.6933862850566858, 0.9651911915619369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 127}], {
             RGBColor[
             0.9113054858308056, 0.9299214980995442, 0.9071298426055663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 140}], {
             RGBColor[
             0.8815034999904368, 0.8141352492157834, 0.6230562141212546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 151}], {
             RGBColor[
             0.8927599811061573, 0.8587634458396455, 0.6321134430505343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 155}], {
             RGBColor[
             0.8620092986053234, 0.8928068323615432, 0.9867004104974026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 171}], {
             RGBColor[
             0.7735296266496318, 0.823115810725753, 0.9780328519712803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 172}], {
             RGBColor[
             0.7025740534083533, 0.7666014339170293, 0.9717013515595404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 191}], {
             RGBColor[
             0.5597004334988731, 0.6439511199425543, 0.9617872652056874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 195}], {
             RGBColor[
             0.6960927240095015, 0.7613395987304794, 0.9711911175673709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 199}], {
             RGBColor[
             0.9101418298259896, 0.9294402964369575, 0.9264146340505728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 90}], {
             RGBColor[
             0.7080750639028099, 0.7718728885814594, 0.971537963098299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 108}], {
             RGBColor[
             0.6155123439372683, 0.6986750554200546, 0.9629187137751334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 111}], {
             RGBColor[
             0.7783935179986354, 0.827535459982321, 0.9783531260931102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 115}], {
             RGBColor[
             0.6057355242726548, 0.6907377927756146, 0.9621490467174645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 163}], {
             RGBColor[
             0.772336702505039, 0.822705919715604, 0.9777754216243479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.761945220906172, 0.8144200343579212, 0.9767842728328628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 175}], {
             RGBColor[
             0.6231903687607347, 0.7049084218628213, 0.9635231560147683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 177}], {
             RGBColor[
             0.8067388178117272, 0.8119197183012468, 0.6456613652587107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 183}], {
             RGBColor[
             0.8150162966855272, 0.8555059676176112, 0.9391492923164998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 109}], {
             RGBColor[
             0.7901003637287773, 0.6539199918858846, 0.5955935312847495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 148}], {
             RGBColor[
             0.6912476261433642, 0.7587271663105166, 0.969860761363784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 150}], {
             RGBColor[
             0.7040551881801735, 0.7687325311147487, 0.971137299454141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 193}], {
             RGBColor[
             0.8447894393215475, 0.868752802925733, 0.6890392299724575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 88}], {
             RGBColor[
             0.48539734095832726`, 0.5902203401671927, 0.9534288451227642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 91}], {
             RGBColor[
             0.33046206349758167`, 0.46065136272051765`, 0.9422777283633049]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 103}], {
             RGBColor[
             0.5910215224223005, 0.673141030114172, 0.9637295380525011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 117}], {
             RGBColor[
             0.656508016488258, 0.7245770254463685, 0.9428924790649704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 121}], {
             RGBColor[
             0.48991249131177, 0.5938859426293229, 0.9537842942981278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 152}], {
             RGBColor[
             0.32873714255551234`, 0.4591573228975446, 0.9421678179261639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 164}], {
             RGBColor[
             0.36291869822111766`, 0.4887636684001506, 0.9443458364276134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 178}], {
             RGBColor[
             0.6400201261362128, 0.7122111866839793, 0.9684030686163039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 200}], {
             RGBColor[
             0.5328565328537365, 0.6275805806809449, 0.957964442486394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 77}], {
             RGBColor[
             0.9114236803087836, 0.9319448903908859, 0.9822734284719352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 96}], {
             RGBColor[
             0.6848252214112287, 0.7518779715355333, 0.9706656920266619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 99}], {
             RGBColor[
             0.8295848075721817, 0.8672574579081547, 0.983526786804482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 102}], {
             RGBColor[
             0.8022091795842958, 0.8458714092615396, 0.9807982400464382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 125}], {
             RGBColor[
             0.8612643981273919, 0.8922128689402254, 0.9866293612248371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 128}], {
             RGBColor[
             0.8485945289826238, 0.8821102591986236, 0.9854208977952834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 137}], {
             RGBColor[
             0.8793226813582997, 0.9066120538095113, 0.9883517764002209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 166}], {
             RGBColor[
             0.8221676076826754, 0.8614630849816654, 0.9827875096371699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 170}], {
             RGBColor[
             0.912308778665422, 0.9326049952960512, 0.9807751878247695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 192}], {
             RGBColor[
             0.7687525937891309, 0.8197348701588869, 0.9774636002439465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 198}], {
             RGBColor[
             0.5639324864359018, 0.6428921858892005, 0.9628625605968061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 62}], {
             RGBColor[
             0.7956215182046869, 0.840279009378093, 0.9802600164550436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 92}], {
             RGBColor[
             0.7923985614871274, 0.837747045776646, 0.9799425412896163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 114}], {
             RGBColor[
             0.6545725316680276, 0.7285027580999945, 0.9672811724600444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 146}], {
             RGBColor[
             0.8644838770280143, 0.8473895479656379, 0.6373380167455187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 184}], {
             RGBColor[
             0.7399007336403625, 0.796735343664484, 0.9747100484299449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 186}], {
             RGBColor[
             0.8818383530704341, 0.9049013077448327, 0.7922524599479279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[
             0.8694476715452473, 0.89827721110622, 0.9571808546756568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 90}], {
             RGBColor[
             0.8823257370774569, 0.9060741491803663, 0.854444864143591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 111}], {
             RGBColor[
             0.9526441911732825, 0.9617367205812279, 0.8612600271384023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 165}], {
             RGBColor[
             0.936195894080819, 0.9486212949568282, 0.859691173878155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 169}], {
             RGBColor[
             0.8665448352544083, 0.8937459887369046, 0.8528719713307817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 67}], {
             RGBColor[
             0.8129691514582903, 0.854410977805695, 0.981835187944957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 79}], {
             RGBColor[
             0.5427761057260871, 0.6185557400721196, 0.9619758334299799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 84}], {
             RGBColor[
             0.9403060280353561, 0.9534235144862165, 0.9263000713621694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 122}], {
             RGBColor[
             0.6454757236783496, 0.7182961617871998, 0.9681247909722822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 126}], {
             RGBColor[
             0.905070487162301, 0.927142655252052, 0.9908076251031441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 179}], {
             RGBColor[
             0.6634748089682118, 0.7338860648049476, 0.9692716767709861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 190}], {
             RGBColor[
             0.7505586161198526, 0.8051235190270303, 0.975978334361089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 192}], {
             RGBColor[
             0.7770294031386035, 0.8263345732661516, 0.978253049708494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 114}], {
             RGBColor[
             0.680687576961314, 0.7489181952831165, 0.9698803170759694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 141}], {
             RGBColor[
             0.7190502827094493, 0.780062768029652, 0.9729003697996841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 149}], {
             RGBColor[
             0.6604879624771911, 0.7325192382626431, 0.9682901294301534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 167}], {
             RGBColor[
             0.7087285192264073, 0.7716830954439726, 0.9720878027684337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 184}], {
             RGBColor[
             0.7660157789336488, 0.817150780847606, 0.9773091930458699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 189}], {
             RGBColor[
             0.5907871537978933, 0.673394773676508, 0.963504340913113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 194}], {
             RGBColor[
             0.8955627168385336, 0.9186926482893419, 0.9597799992915819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 197}], {
             RGBColor[
             0.90843990485536, 0.9263573331202201, 0.8478048338087827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 70}], {
             RGBColor[
             0.9463044752734036, 0.8212733280613855, 0.5316340082241175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 110}], {
             RGBColor[
             0.5879915521053557, 0.5284028277054934, 0.5898292105165224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 132}], {
             RGBColor[
             0.7552238014024446, 0.6723768335205699, 0.6015199652257579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 138}], {
             RGBColor[
             0.6490322967092514, 0.5845830950642574, 0.5935974832432798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 145}], {
             RGBColor[
             0.8277135901149428, 0.7295417552797303, 0.6083790496436652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 153}], {
             RGBColor[
             0.893831519816026, 0.7817160709871, 0.6148304151143191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 185}], {
             RGBColor[
             0.9275232584453129, 0.7500178027891888, 0.26052396822649426`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 65}], {
             RGBColor[
             0.6640746905308834, 0.7354106887932759, 0.9685959892597329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 132}], {
             RGBColor[
             0.5555014986630993, 0.6500201675288597, 0.9581502593252482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 138}], {
             RGBColor[
             0.44930999396990606`, 0.5622264290725473, 0.9502277773427701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 153}], {
             RGBColor[
             0.6941092170766807, 0.75935940499539, 0.9714607092138094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 156}], {
             RGBColor[
             0.7490999046720422, 0.7993768106671111, 0.8043065188088032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 182}], {
             RGBColor[
             0.6032215808983216, 0.6878348063312305, 0.9625405308875683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 185}], {
             RGBColor[
             0.7278009557059676, 0.7276611367974787, 0.6171542623259847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 199}], {
             RGBColor[
             0.7451828044257999, 0.7983379873947907, 0.9114554533260232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 118}], {
             RGBColor[
             0.7319455576978275, 0.7905113163071233, 0.9739390325422931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 119}], {
             RGBColor[
             0.6289257971310118, 0.7063315215174824, 0.965979168910372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 123}], {
             RGBColor[
             0.6098598395333633, 0.6898175473292913, 0.9647643029516142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 127}], {
             RGBColor[
             0.90682986604794, 0.9263527603721498, 0.9067029539952436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 140}], {
             RGBColor[
             0.8770278802075713, 0.8105665114883891, 0.622629325510932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 151}], {
             RGBColor[
             0.8882843613232918, 0.8551947081122511, 0.6316865544402116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 155}], {
             RGBColor[
             0.8575336788224579, 0.8892380946341489, 0.9862735218870801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 156}], {
             RGBColor[
             0.9095833102893665, 0.9269103819818835, 0.8188388109230302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 171}], {
             RGBColor[
             0.7690540068667662, 0.8195470729983587, 0.9776059633609577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 172}], {
             RGBColor[
             0.6980984336254877, 0.763032696189635, 0.9712744629492178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 191}], {
             RGBColor[
             0.5552248137160075, 0.6403823822151599, 0.9613603765953647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 195}], {
             RGBColor[
             0.6916171042266359, 0.7577708610030851, 0.9707642289570483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 199}], {
             RGBColor[
             0.9056662100431241, 0.9258715587095632, 0.9259877454402501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 78}], {
             RGBColor[
             0.81555285314036, 0.8142225397415893, 0.6398476413599894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 80}], {
             RGBColor[
             0.9002619411280969, 0.8805367474642063, 0.6482538118788552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 82}], {
             RGBColor[
             0.9549713984916567, 0.9238800297349312, 0.6437450660759698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[
             0.9753046913084995, 0.9385373272520691, 0.5866109075503985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 100}], {
             RGBColor[
             0.9328829914108915, 0.9065478874848856, 0.6513652367759835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 113}], {
             RGBColor[
             0.835355126129063, 0.829692225903213, 0.6418213468687408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 120}], {
             RGBColor[
             0.8221736872367824, 0.8193947856579173, 0.6405075442275083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 124}], {
             RGBColor[
             0.8748087344927699, 0.8605136846154702, 0.6457537138355027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 136}], {
             RGBColor[
             0.8834901491504654, 0.8672956717272571, 0.6466189961161493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 187}], {
             RGBColor[
             0.8716465403704512, 0.8580433545335495, 0.6454385358777741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 79}], {
             RGBColor[
             0.4622664951068642, 0.5550669895593769, 0.9541090253584351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 82}], {
             RGBColor[
             0.8395190520946063, 0.8753005939129204, 0.9746405584830939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 100}], {
             RGBColor[
             0.8174306450138411, 0.8579684516628747, 0.9822607291831078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 122}], {
             RGBColor[
             0.5649661130591267, 0.6548074112744573, 0.9602579829007374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 125}], {
             RGBColor[
             0.7890315968576416, 0.8353238215347476, 0.9795520026178399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 137}], {
             RGBColor[
             0.8070898800885493, 0.8497230064040334, 0.9812744177932237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 166}], {
             RGBColor[
             0.749934806412925, 0.8045740375761875, 0.9757101510301727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 170}], {
             RGBColor[
             0.8400759773956716, 0.8757159478905734, 0.9736978292177723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 179}], {
             RGBColor[
             0.5829651983489889, 0.6703973142922051, 0.9614048686994412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 192}], {
             RGBColor[
             0.6965197925193806, 0.7628458227534091, 0.9703862416369493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 71}], {
             RGBColor[
             0.5984127657146409, 0.6832876817871592, 0.9625963701132286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 75}], {
             RGBColor[
             0.6651314210004349, 0.7358730625404682, 0.969123061778137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 81}], {
             RGBColor[
             0.4308603691089715, 0.5476113288755396, 0.948675019618127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 102}], {
             RGBColor[
             0.5901663983790891, 0.6768455569499132, 0.961774449283905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 127}], {
             RGBColor[
             0.7209706084579135, 0.7782049390584532, 0.8901765710894338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 129}], {
             RGBColor[
             0.6878615841999325, 0.6493073848540847, 0.6034420218681427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 140}], {
             RGBColor[
             0.6911686226175447, 0.6624186901746925, 0.6061029426051221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 143}], {
             RGBColor[
             0.6775356575168175, 0.7457638640346014, 0.9703061889304623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 155}], {
             RGBColor[
             0.6716744212324314, 0.7410902733204523, 0.9697471389812702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 172}], {
             RGBColor[
             0.5122391760354612, 0.6148848748759383, 0.9547480800434078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 188}], {
             RGBColor[
             0.5175129683734393, 0.6191663770775464, 0.9551632522947914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 86}], {
             RGBColor[
             0.9463918666159958, 0.9568263322923214, 0.8639224138162256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 92}], {
             RGBColor[
             0.8566933519417861, 0.8886059753898722, 0.9861833040824939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 118}], {
             RGBColor[
             0.7687145365340827, 0.8198299019638109, 0.97744609056775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 123}], {
             RGBColor[
             0.6466288183696185, 0.7191361329859789, 0.9682713609770711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 139}], {
             RGBColor[
             0.6136219195145717, 0.6905472161727108, 0.9661681905688821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 146}], {
             RGBColor[
             0.9287786674826731, 0.8982484775788642, 0.6435787795383963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 171}], {
             RGBColor[
             0.8058229857030215, 0.8488656586550463, 0.9811130213864145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 174}], {
             RGBColor[
             0.6101289972969723, 0.6875218225072014, 0.9659456246538466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 186}], {
             RGBColor[
             0.9461331435250928, 0.9557602373580589, 0.7984932227408055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 191}], {
             RGBColor[
             0.5919937925522627, 0.6697009678718474, 0.9648674346208216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 195}], {
             RGBColor[
             0.7283860830628912, 0.7870894466597727, 0.9742712869825052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 196}], {
             RGBColor[
             0.8856642598973072, 0.7194207456831125, 0.6030383992439712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 110}], {
             RGBColor[
             0.6312601369865092, 0.6970857063049554, 0.8806601097941149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 132}], {
             RGBColor[
             0.7984923862835982, 0.8410597121200318, 0.8923508645033502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 138}], {
             RGBColor[
             0.6923008815904049, 0.7532659736637193, 0.8844283825208722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.8709821749960964, 0.8982246338791922, 0.8992099489212575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 185}], {
             RGBColor[
             0.9707918433264664, 0.9187006813886507, 0.5513548675040867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 73}], {
             RGBColor[
             0.5301748786328475, 0.6241834537328386, 0.958248312288771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 75}], {
             RGBColor[
             0.810704605746921, 0.8525121268469722, 0.9816439163290256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 76}], {
             RGBColor[
             0.6543690592503759, 0.7287285118801463, 0.9669978652845019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 81}], {
             RGBColor[
             0.5764335538554577, 0.6642503931820436, 0.9611958741690154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 87}], {
             RGBColor[
             0.46145647523056355`, 0.5526603730468316, 0.9543091123320586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 89}], {
             RGBColor[
             0.6980636563733282, 0.7640519009299129, 0.9705401195576828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 107}], {
             RGBColor[
             0.6820667887342489, 0.7512147764436481, 0.9691783320095986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 127}], {
             RGBColor[
             0.8665437932043998, 0.8948440033649572, 0.9026974256403222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 129}], {
             RGBColor[
             0.8334347689464187, 0.7659464491605887, 0.6159628764190312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 141}], {
             RGBColor[
             0.6801749761910262, 0.749678917795876, 0.9690294015962584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 142}], {
             RGBColor[
             0.6684683513772716, 0.7401749523946322, 0.96810781320814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 147}], {
             RGBColor[
             0.8660028146063353, 0.8946202948121418, 0.9116628410179821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 155}], {
             RGBColor[
             0.8172476059789175, 0.8577293376269562, 0.9822679935321587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 168}], {
             RGBColor[
             0.5842525483377343, 0.6710228132085021, 0.9616940935833607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 188}], {
             RGBColor[
             0.6630861531199255, 0.7358054413840502, 0.9676841068456798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 197}], {
             RGBColor[
             0.8695645983369369, 0.8959734828864441, 0.843933865605357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 76}], {
             RGBColor[
             0.5241414680093783, 0.6245606818908878, 0.9556814828366099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 81}], {
             RGBColor[
             0.44620596261446016`, 0.560082563192785, 0.9498794917211234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 104}], {
             RGBColor[
             0.726459819079113, 0.7841409680663075, 0.9445926486402642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 143}], {
             RGBColor[
             0.6928812510223062, 0.7582350983518468, 0.9715106610334587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 144}], {
             RGBColor[
             0.42249718966485705`, 0.5395472157014157, 0.9483687896736195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 154}], {
             RGBColor[
             0.44303990699955176`, 0.5573402849497335, 0.9496777534569745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 158}], {
             RGBColor[
             0.6687650304913659, 0.7390054787178424, 0.9692104343904135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 160}], {
             RGBColor[
             0.6738620120588503, 0.7430696734658755, 0.9696965890424494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 176}], {
             RGBColor[
             0.4923351461635813, 0.5987388769579993, 0.9531775726705128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 181}], {
             RGBColor[
             0.6141784842811193, 0.6960871209951185, 0.9638427163560126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 75}], {
             RGBColor[
             0.5968935339186415, 0.6767688344861477, 0.9647750039536795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 87}], {
             RGBColor[
             0.247645403402284, 0.376917080686007, 0.9374401999567126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.48425258454504877`, 0.5883086085690884, 0.9536712071823368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 107}], {
             RGBColor[
             0.4682557169059694, 0.5754714840828236, 0.9523094196342525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 130}], {
             RGBColor[
             0.49103106613874525`, 0.5936040099084522, 0.9543468228790843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 142}], {
             RGBColor[
             0.45465727954899204`, 0.5644316600338076, 0.9512389008327939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 147}], {
             RGBColor[
             0.6521917427780558, 0.7188770024513171, 0.8947939286426361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 149}], {
             RGBColor[
             0.40780158413048845`, 0.5263920956680426, 0.9475502488513816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 157}], {
             RGBColor[
             0.573072787154878, 0.6577748176136684, 0.96250295986232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 167}], {
             RGBColor[
             0.45604214087970474`, 0.5655559528493722, 0.9513479221896618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 168}], {
             RGBColor[
             0.3704414765094548, 0.49527952084767757`, 0.9448251812080146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 188}], {
             RGBColor[
             0.449275081291646, 0.5600621490232257, 0.9508151944703338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 189}], {
             RGBColor[
             0.3381007754511906, 0.46726763108190755`, 0.9427644603343411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 197}], {
             RGBColor[
             0.6557535265086574, 0.7202301905256197, 0.827064953230011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 85}], {
             RGBColor[
             0.6923220213455569, 0.7588797693488836, 0.9704373630694384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 88}], {
             RGBColor[
             0.610650036416634, 0.6947922348904928, 0.9624917542329565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 93}], {
             RGBColor[
             0.5900850210017969, 0.6780966289333413, 0.9608728008873669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 95}], {
             RGBColor[
             0.7836541449052208, 0.7969289701156914, 0.6492767891143234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 121}], {
             RGBColor[
             0.6151651867700767, 0.698457837352623, 0.9628472034083202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 140}], {
             RGBColor[
             0.7635138466880872, 0.721164792388743, 0.6117946344227261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 152}], {
             RGBColor[
             0.4539898380138191, 0.5637292176208446, 0.9512307270363562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 159}], {
             RGBColor[
             0.5939177811690662, 0.6812082363010085, 0.9611745298075975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 161}], {
             RGBColor[
             0.4189262831103967, 0.5270327120574421, 0.9492281421047467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 162}], {
             RGBColor[
             0.796108058115454, 0.8375916122590198, 0.81222522996958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 164}], {
             RGBColor[
             0.48817139367942436`, 0.5933355631234507, 0.9534087455378057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 172}], {
             RGBColor[
             0.5845844001060037, 0.6736309770899889, 0.9604397718610118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 173}], {
             RGBColor[
             0.7834594496441668, 0.8304158359631126, 0.9490798683548717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 180}], {
             RGBColor[
             0.68351825101032, 0.7520021970518638, 0.9695598855183334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 81}], {
             RGBColor[
             0.6431522091412517, 0.7168357739353527, 0.9677225658339239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 89}], {
             RGBColor[
             0.7647823116591224, 0.816637281683222, 0.9770668112225912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 118}], {
             RGBColor[
             0.7583781401400813, 0.8115879400532399, 0.97646019585228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 127}], {
             RGBColor[
             0.9332624484901937, 0.9474293841182663, 0.9092241173052307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 129}], {
             RGBColor[
             0.9001534242322127, 0.8185318299138977, 0.6224895680839396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 141}], {
             RGBColor[
             0.7468936314768202, 0.8022642985491852, 0.9755560932611669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 142}], {
             RGBColor[
             0.7351870066630656, 0.7927603331479413, 0.9746345048730485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 147}], {
             RGBColor[
             0.9327214698921293, 0.9472056755654508, 0.9181895326828906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 155}], {
             RGBColor[
             0.8839662612647116, 0.9103147183802653, 0.988794685197067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 168}], {
             RGBColor[
             0.6509712036235283, 0.7236081939618112, 0.9682207852482692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 188}], {
             RGBColor[
             0.7298048084057196, 0.7883908221373594, 0.9742107985105883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 191}], {
             RGBColor[
             0.5816573961582612, 0.6614590059612764, 0.9638815399053517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 81}], {
             RGBColor[
             0.4868166626447066, 0.5930521589685267, 0.9530765147894003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 87}], {
             RGBColor[
             0.37183958401981243`, 0.4814621388333147, 0.9461897529524435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 89}], {
             RGBColor[
             0.6084467651625771, 0.692853666716396, 0.9624207601780677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[
             0.7670705191093594, 0.8171105638420492, 0.947789671708541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 106}], {
             RGBColor[
             0.4366176917970547, 0.5495480372764483, 0.9498787703597347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 107}], {
             RGBColor[
             0.5924498975234977, 0.6800165422301313, 0.9610589726299834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 142}], {
             RGBColor[
             0.5788514601665204, 0.6689767181811153, 0.9599884538285248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 143}], {
             RGBColor[
             0.7334919510525526, 0.7912046941275884, 0.9747076841017357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 147}], {
             RGBColor[
             0.7763859233955842, 0.8234220605986249, 0.903543481638367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 154}], {
             RGBColor[
             0.48365060702979823`, 0.5903098807254752, 0.9528747765252513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[
             0.6972669677724064, 0.7623198757609762, 0.9712525128580509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 158}], {
             RGBColor[
             0.7093757305216124, 0.771975074493584, 0.9724074574586903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 176}], {
             RGBColor[
             0.5329458461938277, 0.631708472733741, 0.9563745957387897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 181}], {
             RGBColor[
             0.6547891843113657, 0.7290567167708601, 0.9670397394242894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 188}], {
             RGBColor[
             0.5734692619091744, 0.6646072071705335, 0.9595647474660647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 83}], {
             RGBColor[
             0.8266341179319786, 0.8652464057736579, 0.973944529267391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 96}], {
             RGBColor[
             0.7193237583414442, 0.779122539822511, 0.9648160234111904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 99}], {
             RGBColor[
             0.8640833445023972, 0.8945020261951325, 0.9776771181890106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 112}], {
             RGBColor[
             0.9439604982356364, 0.9577264118571758, 0.9797444384308981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 143}], {
             RGBColor[
             0.9240769756522399, 0.9420342846332056, 0.9834803110775241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 156}], {
             RGBColor[
             0.9702653708347622, 0.9750329812667912, 0.8154865501642821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 160}], {
             RGBColor[
             0.905057736688784, 0.9268688597472343, 0.9816662390865147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 166}], {
             RGBColor[
             0.8566661446128909, 0.8887076532686432, 0.9769378410216984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 170}], {
             RGBColor[
             0.9468073155956376, 0.9598495635830291, 0.974925519209298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 181}], {
             RGBColor[
             0.845374208911053, 0.8798863072764773, 0.975812366400078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 183}], {
             RGBColor[
             0.9646887297103468, 0.9731854929516508, 0.9446569493328205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 192}], {
             RGBColor[
             0.8032511307193465, 0.8469794384458648, 0.9716139316284751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 80}], {
             RGBColor[
             0.7524505606352887, 0.8066781882688216, 0.9759240581796809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 82}], {
             RGBColor[
             0.8071600179988485, 0.8500214705395465, 0.9714153123767953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 98}], {
             RGBColor[
             0.8274933108156914, 0.8646787680566843, 0.9142811538512241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 100}], {
             RGBColor[
             0.7850716109180833, 0.8326893282895008, 0.9790354830768091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 113}], {
             RGBColor[
             0.687543745636255, 0.7558336667078283, 0.9694915931695665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 120}], {
             RGBColor[
             0.6743623067439743, 0.7455362264625327, 0.968177790528334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 124}], {
             RGBColor[
             0.7269973539999617, 0.7866551254200855, 0.9734239601363284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 136}], {
             RGBColor[
             0.7356787686576574, 0.7934371125318724, 0.9742892424169749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 187}], {
             RGBColor[
             0.7238351598776431, 0.7841847953381647, 0.9731087821785998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 84}], {
             RGBColor[
             0.5896033716839301, 0.6540795262398986, 0.8985739087756475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 122}], {
             RGBColor[
             0.2947730673269235, 0.4189521735408819, 0.9403986283857603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 126}], {
             RGBColor[
             0.5543678308108749, 0.6277986670057341, 0.9630814625166222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 177}], {
             RGBColor[
             0.5794868669043776, 0.6096103902092553, 0.6300819777685285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 179}], {
             RGBColor[
             0.3127721526167857, 0.43454207655862964`, 0.9415455141844642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 190}], {
             RGBColor[
             0.3998559597684265, 0.5057795307807124, 0.9482521717745671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 82}], {
             RGBColor[
             0.8918691059865854, 0.9163356782621634, 0.9798214828956613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 98}], {
             RGBColor[
             0.9122023988034282, 0.9309929757793014, 0.9226873243700899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 100}], {
             RGBColor[
             0.8697806989058202, 0.8990035360121178, 0.987441653595675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 113}], {
             RGBColor[
             0.7722528336239918, 0.8221478744304453, 0.9778977636884324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 116}], {
             RGBColor[
             0.807785458568612, 0.8499062310951344, 0.981439323671653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 120}], {
             RGBColor[
             0.7590713947317111, 0.8118504341851497, 0.9765839610471998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 124}], {
             RGBColor[
             0.8117064419876986, 0.8529693331427025, 0.9818301306551942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 125}], {
             RGBColor[
             0.8413816507496206, 0.8763589058839907, 0.9847329270304072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 136}], {
             RGBColor[
             0.8203878566453942, 0.8597513202544894, 0.9826954129358407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 137}], {
             RGBColor[
             0.8594399339805285, 0.8907580907532766, 0.9864553422057909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 187}], {
             RGBColor[
             0.8085442478653799, 0.8504990030607817, 0.9815149526974657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 198}], {
             RGBColor[
             0.5440497390581305, 0.6270382228329657, 0.9609661264023761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 87}], {
             RGBColor[
             0.2939040786248942, 0.4169840201352121, 0.9403877618369569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 89}], {
             RGBColor[
             0.5305112597676589, 0.6283755480182934, 0.9566187690625811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 104}], {
             RGBColor[
             0.6891350137144412, 0.7526324451439466, 0.9419876805930545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 107}], {
             RGBColor[
             0.5145143921285795, 0.6155384235320287, 0.9552569815144969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 142}], {
             RGBColor[
             0.5009159547716022, 0.6044985994830127, 0.9541864627130383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 143}], {
             RGBColor[
             0.6555564456576344, 0.7267265754294858, 0.9689056929862492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 147}], {
             RGBColor[
             0.698450418000666, 0.7589439419005222, 0.8977414905228804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 154}], {
             RGBColor[
             0.40571510163488, 0.5258317620273726, 0.9470727854097648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 157}], {
             RGBColor[
             0.6193314623774882, 0.6978417570628734, 0.9654505217425644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 158}], {
             RGBColor[
             0.6314402251266942, 0.7074969557954814, 0.9666054663432038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 168}], {
             RGBColor[
             0.416700151732065, 0.5353464602968826, 0.947772743088259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 176}], {
             RGBColor[
             0.4550103407989095, 0.5672303540356383, 0.9505726046233032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 188}], {
             RGBColor[
             0.4955337565142562, 0.6001290884724308, 0.9537627563505782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 98}], {
             RGBColor[
             0.966911856166988, 0.9743362580500262, 0.9181785785672045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 100}], {
             RGBColor[
             0.92449015626938, 0.9423468182828427, 0.9829329077927895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 120}], {
             RGBColor[
             0.813780852095271, 0.8551937164558745, 0.9720752152443144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 124}], {
             RGBColor[
             0.8664158993512584, 0.8963126154134273, 0.9773213848523088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 125}], {
             RGBColor[
             0.8960911081131804, 0.9197021881547156, 0.9802241812275216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 136}], {
             RGBColor[
             0.875097314008954, 0.9030946025252142, 0.9781866671329553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 137}], {
             RGBColor[
             0.9141493913440883, 0.9341013730240014, 0.9819465964029055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 187}], {
             RGBColor[
             0.8632537052289397, 0.8938422853315067, 0.9770062068945802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 198}], {
             RGBColor[
             0.5987591964216903, 0.6703815051036905, 0.9564573805994907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 122}], {
             RGBColor[
             0.552409351952072, 0.644997974062707, 0.9590064423031903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 156}], {
             RGBColor[
             0.8509772715277415, 0.8810899283625853, 0.8130073195752092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 166}], {
             RGBColor[
             0.7373780453058703, 0.7947646003644373, 0.9744586104326256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 170}], {
             RGBColor[
             0.8275192162886169, 0.8659065106788232, 0.9724462886202252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 175}], {
             RGBColor[
             0.6535747024785337, 0.728644894292655, 0.9665515824420162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 179}], {
             RGBColor[
             0.5704084372419341, 0.6605878770804547, 0.9601533281018941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 183}], {
             RGBColor[
             0.8454006304033261, 0.8792424400474449, 0.9421777187437477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 192}], {
             RGBColor[
             0.6839630314123258, 0.7530363855416589, 0.9691347010394022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 126}], {
             RGBColor[
             0.951897753120144, 0.962666441419831, 0.9274057004488117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 190}], {
             RGBColor[
             0.7973858820776956, 0.8406473051948093, 0.9125764097067566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 88}], {
             RGBColor[
             0.7054420286529512, 0.7695311823306199, 0.9714702181048468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 117}], {
             RGBColor[
             0.8765527041828819, 0.9038878676097957, 0.960933852047053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[
             0.709957179006394, 0.7731967847927501, 0.9718256672802106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 133}], {
             RGBColor[
             0.5617673556625632, 0.6497155745017315, 0.9610366171048772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 140}], {
             RGBColor[
             0.8583058389244045, 0.7959037398288702, 0.6207730982946164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 152}], {
             RGBColor[
             0.5487818302501364, 0.6384681650609718, 0.9602091909082466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 159}], {
             RGBColor[
             0.6887097734053835, 0.7559471837411356, 0.9701529936794877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 161}], {
             RGBColor[
             0.513718275346714, 0.6017716594975692, 0.958206605976637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 173}], {
             RGBColor[
             0.8782514418804841, 0.9051547834032398, 0.958058332226762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 200}], {
             RGBColor[
             0.7529012205483605, 0.8068914228443722, 0.9760058154684768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 92}], {
             RGBColor[
             0.9049891647370638, 0.92385087626077, 0.8599633204738457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[
             0.8750890415128587, 0.900492672748668, 0.8569831556233949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 171}], {
             RGBColor[
             0.8541187984982992, 0.8841105595259442, 0.8548930377777664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 174}], {
             RGBColor[
             0.6584248100922501, 0.7227667233780992, 0.8397256410451983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 196}], {
             RGBColor[
             0.933960072692585, 0.7546656465540105, 0.47681841563532296`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 89}], {
             RGBColor[
             0.41553418114276475`, 0.5167855278830814, 0.9497320072256242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 106}], {
             RGBColor[
             0.24370510777724227`, 0.37347989844313356`, 0.9371900174072914]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 107}], {
             RGBColor[
             0.3995373135036854, 0.5039484033968166, 0.9483702196775401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 130}], {
             RGBColor[
             0.4223126627364613, 0.5220809292224452, 0.9504076229223719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 131}], {
             RGBColor[
             0.5802096359629048, 0.645555773611334, 0.9248569677138763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 142}], {
             RGBColor[
             0.3859388761467081, 0.49290857934780063`, 0.9472997008760815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 147}], {
             RGBColor[
             0.5834733393757718, 0.6473539217653101, 0.8908547286859236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[
             0.2907380230099858, 0.41424174189216056`, 0.9401860235728079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 157}], {
             RGBColor[
             0.5043543837525939, 0.5862517369276614, 0.9585637599056076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 168}], {
             RGBColor[
             0.30172307310717084`, 0.4237564401616706, 0.9408859812513022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 176}], {
             RGBColor[
             0.3400332621740153, 0.45564033390042624`, 0.9436858427863464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 188}], {
             RGBColor[
             0.380556677889362, 0.4885390683372187, 0.9468759945136214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 91}], {
             RGBColor[
             0.4688347662632828, 0.5758746704255542, 0.9523734925089057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 93}], {
             RGBColor[
             0.6032050283091913, 0.6887480419150778, 0.9619056559227753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 95}], {
             RGBColor[
             0.7967741522126153, 0.8075803830974279, 0.6503096441497318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 103}], {
             RGBColor[
             0.7293942251880017, 0.7883643378192084, 0.9738253021981018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 117}], {
             RGBColor[
             0.794880719253959, 0.839800333151405, 0.9529882432105712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 121}], {
             RGBColor[
             0.6282851940774711, 0.7091092503343595, 0.9638800584437286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 152}], {
             RGBColor[
             0.46710984532121347`, 0.5743806306025812, 0.9522635820717646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 159}], {
             RGBColor[
             0.6070377884764606, 0.6918596492827449, 0.9622073848430059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 161}], {
             RGBColor[
             0.4320462904177911, 0.5376841250391785, 0.9502609971401551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 164}], {
             RGBColor[
             0.5012914009868188, 0.6039869761051871, 0.9544416005732141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 173}], {
             RGBColor[
             0.7965794569515612, 0.8410672489448491, 0.9501127233902801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 180}], {
             RGBColor[
             0.6966382583177144, 0.7626536100336001, 0.9705927405537418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 200}], {
             RGBColor[
             0.6712292356194376, 0.7428038883859814, 0.9680602066319948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 106}], {
             RGBColor[
             0.48031228892000705`, 0.5848714263262149, 0.9534210246329156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 107}], {
             RGBColor[
             0.6361444946464502, 0.715339931279898, 0.9646012269031643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 142}], {
             RGBColor[
             0.6225460572894728, 0.704300107230882, 0.9635307081017057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 147}], {
             RGBColor[
             0.8200805205185366, 0.8587454496483915, 0.9070857359115478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 154}], {
             RGBColor[
             0.5273452041527505, 0.6256332697752419, 0.9564170307984321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 157}], {
             RGBColor[
             0.7409615648953587, 0.7976432648107428, 0.9747947671312318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 168}], {
             RGBColor[
             0.5383302542499355, 0.6351479680447519, 0.9571169884769264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 176}], {
             RGBColor[
             0.5766404433167801, 0.6670318617835076, 0.9599168500119706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 188}], {
             RGBColor[
             0.6171638590321268, 0.6999305962203002, 0.9631070017392456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 111}], {
             RGBColor[
             0.8398912307120854, 0.8755779405539957, 0.9844826433675868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 115}], {
             RGBColor[
             0.6672332369861045, 0.7387802733472895, 0.9682785639919411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 163}], {
             RGBColor[
             0.8338344152184889, 0.8707484002872787, 0.9839049388988247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 165}], {
             RGBColor[
             0.8234429336196218, 0.8624625149295959, 0.9829137901073396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 169}], {
             RGBColor[
             0.7537918747932111, 0.8075872087096725, 0.9760945875599663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 175}], {
             RGBColor[
             0.6846880814741847, 0.752950902434496, 0.969652673289245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 177}], {
             RGBColor[
             0.868236530525177, 0.8599621988729216, 0.6517908825331873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 103}], {
             RGBColor[
             0.5744589477272561, 0.6587953603725334, 0.9626741854386425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 117}], {
             RGBColor[
             0.6399454417932133, 0.71023135570473, 0.9418371264511118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 121}], {
             RGBColor[
             0.47334991661672554`, 0.5795402728876844, 0.9527289416842695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 152}], {
             RGBColor[
             0.3121745678604679, 0.44481165315590604`, 0.9411124653123055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 159}], {
             RGBColor[
             0.4521025110157151, 0.5622906718360698, 0.9510562680835466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 164}], {
             RGBColor[
             0.34635612352607315`, 0.4744179986585121, 0.943290483813755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 200}], {
             RGBColor[
             0.5162939581586921, 0.6132349109393064, 0.9569090898725356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 118}], {
             RGBColor[
             0.7273118346551508, 0.7868544459322597, 0.9734869972253701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 123}], {
             RGBColor[
             0.6052261164906866, 0.6861606769544277, 0.9643122676346914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 139}], {
             RGBColor[
             0.5722192176356398, 0.6575717601411595, 0.9622090972265023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 141}], {
             RGBColor[
             0.7158273259918897, 0.777530804428205, 0.972582894634257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 146}], {
             RGBColor[
             0.8873759656037412, 0.8652730215473129, 0.6396196861960165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 171}], {
             RGBColor[
             0.7644202838240894, 0.815890202623495, 0.9771539280440348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 174}], {
             RGBColor[
             0.5687262954180403, 0.6545463664756501, 0.9619865313114668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 186}], {
             RGBColor[
             0.9047304416461609, 0.9227847813265075, 0.7945341293984256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 191}], {
             RGBColor[
             0.5505910906733308, 0.6367255118402961, 0.9609083412784418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 195}], {
             RGBColor[
             0.6869833811839592, 0.7541139906282213, 0.9703121936401253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 196}], {
             RGBColor[
             0.8442615580183752, 0.6864452896515613, 0.5990793059015913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 95}], {
             RGBColor[
             0.7762091367977781, 0.7908847771402764, 0.6486906908041421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 121}], {
             RGBColor[
             0.6077201786626341, 0.692413644377208, 0.9622611050981391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 150}], {
             RGBColor[
             0.6444939859996034, 0.7212880485723694, 0.9658262620049681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 159}], {
             RGBColor[
             0.5864727730616236, 0.6751640433255934, 0.9605884314974162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 161}], {
             RGBColor[
             0.41148127500295406`, 0.520988519082027, 0.9486420437945655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 162}], {
             RGBColor[
             0.7886630500080114, 0.8315474192836048, 0.8116391316593988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 164}], {
             RGBColor[
             0.4807263855719817, 0.5872913701480357, 0.9528226472276247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 173}], {
             RGBColor[
             0.7760144415367242, 0.8243716429876976, 0.9484937700446905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 180}], {
             RGBColor[
             0.6760732429028774, 0.7459580040764486, 0.9689737872081521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 200}], {
             RGBColor[
             0.6506642202046006, 0.72610828242883, 0.9664412532864053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 174}], {
             RGBColor[
             0.5388261721938352, 0.631188162963548, 0.959006366461016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 196}], {
             RGBColor[
             0.8143614347941701, 0.6630870861394591, 0.5960991410511405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 121}], {
             RGBColor[
             0.8012893025660579, 0.8112459855595581, 0.6506650933250955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 150}], {
             RGBColor[
             0.8380631099030273, 0.8401203897547194, 0.6542302502319246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 159}], {
             RGBColor[
             0.7800418969650476, 0.7939963845079435, 0.6489924197243727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 161}], {
             RGBColor[
             0.605050398906378, 0.6398208602643771, 0.6370460320215219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 162}], {
             RGBColor[
             0.9822321739114354, 0.9503797604659548, 0.5000431198863553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 164}], {
             RGBColor[
             0.6742955094754056, 0.7061237113303858, 0.641226635454581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 173}], {
             RGBColor[
             0.9695835654401481, 0.9432039841700477, 0.6368977582716469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 180}], {
             RGBColor[
             0.8696423668063014, 0.8647903452587988, 0.6573777754351086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 99}], {
             RGBColor[
             0.6374848856048423, 0.7144351073397799, 0.9660693817437374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 102}], {
             RGBColor[
             0.6101092576169564, 0.6930490586931648, 0.9633408349856936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 125}], {
             RGBColor[
             0.6691644761600525, 0.7393905183718505, 0.9691719561640924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 128}], {
             RGBColor[
             0.6564946070152844, 0.7292879086302488, 0.9679634927345386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 137}], {
             RGBColor[
             0.6872227593909603, 0.7537897032411365, 0.9708943713394762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 166}], {
             RGBColor[
             0.630067685715336, 0.7086407344132906, 0.9653301045764251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 170}], {
             RGBColor[
             0.7202088566980827, 0.7797826447276763, 0.9633177827640247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 198}], {
             RGBColor[
             0.3718325644685624, 0.4900698353208256, 0.9454051555360614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 105}], {
             RGBColor[
             0.48090493525177036`, 0.5894405136077907, 0.9522829399793744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 134}], {
             RGBColor[
             0.7186481279748875, 0.7771960828613649, 0.9268852609142748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 135}], {
             RGBColor[
             0.7010501072633277, 0.7641510478605884, 0.960236084813447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 153}], {
             RGBColor[
             0.668626320784454, 0.7386524385870978, 0.9694597976528421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 100}], {
             RGBColor[
             0.9448234490862228, 0.9570041157999806, 0.9257987492672184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 109}], {
             RGBColor[
             0.9328417295929456, 0.764946069148124, 0.5406613525678003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 113}], {
             RGBColor[
             0.8472955838043944, 0.880148454218308, 0.9162548593599757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 116}], {
             RGBColor[
             0.8828282087490147, 0.9079068108829971, 0.9197964193431962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 120}], {
             RGBColor[
             0.8341141449121139, 0.8698510139730125, 0.914941056718743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 124}], {
             RGBColor[
             0.8867491921681012, 0.9109699129305653, 0.9201872263267374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 125}], {
             RGBColor[
             0.9164244009300233, 0.9343594856718535, 0.9230900227019505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 136}], {
             RGBColor[
             0.8954306068257968, 0.9177519000423522, 0.921052508607384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 187}], {
             RGBColor[
             0.8835869980457827, 0.9084995828486444, 0.919872048369009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 102}], {
             RGBColor[
             0.7548688437779094, 0.8084285450657862, 0.9762019297635136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 109}], {
             RGBColor[
             0.8303413909839278, 0.6853565882207426, 0.5996043808077625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 116}], {
             RGBColor[
             0.7803278701399968, 0.8283173299556157, 0.9787394475831583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 128}], {
             RGBColor[
             0.8012541931762374, 0.8446673950028702, 0.9808245875123588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 136}], {
             RGBColor[
             0.7929302682167789, 0.8381624191149708, 0.9799955368473461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 137}], {
             RGBColor[
             0.8319823455519133, 0.8691691896137579, 0.9837554661172963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 162}], {
             RGBColor[
             0.888465279443732, 0.9104284981608423, 0.8209610186315847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 193}], {
             RGBColor[
             0.8850304665766979, 0.9001893992605912, 0.6930500794954704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 198}], {
             RGBColor[
             0.5165921506295154, 0.6054493216934471, 0.9582662503138815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 113}], {
             RGBColor[
             0.8048738839067864, 0.8481590144511245, 0.9810091885855607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 120}], {
             RGBColor[
             0.7916924450145058, 0.8378615742058289, 0.9796953859443281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 124}], {
             RGBColor[
             0.8443274922704932, 0.8789804731633817, 0.9849415555523225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 125}], {
             RGBColor[
             0.8740027010324152, 0.90237004590467, 0.9878443519275355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 136}], {
             RGBColor[
             0.8530089069281888, 0.8857624602751686, 0.9858068378329691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 137}], {
             RGBColor[
             0.8920609842633231, 0.9167692307739558, 0.9895667671029192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 187}], {
             RGBColor[
             0.8411652981481745, 0.876510143081461, 0.984626377594594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 198}], {
             RGBColor[
             0.5766707893409251, 0.6530493628536449, 0.9640775512995045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 105}], {
             RGBColor[
             0.7467058489775513, 0.8000817240953226, 0.9327808328824239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 134}], {
             RGBColor[
             0.9844490417006685, 0.9878372933488968, 0.9073831538173243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 135}], {
             RGBColor[
             0.9668510209891087, 0.9747922583481203, 0.9407339777164965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 144}], {
             RGBColor[
             0.6728454655656251, 0.7376244754623342, 0.9276553897042878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 128}], {
             RGBColor[
             0.7738785651883516, 0.8232813463562552, 0.978096040754315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 140}], {
             RGBColor[
             0.8284954400284792, 0.7726156296439504, 0.6178018763266869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 162}], {
             RGBColor[
             0.8610896514558462, 0.8890424495142272, 0.8182324718735409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 172}], {
             RGBColor[
             0.6495659934463958, 0.7250818143451963, 0.9664470137649728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 180}], {
             RGBColor[
             0.748499844350712, 0.8034530343070712, 0.9755671274222941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 117}], {
             RGBColor[
             0.9005049007179323, 0.9227210230983842, 0.963288936140308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 152}], {
             RGBColor[
             0.5727340267851868, 0.6573013205495604, 0.9625642750015015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 178}], {
             RGBColor[
             0.8840170103658872, 0.9103551843359952, 0.9887995256916415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 200}], {
             RGBColor[
             0.7768534170834109, 0.8257245783329608, 0.9783608995617317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 143}], {
             RGBColor[
             0.9358103021222872, 0.9507849803030082, 0.9636188499053899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 154}], {
             RGBColor[
             0.6859689580995328, 0.749890166900895, 0.9417859423289056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 158}], {
             RGBColor[
             0.911694081591347, 0.9315553606690039, 0.9613186232623445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 160}], {
             RGBColor[
             0.9167910631588313, 0.9356195554170369, 0.9618047779143803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 176}], {
             RGBColor[
             0.7352641972635623, 0.7912887589091607, 0.9452857615424439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 181}], {
             RGBColor[
             0.8571075353811003, 0.88863700294628, 0.9559509052279437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 188}], {
             RGBColor[
             0.775787612978909, 0.8241874933459532, 0.9484759132697189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 134}], {
             RGBColor[
             0.7469275708975519, 0.8001734118072363, 0.9291063268700781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 135}], {
             RGBColor[
             0.7293295501859921, 0.7871283768064599, 0.9624571507692503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 144}], {
             RGBColor[
             0.43532399476250844`, 0.5499605939206738, 0.9493785627570417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.4643154212809277, 0.5720343018399501, 0.9520592370848313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 130}], {
             RGBColor[
             0.48709077051370353`, 0.5901668276655787, 0.9540966403296632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 131}], {
             RGBColor[
             0.644987743740147, 0.7136416720544674, 0.9285459851211675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 142}], {
             RGBColor[
             0.4507169839239503, 0.5609944777909341, 0.9509887182833727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 147}], {
             RGBColor[
             0.6482514471530141, 0.7154398202084438, 0.8945437460932149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 157}], {
             RGBColor[
             0.5691324915298362, 0.6543376353707949, 0.9622527773128989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 176}], {
             RGBColor[
             0.4048113699512576, 0.5237262323435599, 0.9473748601936376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 130}], {
             RGBColor[
             0.6429229762401467, 0.7206353326192618, 0.9652768425999119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 131}], {
             RGBColor[
             0.8008199494665902, 0.8441101770081505, 0.9397261873914162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 142}], {
             RGBColor[
             0.6065491896503934, 0.6914629827446173, 0.9621689205536215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[
             0.8040836528794573, 0.8459083251621268, 0.9057239483634636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 154}], {
             RGBColor[
             0.5113483365136712, 0.6127961452889772, 0.955055243250348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.7249646972562793, 0.7848061403244779, 0.9734329795831476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 168}], {
             RGBColor[
             0.5223333866108562, 0.6223108435584872, 0.9557552009288421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 176}], {
             RGBColor[
             0.5606435756777007, 0.6541947372972429, 0.9585550624638863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 188}], {
             RGBColor[
             0.6011669913930474, 0.6870934717340353, 0.9617452141911613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 111}], {
             RGBColor[
             0.7473285107465436, 0.8023801073925909, 0.9758633940444212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 115}], {
             RGBColor[
             0.5746705170205628, 0.6655824401858846, 0.9596593146687755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 133}], {
             RGBColor[
             0.4604340172142143, 0.5696660675223884, 0.9515431944974351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 151}], {
             RGBColor[
             0.7682289815917761, 0.7604824294733892, 0.6203369046164539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 163}], {
             RGBColor[
             0.7412716952529472, 0.797550567125874, 0.9752856895756591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 165}], {
             RGBColor[
             0.7308802136540802, 0.7892646817681912, 0.974294540784174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 175}], {
             RGBColor[
             0.5921253615086429, 0.6797530692730913, 0.9610334239660794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 113}], {
             RGBColor[
             0.7928921644135092, 0.656100967799268, 0.5958717918861427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 116}], {
             RGBColor[
             0.8284247893581294, 0.683859324463957, 0.5994133518693634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 124}], {
             RGBColor[
             0.8323457727772159, 0.6869224265115252, 0.5998041588529046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 128}], {
             RGBColor[
             0.84935111239437, 0.7002093895112116, 0.6014984917985637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 136}], {
             RGBColor[
             0.8410271874349116, 0.6937044136233121, 0.6006694411335511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 148}], {
             RGBColor[
             0.7795855726166472, 0.6457057571537161, 0.5945455151730019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 193}], {
             RGBColor[
             0.9331273857948303, 0.7557313937689325, 0.31372398378167543`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 138}], {
             RGBColor[
             0.3339879584223571, 0.4603954733078271, 0.9426235848132769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 145}], {
             RGBColor[
             0.5126692518280486, 0.6053541335233, 0.9574051512136623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 115}], {
             RGBColor[
             0.7375516910819301, 0.7944428447481511, 0.9750937269867525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 163}], {
             RGBColor[
             0.9041528693143144, 0.9264109716881404, 0.990720101893636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 165}], {
             RGBColor[
             0.8937613877154473, 0.9181250863304575, 0.9897289531021509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 169}], {
             RGBColor[
             0.8241103288890366, 0.8632497801105341, 0.9829097505547776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 175}], {
             RGBColor[
             0.7550065355700102, 0.8086134738353576, 0.9764678362840562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 177}], {
             RGBColor[
             0.9385549846210026, 0.9156247702737832, 0.6586060455279985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 134}], {
             RGBColor[
             0.9633347714264713, 0.9720961730486493, 0.9433868824051554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 143}], {
             RGBColor[
             0.9221152566488771, 0.9405712378125177, 0.9868009896519585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 156}], {
             RGBColor[
             0.9683036518313994, 0.9735699344461033, 0.8188072287387165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 160}], {
             RGBColor[
             0.903096017685421, 0.9254058129265463, 0.9849869176609489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 181}], {
             RGBColor[
             0.84341248990769, 0.8784232604557894, 0.9791330449745123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 183}], {
             RGBColor[
             0.962727010706984, 0.9717224461309628, 0.9479776279072549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 116}], {
             RGBColor[
             0.7428786435695782, 0.799061709534141, 0.9750068586615387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 124}], {
             RGBColor[
             0.7467996269886648, 0.8021248115817092, 0.9753976656450799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 128}], {
             RGBColor[
             0.7638049666058188, 0.8154117745813956, 0.9770919985907391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 136}], {
             RGBColor[
             0.7554810416463603, 0.8089067986934961, 0.9762629479257264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 148}], {
             RGBColor[
             0.694039426828096, 0.7609081422239001, 0.9701390219651773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 187}], {
             RGBColor[
             0.7436374328663462, 0.7996544814997883, 0.9750824876873514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 193}], {
             RGBColor[
             0.8475812400062792, 0.8709337788391165, 0.6893174905738508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 198}], {
             RGBColor[
             0.47914292405909664`, 0.5761937012719724, 0.9545336613922618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 167}], {
             RGBColor[
             0.5676795326897481, 0.6599068441658742, 0.9591089587734345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 184}], {
             RGBColor[
             0.6249667923969897, 0.7053745295695075, 0.9643303490508708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 186}], {
             RGBColor[
             0.7669044118270611, 0.8135404936498561, 0.7818727605688538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 194}], {
             RGBColor[
             0.7545137303018744, 0.8069163970112434, 0.9468011552965827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 133}], {
             RGBColor[
             0.45065719754960076`, 0.5617288048779484, 0.9507735274397662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 163}], {
             RGBColor[
             0.7314948755883337, 0.7896133044814341, 0.9745160225179903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 165}], {
             RGBColor[
             0.7211033939894667, 0.7813274191237513, 0.9735248737265052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 175}], {
             RGBColor[
             0.5823485418440294, 0.6718158066286514, 0.9602637569084105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 124}], {
             RGBColor[
             0.7823322519332849, 0.8298831682463983, 0.9789392256283005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 128}], {
             RGBColor[
             0.799337591550439, 0.8431701312460846, 0.9806335585739597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 136}], {
             RGBColor[
             0.7910136665909806, 0.8366651553581852, 0.979804507908947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 148}], {
             RGBColor[
             0.7295720517727162, 0.7886664988885892, 0.9736805819483978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 193}], {
             RGBColor[
             0.8831138649508994, 0.8986921355038056, 0.6928590505570713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 198}], {
             RGBColor[
             0.5146755490037169, 0.6039520579366615, 0.9580752213754824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 121}], {
             RGBColor[
             0.7993958696074017, 0.8434659356135352, 0.9533436923859349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 152}], {
             RGBColor[
             0.6382205208511441, 0.7087373158817569, 0.9417272160139709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 159}], {
             RGBColor[
             0.7781484640063913, 0.8262163345619207, 0.9516710187852121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 164}], {
             RGBColor[
             0.6724020765167493, 0.7383436613843629, 0.9439052345154204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 178}], {
             RGBColor[
             0.9495035044318445, 0.9617911796681917, 0.9679624667041109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 200}], {
             RGBColor[
             0.8423399111493682, 0.8771605736651572, 0.957523840574201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 119}], {
             RGBColor[
             0.5363132586806316, 0.6338985777165573, 0.9567899200787051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 123}], {
             RGBColor[
             0.5172473010829832, 0.6173846035283664, 0.9555750541199474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 127}], {
             RGBColor[
             0.8142173275975599, 0.8539198165712248, 0.8975137051635769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 129}], {
             RGBColor[
             0.7811083033395789, 0.7250222623668563, 0.6107791559422857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 139}], {
             RGBColor[
             0.4842404022279364, 0.5887956867150982, 0.9534718837117584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[
             0.6278485105841864, 0.7087547310021438, 0.963845681119513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 146}], {
             RGBColor[
             0.7993971501960379, 0.7964969481212516, 0.6308824726812725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 155}], {
             RGBColor[
             0.7649211403720777, 0.8168051508332239, 0.9770842730554132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 171}], {
             RGBColor[
             0.6764414684163862, 0.7471141291974337, 0.9684167145292908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 191}], {
             RGBColor[
             0.4626122752656274, 0.567949438414235, 0.9521711277636978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.5990045657762559, 0.6853379172021601, 0.9615749801253815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 196}], {
             RGBColor[
             0.756282742610672, 0.6176692162255, 0.5903420923868474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[
             0.8130536715927439, 0.8534386149086381, 0.9167984966085834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 123}], {
             RGBColor[
             0.41422754051616745`, 0.5332048087387253, 0.9476151904880263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 127}], {
             RGBColor[
             0.7111975670307442, 0.7697400217815837, 0.8895538415316557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 140}], {
             RGBColor[
             0.6813955811903754, 0.653953772897823, 0.605480213047344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 151}], {
             RGBColor[
             0.6926520623060959, 0.698581969521685, 0.6145374419766237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 155}], {
             RGBColor[
             0.661901379805262, 0.7326253560435828, 0.9691244094234921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 156}], {
             RGBColor[
             0.7139510112721705, 0.7702976433913173, 0.8016896984594423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 172}], {
             RGBColor[
             0.5024661346082919, 0.6064199575990689, 0.9541253504856299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 191}], {
             RGBColor[
             0.35959251469881165`, 0.4837696436245938, 0.9442112641317768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 195}], {
             RGBColor[
             0.4959848052094401, 0.601158122412519, 0.9536151164934603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 199}], {
             RGBColor[
             0.7100339110259282, 0.769258820118997, 0.9088386329766622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 124}], {
             RGBColor[
             0.7336181880963841, 0.7918273713364136, 0.9740838630038473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 125}], {
             RGBColor[
             0.7632933968583062, 0.8152169440777017, 0.9769866593790603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 136}], {
             RGBColor[
             0.7422996027540798, 0.7986093584482005, 0.9749491452844938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 137}], {
             RGBColor[
             0.7813516800892141, 0.8296161289469877, 0.978709074554444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 187}], {
             RGBColor[
             0.7304559939740656, 0.7893570412544928, 0.9737686850461188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 198}], {
             RGBColor[
             0.4659614851668161, 0.5658962610266768, 0.9532198587510292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 152}], {
             RGBColor[
             0.4716249956746562, 0.5780462330647114, 0.9526190312471284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 159}], {
             RGBColor[
             0.6115529388299034, 0.6955252517448751, 0.9625628340183696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 161}], {
             RGBColor[
             0.4365614407712338, 0.5413497275013087, 0.9506164463155189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 164}], {
             RGBColor[
             0.5058065513402614, 0.6076525785673174, 0.9547970497485779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 173}], {
             RGBColor[
             0.8010946073050039, 0.8447328514069793, 0.9504681725656439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 180}], {
             RGBColor[
             0.7011534086711572, 0.7663192124957303, 0.9709481897291055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[
             0.6757443859728803, 0.7464694908481116, 0.9684156558073586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 125}], {
             RGBColor[
             0.6215381690777009, 0.6992090055162525, 0.9658416056451651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 137}], {
             RGBColor[
             0.6395964523086086, 0.7136081903855382, 0.9675640208205488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 166}], {
             RGBColor[
             0.5824413786329843, 0.6684592215576923, 0.9619997540574978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 170}], {
             RGBColor[
             0.6725825496157309, 0.7396011318720783, 0.9599874322450974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 179}], {
             RGBColor[
             0.41547177056904816`, 0.5342824982737099, 0.9476944717267664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 192}], {
             RGBColor[
             0.5290263647394399, 0.6267310067349139, 0.9566758446642745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 127}], {
             RGBColor[
             0.6921316094330957, 0.7532260475933928, 0.8883389755728979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 129}], {
             RGBColor[
             0.6590225851751146, 0.6243284933890243, 0.6016044263516069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 139}], {
             RGBColor[
             0.3621546840634722, 0.4881019177372662, 0.9442971541210795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 141}], {
             RGBColor[
             0.5057627924197221, 0.6080609620243118, 0.9546709515288341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 146}], {
             RGBColor[
             0.6773114320315736, 0.6958031791434196, 0.6217077430905937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 155}], {
             RGBColor[
             0.6428354222076136, 0.7161113818553919, 0.9679095434647343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 171}], {
             RGBColor[
             0.5543557502519219, 0.6464203602196017, 0.959241984938612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 191}], {
             RGBColor[
             0.3405265571011632, 0.4672556694364029, 0.942996398173019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 195}], {
             RGBColor[
             0.47691884761179165`, 0.5846441482243281, 0.9524002505347026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 196}], {
             RGBColor[
             0.6341970244462076, 0.516975447247668, 0.5811673627961685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 199}], {
             RGBColor[
             0.6909679534282798, 0.7527448459308062, 0.9076237670179044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 125}], {
             RGBColor[
             0.8159284441142935, 0.8563358430352546, 0.9822328289870547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 136}], {
             RGBColor[
             0.7949346500100671, 0.8397282574057533, 0.9801953148924882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.8339867273452015, 0.8707350279045405, 0.9839552441624384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 187}], {
             RGBColor[
             0.7830910412300529, 0.8304759402120456, 0.9790148546541132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 198}], {
             RGBColor[
             0.5185965324228035, 0.6070151599842296, 0.9584660283590236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 136}], {
             RGBColor[
             0.8246098587719892, 0.8631178301470415, 0.9830981112677012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 137}], {
             RGBColor[
             0.8636619361071235, 0.8941246006458287, 0.9868580405376514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 166}], {
             RGBColor[
             0.8065068624314992, 0.8489756318179827, 0.9812937737746004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[
             0.8966480334142457, 0.9201175421323686, 0.9792814519622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 187}], {
             RGBColor[
             0.812766249991975, 0.8538655129533339, 0.9819176510293262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 192}], {
             RGBColor[
             0.7530918485379547, 0.8072474169952043, 0.975969864381377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 198}], {
             RGBColor[
             0.5482717411847255, 0.6304047327255178, 0.9613688247342366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 190}], {
             RGBColor[
             0.7621503412046404, 0.8143664459606448, 0.9770839634477313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 129}], {
             RGBColor[
             0.9559926116896913, 0.8608637064318827, 0.5435430773952363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 139}], {
             RGBColor[
             0.6591247105780489, 0.7246371307801246, 0.886235805164709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 140}], {
             RGBColor[
             0.9592996501073037, 0.8739750117524905, 0.5462039981322158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 141}], {
             RGBColor[
             0.8027328189342988, 0.8445961750671702, 0.8966096025724635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 155}], {
             RGBColor[
             0.9398054487221903, 0.9526465948982503, 0.9098481945083639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 172}], {
             RGBColor[
             0.7803702035252201, 0.8264411964537364, 0.8948491355705015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 191}], {
             RGBColor[
             0.6374965836157399, 0.7037908824792614, 0.8849350492166483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 195}], {
             RGBColor[
             0.7738888741263683, 0.8211793612671865, 0.8943389015783321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 199}], {
             RGBColor[
             0.9879379799428565, 0.9892800589736646, 0.8495624180615339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 136}], {
             RGBColor[
             0.8119399896272211, 0.8530152204054398, 0.9818896478381475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 162}], {
             RGBColor[
             0.9074750008541741, 0.9252812994513112, 0.822855129622386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 193}], {
             RGBColor[
             0.90404018798714, 0.9150422005510601, 0.6949441904862719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 198}], {
             RGBColor[
             0.5356018720399575, 0.6203021229839161, 0.9601603613046829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 139}], {
             RGBColor[
             0.6260156863200679, 0.5957395765757562, 0.5995012559434179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 141}], {
             RGBColor[
             0.7696237946763178, 0.7156986208628017, 0.6098750533511725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 146}], {
             RGBColor[
             0.9411724342881693, 0.8034408379819096, 0.2769118449129321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 155}], {
             RGBColor[
             0.9066964244642092, 0.8237490406938819, 0.6231136452870727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 191}], {
             RGBColor[
             0.6043875593577588, 0.5748933282748928, 0.5982004999953574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 195}], {
             RGBColor[
             0.7407798498683873, 0.692281807062818, 0.6076043523570409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 131}], {
             RGBColor[
             0.823595298699366, 0.8622427028337791, 0.941763590636248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 149}], {
             RGBColor[
             0.5824688434646657, 0.6715559442044808, 0.960517671817041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 157}], {
             RGBColor[
             0.7477400464890552, 0.8029386661501066, 0.9754703828279795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 168}], {
             RGBColor[
             0.5451087358436321, 0.6404433693841158, 0.9577926041736741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 189}], {
             RGBColor[
             0.5127680347853678, 0.6124314796183458, 0.9557318833000006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 197}], {
             RGBColor[
             0.8304207858428346, 0.8653940390620578, 0.8400323761956703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 147}], {
             RGBColor[
             0.9847559753386765, 0.9875156953766441, 0.8822106963997998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 157}], {
             RGBColor[
             0.9056370197154987, 0.9264135105389952, 0.9499197276194837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 176}], {
             RGBColor[
             0.7413158981369201, 0.7958021075117602, 0.9350418105002225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 138}], {
             RGBColor[
             0.5012202077194461, 0.6043694791229035, 0.9543143395225124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 145}], {
             RGBColor[
             0.6799015011251375, 0.7493281393383765, 0.9690959059228977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 153}], {
             RGBColor[
             0.7460194308262207, 0.8015024550457462, 0.9755472713935517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 182}], {
             RGBColor[
             0.6551317946478616, 0.7299778563815869, 0.9666270930673104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 185}], {
             RGBColor[
             0.7797111694555077, 0.7698041868478349, 0.6212408245057269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 163}], {
             RGBColor[
             0.6172583757819852, 0.6936969318179378, 0.9663999023466497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 178}], {
             RGBColor[
             0.6347181559115258, 0.7076188865601274, 0.968065231761935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 135}], {
             RGBColor[
             0.9670727429091093, 0.974883946060034, 0.9370594717041508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 160}], {
             RGBColor[
             0.9244320098796188, 0.9412386209387077, 0.9453086830607721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 144}], {
             RGBColor[
             0.6554691667740657, 0.7246711281734715, 0.9573317075911144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 148}], {
             RGBColor[
             0.7421744498494984, 0.7985115880479442, 0.9749366712125855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 187}], {
             RGBColor[
             0.7917724558877486, 0.8372579273238325, 0.9798801369347597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 193}], {
             RGBColor[
             0.8957162630276816, 0.9085372246631607, 0.694115139821259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 198}], {
             RGBColor[
             0.527277947080499, 0.6137971470960165, 0.9593313106396701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 166}], {
             RGBColor[
             0.824565145662407, 0.8633748166872686, 0.9830161889499841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 170}], {
             RGBColor[
             0.9147063166451537, 0.9345167270016544, 0.9810038671375837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 179}], {
             RGBColor[
             0.6575955375984709, 0.729198093403286, 0.9687109066192527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 187}], {
             RGBColor[
             0.8308245332228829, 0.8682646978226196, 0.9836400662047099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 192}], {
             RGBColor[
             0.7711501317688625, 0.8216466018644901, 0.9776922795567606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 198}], {
             RGBColor[
             0.5663300244156334, 0.6448039175948037, 0.9630912399096203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 145}], {
             RGBColor[
             0.5737099964319443, 0.661534400882064, 0.9611734239404197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 153}], {
             RGBColor[
             0.6398279261330275, 0.7137087165894338, 0.9676247894110737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 182}], {
             RGBColor[
             0.5489402899546683, 0.6421841179252743, 0.9587046110848324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 185}], {
             RGBColor[
             0.6735196647623143, 0.6820104483915225, 0.6133183425232488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 141}], {
             RGBColor[
             0.4727558935646754, 0.5794720452110436, 0.9525677811206451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 146}], {
             RGBColor[
             0.6443045331765269, 0.6672142623301515, 0.6196045726824047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 155}], {
             RGBColor[
             0.6098285233525667, 0.6875224650421237, 0.9658063730565454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 171}], {
             RGBColor[
             0.5213488513968751, 0.6178314434063336, 0.9571388145304229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 191}], {
             RGBColor[
             0.3075196582461164, 0.4386667526231347, 0.94089322776483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 194}], {
             RGBColor[
             0.6492683276937596, 0.7181019254707335, 0.9394474106125429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 195}], {
             RGBColor[
             0.4439119487567449, 0.5560552314110598, 0.9502970801265136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 196}], {
             RGBColor[
             0.6011901255911609, 0.48838653043439983`, 0.5790641923879796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 151}], {
             RGBColor[
             0.9407541453826553, 0.8028169594925918, 0.27118759857718366`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 161}], {
             RGBColor[
             0.5849101006892443, 0.5640566825374287, 0.5995638773299247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 162}], {
             RGBColor[
             0.9620918756943018, 0.8746155827390065, 0.462560965194758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 172}], {
             RGBColor[
             0.7505682176848514, 0.7106549475699756, 0.6107755070861898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 173}], {
             RGBColor[
             0.9494432672230144, 0.8674398064430993, 0.5994156035800496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 180}], {
             RGBColor[
             0.8495020685891677, 0.7890261675318504, 0.6198956207435113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 191}], {
             RGBColor[
             0.6076945977753712, 0.5880046335955005, 0.6008614207323367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 146}], {
             RGBColor[
             0.7879126415327768, 0.787173306617197, 0.6299783700901593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 155}], {
             RGBColor[
             0.7534366317088167, 0.8074815093291692, 0.9761801704643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 167}], {
             RGBColor[
             0.6060422384378834, 0.6910514169124098, 0.9621290114971491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 191}], {
             RGBColor[
             0.45112776660236636`, 0.5586257969101802, 0.9512670251725845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 194}], {
             RGBColor[
             0.7928764360500097, 0.838060969757779, 0.9498212080202975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 195}], {
             RGBColor[
             0.5875200571129948, 0.6760142756981053, 0.9606708775342682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 147}], {
             RGBColor[
             0.7904852155224799, 0.8348685011131107, 0.904653429562005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 154}], {
             RGBColor[
             0.4977498991566939, 0.6017563212399611, 0.9539847244488894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 157}], {
             RGBColor[
             0.711366259899302, 0.773766316275462, 0.972362460781689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 168}], {
             RGBColor[
             0.5087349492538789, 0.6112710195094712, 0.9546846821273836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 176}], {
             RGBColor[
             0.5470451383207233, 0.6431549132482268, 0.9574845436624277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.58756855403607, 0.6760536476850194, 0.9606746953897027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 154}], {
             RGBColor[
             0.652390390042726, 0.7239842971864343, 0.9687039547221001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 158}], {
             RGBColor[
             0.8781155135345402, 0.9056494909545432, 0.9882366356555392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 160}], {
             RGBColor[
             0.8832124951020246, 0.9097136857025762, 0.988722790307575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 181}], {
             RGBColor[
             0.8235289673242936, 0.8627311332318193, 0.9828689176211383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 188}], {
             RGBColor[
             0.7422090449221023, 0.7982816236314925, 0.9753939256629136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 158}], {
             RGBColor[
             0.607731452177091, 0.686961608304112, 0.9650947642956998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 153}], {
             RGBColor[
             0.8185092195387189, 0.8586673768049067, 0.982406355811459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 185}], {
             RGBColor[
             0.8522009581680058, 0.8269691086069955, 0.6280999089236342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 155}], {
             RGBColor[
             0.9249852713206681, 0.8952237264482772, 0.6432169620260595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 171}], {
             RGBColor[
             0.8365055993649766, 0.825532704812487, 0.6345494034999372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 184}], {
             RGBColor[
             0.8348781377569764, 0.8242613194351509, 0.6343871933363452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 186}], {
             RGBColor[
             0.9768157571870479, 0.9324272835154996, 0.45192960485432804`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 191}], {
             RGBColor[
             0.6226764062142178, 0.6463680140292881, 0.6183038167343442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 194}], {
             RGBColor[
             0.9644250756618611, 0.9258031868768869, 0.6168579995820571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 195}], {
             RGBColor[
             0.7590686967248463, 0.7637564928172134, 0.6277076690960277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 196}], {
             RGBColor[
             0.9163468735592624, 0.6960877918405532, 0.25647478135749374`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 154}], {
             RGBColor[
             0.6952843623857576, 0.7562016636574707, 0.8975397522587315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 157}], {
             RGBColor[
             0.9089007231283658, 0.9282116586929716, 0.9159174885915311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 168}], {
             RGBColor[
             0.7062694124829426, 0.7657163619269807, 0.8982397099372257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 176}], {
             RGBColor[
             0.7445796015497872, 0.7976002556657364, 0.9010395714722699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 188}], {
             RGBColor[
             0.7851030172651339, 0.8304989901025289, 0.9042297231995449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 150}], {
             RGBColor[
             0.6935403970680433, 0.7605182963825803, 0.9700892833423935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 193}], {
             RGBColor[
             0.8342746482094172, 0.8605385681935647, 0.6879912138607099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 167}], {
             RGBColor[
             0.5474799182056251, 0.6435078871454007, 0.9575187711276183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 168}], {
             RGBColor[
             0.46187925383537526`, 0.5732314551437061, 0.9509960301459712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 189}], {
             RGBColor[
             0.42953855277711106`, 0.5452195653779361, 0.9489353092722976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 194}], {
             RGBColor[
             0.7343141158177515, 0.7905174399907701, 0.9452109676507667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.7471913038345779, 0.7981821248216482, 0.8332358021679674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 156}], {
             RGBColor[
             0.9733095754644505, 0.9191608299860863, 0.4673970839892819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 172}], {
             RGBColor[
             0.7618246988005719, 0.7552831441938377, 0.6198327360154694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 175}], {
             RGBColor[
             0.7759070064152427, 0.7667157959161559, 0.6209413468560889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 183}], {
             RGBColor[
             0.9677329343400352, 0.9173133416709458, 0.5965674831578203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 199}], {
             RGBColor[
             0.9693924752182081, 0.9181220067137659, 0.5745460185065019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 159}], {
             RGBColor[
             0.45037759007364575`, 0.5607966320130968, 0.9509463576464057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 178}], {
             RGBColor[
             0.6217326304990989, 0.6963714771193678, 0.9672378055653044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 200}], {
             RGBColor[
             0.5145690372166227, 0.6117408711163332, 0.9567991794353946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 182}], {
             RGBColor[
             0.793739513061443, 0.839317093848117, 0.9799375429558717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 185}], {
             RGBColor[
             0.918318887869089, 0.8791434243143652, 0.6345512743942882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 157}], {
             RGBColor[
             0.6161654067625798, 0.6950994788198219, 0.9652487834784156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 158}], {
             RGBColor[
             0.6282741695117857, 0.7047546775524299, 0.966403728079055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 160}], {
             RGBColor[
             0.6333711510792701, 0.7088188723004629, 0.9668898827310908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 176}], {
             RGBColor[
             0.4518442851840011, 0.5644880757925868, 0.9503708663591542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 181}], {
             RGBColor[
             0.5736876233015391, 0.661836319829706, 0.961036010044654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 188}], {
             RGBColor[
             0.4923677008993478, 0.5973868102293793, 0.9535610180864292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 172}], {
             RGBColor[
             0.731074016299738, 0.7893265307157354, 0.9744197034623379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 191}], {
             RGBColor[
             0.5882003963902578, 0.6666762167412603, 0.9645056171084848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 195}], {
             RGBColor[
             0.7245926869008862, 0.7840646955291856, 0.9739094694701684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 199}], {
             RGBColor[
             0.9386417927173742, 0.9521653932356636, 0.9291329859533703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 166}], {
             RGBColor[
             0.8810092982086539, 0.9045511758575706, 0.8160006313295167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 170}], {
             RGBColor[
             0.9711504691914006, 0.9756930861719565, 0.8139883095171163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 175}], {
             RGBColor[
             0.7972059553813173, 0.8384314697857883, 0.8080936033389075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 183}], {
             RGBColor[
             0.9890318833061098, 0.9890290155405782, 0.7837197396406389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 199}], {
             RGBColor[
             0.9906914241842828, 0.9898376805833982, 0.7616982749893204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 168}], {
             RGBColor[
             0.6271504568597648, 0.7046141770893319, 0.9659487411569098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 176}], {
             RGBColor[
             0.6654606459266093, 0.7364980708280877, 0.9687486026919538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 188}], {
             RGBColor[
             0.7059840616419559, 0.7693968052648801, 0.9719387544192288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 160}], {
             RGBColor[
             0.8590962745710842, 0.8904840660685718, 0.9864225636645297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 176}], {
             RGBColor[
             0.6775694086758153, 0.7461532695606956, 0.9699035472925932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.7994127467933532, 0.8435015135978149, 0.9805686909780931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 161}], {
             RGBColor[
             0.41531403517022336`, 0.5241001264496942, 0.948943772714796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 162}], {
             RGBColor[
             0.7924958101752808, 0.8346590266512719, 0.8119408605796294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 164}], {
             RGBColor[
             0.484559145739251, 0.5904029775157028, 0.9531243761478552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 173}], {
             RGBColor[
             0.7798472017039935, 0.8274832503553647, 0.948795498964921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 180}], {
             RGBColor[
             0.6799060030701467, 0.7490696114441158, 0.9692755161283827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 200}], {
             RGBColor[
             0.6544969803718699, 0.7292198897964971, 0.9667429822066358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[
             0.8045097283608376, 0.8475657083458479, 0.9810548456301289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 162}], {
             RGBColor[
             0.6175043121166113, 0.6804835024077054, 0.7999944728767786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 164}], {
             RGBColor[
             0.3095676476805815, 0.4362274532721364, 0.9411779884450044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 173}], {
             RGBColor[
             0.6048557036453239, 0.6733077261117983, 0.9368491112620703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 180}], {
             RGBColor[
             0.5049145050114772, 0.5948940872005494, 0.9573291284255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 200}], {
             RGBColor[
             0.47950548231320034`, 0.5750443655529307, 0.9547965945037851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 172}], {
             RGBColor[
             0.7831624291122182, 0.8270817674402524, 0.8112061026330437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 173}], {
             RGBColor[
             0.9820374786503814, 0.9838666263133761, 0.7998461991269036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 180}], {
             RGBColor[
             0.8820962800165346, 0.9054529874021271, 0.8203262162903653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 165}], {
             RGBColor[
             0.887704572221851, 0.9132955460637406, 0.9891512486333887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 175}], {
             RGBColor[
             0.7489497200764137, 0.8037839335686408, 0.975890131815294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 177}], {
             RGBColor[
             0.9324981691274061, 0.9107952300070662, 0.6580283410592364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 200}], {
             RGBColor[
             0.548750592882228, 0.6413472166189393, 0.9589771979368441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 169}], {
             RGBColor[
             0.8076620317965731, 0.8501343544861343, 0.9813408972945303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 175}], {
             RGBColor[
             0.7385582384775466, 0.7954980482109579, 0.974898983023809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 177}], {
             RGBColor[
             0.9221066875285391, 0.9025093446493834, 0.6570371922677513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 170}], {
             RGBColor[
             0.8575512429695293, 0.8893677581738085, 0.9754396003745327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 179}], {
             RGBColor[
             0.6004404639228466, 0.6840491245754401, 0.9631466398562016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 183}], {
             RGBColor[
             0.8754326570842386, 0.9027036875424302, 0.9451710304980552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 192}], {
             RGBColor[
             0.7139950580932382, 0.7764976330366442, 0.9721280127937098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 198}], {
             RGBColor[
             0.5091749507400091, 0.5996549487669578, 0.9575269731465693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 189}], {
             RGBColor[
             0.47777910952632735`, 0.5843834225592658, 0.9527329826105779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 194}], {
             RGBColor[
             0.7825546725669678, 0.8296812971720997, 0.9490086409890469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 197}], {
             RGBColor[
             0.7954318605837941, 0.8373459820029778, 0.8370334755062476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 188}], {
             RGBColor[
             0.5033527509965328, 0.6069015084988894, 0.9542609757649234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 189}], {
             RGBColor[
             0.3921784451560774, 0.5141069905575711, 0.9462102416289309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 197}], {
             RGBColor[
             0.7098311962135442, 0.7670695500012832, 0.8305107345246006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 177}], {
             RGBColor[
             0.8524556287021283, 0.8476340384294598, 0.6502179897203779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 190}], {
             RGBColor[
             0.6728247215661772, 0.743803179000917, 0.9683881837264166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 179}], {
             RGBColor[
             0.6905816349055931, 0.7551910348898261, 0.9611343180438012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 183}], {
             RGBColor[
             0.9655738280669851, 0.9738455978568161, 0.9431587086856548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[
             0.8041362290759848, 0.8476395433510301, 0.9701156909813093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 198}], {
             RGBColor[
             0.5993161217227556, 0.6707968590813436, 0.9555146513341689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 174}], {
             RGBColor[
             0.5178559291792757, 0.6148060497408242, 0.9569162486153875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 182}], {
             RGBColor[
             0.7082008972342043, 0.7719711905363134, 0.9715505049887929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 191}], {
             RGBColor[
             0.4997207244345661, 0.5969851951054702, 0.9558380585823625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 195}], {
             RGBColor[
             0.6361130149451946, 0.7143736738933955, 0.965241910944046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 196}], {
             RGBColor[
             0.7933911917796106, 0.6467049729167353, 0.594009023205512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 199}], {
             RGBColor[
             0.8501621207616826, 0.8824743715998735, 0.9204654274272479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 173}], {
             RGBColor[
             0.770513820640931, 0.8199059911443451, 0.9480607410183355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 180}], {
             RGBColor[
             0.6705726220070842, 0.7414923522330963, 0.9685407581817971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 191}], {
             RGBColor[
             0.4287651511932876, 0.5404708182967464, 0.9495065581706226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 180}], {
             RGBColor[
             0.8694476715452473, 0.89827721110622, 0.9571808546756568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 186}], {
             RGBColor[
             0.658166087001347, 0.7217006284438368, 0.7742964499697783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 196}], {
             RGBColor[
             0.5976972033735615, 0.4853611367688905, 0.578841626472944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 183}], {
             RGBColor[
             0.791629314256902, 0.8365839814706479, 0.9372640025074459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 188}], {
             RGBColor[
             0.5416629400633773, 0.638785402237645, 0.9570608372999676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 179}], {
             RGBColor[
             0.7001855701465023, 0.7249407149420832, 0.6373778211095347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 190}], {
             RGBColor[
             0.7872693772981432, 0.7961781691641661, 0.6440844786996376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 183}], {
             RGBColor[
             0.7084630490203023, 0.7685269642584478, 0.9308657481673238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 192}], {
             RGBColor[
             0.547025450029302, 0.6423209097526617, 0.9578227304629783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 185}], {
             RGBColor[
             0.8274312516907298, 0.8076188256502057, 0.6256310960680469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 195}], {
             RGBColor[
             0.6307639945940741, 0.7101949785410397, 0.9647087705848836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 196}], {
             RGBColor[
             0.7880421714284901, 0.6425262775643796, 0.5934758828463496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 199}], {
             RGBColor[
             0.8448131004105621, 0.8782956762475178, 0.9199322870680855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 192}], {
             RGBColor[
             0.822017643190694, 0.8609754727196518, 0.9398471211048318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 186}], {
             RGBColor[
             0.8522326137993961, 0.8817730792143457, 0.7893016365387543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 194}], {
             RGBColor[
             0.8398419322742092, 0.8751489825757329, 0.9542300312664833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 198}], {
             RGBColor[
             0.5154343383004849, 0.6045448299023088, 0.9581508504012951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 194}], {
             RGBColor[
             0.6646133071384537, 0.731392975404635, 0.9404251791337263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 197}], {
             RGBColor[
             0.67749049515528, 0.7390576602355132, 0.828450013650927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 195}], {
             RGBColor[
             0.42228382179443585`, 0.5352089831101965, 0.948996324178453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 199}], {
             RGBColor[
             0.636332927610924, 0.7033096808166746, 0.9042198406616548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 197}], {
             RGBColor[
             0.9822660581959204, 0.984355534848347, 0.8247256720293961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 196}], {
             RGBColor[
             0.7159542891394803, 0.5849287609214617, 0.5871672888016026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 199}], {
             RGBColor[
             0.7727252181215524, 0.8206981596045998, 0.9136236930233386]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.04610843439966642], {
             RGBColor[
             0.974918376118748, 0.9808147464935277, 0.9273408262824829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.04610843439966642], {
             RGBColor[
             0.5757019452613417, 0.6664198000970617, 0.9597405124781359]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.04610843439966642], {
             RGBColor[
             0.42216523483792234`, 0.5400800406001125, 0.9481209733511811]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.04610843439966642], {
             RGBColor[
             0.39642092785410055`, 0.5177816158372183, 0.9464805688749687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.04610843439966642], {
             RGBColor[
             0.9040475157549253, 0.6571840039627259, 0.24164723394634818`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.04610843439966642], {
             RGBColor[
             0.9940032831560337, 0.9895819539688607, 0.5886725628598739]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.04610843439966642], {
             RGBColor[
             0.5576074648744436, 0.6517298857719258, 0.9583160486998136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.04610843439966642], {
             RGBColor[
             0.979796620338884, 0.943511397803234, 0.37601411441502275`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.04610843439966642], {
             RGBColor[
             0.6553910553923596, 0.7307157407198008, 0.9662869134900286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.04610843439966642], {
             RGBColor[
             0.8676518836522882, 0.8973060765141021, 0.9872386052963773]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.04610843439966642], {
             RGBColor[
             0.8113509160570009, 0.852552769209861, 0.9818315348733182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.04610843439966642], {
             RGBColor[
             0.30631552238966, 0.43928741393035164`, 0.9407555878956606]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.04610843439966642], {
             RGBColor[
             0.5672805666171326, 0.6595829455349081, 0.9590775507027373]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.04610843439966642], {
             RGBColor[
             0.8540831945672507, 0.8864867721499468, 0.9859444116185347]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.04610843439966642], {
             RGBColor[
             0.41539505821686284`, 0.5342160538899219, 0.9476895836835192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.04610843439966642], {
             RGBColor[
             0.7458452025743775, 0.8013792079753738, 0.975302537539067]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.04610843439966642], {
             RGBColor[
             0.5599033870886682, 0.6535938188555503, 0.9584967921067575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.04610843439966642], {
             RGBColor[
             0.7839441419777637, 0.8311423889999632, 0.9790998837639653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.04610843439966642], {
             RGBColor[
             0.9887109566620343, 0.9735815474069248, 0.4106446276993004]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.04610843439966642], {
             RGBColor[
             0.9706585495231477, 0.9776377747933549, 0.9345516015681211]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.04610843439966642], {
             RGBColor[
             0.3147594051423885, 0.44705050929180634`, 0.9412771688582277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.04610843439966642], {
             RGBColor[
             0.9661931164741268, 0.9743074621368707, 0.9421104149486488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.04610843439966642], {
             RGBColor[
             0.30848321555448455`, 0.44156579688626707`, 0.9408790348145827]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.04610843439966642], {
             RGBColor[
             0.36520783041368615`, 0.49074639965022404`, 0.9444916979067238]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.04610843439966642], {
             RGBColor[
             0.9924989785246626, 0.9911661490995585, 0.7739748680750453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.04610843439966642], {
             RGBColor[
             0.7424793324440966, 0.7987497646480379, 0.9749670590603253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.04610843439966642], {
             RGBColor[
             0.5612399861622367, 0.6546789301965753, 0.9586020140819526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.04610843439966642], {
             RGBColor[
             0.7315670264367106, 0.7902249882584705, 0.9738794223788065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.04610843439966642], {
             RGBColor[
             0.4819380950236918, 0.5902980824608208, 0.9523590787191275]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.04610843439966642], {
             RGBColor[
             0.8756816383236217, 0.9037087849271394, 0.9880044904651758]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.04610843439966642], {
             RGBColor[
             0.38570250318015065`, 0.5084978551083311, 0.9457976003326755]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.04610843439966642], {
             RGBColor[
             0.48418906917059457`, 0.5921255246785062, 0.9525362836495617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.04610843439966642], {
             RGBColor[
             0.5396111452962791, 0.6371196628134137, 0.9568993124999298]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.04610843439966642], {
             RGBColor[
             0.5272109882126501, 0.6270526566722131, 0.9559231267110344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.04610843439966642], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.04610843439966642], {
             RGBColor[
             0.9001488282558243, 0.6394809745909084, 0.23839407353152295`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.04610843439966642], {
             RGBColor[
             0.9529712857772878, 0.964446642451929, 0.9644915255126626]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.04610843439966642], {
             RGBColor[
             0.5903055332288929, 0.6782756506932606, 0.9608901604176469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.04610843439966642], {
             RGBColor[
             0.9580554522992663, 0.9682384055194618, 0.9558853577539527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.04610843439966642], {
             RGBColor[
             0.9930920149563756, 0.9876328434331401, 0.4894866430225257]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.04610843439966642], {
             RGBColor[
             0.7695064729114005, 0.8198635721949711, 0.9776608718391185]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.04610843439966642], {
             RGBColor[
             0.2915774756419373, 0.4237967923523603, 0.939916277936364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.04610843439966642], {
             RGBColor[
             0.44693087067580467`, 0.5615307896058361, 0.949699017767379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.04610843439966642], {
             RGBColor[
             0.4072400568378569, 0.527152601577714, 0.9471699542068336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.04610843439966642], {
             RGBColor[
             0.513890069985407, 0.6162381351548097, 0.9548744552320546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.04610843439966642], {
             RGBColor[
             0.9755464071592613, 0.9291744307508548, 0.35950283879760003`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.04610843439966642], {
             RGBColor[
             0.9595610670608605, 0.969361290543441, 0.9533367446897943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.04610843439966642], {
             RGBColor[
             0.7283092242588859, 0.7876799684369403, 0.9735547151036132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.04610843439966642], {
             RGBColor[
             0.6762652221946062, 0.7470227984752593, 0.968367455356697]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.04610843439966642], {
             RGBColor[
             0.879885979414867, 0.9070612123894997, 0.9884055042717184]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.04610843439966642], {
             RGBColor[
             0.8883456824638799, 0.5858856462444262, 0.22854523936114635`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.04610843439966642], {
             RGBColor[
             0.4757937713459536, 0.5853098437006056, 0.9518753750518167]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.04610843439966642], {
             RGBColor[
             0.8384111844775699, 0.8739903367098165, 0.9844496013056124]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.04610843439966642], {
             RGBColor[
             0.8335093357139387, 0.8700817355628371, 0.9839820585946052]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.04610843439966642], {
             RGBColor[
             0.6465773511893601, 0.7238304080097846, 0.9654084458238222]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.04610843439966642], {
             RGBColor[
             0.7017624172554945, 0.766941401042685, 0.9709087774755314]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.04610843439966642], {
             RGBColor[
             0.3470246381926262, 0.4749970324621562, 0.9433330809771634]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.04610843439966642], {
             RGBColor[
             0.8769251433785681, 0.904700322103908, 0.9881230970874066]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.04610843439966642], {
             RGBColor[
             0.7695064729114005, 0.8198635721949711, 0.9776608718391185]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.04610843439966642], {
             RGBColor[
             0.9950786975386541, 0.9922329292075985, 0.7312222479144064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.04610843439966642], {
             RGBColor[
             0.8934787620775132, 0.9178997283184375, 0.9897019960165019]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.04610843439966642], {
             RGBColor[
             0.8217365634979732, 0.860694446561215, 0.9828591610709686]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.04610843439966642], {
             RGBColor[
             0.90303589039225, 0.6525904494619237, 0.24080310894652518`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.04610843439966642], {
             RGBColor[
             0.5035912849135593, 0.6078771174785035, 0.954063697145506]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.04610843439966642], {
             RGBColor[
             0.8245580961482076, 0.8629442601080484, 0.9831282813739599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.04610843439966642], {
             RGBColor[
             0.9633642336331681, 0.8880810989369741, 0.3121773950591637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.04610843439966642], {
             RGBColor[
             0.7324595408390674, 0.7909222272929524, 0.9739683798734122]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.04610843439966642], {
             RGBColor[
             0.45283958096815463`, 0.5666486174806552, 0.9500755155623402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.04610843439966642], {
             RGBColor[
             0.898096053820718, 0.9215814314214235, 0.9901423974248738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.04610843439966642], {
             RGBColor[
             0.989573060154557, 0.9899562066608475, 0.8224649075017101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.04610843439966642], {
             RGBColor[
             0.743985950461127, 0.7999267460936631, 0.9751172246641171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.04610843439966642], {
             RGBColor[
             0.48353076797913197`, 0.5915910861151461, 0.9524844597683331]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.04610843439966642], {
             RGBColor[
             0.316363806804568, 0.448440161372014, 0.941379399913425]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.04610843439966642], {
             RGBColor[
             0.5975300291092396, 0.6841408219087564, 0.9614588991975481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.04610843439966642], {
             RGBColor[
             0.8774232610327151, 0.9050975076002813, 0.988170607993934]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.04610843439966642], {
             RGBColor[
             0.5647521680396248, 0.6575302776666294, 0.9588785059048868]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.04610843439966642], {
             RGBColor[
             0.9459222172389993, 0.9591894586778638, 0.9764237598564638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.04610843439966642], {
             RGBColor[
             0.6677414726475519, 0.7403639805462046, 0.9675178876608149]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.04610843439966642], {
             RGBColor[
             0.19207344937466098`, 0.3192117518258016, 0.934249670843458]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.04610843439966642], {
             RGBColor[
             0.8371596486230256, 0.8729923959914386, 0.9843302286985467]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.04610843439966642], {
             RGBColor[
             0.40888115724978835`, 0.5285740402704241, 0.9472745236739137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.04610843439966642], {
             RGBColor[
             0.9465785633501452, 0.9596789605328884, 0.9753127370927758]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.04610843439966642], {
             RGBColor[
             0.7073460186249579, 0.771303352869452, 0.9714652986783181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.04610843439966642], {
             RGBColor[
             0.9871332939931992, 0.9889473006539956, 0.862898146707837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.04610843439966642], {
             RGBColor[
             0.7871140135818742, 0.8336187167890107, 0.9794158269413287]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.04610843439966642], {
             RGBColor[
             0.9946876794112736, 0.9920712331632192, 0.7377024302075773]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.04610843439966642], {
             RGBColor[
             0.6237700437240283, 0.7054436478722292, 0.9635246092683649]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.04610843439966642], {
             RGBColor[
             0.6521413622855295, 0.7281770557661628, 0.9659630144512484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.04610843439966642], {
             RGBColor[
             0.7695727766162598, 0.8199153691531341, 0.9776674803727756]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.04610843439966642], {
             RGBColor[
             0.3138994888025372, 0.4463056929788791, 0.9412223757494464]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.04610843439966642], {
             RGBColor[
             0.8152906500628542, 0.8556305193583209, 0.9822242107401141]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.04610843439966642], {
             RGBColor[
             0.5826400128943543, 0.6720524359579263, 0.9602867025771857]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.04610843439966642], {
             RGBColor[
             0.7554904036144439, 0.8089141123341166, 0.9762638810392125]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.04610843439966642], {
             RGBColor[
             0.9697782607012021, 0.9097171183226265, 0.3370946790310986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.04610843439966642], {
             RGBColor[
             0.4927252994438893, 0.5990556209671584, 0.9532082869659172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.04610843439966642], {
             RGBColor[
             0.452625492329106, 0.5664631846619191, 0.9500618740235711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.04610843439966642], {
             RGBColor[
             0.9872451489838309, 0.9889935555671641, 0.8610444200416333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.04610843439966642], {
             RGBColor[
             0.7822444717657953, 0.8298145937124013, 0.9789304765215574]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.04610843439966642], {
             RGBColor[
             0.9024017491886148, 0.9250146760327971, 0.9905530784928034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.04610843439966642], {
             RGBColor[
             0.9842273197806679, 0.9877456056369832, 0.9110576598296699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.04610843439966642], {
             RGBColor[
             0.7274932157900237, 0.7870424964191711, 0.9734733830054698]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.04610843439966642], {
             RGBColor[
             0.835018406651975, 0.8712850277661878, 0.9841259951278386]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.04610843439966642], {
             RGBColor[
             0.969388870179094, 0.9766908500174689, 0.9367008375121952]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.04610843439966642], {
             RGBColor[
             0.5091843781744347, 0.6124178425536622, 0.9545040059351777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.04610843439966642], {
             RGBColor[
             0.30848321555448455`, 0.44156579688626707`, 0.9408790348145827]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.04610843439966642], {
             RGBColor[
             0.6201476270073708, 0.7025028067936332, 0.96323943935508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.04610843439966642], {
             RGBColor[
             0.5844473366851763, 0.6735197028303246, 0.9604289817264444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.04610843439966642], {
             RGBColor[
             0.8784383102020603, 0.5408985827290841, 0.22027828509396746`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.04610843439966642], {
             RGBColor[
             0.27294721381846143`, 0.4042152059490631, 0.9388553120865196]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.04610843439966642], {
             RGBColor[
             0.9102096848079109, 0.9312405119548574, 0.9912978063623982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.04610843439966642], {
             RGBColor[
             0.9419987792322736, 0.9562633650364879, 0.9830651170053324]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.04610843439966642], {
             RGBColor[
             0.7073460186249579, 0.771303352869452, 0.9714652986783181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.04610843439966642], {
             RGBColor[
             0.5396385904246548, 0.637141944005018, 0.9569014730809703]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.04610843439966642], {
             RGBColor[
             0.5648936973559493, 0.6576451775414447, 0.9588896476111067]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.04610843439966642], {
             RGBColor[
             0.7784112685141984, 0.8268200661988301, 0.9785484186447593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.04610843439966642], {
             RGBColor[
             0.9659913947838896, 0.9741570184305808, 0.9424518771527773]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.04610843439966642], {
             RGBColor[
             0.6393330192474475, 0.7180783725061984, 0.9647497837106263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.04610843439966642], {
             RGBColor[
             0.4332934981138159, 0.5497187829269162, 0.9488300564467841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.04610843439966642], {
             RGBColor[
             0.6809831408403968, 0.7507084723788607, 0.9688376933958529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.04610843439966642], {
             RGBColor[
             0.6328003444309138, 0.7127748527964897, 0.9642355076190924]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.04610843439966642], {
             RGBColor[
             0.397472685279186, 0.5186925952559621, 0.9465475859280625]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.04610843439966642], {
             RGBColor[
             0.395161582918519, 0.5166908345505344, 0.9464003245292685]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.04610843439966642], {
             RGBColor[
             0.7862532353523716, 0.8329462702939664, 0.9793300326118417]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.04610843439966642], {
             RGBColor[
             0.8456036528762156, 0.8797254157765428, 0.9851356253622676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.04610843439966642], {
             RGBColor[
             0.9166622122470889, 0.9363855821856665, 0.9919132541897863]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.04610843439966642], {
             RGBColor[
             0.9891016359476724, 0.9897612606362512, 0.8302776266165274]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.04610843439966642], {
             RGBColor[
             0.8202639145866796, 0.8595201962933392, 0.9827186985031602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.04610843439966642], {
             RGBColor[
             0.9228835874317103, 0.7319661522275143, 0.2568085281739453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.04610843439966642], {
             RGBColor[
             0.6656983254729225, 0.7387678584448905, 0.9673142458447438]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.04610843439966642], {
             RGBColor[
             0.9814922719258095, 0.9857175472226678, 0.9162129354277524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.04610843439966642], {
             RGBColor[
             0.6074117124126394, 0.6921632175792161, 0.9622368215049905]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.04610843439966642], {
             RGBColor[
             0.3364206977432522, 0.4658124322144522, 0.9426574072684257]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.04610843439966642], {
             RGBColor[
             0.9846707636206691, 0.9879289810608105, 0.9037086478049786]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.04610843439966642], {
             RGBColor[
             0.9494747221975495, 0.9618389110592576, 0.970410295603323]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.04610843439966642], {
             RGBColor[
             0.8036160646677627, 0.8465102445175402, 0.9810605971731348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.04610843439966642], {
             RGBColor[
             0.8817202193380314, 0.9085237855151145, 0.9885804557130351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.04610843439966642], {
             RGBColor[
             0.3950287030262528, 0.5165757406665911, 0.9463918575400343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.04610843439966642], {
             RGBColor[
             0.3291477852084254, 0.459513000923998, 0.9421939837128905]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.04610843439966642], {
             RGBColor[
             0.9294976642669348, 0.7581887628687297, 0.26213036964790404`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.04610843439966642], {
             RGBColor[
             0.6163640019209253, 0.6994310894980891, 0.9629415785283997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.04610843439966642], {
             RGBColor[
             0.5929507522934161, 0.6804231586956012, 0.9610984017521629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.04610843439966642], {
             RGBColor[
             0.9022317340654805, 0.9248791105885474, 0.9905368622985845]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.04610843439966642], {
             RGBColor[
             0.36146361135058214`, 0.4875033452876853, 0.9442531195789058]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.04610843439966642], {
             RGBColor[
             0.7523912898376357, 0.8064930610975369, 0.975954990340805]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.04610843439966642], {
             RGBColor[
             0.9594612811446283, 0.8749155237363049, 0.2970151616519189]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.04610843439966642], {
             RGBColor[
             0.9880196787515436, 0.9893138435306204, 0.8482084573718471]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.04610843439966642], {
             RGBColor[
             0.680732835031234, 0.7505129315783482, 0.9688127452520364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.04610843439966642], {
             RGBColor[
             0.4992393614564089, 0.6043440299640712, 0.9537210977893381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.04610843439966642], {
             RGBColor[
             0.7063479591048525, 0.7705236611868124, 0.9713658214327505]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.04610843439966642], {
             RGBColor[
             0.9520106264983759, 0.8474451561164539, 0.28024482750646335`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.04610843439966642], {
             RGBColor[
             0.31044964691839855`, 0.44331761333293296`, 0.9410025548751645]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.04610843439966642], {
             RGBColor[
             0.8846271492398021, 0.9108416925122764, 0.9888577212821129]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.04610843439966642], {
             RGBColor[
             0.4025490460199716, 0.5230894837843211, 0.9468710471456159]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.04610843439966642], {
             RGBColor[
             0.8905092614967081, 0.9155319291602494, 0.9894187624002002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.04610843439966642], {
             RGBColor[
             0.9946085244305252, 0.9908765038557186, 0.6545493404721004]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.04610843439966642], {
             RGBColor[
             0.829781767505188, 0.8671094738553228, 0.9836265198112152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.04610843439966642], {
             RGBColor[
             0.8539992930035999, 0.8864198713205388, 0.9859364090124939]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.04610843439966642], {
             RGBColor[
             0.5903055332288929, 0.6782756506932606, 0.9608901604176469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.04610843439966642], {
             RGBColor[
             0.8641932561385686, 0.8945482608166049, 0.9869087183165656]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.04610843439966642], {
             RGBColor[
             0.24032253711155382`, 0.3699246022061277, 0.9369973850119453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.04610843439966642], {
             RGBColor[
             0.9946860871216686, 0.9910424026092832, 0.6629915607416119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.04610843439966642], {
             RGBColor[
             0.898096053820718, 0.9215814314214235, 0.9901423974248738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.04610843439966642], {
             RGBColor[
             0.37881275824960914`, 0.502530304338145, 0.9453585918780635]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.04610843439966642], {
             RGBColor[
             0.8773130906229839, 0.9050096607060578, 0.9881600998419036]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.04610843439966642], {
             RGBColor[
             0.7674100719867827, 0.8182258478594227, 0.9774519221869331]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.04610843439966642], {
             RGBColor[
             0.5957204749548415, 0.6826717443267304, 0.9613164444658986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.04610843439966642], {
             RGBColor[
             0.4245191462143416, 0.5421188803233411, 0.9482709625026043]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.04610843439966642], {
             RGBColor[
             0.7380109729701624, 0.7952590482662107, 0.974521694747157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.04610843439966642], {
             RGBColor[
             0.9476924139522759, 0.9605096684881944, 0.9734272785621323]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.04610843439966642], {
             RGBColor[
             0.7135499175853248, 0.7761498858886691, 0.9720836453479554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.04610843439966642], {
             RGBColor[
             0.5716387711027678, 0.6631211322712215, 0.9594206445244756]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.04610843439966642], {
             RGBColor[
             0.969388870179094, 0.9766908500174689, 0.9367008375121952]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.04610843439966642], {
             RGBColor[
             0.3221619407732266, 0.45346221359297934`, 0.9417488518828194]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.04610843439966642], {
             RGBColor[
             0.5998033863321095, 0.685986435715858, 0.9616378662057143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.04610843439966642], {
             RGBColor[
             0.5011395243480307, 0.6058866678008525, 0.9538706855726926]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.04610843439966642], {
             RGBColor[
             0.9669002844340943, 0.9000090285927089, 0.32591428469359895`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.04610843439966642], {
             RGBColor[
             0.9330156140797994, 0.9494253409058026, 0.9934730562554444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.04610843439966642], {
             RGBColor[
             0.4334708558589104, 0.5498724012914576, 0.9488413575254703]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.04610843439966642], {
             RGBColor[
             0.7695064729114005, 0.8198635721949711, 0.9776608718391185]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.04610843439966642], {
             RGBColor[
             0.7448262005831066, 0.800583155875091, 0.9752009729436921]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.04610843439966642], {
             RGBColor[
             0.7028518768830838, 0.7677924951839576, 0.9710173646296305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.04610843439966642], {
             RGBColor[
             0.9834552421816943, 0.9871815272254378, 0.9128901388091774]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.04610843439966642], {
             RGBColor[
             0.7102949943693245, 0.7736071151339969, 0.9717592250207714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.04610843439966642], {
             RGBColor[
             0.9520106264983759, 0.8474451561164539, 0.28024482750646335`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.04610843439966642], {
             RGBColor[
             0.9941702332294676, 0.9899390432946943, 0.6068440480567372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.04610843439966642], {
             RGBColor[
             0.7799288471077344, 0.8280056101301249, 0.9786996766963847]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.04610843439966642], {
             RGBColor[
             0.582186355778724, 0.6716841366744375, 0.9602509890272426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.04610843439966642], {
             RGBColor[
             0.3598377440978132, 0.4860951007918011, 0.9441495207552573]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.04610843439966642], {
             RGBColor[
             0.6076384701621921, 0.6923473097356232, 0.9622546727056762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.04610843439966642], {
             RGBColor[
             0.2858915312838074, 0.41782050432227136`, 0.9395924718167694]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.04610843439966642], {
             RGBColor[
             0.6605800441996937, 0.7347694182138658, 0.9668041034004863]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.04610843439966642], {
             RGBColor[
             0.9878164613876005, 0.970564204808781, 0.40716968246938345`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.04610843439966642], {
             RGBColor[
             0.969388870179094, 0.9766908500174689, 0.9367008375121952]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.04610843439966642], {
             RGBColor[
             0.5586761123050643, 0.6525974618981217, 0.9584001765401367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.04610843439966642], {
             RGBColor[
             0.8732324659738964, 0.5172600599448016, 0.21593440106306858`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.04610843439966642], {
             RGBColor[
             0.9951432462127467, 0.9920202196792252, 0.7127505065465968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.04610843439966642], {
             RGBColor[
             0.2509398294932354, 0.38108404967449283`, 0.9376020241062055]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.04610843439966642], {
             RGBColor[
             0.9867743239380404, 0.9887988573110779, 0.8688472095065404]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.04610843439966642], {
             RGBColor[
             0.7186884275148469, 0.7801641288997336, 0.9725958039956247]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
          103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
          129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 
          142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 
          155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 
          168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 
          181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 
          194, 195, 196, 197, 198, 199, 200}, {Null, CompressedData["
1:eJwVxfk/Gg4DAOBN5QibNGP1lWNDwghlmCNXuqiMigzJGcNQUi05SwdqhpKc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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[21, 55] -> 
             RGBColor[
              0.34859095953566543`, 0.47635370128389704`, 0.9434328855880982],
              UndirectedEdge[64, 132] -> 
             RGBColor[
              0.4650482384089718, 0.5716822037632778, 0.9522031318796592], 
             UndirectedEdge[42, 188] -> 
             RGBColor[
              0.2579862693567474, 0.38807828505832953`, 0.9380183944910747], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.5482557857976138, 0.6358309000327967, 0.9605283874597037], 
             UndirectedEdge[33, 68] -> 
             RGBColor[
              0.9768074272678445, 0.9356471682387506, 0.5374347809068445], 
             UndirectedEdge[168, 188] -> 
             RGBColor[
              0.2612998708737691, 0.39156109034719, 0.938207099195435], 
             UndirectedEdge[41, 161] -> 
             RGBColor[
              0.2872671394725109, 0.41926635574719545`, 0.9396708106680862], 
             UndirectedEdge[44, 68] -> 
             RGBColor[
              0.9298826077939246, 0.7566572199616033, 0.27010292258186963`], 
             UndirectedEdge[26, 136] -> 
             RGBColor[
              0.2577972163446346, 0.3882915980387517, 0.9379925421427979], 
             UndirectedEdge[9, 32] -> 
             RGBColor[
              0.18966018913671598`, 0.3166752623061849, 0.9341122392430056], 
             UndirectedEdge[71, 141] -> 
             RGBColor[
              0.3537772547746116, 0.4808458095490941, 0.9437633517346631], 
             UndirectedEdge[52, 100] -> 
             RGBColor[
              0.1956898688928864, 0.3230128380336974, 0.9344556205850076], 
             UndirectedEdge[172, 180] -> 
             RGBColor[
              0.6056868100783286, 0.4851310394922843, 0.577851031637082], 
             UndirectedEdge[168, 197] -> 
             RGBColor[
              0.20505165545148296`, 0.3328526692783333, 0.9349887604799977], 
             UndirectedEdge[125, 137] -> 
             RGBColor[
              0.29408774568202667`, 0.42503485891778914`, 0.9401105091078588],
              UndirectedEdge[17, 147] -> 
             RGBColor[
              0.22049695582396892`, 0.34908665925842064`, 0.9358683474869365],
              UndirectedEdge[10, 71] -> 
             RGBColor[
              0.2908445212370684, 0.4179419677193835, 0.9400607036352882], 
             UndirectedEdge[27, 129] -> 
             RGBColor[
              0.36049570993893, 0.4827296556793453, 0.9443430413040212], 
             UndirectedEdge[67, 166] -> 
             RGBColor[
              0.5298097305765306, 0.6164429264479874, 0.9594779119033563], 
             UndirectedEdge[3, 49] -> 
             RGBColor[
              0.42052372581365627`, 0.5386582479879358, 0.9480163778476842], 
             UndirectedEdge[151, 183] -> 
             RGBColor[
              0.9651436444656913, 0.888619018725243, 0.5091874749108671], 
             UndirectedEdge[125, 136] -> 
             RGBColor[
              0.24354766177349693`, 0.373314412710544, 0.9371810510902985], 
             UndirectedEdge[139, 194] -> 
             RGBColor[
              0.2435950267958037, 0.37336419635210427`, 0.9371837484582486], 
             UndirectedEdge[24, 108] -> 
             RGBColor[
              0.28258697373339425`, 0.41434720481573717`, 0.9394042821529283],
              UndirectedEdge[21, 192] -> 
             RGBColor[
              0.4135089355037963, 0.532245803699352, 0.9476624011874208], 
             UndirectedEdge[16, 52] -> 
             RGBColor[
              0.18638226183152043`, 0.31322995287582944`, 0.9339255661322337],
              UndirectedEdge[44, 166] -> 
             RGBColor[
              0.8512516278317916, 0.7399182542257667, 0.6091593456597434], 
             UndirectedEdge[78, 187] -> 
             RGBColor[
              0.19320618779608617`, 0.3204023317264835, 0.9343141786208218], 
             UndirectedEdge[99, 162] -> 
             RGBColor[
              0.5016163434350541, 0.6062220183620153, 0.9539225219304044], 
             UndirectedEdge[93, 150] -> 
             RGBColor[
              0.21197440955790398`, 0.3401289227721434, 0.9353830010850614], 
             UndirectedEdge[118, 155] -> 
             RGBColor[
              0.5320287520312512, 0.6287959624909311, 0.9570938290152922], 
             UndirectedEdge[16, 125] -> 
             RGBColor[
              0.22572938407249296`, 0.3545862731027316, 0.936166326535006], 
             UndirectedEdge[61, 179] -> 
             RGBColor[
              0.2879403991921272, 0.41444560530367136`, 0.9399115732194068], 
             UndirectedEdge[51, 197] -> 
             RGBColor[
              0.1914512391651612, 0.3185577694452115, 0.9342142368925045], 
             UndirectedEdge[80, 120] -> 
             RGBColor[
              0.20786563933481106`, 0.33581034475659416`, 0.9351490126992371],
              UndirectedEdge[21, 183] -> 
             RGBColor[
              0.6488438964095984, 0.6364280199535685, 0.605957146255827], 
             UndirectedEdge[182, 199] -> 
             RGBColor[
              0.668046802775716, 0.7309711261041182, 0.8355721890992451], 
             UndirectedEdge[17, 189] -> 
             RGBColor[
              0.19295037100619816`, 0.32013345206058996`, 0.9342996102330847],
              UndirectedEdge[116, 136] -> 
             RGBColor[
              0.23171997218972168`, 0.36088276103916334`, 0.9365074816660013],
              UndirectedEdge[119, 123] -> 
             RGBColor[
              0.7149253774106119, 0.4290074920684967, 0.44497128325517005`], 
             UndirectedEdge[71, 89] -> 
             RGBColor[
              0.315626713124748, 0.4439896226750534, 0.9414720128013241], 
             UndirectedEdge[7, 61] -> 
             RGBColor[
              0.2079174287175954, 0.335864778681537, 0.9351519620279711], 
             UndirectedEdge[3, 27] -> 
             RGBColor[
              0.3426067292683088, 0.4672664245880422, 0.9431945216539286], 
             UndirectedEdge[41, 108] -> 
             RGBColor[
              0.29936649893310274`, 0.4319835496839754, 0.9403598512899686], 
             UndirectedEdge[66, 98] -> 
             RGBColor[
              0.18802367047876978`, 0.3149551774354076, 0.9340190419264479], 
             UndirectedEdge[119, 127] -> 
             RGBColor[
              0.8561463869507269, 0.5416184097408903, 0.4576222745671909], 
             UndirectedEdge[15, 167] -> 
             RGBColor[
              0.18913040232451964`, 0.31611842277614255`, 0.9340820686678004],
              UndirectedEdge[12, 96] -> 
             RGBColor[
              0.9432592874949708, 0.8959893159471047, 0.6356118637427102], 
             UndirectedEdge[7, 52] -> 
             RGBColor[
              0.19704159904264756`, 0.32443359212573797`, 0.934532599617331], 
             UndirectedEdge[163, 165] -> 
             RGBColor[
              0.24378292836413576`, 0.3735616928140688, 0.9371944491745896], 
             UndirectedEdge[71, 73] -> 
             RGBColor[
              0.29060892456725834`, 0.41769434068172157`, 0.9400472867534765],
              UndirectedEdge[60, 165] -> 
             RGBColor[
              0.1933919500064047, 0.32059757958753266`, 0.9343247575038889], 
             UndirectedEdge[120, 124] -> 
             RGBColor[
              0.20998768265750406`, 0.3380407468340621, 0.9352698599271827], 
             UndirectedEdge[43, 163] -> 
             RGBColor[
              0.2357550055079826, 0.36512383689254435`, 0.9367372708441793], 
             UndirectedEdge[146, 194] -> 
             RGBColor[
              0.22346288152433108`, 0.352204035220052, 0.9360372525678782], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.24761466346370808`, 0.37758908934975655`, 0.9374126608199662],
              UndirectedEdge[81, 157] -> 
             RGBColor[
              0.25622740358141927`, 0.3866416252927345, 0.9379031436282628], 
             UndirectedEdge[59, 114] -> 
             RGBColor[
              0.1828190891221793, 0.3094848324401137, 0.9337226487176782], 
             UndirectedEdge[31, 185] -> 
             RGBColor[
              0.38200599992585305`, 0.49606971836717273`, 0.9464117075671216],
              UndirectedEdge[58, 198] -> 
             RGBColor[
              0.6531000789032383, 0.7219510755774461, 0.9474306913916395], 
             UndirectedEdge[30, 142] -> 
             RGBColor[
              0.23578204115771023`, 0.3651522530745672, 0.9367388104844356], 
             UndirectedEdge[26, 96] -> 
             RGBColor[
              0.6145993386243387, 0.6885815666825401, 0.9662497087986179], 
             UndirectedEdge[25, 111] -> 
             RGBColor[
              0.19983749274486573`, 0.32737225367666856`, 0.9346918216275183],
              UndirectedEdge[89, 107] -> 
             RGBColor[
              0.24257389966697504`, 0.37229092699650596`, 0.9371255967788841],
              UndirectedEdge[51, 189] -> 
             RGBColor[
              0.18831403886767445`, 0.3152603730225656, 0.9340355779766345], 
             UndirectedEdge[81, 158] -> 
             RGBColor[
              0.3111871249613185, 0.44370525612704076`, 0.9410587411898188], 
             UndirectedEdge[93, 159] -> 
             RGBColor[
              0.24313944261504272`, 0.37288534849241906`, 0.9371578036131307],
              UndirectedEdge[191, 195] -> 
             RGBColor[
              0.6555677203865065, 0.728688801139147, 0.9677847110498968], 
             UndirectedEdge[17, 131] -> 
             RGBColor[
              0.18648216780881113`, 0.31333496039236675`, 0.9339312556298427],
              UndirectedEdge[18, 32] -> 
             RGBColor[
              0.20453729510132862`, 0.33231204393799124`, 0.9349594684189844],
              UndirectedEdge[59, 184] -> 
             RGBColor[
              0.1830159493280225, 0.30969174499811286`, 0.9337338596151724], 
             UndirectedEdge[156, 175] -> 
             RGBColor[
              0.7126688743756485, 0.2983936614071581, 0.42831356501794793`], 
             UndirectedEdge[2, 82] -> 
             RGBColor[
              0.19716931432443496`, 0.3245678289845131, 0.934539872813691], 
             UndirectedEdge[12, 44] -> 
             RGBColor[
              0.9244380104653778, 0.7365581580535521, 0.25797799946440303`], 
             UndirectedEdge[115, 175] -> 
             RGBColor[
              0.4077982725568444, 0.5263530627871394, 0.9475600302171414], 
             UndirectedEdge[30, 131] -> 
             RGBColor[
              0.19553065372363834`, 0.3228454927959929, 0.9344465535166567], 
             UndirectedEdge[53, 65] -> 
             RGBColor[
              0.7940608836370591, 0.7881654857639895, 0.6245197254205552], 
             UndirectedEdge[17, 51] -> 
             RGBColor[
              0.18683289480672916`, 0.31370359670455467`, 0.9339512290135199],
              UndirectedEdge[109, 128] -> 
             RGBColor[
              0.32435782382982603`, 0.44691944921604004`, 0.9421979744658333],
              UndirectedEdge[101, 135] -> 
             RGBColor[
              0.1965653140451214, 0.3239329863951249, 0.9345054758913225], 
             UndirectedEdge[54, 195] -> 
             RGBColor[
              0.7447123095700184, 0.789153733450638, 0.681635360097179], 
             UndirectedEdge[122, 192] -> 
             RGBColor[
              0.3718189687016956, 0.49328632243521403`, 0.9451102958483188], 
             UndirectedEdge[155, 195] -> 
             RGBColor[
              0.5871109616069528, 0.6752098608899229, 0.9609615810995339], 
             UndirectedEdge[42, 87] -> 
             RGBColor[
              0.20973659970745412`, 0.3377768427339811, 0.9352555611246214], 
             UndirectedEdge[31, 153] -> 
             RGBColor[
              0.4071092490619125, 0.522454824847095, 0.9478413004684911], 
             UndirectedEdge[64, 199] -> 
             RGBColor[
              0.8123958459095635, 0.8512144164818124, 0.8460919805023865], 
             UndirectedEdge[107, 188] -> 
             RGBColor[
              0.2654176677513521, 0.39588915594893126`, 0.9384416016358788], 
             UndirectedEdge[27, 189] -> 
             RGBColor[
              0.23047600087590087`, 0.35957526831600095`, 0.9364366393399698],
              UndirectedEdge[14, 176] -> 
             RGBColor[
              0.20667251283261232`, 0.3345562931541938, 0.9350810659100094], 
             UndirectedEdge[123, 146] -> 
             RGBColor[
              0.34826410267529395`, 0.47021417637892043`, 0.9436264907064373],
              UndirectedEdge[30, 130] -> 
             RGBColor[
              0.1969307686942434, 0.3243171024025152, 0.9345262879929481], 
             UndirectedEdge[72, 143] -> 
             RGBColor[
              0.5544319884729032, 0.6356036049331575, 0.9619129375714212], 
             UndirectedEdge[68, 155] -> 
             RGBColor[
              0.817090690205986, 0.812348570970784, 0.6355099976070364], 
             UndirectedEdge[32, 39] -> 
             RGBColor[
              0.2190345544466123, 0.34754958268921615`, 0.9357850658919249], 
             UndirectedEdge[184, 194] -> 
             RGBColor[
              0.19166541671322765`, 0.3187828836278702, 0.9342264339870195], 
             UndirectedEdge[74, 152] -> 
             RGBColor[
              0.2730580915689248, 0.4008937800418094, 0.9389875071669056], 
             UndirectedEdge[71, 147] -> 
             RGBColor[
              0.3066316503071229, 0.4345352413338067, 0.9409597572808632], 
             UndirectedEdge[39, 173] -> 
             RGBColor[
              0.3099077362629189, 0.437607436708477, 0.9411599161992759], 
             UndirectedEdge[139, 171] -> 
             RGBColor[
              0.2967091465842705, 0.42919050387948254`, 0.940208519004903], 
             UndirectedEdge[73, 189] -> 
             RGBColor[
              0.20595537414504966`, 0.3338025349243465, 0.9350402259226642], 
             UndirectedEdge[20, 22] -> 
             RGBColor[
              0.1854064647205249, 0.3122043282430629, 0.9338699959303249], 
             UndirectedEdge[17, 168] -> 
             RGBColor[
              0.2004333110930509, 0.32799849653767643`, 0.9347257526010131], 
             UndirectedEdge[13, 132] -> 
             RGBColor[
              0.26083574153477407`, 0.39148528066721244`, 0.9381655816572811],
              UndirectedEdge[99, 109] -> 
             RGBColor[
              0.38461485844464394`, 0.49643648481667146`, 0.9467764936235569],
              UndirectedEdge[119, 195] -> 
             RGBColor[
              0.7315611984185482, 0.4425529087361424, 0.44626994465755915`], 
             UndirectedEdge[10, 188] -> 
             RGBColor[
              0.26557638653463256`, 0.3960559794535111, 0.9384506404357832], 
             UndirectedEdge[182, 185] -> 
             RGBColor[
              0.28644155976238705`, 0.41543196640215296`, 0.9397324188136974],
              UndirectedEdge[98, 187] -> 
             RGBColor[
              0.1979911315151781, 0.3254316109582035, 0.9345866740869342], 
             UndirectedEdge[10, 167] -> 
             RGBColor[
              0.2086421156058076, 0.33662647054885053`, 0.9351932318741767], 
             UndirectedEdge[113, 187] -> 
             RGBColor[
              0.20396723113485943`, 0.331712870565089, 0.934927004119428], 
             UndirectedEdge[83, 170] -> 
             RGBColor[
              0.7907969761749707, 0.8373558827785927, 0.9795546906537492], 
             UndirectedEdge[39, 41] -> 
             RGBColor[
              0.2713842645263738, 0.40257244714637036`, 0.9387663044365115], 
             UndirectedEdge[138, 145] -> 
             RGBColor[
              0.20603341116594734`, 0.3338845567811428, 0.935044670015559], 
             UndirectedEdge[75, 155] -> 
             RGBColor[
              0.5876661844347633, 0.6756606157940428, 0.9610052902743873], 
             UndirectedEdge[90, 163] -> 
             RGBColor[
              0.2545166466581612, 0.38484351129813643`, 0.9378057185523212], 
             UndirectedEdge[2, 66] -> 
             RGBColor[
              0.1829598466238134, 0.3096327774988722, 0.9337306646491643], 
             UndirectedEdge[88, 200] -> 
             RGBColor[
              0.20358824889509092`, 0.3313145362022305, 0.9349054216415271], 
             UndirectedEdge[67, 170] -> 
             RGBColor[
              0.45554903905121463`, 0.5584299098262512, 0.952076300177731], 
             UndirectedEdge[124, 136] -> 
             RGBColor[
              0.22442474851543817`, 0.35321501841359515`, 0.9360920294700671],
              UndirectedEdge[129, 155] -> 
             RGBColor[
              0.5638305008231241, 0.6563097340528043, 0.959128857947493], 
             UndirectedEdge[149, 167] -> 
             RGBColor[
              0.19241882352516138`, 0.31957476195596346`, 0.9342693393903937],
              UndirectedEdge[172, 173] -> 
             RGBColor[
              0.6185469880325928, 0.49626987926492994`, 0.5786704708045187], 
             UndirectedEdge[143, 160] -> 
             RGBColor[
              0.6494266978782655, 0.7230187336619522, 0.967777881154406], 
             UndirectedEdge[27, 89] -> 
             RGBColor[
              0.2670176485112967, 0.3979828568550783, 0.9385176321142823], 
             UndirectedEdge[172, 191] -> 
             RGBColor[
              0.8397221650752837, 0.6755835027616839, 0.59719713282006], 
             UndirectedEdge[11, 182] -> 
             RGBColor[
              0.27189457932291083`, 0.4001421676284322, 0.9389039897979983], 
             UndirectedEdge[159, 164] -> 
             RGBColor[
              0.22503263737217588`, 0.35385394814440607`, 0.9361266478411673],
              UndirectedEdge[151, 156] -> 
             RGBColor[
              0.8771128434559579, 0.42716749015211075`, 0.3606061102513105], 
             UndirectedEdge[94, 196] -> 
             RGBColor[
              0.21169845343388266`, 0.3398388753891681, 0.9353672857920389], 
             UndirectedEdge[69, 139] -> 
             RGBColor[
              0.2677410752801248, 0.398743224257023, 0.938558830198553], 
             UndirectedEdge[53, 127] -> 
             RGBColor[
              0.7532853090466265, 0.8074724235406385, 0.9760373166313029], 
             UndirectedEdge[171, 196] -> 
             RGBColor[
              0.2703681630861383, 0.4015044601081305, 0.9387084389626774], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.7310843955752011, 0.737038335696917, 0.6195619855898489], 
             UndirectedEdge[74, 162] -> 
             RGBColor[
              0.39867126833608224`, 0.5197307476573095, 0.9466239585805827], 
             UndirectedEdge[34, 153] -> 
             RGBColor[
              0.3561569436366287, 0.48045786172119975`, 0.9440046574916221], 
             UndirectedEdge[98, 109] -> 
             RGBColor[
              0.2049550918267402, 0.33275117478624117`, 0.9349832613244216], 
             UndirectedEdge[77, 183] -> 
             RGBColor[
              0.8570073690583417, 0.35124840474274827`, 0.19870245441911466`],
              UndirectedEdge[2, 78] -> 
             RGBColor[
              0.1826523965739446, 0.3093096280030011, 0.9337131558236558], 
             UndirectedEdge[113, 193] -> 
             RGBColor[
              0.21695734101669506`, 0.34536629967143495`, 0.9356667716600531],
              UndirectedEdge[100, 120] -> 
             RGBColor[
              0.199864476631129, 0.3274006154520085, 0.934693358319922], 
             UndirectedEdge[1, 35] -> 
             RGBColor[
              0.1803467482579951, 0.30688624543639154`, 0.9335818525629636], 
             UndirectedEdge[154, 176] -> 
             RGBColor[
              0.28297932105843965`, 0.41262153691639003`, 0.9395049102298585],
              UndirectedEdge[13, 31] -> 
             RGBColor[
              0.37653388192589077`, 0.49031817539689215`, 0.9461000785422968],
              UndirectedEdge[92, 196] -> 
             RGBColor[
              0.23871657724306206`, 0.3682366365606061, 0.9369059279732393], 
             UndirectedEdge[66, 124] -> 
             RGBColor[
              0.2047917303558609, 0.33257947152263156`, 0.9349739581303267], 
             UndirectedEdge[141, 167] -> 
             RGBColor[
              0.27157484914335084`, 0.3995303123785612, 0.9388958799735516], 
             UndirectedEdge[76, 158] -> 
             RGBColor[
              0.2902964087900912, 0.4217477888831733, 0.9398690458089125], 
             UndirectedEdge[101, 134] -> 
             RGBColor[
              0.22153377048940157`, 0.350176417209637, 0.9359273925483029], 
             UndirectedEdge[139, 141] -> 
             RGBColor[
              0.31474199889707277`, 0.4449017237250964, 0.9413541852919508], 
             UndirectedEdge[88, 93] -> 
             RGBColor[
              0.22397479227765688`, 0.3527420858788138, 0.936066405127976], 
             UndirectedEdge[17, 130] -> 
             RGBColor[
              0.18788228277941618`, 0.31480656999888906`, 0.9340109901061341],
              UndirectedEdge[32, 117] -> 
             RGBColor[
              0.1856648230786062, 0.31247587925827236`, 0.9338847090566107], 
             UndirectedEdge[32, 103] -> 
             RGBColor[
              0.1835438669532831, 0.31024661989417246`, 0.9337639237429469], 
             UndirectedEdge[148, 150] -> 
             RGBColor[
              0.19306951159997304`, 0.3202586763785973, 0.9343063951136474], 
             UndirectedEdge[77, 156] -> 
             RGBColor[
              0.8177852247685861, 0.1377106078723485, 0.16466445736492355`], 
             UndirectedEdge[76, 89] -> 
             RGBColor[
              0.2658816302529869, 0.396788829637877, 0.93845293755506], 
             UndirectedEdge[42, 51] -> 
             RGBColor[
              0.1924833774375055, 0.31964261221079154`, 0.9342730156402028], 
             UndirectedEdge[82, 124] -> 
             RGBColor[
              0.21900119805648247`, 0.34751452300827246`, 0.9357831662948535],
              UndirectedEdge[15, 114] -> 
             RGBColor[
              0.1801710817898224, 0.3067016088404447, 0.9335718486174763], 
             UndirectedEdge[41, 173] -> 
             RGBColor[
              0.32922976019022715`, 0.45791610894315266`, 0.9422602768775632],
              UndirectedEdge[41, 133] -> 
             RGBColor[
              0.2699147403652278, 0.4010278840797926, 0.9386826172095004], 
             UndirectedEdge[27, 147] -> 
             RGBColor[
              0.25802258569367165`, 0.38852847551383163`, 0.9380053765938214],
              UndirectedEdge[19, 88] -> 
             RGBColor[
              0.28388973519432037`, 0.4117897874343075, 0.939622248296642], 
             UndirectedEdge[127, 172] -> 
             RGBColor[
              0.8720640822479042, 0.7012922099091854, 0.6003031260629946], 
             UndirectedEdge[69, 174] -> 
             RGBColor[
              0.21992361240255348`, 0.34848403897044045`, 0.9358356964272725],
              UndirectedEdge[117, 121] -> 
             RGBColor[
              0.2013378942582586, 0.3289492707981949, 0.9347772672740609], 
             UndirectedEdge[69, 196] -> 
             RGBColor[
              0.24140009178199262`, 0.37105718048567105`, 0.9370587501563274],
              UndirectedEdge[92, 195] -> 
             RGBColor[
              0.372739436043382, 0.49002947459904367`, 0.9455472387434574], 
             UndirectedEdge[144, 158] -> 
             RGBColor[
              0.2574165112915451, 0.3871889319062931, 0.9379965842878197], 
             UndirectedEdge[81, 168] -> 
             RGBColor[
              0.2577136388756711, 0.38820375281975344`, 0.9379877825295823], 
             UndirectedEdge[87, 188] -> 
             RGBColor[
              0.264952676857396, 0.39540042103725787`, 0.9384151210923604], 
             UndirectedEdge[74, 88] -> 
             RGBColor[
              0.2812466810785635, 0.40950050680300143`, 0.9394538352255469], 
             UndirectedEdge[74, 140] -> 
             RGBColor[
              0.6698268935487197, 0.7315161778042003, 0.7507274751968138], 
             UndirectedEdge[152, 178] -> 
             RGBColor[
              0.19191650879429833`, 0.319046797325233, 0.9342407333095791], 
             UndirectedEdge[63, 153] -> 
             RGBColor[
              0.23696466171985112`, 0.36639526226785174`, 0.9368061589759192],
              UndirectedEdge[154, 158] -> 
             RGBColor[
              0.3241076056222659, 0.45514745069325846`, 0.9418728279265163], 
             UndirectedEdge[23, 90] -> 
             RGBColor[
              0.22545415356299398`, 0.354296988386626, 0.936150652564657], 
             UndirectedEdge[51, 131] -> 
             RGBColor[
              0.18184583567028742`, 0.3084618813543424, 0.9336672233733925], 
             UndirectedEdge[21, 83] -> 
             RGBColor[
              0.6438448345050425, 0.715751939504987, 0.9685418227069613], 
             UndirectedEdge[57, 178] -> 
             RGBColor[
              0.1827435050835432, 0.30940538882320234`, 0.9337183443184945], 
             UndirectedEdge[17, 197] -> 
             RGBColor[
              0.19608757130368493`, 0.3234308484832359, 0.9344782691489546], 
             UndirectedEdge[64, 156] -> 
             RGBColor[
              0.755655443460662, 0.33329209471324106`, 0.43169762520131116`], 
             UndirectedEdge[40, 123] -> 
             RGBColor[
              0.4784773066745961, 0.5874288969649759, 0.9521030898325651], 
             UndirectedEdge[26, 99] -> 
             RGBColor[
              0.42230145847218425`, 0.5360474909140672, 0.9489226897427967], 
             UndirectedEdge[114, 167] -> 
             RGBColor[
              0.19037448411434205`, 0.3174260316165872, 0.9341529172852767], 
             UndirectedEdge[75, 168] -> 
             RGBColor[
              0.3557698478286644, 0.47206054196027025`, 0.9445929358550735], 
             UndirectedEdge[55, 111] -> 
             RGBColor[
              0.27800719710349053`, 0.40702500884009835`, 0.9392353213324036],
              UndirectedEdge[67, 122] -> 
             RGBColor[
              0.26690693057918574`, 0.3978664852885073, 0.9385113268918411], 
             UndirectedEdge[127, 129] -> 
             RGBColor[
              0.6646291767752983, 0.7354973814495299, 0.9690579811407907], 
             UndirectedEdge[96, 198] -> 
             RGBColor[
              0.6410199693439192, 0.7129417496474699, 0.9678791658783956], 
             UndirectedEdge[154, 181] -> 
             RGBColor[
              0.3850218870849109, 0.5079083396553941, 0.9457542320769319], 
             UndirectedEdge[9, 91] -> 
             RGBColor[
              0.1897739422401799, 0.3167948240302888, 0.9341187173139652], 
             UndirectedEdge[39, 152] -> 
             RGBColor[
              0.22612393827552923`, 0.3550009745863041, 0.9361887958131783], 
             UndirectedEdge[54, 65] -> 
             RGBColor[
              0.9723656669587191, 0.9184450471811106, 0.347146263750879], 
             UndirectedEdge[116, 128] -> 
             RGBColor[
              0.33596717970245343`, 0.45912161831384746`, 0.9428591101082765],
              UndirectedEdge[74, 95] -> 
             RGBColor[
              0.29756419393855826`, 0.4266512474089263, 0.9403830934433266], 
             UndirectedEdge[152, 200] -> 
             RGBColor[
              0.19539965938545223`, 0.3227078094410386, 0.9344390935828858], 
             UndirectedEdge[140, 191] -> 
             RGBColor[
              0.9019134129618684, 0.9202806576422312, 0.7699493982996792], 
             UndirectedEdge[109, 193] -> 
             RGBColor[
              0.223435169075761, 0.3521749076795341, 0.936035674384929], 
             UndirectedEdge[80, 137] -> 
             RGBColor[
              0.2728427891012749, 0.40270506254337235`, 0.9389006402596817], 
             UndirectedEdge[118, 199] -> 
             RGBColor[
              0.6930640728290565, 0.752639828019768, 0.8371662674251406], 
             UndirectedEdge[45, 64] -> 
             RGBColor[
              0.6702869821102313, 0.7421560430065834, 0.9679059544483493], 
             UndirectedEdge[125, 170] -> 
             RGBColor[
              0.4597455397011603, 0.5628406980828529, 0.952315284681579], 
             UndirectedEdge[70, 145] -> 
             RGBColor[
              0.19062187863577218`, 0.31768605894432894`, 0.9341670060372848],
              UndirectedEdge[17, 142] -> 
             RGBColor[
              0.22673355524288302`, 0.35564172067094113`, 0.9362235125976215],
              UndirectedEdge[95, 180] -> 
             RGBColor[
              0.2956153583547517, 0.42496326397755757`, 0.9402589153632142], 
             UndirectedEdge[41, 121] -> 
             RGBColor[
              0.25402964955357293`, 0.38433164646381435`, 0.9377779847876626],
              UndirectedEdge[5, 10] -> 
             RGBColor[
              0.28614225358776674`, 0.41386909982440245`, 0.9397610792987268],
              UndirectedEdge[167, 194] -> 
             RGBColor[
              0.2004278770420817, 0.327992785005569, 0.9347254431398494], 
             UndirectedEdge[78, 100] -> 
             RGBColor[
              0.1943610742796171, 0.3216161906447068, 0.9343799476975574], 
             UndirectedEdge[106, 157] -> 
             RGBColor[
              0.1957274974930852, 0.3230523880782974, 0.9344577634781225], 
             UndirectedEdge[24, 115] -> 
             RGBColor[
              0.28608625432626233`, 0.41744460911573256`, 0.9396248182053492],
              UndirectedEdge[74, 164] -> 
             RGBColor[
              0.2705518531420833, 0.3982595645505048, 0.9388447805961444], 
             UndirectedEdge[46, 135] -> 
             RGBColor[
              0.18995764910618526`, 0.3169879115941485, 0.9341291791482143], 
             UndirectedEdge[126, 190] -> 
             RGBColor[
              0.18192592123823295`, 0.3085460563639715, 0.933671784128011], 
             UndirectedEdge[21, 177] -> 
             RGBColor[
              0.28934680274084895`, 0.4165928965590511, 0.9399671678191333], 
             UndirectedEdge[24, 133] -> 
             RGBColor[
              0.2531352151655193, 0.3833915392115544, 0.93772704807246], 
             UndirectedEdge[30, 188] -> 
             RGBColor[
              0.2613842726407983, 0.39164980195571875`, 0.938211905751206], 
             UndirectedEdge[80, 98] -> 
             RGBColor[
              0.2071471807023911, 0.33505519918101245`, 0.9351080975429851], 
             UndirectedEdge[12, 102] -> 
             RGBColor[
              0.9596388825040008, 0.9082051910857141, 0.6078854818749925], 
             UndirectedEdge[51, 168] -> 
             RGBColor[
              0.1957969789545272, 0.32312541749965207`, 0.934461720344563], 
             UndirectedEdge[42, 189] -> 
             RGBColor[
              0.19860085363697447`, 0.32607246756682684`, 0.9346213968597675],
              UndirectedEdge[52, 187] -> 
             RGBColor[
              0.19453498240935546`, 0.32179897911547406`, 0.934389851508272], 
             UndirectedEdge[10, 89] -> 
             RGBColor[
              0.2427326184502555, 0.3724577505010858, 0.9371346355787884], 
             UndirectedEdge[148, 193] -> 
             RGBColor[
              0.21151914615710812`, 0.33965041207254015`, 0.9353570745078879],
              UndirectedEdge[4, 92] -> 
             RGBColor[
              0.28937728391046563`, 0.41912091134823404`, 0.9398775137264412],
              UndirectedEdge[28, 97] -> 
             RGBColor[
              0.19804503866908396`, 0.3254882707948695, 0.9345897440196007], 
             UndirectedEdge[60, 169] -> 
             RGBColor[
              0.18653686033276015`, 0.3133924457027435, 0.9339343702881713], 
             UndirectedEdge[44, 198] -> 
             RGBColor[
              0.6221986923143263, 0.5535105917539171, 0.5902453016000886], 
             UndirectedEdge[13, 64] -> 
             RGBColor[
              0.4253184848962721, 0.5299237138095665, 0.9499405811920143], 
             UndirectedEdge[42, 106] -> 
             RGBColor[
              0.19390013127031533`, 0.3211317103164559, 0.9343536976750818], 
             UndirectedEdge[43, 90] -> 
             RGBColor[
              0.20850897767362986`, 0.33648653414069934`, 0.935185649865899], 
             UndirectedEdge[166, 192] -> 
             RGBColor[
              0.6347217686990404, 0.711862763594694, 0.9660768808598341], 
             UndirectedEdge[5, 89] -> 
             RGBColor[
              0.31092444547544634`, 0.4399167547800723, 0.9411723884647626], 
             UndirectedEdge[114, 184] -> 
             RGBColor[
              0.18161202378548802`, 0.3082161302388885, 0.9336539081324469], 
             UndirectedEdge[58, 192] -> 
             RGBColor[
              0.7131454310850844, 0.7736227561744136, 0.951349727711992], 
             UndirectedEdge[17, 157] -> 
             RGBColor[
              0.19894707579879906`, 0.3264363690106574, 0.9346411136996936], 
             UndirectedEdge[38, 111] -> 
             RGBColor[
              0.200630301320241, 0.32820554575635497`, 0.9347369709030307], 
             UndirectedEdge[3, 191] -> 
             RGBColor[
              0.6143982789320568, 0.6943254432107253, 0.9648034682477634], 
             UndirectedEdge[40, 195] -> 
             RGBColor[
              0.5034310381865006, 0.6077470219664445, 0.9540510819361487], 
             UndirectedEdge[113, 136] -> 
             RGBColor[
              0.21363278825802834`, 0.3418719839332567, 0.9354774432986821], 
             UndirectedEdge[53, 141] -> 
             RGBColor[
              0.4877995456867602, 0.5920834332461721, 0.9536420283584146], 
             UndirectedEdge[142, 176] -> 
             RGBColor[
              0.24804284091250217`, 0.37803913099645736`, 0.9374370448922433],
              UndirectedEdge[99, 128] -> 
             RGBColor[
              0.49156366276898256`, 0.5975148916314856, 0.9532819740075988], 
             UndirectedEdge[41, 151] -> 
             RGBColor[
              0.6423047351050197, 0.7073139713016436, 0.8452851258395946], 
             UndirectedEdge[5, 157] -> 
             RGBColor[
              0.28037950263265143`, 0.40781208319106244`, 0.939432899157059], 
             UndirectedEdge[39, 74] -> 
             RGBColor[
              0.29899639389246113`, 0.42815658036720006`, 0.9404646551119514],
              UndirectedEdge[86, 171] -> 
             RGBColor[
              0.25492345163412733`, 0.3852710891208021, 0.9378288854938884], 
             UndirectedEdge[162, 180] -> 
             RGBColor[
              0.3967224327522758, 0.5180427642259409, 0.9464997805004701], 
             UndirectedEdge[27, 127] -> 
             RGBColor[
              0.5706539535210267, 0.6502280340235855, 0.9632042593205097], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.2536345517124762, 0.3839163735821717, 0.937755484550107], 
             UndirectedEdge[155, 191] -> 
             RGBColor[
              0.7416468272326004, 0.7980994052495431, 0.9748840827210469], 
             UndirectedEdge[46, 105] -> 
             RGBColor[
              0.19436779950481975`, 0.32162325928279867`, 0.9343803306891837],
              UndirectedEdge[30, 168] -> 
             RGBColor[
              0.2094817970078781, 0.3375090289413025, 0.9352410504878272], 
             UndirectedEdge[161, 180] -> 
             RGBColor[
              0.31293043325479175`, 0.4431625055366565, 0.9412449832634135], 
             UndirectedEdge[125, 192] -> 
             RGBColor[
              0.364998647890857, 0.48611773282970705`, 0.9447218886679021], 
             UndirectedEdge[33, 140] -> 
             RGBColor[
              0.9931733912441731, 0.9901003146609737, 0.6650510516491244], 
             UndirectedEdge[12, 58] -> 
             RGBColor[
              0.9553393970542898, 0.9049986418770809, 0.615163389255954], 
             UndirectedEdge[127, 155] -> 
             RGBColor[
              0.7739887444052208, 0.8238081123970447, 0.9779900759639816], 
             UndirectedEdge[78, 120] -> 
             RGBColor[
              0.188434679061321, 0.31538717351511814`, 0.9340424482571915], 
             UndirectedEdge[45, 183] -> 
             RGBColor[
              0.823713544812509, 0.7798413316678898, 0.6197525703698252], 
             UndirectedEdge[98, 136] -> 
             RGBColor[
              0.20765668863834705`, 0.33559072432637116`, 0.9351371132661883],
              UndirectedEdge[59, 92] -> 
             RGBColor[
              0.21433501599530952`, 0.3426100698089493, 0.9355174341294674], 
             UndirectedEdge[81, 89] -> 
             RGBColor[
              0.2867723464242142, 0.41874629688174436`, 0.9396426329359664], 
             UndirectedEdge[161, 200] -> 
             RGBColor[
              0.23722083665512567`, 0.36666451836725433`, 0.9368207477595063],
              UndirectedEdge[125, 198] -> 
             RGBColor[
              0.30495329570901086`, 0.43444605223273947`, 0.9408028523475496],
              UndirectedEdge[159, 173] -> 
             RGBColor[
              0.3113226737864071, 0.4390946257578836, 0.941240494798026], 
             UndirectedEdge[54, 151] -> 
             RGBColor[
              0.9911479730677677, 0.9821275166719952, 0.580056048665182], 
             UndirectedEdge[61, 192] -> 
             RGBColor[
              0.33652735532483224`, 0.4561925991586039, 0.9431004906757697], 
             UndirectedEdge[59, 194] -> 
             RGBColor[
              0.19287248204991897`, 0.32005158582909543`, 0.934295174572251], 
             UndirectedEdge[80, 82] -> 
             RGBColor[
              0.2168791547337895, 0.3452841209308045, 0.9356623190669078], 
             UndirectedEdge[157, 168] -> 
             RGBColor[
              0.2079111599465971, 0.33585818980575477`, 0.9351516050307367], 
             UndirectedEdge[122, 170] -> 
             RGBColor[
              0.4665658605119989, 0.5700092876883599, 0.9527036918619959], 
             UndirectedEdge[26, 67] -> 
             RGBColor[
              0.2743361643394848, 0.4056750810112081, 0.9389344107639237], 
             UndirectedEdge[160, 181] -> 
             RGBColor[
              0.4406818300512263, 0.5561181847027405, 0.9493008344245906], 
             UndirectedEdge[42, 168] -> 
             RGBColor[
              0.20608379372382724`, 0.3339375120439133, 0.935047539227696], 
             UndirectedEdge[61, 67] -> 
             RGBColor[
              0.2316153172023224, 0.36077276201189723`, 0.936501521719292], 
             UndirectedEdge[9, 39] -> 
             RGBColor[
              0.22268787528916928`, 0.3513894545286635, 0.9359931171093048], 
             UndirectedEdge[118, 171] -> 
             RGBColor[
              0.3493088123107567, 0.4768833997475762, 0.9434819976486537], 
             UndirectedEdge[97, 134] -> 
             RGBColor[
              0.23183626588337625`, 0.3610049930846403, 0.9365141044198138], 
             UndirectedEdge[79, 190] -> 
             RGBColor[
              0.18918203979750087`, 0.31617269703425077`, 0.9340850093454959],
              UndirectedEdge[47, 50] -> 
             RGBColor[
              0.2000038325739316, 0.3275470873835711, 0.9347012944347058], 
             UndirectedEdge[36, 145] -> 
             RGBColor[
              0.1863723647153286, 0.3132195503791984, 0.9339250025061079], 
             UndirectedEdge[170, 179] -> 
             RGBColor[
              0.5118741210410194, 0.6121027531180253, 0.9554863516778458], 
             UndirectedEdge[26, 198] -> 
             RGBColor[
              0.3192028502801486, 0.44942323756094715`, 0.9416143434000489], 
             UndirectedEdge[5, 141] -> 
             RGBColor[
              0.34907498712530993`, 0.4767729416541131, 0.9434637273981017], 
             UndirectedEdge[18, 39] -> 
             RGBColor[
              0.2375649812537819, 0.3670262361604698, 0.9368403462852835], 
             UndirectedEdge[19, 180] -> 
             RGBColor[
              0.3466247657178071, 0.47465068302264285`, 0.9433076014566613], 
             UndirectedEdge[170, 198] -> 
             RGBColor[
              0.5004157249918784, 0.6021780663759904, 0.9547562328138562], 
             UndirectedEdge[12, 172] -> 
             RGBColor[
              0.9097214307201227, 0.6697336065748736, 0.2456981245885829], 
             UndirectedEdge[47, 101] -> 
             RGBColor[
              0.19622767860092072`, 0.3235781101359464, 0.934486248052262], 
             UndirectedEdge[53, 54] -> 
             RGBColor[
              0.810087981057518, 0.842228648704628, 0.6867819724356502], 
             UndirectedEdge[57, 121] -> 
             RGBColor[
              0.1995963195919732, 0.32711876540171747`, 0.9346780871732447], 
             UndirectedEdge[19, 121] -> 
             RGBColor[
              0.28428483303541713`, 0.41220506031595017`, 0.9396447485341975],
              UndirectedEdge[170, 192] -> 
             RGBColor[
              0.5604610771737245, 0.6538497469729578, 0.9586752691342088], 
             UndirectedEdge[7, 137] -> 
             RGBColor[
              0.266193356547354, 0.39571608733082725`, 0.9385219649126898], 
             UndirectedEdge[111, 115] -> 
             RGBColor[
              0.26758071568904057`, 0.3979941146890951, 0.9385709551564505], 
             UndirectedEdge[140, 162] -> 
             RGBColor[
              0.7225676146989453, 0.7771975396388044, 0.7540880673117176], 
             UndirectedEdge[8, 79] -> 
             RGBColor[
              0.2387210212797669, 0.3682413075249512, 0.9369061810545554], 
             UndirectedEdge[2, 52] -> 
             RGBColor[
              0.1839811911872139, 0.31070627539199164`, 0.933788828711106], 
             UndirectedEdge[18, 152] -> 
             RGBColor[
              0.21162667893024556`, 0.3397634358350792, 0.9353631983402376], 
             UndirectedEdge[4, 195] -> 
             RGBColor[
              0.41766970262794245`, 0.5348906935287172, 0.9481924844113676], 
             UndirectedEdge[81, 107] -> 
             RGBColor[
              0.26183143575325407`, 0.39253181842149465`, 0.938222284970026], 
             UndirectedEdge[108, 175] -> 
             RGBColor[
              0.4042989919639763, 0.5232556584871441, 0.9473394941647204], 
             UndirectedEdge[49, 191] -> 
             RGBColor[
              0.6162290328937537, 0.6959111502759776, 0.9649201222713306], 
             UndirectedEdge[77, 192] -> 
             RGBColor[
              0.7001173951211405, 0.28179359390660397`, 0.42650595770684385`],
              UndirectedEdge[21, 166] -> 
             RGBColor[
              0.5825165188394155, 0.666981785574234, 0.9626574089267232], 
             UndirectedEdge[8, 192] -> 
             RGBColor[
              0.37448920004002384`, 0.4960929048742423, 0.9452623615727833], 
             UndirectedEdge[108, 165] -> 
             RGBColor[
              0.25691494582414054`, 0.38736427578253046`, 0.937942298141858], 
             UndirectedEdge[29, 194] -> 
             RGBColor[
              0.2042163465061234, 0.3319747066151143, 0.9349411908712882], 
             UndirectedEdge[106, 131] -> 
             RGBColor[
              0.18326258950309726`, 0.3099509794600067, 0.9337479054082716], 
             UndirectedEdge[12, 68] -> 
             RGBColor[
              0.9555467146303788, 0.8599776150331977, 0.2908341193259223], 
             UndirectedEdge[71, 168] -> 
             RGBColor[
              0.2865680055762049, 0.4134470786130624, 0.93981716239494], 
             UndirectedEdge[49, 146] -> 
             RGBColor[
              0.3338791466944457, 0.45775465051721964`, 0.9427098940314549], 
             UndirectedEdge[112, 134] -> 
             RGBColor[
              0.5941420485372255, 0.6663173396662936, 0.9607153178159171], 
             UndirectedEdge[84, 126] -> 
             RGBColor[
              0.1804502852518648, 0.30699506938157317`, 0.9335877488415951], 
             UndirectedEdge[10, 62] -> 
             RGBColor[
              0.2089259147709481, 0.3369247614653196, 0.9352093938167881], 
             UndirectedEdge[34, 182] -> 
             RGBColor[
              0.3854450302409573, 0.5082748449893679, 0.9457811943846643], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.20133152966492007`, 0.3289425812070576, 0.9347769048198857], 
             UndirectedEdge[67, 79] -> 
             RGBColor[
              0.22503396848065443`, 0.3538553472238142, 0.9361267236458259], 
             UndirectedEdge[33, 96] -> 
             RGBColor[
              0.9645200001324366, 0.9716588691526575, 0.8822125253236324], 
             UndirectedEdge[12, 140] -> 
             RGBColor[
              0.9719126786067074, 0.9144307614554209, 0.4184503900682022], 
             UndirectedEdge[26, 124] -> 
             RGBColor[
              0.25940975173137165`, 0.3899864749708609, 0.9380843736475403], 
             UndirectedEdge[13, 70] -> 
             RGBColor[
              0.20607827017508945`, 0.33393170644397663`, 0.9350472246697668],
              UndirectedEdge[53, 146] -> 
             RGBColor[
              0.438593505674698, 0.543607216634379, 0.9507210951484925], 
             UndirectedEdge[87, 147] -> 
             RGBColor[
              0.23311384595539386`, 0.3623478107435859, 0.9365868607149048], 
             UndirectedEdge[93, 200] -> 
             RGBColor[
              0.21100022620147757`, 0.339104994297747, 0.935327522784088], 
             UndirectedEdge[9, 117] -> 
             RGBColor[
              0.1893181439211632, 0.3163157510977197, 0.9340927602739904], 
             UndirectedEdge[99, 116] -> 
             RGBColor[
              0.39622421431727134`, 0.5086386539144789, 0.9474376292660001], 
             UndirectedEdge[71, 155] -> 
             RGBColor[
              0.5184643421823038, 0.6170471524468351, 0.9562295168142538], 
             UndirectedEdge[54, 140] -> 
             RGBColor[
              0.9910580021453803, 0.9807455899537222, 0.48380004734696136`], 
             UndirectedEdge[76, 154] -> 
             RGBColor[
              0.29805964700021337`, 0.42847191562908343`, 0.9403637124828994],
              UndirectedEdge[33, 128] -> 
             RGBColor[
              0.7119650853654641, 0.7696077577835532, 0.8603069871100877], 
             UndirectedEdge[109, 148] -> 
             RGBColor[
              0.20549299658683456`, 0.33331654679423195`, 0.9350138942047502],
              UndirectedEdge[27, 142] -> 
             RGBColor[
              0.2642591851125857, 0.3950835369263521, 0.9383605417045067], 
             UndirectedEdge[49, 69] -> 
             RGBColor[
              0.33608426308955985`, 0.46007236766093923`, 0.9428354721479792],
              UndirectedEdge[60, 90] -> 
             RGBColor[
              0.2041256683004301, 0.33187939807160033`, 0.9349360268816205], 
             UndirectedEdge[40, 191] -> 
             RGBColor[
              0.6579669038121483, 0.7306365663260646, 0.9679735835576617], 
             UndirectedEdge[58, 166] -> 
             RGBColor[
              0.8821530144207035, 0.9083587380492957, 0.9663447354512944], 
             UndirectedEdge[38, 60] -> 
             RGBColor[
              0.18105257981885614`, 0.3076281191591622, 0.9336220486261704], 
             UndirectedEdge[54, 119] -> 
             RGBColor[
              0.894014834957988, 0.5647892265168832, 0.26478537843675587`], 
             UndirectedEdge[3, 146] -> 
             RGBColor[
              0.33204839273274867`, 0.4561689434519673, 0.9425932400078877], 
             UndirectedEdge[115, 163] -> 
             RGBColor[
              0.2983939725453868, 0.4303808013184385, 0.9403257245502908], 
             UndirectedEdge[137, 170] -> 
             RGBColor[
              0.48955017496489417`, 0.59276687306104, 0.9540638895741654], 
             UndirectedEdge[58, 99] -> 
             RGBColor[
              0.7561986870952739, 0.8085753289305662, 0.9547390377343874], 
             UndirectedEdge[40, 64] -> 
             RGBColor[
              0.5676806016913061, 0.6599077120294969, 0.959109042929153], 
             UndirectedEdge[77, 96] -> 
             RGBColor[
              0.8570181525627032, 0.40678469292302094`, 0.44031684375898816`],
              UndirectedEdge[141, 195] -> 
             RGBColor[
              0.42242387419926064`, 0.539008517992182, 0.9484954160199432], 
             UndirectedEdge[138, 182] -> 
             RGBColor[
              0.28135325644561493`, 0.4100838369991616, 0.9394426474672775], 
             UndirectedEdge[33, 102] -> 
             RGBColor[
              0.9808995951414665, 0.9838747442912669, 0.8544861434559147], 
             UndirectedEdge[137, 198] -> 
             RGBColor[
              0.3347579309727448, 0.4643722272109265, 0.9425514572401359], 
             UndirectedEdge[69, 171] -> 
             RGBColor[
              0.27878211770791206`, 0.41034805989114986`, 0.939187601231057], 
             UndirectedEdge[20, 46] -> 
             RGBColor[
              0.182651270158183, 0.3093084440686167, 0.9337130916759446], 
             UndirectedEdge[76, 157] -> 
             RGBColor[
              0.23533668741019195`, 0.36468415804886706`, 0.9367134482473564],
              UndirectedEdge[10, 168] -> 
             RGBColor[
              0.21367391090171242`, 0.3419152064390949, 0.9354797851724044], 
             UndirectedEdge[82, 100] -> 
             RGBColor[
              0.20887799203010743`, 0.3368743916262188, 0.9352066646875926], 
             UndirectedEdge[9, 57] -> 
             RGBColor[
              0.18757656925487778`, 0.3144852457012422, 0.9339935801731742], 
             UndirectedEdge[27, 71] -> 
             RGBColor[
              0.3151295512981096, 0.44346707407337604`, 0.941443700170782], 
             UndirectedEdge[122, 125] -> 
             RGBColor[
              0.2711034312291314, 0.40227727354510906`, 0.9387503113956892], 
             UndirectedEdge[5, 147] -> 
             RGBColor[
              0.30192938265782127`, 0.43046237343882565`, 0.9406601329443018],
              UndirectedEdge[5, 71] -> 
             RGBColor[
              0.35903634826225916`, 0.48540097199837007`, 0.9440984565212622],
              UndirectedEdge[61, 84] -> 
             RGBColor[
              0.19428775253280067`, 0.3215391248399355, 0.9343757721325461], 
             UndirectedEdge[62, 149] -> 
             RGBColor[
              0.19270262269030192`, 0.3198730528724325, 0.9342855013330051], 
             UndirectedEdge[36, 138] -> 
             RGBColor[
              0.20221257093783607`, 0.32986861144613544`, 0.9348270788169946],
              UndirectedEdge[33, 162] -> 
             RGBColor[
              0.7220177660315357, 0.778314884514083, 0.8609475350328932], 
             UndirectedEdge[63, 145] -> 
             RGBColor[
              0.1909329030445121, 0.31801296531800116`, 0.9341847184172432], 
             UndirectedEdge[93, 173] -> 
             RGBColor[
              0.29957000075540785`, 0.42674182123979476`, 0.9405711974554323],
              UndirectedEdge[23, 55] -> 
             RGBColor[
              0.27975796086466953`, 0.40886517255793126`, 0.9393350247385799],
              UndirectedEdge[23, 165] -> 
             RGBColor[
              0.21472043526896856`, 0.3430151699025583, 0.9355393831869255], 
             UndirectedEdge[54, 64] -> 
             RGBColor[
              0.8089618730748239, 0.8413144235136905, 0.6866933210901831], 
             UndirectedEdge[72, 158] -> 
             RGBColor[
              0.284772839183219, 0.41594216701181014`, 0.93955448669119], 
             UndirectedEdge[73, 149] -> 
             RGBColor[
              0.2014915378121197, 0.32911075991486693`, 0.934786017047158], 
             UndirectedEdge[10, 197] -> 
             RGBColor[
              0.20932817111234645`, 0.33734755838465436`, 0.9352323017203459],
              UndirectedEdge[37, 135] -> 
             RGBColor[
              0.21639131765151565`, 0.3447713732266772, 0.9356345374667627], 
             UndirectedEdge[58, 96] -> 
             RGBColor[
              0.9484965672474285, 0.961109404699039, 0.9720660567902085], 
             UndirectedEdge[112, 156] -> 
             RGBColor[
              0.8596154243912574, 0.41519353040673457`, 0.43839164860472024`],
              UndirectedEdge[2, 187] -> 
             RGBColor[
              0.1929273076602217, 0.3201092110216681, 0.9342982968096505], 
             UndirectedEdge[43, 169] -> 
             RGBColor[
              0.19092016970595993`, 0.3179995817718425, 0.9341839932724498], 
             UndirectedEdge[44, 96] -> 
             RGBColor[
              0.9175951806585165, 0.7926689208755102, 0.6148806669986575], 
             UndirectedEdge[88, 161] -> 
             RGBColor[
              0.25019540273130497`, 0.38030160994832113`, 0.9375596301033943],
              UndirectedEdge[129, 146] -> 
             RGBColor[
              0.3499373734033699, 0.4716321745432704, 0.9437417596579802], 
             UndirectedEdge[23, 111] -> 
             RGBColor[
              0.2218869245410005, 0.3505476045091276, 0.935947504149097], 
             UndirectedEdge[174, 196] -> 
             RGBColor[
              0.21150965778077974`, 0.33964043918742115`, 0.9353565341588927],
              UndirectedEdge[66, 100] -> 
             RGBColor[
              0.1946685243294859, 0.3219393401405779, 0.9343974565230659], 
             UndirectedEdge[10, 73] -> 
             RGBColor[
              0.2177148298927659, 0.346162468507754, 0.9357099095309409], 
             UndirectedEdge[147, 188] -> 
             RGBColor[
              0.2813635156046871, 0.41264925306793426`, 0.9393496940813583], 
             UndirectedEdge[62, 189] -> 
             RGBColor[
              0.19716645902323188`, 0.3245648278819121, 0.9345397102085116], 
             UndirectedEdge[42, 89] -> 
             RGBColor[
              0.2351425012723703, 0.3644800561059042, 0.93670238963408], 
             UndirectedEdge[119, 140] -> 
             RGBColor[
              0.8957916601354561, 0.5702808130715319, 0.3143797361574141], 
             UndirectedEdge[140, 151] -> 
             RGBColor[
              0.9938132108339699, 0.9903648965039682, 0.6544475852461695], 
             UndirectedEdge[1, 86] -> 
             RGBColor[
              0.19100632204633058`, 0.3180901333439459, 0.934188899520783], 
             UndirectedEdge[76, 181] -> 
             RGBColor[
              0.3512106902527362, 0.4745086778453089, 0.9437504499593281], 
             UndirectedEdge[122, 166] -> 
             RGBColor[
              0.5408265520373148, 0.6280223043100961, 0.9601053035876213], 
             UndirectedEdge[10, 189] -> 
             RGBColor[
              0.20619097081485965`, 0.33405016196200843`, 0.935053642804476], 
             UndirectedEdge[102, 162] -> 
             RGBColor[
              0.7102938185962386, 0.7709719692690975, 0.9435231591185078], 
             UndirectedEdge[156, 183] -> 
             RGBColor[
              0.8579398185955138, 0.3584156204874453, 0.19959536914896175`], 
             UndirectedEdge[31, 199] -> 
             RGBColor[
              0.763611242939182, 0.811608878069138, 0.8422514778526693], 
             UndirectedEdge[73, 130] -> 
             RGBColor[
              0.20088728591826768`, 0.3284756528626456, 0.9347516057957137], 
             UndirectedEdge[4, 199] -> 
             RGBColor[
              0.6647841302718416, 0.7281451631679503, 0.8353642944923663], 
             UndirectedEdge[6, 83] -> 
             RGBColor[
              0.8630840140535884, 0.476455427614182, 0.44943597904686494`], 
             UndirectedEdge[73, 89] -> 
             RGBColor[
              0.2424970217804455, 0.37221012346342386`, 0.9371212186969768], 
             UndirectedEdge[60, 111] -> 
             RGBColor[
              0.20055843927843664`, 0.3281300141941019, 0.9347328784660603], 
             UndirectedEdge[166, 179] -> 
             RGBColor[
              0.5861348125663353, 0.6701157697397615, 0.962887963403471], 
             UndirectedEdge[30, 197] -> 
             RGBColor[
              0.20513605721851214`, 0.33294138088686204`, 0.9349935670357687],
              UndirectedEdge[26, 58] -> 
             RGBColor[
              0.6266794481836577, 0.6975908926125163, 0.9458012343118618], 
             UndirectedEdge[11, 35] -> 
             RGBColor[
              0.19186691491128627`, 0.3189946710097535, 0.9342379090113091], 
             UndirectedEdge[137, 187] -> 
             RGBColor[
              0.2636867399140619, 0.3930814743205634, 0.9383792168036308], 
             UndirectedEdge[13, 153] -> 
             RGBColor[
              0.2516813551580962, 0.3818634401637041, 0.9376442528958304], 
             UndirectedEdge[71, 75] -> 
             RGBColor[
              0.4329404581640204, 0.5480873032405589, 0.9491738543179573], 
             UndirectedEdge[16, 67] -> 
             RGBColor[
              0.22153288342254734`, 0.3501754848461299, 0.935927342031158], 
             UndirectedEdge[156, 170] -> 
             RGBColor[
              0.7642144391985147, 0.3401094531533983, 0.43246113644580897`], 
             UndirectedEdge[96, 128] -> 
             RGBColor[
              0.683861542921137, 0.7500489673999585, 0.97060899306342], 
             UndirectedEdge[62, 114] -> 
             RGBColor[
              0.19065828327948256`, 0.31772432253305627`, 0.9341690792278882],
              UndirectedEdge[101, 105] -> 
             RGBColor[
              0.20097546444375586`, 0.32856833408377506`, 0.9347566274322918],
              UndirectedEdge[30, 89] -> 
             RGBColor[
              0.2385405045564212, 0.3680515730032935, 0.9368959008942113], 
             UndirectedEdge[53, 191] -> 
             RGBColor[
              0.720943391874006, 0.781763716393137, 0.9729313233883682], 
             UndirectedEdge[72, 81] -> 
             RGBColor[
              0.2796155967323937, 0.4112240991915025, 0.9392350666284796], 
             UndirectedEdge[163, 175] -> 
             RGBColor[
              0.39116697450397153`, 0.5094530755186824, 0.9465916451974521], 
             UndirectedEdge[82, 125] -> 
             RGBColor[
              0.23812411131454123`, 0.3676139173052213, 0.9368721879150849], 
             UndirectedEdge[113, 148] -> 
             RGBColor[
              0.19901516852776863`, 0.3265079387861328, 0.9346449914798742], 
             UndirectedEdge[33, 44] -> 
             RGBColor[
              0.9456987231028435, 0.812227711259105, 0.5045786610453252], 
             UndirectedEdge[21, 179] -> 
             RGBColor[
              0.3649219793710912, 0.49049880984441946`, 0.9444734837310578], 
             UndirectedEdge[75, 188] -> 
             RGBColor[
              0.40767232346158455`, 0.5262013149746865, 0.9475637911184522], 
             UndirectedEdge[85, 88] -> 
             RGBColor[
              0.24351738394062986`, 0.3732825887884752, 0.9371793268125088], 
             UndirectedEdge[13, 185] -> 
             RGBColor[
              0.22657810602203676`, 0.3554783336837818, 0.936214659994461], 
             UndirectedEdge[93, 161] -> 
             RGBColor[
              0.2576073800376916, 0.38809206804383756`, 0.9379817312459552], 
             UndirectedEdge[146, 196] -> 
             RGBColor[
              0.23919497538687848`, 0.3687394633419514, 0.9369331720398031], 
             UndirectedEdge[19, 162] -> 
             RGBColor[
              0.4013143224518391, 0.5220200282886156, 0.9467923716516777], 
             UndirectedEdge[140, 172] -> 
             RGBColor[
              0.931531992024998, 0.7442858149051479, 0.38543931844832946`], 
             UndirectedEdge[71, 142] -> 
             RGBColor[
              0.312868249726037, 0.44109030274632716`, 0.9413149223915483], 
             UndirectedEdge[87, 142] -> 
             RGBColor[
              0.23935044537430794`, 0.3689028721561064, 0.9369420258255899], 
             UndirectedEdge[89, 147] -> 
             RGBColor[
              0.25851974752031004`, 0.38905102411550896`, 0.9380336892243635],
              UndirectedEdge[30, 42] -> 
             RGBColor[
              0.2061681954908564, 0.33402622365244206`, 0.935052345783467], 
             UndirectedEdge[8, 125] -> 
             RGBColor[
              0.2737736625674596, 0.4050838559841373, 0.9389023771201537], 
             UndirectedEdge[29, 168] -> 
             RGBColor[
              0.2081540694089858, 0.33611350305207477`, 0.9351654383652672], 
             UndirectedEdge[158, 160] -> 
             RGBColor[
              0.3797675485885813, 0.503357295740605, 0.945419430274175], 
             UndirectedEdge[138, 153] -> 
             RGBColor[
              0.25206516984128635`, 0.38226685373099345`, 0.9376661105742352],
              UndirectedEdge[26, 122] -> 
             RGBColor[
              0.285352985800269, 0.4172544588733168, 0.9395618024481885], 
             UndirectedEdge[53, 195] -> 
             RGBColor[
              0.5664075262483584, 0.658874172033517, 0.9590088217668552], 
             UndirectedEdge[19, 93] -> 
             RGBColor[
              0.291301712500707, 0.4195802455298239, 0.9400443494392029], 
             UndirectedEdge[11, 196] -> 
             RGBColor[
              0.21797120015163274`, 0.34643192990463634`, 0.9357245094379176],
              UndirectedEdge[87, 168] -> 
             RGBColor[
              0.21305020122447582`, 0.34125964802284164`, 0.9354442658289815],
              UndirectedEdge[78, 124] -> 
             RGBColor[
              0.20448428030599214`, 0.3322563220267605, 0.9349564493048182], 
             UndirectedEdge[39, 117] -> 
             RGBColor[
              0.21869250923105948`, 0.34719007148075093`, 0.9357655869229098],
              UndirectedEdge[42, 130] -> 
             RGBColor[
              0.1935327654101925, 0.32074558550512594`, 0.9343327767328169], 
             UndirectedEdge[11, 94] -> 
             RGBColor[
              0.19668351642529655`, 0.32405722459115277`, 0.9345122073420087],
              UndirectedEdge[27, 168] -> 
             RGBColor[
              0.23795894096275363`, 0.36744031279308736`, 0.9368627817078983],
              UndirectedEdge[30, 51] -> 
             RGBColor[
              0.19588138072155636`, 0.3232141291081808, 0.934466526900334], 
             UndirectedEdge[6, 58] -> 
             RGBColor[
              0.8744809118671997, 0.48511532004682656`, 0.4356949344281448], 
             UndirectedEdge[6, 156] -> 
             RGBColor[
              0.8271945777002032, 0.21003501770950336`, 0.17367486435858423`],
              UndirectedEdge[19, 173] -> 
             RGBColor[
              0.35948494367207134`, 0.4857895227952885, 0.9441270406240982], 
             UndirectedEdge[57, 200] -> 
             RGBColor[
              0.1862266556746971, 0.31306640093900795`, 0.9339167045918012], 
             UndirectedEdge[37, 50] -> 
             RGBColor[
              0.21979652604601302`, 0.3483504631519761, 0.935828459047275], 
             UndirectedEdge[49, 171] -> 
             RGBColor[
              0.36505233439370555`, 0.4905196472833987, 0.9444851609543292], 
             UndirectedEdge[5, 127] -> 
             RGBColor[
              0.6145607504851762, 0.6921619319485797, 0.9658590156709901], 
             UndirectedEdge[85, 152] -> 
             RGBColor[
              0.2353287944309912, 0.36467586202728325`, 0.9367129987538674], 
             UndirectedEdge[130, 131] -> 
             RGBColor[
              0.18289522364297445`, 0.3095648546486768, 0.9337269844660065], 
             UndirectedEdge[33, 58] -> 
             RGBColor[
              0.9766001096917556, 0.9806681950826337, 0.8617640508368762], 
             UndirectedEdge[82, 98] -> 
             RGBColor[
              0.20223313817939134`, 0.32989022892104847`, 0.9348282500909746],
              UndirectedEdge[74, 173] -> 
             RGBColor[
              0.35684188955631446`, 0.48350024216398235`, 0.9439586275530032],
              UndirectedEdge[118, 146] -> 
             RGBColor[
              0.3181356246114969, 0.44411840298139715`, 0.9417067307257794], 
             UndirectedEdge[23, 115] -> 
             RGBColor[
              0.26933147945021957`, 0.39983427840692803`, 0.9386706585626268],
              UndirectedEdge[49, 65] -> 
             RGBColor[
              0.6893465246568067, 0.7023129196468301, 0.6165085243035178], 
             UndirectedEdge[21, 23] -> 
             RGBColor[
              0.2924706869731754, 0.4198762969529263, 0.9401450684047916], 
             UndirectedEdge[40, 171] -> 
             RGBColor[
              0.40679020531210003`, 0.5252450633334856, 0.9475386222406603], 
             UndirectedEdge[104, 158] -> 
             RGBColor[
              0.3417223041341413, 0.47040441720375525`, 0.9429952209396267], 
             UndirectedEdge[53, 155] -> 
             RGBColor[
              0.6524866330944523, 0.728284776143913, 0.9661081934380052], 
             UndirectedEdge[164, 200] -> 
             RGBColor[
              0.19289342095861073`, 0.320073593949734, 0.9342963670121247], 
             UndirectedEdge[81, 142] -> 
             RGBColor[
              0.28401388302550323`, 0.4158469769530182, 0.9394855425261907], 
             UndirectedEdge[39, 85] -> 
             RGBColor[
              0.26126709675452753`, 0.3919386623526739, 0.9381901466989133], 
             UndirectedEdge[107, 142] -> 
             RGBColor[
              0.23981543626826407`, 0.36939160706777974`, 0.9369685063691083],
              UndirectedEdge[121, 161] -> 
             RGBColor[
              0.25059050057240173`, 0.38071688282996385`, 0.9375821303409498],
              UndirectedEdge[1, 196] -> 
             RGBColor[
              0.20645103349834157`, 0.33432350433127433`, 0.935068452989572], 
             UndirectedEdge[88, 121] -> 
             RGBColor[
              0.21695791281236698`, 0.34536690066494, 0.9356668042229707], 
             UndirectedEdge[85, 133] -> 
             RGBColor[
              0.25979757259338154`, 0.39039409928609614`, 0.9381064594719022],
              UndirectedEdge[118, 127] -> 
             RGBColor[
              0.6328274279834254, 0.7079836098876566, 0.9670229522085898], 
             UndirectedEdge[100, 187] -> 
             RGBColor[
              0.2046359853658942, 0.3324157736633738, 0.9349650886835521], 
             UndirectedEdge[26, 116] -> 
             RGBColor[
              0.2667049754056552, 0.39765421759642916`, 0.9384998258434745], 
             UndirectedEdge[131, 147] -> 
             RGBColor[
              0.21550989668752718`, 0.3438449439082084, 0.9355843418468089], 
             UndirectedEdge[134, 160] -> 
             RGBColor[
              0.3450319511386071, 0.4675505014401682, 0.9434155666515178], 
             UndirectedEdge[3, 5] -> 
             RGBColor[
              0.38651352623245844`, 0.5092003225130362, 0.945849278004409], 
             UndirectedEdge[16, 100] -> 
             RGBColor[
              0.19648326478805916`, 0.32384674742372915`, 0.9345008033075137],
              UndirectedEdge[75, 147] -> 
             RGBColor[
              0.3758334925595824, 0.4931487046810145, 0.9457355307409967], 
             UndirectedEdge[72, 76] -> 
             RGBColor[
              0.25872488056116644`, 0.3892666319476351, 0.9380453712475731], 
             UndirectedEdge[40, 69] -> 
             RGBColor[
              0.37782213400795434`, 0.4947977837110262, 0.9458889334343104], 
             UndirectedEdge[177, 179] -> 
             RGBColor[
              0.2929650964677688, 0.41972688072457853`, 0.940197722295881], 
             UndirectedEdge[98, 100] -> 
             RGBColor[
              0.19914601799870904`, 0.3266454698764268, 0.9346524431636698], 
             UndirectedEdge[136, 187] -> 
             RGBColor[
              0.2131466560055322, 0.3413610281133182, 0.9354497587860706], 
             UndirectedEdge[54, 199] -> 
             RGBColor[
              0.9918267372139176, 0.9824082030898711, 0.5688071701781774], 
             UndirectedEdge[166, 198] -> 
             RGBColor[
              0.5746764165171943, 0.6601910829977264, 0.9621578445394816], 
             UndirectedEdge[48, 104] -> 
             RGBColor[
              0.28879698411440874`, 0.4154790711874804, 0.939955479525905], 
             UndirectedEdge[187, 198] -> 
             RGBColor[
              0.2745522899410462, 0.4024926676355137, 0.9390715600433216], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.20340607327822147`, 0.3311230580782995, 0.9348950470096511], 
             UndirectedEdge[103, 117] -> 
             RGBColor[
              0.1832018217377303, 0.30988710868570724`, 0.9337444447739318], 
             UndirectedEdge[85, 140] -> 
             RGBColor[
              0.632097596410786, 0.6952982597896742, 0.7484529667837756], 
             UndirectedEdge[36, 70] -> 
             RGBColor[
              0.18680103840766088`, 0.3136701136093215, 0.9339494148387204], 
             UndirectedEdge[54, 171] -> 
             RGBColor[
              0.6480714766956179, 0.7066517748176793, 0.6751229004016905], 
             UndirectedEdge[120, 125] -> 
             RGBColor[
              0.22911059591556282`, 0.35814014113101095`, 0.9363588815474142],
              UndirectedEdge[81, 104] -> 
             RGBColor[
              0.336565061683316, 0.46568634938344766`, 0.9426758008769163], 
             UndirectedEdge[93, 162] -> 
             RGBColor[
              0.34139937953517563`, 0.46297232673312194`, 0.9432365284830118],
              UndirectedEdge[73, 168] -> 
             RGBColor[
              0.2134383142319024, 0.3416675794014329, 0.9354663682905927], 
             UndirectedEdge[119, 199] -> 
             RGBColor[
              0.8963041501811476, 0.5713892218289645, 0.37105115137822486`], 
             UndirectedEdge[17, 107] -> 
             RGBColor[
              0.20455110797063392`, 0.33232656213941764`, 0.9349602550414569],
              UndirectedEdge[14, 48] -> 
             RGBColor[
              0.19487547737670605`, 0.3221568609147874, 0.9344092421929455], 
             UndirectedEdge[64, 182] -> 
             RGBColor[
              0.48518193863662246`, 0.5898773465279377, 0.9534583400112507], 
             UndirectedEdge[71, 129] -> 
             RGBColor[
              0.40910477455238126`, 0.5287364214993203, 0.947297421991063], 
             UndirectedEdge[80, 100] -> 
             RGBColor[
              0.2137920345531072, 0.3420393618861828, 0.935486512139603], 
             UndirectedEdge[18, 178] -> 
             RGBColor[
              0.20335755177255102`, 0.3310720588993987, 0.9348922837816843], 
             UndirectedEdge[174, 186] -> 
             RGBColor[
              0.18655058120662976`, 0.3134068672111341, 0.9339351516716399], 
             UndirectedEdge[115, 165] -> 
             RGBColor[
              0.2604142264170086, 0.39046168008252585`, 0.9381628341942789], 
             UndirectedEdge[113, 198] -> 
             RGBColor[
              0.2750384221935423, 0.4030036234554522, 0.939099244555933], 
             UndirectedEdge[67, 100] -> 
             RGBColor[
              0.2308404904839133, 0.3599583700039979, 0.936457396483932], 
             UndirectedEdge[106, 147] -> 
             RGBColor[
              0.21727737751825504`, 0.3457026783260606, 0.9356849972653654], 
             UndirectedEdge[75, 129] -> 
             RGBColor[
              0.47830661680484077`, 0.5873498848465282, 0.9520731954511965], 
             UndirectedEdge[175, 183] -> 
             RGBColor[
              0.7184776908452273, 0.695458275607814, 0.6107486570608233], 
             UndirectedEdge[105, 144] -> 
             RGBColor[
              0.20212260779592514`, 0.3297740544799944, 0.9348219555491514], 
             UndirectedEdge[44, 128] -> 
             RGBColor[
              0.6650402658915442, 0.5906178095064059, 0.5929751287851128], 
             UndirectedEdge[70, 138] -> 
             RGBColor[
              0.2064620848582796, 0.334335120011266, 0.9350690823481714], 
             UndirectedEdge[110, 145] -> 
             RGBColor[
              0.18515978669395372`, 0.31194505399684636`, 0.9338559479816391],
              UndirectedEdge[49, 118] -> 
             RGBColor[
              0.4066109576924045, 0.5266077075173656, 0.9471298685655758], 
             UndirectedEdge[70, 185] -> 
             RGBColor[
              0.21155038817505178`, 0.3396832494142572, 0.9353588536945914], 
             UndirectedEdge[11, 138] -> 
             RGBColor[
              0.2124149402657507, 0.3405919484773504, 0.9354080886571665], 
             UndirectedEdge[120, 187] -> 
             RGBColor[
              0.1987095901475981, 0.32618675653378515`, 0.9346275892431862], 
             UndirectedEdge[71, 127] -> 
             RGBColor[
              0.6192630181344778, 0.6962347998435606, 0.9661586400075515], 
             UndirectedEdge[4, 182] -> 
             RGBColor[
              0.33757022299890055`, 0.4668080932140755, 0.9427306540012304], 
             UndirectedEdge[29, 71] -> 
             RGBColor[
              0.2853246797443417, 0.4121402643323634, 0.939746356828151], 
             UndirectedEdge[63, 185] -> 
             RGBColor[
              0.2118614125837917, 0.3400101557879294, 0.9353765660745497], 
             UndirectedEdge[83, 175] -> 
             RGBColor[
              0.7134786289406714, 0.7747821951592325, 0.9733333335119576], 
             UndirectedEdge[79, 126] -> 
             RGBColor[
              0.1869217092836395, 0.3137969463509505, 0.9339562868665908], 
             UndirectedEdge[107, 154] -> 
             RGBColor[
              0.27475191641420155`, 0.4039740129877124, 0.9390363717067235], 
             UndirectedEdge[34, 64] -> 
             RGBColor[
              0.5297940733748047, 0.6285181353670621, 0.956300985787806], 
             UndirectedEdge[159, 180] -> 
             RGBColor[
              0.29846249583214285`, 0.427955785985238, 0.9404210556305891], 
             UndirectedEdge[3, 123] -> 
             RGBColor[
              0.4349086817945046, 0.5511177738496366, 0.9489329745226667], 
             UndirectedEdge[50, 97] -> 
             RGBColor[
              0.21027301783359342`, 0.33834065219542714`, 0.9352861093433454],
              UndirectedEdge[87, 89] -> 
             RGBColor[
              0.24210890877301894`, 0.37180219208483256`, 0.9370991162353657],
              UndirectedEdge[123, 191] -> 
             RGBColor[
              0.6306139888746021, 0.7083706761376785, 0.9658367189463131], 
             UndirectedEdge[108, 151] -> 
             RGBColor[
              0.6509649455844404, 0.716416401604573, 0.8457783120147642], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.19532837830452823`, 0.32263288850550587`, 0.9344350342307781],
              UndirectedEdge[19, 33] -> 
             RGBColor[
              0.6719200989970671, 0.734922803310785, 0.8577553559890845], 
             UndirectedEdge[156, 199] -> 
             RGBColor[
              0.8775653528867244, 0.4273546144306946, 0.3531068579266407], 
             UndirectedEdge[47, 144] -> 
             RGBColor[
              0.19737482195309003`, 0.32478383053216575`, 0.9345515761691217],
              UndirectedEdge[123, 127] -> 
             RGBColor[
              0.6629559060472224, 0.73407938328518, 0.9689427121892478], 
             UndirectedEdge[82, 120] -> 
             RGBColor[
              0.2029515968118113, 0.3306453744966301, 0.9348691652472267], 
             UndirectedEdge[120, 137] -> 
             RGBColor[
              0.2589152311792967, 0.38806631610919806`, 0.9381074864400005], 
             UndirectedEdge[122, 179] -> 
             RGBColor[
              0.32323201256899053`, 0.45153932858028145`, 0.9419213783919558],
              UndirectedEdge[52, 124] -> 
             RGBColor[
              0.20581307491926143`, 0.333652969415751, 0.9350321221922685], 
             UndirectedEdge[17, 106] -> 
             RGBColor[
              0.18824964863953902`, 0.315192694810219, 0.934031911048399], 
             UndirectedEdge[125, 166] -> 
             RGBColor[
              0.5340062312264762, 0.620853714704589, 0.9597168964072044], 
             UndirectedEdge[7, 79] -> 
             RGBColor[
              0.20133607999592745`, 0.328947363893454, 0.934777163954505], 
             UndirectedEdge[49, 127] -> 
             RGBColor[
              0.6485709500663741, 0.7216198574234791, 0.9680261155142653], 
             UndirectedEdge[121, 200] -> 
             RGBColor[
              0.20398334673618768`, 0.33172980908387323`, 0.9349279218790827],
              UndirectedEdge[56, 193] -> 
             RGBColor[
              0.2060154437903921, 0.33386567193023686`, 0.9350436468001014], 
             UndirectedEdge[149, 194] -> 
             RGBColor[
              0.1935128959182038, 0.3207247014092473, 0.9343316451946424], 
             UndirectedEdge[108, 133] -> 
             RGBColor[
              0.27857495084464845`, 0.41013031438272207`, 0.9391758033846701],
              UndirectedEdge[41, 140] -> 
             RGBColor[
              0.6422147641826323, 0.7059320445833706, 0.7490291245213738], 
             UndirectedEdge[36, 185] -> 
             RGBColor[
              0.2073008742546082, 0.33521674084912667`, 0.9351168501634146], 
             UndirectedEdge[108, 111] -> 
             RGBColor[
              0.26408143509617243`, 0.39489671038909974`, 0.9383504191040295],
              UndirectedEdge[72, 154] -> 
             RGBColor[
              0.2925360773933412, 0.42266629375772025`, 0.940049153365177], 
             UndirectedEdge[63, 110] -> 
             RGBColor[
              0.18589948479502594`, 0.3127225236006417, 0.9338980726942099], 
             UndirectedEdge[15, 186] -> 
             RGBColor[
              0.18099749200595946`, 0.30757021837503873`, 0.933618911456721], 
             UndirectedEdge[54, 155] -> 
             RGBColor[
              0.8307914164161123, 0.8585643375610341, 0.688734731768329], 
             UndirectedEdge[18, 108] -> 
             RGBColor[
              0.2655472156605108, 0.39643733869807485`, 0.9384338931387406], 
             UndirectedEdge[44, 102] -> 
             RGBColor[
              0.9339747756675465, 0.8048847960141194, 0.5871542851309398], 
             UndirectedEdge[8, 122] -> 
             RGBColor[
              0.2805939833782982, 0.4122524455896443, 0.9392907843005704], 
             UndirectedEdge[42, 197] -> 
             RGBColor[
              0.20173805393446126`, 0.32936986398947277`, 0.9348000557756375],
              UndirectedEdge[48, 147] -> 
             RGBColor[
              0.2300092060376818, 0.3590846373445305, 0.9364100560644943], 
             UndirectedEdge[34, 54] -> 
             RGBColor[
              0.7092249646791587, 0.7597119219751208, 0.6790161754635967], 
             UndirectedEdge[5, 75] -> 
             RGBColor[
              0.42823819051471873`, 0.5440144353455778, 0.9488742299813958], 
             UndirectedEdge[55, 115] -> 
             RGBColor[
              0.3254517520127096, 0.4563116827378988, 0.9419584757459334], 
             UndirectedEdge[49, 155] -> 
             RGBColor[
              0.5477722741141999, 0.6424322100267535, 0.9580969923209677], 
             UndirectedEdge[66, 136] -> 
             RGBColor[
              0.2031791949691239, 0.33088459459052233`, 0.9348821266255843], 
             UndirectedEdge[136, 148] -> 
             RGBColor[
              0.2081945933984414, 0.33615609633436194`, 0.9351677461465169], 
             UndirectedEdge[130, 189] -> 
             RGBColor[
              0.18936342684036145`, 0.3163633463169, 0.9340953390692487], 
             UndirectedEdge[48, 76] -> 
             RGBColor[
              0.23737108877035865`, 0.36682244286689847`, 0.9368293043951907],
              UndirectedEdge[29, 141] -> 
             RGBColor[
              0.2753633186073925, 0.40351223398810643`, 0.9391116277049905], 
             UndirectedEdge[133, 163] -> 
             RGBColor[
              0.26544293338464375`, 0.39632773141426036`, 0.9384279544174017],
              UndirectedEdge[111, 169] -> 
             RGBColor[
              0.20611458183414505`, 0.33396987229993624`, 0.9350492925650316],
              UndirectedEdge[76, 142] -> 
             RGBColor[
              0.26312316685427595`, 0.39388950970915076`, 0.9382958471452842],
              UndirectedEdge[78, 98] -> 
             RGBColor[
              0.18771622042890102`, 0.3146320279395365, 0.9340015331009395], 
             UndirectedEdge[21, 170] -> 
             RGBColor[
              0.5082558273140996, 0.6089687689524979, 0.9552557972010979], 
             UndirectedEdge[92, 139] -> 
             RGBColor[
              0.26505756074119424`, 0.3959226803319581, 0.938406008015465], 
             UndirectedEdge[63, 70] -> 
             RGBColor[
              0.1913615767368444, 0.3184635285481242, 0.9342091307498555], 
             UndirectedEdge[71, 197] -> 
             RGBColor[
              0.2822222657868389, 0.40887943055862197`, 0.9395696789428815], 
             UndirectedEdge[127, 141] -> 
             RGBColor[
              0.6093016569975287, 0.6876067694993037, 0.9655239108843909], 
             UndirectedEdge[64, 138] -> 
             RGBColor[
              0.4257022995794623, 0.5303271273768558, 0.949962438870419], 
             UndirectedEdge[39, 108] -> 
             RGBColor[
              0.2800444750057945, 0.41167487744929976`, 0.9392594906116811], 
             UndirectedEdge[24, 165] -> 
             RGBColor[
              0.23147521014501135`, 0.3606255006113628, 0.9364935428296479], 
             UndirectedEdge[132, 182] -> 
             RGBColor[
              0.3206991952751244, 0.45143891338558356`, 0.9416833404765177], 
             UndirectedEdge[77, 181] -> 
             RGBColor[
              0.6909369767791447, 0.27406636729053985`, 0.42585898985112014`],
              UndirectedEdge[20, 47] -> 
             RGBColor[
              0.189292245231432, 0.3162885299327404, 0.9340912853819239], 
             UndirectedEdge[191, 199] -> 
             RGBColor[
              0.9026821480304056, 0.9219432707783801, 0.8549565211308954], 
             UndirectedEdge[89, 154] -> 
             RGBColor[
              0.29969282708516165`, 0.4301884914479621, 0.9404567196726639], 
             UndirectedEdge[93, 164] -> 
             RGBColor[
              0.2132799643411767, 0.3415011436263172, 0.9354573504985735], 
             UndirectedEdge[26, 187] -> 
             RGBColor[
              0.24813165922146568`, 0.378132484670584, 0.9374421029635438], 
             UndirectedEdge[5, 188] -> 
             RGBColor[
              0.33376821355982345`, 0.4635149837324976, 0.9424883933217574], 
             UndirectedEdge[7, 16] -> 
             RGBColor[
              0.19783499493782034`, 0.3252675015157697, 0.9345777823398371], 
             UndirectedEdge[154, 160] -> 
             RGBColor[
              0.38753078679870345`, 0.510081422486515, 0.9459140969481619], 
             UndirectedEdge[88, 152] -> 
             RGBColor[
              0.20837422546163153`, 0.3363449010221054, 0.9351779759267738], 
             UndirectedEdge[9, 18] -> 
             RGBColor[
              0.2081906159438856, 0.3361519157774386, 0.935167519636364], 
             UndirectedEdge[9, 200] -> 
             RGBColor[
              0.19196359639909227`, 0.31909628938339796`, 0.9342434148790122],
              UndirectedEdge[55, 183] -> 
             RGBColor[
              0.6361311703010923, 0.6254168955585735, 0.6051471025896153], 
             UndirectedEdge[72, 104] -> 
             RGBColor[
              0.31015077590521656`, 0.43792326026821704`, 0.9411715463782875],
              UndirectedEdge[112, 181] -> 
             RGBColor[
              0.6897919274498447, 0.754885022928866, 0.9666005855889899], 
             UndirectedEdge[136, 193] -> 
             RGBColor[
              0.22613676588736786`, 0.35501445721966407`, 0.9361895263266957],
              UndirectedEdge[80, 198] -> 
             RGBColor[
              0.28370833912825916`, 0.4121162558583227, 0.9395929834993725], 
             UndirectedEdge[42, 131] -> 
             RGBColor[
              0.19213265043958744`, 0.3192739758986036, 0.9342530422565254], 
             UndirectedEdge[65, 156] -> 
             RGBColor[
              0.8645913060499254, 0.38471251049152105`, 0.20533292030844175`],
              UndirectedEdge[26, 192] -> 
             RGBColor[
              0.37924820246199464`, 0.5010949181579147, 0.9455333797204014], 
             UndirectedEdge[65, 155] -> 
             RGBColor[
              0.8147643189956533, 0.8045011746203956, 0.6264724847532339], 
             UndirectedEdge[59, 62] -> 
             RGBColor[
              0.19206220882201708`, 0.3191999372922807, 0.9342490307106137], 
             UndirectedEdge[82, 187] -> 
             RGBColor[
              0.2077231055465765, 0.3356605327079955, 0.9351408956108569], 
             UndirectedEdge[4, 86] -> 
             RGBColor[
              0.26820213237561147`, 0.3968644845029512, 0.9386716201723606], 
             UndirectedEdge[73, 167] -> 
             RGBColor[
              0.20840651893599757`, 0.33637884351118863`, 0.9351798149923649],
              UndirectedEdge[74, 159] -> 
             RGBColor[
              0.30041133141594933`, 0.42964376941660665`, 0.9405452337107016],
              UndirectedEdge[25, 60] -> 
             RGBColor[
              0.18025977124348086`, 0.3067948270794758, 0.9335768993506579], 
             UndirectedEdge[159, 162] -> 
             RGBColor[
              0.3531520525661749, 0.4753251312512108, 0.9439058258256054], 
             UndirectedEdge[10, 147] -> 
             RGBColor[
              0.23373755563263043`, 0.3630033691598391, 0.9366223800583277], 
             UndirectedEdge[23, 163] -> 
             RGBColor[
              0.2527001813973467, 0.382934291138471, 0.9377022735429374], 
             UndirectedEdge[40, 54] -> 
             RGBColor[
              0.7471114929956602, 0.7911014986375555, 0.6818242326049438], 
             UndirectedEdge[123, 129] -> 
             RGBColor[
              0.45279766246512576`, 0.5665810049409397, 0.9500814941727593], 
             UndirectedEdge[25, 165] -> 
             RGBColor[
              0.19267100347283378`, 0.3198398190700993, 0.9342837006653468], 
             UndirectedEdge[39, 178] -> 
             RGBColor[
              0.21785481111783467`, 0.34630959765062364`, 0.935717881254625], 
             UndirectedEdge[76, 107] -> 
             RGBColor[
              0.2409407195820268, 0.37057435117762727`, 0.9370325895891196], 
             UndirectedEdge[63, 138] -> 
             RGBColor[
              0.20677310926701956`, 0.33466202638493814`, 0.9350867947281298],
              UndirectedEdge[71, 81] -> 
             RGBColor[
              0.334884249211027, 0.4642305141000421, 0.942568700992466], 
             UndirectedEdge[8, 83] -> 
             RGBColor[
              0.60482509904127, 0.6795990406798771, 0.9661417830923238], 
             UndirectedEdge[10, 149] -> 
             RGBColor[
              0.2017271344819297, 0.32935838695252884`, 0.9347994339289696], 
             UndirectedEdge[119, 172] -> 
             RGBColor[
              0.8543308282110663, 0.40714937648450034`, 0.19921155917100125`],
              UndirectedEdge[106, 130] -> 
             RGBColor[
              0.1846627044737023, 0.31142258906652903`, 0.933827639884563], 
             UndirectedEdge[147, 176] -> 
             RGBColor[
              0.24180624149358806`, 0.37148406958393687`, 0.9370818797815581],
              UndirectedEdge[27, 197] -> 
             RGBColor[
              0.23361320117338766`, 0.3628726647386469, 0.9366152982558398], 
             UndirectedEdge[72, 176] -> 
             RGBColor[
              0.2436445546193927, 0.37341625323494165`, 0.9371865689945322], 
             UndirectedEdge[92, 118] -> 
             RGBColor[
              0.31765722646768046`, 0.4436155762000519, 0.9416794866592155], 
             UndirectedEdge[123, 171] -> 
             RGBColor[
              0.3794372903745538, 0.5029791731450995, 0.9454017576293117], 
             UndirectedEdge[66, 113] -> 
             RGBColor[
              0.1939997700984511, 0.32123643704229315`, 0.9343593719589416], 
             UndirectedEdge[67, 179] -> 
             RGBColor[
              0.3122151911082063, 0.43995995071817273`, 0.941293986707691], 
             UndirectedEdge[130, 197] -> 
             RGBColor[
              0.19250062713784824`, 0.3196607427395459, 0.9342739979851187], 
             UndirectedEdge[15, 194] -> 
             RGBColor[
              0.19022447471756204`, 0.31726836222942645`, 0.934144374472049], 
             UndirectedEdge[47, 135] -> 
             RGBColor[
              0.19659862417943424`, 0.3239679974582722, 0.9345073728541936], 
             UndirectedEdge[8, 170] -> 
             RGBColor[
              0.4692360918503271, 0.5728158701273882, 0.9528557575864605], 
             UndirectedEdge[17, 149] -> 
             RGBColor[
              0.1884865346732682, 0.31544167705111037`, 0.9340454013575784], 
             UndirectedEdge[13, 97] -> 
             RGBColor[
              0.21895267363831583`, 0.3474635207681535, 0.9357804029010244], 
             UndirectedEdge[11, 86] -> 
             RGBColor[
              0.20252648869962175`, 0.33019855891730787`, 0.9348449559691285],
              UndirectedEdge[15, 62] -> 
             RGBColor[
              0.18941420148966015`, 0.3164167136926116, 0.9340982306104119], 
             UndirectedEdge[37, 160] -> 
             RGBColor[
              0.33951855272220766`, 0.4617555701348826, 0.9431015867680459], 
             UndirectedEdge[46, 50] -> 
             RGBColor[
              0.1933628575006826, 0.3205670015194474, 0.9343231007287265], 
             UndirectedEdge[49, 53] -> 
             RGBColor[
              0.5270688387556056, 0.6260965211703475, 0.956144232988289], 
             UndirectedEdge[52, 120] -> 
             RGBColor[
              0.1897634736745903, 0.3167838209041087, 0.9341181211446418], 
             UndirectedEdge[81, 147] -> 
             RGBColor[
              0.2777772836065891, 0.4092919155404977, 0.9391303774155055], 
             UndirectedEdge[49, 123] -> 
             RGBColor[
              0.43673943575620155`, 0.552703480914889, 0.949049628546234], 
             UndirectedEdge[127, 140] -> 
             RGBColor[
              0.9342553301344888, 0.9459893647897327, 0.7730553915426139], 
             UndirectedEdge[31, 132] -> 
             RGBColor[
              0.4162636354385904, 0.5320766653506034, 0.9483626292299419], 
             UndirectedEdge[146, 186] -> 
             RGBColor[
              0.2142358988127285, 0.34250589136566434`, 0.9355117895525502], 
             UndirectedEdge[98, 124] -> 
             RGBColor[
              0.20926922402508408`, 0.3372856012584804, 0.9352289447709307], 
             UndirectedEdge[4, 53] -> 
             RGBColor[
              0.483045374115442, 0.5879656087827072, 0.953339096749839], 
             UndirectedEdge[82, 137] -> 
             RGBColor[
              0.26792874657827515`, 0.39754009228340836`, 0.9386207928076713],
              UndirectedEdge[42, 107] -> 
             RGBColor[
              0.21020159060141025`, 0.3382655776456545, 0.9352820416681398], 
             UndirectedEdge[99, 102] -> 
             RGBColor[
              0.7604981725449849, 0.8117818781391992, 0.9474611303534258], 
             UndirectedEdge[57, 88] -> 
             RGBColor[
              0.1992012217508764, 0.32670349252007475`, 0.9346555869356892], 
             UndirectedEdge[40, 49] -> 
             RGBColor[
              0.46409235069374777`, 0.5749693711032751, 0.9511864931575826], 
             UndirectedEdge[21, 90] -> 
             RGBColor[
              0.29428715223398993`, 0.42178551711259177`, 0.9402485134141754],
              UndirectedEdge[143, 158] -> 
             RGBColor[
              0.5860035167018279, 0.6680847618686957, 0.9637366121327604], 
             UndirectedEdge[24, 111] -> 
             RGBColor[
              0.2386416994170433, 0.36815793521793205`, 0.9369016637918195], 
             UndirectedEdge[139, 155] -> 
             RGBColor[
              0.47942908630476494`, 0.5811030666228374, 0.9538203503715414], 
             UndirectedEdge[94, 174] -> 
             RGBColor[
              0.19022197405444352`, 0.31726573387393764`, 0.9341442320629838],
              UndirectedEdge[4, 118] -> 
             RGBColor[
              0.3625874930522409, 0.48847679512972536`, 0.9443247323271259], 
             UndirectedEdge[121, 159] -> 
             RGBColor[
              0.23612256314975283`, 0.36551016327854535`, 0.9367582027081254],
              UndirectedEdge[5, 76] -> 
             RGBColor[
              0.3092912653904981, 0.4382001789611937, 0.9410793812749982], 
             UndirectedEdge[27, 194] -> 
             RGBColor[
              0.23402121805989123`, 0.3633015163561269, 0.9366385342139192], 
             UndirectedEdge[77, 160] -> 
             RGBColor[
              0.6926095765883397, 0.2755150891779538, 0.42596556643194017`], 
             UndirectedEdge[2, 80] -> 
             RGBColor[
              0.20208335684743473`, 0.32973279924447707`, 0.9348197202657014],
              UndirectedEdge[74, 85] -> 
             RGBColor[
              0.3082012500479231, 0.4378314678081793, 0.9409888580526407], 
             UndirectedEdge[35, 110] -> 
             RGBColor[
              0.18045196756199675`, 0.30699683759618646`, 0.9335878446466683],
              UndirectedEdge[143, 154] -> 
             RGBColor[
              0.5937667549119501, 0.6748088886146058, 0.9642312788067474], 
             UndirectedEdge[53, 129] -> 
             RGBColor[
              0.5431270654645298, 0.6399740451963982, 0.9571760986148143], 
             UndirectedEdge[80, 187] -> 
             RGBColor[
              0.21263714806957626`, 0.34082550296795955`, 0.9354207430628674],
              UndirectedEdge[30, 87] -> 
             RGBColor[
              0.213134602991505, 0.3413483596313704, 0.9354490723847526], 
             UndirectedEdge[29, 197] -> 
             RGBColor[
              0.2038083296196198, 0.3315458549976343, 0.9349179549132087], 
             UndirectedEdge[74, 121] -> 
             RGBColor[
              0.28164177891966025`, 0.4099157796846441, 0.9394763354631025], 
             UndirectedEdge[127, 199] -> 
             RGBColor[
              0.935024065203026, 0.9476519779258816, 0.8580625143738301], 
             UndirectedEdge[52, 80] -> 
             RGBColor[
              0.20369103159656846`, 0.33142256733828307`, 0.9349112749643229],
              UndirectedEdge[125, 187] -> 
             RGBColor[
              0.233882104650328, 0.36315529934237634`, 0.9366306119110444], 
             UndirectedEdge[57, 152] -> 
             RGBColor[
              0.19101263224123774`, 0.3180967657588828, 0.9341892588770478], 
             UndirectedEdge[128, 193] -> 
             RGBColor[
              0.3303839734000996, 0.45325331449434825`, 0.942541154768971], 
             UndirectedEdge[151, 172] -> 
             RGBColor[
              0.9316219629473853, 0.7456677416234209, 0.4816953197665501], 
             UndirectedEdge[5, 27] -> 
             RGBColor[
              0.31042728364880795`, 0.439394206178395, 0.9411440758342206], 
             UndirectedEdge[65, 118] -> 
             RGBColor[
              0.6736030025738579, 0.6886766721110076, 0.6155053609978421], 
             UndirectedEdge[78, 80] -> 
             RGBColor[
              0.20236223698329917`, 0.33002591994929253`, 0.9348356020768727],
              UndirectedEdge[40, 199] -> 
             RGBColor[
              0.7505454658303996, 0.8010014916056775, 0.8412228920171474], 
             UndirectedEdge[5, 42] -> 
             RGBColor[
              0.2785521364098815, 0.40589140542922086`, 0.9393288333540183], 
             UndirectedEdge[123, 196] -> 
             RGBColor[
              0.3420552644486344, 0.4636882937396207, 0.9432729065545822], 
             UndirectedEdge[80, 124] -> 
             RGBColor[
              0.22391524057948223`, 0.35267949326823644`, 0.9360630137468638],
              UndirectedEdge[22, 48] -> 
             RGBColor[
              0.19949157754304903`, 0.3270086748672687, 0.9346721222685106], 
             UndirectedEdge[69, 86] -> 
             RGBColor[
              0.22595538032998164`, 0.3548238094983426, 0.9361791966875385], 
             UndirectedEdge[81, 143] -> 
             RGBColor[
              0.5808462742510027, 0.663366694048388, 0.9634171920700499], 
             UndirectedEdge[80, 116] -> 
             RGBColor[
              0.23121046425376574`, 0.3603472358938047, 0.936478465942798], 
             UndirectedEdge[90, 169] -> 
             RGBColor[
              0.20968181085613852`, 0.3377192561774346, 0.9352524409805917], 
             UndirectedEdge[121, 173] -> 
             RGBColor[
              0.292553121290118, 0.41936663602592106`, 0.9401715965504269], 
             UndirectedEdge[8, 179] -> 
             RGBColor[
              0.32590224390731876`, 0.4543459110193097, 0.9420734441164204], 
             UndirectedEdge[29, 167] -> 
             RGBColor[
              0.20312227411308098`, 0.33082476716183046`, 0.9348788850670395],
              UndirectedEdge[76, 87] -> 
             RGBColor[
              0.2404757286880707, 0.37008561626595393`, 0.9370061090456012], 
             UndirectedEdge[111, 163] -> 
             RGBColor[
              0.25094941763616774`, 0.3810941274206381, 0.9376025701367612], 
             UndirectedEdge[130, 149] -> 
             RGBColor[
              0.1848995905074315, 0.3116715713074204, 0.9338411301937424], 
             UndirectedEdge[7, 122] -> 
             RGBColor[
              0.24320904209445873`, 0.37295850195814717`, 0.9371617672005202],
              UndirectedEdge[89, 142] -> 
             RGBColor[
              0.2647563469392241, 0.39560608552802945`, 0.9383888543350487], 
             UndirectedEdge[44, 172] -> 
             RGBColor[
              0.8840573238836684, 0.5664132115032791, 0.22496692784453026`], 
             UndirectedEdge[7, 179] -> 
             RGBColor[
              0.2885173026234793, 0.4150519673878126, 0.9399444270163702], 
             UndirectedEdge[73, 188] -> 
             RGBColor[
              0.26534078986482257`, 0.3958083524158491, 0.9384372235539715], 
             UndirectedEdge[16, 120] -> 
             RGBColor[
              0.19055686956976303`, 0.31761773029414053`, 0.9341633038671477],
              UndirectedEdge[98, 116] -> 
             RGBColor[
              0.21656444769936758`, 0.34495334388404864`, 0.9356443969668649],
              UndirectedEdge[5, 81] -> 
             RGBColor[
              0.3301819815617254, 0.46015764620506105`, 0.9422690766559045], 
             UndirectedEdge[76, 106] -> 
             RGBColor[
              0.2246392602509319, 0.35344048384842863`, 0.9361042455960618], 
             UndirectedEdge[135, 144] -> 
             RGBColor[
              0.19771245739729065`, 0.32513870679134427`, 0.9345708040081819],
              UndirectedEdge[194, 197] -> 
             RGBColor[
              0.20111393254862053`, 0.3287138728413728, 0.9347645129860187], 
             UndirectedEdge[27, 29] -> 
             RGBColor[
              0.2367156151308905, 0.36613349851238836`, 0.9367919761411093], 
             UndirectedEdge[44, 58] -> 
             RGBColor[
              0.9296752902178356, 0.8016782468054864, 0.5944321925119014], 
             UndirectedEdge[53, 92] -> 
             RGBColor[
              0.4381151075308816, 0.5431043898530338, 0.9506938510819287], 
             UndirectedEdge[83, 122] -> 
             RGBColor[
              0.6021548677029418, 0.6767924582408489, 0.9659897173678593], 
             UndirectedEdge[9, 178] -> 
             RGBColor[
              0.18848044580793838`, 0.31543527726759235`, 0.9340450546057055],
              UndirectedEdge[12, 99] -> 
             RGBColor[
              0.7509614073428162, 0.7434552401786318, 0.618284844686889], 
             UndirectedEdge[7, 126] -> 
             RGBColor[
              0.19407996143665954`, 0.32132072322317473`, 0.9343639387370202],
              UndirectedEdge[139, 146] -> 
             RGBColor[
              0.2655359588850107, 0.39642550711330343`, 0.9384332520820287], 
             UndirectedEdge[100, 198] -> 
             RGBColor[
              0.2757071764245771, 0.40370652655373696`, 0.9391373291200573], 
             UndirectedEdge[56, 109] -> 
             RGBColor[
              0.19998929422011852`, 0.3275318066519287, 0.9347004664969638], 
             UndirectedEdge[9, 159] -> 
             RGBColor[
              0.22410281281265743`, 0.3528766435780701, 0.9360736957080549], 
             UndirectedEdge[2, 98] -> 
             RGBColor[
              0.18743734029303655`, 0.314338907234721, 0.9339856512897682], 
             UndirectedEdge[95, 164] -> 
             RGBColor[
              0.22218549989478478`, 0.35086142613672566`, 0.9359645075737923],
              UndirectedEdge[108, 163] -> 
             RGBColor[
              0.29489469195251866`, 0.4272833970184431, 0.94010518849787], 
             UndirectedEdge[85, 121] -> 
             RGBColor[
              0.24391248178172664`, 0.37369786167011787`, 0.9372018270500644],
              UndirectedEdge[55, 177] -> 
             RGBColor[
              0.2766340766323431, 0.4055817721640561, 0.9391571241529215], 
             UndirectedEdge[118, 141] -> 
             RGBColor[
              0.36734166462355905`, 0.4925946195931902, 0.9446276639357014], 
             UndirectedEdge[58, 77] -> 
             RGBColor[
              0.8650715589355825, 0.41279091020967174`, 0.42668452743448415`],
              UndirectedEdge[142, 154] -> 
             RGBColor[
              0.29693436368645065`, 0.4272891715192359, 0.9402996292628881], 
             UndirectedEdge[103, 178] -> 
             RGBColor[
              0.1823641236245055, 0.3090066348555799, 0.933696739105647], 
             UndirectedEdge[48, 154] -> 
             RGBColor[
              0.2711822856025334, 0.4002221046769836, 0.9388330865127945], 
             UndirectedEdge[72, 181] -> 
             RGBColor[
              0.345687120645864, 0.46870305597394574`, 0.9434358908416056], 
             UndirectedEdge[45, 132] -> 
             RGBColor[
              0.5058042387487333, 0.6037176098642293, 0.9561309549136163], 
             UndirectedEdge[103, 200] -> 
             RGBColor[
              0.18584727421565939`, 0.3126676469713855, 0.9338950993789537], 
             UndirectedEdge[21, 61] -> 
             RGBColor[
              0.2843221054652073, 0.4113116211381439, 0.9396810187426589], 
             UndirectedEdge[51, 73] -> 
             RGBColor[
              0.19983789794558066`, 0.3273726795683112, 0.9346918447030995], 
             UndirectedEdge[18, 41] -> 
             RGBColor[
              0.25688700518109014`, 0.38733490839514545`, 0.9379407069635708],
              UndirectedEdge[27, 42] -> 
             RGBColor[
              0.2346453394457319, 0.36395750750422684`, 0.936674077003538], 
             UndirectedEdge[90, 165] -> 
             RGBColor[
              0.21653690052978303`, 0.3449243900622238, 0.9356428281963094], 
             UndirectedEdge[50, 135] -> 
             RGBColor[
              0.20034146801813224`, 0.3279019636427496, 0.9347205222737662], 
             UndirectedEdge[93, 121] -> 
             RGBColor[
              0.22436989011875363`, 0.3531573587604565, 0.9360889053655316], 
             UndirectedEdge[23, 175] -> 
             RGBColor[
              0.36210448140880436`, 0.4789065526071719, 0.9449365792097879], 
             UndirectedEdge[57, 164] -> 
             RGBColor[
              0.1885063938143962, 0.3154625502675782, 0.9340465323062868], 
             UndirectedEdge[54, 172] -> 
             RGBColor[
              0.9288667542587956, 0.7360484350731749, 0.311047781867342], 
             UndirectedEdge[99, 198] -> 
             RGBColor[
              0.44872208919176476`, 0.5604076738789969, 0.9505521468225746], 
             UndirectedEdge[45, 112] -> 
             RGBColor[
              0.8262269535061243, 0.8650081965468237, 0.9779469895534628], 
             UndirectedEdge[88, 173] -> 
             RGBColor[
              0.2921580234490212, 0.41895136314427833`, 0.9401490963128714], 
             UndirectedEdge[14, 22] -> 
             RGBColor[
              0.18387332754707644`, 0.31059290386725735`, 0.9337826860363703],
              UndirectedEdge[7, 67] -> 
             RGBColor[
              0.23219222063367448`, 0.36137912409603845`, 0.9365343755162554],
              UndirectedEdge[105, 135] -> 
             RGBColor[
              0.20134641002226938`, 0.32895822140610087`, 0.9347777522342233],
              UndirectedEdge[104, 176] -> 
             RGBColor[
              0.300594019570315, 0.4278785034268868, 0.9406273032429688], 
             UndirectedEdge[57, 91] -> 
             RGBColor[
              0.18403700151578473`, 0.31076493558589874`, 0.9337920070267542],
              UndirectedEdge[34, 185] -> 
             RGBColor[
              0.3310536945005693, 0.45407275524127744`, 0.9425750645902526], 
             UndirectedEdge[65, 172] -> 
             RGBColor[
              0.9128396568383367, 0.6819852721325363, 0.24878553485224705`], 
             UndirectedEdge[66, 120] -> 
             RGBColor[
              0.18874212911118976`, 0.3157103230109893, 0.9340599570827], 
             UndirectedEdge[91, 117] -> 
             RGBColor[
              0.1857785761820701, 0.31259544098237624`, 0.9338911871275704], 
             UndirectedEdge[27, 141] -> 
             RGBColor[
              0.30516819016116037`, 0.4348390437291191, 0.9408089710476214], 
             UndirectedEdge[13, 145] -> 
             RGBColor[
              0.20564959648275716`, 0.3334811432138535, 0.9350228123371542], 
             UndirectedEdge[1, 174] -> 
             RGBColor[
              0.1849745541189024, 0.31175036281604385`, 0.9338453992605169], 
             UndirectedEdge[182, 196] -> 
             RGBColor[
              0.28690951633149697`, 0.41592381842644754`, 0.9397590682480286],
              UndirectedEdge[96, 137] -> 
             RGBColor[
              0.630154419316935, 0.7035305563325196, 0.9671868226387048], 
             UndirectedEdge[89, 157] -> 
             RGBColor[
              0.23696986749514018`, 0.36640073386774574`, 0.9368064554371207],
              UndirectedEdge[119, 191] -> 
             RGBColor[
              0.8345851088356466, 0.5244792716425559, 0.45555161240523445`], 
             UndirectedEdge[51, 157] -> 
             RGBColor[
              0.19431074366027534`, 0.32156328997263306`, 0.9343770814432435],
              UndirectedEdge[127, 195] -> 
             RGBColor[
              0.6879096375591269, 0.7543975082866485, 0.9708907042928315], 
             UndirectedEdge[27, 62] -> 
             RGBColor[
              0.23321094483198931`, 0.3624498678193121, 0.9365923903522819], 
             UndirectedEdge[4, 40] -> 
             RGBColor[
              0.42006888605358417`, 0.5368384587156347, 0.9483813569191326], 
             UndirectedEdge[161, 164] -> 
             RGBColor[
              0.23950057479482478`, 0.3690606676958246, 0.9369505754739917], 
             UndirectedEdge[20, 101] -> 
             RGBColor[
              0.18925893509711914`, 0.3162535188695931, 0.9340893884190526], 
             UndirectedEdge[13, 36] -> 
             RGBColor[
              0.20182875625464586`, 0.3294651978788461, 0.9348052211385899], 
             UndirectedEdge[182, 195] -> 
             RGBColor[
              0.42093237513181697`, 0.5377166564648852, 0.9484003790182465], 
             UndirectedEdge[184, 186] -> 
             RGBColor[
              0.18243843400162507`, 0.3090847397734826, 0.9337009709716915], 
             UndirectedEdge[96, 166] -> 
             RGBColor[
              0.8700729048613844, 0.8993494121193195, 0.9867932099380505], 
             UndirectedEdge[38, 43] -> 
             RGBColor[
              0.1854358891920559, 0.31223525522826123`, 0.9338716716104489], 
             UndirectedEdge[30, 176] -> 
             RGBColor[
              0.22182699852969923`, 0.3504846184717214, 0.9359440914514059], 
             UndirectedEdge[171, 174] -> 
             RGBColor[
              0.24889168370669917`, 0.37893131859289997`, 0.9374853852336225],
              UndirectedEdge[100, 125] -> 
             RGBColor[
              0.23503699113385892`, 0.36436915826059957`, 0.9366963809877801],
              UndirectedEdge[17, 188] -> 
             RGBColor[
              0.25233578672597107`, 0.38213926955209265`, 0.937696607864392], 
             UndirectedEdge[87, 107] -> 
             RGBColor[
              0.21716799810205883`, 0.34558771362458285`, 0.9356787682694253],
              UndirectedEdge[62, 184] -> 
             RGBColor[
              0.19085514348532573`, 0.3179312350910555, 0.9341802901253824], 
             UndirectedEdge[12, 33] -> 
             RGBColor[
              0.9713628299392978, 0.9155481063306994, 0.5253098577893779], 
             UndirectedEdge[32, 57] -> 
             RGBColor[
              0.1839232484123208, 0.31064537386179486`, 0.9337855289557946], 
             UndirectedEdge[17, 87] -> 
             RGBColor[
              0.2040861170766778, 0.33183782722774424`, 0.9349337744979385], 
             UndirectedEdge[42, 149] -> 
             RGBColor[
              0.1941370173040445, 0.32138069255734725`, 0.9343671879842612], 
             UndirectedEdge[87, 130] -> 
             RGBColor[
              0.20049917291084113`, 0.3280677214840543, 0.9347295033341025], 
             UndirectedEdge[58, 170] -> 
             RGBColor[
              0.8078923228953876, 0.8503457214275595, 0.9589431237256691], 
             UndirectedEdge[118, 196] -> 
             RGBColor[
              0.3119267863848373, 0.4375925203420974, 0.941353146573924], 
             UndirectedEdge[41, 159] -> 
             RGBColor[
              0.27279920204986197`, 0.40405963619577695`, 0.9388468830352616],
              UndirectedEdge[107, 157] -> 
             RGBColor[
              0.2120289568241801, 0.34018625540749603`, 0.9353861074711805], 
             UndirectedEdge[161, 173] -> 
             RGBColor[
              0.32579061120905595`, 0.4543013453093021, 0.9420644224308505], 
             UndirectedEdge[15, 184] -> 
             RGBColor[
              0.18036794199566558`, 0.3069085213984438, 0.9335830595149706], 
             UndirectedEdge[106, 142] -> 
             RGBColor[
              0.22351397693716918`, 0.3522577397385811, 0.9360401623760504], 
             UndirectedEdge[24, 39] -> 
             RGBColor[
              0.25460473932666533`, 0.38493610227813213`, 0.9378107352994711],
              UndirectedEdge[45, 134] -> 
             RGBColor[
              0.478958077481094, 0.5755005922270049, 0.9546021057447607], 
             UndirectedEdge[5, 73] -> 
             RGBColor[
              0.2859066569179567, 0.41362147278674055`, 0.939747662416915], 
             UndirectedEdge[147, 154] -> 
             RGBColor[
              0.2906977642675366, 0.42073411010671546`, 0.939944464152203], 
             UndirectedEdge[76, 143] -> 
             RGBColor[
              0.5599555580797754, 0.6414092268045206, 0.9622274966891435], 
             UndirectedEdge[5, 197] -> 
             RGBColor[
              0.27751999813753725`, 0.4048065626636409, 0.93927005460632], 
             UndirectedEdge[152, 159] -> 
             RGBColor[
              0.22753887579901738`, 0.3564881636357107, 0.9362693744119284], 
             UndirectedEdge[108, 115] -> 
             RGBColor[
              0.3115259900053915, 0.4441833842869002, 0.9410735735175593], 
             UndirectedEdge[65, 123] -> 
             RGBColor[
              0.7037314806376549, 0.7147724455085309, 0.6174251209785002], 
             UndirectedEdge[8, 67] -> 
             RGBColor[
              0.26957716191751396`, 0.4006730677275356, 0.9386633926163057], 
             UndirectedEdge[9, 41] -> 
             RGBColor[
              0.24200989921647753`, 0.37169812676333913`, 0.9370934777875921],
              UndirectedEdge[111, 165] -> 
             RGBColor[
              0.21296967150778956`, 0.3411750061847254, 0.9354396797807493], 
             UndirectedEdge[146, 195] -> 
             RGBColor[
              0.37321783418719845`, 0.490532301380389, 0.9455744828100211], 
             UndirectedEdge[104, 188] -> 
             RGBColor[
              0.34015129368141406`, 0.46904368691088416`, 0.9428951175427689],
              UndirectedEdge[37, 105] -> 
             RGBColor[
              0.22080146805015013`, 0.3494067209153274, 0.9358856890077321], 
             UndirectedEdge[3, 75] -> 
             RGBColor[
              0.4604176361342196, 0.5718866537552251, 0.9509246758011038], 
             UndirectedEdge[40, 132] -> 
             RGBColor[
              0.40319785832980803`, 0.5214692788871429, 0.94733404339442], 
             UndirectedEdge[154, 157] -> 
             RGBColor[
              0.2691478842423667, 0.3980838198589522, 0.9387172303649602], 
             UndirectedEdge[116, 148] -> 
             RGBColor[
              0.21710235245946194`, 0.3455187158920394, 0.9356750298471934], 
             UndirectedEdge[132, 185] -> 
             RGBColor[
              0.26630785953473646`, 0.397236823637493, 0.9384772106821059], 
             UndirectedEdge[92, 123] -> 
             RGBColor[
              0.34778570453147756`, 0.4697113495975751, 0.9435992466398737], 
             UndirectedEdge[53, 139] -> 
             RGBColor[
              0.4587256509461706, 0.5647673777664313, 0.9518675910388628], 
             UndirectedEdge[40, 196] -> 
             RGBColor[
              0.3694081793861806, 0.4859541839280068, 0.9454097711659308], 
             UndirectedEdge[27, 73] -> 
             RGBColor[
              0.2419998599538071, 0.37168757486174653`, 0.9370929060664348], 
             UndirectedEdge[57, 103] -> 
             RGBColor[
              0.1814602470714449, 0.3080566032892297, 0.9336452646731157], 
             UndirectedEdge[44, 77] -> 
             RGBColor[
              0.8444706345429746, 0.3004972543273192, 0.1885609342401168], 
             UndirectedEdge[88, 91] -> 
             RGBColor[
              0.20139859473617852`, 0.32901307084912135`, 0.93478072407648], 
             UndirectedEdge[69, 146] -> 
             RGBColor[
              0.24760893000865222`, 0.37758306312497075`, 0.9374123343081827],
              UndirectedEdge[65, 199] -> 
             RGBColor[
              0.9757996397934585, 0.9283450401492326, 0.5065449231630825], 
             UndirectedEdge[27, 75] -> 
             RGBColor[
              0.3843313935505691, 0.5020805374205839, 0.9462194736309155], 
             UndirectedEdge[4, 65] -> 
             RGBColor[
              0.6453230600166431, 0.6641820072591899, 0.6137033880650677], 
             UndirectedEdge[58, 102] -> 
             RGBColor[
              0.9648761622564584, 0.9733252798376484, 0.9443396749224908], 
             UndirectedEdge[107, 168] -> 
             RGBColor[
              0.21351519211843195`, 0.34174838293451504`, 0.9354707463724999],
              UndirectedEdge[9, 85] -> 
             RGBColor[
              0.23189273144463124`, 0.36106434196964265`, 0.9365173200499939],
              UndirectedEdge[22, 144] -> 
             RGBColor[
              0.19348904144218293`, 0.3206996288424882, 0.9343302867175226], 
             UndirectedEdge[110, 138] -> 
             RGBColor[
              0.20099999291646117`, 0.32859411506378333`, 0.9347580242925257],
              UndirectedEdge[34, 132] -> 
             RGBColor[
              0.3653113300133066, 0.4900797022247081, 0.9445259862530728], 
             UndirectedEdge[48, 158] -> 
             RGBColor[
              0.2634190473924112, 0.39349797793107355`, 0.9383384198388076], 
             UndirectedEdge[19, 95] -> 
             RGBColor[
              0.3002072480543151, 0.4289405280402324, 0.9405515065144217], 
             UndirectedEdge[122, 137] -> 
             RGBColor[
              0.3009080664928653, 0.4322034485232962, 0.9404989162882755], 
             UndirectedEdge[8, 198] -> 
             RGBColor[
              0.31444384785817775`, 0.4444212242772747, 0.9413433252524308], 
             UndirectedEdge[92, 174] -> 
             RGBColor[
              0.2172400978636229, 0.3456634950453756, 0.9356828742441843], 
             UndirectedEdge[39, 133] -> 
             RGBColor[
              0.2505927164379196, 0.38071921184511703`, 0.9375822565312131], 
             UndirectedEdge[120, 198] -> 
             RGBColor[
              0.26978078120628096`, 0.39747750942414833`, 0.9387998296796913],
              UndirectedEdge[4, 34] -> 
             RGBColor[
              0.38218235773708276`, 0.5054488820532, 0.9455732997777855], 
             UndirectedEdge[31, 34] -> 
             RGBColor[
              0.48100947040442327`, 0.5889125969543878, 0.9524604831380885], 
             UndirectedEdge[41, 152] -> 
             RGBColor[
              0.2454459622028375, 0.3753096468209797, 0.9372891564914656], 
             UndirectedEdge[95, 121] -> 
             RGBColor[
              0.23327542567236176`, 0.36251764127086494`, 0.9365960624407503],
              UndirectedEdge[3, 129] -> 
             RGBColor[
              0.4365819525225805, 0.5525357720139865, 0.9490482434742096], 
             UndirectedEdge[49, 199] -> 
             RGBColor[
              0.7088075949120052, 0.7662760755555905, 0.8381694307308162], 
             UndirectedEdge[171, 182] -> 
             RGBColor[
              0.3242915422574164, 0.45521469783192636`, 0.9418879193227581], 
             UndirectedEdge[56, 150] -> 
             RGBColor[
              0.18756580923325702`, 0.31447393623629405`, 0.933992967405861], 
             UndirectedEdge[179, 183] -> 
             RGBColor[
              0.6524621901365182, 0.6395620041190959, 0.6061877007325749], 
             UndirectedEdge[31, 156] -> 
             RGBColor[
              0.723132374813741, 0.30688840243812476`, 0.4291372901014996], 
             UndirectedEdge[132, 153] -> 
             RGBColor[
              0.29141110867079584`, 0.42362193011741534`, 0.9399068035834754],
              UndirectedEdge[78, 136] -> 
             RGBColor[
              0.2028717449192551, 0.3305614450946512, 0.9348646178000759], 
             UndirectedEdge[27, 167] -> 
             RGBColor[
              0.2329271456668488, 0.36215157690284305`, 0.9365762284096705], 
             UndirectedEdge[35, 174] -> 
             RGBColor[
              0.18540537254043327`, 0.31220318029253835`, 0.9338699337322844],
              UndirectedEdge[61, 190] -> 
             RGBColor[
              0.1957633885191688, 0.3230901118223337, 0.9344598074189618], 
             UndirectedEdge[18, 103] -> 
             RGBColor[
              0.20207429376045272`, 0.32972327336542606`, 0.9348192041363055],
              UndirectedEdge[146, 155] -> 
             RGBColor[
              0.4592969410332923, 0.5599429054907851, 0.9526738544811711], 
             UndirectedEdge[77, 166] -> 
             RGBColor[
              0.8127891173448866, 0.371617581823192, 0.4365026295330454], 
             UndirectedEdge[85, 159] -> 
             RGBColor[
              0.26268203427801573`, 0.3934258514020805, 0.9382707252976634], 
             UndirectedEdge[39, 88] -> 
             RGBColor[
              0.2343125277851679, 0.36360770134749604`, 0.9366551238718196], 
             UndirectedEdge[66, 80] -> 
             RGBColor[
              0.20266968703316796`, 0.3303490694451636, 0.9348531109023811], 
             UndirectedEdge[62, 141] -> 
             RGBColor[
              0.2718586483084913, 0.3998286032950302, 0.9389120419161632], 
             UndirectedEdge[91, 103] -> 
             RGBColor[
              0.18365762005674702`, 0.31036618161827634`, 0.9337704018139066],
              UndirectedEdge[149, 189] -> 
             RGBColor[
              0.18996767873421347`, 0.31699845336912136`, 0.934129750320693], 
             UndirectedEdge[4, 69] -> 
             RGBColor[
              0.2920607984493962, 0.42194145527329896`, 0.9400303359095292], 
             UndirectedEdge[23, 169] -> 
             RGBColor[
              0.20786534559532402`, 0.33581003601776915`, 0.9351489959712078],
              UndirectedEdge[32, 152] -> 
             RGBColor[
              0.19309625212307593`, 0.3202867823638255, 0.9343079179468792], 
             UndirectedEdge[100, 124] -> 
             RGBColor[
              0.21591407787580016`, 0.3442697639636507, 0.9356073593675487], 
             UndirectedEdge[129, 139] -> 
             RGBColor[
              0.3700695186748425, 0.49279233567532266`, 0.9448882555483507], 
             UndirectedEdge[29, 73] -> 
             RGBColor[
              0.21219498840003925`, 0.3403607651207339, 0.9353955627238038], 
             UndirectedEdge[32, 178] -> 
             RGBColor[
              0.1848271249653814, 0.311595405428145, 0.9338370033883259], 
             UndirectedEdge[8, 61] -> 
             RGBColor[
              0.24530237000143487`, 0.37515872231303415`, 0.9372809791280214],
              UndirectedEdge[10, 27] -> 
             RGBColor[
              0.24223545662361712`, 0.37193520189940843`, 0.9371063229482464],
              UndirectedEdge[72, 160] -> 
             RGBColor[
              0.3481960203596565, 0.4708761388050667, 0.9435957557128356], 
             UndirectedEdge[72, 144] -> 
             RGBColor[
              0.22584498306262032`, 0.3547077749707548, 0.9361729097264804], 
             UndirectedEdge[134, 135] -> 
             RGBColor[
              0.22190471606791506`, 0.3505663045319628, 0.9359485173502345], 
             UndirectedEdge[95, 150] -> 
             RGBColor[
              0.2208799451115121, 0.3494892052825519, 0.9358901581602801], 
             UndirectedEdge[68, 71] -> 
             RGBColor[
              0.6623649639352431, 0.6847752584173, 0.6236785616506062], 
             UndirectedEdge[118, 123] -> 
             RGBColor[
              0.42099591367325284`, 0.5390672333790665, 0.9480464652405584], 
             UndirectedEdge[89, 168] -> 
             RGBColor[
              0.23845610278939203`, 0.36796286139476475`, 0.9368910943384403],
              UndirectedEdge[44, 99] -> 
             RGBColor[
              0.7252973005063621, 0.6401348451070372, 0.5975536479428364], 
             UndirectedEdge[121, 180] -> 
             RGBColor[
              0.27969294333585376`, 0.40822779625327543`, 0.9393521573829899],
              UndirectedEdge[10, 141] -> 
             RGBColor[
              0.28088316010011916`, 0.40931393737512656`, 0.9394259745121276],
              UndirectedEdge[6, 170] -> 
             RGBColor[
              0.7726913425929597, 0.40526664724585604`, 0.4405786287096226], 
             UndirectedEdge[12, 77] -> 
             RGBColor[
              0.8615800391006107, 0.36937751770838223`, 0.20238173206948523`],
              UndirectedEdge[112, 143] -> 
             RGBColor[
              0.8985367952768839, 0.9217855718880776, 0.9850776323188054], 
             UndirectedEdge[67, 125] -> 
             RGBColor[
              0.2600866097683471, 0.39069789568300034`, 0.9381229197114243], 
             UndirectedEdge[3, 10] -> 
             RGBColor[
              0.3183216992072676, 0.4417413182340497, 0.9418115251184348], 
             UndirectedEdge[124, 125] -> 
             RGBColor[
              0.24516019716023396`, 0.37500928964265323`, 0.9372728825950409],
              UndirectedEdge[11, 174] -> 
             RGBColor[
              0.1964947207721936, 0.32385878838940574`, 0.9345014557088626], 
             UndirectedEdge[71, 87] -> 
             RGBColor[
              0.29022081155983176`, 0.4172864093031303, 0.9400251842918653], 
             UndirectedEdge[7, 192] -> 
             RGBColor[
              0.3371042587561843, 0.4567989612427451, 0.9431333444727331], 
             UndirectedEdge[56, 148] -> 
             RGBColor[
              0.18807327130146562`, 0.31500731104493473`, 0.9340218666199227],
              UndirectedEdge[30, 71] -> 
             RGBColor[
              0.28665240734323405`, 0.41353579022159115`, 0.939821968950711], 
             UndirectedEdge[35, 86] -> 
             RGBColor[
              0.19143714046786142`, 0.31854295082044043`, 0.9342134339925504],
              UndirectedEdge[68, 127] -> 
             RGBColor[
              0.9178893661581602, 0.8915362183675095, 0.645439120800334], 
             UndirectedEdge[10, 30] -> 
             RGBColor[
              0.2137583126687416, 0.34200391804762365`, 0.9354845917281754], 
             UndirectedEdge[89, 176] -> 
             RGBColor[
              0.25080130431121317`, 0.3809384509251836, 0.937594135302019], 
             UndirectedEdge[71, 76] -> 
             RGBColor[
              0.3139935330397997, 0.4422730468561747, 0.9413790056115596], 
             UndirectedEdge[49, 119] -> 
             RGBColor[
              0.705335406756713, 0.42070114149402954`, 0.44436021880518173`], 
             UndirectedEdge[87, 106] -> 
             RGBColor[
              0.20086653877096394`, 0.3284538462953842, 0.9347504242763673], 
             UndirectedEdge[86, 196] -> 
             RGBColor[
              0.2175414257082079, 0.3459802097153233, 0.9357000344191588], 
             UndirectedEdge[53, 123] -> 
             RGBColor[
              0.5414537947364539, 0.6385560470320484, 0.9570608296632714], 
             UndirectedEdge[68, 102] -> 
             RGBColor[
              0.9650834798325474, 0.9283042529937652, 0.6200104049924591], 
             UndirectedEdge[107, 130] -> 
             RGBColor[
              0.20096416380479723`, 0.32855645639572767`, 0.9347559838776209],
              UndirectedEdge[42, 157] -> 
             RGBColor[
              0.2045975584295754, 0.3323753845168943, 0.9349629003263764], 
             UndirectedEdge[96, 99] -> 
             RGBColor[
              0.7441185775359549, 0.79956600300059, 0.9751875122211435], 
             UndirectedEdge[62, 194] -> 
             RGBColor[
              0.2007116762072222, 0.32829107592203804`, 0.9347416050824608], 
             UndirectedEdge[57, 117] -> 
             RGBColor[
              0.18358120319676802`, 0.31028586265332964`, 0.9337660499867794],
              UndirectedEdge[102, 128] -> 
             RGBColor[
              0.700241137930167, 0.7622648425385679, 0.9428826111957023], 
             UndirectedEdge[46, 47] -> 
             RGBColor[
              0.1896200136619846, 0.31663303533497, 0.934109951309154], 
             UndirectedEdge[28, 105] -> 
             RGBColor[
              0.19252363925225727`, 0.3196849299308422, 0.9342753084909909], 
             UndirectedEdge[40, 182] -> 
             RGBColor[
              0.4233315585574587, 0.5396644216518027, 0.9485892515260115], 
             UndirectedEdge[79, 179] -> 
             RGBColor[
              0.2813590504704592, 0.4075281905155883, 0.9395367751459407], 
             UndirectedEdge[36, 63] -> 
             RGBColor[
              0.1871120628164008, 0.3139970199829937, 0.9339671272186787], 
             UndirectedEdge[118, 129] -> 
             RGBColor[
              0.4226691844013287, 0.5404852315434163, 0.9481617341921013], 
             UndirectedEdge[74, 161] -> 
             RGBColor[
              0.31487926883859824`, 0.44485048896802515`, 0.9413691613435261],
              UndirectedEdge[66, 187] -> 
             RGBColor[
              0.19351363784595493`, 0.32072548122235467`, 0.9343316874463302],
              UndirectedEdge[10, 29] -> 
             RGBColor[
              0.2124305850698493, 0.3406083921583959, 0.9354089796056155], 
             UndirectedEdge[30, 147] -> 
             RGBColor[
              0.22954544173879612`, 0.3585971916620468, 0.9363836453737505], 
             UndirectedEdge[109, 116] -> 
             RGBColor[
              0.2290183753781148, 0.3580432114990334, 0.9363536297242345], 
             UndirectedEdge[81, 154] -> 
             RGBColor[
              0.31895036317144065`, 0.45042938287295087`, 0.9415534078638058],
              UndirectedEdge[89, 188] -> 
             RGBColor[
              0.29035857842231216`, 0.42210363440918097`, 0.939861949601819], 
             UndirectedEdge[24, 163] -> 
             RGBColor[
              0.2694549562733895, 0.40054462184727546`, 0.9386564331856598], 
             UndirectedEdge[91, 159] -> 
             RGBColor[
              0.22056324507356437`, 0.3491563334627266, 0.9358721225616348], 
             UndirectedEdge[121, 164] -> 
             RGBColor[
              0.2062630848758868, 0.3341259584124435, 0.9350577495935681], 
             UndirectedEdge[4, 54] -> 
             RGBColor[
              0.661350157437102, 0.7182451701998284, 0.6759656350801627], 
             UndirectedEdge[51, 130] -> 
             RGBColor[
              0.18324595064089247`, 0.3099334909608647, 0.933746957849684], 
             UndirectedEdge[69, 186] -> 
             RGBColor[
              0.21644101520784265`, 0.3448236085093839, 0.9356373676690746], 
             UndirectedEdge[137, 179] -> 
             RGBColor[
              0.3462163270218858, 0.4742969139529616, 0.9432815761041253], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.37725864887478877`, 0.501184212909484, 0.945259565402945], 
             UndirectedEdge[22, 176] -> 
             RGBColor[
              0.2112886129989553, 0.33940810710667507`, 0.9353439459855744], 
             UndirectedEdge[128, 198] -> 
             RGBColor[
              0.38846505457694686`, 0.5108906382783656, 0.9459736276648509], 
             UndirectedEdge[107, 131] -> 
             RGBColor[
              0.19956404883419218`, 0.32708484678920535`, 0.9346762494013294],
              UndirectedEdge[26, 125] -> 
             RGBColor[
              0.2785326649894304, 0.41008586926780977`, 0.9391733952677717], 
             UndirectedEdge[47, 105] -> 
             RGBColor[
              0.2010087745780687, 0.32860334514692235`, 0.934758524395163], 
             UndirectedEdge[23, 60] -> 
             RGBColor[
              0.2023092030396156, 0.32997017791193484`, 0.9348325818722366], 
             UndirectedEdge[43, 111] -> 
             RGBColor[
              0.2049417486516364, 0.33273715026320094`, 0.934982501450339], 
             UndirectedEdge[73, 142] -> 
             RGBColor[
              0.23973855838173452`, 0.36931080353469764`, 0.9369641282872011],
              UndirectedEdge[43, 115] -> 
             RGBColor[
              0.25238630356085545`, 0.3820238241610014, 0.9377056558638687], 
             UndirectedEdge[61, 122] -> 
             RGBColor[
              0.24263213866310665`, 0.37235213987400595`, 0.9371289134035569],
              UndirectedEdge[64, 65] -> 
             RGBColor[
              0.792934775654365, 0.787251260573052, 0.6244310740750881], 
             UndirectedEdge[147, 157] -> 
             RGBColor[
              0.2279748046775151, 0.3569463525264991, 0.9362941999166599], 
             UndirectedEdge[53, 69] -> 
             RGBColor[
              0.4407986220698122, 0.5459249337780987, 0.9508466732650168], 
             UndirectedEdge[27, 188] -> 
             RGBColor[
              0.28986141659567377`, 0.4215810858075036, 0.939833636971277], 
             UndirectedEdge[88, 159] -> 
             RGBColor[
              0.23572746530865607`, 0.3650948903969026, 0.9367357024705698], 
             UndirectedEdge[16, 61] -> 
             RGBColor[
              0.19725809150646825`, 0.3246611394316285, 0.9345449285428737], 
             UndirectedEdge[138, 185] -> 
             RGBColor[
              0.22696192070522694`, 0.35588174725107113`, 0.9362365176728656],
              UndirectedEdge[26, 128] -> 
             RGBColor[
              0.36204442385736635`, 0.48653045531343586`, 0.9443441705850733],
              UndirectedEdge[68, 75] -> 
             RGBColor[
              0.7315668061877028, 0.7433887217645079, 0.6284543351107399], 
             UndirectedEdge[10, 107] -> 
             RGBColor[
              0.21779170777929543`, 0.3462432720408361, 0.9357142876128481], 
             UndirectedEdge[69, 123] -> 
             RGBColor[
              0.3504692190704081, 0.47253189352264, 0.9437520688229617], 
             UndirectedEdge[109, 113] -> 
             RGBColor[
              0.2109311914464215, 0.33903243439312675`, 0.9353235913569153], 
             UndirectedEdge[49, 196] -> 
             RGBColor[
              0.3276703084677861, 0.4512287678779199, 0.9423563098795996], 
             UndirectedEdge[8, 26] -> 
             RGBColor[
              0.28802321713859724`, 0.420061041312345, 0.9397138681726531], 
             UndirectedEdge[30, 73] -> 
             RGBColor[
              0.21352271599893158`, 0.34175629100996163`, 0.9354711748463638],
              UndirectedEdge[46, 144] -> 
             RGBColor[
              0.19073384687984102`, 0.31780374466804207`, 0.9341733824631423],
              UndirectedEdge[81, 176] -> 
             RGBColor[
              0.2700588403974922, 0.4011793423501723, 0.938690823493161], 
             UndirectedEdge[104, 181] -> 
             RGBColor[
              0.4026365855967863, 0.5231653061658909, 0.9468766250900423], 
             UndirectedEdge[65, 171] -> 
             RGBColor[
              0.6320443792751589, 0.6525886118770408, 0.6128606533865955], 
             UndirectedEdge[67, 82] -> 
             RGBColor[
              0.2339276106645956, 0.3632031290486195, 0.9366332034112368], 
             UndirectedEdge[13, 63] -> 
             RGBColor[
              0.20638929458382937`, 0.3342586128176488, 0.935064937049725], 
             UndirectedEdge[153, 182] -> 
             RGBColor[
              0.3115448088984465, 0.4418170728820753, 0.941162011715067], 
             UndirectedEdge[87, 157] -> 
             RGBColor[
              0.21156396593022397`, 0.3396975204958227, 0.9353596269276621], 
             UndirectedEdge[30, 157] -> 
             RGBColor[
              0.20799556171362626`, 0.3359469014142835, 0.9351564115865076], 
             UndirectedEdge[64, 185] -> 
             RGBColor[
              0.4307906028962345, 0.5356752567798472, 0.9502522102168389], 
             UndirectedEdge[9, 103] -> 
             RGBColor[
              0.18719718779584008`, 0.3140864917336198, 0.9339719749603267], 
             UndirectedEdge[18, 117] -> 
             RGBColor[
              0.2041952498857758, 0.331952532729526, 0.9349399894499691], 
             UndirectedEdge[52, 66] -> 
             RGBColor[
              0.18456752137294713`, 0.3113225455926782, 0.9338222193477858], 
             UndirectedEdge[128, 162] -> 
             RGBColor[
              0.4413593088202362, 0.5567049827613839, 0.9493440027726809], 
             UndirectedEdge[23, 177] -> 
             RGBColor[
              0.22051380406985302`, 0.3491043678330853, 0.9358693069696149], 
             UndirectedEdge[11, 110] -> 
             RGBColor[
              0.1915413157937571, 0.3186524456930539, 0.9342193666232466], 
             UndirectedEdge[79, 177] -> 
             RGBColor[
              0.20578387384021699`, 0.33362227723022, 0.9350304592340161], 
             UndirectedEdge[8, 166] -> 
             RGBColor[
              0.543496783375643, 0.6308288867491243, 0.9602573693120857], 
             UndirectedEdge[162, 173] -> 
             RGBColor[
              0.40958261070654, 0.5291816039985865, 0.947319219667907], 
             UndirectedEdge[100, 137] -> 
             RGBColor[
              0.26484162639759284`, 0.3942953332387867, 0.9384449858803665], 
             UndirectedEdge[88, 117] -> 
             RGBColor[
              0.2009427964171618, 0.32853399791655225`, 0.9347547670365053], 
             UndirectedEdge[149, 168] -> 
             RGBColor[
              0.19745061882106624`, 0.32486349784620777`, 0.9345558926886215],
              UndirectedEdge[36, 110] -> 
             RGBColor[
              0.18133894646584242`, 0.3079291086618389, 0.9336383567830746], 
             UndirectedEdge[76, 104] -> 
             RGBColor[
              0.3156743455120887, 0.4437288821395802, 0.9414861054960099], 
             UndirectedEdge[4, 196] -> 
             RGBColor[
              0.28364684382762245`, 0.41309785549027966`, 0.9395511736411497],
              UndirectedEdge[61, 79] -> 
             RGBColor[
              0.20075917656457537`, 0.3283410018093128, 0.9347443101575417], 
             UndirectedEdge[76, 147] -> 
             RGBColor[
              0.2568865674353618, 0.38733444829663033`, 0.9379406820345992], 
             UndirectedEdge[2, 120] -> 
             RGBColor[
              0.18815579892545653`, 0.3150940528103027, 0.9340265664460203], 
             UndirectedEdge[87, 176] -> 
             RGBColor[
              0.22539540274629694`, 0.3542352375532605, 0.9361473067925603], 
             UndirectedEdge[142, 157] -> 
             RGBColor[
              0.2342114040964292, 0.3635014139390195, 0.9366493650273451], 
             UndirectedEdge[65, 191] -> 
             RGBColor[
              0.8832210777752071, 0.8579801148696197, 0.6332956147035969], 
             UndirectedEdge[73, 147] -> 
             RGBColor[
              0.23350195896282042`, 0.3627557421221772, 0.936608963176516], 
             UndirectedEdge[26, 120] -> 
             RGBColor[
              0.2433601504867005, 0.3731173264592187, 0.9371703725999135], 
             UndirectedEdge[113, 116] -> 
             RGBColor[
              0.22254054731904888`, 0.35123460349093416`, 0.9359847269993585],
              UndirectedEdge[35, 94] -> 
             RGBColor[
              0.1855941681935362, 0.31240161649428533`, 0.9338806853654305], 
             UndirectedEdge[31, 45] -> 
             RGBColor[0.62150237913985, 0.702550504593909, 0.964065451798632],
              UndirectedEdge[52, 82] -> 
             RGBColor[
              0.1987769890735687, 0.32625759707831903`, 0.9346314275123124], 
             UndirectedEdge[95, 162] -> 
             RGBColor[
              0.35030491508878375`, 0.4723326092435304, 0.9437436855582304], 
             UndirectedEdge[17, 73] -> 
             RGBColor[
              0.20447423008410437`, 0.33224575860633554`, 0.9349558769595496],
              UndirectedEdge[103, 152] -> 
             RGBColor[
              0.19063325078220003`, 0.31769801179126034`, 0.9341676536642003],
              UndirectedEdge[88, 103] -> 
             RGBColor[
              0.1988218402918387, 0.32630473855245234`, 0.9346339817228415], 
             UndirectedEdge[26, 170] -> 
             RGBColor[
              0.4739950942722979, 0.5778178834110607, 0.9531267757340784], 
             UndirectedEdge[89, 106] -> 
             RGBColor[
              0.22627244033588012`, 0.3551570596673073, 0.9361972527858261], 
             UndirectedEdge[19, 74] -> 
             RGBColor[
              0.34857360130161363`, 0.4763386664540116, 0.9434317795367738], 
             UndirectedEdge[117, 152] -> 
             RGBColor[
              0.19275420690752315`, 0.3199272711553603, 0.934288438977864], 
             UndirectedEdge[157, 176] -> 
             RGBColor[
              0.2202563614684182, 0.34883377933617365`, 0.9358546459943153], 
             UndirectedEdge[49, 139] -> 
             RGBColor[
              0.3540112919659183, 0.4789148116492719, 0.9438563899218253], 
             UndirectedEdge[48, 106] -> 
             RGBColor[
              0.1977618988532519, 0.32519067289632886`, 0.9345736196259569], 
             UndirectedEdge[69, 118] -> 
             RGBColor[
              0.32034074100661103`, 0.44643612012511674`, 0.9418323088423037],
              UndirectedEdge[117, 200] -> 
             RGBColor[
              0.1879682303409825, 0.3148969063354854, 0.9340158846926173], 
             UndirectedEdge[64, 153] -> 
             RGBColor[
              0.4558938520322939, 0.5620603632597695, 0.9516818031182084], 
             UndirectedEdge[73, 87] -> 
             RGBColor[
              0.2170911202155293, 0.3455069100915008, 0.9356743901875181], 
             UndirectedEdge[132, 138] -> 
             RGBColor[
              0.2612195562179643, 0.3918886942345018, 0.9381874393356859], 
             UndirectedEdge[6, 96] -> 
             RGBColor[
              0.8664275054943202, 0.4791091027601758, 0.4493272507526489], 
             UndirectedEdge[34, 65] -> 
             RGBColor[
              0.6931978672586998, 0.7056487590344823, 0.6167539284485017], 
             UndirectedEdge[2, 16] -> 
             RGBColor[
              0.1847745870823867, 0.3115401847820234, 0.9338340114336121], 
             UndirectedEdge[21, 122] -> 
             RGBColor[
              0.3196137188420707, 0.44840534441475405`, 0.941690823915208], 
             UndirectedEdge[90, 175] -> 
             RGBColor[
              0.36392094666961883`, 0.4808157727668374, 0.9450400242191717], 
             UndirectedEdge[6, 179] -> 
             RGBColor[
              0.6771354439642875, 0.3262866745071371, 0.4333904197295959], 
             UndirectedEdge[8, 137] -> 
             RGBColor[
              0.3035782978311935, 0.4350100309623244, 0.94065098201274], 
             UndirectedEdge[3, 127] -> 
             RGBColor[
              0.6467401961046771, 0.7200341503582268, 0.9679094614906981], 
             UndirectedEdge[31, 65] -> 
             RGBColor[
              0.7441501726839835, 0.7476457221603776, 0.6205905714253708], 
             UndirectedEdge[3, 71] -> 
             RGBColor[
              0.3912157938817601, 0.5132731904080172, 0.9461489023409704], 
             UndirectedEdge[146, 184] -> 
             RGBColor[
              0.21360634880243462`, 0.34184419438906943`, 0.9354759376107997],
              UndirectedEdge[33, 99] -> 
             RGBColor[
              0.772222119980282, 0.8191247933841846, 0.8648855062678112], 
             UndirectedEdge[10, 130] -> 
             RGBColor[
              0.2011228825880777, 0.32872327990030753`, 0.9347650226775253], 
             UndirectedEdge[112, 160] -> 
             RGBColor[
              0.6923008271636373, 0.757058105759987, 0.9667604504602199], 
             UndirectedEdge[73, 157] -> 
             RGBColor[
              0.21195207893765056`, 0.34010545187441393`, 0.9353817293892732],
              UndirectedEdge[157, 188] -> 
             RGBColor[
              0.25981363557951725`, 0.389998962820171, 0.9381224602941154], 
             UndirectedEdge[70, 132] -> 
             RGBColor[
              0.2458080236877891, 0.37569019639768786`, 0.9373097753574117], 
             UndirectedEdge[141, 191] -> 
             RGBColor[
              0.5769597398249082, 0.6618980623518022, 0.9624179176414562], 
             UndirectedEdge[26, 80] -> 
             RGBColor[
              0.25728770840867865`, 0.387756072893393, 0.9379635264195947], 
             UndirectedEdge[171, 199] -> 
             RGBColor[
              0.6515054495303574, 0.7165517677858011, 0.834521559813894], 
             UndirectedEdge[23, 43] -> 
             RGBColor[
              0.2066925124128154, 0.33457731398103385`, 0.9350822048565153], 
             UndirectedEdge[75, 81] -> 
             RGBColor[
              0.40408609146348656`, 0.52284397744725, 0.9473444744525996], 
             UndirectedEdge[33, 172] -> 
             RGBColor[
              0.9309821433575884, 0.7454031597804265, 0.49229878616950506`], 
             UndirectedEdge[156, 166] -> 
             RGBColor[
              0.8137215668820587, 0.378784797567889, 0.4373955442628925], 
             UndirectedEdge[151, 175] -> 
             RGBColor[
              0.7472372281358932, 0.7985860801048122, 0.8522647687143463], 
             UndirectedEdge[34, 199] -> 
             RGBColor[
              0.7126589375138983, 0.7696119149432428, 0.8384148348758003], 
             UndirectedEdge[38, 169] -> 
             RGBColor[
              0.18660872237456455`, 0.31346797726499653`, 0.9339384627251416],
              UndirectedEdge[10, 142] -> 
             RGBColor[
              0.23997415505154454`, 0.3695584305723596, 0.9369775451690128], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.2876001150236012, 0.4192043144804547, 0.9397048591920434], 
             UndirectedEdge[12, 128] -> 
             RGBColor[
              0.6907043727279983, 0.6939382045780004, 0.6137063255291655], 
             UndirectedEdge[19, 172] -> 
             RGBColor[
              0.610278699777892, 0.48910830355495916`, 0.5781436227882895], 
             UndirectedEdge[109, 124] -> 
             RGBColor[
              0.22172315170383133`, 0.35037546887346516`, 0.9359381775283004],
              UndirectedEdge[75, 127] -> 
             RGBColor[
              0.6884648603869374, 0.7548482631907685, 0.9709344134676849], 
             UndirectedEdge[4, 191] -> 
             RGBColor[
              0.57220556825359, 0.6577802378883374, 0.9621149860328806], 
             UndirectedEdge[68, 172] -> 
             RGBColor[
              0.9151660280486694, 0.6898326684829248, 0.25782304770604947`], 
             UndirectedEdge[97, 105] -> 
             RGBColor[
              0.21127795983773054`, 0.3393969099587784, 0.9353433393038026], 
             UndirectedEdge[120, 136] -> 
             RGBColor[
              0.208375147270767, 0.3363458699019528, 0.9351780284224404], 
             UndirectedEdge[117, 159] -> 
             RGBColor[
              0.22010744675454766`, 0.3486772605301575, 0.9358461655216599], 
             UndirectedEdge[183, 192] -> 
             RGBColor[
              0.7010491462692232, 0.6813089979740284, 0.609376618188938], 
             UndirectedEdge[71, 188] -> 
             RGBColor[
              0.33847048120912504`, 0.4675878516274786, 0.9427880176583188], 
             UndirectedEdge[14, 106] -> 
             RGBColor[
              0.1821436488572793, 0.3087749018963175, 0.9336841833938165], 
             UndirectedEdge[141, 194] -> 
             RGBColor[
              0.2726689215363932, 0.40068025183184497`, 0.9389581857778003], 
             UndirectedEdge[50, 105] -> 
             RGBColor[
              0.2047516184167667, 0.33253731133139974`, 0.9349716738147356], 
             UndirectedEdge[98, 125] -> 
             RGBColor[
              0.22839213728314284`, 0.35738499555542924`, 0.936317966391162], 
             UndirectedEdge[118, 119] -> 
             RGBColor[
              0.6948397253680805, 0.41161030980348123`, 0.44369144326806464`],
              UndirectedEdge[137, 166] -> 
             RGBColor[
              0.5638108664902101, 0.6507798896827761, 0.9614655012997908], 
             UndirectedEdge[6, 112] -> 
             RGBColor[
              0.8680923277857024, 0.48035072449919225`, 0.44650914086853377`],
              UndirectedEdge[65, 119] -> 
             RGBColor[
              0.8833301033443486, 0.5287471178897909, 0.2232772137600259], 
             UndirectedEdge[170, 183] -> 
             RGBColor[
              0.7957960380795266, 0.7580319632271744, 0.6169700142026149], 
             UndirectedEdge[14, 131] -> 
             RGBColor[
              0.18037616802655143`, 0.3069171674784653, 0.9335835279752602], 
             UndirectedEdge[9, 164] -> 
             RGBColor[
              0.1942433345387914, 0.32149243871196825`, 0.9343732425934977], 
             UndirectedEdge[96, 170] -> 
             RGBColor[
              0.7958122133360686, 0.8413363954975833, 0.9793915982124253], 
             UndirectedEdge[117, 178] -> 
             RGBColor[
              0.18448507974982858`, 0.3112358942196798, 0.9338175244193107], 
             UndirectedEdge[18, 24] -> 
             RGBColor[
              0.24010747998138166`, 0.3696985635269072, 0.9369851378265305], 
             UndirectedEdge[18, 133] -> 
             RGBColor[
              0.2360954570926359, 0.3654816730938921, 0.9367566590582723], 
             UndirectedEdge[49, 129] -> 
             RGBColor[
              0.4384127064842775, 0.5541214790792388, 0.9491648974977769], 
             UndirectedEdge[124, 198] -> 
             RGBColor[
              0.28583038245095216`, 0.4143466579357906, 0.9397138307273181], 
             UndirectedEdge[113, 124] -> 
             RGBColor[
              0.2152453236447654, 0.343566860865366, 0.9355692748034243], 
             UndirectedEdge[176, 188] -> 
             RGBColor[
              0.2736450723955902, 0.4045366798776089, 0.9389101401590136], 
             UndirectedEdge[37, 97] -> 
             RGBColor[
              0.22632286746697683`, 0.35521006177935477`, 0.9362001245363418],
              UndirectedEdge[77, 143] -> 
             RGBColor[
              0.8301002219971707, 0.3853333999300143, 0.43817702100433054`], 
             UndirectedEdge[79, 84] -> 
             RGBColor[
              0.1877064038111327, 0.31462171005185247`, 0.93400097405908], 
             UndirectedEdge[151, 199] -> 
             RGBColor[
              0.9945819459025071, 0.992027509640117, 0.7394547080773856], 
             UndirectedEdge[48, 87] -> 
             RGBColor[
              0.21359836729039067`, 0.3418358053138541, 0.9354754830754963], 
             UndirectedEdge[27, 30] -> 
             RGBColor[
              0.2380433427297828, 0.3675290244016161, 0.9368675882636692], 
             UndirectedEdge[5, 87] -> 
             RGBColor[
              0.28551854391053016`, 0.41321354140814925`, 0.9397255599553038],
              UndirectedEdge[68, 81] -> 
             RGBColor[
              0.6335105972347094, 0.659531932623991, 0.6218491817852485], 
             UndirectedEdge[155, 172] -> 
             RGBColor[
              0.77126540629573, 0.6221045625124598, 0.590374002869697], 
             UndirectedEdge[143, 188] -> 
             RGBColor[
              0.5844325062491007, 0.6667240315758246, 0.9636365087359027], 
             UndirectedEdge[102, 180] -> 
             RGBColor[
              0.6556042618622065, 0.7236026240031248, 0.9400383889234916], 
             UndirectedEdge[80, 136] -> 
             RGBColor[
              0.2223027051927452, 0.3509846163361272, 0.9359711822421215], 
             UndirectedEdge[66, 78] -> 
             RGBColor[
              0.18323872675967784`, 0.30992589820368766`, 0.9337465464603355],
              UndirectedEdge[50, 101] -> 
             RGBColor[
              0.19997052243961871`, 0.3275120763204238, 0.9346993974718347], 
             UndirectedEdge[41, 85] -> 
             RGBColor[
              0.2805891206818358, 0.4122473345873495, 0.9392905073772007], 
             UndirectedEdge[5, 30] -> 
             RGBColor[
              0.28195013969393246`, 0.40946292232661013`, 0.9395223446141496],
              UndirectedEdge[32, 133] -> 
             RGBColor[
              0.21756503028546625`, 0.3460050196226384, 0.9357013786649139], 
             UndirectedEdge[159, 161] -> 
             RGBColor[
              0.2693600530686908, 0.4004448725619264, 0.938651028588549], 
             UndirectedEdge[3, 195] -> 
             RGBColor[
              0.4598624133064091, 0.5714358988511051, 0.9508809666262504], 
             UndirectedEdge[173, 180] -> 
             RGBColor[
              0.35489305397250803`, 0.4818122587326137, 0.9438344494728906], 
             UndirectedEdge[129, 141] -> 
             RGBColor[
              0.399143413415432, 0.5201083911550634, 0.9466626928679024], 
             UndirectedEdge[53, 199] -> 
             RGBColor[
              0.8135219538922576, 0.8521286416727499, 0.8461806318478537], 
             UndirectedEdge[88, 95] -> 
             RGBColor[
              0.23288032783126497`, 0.3621023683892223, 0.9365735622031948], 
             UndirectedEdge[93, 95] -> 
             RGBColor[
              0.24029230513765162`, 0.36989282648473865`, 0.9369956633457557],
              UndirectedEdge[3, 29] -> 
             RGBColor[
              0.312801857714541, 0.4359396148470296, 0.9414971783112978], 
             UndirectedEdge[52, 125] -> 
             RGBColor[
              0.2249359881773202, 0.35375236371269986`, 0.9361211438124999], 
             UndirectedEdge[82, 136] -> 
             RGBColor[
              0.21738866266974544`, 0.34581964607616317`, 0.935691334790111], 
             UndirectedEdge[116, 193] -> 
             RGBColor[
              0.2350445249483884, 0.36437707677734155`, 0.9366968100273723], 
             UndirectedEdge[19, 159] -> 
             RGBColor[
              0.30305438553170616`, 0.43193305004791277`, 0.9407136467817967],
              UndirectedEdge[77, 99] -> 
             RGBColor[
              0.7288195657946002, 0.3050953090773723, 0.4287654977217741], 
             UndirectedEdge[53, 196] -> 
             RGBColor[
              0.43238466744803844`, 0.5370813339950793, 0.9503675109966372], 
             UndirectedEdge[58, 137] -> 
             RGBColor[
              0.6422345288762541, 0.7125398822624958, 0.9467383481519487], 
             UndirectedEdge[159, 200] -> 
             RGBColor[
              0.22275289923247676`, 0.35145779881583583`, 0.9359968201266817],
              UndirectedEdge[3, 62] -> 
             RGBColor[
              0.30929718741563983`, 0.43225598415395333`, 0.9412975925224704],
              UndirectedEdge[48, 157] -> 
             RGBColor[
              0.20845932601251194`, 0.33643434709676723`, 0.9351828222772515],
              UndirectedEdge[130, 168] -> 
             RGBColor[
              0.19684636692721422`, 0.32422839079398647`, 0.9345214814371772],
              UndirectedEdge[140, 180] -> 
             RGBColor[
              0.6678780579649132, 0.7298281943728316, 0.7506032971167013], 
             UndirectedEdge[146, 171] -> 
             RGBColor[
              0.27657700131279794`, 0.4080303427474302, 0.9390620231145327], 
             UndirectedEdge[26, 100] -> 
             RGBColor[
              0.24928654570499661`, 0.3793463435888073, 0.9375078720402794], 
             UndirectedEdge[45, 153] -> 
             RGBColor[
              0.49664985237205533`, 0.594095769360721, 0.9556096261521655], 
             UndirectedEdge[165, 177] -> 
             RGBColor[
              0.2115965510366421, 0.3397317695086831, 0.9353614826012671], 
             UndirectedEdge[123, 139] -> 
             RGBColor[
              0.36839624794676656`, 0.4913743375109727, 0.9447729865968078], 
             UndirectedEdge[13, 34] -> 
             RGBColor[
              0.32558157650060693`, 0.44832121227099686`, 0.9422634355654279],
              UndirectedEdge[48, 72] -> 
             RGBColor[
              0.23184751916348642`, 0.3610168209955353, 0.9365147452774683], 
             UndirectedEdge[127, 191] -> 
             RGBColor[
              0.8424455031847746, 0.8772870526462687, 0.9848132059143445], 
             UndirectedEdge[58, 125] -> 
             RGBColor[
              0.6124298936125201, 0.6826137072843086, 0.9449897432593624], 
             UndirectedEdge[165, 169] -> 
             RGBColor[
              0.1989480925621131, 0.32643743769336697`, 0.9346411716028602], 
             UndirectedEdge[119, 156] -> 
             RGBColor[
              0.8374564716001813, 0.28891243101531533`, 0.18350166554635475`],
              UndirectedEdge[139, 191] -> 
             RGBColor[
              0.5478858450843187, 0.6345820068720615, 0.9606434803219044], 
             UndirectedEdge[48, 81] -> 
             RGBColor[
              0.2582618049415859, 0.3887799101107659, 0.938018999776097], 
             UndirectedEdge[85, 161] -> 
             RGBColor[
              0.2771499717006646, 0.408632570953499, 0.939094652930488], 
             UndirectedEdge[30, 106] -> 
             RGBColor[
              0.19729813455436623`, 0.32470322721384515`, 0.9345472089352131],
              UndirectedEdge[118, 195] -> 
             RGBColor[
              0.44594964518515734`, 0.559385358380535, 0.9499944573441421], 
             UndirectedEdge[132, 145] -> 
             RGBColor[
              0.24537934999545682`, 0.37523963316756476`, 0.9372853630247993],
              UndirectedEdge[124, 137] -> 
             RGBColor[
              0.27496483242396785`, 0.4049354646208403, 0.9390214874876273], 
             UndirectedEdge[53, 182] -> 
             RGBColor[
              0.48630804661931654`, 0.5907915717188752, 0.9535469913567178], 
             UndirectedEdge[31, 40] -> 
             RGBColor[
              0.5188959987209247, 0.6203021736168226, 0.9552685402794356], 
             UndirectedEdge[130, 157] -> 
             RGBColor[
              0.19536013163296237`, 0.32266626326696746`, 0.9344368425358576],
              UndirectedEdge[83, 166] -> 
             RGBColor[
              0.8650576677002866, 0.8953688994003288, 0.9869563023793746], 
             UndirectedEdge[76, 176] -> 
             RGBColor[
              0.24916812422626491`, 0.3792218751063049, 0.9375011281122546], 
             UndirectedEdge[100, 113] -> 
             RGBColor[
              0.20512211761839033`, 0.33292672948331237`, 0.9349927731961636],
              UndirectedEdge[53, 118] -> 
             RGBColor[
              0.5113253166726569, 0.612460273634525, 0.9551410696826135], 
             UndirectedEdge[18, 85] -> 
             RGBColor[
              0.24676983740924385`, 0.376701123601449, 0.9373645492259726], 
             UndirectedEdge[90, 177] -> 
             RGBColor[
              0.22233026933066752`, 0.35101358799275084`, 0.9359727519789987],
              UndirectedEdge[55, 165] -> 
             RGBColor[
              0.2708407078314586, 0.3994925742335291, 0.9388272003702323], 
             UndirectedEdge[9, 121] -> 
             RGBColor[
              0.20533326031636837`, 0.3331486538461075, 0.9350047974604558], 
             UndirectedEdge[70, 110] -> 
             RGBColor[
              0.185588460386286, 0.31239561722696946`, 0.9338803603142515], 
             UndirectedEdge[51, 147] -> 
             RGBColor[
              0.2158606236854452, 0.3442135802203963, 0.9356043152304863], 
             UndirectedEdge[81, 188] -> 
             RGBColor[
              0.3096161145085913, 0.44234452583416967`, 0.9409586377929611], 
             UndirectedEdge[63, 132] -> 
             RGBColor[
              0.24611904809652904`, 0.37601710277136, 0.9373274877373701], 
             UndirectedEdge[68, 143] -> 
             RGBColor[
              0.9083269889752188, 0.8839114383656459, 0.6445270527281901], 
             UndirectedEdge[76, 81] -> 
             RGBColor[
              0.28513916633926595`, 0.41702972106286573`, 0.9395496257462019],
              UndirectedEdge[55, 163] -> 
             RGBColor[
              0.3088204539598367, 0.4394116954694417, 0.9409900907262441], 
             UndirectedEdge[86, 94] -> 
             RGBColor[
              0.19625374198187168`, 0.3236055044018397, 0.9344877323232499], 
             UndirectedEdge[3, 167] -> 
             RGBColor[
              0.3090133882504993, 0.4319576932374843, 0.9412814305798589], 
             UndirectedEdge[16, 82] -> 
             RGBColor[
              0.19957038496874147`, 0.32709150646835083`, 0.9346766102348185],
              UndirectedEdge[51, 107] -> 
             RGBColor[
              0.1999147758321102, 0.3274534831013933, 0.9346962227850067], 
             UndirectedEdge[53, 171] -> 
             RGBColor[
              0.4697666933739579, 0.5763722134005581, 0.9524963620713668], 
             UndirectedEdge[78, 82] -> 
             RGBColor[
              0.1974481944602994, 0.3248609496893285, 0.9345557546248622], 
             UndirectedEdge[92, 186] -> 
             RGBColor[
              0.21375750066891208`, 0.34200306458431906`, 0.9354845454859864],
              UndirectedEdge[75, 118] -> 
             RGBColor[
              0.44650486801296785`, 0.559836113284655, 0.9500381665189955], 
             UndirectedEdge[77, 83] -> 
             RGBColor[
              0.8536746611219712, 0.4041310177770272, 0.4404255720532042], 
             UndirectedEdge[42, 176] -> 
             RGBColor[
              0.21842899524564835`, 0.34691310157433214`, 0.9357505801912747],
              UndirectedEdge[20, 144] -> 
             RGBColor[
              0.19040607844928842`, 0.31745923926581243`, 0.9341547165359123],
              UndirectedEdge[26, 98] -> 
             RGBColor[
              0.24264169185428053`, 0.372362180883637, 0.9371294574436615], 
             UndirectedEdge[16, 84] -> 
             RGBColor[
              0.1842053187530256, 0.3109418476741682, 0.933801592444412], 
             UndirectedEdge[55, 175] -> 
             RGBColor[
              0.4182247539712943, 0.5353839569381427, 0.9482243963930945], 
             UndirectedEdge[113, 128] -> 
             RGBColor[
              0.3178799957707601, 0.44011084120794086`, 0.9418290717409573], 
             UndirectedEdge[142, 147] -> 
             RGBColor[
              0.25576128412159904`, 0.3861517041867828, 0.9378765988145878], 
             UndirectedEdge[10, 42] -> 
             RGBColor[
              0.2103603093846907, 0.3384324011502344, 0.9352910804680441], 
             UndirectedEdge[98, 120] -> 
             RGBColor[
              0.19321962278041294`, 0.32041645274683817`, 0.9343149437233039],
              UndirectedEdge[195, 199] -> 
             RGBColor[
              0.748146282404758, 0.7990537264187598, 0.8410340195093824], 
             UndirectedEdge[49, 195] -> 
             RGBColor[
              0.46169316726810605`, 0.5730216059163575, 0.9509976206498176], 
             UndirectedEdge[25, 43] -> 
             RGBColor[
              0.1846430806166806, 0.3114019631485748, 0.9338265223349365], 
             UndirectedEdge[91, 121] -> 
             RGBColor[
              0.2017936925772753, 0.329428343730764, 0.9348032243140356], 
             UndirectedEdge[8, 21] -> 
             RGBColor[
              0.3222839501803989, 0.4512119268537823, 0.9418428896396724], 
             UndirectedEdge[2, 124] -> 
             RGBColor[
              0.20420540017012767`, 0.331963201321945, 0.9349405674936471], 
             UndirectedEdge[80, 125] -> 
             RGBColor[
              0.243038153837541, 0.3727788875651853, 0.9371520353670952], 
             UndirectedEdge[33, 180] -> 
             RGBColor[
              0.6673282092975037, 0.7309455392481101, 0.857462764837877], 
             UndirectedEdge[5, 155] -> 
             RGBColor[
              0.513762074533002, 0.612974284551854, 0.9559298924776924], 
             UndirectedEdge[179, 192] -> 
             RGBColor[
              0.41712722923071616`, 0.5353797878648794, 0.9478929556641686], 
             UndirectedEdge[59, 146] -> 
             RGBColor[
              0.21481341413912597`, 0.34311289659029465`, 0.935544678196031], 
             UndirectedEdge[3, 68] -> 
             RGBColor[
              0.6898421419054424, 0.7085746089319662, 0.625429383133753], 
             UndirectedEdge[131, 157] -> 
             RGBColor[
              0.19396001666235732`, 0.3211946536604452, 0.9343571080595661], 
             UndirectedEdge[85, 200] -> 
             RGBColor[
              0.23054281786445055`, 0.35964549720740835`, 0.9364404444686207],
              UndirectedEdge[23, 38] -> 
             RGBColor[
              0.20238106508142, 0.3300457094741879, 0.9348366743092069], 
             UndirectedEdge[92, 191] -> 
             RGBColor[
              0.5272753016690297, 0.6129190189586639, 0.9594697403649703], 
             UndirectedEdge[97, 153] -> 
             RGBColor[
              0.24952804077433757`, 0.37960017021835646`, 0.9375216248272185],
              UndirectedEdge[95, 161] -> 
             RGBColor[
              0.26651291559129975`, 0.397452350554246, 0.9384888883211739], 
             UndirectedEdge[139, 196] -> 
             RGBColor[
              0.25932712065835106`, 0.3898996244740037, 0.9380796679301735], 
             UndirectedEdge[1, 94] -> 
             RGBColor[
              0.18516334977200538`, 0.3119487990177908, 0.933856150893663], 
             UndirectedEdge[189, 194] -> 
             RGBColor[
              0.19797673225113377`, 0.32541647641872684`, 0.9345858540701487],
              UndirectedEdge[42, 76] -> 
             RGBColor[
              0.23350932118742207`, 0.36276348028702554`, 0.9366093824443157],
              UndirectedEdge[84, 190] -> 
             RGBColor[
              0.18271061576572617`, 0.30937082006487343`, 0.9337164713205002],
              UndirectedEdge[37, 134] -> 
             RGBColor[
              0.24135977409579584`, 0.37101480404118925`, 0.9370564541237432],
              UndirectedEdge[140, 161] -> 
             RGBColor[
              0.6387756152014612, 0.7023172809495201, 0.7488332700746612], 
             UndirectedEdge[10, 51] -> 
             RGBColor[
              0.20007349461539067`, 0.32762030660597313`, 0.9347052615849112],
              UndirectedEdge[146, 191] -> 
             RGBColor[
              0.527753699812846, 0.6134218457400091, 0.9594969844315341], 
             UndirectedEdge[21, 175] -> 
             RGBColor[
              0.43093748007980026`, 0.5463950813331377, 0.9490344400593063], 
             UndirectedEdge[49, 141] -> 
             RGBColor[
              0.3830851867065078, 0.5062308671290127, 0.9456308272413769], 
             UndirectedEdge[111, 177] -> 
             RGBColor[
              0.21876304030867405`, 0.3472642041152524, 0.9357696035634386], 
             UndirectedEdge[69, 191] -> 
             RGBColor[
              0.5299588162079603, 0.6157395628837288, 0.9596225625480584], 
             UndirectedEdge[111, 175] -> 
             RGBColor[
              0.36035371764762536`, 0.477066388889339, 0.9448368758036116], 
             UndirectedEdge[77, 170] -> 
             RGBColor[
              0.7632819896613426, 0.3329422374087012, 0.4315682217159619], 
             UndirectedEdge[104, 154] -> 
             RGBColor[
              0.3494855423442635, 0.47712854394966536`, 0.9434898876136137], 
             UndirectedEdge[13, 138] -> 
             RGBColor[
              0.2214898027052646, 0.35013020428079056`, 0.9359248886480409], 
             UndirectedEdge[21, 67] -> 
             RGBColor[
              0.30859689738128643`, 0.43682596655264533`, 0.9410634322309431],
              UndirectedEdge[73, 197] -> 
             RGBColor[
              0.20909257444253643`, 0.33709993134699245`, 0.9352188848385342],
              UndirectedEdge[67, 192] -> 
             RGBColor[
              0.36080214724091136`, 0.4817069445731053, 0.944482904164054], 
             UndirectedEdge[37, 101] -> 
             RGBColor[
              0.21602037207300215`, 0.3443814859043514, 0.9356134126648311], 
             UndirectedEdge[6, 44] -> 
             RGBColor[
              0.8538799874745917, 0.37282166416447404`, 0.1975713412337775], 
             UndirectedEdge[75, 89] -> 
             RGBColor[
              0.3848285553772075, 0.5026030860222612, 0.9462477862614576], 
             UndirectedEdge[76, 188] -> 
             RGBColor[
              0.288725398337364, 0.42038705859030223`, 0.9397689424120548], 
             UndirectedEdge[42, 71] -> 
             RGBColor[
              0.2832544040591832, 0.40996427332420193`, 0.9396284576905798], 
             UndirectedEdge[6, 192] -> 
             RGBColor[
              0.7095267480527575, 0.35411800374375885`, 0.4355163647005046], 
             UndirectedEdge[2, 100] -> 
             RGBColor[
              0.19408219414375266`, 0.32132306993989135`, 0.9343640658863862],
              UndirectedEdge[7, 8] -> 
             RGBColor[
              0.24587927343278695`, 0.3757650843971754, 0.9373138329249848], 
             UndirectedEdge[69, 92] -> 
             RGBColor[
              0.2471305318648358, 0.3770802363436254, 0.937385090241619], 
             UndirectedEdge[104, 160] -> 
             RGBColor[
              0.4051454853105788, 0.5253383889970118, 0.9470364899612722], 
             UndirectedEdge[17, 30] -> 
             RGBColor[
              0.20051771286008008`, 0.3280872081462052, 0.9347305591567843], 
             UndirectedEdge[88, 164] -> 
             RGBColor[
              0.20586798703479003`, 0.3337106855308008, 0.9350352493560126], 
             UndirectedEdge[43, 60] -> 
             RGBColor[
              0.18536402715025152`, 0.3121597236660082, 0.9338675791734785], 
             UndirectedEdge[149, 197] -> 
             RGBColor[
              0.19310487903170026`, 0.3202958497917673, 0.934308409236563], 
             UndirectedEdge[167, 197] -> 
             RGBColor[
              0.20001986015557813`, 0.327563933388089, 0.9347022071817699], 
             UndirectedEdge[54, 127] -> 
             RGBColor[
              0.9315900923682865, 0.9377519849577597, 0.6986638549616266], 
             UndirectedEdge[107, 147] -> 
             RGBColor[
              0.23357883684934996`, 0.36283654565525925`, 0.9366133412584232],
              UndirectedEdge[78, 113] -> 
             RGBColor[
              0.19369232004858233`, 0.320913287546422, 0.9343418631334333], 
             UndirectedEdge[81, 87] -> 
             RGBColor[
              0.261366444859298, 0.3920430835098213, 0.9381958044265076], 
             UndirectedEdge[83, 179] -> 
             RGBColor[
              0.6474631282319623, 0.7188859236705143, 0.9687723771837091], 
             UndirectedEdge[82, 198] -> 
             RGBColor[
              0.2787942966052594, 0.4069512855983587, 0.9393131360473621], 
             UndirectedEdge[30, 107] -> 
             RGBColor[
              0.21359959388546113`, 0.3418370945430438, 0.935475552928271], 
             UndirectedEdge[47, 134] -> 
             RGBColor[
              0.22156708062371444`, 0.3502114282727843, 0.9359292895111742], 
             UndirectedEdge[5, 142] -> 
             RGBColor[
              0.3081659820767354, 0.43701743485134614`, 0.9410152980549868], 
             UndirectedEdge[169, 190] -> 
             RGBColor[
              0.18813962732028144`, 0.31507705542792475`, 0.9340256454970293],
              UndirectedEdge[121, 152] -> 
             RGBColor[
              0.20876932330272832`, 0.33676017390374813`, 0.9352004761643293],
              UndirectedEdge[31, 64] -> 
             RGBColor[
              0.5807463788000884, 0.6705150984929575, 0.9601376287646749], 
             UndirectedEdge[105, 134] -> 
             RGBColor[
              0.22631486646654955`, 0.35520165222061295`, 0.936199668891204], 
             UndirectedEdge[83, 192] -> 
             RGBColor[
              0.6960500843646674, 0.7606329175254469, 0.9719612946400722], 
             UndirectedEdge[77, 112] -> 
             RGBColor[
              0.8586829748540853, 0.4080263146620374, 0.43749873387487304`], 
             UndirectedEdge[195, 196] -> 
             RGBColor[
              0.3670089959605389, 0.4840064187410893, 0.9452208986581658], 
             UndirectedEdge[92, 171] -> 
             RGBColor[
              0.2760986031689815, 0.40752751596608494`, 0.939034779047969], 
             UndirectedEdge[166, 183] -> 
             RGBColor[
              0.8700567296048425, 0.8160449798489104, 0.6243716259282402], 
             UndirectedEdge[139, 195] -> 
             RGBColor[
              0.39334997945867106`, 0.5116924625124413, 0.9467209787003914], 
             UndirectedEdge[177, 190] -> 
             RGBColor[
              0.20078808579481044`, 0.3283713872432409, 0.9347459564954362], 
             UndirectedEdge[29, 149] -> 
             RGBColor[
              0.19620729298920309`, 0.32355668356550876`, 0.9344850871218325],
              UndirectedEdge[119, 155] -> 
             RGBColor[
              0.7889472696492774, 0.4888266448097398, 0.4510028591049925], 
             UndirectedEdge[12, 162] -> 
             RGBColor[
              0.7007570533940699, 0.7026453313085301, 0.614346873451971], 
             UndirectedEdge[85, 173] -> 
             RGBColor[
              0.31911259241838086`, 0.4472823241494562, 0.941684119139965], 
             UndirectedEdge[92, 141] -> 
             RGBColor[
              0.29413145548178377`, 0.42323873581169885`, 0.9401804453350167],
              UndirectedEdge[5, 29] -> 
             RGBColor[
              0.28062241209504013`, 0.4080673964373824, 0.9394467324915896], 
             UndirectedEdge[51, 87] -> 
             RGBColor[
              0.19944978493815407`, 0.3269647481897199, 0.9346697422414884], 
             UndirectedEdge[145, 153] -> 
             RGBColor[
              0.2362249636187789, 0.3656177926640565, 0.9367640342633485], 
             UndirectedEdge[118, 191] -> 
             RGBColor[
              0.6004855108108049, 0.6822749027401551, 0.9639169589656551], 
             UndirectedEdge[117, 164] -> 
             RGBColor[
              0.19024796848068162`, 0.3172930556640557, 0.9341457124071029], 
             UndirectedEdge[145, 185] -> 
             RGBColor[
              0.2111217144827195, 0.33923268618413416`, 0.935334441361979], 
             UndirectedEdge[99, 137] -> 
             RGBColor[
              0.4378565391647805, 0.5509964805640466, 0.9498598035828838], 
             UndirectedEdge[48, 176] -> 
             RGBColor[
              0.2222907628285849, 0.3509720641542051, 0.9359705021421497], 
             UndirectedEdge[50, 144] -> 
             RGBColor[
              0.20111766579178803`, 0.32871779671664314`, 0.9347647255886942],
              UndirectedEdge[3, 53] -> 
             RGBColor[
              0.5252380847939087, 0.6245108141050952, 0.9560275789647218], 
             UndirectedEdge[169, 177] -> 
             RGBColor[
              0.20474146136299756`, 0.33252663562389395`, 0.9349710953855495],
              UndirectedEdge[20, 135] -> 
             RGBColor[
              0.18962988067563263`, 0.3166434061919189, 0.9341105132209843], 
             UndirectedEdge[166, 170] -> 
             RGBColor[
              0.7294686605093437, 0.78858572884784, 0.973670276873511], 
             UndirectedEdge[17, 42] -> 
             RGBColor[
              0.1971197095760292, 0.3245156912488159, 0.9345370478966529], 
             UndirectedEdge[129, 195] -> 
             RGBColor[
              0.47775139397703026`, 0.5868991299424082, 0.952029486276343], 
             UndirectedEdge[74, 93] -> 
             RGBColor[
              0.28865865838495014`, 0.4172909648985178, 0.9398759363681078], 
             UndirectedEdge[37, 45] -> 
             RGBColor[
              0.47344467906469456`, 0.5697056609217193, 0.9542881258612889], 
             UndirectedEdge[49, 92] -> 
             RGBColor[
              0.33340074855062923`, 0.45725182373587436`, 0.9426826499648912],
              UndirectedEdge[163, 177] -> 
             RGBColor[
              0.24957629716502022`, 0.3796508907445958, 0.937524372957279], 
             UndirectedEdge[6, 45] -> 
             RGBColor[
              0.7913030137482814, 0.4198062262063331, 0.4424336661544295], 
             UndirectedEdge[6, 166] -> 
             RGBColor[
              0.8221984702765036, 0.44394199166034687`, 0.44551303652670615`],
              UndirectedEdge[65, 127] -> 
             RGBColor[
              0.9155629949478274, 0.8836888220171212, 0.6364016079465316], 
             UndirectedEdge[15, 59] -> 
             RGBColor[
              0.18157500733235693`, 0.30817722359966904`, 0.9336518001002019],
              UndirectedEdge[100, 136] -> 
             RGBColor[
              0.21430154248906313`, 0.3425748870315415, 0.9355155278628062], 
             UndirectedEdge[83, 183] -> 
             RGBColor[
              0.9313850452704695, 0.8648151337796632, 0.6302560397084783], 
             UndirectedEdge[53, 119] -> 
             RGBColor[
              0.7751449794102145, 0.4779361855721358, 0.4497010195498735], 
             UndirectedEdge[5, 68] -> 
             RGBColor[
              0.6576626962859415, 0.680702390522319, 0.6233789373140448], 
             UndirectedEdge[49, 54] -> 
             RGBColor[
              0.7053736220772657, 0.7563760825874686, 0.6787707713186126], 
             UndirectedEdge[153, 185] -> 
             RGBColor[
              0.2571534731580585, 0.38761498313398474`, 0.937955881920655], 
             UndirectedEdge[101, 144] -> 
             RGBColor[
              0.19734151181877715`, 0.32474881946901846`, 0.9345496792062504],
              UndirectedEdge[19, 102] -> 
             RGBColor[
              0.6601961515617699, 0.7275798880657995, 0.9403309800746991], 
             UndirectedEdge[102, 172] -> 
             RGBColor[
              0.9192581959222914, 0.7380602445354411, 0.5748744102551196], 
             UndirectedEdge[102, 140] -> 
             RGBColor[
              0.981449443808876, 0.9827573994159884, 0.747626675734739], 
             UndirectedEdge[71, 107] -> 
             RGBColor[
              0.2906858024537879, 0.41777514421480366`, 0.9400516648353837], 
             UndirectedEdge[5, 168] -> 
             RGBColor[
              0.2818657379269033, 0.4093742107180814, 0.9395175380583785], 
             UndirectedEdge[79, 122] -> 
             RGBColor[
              0.2360507899414387, 0.3654347250859229, 0.9367541153300909], 
             UndirectedEdge[136, 198] -> 
             RGBColor[
              0.2842178470642151, 0.4126517810036814, 0.9396219992225757], 
             UndirectedEdge[97, 135] -> 
             RGBColor[
              0.20686780943909605`, 0.33476156227012827`, 0.9350921877628332],
              UndirectedEdge[19, 164] -> 
             RGBColor[
              0.2731949072578401, 0.40054884518181094`, 0.9390131936672395], 
             UndirectedEdge[118, 139] -> 
             RGBColor[
              0.33826776988296947`, 0.4652785641134494, 0.9428532266161497], 
             UndirectedEdge[26, 137] -> 
             RGBColor[
              0.3083373002531643, 0.4400120442459969, 0.9409220001603581], 
             UndirectedEdge[142, 168] -> 
             RGBColor[
              0.23569763939068106`, 0.3650635414660385, 0.9367340039286646], 
             UndirectedEdge[3, 194] -> 
             RGBColor[
              0.3101074606435417, 0.43310763269076813`, 0.9413437363841075], 
             UndirectedEdge[65, 195] -> 
             RGBColor[
              0.7286852121495595, 0.7350905705099995, 0.6193731130820839], 
             UndirectedEdge[73, 107] -> 
             RGBColor[
              0.21755611110948542`, 0.34599564500317415`, 0.9357008707310365],
              UndirectedEdge[162, 172] -> 
             RGBColor[
              0.6603763668123606, 0.5325003847582571, 0.5813358018320983], 
             UndirectedEdge[68, 140] -> 
             RGBColor[
              0.977357275935254, 0.934529823363472, 0.4305753131856688], 
             UndirectedEdge[38, 165] -> 
             RGBColor[
              0.19346381204820906`, 0.3206731111497857, 0.9343288499408593], 
             UndirectedEdge[86, 92] -> 
             RGBColor[
              0.22327186579105107`, 0.35200326557327766`, 0.9360263745044504],
              UndirectedEdge[90, 115] -> 
             RGBColor[
              0.27114794471103404`, 0.4017434985665935, 0.9387741035720105], 
             UndirectedEdge[11, 70] -> 
             RGBColor[
              0.19700340773557554`, 0.3243934506405365, 0.9345304246788922], 
             UndirectedEdge[54, 123] -> 
             RGBColor[
              0.7197585780581139, 0.7688356084491694, 0.6796873679935951], 
             UndirectedEdge[107, 176] -> 
             RGBColor[
              0.22586039364025307`, 0.35472397246493387`, 0.9361737873360787],
              UndirectedEdge[30, 76] -> 
             RGBColor[
              0.23690732447147297`, 0.36633499718441476`, 0.936802893704447], 
             UndirectedEdge[129, 191] -> 
             RGBColor[
              0.632287259602678, 0.7097886743020284, 0.965951987897856], 
             UndirectedEdge[7, 125] -> 
             RGBColor[
              0.2363887212836201, 0.36578991235264013`, 0.9367733600201034], 
             UndirectedEdge[3, 155] -> 
             RGBColor[
              0.545941520152503, 0.6408465029615011, 0.9579803382974005], 
             UndirectedEdge[54, 118] -> 
             RGBColor[
              0.6896300999943169, 0.7427398350516461, 0.6777676080129371], 
             UndirectedEdge[4, 171] -> 
             RGBColor[
              0.3210288697535419, 0.4523887348957585, 0.9416800247158792], 
             UndirectedEdge[167, 189] -> 
             RGBColor[
              0.19688265985809134`, 0.32426653696544305`, 0.9345235482659], 
             UndirectedEdge[42, 81] -> 
             RGBColor[
              0.25440003735864936`, 0.3847209475308929, 0.9377990778252221], 
             UndirectedEdge[5, 129] -> 
             RGBColor[
              0.40440250690307966`, 0.5246635536043394, 0.9469977976545015], 
             UndirectedEdge[115, 133] -> 
             RGBColor[
              0.2820742314375166, 0.41322771868271746`, 0.939396339437091], 
             UndirectedEdge[92, 146] -> 
             RGBColor[
              0.24492541546972163`, 0.3747625191999059, 0.9372595121250946], 
             UndirectedEdge[65, 151] -> 
             RGBColor[
              0.9751208756473086, 0.9280643537313567, 0.5177938016500871], 
             UndirectedEdge[45, 156] -> 
             RGBColor[
              0.7828261103538363, 0.35464903211387533`, 0.43431617389061594`],
              UndirectedEdge[74, 172] -> 
             RGBColor[
              0.607635645662135, 0.48681902292365303`, 0.5779752097171944], 
             UndirectedEdge[31, 138] -> 
             RGBColor[
              0.3769176966090809, 0.4907215889641815, 0.9461219362207016], 
             UndirectedEdge[116, 198] -> 
             RGBColor[
              0.29312560612523564`, 0.42201440056135886`, 0.9401292829232522],
              UndirectedEdge[42, 142] -> 
             RGBColor[
              0.23238403787365935`, 0.361580736177178, 0.9365452992243044], 
             UndirectedEdge[10, 129] -> 
             RGBColor[
              0.3362106798778888, 0.4572045493253528, 0.9429600447685274], 
             UndirectedEdge[3, 141] -> 
             RGBColor[
              0.38125443274481086`, 0.5046451600637603, 0.9455141732178098], 
             UndirectedEdge[161, 162] -> 
             RGBColor[
              0.3676199899888237, 0.4905318508026293, 0.94472975345843], 
             UndirectedEdge[6, 77] -> 
             RGBColor[
              0.8267283529316172, 0.20645140983715485`, 0.1732284069936607], 
             UndirectedEdge[98, 113] -> 
             RGBColor[
              0.19847726376767427`, 0.32594256677814204`, 0.9346143585995457],
              UndirectedEdge[3, 139] -> 
             RGBColor[
              0.3521805380042213, 0.47732910458401956`, 0.943739735898258], 
             UndirectedEdge[34, 138] -> 
             RGBColor[
              0.32596539118379714`, 0.4487246258382862, 0.9422852932438326], 
             UndirectedEdge[22, 72] -> 
             RGBColor[
              0.22084536933385682`, 0.34945286394800523`, 0.935888189120893], 
             UndirectedEdge[34, 40] -> 
             RGBColor[
              0.4679436932956409, 0.5783052104909272, 0.9514318973025666], 
             UndirectedEdge[41, 74] -> 
             RGBColor[
              0.31831841781976944`, 0.44846525260187575`, 0.9415650157902389],
              UndirectedEdge[141, 146] -> 
             RGBColor[
              0.2946098536256002, 0.4237415625930442, 0.9402076894015805], 
             UndirectedEdge[90, 111] -> 
             RGBColor[
              0.22370338980181498`, 0.3524568246687931, 0.9360509491584807], 
             UndirectedEdge[66, 82] -> 
             RGBColor[
              0.1977556445101682, 0.32518409918519964`, 0.9345732634503707], 
             UndirectedEdge[119, 151] -> 
             RGBColor[
              0.895851640750381, 0.5712020975503805, 0.3785504037028946], 
             UndirectedEdge[4, 139] -> 
             RGBColor[
              0.30998782732575464`, 0.44078389926163164`, 0.9410512536833753],
              UndirectedEdge[165, 175] -> 
             RGBColor[
              0.35318722837559335`, 0.4695339542827697, 0.9444287548414402], 
             UndirectedEdge[127, 139] -> 
             RGBColor[
              0.5802277622569392, 0.660290714019563, 0.9637494735648391], 
             UndirectedEdge[85, 117] -> 
             RGBColor[
              0.22789736538652144`, 0.3568649589217301, 0.9362897898635989], 
             UndirectedEdge[141, 155] -> 
             RGBColor[
              0.5085029810453545, 0.6084191221025781, 0.9555947876910933], 
             UndirectedEdge[168, 189] -> 
             RGBColor[
              0.2019144551539962, 0.3295552728556873, 0.9348101015641277], 
             UndirectedEdge[24, 175] -> 
             RGBColor[
              0.3788592562848471, 0.49651688331597643`, 0.9458907388525104], 
             UndirectedEdge[106, 176] -> 
             RGBColor[
              0.20955893430915817`, 0.33759010513573523`, 0.9352454433430207],
              UndirectedEdge[40, 53] -> 
             RGBColor[
              0.5688067096740002, 0.6608219372204345, 0.9591976942746201], 
             UndirectedEdge[27, 155] -> 
             RGBColor[
              0.4698552775688525, 0.57104038662686, 0.953275136127212], 
             UndirectedEdge[33, 77] -> 
             RGBColor[
              0.8757538475255878, 0.41982388651208413`, 0.36678217312343336`],
              UndirectedEdge[67, 137] -> 
             RGBColor[
              0.289891245032081, 0.42062407066118745`, 0.9398715246040107], 
             UndirectedEdge[68, 129] -> 
             RGBColor[
              0.7077311225760636, 0.7240378400232692, 0.6265779027838456], 
             UndirectedEdge[137, 192] -> 
             RGBColor[
              0.3948032831545909, 0.5160439078078941, 0.9464704935604884], 
             UndirectedEdge[58, 128] -> 
             RGBColor[
              0.695941652480456, 0.7590582933299347, 0.9501605185766638], 
             UndirectedEdge[55, 90] -> 
             RGBColor[
              0.281574426125484, 0.41077439271759675`, 0.9394384697479637], 
             UndirectedEdge[26, 82] -> 
             RGBColor[
              0.2523736658856789, 0.382591102633429, 0.9376836789675842], 
             UndirectedEdge[43, 165] -> 
             RGBColor[
              0.19777525937960444`, 0.32520471565663167`, 0.9345743804881674],
              UndirectedEdge[123, 199] -> 
             RGBColor[
              0.7231925508928534, 0.7787356014172913, 0.8390860274057987], 
             UndirectedEdge[34, 45] -> 
             RGBColor[
              0.5705500737145661, 0.6605535414680137, 0.960228808821763], 
             UndirectedEdge[133, 178] -> 
             RGBColor[
              0.21638528695668868`, 0.3447650345840459, 0.9356341940276138], 
             UndirectedEdge[29, 189] -> 
             RGBColor[
              0.20067112932213305`, 0.3282484585749883, 0.9347392959973388], 
             UndirectedEdge[91, 164] -> 
             RGBColor[
              0.19070376679969833`, 0.3177721285966248, 0.9341716694470776], 
             UndirectedEdge[116, 124] -> 
             RGBColor[
              0.2333325075764587, 0.3625776379712726, 0.9365993131707435], 
             UndirectedEdge[80, 113] -> 
             RGBColor[
              0.2131232803220724, 0.34133645878789803`, 0.9354484275754789], 
             UndirectedEdge[10, 75] -> 
             RGBColor[
              0.3600463634895279, 0.4765554310665914, 0.9448364770954216], 
             UndirectedEdge[74, 180] -> 
             RGBColor[
              0.34398171160205027`, 0.4723614023913367, 0.9431391883855662], 
             UndirectedEdge[27, 149] -> 
             RGBColor[
              0.2260121645429709, 0.35488349330652136`, 0.9361824304644635], 
             UndirectedEdge[4, 49] -> 
             RGBColor[
              0.37833101513518963`, 0.5021130426655478, 0.9453278956328015], 
             UndirectedEdge[9, 152] -> 
             RGBColor[
              0.19674957296563292`, 0.32412665420327286`, 0.9345159691642588],
              UndirectedEdge[19, 85] -> 
             RGBColor[
              0.31084430416368, 0.44012074843948534`, 0.9411572711237357], 
             UndirectedEdge[189, 197] -> 
             RGBColor[
              0.19756871536463022`, 0.3249876248012469, 0.9345626181120692], 
             UndirectedEdge[69, 195] -> 
             RGBColor[
              0.3754229505823126, 0.4928500185241086, 0.9457000609265455], 
             UndirectedEdge[75, 191] -> 
             RGBColor[
              0.656122943214317, 0.729139556043267, 0.9678284202247502], 
             UndirectedEdge[73, 75] -> 
             RGBColor[
              0.3598107668197179, 0.47630780402892936`, 0.9448230602136101], 
             UndirectedEdge[68, 188] -> 
             RGBColor[
              0.6370968292328074, 0.6628892701514275, 0.6220684984511013], 
             UndirectedEdge[4, 123] -> 
             RGBColor[
              0.39271597111603795`, 0.5145725685272486, 0.946244492307784], 
             UndirectedEdge[7, 84] -> 
             RGBColor[
              0.19486465596415276`, 0.32214548692407674`, 0.9344086259295095],
              UndirectedEdge[171, 195] -> 
             RGBColor[
              0.4043910218864583, 0.5232972981465681, 0.9473497497328954], 
             UndirectedEdge[62, 167] -> 
             RGBColor[
              0.19961760381417978`, 0.3271411364687542, 0.9346792992782123], 
             UndirectedEdge[91, 152] -> 
             RGBColor[
              0.19321000522653986`, 0.3204063440879294, 0.9343143960178388], 
             UndirectedEdge[38, 90] -> 
             RGBColor[
              0.20419753034223448`, 0.33195492963385337`, 0.9349401193185908],
              UndirectedEdge[3, 118] -> 
             RGBColor[
              0.40478020373070756`, 0.5250220004521133, 0.9470132145420087], 
             UndirectedEdge[143, 181] -> 
             RGBColor[
              0.6469177981644729, 0.7208456508308313, 0.967618016283176], 
             UndirectedEdge[20, 50] -> 
             RGBColor[
              0.19303508907013, 0.32022249611721776`, 0.9343044348014965], 
             UndirectedEdge[128, 136] -> 
             RGBColor[
              0.3270594206414329, 0.44975899875617, 0.9423518264076001], 
             UndirectedEdge[19, 161] -> 
             RGBColor[
              0.3175223229543551, 0.44713976959933127`, 0.9415375744146212], 
             UndirectedEdge[19, 140] -> 
             RGBColor[
              0.6724699476644765, 0.7338054584355065, 0.7508958882679089], 
             UndirectedEdge[39, 159] -> 
             RGBColor[
              0.25347717812255377`, 0.3837509639611013, 0.9377465223569743], 
             UndirectedEdge[87, 154] -> 
             RGBColor[
              0.2742869255202454, 0.40348527807603907`, 0.9390098911632051], 
             UndirectedEdge[104, 143] -> 
             RGBColor[
              0.6113814534238254, 0.6900658551251025, 0.9653536718198579], 
             UndirectedEdge[6, 183] -> 
             RGBColor[
              0.8664167219899589, 0.42357281457990315`, 0.20771286141277537`],
              UndirectedEdge[17, 89] -> 
             RGBColor[
              0.229492018641594, 0.35854104059966735`, 0.9363806030073972], 
             UndirectedEdge[131, 176] -> 
             RGBColor[
              0.20779145347843028`, 0.335732370717883, 0.9351447879244643], 
             UndirectedEdge[44, 143] -> 
             RGBColor[
              0.8772182848102179, 0.7604919813860003, 0.611670932866671], 
             UndirectedEdge[140, 173] -> 
             RGBColor[
              0.6807382359191774, 0.7409670341454773, 0.7514227362841381], 
             UndirectedEdge[123, 195] -> 
             RGBColor[
              0.4760781232489544, 0.5854811317780583, 0.9519142173248001], 
             UndirectedEdge[96, 125] -> 
             RGBColor[
              0.600349784053201, 0.6736043813543324, 0.9654382177461185], 
             UndirectedEdge[95, 159] -> 
             RGBColor[
              0.2520449781686508, 0.3822456310028275, 0.9376649606883494], 
             UndirectedEdge[171, 191] -> 
             RGBColor[
              0.558926887512106, 0.6461868425061883, 0.9612722513544084], 
             UndirectedEdge[124, 187] -> 
             RGBColor[
              0.21475919139226923`, 0.3430559050454275, 0.935541590290813], 
             UndirectedEdge[54, 191] -> 
             RGBColor[
              0.899248175195666, 0.9120432778102582, 0.6955578617186919], 
             UndirectedEdge[24, 55] -> 
             RGBColor[
              0.29651273574071235`, 0.4264755032667358, 0.9402891843813024], 
             UndirectedEdge[61, 126] -> 
             RGBColor[
              0.19350305800530745`, 0.3207143611390335, 0.9343310849400568], 
             UndirectedEdge[46, 101] -> 
             RGBColor[
              0.18958670352767176`, 0.3165980242718227, 0.9341080543462827], 
             UndirectedEdge[158, 176] -> 
             RGBColor[
              0.27521608284831744`, 0.40589741017048, 0.9390102435558715], 
             UndirectedEdge[91, 200] -> 
             RGBColor[
              0.18842402865999922`, 0.3153759792680545, 0.9340418417325922], 
             UndirectedEdge[29, 129] -> 
             RGBColor[
              0.33069083838516217`, 0.4514028459383327, 0.9426456979613903], 
             UndirectedEdge[37, 47] -> 
             RGBColor[
              0.21605368220731502`, 0.34441649696749876`, 0.9356153096277022],
              UndirectedEdge[25, 38] -> 
             RGBColor[
              0.18033163328528526`, 0.30687035864172885`, 0.9335809917876283],
              UndirectedEdge[95, 173] -> 
             RGBColor[
              0.308475536309016, 0.4361021037502032, 0.9410783545306509], 
             UndirectedEdge[86, 174] -> 
             RGBColor[
              0.19606494632876875`, 0.3234070682000927, 0.9344769806901039], 
             UndirectedEdge[4, 146] -> 
             RGBColor[
              0.289855682054282, 0.41962373812957937`, 0.9399047577930049], 
             UndirectedEdge[114, 186] -> 
             RGBColor[
              0.18224157379578187`, 0.3088778272154834, 0.9336897600741974], 
             UndirectedEdge[155, 199] -> 
             RGBColor[
              0.8342253892508518, 0.868464330529156, 0.8481333911805324], 
             UndirectedEdge[114, 194] -> 
             RGBColor[
              0.19146855650738448`, 0.3185759710698711, 0.9342152230895253], 
             UndirectedEdge[59, 186] -> 
             RGBColor[
              0.18364549933831636`, 0.3103534419747078, 0.9337697115569229], 
             UndirectedEdge[99, 193] -> 
             RGBColor[
              0.3906410080149175, 0.5027703500949796, 0.9471196739266945], 
             UndirectedEdge[109, 136] -> 
             RGBColor[
              0.22011061631709428`, 0.3486805919413559, 0.935846346023558], 
             UndirectedEdge[50, 134] -> 
             RGBColor[
              0.22530992446241244`, 0.3541453944572617, 0.9361424389307468], 
             UndirectedEdge[112, 183] -> 
             RGBColor[
              0.9388975158686406, 0.8706580791071786, 0.6258657824409817], 
             UndirectedEdge[42, 73] -> 
             RGBColor[
              0.2101247127148807, 0.3381847741125724, 0.9352776635862325], 
             UndirectedEdge[42, 147] -> 
             RGBColor[
              0.22614743845474522`, 0.3550256747646575, 0.9361901341136192], 
             UndirectedEdge[87, 131] -> 
             RGBColor[
              0.19909905794023608`, 0.326596111877532, 0.934649768857811], 
             UndirectedEdge[1, 11] -> 
             RGBColor[
              0.19143609648975546`, 0.318541853533259, 0.9342133745395418], 
             UndirectedEdge[30, 81] -> 
             RGBColor[
              0.2577980406427003, 0.3882924644282822, 0.9379925890853533], 
             UndirectedEdge[154, 188] -> 
             RGBColor[
              0.3225365951695387, 0.45378672040038737`, 0.9417727245296585], 
             UndirectedEdge[83, 156] -> 
             RGBColor[
              0.8546071106591433, 0.41129823352172423`, 0.4413184867830513], 
             UndirectedEdge[5, 107] -> 
             RGBColor[
              0.28598353480448624`, 0.4137022763198226, 0.9397520404988222], 
             UndirectedEdge[93, 180] -> 
             RGBColor[
              0.28670982280114365`, 0.41560298146714914`, 0.9397517582879953],
              UndirectedEdge[10, 17] -> 
             RGBColor[
              0.2047098267539144, 0.3324933856439975, 0.9349692938413614], 
             UndirectedEdge[75, 141] -> 
             RGBColor[
              0.42297909702707115`, 0.5394592728963019, 0.9485391251947967], 
             UndirectedEdge[123, 141] -> 
             RGBColor[
              0.39747014268735614`, 0.5186903929907134, 0.9465474239163595], 
             UndirectedEdge[40, 119] -> 
             RGBColor[
              0.7331606540356427, 0.4438514188607542, 0.44639585966273576`], 
             UndirectedEdge[16, 80] -> 
             RGBColor[
              0.20448442749174123`, 0.3322564767283148, 0.934956457686829], 
             UndirectedEdge[88, 180] -> 
             RGBColor[
              0.279297845494757, 0.4078125233716327, 0.9393296571454344], 
             UndirectedEdge[24, 41] -> 
             RGBColor[
              0.2739267632539736, 0.4052447745128077, 0.9389110959777585], 
             UndirectedEdge[4, 119] -> 
             RGBColor[
              0.6759864303299372, 0.3952805332356027, 0.44249012797954834`], 
             UndirectedEdge[99, 136] -> 
             RGBColor[
              0.3873164552562508, 0.49927603435680146`, 0.9469303455653235], 
             UndirectedEdge[10, 194] -> 
             RGBColor[
              0.20973618799885002`, 0.33777641000213443`, 0.9352555376784253],
              UndirectedEdge[96, 102] -> 
             RGBColor[
              0.9527960526971394, 0.9643159539076722, 0.964788149409247], 
             UndirectedEdge[9, 88] -> 
             RGBColor[
              0.20493816247527158`, 0.3327333809644648, 0.9349822972229003], 
             UndirectedEdge[55, 108] -> 
             RGBColor[
              0.3219524714198415, 0.4532142784379034, 0.9417379396935124], 
             UndirectedEdge[62, 197] -> 
             RGBColor[
              0.20030365932071864`, 0.327862224304558, 0.9347183691243814], 
             UndirectedEdge[147, 168] -> 
             RGBColor[
              0.22946103997176695`, 0.35850848005351804`, 0.9363788388179795],
              UndirectedEdge[51, 106] -> 
             RGBColor[
              0.1836133165010153, 0.31031961577219463`, 0.9337678787919488], 
             UndirectedEdge[123, 155] -> 
             RGBColor[
              0.5621572300950483, 0.6548917358884543, 0.9590135889959501], 
             UndirectedEdge[75, 142] -> 
             RGBColor[
              0.3820700919784965, 0.49970376609353495`, 0.9460906958516819], 
             UndirectedEdge[31, 182] -> 
             RGBColor[
              0.43639733566624106`, 0.5502718081152633, 0.9496178373615334], 
             UndirectedEdge[65, 140] -> 
             RGBColor[
              0.9750309047249213, 0.9266824270130837, 0.4215378003318664]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 71 -> 
             RGBColor[
              0.3637386159115608, 0.4894738398933511, 0.9443980808578237], 10 -> 
             RGBColor[
              0.2179504265625759, 0.34641009554541596`, 0.9357233264127526], 
             68 -> RGBColor[
              0.9609913119589255, 0.8800766769412489, 0.30295904244338884`], 
             155 -> RGBColor[
              0.6731900684530466, 0.744620465000319, 0.9680609527706839], 132 -> 
             RGBColor[
              0.30056549504747376`, 0.4332437706209237, 0.9404281323449262], 
             26 -> RGBColor[
              0.2927822195605681, 0.4250630545960175, 0.9399848863202711], 29 -> 
             RGBColor[
              0.20691074357712266`, 0.33480668877137576`, 0.9350946327984784],
              113 -> RGBColor[
              0.20445336338735556`, 0.33222382638502757`, 0.9349546886320393],
              50 -> RGBColor[
              0.20374667641262958`, 0.33148105356804847`, 0.9349144438542785],
              173 -> RGBColor[
              0.36775323192677223`, 0.4929510985052593, 0.9446538886403275], 
             192 -> RGBColor[
              0.46571418536342124`, 0.577126781719812, 0.9510818731205317], 
             165 -> RGBColor[
              0.2058031822357576, 0.33364257157815613`, 0.9350315588185778], 
             92 -> RGBColor[
              0.2444470173259052, 0.37425969241856055`, 0.9372322680585309], 
             11 -> RGBColor[
              0.20295626314304663`, 0.3306502791066209, 0.9348694309878873], 
             137 -> RGBColor[
              0.32389238094576056`, 0.45496103389597625`, 0.9418591140004451],
              120 -> RGBColor[
              0.1939380814128329, 0.3211715983224198, 0.934355858879556], 51 -> 
             RGBColor[
              0.18219656266820544`, 0.3088305176665303, 0.9336871967570698], 
             72 -> RGBColor[
              0.2532013109542942, 0.38346101007627187`, 0.9377308121298508], 
             64 -> RGBColor[
              0.6295309817704698, 0.7101206369056319, 0.9639781314143923], 41 -> 
             RGBColor[
              0.29070628845368207`, 0.422881119381046, 0.9398666651147989], 
             103 -> RGBColor[
              0.1810808656124072, 0.3076578493216073, 0.933623659460268], 162 -> 
             RGBColor[
              0.4514119894863078, 0.5654121094919137, 0.9499845506954865], 
             196 -> RGBColor[
              0.23298613716021888`, 0.3622135807026517, 0.9365795878879478], 
             179 -> RGBColor[
              0.3685402730980111, 0.49363279400994686`, 0.9447040382078057], 
             160 -> RGBColor[
              0.44319072976501883`, 0.5582912675338615, 0.9494606992958204], 
             123 -> RGBColor[
              0.4511243917370499, 0.5651630067765897, 0.9499662252212164], 
             150 -> RGBColor[
              0.19256204953176445`, 0.3197253015699566, 0.9342774958995859], 
             188 -> RGBColor[
              0.31320234650668927`, 0.4457018633616062, 0.9411779544588138], 
             46 -> RGBColor[
              0.18297903858873563`, 0.3096529494708463, 0.9337317576031746], 
             182 -> RGBColor[
              0.34083289550277507`, 0.46963405615024345`, 0.9429385486081092],
              6 -> RGBColor[
              0.8314330293974257, 0.24261361475573226`, 0.17773361049049105`],
              131 -> RGBColor[
              0.1814951086723694, 0.3080932450421545, 0.9336472499897152], 45 -> 
             RGBColor[
              0.7110429824499928, 0.7741914491075349, 0.9718337774823064], 
             195 -> RGBColor[
              0.5010318547608589, 0.6057992567795268, 0.9538622094283838], 
             148 -> RGBColor[
              0.19357697366818166`, 0.320792051187238, 0.9343352943277091], 
             161 -> RGBColor[
              0.2838279904913397, 0.4156515921133449, 0.9394749562213734], 1 -> 
             RGBColor[
              0.17991592983646426`, 0.30643342795989703`, 0.9335573180911961],
              101 -> RGBColor[
              0.19619436846660787`, 0.3235430990727991, 0.9344843510893909], 
             12 -> RGBColor[
              0.950102117301832, 0.8398785531251466, 0.2787091962084557], 39 -> 
             RGBColor[
              0.25206224059906557`, 0.3822637749116947, 0.9376659437582241], 
             48 -> 
             RGBColor[
              0.21049372737267863`, 0.3385726319147987, 0.9352986784250858], 
             77 -> RGBColor[0.817319, 0.134127, 0.164218], 56 -> 
             RGBColor[
              0.1825695689347496, 0.30922257090263144`, 0.9337084389121362], 
             110 -> RGBColor[
              0.18012636844446756`, 0.30665461227948687`, 0.9335693022586058],
              73 -> RGBColor[
              0.21747923322295587`, 0.34591484147009205`, 0.9356964926491292],
              37 -> RGBColor[
              0.23584637567939642`, 0.36521987273590373`, 0.9367424742402714],
              130 -> RGBColor[
              0.1842953386135795, 0.3110364642551991, 0.933806718942298], 107 -> 
             RGBColor[
              0.21763298899601496`, 0.34607644853625624`, 0.9357052488129437],
              59 -> RGBColor[
              0.18422301466471383`, 0.3109604471993381, 0.9338026002004038], 
             47 -> RGBColor[
              0.1962609887352336, 0.32361312119909375`, 0.9344881450151332], 
             159 -> RGBColor[
              0.2548921156460419, 0.3852381530105079, 0.9378271009557244], 55 -> 
             RGBColor[
              0.33587823342715956`, 0.465342576888902, 0.9426228419218866], 
             49 -> RGBColor[
              0.4223544797753533, 0.5402439550531881, 0.9481330318712514], 82 -> 
             RGBColor[
              0.21196511221078973`, 0.3401191506708405, 0.9353824716148974], 
             199 -> RGBColor[
              0.995260710048657, 0.9923081960579929, 0.7282058295903809], 89 -> 
             RGBColor[
              0.2675148103379351, 0.39850540545675567`, 0.9385459447448243], 
             144 -> RGBColor[
              0.19848865517094644`, 0.32595453986523776`, 0.93461500732311], 
             78 -> RGBColor[
              0.18293127670980908`, 0.3096027487078165, 0.9337290376348271], 
             42 -> RGBColor[
              0.2027701922068055, 0.3304547067550528, 0.9348588345233357], 
             154 -> RGBColor[
              0.33187084383238813`, 0.46187157743916857`, 0.9423674946005033],
              168 -> RGBColor[
              0.20939739524084894`, 0.3374203173327738, 0.9352362439320562], 
             121 -> RGBColor[
              0.21735301065346377`, 0.34578217354658275`, 0.9356893044605262],
              128 -> RGBColor[
              0.43130662815416465`, 0.5479978560308542, 0.9487034548498753], 
             115 -> RGBColor[
              0.31502527059825963`, 0.4472807885868956, 0.9412941095699802], 
             61 -> 
             RGBColor[
              0.2073405252862433, 0.3352584165973958, 0.9351191082310077], 93 -> 
             RGBColor[
              0.23138676958404353`, 0.3605325439743302, 0.9364885062705369], 
             88 -> RGBColor[
              0.21656281497127022`, 0.34495162778329735`, 0.9356443039854151],
              21 -> RGBColor[
              0.36130368564417137`, 0.48736482567889206`, 0.94424292925431], 
             62 -> RGBColor[
              0.1999014029793203, 0.32743942738522325`, 0.9346954612208237], 
             136 -> RGBColor[
              0.22281221312870114`, 0.35152014148148586`, 0.9360001979653247],
              190 -> RGBColor[
              0.1841862517520943, 0.3109218070472717, 0.933800506606916], 57 -> 
             RGBColor[
              0.1818396285304826, 0.30845535725685214`, 0.9336668698859633], 
             111 -> RGBColor[
              0.2201361607798215, 0.3487074407912947, 0.9358478007429207], 63 -> 
             RGBColor[
              0.19167260114558432`, 0.31879043492179643`, 0.9342268431298139],
              75 -> RGBColor[
              0.5021423004164799, 0.6067007665877667, 0.9539496277780908], 30 -> 
             RGBColor[
              0.2095661987749073, 0.33759774054983127`, 0.9352458570435983], 
             5 -> RGBColor[
              0.35433408061295757`, 0.481328104103389, 0.9437988321847008], 
             171 -> RGBColor[
              0.30775018901205775`, 0.44079533951360933`, 0.940837290037407], 
             102 -> RGBColor[
              0.9691756477061694, 0.9765318290462814, 0.9370617675415293], 31 -> 
             RGBColor[
              0.531961775829707, 0.6309095600802831, 0.9562971261149575], 96 -> 
             RGBColor[
              0.9364164576881094, 0.9521000787690629, 0.9925145312769647], 70 -> 
             RGBColor[
              0.19105055232810444`, 0.31813662217445204`, 0.9341914183698972],
              52 -> RGBColor[
              0.18558886593634766`, 0.31239604348579764`, 0.9338803834097276],
              183 -> RGBColor[
              0.9363841071750253, 0.7854912142282449, 0.26767136325734403`], 
             158 -> RGBColor[
              0.3163443674121438, 0.4484233239473484, 0.9413781612525294], 13 -> 
             RGBColor[
              0.22110598802207443`, 0.3497267907135012, 0.9359030309696362], 
             170 -> RGBColor[
              0.6552079689840278, 0.7305727122261038, 0.9662686651478858], 86 -> 
             RGBColor[
              0.2020967142561969, 0.3297468387279948, 0.9348204809503698], 18 -> 
             RGBColor[
              0.22306772190849825`, 0.3517886974092449, 0.9360147488123428], 
             153 -> RGBColor[
              0.2822567222941179, 0.41400008961390705`, 0.9393854748220246], 
             58 -> RGBColor[
              0.9605766768067475, 0.9701187306290152, 0.9516175823034524], 22 -> 
             RGBColor[
              0.18848942771341942`, 0.31544471781973865`, 0.9340455661119352],
              66 -> RGBColor[
              0.18354617680954663`, 0.31024904769955874`, 0.9337640552858439],
              143 -> RGBColor[
              0.8556626659915121, 0.887746199790043, 0.9860950630129915], 119 -> 
             RGBColor[
              0.8468258702473929, 0.3609297347144502, 0.19247381227214683`], 
             145 -> RGBColor[
              0.1901932049434399, 0.31723549571420584`, 0.9341425937046723], 
             91 -> RGBColor[
              0.18623437450108682`, 0.31307451391494534`, 0.9339171441675451],
              177 -> RGBColor[
              0.21738991983752656`, 0.34582096743921015`, 0.9356914063839564],
              200 -> RGBColor[
              0.1906136828189116, 0.3176774446211637, 0.9341665392976392], 
             114 -> RGBColor[
              0.18141516357964482`, 0.30800921768088935`, 0.9336426972349526],
              24 -> RGBColor[
              0.2571472380542651, 0.3876084296445695, 0.9379555268407181], 
             176 -> RGBColor[
              0.23408779828449117`, 0.3633714963936115, 0.9366423258592136], 
             79 -> RGBColor[
              0.1941778278429074, 0.3214235870212298, 0.9343695120840757], 
             109 -> RGBColor[
              0.21740901950548744`, 0.34584104240122593`, 0.9356924940817913],
              135 -> RGBColor[
              0.1969362596236349, 0.3243228737174507, 0.934526600693254], 108 -> 
             RGBColor[
              0.3080267094125234, 0.4410859799869048, 0.9408530374651383], 
             191 -> RGBColor[
              0.8101035860121542, 0.8515783454987672, 0.9817072126714098], 14 -> 
             RGBColor[
              0.17925722738073346`, 0.3057410899147761, 0.9335198059608052], 
             185 -> RGBColor[
              0.2320502240219991, 0.3612298766540624, 0.9365262890192856], 32 -> 
             RGBColor[
              0.186006868294159, 0.3128353904667376, 0.9339041880256258], 122 -> 
             RGBColor[
              0.27792375203997, 0.40944586315061604`, 0.939138718576106], 187 -> 
             RGBColor[
              0.20348109888236326`, 0.33120191474515054`, 0.9348993196068165],
              193 -> 
             RGBColor[
              0.22946131864603458`, 0.3585087729578423, 0.9363788546880667], 
             100 -> RGBColor[
              0.20579087184942513`, 0.3336296325815971, 0.9350308577602878], 
             180 -> RGBColor[
              0.3420328760182438, 0.47067341895996806`, 0.9430150103054538], 
             7 -> RGBColor[
              0.20849433214894747`, 0.33647114076567824`, 0.9351848158249345],
              175 -> RGBColor[
              0.5005712745154292, 0.6054253369873833, 0.9538259508643026], 9 -> 
             RGBColor[
              0.19331350997927296`, 0.32051513414563226`, 0.9343202904603853],
              90 -> RGBColor[
              0.22727061882380845`, 0.3562062085462915, 0.9362540975740409], 
             174 -> RGBColor[
              0.19003317840134057`, 0.3170672976721906, 0.9341334804298378], 
             142 -> RGBColor[
              0.2619978835405132, 0.39270676559930323`, 0.938231763925273], 
             134 -> RGBColor[
              0.24687317251219526`, 0.37680973534647483`, 0.9373704340072151],
              105 -> RGBColor[
              0.20575656042090384`, 0.333593569094751, 0.9350289037751928], 
             16 -> RGBColor[
              0.1871756577266932, 0.3140638622658612, 0.9339707488547396], 
             139 -> RGBColor[
              0.28566810415648325`, 0.4175856682453557, 0.9395797479723991], 
             146 -> RGBColor[
              0.24540381361353808`, 0.37526534598125116`, 0.9372867561916584],
              126 -> RGBColor[
              0.1796655907243716, 0.3061703056806712, 0.9335430616491059], 
             198 -> RGBColor[
              0.34562348099972906`, 0.47378342052587685`, 0.9432438004798267],
              40 -> RGBColor[
              0.5058302216121423, 0.609694787153362, 0.9542399544439137], 104 -> 
             RGBColor[
              0.36710024085613885`, 0.49238551046016216`, 0.9446122806267241],
              181 -> RGBColor[
              0.43817293033743376`, 0.5539451018716196, 0.9491409695533606], 
             127 -> RGBColor[
              0.874787420357395, 0.9029957597937702, 0.9879191991572792], 76 -> 
             RGBColor[
              0.26424845016803866`, 0.3950722538189983, 0.9383599303652956], 
             172 -> RGBColor[
              0.8693407441384133, 0.4995886600246006, 0.2126870529687101], 84 -> 
             RGBColor[
              0.181234979779358, 0.3078198330824752, 0.9336324360340843], 184 -> 
             RGBColor[
              0.1818088839913312, 0.30842304279688765`, 0.933665119029941], 
             151 -> 
             RGBColor[
              0.9939031817563573, 0.9917468232222412, 0.7507035865643902], 35 -> 
             RGBColor[
              0.18077756667952594`, 0.30733906291288604`, 0.933606387034731], 
             36 -> RGBColor[
              0.18255152448721731`, 0.309203605044191, 0.9337074113075435], 
             34 -> RGBColor[
              0.4300571649791395, 0.5469156338284925, 0.9486238401612196], 38 -> 
             RGBColor[
              0.18112444186066054`, 0.30770365072141526`, 0.9336261410631407],
              54 -> RGBColor[
              0.988392764379178, 0.9725082101217492, 0.4094085107659739], 60 -> 
             RGBColor[
              0.18098071777705174`, 0.3075525875969092, 0.9336179561892], 87 -> 
             RGBColor[
              0.21670300720810273`, 0.3450989787129095, 0.9356522877259069], 
             141 -> RGBColor[
              0.34381589363766235`, 0.47221777920483715`, 0.9431286226115025],
              67 -> RGBColor[
              0.2558901091184015, 0.3862871074263986, 0.9378839352075763], 
             133 -> RGBColor[
              0.24912319227677354`, 0.3791746487785393, 0.937498569304202], 
             98 -> RGBColor[
              0.19250116414799295`, 0.31966130717125646`, 0.9342740285670519],
              3 -> RGBColor[
              0.4186929718519593, 0.5370725409226834, 0.947899723824117], 27 -> 
             RGBColor[
              0.26652048668465833`, 0.39746030825340095`, 0.9384893194837403],
              163 -> RGBColor[
              0.2817626744925139, 0.41348081404998144`, 0.9393573395306015], 
             85 -> RGBColor[
              0.2704719529099895, 0.40161354979365305`, 0.9387143496396024], 
             83 -> RGBColor[
              0.9263859833659136, 0.9441390533310817, 0.9928407161596127], 28 -> 
             RGBColor[
              0.1792907180836107, 0.3057762907669333, 0.933521713206789], 44 -> 
             RGBColor[
              0.8987739036289236, 0.6332377629819576, 0.2372468027203504], 
             189 -> RGBColor[
              0.19443151506714343`, 0.3216902283786009, 0.9343839591961993], 
             15 -> RGBColor[0.178927, 0.305394, 0.933501], 80 -> 
             RGBColor[
              0.22179319725678925`, 0.3504490911907685, 0.9359421665189183], 
             112 -> RGBColor[
              0.9414109245622558, 0.9558249439861124, 0.9840602016246193], 
             169 -> RGBColor[
              0.19209300288846856`, 0.31923230380857776`, 0.9342507843871425],
              69 -> RGBColor[
              0.24981404640376637`, 0.37990078026869034`, 0.9375379124247071],
              20 -> 
             RGBColor[
              0.1823235017276304, 0.3089639386663871, 0.9336944257487145], 8 -> 
             RGBColor[
              0.28326421471662644`, 0.41505902802867256`, 0.939442850025035], 
             116 -> RGBColor[
              0.24062773125074222`, 0.3702453805968408, 0.9370147653666777], 
             97 -> RGBColor[
              0.21679935925455723`, 0.3452002508228058, 0.9356577748324124], 
             118 -> RGBColor[
              0.39086743560945575`, 0.5129714599815431, 0.9461267052599003], 
             178 -> RGBColor[
              0.1836473816366038, 0.3103554203895525, 0.9337698187510258], 81 -> 
             RGBColor[
              0.30602988251049323`, 0.4389871883067331, 0.9407393211271083], 
             166 -> RGBColor[
              0.8037293520346596, 0.846598745469576, 0.9810718885991364], 125 -> 
             RGBColor[
              0.2642831104182927, 0.3951086839396021, 0.9383619042152723], 95 -> 
             RGBColor[
              0.24919784069125972`, 0.37925310899514714`, 0.9375028204209744],
              157 -> RGBColor[
              0.20642492465234524`, 0.3342960622787358, 0.9350669661294171], 
             74 -> RGBColor[
              0.34593054718585675`, 0.47404938582270545`, 0.9432633664656788],
              19 -> RGBColor[
              0.35121665541737046`, 0.47862794708531764`, 0.9436001926078689],
              156 -> RGBColor[
              0.8187176743057581, 0.14487782361704554`, 0.16555737209477062`],
              167 -> RGBColor[
              0.19933380464903927`, 0.32684284555228516`, 0.9346631373356007],
              33 -> RGBColor[
              0.9926235425767636, 0.9912176595362523, 0.7719105193703001], 43 -> 
             RGBColor[
              0.18974733652345127`, 0.3167668597351072, 0.9341172021577572], 
             140 -> RGBColor[
              0.9937232399115826, 0.9889829697856952, 0.5581915839279488], 
             186 -> RGBColor[
              0.18306798401191893`, 0.3097464367500775, 0.933736822913442], 
             117 -> RGBColor[
              0.1853227778630534, 0.31211636804980714`, 0.9338652300875955], 
             4 -> RGBColor[
              0.33430755049502603`, 0.4639821302779076, 0.9425227593943515], 
             106 -> RGBColor[
              0.18503007033382515`, 0.31180871387785897`, 0.9338485608268279],
              65 -> RGBColor[
              0.95633856953826, 0.8643818842404721, 0.284884016735784], 53 -> 
             RGBColor[
              0.631783197735858, 0.7119490872875069, 0.9641554341053266], 2 -> 
             RGBColor[
              0.18237351643808017`, 0.30901650729818564`, 0.9336972740124846],
              147 -> RGBColor[
              0.24952468470268496`, 0.3795966427742623, 0.9375214337039027], 
             94 -> RGBColor[
              0.19041076970754647`, 0.3174641700756846, 0.9341549836961299], 
             23 -> RGBColor[
              0.22363768830217948`, 0.3523877682269605, 0.9360472075552733], 
             194 -> RGBColor[
              0.2015219494351241, 0.32914272445885284`, 0.9347877489440981], 
             129 -> RGBColor[
              0.4544709331932017, 0.5679990031052896, 0.9501967631243022], 99 -> 
             RGBColor[
              0.5518206973838005, 0.647031927232117, 0.9578604931653224], 25 -> 
             RGBColor[
              0.17953882470990998`, 0.3060370665620425, 0.9335358425121159], 
             138 -> RGBColor[
              0.2218736173884548, 0.35053361784807985`, 0.9359467463264457], 
             124 -> RGBColor[
              0.2260372839021752, 0.3549098953457044, 0.9361838609748094], 
             197 -> RGBColor[
              0.20070591566211698`, 0.3282850212238928, 0.9347412770279392], 
             164 -> RGBColor[
              0.19517315909830985`, 0.32246974327830424`, 0.9344261947266101],
              152 -> RGBColor[
              0.20018563595199287`, 0.32773817426091345`, 0.9347116478681324],
              17 -> RGBColor[
              0.19146922694525287`, 0.31857667574257903`, 0.9342152612699701],
              149 -> RGBColor[
              0.1855038424012835, 0.31230667835964177`, 
               0.9338755414451867]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw1Vnk41Iv7HWbGjH3MjDGYYWbMlDYVokV9jgp1K023DRVaCFlSpNQNyVKW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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 11}], {
             RGBColor[
             0.19143609648975546`, 0.318541853533259, 0.9342133745395418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 35}], {
             RGBColor[
             0.1803467482579951, 0.30688624543639154`, 0.9335818525629636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 86}], {
             RGBColor[
             0.19100632204633058`, 0.3180901333439459, 0.934188899520783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 94}], {
             RGBColor[
             0.18516334977200538`, 0.3119487990177908, 0.933856150893663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 174}], {
             RGBColor[
             0.1849745541189024, 0.31175036281604385`, 0.9338453992605169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 196}], {
             RGBColor[
             0.20645103349834157`, 0.33432350433127433`, 0.935068452989572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 16}], {
             RGBColor[
             0.1847745870823867, 0.3115401847820234, 0.9338340114336121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 52}], {
             RGBColor[
             0.1839811911872139, 0.31070627539199164`, 0.933788828711106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[
             0.1829598466238134, 0.3096327774988722, 0.9337306646491643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 78}], {
             RGBColor[
             0.1826523965739446, 0.3093096280030011, 0.9337131558236558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 80}], {
             RGBColor[
             0.20208335684743473`, 0.32973279924447707`, 0.9348197202657014]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 82}], {
             RGBColor[
             0.19716931432443496`, 0.3245678289845131, 0.934539872813691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 98}], {
             RGBColor[
             0.18743734029303655`, 0.314338907234721, 0.9339856512897682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 100}], {
             RGBColor[
             0.19408219414375266`, 0.32132306993989135`, 0.9343640658863862]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 120}], {
             RGBColor[
             0.18815579892545653`, 0.3150940528103027, 0.9340265664460203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 124}], {
             RGBColor[
             0.20420540017012767`, 0.331963201321945, 0.9349405674936471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 187}], {
             RGBColor[
             0.1929273076602217, 0.3201092110216681, 0.9342982968096505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 5}], {
             RGBColor[
             0.38651352623245844`, 0.5092003225130362, 0.945849278004409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 10}], {
             RGBColor[
             0.3183216992072676, 0.4417413182340497, 0.9418115251184348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 27}], {
             RGBColor[
             0.3426067292683088, 0.4672664245880422, 0.9431945216539286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 29}], {
             RGBColor[
             0.312801857714541, 0.4359396148470296, 0.9414971783112978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 49}], {
             RGBColor[
             0.42052372581365627`, 0.5386582479879358, 0.9480163778476842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 53}], {
             RGBColor[
             0.5252380847939087, 0.6245108141050952, 0.9560275789647218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 62}], {
             RGBColor[
             0.30929718741563983`, 0.43225598415395333`, 0.9412975925224704]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 68}], {
             RGBColor[
             0.6898421419054424, 0.7085746089319662, 0.625429383133753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 71}], {
             RGBColor[
             0.3912157938817601, 0.5132731904080172, 0.9461489023409704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 75}], {
             RGBColor[
             0.4604176361342196, 0.5718866537552251, 0.9509246758011038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 118}], {
             RGBColor[
             0.40478020373070756`, 0.5250220004521133, 0.9470132145420087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[
             0.4349086817945046, 0.5511177738496366, 0.9489329745226667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 127}], {
             RGBColor[
             0.6467401961046771, 0.7200341503582268, 0.9679094614906981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 129}], {
             RGBColor[
             0.4365819525225805, 0.5525357720139865, 0.9490482434742096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 139}], {
             RGBColor[
             0.3521805380042213, 0.47732910458401956`, 0.943739735898258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 141}], {
             RGBColor[
             0.38125443274481086`, 0.5046451600637603, 0.9455141732178098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 146}], {
             RGBColor[
             0.33204839273274867`, 0.4561689434519673, 0.9425932400078877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 155}], {
             RGBColor[
             0.545941520152503, 0.6408465029615011, 0.9579803382974005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 167}], {
             RGBColor[
             0.3090133882504993, 0.4319576932374843, 0.9412814305798589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 191}], {
             RGBColor[
             0.6143982789320568, 0.6943254432107253, 0.9648034682477634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 194}], {
             RGBColor[
             0.3101074606435417, 0.43310763269076813`, 0.9413437363841075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 195}], {
             RGBColor[
             0.4598624133064091, 0.5714358988511051, 0.9508809666262504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 34}], {
             RGBColor[
             0.38218235773708276`, 0.5054488820532, 0.9455732997777855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 40}], {
             RGBColor[
             0.42006888605358417`, 0.5368384587156347, 0.9483813569191326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 49}], {
             RGBColor[
             0.37833101513518963`, 0.5021130426655478, 0.9453278956328015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 53}], {
             RGBColor[
             0.483045374115442, 0.5879656087827072, 0.953339096749839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 54}], {
             RGBColor[
             0.661350157437102, 0.7182451701998284, 0.6759656350801627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 65}], {
             RGBColor[
             0.6453230600166431, 0.6641820072591899, 0.6137033880650677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 69}], {
             RGBColor[
             0.2920607984493962, 0.42194145527329896`, 0.9400303359095292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 86}], {
             RGBColor[
             0.26820213237561147`, 0.3968644845029512, 0.9386716201723606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 92}], {
             RGBColor[
             0.28937728391046563`, 0.41912091134823404`, 0.9398775137264412]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 118}], {
             RGBColor[
             0.3625874930522409, 0.48847679512972536`, 0.9443247323271259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 119}], {
             RGBColor[
             0.6759864303299372, 0.3952805332356027, 0.44249012797954834`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 123}], {
             RGBColor[
             0.39271597111603795`, 0.5145725685272486, 0.946244492307784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 139}], {
             RGBColor[
             0.30998782732575464`, 0.44078389926163164`, 0.9410512536833753]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 146}], {
             RGBColor[
             0.289855682054282, 0.41962373812957937`, 0.9399047577930049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 171}], {
             RGBColor[
             0.3210288697535419, 0.4523887348957585, 0.9416800247158792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 182}], {
             RGBColor[
             0.33757022299890055`, 0.4668080932140755, 0.9427306540012304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 191}], {
             RGBColor[
             0.57220556825359, 0.6577802378883374, 0.9621149860328806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 195}], {
             RGBColor[
             0.41766970262794245`, 0.5348906935287172, 0.9481924844113676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 196}], {
             RGBColor[
             0.28364684382762245`, 0.41309785549027966`, 0.9395511736411497]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 199}], {
             RGBColor[
             0.6647841302718416, 0.7281451631679503, 0.8353642944923663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 10}], {
             RGBColor[
             0.28614225358776674`, 0.41386909982440245`, 0.9397610792987268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 27}], {
             RGBColor[
             0.31042728364880795`, 0.439394206178395, 0.9411440758342206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.28062241209504013`, 0.4080673964373824, 0.9394467324915896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 30}], {
             RGBColor[
             0.28195013969393246`, 0.40946292232661013`, 0.9395223446141496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 42}], {
             RGBColor[
             0.2785521364098815, 0.40589140542922086`, 0.9393288333540183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 68}], {
             RGBColor[
             0.6576626962859415, 0.680702390522319, 0.6233789373140448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 71}], {
             RGBColor[
             0.35903634826225916`, 0.48540097199837007`, 0.9440984565212622]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 73}], {
             RGBColor[
             0.2859066569179567, 0.41362147278674055`, 0.939747662416915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 75}], {
             RGBColor[
             0.42823819051471873`, 0.5440144353455778, 0.9488742299813958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 76}], {
             RGBColor[
             0.3092912653904981, 0.4382001789611937, 0.9410793812749982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 81}], {
             RGBColor[
             0.3301819815617254, 0.46015764620506105`, 0.9422690766559045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 87}], {
             RGBColor[
             0.28551854391053016`, 0.41321354140814925`, 0.9397255599553038]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 89}], {
             RGBColor[
             0.31092444547544634`, 0.4399167547800723, 0.9411723884647626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 107}], {
             RGBColor[
             0.28598353480448624`, 0.4137022763198226, 0.9397520404988222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 127}], {
             RGBColor[
             0.6145607504851762, 0.6921619319485797, 0.9658590156709901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 129}], {
             RGBColor[
             0.40440250690307966`, 0.5246635536043394, 0.9469977976545015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 141}], {
             RGBColor[
             0.34907498712530993`, 0.4767729416541131, 0.9434637273981017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 142}], {
             RGBColor[
             0.3081659820767354, 0.43701743485134614`, 0.9410152980549868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 147}], {
             RGBColor[
             0.30192938265782127`, 0.43046237343882565`, 0.9406601329443018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 155}], {
             RGBColor[
             0.513762074533002, 0.612974284551854, 0.9559298924776924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 157}], {
             RGBColor[
             0.28037950263265143`, 0.40781208319106244`, 0.939432899157059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 168}], {
             RGBColor[
             0.2818657379269033, 0.4093742107180814, 0.9395175380583785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 188}], {
             RGBColor[
             0.33376821355982345`, 0.4635149837324976, 0.9424883933217574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 197}], {
             RGBColor[
             0.27751999813753725`, 0.4048065626636409, 0.93927005460632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 44}], {
             RGBColor[
             0.8538799874745917, 0.37282166416447404`, 0.1975713412337775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 45}], {
             RGBColor[
             0.7913030137482814, 0.4198062262063331, 0.4424336661544295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 58}], {
             RGBColor[
             0.8744809118671997, 0.48511532004682656`, 0.4356949344281448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 77}], {
             RGBColor[
             0.8267283529316172, 0.20645140983715485`, 0.1732284069936607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 83}], {
             RGBColor[
             0.8630840140535884, 0.476455427614182, 0.44943597904686494`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 96}], {
             RGBColor[
             0.8664275054943202, 0.4791091027601758, 0.4493272507526489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 112}], {
             RGBColor[
             0.8680923277857024, 0.48035072449919225`, 0.44650914086853377`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 156}], {
             RGBColor[
             0.8271945777002032, 0.21003501770950336`, 0.17367486435858423`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 166}], {
             RGBColor[
             0.8221984702765036, 0.44394199166034687`, 0.44551303652670615`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 170}], {
             RGBColor[
             0.7726913425929597, 0.40526664724585604`, 0.4405786287096226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 179}], {
             RGBColor[
             0.6771354439642875, 0.3262866745071371, 0.4333904197295959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 183}], {
             RGBColor[
             0.8664167219899589, 0.42357281457990315`, 0.20771286141277537`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 192}], {
             RGBColor[
             0.7095267480527575, 0.35411800374375885`, 0.4355163647005046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 8}], {
             RGBColor[
             0.24587927343278695`, 0.3757650843971754, 0.9373138329249848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 16}], {
             RGBColor[
             0.19783499493782034`, 0.3252675015157697, 0.9345777823398371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 52}], {
             RGBColor[
             0.19704159904264756`, 0.32443359212573797`, 0.934532599617331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.2079174287175954, 0.335864778681537, 0.9351519620279711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 67}], {
             RGBColor[
             0.23219222063367448`, 0.36137912409603845`, 0.9365343755162554]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 79}], {
             RGBColor[
             0.20133607999592745`, 0.328947363893454, 0.934777163954505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.19486465596415276`, 0.32214548692407674`, 0.9344086259295095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 122}], {
             RGBColor[
             0.24320904209445873`, 0.37295850195814717`, 0.9371617672005202]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 125}], {
             RGBColor[
             0.2363887212836201, 0.36578991235264013`, 0.9367733600201034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 126}], {
             RGBColor[
             0.19407996143665954`, 0.32132072322317473`, 0.9343639387370202]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 137}], {
             RGBColor[
             0.266193356547354, 0.39571608733082725`, 0.9385219649126898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 179}], {
             RGBColor[
             0.2885173026234793, 0.4150519673878126, 0.9399444270163702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 192}], {
             RGBColor[
             0.3371042587561843, 0.4567989612427451, 0.9431333444727331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.3222839501803989, 0.4512119268537823, 0.9418428896396724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 26}], {
             RGBColor[
             0.28802321713859724`, 0.420061041312345, 0.9397138681726531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 61}], {
             RGBColor[
             0.24530237000143487`, 0.37515872231303415`, 0.9372809791280214]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 67}], {
             RGBColor[
             0.26957716191751396`, 0.4006730677275356, 0.9386633926163057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 79}], {
             RGBColor[
             0.2387210212797669, 0.3682413075249512, 0.9369061810545554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.24761466346370808`, 0.37758908934975655`, 0.9374126608199662]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 83}], {
             RGBColor[
             0.60482509904127, 0.6795990406798771, 0.9661417830923238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 122}], {
             RGBColor[
             0.2805939833782982, 0.4122524455896443, 0.9392907843005704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 125}], {
             RGBColor[
             0.2737736625674596, 0.4050838559841373, 0.9389023771201537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 137}], {
             RGBColor[
             0.3035782978311935, 0.4350100309623244, 0.94065098201274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 166}], {
             RGBColor[
             0.543496783375643, 0.6308288867491243, 0.9602573693120857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 170}], {
             RGBColor[
             0.4692360918503271, 0.5728158701273882, 0.9528557575864605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 179}], {
             RGBColor[
             0.32590224390731876`, 0.4543459110193097, 0.9420734441164204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 192}], {
             RGBColor[
             0.37448920004002384`, 0.4960929048742423, 0.9452623615727833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 198}], {
             RGBColor[
             0.31444384785817775`, 0.4444212242772747, 0.9413433252524308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 18}], {
             RGBColor[
             0.2081906159438856, 0.3361519157774386, 0.935167519636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 32}], {
             RGBColor[
             0.18966018913671598`, 0.3166752623061849, 0.9341122392430056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 39}], {
             RGBColor[
             0.22268787528916928`, 0.3513894545286635, 0.9359931171093048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 41}], {
             RGBColor[
             0.24200989921647753`, 0.37169812676333913`, 0.9370934777875921]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 57}], {
             RGBColor[
             0.18757656925487778`, 0.3144852457012422, 0.9339935801731742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 85}], {
             RGBColor[
             0.23189273144463124`, 0.36106434196964265`, 0.9365173200499939]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 88}], {
             RGBColor[
             0.20493816247527158`, 0.3327333809644648, 0.9349822972229003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 91}], {
             RGBColor[
             0.1897739422401799, 0.3167948240302888, 0.9341187173139652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 103}], {
             RGBColor[
             0.18719718779584008`, 0.3140864917336198, 0.9339719749603267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 117}], {
             RGBColor[
             0.1893181439211632, 0.3163157510977197, 0.9340927602739904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 121}], {
             RGBColor[
             0.20533326031636837`, 0.3331486538461075, 0.9350047974604558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 152}], {
             RGBColor[
             0.19674957296563292`, 0.32412665420327286`, 0.9345159691642588]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 159}], {
             RGBColor[
             0.22410281281265743`, 0.3528766435780701, 0.9360736957080549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 164}], {
             RGBColor[
             0.1942433345387914, 0.32149243871196825`, 0.9343732425934977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 178}], {
             RGBColor[
             0.18848044580793838`, 0.31543527726759235`, 0.9340450546057055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 200}], {
             RGBColor[
             0.19196359639909227`, 0.31909628938339796`, 0.9342434148790122]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 17}], {
             RGBColor[
             0.2047098267539144, 0.3324933856439975, 0.9349692938413614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 27}], {
             RGBColor[
             0.24223545662361712`, 0.37193520189940843`, 0.9371063229482464]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 29}], {
             RGBColor[
             0.2124305850698493, 0.3406083921583959, 0.9354089796056155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 30}], {
             RGBColor[
             0.2137583126687416, 0.34200391804762365`, 0.9354845917281754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 42}], {
             RGBColor[
             0.2103603093846907, 0.3384324011502344, 0.9352910804680441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 51}], {
             RGBColor[
             0.20007349461539067`, 0.32762030660597313`, 0.9347052615849112]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 62}], {
             RGBColor[
             0.2089259147709481, 0.3369247614653196, 0.9352093938167881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 71}], {
             RGBColor[
             0.2908445212370684, 0.4179419677193835, 0.9400607036352882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 73}], {
             RGBColor[
             0.2177148298927659, 0.346162468507754, 0.9357099095309409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 75}], {
             RGBColor[
             0.3600463634895279, 0.4765554310665914, 0.9448364770954216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 89}], {
             RGBColor[
             0.2427326184502555, 0.3724577505010858, 0.9371346355787884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 107}], {
             RGBColor[
             0.21779170777929543`, 0.3462432720408361, 0.9357142876128481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.3362106798778888, 0.4572045493253528, 0.9429600447685274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 130}], {
             RGBColor[
             0.2011228825880777, 0.32872327990030753`, 0.9347650226775253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 141}], {
             RGBColor[
             0.28088316010011916`, 0.40931393737512656`, 0.9394259745121276]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 142}], {
             RGBColor[
             0.23997415505154454`, 0.3695584305723596, 0.9369775451690128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 147}], {
             RGBColor[
             0.23373755563263043`, 0.3630033691598391, 0.9366223800583277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 149}], {
             RGBColor[
             0.2017271344819297, 0.32935838695252884`, 0.9347994339289696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 167}], {
             RGBColor[
             0.2086421156058076, 0.33662647054885053`, 0.9351932318741767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 168}], {
             RGBColor[
             0.21367391090171242`, 0.3419152064390949, 0.9354797851724044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 188}], {
             RGBColor[
             0.26557638653463256`, 0.3960559794535111, 0.9384506404357832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.20619097081485965`, 0.33405016196200843`, 0.935053642804476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 194}], {
             RGBColor[
             0.20973618799885002`, 0.33777641000213443`, 0.9352555376784253]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 197}], {
             RGBColor[
             0.20932817111234645`, 0.33734755838465436`, 0.9352323017203459]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 35}], {
             RGBColor[
             0.19186691491128627`, 0.3189946710097535, 0.9342379090113091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 70}], {
             RGBColor[
             0.19700340773557554`, 0.3243934506405365, 0.9345304246788922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 86}], {
             RGBColor[
             0.20252648869962175`, 0.33019855891730787`, 0.9348449559691285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 94}], {
             RGBColor[
             0.19668351642529655`, 0.32405722459115277`, 0.9345122073420087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 110}], {
             RGBColor[
             0.1915413157937571, 0.3186524456930539, 0.9342193666232466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 138}], {
             RGBColor[
             0.2124149402657507, 0.3405919484773504, 0.9354080886571665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 174}], {
             RGBColor[
             0.1964947207721936, 0.32385878838940574`, 0.9345014557088626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 182}], {
             RGBColor[
             0.27189457932291083`, 0.4001421676284322, 0.9389039897979983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 196}], {
             RGBColor[
             0.21797120015163274`, 0.34643192990463634`, 0.9357245094379176]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 33}], {
             RGBColor[
             0.9713628299392978, 0.9155481063306994, 0.5253098577893779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 44}], {
             RGBColor[
             0.9244380104653778, 0.7365581580535521, 0.25797799946440303`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 58}], {
             RGBColor[
             0.9553393970542898, 0.9049986418770809, 0.615163389255954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 68}], {
             RGBColor[
             0.9555467146303788, 0.8599776150331977, 0.2908341193259223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 77}], {
             RGBColor[
             0.8615800391006107, 0.36937751770838223`, 0.20238173206948523`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 96}], {
             RGBColor[
             0.9432592874949708, 0.8959893159471047, 0.6356118637427102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 99}], {
             RGBColor[
             0.7509614073428162, 0.7434552401786318, 0.618284844686889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 102}], {
             RGBColor[
             0.9596388825040008, 0.9082051910857141, 0.6078854818749925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 128}], {
             RGBColor[
             0.6907043727279983, 0.6939382045780004, 0.6137063255291655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 140}], {
             RGBColor[
             0.9719126786067074, 0.9144307614554209, 0.4184503900682022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 162}], {
             RGBColor[
             0.7007570533940699, 0.7026453313085301, 0.614346873451971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 172}], {
             RGBColor[
             0.9097214307201227, 0.6697336065748736, 0.2456981245885829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 31}], {
             RGBColor[
             0.37653388192589077`, 0.49031817539689215`, 0.9461000785422968]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 34}], {
             RGBColor[
             0.32558157650060693`, 0.44832121227099686`, 0.9422634355654279]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 36}], {
             RGBColor[
             0.20182875625464586`, 0.3294651978788461, 0.9348052211385899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 63}], {
             RGBColor[
             0.20638929458382937`, 0.3342586128176488, 0.935064937049725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 64}], {
             RGBColor[
             0.4253184848962721, 0.5299237138095665, 0.9499405811920143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 70}], {
             RGBColor[
             0.20607827017508945`, 0.33393170644397663`, 0.9350472246697668]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 97}], {
             RGBColor[
             0.21895267363831583`, 0.3474635207681535, 0.9357804029010244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 132}], {
             RGBColor[
             0.26083574153477407`, 0.39148528066721244`, 0.9381655816572811]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 138}], {
             RGBColor[
             0.2214898027052646, 0.35013020428079056`, 0.9359248886480409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 145}], {
             RGBColor[
             0.20564959648275716`, 0.3334811432138535, 0.9350228123371542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 153}], {
             RGBColor[
             0.2516813551580962, 0.3818634401637041, 0.9376442528958304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 185}], {
             RGBColor[
             0.22657810602203676`, 0.3554783336837818, 0.936214659994461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 22}], {
             RGBColor[
             0.18387332754707644`, 0.31059290386725735`, 0.9337826860363703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 48}], {
             RGBColor[
             0.19487547737670605`, 0.3221568609147874, 0.9344092421929455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 106}], {
             RGBColor[
             0.1821436488572793, 0.3087749018963175, 0.9336841833938165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 131}], {
             RGBColor[
             0.18037616802655143`, 0.3069171674784653, 0.9335835279752602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 176}], {
             RGBColor[
             0.20667251283261232`, 0.3345562931541938, 0.9350810659100094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 59}], {
             RGBColor[
             0.18157500733235693`, 0.30817722359966904`, 0.9336518001002019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.18941420148966015`, 0.3164167136926116, 0.9340982306104119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 114}], {
             RGBColor[
             0.1801710817898224, 0.3067016088404447, 0.9335718486174763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 167}], {
             RGBColor[
             0.18913040232451964`, 0.31611842277614255`, 0.9340820686678004]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 184}], {
             RGBColor[
             0.18036794199566558`, 0.3069085213984438, 0.9335830595149706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 186}], {
             RGBColor[
             0.18099749200595946`, 0.30757021837503873`, 0.933618911456721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 194}], {
             RGBColor[
             0.19022447471756204`, 0.31726836222942645`, 0.934144374472049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 52}], {
             RGBColor[
             0.18638226183152043`, 0.31322995287582944`, 0.9339255661322337]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 61}], {
             RGBColor[
             0.19725809150646825`, 0.3246611394316285, 0.9345449285428737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 67}], {
             RGBColor[
             0.22153288342254734`, 0.3501754848461299, 0.935927342031158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 80}], {
             RGBColor[
             0.20448442749174123`, 0.3322564767283148, 0.934956457686829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 82}], {
             RGBColor[
             0.19957038496874147`, 0.32709150646835083`, 0.9346766102348185]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 84}], {
             RGBColor[
             0.1842053187530256, 0.3109418476741682, 0.933801592444412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 100}], {
             RGBColor[
             0.19648326478805916`, 0.32384674742372915`, 0.9345008033075137]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 120}], {
             RGBColor[
             0.19055686956976303`, 0.31761773029414053`, 0.9341633038671477]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 125}], {
             RGBColor[
             0.22572938407249296`, 0.3545862731027316, 0.936166326535006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.19532837830452823`, 0.32263288850550587`, 0.9344350342307781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 30}], {
             RGBColor[
             0.20051771286008008`, 0.3280872081462052, 0.9347305591567843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[
             0.1971197095760292, 0.3245156912488159, 0.9345370478966529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 51}], {
             RGBColor[
             0.18683289480672916`, 0.31370359670455467`, 0.9339512290135199]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 73}], {
             RGBColor[
             0.20447423008410437`, 0.33224575860633554`, 0.9349558769595496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 87}], {
             RGBColor[
             0.2040861170766778, 0.33183782722774424`, 0.9349337744979385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 89}], {
             RGBColor[
             0.229492018641594, 0.35854104059966735`, 0.9363806030073972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 106}], {
             RGBColor[
             0.18824964863953902`, 0.315192694810219, 0.934031911048399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 107}], {
             RGBColor[
             0.20455110797063392`, 0.33232656213941764`, 0.9349602550414569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 130}], {
             RGBColor[
             0.18788228277941618`, 0.31480656999888906`, 0.9340109901061341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 131}], {
             RGBColor[
             0.18648216780881113`, 0.31333496039236675`, 0.9339312556298427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 142}], {
             RGBColor[
             0.22673355524288302`, 0.35564172067094113`, 0.9362235125976215]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 147}], {
             RGBColor[
             0.22049695582396892`, 0.34908665925842064`, 0.9358683474869365]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 149}], {
             RGBColor[
             0.1884865346732682, 0.31544167705111037`, 0.9340454013575784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 157}], {
             RGBColor[
             0.19894707579879906`, 0.3264363690106574, 0.9346411136996936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 168}], {
             RGBColor[
             0.2004333110930509, 0.32799849653767643`, 0.9347257526010131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 188}], {
             RGBColor[
             0.25233578672597107`, 0.38213926955209265`, 0.937696607864392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 189}], {
             RGBColor[
             0.19295037100619816`, 0.32013345206058996`, 0.9342996102330847]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 197}], {
             RGBColor[
             0.19608757130368493`, 0.3234308484832359, 0.9344782691489546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 24}], {
             RGBColor[
             0.24010747998138166`, 0.3696985635269072, 0.9369851378265305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 32}], {
             RGBColor[
             0.20453729510132862`, 0.33231204393799124`, 0.9349594684189844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 39}], {
             RGBColor[
             0.2375649812537819, 0.3670262361604698, 0.9368403462852835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 41}], {
             RGBColor[
             0.25688700518109014`, 0.38733490839514545`, 0.9379407069635708]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 85}], {
             RGBColor[
             0.24676983740924385`, 0.376701123601449, 0.9373645492259726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 103}], {
             RGBColor[
             0.20207429376045272`, 0.32972327336542606`, 0.9348192041363055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 108}], {
             RGBColor[
             0.2655472156605108, 0.39643733869807485`, 0.9384338931387406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 117}], {
             RGBColor[
             0.2041952498857758, 0.331952532729526, 0.9349399894499691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 133}], {
             RGBColor[
             0.2360954570926359, 0.3654816730938921, 0.9367566590582723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 152}], {
             RGBColor[
             0.21162667893024556`, 0.3397634358350792, 0.9353631983402376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 178}], {
             RGBColor[
             0.20335755177255102`, 0.3310720588993987, 0.9348922837816843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 33}], {
             RGBColor[
             0.6719200989970671, 0.734922803310785, 0.8577553559890845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 74}], {
             RGBColor[
             0.34857360130161363`, 0.4763386664540116, 0.9434317795367738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 85}], {
             RGBColor[
             0.31084430416368, 0.44012074843948534`, 0.9411572711237357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 88}], {
             RGBColor[
             0.28388973519432037`, 0.4117897874343075, 0.939622248296642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 93}], {
             RGBColor[
             0.291301712500707, 0.4195802455298239, 0.9400443494392029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 95}], {
             RGBColor[
             0.3002072480543151, 0.4289405280402324, 0.9405515065144217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 102}], {
             RGBColor[
             0.6601961515617699, 0.7275798880657995, 0.9403309800746991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 121}], {
             RGBColor[
             0.28428483303541713`, 0.41220506031595017`, 0.9396447485341975]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 140}], {
             RGBColor[
             0.6724699476644765, 0.7338054584355065, 0.7508958882679089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 159}], {
             RGBColor[
             0.30305438553170616`, 0.43193305004791277`, 0.9407136467817967]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 161}], {
             RGBColor[
             0.3175223229543551, 0.44713976959933127`, 0.9415375744146212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 162}], {
             RGBColor[
             0.4013143224518391, 0.5220200282886156, 0.9467923716516777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 164}], {
             RGBColor[
             0.2731949072578401, 0.40054884518181094`, 0.9390131936672395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 172}], {
             RGBColor[
             0.610278699777892, 0.48910830355495916`, 0.5781436227882895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 173}], {
             RGBColor[
             0.35948494367207134`, 0.4857895227952885, 0.9441270406240982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 180}], {
             RGBColor[
             0.3466247657178071, 0.47465068302264285`, 0.9433076014566613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 22}], {
             RGBColor[
             0.1854064647205249, 0.3122043282430629, 0.9338699959303249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 46}], {
             RGBColor[
             0.182651270158183, 0.3093084440686167, 0.9337130916759446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 47}], {
             RGBColor[
             0.189292245231432, 0.3162885299327404, 0.9340912853819239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 50}], {
             RGBColor[
             0.19303508907013, 0.32022249611721776`, 0.9343044348014965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 101}], {
             RGBColor[
             0.18925893509711914`, 0.3162535188695931, 0.9340893884190526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 135}], {
             RGBColor[
             0.18962988067563263`, 0.3166434061919189, 0.9341105132209843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 144}], {
             RGBColor[
             0.19040607844928842`, 0.31745923926581243`, 0.9341547165359123]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 23}], {
             RGBColor[
             0.2924706869731754, 0.4198762969529263, 0.9401450684047916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 55}], {
             RGBColor[
             0.34859095953566543`, 0.47635370128389704`, 0.9434328855880982]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 61}], {
             RGBColor[
             0.2843221054652073, 0.4113116211381439, 0.9396810187426589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 67}], {
             RGBColor[
             0.30859689738128643`, 0.43682596655264533`, 0.9410634322309431]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 83}], {
             RGBColor[
             0.6438448345050425, 0.715751939504987, 0.9685418227069613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 90}], {
             RGBColor[
             0.29428715223398993`, 0.42178551711259177`, 0.9402485134141754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 122}], {
             RGBColor[
             0.3196137188420707, 0.44840534441475405`, 0.941690823915208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 166}], {
             RGBColor[
             0.5825165188394155, 0.666981785574234, 0.9626574089267232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 170}], {
             RGBColor[
             0.5082558273140996, 0.6089687689524979, 0.9552557972010979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 175}], {
             RGBColor[
             0.43093748007980026`, 0.5463950813331377, 0.9490344400593063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 177}], {
             RGBColor[
             0.28934680274084895`, 0.4165928965590511, 0.9399671678191333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 179}], {
             RGBColor[
             0.3649219793710912, 0.49049880984441946`, 0.9444734837310578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 183}], {
             RGBColor[
             0.6488438964095984, 0.6364280199535685, 0.605957146255827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 192}], {
             RGBColor[
             0.4135089355037963, 0.532245803699352, 0.9476624011874208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.19949157754304903`, 0.3270086748672687, 0.9346721222685106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 72}], {
             RGBColor[
             0.22084536933385682`, 0.34945286394800523`, 0.935888189120893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 144}], {
             RGBColor[
             0.19348904144218293`, 0.3206996288424882, 0.9343302867175226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 176}], {
             RGBColor[
             0.2112886129989553, 0.33940810710667507`, 0.9353439459855744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 38}], {
             RGBColor[
             0.20238106508142, 0.3300457094741879, 0.9348366743092069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 43}], {
             RGBColor[
             0.2066925124128154, 0.33457731398103385`, 0.9350822048565153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 55}], {
             RGBColor[
             0.27975796086466953`, 0.40886517255793126`, 0.9393350247385799]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 60}], {
             RGBColor[
             0.2023092030396156, 0.32997017791193484`, 0.9348325818722366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 90}], {
             RGBColor[
             0.22545415356299398`, 0.354296988386626, 0.936150652564657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 111}], {
             RGBColor[
             0.2218869245410005, 0.3505476045091276, 0.935947504149097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 115}], {
             RGBColor[
             0.26933147945021957`, 0.39983427840692803`, 0.9386706585626268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 163}], {
             RGBColor[
             0.2527001813973467, 0.382934291138471, 0.9377022735429374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 165}], {
             RGBColor[
             0.21472043526896856`, 0.3430151699025583, 0.9355393831869255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 169}], {
             RGBColor[
             0.20786534559532402`, 0.33581003601776915`, 0.9351489959712078]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 175}], {
             RGBColor[
             0.36210448140880436`, 0.4789065526071719, 0.9449365792097879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 177}], {
             RGBColor[
             0.22051380406985302`, 0.3491043678330853, 0.9358693069696149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 39}], {
             RGBColor[
             0.25460473932666533`, 0.38493610227813213`, 0.9378107352994711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 41}], {
             RGBColor[
             0.2739267632539736, 0.4052447745128077, 0.9389110959777585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 55}], {
             RGBColor[
             0.29651273574071235`, 0.4264755032667358, 0.9402891843813024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 108}], {
             RGBColor[
             0.28258697373339425`, 0.41434720481573717`, 0.9394042821529283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 111}], {
             RGBColor[
             0.2386416994170433, 0.36815793521793205`, 0.9369016637918195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 115}], {
             RGBColor[
             0.28608625432626233`, 0.41744460911573256`, 0.9396248182053492]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 133}], {
             RGBColor[
             0.2531352151655193, 0.3833915392115544, 0.93772704807246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 163}], {
             RGBColor[
             0.2694549562733895, 0.40054462184727546`, 0.9386564331856598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 165}], {
             RGBColor[
             0.23147521014501135`, 0.3606255006113628, 0.9364935428296479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 175}], {
             RGBColor[
             0.3788592562848471, 0.49651688331597643`, 0.9458907388525104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 38}], {
             RGBColor[
             0.18033163328528526`, 0.30687035864172885`, 0.9335809917876283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[
             0.1846430806166806, 0.3114019631485748, 0.9338265223349365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 60}], {
             RGBColor[
             0.18025977124348086`, 0.3067948270794758, 0.9335768993506579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 111}], {
             RGBColor[
             0.19983749274486573`, 0.32737225367666856`, 0.9346918216275183]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 165}], {
             RGBColor[
             0.19267100347283378`, 0.3198398190700993, 0.9342837006653468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 58}], {
             RGBColor[
             0.6266794481836577, 0.6975908926125163, 0.9458012343118618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 67}], {
             RGBColor[
             0.2743361643394848, 0.4056750810112081, 0.9389344107639237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 80}], {
             RGBColor[
             0.25728770840867865`, 0.387756072893393, 0.9379635264195947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 82}], {
             RGBColor[
             0.2523736658856789, 0.382591102633429, 0.9376836789675842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 96}], {
             RGBColor[
             0.6145993386243387, 0.6885815666825401, 0.9662497087986179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 98}], {
             RGBColor[
             0.24264169185428053`, 0.372362180883637, 0.9371294574436615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 99}], {
             RGBColor[
             0.42230145847218425`, 0.5360474909140672, 0.9489226897427967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[
             0.24928654570499661`, 0.3793463435888073, 0.9375078720402794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 116}], {
             RGBColor[
             0.2667049754056552, 0.39765421759642916`, 0.9384998258434745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 120}], {
             RGBColor[
             0.2433601504867005, 0.3731173264592187, 0.9371703725999135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 122}], {
             RGBColor[
             0.285352985800269, 0.4172544588733168, 0.9395618024481885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 124}], {
             RGBColor[
             0.25940975173137165`, 0.3899864749708609, 0.9380843736475403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 125}], {
             RGBColor[
             0.2785326649894304, 0.41008586926780977`, 0.9391733952677717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 128}], {
             RGBColor[
             0.36204442385736635`, 0.48653045531343586`, 0.9443441705850733]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 136}], {
             RGBColor[
             0.2577972163446346, 0.3882915980387517, 0.9379925421427979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 137}], {
             RGBColor[
             0.3083373002531643, 0.4400120442459969, 0.9409220001603581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.5482557857976138, 0.6358309000327967, 0.9605283874597037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 170}], {
             RGBColor[
             0.4739950942722979, 0.5778178834110607, 0.9531267757340784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 187}], {
             RGBColor[
             0.24813165922146568`, 0.378132484670584, 0.9374421029635438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 192}], {
             RGBColor[
             0.37924820246199464`, 0.5010949181579147, 0.9455333797204014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 198}], {
             RGBColor[
             0.3192028502801486, 0.44942323756094715`, 0.9416143434000489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 29}], {
             RGBColor[
             0.2367156151308905, 0.36613349851238836`, 0.9367919761411093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 30}], {
             RGBColor[
             0.2380433427297828, 0.3675290244016161, 0.9368675882636692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 42}], {
             RGBColor[
             0.2346453394457319, 0.36395750750422684`, 0.936674077003538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 62}], {
             RGBColor[
             0.23321094483198931`, 0.3624498678193121, 0.9365923903522819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 71}], {
             RGBColor[
             0.3151295512981096, 0.44346707407337604`, 0.941443700170782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 73}], {
             RGBColor[
             0.2419998599538071, 0.37168757486174653`, 0.9370929060664348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 75}], {
             RGBColor[
             0.3843313935505691, 0.5020805374205839, 0.9462194736309155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 89}], {
             RGBColor[
             0.2670176485112967, 0.3979828568550783, 0.9385176321142823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 127}], {
             RGBColor[
             0.5706539535210267, 0.6502280340235855, 0.9632042593205097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 129}], {
             RGBColor[
             0.36049570993893, 0.4827296556793453, 0.9443430413040212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 141}], {
             RGBColor[
             0.30516819016116037`, 0.4348390437291191, 0.9408089710476214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 142}], {
             RGBColor[
             0.2642591851125857, 0.3950835369263521, 0.9383605417045067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 147}], {
             RGBColor[
             0.25802258569367165`, 0.38852847551383163`, 0.9380053765938214]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 149}], {
             RGBColor[
             0.2260121645429709, 0.35488349330652136`, 0.9361824304644635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 155}], {
             RGBColor[
             0.4698552775688525, 0.57104038662686, 0.953275136127212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 167}], {
             RGBColor[
             0.2329271456668488, 0.36215157690284305`, 0.9365762284096705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 168}], {
             RGBColor[
             0.23795894096275363`, 0.36744031279308736`, 0.9368627817078983]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 188}], {
             RGBColor[
             0.28986141659567377`, 0.4215810858075036, 0.939833636971277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 189}], {
             RGBColor[
             0.23047600087590087`, 0.35957526831600095`, 0.9364366393399698]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[
             0.23402121805989123`, 0.3633015163561269, 0.9366385342139192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 197}], {
             RGBColor[
             0.23361320117338766`, 0.3628726647386469, 0.9366152982558398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 97}], {
             RGBColor[
             0.19804503866908396`, 0.3254882707948695, 0.9345897440196007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 105}], {
             RGBColor[
             0.19252363925225727`, 0.3196849299308422, 0.9342753084909909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.20340607327822147`, 0.3311230580782995, 0.9348950470096511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 71}], {
             RGBColor[
             0.2853246797443417, 0.4121402643323634, 0.939746356828151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 73}], {
             RGBColor[
             0.21219498840003925`, 0.3403607651207339, 0.9353955627238038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 129}], {
             RGBColor[
             0.33069083838516217`, 0.4514028459383327, 0.9426456979613903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 141}], {
             RGBColor[
             0.2753633186073925, 0.40351223398810643`, 0.9391116277049905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 149}], {
             RGBColor[
             0.19620729298920309`, 0.32355668356550876`, 0.9344850871218325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 167}], {
             RGBColor[
             0.20312227411308098`, 0.33082476716183046`, 0.9348788850670395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 168}], {
             RGBColor[
             0.2081540694089858, 0.33611350305207477`, 0.9351654383652672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 189}], {
             RGBColor[
             0.20067112932213305`, 0.3282484585749883, 0.9347392959973388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 194}], {
             RGBColor[
             0.2042163465061234, 0.3319747066151143, 0.9349411908712882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 197}], {
             RGBColor[
             0.2038083296196198, 0.3315458549976343, 0.9349179549132087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 42}], {
             RGBColor[
             0.2061681954908564, 0.33402622365244206`, 0.935052345783467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 51}], {
             RGBColor[
             0.19588138072155636`, 0.3232141291081808, 0.934466526900334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 71}], {
             RGBColor[
             0.28665240734323405`, 0.41353579022159115`, 0.939821968950711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 73}], {
             RGBColor[
             0.21352271599893158`, 0.34175629100996163`, 0.9354711748463638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 76}], {
             RGBColor[
             0.23690732447147297`, 0.36633499718441476`, 0.936802893704447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 81}], {
             RGBColor[
             0.2577980406427003, 0.3882924644282822, 0.9379925890853533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 87}], {
             RGBColor[
             0.213134602991505, 0.3413483596313704, 0.9354490723847526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 89}], {
             RGBColor[
             0.2385405045564212, 0.3680515730032935, 0.9368959008942113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 106}], {
             RGBColor[
             0.19729813455436623`, 0.32470322721384515`, 0.9345472089352131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 107}], {
             RGBColor[
             0.21359959388546113`, 0.3418370945430438, 0.935475552928271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 130}], {
             RGBColor[
             0.1969307686942434, 0.3243171024025152, 0.9345262879929481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 131}], {
             RGBColor[
             0.19553065372363834`, 0.3228454927959929, 0.9344465535166567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 142}], {
             RGBColor[
             0.23578204115771023`, 0.3651522530745672, 0.9367388104844356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 147}], {
             RGBColor[
             0.22954544173879612`, 0.3585971916620468, 0.9363836453737505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 157}], {
             RGBColor[
             0.20799556171362626`, 0.3359469014142835, 0.9351564115865076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 168}], {
             RGBColor[
             0.2094817970078781, 0.3375090289413025, 0.9352410504878272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 176}], {
             RGBColor[
             0.22182699852969923`, 0.3504846184717214, 0.9359440914514059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 188}], {
             RGBColor[
             0.2613842726407983, 0.39164980195571875`, 0.938211905751206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 197}], {
             RGBColor[
             0.20513605721851214`, 0.33294138088686204`, 0.9349935670357687]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 34}], {
             RGBColor[
             0.48100947040442327`, 0.5889125969543878, 0.9524604831380885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[
             0.5188959987209247, 0.6203021736168226, 0.9552685402794356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 45}], {
             RGBColor[
             0.62150237913985, 0.702550504593909, 0.964065451798632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 64}], {
             RGBColor[
             0.5807463788000884, 0.6705150984929575, 0.9601376287646749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 65}], {
             RGBColor[
             0.7441501726839835, 0.7476457221603776, 0.6205905714253708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 132}], {
             RGBColor[
             0.4162636354385904, 0.5320766653506034, 0.9483626292299419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 138}], {
             RGBColor[
             0.3769176966090809, 0.4907215889641815, 0.9461219362207016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 153}], {
             RGBColor[
             0.4071092490619125, 0.522454824847095, 0.9478413004684911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 156}], {
             RGBColor[
             0.723132374813741, 0.30688840243812476`, 0.4291372901014996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 182}], {
             RGBColor[
             0.43639733566624106`, 0.5502718081152633, 0.9496178373615334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 185}], {
             RGBColor[
             0.38200599992585305`, 0.49606971836717273`, 0.9464117075671216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 199}], {
             RGBColor[
             0.763611242939182, 0.811608878069138, 0.8422514778526693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 39}], {
             RGBColor[
             0.2190345544466123, 0.34754958268921615`, 0.9357850658919249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 57}], {
             RGBColor[
             0.1839232484123208, 0.31064537386179486`, 0.9337855289557946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 103}], {
             RGBColor[
             0.1835438669532831, 0.31024661989417246`, 0.9337639237429469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 117}], {
             RGBColor[
             0.1856648230786062, 0.31247587925827236`, 0.9338847090566107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 133}], {
             RGBColor[
             0.21756503028546625`, 0.3460050196226384, 0.9357013786649139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 152}], {
             RGBColor[
             0.19309625212307593`, 0.3202867823638255, 0.9343079179468792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 178}], {
             RGBColor[
             0.1848271249653814, 0.311595405428145, 0.9338370033883259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 44}], {
             RGBColor[
             0.9456987231028435, 0.812227711259105, 0.5045786610453252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 58}], {
             RGBColor[
             0.9766001096917556, 0.9806681950826337, 0.8617640508368762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 68}], {
             RGBColor[
             0.9768074272678445, 0.9356471682387506, 0.5374347809068445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 77}], {
             RGBColor[
             0.8757538475255878, 0.41982388651208413`, 0.36678217312343336`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 96}], {
             RGBColor[
             0.9645200001324366, 0.9716588691526575, 0.8822125253236324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 99}], {
             RGBColor[
             0.772222119980282, 0.8191247933841846, 0.8648855062678112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 102}], {
             RGBColor[
             0.9808995951414665, 0.9838747442912669, 0.8544861434559147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 128}], {
             RGBColor[
             0.7119650853654641, 0.7696077577835532, 0.8603069871100877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 140}], {
             RGBColor[
             0.9931733912441731, 0.9901003146609737, 0.6650510516491244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 162}], {
             RGBColor[
             0.7220177660315357, 0.778314884514083, 0.8609475350328932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 172}], {
             RGBColor[
             0.9309821433575884, 0.7454031597804265, 0.49229878616950506`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 180}], {
             RGBColor[
             0.6673282092975037, 0.7309455392481101, 0.857462764837877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 40}], {
             RGBColor[
             0.4679436932956409, 0.5783052104909272, 0.9514318973025666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 45}], {
             RGBColor[
             0.5705500737145661, 0.6605535414680137, 0.960228808821763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 54}], {
             RGBColor[
             0.7092249646791587, 0.7597119219751208, 0.6790161754635967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 64}], {
             RGBColor[
             0.5297940733748047, 0.6285181353670621, 0.956300985787806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 65}], {
             RGBColor[
             0.6931978672586998, 0.7056487590344823, 0.6167539284485017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 132}], {
             RGBColor[
             0.3653113300133066, 0.4900797022247081, 0.9445259862530728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 138}], {
             RGBColor[
             0.32596539118379714`, 0.4487246258382862, 0.9422852932438326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 153}], {
             RGBColor[
             0.3561569436366287, 0.48045786172119975`, 0.9440046574916221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 182}], {
             RGBColor[
             0.3854450302409573, 0.5082748449893679, 0.9457811943846643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 185}], {
             RGBColor[
             0.3310536945005693, 0.45407275524127744`, 0.9425750645902526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 199}], {
             RGBColor[
             0.7126589375138983, 0.7696119149432428, 0.8384148348758003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 86}], {
             RGBColor[
             0.19143714046786142`, 0.31854295082044043`, 0.9342134339925504]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.1855941681935362, 0.31240161649428533`, 0.9338806853654305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 110}], {
             RGBColor[
             0.18045196756199675`, 0.30699683759618646`, 0.9335878446466683]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 174}], {
             RGBColor[
             0.18540537254043327`, 0.31220318029253835`, 0.9338699337322844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 63}], {
             RGBColor[
             0.1871120628164008, 0.3139970199829937, 0.9339671272186787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 70}], {
             RGBColor[
             0.18680103840766088`, 0.3136701136093215, 0.9339494148387204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 110}], {
             RGBColor[
             0.18133894646584242`, 0.3079291086618389, 0.9336383567830746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 138}], {
             RGBColor[
             0.20221257093783607`, 0.32986861144613544`, 0.9348270788169946]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 145}], {
             RGBColor[
             0.1863723647153286, 0.3132195503791984, 0.9339250025061079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 185}], {
             RGBColor[
             0.2073008742546082, 0.33521674084912667`, 0.9351168501634146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 45}], {
             RGBColor[
             0.47344467906469456`, 0.5697056609217193, 0.9542881258612889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 47}], {
             RGBColor[
             0.21605368220731502`, 0.34441649696749876`, 0.9356153096277022]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 50}], {
             RGBColor[
             0.21979652604601302`, 0.3483504631519761, 0.935828459047275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 97}], {
             RGBColor[
             0.22632286746697683`, 0.35521006177935477`, 0.9362001245363418]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 101}], {
             RGBColor[
             0.21602037207300215`, 0.3443814859043514, 0.9356134126648311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 105}], {
             RGBColor[
             0.22080146805015013`, 0.3494067209153274, 0.9358856890077321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 134}], {
             RGBColor[
             0.24135977409579584`, 0.37101480404118925`, 0.9370564541237432]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 135}], {
             RGBColor[
             0.21639131765151565`, 0.3447713732266772, 0.9356345374667627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 160}], {
             RGBColor[
             0.33951855272220766`, 0.4617555701348826, 0.9431015867680459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 43}], {
             RGBColor[
             0.1854358891920559, 0.31223525522826123`, 0.9338716716104489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 60}], {
             RGBColor[
             0.18105257981885614`, 0.3076281191591622, 0.9336220486261704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 90}], {
             RGBColor[
             0.20419753034223448`, 0.33195492963385337`, 0.9349401193185908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 111}], {
             RGBColor[
             0.200630301320241, 0.32820554575635497`, 0.9347369709030307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 165}], {
             RGBColor[
             0.19346381204820906`, 0.3206731111497857, 0.9343288499408593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 169}], {
             RGBColor[
             0.18660872237456455`, 0.31346797726499653`, 0.9339384627251416]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 41}], {
             RGBColor[
             0.2713842645263738, 0.40257244714637036`, 0.9387663044365115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 74}], {
             RGBColor[
             0.29899639389246113`, 0.42815658036720006`, 0.9404646551119514]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 85}], {
             RGBColor[
             0.26126709675452753`, 0.3919386623526739, 0.9381901466989133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 88}], {
             RGBColor[
             0.2343125277851679, 0.36360770134749604`, 0.9366551238718196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 108}], {
             RGBColor[
             0.2800444750057945, 0.41167487744929976`, 0.9392594906116811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 117}], {
             RGBColor[
             0.21869250923105948`, 0.34719007148075093`, 0.9357655869229098]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 133}], {
             RGBColor[
             0.2505927164379196, 0.38071921184511703`, 0.9375822565312131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 152}], {
             RGBColor[
             0.22612393827552923`, 0.3550009745863041, 0.9361887958131783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 159}], {
             RGBColor[
             0.25347717812255377`, 0.3837509639611013, 0.9377465223569743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 173}], {
             RGBColor[
             0.3099077362629189, 0.437607436708477, 0.9411599161992759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 178}], {
             RGBColor[
             0.21785481111783467`, 0.34630959765062364`, 0.935717881254625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 49}], {
             RGBColor[
             0.46409235069374777`, 0.5749693711032751, 0.9511864931575826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 53}], {
             RGBColor[
             0.5688067096740002, 0.6608219372204345, 0.9591976942746201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 54}], {
             RGBColor[
             0.7471114929956602, 0.7911014986375555, 0.6818242326049438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 64}], {
             RGBColor[
             0.5676806016913061, 0.6599077120294969, 0.959109042929153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.7310843955752011, 0.737038335696917, 0.6195619855898489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 69}], {
             RGBColor[
             0.37782213400795434`, 0.4947977837110262, 0.9458889334343104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 119}], {
             RGBColor[
             0.7331606540356427, 0.4438514188607542, 0.44639585966273576`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 123}], {
             RGBColor[
             0.4784773066745961, 0.5874288969649759, 0.9521030898325651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 132}], {
             RGBColor[
             0.40319785832980803`, 0.5214692788871429, 0.94733404339442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 171}], {
             RGBColor[
             0.40679020531210003`, 0.5252450633334856, 0.9475386222406603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 182}], {
             RGBColor[
             0.4233315585574587, 0.5396644216518027, 0.9485892515260115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 191}], {
             RGBColor[
             0.6579669038121483, 0.7306365663260646, 0.9679735835576617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 195}], {
             RGBColor[
             0.5034310381865006, 0.6077470219664445, 0.9540510819361487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 196}], {
             RGBColor[
             0.3694081793861806, 0.4859541839280068, 0.9454097711659308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 199}], {
             RGBColor[
             0.7505454658303996, 0.8010014916056775, 0.8412228920171474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 74}], {
             RGBColor[
             0.31831841781976944`, 0.44846525260187575`, 0.9415650157902389]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 85}], {
             RGBColor[
             0.2805891206818358, 0.4122473345873495, 0.9392905073772007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.2536345517124762, 0.3839163735821717, 0.937755484550107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 108}], {
             RGBColor[
             0.29936649893310274`, 0.4319835496839754, 0.9403598512899686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 121}], {
             RGBColor[
             0.25402964955357293`, 0.38433164646381435`, 0.9377779847876626]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 133}], {
             RGBColor[
             0.2699147403652278, 0.4010278840797926, 0.9386826172095004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 140}], {
             RGBColor[
             0.6422147641826323, 0.7059320445833706, 0.7490291245213738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 151}], {
             RGBColor[
             0.6423047351050197, 0.7073139713016436, 0.8452851258395946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 152}], {
             RGBColor[
             0.2454459622028375, 0.3753096468209797, 0.9372891564914656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 159}], {
             RGBColor[
             0.27279920204986197`, 0.40405963619577695`, 0.9388468830352616]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 161}], {
             RGBColor[
             0.2872671394725109, 0.41926635574719545`, 0.9396708106680862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 173}], {
             RGBColor[
             0.32922976019022715`, 0.45791610894315266`, 0.9422602768775632]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 51}], {
             RGBColor[
             0.1924833774375055, 0.31964261221079154`, 0.9342730156402028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 71}], {
             RGBColor[
             0.2832544040591832, 0.40996427332420193`, 0.9396284576905798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 73}], {
             RGBColor[
             0.2101247127148807, 0.3381847741125724, 0.9352776635862325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 76}], {
             RGBColor[
             0.23350932118742207`, 0.36276348028702554`, 0.9366093824443157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 81}], {
             RGBColor[
             0.25440003735864936`, 0.3847209475308929, 0.9377990778252221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 87}], {
             RGBColor[
             0.20973659970745412`, 0.3377768427339811, 0.9352555611246214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 89}], {
             RGBColor[
             0.2351425012723703, 0.3644800561059042, 0.93670238963408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 106}], {
             RGBColor[
             0.19390013127031533`, 0.3211317103164559, 0.9343536976750818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 107}], {
             RGBColor[
             0.21020159060141025`, 0.3382655776456545, 0.9352820416681398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 130}], {
             RGBColor[
             0.1935327654101925, 0.32074558550512594`, 0.9343327767328169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 131}], {
             RGBColor[
             0.19213265043958744`, 0.3192739758986036, 0.9342530422565254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 142}], {
             RGBColor[
             0.23238403787365935`, 0.361580736177178, 0.9365452992243044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 147}], {
             RGBColor[
             0.22614743845474522`, 0.3550256747646575, 0.9361901341136192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 149}], {
             RGBColor[
             0.1941370173040445, 0.32138069255734725`, 0.9343671879842612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 157}], {
             RGBColor[
             0.2045975584295754, 0.3323753845168943, 0.9349629003263764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 168}], {
             RGBColor[
             0.20608379372382724`, 0.3339375120439133, 0.935047539227696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 176}], {
             RGBColor[
             0.21842899524564835`, 0.34691310157433214`, 0.9357505801912747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 188}], {
             RGBColor[
             0.2579862693567474, 0.38807828505832953`, 0.9380183944910747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 189}], {
             RGBColor[
             0.19860085363697447`, 0.32607246756682684`, 0.9346213968597675]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 197}], {
             RGBColor[
             0.20173805393446126`, 0.32936986398947277`, 0.9348000557756375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 60}], {
             RGBColor[
             0.18536402715025152`, 0.3121597236660082, 0.9338675791734785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[
             0.20850897767362986`, 0.33648653414069934`, 0.935185649865899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 111}], {
             RGBColor[
             0.2049417486516364, 0.33273715026320094`, 0.934982501450339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 115}], {
             RGBColor[
             0.25238630356085545`, 0.3820238241610014, 0.9377056558638687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 163}], {
             RGBColor[
             0.2357550055079826, 0.36512383689254435`, 0.9367372708441793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 165}], {
             RGBColor[
             0.19777525937960444`, 0.32520471565663167`, 0.9345743804881674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 169}], {
             RGBColor[
             0.19092016970595993`, 0.3179995817718425, 0.9341839932724498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 58}], {
             RGBColor[
             0.9296752902178356, 0.8016782468054864, 0.5944321925119014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 68}], {
             RGBColor[
             0.9298826077939246, 0.7566572199616033, 0.27010292258186963`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 77}], {
             RGBColor[
             0.8444706345429746, 0.3004972543273192, 0.1885609342401168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 96}], {
             RGBColor[
             0.9175951806585165, 0.7926689208755102, 0.6148806669986575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 99}], {
             RGBColor[
             0.7252973005063621, 0.6401348451070372, 0.5975536479428364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 102}], {
             RGBColor[
             0.9339747756675465, 0.8048847960141194, 0.5871542851309398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[
             0.6650402658915442, 0.5906178095064059, 0.5929751287851128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 143}], {
             RGBColor[
             0.8772182848102179, 0.7604919813860003, 0.611670932866671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 166}], {
             RGBColor[
             0.8512516278317916, 0.7399182542257667, 0.6091593456597434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 172}], {
             RGBColor[
             0.8840573238836684, 0.5664132115032791, 0.22496692784453026`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 198}], {
             RGBColor[
             0.6221986923143263, 0.5535105917539171, 0.5902453016000886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 64}], {
             RGBColor[
             0.6702869821102313, 0.7421560430065834, 0.9679059544483493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 112}], {
             RGBColor[
             0.8262269535061243, 0.8650081965468237, 0.9779469895534628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 132}], {
             RGBColor[
             0.5058042387487333, 0.6037176098642293, 0.9561309549136163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 134}], {
             RGBColor[
             0.478958077481094, 0.5755005922270049, 0.9546021057447607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 153}], {
             RGBColor[
             0.49664985237205533`, 0.594095769360721, 0.9556096261521655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 156}], {
             RGBColor[
             0.7828261103538363, 0.35464903211387533`, 0.43431617389061594`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 183}], {
             RGBColor[
             0.823713544812509, 0.7798413316678898, 0.6197525703698252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 47}], {
             RGBColor[
             0.1896200136619846, 0.31663303533497, 0.934109951309154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 50}], {
             RGBColor[
             0.1933628575006826, 0.3205670015194474, 0.9343231007287265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 101}], {
             RGBColor[
             0.18958670352767176`, 0.3165980242718227, 0.9341080543462827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 105}], {
             RGBColor[
             0.19436779950481975`, 0.32162325928279867`, 0.9343803306891837]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 135}], {
             RGBColor[
             0.18995764910618526`, 0.3169879115941485, 0.9341291791482143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 144}], {
             RGBColor[
             0.19073384687984102`, 0.31780374466804207`, 0.9341733824631423]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 50}], {
             RGBColor[
             0.2000038325739316, 0.3275470873835711, 0.9347012944347058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 101}], {
             RGBColor[
             0.19622767860092072`, 0.3235781101359464, 0.934486248052262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 105}], {
             RGBColor[
             0.2010087745780687, 0.32860334514692235`, 0.934758524395163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 134}], {
             RGBColor[
             0.22156708062371444`, 0.3502114282727843, 0.9359292895111742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 135}], {
             RGBColor[
             0.19659862417943424`, 0.3239679974582722, 0.9345073728541936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 144}], {
             RGBColor[
             0.19737482195309003`, 0.32478383053216575`, 0.9345515761691217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 72}], {
             RGBColor[
             0.23184751916348642`, 0.3610168209955353, 0.9365147452774683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 76}], {
             RGBColor[
             0.23737108877035865`, 0.36682244286689847`, 0.9368293043951907]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 81}], {
             RGBColor[
             0.2582618049415859, 0.3887799101107659, 0.938018999776097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 87}], {
             RGBColor[
             0.21359836729039067`, 0.3418358053138541, 0.9354754830754963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 104}], {
             RGBColor[
             0.28879698411440874`, 0.4154790711874804, 0.939955479525905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 106}], {
             RGBColor[
             0.1977618988532519, 0.32519067289632886`, 0.9345736196259569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 147}], {
             RGBColor[
             0.2300092060376818, 0.3590846373445305, 0.9364100560644943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 154}], {
             RGBColor[
             0.2711822856025334, 0.4002221046769836, 0.9388330865127945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 157}], {
             RGBColor[
             0.20845932601251194`, 0.33643434709676723`, 0.9351828222772515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 158}], {
             RGBColor[
             0.2634190473924112, 0.39349797793107355`, 0.9383384198388076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 176}], {
             RGBColor[
             0.2222907628285849, 0.3509720641542051, 0.9359705021421497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 53}], {
             RGBColor[
             0.5270688387556056, 0.6260965211703475, 0.956144232988289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 54}], {
             RGBColor[
             0.7053736220772657, 0.7563760825874686, 0.6787707713186126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 65}], {
             RGBColor[
             0.6893465246568067, 0.7023129196468301, 0.6165085243035178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 69}], {
             RGBColor[
             0.33608426308955985`, 0.46007236766093923`, 0.9428354721479792]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 92}], {
             RGBColor[
             0.33340074855062923`, 0.45725182373587436`, 0.9426826499648912]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 118}], {
             RGBColor[
             0.4066109576924045, 0.5266077075173656, 0.9471298685655758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 119}], {
             RGBColor[
             0.705335406756713, 0.42070114149402954`, 0.44436021880518173`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 123}], {
             RGBColor[
             0.43673943575620155`, 0.552703480914889, 0.949049628546234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 127}], {
             RGBColor[
             0.6485709500663741, 0.7216198574234791, 0.9680261155142653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[
             0.4384127064842775, 0.5541214790792388, 0.9491648974977769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 139}], {
             RGBColor[
             0.3540112919659183, 0.4789148116492719, 0.9438563899218253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 141}], {
             RGBColor[
             0.3830851867065078, 0.5062308671290127, 0.9456308272413769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 146}], {
             RGBColor[
             0.3338791466944457, 0.45775465051721964`, 0.9427098940314549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 155}], {
             RGBColor[
             0.5477722741141999, 0.6424322100267535, 0.9580969923209677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 171}], {
             RGBColor[
             0.36505233439370555`, 0.4905196472833987, 0.9444851609543292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 191}], {
             RGBColor[
             0.6162290328937537, 0.6959111502759776, 0.9649201222713306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 195}], {
             RGBColor[
             0.46169316726810605`, 0.5730216059163575, 0.9509976206498176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 196}], {
             RGBColor[
             0.3276703084677861, 0.4512287678779199, 0.9423563098795996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 199}], {
             RGBColor[
             0.7088075949120052, 0.7662760755555905, 0.8381694307308162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 97}], {
             RGBColor[
             0.21027301783359342`, 0.33834065219542714`, 0.9352861093433454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 101}], {
             RGBColor[
             0.19997052243961871`, 0.3275120763204238, 0.9346993974718347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 105}], {
             RGBColor[
             0.2047516184167667, 0.33253731133139974`, 0.9349716738147356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 134}], {
             RGBColor[
             0.22530992446241244`, 0.3541453944572617, 0.9361424389307468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 135}], {
             RGBColor[
             0.20034146801813224`, 0.3279019636427496, 0.9347205222737662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 144}], {
             RGBColor[
             0.20111766579178803`, 0.32871779671664314`, 0.9347647255886942]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 73}], {
             RGBColor[
             0.19983789794558066`, 0.3273726795683112, 0.9346918447030995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 87}], {
             RGBColor[
             0.19944978493815407`, 0.3269647481897199, 0.9346697422414884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 106}], {
             RGBColor[
             0.1836133165010153, 0.31031961577219463`, 0.9337678787919488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[
             0.1999147758321102, 0.3274534831013933, 0.9346962227850067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 130}], {
             RGBColor[
             0.18324595064089247`, 0.3099334909608647, 0.933746957849684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 131}], {
             RGBColor[
             0.18184583567028742`, 0.3084618813543424, 0.9336672233733925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 147}], {
             RGBColor[
             0.2158606236854452, 0.3442135802203963, 0.9356043152304863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 157}], {
             RGBColor[
             0.19431074366027534`, 0.32156328997263306`, 0.9343770814432435]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 168}], {
             RGBColor[
             0.1957969789545272, 0.32312541749965207`, 0.934461720344563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 189}], {
             RGBColor[
             0.18831403886767445`, 0.3152603730225656, 0.9340355779766345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 197}], {
             RGBColor[
             0.1914512391651612, 0.3185577694452115, 0.9342142368925045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 66}], {
             RGBColor[
             0.18456752137294713`, 0.3113225455926782, 0.9338222193477858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 80}], {
             RGBColor[
             0.20369103159656846`, 0.33142256733828307`, 0.9349112749643229]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 82}], {
             RGBColor[
             0.1987769890735687, 0.32625759707831903`, 0.9346314275123124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 100}], {
             RGBColor[
             0.1956898688928864, 0.3230128380336974, 0.9344556205850076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 120}], {
             RGBColor[
             0.1897634736745903, 0.3167838209041087, 0.9341181211446418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 124}], {
             RGBColor[
             0.20581307491926143`, 0.333652969415751, 0.9350321221922685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 125}], {
             RGBColor[
             0.2249359881773202, 0.35375236371269986`, 0.9361211438124999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 187}], {
             RGBColor[
             0.19453498240935546`, 0.32179897911547406`, 0.934389851508272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 54}], {
             RGBColor[
             0.810087981057518, 0.842228648704628, 0.6867819724356502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 65}], {
             RGBColor[
             0.7940608836370591, 0.7881654857639895, 0.6245197254205552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 69}], {
             RGBColor[
             0.4407986220698122, 0.5459249337780987, 0.9508466732650168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 92}], {
             RGBColor[
             0.4381151075308816, 0.5431043898530338, 0.9506938510819287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 118}], {
             RGBColor[
             0.5113253166726569, 0.612460273634525, 0.9551410696826135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 119}], {
             RGBColor[
             0.7751449794102145, 0.4779361855721358, 0.4497010195498735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 123}], {
             RGBColor[
             0.5414537947364539, 0.6385560470320484, 0.9570608296632714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 127}], {
             RGBColor[
             0.7532853090466265, 0.8074724235406385, 0.9760373166313029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 129}], {
             RGBColor[
             0.5431270654645298, 0.6399740451963982, 0.9571760986148143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 139}], {
             RGBColor[
             0.4587256509461706, 0.5647673777664313, 0.9518675910388628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 141}], {
             RGBColor[
             0.4877995456867602, 0.5920834332461721, 0.9536420283584146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 146}], {
             RGBColor[
             0.438593505674698, 0.543607216634379, 0.9507210951484925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 155}], {
             RGBColor[
             0.6524866330944523, 0.728284776143913, 0.9661081934380052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 171}], {
             RGBColor[
             0.4697666933739579, 0.5763722134005581, 0.9524963620713668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 182}], {
             RGBColor[
             0.48630804661931654`, 0.5907915717188752, 0.9535469913567178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 191}], {
             RGBColor[
             0.720943391874006, 0.781763716393137, 0.9729313233883682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 195}], {
             RGBColor[
             0.5664075262483584, 0.658874172033517, 0.9590088217668552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 196}], {
             RGBColor[
             0.43238466744803844`, 0.5370813339950793, 0.9503675109966372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 199}], {
             RGBColor[
             0.8135219538922576, 0.8521286416727499, 0.8461806318478537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 64}], {
             RGBColor[
             0.8089618730748239, 0.8413144235136905, 0.6866933210901831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 65}], {
             RGBColor[
             0.9723656669587191, 0.9184450471811106, 0.347146263750879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 118}], {
             RGBColor[
             0.6896300999943169, 0.7427398350516461, 0.6777676080129371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 119}], {
             RGBColor[
             0.894014834957988, 0.5647892265168832, 0.26478537843675587`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 123}], {
             RGBColor[
             0.7197585780581139, 0.7688356084491694, 0.6796873679935951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 127}], {
             RGBColor[
             0.9315900923682865, 0.9377519849577597, 0.6986638549616266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 140}], {
             RGBColor[
             0.9910580021453803, 0.9807455899537222, 0.48380004734696136`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 151}], {
             RGBColor[
             0.9911479730677677, 0.9821275166719952, 0.580056048665182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 155}], {
             RGBColor[
             0.8307914164161123, 0.8585643375610341, 0.688734731768329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 171}], {
             RGBColor[
             0.6480714766956179, 0.7066517748176793, 0.6751229004016905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 172}], {
             RGBColor[
             0.9288667542587956, 0.7360484350731749, 0.311047781867342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 191}], {
             RGBColor[
             0.899248175195666, 0.9120432778102582, 0.6955578617186919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 195}], {
             RGBColor[
             0.7447123095700184, 0.789153733450638, 0.681635360097179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 199}], {
             RGBColor[
             0.9918267372139176, 0.9824082030898711, 0.5688071701781774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 90}], {
             RGBColor[
             0.281574426125484, 0.41077439271759675`, 0.9394384697479637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 108}], {
             RGBColor[
             0.3219524714198415, 0.4532142784379034, 0.9417379396935124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 111}], {
             RGBColor[
             0.27800719710349053`, 0.40702500884009835`, 0.9392353213324036]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 115}], {
             RGBColor[
             0.3254517520127096, 0.4563116827378988, 0.9419584757459334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 163}], {
             RGBColor[
             0.3088204539598367, 0.4394116954694417, 0.9409900907262441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.2708407078314586, 0.3994925742335291, 0.9388272003702323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 175}], {
             RGBColor[
             0.4182247539712943, 0.5353839569381427, 0.9482243963930945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 177}], {
             RGBColor[
             0.2766340766323431, 0.4055817721640561, 0.9391571241529215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 183}], {
             RGBColor[
             0.6361311703010923, 0.6254168955585735, 0.6051471025896153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 109}], {
             RGBColor[
             0.19998929422011852`, 0.3275318066519287, 0.9347004664969638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 148}], {
             RGBColor[
             0.18807327130146562`, 0.31500731104493473`, 0.9340218666199227]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 150}], {
             RGBColor[
             0.18756580923325702`, 0.31447393623629405`, 0.933992967405861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 193}], {
             RGBColor[
             0.2060154437903921, 0.33386567193023686`, 0.9350436468001014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 88}], {
             RGBColor[
             0.1992012217508764, 0.32670349252007475`, 0.9346555869356892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 91}], {
             RGBColor[
             0.18403700151578473`, 0.31076493558589874`, 0.9337920070267542]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 103}], {
             RGBColor[
             0.1814602470714449, 0.3080566032892297, 0.9336452646731157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 117}], {
             RGBColor[
             0.18358120319676802`, 0.31028586265332964`, 0.9337660499867794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 121}], {
             RGBColor[
             0.1995963195919732, 0.32711876540171747`, 0.9346780871732447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 152}], {
             RGBColor[
             0.19101263224123774`, 0.3180967657588828, 0.9341892588770478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 164}], {
             RGBColor[
             0.1885063938143962, 0.3154625502675782, 0.9340465323062868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 178}], {
             RGBColor[
             0.1827435050835432, 0.30940538882320234`, 0.9337183443184945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 200}], {
             RGBColor[
             0.1862266556746971, 0.31306640093900795`, 0.9339167045918012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 77}], {
             RGBColor[
             0.8650715589355825, 0.41279091020967174`, 0.42668452743448415`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 96}], {
             RGBColor[
             0.9484965672474285, 0.961109404699039, 0.9720660567902085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 99}], {
             RGBColor[
             0.7561986870952739, 0.8085753289305662, 0.9547390377343874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 102}], {
             RGBColor[
             0.9648761622564584, 0.9733252798376484, 0.9443396749224908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 125}], {
             RGBColor[
             0.6124298936125201, 0.6826137072843086, 0.9449897432593624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 128}], {
             RGBColor[
             0.695941652480456, 0.7590582933299347, 0.9501605185766638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 137}], {
             RGBColor[
             0.6422345288762541, 0.7125398822624958, 0.9467383481519487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 166}], {
             RGBColor[
             0.8821530144207035, 0.9083587380492957, 0.9663447354512944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 170}], {
             RGBColor[
             0.8078923228953876, 0.8503457214275595, 0.9589431237256691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 192}], {
             RGBColor[
             0.7131454310850844, 0.7736227561744136, 0.951349727711992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 198}], {
             RGBColor[
             0.6531000789032383, 0.7219510755774461, 0.9474306913916395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 62}], {
             RGBColor[
             0.19206220882201708`, 0.3191999372922807, 0.9342490307106137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 92}], {
             RGBColor[
             0.21433501599530952`, 0.3426100698089493, 0.9355174341294674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 114}], {
             RGBColor[
             0.1828190891221793, 0.3094848324401137, 0.9337226487176782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 146}], {
             RGBColor[
             0.21481341413912597`, 0.34311289659029465`, 0.935544678196031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 184}], {
             RGBColor[
             0.1830159493280225, 0.30969174499811286`, 0.9337338596151724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 186}], {
             RGBColor[
             0.18364549933831636`, 0.3103534419747078, 0.9337697115569229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[
             0.19287248204991897`, 0.32005158582909543`, 0.934295174572251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 90}], {
             RGBColor[
             0.2041256683004301, 0.33187939807160033`, 0.9349360268816205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 111}], {
             RGBColor[
             0.20055843927843664`, 0.3281300141941019, 0.9347328784660603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 165}], {
             RGBColor[
             0.1933919500064047, 0.32059757958753266`, 0.9343247575038889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 169}], {
             RGBColor[
             0.18653686033276015`, 0.3133924457027435, 0.9339343702881713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 67}], {
             RGBColor[
             0.2316153172023224, 0.36077276201189723`, 0.936501521719292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 79}], {
             RGBColor[
             0.20075917656457537`, 0.3283410018093128, 0.9347443101575417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 84}], {
             RGBColor[
             0.19428775253280067`, 0.3215391248399355, 0.9343757721325461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 122}], {
             RGBColor[
             0.24263213866310665`, 0.37235213987400595`, 0.9371289134035569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 126}], {
             RGBColor[
             0.19350305800530745`, 0.3207143611390335, 0.9343310849400568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 179}], {
             RGBColor[
             0.2879403991921272, 0.41444560530367136`, 0.9399115732194068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 190}], {
             RGBColor[
             0.1957633885191688, 0.3230901118223337, 0.9344598074189618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 192}], {
             RGBColor[
             0.33652735532483224`, 0.4561925991586039, 0.9431004906757697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 114}], {
             RGBColor[
             0.19065828327948256`, 0.31772432253305627`, 0.9341690792278882]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 141}], {
             RGBColor[
             0.2718586483084913, 0.3998286032950302, 0.9389120419161632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 149}], {
             RGBColor[
             0.19270262269030192`, 0.3198730528724325, 0.9342855013330051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 167}], {
             RGBColor[
             0.19961760381417978`, 0.3271411364687542, 0.9346792992782123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 184}], {
             RGBColor[
             0.19085514348532573`, 0.3179312350910555, 0.9341802901253824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 189}], {
             RGBColor[
             0.19716645902323188`, 0.3245648278819121, 0.9345397102085116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 194}], {
             RGBColor[
             0.2007116762072222, 0.32829107592203804`, 0.9347416050824608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 197}], {
             RGBColor[
             0.20030365932071864`, 0.327862224304558, 0.9347183691243814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 70}], {
             RGBColor[
             0.1913615767368444, 0.3184635285481242, 0.9342091307498555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 110}], {
             RGBColor[
             0.18589948479502594`, 0.3127225236006417, 0.9338980726942099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 132}], {
             RGBColor[
             0.24611904809652904`, 0.37601710277136, 0.9373274877373701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 138}], {
             RGBColor[
             0.20677310926701956`, 0.33466202638493814`, 0.9350867947281298]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 145}], {
             RGBColor[
             0.1909329030445121, 0.31801296531800116`, 0.9341847184172432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 153}], {
             RGBColor[
             0.23696466171985112`, 0.36639526226785174`, 0.9368061589759192]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 185}], {
             RGBColor[
             0.2118614125837917, 0.3400101557879294, 0.9353765660745497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 65}], {
             RGBColor[
             0.792934775654365, 0.787251260573052, 0.6244310740750881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 132}], {
             RGBColor[
             0.4650482384089718, 0.5716822037632778, 0.9522031318796592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 138}], {
             RGBColor[
             0.4257022995794623, 0.5303271273768558, 0.949962438870419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 153}], {
             RGBColor[
             0.4558938520322939, 0.5620603632597695, 0.9516818031182084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 156}], {
             RGBColor[
             0.755655443460662, 0.33329209471324106`, 0.43169762520131116`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 182}], {
             RGBColor[
             0.48518193863662246`, 0.5898773465279377, 0.9534583400112507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 185}], {
             RGBColor[
             0.4307906028962345, 0.5356752567798472, 0.9502522102168389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 199}], {
             RGBColor[
             0.8123958459095635, 0.8512144164818124, 0.8460919805023865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 118}], {
             RGBColor[
             0.6736030025738579, 0.6886766721110076, 0.6155053609978421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 119}], {
             RGBColor[
             0.8833301033443486, 0.5287471178897909, 0.2232772137600259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 123}], {
             RGBColor[
             0.7037314806376549, 0.7147724455085309, 0.6174251209785002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 127}], {
             RGBColor[
             0.9155629949478274, 0.8836888220171212, 0.6364016079465316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 140}], {
             RGBColor[
             0.9750309047249213, 0.9266824270130837, 0.4215378003318664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 151}], {
             RGBColor[
             0.9751208756473086, 0.9280643537313567, 0.5177938016500871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 155}], {
             RGBColor[
             0.8147643189956533, 0.8045011746203956, 0.6264724847532339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 156}], {
             RGBColor[
             0.8645913060499254, 0.38471251049152105`, 0.20533292030844175`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 171}], {
             RGBColor[
             0.6320443792751589, 0.6525886118770408, 0.6128606533865955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 172}], {
             RGBColor[
             0.9128396568383367, 0.6819852721325363, 0.24878553485224705`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 191}], {
             RGBColor[
             0.8832210777752071, 0.8579801148696197, 0.6332956147035969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 195}], {
             RGBColor[
             0.7286852121495595, 0.7350905705099995, 0.6193731130820839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 199}], {
             RGBColor[
             0.9757996397934585, 0.9283450401492326, 0.5065449231630825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 78}], {
             RGBColor[
             0.18323872675967784`, 0.30992589820368766`, 0.9337465464603355]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 80}], {
             RGBColor[
             0.20266968703316796`, 0.3303490694451636, 0.9348531109023811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 82}], {
             RGBColor[
             0.1977556445101682, 0.32518409918519964`, 0.9345732634503707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[
             0.18802367047876978`, 0.3149551774354076, 0.9340190419264479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 100}], {
             RGBColor[
             0.1946685243294859, 0.3219393401405779, 0.9343974565230659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 113}], {
             RGBColor[
             0.1939997700984511, 0.32123643704229315`, 0.9343593719589416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 120}], {
             RGBColor[
             0.18874212911118976`, 0.3157103230109893, 0.9340599570827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 124}], {
             RGBColor[
             0.2047917303558609, 0.33257947152263156`, 0.9349739581303267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 136}], {
             RGBColor[
             0.2031791949691239, 0.33088459459052233`, 0.9348821266255843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 187}], {
             RGBColor[
             0.19351363784595493`, 0.32072548122235467`, 0.9343316874463302]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 79}], {
             RGBColor[
             0.22503396848065443`, 0.3538553472238142, 0.9361267236458259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 82}], {
             RGBColor[
             0.2339276106645956, 0.3632031290486195, 0.9366332034112368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 100}], {
             RGBColor[
             0.2308404904839133, 0.3599583700039979, 0.936457396483932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 122}], {
             RGBColor[
             0.26690693057918574`, 0.3978664852885073, 0.9385113268918411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 125}], {
             RGBColor[
             0.2600866097683471, 0.39069789568300034`, 0.9381229197114243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 137}], {
             RGBColor[
             0.289891245032081, 0.42062407066118745`, 0.9398715246040107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 166}], {
             RGBColor[
             0.5298097305765306, 0.6164429264479874, 0.9594779119033563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 170}], {
             RGBColor[
             0.45554903905121463`, 0.5584299098262512, 0.952076300177731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 179}], {
             RGBColor[
             0.3122151911082063, 0.43995995071817273`, 0.941293986707691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 192}], {
             RGBColor[
             0.36080214724091136`, 0.4817069445731053, 0.944482904164054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 71}], {
             RGBColor[
             0.6623649639352431, 0.6847752584173, 0.6236785616506062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 75}], {
             RGBColor[
             0.7315668061877028, 0.7433887217645079, 0.6284543351107399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 81}], {
             RGBColor[
             0.6335105972347094, 0.659531932623991, 0.6218491817852485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 102}], {
             RGBColor[
             0.9650834798325474, 0.9283042529937652, 0.6200104049924591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 127}], {
             RGBColor[
             0.9178893661581602, 0.8915362183675095, 0.645439120800334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 129}], {
             RGBColor[
             0.7077311225760636, 0.7240378400232692, 0.6265779027838456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 140}], {
             RGBColor[
             0.977357275935254, 0.934529823363472, 0.4305753131856688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 143}], {
             RGBColor[
             0.9083269889752188, 0.8839114383656459, 0.6445270527281901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 155}], {
             RGBColor[
             0.817090690205986, 0.812348570970784, 0.6355099976070364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 172}], {
             RGBColor[
             0.9151660280486694, 0.6898326684829248, 0.25782304770604947`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 188}], {
             RGBColor[
             0.6370968292328074, 0.6628892701514275, 0.6220684984511013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 86}], {
             RGBColor[
             0.22595538032998164`, 0.3548238094983426, 0.9361791966875385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 92}], {
             RGBColor[
             0.2471305318648358, 0.3770802363436254, 0.937385090241619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 118}], {
             RGBColor[
             0.32034074100661103`, 0.44643612012511674`, 0.9418323088423037]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 123}], {
             RGBColor[
             0.3504692190704081, 0.47253189352264, 0.9437520688229617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 139}], {
             RGBColor[
             0.2677410752801248, 0.398743224257023, 0.938558830198553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 146}], {
             RGBColor[
             0.24760893000865222`, 0.37758306312497075`, 0.9374123343081827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 171}], {
             RGBColor[
             0.27878211770791206`, 0.41034805989114986`, 0.939187601231057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 174}], {
             RGBColor[
             0.21992361240255348`, 0.34848403897044045`, 0.9358356964272725]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 186}], {
             RGBColor[
             0.21644101520784265`, 0.3448236085093839, 0.9356373676690746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 191}], {
             RGBColor[
             0.5299588162079603, 0.6157395628837288, 0.9596225625480584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 195}], {
             RGBColor[
             0.3754229505823126, 0.4928500185241086, 0.9457000609265455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 196}], {
             RGBColor[
             0.24140009178199262`, 0.37105718048567105`, 0.9370587501563274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 110}], {
             RGBColor[
             0.185588460386286, 0.31239561722696946`, 0.9338803603142515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 132}], {
             RGBColor[
             0.2458080236877891, 0.37569019639768786`, 0.9373097753574117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 138}], {
             RGBColor[
             0.2064620848582796, 0.334335120011266, 0.9350690823481714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.19062187863577218`, 0.31768605894432894`, 0.9341670060372848]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 185}], {
             RGBColor[
             0.21155038817505178`, 0.3396832494142572, 0.9353588536945914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 73}], {
             RGBColor[
             0.29060892456725834`, 0.41769434068172157`, 0.9400472867534765]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 75}], {
             RGBColor[
             0.4329404581640204, 0.5480873032405589, 0.9491738543179573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 76}], {
             RGBColor[
             0.3139935330397997, 0.4422730468561747, 0.9413790056115596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 81}], {
             RGBColor[
             0.334884249211027, 0.4642305141000421, 0.942568700992466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 87}], {
             RGBColor[
             0.29022081155983176`, 0.4172864093031303, 0.9400251842918653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 89}], {
             RGBColor[
             0.315626713124748, 0.4439896226750534, 0.9414720128013241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 107}], {
             RGBColor[
             0.2906858024537879, 0.41777514421480366`, 0.9400516648353837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 127}], {
             RGBColor[
             0.6192630181344778, 0.6962347998435606, 0.9661586400075515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 129}], {
             RGBColor[
             0.40910477455238126`, 0.5287364214993203, 0.947297421991063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 141}], {
             RGBColor[
             0.3537772547746116, 0.4808458095490941, 0.9437633517346631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 142}], {
             RGBColor[
             0.312868249726037, 0.44109030274632716`, 0.9413149223915483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 147}], {
             RGBColor[
             0.3066316503071229, 0.4345352413338067, 0.9409597572808632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 155}], {
             RGBColor[
             0.5184643421823038, 0.6170471524468351, 0.9562295168142538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 168}], {
             RGBColor[
             0.2865680055762049, 0.4134470786130624, 0.93981716239494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 188}], {
             RGBColor[
             0.33847048120912504`, 0.4675878516274786, 0.9427880176583188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 197}], {
             RGBColor[
             0.2822222657868389, 0.40887943055862197`, 0.9395696789428815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 76}], {
             RGBColor[
             0.25872488056116644`, 0.3892666319476351, 0.9380453712475731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 81}], {
             RGBColor[
             0.2796155967323937, 0.4112240991915025, 0.9392350666284796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 104}], {
             RGBColor[
             0.31015077590521656`, 0.43792326026821704`, 0.9411715463782875]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 143}], {
             RGBColor[
             0.5544319884729032, 0.6356036049331575, 0.9619129375714212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 144}], {
             RGBColor[
             0.22584498306262032`, 0.3547077749707548, 0.9361729097264804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 154}], {
             RGBColor[
             0.2925360773933412, 0.42266629375772025`, 0.940049153365177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 158}], {
             RGBColor[
             0.284772839183219, 0.41594216701181014`, 0.93955448669119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 160}], {
             RGBColor[
             0.3481960203596565, 0.4708761388050667, 0.9435957557128356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 176}], {
             RGBColor[
             0.2436445546193927, 0.37341625323494165`, 0.9371865689945322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 181}], {
             RGBColor[
             0.345687120645864, 0.46870305597394574`, 0.9434358908416056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 75}], {
             RGBColor[
             0.3598107668197179, 0.47630780402892936`, 0.9448230602136101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 87}], {
             RGBColor[
             0.2170911202155293, 0.3455069100915008, 0.9356743901875181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.2424970217804455, 0.37221012346342386`, 0.9371212186969768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 107}], {
             RGBColor[
             0.21755611110948542`, 0.34599564500317415`, 0.9357008707310365]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 130}], {
             RGBColor[
             0.20088728591826768`, 0.3284756528626456, 0.9347516057957137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 142}], {
             RGBColor[
             0.23973855838173452`, 0.36931080353469764`, 0.9369641282872011]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 147}], {
             RGBColor[
             0.23350195896282042`, 0.3627557421221772, 0.936608963176516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 149}], {
             RGBColor[
             0.2014915378121197, 0.32911075991486693`, 0.934786017047158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 157}], {
             RGBColor[
             0.21195207893765056`, 0.34010545187441393`, 0.9353817293892732]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 167}], {
             RGBColor[
             0.20840651893599757`, 0.33637884351118863`, 0.9351798149923649]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 168}], {
             RGBColor[
             0.2134383142319024, 0.3416675794014329, 0.9354663682905927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 188}], {
             RGBColor[
             0.26534078986482257`, 0.3958083524158491, 0.9384372235539715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 189}], {
             RGBColor[
             0.20595537414504966`, 0.3338025349243465, 0.9350402259226642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 197}], {
             RGBColor[
             0.20909257444253643`, 0.33709993134699245`, 0.9352188848385342]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 85}], {
             RGBColor[
             0.3082012500479231, 0.4378314678081793, 0.9409888580526407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 88}], {
             RGBColor[
             0.2812466810785635, 0.40950050680300143`, 0.9394538352255469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 93}], {
             RGBColor[
             0.28865865838495014`, 0.4172909648985178, 0.9398759363681078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 95}], {
             RGBColor[
             0.29756419393855826`, 0.4266512474089263, 0.9403830934433266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 121}], {
             RGBColor[
             0.28164177891966025`, 0.4099157796846441, 0.9394763354631025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 140}], {
             RGBColor[
             0.6698268935487197, 0.7315161778042003, 0.7507274751968138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 152}], {
             RGBColor[
             0.2730580915689248, 0.4008937800418094, 0.9389875071669056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 159}], {
             RGBColor[
             0.30041133141594933`, 0.42964376941660665`, 0.9405452337107016]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 161}], {
             RGBColor[
             0.31487926883859824`, 0.44485048896802515`, 0.9413691613435261]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 162}], {
             RGBColor[
             0.39867126833608224`, 0.5197307476573095, 0.9466239585805827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 164}], {
             RGBColor[
             0.2705518531420833, 0.3982595645505048, 0.9388447805961444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 172}], {
             RGBColor[
             0.607635645662135, 0.48681902292365303`, 0.5779752097171944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 173}], {
             RGBColor[
             0.35684188955631446`, 0.48350024216398235`, 0.9439586275530032]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 180}], {
             RGBColor[
             0.34398171160205027`, 0.4723614023913367, 0.9431391883855662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 81}], {
             RGBColor[
             0.40408609146348656`, 0.52284397744725, 0.9473444744525996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 89}], {
             RGBColor[
             0.3848285553772075, 0.5026030860222612, 0.9462477862614576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 118}], {
             RGBColor[
             0.44650486801296785`, 0.559836113284655, 0.9500381665189955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 127}], {
             RGBColor[
             0.6884648603869374, 0.7548482631907685, 0.9709344134676849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 129}], {
             RGBColor[
             0.47830661680484077`, 0.5873498848465282, 0.9520731954511965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 141}], {
             RGBColor[
             0.42297909702707115`, 0.5394592728963019, 0.9485391251947967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 142}], {
             RGBColor[
             0.3820700919784965, 0.49970376609353495`, 0.9460906958516819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 147}], {
             RGBColor[
             0.3758334925595824, 0.4931487046810145, 0.9457355307409967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 155}], {
             RGBColor[
             0.5876661844347633, 0.6756606157940428, 0.9610052902743873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 168}], {
             RGBColor[
             0.3557698478286644, 0.47206054196027025`, 0.9445929358550735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 188}], {
             RGBColor[
             0.40767232346158455`, 0.5262013149746865, 0.9475637911184522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 191}], {
             RGBColor[
             0.656122943214317, 0.729139556043267, 0.9678284202247502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 81}], {
             RGBColor[
             0.28513916633926595`, 0.41702972106286573`, 0.9395496257462019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 87}], {
             RGBColor[
             0.2404757286880707, 0.37008561626595393`, 0.9370061090456012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 89}], {
             RGBColor[
             0.2658816302529869, 0.396788829637877, 0.93845293755506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[
             0.3156743455120887, 0.4437288821395802, 0.9414861054960099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 106}], {
             RGBColor[
             0.2246392602509319, 0.35344048384842863`, 0.9361042455960618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 107}], {
             RGBColor[
             0.2409407195820268, 0.37057435117762727`, 0.9370325895891196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 142}], {
             RGBColor[
             0.26312316685427595`, 0.39388950970915076`, 0.9382958471452842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 143}], {
             RGBColor[
             0.5599555580797754, 0.6414092268045206, 0.9622274966891435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 147}], {
             RGBColor[
             0.2568865674353618, 0.38733444829663033`, 0.9379406820345992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 154}], {
             RGBColor[
             0.29805964700021337`, 0.42847191562908343`, 0.9403637124828994]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[
             0.23533668741019195`, 0.36468415804886706`, 0.9367134482473564]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 158}], {
             RGBColor[
             0.2902964087900912, 0.4217477888831733, 0.9398690458089125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 176}], {
             RGBColor[
             0.24916812422626491`, 0.3792218751063049, 0.9375011281122546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 181}], {
             RGBColor[
             0.3512106902527362, 0.4745086778453089, 0.9437504499593281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 188}], {
             RGBColor[
             0.288725398337364, 0.42038705859030223`, 0.9397689424120548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 83}], {
             RGBColor[
             0.8536746611219712, 0.4041310177770272, 0.4404255720532042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 96}], {
             RGBColor[
             0.8570181525627032, 0.40678469292302094`, 0.44031684375898816`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 99}], {
             RGBColor[
             0.7288195657946002, 0.3050953090773723, 0.4287654977217741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 112}], {
             RGBColor[
             0.8586829748540853, 0.4080263146620374, 0.43749873387487304`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 143}], {
             RGBColor[
             0.8301002219971707, 0.3853333999300143, 0.43817702100433054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 156}], {
             RGBColor[
             0.8177852247685861, 0.1377106078723485, 0.16466445736492355`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 160}], {
             RGBColor[
             0.6926095765883397, 0.2755150891779538, 0.42596556643194017`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 166}], {
             RGBColor[
             0.8127891173448866, 0.371617581823192, 0.4365026295330454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 170}], {
             RGBColor[
             0.7632819896613426, 0.3329422374087012, 0.4315682217159619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 181}], {
             RGBColor[
             0.6909369767791447, 0.27406636729053985`, 0.42585898985112014`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 183}], {
             RGBColor[
             0.8570073690583417, 0.35124840474274827`, 0.19870245441911466`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 192}], {
             RGBColor[
             0.7001173951211405, 0.28179359390660397`, 0.42650595770684385`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 80}], {
             RGBColor[
             0.20236223698329917`, 0.33002591994929253`, 0.9348356020768727]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 82}], {
             RGBColor[
             0.1974481944602994, 0.3248609496893285, 0.9345557546248622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 98}], {
             RGBColor[
             0.18771622042890102`, 0.3146320279395365, 0.9340015331009395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 100}], {
             RGBColor[
             0.1943610742796171, 0.3216161906447068, 0.9343799476975574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 113}], {
             RGBColor[
             0.19369232004858233`, 0.320913287546422, 0.9343418631334333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 120}], {
             RGBColor[
             0.188434679061321, 0.31538717351511814`, 0.9340424482571915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 124}], {
             RGBColor[
             0.20448428030599214`, 0.3322563220267605, 0.9349564493048182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 136}], {
             RGBColor[
             0.2028717449192551, 0.3305614450946512, 0.9348646178000759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 187}], {
             RGBColor[
             0.19320618779608617`, 0.3204023317264835, 0.9343141786208218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 84}], {
             RGBColor[
             0.1877064038111327, 0.31462171005185247`, 0.93400097405908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 122}], {
             RGBColor[
             0.2360507899414387, 0.3654347250859229, 0.9367541153300909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 126}], {
             RGBColor[
             0.1869217092836395, 0.3137969463509505, 0.9339562868665908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 177}], {
             RGBColor[
             0.20578387384021699`, 0.33362227723022, 0.9350304592340161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 179}], {
             RGBColor[
             0.2813590504704592, 0.4075281905155883, 0.9395367751459407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 190}], {
             RGBColor[
             0.18918203979750087`, 0.31617269703425077`, 0.9340850093454959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 82}], {
             RGBColor[
             0.2168791547337895, 0.3452841209308045, 0.9356623190669078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 98}], {
             RGBColor[
             0.2071471807023911, 0.33505519918101245`, 0.9351080975429851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 100}], {
             RGBColor[
             0.2137920345531072, 0.3420393618861828, 0.935486512139603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 113}], {
             RGBColor[
             0.2131232803220724, 0.34133645878789803`, 0.9354484275754789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 116}], {
             RGBColor[
             0.23121046425376574`, 0.3603472358938047, 0.936478465942798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 120}], {
             RGBColor[
             0.20786563933481106`, 0.33581034475659416`, 0.9351490126992371]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 124}], {
             RGBColor[
             0.22391524057948223`, 0.35267949326823644`, 0.9360630137468638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 125}], {
             RGBColor[
             0.243038153837541, 0.3727788875651853, 0.9371520353670952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 136}], {
             RGBColor[
             0.2223027051927452, 0.3509846163361272, 0.9359711822421215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 137}], {
             RGBColor[
             0.2728427891012749, 0.40270506254337235`, 0.9389006402596817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 187}], {
             RGBColor[
             0.21263714806957626`, 0.34082550296795955`, 0.9354207430628674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 198}], {
             RGBColor[
             0.28370833912825916`, 0.4121162558583227, 0.9395929834993725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 87}], {
             RGBColor[
             0.261366444859298, 0.3920430835098213, 0.9381958044265076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 89}], {
             RGBColor[
             0.2867723464242142, 0.41874629688174436`, 0.9396426329359664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 104}], {
             RGBColor[
             0.336565061683316, 0.46568634938344766`, 0.9426758008769163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 107}], {
             RGBColor[
             0.26183143575325407`, 0.39253181842149465`, 0.938222284970026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 142}], {
             RGBColor[
             0.28401388302550323`, 0.4158469769530182, 0.9394855425261907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 143}], {
             RGBColor[
             0.5808462742510027, 0.663366694048388, 0.9634171920700499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 147}], {
             RGBColor[
             0.2777772836065891, 0.4092919155404977, 0.9391303774155055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 154}], {
             RGBColor[
             0.31895036317144065`, 0.45042938287295087`, 0.9415534078638058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 157}], {
             RGBColor[
             0.25622740358141927`, 0.3866416252927345, 0.9379031436282628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 158}], {
             RGBColor[
             0.3111871249613185, 0.44370525612704076`, 0.9410587411898188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 168}], {
             RGBColor[
             0.2577136388756711, 0.38820375281975344`, 0.9379877825295823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 176}], {
             RGBColor[
             0.2700588403974922, 0.4011793423501723, 0.938690823493161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 188}], {
             RGBColor[
             0.3096161145085913, 0.44234452583416967`, 0.9409586377929611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 98}], {
             RGBColor[
             0.20223313817939134`, 0.32989022892104847`, 0.9348282500909746]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 100}], {
             RGBColor[
             0.20887799203010743`, 0.3368743916262188, 0.9352066646875926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 120}], {
             RGBColor[
             0.2029515968118113, 0.3306453744966301, 0.9348691652472267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 124}], {
             RGBColor[
             0.21900119805648247`, 0.34751452300827246`, 0.9357831662948535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 125}], {
             RGBColor[
             0.23812411131454123`, 0.3676139173052213, 0.9368721879150849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 136}], {
             RGBColor[
             0.21738866266974544`, 0.34581964607616317`, 0.935691334790111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 137}], {
             RGBColor[
             0.26792874657827515`, 0.39754009228340836`, 0.9386207928076713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 187}], {
             RGBColor[
             0.2077231055465765, 0.3356605327079955, 0.9351408956108569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 198}], {
             RGBColor[
             0.2787942966052594, 0.4069512855983587, 0.9393131360473621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 122}], {
             RGBColor[
             0.6021548677029418, 0.6767924582408489, 0.9659897173678593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 156}], {
             RGBColor[
             0.8546071106591433, 0.41129823352172423`, 0.4413184867830513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 166}], {
             RGBColor[
             0.8650576677002866, 0.8953688994003288, 0.9869563023793746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 170}], {
             RGBColor[
             0.7907969761749707, 0.8373558827785927, 0.9795546906537492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 175}], {
             RGBColor[
             0.7134786289406714, 0.7747821951592325, 0.9733333335119576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 179}], {
             RGBColor[
             0.6474631282319623, 0.7188859236705143, 0.9687723771837091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 183}], {
             RGBColor[
             0.9313850452704695, 0.8648151337796632, 0.6302560397084783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 192}], {
             RGBColor[
             0.6960500843646674, 0.7606329175254469, 0.9719612946400722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 126}], {
             RGBColor[
             0.1804502852518648, 0.30699506938157317`, 0.9335877488415951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 190}], {
             RGBColor[
             0.18271061576572617`, 0.30937082006487343`, 0.9337164713205002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 88}], {
             RGBColor[
             0.24351738394062986`, 0.3732825887884752, 0.9371793268125088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 117}], {
             RGBColor[
             0.22789736538652144`, 0.3568649589217301, 0.9362897898635989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[
             0.24391248178172664`, 0.37369786167011787`, 0.9372018270500644]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 133}], {
             RGBColor[
             0.25979757259338154`, 0.39039409928609614`, 0.9381064594719022]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 140}], {
             RGBColor[
             0.632097596410786, 0.6952982597896742, 0.7484529667837756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 152}], {
             RGBColor[
             0.2353287944309912, 0.36467586202728325`, 0.9367129987538674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 159}], {
             RGBColor[
             0.26268203427801573`, 0.3934258514020805, 0.9382707252976634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 161}], {
             RGBColor[
             0.2771499717006646, 0.408632570953499, 0.939094652930488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 173}], {
             RGBColor[
             0.31911259241838086`, 0.4472823241494562, 0.941684119139965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 200}], {
             RGBColor[
             0.23054281786445055`, 0.35964549720740835`, 0.9364404444686207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 92}], {
             RGBColor[
             0.22327186579105107`, 0.35200326557327766`, 0.9360263745044504]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[
             0.19625374198187168`, 0.3236055044018397, 0.9344877323232499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 171}], {
             RGBColor[
             0.25492345163412733`, 0.3852710891208021, 0.9378288854938884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 174}], {
             RGBColor[
             0.19606494632876875`, 0.3234070682000927, 0.9344769806901039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 196}], {
             RGBColor[
             0.2175414257082079, 0.3459802097153233, 0.9357000344191588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 89}], {
             RGBColor[
             0.24210890877301894`, 0.37180219208483256`, 0.9370991162353657]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 106}], {
             RGBColor[
             0.20086653877096394`, 0.3284538462953842, 0.9347504242763673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 107}], {
             RGBColor[
             0.21716799810205883`, 0.34558771362458285`, 0.9356787682694253]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 130}], {
             RGBColor[
             0.20049917291084113`, 0.3280677214840543, 0.9347295033341025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 131}], {
             RGBColor[
             0.19909905794023608`, 0.326596111877532, 0.934649768857811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 142}], {
             RGBColor[
             0.23935044537430794`, 0.3689028721561064, 0.9369420258255899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 147}], {
             RGBColor[
             0.23311384595539386`, 0.3623478107435859, 0.9365868607149048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[
             0.2742869255202454, 0.40348527807603907`, 0.9390098911632051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 157}], {
             RGBColor[
             0.21156396593022397`, 0.3396975204958227, 0.9353596269276621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 168}], {
             RGBColor[
             0.21305020122447582`, 0.34125964802284164`, 0.9354442658289815]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 176}], {
             RGBColor[
             0.22539540274629694`, 0.3542352375532605, 0.9361473067925603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 188}], {
             RGBColor[
             0.264952676857396, 0.39540042103725787`, 0.9384151210923604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 91}], {
             RGBColor[
             0.20139859473617852`, 0.32901307084912135`, 0.93478072407648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 93}], {
             RGBColor[
             0.22397479227765688`, 0.3527420858788138, 0.936066405127976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 95}], {
             RGBColor[
             0.23288032783126497`, 0.3621023683892223, 0.9365735622031948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 103}], {
             RGBColor[
             0.1988218402918387, 0.32630473855245234`, 0.9346339817228415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 117}], {
             RGBColor[
             0.2009427964171618, 0.32853399791655225`, 0.9347547670365053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 121}], {
             RGBColor[
             0.21695791281236698`, 0.34536690066494, 0.9356668042229707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 152}], {
             RGBColor[
             0.20837422546163153`, 0.3363449010221054, 0.9351779759267738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 159}], {
             RGBColor[
             0.23572746530865607`, 0.3650948903969026, 0.9367357024705698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 161}], {
             RGBColor[
             0.25019540273130497`, 0.38030160994832113`, 0.9375596301033943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 164}], {
             RGBColor[
             0.20586798703479003`, 0.3337106855308008, 0.9350352493560126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 173}], {
             RGBColor[
             0.2921580234490212, 0.41895136314427833`, 0.9401490963128714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 180}], {
             RGBColor[
             0.279297845494757, 0.4078125233716327, 0.9393296571454344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 200}], {
             RGBColor[
             0.20358824889509092`, 0.3313145362022305, 0.9349054216415271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 106}], {
             RGBColor[
             0.22627244033588012`, 0.3551570596673073, 0.9361972527858261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 107}], {
             RGBColor[
             0.24257389966697504`, 0.37229092699650596`, 0.9371255967788841]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 142}], {
             RGBColor[
             0.2647563469392241, 0.39560608552802945`, 0.9383888543350487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 147}], {
             RGBColor[
             0.25851974752031004`, 0.38905102411550896`, 0.9380336892243635]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 154}], {
             RGBColor[
             0.29969282708516165`, 0.4301884914479621, 0.9404567196726639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 157}], {
             RGBColor[
             0.23696986749514018`, 0.36640073386774574`, 0.9368064554371207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 168}], {
             RGBColor[
             0.23845610278939203`, 0.36796286139476475`, 0.9368910943384403]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 176}], {
             RGBColor[
             0.25080130431121317`, 0.3809384509251836, 0.937594135302019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 188}], {
             RGBColor[
             0.29035857842231216`, 0.42210363440918097`, 0.939861949601819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 111}], {
             RGBColor[
             0.22370338980181498`, 0.3524568246687931, 0.9360509491584807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 115}], {
             RGBColor[
             0.27114794471103404`, 0.4017434985665935, 0.9387741035720105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 163}], {
             RGBColor[
             0.2545166466581612, 0.38484351129813643`, 0.9378057185523212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 165}], {
             RGBColor[
             0.21653690052978303`, 0.3449243900622238, 0.9356428281963094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 169}], {
             RGBColor[
             0.20968181085613852`, 0.3377192561774346, 0.9352524409805917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 175}], {
             RGBColor[
             0.36392094666961883`, 0.4808157727668374, 0.9450400242191717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 177}], {
             RGBColor[
             0.22233026933066752`, 0.35101358799275084`, 0.9359727519789987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 103}], {
             RGBColor[
             0.18365762005674702`, 0.31036618161827634`, 0.9337704018139066]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 117}], {
             RGBColor[
             0.1857785761820701, 0.31259544098237624`, 0.9338911871275704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 121}], {
             RGBColor[
             0.2017936925772753, 0.329428343730764, 0.9348032243140356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 152}], {
             RGBColor[
             0.19321000522653986`, 0.3204063440879294, 0.9343143960178388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 159}], {
             RGBColor[
             0.22056324507356437`, 0.3491563334627266, 0.9358721225616348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 164}], {
             RGBColor[
             0.19070376679969833`, 0.3177721285966248, 0.9341716694470776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 200}], {
             RGBColor[
             0.18842402865999922`, 0.3153759792680545, 0.9340418417325922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 118}], {
             RGBColor[
             0.31765722646768046`, 0.4436155762000519, 0.9416794866592155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 123}], {
             RGBColor[
             0.34778570453147756`, 0.4697113495975751, 0.9435992466398737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 139}], {
             RGBColor[
             0.26505756074119424`, 0.3959226803319581, 0.938406008015465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 141}], {
             RGBColor[
             0.29413145548178377`, 0.42323873581169885`, 0.9401804453350167]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 146}], {
             RGBColor[
             0.24492541546972163`, 0.3747625191999059, 0.9372595121250946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 171}], {
             RGBColor[
             0.2760986031689815, 0.40752751596608494`, 0.939034779047969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 174}], {
             RGBColor[
             0.2172400978636229, 0.3456634950453756, 0.9356828742441843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 186}], {
             RGBColor[
             0.21375750066891208`, 0.34200306458431906`, 0.9354845454859864]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 191}], {
             RGBColor[
             0.5272753016690297, 0.6129190189586639, 0.9594697403649703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 195}], {
             RGBColor[
             0.372739436043382, 0.49002947459904367`, 0.9455472387434574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 196}], {
             RGBColor[
             0.23871657724306206`, 0.3682366365606061, 0.9369059279732393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 95}], {
             RGBColor[
             0.24029230513765162`, 0.36989282648473865`, 0.9369956633457557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 121}], {
             RGBColor[
             0.22436989011875363`, 0.3531573587604565, 0.9360889053655316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 150}], {
             RGBColor[
             0.21197440955790398`, 0.3401289227721434, 0.9353830010850614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 159}], {
             RGBColor[
             0.24313944261504272`, 0.37288534849241906`, 0.9371578036131307]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 161}], {
             RGBColor[
             0.2576073800376916, 0.38809206804383756`, 0.9379817312459552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 162}], {
             RGBColor[
             0.34139937953517563`, 0.46297232673312194`, 0.9432365284830118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 164}], {
             RGBColor[
             0.2132799643411767, 0.3415011436263172, 0.9354573504985735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 173}], {
             RGBColor[
             0.29957000075540785`, 0.42674182123979476`, 0.9405711974554323]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 180}], {
             RGBColor[
             0.28670982280114365`, 0.41560298146714914`, 0.9397517582879953]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 200}], {
             RGBColor[
             0.21100022620147757`, 0.339104994297747, 0.935327522784088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 174}], {
             RGBColor[
             0.19022197405444352`, 0.31726573387393764`, 0.9341442320629838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 196}], {
             RGBColor[
             0.21169845343388266`, 0.3398388753891681, 0.9353672857920389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 121}], {
             RGBColor[
             0.23327542567236176`, 0.36251764127086494`, 0.9365960624407503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 150}], {
             RGBColor[
             0.2208799451115121, 0.3494892052825519, 0.9358901581602801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 159}], {
             RGBColor[
             0.2520449781686508, 0.3822456310028275, 0.9376649606883494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 161}], {
             RGBColor[
             0.26651291559129975`, 0.397452350554246, 0.9384888883211739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 162}], {
             RGBColor[
             0.35030491508878375`, 0.4723326092435304, 0.9437436855582304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 164}], {
             RGBColor[
             0.22218549989478478`, 0.35086142613672566`, 0.9359645075737923]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 173}], {
             RGBColor[
             0.308475536309016, 0.4361021037502032, 0.9410783545306509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 180}], {
             RGBColor[
             0.2956153583547517, 0.42496326397755757`, 0.9402589153632142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 99}], {
             RGBColor[
             0.7441185775359549, 0.79956600300059, 0.9751875122211435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 102}], {
             RGBColor[
             0.9527960526971394, 0.9643159539076722, 0.964788149409247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 125}], {
             RGBColor[
             0.600349784053201, 0.6736043813543324, 0.9654382177461185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 128}], {
             RGBColor[
             0.683861542921137, 0.7500489673999585, 0.97060899306342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 137}], {
             RGBColor[
             0.630154419316935, 0.7035305563325196, 0.9671868226387048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 166}], {
             RGBColor[
             0.8700729048613844, 0.8993494121193195, 0.9867932099380505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 170}], {
             RGBColor[
             0.7958122133360686, 0.8413363954975833, 0.9793915982124253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 198}], {
             RGBColor[
             0.6410199693439192, 0.7129417496474699, 0.9678791658783956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 105}], {
             RGBColor[
             0.21127795983773054`, 0.3393969099587784, 0.9353433393038026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 134}], {
             RGBColor[
             0.23183626588337625`, 0.3610049930846403, 0.9365141044198138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 135}], {
             RGBColor[
             0.20686780943909605`, 0.33476156227012827`, 0.9350921877628332]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 153}], {
             RGBColor[
             0.24952804077433757`, 0.37960017021835646`, 0.9375216248272185]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 100}], {
             RGBColor[
             0.19914601799870904`, 0.3266454698764268, 0.9346524431636698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 109}], {
             RGBColor[
             0.2049550918267402, 0.33275117478624117`, 0.9349832613244216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 113}], {
             RGBColor[
             0.19847726376767427`, 0.32594256677814204`, 0.9346143585995457]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 116}], {
             RGBColor[
             0.21656444769936758`, 0.34495334388404864`, 0.9356443969668649]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 120}], {
             RGBColor[
             0.19321962278041294`, 0.32041645274683817`, 0.9343149437233039]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 124}], {
             RGBColor[
             0.20926922402508408`, 0.3372856012584804, 0.9352289447709307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 125}], {
             RGBColor[
             0.22839213728314284`, 0.35738499555542924`, 0.936317966391162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 136}], {
             RGBColor[
             0.20765668863834705`, 0.33559072432637116`, 0.9351371132661883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 187}], {
             RGBColor[
             0.1979911315151781, 0.3254316109582035, 0.9345866740869342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 102}], {
             RGBColor[
             0.7604981725449849, 0.8117818781391992, 0.9474611303534258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 109}], {
             RGBColor[
             0.38461485844464394`, 0.49643648481667146`, 0.9467764936235569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 116}], {
             RGBColor[
             0.39622421431727134`, 0.5086386539144789, 0.9474376292660001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 128}], {
             RGBColor[
             0.49156366276898256`, 0.5975148916314856, 0.9532819740075988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 136}], {
             RGBColor[
             0.3873164552562508, 0.49927603435680146`, 0.9469303455653235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 137}], {
             RGBColor[
             0.4378565391647805, 0.5509964805640466, 0.9498598035828838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 162}], {
             RGBColor[
             0.5016163434350541, 0.6062220183620153, 0.9539225219304044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 193}], {
             RGBColor[
             0.3906410080149175, 0.5027703500949796, 0.9471196739266945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 198}], {
             RGBColor[
             0.44872208919176476`, 0.5604076738789969, 0.9505521468225746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 113}], {
             RGBColor[
             0.20512211761839033`, 0.33292672948331237`, 0.9349927731961636]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 120}], {
             RGBColor[
             0.199864476631129, 0.3274006154520085, 0.934693358319922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 124}], {
             RGBColor[
             0.21591407787580016`, 0.3442697639636507, 0.9356073593675487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 125}], {
             RGBColor[
             0.23503699113385892`, 0.36436915826059957`, 0.9366963809877801]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 136}], {
             RGBColor[
             0.21430154248906313`, 0.3425748870315415, 0.9355155278628062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 137}], {
             RGBColor[
             0.26484162639759284`, 0.3942953332387867, 0.9384449858803665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 187}], {
             RGBColor[
             0.2046359853658942, 0.3324157736633738, 0.9349650886835521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 198}], {
             RGBColor[
             0.2757071764245771, 0.40370652655373696`, 0.9391373291200573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 105}], {
             RGBColor[
             0.20097546444375586`, 0.32856833408377506`, 0.9347566274322918]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 134}], {
             RGBColor[
             0.22153377048940157`, 0.350176417209637, 0.9359273925483029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 135}], {
             RGBColor[
             0.1965653140451214, 0.3239329863951249, 0.9345054758913225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 144}], {
             RGBColor[
             0.19734151181877715`, 0.32474881946901846`, 0.9345496792062504]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 128}], {
             RGBColor[
             0.700241137930167, 0.7622648425385679, 0.9428826111957023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 140}], {
             RGBColor[
             0.981449443808876, 0.9827573994159884, 0.747626675734739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 162}], {
             RGBColor[
             0.7102938185962386, 0.7709719692690975, 0.9435231591185078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 172}], {
             RGBColor[
             0.9192581959222914, 0.7380602445354411, 0.5748744102551196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 180}], {
             RGBColor[
             0.6556042618622065, 0.7236026240031248, 0.9400383889234916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 117}], {
             RGBColor[
             0.1832018217377303, 0.30988710868570724`, 0.9337444447739318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 152}], {
             RGBColor[
             0.19063325078220003`, 0.31769801179126034`, 0.9341676536642003]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 178}], {
             RGBColor[
             0.1823641236245055, 0.3090066348555799, 0.933696739105647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 200}], {
             RGBColor[
             0.18584727421565939`, 0.3126676469713855, 0.9338950993789537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 143}], {
             RGBColor[
             0.6113814534238254, 0.6900658551251025, 0.9653536718198579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 154}], {
             RGBColor[
             0.3494855423442635, 0.47712854394966536`, 0.9434898876136137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 158}], {
             RGBColor[
             0.3417223041341413, 0.47040441720375525`, 0.9429952209396267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 160}], {
             RGBColor[
             0.4051454853105788, 0.5253383889970118, 0.9470364899612722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 176}], {
             RGBColor[
             0.300594019570315, 0.4278785034268868, 0.9406273032429688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 181}], {
             RGBColor[
             0.4026365855967863, 0.5231653061658909, 0.9468766250900423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 188}], {
             RGBColor[
             0.34015129368141406`, 0.46904368691088416`, 0.9428951175427689]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 134}], {
             RGBColor[
             0.22631486646654955`, 0.35520165222061295`, 0.936199668891204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 135}], {
             RGBColor[
             0.20134641002226938`, 0.32895822140610087`, 0.9347777522342233]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 144}], {
             RGBColor[
             0.20212260779592514`, 0.3297740544799944, 0.9348219555491514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.20133152966492007`, 0.3289425812070576, 0.9347769048198857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 130}], {
             RGBColor[
             0.1846627044737023, 0.31142258906652903`, 0.933827639884563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 131}], {
             RGBColor[
             0.18326258950309726`, 0.3099509794600067, 0.9337479054082716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 142}], {
             RGBColor[
             0.22351397693716918`, 0.3522577397385811, 0.9360401623760504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 147}], {
             RGBColor[
             0.21727737751825504`, 0.3457026783260606, 0.9356849972653654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 157}], {
             RGBColor[
             0.1957274974930852, 0.3230523880782974, 0.9344577634781225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 176}], {
             RGBColor[
             0.20955893430915817`, 0.33759010513573523`, 0.9352454433430207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 130}], {
             RGBColor[
             0.20096416380479723`, 0.32855645639572767`, 0.9347559838776209]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 131}], {
             RGBColor[
             0.19956404883419218`, 0.32708484678920535`, 0.9346762494013294]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 142}], {
             RGBColor[
             0.23981543626826407`, 0.36939160706777974`, 0.9369685063691083]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[
             0.23357883684934996`, 0.36283654565525925`, 0.9366133412584232]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 154}], {
             RGBColor[
             0.27475191641420155`, 0.4039740129877124, 0.9390363717067235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.2120289568241801, 0.34018625540749603`, 0.9353861074711805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 168}], {
             RGBColor[
             0.21351519211843195`, 0.34174838293451504`, 0.9354707463724999]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 176}], {
             RGBColor[
             0.22586039364025307`, 0.35472397246493387`, 0.9361737873360787]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 188}], {
             RGBColor[
             0.2654176677513521, 0.39588915594893126`, 0.9384416016358788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 111}], {
             RGBColor[
             0.26408143509617243`, 0.39489671038909974`, 0.9383504191040295]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 115}], {
             RGBColor[
             0.3115259900053915, 0.4441833842869002, 0.9410735735175593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 133}], {
             RGBColor[
             0.27857495084464845`, 0.41013031438272207`, 0.9391758033846701]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 151}], {
             RGBColor[
             0.6509649455844404, 0.716416401604573, 0.8457783120147642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 163}], {
             RGBColor[
             0.29489469195251866`, 0.4272833970184431, 0.94010518849787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 165}], {
             RGBColor[
             0.25691494582414054`, 0.38736427578253046`, 0.937942298141858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 175}], {
             RGBColor[
             0.4042989919639763, 0.5232556584871441, 0.9473394941647204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 113}], {
             RGBColor[
             0.2109311914464215, 0.33903243439312675`, 0.9353235913569153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 116}], {
             RGBColor[
             0.2290183753781148, 0.3580432114990334, 0.9363536297242345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 124}], {
             RGBColor[
             0.22172315170383133`, 0.35037546887346516`, 0.9359381775283004]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 128}], {
             RGBColor[
             0.32435782382982603`, 0.44691944921604004`, 0.9421979744658333]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 136}], {
             RGBColor[
             0.22011061631709428`, 0.3486805919413559, 0.935846346023558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 148}], {
             RGBColor[
             0.20549299658683456`, 0.33331654679423195`, 0.9350138942047502]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 193}], {
             RGBColor[
             0.223435169075761, 0.3521749076795341, 0.936035674384929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 138}], {
             RGBColor[
             0.20099999291646117`, 0.32859411506378333`, 0.9347580242925257]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 145}], {
             RGBColor[
             0.18515978669395372`, 0.31194505399684636`, 0.9338559479816391]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 115}], {
             RGBColor[
             0.26758071568904057`, 0.3979941146890951, 0.9385709551564505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 163}], {
             RGBColor[
             0.25094941763616774`, 0.3810941274206381, 0.9376025701367612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 165}], {
             RGBColor[
             0.21296967150778956`, 0.3411750061847254, 0.9354396797807493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 169}], {
             RGBColor[
             0.20611458183414505`, 0.33396987229993624`, 0.9350492925650316]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 175}], {
             RGBColor[
             0.36035371764762536`, 0.477066388889339, 0.9448368758036116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 177}], {
             RGBColor[
             0.21876304030867405`, 0.3472642041152524, 0.9357696035634386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 134}], {
             RGBColor[
             0.5941420485372255, 0.6663173396662936, 0.9607153178159171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 143}], {
             RGBColor[
             0.8985367952768839, 0.9217855718880776, 0.9850776323188054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 156}], {
             RGBColor[
             0.8596154243912574, 0.41519353040673457`, 0.43839164860472024`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 160}], {
             RGBColor[
             0.6923008271636373, 0.757058105759987, 0.9667604504602199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 181}], {
             RGBColor[
             0.6897919274498447, 0.754885022928866, 0.9666005855889899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 183}], {
             RGBColor[
             0.9388975158686406, 0.8706580791071786, 0.6258657824409817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 116}], {
             RGBColor[
             0.22254054731904888`, 0.35123460349093416`, 0.9359847269993585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 124}], {
             RGBColor[
             0.2152453236447654, 0.343566860865366, 0.9355692748034243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 128}], {
             RGBColor[
             0.3178799957707601, 0.44011084120794086`, 0.9418290717409573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 136}], {
             RGBColor[
             0.21363278825802834`, 0.3418719839332567, 0.9354774432986821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 148}], {
             RGBColor[
             0.19901516852776863`, 0.3265079387861328, 0.9346449914798742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 187}], {
             RGBColor[
             0.20396723113485943`, 0.331712870565089, 0.934927004119428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 193}], {
             RGBColor[
             0.21695734101669506`, 0.34536629967143495`, 0.9356667716600531]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 198}], {
             RGBColor[
             0.2750384221935423, 0.4030036234554522, 0.939099244555933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 167}], {
             RGBColor[
             0.19037448411434205`, 0.3174260316165872, 0.9341529172852767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 184}], {
             RGBColor[
             0.18161202378548802`, 0.3082161302388885, 0.9336539081324469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 186}], {
             RGBColor[
             0.18224157379578187`, 0.3088778272154834, 0.9336897600741974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 194}], {
             RGBColor[
             0.19146855650738448`, 0.3185759710698711, 0.9342152230895253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 133}], {
             RGBColor[
             0.2820742314375166, 0.41322771868271746`, 0.939396339437091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 163}], {
             RGBColor[
             0.2983939725453868, 0.4303808013184385, 0.9403257245502908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 165}], {
             RGBColor[
             0.2604142264170086, 0.39046168008252585`, 0.9381628341942789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 175}], {
             RGBColor[
             0.4077982725568444, 0.5263530627871394, 0.9475600302171414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 124}], {
             RGBColor[
             0.2333325075764587, 0.3625776379712726, 0.9365993131707435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 128}], {
             RGBColor[
             0.33596717970245343`, 0.45912161831384746`, 0.9428591101082765]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 136}], {
             RGBColor[
             0.23171997218972168`, 0.36088276103916334`, 0.9365074816660013]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 148}], {
             RGBColor[
             0.21710235245946194`, 0.3455187158920394, 0.9356750298471934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 193}], {
             RGBColor[
             0.2350445249483884, 0.36437707677734155`, 0.9366968100273723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 198}], {
             RGBColor[
             0.29312560612523564`, 0.42201440056135886`, 0.9401292829232522]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 121}], {
             RGBColor[
             0.2013378942582586, 0.3289492707981949, 0.9347772672740609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 152}], {
             RGBColor[
             0.19275420690752315`, 0.3199272711553603, 0.934288438977864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 159}], {
             RGBColor[
             0.22010744675454766`, 0.3486772605301575, 0.9358461655216599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 164}], {
             RGBColor[
             0.19024796848068162`, 0.3172930556640557, 0.9341457124071029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 178}], {
             RGBColor[
             0.18448507974982858`, 0.3112358942196798, 0.9338175244193107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 200}], {
             RGBColor[
             0.1879682303409825, 0.3148969063354854, 0.9340158846926173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 119}], {
             RGBColor[
             0.6948397253680805, 0.41161030980348123`, 0.44369144326806464`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 123}], {
             RGBColor[
             0.42099591367325284`, 0.5390672333790665, 0.9480464652405584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 127}], {
             RGBColor[
             0.6328274279834254, 0.7079836098876566, 0.9670229522085898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 129}], {
             RGBColor[
             0.4226691844013287, 0.5404852315434163, 0.9481617341921013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 139}], {
             RGBColor[
             0.33826776988296947`, 0.4652785641134494, 0.9428532266161497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[
             0.36734166462355905`, 0.4925946195931902, 0.9446276639357014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 146}], {
             RGBColor[
             0.3181356246114969, 0.44411840298139715`, 0.9417067307257794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 155}], {
             RGBColor[
             0.5320287520312512, 0.6287959624909311, 0.9570938290152922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 171}], {
             RGBColor[
             0.3493088123107567, 0.4768833997475762, 0.9434819976486537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 191}], {
             RGBColor[
             0.6004855108108049, 0.6822749027401551, 0.9639169589656551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.44594964518515734`, 0.559385358380535, 0.9499944573441421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 196}], {
             RGBColor[
             0.3119267863848373, 0.4375925203420974, 0.941353146573924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[
             0.6930640728290565, 0.752639828019768, 0.8371662674251406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 123}], {
             RGBColor[
             0.7149253774106119, 0.4290074920684967, 0.44497128325517005`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 127}], {
             RGBColor[
             0.8561463869507269, 0.5416184097408903, 0.4576222745671909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 140}], {
             RGBColor[
             0.8957916601354561, 0.5702808130715319, 0.3143797361574141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 151}], {
             RGBColor[
             0.895851640750381, 0.5712020975503805, 0.3785504037028946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 155}], {
             RGBColor[
             0.7889472696492774, 0.4888266448097398, 0.4510028591049925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 156}], {
             RGBColor[
             0.8374564716001813, 0.28891243101531533`, 0.18350166554635475`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 172}], {
             RGBColor[
             0.8543308282110663, 0.40714937648450034`, 0.19921155917100125`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 191}], {
             RGBColor[
             0.8345851088356466, 0.5244792716425559, 0.45555161240523445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 195}], {
             RGBColor[
             0.7315611984185482, 0.4425529087361424, 0.44626994465755915`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 199}], {
             RGBColor[
             0.8963041501811476, 0.5713892218289645, 0.37105115137822486`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 124}], {
             RGBColor[
             0.20998768265750406`, 0.3380407468340621, 0.9352698599271827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 125}], {
             RGBColor[
             0.22911059591556282`, 0.35814014113101095`, 0.9363588815474142]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 136}], {
             RGBColor[
             0.208375147270767, 0.3363458699019528, 0.9351780284224404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 137}], {
             RGBColor[
             0.2589152311792967, 0.38806631610919806`, 0.9381074864400005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 187}], {
             RGBColor[
             0.1987095901475981, 0.32618675653378515`, 0.9346275892431862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 198}], {
             RGBColor[
             0.26978078120628096`, 0.39747750942414833`, 0.9387998296796913]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 152}], {
             RGBColor[
             0.20876932330272832`, 0.33676017390374813`, 0.9352004761643293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 159}], {
             RGBColor[
             0.23612256314975283`, 0.36551016327854535`, 0.9367582027081254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 161}], {
             RGBColor[
             0.25059050057240173`, 0.38071688282996385`, 0.9375821303409498]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 164}], {
             RGBColor[
             0.2062630848758868, 0.3341259584124435, 0.9350577495935681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 173}], {
             RGBColor[
             0.292553121290118, 0.41936663602592106`, 0.9401715965504269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 180}], {
             RGBColor[
             0.27969294333585376`, 0.40822779625327543`, 0.9393521573829899]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[
             0.20398334673618768`, 0.33172980908387323`, 0.9349279218790827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 125}], {
             RGBColor[
             0.2711034312291314, 0.40227727354510906`, 0.9387503113956892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 137}], {
             RGBColor[
             0.3009080664928653, 0.4322034485232962, 0.9404989162882755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 166}], {
             RGBColor[
             0.5408265520373148, 0.6280223043100961, 0.9601053035876213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 170}], {
             RGBColor[
             0.4665658605119989, 0.5700092876883599, 0.9527036918619959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 179}], {
             RGBColor[
             0.32323201256899053`, 0.45153932858028145`, 0.9419213783919558]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 192}], {
             RGBColor[
             0.3718189687016956, 0.49328632243521403`, 0.9451102958483188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 127}], {
             RGBColor[
             0.6629559060472224, 0.73407938328518, 0.9689427121892478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 129}], {
             RGBColor[
             0.45279766246512576`, 0.5665810049409397, 0.9500814941727593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 139}], {
             RGBColor[
             0.36839624794676656`, 0.4913743375109727, 0.9447729865968078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 141}], {
             RGBColor[
             0.39747014268735614`, 0.5186903929907134, 0.9465474239163595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 146}], {
             RGBColor[
             0.34826410267529395`, 0.47021417637892043`, 0.9436264907064373]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 155}], {
             RGBColor[
             0.5621572300950483, 0.6548917358884543, 0.9590135889959501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 171}], {
             RGBColor[
             0.3794372903745538, 0.5029791731450995, 0.9454017576293117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 191}], {
             RGBColor[
             0.6306139888746021, 0.7083706761376785, 0.9658367189463131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 195}], {
             RGBColor[
             0.4760781232489544, 0.5854811317780583, 0.9519142173248001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 196}], {
             RGBColor[
             0.3420552644486344, 0.4636882937396207, 0.9432729065545822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 199}], {
             RGBColor[
             0.7231925508928534, 0.7787356014172913, 0.8390860274057987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 125}], {
             RGBColor[
             0.24516019716023396`, 0.37500928964265323`, 0.9372728825950409]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 136}], {
             RGBColor[
             0.22442474851543817`, 0.35321501841359515`, 0.9360920294700671]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.27496483242396785`, 0.4049354646208403, 0.9390214874876273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 187}], {
             RGBColor[
             0.21475919139226923`, 0.3430559050454275, 0.935541590290813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 198}], {
             RGBColor[
             0.28583038245095216`, 0.4143466579357906, 0.9397138307273181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 136}], {
             RGBColor[
             0.24354766177349693`, 0.373314412710544, 0.9371810510902985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 137}], {
             RGBColor[
             0.29408774568202667`, 0.42503485891778914`, 0.9401105091078588]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 166}], {
             RGBColor[
             0.5340062312264762, 0.620853714704589, 0.9597168964072044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[
             0.4597455397011603, 0.5628406980828529, 0.952315284681579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 187}], {
             RGBColor[
             0.233882104650328, 0.36315529934237634`, 0.9366306119110444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 192}], {
             RGBColor[
             0.364998647890857, 0.48611773282970705`, 0.9447218886679021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 198}], {
             RGBColor[
             0.30495329570901086`, 0.43444605223273947`, 0.9408028523475496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 190}], {
             RGBColor[
             0.18192592123823295`, 0.3085460563639715, 0.933671784128011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 129}], {
             RGBColor[
             0.6646291767752983, 0.7354973814495299, 0.9690579811407907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 139}], {
             RGBColor[
             0.5802277622569392, 0.660290714019563, 0.9637494735648391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 140}], {
             RGBColor[
             0.9342553301344888, 0.9459893647897327, 0.7730553915426139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 141}], {
             RGBColor[
             0.6093016569975287, 0.6876067694993037, 0.9655239108843909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 155}], {
             RGBColor[
             0.7739887444052208, 0.8238081123970447, 0.9779900759639816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 172}], {
             RGBColor[
             0.8720640822479042, 0.7012922099091854, 0.6003031260629946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 191}], {
             RGBColor[
             0.8424455031847746, 0.8772870526462687, 0.9848132059143445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 195}], {
             RGBColor[
             0.6879096375591269, 0.7543975082866485, 0.9708907042928315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 199}], {
             RGBColor[
             0.935024065203026, 0.9476519779258816, 0.8580625143738301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 136}], {
             RGBColor[
             0.3270594206414329, 0.44975899875617, 0.9423518264076001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 162}], {
             RGBColor[
             0.4413593088202362, 0.5567049827613839, 0.9493440027726809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 193}], {
             RGBColor[
             0.3303839734000996, 0.45325331449434825`, 0.942541154768971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 198}], {
             RGBColor[
             0.38846505457694686`, 0.5108906382783656, 0.9459736276648509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 139}], {
             RGBColor[
             0.3700695186748425, 0.49279233567532266`, 0.9448882555483507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 141}], {
             RGBColor[
             0.399143413415432, 0.5201083911550634, 0.9466626928679024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 146}], {
             RGBColor[
             0.3499373734033699, 0.4716321745432704, 0.9437417596579802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 155}], {
             RGBColor[
             0.5638305008231241, 0.6563097340528043, 0.959128857947493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 191}], {
             RGBColor[
             0.632287259602678, 0.7097886743020284, 0.965951987897856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 195}], {
             RGBColor[
             0.47775139397703026`, 0.5868991299424082, 0.952029486276343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 131}], {
             RGBColor[
             0.18289522364297445`, 0.3095648546486768, 0.9337269844660065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 149}], {
             RGBColor[
             0.1848995905074315, 0.3116715713074204, 0.9338411301937424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 157}], {
             RGBColor[
             0.19536013163296237`, 0.32266626326696746`, 0.9344368425358576]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 168}], {
             RGBColor[
             0.19684636692721422`, 0.32422839079398647`, 0.9345214814371772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 189}], {
             RGBColor[
             0.18936342684036145`, 0.3163633463169, 0.9340953390692487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 197}], {
             RGBColor[
             0.19250062713784824`, 0.3196607427395459, 0.9342739979851187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 147}], {
             RGBColor[
             0.21550989668752718`, 0.3438449439082084, 0.9355843418468089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 157}], {
             RGBColor[
             0.19396001666235732`, 0.3211946536604452, 0.9343571080595661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 176}], {
             RGBColor[
             0.20779145347843028`, 0.335732370717883, 0.9351447879244643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 138}], {
             RGBColor[
             0.2612195562179643, 0.3918886942345018, 0.9381874393356859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 145}], {
             RGBColor[
             0.24537934999545682`, 0.37523963316756476`, 0.9372853630247993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 153}], {
             RGBColor[
             0.29141110867079584`, 0.42362193011741534`, 0.9399068035834754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 182}], {
             RGBColor[
             0.3206991952751244, 0.45143891338558356`, 0.9416833404765177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 185}], {
             RGBColor[
             0.26630785953473646`, 0.397236823637493, 0.9384772106821059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 163}], {
             RGBColor[
             0.26544293338464375`, 0.39632773141426036`, 0.9384279544174017]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 178}], {
             RGBColor[
             0.21638528695668868`, 0.3447650345840459, 0.9356341940276138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 135}], {
             RGBColor[
             0.22190471606791506`, 0.3505663045319628, 0.9359485173502345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 160}], {
             RGBColor[
             0.3450319511386071, 0.4675505014401682, 0.9434155666515178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 144}], {
             RGBColor[
             0.19771245739729065`, 0.32513870679134427`, 0.9345708040081819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 148}], {
             RGBColor[
             0.2081945933984414, 0.33615609633436194`, 0.9351677461465169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 187}], {
             RGBColor[
             0.2131466560055322, 0.3413610281133182, 0.9354497587860706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 193}], {
             RGBColor[
             0.22613676588736786`, 0.35501445721966407`, 0.9361895263266957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 198}], {
             RGBColor[
             0.2842178470642151, 0.4126517810036814, 0.9396219992225757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 166}], {
             RGBColor[
             0.5638108664902101, 0.6507798896827761, 0.9614655012997908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 170}], {
             RGBColor[
             0.48955017496489417`, 0.59276687306104, 0.9540638895741654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 179}], {
             RGBColor[
             0.3462163270218858, 0.4742969139529616, 0.9432815761041253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 187}], {
             RGBColor[
             0.2636867399140619, 0.3930814743205634, 0.9383792168036308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 192}], {
             RGBColor[
             0.3948032831545909, 0.5160439078078941, 0.9464704935604884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 198}], {
             RGBColor[
             0.3347579309727448, 0.4643722272109265, 0.9425514572401359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 145}], {
             RGBColor[
             0.20603341116594734`, 0.3338845567811428, 0.935044670015559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 153}], {
             RGBColor[
             0.25206516984128635`, 0.38226685373099345`, 0.9376661105742352]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 182}], {
             RGBColor[
             0.28135325644561493`, 0.4100838369991616, 0.9394426474672775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 185}], {
             RGBColor[
             0.22696192070522694`, 0.35588174725107113`, 0.9362365176728656]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 141}], {
             RGBColor[
             0.31474199889707277`, 0.4449017237250964, 0.9413541852919508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 146}], {
             RGBColor[
             0.2655359588850107, 0.39642550711330343`, 0.9384332520820287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 155}], {
             RGBColor[
             0.47942908630476494`, 0.5811030666228374, 0.9538203503715414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 171}], {
             RGBColor[
             0.2967091465842705, 0.42919050387948254`, 0.940208519004903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 191}], {
             RGBColor[
             0.5478858450843187, 0.6345820068720615, 0.9606434803219044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 194}], {
             RGBColor[
             0.2435950267958037, 0.37336419635210427`, 0.9371837484582486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 195}], {
             RGBColor[
             0.39334997945867106`, 0.5116924625124413, 0.9467209787003914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 196}], {
             RGBColor[
             0.25932712065835106`, 0.3898996244740037, 0.9380796679301735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 151}], {
             RGBColor[
             0.9938132108339699, 0.9903648965039682, 0.6544475852461695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 161}], {
             RGBColor[
             0.6387756152014612, 0.7023172809495201, 0.7488332700746612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 162}], {
             RGBColor[
             0.7225676146989453, 0.7771975396388044, 0.7540880673117176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 172}], {
             RGBColor[
             0.931531992024998, 0.7442858149051479, 0.38543931844832946`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 173}], {
             RGBColor[
             0.6807382359191774, 0.7409670341454773, 0.7514227362841381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 180}], {
             RGBColor[
             0.6678780579649132, 0.7298281943728316, 0.7506032971167013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 191}], {
             RGBColor[
             0.9019134129618684, 0.9202806576422312, 0.7699493982996792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 146}], {
             RGBColor[
             0.2946098536256002, 0.4237415625930442, 0.9402076894015805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 155}], {
             RGBColor[
             0.5085029810453545, 0.6084191221025781, 0.9555947876910933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 167}], {
             RGBColor[
             0.27157484914335084`, 0.3995303123785612, 0.9388958799735516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 191}], {
             RGBColor[
             0.5769597398249082, 0.6618980623518022, 0.9624179176414562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 194}], {
             RGBColor[
             0.2726689215363932, 0.40068025183184497`, 0.9389581857778003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 195}], {
             RGBColor[
             0.42242387419926064`, 0.539008517992182, 0.9484954160199432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 147}], {
             RGBColor[
             0.25576128412159904`, 0.3861517041867828, 0.9378765988145878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 154}], {
             RGBColor[
             0.29693436368645065`, 0.4272891715192359, 0.9402996292628881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 157}], {
             RGBColor[
             0.2342114040964292, 0.3635014139390195, 0.9366493650273451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 168}], {
             RGBColor[
             0.23569763939068106`, 0.3650635414660385, 0.9367340039286646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 176}], {
             RGBColor[
             0.24804284091250217`, 0.37803913099645736`, 0.9374370448922433]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.2876001150236012, 0.4192043144804547, 0.9397048591920434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 154}], {
             RGBColor[
             0.5937667549119501, 0.6748088886146058, 0.9642312788067474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 158}], {
             RGBColor[
             0.5860035167018279, 0.6680847618686957, 0.9637366121327604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 160}], {
             RGBColor[
             0.6494266978782655, 0.7230187336619522, 0.967777881154406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 181}], {
             RGBColor[
             0.6469177981644729, 0.7208456508308313, 0.967618016283176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 188}], {
             RGBColor[
             0.5844325062491007, 0.6667240315758246, 0.9636365087359027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 158}], {
             RGBColor[
             0.2574165112915451, 0.3871889319062931, 0.9379965842878197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 153}], {
             RGBColor[
             0.2362249636187789, 0.3656177926640565, 0.9367640342633485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 185}], {
             RGBColor[
             0.2111217144827195, 0.33923268618413416`, 0.935334441361979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 155}], {
             RGBColor[
             0.4592969410332923, 0.5599429054907851, 0.9526738544811711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 171}], {
             RGBColor[
             0.27657700131279794`, 0.4080303427474302, 0.9390620231145327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 184}], {
             RGBColor[
             0.21360634880243462`, 0.34184419438906943`, 0.9354759376107997]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 186}], {
             RGBColor[
             0.2142358988127285, 0.34250589136566434`, 0.9355117895525502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 191}], {
             RGBColor[
             0.527753699812846, 0.6134218457400091, 0.9594969844315341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 194}], {
             RGBColor[
             0.22346288152433108`, 0.352204035220052, 0.9360372525678782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 195}], {
             RGBColor[
             0.37321783418719845`, 0.490532301380389, 0.9455744828100211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 196}], {
             RGBColor[
             0.23919497538687848`, 0.3687394633419514, 0.9369331720398031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 154}], {
             RGBColor[
             0.2906977642675366, 0.42073411010671546`, 0.939944464152203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 157}], {
             RGBColor[
             0.2279748046775151, 0.3569463525264991, 0.9362941999166599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 168}], {
             RGBColor[
             0.22946103997176695`, 0.35850848005351804`, 0.9363788388179795]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 176}], {
             RGBColor[
             0.24180624149358806`, 0.37148406958393687`, 0.9370818797815581]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 188}], {
             RGBColor[
             0.2813635156046871, 0.41264925306793426`, 0.9393496940813583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 150}], {
             RGBColor[
             0.19306951159997304`, 0.3202586763785973, 0.9343063951136474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 193}], {
             RGBColor[
             0.21151914615710812`, 0.33965041207254015`, 0.9353570745078879]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 167}], {
             RGBColor[
             0.19241882352516138`, 0.31957476195596346`, 0.9342693393903937]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 168}], {
             RGBColor[
             0.19745061882106624`, 0.32486349784620777`, 0.9345558926886215]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 189}], {
             RGBColor[
             0.18996767873421347`, 0.31699845336912136`, 0.934129750320693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 194}], {
             RGBColor[
             0.1935128959182038, 0.3207247014092473, 0.9343316451946424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.19310487903170026`, 0.3202958497917673, 0.934308409236563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 156}], {
             RGBColor[
             0.8771128434559579, 0.42716749015211075`, 0.3606061102513105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 172}], {
             RGBColor[
             0.9316219629473853, 0.7456677416234209, 0.4816953197665501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 175}], {
             RGBColor[
             0.7472372281358932, 0.7985860801048122, 0.8522647687143463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 183}], {
             RGBColor[
             0.9651436444656913, 0.888619018725243, 0.5091874749108671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 199}], {
             RGBColor[
             0.9945819459025071, 0.992027509640117, 0.7394547080773856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 159}], {
             RGBColor[
             0.22753887579901738`, 0.3564881636357107, 0.9362693744119284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 178}], {
             RGBColor[
             0.19191650879429833`, 0.319046797325233, 0.9342407333095791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 200}], {
             RGBColor[
             0.19539965938545223`, 0.3227078094410386, 0.9344390935828858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 182}], {
             RGBColor[
             0.3115448088984465, 0.4418170728820753, 0.941162011715067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 185}], {
             RGBColor[
             0.2571534731580585, 0.38761498313398474`, 0.937955881920655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 157}], {
             RGBColor[
             0.2691478842423667, 0.3980838198589522, 0.9387172303649602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 158}], {
             RGBColor[
             0.3241076056222659, 0.45514745069325846`, 0.9418728279265163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 160}], {
             RGBColor[
             0.38753078679870345`, 0.510081422486515, 0.9459140969481619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 176}], {
             RGBColor[
             0.28297932105843965`, 0.41262153691639003`, 0.9395049102298585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 181}], {
             RGBColor[
             0.3850218870849109, 0.5079083396553941, 0.9457542320769319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 188}], {
             RGBColor[
             0.3225365951695387, 0.45378672040038737`, 0.9417727245296585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 172}], {
             RGBColor[
             0.77126540629573, 0.6221045625124598, 0.590374002869697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 191}], {
             RGBColor[
             0.7416468272326004, 0.7980994052495431, 0.9748840827210469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 195}], {
             RGBColor[
             0.5871109616069528, 0.6752098608899229, 0.9609615810995339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 199}], {
             RGBColor[
             0.8342253892508518, 0.868464330529156, 0.8481333911805324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 166}], {
             RGBColor[
             0.8137215668820587, 0.378784797567889, 0.4373955442628925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 170}], {
             RGBColor[
             0.7642144391985147, 0.3401094531533983, 0.43246113644580897`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 175}], {
             RGBColor[
             0.7126688743756485, 0.2983936614071581, 0.42831356501794793`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 183}], {
             RGBColor[
             0.8579398185955138, 0.3584156204874453, 0.19959536914896175`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 199}], {
             RGBColor[
             0.8775653528867244, 0.4273546144306946, 0.3531068579266407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 168}], {
             RGBColor[
             0.2079111599465971, 0.33585818980575477`, 0.9351516050307367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 176}], {
             RGBColor[
             0.2202563614684182, 0.34883377933617365`, 0.9358546459943153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 188}], {
             RGBColor[
             0.25981363557951725`, 0.389998962820171, 0.9381224602941154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 160}], {
             RGBColor[
             0.3797675485885813, 0.503357295740605, 0.945419430274175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 176}], {
             RGBColor[
             0.27521608284831744`, 0.40589741017048, 0.9390102435558715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.37725864887478877`, 0.501184212909484, 0.945259565402945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 161}], {
             RGBColor[
             0.2693600530686908, 0.4004448725619264, 0.938651028588549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 162}], {
             RGBColor[
             0.3531520525661749, 0.4753251312512108, 0.9439058258256054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 164}], {
             RGBColor[
             0.22503263737217588`, 0.35385394814440607`, 0.9361266478411673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 173}], {
             RGBColor[
             0.3113226737864071, 0.4390946257578836, 0.941240494798026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 180}], {
             RGBColor[
             0.29846249583214285`, 0.427955785985238, 0.9404210556305891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 200}], {
             RGBColor[
             0.22275289923247676`, 0.35145779881583583`, 0.9359968201266817]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[
             0.4406818300512263, 0.5561181847027405, 0.9493008344245906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 162}], {
             RGBColor[
             0.3676199899888237, 0.4905318508026293, 0.94472975345843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 164}], {
             RGBColor[
             0.23950057479482478`, 0.3690606676958246, 0.9369505754739917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 173}], {
             RGBColor[
             0.32579061120905595`, 0.4543013453093021, 0.9420644224308505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 180}], {
             RGBColor[
             0.31293043325479175`, 0.4431625055366565, 0.9412449832634135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 200}], {
             RGBColor[
             0.23722083665512567`, 0.36666451836725433`, 0.9368207477595063]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 172}], {
             RGBColor[
             0.6603763668123606, 0.5325003847582571, 0.5813358018320983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 173}], {
             RGBColor[
             0.40958261070654, 0.5291816039985865, 0.947319219667907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 180}], {
             RGBColor[
             0.3967224327522758, 0.5180427642259409, 0.9464997805004701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 165}], {
             RGBColor[
             0.24378292836413576`, 0.3735616928140688, 0.9371944491745896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 175}], {
             RGBColor[
             0.39116697450397153`, 0.5094530755186824, 0.9465916451974521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 177}], {
             RGBColor[
             0.24957629716502022`, 0.3796508907445958, 0.937524372957279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 200}], {
             RGBColor[
             0.19289342095861073`, 0.320073593949734, 0.9342963670121247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 169}], {
             RGBColor[
             0.1989480925621131, 0.32643743769336697`, 0.9346411716028602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 175}], {
             RGBColor[
             0.35318722837559335`, 0.4695339542827697, 0.9444287548414402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 177}], {
             RGBColor[
             0.2115965510366421, 0.3397317695086831, 0.9353614826012671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 170}], {
             RGBColor[
             0.7294686605093437, 0.78858572884784, 0.973670276873511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 179}], {
             RGBColor[
             0.5861348125663353, 0.6701157697397615, 0.962887963403471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 183}], {
             RGBColor[
             0.8700567296048425, 0.8160449798489104, 0.6243716259282402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 192}], {
             RGBColor[
             0.6347217686990404, 0.711862763594694, 0.9660768808598341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 198}], {
             RGBColor[
             0.5746764165171943, 0.6601910829977264, 0.9621578445394816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 189}], {
             RGBColor[
             0.19688265985809134`, 0.32426653696544305`, 0.9345235482659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 194}], {
             RGBColor[
             0.2004278770420817, 0.327992785005569, 0.9347254431398494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 197}], {
             RGBColor[
             0.20001986015557813`, 0.327563933388089, 0.9347022071817699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 188}], {
             RGBColor[
             0.2612998708737691, 0.39156109034719, 0.938207099195435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 189}], {
             RGBColor[
             0.2019144551539962, 0.3295552728556873, 0.9348101015641277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 197}], {
             RGBColor[
             0.20505165545148296`, 0.3328526692783333, 0.9349887604799977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 177}], {
             RGBColor[
             0.20474146136299756`, 0.33252663562389395`, 0.9349710953855495]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 190}], {
             RGBColor[
             0.18813962732028144`, 0.31507705542792475`, 0.9340256454970293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 179}], {
             RGBColor[
             0.5118741210410194, 0.6121027531180253, 0.9554863516778458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 183}], {
             RGBColor[
             0.7957960380795266, 0.7580319632271744, 0.6169700142026149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[
             0.5604610771737245, 0.6538497469729578, 0.9586752691342088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 198}], {
             RGBColor[
             0.5004157249918784, 0.6021780663759904, 0.9547562328138562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 174}], {
             RGBColor[
             0.24889168370669917`, 0.37893131859289997`, 0.9374853852336225]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 182}], {
             RGBColor[
             0.3242915422574164, 0.45521469783192636`, 0.9418879193227581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 191}], {
             RGBColor[
             0.558926887512106, 0.6461868425061883, 0.9612722513544084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 195}], {
             RGBColor[
             0.4043910218864583, 0.5232972981465681, 0.9473497497328954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 196}], {
             RGBColor[
             0.2703681630861383, 0.4015044601081305, 0.9387084389626774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 199}], {
             RGBColor[
             0.6515054495303574, 0.7165517677858011, 0.834521559813894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 173}], {
             RGBColor[
             0.6185469880325928, 0.49626987926492994`, 0.5786704708045187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 180}], {
             RGBColor[
             0.6056868100783286, 0.4851310394922843, 0.577851031637082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 191}], {
             RGBColor[
             0.8397221650752837, 0.6755835027616839, 0.59719713282006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 180}], {
             RGBColor[
             0.35489305397250803`, 0.4818122587326137, 0.9438344494728906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 186}], {
             RGBColor[
             0.18655058120662976`, 0.3134068672111341, 0.9339351516716399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 196}], {
             RGBColor[
             0.21150965778077974`, 0.33964043918742115`, 0.9353565341588927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 183}], {
             RGBColor[
             0.7184776908452273, 0.695458275607814, 0.6107486570608233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 188}], {
             RGBColor[
             0.2736450723955902, 0.4045366798776089, 0.9389101401590136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 179}], {
             RGBColor[
             0.2929650964677688, 0.41972688072457853`, 0.940197722295881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 190}], {
             RGBColor[
             0.20078808579481044`, 0.3283713872432409, 0.9347459564954362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 183}], {
             RGBColor[
             0.6524621901365182, 0.6395620041190959, 0.6061877007325749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 192}], {
             RGBColor[
             0.41712722923071616`, 0.5353797878648794, 0.9478929556641686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 185}], {
             RGBColor[
             0.28644155976238705`, 0.41543196640215296`, 0.9397324188136974]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 195}], {
             RGBColor[
             0.42093237513181697`, 0.5377166564648852, 0.9484003790182465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 196}], {
             RGBColor[
             0.28690951633149697`, 0.41592381842644754`, 0.9397590682480286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 199}], {
             RGBColor[
             0.668046802775716, 0.7309711261041182, 0.8355721890992451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 192}], {
             RGBColor[
             0.7010491462692232, 0.6813089979740284, 0.609376618188938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 186}], {
             RGBColor[
             0.18243843400162507`, 0.3090847397734826, 0.9337009709716915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 194}], {
             RGBColor[
             0.19166541671322765`, 0.3187828836278702, 0.9342264339870195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 198}], {
             RGBColor[
             0.2745522899410462, 0.4024926676355137, 0.9390715600433216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 194}], {
             RGBColor[
             0.19797673225113377`, 0.32541647641872684`, 0.9345858540701487]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 197}], {
             RGBColor[
             0.19756871536463022`, 0.3249876248012469, 0.9345626181120692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 195}], {
             RGBColor[
             0.6555677203865065, 0.728688801139147, 0.9677847110498968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 199}], {
             RGBColor[
             0.9026821480304056, 0.9219432707783801, 0.8549565211308954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 197}], {
             RGBColor[
             0.20111393254862053`, 0.3287138728413728, 0.9347645129860187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 196}], {
             RGBColor[
             0.3670089959605389, 0.4840064187410893, 0.9452208986581658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 199}], {
             RGBColor[
             0.748146282404758, 0.7990537264187598, 0.8410340195093824]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.04610843439966642], {
             RGBColor[
             0.17991592983646426`, 0.30643342795989703`, 0.9335573180911961]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.04610843439966642], {
             RGBColor[
             0.18237351643808017`, 0.30901650729818564`, 0.9336972740124846]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.04610843439966642], {
             RGBColor[
             0.4186929718519593, 0.5370725409226834, 0.947899723824117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.04610843439966642], {
             RGBColor[
             0.33430755049502603`, 0.4639821302779076, 0.9425227593943515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.04610843439966642], {
             RGBColor[
             0.35433408061295757`, 0.481328104103389, 0.9437988321847008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.04610843439966642], {
             RGBColor[
             0.8314330293974257, 0.24261361475573226`, 0.17773361049049105`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.04610843439966642], {
             RGBColor[
             0.20849433214894747`, 0.33647114076567824`, 0.9351848158249345]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.04610843439966642], {
             RGBColor[
             0.28326421471662644`, 0.41505902802867256`, 0.939442850025035]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.04610843439966642], {
             RGBColor[
             0.19331350997927296`, 0.32051513414563226`, 0.9343202904603853]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.04610843439966642], {
             RGBColor[
             0.2179504265625759, 0.34641009554541596`, 0.9357233264127526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.04610843439966642], {
             RGBColor[
             0.20295626314304663`, 0.3306502791066209, 0.9348694309878873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.04610843439966642], {
             RGBColor[
             0.950102117301832, 0.8398785531251466, 0.2787091962084557]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.04610843439966642], {
             RGBColor[
             0.22110598802207443`, 0.3497267907135012, 0.9359030309696362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.04610843439966642], {
             RGBColor[
             0.17925722738073346`, 0.3057410899147761, 0.9335198059608052]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.04610843439966642], {
             RGBColor[
             0.1871756577266932, 0.3140638622658612, 0.9339707488547396]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.04610843439966642], {
             RGBColor[
             0.19146922694525287`, 0.31857667574257903`, 0.9342152612699701]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.04610843439966642], {
             RGBColor[
             0.22306772190849825`, 0.3517886974092449, 0.9360147488123428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.04610843439966642], {
             RGBColor[
             0.35121665541737046`, 0.47862794708531764`, 0.9436001926078689]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.04610843439966642], {
             RGBColor[
             0.1823235017276304, 0.3089639386663871, 0.9336944257487145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.04610843439966642], {
             RGBColor[
             0.36130368564417137`, 0.48736482567889206`, 0.94424292925431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.04610843439966642], {
             RGBColor[
             0.18848942771341942`, 0.31544471781973865`, 0.9340455661119352]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.04610843439966642], {
             RGBColor[
             0.22363768830217948`, 0.3523877682269605, 0.9360472075552733]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.04610843439966642], {
             RGBColor[
             0.2571472380542651, 0.3876084296445695, 0.9379555268407181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.04610843439966642], {
             RGBColor[
             0.17953882470990998`, 0.3060370665620425, 0.9335358425121159]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.04610843439966642], {
             RGBColor[
             0.2927822195605681, 0.4250630545960175, 0.9399848863202711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.04610843439966642], {
             RGBColor[
             0.26652048668465833`, 0.39746030825340095`, 0.9384893194837403]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.04610843439966642], {
             RGBColor[
             0.1792907180836107, 0.3057762907669333, 0.933521713206789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.04610843439966642], {
             RGBColor[
             0.20691074357712266`, 0.33480668877137576`, 0.9350946327984784]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.04610843439966642], {
             RGBColor[
             0.2095661987749073, 0.33759774054983127`, 0.9352458570435983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.04610843439966642], {
             RGBColor[
             0.531961775829707, 0.6309095600802831, 0.9562971261149575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.04610843439966642], {
             RGBColor[
             0.186006868294159, 0.3128353904667376, 0.9339041880256258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.04610843439966642], {
             RGBColor[
             0.9926235425767636, 0.9912176595362523, 0.7719105193703001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.04610843439966642], {
             RGBColor[
             0.4300571649791395, 0.5469156338284925, 0.9486238401612196]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.04610843439966642], {
             RGBColor[
             0.18077756667952594`, 0.30733906291288604`, 0.933606387034731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.04610843439966642], {
             RGBColor[
             0.18255152448721731`, 0.309203605044191, 0.9337074113075435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.04610843439966642], {
             RGBColor[
             0.23584637567939642`, 0.36521987273590373`, 0.9367424742402714]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.04610843439966642], {
             RGBColor[
             0.18112444186066054`, 0.30770365072141526`, 0.9336261410631407]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.04610843439966642], {
             RGBColor[
             0.25206224059906557`, 0.3822637749116947, 0.9376659437582241]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.04610843439966642], {
             RGBColor[
             0.5058302216121423, 0.609694787153362, 0.9542399544439137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.04610843439966642], {
             RGBColor[
             0.29070628845368207`, 0.422881119381046, 0.9398666651147989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.04610843439966642], {
             RGBColor[
             0.2027701922068055, 0.3304547067550528, 0.9348588345233357]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.04610843439966642], {
             RGBColor[
             0.18974733652345127`, 0.3167668597351072, 0.9341172021577572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.04610843439966642], {
             RGBColor[
             0.8987739036289236, 0.6332377629819576, 0.2372468027203504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.04610843439966642], {
             RGBColor[
             0.7110429824499928, 0.7741914491075349, 0.9718337774823064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.04610843439966642], {
             RGBColor[
             0.18297903858873563`, 0.3096529494708463, 0.9337317576031746]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.04610843439966642], {
             RGBColor[
             0.1962609887352336, 0.32361312119909375`, 0.9344881450151332]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.04610843439966642], {
             RGBColor[
             0.21049372737267863`, 0.3385726319147987, 0.9352986784250858]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.04610843439966642], {
             RGBColor[
             0.4223544797753533, 0.5402439550531881, 0.9481330318712514]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.04610843439966642], {
             RGBColor[
             0.20374667641262958`, 0.33148105356804847`, 0.9349144438542785]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.04610843439966642], {
             RGBColor[
             0.18219656266820544`, 0.3088305176665303, 0.9336871967570698]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.04610843439966642], {
             RGBColor[
             0.18558886593634766`, 0.31239604348579764`, 0.9338803834097276]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.04610843439966642], {
             RGBColor[
             0.631783197735858, 0.7119490872875069, 0.9641554341053266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.04610843439966642], {
             RGBColor[
             0.988392764379178, 0.9725082101217492, 0.4094085107659739]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.04610843439966642], {
             RGBColor[
             0.33587823342715956`, 0.465342576888902, 0.9426228419218866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.04610843439966642], {
             RGBColor[
             0.1825695689347496, 0.30922257090263144`, 0.9337084389121362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.04610843439966642], {
             RGBColor[
             0.1818396285304826, 0.30845535725685214`, 0.9336668698859633]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.04610843439966642], {
             RGBColor[
             0.9605766768067475, 0.9701187306290152, 0.9516175823034524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.04610843439966642], {
             RGBColor[
             0.18422301466471383`, 0.3109604471993381, 0.9338026002004038]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.04610843439966642], {
             RGBColor[
             0.18098071777705174`, 0.3075525875969092, 0.9336179561892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.04610843439966642], {
             RGBColor[
             0.2073405252862433, 0.3352584165973958, 0.9351191082310077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.04610843439966642], {
             RGBColor[
             0.1999014029793203, 0.32743942738522325`, 0.9346954612208237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.04610843439966642], {
             RGBColor[
             0.19167260114558432`, 0.31879043492179643`, 0.9342268431298139]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.04610843439966642], {
             RGBColor[
             0.6295309817704698, 0.7101206369056319, 0.9639781314143923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.04610843439966642], {
             RGBColor[
             0.95633856953826, 0.8643818842404721, 0.284884016735784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.04610843439966642], {
             RGBColor[
             0.18354617680954663`, 0.31024904769955874`, 0.9337640552858439]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.04610843439966642], {
             RGBColor[
             0.2558901091184015, 0.3862871074263986, 0.9378839352075763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.04610843439966642], {
             RGBColor[
             0.9609913119589255, 0.8800766769412489, 0.30295904244338884`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.04610843439966642], {
             RGBColor[
             0.24981404640376637`, 0.37990078026869034`, 0.9375379124247071]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.04610843439966642], {
             RGBColor[
             0.19105055232810444`, 0.31813662217445204`, 0.9341914183698972]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.04610843439966642], {
             RGBColor[
             0.3637386159115608, 0.4894738398933511, 0.9443980808578237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.04610843439966642], {
             RGBColor[
             0.2532013109542942, 0.38346101007627187`, 0.9377308121298508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.04610843439966642], {
             RGBColor[
             0.21747923322295587`, 0.34591484147009205`, 0.9356964926491292]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.04610843439966642], {
             RGBColor[
             0.34593054718585675`, 0.47404938582270545`, 0.9432633664656788]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.04610843439966642], {
             RGBColor[
             0.5021423004164799, 0.6067007665877667, 0.9539496277780908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.04610843439966642], {
             RGBColor[
             0.26424845016803866`, 0.3950722538189983, 0.9383599303652956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.04610843439966642], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.04610843439966642], {
             RGBColor[
             0.18293127670980908`, 0.3096027487078165, 0.9337290376348271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.04610843439966642], {
             RGBColor[
             0.1941778278429074, 0.3214235870212298, 0.9343695120840757]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.04610843439966642], {
             RGBColor[
             0.22179319725678925`, 0.3504490911907685, 0.9359421665189183]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.04610843439966642], {
             RGBColor[
             0.30602988251049323`, 0.4389871883067331, 0.9407393211271083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.04610843439966642], {
             RGBColor[
             0.21196511221078973`, 0.3401191506708405, 0.9353824716148974]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.04610843439966642], {
             RGBColor[
             0.9263859833659136, 0.9441390533310817, 0.9928407161596127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.04610843439966642], {
             RGBColor[
             0.181234979779358, 0.3078198330824752, 0.9336324360340843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.04610843439966642], {
             RGBColor[
             0.2704719529099895, 0.40161354979365305`, 0.9387143496396024]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.04610843439966642], {
             RGBColor[
             0.2020967142561969, 0.3297468387279948, 0.9348204809503698]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.04610843439966642], {
             RGBColor[
             0.21670300720810273`, 0.3450989787129095, 0.9356522877259069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.04610843439966642], {
             RGBColor[
             0.21656281497127022`, 0.34495162778329735`, 0.9356443039854151]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.04610843439966642], {
             RGBColor[
             0.2675148103379351, 0.39850540545675567`, 0.9385459447448243]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.04610843439966642], {
             RGBColor[
             0.22727061882380845`, 0.3562062085462915, 0.9362540975740409]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.04610843439966642], {
             RGBColor[
             0.18623437450108682`, 0.31307451391494534`, 0.9339171441675451]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.04610843439966642], {
             RGBColor[
             0.2444470173259052, 0.37425969241856055`, 0.9372322680585309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.04610843439966642], {
             RGBColor[
             0.23138676958404353`, 0.3605325439743302, 0.9364885062705369]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.04610843439966642], {
             RGBColor[
             0.19041076970754647`, 0.3174641700756846, 0.9341549836961299]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.04610843439966642], {
             RGBColor[
             0.24919784069125972`, 0.37925310899514714`, 0.9375028204209744]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.04610843439966642], {
             RGBColor[
             0.9364164576881094, 0.9521000787690629, 0.9925145312769647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.04610843439966642], {
             RGBColor[
             0.21679935925455723`, 0.3452002508228058, 0.9356577748324124]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.04610843439966642], {
             RGBColor[
             0.19250116414799295`, 0.31966130717125646`, 0.9342740285670519]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.04610843439966642], {
             RGBColor[
             0.5518206973838005, 0.647031927232117, 0.9578604931653224]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.04610843439966642], {
             RGBColor[
             0.20579087184942513`, 0.3336296325815971, 0.9350308577602878]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.04610843439966642], {
             RGBColor[
             0.19619436846660787`, 0.3235430990727991, 0.9344843510893909]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.04610843439966642], {
             RGBColor[
             0.9691756477061694, 0.9765318290462814, 0.9370617675415293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.04610843439966642], {
             RGBColor[
             0.1810808656124072, 0.3076578493216073, 0.933623659460268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.04610843439966642], {
             RGBColor[
             0.36710024085613885`, 0.49238551046016216`, 0.9446122806267241]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.04610843439966642], {
             RGBColor[
             0.20575656042090384`, 0.333593569094751, 0.9350289037751928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.04610843439966642], {
             RGBColor[
             0.18503007033382515`, 0.31180871387785897`, 0.9338485608268279]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.04610843439966642], {
             RGBColor[
             0.21763298899601496`, 0.34607644853625624`, 0.9357052488129437]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.04610843439966642], {
             RGBColor[
             0.3080267094125234, 0.4410859799869048, 0.9408530374651383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.04610843439966642], {
             RGBColor[
             0.21740901950548744`, 0.34584104240122593`, 0.9356924940817913]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.04610843439966642], {
             RGBColor[
             0.18012636844446756`, 0.30665461227948687`, 0.9335693022586058]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.04610843439966642], {
             RGBColor[
             0.2201361607798215, 0.3487074407912947, 0.9358478007429207]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.04610843439966642], {
             RGBColor[
             0.9414109245622558, 0.9558249439861124, 0.9840602016246193]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.04610843439966642], {
             RGBColor[
             0.20445336338735556`, 0.33222382638502757`, 0.9349546886320393]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.04610843439966642], {
             RGBColor[
             0.18141516357964482`, 0.30800921768088935`, 0.9336426972349526]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.04610843439966642], {
             RGBColor[
             0.31502527059825963`, 0.4472807885868956, 0.9412941095699802]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.04610843439966642], {
             RGBColor[
             0.24062773125074222`, 0.3702453805968408, 0.9370147653666777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.04610843439966642], {
             RGBColor[
             0.1853227778630534, 0.31211636804980714`, 0.9338652300875955]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.04610843439966642], {
             RGBColor[
             0.39086743560945575`, 0.5129714599815431, 0.9461267052599003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.04610843439966642], {
             RGBColor[
             0.8468258702473929, 0.3609297347144502, 0.19247381227214683`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.04610843439966642], {
             RGBColor[
             0.1939380814128329, 0.3211715983224198, 0.934355858879556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.04610843439966642], {
             RGBColor[
             0.21735301065346377`, 0.34578217354658275`, 0.9356893044605262]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.04610843439966642], {
             RGBColor[
             0.27792375203997, 0.40944586315061604`, 0.939138718576106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.04610843439966642], {
             RGBColor[
             0.4511243917370499, 0.5651630067765897, 0.9499662252212164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.04610843439966642], {
             RGBColor[
             0.2260372839021752, 0.3549098953457044, 0.9361838609748094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.04610843439966642], {
             RGBColor[
             0.2642831104182927, 0.3951086839396021, 0.9383619042152723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.04610843439966642], {
             RGBColor[
             0.1796655907243716, 0.3061703056806712, 0.9335430616491059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.04610843439966642], {
             RGBColor[
             0.874787420357395, 0.9029957597937702, 0.9879191991572792]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.04610843439966642], {
             RGBColor[
             0.43130662815416465`, 0.5479978560308542, 0.9487034548498753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.04610843439966642], {
             RGBColor[
             0.4544709331932017, 0.5679990031052896, 0.9501967631243022]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.04610843439966642], {
             RGBColor[
             0.1842953386135795, 0.3110364642551991, 0.933806718942298]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.04610843439966642], {
             RGBColor[
             0.1814951086723694, 0.3080932450421545, 0.9336472499897152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.04610843439966642], {
             RGBColor[
             0.30056549504747376`, 0.4332437706209237, 0.9404281323449262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.04610843439966642], {
             RGBColor[
             0.24912319227677354`, 0.3791746487785393, 0.937498569304202]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.04610843439966642], {
             RGBColor[
             0.24687317251219526`, 0.37680973534647483`, 0.9373704340072151]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.04610843439966642], {
             RGBColor[
             0.1969362596236349, 0.3243228737174507, 0.934526600693254]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.04610843439966642], {
             RGBColor[
             0.22281221312870114`, 0.35152014148148586`, 0.9360001979653247]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.04610843439966642], {
             RGBColor[
             0.32389238094576056`, 0.45496103389597625`, 0.9418591140004451]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.04610843439966642], {
             RGBColor[
             0.2218736173884548, 0.35053361784807985`, 0.9359467463264457]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.04610843439966642], {
             RGBColor[
             0.28566810415648325`, 0.4175856682453557, 0.9395797479723991]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.04610843439966642], {
             RGBColor[
             0.9937232399115826, 0.9889829697856952, 0.5581915839279488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.04610843439966642], {
             RGBColor[
             0.34381589363766235`, 0.47221777920483715`, 0.9431286226115025]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.04610843439966642], {
             RGBColor[
             0.2619978835405132, 0.39270676559930323`, 0.938231763925273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.04610843439966642], {
             RGBColor[
             0.8556626659915121, 0.887746199790043, 0.9860950630129915]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.04610843439966642], {
             RGBColor[
             0.19848865517094644`, 0.32595453986523776`, 0.93461500732311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.04610843439966642], {
             RGBColor[
             0.1901932049434399, 0.31723549571420584`, 0.9341425937046723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.04610843439966642], {
             RGBColor[
             0.24540381361353808`, 0.37526534598125116`, 0.9372867561916584]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.04610843439966642], {
             RGBColor[
             0.24952468470268496`, 0.3795966427742623, 0.9375214337039027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.04610843439966642], {
             RGBColor[
             0.19357697366818166`, 0.320792051187238, 0.9343352943277091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.04610843439966642], {
             RGBColor[
             0.1855038424012835, 0.31230667835964177`, 0.9338755414451867]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.04610843439966642], {
             RGBColor[
             0.19256204953176445`, 0.3197253015699566, 0.9342774958995859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.04610843439966642], {
             RGBColor[
             0.9939031817563573, 0.9917468232222412, 0.7507035865643902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.04610843439966642], {
             RGBColor[
             0.20018563595199287`, 0.32773817426091345`, 0.9347116478681324]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.04610843439966642], {
             RGBColor[
             0.2822567222941179, 0.41400008961390705`, 0.9393854748220246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.04610843439966642], {
             RGBColor[
             0.33187084383238813`, 0.46187157743916857`, 0.9423674946005033]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.04610843439966642], {
             RGBColor[
             0.6731900684530466, 0.744620465000319, 0.9680609527706839]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.04610843439966642], {
             RGBColor[
             0.8187176743057581, 0.14487782361704554`, 0.16555737209477062`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.04610843439966642], {
             RGBColor[
             0.20642492465234524`, 0.3342960622787358, 0.9350669661294171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.04610843439966642], {
             RGBColor[
             0.3163443674121438, 0.4484233239473484, 0.9413781612525294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.04610843439966642], {
             RGBColor[
             0.2548921156460419, 0.3852381530105079, 0.9378271009557244]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.04610843439966642], {
             RGBColor[
             0.44319072976501883`, 0.5582912675338615, 0.9494606992958204]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.04610843439966642], {
             RGBColor[
             0.2838279904913397, 0.4156515921133449, 0.9394749562213734]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.04610843439966642], {
             RGBColor[
             0.4514119894863078, 0.5654121094919137, 0.9499845506954865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.04610843439966642], {
             RGBColor[
             0.2817626744925139, 0.41348081404998144`, 0.9393573395306015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.04610843439966642], {
             RGBColor[
             0.19517315909830985`, 0.32246974327830424`, 0.9344261947266101]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.04610843439966642], {
             RGBColor[
             0.2058031822357576, 0.33364257157815613`, 0.9350315588185778]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.04610843439966642], {
             RGBColor[
             0.8037293520346596, 0.846598745469576, 0.9810718885991364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.04610843439966642], {
             RGBColor[
             0.19933380464903927`, 0.32684284555228516`, 0.9346631373356007]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.04610843439966642], {
             RGBColor[
             0.20939739524084894`, 0.3374203173327738, 0.9352362439320562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.04610843439966642], {
             RGBColor[
             0.19209300288846856`, 0.31923230380857776`, 0.9342507843871425]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.04610843439966642], {
             RGBColor[
             0.6552079689840278, 0.7305727122261038, 0.9662686651478858]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.04610843439966642], {
             RGBColor[
             0.30775018901205775`, 0.44079533951360933`, 0.940837290037407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.04610843439966642], {
             RGBColor[
             0.8693407441384133, 0.4995886600246006, 0.2126870529687101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.04610843439966642], {
             RGBColor[
             0.36775323192677223`, 0.4929510985052593, 0.9446538886403275]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.04610843439966642], {
             RGBColor[
             0.19003317840134057`, 0.3170672976721906, 0.9341334804298378]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.04610843439966642], {
             RGBColor[
             0.5005712745154292, 0.6054253369873833, 0.9538259508643026]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.04610843439966642], {
             RGBColor[
             0.23408779828449117`, 0.3633714963936115, 0.9366423258592136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.04610843439966642], {
             RGBColor[
             0.21738991983752656`, 0.34582096743921015`, 0.9356914063839564]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.04610843439966642], {
             RGBColor[
             0.1836473816366038, 0.3103554203895525, 0.9337698187510258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.04610843439966642], {
             RGBColor[
             0.3685402730980111, 0.49363279400994686`, 0.9447040382078057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.04610843439966642], {
             RGBColor[
             0.3420328760182438, 0.47067341895996806`, 0.9430150103054538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.04610843439966642], {
             RGBColor[
             0.43817293033743376`, 0.5539451018716196, 0.9491409695533606]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.04610843439966642], {
             RGBColor[
             0.34083289550277507`, 0.46963405615024345`, 0.9429385486081092]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.04610843439966642], {
             RGBColor[
             0.9363841071750253, 0.7854912142282449, 0.26767136325734403`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.04610843439966642], {
             RGBColor[
             0.1818088839913312, 0.30842304279688765`, 0.933665119029941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.04610843439966642], {
             RGBColor[
             0.2320502240219991, 0.3612298766540624, 0.9365262890192856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.04610843439966642], {
             RGBColor[
             0.18306798401191893`, 0.3097464367500775, 0.933736822913442]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.04610843439966642], {
             RGBColor[
             0.20348109888236326`, 0.33120191474515054`, 0.9348993196068165]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.04610843439966642], {
             RGBColor[
             0.31320234650668927`, 0.4457018633616062, 0.9411779544588138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.04610843439966642], {
             RGBColor[
             0.19443151506714343`, 0.3216902283786009, 0.9343839591961993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.04610843439966642], {
             RGBColor[
             0.1841862517520943, 0.3109218070472717, 0.933800506606916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.04610843439966642], {
             RGBColor[
             0.8101035860121542, 0.8515783454987672, 0.9817072126714098]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.04610843439966642], {
             RGBColor[
             0.46571418536342124`, 0.577126781719812, 0.9510818731205317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.04610843439966642], {
             RGBColor[
             0.22946131864603458`, 0.3585087729578423, 0.9363788546880667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.04610843439966642], {
             RGBColor[
             0.2015219494351241, 0.32914272445885284`, 0.9347877489440981]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.04610843439966642], {
             RGBColor[
             0.5010318547608589, 0.6057992567795268, 0.9538622094283838]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.04610843439966642], {
             RGBColor[
             0.23298613716021888`, 0.3622135807026517, 0.9365795878879478]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.04610843439966642], {
             RGBColor[
             0.20070591566211698`, 0.3282850212238928, 0.9347412770279392]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.04610843439966642], {
             RGBColor[
             0.34562348099972906`, 0.47378342052587685`, 0.9432438004798267]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.04610843439966642], {
             RGBColor[
             0.995260710048657, 0.9923081960579929, 0.7282058295903809]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.04610843439966642], {
             RGBColor[
             0.1906136828189116, 0.3176774446211637, 0.9341665392976392]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{
  3.8349502435193233`*^9, 3.8350238678158054`*^9, {3.8350516990156693`*^9, 
   3.83505171305331*^9}},
 CellLabel->
  "Out[399]=",ExpressionUUID->"a4f8e0f1-190f-4df5-84ab-575258b6112f"]
}, Open  ]],

Cell["Estimated with absolute Mean Deviation v Calculated: (r=6)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 
  3.8349503922098827`*^9}},ExpressionUUID->"a09a78db-06d1-45ce-a84e-\
722375022876"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphin2", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsi2", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}], 
     "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"AMDi6200", ",", "kri2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502409842243`*^9}, {3.8349504019691753`*^9, 3.834950402221115*^9}},
 CellLabel->
  "In[125]:=",ExpressionUUID->"729a5f28-cf5c-4307-89f8-661235f74256"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
          103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
          129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 
          142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 
          155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 
          168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 
          181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 
          194, 195, 196, 197, 198, 199, 200}, {Null, CompressedData["
1:eJwVxfk/Gg4DAOBN5QibNGP1lWNDwghlmCNXuqiMigzJGcNQUi05SwdqhpKc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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[21, 55] -> 
             RGBColor[
              0.9767947479143324, 0.9822141415063979, 0.9241646182687007], 
             UndirectedEdge[64, 132] -> 
             RGBColor[
              0.9387546361479282, 0.948771935393687, 0.7082242625862656], 
             UndirectedEdge[42, 188] -> 
             RGBColor[
              0.9681694428896309, 0.97444348025255, 0.8788500893266251], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.9298322540433287, 0.846424244722467, 0.6262669727349295], 
             UndirectedEdge[33, 68] -> 
             RGBColor[
              0.9803585848405401, 0.9726998688532744, 0.6642137521398621], 
             UndirectedEdge[168, 188] -> 
             RGBColor[
              0.5615103616064328, 0.6316098854135286, 0.9565099616475442], 
             UndirectedEdge[41, 161] -> 
             RGBColor[
              0.9699157829991842, 0.9744870810226354, 0.7934506400732195], 
             UndirectedEdge[44, 68] -> 
             RGBColor[
              0.9891287923010765, 0.9779195439494156, 0.5902051211338415], 
             UndirectedEdge[26, 136] -> 
             RGBColor[
              0.9223293267678003, 0.8166776382772978, 0.6202299413327009], 
             UndirectedEdge[9, 32] -> 
             RGBColor[
              0.922140422888174, 0.9406619663880167, 0.989253275506808], 
             UndirectedEdge[71, 141] -> 
             RGBColor[
              0.9489152986569651, 0.8301704991093678, 0.30380847138600986`], 
             UndirectedEdge[52, 100] -> 
             RGBColor[
              0.9874500086433489, 0.988429430134928, 0.8285929770275128], 
             UndirectedEdge[172, 180] -> 
             RGBColor[
              0.5865630546551774, 0.6476974031559464, 0.771744015629406], 
             UndirectedEdge[168, 197] -> 
             RGBColor[
              0.5514660392215651, 0.520903245186535, 0.5956059530832557], 
             UndirectedEdge[125, 137] -> 
             RGBColor[
              0.94867922158526, 0.8232939863810723, 0.3419934509182928], 
             UndirectedEdge[17, 147] -> 
             RGBColor[
              0.9586576544086234, 0.8627629971023991, 0.5032775862694421], 
             UndirectedEdge[10, 71] -> 
             RGBColor[
              0.9287782032516108, 0.844629403179703, 0.6259527272198709], 
             UndirectedEdge[27, 129] -> 
             RGBColor[
              0.5727880164795747, 0.6022777491855338, 0.6292196100791486], 
             UndirectedEdge[67, 166] -> 
             RGBColor[
              0.959712578785772, 0.8671416427954407, 0.5050865994514528], 
             UndirectedEdge[3, 49] -> 
             RGBColor[
              0.9937747919743803, 0.9900499386295153, 0.6333450032571011], 
             UndirectedEdge[151, 183] -> 
             RGBColor[
              0.8450364329447487, 0.3246069243707179, 0.18987652271054228`], 
             UndirectedEdge[125, 136] -> 
             RGBColor[
              0.9516005194310542, 0.834875958874847, 0.3443439957366924], 
             UndirectedEdge[139, 194] -> 
             RGBColor[
              0.9923020825847075, 0.9910847275683922, 0.777237943350459], 
             UndirectedEdge[24, 108] -> 
             RGBColor[
              0.9948068068828846, 0.9913006099718842, 0.6761311617539709], 
             UndirectedEdge[21, 192] -> 
             RGBColor[
              0.9861051586590497, 0.9880615623906863, 0.8593113914072015], 
             UndirectedEdge[16, 52] -> 
             RGBColor[
              0.9942888260337807, 0.990769419793554, 0.6616734884282927], 
             UndirectedEdge[44, 166] -> 
             RGBColor[
              0.9588485186005469, 0.8667843317035162, 0.5194063128367133], 
             UndirectedEdge[78, 187] -> 
             RGBColor[
              0.5869460537751134, 0.6485165995463383, 0.8134311062378485], 
             UndirectedEdge[99, 162] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[93, 150] -> 
             RGBColor[
              0.9489629196047507, 0.9497446159972616, 0.6975846021127032], 
             UndirectedEdge[118, 155] -> 
             RGBColor[
              0.9643215752078282, 0.9726226632085964, 0.9323361438643656], 
             UndirectedEdge[16, 125] -> 
             RGBColor[
              0.9933090569967167, 0.9880970744111132, 0.5131103296854425], 
             UndirectedEdge[61, 179] -> 
             RGBColor[
              0.9153562519504082, 0.9310588716557211, 0.7825302020724224], 
             UndirectedEdge[51, 197] -> 
             RGBColor[
              0.95944119513953, 0.8639319516551865, 0.4707580484766465], 
             UndirectedEdge[80, 120] -> 
             RGBColor[
              0.9622837944665441, 0.8763395874529079, 0.4057236312420279], 
             UndirectedEdge[21, 183] -> 
             RGBColor[
              0.899369355634505, 0.5598952158018169, 0.540276880846432], 
             UndirectedEdge[182, 199] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[17, 189] -> 
             RGBColor[
              0.9567112201642811, 0.8619580965212852, 0.5355350389085456], 
             UndirectedEdge[116, 136] -> 
             RGBColor[
              0.9520495390042402, 0.8373288257143353, 0.5017030466315835], 
             UndirectedEdge[119, 123] -> 
             RGBColor[
              0.9654211142491939, 0.8938672555990772, 0.5297094151680903], 
             UndirectedEdge[71, 89] -> 
             RGBColor[
              0.9482763511362228, 0.8280151790898919, 0.3013262809230409], 
             UndirectedEdge[7, 61] -> 
             RGBColor[
              0.8867474585751974, 0.91250621988481, 0.9881533304733856], 
             UndirectedEdge[3, 27] -> 
             RGBColor[
              0.5861517831431075, 0.646817734977557, 0.7269796496141474], 
             UndirectedEdge[41, 108] -> 
             RGBColor[
              0.9945142518701815, 0.9906748643815615, 0.6442883540615025], 
             UndirectedEdge[66, 98] -> 
             RGBColor[
              0.5738606030158988, 0.6408206752350442, 0.9356042244001594], 
             UndirectedEdge[119, 127] -> 
             RGBColor[
              0.9615606329499417, 0.8770623073142512, 0.33087138911258834`], 
             UndirectedEdge[15, 167] -> 
             RGBColor[
              0.9944157970050382, 0.9904642793803337, 0.633572149583643], 
             UndirectedEdge[12, 96] -> 
             RGBColor[
              0.9815892872707559, 0.9605742331528156, 0.6168140621470388], 
             UndirectedEdge[7, 52] -> 
             RGBColor[
              0.9656632712463581, 0.9721809170567607, 0.8654722405494516], 
             UndirectedEdge[163, 165] -> 
             RGBColor[
              0.9753018012100971, 0.9282203247501415, 0.3695211988186938], 
             UndirectedEdge[71, 73] -> 
             RGBColor[
              0.9566482343414573, 0.8648044266121087, 0.5506346100621866], 
             UndirectedEdge[60, 165] -> 
             RGBColor[
              0.585819503721545, 0.646107022893438, 0.6908130851679699], 
             UndirectedEdge[120, 124] -> 
             RGBColor[
              0.9626761032295597, 0.8779260547905481, 0.5027490969902193], 
             UndirectedEdge[43, 163] -> 
             RGBColor[
              0.9759257268793492, 0.9295548386681098, 0.43743165749388685`], 
             UndirectedEdge[146, 194] -> 
             RGBColor[
              0.9795380319040969, 0.9453975377855072, 0.5517709696046005], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.5866140321036301, 0.6478064387635759, 0.7772925962971287], 
             UndirectedEdge[81, 157] -> 
             RGBColor[
              0.9917551132058884, 0.9899908317093602, 0.7232292870677162], 
             UndirectedEdge[59, 114] -> 
             RGBColor[
              0.9941084568111487, 0.9898069097824642, 0.6001200661625901], 
             UndirectedEdge[31, 185] -> 
             RGBColor[
              0.9334680917345031, 0.7525258696194765, 0.41184720020192184`], 
             UndirectedEdge[58, 198] -> 
             RGBColor[
              0.9940697915939216, 0.9897242087924687, 0.5959115958814841], 
             UndirectedEdge[30, 142] -> 
             RGBColor[
              0.9660101431068637, 0.9741710008991573, 0.9424201411323279], 
             UndirectedEdge[26, 96] -> 
             RGBColor[
              0.9603953925981101, 0.9695293753917493, 0.9320004327947182], 
             UndirectedEdge[25, 111] -> 
             RGBColor[
              0.9665242331847284, 0.8987405194275656, 0.32445339660113237`], 
             UndirectedEdge[89, 107] -> 
             RGBColor[
              0.5752646984825799, 0.610632179134259, 0.6388410519786725], 
             UndirectedEdge[51, 189] -> 
             RGBColor[
              0.9924835835357779, 0.9908106638226002, 0.7488527331861877], 
             UndirectedEdge[81, 158] -> 
             RGBColor[
              0.9449524224302923, 0.8158335614815693, 0.5334564048256891], 
             UndirectedEdge[93, 159] -> 
             RGBColor[
              0.9672749538602516, 0.8988001918510189, 0.3402475885712726], 
             UndirectedEdge[191, 195] -> 
             RGBColor[
              0.9365122366297398, 0.9496002043322684, 0.8912757114641785], 
             UndirectedEdge[17, 131] -> 
             RGBColor[
              0.9442062459196944, 0.81380737277098, 0.2880061316790452], 
             UndirectedEdge[18, 32] -> 
             RGBColor[
              0.5419746233144771, 0.6162490947801078, 0.9621520119390043], 
             UndirectedEdge[59, 184] -> 
             RGBColor[
              0.9901577900407899, 0.9892638122162186, 0.7448682851044544], 
             UndirectedEdge[156, 175] -> 
             RGBColor[
              0.979155823092877, 0.9408790225007686, 0.41355950897005356`], 
             UndirectedEdge[2, 82] -> 
             RGBColor[
              0.5829377977540889, 0.636515344706445, 0.6686495937052732], 
             UndirectedEdge[12, 44] -> 
             RGBColor[
              0.9843217213457549, 0.9617041648631804, 0.5715305582115958], 
             UndirectedEdge[115, 175] -> 
             RGBColor[
              0.9793012961981908, 0.9413697374437018, 0.41412464451390696`], 
             UndirectedEdge[30, 131] -> 
             RGBColor[
              0.9625881517092018, 0.9318145028490787, 0.6356365162105679], 
             UndirectedEdge[53, 65] -> 
             RGBColor[
              0.9899172962273759, 0.9760982406766446, 0.5473506597225536], 
             UndirectedEdge[17, 51] -> 
             RGBColor[
              0.9591049484644327, 0.8625988456359881, 0.47048749650913935`], 
             UndirectedEdge[109, 128] -> 
             RGBColor[
              0.9497599933417012, 0.8563682651989228, 0.5901063345414657], 
             UndirectedEdge[101, 135] -> 
             RGBColor[
              0.513932347471886, 0.341278072369151, 0.5639985489931821], 
             UndirectedEdge[54, 195] -> 
             RGBColor[
              0.93722089011413, 0.9476742280961723, 0.7182319668523041], 
             UndirectedEdge[122, 192] -> 
             RGBColor[
              0.9645445478080303, 0.8917703978299671, 0.5357493706938865], 
             UndirectedEdge[155, 195] -> 
             RGBColor[
              0.933831789046237, 0.9484917703721294, 0.9356976646988013], 
             UndirectedEdge[42, 87] -> 
             RGBColor[
              0.9917974253811978, 0.9908760388456422, 0.7856014192235952], 
             UndirectedEdge[31, 153] -> 
             RGBColor[
              0.9944662877556282, 0.9905722739904476, 0.6390677561925648], 
             UndirectedEdge[64, 199] -> 
             RGBColor[
              0.5319566192564759, 0.6082610102757336, 0.9611964857687744], 
             UndirectedEdge[107, 188] -> 
             RGBColor[
              0.5615103616064328, 0.6316098854135286, 0.9565099616475442], 
             UndirectedEdge[27, 189] -> 
             RGBColor[
              0.5845084276178132, 0.6477819573539487, 0.8737006377927969], 
             UndirectedEdge[14, 176] -> 
             RGBColor[
              0.9650001789245574, 0.8935995265430511, 0.3185327335938653], 
             UndirectedEdge[123, 146] -> 
             RGBColor[
              0.9791919780024476, 0.9452544356039956, 0.55750597831372], 
             UndirectedEdge[30, 130] -> 
             RGBColor[
              0.97679942234035, 0.9791356283609454, 0.7432951595843844], 
             UndirectedEdge[72, 143] -> 
             RGBColor[
              0.9654307528253299, 0.9715260555785744, 0.8315036647728389], 
             UndirectedEdge[68, 155] -> 
             RGBColor[
              0.9860225339049746, 0.976635026275428, 0.6416838614962906], 
             UndirectedEdge[32, 39] -> 
             RGBColor[
              0.9200163347856372, 0.8535746017794597, 0.6286845442786024], 
             UndirectedEdge[184, 194] -> 
             RGBColor[
              0.9891877593950402, 0.9897968748950094, 0.8288503382133057], 
             UndirectedEdge[74, 152] -> 
             RGBColor[
              0.9932134048440902, 0.989835018872973, 0.6439009526481879], 
             UndirectedEdge[71, 147] -> 
             RGBColor[
              0.9594665145157983, 0.8659698578906954, 0.503928414098062], 
             UndirectedEdge[39, 173] -> 
             RGBColor[
              0.9636347354805879, 0.8855559728340892, 0.5222586010778554], 
             UndirectedEdge[139, 171] -> 
             RGBColor[
              0.9910964507894082, 0.9905861678377119, 0.7972183822736405], 
             UndirectedEdge[73, 189] -> 
             RGBColor[
              0.9892180093056275, 0.9898093840104245, 0.8283490189106152], 
             UndirectedEdge[20, 22] -> 
             RGBColor[
              0.9930269413456123, 0.9874936575596689, 0.48240378207872425`], 
             UndirectedEdge[17, 168] -> 
             RGBColor[
              0.551129792546468, 0.5195701391673365, 0.5953354011157486], 
             UndirectedEdge[13, 132] -> 
             RGBColor[
              0.9932669358036423, 0.9891035960044551, 0.5882380002736297], 
             UndirectedEdge[99, 109] -> 
             RGBColor[
              0.5506993724113656, 0.5178636667606633, 0.5949890749717862], 
             UndirectedEdge[119, 195] -> 
             RGBColor[
              0.9105036459685907, 0.8527434829503868, 0.6292896275765365], 
             UndirectedEdge[10, 188] -> 
             RGBColor[
              0.9383499122044006, 0.953462288637599, 0.9864764599230467], 
             UndirectedEdge[182, 185] -> 
             RGBColor[
              0.5258404329447488, 0.41024042437071795`, 0.5745180227105423], 
             UndirectedEdge[98, 187] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[10, 167] -> 
             RGBColor[
              0.9637320797852114, 0.970254519089121, 0.8375717834391846], 
             UndirectedEdge[113, 187] -> 
             RGBColor[
              0.5539132855555703, 0.5306057614043673, 0.5975750649278506], 
             UndirectedEdge[83, 170] -> 
             RGBColor[
              0.920824238678805, 0.7224605171811918, 0.25508215910777654`], 
             UndirectedEdge[39, 41] -> 
             RGBColor[
              0.9646047661263375, 0.8850229101552983, 0.43827654796900406`], 
             UndirectedEdge[138, 145] -> 
             RGBColor[
              0.9527719428120409, 0.847520970356326, 0.5381435294752692], 
             UndirectedEdge[75, 155] -> 
             RGBColor[
              0.9738562315265679, 0.9797335942795455, 0.916196457753379], 
             UndirectedEdge[90, 163] -> 
             RGBColor[
              0.9765550617251457, 0.9309009222677551, 0.5059308716543671], 
             UndirectedEdge[2, 66] -> 
             RGBColor[
              0.9778714007699878, 0.9719420199414892, 0.6707528181054325], 
             UndirectedEdge[88, 200] -> 
             RGBColor[
              0.988841095883638, 0.9739465603542138, 0.5683341960121457], 
             UndirectedEdge[67, 170] -> 
             RGBColor[
              0.9467218775649124, 0.8142968378709499, 0.49456460759774734`], 
             UndirectedEdge[124, 136] -> 
             RGBColor[
              0.9524813880786476, 0.8375074064046177, 0.4945461898790749], 
             UndirectedEdge[129, 155] -> 
             RGBColor[
              0.9762903036986363, 0.9438059285531277, 0.6038759849221271], 
             UndirectedEdge[149, 167] -> 
             RGBColor[
              0.9878640974641325, 0.969271425899883, 0.5309470462603614], 
             UndirectedEdge[172, 173] -> 
             RGBColor[
              0.5855930240094278, 0.6482304658347373, 0.8557260687382573], 
             UndirectedEdge[143, 160] -> 
             RGBColor[
              0.9912973187784851, 0.9902105051601413, 0.7605448874784759], 
             UndirectedEdge[27, 89] -> 
             RGBColor[
              0.5752646984825798, 0.610632179134259, 0.6388410519786725], 
             UndirectedEdge[172, 191] -> 
             RGBColor[
              0.5851097348025645, 0.6480306133277332, 0.8637354216083557], 
             UndirectedEdge[11, 182] -> 
             RGBColor[
              0.586823190036725, 0.648253806433355, 0.8000581465413696], 
             UndirectedEdge[159, 164] -> 
             RGBColor[
              0.9686795566070374, 0.9099981480189663, 0.5480501316508708], 
             UndirectedEdge[151, 156] -> 
             RGBColor[
              0.9188998236291861, 0.7044201015185665, 0.26712246794991223`], 
             UndirectedEdge[94, 196] -> 
             RGBColor[
              0.9230380335194714, 0.8957685085031091, 0.6461168661203471], 
             UndirectedEdge[69, 139] -> 
             RGBColor[
              0.9751183560638319, 0.9303615635903585, 0.5337209882629257], 
             UndirectedEdge[53, 127] -> 
             RGBColor[
              0.989432309562686, 0.9744622667763615, 0.54546657811228], 
             UndirectedEdge[171, 196] -> 
             RGBColor[
              0.9754688064771238, 0.9352394043314325, 0.5606268880130115], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.9892439601969671, 0.9746580429923157, 0.47406218816085005`], 
             UndirectedEdge[74, 162] -> 
             RGBColor[
              0.5861617683735301, 0.6468390923757693, 0.7280664803239516], 
             UndirectedEdge[34, 153] -> 
             RGBColor[
              0.9849073700796143, 0.986051684836786, 0.7985348320766725], 
             UndirectedEdge[98, 109] -> 
             RGBColor[
              0.5506993724113656, 0.5178636667606633, 0.5949890749717862], 
             UndirectedEdge[77, 183] -> 
             RGBColor[
              0.8348069213171145, 0.26854682649932693`, 0.180964453203051], 
             UndirectedEdge[2, 78] -> 
             RGBColor[
              0.9909568515292024, 0.9796379442527833, 0.5485796999431218], 
             UndirectedEdge[113, 193] -> 
             RGBColor[
              0.9613729015788207, 0.8725317801673038, 0.41661382432501637`], 
             UndirectedEdge[100, 120] -> 
             RGBColor[
              0.9556115267458523, 0.874355830697101, 0.5907710235670254], 
             UndirectedEdge[1, 35] -> 
             RGBColor[
              0.5752409521543687, 0.6105520771932995, 0.6387488019776896], 
             UndirectedEdge[154, 176] -> 
             RGBColor[
              0.950792075210499, 0.9178338354519062, 0.6446013017769159], 
             UndirectedEdge[13, 31] -> 
             RGBColor[
              0.9940965777019446, 0.9908781161352603, 0.6785394009475181], 
             UndirectedEdge[92, 196] -> 
             RGBColor[
              0.9489014427510902, 0.9163651392436134, 0.6476771133754372], 
             UndirectedEdge[66, 124] -> 
             RGBColor[
              0.9816049453846916, 0.9841030534228966, 0.8399587673252789], 
             UndirectedEdge[141, 167] -> 
             RGBColor[
              0.9838691751905657, 0.9557956150187856, 0.5154275276053235], 
             UndirectedEdge[76, 158] -> 
             RGBColor[
              0.9456178913401667, 0.8161087499775732, 0.5224278628107368], 
             UndirectedEdge[101, 134] -> 
             RGBColor[
              0.5841542415806533, 0.6406186953680397, 0.6733752482653345], 
             UndirectedEdge[139, 141] -> 
             RGBColor[
              0.982612704578602, 0.95564176088739, 0.5628351170538431], 
             UndirectedEdge[88, 93] -> 
             RGBColor[
              0.9905608065853618, 0.9797475483584033, 0.575014947348227], 
             UndirectedEdge[17, 130] -> 
             RGBColor[
              0.9584175165508426, 0.8611284982828468, 0.3956647750528617], 
             UndirectedEdge[32, 117] -> 
             RGBColor[
              0.949026042796297, 0.9573020224159255, 0.7367610968984994], 
             UndirectedEdge[32, 103] -> 
             RGBColor[
              0.5419746233144771, 0.6162490947801078, 0.9621520119390043], 
             UndirectedEdge[148, 150] -> 
             RGBColor[
              0.9109772437013233, 0.9318525425816333, 0.9913710168148598], 
             UndirectedEdge[77, 156] -> 
             RGBColor[
              0.9086703120015519, 0.6483600036471756, 0.25821039844242094`], 
             UndirectedEdge[76, 89] -> 
             RGBColor[
              0.9810836920679473, 0.9531183761209583, 0.575103606888079], 
             UndirectedEdge[42, 51] -> 
             RGBColor[
              0.993561237201163, 0.991256301307673, 0.7309932230724716], 
             UndirectedEdge[82, 124] -> 
             RGBColor[
              0.5866713423687928, 0.6486763781878524, 0.8378555429251195], 
             UndirectedEdge[15, 114] -> 
             RGBColor[
              0.993995669973766, 0.9895656701418009, 0.5878439149531451], 
             UndirectedEdge[41, 173] -> 
             RGBColor[
              0.9932290786646052, 0.9905338689906836, 0.6939690843676631], 
             UndirectedEdge[41, 133] -> 
             RGBColor[
              0.9698990786160361, 0.9744746229210344, 0.7934789162366886], 
             UndirectedEdge[27, 147] -> 
             RGBColor[
              0.5864548618621555, 0.6485868579350627, 0.8414431851536934], 
             UndirectedEdge[19, 88] -> 
             RGBColor[
              0.9841929544188217, 0.9582672877578723, 0.5502770441491975], 
             UndirectedEdge[127, 172] -> 
             RGBColor[
              0.5813864888085262, 0.6312824153683996, 0.6626230513918747], 
             UndirectedEdge[69, 174] -> 
             RGBColor[
              0.9758295456700048, 0.929349116786734, 0.4269629264183603], 
             UndirectedEdge[117, 121] -> 
             RGBColor[
              0.9935203383940101, 0.9896455985223195, 0.6158193084156337], 
             UndirectedEdge[69, 196] -> 
             RGBColor[
              0.9594907117515475, 0.875014800084079, 0.2971294940022967], 
             UndirectedEdge[92, 195] -> 
             RGBColor[
              0.9092225303152699, 0.9304272320207734, 0.9902970228796871], 
             UndirectedEdge[144, 158] -> 
             RGBColor[
              0.9366946115033733, 0.7807430486455464, 0.2936731438160489], 
             UndirectedEdge[81, 168] -> 
             RGBColor[
              0.584080524675493, 0.6476050084906954, 0.880792096924359], 
             UndirectedEdge[87, 188] -> 
             RGBColor[
              0.9677217057044323, 0.9742583294201496, 0.8862702531920585], 
             UndirectedEdge[74, 88] -> 
             RGBColor[
              0.993784777204803, 0.9900712960277276, 0.6344318339669054], 
             UndirectedEdge[74, 140] -> 
             RGBColor[
              0.9862914182668983, 0.9648684140111492, 0.4481375474835989], 
             UndirectedEdge[152, 178] -> 
             RGBColor[
              0.9697566136925575, 0.9084578157013796, 0.520483538734421], 
             UndirectedEdge[63, 153] -> 
             RGBColor[
              0.9737739853026115, 0.9208726740015909, 0.4754271464603031], 
             UndirectedEdge[154, 158] -> 
             RGBColor[
              0.9205602306205998, 0.7984795723529374, 0.6122584889455612], 
             UndirectedEdge[23, 90] -> 
             RGBColor[
              0.9897811336783958, 0.9899874943749926, 0.815036405009159], 
             UndirectedEdge[51, 131] -> 
             RGBColor[
              0.9799786092911912, 0.9426599400722951, 0.5013238259566873], 
             UndirectedEdge[21, 83] -> 
             RGBColor[
              0.9617483225487864, 0.896862403245565, 0.5942938534517301], 
             UndirectedEdge[57, 178] -> 
             RGBColor[
              0.9700166337154807, 0.9070714374939434, 0.4075833440925496], 
             UndirectedEdge[17, 197] -> 
             RGBColor[
              0.9236688317680332, 0.7350793843538714, 0.2574403541990043], 
             UndirectedEdge[64, 156] -> 
             RGBColor[
              0.9250160099409133, 0.9024406874235822, 0.6538009310081443], 
             UndirectedEdge[40, 123] -> 
             RGBColor[
              0.9926194548315295, 0.9898270173768586, 0.6710161326060784], 
             UndirectedEdge[26, 99] -> 
             RGBColor[
              0.5565192810579456, 0.6278466100605326, 0.9635392943787455], 
             UndirectedEdge[114, 167] -> 
             RGBColor[
              0.9944379313432148, 0.9905116224915685, 0.6359813356968662], 
             UndirectedEdge[75, 168] -> 
             RGBColor[
              0.5703539443075061, 0.6382054149119516, 0.9415400829104005], 
             UndirectedEdge[55, 111] -> 
             RGBColor[
              0.9650306897683796, 0.9241927275612845, 0.6114553510729926], 
             UndirectedEdge[67, 122] -> 
             RGBColor[
              0.9660853505838745, 0.8924075593746039, 0.510214281228386], 
             UndirectedEdge[127, 129] -> 
             RGBColor[
              0.9752475052881008, 0.9281661645539333, 0.3583416614710232], 
             UndirectedEdge[96, 198] -> 
             RGBColor[
              0.9902258990319021, 0.9889240115891826, 0.7169923394372941], 
             UndirectedEdge[154, 181] -> 
             RGBColor[
              0.96692234088657, 0.9716944854201612, 0.7540769016625457], 
             UndirectedEdge[9, 91] -> 
             RGBColor[
              0.9640758422832815, 0.9719473814245143, 0.9107186878604516], 
             UndirectedEdge[39, 152] -> 
             RGBColor[
              0.9640203479417201, 0.8857154334965556, 0.5158680046638345], 
             UndirectedEdge[54, 65] -> 
             RGBColor[
              0.9887628637601709, 0.9736290263603198, 0.4216978099986295], 
             UndirectedEdge[116, 128] -> 
             RGBColor[
              0.9853001142247211, 0.9870023959358296, 0.8401296592473078], 
             UndirectedEdge[74, 95] -> 
             RGBColor[
              0.9152244013748978, 0.637044857210431, 0.3528732792288294], 
             UndirectedEdge[152, 200] -> 
             RGBColor[
              0.9882697235229251, 0.9737102831994591, 0.5778033146934283], 
             UndirectedEdge[140, 191] -> 
             RGBColor[
              0.9852393846959328, 0.966059934963113, 0.583806488768003], 
             UndirectedEdge[109, 193] -> 
             RGBColor[
              0.9581589884346161, 0.8597896855235999, 0.41402783436895196`], 
             UndirectedEdge[80, 137] -> 
             RGBColor[
              0.9491677814698378, 0.8243389665732028, 0.3951701793124839], 
             UndirectedEdge[118, 199] -> 
             RGBColor[
              0.5608192879887665, 0.6310944838410023, 0.957679769021387], 
             UndirectedEdge[45, 64] -> 
             RGBColor[
              0.9269294030015707, 0.908895011503235, 0.6612341017348378], 
             UndirectedEdge[125, 170] -> 
             RGBColor[
              0.946112745485723, 0.8117777603955255, 0.33985903528521544`], 
             UndirectedEdge[70, 145] -> 
             RGBColor[
              0.9556721004364069, 0.8487202600646526, 0.4900804122721835], 
             UndirectedEdge[17, 142] -> 
             RGBColor[
              0.9476282373173563, 0.8561638708210587, 0.5947897566008051], 
             UndirectedEdge[95, 180] -> 
             RGBColor[
              0.9156256876565452, 0.637903167990608, 0.39655081453428365`], 
             UndirectedEdge[41, 121] -> 
             RGBColor[
              0.9941049735673676, 0.9908960740424482, 0.6794532390855444], 
             UndirectedEdge[5, 10] -> 
             RGBColor[
              0.936966008979997, 0.877091324468239, 0.6325408279014324], 
             UndirectedEdge[167, 194] -> 
             RGBColor[
              0.9935585531966713, 0.991238581699788, 0.7298303539019393], 
             UndirectedEdge[78, 100] -> 
             RGBColor[
              0.9876258196601988, 0.9882287536407437, 0.8058075757397741], 
             UndirectedEdge[106, 157] -> 
             RGBColor[
              0.9893099579721976, 0.9889796971826059, 0.763751837148873], 
             UndirectedEdge[24, 115] -> 
             RGBColor[
              0.9800604734576318, 0.9429935408370507, 0.4967564041050977], 
             UndirectedEdge[74, 164] -> 
             RGBColor[
              0.9915771688744048, 0.9891583932501617, 0.6710176171088231], 
             UndirectedEdge[46, 135] -> 
             RGBColor[
              0.9220388900505291, 0.6845878016197644, 0.4534512715769303], 
             UndirectedEdge[126, 190] -> 
             RGBColor[
              0.9546502884344674, 0.895914920551541, 0.6096809929936786], 
             UndirectedEdge[21, 177] -> 
             RGBColor[
              0.9824970241576358, 0.9709589774554584, 0.6535127960770545], 
             UndirectedEdge[24, 133] -> 
             RGBColor[
              0.9701916336287391, 0.9751003685113571, 0.8253217239291569], 
             UndirectedEdge[30, 188] -> 
             RGBColor[
              0.9520950599424081, 0.9637931546589638, 0.9659747472948155], 
             UndirectedEdge[80, 98] -> 
             RGBColor[
              0.5862790336057773, 0.6470899108502123, 0.7408300771769281], 
             UndirectedEdge[12, 102] -> 
             RGBColor[
              0.9852624286078397, 0.9620931714911265, 0.5559406044064953], 
             UndirectedEdge[51, 168] -> 
             RGBColor[
              0.5869021559179648, 0.6484227064686515, 0.8086530953933908], 
             UndirectedEdge[42, 189] -> 
             RGBColor[
              0.9911675089010114, 0.99061555219297, 0.7960407654718779], 
             UndirectedEdge[52, 187] -> 
             RGBColor[
              0.5867702427582634, 0.6487172760405227, 0.8362165075255872], 
             UndirectedEdge[10, 89] -> 
             RGBColor[
              0.9521042490805476, 0.9324845823583294, 0.6688075502541749], 
             UndirectedEdge[148, 193] -> 
             RGBColor[
              0.9524117378739121, 0.9605492900537532, 0.7814747678045957], 
             UndirectedEdge[4, 92] -> 
             RGBColor[
              0.964354827154736, 0.9716398417993957, 0.8871565452923933], 
             UndirectedEdge[28, 97] -> 
             RGBColor[
              0.963490838326207, 0.8812166519183218, 0.40127812916666994`], 
             UndirectedEdge[60, 169] -> 
             RGBColor[
              0.5680419546257913, 0.6364811367928644, 0.9454536783780605], 
             UndirectedEdge[44, 198] -> 
             RGBColor[
              0.9929583331069011, 0.9900539432995474, 0.671708835501851], 
             UndirectedEdge[13, 64] -> 
             RGBColor[
              0.939498538168666, 0.9514596811622353, 0.8689057092249128], 
             UndirectedEdge[42, 106] -> 
             RGBColor[
              0.9882944507250004, 0.9894274688029623, 0.8436547746845966], 
             UndirectedEdge[43, 90] -> 
             RGBColor[
              0.9945891936273907, 0.990835157222458, 0.6524453018468062], 
             UndirectedEdge[166, 192] -> 
             RGBColor[
              0.9581717760099278, 0.866504481250804, 0.5306216889169535], 
             UndirectedEdge[5, 89] -> 
             RGBColor[
              0.9564641568646091, 0.8604771003784277, 0.30791438160460244`], 
             UndirectedEdge[114, 184] -> 
             RGBColor[
              0.9900671375415837, 0.9890699156867901, 0.7350013200082326], 
             UndirectedEdge[58, 192] -> 
             RGBColor[
              0.992578807126729, 0.9904098091233722, 0.7152744054209321], 
             UndirectedEdge[17, 157] -> 
             RGBColor[
              0.9588043810768633, 0.8619559623860014, 0.4377725912591057], 
             UndirectedEdge[38, 111] -> 
             RGBColor[
              0.9527464535947148, 0.8497921490012774, 0.2838071085167233], 
             UndirectedEdge[3, 191] -> 
             RGBColor[
              0.992334517945672, 0.9894543483052902, 0.6572140712225031], 
             UndirectedEdge[40, 195] -> 
             RGBColor[
              0.9377019865509262, 0.9487032447281682, 0.7705963450145246], 
             UndirectedEdge[113, 136] -> 
             RGBColor[
              0.9197233312654249, 0.7194367896211326, 0.25426571188180597`], 
             UndirectedEdge[53, 141] -> 
             RGBColor[
              0.983949466757482, 0.9559673505616969, 0.5241667691620469], 
             UndirectedEdge[142, 176] -> 
             RGBColor[
              0.966529187115587, 0.929570547743565, 0.6179624762177415], 
             UndirectedEdge[99, 128] -> 
             RGBColor[
              0.5779876209303356, 0.6438985984382595, 0.9286182595696796], 
             UndirectedEdge[41, 151] -> 
             RGBColor[
              0.9334764875999262, 0.7525438275266643, 0.4127610383399482], 
             UndirectedEdge[5, 157] -> 
             RGBColor[
              0.9678010469124245, 0.8976247444628336, 0.44501151976928716`], 
             UndirectedEdge[39, 74] -> 
             RGBColor[
              0.9642034798446901, 0.8841645993751213, 0.3945990126635498], 
             UndirectedEdge[86, 171] -> 
             RGBColor[
              0.9641468582308284, 0.8918677374687051, 0.5436211856292597], 
             UndirectedEdge[162, 180] -> 
             RGBColor[
              0.5865630546551774, 0.6476974031559464, 0.771744015629406], 
             UndirectedEdge[27, 127] -> 
             RGBColor[
              0.5813864888085263, 0.6312824153683996, 0.6626230513918747], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.9941860634864503, 0.9909296068079048, 0.6781093692723597], 
             UndirectedEdge[155, 191] -> 
             RGBColor[
              0.9886120220216263, 0.9895587926953272, 0.8383917964513343], 
             UndirectedEdge[46, 105] -> 
             RGBColor[
              0.9942684568321412, 0.9901491336488832, 0.6175350810419339], 
             UndirectedEdge[30, 168] -> 
             RGBColor[
              0.5695116983359754, 0.6375772692454351, 0.9429657856472713], 
             UndirectedEdge[161, 180] -> 
             RGBColor[
              0.9699157829991842, 0.9744870810226354, 0.7934506400732195], 
             UndirectedEdge[125, 192] -> 
             RGBColor[
              0.9917222767457441, 0.9885777772469512, 0.6220463593435066], 
             UndirectedEdge[33, 140] -> 
             RGBColor[
              0.9768949880479953, 0.9610163435808203, 0.6507583326461974], 
             UndirectedEdge[12, 58] -> 
             RGBColor[
              0.9854331798327756, 0.9613744303561016, 0.49573331859122893`], 
             UndirectedEdge[127, 155] -> 
             RGBColor[
              0.984888776027588, 0.9728105947359936, 0.6372794262348532], 
             UndirectedEdge[78, 120] -> 
             RGBColor[
              0.9629508146358803, 0.8777662761490339, 0.4783246603029484], 
             UndirectedEdge[45, 183] -> 
             RGBColor[
              0.8930957837450948, 0.5203945012275013, 0.2488971159660634], 
             UndirectedEdge[98, 136] -> 
             RGBColor[
              0.5447370457098548, 0.4942250282167653, 0.5901916469539554], 
             UndirectedEdge[59, 92] -> 
             RGBColor[
              0.9654560831432721, 0.9711610441721845, 0.8009997486532703], 
             UndirectedEdge[81, 89] -> 
             RGBColor[
              0.9804182231580729, 0.9528431876249543, 0.5861321489030313], 
             UndirectedEdge[161, 200] -> 
             RGBColor[
              0.9645708153963719, 0.9575040345689445, 0.6836754668130056], 
             UndirectedEdge[125, 198] -> 
             RGBColor[
              0.9932132612129367, 0.9878921769160476, 0.5026835498040586], 
             UndirectedEdge[159, 173] -> 
             RGBColor[
              0.9699301801155904, 0.9105153129793111, 0.5273240636042567], 
             UndirectedEdge[54, 151] -> 
             RGBColor[
              0.9327318212317035, 0.7509510614623549, 0.33170869970702355`], 
             UndirectedEdge[61, 192] -> 
             RGBColor[
              0.9137862331116474, 0.9315754254574413, 0.8932906080102909], 
             UndirectedEdge[59, 194] -> 
             RGBColor[
              0.9932290786646052, 0.9905338689906836, 0.6939690843676631], 
             UndirectedEdge[80, 82] -> 
             RGBColor[
              0.5862790336057773, 0.6470899108502123, 0.7408300771769281], 
             UndirectedEdge[157, 168] -> 
             RGBColor[
              0.5866015885303953, 0.6477798232186649, 0.7759381901433572], 
             UndirectedEdge[122, 170] -> 
             RGBColor[
              0.9189350165480092, 0.7149703809785415, 0.25356204663559534`], 
             UndirectedEdge[26, 67] -> 
             RGBColor[
              0.9639918868583344, 0.9710166181940387, 0.8723972154740145], 
             UndirectedEdge[160, 181] -> 
             RGBColor[
              0.9906196978333809, 0.9887611424765501, 0.6867900293956053], 
             UndirectedEdge[42, 168] -> 
             RGBColor[
              0.5855860812831982, 0.6482275948390214, 0.8558411276790809], 
             UndirectedEdge[61, 67] -> 
             RGBColor[
              0.9153270358874916, 0.9322125870020781, 0.8677555185447903], 
             UndirectedEdge[9, 39] -> 
             RGBColor[
              0.937134511044857, 0.8671323786072609, 0.6271347959074018], 
             UndirectedEdge[118, 171] -> 
             RGBColor[
              0.9662796802028948, 0.9734323899450594, 0.8998852766828257], 
             UndirectedEdge[97, 134] -> 
             RGBColor[
              0.9914561385912414, 0.9822073691107296, 0.47524726646311266`], 
             UndirectedEdge[79, 190] -> 
             RGBColor[
              0.9781302690174529, 0.9819566126508548, 0.8657670272196474], 
             UndirectedEdge[47, 50] -> 
             RGBColor[
              0.920838736037811, 0.934986933421917, 0.7470997771052839], 
             UndirectedEdge[36, 145] -> 
             RGBColor[
              0.9177611326258817, 0.7116573258792782, 0.2526868807977076], 
             UndirectedEdge[170, 179] -> 
             RGBColor[
              0.9467510936278292, 0.813143122524593, 0.4093392911253795], 
             UndirectedEdge[26, 198] -> 
             RGBColor[
              0.9639420685496829, 0.9696938563184984, 0.778569495400067], 
             UndirectedEdge[5, 141] -> 
             RGBColor[
              0.9571031043853514, 0.8626324203979037, 0.3103965720675714], 
             UndirectedEdge[18, 39] -> 
             RGBColor[
              0.5569687114711601, 0.5427195069993519, 0.6000335323395982], 
             UndirectedEdge[19, 180] -> 
             RGBColor[
              0.9842060002427263, 0.9573384872618604, 0.4821547061356497], 
             UndirectedEdge[170, 198] -> 
             RGBColor[
              0.9466720592562611, 0.8129740759954096, 0.4007368875237999], 
             UndirectedEdge[12, 172] -> 
             RGBColor[
              0.5777131757305913, 0.6188914678215988, 0.6483529237310663], 
             UndirectedEdge[47, 101] -> 
             RGBColor[
              0.5136675244030974, 0.5936777824839043, 0.9594520555747914], 
             UndirectedEdge[53, 54] -> 
             RGBColor[
              0.9938642090411146, 0.9892844884995989, 0.5735352037168867], 
             UndirectedEdge[57, 121] -> 
             RGBColor[
              0.9937805754056732, 0.9902022191762692, 0.6441445011385034], 
             UndirectedEdge[19, 121] -> 
             RGBColor[
              0.984111864499739, 0.9582337549924157, 0.5516209139623823], 
             UndirectedEdge[170, 192] -> 
             RGBColor[
              0.9451810747890683, 0.8136596763263132, 0.5200996970632479], 
             UndirectedEdge[7, 137] -> 
             RGBColor[
              0.9207087763521552, 0.8061066967392286, 0.6170968351594202], 
             UndirectedEdge[111, 115] -> 
             RGBColor[
              0.9616141612783033, 0.8821776939474852, 0.3053786944339474], 
             UndirectedEdge[140, 162] -> 
             RGBColor[
              0.5790566498933682, 0.6234233216353798, 0.6535720671596473], 
             UndirectedEdge[8, 79] -> 
             RGBColor[
              0.9930192117249811, 0.9905350387404483, 0.703840531589455], 
             UndirectedEdge[2, 52] -> 
             RGBColor[
              0.9907810405123524, 0.9798386207469676, 0.5713651012308605], 
             UndirectedEdge[18, 152] -> 
             RGBColor[
              0.5859786364705599, 0.6483899264972037, 0.8493354723242363], 
             UndirectedEdge[4, 195] -> 
             RGBColor[
              0.9368643004938166, 0.9497457917876928, 0.8854411021243518], 
             UndirectedEdge[81, 107] -> 
             RGBColor[
              0.584080524675493, 0.6476050084906954, 0.880792096924359], 
             UndirectedEdge[108, 175] -> 
             RGBColor[
              0.9940476296234436, 0.9896768065785351, 0.5934994021627802], 
             UndirectedEdge[49, 191] -> 
             RGBColor[
              0.9927327436338373, 0.9912628169796915, 0.7701007752513096], 
             UndirectedEdge[77, 192] -> 
             RGBColor[
              0.9215427243416592, 0.6967131730881964, 0.4999989637638206], 
             UndirectedEdge[21, 166] -> 
             RGBColor[
              0.9534863286198881, 0.8641063504637514, 0.5876460592026158], 
             UndirectedEdge[8, 192] -> 
             RGBColor[
              0.9925458351281747, 0.9903392853524453, 0.7116856068578983], 
             UndirectedEdge[108, 165] -> 
             RGBColor[
              0.9937707009365492, 0.989084484119053, 0.5633574236000665], 
             UndirectedEdge[29, 194] -> 
             RGBColor[
              0.9932343659691082, 0.9905451780003871, 0.6945445748333536], 
             UndirectedEdge[106, 131] -> 
             RGBColor[
              0.9747118228150287, 0.9408311075675846, 0.6139853775688123], 
             UndirectedEdge[12, 68] -> 
             RGBColor[
              0.9813064224165042, 0.9486043147294327, 0.38187941038437834`], 
             UndirectedEdge[71, 168] -> 
             RGBColor[
              0.551938652653643, 0.5227769999556328, 0.5959862289443685], 
             UndirectedEdge[49, 146] -> 
             RGBColor[
              0.9804950167259421, 0.9457932756027283, 0.5359112545092971], 
             UndirectedEdge[112, 134] -> 
             RGBColor[
              0.9853442830582944, 0.9622249668089558, 0.3975657364917332], 
             UndirectedEdge[84, 126] -> 
             RGBColor[
              0.5618521990383656, 0.5620809078775588, 0.6039629010663576], 
             UndirectedEdge[10, 62] -> 
             RGBColor[
              0.9637781223355562, 0.9703529994486926, 0.8425832309025374], 
             UndirectedEdge[34, 182] -> 
             RGBColor[
              0.5769957411137404, 0.643158856095097, 0.9302972533754872], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.5816353694418022, 0.646593873963941, 0.9213146470055158], 
             UndirectedEdge[67, 79] -> 
             RGBColor[
              0.9928047854217399, 0.9912926081103786, 0.7689068563875954], 
             UndirectedEdge[33, 96] -> 
             RGBColor[
              0.9806414496947918, 0.9846697872766574, 0.8991484039025226], 
             UndirectedEdge[12, 140] -> 
             RGBColor[
              0.9778428256239595, 0.9369207894569787, 0.36842399089071365`], 
             UndirectedEdge[26, 124] -> 
             RGBColor[
              0.9642636234267383, 0.9711289882483849, 0.8678938373038652], 
             UndirectedEdge[13, 70] -> 
             RGBColor[
              0.9946179924836898, 0.992042415827791, 0.7388573229416289], 
             UndirectedEdge[53, 146] -> 
             RGBColor[
              0.9809178286488289, 0.9457409233587318, 0.5123894275867487], 
             UndirectedEdge[87, 147] -> 
             RGBColor[
              0.992666205960155, 0.9912353019416835, 0.7712034766982079], 
             UndirectedEdge[93, 200] -> 
             RGBColor[
              0.9852288848064541, 0.9618357014087004, 0.39711743607446515`], 
             UndirectedEdge[9, 117] -> 
             RGBColor[
              0.966144219055517, 0.9708597992437267, 0.7352113485272989], 
             UndirectedEdge[99, 116] -> 
             RGBColor[
              0.5862394932943855, 0.6484977974975701, 0.8450123996776282], 
             UndirectedEdge[71, 155] -> 
             RGBColor[
              0.9554409398727046, 0.8643051793232268, 0.5706426037873471], 
             UndirectedEdge[54, 140] -> 
             RGBColor[
              0.985948038180323, 0.9641339587270169, 0.41076274415612857`], 
             UndirectedEdge[76, 154] -> 
             RGBColor[
              0.965507326451168, 0.9727372163487626, 0.8958567359536376], 
             UndirectedEdge[33, 128] -> 
             RGBColor[
              0.9758259590849627, 0.9814916203837001, 0.9258045250562297], 
             UndirectedEdge[109, 148] -> 
             RGBColor[
              0.9167244942620273, 0.83109293805148, 0.6239240833792161], 
             UndirectedEdge[27, 142] -> 
             RGBColor[
              0.5754254447708884, 0.6419877316537221, 0.9329553554850567], 
             UndirectedEdge[49, 69] -> 
             RGBColor[
              0.9760323063198248, 0.9307395055086618, 0.5185744672936777], 
             UndirectedEdge[60, 90] -> 
             RGBColor[
              0.5870727642365936, 0.6487876204110516, 0.8272227580036433], 
             UndirectedEdge[40, 191] -> 
             RGBColor[
              0.9924822195263155, 0.9897702670513662, 0.6732904767670576], 
             UndirectedEdge[58, 166] -> 
             RGBColor[
              0.9599599770875674, 0.8664545971964374, 0.44360907321634646`], 
             UndirectedEdge[38, 60] -> 
             RGBColor[
              0.5632641561061628, 0.5676788471445738, 0.6050989948659993], 
             UndirectedEdge[54, 119] -> 
             RGBColor[
              0.9659925324283702, 0.8918845290374886, 0.35894001471719494`], 
             UndirectedEdge[3, 146] -> 
             RGBColor[
              0.9800967910377767, 0.943984806928327, 0.42302455048049065`], 
             UndirectedEdge[115, 163] -> 
             RGBColor[
              0.9616141612783033, 0.8821776939474852, 0.3053786944339474], 
             UndirectedEdge[137, 170] -> 
             RGBColor[
              0.9021380196285842, 0.6483758854604343, 0.2400467886380341], 
             UndirectedEdge[58, 99] -> 
             RGBColor[
              0.5866470041021843, 0.6478769625345028, 0.7808813948601626], 
             UndirectedEdge[40, 64] -> 
             RGBColor[
              0.939329103980227, 0.9500006639993666, 0.7707515409274762], 
             UndirectedEdge[77, 96] -> 
             RGBColor[
              0.9194870328572791, 0.6958630918305437, 0.5340670916190235], 
             UndirectedEdge[141, 195] -> 
             RGBColor[
              0.9273061478304974, 0.9143570901582703, 0.6688635322974641], 
             UndirectedEdge[138, 182] -> 
             RGBColor[
              0.5841759159471336, 0.6476444552329625, 0.879211216688576], 
             UndirectedEdge[33, 102] -> 
             RGBColor[
              0.9843145910318756, 0.9861887256149682, 0.838274946161979], 
             UndirectedEdge[137, 198] -> 
             RGBColor[
              0.9492385353557979, 0.8244903019809564, 0.40287130315687725`], 
             UndirectedEdge[69, 171] -> 
             RGBColor[
              0.9738696897026804, 0.9298452079607606, 0.5544146213121627], 
             UndirectedEdge[20, 46] -> 
             RGBColor[
              0.9941515897998263, 0.9898991668838314, 0.6048148257941885], 
             UndirectedEdge[76, 157] -> 
             RGBColor[
              0.9924205821157628, 0.9902660202053641, 0.7122007450527638], 
             UndirectedEdge[10, 168] -> 
             RGBColor[
              0.5557665505979678, 0.6272464032240703, 0.9634674982755025], 
             UndirectedEdge[82, 100] -> 
             RGBColor[
              0.5796067658850854, 0.6451061540944054, 0.9258774695019256], 
             UndirectedEdge[9, 57] -> 
             RGBColor[
              0.9664044560671801, 0.9714164198976764, 0.7635365412501687], 
             UndirectedEdge[27, 71] -> 
             RGBColor[
              0.551938652653643, 0.5227769999556328, 0.5959862289443685], 
             UndirectedEdge[122, 125] -> 
             RGBColor[
              0.965476218504685, 0.8898884818991795, 0.355508708915854], 
             UndirectedEdge[5, 147] -> 
             RGBColor[
              0.9676543202441846, 0.8984317791792313, 0.5105165147796235], 
             UndirectedEdge[5, 71] -> 
             RGBColor[
              0.9331381110356722, 0.7726219211998016, 0.26505955857029845`], 
             UndirectedEdge[61, 84] -> 
             RGBColor[
              0.5078544300871027, 0.5890425788685719, 0.9588975974495213], 
             UndirectedEdge[62, 149] -> 
             RGBColor[
              0.9879101400144774, 0.9693699062594547, 0.5359584937237141], 
             UndirectedEdge[36, 138] -> 
             RGBColor[
              0.954414021708108, 0.8540312659888774, 0.5394647846995904], 
             UndirectedEdge[33, 162] -> 
             RGBColor[
              0.5767653381546272, 0.6429870219454406, 0.9306872654865501], 
             UndirectedEdge[63, 145] -> 
             RGBColor[
              0.934458383201645, 0.7778563603832653, 0.266121880545811], 
             UndirectedEdge[93, 173] -> 
             RGBColor[
              0.9896038217635167, 0.9793518105411823, 0.5908746624435305], 
             UndirectedEdge[23, 55] -> 
             RGBColor[
              0.9782567617216297, 0.9832792996685218, 0.9205608844277844], 
             UndirectedEdge[23, 165] -> 
             RGBColor[
              0.9885278731633473, 0.9873068968573788, 0.6786267321734856], 
             UndirectedEdge[54, 64] -> 
             RGBColor[
              0.9388480075434307, 0.9489716473673706, 0.7183871627652556], 
             UndirectedEdge[72, 158] -> 
             RGBColor[
              0.9183910216142553, 0.7968617798277594, 0.6159303939729837], 
             UndirectedEdge[73, 149] -> 
             RGBColor[
              0.9846081499647032, 0.9682907366913082, 0.6114911422144974], 
             UndirectedEdge[10, 197] -> 
             RGBColor[
              0.9283055898195329, 0.8427556484106054, 0.6255724513587582], 
             UndirectedEdge[37, 135] -> 
             RGBColor[
              0.8443588451482731, 0.6261219670423125, 0.5895381288476027], 
             UndirectedEdge[58, 96] -> 
             RGBColor[
              0.9905231156423489, 0.9895597278657197, 0.7493425332761352], 
             UndirectedEdge[112, 156] -> 
             RGBColor[
              0.9731764321620784, 0.9211799485887646, 0.3502959334657687], 
             UndirectedEdge[2, 187] -> 
             RGBColor[
              0.5829377977540889, 0.636515344706445, 0.6686495937052732], 
             UndirectedEdge[43, 169] -> 
             RGBColor[
              0.9755583840165886, 0.9785286736042708, 0.7706762222212233], 
             UndirectedEdge[44, 96] -> 
             RGBColor[
              0.9894116571553283, 0.9898894623727985, 0.8251397728965021], 
             UndirectedEdge[88, 161] -> 
             RGBColor[
              0.9699027371752796, 0.9754158815186473, 0.8615729780867675], 
             UndirectedEdge[129, 146] -> 
             RGBColor[
              0.9667330243742438, 0.8994448211363036, 0.3252645109454919], 
             UndirectedEdge[23, 111] -> 
             RGBColor[
              0.9711176669303543, 0.9287071758206444, 0.6000227606562396], 
             UndirectedEdge[174, 196] -> 
             RGBColor[
              0.9774286624444481, 0.9347433131574059, 0.43317519311920916`], 
             UndirectedEdge[66, 100] -> 
             RGBColor[
              0.9745403689009842, 0.9805328293294495, 0.9279806939020849], 
             UndirectedEdge[10, 73] -> 
             RGBColor[
              0.9604761322857821, 0.9692738298805461, 0.9181158793933206], 
             UndirectedEdge[147, 188] -> 
             RGBColor[
              0.9690382234685881, 0.9748027433485913, 0.8644521468012376], 
             UndirectedEdge[62, 189] -> 
             RGBColor[
              0.9925199993554016, 0.990888553578571, 0.7528163704198318], 
             UndirectedEdge[42, 89] -> 
             RGBColor[
              0.981923779765778, 0.9534657739732804, 0.5611811796577533], 
             UndirectedEdge[119, 140] -> 
             RGBColor[
              0.9592307940347837, 0.8692032135812314, 0.321820404880361], 
             UndirectedEdge[140, 151] -> 
             RGBColor[
              0.925970082838117, 0.7282697460060978, 0.2945890898701896], 
             UndirectedEdge[1, 86] -> 
             RGBColor[
              0.5586864660166999, 0.5495298313646481, 0.601415677967821], 
             UndirectedEdge[76, 181] -> 
             RGBColor[
              0.9919800016061369, 0.9893236630447971, 0.6642462755277212], 
             UndirectedEdge[122, 166] -> 
             RGBColor[
              0.9319257177688688, 0.7678151859030322, 0.26408403848930084`], 
             UndirectedEdge[10, 189] -> 
             RGBColor[
              0.961347978215781, 0.969634360578019, 0.9036671360682995], 
             UndirectedEdge[102, 162] -> 
             RGBColor[
              0.5864762528772485, 0.6485957036695277, 0.841088680675429], 
             UndirectedEdge[156, 183] -> 
             RGBColor[
              0.8911823906844374, 0.5139401771478487, 0.24146394523936998`], 
             UndirectedEdge[31, 199] -> 
             RGBColor[
              0.5865546587897544, 0.6476794452487586, 0.7708301774913795], 
             UndirectedEdge[73, 130] -> 
             RGBColor[
              0.990924305692189, 0.9889797857719861, 0.6884787550549313], 
             UndirectedEdge[4, 199] -> 
             RGBColor[
              0.5854617986666414, 0.6481762007831575, 0.857900812268529], 
             UndirectedEdge[6, 83] -> 
             RGBColor[
              0.9683264787445011, 0.8994341814411664, 0.46163188871517596`], 
             UndirectedEdge[73, 89] -> 
             RGBColor[
              0.9799742801703941, 0.9526596057907348, 0.5934894330964906], 
             UndirectedEdge[60, 111] -> 
             RGBColor[
              0.568409297488552, 0.5875073018567036, 0.612209113650724], 
             UndirectedEdge[166, 179] -> 
             RGBColor[
              0.9597417948486886, 0.8659879274490838, 0.419861282979085], 
             UndirectedEdge[30, 197] -> 
             RGBColor[
              0.9420507375575405, 0.8530865144319701, 0.605070738730527], 
             UndirectedEdge[26, 58] -> 
             RGBColor[
              0.9642392851601298, 0.9703295725950354, 0.8109196892389081], 
             UndirectedEdge[11, 35] -> 
             RGBColor[
              0.9831371421910936, 0.9534118836266545, 0.5053059485190593], 
             UndirectedEdge[137, 187] -> 
             RGBColor[
              0.5418157478640605, 0.4826430557229906, 0.5878411021355558], 
             UndirectedEdge[13, 153] -> 
             RGBColor[
              0.9943805478780638, 0.9914854996281907, 0.7094478021573238], 
             UndirectedEdge[71, 75] -> 
             RGBColor[
              0.943365596961149, 0.8555884148675843, 0.6040253118547689], 
             UndirectedEdge[16, 67] -> 
             RGBColor[
              0.9939181890759061, 0.9906161518865375, 0.6678159019979744], 
             UndirectedEdge[156, 170] -> 
             RGBColor[
              0.9323086624489612, 0.7653065068852924, 0.2783111317418483], 
             UndirectedEdge[96, 128] -> 
             RGBColor[
              0.9818637324705002, 0.9855813637694764, 0.8970793979856522], 
             UndirectedEdge[62, 114] -> 
             RGBColor[
              0.9944839738935597, 0.9906101028511403, 0.6409927831602189], 
             UndirectedEdge[101, 105] -> 
             RGBColor[
              0.586161914253498, 0.6468394043982699, 0.7280823584581857], 
             UndirectedEdge[30, 89] -> 
             RGBColor[
              0.9658493968185552, 0.9428154483796942, 0.6483058376259437], 
             UndirectedEdge[53, 191] -> 
             RGBColor[
              0.9931555555567244, 0.9912104647356951, 0.7465789483287611], 
             UndirectedEdge[72, 81] -> 
             RGBColor[
              0.962672648534949, 0.9708442353275808, 0.9105571829960124], 
             UndirectedEdge[163, 175] -> 
             RGBColor[
              0.9755787298969916, 0.9288126472096236, 0.3996631773814075], 
             UndirectedEdge[82, 125] -> 
             RGBColor[
              0.5857904737211994, 0.6460449306580818, 0.6876533487827371], 
             UndirectedEdge[113, 148] -> 
             RGBColor[
              0.9199384074062319, 0.843835032695184, 0.6265100733352805], 
             UndirectedEdge[33, 44] -> 
             RGBColor[
              0.9833738837697908, 0.9857997189870222, 0.8538648999670795], 
             UndirectedEdge[21, 179] -> 
             RGBColor[
              0.9876751774978104, 0.9875450085889661, 0.7485509854693331], 
             UndirectedEdge[75, 188] -> 
             RGBColor[
              0.9529373059139388, 0.9644213003254802, 0.9645490445579447], 
             UndirectedEdge[85, 88] -> 
             RGBColor[
              0.9585704917523651, 0.9666360131205953, 0.8693732049414034], 
             UndirectedEdge[13, 185] -> 
             RGBColor[
              0.9333823518569389, 0.7534390952572196, 0.48222724616668083`], 
             UndirectedEdge[93, 161] -> 
             RGBColor[
              0.9662905260980957, 0.963305022573134, 0.690356218149087], 
             UndirectedEdge[146, 196] -> 
             RGBColor[
              0.9639534221576647, 0.8900685701781453, 0.3144662812179161], 
             UndirectedEdge[19, 162] -> 
             RGBColor[
              0.5765699455875488, 0.615035084105914, 0.6439116905062439], 
             UndirectedEdge[140, 172] -> 
             RGBColor[
              0.5790566498933682, 0.6234233216353798, 0.6535720671596473], 
             UndirectedEdge[71, 142] -> 
             RGBColor[
              0.9484370974245313, 0.8593707316093551, 0.595440584429425], 
             UndirectedEdge[87, 142] -> 
             RGBColor[
              0.9816367888688879, 0.9846361756603431, 0.8627156470295709], 
             UndirectedEdge[89, 147] -> 
             RGBColor[
              0.9827925603447352, 0.9538250370693218, 0.546783237132366], 
             UndirectedEdge[30, 42] -> 
             RGBColor[
              0.9761707796191735, 0.9804108640844564, 0.8653059133263521], 
             UndirectedEdge[8, 125] -> 
             RGBColor[
              0.9934775058248295, 0.9884573694216576, 0.5314449450798657], 
             UndirectedEdge[29, 168] -> 
             RGBColor[
              0.5865683419596804, 0.6477087121656498, 0.7723195060950965], 
             UndirectedEdge[158, 160] -> 
             RGBColor[
              0.9442575875674106, 0.8155462294093263, 0.5449716166786208], 
             UndirectedEdge[138, 153] -> 
             RGBColor[
              0.9920875449130073, 0.9905372839746516, 0.7474487953897614], 
             UndirectedEdge[26, 122] -> 
             RGBColor[
              0.9362050258414312, 0.8716901613016302, 0.6313946545118625], 
             UndirectedEdge[53, 195] -> 
             RGBColor[
              0.938375322581335, 0.9501434424124973, 0.8438848165762282], 
             UndirectedEdge[19, 93] -> 
             RGBColor[
              0.9805807433416378, 0.946156428812359, 0.379060284211517], 
             UndirectedEdge[11, 196] -> 
             RGBColor[
              0.9779046042997205, 0.9357613046607303, 0.4849785268929425], 
             UndirectedEdge[87, 168] -> 
             RGBColor[
              0.5851383440979996, 0.6480424440066209, 0.8632612915445144], 
             UndirectedEdge[78, 124] -> 
             RGBColor[
              0.9946903961439062, 0.9917989777341907, 0.7177856491629682], 
             UndirectedEdge[39, 117] -> 
             RGBColor[
              0.96402013095298, 0.8837724346351696, 0.3746426172990933], 
             UndirectedEdge[42, 130] -> 
             RGBColor[
              0.9928738052875729, 0.9897859539545316, 0.656170501616194], 
             UndirectedEdge[11, 94] -> 
             RGBColor[
              0.9398528092932008, 0.9511208167090885, 0.827753632310144], 
             UndirectedEdge[27, 168] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[30, 51] -> 
             RGBColor[
              0.9774868542539401, 0.9806059757140866, 0.818117881040662], 
             UndirectedEdge[6, 58] -> 
             RGBColor[
              0.9944715159324039, 0.9905834565319211, 0.6396368109700403], 
             UndirectedEdge[6, 156] -> 
             RGBColor[
              0.9798109025146571, 0.942280171145267, 0.4848608613492478], 
             UndirectedEdge[19, 173] -> 
             RGBColor[
              0.9832359695969766, 0.9578715499406512, 0.566136759244501], 
             UndirectedEdge[57, 200] -> 
             RGBColor[
              0.9885297435458482, 0.9723239049920229, 0.4649031200515569], 
             UndirectedEdge[37, 50] -> 
             RGBColor[
              0.9165247093111006, 0.9315470456111741, 0.7466883013849132], 
             UndirectedEdge[49, 171] -> 
             RGBColor[
              0.9920104010454012, 0.9909641097560153, 0.7820718613043925], 
             UndirectedEdge[5, 127] -> 
             RGBColor[
              0.9625859471905555, 0.8811273366125683, 0.33169638101780463`], 
             UndirectedEdge[85, 152] -> 
             RGBColor[
              0.9579991193916522, 0.9663997359658407, 0.8788423236226859], 
             UndirectedEdge[130, 131] -> 
             RGBColor[
              0.9792911773776011, 0.9411895927191538, 0.4265011045004097], 
             UndirectedEdge[33, 58] -> 
             RGBColor[
              0.9844853422568114, 0.9854699844799433, 0.7780676603467127], 
             UndirectedEdge[82, 98] -> RGBColor[0.178927, 0.305394, 0.933501],
              UndirectedEdge[74, 173] -> 
             RGBColor[
              0.9928277923829578, 0.9896755582105066, 0.6502915490622088], 
             UndirectedEdge[118, 146] -> 
             RGBColor[
              0.9547642958834356, 0.9282615557917723, 0.6537246698877303], 
             UndirectedEdge[23, 115] -> 
             RGBColor[
              0.9748402332315536, 0.9412642660547226, 0.6144842277887391], 
             UndirectedEdge[49, 65] -> 
             RGBColor[
              0.9894944843044889, 0.9761505929206411, 0.570872486645102], 
             UndirectedEdge[21, 23] -> 
             RGBColor[
              0.9828817250763071, 0.9867285897657578, 0.9127320278519477], 
             UndirectedEdge[40, 171] -> 
             RGBColor[
              0.9917598769378793, 0.98947155982769, 0.6852615628201406], 
             UndirectedEdge[104, 158] -> 
             RGBColor[
              0.946464921764227, 0.8164590188256111, 0.5083903766395874], 
             UndirectedEdge[53, 155] -> 
             RGBColor[
              0.9904751079732216, 0.9901020307755559, 0.791000901563384], 
             UndirectedEdge[164, 200] -> 
             RGBColor[
              0.9866334875532399, 0.9730336575766478, 0.6049199791540634], 
             UndirectedEdge[81, 142] -> 
             RGBColor[
              0.9805789694463815, 0.9841987401444175, 0.8802464524094156], 
             UndirectedEdge[39, 85] -> 
             RGBColor[
              0.9289891943922524, 0.860729316467989, 0.6295403836380478], 
             UndirectedEdge[107, 142] -> 
             RGBColor[
              0.5754254447708884, 0.6419877316537221, 0.9329553554850567], 
             UndirectedEdge[121, 161] -> 
             RGBColor[
              0.9698216472561969, 0.9753823487531907, 0.8629168478999523], 
             UndirectedEdge[1, 196] -> 
             RGBColor[
              0.5700084142629955, 0.5929014982273755, 0.6184213803515728], 
             UndirectedEdge[88, 121] -> 
             RGBColor[
              0.994091927743463, 0.99182487453846, 0.7475755770990924], 
             UndirectedEdge[85, 133] -> 
             RGBColor[
              0.9342835068819508, 0.9501810292337252, 0.9847427519057322], 
             UndirectedEdge[118, 127] -> 
             RGBColor[
              0.9632787767972926, 0.9569828992094019, 0.6868018204132615], 
             UndirectedEdge[100, 187] -> 
             RGBColor[
              0.5796067658850854, 0.6451061540944054, 0.9258774695019256], 
             UndirectedEdge[26, 116] -> 
             RGBColor[
              0.963831774352331, 0.9709504075581026, 0.8750506940563738], 
             UndirectedEdge[131, 147] -> 
             RGBColor[
              0.9795313152353817, 0.9428240915387063, 0.5341139157169901], 
             UndirectedEdge[134, 160] -> 
             RGBColor[
              0.9886129313932648, 0.9825423717864921, 0.6321815570426251], 
             UndirectedEdge[3, 5] -> 
             RGBColor[
              0.9673512415251367, 0.8966626562217257, 0.3960529792400773], 
             UndirectedEdge[16, 100] -> 
             RGBColor[
              0.9871253491606027, 0.9871582978474368, 0.751334450404631], 
             UndirectedEdge[75, 147] -> 
             RGBColor[
              0.9778818061696615, 0.9813982728470142, 0.8494822680640939], 
             UndirectedEdge[72, 76] -> 
             RGBColor[
              0.9633381174448234, 0.9711194238235847, 0.8995286409810601], 
             UndirectedEdge[40, 69] -> 
             RGBColor[
              0.975781782212303, 0.9292469555803365, 0.4217641688094258], 
             UndirectedEdge[177, 179] -> 
             RGBColor[
              0.9887524903864363, 0.9728405544407908, 0.48572801985352365`], 
             UndirectedEdge[98, 100] -> 
             RGBColor[
              0.5796067658850854, 0.6451061540944054, 0.9258774695019256], 
             UndirectedEdge[136, 187] -> 
             RGBColor[
              0.5447370457098547, 0.4942250282167653, 0.5901916469539553], 
             UndirectedEdge[54, 199] -> 
             RGBColor[
              0.5858183882869548, 0.646104637091637, 0.6906916769964813], 
             UndirectedEdge[166, 198] -> 
             RGBColor[
              0.9596627604771206, 0.8658188809199003, 0.4112588793775054], 
             UndirectedEdge[48, 104] -> 
             RGBColor[
              0.9821324183710609, 0.9541490125294878, 0.5618496711199812], 
             UndirectedEdge[187, 198] -> 
             RGBColor[
              0.5863497874917374, 0.6472412462579658, 0.7485312010213215], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.9945799136972688, 0.9908153083902722, 0.6514352387221314], 
             UndirectedEdge[103, 117] -> 
             RGBColor[
              0.5859784194818198, 0.6464469276358178, 0.7081100849594952], 
             UndirectedEdge[85, 140] -> 
             RGBColor[
              0.9510771328144605, 0.9414331311040169, 0.6830789184580969], 
             UndirectedEdge[36, 70] -> 
             RGBColor[
              0.957314179332474, 0.855230555697204, 0.49140166749650466`], 
             UndirectedEdge[54, 171] -> 
             RGBColor[
              0.9912787805010831, 0.988442543195694, 0.63289718465792], 
             UndirectedEdge[120, 125] -> 
             RGBColor[
              0.9617952345819663, 0.8752946072607773, 0.35254690284783685`], 
             UndirectedEdge[81, 104] -> 
             RGBColor[
              0.9907465486849207, 0.9904414743254326, 0.8030171656626162], 
             UndirectedEdge[93, 162] -> 
             RGBColor[
              0.5829377977540889, 0.636515344706445, 0.6686495937052732], 
             UndirectedEdge[73, 168] -> 
             RGBColor[
              0.5836365816878143, 0.6474214266564758, 0.8881493811178183], 
             UndirectedEdge[119, 199] -> 
             RGBColor[
              0.5591011441414154, 0.5511738919458515, 0.6017493377207137], 
             UndirectedEdge[17, 107] -> 
             RGBColor[
              0.551129792546468, 0.5195701391673365, 0.5953354011157486], 
             UndirectedEdge[14, 48] -> 
             RGBColor[
              0.970435830941492, 0.9119352571479589, 0.3396492152429045], 
             UndirectedEdge[64, 182] -> 
             RGBColor[
              0.5319566192564759, 0.6082610102757336, 0.9611964857687744], 
             UndirectedEdge[71, 129] -> 
             RGBColor[
              0.9457996691332176, 0.8196607491411665, 0.29170483902351707`], 
             UndirectedEdge[80, 100] -> 
             RGBColor[
              0.9869587994908626, 0.9868020649446176, 0.7332065466788537], 
             UndirectedEdge[18, 178] -> 
             RGBColor[
              0.5627049772219976, 0.5654618892041758, 0.6046490664101847], 
             UndirectedEdge[174, 186] -> 
             RGBColor[
              0.9628117921756112, 0.8783083784429768, 0.4135183191343602], 
             UndirectedEdge[115, 165] -> 
             RGBColor[
              0.9790243675112964, 0.9407774149842196, 0.38398266595119324`], 
             UndirectedEdge[113, 198] -> 
             RGBColor[
              0.9613360730473077, 0.8724530076623331, 0.41260526594917213`], 
             UndirectedEdge[67, 100] -> 
             RGBColor[
              0.9870793716854742, 0.9882761622279115, 0.8347353905971946], 
             UndirectedEdge[106, 147] -> 
             RGBColor[
              0.9891632313039576, 0.9897867318990036, 0.8292568321592092], 
             UndirectedEdge[75, 129] -> 
             RGBColor[
              0.9642149607870807, 0.9350891640974852, 0.6372586929895491], 
             UndirectedEdge[175, 183] -> 
             RGBColor[
              0.9052924324084395, 0.56106584535292, 0.33631356373068355`], 
             UndirectedEdge[105, 144] -> 
             RGBColor[
              0.983057628002072, 0.9539599000529423, 0.43559019437290447`], 
             UndirectedEdge[44, 128] -> 
             RGBColor[
              0.9845961665454992, 0.9867112954798412, 0.8517958940502091], 
             UndirectedEdge[70, 138] -> 
             RGBColor[
              0.9923249895186332, 0.9910942001742518, 0.7768583161740663], 
             UndirectedEdge[110, 145] -> 
             RGBColor[
              0.9549715557164987, 0.8484305668197925, 0.5016902512326822], 
             UndirectedEdge[49, 118] -> 
             RGBColor[
              0.9684422968200392, 0.9743266874929606, 0.8640451226643407], 
             UndirectedEdge[70, 185] -> 
             RGBColor[
              0.9339895065162483, 0.753690169312007, 0.47216512219603257`], 
             UndirectedEdge[11, 138] -> 
             RGBColor[
              0.9920721059838586, 0.9905042616663176, 0.7457683632299457], 
             UndirectedEdge[120, 187] -> 
             RGBColor[
              0.5549317608607669, 0.5346436766026956, 0.5983945540650999], 
             UndirectedEdge[71, 127] -> 
             RGBColor[
              0.9543981414621692, 0.8486654153240324, 0.3251082803362431], 
             UndirectedEdge[4, 182] -> 
             RGBColor[
              0.5854617986666414, 0.6481762007831575, 0.857900812268529], 
             UndirectedEdge[29, 71] -> 
             RGBColor[
              0.9595799946133234, 0.8650917121212827, 0.43480473503946493`], 
             UndirectedEdge[63, 185] -> 
             RGBColor[
              0.9127757892814864, 0.6828262696306198, 0.24820659046966004`], 
             UndirectedEdge[83, 175] -> 
             RGBColor[
              0.967671399322721, 0.8980330327966681, 0.39033053633598175`], 
             UndirectedEdge[79, 126] -> 
             RGBColor[
              0.9682573786597165, 0.9048095078544311, 0.530510836358684], 
             UndirectedEdge[107, 154] -> 
             RGBColor[
              0.5596883328658004, 0.6302510193620634, 0.959594181044231], 
             UndirectedEdge[34, 64] -> 
             RGBColor[
              0.9300253603702163, 0.9460258663708306, 0.9579927391442615], 
             UndirectedEdge[159, 180] -> 
             RGBColor[
              0.9709002107613403, 0.9099822503005203, 0.4433420104954052], 
             UndirectedEdge[3, 123] -> 
             RGBColor[
              0.9924717532508859, 0.9895110986307826, 0.6549397270615239], 
             UndirectedEdge[50, 97] -> 
             RGBColor[
              0.9934001086453015, 0.9882918246807024, 0.5230207397282707], 
             UndirectedEdge[87, 89] -> 
             RGBColor[
              0.9814760425805794, 0.9532806231408799, 0.5686013435231868], 
             UndirectedEdge[123, 191] -> 
             RGBColor[
              0.9914297049103429, 0.9907239769809588, 0.7916954990557323], 
             UndirectedEdge[108, 151] -> 
             RGBColor[
              0.9337916301597529, 0.753217885596333, 0.4470623611426389], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.5864455832755172, 0.6474461437530314, 0.7589579809027054], 
             UndirectedEdge[19, 33] -> 
             RGBColor[
              0.974408283742176, 0.9526281060513545, 0.6410979559927938], 
             UndirectedEdge[156, 199] -> 
             RGBColor[
              0.5719863906844375, 0.5995736771478486, 0.62610544523937], 
             UndirectedEdge[47, 144] -> 
             RGBColor[
              0.9105632381516714, 0.9007982781385768, 0.6669598914895102], 
             UndirectedEdge[123, 127] -> 
             RGBColor[
              0.9877064589163046, 0.9739757790216252, 0.5905831288392512], 
             UndirectedEdge[82, 120] -> 
             RGBColor[
              0.5549317608607669, 0.5346436766026956, 0.5983945540650999], 
             UndirectedEdge[120, 137] -> 
             RGBColor[
              0.9178205087248275, 0.7118927323256862, 0.2527346562006556], 
             UndirectedEdge[122, 179] -> 
             RGBColor[
              0.9661145666467911, 0.8912538440282469, 0.4249889647560181], 
             UndirectedEdge[52, 124] -> 
             RGBColor[
              0.9945145851270563, 0.9919996542283751, 0.7405710504507068], 
             UndirectedEdge[17, 106] -> 
             RGBColor[
              0.9538381619882701, 0.8607700131312774, 0.5831490481212642], 
             UndirectedEdge[125, 166] -> 
             RGBColor[
              0.9591034467065825, 0.8646225653200164, 0.35038102713892094`], 
             UndirectedEdge[7, 79] -> 
             RGBColor[
              0.9642252081094457, 0.9715862409931105, 0.8893046683161907], 
             UndirectedEdge[49, 127] -> 
             RGBColor[
              0.9890094976397991, 0.974514619020358, 0.5689884050348284], 
             UndirectedEdge[121, 200] -> 
             RGBColor[
              0.9887600059645552, 0.9739130275887572, 0.5696780658253304], 
             UndirectedEdge[56, 193] -> 
             RGBColor[
              0.868072300512341, 0.8939272160694822, 0.773263770553787], 
             UndirectedEdge[149, 194] -> 
             RGBColor[
              0.9865645922863167, 0.9690997758695696, 0.5790678298349364], 
             UndirectedEdge[108, 133] -> 
             RGBColor[
              0.9702142211758626, 0.9751486809907031, 0.8277802390393794], 
             UndirectedEdge[41, 140] -> 
             RGBColor[
              0.9866927045485456, 0.9657267247913263, 0.4918150827890532], 
             UndirectedEdge[36, 185] -> 
             RGBColor[
              0.8960785387057231, 0.6166272351266328, 0.23477159072155668`], 
             UndirectedEdge[108, 111] -> 
             RGBColor[
              0.9763604947035561, 0.9304847630823186, 0.48475345208282056`], 
             UndirectedEdge[72, 154] -> 
             RGBColor[
              0.9382804567252565, 0.953490246198949, 0.9893592671158845], 
             UndirectedEdge[63, 110] -> 
             RGBColor[
              0.9733108851883291, 0.9211398969563309, 0.5164465062051067], 
             UndirectedEdge[15, 186] -> 
             RGBColor[
              0.962914811811953, 0.8785287270282294, 0.4247313707866849], 
             UndirectedEdge[54, 155] -> 
             RGBColor[
              0.9893206755060165, 0.9876328164592311, 0.6653480518394599], 
             UndirectedEdge[18, 108] -> 
             RGBColor[
              0.5868781972150041, 0.6483714612256151, 0.8060453384320967], 
             UndirectedEdge[44, 102] -> 
             RGBColor[
              0.993084798492412, 0.9914084007111093, 0.7642663151559584], 
             UndirectedEdge[8, 122] -> 
             RGBColor[
              0.9662997768871158, 0.8916499900046736, 0.44514795643024563`], 
             UndirectedEdge[42, 197] -> 
             RGBColor[
              0.9581251205047634, 0.8637368400255563, 0.5179460807623366], 
             UndirectedEdge[48, 147] -> 
             RGBColor[
              0.9829942562237886, 0.9545054046298131, 0.5475667875354174], 
             UndirectedEdge[34, 54] -> 
             RGBColor[
              0.9838871294006952, 0.983869493186734, 0.6874879303719684], 
             UndirectedEdge[5, 75] -> 
             RGBColor[
              0.9515534026895354, 0.8880503361561203, 0.6106134125363305], 
             UndirectedEdge[55, 115] -> 
             RGBColor[
              0.9687532560695788, 0.9367498177953626, 0.6259168182054922], 
             UndirectedEdge[49, 155] -> 
             RGBColor[
              0.9900522960503346, 0.9901543830195523, 0.8145227284859324], 
             UndirectedEdge[66, 136] -> 
             RGBColor[
              0.9396706487257536, 0.8296517034518094, 0.5922948713541147], 
             UndirectedEdge[136, 148] -> 
             RGBColor[
              0.9107621675605164, 0.807454299507582, 0.6191266553613852], 
             UndirectedEdge[130, 189] -> 
             RGBColor[
              0.9917961516221878, 0.989340316469459, 0.6740300117299101], 
             UndirectedEdge[48, 76] -> 
             RGBColor[
              0.9812853879470006, 0.9537987436814499, 0.5758871572911306], 
             UndirectedEdge[29, 141] -> 
             RGBColor[
              0.9835449879630026, 0.9551022113193848, 0.48014174853673786`], 
             UndirectedEdge[133, 163] -> 
             RGBColor[
              0.9517453214494107, 0.9142845216217916, 0.6339440142580066], 
             UndirectedEdge[111, 169] -> 
             RGBColor[
              0.9575242521143434, 0.9185944386495679, 0.6241617920287843], 
             UndirectedEdge[76, 142] -> 
             RGBColor[
              0.9812444383562559, 0.9844739286404215, 0.8692179103944633], 
             UndirectedEdge[78, 98] -> 
             RGBColor[
              0.5869460537751134, 0.6485165995463383, 0.8134311062378485], 
             UndirectedEdge[21, 170] -> 
             RGBColor[
              0.9404956273990286, 0.8112615455392607, 0.5771240673489103], 
             UndirectedEdge[92, 139] -> 
             RGBColor[
              0.9645290870633745, 0.971711902749893, 0.8842686076360662], 
             UndirectedEdge[63, 70] -> 
             RGBColor[
              0.9740114299082373, 0.9214295902011911, 0.5048366672446081], 
             UndirectedEdge[71, 197] -> 
             RGBColor[
              0.9244776918752081, 0.7382862451421678, 0.25809118202762416`], 
             UndirectedEdge[127, 141] -> 
             RGBColor[
              0.9783631348118483, 0.9386759145221346, 0.37044529383351604`], 
             UndirectedEdge[64, 138] -> 
             RGBColor[
              0.9372055352036095, 0.9505114655086961, 0.9069067024573504], 
             UndirectedEdge[39, 108] -> 
             RGBColor[
              0.9649199086861642, 0.885696968224967, 0.4725778707716948], 
             UndirectedEdge[24, 165] -> 
             RGBColor[
              0.9937481133894256, 0.9890361716397069, 0.5608989084898441], 
             UndirectedEdge[132, 182] -> 
             RGBColor[
              0.5857250168914523, 0.6459049251179534, 0.6805287768174912], 
             UndirectedEdge[77, 181] -> 
             RGBColor[
              0.922844929337884, 0.6956237925574249, 0.36008867382136567`], 
             UndirectedEdge[20, 47] -> 
             RGBColor[
              0.9207855716242805, 0.9348732201171223, 0.7413131587852317], 
             UndirectedEdge[191, 199] -> 
             RGBColor[
              0.5851097348025646, 0.6480306133277332, 0.8637354216083557], 
             UndirectedEdge[89, 154] -> 
             RGBColor[
              0.9560260313483804, 0.9354891984963225, 0.6649342330229036], 
             UndirectedEdge[93, 164] -> 
             RGBColor[
              0.9883531982549637, 0.9788346455808374, 0.6116007304901447], 
             UndirectedEdge[26, 187] -> 
             RGBColor[
              0.5565192810579456, 0.6278466100605326, 0.9635392943787455], 
             UndirectedEdge[5, 188] -> 
             RGBColor[
              0.942709819988462, 0.8814548066576974, 0.6255832912734742], 
             UndirectedEdge[7, 16] -> 
             RGBColor[
              0.9653386117636119, 0.9709097847692695, 0.7882137139265698], 
             UndirectedEdge[154, 160] -> 
             RGBColor[
              0.9641470226784119, 0.9721746957805157, 0.9184004898215217], 
             UndirectedEdge[88, 152] -> 
             RGBColor[
              0.9936016453018328, 0.9916221301491619, 0.7557008259671901], 
             UndirectedEdge[9, 18] -> 
             RGBColor[
              0.559092799573697, 0.6298068716079089, 0.9606022635678038], 
             UndirectedEdge[9, 200] -> 
             RGBColor[
              0.961383886626062, 0.9551272283101644, 0.6890701059369957], 
             UndirectedEdge[55, 183] -> 
             RGBColor[
              0.8947443922798275, 0.5564459257045808, 0.5481057374222686], 
             UndirectedEdge[72, 104] -> 
             RGBColor[
              0.9641851478688838, 0.9714696926716226, 0.8854911548099107], 
             UndirectedEdge[112, 181] -> 
             RGBColor[
              0.9873510494984105, 0.9684437374990138, 0.45217420884471343`], 
             UndirectedEdge[136, 193] -> 
             RGBColor[
              0.9521966617331052, 0.8361510469797018, 0.40923040635112107`], 
             UndirectedEdge[80, 198] -> 
             RGBColor[
              0.9937018210975146, 0.9889371571081782, 0.5558602781982496], 
             UndirectedEdge[42, 131] -> 
             RGBColor[
              0.9786625346564246, 0.9424648284426649, 0.5485118582423775], 
             UndirectedEdge[65, 156] -> 
             RGBColor[
              0.9749308661576535, 0.9270980664165314, 0.3571115782415182], 
             UndirectedEdge[26, 192] -> 
             RGBColor[
              0.9624510840824902, 0.970379456649402, 0.8979323049395151], 
             UndirectedEdge[65, 155] -> 
             RGBColor[
              0.9853737626922778, 0.9744465686362768, 0.6391635078451268], 
             UndirectedEdge[59, 62] -> 
             RGBColor[
              0.994574626392766, 0.9908039993805687, 0.6508597482564408], 
             UndirectedEdge[82, 187] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[4, 86] -> 
             RGBColor[
              0.9652212646833414, 0.8923120321478055, 0.52581549023635], 
             UndirectedEdge[73, 167] -> 
             RGBColor[
              0.9916021108750579, 0.9904295425215265, 0.7622536662815003], 
             UndirectedEdge[74, 159] -> 
             RGBColor[
              0.9704989244796929, 0.9091239395203432, 0.39966447518995096`], 
             UndirectedEdge[25, 60] -> 
             RGBColor[
              0.5770419356961763, 0.616627217570862, 0.6457452829504085], 
             UndirectedEdge[159, 162] -> 
             RGBColor[
              0.5632641561061628, 0.5676788471445738, 0.6050989948659993], 
             UndirectedEdge[10, 147] -> 
             RGBColor[
              0.9632944124601232, 0.9704392611591329, 0.871409683429196], 
             UndirectedEdge[23, 163] -> 
             RGBColor[
              0.9711176669303543, 0.9287071758206444, 0.6000227606562396], 
             UndirectedEdge[40, 54] -> 
             RGBColor[
              0.9931908730107057, 0.98784429081527, 0.5002467321551831], 
             UndirectedEdge[123, 129] -> 
             RGBColor[
              0.979107986587353, 0.9449711128387592, 0.5571796875265251], 
             UndirectedEdge[25, 165] -> 
             RGBColor[
              0.9839344394177214, 0.9573402404643, 0.4030573681183783], 
             UndirectedEdge[39, 178] -> 
             RGBColor[
              0.9407466886931577, 0.8027873962035279, 0.27118159874978287`], 
             UndirectedEdge[76, 107] -> 
             RGBColor[
              0.5847459935853674, 0.6478801969866993, 0.8697635549094066], 
             UndirectedEdge[63, 138] -> 
             RGBColor[
              0.9711112722838713, 0.9202303004928645, 0.5528997844476937], 
             UndirectedEdge[71, 81] -> 
             RGBColor[
              0.9570921773291359, 0.8649880084463282, 0.5432773258687273], 
             UndirectedEdge[8, 83] -> 
             RGBColor[
              0.9681889990179116, 0.899140126207324, 0.44666806890242683`], 
             UndirectedEdge[10, 149] -> 
             RGBColor[
              0.9567381188748567, 0.9481157132589026, 0.6868092593721817], 
             UndirectedEdge[119, 172] -> 
             RGBColor[
              0.5591011441414154, 0.5511738919458515, 0.6017493377207137], 
             UndirectedEdge[106, 130] -> 
             RGBColor[
              0.9889230934461768, 0.9881522330794512, 0.7216440209426288], 
             UndirectedEdge[147, 176] -> 
             RGBColor[
              0.9775586042068539, 0.9361696740249054, 0.5264503058863783], 
             UndirectedEdge[27, 197] -> 
             RGBColor[
              0.5514660392215651, 0.520903245186535, 0.5956059530832557], 
             UndirectedEdge[72, 176] -> 
             RGBColor[
              0.9486228662041546, 0.9162160429267282, 0.6482732068043383], 
             UndirectedEdge[92, 118] -> 
             RGBColor[
              0.939712316476861, 0.9545581248572403, 0.9869355020452513], 
             UndirectedEdge[123, 171] -> 
             RGBColor[
              0.9907073623219067, 0.9904252697572826, 0.8036665851088154], 
             UndirectedEdge[66, 113] -> 
             RGBColor[
              0.948846888571469, 0.8660324366394114, 0.5996782893280099], 
             UndirectedEdge[67, 179] -> 
             RGBColor[
              0.9939014276636943, 0.9905803009206553, 0.6659915257181701], 
             UndirectedEdge[130, 197] -> 
             RGBColor[
              0.9587537632259399, 0.8624616043020452, 0.3959353270203688], 
             UndirectedEdge[15, 194] -> 
             RGBColor[
              0.9931162918272224, 0.9902926293500203, 0.6816929331582182], 
             UndirectedEdge[47, 135] -> 
             RGBColor[
              0.8486728718749834, 0.6295618548530553, 0.5899496045679735], 
             UndirectedEdge[8, 170] -> 
             RGBColor[
              0.9469363038681538, 0.8135392685010197, 0.429498282799607], 
             UndirectedEdge[17, 149] -> 
             RGBColor[
              0.9521013608233568, 0.8404394492021688, 0.3186771622124278], 
             UndirectedEdge[13, 97] -> 
             RGBColor[
              0.9937708159227782, 0.9901813446291916, 0.6430822416539167], 
             UndirectedEdge[11, 86] -> 
             RGBColor[
              0.966582656053425, 0.892389637798003, 0.46797282450919064`], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.994461839555383, 0.9905627597399054, 0.6385835970469959], 
             UndirectedEdge[37, 160] -> 
             RGBColor[
              0.9138121874889984, 0.9321615710916138, 0.9178468886317113], 
             UndirectedEdge[46, 50] -> 
             RGBColor[
              0.9942047542133566, 0.9900128801886261, 0.6106014441142407], 
             UndirectedEdge[49, 53] -> 
             RGBColor[
              0.9945958295854327, 0.9918060550599201, 0.7227098803633591], 
             UndirectedEdge[52, 120] -> 
             RGBColor[
              0.9627750036190303, 0.8779669526432182, 0.501110061590687], 
             UndirectedEdge[81, 147] -> 
             RGBColor[
              0.9916083865376484, 0.990797866425758, 0.7887342820780524], 
             UndirectedEdge[49, 123] -> 
             RGBColor[
              0.9928699789390513, 0.9913195673051839, 0.7678264310903304], 
             UndirectedEdge[127, 140] -> 
             RGBColor[
              0.9815161387018945, 0.9493117370037795, 0.38269411855152197`], 
             UndirectedEdge[31, 132] -> 
             RGBColor[
              0.9933526756812067, 0.988190370366712, 0.5178579543088707], 
             UndirectedEdge[146, 186] -> 
             RGBColor[
              0.9493365518888276, 0.8336336354637164, 0.29480940723306714`], 
             UndirectedEdge[98, 124] -> 
             RGBColor[
              0.5866713423687928, 0.6486763781878524, 0.8378555429251195], 
             UndirectedEdge[4, 53] -> 
             RGBColor[
              0.9935076194208012, 0.9913560521911194, 0.7407443389889343], 
             UndirectedEdge[82, 137] -> 
             RGBColor[
              0.5418157478640606, 0.4826430557229906, 0.5878411021355557], 
             UndirectedEdge[42, 107] -> 
             RGBColor[
              0.5855860812831982, 0.6482275948390214, 0.8558411276790809], 
             UndirectedEdge[99, 102] -> 
             RGBColor[
              0.5864762528772485, 0.6485957036695276, 0.841088680675429], 
             UndirectedEdge[57, 88] -> 
             RGBColor[
              0.9938616653247561, 0.9902357519417258, 0.6428006313253187], 
             UndirectedEdge[40, 49] -> 
             RGBColor[
              0.9939224935550239, 0.9903658573755914, 0.6494214088016557], 
             UndirectedEdge[21, 90] -> 
             RGBColor[
              0.9883191198710986, 0.9889223362128685, 0.8186401388500752], 
             UndirectedEdge[143, 158] -> 
             RGBColor[
              0.9477105267206731, 0.8165153817325629, 0.45440288660251554`], 
             UndirectedEdge[24, 111] -> 
             RGBColor[
              0.9763379071564325, 0.9304364506029725, 0.4822949369725982], 
             UndirectedEdge[139, 155] -> 
             RGBColor[
              0.9891383457943417, 0.989776441101249, 0.8296692494551803], 
             UndirectedEdge[94, 174] -> 
             RGBColor[
              0.9393768674379286, 0.9501028252057642, 0.7759502985364107], 
             UndirectedEdge[4, 118] -> 
             RGBColor[
              0.9673540866554078, 0.9738766846241599, 0.8820795812899159], 
             UndirectedEdge[121, 159] -> 
             RGBColor[
              0.9708060750183529, 0.9108775180310755, 0.5128082183221379], 
             UndirectedEdge[5, 76] -> 
             RGBColor[
              0.9659454519673967, 0.897725118230868, 0.5388368845353366], 
             UndirectedEdge[27, 194] -> 
             RGBColor[
              0.5855930240094278, 0.6482304658347373, 0.8557260687382573], 
             UndirectedEdge[77, 160] -> 
             RGBColor[
              0.9200696111297259, 0.6961040029177792, 0.5244122619803416], 
             UndirectedEdge[2, 80] -> 
             RGBColor[
              0.9902898313598663, 0.9782112555566573, 0.47597867088220136`], 
             UndirectedEdge[74, 85] -> 
             RGBColor[
              0.9581822512946223, 0.9648489018444064, 0.7575733316224011], 
             UndirectedEdge[35, 110] -> 
             RGBColor[
              0.9826894810059601, 0.9537121288897286, 0.5480057404236786], 
             UndirectedEdge[143, 154] -> 
             RGBColor[
              0.9675999618316743, 0.9731438481037524, 0.8278317597454163], 
             UndirectedEdge[53, 129] -> 
             RGBColor[
              0.9808338372337344, 0.9454576005934956, 0.512063136799554], 
             UndirectedEdge[80, 187] -> 
             RGBColor[
              0.5862790336057773, 0.6470899108502123, 0.7408300771769281], 
             UndirectedEdge[30, 87] -> 
             RGBColor[
              0.9757230424339749, 0.980225713252056, 0.8727260771917856], 
             UndirectedEdge[29, 197] -> 
             RGBColor[
              0.9591073811812456, 0.8632179573521848, 0.43442445917835215`], 
             UndirectedEdge[74, 121] -> 
             RGBColor[
              0.9937036872857202, 0.990037763262271, 0.6357757037800902], 
             UndirectedEdge[127, 199] -> 
             RGBColor[
              0.5813864888085262, 0.6312824153683996, 0.6626230513918747], 
             UndirectedEdge[52, 80] -> 
             RGBColor[
              0.9941222763640407, 0.9904131868907349, 0.6435455847025153], 
             UndirectedEdge[125, 187] -> 
             RGBColor[
              0.5857904737211994, 0.6460449306580818, 0.6876533487827371], 
             UndirectedEdge[57, 152] -> 
             RGBColor[
              0.9932902929640431, 0.9899994747869711, 0.6522697500066013], 
             UndirectedEdge[128, 193] -> 
             RGBColor[
              0.985447236953586, 0.9858246172011961, 0.7476570189668453], 
             UndirectedEdge[151, 172] -> 
             RGBColor[
              0.5258404329447487, 0.41024042437071795`, 0.5745180227105423], 
             UndirectedEdge[5, 27] -> 
             RGBColor[
              0.5601264583820292, 0.5552389212441687, 0.60257432962593], 
             UndirectedEdge[65, 118] -> 
             RGBColor[
              0.9637637634619824, 0.9586188731096851, 0.6886859020235352], 
             UndirectedEdge[78, 80] -> 
             RGBColor[
              0.9942980873808906, 0.9902125103965507, 0.6207601834147767], 
             UndirectedEdge[40, 199] -> 
             RGBColor[
              0.586299484723751, 0.647133653723633, 0.7430560551587019], 
             UndirectedEdge[5, 42] -> 
             RGBColor[
              0.9667855396652274, 0.89807251608319, 0.5249144573050109], 
             UndirectedEdge[123, 196] -> 
             RGBColor[
              0.976328384370774, 0.9355948618806009, 0.5463814577989494], 
             UndirectedEdge[80, 124] -> 
             RGBColor[
              0.99402337597457, 0.9903722890380647, 0.6451846201020477], 
             UndirectedEdge[22, 48] -> 
             RGBColor[
              0.9824482884860624, 0.9522167666212015, 0.4066662812500079], 
             UndirectedEdge[69, 86] -> 
             RGBColor[
              0.948168763505252, 0.8316431332213516, 0.28012379161854495`], 
             UndirectedEdge[81, 143] -> 
             RGBColor[
              0.9919921536413667, 0.9904978372323843, 0.7490296756255443], 
             UndirectedEdge[80, 116] -> 
             RGBColor[
              0.9935915269001627, 0.9901937083477823, 0.6523414768545563], 
             UndirectedEdge[90, 169] -> 
             RGBColor[
              0.9761877188623851, 0.979874757203916, 0.8391754363817037], 
             UndirectedEdge[121, 173] -> 
             RGBColor[
              0.9931349429216179, 0.9914291367212389, 0.7634352921943958], 
             UndirectedEdge[8, 179] -> 
             RGBColor[
              0.9941158539669355, 0.9898227315507251, 0.6009252009200298], 
             UndirectedEdge[29, 167] -> 
             RGBColor[
              0.994533871146924, 0.9907168280307005, 0.6464237912587786], 
             UndirectedEdge[76, 87] -> 
             RGBColor[
              0.9909573376833669, 0.9905286409933202, 0.7995238464539209], 
             UndirectedEdge[111, 163] -> 
             RGBColor[
              0.9578915949771041, 0.8696206037134071, 0.29091722730144787`], 
             UndirectedEdge[130, 149] -> 
             RGBColor[
              0.9871862922812635, 0.9678216691503426, 0.4571721350337923], 
             UndirectedEdge[7, 122] -> 
             RGBColor[
              0.9375057732715804, 0.8727011922573358, 0.6306120931569813], 
             UndirectedEdge[89, 142] -> 
             RGBColor[
              0.9717631432534684, 0.9472259107879812, 0.638295407463729], 
             UndirectedEdge[44, 172] -> 
             RGBColor[
              0.5855355456151636, 0.6482066970415816, 0.8566786344805295], 
             UndirectedEdge[7, 179] -> 
             RGBColor[
              0.9653218503514001, 0.9708739338033873, 0.7863893376467654], 
             UndirectedEdge[73, 188] -> 
             RGBColor[
              0.9662199432942471, 0.9736373120700045, 0.9111583427653625], 
             UndirectedEdge[16, 120] -> 
             RGBColor[
              0.9624503441362842, 0.876695820355727, 0.42385153496780525`], 
             UndirectedEdge[98, 116] -> 
             RGBColor[
              0.5862394932943855, 0.6484977974975701, 0.8450123996776282], 
             UndirectedEdge[5, 81] -> 
             RGBColor[
              0.9652799830575223, 0.897449929734864, 0.5498654265502889], 
             UndirectedEdge[76, 106] -> 
             RGBColor[
              0.9874543630271696, 0.9890800709506402, 0.8575772019149224], 
             UndirectedEdge[135, 144] -> 
             RGBColor[
              0.91082806122046, 0.6483985680238235, 0.27150638490790086`], 
             UndirectedEdge[194, 197] -> 
             RGBColor[
              0.9581320632309929, 0.8637397110212722, 0.517831021821513], 
             UndirectedEdge[27, 29] -> 
             RGBColor[
              0.5865683419596806, 0.6477087121656497, 0.7723195060950965], 
             UndirectedEdge[44, 58] -> 
             RGBColor[
              0.9932555497173479, 0.9906896595760845, 0.7040590293406921], 
             UndirectedEdge[53, 92] -> 
             RGBColor[
              0.9658658492422545, 0.9720374924241999, 0.8456002597442698], 
             UndirectedEdge[83, 122] -> 
             RGBColor[
              0.940187711697767, 0.8005712386848458, 0.27073183273841517`], 
             UndirectedEdge[9, 178] -> 
             RGBColor[
              0.9428707767956945, 0.8898747608120848, 0.6317503299779883], 
             UndirectedEdge[12, 99] -> 
             RGBColor[
              0.5777131757305913, 0.6188914678215988, 0.6483529237310663], 
             UndirectedEdge[7, 126] -> 
             RGBColor[
              0.9407452275264602, 0.8855445488937967, 0.633218634090222], 
             UndirectedEdge[139, 146] -> 
             RGBColor[
              0.979581066469949, 0.9454153336844249, 0.5510577754785451], 
             UndirectedEdge[100, 198] -> 
             RGBColor[
              0.9870295533768229, 0.9869534003523712, 0.7409076705232471], 
             UndirectedEdge[56, 109] -> 
             RGBColor[
              0.8323850569004562, 0.764470864067209, 0.6157130861284075], 
             UndirectedEdge[9, 159] -> 
             RGBColor[
              0.9434299556798598, 0.8920917187524828, 0.632200258433803], 
             UndirectedEdge[2, 98] -> 
             RGBColor[
              0.5829377977540889, 0.636515344706445, 0.6686495937052732], 
             UndirectedEdge[95, 164] -> 
             RGBColor[
              0.9134050335022423, 0.6379190657090541, 0.5012589356897492], 
             UndirectedEdge[108, 163] -> 
             RGBColor[
              0.9763604947035561, 0.9304847630823186, 0.48475345208282056`], 
             UndirectedEdge[85, 121] -> 
             RGBColor[
              0.9584894018332824, 0.9666024803551387, 0.870717074754588], 
             UndirectedEdge[55, 177] -> 
             RGBColor[
              0.9778720608029583, 0.9675096873582225, 0.6613416526528912], 
             UndirectedEdge[118, 141] -> 
             RGBColor[
              0.9577959339920885, 0.9384879829947373, 0.6655020114630283], 
             UndirectedEdge[58, 77] -> 
             RGBColor[
              0.9233309254192987, 0.6966632890338298, 0.4129863480632136], 
             UndirectedEdge[142, 154] -> 
             RGBColor[
              0.956186777636689, 0.9668447510157856, 0.9590485365292877], 
             UndirectedEdge[103, 178] -> 
             RGBColor[
              0.5627049772219976, 0.5654618892041758, 0.6046490664101847], 
             UndirectedEdge[48, 154] -> 
             RGBColor[
              0.9562277272274338, 0.936169566056814, 0.6657177834259551], 
             UndirectedEdge[72, 181] -> 
             RGBColor[
              0.9647531318802256, 0.9700766928949833, 0.7577488066899681], 
             UndirectedEdge[45, 132] -> 
             RGBColor[
              0.9806978006365471, 0.9465389263454547, 0.3805663927835546], 
             UndirectedEdge[103, 200] -> 
             RGBColor[
              0.5812180870523651, 0.6307143567022555, 0.661968842369192], 
             UndirectedEdge[21, 61] -> 
             RGBColor[
              0.9091007857216078, 0.9291772946703888, 0.9503149782959532], 
             UndirectedEdge[51, 73] -> 
             RGBColor[
              0.9916117376057791, 0.9904501331251274, 0.7633014765112089], 
             UndirectedEdge[18, 41] -> 
             RGBColor[
              0.5865630546551774, 0.6476974031559464, 0.771744015629406], 
             UndirectedEdge[27, 42] -> 
             RGBColor[
              0.5855860812831981, 0.6482275948390213, 0.8558411276790809], 
             UndirectedEdge[90, 165] -> 
             RGBColor[
              0.9939652679581388, 0.9895006433044895, 0.5845348431716131], 
             UndirectedEdge[50, 135] -> 
             RGBColor[
              0.9211035591065995, 0.6825872233071637, 0.35164627052367464`], 
             UndirectedEdge[93, 121] -> 
             RGBColor[
              0.9904797166662791, 0.9797140155929467, 0.5763588171614118], 
             UndirectedEdge[23, 175] -> 
             RGBColor[
              0.9888048018502418, 0.987899219316861, 0.7087687107361993], 
             UndirectedEdge[57, 164] -> 
             RGBColor[
              0.9916540569943579, 0.9893228491641599, 0.6793864144672364], 
             UndirectedEdge[54, 172] -> 
             RGBColor[
              0.5858183882869548, 0.646104637091637, 0.6906916769964813], 
             UndirectedEdge[99, 198] -> 
             RGBColor[
              0.5863497874917374, 0.6472412462579658, 0.7485312010213215], 
             UndirectedEdge[45, 112] -> 
             RGBColor[
              0.9750898252227358, 0.9276342726684174, 0.3577291041924622], 
             UndirectedEdge[88, 173] -> 
             RGBColor[
              0.9932160328407006, 0.9914626694866955, 0.762091422381211], 
             UndirectedEdge[14, 22] -> 
             RGBColor[
              0.980878330704288, 0.9469209303796593, 0.4005672917294644], 
             UndirectedEdge[7, 67] -> 
             RGBColor[
              0.9652926342884836, 0.9720276491497442, 0.8716146541191334], 
             UndirectedEdge[105, 135] -> 
             RGBColor[
              0.9211672617253839, 0.6827234767674208, 0.3585799074513678], 
             UndirectedEdge[104, 176] -> 
             RGBColor[
              0.9766967663541263, 0.9358132819245799, 0.5407331894709421], 
             UndirectedEdge[57, 91] -> 
             RGBColor[
              0.9912216992030676, 0.9891440581063728, 0.6865517019750128], 
             UndirectedEdge[34, 185] -> 
             RGBColor[
              0.9239091740584892, 0.7480052804658149, 0.5713142760860295], 
             UndirectedEdge[65, 172] -> 
             RGBColor[
              0.581871475473216, 0.6329183892686827, 0.6645071330021481], 
             UndirectedEdge[66, 120] -> 
             RGBColor[
              0.9498653638766656, 0.8700703518377397, 0.6004977784652592], 
             UndirectedEdge[91, 117] -> 
             RGBColor[
              0.9909614621914045, 0.9885874374524233, 0.6582265092521431], 
             UndirectedEdge[27, 141] -> 
             RGBColor[
              0.5759036460033222, 0.612787499153735, 0.6413232424416414], 
             UndirectedEdge[13, 145] -> 
             RGBColor[
              0.9550649457770974, 0.8484691860098652, 0.5001425362428318], 
             UndirectedEdge[1, 174] -> 
             RGBColor[
              0.5863472481814527, 0.6472358149300306, 0.7482548127676364], 
             UndirectedEdge[182, 196] -> 
             RGBColor[
              0.5700084142629955, 0.5929014982273755, 0.6184213803515728], 
             UndirectedEdge[96, 137] -> 
             RGBColor[
              0.9456918594042252, 0.8243258210542075, 0.5563022405515283], 
             UndirectedEdge[89, 157] -> 
             RGBColor[
              0.9829392870129752, 0.953018002352924, 0.48127824212202963`], 
             UndirectedEdge[119, 191] -> 
             RGBColor[
              0.9652838789439799, 0.8938105052735847, 0.5319837593290695], 
             UndirectedEdge[51, 157] -> 
             RGBColor[
              0.9945767444483601, 0.9908085296873165, 0.651090285536748], 
             UndirectedEdge[127, 195] -> 
             RGBColor[
              0.9327889906357014, 0.9328520063729349, 0.6901633412476974], 
             UndirectedEdge[27, 62] -> 
             RGBColor[
              0.5869385717375883, 0.6485005962246224, 0.8126167326270348], 
             UndirectedEdge[4, 40] -> 
             RGBColor[
              0.9928342833903924, 0.9899158545067905, 0.6674558674272308], 
             UndirectedEdge[161, 164] -> 
             RGBColor[
              0.9676951288448815, 0.9745029787410815, 0.8981587612286852], 
             UndirectedEdge[20, 101] -> 
             RGBColor[
              0.5860450472211831, 0.646589437633218, 0.7153621032104402], 
             UndirectedEdge[13, 36] -> 
             RGBColor[
              0.9567070246731645, 0.8549794816424166, 0.5014637914671529], 
             UndirectedEdge[182, 195] -> 
             RGBColor[
              0.5303295018271752, 0.6069635910045352, 0.9610412898558227], 
             UndirectedEdge[184, 186] -> 
             RGBColor[
              0.9589862793797709, 0.8780329725732186, 0.5718887758417723], 
             UndirectedEdge[96, 166] -> 
             RGBColor[
              0.9561160845255479, 0.8656543999931514, 0.5646898167721565], 
             UndirectedEdge[38, 43] -> 
             RGBColor[
              0.9707805854969599, 0.9097263839559802, 0.43032153870916223`], 
             UndirectedEdge[30, 176] -> 
             RGBColor[
              0.960615440680674, 0.9251600853352778, 0.6279729063799562], 
             UndirectedEdge[171, 174] -> 
             RGBColor[
              0.991807640395581, 0.9895737210340876, 0.6904603204290751], 
             UndirectedEdge[100, 125] -> 
             RGBColor[
              0.9864702396062848, 0.9857570847524871, 0.6800298182846626], 
             UndirectedEdge[17, 188] -> 
             RGBColor[
              0.9337131541529007, 0.8457860245808652, 0.6183443627632927], 
             UndirectedEdge[87, 107] -> 
             RGBColor[
              0.5851383440979996, 0.6480424440066209, 0.8632612915445144], 
             UndirectedEdge[62, 184] -> 
             RGBColor[
              0.9905333071232009, 0.9900670052848946, 0.7857410021020834], 
             UndirectedEdge[12, 33] -> 
             RGBColor[
              0.9755515138852184, 0.9564844897670393, 0.6455391892176163], 
             UndirectedEdge[32, 57] -> 
             RGBColor[
              0.9492862798079602, 0.9578586430698752, 0.7650862896213693], 
             UndirectedEdge[17, 87] -> 
             RGBColor[
              0.9573411366444675, 0.8622185831739574, 0.525095692660263], 
             UndirectedEdge[42, 149] -> 
             RGBColor[
              0.9865576495600872, 0.9690969048738537, 0.5791828887757601], 
             UndirectedEdge[87, 130] -> 
             RGBColor[
              0.9924260681023742, 0.9896008031221312, 0.6635906654816275], 
             UndirectedEdge[58, 170] -> 
             RGBColor[
              0.9469692758667079, 0.8136097922719465, 0.43308708136264096`], 
             UndirectedEdge[118, 196] -> 
             RGBColor[
              0.9519007022517619, 0.9186019820683777, 0.6426001493729597], 
             UndirectedEdge[41, 159] -> 
             RGBColor[
              0.9709002107613403, 0.9099822503005203, 0.4433420104954052], 
             UndirectedEdge[107, 157] -> 
             RGBColor[
              0.5866015885303952, 0.6477798232186649, 0.7759381901433572], 
             UndirectedEdge[161, 173] -> 
             RGBColor[
              0.9689457523534345, 0.9750201437014263, 0.8774326931820708], 
             UndirectedEdge[15, 184] -> 
             RGBColor[
              0.9900450032034072, 0.9890225725755553, 0.7325921338950094], 
             UndirectedEdge[106, 142] -> 
             RGBColor[
              0.9781338142126906, 0.9831876056176632, 0.9207690024905724], 
             UndirectedEdge[24, 39] -> 
             RGBColor[
              0.9648973211390406, 0.8856486557456209, 0.47011935566147245`], 
             UndirectedEdge[45, 134] -> 
             RGBColor[
              0.9791270253257482, 0.941252696595541, 0.37341286423139786`], 
             UndirectedEdge[5, 73] -> 
             RGBColor[
              0.9648360400698436, 0.8972663479006445, 0.5572227107437482], 
             UndirectedEdge[147, 154] -> 
             RGBColor[
              0.9672161947279558, 0.9734438772971261, 0.8675363661979245], 
             UndirectedEdge[76, 143] -> 
             RGBColor[
              0.9926576225512411, 0.9907730257283882, 0.7380011336105919], 
             UndirectedEdge[5, 197] -> 
             RGBColor[
              0.9326654976035944, 0.7707481664307037, 0.2646792827091857], 
             UndirectedEdge[152, 159] -> 
             RGBColor[
              0.9703157925767227, 0.9106747736417775, 0.5209334671902357], 
             UndirectedEdge[108, 115] -> 
             RGBColor[
              0.9800830610047554, 0.9430418533163968, 0.49921491921532], 
             UndirectedEdge[65, 123] -> 
             RGBColor[
              0.9881914455809945, 0.9756117529219084, 0.5924672104495248], 
             UndirectedEdge[8, 67] -> 
             RGBColor[
              0.994086637904019, 0.9909764468970821, 0.6861505173923976], 
             UndirectedEdge[9, 41] -> 
             RGBColor[
              0.9667288542288744, 0.9721102747638553, 0.7988452791972096], 
             UndirectedEdge[111, 165] -> 
             RGBColor[
              0.9753018012100971, 0.9282203247501415, 0.3695211988186938], 
             UndirectedEdge[146, 195] -> 
             RGBColor[
              0.9242745097218443, 0.9041306629553052, 0.6570861907221661], 
             UndirectedEdge[104, 188] -> 
             RGBColor[
              0.9681763856158605, 0.974446351248266, 0.8787350303858015], 
             UndirectedEdge[37, 105] -> 
             RGBColor[
              0.916588411929885, 0.9316832990714313, 0.7536219383126064], 
             UndirectedEdge[3, 75] -> 
             RGBColor[
              0.9775787274506136, 0.9796291498895086, 0.7350187325245479], 
             UndirectedEdge[40, 132] -> 
             RGBColor[
              0.9930975016152033, 0.9876445788415864, 0.4900838319761931], 
             UndirectedEdge[154, 157] -> 
             RGBColor[
              0.9673629213961958, 0.9726368425807284, 0.8020313711875882], 
             UndirectedEdge[116, 148] -> 
             RGBColor[
              0.9522646151450471, 0.9617270687883868, 0.8739474080850581], 
             UndirectedEdge[132, 185] -> 
             RGBColor[
              0.932638449836201, 0.7507513494886713, 0.32154579952803347`], 
             UndirectedEdge[92, 123] -> 
             RGBColor[
              0.9641399985958731, 0.9715510046694636, 0.890716810471241], 
             UndirectedEdge[53, 139] -> 
             RGBColor[
              0.9936818793294397, 0.9914281131416168, 0.7378564013326072], 
             UndirectedEdge[40, 196] -> 
             RGBColor[
              0.9773808989867465, 0.9346411519510084, 0.42797643551027464`], 
             UndirectedEdge[27, 73] -> 
             RGBColor[
              0.5836365816878144, 0.6474214266564757, 0.8881493811178183], 
             UndirectedEdge[57, 103] -> 
             RGBColor[
              0.5862386564934832, 0.6470035482897675, 0.7364352776823649], 
             UndirectedEdge[44, 77] -> 
             RGBColor[
              0.9222194669322781, 0.6969930235409086, 0.4887835876835805], 
             UndirectedEdge[88, 91] -> 
             RGBColor[
              0.9915330515408574, 0.9907667134685638, 0.7899827779356017], 
             UndirectedEdge[69, 146] -> 
             RGBColor[
              0.9623543053832212, 0.8846743738074735, 0.30825401451706724`], 
             UndirectedEdge[65, 199] -> 
             RGBColor[
              0.581871475473216, 0.6329183892686827, 0.6645071330021481], 
             UndirectedEdge[27, 75] -> 
             RGBColor[
              0.5703539443075061, 0.6382054149119516, 0.9415400829104005], 
             UndirectedEdge[4, 65] -> 
             RGBColor[
              0.9884062741398574, 0.9757005900518403, 0.5889069452706772], 
             UndirectedEdge[58, 102] -> 
             RGBColor[
              0.9941962569794327, 0.9910786662040305, 0.6884690755355916], 
             UndirectedEdge[107, 168] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[9, 85] -> 
             RGBColor[
              0.9311132824947892, 0.947816681076546, 0.9901091148662533], 
             UndirectedEdge[22, 144] -> 
             RGBColor[
              0.9828046078730032, 0.9534187155811233, 0.4080505147830027], 
             UndirectedEdge[110, 138] -> 
             RGBColor[
              0.991624444798725, 0.9908045069293916, 0.7884681551345649], 
             UndirectedEdge[34, 132] -> 
             RGBColor[
              0.9837937580051928, 0.9836697812130504, 0.6773250301929784], 
             UndirectedEdge[48, 158] -> 
             RGBColor[
              0.9363382921164325, 0.7795410996856245, 0.29228891028305415`], 
             UndirectedEdge[19, 95] -> 
             RGBColor[
              0.9056325785889165, 0.6052408489405756, 0.26871848941112153`], 
             UndirectedEdge[122, 137] -> 
             RGBColor[
              0.9215014926475462, 0.7264866069640883, 0.2556964622686727], 
             UndirectedEdge[8, 198] -> 
             RGBColor[
              0.9940368195953675, 0.9896536850215417, 0.5923227973184502], 
             UndirectedEdge[92, 174] -> 
             RGBColor[
              0.9652402766695474, 0.9706994559462685, 0.7775105457915008], 
             UndirectedEdge[39, 133] -> 
             RGBColor[
              0.9403047354320186, 0.86949672676444, 0.6217684329468809], 
             UndirectedEdge[120, 198] -> 
             RGBColor[
              0.9623545483525042, 0.8764909228606614, 0.41342475508642135`], 
             UndirectedEdge[4, 34] -> 
             RGBColor[
              0.9835305397803817, 0.9859410568782545, 0.8546970656440162], 
             UndirectedEdge[31, 34] -> 
             RGBColor[
              0.9846233999034948, 0.9854443013438556, 0.7676264308668668], 
             UndirectedEdge[41, 152] -> 
             RGBColor[
              0.9936146911257375, 0.99069332965315, 0.6875784879536422], 
             UndirectedEdge[95, 121] -> 
             RGBColor[
              0.9155315519135578, 0.6387984357211633, 0.4660170223610163], 
             UndirectedEdge[3, 129] -> 
             RGBColor[
              0.9800127996226821, 0.9437014841630906, 0.4226982596932959], 
             UndirectedEdge[49, 199] -> 
             RGBColor[
              0.5865500088312728, 0.6486262036519583, 0.8398663536429538], 
             UndirectedEdge[171, 182] -> 
             RGBColor[
              0.5843873922141283, 0.6477319061040571, 0.8757065076614388], 
             UndirectedEdge[56, 150] -> 
             RGBColor[
              0.8266378063397521, 0.8652304685973623, 0.9831600195640512], 
             UndirectedEdge[179, 183] -> 
             RGBColor[
              0.9056248218633054, 0.5617767927871492, 0.3724921046229011], 
             UndirectedEdge[31, 156] -> 
             RGBColor[
              0.9796140494741918, 0.9418591223966073, 0.46343462273074953`], 
             UndirectedEdge[132, 153] -> 
             RGBColor[
              0.993636645857326, 0.9887977538596423, 0.5487663555186766], 
             UndirectedEdge[78, 136] -> 
             RGBColor[
              0.9527560994849682, 0.8373476277631036, 0.47012175319180394`], 
             UndirectedEdge[27, 167] -> 
             RGBColor[
              0.5868925291872436, 0.6484021158650506, 0.8076052851636821], 
             UndirectedEdge[35, 174] -> 
             RGBColor[
              0.9826612003358213, 0.95239389212333, 0.45350261474532594`], 
             UndirectedEdge[61, 190] -> 
             RGBColor[
              0.9006525194832047, 0.9228765915425541, 0.9646156893768423], 
             UndirectedEdge[18, 103] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[146, 155] -> 
             RGBColor[
              0.9763742951137309, 0.944089251318364, 0.604202275709322], 
             UndirectedEdge[77, 166] -> 
             RGBColor[
              0.8889238943024976, 0.5727579611612615, 0.22833363155923486`], 
             UndirectedEdge[85, 159] -> 
             RGBColor[
              0.9352846390272549, 0.885688656613211, 0.6346058461644489], 
             UndirectedEdge[39, 88] -> 
             RGBColor[
              0.964591720302433, 0.8859517106513102, 0.506398885982552], 
             UndirectedEdge[66, 80] -> 
             RGBColor[
              0.981212636621676, 0.9825165860852565, 0.7429333015770875], 
             UndirectedEdge[62, 141] -> 
             RGBColor[
              0.9839152177409105, 0.9558940953783573, 0.5204389750686762], 
             UndirectedEdge[91, 103] -> 
             RGBColor[
              0.5839100427095845, 0.6475345098166054, 0.8836174242926479], 
             UndirectedEdge[149, 189] -> 
             RGBColor[
              0.985479995894702, 0.968651267388781, 0.5970423988894762], 
             UndirectedEdge[4, 69] -> 
             RGBColor[
              0.9749440961551934, 0.9302895026398611, 0.5366089259192529], 
             UndirectedEdge[23, 169] -> 
             RGBColor[
              0.9707503240675937, 0.9776810107568054, 0.9332673253835762], 
             UndirectedEdge[32, 152] -> 
             RGBColor[
              0.9490262597850371, 0.9592450212773114, 0.8779864842632406], 
             UndirectedEdge[100, 124] -> 
             RGBColor[
              0.9873511082538782, 0.9883885322822579, 0.830232012427045], 
             UndirectedEdge[129, 139] -> 
             RGBColor[
              0.9794970750548544, 0.9451320109191886, 0.5507314846913504], 
             UndirectedEdge[29, 73] -> 
             RGBColor[
              0.9912779236474948, 0.9897361388221256, 0.7269678872129146], 
             UndirectedEdge[32, 178] -> 
             RGBColor[
              0.9257526005364747, 0.8763169839842837, 0.6333000783491889], 
             UndirectedEdge[8, 61] -> 
             RGBColor[
              0.9155414621907328, 0.9314550176321478, 0.8026891937466499], 
             UndirectedEdge[10, 27] -> 
             RGBColor[
              0.5557665505979678, 0.6272464032240703, 0.9634674982755025], 
             UndirectedEdge[72, 160] -> 
             RGBColor[
              0.9619778136720674, 0.9705569032553378, 0.9220723948489441], 
             UndirectedEdge[72, 144] -> 
             RGBColor[
              0.95441483760803, 0.935753722491558, 0.6707739219863722], 
             UndirectedEdge[134, 135] -> 
             RGBColor[
              0.9191595890525392, 0.6765027677371906, 0.30387279725851657`], 
             UndirectedEdge[95, 150] -> 
             RGBColor[
              0.8740147548520293, 0.6088290361254782, 0.5872428073123077], 
             UndirectedEdge[68, 71] -> 
             RGBColor[
              0.9555318993395558, 0.8524898468634667, 0.3295127155976805], 
             UndirectedEdge[118, 123] -> 
             RGBColor[
              0.9671392580965448, 0.9737878474942279, 0.8856398464687636], 
             UndirectedEdge[89, 168] -> 
             RGBColor[
              0.5752646984825799, 0.610632179134259, 0.6388410519786725], 
             UndirectedEdge[44, 99] -> 
             RGBColor[
              0.5855355456151636, 0.6482066970415816, 0.8566786344805295], 
             UndirectedEdge[121, 180] -> 
             RGBColor[
              0.9941049735673676, 0.9908960740424482, 0.6794532390855444], 
             UndirectedEdge[10, 141] -> 
             RGBColor[
              0.9527431966012899, 0.9346399023778054, 0.6712897407171439], 
             UndirectedEdge[6, 170] -> 
             RGBColor[
              0.9470737835947434, 0.8138333237348621, 0.44446210261235614`], 
             UndirectedEdge[12, 77] -> 
             RGBColor[
              0.9143970970477058, 0.6676777943209258, 0.2804578769341173], 
             UndirectedEdge[112, 143] -> 
             RGBColor[
              0.9880286704435147, 0.969893100182605, 0.5259290669275841], 
             UndirectedEdge[67, 125] -> 
             RGBColor[
              0.9932630795215882, 0.9892149387915878, 0.5965112698780061], 
             UndirectedEdge[3, 10] -> 
             RGBColor[
              0.9629913337410753, 0.9686701382016273, 0.7569461478896498], 
             UndirectedEdge[124, 125] -> 
             RGBColor[
              0.9935348160899922, 0.9893273088459342, 0.5920078917078566], 
             UndirectedEdge[11, 174] -> 
             RGBColor[
              0.9942434382181777, 0.9900956213633854, 0.614811959309006], 
             UndirectedEdge[71, 87] -> 
             RGBColor[
              0.9581499967516425, 0.8654254439622537, 0.5257465204888828], 
             UndirectedEdge[7, 192] -> 
             RGBColor[
              0.9637518315126393, 0.9713904876051075, 0.897149743584634], 
             UndirectedEdge[56, 148] -> 
             RGBColor[
              0.8266378063397521, 0.8652304685973623, 0.9831600195640512], 
             UndirectedEdge[30, 71] -> 
             RGBColor[
              0.9425233509896183, 0.8549602692010678, 0.6054510145916397], 
             UndirectedEdge[35, 86] -> 
             RGBColor[
              0.9550004181710686, 0.8546879085579475, 0.3066634799455106], 
             UndirectedEdge[68, 127] -> 
             RGBColor[
              0.9849797354944392, 0.9609952622762336, 0.3961495380451867], 
             UndirectedEdge[10, 30] -> 
             RGBColor[
              0.9463512489339432, 0.9594296724695054, 0.9729322839227738], 
             UndirectedEdge[89, 176] -> 
             RGBColor[
              0.9663684408272784, 0.8982149952241019, 0.3238481727113573], 
             UndirectedEdge[71, 76] -> 
             RGBColor[
              0.9577576462390103, 0.8652631969423321, 0.532248783853775], 
             UndirectedEdge[49, 119] -> 
             RGBColor[
              0.9667241529726883, 0.8944060955978099, 0.5081146913636675], 
             UndirectedEdge[87, 106] -> 
             RGBColor[
              0.9878467135398017, 0.9892423179705618, 0.85107493855003], 
             UndirectedEdge[86, 196] -> 
             RGBColor[
              0.9497678802796955, 0.8370373295920235, 0.2863360583193938], 
             UndirectedEdge[53, 123] -> 
             RGBColor[
              0.9932927908619382, 0.9912672150611874, 0.744304604167782], 
             UndirectedEdge[68, 102] -> 
             RGBColor[
              0.9900694995631614, 0.9783085505773617, 0.574615167328741], 
             UndirectedEdge[107, 130] -> 
             RGBColor[
              0.5862147240043747, 0.6469523591155102, 0.733830373937113], 
             UndirectedEdge[42, 157] -> 
             RGBColor[
              0.9932606698135935, 0.9906134180576862, 0.6982783178224381], 
             UndirectedEdge[96, 99] -> 
             RGBColor[
              0.5828031115401646, 0.6470767653312168, 0.9019621384159726], 
             UndirectedEdge[62, 194] -> 
             RGBColor[
              0.9936045957470161, 0.9913370620593596, 0.7348418013652921], 
             UndirectedEdge[57, 117] -> 
             RGBColor[
              0.993290075975303, 0.9880564759255852, 0.5110443626418602], 
             UndirectedEdge[102, 128] -> 
             RGBColor[
              0.985536873807584, 0.9871003021077871, 0.8362059402451085], 
             UndirectedEdge[46, 47] -> 
             RGBColor[
              0.9217740669817405, 0.9369875117345178, 0.8489047781585396], 
             UndirectedEdge[28, 105] -> 
             RGBColor[
              0.9634238555691169, 0.8810733825739018, 0.39398746942707746`], 
             UndirectedEdge[40, 182] -> 
             RGBColor[
              0.586299484723751, 0.647133653723633, 0.7430560551587019], 
             UndirectedEdge[79, 179] -> 
             RGBColor[
              0.9928340014846564, 0.9901388927640217, 0.6836815399152275], 
             UndirectedEdge[36, 63] -> 
             RGBColor[
              0.936100462097712, 0.7843666560158167, 0.2674431357701321], 
             UndirectedEdge[118, 129] -> 
             RGBColor[
              0.954680304468341, 0.927978233026536, 0.6533983791005356], 
             UndirectedEdge[74, 161] -> 
             RGBColor[
              0.9695144967175369, 0.9736287702424584, 0.7497731047677653], 
             UndirectedEdge[66, 187] -> 
             RGBColor[
              0.5738606030158988, 0.6408206752350442, 0.9356042244001594], 
             UndirectedEdge[10, 29] -> 
             RGBColor[
              0.9634078925576482, 0.9695611153897201, 0.8022860043705989], 
             UndirectedEdge[30, 147] -> 
             RGBColor[
              0.9770395601981308, 0.9807701271804977, 0.8509079708009648], 
             UndirectedEdge[109, 116] -> 
             RGBColor[
              0.958011865705751, 0.8609674642582335, 0.5065004746494144], 
             UndirectedEdge[81, 154] -> 
             RGBColor[
              0.9648418575412936, 0.9724620278527587, 0.90688527796859], 
             UndirectedEdge[89, 188] -> 
             RGBColor[
              0.9578480600890126, 0.9368480645477877, 0.6618500136262166], 
             UndirectedEdge[24, 163] -> 
             RGBColor[
              0.9763379071564325, 0.9304364506029725, 0.4822949369725982], 
             UndirectedEdge[91, 159] -> 
             RGBColor[
              0.9682471988157473, 0.9098193569611793, 0.5552154191586472], 
             UndirectedEdge[121, 164] -> 
             RGBColor[
              0.9918843194130649, 0.9909119717608941, 0.78416136024101], 
             UndirectedEdge[4, 54] -> 
             RGBColor[
              0.9923531869535962, 0.9888868378747946, 0.6150914892650102], 
             UndirectedEdge[51, 130] -> 
             RGBColor[
              0.9941898799223394, 0.9899810655841619, 0.6089824693305038], 
             UndirectedEdge[69, 186] -> 
             RGBColor[
              0.9448738414827105, 0.8185798653696499, 0.27747262001744777`], 
             UndirectedEdge[137, 179] -> 
             RGBColor[
              0.9493175697273659, 0.8246593485101398, 0.41147370675845685`], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.9470329057755689, 0.8150660190489718, 0.38064802851964485`], 
             UndirectedEdge[22, 176] -> 
             RGBColor[
              0.9770126364691277, 0.9338810360162937, 0.3855497996009688], 
             UndirectedEdge[128, 198] -> 
             RGBColor[
              0.985410408422073, 0.9857458446962253, 0.7436484605910011], 
             UndirectedEdge[107, 131] -> 
             RGBColor[
              0.5720034533732263, 0.5996312336036436, 0.6261717305632966], 
             UndirectedEdge[26, 125] -> 
             RGBColor[
              0.9633827547791449, 0.9684975407186143, 0.7176916431614826], 
             UndirectedEdge[47, 105] -> 
             RGBColor[
              0.9209024386565954, 0.9351231868821741, 0.7540334140329771], 
             UndirectedEdge[23, 60] -> 
             RGBColor[
              0.5816353694418022, 0.646593873963941, 0.9213146470055158], 
             UndirectedEdge[43, 111] -> 
             RGBColor[
              0.9759257268793492, 0.9295548386681098, 0.43743165749388685`], 
             UndirectedEdge[73, 142] -> 
             RGBColor[
              0.9801350264587028, 0.984015158310198, 0.8876037366028748], 
             UndirectedEdge[43, 115] -> 
             RGBColor[
              0.9796482931805485, 0.942111928902188, 0.4518931246263863], 
             UndirectedEdge[61, 122] -> 
             RGBColor[
              0.8875401748705884, 0.8328861301096696, 0.6267529575826383], 
             UndirectedEdge[64, 65] -> 
             RGBColor[
              0.934901094729692, 0.9357853995444163, 0.6922026187709225], 
             UndirectedEdge[147, 157] -> 
             RGBColor[
              0.9941294503925506, 0.9909726811537276, 0.6838803752970506], 
             UndirectedEdge[53, 69] -> 
             RGBColor[
              0.9764551182427119, 0.9306871532646654, 0.49505264037112934`], 
             UndirectedEdge[27, 188] -> 
             RGBColor[
              0.5615103616064328, 0.6316098854135286, 0.9565099616475442], 
             UndirectedEdge[88, 159] -> 
             RGBColor[
              0.9708871649374355, 0.9109110507965321, 0.5114643485089532], 
             UndirectedEdge[16, 61] -> 
             RGBColor[
              0.91537301336262, 0.9310947226216033, 0.7843545783522268], 
             UndirectedEdge[138, 185] -> 
             RGBColor[
              0.9310893488918823, 0.7524908796036804, 0.5202282393991183], 
             UndirectedEdge[26, 128] -> 
             RGBColor[
              0.9555799019882811, 0.966351208498792, 0.9586565539484251], 
             UndirectedEdge[68, 75] -> 
             RGBColor[
              0.973947190993419, 0.9679182618197855, 0.6750665695637126], 
             UndirectedEdge[10, 107] -> 
             RGBColor[
              0.5557665505979678, 0.6272464032240703, 0.9634674982755025], 
             UndirectedEdge[69, 123] -> 
             RGBColor[
              0.9747292675963304, 0.9302006655099291, 0.5401691910981006], 
             UndirectedEdge[109, 113] -> 
             RGBColor[
              0.9256856579669359, 0.7430754281650307, 0.2590631398996368], 
             UndirectedEdge[49, 196] -> 
             RGBColor[
              0.9776314230942684, 0.9361337018793336, 0.5247867339945266], 
             UndirectedEdge[8, 26] -> 
             RGBColor[
              0.9642063131615757, 0.9702590488241084, 0.8073308906758743], 
             UndirectedEdge[30, 73] -> 
             RGBColor[
              0.9742212800237897, 0.9796046959019109, 0.8976141667650894], 
             UndirectedEdge[46, 144] -> 
             RGBColor[
              0.9839292563272171, 0.955824224905286, 0.530461558498467], 
             UndirectedEdge[81, 176] -> 
             RGBColor[
              0.9751842670201916, 0.9351878245805381, 0.5657992176570438], 
             UndirectedEdge[104, 181] -> 
             RGBColor[
              0.9928270320301973, 0.9896739318928351, 0.6502087893565719], 
             UndirectedEdge[65, 171] -> 
             RGBColor[
              0.9873318676873444, 0.9752562953727397, 0.606712640663587], 
             UndirectedEdge[67, 82] -> 
             RGBColor[
              0.5863996058003889, 0.6485640081335061, 0.842358921095269], 
             UndirectedEdge[13, 63] -> 
             RGBColor[
              0.9734042752489278, 0.9211785161464037, 0.5148987912152563], 
             UndirectedEdge[153, 182] -> 
             RGBColor[
              0.5868386289658738, 0.648286828741689, 0.8017385787011854], 
             UndirectedEdge[87, 157] -> 
             RGBColor[
              0.9928129326283949, 0.9904282672252858, 0.7056984816878715], 
             UndirectedEdge[30, 157] -> 
             RGBColor[
              0.9771862868663707, 0.9799630924641001, 0.7854029757906285], 
             UndirectedEdge[64, 185] -> 
             RGBColor[
              0.8788700522012246, 0.7131074346464515, 0.6022135084793167], 
             UndirectedEdge[9, 103] -> 
             RGBColor[
              0.559092799573697, 0.6298068716079089, 0.9606022635678038], 
             UndirectedEdge[18, 117] -> 
             RGBColor[
              0.5859784194818198, 0.6464469276358178, 0.7081100849594952], 
             UndirectedEdge[52, 66] -> 
             RGBColor[
              0.9817038457741623, 0.9841439512755668, 0.8383197319257466], 
             UndirectedEdge[128, 162] -> 
             RGBColor[
              0.5779876209303356, 0.6438985984382595, 0.9286182595696796], 
             UndirectedEdge[23, 177] -> 
             RGBColor[
              0.983959037964933, 0.9720241356175825, 0.6499090622361383], 
             UndirectedEdge[11, 110] -> 
             RGBColor[
              0.9942717188883163, 0.991413858129784, 0.7093150849873586], 
             UndirectedEdge[79, 177] -> 
             RGBColor[
              0.9876558481444819, 0.973552861630514, 0.5886433505229489], 
             UndirectedEdge[8, 166] -> 
             RGBColor[
              0.9599270050890132, 0.8663840734255104, 0.4400202746533125], 
             UndirectedEdge[162, 173] -> 
             RGBColor[
              0.5855930240094278, 0.6482304658347373, 0.8557260687382573], 
             UndirectedEdge[100, 137] -> 
             RGBColor[
              0.942495513749146, 0.822355209817396, 0.5802175716374813], 
             UndirectedEdge[88, 117] -> 
             RGBColor[
              0.9936014283130927, 0.9896791312877761, 0.6144754386024489], 
             UndirectedEdge[149, 168] -> 
             RGBColor[
              0.5798985682768889, 0.6262633100348324, 0.6568427610966792], 
             UndirectedEdge[36, 110] -> 
             RGBColor[
              0.9566136346125658, 0.8549408624523439, 0.5030115064570033], 
             UndirectedEdge[76, 104] -> 
             RGBColor[
              0.9914120175947951, 0.9907166628214366, 0.7919886236476639], 
             UndirectedEdge[4, 196] -> 
             RGBColor[
              0.9765432129296369, 0.9356836990105329, 0.5428211926201018], 
             UndirectedEdge[61, 79] -> 
             RGBColor[
              0.9142596097084538, 0.9317711788454444, 0.8854455327418477], 
             UndirectedEdge[76, 147] -> 
             RGBColor[
              0.9922738554475228, 0.9910730549217619, 0.7777057400631], 
             UndirectedEdge[2, 120] -> 
             RGBColor[
              0.9589425586148559, 0.8657650213091406, 0.3335431477703731], 
             UndirectedEdge[87, 176] -> 
             RGBColor[
              0.9762420864426982, 0.9356252600964636, 0.5482684122771992], 
             UndirectedEdge[142, 157] -> 
             RGBColor[
              0.9831000333012838, 0.9843735548723871, 0.7753925456284139], 
             UndirectedEdge[65, 191] -> 
             RGBColor[
              0.9880542102757806, 0.9755550025964159, 0.5947415546105039], 
             UndirectedEdge[73, 147] -> 
             RGBColor[
              0.9911644435499697, 0.9906142845915384, 0.7960915662715117], 
             UndirectedEdge[26, 120] -> 
             RGBColor[
              0.9325240419187124, 0.8570962866632281, 0.6284328484438454], 
             UndirectedEdge[113, 116] -> 
             RGBColor[
              0.9612257788499556, 0.8737095589019374, 0.5090864646054788], 
             UndirectedEdge[35, 94] -> 
             RGBColor[
              0.9282705714108446, 0.9134190874690331, 0.666444287746464], 
             UndirectedEdge[31, 45] -> 
             RGBColor[
              0.9815274425348492, 0.9483134464762599, 0.4708677934574429], 
             UndirectedEdge[52, 82] -> 
             RGBColor[
              0.5867702427582634, 0.6487172760405227, 0.8362165075255872], 
             UndirectedEdge[95, 162] -> 
             RGBColor[
              0.5079896330013677, 0.29559976483466166`, 0.5583077989048778], 
             UndirectedEdge[17, 73] -> 
             RGBColor[
              0.9558393742342823, 0.8615975658238123, 0.5499837822335667], 
             UndirectedEdge[103, 152] -> 
             RGBColor[
              0.5859786364705599, 0.6483899264972037, 0.8493354723242363], 
             UndirectedEdge[88, 103] -> 
             RGBColor[
              0.5865500088312728, 0.6486262036519583, 0.8398663536429538], 
             UndirectedEdge[26, 170] -> 
             RGBColor[
              0.9168415528224692, 0.7935794397979763, 0.6157449808812239], 
             UndirectedEdge[89, 106] -> 
             RGBColor[
              0.9779730679243821, 0.9518320530982001, 0.6266546989841881], 
             UndirectedEdge[19, 74] -> 
             RGBColor[
              0.9838047139610789, 0.9564801764816833, 0.43847717083019533`], 
             UndirectedEdge[117, 152] -> 
             RGBColor[
              0.9930300559523799, 0.9894428541330214, 0.6239445572837314], 
             UndirectedEdge[157, 176] -> 
             RGBColor[
              0.9777053308750938, 0.9353626393085077, 0.460945310876042], 
             UndirectedEdge[49, 139] -> 
             RGBColor[
              0.9932590674065527, 0.9914804653856133, 0.7613782282551556], 
             UndirectedEdge[48, 106] -> 
             RGBColor[
              0.9781747638034354, 0.9525124206586915, 0.6274382493872397], 
             UndirectedEdge[69, 118] -> 
             RGBColor[
              0.9503015854773185, 0.9132077856977059, 0.6363878826721109], 
             UndirectedEdge[117, 200] -> 
             RGBColor[
              0.988269506534185, 0.9717672843380732, 0.4365779273286871], 
             UndirectedEdge[64, 153] -> 
             RGBColor[
              0.9398682482223497, 0.9511538390174226, 0.8294340644699597], 
             UndirectedEdge[73, 87] -> 
             RGBColor[
              0.9898479257858139, 0.9900698706630967, 0.8179096726623325], 
             UndirectedEdge[132, 138] -> 
             RGBColor[
              0.9909739328385858, 0.988155380350916, 0.6262389935060673], 
             UndirectedEdge[6, 96] -> 
             RGBColor[
              0.9906276233703843, 0.9897832593286352, 0.7607175545258504], 
             UndirectedEdge[34, 65] -> 
             RGBColor[
              0.9799402165869565, 0.9706832453637797, 0.6613033863776354], 
             UndirectedEdge[2, 16] -> 
             RGBColor[
              0.9904563810296062, 0.9785674884594764, 0.4941065746079787], 
             UndirectedEdge[21, 122] -> 
             RGBColor[
              0.9598591004179906, 0.8893722670429146, 0.5927737409795489], 
             UndirectedEdge[90, 175] -> 
             RGBColor[
              0.9942421966450332, 0.9900929657639717, 0.6146768217343268], 
             UndirectedEdge[6, 179] -> 
             RGBColor[
              0.9942533336935251, 0.9901167867845675, 0.615889020732779], 
             UndirectedEdge[8, 137] -> 
             RGBColor[
              0.9495027799676906, 0.8250554944865665, 0.43163269843268437`], 
             UndirectedEdge[3, 127] -> 
             RGBColor[
              0.9886112719516337, 0.9727061503459566, 0.456101701006022], 
             UndirectedEdge[31, 65] -> 
             RGBColor[
              0.9894991342629704, 0.9752038345174414, 0.5018363104935277], 
             UndirectedEdge[3, 71] -> 
             RGBColor[
              0.9591634357967505, 0.8642007349331897, 0.3894648785585158], 
             UndirectedEdge[146, 184] -> 
             RGBColor[
              0.9764667432802816, 0.9441274810110422, 0.6026701703413918], 
             UndirectedEdge[33, 99] -> 
             RGBColor[
              0.5767653381546272, 0.6429870219454406, 0.9306872654865501], 
             UndirectedEdge[10, 130] -> 
             RGBColor[
              0.9630542746023425, 0.9688047623395806, 0.7637968722126156], 
             UndirectedEdge[112, 160] -> 
             RGBColor[
              0.9845757312902523, 0.9689239478593683, 0.6164977970036893], 
             UndirectedEdge[73, 157] -> 
             RGBColor[
              0.9913111702182096, 0.9898072498751407, 0.7305865712611754], 
             UndirectedEdge[157, 188] -> 
             RGBColor[
              0.969184950136828, 0.9739957086321935, 0.7989471517909014], 
             UndirectedEdge[70, 132] -> 
             RGBColor[
              0.9938740904629519, 0.9893546700592426, 0.5781758763029815], 
             UndirectedEdge[141, 191] -> 
             RGBColor[
              0.9820863808058866, 0.9554241124814682, 0.5715576640499971], 
             UndirectedEdge[26, 80] -> 
             RGBColor[
              0.9638713146637228, 0.9695425209107449, 0.7708683715556737], 
             UndirectedEdge[171, 199] -> 
             RGBColor[
              0.5843873922141283, 0.6477319061040571, 0.8757065076614388], 
             UndirectedEdge[23, 43] -> 
             RGBColor[
              0.9891517988325993, 0.9886414107753473, 0.7465371908486786], 
             UndirectedEdge[75, 81] -> 
             RGBColor[
              0.9755074689829991, 0.9804164234026469, 0.8888311798347595], 
             UndirectedEdge[33, 172] -> 
             RGBColor[
              0.5767653381546272, 0.6429870219454406, 0.9306872654865501], 
             UndirectedEdge[156, 166] -> 
             RGBColor[
              0.9452993636698206, 0.8181513118097832, 0.28883312359555385`], 
             UndirectedEdge[151, 175] -> 
             RGBColor[
              0.9330098653531882, 0.751545769723638, 0.3619720864412258], 
             UndirectedEdge[34, 199] -> 
             RGBColor[
              0.5769957411137404, 0.643158856095097, 0.9302972533754872], 
             UndirectedEdge[38, 169] -> 
             RGBColor[
              0.9523791107319541, 0.8987659839374382, 0.6170516732440599], 
             UndirectedEdge[10, 142] -> 
             RGBColor[
              0.9522649953688562, 0.9638401348777925, 0.962921853760559], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.9580088063773211, 0.9682036170672509, 0.9559643171326009], 
             UndirectedEdge[12, 128] -> 
             RGBColor[
              0.9767737966609269, 0.9573960662598583, 0.6434701833007459], 
             UndirectedEdge[19, 172] -> 
             RGBColor[
              0.5765699455875488, 0.615035084105914, 0.6439116905062439], 
             UndirectedEdge[109, 124] -> 
             RGBColor[
              0.9584437147801584, 0.8611460449485158, 0.49934361789690573`], 
             UndirectedEdge[75, 127] -> 
             RGBColor[
              0.9728134331160323, 0.9640938302803512, 0.6706621343022752], 
             UndirectedEdge[4, 191] -> 
             RGBColor[
              0.9916445334692059, 0.9908128141108907, 0.7881352338768848], 
             UndirectedEdge[68, 172] -> 
             RGBColor[
              0.582520246685913, 0.6351068469078339, 0.6670274866533121], 
             UndirectedEdge[97, 105] -> 
             RGBColor[
              0.993463811264086, 0.9884280781409597, 0.5299543766559638], 
             UndirectedEdge[120, 136] -> 
             RGBColor[
              0.9207418065706217, 0.7234747048194609, 0.2550852010190552], 
             UndirectedEdge[117, 159] -> 
             RGBColor[
              0.9703155755879826, 0.9087317747803916, 0.3797080798254945], 
             UndirectedEdge[183, 192] -> 
             RGBColor[
              0.9040548030245447, 0.5622933465888694, 0.48325251056076957`], 
             UndirectedEdge[71, 188] -> 
             RGBColor[
              0.9345220142600756, 0.8489928853691615, 0.6189951905919127], 
             UndirectedEdge[14, 106] -> 
             RGBColor[
              0.976604806021661, 0.9472165844171493, 0.6213392598666962], 
             UndirectedEdge[141, 194] -> 
             RGBColor[
              0.9825696700127499, 0.9556239649884722, 0.5635483111798987], 
             UndirectedEdge[50, 105] -> 
             RGBColor[
              0.9933331258882114, 0.9881485553362825, 0.5157300799886781], 
             UndirectedEdge[98, 125] -> 
             RGBColor[
              0.5857904737211994, 0.6460449306580818, 0.6876533487827371], 
             UndirectedEdge[118, 119] -> 
             RGBColor[
              0.9409934321301818, 0.8768743757868539, 0.6259281067421006], 
             UndirectedEdge[137, 166] -> 
             RGBColor[
              0.9151287208494436, 0.7012206903849252, 0.25056878049173964`], 
             UndirectedEdge[6, 112] -> 
             RGBColor[
              0.9879415533078606, 0.9697067654383343, 0.5164469043362765], 
             UndirectedEdge[65, 119] -> 
             RGBColor[
              0.9620456196146315, 0.8786982812145343, 0.3327554707228619], 
             UndirectedEdge[170, 183] -> 
             RGBColor[
              0.8584452717645237, 0.38549332973744377`, 0.20106518650247834`],
              UndirectedEdge[14, 131] -> 
             RGBColor[
              0.9669728899530852, 0.900253944056852, 0.32619634342447706`], 
             UndirectedEdge[9, 164] -> 
             RGBColor[
              0.9645082000745717, 0.9721261724823014, 0.9035534003526752], 
             UndirectedEdge[96, 170] -> 
             RGBColor[
              0.9431253833046883, 0.8128095950686607, 0.554167824918451], 
             UndirectedEdge[117, 178] -> 
             RGBColor[
              0.9697563967038174, 0.9065148168399937, 0.37925815136967983`], 
             UndirectedEdge[18, 24] -> 
             RGBColor[
              0.5868556096678805, 0.6483231487462691, 0.8035868233218743], 
             UndirectedEdge[18, 133] -> 
             RGBColor[
              0.5622630239608586, 0.6321712197650879, 0.9552359006072827], 
             UndirectedEdge[49, 129] -> 
             RGBColor[
              0.9804110253108475, 0.945509952837492, 0.5355849637221024], 
             UndirectedEdge[124, 198] -> 
             RGBColor[
              0.9940941298605301, 0.9905236244458182, 0.652885743946441], 
             UndirectedEdge[113, 124] -> 
             RGBColor[
              0.961657627924363, 0.8738881395922198, 0.5019296078529701], 
             UndirectedEdge[176, 188] -> 
             RGBColor[
              0.9526141039511313, 0.9191927015033714, 0.641517082380229], 
             UndirectedEdge[37, 97] -> 
             RGBColor[
              0.9166553946869751, 0.9318265684158513, 0.7609125980521988], 
             UndirectedEdge[77, 143] -> 
             RGBColor[
              0.9235225502829882, 0.6970731552410159, 0.4338435319042363], 
             UndirectedEdge[79, 84] -> 
             RGBColor[
              0.585332179621351, 0.6481225999768725, 0.8600489352923264], 
             UndirectedEdge[151, 199] -> 
             RGBColor[
              0.5258404329447487, 0.41024042437071795`, 0.5745180227105423], 
             UndirectedEdge[48, 87] -> 
             RGBColor[
              0.9816777384596327, 0.9539609907013715, 0.5693848939262384], 
             UndirectedEdge[27, 30] -> 
             RGBColor[
              0.5695116983359754, 0.6375772692454351, 0.9429657856472713], 
             UndirectedEdge[5, 87] -> 
             RGBColor[
              0.9663378024800289, 0.8978873652507896, 0.5323346211704443], 
             UndirectedEdge[68, 81] -> 
             RGBColor[
              0.9876737713614059, 0.9773178553985293, 0.614318583577671], 
             UndirectedEdge[155, 172] -> 
             RGBColor[
              0.5824292872190617, 0.646922179367594, 0.9081573748429785], 
             UndirectedEdge[143, 188] -> 
             RGBColor[
              0.9694219905723065, 0.9745027141552176, 0.8247475403487295], 
             UndirectedEdge[102, 180] -> 
             RGBColor[
              0.9941123075324259, 0.990899106825474, 0.6793316963048348], 
             UndirectedEdge[80, 136] -> 
             RGBColor[
              0.952089079315632, 0.8359209390669775, 0.39752072413088346`], 
             UndirectedEdge[66, 78] -> 
             RGBColor[
              0.9818796567910122, 0.9839432747813825, 0.815534330638008], 
             UndirectedEdge[50, 101] -> 
             RGBColor[
              0.5860982116347135, 0.6467031509380127, 0.7211487215304926], 
             UndirectedEdge[41, 85] -> 
             RGBColor[
              0.9585835375762697, 0.9657072126245835, 0.8012508669278555], 
             UndirectedEdge[5, 30] -> 
             RGBColor[
              0.9507111567180047, 0.8874221904896038, 0.6120391152732012], 
             UndirectedEdge[32, 133] -> 
             RGBColor[
              0.9253106472753356, 0.9430263145451958, 0.983886912546287], 
             UndirectedEdge[159, 161] -> 
             RGBColor[
              0.9466168844501694, 0.894468525011263, 0.626805619309813], 
             UndirectedEdge[3, 195] -> 
             RGBColor[
              0.9375542849702827, 0.9483873259820923, 0.7545199394699701], 
             UndirectedEdge[173, 180] -> 
             RGBColor[
              0.9932290786646052, 0.9905338689906836, 0.6939690843676631], 
             UndirectedEdge[129, 141] -> 
             RGBColor[
              0.9697646624828967, 0.9096712483392687, 0.33704185252079], 
             UndirectedEdge[53, 199] -> 
             RGBColor[
              0.5869728207541598, 0.6485738514079619, 0.8163445267204055], 
             UndirectedEdge[88, 95] -> 
             RGBColor[
              0.9156126418326405, 0.6388319684866199, 0.4646731525478316], 
             UndirectedEdge[93, 95] -> 
             RGBColor[
              0.9120004307554566, 0.6267211095411066, 0.293456392610151], 
             UndirectedEdge[3, 29] -> 
             RGBColor[
              0.9937931251027879, 0.9891324471432068, 0.5657981557092437], 
             UndirectedEdge[52, 125] -> 
             RGBColor[
              0.9936337164794629, 0.9893682066986044, 0.5903688563083243], 
             UndirectedEdge[82, 136] -> 
             RGBColor[
              0.5447370457098548, 0.4942250282167653, 0.5901916469539554], 
             UndirectedEdge[116, 193] -> 
             RGBColor[
              0.9936991093176359, 0.9904238162605066, 0.664051159074794], 
             UndirectedEdge[19, 159] -> 
             RGBColor[
              0.9609071016937116, 0.8773199312504878, 0.3155096853722431], 
             UndirectedEdge[77, 99] -> 
             RGBColor[
              0.5156109213171145, 0.35418032649932696`, 0.565605953203051], 
             UndirectedEdge[53, 196] -> 
             RGBColor[
              0.9780542350171553, 0.9360813496353373, 0.5012649070719782], 
             UndirectedEdge[58, 137] -> 
             RGBColor[
              0.9495357519662448, 0.8251260182574933, 0.4352214969957183], 
             UndirectedEdge[159, 200] -> 
             RGBColor[
              0.9655552431585278, 0.8929992038468293, 0.3335668372351913], 
             UndirectedEdge[3, 62] -> 
             RGBColor[
              0.9941633548806958, 0.9899243312021793, 0.6060953822411822], 
             UndirectedEdge[48, 157] -> 
             RGBColor[
              0.9831409828920286, 0.9536983699134155, 0.4820617925250812], 
             UndirectedEdge[130, 168] -> 
             RGBColor[
              0.5862147240043747, 0.6469523591155103, 0.733830373937113], 
             UndirectedEdge[140, 180] -> 
             RGBColor[
              0.9866927045485456, 0.9657267247913263, 0.4918150827890532], 
             UndirectedEdge[146, 171] -> 
             RGBColor[
              0.9783324001087974, 0.9448989780548269, 0.5717514085277821], 
             UndirectedEdge[26, 100] -> 
             RGBColor[
              0.9571990469430309, 0.9675587641549379, 0.9559157638806711], 
             UndirectedEdge[45, 153] -> 
             RGBColor[
              0.9818114127109686, 0.9489208299691902, 0.5017761946672488], 
             UndirectedEdge[165, 177] -> 
             RGBColor[
              0.988143172244676, 0.9715372845470795, 0.41940750039859237`], 
             UndirectedEdge[123, 139] -> 
             RGBColor[
              0.9919560286830582, 0.9909416253868806, 0.7829729520595783], 
             UndirectedEdge[13, 34] -> 
             RGBColor[
              0.9845376600259306, 0.9863575269815987, 0.8380064768316258], 
             UndirectedEdge[48, 72] -> 
             RGBColor[
              0.9540585182210892, 0.934551773531636, 0.6693896884533774], 
             UndirectedEdge[127, 191] -> 
             RGBColor[
              0.9875692236110907, 0.9739190286961328, 0.5928574730002304], 
             UndirectedEdge[58, 125] -> 
             RGBColor[
              0.9935104778233836, 0.9885278931925845, 0.5350337436428997], 
             UndirectedEdge[165, 169] -> 
             RGBColor[
              0.9749344583473365, 0.9771941596863023, 0.7027657635460303], 
             UndirectedEdge[119, 156] -> 
             RGBColor[
              0.9521605348258528, 0.8453535690937002, 0.29435378296008363`], 
             UndirectedEdge[139, 191] -> 
             RGBColor[
              0.9918187933778444, 0.9908848750613881, 0.7852472962205574], 
             UndirectedEdge[48, 81] -> 
             RGBColor[
              0.9806199190371262, 0.953523555185446, 0.5869156993060829], 
             UndirectedEdge[85, 161] -> 
             RGBColor[
              0.934300211265099, 0.9501934873353262, 0.9847144757422632], 
             UndirectedEdge[30, 106] -> 
             RGBColor[
              0.9722200677777775, 0.978777143209376, 0.930779432652787], 
             UndirectedEdge[118, 195] -> 
             RGBColor[
              0.9122217898159417, 0.9326640748455377, 0.9852200588772098], 
             UndirectedEdge[132, 145] -> 
             RGBColor[
              0.9543210437563596, 0.8457814402413169, 0.3394610896041844], 
             UndirectedEdge[124, 137] -> 
             RGBColor[
              0.9495600902328534, 0.825925433910843, 0.49219564506067526`], 
             UndirectedEdge[53, 182] -> 
             RGBColor[
              0.5869728207541598, 0.6485738514079619, 0.8163445267204055], 
             UndirectedEdge[31, 40] -> 
             RGBColor[
              0.9939271435135054, 0.9894190989723917, 0.5803852326500814], 
             UndirectedEdge[130, 157] -> 
             RGBColor[
              0.99388931253477, 0.9893381823341751, 0.5762675640804702], 
             UndirectedEdge[83, 166] -> 
             RGBColor[
              0.9338149398996646, 0.7753053221056826, 0.26560415096148204`], 
             UndirectedEdge[76, 176] -> 
             RGBColor[
              0.975849735930066, 0.935463013076542, 0.5547706756420914], 
             UndirectedEdge[100, 113] -> 
             RGBColor[
              0.9545930514406558, 0.8703179154987727, 0.5899515344297761], 
             UndirectedEdge[53, 118] -> 
             RGBColor[
              0.9688651087429263, 0.9742743352489642, 0.8405232957417923], 
             UndirectedEdge[18, 85] -> 
             RGBColor[
              0.5509474829210923, 0.6234038094686372, 0.9630078512984496], 
             UndirectedEdge[90, 177] -> 
             RGBColor[
              0.9893964327597244, 0.9742178820646932, 0.5558171732342658], 
             UndirectedEdge[55, 165] -> 
             RGBColor[
              0.9824408960013726, 0.9827924485980188, 0.6900593225902385], 
             UndirectedEdge[9, 121] -> 
             RGBColor[
              0.9666347184858871, 0.9730055424944106, 0.8683114870239422], 
             UndirectedEdge[70, 110] -> 
             RGBColor[
              0.994524602423091, 0.9920037966377182, 0.7404050379314793], 
             UndirectedEdge[51, 147] -> 
             RGBColor[
              0.9944300177801202, 0.9916155644037141, 0.7165952805470842], 
             UndirectedEdge[81, 188] -> 
             RGBColor[
              0.9666638862819257, 0.973820893904224, 0.9038010585719032], 
             UndirectedEdge[63, 132] -> 
             RGBColor[
              0.97266037322819, 0.9184907703778553, 0.3542173445766089], 
             UndirectedEdge[68, 143] -> 
             RGBColor[
              0.9904318756517867, 0.9779996756495228, 0.5352650653544974], 
             UndirectedEdge[76, 81] -> 
             RGBColor[
              0.9898995182608604, 0.9900912054773946, 0.8170546518337656], 
             UndirectedEdge[55, 163] -> 
             RGBColor[
              0.9650306897683796, 0.9241927275612845, 0.6114553510729926], 
             UndirectedEdge[86, 94] -> 
             RGBColor[
              0.9117160852731758, 0.8523968416403817, 0.6291111637365954], 
             UndirectedEdge[3, 167] -> 
             RGBColor[
              0.994117312330351, 0.9898258508426077, 0.6010839347778294], 
             UndirectedEdge[16, 82] -> 
             RGBColor[
              0.5864455832755172, 0.6474461437530314, 0.7589579809027054], 
             UndirectedEdge[51, 107] -> 
             RGBColor[
              0.5869021559179648, 0.6484227064686515, 0.8086530953933908], 
             UndirectedEdge[53, 171] -> 
             RGBColor[
              0.9924332129682881, 0.990911757512019, 0.7585500343818441], 
             UndirectedEdge[78, 82] -> 
             RGBColor[
              0.5869460537751134, 0.6485165995463383, 0.8134311062378485], 
             UndirectedEdge[92, 186] -> 
             RGBColor[
              0.934284572482253, 0.8599302045291844, 0.6280202393905883], 
             UndirectedEdge[75, 118] -> 
             RGBColor[
              0.9522462322962726, 0.9639058987529538, 0.9657188519317874], 
             UndirectedEdge[77, 83] -> 
             RGBColor[
              0.8971858882313959, 0.605514013943075, 0.2349814258083492], 
             UndirectedEdge[42, 176] -> 
             RGBColor[
              0.9766898236278967, 0.9358104109288641, 0.5408482484117657], 
             UndirectedEdge[20, 144] -> 
             RGBColor[
              0.9829407609697571, 0.9537099332878904, 0.422869939125159], 
             UndirectedEdge[26, 98] -> 
             RGBColor[
              0.5565192810579456, 0.6278466100605326, 0.9635392943787455], 
             UndirectedEdge[16, 84] -> 
             RGBColor[
              0.5864455832755172, 0.6474461437530314, 0.7589579809027054], 
             UndirectedEdge[55, 175] -> 
             RGBColor[
              0.9827178246882671, 0.983384771057501, 0.7202013011529522], 
             UndirectedEdge[113, 128] -> 
             RGBColor[
              0.9529739064859059, 0.8691103598426269, 0.5926923244975302], 
             UndirectedEdge[142, 147] -> 
             RGBColor[
              0.9829533066330438, 0.9851805895887848, 0.8408975406387501], 
             UndirectedEdge[10, 42] -> 
             RGBColor[
              0.9624256318811659, 0.9700799980630916, 0.8858076259545833], 
             UndirectedEdge[98, 120] -> 
             RGBColor[
              0.5549317608607669, 0.5346436766026956, 0.5983945540650999], 
             UndirectedEdge[195, 199] -> 
             RGBColor[
              0.5303295018271752, 0.6069635910045353, 0.9610412898558227], 
             UndirectedEdge[49, 195] -> 
             RGBColor[
              0.9379525106584481, 0.9501957946564936, 0.8674066434987766], 
             UndirectedEdge[25, 43] -> 
             RGBColor[
              0.9845583650869735, 0.9586747543822685, 0.47096782679357135`], 
             UndirectedEdge[91, 121] -> 
             RGBColor[
              0.9914519616217746, 0.9907331807031072, 0.7913266477487864], 
             UndirectedEdge[8, 21] -> 
             RGBColor[
              0.9878603877381351, 0.9879411545653928, 0.7687099771435606], 
             UndirectedEdge[2, 124] -> 
             RGBColor[
              0.9906821401228818, 0.9797977228942973, 0.5730041366303927], 
             UndirectedEdge[80, 125] -> 
             RGBColor[
              0.9931425073269766, 0.987740841508294, 0.49498242595966513`], 
             UndirectedEdge[33, 180] -> 
             RGBColor[
              0.9844013928098047, 0.985290425101387, 0.768930281115956], 
             UndirectedEdge[5, 155] -> 
             RGBColor[
              0.963628745601091, 0.8967671006117628, 0.5772307044689086], 
             UndirectedEdge[179, 192] -> 
             RGBColor[
              0.99236062488785, 0.9899431393760186, 0.6915266151836708], 
             UndirectedEdge[59, 146] -> 
             RGBColor[
              0.9805080625498466, 0.9448644751067163, 0.4677889164957492], 
             UndirectedEdge[3, 68] -> 
             RGBColor[
              0.9897450298290205, 0.9765305818853909, 0.4605061362674594], 
             UndirectedEdge[131, 157] -> 
             RGBColor[
              0.9796780419036217, 0.9420170568223085, 0.4686089207066538], 
             UndirectedEdge[85, 200] -> 
             RGBColor[
              0.9532385699734574, 0.9487241661708925, 0.6914756936676415], 
             UndirectedEdge[23, 38] -> 
             RGBColor[
              0.965972525547965, 0.9088787211085148, 0.592912641871515], 
             UndirectedEdge[92, 191] -> 
             RGBColor[
              0.9640027632906591, 0.9714942543439713, 0.8929911546322201], 
             UndirectedEdge[97, 153] -> 
             RGBColor[
              0.9941405259764617, 0.9898755024843788, 0.6036105968989636], 
             UndirectedEdge[95, 161] -> 
             RGBColor[
              0.8913423613453744, 0.6223894427013507, 0.5800144233486915], 
             UndirectedEdge[139, 196] -> 
             RGBColor[
              0.9767174728382754, 0.9357557599610303, 0.5399332549637745], 
             UndirectedEdge[1, 94] -> 
             RGBColor[
              0.531956619256476, 0.6082610102757335, 0.9611964857687744], 
             UndirectedEdge[189, 194] -> 
             RGBColor[
              0.9911744516272409, 0.9906184231886859, 0.7959257065310542], 
             UndirectedEdge[42, 76] -> 
             RGBColor[
              0.9914050748685657, 0.9907137918257206, 0.7921036825884875], 
             UndirectedEdge[84, 190] -> 
             RGBColor[
              0.5717250893961019, 0.6392280126739822, 0.9392190919273211], 
             UndirectedEdge[37, 134] -> 
             RGBColor[
              0.9145807392570404, 0.9254625900412012, 0.6989148281197551], 
             UndirectedEdge[140, 161] -> 
             RGBColor[
              0.962409378237375, 0.950212999502069, 0.675278691603461], 
             UndirectedEdge[10, 51] -> 
             RGBColor[
              0.9637417065159326, 0.9702751096927218, 0.8386195936688932], 
             UndirectedEdge[146, 191] -> 
             RGBColor[
              0.9790547426972337, 0.9451976852785031, 0.5597803224746991], 
             UndirectedEdge[21, 175] -> 
             RGBColor[
              0.9873427880429445, 0.9868340611547369, 0.7123724445771156], 
             UndirectedEdge[49, 141] -> 
             RGBColor[
              0.983526654834595, 0.9560197028056934, 0.5476885960845952], 
             UndirectedEdge[111, 177] -> 
             RGBColor[
              0.9707329660116829, 0.9129375635103452, 0.34080352888134646`], 
             UndirectedEdge[69, 191] -> 
             RGBColor[
              0.9745920322911166, 0.9301439151844367, 0.5424435352590797], 
             UndirectedEdge[111, 175] -> 
             RGBColor[
              0.9755787298969916, 0.9288126472096236, 0.3996631773814075], 
             UndirectedEdge[77, 170] -> 
             RGBColor[
              0.8759331930816381, 0.5199131562367707, 0.21781163970552936`], 
             UndirectedEdge[104, 154] -> 
             RGBColor[
              0.9663543568752282, 0.9730874851968007, 0.8818192497824883], 
             UndirectedEdge[13, 138] -> 
             RGBColor[
              0.9917178348593237, 0.9908431261194643, 0.7869204401447145], 
             UndirectedEdge[21, 67] -> 
             RGBColor[
              0.9876459614348938, 0.9886987239353231, 0.8337763019417009], 
             UndirectedEdge[73, 197] -> 
             RGBColor[
              0.9561756209093795, 0.8629306718430108, 0.550254334201074], 
             UndirectedEdge[67, 192] -> 
             RGBColor[
              0.9923314088249335, 0.9910968547223755, 0.7767519316560385], 
             UndirectedEdge[37, 101] -> 
             RGBColor[
              0.509353497676387, 0.5902378946731615, 0.9590405798544206], 
             UndirectedEdge[6, 44] -> 
             RGBColor[0.9933600574453834, 0.990913191039, 0.7154340505904073],
              UndirectedEdge[75, 89] -> 
             RGBColor[
              0.966691642790086, 0.9434435940462107, 0.6468801348890729], 
             UndirectedEdge[76, 188] -> 
             RGBColor[
              0.9673293551918001, 0.9740960824002279, 0.8927725165569508], 
             UndirectedEdge[42, 71] -> 
             RGBColor[
              0.9585977339368411, 0.8656105947946542, 0.5183263566234493], 
             UndirectedEdge[6, 192] -> 
             RGBColor[
              0.9926833148547642, 0.9906333405862877, 0.7266494266706474], 
             UndirectedEdge[2, 100] -> 
             RGBColor[
              0.9836175636391744, 0.9762274988008504, 0.6610260632071987], 
             UndirectedEdge[7, 8] -> 
             RGBColor[
              0.9655070605917248, 0.9712700797798139, 0.806548329320993], 
             UndirectedEdge[69, 92] -> 
             RGBColor[
              0.9473023259766467, 0.9109709428729416, 0.6414648466745883], 
             UndirectedEdge[104, 160] -> 
             RGBColor[
              0.990051713822039, 0.9901541422531895, 0.8145323775155479], 
             UndirectedEdge[17, 30] -> 
             RGBColor[
              0.9417144908824433, 0.8517534084127716, 0.6048001867630199], 
             UndirectedEdge[88, 164] -> 
             RGBColor[
              0.9919654093321476, 0.9909455045263507, 0.7828174904278253], 
             UndirectedEdge[43, 60] -> 
             RGBColor[
              0.5864434293907972, 0.6474415368114064, 0.758723543843163], 
             UndirectedEdge[149, 197] -> 
             RGBColor[
              0.9524376074984542, 0.8417725552213673, 0.31894771417993495`], 
             UndirectedEdge[167, 197] -> 
             RGBColor[
              0.9594315684088088, 0.8639113610515856, 0.4697102382469378], 
             UndirectedEdge[54, 127] -> 
             RGBColor[
              0.988277877095481, 0.9719930524600366, 0.41981372838835596`], 
             UndirectedEdge[107, 147] -> 
             RGBColor[
              0.5864548618621555, 0.6485868579350627, 0.8414431851536934], 
             UndirectedEdge[78, 113] -> 
             RGBColor[
              0.9619323393306837, 0.8737283609507056, 0.4775051711656992], 
             UndirectedEdge[81, 87] -> 
             RGBColor[
              0.9902918687734925, 0.9902534524973162, 0.8105523884688732], 
             UndirectedEdge[83, 179] -> 
             RGBColor[
              0.9680037887775869, 0.8987439802308972, 0.4265090772281993], 
             UndirectedEdge[82, 198] -> 
             RGBColor[
              0.5863497874917374, 0.6472412462579658, 0.7485312010213215], 
             UndirectedEdge[30, 107] -> 
             RGBColor[
              0.5695116983359754, 0.6375772692454351, 0.9429657856472713], 
             UndirectedEdge[47, 134] -> 
             RGBColor[
              0.9188947659837507, 0.928902477851944, 0.6993263038401258], 
             UndirectedEdge[5, 142] -> 
             RGBColor[
              0.9566249031529177, 0.8918326528978909, 0.6020286851109866], 
             UndirectedEdge[169, 190] -> 
             RGBColor[
              0.9608400440218933, 0.9703151494668467, 0.9511717703053815], 
             UndirectedEdge[121, 152] -> 
             RGBColor[
              0.9935205553827502, 0.9915885973837053, 0.7570446957803749], 
             UndirectedEdge[31, 64] -> 
             RGBColor[
              0.9395842780462302, 0.9505464555244922, 0.7985256632601538], 
             UndirectedEdge[105, 134] -> 
             RGBColor[
              0.9913891558341513, 0.9820640997663095, 0.46795660672352013`], 
             UndirectedEdge[83, 192] -> 
             RGBColor[
              0.9664337699388261, 0.8992605340326174, 0.5372694831660678], 
             UndirectedEdge[77, 112] -> 
             RGBColor[
              0.9168009627947554, 0.6757865979402429, 0.28979644142944977`], 
             UndirectedEdge[195, 196] -> 
             RGBColor[
              0.9214109160901707, 0.8944710892319108, 0.6459616702073956], 
             UndirectedEdge[92, 171] -> 
             RGBColor[
              0.963280420702223, 0.9711955471202951, 0.9049622406853031], 
             UndirectedEdge[166, 183] -> 
             RGBColor[
              0.8714359729853831, 0.43833813466193455`, 0.2115871783561839], 
             UndirectedEdge[139, 195] -> 
             RGBColor[
              0.9370385604024551, 0.9498178527381902, 0.8825531644680245], 
             UndirectedEdge[177, 190] -> 
             RGBColor[
              0.9740487579192327, 0.9646582743276237, 0.6678135071579436], 
             UndirectedEdge[29, 149] -> 
             RGBColor[
              0.9875399102365694, 0.9685780222004822, 0.49566126719177567`], 
             UndirectedEdge[119, 155] -> 
             RGBColor[
              0.9626034313604772, 0.8927020713134456, 0.5764057125636923], 
             UndirectedEdge[12, 162] -> 
             RGBColor[
              0.5777131757305913, 0.6188914678215988, 0.6483529237310663], 
             UndirectedEdge[85, 173] -> 
             RGBColor[
              0.9576135069305199, 0.9662402753033743, 0.8852329200367068], 
             UndirectedEdge[92, 141] -> 
             RGBColor[
              0.9547966744914168, 0.9362511401699731, 0.6705789754655058], 
             UndirectedEdge[5, 29] -> 
             RGBColor[
              0.9677678003417097, 0.8975536334098185, 0.44139283572102644`], 
             UndirectedEdge[51, 87] -> 
             RGBColor[
              0.9931135000159643, 0.9910711504752725, 0.738413386937905], 
             UndirectedEdge[145, 153] -> 
             RGBColor[
              0.9554346558307811, 0.8481633438650524, 0.4606708914878786], 
             UndirectedEdge[118, 191] -> 
             RGBColor[
              0.967002022791331, 0.9737310971687355, 0.8879141906297428], 
             UndirectedEdge[117, 164] -> 
             RGBColor[
              0.9913938199826946, 0.9887662285102101, 0.6510612217443666], 
             UndirectedEdge[145, 185] -> 
             RGBColor[
              0.894436459809656, 0.6101169394940813, 0.23345033549723554`], 
             UndirectedEdge[99, 137] -> 
             RGBColor[
              0.5418157478640606, 0.4826430557229906, 0.5878411021355557], 
             UndirectedEdge[48, 176] -> 
             RGBColor[
              0.9665701367063317, 0.8988953627845933, 0.3246317231144088], 
             UndirectedEdge[50, 144] -> 
             RGBColor[
              0.9829939253832876, 0.953823646592685, 0.42865655744521125`], 
             UndirectedEdge[3, 53] -> 
             RGBColor[
              0.9941976038972673, 0.9899975863855188, 0.6098231763345527], 
             UndirectedEdge[169, 177] -> 
             RGBColor[
              0.9703656231489223, 0.961911398446506, 0.674048093608683], 
             UndirectedEdge[20, 135] -> 
             RGBColor[
              0.921050394693069, 0.6824735100023689, 0.3458596522036224], 
             UndirectedEdge[166, 170] -> 
             RGBColor[
              0.9125622447499069, 0.6897044643993784, 0.24843436485866224`], 
             UndirectedEdge[17, 42] -> 
             RGBColor[
              0.9577888738296662, 0.8624037340063578, 0.5176755287948294], 
             UndirectedEdge[129, 195] -> 
             RGBColor[
              0.9241905183067498, 0.9038473401900691, 0.6567598999349713], 
             UndirectedEdge[74, 93] -> 
             RGBColor[
              0.9901725661276191, 0.9779604370822144, 0.4632150740292248], 
             UndirectedEdge[37, 45] -> 
             RGBColor[
              0.9043262814214819, 0.8908718959006628, 0.659078195820484], 
             UndirectedEdge[49, 92] -> 
             RGBColor[
              0.9654430373193675, 0.9720898446681964, 0.8691220866668181], 
             UndirectedEdge[163, 177] -> 
             RGBColor[
              0.9707329660116829, 0.9129375635103452, 0.34080352888134646`], 
             UndirectedEdge[6, 45] -> 
             RGBColor[
              0.9817242955753145, 0.9487344952249197, 0.49229403207594113`], 
             UndirectedEdge[6, 166] -> 
             RGBColor[
              0.9600644848156028, 0.8666781286593529, 0.4549840944660617], 
             UndirectedEdge[65, 127] -> 
             RGBColor[
              0.9843309642817423, 0.9588068046370823, 0.39362918439402284`], 
             UndirectedEdge[15, 59] -> 
             RGBColor[
              0.9940863224729721, 0.9897595666712293, 0.5977108800493669], 
             UndirectedEdge[100, 136] -> 
             RGBColor[
              0.9454168115949402, 0.8339371823111706, 0.5825681164558809], 
             UndirectedEdge[83, 183] -> 
             RGBColor[
              0.8796979669142815, 0.47109418744374804`, 0.21823497260529817`],
              UndirectedEdge[53, 119] -> 
             RGBColor[
              0.9671469648955753, 0.8943537433538135, 0.4845928644411191], 
             UndirectedEdge[5, 68] -> 
             RGBColor[
              0.9637197050679422, 0.8849517681520027, 0.33610081627924204`], 
             UndirectedEdge[49, 54] -> 
             RGBColor[
              0.9934413971182277, 0.9893368407435954, 0.597057030639435], 
             UndirectedEdge[153, 185] -> 
             RGBColor[
              0.9337520619106225, 0.7531332531124069, 0.44275560141172765`], 
             UndirectedEdge[101, 144] -> 
             RGBColor[
              0.5758227137485741, 0.6125144956546724, 0.6410088359147188], 
             UndirectedEdge[19, 102] -> 
             RGBColor[
              0.9841191984647972, 0.9582367877754416, 0.5514993711816727], 
             UndirectedEdge[102, 172] -> 
             RGBColor[
              0.5864762528772485, 0.6485957036695277, 0.841088680675429], 
             UndirectedEdge[102, 140] -> 
             RGBColor[
              0.9866059027706167, 0.9666250253049076, 0.5611597478350763], 
             UndirectedEdge[71, 107] -> 
             RGBColor[
              0.551938652653643, 0.5227769999556328, 0.5959862289443685], 
             UndirectedEdge[5, 168] -> 
             RGBColor[
              0.5601264583820292, 0.5552389212441687, 0.60257432962593], 
             UndirectedEdge[79, 122] -> 
             RGBColor[
              0.9650179244048367, 0.8919661512179702, 0.5279042954254434], 
             UndirectedEdge[136, 198] -> 
             RGBColor[
              0.9521598332015921, 0.8360722744747311, 0.4052218479752768], 
             UndirectedEdge[97, 135] -> 
             RGBColor[
              0.9212342444824739, 0.6828667461118408, 0.3658705671909603], 
             UndirectedEdge[19, 164] -> 
             RGBColor[
              0.9819853460884236, 0.9573543849803063, 0.5868628272911153], 
             UndirectedEdge[118, 139] -> 
             RGBColor[
              0.9675283465640463, 0.9739487455746573, 0.8791916436335887], 
             UndirectedEdge[26, 137] -> 
             RGBColor[
              0.9194080289220061, 0.8050956657835231, 0.6178793965143013], 
             UndirectedEdge[142, 168] -> 
             RGBColor[
              0.5754254447708884, 0.6419877316537222, 0.9329553554850567], 
             UndirectedEdge[3, 194] -> 
             RGBColor[
              0.9928178071525352, 0.9896542008122942, 0.6492047183524046], 
             UndirectedEdge[65, 195] -> 
             RGBColor[
              0.9332739773003913, 0.934487980273218, 0.6920474228579709], 
             UndirectedEdge[73, 107] -> 
             RGBColor[
              0.5836365816878143, 0.6474214266564758, 0.8881493811178183], 
             UndirectedEdge[162, 172] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[68, 140] -> 
             RGBColor[
              0.9826498965792811, 0.9531361685432138, 0.3870985538129593], 
             UndirectedEdge[38, 165] -> 
             RGBColor[
              0.9701566598277078, 0.9083918700380118, 0.36241108003396916`], 
             UndirectedEdge[86, 92] -> 
             RGBColor[
              0.9375794945047946, 0.8729934723808861, 0.6306714109916853], 
             UndirectedEdge[90, 115] -> 
             RGBColor[
              0.980277628026345, 0.9434580125018333, 0.5203923387868666], 
             UndirectedEdge[11, 70] -> 
             RGBColor[
              0.9949722636082245, 0.9917035513746442, 0.69770524602686], 
             UndirectedEdge[54, 123] -> 
             RGBColor[
              0.9921383583947332, 0.9887980007448627, 0.6186517544438579], 
             UndirectedEdge[107, 176] -> 
             RGBColor[
              0.5700307423446986, 0.5929768160898428, 0.6185081207326848], 
             UndirectedEdge[30, 76] -> 
             RGBColor[
              0.9753306919213427, 0.9800634662321344, 0.8792283405566779], 
             UndirectedEdge[129, 191] -> 
             RGBColor[
              0.9789707512821391, 0.9449143625132669, 0.5594540316875043], 
             UndirectedEdge[7, 125] -> 
             RGBColor[
              0.9646835022092941, 0.9695085716743198, 0.7169090818066014], 
             UndirectedEdge[3, 155] -> 
             RGBColor[
              0.9896540703621692, 0.988345914345151, 0.7016360244571259], 
             UndirectedEdge[54, 118] -> 
             RGBColor[
              0.9677106762757213, 0.9718051209326394, 0.7148704460178683], 
             UndirectedEdge[4, 171] -> 
             RGBColor[
              0.9909221908807697, 0.9905141068872145, 0.8001063199299677], 
             UndirectedEdge[167, 189] -> 
             RGBColor[
              0.9924739568050567, 0.9907900732189994, 0.7478049229564792], 
             UndirectedEdge[42, 81] -> 
             RGBColor[
              0.9907396059586913, 0.9904386033297167, 0.8031322246034398], 
             UndirectedEdge[5, 129] -> 
             RGBColor[
              0.9539874748616038, 0.8521226704297025, 0.29829293970507853`], 
             UndirectedEdge[115, 133] -> 
             RGBColor[
              0.95546788775061, 0.9268416118558698, 0.648405481390506], 
             UndirectedEdge[92, 146] -> 
             RGBColor[
              0.9517650363827639, 0.9260247129670081, 0.6588016338902076], 
             UndirectedEdge[65, 151] -> 
             RGBColor[
              0.9287849084179648, 0.7377648136394006, 0.3055241557126905], 
             UndirectedEdge[45, 156] -> 
             RGBColor[
              0.9669591744295323, 0.90020767837535, 0.32614306120543335`], 
             UndirectedEdge[74, 172] -> 
             RGBColor[
              0.5861617683735301, 0.6468390923757693, 0.7280664803239516], 
             UndirectedEdge[31, 138] -> 
             RGBColor[
              0.9918035747368881, 0.9899299004817212, 0.7165403941799555], 
             UndirectedEdge[116, 198] -> 
             RGBColor[
              0.9936622807861228, 0.9903450437555359, 0.6600426006989497], 
             UndirectedEdge[42, 142] -> 
             RGBColor[
              0.9820845260540867, 0.9848213264927436, 0.8552954831641375], 
             UndirectedEdge[10, 129] -> 
             RGBColor[
              0.9496275670775424, 0.9241301524096039, 0.6591861083546511], 
             UndirectedEdge[3, 141] -> 
             RGBColor[
              0.9831284291464296, 0.954211234131292, 0.43480189205578873`], 
             UndirectedEdge[161, 162] -> 
             RGBColor[
              0.5622797283440067, 0.632183677866689, 0.9552076244438137], 
             UndirectedEdge[6, 77] -> 
             RGBColor[
              0.9234354331473341, 0.6968868204967453, 0.4243613693129288], 
             UndirectedEdge[98, 113] -> 
             RGBColor[
              0.5539132855555702, 0.5306057614043673, 0.5975750649278506], 
             UndirectedEdge[3, 139] -> 
             RGBColor[
              0.9928608417183873, 0.989671996711212, 0.6484915242263491], 
             UndirectedEdge[34, 138] -> 
             RGBColor[
              0.982244657060874, 0.9854093113280595, 0.8760074700640632], 
             UndirectedEdge[22, 72] -> 
             RGBColor[
              0.9645010179838852, 0.9695374467633364, 0.7303077649399374], 
             UndirectedEdge[34, 40] -> 
             RGBColor[
              0.9843682258374915, 0.98489850981873, 0.739852308534189], 
             UndirectedEdge[41, 74] -> 
             RGBColor[
              0.9937978230287076, 0.9891424955317157, 0.5663094959533574], 
             UndirectedEdge[141, 146] -> 
             RGBColor[
              0.9698486538979914, 0.909954571104505, 0.3373681433079847], 
             UndirectedEdge[90, 111] -> 
             RGBColor[
              0.9765550617251457, 0.9309009222677551, 0.5059308716543671], 
             UndirectedEdge[66, 82] -> 
             RGBColor[
              0.5738606030158988, 0.6408206752350442, 0.9356042244001594], 
             UndirectedEdge[119, 151] -> 
             RGBColor[
              0.9060145770861642, 0.6560203163165694, 0.242766360431256], 
             UndirectedEdge[4, 139] -> 
             RGBColor[
              0.9921708572419212, 0.9910304625168125, 0.7794126868807307], 
             UndirectedEdge[165, 175] -> 
             RGBColor[
              0.9929889361299846, 0.987412368246358, 0.4782671488986534], 
             UndirectedEdge[127, 139] -> 
             RGBColor[
              0.988095547383806, 0.9741366771020545, 0.5841349260040765], 
             UndirectedEdge[85, 117] -> 
             RGBColor[
              0.9579989024029121, 0.9644567371044548, 0.7376169362579448], 
             UndirectedEdge[141, 155] -> 
             RGBColor[
              0.9794059332223839, 0.954315678521329, 0.6159796172846199], 
             UndirectedEdge[168, 189] -> 
             RGBColor[
              0.5845084276178132, 0.6477819573539487, 0.8737006377927969], 
             UndirectedEdge[24, 175] -> 
             RGBColor[
              0.99402504207632, 0.9896284940991891, 0.5910408870525579], 
             UndirectedEdge[106, 176] -> 
             RGBColor[
              0.9727391117865007, 0.9341766900537837, 0.6063217677382006], 
             UndirectedEdge[40, 53] -> 
             RGBColor[
              0.9943453054779108, 0.9903135051315949, 0.6258995818791073], 
             UndirectedEdge[27, 155] -> 
             RGBColor[
              0.5824292872190617, 0.6469221793675941, 0.9081573748429785], 
             UndirectedEdge[33, 77] -> 
             RGBColor[
              0.9134492594717416, 0.6917733484447675, 0.562792218689601], 
             UndirectedEdge[67, 137] -> 
             RGBColor[
              0.9492883536644494, 0.8258130638564967, 0.4966990232308247], 
             UndirectedEdge[68, 129] -> 
             RGBColor[
              0.9763812631654876, 0.9319905960933677, 0.3627460967324606], 
             UndirectedEdge[137, 192] -> 
             RGBColor[
              0.9477475508886052, 0.82517590231186, 0.5222341126963252], 
             UndirectedEdge[58, 128] -> 
             RGBColor[
              0.9857076250325199, 0.9863815609727623, 0.7759986544298422], 
             UndirectedEdge[55, 90] -> 
             RGBColor[
              0.9836941565164211, 0.9854730461156325, 0.8264689954259119], 
             UndirectedEdge[26, 82] -> 
             RGBColor[
              0.5565192810579456, 0.6278466100605326, 0.9635392943787455], 
             UndirectedEdge[43, 165] -> 
             RGBColor[
              0.9933359331123423, 0.9881545597048442, 0.5160356290111328], 
             UndirectedEdge[123, 199] -> 
             RGBColor[
              0.5852469701077784, 0.6480873636532256, 0.8614610774473765], 
             UndirectedEdge[34, 45] -> 
             RGBColor[
              0.9719685248588352, 0.9437928573225984, 0.6303348693415506], 
             UndirectedEdge[133, 178] -> 
             RGBColor[
              0.9460410011828562, 0.892239108969264, 0.6263839670174673], 
             UndirectedEdge[29, 189] -> 
             RGBColor[
              0.9921497695774937, 0.9900966695195985, 0.7125191438878935], 
             UndirectedEdge[91, 164] -> 
             RGBColor[
              0.9893254432104592, 0.9898538106909979, 0.8265685610775193], 
             UndirectedEdge[116, 124] -> 
             RGBColor[
              0.9939838356631783, 0.9917801756854225, 0.7493669426027477], 
             UndirectedEdge[80, 113] -> 
             RGBColor[
              0.9612653191613475, 0.8723016722545796, 0.4049041421047787], 
             UndirectedEdge[10, 75] -> 
             RGBColor[
              0.9471934949054739, 0.9600578181360219, 0.9715065811859029], 
             UndirectedEdge[74, 180] -> 
             RGBColor[
              0.9937978230287076, 0.9891424955317157, 0.5663094959533574], 
             UndirectedEdge[27, 149] -> 
             RGBColor[
              0.5798985682768889, 0.6262633100348323, 0.6568427610966792], 
             UndirectedEdge[4, 49] -> 
             RGBColor[
              0.9930848074979142, 0.9914084044351159, 0.7642661659114828], 
             UndirectedEdge[9, 152] -> 
             RGBColor[
              0.966144436044257, 0.9728027981051126, 0.87643673589204], 
             UndirectedEdge[19, 85] -> 
             RGBColor[
              0.9485904285086411, 0.933044893574551, 0.6734185418046934], 
             UndirectedEdge[189, 197] -> 
             RGBColor[
              0.9570474668393784, 0.8632912025404837, 0.5358055908760527], 
             UndirectedEdge[69, 195] -> 
             RGBColor[
              0.9198117993157273, 0.8890768928612389, 0.6397494035065467], 
             UndirectedEdge[75, 191] -> 
             RGBColor[
              0.9765366791100707, 0.9808420282396848, 0.8717745045187562], 
             UndirectedEdge[73, 75] -> 
             RGBColor[
              0.9750635259953204, 0.9802328415684274, 0.8961884640282187], 
             UndirectedEdge[68, 188] -> 
             RGBColor[
              0.9651036082923456, 0.9613227323213627, 0.6900364483008563], 
             UndirectedEdge[4, 123] -> 
             RGBColor[
              0.9917817687744197, 0.9908695644363832, 0.7858608897159056], 
             UndirectedEdge[7, 84] -> 
             RGBColor[
              0.5578200284880946, 0.6288576410162381, 0.9627567330238644], 
             UndirectedEdge[171, 195] -> 
             RGBColor[
              0.9357898940413035, 0.9493014971085924, 0.9032467975172616], 
             UndirectedEdge[62, 167] -> 
             RGBColor[
              0.9949041009248321, 0.9915087120896731, 0.686721017790717], 
             UndirectedEdge[91, 152] -> 
             RGBColor[
              0.9909616791801446, 0.9905304363138091, 0.7994518966168842], 
             UndirectedEdge[38, 90] -> 
             RGBColor[
              0.9714099203427564, 0.9110724675556254, 0.49882075286964256`], 
             UndirectedEdge[3, 118] -> 
             RGBColor[
              0.9680440711318739, 0.9725182188185593, 0.7511584186355342], 
             UndirectedEdge[143, 181] -> 
             RGBColor[
              0.9940726369866433, 0.9897302947997868, 0.5962212993195], 
             UndirectedEdge[20, 50] -> 
             RGBColor[
              0.9932162588558966, 0.9878985885712306, 0.5030098247409328], 
             UndirectedEdge[128, 136] -> 
             RGBColor[
              0.9437976666401904, 0.8327296266550248, 0.585308906523635], 
             UndirectedEdge[19, 161] -> 
             RGBColor[
              0.9599226739315556, 0.941824761972603, 0.6656183149500574], 
             UndirectedEdge[19, 140] -> 
             RGBColor[
              0.976699595480917, 0.9330644057412938, 0.36398275766589105`], 
             UndirectedEdge[39, 159] -> 
             RGBColor[
              0.9413058675773228, 0.8050043541439258, 0.2716315272055975], 
             UndirectedEdge[87, 154] -> 
             RGBColor[
              0.9658996769638001, 0.9728994633686843, 0.8893544725887454], 
             UndirectedEdge[104, 143] -> 
             RGBColor[
              0.9935046529753015, 0.9911232945764261, 0.7239636474394426], 
             UndirectedEdge[6, 183] -> 
             RGBColor[
              0.9059475118302196, 0.5624669939974183, 0.40761491610987777`], 
             UndirectedEdge[17, 89] -> 
             RGBColor[
              0.9474674910290478, 0.8248083183015955, 0.300675453094421], 
             UndirectedEdge[131, 176] -> 
             RGBColor[
              0.9631071957179249, 0.8872140496934864, 0.31117885129598144`], 
             UndirectedEdge[44, 143] -> 
             RGBColor[
              0.9934471745810374, 0.9910995257832707, 0.7249162131817148], 
             UndirectedEdge[140, 173] -> 
             RGBColor[
              0.985722673902796, 0.9662597874701171, 0.5757971358979046], 
             UndirectedEdge[123, 195] -> 
             RGBColor[
              0.9366494719349536, 0.9496569546577609, 0.8890013673031993], 
             UndirectedEdge[96, 125] -> 
             RGBColor[
              0.989666585261364, 0.9877276959892987, 0.6561144871987097], 
             UndirectedEdge[95, 159] -> 
             RGBColor[
              0.8923267891075304, 0.5578846119792356, 0.2299057937708771], 
             UndirectedEdge[171, 191] -> 
             RGBColor[
              0.9905701270166929, 0.9903685194317902, 0.8059409292697945], 
             UndirectedEdge[124, 187] -> 
             RGBColor[
              0.5866713423687928, 0.6486763781878524, 0.8378555429251195], 
             UndirectedEdge[54, 191] -> 
             RGBColor[
              0.9920011230895194, 0.9887412504193702, 0.620926098604837], 
             UndirectedEdge[24, 55] -> 
             RGBColor[
              0.9834770019477079, 0.9850085744508499, 0.802833060744143], 
             UndirectedEdge[61, 126] -> 
             RGBColor[
              0.8907796291254683, 0.8457294867461307, 0.6293594985158789], 
             UndirectedEdge[46, 101] -> 
             RGBColor[
              0.5870335425786432, 0.6487037292506135, 0.8229537225837482], 
             UndirectedEdge[158, 176] -> 
             RGBColor[
              0.9309026400994979, 0.7612053690807167, 0.27117242863401503`], 
             UndirectedEdge[91, 200] -> 
             RGBColor[
              0.9862011297619495, 0.972854866518861, 0.6120852666618398], 
             UndirectedEdge[29, 129] -> 
             RGBColor[
              0.980429358439255, 0.9445924613511836, 0.46803811617424507`], 
             UndirectedEdge[37, 47] -> 
             RGBColor[
              0.8440940220794845, 0.8785216771570659, 0.9849916354292121], 
             UndirectedEdge[25, 38] -> 
             RGBColor[
              0.961379091802339, 0.8789120647154359, 0.3173432778164078], 
             UndirectedEdge[95, 173] -> 
             RGBColor[
              0.9146556570107953, 0.6384362306693989, 0.48053286764313496`], 
             UndirectedEdge[86, 174] -> 
             RGBColor[
              0.9661067141981527, 0.8913716462946786, 0.4161694907354574], 
             UndirectedEdge[4, 146] -> 
             RGBColor[
              0.9794068065613105, 0.9453432727339275, 0.5539457131348723], 
             UndirectedEdge[114, 186] -> 
             RGBColor[
              0.9629369461501297, 0.8785760701394643, 0.42714055689990793`], 
             UndirectedEdge[155, 199] -> 
             RGBColor[
              0.5824292872190617, 0.646922179367594, 0.9081573748429785], 
             UndirectedEdge[114, 194] -> 
             RGBColor[
              0.993138426165399, 0.9903399724612552, 0.6841021192714414], 
             UndirectedEdge[59, 186] -> 
             RGBColor[
              0.963027598649336, 0.8787699666688928, 0.4370075219961298], 
             UndirectedEdge[99, 193] -> 
             RGBColor[
              0.5863866160232505, 0.6473200187629367, 0.7525397593971658], 
             UndirectedEdge[109, 136] -> 
             RGBColor[
              0.9165094181212203, 0.7066946949774287, 0.2516797219257415], 
             UndirectedEdge[50, 134] -> 
             RGBColor[
              0.9913254532153668, 0.9819278463060523, 0.461022969795827], 
             UndirectedEdge[112, 183] -> 
             RGBColor[
              0.8993130414776409, 0.541366771440916, 0.27304998822639875`], 
             UndirectedEdge[42, 73] -> 
             RGBColor[
              0.9902956629710125, 0.9902550214954972, 0.8104895087968991], 
             UndirectedEdge[42, 147] -> 
             RGBColor[
              0.9931139431453535, 0.991420452774084, 0.7637833128327743], 
             UndirectedEdge[87, 131] -> 
             RGBColor[
              0.978214797471226, 0.9422796776102644, 0.555932022107811], 
             UndirectedEdge[1, 11] -> 
             RGBColor[
              0.5868231900367249, 0.648253806433355, 0.8000581465413696], 
             UndirectedEdge[30, 81] -> 
             RGBColor[
              0.9746652230114683, 0.9797882777361304, 0.8902568825716302], 
             UndirectedEdge[154, 188] -> 
             RGBColor[
              0.9422716944722332, 0.956466904775592, 0.9826031426917752], 
             UndirectedEdge[83, 156] -> 
             RGBColor[
              0.9535613575987189, 0.8509073645915967, 0.2954809178446681], 
             UndirectedEdge[5, 107] -> 
             RGBColor[
              0.5601264583820292, 0.5552389212441687, 0.60257432962593], 
             UndirectedEdge[93, 180] -> 
             RGBColor[
              0.9905738524092664, 0.9788187478623913, 0.5068926093346792], 
             UndirectedEdge[10, 17] -> 
             RGBColor[
              0.9279693431444358, 0.8414225423914068, 0.625301899391251], 
             UndirectedEdge[75, 141] -> 
             RGBColor[
              0.9673305903108282, 0.9455989140656866, 0.6493623253520419], 
             UndirectedEdge[123, 141] -> 
             RGBColor[
              0.9822236161111005, 0.9554808628069607, 0.5692833198890179], 
             UndirectedEdge[40, 119] -> 
             RGBColor[
              0.9664736288651665, 0.8929135456694846, 0.41130439287941556`], 
             UndirectedEdge[16, 80] -> 
             RGBColor[
              0.9937976168812945, 0.9891420546032437, 0.5662870580796335], 
             UndirectedEdge[88, 180] -> 
             RGBColor[
              0.9941860634864503, 0.9909296068079048, 0.6781093692723597], 
             UndirectedEdge[24, 41] -> 
             RGBColor[
              0.9944916643230579, 0.9906265519022155, 0.6418298389512802], 
             UndirectedEdge[4, 119] -> 
             RGBColor[
              0.9656359428080568, 0.8939560927290091, 0.5261491499892427], 
             UndirectedEdge[99, 136] -> 
             RGBColor[
              0.5447370457098548, 0.4942250282167653, 0.5901916469539554], 
             UndirectedEdge[10, 194] -> 
             RGBColor[
              0.9624325746073955, 0.9700828690588075, 0.8856925670137596], 
             UndirectedEdge[96, 102] -> 
             RGBColor[
              0.990352364417413, 0.9902784690007445, 0.8095498190914016], 
             UndirectedEdge[9, 88] -> 
             RGBColor[
              0.9667158084049698, 0.9730390752598672, 0.8669676172107574], 
             UndirectedEdge[55, 108] -> 
             RGBColor[
              0.9834995894948315, 0.985056886930196, 0.8052915758543653], 
             UndirectedEdge[62, 197] -> 
             RGBColor[
              0.9594776109591536, 0.8640098414111573, 0.4747216857102906], 
             UndirectedEdge[147, 168] -> 
             RGBColor[
              0.5864548618621553, 0.6485868579350627, 0.8414431851536934], 
             UndirectedEdge[51, 106] -> 
             RGBColor[
              0.9896105253597669, 0.9896225804325924, 0.7964667423989065], 
             UndirectedEdge[123, 155] -> 
             RGBColor[
              0.9887492573268402, 0.9896155430208196, 0.8361174522903552], 
             UndirectedEdge[75, 142] -> 
             RGBColor[
              0.9668523890783945, 0.9747991465656738, 0.9409944383954572], 
             UndirectedEdge[31, 182] -> 
             RGBColor[
              0.5865546587897544, 0.6476794452487586, 0.7708301774913795], 
             UndirectedEdge[65, 140] -> 
             RGBColor[
              0.9820011253665843, 0.9509477109040626, 0.3845782001617955]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 71 -> 
             RGBColor[
              0.9249503053072858, 0.7401599999112656, 0.25847145788873693`], 
             10 -> RGBColor[
              0.9326061011959356, 0.9490988064481406, 0.993433996551005], 68 -> 
             RGBColor[
              0.9861134933718259, 0.9648196938156679, 0.40055397330662407`], 
             155 -> RGBColor[
              0.9859315744381235, 0.988450358735188, 0.8828137496859572], 132 -> 
             RGBColor[
              0.9925230337829045, 0.9864158502359067, 0.4275565536349824], 26 -> 
             RGBColor[
              0.9341115621158911, 0.950299220121065, 0.9935775887574911], 29 -> 
             RGBColor[
              0.9942096839193609, 0.9900234243312996, 0.6111380121901929], 
             113 -> RGBColor[
              0.9288995711111405, 0.7558175228087346, 0.2616491298557012], 50 -> 
             RGBColor[
              0.993269423269427, 0.9880123018760253, 0.508796443060985], 173 -> 
             RGBColor[
              0.9922590480188554, 0.9910669316694745, 0.7779511374765145], 
             192 -> RGBColor[
              0.9907906060490893, 0.9904596931777389, 0.8022870211215392], 
             165 -> RGBColor[
              0.9927120074430902, 0.9868200457868759, 0.4481251703359397], 92 -> 
             RGBColor[
              0.9367130569761893, 0.9523212820324761, 0.9920124660477287], 11 -> 
             RGBColor[
              0.99471938007345, 0.9911136128667098, 0.6666152930827394], 137 -> 
             RGBColor[
              0.9047044957281211, 0.6598921114459811, 0.2421812042711115], 
             120 -> RGBColor[
              0.9309365217215337, 0.7638933532053912, 0.26328810813019965`], 
             51 -> RGBColor[
              0.9948773118359295, 0.9914514129373031, 0.6838051907867815], 72 -> 
             RGBColor[
              0.9361112477189121, 0.9518724536737709, 0.9930311721433069], 64 -> 
             RGBColor[
              0.8849862385129518, 0.9111280205514672, 0.9888919715375487], 41 -> 
             RGBColor[
              0.9941991093103549, 0.9900008063118928, 0.6099870312588118], 
             103 -> RGBColor[0.178927, 0.305394, 0.933501], 162 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 196 -> 
             RGBColor[
              0.961089828525991, 0.8804089964547508, 0.3033417607031456], 179 -> 
             RGBColor[
              0.9939306437266109, 0.9894265855742984, 0.5807662092458022], 
             160 -> RGBColor[
              0.9878443796252228, 0.9892413528369046, 0.8511136175545813], 
             123 -> RGBColor[
              0.9915669402155568, 0.9907807273064512, 0.7894211548947532], 
             150 -> RGBColor[
              0.9109772437013233, 0.9318525425816333, 0.9913710168148598], 
             188 -> RGBColor[
              0.9440937232128654, 0.9578257708270573, 0.9795189232950884], 46 -> 
             RGBColor[
              0.9951400851572862, 0.9920134585012269, 0.7124064451674964], 
             182 -> RGBColor[0.178927, 0.305394, 0.933501], 6 -> 
             RGBColor[
              0.9945760236604393, 0.9908069879948367, 0.6510118322197556], 
             131 -> RGBColor[
              0.9650799067464528, 0.8938684672072872, 0.3188424611265932], 45 -> 
             RGBColor[
              0.9688725674901897, 0.9066620024550027, 0.33357623193212677`], 
             195 -> RGBColor[
              0.8817320036543504, 0.9085331820090706, 0.9885815797116455], 
             148 -> RGBColor[
              0.9109772437013233, 0.9318525425816333, 0.9913710168148598], 
             161 -> RGBColor[
              0.9456324566880135, 0.958973355733378, 0.9769142488876273], 1 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 101 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 12 -> 
             RGBColor[
              0.9764993514611826, 0.9323889356431976, 0.3632048474621326], 39 -> 
             RGBColor[
              0.9350104229423202, 0.7800450139987039, 0.26656606467919636`], 
             48 -> RGBColor[
              0.9720057887232664, 0.9172310933895012, 0.345748204763448], 77 -> 
             RGBColor[
              0.8522948426342289, 0.4029666529986539, 0.19771090640610198`], 
             56 -> RGBColor[
              0.742298368978181, 0.7986083946130913, 0.9749490223132425], 110 -> 
             RGBColor[
              0.9938240577031828, 0.9917141033928581, 0.7520148768919779], 73 -> 
             RGBColor[
              0.9883461633756286, 0.9894488533129516, 0.8427977622356364], 37 -> 
             RGBColor[
              0.8397799953527741, 0.875081789346323, 0.9845801597088413], 130 -> 
             RGBColor[
              0.9935024480087493, 0.9885107182310205, 0.5341597478742262], 
             107 -> RGBColor[0.178927, 0.305394, 0.933501], 59 -> 
             RGBColor[
              0.9941991093103549, 0.9900008063118928, 0.6099870312588118], 47 -> 
             RGBColor[
              0.8484080488061948, 0.8819615649678086, 0.9854031111495828], 
             159 -> RGBColor[
              0.9476013122123255, 0.8299636942891477, 0.2766969897319987], 55 -> 
             RGBColor[
              0.972169784559655, 0.9787648514091618, 0.9319934748445374], 49 -> 
             RGBColor[
              0.9941730176625457, 0.9918584073039166, 0.7462317072859076], 82 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 199 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 89 -> 
             RGBColor[
              0.9716023969651597, 0.9158703582685181, 0.3441811039573449], 
             144 -> RGBColor[
              0.972718427497148, 0.9196349913093449, 0.3485166718294375], 78 -> 
             RGBColor[
              0.9949651075502268, 0.9916391990926766, 0.6933612124756972], 42 -> 
             RGBColor[
              0.9922451625663964, 0.9910611896780427, 0.7781812553581617], 
             154 -> RGBColor[
              0.940449665731601, 0.9551080387241269, 0.9856873620884621], 168 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 121 -> 
             RGBColor[
              0.9940108378243803, 0.9917913417730034, 0.7489194469122771], 
             128 -> RGBColor[
              0.9770482418606712, 0.982403196876519, 0.9237355191393591], 115 -> 
             RGBColor[
              0.9653367275795026, 0.8947347841815634, 0.31984016156644685`], 
             61 -> 
             RGBColor[
              0.8367818601742055, 0.8726911577371438, 0.9842941948990426], 93 -> 
             RGBColor[
              0.9869485955081779, 0.9676366894128899, 0.40379818741054646`], 
             88 -> RGBColor[
              0.9941730176625457, 0.9918584073039166, 0.7462317072859076], 21 -> 
             RGBColor[
              0.98141971126901, 0.9856634316036338, 0.9163357616928639], 62 -> 
             RGBColor[
              0.9949501434751769, 0.9916071924492447, 0.6917324652540697], 
             136 -> RGBColor[
              0.9105470914197095, 0.6830560564335305, 0.2468822939079107], 
             190 -> RGBColor[
              0.9645231787922037, 0.9730620253479645, 0.9449371838546421], 57 -> 
             RGBColor[
              0.9935503129869663, 0.9886130965795349, 0.5393695553647299], 
             111 -> RGBColor[
              0.9578915949771041, 0.8696206037134071, 0.29091722730144787`], 
             63 -> RGBColor[
              0.9527977126734753, 0.8505656905198038, 0.2808781355182355], 75 -> 
             RGBColor[
              0.9617808886150122, 0.9710168298239031, 0.9495791658208009], 30 -> 
             RGBColor[
              0.9600963966719507, 0.9697605384908702, 0.9524305712945426], 5 -> 
             RGBColor[
              0.9413259167640585, 0.8050838424883374, 0.27164765925185996`], 
             171 -> RGBColor[
              0.9898477844282566, 0.9900698122081141, 0.8179120153228775], 
             102 -> RGBColor[
              0.9940255057544969, 0.9917974073390553, 0.7486763613508579], 31 -> 
             RGBColor[
              0.9941823175795088, 0.9899648904975172, 0.6081593549827591], 96 -> 
             RGBColor[
              0.9866792230803293, 0.9887595306624337, 0.8704232768319452], 70 -> 
             RGBColor[
              0.9952251471429993, 0.9922934898825784, 0.7287951989709806], 52 -> 
             RGBColor[
              0.9946134855165268, 0.9920405520810452, 0.7389320150511745], 
             183 -> RGBColor[0.817319, 0.134127, 0.164218], 158 -> 
             RGBColor[
              0.9006707955095986, 0.6418511059817479, 0.23882961580266035`], 
             13 -> RGBColor[
              0.9940108378243803, 0.9917913417730034, 0.7489194469122771], 
             170 -> RGBColor[
              0.8995715435290473, 0.6368596594748875, 0.2379123730049567], 86 -> 
             RGBColor[0.9384459320334, 0.7936656627292961, 0.269330355935642],
              18 -> RGBColor[0.178927, 0.305394, 0.933501], 153 -> 
             RGBColor[
              0.9947502579317475, 0.9911796574833779, 0.6699761574023707], 58 -> 
             RGBColor[
              0.9943670082043685, 0.9903599250690056, 0.6282617897203252], 22 -> 
             RGBColor[
              0.9928907882488583, 0.9872024398529018, 0.4675843577365679], 66 -> 
             RGBColor[
              0.9687942060317976, 0.9762473504700884, 0.9377074488003188], 
             143 -> RGBColor[
              0.9947502579317475, 0.9911796574833779, 0.6699761574023707], 
             119 -> RGBColor[
              0.9392752882828309, 0.7969537838917031, 0.2699976754414274], 
             145 -> RGBColor[
              0.9161190537298146, 0.7051470302467269, 0.2513656255733865], 91 -> 
             RGBColor[
              0.988893085419169, 0.9896750196332109, 0.8337338485852958], 177 -> 
             RGBColor[
              0.9835743370462617, 0.9562545233072831, 0.39068983046124506`], 
             200 -> RGBColor[
              0.9835091741047302, 0.956034713404511, 0.3904366847383839], 114 -> 
             RGBColor[
              0.9940178043119425, 0.9896130132530357, 0.5902531010663682], 24 -> 
             RGBColor[
              0.994784219335761, 0.9912522974925381, 0.6736726466437485], 176 -> 
             RGBColor[
              0.9611344846893971, 0.8805596321796855, 0.3035152414653697], 79 -> 
             RGBColor[
              0.991737359242702, 0.9908511999537449, 0.7865968705846528], 109 -> 
             RGBColor[
              0.9224717448227313, 0.7303333335213267, 0.25647714994357235`], 
             135 -> RGBColor[
              0.8489376949437719, 0.377162144738302, 0.19449609798636422`], 
             108 -> RGBColor[
              0.9948293944300082, 0.9913489224512302, 0.6785896768641932], 
             191 -> RGBColor[
              0.9912924696051291, 0.9906672266554664, 0.7939698432167115], 14 -> 
             RGBColor[
              0.9688658731597176, 0.9066394209064167, 0.3335502257223609], 
             185 -> RGBColor[
              0.8727538658894974, 0.5150868487414358, 0.21553504542108456`], 
             32 -> RGBColor[
              0.9050222466289541, 0.9271041895602156, 0.9908030238780086], 
             122 -> RGBColor[
              0.9382984895669713, 0.7930811024821954, 0.2692117202662339], 
             187 -> RGBColor[0.178927, 0.305394, 0.933501], 193 -> 
             RGBColor[
              0.9938462320465009, 0.9892460375258731, 0.5715785187943315], 
             100 -> RGBColor[
              0.9802865317701709, 0.9848183081888108, 0.9182539390038511], 
             180 -> 
             RGBColor[
              0.9941991093103549, 0.9900008063118928, 0.6099870312588118], 7 -> 
             RGBColor[
              0.9367130569761893, 0.9523212820324761, 0.9920124660477287], 
             175 -> RGBColor[
              0.9932658648168791, 0.9880046907058401, 0.5084091274613671], 9 -> 
             RGBColor[
              0.939258599147394, 0.9542197432158178, 0.9877035271356074], 90 -> 
             RGBColor[
              0.9952185284731873, 0.9921812408221032, 0.7209445160072865], 
             174 -> RGBColor[
              0.9937674963629054, 0.989077629860061, 0.5630086255352728], 142 -> 
             RGBColor[
              0.9719238895417769, 0.9785814633074444, 0.9324097109701133], 
             134 -> RGBColor[
              0.9893814831613067, 0.9758433907360794, 0.41324949653066895`], 
             105 -> RGBColor[
              0.993396828506996, 0.9882848087965397, 0.5226637169163714], 16 -> 
             RGBColor[
              0.9939641665510345, 0.9894982875060628, 0.5844149618054109], 
             139 -> RGBColor[
              0.9923451171505597, 0.9911025234673099, 0.7765247492244035], 
             146 -> RGBColor[
              0.9668170157893383, 0.8997281439015399, 0.3255908017326866], 
             126 -> RGBColor[
              0.944777398076731, 0.8187678157551175, 0.2744248021327153], 198 -> 
             RGBColor[
              0.9937725749834748, 0.9890884925159317, 0.563561402042643], 40 -> 
             RGBColor[
              0.993671969447502, 0.988873307447266, 0.5526111103174037], 104 -> 
             RGBColor[
              0.9922590480188554, 0.9910669316694745, 0.7779511374765145], 
             181 -> RGBColor[
              0.993395016041539, 0.9882809321161957, 0.5224664412366293], 127 -> 
             RGBColor[
              0.9838459776170524, 0.9571708307367992, 0.3917451027837493], 76 -> 
             RGBColor[
              0.9905649871707348, 0.9903663939733985, 0.8060261098188132], 
             172 -> RGBColor[0.178927, 0.305394, 0.933501], 84 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 184 -> 
             RGBColor[
              0.9861164707712249, 0.9885268181205444, 0.879749538950097], 151 -> 
             RGBColor[
              0.8727538658894974, 0.5150868487414358, 0.21553504542108456`], 
             35 -> RGBColor[
              0.9715549043087373, 0.9157101543865991, 0.3439966039553792], 36 -> 
             RGBColor[
              0.9194032115219487, 0.7181676215118297, 0.25400813602202876`], 
             34 -> 
             RGBColor[
              0.9750644822274809, 0.980923712190194, 0.9270935067509743], 38 -> 
             RGBColor[
              0.9476013122123255, 0.8299636942891477, 0.2766969897319987], 54 -> 
             RGBColor[
              0.9927097765739096, 0.9868152741832741, 0.44788235399296256`], 
             60 -> RGBColor[0.178927, 0.305394, 0.933501], 87 -> 
             RGBColor[
              0.9913496881959991, 0.9906908880132418, 0.7930215830890287], 
             141 -> RGBColor[
              0.9728802920066443, 0.92018099830747, 0.3491454848832828], 67 -> 
             RGBColor[
              0.9938722116007777, 0.9917340162670123, 0.751216842190538], 133 -> 
             RGBColor[
              0.9455990479217172, 0.9589484395301761, 0.9769708012145654], 98 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 3 -> 
             RGBColor[
              0.993376566286215, 0.988241469955114, 0.5204582992282947], 27 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 163 -> 
             RGBColor[
              0.9578915949771041, 0.8696206037134071, 0.29091722730144787`], 
             85 -> RGBColor[
              0.9229679658421844, 0.9414136189372742, 0.9925147025968991], 83 -> 
             RGBColor[
              0.9420769338285628, 0.8080613748874961, 0.27225194521059637`], 
             28 -> RGBColor[
              0.9334508826312379, 0.7738619563512639, 0.26531122193778356`], 
             44 -> RGBColor[
              0.9921440912303273, 0.9910193940831633, 0.779856268961059], 189 -> 
             RGBColor[
              0.9900898552356263, 0.9901699147078974, 0.813900275585594], 15 -> 
             RGBColor[
              0.9939735356355893, 0.989518327030566, 0.585434728839922], 80 -> 
             RGBColor[
              0.9936310672115545, 0.9887858217004246, 0.5481591543538562], 
             112 -> RGBColor[
              0.9813070829552819, 0.948606542881832, 0.38188197645279753`], 
             169 -> RGBColor[
              0.9571569092515828, 0.9675682735857288, 0.9574063567561208], 69 -> 
             RGBColor[
              0.9578915949771041, 0.8696206037134071, 0.29091722730144787`], 
             20 -> RGBColor[
              0.9931630944423663, 0.9877848752664359, 0.4972232064208806], 8 -> 
             RGBColor[
              0.9943010642072602, 0.9902188775271518, 0.6210841925942573], 
             116 -> RGBColor[
              0.9935519865887709, 0.9916015949951401, 0.7565237993552564], 97 -> 
             RGBColor[
              0.9935307940211761, 0.9885713474853797, 0.5372450363955563], 
             118 -> 
             RGBColor[
              0.9427115759775329, 0.9567949676820047, 0.9818585380427739], 
             178 -> RGBColor[
              0.9464829544439951, 0.8255297784083518, 0.27579713282036933`], 
             81 -> RGBColor[
              0.989234049350986, 0.9898160169813907, 0.8280831938487179], 166 -> 
             RGBColor[
              0.9255529459707663, 0.7425492693238691, 0.2589563567123678], 
             125 -> RGBColor[
              0.9926539474423988, 0.9866958613161635, 0.4418056975654741], 95 -> 
             RGBColor[
              0.8370522660027353, 0.28580552966932327`, 0.18311459780975556`],
              157 -> RGBColor[
              0.9942761770607906, 0.9901656464373298, 0.6183753802867143], 74 -> 
             RGBColor[
              0.9933965367470602, 0.9882841847515387, 0.5226319606479032], 19 -> 
             RGBColor[
              0.9742128911750977, 0.924676168211828, 0.35432238101248753`], 
             156 -> RGBColor[
              0.9650457813688749, 0.8937533542956972, 0.31870989047873993`], 
             167 -> RGBColor[
              0.9948580583744872, 0.9914102317301013, 0.6817095703273642], 33 -> 
             RGBColor[
              0.9746036763092544, 0.980580043890881, 0.9278735309731001], 43 -> 
             RGBColor[
              0.9939598587815943, 0.9894890736228127, 0.5839460876863258], 
             140 -> RGBColor[
              0.9791862997867364, 0.9414526432707597, 0.37364313431929463`], 
             186 -> RGBColor[
              0.9318560879883169, 0.7675391270258928, 0.2640280127334477], 
             117 -> RGBColor[
              0.9930298389636398, 0.9874998552716355, 0.48271916991899033`], 
             4 -> RGBColor[
              0.9919965973332827, 0.9909584015663151, 0.782300624537058], 106 -> 
             RGBColor[
              0.9843437388836044, 0.9877937479278819, 0.9091282940110315], 65 -> 
             RGBColor[
              0.9848159509464322, 0.9604427785373655, 0.39551326600429637`], 
             53 -> RGBColor[
              0.9950186415083196, 0.9917537028159238, 0.6991880534408108], 2 -> 
             RGBColor[
              0.9869485955081779, 0.9676366894128899, 0.40379818741054646`], 
             147 -> RGBColor[
              0.9939827237243107, 0.9917797158701253, 0.7493853703073869], 94 -> 
             RGBColor[
              0.8849862385129518, 0.9111280205514672, 0.9888919715375487], 23 -> 
             RGBColor[
              0.9843437388836044, 0.9877937479278819, 0.9091282940110315], 
             194 -> 
             RGBColor[
              0.9922590480188554, 0.9910669316694745, 0.7779511374765145], 
             129 -> RGBColor[
              0.9666490329591492, 0.8991614983710674, 0.32493822015829715`], 
             99 -> RGBColor[0.178927, 0.305394, 0.933501], 25 -> 
             RGBColor[
              0.9751568713923526, 0.9278604351417241, 0.3579895659008169], 
             138 -> RGBColor[
              0.9894248318942672, 0.9898949104659251, 0.8249214333771521], 
             124 -> RGBColor[
              0.9944156847375856, 0.9919587563757049, 0.7422100858502391], 
             197 -> RGBColor[
              0.9240050784431304, 0.73641249037307, 0.25771090616651143`], 
             164 -> RGBColor[
              0.9897578010017495, 0.9900326017487848, 0.819403273569743], 152 -> 
             RGBColor[
              0.99303027294112, 0.9913858529944073, 0.7651699446484727], 17 -> 
             RGBColor[
              0.9233325850929359, 0.733746278334673, 0.25716980223149716`], 
             149 -> RGBColor[
              0.9808701365537779, 0.9471326200696647, 
               0.3801845221933584]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw1Vnk41Iv7HWbGjH3MjDGYYWbMlDYVokV9jgp1K023DRVaCFlSpNQNyVKW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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 11}], {
             RGBColor[
             0.5868231900367249, 0.648253806433355, 0.8000581465413696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 35}], {
             RGBColor[
             0.5752409521543687, 0.6105520771932995, 0.6387488019776896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 86}], {
             RGBColor[
             0.5586864660166999, 0.5495298313646481, 0.601415677967821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 94}], {
             RGBColor[
             0.531956619256476, 0.6082610102757335, 0.9611964857687744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 174}], {
             RGBColor[
             0.5863472481814527, 0.6472358149300306, 0.7482548127676364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 196}], {
             RGBColor[
             0.5700084142629955, 0.5929014982273755, 0.6184213803515728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 16}], {
             RGBColor[
             0.9904563810296062, 0.9785674884594764, 0.4941065746079787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 52}], {
             RGBColor[
             0.9907810405123524, 0.9798386207469676, 0.5713651012308605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[
             0.9778714007699878, 0.9719420199414892, 0.6707528181054325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 78}], {
             RGBColor[
             0.9909568515292024, 0.9796379442527833, 0.5485796999431218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 80}], {
             RGBColor[
             0.9902898313598663, 0.9782112555566573, 0.47597867088220136`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 82}], {
             RGBColor[
             0.5829377977540889, 0.636515344706445, 0.6686495937052732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 98}], {
             RGBColor[
             0.5829377977540889, 0.636515344706445, 0.6686495937052732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 100}], {
             RGBColor[
             0.9836175636391744, 0.9762274988008504, 0.6610260632071987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 120}], {
             RGBColor[
             0.9589425586148559, 0.8657650213091406, 0.3335431477703731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 124}], {
             RGBColor[
             0.9906821401228818, 0.9797977228942973, 0.5730041366303927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 187}], {
             RGBColor[
             0.5829377977540889, 0.636515344706445, 0.6686495937052732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 5}], {
             RGBColor[
             0.9673512415251367, 0.8966626562217257, 0.3960529792400773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 10}], {
             RGBColor[
             0.9629913337410753, 0.9686701382016273, 0.7569461478896498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 27}], {
             RGBColor[
             0.5861517831431075, 0.646817734977557, 0.7269796496141474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 29}], {
             RGBColor[
             0.9937931251027879, 0.9891324471432068, 0.5657981557092437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 49}], {
             RGBColor[
             0.9937747919743803, 0.9900499386295153, 0.6333450032571011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 53}], {
             RGBColor[
             0.9941976038972673, 0.9899975863855188, 0.6098231763345527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 62}], {
             RGBColor[
             0.9941633548806958, 0.9899243312021793, 0.6060953822411822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 68}], {
             RGBColor[
             0.9897450298290205, 0.9765305818853909, 0.4605061362674594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 71}], {
             RGBColor[
             0.9591634357967505, 0.8642007349331897, 0.3894648785585158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 75}], {
             RGBColor[
             0.9775787274506136, 0.9796291498895086, 0.7350187325245479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 118}], {
             RGBColor[
             0.9680440711318739, 0.9725182188185593, 0.7511584186355342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[
             0.9924717532508859, 0.9895110986307826, 0.6549397270615239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 127}], {
             RGBColor[
             0.9886112719516337, 0.9727061503459566, 0.456101701006022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 129}], {
             RGBColor[
             0.9800127996226821, 0.9437014841630906, 0.4226982596932959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 139}], {
             RGBColor[
             0.9928608417183873, 0.989671996711212, 0.6484915242263491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 141}], {
             RGBColor[
             0.9831284291464296, 0.954211234131292, 0.43480189205578873`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 146}], {
             RGBColor[
             0.9800967910377767, 0.943984806928327, 0.42302455048049065`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 155}], {
             RGBColor[
             0.9896540703621692, 0.988345914345151, 0.7016360244571259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 167}], {
             RGBColor[
             0.994117312330351, 0.9898258508426077, 0.6010839347778294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 191}], {
             RGBColor[
             0.992334517945672, 0.9894543483052902, 0.6572140712225031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 194}], {
             RGBColor[
             0.9928178071525352, 0.9896542008122942, 0.6492047183524046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 195}], {
             RGBColor[
             0.9375542849702827, 0.9483873259820923, 0.7545199394699701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 34}], {
             RGBColor[
             0.9835305397803817, 0.9859410568782545, 0.8546970656440162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 40}], {
             RGBColor[
             0.9928342833903924, 0.9899158545067905, 0.6674558674272308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 49}], {
             RGBColor[
             0.9930848074979142, 0.9914084044351159, 0.7642661659114828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 53}], {
             RGBColor[
             0.9935076194208012, 0.9913560521911194, 0.7407443389889343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 54}], {
             RGBColor[
             0.9923531869535962, 0.9888868378747946, 0.6150914892650102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 65}], {
             RGBColor[
             0.9884062741398574, 0.9757005900518403, 0.5889069452706772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 69}], {
             RGBColor[
             0.9749440961551934, 0.9302895026398611, 0.5366089259192529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 86}], {
             RGBColor[
             0.9652212646833414, 0.8923120321478055, 0.52581549023635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 92}], {
             RGBColor[
             0.964354827154736, 0.9716398417993957, 0.8871565452923933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 118}], {
             RGBColor[
             0.9673540866554078, 0.9738766846241599, 0.8820795812899159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 119}], {
             RGBColor[
             0.9656359428080568, 0.8939560927290091, 0.5261491499892427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 123}], {
             RGBColor[
             0.9917817687744197, 0.9908695644363832, 0.7858608897159056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 139}], {
             RGBColor[
             0.9921708572419212, 0.9910304625168125, 0.7794126868807307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 146}], {
             RGBColor[
             0.9794068065613105, 0.9453432727339275, 0.5539457131348723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 171}], {
             RGBColor[
             0.9909221908807697, 0.9905141068872145, 0.8001063199299677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 182}], {
             RGBColor[
             0.5854617986666414, 0.6481762007831575, 0.857900812268529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 191}], {
             RGBColor[
             0.9916445334692059, 0.9908128141108907, 0.7881352338768848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 195}], {
             RGBColor[
             0.9368643004938166, 0.9497457917876928, 0.8854411021243518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 196}], {
             RGBColor[
             0.9765432129296369, 0.9356836990105329, 0.5428211926201018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 199}], {
             RGBColor[
             0.5854617986666414, 0.6481762007831575, 0.857900812268529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 10}], {
             RGBColor[
             0.936966008979997, 0.877091324468239, 0.6325408279014324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 27}], {
             RGBColor[
             0.5601264583820292, 0.5552389212441687, 0.60257432962593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.9677678003417097, 0.8975536334098185, 0.44139283572102644`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 30}], {
             RGBColor[
             0.9507111567180047, 0.8874221904896038, 0.6120391152732012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 42}], {
             RGBColor[
             0.9667855396652274, 0.89807251608319, 0.5249144573050109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 68}], {
             RGBColor[
             0.9637197050679422, 0.8849517681520027, 0.33610081627924204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 71}], {
             RGBColor[
             0.9331381110356722, 0.7726219211998016, 0.26505955857029845`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 73}], {
             RGBColor[
             0.9648360400698436, 0.8972663479006445, 0.5572227107437482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 75}], {
             RGBColor[
             0.9515534026895354, 0.8880503361561203, 0.6106134125363305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 76}], {
             RGBColor[
             0.9659454519673967, 0.897725118230868, 0.5388368845353366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 81}], {
             RGBColor[
             0.9652799830575223, 0.897449929734864, 0.5498654265502889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 87}], {
             RGBColor[
             0.9663378024800289, 0.8978873652507896, 0.5323346211704443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 89}], {
             RGBColor[
             0.9564641568646091, 0.8604771003784277, 0.30791438160460244`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 107}], {
             RGBColor[
             0.5601264583820292, 0.5552389212441687, 0.60257432962593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 127}], {
             RGBColor[
             0.9625859471905555, 0.8811273366125683, 0.33169638101780463`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 129}], {
             RGBColor[
             0.9539874748616038, 0.8521226704297025, 0.29829293970507853`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 141}], {
             RGBColor[
             0.9571031043853514, 0.8626324203979037, 0.3103965720675714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 142}], {
             RGBColor[
             0.9566249031529177, 0.8918326528978909, 0.6020286851109866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 147}], {
             RGBColor[
             0.9676543202441846, 0.8984317791792313, 0.5105165147796235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 155}], {
             RGBColor[
             0.963628745601091, 0.8967671006117628, 0.5772307044689086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 157}], {
             RGBColor[
             0.9678010469124245, 0.8976247444628336, 0.44501151976928716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 168}], {
             RGBColor[
             0.5601264583820292, 0.5552389212441687, 0.60257432962593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 188}], {
             RGBColor[
             0.942709819988462, 0.8814548066576974, 0.6255832912734742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 197}], {
             RGBColor[
             0.9326654976035944, 0.7707481664307037, 0.2646792827091857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 44}], {
             RGBColor[
             0.9933600574453834, 0.990913191039, 0.7154340505904073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 45}], {
             RGBColor[
             0.9817242955753145, 0.9487344952249197, 0.49229403207594113`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 58}], {
             RGBColor[
             0.9944715159324039, 0.9905834565319211, 0.6396368109700403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 77}], {
             RGBColor[
             0.9234354331473341, 0.6968868204967453, 0.4243613693129288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 83}], {
             RGBColor[
             0.9683264787445011, 0.8994341814411664, 0.46163188871517596`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 96}], {
             RGBColor[
             0.9906276233703843, 0.9897832593286352, 0.7607175545258504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 112}], {
             RGBColor[
             0.9879415533078606, 0.9697067654383343, 0.5164469043362765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 156}], {
             RGBColor[
             0.9798109025146571, 0.942280171145267, 0.4848608613492478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 166}], {
             RGBColor[
             0.9600644848156028, 0.8666781286593529, 0.4549840944660617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 170}], {
             RGBColor[
             0.9470737835947434, 0.8138333237348621, 0.44446210261235614`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 179}], {
             RGBColor[
             0.9942533336935251, 0.9901167867845675, 0.615889020732779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 183}], {
             RGBColor[
             0.9059475118302196, 0.5624669939974183, 0.40761491610987777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 192}], {
             RGBColor[
             0.9926833148547642, 0.9906333405862877, 0.7266494266706474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 8}], {
             RGBColor[
             0.9655070605917248, 0.9712700797798139, 0.806548329320993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 16}], {
             RGBColor[
             0.9653386117636119, 0.9709097847692695, 0.7882137139265698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 52}], {
             RGBColor[
             0.9656632712463581, 0.9721809170567607, 0.8654722405494516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.8867474585751974, 0.91250621988481, 0.9881533304733856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 67}], {
             RGBColor[
             0.9652926342884836, 0.9720276491497442, 0.8716146541191334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 79}], {
             RGBColor[
             0.9642252081094457, 0.9715862409931105, 0.8893046683161907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.5578200284880946, 0.6288576410162381, 0.9627567330238644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 122}], {
             RGBColor[
             0.9375057732715804, 0.8727011922573358, 0.6306120931569813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 125}], {
             RGBColor[
             0.9646835022092941, 0.9695085716743198, 0.7169090818066014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 126}], {
             RGBColor[
             0.9407452275264602, 0.8855445488937967, 0.633218634090222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 137}], {
             RGBColor[
             0.9207087763521552, 0.8061066967392286, 0.6170968351594202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 179}], {
             RGBColor[
             0.9653218503514001, 0.9708739338033873, 0.7863893376467654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 192}], {
             RGBColor[
             0.9637518315126393, 0.9713904876051075, 0.897149743584634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.9878603877381351, 0.9879411545653928, 0.7687099771435606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 26}], {
             RGBColor[
             0.9642063131615757, 0.9702590488241084, 0.8073308906758743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 61}], {
             RGBColor[
             0.9155414621907328, 0.9314550176321478, 0.8026891937466499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 67}], {
             RGBColor[
             0.994086637904019, 0.9909764468970821, 0.6861505173923976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 79}], {
             RGBColor[
             0.9930192117249811, 0.9905350387404483, 0.703840531589455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.5866140321036301, 0.6478064387635759, 0.7772925962971287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 83}], {
             RGBColor[
             0.9681889990179116, 0.899140126207324, 0.44666806890242683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 122}], {
             RGBColor[
             0.9662997768871158, 0.8916499900046736, 0.44514795643024563`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 125}], {
             RGBColor[
             0.9934775058248295, 0.9884573694216576, 0.5314449450798657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 137}], {
             RGBColor[
             0.9495027799676906, 0.8250554944865665, 0.43163269843268437`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 166}], {
             RGBColor[
             0.9599270050890132, 0.8663840734255104, 0.4400202746533125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 170}], {
             RGBColor[
             0.9469363038681538, 0.8135392685010197, 0.429498282799607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 179}], {
             RGBColor[
             0.9941158539669355, 0.9898227315507251, 0.6009252009200298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 192}], {
             RGBColor[
             0.9925458351281747, 0.9903392853524453, 0.7116856068578983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 198}], {
             RGBColor[
             0.9940368195953675, 0.9896536850215417, 0.5923227973184502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 18}], {
             RGBColor[
             0.559092799573697, 0.6298068716079089, 0.9606022635678038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 32}], {
             RGBColor[
             0.922140422888174, 0.9406619663880167, 0.989253275506808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 39}], {
             RGBColor[
             0.937134511044857, 0.8671323786072609, 0.6271347959074018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 41}], {
             RGBColor[
             0.9667288542288744, 0.9721102747638553, 0.7988452791972096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 57}], {
             RGBColor[
             0.9664044560671801, 0.9714164198976764, 0.7635365412501687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 85}], {
             RGBColor[
             0.9311132824947892, 0.947816681076546, 0.9901091148662533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 88}], {
             RGBColor[
             0.9667158084049698, 0.9730390752598672, 0.8669676172107574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 91}], {
             RGBColor[
             0.9640758422832815, 0.9719473814245143, 0.9107186878604516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 103}], {
             RGBColor[
             0.559092799573697, 0.6298068716079089, 0.9606022635678038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 117}], {
             RGBColor[
             0.966144219055517, 0.9708597992437267, 0.7352113485272989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 121}], {
             RGBColor[
             0.9666347184858871, 0.9730055424944106, 0.8683114870239422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 152}], {
             RGBColor[
             0.966144436044257, 0.9728027981051126, 0.87643673589204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 159}], {
             RGBColor[
             0.9434299556798598, 0.8920917187524828, 0.632200258433803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 164}], {
             RGBColor[
             0.9645082000745717, 0.9721261724823014, 0.9035534003526752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 178}], {
             RGBColor[
             0.9428707767956945, 0.8898747608120848, 0.6317503299779883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 200}], {
             RGBColor[
             0.961383886626062, 0.9551272283101644, 0.6890701059369957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 17}], {
             RGBColor[
             0.9279693431444358, 0.8414225423914068, 0.625301899391251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 27}], {
             RGBColor[
             0.5557665505979678, 0.6272464032240703, 0.9634674982755025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 29}], {
             RGBColor[
             0.9634078925576482, 0.9695611153897201, 0.8022860043705989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 30}], {
             RGBColor[
             0.9463512489339432, 0.9594296724695054, 0.9729322839227738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 42}], {
             RGBColor[
             0.9624256318811659, 0.9700799980630916, 0.8858076259545833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 51}], {
             RGBColor[
             0.9637417065159326, 0.9702751096927218, 0.8386195936688932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 62}], {
             RGBColor[
             0.9637781223355562, 0.9703529994486926, 0.8425832309025374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 71}], {
             RGBColor[
             0.9287782032516108, 0.844629403179703, 0.6259527272198709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 73}], {
             RGBColor[
             0.9604761322857821, 0.9692738298805461, 0.9181158793933206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 75}], {
             RGBColor[
             0.9471934949054739, 0.9600578181360219, 0.9715065811859029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 89}], {
             RGBColor[
             0.9521042490805476, 0.9324845823583294, 0.6688075502541749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 107}], {
             RGBColor[
             0.5557665505979678, 0.6272464032240703, 0.9634674982755025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.9496275670775424, 0.9241301524096039, 0.6591861083546511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 130}], {
             RGBColor[
             0.9630542746023425, 0.9688047623395806, 0.7637968722126156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 141}], {
             RGBColor[
             0.9527431966012899, 0.9346399023778054, 0.6712897407171439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 142}], {
             RGBColor[
             0.9522649953688562, 0.9638401348777925, 0.962921853760559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 147}], {
             RGBColor[
             0.9632944124601232, 0.9704392611591329, 0.871409683429196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 149}], {
             RGBColor[
             0.9567381188748567, 0.9481157132589026, 0.6868092593721817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 167}], {
             RGBColor[
             0.9637320797852114, 0.970254519089121, 0.8375717834391846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 168}], {
             RGBColor[
             0.5557665505979678, 0.6272464032240703, 0.9634674982755025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 188}], {
             RGBColor[
             0.9383499122044006, 0.953462288637599, 0.9864764599230467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.961347978215781, 0.969634360578019, 0.9036671360682995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 194}], {
             RGBColor[
             0.9624325746073955, 0.9700828690588075, 0.8856925670137596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 197}], {
             RGBColor[
             0.9283055898195329, 0.8427556484106054, 0.6255724513587582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 35}], {
             RGBColor[
             0.9831371421910936, 0.9534118836266545, 0.5053059485190593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 70}], {
             RGBColor[
             0.9949722636082245, 0.9917035513746442, 0.69770524602686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 86}], {
             RGBColor[
             0.966582656053425, 0.892389637798003, 0.46797282450919064`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 94}], {
             RGBColor[
             0.9398528092932008, 0.9511208167090885, 0.827753632310144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 110}], {
             RGBColor[
             0.9942717188883163, 0.991413858129784, 0.7093150849873586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 138}], {
             RGBColor[
             0.9920721059838586, 0.9905042616663176, 0.7457683632299457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 174}], {
             RGBColor[
             0.9942434382181777, 0.9900956213633854, 0.614811959309006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 182}], {
             RGBColor[
             0.586823190036725, 0.648253806433355, 0.8000581465413696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 196}], {
             RGBColor[
             0.9779046042997205, 0.9357613046607303, 0.4849785268929425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 33}], {
             RGBColor[
             0.9755515138852184, 0.9564844897670393, 0.6455391892176163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 44}], {
             RGBColor[
             0.9843217213457549, 0.9617041648631804, 0.5715305582115958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 58}], {
             RGBColor[
             0.9854331798327756, 0.9613744303561016, 0.49573331859122893`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 68}], {
             RGBColor[
             0.9813064224165042, 0.9486043147294327, 0.38187941038437834`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 77}], {
             RGBColor[
             0.9143970970477058, 0.6676777943209258, 0.2804578769341173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 96}], {
             RGBColor[
             0.9815892872707559, 0.9605742331528156, 0.6168140621470388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 99}], {
             RGBColor[
             0.5777131757305913, 0.6188914678215988, 0.6483529237310663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 102}], {
             RGBColor[
             0.9852624286078397, 0.9620931714911265, 0.5559406044064953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 128}], {
             RGBColor[
             0.9767737966609269, 0.9573960662598583, 0.6434701833007459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 140}], {
             RGBColor[
             0.9778428256239595, 0.9369207894569787, 0.36842399089071365`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 162}], {
             RGBColor[
             0.5777131757305913, 0.6188914678215988, 0.6483529237310663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 172}], {
             RGBColor[
             0.5777131757305913, 0.6188914678215988, 0.6483529237310663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 31}], {
             RGBColor[
             0.9940965777019446, 0.9908781161352603, 0.6785394009475181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 34}], {
             RGBColor[
             0.9845376600259306, 0.9863575269815987, 0.8380064768316258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 36}], {
             RGBColor[
             0.9567070246731645, 0.8549794816424166, 0.5014637914671529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 63}], {
             RGBColor[
             0.9734042752489278, 0.9211785161464037, 0.5148987912152563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 64}], {
             RGBColor[
             0.939498538168666, 0.9514596811622353, 0.8689057092249128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 70}], {
             RGBColor[
             0.9946179924836898, 0.992042415827791, 0.7388573229416289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 97}], {
             RGBColor[
             0.9937708159227782, 0.9901813446291916, 0.6430822416539167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 132}], {
             RGBColor[
             0.9932669358036423, 0.9891035960044551, 0.5882380002736297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 138}], {
             RGBColor[
             0.9917178348593237, 0.9908431261194643, 0.7869204401447145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 145}], {
             RGBColor[
             0.9550649457770974, 0.8484691860098652, 0.5001425362428318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 153}], {
             RGBColor[
             0.9943805478780638, 0.9914854996281907, 0.7094478021573238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 185}], {
             RGBColor[
             0.9333823518569389, 0.7534390952572196, 0.48222724616668083`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 22}], {
             RGBColor[
             0.980878330704288, 0.9469209303796593, 0.4005672917294644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 48}], {
             RGBColor[
             0.970435830941492, 0.9119352571479589, 0.3396492152429045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 106}], {
             RGBColor[
             0.976604806021661, 0.9472165844171493, 0.6213392598666962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 131}], {
             RGBColor[
             0.9669728899530852, 0.900253944056852, 0.32619634342447706`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 176}], {
             RGBColor[
             0.9650001789245574, 0.8935995265430511, 0.3185327335938653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 59}], {
             RGBColor[
             0.9940863224729721, 0.9897595666712293, 0.5977108800493669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.994461839555383, 0.9905627597399054, 0.6385835970469959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 114}], {
             RGBColor[
             0.993995669973766, 0.9895656701418009, 0.5878439149531451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 167}], {
             RGBColor[
             0.9944157970050382, 0.9904642793803337, 0.633572149583643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 184}], {
             RGBColor[
             0.9900450032034072, 0.9890225725755553, 0.7325921338950094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 186}], {
             RGBColor[
             0.962914811811953, 0.8785287270282294, 0.4247313707866849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 194}], {
             RGBColor[
             0.9931162918272224, 0.9902926293500203, 0.6816929331582182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 52}], {
             RGBColor[
             0.9942888260337807, 0.990769419793554, 0.6616734884282927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 61}], {
             RGBColor[
             0.91537301336262, 0.9310947226216033, 0.7843545783522268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 67}], {
             RGBColor[
             0.9939181890759061, 0.9906161518865375, 0.6678159019979744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 80}], {
             RGBColor[
             0.9937976168812945, 0.9891420546032437, 0.5662870580796335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 82}], {
             RGBColor[
             0.5864455832755172, 0.6474461437530314, 0.7589579809027054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 84}], {
             RGBColor[
             0.5864455832755172, 0.6474461437530314, 0.7589579809027054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 100}], {
             RGBColor[
             0.9871253491606027, 0.9871582978474368, 0.751334450404631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 120}], {
             RGBColor[
             0.9624503441362842, 0.876695820355727, 0.42385153496780525`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 125}], {
             RGBColor[
             0.9933090569967167, 0.9880970744111132, 0.5131103296854425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.5864455832755172, 0.6474461437530314, 0.7589579809027054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 30}], {
             RGBColor[
             0.9417144908824433, 0.8517534084127716, 0.6048001867630199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[
             0.9577888738296662, 0.8624037340063578, 0.5176755287948294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 51}], {
             RGBColor[
             0.9591049484644327, 0.8625988456359881, 0.47048749650913935`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 73}], {
             RGBColor[
             0.9558393742342823, 0.8615975658238123, 0.5499837822335667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 87}], {
             RGBColor[
             0.9573411366444675, 0.8622185831739574, 0.525095692660263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 89}], {
             RGBColor[
             0.9474674910290478, 0.8248083183015955, 0.300675453094421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 106}], {
             RGBColor[
             0.9538381619882701, 0.8607700131312774, 0.5831490481212642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 107}], {
             RGBColor[
             0.551129792546468, 0.5195701391673365, 0.5953354011157486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 130}], {
             RGBColor[
             0.9584175165508426, 0.8611284982828468, 0.3956647750528617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 131}], {
             RGBColor[
             0.9442062459196944, 0.81380737277098, 0.2880061316790452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 142}], {
             RGBColor[
             0.9476282373173563, 0.8561638708210587, 0.5947897566008051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 147}], {
             RGBColor[
             0.9586576544086234, 0.8627629971023991, 0.5032775862694421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 149}], {
             RGBColor[
             0.9521013608233568, 0.8404394492021688, 0.3186771622124278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 157}], {
             RGBColor[
             0.9588043810768633, 0.8619559623860014, 0.4377725912591057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 168}], {
             RGBColor[
             0.551129792546468, 0.5195701391673365, 0.5953354011157486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 188}], {
             RGBColor[
             0.9337131541529007, 0.8457860245808652, 0.6183443627632927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 189}], {
             RGBColor[
             0.9567112201642811, 0.8619580965212852, 0.5355350389085456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 197}], {
             RGBColor[
             0.9236688317680332, 0.7350793843538714, 0.2574403541990043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 24}], {
             RGBColor[
             0.5868556096678805, 0.6483231487462691, 0.8035868233218743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 32}], {
             RGBColor[
             0.5419746233144771, 0.6162490947801078, 0.9621520119390043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 39}], {
             RGBColor[
             0.5569687114711601, 0.5427195069993519, 0.6000335323395982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 41}], {
             RGBColor[
             0.5865630546551774, 0.6476974031559464, 0.771744015629406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 85}], {
             RGBColor[
             0.5509474829210923, 0.6234038094686372, 0.9630078512984496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 103}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 108}], {
             RGBColor[
             0.5868781972150041, 0.6483714612256151, 0.8060453384320967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 117}], {
             RGBColor[
             0.5859784194818198, 0.6464469276358178, 0.7081100849594952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 133}], {
             RGBColor[
             0.5622630239608586, 0.6321712197650879, 0.9552359006072827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 152}], {
             RGBColor[
             0.5859786364705599, 0.6483899264972037, 0.8493354723242363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 178}], {
             RGBColor[
             0.5627049772219976, 0.5654618892041758, 0.6046490664101847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 33}], {
             RGBColor[
             0.974408283742176, 0.9526281060513545, 0.6410979559927938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 74}], {
             RGBColor[
             0.9838047139610789, 0.9564801764816833, 0.43847717083019533`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 85}], {
             RGBColor[
             0.9485904285086411, 0.933044893574551, 0.6734185418046934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 88}], {
             RGBColor[
             0.9841929544188217, 0.9582672877578723, 0.5502770441491975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 93}], {
             RGBColor[
             0.9805807433416378, 0.946156428812359, 0.379060284211517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 95}], {
             RGBColor[
             0.9056325785889165, 0.6052408489405756, 0.26871848941112153`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 102}], {
             RGBColor[
             0.9841191984647972, 0.9582367877754416, 0.5514993711816727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 121}], {
             RGBColor[
             0.984111864499739, 0.9582337549924157, 0.5516209139623823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 140}], {
             RGBColor[
             0.976699595480917, 0.9330644057412938, 0.36398275766589105`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 159}], {
             RGBColor[
             0.9609071016937116, 0.8773199312504878, 0.3155096853722431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 161}], {
             RGBColor[
             0.9599226739315556, 0.941824761972603, 0.6656183149500574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 162}], {
             RGBColor[
             0.5765699455875488, 0.615035084105914, 0.6439116905062439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 164}], {
             RGBColor[
             0.9819853460884236, 0.9573543849803063, 0.5868628272911153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 172}], {
             RGBColor[
             0.5765699455875488, 0.615035084105914, 0.6439116905062439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 173}], {
             RGBColor[
             0.9832359695969766, 0.9578715499406512, 0.566136759244501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 180}], {
             RGBColor[
             0.9842060002427263, 0.9573384872618604, 0.4821547061356497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 22}], {
             RGBColor[
             0.9930269413456123, 0.9874936575596689, 0.48240378207872425`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 46}], {
             RGBColor[
             0.9941515897998263, 0.9898991668838314, 0.6048148257941885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 47}], {
             RGBColor[
             0.9207855716242805, 0.9348732201171223, 0.7413131587852317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 50}], {
             RGBColor[
             0.9932162588558966, 0.9878985885712306, 0.5030098247409328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 101}], {
             RGBColor[
             0.5860450472211831, 0.646589437633218, 0.7153621032104402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 135}], {
             RGBColor[
             0.921050394693069, 0.6824735100023689, 0.3458596522036224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 144}], {
             RGBColor[
             0.9829407609697571, 0.9537099332878904, 0.422869939125159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 23}], {
             RGBColor[
             0.9828817250763071, 0.9867285897657578, 0.9127320278519477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 55}], {
             RGBColor[
             0.9767947479143324, 0.9822141415063979, 0.9241646182687007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 61}], {
             RGBColor[
             0.9091007857216078, 0.9291772946703888, 0.9503149782959532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 67}], {
             RGBColor[
             0.9876459614348938, 0.9886987239353231, 0.8337763019417009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 83}], {
             RGBColor[
             0.9617483225487864, 0.896862403245565, 0.5942938534517301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 90}], {
             RGBColor[
             0.9883191198710986, 0.9889223362128685, 0.8186401388500752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 122}], {
             RGBColor[
             0.9598591004179906, 0.8893722670429146, 0.5927737409795489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 166}], {
             RGBColor[
             0.9534863286198881, 0.8641063504637514, 0.5876460592026158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 170}], {
             RGBColor[
             0.9404956273990286, 0.8112615455392607, 0.5771240673489103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 175}], {
             RGBColor[
             0.9873427880429445, 0.9868340611547369, 0.7123724445771156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 177}], {
             RGBColor[
             0.9824970241576358, 0.9709589774554584, 0.6535127960770545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 179}], {
             RGBColor[
             0.9876751774978104, 0.9875450085889661, 0.7485509854693331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 183}], {
             RGBColor[
             0.899369355634505, 0.5598952158018169, 0.540276880846432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 192}], {
             RGBColor[
             0.9861051586590497, 0.9880615623906863, 0.8593113914072015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.9824482884860624, 0.9522167666212015, 0.4066662812500079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 72}], {
             RGBColor[
             0.9645010179838852, 0.9695374467633364, 0.7303077649399374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 144}], {
             RGBColor[
             0.9828046078730032, 0.9534187155811233, 0.4080505147830027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 176}], {
             RGBColor[
             0.9770126364691277, 0.9338810360162937, 0.3855497996009688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 38}], {
             RGBColor[
             0.965972525547965, 0.9088787211085148, 0.592912641871515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 43}], {
             RGBColor[
             0.9891517988325993, 0.9886414107753473, 0.7465371908486786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 55}], {
             RGBColor[
             0.9782567617216297, 0.9832792996685218, 0.9205608844277844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 60}], {
             RGBColor[
             0.5816353694418022, 0.646593873963941, 0.9213146470055158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 90}], {
             RGBColor[
             0.9897811336783958, 0.9899874943749926, 0.815036405009159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 111}], {
             RGBColor[
             0.9711176669303543, 0.9287071758206444, 0.6000227606562396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 115}], {
             RGBColor[
             0.9748402332315536, 0.9412642660547226, 0.6144842277887391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 163}], {
             RGBColor[
             0.9711176669303543, 0.9287071758206444, 0.6000227606562396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 165}], {
             RGBColor[
             0.9885278731633473, 0.9873068968573788, 0.6786267321734856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 169}], {
             RGBColor[
             0.9707503240675937, 0.9776810107568054, 0.9332673253835762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 175}], {
             RGBColor[
             0.9888048018502418, 0.987899219316861, 0.7087687107361993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 177}], {
             RGBColor[
             0.983959037964933, 0.9720241356175825, 0.6499090622361383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 39}], {
             RGBColor[
             0.9648973211390406, 0.8856486557456209, 0.47011935566147245`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 41}], {
             RGBColor[
             0.9944916643230579, 0.9906265519022155, 0.6418298389512802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 55}], {
             RGBColor[
             0.9834770019477079, 0.9850085744508499, 0.802833060744143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 108}], {
             RGBColor[
             0.9948068068828846, 0.9913006099718842, 0.6761311617539709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 111}], {
             RGBColor[
             0.9763379071564325, 0.9304364506029725, 0.4822949369725982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 115}], {
             RGBColor[
             0.9800604734576318, 0.9429935408370507, 0.4967564041050977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 133}], {
             RGBColor[
             0.9701916336287391, 0.9751003685113571, 0.8253217239291569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 163}], {
             RGBColor[
             0.9763379071564325, 0.9304364506029725, 0.4822949369725982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 165}], {
             RGBColor[
             0.9937481133894256, 0.9890361716397069, 0.5608989084898441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 175}], {
             RGBColor[
             0.99402504207632, 0.9896284940991891, 0.5910408870525579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 38}], {
             RGBColor[
             0.961379091802339, 0.8789120647154359, 0.3173432778164078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[
             0.9845583650869735, 0.9586747543822685, 0.47096782679357135`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 60}], {
             RGBColor[
             0.5770419356961763, 0.616627217570862, 0.6457452829504085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 111}], {
             RGBColor[
             0.9665242331847284, 0.8987405194275656, 0.32445339660113237`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 165}], {
             RGBColor[
             0.9839344394177214, 0.9573402404643, 0.4030573681183783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 58}], {
             RGBColor[
             0.9642392851601298, 0.9703295725950354, 0.8109196892389081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 67}], {
             RGBColor[
             0.9639918868583344, 0.9710166181940387, 0.8723972154740145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 80}], {
             RGBColor[
             0.9638713146637228, 0.9695425209107449, 0.7708683715556737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 82}], {
             RGBColor[
             0.5565192810579456, 0.6278466100605326, 0.9635392943787455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 96}], {
             RGBColor[
             0.9603953925981101, 0.9695293753917493, 0.9320004327947182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 98}], {
             RGBColor[
             0.5565192810579456, 0.6278466100605326, 0.9635392943787455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 99}], {
             RGBColor[
             0.5565192810579456, 0.6278466100605326, 0.9635392943787455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[
             0.9571990469430309, 0.9675587641549379, 0.9559157638806711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 116}], {
             RGBColor[
             0.963831774352331, 0.9709504075581026, 0.8750506940563738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 120}], {
             RGBColor[
             0.9325240419187124, 0.8570962866632281, 0.6284328484438454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 122}], {
             RGBColor[
             0.9362050258414312, 0.8716901613016302, 0.6313946545118625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 124}], {
             RGBColor[
             0.9642636234267383, 0.9711289882483849, 0.8678938373038652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 125}], {
             RGBColor[
             0.9633827547791449, 0.9684975407186143, 0.7176916431614826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 128}], {
             RGBColor[
             0.9555799019882811, 0.966351208498792, 0.9586565539484251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 136}], {
             RGBColor[
             0.9223293267678003, 0.8166776382772978, 0.6202299413327009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 137}], {
             RGBColor[
             0.9194080289220061, 0.8050956657835231, 0.6178793965143013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.9298322540433287, 0.846424244722467, 0.6262669727349295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 170}], {
             RGBColor[
             0.9168415528224692, 0.7935794397979763, 0.6157449808812239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 187}], {
             RGBColor[
             0.5565192810579456, 0.6278466100605326, 0.9635392943787455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 192}], {
             RGBColor[
             0.9624510840824902, 0.970379456649402, 0.8979323049395151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 198}], {
             RGBColor[
             0.9639420685496829, 0.9696938563184984, 0.778569495400067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 29}], {
             RGBColor[
             0.5865683419596806, 0.6477087121656497, 0.7723195060950965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 30}], {
             RGBColor[
             0.5695116983359754, 0.6375772692454351, 0.9429657856472713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 42}], {
             RGBColor[
             0.5855860812831981, 0.6482275948390213, 0.8558411276790809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 62}], {
             RGBColor[
             0.5869385717375883, 0.6485005962246224, 0.8126167326270348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 71}], {
             RGBColor[
             0.551938652653643, 0.5227769999556328, 0.5959862289443685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 73}], {
             RGBColor[
             0.5836365816878144, 0.6474214266564757, 0.8881493811178183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 75}], {
             RGBColor[
             0.5703539443075061, 0.6382054149119516, 0.9415400829104005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 89}], {
             RGBColor[
             0.5752646984825798, 0.610632179134259, 0.6388410519786725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 127}], {
             RGBColor[
             0.5813864888085263, 0.6312824153683996, 0.6626230513918747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 129}], {
             RGBColor[
             0.5727880164795747, 0.6022777491855338, 0.6292196100791486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 141}], {
             RGBColor[
             0.5759036460033222, 0.612787499153735, 0.6413232424416414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 142}], {
             RGBColor[
             0.5754254447708884, 0.6419877316537221, 0.9329553554850567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 147}], {
             RGBColor[
             0.5864548618621555, 0.6485868579350627, 0.8414431851536934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 149}], {
             RGBColor[
             0.5798985682768889, 0.6262633100348323, 0.6568427610966792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 155}], {
             RGBColor[
             0.5824292872190617, 0.6469221793675941, 0.9081573748429785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 167}], {
             RGBColor[
             0.5868925291872436, 0.6484021158650506, 0.8076052851636821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 168}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 188}], {
             RGBColor[
             0.5615103616064328, 0.6316098854135286, 0.9565099616475442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 189}], {
             RGBColor[
             0.5845084276178132, 0.6477819573539487, 0.8737006377927969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[
             0.5855930240094278, 0.6482304658347373, 0.8557260687382573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 197}], {
             RGBColor[
             0.5514660392215651, 0.520903245186535, 0.5956059530832557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 97}], {
             RGBColor[
             0.963490838326207, 0.8812166519183218, 0.40127812916666994`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 105}], {
             RGBColor[
             0.9634238555691169, 0.8810733825739018, 0.39398746942707746`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.9945799136972688, 0.9908153083902722, 0.6514352387221314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 71}], {
             RGBColor[
             0.9595799946133234, 0.8650917121212827, 0.43480473503946493`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 73}], {
             RGBColor[
             0.9912779236474948, 0.9897361388221256, 0.7269678872129146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 129}], {
             RGBColor[
             0.980429358439255, 0.9445924613511836, 0.46803811617424507`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 141}], {
             RGBColor[
             0.9835449879630026, 0.9551022113193848, 0.48014174853673786`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 149}], {
             RGBColor[
             0.9875399102365694, 0.9685780222004822, 0.49566126719177567`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 167}], {
             RGBColor[
             0.994533871146924, 0.9907168280307005, 0.6464237912587786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 168}], {
             RGBColor[
             0.5865683419596804, 0.6477087121656498, 0.7723195060950965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 189}], {
             RGBColor[
             0.9921497695774937, 0.9900966695195985, 0.7125191438878935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 194}], {
             RGBColor[
             0.9932343659691082, 0.9905451780003871, 0.6945445748333536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 197}], {
             RGBColor[
             0.9591073811812456, 0.8632179573521848, 0.43442445917835215`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 42}], {
             RGBColor[
             0.9761707796191735, 0.9804108640844564, 0.8653059133263521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 51}], {
             RGBColor[
             0.9774868542539401, 0.9806059757140866, 0.818117881040662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 71}], {
             RGBColor[
             0.9425233509896183, 0.8549602692010678, 0.6054510145916397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 73}], {
             RGBColor[
             0.9742212800237897, 0.9796046959019109, 0.8976141667650894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 76}], {
             RGBColor[
             0.9753306919213427, 0.9800634662321344, 0.8792283405566779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 81}], {
             RGBColor[
             0.9746652230114683, 0.9797882777361304, 0.8902568825716302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 87}], {
             RGBColor[
             0.9757230424339749, 0.980225713252056, 0.8727260771917856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 89}], {
             RGBColor[
             0.9658493968185552, 0.9428154483796942, 0.6483058376259437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 106}], {
             RGBColor[
             0.9722200677777775, 0.978777143209376, 0.930779432652787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 107}], {
             RGBColor[
             0.5695116983359754, 0.6375772692454351, 0.9429657856472713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 130}], {
             RGBColor[
             0.97679942234035, 0.9791356283609454, 0.7432951595843844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 131}], {
             RGBColor[
             0.9625881517092018, 0.9318145028490787, 0.6356365162105679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 142}], {
             RGBColor[
             0.9660101431068637, 0.9741710008991573, 0.9424201411323279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 147}], {
             RGBColor[
             0.9770395601981308, 0.9807701271804977, 0.8509079708009648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 157}], {
             RGBColor[
             0.9771862868663707, 0.9799630924641001, 0.7854029757906285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 168}], {
             RGBColor[
             0.5695116983359754, 0.6375772692454351, 0.9429657856472713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 176}], {
             RGBColor[
             0.960615440680674, 0.9251600853352778, 0.6279729063799562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 188}], {
             RGBColor[
             0.9520950599424081, 0.9637931546589638, 0.9659747472948155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 197}], {
             RGBColor[
             0.9420507375575405, 0.8530865144319701, 0.605070738730527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 34}], {
             RGBColor[
             0.9846233999034948, 0.9854443013438556, 0.7676264308668668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[
             0.9939271435135054, 0.9894190989723917, 0.5803852326500814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 45}], {
             RGBColor[
             0.9815274425348492, 0.9483134464762599, 0.4708677934574429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 64}], {
             RGBColor[
             0.9395842780462302, 0.9505464555244922, 0.7985256632601538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 65}], {
             RGBColor[
             0.9894991342629704, 0.9752038345174414, 0.5018363104935277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 132}], {
             RGBColor[
             0.9933526756812067, 0.988190370366712, 0.5178579543088707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 138}], {
             RGBColor[
             0.9918035747368881, 0.9899299004817212, 0.7165403941799555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 153}], {
             RGBColor[
             0.9944662877556282, 0.9905722739904476, 0.6390677561925648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 156}], {
             RGBColor[
             0.9796140494741918, 0.9418591223966073, 0.46343462273074953`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 182}], {
             RGBColor[
             0.5865546587897544, 0.6476794452487586, 0.7708301774913795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 185}], {
             RGBColor[
             0.9334680917345031, 0.7525258696194765, 0.41184720020192184`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 199}], {
             RGBColor[
             0.5865546587897544, 0.6476794452487586, 0.7708301774913795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 39}], {
             RGBColor[
             0.9200163347856372, 0.8535746017794597, 0.6286845442786024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 57}], {
             RGBColor[
             0.9492862798079602, 0.9578586430698752, 0.7650862896213693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 103}], {
             RGBColor[
             0.5419746233144771, 0.6162490947801078, 0.9621520119390043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 117}], {
             RGBColor[
             0.949026042796297, 0.9573020224159255, 0.7367610968984994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 133}], {
             RGBColor[
             0.9253106472753356, 0.9430263145451958, 0.983886912546287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 152}], {
             RGBColor[
             0.9490262597850371, 0.9592450212773114, 0.8779864842632406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 178}], {
             RGBColor[
             0.9257526005364747, 0.8763169839842837, 0.6333000783491889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 44}], {
             RGBColor[
             0.9833738837697908, 0.9857997189870222, 0.8538648999670795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 58}], {
             RGBColor[
             0.9844853422568114, 0.9854699844799433, 0.7780676603467127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 68}], {
             RGBColor[
             0.9803585848405401, 0.9726998688532744, 0.6642137521398621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 77}], {
             RGBColor[
             0.9134492594717416, 0.6917733484447675, 0.562792218689601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 96}], {
             RGBColor[
             0.9806414496947918, 0.9846697872766574, 0.8991484039025226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 99}], {
             RGBColor[
             0.5767653381546272, 0.6429870219454406, 0.9306872654865501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 102}], {
             RGBColor[
             0.9843145910318756, 0.9861887256149682, 0.838274946161979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 128}], {
             RGBColor[
             0.9758259590849627, 0.9814916203837001, 0.9258045250562297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 140}], {
             RGBColor[
             0.9768949880479953, 0.9610163435808203, 0.6507583326461974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 162}], {
             RGBColor[
             0.5767653381546272, 0.6429870219454406, 0.9306872654865501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 172}], {
             RGBColor[
             0.5767653381546272, 0.6429870219454406, 0.9306872654865501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 180}], {
             RGBColor[
             0.9844013928098047, 0.985290425101387, 0.768930281115956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 40}], {
             RGBColor[
             0.9843682258374915, 0.98489850981873, 0.739852308534189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 45}], {
             RGBColor[
             0.9719685248588352, 0.9437928573225984, 0.6303348693415506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 54}], {
             RGBColor[
             0.9838871294006952, 0.983869493186734, 0.6874879303719684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 64}], {
             RGBColor[
             0.9300253603702163, 0.9460258663708306, 0.9579927391442615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 65}], {
             RGBColor[
             0.9799402165869565, 0.9706832453637797, 0.6613033863776354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 132}], {
             RGBColor[
             0.9837937580051928, 0.9836697812130504, 0.6773250301929784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 138}], {
             RGBColor[
             0.982244657060874, 0.9854093113280595, 0.8760074700640632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 153}], {
             RGBColor[
             0.9849073700796143, 0.986051684836786, 0.7985348320766725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 182}], {
             RGBColor[
             0.5769957411137404, 0.643158856095097, 0.9302972533754872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 185}], {
             RGBColor[
             0.9239091740584892, 0.7480052804658149, 0.5713142760860295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 199}], {
             RGBColor[
             0.5769957411137404, 0.643158856095097, 0.9302972533754872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 86}], {
             RGBColor[
             0.9550004181710686, 0.8546879085579475, 0.3066634799455106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.9282705714108446, 0.9134190874690331, 0.666444287746464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 110}], {
             RGBColor[
             0.9826894810059601, 0.9537121288897286, 0.5480057404236786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 174}], {
             RGBColor[
             0.9826612003358213, 0.95239389212333, 0.45350261474532594`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 63}], {
             RGBColor[
             0.936100462097712, 0.7843666560158167, 0.2674431357701321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 70}], {
             RGBColor[
             0.957314179332474, 0.855230555697204, 0.49140166749650466`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 110}], {
             RGBColor[
             0.9566136346125658, 0.8549408624523439, 0.5030115064570033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 138}], {
             RGBColor[
             0.954414021708108, 0.8540312659888774, 0.5394647846995904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 145}], {
             RGBColor[
             0.9177611326258817, 0.7116573258792782, 0.2526868807977076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 185}], {
             RGBColor[
             0.8960785387057231, 0.6166272351266328, 0.23477159072155668`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 45}], {
             RGBColor[
             0.9043262814214819, 0.8908718959006628, 0.659078195820484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 47}], {
             RGBColor[
             0.8440940220794845, 0.8785216771570659, 0.9849916354292121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 50}], {
             RGBColor[
             0.9165247093111006, 0.9315470456111741, 0.7466883013849132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 97}], {
             RGBColor[
             0.9166553946869751, 0.9318265684158513, 0.7609125980521988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 101}], {
             RGBColor[
             0.509353497676387, 0.5902378946731615, 0.9590405798544206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 105}], {
             RGBColor[
             0.916588411929885, 0.9316832990714313, 0.7536219383126064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 134}], {
             RGBColor[
             0.9145807392570404, 0.9254625900412012, 0.6989148281197551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 135}], {
             RGBColor[
             0.8443588451482731, 0.6261219670423125, 0.5895381288476027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 160}], {
             RGBColor[
             0.9138121874889984, 0.9321615710916138, 0.9178468886317113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 43}], {
             RGBColor[
             0.9707805854969599, 0.9097263839559802, 0.43032153870916223`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 60}], {
             RGBColor[
             0.5632641561061628, 0.5676788471445738, 0.6050989948659993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 90}], {
             RGBColor[
             0.9714099203427564, 0.9110724675556254, 0.49882075286964256`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 111}], {
             RGBColor[
             0.9527464535947148, 0.8497921490012774, 0.2838071085167233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 165}], {
             RGBColor[
             0.9701566598277078, 0.9083918700380118, 0.36241108003396916`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 169}], {
             RGBColor[
             0.9523791107319541, 0.8987659839374382, 0.6170516732440599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 41}], {
             RGBColor[
             0.9646047661263375, 0.8850229101552983, 0.43827654796900406`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 74}], {
             RGBColor[
             0.9642034798446901, 0.8841645993751213, 0.3945990126635498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 85}], {
             RGBColor[
             0.9289891943922524, 0.860729316467989, 0.6295403836380478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 88}], {
             RGBColor[
             0.964591720302433, 0.8859517106513102, 0.506398885982552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 108}], {
             RGBColor[
             0.9649199086861642, 0.885696968224967, 0.4725778707716948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 117}], {
             RGBColor[
             0.96402013095298, 0.8837724346351696, 0.3746426172990933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 133}], {
             RGBColor[
             0.9403047354320186, 0.86949672676444, 0.6217684329468809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 152}], {
             RGBColor[
             0.9640203479417201, 0.8857154334965556, 0.5158680046638345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 159}], {
             RGBColor[
             0.9413058675773228, 0.8050043541439258, 0.2716315272055975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 173}], {
             RGBColor[
             0.9636347354805879, 0.8855559728340892, 0.5222586010778554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 178}], {
             RGBColor[
             0.9407466886931577, 0.8027873962035279, 0.27118159874978287`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 49}], {
             RGBColor[
             0.9939224935550239, 0.9903658573755914, 0.6494214088016557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 53}], {
             RGBColor[
             0.9943453054779108, 0.9903135051315949, 0.6258995818791073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 54}], {
             RGBColor[
             0.9931908730107057, 0.98784429081527, 0.5002467321551831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 64}], {
             RGBColor[
             0.939329103980227, 0.9500006639993666, 0.7707515409274762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.9892439601969671, 0.9746580429923157, 0.47406218816085005`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 69}], {
             RGBColor[
             0.975781782212303, 0.9292469555803365, 0.4217641688094258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 119}], {
             RGBColor[
             0.9664736288651665, 0.8929135456694846, 0.41130439287941556`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 123}], {
             RGBColor[
             0.9926194548315295, 0.9898270173768586, 0.6710161326060784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 132}], {
             RGBColor[
             0.9930975016152033, 0.9876445788415864, 0.4900838319761931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 171}], {
             RGBColor[
             0.9917598769378793, 0.98947155982769, 0.6852615628201406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 182}], {
             RGBColor[
             0.586299484723751, 0.647133653723633, 0.7430560551587019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 191}], {
             RGBColor[
             0.9924822195263155, 0.9897702670513662, 0.6732904767670576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 195}], {
             RGBColor[
             0.9377019865509262, 0.9487032447281682, 0.7705963450145246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 196}], {
             RGBColor[
             0.9773808989867465, 0.9346411519510084, 0.42797643551027464`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 199}], {
             RGBColor[
             0.586299484723751, 0.647133653723633, 0.7430560551587019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 74}], {
             RGBColor[
             0.9937978230287076, 0.9891424955317157, 0.5663094959533574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 85}], {
             RGBColor[
             0.9585835375762697, 0.9657072126245835, 0.8012508669278555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.9941860634864503, 0.9909296068079048, 0.6781093692723597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 108}], {
             RGBColor[
             0.9945142518701815, 0.9906748643815615, 0.6442883540615025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 121}], {
             RGBColor[
             0.9941049735673676, 0.9908960740424482, 0.6794532390855444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 133}], {
             RGBColor[
             0.9698990786160361, 0.9744746229210344, 0.7934789162366886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 140}], {
             RGBColor[
             0.9866927045485456, 0.9657267247913263, 0.4918150827890532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 151}], {
             RGBColor[
             0.9334764875999262, 0.7525438275266643, 0.4127610383399482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 152}], {
             RGBColor[
             0.9936146911257375, 0.99069332965315, 0.6875784879536422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 159}], {
             RGBColor[
             0.9709002107613403, 0.9099822503005203, 0.4433420104954052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 161}], {
             RGBColor[
             0.9699157829991842, 0.9744870810226354, 0.7934506400732195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 173}], {
             RGBColor[
             0.9932290786646052, 0.9905338689906836, 0.6939690843676631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 51}], {
             RGBColor[
             0.993561237201163, 0.991256301307673, 0.7309932230724716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 71}], {
             RGBColor[
             0.9585977339368411, 0.8656105947946542, 0.5183263566234493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 73}], {
             RGBColor[
             0.9902956629710125, 0.9902550214954972, 0.8104895087968991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 76}], {
             RGBColor[
             0.9914050748685657, 0.9907137918257206, 0.7921036825884875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 81}], {
             RGBColor[
             0.9907396059586913, 0.9904386033297167, 0.8031322246034398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 87}], {
             RGBColor[
             0.9917974253811978, 0.9908760388456422, 0.7856014192235952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 89}], {
             RGBColor[
             0.981923779765778, 0.9534657739732804, 0.5611811796577533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 106}], {
             RGBColor[
             0.9882944507250004, 0.9894274688029623, 0.8436547746845966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 107}], {
             RGBColor[
             0.5855860812831982, 0.6482275948390214, 0.8558411276790809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 130}], {
             RGBColor[
             0.9928738052875729, 0.9897859539545316, 0.656170501616194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 131}], {
             RGBColor[
             0.9786625346564246, 0.9424648284426649, 0.5485118582423775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 142}], {
             RGBColor[
             0.9820845260540867, 0.9848213264927436, 0.8552954831641375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 147}], {
             RGBColor[
             0.9931139431453535, 0.991420452774084, 0.7637833128327743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 149}], {
             RGBColor[
             0.9865576495600872, 0.9690969048738537, 0.5791828887757601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 157}], {
             RGBColor[
             0.9932606698135935, 0.9906134180576862, 0.6982783178224381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 168}], {
             RGBColor[
             0.5855860812831982, 0.6482275948390214, 0.8558411276790809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 176}], {
             RGBColor[
             0.9766898236278967, 0.9358104109288641, 0.5408482484117657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 188}], {
             RGBColor[
             0.9681694428896309, 0.97444348025255, 0.8788500893266251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 189}], {
             RGBColor[
             0.9911675089010114, 0.99061555219297, 0.7960407654718779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 197}], {
             RGBColor[
             0.9581251205047634, 0.8637368400255563, 0.5179460807623366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 60}], {
             RGBColor[
             0.5864434293907972, 0.6474415368114064, 0.758723543843163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[
             0.9945891936273907, 0.990835157222458, 0.6524453018468062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 111}], {
             RGBColor[
             0.9759257268793492, 0.9295548386681098, 0.43743165749388685`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 115}], {
             RGBColor[
             0.9796482931805485, 0.942111928902188, 0.4518931246263863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 163}], {
             RGBColor[
             0.9759257268793492, 0.9295548386681098, 0.43743165749388685`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 165}], {
             RGBColor[
             0.9933359331123423, 0.9881545597048442, 0.5160356290111328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 169}], {
             RGBColor[
             0.9755583840165886, 0.9785286736042708, 0.7706762222212233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 58}], {
             RGBColor[
             0.9932555497173479, 0.9906896595760845, 0.7040590293406921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 68}], {
             RGBColor[
             0.9891287923010765, 0.9779195439494156, 0.5902051211338415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 77}], {
             RGBColor[
             0.9222194669322781, 0.6969930235409086, 0.4887835876835805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 96}], {
             RGBColor[
             0.9894116571553283, 0.9898894623727985, 0.8251397728965021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 99}], {
             RGBColor[
             0.5855355456151636, 0.6482066970415816, 0.8566786344805295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 102}], {
             RGBColor[
             0.993084798492412, 0.9914084007111093, 0.7642663151559584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[
             0.9845961665454992, 0.9867112954798412, 0.8517958940502091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 143}], {
             RGBColor[
             0.9934471745810374, 0.9910995257832707, 0.7249162131817148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 166}], {
             RGBColor[
             0.9588485186005469, 0.8667843317035162, 0.5194063128367133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 172}], {
             RGBColor[
             0.5855355456151636, 0.6482066970415816, 0.8566786344805295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 198}], {
             RGBColor[
             0.9929583331069011, 0.9900539432995474, 0.671708835501851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 64}], {
             RGBColor[
             0.9269294030015707, 0.908895011503235, 0.6612341017348378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 112}], {
             RGBColor[
             0.9750898252227358, 0.9276342726684174, 0.3577291041924622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 132}], {
             RGBColor[
             0.9806978006365471, 0.9465389263454547, 0.3805663927835546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 134}], {
             RGBColor[
             0.9791270253257482, 0.941252696595541, 0.37341286423139786`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 153}], {
             RGBColor[
             0.9818114127109686, 0.9489208299691902, 0.5017761946672488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 156}], {
             RGBColor[
             0.9669591744295323, 0.90020767837535, 0.32614306120543335`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 183}], {
             RGBColor[
             0.8930957837450948, 0.5203945012275013, 0.2488971159660634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 47}], {
             RGBColor[
             0.9217740669817405, 0.9369875117345178, 0.8489047781585396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 50}], {
             RGBColor[
             0.9942047542133566, 0.9900128801886261, 0.6106014441142407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 101}], {
             RGBColor[
             0.5870335425786432, 0.6487037292506135, 0.8229537225837482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 105}], {
             RGBColor[
             0.9942684568321412, 0.9901491336488832, 0.6175350810419339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 135}], {
             RGBColor[
             0.9220388900505291, 0.6845878016197644, 0.4534512715769303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 144}], {
             RGBColor[
             0.9839292563272171, 0.955824224905286, 0.530461558498467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 50}], {
             RGBColor[
             0.920838736037811, 0.934986933421917, 0.7470997771052839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 101}], {
             RGBColor[
             0.5136675244030974, 0.5936777824839043, 0.9594520555747914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 105}], {
             RGBColor[
             0.9209024386565954, 0.9351231868821741, 0.7540334140329771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 134}], {
             RGBColor[
             0.9188947659837507, 0.928902477851944, 0.6993263038401258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 135}], {
             RGBColor[
             0.8486728718749834, 0.6295618548530553, 0.5899496045679735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 144}], {
             RGBColor[
             0.9105632381516714, 0.9007982781385768, 0.6669598914895102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 72}], {
             RGBColor[
             0.9540585182210892, 0.934551773531636, 0.6693896884533774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 76}], {
             RGBColor[
             0.9812853879470006, 0.9537987436814499, 0.5758871572911306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 81}], {
             RGBColor[
             0.9806199190371262, 0.953523555185446, 0.5869156993060829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 87}], {
             RGBColor[
             0.9816777384596327, 0.9539609907013715, 0.5693848939262384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 104}], {
             RGBColor[
             0.9821324183710609, 0.9541490125294878, 0.5618496711199812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 106}], {
             RGBColor[
             0.9781747638034354, 0.9525124206586915, 0.6274382493872397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 147}], {
             RGBColor[
             0.9829942562237886, 0.9545054046298131, 0.5475667875354174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 154}], {
             RGBColor[
             0.9562277272274338, 0.936169566056814, 0.6657177834259551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 157}], {
             RGBColor[
             0.9831409828920286, 0.9536983699134155, 0.4820617925250812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 158}], {
             RGBColor[
             0.9363382921164325, 0.7795410996856245, 0.29228891028305415`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 176}], {
             RGBColor[
             0.9665701367063317, 0.8988953627845933, 0.3246317231144088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 53}], {
             RGBColor[
             0.9945958295854327, 0.9918060550599201, 0.7227098803633591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 54}], {
             RGBColor[
             0.9934413971182277, 0.9893368407435954, 0.597057030639435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 65}], {
             RGBColor[
             0.9894944843044889, 0.9761505929206411, 0.570872486645102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 69}], {
             RGBColor[
             0.9760323063198248, 0.9307395055086618, 0.5185744672936777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 92}], {
             RGBColor[
             0.9654430373193675, 0.9720898446681964, 0.8691220866668181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 118}], {
             RGBColor[
             0.9684422968200392, 0.9743266874929606, 0.8640451226643407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 119}], {
             RGBColor[
             0.9667241529726883, 0.8944060955978099, 0.5081146913636675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 123}], {
             RGBColor[
             0.9928699789390513, 0.9913195673051839, 0.7678264310903304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 127}], {
             RGBColor[
             0.9890094976397991, 0.974514619020358, 0.5689884050348284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[
             0.9804110253108475, 0.945509952837492, 0.5355849637221024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 139}], {
             RGBColor[
             0.9932590674065527, 0.9914804653856133, 0.7613782282551556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 141}], {
             RGBColor[
             0.983526654834595, 0.9560197028056934, 0.5476885960845952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 146}], {
             RGBColor[
             0.9804950167259421, 0.9457932756027283, 0.5359112545092971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 155}], {
             RGBColor[
             0.9900522960503346, 0.9901543830195523, 0.8145227284859324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 171}], {
             RGBColor[
             0.9920104010454012, 0.9909641097560153, 0.7820718613043925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 191}], {
             RGBColor[
             0.9927327436338373, 0.9912628169796915, 0.7701007752513096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 195}], {
             RGBColor[
             0.9379525106584481, 0.9501957946564936, 0.8674066434987766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 196}], {
             RGBColor[
             0.9776314230942684, 0.9361337018793336, 0.5247867339945266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 199}], {
             RGBColor[
             0.5865500088312728, 0.6486262036519583, 0.8398663536429538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 97}], {
             RGBColor[
             0.9934001086453015, 0.9882918246807024, 0.5230207397282707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 101}], {
             RGBColor[
             0.5860982116347135, 0.6467031509380127, 0.7211487215304926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 105}], {
             RGBColor[
             0.9933331258882114, 0.9881485553362825, 0.5157300799886781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 134}], {
             RGBColor[
             0.9913254532153668, 0.9819278463060523, 0.461022969795827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 135}], {
             RGBColor[
             0.9211035591065995, 0.6825872233071637, 0.35164627052367464`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 144}], {
             RGBColor[
             0.9829939253832876, 0.953823646592685, 0.42865655744521125`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 73}], {
             RGBColor[
             0.9916117376057791, 0.9904501331251274, 0.7633014765112089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 87}], {
             RGBColor[
             0.9931135000159643, 0.9910711504752725, 0.738413386937905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 106}], {
             RGBColor[
             0.9896105253597669, 0.9896225804325924, 0.7964667423989065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[
             0.5869021559179648, 0.6484227064686515, 0.8086530953933908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 130}], {
             RGBColor[
             0.9941898799223394, 0.9899810655841619, 0.6089824693305038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 131}], {
             RGBColor[
             0.9799786092911912, 0.9426599400722951, 0.5013238259566873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 147}], {
             RGBColor[
             0.9944300177801202, 0.9916155644037141, 0.7165952805470842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 157}], {
             RGBColor[
             0.9945767444483601, 0.9908085296873165, 0.651090285536748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 168}], {
             RGBColor[
             0.5869021559179648, 0.6484227064686515, 0.8086530953933908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 189}], {
             RGBColor[
             0.9924835835357779, 0.9908106638226002, 0.7488527331861877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 197}], {
             RGBColor[
             0.95944119513953, 0.8639319516551865, 0.4707580484766465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 66}], {
             RGBColor[
             0.9817038457741623, 0.9841439512755668, 0.8383197319257466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 80}], {
             RGBColor[
             0.9941222763640407, 0.9904131868907349, 0.6435455847025153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 82}], {
             RGBColor[
             0.5867702427582634, 0.6487172760405227, 0.8362165075255872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 100}], {
             RGBColor[
             0.9874500086433489, 0.988429430134928, 0.8285929770275128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 120}], {
             RGBColor[
             0.9627750036190303, 0.8779669526432182, 0.501110061590687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 124}], {
             RGBColor[
             0.9945145851270563, 0.9919996542283751, 0.7405710504507068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 125}], {
             RGBColor[
             0.9936337164794629, 0.9893682066986044, 0.5903688563083243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 187}], {
             RGBColor[
             0.5867702427582634, 0.6487172760405227, 0.8362165075255872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 54}], {
             RGBColor[
             0.9938642090411146, 0.9892844884995989, 0.5735352037168867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 65}], {
             RGBColor[
             0.9899172962273759, 0.9760982406766446, 0.5473506597225536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 69}], {
             RGBColor[
             0.9764551182427119, 0.9306871532646654, 0.49505264037112934`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 92}], {
             RGBColor[
             0.9658658492422545, 0.9720374924241999, 0.8456002597442698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 118}], {
             RGBColor[
             0.9688651087429263, 0.9742743352489642, 0.8405232957417923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 119}], {
             RGBColor[
             0.9671469648955753, 0.8943537433538135, 0.4845928644411191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 123}], {
             RGBColor[
             0.9932927908619382, 0.9912672150611874, 0.744304604167782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 127}], {
             RGBColor[
             0.989432309562686, 0.9744622667763615, 0.54546657811228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 129}], {
             RGBColor[
             0.9808338372337344, 0.9454576005934956, 0.512063136799554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 139}], {
             RGBColor[
             0.9936818793294397, 0.9914281131416168, 0.7378564013326072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 141}], {
             RGBColor[
             0.983949466757482, 0.9559673505616969, 0.5241667691620469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 146}], {
             RGBColor[
             0.9809178286488289, 0.9457409233587318, 0.5123894275867487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 155}], {
             RGBColor[
             0.9904751079732216, 0.9901020307755559, 0.791000901563384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 171}], {
             RGBColor[
             0.9924332129682881, 0.990911757512019, 0.7585500343818441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 182}], {
             RGBColor[
             0.5869728207541598, 0.6485738514079619, 0.8163445267204055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 191}], {
             RGBColor[
             0.9931555555567244, 0.9912104647356951, 0.7465789483287611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 195}], {
             RGBColor[
             0.938375322581335, 0.9501434424124973, 0.8438848165762282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 196}], {
             RGBColor[
             0.9780542350171553, 0.9360813496353373, 0.5012649070719782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 199}], {
             RGBColor[
             0.5869728207541598, 0.6485738514079619, 0.8163445267204055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 64}], {
             RGBColor[
             0.9388480075434307, 0.9489716473673706, 0.7183871627652556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 65}], {
             RGBColor[
             0.9887628637601709, 0.9736290263603198, 0.4216978099986295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 118}], {
             RGBColor[
             0.9677106762757213, 0.9718051209326394, 0.7148704460178683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 119}], {
             RGBColor[
             0.9659925324283702, 0.8918845290374886, 0.35894001471719494`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 123}], {
             RGBColor[
             0.9921383583947332, 0.9887980007448627, 0.6186517544438579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 127}], {
             RGBColor[
             0.988277877095481, 0.9719930524600366, 0.41981372838835596`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 140}], {
             RGBColor[
             0.985948038180323, 0.9641339587270169, 0.41076274415612857`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 151}], {
             RGBColor[
             0.9327318212317035, 0.7509510614623549, 0.33170869970702355`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 155}], {
             RGBColor[
             0.9893206755060165, 0.9876328164592311, 0.6653480518394599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 171}], {
             RGBColor[
             0.9912787805010831, 0.988442543195694, 0.63289718465792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 172}], {
             RGBColor[
             0.5858183882869548, 0.646104637091637, 0.6906916769964813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 191}], {
             RGBColor[
             0.9920011230895194, 0.9887412504193702, 0.620926098604837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 195}], {
             RGBColor[
             0.93722089011413, 0.9476742280961723, 0.7182319668523041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 199}], {
             RGBColor[
             0.5858183882869548, 0.646104637091637, 0.6906916769964813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 90}], {
             RGBColor[
             0.9836941565164211, 0.9854730461156325, 0.8264689954259119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 108}], {
             RGBColor[
             0.9834995894948315, 0.985056886930196, 0.8052915758543653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 111}], {
             RGBColor[
             0.9650306897683796, 0.9241927275612845, 0.6114553510729926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 115}], {
             RGBColor[
             0.9687532560695788, 0.9367498177953626, 0.6259168182054922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 163}], {
             RGBColor[
             0.9650306897683796, 0.9241927275612845, 0.6114553510729926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.9824408960013726, 0.9827924485980188, 0.6900593225902385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 175}], {
             RGBColor[
             0.9827178246882671, 0.983384771057501, 0.7202013011529522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 177}], {
             RGBColor[
             0.9778720608029583, 0.9675096873582225, 0.6613416526528912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 183}], {
             RGBColor[
             0.8947443922798275, 0.5564459257045808, 0.5481057374222686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 109}], {
             RGBColor[
             0.8323850569004562, 0.764470864067209, 0.6157130861284075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 148}], {
             RGBColor[
             0.8266378063397521, 0.8652304685973623, 0.9831600195640512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 150}], {
             RGBColor[
             0.8266378063397521, 0.8652304685973623, 0.9831600195640512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 193}], {
             RGBColor[
             0.868072300512341, 0.8939272160694822, 0.773263770553787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 88}], {
             RGBColor[
             0.9938616653247561, 0.9902357519417258, 0.6428006313253187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 91}], {
             RGBColor[
             0.9912216992030676, 0.9891440581063728, 0.6865517019750128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 103}], {
             RGBColor[
             0.5862386564934832, 0.6470035482897675, 0.7364352776823649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 117}], {
             RGBColor[
             0.993290075975303, 0.9880564759255852, 0.5110443626418602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 121}], {
             RGBColor[
             0.9937805754056732, 0.9902022191762692, 0.6441445011385034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 152}], {
             RGBColor[
             0.9932902929640431, 0.9899994747869711, 0.6522697500066013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 164}], {
             RGBColor[
             0.9916540569943579, 0.9893228491641599, 0.6793864144672364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 178}], {
             RGBColor[
             0.9700166337154807, 0.9070714374939434, 0.4075833440925496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 200}], {
             RGBColor[
             0.9885297435458482, 0.9723239049920229, 0.4649031200515569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 77}], {
             RGBColor[
             0.9233309254192987, 0.6966632890338298, 0.4129863480632136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 96}], {
             RGBColor[
             0.9905231156423489, 0.9895597278657197, 0.7493425332761352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 99}], {
             RGBColor[
             0.5866470041021843, 0.6478769625345028, 0.7808813948601626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 102}], {
             RGBColor[
             0.9941962569794327, 0.9910786662040305, 0.6884690755355916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 125}], {
             RGBColor[
             0.9935104778233836, 0.9885278931925845, 0.5350337436428997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 128}], {
             RGBColor[
             0.9857076250325199, 0.9863815609727623, 0.7759986544298422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 137}], {
             RGBColor[
             0.9495357519662448, 0.8251260182574933, 0.4352214969957183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 166}], {
             RGBColor[
             0.9599599770875674, 0.8664545971964374, 0.44360907321634646`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 170}], {
             RGBColor[
             0.9469692758667079, 0.8136097922719465, 0.43308708136264096`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 192}], {
             RGBColor[
             0.992578807126729, 0.9904098091233722, 0.7152744054209321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 198}], {
             RGBColor[
             0.9940697915939216, 0.9897242087924687, 0.5959115958814841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 62}], {
             RGBColor[
             0.994574626392766, 0.9908039993805687, 0.6508597482564408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 92}], {
             RGBColor[
             0.9654560831432721, 0.9711610441721845, 0.8009997486532703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 114}], {
             RGBColor[
             0.9941084568111487, 0.9898069097824642, 0.6001200661625901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 146}], {
             RGBColor[
             0.9805080625498466, 0.9448644751067163, 0.4677889164957492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 184}], {
             RGBColor[
             0.9901577900407899, 0.9892638122162186, 0.7448682851044544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 186}], {
             RGBColor[
             0.963027598649336, 0.8787699666688928, 0.4370075219961298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[
             0.9932290786646052, 0.9905338689906836, 0.6939690843676631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 90}], {
             RGBColor[
             0.5870727642365936, 0.6487876204110516, 0.8272227580036433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 111}], {
             RGBColor[
             0.568409297488552, 0.5875073018567036, 0.612209113650724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 165}], {
             RGBColor[
             0.585819503721545, 0.646107022893438, 0.6908130851679699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 169}], {
             RGBColor[
             0.5680419546257913, 0.6364811367928644, 0.9454536783780605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 67}], {
             RGBColor[
             0.9153270358874916, 0.9322125870020781, 0.8677555185447903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 79}], {
             RGBColor[
             0.9142596097084538, 0.9317711788454444, 0.8854455327418477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 84}], {
             RGBColor[
             0.5078544300871027, 0.5890425788685719, 0.9588975974495213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 122}], {
             RGBColor[
             0.8875401748705884, 0.8328861301096696, 0.6267529575826383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 126}], {
             RGBColor[
             0.8907796291254683, 0.8457294867461307, 0.6293594985158789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 179}], {
             RGBColor[
             0.9153562519504082, 0.9310588716557211, 0.7825302020724224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 190}], {
             RGBColor[
             0.9006525194832047, 0.9228765915425541, 0.9646156893768423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 192}], {
             RGBColor[
             0.9137862331116474, 0.9315754254574413, 0.8932906080102909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 114}], {
             RGBColor[
             0.9944839738935597, 0.9906101028511403, 0.6409927831602189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 141}], {
             RGBColor[
             0.9839152177409105, 0.9558940953783573, 0.5204389750686762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 149}], {
             RGBColor[
             0.9879101400144774, 0.9693699062594547, 0.5359584937237141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 167}], {
             RGBColor[
             0.9949041009248321, 0.9915087120896731, 0.686721017790717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 184}], {
             RGBColor[
             0.9905333071232009, 0.9900670052848946, 0.7857410021020834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 189}], {
             RGBColor[
             0.9925199993554016, 0.990888553578571, 0.7528163704198318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 194}], {
             RGBColor[
             0.9936045957470161, 0.9913370620593596, 0.7348418013652921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 197}], {
             RGBColor[
             0.9594776109591536, 0.8640098414111573, 0.4747216857102906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 70}], {
             RGBColor[
             0.9740114299082373, 0.9214295902011911, 0.5048366672446081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 110}], {
             RGBColor[
             0.9733108851883291, 0.9211398969563309, 0.5164465062051067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 132}], {
             RGBColor[
             0.97266037322819, 0.9184907703778553, 0.3542173445766089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 138}], {
             RGBColor[
             0.9711112722838713, 0.9202303004928645, 0.5528997844476937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 145}], {
             RGBColor[
             0.934458383201645, 0.7778563603832653, 0.266121880545811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 153}], {
             RGBColor[
             0.9737739853026115, 0.9208726740015909, 0.4754271464603031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 185}], {
             RGBColor[
             0.9127757892814864, 0.6828262696306198, 0.24820659046966004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 65}], {
             RGBColor[
             0.934901094729692, 0.9357853995444163, 0.6922026187709225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 132}], {
             RGBColor[
             0.9387546361479282, 0.948771935393687, 0.7082242625862656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 138}], {
             RGBColor[
             0.9372055352036095, 0.9505114655086961, 0.9069067024573504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 153}], {
             RGBColor[
             0.9398682482223497, 0.9511538390174226, 0.8294340644699597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 156}], {
             RGBColor[
             0.9250160099409133, 0.9024406874235822, 0.6538009310081443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 182}], {
             RGBColor[
             0.5319566192564759, 0.6082610102757336, 0.9611964857687744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 185}], {
             RGBColor[
             0.8788700522012246, 0.7131074346464515, 0.6022135084793167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 199}], {
             RGBColor[
             0.5319566192564759, 0.6082610102757336, 0.9611964857687744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 118}], {
             RGBColor[
             0.9637637634619824, 0.9586188731096851, 0.6886859020235352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 119}], {
             RGBColor[
             0.9620456196146315, 0.8786982812145343, 0.3327554707228619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 123}], {
             RGBColor[
             0.9881914455809945, 0.9756117529219084, 0.5924672104495248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 127}], {
             RGBColor[
             0.9843309642817423, 0.9588068046370823, 0.39362918439402284`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 140}], {
             RGBColor[
             0.9820011253665843, 0.9509477109040626, 0.3845782001617955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 151}], {
             RGBColor[
             0.9287849084179648, 0.7377648136394006, 0.3055241557126905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 155}], {
             RGBColor[
             0.9853737626922778, 0.9744465686362768, 0.6391635078451268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 156}], {
             RGBColor[
             0.9749308661576535, 0.9270980664165314, 0.3571115782415182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 171}], {
             RGBColor[
             0.9873318676873444, 0.9752562953727397, 0.606712640663587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 172}], {
             RGBColor[
             0.581871475473216, 0.6329183892686827, 0.6645071330021481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 191}], {
             RGBColor[
             0.9880542102757806, 0.9755550025964159, 0.5947415546105039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 195}], {
             RGBColor[
             0.9332739773003913, 0.934487980273218, 0.6920474228579709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 199}], {
             RGBColor[
             0.581871475473216, 0.6329183892686827, 0.6645071330021481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 78}], {
             RGBColor[
             0.9818796567910122, 0.9839432747813825, 0.815534330638008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 80}], {
             RGBColor[
             0.981212636621676, 0.9825165860852565, 0.7429333015770875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 82}], {
             RGBColor[
             0.5738606030158988, 0.6408206752350442, 0.9356042244001594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[
             0.5738606030158988, 0.6408206752350442, 0.9356042244001594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 100}], {
             RGBColor[
             0.9745403689009842, 0.9805328293294495, 0.9279806939020849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 113}], {
             RGBColor[
             0.948846888571469, 0.8660324366394114, 0.5996782893280099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 120}], {
             RGBColor[
             0.9498653638766656, 0.8700703518377397, 0.6004977784652592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 124}], {
             RGBColor[
             0.9816049453846916, 0.9841030534228966, 0.8399587673252789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 136}], {
             RGBColor[
             0.9396706487257536, 0.8296517034518094, 0.5922948713541147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 187}], {
             RGBColor[
             0.5738606030158988, 0.6408206752350442, 0.9356042244001594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 79}], {
             RGBColor[
             0.9928047854217399, 0.9912926081103786, 0.7689068563875954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 82}], {
             RGBColor[
             0.5863996058003889, 0.6485640081335061, 0.842358921095269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 100}], {
             RGBColor[
             0.9870793716854742, 0.9882761622279115, 0.8347353905971946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 122}], {
             RGBColor[
             0.9660853505838745, 0.8924075593746039, 0.510214281228386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 125}], {
             RGBColor[
             0.9932630795215882, 0.9892149387915878, 0.5965112698780061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 137}], {
             RGBColor[
             0.9492883536644494, 0.8258130638564967, 0.4966990232308247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 166}], {
             RGBColor[
             0.959712578785772, 0.8671416427954407, 0.5050865994514528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 170}], {
             RGBColor[
             0.9467218775649124, 0.8142968378709499, 0.49456460759774734`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 179}], {
             RGBColor[
             0.9939014276636943, 0.9905803009206553, 0.6659915257181701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 192}], {
             RGBColor[
             0.9923314088249335, 0.9910968547223755, 0.7767519316560385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 71}], {
             RGBColor[
             0.9555318993395558, 0.8524898468634667, 0.3295127155976805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 75}], {
             RGBColor[
             0.973947190993419, 0.9679182618197855, 0.6750665695637126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 81}], {
             RGBColor[
             0.9876737713614059, 0.9773178553985293, 0.614318583577671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 102}], {
             RGBColor[
             0.9900694995631614, 0.9783085505773617, 0.574615167328741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 127}], {
             RGBColor[
             0.9849797354944392, 0.9609952622762336, 0.3961495380451867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 129}], {
             RGBColor[
             0.9763812631654876, 0.9319905960933677, 0.3627460967324606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 140}], {
             RGBColor[
             0.9826498965792811, 0.9531361685432138, 0.3870985538129593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 143}], {
             RGBColor[
             0.9904318756517867, 0.9779996756495228, 0.5352650653544974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 155}], {
             RGBColor[
             0.9860225339049746, 0.976635026275428, 0.6416838614962906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 172}], {
             RGBColor[
             0.582520246685913, 0.6351068469078339, 0.6670274866533121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 188}], {
             RGBColor[
             0.9651036082923456, 0.9613227323213627, 0.6900364483008563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 86}], {
             RGBColor[
             0.948168763505252, 0.8316431332213516, 0.28012379161854495`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 92}], {
             RGBColor[
             0.9473023259766467, 0.9109709428729416, 0.6414648466745883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 118}], {
             RGBColor[
             0.9503015854773185, 0.9132077856977059, 0.6363878826721109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 123}], {
             RGBColor[
             0.9747292675963304, 0.9302006655099291, 0.5401691910981006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 139}], {
             RGBColor[
             0.9751183560638319, 0.9303615635903585, 0.5337209882629257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 146}], {
             RGBColor[
             0.9623543053832212, 0.8846743738074735, 0.30825401451706724`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 171}], {
             RGBColor[
             0.9738696897026804, 0.9298452079607606, 0.5544146213121627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 174}], {
             RGBColor[
             0.9758295456700048, 0.929349116786734, 0.4269629264183603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 186}], {
             RGBColor[
             0.9448738414827105, 0.8185798653696499, 0.27747262001744777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 191}], {
             RGBColor[
             0.9745920322911166, 0.9301439151844367, 0.5424435352590797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 195}], {
             RGBColor[
             0.9198117993157273, 0.8890768928612389, 0.6397494035065467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 196}], {
             RGBColor[
             0.9594907117515475, 0.875014800084079, 0.2971294940022967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 110}], {
             RGBColor[
             0.994524602423091, 0.9920037966377182, 0.7404050379314793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 132}], {
             RGBColor[
             0.9938740904629519, 0.9893546700592426, 0.5781758763029815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 138}], {
             RGBColor[
             0.9923249895186332, 0.9910942001742518, 0.7768583161740663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.9556721004364069, 0.8487202600646526, 0.4900804122721835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 185}], {
             RGBColor[
             0.9339895065162483, 0.753690169312007, 0.47216512219603257`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 73}], {
             RGBColor[
             0.9566482343414573, 0.8648044266121087, 0.5506346100621866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 75}], {
             RGBColor[
             0.943365596961149, 0.8555884148675843, 0.6040253118547689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 76}], {
             RGBColor[
             0.9577576462390103, 0.8652631969423321, 0.532248783853775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 81}], {
             RGBColor[
             0.9570921773291359, 0.8649880084463282, 0.5432773258687273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 87}], {
             RGBColor[
             0.9581499967516425, 0.8654254439622537, 0.5257465204888828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 89}], {
             RGBColor[
             0.9482763511362228, 0.8280151790898919, 0.3013262809230409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 107}], {
             RGBColor[
             0.551938652653643, 0.5227769999556328, 0.5959862289443685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 127}], {
             RGBColor[
             0.9543981414621692, 0.8486654153240324, 0.3251082803362431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 129}], {
             RGBColor[
             0.9457996691332176, 0.8196607491411665, 0.29170483902351707`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 141}], {
             RGBColor[
             0.9489152986569651, 0.8301704991093678, 0.30380847138600986`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 142}], {
             RGBColor[
             0.9484370974245313, 0.8593707316093551, 0.595440584429425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 147}], {
             RGBColor[
             0.9594665145157983, 0.8659698578906954, 0.503928414098062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 155}], {
             RGBColor[
             0.9554409398727046, 0.8643051793232268, 0.5706426037873471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 168}], {
             RGBColor[
             0.551938652653643, 0.5227769999556328, 0.5959862289443685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 188}], {
             RGBColor[
             0.9345220142600756, 0.8489928853691615, 0.6189951905919127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 197}], {
             RGBColor[
             0.9244776918752081, 0.7382862451421678, 0.25809118202762416`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 76}], {
             RGBColor[
             0.9633381174448234, 0.9711194238235847, 0.8995286409810601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 81}], {
             RGBColor[
             0.962672648534949, 0.9708442353275808, 0.9105571829960124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 104}], {
             RGBColor[
             0.9641851478688838, 0.9714696926716226, 0.8854911548099107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 143}], {
             RGBColor[
             0.9654307528253299, 0.9715260555785744, 0.8315036647728389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 144}], {
             RGBColor[
             0.95441483760803, 0.935753722491558, 0.6707739219863722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 154}], {
             RGBColor[
             0.9382804567252565, 0.953490246198949, 0.9893592671158845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 158}], {
             RGBColor[
             0.9183910216142553, 0.7968617798277594, 0.6159303939729837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 160}], {
             RGBColor[
             0.9619778136720674, 0.9705569032553378, 0.9220723948489441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 176}], {
             RGBColor[
             0.9486228662041546, 0.9162160429267282, 0.6482732068043383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 181}], {
             RGBColor[
             0.9647531318802256, 0.9700766928949833, 0.7577488066899681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 75}], {
             RGBColor[
             0.9750635259953204, 0.9802328415684274, 0.8961884640282187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 87}], {
             RGBColor[
             0.9898479257858139, 0.9900698706630967, 0.8179096726623325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.9799742801703941, 0.9526596057907348, 0.5934894330964906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 107}], {
             RGBColor[
             0.5836365816878143, 0.6474214266564758, 0.8881493811178183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 130}], {
             RGBColor[
             0.990924305692189, 0.9889797857719861, 0.6884787550549313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 142}], {
             RGBColor[
             0.9801350264587028, 0.984015158310198, 0.8876037366028748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 147}], {
             RGBColor[
             0.9911644435499697, 0.9906142845915384, 0.7960915662715117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 149}], {
             RGBColor[
             0.9846081499647032, 0.9682907366913082, 0.6114911422144974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 157}], {
             RGBColor[
             0.9913111702182096, 0.9898072498751407, 0.7305865712611754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 167}], {
             RGBColor[
             0.9916021108750579, 0.9904295425215265, 0.7622536662815003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 168}], {
             RGBColor[
             0.5836365816878143, 0.6474214266564758, 0.8881493811178183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 188}], {
             RGBColor[
             0.9662199432942471, 0.9736373120700045, 0.9111583427653625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 189}], {
             RGBColor[
             0.9892180093056275, 0.9898093840104245, 0.8283490189106152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 197}], {
             RGBColor[
             0.9561756209093795, 0.8629306718430108, 0.550254334201074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 85}], {
             RGBColor[
             0.9581822512946223, 0.9648489018444064, 0.7575733316224011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 88}], {
             RGBColor[
             0.993784777204803, 0.9900712960277276, 0.6344318339669054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 93}], {
             RGBColor[
             0.9901725661276191, 0.9779604370822144, 0.4632150740292248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 95}], {
             RGBColor[
             0.9152244013748978, 0.637044857210431, 0.3528732792288294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 121}], {
             RGBColor[
             0.9937036872857202, 0.990037763262271, 0.6357757037800902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 140}], {
             RGBColor[
             0.9862914182668983, 0.9648684140111492, 0.4481375474835989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 152}], {
             RGBColor[
             0.9932134048440902, 0.989835018872973, 0.6439009526481879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 159}], {
             RGBColor[
             0.9704989244796929, 0.9091239395203432, 0.39966447518995096`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 161}], {
             RGBColor[
             0.9695144967175369, 0.9736287702424584, 0.7497731047677653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 162}], {
             RGBColor[
             0.5861617683735301, 0.6468390923757693, 0.7280664803239516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 164}], {
             RGBColor[
             0.9915771688744048, 0.9891583932501617, 0.6710176171088231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 172}], {
             RGBColor[
             0.5861617683735301, 0.6468390923757693, 0.7280664803239516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 173}], {
             RGBColor[
             0.9928277923829578, 0.9896755582105066, 0.6502915490622088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 180}], {
             RGBColor[
             0.9937978230287076, 0.9891424955317157, 0.5663094959533574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 81}], {
             RGBColor[
             0.9755074689829991, 0.9804164234026469, 0.8888311798347595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 89}], {
             RGBColor[
             0.966691642790086, 0.9434435940462107, 0.6468801348890729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 118}], {
             RGBColor[
             0.9522462322962726, 0.9639058987529538, 0.9657188519317874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 127}], {
             RGBColor[
             0.9728134331160323, 0.9640938302803512, 0.6706621343022752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 129}], {
             RGBColor[
             0.9642149607870807, 0.9350891640974852, 0.6372586929895491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 141}], {
             RGBColor[
             0.9673305903108282, 0.9455989140656866, 0.6493623253520419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 142}], {
             RGBColor[
             0.9668523890783945, 0.9747991465656738, 0.9409944383954572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 147}], {
             RGBColor[
             0.9778818061696615, 0.9813982728470142, 0.8494822680640939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 155}], {
             RGBColor[
             0.9738562315265679, 0.9797335942795455, 0.916196457753379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 168}], {
             RGBColor[
             0.5703539443075061, 0.6382054149119516, 0.9415400829104005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 188}], {
             RGBColor[
             0.9529373059139388, 0.9644213003254802, 0.9645490445579447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 191}], {
             RGBColor[
             0.9765366791100707, 0.9808420282396848, 0.8717745045187562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 81}], {
             RGBColor[
             0.9898995182608604, 0.9900912054773946, 0.8170546518337656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 87}], {
             RGBColor[
             0.9909573376833669, 0.9905286409933202, 0.7995238464539209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 89}], {
             RGBColor[
             0.9810836920679473, 0.9531183761209583, 0.575103606888079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[
             0.9914120175947951, 0.9907166628214366, 0.7919886236476639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 106}], {
             RGBColor[
             0.9874543630271696, 0.9890800709506402, 0.8575772019149224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 107}], {
             RGBColor[
             0.5847459935853674, 0.6478801969866993, 0.8697635549094066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 142}], {
             RGBColor[
             0.9812444383562559, 0.9844739286404215, 0.8692179103944633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 143}], {
             RGBColor[
             0.9926576225512411, 0.9907730257283882, 0.7380011336105919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 147}], {
             RGBColor[
             0.9922738554475228, 0.9910730549217619, 0.7777057400631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 154}], {
             RGBColor[
             0.965507326451168, 0.9727372163487626, 0.8958567359536376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[
             0.9924205821157628, 0.9902660202053641, 0.7122007450527638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 158}], {
             RGBColor[
             0.9456178913401667, 0.8161087499775732, 0.5224278628107368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 176}], {
             RGBColor[
             0.975849735930066, 0.935463013076542, 0.5547706756420914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 181}], {
             RGBColor[
             0.9919800016061369, 0.9893236630447971, 0.6642462755277212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 188}], {
             RGBColor[
             0.9673293551918001, 0.9740960824002279, 0.8927725165569508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 83}], {
             RGBColor[
             0.8971858882313959, 0.605514013943075, 0.2349814258083492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 96}], {
             RGBColor[
             0.9194870328572791, 0.6958630918305437, 0.5340670916190235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 99}], {
             RGBColor[
             0.5156109213171145, 0.35418032649932696`, 0.565605953203051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 112}], {
             RGBColor[
             0.9168009627947554, 0.6757865979402429, 0.28979644142944977`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 143}], {
             RGBColor[
             0.9235225502829882, 0.6970731552410159, 0.4338435319042363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 156}], {
             RGBColor[
             0.9086703120015519, 0.6483600036471756, 0.25821039844242094`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 160}], {
             RGBColor[
             0.9200696111297259, 0.6961040029177792, 0.5244122619803416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 166}], {
             RGBColor[
             0.8889238943024976, 0.5727579611612615, 0.22833363155923486`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 170}], {
             RGBColor[
             0.8759331930816381, 0.5199131562367707, 0.21781163970552936`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 181}], {
             RGBColor[
             0.922844929337884, 0.6956237925574249, 0.36008867382136567`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 183}], {
             RGBColor[
             0.8348069213171145, 0.26854682649932693`, 0.180964453203051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 192}], {
             RGBColor[
             0.9215427243416592, 0.6967131730881964, 0.4999989637638206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 80}], {
             RGBColor[
             0.9942980873808906, 0.9902125103965507, 0.6207601834147767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 82}], {
             RGBColor[
             0.5869460537751134, 0.6485165995463383, 0.8134311062378485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 98}], {
             RGBColor[
             0.5869460537751134, 0.6485165995463383, 0.8134311062378485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 100}], {
             RGBColor[
             0.9876258196601988, 0.9882287536407437, 0.8058075757397741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 113}], {
             RGBColor[
             0.9619323393306837, 0.8737283609507056, 0.4775051711656992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 120}], {
             RGBColor[
             0.9629508146358803, 0.8777662761490339, 0.4783246603029484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 124}], {
             RGBColor[
             0.9946903961439062, 0.9917989777341907, 0.7177856491629682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 136}], {
             RGBColor[
             0.9527560994849682, 0.8373476277631036, 0.47012175319180394`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 187}], {
             RGBColor[
             0.5869460537751134, 0.6485165995463383, 0.8134311062378485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 84}], {
             RGBColor[
             0.585332179621351, 0.6481225999768725, 0.8600489352923264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 122}], {
             RGBColor[
             0.9650179244048367, 0.8919661512179702, 0.5279042954254434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 126}], {
             RGBColor[
             0.9682573786597165, 0.9048095078544311, 0.530510836358684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 177}], {
             RGBColor[
             0.9876558481444819, 0.973552861630514, 0.5886433505229489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 179}], {
             RGBColor[
             0.9928340014846564, 0.9901388927640217, 0.6836815399152275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 190}], {
             RGBColor[
             0.9781302690174529, 0.9819566126508548, 0.8657670272196474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 82}], {
             RGBColor[
             0.5862790336057773, 0.6470899108502123, 0.7408300771769281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 98}], {
             RGBColor[
             0.5862790336057773, 0.6470899108502123, 0.7408300771769281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 100}], {
             RGBColor[
             0.9869587994908626, 0.9868020649446176, 0.7332065466788537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 113}], {
             RGBColor[
             0.9612653191613475, 0.8723016722545796, 0.4049041421047787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 116}], {
             RGBColor[
             0.9935915269001627, 0.9901937083477823, 0.6523414768545563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 120}], {
             RGBColor[
             0.9622837944665441, 0.8763395874529079, 0.4057236312420279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 124}], {
             RGBColor[
             0.99402337597457, 0.9903722890380647, 0.6451846201020477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 125}], {
             RGBColor[
             0.9931425073269766, 0.987740841508294, 0.49498242595966513`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 136}], {
             RGBColor[
             0.952089079315632, 0.8359209390669775, 0.39752072413088346`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 137}], {
             RGBColor[
             0.9491677814698378, 0.8243389665732028, 0.3951701793124839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 187}], {
             RGBColor[
             0.5862790336057773, 0.6470899108502123, 0.7408300771769281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 198}], {
             RGBColor[
             0.9937018210975146, 0.9889371571081782, 0.5558602781982496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 87}], {
             RGBColor[
             0.9902918687734925, 0.9902534524973162, 0.8105523884688732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 89}], {
             RGBColor[
             0.9804182231580729, 0.9528431876249543, 0.5861321489030313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 104}], {
             RGBColor[
             0.9907465486849207, 0.9904414743254326, 0.8030171656626162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 107}], {
             RGBColor[
             0.584080524675493, 0.6476050084906954, 0.880792096924359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 142}], {
             RGBColor[
             0.9805789694463815, 0.9841987401444175, 0.8802464524094156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 143}], {
             RGBColor[
             0.9919921536413667, 0.9904978372323843, 0.7490296756255443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 147}], {
             RGBColor[
             0.9916083865376484, 0.990797866425758, 0.7887342820780524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 154}], {
             RGBColor[
             0.9648418575412936, 0.9724620278527587, 0.90688527796859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 157}], {
             RGBColor[
             0.9917551132058884, 0.9899908317093602, 0.7232292870677162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 158}], {
             RGBColor[
             0.9449524224302923, 0.8158335614815693, 0.5334564048256891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 168}], {
             RGBColor[
             0.584080524675493, 0.6476050084906954, 0.880792096924359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 176}], {
             RGBColor[
             0.9751842670201916, 0.9351878245805381, 0.5657992176570438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 188}], {
             RGBColor[
             0.9666638862819257, 0.973820893904224, 0.9038010585719032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 98}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 100}], {
             RGBColor[
             0.5796067658850854, 0.6451061540944054, 0.9258774695019256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 120}], {
             RGBColor[
             0.5549317608607669, 0.5346436766026956, 0.5983945540650999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 124}], {
             RGBColor[
             0.5866713423687928, 0.6486763781878524, 0.8378555429251195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 125}], {
             RGBColor[
             0.5857904737211994, 0.6460449306580818, 0.6876533487827371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 136}], {
             RGBColor[
             0.5447370457098548, 0.4942250282167653, 0.5901916469539554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 137}], {
             RGBColor[
             0.5418157478640606, 0.4826430557229906, 0.5878411021355557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 187}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 198}], {
             RGBColor[
             0.5863497874917374, 0.6472412462579658, 0.7485312010213215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 122}], {
             RGBColor[
             0.940187711697767, 0.8005712386848458, 0.27073183273841517`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 156}], {
             RGBColor[
             0.9535613575987189, 0.8509073645915967, 0.2954809178446681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 166}], {
             RGBColor[
             0.9338149398996646, 0.7753053221056826, 0.26560415096148204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 170}], {
             RGBColor[
             0.920824238678805, 0.7224605171811918, 0.25508215910777654`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 175}], {
             RGBColor[
             0.967671399322721, 0.8980330327966681, 0.39033053633598175`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 179}], {
             RGBColor[
             0.9680037887775869, 0.8987439802308972, 0.4265090772281993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 183}], {
             RGBColor[
             0.8796979669142815, 0.47109418744374804`, 0.21823497260529817`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 192}], {
             RGBColor[
             0.9664337699388261, 0.8992605340326174, 0.5372694831660678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 126}], {
             RGBColor[
             0.5618521990383656, 0.5620809078775588, 0.6039629010663576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 190}], {
             RGBColor[
             0.5717250893961019, 0.6392280126739822, 0.9392190919273211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 88}], {
             RGBColor[
             0.9585704917523651, 0.9666360131205953, 0.8693732049414034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 117}], {
             RGBColor[
             0.9579989024029121, 0.9644567371044548, 0.7376169362579448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[
             0.9584894018332824, 0.9666024803551387, 0.870717074754588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 133}], {
             RGBColor[
             0.9342835068819508, 0.9501810292337252, 0.9847427519057322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 140}], {
             RGBColor[
             0.9510771328144605, 0.9414331311040169, 0.6830789184580969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 152}], {
             RGBColor[
             0.9579991193916522, 0.9663997359658407, 0.8788423236226859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 159}], {
             RGBColor[
             0.9352846390272549, 0.885688656613211, 0.6346058461644489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 161}], {
             RGBColor[
             0.934300211265099, 0.9501934873353262, 0.9847144757422632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 173}], {
             RGBColor[
             0.9576135069305199, 0.9662402753033743, 0.8852329200367068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 200}], {
             RGBColor[
             0.9532385699734574, 0.9487241661708925, 0.6914756936676415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 92}], {
             RGBColor[
             0.9375794945047946, 0.8729934723808861, 0.6306714109916853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[
             0.9117160852731758, 0.8523968416403817, 0.6291111637365954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 171}], {
             RGBColor[
             0.9641468582308284, 0.8918677374687051, 0.5436211856292597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 174}], {
             RGBColor[
             0.9661067141981527, 0.8913716462946786, 0.4161694907354574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 196}], {
             RGBColor[
             0.9497678802796955, 0.8370373295920235, 0.2863360583193938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 89}], {
             RGBColor[
             0.9814760425805794, 0.9532806231408799, 0.5686013435231868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 106}], {
             RGBColor[
             0.9878467135398017, 0.9892423179705618, 0.85107493855003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 107}], {
             RGBColor[
             0.5851383440979996, 0.6480424440066209, 0.8632612915445144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 130}], {
             RGBColor[
             0.9924260681023742, 0.9896008031221312, 0.6635906654816275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 131}], {
             RGBColor[
             0.978214797471226, 0.9422796776102644, 0.555932022107811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 142}], {
             RGBColor[
             0.9816367888688879, 0.9846361756603431, 0.8627156470295709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 147}], {
             RGBColor[
             0.992666205960155, 0.9912353019416835, 0.7712034766982079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[
             0.9658996769638001, 0.9728994633686843, 0.8893544725887454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 157}], {
             RGBColor[
             0.9928129326283949, 0.9904282672252858, 0.7056984816878715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 168}], {
             RGBColor[
             0.5851383440979996, 0.6480424440066209, 0.8632612915445144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 176}], {
             RGBColor[
             0.9762420864426982, 0.9356252600964636, 0.5482684122771992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 188}], {
             RGBColor[
             0.9677217057044323, 0.9742583294201496, 0.8862702531920585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 91}], {
             RGBColor[
             0.9915330515408574, 0.9907667134685638, 0.7899827779356017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 93}], {
             RGBColor[
             0.9905608065853618, 0.9797475483584033, 0.575014947348227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 95}], {
             RGBColor[
             0.9156126418326405, 0.6388319684866199, 0.4646731525478316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 103}], {
             RGBColor[
             0.5865500088312728, 0.6486262036519583, 0.8398663536429538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 117}], {
             RGBColor[
             0.9936014283130927, 0.9896791312877761, 0.6144754386024489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 121}], {
             RGBColor[
             0.994091927743463, 0.99182487453846, 0.7475755770990924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 152}], {
             RGBColor[
             0.9936016453018328, 0.9916221301491619, 0.7557008259671901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 159}], {
             RGBColor[
             0.9708871649374355, 0.9109110507965321, 0.5114643485089532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 161}], {
             RGBColor[
             0.9699027371752796, 0.9754158815186473, 0.8615729780867675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 164}], {
             RGBColor[
             0.9919654093321476, 0.9909455045263507, 0.7828174904278253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 173}], {
             RGBColor[
             0.9932160328407006, 0.9914626694866955, 0.762091422381211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 180}], {
             RGBColor[
             0.9941860634864503, 0.9909296068079048, 0.6781093692723597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 200}], {
             RGBColor[
             0.988841095883638, 0.9739465603542138, 0.5683341960121457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 106}], {
             RGBColor[
             0.9779730679243821, 0.9518320530982001, 0.6266546989841881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 107}], {
             RGBColor[
             0.5752646984825799, 0.610632179134259, 0.6388410519786725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 142}], {
             RGBColor[
             0.9717631432534684, 0.9472259107879812, 0.638295407463729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 147}], {
             RGBColor[
             0.9827925603447352, 0.9538250370693218, 0.546783237132366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 154}], {
             RGBColor[
             0.9560260313483804, 0.9354891984963225, 0.6649342330229036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 157}], {
             RGBColor[
             0.9829392870129752, 0.953018002352924, 0.48127824212202963`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 168}], {
             RGBColor[
             0.5752646984825799, 0.610632179134259, 0.6388410519786725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 176}], {
             RGBColor[
             0.9663684408272784, 0.8982149952241019, 0.3238481727113573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 188}], {
             RGBColor[
             0.9578480600890126, 0.9368480645477877, 0.6618500136262166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 111}], {
             RGBColor[
             0.9765550617251457, 0.9309009222677551, 0.5059308716543671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 115}], {
             RGBColor[
             0.980277628026345, 0.9434580125018333, 0.5203923387868666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 163}], {
             RGBColor[
             0.9765550617251457, 0.9309009222677551, 0.5059308716543671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 165}], {
             RGBColor[
             0.9939652679581388, 0.9895006433044895, 0.5845348431716131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 169}], {
             RGBColor[
             0.9761877188623851, 0.979874757203916, 0.8391754363817037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 175}], {
             RGBColor[
             0.9942421966450332, 0.9900929657639717, 0.6146768217343268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 177}], {
             RGBColor[
             0.9893964327597244, 0.9742178820646932, 0.5558171732342658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 103}], {
             RGBColor[
             0.5839100427095845, 0.6475345098166054, 0.8836174242926479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 117}], {
             RGBColor[
             0.9909614621914045, 0.9885874374524233, 0.6582265092521431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 121}], {
             RGBColor[
             0.9914519616217746, 0.9907331807031072, 0.7913266477487864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 152}], {
             RGBColor[
             0.9909616791801446, 0.9905304363138091, 0.7994518966168842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 159}], {
             RGBColor[
             0.9682471988157473, 0.9098193569611793, 0.5552154191586472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 164}], {
             RGBColor[
             0.9893254432104592, 0.9898538106909979, 0.8265685610775193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 200}], {
             RGBColor[
             0.9862011297619495, 0.972854866518861, 0.6120852666618398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 118}], {
             RGBColor[
             0.939712316476861, 0.9545581248572403, 0.9869355020452513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 123}], {
             RGBColor[
             0.9641399985958731, 0.9715510046694636, 0.890716810471241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 139}], {
             RGBColor[
             0.9645290870633745, 0.971711902749893, 0.8842686076360662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 141}], {
             RGBColor[
             0.9547966744914168, 0.9362511401699731, 0.6705789754655058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 146}], {
             RGBColor[
             0.9517650363827639, 0.9260247129670081, 0.6588016338902076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 171}], {
             RGBColor[
             0.963280420702223, 0.9711955471202951, 0.9049622406853031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 174}], {
             RGBColor[
             0.9652402766695474, 0.9706994559462685, 0.7775105457915008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 186}], {
             RGBColor[
             0.934284572482253, 0.8599302045291844, 0.6280202393905883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 191}], {
             RGBColor[
             0.9640027632906591, 0.9714942543439713, 0.8929911546322201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 195}], {
             RGBColor[
             0.9092225303152699, 0.9304272320207734, 0.9902970228796871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 196}], {
             RGBColor[
             0.9489014427510902, 0.9163651392436134, 0.6476771133754372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 95}], {
             RGBColor[
             0.9120004307554566, 0.6267211095411066, 0.293456392610151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 121}], {
             RGBColor[
             0.9904797166662791, 0.9797140155929467, 0.5763588171614118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 150}], {
             RGBColor[
             0.9489629196047507, 0.9497446159972616, 0.6975846021127032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 159}], {
             RGBColor[
             0.9672749538602516, 0.8988001918510189, 0.3402475885712726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 161}], {
             RGBColor[
             0.9662905260980957, 0.963305022573134, 0.690356218149087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 162}], {
             RGBColor[
             0.5829377977540889, 0.636515344706445, 0.6686495937052732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 164}], {
             RGBColor[
             0.9883531982549637, 0.9788346455808374, 0.6116007304901447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 173}], {
             RGBColor[
             0.9896038217635167, 0.9793518105411823, 0.5908746624435305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 180}], {
             RGBColor[
             0.9905738524092664, 0.9788187478623913, 0.5068926093346792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 200}], {
             RGBColor[
             0.9852288848064541, 0.9618357014087004, 0.39711743607446515`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 174}], {
             RGBColor[
             0.9393768674379286, 0.9501028252057642, 0.7759502985364107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 196}], {
             RGBColor[
             0.9230380335194714, 0.8957685085031091, 0.6461168661203471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 121}], {
             RGBColor[
             0.9155315519135578, 0.6387984357211633, 0.4660170223610163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 150}], {
             RGBColor[
             0.8740147548520293, 0.6088290361254782, 0.5872428073123077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 159}], {
             RGBColor[
             0.8923267891075304, 0.5578846119792356, 0.2299057937708771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 161}], {
             RGBColor[
             0.8913423613453744, 0.6223894427013507, 0.5800144233486915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 162}], {
             RGBColor[
             0.5079896330013677, 0.29559976483466166`, 0.5583077989048778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 164}], {
             RGBColor[
             0.9134050335022423, 0.6379190657090541, 0.5012589356897492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 173}], {
             RGBColor[
             0.9146556570107953, 0.6384362306693989, 0.48053286764313496`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 180}], {
             RGBColor[
             0.9156256876565452, 0.637903167990608, 0.39655081453428365`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 99}], {
             RGBColor[
             0.5828031115401646, 0.6470767653312168, 0.9019621384159726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 102}], {
             RGBColor[
             0.990352364417413, 0.9902784690007445, 0.8095498190914016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 125}], {
             RGBColor[
             0.989666585261364, 0.9877276959892987, 0.6561144871987097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 128}], {
             RGBColor[
             0.9818637324705002, 0.9855813637694764, 0.8970793979856522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 137}], {
             RGBColor[
             0.9456918594042252, 0.8243258210542075, 0.5563022405515283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 166}], {
             RGBColor[
             0.9561160845255479, 0.8656543999931514, 0.5646898167721565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 170}], {
             RGBColor[
             0.9431253833046883, 0.8128095950686607, 0.554167824918451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 198}], {
             RGBColor[
             0.9902258990319021, 0.9889240115891826, 0.7169923394372941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 105}], {
             RGBColor[
             0.993463811264086, 0.9884280781409597, 0.5299543766559638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 134}], {
             RGBColor[
             0.9914561385912414, 0.9822073691107296, 0.47524726646311266`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 135}], {
             RGBColor[
             0.9212342444824739, 0.6828667461118408, 0.3658705671909603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 153}], {
             RGBColor[
             0.9941405259764617, 0.9898755024843788, 0.6036105968989636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 100}], {
             RGBColor[
             0.5796067658850854, 0.6451061540944054, 0.9258774695019256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 109}], {
             RGBColor[
             0.5506993724113656, 0.5178636667606633, 0.5949890749717862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 113}], {
             RGBColor[
             0.5539132855555702, 0.5306057614043673, 0.5975750649278506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 116}], {
             RGBColor[
             0.5862394932943855, 0.6484977974975701, 0.8450123996776282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 120}], {
             RGBColor[
             0.5549317608607669, 0.5346436766026956, 0.5983945540650999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 124}], {
             RGBColor[
             0.5866713423687928, 0.6486763781878524, 0.8378555429251195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 125}], {
             RGBColor[
             0.5857904737211994, 0.6460449306580818, 0.6876533487827371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 136}], {
             RGBColor[
             0.5447370457098548, 0.4942250282167653, 0.5901916469539554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 187}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 102}], {
             RGBColor[
             0.5864762528772485, 0.6485957036695276, 0.841088680675429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 109}], {
             RGBColor[
             0.5506993724113656, 0.5178636667606633, 0.5949890749717862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 116}], {
             RGBColor[
             0.5862394932943855, 0.6484977974975701, 0.8450123996776282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 128}], {
             RGBColor[
             0.5779876209303356, 0.6438985984382595, 0.9286182595696796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 136}], {
             RGBColor[
             0.5447370457098548, 0.4942250282167653, 0.5901916469539554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 137}], {
             RGBColor[
             0.5418157478640606, 0.4826430557229906, 0.5878411021355557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 162}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 193}], {
             RGBColor[
             0.5863866160232505, 0.6473200187629367, 0.7525397593971658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 198}], {
             RGBColor[
             0.5863497874917374, 0.6472412462579658, 0.7485312010213215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 113}], {
             RGBColor[
             0.9545930514406558, 0.8703179154987727, 0.5899515344297761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 120}], {
             RGBColor[
             0.9556115267458523, 0.874355830697101, 0.5907710235670254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 124}], {
             RGBColor[
             0.9873511082538782, 0.9883885322822579, 0.830232012427045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 125}], {
             RGBColor[
             0.9864702396062848, 0.9857570847524871, 0.6800298182846626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 136}], {
             RGBColor[
             0.9454168115949402, 0.8339371823111706, 0.5825681164558809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 137}], {
             RGBColor[
             0.942495513749146, 0.822355209817396, 0.5802175716374813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 187}], {
             RGBColor[
             0.5796067658850854, 0.6451061540944054, 0.9258774695019256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 198}], {
             RGBColor[
             0.9870295533768229, 0.9869534003523712, 0.7409076705232471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 105}], {
             RGBColor[
             0.586161914253498, 0.6468394043982699, 0.7280823584581857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 134}], {
             RGBColor[
             0.5841542415806533, 0.6406186953680397, 0.6733752482653345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 135}], {
             RGBColor[
             0.513932347471886, 0.341278072369151, 0.5639985489931821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 144}], {
             RGBColor[
             0.5758227137485741, 0.6125144956546724, 0.6410088359147188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 128}], {
             RGBColor[
             0.985536873807584, 0.9871003021077871, 0.8362059402451085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 140}], {
             RGBColor[
             0.9866059027706167, 0.9666250253049076, 0.5611597478350763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 162}], {
             RGBColor[
             0.5864762528772485, 0.6485957036695277, 0.841088680675429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 172}], {
             RGBColor[
             0.5864762528772485, 0.6485957036695277, 0.841088680675429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 180}], {
             RGBColor[
             0.9941123075324259, 0.990899106825474, 0.6793316963048348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 117}], {
             RGBColor[
             0.5859784194818198, 0.6464469276358178, 0.7081100849594952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 152}], {
             RGBColor[
             0.5859786364705599, 0.6483899264972037, 0.8493354723242363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 178}], {
             RGBColor[
             0.5627049772219976, 0.5654618892041758, 0.6046490664101847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 200}], {
             RGBColor[
             0.5812180870523651, 0.6307143567022555, 0.661968842369192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 143}], {
             RGBColor[
             0.9935046529753015, 0.9911232945764261, 0.7239636474394426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 154}], {
             RGBColor[
             0.9663543568752282, 0.9730874851968007, 0.8818192497824883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 158}], {
             RGBColor[
             0.946464921764227, 0.8164590188256111, 0.5083903766395874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 160}], {
             RGBColor[
             0.990051713822039, 0.9901541422531895, 0.8145323775155479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 176}], {
             RGBColor[
             0.9766967663541263, 0.9358132819245799, 0.5407331894709421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 181}], {
             RGBColor[
             0.9928270320301973, 0.9896739318928351, 0.6502087893565719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 188}], {
             RGBColor[
             0.9681763856158605, 0.974446351248266, 0.8787350303858015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 134}], {
             RGBColor[
             0.9913891558341513, 0.9820640997663095, 0.46795660672352013`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 135}], {
             RGBColor[
             0.9211672617253839, 0.6827234767674208, 0.3585799074513678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 144}], {
             RGBColor[
             0.983057628002072, 0.9539599000529423, 0.43559019437290447`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.5816353694418022, 0.646593873963941, 0.9213146470055158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 130}], {
             RGBColor[
             0.9889230934461768, 0.9881522330794512, 0.7216440209426288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 131}], {
             RGBColor[
             0.9747118228150287, 0.9408311075675846, 0.6139853775688123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 142}], {
             RGBColor[
             0.9781338142126906, 0.9831876056176632, 0.9207690024905724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 147}], {
             RGBColor[
             0.9891632313039576, 0.9897867318990036, 0.8292568321592092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 157}], {
             RGBColor[
             0.9893099579721976, 0.9889796971826059, 0.763751837148873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 176}], {
             RGBColor[
             0.9727391117865007, 0.9341766900537837, 0.6063217677382006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 130}], {
             RGBColor[
             0.5862147240043747, 0.6469523591155102, 0.733830373937113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 131}], {
             RGBColor[
             0.5720034533732263, 0.5996312336036436, 0.6261717305632966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 142}], {
             RGBColor[
             0.5754254447708884, 0.6419877316537221, 0.9329553554850567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[
             0.5864548618621555, 0.6485868579350627, 0.8414431851536934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 154}], {
             RGBColor[
             0.5596883328658004, 0.6302510193620634, 0.959594181044231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.5866015885303952, 0.6477798232186649, 0.7759381901433572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 168}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 176}], {
             RGBColor[
             0.5700307423446986, 0.5929768160898428, 0.6185081207326848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 188}], {
             RGBColor[
             0.5615103616064328, 0.6316098854135286, 0.9565099616475442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 111}], {
             RGBColor[
             0.9763604947035561, 0.9304847630823186, 0.48475345208282056`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 115}], {
             RGBColor[
             0.9800830610047554, 0.9430418533163968, 0.49921491921532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 133}], {
             RGBColor[
             0.9702142211758626, 0.9751486809907031, 0.8277802390393794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 151}], {
             RGBColor[
             0.9337916301597529, 0.753217885596333, 0.4470623611426389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 163}], {
             RGBColor[
             0.9763604947035561, 0.9304847630823186, 0.48475345208282056`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 165}], {
             RGBColor[
             0.9937707009365492, 0.989084484119053, 0.5633574236000665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 175}], {
             RGBColor[
             0.9940476296234436, 0.9896768065785351, 0.5934994021627802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 113}], {
             RGBColor[
             0.9256856579669359, 0.7430754281650307, 0.2590631398996368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 116}], {
             RGBColor[
             0.958011865705751, 0.8609674642582335, 0.5065004746494144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 124}], {
             RGBColor[
             0.9584437147801584, 0.8611460449485158, 0.49934361789690573`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 128}], {
             RGBColor[
             0.9497599933417012, 0.8563682651989228, 0.5901063345414657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 136}], {
             RGBColor[
             0.9165094181212203, 0.7066946949774287, 0.2516797219257415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 148}], {
             RGBColor[
             0.9167244942620273, 0.83109293805148, 0.6239240833792161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 193}], {
             RGBColor[
             0.9581589884346161, 0.8597896855235999, 0.41402783436895196`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 138}], {
             RGBColor[
             0.991624444798725, 0.9908045069293916, 0.7884681551345649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 145}], {
             RGBColor[
             0.9549715557164987, 0.8484305668197925, 0.5016902512326822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 115}], {
             RGBColor[
             0.9616141612783033, 0.8821776939474852, 0.3053786944339474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 163}], {
             RGBColor[
             0.9578915949771041, 0.8696206037134071, 0.29091722730144787`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 165}], {
             RGBColor[
             0.9753018012100971, 0.9282203247501415, 0.3695211988186938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 169}], {
             RGBColor[
             0.9575242521143434, 0.9185944386495679, 0.6241617920287843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 175}], {
             RGBColor[
             0.9755787298969916, 0.9288126472096236, 0.3996631773814075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 177}], {
             RGBColor[
             0.9707329660116829, 0.9129375635103452, 0.34080352888134646`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 134}], {
             RGBColor[
             0.9853442830582944, 0.9622249668089558, 0.3975657364917332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 143}], {
             RGBColor[
             0.9880286704435147, 0.969893100182605, 0.5259290669275841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 156}], {
             RGBColor[
             0.9731764321620784, 0.9211799485887646, 0.3502959334657687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 160}], {
             RGBColor[
             0.9845757312902523, 0.9689239478593683, 0.6164977970036893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 181}], {
             RGBColor[
             0.9873510494984105, 0.9684437374990138, 0.45217420884471343`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 183}], {
             RGBColor[
             0.8993130414776409, 0.541366771440916, 0.27304998822639875`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 116}], {
             RGBColor[
             0.9612257788499556, 0.8737095589019374, 0.5090864646054788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 124}], {
             RGBColor[
             0.961657627924363, 0.8738881395922198, 0.5019296078529701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 128}], {
             RGBColor[
             0.9529739064859059, 0.8691103598426269, 0.5926923244975302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 136}], {
             RGBColor[
             0.9197233312654249, 0.7194367896211326, 0.25426571188180597`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 148}], {
             RGBColor[
             0.9199384074062319, 0.843835032695184, 0.6265100733352805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 187}], {
             RGBColor[
             0.5539132855555703, 0.5306057614043673, 0.5975750649278506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 193}], {
             RGBColor[
             0.9613729015788207, 0.8725317801673038, 0.41661382432501637`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 198}], {
             RGBColor[
             0.9613360730473077, 0.8724530076623331, 0.41260526594917213`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 167}], {
             RGBColor[
             0.9944379313432148, 0.9905116224915685, 0.6359813356968662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 184}], {
             RGBColor[
             0.9900671375415837, 0.9890699156867901, 0.7350013200082326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 186}], {
             RGBColor[
             0.9629369461501297, 0.8785760701394643, 0.42714055689990793`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 194}], {
             RGBColor[
             0.993138426165399, 0.9903399724612552, 0.6841021192714414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 133}], {
             RGBColor[
             0.95546788775061, 0.9268416118558698, 0.648405481390506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 163}], {
             RGBColor[
             0.9616141612783033, 0.8821776939474852, 0.3053786944339474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 165}], {
             RGBColor[
             0.9790243675112964, 0.9407774149842196, 0.38398266595119324`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 175}], {
             RGBColor[
             0.9793012961981908, 0.9413697374437018, 0.41412464451390696`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 124}], {
             RGBColor[
             0.9939838356631783, 0.9917801756854225, 0.7493669426027477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 128}], {
             RGBColor[
             0.9853001142247211, 0.9870023959358296, 0.8401296592473078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 136}], {
             RGBColor[
             0.9520495390042402, 0.8373288257143353, 0.5017030466315835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 148}], {
             RGBColor[
             0.9522646151450471, 0.9617270687883868, 0.8739474080850581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 193}], {
             RGBColor[
             0.9936991093176359, 0.9904238162605066, 0.664051159074794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 198}], {
             RGBColor[
             0.9936622807861228, 0.9903450437555359, 0.6600426006989497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 121}], {
             RGBColor[
             0.9935203383940101, 0.9896455985223195, 0.6158193084156337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 152}], {
             RGBColor[
             0.9930300559523799, 0.9894428541330214, 0.6239445572837314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 159}], {
             RGBColor[
             0.9703155755879826, 0.9087317747803916, 0.3797080798254945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 164}], {
             RGBColor[
             0.9913938199826946, 0.9887662285102101, 0.6510612217443666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 178}], {
             RGBColor[
             0.9697563967038174, 0.9065148168399937, 0.37925815136967983`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 200}], {
             RGBColor[
             0.988269506534185, 0.9717672843380732, 0.4365779273286871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 119}], {
             RGBColor[
             0.9409934321301818, 0.8768743757868539, 0.6259281067421006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 123}], {
             RGBColor[
             0.9671392580965448, 0.9737878474942279, 0.8856398464687636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 127}], {
             RGBColor[
             0.9632787767972926, 0.9569828992094019, 0.6868018204132615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 129}], {
             RGBColor[
             0.954680304468341, 0.927978233026536, 0.6533983791005356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 139}], {
             RGBColor[
             0.9675283465640463, 0.9739487455746573, 0.8791916436335887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[
             0.9577959339920885, 0.9384879829947373, 0.6655020114630283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 146}], {
             RGBColor[
             0.9547642958834356, 0.9282615557917723, 0.6537246698877303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 155}], {
             RGBColor[
             0.9643215752078282, 0.9726226632085964, 0.9323361438643656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 171}], {
             RGBColor[
             0.9662796802028948, 0.9734323899450594, 0.8998852766828257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 191}], {
             RGBColor[
             0.967002022791331, 0.9737310971687355, 0.8879141906297428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.9122217898159417, 0.9326640748455377, 0.9852200588772098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 196}], {
             RGBColor[
             0.9519007022517619, 0.9186019820683777, 0.6426001493729597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[
             0.5608192879887665, 0.6310944838410023, 0.957679769021387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 123}], {
             RGBColor[
             0.9654211142491939, 0.8938672555990772, 0.5297094151680903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 127}], {
             RGBColor[
             0.9615606329499417, 0.8770623073142512, 0.33087138911258834`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 140}], {
             RGBColor[
             0.9592307940347837, 0.8692032135812314, 0.321820404880361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 151}], {
             RGBColor[
             0.9060145770861642, 0.6560203163165694, 0.242766360431256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 155}], {
             RGBColor[
             0.9626034313604772, 0.8927020713134456, 0.5764057125636923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 156}], {
             RGBColor[
             0.9521605348258528, 0.8453535690937002, 0.29435378296008363`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 172}], {
             RGBColor[
             0.5591011441414154, 0.5511738919458515, 0.6017493377207137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 191}], {
             RGBColor[
             0.9652838789439799, 0.8938105052735847, 0.5319837593290695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 195}], {
             RGBColor[
             0.9105036459685907, 0.8527434829503868, 0.6292896275765365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 199}], {
             RGBColor[
             0.5591011441414154, 0.5511738919458515, 0.6017493377207137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 124}], {
             RGBColor[
             0.9626761032295597, 0.8779260547905481, 0.5027490969902193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 125}], {
             RGBColor[
             0.9617952345819663, 0.8752946072607773, 0.35254690284783685`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 136}], {
             RGBColor[
             0.9207418065706217, 0.7234747048194609, 0.2550852010190552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 137}], {
             RGBColor[
             0.9178205087248275, 0.7118927323256862, 0.2527346562006556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 187}], {
             RGBColor[
             0.5549317608607669, 0.5346436766026956, 0.5983945540650999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 198}], {
             RGBColor[
             0.9623545483525042, 0.8764909228606614, 0.41342475508642135`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 152}], {
             RGBColor[
             0.9935205553827502, 0.9915885973837053, 0.7570446957803749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 159}], {
             RGBColor[
             0.9708060750183529, 0.9108775180310755, 0.5128082183221379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 161}], {
             RGBColor[
             0.9698216472561969, 0.9753823487531907, 0.8629168478999523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 164}], {
             RGBColor[
             0.9918843194130649, 0.9909119717608941, 0.78416136024101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 173}], {
             RGBColor[
             0.9931349429216179, 0.9914291367212389, 0.7634352921943958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 180}], {
             RGBColor[
             0.9941049735673676, 0.9908960740424482, 0.6794532390855444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[
             0.9887600059645552, 0.9739130275887572, 0.5696780658253304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 125}], {
             RGBColor[
             0.965476218504685, 0.8898884818991795, 0.355508708915854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 137}], {
             RGBColor[
             0.9215014926475462, 0.7264866069640883, 0.2556964622686727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 166}], {
             RGBColor[
             0.9319257177688688, 0.7678151859030322, 0.26408403848930084`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 170}], {
             RGBColor[
             0.9189350165480092, 0.7149703809785415, 0.25356204663559534`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 179}], {
             RGBColor[
             0.9661145666467911, 0.8912538440282469, 0.4249889647560181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 192}], {
             RGBColor[
             0.9645445478080303, 0.8917703978299671, 0.5357493706938865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 127}], {
             RGBColor[
             0.9877064589163046, 0.9739757790216252, 0.5905831288392512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 129}], {
             RGBColor[
             0.979107986587353, 0.9449711128387592, 0.5571796875265251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 139}], {
             RGBColor[
             0.9919560286830582, 0.9909416253868806, 0.7829729520595783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 141}], {
             RGBColor[
             0.9822236161111005, 0.9554808628069607, 0.5692833198890179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 146}], {
             RGBColor[
             0.9791919780024476, 0.9452544356039956, 0.55750597831372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 155}], {
             RGBColor[
             0.9887492573268402, 0.9896155430208196, 0.8361174522903552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 171}], {
             RGBColor[
             0.9907073623219067, 0.9904252697572826, 0.8036665851088154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 191}], {
             RGBColor[
             0.9914297049103429, 0.9907239769809588, 0.7916954990557323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 195}], {
             RGBColor[
             0.9366494719349536, 0.9496569546577609, 0.8890013673031993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 196}], {
             RGBColor[
             0.976328384370774, 0.9355948618806009, 0.5463814577989494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 199}], {
             RGBColor[
             0.5852469701077784, 0.6480873636532256, 0.8614610774473765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 125}], {
             RGBColor[
             0.9935348160899922, 0.9893273088459342, 0.5920078917078566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 136}], {
             RGBColor[
             0.9524813880786476, 0.8375074064046177, 0.4945461898790749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.9495600902328534, 0.825925433910843, 0.49219564506067526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 187}], {
             RGBColor[
             0.5866713423687928, 0.6486763781878524, 0.8378555429251195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 198}], {
             RGBColor[
             0.9940941298605301, 0.9905236244458182, 0.652885743946441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 136}], {
             RGBColor[
             0.9516005194310542, 0.834875958874847, 0.3443439957366924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 137}], {
             RGBColor[
             0.94867922158526, 0.8232939863810723, 0.3419934509182928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 166}], {
             RGBColor[
             0.9591034467065825, 0.8646225653200164, 0.35038102713892094`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[
             0.946112745485723, 0.8117777603955255, 0.33985903528521544`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 187}], {
             RGBColor[
             0.5857904737211994, 0.6460449306580818, 0.6876533487827371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 192}], {
             RGBColor[
             0.9917222767457441, 0.9885777772469512, 0.6220463593435066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 198}], {
             RGBColor[
             0.9932132612129367, 0.9878921769160476, 0.5026835498040586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 190}], {
             RGBColor[
             0.9546502884344674, 0.895914920551541, 0.6096809929936786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 129}], {
             RGBColor[
             0.9752475052881008, 0.9281661645539333, 0.3583416614710232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 139}], {
             RGBColor[
             0.988095547383806, 0.9741366771020545, 0.5841349260040765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 140}], {
             RGBColor[
             0.9815161387018945, 0.9493117370037795, 0.38269411855152197`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 141}], {
             RGBColor[
             0.9783631348118483, 0.9386759145221346, 0.37044529383351604`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 155}], {
             RGBColor[
             0.984888776027588, 0.9728105947359936, 0.6372794262348532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 172}], {
             RGBColor[
             0.5813864888085262, 0.6312824153683996, 0.6626230513918747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 191}], {
             RGBColor[
             0.9875692236110907, 0.9739190286961328, 0.5928574730002304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 195}], {
             RGBColor[
             0.9327889906357014, 0.9328520063729349, 0.6901633412476974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 199}], {
             RGBColor[
             0.5813864888085262, 0.6312824153683996, 0.6626230513918747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 136}], {
             RGBColor[
             0.9437976666401904, 0.8327296266550248, 0.585308906523635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 162}], {
             RGBColor[
             0.5779876209303356, 0.6438985984382595, 0.9286182595696796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 193}], {
             RGBColor[
             0.985447236953586, 0.9858246172011961, 0.7476570189668453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 198}], {
             RGBColor[
             0.985410408422073, 0.9857458446962253, 0.7436484605910011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 139}], {
             RGBColor[
             0.9794970750548544, 0.9451320109191886, 0.5507314846913504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 141}], {
             RGBColor[
             0.9697646624828967, 0.9096712483392687, 0.33704185252079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 146}], {
             RGBColor[
             0.9667330243742438, 0.8994448211363036, 0.3252645109454919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 155}], {
             RGBColor[
             0.9762903036986363, 0.9438059285531277, 0.6038759849221271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 191}], {
             RGBColor[
             0.9789707512821391, 0.9449143625132669, 0.5594540316875043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 195}], {
             RGBColor[
             0.9241905183067498, 0.9038473401900691, 0.6567598999349713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 131}], {
             RGBColor[
             0.9792911773776011, 0.9411895927191538, 0.4265011045004097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 149}], {
             RGBColor[
             0.9871862922812635, 0.9678216691503426, 0.4571721350337923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 157}], {
             RGBColor[
             0.99388931253477, 0.9893381823341751, 0.5762675640804702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 168}], {
             RGBColor[
             0.5862147240043747, 0.6469523591155103, 0.733830373937113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 189}], {
             RGBColor[
             0.9917961516221878, 0.989340316469459, 0.6740300117299101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 197}], {
             RGBColor[
             0.9587537632259399, 0.8624616043020452, 0.3959353270203688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 147}], {
             RGBColor[
             0.9795313152353817, 0.9428240915387063, 0.5341139157169901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 157}], {
             RGBColor[
             0.9796780419036217, 0.9420170568223085, 0.4686089207066538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 176}], {
             RGBColor[
             0.9631071957179249, 0.8872140496934864, 0.31117885129598144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 138}], {
             RGBColor[
             0.9909739328385858, 0.988155380350916, 0.6262389935060673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 145}], {
             RGBColor[
             0.9543210437563596, 0.8457814402413169, 0.3394610896041844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 153}], {
             RGBColor[
             0.993636645857326, 0.9887977538596423, 0.5487663555186766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 182}], {
             RGBColor[
             0.5857250168914523, 0.6459049251179534, 0.6805287768174912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 185}], {
             RGBColor[
             0.932638449836201, 0.7507513494886713, 0.32154579952803347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 163}], {
             RGBColor[
             0.9517453214494107, 0.9142845216217916, 0.6339440142580066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 178}], {
             RGBColor[
             0.9460410011828562, 0.892239108969264, 0.6263839670174673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 135}], {
             RGBColor[
             0.9191595890525392, 0.6765027677371906, 0.30387279725851657`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 160}], {
             RGBColor[
             0.9886129313932648, 0.9825423717864921, 0.6321815570426251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 144}], {
             RGBColor[
             0.91082806122046, 0.6483985680238235, 0.27150638490790086`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 148}], {
             RGBColor[
             0.9107621675605164, 0.807454299507582, 0.6191266553613852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 187}], {
             RGBColor[
             0.5447370457098547, 0.4942250282167653, 0.5901916469539553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 193}], {
             RGBColor[
             0.9521966617331052, 0.8361510469797018, 0.40923040635112107`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 198}], {
             RGBColor[
             0.9521598332015921, 0.8360722744747311, 0.4052218479752768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 166}], {
             RGBColor[
             0.9151287208494436, 0.7012206903849252, 0.25056878049173964`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 170}], {
             RGBColor[
             0.9021380196285842, 0.6483758854604343, 0.2400467886380341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 179}], {
             RGBColor[
             0.9493175697273659, 0.8246593485101398, 0.41147370675845685`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 187}], {
             RGBColor[
             0.5418157478640605, 0.4826430557229906, 0.5878411021355558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 192}], {
             RGBColor[
             0.9477475508886052, 0.82517590231186, 0.5222341126963252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 198}], {
             RGBColor[
             0.9492385353557979, 0.8244903019809564, 0.40287130315687725`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 145}], {
             RGBColor[
             0.9527719428120409, 0.847520970356326, 0.5381435294752692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 153}], {
             RGBColor[
             0.9920875449130073, 0.9905372839746516, 0.7474487953897614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 182}], {
             RGBColor[
             0.5841759159471336, 0.6476444552329625, 0.879211216688576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 185}], {
             RGBColor[
             0.9310893488918823, 0.7524908796036804, 0.5202282393991183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 141}], {
             RGBColor[
             0.982612704578602, 0.95564176088739, 0.5628351170538431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 146}], {
             RGBColor[
             0.979581066469949, 0.9454153336844249, 0.5510577754785451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 155}], {
             RGBColor[
             0.9891383457943417, 0.989776441101249, 0.8296692494551803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 171}], {
             RGBColor[
             0.9910964507894082, 0.9905861678377119, 0.7972183822736405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 191}], {
             RGBColor[
             0.9918187933778444, 0.9908848750613881, 0.7852472962205574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 194}], {
             RGBColor[
             0.9923020825847075, 0.9910847275683922, 0.777237943350459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 195}], {
             RGBColor[
             0.9370385604024551, 0.9498178527381902, 0.8825531644680245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 196}], {
             RGBColor[
             0.9767174728382754, 0.9357557599610303, 0.5399332549637745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 151}], {
             RGBColor[
             0.925970082838117, 0.7282697460060978, 0.2945890898701896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 161}], {
             RGBColor[
             0.962409378237375, 0.950212999502069, 0.675278691603461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 162}], {
             RGBColor[
             0.5790566498933682, 0.6234233216353798, 0.6535720671596473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 172}], {
             RGBColor[
             0.5790566498933682, 0.6234233216353798, 0.6535720671596473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 173}], {
             RGBColor[
             0.985722673902796, 0.9662597874701171, 0.5757971358979046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 180}], {
             RGBColor[
             0.9866927045485456, 0.9657267247913263, 0.4918150827890532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 191}], {
             RGBColor[
             0.9852393846959328, 0.966059934963113, 0.583806488768003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 146}], {
             RGBColor[
             0.9698486538979914, 0.909954571104505, 0.3373681433079847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 155}], {
             RGBColor[
             0.9794059332223839, 0.954315678521329, 0.6159796172846199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 167}], {
             RGBColor[
             0.9838691751905657, 0.9557956150187856, 0.5154275276053235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 191}], {
             RGBColor[
             0.9820863808058866, 0.9554241124814682, 0.5715576640499971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 194}], {
             RGBColor[
             0.9825696700127499, 0.9556239649884722, 0.5635483111798987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 195}], {
             RGBColor[
             0.9273061478304974, 0.9143570901582703, 0.6688635322974641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 147}], {
             RGBColor[
             0.9829533066330438, 0.9851805895887848, 0.8408975406387501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 154}], {
             RGBColor[
             0.956186777636689, 0.9668447510157856, 0.9590485365292877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 157}], {
             RGBColor[
             0.9831000333012838, 0.9843735548723871, 0.7753925456284139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 168}], {
             RGBColor[
             0.5754254447708884, 0.6419877316537222, 0.9329553554850567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 176}], {
             RGBColor[
             0.966529187115587, 0.929570547743565, 0.6179624762177415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.9580088063773211, 0.9682036170672509, 0.9559643171326009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 154}], {
             RGBColor[
             0.9675999618316743, 0.9731438481037524, 0.8278317597454163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 158}], {
             RGBColor[
             0.9477105267206731, 0.8165153817325629, 0.45440288660251554`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 160}], {
             RGBColor[
             0.9912973187784851, 0.9902105051601413, 0.7605448874784759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 181}], {
             RGBColor[
             0.9940726369866433, 0.9897302947997868, 0.5962212993195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 188}], {
             RGBColor[
             0.9694219905723065, 0.9745027141552176, 0.8247475403487295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 158}], {
             RGBColor[
             0.9366946115033733, 0.7807430486455464, 0.2936731438160489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 153}], {
             RGBColor[
             0.9554346558307811, 0.8481633438650524, 0.4606708914878786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 185}], {
             RGBColor[
             0.894436459809656, 0.6101169394940813, 0.23345033549723554`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 155}], {
             RGBColor[
             0.9763742951137309, 0.944089251318364, 0.604202275709322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 171}], {
             RGBColor[
             0.9783324001087974, 0.9448989780548269, 0.5717514085277821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 184}], {
             RGBColor[
             0.9764667432802816, 0.9441274810110422, 0.6026701703413918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 186}], {
             RGBColor[
             0.9493365518888276, 0.8336336354637164, 0.29480940723306714`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 191}], {
             RGBColor[
             0.9790547426972337, 0.9451976852785031, 0.5597803224746991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 194}], {
             RGBColor[
             0.9795380319040969, 0.9453975377855072, 0.5517709696046005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 195}], {
             RGBColor[
             0.9242745097218443, 0.9041306629553052, 0.6570861907221661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 196}], {
             RGBColor[
             0.9639534221576647, 0.8900685701781453, 0.3144662812179161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 154}], {
             RGBColor[
             0.9672161947279558, 0.9734438772971261, 0.8675363661979245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 157}], {
             RGBColor[
             0.9941294503925506, 0.9909726811537276, 0.6838803752970506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 168}], {
             RGBColor[
             0.5864548618621553, 0.6485868579350627, 0.8414431851536934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 176}], {
             RGBColor[
             0.9775586042068539, 0.9361696740249054, 0.5264503058863783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 188}], {
             RGBColor[
             0.9690382234685881, 0.9748027433485913, 0.8644521468012376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 150}], {
             RGBColor[
             0.9109772437013233, 0.9318525425816333, 0.9913710168148598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 193}], {
             RGBColor[
             0.9524117378739121, 0.9605492900537532, 0.7814747678045957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 167}], {
             RGBColor[
             0.9878640974641325, 0.969271425899883, 0.5309470462603614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 168}], {
             RGBColor[
             0.5798985682768889, 0.6262633100348324, 0.6568427610966792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 189}], {
             RGBColor[
             0.985479995894702, 0.968651267388781, 0.5970423988894762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 194}], {
             RGBColor[
             0.9865645922863167, 0.9690997758695696, 0.5790678298349364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.9524376074984542, 0.8417725552213673, 0.31894771417993495`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 156}], {
             RGBColor[
             0.9188998236291861, 0.7044201015185665, 0.26712246794991223`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 172}], {
             RGBColor[
             0.5258404329447487, 0.41024042437071795`, 0.5745180227105423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 175}], {
             RGBColor[
             0.9330098653531882, 0.751545769723638, 0.3619720864412258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 183}], {
             RGBColor[
             0.8450364329447487, 0.3246069243707179, 0.18987652271054228`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 199}], {
             RGBColor[
             0.5258404329447487, 0.41024042437071795`, 0.5745180227105423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 159}], {
             RGBColor[
             0.9703157925767227, 0.9106747736417775, 0.5209334671902357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 178}], {
             RGBColor[
             0.9697566136925575, 0.9084578157013796, 0.520483538734421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 200}], {
             RGBColor[
             0.9882697235229251, 0.9737102831994591, 0.5778033146934283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 182}], {
             RGBColor[
             0.5868386289658738, 0.648286828741689, 0.8017385787011854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 185}], {
             RGBColor[
             0.9337520619106225, 0.7531332531124069, 0.44275560141172765`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 157}], {
             RGBColor[
             0.9673629213961958, 0.9726368425807284, 0.8020313711875882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 158}], {
             RGBColor[
             0.9205602306205998, 0.7984795723529374, 0.6122584889455612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 160}], {
             RGBColor[
             0.9641470226784119, 0.9721746957805157, 0.9184004898215217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 176}], {
             RGBColor[
             0.950792075210499, 0.9178338354519062, 0.6446013017769159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 181}], {
             RGBColor[
             0.96692234088657, 0.9716944854201612, 0.7540769016625457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 188}], {
             RGBColor[
             0.9422716944722332, 0.956466904775592, 0.9826031426917752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 172}], {
             RGBColor[
             0.5824292872190617, 0.646922179367594, 0.9081573748429785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 191}], {
             RGBColor[
             0.9886120220216263, 0.9895587926953272, 0.8383917964513343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 195}], {
             RGBColor[
             0.933831789046237, 0.9484917703721294, 0.9356976646988013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 199}], {
             RGBColor[
             0.5824292872190617, 0.646922179367594, 0.9081573748429785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 166}], {
             RGBColor[
             0.9452993636698206, 0.8181513118097832, 0.28883312359555385`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 170}], {
             RGBColor[
             0.9323086624489612, 0.7653065068852924, 0.2783111317418483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 175}], {
             RGBColor[
             0.979155823092877, 0.9408790225007686, 0.41355950897005356`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 183}], {
             RGBColor[
             0.8911823906844374, 0.5139401771478487, 0.24146394523936998`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 199}], {
             RGBColor[
             0.5719863906844375, 0.5995736771478486, 0.62610544523937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 168}], {
             RGBColor[
             0.5866015885303953, 0.6477798232186649, 0.7759381901433572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 176}], {
             RGBColor[
             0.9777053308750938, 0.9353626393085077, 0.460945310876042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 188}], {
             RGBColor[
             0.969184950136828, 0.9739957086321935, 0.7989471517909014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 160}], {
             RGBColor[
             0.9442575875674106, 0.8155462294093263, 0.5449716166786208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 176}], {
             RGBColor[
             0.9309026400994979, 0.7612053690807167, 0.27117242863401503`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.9470329057755689, 0.8150660190489718, 0.38064802851964485`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 161}], {
             RGBColor[
             0.9466168844501694, 0.894468525011263, 0.626805619309813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 162}], {
             RGBColor[
             0.5632641561061628, 0.5676788471445738, 0.6050989948659993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 164}], {
             RGBColor[
             0.9686795566070374, 0.9099981480189663, 0.5480501316508708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 173}], {
             RGBColor[
             0.9699301801155904, 0.9105153129793111, 0.5273240636042567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 180}], {
             RGBColor[
             0.9709002107613403, 0.9099822503005203, 0.4433420104954052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 200}], {
             RGBColor[
             0.9655552431585278, 0.8929992038468293, 0.3335668372351913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[
             0.9906196978333809, 0.9887611424765501, 0.6867900293956053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 162}], {
             RGBColor[
             0.5622797283440067, 0.632183677866689, 0.9552076244438137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 164}], {
             RGBColor[
             0.9676951288448815, 0.9745029787410815, 0.8981587612286852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 173}], {
             RGBColor[
             0.9689457523534345, 0.9750201437014263, 0.8774326931820708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 180}], {
             RGBColor[
             0.9699157829991842, 0.9744870810226354, 0.7934506400732195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 200}], {
             RGBColor[
             0.9645708153963719, 0.9575040345689445, 0.6836754668130056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 172}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 173}], {
             RGBColor[
             0.5855930240094278, 0.6482304658347373, 0.8557260687382573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 180}], {
             RGBColor[
             0.5865630546551774, 0.6476974031559464, 0.771744015629406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 165}], {
             RGBColor[
             0.9753018012100971, 0.9282203247501415, 0.3695211988186938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 175}], {
             RGBColor[
             0.9755787298969916, 0.9288126472096236, 0.3996631773814075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 177}], {
             RGBColor[
             0.9707329660116829, 0.9129375635103452, 0.34080352888134646`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 200}], {
             RGBColor[
             0.9866334875532399, 0.9730336575766478, 0.6049199791540634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 169}], {
             RGBColor[
             0.9749344583473365, 0.9771941596863023, 0.7027657635460303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 175}], {
             RGBColor[
             0.9929889361299846, 0.987412368246358, 0.4782671488986534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 177}], {
             RGBColor[
             0.988143172244676, 0.9715372845470795, 0.41940750039859237`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 170}], {
             RGBColor[
             0.9125622447499069, 0.6897044643993784, 0.24843436485866224`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 179}], {
             RGBColor[
             0.9597417948486886, 0.8659879274490838, 0.419861282979085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 183}], {
             RGBColor[
             0.8714359729853831, 0.43833813466193455`, 0.2115871783561839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 192}], {
             RGBColor[
             0.9581717760099278, 0.866504481250804, 0.5306216889169535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 198}], {
             RGBColor[
             0.9596627604771206, 0.8658188809199003, 0.4112588793775054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 189}], {
             RGBColor[
             0.9924739568050567, 0.9907900732189994, 0.7478049229564792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 194}], {
             RGBColor[
             0.9935585531966713, 0.991238581699788, 0.7298303539019393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 197}], {
             RGBColor[
             0.9594315684088088, 0.8639113610515856, 0.4697102382469378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 188}], {
             RGBColor[
             0.5615103616064328, 0.6316098854135286, 0.9565099616475442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 189}], {
             RGBColor[
             0.5845084276178132, 0.6477819573539487, 0.8737006377927969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 197}], {
             RGBColor[
             0.5514660392215651, 0.520903245186535, 0.5956059530832557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 177}], {
             RGBColor[
             0.9703656231489223, 0.961911398446506, 0.674048093608683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 190}], {
             RGBColor[
             0.9608400440218933, 0.9703151494668467, 0.9511717703053815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 179}], {
             RGBColor[
             0.9467510936278292, 0.813143122524593, 0.4093392911253795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 183}], {
             RGBColor[
             0.8584452717645237, 0.38549332973744377`, 0.20106518650247834`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[
             0.9451810747890683, 0.8136596763263132, 0.5200996970632479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 198}], {
             RGBColor[
             0.9466720592562611, 0.8129740759954096, 0.4007368875237999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 174}], {
             RGBColor[
             0.991807640395581, 0.9895737210340876, 0.6904603204290751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 182}], {
             RGBColor[
             0.5843873922141283, 0.6477319061040571, 0.8757065076614388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 191}], {
             RGBColor[
             0.9905701270166929, 0.9903685194317902, 0.8059409292697945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 195}], {
             RGBColor[
             0.9357898940413035, 0.9493014971085924, 0.9032467975172616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 196}], {
             RGBColor[
             0.9754688064771238, 0.9352394043314325, 0.5606268880130115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 199}], {
             RGBColor[
             0.5843873922141283, 0.6477319061040571, 0.8757065076614388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 173}], {
             RGBColor[
             0.5855930240094278, 0.6482304658347373, 0.8557260687382573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 180}], {
             RGBColor[
             0.5865630546551774, 0.6476974031559464, 0.771744015629406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 191}], {
             RGBColor[
             0.5851097348025645, 0.6480306133277332, 0.8637354216083557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 180}], {
             RGBColor[
             0.9932290786646052, 0.9905338689906836, 0.6939690843676631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 186}], {
             RGBColor[
             0.9628117921756112, 0.8783083784429768, 0.4135183191343602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 196}], {
             RGBColor[
             0.9774286624444481, 0.9347433131574059, 0.43317519311920916`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 183}], {
             RGBColor[
             0.9052924324084395, 0.56106584535292, 0.33631356373068355`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 188}], {
             RGBColor[
             0.9526141039511313, 0.9191927015033714, 0.641517082380229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 179}], {
             RGBColor[
             0.9887524903864363, 0.9728405544407908, 0.48572801985352365`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 190}], {
             RGBColor[
             0.9740487579192327, 0.9646582743276237, 0.6678135071579436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 183}], {
             RGBColor[
             0.9056248218633054, 0.5617767927871492, 0.3724921046229011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 192}], {
             RGBColor[
             0.99236062488785, 0.9899431393760186, 0.6915266151836708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 185}], {
             RGBColor[
             0.5258404329447488, 0.41024042437071795`, 0.5745180227105423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 195}], {
             RGBColor[
             0.5303295018271752, 0.6069635910045352, 0.9610412898558227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 196}], {
             RGBColor[
             0.5700084142629955, 0.5929014982273755, 0.6184213803515728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 199}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 192}], {
             RGBColor[
             0.9040548030245447, 0.5622933465888694, 0.48325251056076957`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 186}], {
             RGBColor[
             0.9589862793797709, 0.8780329725732186, 0.5718887758417723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 194}], {
             RGBColor[
             0.9891877593950402, 0.9897968748950094, 0.8288503382133057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 198}], {
             RGBColor[
             0.5863497874917374, 0.6472412462579658, 0.7485312010213215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 194}], {
             RGBColor[
             0.9911744516272409, 0.9906184231886859, 0.7959257065310542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 197}], {
             RGBColor[
             0.9570474668393784, 0.8632912025404837, 0.5358055908760527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 195}], {
             RGBColor[
             0.9365122366297398, 0.9496002043322684, 0.8912757114641785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 199}], {
             RGBColor[
             0.5851097348025646, 0.6480306133277332, 0.8637354216083557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 197}], {
             RGBColor[
             0.9581320632309929, 0.8637397110212722, 0.517831021821513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 196}], {
             RGBColor[
             0.9214109160901707, 0.8944710892319108, 0.6459616702073956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 199}], {
             RGBColor[
             0.5303295018271752, 0.6069635910045353, 0.9610412898558227]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.04610843439966642], {
             RGBColor[
             0.9869485955081779, 0.9676366894128899, 0.40379818741054646`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.04610843439966642], {
             RGBColor[
             0.993376566286215, 0.988241469955114, 0.5204582992282947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.04610843439966642], {
             RGBColor[
             0.9919965973332827, 0.9909584015663151, 0.782300624537058]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.04610843439966642], {
             RGBColor[
             0.9413259167640585, 0.8050838424883374, 0.27164765925185996`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.04610843439966642], {
             RGBColor[
             0.9945760236604393, 0.9908069879948367, 0.6510118322197556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.04610843439966642], {
             RGBColor[
             0.9367130569761893, 0.9523212820324761, 0.9920124660477287]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.04610843439966642], {
             RGBColor[
             0.9943010642072602, 0.9902188775271518, 0.6210841925942573]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.04610843439966642], {
             RGBColor[
             0.939258599147394, 0.9542197432158178, 0.9877035271356074]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.04610843439966642], {
             RGBColor[
             0.9326061011959356, 0.9490988064481406, 0.993433996551005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.04610843439966642], {
             RGBColor[
             0.99471938007345, 0.9911136128667098, 0.6666152930827394]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.04610843439966642], {
             RGBColor[
             0.9764993514611826, 0.9323889356431976, 0.3632048474621326]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.04610843439966642], {
             RGBColor[
             0.9940108378243803, 0.9917913417730034, 0.7489194469122771]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.04610843439966642], {
             RGBColor[
             0.9688658731597176, 0.9066394209064167, 0.3335502257223609]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.04610843439966642], {
             RGBColor[
             0.9939735356355893, 0.989518327030566, 0.585434728839922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.04610843439966642], {
             RGBColor[
             0.9939641665510345, 0.9894982875060628, 0.5844149618054109]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.04610843439966642], {
             RGBColor[
             0.9233325850929359, 0.733746278334673, 0.25716980223149716`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.04610843439966642], {
             RGBColor[
             0.9742128911750977, 0.924676168211828, 0.35432238101248753`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.04610843439966642], {
             RGBColor[
             0.9931630944423663, 0.9877848752664359, 0.4972232064208806]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.04610843439966642], {
             RGBColor[
             0.98141971126901, 0.9856634316036338, 0.9163357616928639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.04610843439966642], {
             RGBColor[
             0.9928907882488583, 0.9872024398529018, 0.4675843577365679]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.04610843439966642], {
             RGBColor[
             0.9843437388836044, 0.9877937479278819, 0.9091282940110315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.04610843439966642], {
             RGBColor[
             0.994784219335761, 0.9912522974925381, 0.6736726466437485]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.04610843439966642], {
             RGBColor[
             0.9751568713923526, 0.9278604351417241, 0.3579895659008169]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.04610843439966642], {
             RGBColor[
             0.9341115621158911, 0.950299220121065, 0.9935775887574911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.04610843439966642], {
             RGBColor[
             0.9334508826312379, 0.7738619563512639, 0.26531122193778356`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.04610843439966642], {
             RGBColor[
             0.9942096839193609, 0.9900234243312996, 0.6111380121901929]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.04610843439966642], {
             RGBColor[
             0.9600963966719507, 0.9697605384908702, 0.9524305712945426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.04610843439966642], {
             RGBColor[
             0.9941823175795088, 0.9899648904975172, 0.6081593549827591]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.04610843439966642], {
             RGBColor[
             0.9050222466289541, 0.9271041895602156, 0.9908030238780086]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.04610843439966642], {
             RGBColor[
             0.9746036763092544, 0.980580043890881, 0.9278735309731001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.04610843439966642], {
             RGBColor[
             0.9750644822274809, 0.980923712190194, 0.9270935067509743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.04610843439966642], {
             RGBColor[
             0.9715549043087373, 0.9157101543865991, 0.3439966039553792]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.04610843439966642], {
             RGBColor[
             0.9194032115219487, 0.7181676215118297, 0.25400813602202876`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.04610843439966642], {
             RGBColor[
             0.8397799953527741, 0.875081789346323, 0.9845801597088413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.04610843439966642], {
             RGBColor[
             0.9476013122123255, 0.8299636942891477, 0.2766969897319987]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.04610843439966642], {
             RGBColor[
             0.9350104229423202, 0.7800450139987039, 0.26656606467919636`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.04610843439966642], {
             RGBColor[
             0.993671969447502, 0.988873307447266, 0.5526111103174037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.04610843439966642], {
             RGBColor[
             0.9941991093103549, 0.9900008063118928, 0.6099870312588118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.04610843439966642], {
             RGBColor[
             0.9922451625663964, 0.9910611896780427, 0.7781812553581617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.04610843439966642], {
             RGBColor[
             0.9939598587815943, 0.9894890736228127, 0.5839460876863258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.04610843439966642], {
             RGBColor[
             0.9921440912303273, 0.9910193940831633, 0.779856268961059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.04610843439966642], {
             RGBColor[
             0.9688725674901897, 0.9066620024550027, 0.33357623193212677`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.04610843439966642], {
             RGBColor[
             0.9951400851572862, 0.9920134585012269, 0.7124064451674964]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.04610843439966642], {
             RGBColor[
             0.8484080488061948, 0.8819615649678086, 0.9854031111495828]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.04610843439966642], {
             RGBColor[
             0.9720057887232664, 0.9172310933895012, 0.345748204763448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.04610843439966642], {
             RGBColor[
             0.9941730176625457, 0.9918584073039166, 0.7462317072859076]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.04610843439966642], {
             RGBColor[
             0.993269423269427, 0.9880123018760253, 0.508796443060985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.04610843439966642], {
             RGBColor[
             0.9948773118359295, 0.9914514129373031, 0.6838051907867815]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.04610843439966642], {
             RGBColor[
             0.9946134855165268, 0.9920405520810452, 0.7389320150511745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.04610843439966642], {
             RGBColor[
             0.9950186415083196, 0.9917537028159238, 0.6991880534408108]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.04610843439966642], {
             RGBColor[
             0.9927097765739096, 0.9868152741832741, 0.44788235399296256`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.04610843439966642], {
             RGBColor[
             0.972169784559655, 0.9787648514091618, 0.9319934748445374]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.04610843439966642], {
             RGBColor[
             0.742298368978181, 0.7986083946130913, 0.9749490223132425]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.04610843439966642], {
             RGBColor[
             0.9935503129869663, 0.9886130965795349, 0.5393695553647299]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.04610843439966642], {
             RGBColor[
             0.9943670082043685, 0.9903599250690056, 0.6282617897203252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.04610843439966642], {
             RGBColor[
             0.9941991093103549, 0.9900008063118928, 0.6099870312588118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.04610843439966642], {
             RGBColor[
             0.8367818601742055, 0.8726911577371438, 0.9842941948990426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.04610843439966642], {
             RGBColor[
             0.9949501434751769, 0.9916071924492447, 0.6917324652540697]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.04610843439966642], {
             RGBColor[
             0.9527977126734753, 0.8505656905198038, 0.2808781355182355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.04610843439966642], {
             RGBColor[
             0.8849862385129518, 0.9111280205514672, 0.9888919715375487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.04610843439966642], {
             RGBColor[
             0.9848159509464322, 0.9604427785373655, 0.39551326600429637`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.04610843439966642], {
             RGBColor[
             0.9687942060317976, 0.9762473504700884, 0.9377074488003188]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.04610843439966642], {
             RGBColor[
             0.9938722116007777, 0.9917340162670123, 0.751216842190538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.04610843439966642], {
             RGBColor[
             0.9861134933718259, 0.9648196938156679, 0.40055397330662407`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.04610843439966642], {
             RGBColor[
             0.9578915949771041, 0.8696206037134071, 0.29091722730144787`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.04610843439966642], {
             RGBColor[
             0.9952251471429993, 0.9922934898825784, 0.7287951989709806]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.04610843439966642], {
             RGBColor[
             0.9249503053072858, 0.7401599999112656, 0.25847145788873693`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.04610843439966642], {
             RGBColor[
             0.9361112477189121, 0.9518724536737709, 0.9930311721433069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.04610843439966642], {
             RGBColor[
             0.9883461633756286, 0.9894488533129516, 0.8427977622356364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.04610843439966642], {
             RGBColor[
             0.9933965367470602, 0.9882841847515387, 0.5226319606479032]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.04610843439966642], {
             RGBColor[
             0.9617808886150122, 0.9710168298239031, 0.9495791658208009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.04610843439966642], {
             RGBColor[
             0.9905649871707348, 0.9903663939733985, 0.8060261098188132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.04610843439966642], {
             RGBColor[
             0.8522948426342289, 0.4029666529986539, 0.19771090640610198`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.04610843439966642], {
             RGBColor[
             0.9949651075502268, 0.9916391990926766, 0.6933612124756972]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.04610843439966642], {
             RGBColor[
             0.991737359242702, 0.9908511999537449, 0.7865968705846528]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.04610843439966642], {
             RGBColor[
             0.9936310672115545, 0.9887858217004246, 0.5481591543538562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.04610843439966642], {
             RGBColor[
             0.989234049350986, 0.9898160169813907, 0.8280831938487179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.04610843439966642], {
             RGBColor[
             0.9420769338285628, 0.8080613748874961, 0.27225194521059637`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.04610843439966642], {
             RGBColor[
             0.9229679658421844, 0.9414136189372742, 0.9925147025968991]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.04610843439966642], {
             RGBColor[
             0.9384459320334, 0.7936656627292961, 0.269330355935642]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.04610843439966642], {
             RGBColor[
             0.9913496881959991, 0.9906908880132418, 0.7930215830890287]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.04610843439966642], {
             RGBColor[
             0.9941730176625457, 0.9918584073039166, 0.7462317072859076]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.04610843439966642], {
             RGBColor[
             0.9716023969651597, 0.9158703582685181, 0.3441811039573449]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.04610843439966642], {
             RGBColor[
             0.9952185284731873, 0.9921812408221032, 0.7209445160072865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.04610843439966642], {
             RGBColor[
             0.988893085419169, 0.9896750196332109, 0.8337338485852958]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.04610843439966642], {
             RGBColor[
             0.9367130569761893, 0.9523212820324761, 0.9920124660477287]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.04610843439966642], {
             RGBColor[
             0.9869485955081779, 0.9676366894128899, 0.40379818741054646`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.04610843439966642], {
             RGBColor[
             0.8849862385129518, 0.9111280205514672, 0.9888919715375487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.04610843439966642], {
             RGBColor[
             0.8370522660027353, 0.28580552966932327`, 0.18311459780975556`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.04610843439966642], {
             RGBColor[
             0.9866792230803293, 0.9887595306624337, 0.8704232768319452]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.04610843439966642], {
             RGBColor[
             0.9935307940211761, 0.9885713474853797, 0.5372450363955563]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.04610843439966642], {
             RGBColor[
             0.9802865317701709, 0.9848183081888108, 0.9182539390038511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.04610843439966642], {
             RGBColor[
             0.9940255057544969, 0.9917974073390553, 0.7486763613508579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.04610843439966642], {
             RGBColor[
             0.9922590480188554, 0.9910669316694745, 0.7779511374765145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.04610843439966642], {
             RGBColor[
             0.993396828506996, 0.9882848087965397, 0.5226637169163714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.04610843439966642], {
             RGBColor[
             0.9843437388836044, 0.9877937479278819, 0.9091282940110315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.04610843439966642], {
             RGBColor[
             0.9948293944300082, 0.9913489224512302, 0.6785896768641932]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.04610843439966642], {
             RGBColor[
             0.9224717448227313, 0.7303333335213267, 0.25647714994357235`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.04610843439966642], {
             RGBColor[
             0.9938240577031828, 0.9917141033928581, 0.7520148768919779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.04610843439966642], {
             RGBColor[
             0.9578915949771041, 0.8696206037134071, 0.29091722730144787`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.04610843439966642], {
             RGBColor[
             0.9813070829552819, 0.948606542881832, 0.38188197645279753`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.04610843439966642], {
             RGBColor[
             0.9288995711111405, 0.7558175228087346, 0.2616491298557012]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.04610843439966642], {
             RGBColor[
             0.9940178043119425, 0.9896130132530357, 0.5902531010663682]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.04610843439966642], {
             RGBColor[
             0.9653367275795026, 0.8947347841815634, 0.31984016156644685`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.04610843439966642], {
             RGBColor[
             0.9935519865887709, 0.9916015949951401, 0.7565237993552564]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.04610843439966642], {
             RGBColor[
             0.9930298389636398, 0.9874998552716355, 0.48271916991899033`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.04610843439966642], {
             RGBColor[
             0.9427115759775329, 0.9567949676820047, 0.9818585380427739]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.04610843439966642], {
             RGBColor[
             0.9392752882828309, 0.7969537838917031, 0.2699976754414274]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.04610843439966642], {
             RGBColor[
             0.9309365217215337, 0.7638933532053912, 0.26328810813019965`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.04610843439966642], {
             RGBColor[
             0.9940108378243803, 0.9917913417730034, 0.7489194469122771]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.04610843439966642], {
             RGBColor[
             0.9382984895669713, 0.7930811024821954, 0.2692117202662339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.04610843439966642], {
             RGBColor[
             0.9915669402155568, 0.9907807273064512, 0.7894211548947532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.04610843439966642], {
             RGBColor[
             0.9944156847375856, 0.9919587563757049, 0.7422100858502391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.04610843439966642], {
             RGBColor[
             0.9926539474423988, 0.9866958613161635, 0.4418056975654741]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.04610843439966642], {
             RGBColor[
             0.944777398076731, 0.8187678157551175, 0.2744248021327153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.04610843439966642], {
             RGBColor[
             0.9838459776170524, 0.9571708307367992, 0.3917451027837493]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.04610843439966642], {
             RGBColor[
             0.9770482418606712, 0.982403196876519, 0.9237355191393591]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.04610843439966642], {
             RGBColor[
             0.9666490329591492, 0.8991614983710674, 0.32493822015829715`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.04610843439966642], {
             RGBColor[
             0.9935024480087493, 0.9885107182310205, 0.5341597478742262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.04610843439966642], {
             RGBColor[
             0.9650799067464528, 0.8938684672072872, 0.3188424611265932]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.04610843439966642], {
             RGBColor[
             0.9925230337829045, 0.9864158502359067, 0.4275565536349824]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.04610843439966642], {
             RGBColor[
             0.9455990479217172, 0.9589484395301761, 0.9769708012145654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.04610843439966642], {
             RGBColor[
             0.9893814831613067, 0.9758433907360794, 0.41324949653066895`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.04610843439966642], {
             RGBColor[
             0.8489376949437719, 0.377162144738302, 0.19449609798636422`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.04610843439966642], {
             RGBColor[
             0.9105470914197095, 0.6830560564335305, 0.2468822939079107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.04610843439966642], {
             RGBColor[
             0.9047044957281211, 0.6598921114459811, 0.2421812042711115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.04610843439966642], {
             RGBColor[
             0.9894248318942672, 0.9898949104659251, 0.8249214333771521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.04610843439966642], {
             RGBColor[
             0.9923451171505597, 0.9911025234673099, 0.7765247492244035]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.04610843439966642], {
             RGBColor[
             0.9791862997867364, 0.9414526432707597, 0.37364313431929463`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.04610843439966642], {
             RGBColor[
             0.9728802920066443, 0.92018099830747, 0.3491454848832828]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.04610843439966642], {
             RGBColor[
             0.9719238895417769, 0.9785814633074444, 0.9324097109701133]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.04610843439966642], {
             RGBColor[
             0.9947502579317475, 0.9911796574833779, 0.6699761574023707]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.04610843439966642], {
             RGBColor[
             0.972718427497148, 0.9196349913093449, 0.3485166718294375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.04610843439966642], {
             RGBColor[
             0.9161190537298146, 0.7051470302467269, 0.2513656255733865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.04610843439966642], {
             RGBColor[
             0.9668170157893383, 0.8997281439015399, 0.3255908017326866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.04610843439966642], {
             RGBColor[
             0.9939827237243107, 0.9917797158701253, 0.7493853703073869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.04610843439966642], {
             RGBColor[
             0.9109772437013233, 0.9318525425816333, 0.9913710168148598]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.04610843439966642], {
             RGBColor[
             0.9808701365537779, 0.9471326200696647, 0.3801845221933584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.04610843439966642], {
             RGBColor[
             0.9109772437013233, 0.9318525425816333, 0.9913710168148598]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.04610843439966642], {
             RGBColor[
             0.8727538658894974, 0.5150868487414358, 0.21553504542108456`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.04610843439966642], {
             RGBColor[
             0.99303027294112, 0.9913858529944073, 0.7651699446484727]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.04610843439966642], {
             RGBColor[
             0.9947502579317475, 0.9911796574833779, 0.6699761574023707]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.04610843439966642], {
             RGBColor[
             0.940449665731601, 0.9551080387241269, 0.9856873620884621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.04610843439966642], {
             RGBColor[
             0.9859315744381235, 0.988450358735188, 0.8828137496859572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.04610843439966642], {
             RGBColor[
             0.9650457813688749, 0.8937533542956972, 0.31870989047873993`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.04610843439966642], {
             RGBColor[
             0.9942761770607906, 0.9901656464373298, 0.6183753802867143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.04610843439966642], {
             RGBColor[
             0.9006707955095986, 0.6418511059817479, 0.23882961580266035`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.04610843439966642], {
             RGBColor[
             0.9476013122123255, 0.8299636942891477, 0.2766969897319987]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.04610843439966642], {
             RGBColor[
             0.9878443796252228, 0.9892413528369046, 0.8511136175545813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.04610843439966642], {
             RGBColor[
             0.9456324566880135, 0.958973355733378, 0.9769142488876273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.04610843439966642], {
             RGBColor[
             0.9578915949771041, 0.8696206037134071, 0.29091722730144787`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.04610843439966642], {
             RGBColor[
             0.9897578010017495, 0.9900326017487848, 0.819403273569743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.04610843439966642], {
             RGBColor[
             0.9927120074430902, 0.9868200457868759, 0.4481251703359397]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.04610843439966642], {
             RGBColor[
             0.9255529459707663, 0.7425492693238691, 0.2589563567123678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.04610843439966642], {
             RGBColor[
             0.9948580583744872, 0.9914102317301013, 0.6817095703273642]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.04610843439966642], {
             RGBColor[
             0.9571569092515828, 0.9675682735857288, 0.9574063567561208]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.04610843439966642], {
             RGBColor[
             0.8995715435290473, 0.6368596594748875, 0.2379123730049567]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.04610843439966642], {
             RGBColor[
             0.9898477844282566, 0.9900698122081141, 0.8179120153228775]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.04610843439966642], {
             RGBColor[
             0.9922590480188554, 0.9910669316694745, 0.7779511374765145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.04610843439966642], {
             RGBColor[
             0.9937674963629054, 0.989077629860061, 0.5630086255352728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.04610843439966642], {
             RGBColor[
             0.9932658648168791, 0.9880046907058401, 0.5084091274613671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.04610843439966642], {
             RGBColor[
             0.9611344846893971, 0.8805596321796855, 0.3035152414653697]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.04610843439966642], {
             RGBColor[
             0.9835743370462617, 0.9562545233072831, 0.39068983046124506`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.04610843439966642], {
             RGBColor[
             0.9464829544439951, 0.8255297784083518, 0.27579713282036933`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.04610843439966642], {
             RGBColor[
             0.9939306437266109, 0.9894265855742984, 0.5807662092458022]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.04610843439966642], {
             RGBColor[
             0.9941991093103549, 0.9900008063118928, 0.6099870312588118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.04610843439966642], {
             RGBColor[
             0.993395016041539, 0.9882809321161957, 0.5224664412366293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.04610843439966642], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.04610843439966642], {
             RGBColor[
             0.9861164707712249, 0.9885268181205444, 0.879749538950097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.04610843439966642], {
             RGBColor[
             0.8727538658894974, 0.5150868487414358, 0.21553504542108456`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.04610843439966642], {
             RGBColor[
             0.9318560879883169, 0.7675391270258928, 0.2640280127334477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.04610843439966642], {
             RGBColor[
             0.9440937232128654, 0.9578257708270573, 0.9795189232950884]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.04610843439966642], {
             RGBColor[
             0.9900898552356263, 0.9901699147078974, 0.813900275585594]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.04610843439966642], {
             RGBColor[
             0.9645231787922037, 0.9730620253479645, 0.9449371838546421]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.04610843439966642], {
             RGBColor[
             0.9912924696051291, 0.9906672266554664, 0.7939698432167115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.04610843439966642], {
             RGBColor[
             0.9907906060490893, 0.9904596931777389, 0.8022870211215392]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.04610843439966642], {
             RGBColor[
             0.9938462320465009, 0.9892460375258731, 0.5715785187943315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.04610843439966642], {
             RGBColor[
             0.9922590480188554, 0.9910669316694745, 0.7779511374765145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.04610843439966642], {
             RGBColor[
             0.8817320036543504, 0.9085331820090706, 0.9885815797116455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.04610843439966642], {
             RGBColor[
             0.961089828525991, 0.8804089964547508, 0.3033417607031456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.04610843439966642], {
             RGBColor[
             0.9240050784431304, 0.73641249037307, 0.25771090616651143`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.04610843439966642], {
             RGBColor[
             0.9937725749834748, 0.9890884925159317, 0.563561402042643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.04610843439966642], {
             RGBColor[
             0.9835091741047302, 0.956034713404511, 0.3904366847383839]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
          103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
          129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 
          142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 
          155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 
          168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 
          181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 
          194, 195, 196, 197, 198, 199, 200}, {Null, CompressedData["
1:eJwVxfk/Gg4DAOBN5QibNGP1lWNDwghlmCNXuqiMigzJGcNQUi05SwdqhpKc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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[21, 55] -> 
             RGBColor[
              0.34859095953566543`, 0.47635370128389704`, 0.9434328855880982],
              UndirectedEdge[64, 132] -> 
             RGBColor[
              0.4650482384089718, 0.5716822037632778, 0.9522031318796592], 
             UndirectedEdge[42, 188] -> 
             RGBColor[
              0.2579862693567474, 0.38807828505832953`, 0.9380183944910747], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.5482557857976138, 0.6358309000327967, 0.9605283874597037], 
             UndirectedEdge[33, 68] -> 
             RGBColor[
              0.9768074272678445, 0.9356471682387506, 0.5374347809068445], 
             UndirectedEdge[168, 188] -> 
             RGBColor[
              0.2612998708737691, 0.39156109034719, 0.938207099195435], 
             UndirectedEdge[41, 161] -> 
             RGBColor[
              0.2872671394725109, 0.41926635574719545`, 0.9396708106680862], 
             UndirectedEdge[44, 68] -> 
             RGBColor[
              0.9298826077939246, 0.7566572199616033, 0.27010292258186963`], 
             UndirectedEdge[26, 136] -> 
             RGBColor[
              0.2577972163446346, 0.3882915980387517, 0.9379925421427979], 
             UndirectedEdge[9, 32] -> 
             RGBColor[
              0.18966018913671598`, 0.3166752623061849, 0.9341122392430056], 
             UndirectedEdge[71, 141] -> 
             RGBColor[
              0.3537772547746116, 0.4808458095490941, 0.9437633517346631], 
             UndirectedEdge[52, 100] -> 
             RGBColor[
              0.1956898688928864, 0.3230128380336974, 0.9344556205850076], 
             UndirectedEdge[172, 180] -> 
             RGBColor[
              0.6056868100783286, 0.4851310394922843, 0.577851031637082], 
             UndirectedEdge[168, 197] -> 
             RGBColor[
              0.20505165545148296`, 0.3328526692783333, 0.9349887604799977], 
             UndirectedEdge[125, 137] -> 
             RGBColor[
              0.29408774568202667`, 0.42503485891778914`, 0.9401105091078588],
              UndirectedEdge[17, 147] -> 
             RGBColor[
              0.22049695582396892`, 0.34908665925842064`, 0.9358683474869365],
              UndirectedEdge[10, 71] -> 
             RGBColor[
              0.2908445212370684, 0.4179419677193835, 0.9400607036352882], 
             UndirectedEdge[27, 129] -> 
             RGBColor[
              0.36049570993893, 0.4827296556793453, 0.9443430413040212], 
             UndirectedEdge[67, 166] -> 
             RGBColor[
              0.5298097305765306, 0.6164429264479874, 0.9594779119033563], 
             UndirectedEdge[3, 49] -> 
             RGBColor[
              0.42052372581365627`, 0.5386582479879358, 0.9480163778476842], 
             UndirectedEdge[151, 183] -> 
             RGBColor[
              0.9651436444656913, 0.888619018725243, 0.5091874749108671], 
             UndirectedEdge[125, 136] -> 
             RGBColor[
              0.24354766177349693`, 0.373314412710544, 0.9371810510902985], 
             UndirectedEdge[139, 194] -> 
             RGBColor[
              0.2435950267958037, 0.37336419635210427`, 0.9371837484582486], 
             UndirectedEdge[24, 108] -> 
             RGBColor[
              0.28258697373339425`, 0.41434720481573717`, 0.9394042821529283],
              UndirectedEdge[21, 192] -> 
             RGBColor[
              0.4135089355037963, 0.532245803699352, 0.9476624011874208], 
             UndirectedEdge[16, 52] -> 
             RGBColor[
              0.18638226183152043`, 0.31322995287582944`, 0.9339255661322337],
              UndirectedEdge[44, 166] -> 
             RGBColor[
              0.8512516278317916, 0.7399182542257667, 0.6091593456597434], 
             UndirectedEdge[78, 187] -> 
             RGBColor[
              0.19320618779608617`, 0.3204023317264835, 0.9343141786208218], 
             UndirectedEdge[99, 162] -> 
             RGBColor[
              0.5016163434350541, 0.6062220183620153, 0.9539225219304044], 
             UndirectedEdge[93, 150] -> 
             RGBColor[
              0.21197440955790398`, 0.3401289227721434, 0.9353830010850614], 
             UndirectedEdge[118, 155] -> 
             RGBColor[
              0.5320287520312512, 0.6287959624909311, 0.9570938290152922], 
             UndirectedEdge[16, 125] -> 
             RGBColor[
              0.22572938407249296`, 0.3545862731027316, 0.936166326535006], 
             UndirectedEdge[61, 179] -> 
             RGBColor[
              0.2879403991921272, 0.41444560530367136`, 0.9399115732194068], 
             UndirectedEdge[51, 197] -> 
             RGBColor[
              0.1914512391651612, 0.3185577694452115, 0.9342142368925045], 
             UndirectedEdge[80, 120] -> 
             RGBColor[
              0.20786563933481106`, 0.33581034475659416`, 0.9351490126992371],
              UndirectedEdge[21, 183] -> 
             RGBColor[
              0.6488438964095984, 0.6364280199535685, 0.605957146255827], 
             UndirectedEdge[182, 199] -> 
             RGBColor[
              0.668046802775716, 0.7309711261041182, 0.8355721890992451], 
             UndirectedEdge[17, 189] -> 
             RGBColor[
              0.19295037100619816`, 0.32013345206058996`, 0.9342996102330847],
              UndirectedEdge[116, 136] -> 
             RGBColor[
              0.23171997218972168`, 0.36088276103916334`, 0.9365074816660013],
              UndirectedEdge[119, 123] -> 
             RGBColor[
              0.6489751309922214, 0.46304637074551996`, 0.5712200187466816], 
             UndirectedEdge[71, 89] -> 
             RGBColor[
              0.315626713124748, 0.4439896226750534, 0.9414720128013241], 
             UndirectedEdge[7, 61] -> 
             RGBColor[
              0.2079174287175954, 0.335864778681537, 0.9351519620279711], 
             UndirectedEdge[3, 27] -> 
             RGBColor[
              0.3426067292683088, 0.4672664245880422, 0.9431945216539286], 
             UndirectedEdge[41, 108] -> 
             RGBColor[
              0.29936649893310274`, 0.4319835496839754, 0.9403598512899686], 
             UndirectedEdge[66, 98] -> 
             RGBColor[
              0.18802367047876978`, 0.3149551774354076, 0.9340190419264479], 
             UndirectedEdge[119, 127] -> 
             RGBColor[
              0.8608066453023939, 0.6319627472541103, 0.5901965057147129], 
             UndirectedEdge[15, 167] -> 
             RGBColor[
              0.18913040232451964`, 0.31611842277614255`, 0.9340820686678004],
              UndirectedEdge[12, 96] -> 
             RGBColor[
              0.9432592874949708, 0.8959893159471047, 0.6356118637427102], 
             UndirectedEdge[7, 52] -> 
             RGBColor[
              0.19704159904264756`, 0.32443359212573797`, 0.934532599617331], 
             UndirectedEdge[163, 165] -> 
             RGBColor[
              0.24378292836413576`, 0.3735616928140688, 0.9371944491745896], 
             UndirectedEdge[71, 73] -> 
             RGBColor[
              0.29060892456725834`, 0.41769434068172157`, 0.9400472867534765],
              UndirectedEdge[60, 165] -> 
             RGBColor[
              0.1933919500064047, 0.32059757958753266`, 0.9343247575038889], 
             UndirectedEdge[120, 124] -> 
             RGBColor[
              0.20998768265750406`, 0.3380407468340621, 0.9352698599271827], 
             UndirectedEdge[43, 163] -> 
             RGBColor[
              0.2357550055079826, 0.36512383689254435`, 0.9367372708441793], 
             UndirectedEdge[146, 194] -> 
             RGBColor[
              0.22346288152433108`, 0.352204035220052, 0.9360372525678782], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.24761466346370808`, 0.37758908934975655`, 0.9374126608199662],
              UndirectedEdge[81, 157] -> 
             RGBColor[
              0.25622740358141927`, 0.3866416252927345, 0.9379031436282628], 
             UndirectedEdge[59, 114] -> 
             RGBColor[
              0.1828190891221793, 0.3094848324401137, 0.9337226487176782], 
             UndirectedEdge[31, 185] -> 
             RGBColor[
              0.38200599992585305`, 0.49606971836717273`, 0.9464117075671216],
              UndirectedEdge[58, 198] -> 
             RGBColor[
              0.6531000789032383, 0.7219510755774461, 0.9474306913916395], 
             UndirectedEdge[30, 142] -> 
             RGBColor[
              0.23578204115771023`, 0.3651522530745672, 0.9367388104844356], 
             UndirectedEdge[26, 96] -> 
             RGBColor[
              0.6145993386243387, 0.6885815666825401, 0.9662497087986179], 
             UndirectedEdge[25, 111] -> 
             RGBColor[
              0.19983749274486573`, 0.32737225367666856`, 0.9346918216275183],
              UndirectedEdge[89, 107] -> 
             RGBColor[
              0.24257389966697504`, 0.37229092699650596`, 0.9371255967788841],
              UndirectedEdge[51, 189] -> 
             RGBColor[
              0.18831403886767445`, 0.3152603730225656, 0.9340355779766345], 
             UndirectedEdge[81, 158] -> 
             RGBColor[
              0.3111871249613185, 0.44370525612704076`, 0.9410587411898188], 
             UndirectedEdge[93, 159] -> 
             RGBColor[
              0.24313944261504272`, 0.37288534849241906`, 0.9371578036131307],
              UndirectedEdge[191, 195] -> 
             RGBColor[
              0.6555677203865065, 0.728688801139147, 0.9677847110498968], 
             UndirectedEdge[17, 131] -> 
             RGBColor[
              0.18648216780881113`, 0.31333496039236675`, 0.9339312556298427],
              UndirectedEdge[18, 32] -> 
             RGBColor[
              0.20453729510132862`, 0.33231204393799124`, 0.9349594684189844],
              UndirectedEdge[59, 184] -> 
             RGBColor[
              0.1830159493280225, 0.30969174499811286`, 0.9337338596151724], 
             UndirectedEdge[156, 175] -> 
             RGBColor[
              0.6596444744105936, 0.3751515803022144, 0.5596916614795366], 
             UndirectedEdge[2, 82] -> 
             RGBColor[
              0.19716931432443496`, 0.3245678289845131, 0.934539872813691], 
             UndirectedEdge[12, 44] -> 
             RGBColor[
              0.9244380104653778, 0.7365581580535521, 0.25797799946440303`], 
             UndirectedEdge[115, 175] -> 
             RGBColor[
              0.4077982725568444, 0.5263530627871394, 0.9475600302171414], 
             UndirectedEdge[30, 131] -> 
             RGBColor[
              0.19553065372363834`, 0.3228454927959929, 0.9344465535166567], 
             UndirectedEdge[53, 65] -> 
             RGBColor[
              0.7940608836370591, 0.7881654857639895, 0.6245197254205552], 
             UndirectedEdge[17, 51] -> 
             RGBColor[
              0.18683289480672916`, 0.31370359670455467`, 0.9339512290135199],
              UndirectedEdge[109, 128] -> 
             RGBColor[
              0.32435782382982603`, 0.44691944921604004`, 0.9421979744658333],
              UndirectedEdge[101, 135] -> 
             RGBColor[
              0.1965653140451214, 0.3239329863951249, 0.9345054758913225], 
             UndirectedEdge[54, 195] -> 
             RGBColor[
              0.7447123095700184, 0.789153733450638, 0.681635360097179], 
             UndirectedEdge[122, 192] -> 
             RGBColor[
              0.3718189687016956, 0.49328632243521403`, 0.9451102958483188], 
             UndirectedEdge[155, 195] -> 
             RGBColor[
              0.5871109616069528, 0.6752098608899229, 0.9609615810995339], 
             UndirectedEdge[42, 87] -> 
             RGBColor[
              0.20973659970745412`, 0.3377768427339811, 0.9352555611246214], 
             UndirectedEdge[31, 153] -> 
             RGBColor[
              0.4071092490619125, 0.522454824847095, 0.9478413004684911], 
             UndirectedEdge[64, 199] -> 
             RGBColor[
              0.8123958459095635, 0.8512144164818124, 0.8460919805023865], 
             UndirectedEdge[107, 188] -> 
             RGBColor[
              0.2654176677513521, 0.39588915594893126`, 0.9384416016358788], 
             UndirectedEdge[27, 189] -> 
             RGBColor[
              0.23047600087590087`, 0.35957526831600095`, 0.9364366393399698],
              UndirectedEdge[14, 176] -> 
             RGBColor[
              0.20667251283261232`, 0.3345562931541938, 0.9350810659100094], 
             UndirectedEdge[123, 146] -> 
             RGBColor[
              0.34826410267529395`, 0.47021417637892043`, 0.9436264907064373],
              UndirectedEdge[30, 130] -> 
             RGBColor[
              0.1969307686942434, 0.3243171024025152, 0.9345262879929481], 
             UndirectedEdge[72, 143] -> 
             RGBColor[
              0.5544319884729032, 0.6356036049331575, 0.9619129375714212], 
             UndirectedEdge[68, 155] -> 
             RGBColor[
              0.817090690205986, 0.812348570970784, 0.6355099976070364], 
             UndirectedEdge[32, 39] -> 
             RGBColor[
              0.2190345544466123, 0.34754958268921615`, 0.9357850658919249], 
             UndirectedEdge[184, 194] -> 
             RGBColor[
              0.19166541671322765`, 0.3187828836278702, 0.9342264339870195], 
             UndirectedEdge[74, 152] -> 
             RGBColor[
              0.2730580915689248, 0.4008937800418094, 0.9389875071669056], 
             UndirectedEdge[71, 147] -> 
             RGBColor[
              0.3066316503071229, 0.4345352413338067, 0.9409597572808632], 
             UndirectedEdge[39, 173] -> 
             RGBColor[
              0.3099077362629189, 0.437607436708477, 0.9411599161992759], 
             UndirectedEdge[139, 171] -> 
             RGBColor[
              0.2967091465842705, 0.42919050387948254`, 0.940208519004903], 
             UndirectedEdge[73, 189] -> 
             RGBColor[
              0.20595537414504966`, 0.3338025349243465, 0.9350402259226642], 
             UndirectedEdge[20, 22] -> 
             RGBColor[
              0.1854064647205249, 0.3122043282430629, 0.9338699959303249], 
             UndirectedEdge[17, 168] -> 
             RGBColor[
              0.2004333110930509, 0.32799849653767643`, 0.9347257526010131], 
             UndirectedEdge[13, 132] -> 
             RGBColor[
              0.26083574153477407`, 0.39148528066721244`, 0.9381655816572811],
              UndirectedEdge[99, 109] -> 
             RGBColor[
              0.38461485844464394`, 0.49643648481667146`, 0.9467764936235569],
              UndirectedEdge[119, 195] -> 
             RGBColor[
              0.6739288625041259, 0.48336449574698853`, 0.5731680108502653], 
             UndirectedEdge[10, 188] -> 
             RGBColor[
              0.26557638653463256`, 0.3960559794535111, 0.9384506404357832], 
             UndirectedEdge[182, 185] -> 
             RGBColor[
              0.28644155976238705`, 0.41543196640215296`, 0.9397324188136974],
              UndirectedEdge[98, 187] -> 
             RGBColor[
              0.1979911315151781, 0.3254316109582035, 0.9345866740869342], 
             UndirectedEdge[10, 167] -> 
             RGBColor[
              0.2086421156058076, 0.33662647054885053`, 0.9351932318741767], 
             UndirectedEdge[113, 187] -> 
             RGBColor[
              0.20396723113485943`, 0.331712870565089, 0.934927004119428], 
             UndirectedEdge[83, 170] -> 
             RGBColor[
              0.7907969761749707, 0.8373558827785927, 0.9795546906537492], 
             UndirectedEdge[39, 41] -> 
             RGBColor[
              0.2713842645263738, 0.40257244714637036`, 0.9387663044365115], 
             UndirectedEdge[138, 145] -> 
             RGBColor[
              0.20603341116594734`, 0.3338845567811428, 0.935044670015559], 
             UndirectedEdge[75, 155] -> 
             RGBColor[
              0.5876661844347633, 0.6756606157940428, 0.9610052902743873], 
             UndirectedEdge[90, 163] -> 
             RGBColor[
              0.2545166466581612, 0.38484351129813643`, 0.9378057185523212], 
             UndirectedEdge[2, 66] -> 
             RGBColor[
              0.1829598466238134, 0.3096327774988722, 0.9337306646491643], 
             UndirectedEdge[88, 200] -> 
             RGBColor[
              0.20358824889509092`, 0.3313145362022305, 0.9349054216415271], 
             UndirectedEdge[67, 170] -> 
             RGBColor[
              0.45554903905121463`, 0.5584299098262512, 0.952076300177731], 
             UndirectedEdge[124, 136] -> 
             RGBColor[
              0.22442474851543817`, 0.35321501841359515`, 0.9360920294700671],
              UndirectedEdge[129, 155] -> 
             RGBColor[
              0.5638305008231241, 0.6563097340528043, 0.959128857947493], 
             UndirectedEdge[149, 167] -> 
             RGBColor[
              0.19241882352516138`, 0.31957476195596346`, 0.9342693393903937],
              UndirectedEdge[172, 173] -> 
             RGBColor[
              0.6185469880325928, 0.49626987926492994`, 0.5786704708045187], 
             UndirectedEdge[143, 160] -> 
             RGBColor[
              0.6494266978782655, 0.7230187336619522, 0.967777881154406], 
             UndirectedEdge[27, 89] -> 
             RGBColor[
              0.2670176485112967, 0.3979828568550783, 0.9385176321142823], 
             UndirectedEdge[172, 191] -> 
             RGBColor[
              0.8397221650752837, 0.6755835027616839, 0.59719713282006], 
             UndirectedEdge[11, 182] -> 
             RGBColor[
              0.27189457932291083`, 0.4001421676284322, 0.9389039897979983], 
             UndirectedEdge[159, 164] -> 
             RGBColor[
              0.22503263737217588`, 0.35385394814440607`, 0.9361266478411673],
              UndirectedEdge[151, 156] -> 
             RGBColor[
              0.9063104280310577, 0.5683123234196433, 0.4581304793295804], 
             UndirectedEdge[94, 196] -> 
             RGBColor[
              0.21169845343388266`, 0.3398388753891681, 0.9353672857920389], 
             UndirectedEdge[69, 139] -> 
             RGBColor[
              0.2677410752801248, 0.398743224257023, 0.938558830198553], 
             UndirectedEdge[53, 127] -> 
             RGBColor[
              0.7532853090466265, 0.8074724235406385, 0.9760373166313029], 
             UndirectedEdge[171, 196] -> 
             RGBColor[
              0.2703681630861383, 0.4015044601081305, 0.9387084389626774], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.7310843955752011, 0.737038335696917, 0.6195619855898489], 
             UndirectedEdge[74, 162] -> 
             RGBColor[
              0.39867126833608224`, 0.5197307476573095, 0.9466239585805827], 
             UndirectedEdge[34, 153] -> 
             RGBColor[
              0.3561569436366287, 0.48045786172119975`, 0.9440046574916221], 
             UndirectedEdge[98, 109] -> 
             RGBColor[
              0.2049550918267402, 0.33275117478624117`, 0.9349832613244216], 
             UndirectedEdge[77, 183] -> 
             RGBColor[
              0.8768515535875127, 0.45980910711412243`, 0.21594468162867203`],
              UndirectedEdge[2, 78] -> 
             RGBColor[
              0.1826523965739446, 0.3093096280030011, 0.9337131558236558], 
             UndirectedEdge[113, 193] -> 
             RGBColor[
              0.21695734101669506`, 0.34536629967143495`, 0.9356667716600531],
              UndirectedEdge[100, 120] -> 
             RGBColor[
              0.199864476631129, 0.3274006154520085, 0.934693358319922], 
             UndirectedEdge[1, 35] -> 
             RGBColor[
              0.1803467482579951, 0.30688624543639154`, 0.9335818525629636], 
             UndirectedEdge[154, 176] -> 
             RGBColor[
              0.28297932105843965`, 0.41262153691639003`, 0.9395049102298585],
              UndirectedEdge[13, 31] -> 
             RGBColor[
              0.37653388192589077`, 0.49031817539689215`, 0.9461000785422968],
              UndirectedEdge[92, 196] -> 
             RGBColor[
              0.23871657724306206`, 0.3682366365606061, 0.9369059279732393], 
             UndirectedEdge[66, 124] -> 
             RGBColor[
              0.2047917303558609, 0.33257947152263156`, 0.9349739581303267], 
             UndirectedEdge[141, 167] -> 
             RGBColor[
              0.27157484914335084`, 0.3995303123785612, 0.9388958799735516], 
             UndirectedEdge[76, 158] -> 
             RGBColor[
              0.2902964087900912, 0.4217477888831733, 0.9398690458089125], 
             UndirectedEdge[101, 134] -> 
             RGBColor[
              0.22153377048940157`, 0.350176417209637, 0.9359273925483029], 
             UndirectedEdge[139, 141] -> 
             RGBColor[
              0.31474199889707277`, 0.4449017237250964, 0.9413541852919508], 
             UndirectedEdge[88, 93] -> 
             RGBColor[
              0.22397479227765688`, 0.3527420858788138, 0.936066405127976], 
             UndirectedEdge[17, 130] -> 
             RGBColor[
              0.18788228277941618`, 0.31480656999888906`, 0.9340109901061341],
              UndirectedEdge[32, 117] -> 
             RGBColor[
              0.1856648230786062, 0.31247587925827236`, 0.9338847090566107], 
             UndirectedEdge[32, 103] -> 
             RGBColor[
              0.1835438669532831, 0.31024661989417246`, 0.9337639237429469], 
             UndirectedEdge[148, 150] -> 
             RGBColor[
              0.19306951159997304`, 0.3202586763785973, 0.9343063951136474], 
             UndirectedEdge[77, 156] -> 
             RGBColor[
              0.8180183371528791, 0.13950241180852277`, 0.1648876860473853], 
             UndirectedEdge[76, 89] -> 
             RGBColor[
              0.2658816302529869, 0.396788829637877, 0.93845293755506], 
             UndirectedEdge[42, 51] -> 
             RGBColor[
              0.1924833774375055, 0.31964261221079154`, 0.9342730156402028], 
             UndirectedEdge[82, 124] -> 
             RGBColor[
              0.21900119805648247`, 0.34751452300827246`, 0.9357831662948535],
              UndirectedEdge[15, 114] -> 
             RGBColor[
              0.1801710817898224, 0.3067016088404447, 0.9335718486174763], 
             UndirectedEdge[41, 173] -> 
             RGBColor[
              0.32922976019022715`, 0.45791610894315266`, 0.9422602768775632],
              UndirectedEdge[41, 133] -> 
             RGBColor[
              0.2699147403652278, 0.4010278840797926, 0.9386826172095004], 
             UndirectedEdge[27, 147] -> 
             RGBColor[
              0.25802258569367165`, 0.38852847551383163`, 0.9380053765938214],
              UndirectedEdge[19, 88] -> 
             RGBColor[
              0.28388973519432037`, 0.4117897874343075, 0.939622248296642], 
             UndirectedEdge[127, 172] -> 
             RGBColor[
              0.8720640822479042, 0.7012922099091854, 0.6003031260629946], 
             UndirectedEdge[69, 174] -> 
             RGBColor[
              0.21992361240255348`, 0.34848403897044045`, 0.9358356964272725],
              UndirectedEdge[117, 121] -> 
             RGBColor[
              0.2013378942582586, 0.3289492707981949, 0.9347772672740609], 
             UndirectedEdge[69, 196] -> 
             RGBColor[
              0.24140009178199262`, 0.37105718048567105`, 0.9370587501563274],
              UndirectedEdge[92, 195] -> 
             RGBColor[
              0.372739436043382, 0.49002947459904367`, 0.9455472387434574], 
             UndirectedEdge[144, 158] -> 
             RGBColor[
              0.2574165112915451, 0.3871889319062931, 0.9379965842878197], 
             UndirectedEdge[81, 168] -> 
             RGBColor[
              0.2577136388756711, 0.38820375281975344`, 0.9379877825295823], 
             UndirectedEdge[87, 188] -> 
             RGBColor[
              0.264952676857396, 0.39540042103725787`, 0.9384151210923604], 
             UndirectedEdge[74, 88] -> 
             RGBColor[
              0.2812466810785635, 0.40950050680300143`, 0.9394538352255469], 
             UndirectedEdge[74, 140] -> 
             RGBColor[
              0.6698268935487197, 0.7315161778042003, 0.7507274751968138], 
             UndirectedEdge[152, 178] -> 
             RGBColor[
              0.19191650879429833`, 0.319046797325233, 0.9342407333095791], 
             UndirectedEdge[63, 153] -> 
             RGBColor[
              0.23696466171985112`, 0.36639526226785174`, 0.9368061589759192],
              UndirectedEdge[154, 158] -> 
             RGBColor[
              0.3241076056222659, 0.45514745069325846`, 0.9418728279265163], 
             UndirectedEdge[23, 90] -> 
             RGBColor[
              0.22545415356299398`, 0.354296988386626, 0.936150652564657], 
             UndirectedEdge[51, 131] -> 
             RGBColor[
              0.18184583567028742`, 0.3084618813543424, 0.9336672233733925], 
             UndirectedEdge[21, 83] -> 
             RGBColor[
              0.6438448345050425, 0.715751939504987, 0.9685418227069613], 
             UndirectedEdge[57, 178] -> 
             RGBColor[
              0.1827435050835432, 0.30940538882320234`, 0.9337183443184945], 
             UndirectedEdge[17, 197] -> 
             RGBColor[
              0.19608757130368493`, 0.3234308484832359, 0.9344782691489546], 
             UndirectedEdge[64, 156] -> 
             RGBColor[
              0.724124328038114, 0.42749923026133874`, 0.5647677517545815], 
             UndirectedEdge[40, 123] -> 
             RGBColor[
              0.4784773066745961, 0.5874288969649759, 0.9521030898325651], 
             UndirectedEdge[26, 99] -> 
             RGBColor[
              0.42230145847218425`, 0.5360474909140672, 0.9489226897427967], 
             UndirectedEdge[114, 167] -> 
             RGBColor[
              0.19037448411434205`, 0.3174260316165872, 0.9341529172852767], 
             UndirectedEdge[75, 168] -> 
             RGBColor[
              0.3557698478286644, 0.47206054196027025`, 0.9445929358550735], 
             UndirectedEdge[55, 111] -> 
             RGBColor[
              0.27800719710349053`, 0.40702500884009835`, 0.9392353213324036],
              UndirectedEdge[67, 122] -> 
             RGBColor[
              0.26690693057918574`, 0.3978664852885073, 0.9385113268918411], 
             UndirectedEdge[127, 129] -> 
             RGBColor[
              0.6646291767752983, 0.7354973814495299, 0.9690579811407907], 
             UndirectedEdge[96, 198] -> 
             RGBColor[
              0.6410199693439192, 0.7129417496474699, 0.9678791658783956], 
             UndirectedEdge[154, 181] -> 
             RGBColor[
              0.3850218870849109, 0.5079083396553941, 0.9457542320769319], 
             UndirectedEdge[9, 91] -> 
             RGBColor[
              0.1897739422401799, 0.3167948240302888, 0.9341187173139652], 
             UndirectedEdge[39, 152] -> 
             RGBColor[
              0.22612393827552923`, 0.3550009745863041, 0.9361887958131783], 
             UndirectedEdge[54, 65] -> 
             RGBColor[
              0.9723656669587191, 0.9184450471811106, 0.347146263750879], 
             UndirectedEdge[116, 128] -> 
             RGBColor[
              0.33596717970245343`, 0.45912161831384746`, 0.9428591101082765],
              UndirectedEdge[74, 95] -> 
             RGBColor[
              0.29756419393855826`, 0.4266512474089263, 0.9403830934433266], 
             UndirectedEdge[152, 200] -> 
             RGBColor[
              0.19539965938545223`, 0.3227078094410386, 0.9344390935828858], 
             UndirectedEdge[140, 191] -> 
             RGBColor[
              0.9019134129618684, 0.9202806576422312, 0.7699493982996792], 
             UndirectedEdge[109, 193] -> 
             RGBColor[
              0.223435169075761, 0.3521749076795341, 0.936035674384929], 
             UndirectedEdge[80, 137] -> 
             RGBColor[
              0.2728427891012749, 0.40270506254337235`, 0.9389006402596817], 
             UndirectedEdge[118, 199] -> 
             RGBColor[
              0.6930640728290565, 0.752639828019768, 0.8371662674251406], 
             UndirectedEdge[45, 64] -> 
             RGBColor[
              0.6702869821102313, 0.7421560430065834, 0.9679059544483493], 
             UndirectedEdge[125, 170] -> 
             RGBColor[
              0.4597455397011603, 0.5628406980828529, 0.952315284681579], 
             UndirectedEdge[70, 145] -> 
             RGBColor[
              0.19062187863577218`, 0.31768605894432894`, 0.9341670060372848],
              UndirectedEdge[17, 142] -> 
             RGBColor[
              0.22673355524288302`, 0.35564172067094113`, 0.9362235125976215],
              UndirectedEdge[95, 180] -> 
             RGBColor[
              0.2956153583547517, 0.42496326397755757`, 0.9402589153632142], 
             UndirectedEdge[41, 121] -> 
             RGBColor[
              0.25402964955357293`, 0.38433164646381435`, 0.9377779847876626],
              UndirectedEdge[5, 10] -> 
             RGBColor[
              0.28614225358776674`, 0.41386909982440245`, 0.9397610792987268],
              UndirectedEdge[167, 194] -> 
             RGBColor[
              0.2004278770420817, 0.327992785005569, 0.9347254431398494], 
             UndirectedEdge[78, 100] -> 
             RGBColor[
              0.1943610742796171, 0.3216161906447068, 0.9343799476975574], 
             UndirectedEdge[106, 157] -> 
             RGBColor[
              0.1957274974930852, 0.3230523880782974, 0.9344577634781225], 
             UndirectedEdge[24, 115] -> 
             RGBColor[
              0.28608625432626233`, 0.41744460911573256`, 0.9396248182053492],
              UndirectedEdge[74, 164] -> 
             RGBColor[
              0.2705518531420833, 0.3982595645505048, 0.9388447805961444], 
             UndirectedEdge[46, 135] -> 
             RGBColor[
              0.18995764910618526`, 0.3169879115941485, 0.9341291791482143], 
             UndirectedEdge[126, 190] -> 
             RGBColor[
              0.18192592123823295`, 0.3085460563639715, 0.933671784128011], 
             UndirectedEdge[21, 177] -> 
             RGBColor[
              0.28934680274084895`, 0.4165928965590511, 0.9399671678191333], 
             UndirectedEdge[24, 133] -> 
             RGBColor[
              0.2531352151655193, 0.3833915392115544, 0.93772704807246], 
             UndirectedEdge[30, 188] -> 
             RGBColor[
              0.2613842726407983, 0.39164980195571875`, 0.938211905751206], 
             UndirectedEdge[80, 98] -> 
             RGBColor[
              0.2071471807023911, 0.33505519918101245`, 0.9351080975429851], 
             UndirectedEdge[12, 102] -> 
             RGBColor[
              0.9596388825040008, 0.9082051910857141, 0.6078854818749925], 
             UndirectedEdge[51, 168] -> 
             RGBColor[
              0.1957969789545272, 0.32312541749965207`, 0.934461720344563], 
             UndirectedEdge[42, 189] -> 
             RGBColor[
              0.19860085363697447`, 0.32607246756682684`, 0.9346213968597675],
              UndirectedEdge[52, 187] -> 
             RGBColor[
              0.19453498240935546`, 0.32179897911547406`, 0.934389851508272], 
             UndirectedEdge[10, 89] -> 
             RGBColor[
              0.2427326184502555, 0.3724577505010858, 0.9371346355787884], 
             UndirectedEdge[148, 193] -> 
             RGBColor[
              0.21151914615710812`, 0.33965041207254015`, 0.9353570745078879],
              UndirectedEdge[4, 92] -> 
             RGBColor[
              0.28937728391046563`, 0.41912091134823404`, 0.9398775137264412],
              UndirectedEdge[28, 97] -> 
             RGBColor[
              0.19804503866908396`, 0.3254882707948695, 0.9345897440196007], 
             UndirectedEdge[60, 169] -> 
             RGBColor[
              0.18653686033276015`, 0.3133924457027435, 0.9339343702881713], 
             UndirectedEdge[44, 198] -> 
             RGBColor[
              0.6221986923143263, 0.5535105917539171, 0.5902453016000886], 
             UndirectedEdge[13, 64] -> 
             RGBColor[
              0.4253184848962721, 0.5299237138095665, 0.9499405811920143], 
             UndirectedEdge[42, 106] -> 
             RGBColor[
              0.19390013127031533`, 0.3211317103164559, 0.9343536976750818], 
             UndirectedEdge[43, 90] -> 
             RGBColor[
              0.20850897767362986`, 0.33648653414069934`, 0.935185649865899], 
             UndirectedEdge[166, 192] -> 
             RGBColor[
              0.6347217686990404, 0.711862763594694, 0.9660768808598341], 
             UndirectedEdge[5, 89] -> 
             RGBColor[
              0.31092444547544634`, 0.4399167547800723, 0.9411723884647626], 
             UndirectedEdge[114, 184] -> 
             RGBColor[
              0.18161202378548802`, 0.3082161302388885, 0.9336539081324469], 
             UndirectedEdge[58, 192] -> 
             RGBColor[
              0.7131454310850844, 0.7736227561744136, 0.951349727711992], 
             UndirectedEdge[17, 157] -> 
             RGBColor[
              0.19894707579879906`, 0.3264363690106574, 0.9346411136996936], 
             UndirectedEdge[38, 111] -> 
             RGBColor[
              0.200630301320241, 0.32820554575635497`, 0.9347369709030307], 
             UndirectedEdge[3, 191] -> 
             RGBColor[
              0.6143982789320568, 0.6943254432107253, 0.9648034682477634], 
             UndirectedEdge[40, 195] -> 
             RGBColor[
              0.5034310381865006, 0.6077470219664445, 0.9540510819361487], 
             UndirectedEdge[113, 136] -> 
             RGBColor[
              0.21363278825802834`, 0.3418719839332567, 0.9354774432986821], 
             UndirectedEdge[53, 141] -> 
             RGBColor[
              0.4877995456867602, 0.5920834332461721, 0.9536420283584146], 
             UndirectedEdge[142, 176] -> 
             RGBColor[
              0.24804284091250217`, 0.37803913099645736`, 0.9374370448922433],
              UndirectedEdge[99, 128] -> 
             RGBColor[
              0.49156366276898256`, 0.5975148916314856, 0.9532819740075988], 
             UndirectedEdge[41, 151] -> 
             RGBColor[
              0.6423047351050197, 0.7073139713016436, 0.8452851258395946], 
             UndirectedEdge[5, 157] -> 
             RGBColor[
              0.28037950263265143`, 0.40781208319106244`, 0.939432899157059], 
             UndirectedEdge[39, 74] -> 
             RGBColor[
              0.29899639389246113`, 0.42815658036720006`, 0.9404646551119514],
              UndirectedEdge[86, 171] -> 
             RGBColor[
              0.25492345163412733`, 0.3852710891208021, 0.9378288854938884], 
             UndirectedEdge[162, 180] -> 
             RGBColor[
              0.3967224327522758, 0.5180427642259409, 0.9464997805004701], 
             UndirectedEdge[27, 127] -> 
             RGBColor[
              0.5706539535210267, 0.6502280340235855, 0.9632042593205097], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.2536345517124762, 0.3839163735821717, 0.937755484550107], 
             UndirectedEdge[155, 191] -> 
             RGBColor[
              0.7416468272326004, 0.7980994052495431, 0.9748840827210469], 
             UndirectedEdge[46, 105] -> 
             RGBColor[
              0.19436779950481975`, 0.32162325928279867`, 0.9343803306891837],
              UndirectedEdge[30, 168] -> 
             RGBColor[
              0.2094817970078781, 0.3375090289413025, 0.9352410504878272], 
             UndirectedEdge[161, 180] -> 
             RGBColor[
              0.31293043325479175`, 0.4431625055366565, 0.9412449832634135], 
             UndirectedEdge[125, 192] -> 
             RGBColor[
              0.364998647890857, 0.48611773282970705`, 0.9447218886679021], 
             UndirectedEdge[33, 140] -> 
             RGBColor[
              0.9931733912441731, 0.9901003146609737, 0.6650510516491244], 
             UndirectedEdge[12, 58] -> 
             RGBColor[
              0.9553393970542898, 0.9049986418770809, 0.615163389255954], 
             UndirectedEdge[127, 155] -> 
             RGBColor[
              0.7739887444052208, 0.8238081123970447, 0.9779900759639816], 
             UndirectedEdge[78, 120] -> 
             RGBColor[
              0.188434679061321, 0.31538717351511814`, 0.9340424482571915], 
             UndirectedEdge[45, 183] -> 
             RGBColor[
              0.823713544812509, 0.7798413316678898, 0.6197525703698252], 
             UndirectedEdge[98, 136] -> 
             RGBColor[
              0.20765668863834705`, 0.33559072432637116`, 0.9351371132661883],
              UndirectedEdge[59, 92] -> 
             RGBColor[
              0.21433501599530952`, 0.3426100698089493, 0.9355174341294674], 
             UndirectedEdge[81, 89] -> 
             RGBColor[
              0.2867723464242142, 0.41874629688174436`, 0.9396426329359664], 
             UndirectedEdge[161, 200] -> 
             RGBColor[
              0.23722083665512567`, 0.36666451836725433`, 0.9368207477595063],
              UndirectedEdge[125, 198] -> 
             RGBColor[
              0.30495329570901086`, 0.43444605223273947`, 0.9408028523475496],
              UndirectedEdge[159, 173] -> 
             RGBColor[
              0.3113226737864071, 0.4390946257578836, 0.941240494798026], 
             UndirectedEdge[54, 151] -> 
             RGBColor[
              0.9911479730677677, 0.9821275166719952, 0.580056048665182], 
             UndirectedEdge[61, 192] -> 
             RGBColor[
              0.33652735532483224`, 0.4561925991586039, 0.9431004906757697], 
             UndirectedEdge[59, 194] -> 
             RGBColor[
              0.19287248204991897`, 0.32005158582909543`, 0.934295174572251], 
             UndirectedEdge[80, 82] -> 
             RGBColor[
              0.2168791547337895, 0.3452841209308045, 0.9356623190669078], 
             UndirectedEdge[157, 168] -> 
             RGBColor[
              0.2079111599465971, 0.33585818980575477`, 0.9351516050307367], 
             UndirectedEdge[122, 170] -> 
             RGBColor[
              0.4665658605119989, 0.5700092876883599, 0.9527036918619959], 
             UndirectedEdge[26, 67] -> 
             RGBColor[
              0.2743361643394848, 0.4056750810112081, 0.9389344107639237], 
             UndirectedEdge[160, 181] -> 
             RGBColor[
              0.4406818300512263, 0.5561181847027405, 0.9493008344245906], 
             UndirectedEdge[42, 168] -> 
             RGBColor[
              0.20608379372382724`, 0.3339375120439133, 0.935047539227696], 
             UndirectedEdge[61, 67] -> 
             RGBColor[
              0.2316153172023224, 0.36077276201189723`, 0.936501521719292], 
             UndirectedEdge[9, 39] -> 
             RGBColor[
              0.22268787528916928`, 0.3513894545286635, 0.9359931171093048], 
             UndirectedEdge[118, 171] -> 
             RGBColor[
              0.3493088123107567, 0.4768833997475762, 0.9434819976486537], 
             UndirectedEdge[97, 134] -> 
             RGBColor[
              0.23183626588337625`, 0.3610049930846403, 0.9365141044198138], 
             UndirectedEdge[79, 190] -> 
             RGBColor[
              0.18918203979750087`, 0.31617269703425077`, 0.9340850093454959],
              UndirectedEdge[47, 50] -> 
             RGBColor[
              0.2000038325739316, 0.3275470873835711, 0.9347012944347058], 
             UndirectedEdge[36, 145] -> 
             RGBColor[
              0.1863723647153286, 0.3132195503791984, 0.9339250025061079], 
             UndirectedEdge[170, 179] -> 
             RGBColor[
              0.5118741210410194, 0.6121027531180253, 0.9554863516778458], 
             UndirectedEdge[26, 198] -> 
             RGBColor[
              0.3192028502801486, 0.44942323756094715`, 0.9416143434000489], 
             UndirectedEdge[5, 141] -> 
             RGBColor[
              0.34907498712530993`, 0.4767729416541131, 0.9434637273981017], 
             UndirectedEdge[18, 39] -> 
             RGBColor[
              0.2375649812537819, 0.3670262361604698, 0.9368403462852835], 
             UndirectedEdge[19, 180] -> 
             RGBColor[
              0.3466247657178071, 0.47465068302264285`, 0.9433076014566613], 
             UndirectedEdge[170, 198] -> 
             RGBColor[
              0.5004157249918784, 0.6021780663759904, 0.9547562328138562], 
             UndirectedEdge[12, 172] -> 
             RGBColor[
              0.9097214307201227, 0.6697336065748736, 0.2456981245885829], 
             UndirectedEdge[47, 101] -> 
             RGBColor[
              0.19622767860092072`, 0.3235781101359464, 0.934486248052262], 
             UndirectedEdge[53, 54] -> 
             RGBColor[
              0.810087981057518, 0.842228648704628, 0.6867819724356502], 
             UndirectedEdge[57, 121] -> 
             RGBColor[
              0.1995963195919732, 0.32711876540171747`, 0.9346780871732447], 
             UndirectedEdge[19, 121] -> 
             RGBColor[
              0.28428483303541713`, 0.41220506031595017`, 0.9396447485341975],
              UndirectedEdge[170, 192] -> 
             RGBColor[
              0.5604610771737245, 0.6538497469729578, 0.9586752691342088], 
             UndirectedEdge[7, 137] -> 
             RGBColor[
              0.266193356547354, 0.39571608733082725`, 0.9385219649126898], 
             UndirectedEdge[111, 115] -> 
             RGBColor[
              0.26758071568904057`, 0.3979941146890951, 0.9385709551564505], 
             UndirectedEdge[140, 162] -> 
             RGBColor[
              0.7225676146989453, 0.7771975396388044, 0.7540880673117176], 
             UndirectedEdge[8, 79] -> 
             RGBColor[
              0.2387210212797669, 0.3682413075249512, 0.9369061810545554], 
             UndirectedEdge[2, 52] -> 
             RGBColor[
              0.1839811911872139, 0.31070627539199164`, 0.933788828711106], 
             UndirectedEdge[18, 152] -> 
             RGBColor[
              0.21162667893024556`, 0.3397634358350792, 0.9353631983402376], 
             UndirectedEdge[4, 195] -> 
             RGBColor[
              0.41766970262794245`, 0.5348906935287172, 0.9481924844113676], 
             UndirectedEdge[81, 107] -> 
             RGBColor[
              0.26183143575325407`, 0.39253181842149465`, 0.938222284970026], 
             UndirectedEdge[108, 175] -> 
             RGBColor[
              0.4042989919639763, 0.5232556584871441, 0.9473394941647204], 
             UndirectedEdge[49, 191] -> 
             RGBColor[
              0.6162290328937537, 0.6959111502759776, 0.9649201222713306], 
             UndirectedEdge[77, 192] -> 
             RGBColor[
              0.6415165926817106, 0.355626890859906, 0.5576499365602658], 
             UndirectedEdge[21, 166] -> 
             RGBColor[
              0.5825165188394155, 0.666981785574234, 0.9626574089267232], 
             UndirectedEdge[8, 192] -> 
             RGBColor[
              0.37448920004002384`, 0.4960929048742423, 0.9452623615727833], 
             UndirectedEdge[108, 165] -> 
             RGBColor[
              0.25691494582414054`, 0.38736427578253046`, 0.937942298141858], 
             UndirectedEdge[29, 194] -> 
             RGBColor[
              0.2042163465061234, 0.3319747066151143, 0.9349411908712882], 
             UndirectedEdge[106, 131] -> 
             RGBColor[
              0.18326258950309726`, 0.3099509794600067, 0.9337479054082716], 
             UndirectedEdge[12, 68] -> 
             RGBColor[
              0.9555467146303788, 0.8599776150331977, 0.2908341193259223], 
             UndirectedEdge[71, 168] -> 
             RGBColor[
              0.2865680055762049, 0.4134470786130624, 0.93981716239494], 
             UndirectedEdge[49, 146] -> 
             RGBColor[
              0.3338791466944457, 0.45775465051721964`, 0.9427098940314549], 
             UndirectedEdge[112, 134] -> 
             RGBColor[
              0.5941420485372255, 0.6663173396662936, 0.9607153178159171], 
             UndirectedEdge[84, 126] -> 
             RGBColor[
              0.1804502852518648, 0.30699506938157317`, 0.9335877488415951], 
             UndirectedEdge[10, 62] -> 
             RGBColor[
              0.2089259147709481, 0.3369247614653196, 0.9352093938167881], 
             UndirectedEdge[34, 182] -> 
             RGBColor[
              0.3854450302409573, 0.5082748449893679, 0.9457811943846643], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.20133152966492007`, 0.3289425812070576, 0.9347769048198857], 
             UndirectedEdge[67, 79] -> 
             RGBColor[
              0.22503396848065443`, 0.3538553472238142, 0.9361267236458259], 
             UndirectedEdge[33, 96] -> 
             RGBColor[
              0.9645200001324366, 0.9716588691526575, 0.8822125253236324], 
             UndirectedEdge[12, 140] -> 
             RGBColor[
              0.9719126786067074, 0.9144307614554209, 0.4184503900682022], 
             UndirectedEdge[26, 124] -> 
             RGBColor[
              0.25940975173137165`, 0.3899864749708609, 0.9380843736475403], 
             UndirectedEdge[13, 70] -> 
             RGBColor[
              0.20607827017508945`, 0.33393170644397663`, 0.9350472246697668],
              UndirectedEdge[53, 146] -> 
             RGBColor[
              0.438593505674698, 0.543607216634379, 0.9507210951484925], 
             UndirectedEdge[87, 147] -> 
             RGBColor[
              0.23311384595539386`, 0.3623478107435859, 0.9365868607149048], 
             UndirectedEdge[93, 200] -> 
             RGBColor[
              0.21100022620147757`, 0.339104994297747, 0.935327522784088], 
             UndirectedEdge[9, 117] -> 
             RGBColor[
              0.1893181439211632, 0.3163157510977197, 0.9340927602739904], 
             UndirectedEdge[99, 116] -> 
             RGBColor[
              0.39622421431727134`, 0.5086386539144789, 0.9474376292660001], 
             UndirectedEdge[71, 155] -> 
             RGBColor[
              0.5184643421823038, 0.6170471524468351, 0.9562295168142538], 
             UndirectedEdge[54, 140] -> 
             RGBColor[
              0.9910580021453803, 0.9807455899537222, 0.48380004734696136`], 
             UndirectedEdge[76, 154] -> 
             RGBColor[
              0.29805964700021337`, 0.42847191562908343`, 0.9403637124828994],
              UndirectedEdge[33, 128] -> 
             RGBColor[
              0.7119650853654641, 0.7696077577835532, 0.8603069871100877], 
             UndirectedEdge[109, 148] -> 
             RGBColor[
              0.20549299658683456`, 0.33331654679423195`, 0.9350138942047502],
              UndirectedEdge[27, 142] -> 
             RGBColor[
              0.2642591851125857, 0.3950835369263521, 0.9383605417045067], 
             UndirectedEdge[49, 69] -> 
             RGBColor[
              0.33608426308955985`, 0.46007236766093923`, 0.9428354721479792],
              UndirectedEdge[60, 90] -> 
             RGBColor[
              0.2041256683004301, 0.33187939807160033`, 0.9349360268816205], 
             UndirectedEdge[40, 191] -> 
             RGBColor[
              0.6579669038121483, 0.7306365663260646, 0.9679735835576617], 
             UndirectedEdge[58, 166] -> 
             RGBColor[
              0.8821530144207035, 0.9083587380492957, 0.9663447354512944], 
             UndirectedEdge[38, 60] -> 
             RGBColor[
              0.18105257981885614`, 0.3076281191591622, 0.9336220486261704], 
             UndirectedEdge[54, 119] -> 
             RGBColor[
              0.9176093173132854, 0.6667189724180997, 0.30094116151906036`], 
             UndirectedEdge[3, 146] -> 
             RGBColor[
              0.33204839273274867`, 0.4561689434519673, 0.9425932400078877], 
             UndirectedEdge[115, 163] -> 
             RGBColor[
              0.2983939725453868, 0.4303808013184385, 0.9403257245502908], 
             UndirectedEdge[137, 170] -> 
             RGBColor[
              0.48955017496489417`, 0.59276687306104, 0.9540638895741654], 
             UndirectedEdge[58, 99] -> 
             RGBColor[
              0.7561986870952739, 0.8085753289305662, 0.9547390377343874], 
             UndirectedEdge[40, 64] -> 
             RGBColor[
              0.5676806016913061, 0.6599077120294969, 0.959109042929153], 
             UndirectedEdge[77, 96] -> 
             RGBColor[
              0.8768677288440547, 0.5431135393845314, 0.5783662656384824], 
             UndirectedEdge[141, 195] -> 
             RGBColor[
              0.42242387419926064`, 0.539008517992182, 0.9484954160199432], 
             UndirectedEdge[138, 182] -> 
             RGBColor[
              0.28135325644561493`, 0.4100838369991616, 0.9394426474672775], 
             UndirectedEdge[33, 102] -> 
             RGBColor[
              0.9808995951414665, 0.9838747442912669, 0.8544861434559147], 
             UndirectedEdge[137, 198] -> 
             RGBColor[
              0.3347579309727448, 0.4643722272109265, 0.9425514572401359], 
             UndirectedEdge[69, 171] -> 
             RGBColor[
              0.27878211770791206`, 0.41034805989114986`, 0.939187601231057], 
             UndirectedEdge[20, 46] -> 
             RGBColor[
              0.182651270158183, 0.3093084440686167, 0.9337130916759446], 
             UndirectedEdge[76, 157] -> 
             RGBColor[
              0.23533668741019195`, 0.36468415804886706`, 0.9367134482473564],
              UndirectedEdge[10, 168] -> 
             RGBColor[
              0.21367391090171242`, 0.3419152064390949, 0.9354797851724044], 
             UndirectedEdge[82, 100] -> 
             RGBColor[
              0.20887799203010743`, 0.3368743916262188, 0.9352066646875926], 
             UndirectedEdge[9, 57] -> 
             RGBColor[
              0.18757656925487778`, 0.3144852457012422, 0.9339935801731742], 
             UndirectedEdge[27, 71] -> 
             RGBColor[
              0.3151295512981096, 0.44346707407337604`, 0.941443700170782], 
             UndirectedEdge[122, 125] -> 
             RGBColor[
              0.2711034312291314, 0.40227727354510906`, 0.9387503113956892], 
             UndirectedEdge[5, 147] -> 
             RGBColor[
              0.30192938265782127`, 0.43046237343882565`, 0.9406601329443018],
              UndirectedEdge[5, 71] -> 
             RGBColor[
              0.35903634826225916`, 0.48540097199837007`, 0.9440984565212622],
              UndirectedEdge[61, 84] -> 
             RGBColor[
              0.19428775253280067`, 0.3215391248399355, 0.9343757721325461], 
             UndirectedEdge[62, 149] -> 
             RGBColor[
              0.19270262269030192`, 0.3198730528724325, 0.9342855013330051], 
             UndirectedEdge[36, 138] -> 
             RGBColor[
              0.20221257093783607`, 0.32986861144613544`, 0.9348270788169946],
              UndirectedEdge[33, 162] -> 
             RGBColor[
              0.7220177660315357, 0.778314884514083, 0.8609475350328932], 
             UndirectedEdge[63, 145] -> 
             RGBColor[
              0.1909329030445121, 0.31801296531800116`, 0.9341847184172432], 
             UndirectedEdge[93, 173] -> 
             RGBColor[
              0.29957000075540785`, 0.42674182123979476`, 0.9405711974554323],
              UndirectedEdge[23, 55] -> 
             RGBColor[
              0.27975796086466953`, 0.40886517255793126`, 0.9393350247385799],
              UndirectedEdge[23, 165] -> 
             RGBColor[
              0.21472043526896856`, 0.3430151699025583, 0.9355393831869255], 
             UndirectedEdge[54, 64] -> 
             RGBColor[
              0.8089618730748239, 0.8413144235136905, 0.6866933210901831], 
             UndirectedEdge[72, 158] -> 
             RGBColor[
              0.284772839183219, 0.41594216701181014`, 0.93955448669119], 
             UndirectedEdge[73, 149] -> 
             RGBColor[
              0.2014915378121197, 0.32911075991486693`, 0.934786017047158], 
             UndirectedEdge[10, 197] -> 
             RGBColor[
              0.20932817111234645`, 0.33734755838465436`, 0.9352323017203459],
              UndirectedEdge[37, 135] -> 
             RGBColor[
              0.21639131765151565`, 0.3447713732266772, 0.9356345374667627], 
             UndirectedEdge[58, 96] -> 
             RGBColor[
              0.9484965672474285, 0.961109404699039, 0.9720660567902085], 
             UndirectedEdge[112, 156] -> 
             RGBColor[
              0.880064299434007, 0.550351383801579, 0.5748087868596949], 
             UndirectedEdge[2, 187] -> 
             RGBColor[
              0.1929273076602217, 0.3201092110216681, 0.9342982968096505], 
             UndirectedEdge[43, 169] -> 
             RGBColor[
              0.19092016970595993`, 0.3179995817718425, 0.9341839932724498], 
             UndirectedEdge[44, 96] -> 
             RGBColor[
              0.9175951806585165, 0.7926689208755102, 0.6148806669986575], 
             UndirectedEdge[88, 161] -> 
             RGBColor[
              0.25019540273130497`, 0.38030160994832113`, 0.9375596301033943],
              UndirectedEdge[129, 146] -> 
             RGBColor[
              0.3499373734033699, 0.4716321745432704, 0.9437417596579802], 
             UndirectedEdge[23, 111] -> 
             RGBColor[
              0.2218869245410005, 0.3505476045091276, 0.935947504149097], 
             UndirectedEdge[174, 196] -> 
             RGBColor[
              0.21150965778077974`, 0.33964043918742115`, 0.9353565341588927],
              UndirectedEdge[66, 100] -> 
             RGBColor[
              0.1946685243294859, 0.3219393401405779, 0.9343974565230659], 
             UndirectedEdge[10, 73] -> 
             RGBColor[
              0.2177148298927659, 0.346162468507754, 0.9357099095309409], 
             UndirectedEdge[147, 188] -> 
             RGBColor[
              0.2813635156046871, 0.41264925306793426`, 0.9393496940813583], 
             UndirectedEdge[62, 189] -> 
             RGBColor[
              0.19716645902323188`, 0.3245648278819121, 0.9345397102085116], 
             UndirectedEdge[42, 89] -> 
             RGBColor[
              0.2351425012723703, 0.3644800561059042, 0.93670238963408], 
             UndirectedEdge[119, 140] -> 
             RGBColor[
              0.9202745550794877, 0.6749563522500728, 0.37533269810004777`], 
             UndirectedEdge[140, 151] -> 
             RGBColor[
              0.9938132108339699, 0.9903648965039682, 0.6544475852461695], 
             UndirectedEdge[1, 86] -> 
             RGBColor[
              0.19100632204633058`, 0.3180901333439459, 0.934188899520783], 
             UndirectedEdge[76, 181] -> 
             RGBColor[
              0.3512106902527362, 0.4745086778453089, 0.9437504499593281], 
             UndirectedEdge[122, 166] -> 
             RGBColor[
              0.5408265520373148, 0.6280223043100961, 0.9601053035876213], 
             UndirectedEdge[10, 189] -> 
             RGBColor[
              0.20619097081485965`, 0.33405016196200843`, 0.935053642804476], 
             UndirectedEdge[102, 162] -> 
             RGBColor[
              0.7102938185962386, 0.7709719692690975, 0.9435231591185078], 
             UndirectedEdge[156, 183] -> 
             RGBColor[
              0.8775508907403917, 0.4651845189226452, 0.21661436767605732`], 
             UndirectedEdge[31, 199] -> 
             RGBColor[
              0.763611242939182, 0.811608878069138, 0.8422514778526693], 
             UndirectedEdge[73, 130] -> 
             RGBColor[
              0.20088728591826768`, 0.3284756528626456, 0.9347516057957137], 
             UndirectedEdge[4, 199] -> 
             RGBColor[
              0.6647841302718416, 0.7281451631679503, 0.8353642944923663], 
             UndirectedEdge[6, 83] -> 
             RGBColor[
              0.8789095063816696, 0.593376334043407, 0.5852871633250518], 
             UndirectedEdge[73, 89] -> 
             RGBColor[
              0.2424970217804455, 0.37221012346342386`, 0.9371212186969768], 
             UndirectedEdge[60, 111] -> 
             RGBColor[
              0.20055843927843664`, 0.3281300141941019, 0.9347328784660603], 
             UndirectedEdge[166, 179] -> 
             RGBColor[
              0.5861348125663353, 0.6701157697397615, 0.962887963403471], 
             UndirectedEdge[30, 197] -> 
             RGBColor[
              0.20513605721851214`, 0.33294138088686204`, 0.9349935670357687],
              UndirectedEdge[26, 58] -> 
             RGBColor[
              0.6266794481836577, 0.6975908926125163, 0.9458012343118618], 
             UndirectedEdge[11, 35] -> 
             RGBColor[
              0.19186691491128627`, 0.3189946710097535, 0.9342379090113091], 
             UndirectedEdge[137, 187] -> 
             RGBColor[
              0.2636867399140619, 0.3930814743205634, 0.9383792168036308], 
             UndirectedEdge[13, 153] -> 
             RGBColor[
              0.2516813551580962, 0.3818634401637041, 0.9376442528958304], 
             UndirectedEdge[71, 75] -> 
             RGBColor[
              0.4329404581640204, 0.5480873032405589, 0.9491738543179573], 
             UndirectedEdge[16, 67] -> 
             RGBColor[
              0.22153288342254734`, 0.3501754848461299, 0.935927342031158], 
             UndirectedEdge[156, 170] -> 
             RGBColor[
              0.7369628216448929, 0.4377252679215747, 0.5659130186213281], 
             UndirectedEdge[96, 128] -> 
             RGBColor[
              0.683861542921137, 0.7500489673999585, 0.97060899306342], 
             UndirectedEdge[62, 114] -> 
             RGBColor[
              0.19065828327948256`, 0.31772432253305627`, 0.9341690792278882],
              UndirectedEdge[101, 105] -> 
             RGBColor[
              0.20097546444375586`, 0.32856833408377506`, 0.9347566274322918],
              UndirectedEdge[30, 89] -> 
             RGBColor[
              0.2385405045564212, 0.3680515730032935, 0.9368959008942113], 
             UndirectedEdge[53, 191] -> 
             RGBColor[
              0.720943391874006, 0.781763716393137, 0.9729313233883682], 
             UndirectedEdge[72, 81] -> 
             RGBColor[
              0.2796155967323937, 0.4112240991915025, 0.9392350666284796], 
             UndirectedEdge[163, 175] -> 
             RGBColor[
              0.39116697450397153`, 0.5094530755186824, 0.9465916451974521], 
             UndirectedEdge[82, 125] -> 
             RGBColor[
              0.23812411131454123`, 0.3676139173052213, 0.9368721879150849], 
             UndirectedEdge[113, 148] -> 
             RGBColor[
              0.19901516852776863`, 0.3265079387861328, 0.9346449914798742], 
             UndirectedEdge[33, 44] -> 
             RGBColor[
              0.9456987231028435, 0.812227711259105, 0.5045786610453252], 
             UndirectedEdge[21, 179] -> 
             RGBColor[
              0.3649219793710912, 0.49049880984441946`, 0.9444734837310578], 
             UndirectedEdge[75, 188] -> 
             RGBColor[
              0.40767232346158455`, 0.5262013149746865, 0.9475637911184522], 
             UndirectedEdge[85, 88] -> 
             RGBColor[
              0.24351738394062986`, 0.3732825887884752, 0.9371793268125088], 
             UndirectedEdge[13, 185] -> 
             RGBColor[
              0.22657810602203676`, 0.3554783336837818, 0.936214659994461], 
             UndirectedEdge[93, 161] -> 
             RGBColor[
              0.2576073800376916, 0.38809206804383756`, 0.9379817312459552], 
             UndirectedEdge[146, 196] -> 
             RGBColor[
              0.23919497538687848`, 0.3687394633419514, 0.9369331720398031], 
             UndirectedEdge[19, 162] -> 
             RGBColor[
              0.4013143224518391, 0.5220200282886156, 0.9467923716516777], 
             UndirectedEdge[140, 172] -> 
             RGBColor[
              0.931531992024998, 0.7442858149051479, 0.38543931844832946`], 
             UndirectedEdge[71, 142] -> 
             RGBColor[
              0.312868249726037, 0.44109030274632716`, 0.9413149223915483], 
             UndirectedEdge[87, 142] -> 
             RGBColor[
              0.23935044537430794`, 0.3689028721561064, 0.9369420258255899], 
             UndirectedEdge[89, 147] -> 
             RGBColor[
              0.25851974752031004`, 0.38905102411550896`, 0.9380336892243635],
              UndirectedEdge[30, 42] -> 
             RGBColor[
              0.2061681954908564, 0.33402622365244206`, 0.935052345783467], 
             UndirectedEdge[8, 125] -> 
             RGBColor[
              0.2737736625674596, 0.4050838559841373, 0.9389023771201537], 
             UndirectedEdge[29, 168] -> 
             RGBColor[
              0.2081540694089858, 0.33611350305207477`, 0.9351654383652672], 
             UndirectedEdge[158, 160] -> 
             RGBColor[
              0.3797675485885813, 0.503357295740605, 0.945419430274175], 
             UndirectedEdge[138, 153] -> 
             RGBColor[
              0.25206516984128635`, 0.38226685373099345`, 0.9376661105742352],
              UndirectedEdge[26, 122] -> 
             RGBColor[
              0.285352985800269, 0.4172544588733168, 0.9395618024481885], 
             UndirectedEdge[53, 195] -> 
             RGBColor[
              0.5664075262483584, 0.658874172033517, 0.9590088217668552], 
             UndirectedEdge[19, 93] -> 
             RGBColor[
              0.291301712500707, 0.4195802455298239, 0.9400443494392029], 
             UndirectedEdge[11, 196] -> 
             RGBColor[
              0.21797120015163274`, 0.34643192990463634`, 0.9357245094379176],
              UndirectedEdge[87, 168] -> 
             RGBColor[
              0.21305020122447582`, 0.34125964802284164`, 0.9354442658289815],
              UndirectedEdge[78, 124] -> 
             RGBColor[
              0.20448428030599214`, 0.3322563220267605, 0.9349564493048182], 
             UndirectedEdge[39, 117] -> 
             RGBColor[
              0.21869250923105948`, 0.34719007148075093`, 0.9357655869229098],
              UndirectedEdge[42, 130] -> 
             RGBColor[
              0.1935327654101925, 0.32074558550512594`, 0.9343327767328169], 
             UndirectedEdge[11, 94] -> 
             RGBColor[
              0.19668351642529655`, 0.32405722459115277`, 0.9345122073420087],
              UndirectedEdge[27, 168] -> 
             RGBColor[
              0.23795894096275363`, 0.36744031279308736`, 0.9368627817078983],
              UndirectedEdge[30, 51] -> 
             RGBColor[
              0.19588138072155636`, 0.3232141291081808, 0.934466526900334], 
             UndirectedEdge[6, 58] -> 
             RGBColor[
              0.8960048531020866, 0.6063661726923737, 0.5646755963969717], 
             UndirectedEdge[6, 156] -> 
             RGBColor[
              0.8250753518515919, 0.1937457191863889, 0.17164549129263085`], 
             UndirectedEdge[19, 173] -> 
             RGBColor[
              0.35948494367207134`, 0.4857895227952885, 0.9441270406240982], 
             UndirectedEdge[57, 200] -> 
             RGBColor[
              0.1862266556746971, 0.31306640093900795`, 0.9339167045918012], 
             UndirectedEdge[37, 50] -> 
             RGBColor[
              0.21979652604601302`, 0.3483504631519761, 0.935828459047275], 
             UndirectedEdge[49, 171] -> 
             RGBColor[
              0.36505233439370555`, 0.4905196472833987, 0.9444851609543292], 
             UndirectedEdge[5, 127] -> 
             RGBColor[
              0.6145607504851762, 0.6921619319485797, 0.9658590156709901], 
             UndirectedEdge[85, 152] -> 
             RGBColor[
              0.2353287944309912, 0.36467586202728325`, 0.9367129987538674], 
             UndirectedEdge[130, 131] -> 
             RGBColor[
              0.18289522364297445`, 0.3095648546486768, 0.9337269844660065], 
             UndirectedEdge[33, 58] -> 
             RGBColor[
              0.9766001096917556, 0.9806681950826337, 0.8617640508368762], 
             UndirectedEdge[82, 98] -> 
             RGBColor[
              0.20223313817939134`, 0.32989022892104847`, 0.9348282500909746],
              UndirectedEdge[74, 173] -> 
             RGBColor[
              0.35684188955631446`, 0.48350024216398235`, 0.9439586275530032],
              UndirectedEdge[118, 146] -> 
             RGBColor[
              0.3181356246114969, 0.44411840298139715`, 0.9417067307257794], 
             UndirectedEdge[23, 115] -> 
             RGBColor[
              0.26933147945021957`, 0.39983427840692803`, 0.9386706585626268],
              UndirectedEdge[49, 65] -> 
             RGBColor[
              0.6893465246568067, 0.7023129196468301, 0.6165085243035178], 
             UndirectedEdge[21, 23] -> 
             RGBColor[
              0.2924706869731754, 0.4198762969529263, 0.9401450684047916], 
             UndirectedEdge[40, 171] -> 
             RGBColor[
              0.40679020531210003`, 0.5252450633334856, 0.9475386222406603], 
             UndirectedEdge[104, 158] -> 
             RGBColor[
              0.3417223041341413, 0.47040441720375525`, 0.9429952209396267], 
             UndirectedEdge[53, 155] -> 
             RGBColor[
              0.6524866330944523, 0.728284776143913, 0.9661081934380052], 
             UndirectedEdge[164, 200] -> 
             RGBColor[
              0.19289342095861073`, 0.320073593949734, 0.9342963670121247], 
             UndirectedEdge[81, 142] -> 
             RGBColor[
              0.28401388302550323`, 0.4158469769530182, 0.9394855425261907], 
             UndirectedEdge[39, 85] -> 
             RGBColor[
              0.26126709675452753`, 0.3919386623526739, 0.9381901466989133], 
             UndirectedEdge[107, 142] -> 
             RGBColor[
              0.23981543626826407`, 0.36939160706777974`, 0.9369685063691083],
              UndirectedEdge[121, 161] -> 
             RGBColor[
              0.25059050057240173`, 0.38071688282996385`, 0.9375821303409498],
              UndirectedEdge[1, 196] -> 
             RGBColor[
              0.20645103349834157`, 0.33432350433127433`, 0.935068452989572], 
             UndirectedEdge[88, 121] -> 
             RGBColor[
              0.21695791281236698`, 0.34536690066494, 0.9356668042229707], 
             UndirectedEdge[85, 133] -> 
             RGBColor[
              0.25979757259338154`, 0.39039409928609614`, 0.9381064594719022],
              UndirectedEdge[118, 127] -> 
             RGBColor[
              0.6328274279834254, 0.7079836098876566, 0.9670229522085898], 
             UndirectedEdge[100, 187] -> 
             RGBColor[
              0.2046359853658942, 0.3324157736633738, 0.9349650886835521], 
             UndirectedEdge[26, 116] -> 
             RGBColor[
              0.2667049754056552, 0.39765421759642916`, 0.9384998258434745], 
             UndirectedEdge[131, 147] -> 
             RGBColor[
              0.21550989668752718`, 0.3438449439082084, 0.9355843418468089], 
             UndirectedEdge[134, 160] -> 
             RGBColor[
              0.3450319511386071, 0.4675505014401682, 0.9434155666515178], 
             UndirectedEdge[3, 5] -> 
             RGBColor[
              0.38651352623245844`, 0.5092003225130362, 0.945849278004409], 
             UndirectedEdge[16, 100] -> 
             RGBColor[
              0.19648326478805916`, 0.32384674742372915`, 0.9345008033075137],
              UndirectedEdge[75, 147] -> 
             RGBColor[
              0.3758334925595824, 0.4931487046810145, 0.9457355307409967], 
             UndirectedEdge[72, 76] -> 
             RGBColor[
              0.25872488056116644`, 0.3892666319476351, 0.9380453712475731], 
             UndirectedEdge[40, 69] -> 
             RGBColor[
              0.37782213400795434`, 0.4947977837110262, 0.9458889334343104], 
             UndirectedEdge[177, 179] -> 
             RGBColor[
              0.2929650964677688, 0.41972688072457853`, 0.940197722295881], 
             UndirectedEdge[98, 100] -> 
             RGBColor[
              0.19914601799870904`, 0.3266454698764268, 0.9346524431636698], 
             UndirectedEdge[136, 187] -> 
             RGBColor[
              0.2131466560055322, 0.3413610281133182, 0.9354497587860706], 
             UndirectedEdge[54, 199] -> 
             RGBColor[
              0.9918267372139176, 0.9824082030898711, 0.5688071701781774], 
             UndirectedEdge[166, 198] -> 
             RGBColor[
              0.5746764165171943, 0.6601910829977264, 0.9621578445394816], 
             UndirectedEdge[48, 104] -> 
             RGBColor[
              0.28879698411440874`, 0.4154790711874804, 0.939955479525905], 
             UndirectedEdge[187, 198] -> 
             RGBColor[
              0.2745522899410462, 0.4024926676355137, 0.9390715600433216], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.20340607327822147`, 0.3311230580782995, 0.9348950470096511], 
             UndirectedEdge[103, 117] -> 
             RGBColor[
              0.1832018217377303, 0.30988710868570724`, 0.9337444447739318], 
             UndirectedEdge[85, 140] -> 
             RGBColor[
              0.632097596410786, 0.6952982597896742, 0.7484529667837756], 
             UndirectedEdge[36, 70] -> 
             RGBColor[
              0.18680103840766088`, 0.3136701136093215, 0.9339494148387204], 
             UndirectedEdge[54, 171] -> 
             RGBColor[
              0.6480714766956179, 0.7066517748176793, 0.6751229004016905], 
             UndirectedEdge[120, 125] -> 
             RGBColor[
              0.22911059591556282`, 0.35814014113101095`, 0.9363588815474142],
              UndirectedEdge[81, 104] -> 
             RGBColor[
              0.336565061683316, 0.46568634938344766`, 0.9426758008769163], 
             UndirectedEdge[93, 162] -> 
             RGBColor[
              0.34139937953517563`, 0.46297232673312194`, 0.9432365284830118],
              UndirectedEdge[73, 168] -> 
             RGBColor[
              0.2134383142319024, 0.3416675794014329, 0.9354663682905927], 
             UndirectedEdge[119, 199] -> 
             RGBColor[
              0.921043290148025, 0.6766189653862216, 0.46033982093126385`], 
             UndirectedEdge[17, 107] -> 
             RGBColor[
              0.20455110797063392`, 0.33232656213941764`, 0.9349602550414569],
              UndirectedEdge[14, 48] -> 
             RGBColor[
              0.19487547737670605`, 0.3221568609147874, 0.9344092421929455], 
             UndirectedEdge[64, 182] -> 
             RGBColor[
              0.48518193863662246`, 0.5898773465279377, 0.9534583400112507], 
             UndirectedEdge[71, 129] -> 
             RGBColor[
              0.40910477455238126`, 0.5287364214993203, 0.947297421991063], 
             UndirectedEdge[80, 100] -> 
             RGBColor[
              0.2137920345531072, 0.3420393618861828, 0.935486512139603], 
             UndirectedEdge[18, 178] -> 
             RGBColor[
              0.20335755177255102`, 0.3310720588993987, 0.9348922837816843], 
             UndirectedEdge[174, 186] -> 
             RGBColor[
              0.18655058120662976`, 0.3134068672111341, 0.9339351516716399], 
             UndirectedEdge[115, 165] -> 
             RGBColor[
              0.2604142264170086, 0.39046168008252585`, 0.9381628341942789], 
             UndirectedEdge[113, 198] -> 
             RGBColor[
              0.2750384221935423, 0.4030036234554522, 0.939099244555933], 
             UndirectedEdge[67, 100] -> 
             RGBColor[
              0.2308404904839133, 0.3599583700039979, 0.936457396483932], 
             UndirectedEdge[106, 147] -> 
             RGBColor[
              0.21727737751825504`, 0.3457026783260606, 0.9356849972653654], 
             UndirectedEdge[75, 129] -> 
             RGBColor[
              0.47830661680484077`, 0.5873498848465282, 0.9520731954511965], 
             UndirectedEdge[175, 183] -> 
             RGBColor[
              0.7184776908452273, 0.695458275607814, 0.6107486570608233], 
             UndirectedEdge[105, 144] -> 
             RGBColor[
              0.20212260779592514`, 0.3297740544799944, 0.9348219555491514], 
             UndirectedEdge[44, 128] -> 
             RGBColor[
              0.6650402658915442, 0.5906178095064059, 0.5929751287851128], 
             UndirectedEdge[70, 138] -> 
             RGBColor[
              0.2064620848582796, 0.334335120011266, 0.9350690823481714], 
             UndirectedEdge[110, 145] -> 
             RGBColor[
              0.18515978669395372`, 0.31194505399684636`, 0.9338559479816391],
              UndirectedEdge[49, 118] -> 
             RGBColor[
              0.4066109576924045, 0.5266077075173656, 0.9471298685655758], 
             UndirectedEdge[70, 185] -> 
             RGBColor[
              0.21155038817505178`, 0.3396832494142572, 0.9353588536945914], 
             UndirectedEdge[11, 138] -> 
             RGBColor[
              0.2124149402657507, 0.3405919484773504, 0.9354080886571665], 
             UndirectedEdge[120, 187] -> 
             RGBColor[
              0.1987095901475981, 0.32618675653378515`, 0.9346275892431862], 
             UndirectedEdge[71, 127] -> 
             RGBColor[
              0.6192630181344778, 0.6962347998435606, 0.9661586400075515], 
             UndirectedEdge[4, 182] -> 
             RGBColor[
              0.33757022299890055`, 0.4668080932140755, 0.9427306540012304], 
             UndirectedEdge[29, 71] -> 
             RGBColor[
              0.2853246797443417, 0.4121402643323634, 0.939746356828151], 
             UndirectedEdge[63, 185] -> 
             RGBColor[
              0.2118614125837917, 0.3400101557879294, 0.9353765660745497], 
             UndirectedEdge[83, 175] -> 
             RGBColor[
              0.7134786289406714, 0.7747821951592325, 0.9733333335119576], 
             UndirectedEdge[79, 126] -> 
             RGBColor[
              0.1869217092836395, 0.3137969463509505, 0.9339562868665908], 
             UndirectedEdge[107, 154] -> 
             RGBColor[
              0.27475191641420155`, 0.4039740129877124, 0.9390363717067235], 
             UndirectedEdge[34, 64] -> 
             RGBColor[
              0.5297940733748047, 0.6285181353670621, 0.956300985787806], 
             UndirectedEdge[159, 180] -> 
             RGBColor[
              0.29846249583214285`, 0.427955785985238, 0.9404210556305891], 
             UndirectedEdge[3, 123] -> 
             RGBColor[
              0.4349086817945046, 0.5511177738496366, 0.9489329745226667], 
             UndirectedEdge[50, 97] -> 
             RGBColor[
              0.21027301783359342`, 0.33834065219542714`, 0.9352861093433454],
              UndirectedEdge[87, 89] -> 
             RGBColor[
              0.24210890877301894`, 0.37180219208483256`, 0.9370991162353657],
              UndirectedEdge[123, 191] -> 
             RGBColor[
              0.6306139888746021, 0.7083706761376785, 0.9658367189463131], 
             UndirectedEdge[108, 151] -> 
             RGBColor[
              0.6509649455844404, 0.716416401604573, 0.8457783120147642], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.19532837830452823`, 0.32263288850550587`, 0.9344350342307781],
              UndirectedEdge[19, 33] -> 
             RGBColor[
              0.6719200989970671, 0.734922803310785, 0.8577553559890845], 
             UndirectedEdge[156, 199] -> 
             RGBColor[
              0.9069891921772075, 0.5685930098375191, 0.4468816008425758], 
             UndirectedEdge[47, 144] -> 
             RGBColor[
              0.19737482195309003`, 0.32478383053216575`, 0.9345515761691217],
              UndirectedEdge[123, 127] -> 
             RGBColor[
              0.6629559060472224, 0.73407938328518, 0.9689427121892478], 
             UndirectedEdge[82, 120] -> 
             RGBColor[
              0.2029515968118113, 0.3306453744966301, 0.9348691652472267], 
             UndirectedEdge[120, 137] -> 
             RGBColor[
              0.2589152311792967, 0.38806631610919806`, 0.9381074864400005], 
             UndirectedEdge[122, 179] -> 
             RGBColor[
              0.32323201256899053`, 0.45153932858028145`, 0.9419213783919558],
              UndirectedEdge[52, 124] -> 
             RGBColor[
              0.20581307491926143`, 0.333652969415751, 0.9350321221922685], 
             UndirectedEdge[17, 106] -> 
             RGBColor[
              0.18824964863953902`, 0.315192694810219, 0.934031911048399], 
             UndirectedEdge[125, 166] -> 
             RGBColor[
              0.5340062312264762, 0.620853714704589, 0.9597168964072044], 
             UndirectedEdge[7, 79] -> 
             RGBColor[
              0.20133607999592745`, 0.328947363893454, 0.934777163954505], 
             UndirectedEdge[49, 127] -> 
             RGBColor[
              0.6485709500663741, 0.7216198574234791, 0.9680261155142653], 
             UndirectedEdge[121, 200] -> 
             RGBColor[
              0.20398334673618768`, 0.33172980908387323`, 0.9349279218790827],
              UndirectedEdge[56, 193] -> 
             RGBColor[
              0.2060154437903921, 0.33386567193023686`, 0.9350436468001014], 
             UndirectedEdge[149, 194] -> 
             RGBColor[
              0.1935128959182038, 0.3207247014092473, 0.9343316451946424], 
             UndirectedEdge[108, 133] -> 
             RGBColor[
              0.27857495084464845`, 0.41013031438272207`, 0.9391758033846701],
              UndirectedEdge[41, 140] -> 
             RGBColor[
              0.6422147641826323, 0.7059320445833706, 0.7490291245213738], 
             UndirectedEdge[36, 185] -> 
             RGBColor[
              0.2073008742546082, 0.33521674084912667`, 0.9351168501634146], 
             UndirectedEdge[108, 111] -> 
             RGBColor[
              0.26408143509617243`, 0.39489671038909974`, 0.9383504191040295],
              UndirectedEdge[72, 154] -> 
             RGBColor[
              0.2925360773933412, 0.42266629375772025`, 0.940049153365177], 
             UndirectedEdge[63, 110] -> 
             RGBColor[
              0.18589948479502594`, 0.3127225236006417, 0.9338980726942099], 
             UndirectedEdge[15, 186] -> 
             RGBColor[
              0.18099749200595946`, 0.30757021837503873`, 0.933618911456721], 
             UndirectedEdge[54, 155] -> 
             RGBColor[
              0.8307914164161123, 0.8585643375610341, 0.688734731768329], 
             UndirectedEdge[18, 108] -> 
             RGBColor[
              0.2655472156605108, 0.39643733869807485`, 0.9384338931387406], 
             UndirectedEdge[44, 102] -> 
             RGBColor[
              0.9339747756675465, 0.8048847960141194, 0.5871542851309398], 
             UndirectedEdge[8, 122] -> 
             RGBColor[
              0.2805939833782982, 0.4122524455896443, 0.9392907843005704], 
             UndirectedEdge[42, 197] -> 
             RGBColor[
              0.20173805393446126`, 0.32936986398947277`, 0.9348000557756375],
              UndirectedEdge[48, 147] -> 
             RGBColor[
              0.2300092060376818, 0.3590846373445305, 0.9364100560644943], 
             UndirectedEdge[34, 54] -> 
             RGBColor[
              0.7092249646791587, 0.7597119219751208, 0.6790161754635967], 
             UndirectedEdge[5, 75] -> 
             RGBColor[
              0.42823819051471873`, 0.5440144353455778, 0.9488742299813958], 
             UndirectedEdge[55, 115] -> 
             RGBColor[
              0.3254517520127096, 0.4563116827378988, 0.9419584757459334], 
             UndirectedEdge[49, 155] -> 
             RGBColor[
              0.5477722741141999, 0.6424322100267535, 0.9580969923209677], 
             UndirectedEdge[66, 136] -> 
             RGBColor[
              0.2031791949691239, 0.33088459459052233`, 0.9348821266255843], 
             UndirectedEdge[136, 148] -> 
             RGBColor[
              0.2081945933984414, 0.33615609633436194`, 0.9351677461465169], 
             UndirectedEdge[130, 189] -> 
             RGBColor[
              0.18936342684036145`, 0.3163633463169, 0.9340953390692487], 
             UndirectedEdge[48, 76] -> 
             RGBColor[
              0.23737108877035865`, 0.36682244286689847`, 0.9368293043951907],
              UndirectedEdge[29, 141] -> 
             RGBColor[
              0.2753633186073925, 0.40351223398810643`, 0.9391116277049905], 
             UndirectedEdge[133, 163] -> 
             RGBColor[
              0.26544293338464375`, 0.39632773141426036`, 0.9384279544174017],
              UndirectedEdge[111, 169] -> 
             RGBColor[
              0.20611458183414505`, 0.33396987229993624`, 0.9350492925650316],
              UndirectedEdge[76, 142] -> 
             RGBColor[
              0.26312316685427595`, 0.39388950970915076`, 0.9382958471452842],
              UndirectedEdge[78, 98] -> 
             RGBColor[
              0.18771622042890102`, 0.3146320279395365, 0.9340015331009395], 
             UndirectedEdge[21, 170] -> 
             RGBColor[
              0.5082558273140996, 0.6089687689524979, 0.9552557972010979], 
             UndirectedEdge[92, 139] -> 
             RGBColor[
              0.26505756074119424`, 0.3959226803319581, 0.938406008015465], 
             UndirectedEdge[63, 70] -> 
             RGBColor[
              0.1913615767368444, 0.3184635285481242, 0.9342091307498555], 
             UndirectedEdge[71, 197] -> 
             RGBColor[
              0.2822222657868389, 0.40887943055862197`, 0.9395696789428815], 
             UndirectedEdge[127, 141] -> 
             RGBColor[
              0.6093016569975287, 0.6876067694993037, 0.9655239108843909], 
             UndirectedEdge[64, 138] -> 
             RGBColor[
              0.4257022995794623, 0.5303271273768558, 0.949962438870419], 
             UndirectedEdge[39, 108] -> 
             RGBColor[
              0.2800444750057945, 0.41167487744929976`, 0.9392594906116811], 
             UndirectedEdge[24, 165] -> 
             RGBColor[
              0.23147521014501135`, 0.3606255006113628, 0.9364935428296479], 
             UndirectedEdge[132, 182] -> 
             RGBColor[
              0.3206991952751244, 0.45143891338558356`, 0.9416833404765177], 
             UndirectedEdge[77, 181] -> 
             RGBColor[
              0.627745965168717, 0.3440360509358098, 0.5566794847766803], 
             UndirectedEdge[20, 47] -> 
             RGBColor[
              0.189292245231432, 0.3162885299327404, 0.9340912853819239], 
             UndirectedEdge[191, 199] -> 
             RGBColor[
              0.9026821480304056, 0.9219432707783801, 0.8549565211308954], 
             UndirectedEdge[89, 154] -> 
             RGBColor[
              0.29969282708516165`, 0.4301884914479621, 0.9404567196726639], 
             UndirectedEdge[93, 164] -> 
             RGBColor[
              0.2132799643411767, 0.3415011436263172, 0.9354573504985735], 
             UndirectedEdge[26, 187] -> 
             RGBColor[
              0.24813165922146568`, 0.378132484670584, 0.9374421029635438], 
             UndirectedEdge[5, 188] -> 
             RGBColor[
              0.33376821355982345`, 0.4635149837324976, 0.9424883933217574], 
             UndirectedEdge[7, 16] -> 
             RGBColor[
              0.19783499493782034`, 0.3252675015157697, 0.9345777823398371], 
             UndirectedEdge[154, 160] -> 
             RGBColor[
              0.38753078679870345`, 0.510081422486515, 0.9459140969481619], 
             UndirectedEdge[88, 152] -> 
             RGBColor[
              0.20837422546163153`, 0.3363449010221054, 0.9351779759267738], 
             UndirectedEdge[9, 18] -> 
             RGBColor[
              0.2081906159438856, 0.3361519157774386, 0.935167519636364], 
             UndirectedEdge[9, 200] -> 
             RGBColor[
              0.19196359639909227`, 0.31909628938339796`, 0.9342434148790122],
              UndirectedEdge[55, 183] -> 
             RGBColor[
              0.6361311703010923, 0.6254168955585735, 0.6051471025896153], 
             UndirectedEdge[72, 104] -> 
             RGBColor[
              0.31015077590521656`, 0.43792326026821704`, 0.9411715463782875],
              UndirectedEdge[112, 181] -> 
             RGBColor[
              0.6897919274498447, 0.754885022928866, 0.9666005855889899], 
             UndirectedEdge[136, 193] -> 
             RGBColor[
              0.22613676588736786`, 0.35501445721966407`, 0.9361895263266957],
              UndirectedEdge[80, 198] -> 
             RGBColor[
              0.28370833912825916`, 0.4121162558583227, 0.9395929834993725], 
             UndirectedEdge[42, 131] -> 
             RGBColor[
              0.19213265043958744`, 0.3192739758986036, 0.9342530422565254], 
             UndirectedEdge[65, 156] -> 
             RGBColor[
              0.887528121922009, 0.5046298539287588, 0.2252206944152773], 
             UndirectedEdge[26, 192] -> 
             RGBColor[
              0.37924820246199464`, 0.5010949181579147, 0.9455333797204014], 
             UndirectedEdge[65, 155] -> 
             RGBColor[
              0.8147643189956533, 0.8045011746203956, 0.6264724847532339], 
             UndirectedEdge[59, 62] -> 
             RGBColor[
              0.19206220882201708`, 0.3191999372922807, 0.9342490307106137], 
             UndirectedEdge[82, 187] -> 
             RGBColor[
              0.2077231055465765, 0.3356605327079955, 0.9351408956108569], 
             UndirectedEdge[4, 86] -> 
             RGBColor[
              0.26820213237561147`, 0.3968644845029512, 0.9386716201723606], 
             UndirectedEdge[73, 167] -> 
             RGBColor[
              0.20840651893599757`, 0.33637884351118863`, 0.9351798149923649],
              UndirectedEdge[74, 159] -> 
             RGBColor[
              0.30041133141594933`, 0.42964376941660665`, 0.9405452337107016],
              UndirectedEdge[25, 60] -> 
             RGBColor[
              0.18025977124348086`, 0.3067948270794758, 0.9335768993506579], 
             UndirectedEdge[159, 162] -> 
             RGBColor[
              0.3531520525661749, 0.4753251312512108, 0.9439058258256054], 
             UndirectedEdge[10, 147] -> 
             RGBColor[
              0.23373755563263043`, 0.3630033691598391, 0.9366223800583277], 
             UndirectedEdge[23, 163] -> 
             RGBColor[
              0.2527001813973467, 0.382934291138471, 0.9377022735429374], 
             UndirectedEdge[40, 54] -> 
             RGBColor[
              0.7471114929956602, 0.7911014986375555, 0.6818242326049438], 
             UndirectedEdge[123, 129] -> 
             RGBColor[
              0.45279766246512576`, 0.5665810049409397, 0.9500814941727593], 
             UndirectedEdge[25, 165] -> 
             RGBColor[
              0.19267100347283378`, 0.3198398190700993, 0.9342837006653468], 
             UndirectedEdge[39, 178] -> 
             RGBColor[
              0.21785481111783467`, 0.34630959765062364`, 0.935717881254625], 
             UndirectedEdge[76, 107] -> 
             RGBColor[
              0.2409407195820268, 0.37057435117762727`, 0.9370325895891196], 
             UndirectedEdge[63, 138] -> 
             RGBColor[
              0.20677310926701956`, 0.33466202638493814`, 0.9350867947281298],
              UndirectedEdge[71, 81] -> 
             RGBColor[
              0.334884249211027, 0.4642305141000421, 0.942568700992466], 
             UndirectedEdge[8, 83] -> 
             RGBColor[
              0.60482509904127, 0.6795990406798771, 0.9661417830923238], 
             UndirectedEdge[10, 149] -> 
             RGBColor[
              0.2017271344819297, 0.32935838695252884`, 0.9347994339289696], 
             UndirectedEdge[119, 172] -> 
             RGBColor[
              0.858083307192903, 0.43025919736952545`, 0.20258043262042846`], 
             UndirectedEdge[106, 130] -> 
             RGBColor[
              0.1846627044737023, 0.31142258906652903`, 0.933827639884563], 
             UndirectedEdge[147, 176] -> 
             RGBColor[
              0.24180624149358806`, 0.37148406958393687`, 0.9370818797815581],
              UndirectedEdge[27, 197] -> 
             RGBColor[
              0.23361320117338766`, 0.3628726647386469, 0.9366152982558398], 
             UndirectedEdge[72, 176] -> 
             RGBColor[
              0.2436445546193927, 0.37341625323494165`, 0.9371865689945322], 
             UndirectedEdge[92, 118] -> 
             RGBColor[
              0.31765722646768046`, 0.4436155762000519, 0.9416794866592155], 
             UndirectedEdge[123, 171] -> 
             RGBColor[
              0.3794372903745538, 0.5029791731450995, 0.9454017576293117], 
             UndirectedEdge[66, 113] -> 
             RGBColor[
              0.1939997700984511, 0.32123643704229315`, 0.9343593719589416], 
             UndirectedEdge[67, 179] -> 
             RGBColor[
              0.3122151911082063, 0.43995995071817273`, 0.941293986707691], 
             UndirectedEdge[130, 197] -> 
             RGBColor[
              0.19250062713784824`, 0.3196607427395459, 0.9342739979851187], 
             UndirectedEdge[15, 194] -> 
             RGBColor[
              0.19022447471756204`, 0.31726836222942645`, 0.934144374472049], 
             UndirectedEdge[47, 135] -> 
             RGBColor[
              0.19659862417943424`, 0.3239679974582722, 0.9345073728541936], 
             UndirectedEdge[8, 170] -> 
             RGBColor[
              0.4692360918503271, 0.5728158701273882, 0.9528557575864605], 
             UndirectedEdge[17, 149] -> 
             RGBColor[
              0.1884865346732682, 0.31544167705111037`, 0.9340454013575784], 
             UndirectedEdge[13, 97] -> 
             RGBColor[
              0.21895267363831583`, 0.3474635207681535, 0.9357804029010244], 
             UndirectedEdge[11, 86] -> 
             RGBColor[
              0.20252648869962175`, 0.33019855891730787`, 0.9348449559691285],
              UndirectedEdge[15, 62] -> 
             RGBColor[
              0.18941420148966015`, 0.3164167136926116, 0.9340982306104119], 
             UndirectedEdge[37, 160] -> 
             RGBColor[
              0.33951855272220766`, 0.4617555701348826, 0.9431015867680459], 
             UndirectedEdge[46, 50] -> 
             RGBColor[
              0.1933628575006826, 0.3205670015194474, 0.9343231007287265], 
             UndirectedEdge[49, 53] -> 
             RGBColor[
              0.5270688387556056, 0.6260965211703475, 0.956144232988289], 
             UndirectedEdge[52, 120] -> 
             RGBColor[
              0.1897634736745903, 0.3167838209041087, 0.9341181211446418], 
             UndirectedEdge[81, 147] -> 
             RGBColor[
              0.2777772836065891, 0.4092919155404977, 0.9391303774155055], 
             UndirectedEdge[49, 123] -> 
             RGBColor[
              0.43673943575620155`, 0.552703480914889, 0.949049628546234], 
             UndirectedEdge[127, 140] -> 
             RGBColor[
              0.9342553301344888, 0.9459893647897327, 0.7730553915426139], 
             UndirectedEdge[31, 132] -> 
             RGBColor[
              0.4162636354385904, 0.5320766653506034, 0.9483626292299419], 
             UndirectedEdge[146, 186] -> 
             RGBColor[
              0.2142358988127285, 0.34250589136566434`, 0.9355117895525502], 
             UndirectedEdge[98, 124] -> 
             RGBColor[
              0.20926922402508408`, 0.3372856012584804, 0.9352289447709307], 
             UndirectedEdge[4, 53] -> 
             RGBColor[
              0.483045374115442, 0.5879656087827072, 0.953339096749839], 
             UndirectedEdge[82, 137] -> 
             RGBColor[
              0.26792874657827515`, 0.39754009228340836`, 0.9386207928076713],
              UndirectedEdge[42, 107] -> 
             RGBColor[
              0.21020159060141025`, 0.3382655776456545, 0.9352820416681398], 
             UndirectedEdge[99, 102] -> 
             RGBColor[
              0.7604981725449849, 0.8117818781391992, 0.9474611303534258], 
             UndirectedEdge[57, 88] -> 
             RGBColor[
              0.1992012217508764, 0.32670349252007475`, 0.9346555869356892], 
             UndirectedEdge[40, 49] -> 
             RGBColor[
              0.46409235069374777`, 0.5749693711032751, 0.9511864931575826], 
             UndirectedEdge[21, 90] -> 
             RGBColor[
              0.29428715223398993`, 0.42178551711259177`, 0.9402485134141754],
              UndirectedEdge[143, 158] -> 
             RGBColor[
              0.5860035167018279, 0.6680847618686957, 0.9637366121327604], 
             UndirectedEdge[24, 111] -> 
             RGBColor[
              0.2386416994170433, 0.36815793521793205`, 0.9369016637918195], 
             UndirectedEdge[139, 155] -> 
             RGBColor[
              0.47942908630476494`, 0.5811030666228374, 0.9538203503715414], 
             UndirectedEdge[94, 174] -> 
             RGBColor[
              0.19022197405444352`, 0.31726573387393764`, 0.9341442320629838],
              UndirectedEdge[4, 118] -> 
             RGBColor[
              0.3625874930522409, 0.48847679512972536`, 0.9443247323271259], 
             UndirectedEdge[121, 159] -> 
             RGBColor[
              0.23612256314975283`, 0.36551016327854535`, 0.9367582027081254],
              UndirectedEdge[5, 76] -> 
             RGBColor[
              0.3092912653904981, 0.4382001789611937, 0.9410793812749982], 
             UndirectedEdge[27, 194] -> 
             RGBColor[
              0.23402121805989123`, 0.3633015163561269, 0.9366385342139192], 
             UndirectedEdge[77, 160] -> 
             RGBColor[
              0.6302548648825095, 0.34620913376693074`, 0.5568393496479103], 
             UndirectedEdge[2, 80] -> 
             RGBColor[
              0.20208335684743473`, 0.32973279924447707`, 0.9348197202657014],
              UndirectedEdge[74, 85] -> 
             RGBColor[
              0.3082012500479231, 0.4378314678081793, 0.9409888580526407], 
             UndirectedEdge[35, 110] -> 
             RGBColor[
              0.18045196756199675`, 0.30699683759618646`, 0.9335878446466683],
              UndirectedEdge[143, 154] -> 
             RGBColor[
              0.5937667549119501, 0.6748088886146058, 0.9642312788067474], 
             UndirectedEdge[53, 129] -> 
             RGBColor[
              0.5431270654645298, 0.6399740451963982, 0.9571760986148143], 
             UndirectedEdge[80, 187] -> 
             RGBColor[
              0.21263714806957626`, 0.34082550296795955`, 0.9354207430628674],
              UndirectedEdge[30, 87] -> 
             RGBColor[
              0.213134602991505, 0.3413483596313704, 0.9354490723847526], 
             UndirectedEdge[29, 197] -> 
             RGBColor[
              0.2038083296196198, 0.3315458549976343, 0.9349179549132087], 
             UndirectedEdge[74, 121] -> 
             RGBColor[
              0.28164177891966025`, 0.4099157796846441, 0.9394763354631025], 
             UndirectedEdge[127, 199] -> 
             RGBColor[
              0.935024065203026, 0.9476519779258816, 0.8580625143738301], 
             UndirectedEdge[52, 80] -> 
             RGBColor[
              0.20369103159656846`, 0.33142256733828307`, 0.9349112749643229],
              UndirectedEdge[125, 187] -> 
             RGBColor[
              0.233882104650328, 0.36315529934237634`, 0.9366306119110444], 
             UndirectedEdge[57, 152] -> 
             RGBColor[
              0.19101263224123774`, 0.3180967657588828, 0.9341892588770478], 
             UndirectedEdge[128, 193] -> 
             RGBColor[
              0.3303839734000996, 0.45325331449434825`, 0.942541154768971], 
             UndirectedEdge[151, 172] -> 
             RGBColor[
              0.9316219629473853, 0.7456677416234209, 0.4816953197665501], 
             UndirectedEdge[5, 27] -> 
             RGBColor[
              0.31042728364880795`, 0.439394206178395, 0.9411440758342206], 
             UndirectedEdge[65, 118] -> 
             RGBColor[
              0.6736030025738579, 0.6886766721110076, 0.6155053609978421], 
             UndirectedEdge[78, 80] -> 
             RGBColor[
              0.20236223698329917`, 0.33002591994929253`, 0.9348356020768727],
              UndirectedEdge[40, 199] -> 
             RGBColor[
              0.7505454658303996, 0.8010014916056775, 0.8412228920171474], 
             UndirectedEdge[5, 42] -> 
             RGBColor[
              0.2785521364098815, 0.40589140542922086`, 0.9393288333540183], 
             UndirectedEdge[123, 196] -> 
             RGBColor[
              0.3420552644486344, 0.4636882937396207, 0.9432729065545822], 
             UndirectedEdge[80, 124] -> 
             RGBColor[
              0.22391524057948223`, 0.35267949326823644`, 0.9360630137468638],
              UndirectedEdge[22, 48] -> 
             RGBColor[
              0.19949157754304903`, 0.3270086748672687, 0.9346721222685106], 
             UndirectedEdge[69, 86] -> 
             RGBColor[
              0.22595538032998164`, 0.3548238094983426, 0.9361791966875385], 
             UndirectedEdge[81, 143] -> 
             RGBColor[
              0.5808462742510027, 0.663366694048388, 0.9634171920700499], 
             UndirectedEdge[80, 116] -> 
             RGBColor[
              0.23121046425376574`, 0.3603472358938047, 0.936478465942798], 
             UndirectedEdge[90, 169] -> 
             RGBColor[
              0.20968181085613852`, 0.3377192561774346, 0.9352524409805917], 
             UndirectedEdge[121, 173] -> 
             RGBColor[
              0.292553121290118, 0.41936663602592106`, 0.9401715965504269], 
             UndirectedEdge[8, 179] -> 
             RGBColor[
              0.32590224390731876`, 0.4543459110193097, 0.9420734441164204], 
             UndirectedEdge[29, 167] -> 
             RGBColor[
              0.20312227411308098`, 0.33082476716183046`, 0.9348788850670395],
              UndirectedEdge[76, 87] -> 
             RGBColor[
              0.2404757286880707, 0.37008561626595393`, 0.9370061090456012], 
             UndirectedEdge[111, 163] -> 
             RGBColor[
              0.25094941763616774`, 0.3810941274206381, 0.9376025701367612], 
             UndirectedEdge[130, 149] -> 
             RGBColor[
              0.1848995905074315, 0.3116715713074204, 0.9338411301937424], 
             UndirectedEdge[7, 122] -> 
             RGBColor[
              0.24320904209445873`, 0.37295850195814717`, 0.9371617672005202],
              UndirectedEdge[89, 142] -> 
             RGBColor[
              0.2647563469392241, 0.39560608552802945`, 0.9383888543350487], 
             UndirectedEdge[44, 172] -> 
             RGBColor[
              0.8840573238836684, 0.5664132115032791, 0.22496692784453026`], 
             UndirectedEdge[7, 179] -> 
             RGBColor[
              0.2885173026234793, 0.4150519673878126, 0.9399444270163702], 
             UndirectedEdge[73, 188] -> 
             RGBColor[
              0.26534078986482257`, 0.3958083524158491, 0.9384372235539715], 
             UndirectedEdge[16, 120] -> 
             RGBColor[
              0.19055686956976303`, 0.31761773029414053`, 0.9341633038671477],
              UndirectedEdge[98, 116] -> 
             RGBColor[
              0.21656444769936758`, 0.34495334388404864`, 0.9356443969668649],
              UndirectedEdge[5, 81] -> 
             RGBColor[
              0.3301819815617254, 0.46015764620506105`, 0.9422690766559045], 
             UndirectedEdge[76, 106] -> 
             RGBColor[
              0.2246392602509319, 0.35344048384842863`, 0.9361042455960618], 
             UndirectedEdge[135, 144] -> 
             RGBColor[
              0.19771245739729065`, 0.32513870679134427`, 0.9345708040081819],
              UndirectedEdge[194, 197] -> 
             RGBColor[
              0.20111393254862053`, 0.3287138728413728, 0.9347645129860187], 
             UndirectedEdge[27, 29] -> 
             RGBColor[
              0.2367156151308905, 0.36613349851238836`, 0.9367919761411093], 
             UndirectedEdge[44, 58] -> 
             RGBColor[
              0.9296752902178356, 0.8016782468054864, 0.5944321925119014], 
             UndirectedEdge[53, 92] -> 
             RGBColor[
              0.4381151075308816, 0.5431043898530338, 0.9506938510819287], 
             UndirectedEdge[83, 122] -> 
             RGBColor[
              0.6021548677029418, 0.6767924582408489, 0.9659897173678593], 
             UndirectedEdge[9, 178] -> 
             RGBColor[
              0.18848044580793838`, 0.31543527726759235`, 0.9340450546057055],
              UndirectedEdge[12, 99] -> 
             RGBColor[
              0.7509614073428162, 0.7434552401786318, 0.618284844686889], 
             UndirectedEdge[7, 126] -> 
             RGBColor[
              0.19407996143665954`, 0.32132072322317473`, 0.9343639387370202],
              UndirectedEdge[139, 146] -> 
             RGBColor[
              0.2655359588850107, 0.39642550711330343`, 0.9384332520820287], 
             UndirectedEdge[100, 198] -> 
             RGBColor[
              0.2757071764245771, 0.40370652655373696`, 0.9391373291200573], 
             UndirectedEdge[56, 109] -> 
             RGBColor[
              0.19998929422011852`, 0.3275318066519287, 0.9347004664969638], 
             UndirectedEdge[9, 159] -> 
             RGBColor[
              0.22410281281265743`, 0.3528766435780701, 0.9360736957080549], 
             UndirectedEdge[2, 98] -> 
             RGBColor[
              0.18743734029303655`, 0.314338907234721, 0.9339856512897682], 
             UndirectedEdge[95, 164] -> 
             RGBColor[
              0.22218549989478478`, 0.35086142613672566`, 0.9359645075737923],
              UndirectedEdge[108, 163] -> 
             RGBColor[
              0.29489469195251866`, 0.4272833970184431, 0.94010518849787], 
             UndirectedEdge[85, 121] -> 
             RGBColor[
              0.24391248178172664`, 0.37369786167011787`, 0.9372018270500644],
              UndirectedEdge[55, 177] -> 
             RGBColor[
              0.2766340766323431, 0.4055817721640561, 0.9391571241529215], 
             UndirectedEdge[118, 141] -> 
             RGBColor[
              0.36734166462355905`, 0.4925946195931902, 0.9446276639357014], 
             UndirectedEdge[58, 77] -> 
             RGBColor[
              0.8889478384033738, 0.5521228653145076, 0.5579177911517261], 
             UndirectedEdge[142, 154] -> 
             RGBColor[
              0.29693436368645065`, 0.4272891715192359, 0.9402996292628881], 
             UndirectedEdge[103, 178] -> 
             RGBColor[
              0.1823641236245055, 0.3090066348555799, 0.933696739105647], 
             UndirectedEdge[48, 154] -> 
             RGBColor[
              0.2711822856025334, 0.4002221046769836, 0.9388330865127945], 
             UndirectedEdge[72, 181] -> 
             RGBColor[
              0.345687120645864, 0.46870305597394574`, 0.9434358908416056], 
             UndirectedEdge[45, 132] -> 
             RGBColor[
              0.5058042387487333, 0.6037176098642293, 0.9561309549136163], 
             UndirectedEdge[103, 200] -> 
             RGBColor[
              0.18584727421565939`, 0.3126676469713855, 0.9338950993789537], 
             UndirectedEdge[21, 61] -> 
             RGBColor[
              0.2843221054652073, 0.4113116211381439, 0.9396810187426589], 
             UndirectedEdge[51, 73] -> 
             RGBColor[
              0.19983789794558066`, 0.3273726795683112, 0.9346918447030995], 
             UndirectedEdge[18, 41] -> 
             RGBColor[
              0.25688700518109014`, 0.38733490839514545`, 0.9379407069635708],
              UndirectedEdge[27, 42] -> 
             RGBColor[
              0.2346453394457319, 0.36395750750422684`, 0.936674077003538], 
             UndirectedEdge[90, 165] -> 
             RGBColor[
              0.21653690052978303`, 0.3449243900622238, 0.9356428281963094], 
             UndirectedEdge[50, 135] -> 
             RGBColor[
              0.20034146801813224`, 0.3279019636427496, 0.9347205222737662], 
             UndirectedEdge[93, 121] -> 
             RGBColor[
              0.22436989011875363`, 0.3531573587604565, 0.9360889053655316], 
             UndirectedEdge[23, 175] -> 
             RGBColor[
              0.36210448140880436`, 0.4789065526071719, 0.9449365792097879], 
             UndirectedEdge[57, 164] -> 
             RGBColor[
              0.1885063938143962, 0.3154625502675782, 0.9340465323062868], 
             UndirectedEdge[54, 172] -> 
             RGBColor[
              0.9288667542587956, 0.7360484350731749, 0.311047781867342], 
             UndirectedEdge[99, 198] -> 
             RGBColor[
              0.44872208919176476`, 0.5604076738789969, 0.9505521468225746], 
             UndirectedEdge[45, 112] -> 
             RGBColor[
              0.8262269535061243, 0.8650081965468237, 0.9779469895534628], 
             UndirectedEdge[88, 173] -> 
             RGBColor[
              0.2921580234490212, 0.41895136314427833`, 0.9401490963128714], 
             UndirectedEdge[14, 22] -> 
             RGBColor[
              0.18387332754707644`, 0.31059290386725735`, 0.9337826860363703],
              UndirectedEdge[7, 67] -> 
             RGBColor[
              0.23219222063367448`, 0.36137912409603845`, 0.9365343755162554],
              UndirectedEdge[105, 135] -> 
             RGBColor[
              0.20134641002226938`, 0.32895822140610087`, 0.9347777522342233],
              UndirectedEdge[104, 176] -> 
             RGBColor[
              0.300594019570315, 0.4278785034268868, 0.9406273032429688], 
             UndirectedEdge[57, 91] -> 
             RGBColor[
              0.18403700151578473`, 0.31076493558589874`, 0.9337920070267542],
              UndirectedEdge[34, 185] -> 
             RGBColor[
              0.3310536945005693, 0.45407275524127744`, 0.9425750645902526], 
             UndirectedEdge[65, 172] -> 
             RGBColor[
              0.9128396568383367, 0.6819852721325363, 0.24878553485224705`], 
             UndirectedEdge[66, 120] -> 
             RGBColor[
              0.18874212911118976`, 0.3157103230109893, 0.9340599570827], 
             UndirectedEdge[91, 117] -> 
             RGBColor[
              0.1857785761820701, 0.31259544098237624`, 0.9338911871275704], 
             UndirectedEdge[27, 141] -> 
             RGBColor[
              0.30516819016116037`, 0.4348390437291191, 0.9408089710476214], 
             UndirectedEdge[13, 145] -> 
             RGBColor[
              0.20564959648275716`, 0.3334811432138535, 0.9350228123371542], 
             UndirectedEdge[1, 174] -> 
             RGBColor[
              0.1849745541189024, 0.31175036281604385`, 0.9338453992605169], 
             UndirectedEdge[182, 196] -> 
             RGBColor[
              0.28690951633149697`, 0.41592381842644754`, 0.9397590682480286],
              UndirectedEdge[96, 137] -> 
             RGBColor[
              0.630154419316935, 0.7035305563325196, 0.9671868226387048], 
             UndirectedEdge[89, 157] -> 
             RGBColor[
              0.23696986749514018`, 0.36640073386774574`, 0.9368064554371207],
              UndirectedEdge[119, 191] -> 
             RGBColor[
              0.8284647281297735, 0.6062540401066088, 0.5870905124717782], 
             UndirectedEdge[51, 157] -> 
             RGBColor[
              0.19431074366027534`, 0.32156328997263306`, 0.9343770814432435],
              UndirectedEdge[127, 195] -> 
             RGBColor[
              0.6879096375591269, 0.7543975082866485, 0.9708907042928315], 
             UndirectedEdge[27, 62] -> 
             RGBColor[
              0.23321094483198931`, 0.3624498678193121, 0.9365923903522819], 
             UndirectedEdge[4, 40] -> 
             RGBColor[
              0.42006888605358417`, 0.5368384587156347, 0.9483813569191326], 
             UndirectedEdge[161, 164] -> 
             RGBColor[
              0.23950057479482478`, 0.3690606676958246, 0.9369505754739917], 
             UndirectedEdge[20, 101] -> 
             RGBColor[
              0.18925893509711914`, 0.3162535188695931, 0.9340893884190526], 
             UndirectedEdge[13, 36] -> 
             RGBColor[
              0.20182875625464586`, 0.3294651978788461, 0.9348052211385899], 
             UndirectedEdge[182, 195] -> 
             RGBColor[
              0.42093237513181697`, 0.5377166564648852, 0.9484003790182465], 
             UndirectedEdge[184, 186] -> 
             RGBColor[
              0.18243843400162507`, 0.3090847397734826, 0.9337009709716915], 
             UndirectedEdge[96, 166] -> 
             RGBColor[
              0.8700729048613844, 0.8993494121193195, 0.9867932099380505], 
             UndirectedEdge[38, 43] -> 
             RGBColor[
              0.1854358891920559, 0.31223525522826123`, 0.9338716716104489], 
             UndirectedEdge[30, 176] -> 
             RGBColor[
              0.22182699852969923`, 0.3504846184717214, 0.9359440914514059], 
             UndirectedEdge[171, 174] -> 
             RGBColor[
              0.24889168370669917`, 0.37893131859289997`, 0.9374853852336225],
              UndirectedEdge[100, 125] -> 
             RGBColor[
              0.23503699113385892`, 0.36436915826059957`, 0.9366963809877801],
              UndirectedEdge[17, 188] -> 
             RGBColor[
              0.25233578672597107`, 0.38213926955209265`, 0.937696607864392], 
             UndirectedEdge[87, 107] -> 
             RGBColor[
              0.21716799810205883`, 0.34558771362458285`, 0.9356787682694253],
              UndirectedEdge[62, 184] -> 
             RGBColor[
              0.19085514348532573`, 0.3179312350910555, 0.9341802901253824], 
             UndirectedEdge[12, 33] -> 
             RGBColor[
              0.9713628299392978, 0.9155481063306994, 0.5253098577893779], 
             UndirectedEdge[32, 57] -> 
             RGBColor[
              0.1839232484123208, 0.31064537386179486`, 0.9337855289557946], 
             UndirectedEdge[17, 87] -> 
             RGBColor[
              0.2040861170766778, 0.33183782722774424`, 0.9349337744979385], 
             UndirectedEdge[42, 149] -> 
             RGBColor[
              0.1941370173040445, 0.32138069255734725`, 0.9343671879842612], 
             UndirectedEdge[87, 130] -> 
             RGBColor[
              0.20049917291084113`, 0.3280677214840543, 0.9347295033341025], 
             UndirectedEdge[58, 170] -> 
             RGBColor[
              0.8078923228953876, 0.8503457214275595, 0.9589431237256691], 
             UndirectedEdge[118, 196] -> 
             RGBColor[
              0.3119267863848373, 0.4375925203420974, 0.941353146573924], 
             UndirectedEdge[41, 159] -> 
             RGBColor[
              0.27279920204986197`, 0.40405963619577695`, 0.9388468830352616],
              UndirectedEdge[107, 157] -> 
             RGBColor[
              0.2120289568241801, 0.34018625540749603`, 0.9353861074711805], 
             UndirectedEdge[161, 173] -> 
             RGBColor[
              0.32579061120905595`, 0.4543013453093021, 0.9420644224308505], 
             UndirectedEdge[15, 184] -> 
             RGBColor[
              0.18036794199566558`, 0.3069085213984438, 0.9335830595149706], 
             UndirectedEdge[106, 142] -> 
             RGBColor[
              0.22351397693716918`, 0.3522577397385811, 0.9360401623760504], 
             UndirectedEdge[24, 39] -> 
             RGBColor[
              0.25460473932666533`, 0.38493610227813213`, 0.9378107352994711],
              UndirectedEdge[45, 134] -> 
             RGBColor[
              0.478958077481094, 0.5755005922270049, 0.9546021057447607], 
             UndirectedEdge[5, 73] -> 
             RGBColor[
              0.2859066569179567, 0.41362147278674055`, 0.939747662416915], 
             UndirectedEdge[147, 154] -> 
             RGBColor[
              0.2906977642675366, 0.42073411010671546`, 0.939944464152203], 
             UndirectedEdge[76, 143] -> 
             RGBColor[
              0.5599555580797754, 0.6414092268045206, 0.9622274966891435], 
             UndirectedEdge[5, 197] -> 
             RGBColor[
              0.27751999813753725`, 0.4048065626636409, 0.93927005460632], 
             UndirectedEdge[152, 159] -> 
             RGBColor[
              0.22753887579901738`, 0.3564881636357107, 0.9362693744119284], 
             UndirectedEdge[108, 115] -> 
             RGBColor[
              0.3115259900053915, 0.4441833842869002, 0.9410735735175593], 
             UndirectedEdge[65, 123] -> 
             RGBColor[
              0.7037314806376549, 0.7147724455085309, 0.6174251209785002], 
             UndirectedEdge[8, 67] -> 
             RGBColor[
              0.26957716191751396`, 0.4006730677275356, 0.9386633926163057], 
             UndirectedEdge[9, 41] -> 
             RGBColor[
              0.24200989921647753`, 0.37169812676333913`, 0.9370934777875921],
              UndirectedEdge[111, 165] -> 
             RGBColor[
              0.21296967150778956`, 0.3411750061847254, 0.9354396797807493], 
             UndirectedEdge[146, 195] -> 
             RGBColor[
              0.37321783418719845`, 0.490532301380389, 0.9455744828100211], 
             UndirectedEdge[104, 188] -> 
             RGBColor[
              0.34015129368141406`, 0.46904368691088416`, 0.9428951175427689],
              UndirectedEdge[37, 105] -> 
             RGBColor[
              0.22080146805015013`, 0.3494067209153274, 0.9358856890077321], 
             UndirectedEdge[3, 75] -> 
             RGBColor[
              0.4604176361342196, 0.5718866537552251, 0.9509246758011038], 
             UndirectedEdge[40, 132] -> 
             RGBColor[
              0.40319785832980803`, 0.5214692788871429, 0.94733404339442], 
             UndirectedEdge[154, 157] -> 
             RGBColor[
              0.2691478842423667, 0.3980838198589522, 0.9387172303649602], 
             UndirectedEdge[116, 148] -> 
             RGBColor[
              0.21710235245946194`, 0.3455187158920394, 0.9356750298471934], 
             UndirectedEdge[132, 185] -> 
             RGBColor[
              0.26630785953473646`, 0.397236823637493, 0.9384772106821059], 
             UndirectedEdge[92, 123] -> 
             RGBColor[
              0.34778570453147756`, 0.4697113495975751, 0.9435992466398737], 
             UndirectedEdge[53, 139] -> 
             RGBColor[
              0.4587256509461706, 0.5647673777664313, 0.9518675910388628], 
             UndirectedEdge[40, 196] -> 
             RGBColor[
              0.3694081793861806, 0.4859541839280068, 0.9454097711659308], 
             UndirectedEdge[27, 73] -> 
             RGBColor[
              0.2419998599538071, 0.37168757486174653`, 0.9370929060664348], 
             UndirectedEdge[57, 103] -> 
             RGBColor[
              0.1814602470714449, 0.3080566032892297, 0.9336452646731157], 
             UndirectedEdge[44, 77] -> 
             RGBColor[
              0.8580464518144618, 0.3836823814909788, 0.2007324013601752], 
             UndirectedEdge[88, 91] -> 
             RGBColor[
              0.20139859473617852`, 0.32901307084912135`, 0.93478072407648], 
             UndirectedEdge[69, 146] -> 
             RGBColor[
              0.24760893000865222`, 0.37758306312497075`, 0.9374123343081827],
              UndirectedEdge[65, 199] -> 
             RGBColor[
              0.9757996397934585, 0.9283450401492326, 0.5065449231630825], 
             UndirectedEdge[27, 75] -> 
             RGBColor[
              0.3843313935505691, 0.5020805374205839, 0.9462194736309155], 
             UndirectedEdge[4, 65] -> 
             RGBColor[
              0.6453230600166431, 0.6641820072591899, 0.6137033880650677], 
             UndirectedEdge[58, 102] -> 
             RGBColor[
              0.9648761622564584, 0.9733252798376484, 0.9443396749224908], 
             UndirectedEdge[107, 168] -> 
             RGBColor[
              0.21351519211843195`, 0.34174838293451504`, 0.9354707463724999],
              UndirectedEdge[9, 85] -> 
             RGBColor[
              0.23189273144463124`, 0.36106434196964265`, 0.9365173200499939],
              UndirectedEdge[22, 144] -> 
             RGBColor[
              0.19348904144218293`, 0.3206996288424882, 0.9343302867175226], 
             UndirectedEdge[110, 138] -> 
             RGBColor[
              0.20099999291646117`, 0.32859411506378333`, 0.9347580242925257],
              UndirectedEdge[34, 132] -> 
             RGBColor[
              0.3653113300133066, 0.4900797022247081, 0.9445259862530728], 
             UndirectedEdge[48, 158] -> 
             RGBColor[
              0.2634190473924112, 0.39349797793107355`, 0.9383384198388076], 
             UndirectedEdge[19, 95] -> 
             RGBColor[
              0.3002072480543151, 0.4289405280402324, 0.9405515065144217], 
             UndirectedEdge[122, 137] -> 
             RGBColor[
              0.3009080664928653, 0.4322034485232962, 0.9404989162882755], 
             UndirectedEdge[8, 198] -> 
             RGBColor[
              0.31444384785817775`, 0.4444212242772747, 0.9413433252524308], 
             UndirectedEdge[92, 174] -> 
             RGBColor[
              0.2172400978636229, 0.3456634950453756, 0.9356828742441843], 
             UndirectedEdge[39, 133] -> 
             RGBColor[
              0.2505927164379196, 0.38071921184511703`, 0.9375822565312131], 
             UndirectedEdge[120, 198] -> 
             RGBColor[
              0.26978078120628096`, 0.39747750942414833`, 0.9387998296796913],
              UndirectedEdge[4, 34] -> 
             RGBColor[
              0.38218235773708276`, 0.5054488820532, 0.9455732997777855], 
             UndirectedEdge[31, 34] -> 
             RGBColor[
              0.48100947040442327`, 0.5889125969543878, 0.9524604831380885], 
             UndirectedEdge[41, 152] -> 
             RGBColor[
              0.2454459622028375, 0.3753096468209797, 0.9372891564914656], 
             UndirectedEdge[95, 121] -> 
             RGBColor[
              0.23327542567236176`, 0.36251764127086494`, 0.9365960624407503],
              UndirectedEdge[3, 129] -> 
             RGBColor[
              0.4365819525225805, 0.5525357720139865, 0.9490482434742096], 
             UndirectedEdge[49, 199] -> 
             RGBColor[
              0.7088075949120052, 0.7662760755555905, 0.8381694307308162], 
             UndirectedEdge[171, 182] -> 
             RGBColor[
              0.3242915422574164, 0.45521469783192636`, 0.9418879193227581], 
             UndirectedEdge[56, 150] -> 
             RGBColor[
              0.18756580923325702`, 0.31447393623629405`, 0.933992967405861], 
             UndirectedEdge[179, 183] -> 
             RGBColor[
              0.6524621901365182, 0.6395620041190959, 0.6061877007325749], 
             UndirectedEdge[31, 156] -> 
             RGBColor[
              0.6753397250677327, 0.3878936918486643, 0.560927249104864], 
             UndirectedEdge[132, 153] -> 
             RGBColor[
              0.29141110867079584`, 0.42362193011741534`, 0.9399068035834754],
              UndirectedEdge[78, 136] -> 
             RGBColor[
              0.2028717449192551, 0.3305614450946512, 0.9348646178000759], 
             UndirectedEdge[27, 167] -> 
             RGBColor[
              0.2329271456668488, 0.36215157690284305`, 0.9365762284096705], 
             UndirectedEdge[35, 174] -> 
             RGBColor[
              0.18540537254043327`, 0.31220318029253835`, 0.9338699337322844],
              UndirectedEdge[61, 190] -> 
             RGBColor[
              0.1957633885191688, 0.3230901118223337, 0.9344598074189618], 
             UndirectedEdge[18, 103] -> 
             RGBColor[
              0.20207429376045272`, 0.32972327336542606`, 0.9348192041363055],
              UndirectedEdge[146, 155] -> 
             RGBColor[
              0.4592969410332923, 0.5599429054907851, 0.9526738544811711], 
             UndirectedEdge[77, 166] -> 
             RGBColor[
              0.8105241760173298, 0.490362872734788, 0.5726449442995682], 
             UndirectedEdge[85, 159] -> 
             RGBColor[
              0.26268203427801573`, 0.3934258514020805, 0.9382707252976634], 
             UndirectedEdge[39, 88] -> 
             RGBColor[
              0.2343125277851679, 0.36360770134749604`, 0.9366551238718196], 
             UndirectedEdge[66, 80] -> 
             RGBColor[
              0.20266968703316796`, 0.3303490694451636, 0.9348531109023811], 
             UndirectedEdge[62, 141] -> 
             RGBColor[
              0.2718586483084913, 0.3998286032950302, 0.9389120419161632], 
             UndirectedEdge[91, 103] -> 
             RGBColor[
              0.18365762005674702`, 0.31036618161827634`, 0.9337704018139066],
              UndirectedEdge[149, 189] -> 
             RGBColor[
              0.18996767873421347`, 0.31699845336912136`, 0.934129750320693], 
             UndirectedEdge[4, 69] -> 
             RGBColor[
              0.2920607984493962, 0.42194145527329896`, 0.9400303359095292], 
             UndirectedEdge[23, 169] -> 
             RGBColor[
              0.20786534559532402`, 0.33581003601776915`, 0.9351489959712078],
              UndirectedEdge[32, 152] -> 
             RGBColor[
              0.19309625212307593`, 0.3202867823638255, 0.9343079179468792], 
             UndirectedEdge[100, 124] -> 
             RGBColor[
              0.21591407787580016`, 0.3442697639636507, 0.9356073593675487], 
             UndirectedEdge[129, 139] -> 
             RGBColor[
              0.3700695186748425, 0.49279233567532266`, 0.9448882555483507], 
             UndirectedEdge[29, 73] -> 
             RGBColor[
              0.21219498840003925`, 0.3403607651207339, 0.9353955627238038], 
             UndirectedEdge[32, 178] -> 
             RGBColor[
              0.1848271249653814, 0.311595405428145, 0.9338370033883259], 
             UndirectedEdge[8, 61] -> 
             RGBColor[
              0.24530237000143487`, 0.37515872231303415`, 0.9372809791280214],
              UndirectedEdge[10, 27] -> 
             RGBColor[
              0.24223545662361712`, 0.37193520189940843`, 0.9371063229482464],
              UndirectedEdge[72, 160] -> 
             RGBColor[
              0.3481960203596565, 0.4708761388050667, 0.9435957557128356], 
             UndirectedEdge[72, 144] -> 
             RGBColor[
              0.22584498306262032`, 0.3547077749707548, 0.9361729097264804], 
             UndirectedEdge[134, 135] -> 
             RGBColor[
              0.22190471606791506`, 0.3505663045319628, 0.9359485173502345], 
             UndirectedEdge[95, 150] -> 
             RGBColor[
              0.2208799451115121, 0.3494892052825519, 0.9358901581602801], 
             UndirectedEdge[68, 71] -> 
             RGBColor[
              0.6623649639352431, 0.6847752584173, 0.6236785616506062], 
             UndirectedEdge[118, 123] -> 
             RGBColor[
              0.42099591367325284`, 0.5390672333790665, 0.9480464652405584], 
             UndirectedEdge[89, 168] -> 
             RGBColor[
              0.23845610278939203`, 0.36796286139476475`, 0.9368910943384403],
              UndirectedEdge[44, 99] -> 
             RGBColor[
              0.7252973005063621, 0.6401348451070372, 0.5975536479428364], 
             UndirectedEdge[121, 180] -> 
             RGBColor[
              0.27969294333585376`, 0.40822779625327543`, 0.9393521573829899],
              UndirectedEdge[10, 141] -> 
             RGBColor[
              0.28088316010011916`, 0.40931393737512656`, 0.9394259745121276],
              UndirectedEdge[6, 170] -> 
             RGBColor[
              0.7433204991907267, 0.48659316349091797`, 0.5720011378191884], 
             UndirectedEdge[12, 77] -> 
             RGBColor[
              0.883710558650916, 0.4870027765625733, 0.22146359810422783`], 
             UndirectedEdge[112, 143] -> 
             RGBColor[
              0.8985367952768839, 0.9217855718880776, 0.9850776323188054], 
             UndirectedEdge[67, 125] -> 
             RGBColor[
              0.2600866097683471, 0.39069789568300034`, 0.9381229197114243], 
             UndirectedEdge[3, 10] -> 
             RGBColor[
              0.3183216992072676, 0.4417413182340497, 0.9418115251184348], 
             UndirectedEdge[124, 125] -> 
             RGBColor[
              0.24516019716023396`, 0.37500928964265323`, 0.9372728825950409],
              UndirectedEdge[11, 174] -> 
             RGBColor[
              0.1964947207721936, 0.32385878838940574`, 0.9345014557088626], 
             UndirectedEdge[71, 87] -> 
             RGBColor[
              0.29022081155983176`, 0.4172864093031303, 0.9400251842918653], 
             UndirectedEdge[7, 192] -> 
             RGBColor[
              0.3371042587561843, 0.4567989612427451, 0.9431333444727331], 
             UndirectedEdge[56, 148] -> 
             RGBColor[
              0.18807327130146562`, 0.31500731104493473`, 0.9340218666199227],
              UndirectedEdge[30, 71] -> 
             RGBColor[
              0.28665240734323405`, 0.41353579022159115`, 0.939821968950711], 
             UndirectedEdge[35, 86] -> 
             RGBColor[
              0.19143714046786142`, 0.31854295082044043`, 0.9342134339925504],
              UndirectedEdge[68, 127] -> 
             RGBColor[
              0.9178893661581602, 0.8915362183675095, 0.645439120800334], 
             UndirectedEdge[10, 30] -> 
             RGBColor[
              0.2137583126687416, 0.34200391804762365`, 0.9354845917281754], 
             UndirectedEdge[89, 176] -> 
             RGBColor[
              0.25080130431121317`, 0.3809384509251836, 0.937594135302019], 
             UndirectedEdge[71, 76] -> 
             RGBColor[
              0.3139935330397997, 0.4422730468561747, 0.9413790056115596], 
             UndirectedEdge[49, 119] -> 
             RGBColor[
              0.634590175011373, 0.45058684488381917`, 0.5703034220716992], 
             UndirectedEdge[87, 106] -> 
             RGBColor[
              0.20086653877096394`, 0.3284538462953842, 0.9347504242763673], 
             UndirectedEdge[86, 196] -> 
             RGBColor[
              0.2175414257082079, 0.3459802097153233, 0.9357000344191588], 
             UndirectedEdge[53, 123] -> 
             RGBColor[
              0.5414537947364539, 0.6385560470320484, 0.9570608296632714], 
             UndirectedEdge[68, 102] -> 
             RGBColor[
              0.9650834798325474, 0.9283042529937652, 0.6200104049924591], 
             UndirectedEdge[107, 130] -> 
             RGBColor[
              0.20096416380479723`, 0.32855645639572767`, 0.9347559838776209],
              UndirectedEdge[42, 157] -> 
             RGBColor[
              0.2045975584295754, 0.3323753845168943, 0.9349629003263764], 
             UndirectedEdge[96, 99] -> 
             RGBColor[
              0.7441185775359549, 0.79956600300059, 0.9751875122211435], 
             UndirectedEdge[62, 194] -> 
             RGBColor[
              0.2007116762072222, 0.32829107592203804`, 0.9347416050824608], 
             UndirectedEdge[57, 117] -> 
             RGBColor[
              0.18358120319676802`, 0.31028586265332964`, 0.9337660499867794],
              UndirectedEdge[102, 128] -> 
             RGBColor[
              0.700241137930167, 0.7622648425385679, 0.9428826111957023], 
             UndirectedEdge[46, 47] -> 
             RGBColor[
              0.1896200136619846, 0.31663303533497, 0.934109951309154], 
             UndirectedEdge[28, 105] -> 
             RGBColor[
              0.19252363925225727`, 0.3196849299308422, 0.9342753084909909], 
             UndirectedEdge[40, 182] -> 
             RGBColor[
              0.4233315585574587, 0.5396644216518027, 0.9485892515260115], 
             UndirectedEdge[79, 179] -> 
             RGBColor[
              0.2813590504704592, 0.4075281905155883, 0.9395367751459407], 
             UndirectedEdge[36, 63] -> 
             RGBColor[
              0.1871120628164008, 0.3139970199829937, 0.9339671272186787], 
             UndirectedEdge[118, 129] -> 
             RGBColor[
              0.4226691844013287, 0.5404852315434163, 0.9481617341921013], 
             UndirectedEdge[74, 161] -> 
             RGBColor[
              0.31487926883859824`, 0.44485048896802515`, 0.9413691613435261],
              UndirectedEdge[66, 187] -> 
             RGBColor[
              0.19351363784595493`, 0.32072548122235467`, 0.9343316874463302],
              UndirectedEdge[10, 29] -> 
             RGBColor[
              0.2124305850698493, 0.3406083921583959, 0.9354089796056155], 
             UndirectedEdge[30, 147] -> 
             RGBColor[
              0.22954544173879612`, 0.3585971916620468, 0.9363836453737505], 
             UndirectedEdge[109, 116] -> 
             RGBColor[
              0.2290183753781148, 0.3580432114990334, 0.9363536297242345], 
             UndirectedEdge[81, 154] -> 
             RGBColor[
              0.31895036317144065`, 0.45042938287295087`, 0.9415534078638058],
              UndirectedEdge[89, 188] -> 
             RGBColor[
              0.29035857842231216`, 0.42210363440918097`, 0.939861949601819], 
             UndirectedEdge[24, 163] -> 
             RGBColor[
              0.2694549562733895, 0.40054462184727546`, 0.9386564331856598], 
             UndirectedEdge[91, 159] -> 
             RGBColor[
              0.22056324507356437`, 0.3491563334627266, 0.9358721225616348], 
             UndirectedEdge[121, 164] -> 
             RGBColor[
              0.2062630848758868, 0.3341259584124435, 0.9350577495935681], 
             UndirectedEdge[4, 54] -> 
             RGBColor[
              0.661350157437102, 0.7182451701998284, 0.6759656350801627], 
             UndirectedEdge[51, 130] -> 
             RGBColor[
              0.18324595064089247`, 0.3099334909608647, 0.933746957849684], 
             UndirectedEdge[69, 186] -> 
             RGBColor[
              0.21644101520784265`, 0.3448236085093839, 0.9356373676690746], 
             UndirectedEdge[137, 179] -> 
             RGBColor[
              0.3462163270218858, 0.4742969139529616, 0.9432815761041253], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.37725864887478877`, 0.501184212909484, 0.945259565402945], 
             UndirectedEdge[22, 176] -> 
             RGBColor[
              0.2112886129989553, 0.33940810710667507`, 0.9353439459855744], 
             UndirectedEdge[128, 198] -> 
             RGBColor[
              0.38846505457694686`, 0.5108906382783656, 0.9459736276648509], 
             UndirectedEdge[107, 131] -> 
             RGBColor[
              0.19956404883419218`, 0.32708484678920535`, 0.9346762494013294],
              UndirectedEdge[26, 125] -> 
             RGBColor[
              0.2785326649894304, 0.41008586926780977`, 0.9391733952677717], 
             UndirectedEdge[47, 105] -> 
             RGBColor[
              0.2010087745780687, 0.32860334514692235`, 0.934758524395163], 
             UndirectedEdge[23, 60] -> 
             RGBColor[
              0.2023092030396156, 0.32997017791193484`, 0.9348325818722366], 
             UndirectedEdge[43, 111] -> 
             RGBColor[
              0.2049417486516364, 0.33273715026320094`, 0.934982501450339], 
             UndirectedEdge[73, 142] -> 
             RGBColor[
              0.23973855838173452`, 0.36931080353469764`, 0.9369641282872011],
              UndirectedEdge[43, 115] -> 
             RGBColor[
              0.25238630356085545`, 0.3820238241610014, 0.9377056558638687], 
             UndirectedEdge[61, 122] -> 
             RGBColor[
              0.24263213866310665`, 0.37235213987400595`, 0.9371289134035569],
              UndirectedEdge[64, 65] -> 
             RGBColor[
              0.792934775654365, 0.787251260573052, 0.6244310740750881], 
             UndirectedEdge[147, 157] -> 
             RGBColor[
              0.2279748046775151, 0.3569463525264991, 0.9362941999166599], 
             UndirectedEdge[53, 69] -> 
             RGBColor[
              0.4407986220698122, 0.5459249337780987, 0.9508466732650168], 
             UndirectedEdge[27, 188] -> 
             RGBColor[
              0.28986141659567377`, 0.4215810858075036, 0.939833636971277], 
             UndirectedEdge[88, 159] -> 
             RGBColor[
              0.23572746530865607`, 0.3650948903969026, 0.9367357024705698], 
             UndirectedEdge[16, 61] -> 
             RGBColor[
              0.19725809150646825`, 0.3246611394316285, 0.9345449285428737], 
             UndirectedEdge[138, 185] -> 
             RGBColor[
              0.22696192070522694`, 0.35588174725107113`, 0.9362365176728656],
              UndirectedEdge[26, 128] -> 
             RGBColor[
              0.36204442385736635`, 0.48653045531343586`, 0.9443441705850733],
              UndirectedEdge[68, 75] -> 
             RGBColor[
              0.7315668061877028, 0.7433887217645079, 0.6284543351107399], 
             UndirectedEdge[10, 107] -> 
             RGBColor[
              0.21779170777929543`, 0.3462432720408361, 0.9357142876128481], 
             UndirectedEdge[69, 123] -> 
             RGBColor[
              0.3504692190704081, 0.47253189352264, 0.9437520688229617], 
             UndirectedEdge[109, 113] -> 
             RGBColor[
              0.2109311914464215, 0.33903243439312675`, 0.9353235913569153], 
             UndirectedEdge[49, 196] -> 
             RGBColor[
              0.3276703084677861, 0.4512287678779199, 0.9423563098795996], 
             UndirectedEdge[8, 26] -> 
             RGBColor[
              0.28802321713859724`, 0.420061041312345, 0.9397138681726531], 
             UndirectedEdge[30, 73] -> 
             RGBColor[
              0.21352271599893158`, 0.34175629100996163`, 0.9354711748463638],
              UndirectedEdge[46, 144] -> 
             RGBColor[
              0.19073384687984102`, 0.31780374466804207`, 0.9341733824631423],
              UndirectedEdge[81, 176] -> 
             RGBColor[
              0.2700588403974922, 0.4011793423501723, 0.938690823493161], 
             UndirectedEdge[104, 181] -> 
             RGBColor[
              0.4026365855967863, 0.5231653061658909, 0.9468766250900423], 
             UndirectedEdge[65, 171] -> 
             RGBColor[
              0.6320443792751589, 0.6525886118770408, 0.6128606533865955], 
             UndirectedEdge[67, 82] -> 
             RGBColor[
              0.2339276106645956, 0.3632031290486195, 0.9366332034112368], 
             UndirectedEdge[13, 63] -> 
             RGBColor[
              0.20638929458382937`, 0.3342586128176488, 0.935064937049725], 
             UndirectedEdge[153, 182] -> 
             RGBColor[
              0.3115448088984465, 0.4418170728820753, 0.941162011715067], 
             UndirectedEdge[87, 157] -> 
             RGBColor[
              0.21156396593022397`, 0.3396975204958227, 0.9353596269276621], 
             UndirectedEdge[30, 157] -> 
             RGBColor[
              0.20799556171362626`, 0.3359469014142835, 0.9351564115865076], 
             UndirectedEdge[64, 185] -> 
             RGBColor[
              0.4307906028962345, 0.5356752567798472, 0.9502522102168389], 
             UndirectedEdge[9, 103] -> 
             RGBColor[
              0.18719718779584008`, 0.3140864917336198, 0.9339719749603267], 
             UndirectedEdge[18, 117] -> 
             RGBColor[
              0.2041952498857758, 0.331952532729526, 0.9349399894499691], 
             UndirectedEdge[52, 66] -> 
             RGBColor[
              0.18456752137294713`, 0.3113225455926782, 0.9338222193477858], 
             UndirectedEdge[128, 162] -> 
             RGBColor[
              0.4413593088202362, 0.5567049827613839, 0.9493440027726809], 
             UndirectedEdge[23, 177] -> 
             RGBColor[
              0.22051380406985302`, 0.3491043678330853, 0.9358693069696149], 
             UndirectedEdge[11, 110] -> 
             RGBColor[
              0.1915413157937571, 0.3186524456930539, 0.9342193666232466], 
             UndirectedEdge[79, 177] -> 
             RGBColor[
              0.20578387384021699`, 0.33362227723022, 0.9350304592340161], 
             UndirectedEdge[8, 166] -> 
             RGBColor[
              0.543496783375643, 0.6308288867491243, 0.9602573693120857], 
             UndirectedEdge[162, 173] -> 
             RGBColor[
              0.40958261070654, 0.5291816039985865, 0.947319219667907], 
             UndirectedEdge[100, 137] -> 
             RGBColor[
              0.26484162639759284`, 0.3942953332387867, 0.9384449858803665], 
             UndirectedEdge[88, 117] -> 
             RGBColor[
              0.2009427964171618, 0.32853399791655225`, 0.9347547670365053], 
             UndirectedEdge[149, 168] -> 
             RGBColor[
              0.19745061882106624`, 0.32486349784620777`, 0.9345558926886215],
              UndirectedEdge[36, 110] -> 
             RGBColor[
              0.18133894646584242`, 0.3079291086618389, 0.9336383567830746], 
             UndirectedEdge[76, 104] -> 
             RGBColor[
              0.3156743455120887, 0.4437288821395802, 0.9414861054960099], 
             UndirectedEdge[4, 196] -> 
             RGBColor[
              0.28364684382762245`, 0.41309785549027966`, 0.9395511736411497],
              UndirectedEdge[61, 79] -> 
             RGBColor[
              0.20075917656457537`, 0.3283410018093128, 0.9347443101575417], 
             UndirectedEdge[76, 147] -> 
             RGBColor[
              0.2568865674353618, 0.38733444829663033`, 0.9379406820345992], 
             UndirectedEdge[2, 120] -> 
             RGBColor[
              0.18815579892545653`, 0.3150940528103027, 0.9340265664460203], 
             UndirectedEdge[87, 176] -> 
             RGBColor[
              0.22539540274629694`, 0.3542352375532605, 0.9361473067925603], 
             UndirectedEdge[142, 157] -> 
             RGBColor[
              0.2342114040964292, 0.3635014139390195, 0.9366493650273451], 
             UndirectedEdge[65, 191] -> 
             RGBColor[
              0.8832210777752071, 0.8579801148696197, 0.6332956147035969], 
             UndirectedEdge[73, 147] -> 
             RGBColor[
              0.23350195896282042`, 0.3627557421221772, 0.936608963176516], 
             UndirectedEdge[26, 120] -> 
             RGBColor[
              0.2433601504867005, 0.3731173264592187, 0.9371703725999135], 
             UndirectedEdge[113, 116] -> 
             RGBColor[
              0.22254054731904888`, 0.35123460349093416`, 0.9359847269993585],
              UndirectedEdge[35, 94] -> 
             RGBColor[
              0.1855941681935362, 0.31240161649428533`, 0.9338806853654305], 
             UndirectedEdge[31, 45] -> 
             RGBColor[0.62150237913985, 0.702550504593909, 0.964065451798632],
              UndirectedEdge[52, 82] -> 
             RGBColor[
              0.1987769890735687, 0.32625759707831903`, 0.9346314275123124], 
             UndirectedEdge[95, 162] -> 
             RGBColor[
              0.35030491508878375`, 0.4723326092435304, 0.9437436855582304], 
             UndirectedEdge[17, 73] -> 
             RGBColor[
              0.20447423008410437`, 0.33224575860633554`, 0.9349558769595496],
              UndirectedEdge[103, 152] -> 
             RGBColor[
              0.19063325078220003`, 0.31769801179126034`, 0.9341676536642003],
              UndirectedEdge[88, 103] -> 
             RGBColor[
              0.1988218402918387, 0.32630473855245234`, 0.9346339817228415], 
             UndirectedEdge[26, 170] -> 
             RGBColor[
              0.4739950942722979, 0.5778178834110607, 0.9531267757340784], 
             UndirectedEdge[89, 106] -> 
             RGBColor[
              0.22627244033588012`, 0.3551570596673073, 0.9361972527858261], 
             UndirectedEdge[19, 74] -> 
             RGBColor[
              0.34857360130161363`, 0.4763386664540116, 0.9434317795367738], 
             UndirectedEdge[117, 152] -> 
             RGBColor[
              0.19275420690752315`, 0.3199272711553603, 0.934288438977864], 
             UndirectedEdge[157, 176] -> 
             RGBColor[
              0.2202563614684182, 0.34883377933617365`, 0.9358546459943153], 
             UndirectedEdge[49, 139] -> 
             RGBColor[
              0.3540112919659183, 0.4789148116492719, 0.9438563899218253], 
             UndirectedEdge[48, 106] -> 
             RGBColor[
              0.1977618988532519, 0.32519067289632886`, 0.9345736196259569], 
             UndirectedEdge[69, 118] -> 
             RGBColor[
              0.32034074100661103`, 0.44643612012511674`, 0.9418323088423037],
              UndirectedEdge[117, 200] -> 
             RGBColor[
              0.1879682303409825, 0.3148969063354854, 0.9340158846926173], 
             UndirectedEdge[64, 153] -> 
             RGBColor[
              0.4558938520322939, 0.5620603632597695, 0.9516818031182084], 
             UndirectedEdge[73, 87] -> 
             RGBColor[
              0.2170911202155293, 0.3455069100915008, 0.9356743901875181], 
             UndirectedEdge[132, 138] -> 
             RGBColor[
              0.2612195562179643, 0.3918886942345018, 0.9381874393356859], 
             UndirectedEdge[6, 96] -> 
             RGBColor[
              0.8839247435427675, 0.5973568467623975, 0.5851240708837279], 
             UndirectedEdge[34, 65] -> 
             RGBColor[
              0.6931978672586998, 0.7056487590344823, 0.6167539284485017], 
             UndirectedEdge[2, 16] -> 
             RGBColor[
              0.1847745870823867, 0.3115401847820234, 0.9338340114336121], 
             UndirectedEdge[21, 122] -> 
             RGBColor[
              0.3196137188420707, 0.44840534441475405`, 0.941690823915208], 
             UndirectedEdge[90, 175] -> 
             RGBColor[
              0.36392094666961883`, 0.4808157727668374, 0.9450400242191717], 
             UndirectedEdge[6, 179] -> 
             RGBColor[
              0.5999866512477183, 0.3681232043828395, 0.5612188243491484], 
             UndirectedEdge[8, 137] -> 
             RGBColor[
              0.3035782978311935, 0.4350100309623244, 0.94065098201274], 
             UndirectedEdge[3, 127] -> 
             RGBColor[
              0.6467401961046771, 0.7200341503582268, 0.9679094614906981], 
             UndirectedEdge[31, 65] -> 
             RGBColor[
              0.7441501726839835, 0.7476457221603776, 0.6205905714253708], 
             UndirectedEdge[3, 71] -> 
             RGBColor[
              0.3912157938817601, 0.5132731904080172, 0.9461489023409704], 
             UndirectedEdge[146, 184] -> 
             RGBColor[
              0.21360634880243462`, 0.34184419438906943`, 0.9354759376107997],
              UndirectedEdge[33, 99] -> 
             RGBColor[
              0.772222119980282, 0.8191247933841846, 0.8648855062678112], 
             UndirectedEdge[10, 130] -> 
             RGBColor[
              0.2011228825880777, 0.32872327990030753`, 0.9347650226775253], 
             UndirectedEdge[112, 160] -> 
             RGBColor[
              0.6923008271636373, 0.757058105759987, 0.9667604504602199], 
             UndirectedEdge[73, 157] -> 
             RGBColor[
              0.21195207893765056`, 0.34010545187441393`, 0.9353817293892732],
              UndirectedEdge[157, 188] -> 
             RGBColor[
              0.25981363557951725`, 0.389998962820171, 0.9381224602941154], 
             UndirectedEdge[70, 132] -> 
             RGBColor[
              0.2458080236877891, 0.37569019639768786`, 0.9373097753574117], 
             UndirectedEdge[141, 191] -> 
             RGBColor[
              0.5769597398249082, 0.6618980623518022, 0.9624179176414562], 
             UndirectedEdge[26, 80] -> 
             RGBColor[
              0.25728770840867865`, 0.387756072893393, 0.9379635264195947], 
             UndirectedEdge[171, 199] -> 
             RGBColor[
              0.6515054495303574, 0.7165517677858011, 0.834521559813894], 
             UndirectedEdge[23, 43] -> 
             RGBColor[
              0.2066925124128154, 0.33457731398103385`, 0.9350822048565153], 
             UndirectedEdge[75, 81] -> 
             RGBColor[
              0.40408609146348656`, 0.52284397744725, 0.9473444744525996], 
             UndirectedEdge[33, 172] -> 
             RGBColor[
              0.9309821433575884, 0.7454031597804265, 0.49229878616950506`], 
             UndirectedEdge[156, 166] -> 
             RGBColor[
              0.8112235131702088, 0.49573828454331076`, 0.5733146303469535], 
             UndirectedEdge[151, 175] -> 
             RGBColor[
              0.7472372281358932, 0.7985860801048122, 0.8522647687143463], 
             UndirectedEdge[34, 199] -> 
             RGBColor[
              0.7126589375138983, 0.7696119149432428, 0.8384148348758003], 
             UndirectedEdge[38, 169] -> 
             RGBColor[
              0.18660872237456455`, 0.31346797726499653`, 0.9339384627251416],
              UndirectedEdge[10, 142] -> 
             RGBColor[
              0.23997415505154454`, 0.3695584305723596, 0.9369775451690128], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.2876001150236012, 0.4192043144804547, 0.9397048591920434], 
             UndirectedEdge[12, 128] -> 
             RGBColor[
              0.6907043727279983, 0.6939382045780004, 0.6137063255291655], 
             UndirectedEdge[19, 172] -> 
             RGBColor[
              0.610278699777892, 0.48910830355495916`, 0.5781436227882895], 
             UndirectedEdge[109, 124] -> 
             RGBColor[
              0.22172315170383133`, 0.35037546887346516`, 0.9359381775283004],
              UndirectedEdge[75, 127] -> 
             RGBColor[
              0.6884648603869374, 0.7548482631907685, 0.9709344134676849], 
             UndirectedEdge[4, 191] -> 
             RGBColor[
              0.57220556825359, 0.6577802378883374, 0.9621149860328806], 
             UndirectedEdge[68, 172] -> 
             RGBColor[
              0.9151660280486694, 0.6898326684829248, 0.25782304770604947`], 
             UndirectedEdge[97, 105] -> 
             RGBColor[
              0.21127795983773054`, 0.3393969099587784, 0.9353433393038026], 
             UndirectedEdge[120, 136] -> 
             RGBColor[
              0.208375147270767, 0.3363458699019528, 0.9351780284224404], 
             UndirectedEdge[117, 159] -> 
             RGBColor[
              0.22010744675454766`, 0.3486772605301575, 0.9358461655216599], 
             UndirectedEdge[183, 192] -> 
             RGBColor[
              0.7010491462692232, 0.6813089979740284, 0.609376618188938], 
             UndirectedEdge[71, 188] -> 
             RGBColor[
              0.33847048120912504`, 0.4675878516274786, 0.9427880176583188], 
             UndirectedEdge[14, 106] -> 
             RGBColor[
              0.1821436488572793, 0.3087749018963175, 0.9336841833938165], 
             UndirectedEdge[141, 194] -> 
             RGBColor[
              0.2726689215363932, 0.40068025183184497`, 0.9389581857778003], 
             UndirectedEdge[50, 105] -> 
             RGBColor[
              0.2047516184167667, 0.33253731133139974`, 0.9349716738147356], 
             UndirectedEdge[98, 125] -> 
             RGBColor[
              0.22839213728314284`, 0.35738499555542924`, 0.936317966391162], 
             UndirectedEdge[118, 119] -> 
             RGBColor[
              0.6188466529284243, 0.4369505973479967, 0.5693002587660235], 
             UndirectedEdge[137, 166] -> 
             RGBColor[
              0.5638108664902101, 0.6507798896827761, 0.9614655012997908], 
             UndirectedEdge[6, 112] -> 
             RGBColor[
              0.8864219769798407, 0.5992192793709223, 0.5808969060575552], 
             UndirectedEdge[65, 119] -> 
             RGBColor[
              0.9015822198928265, 0.6126558094774612, 0.23867891450396542`], 
             UndirectedEdge[170, 183] -> 
             RGBColor[
              0.7957960380795266, 0.7580319632271744, 0.6169700142026149], 
             UndirectedEdge[14, 131] -> 
             RGBColor[
              0.18037616802655143`, 0.3069171674784653, 0.9335835279752602], 
             UndirectedEdge[9, 164] -> 
             RGBColor[
              0.1942433345387914, 0.32149243871196825`, 0.9343732425934977], 
             UndirectedEdge[96, 170] -> 
             RGBColor[
              0.7958122133360686, 0.8413363954975833, 0.9793915982124253], 
             UndirectedEdge[117, 178] -> 
             RGBColor[
              0.18448507974982858`, 0.3112358942196798, 0.9338175244193107], 
             UndirectedEdge[18, 24] -> 
             RGBColor[
              0.24010747998138166`, 0.3696985635269072, 0.9369851378265305], 
             UndirectedEdge[18, 133] -> 
             RGBColor[
              0.2360954570926359, 0.3654816730938921, 0.9367566590582723], 
             UndirectedEdge[49, 129] -> 
             RGBColor[
              0.4384127064842775, 0.5541214790792388, 0.9491648974977769], 
             UndirectedEdge[124, 198] -> 
             RGBColor[
              0.28583038245095216`, 0.4143466579357906, 0.9397138307273181], 
             UndirectedEdge[113, 124] -> 
             RGBColor[
              0.2152453236447654, 0.343566860865366, 0.9355692748034243], 
             UndirectedEdge[176, 188] -> 
             RGBColor[
              0.2736450723955902, 0.4045366798776089, 0.9389101401590136], 
             UndirectedEdge[37, 97] -> 
             RGBColor[
              0.22632286746697683`, 0.35521006177935477`, 0.9362001245363418],
              UndirectedEdge[77, 143] -> 
             RGBColor[
              0.8364908329957561, 0.5109365998950215, 0.5751565315064958], 
             UndirectedEdge[79, 84] -> 
             RGBColor[
              0.1877064038111327, 0.31462171005185247`, 0.93400097405908], 
             UndirectedEdge[151, 199] -> 
             RGBColor[
              0.9945819459025071, 0.992027509640117, 0.7394547080773856], 
             UndirectedEdge[48, 87] -> 
             RGBColor[
              0.21359836729039067`, 0.3418358053138541, 0.9354754830754963], 
             UndirectedEdge[27, 30] -> 
             RGBColor[
              0.2380433427297828, 0.3675290244016161, 0.9368675882636692], 
             UndirectedEdge[5, 87] -> 
             RGBColor[
              0.28551854391053016`, 0.41321354140814925`, 0.9397255599553038],
              UndirectedEdge[68, 81] -> 
             RGBColor[
              0.6335105972347094, 0.659531932623991, 0.6218491817852485], 
             UndirectedEdge[155, 172] -> 
             RGBColor[
              0.77126540629573, 0.6221045625124598, 0.590374002869697], 
             UndirectedEdge[143, 188] -> 
             RGBColor[
              0.5844325062491007, 0.6667240315758246, 0.9636365087359027], 
             UndirectedEdge[102, 180] -> 
             RGBColor[
              0.6556042618622065, 0.7236026240031248, 0.9400383889234916], 
             UndirectedEdge[80, 136] -> 
             RGBColor[
              0.2223027051927452, 0.3509846163361272, 0.9359711822421215], 
             UndirectedEdge[66, 78] -> 
             RGBColor[
              0.18323872675967784`, 0.30992589820368766`, 0.9337465464603355],
              UndirectedEdge[50, 101] -> 
             RGBColor[
              0.19997052243961871`, 0.3275120763204238, 0.9346993974718347], 
             UndirectedEdge[41, 85] -> 
             RGBColor[
              0.2805891206818358, 0.4122473345873495, 0.9392905073772007], 
             UndirectedEdge[5, 30] -> 
             RGBColor[
              0.28195013969393246`, 0.40946292232661013`, 0.9395223446141496],
              UndirectedEdge[32, 133] -> 
             RGBColor[
              0.21756503028546625`, 0.3460050196226384, 0.9357013786649139], 
             UndirectedEdge[159, 161] -> 
             RGBColor[
              0.2693600530686908, 0.4004448725619264, 0.938651028588549], 
             UndirectedEdge[3, 195] -> 
             RGBColor[
              0.4598624133064091, 0.5714358988511051, 0.9508809666262504], 
             UndirectedEdge[173, 180] -> 
             RGBColor[
              0.35489305397250803`, 0.4818122587326137, 0.9438344494728906], 
             UndirectedEdge[129, 141] -> 
             RGBColor[
              0.399143413415432, 0.5201083911550634, 0.9466626928679024], 
             UndirectedEdge[53, 199] -> 
             RGBColor[
              0.8135219538922576, 0.8521286416727499, 0.8461806318478537], 
             UndirectedEdge[88, 95] -> 
             RGBColor[
              0.23288032783126497`, 0.3621023683892223, 0.9365735622031948], 
             UndirectedEdge[93, 95] -> 
             RGBColor[
              0.24029230513765162`, 0.36989282648473865`, 0.9369956633457557],
              UndirectedEdge[3, 29] -> 
             RGBColor[
              0.312801857714541, 0.4359396148470296, 0.9414971783112978], 
             UndirectedEdge[52, 125] -> 
             RGBColor[
              0.2249359881773202, 0.35375236371269986`, 0.9361211438124999], 
             UndirectedEdge[82, 136] -> 
             RGBColor[
              0.21738866266974544`, 0.34581964607616317`, 0.935691334790111], 
             UndirectedEdge[116, 193] -> 
             RGBColor[
              0.2350445249483884, 0.36437707677734155`, 0.9366968100273723], 
             UndirectedEdge[19, 159] -> 
             RGBColor[
              0.30305438553170616`, 0.43193305004791277`, 0.9407136467817967],
              UndirectedEdge[77, 99] -> 
             RGBColor[
              0.6845698486919003, 0.3905794636160585, 0.5610392465826612], 
             UndirectedEdge[53, 196] -> 
             RGBColor[
              0.43238466744803844`, 0.5370813339950793, 0.9503675109966372], 
             UndirectedEdge[58, 137] -> 
             RGBColor[
              0.6422345288762541, 0.7125398822624958, 0.9467383481519487], 
             UndirectedEdge[159, 200] -> 
             RGBColor[
              0.22275289923247676`, 0.35145779881583583`, 0.9359968201266817],
              UndirectedEdge[3, 62] -> 
             RGBColor[
              0.30929718741563983`, 0.43225598415395333`, 0.9412975925224704],
              UndirectedEdge[48, 157] -> 
             RGBColor[
              0.20845932601251194`, 0.33643434709676723`, 0.9351828222772515],
              UndirectedEdge[130, 168] -> 
             RGBColor[
              0.19684636692721422`, 0.32422839079398647`, 0.9345214814371772],
              UndirectedEdge[140, 180] -> 
             RGBColor[
              0.6678780579649132, 0.7298281943728316, 0.7506032971167013], 
             UndirectedEdge[146, 171] -> 
             RGBColor[
              0.27657700131279794`, 0.4080303427474302, 0.9390620231145327], 
             UndirectedEdge[26, 100] -> 
             RGBColor[
              0.24928654570499661`, 0.3793463435888073, 0.9375078720402794], 
             UndirectedEdge[45, 153] -> 
             RGBColor[
              0.49664985237205533`, 0.594095769360721, 0.9556096261521655], 
             UndirectedEdge[165, 177] -> 
             RGBColor[
              0.2115965510366421, 0.3397317695086831, 0.9353614826012671], 
             UndirectedEdge[123, 139] -> 
             RGBColor[
              0.36839624794676656`, 0.4913743375109727, 0.9447729865968078], 
             UndirectedEdge[13, 34] -> 
             RGBColor[
              0.32558157650060693`, 0.44832121227099686`, 0.9422634355654279],
              UndirectedEdge[48, 72] -> 
             RGBColor[
              0.23184751916348642`, 0.3610168209955353, 0.9365147452774683], 
             UndirectedEdge[127, 191] -> 
             RGBColor[
              0.8424455031847746, 0.8772870526462687, 0.9848132059143445], 
             UndirectedEdge[58, 125] -> 
             RGBColor[
              0.6124298936125201, 0.6826137072843086, 0.9449897432593624], 
             UndirectedEdge[165, 169] -> 
             RGBColor[
              0.1989480925621131, 0.32643743769336697`, 0.9346411716028602], 
             UndirectedEdge[119, 156] -> 
             RGBColor[
              0.8327717722765755, 0.2529037791657479, 0.17901559218345872`], 
             UndirectedEdge[139, 191] -> 
             RGBColor[
              0.5478858450843187, 0.6345820068720615, 0.9606434803219044], 
             UndirectedEdge[48, 81] -> 
             RGBColor[
              0.2582618049415859, 0.3887799101107659, 0.938018999776097], 
             UndirectedEdge[85, 161] -> 
             RGBColor[
              0.2771499717006646, 0.408632570953499, 0.939094652930488], 
             UndirectedEdge[30, 106] -> 
             RGBColor[
              0.19729813455436623`, 0.32470322721384515`, 0.9345472089352131],
              UndirectedEdge[118, 195] -> 
             RGBColor[
              0.44594964518515734`, 0.559385358380535, 0.9499944573441421], 
             UndirectedEdge[132, 145] -> 
             RGBColor[
              0.24537934999545682`, 0.37523963316756476`, 0.9372853630247993],
              UndirectedEdge[124, 137] -> 
             RGBColor[
              0.27496483242396785`, 0.4049354646208403, 0.9390214874876273], 
             UndirectedEdge[53, 182] -> 
             RGBColor[
              0.48630804661931654`, 0.5907915717188752, 0.9535469913567178], 
             UndirectedEdge[31, 40] -> 
             RGBColor[
              0.5188959987209247, 0.6203021736168226, 0.9552685402794356], 
             UndirectedEdge[130, 157] -> 
             RGBColor[
              0.19536013163296237`, 0.32266626326696746`, 0.9344368425358576],
              UndirectedEdge[83, 166] -> 
             RGBColor[
              0.8650576677002866, 0.8953688994003288, 0.9869563023793746], 
             UndirectedEdge[76, 176] -> 
             RGBColor[
              0.24916812422626491`, 0.3792218751063049, 0.9375011281122546], 
             UndirectedEdge[100, 113] -> 
             RGBColor[
              0.20512211761839033`, 0.33292672948331237`, 0.9349927731961636],
              UndirectedEdge[53, 118] -> 
             RGBColor[
              0.5113253166726569, 0.612460273634525, 0.9551410696826135], 
             UndirectedEdge[18, 85] -> 
             RGBColor[
              0.24676983740924385`, 0.376701123601449, 0.9373645492259726], 
             UndirectedEdge[90, 177] -> 
             RGBColor[
              0.22233026933066752`, 0.35101358799275084`, 0.9359727519789987],
              UndirectedEdge[55, 165] -> 
             RGBColor[
              0.2708407078314586, 0.3994925742335291, 0.9388272003702323], 
             UndirectedEdge[9, 121] -> 
             RGBColor[
              0.20533326031636837`, 0.3331486538461075, 0.9350047974604558], 
             UndirectedEdge[70, 110] -> 
             RGBColor[
              0.185588460386286, 0.31239561722696946`, 0.9338803603142515], 
             UndirectedEdge[51, 147] -> 
             RGBColor[
              0.2158606236854452, 0.3442135802203963, 0.9356043152304863], 
             UndirectedEdge[81, 188] -> 
             RGBColor[
              0.3096161145085913, 0.44234452583416967`, 0.9409586377929611], 
             UndirectedEdge[63, 132] -> 
             RGBColor[
              0.24611904809652904`, 0.37601710277136, 0.9373274877373701], 
             UndirectedEdge[68, 143] -> 
             RGBColor[
              0.9083269889752188, 0.8839114383656459, 0.6445270527281901], 
             UndirectedEdge[76, 81] -> 
             RGBColor[
              0.28513916633926595`, 0.41702972106286573`, 0.9395496257462019],
              UndirectedEdge[55, 163] -> 
             RGBColor[
              0.3088204539598367, 0.4394116954694417, 0.9409900907262441], 
             UndirectedEdge[86, 94] -> 
             RGBColor[
              0.19625374198187168`, 0.3236055044018397, 0.9344877323232499], 
             UndirectedEdge[3, 167] -> 
             RGBColor[
              0.3090133882504993, 0.4319576932374843, 0.9412814305798589], 
             UndirectedEdge[16, 82] -> 
             RGBColor[
              0.19957038496874147`, 0.32709150646835083`, 0.9346766102348185],
              UndirectedEdge[51, 107] -> 
             RGBColor[
              0.1999147758321102, 0.3274534831013933, 0.9346962227850067], 
             UndirectedEdge[53, 171] -> 
             RGBColor[
              0.4697666933739579, 0.5763722134005581, 0.9524963620713668], 
             UndirectedEdge[78, 82] -> 
             RGBColor[
              0.1974481944602994, 0.3248609496893285, 0.9345557546248622], 
             UndirectedEdge[92, 186] -> 
             RGBColor[
              0.21375750066891208`, 0.34200306458431906`, 0.9354845454859864],
              UndirectedEdge[75, 118] -> 
             RGBColor[
              0.44650486801296785`, 0.559836113284655, 0.9500381665189955], 
             UndirectedEdge[77, 83] -> 
             RGBColor[
              0.8718524916829569, 0.5391330266655409, 0.5785293580798063], 
             UndirectedEdge[42, 176] -> 
             RGBColor[
              0.21842899524564835`, 0.34691310157433214`, 0.9357505801912747],
              UndirectedEdge[20, 144] -> 
             RGBColor[
              0.19040607844928842`, 0.31745923926581243`, 0.9341547165359123],
              UndirectedEdge[26, 98] -> 
             RGBColor[
              0.24264169185428053`, 0.372362180883637, 0.9371294574436615], 
             UndirectedEdge[16, 84] -> 
             RGBColor[
              0.1842053187530256, 0.3109418476741682, 0.933801592444412], 
             UndirectedEdge[55, 175] -> 
             RGBColor[
              0.4182247539712943, 0.5353839569381427, 0.9482243963930945], 
             UndirectedEdge[113, 128] -> 
             RGBColor[
              0.3178799957707601, 0.44011084120794086`, 0.9418290717409573], 
             UndirectedEdge[142, 147] -> 
             RGBColor[
              0.25576128412159904`, 0.3861517041867828, 0.9378765988145878], 
             UndirectedEdge[10, 42] -> 
             RGBColor[
              0.2103603093846907, 0.3384324011502344, 0.9352910804680441], 
             UndirectedEdge[98, 120] -> 
             RGBColor[
              0.19321962278041294`, 0.32041645274683817`, 0.9343149437233039],
              UndirectedEdge[195, 199] -> 
             RGBColor[
              0.748146282404758, 0.7990537264187598, 0.8410340195093824], 
             UndirectedEdge[49, 195] -> 
             RGBColor[
              0.46169316726810605`, 0.5730216059163575, 0.9509976206498176], 
             UndirectedEdge[25, 43] -> 
             RGBColor[
              0.1846430806166806, 0.3114019631485748, 0.9338265223349365], 
             UndirectedEdge[91, 121] -> 
             RGBColor[
              0.2017936925772753, 0.329428343730764, 0.9348032243140356], 
             UndirectedEdge[8, 21] -> 
             RGBColor[
              0.3222839501803989, 0.4512119268537823, 0.9418428896396724], 
             UndirectedEdge[2, 124] -> 
             RGBColor[
              0.20420540017012767`, 0.331963201321945, 0.9349405674936471], 
             UndirectedEdge[80, 125] -> 
             RGBColor[
              0.243038153837541, 0.3727788875651853, 0.9371520353670952], 
             UndirectedEdge[33, 180] -> 
             RGBColor[
              0.6673282092975037, 0.7309455392481101, 0.857462764837877], 
             UndirectedEdge[5, 155] -> 
             RGBColor[
              0.513762074533002, 0.612974284551854, 0.9559298924776924], 
             UndirectedEdge[179, 192] -> 
             RGBColor[
              0.41712722923071616`, 0.5353797878648794, 0.9478929556641686], 
             UndirectedEdge[59, 146] -> 
             RGBColor[
              0.21481341413912597`, 0.34311289659029465`, 0.935544678196031], 
             UndirectedEdge[3, 68] -> 
             RGBColor[
              0.6898421419054424, 0.7085746089319662, 0.625429383133753], 
             UndirectedEdge[131, 157] -> 
             RGBColor[
              0.19396001666235732`, 0.3211946536604452, 0.9343571080595661], 
             UndirectedEdge[85, 200] -> 
             RGBColor[
              0.23054281786445055`, 0.35964549720740835`, 0.9364404444686207],
              UndirectedEdge[23, 38] -> 
             RGBColor[
              0.20238106508142, 0.3300457094741879, 0.9348366743092069], 
             UndirectedEdge[92, 191] -> 
             RGBColor[
              0.5272753016690297, 0.6129190189586639, 0.9594697403649703], 
             UndirectedEdge[97, 153] -> 
             RGBColor[
              0.24952804077433757`, 0.37960017021835646`, 0.9375216248272185],
              UndirectedEdge[95, 161] -> 
             RGBColor[
              0.26651291559129975`, 0.397452350554246, 0.9384888883211739], 
             UndirectedEdge[139, 196] -> 
             RGBColor[
              0.25932712065835106`, 0.3898996244740037, 0.9380796679301735], 
             UndirectedEdge[1, 94] -> 
             RGBColor[
              0.18516334977200538`, 0.3119487990177908, 0.933856150893663], 
             UndirectedEdge[189, 194] -> 
             RGBColor[
              0.19797673225113377`, 0.32541647641872684`, 0.9345858540701487],
              UndirectedEdge[42, 76] -> 
             RGBColor[
              0.23350932118742207`, 0.36276348028702554`, 0.9366093824443157],
              UndirectedEdge[84, 190] -> 
             RGBColor[
              0.18271061576572617`, 0.30937082006487343`, 0.9337164713205002],
              UndirectedEdge[37, 134] -> 
             RGBColor[
              0.24135977409579584`, 0.37101480404118925`, 0.9370564541237432],
              UndirectedEdge[140, 161] -> 
             RGBColor[
              0.6387756152014612, 0.7023172809495201, 0.7488332700746612], 
             UndirectedEdge[10, 51] -> 
             RGBColor[
              0.20007349461539067`, 0.32762030660597313`, 0.9347052615849112],
              UndirectedEdge[146, 191] -> 
             RGBColor[
              0.527753699812846, 0.6134218457400091, 0.9594969844315341], 
             UndirectedEdge[21, 175] -> 
             RGBColor[
              0.43093748007980026`, 0.5463950813331377, 0.9490344400593063], 
             UndirectedEdge[49, 141] -> 
             RGBColor[
              0.3830851867065078, 0.5062308671290127, 0.9456308272413769], 
             UndirectedEdge[111, 177] -> 
             RGBColor[
              0.21876304030867405`, 0.3472642041152524, 0.9357696035634386], 
             UndirectedEdge[69, 191] -> 
             RGBColor[
              0.5299588162079603, 0.6157395628837288, 0.9596225625480584], 
             UndirectedEdge[111, 175] -> 
             RGBColor[
              0.36035371764762536`, 0.477066388889339, 0.9448368758036116], 
             UndirectedEdge[77, 170] -> 
             RGBColor[
              0.736263484492014, 0.4323498561130519, 0.5652433325739429], 
             UndirectedEdge[104, 154] -> 
             RGBColor[
              0.3494855423442635, 0.47712854394966536`, 0.9434898876136137], 
             UndirectedEdge[13, 138] -> 
             RGBColor[
              0.2214898027052646, 0.35013020428079056`, 0.9359248886480409], 
             UndirectedEdge[21, 67] -> 
             RGBColor[
              0.30859689738128643`, 0.43682596655264533`, 0.9410634322309431],
              UndirectedEdge[73, 197] -> 
             RGBColor[
              0.20909257444253643`, 0.33709993134699245`, 0.9352188848385342],
              UndirectedEdge[67, 192] -> 
             RGBColor[
              0.36080214724091136`, 0.4817069445731053, 0.944482904164054], 
             UndirectedEdge[37, 101] -> 
             RGBColor[
              0.21602037207300215`, 0.3443814859043514, 0.9356134126648311], 
             UndirectedEdge[6, 44] -> 
             RGBColor[
              0.8651034665131747, 0.43792568886884486`, 0.20749020660542072`],
              UndirectedEdge[75, 89] -> 
             RGBColor[
              0.3848285553772075, 0.5026030860222612, 0.9462477862614576], 
             UndirectedEdge[76, 188] -> 
             RGBColor[
              0.288725398337364, 0.42038705859030223`, 0.9397689424120548], 
             UndirectedEdge[42, 71] -> 
             RGBColor[
              0.2832544040591832, 0.40996427332420193`, 0.9396284576905798], 
             UndirectedEdge[6, 192] -> 
             RGBColor[
              0.6485736073804235, 0.40987019823777215`, 0.5644077418055113], 
             UndirectedEdge[2, 100] -> 
             RGBColor[
              0.19408219414375266`, 0.32132306993989135`, 0.9343640658863862],
              UndirectedEdge[7, 8] -> 
             RGBColor[
              0.24587927343278695`, 0.3757650843971754, 0.9373138329249848], 
             UndirectedEdge[69, 92] -> 
             RGBColor[
              0.2471305318648358, 0.3770802363436254, 0.937385090241619], 
             UndirectedEdge[104, 160] -> 
             RGBColor[
              0.4051454853105788, 0.5253383889970118, 0.9470364899612722], 
             UndirectedEdge[17, 30] -> 
             RGBColor[
              0.20051771286008008`, 0.3280872081462052, 0.9347305591567843], 
             UndirectedEdge[88, 164] -> 
             RGBColor[
              0.20586798703479003`, 0.3337106855308008, 0.9350352493560126], 
             UndirectedEdge[43, 60] -> 
             RGBColor[
              0.18536402715025152`, 0.3121597236660082, 0.9338675791734785], 
             UndirectedEdge[149, 197] -> 
             RGBColor[
              0.19310487903170026`, 0.3202958497917673, 0.934308409236563], 
             UndirectedEdge[167, 197] -> 
             RGBColor[
              0.20001986015557813`, 0.327563933388089, 0.9347022071817699], 
             UndirectedEdge[54, 127] -> 
             RGBColor[
              0.9315900923682865, 0.9377519849577597, 0.6986638549616266], 
             UndirectedEdge[107, 147] -> 
             RGBColor[
              0.23357883684934996`, 0.36283654565525925`, 0.9366133412584232],
              UndirectedEdge[78, 113] -> 
             RGBColor[
              0.19369232004858233`, 0.320913287546422, 0.9343418631334333], 
             UndirectedEdge[81, 87] -> 
             RGBColor[
              0.261366444859298, 0.3920430835098213, 0.9381958044265076], 
             UndirectedEdge[83, 179] -> 
             RGBColor[
              0.6474631282319623, 0.7188859236705143, 0.9687723771837091], 
             UndirectedEdge[82, 198] -> 
             RGBColor[
              0.2787942966052594, 0.4069512855983587, 0.9393131360473621], 
             UndirectedEdge[30, 107] -> 
             RGBColor[
              0.21359959388546113`, 0.3418370945430438, 0.935475552928271], 
             UndirectedEdge[47, 134] -> 
             RGBColor[
              0.22156708062371444`, 0.3502114282727843, 0.9359292895111742], 
             UndirectedEdge[5, 142] -> 
             RGBColor[
              0.3081659820767354, 0.43701743485134614`, 0.9410152980549868], 
             UndirectedEdge[169, 190] -> 
             RGBColor[
              0.18813962732028144`, 0.31507705542792475`, 0.9340256454970293],
              UndirectedEdge[121, 152] -> 
             RGBColor[
              0.20876932330272832`, 0.33676017390374813`, 0.9352004761643293],
              UndirectedEdge[31, 64] -> 
             RGBColor[
              0.5807463788000884, 0.6705150984929575, 0.9601376287646749], 
             UndirectedEdge[105, 134] -> 
             RGBColor[
              0.22631486646654955`, 0.35520165222061295`, 0.936199668891204], 
             UndirectedEdge[83, 192] -> 
             RGBColor[
              0.6960500843646674, 0.7606329175254469, 0.9719612946400722], 
             UndirectedEdge[77, 112] -> 
             RGBColor[
              0.8793649622811279, 0.5449759719930563, 0.5741391008123097], 
             UndirectedEdge[195, 196] -> 
             RGBColor[
              0.3670089959605389, 0.4840064187410893, 0.9452208986581658], 
             UndirectedEdge[92, 171] -> 
             RGBColor[
              0.2760986031689815, 0.40752751596608494`, 0.939034779047969], 
             UndirectedEdge[166, 183] -> 
             RGBColor[
              0.8700567296048425, 0.8160449798489104, 0.6243716259282402], 
             UndirectedEdge[139, 195] -> 
             RGBColor[
              0.39334997945867106`, 0.5116924625124413, 0.9467209787003914], 
             UndirectedEdge[177, 190] -> 
             RGBColor[
              0.20078808579481044`, 0.3283713872432409, 0.9347459564954362], 
             UndirectedEdge[29, 149] -> 
             RGBColor[
              0.19620729298920309`, 0.32355668356550876`, 0.9344850871218325],
              UndirectedEdge[119, 155] -> 
             RGBColor[
              0.7600079693502197, 0.5527750998573846, 0.5802673825214153], 
             UndirectedEdge[12, 162] -> 
             RGBColor[
              0.7007570533940699, 0.7026453313085301, 0.614346873451971], 
             UndirectedEdge[85, 173] -> 
             RGBColor[
              0.31911259241838086`, 0.4472823241494562, 0.941684119139965], 
             UndirectedEdge[92, 141] -> 
             RGBColor[
              0.29413145548178377`, 0.42323873581169885`, 0.9401804453350167],
              UndirectedEdge[5, 29] -> 
             RGBColor[
              0.28062241209504013`, 0.4080673964373824, 0.9394467324915896], 
             UndirectedEdge[51, 87] -> 
             RGBColor[
              0.19944978493815407`, 0.3269647481897199, 0.9346697422414884], 
             UndirectedEdge[145, 153] -> 
             RGBColor[
              0.2362249636187789, 0.3656177926640565, 0.9367640342633485], 
             UndirectedEdge[118, 191] -> 
             RGBColor[
              0.6004855108108049, 0.6822749027401551, 0.9639169589656551], 
             UndirectedEdge[117, 164] -> 
             RGBColor[
              0.19024796848068162`, 0.3172930556640557, 0.9341457124071029], 
             UndirectedEdge[145, 185] -> 
             RGBColor[
              0.2111217144827195, 0.33923268618413416`, 0.935334441361979], 
             UndirectedEdge[99, 137] -> 
             RGBColor[
              0.4378565391647805, 0.5509964805640466, 0.9498598035828838], 
             UndirectedEdge[48, 176] -> 
             RGBColor[
              0.2222907628285849, 0.3509720641542051, 0.9359705021421497], 
             UndirectedEdge[50, 144] -> 
             RGBColor[
              0.20111766579178803`, 0.32871779671664314`, 0.9347647255886942],
              UndirectedEdge[3, 53] -> 
             RGBColor[
              0.5252380847939087, 0.6245108141050952, 0.9560275789647218], 
             UndirectedEdge[169, 177] -> 
             RGBColor[
              0.20474146136299756`, 0.33252663562389395`, 0.9349710953855495],
              UndirectedEdge[20, 135] -> 
             RGBColor[
              0.18962988067563263`, 0.3166434061919189, 0.9341105132209843], 
             UndirectedEdge[166, 170] -> 
             RGBColor[
              0.7294686605093437, 0.78858572884784, 0.973670276873511], 
             UndirectedEdge[17, 42] -> 
             RGBColor[
              0.1971197095760292, 0.3245156912488159, 0.9345370478966529], 
             UndirectedEdge[129, 195] -> 
             RGBColor[
              0.47775139397703026`, 0.5868991299424082, 0.952029486276343], 
             UndirectedEdge[74, 93] -> 
             RGBColor[
              0.28865865838495014`, 0.4172909648985178, 0.9398759363681078], 
             UndirectedEdge[37, 45] -> 
             RGBColor[
              0.47344467906469456`, 0.5697056609217193, 0.9542881258612889], 
             UndirectedEdge[49, 92] -> 
             RGBColor[
              0.33340074855062923`, 0.45725182373587436`, 0.9426826499648912],
              UndirectedEdge[163, 177] -> 
             RGBColor[
              0.24957629716502022`, 0.3796508907445958, 0.937524372957279], 
             UndirectedEdge[6, 45] -> 
             RGBColor[
              0.7712380059237092, 0.5084025319316335, 0.5747836939863987], 
             UndirectedEdge[6, 166] -> 
             RGBColor[
              0.8175811907160426, 0.5446061801126542, 0.5794027495448137], 
             UndirectedEdge[65, 127] -> 
             RGBColor[
              0.9155629949478274, 0.8836888220171212, 0.6364016079465316], 
             UndirectedEdge[15, 59] -> 
             RGBColor[
              0.18157500733235693`, 0.30817722359966904`, 0.9336518001002019],
              UndirectedEdge[100, 136] -> 
             RGBColor[
              0.21430154248906313`, 0.3425748870315415, 0.9355155278628062], 
             UndirectedEdge[83, 183] -> 
             RGBColor[
              0.9313850452704695, 0.8648151337796632, 0.6302560397084783], 
             UndirectedEdge[53, 119] -> 
             RGBColor[
              0.7393045339916254, 0.5364394110009786, 0.5783146231887367], 
             UndirectedEdge[5, 68] -> 
             RGBColor[
              0.6576626962859415, 0.680702390522319, 0.6233789373140448], 
             UndirectedEdge[49, 54] -> 
             RGBColor[
              0.7053736220772657, 0.7563760825874686, 0.6787707713186126], 
             UndirectedEdge[153, 185] -> 
             RGBColor[
              0.2571534731580585, 0.38761498313398474`, 0.937955881920655], 
             UndirectedEdge[101, 144] -> 
             RGBColor[
              0.19734151181877715`, 0.32474881946901846`, 0.9345496792062504],
              UndirectedEdge[19, 102] -> 
             RGBColor[
              0.6601961515617699, 0.7275798880657995, 0.9403309800746991], 
             UndirectedEdge[102, 172] -> 
             RGBColor[
              0.9192581959222914, 0.7380602445354411, 0.5748744102551196], 
             UndirectedEdge[102, 140] -> 
             RGBColor[
              0.981449443808876, 0.9827573994159884, 0.747626675734739], 
             UndirectedEdge[71, 107] -> 
             RGBColor[
              0.2906858024537879, 0.41777514421480366`, 0.9400516648353837], 
             UndirectedEdge[5, 168] -> 
             RGBColor[
              0.2818657379269033, 0.4093742107180814, 0.9395175380583785], 
             UndirectedEdge[79, 122] -> 
             RGBColor[
              0.2360507899414387, 0.3654347250859229, 0.9367541153300909], 
             UndirectedEdge[136, 198] -> 
             RGBColor[
              0.2842178470642151, 0.4126517810036814, 0.9396219992225757], 
             UndirectedEdge[97, 135] -> 
             RGBColor[
              0.20686780943909605`, 0.33476156227012827`, 0.9350921877628332],
              UndirectedEdge[19, 164] -> 
             RGBColor[
              0.2731949072578401, 0.40054884518181094`, 0.9390131936672395], 
             UndirectedEdge[118, 139] -> 
             RGBColor[
              0.33826776988296947`, 0.4652785641134494, 0.9428532266161497], 
             UndirectedEdge[26, 137] -> 
             RGBColor[
              0.3083373002531643, 0.4400120442459969, 0.9409220001603581], 
             UndirectedEdge[142, 168] -> 
             RGBColor[
              0.23569763939068106`, 0.3650635414660385, 0.9367340039286646], 
             UndirectedEdge[3, 194] -> 
             RGBColor[
              0.3101074606435417, 0.43310763269076813`, 0.9413437363841075], 
             UndirectedEdge[65, 195] -> 
             RGBColor[
              0.7286852121495595, 0.7350905705099995, 0.6193731130820839], 
             UndirectedEdge[73, 107] -> 
             RGBColor[
              0.21755611110948542`, 0.34599564500317415`, 0.9357008707310365],
              UndirectedEdge[162, 172] -> 
             RGBColor[
              0.6603763668123606, 0.5325003847582571, 0.5813358018320983], 
             UndirectedEdge[68, 140] -> 
             RGBColor[
              0.977357275935254, 0.934529823363472, 0.4305753131856688], 
             UndirectedEdge[38, 165] -> 
             RGBColor[
              0.19346381204820906`, 0.3206731111497857, 0.9343288499408593], 
             UndirectedEdge[86, 92] -> 
             RGBColor[
              0.22327186579105107`, 0.35200326557327766`, 0.9360263745044504],
              UndirectedEdge[90, 115] -> 
             RGBColor[
              0.27114794471103404`, 0.4017434985665935, 0.9387741035720105], 
             UndirectedEdge[11, 70] -> 
             RGBColor[
              0.19700340773557554`, 0.3243934506405365, 0.9345304246788922], 
             UndirectedEdge[54, 123] -> 
             RGBColor[
              0.7197585780581139, 0.7688356084491694, 0.6796873679935951], 
             UndirectedEdge[107, 176] -> 
             RGBColor[
              0.22586039364025307`, 0.35472397246493387`, 0.9361737873360787],
              UndirectedEdge[30, 76] -> 
             RGBColor[
              0.23690732447147297`, 0.36633499718441476`, 0.936802893704447], 
             UndirectedEdge[129, 191] -> 
             RGBColor[
              0.632287259602678, 0.7097886743020284, 0.965951987897856], 
             UndirectedEdge[7, 125] -> 
             RGBColor[
              0.2363887212836201, 0.36578991235264013`, 0.9367733600201034], 
             UndirectedEdge[3, 155] -> 
             RGBColor[
              0.545941520152503, 0.6408465029615011, 0.9579803382974005], 
             UndirectedEdge[54, 118] -> 
             RGBColor[
              0.6896300999943169, 0.7427398350516461, 0.6777676080129371], 
             UndirectedEdge[4, 171] -> 
             RGBColor[
              0.3210288697535419, 0.4523887348957585, 0.9416800247158792], 
             UndirectedEdge[167, 189] -> 
             RGBColor[
              0.19688265985809134`, 0.32426653696544305`, 0.9345235482659], 
             UndirectedEdge[42, 81] -> 
             RGBColor[
              0.25440003735864936`, 0.3847209475308929, 0.9377990778252221], 
             UndirectedEdge[5, 129] -> 
             RGBColor[
              0.40440250690307966`, 0.5246635536043394, 0.9469977976545015], 
             UndirectedEdge[115, 133] -> 
             RGBColor[
              0.2820742314375166, 0.41322771868271746`, 0.939396339437091], 
             UndirectedEdge[92, 146] -> 
             RGBColor[
              0.24492541546972163`, 0.3747625191999059, 0.9372595121250946], 
             UndirectedEdge[65, 151] -> 
             RGBColor[
              0.9751208756473086, 0.9280643537313567, 0.5177938016500871], 
             UndirectedEdge[45, 156] -> 
             RGBColor[
              0.7648803283778755, 0.4595346363622902, 0.5686955747885385], 
             UndirectedEdge[74, 172] -> 
             RGBColor[
              0.607635645662135, 0.48681902292365303`, 0.5779752097171944], 
             UndirectedEdge[31, 138] -> 
             RGBColor[
              0.3769176966090809, 0.4907215889641815, 0.9461219362207016], 
             UndirectedEdge[116, 198] -> 
             RGBColor[
              0.29312560612523564`, 0.42201440056135886`, 0.9401292829232522],
              UndirectedEdge[42, 142] -> 
             RGBColor[
              0.23238403787365935`, 0.361580736177178, 0.9365452992243044], 
             UndirectedEdge[10, 129] -> 
             RGBColor[
              0.3362106798778888, 0.4572045493253528, 0.9429600447685274], 
             UndirectedEdge[3, 141] -> 
             RGBColor[
              0.38125443274481086`, 0.5046451600637603, 0.9455141732178098], 
             UndirectedEdge[161, 162] -> 
             RGBColor[
              0.3676199899888237, 0.4905318508026293, 0.94472975345843], 
             UndirectedEdge[6, 77] -> 
             RGBColor[
              0.8243760146987129, 0.18837030737786614`, 0.17097580524524553`],
              UndirectedEdge[98, 113] -> 
             RGBColor[
              0.19847726376767427`, 0.32594256677814204`, 0.9346143585995457],
              UndirectedEdge[3, 139] -> 
             RGBColor[
              0.3521805380042213, 0.47732910458401956`, 0.943739735898258], 
             UndirectedEdge[34, 138] -> 
             RGBColor[
              0.32596539118379714`, 0.4487246258382862, 0.9422852932438326], 
             UndirectedEdge[22, 72] -> 
             RGBColor[
              0.22084536933385682`, 0.34945286394800523`, 0.935888189120893], 
             UndirectedEdge[34, 40] -> 
             RGBColor[
              0.4679436932956409, 0.5783052104909272, 0.9514318973025666], 
             UndirectedEdge[41, 74] -> 
             RGBColor[
              0.31831841781976944`, 0.44846525260187575`, 0.9415650157902389],
              UndirectedEdge[141, 146] -> 
             RGBColor[
              0.2946098536256002, 0.4237415625930442, 0.9402076894015805], 
             UndirectedEdge[90, 111] -> 
             RGBColor[
              0.22370338980181498`, 0.3524568246687931, 0.9360509491584807], 
             UndirectedEdge[66, 82] -> 
             RGBColor[
              0.1977556445101682, 0.32518409918519964`, 0.9345732634503707], 
             UndirectedEdge[119, 151] -> 
             RGBColor[
              0.9203645260018751, 0.6763382789683456, 0.4715886994182685], 
             UndirectedEdge[4, 139] -> 
             RGBColor[
              0.30998782732575464`, 0.44078389926163164`, 0.9410512536833753],
              UndirectedEdge[165, 175] -> 
             RGBColor[
              0.35318722837559335`, 0.4695339542827697, 0.9444287548414402], 
             UndirectedEdge[127, 139] -> 
             RGBColor[
              0.5802277622569392, 0.660290714019563, 0.9637494735648391], 
             UndirectedEdge[85, 117] -> 
             RGBColor[
              0.22789736538652144`, 0.3568649589217301, 0.9362897898635989], 
             UndirectedEdge[141, 155] -> 
             RGBColor[
              0.5085029810453545, 0.6084191221025781, 0.9555947876910933], 
             UndirectedEdge[168, 189] -> 
             RGBColor[
              0.2019144551539962, 0.3295552728556873, 0.9348101015641277], 
             UndirectedEdge[24, 175] -> 
             RGBColor[
              0.3788592562848471, 0.49651688331597643`, 0.9458907388525104], 
             UndirectedEdge[106, 176] -> 
             RGBColor[
              0.20955893430915817`, 0.33759010513573523`, 0.9352454433430207],
              UndirectedEdge[40, 53] -> 
             RGBColor[
              0.5688067096740002, 0.6608219372204345, 0.9591976942746201], 
             UndirectedEdge[27, 155] -> 
             RGBColor[
              0.4698552775688525, 0.57104038662686, 0.953275136127212], 
             UndirectedEdge[33, 77] -> 
             RGBColor[
              0.9049712712883817, 0.5626723297681262, 0.46806425968515003`], 
             UndirectedEdge[67, 137] -> 
             RGBColor[
              0.289891245032081, 0.42062407066118745`, 0.9398715246040107], 
             UndirectedEdge[68, 129] -> 
             RGBColor[
              0.7077311225760636, 0.7240378400232692, 0.6265779027838456], 
             UndirectedEdge[137, 192] -> 
             RGBColor[
              0.3948032831545909, 0.5160439078078941, 0.9464704935604884], 
             UndirectedEdge[58, 128] -> 
             RGBColor[
              0.695941652480456, 0.7590582933299347, 0.9501605185766638], 
             UndirectedEdge[55, 90] -> 
             RGBColor[
              0.281574426125484, 0.41077439271759675`, 0.9394384697479637], 
             UndirectedEdge[26, 82] -> 
             RGBColor[
              0.2523736658856789, 0.382591102633429, 0.9376836789675842], 
             UndirectedEdge[43, 165] -> 
             RGBColor[
              0.19777525937960444`, 0.32520471565663167`, 0.9345743804881674],
              UndirectedEdge[123, 199] -> 
             RGBColor[
              0.7231925508928534, 0.7787356014172913, 0.8390860274057987], 
             UndirectedEdge[34, 45] -> 
             RGBColor[
              0.5705500737145661, 0.6605535414680137, 0.960228808821763], 
             UndirectedEdge[133, 178] -> 
             RGBColor[
              0.21638528695668868`, 0.3447650345840459, 0.9356341940276138], 
             UndirectedEdge[29, 189] -> 
             RGBColor[
              0.20067112932213305`, 0.3282484585749883, 0.9347392959973388], 
             UndirectedEdge[91, 164] -> 
             RGBColor[
              0.19070376679969833`, 0.3177721285966248, 0.9341716694470776], 
             UndirectedEdge[116, 124] -> 
             RGBColor[
              0.2333325075764587, 0.3625776379712726, 0.9365993131707435], 
             UndirectedEdge[80, 113] -> 
             RGBColor[
              0.2131232803220724, 0.34133645878789803`, 0.9354484275754789], 
             UndirectedEdge[10, 75] -> 
             RGBColor[
              0.3600463634895279, 0.4765554310665914, 0.9448364770954216], 
             UndirectedEdge[74, 180] -> 
             RGBColor[
              0.34398171160205027`, 0.4723614023913367, 0.9431391883855662], 
             UndirectedEdge[27, 149] -> 
             RGBColor[
              0.2260121645429709, 0.35488349330652136`, 0.9361824304644635], 
             UndirectedEdge[4, 49] -> 
             RGBColor[
              0.37833101513518963`, 0.5021130426655478, 0.9453278956328015], 
             UndirectedEdge[9, 152] -> 
             RGBColor[
              0.19674957296563292`, 0.32412665420327286`, 0.9345159691642588],
              UndirectedEdge[19, 85] -> 
             RGBColor[
              0.31084430416368, 0.44012074843948534`, 0.9411572711237357], 
             UndirectedEdge[189, 197] -> 
             RGBColor[
              0.19756871536463022`, 0.3249876248012469, 0.9345626181120692], 
             UndirectedEdge[69, 195] -> 
             RGBColor[
              0.3754229505823126, 0.4928500185241086, 0.9457000609265455], 
             UndirectedEdge[75, 191] -> 
             RGBColor[
              0.656122943214317, 0.729139556043267, 0.9678284202247502], 
             UndirectedEdge[73, 75] -> 
             RGBColor[
              0.3598107668197179, 0.47630780402892936`, 0.9448230602136101], 
             UndirectedEdge[68, 188] -> 
             RGBColor[
              0.6370968292328074, 0.6628892701514275, 0.6220684984511013], 
             UndirectedEdge[4, 123] -> 
             RGBColor[
              0.39271597111603795`, 0.5145725685272486, 0.946244492307784], 
             UndirectedEdge[7, 84] -> 
             RGBColor[
              0.19486465596415276`, 0.32214548692407674`, 0.9344086259295095],
              UndirectedEdge[171, 195] -> 
             RGBColor[
              0.4043910218864583, 0.5232972981465681, 0.9473497497328954], 
             UndirectedEdge[62, 167] -> 
             RGBColor[
              0.19961760381417978`, 0.3271411364687542, 0.9346792992782123], 
             UndirectedEdge[91, 152] -> 
             RGBColor[
              0.19321000522653986`, 0.3204063440879294, 0.9343143960178388], 
             UndirectedEdge[38, 90] -> 
             RGBColor[
              0.20419753034223448`, 0.33195492963385337`, 0.9349401193185908],
              UndirectedEdge[3, 118] -> 
             RGBColor[
              0.40478020373070756`, 0.5250220004521133, 0.9470132145420087], 
             UndirectedEdge[143, 181] -> 
             RGBColor[
              0.6469177981644729, 0.7208456508308313, 0.967618016283176], 
             UndirectedEdge[20, 50] -> 
             RGBColor[
              0.19303508907013, 0.32022249611721776`, 0.9343044348014965], 
             UndirectedEdge[128, 136] -> 
             RGBColor[
              0.3270594206414329, 0.44975899875617, 0.9423518264076001], 
             UndirectedEdge[19, 161] -> 
             RGBColor[
              0.3175223229543551, 0.44713976959933127`, 0.9415375744146212], 
             UndirectedEdge[19, 140] -> 
             RGBColor[
              0.6724699476644765, 0.7338054584355065, 0.7508958882679089], 
             UndirectedEdge[39, 159] -> 
             RGBColor[
              0.25347717812255377`, 0.3837509639611013, 0.9377465223569743], 
             UndirectedEdge[87, 154] -> 
             RGBColor[
              0.2742869255202454, 0.40348527807603907`, 0.9390098911632051], 
             UndirectedEdge[104, 143] -> 
             RGBColor[
              0.6113814534238254, 0.6900658551251025, 0.9653536718198579], 
             UndirectedEdge[6, 183] -> 
             RGBColor[
              0.8839085682862255, 0.5140524144919886, 0.22270248687391753`], 
             UndirectedEdge[17, 89] -> 
             RGBColor[
              0.229492018641594, 0.35854104059966735`, 0.9363806030073972], 
             UndirectedEdge[131, 176] -> 
             RGBColor[
              0.20779145347843028`, 0.335732370717883, 0.9351447879244643], 
             UndirectedEdge[44, 143] -> 
             RGBColor[
              0.8772182848102179, 0.7604919813860003, 0.611670932866671], 
             UndirectedEdge[140, 173] -> 
             RGBColor[
              0.6807382359191774, 0.7409670341454773, 0.7514227362841381], 
             UndirectedEdge[123, 195] -> 
             RGBColor[
              0.4760781232489544, 0.5854811317780583, 0.9519142173248001], 
             UndirectedEdge[96, 125] -> 
             RGBColor[
              0.600349784053201, 0.6736043813543324, 0.9654382177461185], 
             UndirectedEdge[95, 159] -> 
             RGBColor[
              0.2520449781686508, 0.3822456310028275, 0.9376649606883494], 
             UndirectedEdge[171, 191] -> 
             RGBColor[
              0.558926887512106, 0.6461868425061883, 0.9612722513544084], 
             UndirectedEdge[124, 187] -> 
             RGBColor[
              0.21475919139226923`, 0.3430559050454275, 0.935541590290813], 
             UndirectedEdge[54, 191] -> 
             RGBColor[
              0.899248175195666, 0.9120432778102582, 0.6955578617186919], 
             UndirectedEdge[24, 55] -> 
             RGBColor[
              0.29651273574071235`, 0.4264755032667358, 0.9402891843813024], 
             UndirectedEdge[61, 126] -> 
             RGBColor[
              0.19350305800530745`, 0.3207143611390335, 0.9343310849400568], 
             UndirectedEdge[46, 101] -> 
             RGBColor[
              0.18958670352767176`, 0.3165980242718227, 0.9341080543462827], 
             UndirectedEdge[158, 176] -> 
             RGBColor[
              0.27521608284831744`, 0.40589741017048, 0.9390102435558715], 
             UndirectedEdge[91, 200] -> 
             RGBColor[
              0.18842402865999922`, 0.3153759792680545, 0.9340418417325922], 
             UndirectedEdge[29, 129] -> 
             RGBColor[
              0.33069083838516217`, 0.4514028459383327, 0.9426456979613903], 
             UndirectedEdge[37, 47] -> 
             RGBColor[
              0.21605368220731502`, 0.34441649696749876`, 0.9356153096277022],
              UndirectedEdge[25, 38] -> 
             RGBColor[
              0.18033163328528526`, 0.30687035864172885`, 0.9335809917876283],
              UndirectedEdge[95, 173] -> 
             RGBColor[
              0.308475536309016, 0.4361021037502032, 0.9410783545306509], 
             UndirectedEdge[86, 174] -> 
             RGBColor[
              0.19606494632876875`, 0.3234070682000927, 0.9344769806901039], 
             UndirectedEdge[4, 146] -> 
             RGBColor[
              0.289855682054282, 0.41962373812957937`, 0.9399047577930049], 
             UndirectedEdge[114, 186] -> 
             RGBColor[
              0.18224157379578187`, 0.3088778272154834, 0.9336897600741974], 
             UndirectedEdge[155, 199] -> 
             RGBColor[
              0.8342253892508518, 0.868464330529156, 0.8481333911805324], 
             UndirectedEdge[114, 194] -> 
             RGBColor[
              0.19146855650738448`, 0.3185759710698711, 0.9342152230895253], 
             UndirectedEdge[59, 186] -> 
             RGBColor[
              0.18364549933831636`, 0.3103534419747078, 0.9337697115569229], 
             UndirectedEdge[99, 193] -> 
             RGBColor[
              0.3906410080149175, 0.5027703500949796, 0.9471196739266945], 
             UndirectedEdge[109, 136] -> 
             RGBColor[
              0.22011061631709428`, 0.3486805919413559, 0.935846346023558], 
             UndirectedEdge[50, 134] -> 
             RGBColor[
              0.22530992446241244`, 0.3541453944572617, 0.9361424389307468], 
             UndirectedEdge[112, 183] -> 
             RGBColor[
              0.9388975158686406, 0.8706580791071786, 0.6258657824409817], 
             UndirectedEdge[42, 73] -> 
             RGBColor[
              0.2101247127148807, 0.3381847741125724, 0.9352776635862325], 
             UndirectedEdge[42, 147] -> 
             RGBColor[
              0.22614743845474522`, 0.3550256747646575, 0.9361901341136192], 
             UndirectedEdge[87, 131] -> 
             RGBColor[
              0.19909905794023608`, 0.326596111877532, 0.934649768857811], 
             UndirectedEdge[1, 11] -> 
             RGBColor[
              0.19143609648975546`, 0.318541853533259, 0.9342133745395418], 
             UndirectedEdge[30, 81] -> 
             RGBColor[
              0.2577980406427003, 0.3882924644282822, 0.9379925890853533], 
             UndirectedEdge[154, 188] -> 
             RGBColor[
              0.3225365951695387, 0.45378672040038737`, 0.9417727245296585], 
             UndirectedEdge[83, 156] -> 
             RGBColor[
              0.8725518288358358, 0.5445084384740636, 0.5791990441271917], 
             UndirectedEdge[5, 107] -> 
             RGBColor[
              0.28598353480448624`, 0.4137022763198226, 0.9397520404988222], 
             UndirectedEdge[93, 180] -> 
             RGBColor[
              0.28670982280114365`, 0.41560298146714914`, 0.9397517582879953],
              UndirectedEdge[10, 17] -> 
             RGBColor[
              0.2047098267539144, 0.3324933856439975, 0.9349692938413614], 
             UndirectedEdge[75, 141] -> 
             RGBColor[
              0.42297909702707115`, 0.5394592728963019, 0.9485391251947967], 
             UndirectedEdge[123, 141] -> 
             RGBColor[
              0.39747014268735614`, 0.5186903929907134, 0.9465474239163595], 
             UndirectedEdge[40, 119] -> 
             RGBColor[
              0.6763280459297676, 0.4853122609339061, 0.5733568833580303], 
             UndirectedEdge[16, 80] -> 
             RGBColor[
              0.20448442749174123`, 0.3322564767283148, 0.934956457686829], 
             UndirectedEdge[88, 180] -> 
             RGBColor[
              0.279297845494757, 0.4078125233716327, 0.9393296571454344], 
             UndirectedEdge[24, 41] -> 
             RGBColor[
              0.2739267632539736, 0.4052447745128077, 0.9389110959777585], 
             UndirectedEdge[4, 119] -> 
             RGBColor[
              0.5905667103712094, 0.4124559324961789, 0.5674982858332491], 
             UndirectedEdge[99, 136] -> 
             RGBColor[
              0.3873164552562508, 0.49927603435680146`, 0.9469303455653235], 
             UndirectedEdge[10, 194] -> 
             RGBColor[
              0.20973618799885002`, 0.33777641000213443`, 0.9352555376784253],
              UndirectedEdge[96, 102] -> 
             RGBColor[
              0.9527960526971394, 0.9643159539076722, 0.964788149409247], 
             UndirectedEdge[9, 88] -> 
             RGBColor[
              0.20493816247527158`, 0.3327333809644648, 0.9349822972229003], 
             UndirectedEdge[55, 108] -> 
             RGBColor[
              0.3219524714198415, 0.4532142784379034, 0.9417379396935124], 
             UndirectedEdge[62, 197] -> 
             RGBColor[
              0.20030365932071864`, 0.327862224304558, 0.9347183691243814], 
             UndirectedEdge[147, 168] -> 
             RGBColor[
              0.22946103997176695`, 0.35850848005351804`, 0.9363788388179795],
              UndirectedEdge[51, 106] -> 
             RGBColor[
              0.1836133165010153, 0.31031961577219463`, 0.9337678787919488], 
             UndirectedEdge[123, 155] -> 
             RGBColor[
              0.5621572300950483, 0.6548917358884543, 0.9590135889959501], 
             UndirectedEdge[75, 142] -> 
             RGBColor[
              0.3820700919784965, 0.49970376609353495`, 0.9460906958516819], 
             UndirectedEdge[31, 182] -> 
             RGBColor[
              0.43639733566624106`, 0.5502718081152633, 0.9496178373615334], 
             UndirectedEdge[65, 140] -> 
             RGBColor[
              0.9750309047249213, 0.9266824270130837, 0.4215378003318664]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 71 -> 
             RGBColor[
              0.3637386159115608, 0.4894738398933511, 0.9443980808578237], 10 -> 
             RGBColor[
              0.2179504265625759, 0.34641009554541596`, 0.9357233264127526], 
             68 -> RGBColor[
              0.9609913119589255, 0.8800766769412489, 0.30295904244338884`], 
             155 -> RGBColor[
              0.6731900684530466, 0.744620465000319, 0.9680609527706839], 132 -> 
             RGBColor[
              0.30056549504747376`, 0.4332437706209237, 0.9404281323449262], 
             26 -> RGBColor[
              0.2927822195605681, 0.4250630545960175, 0.9399848863202711], 29 -> 
             RGBColor[
              0.20691074357712266`, 0.33480668877137576`, 0.9350946327984784],
              113 -> RGBColor[
              0.20445336338735556`, 0.33222382638502757`, 0.9349546886320393],
              50 -> RGBColor[
              0.20374667641262958`, 0.33148105356804847`, 0.9349144438542785],
              173 -> RGBColor[
              0.36775323192677223`, 0.4929510985052593, 0.9446538886403275], 
             192 -> RGBColor[
              0.46571418536342124`, 0.577126781719812, 0.9510818731205317], 
             165 -> RGBColor[
              0.2058031822357576, 0.33364257157815613`, 0.9350315588185778], 
             92 -> RGBColor[
              0.2444470173259052, 0.37425969241856055`, 0.9372322680585309], 
             11 -> RGBColor[
              0.20295626314304663`, 0.3306502791066209, 0.9348694309878873], 
             137 -> RGBColor[
              0.32389238094576056`, 0.45496103389597625`, 0.9418591140004451],
              120 -> RGBColor[
              0.1939380814128329, 0.3211715983224198, 0.934355858879556], 51 -> 
             RGBColor[
              0.18219656266820544`, 0.3088305176665303, 0.9336871967570698], 
             72 -> RGBColor[
              0.2532013109542942, 0.38346101007627187`, 0.9377308121298508], 
             64 -> RGBColor[
              0.6295309817704698, 0.7101206369056319, 0.9639781314143923], 41 -> 
             RGBColor[
              0.29070628845368207`, 0.422881119381046, 0.9398666651147989], 
             103 -> RGBColor[
              0.1810808656124072, 0.3076578493216073, 0.933623659460268], 162 -> 
             RGBColor[
              0.4514119894863078, 0.5654121094919137, 0.9499845506954865], 
             196 -> RGBColor[
              0.23298613716021888`, 0.3622135807026517, 0.9365795878879478], 
             179 -> RGBColor[
              0.3685402730980111, 0.49363279400994686`, 0.9447040382078057], 
             160 -> RGBColor[
              0.44319072976501883`, 0.5582912675338615, 0.9494606992958204], 
             123 -> RGBColor[
              0.4511243917370499, 0.5651630067765897, 0.9499662252212164], 
             150 -> RGBColor[
              0.19256204953176445`, 0.3197253015699566, 0.9342774958995859], 
             188 -> RGBColor[
              0.31320234650668927`, 0.4457018633616062, 0.9411779544588138], 
             46 -> RGBColor[
              0.18297903858873563`, 0.3096529494708463, 0.9337317576031746], 
             182 -> RGBColor[
              0.34083289550277507`, 0.46963405615024345`, 0.9429385486081092],
              6 -> 
             RGBColor[
              0.8314330293974257, 0.24261361475573226`, 0.17773361049049105`],
              131 -> RGBColor[
              0.1814951086723694, 0.3080932450421545, 0.9336472499897152], 45 -> 
             RGBColor[
              0.7110429824499928, 0.7741914491075349, 0.9718337774823064], 
             195 -> RGBColor[
              0.5010318547608589, 0.6057992567795268, 0.9538622094283838], 
             148 -> RGBColor[
              0.19357697366818166`, 0.320792051187238, 0.9343352943277091], 
             161 -> RGBColor[
              0.2838279904913397, 0.4156515921133449, 0.9394749562213734], 1 -> 
             RGBColor[
              0.17991592983646426`, 0.30643342795989703`, 0.9335573180911961],
              101 -> RGBColor[
              0.19619436846660787`, 0.3235430990727991, 0.9344843510893909], 
             12 -> RGBColor[
              0.950102117301832, 0.8398785531251466, 0.2787091962084557], 39 -> 
             RGBColor[
              0.25206224059906557`, 0.3822637749116947, 0.9376659437582241], 
             48 -> RGBColor[
              0.21049372737267863`, 0.3385726319147987, 0.9352986784250858], 
             77 -> RGBColor[0.817319, 0.134127, 0.164218], 56 -> 
             RGBColor[
              0.1825695689347496, 0.30922257090263144`, 0.9337084389121362], 
             110 -> RGBColor[
              0.18012636844446756`, 0.30665461227948687`, 0.9335693022586058],
              73 -> RGBColor[
              0.21747923322295587`, 0.34591484147009205`, 0.9356964926491292],
              37 -> RGBColor[
              0.23584637567939642`, 0.36521987273590373`, 0.9367424742402714],
              130 -> RGBColor[
              0.1842953386135795, 0.3110364642551991, 0.933806718942298], 107 -> 
             RGBColor[
              0.21763298899601496`, 0.34607644853625624`, 0.9357052488129437],
              59 -> RGBColor[
              0.18422301466471383`, 0.3109604471993381, 0.9338026002004038], 
             47 -> RGBColor[
              0.1962609887352336, 0.32361312119909375`, 0.9344881450151332], 
             159 -> RGBColor[
              0.2548921156460419, 0.3852381530105079, 0.9378271009557244], 55 -> 
             RGBColor[
              0.33587823342715956`, 0.465342576888902, 0.9426228419218866], 
             49 -> RGBColor[
              0.4223544797753533, 0.5402439550531881, 0.9481330318712514], 82 -> 
             RGBColor[
              0.21196511221078973`, 0.3401191506708405, 0.9353824716148974], 
             199 -> RGBColor[
              0.995260710048657, 0.9923081960579929, 0.7282058295903809], 89 -> 
             RGBColor[
              0.2675148103379351, 0.39850540545675567`, 0.9385459447448243], 
             144 -> RGBColor[
              0.19848865517094644`, 0.32595453986523776`, 0.93461500732311], 
             78 -> RGBColor[
              0.18293127670980908`, 0.3096027487078165, 0.9337290376348271], 
             42 -> RGBColor[
              0.2027701922068055, 0.3304547067550528, 0.9348588345233357], 
             154 -> RGBColor[
              0.33187084383238813`, 0.46187157743916857`, 0.9423674946005033],
              168 -> RGBColor[
              0.20939739524084894`, 0.3374203173327738, 0.9352362439320562], 
             121 -> RGBColor[
              0.21735301065346377`, 0.34578217354658275`, 0.9356893044605262],
              128 -> RGBColor[
              0.43130662815416465`, 0.5479978560308542, 0.9487034548498753], 
             115 -> RGBColor[
              0.31502527059825963`, 0.4472807885868956, 0.9412941095699802], 
             61 -> RGBColor[
              0.2073405252862433, 0.3352584165973958, 0.9351191082310077], 93 -> 
             RGBColor[
              0.23138676958404353`, 0.3605325439743302, 0.9364885062705369], 
             88 -> RGBColor[
              0.21656281497127022`, 0.34495162778329735`, 0.9356443039854151],
              21 -> RGBColor[
              0.36130368564417137`, 0.48736482567889206`, 0.94424292925431], 
             62 -> RGBColor[
              0.1999014029793203, 0.32743942738522325`, 0.9346954612208237], 
             136 -> RGBColor[
              0.22281221312870114`, 0.35152014148148586`, 0.9360001979653247],
              190 -> RGBColor[
              0.1841862517520943, 0.3109218070472717, 0.933800506606916], 57 -> 
             RGBColor[
              0.1818396285304826, 0.30845535725685214`, 0.9336668698859633], 
             111 -> RGBColor[
              0.2201361607798215, 0.3487074407912947, 0.9358478007429207], 63 -> 
             RGBColor[
              0.19167260114558432`, 0.31879043492179643`, 0.9342268431298139],
              75 -> RGBColor[
              0.5021423004164799, 0.6067007665877667, 0.9539496277780908], 30 -> 
             RGBColor[
              0.2095661987749073, 0.33759774054983127`, 0.9352458570435983], 
             5 -> RGBColor[
              0.35433408061295757`, 0.481328104103389, 0.9437988321847008], 
             171 -> RGBColor[
              0.30775018901205775`, 0.44079533951360933`, 0.940837290037407], 
             102 -> 
             RGBColor[
              0.9691756477061694, 0.9765318290462814, 0.9370617675415293], 31 -> 
             RGBColor[
              0.531961775829707, 0.6309095600802831, 0.9562971261149575], 96 -> 
             RGBColor[
              0.9364164576881094, 0.9521000787690629, 0.9925145312769647], 70 -> 
             RGBColor[
              0.19105055232810444`, 0.31813662217445204`, 0.9341914183698972],
              52 -> RGBColor[
              0.18558886593634766`, 0.31239604348579764`, 0.9338803834097276],
              183 -> RGBColor[
              0.9363841071750253, 0.7854912142282449, 0.26767136325734403`], 
             158 -> RGBColor[
              0.3163443674121438, 0.4484233239473484, 0.9413781612525294], 13 -> 
             RGBColor[
              0.22110598802207443`, 0.3497267907135012, 0.9359030309696362], 
             170 -> RGBColor[
              0.6552079689840278, 0.7305727122261038, 0.9662686651478858], 86 -> 
             RGBColor[
              0.2020967142561969, 0.3297468387279948, 0.9348204809503698], 18 -> 
             RGBColor[
              0.22306772190849825`, 0.3517886974092449, 0.9360147488123428], 
             153 -> RGBColor[
              0.2822567222941179, 0.41400008961390705`, 0.9393854748220246], 
             58 -> RGBColor[
              0.9605766768067475, 0.9701187306290152, 0.9516175823034524], 22 -> 
             RGBColor[
              0.18848942771341942`, 0.31544471781973865`, 0.9340455661119352],
              66 -> RGBColor[
              0.18354617680954663`, 0.31024904769955874`, 0.9337640552858439],
              143 -> RGBColor[
              0.8556626659915121, 0.887746199790043, 0.9860950630129915], 119 -> 
             RGBColor[
              0.8468258702473929, 0.3609297347144502, 0.19247381227214683`], 
             145 -> RGBColor[
              0.1901932049434399, 0.31723549571420584`, 0.9341425937046723], 
             91 -> RGBColor[
              0.18623437450108682`, 0.31307451391494534`, 0.9339171441675451],
              177 -> RGBColor[
              0.21738991983752656`, 0.34582096743921015`, 0.9356914063839564],
              200 -> RGBColor[
              0.1906136828189116, 0.3176774446211637, 0.9341665392976392], 
             114 -> RGBColor[
              0.18141516357964482`, 0.30800921768088935`, 0.9336426972349526],
              24 -> RGBColor[
              0.2571472380542651, 0.3876084296445695, 0.9379555268407181], 
             176 -> RGBColor[
              0.23408779828449117`, 0.3633714963936115, 0.9366423258592136], 
             79 -> 
             RGBColor[
              0.1941778278429074, 0.3214235870212298, 0.9343695120840757], 
             109 -> RGBColor[
              0.21740901950548744`, 0.34584104240122593`, 0.9356924940817913],
              135 -> RGBColor[
              0.1969362596236349, 0.3243228737174507, 0.934526600693254], 108 -> 
             RGBColor[
              0.3080267094125234, 0.4410859799869048, 0.9408530374651383], 
             191 -> RGBColor[
              0.8101035860121542, 0.8515783454987672, 0.9817072126714098], 14 -> 
             RGBColor[
              0.17925722738073346`, 0.3057410899147761, 0.9335198059608052], 
             185 -> RGBColor[
              0.2320502240219991, 0.3612298766540624, 0.9365262890192856], 32 -> 
             RGBColor[
              0.186006868294159, 0.3128353904667376, 0.9339041880256258], 122 -> 
             RGBColor[
              0.27792375203997, 0.40944586315061604`, 0.939138718576106], 187 -> 
             RGBColor[
              0.20348109888236326`, 0.33120191474515054`, 0.9348993196068165],
              193 -> RGBColor[
              0.22946131864603458`, 0.3585087729578423, 0.9363788546880667], 
             100 -> RGBColor[
              0.20579087184942513`, 0.3336296325815971, 0.9350308577602878], 
             180 -> RGBColor[
              0.3420328760182438, 0.47067341895996806`, 0.9430150103054538], 
             7 -> RGBColor[
              0.20849433214894747`, 0.33647114076567824`, 0.9351848158249345],
              175 -> RGBColor[
              0.5005712745154292, 0.6054253369873833, 0.9538259508643026], 9 -> 
             RGBColor[
              0.19331350997927296`, 0.32051513414563226`, 0.9343202904603853],
              90 -> RGBColor[
              0.22727061882380845`, 0.3562062085462915, 0.9362540975740409], 
             174 -> RGBColor[
              0.19003317840134057`, 0.3170672976721906, 0.9341334804298378], 
             142 -> RGBColor[
              0.2619978835405132, 0.39270676559930323`, 0.938231763925273], 
             134 -> RGBColor[
              0.24687317251219526`, 0.37680973534647483`, 0.9373704340072151],
              105 -> RGBColor[
              0.20575656042090384`, 0.333593569094751, 0.9350289037751928], 
             16 -> RGBColor[
              0.1871756577266932, 0.3140638622658612, 0.9339707488547396], 
             139 -> RGBColor[
              0.28566810415648325`, 0.4175856682453557, 0.9395797479723991], 
             146 -> RGBColor[
              0.24540381361353808`, 0.37526534598125116`, 0.9372867561916584],
              126 -> 
             RGBColor[
              0.1796655907243716, 0.3061703056806712, 0.9335430616491059], 
             198 -> RGBColor[
              0.34562348099972906`, 0.47378342052587685`, 0.9432438004798267],
              40 -> RGBColor[
              0.5058302216121423, 0.609694787153362, 0.9542399544439137], 104 -> 
             RGBColor[
              0.36710024085613885`, 0.49238551046016216`, 0.9446122806267241],
              181 -> RGBColor[
              0.43817293033743376`, 0.5539451018716196, 0.9491409695533606], 
             127 -> RGBColor[
              0.874787420357395, 0.9029957597937702, 0.9879191991572792], 76 -> 
             RGBColor[
              0.26424845016803866`, 0.3950722538189983, 0.9383599303652956], 
             172 -> RGBColor[
              0.8693407441384133, 0.4995886600246006, 0.2126870529687101], 84 -> 
             RGBColor[
              0.181234979779358, 0.3078198330824752, 0.9336324360340843], 184 -> 
             RGBColor[
              0.1818088839913312, 0.30842304279688765`, 0.933665119029941], 
             151 -> RGBColor[
              0.9939031817563573, 0.9917468232222412, 0.7507035865643902], 35 -> 
             RGBColor[
              0.18077756667952594`, 0.30733906291288604`, 0.933606387034731], 
             36 -> RGBColor[
              0.18255152448721731`, 0.309203605044191, 0.9337074113075435], 
             34 -> RGBColor[
              0.4300571649791395, 0.5469156338284925, 0.9486238401612196], 38 -> 
             RGBColor[
              0.18112444186066054`, 0.30770365072141526`, 0.9336261410631407],
              54 -> RGBColor[
              0.988392764379178, 0.9725082101217492, 0.4094085107659739], 60 -> 
             RGBColor[
              0.18098071777705174`, 0.3075525875969092, 0.9336179561892], 87 -> 
             RGBColor[
              0.21670300720810273`, 0.3450989787129095, 0.9356522877259069], 
             141 -> RGBColor[
              0.34381589363766235`, 0.47221777920483715`, 0.9431286226115025],
              67 -> RGBColor[
              0.2558901091184015, 0.3862871074263986, 0.9378839352075763], 
             133 -> RGBColor[
              0.24912319227677354`, 0.3791746487785393, 0.937498569304202], 
             98 -> RGBColor[
              0.19250116414799295`, 0.31966130717125646`, 0.9342740285670519],
              3 -> RGBColor[
              0.4186929718519593, 0.5370725409226834, 0.947899723824117], 27 -> 
             RGBColor[
              0.26652048668465833`, 0.39746030825340095`, 0.9384893194837403],
              163 -> 
             RGBColor[
              0.2817626744925139, 0.41348081404998144`, 0.9393573395306015], 
             85 -> RGBColor[
              0.2704719529099895, 0.40161354979365305`, 0.9387143496396024], 
             83 -> RGBColor[
              0.9263859833659136, 0.9441390533310817, 0.9928407161596127], 28 -> 
             RGBColor[
              0.1792907180836107, 0.3057762907669333, 0.933521713206789], 44 -> 
             RGBColor[
              0.8987739036289236, 0.6332377629819576, 0.2372468027203504], 
             189 -> RGBColor[
              0.19443151506714343`, 0.3216902283786009, 0.9343839591961993], 
             15 -> RGBColor[0.178927, 0.305394, 0.933501], 80 -> 
             RGBColor[
              0.22179319725678925`, 0.3504490911907685, 0.9359421665189183], 
             112 -> RGBColor[
              0.9414109245622558, 0.9558249439861124, 0.9840602016246193], 
             169 -> RGBColor[
              0.19209300288846856`, 0.31923230380857776`, 0.9342507843871425],
              69 -> RGBColor[
              0.24981404640376637`, 0.37990078026869034`, 0.9375379124247071],
              20 -> RGBColor[
              0.1823235017276304, 0.3089639386663871, 0.9336944257487145], 8 -> 
             RGBColor[
              0.28326421471662644`, 0.41505902802867256`, 0.939442850025035], 
             116 -> RGBColor[
              0.24062773125074222`, 0.3702453805968408, 0.9370147653666777], 
             97 -> RGBColor[
              0.21679935925455723`, 0.3452002508228058, 0.9356577748324124], 
             118 -> RGBColor[
              0.39086743560945575`, 0.5129714599815431, 0.9461267052599003], 
             178 -> RGBColor[
              0.1836473816366038, 0.3103554203895525, 0.9337698187510258], 81 -> 
             RGBColor[
              0.30602988251049323`, 0.4389871883067331, 0.9407393211271083], 
             166 -> RGBColor[
              0.8037293520346596, 0.846598745469576, 0.9810718885991364], 125 -> 
             RGBColor[
              0.2642831104182927, 0.3951086839396021, 0.9383619042152723], 95 -> 
             RGBColor[
              0.24919784069125972`, 0.37925310899514714`, 0.9375028204209744],
              157 -> RGBColor[
              0.20642492465234524`, 0.3342960622787358, 0.9350669661294171], 
             74 -> RGBColor[
              0.34593054718585675`, 0.47404938582270545`, 0.9432633664656788],
              19 -> RGBColor[
              0.35121665541737046`, 0.47862794708531764`, 0.9436001926078689],
              156 -> RGBColor[
              0.8187176743057581, 0.14487782361704554`, 0.16555737209477062`],
              167 -> RGBColor[
              0.19933380464903927`, 0.32684284555228516`, 0.9346631373356007],
              33 -> RGBColor[
              0.9926235425767636, 0.9912176595362523, 0.7719105193703001], 43 -> 
             RGBColor[
              0.18974733652345127`, 0.3167668597351072, 0.9341172021577572], 
             140 -> RGBColor[
              0.9937232399115826, 0.9889829697856952, 0.5581915839279488], 
             186 -> RGBColor[
              0.18306798401191893`, 0.3097464367500775, 0.933736822913442], 
             117 -> RGBColor[
              0.1853227778630534, 0.31211636804980714`, 0.9338652300875955], 
             4 -> RGBColor[
              0.33430755049502603`, 0.4639821302779076, 0.9425227593943515], 
             106 -> RGBColor[
              0.18503007033382515`, 0.31180871387785897`, 0.9338485608268279],
              65 -> RGBColor[
              0.95633856953826, 0.8643818842404721, 0.284884016735784], 53 -> 
             RGBColor[
              0.631783197735858, 0.7119490872875069, 0.9641554341053266], 2 -> 
             RGBColor[
              0.18237351643808017`, 0.30901650729818564`, 0.9336972740124846],
              147 -> RGBColor[
              0.24952468470268496`, 0.3795966427742623, 0.9375214337039027], 
             94 -> RGBColor[
              0.19041076970754647`, 0.3174641700756846, 0.9341549836961299], 
             23 -> RGBColor[
              0.22363768830217948`, 0.3523877682269605, 0.9360472075552733], 
             194 -> RGBColor[
              0.2015219494351241, 0.32914272445885284`, 0.9347877489440981], 
             129 -> RGBColor[
              0.4544709331932017, 0.5679990031052896, 0.9501967631243022], 99 -> 
             RGBColor[
              0.5518206973838005, 0.647031927232117, 0.9578604931653224], 25 -> 
             RGBColor[
              0.17953882470990998`, 0.3060370665620425, 0.9335358425121159], 
             138 -> RGBColor[
              0.2218736173884548, 0.35053361784807985`, 0.9359467463264457], 
             124 -> RGBColor[
              0.2260372839021752, 0.3549098953457044, 0.9361838609748094], 
             197 -> RGBColor[
              0.20070591566211698`, 0.3282850212238928, 0.9347412770279392], 
             164 -> RGBColor[
              0.19517315909830985`, 0.32246974327830424`, 0.9344261947266101],
              152 -> RGBColor[
              0.20018563595199287`, 0.32773817426091345`, 0.9347116478681324],
              17 -> 
             RGBColor[
              0.19146922694525287`, 0.31857667574257903`, 0.9342152612699701],
              149 -> RGBColor[
              0.1855038424012835, 0.31230667835964177`, 
               0.9338755414451867]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw1Vnk41Iv7HWbGjH3MjDGYYWbMlDYVokV9jgp1K023DRVaCFlSpNQNyVKW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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 11}], {
             RGBColor[
             0.19143609648975546`, 0.318541853533259, 0.9342133745395418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 35}], {
             RGBColor[
             0.1803467482579951, 0.30688624543639154`, 0.9335818525629636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 86}], {
             RGBColor[
             0.19100632204633058`, 0.3180901333439459, 0.934188899520783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 94}], {
             RGBColor[
             0.18516334977200538`, 0.3119487990177908, 0.933856150893663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 174}], {
             RGBColor[
             0.1849745541189024, 0.31175036281604385`, 0.9338453992605169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 196}], {
             RGBColor[
             0.20645103349834157`, 0.33432350433127433`, 0.935068452989572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 16}], {
             RGBColor[
             0.1847745870823867, 0.3115401847820234, 0.9338340114336121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 52}], {
             RGBColor[
             0.1839811911872139, 0.31070627539199164`, 0.933788828711106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[
             0.1829598466238134, 0.3096327774988722, 0.9337306646491643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 78}], {
             RGBColor[
             0.1826523965739446, 0.3093096280030011, 0.9337131558236558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 80}], {
             RGBColor[
             0.20208335684743473`, 0.32973279924447707`, 0.9348197202657014]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 82}], {
             RGBColor[
             0.19716931432443496`, 0.3245678289845131, 0.934539872813691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 98}], {
             RGBColor[
             0.18743734029303655`, 0.314338907234721, 0.9339856512897682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 100}], {
             RGBColor[
             0.19408219414375266`, 0.32132306993989135`, 0.9343640658863862]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 120}], {
             RGBColor[
             0.18815579892545653`, 0.3150940528103027, 0.9340265664460203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 124}], {
             RGBColor[
             0.20420540017012767`, 0.331963201321945, 0.9349405674936471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 187}], {
             RGBColor[
             0.1929273076602217, 0.3201092110216681, 0.9342982968096505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 5}], {
             RGBColor[
             0.38651352623245844`, 0.5092003225130362, 0.945849278004409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 10}], {
             RGBColor[
             0.3183216992072676, 0.4417413182340497, 0.9418115251184348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 27}], {
             RGBColor[
             0.3426067292683088, 0.4672664245880422, 0.9431945216539286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 29}], {
             RGBColor[
             0.312801857714541, 0.4359396148470296, 0.9414971783112978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 49}], {
             RGBColor[
             0.42052372581365627`, 0.5386582479879358, 0.9480163778476842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 53}], {
             RGBColor[
             0.5252380847939087, 0.6245108141050952, 0.9560275789647218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 62}], {
             RGBColor[
             0.30929718741563983`, 0.43225598415395333`, 0.9412975925224704]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 68}], {
             RGBColor[
             0.6898421419054424, 0.7085746089319662, 0.625429383133753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 71}], {
             RGBColor[
             0.3912157938817601, 0.5132731904080172, 0.9461489023409704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 75}], {
             RGBColor[
             0.4604176361342196, 0.5718866537552251, 0.9509246758011038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 118}], {
             RGBColor[
             0.40478020373070756`, 0.5250220004521133, 0.9470132145420087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[
             0.4349086817945046, 0.5511177738496366, 0.9489329745226667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 127}], {
             RGBColor[
             0.6467401961046771, 0.7200341503582268, 0.9679094614906981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 129}], {
             RGBColor[
             0.4365819525225805, 0.5525357720139865, 0.9490482434742096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 139}], {
             RGBColor[
             0.3521805380042213, 0.47732910458401956`, 0.943739735898258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 141}], {
             RGBColor[
             0.38125443274481086`, 0.5046451600637603, 0.9455141732178098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 146}], {
             RGBColor[
             0.33204839273274867`, 0.4561689434519673, 0.9425932400078877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 155}], {
             RGBColor[
             0.545941520152503, 0.6408465029615011, 0.9579803382974005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 167}], {
             RGBColor[
             0.3090133882504993, 0.4319576932374843, 0.9412814305798589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 191}], {
             RGBColor[
             0.6143982789320568, 0.6943254432107253, 0.9648034682477634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 194}], {
             RGBColor[
             0.3101074606435417, 0.43310763269076813`, 0.9413437363841075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 195}], {
             RGBColor[
             0.4598624133064091, 0.5714358988511051, 0.9508809666262504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 34}], {
             RGBColor[
             0.38218235773708276`, 0.5054488820532, 0.9455732997777855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 40}], {
             RGBColor[
             0.42006888605358417`, 0.5368384587156347, 0.9483813569191326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 49}], {
             RGBColor[
             0.37833101513518963`, 0.5021130426655478, 0.9453278956328015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 53}], {
             RGBColor[
             0.483045374115442, 0.5879656087827072, 0.953339096749839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 54}], {
             RGBColor[
             0.661350157437102, 0.7182451701998284, 0.6759656350801627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 65}], {
             RGBColor[
             0.6453230600166431, 0.6641820072591899, 0.6137033880650677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 69}], {
             RGBColor[
             0.2920607984493962, 0.42194145527329896`, 0.9400303359095292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 86}], {
             RGBColor[
             0.26820213237561147`, 0.3968644845029512, 0.9386716201723606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 92}], {
             RGBColor[
             0.28937728391046563`, 0.41912091134823404`, 0.9398775137264412]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 118}], {
             RGBColor[
             0.3625874930522409, 0.48847679512972536`, 0.9443247323271259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 119}], {
             RGBColor[
             0.5905667103712094, 0.4124559324961789, 0.5674982858332491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 123}], {
             RGBColor[
             0.39271597111603795`, 0.5145725685272486, 0.946244492307784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 139}], {
             RGBColor[
             0.30998782732575464`, 0.44078389926163164`, 0.9410512536833753]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 146}], {
             RGBColor[
             0.289855682054282, 0.41962373812957937`, 0.9399047577930049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 171}], {
             RGBColor[
             0.3210288697535419, 0.4523887348957585, 0.9416800247158792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 182}], {
             RGBColor[
             0.33757022299890055`, 0.4668080932140755, 0.9427306540012304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 191}], {
             RGBColor[
             0.57220556825359, 0.6577802378883374, 0.9621149860328806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 195}], {
             RGBColor[
             0.41766970262794245`, 0.5348906935287172, 0.9481924844113676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 196}], {
             RGBColor[
             0.28364684382762245`, 0.41309785549027966`, 0.9395511736411497]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 199}], {
             RGBColor[
             0.6647841302718416, 0.7281451631679503, 0.8353642944923663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 10}], {
             RGBColor[
             0.28614225358776674`, 0.41386909982440245`, 0.9397610792987268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 27}], {
             RGBColor[
             0.31042728364880795`, 0.439394206178395, 0.9411440758342206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.28062241209504013`, 0.4080673964373824, 0.9394467324915896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 30}], {
             RGBColor[
             0.28195013969393246`, 0.40946292232661013`, 0.9395223446141496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 42}], {
             RGBColor[
             0.2785521364098815, 0.40589140542922086`, 0.9393288333540183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 68}], {
             RGBColor[
             0.6576626962859415, 0.680702390522319, 0.6233789373140448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 71}], {
             RGBColor[
             0.35903634826225916`, 0.48540097199837007`, 0.9440984565212622]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 73}], {
             RGBColor[
             0.2859066569179567, 0.41362147278674055`, 0.939747662416915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 75}], {
             RGBColor[
             0.42823819051471873`, 0.5440144353455778, 0.9488742299813958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 76}], {
             RGBColor[
             0.3092912653904981, 0.4382001789611937, 0.9410793812749982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 81}], {
             RGBColor[
             0.3301819815617254, 0.46015764620506105`, 0.9422690766559045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 87}], {
             RGBColor[
             0.28551854391053016`, 0.41321354140814925`, 0.9397255599553038]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 89}], {
             RGBColor[
             0.31092444547544634`, 0.4399167547800723, 0.9411723884647626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 107}], {
             RGBColor[
             0.28598353480448624`, 0.4137022763198226, 0.9397520404988222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 127}], {
             RGBColor[
             0.6145607504851762, 0.6921619319485797, 0.9658590156709901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 129}], {
             RGBColor[
             0.40440250690307966`, 0.5246635536043394, 0.9469977976545015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 141}], {
             RGBColor[
             0.34907498712530993`, 0.4767729416541131, 0.9434637273981017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 142}], {
             RGBColor[
             0.3081659820767354, 0.43701743485134614`, 0.9410152980549868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 147}], {
             RGBColor[
             0.30192938265782127`, 0.43046237343882565`, 0.9406601329443018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 155}], {
             RGBColor[
             0.513762074533002, 0.612974284551854, 0.9559298924776924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 157}], {
             RGBColor[
             0.28037950263265143`, 0.40781208319106244`, 0.939432899157059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 168}], {
             RGBColor[
             0.2818657379269033, 0.4093742107180814, 0.9395175380583785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 188}], {
             RGBColor[
             0.33376821355982345`, 0.4635149837324976, 0.9424883933217574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 197}], {
             RGBColor[
             0.27751999813753725`, 0.4048065626636409, 0.93927005460632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 44}], {
             RGBColor[
             0.8651034665131747, 0.43792568886884486`, 0.20749020660542072`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 45}], {
             RGBColor[
             0.7712380059237092, 0.5084025319316335, 0.5747836939863987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 58}], {
             RGBColor[
             0.8960048531020866, 0.6063661726923737, 0.5646755963969717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 77}], {
             RGBColor[
             0.8243760146987129, 0.18837030737786614`, 0.17097580524524553`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 83}], {
             RGBColor[
             0.8789095063816696, 0.593376334043407, 0.5852871633250518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 96}], {
             RGBColor[
             0.8839247435427675, 0.5973568467623975, 0.5851240708837279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 112}], {
             RGBColor[
             0.8864219769798407, 0.5992192793709223, 0.5808969060575552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 156}], {
             RGBColor[
             0.8250753518515919, 0.1937457191863889, 0.17164549129263085`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 166}], {
             RGBColor[
             0.8175811907160426, 0.5446061801126542, 0.5794027495448137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 170}], {
             RGBColor[
             0.7433204991907267, 0.48659316349091797`, 0.5720011378191884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 179}], {
             RGBColor[
             0.5999866512477183, 0.3681232043828395, 0.5612188243491484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 183}], {
             RGBColor[
             0.8839085682862255, 0.5140524144919886, 0.22270248687391753`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 192}], {
             RGBColor[
             0.6485736073804235, 0.40987019823777215`, 0.5644077418055113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 8}], {
             RGBColor[
             0.24587927343278695`, 0.3757650843971754, 0.9373138329249848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 16}], {
             RGBColor[
             0.19783499493782034`, 0.3252675015157697, 0.9345777823398371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 52}], {
             RGBColor[
             0.19704159904264756`, 0.32443359212573797`, 0.934532599617331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.2079174287175954, 0.335864778681537, 0.9351519620279711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 67}], {
             RGBColor[
             0.23219222063367448`, 0.36137912409603845`, 0.9365343755162554]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 79}], {
             RGBColor[
             0.20133607999592745`, 0.328947363893454, 0.934777163954505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.19486465596415276`, 0.32214548692407674`, 0.9344086259295095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 122}], {
             RGBColor[
             0.24320904209445873`, 0.37295850195814717`, 0.9371617672005202]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 125}], {
             RGBColor[
             0.2363887212836201, 0.36578991235264013`, 0.9367733600201034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 126}], {
             RGBColor[
             0.19407996143665954`, 0.32132072322317473`, 0.9343639387370202]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 137}], {
             RGBColor[
             0.266193356547354, 0.39571608733082725`, 0.9385219649126898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 179}], {
             RGBColor[
             0.2885173026234793, 0.4150519673878126, 0.9399444270163702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 192}], {
             RGBColor[
             0.3371042587561843, 0.4567989612427451, 0.9431333444727331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.3222839501803989, 0.4512119268537823, 0.9418428896396724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 26}], {
             RGBColor[
             0.28802321713859724`, 0.420061041312345, 0.9397138681726531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 61}], {
             RGBColor[
             0.24530237000143487`, 0.37515872231303415`, 0.9372809791280214]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 67}], {
             RGBColor[
             0.26957716191751396`, 0.4006730677275356, 0.9386633926163057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 79}], {
             RGBColor[
             0.2387210212797669, 0.3682413075249512, 0.9369061810545554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.24761466346370808`, 0.37758908934975655`, 0.9374126608199662]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 83}], {
             RGBColor[
             0.60482509904127, 0.6795990406798771, 0.9661417830923238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 122}], {
             RGBColor[
             0.2805939833782982, 0.4122524455896443, 0.9392907843005704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 125}], {
             RGBColor[
             0.2737736625674596, 0.4050838559841373, 0.9389023771201537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 137}], {
             RGBColor[
             0.3035782978311935, 0.4350100309623244, 0.94065098201274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 166}], {
             RGBColor[
             0.543496783375643, 0.6308288867491243, 0.9602573693120857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 170}], {
             RGBColor[
             0.4692360918503271, 0.5728158701273882, 0.9528557575864605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 179}], {
             RGBColor[
             0.32590224390731876`, 0.4543459110193097, 0.9420734441164204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 192}], {
             RGBColor[
             0.37448920004002384`, 0.4960929048742423, 0.9452623615727833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 198}], {
             RGBColor[
             0.31444384785817775`, 0.4444212242772747, 0.9413433252524308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 18}], {
             RGBColor[
             0.2081906159438856, 0.3361519157774386, 0.935167519636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 32}], {
             RGBColor[
             0.18966018913671598`, 0.3166752623061849, 0.9341122392430056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 39}], {
             RGBColor[
             0.22268787528916928`, 0.3513894545286635, 0.9359931171093048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 41}], {
             RGBColor[
             0.24200989921647753`, 0.37169812676333913`, 0.9370934777875921]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 57}], {
             RGBColor[
             0.18757656925487778`, 0.3144852457012422, 0.9339935801731742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 85}], {
             RGBColor[
             0.23189273144463124`, 0.36106434196964265`, 0.9365173200499939]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 88}], {
             RGBColor[
             0.20493816247527158`, 0.3327333809644648, 0.9349822972229003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 91}], {
             RGBColor[
             0.1897739422401799, 0.3167948240302888, 0.9341187173139652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 103}], {
             RGBColor[
             0.18719718779584008`, 0.3140864917336198, 0.9339719749603267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 117}], {
             RGBColor[
             0.1893181439211632, 0.3163157510977197, 0.9340927602739904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 121}], {
             RGBColor[
             0.20533326031636837`, 0.3331486538461075, 0.9350047974604558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 152}], {
             RGBColor[
             0.19674957296563292`, 0.32412665420327286`, 0.9345159691642588]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 159}], {
             RGBColor[
             0.22410281281265743`, 0.3528766435780701, 0.9360736957080549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 164}], {
             RGBColor[
             0.1942433345387914, 0.32149243871196825`, 0.9343732425934977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 178}], {
             RGBColor[
             0.18848044580793838`, 0.31543527726759235`, 0.9340450546057055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 200}], {
             RGBColor[
             0.19196359639909227`, 0.31909628938339796`, 0.9342434148790122]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 17}], {
             RGBColor[
             0.2047098267539144, 0.3324933856439975, 0.9349692938413614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 27}], {
             RGBColor[
             0.24223545662361712`, 0.37193520189940843`, 0.9371063229482464]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 29}], {
             RGBColor[
             0.2124305850698493, 0.3406083921583959, 0.9354089796056155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 30}], {
             RGBColor[
             0.2137583126687416, 0.34200391804762365`, 0.9354845917281754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 42}], {
             RGBColor[
             0.2103603093846907, 0.3384324011502344, 0.9352910804680441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 51}], {
             RGBColor[
             0.20007349461539067`, 0.32762030660597313`, 0.9347052615849112]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 62}], {
             RGBColor[
             0.2089259147709481, 0.3369247614653196, 0.9352093938167881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 71}], {
             RGBColor[
             0.2908445212370684, 0.4179419677193835, 0.9400607036352882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 73}], {
             RGBColor[
             0.2177148298927659, 0.346162468507754, 0.9357099095309409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 75}], {
             RGBColor[
             0.3600463634895279, 0.4765554310665914, 0.9448364770954216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 89}], {
             RGBColor[
             0.2427326184502555, 0.3724577505010858, 0.9371346355787884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 107}], {
             RGBColor[
             0.21779170777929543`, 0.3462432720408361, 0.9357142876128481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.3362106798778888, 0.4572045493253528, 0.9429600447685274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 130}], {
             RGBColor[
             0.2011228825880777, 0.32872327990030753`, 0.9347650226775253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 141}], {
             RGBColor[
             0.28088316010011916`, 0.40931393737512656`, 0.9394259745121276]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 142}], {
             RGBColor[
             0.23997415505154454`, 0.3695584305723596, 0.9369775451690128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 147}], {
             RGBColor[
             0.23373755563263043`, 0.3630033691598391, 0.9366223800583277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 149}], {
             RGBColor[
             0.2017271344819297, 0.32935838695252884`, 0.9347994339289696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 167}], {
             RGBColor[
             0.2086421156058076, 0.33662647054885053`, 0.9351932318741767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 168}], {
             RGBColor[
             0.21367391090171242`, 0.3419152064390949, 0.9354797851724044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 188}], {
             RGBColor[
             0.26557638653463256`, 0.3960559794535111, 0.9384506404357832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.20619097081485965`, 0.33405016196200843`, 0.935053642804476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 194}], {
             RGBColor[
             0.20973618799885002`, 0.33777641000213443`, 0.9352555376784253]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 197}], {
             RGBColor[
             0.20932817111234645`, 0.33734755838465436`, 0.9352323017203459]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 35}], {
             RGBColor[
             0.19186691491128627`, 0.3189946710097535, 0.9342379090113091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 70}], {
             RGBColor[
             0.19700340773557554`, 0.3243934506405365, 0.9345304246788922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 86}], {
             RGBColor[
             0.20252648869962175`, 0.33019855891730787`, 0.9348449559691285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 94}], {
             RGBColor[
             0.19668351642529655`, 0.32405722459115277`, 0.9345122073420087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 110}], {
             RGBColor[
             0.1915413157937571, 0.3186524456930539, 0.9342193666232466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 138}], {
             RGBColor[
             0.2124149402657507, 0.3405919484773504, 0.9354080886571665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 174}], {
             RGBColor[
             0.1964947207721936, 0.32385878838940574`, 0.9345014557088626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 182}], {
             RGBColor[
             0.27189457932291083`, 0.4001421676284322, 0.9389039897979983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 196}], {
             RGBColor[
             0.21797120015163274`, 0.34643192990463634`, 0.9357245094379176]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 33}], {
             RGBColor[
             0.9713628299392978, 0.9155481063306994, 0.5253098577893779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 44}], {
             RGBColor[
             0.9244380104653778, 0.7365581580535521, 0.25797799946440303`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 58}], {
             RGBColor[
             0.9553393970542898, 0.9049986418770809, 0.615163389255954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 68}], {
             RGBColor[
             0.9555467146303788, 0.8599776150331977, 0.2908341193259223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 77}], {
             RGBColor[
             0.883710558650916, 0.4870027765625733, 0.22146359810422783`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 96}], {
             RGBColor[
             0.9432592874949708, 0.8959893159471047, 0.6356118637427102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 99}], {
             RGBColor[
             0.7509614073428162, 0.7434552401786318, 0.618284844686889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 102}], {
             RGBColor[
             0.9596388825040008, 0.9082051910857141, 0.6078854818749925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 128}], {
             RGBColor[
             0.6907043727279983, 0.6939382045780004, 0.6137063255291655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 140}], {
             RGBColor[
             0.9719126786067074, 0.9144307614554209, 0.4184503900682022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 162}], {
             RGBColor[
             0.7007570533940699, 0.7026453313085301, 0.614346873451971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 172}], {
             RGBColor[
             0.9097214307201227, 0.6697336065748736, 0.2456981245885829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 31}], {
             RGBColor[
             0.37653388192589077`, 0.49031817539689215`, 0.9461000785422968]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 34}], {
             RGBColor[
             0.32558157650060693`, 0.44832121227099686`, 0.9422634355654279]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 36}], {
             RGBColor[
             0.20182875625464586`, 0.3294651978788461, 0.9348052211385899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 63}], {
             RGBColor[
             0.20638929458382937`, 0.3342586128176488, 0.935064937049725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 64}], {
             RGBColor[
             0.4253184848962721, 0.5299237138095665, 0.9499405811920143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 70}], {
             RGBColor[
             0.20607827017508945`, 0.33393170644397663`, 0.9350472246697668]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 97}], {
             RGBColor[
             0.21895267363831583`, 0.3474635207681535, 0.9357804029010244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 132}], {
             RGBColor[
             0.26083574153477407`, 0.39148528066721244`, 0.9381655816572811]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 138}], {
             RGBColor[
             0.2214898027052646, 0.35013020428079056`, 0.9359248886480409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 145}], {
             RGBColor[
             0.20564959648275716`, 0.3334811432138535, 0.9350228123371542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 153}], {
             RGBColor[
             0.2516813551580962, 0.3818634401637041, 0.9376442528958304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 185}], {
             RGBColor[
             0.22657810602203676`, 0.3554783336837818, 0.936214659994461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 22}], {
             RGBColor[
             0.18387332754707644`, 0.31059290386725735`, 0.9337826860363703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 48}], {
             RGBColor[
             0.19487547737670605`, 0.3221568609147874, 0.9344092421929455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 106}], {
             RGBColor[
             0.1821436488572793, 0.3087749018963175, 0.9336841833938165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 131}], {
             RGBColor[
             0.18037616802655143`, 0.3069171674784653, 0.9335835279752602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 176}], {
             RGBColor[
             0.20667251283261232`, 0.3345562931541938, 0.9350810659100094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 59}], {
             RGBColor[
             0.18157500733235693`, 0.30817722359966904`, 0.9336518001002019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.18941420148966015`, 0.3164167136926116, 0.9340982306104119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 114}], {
             RGBColor[
             0.1801710817898224, 0.3067016088404447, 0.9335718486174763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 167}], {
             RGBColor[
             0.18913040232451964`, 0.31611842277614255`, 0.9340820686678004]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 184}], {
             RGBColor[
             0.18036794199566558`, 0.3069085213984438, 0.9335830595149706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 186}], {
             RGBColor[
             0.18099749200595946`, 0.30757021837503873`, 0.933618911456721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 194}], {
             RGBColor[
             0.19022447471756204`, 0.31726836222942645`, 0.934144374472049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 52}], {
             RGBColor[
             0.18638226183152043`, 0.31322995287582944`, 0.9339255661322337]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 61}], {
             RGBColor[
             0.19725809150646825`, 0.3246611394316285, 0.9345449285428737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 67}], {
             RGBColor[
             0.22153288342254734`, 0.3501754848461299, 0.935927342031158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 80}], {
             RGBColor[
             0.20448442749174123`, 0.3322564767283148, 0.934956457686829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 82}], {
             RGBColor[
             0.19957038496874147`, 0.32709150646835083`, 0.9346766102348185]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 84}], {
             RGBColor[
             0.1842053187530256, 0.3109418476741682, 0.933801592444412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 100}], {
             RGBColor[
             0.19648326478805916`, 0.32384674742372915`, 0.9345008033075137]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 120}], {
             RGBColor[
             0.19055686956976303`, 0.31761773029414053`, 0.9341633038671477]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 125}], {
             RGBColor[
             0.22572938407249296`, 0.3545862731027316, 0.936166326535006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.19532837830452823`, 0.32263288850550587`, 0.9344350342307781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 30}], {
             RGBColor[
             0.20051771286008008`, 0.3280872081462052, 0.9347305591567843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[
             0.1971197095760292, 0.3245156912488159, 0.9345370478966529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 51}], {
             RGBColor[
             0.18683289480672916`, 0.31370359670455467`, 0.9339512290135199]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 73}], {
             RGBColor[
             0.20447423008410437`, 0.33224575860633554`, 0.9349558769595496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 87}], {
             RGBColor[
             0.2040861170766778, 0.33183782722774424`, 0.9349337744979385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 89}], {
             RGBColor[
             0.229492018641594, 0.35854104059966735`, 0.9363806030073972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 106}], {
             RGBColor[
             0.18824964863953902`, 0.315192694810219, 0.934031911048399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 107}], {
             RGBColor[
             0.20455110797063392`, 0.33232656213941764`, 0.9349602550414569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 130}], {
             RGBColor[
             0.18788228277941618`, 0.31480656999888906`, 0.9340109901061341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 131}], {
             RGBColor[
             0.18648216780881113`, 0.31333496039236675`, 0.9339312556298427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 142}], {
             RGBColor[
             0.22673355524288302`, 0.35564172067094113`, 0.9362235125976215]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 147}], {
             RGBColor[
             0.22049695582396892`, 0.34908665925842064`, 0.9358683474869365]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 149}], {
             RGBColor[
             0.1884865346732682, 0.31544167705111037`, 0.9340454013575784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 157}], {
             RGBColor[
             0.19894707579879906`, 0.3264363690106574, 0.9346411136996936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 168}], {
             RGBColor[
             0.2004333110930509, 0.32799849653767643`, 0.9347257526010131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 188}], {
             RGBColor[
             0.25233578672597107`, 0.38213926955209265`, 0.937696607864392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 189}], {
             RGBColor[
             0.19295037100619816`, 0.32013345206058996`, 0.9342996102330847]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 197}], {
             RGBColor[
             0.19608757130368493`, 0.3234308484832359, 0.9344782691489546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 24}], {
             RGBColor[
             0.24010747998138166`, 0.3696985635269072, 0.9369851378265305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 32}], {
             RGBColor[
             0.20453729510132862`, 0.33231204393799124`, 0.9349594684189844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 39}], {
             RGBColor[
             0.2375649812537819, 0.3670262361604698, 0.9368403462852835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 41}], {
             RGBColor[
             0.25688700518109014`, 0.38733490839514545`, 0.9379407069635708]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 85}], {
             RGBColor[
             0.24676983740924385`, 0.376701123601449, 0.9373645492259726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 103}], {
             RGBColor[
             0.20207429376045272`, 0.32972327336542606`, 0.9348192041363055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 108}], {
             RGBColor[
             0.2655472156605108, 0.39643733869807485`, 0.9384338931387406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 117}], {
             RGBColor[
             0.2041952498857758, 0.331952532729526, 0.9349399894499691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 133}], {
             RGBColor[
             0.2360954570926359, 0.3654816730938921, 0.9367566590582723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 152}], {
             RGBColor[
             0.21162667893024556`, 0.3397634358350792, 0.9353631983402376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 178}], {
             RGBColor[
             0.20335755177255102`, 0.3310720588993987, 0.9348922837816843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 33}], {
             RGBColor[
             0.6719200989970671, 0.734922803310785, 0.8577553559890845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 74}], {
             RGBColor[
             0.34857360130161363`, 0.4763386664540116, 0.9434317795367738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 85}], {
             RGBColor[
             0.31084430416368, 0.44012074843948534`, 0.9411572711237357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 88}], {
             RGBColor[
             0.28388973519432037`, 0.4117897874343075, 0.939622248296642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 93}], {
             RGBColor[
             0.291301712500707, 0.4195802455298239, 0.9400443494392029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 95}], {
             RGBColor[
             0.3002072480543151, 0.4289405280402324, 0.9405515065144217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 102}], {
             RGBColor[
             0.6601961515617699, 0.7275798880657995, 0.9403309800746991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 121}], {
             RGBColor[
             0.28428483303541713`, 0.41220506031595017`, 0.9396447485341975]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 140}], {
             RGBColor[
             0.6724699476644765, 0.7338054584355065, 0.7508958882679089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 159}], {
             RGBColor[
             0.30305438553170616`, 0.43193305004791277`, 0.9407136467817967]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 161}], {
             RGBColor[
             0.3175223229543551, 0.44713976959933127`, 0.9415375744146212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 162}], {
             RGBColor[
             0.4013143224518391, 0.5220200282886156, 0.9467923716516777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 164}], {
             RGBColor[
             0.2731949072578401, 0.40054884518181094`, 0.9390131936672395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 172}], {
             RGBColor[
             0.610278699777892, 0.48910830355495916`, 0.5781436227882895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 173}], {
             RGBColor[
             0.35948494367207134`, 0.4857895227952885, 0.9441270406240982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 180}], {
             RGBColor[
             0.3466247657178071, 0.47465068302264285`, 0.9433076014566613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 22}], {
             RGBColor[
             0.1854064647205249, 0.3122043282430629, 0.9338699959303249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 46}], {
             RGBColor[
             0.182651270158183, 0.3093084440686167, 0.9337130916759446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 47}], {
             RGBColor[
             0.189292245231432, 0.3162885299327404, 0.9340912853819239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 50}], {
             RGBColor[
             0.19303508907013, 0.32022249611721776`, 0.9343044348014965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 101}], {
             RGBColor[
             0.18925893509711914`, 0.3162535188695931, 0.9340893884190526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 135}], {
             RGBColor[
             0.18962988067563263`, 0.3166434061919189, 0.9341105132209843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 144}], {
             RGBColor[
             0.19040607844928842`, 0.31745923926581243`, 0.9341547165359123]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 23}], {
             RGBColor[
             0.2924706869731754, 0.4198762969529263, 0.9401450684047916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 55}], {
             RGBColor[
             0.34859095953566543`, 0.47635370128389704`, 0.9434328855880982]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 61}], {
             RGBColor[
             0.2843221054652073, 0.4113116211381439, 0.9396810187426589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 67}], {
             RGBColor[
             0.30859689738128643`, 0.43682596655264533`, 0.9410634322309431]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 83}], {
             RGBColor[
             0.6438448345050425, 0.715751939504987, 0.9685418227069613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 90}], {
             RGBColor[
             0.29428715223398993`, 0.42178551711259177`, 0.9402485134141754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 122}], {
             RGBColor[
             0.3196137188420707, 0.44840534441475405`, 0.941690823915208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 166}], {
             RGBColor[
             0.5825165188394155, 0.666981785574234, 0.9626574089267232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 170}], {
             RGBColor[
             0.5082558273140996, 0.6089687689524979, 0.9552557972010979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 175}], {
             RGBColor[
             0.43093748007980026`, 0.5463950813331377, 0.9490344400593063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 177}], {
             RGBColor[
             0.28934680274084895`, 0.4165928965590511, 0.9399671678191333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 179}], {
             RGBColor[
             0.3649219793710912, 0.49049880984441946`, 0.9444734837310578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 183}], {
             RGBColor[
             0.6488438964095984, 0.6364280199535685, 0.605957146255827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 192}], {
             RGBColor[
             0.4135089355037963, 0.532245803699352, 0.9476624011874208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.19949157754304903`, 0.3270086748672687, 0.9346721222685106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 72}], {
             RGBColor[
             0.22084536933385682`, 0.34945286394800523`, 0.935888189120893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 144}], {
             RGBColor[
             0.19348904144218293`, 0.3206996288424882, 0.9343302867175226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 176}], {
             RGBColor[
             0.2112886129989553, 0.33940810710667507`, 0.9353439459855744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 38}], {
             RGBColor[
             0.20238106508142, 0.3300457094741879, 0.9348366743092069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 43}], {
             RGBColor[
             0.2066925124128154, 0.33457731398103385`, 0.9350822048565153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 55}], {
             RGBColor[
             0.27975796086466953`, 0.40886517255793126`, 0.9393350247385799]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 60}], {
             RGBColor[
             0.2023092030396156, 0.32997017791193484`, 0.9348325818722366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 90}], {
             RGBColor[
             0.22545415356299398`, 0.354296988386626, 0.936150652564657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 111}], {
             RGBColor[
             0.2218869245410005, 0.3505476045091276, 0.935947504149097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 115}], {
             RGBColor[
             0.26933147945021957`, 0.39983427840692803`, 0.9386706585626268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 163}], {
             RGBColor[
             0.2527001813973467, 0.382934291138471, 0.9377022735429374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 165}], {
             RGBColor[
             0.21472043526896856`, 0.3430151699025583, 0.9355393831869255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 169}], {
             RGBColor[
             0.20786534559532402`, 0.33581003601776915`, 0.9351489959712078]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 175}], {
             RGBColor[
             0.36210448140880436`, 0.4789065526071719, 0.9449365792097879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 177}], {
             RGBColor[
             0.22051380406985302`, 0.3491043678330853, 0.9358693069696149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 39}], {
             RGBColor[
             0.25460473932666533`, 0.38493610227813213`, 0.9378107352994711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 41}], {
             RGBColor[
             0.2739267632539736, 0.4052447745128077, 0.9389110959777585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 55}], {
             RGBColor[
             0.29651273574071235`, 0.4264755032667358, 0.9402891843813024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 108}], {
             RGBColor[
             0.28258697373339425`, 0.41434720481573717`, 0.9394042821529283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 111}], {
             RGBColor[
             0.2386416994170433, 0.36815793521793205`, 0.9369016637918195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 115}], {
             RGBColor[
             0.28608625432626233`, 0.41744460911573256`, 0.9396248182053492]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 133}], {
             RGBColor[
             0.2531352151655193, 0.3833915392115544, 0.93772704807246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 163}], {
             RGBColor[
             0.2694549562733895, 0.40054462184727546`, 0.9386564331856598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 165}], {
             RGBColor[
             0.23147521014501135`, 0.3606255006113628, 0.9364935428296479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 175}], {
             RGBColor[
             0.3788592562848471, 0.49651688331597643`, 0.9458907388525104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 38}], {
             RGBColor[
             0.18033163328528526`, 0.30687035864172885`, 0.9335809917876283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[
             0.1846430806166806, 0.3114019631485748, 0.9338265223349365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 60}], {
             RGBColor[
             0.18025977124348086`, 0.3067948270794758, 0.9335768993506579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 111}], {
             RGBColor[
             0.19983749274486573`, 0.32737225367666856`, 0.9346918216275183]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 165}], {
             RGBColor[
             0.19267100347283378`, 0.3198398190700993, 0.9342837006653468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 58}], {
             RGBColor[
             0.6266794481836577, 0.6975908926125163, 0.9458012343118618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 67}], {
             RGBColor[
             0.2743361643394848, 0.4056750810112081, 0.9389344107639237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 80}], {
             RGBColor[
             0.25728770840867865`, 0.387756072893393, 0.9379635264195947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 82}], {
             RGBColor[
             0.2523736658856789, 0.382591102633429, 0.9376836789675842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 96}], {
             RGBColor[
             0.6145993386243387, 0.6885815666825401, 0.9662497087986179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 98}], {
             RGBColor[
             0.24264169185428053`, 0.372362180883637, 0.9371294574436615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 99}], {
             RGBColor[
             0.42230145847218425`, 0.5360474909140672, 0.9489226897427967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[
             0.24928654570499661`, 0.3793463435888073, 0.9375078720402794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 116}], {
             RGBColor[
             0.2667049754056552, 0.39765421759642916`, 0.9384998258434745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 120}], {
             RGBColor[
             0.2433601504867005, 0.3731173264592187, 0.9371703725999135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 122}], {
             RGBColor[
             0.285352985800269, 0.4172544588733168, 0.9395618024481885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 124}], {
             RGBColor[
             0.25940975173137165`, 0.3899864749708609, 0.9380843736475403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 125}], {
             RGBColor[
             0.2785326649894304, 0.41008586926780977`, 0.9391733952677717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 128}], {
             RGBColor[
             0.36204442385736635`, 0.48653045531343586`, 0.9443441705850733]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 136}], {
             RGBColor[
             0.2577972163446346, 0.3882915980387517, 0.9379925421427979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 137}], {
             RGBColor[
             0.3083373002531643, 0.4400120442459969, 0.9409220001603581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.5482557857976138, 0.6358309000327967, 0.9605283874597037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 170}], {
             RGBColor[
             0.4739950942722979, 0.5778178834110607, 0.9531267757340784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 187}], {
             RGBColor[
             0.24813165922146568`, 0.378132484670584, 0.9374421029635438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 192}], {
             RGBColor[
             0.37924820246199464`, 0.5010949181579147, 0.9455333797204014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 198}], {
             RGBColor[
             0.3192028502801486, 0.44942323756094715`, 0.9416143434000489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 29}], {
             RGBColor[
             0.2367156151308905, 0.36613349851238836`, 0.9367919761411093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 30}], {
             RGBColor[
             0.2380433427297828, 0.3675290244016161, 0.9368675882636692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 42}], {
             RGBColor[
             0.2346453394457319, 0.36395750750422684`, 0.936674077003538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 62}], {
             RGBColor[
             0.23321094483198931`, 0.3624498678193121, 0.9365923903522819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 71}], {
             RGBColor[
             0.3151295512981096, 0.44346707407337604`, 0.941443700170782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 73}], {
             RGBColor[
             0.2419998599538071, 0.37168757486174653`, 0.9370929060664348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 75}], {
             RGBColor[
             0.3843313935505691, 0.5020805374205839, 0.9462194736309155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 89}], {
             RGBColor[
             0.2670176485112967, 0.3979828568550783, 0.9385176321142823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 127}], {
             RGBColor[
             0.5706539535210267, 0.6502280340235855, 0.9632042593205097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 129}], {
             RGBColor[
             0.36049570993893, 0.4827296556793453, 0.9443430413040212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 141}], {
             RGBColor[
             0.30516819016116037`, 0.4348390437291191, 0.9408089710476214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 142}], {
             RGBColor[
             0.2642591851125857, 0.3950835369263521, 0.9383605417045067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 147}], {
             RGBColor[
             0.25802258569367165`, 0.38852847551383163`, 0.9380053765938214]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 149}], {
             RGBColor[
             0.2260121645429709, 0.35488349330652136`, 0.9361824304644635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 155}], {
             RGBColor[
             0.4698552775688525, 0.57104038662686, 0.953275136127212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 167}], {
             RGBColor[
             0.2329271456668488, 0.36215157690284305`, 0.9365762284096705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 168}], {
             RGBColor[
             0.23795894096275363`, 0.36744031279308736`, 0.9368627817078983]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 188}], {
             RGBColor[
             0.28986141659567377`, 0.4215810858075036, 0.939833636971277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 189}], {
             RGBColor[
             0.23047600087590087`, 0.35957526831600095`, 0.9364366393399698]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[
             0.23402121805989123`, 0.3633015163561269, 0.9366385342139192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 197}], {
             RGBColor[
             0.23361320117338766`, 0.3628726647386469, 0.9366152982558398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 97}], {
             RGBColor[
             0.19804503866908396`, 0.3254882707948695, 0.9345897440196007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 105}], {
             RGBColor[
             0.19252363925225727`, 0.3196849299308422, 0.9342753084909909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.20340607327822147`, 0.3311230580782995, 0.9348950470096511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 71}], {
             RGBColor[
             0.2853246797443417, 0.4121402643323634, 0.939746356828151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 73}], {
             RGBColor[
             0.21219498840003925`, 0.3403607651207339, 0.9353955627238038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 129}], {
             RGBColor[
             0.33069083838516217`, 0.4514028459383327, 0.9426456979613903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 141}], {
             RGBColor[
             0.2753633186073925, 0.40351223398810643`, 0.9391116277049905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 149}], {
             RGBColor[
             0.19620729298920309`, 0.32355668356550876`, 0.9344850871218325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 167}], {
             RGBColor[
             0.20312227411308098`, 0.33082476716183046`, 0.9348788850670395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 168}], {
             RGBColor[
             0.2081540694089858, 0.33611350305207477`, 0.9351654383652672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 189}], {
             RGBColor[
             0.20067112932213305`, 0.3282484585749883, 0.9347392959973388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 194}], {
             RGBColor[
             0.2042163465061234, 0.3319747066151143, 0.9349411908712882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 197}], {
             RGBColor[
             0.2038083296196198, 0.3315458549976343, 0.9349179549132087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 42}], {
             RGBColor[
             0.2061681954908564, 0.33402622365244206`, 0.935052345783467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 51}], {
             RGBColor[
             0.19588138072155636`, 0.3232141291081808, 0.934466526900334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 71}], {
             RGBColor[
             0.28665240734323405`, 0.41353579022159115`, 0.939821968950711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 73}], {
             RGBColor[
             0.21352271599893158`, 0.34175629100996163`, 0.9354711748463638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 76}], {
             RGBColor[
             0.23690732447147297`, 0.36633499718441476`, 0.936802893704447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 81}], {
             RGBColor[
             0.2577980406427003, 0.3882924644282822, 0.9379925890853533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 87}], {
             RGBColor[
             0.213134602991505, 0.3413483596313704, 0.9354490723847526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 89}], {
             RGBColor[
             0.2385405045564212, 0.3680515730032935, 0.9368959008942113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 106}], {
             RGBColor[
             0.19729813455436623`, 0.32470322721384515`, 0.9345472089352131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 107}], {
             RGBColor[
             0.21359959388546113`, 0.3418370945430438, 0.935475552928271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 130}], {
             RGBColor[
             0.1969307686942434, 0.3243171024025152, 0.9345262879929481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 131}], {
             RGBColor[
             0.19553065372363834`, 0.3228454927959929, 0.9344465535166567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 142}], {
             RGBColor[
             0.23578204115771023`, 0.3651522530745672, 0.9367388104844356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 147}], {
             RGBColor[
             0.22954544173879612`, 0.3585971916620468, 0.9363836453737505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 157}], {
             RGBColor[
             0.20799556171362626`, 0.3359469014142835, 0.9351564115865076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 168}], {
             RGBColor[
             0.2094817970078781, 0.3375090289413025, 0.9352410504878272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 176}], {
             RGBColor[
             0.22182699852969923`, 0.3504846184717214, 0.9359440914514059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 188}], {
             RGBColor[
             0.2613842726407983, 0.39164980195571875`, 0.938211905751206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 197}], {
             RGBColor[
             0.20513605721851214`, 0.33294138088686204`, 0.9349935670357687]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 34}], {
             RGBColor[
             0.48100947040442327`, 0.5889125969543878, 0.9524604831380885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[
             0.5188959987209247, 0.6203021736168226, 0.9552685402794356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 45}], {
             RGBColor[
             0.62150237913985, 0.702550504593909, 0.964065451798632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 64}], {
             RGBColor[
             0.5807463788000884, 0.6705150984929575, 0.9601376287646749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 65}], {
             RGBColor[
             0.7441501726839835, 0.7476457221603776, 0.6205905714253708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 132}], {
             RGBColor[
             0.4162636354385904, 0.5320766653506034, 0.9483626292299419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 138}], {
             RGBColor[
             0.3769176966090809, 0.4907215889641815, 0.9461219362207016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 153}], {
             RGBColor[
             0.4071092490619125, 0.522454824847095, 0.9478413004684911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 156}], {
             RGBColor[
             0.6753397250677327, 0.3878936918486643, 0.560927249104864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 182}], {
             RGBColor[
             0.43639733566624106`, 0.5502718081152633, 0.9496178373615334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 185}], {
             RGBColor[
             0.38200599992585305`, 0.49606971836717273`, 0.9464117075671216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 199}], {
             RGBColor[
             0.763611242939182, 0.811608878069138, 0.8422514778526693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 39}], {
             RGBColor[
             0.2190345544466123, 0.34754958268921615`, 0.9357850658919249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 57}], {
             RGBColor[
             0.1839232484123208, 0.31064537386179486`, 0.9337855289557946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 103}], {
             RGBColor[
             0.1835438669532831, 0.31024661989417246`, 0.9337639237429469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 117}], {
             RGBColor[
             0.1856648230786062, 0.31247587925827236`, 0.9338847090566107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 133}], {
             RGBColor[
             0.21756503028546625`, 0.3460050196226384, 0.9357013786649139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 152}], {
             RGBColor[
             0.19309625212307593`, 0.3202867823638255, 0.9343079179468792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 178}], {
             RGBColor[
             0.1848271249653814, 0.311595405428145, 0.9338370033883259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 44}], {
             RGBColor[
             0.9456987231028435, 0.812227711259105, 0.5045786610453252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 58}], {
             RGBColor[
             0.9766001096917556, 0.9806681950826337, 0.8617640508368762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 68}], {
             RGBColor[
             0.9768074272678445, 0.9356471682387506, 0.5374347809068445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 77}], {
             RGBColor[
             0.9049712712883817, 0.5626723297681262, 0.46806425968515003`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 96}], {
             RGBColor[
             0.9645200001324366, 0.9716588691526575, 0.8822125253236324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 99}], {
             RGBColor[
             0.772222119980282, 0.8191247933841846, 0.8648855062678112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 102}], {
             RGBColor[
             0.9808995951414665, 0.9838747442912669, 0.8544861434559147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 128}], {
             RGBColor[
             0.7119650853654641, 0.7696077577835532, 0.8603069871100877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 140}], {
             RGBColor[
             0.9931733912441731, 0.9901003146609737, 0.6650510516491244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 162}], {
             RGBColor[
             0.7220177660315357, 0.778314884514083, 0.8609475350328932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 172}], {
             RGBColor[
             0.9309821433575884, 0.7454031597804265, 0.49229878616950506`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 180}], {
             RGBColor[
             0.6673282092975037, 0.7309455392481101, 0.857462764837877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 40}], {
             RGBColor[
             0.4679436932956409, 0.5783052104909272, 0.9514318973025666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 45}], {
             RGBColor[
             0.5705500737145661, 0.6605535414680137, 0.960228808821763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 54}], {
             RGBColor[
             0.7092249646791587, 0.7597119219751208, 0.6790161754635967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 64}], {
             RGBColor[
             0.5297940733748047, 0.6285181353670621, 0.956300985787806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 65}], {
             RGBColor[
             0.6931978672586998, 0.7056487590344823, 0.6167539284485017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 132}], {
             RGBColor[
             0.3653113300133066, 0.4900797022247081, 0.9445259862530728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 138}], {
             RGBColor[
             0.32596539118379714`, 0.4487246258382862, 0.9422852932438326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 153}], {
             RGBColor[
             0.3561569436366287, 0.48045786172119975`, 0.9440046574916221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 182}], {
             RGBColor[
             0.3854450302409573, 0.5082748449893679, 0.9457811943846643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 185}], {
             RGBColor[
             0.3310536945005693, 0.45407275524127744`, 0.9425750645902526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 199}], {
             RGBColor[
             0.7126589375138983, 0.7696119149432428, 0.8384148348758003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 86}], {
             RGBColor[
             0.19143714046786142`, 0.31854295082044043`, 0.9342134339925504]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.1855941681935362, 0.31240161649428533`, 0.9338806853654305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 110}], {
             RGBColor[
             0.18045196756199675`, 0.30699683759618646`, 0.9335878446466683]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 174}], {
             RGBColor[
             0.18540537254043327`, 0.31220318029253835`, 0.9338699337322844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 63}], {
             RGBColor[
             0.1871120628164008, 0.3139970199829937, 0.9339671272186787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 70}], {
             RGBColor[
             0.18680103840766088`, 0.3136701136093215, 0.9339494148387204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 110}], {
             RGBColor[
             0.18133894646584242`, 0.3079291086618389, 0.9336383567830746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 138}], {
             RGBColor[
             0.20221257093783607`, 0.32986861144613544`, 0.9348270788169946]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 145}], {
             RGBColor[
             0.1863723647153286, 0.3132195503791984, 0.9339250025061079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 185}], {
             RGBColor[
             0.2073008742546082, 0.33521674084912667`, 0.9351168501634146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 45}], {
             RGBColor[
             0.47344467906469456`, 0.5697056609217193, 0.9542881258612889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 47}], {
             RGBColor[
             0.21605368220731502`, 0.34441649696749876`, 0.9356153096277022]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 50}], {
             RGBColor[
             0.21979652604601302`, 0.3483504631519761, 0.935828459047275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 97}], {
             RGBColor[
             0.22632286746697683`, 0.35521006177935477`, 0.9362001245363418]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 101}], {
             RGBColor[
             0.21602037207300215`, 0.3443814859043514, 0.9356134126648311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 105}], {
             RGBColor[
             0.22080146805015013`, 0.3494067209153274, 0.9358856890077321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 134}], {
             RGBColor[
             0.24135977409579584`, 0.37101480404118925`, 0.9370564541237432]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 135}], {
             RGBColor[
             0.21639131765151565`, 0.3447713732266772, 0.9356345374667627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 160}], {
             RGBColor[
             0.33951855272220766`, 0.4617555701348826, 0.9431015867680459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 43}], {
             RGBColor[
             0.1854358891920559, 0.31223525522826123`, 0.9338716716104489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 60}], {
             RGBColor[
             0.18105257981885614`, 0.3076281191591622, 0.9336220486261704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 90}], {
             RGBColor[
             0.20419753034223448`, 0.33195492963385337`, 0.9349401193185908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 111}], {
             RGBColor[
             0.200630301320241, 0.32820554575635497`, 0.9347369709030307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 165}], {
             RGBColor[
             0.19346381204820906`, 0.3206731111497857, 0.9343288499408593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 169}], {
             RGBColor[
             0.18660872237456455`, 0.31346797726499653`, 0.9339384627251416]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 41}], {
             RGBColor[
             0.2713842645263738, 0.40257244714637036`, 0.9387663044365115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 74}], {
             RGBColor[
             0.29899639389246113`, 0.42815658036720006`, 0.9404646551119514]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 85}], {
             RGBColor[
             0.26126709675452753`, 0.3919386623526739, 0.9381901466989133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 88}], {
             RGBColor[
             0.2343125277851679, 0.36360770134749604`, 0.9366551238718196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 108}], {
             RGBColor[
             0.2800444750057945, 0.41167487744929976`, 0.9392594906116811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 117}], {
             RGBColor[
             0.21869250923105948`, 0.34719007148075093`, 0.9357655869229098]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 133}], {
             RGBColor[
             0.2505927164379196, 0.38071921184511703`, 0.9375822565312131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 152}], {
             RGBColor[
             0.22612393827552923`, 0.3550009745863041, 0.9361887958131783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 159}], {
             RGBColor[
             0.25347717812255377`, 0.3837509639611013, 0.9377465223569743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 173}], {
             RGBColor[
             0.3099077362629189, 0.437607436708477, 0.9411599161992759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 178}], {
             RGBColor[
             0.21785481111783467`, 0.34630959765062364`, 0.935717881254625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 49}], {
             RGBColor[
             0.46409235069374777`, 0.5749693711032751, 0.9511864931575826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 53}], {
             RGBColor[
             0.5688067096740002, 0.6608219372204345, 0.9591976942746201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 54}], {
             RGBColor[
             0.7471114929956602, 0.7911014986375555, 0.6818242326049438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 64}], {
             RGBColor[
             0.5676806016913061, 0.6599077120294969, 0.959109042929153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.7310843955752011, 0.737038335696917, 0.6195619855898489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 69}], {
             RGBColor[
             0.37782213400795434`, 0.4947977837110262, 0.9458889334343104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 119}], {
             RGBColor[
             0.6763280459297676, 0.4853122609339061, 0.5733568833580303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 123}], {
             RGBColor[
             0.4784773066745961, 0.5874288969649759, 0.9521030898325651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 132}], {
             RGBColor[
             0.40319785832980803`, 0.5214692788871429, 0.94733404339442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 171}], {
             RGBColor[
             0.40679020531210003`, 0.5252450633334856, 0.9475386222406603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 182}], {
             RGBColor[
             0.4233315585574587, 0.5396644216518027, 0.9485892515260115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 191}], {
             RGBColor[
             0.6579669038121483, 0.7306365663260646, 0.9679735835576617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 195}], {
             RGBColor[
             0.5034310381865006, 0.6077470219664445, 0.9540510819361487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 196}], {
             RGBColor[
             0.3694081793861806, 0.4859541839280068, 0.9454097711659308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 199}], {
             RGBColor[
             0.7505454658303996, 0.8010014916056775, 0.8412228920171474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 74}], {
             RGBColor[
             0.31831841781976944`, 0.44846525260187575`, 0.9415650157902389]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 85}], {
             RGBColor[
             0.2805891206818358, 0.4122473345873495, 0.9392905073772007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.2536345517124762, 0.3839163735821717, 0.937755484550107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 108}], {
             RGBColor[
             0.29936649893310274`, 0.4319835496839754, 0.9403598512899686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 121}], {
             RGBColor[
             0.25402964955357293`, 0.38433164646381435`, 0.9377779847876626]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 133}], {
             RGBColor[
             0.2699147403652278, 0.4010278840797926, 0.9386826172095004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 140}], {
             RGBColor[
             0.6422147641826323, 0.7059320445833706, 0.7490291245213738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 151}], {
             RGBColor[
             0.6423047351050197, 0.7073139713016436, 0.8452851258395946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 152}], {
             RGBColor[
             0.2454459622028375, 0.3753096468209797, 0.9372891564914656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 159}], {
             RGBColor[
             0.27279920204986197`, 0.40405963619577695`, 0.9388468830352616]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 161}], {
             RGBColor[
             0.2872671394725109, 0.41926635574719545`, 0.9396708106680862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 173}], {
             RGBColor[
             0.32922976019022715`, 0.45791610894315266`, 0.9422602768775632]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 51}], {
             RGBColor[
             0.1924833774375055, 0.31964261221079154`, 0.9342730156402028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 71}], {
             RGBColor[
             0.2832544040591832, 0.40996427332420193`, 0.9396284576905798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 73}], {
             RGBColor[
             0.2101247127148807, 0.3381847741125724, 0.9352776635862325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 76}], {
             RGBColor[
             0.23350932118742207`, 0.36276348028702554`, 0.9366093824443157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 81}], {
             RGBColor[
             0.25440003735864936`, 0.3847209475308929, 0.9377990778252221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 87}], {
             RGBColor[
             0.20973659970745412`, 0.3377768427339811, 0.9352555611246214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 89}], {
             RGBColor[
             0.2351425012723703, 0.3644800561059042, 0.93670238963408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 106}], {
             RGBColor[
             0.19390013127031533`, 0.3211317103164559, 0.9343536976750818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 107}], {
             RGBColor[
             0.21020159060141025`, 0.3382655776456545, 0.9352820416681398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 130}], {
             RGBColor[
             0.1935327654101925, 0.32074558550512594`, 0.9343327767328169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 131}], {
             RGBColor[
             0.19213265043958744`, 0.3192739758986036, 0.9342530422565254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 142}], {
             RGBColor[
             0.23238403787365935`, 0.361580736177178, 0.9365452992243044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 147}], {
             RGBColor[
             0.22614743845474522`, 0.3550256747646575, 0.9361901341136192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 149}], {
             RGBColor[
             0.1941370173040445, 0.32138069255734725`, 0.9343671879842612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 157}], {
             RGBColor[
             0.2045975584295754, 0.3323753845168943, 0.9349629003263764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 168}], {
             RGBColor[
             0.20608379372382724`, 0.3339375120439133, 0.935047539227696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 176}], {
             RGBColor[
             0.21842899524564835`, 0.34691310157433214`, 0.9357505801912747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 188}], {
             RGBColor[
             0.2579862693567474, 0.38807828505832953`, 0.9380183944910747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 189}], {
             RGBColor[
             0.19860085363697447`, 0.32607246756682684`, 0.9346213968597675]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 197}], {
             RGBColor[
             0.20173805393446126`, 0.32936986398947277`, 0.9348000557756375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 60}], {
             RGBColor[
             0.18536402715025152`, 0.3121597236660082, 0.9338675791734785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[
             0.20850897767362986`, 0.33648653414069934`, 0.935185649865899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 111}], {
             RGBColor[
             0.2049417486516364, 0.33273715026320094`, 0.934982501450339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 115}], {
             RGBColor[
             0.25238630356085545`, 0.3820238241610014, 0.9377056558638687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 163}], {
             RGBColor[
             0.2357550055079826, 0.36512383689254435`, 0.9367372708441793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 165}], {
             RGBColor[
             0.19777525937960444`, 0.32520471565663167`, 0.9345743804881674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 169}], {
             RGBColor[
             0.19092016970595993`, 0.3179995817718425, 0.9341839932724498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 58}], {
             RGBColor[
             0.9296752902178356, 0.8016782468054864, 0.5944321925119014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 68}], {
             RGBColor[
             0.9298826077939246, 0.7566572199616033, 0.27010292258186963`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 77}], {
             RGBColor[
             0.8580464518144618, 0.3836823814909788, 0.2007324013601752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 96}], {
             RGBColor[
             0.9175951806585165, 0.7926689208755102, 0.6148806669986575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 99}], {
             RGBColor[
             0.7252973005063621, 0.6401348451070372, 0.5975536479428364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 102}], {
             RGBColor[
             0.9339747756675465, 0.8048847960141194, 0.5871542851309398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[
             0.6650402658915442, 0.5906178095064059, 0.5929751287851128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 143}], {
             RGBColor[
             0.8772182848102179, 0.7604919813860003, 0.611670932866671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 166}], {
             RGBColor[
             0.8512516278317916, 0.7399182542257667, 0.6091593456597434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 172}], {
             RGBColor[
             0.8840573238836684, 0.5664132115032791, 0.22496692784453026`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 198}], {
             RGBColor[
             0.6221986923143263, 0.5535105917539171, 0.5902453016000886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 64}], {
             RGBColor[
             0.6702869821102313, 0.7421560430065834, 0.9679059544483493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 112}], {
             RGBColor[
             0.8262269535061243, 0.8650081965468237, 0.9779469895534628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 132}], {
             RGBColor[
             0.5058042387487333, 0.6037176098642293, 0.9561309549136163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 134}], {
             RGBColor[
             0.478958077481094, 0.5755005922270049, 0.9546021057447607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 153}], {
             RGBColor[
             0.49664985237205533`, 0.594095769360721, 0.9556096261521655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 156}], {
             RGBColor[
             0.7648803283778755, 0.4595346363622902, 0.5686955747885385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 183}], {
             RGBColor[
             0.823713544812509, 0.7798413316678898, 0.6197525703698252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 47}], {
             RGBColor[
             0.1896200136619846, 0.31663303533497, 0.934109951309154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 50}], {
             RGBColor[
             0.1933628575006826, 0.3205670015194474, 0.9343231007287265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 101}], {
             RGBColor[
             0.18958670352767176`, 0.3165980242718227, 0.9341080543462827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 105}], {
             RGBColor[
             0.19436779950481975`, 0.32162325928279867`, 0.9343803306891837]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 135}], {
             RGBColor[
             0.18995764910618526`, 0.3169879115941485, 0.9341291791482143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 144}], {
             RGBColor[
             0.19073384687984102`, 0.31780374466804207`, 0.9341733824631423]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 50}], {
             RGBColor[
             0.2000038325739316, 0.3275470873835711, 0.9347012944347058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 101}], {
             RGBColor[
             0.19622767860092072`, 0.3235781101359464, 0.934486248052262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 105}], {
             RGBColor[
             0.2010087745780687, 0.32860334514692235`, 0.934758524395163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 134}], {
             RGBColor[
             0.22156708062371444`, 0.3502114282727843, 0.9359292895111742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 135}], {
             RGBColor[
             0.19659862417943424`, 0.3239679974582722, 0.9345073728541936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 144}], {
             RGBColor[
             0.19737482195309003`, 0.32478383053216575`, 0.9345515761691217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 72}], {
             RGBColor[
             0.23184751916348642`, 0.3610168209955353, 0.9365147452774683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 76}], {
             RGBColor[
             0.23737108877035865`, 0.36682244286689847`, 0.9368293043951907]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 81}], {
             RGBColor[
             0.2582618049415859, 0.3887799101107659, 0.938018999776097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 87}], {
             RGBColor[
             0.21359836729039067`, 0.3418358053138541, 0.9354754830754963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 104}], {
             RGBColor[
             0.28879698411440874`, 0.4154790711874804, 0.939955479525905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 106}], {
             RGBColor[
             0.1977618988532519, 0.32519067289632886`, 0.9345736196259569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 147}], {
             RGBColor[
             0.2300092060376818, 0.3590846373445305, 0.9364100560644943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 154}], {
             RGBColor[
             0.2711822856025334, 0.4002221046769836, 0.9388330865127945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 157}], {
             RGBColor[
             0.20845932601251194`, 0.33643434709676723`, 0.9351828222772515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 158}], {
             RGBColor[
             0.2634190473924112, 0.39349797793107355`, 0.9383384198388076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 176}], {
             RGBColor[
             0.2222907628285849, 0.3509720641542051, 0.9359705021421497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 53}], {
             RGBColor[
             0.5270688387556056, 0.6260965211703475, 0.956144232988289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 54}], {
             RGBColor[
             0.7053736220772657, 0.7563760825874686, 0.6787707713186126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 65}], {
             RGBColor[
             0.6893465246568067, 0.7023129196468301, 0.6165085243035178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 69}], {
             RGBColor[
             0.33608426308955985`, 0.46007236766093923`, 0.9428354721479792]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 92}], {
             RGBColor[
             0.33340074855062923`, 0.45725182373587436`, 0.9426826499648912]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 118}], {
             RGBColor[
             0.4066109576924045, 0.5266077075173656, 0.9471298685655758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 119}], {
             RGBColor[
             0.634590175011373, 0.45058684488381917`, 0.5703034220716992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 123}], {
             RGBColor[
             0.43673943575620155`, 0.552703480914889, 0.949049628546234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 127}], {
             RGBColor[
             0.6485709500663741, 0.7216198574234791, 0.9680261155142653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[
             0.4384127064842775, 0.5541214790792388, 0.9491648974977769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 139}], {
             RGBColor[
             0.3540112919659183, 0.4789148116492719, 0.9438563899218253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 141}], {
             RGBColor[
             0.3830851867065078, 0.5062308671290127, 0.9456308272413769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 146}], {
             RGBColor[
             0.3338791466944457, 0.45775465051721964`, 0.9427098940314549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 155}], {
             RGBColor[
             0.5477722741141999, 0.6424322100267535, 0.9580969923209677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 171}], {
             RGBColor[
             0.36505233439370555`, 0.4905196472833987, 0.9444851609543292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 191}], {
             RGBColor[
             0.6162290328937537, 0.6959111502759776, 0.9649201222713306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 195}], {
             RGBColor[
             0.46169316726810605`, 0.5730216059163575, 0.9509976206498176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 196}], {
             RGBColor[
             0.3276703084677861, 0.4512287678779199, 0.9423563098795996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 199}], {
             RGBColor[
             0.7088075949120052, 0.7662760755555905, 0.8381694307308162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 97}], {
             RGBColor[
             0.21027301783359342`, 0.33834065219542714`, 0.9352861093433454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 101}], {
             RGBColor[
             0.19997052243961871`, 0.3275120763204238, 0.9346993974718347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 105}], {
             RGBColor[
             0.2047516184167667, 0.33253731133139974`, 0.9349716738147356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 134}], {
             RGBColor[
             0.22530992446241244`, 0.3541453944572617, 0.9361424389307468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 135}], {
             RGBColor[
             0.20034146801813224`, 0.3279019636427496, 0.9347205222737662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 144}], {
             RGBColor[
             0.20111766579178803`, 0.32871779671664314`, 0.9347647255886942]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 73}], {
             RGBColor[
             0.19983789794558066`, 0.3273726795683112, 0.9346918447030995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 87}], {
             RGBColor[
             0.19944978493815407`, 0.3269647481897199, 0.9346697422414884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 106}], {
             RGBColor[
             0.1836133165010153, 0.31031961577219463`, 0.9337678787919488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[
             0.1999147758321102, 0.3274534831013933, 0.9346962227850067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 130}], {
             RGBColor[
             0.18324595064089247`, 0.3099334909608647, 0.933746957849684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 131}], {
             RGBColor[
             0.18184583567028742`, 0.3084618813543424, 0.9336672233733925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 147}], {
             RGBColor[
             0.2158606236854452, 0.3442135802203963, 0.9356043152304863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 157}], {
             RGBColor[
             0.19431074366027534`, 0.32156328997263306`, 0.9343770814432435]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 168}], {
             RGBColor[
             0.1957969789545272, 0.32312541749965207`, 0.934461720344563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 189}], {
             RGBColor[
             0.18831403886767445`, 0.3152603730225656, 0.9340355779766345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 197}], {
             RGBColor[
             0.1914512391651612, 0.3185577694452115, 0.9342142368925045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 66}], {
             RGBColor[
             0.18456752137294713`, 0.3113225455926782, 0.9338222193477858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 80}], {
             RGBColor[
             0.20369103159656846`, 0.33142256733828307`, 0.9349112749643229]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 82}], {
             RGBColor[
             0.1987769890735687, 0.32625759707831903`, 0.9346314275123124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 100}], {
             RGBColor[
             0.1956898688928864, 0.3230128380336974, 0.9344556205850076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 120}], {
             RGBColor[
             0.1897634736745903, 0.3167838209041087, 0.9341181211446418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 124}], {
             RGBColor[
             0.20581307491926143`, 0.333652969415751, 0.9350321221922685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 125}], {
             RGBColor[
             0.2249359881773202, 0.35375236371269986`, 0.9361211438124999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 187}], {
             RGBColor[
             0.19453498240935546`, 0.32179897911547406`, 0.934389851508272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 54}], {
             RGBColor[
             0.810087981057518, 0.842228648704628, 0.6867819724356502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 65}], {
             RGBColor[
             0.7940608836370591, 0.7881654857639895, 0.6245197254205552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 69}], {
             RGBColor[
             0.4407986220698122, 0.5459249337780987, 0.9508466732650168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 92}], {
             RGBColor[
             0.4381151075308816, 0.5431043898530338, 0.9506938510819287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 118}], {
             RGBColor[
             0.5113253166726569, 0.612460273634525, 0.9551410696826135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 119}], {
             RGBColor[
             0.7393045339916254, 0.5364394110009786, 0.5783146231887367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 123}], {
             RGBColor[
             0.5414537947364539, 0.6385560470320484, 0.9570608296632714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 127}], {
             RGBColor[
             0.7532853090466265, 0.8074724235406385, 0.9760373166313029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 129}], {
             RGBColor[
             0.5431270654645298, 0.6399740451963982, 0.9571760986148143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 139}], {
             RGBColor[
             0.4587256509461706, 0.5647673777664313, 0.9518675910388628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 141}], {
             RGBColor[
             0.4877995456867602, 0.5920834332461721, 0.9536420283584146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 146}], {
             RGBColor[
             0.438593505674698, 0.543607216634379, 0.9507210951484925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 155}], {
             RGBColor[
             0.6524866330944523, 0.728284776143913, 0.9661081934380052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 171}], {
             RGBColor[
             0.4697666933739579, 0.5763722134005581, 0.9524963620713668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 182}], {
             RGBColor[
             0.48630804661931654`, 0.5907915717188752, 0.9535469913567178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 191}], {
             RGBColor[
             0.720943391874006, 0.781763716393137, 0.9729313233883682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 195}], {
             RGBColor[
             0.5664075262483584, 0.658874172033517, 0.9590088217668552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 196}], {
             RGBColor[
             0.43238466744803844`, 0.5370813339950793, 0.9503675109966372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 199}], {
             RGBColor[
             0.8135219538922576, 0.8521286416727499, 0.8461806318478537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 64}], {
             RGBColor[
             0.8089618730748239, 0.8413144235136905, 0.6866933210901831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 65}], {
             RGBColor[
             0.9723656669587191, 0.9184450471811106, 0.347146263750879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 118}], {
             RGBColor[
             0.6896300999943169, 0.7427398350516461, 0.6777676080129371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 119}], {
             RGBColor[
             0.9176093173132854, 0.6667189724180997, 0.30094116151906036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 123}], {
             RGBColor[
             0.7197585780581139, 0.7688356084491694, 0.6796873679935951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 127}], {
             RGBColor[
             0.9315900923682865, 0.9377519849577597, 0.6986638549616266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 140}], {
             RGBColor[
             0.9910580021453803, 0.9807455899537222, 0.48380004734696136`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 151}], {
             RGBColor[
             0.9911479730677677, 0.9821275166719952, 0.580056048665182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 155}], {
             RGBColor[
             0.8307914164161123, 0.8585643375610341, 0.688734731768329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 171}], {
             RGBColor[
             0.6480714766956179, 0.7066517748176793, 0.6751229004016905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 172}], {
             RGBColor[
             0.9288667542587956, 0.7360484350731749, 0.311047781867342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 191}], {
             RGBColor[
             0.899248175195666, 0.9120432778102582, 0.6955578617186919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 195}], {
             RGBColor[
             0.7447123095700184, 0.789153733450638, 0.681635360097179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 199}], {
             RGBColor[
             0.9918267372139176, 0.9824082030898711, 0.5688071701781774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 90}], {
             RGBColor[
             0.281574426125484, 0.41077439271759675`, 0.9394384697479637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 108}], {
             RGBColor[
             0.3219524714198415, 0.4532142784379034, 0.9417379396935124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 111}], {
             RGBColor[
             0.27800719710349053`, 0.40702500884009835`, 0.9392353213324036]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 115}], {
             RGBColor[
             0.3254517520127096, 0.4563116827378988, 0.9419584757459334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 163}], {
             RGBColor[
             0.3088204539598367, 0.4394116954694417, 0.9409900907262441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.2708407078314586, 0.3994925742335291, 0.9388272003702323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 175}], {
             RGBColor[
             0.4182247539712943, 0.5353839569381427, 0.9482243963930945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 177}], {
             RGBColor[
             0.2766340766323431, 0.4055817721640561, 0.9391571241529215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 183}], {
             RGBColor[
             0.6361311703010923, 0.6254168955585735, 0.6051471025896153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 109}], {
             RGBColor[
             0.19998929422011852`, 0.3275318066519287, 0.9347004664969638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 148}], {
             RGBColor[
             0.18807327130146562`, 0.31500731104493473`, 0.9340218666199227]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 150}], {
             RGBColor[
             0.18756580923325702`, 0.31447393623629405`, 0.933992967405861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 193}], {
             RGBColor[
             0.2060154437903921, 0.33386567193023686`, 0.9350436468001014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 88}], {
             RGBColor[
             0.1992012217508764, 0.32670349252007475`, 0.9346555869356892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 91}], {
             RGBColor[
             0.18403700151578473`, 0.31076493558589874`, 0.9337920070267542]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 103}], {
             RGBColor[
             0.1814602470714449, 0.3080566032892297, 0.9336452646731157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 117}], {
             RGBColor[
             0.18358120319676802`, 0.31028586265332964`, 0.9337660499867794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 121}], {
             RGBColor[
             0.1995963195919732, 0.32711876540171747`, 0.9346780871732447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 152}], {
             RGBColor[
             0.19101263224123774`, 0.3180967657588828, 0.9341892588770478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 164}], {
             RGBColor[
             0.1885063938143962, 0.3154625502675782, 0.9340465323062868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 178}], {
             RGBColor[
             0.1827435050835432, 0.30940538882320234`, 0.9337183443184945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 200}], {
             RGBColor[
             0.1862266556746971, 0.31306640093900795`, 0.9339167045918012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 77}], {
             RGBColor[
             0.8889478384033738, 0.5521228653145076, 0.5579177911517261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 96}], {
             RGBColor[
             0.9484965672474285, 0.961109404699039, 0.9720660567902085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 99}], {
             RGBColor[
             0.7561986870952739, 0.8085753289305662, 0.9547390377343874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 102}], {
             RGBColor[
             0.9648761622564584, 0.9733252798376484, 0.9443396749224908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 125}], {
             RGBColor[
             0.6124298936125201, 0.6826137072843086, 0.9449897432593624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 128}], {
             RGBColor[
             0.695941652480456, 0.7590582933299347, 0.9501605185766638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 137}], {
             RGBColor[
             0.6422345288762541, 0.7125398822624958, 0.9467383481519487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 166}], {
             RGBColor[
             0.8821530144207035, 0.9083587380492957, 0.9663447354512944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 170}], {
             RGBColor[
             0.8078923228953876, 0.8503457214275595, 0.9589431237256691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 192}], {
             RGBColor[
             0.7131454310850844, 0.7736227561744136, 0.951349727711992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 198}], {
             RGBColor[
             0.6531000789032383, 0.7219510755774461, 0.9474306913916395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 62}], {
             RGBColor[
             0.19206220882201708`, 0.3191999372922807, 0.9342490307106137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 92}], {
             RGBColor[
             0.21433501599530952`, 0.3426100698089493, 0.9355174341294674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 114}], {
             RGBColor[
             0.1828190891221793, 0.3094848324401137, 0.9337226487176782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 146}], {
             RGBColor[
             0.21481341413912597`, 0.34311289659029465`, 0.935544678196031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 184}], {
             RGBColor[
             0.1830159493280225, 0.30969174499811286`, 0.9337338596151724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 186}], {
             RGBColor[
             0.18364549933831636`, 0.3103534419747078, 0.9337697115569229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[
             0.19287248204991897`, 0.32005158582909543`, 0.934295174572251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 90}], {
             RGBColor[
             0.2041256683004301, 0.33187939807160033`, 0.9349360268816205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 111}], {
             RGBColor[
             0.20055843927843664`, 0.3281300141941019, 0.9347328784660603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 165}], {
             RGBColor[
             0.1933919500064047, 0.32059757958753266`, 0.9343247575038889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 169}], {
             RGBColor[
             0.18653686033276015`, 0.3133924457027435, 0.9339343702881713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 67}], {
             RGBColor[
             0.2316153172023224, 0.36077276201189723`, 0.936501521719292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 79}], {
             RGBColor[
             0.20075917656457537`, 0.3283410018093128, 0.9347443101575417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 84}], {
             RGBColor[
             0.19428775253280067`, 0.3215391248399355, 0.9343757721325461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 122}], {
             RGBColor[
             0.24263213866310665`, 0.37235213987400595`, 0.9371289134035569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 126}], {
             RGBColor[
             0.19350305800530745`, 0.3207143611390335, 0.9343310849400568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 179}], {
             RGBColor[
             0.2879403991921272, 0.41444560530367136`, 0.9399115732194068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 190}], {
             RGBColor[
             0.1957633885191688, 0.3230901118223337, 0.9344598074189618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 192}], {
             RGBColor[
             0.33652735532483224`, 0.4561925991586039, 0.9431004906757697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 114}], {
             RGBColor[
             0.19065828327948256`, 0.31772432253305627`, 0.9341690792278882]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 141}], {
             RGBColor[
             0.2718586483084913, 0.3998286032950302, 0.9389120419161632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 149}], {
             RGBColor[
             0.19270262269030192`, 0.3198730528724325, 0.9342855013330051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 167}], {
             RGBColor[
             0.19961760381417978`, 0.3271411364687542, 0.9346792992782123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 184}], {
             RGBColor[
             0.19085514348532573`, 0.3179312350910555, 0.9341802901253824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 189}], {
             RGBColor[
             0.19716645902323188`, 0.3245648278819121, 0.9345397102085116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 194}], {
             RGBColor[
             0.2007116762072222, 0.32829107592203804`, 0.9347416050824608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 197}], {
             RGBColor[
             0.20030365932071864`, 0.327862224304558, 0.9347183691243814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 70}], {
             RGBColor[
             0.1913615767368444, 0.3184635285481242, 0.9342091307498555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 110}], {
             RGBColor[
             0.18589948479502594`, 0.3127225236006417, 0.9338980726942099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 132}], {
             RGBColor[
             0.24611904809652904`, 0.37601710277136, 0.9373274877373701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 138}], {
             RGBColor[
             0.20677310926701956`, 0.33466202638493814`, 0.9350867947281298]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 145}], {
             RGBColor[
             0.1909329030445121, 0.31801296531800116`, 0.9341847184172432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 153}], {
             RGBColor[
             0.23696466171985112`, 0.36639526226785174`, 0.9368061589759192]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 185}], {
             RGBColor[
             0.2118614125837917, 0.3400101557879294, 0.9353765660745497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 65}], {
             RGBColor[
             0.792934775654365, 0.787251260573052, 0.6244310740750881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 132}], {
             RGBColor[
             0.4650482384089718, 0.5716822037632778, 0.9522031318796592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 138}], {
             RGBColor[
             0.4257022995794623, 0.5303271273768558, 0.949962438870419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 153}], {
             RGBColor[
             0.4558938520322939, 0.5620603632597695, 0.9516818031182084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 156}], {
             RGBColor[
             0.724124328038114, 0.42749923026133874`, 0.5647677517545815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 182}], {
             RGBColor[
             0.48518193863662246`, 0.5898773465279377, 0.9534583400112507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 185}], {
             RGBColor[
             0.4307906028962345, 0.5356752567798472, 0.9502522102168389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 199}], {
             RGBColor[
             0.8123958459095635, 0.8512144164818124, 0.8460919805023865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 118}], {
             RGBColor[
             0.6736030025738579, 0.6886766721110076, 0.6155053609978421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 119}], {
             RGBColor[
             0.9015822198928265, 0.6126558094774612, 0.23867891450396542`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 123}], {
             RGBColor[
             0.7037314806376549, 0.7147724455085309, 0.6174251209785002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 127}], {
             RGBColor[
             0.9155629949478274, 0.8836888220171212, 0.6364016079465316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 140}], {
             RGBColor[
             0.9750309047249213, 0.9266824270130837, 0.4215378003318664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 151}], {
             RGBColor[
             0.9751208756473086, 0.9280643537313567, 0.5177938016500871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 155}], {
             RGBColor[
             0.8147643189956533, 0.8045011746203956, 0.6264724847532339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 156}], {
             RGBColor[
             0.887528121922009, 0.5046298539287588, 0.2252206944152773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 171}], {
             RGBColor[
             0.6320443792751589, 0.6525886118770408, 0.6128606533865955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 172}], {
             RGBColor[
             0.9128396568383367, 0.6819852721325363, 0.24878553485224705`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 191}], {
             RGBColor[
             0.8832210777752071, 0.8579801148696197, 0.6332956147035969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 195}], {
             RGBColor[
             0.7286852121495595, 0.7350905705099995, 0.6193731130820839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 199}], {
             RGBColor[
             0.9757996397934585, 0.9283450401492326, 0.5065449231630825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 78}], {
             RGBColor[
             0.18323872675967784`, 0.30992589820368766`, 0.9337465464603355]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 80}], {
             RGBColor[
             0.20266968703316796`, 0.3303490694451636, 0.9348531109023811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 82}], {
             RGBColor[
             0.1977556445101682, 0.32518409918519964`, 0.9345732634503707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[
             0.18802367047876978`, 0.3149551774354076, 0.9340190419264479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 100}], {
             RGBColor[
             0.1946685243294859, 0.3219393401405779, 0.9343974565230659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 113}], {
             RGBColor[
             0.1939997700984511, 0.32123643704229315`, 0.9343593719589416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 120}], {
             RGBColor[
             0.18874212911118976`, 0.3157103230109893, 0.9340599570827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 124}], {
             RGBColor[
             0.2047917303558609, 0.33257947152263156`, 0.9349739581303267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 136}], {
             RGBColor[
             0.2031791949691239, 0.33088459459052233`, 0.9348821266255843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 187}], {
             RGBColor[
             0.19351363784595493`, 0.32072548122235467`, 0.9343316874463302]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 79}], {
             RGBColor[
             0.22503396848065443`, 0.3538553472238142, 0.9361267236458259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 82}], {
             RGBColor[
             0.2339276106645956, 0.3632031290486195, 0.9366332034112368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 100}], {
             RGBColor[
             0.2308404904839133, 0.3599583700039979, 0.936457396483932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 122}], {
             RGBColor[
             0.26690693057918574`, 0.3978664852885073, 0.9385113268918411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 125}], {
             RGBColor[
             0.2600866097683471, 0.39069789568300034`, 0.9381229197114243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 137}], {
             RGBColor[
             0.289891245032081, 0.42062407066118745`, 0.9398715246040107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 166}], {
             RGBColor[
             0.5298097305765306, 0.6164429264479874, 0.9594779119033563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 170}], {
             RGBColor[
             0.45554903905121463`, 0.5584299098262512, 0.952076300177731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 179}], {
             RGBColor[
             0.3122151911082063, 0.43995995071817273`, 0.941293986707691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 192}], {
             RGBColor[
             0.36080214724091136`, 0.4817069445731053, 0.944482904164054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 71}], {
             RGBColor[
             0.6623649639352431, 0.6847752584173, 0.6236785616506062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 75}], {
             RGBColor[
             0.7315668061877028, 0.7433887217645079, 0.6284543351107399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 81}], {
             RGBColor[
             0.6335105972347094, 0.659531932623991, 0.6218491817852485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 102}], {
             RGBColor[
             0.9650834798325474, 0.9283042529937652, 0.6200104049924591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 127}], {
             RGBColor[
             0.9178893661581602, 0.8915362183675095, 0.645439120800334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 129}], {
             RGBColor[
             0.7077311225760636, 0.7240378400232692, 0.6265779027838456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 140}], {
             RGBColor[
             0.977357275935254, 0.934529823363472, 0.4305753131856688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 143}], {
             RGBColor[
             0.9083269889752188, 0.8839114383656459, 0.6445270527281901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 155}], {
             RGBColor[
             0.817090690205986, 0.812348570970784, 0.6355099976070364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 172}], {
             RGBColor[
             0.9151660280486694, 0.6898326684829248, 0.25782304770604947`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 188}], {
             RGBColor[
             0.6370968292328074, 0.6628892701514275, 0.6220684984511013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 86}], {
             RGBColor[
             0.22595538032998164`, 0.3548238094983426, 0.9361791966875385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 92}], {
             RGBColor[
             0.2471305318648358, 0.3770802363436254, 0.937385090241619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 118}], {
             RGBColor[
             0.32034074100661103`, 0.44643612012511674`, 0.9418323088423037]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 123}], {
             RGBColor[
             0.3504692190704081, 0.47253189352264, 0.9437520688229617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 139}], {
             RGBColor[
             0.2677410752801248, 0.398743224257023, 0.938558830198553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 146}], {
             RGBColor[
             0.24760893000865222`, 0.37758306312497075`, 0.9374123343081827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 171}], {
             RGBColor[
             0.27878211770791206`, 0.41034805989114986`, 0.939187601231057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 174}], {
             RGBColor[
             0.21992361240255348`, 0.34848403897044045`, 0.9358356964272725]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 186}], {
             RGBColor[
             0.21644101520784265`, 0.3448236085093839, 0.9356373676690746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 191}], {
             RGBColor[
             0.5299588162079603, 0.6157395628837288, 0.9596225625480584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 195}], {
             RGBColor[
             0.3754229505823126, 0.4928500185241086, 0.9457000609265455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 196}], {
             RGBColor[
             0.24140009178199262`, 0.37105718048567105`, 0.9370587501563274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 110}], {
             RGBColor[
             0.185588460386286, 0.31239561722696946`, 0.9338803603142515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 132}], {
             RGBColor[
             0.2458080236877891, 0.37569019639768786`, 0.9373097753574117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 138}], {
             RGBColor[
             0.2064620848582796, 0.334335120011266, 0.9350690823481714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.19062187863577218`, 0.31768605894432894`, 0.9341670060372848]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 185}], {
             RGBColor[
             0.21155038817505178`, 0.3396832494142572, 0.9353588536945914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 73}], {
             RGBColor[
             0.29060892456725834`, 0.41769434068172157`, 0.9400472867534765]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 75}], {
             RGBColor[
             0.4329404581640204, 0.5480873032405589, 0.9491738543179573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 76}], {
             RGBColor[
             0.3139935330397997, 0.4422730468561747, 0.9413790056115596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 81}], {
             RGBColor[
             0.334884249211027, 0.4642305141000421, 0.942568700992466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 87}], {
             RGBColor[
             0.29022081155983176`, 0.4172864093031303, 0.9400251842918653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 89}], {
             RGBColor[
             0.315626713124748, 0.4439896226750534, 0.9414720128013241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 107}], {
             RGBColor[
             0.2906858024537879, 0.41777514421480366`, 0.9400516648353837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 127}], {
             RGBColor[
             0.6192630181344778, 0.6962347998435606, 0.9661586400075515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 129}], {
             RGBColor[
             0.40910477455238126`, 0.5287364214993203, 0.947297421991063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 141}], {
             RGBColor[
             0.3537772547746116, 0.4808458095490941, 0.9437633517346631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 142}], {
             RGBColor[
             0.312868249726037, 0.44109030274632716`, 0.9413149223915483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 147}], {
             RGBColor[
             0.3066316503071229, 0.4345352413338067, 0.9409597572808632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 155}], {
             RGBColor[
             0.5184643421823038, 0.6170471524468351, 0.9562295168142538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 168}], {
             RGBColor[
             0.2865680055762049, 0.4134470786130624, 0.93981716239494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 188}], {
             RGBColor[
             0.33847048120912504`, 0.4675878516274786, 0.9427880176583188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 197}], {
             RGBColor[
             0.2822222657868389, 0.40887943055862197`, 0.9395696789428815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 76}], {
             RGBColor[
             0.25872488056116644`, 0.3892666319476351, 0.9380453712475731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 81}], {
             RGBColor[
             0.2796155967323937, 0.4112240991915025, 0.9392350666284796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 104}], {
             RGBColor[
             0.31015077590521656`, 0.43792326026821704`, 0.9411715463782875]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 143}], {
             RGBColor[
             0.5544319884729032, 0.6356036049331575, 0.9619129375714212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 144}], {
             RGBColor[
             0.22584498306262032`, 0.3547077749707548, 0.9361729097264804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 154}], {
             RGBColor[
             0.2925360773933412, 0.42266629375772025`, 0.940049153365177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 158}], {
             RGBColor[
             0.284772839183219, 0.41594216701181014`, 0.93955448669119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 160}], {
             RGBColor[
             0.3481960203596565, 0.4708761388050667, 0.9435957557128356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 176}], {
             RGBColor[
             0.2436445546193927, 0.37341625323494165`, 0.9371865689945322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 181}], {
             RGBColor[
             0.345687120645864, 0.46870305597394574`, 0.9434358908416056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 75}], {
             RGBColor[
             0.3598107668197179, 0.47630780402892936`, 0.9448230602136101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 87}], {
             RGBColor[
             0.2170911202155293, 0.3455069100915008, 0.9356743901875181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.2424970217804455, 0.37221012346342386`, 0.9371212186969768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 107}], {
             RGBColor[
             0.21755611110948542`, 0.34599564500317415`, 0.9357008707310365]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 130}], {
             RGBColor[
             0.20088728591826768`, 0.3284756528626456, 0.9347516057957137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 142}], {
             RGBColor[
             0.23973855838173452`, 0.36931080353469764`, 0.9369641282872011]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 147}], {
             RGBColor[
             0.23350195896282042`, 0.3627557421221772, 0.936608963176516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 149}], {
             RGBColor[
             0.2014915378121197, 0.32911075991486693`, 0.934786017047158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 157}], {
             RGBColor[
             0.21195207893765056`, 0.34010545187441393`, 0.9353817293892732]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 167}], {
             RGBColor[
             0.20840651893599757`, 0.33637884351118863`, 0.9351798149923649]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 168}], {
             RGBColor[
             0.2134383142319024, 0.3416675794014329, 0.9354663682905927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 188}], {
             RGBColor[
             0.26534078986482257`, 0.3958083524158491, 0.9384372235539715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 189}], {
             RGBColor[
             0.20595537414504966`, 0.3338025349243465, 0.9350402259226642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 197}], {
             RGBColor[
             0.20909257444253643`, 0.33709993134699245`, 0.9352188848385342]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 85}], {
             RGBColor[
             0.3082012500479231, 0.4378314678081793, 0.9409888580526407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 88}], {
             RGBColor[
             0.2812466810785635, 0.40950050680300143`, 0.9394538352255469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 93}], {
             RGBColor[
             0.28865865838495014`, 0.4172909648985178, 0.9398759363681078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 95}], {
             RGBColor[
             0.29756419393855826`, 0.4266512474089263, 0.9403830934433266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 121}], {
             RGBColor[
             0.28164177891966025`, 0.4099157796846441, 0.9394763354631025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 140}], {
             RGBColor[
             0.6698268935487197, 0.7315161778042003, 0.7507274751968138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 152}], {
             RGBColor[
             0.2730580915689248, 0.4008937800418094, 0.9389875071669056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 159}], {
             RGBColor[
             0.30041133141594933`, 0.42964376941660665`, 0.9405452337107016]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 161}], {
             RGBColor[
             0.31487926883859824`, 0.44485048896802515`, 0.9413691613435261]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 162}], {
             RGBColor[
             0.39867126833608224`, 0.5197307476573095, 0.9466239585805827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 164}], {
             RGBColor[
             0.2705518531420833, 0.3982595645505048, 0.9388447805961444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 172}], {
             RGBColor[
             0.607635645662135, 0.48681902292365303`, 0.5779752097171944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 173}], {
             RGBColor[
             0.35684188955631446`, 0.48350024216398235`, 0.9439586275530032]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 180}], {
             RGBColor[
             0.34398171160205027`, 0.4723614023913367, 0.9431391883855662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 81}], {
             RGBColor[
             0.40408609146348656`, 0.52284397744725, 0.9473444744525996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 89}], {
             RGBColor[
             0.3848285553772075, 0.5026030860222612, 0.9462477862614576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 118}], {
             RGBColor[
             0.44650486801296785`, 0.559836113284655, 0.9500381665189955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 127}], {
             RGBColor[
             0.6884648603869374, 0.7548482631907685, 0.9709344134676849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 129}], {
             RGBColor[
             0.47830661680484077`, 0.5873498848465282, 0.9520731954511965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 141}], {
             RGBColor[
             0.42297909702707115`, 0.5394592728963019, 0.9485391251947967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 142}], {
             RGBColor[
             0.3820700919784965, 0.49970376609353495`, 0.9460906958516819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 147}], {
             RGBColor[
             0.3758334925595824, 0.4931487046810145, 0.9457355307409967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 155}], {
             RGBColor[
             0.5876661844347633, 0.6756606157940428, 0.9610052902743873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 168}], {
             RGBColor[
             0.3557698478286644, 0.47206054196027025`, 0.9445929358550735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 188}], {
             RGBColor[
             0.40767232346158455`, 0.5262013149746865, 0.9475637911184522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 191}], {
             RGBColor[
             0.656122943214317, 0.729139556043267, 0.9678284202247502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 81}], {
             RGBColor[
             0.28513916633926595`, 0.41702972106286573`, 0.9395496257462019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 87}], {
             RGBColor[
             0.2404757286880707, 0.37008561626595393`, 0.9370061090456012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 89}], {
             RGBColor[
             0.2658816302529869, 0.396788829637877, 0.93845293755506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[
             0.3156743455120887, 0.4437288821395802, 0.9414861054960099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 106}], {
             RGBColor[
             0.2246392602509319, 0.35344048384842863`, 0.9361042455960618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 107}], {
             RGBColor[
             0.2409407195820268, 0.37057435117762727`, 0.9370325895891196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 142}], {
             RGBColor[
             0.26312316685427595`, 0.39388950970915076`, 0.9382958471452842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 143}], {
             RGBColor[
             0.5599555580797754, 0.6414092268045206, 0.9622274966891435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 147}], {
             RGBColor[
             0.2568865674353618, 0.38733444829663033`, 0.9379406820345992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 154}], {
             RGBColor[
             0.29805964700021337`, 0.42847191562908343`, 0.9403637124828994]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[
             0.23533668741019195`, 0.36468415804886706`, 0.9367134482473564]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 158}], {
             RGBColor[
             0.2902964087900912, 0.4217477888831733, 0.9398690458089125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 176}], {
             RGBColor[
             0.24916812422626491`, 0.3792218751063049, 0.9375011281122546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 181}], {
             RGBColor[
             0.3512106902527362, 0.4745086778453089, 0.9437504499593281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 188}], {
             RGBColor[
             0.288725398337364, 0.42038705859030223`, 0.9397689424120548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 83}], {
             RGBColor[
             0.8718524916829569, 0.5391330266655409, 0.5785293580798063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 96}], {
             RGBColor[
             0.8768677288440547, 0.5431135393845314, 0.5783662656384824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 99}], {
             RGBColor[
             0.6845698486919003, 0.3905794636160585, 0.5610392465826612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 112}], {
             RGBColor[
             0.8793649622811279, 0.5449759719930563, 0.5741391008123097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 143}], {
             RGBColor[
             0.8364908329957561, 0.5109365998950215, 0.5751565315064958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 156}], {
             RGBColor[
             0.8180183371528791, 0.13950241180852277`, 0.1648876860473853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 160}], {
             RGBColor[
             0.6302548648825095, 0.34620913376693074`, 0.5568393496479103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 166}], {
             RGBColor[
             0.8105241760173298, 0.490362872734788, 0.5726449442995682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 170}], {
             RGBColor[
             0.736263484492014, 0.4323498561130519, 0.5652433325739429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 181}], {
             RGBColor[
             0.627745965168717, 0.3440360509358098, 0.5566794847766803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 183}], {
             RGBColor[
             0.8768515535875127, 0.45980910711412243`, 0.21594468162867203`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 192}], {
             RGBColor[
             0.6415165926817106, 0.355626890859906, 0.5576499365602658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 80}], {
             RGBColor[
             0.20236223698329917`, 0.33002591994929253`, 0.9348356020768727]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 82}], {
             RGBColor[
             0.1974481944602994, 0.3248609496893285, 0.9345557546248622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 98}], {
             RGBColor[
             0.18771622042890102`, 0.3146320279395365, 0.9340015331009395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 100}], {
             RGBColor[
             0.1943610742796171, 0.3216161906447068, 0.9343799476975574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 113}], {
             RGBColor[
             0.19369232004858233`, 0.320913287546422, 0.9343418631334333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 120}], {
             RGBColor[
             0.188434679061321, 0.31538717351511814`, 0.9340424482571915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 124}], {
             RGBColor[
             0.20448428030599214`, 0.3322563220267605, 0.9349564493048182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 136}], {
             RGBColor[
             0.2028717449192551, 0.3305614450946512, 0.9348646178000759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 187}], {
             RGBColor[
             0.19320618779608617`, 0.3204023317264835, 0.9343141786208218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 84}], {
             RGBColor[
             0.1877064038111327, 0.31462171005185247`, 0.93400097405908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 122}], {
             RGBColor[
             0.2360507899414387, 0.3654347250859229, 0.9367541153300909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 126}], {
             RGBColor[
             0.1869217092836395, 0.3137969463509505, 0.9339562868665908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 177}], {
             RGBColor[
             0.20578387384021699`, 0.33362227723022, 0.9350304592340161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 179}], {
             RGBColor[
             0.2813590504704592, 0.4075281905155883, 0.9395367751459407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 190}], {
             RGBColor[
             0.18918203979750087`, 0.31617269703425077`, 0.9340850093454959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 82}], {
             RGBColor[
             0.2168791547337895, 0.3452841209308045, 0.9356623190669078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 98}], {
             RGBColor[
             0.2071471807023911, 0.33505519918101245`, 0.9351080975429851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 100}], {
             RGBColor[
             0.2137920345531072, 0.3420393618861828, 0.935486512139603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 113}], {
             RGBColor[
             0.2131232803220724, 0.34133645878789803`, 0.9354484275754789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 116}], {
             RGBColor[
             0.23121046425376574`, 0.3603472358938047, 0.936478465942798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 120}], {
             RGBColor[
             0.20786563933481106`, 0.33581034475659416`, 0.9351490126992371]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 124}], {
             RGBColor[
             0.22391524057948223`, 0.35267949326823644`, 0.9360630137468638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 125}], {
             RGBColor[
             0.243038153837541, 0.3727788875651853, 0.9371520353670952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 136}], {
             RGBColor[
             0.2223027051927452, 0.3509846163361272, 0.9359711822421215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 137}], {
             RGBColor[
             0.2728427891012749, 0.40270506254337235`, 0.9389006402596817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 187}], {
             RGBColor[
             0.21263714806957626`, 0.34082550296795955`, 0.9354207430628674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 198}], {
             RGBColor[
             0.28370833912825916`, 0.4121162558583227, 0.9395929834993725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 87}], {
             RGBColor[
             0.261366444859298, 0.3920430835098213, 0.9381958044265076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 89}], {
             RGBColor[
             0.2867723464242142, 0.41874629688174436`, 0.9396426329359664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 104}], {
             RGBColor[
             0.336565061683316, 0.46568634938344766`, 0.9426758008769163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 107}], {
             RGBColor[
             0.26183143575325407`, 0.39253181842149465`, 0.938222284970026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 142}], {
             RGBColor[
             0.28401388302550323`, 0.4158469769530182, 0.9394855425261907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 143}], {
             RGBColor[
             0.5808462742510027, 0.663366694048388, 0.9634171920700499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 147}], {
             RGBColor[
             0.2777772836065891, 0.4092919155404977, 0.9391303774155055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 154}], {
             RGBColor[
             0.31895036317144065`, 0.45042938287295087`, 0.9415534078638058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 157}], {
             RGBColor[
             0.25622740358141927`, 0.3866416252927345, 0.9379031436282628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 158}], {
             RGBColor[
             0.3111871249613185, 0.44370525612704076`, 0.9410587411898188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 168}], {
             RGBColor[
             0.2577136388756711, 0.38820375281975344`, 0.9379877825295823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 176}], {
             RGBColor[
             0.2700588403974922, 0.4011793423501723, 0.938690823493161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 188}], {
             RGBColor[
             0.3096161145085913, 0.44234452583416967`, 0.9409586377929611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 98}], {
             RGBColor[
             0.20223313817939134`, 0.32989022892104847`, 0.9348282500909746]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 100}], {
             RGBColor[
             0.20887799203010743`, 0.3368743916262188, 0.9352066646875926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 120}], {
             RGBColor[
             0.2029515968118113, 0.3306453744966301, 0.9348691652472267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 124}], {
             RGBColor[
             0.21900119805648247`, 0.34751452300827246`, 0.9357831662948535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 125}], {
             RGBColor[
             0.23812411131454123`, 0.3676139173052213, 0.9368721879150849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 136}], {
             RGBColor[
             0.21738866266974544`, 0.34581964607616317`, 0.935691334790111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 137}], {
             RGBColor[
             0.26792874657827515`, 0.39754009228340836`, 0.9386207928076713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 187}], {
             RGBColor[
             0.2077231055465765, 0.3356605327079955, 0.9351408956108569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 198}], {
             RGBColor[
             0.2787942966052594, 0.4069512855983587, 0.9393131360473621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 122}], {
             RGBColor[
             0.6021548677029418, 0.6767924582408489, 0.9659897173678593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 156}], {
             RGBColor[
             0.8725518288358358, 0.5445084384740636, 0.5791990441271917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 166}], {
             RGBColor[
             0.8650576677002866, 0.8953688994003288, 0.9869563023793746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 170}], {
             RGBColor[
             0.7907969761749707, 0.8373558827785927, 0.9795546906537492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 175}], {
             RGBColor[
             0.7134786289406714, 0.7747821951592325, 0.9733333335119576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 179}], {
             RGBColor[
             0.6474631282319623, 0.7188859236705143, 0.9687723771837091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 183}], {
             RGBColor[
             0.9313850452704695, 0.8648151337796632, 0.6302560397084783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 192}], {
             RGBColor[
             0.6960500843646674, 0.7606329175254469, 0.9719612946400722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 126}], {
             RGBColor[
             0.1804502852518648, 0.30699506938157317`, 0.9335877488415951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 190}], {
             RGBColor[
             0.18271061576572617`, 0.30937082006487343`, 0.9337164713205002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 88}], {
             RGBColor[
             0.24351738394062986`, 0.3732825887884752, 0.9371793268125088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 117}], {
             RGBColor[
             0.22789736538652144`, 0.3568649589217301, 0.9362897898635989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[
             0.24391248178172664`, 0.37369786167011787`, 0.9372018270500644]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 133}], {
             RGBColor[
             0.25979757259338154`, 0.39039409928609614`, 0.9381064594719022]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 140}], {
             RGBColor[
             0.632097596410786, 0.6952982597896742, 0.7484529667837756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 152}], {
             RGBColor[
             0.2353287944309912, 0.36467586202728325`, 0.9367129987538674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 159}], {
             RGBColor[
             0.26268203427801573`, 0.3934258514020805, 0.9382707252976634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 161}], {
             RGBColor[
             0.2771499717006646, 0.408632570953499, 0.939094652930488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 173}], {
             RGBColor[
             0.31911259241838086`, 0.4472823241494562, 0.941684119139965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 200}], {
             RGBColor[
             0.23054281786445055`, 0.35964549720740835`, 0.9364404444686207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 92}], {
             RGBColor[
             0.22327186579105107`, 0.35200326557327766`, 0.9360263745044504]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[
             0.19625374198187168`, 0.3236055044018397, 0.9344877323232499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 171}], {
             RGBColor[
             0.25492345163412733`, 0.3852710891208021, 0.9378288854938884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 174}], {
             RGBColor[
             0.19606494632876875`, 0.3234070682000927, 0.9344769806901039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 196}], {
             RGBColor[
             0.2175414257082079, 0.3459802097153233, 0.9357000344191588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 89}], {
             RGBColor[
             0.24210890877301894`, 0.37180219208483256`, 0.9370991162353657]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 106}], {
             RGBColor[
             0.20086653877096394`, 0.3284538462953842, 0.9347504242763673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 107}], {
             RGBColor[
             0.21716799810205883`, 0.34558771362458285`, 0.9356787682694253]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 130}], {
             RGBColor[
             0.20049917291084113`, 0.3280677214840543, 0.9347295033341025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 131}], {
             RGBColor[
             0.19909905794023608`, 0.326596111877532, 0.934649768857811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 142}], {
             RGBColor[
             0.23935044537430794`, 0.3689028721561064, 0.9369420258255899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 147}], {
             RGBColor[
             0.23311384595539386`, 0.3623478107435859, 0.9365868607149048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[
             0.2742869255202454, 0.40348527807603907`, 0.9390098911632051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 157}], {
             RGBColor[
             0.21156396593022397`, 0.3396975204958227, 0.9353596269276621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 168}], {
             RGBColor[
             0.21305020122447582`, 0.34125964802284164`, 0.9354442658289815]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 176}], {
             RGBColor[
             0.22539540274629694`, 0.3542352375532605, 0.9361473067925603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 188}], {
             RGBColor[
             0.264952676857396, 0.39540042103725787`, 0.9384151210923604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 91}], {
             RGBColor[
             0.20139859473617852`, 0.32901307084912135`, 0.93478072407648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 93}], {
             RGBColor[
             0.22397479227765688`, 0.3527420858788138, 0.936066405127976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 95}], {
             RGBColor[
             0.23288032783126497`, 0.3621023683892223, 0.9365735622031948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 103}], {
             RGBColor[
             0.1988218402918387, 0.32630473855245234`, 0.9346339817228415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 117}], {
             RGBColor[
             0.2009427964171618, 0.32853399791655225`, 0.9347547670365053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 121}], {
             RGBColor[
             0.21695791281236698`, 0.34536690066494, 0.9356668042229707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 152}], {
             RGBColor[
             0.20837422546163153`, 0.3363449010221054, 0.9351779759267738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 159}], {
             RGBColor[
             0.23572746530865607`, 0.3650948903969026, 0.9367357024705698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 161}], {
             RGBColor[
             0.25019540273130497`, 0.38030160994832113`, 0.9375596301033943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 164}], {
             RGBColor[
             0.20586798703479003`, 0.3337106855308008, 0.9350352493560126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 173}], {
             RGBColor[
             0.2921580234490212, 0.41895136314427833`, 0.9401490963128714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 180}], {
             RGBColor[
             0.279297845494757, 0.4078125233716327, 0.9393296571454344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 200}], {
             RGBColor[
             0.20358824889509092`, 0.3313145362022305, 0.9349054216415271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 106}], {
             RGBColor[
             0.22627244033588012`, 0.3551570596673073, 0.9361972527858261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 107}], {
             RGBColor[
             0.24257389966697504`, 0.37229092699650596`, 0.9371255967788841]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 142}], {
             RGBColor[
             0.2647563469392241, 0.39560608552802945`, 0.9383888543350487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 147}], {
             RGBColor[
             0.25851974752031004`, 0.38905102411550896`, 0.9380336892243635]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 154}], {
             RGBColor[
             0.29969282708516165`, 0.4301884914479621, 0.9404567196726639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 157}], {
             RGBColor[
             0.23696986749514018`, 0.36640073386774574`, 0.9368064554371207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 168}], {
             RGBColor[
             0.23845610278939203`, 0.36796286139476475`, 0.9368910943384403]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 176}], {
             RGBColor[
             0.25080130431121317`, 0.3809384509251836, 0.937594135302019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 188}], {
             RGBColor[
             0.29035857842231216`, 0.42210363440918097`, 0.939861949601819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 111}], {
             RGBColor[
             0.22370338980181498`, 0.3524568246687931, 0.9360509491584807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 115}], {
             RGBColor[
             0.27114794471103404`, 0.4017434985665935, 0.9387741035720105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 163}], {
             RGBColor[
             0.2545166466581612, 0.38484351129813643`, 0.9378057185523212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 165}], {
             RGBColor[
             0.21653690052978303`, 0.3449243900622238, 0.9356428281963094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 169}], {
             RGBColor[
             0.20968181085613852`, 0.3377192561774346, 0.9352524409805917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 175}], {
             RGBColor[
             0.36392094666961883`, 0.4808157727668374, 0.9450400242191717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 177}], {
             RGBColor[
             0.22233026933066752`, 0.35101358799275084`, 0.9359727519789987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 103}], {
             RGBColor[
             0.18365762005674702`, 0.31036618161827634`, 0.9337704018139066]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 117}], {
             RGBColor[
             0.1857785761820701, 0.31259544098237624`, 0.9338911871275704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 121}], {
             RGBColor[
             0.2017936925772753, 0.329428343730764, 0.9348032243140356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 152}], {
             RGBColor[
             0.19321000522653986`, 0.3204063440879294, 0.9343143960178388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 159}], {
             RGBColor[
             0.22056324507356437`, 0.3491563334627266, 0.9358721225616348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 164}], {
             RGBColor[
             0.19070376679969833`, 0.3177721285966248, 0.9341716694470776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 200}], {
             RGBColor[
             0.18842402865999922`, 0.3153759792680545, 0.9340418417325922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 118}], {
             RGBColor[
             0.31765722646768046`, 0.4436155762000519, 0.9416794866592155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 123}], {
             RGBColor[
             0.34778570453147756`, 0.4697113495975751, 0.9435992466398737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 139}], {
             RGBColor[
             0.26505756074119424`, 0.3959226803319581, 0.938406008015465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 141}], {
             RGBColor[
             0.29413145548178377`, 0.42323873581169885`, 0.9401804453350167]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 146}], {
             RGBColor[
             0.24492541546972163`, 0.3747625191999059, 0.9372595121250946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 171}], {
             RGBColor[
             0.2760986031689815, 0.40752751596608494`, 0.939034779047969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 174}], {
             RGBColor[
             0.2172400978636229, 0.3456634950453756, 0.9356828742441843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 186}], {
             RGBColor[
             0.21375750066891208`, 0.34200306458431906`, 0.9354845454859864]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 191}], {
             RGBColor[
             0.5272753016690297, 0.6129190189586639, 0.9594697403649703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 195}], {
             RGBColor[
             0.372739436043382, 0.49002947459904367`, 0.9455472387434574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 196}], {
             RGBColor[
             0.23871657724306206`, 0.3682366365606061, 0.9369059279732393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 95}], {
             RGBColor[
             0.24029230513765162`, 0.36989282648473865`, 0.9369956633457557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 121}], {
             RGBColor[
             0.22436989011875363`, 0.3531573587604565, 0.9360889053655316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 150}], {
             RGBColor[
             0.21197440955790398`, 0.3401289227721434, 0.9353830010850614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 159}], {
             RGBColor[
             0.24313944261504272`, 0.37288534849241906`, 0.9371578036131307]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 161}], {
             RGBColor[
             0.2576073800376916, 0.38809206804383756`, 0.9379817312459552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 162}], {
             RGBColor[
             0.34139937953517563`, 0.46297232673312194`, 0.9432365284830118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 164}], {
             RGBColor[
             0.2132799643411767, 0.3415011436263172, 0.9354573504985735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 173}], {
             RGBColor[
             0.29957000075540785`, 0.42674182123979476`, 0.9405711974554323]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 180}], {
             RGBColor[
             0.28670982280114365`, 0.41560298146714914`, 0.9397517582879953]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 200}], {
             RGBColor[
             0.21100022620147757`, 0.339104994297747, 0.935327522784088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 174}], {
             RGBColor[
             0.19022197405444352`, 0.31726573387393764`, 0.9341442320629838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 196}], {
             RGBColor[
             0.21169845343388266`, 0.3398388753891681, 0.9353672857920389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 121}], {
             RGBColor[
             0.23327542567236176`, 0.36251764127086494`, 0.9365960624407503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 150}], {
             RGBColor[
             0.2208799451115121, 0.3494892052825519, 0.9358901581602801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 159}], {
             RGBColor[
             0.2520449781686508, 0.3822456310028275, 0.9376649606883494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 161}], {
             RGBColor[
             0.26651291559129975`, 0.397452350554246, 0.9384888883211739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 162}], {
             RGBColor[
             0.35030491508878375`, 0.4723326092435304, 0.9437436855582304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 164}], {
             RGBColor[
             0.22218549989478478`, 0.35086142613672566`, 0.9359645075737923]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 173}], {
             RGBColor[
             0.308475536309016, 0.4361021037502032, 0.9410783545306509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 180}], {
             RGBColor[
             0.2956153583547517, 0.42496326397755757`, 0.9402589153632142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 99}], {
             RGBColor[
             0.7441185775359549, 0.79956600300059, 0.9751875122211435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 102}], {
             RGBColor[
             0.9527960526971394, 0.9643159539076722, 0.964788149409247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 125}], {
             RGBColor[
             0.600349784053201, 0.6736043813543324, 0.9654382177461185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 128}], {
             RGBColor[
             0.683861542921137, 0.7500489673999585, 0.97060899306342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 137}], {
             RGBColor[
             0.630154419316935, 0.7035305563325196, 0.9671868226387048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 166}], {
             RGBColor[
             0.8700729048613844, 0.8993494121193195, 0.9867932099380505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 170}], {
             RGBColor[
             0.7958122133360686, 0.8413363954975833, 0.9793915982124253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 198}], {
             RGBColor[
             0.6410199693439192, 0.7129417496474699, 0.9678791658783956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 105}], {
             RGBColor[
             0.21127795983773054`, 0.3393969099587784, 0.9353433393038026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 134}], {
             RGBColor[
             0.23183626588337625`, 0.3610049930846403, 0.9365141044198138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 135}], {
             RGBColor[
             0.20686780943909605`, 0.33476156227012827`, 0.9350921877628332]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 153}], {
             RGBColor[
             0.24952804077433757`, 0.37960017021835646`, 0.9375216248272185]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 100}], {
             RGBColor[
             0.19914601799870904`, 0.3266454698764268, 0.9346524431636698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 109}], {
             RGBColor[
             0.2049550918267402, 0.33275117478624117`, 0.9349832613244216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 113}], {
             RGBColor[
             0.19847726376767427`, 0.32594256677814204`, 0.9346143585995457]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 116}], {
             RGBColor[
             0.21656444769936758`, 0.34495334388404864`, 0.9356443969668649]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 120}], {
             RGBColor[
             0.19321962278041294`, 0.32041645274683817`, 0.9343149437233039]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 124}], {
             RGBColor[
             0.20926922402508408`, 0.3372856012584804, 0.9352289447709307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 125}], {
             RGBColor[
             0.22839213728314284`, 0.35738499555542924`, 0.936317966391162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 136}], {
             RGBColor[
             0.20765668863834705`, 0.33559072432637116`, 0.9351371132661883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 187}], {
             RGBColor[
             0.1979911315151781, 0.3254316109582035, 0.9345866740869342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 102}], {
             RGBColor[
             0.7604981725449849, 0.8117818781391992, 0.9474611303534258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 109}], {
             RGBColor[
             0.38461485844464394`, 0.49643648481667146`, 0.9467764936235569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 116}], {
             RGBColor[
             0.39622421431727134`, 0.5086386539144789, 0.9474376292660001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 128}], {
             RGBColor[
             0.49156366276898256`, 0.5975148916314856, 0.9532819740075988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 136}], {
             RGBColor[
             0.3873164552562508, 0.49927603435680146`, 0.9469303455653235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 137}], {
             RGBColor[
             0.4378565391647805, 0.5509964805640466, 0.9498598035828838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 162}], {
             RGBColor[
             0.5016163434350541, 0.6062220183620153, 0.9539225219304044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 193}], {
             RGBColor[
             0.3906410080149175, 0.5027703500949796, 0.9471196739266945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 198}], {
             RGBColor[
             0.44872208919176476`, 0.5604076738789969, 0.9505521468225746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 113}], {
             RGBColor[
             0.20512211761839033`, 0.33292672948331237`, 0.9349927731961636]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 120}], {
             RGBColor[
             0.199864476631129, 0.3274006154520085, 0.934693358319922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 124}], {
             RGBColor[
             0.21591407787580016`, 0.3442697639636507, 0.9356073593675487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 125}], {
             RGBColor[
             0.23503699113385892`, 0.36436915826059957`, 0.9366963809877801]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 136}], {
             RGBColor[
             0.21430154248906313`, 0.3425748870315415, 0.9355155278628062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 137}], {
             RGBColor[
             0.26484162639759284`, 0.3942953332387867, 0.9384449858803665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 187}], {
             RGBColor[
             0.2046359853658942, 0.3324157736633738, 0.9349650886835521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 198}], {
             RGBColor[
             0.2757071764245771, 0.40370652655373696`, 0.9391373291200573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 105}], {
             RGBColor[
             0.20097546444375586`, 0.32856833408377506`, 0.9347566274322918]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 134}], {
             RGBColor[
             0.22153377048940157`, 0.350176417209637, 0.9359273925483029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 135}], {
             RGBColor[
             0.1965653140451214, 0.3239329863951249, 0.9345054758913225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 144}], {
             RGBColor[
             0.19734151181877715`, 0.32474881946901846`, 0.9345496792062504]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 128}], {
             RGBColor[
             0.700241137930167, 0.7622648425385679, 0.9428826111957023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 140}], {
             RGBColor[
             0.981449443808876, 0.9827573994159884, 0.747626675734739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 162}], {
             RGBColor[
             0.7102938185962386, 0.7709719692690975, 0.9435231591185078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 172}], {
             RGBColor[
             0.9192581959222914, 0.7380602445354411, 0.5748744102551196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 180}], {
             RGBColor[
             0.6556042618622065, 0.7236026240031248, 0.9400383889234916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 117}], {
             RGBColor[
             0.1832018217377303, 0.30988710868570724`, 0.9337444447739318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 152}], {
             RGBColor[
             0.19063325078220003`, 0.31769801179126034`, 0.9341676536642003]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 178}], {
             RGBColor[
             0.1823641236245055, 0.3090066348555799, 0.933696739105647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 200}], {
             RGBColor[
             0.18584727421565939`, 0.3126676469713855, 0.9338950993789537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 143}], {
             RGBColor[
             0.6113814534238254, 0.6900658551251025, 0.9653536718198579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 154}], {
             RGBColor[
             0.3494855423442635, 0.47712854394966536`, 0.9434898876136137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 158}], {
             RGBColor[
             0.3417223041341413, 0.47040441720375525`, 0.9429952209396267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 160}], {
             RGBColor[
             0.4051454853105788, 0.5253383889970118, 0.9470364899612722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 176}], {
             RGBColor[
             0.300594019570315, 0.4278785034268868, 0.9406273032429688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 181}], {
             RGBColor[
             0.4026365855967863, 0.5231653061658909, 0.9468766250900423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 188}], {
             RGBColor[
             0.34015129368141406`, 0.46904368691088416`, 0.9428951175427689]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 134}], {
             RGBColor[
             0.22631486646654955`, 0.35520165222061295`, 0.936199668891204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 135}], {
             RGBColor[
             0.20134641002226938`, 0.32895822140610087`, 0.9347777522342233]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 144}], {
             RGBColor[
             0.20212260779592514`, 0.3297740544799944, 0.9348219555491514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.20133152966492007`, 0.3289425812070576, 0.9347769048198857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 130}], {
             RGBColor[
             0.1846627044737023, 0.31142258906652903`, 0.933827639884563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 131}], {
             RGBColor[
             0.18326258950309726`, 0.3099509794600067, 0.9337479054082716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 142}], {
             RGBColor[
             0.22351397693716918`, 0.3522577397385811, 0.9360401623760504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 147}], {
             RGBColor[
             0.21727737751825504`, 0.3457026783260606, 0.9356849972653654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 157}], {
             RGBColor[
             0.1957274974930852, 0.3230523880782974, 0.9344577634781225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 176}], {
             RGBColor[
             0.20955893430915817`, 0.33759010513573523`, 0.9352454433430207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 130}], {
             RGBColor[
             0.20096416380479723`, 0.32855645639572767`, 0.9347559838776209]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 131}], {
             RGBColor[
             0.19956404883419218`, 0.32708484678920535`, 0.9346762494013294]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 142}], {
             RGBColor[
             0.23981543626826407`, 0.36939160706777974`, 0.9369685063691083]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[
             0.23357883684934996`, 0.36283654565525925`, 0.9366133412584232]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 154}], {
             RGBColor[
             0.27475191641420155`, 0.4039740129877124, 0.9390363717067235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.2120289568241801, 0.34018625540749603`, 0.9353861074711805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 168}], {
             RGBColor[
             0.21351519211843195`, 0.34174838293451504`, 0.9354707463724999]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 176}], {
             RGBColor[
             0.22586039364025307`, 0.35472397246493387`, 0.9361737873360787]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 188}], {
             RGBColor[
             0.2654176677513521, 0.39588915594893126`, 0.9384416016358788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 111}], {
             RGBColor[
             0.26408143509617243`, 0.39489671038909974`, 0.9383504191040295]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 115}], {
             RGBColor[
             0.3115259900053915, 0.4441833842869002, 0.9410735735175593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 133}], {
             RGBColor[
             0.27857495084464845`, 0.41013031438272207`, 0.9391758033846701]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 151}], {
             RGBColor[
             0.6509649455844404, 0.716416401604573, 0.8457783120147642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 163}], {
             RGBColor[
             0.29489469195251866`, 0.4272833970184431, 0.94010518849787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 165}], {
             RGBColor[
             0.25691494582414054`, 0.38736427578253046`, 0.937942298141858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 175}], {
             RGBColor[
             0.4042989919639763, 0.5232556584871441, 0.9473394941647204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 113}], {
             RGBColor[
             0.2109311914464215, 0.33903243439312675`, 0.9353235913569153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 116}], {
             RGBColor[
             0.2290183753781148, 0.3580432114990334, 0.9363536297242345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 124}], {
             RGBColor[
             0.22172315170383133`, 0.35037546887346516`, 0.9359381775283004]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 128}], {
             RGBColor[
             0.32435782382982603`, 0.44691944921604004`, 0.9421979744658333]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 136}], {
             RGBColor[
             0.22011061631709428`, 0.3486805919413559, 0.935846346023558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 148}], {
             RGBColor[
             0.20549299658683456`, 0.33331654679423195`, 0.9350138942047502]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 193}], {
             RGBColor[
             0.223435169075761, 0.3521749076795341, 0.936035674384929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 138}], {
             RGBColor[
             0.20099999291646117`, 0.32859411506378333`, 0.9347580242925257]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 145}], {
             RGBColor[
             0.18515978669395372`, 0.31194505399684636`, 0.9338559479816391]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 115}], {
             RGBColor[
             0.26758071568904057`, 0.3979941146890951, 0.9385709551564505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 163}], {
             RGBColor[
             0.25094941763616774`, 0.3810941274206381, 0.9376025701367612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 165}], {
             RGBColor[
             0.21296967150778956`, 0.3411750061847254, 0.9354396797807493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 169}], {
             RGBColor[
             0.20611458183414505`, 0.33396987229993624`, 0.9350492925650316]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 175}], {
             RGBColor[
             0.36035371764762536`, 0.477066388889339, 0.9448368758036116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 177}], {
             RGBColor[
             0.21876304030867405`, 0.3472642041152524, 0.9357696035634386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 134}], {
             RGBColor[
             0.5941420485372255, 0.6663173396662936, 0.9607153178159171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 143}], {
             RGBColor[
             0.8985367952768839, 0.9217855718880776, 0.9850776323188054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 156}], {
             RGBColor[
             0.880064299434007, 0.550351383801579, 0.5748087868596949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 160}], {
             RGBColor[
             0.6923008271636373, 0.757058105759987, 0.9667604504602199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 181}], {
             RGBColor[
             0.6897919274498447, 0.754885022928866, 0.9666005855889899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 183}], {
             RGBColor[
             0.9388975158686406, 0.8706580791071786, 0.6258657824409817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 116}], {
             RGBColor[
             0.22254054731904888`, 0.35123460349093416`, 0.9359847269993585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 124}], {
             RGBColor[
             0.2152453236447654, 0.343566860865366, 0.9355692748034243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 128}], {
             RGBColor[
             0.3178799957707601, 0.44011084120794086`, 0.9418290717409573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 136}], {
             RGBColor[
             0.21363278825802834`, 0.3418719839332567, 0.9354774432986821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 148}], {
             RGBColor[
             0.19901516852776863`, 0.3265079387861328, 0.9346449914798742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 187}], {
             RGBColor[
             0.20396723113485943`, 0.331712870565089, 0.934927004119428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 193}], {
             RGBColor[
             0.21695734101669506`, 0.34536629967143495`, 0.9356667716600531]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 198}], {
             RGBColor[
             0.2750384221935423, 0.4030036234554522, 0.939099244555933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 167}], {
             RGBColor[
             0.19037448411434205`, 0.3174260316165872, 0.9341529172852767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 184}], {
             RGBColor[
             0.18161202378548802`, 0.3082161302388885, 0.9336539081324469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 186}], {
             RGBColor[
             0.18224157379578187`, 0.3088778272154834, 0.9336897600741974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 194}], {
             RGBColor[
             0.19146855650738448`, 0.3185759710698711, 0.9342152230895253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 133}], {
             RGBColor[
             0.2820742314375166, 0.41322771868271746`, 0.939396339437091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 163}], {
             RGBColor[
             0.2983939725453868, 0.4303808013184385, 0.9403257245502908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 165}], {
             RGBColor[
             0.2604142264170086, 0.39046168008252585`, 0.9381628341942789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 175}], {
             RGBColor[
             0.4077982725568444, 0.5263530627871394, 0.9475600302171414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 124}], {
             RGBColor[
             0.2333325075764587, 0.3625776379712726, 0.9365993131707435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 128}], {
             RGBColor[
             0.33596717970245343`, 0.45912161831384746`, 0.9428591101082765]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 136}], {
             RGBColor[
             0.23171997218972168`, 0.36088276103916334`, 0.9365074816660013]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 148}], {
             RGBColor[
             0.21710235245946194`, 0.3455187158920394, 0.9356750298471934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 193}], {
             RGBColor[
             0.2350445249483884, 0.36437707677734155`, 0.9366968100273723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 198}], {
             RGBColor[
             0.29312560612523564`, 0.42201440056135886`, 0.9401292829232522]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 121}], {
             RGBColor[
             0.2013378942582586, 0.3289492707981949, 0.9347772672740609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 152}], {
             RGBColor[
             0.19275420690752315`, 0.3199272711553603, 0.934288438977864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 159}], {
             RGBColor[
             0.22010744675454766`, 0.3486772605301575, 0.9358461655216599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 164}], {
             RGBColor[
             0.19024796848068162`, 0.3172930556640557, 0.9341457124071029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 178}], {
             RGBColor[
             0.18448507974982858`, 0.3112358942196798, 0.9338175244193107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 200}], {
             RGBColor[
             0.1879682303409825, 0.3148969063354854, 0.9340158846926173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 119}], {
             RGBColor[
             0.6188466529284243, 0.4369505973479967, 0.5693002587660235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 123}], {
             RGBColor[
             0.42099591367325284`, 0.5390672333790665, 0.9480464652405584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 127}], {
             RGBColor[
             0.6328274279834254, 0.7079836098876566, 0.9670229522085898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 129}], {
             RGBColor[
             0.4226691844013287, 0.5404852315434163, 0.9481617341921013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 139}], {
             RGBColor[
             0.33826776988296947`, 0.4652785641134494, 0.9428532266161497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[
             0.36734166462355905`, 0.4925946195931902, 0.9446276639357014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 146}], {
             RGBColor[
             0.3181356246114969, 0.44411840298139715`, 0.9417067307257794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 155}], {
             RGBColor[
             0.5320287520312512, 0.6287959624909311, 0.9570938290152922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 171}], {
             RGBColor[
             0.3493088123107567, 0.4768833997475762, 0.9434819976486537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 191}], {
             RGBColor[
             0.6004855108108049, 0.6822749027401551, 0.9639169589656551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.44594964518515734`, 0.559385358380535, 0.9499944573441421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 196}], {
             RGBColor[
             0.3119267863848373, 0.4375925203420974, 0.941353146573924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[
             0.6930640728290565, 0.752639828019768, 0.8371662674251406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 123}], {
             RGBColor[
             0.6489751309922214, 0.46304637074551996`, 0.5712200187466816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 127}], {
             RGBColor[
             0.8608066453023939, 0.6319627472541103, 0.5901965057147129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 140}], {
             RGBColor[
             0.9202745550794877, 0.6749563522500728, 0.37533269810004777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 151}], {
             RGBColor[
             0.9203645260018751, 0.6763382789683456, 0.4715886994182685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 155}], {
             RGBColor[
             0.7600079693502197, 0.5527750998573846, 0.5802673825214153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 156}], {
             RGBColor[
             0.8327717722765755, 0.2529037791657479, 0.17901559218345872`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 172}], {
             RGBColor[
             0.858083307192903, 0.43025919736952545`, 0.20258043262042846`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 191}], {
             RGBColor[
             0.8284647281297735, 0.6062540401066088, 0.5870905124717782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 195}], {
             RGBColor[
             0.6739288625041259, 0.48336449574698853`, 0.5731680108502653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 199}], {
             RGBColor[
             0.921043290148025, 0.6766189653862216, 0.46033982093126385`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 124}], {
             RGBColor[
             0.20998768265750406`, 0.3380407468340621, 0.9352698599271827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 125}], {
             RGBColor[
             0.22911059591556282`, 0.35814014113101095`, 0.9363588815474142]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 136}], {
             RGBColor[
             0.208375147270767, 0.3363458699019528, 0.9351780284224404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 137}], {
             RGBColor[
             0.2589152311792967, 0.38806631610919806`, 0.9381074864400005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 187}], {
             RGBColor[
             0.1987095901475981, 0.32618675653378515`, 0.9346275892431862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 198}], {
             RGBColor[
             0.26978078120628096`, 0.39747750942414833`, 0.9387998296796913]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 152}], {
             RGBColor[
             0.20876932330272832`, 0.33676017390374813`, 0.9352004761643293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 159}], {
             RGBColor[
             0.23612256314975283`, 0.36551016327854535`, 0.9367582027081254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 161}], {
             RGBColor[
             0.25059050057240173`, 0.38071688282996385`, 0.9375821303409498]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 164}], {
             RGBColor[
             0.2062630848758868, 0.3341259584124435, 0.9350577495935681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 173}], {
             RGBColor[
             0.292553121290118, 0.41936663602592106`, 0.9401715965504269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 180}], {
             RGBColor[
             0.27969294333585376`, 0.40822779625327543`, 0.9393521573829899]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[
             0.20398334673618768`, 0.33172980908387323`, 0.9349279218790827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 125}], {
             RGBColor[
             0.2711034312291314, 0.40227727354510906`, 0.9387503113956892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 137}], {
             RGBColor[
             0.3009080664928653, 0.4322034485232962, 0.9404989162882755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 166}], {
             RGBColor[
             0.5408265520373148, 0.6280223043100961, 0.9601053035876213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 170}], {
             RGBColor[
             0.4665658605119989, 0.5700092876883599, 0.9527036918619959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 179}], {
             RGBColor[
             0.32323201256899053`, 0.45153932858028145`, 0.9419213783919558]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 192}], {
             RGBColor[
             0.3718189687016956, 0.49328632243521403`, 0.9451102958483188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 127}], {
             RGBColor[
             0.6629559060472224, 0.73407938328518, 0.9689427121892478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 129}], {
             RGBColor[
             0.45279766246512576`, 0.5665810049409397, 0.9500814941727593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 139}], {
             RGBColor[
             0.36839624794676656`, 0.4913743375109727, 0.9447729865968078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 141}], {
             RGBColor[
             0.39747014268735614`, 0.5186903929907134, 0.9465474239163595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 146}], {
             RGBColor[
             0.34826410267529395`, 0.47021417637892043`, 0.9436264907064373]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 155}], {
             RGBColor[
             0.5621572300950483, 0.6548917358884543, 0.9590135889959501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 171}], {
             RGBColor[
             0.3794372903745538, 0.5029791731450995, 0.9454017576293117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 191}], {
             RGBColor[
             0.6306139888746021, 0.7083706761376785, 0.9658367189463131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 195}], {
             RGBColor[
             0.4760781232489544, 0.5854811317780583, 0.9519142173248001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 196}], {
             RGBColor[
             0.3420552644486344, 0.4636882937396207, 0.9432729065545822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 199}], {
             RGBColor[
             0.7231925508928534, 0.7787356014172913, 0.8390860274057987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 125}], {
             RGBColor[
             0.24516019716023396`, 0.37500928964265323`, 0.9372728825950409]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 136}], {
             RGBColor[
             0.22442474851543817`, 0.35321501841359515`, 0.9360920294700671]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.27496483242396785`, 0.4049354646208403, 0.9390214874876273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 187}], {
             RGBColor[
             0.21475919139226923`, 0.3430559050454275, 0.935541590290813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 198}], {
             RGBColor[
             0.28583038245095216`, 0.4143466579357906, 0.9397138307273181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 136}], {
             RGBColor[
             0.24354766177349693`, 0.373314412710544, 0.9371810510902985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 137}], {
             RGBColor[
             0.29408774568202667`, 0.42503485891778914`, 0.9401105091078588]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 166}], {
             RGBColor[
             0.5340062312264762, 0.620853714704589, 0.9597168964072044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[
             0.4597455397011603, 0.5628406980828529, 0.952315284681579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 187}], {
             RGBColor[
             0.233882104650328, 0.36315529934237634`, 0.9366306119110444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 192}], {
             RGBColor[
             0.364998647890857, 0.48611773282970705`, 0.9447218886679021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 198}], {
             RGBColor[
             0.30495329570901086`, 0.43444605223273947`, 0.9408028523475496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 190}], {
             RGBColor[
             0.18192592123823295`, 0.3085460563639715, 0.933671784128011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 129}], {
             RGBColor[
             0.6646291767752983, 0.7354973814495299, 0.9690579811407907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 139}], {
             RGBColor[
             0.5802277622569392, 0.660290714019563, 0.9637494735648391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 140}], {
             RGBColor[
             0.9342553301344888, 0.9459893647897327, 0.7730553915426139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 141}], {
             RGBColor[
             0.6093016569975287, 0.6876067694993037, 0.9655239108843909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 155}], {
             RGBColor[
             0.7739887444052208, 0.8238081123970447, 0.9779900759639816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 172}], {
             RGBColor[
             0.8720640822479042, 0.7012922099091854, 0.6003031260629946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 191}], {
             RGBColor[
             0.8424455031847746, 0.8772870526462687, 0.9848132059143445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 195}], {
             RGBColor[
             0.6879096375591269, 0.7543975082866485, 0.9708907042928315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 199}], {
             RGBColor[
             0.935024065203026, 0.9476519779258816, 0.8580625143738301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 136}], {
             RGBColor[
             0.3270594206414329, 0.44975899875617, 0.9423518264076001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 162}], {
             RGBColor[
             0.4413593088202362, 0.5567049827613839, 0.9493440027726809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 193}], {
             RGBColor[
             0.3303839734000996, 0.45325331449434825`, 0.942541154768971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 198}], {
             RGBColor[
             0.38846505457694686`, 0.5108906382783656, 0.9459736276648509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 139}], {
             RGBColor[
             0.3700695186748425, 0.49279233567532266`, 0.9448882555483507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 141}], {
             RGBColor[
             0.399143413415432, 0.5201083911550634, 0.9466626928679024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 146}], {
             RGBColor[
             0.3499373734033699, 0.4716321745432704, 0.9437417596579802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 155}], {
             RGBColor[
             0.5638305008231241, 0.6563097340528043, 0.959128857947493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 191}], {
             RGBColor[
             0.632287259602678, 0.7097886743020284, 0.965951987897856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 195}], {
             RGBColor[
             0.47775139397703026`, 0.5868991299424082, 0.952029486276343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 131}], {
             RGBColor[
             0.18289522364297445`, 0.3095648546486768, 0.9337269844660065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 149}], {
             RGBColor[
             0.1848995905074315, 0.3116715713074204, 0.9338411301937424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 157}], {
             RGBColor[
             0.19536013163296237`, 0.32266626326696746`, 0.9344368425358576]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 168}], {
             RGBColor[
             0.19684636692721422`, 0.32422839079398647`, 0.9345214814371772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 189}], {
             RGBColor[
             0.18936342684036145`, 0.3163633463169, 0.9340953390692487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 197}], {
             RGBColor[
             0.19250062713784824`, 0.3196607427395459, 0.9342739979851187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 147}], {
             RGBColor[
             0.21550989668752718`, 0.3438449439082084, 0.9355843418468089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 157}], {
             RGBColor[
             0.19396001666235732`, 0.3211946536604452, 0.9343571080595661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 176}], {
             RGBColor[
             0.20779145347843028`, 0.335732370717883, 0.9351447879244643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 138}], {
             RGBColor[
             0.2612195562179643, 0.3918886942345018, 0.9381874393356859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 145}], {
             RGBColor[
             0.24537934999545682`, 0.37523963316756476`, 0.9372853630247993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 153}], {
             RGBColor[
             0.29141110867079584`, 0.42362193011741534`, 0.9399068035834754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 182}], {
             RGBColor[
             0.3206991952751244, 0.45143891338558356`, 0.9416833404765177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 185}], {
             RGBColor[
             0.26630785953473646`, 0.397236823637493, 0.9384772106821059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 163}], {
             RGBColor[
             0.26544293338464375`, 0.39632773141426036`, 0.9384279544174017]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 178}], {
             RGBColor[
             0.21638528695668868`, 0.3447650345840459, 0.9356341940276138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 135}], {
             RGBColor[
             0.22190471606791506`, 0.3505663045319628, 0.9359485173502345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 160}], {
             RGBColor[
             0.3450319511386071, 0.4675505014401682, 0.9434155666515178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 144}], {
             RGBColor[
             0.19771245739729065`, 0.32513870679134427`, 0.9345708040081819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 148}], {
             RGBColor[
             0.2081945933984414, 0.33615609633436194`, 0.9351677461465169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 187}], {
             RGBColor[
             0.2131466560055322, 0.3413610281133182, 0.9354497587860706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 193}], {
             RGBColor[
             0.22613676588736786`, 0.35501445721966407`, 0.9361895263266957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 198}], {
             RGBColor[
             0.2842178470642151, 0.4126517810036814, 0.9396219992225757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 166}], {
             RGBColor[
             0.5638108664902101, 0.6507798896827761, 0.9614655012997908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 170}], {
             RGBColor[
             0.48955017496489417`, 0.59276687306104, 0.9540638895741654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 179}], {
             RGBColor[
             0.3462163270218858, 0.4742969139529616, 0.9432815761041253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 187}], {
             RGBColor[
             0.2636867399140619, 0.3930814743205634, 0.9383792168036308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 192}], {
             RGBColor[
             0.3948032831545909, 0.5160439078078941, 0.9464704935604884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 198}], {
             RGBColor[
             0.3347579309727448, 0.4643722272109265, 0.9425514572401359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 145}], {
             RGBColor[
             0.20603341116594734`, 0.3338845567811428, 0.935044670015559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 153}], {
             RGBColor[
             0.25206516984128635`, 0.38226685373099345`, 0.9376661105742352]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 182}], {
             RGBColor[
             0.28135325644561493`, 0.4100838369991616, 0.9394426474672775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 185}], {
             RGBColor[
             0.22696192070522694`, 0.35588174725107113`, 0.9362365176728656]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 141}], {
             RGBColor[
             0.31474199889707277`, 0.4449017237250964, 0.9413541852919508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 146}], {
             RGBColor[
             0.2655359588850107, 0.39642550711330343`, 0.9384332520820287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 155}], {
             RGBColor[
             0.47942908630476494`, 0.5811030666228374, 0.9538203503715414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 171}], {
             RGBColor[
             0.2967091465842705, 0.42919050387948254`, 0.940208519004903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 191}], {
             RGBColor[
             0.5478858450843187, 0.6345820068720615, 0.9606434803219044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 194}], {
             RGBColor[
             0.2435950267958037, 0.37336419635210427`, 0.9371837484582486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 195}], {
             RGBColor[
             0.39334997945867106`, 0.5116924625124413, 0.9467209787003914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 196}], {
             RGBColor[
             0.25932712065835106`, 0.3898996244740037, 0.9380796679301735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 151}], {
             RGBColor[
             0.9938132108339699, 0.9903648965039682, 0.6544475852461695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 161}], {
             RGBColor[
             0.6387756152014612, 0.7023172809495201, 0.7488332700746612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 162}], {
             RGBColor[
             0.7225676146989453, 0.7771975396388044, 0.7540880673117176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 172}], {
             RGBColor[
             0.931531992024998, 0.7442858149051479, 0.38543931844832946`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 173}], {
             RGBColor[
             0.6807382359191774, 0.7409670341454773, 0.7514227362841381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 180}], {
             RGBColor[
             0.6678780579649132, 0.7298281943728316, 0.7506032971167013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 191}], {
             RGBColor[
             0.9019134129618684, 0.9202806576422312, 0.7699493982996792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 146}], {
             RGBColor[
             0.2946098536256002, 0.4237415625930442, 0.9402076894015805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 155}], {
             RGBColor[
             0.5085029810453545, 0.6084191221025781, 0.9555947876910933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 167}], {
             RGBColor[
             0.27157484914335084`, 0.3995303123785612, 0.9388958799735516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 191}], {
             RGBColor[
             0.5769597398249082, 0.6618980623518022, 0.9624179176414562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 194}], {
             RGBColor[
             0.2726689215363932, 0.40068025183184497`, 0.9389581857778003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 195}], {
             RGBColor[
             0.42242387419926064`, 0.539008517992182, 0.9484954160199432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 147}], {
             RGBColor[
             0.25576128412159904`, 0.3861517041867828, 0.9378765988145878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 154}], {
             RGBColor[
             0.29693436368645065`, 0.4272891715192359, 0.9402996292628881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 157}], {
             RGBColor[
             0.2342114040964292, 0.3635014139390195, 0.9366493650273451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 168}], {
             RGBColor[
             0.23569763939068106`, 0.3650635414660385, 0.9367340039286646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 176}], {
             RGBColor[
             0.24804284091250217`, 0.37803913099645736`, 0.9374370448922433]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.2876001150236012, 0.4192043144804547, 0.9397048591920434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 154}], {
             RGBColor[
             0.5937667549119501, 0.6748088886146058, 0.9642312788067474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 158}], {
             RGBColor[
             0.5860035167018279, 0.6680847618686957, 0.9637366121327604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 160}], {
             RGBColor[
             0.6494266978782655, 0.7230187336619522, 0.967777881154406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 181}], {
             RGBColor[
             0.6469177981644729, 0.7208456508308313, 0.967618016283176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 188}], {
             RGBColor[
             0.5844325062491007, 0.6667240315758246, 0.9636365087359027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 158}], {
             RGBColor[
             0.2574165112915451, 0.3871889319062931, 0.9379965842878197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 153}], {
             RGBColor[
             0.2362249636187789, 0.3656177926640565, 0.9367640342633485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 185}], {
             RGBColor[
             0.2111217144827195, 0.33923268618413416`, 0.935334441361979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 155}], {
             RGBColor[
             0.4592969410332923, 0.5599429054907851, 0.9526738544811711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 171}], {
             RGBColor[
             0.27657700131279794`, 0.4080303427474302, 0.9390620231145327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 184}], {
             RGBColor[
             0.21360634880243462`, 0.34184419438906943`, 0.9354759376107997]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 186}], {
             RGBColor[
             0.2142358988127285, 0.34250589136566434`, 0.9355117895525502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 191}], {
             RGBColor[
             0.527753699812846, 0.6134218457400091, 0.9594969844315341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 194}], {
             RGBColor[
             0.22346288152433108`, 0.352204035220052, 0.9360372525678782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 195}], {
             RGBColor[
             0.37321783418719845`, 0.490532301380389, 0.9455744828100211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 196}], {
             RGBColor[
             0.23919497538687848`, 0.3687394633419514, 0.9369331720398031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 154}], {
             RGBColor[
             0.2906977642675366, 0.42073411010671546`, 0.939944464152203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 157}], {
             RGBColor[
             0.2279748046775151, 0.3569463525264991, 0.9362941999166599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 168}], {
             RGBColor[
             0.22946103997176695`, 0.35850848005351804`, 0.9363788388179795]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 176}], {
             RGBColor[
             0.24180624149358806`, 0.37148406958393687`, 0.9370818797815581]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 188}], {
             RGBColor[
             0.2813635156046871, 0.41264925306793426`, 0.9393496940813583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 150}], {
             RGBColor[
             0.19306951159997304`, 0.3202586763785973, 0.9343063951136474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 193}], {
             RGBColor[
             0.21151914615710812`, 0.33965041207254015`, 0.9353570745078879]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 167}], {
             RGBColor[
             0.19241882352516138`, 0.31957476195596346`, 0.9342693393903937]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 168}], {
             RGBColor[
             0.19745061882106624`, 0.32486349784620777`, 0.9345558926886215]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 189}], {
             RGBColor[
             0.18996767873421347`, 0.31699845336912136`, 0.934129750320693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 194}], {
             RGBColor[
             0.1935128959182038, 0.3207247014092473, 0.9343316451946424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.19310487903170026`, 0.3202958497917673, 0.934308409236563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 156}], {
             RGBColor[
             0.9063104280310577, 0.5683123234196433, 0.4581304793295804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 172}], {
             RGBColor[
             0.9316219629473853, 0.7456677416234209, 0.4816953197665501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 175}], {
             RGBColor[
             0.7472372281358932, 0.7985860801048122, 0.8522647687143463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 183}], {
             RGBColor[
             0.9651436444656913, 0.888619018725243, 0.5091874749108671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 199}], {
             RGBColor[
             0.9945819459025071, 0.992027509640117, 0.7394547080773856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 159}], {
             RGBColor[
             0.22753887579901738`, 0.3564881636357107, 0.9362693744119284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 178}], {
             RGBColor[
             0.19191650879429833`, 0.319046797325233, 0.9342407333095791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 200}], {
             RGBColor[
             0.19539965938545223`, 0.3227078094410386, 0.9344390935828858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 182}], {
             RGBColor[
             0.3115448088984465, 0.4418170728820753, 0.941162011715067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 185}], {
             RGBColor[
             0.2571534731580585, 0.38761498313398474`, 0.937955881920655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 157}], {
             RGBColor[
             0.2691478842423667, 0.3980838198589522, 0.9387172303649602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 158}], {
             RGBColor[
             0.3241076056222659, 0.45514745069325846`, 0.9418728279265163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 160}], {
             RGBColor[
             0.38753078679870345`, 0.510081422486515, 0.9459140969481619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 176}], {
             RGBColor[
             0.28297932105843965`, 0.41262153691639003`, 0.9395049102298585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 181}], {
             RGBColor[
             0.3850218870849109, 0.5079083396553941, 0.9457542320769319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 188}], {
             RGBColor[
             0.3225365951695387, 0.45378672040038737`, 0.9417727245296585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 172}], {
             RGBColor[
             0.77126540629573, 0.6221045625124598, 0.590374002869697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 191}], {
             RGBColor[
             0.7416468272326004, 0.7980994052495431, 0.9748840827210469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 195}], {
             RGBColor[
             0.5871109616069528, 0.6752098608899229, 0.9609615810995339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 199}], {
             RGBColor[
             0.8342253892508518, 0.868464330529156, 0.8481333911805324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 166}], {
             RGBColor[
             0.8112235131702088, 0.49573828454331076`, 0.5733146303469535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 170}], {
             RGBColor[
             0.7369628216448929, 0.4377252679215747, 0.5659130186213281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 175}], {
             RGBColor[
             0.6596444744105936, 0.3751515803022144, 0.5596916614795366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 183}], {
             RGBColor[
             0.8775508907403917, 0.4651845189226452, 0.21661436767605732`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 199}], {
             RGBColor[
             0.9069891921772075, 0.5685930098375191, 0.4468816008425758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 168}], {
             RGBColor[
             0.2079111599465971, 0.33585818980575477`, 0.9351516050307367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 176}], {
             RGBColor[
             0.2202563614684182, 0.34883377933617365`, 0.9358546459943153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 188}], {
             RGBColor[
             0.25981363557951725`, 0.389998962820171, 0.9381224602941154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 160}], {
             RGBColor[
             0.3797675485885813, 0.503357295740605, 0.945419430274175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 176}], {
             RGBColor[
             0.27521608284831744`, 0.40589741017048, 0.9390102435558715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.37725864887478877`, 0.501184212909484, 0.945259565402945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 161}], {
             RGBColor[
             0.2693600530686908, 0.4004448725619264, 0.938651028588549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 162}], {
             RGBColor[
             0.3531520525661749, 0.4753251312512108, 0.9439058258256054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 164}], {
             RGBColor[
             0.22503263737217588`, 0.35385394814440607`, 0.9361266478411673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 173}], {
             RGBColor[
             0.3113226737864071, 0.4390946257578836, 0.941240494798026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 180}], {
             RGBColor[
             0.29846249583214285`, 0.427955785985238, 0.9404210556305891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 200}], {
             RGBColor[
             0.22275289923247676`, 0.35145779881583583`, 0.9359968201266817]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[
             0.4406818300512263, 0.5561181847027405, 0.9493008344245906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 162}], {
             RGBColor[
             0.3676199899888237, 0.4905318508026293, 0.94472975345843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 164}], {
             RGBColor[
             0.23950057479482478`, 0.3690606676958246, 0.9369505754739917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 173}], {
             RGBColor[
             0.32579061120905595`, 0.4543013453093021, 0.9420644224308505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 180}], {
             RGBColor[
             0.31293043325479175`, 0.4431625055366565, 0.9412449832634135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 200}], {
             RGBColor[
             0.23722083665512567`, 0.36666451836725433`, 0.9368207477595063]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 172}], {
             RGBColor[
             0.6603763668123606, 0.5325003847582571, 0.5813358018320983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 173}], {
             RGBColor[
             0.40958261070654, 0.5291816039985865, 0.947319219667907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 180}], {
             RGBColor[
             0.3967224327522758, 0.5180427642259409, 0.9464997805004701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 165}], {
             RGBColor[
             0.24378292836413576`, 0.3735616928140688, 0.9371944491745896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 175}], {
             RGBColor[
             0.39116697450397153`, 0.5094530755186824, 0.9465916451974521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 177}], {
             RGBColor[
             0.24957629716502022`, 0.3796508907445958, 0.937524372957279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 200}], {
             RGBColor[
             0.19289342095861073`, 0.320073593949734, 0.9342963670121247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 169}], {
             RGBColor[
             0.1989480925621131, 0.32643743769336697`, 0.9346411716028602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 175}], {
             RGBColor[
             0.35318722837559335`, 0.4695339542827697, 0.9444287548414402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 177}], {
             RGBColor[
             0.2115965510366421, 0.3397317695086831, 0.9353614826012671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 170}], {
             RGBColor[
             0.7294686605093437, 0.78858572884784, 0.973670276873511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 179}], {
             RGBColor[
             0.5861348125663353, 0.6701157697397615, 0.962887963403471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 183}], {
             RGBColor[
             0.8700567296048425, 0.8160449798489104, 0.6243716259282402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 192}], {
             RGBColor[
             0.6347217686990404, 0.711862763594694, 0.9660768808598341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 198}], {
             RGBColor[
             0.5746764165171943, 0.6601910829977264, 0.9621578445394816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 189}], {
             RGBColor[
             0.19688265985809134`, 0.32426653696544305`, 0.9345235482659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 194}], {
             RGBColor[
             0.2004278770420817, 0.327992785005569, 0.9347254431398494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 197}], {
             RGBColor[
             0.20001986015557813`, 0.327563933388089, 0.9347022071817699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 188}], {
             RGBColor[
             0.2612998708737691, 0.39156109034719, 0.938207099195435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 189}], {
             RGBColor[
             0.2019144551539962, 0.3295552728556873, 0.9348101015641277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 197}], {
             RGBColor[
             0.20505165545148296`, 0.3328526692783333, 0.9349887604799977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 177}], {
             RGBColor[
             0.20474146136299756`, 0.33252663562389395`, 0.9349710953855495]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 190}], {
             RGBColor[
             0.18813962732028144`, 0.31507705542792475`, 0.9340256454970293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 179}], {
             RGBColor[
             0.5118741210410194, 0.6121027531180253, 0.9554863516778458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 183}], {
             RGBColor[
             0.7957960380795266, 0.7580319632271744, 0.6169700142026149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[
             0.5604610771737245, 0.6538497469729578, 0.9586752691342088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 198}], {
             RGBColor[
             0.5004157249918784, 0.6021780663759904, 0.9547562328138562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 174}], {
             RGBColor[
             0.24889168370669917`, 0.37893131859289997`, 0.9374853852336225]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 182}], {
             RGBColor[
             0.3242915422574164, 0.45521469783192636`, 0.9418879193227581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 191}], {
             RGBColor[
             0.558926887512106, 0.6461868425061883, 0.9612722513544084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 195}], {
             RGBColor[
             0.4043910218864583, 0.5232972981465681, 0.9473497497328954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 196}], {
             RGBColor[
             0.2703681630861383, 0.4015044601081305, 0.9387084389626774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 199}], {
             RGBColor[
             0.6515054495303574, 0.7165517677858011, 0.834521559813894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 173}], {
             RGBColor[
             0.6185469880325928, 0.49626987926492994`, 0.5786704708045187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 180}], {
             RGBColor[
             0.6056868100783286, 0.4851310394922843, 0.577851031637082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 191}], {
             RGBColor[
             0.8397221650752837, 0.6755835027616839, 0.59719713282006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 180}], {
             RGBColor[
             0.35489305397250803`, 0.4818122587326137, 0.9438344494728906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 186}], {
             RGBColor[
             0.18655058120662976`, 0.3134068672111341, 0.9339351516716399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 196}], {
             RGBColor[
             0.21150965778077974`, 0.33964043918742115`, 0.9353565341588927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 183}], {
             RGBColor[
             0.7184776908452273, 0.695458275607814, 0.6107486570608233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 188}], {
             RGBColor[
             0.2736450723955902, 0.4045366798776089, 0.9389101401590136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 179}], {
             RGBColor[
             0.2929650964677688, 0.41972688072457853`, 0.940197722295881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 190}], {
             RGBColor[
             0.20078808579481044`, 0.3283713872432409, 0.9347459564954362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 183}], {
             RGBColor[
             0.6524621901365182, 0.6395620041190959, 0.6061877007325749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 192}], {
             RGBColor[
             0.41712722923071616`, 0.5353797878648794, 0.9478929556641686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 185}], {
             RGBColor[
             0.28644155976238705`, 0.41543196640215296`, 0.9397324188136974]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 195}], {
             RGBColor[
             0.42093237513181697`, 0.5377166564648852, 0.9484003790182465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 196}], {
             RGBColor[
             0.28690951633149697`, 0.41592381842644754`, 0.9397590682480286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 199}], {
             RGBColor[
             0.668046802775716, 0.7309711261041182, 0.8355721890992451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 192}], {
             RGBColor[
             0.7010491462692232, 0.6813089979740284, 0.609376618188938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 186}], {
             RGBColor[
             0.18243843400162507`, 0.3090847397734826, 0.9337009709716915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 194}], {
             RGBColor[
             0.19166541671322765`, 0.3187828836278702, 0.9342264339870195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 198}], {
             RGBColor[
             0.2745522899410462, 0.4024926676355137, 0.9390715600433216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 194}], {
             RGBColor[
             0.19797673225113377`, 0.32541647641872684`, 0.9345858540701487]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 197}], {
             RGBColor[
             0.19756871536463022`, 0.3249876248012469, 0.9345626181120692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 195}], {
             RGBColor[
             0.6555677203865065, 0.728688801139147, 0.9677847110498968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 199}], {
             RGBColor[
             0.9026821480304056, 0.9219432707783801, 0.8549565211308954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 197}], {
             RGBColor[
             0.20111393254862053`, 0.3287138728413728, 0.9347645129860187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 196}], {
             RGBColor[
             0.3670089959605389, 0.4840064187410893, 0.9452208986581658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 199}], {
             RGBColor[
             0.748146282404758, 0.7990537264187598, 0.8410340195093824]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.04610843439966642], {
             RGBColor[
             0.17991592983646426`, 0.30643342795989703`, 0.9335573180911961]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.04610843439966642], {
             RGBColor[
             0.18237351643808017`, 0.30901650729818564`, 0.9336972740124846]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.04610843439966642], {
             RGBColor[
             0.4186929718519593, 0.5370725409226834, 0.947899723824117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.04610843439966642], {
             RGBColor[
             0.33430755049502603`, 0.4639821302779076, 0.9425227593943515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.04610843439966642], {
             RGBColor[
             0.35433408061295757`, 0.481328104103389, 0.9437988321847008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.04610843439966642], {
             RGBColor[
             0.8314330293974257, 0.24261361475573226`, 0.17773361049049105`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.04610843439966642], {
             RGBColor[
             0.20849433214894747`, 0.33647114076567824`, 0.9351848158249345]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.04610843439966642], {
             RGBColor[
             0.28326421471662644`, 0.41505902802867256`, 0.939442850025035]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.04610843439966642], {
             RGBColor[
             0.19331350997927296`, 0.32051513414563226`, 0.9343202904603853]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.04610843439966642], {
             RGBColor[
             0.2179504265625759, 0.34641009554541596`, 0.9357233264127526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.04610843439966642], {
             RGBColor[
             0.20295626314304663`, 0.3306502791066209, 0.9348694309878873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.04610843439966642], {
             RGBColor[
             0.950102117301832, 0.8398785531251466, 0.2787091962084557]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.04610843439966642], {
             RGBColor[
             0.22110598802207443`, 0.3497267907135012, 0.9359030309696362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.04610843439966642], {
             RGBColor[
             0.17925722738073346`, 0.3057410899147761, 0.9335198059608052]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.04610843439966642], {
             RGBColor[
             0.1871756577266932, 0.3140638622658612, 0.9339707488547396]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.04610843439966642], {
             RGBColor[
             0.19146922694525287`, 0.31857667574257903`, 0.9342152612699701]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.04610843439966642], {
             RGBColor[
             0.22306772190849825`, 0.3517886974092449, 0.9360147488123428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.04610843439966642], {
             RGBColor[
             0.35121665541737046`, 0.47862794708531764`, 0.9436001926078689]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.04610843439966642], {
             RGBColor[
             0.1823235017276304, 0.3089639386663871, 0.9336944257487145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.04610843439966642], {
             RGBColor[
             0.36130368564417137`, 0.48736482567889206`, 0.94424292925431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.04610843439966642], {
             RGBColor[
             0.18848942771341942`, 0.31544471781973865`, 0.9340455661119352]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.04610843439966642], {
             RGBColor[
             0.22363768830217948`, 0.3523877682269605, 0.9360472075552733]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.04610843439966642], {
             RGBColor[
             0.2571472380542651, 0.3876084296445695, 0.9379555268407181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.04610843439966642], {
             RGBColor[
             0.17953882470990998`, 0.3060370665620425, 0.9335358425121159]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.04610843439966642], {
             RGBColor[
             0.2927822195605681, 0.4250630545960175, 0.9399848863202711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.04610843439966642], {
             RGBColor[
             0.26652048668465833`, 0.39746030825340095`, 0.9384893194837403]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.04610843439966642], {
             RGBColor[
             0.1792907180836107, 0.3057762907669333, 0.933521713206789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.04610843439966642], {
             RGBColor[
             0.20691074357712266`, 0.33480668877137576`, 0.9350946327984784]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.04610843439966642], {
             RGBColor[
             0.2095661987749073, 0.33759774054983127`, 0.9352458570435983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.04610843439966642], {
             RGBColor[
             0.531961775829707, 0.6309095600802831, 0.9562971261149575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.04610843439966642], {
             RGBColor[
             0.186006868294159, 0.3128353904667376, 0.9339041880256258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.04610843439966642], {
             RGBColor[
             0.9926235425767636, 0.9912176595362523, 0.7719105193703001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.04610843439966642], {
             RGBColor[
             0.4300571649791395, 0.5469156338284925, 0.9486238401612196]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.04610843439966642], {
             RGBColor[
             0.18077756667952594`, 0.30733906291288604`, 0.933606387034731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.04610843439966642], {
             RGBColor[
             0.18255152448721731`, 0.309203605044191, 0.9337074113075435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.04610843439966642], {
             RGBColor[
             0.23584637567939642`, 0.36521987273590373`, 0.9367424742402714]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.04610843439966642], {
             RGBColor[
             0.18112444186066054`, 0.30770365072141526`, 0.9336261410631407]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.04610843439966642], {
             RGBColor[
             0.25206224059906557`, 0.3822637749116947, 0.9376659437582241]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.04610843439966642], {
             RGBColor[
             0.5058302216121423, 0.609694787153362, 0.9542399544439137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.04610843439966642], {
             RGBColor[
             0.29070628845368207`, 0.422881119381046, 0.9398666651147989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.04610843439966642], {
             RGBColor[
             0.2027701922068055, 0.3304547067550528, 0.9348588345233357]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.04610843439966642], {
             RGBColor[
             0.18974733652345127`, 0.3167668597351072, 0.9341172021577572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.04610843439966642], {
             RGBColor[
             0.8987739036289236, 0.6332377629819576, 0.2372468027203504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.04610843439966642], {
             RGBColor[
             0.7110429824499928, 0.7741914491075349, 0.9718337774823064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.04610843439966642], {
             RGBColor[
             0.18297903858873563`, 0.3096529494708463, 0.9337317576031746]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.04610843439966642], {
             RGBColor[
             0.1962609887352336, 0.32361312119909375`, 0.9344881450151332]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.04610843439966642], {
             RGBColor[
             0.21049372737267863`, 0.3385726319147987, 0.9352986784250858]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.04610843439966642], {
             RGBColor[
             0.4223544797753533, 0.5402439550531881, 0.9481330318712514]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.04610843439966642], {
             RGBColor[
             0.20374667641262958`, 0.33148105356804847`, 0.9349144438542785]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.04610843439966642], {
             RGBColor[
             0.18219656266820544`, 0.3088305176665303, 0.9336871967570698]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.04610843439966642], {
             RGBColor[
             0.18558886593634766`, 0.31239604348579764`, 0.9338803834097276]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.04610843439966642], {
             RGBColor[
             0.631783197735858, 0.7119490872875069, 0.9641554341053266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.04610843439966642], {
             RGBColor[
             0.988392764379178, 0.9725082101217492, 0.4094085107659739]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.04610843439966642], {
             RGBColor[
             0.33587823342715956`, 0.465342576888902, 0.9426228419218866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.04610843439966642], {
             RGBColor[
             0.1825695689347496, 0.30922257090263144`, 0.9337084389121362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.04610843439966642], {
             RGBColor[
             0.1818396285304826, 0.30845535725685214`, 0.9336668698859633]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.04610843439966642], {
             RGBColor[
             0.9605766768067475, 0.9701187306290152, 0.9516175823034524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.04610843439966642], {
             RGBColor[
             0.18422301466471383`, 0.3109604471993381, 0.9338026002004038]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.04610843439966642], {
             RGBColor[
             0.18098071777705174`, 0.3075525875969092, 0.9336179561892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.04610843439966642], {
             RGBColor[
             0.2073405252862433, 0.3352584165973958, 0.9351191082310077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.04610843439966642], {
             RGBColor[
             0.1999014029793203, 0.32743942738522325`, 0.9346954612208237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.04610843439966642], {
             RGBColor[
             0.19167260114558432`, 0.31879043492179643`, 0.9342268431298139]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.04610843439966642], {
             RGBColor[
             0.6295309817704698, 0.7101206369056319, 0.9639781314143923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.04610843439966642], {
             RGBColor[
             0.95633856953826, 0.8643818842404721, 0.284884016735784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.04610843439966642], {
             RGBColor[
             0.18354617680954663`, 0.31024904769955874`, 0.9337640552858439]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.04610843439966642], {
             RGBColor[
             0.2558901091184015, 0.3862871074263986, 0.9378839352075763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.04610843439966642], {
             RGBColor[
             0.9609913119589255, 0.8800766769412489, 0.30295904244338884`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.04610843439966642], {
             RGBColor[
             0.24981404640376637`, 0.37990078026869034`, 0.9375379124247071]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.04610843439966642], {
             RGBColor[
             0.19105055232810444`, 0.31813662217445204`, 0.9341914183698972]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.04610843439966642], {
             RGBColor[
             0.3637386159115608, 0.4894738398933511, 0.9443980808578237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.04610843439966642], {
             RGBColor[
             0.2532013109542942, 0.38346101007627187`, 0.9377308121298508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.04610843439966642], {
             RGBColor[
             0.21747923322295587`, 0.34591484147009205`, 0.9356964926491292]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.04610843439966642], {
             RGBColor[
             0.34593054718585675`, 0.47404938582270545`, 0.9432633664656788]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.04610843439966642], {
             RGBColor[
             0.5021423004164799, 0.6067007665877667, 0.9539496277780908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.04610843439966642], {
             RGBColor[
             0.26424845016803866`, 0.3950722538189983, 0.9383599303652956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.04610843439966642], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.04610843439966642], {
             RGBColor[
             0.18293127670980908`, 0.3096027487078165, 0.9337290376348271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.04610843439966642], {
             RGBColor[
             0.1941778278429074, 0.3214235870212298, 0.9343695120840757]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.04610843439966642], {
             RGBColor[
             0.22179319725678925`, 0.3504490911907685, 0.9359421665189183]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.04610843439966642], {
             RGBColor[
             0.30602988251049323`, 0.4389871883067331, 0.9407393211271083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.04610843439966642], {
             RGBColor[
             0.21196511221078973`, 0.3401191506708405, 0.9353824716148974]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.04610843439966642], {
             RGBColor[
             0.9263859833659136, 0.9441390533310817, 0.9928407161596127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.04610843439966642], {
             RGBColor[
             0.181234979779358, 0.3078198330824752, 0.9336324360340843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.04610843439966642], {
             RGBColor[
             0.2704719529099895, 0.40161354979365305`, 0.9387143496396024]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.04610843439966642], {
             RGBColor[
             0.2020967142561969, 0.3297468387279948, 0.9348204809503698]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.04610843439966642], {
             RGBColor[
             0.21670300720810273`, 0.3450989787129095, 0.9356522877259069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.04610843439966642], {
             RGBColor[
             0.21656281497127022`, 0.34495162778329735`, 0.9356443039854151]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.04610843439966642], {
             RGBColor[
             0.2675148103379351, 0.39850540545675567`, 0.9385459447448243]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.04610843439966642], {
             RGBColor[
             0.22727061882380845`, 0.3562062085462915, 0.9362540975740409]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.04610843439966642], {
             RGBColor[
             0.18623437450108682`, 0.31307451391494534`, 0.9339171441675451]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.04610843439966642], {
             RGBColor[
             0.2444470173259052, 0.37425969241856055`, 0.9372322680585309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.04610843439966642], {
             RGBColor[
             0.23138676958404353`, 0.3605325439743302, 0.9364885062705369]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.04610843439966642], {
             RGBColor[
             0.19041076970754647`, 0.3174641700756846, 0.9341549836961299]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.04610843439966642], {
             RGBColor[
             0.24919784069125972`, 0.37925310899514714`, 0.9375028204209744]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.04610843439966642], {
             RGBColor[
             0.9364164576881094, 0.9521000787690629, 0.9925145312769647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.04610843439966642], {
             RGBColor[
             0.21679935925455723`, 0.3452002508228058, 0.9356577748324124]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.04610843439966642], {
             RGBColor[
             0.19250116414799295`, 0.31966130717125646`, 0.9342740285670519]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.04610843439966642], {
             RGBColor[
             0.5518206973838005, 0.647031927232117, 0.9578604931653224]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.04610843439966642], {
             RGBColor[
             0.20579087184942513`, 0.3336296325815971, 0.9350308577602878]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.04610843439966642], {
             RGBColor[
             0.19619436846660787`, 0.3235430990727991, 0.9344843510893909]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.04610843439966642], {
             RGBColor[
             0.9691756477061694, 0.9765318290462814, 0.9370617675415293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.04610843439966642], {
             RGBColor[
             0.1810808656124072, 0.3076578493216073, 0.933623659460268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.04610843439966642], {
             RGBColor[
             0.36710024085613885`, 0.49238551046016216`, 0.9446122806267241]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.04610843439966642], {
             RGBColor[
             0.20575656042090384`, 0.333593569094751, 0.9350289037751928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.04610843439966642], {
             RGBColor[
             0.18503007033382515`, 0.31180871387785897`, 0.9338485608268279]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.04610843439966642], {
             RGBColor[
             0.21763298899601496`, 0.34607644853625624`, 0.9357052488129437]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.04610843439966642], {
             RGBColor[
             0.3080267094125234, 0.4410859799869048, 0.9408530374651383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.04610843439966642], {
             RGBColor[
             0.21740901950548744`, 0.34584104240122593`, 0.9356924940817913]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.04610843439966642], {
             RGBColor[
             0.18012636844446756`, 0.30665461227948687`, 0.9335693022586058]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.04610843439966642], {
             RGBColor[
             0.2201361607798215, 0.3487074407912947, 0.9358478007429207]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.04610843439966642], {
             RGBColor[
             0.9414109245622558, 0.9558249439861124, 0.9840602016246193]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.04610843439966642], {
             RGBColor[
             0.20445336338735556`, 0.33222382638502757`, 0.9349546886320393]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.04610843439966642], {
             RGBColor[
             0.18141516357964482`, 0.30800921768088935`, 0.9336426972349526]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.04610843439966642], {
             RGBColor[
             0.31502527059825963`, 0.4472807885868956, 0.9412941095699802]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.04610843439966642], {
             RGBColor[
             0.24062773125074222`, 0.3702453805968408, 0.9370147653666777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.04610843439966642], {
             RGBColor[
             0.1853227778630534, 0.31211636804980714`, 0.9338652300875955]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.04610843439966642], {
             RGBColor[
             0.39086743560945575`, 0.5129714599815431, 0.9461267052599003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.04610843439966642], {
             RGBColor[
             0.8468258702473929, 0.3609297347144502, 0.19247381227214683`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.04610843439966642], {
             RGBColor[
             0.1939380814128329, 0.3211715983224198, 0.934355858879556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.04610843439966642], {
             RGBColor[
             0.21735301065346377`, 0.34578217354658275`, 0.9356893044605262]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.04610843439966642], {
             RGBColor[
             0.27792375203997, 0.40944586315061604`, 0.939138718576106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.04610843439966642], {
             RGBColor[
             0.4511243917370499, 0.5651630067765897, 0.9499662252212164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.04610843439966642], {
             RGBColor[
             0.2260372839021752, 0.3549098953457044, 0.9361838609748094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.04610843439966642], {
             RGBColor[
             0.2642831104182927, 0.3951086839396021, 0.9383619042152723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.04610843439966642], {
             RGBColor[
             0.1796655907243716, 0.3061703056806712, 0.9335430616491059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.04610843439966642], {
             RGBColor[
             0.874787420357395, 0.9029957597937702, 0.9879191991572792]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.04610843439966642], {
             RGBColor[
             0.43130662815416465`, 0.5479978560308542, 0.9487034548498753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.04610843439966642], {
             RGBColor[
             0.4544709331932017, 0.5679990031052896, 0.9501967631243022]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.04610843439966642], {
             RGBColor[
             0.1842953386135795, 0.3110364642551991, 0.933806718942298]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.04610843439966642], {
             RGBColor[
             0.1814951086723694, 0.3080932450421545, 0.9336472499897152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.04610843439966642], {
             RGBColor[
             0.30056549504747376`, 0.4332437706209237, 0.9404281323449262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.04610843439966642], {
             RGBColor[
             0.24912319227677354`, 0.3791746487785393, 0.937498569304202]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.04610843439966642], {
             RGBColor[
             0.24687317251219526`, 0.37680973534647483`, 0.9373704340072151]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.04610843439966642], {
             RGBColor[
             0.1969362596236349, 0.3243228737174507, 0.934526600693254]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.04610843439966642], {
             RGBColor[
             0.22281221312870114`, 0.35152014148148586`, 0.9360001979653247]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.04610843439966642], {
             RGBColor[
             0.32389238094576056`, 0.45496103389597625`, 0.9418591140004451]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.04610843439966642], {
             RGBColor[
             0.2218736173884548, 0.35053361784807985`, 0.9359467463264457]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.04610843439966642], {
             RGBColor[
             0.28566810415648325`, 0.4175856682453557, 0.9395797479723991]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.04610843439966642], {
             RGBColor[
             0.9937232399115826, 0.9889829697856952, 0.5581915839279488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.04610843439966642], {
             RGBColor[
             0.34381589363766235`, 0.47221777920483715`, 0.9431286226115025]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.04610843439966642], {
             RGBColor[
             0.2619978835405132, 0.39270676559930323`, 0.938231763925273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.04610843439966642], {
             RGBColor[
             0.8556626659915121, 0.887746199790043, 0.9860950630129915]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.04610843439966642], {
             RGBColor[
             0.19848865517094644`, 0.32595453986523776`, 0.93461500732311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.04610843439966642], {
             RGBColor[
             0.1901932049434399, 0.31723549571420584`, 0.9341425937046723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.04610843439966642], {
             RGBColor[
             0.24540381361353808`, 0.37526534598125116`, 0.9372867561916584]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.04610843439966642], {
             RGBColor[
             0.24952468470268496`, 0.3795966427742623, 0.9375214337039027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.04610843439966642], {
             RGBColor[
             0.19357697366818166`, 0.320792051187238, 0.9343352943277091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.04610843439966642], {
             RGBColor[
             0.1855038424012835, 0.31230667835964177`, 0.9338755414451867]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.04610843439966642], {
             RGBColor[
             0.19256204953176445`, 0.3197253015699566, 0.9342774958995859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.04610843439966642], {
             RGBColor[
             0.9939031817563573, 0.9917468232222412, 0.7507035865643902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.04610843439966642], {
             RGBColor[
             0.20018563595199287`, 0.32773817426091345`, 0.9347116478681324]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.04610843439966642], {
             RGBColor[
             0.2822567222941179, 0.41400008961390705`, 0.9393854748220246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.04610843439966642], {
             RGBColor[
             0.33187084383238813`, 0.46187157743916857`, 0.9423674946005033]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.04610843439966642], {
             RGBColor[
             0.6731900684530466, 0.744620465000319, 0.9680609527706839]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.04610843439966642], {
             RGBColor[
             0.8187176743057581, 0.14487782361704554`, 0.16555737209477062`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.04610843439966642], {
             RGBColor[
             0.20642492465234524`, 0.3342960622787358, 0.9350669661294171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.04610843439966642], {
             RGBColor[
             0.3163443674121438, 0.4484233239473484, 0.9413781612525294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.04610843439966642], {
             RGBColor[
             0.2548921156460419, 0.3852381530105079, 0.9378271009557244]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.04610843439966642], {
             RGBColor[
             0.44319072976501883`, 0.5582912675338615, 0.9494606992958204]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.04610843439966642], {
             RGBColor[
             0.2838279904913397, 0.4156515921133449, 0.9394749562213734]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.04610843439966642], {
             RGBColor[
             0.4514119894863078, 0.5654121094919137, 0.9499845506954865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.04610843439966642], {
             RGBColor[
             0.2817626744925139, 0.41348081404998144`, 0.9393573395306015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.04610843439966642], {
             RGBColor[
             0.19517315909830985`, 0.32246974327830424`, 0.9344261947266101]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.04610843439966642], {
             RGBColor[
             0.2058031822357576, 0.33364257157815613`, 0.9350315588185778]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.04610843439966642], {
             RGBColor[
             0.8037293520346596, 0.846598745469576, 0.9810718885991364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.04610843439966642], {
             RGBColor[
             0.19933380464903927`, 0.32684284555228516`, 0.9346631373356007]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.04610843439966642], {
             RGBColor[
             0.20939739524084894`, 0.3374203173327738, 0.9352362439320562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.04610843439966642], {
             RGBColor[
             0.19209300288846856`, 0.31923230380857776`, 0.9342507843871425]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.04610843439966642], {
             RGBColor[
             0.6552079689840278, 0.7305727122261038, 0.9662686651478858]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.04610843439966642], {
             RGBColor[
             0.30775018901205775`, 0.44079533951360933`, 0.940837290037407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.04610843439966642], {
             RGBColor[
             0.8693407441384133, 0.4995886600246006, 0.2126870529687101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.04610843439966642], {
             RGBColor[
             0.36775323192677223`, 0.4929510985052593, 0.9446538886403275]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.04610843439966642], {
             RGBColor[
             0.19003317840134057`, 0.3170672976721906, 0.9341334804298378]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.04610843439966642], {
             RGBColor[
             0.5005712745154292, 0.6054253369873833, 0.9538259508643026]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.04610843439966642], {
             RGBColor[
             0.23408779828449117`, 0.3633714963936115, 0.9366423258592136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.04610843439966642], {
             RGBColor[
             0.21738991983752656`, 0.34582096743921015`, 0.9356914063839564]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.04610843439966642], {
             RGBColor[
             0.1836473816366038, 0.3103554203895525, 0.9337698187510258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.04610843439966642], {
             RGBColor[
             0.3685402730980111, 0.49363279400994686`, 0.9447040382078057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.04610843439966642], {
             RGBColor[
             0.3420328760182438, 0.47067341895996806`, 0.9430150103054538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.04610843439966642], {
             RGBColor[
             0.43817293033743376`, 0.5539451018716196, 0.9491409695533606]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.04610843439966642], {
             RGBColor[
             0.34083289550277507`, 0.46963405615024345`, 0.9429385486081092]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.04610843439966642], {
             RGBColor[
             0.9363841071750253, 0.7854912142282449, 0.26767136325734403`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.04610843439966642], {
             RGBColor[
             0.1818088839913312, 0.30842304279688765`, 0.933665119029941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.04610843439966642], {
             RGBColor[
             0.2320502240219991, 0.3612298766540624, 0.9365262890192856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.04610843439966642], {
             RGBColor[
             0.18306798401191893`, 0.3097464367500775, 0.933736822913442]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.04610843439966642], {
             RGBColor[
             0.20348109888236326`, 0.33120191474515054`, 0.9348993196068165]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.04610843439966642], {
             RGBColor[
             0.31320234650668927`, 0.4457018633616062, 0.9411779544588138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.04610843439966642], {
             RGBColor[
             0.19443151506714343`, 0.3216902283786009, 0.9343839591961993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.04610843439966642], {
             RGBColor[
             0.1841862517520943, 0.3109218070472717, 0.933800506606916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.04610843439966642], {
             RGBColor[
             0.8101035860121542, 0.8515783454987672, 0.9817072126714098]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.04610843439966642], {
             RGBColor[
             0.46571418536342124`, 0.577126781719812, 0.9510818731205317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.04610843439966642], {
             RGBColor[
             0.22946131864603458`, 0.3585087729578423, 0.9363788546880667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.04610843439966642], {
             RGBColor[
             0.2015219494351241, 0.32914272445885284`, 0.9347877489440981]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.04610843439966642], {
             RGBColor[
             0.5010318547608589, 0.6057992567795268, 0.9538622094283838]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.04610843439966642], {
             RGBColor[
             0.23298613716021888`, 0.3622135807026517, 0.9365795878879478]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.04610843439966642], {
             RGBColor[
             0.20070591566211698`, 0.3282850212238928, 0.9347412770279392]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.04610843439966642], {
             RGBColor[
             0.34562348099972906`, 0.47378342052587685`, 0.9432438004798267]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.04610843439966642], {
             RGBColor[
             0.995260710048657, 0.9923081960579929, 0.7282058295903809]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.04610843439966642], {
             RGBColor[
             0.1906136828189116, 0.3176774446211637, 0.9341665392976392]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{3.8349504055390835`*^9, 3.835023870141656*^9},
 CellLabel->
  "Out[125]=",ExpressionUUID->"49560f7d-d17e-4336-8e53-4f70051474e1"]
}, Open  ]],

Cell["Estimated with Max-Min Deviation v Calculated: (r = 3)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 3.8349503922098827`*^9}, {3.8349504781120467`*^9, 
  3.8349504928656063`*^9}},ExpressionUUID->"13ab198d-9c2c-4412-b0d6-\
8d14d586bc2e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphin2", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsi2", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}], 
     "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"mMDi3200", ",", "kri2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 3.8349502554527807`*^9}},
 CellLabel->
  "In[126]:=",ExpressionUUID->"9ddb3754-21b2-4cac-be94-5fd86f4e2020"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
          103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
          129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 
          142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 
          155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 
          168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 
          181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 
          194, 195, 196, 197, 198, 199, 200}, {Null, CompressedData["
1:eJwVxfk/Gg4DAOBN5QibNGP1lWNDwghlmCNXuqiMigzJGcNQUi05SwdqhpKc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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[21, 55] -> 
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244], 
             UndirectedEdge[64, 132] -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 
             UndirectedEdge[42, 188] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[26, 166] -> 
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375], 
             UndirectedEdge[33, 68] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[168, 188] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[41, 161] -> 
             RGBColor[0.4106430000000001, 0.5129645, 0.9492445], 
             UndirectedEdge[44, 68] -> 
             RGBColor[0.6380780000000001, 0.7150187500000001, 0.96604625], 
             UndirectedEdge[26, 136] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[9, 32] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[71, 141] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[52, 100] -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 
             UndirectedEdge[172, 180] -> 
             RGBColor[
              0.8128635000000001, 0.8380467500000001, 0.6774381249999999], 
             UndirectedEdge[168, 197] -> 
             RGBColor[0.93101675, 0.9465810000000001, 0.9499267499999999], 
             UndirectedEdge[125, 137] -> 
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375], 
             UndirectedEdge[17, 147] -> 
             RGBColor[0.970857375, 0.97497575, 0.774911], 
             UndirectedEdge[10, 71] -> 
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725], 
             UndirectedEdge[27, 129] -> 
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999], 
             UndirectedEdge[67, 166] -> 
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999], 
             UndirectedEdge[3, 49] -> 
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375], 
             UndirectedEdge[151, 183] -> 
             RGBColor[0.9145691249999999, 0.7572859999999999, 0.5979435], 
             UndirectedEdge[125, 136] -> 
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125], 
             UndirectedEdge[139, 194] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[24, 108] -> 
             RGBColor[0.5259345000000002, 0.6161682500000001, 0.958655875], 
             UndirectedEdge[21, 192] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[16, 52] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[44, 166] -> 
             RGBColor[0.7419731250000001, 0.7804947500000001, 0.671857375], 
             UndirectedEdge[78, 187] -> 
             RGBColor[0.81743425, 0.85585275, 0.86939425], 
             UndirectedEdge[99, 162] -> 
             RGBColor[0.8657703750000001, 0.84386075, 0.6308455], 
             UndirectedEdge[93, 150] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[118, 155] -> 
             RGBColor[0.7419731250000001, 0.7804947500000001, 0.671857375], 
             UndirectedEdge[16, 125] -> 
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999], 
             UndirectedEdge[61, 179] -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 
             UndirectedEdge[51, 197] -> 
             RGBColor[0.932754, 0.77084825, 0.56716125], 
             UndirectedEdge[80, 120] -> 
             RGBColor[0.9548352499999999, 0.85022425, 0.51300225], 
             UndirectedEdge[21, 183] -> 
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375], 
             UndirectedEdge[182, 199] -> 
             RGBColor[0.91616275, 0.6793558749999999, 0.5526845], 
             UndirectedEdge[17, 189] -> 
             RGBColor[0.72420025, 0.7830187500000001, 0.963517], 
             UndirectedEdge[116, 136] -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 
             UndirectedEdge[119, 123] -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 
             UndirectedEdge[71, 89] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[7, 61] -> 
             RGBColor[0.5259345000000002, 0.6161682500000001, 0.958655875], 
             UndirectedEdge[3, 27] -> 
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375], 
             UndirectedEdge[41, 108] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[66, 98] -> 
             RGBColor[0.936562, 0.7861965, 0.2678145], 
             UndirectedEdge[119, 127] -> 
             RGBColor[0.81743425, 0.85585275, 0.86939425], 
             UndirectedEdge[15, 167] -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 
             UndirectedEdge[12, 96] -> 
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455], 
             UndirectedEdge[7, 52] -> 
             RGBColor[0.5259345000000002, 0.6161682500000001, 0.958655875], 
             UndirectedEdge[163, 165] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[71, 73] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[60, 165] -> 
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725], 
             UndirectedEdge[120, 124] -> 
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325], 
             UndirectedEdge[43, 163] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[146, 194] -> 
             RGBColor[0.7298390000000001, 0.42733100000000007`, 0.564603], 
             UndirectedEdge[8, 82] -> 
             RGBColor[0.88264725, 0.540129375, 0.22296500000000002`], 
             UndirectedEdge[81, 157] -> 
             RGBColor[0.970857375, 0.97497575, 0.774911], 
             UndirectedEdge[59, 114] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[31, 185] -> 
             RGBColor[0.578803625, 0.48084775, 0.580862625], 
             UndirectedEdge[58, 198] -> 
             RGBColor[0.577066375, 0.6565805000000001, 0.9636281250000001], 
             UndirectedEdge[30, 142] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[26, 96] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[25, 111] -> 
             RGBColor[0.8629875, 0.6382058749999999, 0.59096825], 
             UndirectedEdge[89, 107] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[51, 189] -> 
             RGBColor[0.6909471250000001, 0.5796982500000001, 0.588253], 
             UndirectedEdge[81, 158] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[93, 159] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[191, 195] -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 
             UndirectedEdge[17, 131] -> 
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075], 
             UndirectedEdge[18, 32] -> 
             RGBColor[0.93101675, 0.9465810000000001, 0.9499267499999999], 
             UndirectedEdge[59, 184] -> 
             RGBColor[
              0.5714686250000001, 0.6629830000000001, 0.9594072499999999], 
             UndirectedEdge[156, 175] -> 
             RGBColor[
              0.7618375000000001, 0.6372502500000001, 0.5938337499999999], 
             UndirectedEdge[2, 82] -> 
             RGBColor[0.8463693750000001, 0.76694225, 0.615235], 
             UndirectedEdge[12, 44] -> 
             RGBColor[0.44080512500000013`, 0.5549417500000001, 0.94966325], 
             UndirectedEdge[115, 175] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[30, 131] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[53, 65] -> 
             RGBColor[0.966007125, 0.97416875, 0.94242525], 
             UndirectedEdge[17, 51] -> 
             RGBColor[0.9145691249999999, 0.7572859999999999, 0.5979435], 
             UndirectedEdge[109, 128] -> 
             RGBColor[0.8795787500000001, 0.72969825, 0.605445], 
             UndirectedEdge[101, 135] -> 
             RGBColor[0.8629875, 0.6382058749999999, 0.59096825], 
             UndirectedEdge[54, 195] -> 
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125], 
             UndirectedEdge[122, 192] -> 
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185], 
             UndirectedEdge[155, 195] -> 
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125], 
             UndirectedEdge[42, 87] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[31, 153] -> 
             RGBColor[0.5259345000000002, 0.6161682500000001, 0.958655875], 
             UndirectedEdge[64, 199] -> 
             RGBColor[
              0.7452462500000001, 0.5457578750000001, 0.5793569999999999], 
             UndirectedEdge[107, 188] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[27, 189] -> 
             RGBColor[0.72420025, 0.7830187500000001, 0.963517], 
             UndirectedEdge[14, 176] -> 
             RGBColor[0.8132755, 0.854133, 0.9383155], 
             UndirectedEdge[123, 146] -> 
             RGBColor[0.7298390000000001, 0.42733100000000007`, 0.564603], 
             UndirectedEdge[30, 130] -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 
             UndirectedEdge[72, 143] -> 
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883], 
             UndirectedEdge[68, 155] -> 
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125], 
             UndirectedEdge[32, 39] -> 
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375], 
             UndirectedEdge[184, 194] -> 
             RGBColor[
              0.5714686250000001, 0.6629830000000001, 0.9594072499999999], 
             UndirectedEdge[74, 152] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[71, 147] -> 
             RGBColor[0.935867, 0.9473880000000001, 0.7824125], 
             UndirectedEdge[39, 173] -> 
             RGBColor[
              0.8128635000000001, 0.8380467500000001, 0.6774381249999999], 
             UndirectedEdge[139, 171] -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 
             UndirectedEdge[73, 189] -> 
             RGBColor[0.44080512500000013`, 0.5549417500000001, 0.94966325], 
             UndirectedEdge[20, 22] -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 
             UndirectedEdge[17, 168] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[13, 132] -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 
             UndirectedEdge[99, 109] -> 
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275], 
             UndirectedEdge[119, 195] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[10, 188] -> 
             RGBColor[0.9324916249999999, 0.83494225, 0.6127057499999999], 
             UndirectedEdge[182, 185] -> 
             RGBColor[0.932754, 0.77084825, 0.5671612500000001], 
             UndirectedEdge[98, 187] -> 
             RGBColor[0.9548352499999999, 0.85022425, 0.51300225], 
             UndirectedEdge[10, 167] -> 
             RGBColor[0.8463693750000001, 0.76694225, 0.615235], 
             UndirectedEdge[113, 187] -> 
             RGBColor[0.9925094999999999, 0.9911705, 0.7738005], 
             UndirectedEdge[83, 170] -> 
             RGBColor[0.8118556250000001, 0.597793625, 0.585996], 
             UndirectedEdge[39, 41] -> 
             RGBColor[
              0.8128635000000001, 0.8380467500000001, 0.6774381249999999], 
             UndirectedEdge[138, 145] -> 
             RGBColor[0.742385125, 0.7965810000000001, 0.9327347500000001], 
             UndirectedEdge[75, 155] -> 
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375], 
             UndirectedEdge[90, 163] -> 
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185], 
             UndirectedEdge[2, 66] -> 
             RGBColor[0.8657703750000001, 0.84386075, 0.6308455], 
             UndirectedEdge[88, 200] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[67, 170] -> 
             RGBColor[0.8979778749999999, 0.665793625, 0.5834667499999999], 
             UndirectedEdge[124, 136] -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 
             UndirectedEdge[129, 155] -> 
             RGBColor[0.983368, 0.9555585, 0.38988824999999994`], 
             UndirectedEdge[149, 167] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[172, 173] -> 
             RGBColor[
              0.8128635000000001, 0.8380467500000001, 0.6774381249999999], 
             UndirectedEdge[143, 160] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[27, 89] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[172, 191] -> 
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125], 
             UndirectedEdge[11, 182] -> 
             RGBColor[0.93101675, 0.9465810000000001, 0.9499267499999999], 
             UndirectedEdge[159, 164] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[151, 156] -> 
             RGBColor[0.881316, 0.5539655, 0.2226795], 
             UndirectedEdge[94, 196] -> 
             RGBColor[0.8629875, 0.638205875, 0.59096825], 
             UndirectedEdge[69, 139] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[53, 127] -> 
             RGBColor[0.98835075, 0.98945075, 0.8427217499999999], 
             UndirectedEdge[171, 196] -> 
             RGBColor[0.8118556250000001, 0.597793625, 0.585996], 
             UndirectedEdge[40, 65] -> 
             RGBColor[0.8825706249999999, 0.5473667499999999, 0.56871275], 
             UndirectedEdge[74, 162] -> 
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775], 
             UndirectedEdge[34, 153] -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 
             UndirectedEdge[98, 109] -> 
             RGBColor[0.8992385, 0.6316217500000001, 0.23744175], 
             UndirectedEdge[77, 183] -> 
             RGBColor[0.9518926249999999, 0.91186075, 0.6283162499999999], 
             UndirectedEdge[2, 78] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[113, 193] -> 
             RGBColor[0.9548352499999999, 0.85022425, 0.51300225], 
             UndirectedEdge[100, 120] -> 
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325], 
             UndirectedEdge[1, 35] -> 
             RGBColor[0.9203215, 0.681075625, 0.48376325], 
             UndirectedEdge[154, 176] -> 
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244], 
             UndirectedEdge[13, 31] -> 
             RGBColor[0.4593251250000001, 0.5641325000000001, 0.952016875], 
             UndirectedEdge[92, 196] -> 
             RGBColor[0.8629875, 0.638205875, 0.59096825], 
             UndirectedEdge[66, 124] -> 
             RGBColor[0.8657703750000001, 0.84386075, 0.6308455], 
             UndirectedEdge[141, 167] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[76, 158] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[101, 134] -> 
             RGBColor[0.9203215, 0.6810756249999999, 0.48376325], 
             UndirectedEdge[139, 141] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[88, 93] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[17, 130] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[32, 117] -> 
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725], 
             UndirectedEdge[32, 103] -> 
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375], 
             UndirectedEdge[148, 150] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[77, 156] -> 
             RGBColor[0.9186395, 0.70854025, 0.25305225], 
             UndirectedEdge[76, 89] -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 
             UndirectedEdge[42, 51] -> 
             RGBColor[0.8795787500000001, 0.72969825, 0.605445], 
             UndirectedEdge[82, 124] -> 
             RGBColor[0.8463693750000001, 0.76694225, 0.615235], 
             UndirectedEdge[15, 114] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[41, 173] -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 
             UndirectedEdge[41, 133] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[27, 147] -> 
             RGBColor[0.970857375, 0.97497575, 0.774911], 
             UndirectedEdge[19, 88] -> 
             RGBColor[0.9518926249999999, 0.91186075, 0.6283162499999999], 
             UndirectedEdge[127, 172] -> 
             RGBColor[0.98793875, 0.9733645, 0.581844375], 
             UndirectedEdge[69, 174] -> 
             RGBColor[0.577066375, 0.6565805000000001, 0.9636281250000001], 
             UndirectedEdge[117, 121] -> 
             RGBColor[0.8463693750000001, 0.76694225, 0.615235], 
             UndirectedEdge[69, 196] -> 
             RGBColor[0.8629875, 0.638205875, 0.59096825], 
             UndirectedEdge[92, 195] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[144, 158] -> 
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883], 
             UndirectedEdge[81, 168] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[87, 188] -> 
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375], 
             UndirectedEdge[74, 88] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[74, 140] -> 
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775], 
             UndirectedEdge[152, 178] -> 
             RGBColor[0.8979778749999999, 0.665793625, 0.5834667499999999], 
             UndirectedEdge[63, 153] -> 
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275], 
             UndirectedEdge[154, 158] -> 
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883], 
             UndirectedEdge[23, 90] -> 
             RGBColor[0.44080512500000013`, 0.5549417500000001, 0.94966325], 
             UndirectedEdge[51, 131] -> 
             RGBColor[0.9145691249999999, 0.7572859999999999, 0.5979435], 
             UndirectedEdge[21, 83] -> 
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883], 
             UndirectedEdge[57, 178] -> 
             RGBColor[
              0.6145827500000001, 0.43771662499999997`, 0.5696129999999999], 
             UndirectedEdge[17, 197] -> 
             RGBColor[0.966007125, 0.97416875, 0.94242525], 
             UndirectedEdge[64, 156] -> 
             RGBColor[
              0.7618375000000001, 0.6372502500000001, 0.5938337499999999], 
             UndirectedEdge[40, 123] -> 
             RGBColor[0.7298390000000001, 0.42733100000000007`, 0.564603], 
             UndirectedEdge[26, 99] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[114, 167] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[75, 168] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[55, 111] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[67, 122] -> 
             RGBColor[0.72420025, 0.7830187500000001, 0.963517], 
             UndirectedEdge[127, 129] -> 
             RGBColor[0.98793875, 0.9733645, 0.581844375], 
             UndirectedEdge[96, 198] -> 
             RGBColor[0.3286616250000001, 0.45609125000000006`, 0.942272875], 
             UndirectedEdge[154, 181] -> 
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883], 
             UndirectedEdge[9, 91] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[39, 152] -> 
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999], 
             UndirectedEdge[54, 65] -> 
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999], 
             UndirectedEdge[116, 128] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[74, 95] -> 
             RGBColor[0.8629875, 0.638205875, 0.59096825], 
             UndirectedEdge[152, 200] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[140, 191] -> 
             RGBColor[0.8657703750000001, 0.84386075, 0.6308455], 
             UndirectedEdge[109, 193] -> 
             RGBColor[0.8992385, 0.6316217500000001, 0.23744175], 
             UndirectedEdge[80, 137] -> 
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725], 
             UndirectedEdge[118, 199] -> 
             RGBColor[0.674355875, 0.488205875, 0.57377625], 
             UndirectedEdge[45, 64] -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 
             UndirectedEdge[125, 170] -> 
             RGBColor[0.91575075, 0.663269625, 0.29180712499999995`], 
             UndirectedEdge[70, 145] -> 
             RGBColor[0.966007125, 0.97416875, 0.94242525], 
             UndirectedEdge[17, 142] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[95, 180] -> 
             RGBColor[0.7452462500000001, 0.5457578750000001, 0.579357], 
             UndirectedEdge[41, 121] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[5, 10] -> 
             RGBColor[0.917161, 0.7092780000000001, 0.25220400000000004`], 
             UndirectedEdge[167, 194] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[78, 100] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[106, 157] -> 
             RGBColor[0.68746225, 0.7468987500000001, 0.76105725], 
             UndirectedEdge[24, 115] -> 
             RGBColor[0.5259345000000002, 0.6161682500000001, 0.958655875], 
             UndirectedEdge[74, 164] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[46, 135] -> 
             RGBColor[0.8629875, 0.6382058749999999, 0.59096825], 
             UndirectedEdge[126, 190] -> 
             RGBColor[
              0.7618375000000001, 0.6372502500000001, 0.5938337499999999], 
             UndirectedEdge[21, 177] -> 
             RGBColor[0.6684975000000001, 0.68378375, 0.6144625], 
             UndirectedEdge[24, 133] -> 
             RGBColor[0.5259345000000002, 0.6161682500000001, 0.958655875], 
             UndirectedEdge[30, 188] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[80, 98] -> 
             RGBColor[0.917161, 0.7092780000000001, 0.25220400000000004`], 
             UndirectedEdge[12, 102] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[51, 168] -> 
             RGBColor[0.8795787500000001, 0.72969825, 0.605445], 
             UndirectedEdge[42, 189] -> 
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185], 
             UndirectedEdge[52, 187] -> 
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325], 
             UndirectedEdge[10, 89] -> 
             RGBColor[0.77976, 0.7149065000000001, 0.6085959999999999], 
             UndirectedEdge[148, 193] -> 
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725], 
             UndirectedEdge[4, 92] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[28, 97] -> 
             RGBColor[0.9351754999999999, 0.94830075, 0.8810055], 
             UndirectedEdge[60, 169] -> 
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725], 
             UndirectedEdge[44, 198] -> 
             RGBColor[0.3884347500000001, 0.5065805000000001, 0.946436125], 
             UndirectedEdge[13, 64] -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 
             UndirectedEdge[42, 106] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[43, 90] -> 
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185], 
             UndirectedEdge[166, 192] -> 
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375], 
             UndirectedEdge[5, 89] -> 
             RGBColor[0.77976, 0.7149065000000001, 0.6085959999999999], 
             UndirectedEdge[114, 184] -> 
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185], 
             UndirectedEdge[58, 192] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[17, 157] -> 
             RGBColor[0.970857375, 0.97497575, 0.774911], 
             UndirectedEdge[38, 111] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[3, 191] -> 
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883], 
             UndirectedEdge[40, 195] -> 
             RGBColor[0.7964483750000001, 0.47936675000000006`, 0.571242], 
             UndirectedEdge[113, 136] -> 
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325], 
             UndirectedEdge[53, 141] -> 
             RGBColor[0.93101675, 0.9465810000000001, 0.9499267499999999], 
             UndirectedEdge[142, 176] -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 
             UndirectedEdge[99, 128] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[41, 151] -> 
             RGBColor[
              0.7618375000000001, 0.6372502500000001, 0.5938337499999999], 
             UndirectedEdge[5, 157] -> 
             RGBColor[0.95552675, 0.8493115, 0.41440925000000006`], 
             UndirectedEdge[39, 74] -> 
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375], 
             UndirectedEdge[86, 171] -> 
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275], 
             UndirectedEdge[162, 180] -> 
             RGBColor[0.799161, 0.791825, 0.6242064999999999], 
             UndirectedEdge[27, 127] -> 
             RGBColor[0.970165875, 0.9758884999999999, 0.8735040000000001], 
             UndirectedEdge[41, 88] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[155, 191] -> 
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125], 
             UndirectedEdge[46, 105] -> 
             RGBColor[0.8118556250000001, 0.597793625, 0.585996], 
             UndirectedEdge[30, 168] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[161, 180] -> 
             RGBColor[0.4106430000000001, 0.5129645, 0.9492445], 
             UndirectedEdge[125, 192] -> 
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375], 
             UndirectedEdge[33, 140] -> 
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775], 
             UndirectedEdge[12, 58] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[127, 155] -> 
             RGBColor[0.98793875, 0.9733645, 0.581844375], 
             UndirectedEdge[78, 120] -> 
             RGBColor[0.81743425, 0.85585275, 0.86939425], 
             UndirectedEdge[45, 183] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[98, 136] -> 
             RGBColor[0.8463693750000001, 0.76694225, 0.615235], 
             UndirectedEdge[59, 92] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[81, 89] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[161, 200] -> 
             RGBColor[0.52838425, 0.6054125000000001, 0.96085575], 
             UndirectedEdge[125, 198] -> 
             RGBColor[
              0.6298296250000001, 0.6816442500000001, 0.6644669999999999], 
             UndirectedEdge[159, 173] -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 
             UndirectedEdge[54, 151] -> 
             RGBColor[0.932342, 0.7547619999999999, 0.306283875], 
             UndirectedEdge[61, 192] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[59, 194] -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 
             UndirectedEdge[80, 82] -> 
             RGBColor[0.917161, 0.7092780000000001, 0.25220400000000004`], 
             UndirectedEdge[157, 168] -> 
             RGBColor[0.935867, 0.9473880000000001, 0.7824125], 
             UndirectedEdge[122, 170] -> 
             RGBColor[0.674355875, 0.488205875, 0.57377625], 
             UndirectedEdge[26, 67] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[160, 181] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[42, 168] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[61, 67] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[9, 39] -> 
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999], 
             UndirectedEdge[118, 171] -> 
             RGBColor[0.6380780000000001, 0.7150187500000001, 0.96604625], 
             UndirectedEdge[97, 134] -> 
             RGBColor[0.9351754999999999, 0.94830075, 0.8810055], 
             UndirectedEdge[79, 190] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[47, 50] -> 
             RGBColor[0.8795787500000001, 0.72969825, 0.605445], 
             UndirectedEdge[36, 145] -> 
             RGBColor[0.98378, 0.9716447500000001, 0.650765625], 
             UndirectedEdge[170, 179] -> 
             RGBColor[0.8118556250000001, 0.597793625, 0.585996], 
             UndirectedEdge[26, 198] -> 
             RGBColor[0.577066375, 0.6565805000000001, 0.9636281250000001], 
             UndirectedEdge[5, 141] -> 
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725], 
             UndirectedEdge[18, 39] -> 
             RGBColor[0.98378, 0.9716447500000001, 0.650765625], 
             UndirectedEdge[19, 180] -> 
             RGBColor[0.799161, 0.791825, 0.6242064999999999], 
             UndirectedEdge[170, 198] -> 
             RGBColor[0.5622123750000001, 0.389355375, 0.566385875], 
             UndirectedEdge[12, 172] -> 
             RGBColor[
              0.6822000000000001, 0.7300055000000001, 0.6676941249999999], 
             UndirectedEdge[47, 101] -> 
             RGBColor[0.8647247499999999, 0.46247312499999993`, 0.20820275], 
             UndirectedEdge[53, 54] -> 
             RGBColor[0.98378, 0.9716447500000001, 0.650765625], 
             UndirectedEdge[57, 121] -> 
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883], 
             UndirectedEdge[19, 121] -> 
             RGBColor[0.8657703750000001, 0.84386075, 0.6308455], 
             UndirectedEdge[170, 192] -> 
             RGBColor[0.8629875, 0.6382058749999999, 0.59096825], 
             UndirectedEdge[7, 137] -> 
             RGBColor[0.577066375, 0.6565805000000001, 0.9636281250000001], 
             UndirectedEdge[111, 115] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[140, 162] -> 
             RGBColor[0.955963, 0.863115, 0.283425], UndirectedEdge[8, 79] -> 
             RGBColor[0.8118556250000001, 0.597793625, 0.585996], 
             UndirectedEdge[2, 52] -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 
             UndirectedEdge[18, 152] -> 
             RGBColor[0.966007125, 0.97416875, 0.94242525], 
             UndirectedEdge[4, 195] -> 
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883], 
             UndirectedEdge[81, 107] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[108, 175] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[49, 191] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[77, 192] -> 
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775], 
             UndirectedEdge[21, 166] -> 
             RGBColor[
              0.6822000000000001, 0.7300055000000001, 0.6676941249999999], 
             UndirectedEdge[8, 192] -> 
             RGBColor[0.8629875, 0.6382058749999999, 0.59096825], 
             UndirectedEdge[108, 165] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[29, 194] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[106, 131] -> 
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375], 
             UndirectedEdge[12, 68] -> 
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883], 
             UndirectedEdge[71, 168] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[49, 146] -> 
             RGBColor[0.8825706249999999, 0.5473667499999999, 0.56871275], 
             UndirectedEdge[112, 134] -> 
             RGBColor[0.98835075, 0.98945075, 0.8427217499999999], 
             UndirectedEdge[84, 126] -> 
             RGBColor[0.881316, 0.5539655, 0.2226795], UndirectedEdge[10, 62] -> 
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725], 
             UndirectedEdge[34, 182] -> 
             RGBColor[
              0.8798848750000001, 0.9061687500000001, 0.9449544999999999], 
             UndirectedEdge[106, 107] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[67, 79] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[33, 96] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[12, 140] -> 
             RGBColor[0.6684975000000001, 0.68378375, 0.6144625], 
             UndirectedEdge[26, 124] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[13, 70] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[53, 146] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[87, 147] -> 
             RGBColor[0.68746225, 0.7468987500000001, 0.76105725], 
             UndirectedEdge[93, 200] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[9, 117] -> 
             RGBColor[0.9324916249999999, 0.83494225, 0.61270575], 
             UndirectedEdge[99, 116] -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 
             UndirectedEdge[71, 155] -> 
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375], 
             UndirectedEdge[54, 140] -> 
             RGBColor[0.9696655000000001, 0.90933675, 0.33665662499999993`], 
             UndirectedEdge[76, 154] -> 
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244], 
             UndirectedEdge[33, 128] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[109, 148] -> 
             RGBColor[0.8795787500000001, 0.72969825, 0.605445], 
             UndirectedEdge[27, 142] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[49, 69] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[60, 90] -> 
             RGBColor[
              0.7088696250000001, 0.6573545000000001, 0.6030152500000001], 
             UndirectedEdge[40, 191] -> 
             RGBColor[0.7964483750000001, 0.47936675000000006`, 0.571242], 
             UndirectedEdge[58, 166] -> 
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375], 
             UndirectedEdge[38, 60] -> 
             RGBColor[0.77976, 0.7149065000000001, 0.608596], 
             UndirectedEdge[54, 119] -> 
             RGBColor[
              0.8128635000000001, 0.8380467500000001, 0.6774381249999999], 
             UndirectedEdge[3, 146] -> 
             RGBColor[0.5991755000000001, 0.31928975000000004`, 0.554859], 
             UndirectedEdge[115, 163] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[137, 170] -> 
             RGBColor[0.8629875, 0.638205875, 0.59096825], 
             UndirectedEdge[58, 99] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[40, 64] -> 
             RGBColor[0.7298390000000001, 0.42733100000000007`, 0.564603], 
             UndirectedEdge[77, 96] -> 
             RGBColor[0.6684975000000001, 0.68378375, 0.6144624999999999], 
             UndirectedEdge[141, 195] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[138, 182] -> 
             RGBColor[0.742385125, 0.7965810000000001, 0.9327347500000001], 
             UndirectedEdge[33, 102] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[137, 198] -> 
             RGBColor[0.577066375, 0.6565805000000001, 0.9636281250000001], 
             UndirectedEdge[69, 171] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[20, 46] -> 
             RGBColor[
              0.7452462500000001, 0.5457578750000001, 0.5793569999999999], 
             UndirectedEdge[76, 157] -> 
             RGBColor[0.8181257500000001, 0.85494, 0.77080125], 
             UndirectedEdge[10, 168] -> 
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725], 
             UndirectedEdge[82, 100] -> 
             RGBColor[0.8463693750000001, 0.76694225, 0.615235], 
             UndirectedEdge[9, 57] -> 
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375], 
             UndirectedEdge[27, 71] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[122, 125] -> 
             RGBColor[0.7419731250000001, 0.7804947500000001, 0.671857375], 
             UndirectedEdge[5, 147] -> 
             RGBColor[0.95552675, 0.8493115, 0.41440925000000006`], 
             UndirectedEdge[5, 71] -> 
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725], 
             UndirectedEdge[61, 84] -> 
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275], 
             UndirectedEdge[62, 149] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[36, 138] -> 
             RGBColor[0.7419731250000001, 0.7804947500000001, 0.671857375], 
             UndirectedEdge[33, 162] -> 
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775], 
             UndirectedEdge[63, 145] -> 
             RGBColor[0.932754, 0.77084825, 0.56716125], 
             UndirectedEdge[93, 173] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[23, 55] -> 
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244], 
             UndirectedEdge[23, 165] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[54, 64] -> 
             RGBColor[
              0.8128635000000001, 0.8380467500000001, 0.6774381249999999], 
             UndirectedEdge[72, 158] -> 
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883], 
             UndirectedEdge[73, 149] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[10, 197] -> 
             RGBColor[0.9506764999999999, 0.8485045, 0.5819235], 
             UndirectedEdge[37, 135] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[58, 96] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[112, 156] -> 
             RGBColor[0.932754, 0.77084825, 0.5671612500000001], 
             UndirectedEdge[2, 187] -> 
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325], 
             UndirectedEdge[43, 169] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[44, 96] -> 
             RGBColor[0.44080512500000013`, 0.5549417500000001, 0.94966325], 
             UndirectedEdge[88, 161] -> 
             RGBColor[
              0.5633746249999999, 0.6330002499999999, 0.9533542500000001], 
             UndirectedEdge[129, 146] -> 
             RGBColor[0.9003435, 0.5448427499999999, 0.27705312499999996`], 
             UndirectedEdge[23, 111] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[174, 196] -> 
             RGBColor[0.5622123750000001, 0.389355375, 0.5663858749999999], 
             UndirectedEdge[66, 100] -> 
             RGBColor[0.8657703750000001, 0.84386075, 0.6308455], 
             UndirectedEdge[10, 73] -> 
             RGBColor[0.6490965000000001, 0.60686525, 0.5988519999999999], 
             UndirectedEdge[147, 188] -> 
             RGBColor[0.970857375, 0.97497575, 0.774911], 
             UndirectedEdge[62, 189] -> 
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185], 
             UndirectedEdge[42, 89] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[119, 140] -> 
             RGBColor[0.799161, 0.791825, 0.6242065], 
             UndirectedEdge[140, 151] -> 
             RGBColor[0.9186395, 0.70854025, 0.25305225], 
             UndirectedEdge[1, 86] -> 
             RGBColor[0.93691275, 0.7725679999999999, 0.49824], 
             UndirectedEdge[76, 181] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[122, 166] -> 
             RGBColor[0.7419731250000001, 0.7804947500000001, 0.671857375], 
             UndirectedEdge[10, 189] -> 
             RGBColor[
              0.7088696250000001, 0.6573545000000001, 0.6030152500000001], 
             UndirectedEdge[102, 162] -> 
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775], 
             UndirectedEdge[156, 183] -> 
             RGBColor[0.9145691249999999, 0.7572859999999999, 0.5979435], 
             UndirectedEdge[31, 199] -> 
             RGBColor[0.5622123750000001, 0.389355375, 0.5663858749999999], 
             UndirectedEdge[73, 130] -> 
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883], 
             UndirectedEdge[4, 199] -> 
             RGBColor[
              0.6145827500000001, 0.43771662499999997`, 0.5696129999999999], 
             UndirectedEdge[6, 83] -> 
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125], 
             UndirectedEdge[73, 89] -> 
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244], 
             UndirectedEdge[60, 111] -> 
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725], 
             UndirectedEdge[166, 179] -> 
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125], 
             UndirectedEdge[30, 197] -> 
             RGBColor[
              0.8798848750000001, 0.9061687500000001, 0.9449544999999999], 
             UndirectedEdge[26, 58] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[11, 35] -> 
             RGBColor[0.8629875, 0.638205875, 0.59096825], 
             UndirectedEdge[137, 187] -> 
             RGBColor[0.9351754999999999, 0.94830075, 0.8810055], 
             UndirectedEdge[13, 153] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[71, 75] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[16, 67] -> 
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075], 
             UndirectedEdge[156, 170] -> 
             RGBColor[0.8647247499999999, 0.46247312499999993`, 0.20820275], 
             UndirectedEdge[96, 128] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[62, 114] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[101, 105] -> 
             RGBColor[0.8118556250000001, 0.597793625, 0.585996], 
             UndirectedEdge[30, 89] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[53, 191] -> 
             RGBColor[
              0.8798848750000001, 0.9061687500000001, 0.9449544999999999], 
             UndirectedEdge[72, 81] -> 
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375], 
             UndirectedEdge[163, 175] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[82, 125] -> 
             RGBColor[0.9502645000000001, 0.83241825, 0.32104612499999996`], 
             UndirectedEdge[113, 148] -> 
             RGBColor[0.9351754999999999, 0.94830075, 0.8810055], 
             UndirectedEdge[33, 44] -> 
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185], 
             UndirectedEdge[21, 179] -> 
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883], 
             UndirectedEdge[75, 188] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[85, 88] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[13, 185] -> 
             RGBColor[
              0.7618375000000001, 0.6372502500000001, 0.5938337499999999], 
             UndirectedEdge[93, 161] -> 
             RGBColor[0.52838425, 0.6054125, 0.96085575], 
             UndirectedEdge[146, 196] -> 
             RGBColor[0.83272625, 0.2525538749999999, 0.178972], 
             UndirectedEdge[19, 162] -> 
             RGBColor[0.955963, 0.863115, 0.283425], UndirectedEdge[140, 172] -> 
             RGBColor[0.9696655000000001, 0.90933675, 0.33665662499999993`], 
             UndirectedEdge[71, 142] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[87, 142] -> 
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244], 
             UndirectedEdge[89, 147] -> 
             RGBColor[0.8181257500000001, 0.85494, 0.77080125], 
             UndirectedEdge[30, 42] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[8, 125] -> 
             RGBColor[0.91575075, 0.6632696249999999, 0.29180712499999995`], 
             UndirectedEdge[29, 168] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[158, 160] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[138, 153] -> 
             RGBColor[0.6380780000000001, 0.7150187500000001, 0.96604625], 
             UndirectedEdge[26, 122] -> 
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185], 
             UndirectedEdge[53, 195] -> 
             RGBColor[
              0.8798848750000001, 0.9061687500000001, 0.9449544999999999], 
             UndirectedEdge[19, 93] -> 
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775], 
             UndirectedEdge[11, 196] -> 
             RGBColor[0.8629875, 0.638205875, 0.59096825], 
             UndirectedEdge[87, 168] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[78, 124] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[39, 117] -> 
             RGBColor[0.9502645000000001, 0.83241825, 0.32104612499999996`], 
             UndirectedEdge[42, 130] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[11, 94] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[27, 168] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[30, 51] -> 
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275], 
             UndirectedEdge[6, 58] -> 
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375], 
             UndirectedEdge[6, 156] -> 
             RGBColor[0.932342, 0.7547619999999999, 0.306283875], 
             UndirectedEdge[19, 173] -> 
             RGBColor[0.799161, 0.791825, 0.6242064999999999], 
             UndirectedEdge[57, 200] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[37, 50] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[49, 171] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[5, 127] -> 
             RGBColor[0.9548352499999999, 0.85022425, 0.51300225], 
             UndirectedEdge[85, 152] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[130, 131] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[33, 58] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[82, 98] -> 
             RGBColor[0.917161, 0.7092780000000001, 0.25220400000000004`], 
             UndirectedEdge[74, 173] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[118, 146] -> 
             RGBColor[
              0.6589486250000001, 0.3697790000000001, 0.5590222499999999], 
             UndirectedEdge[23, 115] -> 
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883], 
             UndirectedEdge[49, 65] -> 
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075], 
             UndirectedEdge[21, 23] -> 
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455], 
             UndirectedEdge[40, 171] -> 
             RGBColor[0.7964483750000001, 0.47936675000000006`, 0.571242], 
             UndirectedEdge[104, 158] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[53, 155] -> 
             RGBColor[0.98378, 0.9716447500000001, 0.650765625], 
             UndirectedEdge[164, 200] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[81, 142] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[39, 85] -> 
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375], 
             UndirectedEdge[107, 142] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[121, 161] -> 
             RGBColor[0.47725237500000006`, 0.5650002500000001, 0.9558835], 
             UndirectedEdge[1, 196] -> 
             RGBColor[0.9203215, 0.681075625, 0.48376325], 
             UndirectedEdge[88, 121] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[85, 133] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[118, 127] -> 
             RGBColor[0.746543875, 0.7983007500000001, 0.8638135], 
             UndirectedEdge[100, 187] -> 
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325], 
             UndirectedEdge[26, 116] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[131, 147] -> 
             RGBColor[0.970857375, 0.97497575, 0.774911], 
             UndirectedEdge[134, 160] -> 
             RGBColor[0.9351754999999999, 0.94830075, 0.8810055], 
             UndirectedEdge[3, 5] -> 
             RGBColor[0.6490965000000001, 0.60686525, 0.598852], 
             UndirectedEdge[16, 100] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[75, 147] -> 
             RGBColor[0.935867, 0.9473880000000001, 0.7824125], 
             UndirectedEdge[72, 76] -> 
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244], 
             UndirectedEdge[40, 69] -> 
             RGBColor[0.84758025, 0.519779, 0.57621425], 
             UndirectedEdge[177, 179] -> 
             RGBColor[0.8657703750000001, 0.84386075, 0.6308455], 
             UndirectedEdge[98, 100] -> 
             RGBColor[0.8463693750000001, 0.76694225, 0.615235], 
             UndirectedEdge[136, 187] -> 
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325], 
             UndirectedEdge[54, 199] -> 
             RGBColor[0.91575075, 0.663269625, 0.29180712499999995`], 
             UndirectedEdge[166, 198] -> 
             RGBColor[
              0.6298296250000001, 0.6816442500000001, 0.6644669999999999], 
             UndirectedEdge[48, 104] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[187, 198] -> 
             RGBColor[0.634400375, 0.69945025, 0.8564231250000001], 
             UndirectedEdge[29, 62] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[103, 117] -> 
             RGBColor[0.9502645000000001, 0.83241825, 0.32104612499999996`], 
             UndirectedEdge[85, 140] -> 
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775], 
             UndirectedEdge[36, 70] -> 
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999], 
             UndirectedEdge[54, 171] -> 
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125], 
             UndirectedEdge[120, 125] -> 
             RGBColor[0.98793875, 0.9733645, 0.581844375], 
             UndirectedEdge[81, 104] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[93, 162] -> 
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775], 
             UndirectedEdge[73, 168] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[119, 199] -> 
             RGBColor[
              0.7452462500000001, 0.5457578750000001, 0.5793569999999999], 
             UndirectedEdge[17, 107] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[14, 48] -> 
             RGBColor[0.93101675, 0.9465810000000001, 0.9499267499999999], 
             UndirectedEdge[64, 182] -> 
             RGBColor[0.8132755, 0.854133, 0.9383155], 
             UndirectedEdge[71, 129] -> 
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375], 
             UndirectedEdge[80, 100] -> 
             RGBColor[0.8463693750000001, 0.76694225, 0.615235], 
             UndirectedEdge[18, 178] -> 
             RGBColor[0.91616275, 0.6793558749999999, 0.5526845], 
             UndirectedEdge[174, 186] -> 
             RGBColor[0.616127125, 0.6354225, 0.611235375], 
             UndirectedEdge[115, 165] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[113, 198] -> 
             RGBColor[0.634400375, 0.69945025, 0.8564231250000001], 
             UndirectedEdge[67, 100] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[106, 147] -> 
             RGBColor[0.68746225, 0.7468987500000001, 0.76105725], 
             UndirectedEdge[75, 129] -> 
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375], 
             UndirectedEdge[175, 183] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[105, 144] -> 
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883], 
             UndirectedEdge[44, 128] -> 
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185], 
             UndirectedEdge[70, 138] -> 
             RGBColor[0.72420025, 0.7830187500000001, 0.963517], 
             UndirectedEdge[110, 145] -> 
             RGBColor[0.8132755, 0.854133, 0.9383155], 
             UndirectedEdge[49, 118] -> 
             RGBColor[0.72420025, 0.7830187500000001, 0.963517], 
             UndirectedEdge[70, 185] -> 
             RGBColor[0.9145691249999999, 0.7572859999999999, 0.5979435], 
             UndirectedEdge[11, 138] -> 
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185], 
             UndirectedEdge[120, 187] -> 
             RGBColor[0.9925094999999999, 0.9911705, 0.7738005], 
             UndirectedEdge[71, 127] -> 
             RGBColor[0.9351754999999999, 0.94830075, 0.8810055], 
             UndirectedEdge[4, 182] -> 
             RGBColor[0.682612, 0.74609175, 0.9285715], 
             UndirectedEdge[29, 71] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[63, 185] -> 
             RGBColor[0.881316, 0.5539655, 0.2226795], 
             UndirectedEdge[83, 175] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[79, 126] -> 
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275], 
             UndirectedEdge[107, 154] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[34, 64] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[159, 180] -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 
             UndirectedEdge[3, 123] -> 
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244], 
             UndirectedEdge[50, 97] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[87, 89] -> 
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244], 
             UndirectedEdge[123, 191] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[108, 151] -> 
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275], 
             UndirectedEdge[16, 187] -> 
             RGBColor[0.970165875, 0.9758884999999999, 0.8735040000000001], 
             UndirectedEdge[19, 33] -> 
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775], 
             UndirectedEdge[156, 199] -> 
             RGBColor[0.8647247499999999, 0.46247312499999993`, 0.20820275], 
             UndirectedEdge[47, 144] -> 
             RGBColor[0.6311740000000001, 0.529209, 0.58408975], 
             UndirectedEdge[123, 127] -> 
             RGBColor[0.81743425, 0.85585275, 0.86939425], 
             UndirectedEdge[82, 120] -> 
             RGBColor[0.9548352499999999, 0.85022425, 0.51300225], 
             UndirectedEdge[120, 137] -> 
             RGBColor[0.9351754999999999, 0.94830075, 0.8810055], 
             UndirectedEdge[122, 179] -> 
             RGBColor[0.6380780000000001, 0.7150187500000001, 0.96604625], 
             UndirectedEdge[52, 124] -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 
             UndirectedEdge[17, 106] -> 
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375], 
             UndirectedEdge[125, 166] -> 
             RGBColor[0.983368, 0.9555585, 0.38988824999999994`], 
             UndirectedEdge[7, 79] -> 
             RGBColor[0.5259345000000002, 0.6161682500000001, 0.958655875], 
             UndirectedEdge[49, 127] -> 
             RGBColor[0.970165875, 0.9758884999999999, 0.8735040000000001], 
             UndirectedEdge[121, 200] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[56, 193] -> 
             RGBColor[0.8463693750000001, 0.76694225, 0.615235], 
             UndirectedEdge[149, 194] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[108, 133] -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 
             UndirectedEdge[41, 140] -> 
             RGBColor[0.799161, 0.791825, 0.6242065], UndirectedEdge[36, 185] -> 
             RGBColor[0.932342, 0.7547619999999999, 0.306283875], 
             UndirectedEdge[108, 111] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[72, 154] -> 
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455], 
             UndirectedEdge[63, 110] -> 
             RGBColor[
              0.7618375000000001, 0.6372502500000001, 0.5938337499999999], 
             UndirectedEdge[15, 186] -> 
             RGBColor[0.8657703750000001, 0.84386075, 0.6308455], 
             UndirectedEdge[54, 155] -> 
             RGBColor[0.983368, 0.9555585, 0.38988824999999994`], 
             UndirectedEdge[18, 108] -> 
             RGBColor[
              0.8798848750000001, 0.9061687500000001, 0.9449544999999999], 
             UndirectedEdge[44, 102] -> 
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185], 
             UndirectedEdge[8, 122] -> 
             RGBColor[0.674355875, 0.488205875, 0.57377625], 
             UndirectedEdge[42, 197] -> 
             RGBColor[0.93101675, 0.9465810000000001, 0.9499267499999999], 
             UndirectedEdge[48, 147] -> 
             RGBColor[0.935867, 0.9473880000000001, 0.7824125], 
             UndirectedEdge[34, 54] -> 
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125], 
             UndirectedEdge[5, 75] -> 
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725], 
             UndirectedEdge[55, 115] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[49, 155] -> 
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999], 
             UndirectedEdge[66, 136] -> 
             RGBColor[0.8657703750000001, 0.84386075, 0.6308455], 
             UndirectedEdge[136, 148] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[130, 189] -> 
             RGBColor[0.6380780000000001, 0.7150187500000001, 0.96604625], 
             UndirectedEdge[48, 76] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[29, 141] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[133, 163] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[111, 169] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[76, 142] -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 
             UndirectedEdge[78, 98] -> 
             RGBColor[0.77976, 0.7149065000000001, 0.608596], 
             UndirectedEdge[21, 170] -> 
             RGBColor[
              0.6145827500000001, 0.43771662499999997`, 0.5696129999999999], 
             UndirectedEdge[92, 139] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[63, 70] -> 
             RGBColor[0.9145691249999999, 0.7572859999999999, 0.5979435], 
             UndirectedEdge[71, 197] -> 
             RGBColor[0.93101675, 0.9465810000000001, 0.9499267499999999], 
             UndirectedEdge[127, 141] -> 
             RGBColor[0.9351754999999999, 0.94830075, 0.8810055], 
             UndirectedEdge[64, 138] -> 
             RGBColor[
              0.5714686250000001, 0.6629830000000001, 0.9594072499999999], 
             UndirectedEdge[39, 108] -> 
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125], 
             UndirectedEdge[24, 165] -> 
             RGBColor[0.577066375, 0.6565805000000001, 0.9636281250000001], 
             UndirectedEdge[132, 182] -> 
             RGBColor[0.8132755, 0.854133, 0.9383155], 
             UndirectedEdge[77, 181] -> 
             RGBColor[0.8657703750000001, 0.84386075, 0.6308455], 
             UndirectedEdge[20, 47] -> 
             RGBColor[
              0.7618375000000001, 0.6372502500000001, 0.5938337499999999], 
             UndirectedEdge[191, 199] -> 
             RGBColor[0.8118556250000001, 0.597793625, 0.585996], 
             UndirectedEdge[89, 154] -> 
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244], 
             UndirectedEdge[93, 164] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[26, 187] -> 
             RGBColor[0.9351754999999999, 0.94830075, 0.8810055], 
             UndirectedEdge[5, 188] -> 
             RGBColor[0.9324916249999999, 0.83494225, 0.6127057499999999], 
             UndirectedEdge[7, 16] -> 
             RGBColor[0.61205675, 0.6841682499999999, 0.956126625], 
             UndirectedEdge[154, 160] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[88, 152] -> 
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075], 
             UndirectedEdge[9, 18] -> 
             RGBColor[0.966007125, 0.97416875, 0.94242525], 
             UndirectedEdge[9, 200] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[55, 183] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[72, 104] -> 
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244], 
             UndirectedEdge[112, 181] -> 
             RGBColor[
              0.8798848750000001, 0.9061687500000001, 0.9449544999999999], 
             UndirectedEdge[136, 193] -> 
             RGBColor[0.8463693750000001, 0.76694225, 0.615235], 
             UndirectedEdge[80, 198] -> 
             RGBColor[0.596726125, 0.5585040000000001, 0.5956248749999999], 
             UndirectedEdge[42, 131] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[65, 156] -> 
             RGBColor[0.9145691249999999, 0.7572859999999999, 0.5979435], 
             UndirectedEdge[26, 192] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[65, 155] -> 
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999], 
             UndirectedEdge[59, 62] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[82, 187] -> 
             RGBColor[0.9548352499999999, 0.85022425, 0.51300225], 
             UndirectedEdge[4, 86] -> 
             RGBColor[0.6311740000000001, 0.529209, 0.58408975], 
             UndirectedEdge[73, 167] -> 
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883], 
             UndirectedEdge[74, 159] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[25, 60] -> 
             RGBColor[0.88264725, 0.540129375, 0.22296500000000002`], 
             UndirectedEdge[159, 162] -> 
             RGBColor[0.799161, 0.791825, 0.6242065], UndirectedEdge[10, 147] -> 
             RGBColor[0.95552675, 0.8493115, 0.41440925000000006`], 
             UndirectedEdge[23, 163] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[40, 54] -> 
             RGBColor[0.9003435, 0.5448427499999999, 0.27705312499999996`], 
             UndirectedEdge[123, 129] -> 
             RGBColor[
              0.8128635000000001, 0.8380467500000001, 0.6774381249999999], 
             UndirectedEdge[25, 165] -> 
             RGBColor[0.8629875, 0.6382058749999999, 0.59096825], 
             UndirectedEdge[39, 178] -> 
             RGBColor[0.91575075, 0.663269625, 0.29180712499999995`], 
             UndirectedEdge[76, 107] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[63, 138] -> 
             RGBColor[0.6909471250000001, 0.5796982500000001, 0.588253], 
             UndirectedEdge[71, 81] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[8, 83] -> 
             RGBColor[0.8118556250000001, 0.597793625, 0.585996], 
             UndirectedEdge[10, 149] -> 
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725], 
             UndirectedEdge[119, 172] -> 
             RGBColor[
              0.8128635000000001, 0.8380467500000001, 0.6774381249999999], 
             UndirectedEdge[106, 130] -> 
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883], 
             UndirectedEdge[147, 176] -> 
             RGBColor[0.8181257500000001, 0.85494, 0.77080125], 
             UndirectedEdge[27, 197] -> 
             RGBColor[0.966007125, 0.97416875, 0.94242525], 
             UndirectedEdge[72, 176] -> 
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244], 
             UndirectedEdge[92, 118] -> 
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185], 
             UndirectedEdge[123, 171] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[66, 113] -> 
             RGBColor[0.9742362499999999, 0.92714275, 0.52861275], 
             UndirectedEdge[67, 179] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[130, 197] -> 
             RGBColor[
              0.8798848750000001, 0.9061687500000001, 0.9449544999999999], 
             UndirectedEdge[15, 194] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[47, 135] -> 
             RGBColor[0.8795787500000001, 0.72969825, 0.605445], 
             UndirectedEdge[8, 170] -> 
             RGBColor[0.8481335, 0.3709807499999999, 0.19372599999999998`], 
             UndirectedEdge[17, 149] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[13, 97] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[11, 86] -> 
             RGBColor[0.8795787500000001, 0.72969825, 0.605445], 
             UndirectedEdge[15, 62] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[37, 160] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[46, 50] -> 
             RGBColor[0.8629875, 0.6382058749999999, 0.59096825], 
             UndirectedEdge[49, 53] -> 
             RGBColor[0.966007125, 0.97416875, 0.94242525], 
             UndirectedEdge[52, 120] -> 
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325], 
             UndirectedEdge[81, 147] -> 
             RGBColor[0.970857375, 0.97497575, 0.774911], 
             UndirectedEdge[49, 123] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[127, 140] -> 
             RGBColor[0.9742362499999999, 0.92714275, 0.52861275], 
             UndirectedEdge[31, 132] -> 
             RGBColor[0.4593251250000001, 0.5641325000000001, 0.952016875], 
             UndirectedEdge[146, 186] -> 
             RGBColor[0.886641, 0.498621, 0.2238215], UndirectedEdge[98, 124] -> 
             RGBColor[0.8463693750000001, 0.76694225, 0.615235], 
             UndirectedEdge[4, 53] -> 
             RGBColor[0.682612, 0.74609175, 0.9285715], 
             UndirectedEdge[82, 137] -> 
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725], 
             UndirectedEdge[42, 107] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[99, 102] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[57, 88] -> 
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375], 
             UndirectedEdge[40, 49] -> 
             RGBColor[0.8825706249999999, 0.5473667499999999, 0.56871275], 
             UndirectedEdge[21, 90] -> 
             RGBColor[0.44080512500000013`, 0.5549417500000001, 0.94966325], 
             UndirectedEdge[143, 158] -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 
             UndirectedEdge[24, 111] -> 
             RGBColor[0.577066375, 0.6565805000000001, 0.9636281250000001], 
             UndirectedEdge[139, 155] -> 
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125], 
             UndirectedEdge[94, 174] -> 
             RGBColor[0.577066375, 0.6565805000000001, 0.9636281250000001], 
             UndirectedEdge[4, 118] -> 
             RGBColor[0.44080512500000013`, 0.5549417500000001, 0.94966325], 
             UndirectedEdge[121, 159] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[5, 76] -> 
             RGBColor[0.77976, 0.7149065000000001, 0.6085959999999999], 
             UndirectedEdge[27, 194] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[77, 160] -> 
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775], 
             UndirectedEdge[2, 80] -> 
             RGBColor[0.8463693750000001, 0.76694225, 0.615235], 
             UndirectedEdge[74, 85] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[35, 110] -> 
             RGBColor[0.7452462500000001, 0.5457578750000001, 0.579357], 
             UndirectedEdge[143, 154] -> 
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883], 
             UndirectedEdge[53, 129] -> 
             RGBColor[0.98378, 0.9716447500000001, 0.650765625], 
             UndirectedEdge[80, 187] -> 
             RGBColor[0.9548352499999999, 0.85022425, 0.51300225], 
             UndirectedEdge[30, 87] -> 
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883], 
             UndirectedEdge[29, 197] -> 
             RGBColor[0.93101675, 0.9465810000000001, 0.9499267499999999], 
             UndirectedEdge[74, 121] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[127, 199] -> 
             RGBColor[0.9203215, 0.681075625, 0.48376325], 
             UndirectedEdge[52, 80] -> 
             RGBColor[0.8463693750000001, 0.76694225, 0.615235], 
             UndirectedEdge[125, 187] -> 
             RGBColor[0.98793875, 0.9733645, 0.581844375], 
             UndirectedEdge[57, 152] -> 
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375], 
             UndirectedEdge[128, 193] -> 
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725], 
             UndirectedEdge[151, 172] -> 
             RGBColor[0.932342, 0.7547619999999999, 0.306283875], 
             UndirectedEdge[5, 27] -> 
             RGBColor[0.9324916249999999, 0.83494225, 0.6127057499999999], 
             UndirectedEdge[65, 118] -> 
             RGBColor[0.72420025, 0.7830187500000001, 0.963517], 
             UndirectedEdge[78, 80] -> 
             RGBColor[0.77976, 0.7149065000000001, 0.608596], 
             UndirectedEdge[40, 199] -> 
             RGBColor[0.83272625, 0.2525538749999999, 0.178972], 
             UndirectedEdge[5, 42] -> 
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725], 
             UndirectedEdge[123, 196] -> 
             RGBColor[
              0.7452462500000001, 0.5457578750000001, 0.5793569999999999], 
             UndirectedEdge[80, 124] -> 
             RGBColor[0.8463693750000001, 0.76694225, 0.615235], 
             UndirectedEdge[22, 48] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[69, 86] -> 
             RGBColor[0.8795787500000001, 0.72969825, 0.605445], 
             UndirectedEdge[81, 143] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[80, 116] -> 
             RGBColor[0.8463693750000001, 0.76694225, 0.615235], 
             UndirectedEdge[90, 169] -> 
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185], 
             UndirectedEdge[121, 173] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[8, 179] -> 
             RGBColor[0.8118556250000001, 0.597793625, 0.585996], 
             UndirectedEdge[29, 167] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[76, 87] -> 
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244], 
             UndirectedEdge[111, 163] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[130, 149] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[7, 122] -> 
             RGBColor[0.3884347500000001, 0.5065805000000001, 0.946436125], 
             UndirectedEdge[89, 142] -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 
             UndirectedEdge[44, 172] -> 
             RGBColor[0.7419731250000001, 0.7804947500000001, 0.671857375], 
             UndirectedEdge[7, 179] -> 
             RGBColor[0.5259345000000002, 0.6161682500000001, 0.958655875], 
             UndirectedEdge[73, 188] -> 
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375], 
             UndirectedEdge[16, 120] -> 
             RGBColor[0.970165875, 0.9758884999999999, 0.8735040000000001], 
             UndirectedEdge[98, 116] -> 
             RGBColor[0.8463693750000001, 0.76694225, 0.615235], 
             UndirectedEdge[5, 81] -> 
             RGBColor[0.9324916249999999, 0.83494225, 0.6127057499999999], 
             UndirectedEdge[76, 106] -> 
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244], 
             UndirectedEdge[135, 144] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[194, 197] -> 
             RGBColor[0.8132755, 0.854133, 0.9383155], UndirectedEdge[27, 29] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[44, 58] -> 
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185], 
             UndirectedEdge[53, 92] -> 
             RGBColor[0.93101675, 0.9465810000000001, 0.9499267499999999], 
             UndirectedEdge[83, 122] -> 
             RGBColor[0.6380780000000001, 0.7150187500000001, 0.96604625], 
             UndirectedEdge[9, 178] -> 
             RGBColor[0.8979778749999999, 0.665793625, 0.5834667499999999], 
             UndirectedEdge[12, 99] -> 
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883], 
             UndirectedEdge[7, 126] -> 
             RGBColor[0.578803625, 0.48084775, 0.580862625], 
             UndirectedEdge[139, 146] -> 
             RGBColor[0.7964483750000001, 0.47936675000000006`, 0.571242], 
             UndirectedEdge[100, 198] -> 
             RGBColor[0.5259345000000002, 0.6161682500000001, 0.958655875], 
             UndirectedEdge[56, 109] -> 
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275], 
             UndirectedEdge[9, 159] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[2, 98] -> 
             RGBColor[0.8463693750000001, 0.76694225, 0.615235], 
             UndirectedEdge[95, 164] -> 
             RGBColor[0.8118556250000001, 0.597793625, 0.585996], 
             UndirectedEdge[108, 163] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[85, 121] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[55, 177] -> 
             RGBColor[0.799161, 0.791825, 0.6242065], 
             UndirectedEdge[118, 141] -> 
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185], 
             UndirectedEdge[58, 77] -> 
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775], 
             UndirectedEdge[142, 154] -> 
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244], 
             UndirectedEdge[103, 178] -> 
             RGBColor[0.91575075, 0.663269625, 0.29180712499999995`], 
             UndirectedEdge[48, 154] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[72, 181] -> 
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883], 
             UndirectedEdge[45, 132] -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 
             UndirectedEdge[103, 200] -> 
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375], 
             UndirectedEdge[21, 61] -> 
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883], 
             UndirectedEdge[51, 73] -> 
             RGBColor[0.6311740000000001, 0.529209, 0.58408975], 
             UndirectedEdge[18, 41] -> 
             RGBColor[0.8132755, 0.854133, 0.9383155], UndirectedEdge[27, 42] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[90, 165] -> 
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185], 
             UndirectedEdge[50, 135] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[93, 121] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[23, 175] -> 
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244], 
             UndirectedEdge[57, 164] -> 
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883], 
             UndirectedEdge[54, 172] -> 
             RGBColor[0.983368, 0.9555585, 0.38988824999999994`], 
             UndirectedEdge[99, 198] -> 
             RGBColor[0.5259345000000002, 0.6161682500000001, 0.958655875], 
             UndirectedEdge[45, 112] -> 
             RGBColor[0.8132755, 0.854133, 0.9383155], 
             UndirectedEdge[88, 173] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[14, 22] -> 
             RGBColor[0.8132755, 0.854133, 0.9383155], UndirectedEdge[7, 67] -> 
             RGBColor[0.61205675, 0.6841682499999999, 0.956126625], 
             UndirectedEdge[105, 135] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[104, 176] -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 
             UndirectedEdge[57, 91] -> 
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244], 
             UndirectedEdge[34, 185] -> 
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275], 
             UndirectedEdge[65, 172] -> 
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999], 
             UndirectedEdge[66, 120] -> 
             RGBColor[0.9742362499999999, 0.92714275, 0.52861275], 
             UndirectedEdge[91, 117] -> 
             RGBColor[0.77976, 0.7149065000000001, 0.608596], 
             UndirectedEdge[27, 141] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[13, 145] -> 
             RGBColor[0.8132755, 0.854133, 0.9383155], UndirectedEdge[1, 174] -> 
             RGBColor[0.634400375, 0.69945025, 0.8564231250000001], 
             UndirectedEdge[182, 196] -> 
             RGBColor[0.91616275, 0.6793558749999999, 0.5526845], 
             UndirectedEdge[96, 137] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[89, 157] -> 
             RGBColor[0.8181257500000001, 0.85494, 0.77080125], 
             UndirectedEdge[119, 191] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[51, 157] -> 
             RGBColor[0.93760425, 0.77165525, 0.399647], 
             UndirectedEdge[127, 195] -> 
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325], 
             UndirectedEdge[27, 62] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[4, 40] -> 
             RGBColor[0.5991755000000001, 0.31928975000000004`, 0.554859], 
             UndirectedEdge[161, 164] -> 
             RGBColor[0.4772523750000001, 0.56500025, 0.9558835], 
             UndirectedEdge[20, 101] -> 
             RGBColor[
              0.7452462500000001, 0.5457578750000001, 0.5793569999999999], 
             UndirectedEdge[13, 36] -> 
             RGBColor[
              0.8128635000000001, 0.8380467500000001, 0.6774381249999999], 
             UndirectedEdge[182, 195] -> 
             RGBColor[
              0.8798848750000001, 0.9061687500000001, 0.9449544999999999], 
             UndirectedEdge[184, 186] -> 
             RGBColor[0.7282706250000001, 0.7342730000000001, 0.61862575], 
             UndirectedEdge[96, 166] -> 
             RGBColor[
              0.6822000000000001, 0.7300055000000001, 0.6676941249999999], 
             UndirectedEdge[38, 43] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[30, 176] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[171, 174] -> 
             RGBColor[0.5259345000000002, 0.6161682500000001, 0.958655875], 
             UndirectedEdge[100, 125] -> 
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125], 
             UndirectedEdge[17, 188] -> 
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075], 
             UndirectedEdge[87, 107] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[62, 184] -> 
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185], 
             UndirectedEdge[12, 33] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[32, 57] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[17, 87] -> 
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375], 
             UndirectedEdge[42, 149] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[87, 130] -> 
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883], 
             UndirectedEdge[58, 170] -> 
             RGBColor[0.8629875, 0.638205875, 0.59096825], 
             UndirectedEdge[118, 196] -> 
             RGBColor[0.674355875, 0.488205875, 0.57377625], 
             UndirectedEdge[41, 159] -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 
             UndirectedEdge[107, 157] -> 
             RGBColor[0.935867, 0.9473880000000001, 0.7824125], 
             UndirectedEdge[161, 173] -> 
             RGBColor[0.4106430000000001, 0.5129645, 0.9492445], 
             UndirectedEdge[15, 184] -> 
             RGBColor[0.6380780000000001, 0.7150187500000001, 0.96604625], 
             UndirectedEdge[106, 142] -> 
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244], 
             UndirectedEdge[24, 39] -> 
             RGBColor[0.6298296250000001, 0.68164425, 0.6644669999999999], 
             UndirectedEdge[45, 134] -> 
             RGBColor[0.81743425, 0.85585275, 0.86939425], 
             UndirectedEdge[5, 73] -> 
             RGBColor[0.6490965000000001, 0.60686525, 0.5988519999999999], 
             UndirectedEdge[147, 154] -> 
             RGBColor[0.68746225, 0.7468987500000001, 0.76105725], 
             UndirectedEdge[76, 143] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[5, 197] -> 
             RGBColor[0.9506764999999999, 0.8485045, 0.5819235], 
             UndirectedEdge[152, 159] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[108, 115] -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 
             UndirectedEdge[65, 123] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[8, 67] -> 
             RGBColor[0.8979778749999999, 0.6657936249999998, 0.58346675], 
             UndirectedEdge[9, 41] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[111, 165] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[146, 195] -> 
             RGBColor[0.7964483750000001, 0.47936675000000006`, 0.571242], 
             UndirectedEdge[104, 188] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[37, 105] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[3, 75] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[40, 132] -> 
             RGBColor[0.7298390000000001, 0.42733100000000007`, 0.564603], 
             UndirectedEdge[154, 157] -> 
             RGBColor[0.68746225, 0.7468987500000001, 0.76105725], 
             UndirectedEdge[116, 148] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[132, 185] -> 
             RGBColor[
              0.7618375000000001, 0.6372502500000001, 0.5938337499999999], 
             UndirectedEdge[92, 123] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[53, 139] -> 
             RGBColor[
              0.8798848750000001, 0.9061687500000001, 0.9449544999999999], 
             UndirectedEdge[40, 196] -> 
             RGBColor[0.83272625, 0.2525538749999999, 0.178972], 
             UndirectedEdge[27, 73] -> 
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375], 
             UndirectedEdge[57, 103] -> 
             RGBColor[
              0.6822000000000001, 0.7300055000000001, 0.6676941249999999], 
             UndirectedEdge[44, 77] -> 
             RGBColor[0.7282706250000001, 0.7342730000000001, 0.61862575], 
             UndirectedEdge[88, 91] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[69, 146] -> 
             RGBColor[0.84758025, 0.519779, 0.57621425], 
             UndirectedEdge[65, 199] -> 
             RGBColor[0.8979778749999999, 0.665793625, 0.5834667499999999], 
             UndirectedEdge[27, 75] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[4, 65] -> 
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375], 
             UndirectedEdge[58, 102] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[107, 168] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[9, 85] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[22, 144] -> 
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244], 
             UndirectedEdge[110, 138] -> 
             RGBColor[
              0.5714686250000001, 0.6629830000000001, 0.9594072499999999], 
             UndirectedEdge[34, 132] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[48, 158] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[19, 95] -> 
             RGBColor[0.90204825, 0.6170478749999999, 0.2385755], 
             UndirectedEdge[122, 137] -> 
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185], 
             UndirectedEdge[8, 198] -> 
             RGBColor[0.5622123750000001, 0.389355375, 0.566385875], 
             UndirectedEdge[92, 174] -> 
             RGBColor[0.577066375, 0.6565805000000001, 0.9636281250000001], 
             UndirectedEdge[39, 133] -> 
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125], 
             UndirectedEdge[120, 198] -> 
             RGBColor[0.634400375, 0.69945025, 0.8564231250000001], 
             UndirectedEdge[4, 34] -> 
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883], 
             UndirectedEdge[31, 34] -> 
             RGBColor[0.5259345000000002, 0.6161682500000001, 0.958655875], 
             UndirectedEdge[41, 152] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[95, 121] -> 
             RGBColor[0.8118556250000001, 0.597793625, 0.585996], 
             UndirectedEdge[3, 129] -> 
             RGBColor[
              0.6822000000000001, 0.7300055000000001, 0.6676941249999999], 
             UndirectedEdge[49, 199] -> 
             RGBColor[0.8979778749999999, 0.665793625, 0.5834667499999999], 
             UndirectedEdge[171, 182] -> 
             RGBColor[
              0.8798848750000001, 0.9061687500000001, 0.9449544999999999], 
             UndirectedEdge[56, 150] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[179, 183] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[31, 156] -> 
             RGBColor[0.578803625, 0.48084775, 0.580862625], 
             UndirectedEdge[132, 153] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[78, 136] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[27, 167] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[35, 174] -> 
             RGBColor[0.5622123750000001, 0.389355375, 0.566385875], 
             UndirectedEdge[61, 190] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[18, 103] -> 
             RGBColor[0.98378, 0.9716447500000001, 0.650765625], 
             UndirectedEdge[146, 155] -> 
             RGBColor[0.9003435, 0.5448427499999999, 0.27705312499999996`], 
             UndirectedEdge[77, 166] -> 
             RGBColor[0.9696655000000001, 0.90933675, 0.33665662499999993`], 
             UndirectedEdge[85, 159] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[39, 88] -> 
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999], 
             UndirectedEdge[66, 80] -> 
             RGBColor[0.936562, 0.7861965, 0.2678145], 
             UndirectedEdge[62, 141] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[91, 103] -> 
             RGBColor[
              0.8128635000000001, 0.8380467500000001, 0.6774381249999999], 
             UndirectedEdge[149, 189] -> 
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185], 
             UndirectedEdge[4, 69] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[23, 169] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[32, 152] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[100, 124] -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 
             UndirectedEdge[129, 139] -> 
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125], 
             UndirectedEdge[29, 73] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[32, 178] -> 
             RGBColor[0.8629875, 0.638205875, 0.59096825], 
             UndirectedEdge[8, 61] -> 
             RGBColor[0.8118556250000001, 0.597793625, 0.585996], 
             UndirectedEdge[10, 27] -> 
             RGBColor[0.9324916249999999, 0.83494225, 0.6127057499999999], 
             UndirectedEdge[72, 160] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[72, 144] -> 
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455], 
             UndirectedEdge[134, 135] -> 
             RGBColor[0.9351754999999999, 0.94830075, 0.8810055], 
             UndirectedEdge[95, 150] -> 
             RGBColor[0.8629875, 0.6382058749999999, 0.59096825], 
             UndirectedEdge[68, 71] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[118, 123] -> 
             RGBColor[
              0.5714686250000001, 0.6629830000000001, 0.9594072499999999], 
             UndirectedEdge[89, 168] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[44, 99] -> 
             RGBColor[0.6380780000000001, 0.7150187500000001, 0.96604625], 
             UndirectedEdge[121, 180] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[10, 141] -> 
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725], 
             UndirectedEdge[6, 170] -> 
             RGBColor[0.91575075, 0.663269625, 0.29180712499999995`], 
             UndirectedEdge[12, 77] -> 
             RGBColor[0.6684975000000001, 0.68378375, 0.6144625], 
             UndirectedEdge[112, 143] -> 
             RGBColor[
              0.8798848750000001, 0.9061687500000001, 0.9449544999999999], 
             UndirectedEdge[67, 125] -> 
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999], 
             UndirectedEdge[3, 10] -> 
             RGBColor[0.6490965000000001, 0.60686525, 0.598852], 
             UndirectedEdge[124, 125] -> 
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125], 
             UndirectedEdge[11, 174] -> 
             RGBColor[0.577066375, 0.6565805000000001, 0.9636281250000001], 
             UndirectedEdge[71, 87] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[7, 192] -> 
             RGBColor[0.577066375, 0.6565805000000001, 0.9636281250000001], 
             UndirectedEdge[56, 148] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[30, 71] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[35, 86] -> 
             RGBColor[0.8647247499999999, 0.46247312499999993`, 0.20820275], 
             UndirectedEdge[68, 127] -> 
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325], 
             UndirectedEdge[10, 30] -> 
             RGBColor[0.8463693750000001, 0.76694225, 0.615235], 
             UndirectedEdge[89, 176] -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 
             UndirectedEdge[71, 76] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[49, 119] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[87, 106] -> 
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455], 
             UndirectedEdge[86, 196] -> 
             RGBColor[0.8647247499999999, 0.46247312499999993`, 0.20820275], 
             UndirectedEdge[53, 123] -> 
             RGBColor[0.8132755, 0.854133, 0.9383155], 
             UndirectedEdge[68, 102] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[107, 130] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[42, 157] -> 
             RGBColor[0.935867, 0.9473880000000001, 0.7824125], 
             UndirectedEdge[96, 99] -> 
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883], 
             UndirectedEdge[62, 194] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[57, 117] -> 
             RGBColor[0.6490965000000001, 0.60686525, 0.598852], 
             UndirectedEdge[102, 128] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[46, 47] -> 
             RGBColor[0.8647247499999999, 0.46247312499999993`, 0.20820275], 
             UndirectedEdge[28, 105] -> 
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325], 
             UndirectedEdge[40, 182] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[79, 179] -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 
             UndirectedEdge[36, 63] -> 
             RGBColor[0.932342, 0.7547619999999999, 0.306283875], 
             UndirectedEdge[118, 129] -> 
             RGBColor[0.7419731250000001, 0.7804947500000001, 0.671857375], 
             UndirectedEdge[74, 161] -> 
             RGBColor[0.52838425, 0.6054125, 0.96085575], 
             UndirectedEdge[66, 187] -> 
             RGBColor[0.9742362499999999, 0.92714275, 0.52861275], 
             UndirectedEdge[10, 29] -> 
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725], 
             UndirectedEdge[30, 147] -> 
             RGBColor[
              0.8847351250000002, 0.9069757500000001, 0.7774402499999999], 
             UndirectedEdge[109, 116] -> 
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275], 
             UndirectedEdge[81, 154] -> 
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375], 
             UndirectedEdge[89, 188] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[24, 163] -> 
             RGBColor[0.577066375, 0.6565805000000001, 0.9636281250000001], 
             UndirectedEdge[91, 159] -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 
             UndirectedEdge[121, 164] -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 
             UndirectedEdge[4, 54] -> 
             RGBColor[
              0.6822000000000001, 0.7300055000000001, 0.6676941249999999], 
             UndirectedEdge[51, 130] -> 
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275], 
             UndirectedEdge[69, 186] -> 
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775], 
             UndirectedEdge[137, 179] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[158, 181] -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 
             UndirectedEdge[22, 176] -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 
             UndirectedEdge[128, 198] -> 
             RGBColor[0.577066375, 0.6565805000000001, 0.9636281250000001], 
             UndirectedEdge[107, 131] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[26, 125] -> 
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375], 
             UndirectedEdge[47, 105] -> 
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275], 
             UndirectedEdge[23, 60] -> 
             RGBColor[0.6490965000000001, 0.60686525, 0.598852], 
             UndirectedEdge[43, 111] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[73, 142] -> 
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244], 
             UndirectedEdge[43, 115] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[61, 122] -> 
             RGBColor[0.6380780000000001, 0.7150187500000001, 0.96604625], 
             UndirectedEdge[64, 65] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[147, 157] -> 
             RGBColor[0.9938925000000001, 0.989345, 0.5766145], 
             UndirectedEdge[53, 69] -> 
             RGBColor[0.93101675, 0.9465810000000001, 0.9499267499999999], 
             UndirectedEdge[27, 188] -> 
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075], 
             UndirectedEdge[88, 159] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[16, 61] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[138, 185] -> 
             RGBColor[0.6909471250000001, 0.5796982500000001, 0.588253], 
             UndirectedEdge[26, 128] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[68, 75] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[10, 107] -> 
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725], 
             UndirectedEdge[69, 123] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[109, 113] -> 
             RGBColor[0.93691275, 0.7725679999999999, 0.49824], 
             UndirectedEdge[49, 196] -> 
             RGBColor[0.8979778749999999, 0.665793625, 0.5834667499999999], 
             UndirectedEdge[8, 26] -> 
             RGBColor[0.8629875, 0.6382058749999999, 0.59096825], 
             UndirectedEdge[30, 73] -> 
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883], 
             UndirectedEdge[46, 144] -> 
             RGBColor[0.6145827500000001, 0.43771662499999997`, 0.569613], 
             UndirectedEdge[81, 176] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[104, 181] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[65, 171] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[67, 82] -> 
             RGBColor[0.9324916249999999, 0.83494225, 0.61270575], 
             UndirectedEdge[13, 63] -> 
             RGBColor[
              0.7618375000000001, 0.6372502500000001, 0.5938337499999999], 
             UndirectedEdge[153, 182] -> 
             RGBColor[
              0.8798848750000001, 0.9061687500000001, 0.9449544999999999], 
             UndirectedEdge[87, 157] -> 
             RGBColor[0.68746225, 0.7468987500000001, 0.76105725], 
             UndirectedEdge[30, 157] -> 
             RGBColor[
              0.8847351250000002, 0.9069757500000001, 0.7774402499999999], 
             UndirectedEdge[64, 185] -> 
             RGBColor[
              0.7618375000000001, 0.6372502500000001, 0.5938337499999999], 
             UndirectedEdge[9, 103] -> 
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999], 
             UndirectedEdge[18, 117] -> 
             RGBColor[0.9506764999999999, 0.8485045, 0.5819235], 
             UndirectedEdge[52, 66] -> 
             RGBColor[0.8657703750000001, 0.84386075, 0.6308455], 
             UndirectedEdge[128, 162] -> 
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775], 
             UndirectedEdge[23, 177] -> 
             RGBColor[0.6684975000000001, 0.68378375, 0.6144625], 
             UndirectedEdge[11, 110] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[79, 177] -> 
             RGBColor[0.8657703750000001, 0.84386075, 0.6308455], 
             UndirectedEdge[8, 166] -> 
             RGBColor[0.91575075, 0.6632696249999999, 0.29180712499999995`], 
             UndirectedEdge[162, 173] -> 
             RGBColor[0.799161, 0.791825, 0.6242064999999999], 
             UndirectedEdge[100, 137] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[88, 117] -> 
             RGBColor[0.9324916249999999, 0.83494225, 0.61270575], 
             UndirectedEdge[149, 168] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[36, 110] -> 
             RGBColor[
              0.8128635000000001, 0.8380467500000001, 0.6774381249999999], 
             UndirectedEdge[76, 104] -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 
             UndirectedEdge[4, 196] -> 
             RGBColor[
              0.6145827500000001, 0.43771662499999997`, 0.5696129999999999], 
             UndirectedEdge[61, 79] -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 
             UndirectedEdge[76, 147] -> 
             RGBColor[0.8181257500000001, 0.85494, 0.77080125], 
             UndirectedEdge[2, 120] -> 
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325], 
             UndirectedEdge[87, 176] -> 
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244], 
             UndirectedEdge[142, 157] -> 
             RGBColor[0.8181257500000001, 0.85494, 0.77080125], 
             UndirectedEdge[65, 191] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[73, 147] -> 
             RGBColor[0.68746225, 0.7468987500000001, 0.76105725], 
             UndirectedEdge[26, 120] -> 
             RGBColor[0.9351754999999999, 0.94830075, 0.8810055], 
             UndirectedEdge[113, 116] -> 
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325], 
             UndirectedEdge[35, 94] -> 
             RGBColor[0.8629875, 0.6382058749999999, 0.59096825], 
             UndirectedEdge[31, 45] -> 
             RGBColor[0.4593251250000001, 0.5641325000000001, 0.952016875], 
             UndirectedEdge[52, 82] -> 
             RGBColor[0.8463693750000001, 0.76694225, 0.615235], 
             UndirectedEdge[95, 162] -> 
             RGBColor[0.90204825, 0.6170478749999999, 0.2385755], 
             UndirectedEdge[17, 73] -> 
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375], 
             UndirectedEdge[103, 152] -> 
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999], 
             UndirectedEdge[88, 103] -> 
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999], 
             UndirectedEdge[26, 170] -> 
             RGBColor[0.8629875, 0.638205875, 0.59096825], 
             UndirectedEdge[89, 106] -> 
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244], 
             UndirectedEdge[19, 74] -> 
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775], 
             UndirectedEdge[117, 152] -> 
             RGBColor[0.9324916249999999, 0.83494225, 0.6127057499999999], 
             UndirectedEdge[157, 176] -> 
             RGBColor[0.8181257500000001, 0.85494, 0.77080125], 
             UndirectedEdge[49, 139] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[48, 106] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[69, 118] -> 
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185], 
             UndirectedEdge[117, 200] -> 
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725], 
             UndirectedEdge[64, 153] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[73, 87] -> 
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455], 
             UndirectedEdge[132, 138] -> 
             RGBColor[
              0.5714686250000001, 0.6629830000000001, 0.9594072499999999], 
             UndirectedEdge[6, 96] -> 
             RGBColor[
              0.6822000000000001, 0.7300055000000001, 0.6676941249999999], 
             UndirectedEdge[34, 65] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[2, 16] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[21, 122] -> 
             RGBColor[0.44080512500000013`, 0.5549417500000001, 0.94966325], 
             UndirectedEdge[90, 175] -> 
             RGBColor[
              0.5714686250000001, 0.6629830000000001, 0.9594072499999999], 
             UndirectedEdge[6, 179] -> 
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125], 
             UndirectedEdge[8, 137] -> 
             RGBColor[0.8629875, 0.6382058749999999, 0.59096825], 
             UndirectedEdge[3, 127] -> 
             RGBColor[0.68677075, 0.7478115000000001, 0.8596502500000001], 
             UndirectedEdge[31, 65] -> 
             RGBColor[0.61205675, 0.6841682499999999, 0.956126625], 
             UndirectedEdge[3, 71] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[146, 184] -> 
             RGBColor[0.6589486250000001, 0.3697790000000001, 0.55902225], 
             UndirectedEdge[33, 99] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[10, 130] -> 
             RGBColor[0.8463693750000001, 0.76694225, 0.615235], 
             UndirectedEdge[112, 160] -> 
             RGBColor[0.93101675, 0.9465810000000001, 0.9499267499999999], 
             UndirectedEdge[73, 157] -> 
             RGBColor[0.68746225, 0.7468987500000001, 0.76105725], 
             UndirectedEdge[157, 188] -> 
             RGBColor[0.970857375, 0.97497575, 0.774911], 
             UndirectedEdge[70, 132] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[141, 191] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[26, 80] -> 
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725], 
             UndirectedEdge[171, 199] -> 
             RGBColor[0.8118556250000001, 0.597793625, 0.585996], 
             UndirectedEdge[23, 43] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[75, 81] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[33, 172] -> 
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375], 
             UndirectedEdge[156, 166] -> 
             RGBColor[0.932342, 0.7547619999999999, 0.306283875], 
             UndirectedEdge[151, 175] -> 
             RGBColor[
              0.7618375000000001, 0.6372502500000001, 0.5938337499999999], 
             UndirectedEdge[34, 199] -> 
             RGBColor[0.8118556250000001, 0.597793625, 0.585996], 
             UndirectedEdge[38, 169] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[10, 142] -> 
             RGBColor[0.77976, 0.7149065000000001, 0.6085959999999999], 
             UndirectedEdge[142, 188] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[12, 128] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[19, 172] -> 
             RGBColor[0.9696655000000001, 0.90933675, 0.33665662499999993`], 
             UndirectedEdge[109, 124] -> 
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275], 
             UndirectedEdge[75, 127] -> 
             RGBColor[0.9351754999999999, 0.94830075, 0.8810055], 
             UndirectedEdge[4, 191] -> 
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883], 
             UndirectedEdge[68, 172] -> 
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125], 
             UndirectedEdge[97, 105] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[120, 136] -> 
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325], 
             UndirectedEdge[117, 159] -> 
             RGBColor[0.77976, 0.7149065000000001, 0.6085959999999999], 
             UndirectedEdge[183, 192] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[71, 188] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[14, 106] -> 
             RGBColor[0.682612, 0.74609175, 0.9285715], 
             UndirectedEdge[141, 194] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[50, 105] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[98, 125] -> 
             RGBColor[0.9502645000000001, 0.83241825, 0.32104612499999996`], 
             UndirectedEdge[118, 119] -> 
             RGBColor[
              0.5714686250000001, 0.6629830000000001, 0.9594072499999999], 
             UndirectedEdge[137, 166] -> 
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375], 
             UndirectedEdge[6, 112] -> 
             RGBColor[0.98378, 0.9716447500000001, 0.650765625], 
             UndirectedEdge[65, 119] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[170, 183] -> 
             RGBColor[0.8979778749999999, 0.6657936249999998, 0.58346675], 
             UndirectedEdge[14, 131] -> 
             RGBColor[0.966007125, 0.97416875, 0.94242525], 
             UndirectedEdge[9, 164] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[96, 170] -> 
             RGBColor[
              0.6145827500000001, 0.43771662499999997`, 0.5696129999999999], 
             UndirectedEdge[117, 178] -> 
             RGBColor[0.88264725, 0.540129375, 0.22296500000000002`], 
             UndirectedEdge[18, 24] -> 
             RGBColor[0.630241625, 0.6977305, 0.925344375], 
             UndirectedEdge[18, 133] -> 
             RGBColor[
              0.8798848750000001, 0.9061687500000001, 0.9449544999999999], 
             UndirectedEdge[49, 129] -> 
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999], 
             UndirectedEdge[124, 198] -> 
             RGBColor[0.5259345000000002, 0.6161682500000001, 0.958655875], 
             UndirectedEdge[113, 124] -> 
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325], 
             UndirectedEdge[176, 188] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[37, 97] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[77, 143] -> 
             RGBColor[0.8657703750000001, 0.84386075, 0.6308455], 
             UndirectedEdge[79, 84] -> 
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275], 
             UndirectedEdge[151, 199] -> 
             RGBColor[0.8647247499999999, 0.46247312499999993`, 0.20820275], 
             UndirectedEdge[48, 87] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[27, 30] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[5, 87] -> 
             RGBColor[0.6490965000000001, 0.60686525, 0.5988519999999999], 
             UndirectedEdge[68, 81] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[155, 172] -> 
             RGBColor[0.983368, 0.9555585, 0.38988824999999994`], 
             UndirectedEdge[143, 188] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[102, 180] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[80, 136] -> 
             RGBColor[0.8463693750000001, 0.76694225, 0.615235], 
             UndirectedEdge[66, 78] -> 
             RGBColor[0.799161, 0.791825, 0.6242064999999999], 
             UndirectedEdge[50, 101] -> 
             RGBColor[0.8629875, 0.638205875, 0.59096825], 
             UndirectedEdge[41, 85] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[5, 30] -> 
             RGBColor[0.8463693750000001, 0.76694225, 0.615235], 
             UndirectedEdge[32, 133] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[159, 161] -> 
             RGBColor[0.4106430000000001, 0.5129645, 0.9492445], 
             UndirectedEdge[3, 195] -> 
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883], 
             UndirectedEdge[173, 180] -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 
             UndirectedEdge[129, 141] -> 
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375], 
             UndirectedEdge[53, 199] -> 
             RGBColor[0.91616275, 0.6793558749999999, 0.5526845], 
             UndirectedEdge[88, 95] -> 
             RGBColor[0.8979778749999999, 0.665793625, 0.5834667499999999], 
             UndirectedEdge[93, 95] -> 
             RGBColor[0.8629875, 0.638205875, 0.59096825], 
             UndirectedEdge[3, 29] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[52, 125] -> 
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125], 
             UndirectedEdge[82, 136] -> 
             RGBColor[0.8463693750000001, 0.76694225, 0.615235], 
             UndirectedEdge[116, 193] -> 
             RGBColor[0.8463693750000001, 0.76694225, 0.615235], 
             UndirectedEdge[19, 159] -> 
             RGBColor[0.799161, 0.791825, 0.6242064999999999], 
             UndirectedEdge[77, 99] -> 
             RGBColor[0.8657703750000001, 0.84386075, 0.6308455], 
             UndirectedEdge[53, 196] -> 
             RGBColor[0.91616275, 0.6793558749999999, 0.5526845], 
             UndirectedEdge[58, 137] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[159, 200] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[3, 62] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[48, 157] -> 
             RGBColor[0.935867, 0.9473880000000001, 0.7824125], 
             UndirectedEdge[130, 168] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[140, 180] -> 
             RGBColor[0.799161, 0.791825, 0.6242064999999999], 
             UndirectedEdge[146, 171] -> 
             RGBColor[0.7964483750000001, 0.47936675000000006`, 0.571242], 
             UndirectedEdge[26, 100] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[45, 153] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[165, 177] -> 
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775], 
             UndirectedEdge[123, 139] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[13, 34] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[48, 72] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[127, 191] -> 
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325], 
             UndirectedEdge[58, 125] -> 
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375], 
             UndirectedEdge[165, 169] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[119, 156] -> 
             RGBColor[
              0.7618375000000001, 0.6372502500000001, 0.5938337499999999], 
             UndirectedEdge[139, 191] -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 
             UndirectedEdge[48, 81] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[85, 161] -> 
             RGBColor[0.52838425, 0.6054125, 0.96085575], 
             UndirectedEdge[30, 106] -> 
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883], 
             UndirectedEdge[118, 195] -> 
             RGBColor[0.6380780000000001, 0.7150187500000001, 0.96604625], 
             UndirectedEdge[132, 145] -> 
             RGBColor[0.8132755, 0.854133, 0.9383155], 
             UndirectedEdge[124, 137] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[53, 182] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[31, 40] -> 
             RGBColor[0.5468051250000001, 0.2709285, 0.551631875], 
             UndirectedEdge[130, 157] -> 
             RGBColor[
              0.8847351250000002, 0.9069757500000001, 0.7774402499999999], 
             UndirectedEdge[83, 166] -> 
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125], 
             UndirectedEdge[76, 176] -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 
             UndirectedEdge[100, 113] -> 
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325], 
             UndirectedEdge[53, 118] -> 
             RGBColor[0.742385125, 0.7965810000000001, 0.9327347500000001], 
             UndirectedEdge[18, 85] -> 
             RGBColor[0.93101675, 0.9465810000000001, 0.9499267499999999], 
             UndirectedEdge[90, 177] -> 
             RGBColor[0.7282706250000001, 0.7342730000000001, 0.61862575], 
             UndirectedEdge[55, 165] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[9, 121] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[70, 110] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[51, 147] -> 
             RGBColor[0.93760425, 0.77165525, 0.399647], 
             UndirectedEdge[81, 188] -> 
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075], 
             UndirectedEdge[63, 132] -> 
             RGBColor[
              0.7618375000000001, 0.6372502500000001, 0.5938337499999999], 
             UndirectedEdge[68, 143] -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 
             UndirectedEdge[76, 81] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[55, 163] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[86, 94] -> 
             RGBColor[0.8795787500000001, 0.72969825, 0.605445], 
             UndirectedEdge[3, 167] -> 
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883], 
             UndirectedEdge[16, 82] -> 
             RGBColor[0.9324916249999999, 0.83494225, 0.61270575], 
             UndirectedEdge[51, 107] -> 
             RGBColor[0.8795787500000001, 0.72969825, 0.605445], 
             UndirectedEdge[53, 171] -> 
             RGBColor[
              0.8798848750000001, 0.9061687500000001, 0.9449544999999999], 
             UndirectedEdge[78, 82] -> 
             RGBColor[0.77976, 0.7149065000000001, 0.608596], 
             UndirectedEdge[92, 186] -> 
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775], 
             UndirectedEdge[75, 118] -> 
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185], 
             UndirectedEdge[77, 83] -> 
             RGBColor[0.8657703750000001, 0.84386075, 0.6308455], 
             UndirectedEdge[42, 176] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[20, 144] -> 
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244], 
             UndirectedEdge[26, 98] -> 
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725], 
             UndirectedEdge[16, 84] -> 
             RGBColor[0.9145691249999999, 0.7572859999999999, 0.5979435], 
             UndirectedEdge[55, 175] -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 
             UndirectedEdge[113, 128] -> 
             RGBColor[0.9351754999999999, 0.94830075, 0.8810055], 
             UndirectedEdge[142, 147] -> 
             RGBColor[0.8181257500000001, 0.85494, 0.77080125], 
             UndirectedEdge[10, 42] -> 
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725], 
             UndirectedEdge[98, 120] -> 
             RGBColor[0.9548352499999999, 0.85022425, 0.51300225], 
             UndirectedEdge[195, 199] -> 
             RGBColor[0.8118556250000001, 0.597793625, 0.585996], 
             UndirectedEdge[49, 195] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[25, 43] -> 
             RGBColor[0.8629875, 0.6382058749999999, 0.59096825], 
             UndirectedEdge[91, 121] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[8, 21] -> 
             RGBColor[0.6145827500000001, 0.43771662499999997`, 0.569613], 
             UndirectedEdge[2, 124] -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 
             UndirectedEdge[80, 125] -> 
             RGBColor[0.9502645000000001, 0.83241825, 0.32104612499999996`], 
             UndirectedEdge[33, 180] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[5, 155] -> 
             RGBColor[0.9502645000000001, 0.83241825, 0.32104612499999996`], 
             UndirectedEdge[179, 192] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[59, 146] -> 
             RGBColor[0.7298390000000001, 0.42733100000000007`, 0.564603], 
             UndirectedEdge[3, 68] -> 
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883], 
             UndirectedEdge[131, 157] -> 
             RGBColor[0.970857375, 0.97497575, 0.774911], 
             UndirectedEdge[85, 200] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[23, 38] -> 
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244], 
             UndirectedEdge[92, 191] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[97, 153] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[95, 161] -> 
             RGBColor[0.51353025, 0.33818737499999996`, 0.5636135], 
             UndirectedEdge[139, 196] -> 
             RGBColor[0.8118556250000001, 0.597793625, 0.585996], 
             UndirectedEdge[1, 94] -> 
             RGBColor[0.9351754999999999, 0.94830075, 0.8810055], 
             UndirectedEdge[189, 194] -> 
             RGBColor[
              0.5714686250000001, 0.6629830000000001, 0.9594072499999999], 
             UndirectedEdge[42, 76] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[84, 190] -> 
             RGBColor[
              0.7618375000000001, 0.6372502500000001, 0.5938337499999999], 
             UndirectedEdge[37, 134] -> 
             RGBColor[0.9351754999999999, 0.94830075, 0.8810055], 
             UndirectedEdge[140, 161] -> 
             RGBColor[0.567445, 0.5842545, 0.608463], UndirectedEdge[10, 51] -> 
             RGBColor[0.8992385, 0.6316217500000001, 0.23744175], 
             UndirectedEdge[146, 191] -> 
             RGBColor[0.7964483750000001, 0.47936675000000006`, 0.571242], 
             UndirectedEdge[21, 175] -> 
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244], 
             UndirectedEdge[49, 141] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[111, 177] -> 
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775], 
             UndirectedEdge[69, 191] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[111, 175] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[77, 170] -> 
             RGBColor[0.90204825, 0.6170478749999999, 0.2385755], 
             UndirectedEdge[104, 154] -> 
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244], 
             UndirectedEdge[13, 138] -> 
             RGBColor[
              0.5714686250000001, 0.6629830000000001, 0.9594072499999999], 
             UndirectedEdge[21, 67] -> 
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375], 
             UndirectedEdge[73, 197] -> 
             RGBColor[0.682612, 0.74609175, 0.9285715], 
             UndirectedEdge[67, 192] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[37, 101] -> 
             RGBColor[0.8629875, 0.638205875, 0.59096825], 
             UndirectedEdge[6, 44] -> 
             RGBColor[0.7419731250000001, 0.7804947500000001, 0.671857375], 
             UndirectedEdge[75, 89] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[76, 188] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[42, 71] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[6, 192] -> 
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375], 
             UndirectedEdge[2, 100] -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 
             UndirectedEdge[7, 8] -> 
             RGBColor[0.5622123750000001, 0.389355375, 0.5663858749999999], 
             UndirectedEdge[69, 92] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[104, 160] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[17, 30] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[88, 164] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[43, 60] -> 
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725], 
             UndirectedEdge[149, 197] -> 
             RGBColor[0.93101675, 0.9465810000000001, 0.9499267499999999], 
             UndirectedEdge[167, 197] -> 
             RGBColor[
              0.8798848750000001, 0.9061687500000001, 0.9449544999999999], 
             UndirectedEdge[54, 127] -> 
             RGBColor[0.98793875, 0.9733645, 0.581844375], 
             UndirectedEdge[107, 147] -> 
             RGBColor[0.935867, 0.9473880000000001, 0.7824125], 
             UndirectedEdge[78, 113] -> 
             RGBColor[0.81743425, 0.85585275, 0.86939425], 
             UndirectedEdge[81, 87] -> 
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375], 
             UndirectedEdge[83, 179] -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 
             UndirectedEdge[82, 198] -> 
             RGBColor[0.596726125, 0.5585040000000001, 0.5956248749999999], 
             UndirectedEdge[30, 107] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[47, 134] -> 
             RGBColor[0.93691275, 0.7725679999999999, 0.49824], 
             UndirectedEdge[5, 142] -> 
             RGBColor[0.77976, 0.7149065000000001, 0.6085959999999999], 
             UndirectedEdge[169, 190] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[121, 152] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[31, 64] -> 
             RGBColor[0.4593251250000001, 0.5641325000000001, 0.952016875], 
             UndirectedEdge[105, 134] -> 
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325], 
             UndirectedEdge[83, 192] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[77, 112] -> 
             RGBColor[0.9700774999999999, 0.925423, 0.597534], 
             UndirectedEdge[195, 196] -> 
             RGBColor[0.8118556250000001, 0.597793625, 0.585996], 
             UndirectedEdge[92, 171] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[166, 183] -> 
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999], 
             UndirectedEdge[139, 195] -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 
             UndirectedEdge[177, 190] -> 
             RGBColor[0.799161, 0.791825, 0.6242064999999999], 
             UndirectedEdge[29, 149] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[119, 155] -> 
             RGBColor[
              0.8128635000000001, 0.8380467500000001, 0.6774381249999999], 
             UndirectedEdge[12, 162] -> 
             RGBColor[0.6684975000000001, 0.68378375, 0.6144625], 
             UndirectedEdge[85, 173] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[92, 141] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[5, 29] -> 
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725], 
             UndirectedEdge[51, 87] -> 
             RGBColor[0.6311740000000001, 0.529209, 0.58408975], 
             UndirectedEdge[145, 153] -> 
             RGBColor[
              0.8798848750000001, 0.9061687500000001, 0.9449544999999999], 
             UndirectedEdge[118, 191] -> 
             RGBColor[0.6380780000000001, 0.7150187500000001, 0.96604625], 
             UndirectedEdge[117, 164] -> 
             RGBColor[0.8463693750000001, 0.76694225, 0.615235], 
             UndirectedEdge[145, 185] -> 
             RGBColor[0.932754, 0.77084825, 0.5671612500000001], 
             UndirectedEdge[99, 137] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[48, 176] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[50, 144] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[3, 53] -> 
             RGBColor[0.682612, 0.74609175, 0.9285715], 
             UndirectedEdge[169, 177] -> 
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775], 
             UndirectedEdge[20, 135] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[166, 170] -> 
             RGBColor[0.91575075, 0.663269625, 0.29180712499999995`], 
             UndirectedEdge[17, 42] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[129, 195] -> 
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125], 
             UndirectedEdge[74, 93] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[37, 45] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[49, 92] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[163, 177] -> 
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775], 
             UndirectedEdge[6, 45] -> 
             RGBColor[
              0.8128635000000001, 0.8380467500000001, 0.6774381249999999], 
             UndirectedEdge[6, 166] -> 
             RGBColor[0.983368, 0.9555585, 0.38988824999999994`], 
             UndirectedEdge[65, 127] -> 
             RGBColor[0.970165875, 0.9758884999999999, 0.8735040000000001], 
             UndirectedEdge[15, 59] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[100, 136] -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 
             UndirectedEdge[83, 183] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[53, 119] -> 
             RGBColor[0.8132755, 0.854133, 0.9383155], UndirectedEdge[5, 68] -> 
             RGBColor[0.8463693750000001, 0.76694225, 0.615235], 
             UndirectedEdge[49, 54] -> 
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999], 
             UndirectedEdge[153, 185] -> 
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275], 
             UndirectedEdge[101, 144] -> 
             RGBColor[0.6145827500000001, 0.43771662499999997`, 0.569613], 
             UndirectedEdge[19, 102] -> 
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775], 
             UndirectedEdge[102, 172] -> 
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375], 
             UndirectedEdge[102, 140] -> 
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775], 
             UndirectedEdge[71, 107] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[5, 168] -> 
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725], 
             UndirectedEdge[79, 122] -> 
             RGBColor[0.6380780000000001, 0.7150187500000001, 0.96604625], 
             UndirectedEdge[136, 198] -> 
             RGBColor[0.5259345000000002, 0.6161682500000001, 0.958655875], 
             UndirectedEdge[97, 135] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[19, 164] -> 
             RGBColor[0.8657703750000001, 0.84386075, 0.6308455], 
             UndirectedEdge[118, 139] -> 
             RGBColor[0.6380780000000001, 0.7150187500000001, 0.96604625], 
             UndirectedEdge[26, 137] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[142, 168] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[3, 194] -> 
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244], 
             UndirectedEdge[65, 195] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[73, 107] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[162, 172] -> 
             RGBColor[0.9696655000000001, 0.90933675, 0.33665662499999993`], 
             UndirectedEdge[68, 140] -> 
             RGBColor[0.8657703750000001, 0.84386075, 0.6308455], 
             UndirectedEdge[38, 165] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[86, 92] -> 
             RGBColor[0.8795787500000001, 0.72969825, 0.605445], 
             UndirectedEdge[90, 115] -> 
             RGBColor[0.6380780000000001, 0.7150187500000001, 0.96604625], 
             UndirectedEdge[11, 70] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[54, 123] -> 
             RGBColor[
              0.8128635000000001, 0.8380467500000001, 0.6774381249999999], 
             UndirectedEdge[107, 176] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[30, 76] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[129, 191] -> 
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125], 
             UndirectedEdge[7, 125] -> 
             RGBColor[0.6298296250000001, 0.68164425, 0.6644669999999999], 
             UndirectedEdge[3, 155] -> 
             RGBColor[
              0.6822000000000001, 0.7300055000000001, 0.6676941249999999], 
             UndirectedEdge[54, 118] -> 
             RGBColor[0.7419731250000001, 0.7804947500000001, 0.671857375], 
             UndirectedEdge[4, 171] -> 
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883], 
             UndirectedEdge[167, 189] -> 
             RGBColor[0.6380780000000001, 0.7150187500000001, 0.96604625], 
             UndirectedEdge[42, 81] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[5, 129] -> 
             RGBColor[0.9502645000000001, 0.83241825, 0.32104612499999996`], 
             UndirectedEdge[115, 133] -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 
             UndirectedEdge[92, 146] -> 
             RGBColor[0.84758025, 0.519779, 0.57621425], 
             UndirectedEdge[65, 151] -> 
             RGBColor[0.9145691249999999, 0.7572859999999999, 0.5979435], 
             UndirectedEdge[45, 156] -> 
             RGBColor[
              0.7618375000000001, 0.6372502500000001, 0.5938337499999999], 
             UndirectedEdge[74, 172] -> 
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375], 
             UndirectedEdge[31, 138] -> 
             RGBColor[0.3884347500000001, 0.5065805000000001, 0.946436125], 
             UndirectedEdge[116, 198] -> 
             RGBColor[0.5259345000000002, 0.6161682500000001, 0.958655875], 
             UndirectedEdge[42, 142] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[10, 129] -> 
             RGBColor[0.9502645000000001, 0.83241825, 0.32104612499999996`], 
             UndirectedEdge[3, 141] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[161, 162] -> 
             RGBColor[0.567445, 0.5842544999999999, 0.608463], 
             UndirectedEdge[6, 77] -> 
             RGBColor[0.9696655000000001, 0.90933675, 0.33665662499999993`], 
             UndirectedEdge[98, 113] -> 
             RGBColor[0.9548352499999999, 0.85022425, 0.51300225], 
             UndirectedEdge[3, 139] -> 
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883], 
             UndirectedEdge[34, 138] -> 
             RGBColor[0.6380780000000001, 0.7150187500000001, 0.96604625], 
             UndirectedEdge[22, 72] -> 
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244], 
             UndirectedEdge[34, 40] -> 
             RGBColor[0.7964483750000001, 0.47936675000000006`, 0.571242], 
             UndirectedEdge[41, 74] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[141, 146] -> 
             RGBColor[0.84758025, 0.519779, 0.57621425], 
             UndirectedEdge[90, 111] -> 
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185], 
             UndirectedEdge[66, 82] -> 
             RGBColor[0.936562, 0.7861965, 0.2678145], 
             UndirectedEdge[119, 151] -> 
             RGBColor[
              0.7618375000000001, 0.6372502500000001, 0.5938337499999999], 
             UndirectedEdge[4, 139] -> 
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883], 
             UndirectedEdge[165, 175] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[127, 139] -> 
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325], 
             UndirectedEdge[85, 117] -> 
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725], 
             UndirectedEdge[141, 155] -> 
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375], 
             UndirectedEdge[168, 189] -> 
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185], 
             UndirectedEdge[24, 175] -> 
             RGBColor[0.4593251250000001, 0.5641325000000001, 0.952016875], 
             UndirectedEdge[106, 176] -> 
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244], 
             UndirectedEdge[40, 53] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[27, 155] -> 
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999], 
             UndirectedEdge[33, 77] -> 
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775], 
             UndirectedEdge[67, 137] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[68, 129] -> 
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125], 
             UndirectedEdge[137, 192] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[58, 128] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[55, 90] -> 
             RGBColor[
              0.5714686250000001, 0.6629830000000001, 0.9594072499999999], 
             UndirectedEdge[26, 82] -> 
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725], 
             UndirectedEdge[43, 165] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[123, 199] -> 
             RGBColor[
              0.7452462500000001, 0.5457578750000001, 0.5793569999999999], 
             UndirectedEdge[34, 45] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[133, 178] -> 
             RGBColor[0.8118556250000001, 0.597793625, 0.585996], 
             UndirectedEdge[29, 189] -> 
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185], 
             UndirectedEdge[91, 164] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[116, 124] -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 
             UndirectedEdge[80, 113] -> 
             RGBColor[0.9548352499999999, 0.85022425, 0.51300225], 
             UndirectedEdge[10, 75] -> 
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725], 
             UndirectedEdge[74, 180] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[27, 149] -> 
             RGBColor[0.912831875, 0.93301875, 0.980709], 
             UndirectedEdge[4, 49] -> 
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375], 
             UndirectedEdge[9, 152] -> 
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075], 
             UndirectedEdge[19, 85] -> 
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775], 
             UndirectedEdge[189, 197] -> 
             RGBColor[0.742385125, 0.7965810000000001, 0.9327347500000001], 
             UndirectedEdge[69, 195] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[75, 191] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[73, 75] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[68, 188] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[4, 123] -> 
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244], 
             UndirectedEdge[7, 84] -> 
             RGBColor[0.578803625, 0.48084775, 0.580862625], 
             UndirectedEdge[171, 195] -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 
             UndirectedEdge[62, 167] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[91, 152] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[38, 90] -> 
             RGBColor[
              0.5714686250000001, 0.6629830000000001, 0.9594072499999999], 
             UndirectedEdge[3, 118] -> 
             RGBColor[0.44080512500000013`, 0.5549417500000001, 0.94966325], 
             UndirectedEdge[143, 181] -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 
             UndirectedEdge[20, 50] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[128, 136] -> 
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825], 
             UndirectedEdge[19, 161] -> 
             RGBColor[0.567445, 0.5842545, 0.608463], UndirectedEdge[19, 140] -> 
             RGBColor[0.955963, 0.863115, 0.283425], UndirectedEdge[39, 159] -> 
             RGBColor[
              0.8128635000000001, 0.8380467500000001, 0.6774381249999999], 
             UndirectedEdge[87, 154] -> 
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455], 
             UndirectedEdge[104, 143] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[6, 183] -> 
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999], 
             UndirectedEdge[17, 89] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[131, 176] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[44, 143] -> 
             RGBColor[0.6380780000000001, 0.7150187500000001, 0.96604625], 
             UndirectedEdge[140, 173] -> 
             RGBColor[0.799161, 0.791825, 0.6242064999999999], 
             UndirectedEdge[123, 195] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[96, 125] -> 
             RGBColor[
              0.6822000000000001, 0.7300055000000001, 0.6676941249999999], 
             UndirectedEdge[95, 159] -> 
             RGBColor[0.7452462500000001, 0.5457578750000001, 0.579357], 
             UndirectedEdge[171, 191] -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 
             UndirectedEdge[124, 187] -> 
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325], 
             UndirectedEdge[54, 191] -> 
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125], 
             UndirectedEdge[24, 55] -> 
             RGBColor[0.4593251250000001, 0.5641325000000001, 0.952016875], 
             UndirectedEdge[61, 126] -> 
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275], 
             UndirectedEdge[46, 101] -> 
             RGBColor[0.8481335, 0.3709807499999999, 0.19372599999999998`], 
             UndirectedEdge[158, 176] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[91, 200] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[29, 129] -> 
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375], 
             UndirectedEdge[37, 47] -> 
             RGBColor[0.8795787500000001, 0.72969825, 0.605445], 
             UndirectedEdge[25, 38] -> 
             RGBColor[0.7452462500000001, 0.5457578750000001, 0.579357], 
             UndirectedEdge[95, 173] -> 
             RGBColor[0.7452462500000001, 0.5457578750000001, 0.579357], 
             UndirectedEdge[86, 174] -> 
             RGBColor[0.578803625, 0.48084775, 0.580862625], 
             UndirectedEdge[4, 146] -> 
             RGBColor[0.5991755000000001, 0.31928975000000004`, 0.554859], 
             UndirectedEdge[114, 186] -> 
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775], 
             UndirectedEdge[155, 199] -> 
             RGBColor[0.91575075, 0.663269625, 0.29180712499999995`], 
             UndirectedEdge[114, 194] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[59, 186] -> 
             RGBColor[0.799161, 0.791825, 0.6242065], UndirectedEdge[99, 193] -> 
             RGBColor[0.8463693750000001, 0.76694225, 0.615235], 
             UndirectedEdge[109, 136] -> 
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275], 
             UndirectedEdge[50, 134] -> 
             RGBColor[0.9351754999999999, 0.94830075, 0.8810055], 
             UndirectedEdge[112, 183] -> 
             RGBColor[0.966007125, 0.97416875, 0.94242525], 
             UndirectedEdge[42, 73] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[42, 147] -> 
             RGBColor[0.935867, 0.9473880000000001, 0.7824125], 
             UndirectedEdge[87, 131] -> 
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375], 
             UndirectedEdge[1, 11] -> 
             RGBColor[0.9351754999999999, 0.94830075, 0.8810055], 
             UndirectedEdge[30, 81] -> 
             RGBColor[0.8617, 0.8926065000000001, 0.97573675], 
             UndirectedEdge[154, 188] -> 
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375], 
             UndirectedEdge[83, 156] -> 
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275], 
             UndirectedEdge[5, 107] -> 
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725], 
             UndirectedEdge[93, 180] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[10, 17] -> 
             RGBColor[0.9324916249999999, 0.83494225, 0.6127057499999999], 
             UndirectedEdge[75, 141] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[123, 141] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[40, 119] -> 
             RGBColor[0.7298390000000001, 0.42733100000000007`, 0.564603], 
             UndirectedEdge[16, 80] -> 
             RGBColor[0.9324916249999999, 0.83494225, 0.61270575], 
             UndirectedEdge[88, 180] -> 
             RGBColor[0.795090625, 0.84057075, 0.96909775], 
             UndirectedEdge[24, 41] -> 
             RGBColor[0.4593251250000001, 0.5641325000000001, 0.952016875], 
             UndirectedEdge[4, 119] -> 
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244], 
             UndirectedEdge[99, 136] -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 
             UndirectedEdge[10, 194] -> 
             RGBColor[0.77976, 0.7149065000000001, 0.6085959999999999], 
             UndirectedEdge[96, 102] -> 
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525], 
             UndirectedEdge[9, 88] -> 
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075], 
             UndirectedEdge[55, 108] -> 
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627], 
             UndirectedEdge[62, 197] -> 
             RGBColor[0.93101675, 0.9465810000000001, 0.9499267499999999], 
             UndirectedEdge[147, 168] -> 
             RGBColor[0.935867, 0.9473880000000001, 0.7824125], 
             UndirectedEdge[51, 106] -> 
             RGBColor[0.6311740000000001, 0.529209, 0.58408975], 
             UndirectedEdge[123, 155] -> 
             RGBColor[
              0.8128635000000001, 0.8380467500000001, 0.6774381249999999], 
             UndirectedEdge[75, 142] -> 
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925], 
             UndirectedEdge[31, 182] -> 
             RGBColor[0.630241625, 0.6977305, 0.925344375], 
             UndirectedEdge[65, 140] -> 
             RGBColor[0.9518926249999999, 0.91186075, 0.62831625]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 71 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 10 -> 
             RGBColor[0.917161, 0.7092780000000001, 0.25220400000000004`], 68 -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 155 -> 
             RGBColor[0.983368, 0.9555585, 0.38988824999999994`], 132 -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 26 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 29 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 113 -> 
             RGBColor[0.9925094999999999, 0.9911705, 0.7738005], 50 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 173 -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 192 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 165 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 92 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 11 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 137 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 120 -> 
             RGBColor[0.9925094999999999, 0.9911705, 0.7738005], 51 -> 
             RGBColor[0.881316, 0.5539655, 0.2226795], 72 -> 
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455], 64 -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 41 -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 103 -> 
             RGBColor[0.983368, 0.9555585, 0.38988824999999994`], 162 -> 
             RGBColor[0.955963, 0.863115, 0.283425], 196 -> 
             RGBColor[0.8481335, 0.3709807499999999, 0.19372599999999998`], 
             179 -> RGBColor[
              0.7755777500000002, 0.8246065000000001, 0.978266], 160 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 123 -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 150 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 188 -> 
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075], 46 -> 
             RGBColor[0.8481335, 0.3709807499999999, 0.19372599999999998`], 
             182 -> RGBColor[0.984192, 0.987731, 0.911643], 6 -> 
             RGBColor[0.983368, 0.9555585, 0.38988824999999994`], 131 -> 
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075], 45 -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 195 -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 148 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 161 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 1 -> 
             RGBColor[0.9925094999999999, 0.9911705, 0.7738005], 101 -> 
             RGBColor[0.8481335, 0.3709807499999999, 0.19372599999999998`], 
             12 -> RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455],
              39 -> RGBColor[0.983368, 0.9555585, 0.38988824999999994`], 48 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 77 -> 
             RGBColor[0.955963, 0.863115, 0.283425], 56 -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 110 -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 73 -> 
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455], 37 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 130 -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 107 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 59 -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 47 -> 
             RGBColor[0.881316, 0.5539655, 0.2226795], 159 -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 55 -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 49 -> 
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075], 82 -> 
             RGBColor[0.917161, 0.7092780000000001, 0.25220400000000004`], 
             199 -> RGBColor[
              0.8481335, 0.3709807499999999, 0.19372599999999998`], 89 -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 144 -> 
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455], 78 -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 42 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 154 -> 
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455], 168 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 121 -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 128 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 115 -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 61 -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 93 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 88 -> 
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075], 21 -> 
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455], 62 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 136 -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 190 -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 57 -> 
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455], 111 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 63 -> 
             RGBColor[0.881316, 0.5539655, 0.2226795], 75 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 30 -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 5 -> 
             RGBColor[0.917161, 0.7092780000000001, 0.25220400000000004`], 
             171 -> RGBColor[
              0.7755777500000002, 0.8246065000000001, 0.978266], 102 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 31 -> 
             RGBColor[0.2762912500000001, 0.4077300000000001, 0.93904575], 96 -> 
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455], 70 -> 
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075], 52 -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 183 -> 
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075], 158 -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 13 -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 170 -> 
             RGBColor[0.8481335, 0.3709807499999999, 0.19372599999999998`], 
             86 -> RGBColor[0.881316, 0.5539655, 0.2226795], 18 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 153 -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 58 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 22 -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 66 -> 
             RGBColor[0.955963, 0.863115, 0.283425], 143 -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 119 -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 145 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 91 -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 177 -> 
             RGBColor[0.955963, 0.863115, 0.283425], 200 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 114 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 24 -> 
             RGBColor[0.2762912500000001, 0.4077300000000001, 0.93904575], 
             176 -> RGBColor[
              0.6423590000000001, 0.7205350000000001, 0.964988], 79 -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 109 -> 
             RGBColor[0.881316, 0.5539655, 0.2226795], 135 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 108 -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 191 -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 14 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 185 -> 
             RGBColor[0.881316, 0.5539655, 0.2226795], 32 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 122 -> 
             RGBColor[0.5005782500000001, 0.6054310000000002, 0.9538265], 187 -> 
             RGBColor[0.9925094999999999, 0.9911705, 0.7738005], 193 -> 
             RGBColor[0.917161, 0.7092780000000001, 0.25220400000000004`], 
             100 -> RGBColor[
              0.7755777500000002, 0.8246065000000001, 0.978266], 180 -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 7 -> 
             RGBColor[0.2762912500000001, 0.4077300000000001, 0.93904575], 
             175 -> RGBColor[
              0.6423590000000001, 0.7205350000000001, 0.964988], 9 -> 
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075], 90 -> 
             RGBColor[0.5005782500000001, 0.6054310000000002, 0.9538265], 174 -> 
             RGBColor[0.2762912500000001, 0.4077300000000001, 0.93904575], 
             142 -> RGBColor[
              0.6423590000000001, 0.7205350000000001, 0.964988], 134 -> 
             RGBColor[0.9925094999999999, 0.9911705, 0.7738005], 105 -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 16 -> 
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075], 139 -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 146 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 126 -> 
             RGBColor[0.881316, 0.5539655, 0.2226795], 198 -> 
             RGBColor[0.2762912500000001, 0.4077300000000001, 0.93904575], 40 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 104 -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 181 -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 127 -> 
             RGBColor[0.9925094999999999, 0.9911705, 0.7738005], 76 -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 172 -> 
             RGBColor[0.983368, 0.9555585, 0.38988824999999994`], 84 -> 
             RGBColor[0.881316, 0.5539655, 0.2226795], 184 -> 
             RGBColor[0.5005782500000001, 0.6054310000000002, 0.9538265], 151 -> 
             RGBColor[0.881316, 0.5539655, 0.2226795], 35 -> 
             RGBColor[0.8481335, 0.3709807499999999, 0.19372599999999998`], 
             36 -> RGBColor[0.983368, 0.9555585, 0.38988824999999994`], 34 -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 38 -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 54 -> 
             RGBColor[0.983368, 0.9555585, 0.38988824999999994`], 60 -> 
             RGBColor[0.917161, 0.7092780000000001, 0.25220400000000004`], 87 -> 
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455], 141 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 67 -> 
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075], 133 -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 98 -> 
             RGBColor[0.917161, 0.7092780000000001, 0.25220400000000004`], 3 -> 
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455], 27 -> 
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075], 163 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 85 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 83 -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 28 -> 
             RGBColor[0.9925094999999999, 0.9911705, 0.7738005], 44 -> 
             RGBColor[0.5005782500000001, 0.6054310000000002, 0.9538265], 189 -> 
             RGBColor[0.5005782500000001, 0.6054310000000002, 0.9538265], 15 -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 80 -> 
             RGBColor[0.917161, 0.7092780000000001, 0.25220400000000004`], 
             112 -> RGBColor[0.984192, 0.987731, 0.911643], 169 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 69 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 20 -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 8 -> 
             RGBColor[0.8481335, 0.3709807499999999, 0.19372599999999998`], 
             116 -> RGBColor[
              0.7755777500000002, 0.8246065000000001, 0.978266], 97 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 118 -> 
             RGBColor[0.5005782500000001, 0.6054310000000002, 0.9538265], 178 -> 
             RGBColor[0.8481335, 0.3709807499999999, 0.19372599999999998`], 
             81 -> RGBColor[
              0.9478222499999999, 0.9606064999999999, 0.9732075], 166 -> 
             RGBColor[0.983368, 0.9555585, 0.38988824999999994`], 125 -> 
             RGBColor[0.983368, 0.9555585, 0.38988824999999994`], 95 -> 
             RGBColor[0.8481335, 0.3709807499999999, 0.19372599999999998`], 
             157 -> RGBColor[0.9938925000000001, 0.989345, 0.5766145], 74 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 19 -> 
             RGBColor[0.955963, 0.863115, 0.283425], 156 -> 
             RGBColor[0.881316, 0.5539655, 0.2226795], 167 -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 33 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 43 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 140 -> 
             RGBColor[0.955963, 0.863115, 0.283425], 186 -> 
             RGBColor[0.955963, 0.863115, 0.283425], 117 -> 
             RGBColor[0.917161, 0.7092780000000001, 0.25220400000000004`], 4 -> 
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455], 106 -> 
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455], 65 -> 
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075], 53 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 2 -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 147 -> 
             RGBColor[0.9938925000000001, 0.989345, 0.5766145], 94 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 23 -> 
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455], 194 -> 
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988], 129 -> 
             RGBColor[0.983368, 0.9555585, 0.38988824999999994`], 99 -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 25 -> 
             RGBColor[0.8481335, 0.3709807499999999, 0.19372599999999998`], 
             138 -> RGBColor[
              0.5005782500000001, 0.6054310000000002, 0.9538265], 124 -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 197 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 164 -> 
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266], 152 -> 
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075], 17 -> 
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075], 149 -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw1Vnk41Iv7HWbGjH3MjDGYYWbMlDYVokV9jgp1K023DRVaCFlSpNQNyVKW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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 11}], {
             RGBColor[0.9351754999999999, 0.94830075, 0.8810055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 35}], {
             RGBColor[0.9203215, 0.681075625, 0.48376325]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{1, 86}], {
             RGBColor[0.93691275, 0.7725679999999999, 0.49824]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{1, 94}], {
             RGBColor[0.9351754999999999, 0.94830075, 0.8810055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 174}], {
             RGBColor[0.634400375, 0.69945025, 0.8564231250000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 196}], {
             RGBColor[0.9203215, 0.681075625, 0.48376325]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{2, 16}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{2, 52}], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[0.8657703750000001, 0.84386075, 0.6308455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 78}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 80}], {
             RGBColor[0.8463693750000001, 0.76694225, 0.615235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 82}], {
             RGBColor[0.8463693750000001, 0.76694225, 0.615235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 98}], {
             RGBColor[0.8463693750000001, 0.76694225, 0.615235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 100}], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 120}], {
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 124}], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 187}], {
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 5}], {
             RGBColor[0.6490965000000001, 0.60686525, 0.598852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 10}], {
             RGBColor[0.6490965000000001, 0.60686525, 0.598852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 27}], {
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 29}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 49}], {
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 53}], {
             RGBColor[0.682612, 0.74609175, 0.9285715]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{3, 62}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 68}], {
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 71}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 75}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 118}], {
             RGBColor[0.44080512500000013`, 0.5549417500000001, 0.94966325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 127}], {
             RGBColor[0.68677075, 0.7478115000000001, 0.8596502500000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 129}], {
             RGBColor[
             0.6822000000000001, 0.7300055000000001, 0.6676941249999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 139}], {
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 141}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 146}], {
             RGBColor[0.5991755000000001, 0.31928975000000004`, 0.554859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 155}], {
             RGBColor[
             0.6822000000000001, 0.7300055000000001, 0.6676941249999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 167}], {
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 191}], {
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 194}], {
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 195}], {
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 34}], {
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 40}], {
             RGBColor[0.5991755000000001, 0.31928975000000004`, 0.554859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 49}], {
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 53}], {
             RGBColor[0.682612, 0.74609175, 0.9285715]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{4, 54}], {
             RGBColor[
             0.6822000000000001, 0.7300055000000001, 0.6676941249999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 65}], {
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 69}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 86}], {
             RGBColor[0.6311740000000001, 0.529209, 0.58408975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 92}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 118}], {
             RGBColor[0.44080512500000013`, 0.5549417500000001, 0.94966325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 119}], {
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 123}], {
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 139}], {
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 146}], {
             RGBColor[0.5991755000000001, 0.31928975000000004`, 0.554859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 171}], {
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 182}], {
             RGBColor[0.682612, 0.74609175, 0.9285715]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{4, 191}], {
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 195}], {
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 196}], {
             RGBColor[
             0.6145827500000001, 0.43771662499999997`, 0.5696129999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 199}], {
             RGBColor[
             0.6145827500000001, 0.43771662499999997`, 0.5696129999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 10}], {
             RGBColor[0.917161, 0.7092780000000001, 0.25220400000000004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 27}], {
             RGBColor[0.9324916249999999, 0.83494225, 0.6127057499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 30}], {
             RGBColor[0.8463693750000001, 0.76694225, 0.615235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 42}], {
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 68}], {
             RGBColor[0.8463693750000001, 0.76694225, 0.615235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 71}], {
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 73}], {
             RGBColor[0.6490965000000001, 0.60686525, 0.5988519999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 75}], {
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 76}], {
             RGBColor[0.77976, 0.7149065000000001, 0.6085959999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 81}], {
             RGBColor[0.9324916249999999, 0.83494225, 0.6127057499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 87}], {
             RGBColor[0.6490965000000001, 0.60686525, 0.5988519999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 89}], {
             RGBColor[0.77976, 0.7149065000000001, 0.6085959999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 107}], {
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 127}], {
             RGBColor[0.9548352499999999, 0.85022425, 0.51300225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 129}], {
             RGBColor[0.9502645000000001, 0.83241825, 0.32104612499999996`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 141}], {
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 142}], {
             RGBColor[0.77976, 0.7149065000000001, 0.6085959999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 147}], {
             RGBColor[0.95552675, 0.8493115, 0.41440925000000006`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 155}], {
             RGBColor[0.9502645000000001, 0.83241825, 0.32104612499999996`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 157}], {
             RGBColor[0.95552675, 0.8493115, 0.41440925000000006`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 168}], {
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 188}], {
             RGBColor[0.9324916249999999, 0.83494225, 0.6127057499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 197}], {
             RGBColor[0.9506764999999999, 0.8485045, 0.5819235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 44}], {
             RGBColor[0.7419731250000001, 0.7804947500000001, 0.671857375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 45}], {
             RGBColor[
             0.8128635000000001, 0.8380467500000001, 0.6774381249999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 58}], {
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 77}], {
             RGBColor[0.9696655000000001, 0.90933675, 0.33665662499999993`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 83}], {
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 96}], {
             RGBColor[
             0.6822000000000001, 0.7300055000000001, 0.6676941249999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 112}], {
             RGBColor[0.98378, 0.9716447500000001, 0.650765625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 156}], {
             RGBColor[0.932342, 0.7547619999999999, 0.306283875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 166}], {
             RGBColor[0.983368, 0.9555585, 0.38988824999999994`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 170}], {
             RGBColor[0.91575075, 0.663269625, 0.29180712499999995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 179}], {
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 183}], {
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 192}], {
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 8}], {
             RGBColor[0.5622123750000001, 0.389355375, 0.5663858749999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 16}], {
             RGBColor[0.61205675, 0.6841682499999999, 0.956126625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 52}], {
             RGBColor[0.5259345000000002, 0.6161682500000001, 0.958655875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[0.5259345000000002, 0.6161682500000001, 0.958655875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 67}], {
             RGBColor[0.61205675, 0.6841682499999999, 0.956126625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 79}], {
             RGBColor[0.5259345000000002, 0.6161682500000001, 0.958655875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[0.578803625, 0.48084775, 0.580862625]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{7, 122}], {
             RGBColor[0.3884347500000001, 0.5065805000000001, 0.946436125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 125}], {
             RGBColor[0.6298296250000001, 0.68164425, 0.6644669999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 126}], {
             RGBColor[0.578803625, 0.48084775, 0.580862625]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{7, 137}], {
             RGBColor[0.577066375, 0.6565805000000001, 0.9636281250000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 179}], {
             RGBColor[0.5259345000000002, 0.6161682500000001, 0.958655875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 192}], {
             RGBColor[0.577066375, 0.6565805000000001, 0.9636281250000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[0.6145827500000001, 0.43771662499999997`, 0.569613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 26}], {
             RGBColor[0.8629875, 0.6382058749999999, 0.59096825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 61}], {
             RGBColor[0.8118556250000001, 0.597793625, 0.585996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 67}], {
             RGBColor[0.8979778749999999, 0.6657936249999998, 0.58346675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 79}], {
             RGBColor[0.8118556250000001, 0.597793625, 0.585996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[0.88264725, 0.540129375, 0.22296500000000002`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 83}], {
             RGBColor[0.8118556250000001, 0.597793625, 0.585996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 122}], {
             RGBColor[0.674355875, 0.488205875, 0.57377625]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{8, 125}], {
             RGBColor[0.91575075, 0.6632696249999999, 0.29180712499999995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 137}], {
             RGBColor[0.8629875, 0.6382058749999999, 0.59096825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 166}], {
             RGBColor[0.91575075, 0.6632696249999999, 0.29180712499999995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 170}], {
             RGBColor[0.8481335, 0.3709807499999999, 0.19372599999999998`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 179}], {
             RGBColor[0.8118556250000001, 0.597793625, 0.585996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 192}], {
             RGBColor[0.8629875, 0.6382058749999999, 0.59096825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 198}], {
             RGBColor[0.5622123750000001, 0.389355375, 0.566385875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 18}], {
             RGBColor[0.966007125, 0.97416875, 0.94242525]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{9, 32}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{9, 39}], {
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 41}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{9, 57}], {
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 85}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{9, 88}], {
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 91}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{9, 103}], {
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 117}], {
             RGBColor[0.9324916249999999, 0.83494225, 0.61270575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 121}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{9, 152}], {
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 159}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{9, 164}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{9, 178}], {
             RGBColor[0.8979778749999999, 0.665793625, 0.5834667499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 200}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{10, 17}], {
             RGBColor[0.9324916249999999, 0.83494225, 0.6127057499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 27}], {
             RGBColor[0.9324916249999999, 0.83494225, 0.6127057499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 29}], {
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 30}], {
             RGBColor[0.8463693750000001, 0.76694225, 0.615235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 42}], {
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 51}], {
             RGBColor[0.8992385, 0.6316217500000001, 0.23744175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 62}], {
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 71}], {
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 73}], {
             RGBColor[0.6490965000000001, 0.60686525, 0.5988519999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 75}], {
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 89}], {
             RGBColor[0.77976, 0.7149065000000001, 0.6085959999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 107}], {
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[0.9502645000000001, 0.83241825, 0.32104612499999996`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 130}], {
             RGBColor[0.8463693750000001, 0.76694225, 0.615235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 141}], {
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 142}], {
             RGBColor[0.77976, 0.7149065000000001, 0.6085959999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 147}], {
             RGBColor[0.95552675, 0.8493115, 0.41440925000000006`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 149}], {
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 167}], {
             RGBColor[0.8463693750000001, 0.76694225, 0.615235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 168}], {
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 188}], {
             RGBColor[0.9324916249999999, 0.83494225, 0.6127057499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.7088696250000001, 0.6573545000000001, 0.6030152500000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 194}], {
             RGBColor[0.77976, 0.7149065000000001, 0.6085959999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 197}], {
             RGBColor[0.9506764999999999, 0.8485045, 0.5819235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 35}], {
             RGBColor[0.8629875, 0.638205875, 0.59096825]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{11, 70}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{11, 86}], {
             RGBColor[0.8795787500000001, 0.72969825, 0.605445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 94}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 110}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 138}], {
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 174}], {
             RGBColor[0.577066375, 0.6565805000000001, 0.9636281250000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 182}], {
             RGBColor[0.93101675, 0.9465810000000001, 0.9499267499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 196}], {
             RGBColor[0.8629875, 0.638205875, 0.59096825]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{12, 33}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 44}], {
             RGBColor[0.44080512500000013`, 0.5549417500000001, 0.94966325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 58}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 68}], {
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 77}], {
             RGBColor[0.6684975000000001, 0.68378375, 0.6144625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 96}], {
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 99}], {
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 102}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 128}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 140}], {
             RGBColor[0.6684975000000001, 0.68378375, 0.6144625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 162}], {
             RGBColor[0.6684975000000001, 0.68378375, 0.6144625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 172}], {
             RGBColor[
             0.6822000000000001, 0.7300055000000001, 0.6676941249999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 31}], {
             RGBColor[0.4593251250000001, 0.5641325000000001, 0.952016875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 34}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 36}], {
             RGBColor[
             0.8128635000000001, 0.8380467500000001, 0.6774381249999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 63}], {
             RGBColor[
             0.7618375000000001, 0.6372502500000001, 0.5938337499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 64}], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 70}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{13, 97}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 132}], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 138}], {
             RGBColor[
             0.5714686250000001, 0.6629830000000001, 0.9594072499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 145}], {
             RGBColor[0.8132755, 0.854133, 0.9383155]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{13, 153}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 185}], {
             RGBColor[
             0.7618375000000001, 0.6372502500000001, 0.5938337499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 22}], {
             RGBColor[0.8132755, 0.854133, 0.9383155]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{14, 48}], {
             RGBColor[0.93101675, 0.9465810000000001, 0.9499267499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 106}], {
             RGBColor[0.682612, 0.74609175, 0.9285715]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{14, 131}], {
             RGBColor[0.966007125, 0.97416875, 0.94242525]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{14, 176}], {
             RGBColor[0.8132755, 0.854133, 0.9383155]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{15, 59}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 114}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 167}], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 184}], {
             RGBColor[0.6380780000000001, 0.7150187500000001, 0.96604625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 186}], {
             RGBColor[0.8657703750000001, 0.84386075, 0.6308455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 194}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 52}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{16, 61}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{16, 67}], {
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 80}], {
             RGBColor[0.9324916249999999, 0.83494225, 0.61270575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 82}], {
             RGBColor[0.9324916249999999, 0.83494225, 0.61270575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 84}], {
             RGBColor[0.9145691249999999, 0.7572859999999999, 0.5979435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 100}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{16, 120}], {
             RGBColor[0.970165875, 0.9758884999999999, 0.8735040000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 125}], {
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[0.970165875, 0.9758884999999999, 0.8735040000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 30}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{17, 51}], {
             RGBColor[0.9145691249999999, 0.7572859999999999, 0.5979435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 73}], {
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 87}], {
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 89}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{17, 106}], {
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 107}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{17, 130}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{17, 131}], {
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 142}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{17, 147}], {
             RGBColor[0.970857375, 0.97497575, 0.774911]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{17, 149}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{17, 157}], {
             RGBColor[0.970857375, 0.97497575, 0.774911]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{17, 168}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{17, 188}], {
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 189}], {
             RGBColor[0.72420025, 0.7830187500000001, 0.963517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 197}], {
             RGBColor[0.966007125, 0.97416875, 0.94242525]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{18, 24}], {
             RGBColor[0.630241625, 0.6977305, 0.925344375]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{18, 32}], {
             RGBColor[0.93101675, 0.9465810000000001, 0.9499267499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 39}], {
             RGBColor[0.98378, 0.9716447500000001, 0.650765625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 41}], {
             RGBColor[0.8132755, 0.854133, 0.9383155]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{18, 85}], {
             RGBColor[0.93101675, 0.9465810000000001, 0.9499267499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 103}], {
             RGBColor[0.98378, 0.9716447500000001, 0.650765625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 108}], {
             RGBColor[
             0.8798848750000001, 0.9061687500000001, 0.9449544999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 117}], {
             RGBColor[0.9506764999999999, 0.8485045, 0.5819235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 133}], {
             RGBColor[
             0.8798848750000001, 0.9061687500000001, 0.9449544999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 152}], {
             RGBColor[0.966007125, 0.97416875, 0.94242525]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{18, 178}], {
             RGBColor[0.91616275, 0.6793558749999999, 0.5526845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 33}], {
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 74}], {
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 85}], {
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 88}], {
             RGBColor[0.9518926249999999, 0.91186075, 0.6283162499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 93}], {
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 95}], {
             RGBColor[0.90204825, 0.6170478749999999, 0.2385755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 102}], {
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 121}], {
             RGBColor[0.8657703750000001, 0.84386075, 0.6308455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 140}], {
             RGBColor[0.955963, 0.863115, 0.283425]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 159}], {
             RGBColor[0.799161, 0.791825, 0.6242064999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{19, 161}], {
             RGBColor[0.567445, 0.5842545, 0.608463]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 162}], {
             RGBColor[0.955963, 0.863115, 0.283425]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 164}], {
             RGBColor[0.8657703750000001, 0.84386075, 0.6308455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 172}], {
             RGBColor[0.9696655000000001, 0.90933675, 0.33665662499999993`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 173}], {
             RGBColor[0.799161, 0.791825, 0.6242064999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{19, 180}], {
             RGBColor[0.799161, 0.791825, 0.6242064999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{20, 22}], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 46}], {
             RGBColor[
             0.7452462500000001, 0.5457578750000001, 0.5793569999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 47}], {
             RGBColor[
             0.7618375000000001, 0.6372502500000001, 0.5938337499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 50}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 101}], {
             RGBColor[
             0.7452462500000001, 0.5457578750000001, 0.5793569999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 135}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 144}], {
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 23}], {
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 55}], {
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 61}], {
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 67}], {
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 83}], {
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 90}], {
             RGBColor[0.44080512500000013`, 0.5549417500000001, 0.94966325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 122}], {
             RGBColor[0.44080512500000013`, 0.5549417500000001, 0.94966325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 166}], {
             RGBColor[
             0.6822000000000001, 0.7300055000000001, 0.6676941249999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 170}], {
             RGBColor[
             0.6145827500000001, 0.43771662499999997`, 0.5696129999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 175}], {
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 177}], {
             RGBColor[0.6684975000000001, 0.68378375, 0.6144625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 179}], {
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 183}], {
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 192}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 72}], {
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 144}], {
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 176}], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 38}], {
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 43}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 55}], {
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 60}], {
             RGBColor[0.6490965000000001, 0.60686525, 0.598852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 90}], {
             RGBColor[0.44080512500000013`, 0.5549417500000001, 0.94966325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 111}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 115}], {
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 163}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 165}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 169}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 175}], {
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 177}], {
             RGBColor[0.6684975000000001, 0.68378375, 0.6144625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 39}], {
             RGBColor[0.6298296250000001, 0.68164425, 0.6644669999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 41}], {
             RGBColor[0.4593251250000001, 0.5641325000000001, 0.952016875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 55}], {
             RGBColor[0.4593251250000001, 0.5641325000000001, 0.952016875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 108}], {
             RGBColor[0.5259345000000002, 0.6161682500000001, 0.958655875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 111}], {
             RGBColor[0.577066375, 0.6565805000000001, 0.9636281250000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 115}], {
             RGBColor[0.5259345000000002, 0.6161682500000001, 0.958655875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 133}], {
             RGBColor[0.5259345000000002, 0.6161682500000001, 0.958655875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 163}], {
             RGBColor[0.577066375, 0.6565805000000001, 0.9636281250000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 165}], {
             RGBColor[0.577066375, 0.6565805000000001, 0.9636281250000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 175}], {
             RGBColor[0.4593251250000001, 0.5641325000000001, 0.952016875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 38}], {
             RGBColor[0.7452462500000001, 0.5457578750000001, 0.579357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[0.8629875, 0.6382058749999999, 0.59096825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 60}], {
             RGBColor[0.88264725, 0.540129375, 0.22296500000000002`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 111}], {
             RGBColor[0.8629875, 0.6382058749999999, 0.59096825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 165}], {
             RGBColor[0.8629875, 0.6382058749999999, 0.59096825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 58}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 67}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{26, 80}], {
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 82}], {
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 96}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 98}], {
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 99}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 116}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 120}], {
             RGBColor[0.9351754999999999, 0.94830075, 0.8810055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 122}], {
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 124}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 125}], {
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 128}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 136}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 137}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 170}], {
             RGBColor[0.8629875, 0.638205875, 0.59096825]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{26, 187}], {
             RGBColor[0.9351754999999999, 0.94830075, 0.8810055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 192}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 198}], {
             RGBColor[0.577066375, 0.6565805000000001, 0.9636281250000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 29}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{27, 30}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{27, 42}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{27, 62}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{27, 71}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{27, 73}], {
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 75}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{27, 89}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{27, 127}], {
             RGBColor[0.970165875, 0.9758884999999999, 0.8735040000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 129}], {
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 141}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{27, 142}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{27, 147}], {
             RGBColor[0.970857375, 0.97497575, 0.774911]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{27, 149}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{27, 155}], {
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 167}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{27, 168}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{27, 188}], {
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 189}], {
             RGBColor[0.72420025, 0.7830187500000001, 0.963517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{27, 197}], {
             RGBColor[0.966007125, 0.97416875, 0.94242525]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{28, 97}], {
             RGBColor[0.9351754999999999, 0.94830075, 0.8810055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 105}], {
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 71}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 73}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 129}], {
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 141}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 149}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 167}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 168}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 189}], {
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 194}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 197}], {
             RGBColor[0.93101675, 0.9465810000000001, 0.9499267499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 42}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 51}], {
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 71}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 73}], {
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 76}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 81}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{30, 87}], {
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 89}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 106}], {
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 107}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 130}], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 131}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{30, 142}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 147}], {
             RGBColor[
             0.8847351250000002, 0.9069757500000001, 0.7774402499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 157}], {
             RGBColor[
             0.8847351250000002, 0.9069757500000001, 0.7774402499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 168}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 176}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 188}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{30, 197}], {
             RGBColor[
             0.8798848750000001, 0.9061687500000001, 0.9449544999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 34}], {
             RGBColor[0.5259345000000002, 0.6161682500000001, 0.958655875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[0.5468051250000001, 0.2709285, 0.551631875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 45}], {
             RGBColor[0.4593251250000001, 0.5641325000000001, 0.952016875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 64}], {
             RGBColor[0.4593251250000001, 0.5641325000000001, 0.952016875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 65}], {
             RGBColor[0.61205675, 0.6841682499999999, 0.956126625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 132}], {
             RGBColor[0.4593251250000001, 0.5641325000000001, 0.952016875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 138}], {
             RGBColor[0.3884347500000001, 0.5065805000000001, 0.946436125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 153}], {
             RGBColor[0.5259345000000002, 0.6161682500000001, 0.958655875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 156}], {
             RGBColor[0.578803625, 0.48084775, 0.580862625]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{31, 182}], {
             RGBColor[0.630241625, 0.6977305, 0.925344375]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{31, 185}], {
             RGBColor[0.578803625, 0.48084775, 0.580862625]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{31, 199}], {
             RGBColor[0.5622123750000001, 0.389355375, 0.5663858749999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 39}], {
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 57}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 103}], {
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 117}], {
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 133}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 152}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{32, 178}], {
             RGBColor[0.8629875, 0.638205875, 0.59096825]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{33, 44}], {
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 58}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 68}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 77}], {
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 96}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 99}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 102}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 128}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 140}], {
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 162}], {
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 172}], {
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 180}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 40}], {
             RGBColor[0.7964483750000001, 0.47936675000000006`, 0.571242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 45}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 54}], {
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 64}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 65}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{34, 132}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 138}], {
             RGBColor[0.6380780000000001, 0.7150187500000001, 0.96604625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 153}], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 182}], {
             RGBColor[
             0.8798848750000001, 0.9061687500000001, 0.9449544999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 185}], {
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 199}], {
             RGBColor[0.8118556250000001, 0.597793625, 0.585996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 86}], {
             RGBColor[0.8647247499999999, 0.46247312499999993`, 0.20820275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[0.8629875, 0.6382058749999999, 0.59096825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 110}], {
             RGBColor[0.7452462500000001, 0.5457578750000001, 0.579357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 174}], {
             RGBColor[0.5622123750000001, 0.389355375, 0.566385875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 63}], {
             RGBColor[0.932342, 0.7547619999999999, 0.306283875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 70}], {
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 110}], {
             RGBColor[
             0.8128635000000001, 0.8380467500000001, 0.6774381249999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 138}], {
             RGBColor[0.7419731250000001, 0.7804947500000001, 0.671857375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 145}], {
             RGBColor[0.98378, 0.9716447500000001, 0.650765625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 185}], {
             RGBColor[0.932342, 0.7547619999999999, 0.306283875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 45}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 47}], {
             RGBColor[0.8795787500000001, 0.72969825, 0.605445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 50}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 97}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 101}], {
             RGBColor[0.8629875, 0.638205875, 0.59096825]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{37, 105}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 134}], {
             RGBColor[0.9351754999999999, 0.94830075, 0.8810055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 135}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 160}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 43}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 60}], {
             RGBColor[0.77976, 0.7149065000000001, 0.608596]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{38, 90}], {
             RGBColor[
             0.5714686250000001, 0.6629830000000001, 0.9594072499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 111}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 165}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 169}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 41}], {
             RGBColor[
             0.8128635000000001, 0.8380467500000001, 0.6774381249999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 74}], {
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 85}], {
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 88}], {
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 108}], {
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 117}], {
             RGBColor[0.9502645000000001, 0.83241825, 0.32104612499999996`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 133}], {
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 152}], {
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 159}], {
             RGBColor[
             0.8128635000000001, 0.8380467500000001, 0.6774381249999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 173}], {
             RGBColor[
             0.8128635000000001, 0.8380467500000001, 0.6774381249999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 178}], {
             RGBColor[0.91575075, 0.663269625, 0.29180712499999995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 49}], {
             RGBColor[0.8825706249999999, 0.5473667499999999, 0.56871275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 53}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{40, 54}], {
             RGBColor[0.9003435, 0.5448427499999999, 0.27705312499999996`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 64}], {
             RGBColor[0.7298390000000001, 0.42733100000000007`, 0.564603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[0.8825706249999999, 0.5473667499999999, 0.56871275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 69}], {
             RGBColor[0.84758025, 0.519779, 0.57621425]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{40, 119}], {
             RGBColor[0.7298390000000001, 0.42733100000000007`, 0.564603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 123}], {
             RGBColor[0.7298390000000001, 0.42733100000000007`, 0.564603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 132}], {
             RGBColor[0.7298390000000001, 0.42733100000000007`, 0.564603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 171}], {
             RGBColor[0.7964483750000001, 0.47936675000000006`, 0.571242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 182}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{40, 191}], {
             RGBColor[0.7964483750000001, 0.47936675000000006`, 0.571242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 195}], {
             RGBColor[0.7964483750000001, 0.47936675000000006`, 0.571242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 196}], {
             RGBColor[0.83272625, 0.2525538749999999, 0.178972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 199}], {
             RGBColor[0.83272625, 0.2525538749999999, 0.178972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 74}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 85}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{41, 108}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 121}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 133}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 140}], {
             RGBColor[0.799161, 0.791825, 0.6242065]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 151}], {
             RGBColor[
             0.7618375000000001, 0.6372502500000001, 0.5938337499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 152}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{41, 159}], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 161}], {
             RGBColor[0.4106430000000001, 0.5129645, 0.9492445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 173}], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 51}], {
             RGBColor[0.8795787500000001, 0.72969825, 0.605445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 71}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 73}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 76}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 81}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{42, 87}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 89}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 106}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 107}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 130}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 131}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{42, 142}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 147}], {
             RGBColor[0.935867, 0.9473880000000001, 0.7824125]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{42, 149}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 157}], {
             RGBColor[0.935867, 0.9473880000000001, 0.7824125]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{42, 168}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 176}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 188}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{42, 189}], {
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 197}], {
             RGBColor[0.93101675, 0.9465810000000001, 0.9499267499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 60}], {
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 111}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 115}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 163}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 165}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 169}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 58}], {
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 68}], {
             RGBColor[0.6380780000000001, 0.7150187500000001, 0.96604625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 77}], {
             RGBColor[0.7282706250000001, 0.7342730000000001, 0.61862575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 96}], {
             RGBColor[0.44080512500000013`, 0.5549417500000001, 0.94966325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 99}], {
             RGBColor[0.6380780000000001, 0.7150187500000001, 0.96604625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 102}], {
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 143}], {
             RGBColor[0.6380780000000001, 0.7150187500000001, 0.96604625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 166}], {
             RGBColor[0.7419731250000001, 0.7804947500000001, 0.671857375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 172}], {
             RGBColor[0.7419731250000001, 0.7804947500000001, 0.671857375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 198}], {
             RGBColor[0.3884347500000001, 0.5065805000000001, 0.946436125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 64}], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 112}], {
             RGBColor[0.8132755, 0.854133, 0.9383155]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{45, 132}], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 134}], {
             RGBColor[0.81743425, 0.85585275, 0.86939425]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{45, 153}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 156}], {
             RGBColor[
             0.7618375000000001, 0.6372502500000001, 0.5938337499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 183}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{46, 47}], {
             RGBColor[0.8647247499999999, 0.46247312499999993`, 0.20820275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 50}], {
             RGBColor[0.8629875, 0.6382058749999999, 0.59096825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 101}], {
             RGBColor[0.8481335, 0.3709807499999999, 0.19372599999999998`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 105}], {
             RGBColor[0.8118556250000001, 0.597793625, 0.585996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 135}], {
             RGBColor[0.8629875, 0.6382058749999999, 0.59096825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 144}], {
             RGBColor[0.6145827500000001, 0.43771662499999997`, 0.569613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 50}], {
             RGBColor[0.8795787500000001, 0.72969825, 0.605445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 101}], {
             RGBColor[0.8647247499999999, 0.46247312499999993`, 0.20820275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 105}], {
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 134}], {
             RGBColor[0.93691275, 0.7725679999999999, 0.49824]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{47, 135}], {
             RGBColor[0.8795787500000001, 0.72969825, 0.605445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 144}], {
             RGBColor[0.6311740000000001, 0.529209, 0.58408975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 72}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 76}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 81}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{48, 87}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 104}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 106}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 147}], {
             RGBColor[0.935867, 0.9473880000000001, 0.7824125]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{48, 154}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 157}], {
             RGBColor[0.935867, 0.9473880000000001, 0.7824125]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{48, 158}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 176}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 53}], {
             RGBColor[0.966007125, 0.97416875, 0.94242525]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{49, 54}], {
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 65}], {
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 69}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{49, 92}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{49, 118}], {
             RGBColor[0.72420025, 0.7830187500000001, 0.963517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 119}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{49, 123}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{49, 127}], {
             RGBColor[0.970165875, 0.9758884999999999, 0.8735040000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 139}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{49, 141}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{49, 146}], {
             RGBColor[0.8825706249999999, 0.5473667499999999, 0.56871275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 155}], {
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 171}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{49, 191}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{49, 195}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{49, 196}], {
             RGBColor[0.8979778749999999, 0.665793625, 0.5834667499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 199}], {
             RGBColor[0.8979778749999999, 0.665793625, 0.5834667499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 97}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 101}], {
             RGBColor[0.8629875, 0.638205875, 0.59096825]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{50, 105}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 134}], {
             RGBColor[0.9351754999999999, 0.94830075, 0.8810055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 135}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 144}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 73}], {
             RGBColor[0.6311740000000001, 0.529209, 0.58408975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 87}], {
             RGBColor[0.6311740000000001, 0.529209, 0.58408975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 106}], {
             RGBColor[0.6311740000000001, 0.529209, 0.58408975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[0.8795787500000001, 0.72969825, 0.605445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 130}], {
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 131}], {
             RGBColor[0.9145691249999999, 0.7572859999999999, 0.5979435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 147}], {
             RGBColor[0.93760425, 0.77165525, 0.399647]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{51, 157}], {
             RGBColor[0.93760425, 0.77165525, 0.399647]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{51, 168}], {
             RGBColor[0.8795787500000001, 0.72969825, 0.605445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 189}], {
             RGBColor[0.6909471250000001, 0.5796982500000001, 0.588253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 197}], {
             RGBColor[0.932754, 0.77084825, 0.56716125]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{52, 66}], {
             RGBColor[0.8657703750000001, 0.84386075, 0.6308455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 80}], {
             RGBColor[0.8463693750000001, 0.76694225, 0.615235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 82}], {
             RGBColor[0.8463693750000001, 0.76694225, 0.615235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 100}], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 120}], {
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 124}], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 125}], {
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 187}], {
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 54}], {
             RGBColor[0.98378, 0.9716447500000001, 0.650765625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 65}], {
             RGBColor[0.966007125, 0.97416875, 0.94242525]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{53, 69}], {
             RGBColor[0.93101675, 0.9465810000000001, 0.9499267499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 92}], {
             RGBColor[0.93101675, 0.9465810000000001, 0.9499267499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 118}], {
             RGBColor[0.742385125, 0.7965810000000001, 0.9327347500000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 119}], {
             RGBColor[0.8132755, 0.854133, 0.9383155]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{53, 123}], {
             RGBColor[0.8132755, 0.854133, 0.9383155]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{53, 127}], {
             RGBColor[0.98835075, 0.98945075, 0.8427217499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 129}], {
             RGBColor[0.98378, 0.9716447500000001, 0.650765625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 139}], {
             RGBColor[
             0.8798848750000001, 0.9061687500000001, 0.9449544999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 141}], {
             RGBColor[0.93101675, 0.9465810000000001, 0.9499267499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 146}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{53, 155}], {
             RGBColor[0.98378, 0.9716447500000001, 0.650765625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 171}], {
             RGBColor[
             0.8798848750000001, 0.9061687500000001, 0.9449544999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 182}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 191}], {
             RGBColor[
             0.8798848750000001, 0.9061687500000001, 0.9449544999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 195}], {
             RGBColor[
             0.8798848750000001, 0.9061687500000001, 0.9449544999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 196}], {
             RGBColor[0.91616275, 0.6793558749999999, 0.5526845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 199}], {
             RGBColor[0.91616275, 0.6793558749999999, 0.5526845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 64}], {
             RGBColor[
             0.8128635000000001, 0.8380467500000001, 0.6774381249999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 65}], {
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 118}], {
             RGBColor[0.7419731250000001, 0.7804947500000001, 0.671857375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 119}], {
             RGBColor[
             0.8128635000000001, 0.8380467500000001, 0.6774381249999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 123}], {
             RGBColor[
             0.8128635000000001, 0.8380467500000001, 0.6774381249999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 127}], {
             RGBColor[0.98793875, 0.9733645, 0.581844375]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{54, 140}], {
             RGBColor[0.9696655000000001, 0.90933675, 0.33665662499999993`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 151}], {
             RGBColor[0.932342, 0.7547619999999999, 0.306283875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 155}], {
             RGBColor[0.983368, 0.9555585, 0.38988824999999994`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 171}], {
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 172}], {
             RGBColor[0.983368, 0.9555585, 0.38988824999999994`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 191}], {
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 195}], {
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 199}], {
             RGBColor[0.91575075, 0.663269625, 0.29180712499999995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 90}], {
             RGBColor[
             0.5714686250000001, 0.6629830000000001, 0.9594072499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 108}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 111}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 115}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 163}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 175}], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 177}], {
             RGBColor[0.799161, 0.791825, 0.6242065]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 183}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{56, 109}], {
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 148}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 150}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 193}], {
             RGBColor[0.8463693750000001, 0.76694225, 0.615235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 88}], {
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 91}], {
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 103}], {
             RGBColor[
             0.6822000000000001, 0.7300055000000001, 0.6676941249999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 117}], {
             RGBColor[0.6490965000000001, 0.60686525, 0.598852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 121}], {
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 152}], {
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 164}], {
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 178}], {
             RGBColor[
             0.6145827500000001, 0.43771662499999997`, 0.5696129999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 200}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 77}], {
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 96}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 99}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 102}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 125}], {
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 128}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 137}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 166}], {
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 170}], {
             RGBColor[0.8629875, 0.638205875, 0.59096825]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{58, 192}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 198}], {
             RGBColor[0.577066375, 0.6565805000000001, 0.9636281250000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 62}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 92}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 114}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 146}], {
             RGBColor[0.7298390000000001, 0.42733100000000007`, 0.564603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 184}], {
             RGBColor[
             0.5714686250000001, 0.6629830000000001, 0.9594072499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 186}], {
             RGBColor[0.799161, 0.791825, 0.6242065]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 90}], {
             RGBColor[
             0.7088696250000001, 0.6573545000000001, 0.6030152500000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 111}], {
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 165}], {
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 169}], {
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 67}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{61, 79}], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 84}], {
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 122}], {
             RGBColor[0.6380780000000001, 0.7150187500000001, 0.96604625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 126}], {
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 179}], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 190}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 192}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 114}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 141}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 149}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 167}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 184}], {
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 189}], {
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 194}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 197}], {
             RGBColor[0.93101675, 0.9465810000000001, 0.9499267499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 70}], {
             RGBColor[0.9145691249999999, 0.7572859999999999, 0.5979435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 110}], {
             RGBColor[
             0.7618375000000001, 0.6372502500000001, 0.5938337499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 132}], {
             RGBColor[
             0.7618375000000001, 0.6372502500000001, 0.5938337499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 138}], {
             RGBColor[0.6909471250000001, 0.5796982500000001, 0.588253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 145}], {
             RGBColor[0.932754, 0.77084825, 0.56716125]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{63, 153}], {
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 185}], {
             RGBColor[0.881316, 0.5539655, 0.2226795]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{64, 65}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{64, 132}], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 138}], {
             RGBColor[
             0.5714686250000001, 0.6629830000000001, 0.9594072499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 153}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 156}], {
             RGBColor[
             0.7618375000000001, 0.6372502500000001, 0.5938337499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 182}], {
             RGBColor[0.8132755, 0.854133, 0.9383155]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{64, 185}], {
             RGBColor[
             0.7618375000000001, 0.6372502500000001, 0.5938337499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 199}], {
             RGBColor[
             0.7452462500000001, 0.5457578750000001, 0.5793569999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 118}], {
             RGBColor[0.72420025, 0.7830187500000001, 0.963517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 119}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{65, 123}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{65, 127}], {
             RGBColor[0.970165875, 0.9758884999999999, 0.8735040000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 140}], {
             RGBColor[0.9518926249999999, 0.91186075, 0.62831625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 151}], {
             RGBColor[0.9145691249999999, 0.7572859999999999, 0.5979435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 155}], {
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 156}], {
             RGBColor[0.9145691249999999, 0.7572859999999999, 0.5979435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 171}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{65, 172}], {
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 191}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{65, 195}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{65, 199}], {
             RGBColor[0.8979778749999999, 0.665793625, 0.5834667499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 78}], {
             RGBColor[0.799161, 0.791825, 0.6242064999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{66, 80}], {
             RGBColor[0.936562, 0.7861965, 0.2678145]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{66, 82}], {
             RGBColor[0.936562, 0.7861965, 0.2678145]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[0.936562, 0.7861965, 0.2678145]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{66, 100}], {
             RGBColor[0.8657703750000001, 0.84386075, 0.6308455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 113}], {
             RGBColor[0.9742362499999999, 0.92714275, 0.52861275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 120}], {
             RGBColor[0.9742362499999999, 0.92714275, 0.52861275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 124}], {
             RGBColor[0.8657703750000001, 0.84386075, 0.6308455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 136}], {
             RGBColor[0.8657703750000001, 0.84386075, 0.6308455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 187}], {
             RGBColor[0.9742362499999999, 0.92714275, 0.52861275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 79}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{67, 82}], {
             RGBColor[0.9324916249999999, 0.83494225, 0.61270575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 100}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{67, 122}], {
             RGBColor[0.72420025, 0.7830187500000001, 0.963517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 125}], {
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 137}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{67, 166}], {
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 170}], {
             RGBColor[0.8979778749999999, 0.665793625, 0.5834667499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 179}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{67, 192}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{68, 71}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 75}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 81}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{68, 102}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 127}], {
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 129}], {
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 140}], {
             RGBColor[0.8657703750000001, 0.84386075, 0.6308455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 143}], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 155}], {
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 172}], {
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 188}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{69, 86}], {
             RGBColor[0.8795787500000001, 0.72969825, 0.605445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 92}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 118}], {
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 123}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 139}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 146}], {
             RGBColor[0.84758025, 0.519779, 0.57621425]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{69, 171}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 174}], {
             RGBColor[0.577066375, 0.6565805000000001, 0.9636281250000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 186}], {
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 191}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 195}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 196}], {
             RGBColor[0.8629875, 0.638205875, 0.59096825]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{70, 110}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{70, 132}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{70, 138}], {
             RGBColor[0.72420025, 0.7830187500000001, 0.963517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[0.966007125, 0.97416875, 0.94242525]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{70, 185}], {
             RGBColor[0.9145691249999999, 0.7572859999999999, 0.5979435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 73}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 75}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 76}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 81}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{71, 87}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 89}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 107}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 127}], {
             RGBColor[0.9351754999999999, 0.94830075, 0.8810055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 129}], {
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 141}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 142}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 147}], {
             RGBColor[0.935867, 0.9473880000000001, 0.7824125]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{71, 155}], {
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 168}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 188}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{71, 197}], {
             RGBColor[0.93101675, 0.9465810000000001, 0.9499267499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 76}], {
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 81}], {
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 104}], {
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 143}], {
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 144}], {
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 154}], {
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 158}], {
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 160}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 176}], {
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 181}], {
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 75}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 87}], {
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 107}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 130}], {
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 142}], {
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 147}], {
             RGBColor[0.68746225, 0.7468987500000001, 0.76105725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 149}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 157}], {
             RGBColor[0.68746225, 0.7468987500000001, 0.76105725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 167}], {
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 168}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 188}], {
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 189}], {
             RGBColor[0.44080512500000013`, 0.5549417500000001, 0.94966325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 197}], {
             RGBColor[0.682612, 0.74609175, 0.9285715]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{74, 85}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 88}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{74, 93}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 95}], {
             RGBColor[0.8629875, 0.638205875, 0.59096825]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{74, 121}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 140}], {
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 152}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{74, 159}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 161}], {
             RGBColor[0.52838425, 0.6054125, 0.96085575]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{74, 162}], {
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 164}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 172}], {
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 173}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 180}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 81}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{75, 89}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 118}], {
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 127}], {
             RGBColor[0.9351754999999999, 0.94830075, 0.8810055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 129}], {
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 141}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 142}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 147}], {
             RGBColor[0.935867, 0.9473880000000001, 0.7824125]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{75, 155}], {
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 168}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 188}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{75, 191}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 81}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{76, 87}], {
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 89}], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 106}], {
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 107}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 142}], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 143}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 147}], {
             RGBColor[0.8181257500000001, 0.85494, 0.77080125]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{76, 154}], {
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[0.8181257500000001, 0.85494, 0.77080125]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{76, 158}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 176}], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 181}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 188}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{77, 83}], {
             RGBColor[0.8657703750000001, 0.84386075, 0.6308455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 96}], {
             RGBColor[0.6684975000000001, 0.68378375, 0.6144624999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 99}], {
             RGBColor[0.8657703750000001, 0.84386075, 0.6308455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 112}], {
             RGBColor[0.9700774999999999, 0.925423, 0.597534]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{77, 143}], {
             RGBColor[0.8657703750000001, 0.84386075, 0.6308455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 156}], {
             RGBColor[0.9186395, 0.70854025, 0.25305225]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{77, 160}], {
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 166}], {
             RGBColor[0.9696655000000001, 0.90933675, 0.33665662499999993`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 170}], {
             RGBColor[0.90204825, 0.6170478749999999, 0.2385755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 181}], {
             RGBColor[0.8657703750000001, 0.84386075, 0.6308455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 183}], {
             RGBColor[0.9518926249999999, 0.91186075, 0.6283162499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 192}], {
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 80}], {
             RGBColor[0.77976, 0.7149065000000001, 0.608596]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{78, 82}], {
             RGBColor[0.77976, 0.7149065000000001, 0.608596]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{78, 98}], {
             RGBColor[0.77976, 0.7149065000000001, 0.608596]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{78, 100}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 113}], {
             RGBColor[0.81743425, 0.85585275, 0.86939425]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{78, 120}], {
             RGBColor[0.81743425, 0.85585275, 0.86939425]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{78, 124}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 136}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 187}], {
             RGBColor[0.81743425, 0.85585275, 0.86939425]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{79, 84}], {
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 122}], {
             RGBColor[0.6380780000000001, 0.7150187500000001, 0.96604625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 126}], {
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 177}], {
             RGBColor[0.8657703750000001, 0.84386075, 0.6308455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 179}], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 190}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 82}], {
             RGBColor[0.917161, 0.7092780000000001, 0.25220400000000004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 98}], {
             RGBColor[0.917161, 0.7092780000000001, 0.25220400000000004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 100}], {
             RGBColor[0.8463693750000001, 0.76694225, 0.615235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 113}], {
             RGBColor[0.9548352499999999, 0.85022425, 0.51300225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 116}], {
             RGBColor[0.8463693750000001, 0.76694225, 0.615235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 120}], {
             RGBColor[0.9548352499999999, 0.85022425, 0.51300225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 124}], {
             RGBColor[0.8463693750000001, 0.76694225, 0.615235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 125}], {
             RGBColor[0.9502645000000001, 0.83241825, 0.32104612499999996`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 136}], {
             RGBColor[0.8463693750000001, 0.76694225, 0.615235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 137}], {
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 187}], {
             RGBColor[0.9548352499999999, 0.85022425, 0.51300225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 198}], {
             RGBColor[0.596726125, 0.5585040000000001, 0.5956248749999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 87}], {
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 89}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{81, 104}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{81, 107}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{81, 142}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{81, 143}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{81, 147}], {
             RGBColor[0.970857375, 0.97497575, 0.774911]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{81, 154}], {
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 157}], {
             RGBColor[0.970857375, 0.97497575, 0.774911]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{81, 158}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{81, 168}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{81, 176}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{81, 188}], {
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 98}], {
             RGBColor[0.917161, 0.7092780000000001, 0.25220400000000004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 100}], {
             RGBColor[0.8463693750000001, 0.76694225, 0.615235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 120}], {
             RGBColor[0.9548352499999999, 0.85022425, 0.51300225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 124}], {
             RGBColor[0.8463693750000001, 0.76694225, 0.615235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 125}], {
             RGBColor[0.9502645000000001, 0.83241825, 0.32104612499999996`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 136}], {
             RGBColor[0.8463693750000001, 0.76694225, 0.615235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 137}], {
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 187}], {
             RGBColor[0.9548352499999999, 0.85022425, 0.51300225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 198}], {
             RGBColor[0.596726125, 0.5585040000000001, 0.5956248749999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 122}], {
             RGBColor[0.6380780000000001, 0.7150187500000001, 0.96604625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 156}], {
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 166}], {
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 170}], {
             RGBColor[0.8118556250000001, 0.597793625, 0.585996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 175}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 179}], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 183}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{83, 192}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 126}], {
             RGBColor[0.881316, 0.5539655, 0.2226795]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{84, 190}], {
             RGBColor[
             0.7618375000000001, 0.6372502500000001, 0.5938337499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 88}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{85, 117}], {
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 133}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 140}], {
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 152}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{85, 159}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 161}], {
             RGBColor[0.52838425, 0.6054125, 0.96085575]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{85, 173}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 200}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 92}], {
             RGBColor[0.8795787500000001, 0.72969825, 0.605445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[0.8795787500000001, 0.72969825, 0.605445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 171}], {
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 174}], {
             RGBColor[0.578803625, 0.48084775, 0.580862625]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{86, 196}], {
             RGBColor[0.8647247499999999, 0.46247312499999993`, 0.20820275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 89}], {
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 106}], {
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 107}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 130}], {
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 131}], {
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 142}], {
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 147}], {
             RGBColor[0.68746225, 0.7468987500000001, 0.76105725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 157}], {
             RGBColor[0.68746225, 0.7468987500000001, 0.76105725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 168}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 176}], {
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 188}], {
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 91}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{88, 93}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{88, 95}], {
             RGBColor[0.8979778749999999, 0.665793625, 0.5834667499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 103}], {
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 117}], {
             RGBColor[0.9324916249999999, 0.83494225, 0.61270575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 121}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{88, 152}], {
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 159}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{88, 161}], {
             RGBColor[
             0.5633746249999999, 0.6330002499999999, 0.9533542500000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 164}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{88, 173}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{88, 180}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{88, 200}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{89, 106}], {
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 107}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 142}], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 147}], {
             RGBColor[0.8181257500000001, 0.85494, 0.77080125]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{89, 154}], {
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 157}], {
             RGBColor[0.8181257500000001, 0.85494, 0.77080125]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{89, 168}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 176}], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 188}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{90, 111}], {
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 115}], {
             RGBColor[0.6380780000000001, 0.7150187500000001, 0.96604625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 163}], {
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 165}], {
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 169}], {
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 175}], {
             RGBColor[
             0.5714686250000001, 0.6629830000000001, 0.9594072499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 177}], {
             RGBColor[0.7282706250000001, 0.7342730000000001, 0.61862575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 103}], {
             RGBColor[
             0.8128635000000001, 0.8380467500000001, 0.6774381249999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 117}], {
             RGBColor[0.77976, 0.7149065000000001, 0.608596]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{91, 121}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 152}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{91, 159}], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 164}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 200}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 118}], {
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 123}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 139}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 141}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 146}], {
             RGBColor[0.84758025, 0.519779, 0.57621425]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{92, 171}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 174}], {
             RGBColor[0.577066375, 0.6565805000000001, 0.9636281250000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 186}], {
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 191}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 195}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 196}], {
             RGBColor[0.8629875, 0.638205875, 0.59096825]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{93, 95}], {
             RGBColor[0.8629875, 0.638205875, 0.59096825]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{93, 121}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 150}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 159}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 161}], {
             RGBColor[0.52838425, 0.6054125, 0.96085575]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{93, 162}], {
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 164}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 173}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 180}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 200}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 174}], {
             RGBColor[0.577066375, 0.6565805000000001, 0.9636281250000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 196}], {
             RGBColor[0.8629875, 0.638205875, 0.59096825]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{95, 121}], {
             RGBColor[0.8118556250000001, 0.597793625, 0.585996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 150}], {
             RGBColor[0.8629875, 0.6382058749999999, 0.59096825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 159}], {
             RGBColor[0.7452462500000001, 0.5457578750000001, 0.579357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 161}], {
             RGBColor[0.51353025, 0.33818737499999996`, 0.5636135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 162}], {
             RGBColor[0.90204825, 0.6170478749999999, 0.2385755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 164}], {
             RGBColor[0.8118556250000001, 0.597793625, 0.585996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 173}], {
             RGBColor[0.7452462500000001, 0.5457578750000001, 0.579357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 180}], {
             RGBColor[0.7452462500000001, 0.5457578750000001, 0.579357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 99}], {
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 102}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 125}], {
             RGBColor[
             0.6822000000000001, 0.7300055000000001, 0.6676941249999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 128}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 137}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 166}], {
             RGBColor[
             0.6822000000000001, 0.7300055000000001, 0.6676941249999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 170}], {
             RGBColor[
             0.6145827500000001, 0.43771662499999997`, 0.5696129999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 198}], {
             RGBColor[0.3286616250000001, 0.45609125000000006`, 0.942272875]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 105}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 134}], {
             RGBColor[0.9351754999999999, 0.94830075, 0.8810055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 135}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 153}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 100}], {
             RGBColor[0.8463693750000001, 0.76694225, 0.615235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 109}], {
             RGBColor[0.8992385, 0.6316217500000001, 0.23744175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 113}], {
             RGBColor[0.9548352499999999, 0.85022425, 0.51300225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 116}], {
             RGBColor[0.8463693750000001, 0.76694225, 0.615235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 120}], {
             RGBColor[0.9548352499999999, 0.85022425, 0.51300225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 124}], {
             RGBColor[0.8463693750000001, 0.76694225, 0.615235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 125}], {
             RGBColor[0.9502645000000001, 0.83241825, 0.32104612499999996`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 136}], {
             RGBColor[0.8463693750000001, 0.76694225, 0.615235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 187}], {
             RGBColor[0.9548352499999999, 0.85022425, 0.51300225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 102}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 109}], {
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 116}], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 128}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 136}], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 137}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 162}], {
             RGBColor[0.8657703750000001, 0.84386075, 0.6308455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 193}], {
             RGBColor[0.8463693750000001, 0.76694225, 0.615235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 198}], {
             RGBColor[0.5259345000000002, 0.6161682500000001, 0.958655875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 113}], {
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 120}], {
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 124}], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 125}], {
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 136}], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 137}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 187}], {
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 198}], {
             RGBColor[0.5259345000000002, 0.6161682500000001, 0.958655875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 105}], {
             RGBColor[0.8118556250000001, 0.597793625, 0.585996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 134}], {
             RGBColor[0.9203215, 0.6810756249999999, 0.48376325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 135}], {
             RGBColor[0.8629875, 0.6382058749999999, 0.59096825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 144}], {
             RGBColor[0.6145827500000001, 0.43771662499999997`, 0.569613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 128}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 140}], {
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 162}], {
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 172}], {
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 180}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 117}], {
             RGBColor[0.9502645000000001, 0.83241825, 0.32104612499999996`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 152}], {
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 178}], {
             RGBColor[0.91575075, 0.663269625, 0.29180712499999995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 200}], {
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 143}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 154}], {
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 158}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 160}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 176}], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 181}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 188}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{105, 134}], {
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 135}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 144}], {
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 130}], {
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 131}], {
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 142}], {
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 147}], {
             RGBColor[0.68746225, 0.7468987500000001, 0.76105725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 157}], {
             RGBColor[0.68746225, 0.7468987500000001, 0.76105725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 176}], {
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 130}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 131}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{107, 142}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[0.935867, 0.9473880000000001, 0.7824125]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{107, 154}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[0.935867, 0.9473880000000001, 0.7824125]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{107, 168}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 176}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 188}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{108, 111}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 115}], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 133}], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 151}], {
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 163}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 165}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 175}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 113}], {
             RGBColor[0.93691275, 0.7725679999999999, 0.49824]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{109, 116}], {
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 124}], {
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 128}], {
             RGBColor[0.8795787500000001, 0.72969825, 0.605445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 136}], {
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 148}], {
             RGBColor[0.8795787500000001, 0.72969825, 0.605445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 193}], {
             RGBColor[0.8992385, 0.6316217500000001, 0.23744175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 138}], {
             RGBColor[
             0.5714686250000001, 0.6629830000000001, 0.9594072499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 145}], {
             RGBColor[0.8132755, 0.854133, 0.9383155]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{111, 115}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 163}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 165}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 169}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 175}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 177}], {
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 134}], {
             RGBColor[0.98835075, 0.98945075, 0.8427217499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 143}], {
             RGBColor[
             0.8798848750000001, 0.9061687500000001, 0.9449544999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 156}], {
             RGBColor[0.932754, 0.77084825, 0.5671612500000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 160}], {
             RGBColor[0.93101675, 0.9465810000000001, 0.9499267499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 181}], {
             RGBColor[
             0.8798848750000001, 0.9061687500000001, 0.9449544999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 183}], {
             RGBColor[0.966007125, 0.97416875, 0.94242525]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{113, 116}], {
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 124}], {
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 128}], {
             RGBColor[0.9351754999999999, 0.94830075, 0.8810055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 136}], {
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 148}], {
             RGBColor[0.9351754999999999, 0.94830075, 0.8810055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 187}], {
             RGBColor[0.9925094999999999, 0.9911705, 0.7738005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 193}], {
             RGBColor[0.9548352499999999, 0.85022425, 0.51300225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 198}], {
             RGBColor[0.634400375, 0.69945025, 0.8564231250000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 167}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 184}], {
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 186}], {
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 194}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 133}], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 163}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 165}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 175}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 124}], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 128}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 136}], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 148}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 193}], {
             RGBColor[0.8463693750000001, 0.76694225, 0.615235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 198}], {
             RGBColor[0.5259345000000002, 0.6161682500000001, 0.958655875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 121}], {
             RGBColor[0.8463693750000001, 0.76694225, 0.615235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 152}], {
             RGBColor[0.9324916249999999, 0.83494225, 0.6127057499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 159}], {
             RGBColor[0.77976, 0.7149065000000001, 0.6085959999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 164}], {
             RGBColor[0.8463693750000001, 0.76694225, 0.615235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 178}], {
             RGBColor[0.88264725, 0.540129375, 0.22296500000000002`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 200}], {
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 119}], {
             RGBColor[
             0.5714686250000001, 0.6629830000000001, 0.9594072499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 123}], {
             RGBColor[
             0.5714686250000001, 0.6629830000000001, 0.9594072499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 127}], {
             RGBColor[0.746543875, 0.7983007500000001, 0.8638135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 129}], {
             RGBColor[0.7419731250000001, 0.7804947500000001, 0.671857375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 139}], {
             RGBColor[0.6380780000000001, 0.7150187500000001, 0.96604625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 146}], {
             RGBColor[
             0.6589486250000001, 0.3697790000000001, 0.5590222499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 155}], {
             RGBColor[0.7419731250000001, 0.7804947500000001, 0.671857375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 171}], {
             RGBColor[0.6380780000000001, 0.7150187500000001, 0.96604625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 191}], {
             RGBColor[0.6380780000000001, 0.7150187500000001, 0.96604625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[0.6380780000000001, 0.7150187500000001, 0.96604625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 196}], {
             RGBColor[0.674355875, 0.488205875, 0.57377625]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[0.674355875, 0.488205875, 0.57377625]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{119, 123}], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 127}], {
             RGBColor[0.81743425, 0.85585275, 0.86939425]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{119, 140}], {
             RGBColor[0.799161, 0.791825, 0.6242065]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 151}], {
             RGBColor[
             0.7618375000000001, 0.6372502500000001, 0.5938337499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 155}], {
             RGBColor[
             0.8128635000000001, 0.8380467500000001, 0.6774381249999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 156}], {
             RGBColor[
             0.7618375000000001, 0.6372502500000001, 0.5938337499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 172}], {
             RGBColor[
             0.8128635000000001, 0.8380467500000001, 0.6774381249999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 191}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 195}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 199}], {
             RGBColor[
             0.7452462500000001, 0.5457578750000001, 0.5793569999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 124}], {
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 125}], {
             RGBColor[0.98793875, 0.9733645, 0.581844375]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{120, 136}], {
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 137}], {
             RGBColor[0.9351754999999999, 0.94830075, 0.8810055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 187}], {
             RGBColor[0.9925094999999999, 0.9911705, 0.7738005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 198}], {
             RGBColor[0.634400375, 0.69945025, 0.8564231250000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 152}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{121, 159}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 161}], {
             RGBColor[0.47725237500000006`, 0.5650002500000001, 0.9558835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 164}], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 173}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 180}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 125}], {
             RGBColor[0.7419731250000001, 0.7804947500000001, 0.671857375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 137}], {
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 166}], {
             RGBColor[0.7419731250000001, 0.7804947500000001, 0.671857375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 170}], {
             RGBColor[0.674355875, 0.488205875, 0.57377625]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{122, 179}], {
             RGBColor[0.6380780000000001, 0.7150187500000001, 0.96604625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 192}], {
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 127}], {
             RGBColor[0.81743425, 0.85585275, 0.86939425]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{123, 129}], {
             RGBColor[
             0.8128635000000001, 0.8380467500000001, 0.6774381249999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 139}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 141}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 146}], {
             RGBColor[0.7298390000000001, 0.42733100000000007`, 0.564603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 155}], {
             RGBColor[
             0.8128635000000001, 0.8380467500000001, 0.6774381249999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 171}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 191}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 195}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 196}], {
             RGBColor[
             0.7452462500000001, 0.5457578750000001, 0.5793569999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 199}], {
             RGBColor[
             0.7452462500000001, 0.5457578750000001, 0.5793569999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 125}], {
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 136}], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 187}], {
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 198}], {
             RGBColor[0.5259345000000002, 0.6161682500000001, 0.958655875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 136}], {
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 137}], {
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 166}], {
             RGBColor[0.983368, 0.9555585, 0.38988824999999994`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[0.91575075, 0.663269625, 0.29180712499999995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 187}], {
             RGBColor[0.98793875, 0.9733645, 0.581844375]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{125, 192}], {
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 198}], {
             RGBColor[
             0.6298296250000001, 0.6816442500000001, 0.6644669999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 190}], {
             RGBColor[
             0.7618375000000001, 0.6372502500000001, 0.5938337499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 129}], {
             RGBColor[0.98793875, 0.9733645, 0.581844375]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{127, 139}], {
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 140}], {
             RGBColor[0.9742362499999999, 0.92714275, 0.52861275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 141}], {
             RGBColor[0.9351754999999999, 0.94830075, 0.8810055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 155}], {
             RGBColor[0.98793875, 0.9733645, 0.581844375]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{127, 172}], {
             RGBColor[0.98793875, 0.9733645, 0.581844375]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{127, 191}], {
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 195}], {
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 199}], {
             RGBColor[0.9203215, 0.681075625, 0.48376325]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{128, 136}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 162}], {
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 193}], {
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 198}], {
             RGBColor[0.577066375, 0.6565805000000001, 0.9636281250000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 139}], {
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 141}], {
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 146}], {
             RGBColor[0.9003435, 0.5448427499999999, 0.27705312499999996`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 155}], {
             RGBColor[0.983368, 0.9555585, 0.38988824999999994`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 191}], {
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 195}], {
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 131}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{130, 149}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 157}], {
             RGBColor[
             0.8847351250000002, 0.9069757500000001, 0.7774402499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 168}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 189}], {
             RGBColor[0.6380780000000001, 0.7150187500000001, 0.96604625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 197}], {
             RGBColor[
             0.8798848750000001, 0.9061687500000001, 0.9449544999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 147}], {
             RGBColor[0.970857375, 0.97497575, 0.774911]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{131, 157}], {
             RGBColor[0.970857375, 0.97497575, 0.774911]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{131, 176}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{132, 138}], {
             RGBColor[
             0.5714686250000001, 0.6629830000000001, 0.9594072499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 145}], {
             RGBColor[0.8132755, 0.854133, 0.9383155]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{132, 153}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 182}], {
             RGBColor[0.8132755, 0.854133, 0.9383155]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{132, 185}], {
             RGBColor[
             0.7618375000000001, 0.6372502500000001, 0.5938337499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 163}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 178}], {
             RGBColor[0.8118556250000001, 0.597793625, 0.585996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 135}], {
             RGBColor[0.9351754999999999, 0.94830075, 0.8810055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 160}], {
             RGBColor[0.9351754999999999, 0.94830075, 0.8810055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 144}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 148}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 187}], {
             RGBColor[0.8840436250000001, 0.9078885000000001, 0.87603325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 193}], {
             RGBColor[0.8463693750000001, 0.76694225, 0.615235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 198}], {
             RGBColor[0.5259345000000002, 0.6161682500000001, 0.958655875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 166}], {
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 170}], {
             RGBColor[0.8629875, 0.638205875, 0.59096825]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{137, 179}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 187}], {
             RGBColor[0.9351754999999999, 0.94830075, 0.8810055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 192}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 198}], {
             RGBColor[0.577066375, 0.6565805000000001, 0.9636281250000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 145}], {
             RGBColor[0.742385125, 0.7965810000000001, 0.9327347500000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 153}], {
             RGBColor[0.6380780000000001, 0.7150187500000001, 0.96604625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 182}], {
             RGBColor[0.742385125, 0.7965810000000001, 0.9327347500000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 185}], {
             RGBColor[0.6909471250000001, 0.5796982500000001, 0.588253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 141}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 146}], {
             RGBColor[0.7964483750000001, 0.47936675000000006`, 0.571242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 155}], {
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 171}], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 191}], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 194}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 195}], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 196}], {
             RGBColor[0.8118556250000001, 0.597793625, 0.585996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 151}], {
             RGBColor[0.9186395, 0.70854025, 0.25305225]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{140, 161}], {
             RGBColor[0.567445, 0.5842545, 0.608463]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 162}], {
             RGBColor[0.955963, 0.863115, 0.283425]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 172}], {
             RGBColor[0.9696655000000001, 0.90933675, 0.33665662499999993`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 173}], {
             RGBColor[0.799161, 0.791825, 0.6242064999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{140, 180}], {
             RGBColor[0.799161, 0.791825, 0.6242064999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{140, 191}], {
             RGBColor[0.8657703750000001, 0.84386075, 0.6308455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 146}], {
             RGBColor[0.84758025, 0.519779, 0.57621425]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{141, 155}], {
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 167}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 191}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 194}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 195}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 147}], {
             RGBColor[0.8181257500000001, 0.85494, 0.77080125]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{142, 154}], {
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 157}], {
             RGBColor[0.8181257500000001, 0.85494, 0.77080125]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{142, 168}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 176}], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{143, 154}], {
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 158}], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 160}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 181}], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 188}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{144, 158}], {
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 153}], {
             RGBColor[
             0.8798848750000001, 0.9061687500000001, 0.9449544999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 185}], {
             RGBColor[0.932754, 0.77084825, 0.5671612500000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 155}], {
             RGBColor[0.9003435, 0.5448427499999999, 0.27705312499999996`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 171}], {
             RGBColor[0.7964483750000001, 0.47936675000000006`, 0.571242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 184}], {
             RGBColor[0.6589486250000001, 0.3697790000000001, 0.55902225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 186}], {
             RGBColor[0.886641, 0.498621, 0.2238215]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 191}], {
             RGBColor[0.7964483750000001, 0.47936675000000006`, 0.571242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 194}], {
             RGBColor[0.7298390000000001, 0.42733100000000007`, 0.564603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 195}], {
             RGBColor[0.7964483750000001, 0.47936675000000006`, 0.571242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 196}], {
             RGBColor[0.83272625, 0.2525538749999999, 0.178972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 154}], {
             RGBColor[0.68746225, 0.7468987500000001, 0.76105725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 157}], {
             RGBColor[0.9938925000000001, 0.989345, 0.5766145]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{147, 168}], {
             RGBColor[0.935867, 0.9473880000000001, 0.7824125]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{147, 176}], {
             RGBColor[0.8181257500000001, 0.85494, 0.77080125]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{147, 188}], {
             RGBColor[0.970857375, 0.97497575, 0.774911]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{148, 150}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 193}], {
             RGBColor[0.89750125, 0.8073545000000001, 0.62020725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 167}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 168}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 189}], {
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 194}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[0.93101675, 0.9465810000000001, 0.9499267499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 156}], {
             RGBColor[0.881316, 0.5539655, 0.2226795]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{151, 172}], {
             RGBColor[0.932342, 0.7547619999999999, 0.306283875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 175}], {
             RGBColor[
             0.7618375000000001, 0.6372502500000001, 0.5938337499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 183}], {
             RGBColor[0.9145691249999999, 0.7572859999999999, 0.5979435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 199}], {
             RGBColor[0.8647247499999999, 0.46247312499999993`, 0.20820275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 159}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{152, 178}], {
             RGBColor[0.8979778749999999, 0.665793625, 0.5834667499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 200}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{153, 182}], {
             RGBColor[
             0.8798848750000001, 0.9061687500000001, 0.9449544999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 185}], {
             RGBColor[0.828446875, 0.6892860000000001, 0.60047275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 157}], {
             RGBColor[0.68746225, 0.7468987500000001, 0.76105725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 158}], {
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 160}], {
             RGBColor[0.6294367500000001, 0.7049417500000001, 0.96685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 176}], {
             RGBColor[0.5116955000000001, 0.6124937500000001, 0.955244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 181}], {
             RGBColor[0.5783048750000002, 0.6645295000000001, 0.961883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 188}], {
             RGBColor[0.664427125, 0.7325295000000001, 0.95935375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 172}], {
             RGBColor[0.983368, 0.9555585, 0.38988824999999994`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 191}], {
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 195}], {
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 199}], {
             RGBColor[0.91575075, 0.663269625, 0.29180712499999995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 166}], {
             RGBColor[0.932342, 0.7547619999999999, 0.306283875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 170}], {
             RGBColor[0.8647247499999999, 0.46247312499999993`, 0.20820275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 175}], {
             RGBColor[
             0.7618375000000001, 0.6372502500000001, 0.5938337499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 183}], {
             RGBColor[0.9145691249999999, 0.7572859999999999, 0.5979435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 199}], {
             RGBColor[0.8647247499999999, 0.46247312499999993`, 0.20820275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 168}], {
             RGBColor[0.935867, 0.9473880000000001, 0.7824125]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{157, 176}], {
             RGBColor[0.8181257500000001, 0.85494, 0.77080125]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{157, 188}], {
             RGBColor[0.970857375, 0.97497575, 0.774911]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{158, 160}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 176}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 161}], {
             RGBColor[0.4106430000000001, 0.5129645, 0.9492445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 162}], {
             RGBColor[0.799161, 0.791825, 0.6242065]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 164}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 173}], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 180}], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 200}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 162}], {
             RGBColor[0.567445, 0.5842544999999999, 0.608463]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{161, 164}], {
             RGBColor[0.4772523750000001, 0.56500025, 0.9558835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 173}], {
             RGBColor[0.4106430000000001, 0.5129645, 0.9492445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 180}], {
             RGBColor[0.4106430000000001, 0.5129645, 0.9492445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 200}], {
             RGBColor[0.52838425, 0.6054125000000001, 0.96085575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 172}], {
             RGBColor[0.9696655000000001, 0.90933675, 0.33665662499999993`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 173}], {
             RGBColor[0.799161, 0.791825, 0.6242064999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{162, 180}], {
             RGBColor[0.799161, 0.791825, 0.6242064999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{163, 165}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 175}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 177}], {
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 200}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 169}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 175}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 177}], {
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 170}], {
             RGBColor[0.91575075, 0.663269625, 0.29180712499999995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 179}], {
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 183}], {
             RGBColor[0.9655951249999999, 0.9580825, 0.6815478749999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 192}], {
             RGBColor[0.9306047500000001, 0.93049475, 0.689049375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 198}], {
             RGBColor[
             0.6298296250000001, 0.6816442500000001, 0.6644669999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 189}], {
             RGBColor[0.6380780000000001, 0.7150187500000001, 0.96604625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 194}], {
             RGBColor[0.7089683750000002, 0.7725707500000001, 0.971627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 197}], {
             RGBColor[
             0.8798848750000001, 0.9061687500000001, 0.9449544999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 188}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{168, 189}], {
             RGBColor[0.6892098750000001, 0.7554310000000002, 0.9710185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 197}], {
             RGBColor[0.93101675, 0.9465810000000001, 0.9499267499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 177}], {
             RGBColor[0.91690225, 0.8842730000000001, 0.63581775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 190}], {
             RGBColor[0.76010025, 0.8129830000000001, 0.97659925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 179}], {
             RGBColor[0.8118556250000001, 0.597793625, 0.585996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 183}], {
             RGBColor[0.8979778749999999, 0.6657936249999998, 0.58346675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[0.8629875, 0.6382058749999999, 0.59096825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 198}], {
             RGBColor[0.5622123750000001, 0.389355375, 0.566385875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 174}], {
             RGBColor[0.5259345000000002, 0.6161682500000001, 0.958655875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 182}], {
             RGBColor[
             0.8798848750000001, 0.9061687500000001, 0.9449544999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 191}], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 195}], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 196}], {
             RGBColor[0.8118556250000001, 0.597793625, 0.585996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 199}], {
             RGBColor[0.8118556250000001, 0.597793625, 0.585996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 173}], {
             RGBColor[
             0.8128635000000001, 0.8380467500000001, 0.6774381249999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 180}], {
             RGBColor[
             0.8128635000000001, 0.8380467500000001, 0.6774381249999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 191}], {
             RGBColor[0.879472875, 0.8900825000000001, 0.684077125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 180}], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 186}], {
             RGBColor[0.616127125, 0.6354225, 0.611235375]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{174, 196}], {
             RGBColor[0.5622123750000001, 0.389355375, 0.5663858749999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 183}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{176, 188}], {
             RGBColor[0.795090625, 0.84057075, 0.96909775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{177, 179}], {
             RGBColor[0.8657703750000001, 0.84386075, 0.6308455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 190}], {
             RGBColor[0.799161, 0.791825, 0.6242064999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{179, 183}], {
             RGBColor[0.8617, 0.8926065000000001, 0.97573675]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{179, 192}], {
             RGBColor[0.8267096250000001, 0.8650187500000002, 0.98323825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 185}], {
             RGBColor[0.932754, 0.77084825, 0.5671612500000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 195}], {
             RGBColor[
             0.8798848750000001, 0.9061687500000001, 0.9449544999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 196}], {
             RGBColor[0.91616275, 0.6793558749999999, 0.5526845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 199}], {
             RGBColor[0.91616275, 0.6793558749999999, 0.5526845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 192}], {
             RGBColor[0.912831875, 0.93301875, 0.980709]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{184, 186}], {
             RGBColor[0.7282706250000001, 0.7342730000000001, 0.61862575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 194}], {
             RGBColor[
             0.5714686250000001, 0.6629830000000001, 0.9594072499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 198}], {
             RGBColor[0.634400375, 0.69945025, 0.8564231250000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 194}], {
             RGBColor[
             0.5714686250000001, 0.6629830000000001, 0.9594072499999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 197}], {
             RGBColor[0.742385125, 0.7965810000000001, 0.9327347500000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 195}], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 199}], {
             RGBColor[0.8118556250000001, 0.597793625, 0.585996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 197}], {
             RGBColor[0.8132755, 0.854133, 0.9383155]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{195, 196}], {
             RGBColor[0.8118556250000001, 0.597793625, 0.585996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 199}], {
             RGBColor[0.8118556250000001, 0.597793625, 0.585996]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.04610843439966642], {
             RGBColor[0.9925094999999999, 0.9911705, 0.7738005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.04610843439966642], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.04610843439966642], {
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.04610843439966642], {
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.04610843439966642], {
             RGBColor[0.917161, 0.7092780000000001, 0.25220400000000004`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.04610843439966642], {
             RGBColor[0.983368, 0.9555585, 0.38988824999999994`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.04610843439966642], {
             RGBColor[0.2762912500000001, 0.4077300000000001, 0.93904575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.04610843439966642], {
             RGBColor[0.8481335, 0.3709807499999999, 0.19372599999999998`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.04610843439966642], {
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.04610843439966642], {
             RGBColor[0.917161, 0.7092780000000001, 0.25220400000000004`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.04610843439966642], {
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.04610843439966642], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.04610843439966642], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.04610843439966642], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.04610843439966642], {
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.04610843439966642], {
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.04610843439966642], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.04610843439966642], {
             RGBColor[0.955963, 0.863115, 0.283425]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.04610843439966642], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.04610843439966642], {
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.04610843439966642], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.04610843439966642], {
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.04610843439966642], {
             RGBColor[0.2762912500000001, 0.4077300000000001, 0.93904575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.04610843439966642], {
             RGBColor[0.8481335, 0.3709807499999999, 0.19372599999999998`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.04610843439966642], {
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.04610843439966642], {
             RGBColor[0.9925094999999999, 0.9911705, 0.7738005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.04610843439966642], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.04610843439966642], {
             RGBColor[0.2762912500000001, 0.4077300000000001, 0.93904575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.04610843439966642], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.04610843439966642], {
             RGBColor[0.8481335, 0.3709807499999999, 0.19372599999999998`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.04610843439966642], {
             RGBColor[0.983368, 0.9555585, 0.38988824999999994`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.04610843439966642], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.04610843439966642], {
             RGBColor[0.983368, 0.9555585, 0.38988824999999994`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.04610843439966642], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.04610843439966642], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.04610843439966642], {
             RGBColor[0.5005782500000001, 0.6054310000000002, 0.9538265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.04610843439966642], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.04610843439966642], {
             RGBColor[0.8481335, 0.3709807499999999, 0.19372599999999998`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.04610843439966642], {
             RGBColor[0.881316, 0.5539655, 0.2226795]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[48, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.04610843439966642], {
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.04610843439966642], {
             RGBColor[0.881316, 0.5539655, 0.2226795]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[52, 0.04610843439966642], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.04610843439966642], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.04610843439966642], {
             RGBColor[0.983368, 0.9555585, 0.38988824999999994`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.04610843439966642], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.04610843439966642], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.04610843439966642], {
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.04610843439966642], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.04610843439966642], {
             RGBColor[0.917161, 0.7092780000000001, 0.25220400000000004`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.04610843439966642], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.04610843439966642], {
             RGBColor[0.881316, 0.5539655, 0.2226795]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[64, 0.04610843439966642], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.04610843439966642], {
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.04610843439966642], {
             RGBColor[0.955963, 0.863115, 0.283425]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.04610843439966642], {
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.04610843439966642], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.04610843439966642], {
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.04610843439966642], {
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.04610843439966642], {
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.04610843439966642], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.04610843439966642], {
             RGBColor[0.955963, 0.863115, 0.283425]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.04610843439966642], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.04610843439966642], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.04610843439966642], {
             RGBColor[0.917161, 0.7092780000000001, 0.25220400000000004`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.04610843439966642], {
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.04610843439966642], {
             RGBColor[0.917161, 0.7092780000000001, 0.25220400000000004`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.04610843439966642], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.04610843439966642], {
             RGBColor[0.881316, 0.5539655, 0.2226795]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[85, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.04610843439966642], {
             RGBColor[0.881316, 0.5539655, 0.2226795]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[87, 0.04610843439966642], {
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.04610843439966642], {
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.04610843439966642], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.04610843439966642], {
             RGBColor[0.5005782500000001, 0.6054310000000002, 0.9538265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.04610843439966642], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.04610843439966642], {
             RGBColor[0.8481335, 0.3709807499999999, 0.19372599999999998`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.04610843439966642], {
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.04610843439966642], {
             RGBColor[0.917161, 0.7092780000000001, 0.25220400000000004`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.04610843439966642], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.04610843439966642], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.04610843439966642], {
             RGBColor[0.8481335, 0.3709807499999999, 0.19372599999999998`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.04610843439966642], {
             RGBColor[0.983368, 0.9555585, 0.38988824999999994`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.04610843439966642], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.04610843439966642], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.04610843439966642], {
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.04610843439966642], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.04610843439966642], {
             RGBColor[0.881316, 0.5539655, 0.2226795]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[110, 0.04610843439966642], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.04610843439966642], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.04610843439966642], {
             RGBColor[0.9925094999999999, 0.9911705, 0.7738005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.04610843439966642], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.04610843439966642], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.04610843439966642], {
             RGBColor[0.917161, 0.7092780000000001, 0.25220400000000004`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.04610843439966642], {
             RGBColor[0.5005782500000001, 0.6054310000000002, 0.9538265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.04610843439966642], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.04610843439966642], {
             RGBColor[0.9925094999999999, 0.9911705, 0.7738005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.04610843439966642], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.04610843439966642], {
             RGBColor[0.5005782500000001, 0.6054310000000002, 0.9538265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.04610843439966642], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.04610843439966642], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.04610843439966642], {
             RGBColor[0.983368, 0.9555585, 0.38988824999999994`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.04610843439966642], {
             RGBColor[0.881316, 0.5539655, 0.2226795]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[127, 0.04610843439966642], {
             RGBColor[0.9925094999999999, 0.9911705, 0.7738005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.04610843439966642], {
             RGBColor[0.983368, 0.9555585, 0.38988824999999994`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.04610843439966642], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.04610843439966642], {
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.04610843439966642], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.04610843439966642], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.04610843439966642], {
             RGBColor[0.9925094999999999, 0.9911705, 0.7738005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.04610843439966642], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.04610843439966642], {
             RGBColor[0.5005782500000001, 0.6054310000000002, 0.9538265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.04610843439966642], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.04610843439966642], {
             RGBColor[0.955963, 0.863115, 0.283425]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.04610843439966642], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.04610843439966642], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.04610843439966642], {
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.04610843439966642], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.04610843439966642], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.04610843439966642], {
             RGBColor[0.9938925000000001, 0.989345, 0.5766145]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[148, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.04610843439966642], {
             RGBColor[0.881316, 0.5539655, 0.2226795]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[152, 0.04610843439966642], {
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.04610843439966642], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.04610843439966642], {
             RGBColor[0.38103200000000015`, 0.5044525000000001, 0.9455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.04610843439966642], {
             RGBColor[0.983368, 0.9555585, 0.38988824999999994`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.04610843439966642], {
             RGBColor[0.881316, 0.5539655, 0.2226795]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[157, 0.04610843439966642], {
             RGBColor[0.9938925000000001, 0.989345, 0.5766145]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[158, 0.04610843439966642], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.04610843439966642], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.04610843439966642], {
             RGBColor[0.955963, 0.863115, 0.283425]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.04610843439966642], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.04610843439966642], {
             RGBColor[0.983368, 0.9555585, 0.38988824999999994`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.04610843439966642], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.04610843439966642], {
             RGBColor[0.8481335, 0.3709807499999999, 0.19372599999999998`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.04610843439966642], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.04610843439966642], {
             RGBColor[0.983368, 0.9555585, 0.38988824999999994`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.04610843439966642], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.04610843439966642], {
             RGBColor[0.2762912500000001, 0.4077300000000001, 0.93904575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.04610843439966642], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.04610843439966642], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.04610843439966642], {
             RGBColor[0.955963, 0.863115, 0.283425]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.04610843439966642], {
             RGBColor[0.8481335, 0.3709807499999999, 0.19372599999999998`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.04610843439966642], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.04610843439966642], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.04610843439966642], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.04610843439966642], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.04610843439966642], {
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.04610843439966642], {
             RGBColor[0.5005782500000001, 0.6054310000000002, 0.9538265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.04610843439966642], {
             RGBColor[0.881316, 0.5539655, 0.2226795]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[186, 0.04610843439966642], {
             RGBColor[0.955963, 0.863115, 0.283425]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.04610843439966642], {
             RGBColor[0.9925094999999999, 0.9911705, 0.7738005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.04610843439966642], {
             RGBColor[0.9478222499999999, 0.9606064999999999, 0.9732075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.04610843439966642], {
             RGBColor[0.5005782500000001, 0.6054310000000002, 0.9538265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.04610843439966642], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.04610843439966642], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.04610843439966642], {
             RGBColor[0.917161, 0.7092780000000001, 0.25220400000000004`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.04610843439966642], {
             RGBColor[0.6423590000000001, 0.7205350000000001, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.04610843439966642], {
             RGBColor[0.7755777500000002, 0.8246065000000001, 0.978266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.04610843439966642], {
             RGBColor[0.8481335, 0.3709807499999999, 0.19372599999999998`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.04610843439966642], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.04610843439966642], {
             RGBColor[0.2762912500000001, 0.4077300000000001, 0.93904575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.04610843439966642], {
             RGBColor[0.8481335, 0.3709807499999999, 0.19372599999999998`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.04610843439966642], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
          103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
          129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 
          142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 
          155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 
          168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 
          181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 
          194, 195, 196, 197, 198, 199, 200}, {Null, CompressedData["
1:eJwVxfk/Gg4DAOBN5QibNGP1lWNDwghlmCNXuqiMigzJGcNQUi05SwdqhpKc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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[21, 55] -> 
             RGBColor[
              0.34859095953566543`, 0.47635370128389704`, 0.9434328855880982],
              UndirectedEdge[64, 132] -> 
             RGBColor[
              0.4650482384089718, 0.5716822037632778, 0.9522031318796592], 
             UndirectedEdge[42, 188] -> 
             RGBColor[
              0.2579862693567474, 0.38807828505832953`, 0.9380183944910747], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.5482557857976138, 0.6358309000327967, 0.9605283874597037], 
             UndirectedEdge[33, 68] -> 
             RGBColor[
              0.9768074272678445, 0.9356471682387506, 0.5374347809068445], 
             UndirectedEdge[168, 188] -> 
             RGBColor[
              0.2612998708737691, 0.39156109034719, 0.938207099195435], 
             UndirectedEdge[41, 161] -> 
             RGBColor[
              0.2872671394725109, 0.41926635574719545`, 0.9396708106680862], 
             UndirectedEdge[44, 68] -> 
             RGBColor[
              0.9298826077939246, 0.7566572199616033, 0.27010292258186963`], 
             UndirectedEdge[26, 136] -> 
             RGBColor[
              0.2577972163446346, 0.3882915980387517, 0.9379925421427979], 
             UndirectedEdge[9, 32] -> 
             RGBColor[
              0.18966018913671598`, 0.3166752623061849, 0.9341122392430056], 
             UndirectedEdge[71, 141] -> 
             RGBColor[
              0.3537772547746116, 0.4808458095490941, 0.9437633517346631], 
             UndirectedEdge[52, 100] -> 
             RGBColor[
              0.1956898688928864, 0.3230128380336974, 0.9344556205850076], 
             UndirectedEdge[172, 180] -> 
             RGBColor[
              0.6056868100783286, 0.4851310394922843, 0.577851031637082], 
             UndirectedEdge[168, 197] -> 
             RGBColor[
              0.20505165545148296`, 0.3328526692783333, 0.9349887604799977], 
             UndirectedEdge[125, 137] -> 
             RGBColor[
              0.29408774568202667`, 0.42503485891778914`, 0.9401105091078588],
              UndirectedEdge[17, 147] -> 
             RGBColor[
              0.22049695582396892`, 0.34908665925842064`, 0.9358683474869365],
              UndirectedEdge[10, 71] -> 
             RGBColor[
              0.2908445212370684, 0.4179419677193835, 0.9400607036352882], 
             UndirectedEdge[27, 129] -> 
             RGBColor[
              0.36049570993893, 0.4827296556793453, 0.9443430413040212], 
             UndirectedEdge[67, 166] -> 
             RGBColor[
              0.5298097305765306, 0.6164429264479874, 0.9594779119033563], 
             UndirectedEdge[3, 49] -> 
             RGBColor[
              0.42052372581365627`, 0.5386582479879358, 0.9480163778476842], 
             UndirectedEdge[151, 183] -> 
             RGBColor[
              0.9651436444656913, 0.888619018725243, 0.5091874749108671], 
             UndirectedEdge[125, 136] -> 
             RGBColor[
              0.24354766177349693`, 0.373314412710544, 0.9371810510902985], 
             UndirectedEdge[139, 194] -> 
             RGBColor[
              0.2435950267958037, 0.37336419635210427`, 0.9371837484582486], 
             UndirectedEdge[24, 108] -> 
             RGBColor[
              0.28258697373339425`, 0.41434720481573717`, 0.9394042821529283],
              UndirectedEdge[21, 192] -> 
             RGBColor[
              0.4135089355037963, 0.532245803699352, 0.9476624011874208], 
             UndirectedEdge[16, 52] -> 
             RGBColor[
              0.18638226183152043`, 0.31322995287582944`, 0.9339255661322337],
              UndirectedEdge[44, 166] -> 
             RGBColor[
              0.8512516278317916, 0.7399182542257667, 0.6091593456597434], 
             UndirectedEdge[78, 187] -> 
             RGBColor[
              0.19320618779608617`, 0.3204023317264835, 0.9343141786208218], 
             UndirectedEdge[99, 162] -> 
             RGBColor[
              0.5016163434350541, 0.6062220183620153, 0.9539225219304044], 
             UndirectedEdge[93, 150] -> 
             RGBColor[
              0.21197440955790398`, 0.3401289227721434, 0.9353830010850614], 
             UndirectedEdge[118, 155] -> 
             RGBColor[
              0.5320287520312512, 0.6287959624909311, 0.9570938290152922], 
             UndirectedEdge[16, 125] -> 
             RGBColor[
              0.22572938407249296`, 0.3545862731027316, 0.936166326535006], 
             UndirectedEdge[61, 179] -> 
             RGBColor[
              0.2879403991921272, 0.41444560530367136`, 0.9399115732194068], 
             UndirectedEdge[51, 197] -> 
             RGBColor[
              0.1914512391651612, 0.3185577694452115, 0.9342142368925045], 
             UndirectedEdge[80, 120] -> 
             RGBColor[
              0.20786563933481106`, 0.33581034475659416`, 0.9351490126992371],
              UndirectedEdge[21, 183] -> 
             RGBColor[
              0.6488438964095984, 0.6364280199535685, 0.605957146255827], 
             UndirectedEdge[182, 199] -> 
             RGBColor[
              0.668046802775716, 0.7309711261041182, 0.8355721890992451], 
             UndirectedEdge[17, 189] -> 
             RGBColor[
              0.19295037100619816`, 0.32013345206058996`, 0.9342996102330847],
              UndirectedEdge[116, 136] -> 
             RGBColor[
              0.23171997218972168`, 0.36088276103916334`, 0.9365074816660013],
              UndirectedEdge[119, 123] -> 
             RGBColor[
              0.6489751309922214, 0.46304637074551996`, 0.5712200187466816], 
             UndirectedEdge[71, 89] -> 
             RGBColor[
              0.315626713124748, 0.4439896226750534, 0.9414720128013241], 
             UndirectedEdge[7, 61] -> 
             RGBColor[
              0.2079174287175954, 0.335864778681537, 0.9351519620279711], 
             UndirectedEdge[3, 27] -> 
             RGBColor[
              0.3426067292683088, 0.4672664245880422, 0.9431945216539286], 
             UndirectedEdge[41, 108] -> 
             RGBColor[
              0.29936649893310274`, 0.4319835496839754, 0.9403598512899686], 
             UndirectedEdge[66, 98] -> 
             RGBColor[
              0.18802367047876978`, 0.3149551774354076, 0.9340190419264479], 
             UndirectedEdge[119, 127] -> 
             RGBColor[
              0.8608066453023939, 0.6319627472541103, 0.5901965057147129], 
             UndirectedEdge[15, 167] -> 
             RGBColor[
              0.18913040232451964`, 0.31611842277614255`, 0.9340820686678004],
              UndirectedEdge[12, 96] -> 
             RGBColor[
              0.9432592874949708, 0.8959893159471047, 0.6356118637427102], 
             UndirectedEdge[7, 52] -> 
             RGBColor[
              0.19704159904264756`, 0.32443359212573797`, 0.934532599617331], 
             UndirectedEdge[163, 165] -> 
             RGBColor[
              0.24378292836413576`, 0.3735616928140688, 0.9371944491745896], 
             UndirectedEdge[71, 73] -> 
             RGBColor[
              0.29060892456725834`, 0.41769434068172157`, 0.9400472867534765],
              UndirectedEdge[60, 165] -> 
             RGBColor[
              0.1933919500064047, 0.32059757958753266`, 0.9343247575038889], 
             UndirectedEdge[120, 124] -> 
             RGBColor[
              0.20998768265750406`, 0.3380407468340621, 0.9352698599271827], 
             UndirectedEdge[43, 163] -> 
             RGBColor[
              0.2357550055079826, 0.36512383689254435`, 0.9367372708441793], 
             UndirectedEdge[146, 194] -> 
             RGBColor[
              0.22346288152433108`, 0.352204035220052, 0.9360372525678782], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.24761466346370808`, 0.37758908934975655`, 0.9374126608199662],
              UndirectedEdge[81, 157] -> 
             RGBColor[
              0.25622740358141927`, 0.3866416252927345, 0.9379031436282628], 
             UndirectedEdge[59, 114] -> 
             RGBColor[
              0.1828190891221793, 0.3094848324401137, 0.9337226487176782], 
             UndirectedEdge[31, 185] -> 
             RGBColor[
              0.38200599992585305`, 0.49606971836717273`, 0.9464117075671216],
              UndirectedEdge[58, 198] -> 
             RGBColor[
              0.6531000789032383, 0.7219510755774461, 0.9474306913916395], 
             UndirectedEdge[30, 142] -> 
             RGBColor[
              0.23578204115771023`, 0.3651522530745672, 0.9367388104844356], 
             UndirectedEdge[26, 96] -> 
             RGBColor[
              0.6145993386243387, 0.6885815666825401, 0.9662497087986179], 
             UndirectedEdge[25, 111] -> 
             RGBColor[
              0.19983749274486573`, 0.32737225367666856`, 0.9346918216275183],
              UndirectedEdge[89, 107] -> 
             RGBColor[
              0.24257389966697504`, 0.37229092699650596`, 0.9371255967788841],
              UndirectedEdge[51, 189] -> 
             RGBColor[
              0.18831403886767445`, 0.3152603730225656, 0.9340355779766345], 
             UndirectedEdge[81, 158] -> 
             RGBColor[
              0.3111871249613185, 0.44370525612704076`, 0.9410587411898188], 
             UndirectedEdge[93, 159] -> 
             RGBColor[
              0.24313944261504272`, 0.37288534849241906`, 0.9371578036131307],
              UndirectedEdge[191, 195] -> 
             RGBColor[
              0.6555677203865065, 0.728688801139147, 0.9677847110498968], 
             UndirectedEdge[17, 131] -> 
             RGBColor[
              0.18648216780881113`, 0.31333496039236675`, 0.9339312556298427],
              UndirectedEdge[18, 32] -> 
             RGBColor[
              0.20453729510132862`, 0.33231204393799124`, 0.9349594684189844],
              UndirectedEdge[59, 184] -> 
             RGBColor[
              0.1830159493280225, 0.30969174499811286`, 0.9337338596151724], 
             UndirectedEdge[156, 175] -> 
             RGBColor[
              0.6596444744105936, 0.3751515803022144, 0.5596916614795366], 
             UndirectedEdge[2, 82] -> 
             RGBColor[
              0.19716931432443496`, 0.3245678289845131, 0.934539872813691], 
             UndirectedEdge[12, 44] -> 
             RGBColor[
              0.9244380104653778, 0.7365581580535521, 0.25797799946440303`], 
             UndirectedEdge[115, 175] -> 
             RGBColor[
              0.4077982725568444, 0.5263530627871394, 0.9475600302171414], 
             UndirectedEdge[30, 131] -> 
             RGBColor[
              0.19553065372363834`, 0.3228454927959929, 0.9344465535166567], 
             UndirectedEdge[53, 65] -> 
             RGBColor[
              0.7940608836370591, 0.7881654857639895, 0.6245197254205552], 
             UndirectedEdge[17, 51] -> 
             RGBColor[
              0.18683289480672916`, 0.31370359670455467`, 0.9339512290135199],
              UndirectedEdge[109, 128] -> 
             RGBColor[
              0.32435782382982603`, 0.44691944921604004`, 0.9421979744658333],
              UndirectedEdge[101, 135] -> 
             RGBColor[
              0.1965653140451214, 0.3239329863951249, 0.9345054758913225], 
             UndirectedEdge[54, 195] -> 
             RGBColor[
              0.7447123095700184, 0.789153733450638, 0.681635360097179], 
             UndirectedEdge[122, 192] -> 
             RGBColor[
              0.3718189687016956, 0.49328632243521403`, 0.9451102958483188], 
             UndirectedEdge[155, 195] -> 
             RGBColor[
              0.5871109616069528, 0.6752098608899229, 0.9609615810995339], 
             UndirectedEdge[42, 87] -> 
             RGBColor[
              0.20973659970745412`, 0.3377768427339811, 0.9352555611246214], 
             UndirectedEdge[31, 153] -> 
             RGBColor[
              0.4071092490619125, 0.522454824847095, 0.9478413004684911], 
             UndirectedEdge[64, 199] -> 
             RGBColor[
              0.8123958459095635, 0.8512144164818124, 0.8460919805023865], 
             UndirectedEdge[107, 188] -> 
             RGBColor[
              0.2654176677513521, 0.39588915594893126`, 0.9384416016358788], 
             UndirectedEdge[27, 189] -> 
             RGBColor[
              0.23047600087590087`, 0.35957526831600095`, 0.9364366393399698],
              UndirectedEdge[14, 176] -> 
             RGBColor[
              0.20667251283261232`, 0.3345562931541938, 0.9350810659100094], 
             UndirectedEdge[123, 146] -> 
             RGBColor[
              0.34826410267529395`, 0.47021417637892043`, 0.9436264907064373],
              UndirectedEdge[30, 130] -> 
             RGBColor[
              0.1969307686942434, 0.3243171024025152, 0.9345262879929481], 
             UndirectedEdge[72, 143] -> 
             RGBColor[
              0.5544319884729032, 0.6356036049331575, 0.9619129375714212], 
             UndirectedEdge[68, 155] -> 
             RGBColor[
              0.817090690205986, 0.812348570970784, 0.6355099976070364], 
             UndirectedEdge[32, 39] -> 
             RGBColor[
              0.2190345544466123, 0.34754958268921615`, 0.9357850658919249], 
             UndirectedEdge[184, 194] -> 
             RGBColor[
              0.19166541671322765`, 0.3187828836278702, 0.9342264339870195], 
             UndirectedEdge[74, 152] -> 
             RGBColor[
              0.2730580915689248, 0.4008937800418094, 0.9389875071669056], 
             UndirectedEdge[71, 147] -> 
             RGBColor[
              0.3066316503071229, 0.4345352413338067, 0.9409597572808632], 
             UndirectedEdge[39, 173] -> 
             RGBColor[
              0.3099077362629189, 0.437607436708477, 0.9411599161992759], 
             UndirectedEdge[139, 171] -> 
             RGBColor[
              0.2967091465842705, 0.42919050387948254`, 0.940208519004903], 
             UndirectedEdge[73, 189] -> 
             RGBColor[
              0.20595537414504966`, 0.3338025349243465, 0.9350402259226642], 
             UndirectedEdge[20, 22] -> 
             RGBColor[
              0.1854064647205249, 0.3122043282430629, 0.9338699959303249], 
             UndirectedEdge[17, 168] -> 
             RGBColor[
              0.2004333110930509, 0.32799849653767643`, 0.9347257526010131], 
             UndirectedEdge[13, 132] -> 
             RGBColor[
              0.26083574153477407`, 0.39148528066721244`, 0.9381655816572811],
              UndirectedEdge[99, 109] -> 
             RGBColor[
              0.38461485844464394`, 0.49643648481667146`, 0.9467764936235569],
              UndirectedEdge[119, 195] -> 
             RGBColor[
              0.6739288625041259, 0.48336449574698853`, 0.5731680108502653], 
             UndirectedEdge[10, 188] -> 
             RGBColor[
              0.26557638653463256`, 0.3960559794535111, 0.9384506404357832], 
             UndirectedEdge[182, 185] -> 
             RGBColor[
              0.28644155976238705`, 0.41543196640215296`, 0.9397324188136974],
              UndirectedEdge[98, 187] -> 
             RGBColor[
              0.1979911315151781, 0.3254316109582035, 0.9345866740869342], 
             UndirectedEdge[10, 167] -> 
             RGBColor[
              0.2086421156058076, 0.33662647054885053`, 0.9351932318741767], 
             UndirectedEdge[113, 187] -> 
             RGBColor[
              0.20396723113485943`, 0.331712870565089, 0.934927004119428], 
             UndirectedEdge[83, 170] -> 
             RGBColor[
              0.7907969761749707, 0.8373558827785927, 0.9795546906537492], 
             UndirectedEdge[39, 41] -> 
             RGBColor[
              0.2713842645263738, 0.40257244714637036`, 0.9387663044365115], 
             UndirectedEdge[138, 145] -> 
             RGBColor[
              0.20603341116594734`, 0.3338845567811428, 0.935044670015559], 
             UndirectedEdge[75, 155] -> 
             RGBColor[
              0.5876661844347633, 0.6756606157940428, 0.9610052902743873], 
             UndirectedEdge[90, 163] -> 
             RGBColor[
              0.2545166466581612, 0.38484351129813643`, 0.9378057185523212], 
             UndirectedEdge[2, 66] -> 
             RGBColor[
              0.1829598466238134, 0.3096327774988722, 0.9337306646491643], 
             UndirectedEdge[88, 200] -> 
             RGBColor[
              0.20358824889509092`, 0.3313145362022305, 0.9349054216415271], 
             UndirectedEdge[67, 170] -> 
             RGBColor[
              0.45554903905121463`, 0.5584299098262512, 0.952076300177731], 
             UndirectedEdge[124, 136] -> 
             RGBColor[
              0.22442474851543817`, 0.35321501841359515`, 0.9360920294700671],
              UndirectedEdge[129, 155] -> 
             RGBColor[
              0.5638305008231241, 0.6563097340528043, 0.959128857947493], 
             UndirectedEdge[149, 167] -> 
             RGBColor[
              0.19241882352516138`, 0.31957476195596346`, 0.9342693393903937],
              UndirectedEdge[172, 173] -> 
             RGBColor[
              0.6185469880325928, 0.49626987926492994`, 0.5786704708045187], 
             UndirectedEdge[143, 160] -> 
             RGBColor[
              0.6494266978782655, 0.7230187336619522, 0.967777881154406], 
             UndirectedEdge[27, 89] -> 
             RGBColor[
              0.2670176485112967, 0.3979828568550783, 0.9385176321142823], 
             UndirectedEdge[172, 191] -> 
             RGBColor[
              0.8397221650752837, 0.6755835027616839, 0.59719713282006], 
             UndirectedEdge[11, 182] -> 
             RGBColor[
              0.27189457932291083`, 0.4001421676284322, 0.9389039897979983], 
             UndirectedEdge[159, 164] -> 
             RGBColor[
              0.22503263737217588`, 0.35385394814440607`, 0.9361266478411673],
              UndirectedEdge[151, 156] -> 
             RGBColor[
              0.9063104280310577, 0.5683123234196433, 0.4581304793295804], 
             UndirectedEdge[94, 196] -> 
             RGBColor[
              0.21169845343388266`, 0.3398388753891681, 0.9353672857920389], 
             UndirectedEdge[69, 139] -> 
             RGBColor[
              0.2677410752801248, 0.398743224257023, 0.938558830198553], 
             UndirectedEdge[53, 127] -> 
             RGBColor[
              0.7532853090466265, 0.8074724235406385, 0.9760373166313029], 
             UndirectedEdge[171, 196] -> 
             RGBColor[
              0.2703681630861383, 0.4015044601081305, 0.9387084389626774], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.7310843955752011, 0.737038335696917, 0.6195619855898489], 
             UndirectedEdge[74, 162] -> 
             RGBColor[
              0.39867126833608224`, 0.5197307476573095, 0.9466239585805827], 
             UndirectedEdge[34, 153] -> 
             RGBColor[
              0.3561569436366287, 0.48045786172119975`, 0.9440046574916221], 
             UndirectedEdge[98, 109] -> 
             RGBColor[
              0.2049550918267402, 0.33275117478624117`, 0.9349832613244216], 
             UndirectedEdge[77, 183] -> 
             RGBColor[
              0.8768515535875127, 0.45980910711412243`, 0.21594468162867203`],
              UndirectedEdge[2, 78] -> 
             RGBColor[
              0.1826523965739446, 0.3093096280030011, 0.9337131558236558], 
             UndirectedEdge[113, 193] -> 
             RGBColor[
              0.21695734101669506`, 0.34536629967143495`, 0.9356667716600531],
              UndirectedEdge[100, 120] -> 
             RGBColor[
              0.199864476631129, 0.3274006154520085, 0.934693358319922], 
             UndirectedEdge[1, 35] -> 
             RGBColor[
              0.1803467482579951, 0.30688624543639154`, 0.9335818525629636], 
             UndirectedEdge[154, 176] -> 
             RGBColor[
              0.28297932105843965`, 0.41262153691639003`, 0.9395049102298585],
              UndirectedEdge[13, 31] -> 
             RGBColor[
              0.37653388192589077`, 0.49031817539689215`, 0.9461000785422968],
              UndirectedEdge[92, 196] -> 
             RGBColor[
              0.23871657724306206`, 0.3682366365606061, 0.9369059279732393], 
             UndirectedEdge[66, 124] -> 
             RGBColor[
              0.2047917303558609, 0.33257947152263156`, 0.9349739581303267], 
             UndirectedEdge[141, 167] -> 
             RGBColor[
              0.27157484914335084`, 0.3995303123785612, 0.9388958799735516], 
             UndirectedEdge[76, 158] -> 
             RGBColor[
              0.2902964087900912, 0.4217477888831733, 0.9398690458089125], 
             UndirectedEdge[101, 134] -> 
             RGBColor[
              0.22153377048940157`, 0.350176417209637, 0.9359273925483029], 
             UndirectedEdge[139, 141] -> 
             RGBColor[
              0.31474199889707277`, 0.4449017237250964, 0.9413541852919508], 
             UndirectedEdge[88, 93] -> 
             RGBColor[
              0.22397479227765688`, 0.3527420858788138, 0.936066405127976], 
             UndirectedEdge[17, 130] -> 
             RGBColor[
              0.18788228277941618`, 0.31480656999888906`, 0.9340109901061341],
              UndirectedEdge[32, 117] -> 
             RGBColor[
              0.1856648230786062, 0.31247587925827236`, 0.9338847090566107], 
             UndirectedEdge[32, 103] -> 
             RGBColor[
              0.1835438669532831, 0.31024661989417246`, 0.9337639237429469], 
             UndirectedEdge[148, 150] -> 
             RGBColor[
              0.19306951159997304`, 0.3202586763785973, 0.9343063951136474], 
             UndirectedEdge[77, 156] -> 
             RGBColor[
              0.8180183371528791, 0.13950241180852277`, 0.1648876860473853], 
             UndirectedEdge[76, 89] -> 
             RGBColor[
              0.2658816302529869, 0.396788829637877, 0.93845293755506], 
             UndirectedEdge[42, 51] -> 
             RGBColor[
              0.1924833774375055, 0.31964261221079154`, 0.9342730156402028], 
             UndirectedEdge[82, 124] -> 
             RGBColor[
              0.21900119805648247`, 0.34751452300827246`, 0.9357831662948535],
              UndirectedEdge[15, 114] -> 
             RGBColor[
              0.1801710817898224, 0.3067016088404447, 0.9335718486174763], 
             UndirectedEdge[41, 173] -> 
             RGBColor[
              0.32922976019022715`, 0.45791610894315266`, 0.9422602768775632],
              UndirectedEdge[41, 133] -> 
             RGBColor[
              0.2699147403652278, 0.4010278840797926, 0.9386826172095004], 
             UndirectedEdge[27, 147] -> 
             RGBColor[
              0.25802258569367165`, 0.38852847551383163`, 0.9380053765938214],
              UndirectedEdge[19, 88] -> 
             RGBColor[
              0.28388973519432037`, 0.4117897874343075, 0.939622248296642], 
             UndirectedEdge[127, 172] -> 
             RGBColor[
              0.8720640822479042, 0.7012922099091854, 0.6003031260629946], 
             UndirectedEdge[69, 174] -> 
             RGBColor[
              0.21992361240255348`, 0.34848403897044045`, 0.9358356964272725],
              UndirectedEdge[117, 121] -> 
             RGBColor[
              0.2013378942582586, 0.3289492707981949, 0.9347772672740609], 
             UndirectedEdge[69, 196] -> 
             RGBColor[
              0.24140009178199262`, 0.37105718048567105`, 0.9370587501563274],
              UndirectedEdge[92, 195] -> 
             RGBColor[
              0.372739436043382, 0.49002947459904367`, 0.9455472387434574], 
             UndirectedEdge[144, 158] -> 
             RGBColor[
              0.2574165112915451, 0.3871889319062931, 0.9379965842878197], 
             UndirectedEdge[81, 168] -> 
             RGBColor[
              0.2577136388756711, 0.38820375281975344`, 0.9379877825295823], 
             UndirectedEdge[87, 188] -> 
             RGBColor[
              0.264952676857396, 0.39540042103725787`, 0.9384151210923604], 
             UndirectedEdge[74, 88] -> 
             RGBColor[
              0.2812466810785635, 0.40950050680300143`, 0.9394538352255469], 
             UndirectedEdge[74, 140] -> 
             RGBColor[
              0.6698268935487197, 0.7315161778042003, 0.7507274751968138], 
             UndirectedEdge[152, 178] -> 
             RGBColor[
              0.19191650879429833`, 0.319046797325233, 0.9342407333095791], 
             UndirectedEdge[63, 153] -> 
             RGBColor[
              0.23696466171985112`, 0.36639526226785174`, 0.9368061589759192],
              UndirectedEdge[154, 158] -> 
             RGBColor[
              0.3241076056222659, 0.45514745069325846`, 0.9418728279265163], 
             UndirectedEdge[23, 90] -> 
             RGBColor[
              0.22545415356299398`, 0.354296988386626, 0.936150652564657], 
             UndirectedEdge[51, 131] -> 
             RGBColor[
              0.18184583567028742`, 0.3084618813543424, 0.9336672233733925], 
             UndirectedEdge[21, 83] -> 
             RGBColor[
              0.6438448345050425, 0.715751939504987, 0.9685418227069613], 
             UndirectedEdge[57, 178] -> 
             RGBColor[
              0.1827435050835432, 0.30940538882320234`, 0.9337183443184945], 
             UndirectedEdge[17, 197] -> 
             RGBColor[
              0.19608757130368493`, 0.3234308484832359, 0.9344782691489546], 
             UndirectedEdge[64, 156] -> 
             RGBColor[
              0.724124328038114, 0.42749923026133874`, 0.5647677517545815], 
             UndirectedEdge[40, 123] -> 
             RGBColor[
              0.4784773066745961, 0.5874288969649759, 0.9521030898325651], 
             UndirectedEdge[26, 99] -> 
             RGBColor[
              0.42230145847218425`, 0.5360474909140672, 0.9489226897427967], 
             UndirectedEdge[114, 167] -> 
             RGBColor[
              0.19037448411434205`, 0.3174260316165872, 0.9341529172852767], 
             UndirectedEdge[75, 168] -> 
             RGBColor[
              0.3557698478286644, 0.47206054196027025`, 0.9445929358550735], 
             UndirectedEdge[55, 111] -> 
             RGBColor[
              0.27800719710349053`, 0.40702500884009835`, 0.9392353213324036],
              UndirectedEdge[67, 122] -> 
             RGBColor[
              0.26690693057918574`, 0.3978664852885073, 0.9385113268918411], 
             UndirectedEdge[127, 129] -> 
             RGBColor[
              0.6646291767752983, 0.7354973814495299, 0.9690579811407907], 
             UndirectedEdge[96, 198] -> 
             RGBColor[
              0.6410199693439192, 0.7129417496474699, 0.9678791658783956], 
             UndirectedEdge[154, 181] -> 
             RGBColor[
              0.3850218870849109, 0.5079083396553941, 0.9457542320769319], 
             UndirectedEdge[9, 91] -> 
             RGBColor[
              0.1897739422401799, 0.3167948240302888, 0.9341187173139652], 
             UndirectedEdge[39, 152] -> 
             RGBColor[
              0.22612393827552923`, 0.3550009745863041, 0.9361887958131783], 
             UndirectedEdge[54, 65] -> 
             RGBColor[
              0.9723656669587191, 0.9184450471811106, 0.347146263750879], 
             UndirectedEdge[116, 128] -> 
             RGBColor[
              0.33596717970245343`, 0.45912161831384746`, 0.9428591101082765],
              UndirectedEdge[74, 95] -> 
             RGBColor[
              0.29756419393855826`, 0.4266512474089263, 0.9403830934433266], 
             UndirectedEdge[152, 200] -> 
             RGBColor[
              0.19539965938545223`, 0.3227078094410386, 0.9344390935828858], 
             UndirectedEdge[140, 191] -> 
             RGBColor[
              0.9019134129618684, 0.9202806576422312, 0.7699493982996792], 
             UndirectedEdge[109, 193] -> 
             RGBColor[
              0.223435169075761, 0.3521749076795341, 0.936035674384929], 
             UndirectedEdge[80, 137] -> 
             RGBColor[
              0.2728427891012749, 0.40270506254337235`, 0.9389006402596817], 
             UndirectedEdge[118, 199] -> 
             RGBColor[
              0.6930640728290565, 0.752639828019768, 0.8371662674251406], 
             UndirectedEdge[45, 64] -> 
             RGBColor[
              0.6702869821102313, 0.7421560430065834, 0.9679059544483493], 
             UndirectedEdge[125, 170] -> 
             RGBColor[
              0.4597455397011603, 0.5628406980828529, 0.952315284681579], 
             UndirectedEdge[70, 145] -> 
             RGBColor[
              0.19062187863577218`, 0.31768605894432894`, 0.9341670060372848],
              UndirectedEdge[17, 142] -> 
             RGBColor[
              0.22673355524288302`, 0.35564172067094113`, 0.9362235125976215],
              UndirectedEdge[95, 180] -> 
             RGBColor[
              0.2956153583547517, 0.42496326397755757`, 0.9402589153632142], 
             UndirectedEdge[41, 121] -> 
             RGBColor[
              0.25402964955357293`, 0.38433164646381435`, 0.9377779847876626],
              UndirectedEdge[5, 10] -> 
             RGBColor[
              0.28614225358776674`, 0.41386909982440245`, 0.9397610792987268],
              UndirectedEdge[167, 194] -> 
             RGBColor[
              0.2004278770420817, 0.327992785005569, 0.9347254431398494], 
             UndirectedEdge[78, 100] -> 
             RGBColor[
              0.1943610742796171, 0.3216161906447068, 0.9343799476975574], 
             UndirectedEdge[106, 157] -> 
             RGBColor[
              0.1957274974930852, 0.3230523880782974, 0.9344577634781225], 
             UndirectedEdge[24, 115] -> 
             RGBColor[
              0.28608625432626233`, 0.41744460911573256`, 0.9396248182053492],
              UndirectedEdge[74, 164] -> 
             RGBColor[
              0.2705518531420833, 0.3982595645505048, 0.9388447805961444], 
             UndirectedEdge[46, 135] -> 
             RGBColor[
              0.18995764910618526`, 0.3169879115941485, 0.9341291791482143], 
             UndirectedEdge[126, 190] -> 
             RGBColor[
              0.18192592123823295`, 0.3085460563639715, 0.933671784128011], 
             UndirectedEdge[21, 177] -> 
             RGBColor[
              0.28934680274084895`, 0.4165928965590511, 0.9399671678191333], 
             UndirectedEdge[24, 133] -> 
             RGBColor[
              0.2531352151655193, 0.3833915392115544, 0.93772704807246], 
             UndirectedEdge[30, 188] -> 
             RGBColor[
              0.2613842726407983, 0.39164980195571875`, 0.938211905751206], 
             UndirectedEdge[80, 98] -> 
             RGBColor[
              0.2071471807023911, 0.33505519918101245`, 0.9351080975429851], 
             UndirectedEdge[12, 102] -> 
             RGBColor[
              0.9596388825040008, 0.9082051910857141, 0.6078854818749925], 
             UndirectedEdge[51, 168] -> 
             RGBColor[
              0.1957969789545272, 0.32312541749965207`, 0.934461720344563], 
             UndirectedEdge[42, 189] -> 
             RGBColor[
              0.19860085363697447`, 0.32607246756682684`, 0.9346213968597675],
              UndirectedEdge[52, 187] -> 
             RGBColor[
              0.19453498240935546`, 0.32179897911547406`, 0.934389851508272], 
             UndirectedEdge[10, 89] -> 
             RGBColor[
              0.2427326184502555, 0.3724577505010858, 0.9371346355787884], 
             UndirectedEdge[148, 193] -> 
             RGBColor[
              0.21151914615710812`, 0.33965041207254015`, 0.9353570745078879],
              UndirectedEdge[4, 92] -> 
             RGBColor[
              0.28937728391046563`, 0.41912091134823404`, 0.9398775137264412],
              UndirectedEdge[28, 97] -> 
             RGBColor[
              0.19804503866908396`, 0.3254882707948695, 0.9345897440196007], 
             UndirectedEdge[60, 169] -> 
             RGBColor[
              0.18653686033276015`, 0.3133924457027435, 0.9339343702881713], 
             UndirectedEdge[44, 198] -> 
             RGBColor[
              0.6221986923143263, 0.5535105917539171, 0.5902453016000886], 
             UndirectedEdge[13, 64] -> 
             RGBColor[
              0.4253184848962721, 0.5299237138095665, 0.9499405811920143], 
             UndirectedEdge[42, 106] -> 
             RGBColor[
              0.19390013127031533`, 0.3211317103164559, 0.9343536976750818], 
             UndirectedEdge[43, 90] -> 
             RGBColor[
              0.20850897767362986`, 0.33648653414069934`, 0.935185649865899], 
             UndirectedEdge[166, 192] -> 
             RGBColor[
              0.6347217686990404, 0.711862763594694, 0.9660768808598341], 
             UndirectedEdge[5, 89] -> 
             RGBColor[
              0.31092444547544634`, 0.4399167547800723, 0.9411723884647626], 
             UndirectedEdge[114, 184] -> 
             RGBColor[
              0.18161202378548802`, 0.3082161302388885, 0.9336539081324469], 
             UndirectedEdge[58, 192] -> 
             RGBColor[
              0.7131454310850844, 0.7736227561744136, 0.951349727711992], 
             UndirectedEdge[17, 157] -> 
             RGBColor[
              0.19894707579879906`, 0.3264363690106574, 0.9346411136996936], 
             UndirectedEdge[38, 111] -> 
             RGBColor[
              0.200630301320241, 0.32820554575635497`, 0.9347369709030307], 
             UndirectedEdge[3, 191] -> 
             RGBColor[
              0.6143982789320568, 0.6943254432107253, 0.9648034682477634], 
             UndirectedEdge[40, 195] -> 
             RGBColor[
              0.5034310381865006, 0.6077470219664445, 0.9540510819361487], 
             UndirectedEdge[113, 136] -> 
             RGBColor[
              0.21363278825802834`, 0.3418719839332567, 0.9354774432986821], 
             UndirectedEdge[53, 141] -> 
             RGBColor[
              0.4877995456867602, 0.5920834332461721, 0.9536420283584146], 
             UndirectedEdge[142, 176] -> 
             RGBColor[
              0.24804284091250217`, 0.37803913099645736`, 0.9374370448922433],
              UndirectedEdge[99, 128] -> 
             RGBColor[
              0.49156366276898256`, 0.5975148916314856, 0.9532819740075988], 
             UndirectedEdge[41, 151] -> 
             RGBColor[
              0.6423047351050197, 0.7073139713016436, 0.8452851258395946], 
             UndirectedEdge[5, 157] -> 
             RGBColor[
              0.28037950263265143`, 0.40781208319106244`, 0.939432899157059], 
             UndirectedEdge[39, 74] -> 
             RGBColor[
              0.29899639389246113`, 0.42815658036720006`, 0.9404646551119514],
              UndirectedEdge[86, 171] -> 
             RGBColor[
              0.25492345163412733`, 0.3852710891208021, 0.9378288854938884], 
             UndirectedEdge[162, 180] -> 
             RGBColor[
              0.3967224327522758, 0.5180427642259409, 0.9464997805004701], 
             UndirectedEdge[27, 127] -> 
             RGBColor[
              0.5706539535210267, 0.6502280340235855, 0.9632042593205097], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.2536345517124762, 0.3839163735821717, 0.937755484550107], 
             UndirectedEdge[155, 191] -> 
             RGBColor[
              0.7416468272326004, 0.7980994052495431, 0.9748840827210469], 
             UndirectedEdge[46, 105] -> 
             RGBColor[
              0.19436779950481975`, 0.32162325928279867`, 0.9343803306891837],
              UndirectedEdge[30, 168] -> 
             RGBColor[
              0.2094817970078781, 0.3375090289413025, 0.9352410504878272], 
             UndirectedEdge[161, 180] -> 
             RGBColor[
              0.31293043325479175`, 0.4431625055366565, 0.9412449832634135], 
             UndirectedEdge[125, 192] -> 
             RGBColor[
              0.364998647890857, 0.48611773282970705`, 0.9447218886679021], 
             UndirectedEdge[33, 140] -> 
             RGBColor[
              0.9931733912441731, 0.9901003146609737, 0.6650510516491244], 
             UndirectedEdge[12, 58] -> 
             RGBColor[
              0.9553393970542898, 0.9049986418770809, 0.615163389255954], 
             UndirectedEdge[127, 155] -> 
             RGBColor[
              0.7739887444052208, 0.8238081123970447, 0.9779900759639816], 
             UndirectedEdge[78, 120] -> 
             RGBColor[
              0.188434679061321, 0.31538717351511814`, 0.9340424482571915], 
             UndirectedEdge[45, 183] -> 
             RGBColor[
              0.823713544812509, 0.7798413316678898, 0.6197525703698252], 
             UndirectedEdge[98, 136] -> 
             RGBColor[
              0.20765668863834705`, 0.33559072432637116`, 0.9351371132661883],
              UndirectedEdge[59, 92] -> 
             RGBColor[
              0.21433501599530952`, 0.3426100698089493, 0.9355174341294674], 
             UndirectedEdge[81, 89] -> 
             RGBColor[
              0.2867723464242142, 0.41874629688174436`, 0.9396426329359664], 
             UndirectedEdge[161, 200] -> 
             RGBColor[
              0.23722083665512567`, 0.36666451836725433`, 0.9368207477595063],
              UndirectedEdge[125, 198] -> 
             RGBColor[
              0.30495329570901086`, 0.43444605223273947`, 0.9408028523475496],
              UndirectedEdge[159, 173] -> 
             RGBColor[
              0.3113226737864071, 0.4390946257578836, 0.941240494798026], 
             UndirectedEdge[54, 151] -> 
             RGBColor[
              0.9911479730677677, 0.9821275166719952, 0.580056048665182], 
             UndirectedEdge[61, 192] -> 
             RGBColor[
              0.33652735532483224`, 0.4561925991586039, 0.9431004906757697], 
             UndirectedEdge[59, 194] -> 
             RGBColor[
              0.19287248204991897`, 0.32005158582909543`, 0.934295174572251], 
             UndirectedEdge[80, 82] -> 
             RGBColor[
              0.2168791547337895, 0.3452841209308045, 0.9356623190669078], 
             UndirectedEdge[157, 168] -> 
             RGBColor[
              0.2079111599465971, 0.33585818980575477`, 0.9351516050307367], 
             UndirectedEdge[122, 170] -> 
             RGBColor[
              0.4665658605119989, 0.5700092876883599, 0.9527036918619959], 
             UndirectedEdge[26, 67] -> 
             RGBColor[
              0.2743361643394848, 0.4056750810112081, 0.9389344107639237], 
             UndirectedEdge[160, 181] -> 
             RGBColor[
              0.4406818300512263, 0.5561181847027405, 0.9493008344245906], 
             UndirectedEdge[42, 168] -> 
             RGBColor[
              0.20608379372382724`, 0.3339375120439133, 0.935047539227696], 
             UndirectedEdge[61, 67] -> 
             RGBColor[
              0.2316153172023224, 0.36077276201189723`, 0.936501521719292], 
             UndirectedEdge[9, 39] -> 
             RGBColor[
              0.22268787528916928`, 0.3513894545286635, 0.9359931171093048], 
             UndirectedEdge[118, 171] -> 
             RGBColor[
              0.3493088123107567, 0.4768833997475762, 0.9434819976486537], 
             UndirectedEdge[97, 134] -> 
             RGBColor[
              0.23183626588337625`, 0.3610049930846403, 0.9365141044198138], 
             UndirectedEdge[79, 190] -> 
             RGBColor[
              0.18918203979750087`, 0.31617269703425077`, 0.9340850093454959],
              UndirectedEdge[47, 50] -> 
             RGBColor[
              0.2000038325739316, 0.3275470873835711, 0.9347012944347058], 
             UndirectedEdge[36, 145] -> 
             RGBColor[
              0.1863723647153286, 0.3132195503791984, 0.9339250025061079], 
             UndirectedEdge[170, 179] -> 
             RGBColor[
              0.5118741210410194, 0.6121027531180253, 0.9554863516778458], 
             UndirectedEdge[26, 198] -> 
             RGBColor[
              0.3192028502801486, 0.44942323756094715`, 0.9416143434000489], 
             UndirectedEdge[5, 141] -> 
             RGBColor[
              0.34907498712530993`, 0.4767729416541131, 0.9434637273981017], 
             UndirectedEdge[18, 39] -> 
             RGBColor[
              0.2375649812537819, 0.3670262361604698, 0.9368403462852835], 
             UndirectedEdge[19, 180] -> 
             RGBColor[
              0.3466247657178071, 0.47465068302264285`, 0.9433076014566613], 
             UndirectedEdge[170, 198] -> 
             RGBColor[
              0.5004157249918784, 0.6021780663759904, 0.9547562328138562], 
             UndirectedEdge[12, 172] -> 
             RGBColor[
              0.9097214307201227, 0.6697336065748736, 0.2456981245885829], 
             UndirectedEdge[47, 101] -> 
             RGBColor[
              0.19622767860092072`, 0.3235781101359464, 0.934486248052262], 
             UndirectedEdge[53, 54] -> 
             RGBColor[
              0.810087981057518, 0.842228648704628, 0.6867819724356502], 
             UndirectedEdge[57, 121] -> 
             RGBColor[
              0.1995963195919732, 0.32711876540171747`, 0.9346780871732447], 
             UndirectedEdge[19, 121] -> 
             RGBColor[
              0.28428483303541713`, 0.41220506031595017`, 0.9396447485341975],
              UndirectedEdge[170, 192] -> 
             RGBColor[
              0.5604610771737245, 0.6538497469729578, 0.9586752691342088], 
             UndirectedEdge[7, 137] -> 
             RGBColor[
              0.266193356547354, 0.39571608733082725`, 0.9385219649126898], 
             UndirectedEdge[111, 115] -> 
             RGBColor[
              0.26758071568904057`, 0.3979941146890951, 0.9385709551564505], 
             UndirectedEdge[140, 162] -> 
             RGBColor[
              0.7225676146989453, 0.7771975396388044, 0.7540880673117176], 
             UndirectedEdge[8, 79] -> 
             RGBColor[
              0.2387210212797669, 0.3682413075249512, 0.9369061810545554], 
             UndirectedEdge[2, 52] -> 
             RGBColor[
              0.1839811911872139, 0.31070627539199164`, 0.933788828711106], 
             UndirectedEdge[18, 152] -> 
             RGBColor[
              0.21162667893024556`, 0.3397634358350792, 0.9353631983402376], 
             UndirectedEdge[4, 195] -> 
             RGBColor[
              0.41766970262794245`, 0.5348906935287172, 0.9481924844113676], 
             UndirectedEdge[81, 107] -> 
             RGBColor[
              0.26183143575325407`, 0.39253181842149465`, 0.938222284970026], 
             UndirectedEdge[108, 175] -> 
             RGBColor[
              0.4042989919639763, 0.5232556584871441, 0.9473394941647204], 
             UndirectedEdge[49, 191] -> 
             RGBColor[
              0.6162290328937537, 0.6959111502759776, 0.9649201222713306], 
             UndirectedEdge[77, 192] -> 
             RGBColor[
              0.6415165926817106, 0.355626890859906, 0.5576499365602658], 
             UndirectedEdge[21, 166] -> 
             RGBColor[
              0.5825165188394155, 0.666981785574234, 0.9626574089267232], 
             UndirectedEdge[8, 192] -> 
             RGBColor[
              0.37448920004002384`, 0.4960929048742423, 0.9452623615727833], 
             UndirectedEdge[108, 165] -> 
             RGBColor[
              0.25691494582414054`, 0.38736427578253046`, 0.937942298141858], 
             UndirectedEdge[29, 194] -> 
             RGBColor[
              0.2042163465061234, 0.3319747066151143, 0.9349411908712882], 
             UndirectedEdge[106, 131] -> 
             RGBColor[
              0.18326258950309726`, 0.3099509794600067, 0.9337479054082716], 
             UndirectedEdge[12, 68] -> 
             RGBColor[
              0.9555467146303788, 0.8599776150331977, 0.2908341193259223], 
             UndirectedEdge[71, 168] -> 
             RGBColor[
              0.2865680055762049, 0.4134470786130624, 0.93981716239494], 
             UndirectedEdge[49, 146] -> 
             RGBColor[
              0.3338791466944457, 0.45775465051721964`, 0.9427098940314549], 
             UndirectedEdge[112, 134] -> 
             RGBColor[
              0.5941420485372255, 0.6663173396662936, 0.9607153178159171], 
             UndirectedEdge[84, 126] -> 
             RGBColor[
              0.1804502852518648, 0.30699506938157317`, 0.9335877488415951], 
             UndirectedEdge[10, 62] -> 
             RGBColor[
              0.2089259147709481, 0.3369247614653196, 0.9352093938167881], 
             UndirectedEdge[34, 182] -> 
             RGBColor[
              0.3854450302409573, 0.5082748449893679, 0.9457811943846643], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.20133152966492007`, 0.3289425812070576, 0.9347769048198857], 
             UndirectedEdge[67, 79] -> 
             RGBColor[
              0.22503396848065443`, 0.3538553472238142, 0.9361267236458259], 
             UndirectedEdge[33, 96] -> 
             RGBColor[
              0.9645200001324366, 0.9716588691526575, 0.8822125253236324], 
             UndirectedEdge[12, 140] -> 
             RGBColor[
              0.9719126786067074, 0.9144307614554209, 0.4184503900682022], 
             UndirectedEdge[26, 124] -> 
             RGBColor[
              0.25940975173137165`, 0.3899864749708609, 0.9380843736475403], 
             UndirectedEdge[13, 70] -> 
             RGBColor[
              0.20607827017508945`, 0.33393170644397663`, 0.9350472246697668],
              UndirectedEdge[53, 146] -> 
             RGBColor[
              0.438593505674698, 0.543607216634379, 0.9507210951484925], 
             UndirectedEdge[87, 147] -> 
             RGBColor[
              0.23311384595539386`, 0.3623478107435859, 0.9365868607149048], 
             UndirectedEdge[93, 200] -> 
             RGBColor[
              0.21100022620147757`, 0.339104994297747, 0.935327522784088], 
             UndirectedEdge[9, 117] -> 
             RGBColor[
              0.1893181439211632, 0.3163157510977197, 0.9340927602739904], 
             UndirectedEdge[99, 116] -> 
             RGBColor[
              0.39622421431727134`, 0.5086386539144789, 0.9474376292660001], 
             UndirectedEdge[71, 155] -> 
             RGBColor[
              0.5184643421823038, 0.6170471524468351, 0.9562295168142538], 
             UndirectedEdge[54, 140] -> 
             RGBColor[
              0.9910580021453803, 0.9807455899537222, 0.48380004734696136`], 
             UndirectedEdge[76, 154] -> 
             RGBColor[
              0.29805964700021337`, 0.42847191562908343`, 0.9403637124828994],
              UndirectedEdge[33, 128] -> 
             RGBColor[
              0.7119650853654641, 0.7696077577835532, 0.8603069871100877], 
             UndirectedEdge[109, 148] -> 
             RGBColor[
              0.20549299658683456`, 0.33331654679423195`, 0.9350138942047502],
              UndirectedEdge[27, 142] -> 
             RGBColor[
              0.2642591851125857, 0.3950835369263521, 0.9383605417045067], 
             UndirectedEdge[49, 69] -> 
             RGBColor[
              0.33608426308955985`, 0.46007236766093923`, 0.9428354721479792],
              UndirectedEdge[60, 90] -> 
             RGBColor[
              0.2041256683004301, 0.33187939807160033`, 0.9349360268816205], 
             UndirectedEdge[40, 191] -> 
             RGBColor[
              0.6579669038121483, 0.7306365663260646, 0.9679735835576617], 
             UndirectedEdge[58, 166] -> 
             RGBColor[
              0.8821530144207035, 0.9083587380492957, 0.9663447354512944], 
             UndirectedEdge[38, 60] -> 
             RGBColor[
              0.18105257981885614`, 0.3076281191591622, 0.9336220486261704], 
             UndirectedEdge[54, 119] -> 
             RGBColor[
              0.9176093173132854, 0.6667189724180997, 0.30094116151906036`], 
             UndirectedEdge[3, 146] -> 
             RGBColor[
              0.33204839273274867`, 0.4561689434519673, 0.9425932400078877], 
             UndirectedEdge[115, 163] -> 
             RGBColor[
              0.2983939725453868, 0.4303808013184385, 0.9403257245502908], 
             UndirectedEdge[137, 170] -> 
             RGBColor[
              0.48955017496489417`, 0.59276687306104, 0.9540638895741654], 
             UndirectedEdge[58, 99] -> 
             RGBColor[
              0.7561986870952739, 0.8085753289305662, 0.9547390377343874], 
             UndirectedEdge[40, 64] -> 
             RGBColor[
              0.5676806016913061, 0.6599077120294969, 0.959109042929153], 
             UndirectedEdge[77, 96] -> 
             RGBColor[
              0.8768677288440547, 0.5431135393845314, 0.5783662656384824], 
             UndirectedEdge[141, 195] -> 
             RGBColor[
              0.42242387419926064`, 0.539008517992182, 0.9484954160199432], 
             UndirectedEdge[138, 182] -> 
             RGBColor[
              0.28135325644561493`, 0.4100838369991616, 0.9394426474672775], 
             UndirectedEdge[33, 102] -> 
             RGBColor[
              0.9808995951414665, 0.9838747442912669, 0.8544861434559147], 
             UndirectedEdge[137, 198] -> 
             RGBColor[
              0.3347579309727448, 0.4643722272109265, 0.9425514572401359], 
             UndirectedEdge[69, 171] -> 
             RGBColor[
              0.27878211770791206`, 0.41034805989114986`, 0.939187601231057], 
             UndirectedEdge[20, 46] -> 
             RGBColor[
              0.182651270158183, 0.3093084440686167, 0.9337130916759446], 
             UndirectedEdge[76, 157] -> 
             RGBColor[
              0.23533668741019195`, 0.36468415804886706`, 0.9367134482473564],
              UndirectedEdge[10, 168] -> 
             RGBColor[
              0.21367391090171242`, 0.3419152064390949, 0.9354797851724044], 
             UndirectedEdge[82, 100] -> 
             RGBColor[
              0.20887799203010743`, 0.3368743916262188, 0.9352066646875926], 
             UndirectedEdge[9, 57] -> 
             RGBColor[
              0.18757656925487778`, 0.3144852457012422, 0.9339935801731742], 
             UndirectedEdge[27, 71] -> 
             RGBColor[
              0.3151295512981096, 0.44346707407337604`, 0.941443700170782], 
             UndirectedEdge[122, 125] -> 
             RGBColor[
              0.2711034312291314, 0.40227727354510906`, 0.9387503113956892], 
             UndirectedEdge[5, 147] -> 
             RGBColor[
              0.30192938265782127`, 0.43046237343882565`, 0.9406601329443018],
              UndirectedEdge[5, 71] -> 
             RGBColor[
              0.35903634826225916`, 0.48540097199837007`, 0.9440984565212622],
              UndirectedEdge[61, 84] -> 
             RGBColor[
              0.19428775253280067`, 0.3215391248399355, 0.9343757721325461], 
             UndirectedEdge[62, 149] -> 
             RGBColor[
              0.19270262269030192`, 0.3198730528724325, 0.9342855013330051], 
             UndirectedEdge[36, 138] -> 
             RGBColor[
              0.20221257093783607`, 0.32986861144613544`, 0.9348270788169946],
              UndirectedEdge[33, 162] -> 
             RGBColor[
              0.7220177660315357, 0.778314884514083, 0.8609475350328932], 
             UndirectedEdge[63, 145] -> 
             RGBColor[
              0.1909329030445121, 0.31801296531800116`, 0.9341847184172432], 
             UndirectedEdge[93, 173] -> 
             RGBColor[
              0.29957000075540785`, 0.42674182123979476`, 0.9405711974554323],
              UndirectedEdge[23, 55] -> 
             RGBColor[
              0.27975796086466953`, 0.40886517255793126`, 0.9393350247385799],
              UndirectedEdge[23, 165] -> 
             RGBColor[
              0.21472043526896856`, 0.3430151699025583, 0.9355393831869255], 
             UndirectedEdge[54, 64] -> 
             RGBColor[
              0.8089618730748239, 0.8413144235136905, 0.6866933210901831], 
             UndirectedEdge[72, 158] -> 
             RGBColor[
              0.284772839183219, 0.41594216701181014`, 0.93955448669119], 
             UndirectedEdge[73, 149] -> 
             RGBColor[
              0.2014915378121197, 0.32911075991486693`, 0.934786017047158], 
             UndirectedEdge[10, 197] -> 
             RGBColor[
              0.20932817111234645`, 0.33734755838465436`, 0.9352323017203459],
              UndirectedEdge[37, 135] -> 
             RGBColor[
              0.21639131765151565`, 0.3447713732266772, 0.9356345374667627], 
             UndirectedEdge[58, 96] -> 
             RGBColor[
              0.9484965672474285, 0.961109404699039, 0.9720660567902085], 
             UndirectedEdge[112, 156] -> 
             RGBColor[
              0.880064299434007, 0.550351383801579, 0.5748087868596949], 
             UndirectedEdge[2, 187] -> 
             RGBColor[
              0.1929273076602217, 0.3201092110216681, 0.9342982968096505], 
             UndirectedEdge[43, 169] -> 
             RGBColor[
              0.19092016970595993`, 0.3179995817718425, 0.9341839932724498], 
             UndirectedEdge[44, 96] -> 
             RGBColor[
              0.9175951806585165, 0.7926689208755102, 0.6148806669986575], 
             UndirectedEdge[88, 161] -> 
             RGBColor[
              0.25019540273130497`, 0.38030160994832113`, 0.9375596301033943],
              UndirectedEdge[129, 146] -> 
             RGBColor[
              0.3499373734033699, 0.4716321745432704, 0.9437417596579802], 
             UndirectedEdge[23, 111] -> 
             RGBColor[
              0.2218869245410005, 0.3505476045091276, 0.935947504149097], 
             UndirectedEdge[174, 196] -> 
             RGBColor[
              0.21150965778077974`, 0.33964043918742115`, 0.9353565341588927],
              UndirectedEdge[66, 100] -> 
             RGBColor[
              0.1946685243294859, 0.3219393401405779, 0.9343974565230659], 
             UndirectedEdge[10, 73] -> 
             RGBColor[
              0.2177148298927659, 0.346162468507754, 0.9357099095309409], 
             UndirectedEdge[147, 188] -> 
             RGBColor[
              0.2813635156046871, 0.41264925306793426`, 0.9393496940813583], 
             UndirectedEdge[62, 189] -> 
             RGBColor[
              0.19716645902323188`, 0.3245648278819121, 0.9345397102085116], 
             UndirectedEdge[42, 89] -> 
             RGBColor[
              0.2351425012723703, 0.3644800561059042, 0.93670238963408], 
             UndirectedEdge[119, 140] -> 
             RGBColor[
              0.9202745550794877, 0.6749563522500728, 0.37533269810004777`], 
             UndirectedEdge[140, 151] -> 
             RGBColor[
              0.9938132108339699, 0.9903648965039682, 0.6544475852461695], 
             UndirectedEdge[1, 86] -> 
             RGBColor[
              0.19100632204633058`, 0.3180901333439459, 0.934188899520783], 
             UndirectedEdge[76, 181] -> 
             RGBColor[
              0.3512106902527362, 0.4745086778453089, 0.9437504499593281], 
             UndirectedEdge[122, 166] -> 
             RGBColor[
              0.5408265520373148, 0.6280223043100961, 0.9601053035876213], 
             UndirectedEdge[10, 189] -> 
             RGBColor[
              0.20619097081485965`, 0.33405016196200843`, 0.935053642804476], 
             UndirectedEdge[102, 162] -> 
             RGBColor[
              0.7102938185962386, 0.7709719692690975, 0.9435231591185078], 
             UndirectedEdge[156, 183] -> 
             RGBColor[
              0.8775508907403917, 0.4651845189226452, 0.21661436767605732`], 
             UndirectedEdge[31, 199] -> 
             RGBColor[
              0.763611242939182, 0.811608878069138, 0.8422514778526693], 
             UndirectedEdge[73, 130] -> 
             RGBColor[
              0.20088728591826768`, 0.3284756528626456, 0.9347516057957137], 
             UndirectedEdge[4, 199] -> 
             RGBColor[
              0.6647841302718416, 0.7281451631679503, 0.8353642944923663], 
             UndirectedEdge[6, 83] -> 
             RGBColor[
              0.8789095063816696, 0.593376334043407, 0.5852871633250518], 
             UndirectedEdge[73, 89] -> 
             RGBColor[
              0.2424970217804455, 0.37221012346342386`, 0.9371212186969768], 
             UndirectedEdge[60, 111] -> 
             RGBColor[
              0.20055843927843664`, 0.3281300141941019, 0.9347328784660603], 
             UndirectedEdge[166, 179] -> 
             RGBColor[
              0.5861348125663353, 0.6701157697397615, 0.962887963403471], 
             UndirectedEdge[30, 197] -> 
             RGBColor[
              0.20513605721851214`, 0.33294138088686204`, 0.9349935670357687],
              UndirectedEdge[26, 58] -> 
             RGBColor[
              0.6266794481836577, 0.6975908926125163, 0.9458012343118618], 
             UndirectedEdge[11, 35] -> 
             RGBColor[
              0.19186691491128627`, 0.3189946710097535, 0.9342379090113091], 
             UndirectedEdge[137, 187] -> 
             RGBColor[
              0.2636867399140619, 0.3930814743205634, 0.9383792168036308], 
             UndirectedEdge[13, 153] -> 
             RGBColor[
              0.2516813551580962, 0.3818634401637041, 0.9376442528958304], 
             UndirectedEdge[71, 75] -> 
             RGBColor[
              0.4329404581640204, 0.5480873032405589, 0.9491738543179573], 
             UndirectedEdge[16, 67] -> 
             RGBColor[
              0.22153288342254734`, 0.3501754848461299, 0.935927342031158], 
             UndirectedEdge[156, 170] -> 
             RGBColor[
              0.7369628216448929, 0.4377252679215747, 0.5659130186213281], 
             UndirectedEdge[96, 128] -> 
             RGBColor[
              0.683861542921137, 0.7500489673999585, 0.97060899306342], 
             UndirectedEdge[62, 114] -> 
             RGBColor[
              0.19065828327948256`, 0.31772432253305627`, 0.9341690792278882],
              UndirectedEdge[101, 105] -> 
             RGBColor[
              0.20097546444375586`, 0.32856833408377506`, 0.9347566274322918],
              UndirectedEdge[30, 89] -> 
             RGBColor[
              0.2385405045564212, 0.3680515730032935, 0.9368959008942113], 
             UndirectedEdge[53, 191] -> 
             RGBColor[
              0.720943391874006, 0.781763716393137, 0.9729313233883682], 
             UndirectedEdge[72, 81] -> 
             RGBColor[
              0.2796155967323937, 0.4112240991915025, 0.9392350666284796], 
             UndirectedEdge[163, 175] -> 
             RGBColor[
              0.39116697450397153`, 0.5094530755186824, 0.9465916451974521], 
             UndirectedEdge[82, 125] -> 
             RGBColor[
              0.23812411131454123`, 0.3676139173052213, 0.9368721879150849], 
             UndirectedEdge[113, 148] -> 
             RGBColor[
              0.19901516852776863`, 0.3265079387861328, 0.9346449914798742], 
             UndirectedEdge[33, 44] -> 
             RGBColor[
              0.9456987231028435, 0.812227711259105, 0.5045786610453252], 
             UndirectedEdge[21, 179] -> 
             RGBColor[
              0.3649219793710912, 0.49049880984441946`, 0.9444734837310578], 
             UndirectedEdge[75, 188] -> 
             RGBColor[
              0.40767232346158455`, 0.5262013149746865, 0.9475637911184522], 
             UndirectedEdge[85, 88] -> 
             RGBColor[
              0.24351738394062986`, 0.3732825887884752, 0.9371793268125088], 
             UndirectedEdge[13, 185] -> 
             RGBColor[
              0.22657810602203676`, 0.3554783336837818, 0.936214659994461], 
             UndirectedEdge[93, 161] -> 
             RGBColor[
              0.2576073800376916, 0.38809206804383756`, 0.9379817312459552], 
             UndirectedEdge[146, 196] -> 
             RGBColor[
              0.23919497538687848`, 0.3687394633419514, 0.9369331720398031], 
             UndirectedEdge[19, 162] -> 
             RGBColor[
              0.4013143224518391, 0.5220200282886156, 0.9467923716516777], 
             UndirectedEdge[140, 172] -> 
             RGBColor[
              0.931531992024998, 0.7442858149051479, 0.38543931844832946`], 
             UndirectedEdge[71, 142] -> 
             RGBColor[
              0.312868249726037, 0.44109030274632716`, 0.9413149223915483], 
             UndirectedEdge[87, 142] -> 
             RGBColor[
              0.23935044537430794`, 0.3689028721561064, 0.9369420258255899], 
             UndirectedEdge[89, 147] -> 
             RGBColor[
              0.25851974752031004`, 0.38905102411550896`, 0.9380336892243635],
              UndirectedEdge[30, 42] -> 
             RGBColor[
              0.2061681954908564, 0.33402622365244206`, 0.935052345783467], 
             UndirectedEdge[8, 125] -> 
             RGBColor[
              0.2737736625674596, 0.4050838559841373, 0.9389023771201537], 
             UndirectedEdge[29, 168] -> 
             RGBColor[
              0.2081540694089858, 0.33611350305207477`, 0.9351654383652672], 
             UndirectedEdge[158, 160] -> 
             RGBColor[
              0.3797675485885813, 0.503357295740605, 0.945419430274175], 
             UndirectedEdge[138, 153] -> 
             RGBColor[
              0.25206516984128635`, 0.38226685373099345`, 0.9376661105742352],
              UndirectedEdge[26, 122] -> 
             RGBColor[
              0.285352985800269, 0.4172544588733168, 0.9395618024481885], 
             UndirectedEdge[53, 195] -> 
             RGBColor[
              0.5664075262483584, 0.658874172033517, 0.9590088217668552], 
             UndirectedEdge[19, 93] -> 
             RGBColor[
              0.291301712500707, 0.4195802455298239, 0.9400443494392029], 
             UndirectedEdge[11, 196] -> 
             RGBColor[
              0.21797120015163274`, 0.34643192990463634`, 0.9357245094379176],
              UndirectedEdge[87, 168] -> 
             RGBColor[
              0.21305020122447582`, 0.34125964802284164`, 0.9354442658289815],
              UndirectedEdge[78, 124] -> 
             RGBColor[
              0.20448428030599214`, 0.3322563220267605, 0.9349564493048182], 
             UndirectedEdge[39, 117] -> 
             RGBColor[
              0.21869250923105948`, 0.34719007148075093`, 0.9357655869229098],
              UndirectedEdge[42, 130] -> 
             RGBColor[
              0.1935327654101925, 0.32074558550512594`, 0.9343327767328169], 
             UndirectedEdge[11, 94] -> 
             RGBColor[
              0.19668351642529655`, 0.32405722459115277`, 0.9345122073420087],
              UndirectedEdge[27, 168] -> 
             RGBColor[
              0.23795894096275363`, 0.36744031279308736`, 0.9368627817078983],
              UndirectedEdge[30, 51] -> 
             RGBColor[
              0.19588138072155636`, 0.3232141291081808, 0.934466526900334], 
             UndirectedEdge[6, 58] -> 
             RGBColor[
              0.8960048531020866, 0.6063661726923737, 0.5646755963969717], 
             UndirectedEdge[6, 156] -> 
             RGBColor[
              0.8250753518515919, 0.1937457191863889, 0.17164549129263085`], 
             UndirectedEdge[19, 173] -> 
             RGBColor[
              0.35948494367207134`, 0.4857895227952885, 0.9441270406240982], 
             UndirectedEdge[57, 200] -> 
             RGBColor[
              0.1862266556746971, 0.31306640093900795`, 0.9339167045918012], 
             UndirectedEdge[37, 50] -> 
             RGBColor[
              0.21979652604601302`, 0.3483504631519761, 0.935828459047275], 
             UndirectedEdge[49, 171] -> 
             RGBColor[
              0.36505233439370555`, 0.4905196472833987, 0.9444851609543292], 
             UndirectedEdge[5, 127] -> 
             RGBColor[
              0.6145607504851762, 0.6921619319485797, 0.9658590156709901], 
             UndirectedEdge[85, 152] -> 
             RGBColor[
              0.2353287944309912, 0.36467586202728325`, 0.9367129987538674], 
             UndirectedEdge[130, 131] -> 
             RGBColor[
              0.18289522364297445`, 0.3095648546486768, 0.9337269844660065], 
             UndirectedEdge[33, 58] -> 
             RGBColor[
              0.9766001096917556, 0.9806681950826337, 0.8617640508368762], 
             UndirectedEdge[82, 98] -> 
             RGBColor[
              0.20223313817939134`, 0.32989022892104847`, 0.9348282500909746],
              UndirectedEdge[74, 173] -> 
             RGBColor[
              0.35684188955631446`, 0.48350024216398235`, 0.9439586275530032],
              UndirectedEdge[118, 146] -> 
             RGBColor[
              0.3181356246114969, 0.44411840298139715`, 0.9417067307257794], 
             UndirectedEdge[23, 115] -> 
             RGBColor[
              0.26933147945021957`, 0.39983427840692803`, 0.9386706585626268],
              UndirectedEdge[49, 65] -> 
             RGBColor[
              0.6893465246568067, 0.7023129196468301, 0.6165085243035178], 
             UndirectedEdge[21, 23] -> 
             RGBColor[
              0.2924706869731754, 0.4198762969529263, 0.9401450684047916], 
             UndirectedEdge[40, 171] -> 
             RGBColor[
              0.40679020531210003`, 0.5252450633334856, 0.9475386222406603], 
             UndirectedEdge[104, 158] -> 
             RGBColor[
              0.3417223041341413, 0.47040441720375525`, 0.9429952209396267], 
             UndirectedEdge[53, 155] -> 
             RGBColor[
              0.6524866330944523, 0.728284776143913, 0.9661081934380052], 
             UndirectedEdge[164, 200] -> 
             RGBColor[
              0.19289342095861073`, 0.320073593949734, 0.9342963670121247], 
             UndirectedEdge[81, 142] -> 
             RGBColor[
              0.28401388302550323`, 0.4158469769530182, 0.9394855425261907], 
             UndirectedEdge[39, 85] -> 
             RGBColor[
              0.26126709675452753`, 0.3919386623526739, 0.9381901466989133], 
             UndirectedEdge[107, 142] -> 
             RGBColor[
              0.23981543626826407`, 0.36939160706777974`, 0.9369685063691083],
              UndirectedEdge[121, 161] -> 
             RGBColor[
              0.25059050057240173`, 0.38071688282996385`, 0.9375821303409498],
              UndirectedEdge[1, 196] -> 
             RGBColor[
              0.20645103349834157`, 0.33432350433127433`, 0.935068452989572], 
             UndirectedEdge[88, 121] -> 
             RGBColor[
              0.21695791281236698`, 0.34536690066494, 0.9356668042229707], 
             UndirectedEdge[85, 133] -> 
             RGBColor[
              0.25979757259338154`, 0.39039409928609614`, 0.9381064594719022],
              UndirectedEdge[118, 127] -> 
             RGBColor[
              0.6328274279834254, 0.7079836098876566, 0.9670229522085898], 
             UndirectedEdge[100, 187] -> 
             RGBColor[
              0.2046359853658942, 0.3324157736633738, 0.9349650886835521], 
             UndirectedEdge[26, 116] -> 
             RGBColor[
              0.2667049754056552, 0.39765421759642916`, 0.9384998258434745], 
             UndirectedEdge[131, 147] -> 
             RGBColor[
              0.21550989668752718`, 0.3438449439082084, 0.9355843418468089], 
             UndirectedEdge[134, 160] -> 
             RGBColor[
              0.3450319511386071, 0.4675505014401682, 0.9434155666515178], 
             UndirectedEdge[3, 5] -> 
             RGBColor[
              0.38651352623245844`, 0.5092003225130362, 0.945849278004409], 
             UndirectedEdge[16, 100] -> 
             RGBColor[
              0.19648326478805916`, 0.32384674742372915`, 0.9345008033075137],
              UndirectedEdge[75, 147] -> 
             RGBColor[
              0.3758334925595824, 0.4931487046810145, 0.9457355307409967], 
             UndirectedEdge[72, 76] -> 
             RGBColor[
              0.25872488056116644`, 0.3892666319476351, 0.9380453712475731], 
             UndirectedEdge[40, 69] -> 
             RGBColor[
              0.37782213400795434`, 0.4947977837110262, 0.9458889334343104], 
             UndirectedEdge[177, 179] -> 
             RGBColor[
              0.2929650964677688, 0.41972688072457853`, 0.940197722295881], 
             UndirectedEdge[98, 100] -> 
             RGBColor[
              0.19914601799870904`, 0.3266454698764268, 0.9346524431636698], 
             UndirectedEdge[136, 187] -> 
             RGBColor[
              0.2131466560055322, 0.3413610281133182, 0.9354497587860706], 
             UndirectedEdge[54, 199] -> 
             RGBColor[
              0.9918267372139176, 0.9824082030898711, 0.5688071701781774], 
             UndirectedEdge[166, 198] -> 
             RGBColor[
              0.5746764165171943, 0.6601910829977264, 0.9621578445394816], 
             UndirectedEdge[48, 104] -> 
             RGBColor[
              0.28879698411440874`, 0.4154790711874804, 0.939955479525905], 
             UndirectedEdge[187, 198] -> 
             RGBColor[
              0.2745522899410462, 0.4024926676355137, 0.9390715600433216], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.20340607327822147`, 0.3311230580782995, 0.9348950470096511], 
             UndirectedEdge[103, 117] -> 
             RGBColor[
              0.1832018217377303, 0.30988710868570724`, 0.9337444447739318], 
             UndirectedEdge[85, 140] -> 
             RGBColor[
              0.632097596410786, 0.6952982597896742, 0.7484529667837756], 
             UndirectedEdge[36, 70] -> 
             RGBColor[
              0.18680103840766088`, 0.3136701136093215, 0.9339494148387204], 
             UndirectedEdge[54, 171] -> 
             RGBColor[
              0.6480714766956179, 0.7066517748176793, 0.6751229004016905], 
             UndirectedEdge[120, 125] -> 
             RGBColor[
              0.22911059591556282`, 0.35814014113101095`, 0.9363588815474142],
              UndirectedEdge[81, 104] -> 
             RGBColor[
              0.336565061683316, 0.46568634938344766`, 0.9426758008769163], 
             UndirectedEdge[93, 162] -> 
             RGBColor[
              0.34139937953517563`, 0.46297232673312194`, 0.9432365284830118],
              UndirectedEdge[73, 168] -> 
             RGBColor[
              0.2134383142319024, 0.3416675794014329, 0.9354663682905927], 
             UndirectedEdge[119, 199] -> 
             RGBColor[
              0.921043290148025, 0.6766189653862216, 0.46033982093126385`], 
             UndirectedEdge[17, 107] -> 
             RGBColor[
              0.20455110797063392`, 0.33232656213941764`, 0.9349602550414569],
              UndirectedEdge[14, 48] -> 
             RGBColor[
              0.19487547737670605`, 0.3221568609147874, 0.9344092421929455], 
             UndirectedEdge[64, 182] -> 
             RGBColor[
              0.48518193863662246`, 0.5898773465279377, 0.9534583400112507], 
             UndirectedEdge[71, 129] -> 
             RGBColor[
              0.40910477455238126`, 0.5287364214993203, 0.947297421991063], 
             UndirectedEdge[80, 100] -> 
             RGBColor[
              0.2137920345531072, 0.3420393618861828, 0.935486512139603], 
             UndirectedEdge[18, 178] -> 
             RGBColor[
              0.20335755177255102`, 0.3310720588993987, 0.9348922837816843], 
             UndirectedEdge[174, 186] -> 
             RGBColor[
              0.18655058120662976`, 0.3134068672111341, 0.9339351516716399], 
             UndirectedEdge[115, 165] -> 
             RGBColor[
              0.2604142264170086, 0.39046168008252585`, 0.9381628341942789], 
             UndirectedEdge[113, 198] -> 
             RGBColor[
              0.2750384221935423, 0.4030036234554522, 0.939099244555933], 
             UndirectedEdge[67, 100] -> 
             RGBColor[
              0.2308404904839133, 0.3599583700039979, 0.936457396483932], 
             UndirectedEdge[106, 147] -> 
             RGBColor[
              0.21727737751825504`, 0.3457026783260606, 0.9356849972653654], 
             UndirectedEdge[75, 129] -> 
             RGBColor[
              0.47830661680484077`, 0.5873498848465282, 0.9520731954511965], 
             UndirectedEdge[175, 183] -> 
             RGBColor[
              0.7184776908452273, 0.695458275607814, 0.6107486570608233], 
             UndirectedEdge[105, 144] -> 
             RGBColor[
              0.20212260779592514`, 0.3297740544799944, 0.9348219555491514], 
             UndirectedEdge[44, 128] -> 
             RGBColor[
              0.6650402658915442, 0.5906178095064059, 0.5929751287851128], 
             UndirectedEdge[70, 138] -> 
             RGBColor[
              0.2064620848582796, 0.334335120011266, 0.9350690823481714], 
             UndirectedEdge[110, 145] -> 
             RGBColor[
              0.18515978669395372`, 0.31194505399684636`, 0.9338559479816391],
              UndirectedEdge[49, 118] -> 
             RGBColor[
              0.4066109576924045, 0.5266077075173656, 0.9471298685655758], 
             UndirectedEdge[70, 185] -> 
             RGBColor[
              0.21155038817505178`, 0.3396832494142572, 0.9353588536945914], 
             UndirectedEdge[11, 138] -> 
             RGBColor[
              0.2124149402657507, 0.3405919484773504, 0.9354080886571665], 
             UndirectedEdge[120, 187] -> 
             RGBColor[
              0.1987095901475981, 0.32618675653378515`, 0.9346275892431862], 
             UndirectedEdge[71, 127] -> 
             RGBColor[
              0.6192630181344778, 0.6962347998435606, 0.9661586400075515], 
             UndirectedEdge[4, 182] -> 
             RGBColor[
              0.33757022299890055`, 0.4668080932140755, 0.9427306540012304], 
             UndirectedEdge[29, 71] -> 
             RGBColor[
              0.2853246797443417, 0.4121402643323634, 0.939746356828151], 
             UndirectedEdge[63, 185] -> 
             RGBColor[
              0.2118614125837917, 0.3400101557879294, 0.9353765660745497], 
             UndirectedEdge[83, 175] -> 
             RGBColor[
              0.7134786289406714, 0.7747821951592325, 0.9733333335119576], 
             UndirectedEdge[79, 126] -> 
             RGBColor[
              0.1869217092836395, 0.3137969463509505, 0.9339562868665908], 
             UndirectedEdge[107, 154] -> 
             RGBColor[
              0.27475191641420155`, 0.4039740129877124, 0.9390363717067235], 
             UndirectedEdge[34, 64] -> 
             RGBColor[
              0.5297940733748047, 0.6285181353670621, 0.956300985787806], 
             UndirectedEdge[159, 180] -> 
             RGBColor[
              0.29846249583214285`, 0.427955785985238, 0.9404210556305891], 
             UndirectedEdge[3, 123] -> 
             RGBColor[
              0.4349086817945046, 0.5511177738496366, 0.9489329745226667], 
             UndirectedEdge[50, 97] -> 
             RGBColor[
              0.21027301783359342`, 0.33834065219542714`, 0.9352861093433454],
              UndirectedEdge[87, 89] -> 
             RGBColor[
              0.24210890877301894`, 0.37180219208483256`, 0.9370991162353657],
              UndirectedEdge[123, 191] -> 
             RGBColor[
              0.6306139888746021, 0.7083706761376785, 0.9658367189463131], 
             UndirectedEdge[108, 151] -> 
             RGBColor[
              0.6509649455844404, 0.716416401604573, 0.8457783120147642], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.19532837830452823`, 0.32263288850550587`, 0.9344350342307781],
              UndirectedEdge[19, 33] -> 
             RGBColor[
              0.6719200989970671, 0.734922803310785, 0.8577553559890845], 
             UndirectedEdge[156, 199] -> 
             RGBColor[
              0.9069891921772075, 0.5685930098375191, 0.4468816008425758], 
             UndirectedEdge[47, 144] -> 
             RGBColor[
              0.19737482195309003`, 0.32478383053216575`, 0.9345515761691217],
              UndirectedEdge[123, 127] -> 
             RGBColor[
              0.6629559060472224, 0.73407938328518, 0.9689427121892478], 
             UndirectedEdge[82, 120] -> 
             RGBColor[
              0.2029515968118113, 0.3306453744966301, 0.9348691652472267], 
             UndirectedEdge[120, 137] -> 
             RGBColor[
              0.2589152311792967, 0.38806631610919806`, 0.9381074864400005], 
             UndirectedEdge[122, 179] -> 
             RGBColor[
              0.32323201256899053`, 0.45153932858028145`, 0.9419213783919558],
              UndirectedEdge[52, 124] -> 
             RGBColor[
              0.20581307491926143`, 0.333652969415751, 0.9350321221922685], 
             UndirectedEdge[17, 106] -> 
             RGBColor[
              0.18824964863953902`, 0.315192694810219, 0.934031911048399], 
             UndirectedEdge[125, 166] -> 
             RGBColor[
              0.5340062312264762, 0.620853714704589, 0.9597168964072044], 
             UndirectedEdge[7, 79] -> 
             RGBColor[
              0.20133607999592745`, 0.328947363893454, 0.934777163954505], 
             UndirectedEdge[49, 127] -> 
             RGBColor[
              0.6485709500663741, 0.7216198574234791, 0.9680261155142653], 
             UndirectedEdge[121, 200] -> 
             RGBColor[
              0.20398334673618768`, 0.33172980908387323`, 0.9349279218790827],
              UndirectedEdge[56, 193] -> 
             RGBColor[
              0.2060154437903921, 0.33386567193023686`, 0.9350436468001014], 
             UndirectedEdge[149, 194] -> 
             RGBColor[
              0.1935128959182038, 0.3207247014092473, 0.9343316451946424], 
             UndirectedEdge[108, 133] -> 
             RGBColor[
              0.27857495084464845`, 0.41013031438272207`, 0.9391758033846701],
              UndirectedEdge[41, 140] -> 
             RGBColor[
              0.6422147641826323, 0.7059320445833706, 0.7490291245213738], 
             UndirectedEdge[36, 185] -> 
             RGBColor[
              0.2073008742546082, 0.33521674084912667`, 0.9351168501634146], 
             UndirectedEdge[108, 111] -> 
             RGBColor[
              0.26408143509617243`, 0.39489671038909974`, 0.9383504191040295],
              UndirectedEdge[72, 154] -> 
             RGBColor[
              0.2925360773933412, 0.42266629375772025`, 0.940049153365177], 
             UndirectedEdge[63, 110] -> 
             RGBColor[
              0.18589948479502594`, 0.3127225236006417, 0.9338980726942099], 
             UndirectedEdge[15, 186] -> 
             RGBColor[
              0.18099749200595946`, 0.30757021837503873`, 0.933618911456721], 
             UndirectedEdge[54, 155] -> 
             RGBColor[
              0.8307914164161123, 0.8585643375610341, 0.688734731768329], 
             UndirectedEdge[18, 108] -> 
             RGBColor[
              0.2655472156605108, 0.39643733869807485`, 0.9384338931387406], 
             UndirectedEdge[44, 102] -> 
             RGBColor[
              0.9339747756675465, 0.8048847960141194, 0.5871542851309398], 
             UndirectedEdge[8, 122] -> 
             RGBColor[
              0.2805939833782982, 0.4122524455896443, 0.9392907843005704], 
             UndirectedEdge[42, 197] -> 
             RGBColor[
              0.20173805393446126`, 0.32936986398947277`, 0.9348000557756375],
              UndirectedEdge[48, 147] -> 
             RGBColor[
              0.2300092060376818, 0.3590846373445305, 0.9364100560644943], 
             UndirectedEdge[34, 54] -> 
             RGBColor[
              0.7092249646791587, 0.7597119219751208, 0.6790161754635967], 
             UndirectedEdge[5, 75] -> 
             RGBColor[
              0.42823819051471873`, 0.5440144353455778, 0.9488742299813958], 
             UndirectedEdge[55, 115] -> 
             RGBColor[
              0.3254517520127096, 0.4563116827378988, 0.9419584757459334], 
             UndirectedEdge[49, 155] -> 
             RGBColor[
              0.5477722741141999, 0.6424322100267535, 0.9580969923209677], 
             UndirectedEdge[66, 136] -> 
             RGBColor[
              0.2031791949691239, 0.33088459459052233`, 0.9348821266255843], 
             UndirectedEdge[136, 148] -> 
             RGBColor[
              0.2081945933984414, 0.33615609633436194`, 0.9351677461465169], 
             UndirectedEdge[130, 189] -> 
             RGBColor[
              0.18936342684036145`, 0.3163633463169, 0.9340953390692487], 
             UndirectedEdge[48, 76] -> 
             RGBColor[
              0.23737108877035865`, 0.36682244286689847`, 0.9368293043951907],
              UndirectedEdge[29, 141] -> 
             RGBColor[
              0.2753633186073925, 0.40351223398810643`, 0.9391116277049905], 
             UndirectedEdge[133, 163] -> 
             RGBColor[
              0.26544293338464375`, 0.39632773141426036`, 0.9384279544174017],
              UndirectedEdge[111, 169] -> 
             RGBColor[
              0.20611458183414505`, 0.33396987229993624`, 0.9350492925650316],
              UndirectedEdge[76, 142] -> 
             RGBColor[
              0.26312316685427595`, 0.39388950970915076`, 0.9382958471452842],
              UndirectedEdge[78, 98] -> 
             RGBColor[
              0.18771622042890102`, 0.3146320279395365, 0.9340015331009395], 
             UndirectedEdge[21, 170] -> 
             RGBColor[
              0.5082558273140996, 0.6089687689524979, 0.9552557972010979], 
             UndirectedEdge[92, 139] -> 
             RGBColor[
              0.26505756074119424`, 0.3959226803319581, 0.938406008015465], 
             UndirectedEdge[63, 70] -> 
             RGBColor[
              0.1913615767368444, 0.3184635285481242, 0.9342091307498555], 
             UndirectedEdge[71, 197] -> 
             RGBColor[
              0.2822222657868389, 0.40887943055862197`, 0.9395696789428815], 
             UndirectedEdge[127, 141] -> 
             RGBColor[
              0.6093016569975287, 0.6876067694993037, 0.9655239108843909], 
             UndirectedEdge[64, 138] -> 
             RGBColor[
              0.4257022995794623, 0.5303271273768558, 0.949962438870419], 
             UndirectedEdge[39, 108] -> 
             RGBColor[
              0.2800444750057945, 0.41167487744929976`, 0.9392594906116811], 
             UndirectedEdge[24, 165] -> 
             RGBColor[
              0.23147521014501135`, 0.3606255006113628, 0.9364935428296479], 
             UndirectedEdge[132, 182] -> 
             RGBColor[
              0.3206991952751244, 0.45143891338558356`, 0.9416833404765177], 
             UndirectedEdge[77, 181] -> 
             RGBColor[
              0.627745965168717, 0.3440360509358098, 0.5566794847766803], 
             UndirectedEdge[20, 47] -> 
             RGBColor[
              0.189292245231432, 0.3162885299327404, 0.9340912853819239], 
             UndirectedEdge[191, 199] -> 
             RGBColor[
              0.9026821480304056, 0.9219432707783801, 0.8549565211308954], 
             UndirectedEdge[89, 154] -> 
             RGBColor[
              0.29969282708516165`, 0.4301884914479621, 0.9404567196726639], 
             UndirectedEdge[93, 164] -> 
             RGBColor[
              0.2132799643411767, 0.3415011436263172, 0.9354573504985735], 
             UndirectedEdge[26, 187] -> 
             RGBColor[
              0.24813165922146568`, 0.378132484670584, 0.9374421029635438], 
             UndirectedEdge[5, 188] -> 
             RGBColor[
              0.33376821355982345`, 0.4635149837324976, 0.9424883933217574], 
             UndirectedEdge[7, 16] -> 
             RGBColor[
              0.19783499493782034`, 0.3252675015157697, 0.9345777823398371], 
             UndirectedEdge[154, 160] -> 
             RGBColor[
              0.38753078679870345`, 0.510081422486515, 0.9459140969481619], 
             UndirectedEdge[88, 152] -> 
             RGBColor[
              0.20837422546163153`, 0.3363449010221054, 0.9351779759267738], 
             UndirectedEdge[9, 18] -> 
             RGBColor[
              0.2081906159438856, 0.3361519157774386, 0.935167519636364], 
             UndirectedEdge[9, 200] -> 
             RGBColor[
              0.19196359639909227`, 0.31909628938339796`, 0.9342434148790122],
              UndirectedEdge[55, 183] -> 
             RGBColor[
              0.6361311703010923, 0.6254168955585735, 0.6051471025896153], 
             UndirectedEdge[72, 104] -> 
             RGBColor[
              0.31015077590521656`, 0.43792326026821704`, 0.9411715463782875],
              UndirectedEdge[112, 181] -> 
             RGBColor[
              0.6897919274498447, 0.754885022928866, 0.9666005855889899], 
             UndirectedEdge[136, 193] -> 
             RGBColor[
              0.22613676588736786`, 0.35501445721966407`, 0.9361895263266957],
              UndirectedEdge[80, 198] -> 
             RGBColor[
              0.28370833912825916`, 0.4121162558583227, 0.9395929834993725], 
             UndirectedEdge[42, 131] -> 
             RGBColor[
              0.19213265043958744`, 0.3192739758986036, 0.9342530422565254], 
             UndirectedEdge[65, 156] -> 
             RGBColor[
              0.887528121922009, 0.5046298539287588, 0.2252206944152773], 
             UndirectedEdge[26, 192] -> 
             RGBColor[
              0.37924820246199464`, 0.5010949181579147, 0.9455333797204014], 
             UndirectedEdge[65, 155] -> 
             RGBColor[
              0.8147643189956533, 0.8045011746203956, 0.6264724847532339], 
             UndirectedEdge[59, 62] -> 
             RGBColor[
              0.19206220882201708`, 0.3191999372922807, 0.9342490307106137], 
             UndirectedEdge[82, 187] -> 
             RGBColor[
              0.2077231055465765, 0.3356605327079955, 0.9351408956108569], 
             UndirectedEdge[4, 86] -> 
             RGBColor[
              0.26820213237561147`, 0.3968644845029512, 0.9386716201723606], 
             UndirectedEdge[73, 167] -> 
             RGBColor[
              0.20840651893599757`, 0.33637884351118863`, 0.9351798149923649],
              UndirectedEdge[74, 159] -> 
             RGBColor[
              0.30041133141594933`, 0.42964376941660665`, 0.9405452337107016],
              UndirectedEdge[25, 60] -> 
             RGBColor[
              0.18025977124348086`, 0.3067948270794758, 0.9335768993506579], 
             UndirectedEdge[159, 162] -> 
             RGBColor[
              0.3531520525661749, 0.4753251312512108, 0.9439058258256054], 
             UndirectedEdge[10, 147] -> 
             RGBColor[
              0.23373755563263043`, 0.3630033691598391, 0.9366223800583277], 
             UndirectedEdge[23, 163] -> 
             RGBColor[
              0.2527001813973467, 0.382934291138471, 0.9377022735429374], 
             UndirectedEdge[40, 54] -> 
             RGBColor[
              0.7471114929956602, 0.7911014986375555, 0.6818242326049438], 
             UndirectedEdge[123, 129] -> 
             RGBColor[
              0.45279766246512576`, 0.5665810049409397, 0.9500814941727593], 
             UndirectedEdge[25, 165] -> 
             RGBColor[
              0.19267100347283378`, 0.3198398190700993, 0.9342837006653468], 
             UndirectedEdge[39, 178] -> 
             RGBColor[
              0.21785481111783467`, 0.34630959765062364`, 0.935717881254625], 
             UndirectedEdge[76, 107] -> 
             RGBColor[
              0.2409407195820268, 0.37057435117762727`, 0.9370325895891196], 
             UndirectedEdge[63, 138] -> 
             RGBColor[
              0.20677310926701956`, 0.33466202638493814`, 0.9350867947281298],
              UndirectedEdge[71, 81] -> 
             RGBColor[
              0.334884249211027, 0.4642305141000421, 0.942568700992466], 
             UndirectedEdge[8, 83] -> 
             RGBColor[
              0.60482509904127, 0.6795990406798771, 0.9661417830923238], 
             UndirectedEdge[10, 149] -> 
             RGBColor[
              0.2017271344819297, 0.32935838695252884`, 0.9347994339289696], 
             UndirectedEdge[119, 172] -> 
             RGBColor[
              0.858083307192903, 0.43025919736952545`, 0.20258043262042846`], 
             UndirectedEdge[106, 130] -> 
             RGBColor[
              0.1846627044737023, 0.31142258906652903`, 0.933827639884563], 
             UndirectedEdge[147, 176] -> 
             RGBColor[
              0.24180624149358806`, 0.37148406958393687`, 0.9370818797815581],
              UndirectedEdge[27, 197] -> 
             RGBColor[
              0.23361320117338766`, 0.3628726647386469, 0.9366152982558398], 
             UndirectedEdge[72, 176] -> 
             RGBColor[
              0.2436445546193927, 0.37341625323494165`, 0.9371865689945322], 
             UndirectedEdge[92, 118] -> 
             RGBColor[
              0.31765722646768046`, 0.4436155762000519, 0.9416794866592155], 
             UndirectedEdge[123, 171] -> 
             RGBColor[
              0.3794372903745538, 0.5029791731450995, 0.9454017576293117], 
             UndirectedEdge[66, 113] -> 
             RGBColor[
              0.1939997700984511, 0.32123643704229315`, 0.9343593719589416], 
             UndirectedEdge[67, 179] -> 
             RGBColor[
              0.3122151911082063, 0.43995995071817273`, 0.941293986707691], 
             UndirectedEdge[130, 197] -> 
             RGBColor[
              0.19250062713784824`, 0.3196607427395459, 0.9342739979851187], 
             UndirectedEdge[15, 194] -> 
             RGBColor[
              0.19022447471756204`, 0.31726836222942645`, 0.934144374472049], 
             UndirectedEdge[47, 135] -> 
             RGBColor[
              0.19659862417943424`, 0.3239679974582722, 0.9345073728541936], 
             UndirectedEdge[8, 170] -> 
             RGBColor[
              0.4692360918503271, 0.5728158701273882, 0.9528557575864605], 
             UndirectedEdge[17, 149] -> 
             RGBColor[
              0.1884865346732682, 0.31544167705111037`, 0.9340454013575784], 
             UndirectedEdge[13, 97] -> 
             RGBColor[
              0.21895267363831583`, 0.3474635207681535, 0.9357804029010244], 
             UndirectedEdge[11, 86] -> 
             RGBColor[
              0.20252648869962175`, 0.33019855891730787`, 0.9348449559691285],
              UndirectedEdge[15, 62] -> 
             RGBColor[
              0.18941420148966015`, 0.3164167136926116, 0.9340982306104119], 
             UndirectedEdge[37, 160] -> 
             RGBColor[
              0.33951855272220766`, 0.4617555701348826, 0.9431015867680459], 
             UndirectedEdge[46, 50] -> 
             RGBColor[
              0.1933628575006826, 0.3205670015194474, 0.9343231007287265], 
             UndirectedEdge[49, 53] -> 
             RGBColor[
              0.5270688387556056, 0.6260965211703475, 0.956144232988289], 
             UndirectedEdge[52, 120] -> 
             RGBColor[
              0.1897634736745903, 0.3167838209041087, 0.9341181211446418], 
             UndirectedEdge[81, 147] -> 
             RGBColor[
              0.2777772836065891, 0.4092919155404977, 0.9391303774155055], 
             UndirectedEdge[49, 123] -> 
             RGBColor[
              0.43673943575620155`, 0.552703480914889, 0.949049628546234], 
             UndirectedEdge[127, 140] -> 
             RGBColor[
              0.9342553301344888, 0.9459893647897327, 0.7730553915426139], 
             UndirectedEdge[31, 132] -> 
             RGBColor[
              0.4162636354385904, 0.5320766653506034, 0.9483626292299419], 
             UndirectedEdge[146, 186] -> 
             RGBColor[
              0.2142358988127285, 0.34250589136566434`, 0.9355117895525502], 
             UndirectedEdge[98, 124] -> 
             RGBColor[
              0.20926922402508408`, 0.3372856012584804, 0.9352289447709307], 
             UndirectedEdge[4, 53] -> 
             RGBColor[
              0.483045374115442, 0.5879656087827072, 0.953339096749839], 
             UndirectedEdge[82, 137] -> 
             RGBColor[
              0.26792874657827515`, 0.39754009228340836`, 0.9386207928076713],
              UndirectedEdge[42, 107] -> 
             RGBColor[
              0.21020159060141025`, 0.3382655776456545, 0.9352820416681398], 
             UndirectedEdge[99, 102] -> 
             RGBColor[
              0.7604981725449849, 0.8117818781391992, 0.9474611303534258], 
             UndirectedEdge[57, 88] -> 
             RGBColor[
              0.1992012217508764, 0.32670349252007475`, 0.9346555869356892], 
             UndirectedEdge[40, 49] -> 
             RGBColor[
              0.46409235069374777`, 0.5749693711032751, 0.9511864931575826], 
             UndirectedEdge[21, 90] -> 
             RGBColor[
              0.29428715223398993`, 0.42178551711259177`, 0.9402485134141754],
              UndirectedEdge[143, 158] -> 
             RGBColor[
              0.5860035167018279, 0.6680847618686957, 0.9637366121327604], 
             UndirectedEdge[24, 111] -> 
             RGBColor[
              0.2386416994170433, 0.36815793521793205`, 0.9369016637918195], 
             UndirectedEdge[139, 155] -> 
             RGBColor[
              0.47942908630476494`, 0.5811030666228374, 0.9538203503715414], 
             UndirectedEdge[94, 174] -> 
             RGBColor[
              0.19022197405444352`, 0.31726573387393764`, 0.9341442320629838],
              UndirectedEdge[4, 118] -> 
             RGBColor[
              0.3625874930522409, 0.48847679512972536`, 0.9443247323271259], 
             UndirectedEdge[121, 159] -> 
             RGBColor[
              0.23612256314975283`, 0.36551016327854535`, 0.9367582027081254],
              UndirectedEdge[5, 76] -> 
             RGBColor[
              0.3092912653904981, 0.4382001789611937, 0.9410793812749982], 
             UndirectedEdge[27, 194] -> 
             RGBColor[
              0.23402121805989123`, 0.3633015163561269, 0.9366385342139192], 
             UndirectedEdge[77, 160] -> 
             RGBColor[
              0.6302548648825095, 0.34620913376693074`, 0.5568393496479103], 
             UndirectedEdge[2, 80] -> 
             RGBColor[
              0.20208335684743473`, 0.32973279924447707`, 0.9348197202657014],
              UndirectedEdge[74, 85] -> 
             RGBColor[
              0.3082012500479231, 0.4378314678081793, 0.9409888580526407], 
             UndirectedEdge[35, 110] -> 
             RGBColor[
              0.18045196756199675`, 0.30699683759618646`, 0.9335878446466683],
              UndirectedEdge[143, 154] -> 
             RGBColor[
              0.5937667549119501, 0.6748088886146058, 0.9642312788067474], 
             UndirectedEdge[53, 129] -> 
             RGBColor[
              0.5431270654645298, 0.6399740451963982, 0.9571760986148143], 
             UndirectedEdge[80, 187] -> 
             RGBColor[
              0.21263714806957626`, 0.34082550296795955`, 0.9354207430628674],
              UndirectedEdge[30, 87] -> 
             RGBColor[
              0.213134602991505, 0.3413483596313704, 0.9354490723847526], 
             UndirectedEdge[29, 197] -> 
             RGBColor[
              0.2038083296196198, 0.3315458549976343, 0.9349179549132087], 
             UndirectedEdge[74, 121] -> 
             RGBColor[
              0.28164177891966025`, 0.4099157796846441, 0.9394763354631025], 
             UndirectedEdge[127, 199] -> 
             RGBColor[
              0.935024065203026, 0.9476519779258816, 0.8580625143738301], 
             UndirectedEdge[52, 80] -> 
             RGBColor[
              0.20369103159656846`, 0.33142256733828307`, 0.9349112749643229],
              UndirectedEdge[125, 187] -> 
             RGBColor[
              0.233882104650328, 0.36315529934237634`, 0.9366306119110444], 
             UndirectedEdge[57, 152] -> 
             RGBColor[
              0.19101263224123774`, 0.3180967657588828, 0.9341892588770478], 
             UndirectedEdge[128, 193] -> 
             RGBColor[
              0.3303839734000996, 0.45325331449434825`, 0.942541154768971], 
             UndirectedEdge[151, 172] -> 
             RGBColor[
              0.9316219629473853, 0.7456677416234209, 0.4816953197665501], 
             UndirectedEdge[5, 27] -> 
             RGBColor[
              0.31042728364880795`, 0.439394206178395, 0.9411440758342206], 
             UndirectedEdge[65, 118] -> 
             RGBColor[
              0.6736030025738579, 0.6886766721110076, 0.6155053609978421], 
             UndirectedEdge[78, 80] -> 
             RGBColor[
              0.20236223698329917`, 0.33002591994929253`, 0.9348356020768727],
              UndirectedEdge[40, 199] -> 
             RGBColor[
              0.7505454658303996, 0.8010014916056775, 0.8412228920171474], 
             UndirectedEdge[5, 42] -> 
             RGBColor[
              0.2785521364098815, 0.40589140542922086`, 0.9393288333540183], 
             UndirectedEdge[123, 196] -> 
             RGBColor[
              0.3420552644486344, 0.4636882937396207, 0.9432729065545822], 
             UndirectedEdge[80, 124] -> 
             RGBColor[
              0.22391524057948223`, 0.35267949326823644`, 0.9360630137468638],
              UndirectedEdge[22, 48] -> 
             RGBColor[
              0.19949157754304903`, 0.3270086748672687, 0.9346721222685106], 
             UndirectedEdge[69, 86] -> 
             RGBColor[
              0.22595538032998164`, 0.3548238094983426, 0.9361791966875385], 
             UndirectedEdge[81, 143] -> 
             RGBColor[
              0.5808462742510027, 0.663366694048388, 0.9634171920700499], 
             UndirectedEdge[80, 116] -> 
             RGBColor[
              0.23121046425376574`, 0.3603472358938047, 0.936478465942798], 
             UndirectedEdge[90, 169] -> 
             RGBColor[
              0.20968181085613852`, 0.3377192561774346, 0.9352524409805917], 
             UndirectedEdge[121, 173] -> 
             RGBColor[
              0.292553121290118, 0.41936663602592106`, 0.9401715965504269], 
             UndirectedEdge[8, 179] -> 
             RGBColor[
              0.32590224390731876`, 0.4543459110193097, 0.9420734441164204], 
             UndirectedEdge[29, 167] -> 
             RGBColor[
              0.20312227411308098`, 0.33082476716183046`, 0.9348788850670395],
              UndirectedEdge[76, 87] -> 
             RGBColor[
              0.2404757286880707, 0.37008561626595393`, 0.9370061090456012], 
             UndirectedEdge[111, 163] -> 
             RGBColor[
              0.25094941763616774`, 0.3810941274206381, 0.9376025701367612], 
             UndirectedEdge[130, 149] -> 
             RGBColor[
              0.1848995905074315, 0.3116715713074204, 0.9338411301937424], 
             UndirectedEdge[7, 122] -> 
             RGBColor[
              0.24320904209445873`, 0.37295850195814717`, 0.9371617672005202],
              UndirectedEdge[89, 142] -> 
             RGBColor[
              0.2647563469392241, 0.39560608552802945`, 0.9383888543350487], 
             UndirectedEdge[44, 172] -> 
             RGBColor[
              0.8840573238836684, 0.5664132115032791, 0.22496692784453026`], 
             UndirectedEdge[7, 179] -> 
             RGBColor[
              0.2885173026234793, 0.4150519673878126, 0.9399444270163702], 
             UndirectedEdge[73, 188] -> 
             RGBColor[
              0.26534078986482257`, 0.3958083524158491, 0.9384372235539715], 
             UndirectedEdge[16, 120] -> 
             RGBColor[
              0.19055686956976303`, 0.31761773029414053`, 0.9341633038671477],
              UndirectedEdge[98, 116] -> 
             RGBColor[
              0.21656444769936758`, 0.34495334388404864`, 0.9356443969668649],
              UndirectedEdge[5, 81] -> 
             RGBColor[
              0.3301819815617254, 0.46015764620506105`, 0.9422690766559045], 
             UndirectedEdge[76, 106] -> 
             RGBColor[
              0.2246392602509319, 0.35344048384842863`, 0.9361042455960618], 
             UndirectedEdge[135, 144] -> 
             RGBColor[
              0.19771245739729065`, 0.32513870679134427`, 0.9345708040081819],
              UndirectedEdge[194, 197] -> 
             RGBColor[
              0.20111393254862053`, 0.3287138728413728, 0.9347645129860187], 
             UndirectedEdge[27, 29] -> 
             RGBColor[
              0.2367156151308905, 0.36613349851238836`, 0.9367919761411093], 
             UndirectedEdge[44, 58] -> 
             RGBColor[
              0.9296752902178356, 0.8016782468054864, 0.5944321925119014], 
             UndirectedEdge[53, 92] -> 
             RGBColor[
              0.4381151075308816, 0.5431043898530338, 0.9506938510819287], 
             UndirectedEdge[83, 122] -> 
             RGBColor[
              0.6021548677029418, 0.6767924582408489, 0.9659897173678593], 
             UndirectedEdge[9, 178] -> 
             RGBColor[
              0.18848044580793838`, 0.31543527726759235`, 0.9340450546057055],
              UndirectedEdge[12, 99] -> 
             RGBColor[
              0.7509614073428162, 0.7434552401786318, 0.618284844686889], 
             UndirectedEdge[7, 126] -> 
             RGBColor[
              0.19407996143665954`, 0.32132072322317473`, 0.9343639387370202],
              UndirectedEdge[139, 146] -> 
             RGBColor[
              0.2655359588850107, 0.39642550711330343`, 0.9384332520820287], 
             UndirectedEdge[100, 198] -> 
             RGBColor[
              0.2757071764245771, 0.40370652655373696`, 0.9391373291200573], 
             UndirectedEdge[56, 109] -> 
             RGBColor[
              0.19998929422011852`, 0.3275318066519287, 0.9347004664969638], 
             UndirectedEdge[9, 159] -> 
             RGBColor[
              0.22410281281265743`, 0.3528766435780701, 0.9360736957080549], 
             UndirectedEdge[2, 98] -> 
             RGBColor[
              0.18743734029303655`, 0.314338907234721, 0.9339856512897682], 
             UndirectedEdge[95, 164] -> 
             RGBColor[
              0.22218549989478478`, 0.35086142613672566`, 0.9359645075737923],
              UndirectedEdge[108, 163] -> 
             RGBColor[
              0.29489469195251866`, 0.4272833970184431, 0.94010518849787], 
             UndirectedEdge[85, 121] -> 
             RGBColor[
              0.24391248178172664`, 0.37369786167011787`, 0.9372018270500644],
              UndirectedEdge[55, 177] -> 
             RGBColor[
              0.2766340766323431, 0.4055817721640561, 0.9391571241529215], 
             UndirectedEdge[118, 141] -> 
             RGBColor[
              0.36734166462355905`, 0.4925946195931902, 0.9446276639357014], 
             UndirectedEdge[58, 77] -> 
             RGBColor[
              0.8889478384033738, 0.5521228653145076, 0.5579177911517261], 
             UndirectedEdge[142, 154] -> 
             RGBColor[
              0.29693436368645065`, 0.4272891715192359, 0.9402996292628881], 
             UndirectedEdge[103, 178] -> 
             RGBColor[
              0.1823641236245055, 0.3090066348555799, 0.933696739105647], 
             UndirectedEdge[48, 154] -> 
             RGBColor[
              0.2711822856025334, 0.4002221046769836, 0.9388330865127945], 
             UndirectedEdge[72, 181] -> 
             RGBColor[
              0.345687120645864, 0.46870305597394574`, 0.9434358908416056], 
             UndirectedEdge[45, 132] -> 
             RGBColor[
              0.5058042387487333, 0.6037176098642293, 0.9561309549136163], 
             UndirectedEdge[103, 200] -> 
             RGBColor[
              0.18584727421565939`, 0.3126676469713855, 0.9338950993789537], 
             UndirectedEdge[21, 61] -> 
             RGBColor[
              0.2843221054652073, 0.4113116211381439, 0.9396810187426589], 
             UndirectedEdge[51, 73] -> 
             RGBColor[
              0.19983789794558066`, 0.3273726795683112, 0.9346918447030995], 
             UndirectedEdge[18, 41] -> 
             RGBColor[
              0.25688700518109014`, 0.38733490839514545`, 0.9379407069635708],
              UndirectedEdge[27, 42] -> 
             RGBColor[
              0.2346453394457319, 0.36395750750422684`, 0.936674077003538], 
             UndirectedEdge[90, 165] -> 
             RGBColor[
              0.21653690052978303`, 0.3449243900622238, 0.9356428281963094], 
             UndirectedEdge[50, 135] -> 
             RGBColor[
              0.20034146801813224`, 0.3279019636427496, 0.9347205222737662], 
             UndirectedEdge[93, 121] -> 
             RGBColor[
              0.22436989011875363`, 0.3531573587604565, 0.9360889053655316], 
             UndirectedEdge[23, 175] -> 
             RGBColor[
              0.36210448140880436`, 0.4789065526071719, 0.9449365792097879], 
             UndirectedEdge[57, 164] -> 
             RGBColor[
              0.1885063938143962, 0.3154625502675782, 0.9340465323062868], 
             UndirectedEdge[54, 172] -> 
             RGBColor[
              0.9288667542587956, 0.7360484350731749, 0.311047781867342], 
             UndirectedEdge[99, 198] -> 
             RGBColor[
              0.44872208919176476`, 0.5604076738789969, 0.9505521468225746], 
             UndirectedEdge[45, 112] -> 
             RGBColor[
              0.8262269535061243, 0.8650081965468237, 0.9779469895534628], 
             UndirectedEdge[88, 173] -> 
             RGBColor[
              0.2921580234490212, 0.41895136314427833`, 0.9401490963128714], 
             UndirectedEdge[14, 22] -> 
             RGBColor[
              0.18387332754707644`, 0.31059290386725735`, 0.9337826860363703],
              UndirectedEdge[7, 67] -> 
             RGBColor[
              0.23219222063367448`, 0.36137912409603845`, 0.9365343755162554],
              UndirectedEdge[105, 135] -> 
             RGBColor[
              0.20134641002226938`, 0.32895822140610087`, 0.9347777522342233],
              UndirectedEdge[104, 176] -> 
             RGBColor[
              0.300594019570315, 0.4278785034268868, 0.9406273032429688], 
             UndirectedEdge[57, 91] -> 
             RGBColor[
              0.18403700151578473`, 0.31076493558589874`, 0.9337920070267542],
              UndirectedEdge[34, 185] -> 
             RGBColor[
              0.3310536945005693, 0.45407275524127744`, 0.9425750645902526], 
             UndirectedEdge[65, 172] -> 
             RGBColor[
              0.9128396568383367, 0.6819852721325363, 0.24878553485224705`], 
             UndirectedEdge[66, 120] -> 
             RGBColor[
              0.18874212911118976`, 0.3157103230109893, 0.9340599570827], 
             UndirectedEdge[91, 117] -> 
             RGBColor[
              0.1857785761820701, 0.31259544098237624`, 0.9338911871275704], 
             UndirectedEdge[27, 141] -> 
             RGBColor[
              0.30516819016116037`, 0.4348390437291191, 0.9408089710476214], 
             UndirectedEdge[13, 145] -> 
             RGBColor[
              0.20564959648275716`, 0.3334811432138535, 0.9350228123371542], 
             UndirectedEdge[1, 174] -> 
             RGBColor[
              0.1849745541189024, 0.31175036281604385`, 0.9338453992605169], 
             UndirectedEdge[182, 196] -> 
             RGBColor[
              0.28690951633149697`, 0.41592381842644754`, 0.9397590682480286],
              UndirectedEdge[96, 137] -> 
             RGBColor[
              0.630154419316935, 0.7035305563325196, 0.9671868226387048], 
             UndirectedEdge[89, 157] -> 
             RGBColor[
              0.23696986749514018`, 0.36640073386774574`, 0.9368064554371207],
              UndirectedEdge[119, 191] -> 
             RGBColor[
              0.8284647281297735, 0.6062540401066088, 0.5870905124717782], 
             UndirectedEdge[51, 157] -> 
             RGBColor[
              0.19431074366027534`, 0.32156328997263306`, 0.9343770814432435],
              UndirectedEdge[127, 195] -> 
             RGBColor[
              0.6879096375591269, 0.7543975082866485, 0.9708907042928315], 
             UndirectedEdge[27, 62] -> 
             RGBColor[
              0.23321094483198931`, 0.3624498678193121, 0.9365923903522819], 
             UndirectedEdge[4, 40] -> 
             RGBColor[
              0.42006888605358417`, 0.5368384587156347, 0.9483813569191326], 
             UndirectedEdge[161, 164] -> 
             RGBColor[
              0.23950057479482478`, 0.3690606676958246, 0.9369505754739917], 
             UndirectedEdge[20, 101] -> 
             RGBColor[
              0.18925893509711914`, 0.3162535188695931, 0.9340893884190526], 
             UndirectedEdge[13, 36] -> 
             RGBColor[
              0.20182875625464586`, 0.3294651978788461, 0.9348052211385899], 
             UndirectedEdge[182, 195] -> 
             RGBColor[
              0.42093237513181697`, 0.5377166564648852, 0.9484003790182465], 
             UndirectedEdge[184, 186] -> 
             RGBColor[
              0.18243843400162507`, 0.3090847397734826, 0.9337009709716915], 
             UndirectedEdge[96, 166] -> 
             RGBColor[
              0.8700729048613844, 0.8993494121193195, 0.9867932099380505], 
             UndirectedEdge[38, 43] -> 
             RGBColor[
              0.1854358891920559, 0.31223525522826123`, 0.9338716716104489], 
             UndirectedEdge[30, 176] -> 
             RGBColor[
              0.22182699852969923`, 0.3504846184717214, 0.9359440914514059], 
             UndirectedEdge[171, 174] -> 
             RGBColor[
              0.24889168370669917`, 0.37893131859289997`, 0.9374853852336225],
              UndirectedEdge[100, 125] -> 
             RGBColor[
              0.23503699113385892`, 0.36436915826059957`, 0.9366963809877801],
              UndirectedEdge[17, 188] -> 
             RGBColor[
              0.25233578672597107`, 0.38213926955209265`, 0.937696607864392], 
             UndirectedEdge[87, 107] -> 
             RGBColor[
              0.21716799810205883`, 0.34558771362458285`, 0.9356787682694253],
              UndirectedEdge[62, 184] -> 
             RGBColor[
              0.19085514348532573`, 0.3179312350910555, 0.9341802901253824], 
             UndirectedEdge[12, 33] -> 
             RGBColor[
              0.9713628299392978, 0.9155481063306994, 0.5253098577893779], 
             UndirectedEdge[32, 57] -> 
             RGBColor[
              0.1839232484123208, 0.31064537386179486`, 0.9337855289557946], 
             UndirectedEdge[17, 87] -> 
             RGBColor[
              0.2040861170766778, 0.33183782722774424`, 0.9349337744979385], 
             UndirectedEdge[42, 149] -> 
             RGBColor[
              0.1941370173040445, 0.32138069255734725`, 0.9343671879842612], 
             UndirectedEdge[87, 130] -> 
             RGBColor[
              0.20049917291084113`, 0.3280677214840543, 0.9347295033341025], 
             UndirectedEdge[58, 170] -> 
             RGBColor[
              0.8078923228953876, 0.8503457214275595, 0.9589431237256691], 
             UndirectedEdge[118, 196] -> 
             RGBColor[
              0.3119267863848373, 0.4375925203420974, 0.941353146573924], 
             UndirectedEdge[41, 159] -> 
             RGBColor[
              0.27279920204986197`, 0.40405963619577695`, 0.9388468830352616],
              UndirectedEdge[107, 157] -> 
             RGBColor[
              0.2120289568241801, 0.34018625540749603`, 0.9353861074711805], 
             UndirectedEdge[161, 173] -> 
             RGBColor[
              0.32579061120905595`, 0.4543013453093021, 0.9420644224308505], 
             UndirectedEdge[15, 184] -> 
             RGBColor[
              0.18036794199566558`, 0.3069085213984438, 0.9335830595149706], 
             UndirectedEdge[106, 142] -> 
             RGBColor[
              0.22351397693716918`, 0.3522577397385811, 0.9360401623760504], 
             UndirectedEdge[24, 39] -> 
             RGBColor[
              0.25460473932666533`, 0.38493610227813213`, 0.9378107352994711],
              UndirectedEdge[45, 134] -> 
             RGBColor[
              0.478958077481094, 0.5755005922270049, 0.9546021057447607], 
             UndirectedEdge[5, 73] -> 
             RGBColor[
              0.2859066569179567, 0.41362147278674055`, 0.939747662416915], 
             UndirectedEdge[147, 154] -> 
             RGBColor[
              0.2906977642675366, 0.42073411010671546`, 0.939944464152203], 
             UndirectedEdge[76, 143] -> 
             RGBColor[
              0.5599555580797754, 0.6414092268045206, 0.9622274966891435], 
             UndirectedEdge[5, 197] -> 
             RGBColor[
              0.27751999813753725`, 0.4048065626636409, 0.93927005460632], 
             UndirectedEdge[152, 159] -> 
             RGBColor[
              0.22753887579901738`, 0.3564881636357107, 0.9362693744119284], 
             UndirectedEdge[108, 115] -> 
             RGBColor[
              0.3115259900053915, 0.4441833842869002, 0.9410735735175593], 
             UndirectedEdge[65, 123] -> 
             RGBColor[
              0.7037314806376549, 0.7147724455085309, 0.6174251209785002], 
             UndirectedEdge[8, 67] -> 
             RGBColor[
              0.26957716191751396`, 0.4006730677275356, 0.9386633926163057], 
             UndirectedEdge[9, 41] -> 
             RGBColor[
              0.24200989921647753`, 0.37169812676333913`, 0.9370934777875921],
              UndirectedEdge[111, 165] -> 
             RGBColor[
              0.21296967150778956`, 0.3411750061847254, 0.9354396797807493], 
             UndirectedEdge[146, 195] -> 
             RGBColor[
              0.37321783418719845`, 0.490532301380389, 0.9455744828100211], 
             UndirectedEdge[104, 188] -> 
             RGBColor[
              0.34015129368141406`, 0.46904368691088416`, 0.9428951175427689],
              UndirectedEdge[37, 105] -> 
             RGBColor[
              0.22080146805015013`, 0.3494067209153274, 0.9358856890077321], 
             UndirectedEdge[3, 75] -> 
             RGBColor[
              0.4604176361342196, 0.5718866537552251, 0.9509246758011038], 
             UndirectedEdge[40, 132] -> 
             RGBColor[
              0.40319785832980803`, 0.5214692788871429, 0.94733404339442], 
             UndirectedEdge[154, 157] -> 
             RGBColor[
              0.2691478842423667, 0.3980838198589522, 0.9387172303649602], 
             UndirectedEdge[116, 148] -> 
             RGBColor[
              0.21710235245946194`, 0.3455187158920394, 0.9356750298471934], 
             UndirectedEdge[132, 185] -> 
             RGBColor[
              0.26630785953473646`, 0.397236823637493, 0.9384772106821059], 
             UndirectedEdge[92, 123] -> 
             RGBColor[
              0.34778570453147756`, 0.4697113495975751, 0.9435992466398737], 
             UndirectedEdge[53, 139] -> 
             RGBColor[
              0.4587256509461706, 0.5647673777664313, 0.9518675910388628], 
             UndirectedEdge[40, 196] -> 
             RGBColor[
              0.3694081793861806, 0.4859541839280068, 0.9454097711659308], 
             UndirectedEdge[27, 73] -> 
             RGBColor[
              0.2419998599538071, 0.37168757486174653`, 0.9370929060664348], 
             UndirectedEdge[57, 103] -> 
             RGBColor[
              0.1814602470714449, 0.3080566032892297, 0.9336452646731157], 
             UndirectedEdge[44, 77] -> 
             RGBColor[
              0.8580464518144618, 0.3836823814909788, 0.2007324013601752], 
             UndirectedEdge[88, 91] -> 
             RGBColor[
              0.20139859473617852`, 0.32901307084912135`, 0.93478072407648], 
             UndirectedEdge[69, 146] -> 
             RGBColor[
              0.24760893000865222`, 0.37758306312497075`, 0.9374123343081827],
              UndirectedEdge[65, 199] -> 
             RGBColor[
              0.9757996397934585, 0.9283450401492326, 0.5065449231630825], 
             UndirectedEdge[27, 75] -> 
             RGBColor[
              0.3843313935505691, 0.5020805374205839, 0.9462194736309155], 
             UndirectedEdge[4, 65] -> 
             RGBColor[
              0.6453230600166431, 0.6641820072591899, 0.6137033880650677], 
             UndirectedEdge[58, 102] -> 
             RGBColor[
              0.9648761622564584, 0.9733252798376484, 0.9443396749224908], 
             UndirectedEdge[107, 168] -> 
             RGBColor[
              0.21351519211843195`, 0.34174838293451504`, 0.9354707463724999],
              UndirectedEdge[9, 85] -> 
             RGBColor[
              0.23189273144463124`, 0.36106434196964265`, 0.9365173200499939],
              UndirectedEdge[22, 144] -> 
             RGBColor[
              0.19348904144218293`, 0.3206996288424882, 0.9343302867175226], 
             UndirectedEdge[110, 138] -> 
             RGBColor[
              0.20099999291646117`, 0.32859411506378333`, 0.9347580242925257],
              UndirectedEdge[34, 132] -> 
             RGBColor[
              0.3653113300133066, 0.4900797022247081, 0.9445259862530728], 
             UndirectedEdge[48, 158] -> 
             RGBColor[
              0.2634190473924112, 0.39349797793107355`, 0.9383384198388076], 
             UndirectedEdge[19, 95] -> 
             RGBColor[
              0.3002072480543151, 0.4289405280402324, 0.9405515065144217], 
             UndirectedEdge[122, 137] -> 
             RGBColor[
              0.3009080664928653, 0.4322034485232962, 0.9404989162882755], 
             UndirectedEdge[8, 198] -> 
             RGBColor[
              0.31444384785817775`, 0.4444212242772747, 0.9413433252524308], 
             UndirectedEdge[92, 174] -> 
             RGBColor[
              0.2172400978636229, 0.3456634950453756, 0.9356828742441843], 
             UndirectedEdge[39, 133] -> 
             RGBColor[
              0.2505927164379196, 0.38071921184511703`, 0.9375822565312131], 
             UndirectedEdge[120, 198] -> 
             RGBColor[
              0.26978078120628096`, 0.39747750942414833`, 0.9387998296796913],
              UndirectedEdge[4, 34] -> 
             RGBColor[
              0.38218235773708276`, 0.5054488820532, 0.9455732997777855], 
             UndirectedEdge[31, 34] -> 
             RGBColor[
              0.48100947040442327`, 0.5889125969543878, 0.9524604831380885], 
             UndirectedEdge[41, 152] -> 
             RGBColor[
              0.2454459622028375, 0.3753096468209797, 0.9372891564914656], 
             UndirectedEdge[95, 121] -> 
             RGBColor[
              0.23327542567236176`, 0.36251764127086494`, 0.9365960624407503],
              UndirectedEdge[3, 129] -> 
             RGBColor[
              0.4365819525225805, 0.5525357720139865, 0.9490482434742096], 
             UndirectedEdge[49, 199] -> 
             RGBColor[
              0.7088075949120052, 0.7662760755555905, 0.8381694307308162], 
             UndirectedEdge[171, 182] -> 
             RGBColor[
              0.3242915422574164, 0.45521469783192636`, 0.9418879193227581], 
             UndirectedEdge[56, 150] -> 
             RGBColor[
              0.18756580923325702`, 0.31447393623629405`, 0.933992967405861], 
             UndirectedEdge[179, 183] -> 
             RGBColor[
              0.6524621901365182, 0.6395620041190959, 0.6061877007325749], 
             UndirectedEdge[31, 156] -> 
             RGBColor[
              0.6753397250677327, 0.3878936918486643, 0.560927249104864], 
             UndirectedEdge[132, 153] -> 
             RGBColor[
              0.29141110867079584`, 0.42362193011741534`, 0.9399068035834754],
              UndirectedEdge[78, 136] -> 
             RGBColor[
              0.2028717449192551, 0.3305614450946512, 0.9348646178000759], 
             UndirectedEdge[27, 167] -> 
             RGBColor[
              0.2329271456668488, 0.36215157690284305`, 0.9365762284096705], 
             UndirectedEdge[35, 174] -> 
             RGBColor[
              0.18540537254043327`, 0.31220318029253835`, 0.9338699337322844],
              UndirectedEdge[61, 190] -> 
             RGBColor[
              0.1957633885191688, 0.3230901118223337, 0.9344598074189618], 
             UndirectedEdge[18, 103] -> 
             RGBColor[
              0.20207429376045272`, 0.32972327336542606`, 0.9348192041363055],
              UndirectedEdge[146, 155] -> 
             RGBColor[
              0.4592969410332923, 0.5599429054907851, 0.9526738544811711], 
             UndirectedEdge[77, 166] -> 
             RGBColor[
              0.8105241760173298, 0.490362872734788, 0.5726449442995682], 
             UndirectedEdge[85, 159] -> 
             RGBColor[
              0.26268203427801573`, 0.3934258514020805, 0.9382707252976634], 
             UndirectedEdge[39, 88] -> 
             RGBColor[
              0.2343125277851679, 0.36360770134749604`, 0.9366551238718196], 
             UndirectedEdge[66, 80] -> 
             RGBColor[
              0.20266968703316796`, 0.3303490694451636, 0.9348531109023811], 
             UndirectedEdge[62, 141] -> 
             RGBColor[
              0.2718586483084913, 0.3998286032950302, 0.9389120419161632], 
             UndirectedEdge[91, 103] -> 
             RGBColor[
              0.18365762005674702`, 0.31036618161827634`, 0.9337704018139066],
              UndirectedEdge[149, 189] -> 
             RGBColor[
              0.18996767873421347`, 0.31699845336912136`, 0.934129750320693], 
             UndirectedEdge[4, 69] -> 
             RGBColor[
              0.2920607984493962, 0.42194145527329896`, 0.9400303359095292], 
             UndirectedEdge[23, 169] -> 
             RGBColor[
              0.20786534559532402`, 0.33581003601776915`, 0.9351489959712078],
              UndirectedEdge[32, 152] -> 
             RGBColor[
              0.19309625212307593`, 0.3202867823638255, 0.9343079179468792], 
             UndirectedEdge[100, 124] -> 
             RGBColor[
              0.21591407787580016`, 0.3442697639636507, 0.9356073593675487], 
             UndirectedEdge[129, 139] -> 
             RGBColor[
              0.3700695186748425, 0.49279233567532266`, 0.9448882555483507], 
             UndirectedEdge[29, 73] -> 
             RGBColor[
              0.21219498840003925`, 0.3403607651207339, 0.9353955627238038], 
             UndirectedEdge[32, 178] -> 
             RGBColor[
              0.1848271249653814, 0.311595405428145, 0.9338370033883259], 
             UndirectedEdge[8, 61] -> 
             RGBColor[
              0.24530237000143487`, 0.37515872231303415`, 0.9372809791280214],
              UndirectedEdge[10, 27] -> 
             RGBColor[
              0.24223545662361712`, 0.37193520189940843`, 0.9371063229482464],
              UndirectedEdge[72, 160] -> 
             RGBColor[
              0.3481960203596565, 0.4708761388050667, 0.9435957557128356], 
             UndirectedEdge[72, 144] -> 
             RGBColor[
              0.22584498306262032`, 0.3547077749707548, 0.9361729097264804], 
             UndirectedEdge[134, 135] -> 
             RGBColor[
              0.22190471606791506`, 0.3505663045319628, 0.9359485173502345], 
             UndirectedEdge[95, 150] -> 
             RGBColor[
              0.2208799451115121, 0.3494892052825519, 0.9358901581602801], 
             UndirectedEdge[68, 71] -> 
             RGBColor[
              0.6623649639352431, 0.6847752584173, 0.6236785616506062], 
             UndirectedEdge[118, 123] -> 
             RGBColor[
              0.42099591367325284`, 0.5390672333790665, 0.9480464652405584], 
             UndirectedEdge[89, 168] -> 
             RGBColor[
              0.23845610278939203`, 0.36796286139476475`, 0.9368910943384403],
              UndirectedEdge[44, 99] -> 
             RGBColor[
              0.7252973005063621, 0.6401348451070372, 0.5975536479428364], 
             UndirectedEdge[121, 180] -> 
             RGBColor[
              0.27969294333585376`, 0.40822779625327543`, 0.9393521573829899],
              UndirectedEdge[10, 141] -> 
             RGBColor[
              0.28088316010011916`, 0.40931393737512656`, 0.9394259745121276],
              UndirectedEdge[6, 170] -> 
             RGBColor[
              0.7433204991907267, 0.48659316349091797`, 0.5720011378191884], 
             UndirectedEdge[12, 77] -> 
             RGBColor[
              0.883710558650916, 0.4870027765625733, 0.22146359810422783`], 
             UndirectedEdge[112, 143] -> 
             RGBColor[
              0.8985367952768839, 0.9217855718880776, 0.9850776323188054], 
             UndirectedEdge[67, 125] -> 
             RGBColor[
              0.2600866097683471, 0.39069789568300034`, 0.9381229197114243], 
             UndirectedEdge[3, 10] -> 
             RGBColor[
              0.3183216992072676, 0.4417413182340497, 0.9418115251184348], 
             UndirectedEdge[124, 125] -> 
             RGBColor[
              0.24516019716023396`, 0.37500928964265323`, 0.9372728825950409],
              UndirectedEdge[11, 174] -> 
             RGBColor[
              0.1964947207721936, 0.32385878838940574`, 0.9345014557088626], 
             UndirectedEdge[71, 87] -> 
             RGBColor[
              0.29022081155983176`, 0.4172864093031303, 0.9400251842918653], 
             UndirectedEdge[7, 192] -> 
             RGBColor[
              0.3371042587561843, 0.4567989612427451, 0.9431333444727331], 
             UndirectedEdge[56, 148] -> 
             RGBColor[
              0.18807327130146562`, 0.31500731104493473`, 0.9340218666199227],
              UndirectedEdge[30, 71] -> 
             RGBColor[
              0.28665240734323405`, 0.41353579022159115`, 0.939821968950711], 
             UndirectedEdge[35, 86] -> 
             RGBColor[
              0.19143714046786142`, 0.31854295082044043`, 0.9342134339925504],
              UndirectedEdge[68, 127] -> 
             RGBColor[
              0.9178893661581602, 0.8915362183675095, 0.645439120800334], 
             UndirectedEdge[10, 30] -> 
             RGBColor[
              0.2137583126687416, 0.34200391804762365`, 0.9354845917281754], 
             UndirectedEdge[89, 176] -> 
             RGBColor[
              0.25080130431121317`, 0.3809384509251836, 0.937594135302019], 
             UndirectedEdge[71, 76] -> 
             RGBColor[
              0.3139935330397997, 0.4422730468561747, 0.9413790056115596], 
             UndirectedEdge[49, 119] -> 
             RGBColor[
              0.634590175011373, 0.45058684488381917`, 0.5703034220716992], 
             UndirectedEdge[87, 106] -> 
             RGBColor[
              0.20086653877096394`, 0.3284538462953842, 0.9347504242763673], 
             UndirectedEdge[86, 196] -> 
             RGBColor[
              0.2175414257082079, 0.3459802097153233, 0.9357000344191588], 
             UndirectedEdge[53, 123] -> 
             RGBColor[
              0.5414537947364539, 0.6385560470320484, 0.9570608296632714], 
             UndirectedEdge[68, 102] -> 
             RGBColor[
              0.9650834798325474, 0.9283042529937652, 0.6200104049924591], 
             UndirectedEdge[107, 130] -> 
             RGBColor[
              0.20096416380479723`, 0.32855645639572767`, 0.9347559838776209],
              UndirectedEdge[42, 157] -> 
             RGBColor[
              0.2045975584295754, 0.3323753845168943, 0.9349629003263764], 
             UndirectedEdge[96, 99] -> 
             RGBColor[
              0.7441185775359549, 0.79956600300059, 0.9751875122211435], 
             UndirectedEdge[62, 194] -> 
             RGBColor[
              0.2007116762072222, 0.32829107592203804`, 0.9347416050824608], 
             UndirectedEdge[57, 117] -> 
             RGBColor[
              0.18358120319676802`, 0.31028586265332964`, 0.9337660499867794],
              UndirectedEdge[102, 128] -> 
             RGBColor[
              0.700241137930167, 0.7622648425385679, 0.9428826111957023], 
             UndirectedEdge[46, 47] -> 
             RGBColor[
              0.1896200136619846, 0.31663303533497, 0.934109951309154], 
             UndirectedEdge[28, 105] -> 
             RGBColor[
              0.19252363925225727`, 0.3196849299308422, 0.9342753084909909], 
             UndirectedEdge[40, 182] -> 
             RGBColor[
              0.4233315585574587, 0.5396644216518027, 0.9485892515260115], 
             UndirectedEdge[79, 179] -> 
             RGBColor[
              0.2813590504704592, 0.4075281905155883, 0.9395367751459407], 
             UndirectedEdge[36, 63] -> 
             RGBColor[
              0.1871120628164008, 0.3139970199829937, 0.9339671272186787], 
             UndirectedEdge[118, 129] -> 
             RGBColor[
              0.4226691844013287, 0.5404852315434163, 0.9481617341921013], 
             UndirectedEdge[74, 161] -> 
             RGBColor[
              0.31487926883859824`, 0.44485048896802515`, 0.9413691613435261],
              UndirectedEdge[66, 187] -> 
             RGBColor[
              0.19351363784595493`, 0.32072548122235467`, 0.9343316874463302],
              UndirectedEdge[10, 29] -> 
             RGBColor[
              0.2124305850698493, 0.3406083921583959, 0.9354089796056155], 
             UndirectedEdge[30, 147] -> 
             RGBColor[
              0.22954544173879612`, 0.3585971916620468, 0.9363836453737505], 
             UndirectedEdge[109, 116] -> 
             RGBColor[
              0.2290183753781148, 0.3580432114990334, 0.9363536297242345], 
             UndirectedEdge[81, 154] -> 
             RGBColor[
              0.31895036317144065`, 0.45042938287295087`, 0.9415534078638058],
              UndirectedEdge[89, 188] -> 
             RGBColor[
              0.29035857842231216`, 0.42210363440918097`, 0.939861949601819], 
             UndirectedEdge[24, 163] -> 
             RGBColor[
              0.2694549562733895, 0.40054462184727546`, 0.9386564331856598], 
             UndirectedEdge[91, 159] -> 
             RGBColor[
              0.22056324507356437`, 0.3491563334627266, 0.9358721225616348], 
             UndirectedEdge[121, 164] -> 
             RGBColor[
              0.2062630848758868, 0.3341259584124435, 0.9350577495935681], 
             UndirectedEdge[4, 54] -> 
             RGBColor[
              0.661350157437102, 0.7182451701998284, 0.6759656350801627], 
             UndirectedEdge[51, 130] -> 
             RGBColor[
              0.18324595064089247`, 0.3099334909608647, 0.933746957849684], 
             UndirectedEdge[69, 186] -> 
             RGBColor[
              0.21644101520784265`, 0.3448236085093839, 0.9356373676690746], 
             UndirectedEdge[137, 179] -> 
             RGBColor[
              0.3462163270218858, 0.4742969139529616, 0.9432815761041253], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.37725864887478877`, 0.501184212909484, 0.945259565402945], 
             UndirectedEdge[22, 176] -> 
             RGBColor[
              0.2112886129989553, 0.33940810710667507`, 0.9353439459855744], 
             UndirectedEdge[128, 198] -> 
             RGBColor[
              0.38846505457694686`, 0.5108906382783656, 0.9459736276648509], 
             UndirectedEdge[107, 131] -> 
             RGBColor[
              0.19956404883419218`, 0.32708484678920535`, 0.9346762494013294],
              UndirectedEdge[26, 125] -> 
             RGBColor[
              0.2785326649894304, 0.41008586926780977`, 0.9391733952677717], 
             UndirectedEdge[47, 105] -> 
             RGBColor[
              0.2010087745780687, 0.32860334514692235`, 0.934758524395163], 
             UndirectedEdge[23, 60] -> 
             RGBColor[
              0.2023092030396156, 0.32997017791193484`, 0.9348325818722366], 
             UndirectedEdge[43, 111] -> 
             RGBColor[
              0.2049417486516364, 0.33273715026320094`, 0.934982501450339], 
             UndirectedEdge[73, 142] -> 
             RGBColor[
              0.23973855838173452`, 0.36931080353469764`, 0.9369641282872011],
              UndirectedEdge[43, 115] -> 
             RGBColor[
              0.25238630356085545`, 0.3820238241610014, 0.9377056558638687], 
             UndirectedEdge[61, 122] -> 
             RGBColor[
              0.24263213866310665`, 0.37235213987400595`, 0.9371289134035569],
              UndirectedEdge[64, 65] -> 
             RGBColor[
              0.792934775654365, 0.787251260573052, 0.6244310740750881], 
             UndirectedEdge[147, 157] -> 
             RGBColor[
              0.2279748046775151, 0.3569463525264991, 0.9362941999166599], 
             UndirectedEdge[53, 69] -> 
             RGBColor[
              0.4407986220698122, 0.5459249337780987, 0.9508466732650168], 
             UndirectedEdge[27, 188] -> 
             RGBColor[
              0.28986141659567377`, 0.4215810858075036, 0.939833636971277], 
             UndirectedEdge[88, 159] -> 
             RGBColor[
              0.23572746530865607`, 0.3650948903969026, 0.9367357024705698], 
             UndirectedEdge[16, 61] -> 
             RGBColor[
              0.19725809150646825`, 0.3246611394316285, 0.9345449285428737], 
             UndirectedEdge[138, 185] -> 
             RGBColor[
              0.22696192070522694`, 0.35588174725107113`, 0.9362365176728656],
              UndirectedEdge[26, 128] -> 
             RGBColor[
              0.36204442385736635`, 0.48653045531343586`, 0.9443441705850733],
              UndirectedEdge[68, 75] -> 
             RGBColor[
              0.7315668061877028, 0.7433887217645079, 0.6284543351107399], 
             UndirectedEdge[10, 107] -> 
             RGBColor[
              0.21779170777929543`, 0.3462432720408361, 0.9357142876128481], 
             UndirectedEdge[69, 123] -> 
             RGBColor[
              0.3504692190704081, 0.47253189352264, 0.9437520688229617], 
             UndirectedEdge[109, 113] -> 
             RGBColor[
              0.2109311914464215, 0.33903243439312675`, 0.9353235913569153], 
             UndirectedEdge[49, 196] -> 
             RGBColor[
              0.3276703084677861, 0.4512287678779199, 0.9423563098795996], 
             UndirectedEdge[8, 26] -> 
             RGBColor[
              0.28802321713859724`, 0.420061041312345, 0.9397138681726531], 
             UndirectedEdge[30, 73] -> 
             RGBColor[
              0.21352271599893158`, 0.34175629100996163`, 0.9354711748463638],
              UndirectedEdge[46, 144] -> 
             RGBColor[
              0.19073384687984102`, 0.31780374466804207`, 0.9341733824631423],
              UndirectedEdge[81, 176] -> 
             RGBColor[
              0.2700588403974922, 0.4011793423501723, 0.938690823493161], 
             UndirectedEdge[104, 181] -> 
             RGBColor[
              0.4026365855967863, 0.5231653061658909, 0.9468766250900423], 
             UndirectedEdge[65, 171] -> 
             RGBColor[
              0.6320443792751589, 0.6525886118770408, 0.6128606533865955], 
             UndirectedEdge[67, 82] -> 
             RGBColor[
              0.2339276106645956, 0.3632031290486195, 0.9366332034112368], 
             UndirectedEdge[13, 63] -> 
             RGBColor[
              0.20638929458382937`, 0.3342586128176488, 0.935064937049725], 
             UndirectedEdge[153, 182] -> 
             RGBColor[
              0.3115448088984465, 0.4418170728820753, 0.941162011715067], 
             UndirectedEdge[87, 157] -> 
             RGBColor[
              0.21156396593022397`, 0.3396975204958227, 0.9353596269276621], 
             UndirectedEdge[30, 157] -> 
             RGBColor[
              0.20799556171362626`, 0.3359469014142835, 0.9351564115865076], 
             UndirectedEdge[64, 185] -> 
             RGBColor[
              0.4307906028962345, 0.5356752567798472, 0.9502522102168389], 
             UndirectedEdge[9, 103] -> 
             RGBColor[
              0.18719718779584008`, 0.3140864917336198, 0.9339719749603267], 
             UndirectedEdge[18, 117] -> 
             RGBColor[
              0.2041952498857758, 0.331952532729526, 0.9349399894499691], 
             UndirectedEdge[52, 66] -> 
             RGBColor[
              0.18456752137294713`, 0.3113225455926782, 0.9338222193477858], 
             UndirectedEdge[128, 162] -> 
             RGBColor[
              0.4413593088202362, 0.5567049827613839, 0.9493440027726809], 
             UndirectedEdge[23, 177] -> 
             RGBColor[
              0.22051380406985302`, 0.3491043678330853, 0.9358693069696149], 
             UndirectedEdge[11, 110] -> 
             RGBColor[
              0.1915413157937571, 0.3186524456930539, 0.9342193666232466], 
             UndirectedEdge[79, 177] -> 
             RGBColor[
              0.20578387384021699`, 0.33362227723022, 0.9350304592340161], 
             UndirectedEdge[8, 166] -> 
             RGBColor[
              0.543496783375643, 0.6308288867491243, 0.9602573693120857], 
             UndirectedEdge[162, 173] -> 
             RGBColor[
              0.40958261070654, 0.5291816039985865, 0.947319219667907], 
             UndirectedEdge[100, 137] -> 
             RGBColor[
              0.26484162639759284`, 0.3942953332387867, 0.9384449858803665], 
             UndirectedEdge[88, 117] -> 
             RGBColor[
              0.2009427964171618, 0.32853399791655225`, 0.9347547670365053], 
             UndirectedEdge[149, 168] -> 
             RGBColor[
              0.19745061882106624`, 0.32486349784620777`, 0.9345558926886215],
              UndirectedEdge[36, 110] -> 
             RGBColor[
              0.18133894646584242`, 0.3079291086618389, 0.9336383567830746], 
             UndirectedEdge[76, 104] -> 
             RGBColor[
              0.3156743455120887, 0.4437288821395802, 0.9414861054960099], 
             UndirectedEdge[4, 196] -> 
             RGBColor[
              0.28364684382762245`, 0.41309785549027966`, 0.9395511736411497],
              UndirectedEdge[61, 79] -> 
             RGBColor[
              0.20075917656457537`, 0.3283410018093128, 0.9347443101575417], 
             UndirectedEdge[76, 147] -> 
             RGBColor[
              0.2568865674353618, 0.38733444829663033`, 0.9379406820345992], 
             UndirectedEdge[2, 120] -> 
             RGBColor[
              0.18815579892545653`, 0.3150940528103027, 0.9340265664460203], 
             UndirectedEdge[87, 176] -> 
             RGBColor[
              0.22539540274629694`, 0.3542352375532605, 0.9361473067925603], 
             UndirectedEdge[142, 157] -> 
             RGBColor[
              0.2342114040964292, 0.3635014139390195, 0.9366493650273451], 
             UndirectedEdge[65, 191] -> 
             RGBColor[
              0.8832210777752071, 0.8579801148696197, 0.6332956147035969], 
             UndirectedEdge[73, 147] -> 
             RGBColor[
              0.23350195896282042`, 0.3627557421221772, 0.936608963176516], 
             UndirectedEdge[26, 120] -> 
             RGBColor[
              0.2433601504867005, 0.3731173264592187, 0.9371703725999135], 
             UndirectedEdge[113, 116] -> 
             RGBColor[
              0.22254054731904888`, 0.35123460349093416`, 0.9359847269993585],
              UndirectedEdge[35, 94] -> 
             RGBColor[
              0.1855941681935362, 0.31240161649428533`, 0.9338806853654305], 
             UndirectedEdge[31, 45] -> 
             RGBColor[0.62150237913985, 0.702550504593909, 0.964065451798632],
              UndirectedEdge[52, 82] -> 
             RGBColor[
              0.1987769890735687, 0.32625759707831903`, 0.9346314275123124], 
             UndirectedEdge[95, 162] -> 
             RGBColor[
              0.35030491508878375`, 0.4723326092435304, 0.9437436855582304], 
             UndirectedEdge[17, 73] -> 
             RGBColor[
              0.20447423008410437`, 0.33224575860633554`, 0.9349558769595496],
              UndirectedEdge[103, 152] -> 
             RGBColor[
              0.19063325078220003`, 0.31769801179126034`, 0.9341676536642003],
              UndirectedEdge[88, 103] -> 
             RGBColor[
              0.1988218402918387, 0.32630473855245234`, 0.9346339817228415], 
             UndirectedEdge[26, 170] -> 
             RGBColor[
              0.4739950942722979, 0.5778178834110607, 0.9531267757340784], 
             UndirectedEdge[89, 106] -> 
             RGBColor[
              0.22627244033588012`, 0.3551570596673073, 0.9361972527858261], 
             UndirectedEdge[19, 74] -> 
             RGBColor[
              0.34857360130161363`, 0.4763386664540116, 0.9434317795367738], 
             UndirectedEdge[117, 152] -> 
             RGBColor[
              0.19275420690752315`, 0.3199272711553603, 0.934288438977864], 
             UndirectedEdge[157, 176] -> 
             RGBColor[
              0.2202563614684182, 0.34883377933617365`, 0.9358546459943153], 
             UndirectedEdge[49, 139] -> 
             RGBColor[
              0.3540112919659183, 0.4789148116492719, 0.9438563899218253], 
             UndirectedEdge[48, 106] -> 
             RGBColor[
              0.1977618988532519, 0.32519067289632886`, 0.9345736196259569], 
             UndirectedEdge[69, 118] -> 
             RGBColor[
              0.32034074100661103`, 0.44643612012511674`, 0.9418323088423037],
              UndirectedEdge[117, 200] -> 
             RGBColor[
              0.1879682303409825, 0.3148969063354854, 0.9340158846926173], 
             UndirectedEdge[64, 153] -> 
             RGBColor[
              0.4558938520322939, 0.5620603632597695, 0.9516818031182084], 
             UndirectedEdge[73, 87] -> 
             RGBColor[
              0.2170911202155293, 0.3455069100915008, 0.9356743901875181], 
             UndirectedEdge[132, 138] -> 
             RGBColor[
              0.2612195562179643, 0.3918886942345018, 0.9381874393356859], 
             UndirectedEdge[6, 96] -> 
             RGBColor[
              0.8839247435427675, 0.5973568467623975, 0.5851240708837279], 
             UndirectedEdge[34, 65] -> 
             RGBColor[
              0.6931978672586998, 0.7056487590344823, 0.6167539284485017], 
             UndirectedEdge[2, 16] -> 
             RGBColor[
              0.1847745870823867, 0.3115401847820234, 0.9338340114336121], 
             UndirectedEdge[21, 122] -> 
             RGBColor[
              0.3196137188420707, 0.44840534441475405`, 0.941690823915208], 
             UndirectedEdge[90, 175] -> 
             RGBColor[
              0.36392094666961883`, 0.4808157727668374, 0.9450400242191717], 
             UndirectedEdge[6, 179] -> 
             RGBColor[
              0.5999866512477183, 0.3681232043828395, 0.5612188243491484], 
             UndirectedEdge[8, 137] -> 
             RGBColor[
              0.3035782978311935, 0.4350100309623244, 0.94065098201274], 
             UndirectedEdge[3, 127] -> 
             RGBColor[
              0.6467401961046771, 0.7200341503582268, 0.9679094614906981], 
             UndirectedEdge[31, 65] -> 
             RGBColor[
              0.7441501726839835, 0.7476457221603776, 0.6205905714253708], 
             UndirectedEdge[3, 71] -> 
             RGBColor[
              0.3912157938817601, 0.5132731904080172, 0.9461489023409704], 
             UndirectedEdge[146, 184] -> 
             RGBColor[
              0.21360634880243462`, 0.34184419438906943`, 0.9354759376107997],
              UndirectedEdge[33, 99] -> 
             RGBColor[
              0.772222119980282, 0.8191247933841846, 0.8648855062678112], 
             UndirectedEdge[10, 130] -> 
             RGBColor[
              0.2011228825880777, 0.32872327990030753`, 0.9347650226775253], 
             UndirectedEdge[112, 160] -> 
             RGBColor[
              0.6923008271636373, 0.757058105759987, 0.9667604504602199], 
             UndirectedEdge[73, 157] -> 
             RGBColor[
              0.21195207893765056`, 0.34010545187441393`, 0.9353817293892732],
              UndirectedEdge[157, 188] -> 
             RGBColor[
              0.25981363557951725`, 0.389998962820171, 0.9381224602941154], 
             UndirectedEdge[70, 132] -> 
             RGBColor[
              0.2458080236877891, 0.37569019639768786`, 0.9373097753574117], 
             UndirectedEdge[141, 191] -> 
             RGBColor[
              0.5769597398249082, 0.6618980623518022, 0.9624179176414562], 
             UndirectedEdge[26, 80] -> 
             RGBColor[
              0.25728770840867865`, 0.387756072893393, 0.9379635264195947], 
             UndirectedEdge[171, 199] -> 
             RGBColor[
              0.6515054495303574, 0.7165517677858011, 0.834521559813894], 
             UndirectedEdge[23, 43] -> 
             RGBColor[
              0.2066925124128154, 0.33457731398103385`, 0.9350822048565153], 
             UndirectedEdge[75, 81] -> 
             RGBColor[
              0.40408609146348656`, 0.52284397744725, 0.9473444744525996], 
             UndirectedEdge[33, 172] -> 
             RGBColor[
              0.9309821433575884, 0.7454031597804265, 0.49229878616950506`], 
             UndirectedEdge[156, 166] -> 
             RGBColor[
              0.8112235131702088, 0.49573828454331076`, 0.5733146303469535], 
             UndirectedEdge[151, 175] -> 
             RGBColor[
              0.7472372281358932, 0.7985860801048122, 0.8522647687143463], 
             UndirectedEdge[34, 199] -> 
             RGBColor[
              0.7126589375138983, 0.7696119149432428, 0.8384148348758003], 
             UndirectedEdge[38, 169] -> 
             RGBColor[
              0.18660872237456455`, 0.31346797726499653`, 0.9339384627251416],
              UndirectedEdge[10, 142] -> 
             RGBColor[
              0.23997415505154454`, 0.3695584305723596, 0.9369775451690128], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.2876001150236012, 0.4192043144804547, 0.9397048591920434], 
             UndirectedEdge[12, 128] -> 
             RGBColor[
              0.6907043727279983, 0.6939382045780004, 0.6137063255291655], 
             UndirectedEdge[19, 172] -> 
             RGBColor[
              0.610278699777892, 0.48910830355495916`, 0.5781436227882895], 
             UndirectedEdge[109, 124] -> 
             RGBColor[
              0.22172315170383133`, 0.35037546887346516`, 0.9359381775283004],
              UndirectedEdge[75, 127] -> 
             RGBColor[
              0.6884648603869374, 0.7548482631907685, 0.9709344134676849], 
             UndirectedEdge[4, 191] -> 
             RGBColor[
              0.57220556825359, 0.6577802378883374, 0.9621149860328806], 
             UndirectedEdge[68, 172] -> 
             RGBColor[
              0.9151660280486694, 0.6898326684829248, 0.25782304770604947`], 
             UndirectedEdge[97, 105] -> 
             RGBColor[
              0.21127795983773054`, 0.3393969099587784, 0.9353433393038026], 
             UndirectedEdge[120, 136] -> 
             RGBColor[
              0.208375147270767, 0.3363458699019528, 0.9351780284224404], 
             UndirectedEdge[117, 159] -> 
             RGBColor[
              0.22010744675454766`, 0.3486772605301575, 0.9358461655216599], 
             UndirectedEdge[183, 192] -> 
             RGBColor[
              0.7010491462692232, 0.6813089979740284, 0.609376618188938], 
             UndirectedEdge[71, 188] -> 
             RGBColor[
              0.33847048120912504`, 0.4675878516274786, 0.9427880176583188], 
             UndirectedEdge[14, 106] -> 
             RGBColor[
              0.1821436488572793, 0.3087749018963175, 0.9336841833938165], 
             UndirectedEdge[141, 194] -> 
             RGBColor[
              0.2726689215363932, 0.40068025183184497`, 0.9389581857778003], 
             UndirectedEdge[50, 105] -> 
             RGBColor[
              0.2047516184167667, 0.33253731133139974`, 0.9349716738147356], 
             UndirectedEdge[98, 125] -> 
             RGBColor[
              0.22839213728314284`, 0.35738499555542924`, 0.936317966391162], 
             UndirectedEdge[118, 119] -> 
             RGBColor[
              0.6188466529284243, 0.4369505973479967, 0.5693002587660235], 
             UndirectedEdge[137, 166] -> 
             RGBColor[
              0.5638108664902101, 0.6507798896827761, 0.9614655012997908], 
             UndirectedEdge[6, 112] -> 
             RGBColor[
              0.8864219769798407, 0.5992192793709223, 0.5808969060575552], 
             UndirectedEdge[65, 119] -> 
             RGBColor[
              0.9015822198928265, 0.6126558094774612, 0.23867891450396542`], 
             UndirectedEdge[170, 183] -> 
             RGBColor[
              0.7957960380795266, 0.7580319632271744, 0.6169700142026149], 
             UndirectedEdge[14, 131] -> 
             RGBColor[
              0.18037616802655143`, 0.3069171674784653, 0.9335835279752602], 
             UndirectedEdge[9, 164] -> 
             RGBColor[
              0.1942433345387914, 0.32149243871196825`, 0.9343732425934977], 
             UndirectedEdge[96, 170] -> 
             RGBColor[
              0.7958122133360686, 0.8413363954975833, 0.9793915982124253], 
             UndirectedEdge[117, 178] -> 
             RGBColor[
              0.18448507974982858`, 0.3112358942196798, 0.9338175244193107], 
             UndirectedEdge[18, 24] -> 
             RGBColor[
              0.24010747998138166`, 0.3696985635269072, 0.9369851378265305], 
             UndirectedEdge[18, 133] -> 
             RGBColor[
              0.2360954570926359, 0.3654816730938921, 0.9367566590582723], 
             UndirectedEdge[49, 129] -> 
             RGBColor[
              0.4384127064842775, 0.5541214790792388, 0.9491648974977769], 
             UndirectedEdge[124, 198] -> 
             RGBColor[
              0.28583038245095216`, 0.4143466579357906, 0.9397138307273181], 
             UndirectedEdge[113, 124] -> 
             RGBColor[
              0.2152453236447654, 0.343566860865366, 0.9355692748034243], 
             UndirectedEdge[176, 188] -> 
             RGBColor[
              0.2736450723955902, 0.4045366798776089, 0.9389101401590136], 
             UndirectedEdge[37, 97] -> 
             RGBColor[
              0.22632286746697683`, 0.35521006177935477`, 0.9362001245363418],
              UndirectedEdge[77, 143] -> 
             RGBColor[
              0.8364908329957561, 0.5109365998950215, 0.5751565315064958], 
             UndirectedEdge[79, 84] -> 
             RGBColor[
              0.1877064038111327, 0.31462171005185247`, 0.93400097405908], 
             UndirectedEdge[151, 199] -> 
             RGBColor[
              0.9945819459025071, 0.992027509640117, 0.7394547080773856], 
             UndirectedEdge[48, 87] -> 
             RGBColor[
              0.21359836729039067`, 0.3418358053138541, 0.9354754830754963], 
             UndirectedEdge[27, 30] -> 
             RGBColor[
              0.2380433427297828, 0.3675290244016161, 0.9368675882636692], 
             UndirectedEdge[5, 87] -> 
             RGBColor[
              0.28551854391053016`, 0.41321354140814925`, 0.9397255599553038],
              UndirectedEdge[68, 81] -> 
             RGBColor[
              0.6335105972347094, 0.659531932623991, 0.6218491817852485], 
             UndirectedEdge[155, 172] -> 
             RGBColor[
              0.77126540629573, 0.6221045625124598, 0.590374002869697], 
             UndirectedEdge[143, 188] -> 
             RGBColor[
              0.5844325062491007, 0.6667240315758246, 0.9636365087359027], 
             UndirectedEdge[102, 180] -> 
             RGBColor[
              0.6556042618622065, 0.7236026240031248, 0.9400383889234916], 
             UndirectedEdge[80, 136] -> 
             RGBColor[
              0.2223027051927452, 0.3509846163361272, 0.9359711822421215], 
             UndirectedEdge[66, 78] -> 
             RGBColor[
              0.18323872675967784`, 0.30992589820368766`, 0.9337465464603355],
              UndirectedEdge[50, 101] -> 
             RGBColor[
              0.19997052243961871`, 0.3275120763204238, 0.9346993974718347], 
             UndirectedEdge[41, 85] -> 
             RGBColor[
              0.2805891206818358, 0.4122473345873495, 0.9392905073772007], 
             UndirectedEdge[5, 30] -> 
             RGBColor[
              0.28195013969393246`, 0.40946292232661013`, 0.9395223446141496],
              UndirectedEdge[32, 133] -> 
             RGBColor[
              0.21756503028546625`, 0.3460050196226384, 0.9357013786649139], 
             UndirectedEdge[159, 161] -> 
             RGBColor[
              0.2693600530686908, 0.4004448725619264, 0.938651028588549], 
             UndirectedEdge[3, 195] -> 
             RGBColor[
              0.4598624133064091, 0.5714358988511051, 0.9508809666262504], 
             UndirectedEdge[173, 180] -> 
             RGBColor[
              0.35489305397250803`, 0.4818122587326137, 0.9438344494728906], 
             UndirectedEdge[129, 141] -> 
             RGBColor[
              0.399143413415432, 0.5201083911550634, 0.9466626928679024], 
             UndirectedEdge[53, 199] -> 
             RGBColor[
              0.8135219538922576, 0.8521286416727499, 0.8461806318478537], 
             UndirectedEdge[88, 95] -> 
             RGBColor[
              0.23288032783126497`, 0.3621023683892223, 0.9365735622031948], 
             UndirectedEdge[93, 95] -> 
             RGBColor[
              0.24029230513765162`, 0.36989282648473865`, 0.9369956633457557],
              UndirectedEdge[3, 29] -> 
             RGBColor[
              0.312801857714541, 0.4359396148470296, 0.9414971783112978], 
             UndirectedEdge[52, 125] -> 
             RGBColor[
              0.2249359881773202, 0.35375236371269986`, 0.9361211438124999], 
             UndirectedEdge[82, 136] -> 
             RGBColor[
              0.21738866266974544`, 0.34581964607616317`, 0.935691334790111], 
             UndirectedEdge[116, 193] -> 
             RGBColor[
              0.2350445249483884, 0.36437707677734155`, 0.9366968100273723], 
             UndirectedEdge[19, 159] -> 
             RGBColor[
              0.30305438553170616`, 0.43193305004791277`, 0.9407136467817967],
              UndirectedEdge[77, 99] -> 
             RGBColor[
              0.6845698486919003, 0.3905794636160585, 0.5610392465826612], 
             UndirectedEdge[53, 196] -> 
             RGBColor[
              0.43238466744803844`, 0.5370813339950793, 0.9503675109966372], 
             UndirectedEdge[58, 137] -> 
             RGBColor[
              0.6422345288762541, 0.7125398822624958, 0.9467383481519487], 
             UndirectedEdge[159, 200] -> 
             RGBColor[
              0.22275289923247676`, 0.35145779881583583`, 0.9359968201266817],
              UndirectedEdge[3, 62] -> 
             RGBColor[
              0.30929718741563983`, 0.43225598415395333`, 0.9412975925224704],
              UndirectedEdge[48, 157] -> 
             RGBColor[
              0.20845932601251194`, 0.33643434709676723`, 0.9351828222772515],
              UndirectedEdge[130, 168] -> 
             RGBColor[
              0.19684636692721422`, 0.32422839079398647`, 0.9345214814371772],
              UndirectedEdge[140, 180] -> 
             RGBColor[
              0.6678780579649132, 0.7298281943728316, 0.7506032971167013], 
             UndirectedEdge[146, 171] -> 
             RGBColor[
              0.27657700131279794`, 0.4080303427474302, 0.9390620231145327], 
             UndirectedEdge[26, 100] -> 
             RGBColor[
              0.24928654570499661`, 0.3793463435888073, 0.9375078720402794], 
             UndirectedEdge[45, 153] -> 
             RGBColor[
              0.49664985237205533`, 0.594095769360721, 0.9556096261521655], 
             UndirectedEdge[165, 177] -> 
             RGBColor[
              0.2115965510366421, 0.3397317695086831, 0.9353614826012671], 
             UndirectedEdge[123, 139] -> 
             RGBColor[
              0.36839624794676656`, 0.4913743375109727, 0.9447729865968078], 
             UndirectedEdge[13, 34] -> 
             RGBColor[
              0.32558157650060693`, 0.44832121227099686`, 0.9422634355654279],
              UndirectedEdge[48, 72] -> 
             RGBColor[
              0.23184751916348642`, 0.3610168209955353, 0.9365147452774683], 
             UndirectedEdge[127, 191] -> 
             RGBColor[
              0.8424455031847746, 0.8772870526462687, 0.9848132059143445], 
             UndirectedEdge[58, 125] -> 
             RGBColor[
              0.6124298936125201, 0.6826137072843086, 0.9449897432593624], 
             UndirectedEdge[165, 169] -> 
             RGBColor[
              0.1989480925621131, 0.32643743769336697`, 0.9346411716028602], 
             UndirectedEdge[119, 156] -> 
             RGBColor[
              0.8327717722765755, 0.2529037791657479, 0.17901559218345872`], 
             UndirectedEdge[139, 191] -> 
             RGBColor[
              0.5478858450843187, 0.6345820068720615, 0.9606434803219044], 
             UndirectedEdge[48, 81] -> 
             RGBColor[
              0.2582618049415859, 0.3887799101107659, 0.938018999776097], 
             UndirectedEdge[85, 161] -> 
             RGBColor[
              0.2771499717006646, 0.408632570953499, 0.939094652930488], 
             UndirectedEdge[30, 106] -> 
             RGBColor[
              0.19729813455436623`, 0.32470322721384515`, 0.9345472089352131],
              UndirectedEdge[118, 195] -> 
             RGBColor[
              0.44594964518515734`, 0.559385358380535, 0.9499944573441421], 
             UndirectedEdge[132, 145] -> 
             RGBColor[
              0.24537934999545682`, 0.37523963316756476`, 0.9372853630247993],
              UndirectedEdge[124, 137] -> 
             RGBColor[
              0.27496483242396785`, 0.4049354646208403, 0.9390214874876273], 
             UndirectedEdge[53, 182] -> 
             RGBColor[
              0.48630804661931654`, 0.5907915717188752, 0.9535469913567178], 
             UndirectedEdge[31, 40] -> 
             RGBColor[
              0.5188959987209247, 0.6203021736168226, 0.9552685402794356], 
             UndirectedEdge[130, 157] -> 
             RGBColor[
              0.19536013163296237`, 0.32266626326696746`, 0.9344368425358576],
              UndirectedEdge[83, 166] -> 
             RGBColor[
              0.8650576677002866, 0.8953688994003288, 0.9869563023793746], 
             UndirectedEdge[76, 176] -> 
             RGBColor[
              0.24916812422626491`, 0.3792218751063049, 0.9375011281122546], 
             UndirectedEdge[100, 113] -> 
             RGBColor[
              0.20512211761839033`, 0.33292672948331237`, 0.9349927731961636],
              UndirectedEdge[53, 118] -> 
             RGBColor[
              0.5113253166726569, 0.612460273634525, 0.9551410696826135], 
             UndirectedEdge[18, 85] -> 
             RGBColor[
              0.24676983740924385`, 0.376701123601449, 0.9373645492259726], 
             UndirectedEdge[90, 177] -> 
             RGBColor[
              0.22233026933066752`, 0.35101358799275084`, 0.9359727519789987],
              UndirectedEdge[55, 165] -> 
             RGBColor[
              0.2708407078314586, 0.3994925742335291, 0.9388272003702323], 
             UndirectedEdge[9, 121] -> 
             RGBColor[
              0.20533326031636837`, 0.3331486538461075, 0.9350047974604558], 
             UndirectedEdge[70, 110] -> 
             RGBColor[
              0.185588460386286, 0.31239561722696946`, 0.9338803603142515], 
             UndirectedEdge[51, 147] -> 
             RGBColor[
              0.2158606236854452, 0.3442135802203963, 0.9356043152304863], 
             UndirectedEdge[81, 188] -> 
             RGBColor[
              0.3096161145085913, 0.44234452583416967`, 0.9409586377929611], 
             UndirectedEdge[63, 132] -> 
             RGBColor[
              0.24611904809652904`, 0.37601710277136, 0.9373274877373701], 
             UndirectedEdge[68, 143] -> 
             RGBColor[
              0.9083269889752188, 0.8839114383656459, 0.6445270527281901], 
             UndirectedEdge[76, 81] -> 
             RGBColor[
              0.28513916633926595`, 0.41702972106286573`, 0.9395496257462019],
              UndirectedEdge[55, 163] -> 
             RGBColor[
              0.3088204539598367, 0.4394116954694417, 0.9409900907262441], 
             UndirectedEdge[86, 94] -> 
             RGBColor[
              0.19625374198187168`, 0.3236055044018397, 0.9344877323232499], 
             UndirectedEdge[3, 167] -> 
             RGBColor[
              0.3090133882504993, 0.4319576932374843, 0.9412814305798589], 
             UndirectedEdge[16, 82] -> 
             RGBColor[
              0.19957038496874147`, 0.32709150646835083`, 0.9346766102348185],
              UndirectedEdge[51, 107] -> 
             RGBColor[
              0.1999147758321102, 0.3274534831013933, 0.9346962227850067], 
             UndirectedEdge[53, 171] -> 
             RGBColor[
              0.4697666933739579, 0.5763722134005581, 0.9524963620713668], 
             UndirectedEdge[78, 82] -> 
             RGBColor[
              0.1974481944602994, 0.3248609496893285, 0.9345557546248622], 
             UndirectedEdge[92, 186] -> 
             RGBColor[
              0.21375750066891208`, 0.34200306458431906`, 0.9354845454859864],
              UndirectedEdge[75, 118] -> 
             RGBColor[
              0.44650486801296785`, 0.559836113284655, 0.9500381665189955], 
             UndirectedEdge[77, 83] -> 
             RGBColor[
              0.8718524916829569, 0.5391330266655409, 0.5785293580798063], 
             UndirectedEdge[42, 176] -> 
             RGBColor[
              0.21842899524564835`, 0.34691310157433214`, 0.9357505801912747],
              UndirectedEdge[20, 144] -> 
             RGBColor[
              0.19040607844928842`, 0.31745923926581243`, 0.9341547165359123],
              UndirectedEdge[26, 98] -> 
             RGBColor[
              0.24264169185428053`, 0.372362180883637, 0.9371294574436615], 
             UndirectedEdge[16, 84] -> 
             RGBColor[
              0.1842053187530256, 0.3109418476741682, 0.933801592444412], 
             UndirectedEdge[55, 175] -> 
             RGBColor[
              0.4182247539712943, 0.5353839569381427, 0.9482243963930945], 
             UndirectedEdge[113, 128] -> 
             RGBColor[
              0.3178799957707601, 0.44011084120794086`, 0.9418290717409573], 
             UndirectedEdge[142, 147] -> 
             RGBColor[
              0.25576128412159904`, 0.3861517041867828, 0.9378765988145878], 
             UndirectedEdge[10, 42] -> 
             RGBColor[
              0.2103603093846907, 0.3384324011502344, 0.9352910804680441], 
             UndirectedEdge[98, 120] -> 
             RGBColor[
              0.19321962278041294`, 0.32041645274683817`, 0.9343149437233039],
              UndirectedEdge[195, 199] -> 
             RGBColor[
              0.748146282404758, 0.7990537264187598, 0.8410340195093824], 
             UndirectedEdge[49, 195] -> 
             RGBColor[
              0.46169316726810605`, 0.5730216059163575, 0.9509976206498176], 
             UndirectedEdge[25, 43] -> 
             RGBColor[
              0.1846430806166806, 0.3114019631485748, 0.9338265223349365], 
             UndirectedEdge[91, 121] -> 
             RGBColor[
              0.2017936925772753, 0.329428343730764, 0.9348032243140356], 
             UndirectedEdge[8, 21] -> 
             RGBColor[
              0.3222839501803989, 0.4512119268537823, 0.9418428896396724], 
             UndirectedEdge[2, 124] -> 
             RGBColor[
              0.20420540017012767`, 0.331963201321945, 0.9349405674936471], 
             UndirectedEdge[80, 125] -> 
             RGBColor[
              0.243038153837541, 0.3727788875651853, 0.9371520353670952], 
             UndirectedEdge[33, 180] -> 
             RGBColor[
              0.6673282092975037, 0.7309455392481101, 0.857462764837877], 
             UndirectedEdge[5, 155] -> 
             RGBColor[
              0.513762074533002, 0.612974284551854, 0.9559298924776924], 
             UndirectedEdge[179, 192] -> 
             RGBColor[
              0.41712722923071616`, 0.5353797878648794, 0.9478929556641686], 
             UndirectedEdge[59, 146] -> 
             RGBColor[
              0.21481341413912597`, 0.34311289659029465`, 0.935544678196031], 
             UndirectedEdge[3, 68] -> 
             RGBColor[
              0.6898421419054424, 0.7085746089319662, 0.625429383133753], 
             UndirectedEdge[131, 157] -> 
             RGBColor[
              0.19396001666235732`, 0.3211946536604452, 0.9343571080595661], 
             UndirectedEdge[85, 200] -> 
             RGBColor[
              0.23054281786445055`, 0.35964549720740835`, 0.9364404444686207],
              UndirectedEdge[23, 38] -> 
             RGBColor[
              0.20238106508142, 0.3300457094741879, 0.9348366743092069], 
             UndirectedEdge[92, 191] -> 
             RGBColor[
              0.5272753016690297, 0.6129190189586639, 0.9594697403649703], 
             UndirectedEdge[97, 153] -> 
             RGBColor[
              0.24952804077433757`, 0.37960017021835646`, 0.9375216248272185],
              UndirectedEdge[95, 161] -> 
             RGBColor[
              0.26651291559129975`, 0.397452350554246, 0.9384888883211739], 
             UndirectedEdge[139, 196] -> 
             RGBColor[
              0.25932712065835106`, 0.3898996244740037, 0.9380796679301735], 
             UndirectedEdge[1, 94] -> 
             RGBColor[
              0.18516334977200538`, 0.3119487990177908, 0.933856150893663], 
             UndirectedEdge[189, 194] -> 
             RGBColor[
              0.19797673225113377`, 0.32541647641872684`, 0.9345858540701487],
              UndirectedEdge[42, 76] -> 
             RGBColor[
              0.23350932118742207`, 0.36276348028702554`, 0.9366093824443157],
              UndirectedEdge[84, 190] -> 
             RGBColor[
              0.18271061576572617`, 0.30937082006487343`, 0.9337164713205002],
              UndirectedEdge[37, 134] -> 
             RGBColor[
              0.24135977409579584`, 0.37101480404118925`, 0.9370564541237432],
              UndirectedEdge[140, 161] -> 
             RGBColor[
              0.6387756152014612, 0.7023172809495201, 0.7488332700746612], 
             UndirectedEdge[10, 51] -> 
             RGBColor[
              0.20007349461539067`, 0.32762030660597313`, 0.9347052615849112],
              UndirectedEdge[146, 191] -> 
             RGBColor[
              0.527753699812846, 0.6134218457400091, 0.9594969844315341], 
             UndirectedEdge[21, 175] -> 
             RGBColor[
              0.43093748007980026`, 0.5463950813331377, 0.9490344400593063], 
             UndirectedEdge[49, 141] -> 
             RGBColor[
              0.3830851867065078, 0.5062308671290127, 0.9456308272413769], 
             UndirectedEdge[111, 177] -> 
             RGBColor[
              0.21876304030867405`, 0.3472642041152524, 0.9357696035634386], 
             UndirectedEdge[69, 191] -> 
             RGBColor[
              0.5299588162079603, 0.6157395628837288, 0.9596225625480584], 
             UndirectedEdge[111, 175] -> 
             RGBColor[
              0.36035371764762536`, 0.477066388889339, 0.9448368758036116], 
             UndirectedEdge[77, 170] -> 
             RGBColor[
              0.736263484492014, 0.4323498561130519, 0.5652433325739429], 
             UndirectedEdge[104, 154] -> 
             RGBColor[
              0.3494855423442635, 0.47712854394966536`, 0.9434898876136137], 
             UndirectedEdge[13, 138] -> 
             RGBColor[
              0.2214898027052646, 0.35013020428079056`, 0.9359248886480409], 
             UndirectedEdge[21, 67] -> 
             RGBColor[
              0.30859689738128643`, 0.43682596655264533`, 0.9410634322309431],
              UndirectedEdge[73, 197] -> 
             RGBColor[
              0.20909257444253643`, 0.33709993134699245`, 0.9352188848385342],
              UndirectedEdge[67, 192] -> 
             RGBColor[
              0.36080214724091136`, 0.4817069445731053, 0.944482904164054], 
             UndirectedEdge[37, 101] -> 
             RGBColor[
              0.21602037207300215`, 0.3443814859043514, 0.9356134126648311], 
             UndirectedEdge[6, 44] -> 
             RGBColor[
              0.8651034665131747, 0.43792568886884486`, 0.20749020660542072`],
              UndirectedEdge[75, 89] -> 
             RGBColor[
              0.3848285553772075, 0.5026030860222612, 0.9462477862614576], 
             UndirectedEdge[76, 188] -> 
             RGBColor[
              0.288725398337364, 0.42038705859030223`, 0.9397689424120548], 
             UndirectedEdge[42, 71] -> 
             RGBColor[
              0.2832544040591832, 0.40996427332420193`, 0.9396284576905798], 
             UndirectedEdge[6, 192] -> 
             RGBColor[
              0.6485736073804235, 0.40987019823777215`, 0.5644077418055113], 
             UndirectedEdge[2, 100] -> 
             RGBColor[
              0.19408219414375266`, 0.32132306993989135`, 0.9343640658863862],
              UndirectedEdge[7, 8] -> 
             RGBColor[
              0.24587927343278695`, 0.3757650843971754, 0.9373138329249848], 
             UndirectedEdge[69, 92] -> 
             RGBColor[
              0.2471305318648358, 0.3770802363436254, 0.937385090241619], 
             UndirectedEdge[104, 160] -> 
             RGBColor[
              0.4051454853105788, 0.5253383889970118, 0.9470364899612722], 
             UndirectedEdge[17, 30] -> 
             RGBColor[
              0.20051771286008008`, 0.3280872081462052, 0.9347305591567843], 
             UndirectedEdge[88, 164] -> 
             RGBColor[
              0.20586798703479003`, 0.3337106855308008, 0.9350352493560126], 
             UndirectedEdge[43, 60] -> 
             RGBColor[
              0.18536402715025152`, 0.3121597236660082, 0.9338675791734785], 
             UndirectedEdge[149, 197] -> 
             RGBColor[
              0.19310487903170026`, 0.3202958497917673, 0.934308409236563], 
             UndirectedEdge[167, 197] -> 
             RGBColor[
              0.20001986015557813`, 0.327563933388089, 0.9347022071817699], 
             UndirectedEdge[54, 127] -> 
             RGBColor[
              0.9315900923682865, 0.9377519849577597, 0.6986638549616266], 
             UndirectedEdge[107, 147] -> 
             RGBColor[
              0.23357883684934996`, 0.36283654565525925`, 0.9366133412584232],
              UndirectedEdge[78, 113] -> 
             RGBColor[
              0.19369232004858233`, 0.320913287546422, 0.9343418631334333], 
             UndirectedEdge[81, 87] -> 
             RGBColor[
              0.261366444859298, 0.3920430835098213, 0.9381958044265076], 
             UndirectedEdge[83, 179] -> 
             RGBColor[
              0.6474631282319623, 0.7188859236705143, 0.9687723771837091], 
             UndirectedEdge[82, 198] -> 
             RGBColor[
              0.2787942966052594, 0.4069512855983587, 0.9393131360473621], 
             UndirectedEdge[30, 107] -> 
             RGBColor[
              0.21359959388546113`, 0.3418370945430438, 0.935475552928271], 
             UndirectedEdge[47, 134] -> 
             RGBColor[
              0.22156708062371444`, 0.3502114282727843, 0.9359292895111742], 
             UndirectedEdge[5, 142] -> 
             RGBColor[
              0.3081659820767354, 0.43701743485134614`, 0.9410152980549868], 
             UndirectedEdge[169, 190] -> 
             RGBColor[
              0.18813962732028144`, 0.31507705542792475`, 0.9340256454970293],
              UndirectedEdge[121, 152] -> 
             RGBColor[
              0.20876932330272832`, 0.33676017390374813`, 0.9352004761643293],
              UndirectedEdge[31, 64] -> 
             RGBColor[
              0.5807463788000884, 0.6705150984929575, 0.9601376287646749], 
             UndirectedEdge[105, 134] -> 
             RGBColor[
              0.22631486646654955`, 0.35520165222061295`, 0.936199668891204], 
             UndirectedEdge[83, 192] -> 
             RGBColor[
              0.6960500843646674, 0.7606329175254469, 0.9719612946400722], 
             UndirectedEdge[77, 112] -> 
             RGBColor[
              0.8793649622811279, 0.5449759719930563, 0.5741391008123097], 
             UndirectedEdge[195, 196] -> 
             RGBColor[
              0.3670089959605389, 0.4840064187410893, 0.9452208986581658], 
             UndirectedEdge[92, 171] -> 
             RGBColor[
              0.2760986031689815, 0.40752751596608494`, 0.939034779047969], 
             UndirectedEdge[166, 183] -> 
             RGBColor[
              0.8700567296048425, 0.8160449798489104, 0.6243716259282402], 
             UndirectedEdge[139, 195] -> 
             RGBColor[
              0.39334997945867106`, 0.5116924625124413, 0.9467209787003914], 
             UndirectedEdge[177, 190] -> 
             RGBColor[
              0.20078808579481044`, 0.3283713872432409, 0.9347459564954362], 
             UndirectedEdge[29, 149] -> 
             RGBColor[
              0.19620729298920309`, 0.32355668356550876`, 0.9344850871218325],
              UndirectedEdge[119, 155] -> 
             RGBColor[
              0.7600079693502197, 0.5527750998573846, 0.5802673825214153], 
             UndirectedEdge[12, 162] -> 
             RGBColor[
              0.7007570533940699, 0.7026453313085301, 0.614346873451971], 
             UndirectedEdge[85, 173] -> 
             RGBColor[
              0.31911259241838086`, 0.4472823241494562, 0.941684119139965], 
             UndirectedEdge[92, 141] -> 
             RGBColor[
              0.29413145548178377`, 0.42323873581169885`, 0.9401804453350167],
              UndirectedEdge[5, 29] -> 
             RGBColor[
              0.28062241209504013`, 0.4080673964373824, 0.9394467324915896], 
             UndirectedEdge[51, 87] -> 
             RGBColor[
              0.19944978493815407`, 0.3269647481897199, 0.9346697422414884], 
             UndirectedEdge[145, 153] -> 
             RGBColor[
              0.2362249636187789, 0.3656177926640565, 0.9367640342633485], 
             UndirectedEdge[118, 191] -> 
             RGBColor[
              0.6004855108108049, 0.6822749027401551, 0.9639169589656551], 
             UndirectedEdge[117, 164] -> 
             RGBColor[
              0.19024796848068162`, 0.3172930556640557, 0.9341457124071029], 
             UndirectedEdge[145, 185] -> 
             RGBColor[
              0.2111217144827195, 0.33923268618413416`, 0.935334441361979], 
             UndirectedEdge[99, 137] -> 
             RGBColor[
              0.4378565391647805, 0.5509964805640466, 0.9498598035828838], 
             UndirectedEdge[48, 176] -> 
             RGBColor[
              0.2222907628285849, 0.3509720641542051, 0.9359705021421497], 
             UndirectedEdge[50, 144] -> 
             RGBColor[
              0.20111766579178803`, 0.32871779671664314`, 0.9347647255886942],
              UndirectedEdge[3, 53] -> 
             RGBColor[
              0.5252380847939087, 0.6245108141050952, 0.9560275789647218], 
             UndirectedEdge[169, 177] -> 
             RGBColor[
              0.20474146136299756`, 0.33252663562389395`, 0.9349710953855495],
              UndirectedEdge[20, 135] -> 
             RGBColor[
              0.18962988067563263`, 0.3166434061919189, 0.9341105132209843], 
             UndirectedEdge[166, 170] -> 
             RGBColor[
              0.7294686605093437, 0.78858572884784, 0.973670276873511], 
             UndirectedEdge[17, 42] -> 
             RGBColor[
              0.1971197095760292, 0.3245156912488159, 0.9345370478966529], 
             UndirectedEdge[129, 195] -> 
             RGBColor[
              0.47775139397703026`, 0.5868991299424082, 0.952029486276343], 
             UndirectedEdge[74, 93] -> 
             RGBColor[
              0.28865865838495014`, 0.4172909648985178, 0.9398759363681078], 
             UndirectedEdge[37, 45] -> 
             RGBColor[
              0.47344467906469456`, 0.5697056609217193, 0.9542881258612889], 
             UndirectedEdge[49, 92] -> 
             RGBColor[
              0.33340074855062923`, 0.45725182373587436`, 0.9426826499648912],
              UndirectedEdge[163, 177] -> 
             RGBColor[
              0.24957629716502022`, 0.3796508907445958, 0.937524372957279], 
             UndirectedEdge[6, 45] -> 
             RGBColor[
              0.7712380059237092, 0.5084025319316335, 0.5747836939863987], 
             UndirectedEdge[6, 166] -> 
             RGBColor[
              0.8175811907160426, 0.5446061801126542, 0.5794027495448137], 
             UndirectedEdge[65, 127] -> 
             RGBColor[
              0.9155629949478274, 0.8836888220171212, 0.6364016079465316], 
             UndirectedEdge[15, 59] -> 
             RGBColor[
              0.18157500733235693`, 0.30817722359966904`, 0.9336518001002019],
              UndirectedEdge[100, 136] -> 
             RGBColor[
              0.21430154248906313`, 0.3425748870315415, 0.9355155278628062], 
             UndirectedEdge[83, 183] -> 
             RGBColor[
              0.9313850452704695, 0.8648151337796632, 0.6302560397084783], 
             UndirectedEdge[53, 119] -> 
             RGBColor[
              0.7393045339916254, 0.5364394110009786, 0.5783146231887367], 
             UndirectedEdge[5, 68] -> 
             RGBColor[
              0.6576626962859415, 0.680702390522319, 0.6233789373140448], 
             UndirectedEdge[49, 54] -> 
             RGBColor[
              0.7053736220772657, 0.7563760825874686, 0.6787707713186126], 
             UndirectedEdge[153, 185] -> 
             RGBColor[
              0.2571534731580585, 0.38761498313398474`, 0.937955881920655], 
             UndirectedEdge[101, 144] -> 
             RGBColor[
              0.19734151181877715`, 0.32474881946901846`, 0.9345496792062504],
              UndirectedEdge[19, 102] -> 
             RGBColor[
              0.6601961515617699, 0.7275798880657995, 0.9403309800746991], 
             UndirectedEdge[102, 172] -> 
             RGBColor[
              0.9192581959222914, 0.7380602445354411, 0.5748744102551196], 
             UndirectedEdge[102, 140] -> 
             RGBColor[
              0.981449443808876, 0.9827573994159884, 0.747626675734739], 
             UndirectedEdge[71, 107] -> 
             RGBColor[
              0.2906858024537879, 0.41777514421480366`, 0.9400516648353837], 
             UndirectedEdge[5, 168] -> 
             RGBColor[
              0.2818657379269033, 0.4093742107180814, 0.9395175380583785], 
             UndirectedEdge[79, 122] -> 
             RGBColor[
              0.2360507899414387, 0.3654347250859229, 0.9367541153300909], 
             UndirectedEdge[136, 198] -> 
             RGBColor[
              0.2842178470642151, 0.4126517810036814, 0.9396219992225757], 
             UndirectedEdge[97, 135] -> 
             RGBColor[
              0.20686780943909605`, 0.33476156227012827`, 0.9350921877628332],
              UndirectedEdge[19, 164] -> 
             RGBColor[
              0.2731949072578401, 0.40054884518181094`, 0.9390131936672395], 
             UndirectedEdge[118, 139] -> 
             RGBColor[
              0.33826776988296947`, 0.4652785641134494, 0.9428532266161497], 
             UndirectedEdge[26, 137] -> 
             RGBColor[
              0.3083373002531643, 0.4400120442459969, 0.9409220001603581], 
             UndirectedEdge[142, 168] -> 
             RGBColor[
              0.23569763939068106`, 0.3650635414660385, 0.9367340039286646], 
             UndirectedEdge[3, 194] -> 
             RGBColor[
              0.3101074606435417, 0.43310763269076813`, 0.9413437363841075], 
             UndirectedEdge[65, 195] -> 
             RGBColor[
              0.7286852121495595, 0.7350905705099995, 0.6193731130820839], 
             UndirectedEdge[73, 107] -> 
             RGBColor[
              0.21755611110948542`, 0.34599564500317415`, 0.9357008707310365],
              UndirectedEdge[162, 172] -> 
             RGBColor[
              0.6603763668123606, 0.5325003847582571, 0.5813358018320983], 
             UndirectedEdge[68, 140] -> 
             RGBColor[
              0.977357275935254, 0.934529823363472, 0.4305753131856688], 
             UndirectedEdge[38, 165] -> 
             RGBColor[
              0.19346381204820906`, 0.3206731111497857, 0.9343288499408593], 
             UndirectedEdge[86, 92] -> 
             RGBColor[
              0.22327186579105107`, 0.35200326557327766`, 0.9360263745044504],
              UndirectedEdge[90, 115] -> 
             RGBColor[
              0.27114794471103404`, 0.4017434985665935, 0.9387741035720105], 
             UndirectedEdge[11, 70] -> 
             RGBColor[
              0.19700340773557554`, 0.3243934506405365, 0.9345304246788922], 
             UndirectedEdge[54, 123] -> 
             RGBColor[
              0.7197585780581139, 0.7688356084491694, 0.6796873679935951], 
             UndirectedEdge[107, 176] -> 
             RGBColor[
              0.22586039364025307`, 0.35472397246493387`, 0.9361737873360787],
              UndirectedEdge[30, 76] -> 
             RGBColor[
              0.23690732447147297`, 0.36633499718441476`, 0.936802893704447], 
             UndirectedEdge[129, 191] -> 
             RGBColor[
              0.632287259602678, 0.7097886743020284, 0.965951987897856], 
             UndirectedEdge[7, 125] -> 
             RGBColor[
              0.2363887212836201, 0.36578991235264013`, 0.9367733600201034], 
             UndirectedEdge[3, 155] -> 
             RGBColor[
              0.545941520152503, 0.6408465029615011, 0.9579803382974005], 
             UndirectedEdge[54, 118] -> 
             RGBColor[
              0.6896300999943169, 0.7427398350516461, 0.6777676080129371], 
             UndirectedEdge[4, 171] -> 
             RGBColor[
              0.3210288697535419, 0.4523887348957585, 0.9416800247158792], 
             UndirectedEdge[167, 189] -> 
             RGBColor[
              0.19688265985809134`, 0.32426653696544305`, 0.9345235482659], 
             UndirectedEdge[42, 81] -> 
             RGBColor[
              0.25440003735864936`, 0.3847209475308929, 0.9377990778252221], 
             UndirectedEdge[5, 129] -> 
             RGBColor[
              0.40440250690307966`, 0.5246635536043394, 0.9469977976545015], 
             UndirectedEdge[115, 133] -> 
             RGBColor[
              0.2820742314375166, 0.41322771868271746`, 0.939396339437091], 
             UndirectedEdge[92, 146] -> 
             RGBColor[
              0.24492541546972163`, 0.3747625191999059, 0.9372595121250946], 
             UndirectedEdge[65, 151] -> 
             RGBColor[
              0.9751208756473086, 0.9280643537313567, 0.5177938016500871], 
             UndirectedEdge[45, 156] -> 
             RGBColor[
              0.7648803283778755, 0.4595346363622902, 0.5686955747885385], 
             UndirectedEdge[74, 172] -> 
             RGBColor[
              0.607635645662135, 0.48681902292365303`, 0.5779752097171944], 
             UndirectedEdge[31, 138] -> 
             RGBColor[
              0.3769176966090809, 0.4907215889641815, 0.9461219362207016], 
             UndirectedEdge[116, 198] -> 
             RGBColor[
              0.29312560612523564`, 0.42201440056135886`, 0.9401292829232522],
              UndirectedEdge[42, 142] -> 
             RGBColor[
              0.23238403787365935`, 0.361580736177178, 0.9365452992243044], 
             UndirectedEdge[10, 129] -> 
             RGBColor[
              0.3362106798778888, 0.4572045493253528, 0.9429600447685274], 
             UndirectedEdge[3, 141] -> 
             RGBColor[
              0.38125443274481086`, 0.5046451600637603, 0.9455141732178098], 
             UndirectedEdge[161, 162] -> 
             RGBColor[
              0.3676199899888237, 0.4905318508026293, 0.94472975345843], 
             UndirectedEdge[6, 77] -> 
             RGBColor[
              0.8243760146987129, 0.18837030737786614`, 0.17097580524524553`],
              UndirectedEdge[98, 113] -> 
             RGBColor[
              0.19847726376767427`, 0.32594256677814204`, 0.9346143585995457],
              UndirectedEdge[3, 139] -> 
             RGBColor[
              0.3521805380042213, 0.47732910458401956`, 0.943739735898258], 
             UndirectedEdge[34, 138] -> 
             RGBColor[
              0.32596539118379714`, 0.4487246258382862, 0.9422852932438326], 
             UndirectedEdge[22, 72] -> 
             RGBColor[
              0.22084536933385682`, 0.34945286394800523`, 0.935888189120893], 
             UndirectedEdge[34, 40] -> 
             RGBColor[
              0.4679436932956409, 0.5783052104909272, 0.9514318973025666], 
             UndirectedEdge[41, 74] -> 
             RGBColor[
              0.31831841781976944`, 0.44846525260187575`, 0.9415650157902389],
              UndirectedEdge[141, 146] -> 
             RGBColor[
              0.2946098536256002, 0.4237415625930442, 0.9402076894015805], 
             UndirectedEdge[90, 111] -> 
             RGBColor[
              0.22370338980181498`, 0.3524568246687931, 0.9360509491584807], 
             UndirectedEdge[66, 82] -> 
             RGBColor[
              0.1977556445101682, 0.32518409918519964`, 0.9345732634503707], 
             UndirectedEdge[119, 151] -> 
             RGBColor[
              0.9203645260018751, 0.6763382789683456, 0.4715886994182685], 
             UndirectedEdge[4, 139] -> 
             RGBColor[
              0.30998782732575464`, 0.44078389926163164`, 0.9410512536833753],
              UndirectedEdge[165, 175] -> 
             RGBColor[
              0.35318722837559335`, 0.4695339542827697, 0.9444287548414402], 
             UndirectedEdge[127, 139] -> 
             RGBColor[
              0.5802277622569392, 0.660290714019563, 0.9637494735648391], 
             UndirectedEdge[85, 117] -> 
             RGBColor[
              0.22789736538652144`, 0.3568649589217301, 0.9362897898635989], 
             UndirectedEdge[141, 155] -> 
             RGBColor[
              0.5085029810453545, 0.6084191221025781, 0.9555947876910933], 
             UndirectedEdge[168, 189] -> 
             RGBColor[
              0.2019144551539962, 0.3295552728556873, 0.9348101015641277], 
             UndirectedEdge[24, 175] -> 
             RGBColor[
              0.3788592562848471, 0.49651688331597643`, 0.9458907388525104], 
             UndirectedEdge[106, 176] -> 
             RGBColor[
              0.20955893430915817`, 0.33759010513573523`, 0.9352454433430207],
              UndirectedEdge[40, 53] -> 
             RGBColor[
              0.5688067096740002, 0.6608219372204345, 0.9591976942746201], 
             UndirectedEdge[27, 155] -> 
             RGBColor[
              0.4698552775688525, 0.57104038662686, 0.953275136127212], 
             UndirectedEdge[33, 77] -> 
             RGBColor[
              0.9049712712883817, 0.5626723297681262, 0.46806425968515003`], 
             UndirectedEdge[67, 137] -> 
             RGBColor[
              0.289891245032081, 0.42062407066118745`, 0.9398715246040107], 
             UndirectedEdge[68, 129] -> 
             RGBColor[
              0.7077311225760636, 0.7240378400232692, 0.6265779027838456], 
             UndirectedEdge[137, 192] -> 
             RGBColor[
              0.3948032831545909, 0.5160439078078941, 0.9464704935604884], 
             UndirectedEdge[58, 128] -> 
             RGBColor[
              0.695941652480456, 0.7590582933299347, 0.9501605185766638], 
             UndirectedEdge[55, 90] -> 
             RGBColor[
              0.281574426125484, 0.41077439271759675`, 0.9394384697479637], 
             UndirectedEdge[26, 82] -> 
             RGBColor[
              0.2523736658856789, 0.382591102633429, 0.9376836789675842], 
             UndirectedEdge[43, 165] -> 
             RGBColor[
              0.19777525937960444`, 0.32520471565663167`, 0.9345743804881674],
              UndirectedEdge[123, 199] -> 
             RGBColor[
              0.7231925508928534, 0.7787356014172913, 0.8390860274057987], 
             UndirectedEdge[34, 45] -> 
             RGBColor[
              0.5705500737145661, 0.6605535414680137, 0.960228808821763], 
             UndirectedEdge[133, 178] -> 
             RGBColor[
              0.21638528695668868`, 0.3447650345840459, 0.9356341940276138], 
             UndirectedEdge[29, 189] -> 
             RGBColor[
              0.20067112932213305`, 0.3282484585749883, 0.9347392959973388], 
             UndirectedEdge[91, 164] -> 
             RGBColor[
              0.19070376679969833`, 0.3177721285966248, 0.9341716694470776], 
             UndirectedEdge[116, 124] -> 
             RGBColor[
              0.2333325075764587, 0.3625776379712726, 0.9365993131707435], 
             UndirectedEdge[80, 113] -> 
             RGBColor[
              0.2131232803220724, 0.34133645878789803`, 0.9354484275754789], 
             UndirectedEdge[10, 75] -> 
             RGBColor[
              0.3600463634895279, 0.4765554310665914, 0.9448364770954216], 
             UndirectedEdge[74, 180] -> 
             RGBColor[
              0.34398171160205027`, 0.4723614023913367, 0.9431391883855662], 
             UndirectedEdge[27, 149] -> 
             RGBColor[
              0.2260121645429709, 0.35488349330652136`, 0.9361824304644635], 
             UndirectedEdge[4, 49] -> 
             RGBColor[
              0.37833101513518963`, 0.5021130426655478, 0.9453278956328015], 
             UndirectedEdge[9, 152] -> 
             RGBColor[
              0.19674957296563292`, 0.32412665420327286`, 0.9345159691642588],
              UndirectedEdge[19, 85] -> 
             RGBColor[
              0.31084430416368, 0.44012074843948534`, 0.9411572711237357], 
             UndirectedEdge[189, 197] -> 
             RGBColor[
              0.19756871536463022`, 0.3249876248012469, 0.9345626181120692], 
             UndirectedEdge[69, 195] -> 
             RGBColor[
              0.3754229505823126, 0.4928500185241086, 0.9457000609265455], 
             UndirectedEdge[75, 191] -> 
             RGBColor[
              0.656122943214317, 0.729139556043267, 0.9678284202247502], 
             UndirectedEdge[73, 75] -> 
             RGBColor[
              0.3598107668197179, 0.47630780402892936`, 0.9448230602136101], 
             UndirectedEdge[68, 188] -> 
             RGBColor[
              0.6370968292328074, 0.6628892701514275, 0.6220684984511013], 
             UndirectedEdge[4, 123] -> 
             RGBColor[
              0.39271597111603795`, 0.5145725685272486, 0.946244492307784], 
             UndirectedEdge[7, 84] -> 
             RGBColor[
              0.19486465596415276`, 0.32214548692407674`, 0.9344086259295095],
              UndirectedEdge[171, 195] -> 
             RGBColor[
              0.4043910218864583, 0.5232972981465681, 0.9473497497328954], 
             UndirectedEdge[62, 167] -> 
             RGBColor[
              0.19961760381417978`, 0.3271411364687542, 0.9346792992782123], 
             UndirectedEdge[91, 152] -> 
             RGBColor[
              0.19321000522653986`, 0.3204063440879294, 0.9343143960178388], 
             UndirectedEdge[38, 90] -> 
             RGBColor[
              0.20419753034223448`, 0.33195492963385337`, 0.9349401193185908],
              UndirectedEdge[3, 118] -> 
             RGBColor[
              0.40478020373070756`, 0.5250220004521133, 0.9470132145420087], 
             UndirectedEdge[143, 181] -> 
             RGBColor[
              0.6469177981644729, 0.7208456508308313, 0.967618016283176], 
             UndirectedEdge[20, 50] -> 
             RGBColor[
              0.19303508907013, 0.32022249611721776`, 0.9343044348014965], 
             UndirectedEdge[128, 136] -> 
             RGBColor[
              0.3270594206414329, 0.44975899875617, 0.9423518264076001], 
             UndirectedEdge[19, 161] -> 
             RGBColor[
              0.3175223229543551, 0.44713976959933127`, 0.9415375744146212], 
             UndirectedEdge[19, 140] -> 
             RGBColor[
              0.6724699476644765, 0.7338054584355065, 0.7508958882679089], 
             UndirectedEdge[39, 159] -> 
             RGBColor[
              0.25347717812255377`, 0.3837509639611013, 0.9377465223569743], 
             UndirectedEdge[87, 154] -> 
             RGBColor[
              0.2742869255202454, 0.40348527807603907`, 0.9390098911632051], 
             UndirectedEdge[104, 143] -> 
             RGBColor[
              0.6113814534238254, 0.6900658551251025, 0.9653536718198579], 
             UndirectedEdge[6, 183] -> 
             RGBColor[
              0.8839085682862255, 0.5140524144919886, 0.22270248687391753`], 
             UndirectedEdge[17, 89] -> 
             RGBColor[
              0.229492018641594, 0.35854104059966735`, 0.9363806030073972], 
             UndirectedEdge[131, 176] -> 
             RGBColor[
              0.20779145347843028`, 0.335732370717883, 0.9351447879244643], 
             UndirectedEdge[44, 143] -> 
             RGBColor[
              0.8772182848102179, 0.7604919813860003, 0.611670932866671], 
             UndirectedEdge[140, 173] -> 
             RGBColor[
              0.6807382359191774, 0.7409670341454773, 0.7514227362841381], 
             UndirectedEdge[123, 195] -> 
             RGBColor[
              0.4760781232489544, 0.5854811317780583, 0.9519142173248001], 
             UndirectedEdge[96, 125] -> 
             RGBColor[
              0.600349784053201, 0.6736043813543324, 0.9654382177461185], 
             UndirectedEdge[95, 159] -> 
             RGBColor[
              0.2520449781686508, 0.3822456310028275, 0.9376649606883494], 
             UndirectedEdge[171, 191] -> 
             RGBColor[
              0.558926887512106, 0.6461868425061883, 0.9612722513544084], 
             UndirectedEdge[124, 187] -> 
             RGBColor[
              0.21475919139226923`, 0.3430559050454275, 0.935541590290813], 
             UndirectedEdge[54, 191] -> 
             RGBColor[
              0.899248175195666, 0.9120432778102582, 0.6955578617186919], 
             UndirectedEdge[24, 55] -> 
             RGBColor[
              0.29651273574071235`, 0.4264755032667358, 0.9402891843813024], 
             UndirectedEdge[61, 126] -> 
             RGBColor[
              0.19350305800530745`, 0.3207143611390335, 0.9343310849400568], 
             UndirectedEdge[46, 101] -> 
             RGBColor[
              0.18958670352767176`, 0.3165980242718227, 0.9341080543462827], 
             UndirectedEdge[158, 176] -> 
             RGBColor[
              0.27521608284831744`, 0.40589741017048, 0.9390102435558715], 
             UndirectedEdge[91, 200] -> 
             RGBColor[
              0.18842402865999922`, 0.3153759792680545, 0.9340418417325922], 
             UndirectedEdge[29, 129] -> 
             RGBColor[
              0.33069083838516217`, 0.4514028459383327, 0.9426456979613903], 
             UndirectedEdge[37, 47] -> 
             RGBColor[
              0.21605368220731502`, 0.34441649696749876`, 0.9356153096277022],
              UndirectedEdge[25, 38] -> 
             RGBColor[
              0.18033163328528526`, 0.30687035864172885`, 0.9335809917876283],
              UndirectedEdge[95, 173] -> 
             RGBColor[
              0.308475536309016, 0.4361021037502032, 0.9410783545306509], 
             UndirectedEdge[86, 174] -> 
             RGBColor[
              0.19606494632876875`, 0.3234070682000927, 0.9344769806901039], 
             UndirectedEdge[4, 146] -> 
             RGBColor[
              0.289855682054282, 0.41962373812957937`, 0.9399047577930049], 
             UndirectedEdge[114, 186] -> 
             RGBColor[
              0.18224157379578187`, 0.3088778272154834, 0.9336897600741974], 
             UndirectedEdge[155, 199] -> 
             RGBColor[
              0.8342253892508518, 0.868464330529156, 0.8481333911805324], 
             UndirectedEdge[114, 194] -> 
             RGBColor[
              0.19146855650738448`, 0.3185759710698711, 0.9342152230895253], 
             UndirectedEdge[59, 186] -> 
             RGBColor[
              0.18364549933831636`, 0.3103534419747078, 0.9337697115569229], 
             UndirectedEdge[99, 193] -> 
             RGBColor[
              0.3906410080149175, 0.5027703500949796, 0.9471196739266945], 
             UndirectedEdge[109, 136] -> 
             RGBColor[
              0.22011061631709428`, 0.3486805919413559, 0.935846346023558], 
             UndirectedEdge[50, 134] -> 
             RGBColor[
              0.22530992446241244`, 0.3541453944572617, 0.9361424389307468], 
             UndirectedEdge[112, 183] -> 
             RGBColor[
              0.9388975158686406, 0.8706580791071786, 0.6258657824409817], 
             UndirectedEdge[42, 73] -> 
             RGBColor[
              0.2101247127148807, 0.3381847741125724, 0.9352776635862325], 
             UndirectedEdge[42, 147] -> 
             RGBColor[
              0.22614743845474522`, 0.3550256747646575, 0.9361901341136192], 
             UndirectedEdge[87, 131] -> 
             RGBColor[
              0.19909905794023608`, 0.326596111877532, 0.934649768857811], 
             UndirectedEdge[1, 11] -> 
             RGBColor[
              0.19143609648975546`, 0.318541853533259, 0.9342133745395418], 
             UndirectedEdge[30, 81] -> 
             RGBColor[
              0.2577980406427003, 0.3882924644282822, 0.9379925890853533], 
             UndirectedEdge[154, 188] -> 
             RGBColor[
              0.3225365951695387, 0.45378672040038737`, 0.9417727245296585], 
             UndirectedEdge[83, 156] -> 
             RGBColor[
              0.8725518288358358, 0.5445084384740636, 0.5791990441271917], 
             UndirectedEdge[5, 107] -> 
             RGBColor[
              0.28598353480448624`, 0.4137022763198226, 0.9397520404988222], 
             UndirectedEdge[93, 180] -> 
             RGBColor[
              0.28670982280114365`, 0.41560298146714914`, 0.9397517582879953],
              UndirectedEdge[10, 17] -> 
             RGBColor[
              0.2047098267539144, 0.3324933856439975, 0.9349692938413614], 
             UndirectedEdge[75, 141] -> 
             RGBColor[
              0.42297909702707115`, 0.5394592728963019, 0.9485391251947967], 
             UndirectedEdge[123, 141] -> 
             RGBColor[
              0.39747014268735614`, 0.5186903929907134, 0.9465474239163595], 
             UndirectedEdge[40, 119] -> 
             RGBColor[
              0.6763280459297676, 0.4853122609339061, 0.5733568833580303], 
             UndirectedEdge[16, 80] -> 
             RGBColor[
              0.20448442749174123`, 0.3322564767283148, 0.934956457686829], 
             UndirectedEdge[88, 180] -> 
             RGBColor[
              0.279297845494757, 0.4078125233716327, 0.9393296571454344], 
             UndirectedEdge[24, 41] -> 
             RGBColor[
              0.2739267632539736, 0.4052447745128077, 0.9389110959777585], 
             UndirectedEdge[4, 119] -> 
             RGBColor[
              0.5905667103712094, 0.4124559324961789, 0.5674982858332491], 
             UndirectedEdge[99, 136] -> 
             RGBColor[
              0.3873164552562508, 0.49927603435680146`, 0.9469303455653235], 
             UndirectedEdge[10, 194] -> 
             RGBColor[
              0.20973618799885002`, 0.33777641000213443`, 0.9352555376784253],
              UndirectedEdge[96, 102] -> 
             RGBColor[
              0.9527960526971394, 0.9643159539076722, 0.964788149409247], 
             UndirectedEdge[9, 88] -> 
             RGBColor[
              0.20493816247527158`, 0.3327333809644648, 0.9349822972229003], 
             UndirectedEdge[55, 108] -> 
             RGBColor[
              0.3219524714198415, 0.4532142784379034, 0.9417379396935124], 
             UndirectedEdge[62, 197] -> 
             RGBColor[
              0.20030365932071864`, 0.327862224304558, 0.9347183691243814], 
             UndirectedEdge[147, 168] -> 
             RGBColor[
              0.22946103997176695`, 0.35850848005351804`, 0.9363788388179795],
              UndirectedEdge[51, 106] -> 
             RGBColor[
              0.1836133165010153, 0.31031961577219463`, 0.9337678787919488], 
             UndirectedEdge[123, 155] -> 
             RGBColor[
              0.5621572300950483, 0.6548917358884543, 0.9590135889959501], 
             UndirectedEdge[75, 142] -> 
             RGBColor[
              0.3820700919784965, 0.49970376609353495`, 0.9460906958516819], 
             UndirectedEdge[31, 182] -> 
             RGBColor[
              0.43639733566624106`, 0.5502718081152633, 0.9496178373615334], 
             UndirectedEdge[65, 140] -> 
             RGBColor[
              0.9750309047249213, 0.9266824270130837, 0.4215378003318664]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 71 -> 
             RGBColor[
              0.3637386159115608, 0.4894738398933511, 0.9443980808578237], 10 -> 
             RGBColor[
              0.2179504265625759, 0.34641009554541596`, 0.9357233264127526], 
             68 -> RGBColor[
              0.9609913119589255, 0.8800766769412489, 0.30295904244338884`], 
             155 -> RGBColor[
              0.6731900684530466, 0.744620465000319, 0.9680609527706839], 132 -> 
             RGBColor[
              0.30056549504747376`, 0.4332437706209237, 0.9404281323449262], 
             26 -> RGBColor[
              0.2927822195605681, 0.4250630545960175, 0.9399848863202711], 29 -> 
             RGBColor[
              0.20691074357712266`, 0.33480668877137576`, 0.9350946327984784],
              113 -> RGBColor[
              0.20445336338735556`, 0.33222382638502757`, 0.9349546886320393],
              50 -> RGBColor[
              0.20374667641262958`, 0.33148105356804847`, 0.9349144438542785],
              173 -> RGBColor[
              0.36775323192677223`, 0.4929510985052593, 0.9446538886403275], 
             192 -> RGBColor[
              0.46571418536342124`, 0.577126781719812, 0.9510818731205317], 
             165 -> RGBColor[
              0.2058031822357576, 0.33364257157815613`, 0.9350315588185778], 
             92 -> 
             RGBColor[
              0.2444470173259052, 0.37425969241856055`, 0.9372322680585309], 
             11 -> RGBColor[
              0.20295626314304663`, 0.3306502791066209, 0.9348694309878873], 
             137 -> RGBColor[
              0.32389238094576056`, 0.45496103389597625`, 0.9418591140004451],
              120 -> RGBColor[
              0.1939380814128329, 0.3211715983224198, 0.934355858879556], 51 -> 
             RGBColor[
              0.18219656266820544`, 0.3088305176665303, 0.9336871967570698], 
             72 -> RGBColor[
              0.2532013109542942, 0.38346101007627187`, 0.9377308121298508], 
             64 -> RGBColor[
              0.6295309817704698, 0.7101206369056319, 0.9639781314143923], 41 -> 
             RGBColor[
              0.29070628845368207`, 0.422881119381046, 0.9398666651147989], 
             103 -> RGBColor[
              0.1810808656124072, 0.3076578493216073, 0.933623659460268], 162 -> 
             RGBColor[
              0.4514119894863078, 0.5654121094919137, 0.9499845506954865], 
             196 -> RGBColor[
              0.23298613716021888`, 0.3622135807026517, 0.9365795878879478], 
             179 -> RGBColor[
              0.3685402730980111, 0.49363279400994686`, 0.9447040382078057], 
             160 -> RGBColor[
              0.44319072976501883`, 0.5582912675338615, 0.9494606992958204], 
             123 -> RGBColor[
              0.4511243917370499, 0.5651630067765897, 0.9499662252212164], 
             150 -> RGBColor[
              0.19256204953176445`, 0.3197253015699566, 0.9342774958995859], 
             188 -> RGBColor[
              0.31320234650668927`, 0.4457018633616062, 0.9411779544588138], 
             46 -> RGBColor[
              0.18297903858873563`, 0.3096529494708463, 0.9337317576031746], 
             182 -> RGBColor[
              0.34083289550277507`, 0.46963405615024345`, 0.9429385486081092],
              6 -> RGBColor[
              0.8314330293974257, 0.24261361475573226`, 0.17773361049049105`],
              131 -> RGBColor[
              0.1814951086723694, 0.3080932450421545, 0.9336472499897152], 45 -> 
             RGBColor[
              0.7110429824499928, 0.7741914491075349, 0.9718337774823064], 
             195 -> RGBColor[
              0.5010318547608589, 0.6057992567795268, 0.9538622094283838], 
             148 -> RGBColor[
              0.19357697366818166`, 0.320792051187238, 0.9343352943277091], 
             161 -> RGBColor[
              0.2838279904913397, 0.4156515921133449, 0.9394749562213734], 1 -> 
             RGBColor[
              0.17991592983646426`, 0.30643342795989703`, 0.9335573180911961],
              101 -> RGBColor[
              0.19619436846660787`, 0.3235430990727991, 0.9344843510893909], 
             12 -> RGBColor[
              0.950102117301832, 0.8398785531251466, 0.2787091962084557], 39 -> 
             RGBColor[
              0.25206224059906557`, 0.3822637749116947, 0.9376659437582241], 
             48 -> RGBColor[
              0.21049372737267863`, 0.3385726319147987, 0.9352986784250858], 
             77 -> RGBColor[0.817319, 0.134127, 0.164218], 56 -> 
             RGBColor[
              0.1825695689347496, 0.30922257090263144`, 0.9337084389121362], 
             110 -> RGBColor[
              0.18012636844446756`, 0.30665461227948687`, 0.9335693022586058],
              73 -> RGBColor[
              0.21747923322295587`, 0.34591484147009205`, 0.9356964926491292],
              37 -> RGBColor[
              0.23584637567939642`, 0.36521987273590373`, 0.9367424742402714],
              130 -> RGBColor[
              0.1842953386135795, 0.3110364642551991, 0.933806718942298], 107 -> 
             RGBColor[
              0.21763298899601496`, 0.34607644853625624`, 0.9357052488129437],
              59 -> RGBColor[
              0.18422301466471383`, 0.3109604471993381, 0.9338026002004038], 
             47 -> RGBColor[
              0.1962609887352336, 0.32361312119909375`, 0.9344881450151332], 
             159 -> RGBColor[
              0.2548921156460419, 0.3852381530105079, 0.9378271009557244], 55 -> 
             RGBColor[
              0.33587823342715956`, 0.465342576888902, 0.9426228419218866], 
             49 -> RGBColor[
              0.4223544797753533, 0.5402439550531881, 0.9481330318712514], 82 -> 
             RGBColor[
              0.21196511221078973`, 0.3401191506708405, 0.9353824716148974], 
             199 -> RGBColor[
              0.995260710048657, 0.9923081960579929, 0.7282058295903809], 89 -> 
             RGBColor[
              0.2675148103379351, 0.39850540545675567`, 0.9385459447448243], 
             144 -> RGBColor[
              0.19848865517094644`, 0.32595453986523776`, 0.93461500732311], 
             78 -> RGBColor[
              0.18293127670980908`, 0.3096027487078165, 0.9337290376348271], 
             42 -> RGBColor[
              0.2027701922068055, 0.3304547067550528, 0.9348588345233357], 
             154 -> RGBColor[
              0.33187084383238813`, 0.46187157743916857`, 0.9423674946005033],
              168 -> RGBColor[
              0.20939739524084894`, 0.3374203173327738, 0.9352362439320562], 
             121 -> RGBColor[
              0.21735301065346377`, 0.34578217354658275`, 0.9356893044605262],
              128 -> RGBColor[
              0.43130662815416465`, 0.5479978560308542, 0.9487034548498753], 
             115 -> RGBColor[
              0.31502527059825963`, 0.4472807885868956, 0.9412941095699802], 
             61 -> RGBColor[
              0.2073405252862433, 0.3352584165973958, 0.9351191082310077], 93 -> 
             RGBColor[
              0.23138676958404353`, 0.3605325439743302, 0.9364885062705369], 
             88 -> RGBColor[
              0.21656281497127022`, 0.34495162778329735`, 0.9356443039854151],
              21 -> RGBColor[
              0.36130368564417137`, 0.48736482567889206`, 0.94424292925431], 
             62 -> RGBColor[
              0.1999014029793203, 0.32743942738522325`, 0.9346954612208237], 
             136 -> RGBColor[
              0.22281221312870114`, 0.35152014148148586`, 0.9360001979653247],
              190 -> RGBColor[
              0.1841862517520943, 0.3109218070472717, 0.933800506606916], 57 -> 
             RGBColor[
              0.1818396285304826, 0.30845535725685214`, 0.9336668698859633], 
             111 -> RGBColor[
              0.2201361607798215, 0.3487074407912947, 0.9358478007429207], 63 -> 
             RGBColor[
              0.19167260114558432`, 0.31879043492179643`, 0.9342268431298139],
              75 -> RGBColor[
              0.5021423004164799, 0.6067007665877667, 0.9539496277780908], 30 -> 
             RGBColor[
              0.2095661987749073, 0.33759774054983127`, 0.9352458570435983], 
             5 -> RGBColor[
              0.35433408061295757`, 0.481328104103389, 0.9437988321847008], 
             171 -> RGBColor[
              0.30775018901205775`, 0.44079533951360933`, 0.940837290037407], 
             102 -> RGBColor[
              0.9691756477061694, 0.9765318290462814, 0.9370617675415293], 31 -> 
             RGBColor[
              0.531961775829707, 0.6309095600802831, 0.9562971261149575], 96 -> 
             RGBColor[
              0.9364164576881094, 0.9521000787690629, 0.9925145312769647], 70 -> 
             RGBColor[
              0.19105055232810444`, 0.31813662217445204`, 0.9341914183698972],
              52 -> RGBColor[
              0.18558886593634766`, 0.31239604348579764`, 0.9338803834097276],
              183 -> RGBColor[
              0.9363841071750253, 0.7854912142282449, 0.26767136325734403`], 
             158 -> 
             RGBColor[
              0.3163443674121438, 0.4484233239473484, 0.9413781612525294], 13 -> 
             RGBColor[
              0.22110598802207443`, 0.3497267907135012, 0.9359030309696362], 
             170 -> RGBColor[
              0.6552079689840278, 0.7305727122261038, 0.9662686651478858], 86 -> 
             RGBColor[
              0.2020967142561969, 0.3297468387279948, 0.9348204809503698], 18 -> 
             RGBColor[
              0.22306772190849825`, 0.3517886974092449, 0.9360147488123428], 
             153 -> RGBColor[
              0.2822567222941179, 0.41400008961390705`, 0.9393854748220246], 
             58 -> RGBColor[
              0.9605766768067475, 0.9701187306290152, 0.9516175823034524], 22 -> 
             RGBColor[
              0.18848942771341942`, 0.31544471781973865`, 0.9340455661119352],
              66 -> RGBColor[
              0.18354617680954663`, 0.31024904769955874`, 0.9337640552858439],
              143 -> RGBColor[
              0.8556626659915121, 0.887746199790043, 0.9860950630129915], 119 -> 
             RGBColor[
              0.8468258702473929, 0.3609297347144502, 0.19247381227214683`], 
             145 -> RGBColor[
              0.1901932049434399, 0.31723549571420584`, 0.9341425937046723], 
             91 -> RGBColor[
              0.18623437450108682`, 0.31307451391494534`, 0.9339171441675451],
              177 -> RGBColor[
              0.21738991983752656`, 0.34582096743921015`, 0.9356914063839564],
              200 -> RGBColor[
              0.1906136828189116, 0.3176774446211637, 0.9341665392976392], 
             114 -> RGBColor[
              0.18141516357964482`, 0.30800921768088935`, 0.9336426972349526],
              24 -> RGBColor[
              0.2571472380542651, 0.3876084296445695, 0.9379555268407181], 
             176 -> RGBColor[
              0.23408779828449117`, 0.3633714963936115, 0.9366423258592136], 
             79 -> RGBColor[
              0.1941778278429074, 0.3214235870212298, 0.9343695120840757], 
             109 -> RGBColor[
              0.21740901950548744`, 0.34584104240122593`, 0.9356924940817913],
              135 -> RGBColor[
              0.1969362596236349, 0.3243228737174507, 0.934526600693254], 108 -> 
             RGBColor[
              0.3080267094125234, 0.4410859799869048, 0.9408530374651383], 
             191 -> RGBColor[
              0.8101035860121542, 0.8515783454987672, 0.9817072126714098], 14 -> 
             RGBColor[
              0.17925722738073346`, 0.3057410899147761, 0.9335198059608052], 
             185 -> 
             RGBColor[
              0.2320502240219991, 0.3612298766540624, 0.9365262890192856], 32 -> 
             RGBColor[
              0.186006868294159, 0.3128353904667376, 0.9339041880256258], 122 -> 
             RGBColor[
              0.27792375203997, 0.40944586315061604`, 0.939138718576106], 187 -> 
             RGBColor[
              0.20348109888236326`, 0.33120191474515054`, 0.9348993196068165],
              193 -> RGBColor[
              0.22946131864603458`, 0.3585087729578423, 0.9363788546880667], 
             100 -> RGBColor[
              0.20579087184942513`, 0.3336296325815971, 0.9350308577602878], 
             180 -> RGBColor[
              0.3420328760182438, 0.47067341895996806`, 0.9430150103054538], 
             7 -> RGBColor[
              0.20849433214894747`, 0.33647114076567824`, 0.9351848158249345],
              175 -> RGBColor[
              0.5005712745154292, 0.6054253369873833, 0.9538259508643026], 9 -> 
             RGBColor[
              0.19331350997927296`, 0.32051513414563226`, 0.9343202904603853],
              90 -> RGBColor[
              0.22727061882380845`, 0.3562062085462915, 0.9362540975740409], 
             174 -> RGBColor[
              0.19003317840134057`, 0.3170672976721906, 0.9341334804298378], 
             142 -> RGBColor[
              0.2619978835405132, 0.39270676559930323`, 0.938231763925273], 
             134 -> RGBColor[
              0.24687317251219526`, 0.37680973534647483`, 0.9373704340072151],
              105 -> RGBColor[
              0.20575656042090384`, 0.333593569094751, 0.9350289037751928], 
             16 -> RGBColor[
              0.1871756577266932, 0.3140638622658612, 0.9339707488547396], 
             139 -> RGBColor[
              0.28566810415648325`, 0.4175856682453557, 0.9395797479723991], 
             146 -> RGBColor[
              0.24540381361353808`, 0.37526534598125116`, 0.9372867561916584],
              126 -> RGBColor[
              0.1796655907243716, 0.3061703056806712, 0.9335430616491059], 
             198 -> RGBColor[
              0.34562348099972906`, 0.47378342052587685`, 0.9432438004798267],
              40 -> RGBColor[
              0.5058302216121423, 0.609694787153362, 0.9542399544439137], 104 -> 
             RGBColor[
              0.36710024085613885`, 0.49238551046016216`, 0.9446122806267241],
              181 -> RGBColor[
              0.43817293033743376`, 0.5539451018716196, 0.9491409695533606], 
             127 -> RGBColor[
              0.874787420357395, 0.9029957597937702, 0.9879191991572792], 76 -> 
             RGBColor[
              0.26424845016803866`, 0.3950722538189983, 0.9383599303652956], 
             172 -> RGBColor[
              0.8693407441384133, 0.4995886600246006, 0.2126870529687101], 84 -> 
             RGBColor[
              0.181234979779358, 0.3078198330824752, 0.9336324360340843], 184 -> 
             RGBColor[
              0.1818088839913312, 0.30842304279688765`, 0.933665119029941], 
             151 -> RGBColor[
              0.9939031817563573, 0.9917468232222412, 0.7507035865643902], 35 -> 
             RGBColor[
              0.18077756667952594`, 0.30733906291288604`, 0.933606387034731], 
             36 -> RGBColor[
              0.18255152448721731`, 0.309203605044191, 0.9337074113075435], 
             34 -> RGBColor[
              0.4300571649791395, 0.5469156338284925, 0.9486238401612196], 38 -> 
             RGBColor[
              0.18112444186066054`, 0.30770365072141526`, 0.9336261410631407],
              54 -> RGBColor[
              0.988392764379178, 0.9725082101217492, 0.4094085107659739], 60 -> 
             RGBColor[
              0.18098071777705174`, 0.3075525875969092, 0.9336179561892], 87 -> 
             RGBColor[
              0.21670300720810273`, 0.3450989787129095, 0.9356522877259069], 
             141 -> RGBColor[
              0.34381589363766235`, 0.47221777920483715`, 0.9431286226115025],
              67 -> RGBColor[
              0.2558901091184015, 0.3862871074263986, 0.9378839352075763], 
             133 -> RGBColor[
              0.24912319227677354`, 0.3791746487785393, 0.937498569304202], 
             98 -> RGBColor[
              0.19250116414799295`, 0.31966130717125646`, 0.9342740285670519],
              3 -> RGBColor[
              0.4186929718519593, 0.5370725409226834, 0.947899723824117], 27 -> 
             RGBColor[
              0.26652048668465833`, 0.39746030825340095`, 0.9384893194837403],
              163 -> RGBColor[
              0.2817626744925139, 0.41348081404998144`, 0.9393573395306015], 
             85 -> RGBColor[
              0.2704719529099895, 0.40161354979365305`, 0.9387143496396024], 
             83 -> RGBColor[
              0.9263859833659136, 0.9441390533310817, 0.9928407161596127], 28 -> 
             RGBColor[
              0.1792907180836107, 0.3057762907669333, 0.933521713206789], 44 -> 
             RGBColor[
              0.8987739036289236, 0.6332377629819576, 0.2372468027203504], 
             189 -> RGBColor[
              0.19443151506714343`, 0.3216902283786009, 0.9343839591961993], 
             15 -> RGBColor[0.178927, 0.305394, 0.933501], 80 -> 
             RGBColor[
              0.22179319725678925`, 0.3504490911907685, 0.9359421665189183], 
             112 -> RGBColor[
              0.9414109245622558, 0.9558249439861124, 0.9840602016246193], 
             169 -> RGBColor[
              0.19209300288846856`, 0.31923230380857776`, 0.9342507843871425],
              69 -> RGBColor[
              0.24981404640376637`, 0.37990078026869034`, 0.9375379124247071],
              20 -> RGBColor[
              0.1823235017276304, 0.3089639386663871, 0.9336944257487145], 8 -> 
             RGBColor[
              0.28326421471662644`, 0.41505902802867256`, 0.939442850025035], 
             116 -> RGBColor[
              0.24062773125074222`, 0.3702453805968408, 0.9370147653666777], 
             97 -> RGBColor[
              0.21679935925455723`, 0.3452002508228058, 0.9356577748324124], 
             118 -> RGBColor[
              0.39086743560945575`, 0.5129714599815431, 0.9461267052599003], 
             178 -> RGBColor[
              0.1836473816366038, 0.3103554203895525, 0.9337698187510258], 81 -> 
             RGBColor[
              0.30602988251049323`, 0.4389871883067331, 0.9407393211271083], 
             166 -> RGBColor[
              0.8037293520346596, 0.846598745469576, 0.9810718885991364], 125 -> 
             RGBColor[
              0.2642831104182927, 0.3951086839396021, 0.9383619042152723], 95 -> 
             RGBColor[
              0.24919784069125972`, 0.37925310899514714`, 0.9375028204209744],
              157 -> RGBColor[
              0.20642492465234524`, 0.3342960622787358, 0.9350669661294171], 
             74 -> RGBColor[
              0.34593054718585675`, 0.47404938582270545`, 0.9432633664656788],
              19 -> RGBColor[
              0.35121665541737046`, 0.47862794708531764`, 0.9436001926078689],
              156 -> RGBColor[
              0.8187176743057581, 0.14487782361704554`, 0.16555737209477062`],
              167 -> RGBColor[
              0.19933380464903927`, 0.32684284555228516`, 0.9346631373356007],
              33 -> RGBColor[
              0.9926235425767636, 0.9912176595362523, 0.7719105193703001], 43 -> 
             RGBColor[
              0.18974733652345127`, 0.3167668597351072, 0.9341172021577572], 
             140 -> RGBColor[
              0.9937232399115826, 0.9889829697856952, 0.5581915839279488], 
             186 -> RGBColor[
              0.18306798401191893`, 0.3097464367500775, 0.933736822913442], 
             117 -> 
             RGBColor[
              0.1853227778630534, 0.31211636804980714`, 0.9338652300875955], 
             4 -> RGBColor[
              0.33430755049502603`, 0.4639821302779076, 0.9425227593943515], 
             106 -> RGBColor[
              0.18503007033382515`, 0.31180871387785897`, 0.9338485608268279],
              65 -> RGBColor[
              0.95633856953826, 0.8643818842404721, 0.284884016735784], 53 -> 
             RGBColor[
              0.631783197735858, 0.7119490872875069, 0.9641554341053266], 2 -> 
             RGBColor[
              0.18237351643808017`, 0.30901650729818564`, 0.9336972740124846],
              147 -> RGBColor[
              0.24952468470268496`, 0.3795966427742623, 0.9375214337039027], 
             94 -> RGBColor[
              0.19041076970754647`, 0.3174641700756846, 0.9341549836961299], 
             23 -> RGBColor[
              0.22363768830217948`, 0.3523877682269605, 0.9360472075552733], 
             194 -> RGBColor[
              0.2015219494351241, 0.32914272445885284`, 0.9347877489440981], 
             129 -> RGBColor[
              0.4544709331932017, 0.5679990031052896, 0.9501967631243022], 99 -> 
             RGBColor[
              0.5518206973838005, 0.647031927232117, 0.9578604931653224], 25 -> 
             RGBColor[
              0.17953882470990998`, 0.3060370665620425, 0.9335358425121159], 
             138 -> RGBColor[
              0.2218736173884548, 0.35053361784807985`, 0.9359467463264457], 
             124 -> RGBColor[
              0.2260372839021752, 0.3549098953457044, 0.9361838609748094], 
             197 -> RGBColor[
              0.20070591566211698`, 0.3282850212238928, 0.9347412770279392], 
             164 -> RGBColor[
              0.19517315909830985`, 0.32246974327830424`, 0.9344261947266101],
              152 -> RGBColor[
              0.20018563595199287`, 0.32773817426091345`, 0.9347116478681324],
              17 -> RGBColor[
              0.19146922694525287`, 0.31857667574257903`, 0.9342152612699701],
              149 -> RGBColor[
              0.1855038424012835, 0.31230667835964177`, 
               0.9338755414451867]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw1Vnk41Iv7HWbGjH3MjDGYYWbMlDYVokV9jgp1K023DRVaCFlSpNQNyVKW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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 11}], {
             RGBColor[
             0.19143609648975546`, 0.318541853533259, 0.9342133745395418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 35}], {
             RGBColor[
             0.1803467482579951, 0.30688624543639154`, 0.9335818525629636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 86}], {
             RGBColor[
             0.19100632204633058`, 0.3180901333439459, 0.934188899520783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 94}], {
             RGBColor[
             0.18516334977200538`, 0.3119487990177908, 0.933856150893663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 174}], {
             RGBColor[
             0.1849745541189024, 0.31175036281604385`, 0.9338453992605169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 196}], {
             RGBColor[
             0.20645103349834157`, 0.33432350433127433`, 0.935068452989572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 16}], {
             RGBColor[
             0.1847745870823867, 0.3115401847820234, 0.9338340114336121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 52}], {
             RGBColor[
             0.1839811911872139, 0.31070627539199164`, 0.933788828711106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[
             0.1829598466238134, 0.3096327774988722, 0.9337306646491643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 78}], {
             RGBColor[
             0.1826523965739446, 0.3093096280030011, 0.9337131558236558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 80}], {
             RGBColor[
             0.20208335684743473`, 0.32973279924447707`, 0.9348197202657014]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 82}], {
             RGBColor[
             0.19716931432443496`, 0.3245678289845131, 0.934539872813691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 98}], {
             RGBColor[
             0.18743734029303655`, 0.314338907234721, 0.9339856512897682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 100}], {
             RGBColor[
             0.19408219414375266`, 0.32132306993989135`, 0.9343640658863862]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 120}], {
             RGBColor[
             0.18815579892545653`, 0.3150940528103027, 0.9340265664460203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 124}], {
             RGBColor[
             0.20420540017012767`, 0.331963201321945, 0.9349405674936471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 187}], {
             RGBColor[
             0.1929273076602217, 0.3201092110216681, 0.9342982968096505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 5}], {
             RGBColor[
             0.38651352623245844`, 0.5092003225130362, 0.945849278004409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 10}], {
             RGBColor[
             0.3183216992072676, 0.4417413182340497, 0.9418115251184348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 27}], {
             RGBColor[
             0.3426067292683088, 0.4672664245880422, 0.9431945216539286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 29}], {
             RGBColor[
             0.312801857714541, 0.4359396148470296, 0.9414971783112978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 49}], {
             RGBColor[
             0.42052372581365627`, 0.5386582479879358, 0.9480163778476842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 53}], {
             RGBColor[
             0.5252380847939087, 0.6245108141050952, 0.9560275789647218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 62}], {
             RGBColor[
             0.30929718741563983`, 0.43225598415395333`, 0.9412975925224704]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 68}], {
             RGBColor[
             0.6898421419054424, 0.7085746089319662, 0.625429383133753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 71}], {
             RGBColor[
             0.3912157938817601, 0.5132731904080172, 0.9461489023409704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 75}], {
             RGBColor[
             0.4604176361342196, 0.5718866537552251, 0.9509246758011038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 118}], {
             RGBColor[
             0.40478020373070756`, 0.5250220004521133, 0.9470132145420087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[
             0.4349086817945046, 0.5511177738496366, 0.9489329745226667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 127}], {
             RGBColor[
             0.6467401961046771, 0.7200341503582268, 0.9679094614906981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 129}], {
             RGBColor[
             0.4365819525225805, 0.5525357720139865, 0.9490482434742096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 139}], {
             RGBColor[
             0.3521805380042213, 0.47732910458401956`, 0.943739735898258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 141}], {
             RGBColor[
             0.38125443274481086`, 0.5046451600637603, 0.9455141732178098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 146}], {
             RGBColor[
             0.33204839273274867`, 0.4561689434519673, 0.9425932400078877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 155}], {
             RGBColor[
             0.545941520152503, 0.6408465029615011, 0.9579803382974005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 167}], {
             RGBColor[
             0.3090133882504993, 0.4319576932374843, 0.9412814305798589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 191}], {
             RGBColor[
             0.6143982789320568, 0.6943254432107253, 0.9648034682477634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 194}], {
             RGBColor[
             0.3101074606435417, 0.43310763269076813`, 0.9413437363841075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 195}], {
             RGBColor[
             0.4598624133064091, 0.5714358988511051, 0.9508809666262504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 34}], {
             RGBColor[
             0.38218235773708276`, 0.5054488820532, 0.9455732997777855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 40}], {
             RGBColor[
             0.42006888605358417`, 0.5368384587156347, 0.9483813569191326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 49}], {
             RGBColor[
             0.37833101513518963`, 0.5021130426655478, 0.9453278956328015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 53}], {
             RGBColor[
             0.483045374115442, 0.5879656087827072, 0.953339096749839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 54}], {
             RGBColor[
             0.661350157437102, 0.7182451701998284, 0.6759656350801627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 65}], {
             RGBColor[
             0.6453230600166431, 0.6641820072591899, 0.6137033880650677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 69}], {
             RGBColor[
             0.2920607984493962, 0.42194145527329896`, 0.9400303359095292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 86}], {
             RGBColor[
             0.26820213237561147`, 0.3968644845029512, 0.9386716201723606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 92}], {
             RGBColor[
             0.28937728391046563`, 0.41912091134823404`, 0.9398775137264412]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 118}], {
             RGBColor[
             0.3625874930522409, 0.48847679512972536`, 0.9443247323271259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 119}], {
             RGBColor[
             0.5905667103712094, 0.4124559324961789, 0.5674982858332491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 123}], {
             RGBColor[
             0.39271597111603795`, 0.5145725685272486, 0.946244492307784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 139}], {
             RGBColor[
             0.30998782732575464`, 0.44078389926163164`, 0.9410512536833753]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 146}], {
             RGBColor[
             0.289855682054282, 0.41962373812957937`, 0.9399047577930049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 171}], {
             RGBColor[
             0.3210288697535419, 0.4523887348957585, 0.9416800247158792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 182}], {
             RGBColor[
             0.33757022299890055`, 0.4668080932140755, 0.9427306540012304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 191}], {
             RGBColor[
             0.57220556825359, 0.6577802378883374, 0.9621149860328806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 195}], {
             RGBColor[
             0.41766970262794245`, 0.5348906935287172, 0.9481924844113676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 196}], {
             RGBColor[
             0.28364684382762245`, 0.41309785549027966`, 0.9395511736411497]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 199}], {
             RGBColor[
             0.6647841302718416, 0.7281451631679503, 0.8353642944923663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 10}], {
             RGBColor[
             0.28614225358776674`, 0.41386909982440245`, 0.9397610792987268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 27}], {
             RGBColor[
             0.31042728364880795`, 0.439394206178395, 0.9411440758342206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.28062241209504013`, 0.4080673964373824, 0.9394467324915896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 30}], {
             RGBColor[
             0.28195013969393246`, 0.40946292232661013`, 0.9395223446141496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 42}], {
             RGBColor[
             0.2785521364098815, 0.40589140542922086`, 0.9393288333540183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 68}], {
             RGBColor[
             0.6576626962859415, 0.680702390522319, 0.6233789373140448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 71}], {
             RGBColor[
             0.35903634826225916`, 0.48540097199837007`, 0.9440984565212622]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 73}], {
             RGBColor[
             0.2859066569179567, 0.41362147278674055`, 0.939747662416915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 75}], {
             RGBColor[
             0.42823819051471873`, 0.5440144353455778, 0.9488742299813958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 76}], {
             RGBColor[
             0.3092912653904981, 0.4382001789611937, 0.9410793812749982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 81}], {
             RGBColor[
             0.3301819815617254, 0.46015764620506105`, 0.9422690766559045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 87}], {
             RGBColor[
             0.28551854391053016`, 0.41321354140814925`, 0.9397255599553038]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 89}], {
             RGBColor[
             0.31092444547544634`, 0.4399167547800723, 0.9411723884647626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 107}], {
             RGBColor[
             0.28598353480448624`, 0.4137022763198226, 0.9397520404988222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 127}], {
             RGBColor[
             0.6145607504851762, 0.6921619319485797, 0.9658590156709901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 129}], {
             RGBColor[
             0.40440250690307966`, 0.5246635536043394, 0.9469977976545015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 141}], {
             RGBColor[
             0.34907498712530993`, 0.4767729416541131, 0.9434637273981017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 142}], {
             RGBColor[
             0.3081659820767354, 0.43701743485134614`, 0.9410152980549868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 147}], {
             RGBColor[
             0.30192938265782127`, 0.43046237343882565`, 0.9406601329443018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 155}], {
             RGBColor[
             0.513762074533002, 0.612974284551854, 0.9559298924776924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 157}], {
             RGBColor[
             0.28037950263265143`, 0.40781208319106244`, 0.939432899157059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 168}], {
             RGBColor[
             0.2818657379269033, 0.4093742107180814, 0.9395175380583785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 188}], {
             RGBColor[
             0.33376821355982345`, 0.4635149837324976, 0.9424883933217574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 197}], {
             RGBColor[
             0.27751999813753725`, 0.4048065626636409, 0.93927005460632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 44}], {
             RGBColor[
             0.8651034665131747, 0.43792568886884486`, 0.20749020660542072`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 45}], {
             RGBColor[
             0.7712380059237092, 0.5084025319316335, 0.5747836939863987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 58}], {
             RGBColor[
             0.8960048531020866, 0.6063661726923737, 0.5646755963969717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 77}], {
             RGBColor[
             0.8243760146987129, 0.18837030737786614`, 0.17097580524524553`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 83}], {
             RGBColor[
             0.8789095063816696, 0.593376334043407, 0.5852871633250518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 96}], {
             RGBColor[
             0.8839247435427675, 0.5973568467623975, 0.5851240708837279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 112}], {
             RGBColor[
             0.8864219769798407, 0.5992192793709223, 0.5808969060575552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 156}], {
             RGBColor[
             0.8250753518515919, 0.1937457191863889, 0.17164549129263085`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 166}], {
             RGBColor[
             0.8175811907160426, 0.5446061801126542, 0.5794027495448137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 170}], {
             RGBColor[
             0.7433204991907267, 0.48659316349091797`, 0.5720011378191884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 179}], {
             RGBColor[
             0.5999866512477183, 0.3681232043828395, 0.5612188243491484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 183}], {
             RGBColor[
             0.8839085682862255, 0.5140524144919886, 0.22270248687391753`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 192}], {
             RGBColor[
             0.6485736073804235, 0.40987019823777215`, 0.5644077418055113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 8}], {
             RGBColor[
             0.24587927343278695`, 0.3757650843971754, 0.9373138329249848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 16}], {
             RGBColor[
             0.19783499493782034`, 0.3252675015157697, 0.9345777823398371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 52}], {
             RGBColor[
             0.19704159904264756`, 0.32443359212573797`, 0.934532599617331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.2079174287175954, 0.335864778681537, 0.9351519620279711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 67}], {
             RGBColor[
             0.23219222063367448`, 0.36137912409603845`, 0.9365343755162554]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 79}], {
             RGBColor[
             0.20133607999592745`, 0.328947363893454, 0.934777163954505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.19486465596415276`, 0.32214548692407674`, 0.9344086259295095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 122}], {
             RGBColor[
             0.24320904209445873`, 0.37295850195814717`, 0.9371617672005202]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 125}], {
             RGBColor[
             0.2363887212836201, 0.36578991235264013`, 0.9367733600201034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 126}], {
             RGBColor[
             0.19407996143665954`, 0.32132072322317473`, 0.9343639387370202]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 137}], {
             RGBColor[
             0.266193356547354, 0.39571608733082725`, 0.9385219649126898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 179}], {
             RGBColor[
             0.2885173026234793, 0.4150519673878126, 0.9399444270163702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 192}], {
             RGBColor[
             0.3371042587561843, 0.4567989612427451, 0.9431333444727331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.3222839501803989, 0.4512119268537823, 0.9418428896396724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 26}], {
             RGBColor[
             0.28802321713859724`, 0.420061041312345, 0.9397138681726531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 61}], {
             RGBColor[
             0.24530237000143487`, 0.37515872231303415`, 0.9372809791280214]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 67}], {
             RGBColor[
             0.26957716191751396`, 0.4006730677275356, 0.9386633926163057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 79}], {
             RGBColor[
             0.2387210212797669, 0.3682413075249512, 0.9369061810545554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.24761466346370808`, 0.37758908934975655`, 0.9374126608199662]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 83}], {
             RGBColor[
             0.60482509904127, 0.6795990406798771, 0.9661417830923238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 122}], {
             RGBColor[
             0.2805939833782982, 0.4122524455896443, 0.9392907843005704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 125}], {
             RGBColor[
             0.2737736625674596, 0.4050838559841373, 0.9389023771201537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 137}], {
             RGBColor[
             0.3035782978311935, 0.4350100309623244, 0.94065098201274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 166}], {
             RGBColor[
             0.543496783375643, 0.6308288867491243, 0.9602573693120857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 170}], {
             RGBColor[
             0.4692360918503271, 0.5728158701273882, 0.9528557575864605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 179}], {
             RGBColor[
             0.32590224390731876`, 0.4543459110193097, 0.9420734441164204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 192}], {
             RGBColor[
             0.37448920004002384`, 0.4960929048742423, 0.9452623615727833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 198}], {
             RGBColor[
             0.31444384785817775`, 0.4444212242772747, 0.9413433252524308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 18}], {
             RGBColor[
             0.2081906159438856, 0.3361519157774386, 0.935167519636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 32}], {
             RGBColor[
             0.18966018913671598`, 0.3166752623061849, 0.9341122392430056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 39}], {
             RGBColor[
             0.22268787528916928`, 0.3513894545286635, 0.9359931171093048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 41}], {
             RGBColor[
             0.24200989921647753`, 0.37169812676333913`, 0.9370934777875921]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 57}], {
             RGBColor[
             0.18757656925487778`, 0.3144852457012422, 0.9339935801731742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 85}], {
             RGBColor[
             0.23189273144463124`, 0.36106434196964265`, 0.9365173200499939]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 88}], {
             RGBColor[
             0.20493816247527158`, 0.3327333809644648, 0.9349822972229003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 91}], {
             RGBColor[
             0.1897739422401799, 0.3167948240302888, 0.9341187173139652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 103}], {
             RGBColor[
             0.18719718779584008`, 0.3140864917336198, 0.9339719749603267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 117}], {
             RGBColor[
             0.1893181439211632, 0.3163157510977197, 0.9340927602739904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 121}], {
             RGBColor[
             0.20533326031636837`, 0.3331486538461075, 0.9350047974604558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 152}], {
             RGBColor[
             0.19674957296563292`, 0.32412665420327286`, 0.9345159691642588]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 159}], {
             RGBColor[
             0.22410281281265743`, 0.3528766435780701, 0.9360736957080549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 164}], {
             RGBColor[
             0.1942433345387914, 0.32149243871196825`, 0.9343732425934977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 178}], {
             RGBColor[
             0.18848044580793838`, 0.31543527726759235`, 0.9340450546057055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 200}], {
             RGBColor[
             0.19196359639909227`, 0.31909628938339796`, 0.9342434148790122]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 17}], {
             RGBColor[
             0.2047098267539144, 0.3324933856439975, 0.9349692938413614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 27}], {
             RGBColor[
             0.24223545662361712`, 0.37193520189940843`, 0.9371063229482464]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 29}], {
             RGBColor[
             0.2124305850698493, 0.3406083921583959, 0.9354089796056155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 30}], {
             RGBColor[
             0.2137583126687416, 0.34200391804762365`, 0.9354845917281754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 42}], {
             RGBColor[
             0.2103603093846907, 0.3384324011502344, 0.9352910804680441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 51}], {
             RGBColor[
             0.20007349461539067`, 0.32762030660597313`, 0.9347052615849112]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 62}], {
             RGBColor[
             0.2089259147709481, 0.3369247614653196, 0.9352093938167881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 71}], {
             RGBColor[
             0.2908445212370684, 0.4179419677193835, 0.9400607036352882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 73}], {
             RGBColor[
             0.2177148298927659, 0.346162468507754, 0.9357099095309409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 75}], {
             RGBColor[
             0.3600463634895279, 0.4765554310665914, 0.9448364770954216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 89}], {
             RGBColor[
             0.2427326184502555, 0.3724577505010858, 0.9371346355787884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 107}], {
             RGBColor[
             0.21779170777929543`, 0.3462432720408361, 0.9357142876128481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.3362106798778888, 0.4572045493253528, 0.9429600447685274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 130}], {
             RGBColor[
             0.2011228825880777, 0.32872327990030753`, 0.9347650226775253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 141}], {
             RGBColor[
             0.28088316010011916`, 0.40931393737512656`, 0.9394259745121276]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 142}], {
             RGBColor[
             0.23997415505154454`, 0.3695584305723596, 0.9369775451690128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 147}], {
             RGBColor[
             0.23373755563263043`, 0.3630033691598391, 0.9366223800583277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 149}], {
             RGBColor[
             0.2017271344819297, 0.32935838695252884`, 0.9347994339289696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 167}], {
             RGBColor[
             0.2086421156058076, 0.33662647054885053`, 0.9351932318741767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 168}], {
             RGBColor[
             0.21367391090171242`, 0.3419152064390949, 0.9354797851724044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 188}], {
             RGBColor[
             0.26557638653463256`, 0.3960559794535111, 0.9384506404357832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.20619097081485965`, 0.33405016196200843`, 0.935053642804476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 194}], {
             RGBColor[
             0.20973618799885002`, 0.33777641000213443`, 0.9352555376784253]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 197}], {
             RGBColor[
             0.20932817111234645`, 0.33734755838465436`, 0.9352323017203459]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 35}], {
             RGBColor[
             0.19186691491128627`, 0.3189946710097535, 0.9342379090113091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 70}], {
             RGBColor[
             0.19700340773557554`, 0.3243934506405365, 0.9345304246788922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 86}], {
             RGBColor[
             0.20252648869962175`, 0.33019855891730787`, 0.9348449559691285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 94}], {
             RGBColor[
             0.19668351642529655`, 0.32405722459115277`, 0.9345122073420087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 110}], {
             RGBColor[
             0.1915413157937571, 0.3186524456930539, 0.9342193666232466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 138}], {
             RGBColor[
             0.2124149402657507, 0.3405919484773504, 0.9354080886571665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 174}], {
             RGBColor[
             0.1964947207721936, 0.32385878838940574`, 0.9345014557088626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 182}], {
             RGBColor[
             0.27189457932291083`, 0.4001421676284322, 0.9389039897979983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 196}], {
             RGBColor[
             0.21797120015163274`, 0.34643192990463634`, 0.9357245094379176]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 33}], {
             RGBColor[
             0.9713628299392978, 0.9155481063306994, 0.5253098577893779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 44}], {
             RGBColor[
             0.9244380104653778, 0.7365581580535521, 0.25797799946440303`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 58}], {
             RGBColor[
             0.9553393970542898, 0.9049986418770809, 0.615163389255954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 68}], {
             RGBColor[
             0.9555467146303788, 0.8599776150331977, 0.2908341193259223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 77}], {
             RGBColor[
             0.883710558650916, 0.4870027765625733, 0.22146359810422783`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 96}], {
             RGBColor[
             0.9432592874949708, 0.8959893159471047, 0.6356118637427102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 99}], {
             RGBColor[
             0.7509614073428162, 0.7434552401786318, 0.618284844686889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 102}], {
             RGBColor[
             0.9596388825040008, 0.9082051910857141, 0.6078854818749925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 128}], {
             RGBColor[
             0.6907043727279983, 0.6939382045780004, 0.6137063255291655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 140}], {
             RGBColor[
             0.9719126786067074, 0.9144307614554209, 0.4184503900682022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 162}], {
             RGBColor[
             0.7007570533940699, 0.7026453313085301, 0.614346873451971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 172}], {
             RGBColor[
             0.9097214307201227, 0.6697336065748736, 0.2456981245885829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 31}], {
             RGBColor[
             0.37653388192589077`, 0.49031817539689215`, 0.9461000785422968]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 34}], {
             RGBColor[
             0.32558157650060693`, 0.44832121227099686`, 0.9422634355654279]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 36}], {
             RGBColor[
             0.20182875625464586`, 0.3294651978788461, 0.9348052211385899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 63}], {
             RGBColor[
             0.20638929458382937`, 0.3342586128176488, 0.935064937049725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 64}], {
             RGBColor[
             0.4253184848962721, 0.5299237138095665, 0.9499405811920143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 70}], {
             RGBColor[
             0.20607827017508945`, 0.33393170644397663`, 0.9350472246697668]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 97}], {
             RGBColor[
             0.21895267363831583`, 0.3474635207681535, 0.9357804029010244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 132}], {
             RGBColor[
             0.26083574153477407`, 0.39148528066721244`, 0.9381655816572811]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 138}], {
             RGBColor[
             0.2214898027052646, 0.35013020428079056`, 0.9359248886480409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 145}], {
             RGBColor[
             0.20564959648275716`, 0.3334811432138535, 0.9350228123371542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 153}], {
             RGBColor[
             0.2516813551580962, 0.3818634401637041, 0.9376442528958304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 185}], {
             RGBColor[
             0.22657810602203676`, 0.3554783336837818, 0.936214659994461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 22}], {
             RGBColor[
             0.18387332754707644`, 0.31059290386725735`, 0.9337826860363703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 48}], {
             RGBColor[
             0.19487547737670605`, 0.3221568609147874, 0.9344092421929455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 106}], {
             RGBColor[
             0.1821436488572793, 0.3087749018963175, 0.9336841833938165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 131}], {
             RGBColor[
             0.18037616802655143`, 0.3069171674784653, 0.9335835279752602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 176}], {
             RGBColor[
             0.20667251283261232`, 0.3345562931541938, 0.9350810659100094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 59}], {
             RGBColor[
             0.18157500733235693`, 0.30817722359966904`, 0.9336518001002019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.18941420148966015`, 0.3164167136926116, 0.9340982306104119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 114}], {
             RGBColor[
             0.1801710817898224, 0.3067016088404447, 0.9335718486174763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 167}], {
             RGBColor[
             0.18913040232451964`, 0.31611842277614255`, 0.9340820686678004]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 184}], {
             RGBColor[
             0.18036794199566558`, 0.3069085213984438, 0.9335830595149706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 186}], {
             RGBColor[
             0.18099749200595946`, 0.30757021837503873`, 0.933618911456721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 194}], {
             RGBColor[
             0.19022447471756204`, 0.31726836222942645`, 0.934144374472049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 52}], {
             RGBColor[
             0.18638226183152043`, 0.31322995287582944`, 0.9339255661322337]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 61}], {
             RGBColor[
             0.19725809150646825`, 0.3246611394316285, 0.9345449285428737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 67}], {
             RGBColor[
             0.22153288342254734`, 0.3501754848461299, 0.935927342031158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 80}], {
             RGBColor[
             0.20448442749174123`, 0.3322564767283148, 0.934956457686829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 82}], {
             RGBColor[
             0.19957038496874147`, 0.32709150646835083`, 0.9346766102348185]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 84}], {
             RGBColor[
             0.1842053187530256, 0.3109418476741682, 0.933801592444412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 100}], {
             RGBColor[
             0.19648326478805916`, 0.32384674742372915`, 0.9345008033075137]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 120}], {
             RGBColor[
             0.19055686956976303`, 0.31761773029414053`, 0.9341633038671477]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 125}], {
             RGBColor[
             0.22572938407249296`, 0.3545862731027316, 0.936166326535006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.19532837830452823`, 0.32263288850550587`, 0.9344350342307781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 30}], {
             RGBColor[
             0.20051771286008008`, 0.3280872081462052, 0.9347305591567843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[
             0.1971197095760292, 0.3245156912488159, 0.9345370478966529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 51}], {
             RGBColor[
             0.18683289480672916`, 0.31370359670455467`, 0.9339512290135199]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 73}], {
             RGBColor[
             0.20447423008410437`, 0.33224575860633554`, 0.9349558769595496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 87}], {
             RGBColor[
             0.2040861170766778, 0.33183782722774424`, 0.9349337744979385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 89}], {
             RGBColor[
             0.229492018641594, 0.35854104059966735`, 0.9363806030073972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 106}], {
             RGBColor[
             0.18824964863953902`, 0.315192694810219, 0.934031911048399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 107}], {
             RGBColor[
             0.20455110797063392`, 0.33232656213941764`, 0.9349602550414569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 130}], {
             RGBColor[
             0.18788228277941618`, 0.31480656999888906`, 0.9340109901061341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 131}], {
             RGBColor[
             0.18648216780881113`, 0.31333496039236675`, 0.9339312556298427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 142}], {
             RGBColor[
             0.22673355524288302`, 0.35564172067094113`, 0.9362235125976215]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 147}], {
             RGBColor[
             0.22049695582396892`, 0.34908665925842064`, 0.9358683474869365]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 149}], {
             RGBColor[
             0.1884865346732682, 0.31544167705111037`, 0.9340454013575784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 157}], {
             RGBColor[
             0.19894707579879906`, 0.3264363690106574, 0.9346411136996936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 168}], {
             RGBColor[
             0.2004333110930509, 0.32799849653767643`, 0.9347257526010131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 188}], {
             RGBColor[
             0.25233578672597107`, 0.38213926955209265`, 0.937696607864392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 189}], {
             RGBColor[
             0.19295037100619816`, 0.32013345206058996`, 0.9342996102330847]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 197}], {
             RGBColor[
             0.19608757130368493`, 0.3234308484832359, 0.9344782691489546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 24}], {
             RGBColor[
             0.24010747998138166`, 0.3696985635269072, 0.9369851378265305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 32}], {
             RGBColor[
             0.20453729510132862`, 0.33231204393799124`, 0.9349594684189844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 39}], {
             RGBColor[
             0.2375649812537819, 0.3670262361604698, 0.9368403462852835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 41}], {
             RGBColor[
             0.25688700518109014`, 0.38733490839514545`, 0.9379407069635708]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 85}], {
             RGBColor[
             0.24676983740924385`, 0.376701123601449, 0.9373645492259726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 103}], {
             RGBColor[
             0.20207429376045272`, 0.32972327336542606`, 0.9348192041363055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 108}], {
             RGBColor[
             0.2655472156605108, 0.39643733869807485`, 0.9384338931387406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 117}], {
             RGBColor[
             0.2041952498857758, 0.331952532729526, 0.9349399894499691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 133}], {
             RGBColor[
             0.2360954570926359, 0.3654816730938921, 0.9367566590582723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 152}], {
             RGBColor[
             0.21162667893024556`, 0.3397634358350792, 0.9353631983402376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 178}], {
             RGBColor[
             0.20335755177255102`, 0.3310720588993987, 0.9348922837816843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 33}], {
             RGBColor[
             0.6719200989970671, 0.734922803310785, 0.8577553559890845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 74}], {
             RGBColor[
             0.34857360130161363`, 0.4763386664540116, 0.9434317795367738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 85}], {
             RGBColor[
             0.31084430416368, 0.44012074843948534`, 0.9411572711237357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 88}], {
             RGBColor[
             0.28388973519432037`, 0.4117897874343075, 0.939622248296642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 93}], {
             RGBColor[
             0.291301712500707, 0.4195802455298239, 0.9400443494392029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 95}], {
             RGBColor[
             0.3002072480543151, 0.4289405280402324, 0.9405515065144217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 102}], {
             RGBColor[
             0.6601961515617699, 0.7275798880657995, 0.9403309800746991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 121}], {
             RGBColor[
             0.28428483303541713`, 0.41220506031595017`, 0.9396447485341975]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 140}], {
             RGBColor[
             0.6724699476644765, 0.7338054584355065, 0.7508958882679089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 159}], {
             RGBColor[
             0.30305438553170616`, 0.43193305004791277`, 0.9407136467817967]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 161}], {
             RGBColor[
             0.3175223229543551, 0.44713976959933127`, 0.9415375744146212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 162}], {
             RGBColor[
             0.4013143224518391, 0.5220200282886156, 0.9467923716516777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 164}], {
             RGBColor[
             0.2731949072578401, 0.40054884518181094`, 0.9390131936672395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 172}], {
             RGBColor[
             0.610278699777892, 0.48910830355495916`, 0.5781436227882895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 173}], {
             RGBColor[
             0.35948494367207134`, 0.4857895227952885, 0.9441270406240982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 180}], {
             RGBColor[
             0.3466247657178071, 0.47465068302264285`, 0.9433076014566613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 22}], {
             RGBColor[
             0.1854064647205249, 0.3122043282430629, 0.9338699959303249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 46}], {
             RGBColor[
             0.182651270158183, 0.3093084440686167, 0.9337130916759446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 47}], {
             RGBColor[
             0.189292245231432, 0.3162885299327404, 0.9340912853819239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 50}], {
             RGBColor[
             0.19303508907013, 0.32022249611721776`, 0.9343044348014965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 101}], {
             RGBColor[
             0.18925893509711914`, 0.3162535188695931, 0.9340893884190526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 135}], {
             RGBColor[
             0.18962988067563263`, 0.3166434061919189, 0.9341105132209843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 144}], {
             RGBColor[
             0.19040607844928842`, 0.31745923926581243`, 0.9341547165359123]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 23}], {
             RGBColor[
             0.2924706869731754, 0.4198762969529263, 0.9401450684047916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 55}], {
             RGBColor[
             0.34859095953566543`, 0.47635370128389704`, 0.9434328855880982]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 61}], {
             RGBColor[
             0.2843221054652073, 0.4113116211381439, 0.9396810187426589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 67}], {
             RGBColor[
             0.30859689738128643`, 0.43682596655264533`, 0.9410634322309431]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 83}], {
             RGBColor[
             0.6438448345050425, 0.715751939504987, 0.9685418227069613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 90}], {
             RGBColor[
             0.29428715223398993`, 0.42178551711259177`, 0.9402485134141754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 122}], {
             RGBColor[
             0.3196137188420707, 0.44840534441475405`, 0.941690823915208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 166}], {
             RGBColor[
             0.5825165188394155, 0.666981785574234, 0.9626574089267232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 170}], {
             RGBColor[
             0.5082558273140996, 0.6089687689524979, 0.9552557972010979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 175}], {
             RGBColor[
             0.43093748007980026`, 0.5463950813331377, 0.9490344400593063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 177}], {
             RGBColor[
             0.28934680274084895`, 0.4165928965590511, 0.9399671678191333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 179}], {
             RGBColor[
             0.3649219793710912, 0.49049880984441946`, 0.9444734837310578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 183}], {
             RGBColor[
             0.6488438964095984, 0.6364280199535685, 0.605957146255827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 192}], {
             RGBColor[
             0.4135089355037963, 0.532245803699352, 0.9476624011874208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.19949157754304903`, 0.3270086748672687, 0.9346721222685106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 72}], {
             RGBColor[
             0.22084536933385682`, 0.34945286394800523`, 0.935888189120893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 144}], {
             RGBColor[
             0.19348904144218293`, 0.3206996288424882, 0.9343302867175226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 176}], {
             RGBColor[
             0.2112886129989553, 0.33940810710667507`, 0.9353439459855744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 38}], {
             RGBColor[
             0.20238106508142, 0.3300457094741879, 0.9348366743092069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 43}], {
             RGBColor[
             0.2066925124128154, 0.33457731398103385`, 0.9350822048565153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 55}], {
             RGBColor[
             0.27975796086466953`, 0.40886517255793126`, 0.9393350247385799]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 60}], {
             RGBColor[
             0.2023092030396156, 0.32997017791193484`, 0.9348325818722366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 90}], {
             RGBColor[
             0.22545415356299398`, 0.354296988386626, 0.936150652564657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 111}], {
             RGBColor[
             0.2218869245410005, 0.3505476045091276, 0.935947504149097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 115}], {
             RGBColor[
             0.26933147945021957`, 0.39983427840692803`, 0.9386706585626268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 163}], {
             RGBColor[
             0.2527001813973467, 0.382934291138471, 0.9377022735429374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 165}], {
             RGBColor[
             0.21472043526896856`, 0.3430151699025583, 0.9355393831869255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 169}], {
             RGBColor[
             0.20786534559532402`, 0.33581003601776915`, 0.9351489959712078]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 175}], {
             RGBColor[
             0.36210448140880436`, 0.4789065526071719, 0.9449365792097879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 177}], {
             RGBColor[
             0.22051380406985302`, 0.3491043678330853, 0.9358693069696149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 39}], {
             RGBColor[
             0.25460473932666533`, 0.38493610227813213`, 0.9378107352994711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 41}], {
             RGBColor[
             0.2739267632539736, 0.4052447745128077, 0.9389110959777585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 55}], {
             RGBColor[
             0.29651273574071235`, 0.4264755032667358, 0.9402891843813024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 108}], {
             RGBColor[
             0.28258697373339425`, 0.41434720481573717`, 0.9394042821529283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 111}], {
             RGBColor[
             0.2386416994170433, 0.36815793521793205`, 0.9369016637918195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 115}], {
             RGBColor[
             0.28608625432626233`, 0.41744460911573256`, 0.9396248182053492]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 133}], {
             RGBColor[
             0.2531352151655193, 0.3833915392115544, 0.93772704807246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 163}], {
             RGBColor[
             0.2694549562733895, 0.40054462184727546`, 0.9386564331856598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 165}], {
             RGBColor[
             0.23147521014501135`, 0.3606255006113628, 0.9364935428296479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 175}], {
             RGBColor[
             0.3788592562848471, 0.49651688331597643`, 0.9458907388525104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 38}], {
             RGBColor[
             0.18033163328528526`, 0.30687035864172885`, 0.9335809917876283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[
             0.1846430806166806, 0.3114019631485748, 0.9338265223349365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 60}], {
             RGBColor[
             0.18025977124348086`, 0.3067948270794758, 0.9335768993506579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 111}], {
             RGBColor[
             0.19983749274486573`, 0.32737225367666856`, 0.9346918216275183]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 165}], {
             RGBColor[
             0.19267100347283378`, 0.3198398190700993, 0.9342837006653468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 58}], {
             RGBColor[
             0.6266794481836577, 0.6975908926125163, 0.9458012343118618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 67}], {
             RGBColor[
             0.2743361643394848, 0.4056750810112081, 0.9389344107639237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 80}], {
             RGBColor[
             0.25728770840867865`, 0.387756072893393, 0.9379635264195947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 82}], {
             RGBColor[
             0.2523736658856789, 0.382591102633429, 0.9376836789675842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 96}], {
             RGBColor[
             0.6145993386243387, 0.6885815666825401, 0.9662497087986179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 98}], {
             RGBColor[
             0.24264169185428053`, 0.372362180883637, 0.9371294574436615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 99}], {
             RGBColor[
             0.42230145847218425`, 0.5360474909140672, 0.9489226897427967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[
             0.24928654570499661`, 0.3793463435888073, 0.9375078720402794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 116}], {
             RGBColor[
             0.2667049754056552, 0.39765421759642916`, 0.9384998258434745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 120}], {
             RGBColor[
             0.2433601504867005, 0.3731173264592187, 0.9371703725999135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 122}], {
             RGBColor[
             0.285352985800269, 0.4172544588733168, 0.9395618024481885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 124}], {
             RGBColor[
             0.25940975173137165`, 0.3899864749708609, 0.9380843736475403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 125}], {
             RGBColor[
             0.2785326649894304, 0.41008586926780977`, 0.9391733952677717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 128}], {
             RGBColor[
             0.36204442385736635`, 0.48653045531343586`, 0.9443441705850733]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 136}], {
             RGBColor[
             0.2577972163446346, 0.3882915980387517, 0.9379925421427979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 137}], {
             RGBColor[
             0.3083373002531643, 0.4400120442459969, 0.9409220001603581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.5482557857976138, 0.6358309000327967, 0.9605283874597037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 170}], {
             RGBColor[
             0.4739950942722979, 0.5778178834110607, 0.9531267757340784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 187}], {
             RGBColor[
             0.24813165922146568`, 0.378132484670584, 0.9374421029635438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 192}], {
             RGBColor[
             0.37924820246199464`, 0.5010949181579147, 0.9455333797204014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 198}], {
             RGBColor[
             0.3192028502801486, 0.44942323756094715`, 0.9416143434000489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 29}], {
             RGBColor[
             0.2367156151308905, 0.36613349851238836`, 0.9367919761411093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 30}], {
             RGBColor[
             0.2380433427297828, 0.3675290244016161, 0.9368675882636692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 42}], {
             RGBColor[
             0.2346453394457319, 0.36395750750422684`, 0.936674077003538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 62}], {
             RGBColor[
             0.23321094483198931`, 0.3624498678193121, 0.9365923903522819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 71}], {
             RGBColor[
             0.3151295512981096, 0.44346707407337604`, 0.941443700170782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 73}], {
             RGBColor[
             0.2419998599538071, 0.37168757486174653`, 0.9370929060664348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 75}], {
             RGBColor[
             0.3843313935505691, 0.5020805374205839, 0.9462194736309155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 89}], {
             RGBColor[
             0.2670176485112967, 0.3979828568550783, 0.9385176321142823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 127}], {
             RGBColor[
             0.5706539535210267, 0.6502280340235855, 0.9632042593205097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 129}], {
             RGBColor[
             0.36049570993893, 0.4827296556793453, 0.9443430413040212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 141}], {
             RGBColor[
             0.30516819016116037`, 0.4348390437291191, 0.9408089710476214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 142}], {
             RGBColor[
             0.2642591851125857, 0.3950835369263521, 0.9383605417045067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 147}], {
             RGBColor[
             0.25802258569367165`, 0.38852847551383163`, 0.9380053765938214]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 149}], {
             RGBColor[
             0.2260121645429709, 0.35488349330652136`, 0.9361824304644635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 155}], {
             RGBColor[
             0.4698552775688525, 0.57104038662686, 0.953275136127212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 167}], {
             RGBColor[
             0.2329271456668488, 0.36215157690284305`, 0.9365762284096705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 168}], {
             RGBColor[
             0.23795894096275363`, 0.36744031279308736`, 0.9368627817078983]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 188}], {
             RGBColor[
             0.28986141659567377`, 0.4215810858075036, 0.939833636971277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 189}], {
             RGBColor[
             0.23047600087590087`, 0.35957526831600095`, 0.9364366393399698]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[
             0.23402121805989123`, 0.3633015163561269, 0.9366385342139192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 197}], {
             RGBColor[
             0.23361320117338766`, 0.3628726647386469, 0.9366152982558398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 97}], {
             RGBColor[
             0.19804503866908396`, 0.3254882707948695, 0.9345897440196007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 105}], {
             RGBColor[
             0.19252363925225727`, 0.3196849299308422, 0.9342753084909909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.20340607327822147`, 0.3311230580782995, 0.9348950470096511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 71}], {
             RGBColor[
             0.2853246797443417, 0.4121402643323634, 0.939746356828151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 73}], {
             RGBColor[
             0.21219498840003925`, 0.3403607651207339, 0.9353955627238038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 129}], {
             RGBColor[
             0.33069083838516217`, 0.4514028459383327, 0.9426456979613903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 141}], {
             RGBColor[
             0.2753633186073925, 0.40351223398810643`, 0.9391116277049905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 149}], {
             RGBColor[
             0.19620729298920309`, 0.32355668356550876`, 0.9344850871218325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 167}], {
             RGBColor[
             0.20312227411308098`, 0.33082476716183046`, 0.9348788850670395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 168}], {
             RGBColor[
             0.2081540694089858, 0.33611350305207477`, 0.9351654383652672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 189}], {
             RGBColor[
             0.20067112932213305`, 0.3282484585749883, 0.9347392959973388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 194}], {
             RGBColor[
             0.2042163465061234, 0.3319747066151143, 0.9349411908712882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 197}], {
             RGBColor[
             0.2038083296196198, 0.3315458549976343, 0.9349179549132087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 42}], {
             RGBColor[
             0.2061681954908564, 0.33402622365244206`, 0.935052345783467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 51}], {
             RGBColor[
             0.19588138072155636`, 0.3232141291081808, 0.934466526900334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 71}], {
             RGBColor[
             0.28665240734323405`, 0.41353579022159115`, 0.939821968950711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 73}], {
             RGBColor[
             0.21352271599893158`, 0.34175629100996163`, 0.9354711748463638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 76}], {
             RGBColor[
             0.23690732447147297`, 0.36633499718441476`, 0.936802893704447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 81}], {
             RGBColor[
             0.2577980406427003, 0.3882924644282822, 0.9379925890853533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 87}], {
             RGBColor[
             0.213134602991505, 0.3413483596313704, 0.9354490723847526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 89}], {
             RGBColor[
             0.2385405045564212, 0.3680515730032935, 0.9368959008942113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 106}], {
             RGBColor[
             0.19729813455436623`, 0.32470322721384515`, 0.9345472089352131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 107}], {
             RGBColor[
             0.21359959388546113`, 0.3418370945430438, 0.935475552928271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 130}], {
             RGBColor[
             0.1969307686942434, 0.3243171024025152, 0.9345262879929481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 131}], {
             RGBColor[
             0.19553065372363834`, 0.3228454927959929, 0.9344465535166567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 142}], {
             RGBColor[
             0.23578204115771023`, 0.3651522530745672, 0.9367388104844356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 147}], {
             RGBColor[
             0.22954544173879612`, 0.3585971916620468, 0.9363836453737505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 157}], {
             RGBColor[
             0.20799556171362626`, 0.3359469014142835, 0.9351564115865076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 168}], {
             RGBColor[
             0.2094817970078781, 0.3375090289413025, 0.9352410504878272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 176}], {
             RGBColor[
             0.22182699852969923`, 0.3504846184717214, 0.9359440914514059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 188}], {
             RGBColor[
             0.2613842726407983, 0.39164980195571875`, 0.938211905751206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 197}], {
             RGBColor[
             0.20513605721851214`, 0.33294138088686204`, 0.9349935670357687]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 34}], {
             RGBColor[
             0.48100947040442327`, 0.5889125969543878, 0.9524604831380885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[
             0.5188959987209247, 0.6203021736168226, 0.9552685402794356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 45}], {
             RGBColor[
             0.62150237913985, 0.702550504593909, 0.964065451798632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 64}], {
             RGBColor[
             0.5807463788000884, 0.6705150984929575, 0.9601376287646749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 65}], {
             RGBColor[
             0.7441501726839835, 0.7476457221603776, 0.6205905714253708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 132}], {
             RGBColor[
             0.4162636354385904, 0.5320766653506034, 0.9483626292299419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 138}], {
             RGBColor[
             0.3769176966090809, 0.4907215889641815, 0.9461219362207016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 153}], {
             RGBColor[
             0.4071092490619125, 0.522454824847095, 0.9478413004684911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 156}], {
             RGBColor[
             0.6753397250677327, 0.3878936918486643, 0.560927249104864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 182}], {
             RGBColor[
             0.43639733566624106`, 0.5502718081152633, 0.9496178373615334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 185}], {
             RGBColor[
             0.38200599992585305`, 0.49606971836717273`, 0.9464117075671216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 199}], {
             RGBColor[
             0.763611242939182, 0.811608878069138, 0.8422514778526693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 39}], {
             RGBColor[
             0.2190345544466123, 0.34754958268921615`, 0.9357850658919249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 57}], {
             RGBColor[
             0.1839232484123208, 0.31064537386179486`, 0.9337855289557946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 103}], {
             RGBColor[
             0.1835438669532831, 0.31024661989417246`, 0.9337639237429469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 117}], {
             RGBColor[
             0.1856648230786062, 0.31247587925827236`, 0.9338847090566107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 133}], {
             RGBColor[
             0.21756503028546625`, 0.3460050196226384, 0.9357013786649139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 152}], {
             RGBColor[
             0.19309625212307593`, 0.3202867823638255, 0.9343079179468792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 178}], {
             RGBColor[
             0.1848271249653814, 0.311595405428145, 0.9338370033883259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 44}], {
             RGBColor[
             0.9456987231028435, 0.812227711259105, 0.5045786610453252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 58}], {
             RGBColor[
             0.9766001096917556, 0.9806681950826337, 0.8617640508368762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 68}], {
             RGBColor[
             0.9768074272678445, 0.9356471682387506, 0.5374347809068445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 77}], {
             RGBColor[
             0.9049712712883817, 0.5626723297681262, 0.46806425968515003`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 96}], {
             RGBColor[
             0.9645200001324366, 0.9716588691526575, 0.8822125253236324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 99}], {
             RGBColor[
             0.772222119980282, 0.8191247933841846, 0.8648855062678112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 102}], {
             RGBColor[
             0.9808995951414665, 0.9838747442912669, 0.8544861434559147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 128}], {
             RGBColor[
             0.7119650853654641, 0.7696077577835532, 0.8603069871100877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 140}], {
             RGBColor[
             0.9931733912441731, 0.9901003146609737, 0.6650510516491244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 162}], {
             RGBColor[
             0.7220177660315357, 0.778314884514083, 0.8609475350328932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 172}], {
             RGBColor[
             0.9309821433575884, 0.7454031597804265, 0.49229878616950506`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 180}], {
             RGBColor[
             0.6673282092975037, 0.7309455392481101, 0.857462764837877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 40}], {
             RGBColor[
             0.4679436932956409, 0.5783052104909272, 0.9514318973025666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 45}], {
             RGBColor[
             0.5705500737145661, 0.6605535414680137, 0.960228808821763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 54}], {
             RGBColor[
             0.7092249646791587, 0.7597119219751208, 0.6790161754635967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 64}], {
             RGBColor[
             0.5297940733748047, 0.6285181353670621, 0.956300985787806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 65}], {
             RGBColor[
             0.6931978672586998, 0.7056487590344823, 0.6167539284485017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 132}], {
             RGBColor[
             0.3653113300133066, 0.4900797022247081, 0.9445259862530728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 138}], {
             RGBColor[
             0.32596539118379714`, 0.4487246258382862, 0.9422852932438326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 153}], {
             RGBColor[
             0.3561569436366287, 0.48045786172119975`, 0.9440046574916221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 182}], {
             RGBColor[
             0.3854450302409573, 0.5082748449893679, 0.9457811943846643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 185}], {
             RGBColor[
             0.3310536945005693, 0.45407275524127744`, 0.9425750645902526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 199}], {
             RGBColor[
             0.7126589375138983, 0.7696119149432428, 0.8384148348758003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 86}], {
             RGBColor[
             0.19143714046786142`, 0.31854295082044043`, 0.9342134339925504]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.1855941681935362, 0.31240161649428533`, 0.9338806853654305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 110}], {
             RGBColor[
             0.18045196756199675`, 0.30699683759618646`, 0.9335878446466683]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 174}], {
             RGBColor[
             0.18540537254043327`, 0.31220318029253835`, 0.9338699337322844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 63}], {
             RGBColor[
             0.1871120628164008, 0.3139970199829937, 0.9339671272186787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 70}], {
             RGBColor[
             0.18680103840766088`, 0.3136701136093215, 0.9339494148387204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 110}], {
             RGBColor[
             0.18133894646584242`, 0.3079291086618389, 0.9336383567830746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 138}], {
             RGBColor[
             0.20221257093783607`, 0.32986861144613544`, 0.9348270788169946]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 145}], {
             RGBColor[
             0.1863723647153286, 0.3132195503791984, 0.9339250025061079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 185}], {
             RGBColor[
             0.2073008742546082, 0.33521674084912667`, 0.9351168501634146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 45}], {
             RGBColor[
             0.47344467906469456`, 0.5697056609217193, 0.9542881258612889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 47}], {
             RGBColor[
             0.21605368220731502`, 0.34441649696749876`, 0.9356153096277022]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 50}], {
             RGBColor[
             0.21979652604601302`, 0.3483504631519761, 0.935828459047275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 97}], {
             RGBColor[
             0.22632286746697683`, 0.35521006177935477`, 0.9362001245363418]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 101}], {
             RGBColor[
             0.21602037207300215`, 0.3443814859043514, 0.9356134126648311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 105}], {
             RGBColor[
             0.22080146805015013`, 0.3494067209153274, 0.9358856890077321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 134}], {
             RGBColor[
             0.24135977409579584`, 0.37101480404118925`, 0.9370564541237432]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 135}], {
             RGBColor[
             0.21639131765151565`, 0.3447713732266772, 0.9356345374667627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 160}], {
             RGBColor[
             0.33951855272220766`, 0.4617555701348826, 0.9431015867680459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 43}], {
             RGBColor[
             0.1854358891920559, 0.31223525522826123`, 0.9338716716104489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 60}], {
             RGBColor[
             0.18105257981885614`, 0.3076281191591622, 0.9336220486261704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 90}], {
             RGBColor[
             0.20419753034223448`, 0.33195492963385337`, 0.9349401193185908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 111}], {
             RGBColor[
             0.200630301320241, 0.32820554575635497`, 0.9347369709030307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 165}], {
             RGBColor[
             0.19346381204820906`, 0.3206731111497857, 0.9343288499408593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 169}], {
             RGBColor[
             0.18660872237456455`, 0.31346797726499653`, 0.9339384627251416]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 41}], {
             RGBColor[
             0.2713842645263738, 0.40257244714637036`, 0.9387663044365115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 74}], {
             RGBColor[
             0.29899639389246113`, 0.42815658036720006`, 0.9404646551119514]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 85}], {
             RGBColor[
             0.26126709675452753`, 0.3919386623526739, 0.9381901466989133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 88}], {
             RGBColor[
             0.2343125277851679, 0.36360770134749604`, 0.9366551238718196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 108}], {
             RGBColor[
             0.2800444750057945, 0.41167487744929976`, 0.9392594906116811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 117}], {
             RGBColor[
             0.21869250923105948`, 0.34719007148075093`, 0.9357655869229098]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 133}], {
             RGBColor[
             0.2505927164379196, 0.38071921184511703`, 0.9375822565312131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 152}], {
             RGBColor[
             0.22612393827552923`, 0.3550009745863041, 0.9361887958131783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 159}], {
             RGBColor[
             0.25347717812255377`, 0.3837509639611013, 0.9377465223569743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 173}], {
             RGBColor[
             0.3099077362629189, 0.437607436708477, 0.9411599161992759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 178}], {
             RGBColor[
             0.21785481111783467`, 0.34630959765062364`, 0.935717881254625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 49}], {
             RGBColor[
             0.46409235069374777`, 0.5749693711032751, 0.9511864931575826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 53}], {
             RGBColor[
             0.5688067096740002, 0.6608219372204345, 0.9591976942746201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 54}], {
             RGBColor[
             0.7471114929956602, 0.7911014986375555, 0.6818242326049438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 64}], {
             RGBColor[
             0.5676806016913061, 0.6599077120294969, 0.959109042929153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.7310843955752011, 0.737038335696917, 0.6195619855898489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 69}], {
             RGBColor[
             0.37782213400795434`, 0.4947977837110262, 0.9458889334343104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 119}], {
             RGBColor[
             0.6763280459297676, 0.4853122609339061, 0.5733568833580303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 123}], {
             RGBColor[
             0.4784773066745961, 0.5874288969649759, 0.9521030898325651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 132}], {
             RGBColor[
             0.40319785832980803`, 0.5214692788871429, 0.94733404339442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 171}], {
             RGBColor[
             0.40679020531210003`, 0.5252450633334856, 0.9475386222406603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 182}], {
             RGBColor[
             0.4233315585574587, 0.5396644216518027, 0.9485892515260115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 191}], {
             RGBColor[
             0.6579669038121483, 0.7306365663260646, 0.9679735835576617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 195}], {
             RGBColor[
             0.5034310381865006, 0.6077470219664445, 0.9540510819361487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 196}], {
             RGBColor[
             0.3694081793861806, 0.4859541839280068, 0.9454097711659308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 199}], {
             RGBColor[
             0.7505454658303996, 0.8010014916056775, 0.8412228920171474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 74}], {
             RGBColor[
             0.31831841781976944`, 0.44846525260187575`, 0.9415650157902389]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 85}], {
             RGBColor[
             0.2805891206818358, 0.4122473345873495, 0.9392905073772007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.2536345517124762, 0.3839163735821717, 0.937755484550107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 108}], {
             RGBColor[
             0.29936649893310274`, 0.4319835496839754, 0.9403598512899686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 121}], {
             RGBColor[
             0.25402964955357293`, 0.38433164646381435`, 0.9377779847876626]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 133}], {
             RGBColor[
             0.2699147403652278, 0.4010278840797926, 0.9386826172095004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 140}], {
             RGBColor[
             0.6422147641826323, 0.7059320445833706, 0.7490291245213738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 151}], {
             RGBColor[
             0.6423047351050197, 0.7073139713016436, 0.8452851258395946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 152}], {
             RGBColor[
             0.2454459622028375, 0.3753096468209797, 0.9372891564914656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 159}], {
             RGBColor[
             0.27279920204986197`, 0.40405963619577695`, 0.9388468830352616]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 161}], {
             RGBColor[
             0.2872671394725109, 0.41926635574719545`, 0.9396708106680862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 173}], {
             RGBColor[
             0.32922976019022715`, 0.45791610894315266`, 0.9422602768775632]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 51}], {
             RGBColor[
             0.1924833774375055, 0.31964261221079154`, 0.9342730156402028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 71}], {
             RGBColor[
             0.2832544040591832, 0.40996427332420193`, 0.9396284576905798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 73}], {
             RGBColor[
             0.2101247127148807, 0.3381847741125724, 0.9352776635862325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 76}], {
             RGBColor[
             0.23350932118742207`, 0.36276348028702554`, 0.9366093824443157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 81}], {
             RGBColor[
             0.25440003735864936`, 0.3847209475308929, 0.9377990778252221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 87}], {
             RGBColor[
             0.20973659970745412`, 0.3377768427339811, 0.9352555611246214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 89}], {
             RGBColor[
             0.2351425012723703, 0.3644800561059042, 0.93670238963408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 106}], {
             RGBColor[
             0.19390013127031533`, 0.3211317103164559, 0.9343536976750818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 107}], {
             RGBColor[
             0.21020159060141025`, 0.3382655776456545, 0.9352820416681398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 130}], {
             RGBColor[
             0.1935327654101925, 0.32074558550512594`, 0.9343327767328169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 131}], {
             RGBColor[
             0.19213265043958744`, 0.3192739758986036, 0.9342530422565254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 142}], {
             RGBColor[
             0.23238403787365935`, 0.361580736177178, 0.9365452992243044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 147}], {
             RGBColor[
             0.22614743845474522`, 0.3550256747646575, 0.9361901341136192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 149}], {
             RGBColor[
             0.1941370173040445, 0.32138069255734725`, 0.9343671879842612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 157}], {
             RGBColor[
             0.2045975584295754, 0.3323753845168943, 0.9349629003263764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 168}], {
             RGBColor[
             0.20608379372382724`, 0.3339375120439133, 0.935047539227696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 176}], {
             RGBColor[
             0.21842899524564835`, 0.34691310157433214`, 0.9357505801912747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 188}], {
             RGBColor[
             0.2579862693567474, 0.38807828505832953`, 0.9380183944910747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 189}], {
             RGBColor[
             0.19860085363697447`, 0.32607246756682684`, 0.9346213968597675]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 197}], {
             RGBColor[
             0.20173805393446126`, 0.32936986398947277`, 0.9348000557756375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 60}], {
             RGBColor[
             0.18536402715025152`, 0.3121597236660082, 0.9338675791734785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[
             0.20850897767362986`, 0.33648653414069934`, 0.935185649865899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 111}], {
             RGBColor[
             0.2049417486516364, 0.33273715026320094`, 0.934982501450339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 115}], {
             RGBColor[
             0.25238630356085545`, 0.3820238241610014, 0.9377056558638687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 163}], {
             RGBColor[
             0.2357550055079826, 0.36512383689254435`, 0.9367372708441793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 165}], {
             RGBColor[
             0.19777525937960444`, 0.32520471565663167`, 0.9345743804881674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 169}], {
             RGBColor[
             0.19092016970595993`, 0.3179995817718425, 0.9341839932724498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 58}], {
             RGBColor[
             0.9296752902178356, 0.8016782468054864, 0.5944321925119014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 68}], {
             RGBColor[
             0.9298826077939246, 0.7566572199616033, 0.27010292258186963`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 77}], {
             RGBColor[
             0.8580464518144618, 0.3836823814909788, 0.2007324013601752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 96}], {
             RGBColor[
             0.9175951806585165, 0.7926689208755102, 0.6148806669986575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 99}], {
             RGBColor[
             0.7252973005063621, 0.6401348451070372, 0.5975536479428364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 102}], {
             RGBColor[
             0.9339747756675465, 0.8048847960141194, 0.5871542851309398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[
             0.6650402658915442, 0.5906178095064059, 0.5929751287851128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 143}], {
             RGBColor[
             0.8772182848102179, 0.7604919813860003, 0.611670932866671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 166}], {
             RGBColor[
             0.8512516278317916, 0.7399182542257667, 0.6091593456597434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 172}], {
             RGBColor[
             0.8840573238836684, 0.5664132115032791, 0.22496692784453026`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 198}], {
             RGBColor[
             0.6221986923143263, 0.5535105917539171, 0.5902453016000886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 64}], {
             RGBColor[
             0.6702869821102313, 0.7421560430065834, 0.9679059544483493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 112}], {
             RGBColor[
             0.8262269535061243, 0.8650081965468237, 0.9779469895534628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 132}], {
             RGBColor[
             0.5058042387487333, 0.6037176098642293, 0.9561309549136163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 134}], {
             RGBColor[
             0.478958077481094, 0.5755005922270049, 0.9546021057447607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 153}], {
             RGBColor[
             0.49664985237205533`, 0.594095769360721, 0.9556096261521655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 156}], {
             RGBColor[
             0.7648803283778755, 0.4595346363622902, 0.5686955747885385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 183}], {
             RGBColor[
             0.823713544812509, 0.7798413316678898, 0.6197525703698252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 47}], {
             RGBColor[
             0.1896200136619846, 0.31663303533497, 0.934109951309154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 50}], {
             RGBColor[
             0.1933628575006826, 0.3205670015194474, 0.9343231007287265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 101}], {
             RGBColor[
             0.18958670352767176`, 0.3165980242718227, 0.9341080543462827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 105}], {
             RGBColor[
             0.19436779950481975`, 0.32162325928279867`, 0.9343803306891837]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 135}], {
             RGBColor[
             0.18995764910618526`, 0.3169879115941485, 0.9341291791482143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 144}], {
             RGBColor[
             0.19073384687984102`, 0.31780374466804207`, 0.9341733824631423]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 50}], {
             RGBColor[
             0.2000038325739316, 0.3275470873835711, 0.9347012944347058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 101}], {
             RGBColor[
             0.19622767860092072`, 0.3235781101359464, 0.934486248052262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 105}], {
             RGBColor[
             0.2010087745780687, 0.32860334514692235`, 0.934758524395163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 134}], {
             RGBColor[
             0.22156708062371444`, 0.3502114282727843, 0.9359292895111742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 135}], {
             RGBColor[
             0.19659862417943424`, 0.3239679974582722, 0.9345073728541936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 144}], {
             RGBColor[
             0.19737482195309003`, 0.32478383053216575`, 0.9345515761691217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 72}], {
             RGBColor[
             0.23184751916348642`, 0.3610168209955353, 0.9365147452774683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 76}], {
             RGBColor[
             0.23737108877035865`, 0.36682244286689847`, 0.9368293043951907]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 81}], {
             RGBColor[
             0.2582618049415859, 0.3887799101107659, 0.938018999776097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 87}], {
             RGBColor[
             0.21359836729039067`, 0.3418358053138541, 0.9354754830754963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 104}], {
             RGBColor[
             0.28879698411440874`, 0.4154790711874804, 0.939955479525905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 106}], {
             RGBColor[
             0.1977618988532519, 0.32519067289632886`, 0.9345736196259569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 147}], {
             RGBColor[
             0.2300092060376818, 0.3590846373445305, 0.9364100560644943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 154}], {
             RGBColor[
             0.2711822856025334, 0.4002221046769836, 0.9388330865127945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 157}], {
             RGBColor[
             0.20845932601251194`, 0.33643434709676723`, 0.9351828222772515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 158}], {
             RGBColor[
             0.2634190473924112, 0.39349797793107355`, 0.9383384198388076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 176}], {
             RGBColor[
             0.2222907628285849, 0.3509720641542051, 0.9359705021421497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 53}], {
             RGBColor[
             0.5270688387556056, 0.6260965211703475, 0.956144232988289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 54}], {
             RGBColor[
             0.7053736220772657, 0.7563760825874686, 0.6787707713186126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 65}], {
             RGBColor[
             0.6893465246568067, 0.7023129196468301, 0.6165085243035178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 69}], {
             RGBColor[
             0.33608426308955985`, 0.46007236766093923`, 0.9428354721479792]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 92}], {
             RGBColor[
             0.33340074855062923`, 0.45725182373587436`, 0.9426826499648912]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 118}], {
             RGBColor[
             0.4066109576924045, 0.5266077075173656, 0.9471298685655758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 119}], {
             RGBColor[
             0.634590175011373, 0.45058684488381917`, 0.5703034220716992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 123}], {
             RGBColor[
             0.43673943575620155`, 0.552703480914889, 0.949049628546234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 127}], {
             RGBColor[
             0.6485709500663741, 0.7216198574234791, 0.9680261155142653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[
             0.4384127064842775, 0.5541214790792388, 0.9491648974977769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 139}], {
             RGBColor[
             0.3540112919659183, 0.4789148116492719, 0.9438563899218253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 141}], {
             RGBColor[
             0.3830851867065078, 0.5062308671290127, 0.9456308272413769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 146}], {
             RGBColor[
             0.3338791466944457, 0.45775465051721964`, 0.9427098940314549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 155}], {
             RGBColor[
             0.5477722741141999, 0.6424322100267535, 0.9580969923209677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 171}], {
             RGBColor[
             0.36505233439370555`, 0.4905196472833987, 0.9444851609543292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 191}], {
             RGBColor[
             0.6162290328937537, 0.6959111502759776, 0.9649201222713306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 195}], {
             RGBColor[
             0.46169316726810605`, 0.5730216059163575, 0.9509976206498176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 196}], {
             RGBColor[
             0.3276703084677861, 0.4512287678779199, 0.9423563098795996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 199}], {
             RGBColor[
             0.7088075949120052, 0.7662760755555905, 0.8381694307308162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 97}], {
             RGBColor[
             0.21027301783359342`, 0.33834065219542714`, 0.9352861093433454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 101}], {
             RGBColor[
             0.19997052243961871`, 0.3275120763204238, 0.9346993974718347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 105}], {
             RGBColor[
             0.2047516184167667, 0.33253731133139974`, 0.9349716738147356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 134}], {
             RGBColor[
             0.22530992446241244`, 0.3541453944572617, 0.9361424389307468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 135}], {
             RGBColor[
             0.20034146801813224`, 0.3279019636427496, 0.9347205222737662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 144}], {
             RGBColor[
             0.20111766579178803`, 0.32871779671664314`, 0.9347647255886942]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 73}], {
             RGBColor[
             0.19983789794558066`, 0.3273726795683112, 0.9346918447030995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 87}], {
             RGBColor[
             0.19944978493815407`, 0.3269647481897199, 0.9346697422414884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 106}], {
             RGBColor[
             0.1836133165010153, 0.31031961577219463`, 0.9337678787919488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[
             0.1999147758321102, 0.3274534831013933, 0.9346962227850067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 130}], {
             RGBColor[
             0.18324595064089247`, 0.3099334909608647, 0.933746957849684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 131}], {
             RGBColor[
             0.18184583567028742`, 0.3084618813543424, 0.9336672233733925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 147}], {
             RGBColor[
             0.2158606236854452, 0.3442135802203963, 0.9356043152304863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 157}], {
             RGBColor[
             0.19431074366027534`, 0.32156328997263306`, 0.9343770814432435]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 168}], {
             RGBColor[
             0.1957969789545272, 0.32312541749965207`, 0.934461720344563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 189}], {
             RGBColor[
             0.18831403886767445`, 0.3152603730225656, 0.9340355779766345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 197}], {
             RGBColor[
             0.1914512391651612, 0.3185577694452115, 0.9342142368925045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 66}], {
             RGBColor[
             0.18456752137294713`, 0.3113225455926782, 0.9338222193477858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 80}], {
             RGBColor[
             0.20369103159656846`, 0.33142256733828307`, 0.9349112749643229]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 82}], {
             RGBColor[
             0.1987769890735687, 0.32625759707831903`, 0.9346314275123124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 100}], {
             RGBColor[
             0.1956898688928864, 0.3230128380336974, 0.9344556205850076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 120}], {
             RGBColor[
             0.1897634736745903, 0.3167838209041087, 0.9341181211446418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 124}], {
             RGBColor[
             0.20581307491926143`, 0.333652969415751, 0.9350321221922685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 125}], {
             RGBColor[
             0.2249359881773202, 0.35375236371269986`, 0.9361211438124999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 187}], {
             RGBColor[
             0.19453498240935546`, 0.32179897911547406`, 0.934389851508272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 54}], {
             RGBColor[
             0.810087981057518, 0.842228648704628, 0.6867819724356502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 65}], {
             RGBColor[
             0.7940608836370591, 0.7881654857639895, 0.6245197254205552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 69}], {
             RGBColor[
             0.4407986220698122, 0.5459249337780987, 0.9508466732650168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 92}], {
             RGBColor[
             0.4381151075308816, 0.5431043898530338, 0.9506938510819287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 118}], {
             RGBColor[
             0.5113253166726569, 0.612460273634525, 0.9551410696826135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 119}], {
             RGBColor[
             0.7393045339916254, 0.5364394110009786, 0.5783146231887367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 123}], {
             RGBColor[
             0.5414537947364539, 0.6385560470320484, 0.9570608296632714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 127}], {
             RGBColor[
             0.7532853090466265, 0.8074724235406385, 0.9760373166313029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 129}], {
             RGBColor[
             0.5431270654645298, 0.6399740451963982, 0.9571760986148143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 139}], {
             RGBColor[
             0.4587256509461706, 0.5647673777664313, 0.9518675910388628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 141}], {
             RGBColor[
             0.4877995456867602, 0.5920834332461721, 0.9536420283584146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 146}], {
             RGBColor[
             0.438593505674698, 0.543607216634379, 0.9507210951484925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 155}], {
             RGBColor[
             0.6524866330944523, 0.728284776143913, 0.9661081934380052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 171}], {
             RGBColor[
             0.4697666933739579, 0.5763722134005581, 0.9524963620713668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 182}], {
             RGBColor[
             0.48630804661931654`, 0.5907915717188752, 0.9535469913567178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 191}], {
             RGBColor[
             0.720943391874006, 0.781763716393137, 0.9729313233883682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 195}], {
             RGBColor[
             0.5664075262483584, 0.658874172033517, 0.9590088217668552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 196}], {
             RGBColor[
             0.43238466744803844`, 0.5370813339950793, 0.9503675109966372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 199}], {
             RGBColor[
             0.8135219538922576, 0.8521286416727499, 0.8461806318478537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 64}], {
             RGBColor[
             0.8089618730748239, 0.8413144235136905, 0.6866933210901831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 65}], {
             RGBColor[
             0.9723656669587191, 0.9184450471811106, 0.347146263750879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 118}], {
             RGBColor[
             0.6896300999943169, 0.7427398350516461, 0.6777676080129371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 119}], {
             RGBColor[
             0.9176093173132854, 0.6667189724180997, 0.30094116151906036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 123}], {
             RGBColor[
             0.7197585780581139, 0.7688356084491694, 0.6796873679935951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 127}], {
             RGBColor[
             0.9315900923682865, 0.9377519849577597, 0.6986638549616266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 140}], {
             RGBColor[
             0.9910580021453803, 0.9807455899537222, 0.48380004734696136`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 151}], {
             RGBColor[
             0.9911479730677677, 0.9821275166719952, 0.580056048665182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 155}], {
             RGBColor[
             0.8307914164161123, 0.8585643375610341, 0.688734731768329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 171}], {
             RGBColor[
             0.6480714766956179, 0.7066517748176793, 0.6751229004016905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 172}], {
             RGBColor[
             0.9288667542587956, 0.7360484350731749, 0.311047781867342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 191}], {
             RGBColor[
             0.899248175195666, 0.9120432778102582, 0.6955578617186919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 195}], {
             RGBColor[
             0.7447123095700184, 0.789153733450638, 0.681635360097179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 199}], {
             RGBColor[
             0.9918267372139176, 0.9824082030898711, 0.5688071701781774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 90}], {
             RGBColor[
             0.281574426125484, 0.41077439271759675`, 0.9394384697479637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 108}], {
             RGBColor[
             0.3219524714198415, 0.4532142784379034, 0.9417379396935124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 111}], {
             RGBColor[
             0.27800719710349053`, 0.40702500884009835`, 0.9392353213324036]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 115}], {
             RGBColor[
             0.3254517520127096, 0.4563116827378988, 0.9419584757459334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 163}], {
             RGBColor[
             0.3088204539598367, 0.4394116954694417, 0.9409900907262441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.2708407078314586, 0.3994925742335291, 0.9388272003702323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 175}], {
             RGBColor[
             0.4182247539712943, 0.5353839569381427, 0.9482243963930945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 177}], {
             RGBColor[
             0.2766340766323431, 0.4055817721640561, 0.9391571241529215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 183}], {
             RGBColor[
             0.6361311703010923, 0.6254168955585735, 0.6051471025896153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 109}], {
             RGBColor[
             0.19998929422011852`, 0.3275318066519287, 0.9347004664969638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 148}], {
             RGBColor[
             0.18807327130146562`, 0.31500731104493473`, 0.9340218666199227]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 150}], {
             RGBColor[
             0.18756580923325702`, 0.31447393623629405`, 0.933992967405861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 193}], {
             RGBColor[
             0.2060154437903921, 0.33386567193023686`, 0.9350436468001014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 88}], {
             RGBColor[
             0.1992012217508764, 0.32670349252007475`, 0.9346555869356892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 91}], {
             RGBColor[
             0.18403700151578473`, 0.31076493558589874`, 0.9337920070267542]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 103}], {
             RGBColor[
             0.1814602470714449, 0.3080566032892297, 0.9336452646731157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 117}], {
             RGBColor[
             0.18358120319676802`, 0.31028586265332964`, 0.9337660499867794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 121}], {
             RGBColor[
             0.1995963195919732, 0.32711876540171747`, 0.9346780871732447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 152}], {
             RGBColor[
             0.19101263224123774`, 0.3180967657588828, 0.9341892588770478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 164}], {
             RGBColor[
             0.1885063938143962, 0.3154625502675782, 0.9340465323062868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 178}], {
             RGBColor[
             0.1827435050835432, 0.30940538882320234`, 0.9337183443184945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 200}], {
             RGBColor[
             0.1862266556746971, 0.31306640093900795`, 0.9339167045918012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 77}], {
             RGBColor[
             0.8889478384033738, 0.5521228653145076, 0.5579177911517261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 96}], {
             RGBColor[
             0.9484965672474285, 0.961109404699039, 0.9720660567902085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 99}], {
             RGBColor[
             0.7561986870952739, 0.8085753289305662, 0.9547390377343874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 102}], {
             RGBColor[
             0.9648761622564584, 0.9733252798376484, 0.9443396749224908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 125}], {
             RGBColor[
             0.6124298936125201, 0.6826137072843086, 0.9449897432593624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 128}], {
             RGBColor[
             0.695941652480456, 0.7590582933299347, 0.9501605185766638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 137}], {
             RGBColor[
             0.6422345288762541, 0.7125398822624958, 0.9467383481519487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 166}], {
             RGBColor[
             0.8821530144207035, 0.9083587380492957, 0.9663447354512944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 170}], {
             RGBColor[
             0.8078923228953876, 0.8503457214275595, 0.9589431237256691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 192}], {
             RGBColor[
             0.7131454310850844, 0.7736227561744136, 0.951349727711992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 198}], {
             RGBColor[
             0.6531000789032383, 0.7219510755774461, 0.9474306913916395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 62}], {
             RGBColor[
             0.19206220882201708`, 0.3191999372922807, 0.9342490307106137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 92}], {
             RGBColor[
             0.21433501599530952`, 0.3426100698089493, 0.9355174341294674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 114}], {
             RGBColor[
             0.1828190891221793, 0.3094848324401137, 0.9337226487176782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 146}], {
             RGBColor[
             0.21481341413912597`, 0.34311289659029465`, 0.935544678196031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 184}], {
             RGBColor[
             0.1830159493280225, 0.30969174499811286`, 0.9337338596151724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 186}], {
             RGBColor[
             0.18364549933831636`, 0.3103534419747078, 0.9337697115569229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[
             0.19287248204991897`, 0.32005158582909543`, 0.934295174572251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 90}], {
             RGBColor[
             0.2041256683004301, 0.33187939807160033`, 0.9349360268816205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 111}], {
             RGBColor[
             0.20055843927843664`, 0.3281300141941019, 0.9347328784660603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 165}], {
             RGBColor[
             0.1933919500064047, 0.32059757958753266`, 0.9343247575038889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 169}], {
             RGBColor[
             0.18653686033276015`, 0.3133924457027435, 0.9339343702881713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 67}], {
             RGBColor[
             0.2316153172023224, 0.36077276201189723`, 0.936501521719292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 79}], {
             RGBColor[
             0.20075917656457537`, 0.3283410018093128, 0.9347443101575417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 84}], {
             RGBColor[
             0.19428775253280067`, 0.3215391248399355, 0.9343757721325461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 122}], {
             RGBColor[
             0.24263213866310665`, 0.37235213987400595`, 0.9371289134035569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 126}], {
             RGBColor[
             0.19350305800530745`, 0.3207143611390335, 0.9343310849400568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 179}], {
             RGBColor[
             0.2879403991921272, 0.41444560530367136`, 0.9399115732194068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 190}], {
             RGBColor[
             0.1957633885191688, 0.3230901118223337, 0.9344598074189618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 192}], {
             RGBColor[
             0.33652735532483224`, 0.4561925991586039, 0.9431004906757697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 114}], {
             RGBColor[
             0.19065828327948256`, 0.31772432253305627`, 0.9341690792278882]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 141}], {
             RGBColor[
             0.2718586483084913, 0.3998286032950302, 0.9389120419161632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 149}], {
             RGBColor[
             0.19270262269030192`, 0.3198730528724325, 0.9342855013330051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 167}], {
             RGBColor[
             0.19961760381417978`, 0.3271411364687542, 0.9346792992782123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 184}], {
             RGBColor[
             0.19085514348532573`, 0.3179312350910555, 0.9341802901253824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 189}], {
             RGBColor[
             0.19716645902323188`, 0.3245648278819121, 0.9345397102085116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 194}], {
             RGBColor[
             0.2007116762072222, 0.32829107592203804`, 0.9347416050824608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 197}], {
             RGBColor[
             0.20030365932071864`, 0.327862224304558, 0.9347183691243814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 70}], {
             RGBColor[
             0.1913615767368444, 0.3184635285481242, 0.9342091307498555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 110}], {
             RGBColor[
             0.18589948479502594`, 0.3127225236006417, 0.9338980726942099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 132}], {
             RGBColor[
             0.24611904809652904`, 0.37601710277136, 0.9373274877373701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 138}], {
             RGBColor[
             0.20677310926701956`, 0.33466202638493814`, 0.9350867947281298]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 145}], {
             RGBColor[
             0.1909329030445121, 0.31801296531800116`, 0.9341847184172432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 153}], {
             RGBColor[
             0.23696466171985112`, 0.36639526226785174`, 0.9368061589759192]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 185}], {
             RGBColor[
             0.2118614125837917, 0.3400101557879294, 0.9353765660745497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 65}], {
             RGBColor[
             0.792934775654365, 0.787251260573052, 0.6244310740750881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 132}], {
             RGBColor[
             0.4650482384089718, 0.5716822037632778, 0.9522031318796592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 138}], {
             RGBColor[
             0.4257022995794623, 0.5303271273768558, 0.949962438870419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 153}], {
             RGBColor[
             0.4558938520322939, 0.5620603632597695, 0.9516818031182084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 156}], {
             RGBColor[
             0.724124328038114, 0.42749923026133874`, 0.5647677517545815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 182}], {
             RGBColor[
             0.48518193863662246`, 0.5898773465279377, 0.9534583400112507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 185}], {
             RGBColor[
             0.4307906028962345, 0.5356752567798472, 0.9502522102168389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 199}], {
             RGBColor[
             0.8123958459095635, 0.8512144164818124, 0.8460919805023865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 118}], {
             RGBColor[
             0.6736030025738579, 0.6886766721110076, 0.6155053609978421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 119}], {
             RGBColor[
             0.9015822198928265, 0.6126558094774612, 0.23867891450396542`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 123}], {
             RGBColor[
             0.7037314806376549, 0.7147724455085309, 0.6174251209785002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 127}], {
             RGBColor[
             0.9155629949478274, 0.8836888220171212, 0.6364016079465316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 140}], {
             RGBColor[
             0.9750309047249213, 0.9266824270130837, 0.4215378003318664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 151}], {
             RGBColor[
             0.9751208756473086, 0.9280643537313567, 0.5177938016500871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 155}], {
             RGBColor[
             0.8147643189956533, 0.8045011746203956, 0.6264724847532339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 156}], {
             RGBColor[
             0.887528121922009, 0.5046298539287588, 0.2252206944152773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 171}], {
             RGBColor[
             0.6320443792751589, 0.6525886118770408, 0.6128606533865955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 172}], {
             RGBColor[
             0.9128396568383367, 0.6819852721325363, 0.24878553485224705`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 191}], {
             RGBColor[
             0.8832210777752071, 0.8579801148696197, 0.6332956147035969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 195}], {
             RGBColor[
             0.7286852121495595, 0.7350905705099995, 0.6193731130820839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 199}], {
             RGBColor[
             0.9757996397934585, 0.9283450401492326, 0.5065449231630825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 78}], {
             RGBColor[
             0.18323872675967784`, 0.30992589820368766`, 0.9337465464603355]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 80}], {
             RGBColor[
             0.20266968703316796`, 0.3303490694451636, 0.9348531109023811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 82}], {
             RGBColor[
             0.1977556445101682, 0.32518409918519964`, 0.9345732634503707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[
             0.18802367047876978`, 0.3149551774354076, 0.9340190419264479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 100}], {
             RGBColor[
             0.1946685243294859, 0.3219393401405779, 0.9343974565230659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 113}], {
             RGBColor[
             0.1939997700984511, 0.32123643704229315`, 0.9343593719589416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 120}], {
             RGBColor[
             0.18874212911118976`, 0.3157103230109893, 0.9340599570827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 124}], {
             RGBColor[
             0.2047917303558609, 0.33257947152263156`, 0.9349739581303267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 136}], {
             RGBColor[
             0.2031791949691239, 0.33088459459052233`, 0.9348821266255843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 187}], {
             RGBColor[
             0.19351363784595493`, 0.32072548122235467`, 0.9343316874463302]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 79}], {
             RGBColor[
             0.22503396848065443`, 0.3538553472238142, 0.9361267236458259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 82}], {
             RGBColor[
             0.2339276106645956, 0.3632031290486195, 0.9366332034112368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 100}], {
             RGBColor[
             0.2308404904839133, 0.3599583700039979, 0.936457396483932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 122}], {
             RGBColor[
             0.26690693057918574`, 0.3978664852885073, 0.9385113268918411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 125}], {
             RGBColor[
             0.2600866097683471, 0.39069789568300034`, 0.9381229197114243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 137}], {
             RGBColor[
             0.289891245032081, 0.42062407066118745`, 0.9398715246040107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 166}], {
             RGBColor[
             0.5298097305765306, 0.6164429264479874, 0.9594779119033563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 170}], {
             RGBColor[
             0.45554903905121463`, 0.5584299098262512, 0.952076300177731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 179}], {
             RGBColor[
             0.3122151911082063, 0.43995995071817273`, 0.941293986707691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 192}], {
             RGBColor[
             0.36080214724091136`, 0.4817069445731053, 0.944482904164054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 71}], {
             RGBColor[
             0.6623649639352431, 0.6847752584173, 0.6236785616506062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 75}], {
             RGBColor[
             0.7315668061877028, 0.7433887217645079, 0.6284543351107399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 81}], {
             RGBColor[
             0.6335105972347094, 0.659531932623991, 0.6218491817852485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 102}], {
             RGBColor[
             0.9650834798325474, 0.9283042529937652, 0.6200104049924591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 127}], {
             RGBColor[
             0.9178893661581602, 0.8915362183675095, 0.645439120800334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 129}], {
             RGBColor[
             0.7077311225760636, 0.7240378400232692, 0.6265779027838456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 140}], {
             RGBColor[
             0.977357275935254, 0.934529823363472, 0.4305753131856688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 143}], {
             RGBColor[
             0.9083269889752188, 0.8839114383656459, 0.6445270527281901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 155}], {
             RGBColor[
             0.817090690205986, 0.812348570970784, 0.6355099976070364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 172}], {
             RGBColor[
             0.9151660280486694, 0.6898326684829248, 0.25782304770604947`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 188}], {
             RGBColor[
             0.6370968292328074, 0.6628892701514275, 0.6220684984511013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 86}], {
             RGBColor[
             0.22595538032998164`, 0.3548238094983426, 0.9361791966875385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 92}], {
             RGBColor[
             0.2471305318648358, 0.3770802363436254, 0.937385090241619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 118}], {
             RGBColor[
             0.32034074100661103`, 0.44643612012511674`, 0.9418323088423037]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 123}], {
             RGBColor[
             0.3504692190704081, 0.47253189352264, 0.9437520688229617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 139}], {
             RGBColor[
             0.2677410752801248, 0.398743224257023, 0.938558830198553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 146}], {
             RGBColor[
             0.24760893000865222`, 0.37758306312497075`, 0.9374123343081827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 171}], {
             RGBColor[
             0.27878211770791206`, 0.41034805989114986`, 0.939187601231057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 174}], {
             RGBColor[
             0.21992361240255348`, 0.34848403897044045`, 0.9358356964272725]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 186}], {
             RGBColor[
             0.21644101520784265`, 0.3448236085093839, 0.9356373676690746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 191}], {
             RGBColor[
             0.5299588162079603, 0.6157395628837288, 0.9596225625480584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 195}], {
             RGBColor[
             0.3754229505823126, 0.4928500185241086, 0.9457000609265455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 196}], {
             RGBColor[
             0.24140009178199262`, 0.37105718048567105`, 0.9370587501563274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 110}], {
             RGBColor[
             0.185588460386286, 0.31239561722696946`, 0.9338803603142515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 132}], {
             RGBColor[
             0.2458080236877891, 0.37569019639768786`, 0.9373097753574117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 138}], {
             RGBColor[
             0.2064620848582796, 0.334335120011266, 0.9350690823481714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.19062187863577218`, 0.31768605894432894`, 0.9341670060372848]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 185}], {
             RGBColor[
             0.21155038817505178`, 0.3396832494142572, 0.9353588536945914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 73}], {
             RGBColor[
             0.29060892456725834`, 0.41769434068172157`, 0.9400472867534765]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 75}], {
             RGBColor[
             0.4329404581640204, 0.5480873032405589, 0.9491738543179573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 76}], {
             RGBColor[
             0.3139935330397997, 0.4422730468561747, 0.9413790056115596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 81}], {
             RGBColor[
             0.334884249211027, 0.4642305141000421, 0.942568700992466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 87}], {
             RGBColor[
             0.29022081155983176`, 0.4172864093031303, 0.9400251842918653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 89}], {
             RGBColor[
             0.315626713124748, 0.4439896226750534, 0.9414720128013241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 107}], {
             RGBColor[
             0.2906858024537879, 0.41777514421480366`, 0.9400516648353837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 127}], {
             RGBColor[
             0.6192630181344778, 0.6962347998435606, 0.9661586400075515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 129}], {
             RGBColor[
             0.40910477455238126`, 0.5287364214993203, 0.947297421991063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 141}], {
             RGBColor[
             0.3537772547746116, 0.4808458095490941, 0.9437633517346631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 142}], {
             RGBColor[
             0.312868249726037, 0.44109030274632716`, 0.9413149223915483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 147}], {
             RGBColor[
             0.3066316503071229, 0.4345352413338067, 0.9409597572808632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 155}], {
             RGBColor[
             0.5184643421823038, 0.6170471524468351, 0.9562295168142538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 168}], {
             RGBColor[
             0.2865680055762049, 0.4134470786130624, 0.93981716239494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 188}], {
             RGBColor[
             0.33847048120912504`, 0.4675878516274786, 0.9427880176583188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 197}], {
             RGBColor[
             0.2822222657868389, 0.40887943055862197`, 0.9395696789428815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 76}], {
             RGBColor[
             0.25872488056116644`, 0.3892666319476351, 0.9380453712475731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 81}], {
             RGBColor[
             0.2796155967323937, 0.4112240991915025, 0.9392350666284796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 104}], {
             RGBColor[
             0.31015077590521656`, 0.43792326026821704`, 0.9411715463782875]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 143}], {
             RGBColor[
             0.5544319884729032, 0.6356036049331575, 0.9619129375714212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 144}], {
             RGBColor[
             0.22584498306262032`, 0.3547077749707548, 0.9361729097264804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 154}], {
             RGBColor[
             0.2925360773933412, 0.42266629375772025`, 0.940049153365177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 158}], {
             RGBColor[
             0.284772839183219, 0.41594216701181014`, 0.93955448669119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 160}], {
             RGBColor[
             0.3481960203596565, 0.4708761388050667, 0.9435957557128356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 176}], {
             RGBColor[
             0.2436445546193927, 0.37341625323494165`, 0.9371865689945322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 181}], {
             RGBColor[
             0.345687120645864, 0.46870305597394574`, 0.9434358908416056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 75}], {
             RGBColor[
             0.3598107668197179, 0.47630780402892936`, 0.9448230602136101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 87}], {
             RGBColor[
             0.2170911202155293, 0.3455069100915008, 0.9356743901875181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.2424970217804455, 0.37221012346342386`, 0.9371212186969768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 107}], {
             RGBColor[
             0.21755611110948542`, 0.34599564500317415`, 0.9357008707310365]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 130}], {
             RGBColor[
             0.20088728591826768`, 0.3284756528626456, 0.9347516057957137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 142}], {
             RGBColor[
             0.23973855838173452`, 0.36931080353469764`, 0.9369641282872011]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 147}], {
             RGBColor[
             0.23350195896282042`, 0.3627557421221772, 0.936608963176516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 149}], {
             RGBColor[
             0.2014915378121197, 0.32911075991486693`, 0.934786017047158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 157}], {
             RGBColor[
             0.21195207893765056`, 0.34010545187441393`, 0.9353817293892732]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 167}], {
             RGBColor[
             0.20840651893599757`, 0.33637884351118863`, 0.9351798149923649]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 168}], {
             RGBColor[
             0.2134383142319024, 0.3416675794014329, 0.9354663682905927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 188}], {
             RGBColor[
             0.26534078986482257`, 0.3958083524158491, 0.9384372235539715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 189}], {
             RGBColor[
             0.20595537414504966`, 0.3338025349243465, 0.9350402259226642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 197}], {
             RGBColor[
             0.20909257444253643`, 0.33709993134699245`, 0.9352188848385342]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 85}], {
             RGBColor[
             0.3082012500479231, 0.4378314678081793, 0.9409888580526407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 88}], {
             RGBColor[
             0.2812466810785635, 0.40950050680300143`, 0.9394538352255469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 93}], {
             RGBColor[
             0.28865865838495014`, 0.4172909648985178, 0.9398759363681078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 95}], {
             RGBColor[
             0.29756419393855826`, 0.4266512474089263, 0.9403830934433266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 121}], {
             RGBColor[
             0.28164177891966025`, 0.4099157796846441, 0.9394763354631025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 140}], {
             RGBColor[
             0.6698268935487197, 0.7315161778042003, 0.7507274751968138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 152}], {
             RGBColor[
             0.2730580915689248, 0.4008937800418094, 0.9389875071669056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 159}], {
             RGBColor[
             0.30041133141594933`, 0.42964376941660665`, 0.9405452337107016]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 161}], {
             RGBColor[
             0.31487926883859824`, 0.44485048896802515`, 0.9413691613435261]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 162}], {
             RGBColor[
             0.39867126833608224`, 0.5197307476573095, 0.9466239585805827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 164}], {
             RGBColor[
             0.2705518531420833, 0.3982595645505048, 0.9388447805961444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 172}], {
             RGBColor[
             0.607635645662135, 0.48681902292365303`, 0.5779752097171944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 173}], {
             RGBColor[
             0.35684188955631446`, 0.48350024216398235`, 0.9439586275530032]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 180}], {
             RGBColor[
             0.34398171160205027`, 0.4723614023913367, 0.9431391883855662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 81}], {
             RGBColor[
             0.40408609146348656`, 0.52284397744725, 0.9473444744525996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 89}], {
             RGBColor[
             0.3848285553772075, 0.5026030860222612, 0.9462477862614576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 118}], {
             RGBColor[
             0.44650486801296785`, 0.559836113284655, 0.9500381665189955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 127}], {
             RGBColor[
             0.6884648603869374, 0.7548482631907685, 0.9709344134676849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 129}], {
             RGBColor[
             0.47830661680484077`, 0.5873498848465282, 0.9520731954511965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 141}], {
             RGBColor[
             0.42297909702707115`, 0.5394592728963019, 0.9485391251947967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 142}], {
             RGBColor[
             0.3820700919784965, 0.49970376609353495`, 0.9460906958516819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 147}], {
             RGBColor[
             0.3758334925595824, 0.4931487046810145, 0.9457355307409967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 155}], {
             RGBColor[
             0.5876661844347633, 0.6756606157940428, 0.9610052902743873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 168}], {
             RGBColor[
             0.3557698478286644, 0.47206054196027025`, 0.9445929358550735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 188}], {
             RGBColor[
             0.40767232346158455`, 0.5262013149746865, 0.9475637911184522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 191}], {
             RGBColor[
             0.656122943214317, 0.729139556043267, 0.9678284202247502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 81}], {
             RGBColor[
             0.28513916633926595`, 0.41702972106286573`, 0.9395496257462019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 87}], {
             RGBColor[
             0.2404757286880707, 0.37008561626595393`, 0.9370061090456012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 89}], {
             RGBColor[
             0.2658816302529869, 0.396788829637877, 0.93845293755506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[
             0.3156743455120887, 0.4437288821395802, 0.9414861054960099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 106}], {
             RGBColor[
             0.2246392602509319, 0.35344048384842863`, 0.9361042455960618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 107}], {
             RGBColor[
             0.2409407195820268, 0.37057435117762727`, 0.9370325895891196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 142}], {
             RGBColor[
             0.26312316685427595`, 0.39388950970915076`, 0.9382958471452842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 143}], {
             RGBColor[
             0.5599555580797754, 0.6414092268045206, 0.9622274966891435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 147}], {
             RGBColor[
             0.2568865674353618, 0.38733444829663033`, 0.9379406820345992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 154}], {
             RGBColor[
             0.29805964700021337`, 0.42847191562908343`, 0.9403637124828994]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[
             0.23533668741019195`, 0.36468415804886706`, 0.9367134482473564]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 158}], {
             RGBColor[
             0.2902964087900912, 0.4217477888831733, 0.9398690458089125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 176}], {
             RGBColor[
             0.24916812422626491`, 0.3792218751063049, 0.9375011281122546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 181}], {
             RGBColor[
             0.3512106902527362, 0.4745086778453089, 0.9437504499593281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 188}], {
             RGBColor[
             0.288725398337364, 0.42038705859030223`, 0.9397689424120548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 83}], {
             RGBColor[
             0.8718524916829569, 0.5391330266655409, 0.5785293580798063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 96}], {
             RGBColor[
             0.8768677288440547, 0.5431135393845314, 0.5783662656384824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 99}], {
             RGBColor[
             0.6845698486919003, 0.3905794636160585, 0.5610392465826612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 112}], {
             RGBColor[
             0.8793649622811279, 0.5449759719930563, 0.5741391008123097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 143}], {
             RGBColor[
             0.8364908329957561, 0.5109365998950215, 0.5751565315064958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 156}], {
             RGBColor[
             0.8180183371528791, 0.13950241180852277`, 0.1648876860473853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 160}], {
             RGBColor[
             0.6302548648825095, 0.34620913376693074`, 0.5568393496479103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 166}], {
             RGBColor[
             0.8105241760173298, 0.490362872734788, 0.5726449442995682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 170}], {
             RGBColor[
             0.736263484492014, 0.4323498561130519, 0.5652433325739429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 181}], {
             RGBColor[
             0.627745965168717, 0.3440360509358098, 0.5566794847766803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 183}], {
             RGBColor[
             0.8768515535875127, 0.45980910711412243`, 0.21594468162867203`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 192}], {
             RGBColor[
             0.6415165926817106, 0.355626890859906, 0.5576499365602658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 80}], {
             RGBColor[
             0.20236223698329917`, 0.33002591994929253`, 0.9348356020768727]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 82}], {
             RGBColor[
             0.1974481944602994, 0.3248609496893285, 0.9345557546248622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 98}], {
             RGBColor[
             0.18771622042890102`, 0.3146320279395365, 0.9340015331009395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 100}], {
             RGBColor[
             0.1943610742796171, 0.3216161906447068, 0.9343799476975574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 113}], {
             RGBColor[
             0.19369232004858233`, 0.320913287546422, 0.9343418631334333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 120}], {
             RGBColor[
             0.188434679061321, 0.31538717351511814`, 0.9340424482571915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 124}], {
             RGBColor[
             0.20448428030599214`, 0.3322563220267605, 0.9349564493048182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 136}], {
             RGBColor[
             0.2028717449192551, 0.3305614450946512, 0.9348646178000759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 187}], {
             RGBColor[
             0.19320618779608617`, 0.3204023317264835, 0.9343141786208218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 84}], {
             RGBColor[
             0.1877064038111327, 0.31462171005185247`, 0.93400097405908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 122}], {
             RGBColor[
             0.2360507899414387, 0.3654347250859229, 0.9367541153300909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 126}], {
             RGBColor[
             0.1869217092836395, 0.3137969463509505, 0.9339562868665908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 177}], {
             RGBColor[
             0.20578387384021699`, 0.33362227723022, 0.9350304592340161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 179}], {
             RGBColor[
             0.2813590504704592, 0.4075281905155883, 0.9395367751459407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 190}], {
             RGBColor[
             0.18918203979750087`, 0.31617269703425077`, 0.9340850093454959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 82}], {
             RGBColor[
             0.2168791547337895, 0.3452841209308045, 0.9356623190669078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 98}], {
             RGBColor[
             0.2071471807023911, 0.33505519918101245`, 0.9351080975429851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 100}], {
             RGBColor[
             0.2137920345531072, 0.3420393618861828, 0.935486512139603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 113}], {
             RGBColor[
             0.2131232803220724, 0.34133645878789803`, 0.9354484275754789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 116}], {
             RGBColor[
             0.23121046425376574`, 0.3603472358938047, 0.936478465942798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 120}], {
             RGBColor[
             0.20786563933481106`, 0.33581034475659416`, 0.9351490126992371]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 124}], {
             RGBColor[
             0.22391524057948223`, 0.35267949326823644`, 0.9360630137468638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 125}], {
             RGBColor[
             0.243038153837541, 0.3727788875651853, 0.9371520353670952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 136}], {
             RGBColor[
             0.2223027051927452, 0.3509846163361272, 0.9359711822421215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 137}], {
             RGBColor[
             0.2728427891012749, 0.40270506254337235`, 0.9389006402596817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 187}], {
             RGBColor[
             0.21263714806957626`, 0.34082550296795955`, 0.9354207430628674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 198}], {
             RGBColor[
             0.28370833912825916`, 0.4121162558583227, 0.9395929834993725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 87}], {
             RGBColor[
             0.261366444859298, 0.3920430835098213, 0.9381958044265076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 89}], {
             RGBColor[
             0.2867723464242142, 0.41874629688174436`, 0.9396426329359664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 104}], {
             RGBColor[
             0.336565061683316, 0.46568634938344766`, 0.9426758008769163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 107}], {
             RGBColor[
             0.26183143575325407`, 0.39253181842149465`, 0.938222284970026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 142}], {
             RGBColor[
             0.28401388302550323`, 0.4158469769530182, 0.9394855425261907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 143}], {
             RGBColor[
             0.5808462742510027, 0.663366694048388, 0.9634171920700499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 147}], {
             RGBColor[
             0.2777772836065891, 0.4092919155404977, 0.9391303774155055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 154}], {
             RGBColor[
             0.31895036317144065`, 0.45042938287295087`, 0.9415534078638058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 157}], {
             RGBColor[
             0.25622740358141927`, 0.3866416252927345, 0.9379031436282628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 158}], {
             RGBColor[
             0.3111871249613185, 0.44370525612704076`, 0.9410587411898188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 168}], {
             RGBColor[
             0.2577136388756711, 0.38820375281975344`, 0.9379877825295823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 176}], {
             RGBColor[
             0.2700588403974922, 0.4011793423501723, 0.938690823493161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 188}], {
             RGBColor[
             0.3096161145085913, 0.44234452583416967`, 0.9409586377929611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 98}], {
             RGBColor[
             0.20223313817939134`, 0.32989022892104847`, 0.9348282500909746]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 100}], {
             RGBColor[
             0.20887799203010743`, 0.3368743916262188, 0.9352066646875926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 120}], {
             RGBColor[
             0.2029515968118113, 0.3306453744966301, 0.9348691652472267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 124}], {
             RGBColor[
             0.21900119805648247`, 0.34751452300827246`, 0.9357831662948535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 125}], {
             RGBColor[
             0.23812411131454123`, 0.3676139173052213, 0.9368721879150849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 136}], {
             RGBColor[
             0.21738866266974544`, 0.34581964607616317`, 0.935691334790111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 137}], {
             RGBColor[
             0.26792874657827515`, 0.39754009228340836`, 0.9386207928076713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 187}], {
             RGBColor[
             0.2077231055465765, 0.3356605327079955, 0.9351408956108569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 198}], {
             RGBColor[
             0.2787942966052594, 0.4069512855983587, 0.9393131360473621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 122}], {
             RGBColor[
             0.6021548677029418, 0.6767924582408489, 0.9659897173678593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 156}], {
             RGBColor[
             0.8725518288358358, 0.5445084384740636, 0.5791990441271917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 166}], {
             RGBColor[
             0.8650576677002866, 0.8953688994003288, 0.9869563023793746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 170}], {
             RGBColor[
             0.7907969761749707, 0.8373558827785927, 0.9795546906537492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 175}], {
             RGBColor[
             0.7134786289406714, 0.7747821951592325, 0.9733333335119576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 179}], {
             RGBColor[
             0.6474631282319623, 0.7188859236705143, 0.9687723771837091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 183}], {
             RGBColor[
             0.9313850452704695, 0.8648151337796632, 0.6302560397084783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 192}], {
             RGBColor[
             0.6960500843646674, 0.7606329175254469, 0.9719612946400722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 126}], {
             RGBColor[
             0.1804502852518648, 0.30699506938157317`, 0.9335877488415951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 190}], {
             RGBColor[
             0.18271061576572617`, 0.30937082006487343`, 0.9337164713205002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 88}], {
             RGBColor[
             0.24351738394062986`, 0.3732825887884752, 0.9371793268125088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 117}], {
             RGBColor[
             0.22789736538652144`, 0.3568649589217301, 0.9362897898635989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[
             0.24391248178172664`, 0.37369786167011787`, 0.9372018270500644]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 133}], {
             RGBColor[
             0.25979757259338154`, 0.39039409928609614`, 0.9381064594719022]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 140}], {
             RGBColor[
             0.632097596410786, 0.6952982597896742, 0.7484529667837756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 152}], {
             RGBColor[
             0.2353287944309912, 0.36467586202728325`, 0.9367129987538674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 159}], {
             RGBColor[
             0.26268203427801573`, 0.3934258514020805, 0.9382707252976634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 161}], {
             RGBColor[
             0.2771499717006646, 0.408632570953499, 0.939094652930488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 173}], {
             RGBColor[
             0.31911259241838086`, 0.4472823241494562, 0.941684119139965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 200}], {
             RGBColor[
             0.23054281786445055`, 0.35964549720740835`, 0.9364404444686207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 92}], {
             RGBColor[
             0.22327186579105107`, 0.35200326557327766`, 0.9360263745044504]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[
             0.19625374198187168`, 0.3236055044018397, 0.9344877323232499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 171}], {
             RGBColor[
             0.25492345163412733`, 0.3852710891208021, 0.9378288854938884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 174}], {
             RGBColor[
             0.19606494632876875`, 0.3234070682000927, 0.9344769806901039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 196}], {
             RGBColor[
             0.2175414257082079, 0.3459802097153233, 0.9357000344191588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 89}], {
             RGBColor[
             0.24210890877301894`, 0.37180219208483256`, 0.9370991162353657]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 106}], {
             RGBColor[
             0.20086653877096394`, 0.3284538462953842, 0.9347504242763673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 107}], {
             RGBColor[
             0.21716799810205883`, 0.34558771362458285`, 0.9356787682694253]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 130}], {
             RGBColor[
             0.20049917291084113`, 0.3280677214840543, 0.9347295033341025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 131}], {
             RGBColor[
             0.19909905794023608`, 0.326596111877532, 0.934649768857811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 142}], {
             RGBColor[
             0.23935044537430794`, 0.3689028721561064, 0.9369420258255899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 147}], {
             RGBColor[
             0.23311384595539386`, 0.3623478107435859, 0.9365868607149048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[
             0.2742869255202454, 0.40348527807603907`, 0.9390098911632051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 157}], {
             RGBColor[
             0.21156396593022397`, 0.3396975204958227, 0.9353596269276621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 168}], {
             RGBColor[
             0.21305020122447582`, 0.34125964802284164`, 0.9354442658289815]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 176}], {
             RGBColor[
             0.22539540274629694`, 0.3542352375532605, 0.9361473067925603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 188}], {
             RGBColor[
             0.264952676857396, 0.39540042103725787`, 0.9384151210923604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 91}], {
             RGBColor[
             0.20139859473617852`, 0.32901307084912135`, 0.93478072407648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 93}], {
             RGBColor[
             0.22397479227765688`, 0.3527420858788138, 0.936066405127976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 95}], {
             RGBColor[
             0.23288032783126497`, 0.3621023683892223, 0.9365735622031948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 103}], {
             RGBColor[
             0.1988218402918387, 0.32630473855245234`, 0.9346339817228415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 117}], {
             RGBColor[
             0.2009427964171618, 0.32853399791655225`, 0.9347547670365053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 121}], {
             RGBColor[
             0.21695791281236698`, 0.34536690066494, 0.9356668042229707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 152}], {
             RGBColor[
             0.20837422546163153`, 0.3363449010221054, 0.9351779759267738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 159}], {
             RGBColor[
             0.23572746530865607`, 0.3650948903969026, 0.9367357024705698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 161}], {
             RGBColor[
             0.25019540273130497`, 0.38030160994832113`, 0.9375596301033943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 164}], {
             RGBColor[
             0.20586798703479003`, 0.3337106855308008, 0.9350352493560126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 173}], {
             RGBColor[
             0.2921580234490212, 0.41895136314427833`, 0.9401490963128714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 180}], {
             RGBColor[
             0.279297845494757, 0.4078125233716327, 0.9393296571454344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 200}], {
             RGBColor[
             0.20358824889509092`, 0.3313145362022305, 0.9349054216415271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 106}], {
             RGBColor[
             0.22627244033588012`, 0.3551570596673073, 0.9361972527858261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 107}], {
             RGBColor[
             0.24257389966697504`, 0.37229092699650596`, 0.9371255967788841]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 142}], {
             RGBColor[
             0.2647563469392241, 0.39560608552802945`, 0.9383888543350487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 147}], {
             RGBColor[
             0.25851974752031004`, 0.38905102411550896`, 0.9380336892243635]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 154}], {
             RGBColor[
             0.29969282708516165`, 0.4301884914479621, 0.9404567196726639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 157}], {
             RGBColor[
             0.23696986749514018`, 0.36640073386774574`, 0.9368064554371207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 168}], {
             RGBColor[
             0.23845610278939203`, 0.36796286139476475`, 0.9368910943384403]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 176}], {
             RGBColor[
             0.25080130431121317`, 0.3809384509251836, 0.937594135302019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 188}], {
             RGBColor[
             0.29035857842231216`, 0.42210363440918097`, 0.939861949601819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 111}], {
             RGBColor[
             0.22370338980181498`, 0.3524568246687931, 0.9360509491584807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 115}], {
             RGBColor[
             0.27114794471103404`, 0.4017434985665935, 0.9387741035720105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 163}], {
             RGBColor[
             0.2545166466581612, 0.38484351129813643`, 0.9378057185523212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 165}], {
             RGBColor[
             0.21653690052978303`, 0.3449243900622238, 0.9356428281963094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 169}], {
             RGBColor[
             0.20968181085613852`, 0.3377192561774346, 0.9352524409805917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 175}], {
             RGBColor[
             0.36392094666961883`, 0.4808157727668374, 0.9450400242191717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 177}], {
             RGBColor[
             0.22233026933066752`, 0.35101358799275084`, 0.9359727519789987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 103}], {
             RGBColor[
             0.18365762005674702`, 0.31036618161827634`, 0.9337704018139066]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 117}], {
             RGBColor[
             0.1857785761820701, 0.31259544098237624`, 0.9338911871275704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 121}], {
             RGBColor[
             0.2017936925772753, 0.329428343730764, 0.9348032243140356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 152}], {
             RGBColor[
             0.19321000522653986`, 0.3204063440879294, 0.9343143960178388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 159}], {
             RGBColor[
             0.22056324507356437`, 0.3491563334627266, 0.9358721225616348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 164}], {
             RGBColor[
             0.19070376679969833`, 0.3177721285966248, 0.9341716694470776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 200}], {
             RGBColor[
             0.18842402865999922`, 0.3153759792680545, 0.9340418417325922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 118}], {
             RGBColor[
             0.31765722646768046`, 0.4436155762000519, 0.9416794866592155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 123}], {
             RGBColor[
             0.34778570453147756`, 0.4697113495975751, 0.9435992466398737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 139}], {
             RGBColor[
             0.26505756074119424`, 0.3959226803319581, 0.938406008015465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 141}], {
             RGBColor[
             0.29413145548178377`, 0.42323873581169885`, 0.9401804453350167]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 146}], {
             RGBColor[
             0.24492541546972163`, 0.3747625191999059, 0.9372595121250946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 171}], {
             RGBColor[
             0.2760986031689815, 0.40752751596608494`, 0.939034779047969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 174}], {
             RGBColor[
             0.2172400978636229, 0.3456634950453756, 0.9356828742441843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 186}], {
             RGBColor[
             0.21375750066891208`, 0.34200306458431906`, 0.9354845454859864]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 191}], {
             RGBColor[
             0.5272753016690297, 0.6129190189586639, 0.9594697403649703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 195}], {
             RGBColor[
             0.372739436043382, 0.49002947459904367`, 0.9455472387434574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 196}], {
             RGBColor[
             0.23871657724306206`, 0.3682366365606061, 0.9369059279732393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 95}], {
             RGBColor[
             0.24029230513765162`, 0.36989282648473865`, 0.9369956633457557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 121}], {
             RGBColor[
             0.22436989011875363`, 0.3531573587604565, 0.9360889053655316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 150}], {
             RGBColor[
             0.21197440955790398`, 0.3401289227721434, 0.9353830010850614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 159}], {
             RGBColor[
             0.24313944261504272`, 0.37288534849241906`, 0.9371578036131307]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 161}], {
             RGBColor[
             0.2576073800376916, 0.38809206804383756`, 0.9379817312459552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 162}], {
             RGBColor[
             0.34139937953517563`, 0.46297232673312194`, 0.9432365284830118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 164}], {
             RGBColor[
             0.2132799643411767, 0.3415011436263172, 0.9354573504985735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 173}], {
             RGBColor[
             0.29957000075540785`, 0.42674182123979476`, 0.9405711974554323]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 180}], {
             RGBColor[
             0.28670982280114365`, 0.41560298146714914`, 0.9397517582879953]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 200}], {
             RGBColor[
             0.21100022620147757`, 0.339104994297747, 0.935327522784088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 174}], {
             RGBColor[
             0.19022197405444352`, 0.31726573387393764`, 0.9341442320629838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 196}], {
             RGBColor[
             0.21169845343388266`, 0.3398388753891681, 0.9353672857920389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 121}], {
             RGBColor[
             0.23327542567236176`, 0.36251764127086494`, 0.9365960624407503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 150}], {
             RGBColor[
             0.2208799451115121, 0.3494892052825519, 0.9358901581602801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 159}], {
             RGBColor[
             0.2520449781686508, 0.3822456310028275, 0.9376649606883494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 161}], {
             RGBColor[
             0.26651291559129975`, 0.397452350554246, 0.9384888883211739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 162}], {
             RGBColor[
             0.35030491508878375`, 0.4723326092435304, 0.9437436855582304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 164}], {
             RGBColor[
             0.22218549989478478`, 0.35086142613672566`, 0.9359645075737923]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 173}], {
             RGBColor[
             0.308475536309016, 0.4361021037502032, 0.9410783545306509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 180}], {
             RGBColor[
             0.2956153583547517, 0.42496326397755757`, 0.9402589153632142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 99}], {
             RGBColor[
             0.7441185775359549, 0.79956600300059, 0.9751875122211435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 102}], {
             RGBColor[
             0.9527960526971394, 0.9643159539076722, 0.964788149409247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 125}], {
             RGBColor[
             0.600349784053201, 0.6736043813543324, 0.9654382177461185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 128}], {
             RGBColor[
             0.683861542921137, 0.7500489673999585, 0.97060899306342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 137}], {
             RGBColor[
             0.630154419316935, 0.7035305563325196, 0.9671868226387048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 166}], {
             RGBColor[
             0.8700729048613844, 0.8993494121193195, 0.9867932099380505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 170}], {
             RGBColor[
             0.7958122133360686, 0.8413363954975833, 0.9793915982124253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 198}], {
             RGBColor[
             0.6410199693439192, 0.7129417496474699, 0.9678791658783956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 105}], {
             RGBColor[
             0.21127795983773054`, 0.3393969099587784, 0.9353433393038026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 134}], {
             RGBColor[
             0.23183626588337625`, 0.3610049930846403, 0.9365141044198138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 135}], {
             RGBColor[
             0.20686780943909605`, 0.33476156227012827`, 0.9350921877628332]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 153}], {
             RGBColor[
             0.24952804077433757`, 0.37960017021835646`, 0.9375216248272185]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 100}], {
             RGBColor[
             0.19914601799870904`, 0.3266454698764268, 0.9346524431636698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 109}], {
             RGBColor[
             0.2049550918267402, 0.33275117478624117`, 0.9349832613244216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 113}], {
             RGBColor[
             0.19847726376767427`, 0.32594256677814204`, 0.9346143585995457]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 116}], {
             RGBColor[
             0.21656444769936758`, 0.34495334388404864`, 0.9356443969668649]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 120}], {
             RGBColor[
             0.19321962278041294`, 0.32041645274683817`, 0.9343149437233039]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 124}], {
             RGBColor[
             0.20926922402508408`, 0.3372856012584804, 0.9352289447709307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 125}], {
             RGBColor[
             0.22839213728314284`, 0.35738499555542924`, 0.936317966391162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 136}], {
             RGBColor[
             0.20765668863834705`, 0.33559072432637116`, 0.9351371132661883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 187}], {
             RGBColor[
             0.1979911315151781, 0.3254316109582035, 0.9345866740869342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 102}], {
             RGBColor[
             0.7604981725449849, 0.8117818781391992, 0.9474611303534258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 109}], {
             RGBColor[
             0.38461485844464394`, 0.49643648481667146`, 0.9467764936235569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 116}], {
             RGBColor[
             0.39622421431727134`, 0.5086386539144789, 0.9474376292660001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 128}], {
             RGBColor[
             0.49156366276898256`, 0.5975148916314856, 0.9532819740075988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 136}], {
             RGBColor[
             0.3873164552562508, 0.49927603435680146`, 0.9469303455653235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 137}], {
             RGBColor[
             0.4378565391647805, 0.5509964805640466, 0.9498598035828838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 162}], {
             RGBColor[
             0.5016163434350541, 0.6062220183620153, 0.9539225219304044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 193}], {
             RGBColor[
             0.3906410080149175, 0.5027703500949796, 0.9471196739266945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 198}], {
             RGBColor[
             0.44872208919176476`, 0.5604076738789969, 0.9505521468225746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 113}], {
             RGBColor[
             0.20512211761839033`, 0.33292672948331237`, 0.9349927731961636]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 120}], {
             RGBColor[
             0.199864476631129, 0.3274006154520085, 0.934693358319922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 124}], {
             RGBColor[
             0.21591407787580016`, 0.3442697639636507, 0.9356073593675487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 125}], {
             RGBColor[
             0.23503699113385892`, 0.36436915826059957`, 0.9366963809877801]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 136}], {
             RGBColor[
             0.21430154248906313`, 0.3425748870315415, 0.9355155278628062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 137}], {
             RGBColor[
             0.26484162639759284`, 0.3942953332387867, 0.9384449858803665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 187}], {
             RGBColor[
             0.2046359853658942, 0.3324157736633738, 0.9349650886835521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 198}], {
             RGBColor[
             0.2757071764245771, 0.40370652655373696`, 0.9391373291200573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 105}], {
             RGBColor[
             0.20097546444375586`, 0.32856833408377506`, 0.9347566274322918]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 134}], {
             RGBColor[
             0.22153377048940157`, 0.350176417209637, 0.9359273925483029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 135}], {
             RGBColor[
             0.1965653140451214, 0.3239329863951249, 0.9345054758913225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 144}], {
             RGBColor[
             0.19734151181877715`, 0.32474881946901846`, 0.9345496792062504]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 128}], {
             RGBColor[
             0.700241137930167, 0.7622648425385679, 0.9428826111957023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 140}], {
             RGBColor[
             0.981449443808876, 0.9827573994159884, 0.747626675734739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 162}], {
             RGBColor[
             0.7102938185962386, 0.7709719692690975, 0.9435231591185078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 172}], {
             RGBColor[
             0.9192581959222914, 0.7380602445354411, 0.5748744102551196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 180}], {
             RGBColor[
             0.6556042618622065, 0.7236026240031248, 0.9400383889234916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 117}], {
             RGBColor[
             0.1832018217377303, 0.30988710868570724`, 0.9337444447739318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 152}], {
             RGBColor[
             0.19063325078220003`, 0.31769801179126034`, 0.9341676536642003]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 178}], {
             RGBColor[
             0.1823641236245055, 0.3090066348555799, 0.933696739105647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 200}], {
             RGBColor[
             0.18584727421565939`, 0.3126676469713855, 0.9338950993789537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 143}], {
             RGBColor[
             0.6113814534238254, 0.6900658551251025, 0.9653536718198579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 154}], {
             RGBColor[
             0.3494855423442635, 0.47712854394966536`, 0.9434898876136137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 158}], {
             RGBColor[
             0.3417223041341413, 0.47040441720375525`, 0.9429952209396267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 160}], {
             RGBColor[
             0.4051454853105788, 0.5253383889970118, 0.9470364899612722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 176}], {
             RGBColor[
             0.300594019570315, 0.4278785034268868, 0.9406273032429688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 181}], {
             RGBColor[
             0.4026365855967863, 0.5231653061658909, 0.9468766250900423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 188}], {
             RGBColor[
             0.34015129368141406`, 0.46904368691088416`, 0.9428951175427689]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 134}], {
             RGBColor[
             0.22631486646654955`, 0.35520165222061295`, 0.936199668891204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 135}], {
             RGBColor[
             0.20134641002226938`, 0.32895822140610087`, 0.9347777522342233]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 144}], {
             RGBColor[
             0.20212260779592514`, 0.3297740544799944, 0.9348219555491514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.20133152966492007`, 0.3289425812070576, 0.9347769048198857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 130}], {
             RGBColor[
             0.1846627044737023, 0.31142258906652903`, 0.933827639884563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 131}], {
             RGBColor[
             0.18326258950309726`, 0.3099509794600067, 0.9337479054082716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 142}], {
             RGBColor[
             0.22351397693716918`, 0.3522577397385811, 0.9360401623760504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 147}], {
             RGBColor[
             0.21727737751825504`, 0.3457026783260606, 0.9356849972653654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 157}], {
             RGBColor[
             0.1957274974930852, 0.3230523880782974, 0.9344577634781225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 176}], {
             RGBColor[
             0.20955893430915817`, 0.33759010513573523`, 0.9352454433430207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 130}], {
             RGBColor[
             0.20096416380479723`, 0.32855645639572767`, 0.9347559838776209]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 131}], {
             RGBColor[
             0.19956404883419218`, 0.32708484678920535`, 0.9346762494013294]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 142}], {
             RGBColor[
             0.23981543626826407`, 0.36939160706777974`, 0.9369685063691083]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[
             0.23357883684934996`, 0.36283654565525925`, 0.9366133412584232]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 154}], {
             RGBColor[
             0.27475191641420155`, 0.4039740129877124, 0.9390363717067235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.2120289568241801, 0.34018625540749603`, 0.9353861074711805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 168}], {
             RGBColor[
             0.21351519211843195`, 0.34174838293451504`, 0.9354707463724999]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 176}], {
             RGBColor[
             0.22586039364025307`, 0.35472397246493387`, 0.9361737873360787]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 188}], {
             RGBColor[
             0.2654176677513521, 0.39588915594893126`, 0.9384416016358788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 111}], {
             RGBColor[
             0.26408143509617243`, 0.39489671038909974`, 0.9383504191040295]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 115}], {
             RGBColor[
             0.3115259900053915, 0.4441833842869002, 0.9410735735175593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 133}], {
             RGBColor[
             0.27857495084464845`, 0.41013031438272207`, 0.9391758033846701]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 151}], {
             RGBColor[
             0.6509649455844404, 0.716416401604573, 0.8457783120147642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 163}], {
             RGBColor[
             0.29489469195251866`, 0.4272833970184431, 0.94010518849787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 165}], {
             RGBColor[
             0.25691494582414054`, 0.38736427578253046`, 0.937942298141858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 175}], {
             RGBColor[
             0.4042989919639763, 0.5232556584871441, 0.9473394941647204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 113}], {
             RGBColor[
             0.2109311914464215, 0.33903243439312675`, 0.9353235913569153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 116}], {
             RGBColor[
             0.2290183753781148, 0.3580432114990334, 0.9363536297242345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 124}], {
             RGBColor[
             0.22172315170383133`, 0.35037546887346516`, 0.9359381775283004]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 128}], {
             RGBColor[
             0.32435782382982603`, 0.44691944921604004`, 0.9421979744658333]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 136}], {
             RGBColor[
             0.22011061631709428`, 0.3486805919413559, 0.935846346023558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 148}], {
             RGBColor[
             0.20549299658683456`, 0.33331654679423195`, 0.9350138942047502]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 193}], {
             RGBColor[
             0.223435169075761, 0.3521749076795341, 0.936035674384929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 138}], {
             RGBColor[
             0.20099999291646117`, 0.32859411506378333`, 0.9347580242925257]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 145}], {
             RGBColor[
             0.18515978669395372`, 0.31194505399684636`, 0.9338559479816391]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 115}], {
             RGBColor[
             0.26758071568904057`, 0.3979941146890951, 0.9385709551564505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 163}], {
             RGBColor[
             0.25094941763616774`, 0.3810941274206381, 0.9376025701367612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 165}], {
             RGBColor[
             0.21296967150778956`, 0.3411750061847254, 0.9354396797807493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 169}], {
             RGBColor[
             0.20611458183414505`, 0.33396987229993624`, 0.9350492925650316]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 175}], {
             RGBColor[
             0.36035371764762536`, 0.477066388889339, 0.9448368758036116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 177}], {
             RGBColor[
             0.21876304030867405`, 0.3472642041152524, 0.9357696035634386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 134}], {
             RGBColor[
             0.5941420485372255, 0.6663173396662936, 0.9607153178159171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 143}], {
             RGBColor[
             0.8985367952768839, 0.9217855718880776, 0.9850776323188054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 156}], {
             RGBColor[
             0.880064299434007, 0.550351383801579, 0.5748087868596949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 160}], {
             RGBColor[
             0.6923008271636373, 0.757058105759987, 0.9667604504602199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 181}], {
             RGBColor[
             0.6897919274498447, 0.754885022928866, 0.9666005855889899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 183}], {
             RGBColor[
             0.9388975158686406, 0.8706580791071786, 0.6258657824409817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 116}], {
             RGBColor[
             0.22254054731904888`, 0.35123460349093416`, 0.9359847269993585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 124}], {
             RGBColor[
             0.2152453236447654, 0.343566860865366, 0.9355692748034243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 128}], {
             RGBColor[
             0.3178799957707601, 0.44011084120794086`, 0.9418290717409573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 136}], {
             RGBColor[
             0.21363278825802834`, 0.3418719839332567, 0.9354774432986821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 148}], {
             RGBColor[
             0.19901516852776863`, 0.3265079387861328, 0.9346449914798742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 187}], {
             RGBColor[
             0.20396723113485943`, 0.331712870565089, 0.934927004119428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 193}], {
             RGBColor[
             0.21695734101669506`, 0.34536629967143495`, 0.9356667716600531]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 198}], {
             RGBColor[
             0.2750384221935423, 0.4030036234554522, 0.939099244555933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 167}], {
             RGBColor[
             0.19037448411434205`, 0.3174260316165872, 0.9341529172852767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 184}], {
             RGBColor[
             0.18161202378548802`, 0.3082161302388885, 0.9336539081324469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 186}], {
             RGBColor[
             0.18224157379578187`, 0.3088778272154834, 0.9336897600741974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 194}], {
             RGBColor[
             0.19146855650738448`, 0.3185759710698711, 0.9342152230895253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 133}], {
             RGBColor[
             0.2820742314375166, 0.41322771868271746`, 0.939396339437091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 163}], {
             RGBColor[
             0.2983939725453868, 0.4303808013184385, 0.9403257245502908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 165}], {
             RGBColor[
             0.2604142264170086, 0.39046168008252585`, 0.9381628341942789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 175}], {
             RGBColor[
             0.4077982725568444, 0.5263530627871394, 0.9475600302171414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 124}], {
             RGBColor[
             0.2333325075764587, 0.3625776379712726, 0.9365993131707435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 128}], {
             RGBColor[
             0.33596717970245343`, 0.45912161831384746`, 0.9428591101082765]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 136}], {
             RGBColor[
             0.23171997218972168`, 0.36088276103916334`, 0.9365074816660013]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 148}], {
             RGBColor[
             0.21710235245946194`, 0.3455187158920394, 0.9356750298471934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 193}], {
             RGBColor[
             0.2350445249483884, 0.36437707677734155`, 0.9366968100273723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 198}], {
             RGBColor[
             0.29312560612523564`, 0.42201440056135886`, 0.9401292829232522]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 121}], {
             RGBColor[
             0.2013378942582586, 0.3289492707981949, 0.9347772672740609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 152}], {
             RGBColor[
             0.19275420690752315`, 0.3199272711553603, 0.934288438977864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 159}], {
             RGBColor[
             0.22010744675454766`, 0.3486772605301575, 0.9358461655216599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 164}], {
             RGBColor[
             0.19024796848068162`, 0.3172930556640557, 0.9341457124071029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 178}], {
             RGBColor[
             0.18448507974982858`, 0.3112358942196798, 0.9338175244193107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 200}], {
             RGBColor[
             0.1879682303409825, 0.3148969063354854, 0.9340158846926173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 119}], {
             RGBColor[
             0.6188466529284243, 0.4369505973479967, 0.5693002587660235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 123}], {
             RGBColor[
             0.42099591367325284`, 0.5390672333790665, 0.9480464652405584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 127}], {
             RGBColor[
             0.6328274279834254, 0.7079836098876566, 0.9670229522085898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 129}], {
             RGBColor[
             0.4226691844013287, 0.5404852315434163, 0.9481617341921013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 139}], {
             RGBColor[
             0.33826776988296947`, 0.4652785641134494, 0.9428532266161497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[
             0.36734166462355905`, 0.4925946195931902, 0.9446276639357014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 146}], {
             RGBColor[
             0.3181356246114969, 0.44411840298139715`, 0.9417067307257794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 155}], {
             RGBColor[
             0.5320287520312512, 0.6287959624909311, 0.9570938290152922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 171}], {
             RGBColor[
             0.3493088123107567, 0.4768833997475762, 0.9434819976486537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 191}], {
             RGBColor[
             0.6004855108108049, 0.6822749027401551, 0.9639169589656551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.44594964518515734`, 0.559385358380535, 0.9499944573441421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 196}], {
             RGBColor[
             0.3119267863848373, 0.4375925203420974, 0.941353146573924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[
             0.6930640728290565, 0.752639828019768, 0.8371662674251406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 123}], {
             RGBColor[
             0.6489751309922214, 0.46304637074551996`, 0.5712200187466816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 127}], {
             RGBColor[
             0.8608066453023939, 0.6319627472541103, 0.5901965057147129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 140}], {
             RGBColor[
             0.9202745550794877, 0.6749563522500728, 0.37533269810004777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 151}], {
             RGBColor[
             0.9203645260018751, 0.6763382789683456, 0.4715886994182685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 155}], {
             RGBColor[
             0.7600079693502197, 0.5527750998573846, 0.5802673825214153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 156}], {
             RGBColor[
             0.8327717722765755, 0.2529037791657479, 0.17901559218345872`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 172}], {
             RGBColor[
             0.858083307192903, 0.43025919736952545`, 0.20258043262042846`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 191}], {
             RGBColor[
             0.8284647281297735, 0.6062540401066088, 0.5870905124717782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 195}], {
             RGBColor[
             0.6739288625041259, 0.48336449574698853`, 0.5731680108502653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 199}], {
             RGBColor[
             0.921043290148025, 0.6766189653862216, 0.46033982093126385`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 124}], {
             RGBColor[
             0.20998768265750406`, 0.3380407468340621, 0.9352698599271827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 125}], {
             RGBColor[
             0.22911059591556282`, 0.35814014113101095`, 0.9363588815474142]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 136}], {
             RGBColor[
             0.208375147270767, 0.3363458699019528, 0.9351780284224404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 137}], {
             RGBColor[
             0.2589152311792967, 0.38806631610919806`, 0.9381074864400005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 187}], {
             RGBColor[
             0.1987095901475981, 0.32618675653378515`, 0.9346275892431862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 198}], {
             RGBColor[
             0.26978078120628096`, 0.39747750942414833`, 0.9387998296796913]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 152}], {
             RGBColor[
             0.20876932330272832`, 0.33676017390374813`, 0.9352004761643293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 159}], {
             RGBColor[
             0.23612256314975283`, 0.36551016327854535`, 0.9367582027081254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 161}], {
             RGBColor[
             0.25059050057240173`, 0.38071688282996385`, 0.9375821303409498]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 164}], {
             RGBColor[
             0.2062630848758868, 0.3341259584124435, 0.9350577495935681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 173}], {
             RGBColor[
             0.292553121290118, 0.41936663602592106`, 0.9401715965504269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 180}], {
             RGBColor[
             0.27969294333585376`, 0.40822779625327543`, 0.9393521573829899]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[
             0.20398334673618768`, 0.33172980908387323`, 0.9349279218790827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 125}], {
             RGBColor[
             0.2711034312291314, 0.40227727354510906`, 0.9387503113956892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 137}], {
             RGBColor[
             0.3009080664928653, 0.4322034485232962, 0.9404989162882755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 166}], {
             RGBColor[
             0.5408265520373148, 0.6280223043100961, 0.9601053035876213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 170}], {
             RGBColor[
             0.4665658605119989, 0.5700092876883599, 0.9527036918619959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 179}], {
             RGBColor[
             0.32323201256899053`, 0.45153932858028145`, 0.9419213783919558]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 192}], {
             RGBColor[
             0.3718189687016956, 0.49328632243521403`, 0.9451102958483188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 127}], {
             RGBColor[
             0.6629559060472224, 0.73407938328518, 0.9689427121892478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 129}], {
             RGBColor[
             0.45279766246512576`, 0.5665810049409397, 0.9500814941727593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 139}], {
             RGBColor[
             0.36839624794676656`, 0.4913743375109727, 0.9447729865968078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 141}], {
             RGBColor[
             0.39747014268735614`, 0.5186903929907134, 0.9465474239163595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 146}], {
             RGBColor[
             0.34826410267529395`, 0.47021417637892043`, 0.9436264907064373]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 155}], {
             RGBColor[
             0.5621572300950483, 0.6548917358884543, 0.9590135889959501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 171}], {
             RGBColor[
             0.3794372903745538, 0.5029791731450995, 0.9454017576293117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 191}], {
             RGBColor[
             0.6306139888746021, 0.7083706761376785, 0.9658367189463131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 195}], {
             RGBColor[
             0.4760781232489544, 0.5854811317780583, 0.9519142173248001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 196}], {
             RGBColor[
             0.3420552644486344, 0.4636882937396207, 0.9432729065545822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 199}], {
             RGBColor[
             0.7231925508928534, 0.7787356014172913, 0.8390860274057987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 125}], {
             RGBColor[
             0.24516019716023396`, 0.37500928964265323`, 0.9372728825950409]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 136}], {
             RGBColor[
             0.22442474851543817`, 0.35321501841359515`, 0.9360920294700671]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.27496483242396785`, 0.4049354646208403, 0.9390214874876273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 187}], {
             RGBColor[
             0.21475919139226923`, 0.3430559050454275, 0.935541590290813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 198}], {
             RGBColor[
             0.28583038245095216`, 0.4143466579357906, 0.9397138307273181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 136}], {
             RGBColor[
             0.24354766177349693`, 0.373314412710544, 0.9371810510902985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 137}], {
             RGBColor[
             0.29408774568202667`, 0.42503485891778914`, 0.9401105091078588]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 166}], {
             RGBColor[
             0.5340062312264762, 0.620853714704589, 0.9597168964072044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[
             0.4597455397011603, 0.5628406980828529, 0.952315284681579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 187}], {
             RGBColor[
             0.233882104650328, 0.36315529934237634`, 0.9366306119110444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 192}], {
             RGBColor[
             0.364998647890857, 0.48611773282970705`, 0.9447218886679021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 198}], {
             RGBColor[
             0.30495329570901086`, 0.43444605223273947`, 0.9408028523475496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 190}], {
             RGBColor[
             0.18192592123823295`, 0.3085460563639715, 0.933671784128011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 129}], {
             RGBColor[
             0.6646291767752983, 0.7354973814495299, 0.9690579811407907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 139}], {
             RGBColor[
             0.5802277622569392, 0.660290714019563, 0.9637494735648391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 140}], {
             RGBColor[
             0.9342553301344888, 0.9459893647897327, 0.7730553915426139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 141}], {
             RGBColor[
             0.6093016569975287, 0.6876067694993037, 0.9655239108843909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 155}], {
             RGBColor[
             0.7739887444052208, 0.8238081123970447, 0.9779900759639816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 172}], {
             RGBColor[
             0.8720640822479042, 0.7012922099091854, 0.6003031260629946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 191}], {
             RGBColor[
             0.8424455031847746, 0.8772870526462687, 0.9848132059143445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 195}], {
             RGBColor[
             0.6879096375591269, 0.7543975082866485, 0.9708907042928315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 199}], {
             RGBColor[
             0.935024065203026, 0.9476519779258816, 0.8580625143738301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 136}], {
             RGBColor[
             0.3270594206414329, 0.44975899875617, 0.9423518264076001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 162}], {
             RGBColor[
             0.4413593088202362, 0.5567049827613839, 0.9493440027726809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 193}], {
             RGBColor[
             0.3303839734000996, 0.45325331449434825`, 0.942541154768971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 198}], {
             RGBColor[
             0.38846505457694686`, 0.5108906382783656, 0.9459736276648509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 139}], {
             RGBColor[
             0.3700695186748425, 0.49279233567532266`, 0.9448882555483507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 141}], {
             RGBColor[
             0.399143413415432, 0.5201083911550634, 0.9466626928679024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 146}], {
             RGBColor[
             0.3499373734033699, 0.4716321745432704, 0.9437417596579802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 155}], {
             RGBColor[
             0.5638305008231241, 0.6563097340528043, 0.959128857947493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 191}], {
             RGBColor[
             0.632287259602678, 0.7097886743020284, 0.965951987897856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 195}], {
             RGBColor[
             0.47775139397703026`, 0.5868991299424082, 0.952029486276343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 131}], {
             RGBColor[
             0.18289522364297445`, 0.3095648546486768, 0.9337269844660065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 149}], {
             RGBColor[
             0.1848995905074315, 0.3116715713074204, 0.9338411301937424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 157}], {
             RGBColor[
             0.19536013163296237`, 0.32266626326696746`, 0.9344368425358576]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 168}], {
             RGBColor[
             0.19684636692721422`, 0.32422839079398647`, 0.9345214814371772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 189}], {
             RGBColor[
             0.18936342684036145`, 0.3163633463169, 0.9340953390692487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 197}], {
             RGBColor[
             0.19250062713784824`, 0.3196607427395459, 0.9342739979851187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 147}], {
             RGBColor[
             0.21550989668752718`, 0.3438449439082084, 0.9355843418468089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 157}], {
             RGBColor[
             0.19396001666235732`, 0.3211946536604452, 0.9343571080595661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 176}], {
             RGBColor[
             0.20779145347843028`, 0.335732370717883, 0.9351447879244643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 138}], {
             RGBColor[
             0.2612195562179643, 0.3918886942345018, 0.9381874393356859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 145}], {
             RGBColor[
             0.24537934999545682`, 0.37523963316756476`, 0.9372853630247993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 153}], {
             RGBColor[
             0.29141110867079584`, 0.42362193011741534`, 0.9399068035834754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 182}], {
             RGBColor[
             0.3206991952751244, 0.45143891338558356`, 0.9416833404765177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 185}], {
             RGBColor[
             0.26630785953473646`, 0.397236823637493, 0.9384772106821059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 163}], {
             RGBColor[
             0.26544293338464375`, 0.39632773141426036`, 0.9384279544174017]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 178}], {
             RGBColor[
             0.21638528695668868`, 0.3447650345840459, 0.9356341940276138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 135}], {
             RGBColor[
             0.22190471606791506`, 0.3505663045319628, 0.9359485173502345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 160}], {
             RGBColor[
             0.3450319511386071, 0.4675505014401682, 0.9434155666515178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 144}], {
             RGBColor[
             0.19771245739729065`, 0.32513870679134427`, 0.9345708040081819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 148}], {
             RGBColor[
             0.2081945933984414, 0.33615609633436194`, 0.9351677461465169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 187}], {
             RGBColor[
             0.2131466560055322, 0.3413610281133182, 0.9354497587860706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 193}], {
             RGBColor[
             0.22613676588736786`, 0.35501445721966407`, 0.9361895263266957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 198}], {
             RGBColor[
             0.2842178470642151, 0.4126517810036814, 0.9396219992225757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 166}], {
             RGBColor[
             0.5638108664902101, 0.6507798896827761, 0.9614655012997908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 170}], {
             RGBColor[
             0.48955017496489417`, 0.59276687306104, 0.9540638895741654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 179}], {
             RGBColor[
             0.3462163270218858, 0.4742969139529616, 0.9432815761041253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 187}], {
             RGBColor[
             0.2636867399140619, 0.3930814743205634, 0.9383792168036308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 192}], {
             RGBColor[
             0.3948032831545909, 0.5160439078078941, 0.9464704935604884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 198}], {
             RGBColor[
             0.3347579309727448, 0.4643722272109265, 0.9425514572401359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 145}], {
             RGBColor[
             0.20603341116594734`, 0.3338845567811428, 0.935044670015559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 153}], {
             RGBColor[
             0.25206516984128635`, 0.38226685373099345`, 0.9376661105742352]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 182}], {
             RGBColor[
             0.28135325644561493`, 0.4100838369991616, 0.9394426474672775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 185}], {
             RGBColor[
             0.22696192070522694`, 0.35588174725107113`, 0.9362365176728656]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 141}], {
             RGBColor[
             0.31474199889707277`, 0.4449017237250964, 0.9413541852919508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 146}], {
             RGBColor[
             0.2655359588850107, 0.39642550711330343`, 0.9384332520820287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 155}], {
             RGBColor[
             0.47942908630476494`, 0.5811030666228374, 0.9538203503715414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 171}], {
             RGBColor[
             0.2967091465842705, 0.42919050387948254`, 0.940208519004903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 191}], {
             RGBColor[
             0.5478858450843187, 0.6345820068720615, 0.9606434803219044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 194}], {
             RGBColor[
             0.2435950267958037, 0.37336419635210427`, 0.9371837484582486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 195}], {
             RGBColor[
             0.39334997945867106`, 0.5116924625124413, 0.9467209787003914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 196}], {
             RGBColor[
             0.25932712065835106`, 0.3898996244740037, 0.9380796679301735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 151}], {
             RGBColor[
             0.9938132108339699, 0.9903648965039682, 0.6544475852461695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 161}], {
             RGBColor[
             0.6387756152014612, 0.7023172809495201, 0.7488332700746612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 162}], {
             RGBColor[
             0.7225676146989453, 0.7771975396388044, 0.7540880673117176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 172}], {
             RGBColor[
             0.931531992024998, 0.7442858149051479, 0.38543931844832946`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 173}], {
             RGBColor[
             0.6807382359191774, 0.7409670341454773, 0.7514227362841381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 180}], {
             RGBColor[
             0.6678780579649132, 0.7298281943728316, 0.7506032971167013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 191}], {
             RGBColor[
             0.9019134129618684, 0.9202806576422312, 0.7699493982996792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 146}], {
             RGBColor[
             0.2946098536256002, 0.4237415625930442, 0.9402076894015805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 155}], {
             RGBColor[
             0.5085029810453545, 0.6084191221025781, 0.9555947876910933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 167}], {
             RGBColor[
             0.27157484914335084`, 0.3995303123785612, 0.9388958799735516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 191}], {
             RGBColor[
             0.5769597398249082, 0.6618980623518022, 0.9624179176414562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 194}], {
             RGBColor[
             0.2726689215363932, 0.40068025183184497`, 0.9389581857778003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 195}], {
             RGBColor[
             0.42242387419926064`, 0.539008517992182, 0.9484954160199432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 147}], {
             RGBColor[
             0.25576128412159904`, 0.3861517041867828, 0.9378765988145878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 154}], {
             RGBColor[
             0.29693436368645065`, 0.4272891715192359, 0.9402996292628881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 157}], {
             RGBColor[
             0.2342114040964292, 0.3635014139390195, 0.9366493650273451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 168}], {
             RGBColor[
             0.23569763939068106`, 0.3650635414660385, 0.9367340039286646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 176}], {
             RGBColor[
             0.24804284091250217`, 0.37803913099645736`, 0.9374370448922433]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.2876001150236012, 0.4192043144804547, 0.9397048591920434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 154}], {
             RGBColor[
             0.5937667549119501, 0.6748088886146058, 0.9642312788067474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 158}], {
             RGBColor[
             0.5860035167018279, 0.6680847618686957, 0.9637366121327604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 160}], {
             RGBColor[
             0.6494266978782655, 0.7230187336619522, 0.967777881154406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 181}], {
             RGBColor[
             0.6469177981644729, 0.7208456508308313, 0.967618016283176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 188}], {
             RGBColor[
             0.5844325062491007, 0.6667240315758246, 0.9636365087359027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 158}], {
             RGBColor[
             0.2574165112915451, 0.3871889319062931, 0.9379965842878197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 153}], {
             RGBColor[
             0.2362249636187789, 0.3656177926640565, 0.9367640342633485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 185}], {
             RGBColor[
             0.2111217144827195, 0.33923268618413416`, 0.935334441361979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 155}], {
             RGBColor[
             0.4592969410332923, 0.5599429054907851, 0.9526738544811711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 171}], {
             RGBColor[
             0.27657700131279794`, 0.4080303427474302, 0.9390620231145327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 184}], {
             RGBColor[
             0.21360634880243462`, 0.34184419438906943`, 0.9354759376107997]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 186}], {
             RGBColor[
             0.2142358988127285, 0.34250589136566434`, 0.9355117895525502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 191}], {
             RGBColor[
             0.527753699812846, 0.6134218457400091, 0.9594969844315341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 194}], {
             RGBColor[
             0.22346288152433108`, 0.352204035220052, 0.9360372525678782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 195}], {
             RGBColor[
             0.37321783418719845`, 0.490532301380389, 0.9455744828100211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 196}], {
             RGBColor[
             0.23919497538687848`, 0.3687394633419514, 0.9369331720398031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 154}], {
             RGBColor[
             0.2906977642675366, 0.42073411010671546`, 0.939944464152203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 157}], {
             RGBColor[
             0.2279748046775151, 0.3569463525264991, 0.9362941999166599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 168}], {
             RGBColor[
             0.22946103997176695`, 0.35850848005351804`, 0.9363788388179795]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 176}], {
             RGBColor[
             0.24180624149358806`, 0.37148406958393687`, 0.9370818797815581]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 188}], {
             RGBColor[
             0.2813635156046871, 0.41264925306793426`, 0.9393496940813583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 150}], {
             RGBColor[
             0.19306951159997304`, 0.3202586763785973, 0.9343063951136474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 193}], {
             RGBColor[
             0.21151914615710812`, 0.33965041207254015`, 0.9353570745078879]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 167}], {
             RGBColor[
             0.19241882352516138`, 0.31957476195596346`, 0.9342693393903937]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 168}], {
             RGBColor[
             0.19745061882106624`, 0.32486349784620777`, 0.9345558926886215]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 189}], {
             RGBColor[
             0.18996767873421347`, 0.31699845336912136`, 0.934129750320693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 194}], {
             RGBColor[
             0.1935128959182038, 0.3207247014092473, 0.9343316451946424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.19310487903170026`, 0.3202958497917673, 0.934308409236563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 156}], {
             RGBColor[
             0.9063104280310577, 0.5683123234196433, 0.4581304793295804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 172}], {
             RGBColor[
             0.9316219629473853, 0.7456677416234209, 0.4816953197665501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 175}], {
             RGBColor[
             0.7472372281358932, 0.7985860801048122, 0.8522647687143463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 183}], {
             RGBColor[
             0.9651436444656913, 0.888619018725243, 0.5091874749108671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 199}], {
             RGBColor[
             0.9945819459025071, 0.992027509640117, 0.7394547080773856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 159}], {
             RGBColor[
             0.22753887579901738`, 0.3564881636357107, 0.9362693744119284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 178}], {
             RGBColor[
             0.19191650879429833`, 0.319046797325233, 0.9342407333095791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 200}], {
             RGBColor[
             0.19539965938545223`, 0.3227078094410386, 0.9344390935828858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 182}], {
             RGBColor[
             0.3115448088984465, 0.4418170728820753, 0.941162011715067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 185}], {
             RGBColor[
             0.2571534731580585, 0.38761498313398474`, 0.937955881920655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 157}], {
             RGBColor[
             0.2691478842423667, 0.3980838198589522, 0.9387172303649602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 158}], {
             RGBColor[
             0.3241076056222659, 0.45514745069325846`, 0.9418728279265163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 160}], {
             RGBColor[
             0.38753078679870345`, 0.510081422486515, 0.9459140969481619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 176}], {
             RGBColor[
             0.28297932105843965`, 0.41262153691639003`, 0.9395049102298585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 181}], {
             RGBColor[
             0.3850218870849109, 0.5079083396553941, 0.9457542320769319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 188}], {
             RGBColor[
             0.3225365951695387, 0.45378672040038737`, 0.9417727245296585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 172}], {
             RGBColor[
             0.77126540629573, 0.6221045625124598, 0.590374002869697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 191}], {
             RGBColor[
             0.7416468272326004, 0.7980994052495431, 0.9748840827210469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 195}], {
             RGBColor[
             0.5871109616069528, 0.6752098608899229, 0.9609615810995339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 199}], {
             RGBColor[
             0.8342253892508518, 0.868464330529156, 0.8481333911805324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 166}], {
             RGBColor[
             0.8112235131702088, 0.49573828454331076`, 0.5733146303469535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 170}], {
             RGBColor[
             0.7369628216448929, 0.4377252679215747, 0.5659130186213281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 175}], {
             RGBColor[
             0.6596444744105936, 0.3751515803022144, 0.5596916614795366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 183}], {
             RGBColor[
             0.8775508907403917, 0.4651845189226452, 0.21661436767605732`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 199}], {
             RGBColor[
             0.9069891921772075, 0.5685930098375191, 0.4468816008425758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 168}], {
             RGBColor[
             0.2079111599465971, 0.33585818980575477`, 0.9351516050307367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 176}], {
             RGBColor[
             0.2202563614684182, 0.34883377933617365`, 0.9358546459943153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 188}], {
             RGBColor[
             0.25981363557951725`, 0.389998962820171, 0.9381224602941154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 160}], {
             RGBColor[
             0.3797675485885813, 0.503357295740605, 0.945419430274175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 176}], {
             RGBColor[
             0.27521608284831744`, 0.40589741017048, 0.9390102435558715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.37725864887478877`, 0.501184212909484, 0.945259565402945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 161}], {
             RGBColor[
             0.2693600530686908, 0.4004448725619264, 0.938651028588549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 162}], {
             RGBColor[
             0.3531520525661749, 0.4753251312512108, 0.9439058258256054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 164}], {
             RGBColor[
             0.22503263737217588`, 0.35385394814440607`, 0.9361266478411673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 173}], {
             RGBColor[
             0.3113226737864071, 0.4390946257578836, 0.941240494798026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 180}], {
             RGBColor[
             0.29846249583214285`, 0.427955785985238, 0.9404210556305891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 200}], {
             RGBColor[
             0.22275289923247676`, 0.35145779881583583`, 0.9359968201266817]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[
             0.4406818300512263, 0.5561181847027405, 0.9493008344245906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 162}], {
             RGBColor[
             0.3676199899888237, 0.4905318508026293, 0.94472975345843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 164}], {
             RGBColor[
             0.23950057479482478`, 0.3690606676958246, 0.9369505754739917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 173}], {
             RGBColor[
             0.32579061120905595`, 0.4543013453093021, 0.9420644224308505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 180}], {
             RGBColor[
             0.31293043325479175`, 0.4431625055366565, 0.9412449832634135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 200}], {
             RGBColor[
             0.23722083665512567`, 0.36666451836725433`, 0.9368207477595063]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 172}], {
             RGBColor[
             0.6603763668123606, 0.5325003847582571, 0.5813358018320983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 173}], {
             RGBColor[
             0.40958261070654, 0.5291816039985865, 0.947319219667907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 180}], {
             RGBColor[
             0.3967224327522758, 0.5180427642259409, 0.9464997805004701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 165}], {
             RGBColor[
             0.24378292836413576`, 0.3735616928140688, 0.9371944491745896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 175}], {
             RGBColor[
             0.39116697450397153`, 0.5094530755186824, 0.9465916451974521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 177}], {
             RGBColor[
             0.24957629716502022`, 0.3796508907445958, 0.937524372957279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 200}], {
             RGBColor[
             0.19289342095861073`, 0.320073593949734, 0.9342963670121247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 169}], {
             RGBColor[
             0.1989480925621131, 0.32643743769336697`, 0.9346411716028602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 175}], {
             RGBColor[
             0.35318722837559335`, 0.4695339542827697, 0.9444287548414402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 177}], {
             RGBColor[
             0.2115965510366421, 0.3397317695086831, 0.9353614826012671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 170}], {
             RGBColor[
             0.7294686605093437, 0.78858572884784, 0.973670276873511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 179}], {
             RGBColor[
             0.5861348125663353, 0.6701157697397615, 0.962887963403471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 183}], {
             RGBColor[
             0.8700567296048425, 0.8160449798489104, 0.6243716259282402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 192}], {
             RGBColor[
             0.6347217686990404, 0.711862763594694, 0.9660768808598341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 198}], {
             RGBColor[
             0.5746764165171943, 0.6601910829977264, 0.9621578445394816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 189}], {
             RGBColor[
             0.19688265985809134`, 0.32426653696544305`, 0.9345235482659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 194}], {
             RGBColor[
             0.2004278770420817, 0.327992785005569, 0.9347254431398494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 197}], {
             RGBColor[
             0.20001986015557813`, 0.327563933388089, 0.9347022071817699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 188}], {
             RGBColor[
             0.2612998708737691, 0.39156109034719, 0.938207099195435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 189}], {
             RGBColor[
             0.2019144551539962, 0.3295552728556873, 0.9348101015641277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 197}], {
             RGBColor[
             0.20505165545148296`, 0.3328526692783333, 0.9349887604799977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 177}], {
             RGBColor[
             0.20474146136299756`, 0.33252663562389395`, 0.9349710953855495]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 190}], {
             RGBColor[
             0.18813962732028144`, 0.31507705542792475`, 0.9340256454970293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 179}], {
             RGBColor[
             0.5118741210410194, 0.6121027531180253, 0.9554863516778458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 183}], {
             RGBColor[
             0.7957960380795266, 0.7580319632271744, 0.6169700142026149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[
             0.5604610771737245, 0.6538497469729578, 0.9586752691342088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 198}], {
             RGBColor[
             0.5004157249918784, 0.6021780663759904, 0.9547562328138562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 174}], {
             RGBColor[
             0.24889168370669917`, 0.37893131859289997`, 0.9374853852336225]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 182}], {
             RGBColor[
             0.3242915422574164, 0.45521469783192636`, 0.9418879193227581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 191}], {
             RGBColor[
             0.558926887512106, 0.6461868425061883, 0.9612722513544084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 195}], {
             RGBColor[
             0.4043910218864583, 0.5232972981465681, 0.9473497497328954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 196}], {
             RGBColor[
             0.2703681630861383, 0.4015044601081305, 0.9387084389626774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 199}], {
             RGBColor[
             0.6515054495303574, 0.7165517677858011, 0.834521559813894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 173}], {
             RGBColor[
             0.6185469880325928, 0.49626987926492994`, 0.5786704708045187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 180}], {
             RGBColor[
             0.6056868100783286, 0.4851310394922843, 0.577851031637082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 191}], {
             RGBColor[
             0.8397221650752837, 0.6755835027616839, 0.59719713282006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 180}], {
             RGBColor[
             0.35489305397250803`, 0.4818122587326137, 0.9438344494728906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 186}], {
             RGBColor[
             0.18655058120662976`, 0.3134068672111341, 0.9339351516716399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 196}], {
             RGBColor[
             0.21150965778077974`, 0.33964043918742115`, 0.9353565341588927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 183}], {
             RGBColor[
             0.7184776908452273, 0.695458275607814, 0.6107486570608233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 188}], {
             RGBColor[
             0.2736450723955902, 0.4045366798776089, 0.9389101401590136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 179}], {
             RGBColor[
             0.2929650964677688, 0.41972688072457853`, 0.940197722295881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 190}], {
             RGBColor[
             0.20078808579481044`, 0.3283713872432409, 0.9347459564954362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 183}], {
             RGBColor[
             0.6524621901365182, 0.6395620041190959, 0.6061877007325749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 192}], {
             RGBColor[
             0.41712722923071616`, 0.5353797878648794, 0.9478929556641686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 185}], {
             RGBColor[
             0.28644155976238705`, 0.41543196640215296`, 0.9397324188136974]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 195}], {
             RGBColor[
             0.42093237513181697`, 0.5377166564648852, 0.9484003790182465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 196}], {
             RGBColor[
             0.28690951633149697`, 0.41592381842644754`, 0.9397590682480286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 199}], {
             RGBColor[
             0.668046802775716, 0.7309711261041182, 0.8355721890992451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 192}], {
             RGBColor[
             0.7010491462692232, 0.6813089979740284, 0.609376618188938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 186}], {
             RGBColor[
             0.18243843400162507`, 0.3090847397734826, 0.9337009709716915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 194}], {
             RGBColor[
             0.19166541671322765`, 0.3187828836278702, 0.9342264339870195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 198}], {
             RGBColor[
             0.2745522899410462, 0.4024926676355137, 0.9390715600433216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 194}], {
             RGBColor[
             0.19797673225113377`, 0.32541647641872684`, 0.9345858540701487]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 197}], {
             RGBColor[
             0.19756871536463022`, 0.3249876248012469, 0.9345626181120692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 195}], {
             RGBColor[
             0.6555677203865065, 0.728688801139147, 0.9677847110498968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 199}], {
             RGBColor[
             0.9026821480304056, 0.9219432707783801, 0.8549565211308954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 197}], {
             RGBColor[
             0.20111393254862053`, 0.3287138728413728, 0.9347645129860187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 196}], {
             RGBColor[
             0.3670089959605389, 0.4840064187410893, 0.9452208986581658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 199}], {
             RGBColor[
             0.748146282404758, 0.7990537264187598, 0.8410340195093824]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.04610843439966642], {
             RGBColor[
             0.17991592983646426`, 0.30643342795989703`, 0.9335573180911961]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.04610843439966642], {
             RGBColor[
             0.18237351643808017`, 0.30901650729818564`, 0.9336972740124846]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.04610843439966642], {
             RGBColor[
             0.4186929718519593, 0.5370725409226834, 0.947899723824117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.04610843439966642], {
             RGBColor[
             0.33430755049502603`, 0.4639821302779076, 0.9425227593943515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.04610843439966642], {
             RGBColor[
             0.35433408061295757`, 0.481328104103389, 0.9437988321847008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.04610843439966642], {
             RGBColor[
             0.8314330293974257, 0.24261361475573226`, 0.17773361049049105`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.04610843439966642], {
             RGBColor[
             0.20849433214894747`, 0.33647114076567824`, 0.9351848158249345]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.04610843439966642], {
             RGBColor[
             0.28326421471662644`, 0.41505902802867256`, 0.939442850025035]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.04610843439966642], {
             RGBColor[
             0.19331350997927296`, 0.32051513414563226`, 0.9343202904603853]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.04610843439966642], {
             RGBColor[
             0.2179504265625759, 0.34641009554541596`, 0.9357233264127526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.04610843439966642], {
             RGBColor[
             0.20295626314304663`, 0.3306502791066209, 0.9348694309878873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.04610843439966642], {
             RGBColor[
             0.950102117301832, 0.8398785531251466, 0.2787091962084557]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.04610843439966642], {
             RGBColor[
             0.22110598802207443`, 0.3497267907135012, 0.9359030309696362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.04610843439966642], {
             RGBColor[
             0.17925722738073346`, 0.3057410899147761, 0.9335198059608052]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.04610843439966642], {
             RGBColor[
             0.1871756577266932, 0.3140638622658612, 0.9339707488547396]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.04610843439966642], {
             RGBColor[
             0.19146922694525287`, 0.31857667574257903`, 0.9342152612699701]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.04610843439966642], {
             RGBColor[
             0.22306772190849825`, 0.3517886974092449, 0.9360147488123428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.04610843439966642], {
             RGBColor[
             0.35121665541737046`, 0.47862794708531764`, 0.9436001926078689]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.04610843439966642], {
             RGBColor[
             0.1823235017276304, 0.3089639386663871, 0.9336944257487145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.04610843439966642], {
             RGBColor[
             0.36130368564417137`, 0.48736482567889206`, 0.94424292925431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.04610843439966642], {
             RGBColor[
             0.18848942771341942`, 0.31544471781973865`, 0.9340455661119352]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.04610843439966642], {
             RGBColor[
             0.22363768830217948`, 0.3523877682269605, 0.9360472075552733]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.04610843439966642], {
             RGBColor[
             0.2571472380542651, 0.3876084296445695, 0.9379555268407181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.04610843439966642], {
             RGBColor[
             0.17953882470990998`, 0.3060370665620425, 0.9335358425121159]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.04610843439966642], {
             RGBColor[
             0.2927822195605681, 0.4250630545960175, 0.9399848863202711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.04610843439966642], {
             RGBColor[
             0.26652048668465833`, 0.39746030825340095`, 0.9384893194837403]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.04610843439966642], {
             RGBColor[
             0.1792907180836107, 0.3057762907669333, 0.933521713206789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.04610843439966642], {
             RGBColor[
             0.20691074357712266`, 0.33480668877137576`, 0.9350946327984784]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.04610843439966642], {
             RGBColor[
             0.2095661987749073, 0.33759774054983127`, 0.9352458570435983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.04610843439966642], {
             RGBColor[
             0.531961775829707, 0.6309095600802831, 0.9562971261149575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.04610843439966642], {
             RGBColor[
             0.186006868294159, 0.3128353904667376, 0.9339041880256258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.04610843439966642], {
             RGBColor[
             0.9926235425767636, 0.9912176595362523, 0.7719105193703001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.04610843439966642], {
             RGBColor[
             0.4300571649791395, 0.5469156338284925, 0.9486238401612196]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.04610843439966642], {
             RGBColor[
             0.18077756667952594`, 0.30733906291288604`, 0.933606387034731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.04610843439966642], {
             RGBColor[
             0.18255152448721731`, 0.309203605044191, 0.9337074113075435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.04610843439966642], {
             RGBColor[
             0.23584637567939642`, 0.36521987273590373`, 0.9367424742402714]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.04610843439966642], {
             RGBColor[
             0.18112444186066054`, 0.30770365072141526`, 0.9336261410631407]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.04610843439966642], {
             RGBColor[
             0.25206224059906557`, 0.3822637749116947, 0.9376659437582241]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.04610843439966642], {
             RGBColor[
             0.5058302216121423, 0.609694787153362, 0.9542399544439137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.04610843439966642], {
             RGBColor[
             0.29070628845368207`, 0.422881119381046, 0.9398666651147989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.04610843439966642], {
             RGBColor[
             0.2027701922068055, 0.3304547067550528, 0.9348588345233357]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.04610843439966642], {
             RGBColor[
             0.18974733652345127`, 0.3167668597351072, 0.9341172021577572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.04610843439966642], {
             RGBColor[
             0.8987739036289236, 0.6332377629819576, 0.2372468027203504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.04610843439966642], {
             RGBColor[
             0.7110429824499928, 0.7741914491075349, 0.9718337774823064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.04610843439966642], {
             RGBColor[
             0.18297903858873563`, 0.3096529494708463, 0.9337317576031746]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.04610843439966642], {
             RGBColor[
             0.1962609887352336, 0.32361312119909375`, 0.9344881450151332]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.04610843439966642], {
             RGBColor[
             0.21049372737267863`, 0.3385726319147987, 0.9352986784250858]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.04610843439966642], {
             RGBColor[
             0.4223544797753533, 0.5402439550531881, 0.9481330318712514]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.04610843439966642], {
             RGBColor[
             0.20374667641262958`, 0.33148105356804847`, 0.9349144438542785]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.04610843439966642], {
             RGBColor[
             0.18219656266820544`, 0.3088305176665303, 0.9336871967570698]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.04610843439966642], {
             RGBColor[
             0.18558886593634766`, 0.31239604348579764`, 0.9338803834097276]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.04610843439966642], {
             RGBColor[
             0.631783197735858, 0.7119490872875069, 0.9641554341053266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.04610843439966642], {
             RGBColor[
             0.988392764379178, 0.9725082101217492, 0.4094085107659739]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.04610843439966642], {
             RGBColor[
             0.33587823342715956`, 0.465342576888902, 0.9426228419218866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.04610843439966642], {
             RGBColor[
             0.1825695689347496, 0.30922257090263144`, 0.9337084389121362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.04610843439966642], {
             RGBColor[
             0.1818396285304826, 0.30845535725685214`, 0.9336668698859633]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.04610843439966642], {
             RGBColor[
             0.9605766768067475, 0.9701187306290152, 0.9516175823034524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.04610843439966642], {
             RGBColor[
             0.18422301466471383`, 0.3109604471993381, 0.9338026002004038]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.04610843439966642], {
             RGBColor[
             0.18098071777705174`, 0.3075525875969092, 0.9336179561892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.04610843439966642], {
             RGBColor[
             0.2073405252862433, 0.3352584165973958, 0.9351191082310077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.04610843439966642], {
             RGBColor[
             0.1999014029793203, 0.32743942738522325`, 0.9346954612208237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.04610843439966642], {
             RGBColor[
             0.19167260114558432`, 0.31879043492179643`, 0.9342268431298139]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.04610843439966642], {
             RGBColor[
             0.6295309817704698, 0.7101206369056319, 0.9639781314143923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.04610843439966642], {
             RGBColor[
             0.95633856953826, 0.8643818842404721, 0.284884016735784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.04610843439966642], {
             RGBColor[
             0.18354617680954663`, 0.31024904769955874`, 0.9337640552858439]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.04610843439966642], {
             RGBColor[
             0.2558901091184015, 0.3862871074263986, 0.9378839352075763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.04610843439966642], {
             RGBColor[
             0.9609913119589255, 0.8800766769412489, 0.30295904244338884`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.04610843439966642], {
             RGBColor[
             0.24981404640376637`, 0.37990078026869034`, 0.9375379124247071]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.04610843439966642], {
             RGBColor[
             0.19105055232810444`, 0.31813662217445204`, 0.9341914183698972]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.04610843439966642], {
             RGBColor[
             0.3637386159115608, 0.4894738398933511, 0.9443980808578237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.04610843439966642], {
             RGBColor[
             0.2532013109542942, 0.38346101007627187`, 0.9377308121298508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.04610843439966642], {
             RGBColor[
             0.21747923322295587`, 0.34591484147009205`, 0.9356964926491292]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.04610843439966642], {
             RGBColor[
             0.34593054718585675`, 0.47404938582270545`, 0.9432633664656788]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.04610843439966642], {
             RGBColor[
             0.5021423004164799, 0.6067007665877667, 0.9539496277780908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.04610843439966642], {
             RGBColor[
             0.26424845016803866`, 0.3950722538189983, 0.9383599303652956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.04610843439966642], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.04610843439966642], {
             RGBColor[
             0.18293127670980908`, 0.3096027487078165, 0.9337290376348271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.04610843439966642], {
             RGBColor[
             0.1941778278429074, 0.3214235870212298, 0.9343695120840757]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.04610843439966642], {
             RGBColor[
             0.22179319725678925`, 0.3504490911907685, 0.9359421665189183]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.04610843439966642], {
             RGBColor[
             0.30602988251049323`, 0.4389871883067331, 0.9407393211271083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.04610843439966642], {
             RGBColor[
             0.21196511221078973`, 0.3401191506708405, 0.9353824716148974]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.04610843439966642], {
             RGBColor[
             0.9263859833659136, 0.9441390533310817, 0.9928407161596127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.04610843439966642], {
             RGBColor[
             0.181234979779358, 0.3078198330824752, 0.9336324360340843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.04610843439966642], {
             RGBColor[
             0.2704719529099895, 0.40161354979365305`, 0.9387143496396024]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.04610843439966642], {
             RGBColor[
             0.2020967142561969, 0.3297468387279948, 0.9348204809503698]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.04610843439966642], {
             RGBColor[
             0.21670300720810273`, 0.3450989787129095, 0.9356522877259069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.04610843439966642], {
             RGBColor[
             0.21656281497127022`, 0.34495162778329735`, 0.9356443039854151]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.04610843439966642], {
             RGBColor[
             0.2675148103379351, 0.39850540545675567`, 0.9385459447448243]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.04610843439966642], {
             RGBColor[
             0.22727061882380845`, 0.3562062085462915, 0.9362540975740409]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.04610843439966642], {
             RGBColor[
             0.18623437450108682`, 0.31307451391494534`, 0.9339171441675451]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.04610843439966642], {
             RGBColor[
             0.2444470173259052, 0.37425969241856055`, 0.9372322680585309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.04610843439966642], {
             RGBColor[
             0.23138676958404353`, 0.3605325439743302, 0.9364885062705369]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.04610843439966642], {
             RGBColor[
             0.19041076970754647`, 0.3174641700756846, 0.9341549836961299]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.04610843439966642], {
             RGBColor[
             0.24919784069125972`, 0.37925310899514714`, 0.9375028204209744]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.04610843439966642], {
             RGBColor[
             0.9364164576881094, 0.9521000787690629, 0.9925145312769647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.04610843439966642], {
             RGBColor[
             0.21679935925455723`, 0.3452002508228058, 0.9356577748324124]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.04610843439966642], {
             RGBColor[
             0.19250116414799295`, 0.31966130717125646`, 0.9342740285670519]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.04610843439966642], {
             RGBColor[
             0.5518206973838005, 0.647031927232117, 0.9578604931653224]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.04610843439966642], {
             RGBColor[
             0.20579087184942513`, 0.3336296325815971, 0.9350308577602878]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.04610843439966642], {
             RGBColor[
             0.19619436846660787`, 0.3235430990727991, 0.9344843510893909]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.04610843439966642], {
             RGBColor[
             0.9691756477061694, 0.9765318290462814, 0.9370617675415293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.04610843439966642], {
             RGBColor[
             0.1810808656124072, 0.3076578493216073, 0.933623659460268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.04610843439966642], {
             RGBColor[
             0.36710024085613885`, 0.49238551046016216`, 0.9446122806267241]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.04610843439966642], {
             RGBColor[
             0.20575656042090384`, 0.333593569094751, 0.9350289037751928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.04610843439966642], {
             RGBColor[
             0.18503007033382515`, 0.31180871387785897`, 0.9338485608268279]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.04610843439966642], {
             RGBColor[
             0.21763298899601496`, 0.34607644853625624`, 0.9357052488129437]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.04610843439966642], {
             RGBColor[
             0.3080267094125234, 0.4410859799869048, 0.9408530374651383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.04610843439966642], {
             RGBColor[
             0.21740901950548744`, 0.34584104240122593`, 0.9356924940817913]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.04610843439966642], {
             RGBColor[
             0.18012636844446756`, 0.30665461227948687`, 0.9335693022586058]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.04610843439966642], {
             RGBColor[
             0.2201361607798215, 0.3487074407912947, 0.9358478007429207]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.04610843439966642], {
             RGBColor[
             0.9414109245622558, 0.9558249439861124, 0.9840602016246193]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.04610843439966642], {
             RGBColor[
             0.20445336338735556`, 0.33222382638502757`, 0.9349546886320393]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.04610843439966642], {
             RGBColor[
             0.18141516357964482`, 0.30800921768088935`, 0.9336426972349526]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.04610843439966642], {
             RGBColor[
             0.31502527059825963`, 0.4472807885868956, 0.9412941095699802]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.04610843439966642], {
             RGBColor[
             0.24062773125074222`, 0.3702453805968408, 0.9370147653666777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.04610843439966642], {
             RGBColor[
             0.1853227778630534, 0.31211636804980714`, 0.9338652300875955]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.04610843439966642], {
             RGBColor[
             0.39086743560945575`, 0.5129714599815431, 0.9461267052599003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.04610843439966642], {
             RGBColor[
             0.8468258702473929, 0.3609297347144502, 0.19247381227214683`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.04610843439966642], {
             RGBColor[
             0.1939380814128329, 0.3211715983224198, 0.934355858879556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.04610843439966642], {
             RGBColor[
             0.21735301065346377`, 0.34578217354658275`, 0.9356893044605262]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.04610843439966642], {
             RGBColor[
             0.27792375203997, 0.40944586315061604`, 0.939138718576106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.04610843439966642], {
             RGBColor[
             0.4511243917370499, 0.5651630067765897, 0.9499662252212164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.04610843439966642], {
             RGBColor[
             0.2260372839021752, 0.3549098953457044, 0.9361838609748094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.04610843439966642], {
             RGBColor[
             0.2642831104182927, 0.3951086839396021, 0.9383619042152723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.04610843439966642], {
             RGBColor[
             0.1796655907243716, 0.3061703056806712, 0.9335430616491059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.04610843439966642], {
             RGBColor[
             0.874787420357395, 0.9029957597937702, 0.9879191991572792]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.04610843439966642], {
             RGBColor[
             0.43130662815416465`, 0.5479978560308542, 0.9487034548498753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.04610843439966642], {
             RGBColor[
             0.4544709331932017, 0.5679990031052896, 0.9501967631243022]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.04610843439966642], {
             RGBColor[
             0.1842953386135795, 0.3110364642551991, 0.933806718942298]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.04610843439966642], {
             RGBColor[
             0.1814951086723694, 0.3080932450421545, 0.9336472499897152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.04610843439966642], {
             RGBColor[
             0.30056549504747376`, 0.4332437706209237, 0.9404281323449262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.04610843439966642], {
             RGBColor[
             0.24912319227677354`, 0.3791746487785393, 0.937498569304202]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.04610843439966642], {
             RGBColor[
             0.24687317251219526`, 0.37680973534647483`, 0.9373704340072151]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.04610843439966642], {
             RGBColor[
             0.1969362596236349, 0.3243228737174507, 0.934526600693254]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.04610843439966642], {
             RGBColor[
             0.22281221312870114`, 0.35152014148148586`, 0.9360001979653247]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.04610843439966642], {
             RGBColor[
             0.32389238094576056`, 0.45496103389597625`, 0.9418591140004451]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.04610843439966642], {
             RGBColor[
             0.2218736173884548, 0.35053361784807985`, 0.9359467463264457]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.04610843439966642], {
             RGBColor[
             0.28566810415648325`, 0.4175856682453557, 0.9395797479723991]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.04610843439966642], {
             RGBColor[
             0.9937232399115826, 0.9889829697856952, 0.5581915839279488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.04610843439966642], {
             RGBColor[
             0.34381589363766235`, 0.47221777920483715`, 0.9431286226115025]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.04610843439966642], {
             RGBColor[
             0.2619978835405132, 0.39270676559930323`, 0.938231763925273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.04610843439966642], {
             RGBColor[
             0.8556626659915121, 0.887746199790043, 0.9860950630129915]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.04610843439966642], {
             RGBColor[
             0.19848865517094644`, 0.32595453986523776`, 0.93461500732311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.04610843439966642], {
             RGBColor[
             0.1901932049434399, 0.31723549571420584`, 0.9341425937046723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.04610843439966642], {
             RGBColor[
             0.24540381361353808`, 0.37526534598125116`, 0.9372867561916584]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.04610843439966642], {
             RGBColor[
             0.24952468470268496`, 0.3795966427742623, 0.9375214337039027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.04610843439966642], {
             RGBColor[
             0.19357697366818166`, 0.320792051187238, 0.9343352943277091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.04610843439966642], {
             RGBColor[
             0.1855038424012835, 0.31230667835964177`, 0.9338755414451867]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.04610843439966642], {
             RGBColor[
             0.19256204953176445`, 0.3197253015699566, 0.9342774958995859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.04610843439966642], {
             RGBColor[
             0.9939031817563573, 0.9917468232222412, 0.7507035865643902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.04610843439966642], {
             RGBColor[
             0.20018563595199287`, 0.32773817426091345`, 0.9347116478681324]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.04610843439966642], {
             RGBColor[
             0.2822567222941179, 0.41400008961390705`, 0.9393854748220246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.04610843439966642], {
             RGBColor[
             0.33187084383238813`, 0.46187157743916857`, 0.9423674946005033]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.04610843439966642], {
             RGBColor[
             0.6731900684530466, 0.744620465000319, 0.9680609527706839]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.04610843439966642], {
             RGBColor[
             0.8187176743057581, 0.14487782361704554`, 0.16555737209477062`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.04610843439966642], {
             RGBColor[
             0.20642492465234524`, 0.3342960622787358, 0.9350669661294171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.04610843439966642], {
             RGBColor[
             0.3163443674121438, 0.4484233239473484, 0.9413781612525294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.04610843439966642], {
             RGBColor[
             0.2548921156460419, 0.3852381530105079, 0.9378271009557244]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.04610843439966642], {
             RGBColor[
             0.44319072976501883`, 0.5582912675338615, 0.9494606992958204]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.04610843439966642], {
             RGBColor[
             0.2838279904913397, 0.4156515921133449, 0.9394749562213734]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.04610843439966642], {
             RGBColor[
             0.4514119894863078, 0.5654121094919137, 0.9499845506954865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.04610843439966642], {
             RGBColor[
             0.2817626744925139, 0.41348081404998144`, 0.9393573395306015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.04610843439966642], {
             RGBColor[
             0.19517315909830985`, 0.32246974327830424`, 0.9344261947266101]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.04610843439966642], {
             RGBColor[
             0.2058031822357576, 0.33364257157815613`, 0.9350315588185778]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.04610843439966642], {
             RGBColor[
             0.8037293520346596, 0.846598745469576, 0.9810718885991364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.04610843439966642], {
             RGBColor[
             0.19933380464903927`, 0.32684284555228516`, 0.9346631373356007]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.04610843439966642], {
             RGBColor[
             0.20939739524084894`, 0.3374203173327738, 0.9352362439320562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.04610843439966642], {
             RGBColor[
             0.19209300288846856`, 0.31923230380857776`, 0.9342507843871425]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.04610843439966642], {
             RGBColor[
             0.6552079689840278, 0.7305727122261038, 0.9662686651478858]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.04610843439966642], {
             RGBColor[
             0.30775018901205775`, 0.44079533951360933`, 0.940837290037407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.04610843439966642], {
             RGBColor[
             0.8693407441384133, 0.4995886600246006, 0.2126870529687101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.04610843439966642], {
             RGBColor[
             0.36775323192677223`, 0.4929510985052593, 0.9446538886403275]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.04610843439966642], {
             RGBColor[
             0.19003317840134057`, 0.3170672976721906, 0.9341334804298378]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.04610843439966642], {
             RGBColor[
             0.5005712745154292, 0.6054253369873833, 0.9538259508643026]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.04610843439966642], {
             RGBColor[
             0.23408779828449117`, 0.3633714963936115, 0.9366423258592136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.04610843439966642], {
             RGBColor[
             0.21738991983752656`, 0.34582096743921015`, 0.9356914063839564]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.04610843439966642], {
             RGBColor[
             0.1836473816366038, 0.3103554203895525, 0.9337698187510258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.04610843439966642], {
             RGBColor[
             0.3685402730980111, 0.49363279400994686`, 0.9447040382078057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.04610843439966642], {
             RGBColor[
             0.3420328760182438, 0.47067341895996806`, 0.9430150103054538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.04610843439966642], {
             RGBColor[
             0.43817293033743376`, 0.5539451018716196, 0.9491409695533606]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.04610843439966642], {
             RGBColor[
             0.34083289550277507`, 0.46963405615024345`, 0.9429385486081092]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.04610843439966642], {
             RGBColor[
             0.9363841071750253, 0.7854912142282449, 0.26767136325734403`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.04610843439966642], {
             RGBColor[
             0.1818088839913312, 0.30842304279688765`, 0.933665119029941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.04610843439966642], {
             RGBColor[
             0.2320502240219991, 0.3612298766540624, 0.9365262890192856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.04610843439966642], {
             RGBColor[
             0.18306798401191893`, 0.3097464367500775, 0.933736822913442]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.04610843439966642], {
             RGBColor[
             0.20348109888236326`, 0.33120191474515054`, 0.9348993196068165]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.04610843439966642], {
             RGBColor[
             0.31320234650668927`, 0.4457018633616062, 0.9411779544588138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.04610843439966642], {
             RGBColor[
             0.19443151506714343`, 0.3216902283786009, 0.9343839591961993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.04610843439966642], {
             RGBColor[
             0.1841862517520943, 0.3109218070472717, 0.933800506606916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.04610843439966642], {
             RGBColor[
             0.8101035860121542, 0.8515783454987672, 0.9817072126714098]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.04610843439966642], {
             RGBColor[
             0.46571418536342124`, 0.577126781719812, 0.9510818731205317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.04610843439966642], {
             RGBColor[
             0.22946131864603458`, 0.3585087729578423, 0.9363788546880667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.04610843439966642], {
             RGBColor[
             0.2015219494351241, 0.32914272445885284`, 0.9347877489440981]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.04610843439966642], {
             RGBColor[
             0.5010318547608589, 0.6057992567795268, 0.9538622094283838]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.04610843439966642], {
             RGBColor[
             0.23298613716021888`, 0.3622135807026517, 0.9365795878879478]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.04610843439966642], {
             RGBColor[
             0.20070591566211698`, 0.3282850212238928, 0.9347412770279392]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.04610843439966642], {
             RGBColor[
             0.34562348099972906`, 0.47378342052587685`, 0.9432438004798267]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.04610843439966642], {
             RGBColor[
             0.995260710048657, 0.9923081960579929, 0.7282058295903809]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.04610843439966642], {
             RGBColor[
             0.1906136828189116, 0.3176774446211637, 0.9341665392976392]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{{3.8349502435193233`*^9, 3.8349502581408367`*^9}, 
   3.8350238732693977`*^9},
 CellLabel->
  "Out[126]=",ExpressionUUID->"88e472a1-4b88-4d16-b56c-a1c10b1cdeeb"]
}, Open  ]],

Cell["Estimated with Max-Min Deviation v Calculated: (r = 6)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 3.8349503922098827`*^9}, {3.8349504781120467`*^9, 
  3.834950521977162*^9}},ExpressionUUID->"ea8bfb1f-b615-45a5-bce9-\
b90c082f516b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphin2", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsi2", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}], 
     "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"mMDi6200", ",", "kri2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502554527807`*^9}, {3.8349505249112787`*^9, 3.834950525026289*^9}},
 CellLabel->
  "In[127]:=",ExpressionUUID->"111b75dd-38d6-4474-bbdd-9c03ada428ed"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
          103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
          129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 
          142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 
          155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 
          168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 
          181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 
          194, 195, 196, 197, 198, 199, 200}, {Null, CompressedData["
1:eJwVxfk/Gg4DAOBN5QibNGP1lWNDwghlmCNXuqiMigzJGcNQUi05SwdqhpKc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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[21, 55] -> 
             RGBColor[
              0.9787521621621622, 0.9398954864864864, 0.37983986486486465`], 
             UndirectedEdge[64, 132] -> 
             RGBColor[
              0.9035733108108108, 0.8537155675675676, 0.6300837162162162], 
             UndirectedEdge[42, 188] -> 
             RGBColor[
              0.9911201756756757, 0.9883281621621622, 0.6319788783783783], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.9543072837837838, 0.9560720810810811, 0.7011337297297298], 
             UndirectedEdge[33, 68] -> 
             RGBColor[
              0.8764190945945947, 0.8054911351351352, 0.6215434459459459], 
             UndirectedEdge[168, 188] -> 
             RGBColor[
              0.5842570675675676, 0.6476780135135136, 0.8778663243243243], 
             UndirectedEdge[41, 161] -> 
             RGBColor[
              0.9819802027027027, 0.952266918918919, 0.551798391891892], 
             UndirectedEdge[44, 68] -> 
             RGBColor[
              0.9600769189189189, 0.867659945945946, 0.3998125270270269], 
             UndirectedEdge[26, 136] -> 
             RGBColor[
              0.9568081756756757, 0.9638592162162163, 0.766032135135135], 
             UndirectedEdge[9, 32] -> 
             RGBColor[
              0.8172154864864865, 0.8579431081081081, 0.9822014054054053], 
             UndirectedEdge[71, 141] -> 
             RGBColor[
              0.9852080405405406, 0.9711391891891892, 0.6195231486486485], 
             UndirectedEdge[52, 100] -> 
             RGBColor[
              0.9906029729729731, 0.9798710540540541, 0.42587802702702693`], 
             UndirectedEdge[172, 180] -> 
             RGBColor[
              0.5748517567567568, 0.6092392297297298, 0.6372368513513514], 
             UndirectedEdge[168, 197] -> 
             RGBColor[
              0.556957972972973, 0.5426769324324324, 0.6000248918918919], 
             UndirectedEdge[125, 137] -> 
             RGBColor[
              0.9915708243243243, 0.9892920540540541, 0.6810292027027025], 
             UndirectedEdge[17, 147] -> 
             RGBColor[
              0.9895871351351351, 0.9899620270270271, 0.8222316486486487], 
             UndirectedEdge[10, 71] -> 
             RGBColor[
              0.9539252972972972, 0.9641573513513514, 0.9221364729729729], 
             UndirectedEdge[27, 129] -> 
             RGBColor[
              0.5653475945945947, 0.5759389864864866, 0.6067753783783784], 
             UndirectedEdge[67, 166] -> 
             RGBColor[
              0.9449249864864865, 0.9485908918918919, 0.7002388378378378], 
             UndirectedEdge[3, 49] -> 
             RGBColor[0.9479676621621622, 0.9128256756756756, 0.6432225], 
             UndirectedEdge[151, 183] -> 
             RGBColor[
              0.9678138108108107, 0.9030905675675676, 0.3294631621621621], 
             UndirectedEdge[125, 136] -> 
             RGBColor[
              0.9935545135135135, 0.9886220810810811, 0.5398267567567565], 
             UndirectedEdge[139, 194] -> 
             RGBColor[
              0.9181944864864865, 0.9349762702702703, 0.8887531216216216], 
             UndirectedEdge[24, 108] -> 
             RGBColor[
              0.9922446891891892, 0.989181945945946, 0.6416021486486485], 
             UndirectedEdge[21, 192] -> 
             RGBColor[
              0.9648314189189189, 0.9696183783783784, 0.7166182837837838], 
             UndirectedEdge[16, 52] -> 
             RGBColor[0.9917675, 0.9826204324324324, 0.5714251216216217], 
             UndirectedEdge[44, 166] -> 
             RGBColor[
              0.9910536216216217, 0.980834945945946, 0.4749283513513512], 
             UndirectedEdge[78, 187] -> 
             RGBColor[
              0.5494944189189189, 0.6222451756756757, 0.9628692567567567], 
             UndirectedEdge[99, 162] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[93, 150] -> 
             RGBColor[
              0.9215667297297296, 0.9396541621621621, 0.9701173378378378], 
             UndirectedEdge[118, 155] -> 
             RGBColor[
              0.8543857567567568, 0.886728027027027, 0.9859732702702703], 
             UndirectedEdge[16, 125] -> 
             RGBColor[
              0.994268391891892, 0.9904075675675675, 0.636323527027027], 
             UndirectedEdge[61, 179] -> 
             RGBColor[0.9676822027027027, 0.958666, 0.6759494189189188], 
             UndirectedEdge[51, 197] -> 
             RGBColor[
              0.959590472972973, 0.8838454324324325, 0.5890958918918918], 
             UndirectedEdge[80, 120] -> 
             RGBColor[
              0.9947190405405406, 0.9913714594594594, 0.6853738513513514], 
             UndirectedEdge[21, 183] -> 
             RGBColor[
              0.9787521621621622, 0.9398954864864864, 0.37983986486486465`], 
             UndirectedEdge[182, 199] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[17, 189] -> 
             RGBColor[
              0.9691804189189189, 0.9027074864864865, 0.5030597837837838], 
             UndirectedEdge[116, 136] -> 
             RGBColor[
              0.9931038648648649, 0.9876581891891891, 0.4907764324324322], 
             UndirectedEdge[119, 123] -> 
             RGBColor[
              0.9433371216216216, 0.8447186216216216, 0.5956566486486485], 
             UndirectedEdge[71, 89] -> 
             RGBColor[
              0.9895871351351351, 0.9899620270270271, 0.8222316486486485], 
             UndirectedEdge[7, 61] -> 
             RGBColor[
              0.9363994594594593, 0.9516841621621621, 0.9785627432432432], 
             UndirectedEdge[3, 27] -> 
             RGBColor[
              0.5689263513513514, 0.5892514459459459, 0.6142177702702702], 
             UndirectedEdge[41, 108] -> 
             RGBColor[
              0.9810810135135135, 0.9518950810810811, 0.5667002837837838], 
             UndirectedEdge[66, 98] -> 
             RGBColor[
              0.5869546351351351, 0.648793527027027, 0.8331606486486487], 
             UndirectedEdge[119, 127] -> 
             RGBColor[
              0.9538984189189189, 0.8516988918918919, 0.5376397297297297], 
             UndirectedEdge[15, 167] -> 
             RGBColor[
              0.9933291891891892, 0.9881401351351351, 0.5153015945945946], 
             UndirectedEdge[12, 96] -> 
             RGBColor[
              0.9767019189189189, 0.9330722432432432, 0.36399178378378366`], 
             UndirectedEdge[7, 52] -> 
             RGBColor[
              0.9543072837837838, 0.9560720810810811, 0.7011337297297298], 
             UndirectedEdge[163, 165] -> 
             RGBColor[
              0.9603022432432433, 0.868141891891892, 0.42433768918918924`], 
             UndirectedEdge[71, 73] -> 
             RGBColor[
              0.9623991891891892, 0.9708804054054054, 0.9217729459459458], 
             UndirectedEdge[60, 165] -> 
             RGBColor[
              0.5864660810810811, 0.6474899864864865, 0.7611890405405406], 
             UndirectedEdge[120, 124] -> 
             RGBColor[
              0.9657327162162161, 0.9715461621621622, 0.8147189324324324], 
             UndirectedEdge[43, 163] -> 
             RGBColor[
              0.931804472972973, 0.8496201351351351, 0.6256543783783783], 
             UndirectedEdge[146, 194] -> 
             RGBColor[
              0.9547976081081081, 0.8520707297297296, 0.5227378378378378], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.556957972972973, 0.5426769324324324, 0.6000248918918919], 
             UndirectedEdge[81, 157] -> 
             RGBColor[
              0.9236918783783783, 0.901134135135135, 0.6533057837837837], 
             UndirectedEdge[59, 114] -> 
             RGBColor[
              0.9801818243243243, 0.9515232432432433, 0.5816021756756757], 
             UndirectedEdge[31, 185] -> 
             RGBColor[
              0.9819401891891892, 0.9503713243243244, 0.41587456756756747`], 
             UndirectedEdge[58, 198] -> 
             RGBColor[
              0.9828793918918919, 0.9526387567567568, 0.5368965000000001], 
             UndirectedEdge[30, 142] -> 
             RGBColor[
              0.9003888378378379, 0.9233758378378378, 0.9891893108108107], 
             UndirectedEdge[26, 96] -> 
             RGBColor[
              0.9543072837837838, 0.9560720810810811, 0.7011337297297298], 
             UndirectedEdge[25, 111] -> 
             RGBColor[
              0.9357363378378378, 0.8525525135135136, 0.6189987567567568], 
             UndirectedEdge[89, 107] -> 
             RGBColor[
              0.5851562567567568, 0.6480498513513514, 0.8629644324324324], 
             UndirectedEdge[51, 189] -> 
             RGBColor[
              0.9637852837837837, 0.9004764594594594, 0.592471135135135], 
             UndirectedEdge[81, 158] -> 
             RGBColor[
              0.964851108108108, 0.8930966756756755, 0.31795362162162144`], 
             UndirectedEdge[93, 159] -> 
             RGBColor[
              0.9745767702702702, 0.9715922702702703, 0.6808033378378378], 
             UndirectedEdge[191, 195] -> 
             RGBColor[
              0.9895471216216216, 0.9880664324324324, 0.6863078243243242], 
             UndirectedEdge[17, 131] -> 
             RGBColor[
              0.9733752297297298, 0.9193385135135135, 0.5064350270270271], 
             UndirectedEdge[18, 32] -> 
             RGBColor[
              0.44664806756756753`, 0.5410919324324325, 0.9528331486486487], 
             UndirectedEdge[59, 184] -> 
             RGBColor[
              0.9819802027027027, 0.952266918918919, 0.551798391891892], 
             UndirectedEdge[156, 175] -> 
             RGBColor[
              0.9931438783783784, 0.9895537837837838, 0.6267002567567567], 
             UndirectedEdge[2, 82] -> 
             RGBColor[
              0.5697639054054053, 0.6377653648648649, 0.9425388648648649], 
             UndirectedEdge[12, 44] -> 
             RGBColor[
              0.9792028108108108, 0.9408593783783783, 0.428890189189189], 
             UndirectedEdge[115, 175] -> 
             RGBColor[
              0.993594527027027, 0.9905176756756757, 0.6757505810810811], 
             UndirectedEdge[30, 131] -> 
             RGBColor[
              0.9077681216216217, 0.8703465945945947, 0.6334589594594594], 
             UndirectedEdge[53, 65] -> 
             RGBColor[
              0.9933291891891892, 0.9881401351351351, 0.5153015945945943], 
             UndirectedEdge[17, 51] -> 
             RGBColor[
              0.9895871351351351, 0.9899620270270271, 0.8222316486486487], 
             UndirectedEdge[109, 128] -> 
             RGBColor[
              0.9506027972972972, 0.8354397027027027, 0.5193625945945946], 
             UndirectedEdge[101, 135] -> 
             RGBColor[
              0.5014542972972973, 0.24536631081081076`, 0.5520495540540541], 
             UndirectedEdge[54, 195] -> 
             RGBColor[
              0.9877887567567567, 0.9892183513513514, 0.8520354324324324], 
             UndirectedEdge[122, 192] -> 
             RGBColor[
              0.9632983783783784, 0.9712522432432433, 0.9068710540540541], 
             UndirectedEdge[155, 195] -> 
             RGBColor[
              0.9154969189189189, 0.9338607567567567, 0.9334587972972974], 
             UndirectedEdge[42, 87] -> 
             RGBColor[
              0.9726951486486486, 0.9754831351351352, 0.7033070405405404], 
             UndirectedEdge[31, 153] -> 
             RGBColor[0.947427, 0.8172051621621622, 0.36525333783783775`], 
             UndirectedEdge[64, 199] -> 
             RGBColor[
              0.521347527027027, 0.5998016081081081, 0.9601845810810811], 
             UndirectedEdge[107, 188] -> 
             RGBColor[
              0.5842570675675676, 0.6476780135135136, 0.8778663243243243], 
             UndirectedEdge[27, 189] -> 
             RGBColor[
              0.5611527837837837, 0.5593079594594594, 0.6034001351351351], 
             UndirectedEdge[14, 176] -> 
             RGBColor[
              0.9849028918918918, 0.9603652162162162, 0.4273841081081079], 
             UndirectedEdge[123, 146] -> 
             RGBColor[
              0.9433371216216216, 0.8447186216216216, 0.5956566486486486], 
             UndirectedEdge[30, 130] -> 
             RGBColor[
              0.9248792162162163, 0.941341945945946, 0.9343536891891893], 
             UndirectedEdge[72, 143] -> 
             RGBColor[
              0.9447694459459459, 0.8179852432432433, 0.5458828378378378], 
             UndirectedEdge[68, 155] -> 
             RGBColor[
              0.8858013918918919, 0.8129723243243243, 0.6224383378378379], 
             UndirectedEdge[32, 39] -> 
             RGBColor[
              0.8501797567567567, 0.8826322702702702, 0.9270022567567568], 
             UndirectedEdge[184, 194] -> 
             RGBColor[
              0.9922847027027026, 0.9910775405405405, 0.777525972972973], 
             UndirectedEdge[74, 152] -> 
             RGBColor[
              0.9876402702702702, 0.9698771621621621, 0.4143684864864863], 
             UndirectedEdge[71, 147] -> 
             RGBColor[
              0.9859903783783783, 0.9884746756756757, 0.8818392162162161], 
             UndirectedEdge[39, 173] -> 
             RGBColor[
              0.9886879459459459, 0.9895901891891892, 0.8371335405405406], 
             UndirectedEdge[139, 171] -> 
             RGBColor[
              0.8988702702702702, 0.9217594054054055, 0.9749831756756757], 
             UndirectedEdge[73, 189] -> 
             RGBColor[
              0.9401940945945946, 0.8828821891891891, 0.6324048648648648], 
             UndirectedEdge[20, 22] -> 
             RGBColor[
              0.9475733783783784, 0.829852945945946, 0.27667451351351346`], 
             UndirectedEdge[17, 168] -> 
             RGBColor[
              0.5869546351351351, 0.648793527027027, 0.8331606486486487], 
             UndirectedEdge[13, 132] -> 
             RGBColor[
              0.9637852837837837, 0.9004764594594594, 0.592471135135135], 
             UndirectedEdge[99, 109] -> 
             RGBColor[
              0.5443735405405405, 0.4927838513513514, 0.5898991621621622], 
             UndirectedEdge[119, 195] -> 
             RGBColor[
              0.9521000405405405, 0.8509552162162162, 0.5674435135135136], 
             UndirectedEdge[10, 188] -> 
             RGBColor[
              0.9548244864864864, 0.9645291891891892, 0.9072345810810811], 
             UndirectedEdge[182, 185] -> 
             RGBColor[
              0.5748517567567568, 0.6092392297297298, 0.6372368513513514], 
             UndirectedEdge[98, 187] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[10, 167] -> 
             RGBColor[
              0.956357527027027, 0.9628953243243243, 0.7169818108108107], 
             UndirectedEdge[113, 187] -> 
             RGBColor[
              0.5866914054054054, 0.6479719324324325, 0.7857142027027026], 
             UndirectedEdge[83, 170] -> 
             RGBColor[
              0.9016546891891892, 0.5613008378378379, 0.5230286081081081], 
             UndirectedEdge[39, 41] -> 
             RGBColor[
              0.978383445945946, 0.9507795675675677, 0.6114059594594595], 
             UndirectedEdge[138, 145] -> 
             RGBColor[
              0.9895492297297297, 0.9896223783783784, 0.7993103648648648], 
             UndirectedEdge[75, 155] -> 
             RGBColor[
              0.8543857567567568, 0.886728027027027, 0.9859732702702703], 
             UndirectedEdge[90, 163] -> 
             RGBColor[
              0.9427625135135136, 0.8099033513513514, 0.27736641891891894`], 
             UndirectedEdge[2, 66] -> 
             RGBColor[
              0.9777915405405405, 0.9811648918918918, 0.8421985135135136], 
             UndirectedEdge[88, 200] -> 
             RGBColor[
              0.9650567432432433, 0.9701003243243244, 0.7411434459459458], 
             UndirectedEdge[67, 170] -> 
             RGBColor[
              0.8593081216216216, 0.5291304864864865, 0.5773328648648648], 
             UndirectedEdge[124, 136] -> 
             RGBColor[
              0.9652820675675675, 0.9705822702702702, 0.765668608108108], 
             UndirectedEdge[129, 155] -> 
             RGBColor[
              0.8983858243243243, 0.8628654054054055, 0.6325640675675677], 
             UndirectedEdge[149, 167] -> 
             RGBColor[
              0.9554314594594595, 0.8500650270270269, 0.34738695945945935`], 
             UndirectedEdge[172, 173] -> 
             RGBColor[
              0.5851562567567568, 0.6480498513513513, 0.8629644324324324], 
             UndirectedEdge[143, 160] -> 
             RGBColor[
              0.9483662027027027, 0.8194725945945946, 0.4862752702702704], 
             UndirectedEdge[27, 89] -> 
             RGBColor[
              0.5851562567567568, 0.6480498513513513, 0.8629644324324324], 
             UndirectedEdge[172, 191] -> 
             RGBColor[
              0.5860154324324325, 0.6465260945945945, 0.712138716216216], 
             UndirectedEdge[11, 182] -> 
             RGBColor[
              0.5837398648648648, 0.6392209054054054, 0.671765472972973], 
             UndirectedEdge[159, 164] -> 
             RGBColor[
              0.9449249864864865, 0.9485908918918919, 0.7002388378378378], 
             UndirectedEdge[151, 156] -> 
             RGBColor[
              0.9819401891891892, 0.9503713243243244, 0.41587456756756747`], 
             UndirectedEdge[94, 196] -> 
             RGBColor[
              0.9275767837837838, 0.9424574594594595, 0.8896480135135134], 
             UndirectedEdge[69, 139] -> 
             RGBColor[
              0.8858013918918919, 0.8129723243243243, 0.6224383378378379], 
             UndirectedEdge[53, 127] -> 
             RGBColor[0.9913455, 0.9888101081081082, 0.6565040405405405], 
             UndirectedEdge[171, 196] -> 
             RGBColor[
              0.9720612972972973, 0.9774888378378379, 0.8786579189189189], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.9897724459459459, 0.9885483783783784, 0.7108329864864864], 
             UndirectedEdge[74, 162] -> 
             RGBColor[
              0.5857901081081082, 0.6460441486486487, 0.687613554054054], 
             UndirectedEdge[34, 153] -> 
             RGBColor[0.948102972972973, 0.818651, 0.43882882432432435`], 
             UndirectedEdge[98, 109] -> 
             RGBColor[
              0.5443735405405405, 0.4927838513513514, 0.5898991621621622], 
             UndirectedEdge[77, 183] -> 
             RGBColor[
              0.964851108108108, 0.8930966756756755, 0.31795362162162144`], 
             UndirectedEdge[2, 78] -> 
             RGBColor[
              0.9403313243243243, 0.9546165405405406, 0.9719071216216216], 
             UndirectedEdge[113, 193] -> 
             RGBColor[
              0.9814601756756757, 0.9832756756756758, 0.7880964459459459], 
             UndirectedEdge[100, 120] -> 
             RGBColor[
              0.9935545135135135, 0.9886220810810811, 0.5398267567567566], 
             UndirectedEdge[1, 35] -> 
             RGBColor[
              0.5869167297297297, 0.6484538783783784, 0.8102393648648649], 
             UndirectedEdge[154, 176] -> 
             RGBColor[0.9913455, 0.9888101081081082, 0.6565040405405405], 
             UndirectedEdge[13, 31] -> 
             RGBColor[
              0.9886479324324324, 0.9876945945945946, 0.7012097162162161], 
             UndirectedEdge[92, 196] -> 
             RGBColor[
              0.9557236756756756, 0.9649010270270271, 0.8923326891891892], 
             UndirectedEdge[66, 124] -> 
             RGBColor[
              0.965995945945946, 0.9723677567567568, 0.8621653783783785], 
             UndirectedEdge[141, 167] -> 
             RGBColor[
              0.9876402702702702, 0.9698771621621621, 0.4143684864864863], 
             UndirectedEdge[76, 158] -> 
             RGBColor[
              0.9798787837837837, 0.9423052162162162, 0.5024656756756756], 
             UndirectedEdge[101, 134] -> 
             RGBColor[
              0.5842570675675676, 0.6476780135135136, 0.8778663243243243], 
             UndirectedEdge[139, 141] -> 
             RGBColor[
              0.9138153918918919, 0.9161534324324324, 0.6860446216216216], 
             UndirectedEdge[88, 93] -> 
             RGBColor[
              0.9488052162162162, 0.9613395945945946, 0.9715435945945946], 
             UndirectedEdge[17, 130] -> 
             RGBColor[
              0.9904863243243243, 0.9903338648648649, 0.8073297567567569], 
             UndirectedEdge[32, 117] -> 
             RGBColor[
              0.8484982297297297, 0.8649249459459459, 0.679588081081081], 
             UndirectedEdge[32, 103] -> 
             RGBColor[
              0.4466480675675676, 0.5410919324324325, 0.9528331486486487], 
             UndirectedEdge[148, 150] -> 
             RGBColor[
              0.8825326486486486, 0.9091715945945945, 0.9886579459459459], 
             UndirectedEdge[77, 156] -> 
             RGBColor[
              0.9789774864864864, 0.9403774324324323, 0.4043650270270268], 
             UndirectedEdge[76, 89] -> 
             RGBColor[
              0.9931459864864864, 0.9911097297297298, 0.7397027972972973], 
             UndirectedEdge[42, 51] -> 
             RGBColor[
              0.9884226081081081, 0.9872126486486487, 0.6766845540540539], 
             UndirectedEdge[82, 124] -> 
             RGBColor[
              0.5579683108108109, 0.6289682297297297, 0.9625057297297297], 
             UndirectedEdge[15, 114] -> 
             RGBColor[0.9917961486486486, 0.989774, 0.7055543648648649], 
             UndirectedEdge[41, 173] -> 
             RGBColor[
              0.9810810135135135, 0.9518950810810811, 0.5667002837837838], 
             UndirectedEdge[41, 133] -> 
             RGBColor[
              0.9266545810810811, 0.911128027027027, 0.6648153243243244], 
             UndirectedEdge[27, 147] -> 
             RGBColor[0.5815595, 0.6465624999999999, 0.922572], 
             UndirectedEdge[19, 88] -> 
             RGBColor[
              0.9443889054054054, 0.8995132162162163, 0.635780108108108], 
             UndirectedEdge[127, 172] -> 
             RGBColor[
              0.5842570675675676, 0.6476780135135135, 0.8778663243243243], 
             UndirectedEdge[69, 174] -> 
             RGBColor[
              0.9457252162162162, 0.8198972432432432, 0.2888759594594594], 
             UndirectedEdge[117, 121] -> 
             RGBColor[
              0.9834096621621622, 0.9703955135135135, 0.6493269324324323], 
             UndirectedEdge[69, 196] -> 
             RGBColor[
              0.958992418918919, 0.8687017567567568, 0.526113081081081], 
             UndirectedEdge[92, 195] -> 
             RGBColor[
              0.9530261081081081, 0.9637855135135136, 0.9370383648648649], 
             UndirectedEdge[144, 158] -> 
             RGBColor[
              0.9618884054054053, 0.8831027837837837, 0.306444081081081], 
             UndirectedEdge[81, 168] -> 
             RGBColor[
              0.571889054054054, 0.5992453378378377, 0.6257273108108108], 
             UndirectedEdge[87, 188] -> 
             RGBColor[0.9711621081081081, 0.977117, 0.8935598108108107], 
             UndirectedEdge[74, 88] -> 
             RGBColor[
              0.9648314189189189, 0.9696183783783784, 0.7166182837837838], 
             UndirectedEdge[74, 140] -> 
             RGBColor[
              0.9935545135135135, 0.9886220810810811, 0.5398267567567566], 
             UndirectedEdge[152, 178] -> 
             RGBColor[
              0.9878655945945947, 0.9703591081081081, 0.43889364864864844`], 
             UndirectedEdge[63, 153] -> 
             RGBColor[
              0.9472016756756757, 0.8167232162162162, 0.3407281756756756], 
             UndirectedEdge[154, 158] -> 
             RGBColor[
              0.9772191216216215, 0.9415293513513513, 0.570092635135135], 
             UndirectedEdge[23, 90] -> 
             RGBColor[
              0.9737392162162162, 0.9230783513513514, 0.35248224324324323`], 
             UndirectedEdge[51, 131] -> 
             RGBColor[
              0.9679800945945947, 0.9171074864864865, 0.5958463783783784], 
             UndirectedEdge[21, 83] -> 
             RGBColor[
              0.9893217972972973, 0.9875844864864864, 0.6617826621621621], 
             UndirectedEdge[57, 178] -> 
             RGBColor[
              0.9789774864864864, 0.9403774324324323, 0.4043650270270268], 
             UndirectedEdge[17, 197] -> 
             RGBColor[
              0.9649856081081081, 0.8860764594594595, 0.4996845405405406], 
             UndirectedEdge[64, 156] -> 
             RGBColor[
              0.9284359594594596, 0.9409337027027027, 0.7388222972972971], 
             UndirectedEdge[40, 123] -> 
             RGBColor[
              0.9772274594594594, 0.9822380810810811, 0.9100523513513514], 
             UndirectedEdge[26, 99] -> 
             RGBColor[
              0.5494944189189189, 0.6222451756756757, 0.9628692567567567], 
             UndirectedEdge[114, 167] -> 
             RGBColor[
              0.9911201756756757, 0.9883281621621622, 0.6319788783783783], 
             UndirectedEdge[75, 168] -> 
             RGBColor[
              0.521347527027027, 0.5998016081081081, 0.9601845810810811], 
             UndirectedEdge[55, 111] -> 
             RGBColor[
              0.9457252162162162, 0.8198972432432432, 0.2888759594594594], 
             UndirectedEdge[67, 122] -> 
             RGBColor[0.9454421891891891, 0.957048, 0.9063396891891892], 
             UndirectedEdge[127, 129] -> 
             RGBColor[0.9706776621621622, 0.918223, 0.5511407027027027], 
             UndirectedEdge[96, 198] -> 
             RGBColor[0.9917675, 0.9826204324324324, 0.5714251216216217], 
             UndirectedEdge[154, 181] -> 
             RGBColor[
              0.9861072297297298, 0.9715110270270271, 0.6046212567567566], 
             UndirectedEdge[9, 91] -> 
             RGBColor[
              0.9200618378378378, 0.9390963513513514, 0.9922375135135135], 
             UndirectedEdge[39, 152] -> 
             RGBColor[
              0.9843088513513514, 0.9707673513513513, 0.6344250405405405], 
             UndirectedEdge[54, 65] -> 
             RGBColor[
              0.9915708243243243, 0.9892920540540541, 0.6810292027027025], 
             UndirectedEdge[116, 128] -> 
             RGBColor[0.9920193648648649, 0.9887, 0.6170769864864863], 
             UndirectedEdge[74, 95] -> 
             RGBColor[
              0.9596262702702703, 0.866696054054054, 0.35076220270270264`], 
             UndirectedEdge[152, 200] -> 
             RGBColor[
              0.9878655945945947, 0.9703591081081081, 0.43889364864864844`], 
             UndirectedEdge[140, 191] -> 
             RGBColor[
              0.9937798378378379, 0.989104027027027, 0.5643519189189188], 
             UndirectedEdge[109, 193] -> 
             RGBColor[
              0.9391423108108108, 0.8280875945945947, 0.5922814054054053], 
             UndirectedEdge[80, 137] -> 
             RGBColor[
              0.9922847027027026, 0.9910775405405405, 0.7775259729729731], 
             UndirectedEdge[118, 199] -> 
             RGBColor[
              0.521347527027027, 0.5998016081081081, 0.9601845810810811], 
             UndirectedEdge[45, 64] -> 
             RGBColor[
              0.9293751621621622, 0.9432011351351351, 0.8598442297297297], 
             UndirectedEdge[125, 170] -> 
             RGBColor[
              0.9054367567567567, 0.5613745405405406, 0.35202237837837824`], 
             UndirectedEdge[70, 145] -> 
             RGBColor[
              0.9887668918918919, 0.9722868918918919, 0.5369942972972972], 
             UndirectedEdge[17, 142] -> 
             RGBColor[
              0.965995945945946, 0.9723677567567568, 0.8621653783783785], 
             UndirectedEdge[95, 180] -> 
             RGBColor[
              0.948687918918919, 0.8298911351351352, 0.3003855000000001], 
             UndirectedEdge[41, 121] -> 
             RGBColor[
              0.9774842567567568, 0.9504077297297298, 0.6263078513513514], 
             UndirectedEdge[5, 10] -> 
             RGBColor[
              0.9359150135135135, 0.8927901621621622, 0.636143635135135], 
             UndirectedEdge[167, 194] -> 
             RGBColor[0.9920193648648649, 0.9887, 0.6170769864864863], 
             UndirectedEdge[78, 100] -> 
             RGBColor[
              0.956357527027027, 0.9628953243243243, 0.7169818108108107], 
             UndirectedEdge[106, 157] -> 
             RGBColor[
              0.9355426891891891, 0.9411097027027027, 0.6993439459459458], 
             UndirectedEdge[24, 115] -> 
             RGBColor[
              0.9935545135135135, 0.9886220810810811, 0.5398267567567567], 
             UndirectedEdge[74, 164] -> 
             RGBColor[
              0.9469752297297298, 0.9554141351351351, 0.7160869189189187], 
             UndirectedEdge[46, 135] -> 
             RGBColor[
              0.909444027027027, 0.5884261891891891, 0.4287879189189189], 
             UndirectedEdge[126, 190] -> 
             RGBColor[
              0.9190536621621622, 0.9334525135135135, 0.7379274054054052], 
             UndirectedEdge[21, 177] -> 
             RGBColor[
              0.9638210810810811, 0.8833270810810812, 0.3541374459459459], 
             UndirectedEdge[24, 133] -> 
             RGBColor[
              0.9378182567567568, 0.9484148918918919, 0.739717189189189], 
             UndirectedEdge[30, 188] -> 
             RGBColor[
              0.9266775945945946, 0.9420856216216217, 0.9045499054054054], 
             UndirectedEdge[80, 98] -> 
             RGBColor[
              0.5869546351351351, 0.648793527027027, 0.8331606486486487], 
             UndirectedEdge[12, 102] -> 
             RGBColor[
              0.9799166891891892, 0.9426448648648648, 0.5253869594594595], 
             UndirectedEdge[51, 168] -> 
             RGBColor[0.5815595, 0.6465625, 0.922572], 
             UndirectedEdge[42, 189] -> 
             RGBColor[
              0.968015891891892, 0.8999581081081081, 0.3575126891891891], 
             UndirectedEdge[52, 187] -> 
             RGBColor[
              0.5837398648648648, 0.6392209054054054, 0.671765472972973], 
             UndirectedEdge[10, 89] -> 
             RGBColor[
              0.9557236756756756, 0.9649010270270271, 0.8923326891891892], 
             UndirectedEdge[148, 193] -> 
             RGBColor[
              0.9254985945945946, 0.9425865405405405, 0.9634617162162162], 
             UndirectedEdge[4, 92] -> 
             RGBColor[
              0.9575220540540541, 0.9656447027027026, 0.8625289054054055], 
             UndirectedEdge[28, 97] -> 
             RGBColor[
              0.9804469594594594, 0.9604016216216216, 0.6378173918918918], 
             UndirectedEdge[60, 169] -> 
             RGBColor[
              0.5619001756756756, 0.6319006081081082, 0.9558501081081081], 
             UndirectedEdge[44, 198] -> 
             RGBColor[
              0.994268391891892, 0.9904075675675675, 0.636323527027027], 
             UndirectedEdge[13, 64] -> 
             RGBColor[
              0.9239800270270271, 0.9409701081081081, 0.949255581081081], 
             UndirectedEdge[42, 106] -> 
             RGBColor[
              0.9906029729729731, 0.9798710540540541, 0.42587802702702693`], 
             UndirectedEdge[43, 90] -> 
             RGBColor[0.9479676621621622, 0.9128256756756756, 0.6432225], 
             UndirectedEdge[166, 192] -> 
             RGBColor[
              0.9627811756756757, 0.9627951351351351, 0.7007702027027027], 
             UndirectedEdge[5, 89] -> 
             RGBColor[
              0.9715768513513514, 0.9185948378378379, 0.5362388108108107], 
             UndirectedEdge[114, 184] -> 
             RGBColor[
              0.9913855135135134, 0.9907057027027028, 0.7924278648648648], 
             UndirectedEdge[58, 192] -> 
             RGBColor[
              0.9538930675675676, 0.9328134594594595, 0.6662415810810811], 
             UndirectedEdge[17, 157] -> 
             RGBColor[
              0.9387574594594594, 0.9506823243243243, 0.8607391216216217], 
             UndirectedEdge[38, 111] -> 
             RGBColor[
              0.957576027027027, 0.8598728108108109, 0.3349141216216216], 
             UndirectedEdge[3, 191] -> 
             RGBColor[
              0.9760147837837838, 0.9303835405405405, 0.3928554864864864], 
             UndirectedEdge[40, 195] -> 
             RGBColor[
              0.9859903783783783, 0.9884746756756757, 0.8818392162162163], 
             UndirectedEdge[113, 136] -> 
             RGBColor[
              0.9940051621621622, 0.989585972972973, 0.5888770810810809], 
             UndirectedEdge[53, 141] -> 
             RGBColor[
              0.9878655945945947, 0.9703591081081081, 0.43889364864864844`], 
             UndirectedEdge[142, 176] -> 
             RGBColor[
              0.9650567432432433, 0.9701003243243244, 0.7411434459459458], 
             UndirectedEdge[99, 128] -> 
             RGBColor[
              0.5851562567567568, 0.6480498513513513, 0.8629644324324324], 
             UndirectedEdge[41, 151] -> 
             RGBColor[
              0.9707765135135136, 0.9130844594594596, 0.3409727027027028], 
             UndirectedEdge[5, 157] -> 
             RGBColor[
              0.9171504189189189, 0.8778277837837838, 0.6343538513513514], 
             UndirectedEdge[39, 74] -> 
             RGBColor[
              0.9893217972972973, 0.9875844864864864, 0.6617826621621621], 
             UndirectedEdge[86, 171] -> 
             RGBColor[
              0.9617567972972974, 0.9386782162162163, 0.6529303378378379], 
             UndirectedEdge[162, 180] -> 
             RGBColor[
              0.5748517567567568, 0.6092392297297298, 0.6372368513513514], 
             UndirectedEdge[27, 127] -> 
             RGBColor[
              0.5842570675675676, 0.6476780135135136, 0.8778663243243243], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.9538930675675676, 0.9328134594594595, 0.6662415810810811], 
             UndirectedEdge[155, 191] -> 
             RGBColor[
              0.9190536621621622, 0.9334525135135135, 0.7379274054054052], 
             UndirectedEdge[46, 105] -> 
             RGBColor[
              0.9937798378378379, 0.989104027027027, 0.5643519189189188], 
             UndirectedEdge[30, 168] -> 
             RGBColor[
              0.521347527027027, 0.5998016081081081, 0.9601845810810811], 
             UndirectedEdge[161, 180] -> 
             RGBColor[
              0.9819802027027027, 0.952266918918919, 0.551798391891892], 
             UndirectedEdge[125, 192] -> 
             RGBColor[
              0.9652820675675675, 0.9705822702702702, 0.765668608108108], 
             UndirectedEdge[33, 140] -> 
             RGBColor[0.9103473378378378, 0.9274171621621621, 0.810608], 
             UndirectedEdge[12, 58] -> 
             RGBColor[
              0.9678138108108107, 0.9030905675675676, 0.3294631621621621], 
             UndirectedEdge[127, 155] -> 
             RGBColor[
              0.9172952972972973, 0.9346044324324325, 0.9036550135135135], 
             UndirectedEdge[78, 120] -> 
             RGBColor[
              0.9572588243243243, 0.9648231081081081, 0.8150824594594595], 
             UndirectedEdge[45, 183] -> 
             RGBColor[
              0.9799166891891892, 0.9426448648648648, 0.5253869594594595], 
             UndirectedEdge[98, 136] -> 
             RGBColor[
              0.5862407567567567, 0.6470080405405405, 0.7366638783783783], 
             UndirectedEdge[59, 92] -> 
             RGBColor[
              0.9454191756756757, 0.9260904054054055, 0.6666051081081081], 
             UndirectedEdge[81, 89] -> 
             RGBColor[
              0.9781183108108107, 0.9419011891891891, 0.5551907432432431], 
             UndirectedEdge[161, 200] -> 
             RGBColor[
              0.9931438783783784, 0.9895537837837838, 0.6267002567567567], 
             UndirectedEdge[125, 198] -> 
             RGBColor[
              0.994268391891892, 0.9904075675675675, 0.636323527027027], 
             UndirectedEdge[159, 173] -> 
             RGBColor[
              0.9899691216216215, 0.9818767567567568, 0.6012289054054054], 
             UndirectedEdge[54, 151] -> 
             RGBColor[
              0.9801818243243243, 0.9515232432432433, 0.5816021756756757], 
             UndirectedEdge[61, 192] -> 
             RGBColor[
              0.9448733513513513, 0.9584072162162163, 0.9781992162162162], 
             UndirectedEdge[59, 194] -> 
             RGBColor[
              0.9810810135135135, 0.9518950810810811, 0.5667002837837838], 
             UndirectedEdge[80, 82] -> 
             RGBColor[
              0.5869546351351351, 0.648793527027027, 0.8331606486486487], 
             UndirectedEdge[157, 168] -> 
             RGBColor[
              0.5307298243243243, 0.6072827972972973, 0.961079472972973], 
             UndirectedEdge[122, 170] -> 
             RGBColor[
              0.9034530675675676, 0.5620445135135135, 0.4932248243243243], 
             UndirectedEdge[26, 67] -> 
             RGBColor[
              0.9106795405405406, 0.9316151621621622, 0.9913426216216217], 
             UndirectedEdge[160, 181] -> 
             RGBColor[
              0.9888047972972973, 0.9726265405405405, 0.5599155810810811], 
             UndirectedEdge[42, 168] -> 
             RGBColor[
              0.5857901081081082, 0.6460441486486487, 0.687613554054054], 
             UndirectedEdge[61, 67] -> 
             RGBColor[
              0.9270171621621621, 0.944202972972973, 0.9776678513513513], 
             UndirectedEdge[9, 39] -> 
             RGBColor[
              0.9530261081081081, 0.9637855135135136, 0.9370383648648649], 
             UndirectedEdge[118, 171] -> 
             RGBColor[
              0.9082525675675676, 0.9292405945945946, 0.9758780675675676], 
             UndirectedEdge[97, 134] -> 
             RGBColor[
              0.9831445270270269, 0.9615171351351351, 0.5931117162162162], 
             UndirectedEdge[79, 190] -> 
             RGBColor[
              0.9190536621621622, 0.9334525135135135, 0.7379274054054052], 
             UndirectedEdge[47, 50] -> 
             RGBColor[
              0.9070138108108108, 0.9267514054054053, 0.9176620135135134], 
             UndirectedEdge[36, 145] -> 
             RGBColor[
              0.9565580810810811, 0.8524747567567568, 0.4700127702702702], 
             UndirectedEdge[170, 179] -> 
             RGBColor[
              0.8999731621621622, 0.5435935135135135, 0.27561443243243233`], 
             UndirectedEdge[26, 198] -> 
             RGBColor[
              0.9575220540540541, 0.9656447027027026, 0.8625289054054055], 
             UndirectedEdge[5, 141] -> 
             RGBColor[0.9671977567567568, 0.899772, 0.33353031081081075`], 
             UndirectedEdge[18, 39] -> 
             RGBColor[
              0.5824586891891892, 0.6469343378378378, 0.9076701081081082], 
             UndirectedEdge[19, 180] -> 
             RGBColor[
              0.9612723513513515, 0.8797842162162164, 0.3105112297297298], 
             UndirectedEdge[170, 198] -> 
             RGBColor[
              0.9061506351351352, 0.5631600270270269, 0.4485191486486487], 
             UndirectedEdge[12, 172] -> 
             RGBColor[
              0.571889054054054, 0.5992453378378377, 0.6257273108108108], 
             UndirectedEdge[47, 101] -> 
             RGBColor[
              0.5025829324324325, 0.5848392297297297, 0.9583947972972973], 
             UndirectedEdge[53, 54] -> 
             RGBColor[0.9913455, 0.9888101081081082, 0.6565040405405405], 
             UndirectedEdge[57, 121] -> 
             RGBColor[
              0.9745215540540539, 0.9404138378378377, 0.6147983108108107], 
             UndirectedEdge[19, 121] -> 
             RGBColor[
              0.9679800945945947, 0.9171074864864865, 0.5958463783783783], 
             UndirectedEdge[170, 192] -> 
             RGBColor[
              0.8771643108108108, 0.5433347297297297, 0.5778642297297297], 
             UndirectedEdge[7, 137] -> 
             RGBColor[
              0.9548244864864864, 0.9645291891891892, 0.9072345810810811], 
             UndirectedEdge[111, 115] -> 
             RGBColor[
              0.9603022432432433, 0.868141891891892, 0.42433768918918924`], 
             UndirectedEdge[140, 162] -> 
             RGBColor[
              0.5866914054054054, 0.6479719324324325, 0.7857142027027026], 
             UndirectedEdge[8, 79] -> 
             RGBColor[
              0.9640464054054054, 0.8838090270270271, 0.378662608108108], 
             UndirectedEdge[2, 52] -> 
             RGBColor[
              0.9745767702702702, 0.9715922702702703, 0.6808033378378378], 
             UndirectedEdge[18, 152] -> 
             RGBColor[
              0.5807771621621622, 0.6292270135135134, 0.6602559324324324], 
             UndirectedEdge[4, 195] -> 
             RGBColor[
              0.9904863243243243, 0.9903338648648649, 0.8073297567567569], 
             UndirectedEdge[81, 107] -> 
             RGBColor[
              0.571889054054054, 0.5992453378378377, 0.6257273108108108], 
             UndirectedEdge[108, 175] -> 
             RGBColor[
              0.9922847027027026, 0.9910775405405405, 0.777525972972973], 
             UndirectedEdge[49, 191] -> 
             RGBColor[
              0.9650567432432433, 0.9701003243243244, 0.7411434459459458], 
             UndirectedEdge[77, 192] -> 
             RGBColor[
              0.9509303648648648, 0.9228195675675674, 0.6547320405405405], 
             UndirectedEdge[21, 166] -> 
             RGBColor[
              0.9906029729729731, 0.9798710540540541, 0.42587802702702693`], 
             UndirectedEdge[8, 192] -> 
             RGBColor[
              0.9359992837837838, 0.8662511621621622, 0.6290296216216216], 
             UndirectedEdge[108, 165] -> 
             RGBColor[
              0.9926953378378378, 0.9901458378378378, 0.690652472972973], 
             UndirectedEdge[29, 194] -> 
             RGBColor[
              0.9899691216216215, 0.9818767567567568, 0.6012289054054054], 
             UndirectedEdge[106, 131] -> 
             RGBColor[
              0.9701604594594595, 0.9097658918918919, 0.3450398513513513], 
             UndirectedEdge[12, 68] -> 
             RGBColor[
              0.9457252162162162, 0.8198972432432432, 0.2888759594594594], 
             UndirectedEdge[71, 168] -> 
             RGBColor[
              0.5833578783783784, 0.6473061756756757, 0.8927682162162162], 
             UndirectedEdge[49, 146] -> 
             RGBColor[
              0.9276096621621621, 0.832989108108108, 0.6222791351351351], 
             UndirectedEdge[112, 134] -> 
             RGBColor[
              0.9672302432432431, 0.9741846216216217, 0.9002154324324324], 
             UndirectedEdge[84, 126] -> 
             RGBColor[
              0.5860154324324325, 0.6465260945945945, 0.712138716216216], 
             UndirectedEdge[10, 62] -> 
             RGBColor[
              0.9543072837837838, 0.9560720810810811, 0.7011337297297298], 
             UndirectedEdge[34, 182] -> 
             RGBColor[
              0.5866914054054054, 0.6479719324324325, 0.7857142027027026], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.5837398648648648, 0.6392209054054054, 0.671765472972973], 
             UndirectedEdge[67, 79] -> 
             RGBColor[
              0.947200554054054, 0.955896081081081, 0.740612081081081], 
             UndirectedEdge[33, 96] -> 
             RGBColor[
              0.9073957972972972, 0.9186661351351351, 0.6966592702702703], 
             UndirectedEdge[12, 140] -> 
             RGBColor[
              0.9796534594594595, 0.9418232702702702, 0.4779405135135134], 
             UndirectedEdge[26, 124] -> 
             RGBColor[
              0.9285357297297296, 0.9458194054054054, 0.9918739864864865], 
             UndirectedEdge[13, 70] -> 
             RGBColor[
              0.9834096621621622, 0.9703955135135135, 0.6493269324324323], 
             UndirectedEdge[53, 146] -> 
             RGBColor[
              0.9556567837837838, 0.8505469729729729, 0.37191212162162146`], 
             UndirectedEdge[87, 147] -> 
             RGBColor[
              0.9684645405405405, 0.9760014864864865, 0.9382654864864864], 
             UndirectedEdge[93, 200] -> 
             RGBColor[
              0.9768523378378378, 0.9788974594594595, 0.721176581081081], 
             UndirectedEdge[9, 117] -> 
             RGBColor[
              0.951344581081081, 0.9460781891891892, 0.6896241891891891], 
             UndirectedEdge[99, 116] -> 
             RGBColor[
              0.585790108108108, 0.6460441486486486, 0.687613554054054], 
             UndirectedEdge[71, 155] -> 
             RGBColor[
              0.9163961081081081, 0.9342325945945946, 0.9185569054054054], 
             UndirectedEdge[54, 140] -> 
             RGBColor[
              0.9920214729729729, 0.9902559459459459, 0.730079527027027], 
             UndirectedEdge[76, 154] -> 
             RGBColor[
              0.9922467972972973, 0.9907378918918919, 0.7546046891891891], 
             UndirectedEdge[33, 128] -> 
             RGBColor[
              0.9088121891891892, 0.9274950810810811, 0.8878582297297297], 
             UndirectedEdge[109, 148] -> 
             RGBColor[
              0.8961763648648648, 0.7946726486486486, 0.6174776351351352], 
             UndirectedEdge[27, 142] -> 
             RGBColor[
              0.5579683108108109, 0.6289682297297297, 0.9625057297297297], 
             UndirectedEdge[49, 69] -> 
             RGBColor[
              0.931804472972973, 0.8496201351351351, 0.6256543783783783], 
             UndirectedEdge[60, 90] -> 
             RGBColor[
              0.5689263513513514, 0.5892514459459459, 0.6142177702702702], 
             UndirectedEdge[40, 191] -> 
             RGBColor[
              0.9895471216216216, 0.9880664324324324, 0.6863078243243242], 
             UndirectedEdge[58, 166] -> 
             RGBColor[
              0.9796646216216216, 0.9430661351351353, 0.37550132432432437`], 
             UndirectedEdge[38, 60] -> 
             RGBColor[
              0.5837398648648648, 0.6392209054054054, 0.671765472972973], 
             UndirectedEdge[54, 119] -> 
             RGBColor[
              0.9538984189189189, 0.8516988918918919, 0.5376397297297297], 
             UndirectedEdge[3, 146] -> 
             RGBColor[
              0.9385677027027027, 0.7932723243243243, 0.27399117567567566`], 
             UndirectedEdge[115, 163] -> 
             RGBColor[
              0.9603022432432433, 0.868141891891892, 0.42433768918918924`], 
             UndirectedEdge[137, 170] -> 
             RGBColor[
              0.9034530675675676, 0.5620445135135135, 0.4932248243243243], 
             UndirectedEdge[58, 99] -> 
             RGBColor[
              0.5748517567567568, 0.6092392297297298, 0.6372368513513513], 
             UndirectedEdge[40, 64] -> 
             RGBColor[
              0.9248792162162163, 0.941341945945946, 0.9343536891891893], 
             UndirectedEdge[77, 96] -> 
             RGBColor[
              0.9767019189189189, 0.9330722432432432, 0.36399178378378366`], 
             UndirectedEdge[141, 195] -> 
             RGBColor[
              0.9843088513513514, 0.9707673513513513, 0.6344250405405405], 
             UndirectedEdge[138, 182] -> 
             RGBColor[0.5815595, 0.6465625, 0.922572], 
             UndirectedEdge[33, 102] -> 
             RGBColor[
              0.9106105675675675, 0.9282387567567567, 0.858054445945946], 
             UndirectedEdge[137, 198] -> 
             RGBColor[
              0.9922847027027026, 0.9910775405405405, 0.7775259729729731], 
             UndirectedEdge[69, 171] -> 
             RGBColor[
              0.9396682027027027, 0.8554848918918919, 0.6123431351351352], 
             UndirectedEdge[20, 46] -> 
             RGBColor[
              0.9733373243243244, 0.9189988648648649, 0.48351374324324325`], 
             UndirectedEdge[76, 157] -> 
             RGBColor[
              0.938719554054054, 0.9503426756756757, 0.8378178378378378], 
             UndirectedEdge[10, 168] -> 
             RGBColor[
              0.5494944189189189, 0.6222451756756757, 0.9628692567567567], 
             UndirectedEdge[82, 100] -> 
             RGBColor[
              0.585790108108108, 0.6460441486486486, 0.687613554054054], 
             UndirectedEdge[9, 57] -> 
             RGBColor[
              0.942456472972973, 0.9160965135135135, 0.6550955675675675], 
             UndirectedEdge[27, 71] -> 
             RGBColor[
              0.5833578783783784, 0.6473061756756757, 0.8927682162162162], 
             UndirectedEdge[122, 125] -> 
             RGBColor[
              0.9915708243243243, 0.9892920540540541, 0.6810292027027025], 
             UndirectedEdge[5, 147] -> 
             RGBColor[
              0.9679800945945947, 0.9171074864864865, 0.5958463783783783], 
             UndirectedEdge[5, 71] -> 
             RGBColor[
              0.969778472972973, 0.9178511621621622, 0.5660425945945946], 
             UndirectedEdge[61, 84] -> 
             RGBColor[
              0.5658320405405405, 0.6348329864864865, 0.9491944864864865], 
             UndirectedEdge[62, 149] -> 
             RGBColor[
              0.9533812162162163, 0.8432417837837838, 0.33153887837837837`], 
             UndirectedEdge[36, 138] -> 
             RGBColor[
              0.9512008513513514, 0.8505833783783783, 0.5823454054054054], 
             UndirectedEdge[33, 162] -> 
             RGBColor[
              0.5025829324324325, 0.5848392297297297, 0.9583947972972973], 
             UndirectedEdge[63, 145] -> 
             RGBColor[
              0.9937798378378379, 0.989104027027027, 0.5643519189189188], 
             UndirectedEdge[93, 173] -> 
             RGBColor[
              0.975993162162162, 0.9804212162162163, 0.8720022972972973], 
             UndirectedEdge[23, 55] -> 
             RGBColor[
              0.9767019189189189, 0.9330722432432432, 0.36399178378378366`], 
             UndirectedEdge[23, 165] -> 
             RGBColor[
              0.9912789459459459, 0.981316891891892, 0.4994535135135135], 
             UndirectedEdge[54, 64] -> 
             RGBColor[
              0.9266775945945946, 0.9420856216216217, 0.9045499054054054], 
             UndirectedEdge[72, 158] -> 
             RGBColor[
              0.9763199324324323, 0.9411575135135135, 0.5849945270270269], 
             UndirectedEdge[73, 149] -> 
             RGBColor[
              0.9276096621621621, 0.832989108108108, 0.6222791351351351], 
             UndirectedEdge[10, 197] -> 
             RGBColor[
              0.9275253918918919, 0.8595281081081081, 0.6293931486486486], 
             UndirectedEdge[37, 135] -> 
             RGBColor[
              0.8922912027027027, 0.5777376756756756, 0.5610874189189189], 
             UndirectedEdge[58, 96] -> 
             RGBColor[
              0.9796646216216216, 0.9430661351351353, 0.37550132432432437`], 
             UndirectedEdge[112, 156] -> 
             RGBColor[
              0.968988608108108, 0.9730327027027028, 0.7344878243243242], 
             UndirectedEdge[2, 187] -> 
             RGBColor[
              0.5697639054054053, 0.6377653648648649, 0.9425388648648649], 
             UndirectedEdge[43, 169] -> 
             RGBColor[
              0.9409414864864865, 0.9554748378378379, 0.9848548378378379], 
             UndirectedEdge[44, 96] -> 
             RGBColor[
              0.9910536216216217, 0.980834945945946, 0.4749283513513512], 
             UndirectedEdge[88, 161] -> 
             RGBColor[
              0.9650967567567568, 0.9719959189189189, 0.8770672702702703], 
             UndirectedEdge[129, 146] -> 
             RGBColor[
              0.934988945945946, 0.7799598648648649, 0.26654878378378377`], 
             UndirectedEdge[23, 111] -> 
             RGBColor[
              0.957576027027027, 0.8598728108108109, 0.3349141216216216], 
             UndirectedEdge[174, 196] -> 
             RGBColor[
              0.9781183108108107, 0.9419011891891891, 0.5551907432432431], 
             UndirectedEdge[66, 100] -> 
             RGBColor[
              0.9938177432432433, 0.9894436756756757, 0.5872732027027027], 
             UndirectedEdge[10, 73] -> 
             RGBColor[
              0.9285357297297296, 0.9458194054054054, 0.9918739864864865], 
             UndirectedEdge[147, 188] -> 
             RGBColor[
              0.9868895675675675, 0.9888465135135136, 0.8669373243243244], 
             UndirectedEdge[62, 189] -> 
             RGBColor[
              0.9659656486486486, 0.8931348648648649, 0.34166460810810806`], 
             UndirectedEdge[42, 89] -> 
             RGBColor[0.9920193648648649, 0.9887, 0.6170769864864863], 
             UndirectedEdge[119, 140] -> 
             RGBColor[
              0.9563327567567568, 0.8519928108108108, 0.44548760810810806`], 
             UndirectedEdge[140, 151] -> 
             RGBColor[
              0.9826161621621622, 0.9518171621621623, 0.48945005405405406`], 
             UndirectedEdge[1, 86] -> 
             RGBColor[
              0.5748517567567568, 0.6092392297297298, 0.6372368513513514], 
             UndirectedEdge[76, 181] -> 
             RGBColor[
              0.9887668918918919, 0.9722868918918919, 0.5369942972972972], 
             UndirectedEdge[122, 166] -> 
             RGBColor[
              0.9890699324324324, 0.9815049189189189, 0.6161307972972973], 
             UndirectedEdge[10, 189] -> 
             RGBColor[
              0.9317202027027027, 0.8761591351351352, 0.6327683918918918], 
             UndirectedEdge[102, 162] -> 
             RGBColor[
              0.5869546351351351, 0.648793527027027, 0.8331606486486487], 
             UndirectedEdge[156, 183] -> 
             RGBColor[
              0.9789774864864864, 0.9403774324324323, 0.4043650270270268], 
             UndirectedEdge[31, 199] -> 
             RGBColor[
              0.5860154324324325, 0.6465260945945946, 0.712138716216216], 
             UndirectedEdge[73, 130] -> 
             RGBColor[0.9615, 0.9705085675675675, 0.9366748378378379], 
             UndirectedEdge[4, 199] -> 
             RGBColor[
              0.5869546351351351, 0.648793527027027, 0.8331606486486487], 
             UndirectedEdge[6, 83] -> 
             RGBColor[
              0.9859903783783783, 0.9884746756756757, 0.8818392162162163], 
             UndirectedEdge[73, 89] -> 
             RGBColor[
              0.9641975675675676, 0.9716240810810811, 0.8919691621621622], 
             UndirectedEdge[60, 111] -> 
             RGBColor[
              0.5527631621621623, 0.5260459054054054, 0.5966496486486487], 
             UndirectedEdge[166, 179] -> 
             RGBColor[
              0.985590027027027, 0.9630539189189189, 0.3985204054054053], 
             UndirectedEdge[30, 197] -> 
             RGBColor[
              0.8993785000000001, 0.8370845405405406, 0.6267084729729729], 
             UndirectedEdge[26, 58] -> 
             RGBColor[
              0.9454191756756757, 0.9260904054054055, 0.6666051081081081], 
             UndirectedEdge[11, 35] -> 
             RGBColor[
              0.9917295945945945, 0.9822807837837838, 0.5485038378378377], 
             UndirectedEdge[137, 187] -> 
             RGBColor[
              0.5842570675675676, 0.6476780135135135, 0.8778663243243243], 
             UndirectedEdge[13, 153] -> 
             RGBColor[
              0.9429710675675675, 0.8172415675675676, 0.5756866216216217], 
             UndirectedEdge[71, 75] -> 
             RGBColor[
              0.9257784054054055, 0.9417137837837839, 0.9194517972972972], 
             UndirectedEdge[16, 67] -> 
             RGBColor[
              0.9481397567567568, 0.9581635135135135, 0.8616340135135137], 
             UndirectedEdge[156, 170] -> 
             RGBColor[
              0.9052114324324325, 0.5608925945945946, 0.3274972162162161], 
             UndirectedEdge[96, 128] -> 
             RGBColor[
              0.9899691216216215, 0.9818767567567568, 0.6012289054054054], 
             UndirectedEdge[62, 114] -> 
             RGBColor[
              0.9890699324324324, 0.9815049189189189, 0.6161307972972973], 
             UndirectedEdge[101, 105] -> 
             RGBColor[
              0.585790108108108, 0.6460441486486486, 0.687613554054054], 
             UndirectedEdge[30, 89] -> 
             RGBColor[
              0.9275767837837838, 0.9424574594594595, 0.8896480135135134], 
             UndirectedEdge[53, 191] -> 
             RGBColor[
              0.9931038648648649, 0.9876581891891892, 0.4907764324324322], 
             UndirectedEdge[72, 81] -> 
             RGBColor[
              0.9763199324324323, 0.9411575135135135, 0.5849945270270269], 
             UndirectedEdge[163, 175] -> 
             RGBColor[
              0.9598916081081081, 0.8690735945945947, 0.5112111891891893], 
             UndirectedEdge[82, 125] -> 
             RGBColor[
              0.5862407567567567, 0.6470080405405405, 0.7366638783783783], 
             UndirectedEdge[113, 148] -> 
             RGBColor[
              0.9384942297297296, 0.9498607297297297, 0.8132926756756756], 
             UndirectedEdge[33, 44] -> 
             RGBColor[
              0.9098966891891892, 0.9264532702702702, 0.7615576756756756], 
             UndirectedEdge[21, 179] -> 
             RGBColor[
              0.9876402702702702, 0.9698771621621621, 0.4143684864864863], 
             UndirectedEdge[75, 188] -> 
             RGBColor[
              0.9266775945945946, 0.9420856216216217, 0.9045499054054054], 
             UndirectedEdge[85, 88] -> 
             RGBColor[
              0.9632983783783784, 0.9712522432432433, 0.9068710540540541], 
             UndirectedEdge[13, 185] -> 
             RGBColor[
              0.9774842567567568, 0.9504077297297298, 0.6263078513513514], 
             UndirectedEdge[93, 161] -> 
             RGBColor[
              0.9768923513513512, 0.9807930540540541, 0.8571004054054054], 
             UndirectedEdge[146, 196] -> 
             RGBColor[
              0.9547976081081081, 0.8520707297297296, 0.5227378378378378], 
             UndirectedEdge[19, 162] -> 
             RGBColor[
              0.5653475945945946, 0.5759389864864866, 0.6067753783783785], 
             UndirectedEdge[140, 172] -> 
             RGBColor[
              0.5866914054054054, 0.6479719324324325, 0.7857142027027026], 
             UndirectedEdge[71, 142] -> 
             RGBColor[
              0.9623991891891892, 0.9708804054054054, 0.9217729459459458], 
             UndirectedEdge[87, 142] -> 
             RGBColor[
              0.9448733513513513, 0.9584072162162163, 0.9781992162162162], 
             UndirectedEdge[89, 147] -> 
             RGBColor[
              0.9877887567567567, 0.9892183513513514, 0.8520354324324324], 
             UndirectedEdge[30, 42] -> 
             RGBColor[
              0.9282106351351351, 0.9404517567567567, 0.714297135135135], 
             UndirectedEdge[8, 125] -> 
             RGBColor[
              0.9642717297297297, 0.884290972972973, 0.40318777027027014`], 
             UndirectedEdge[29, 168] -> 
             RGBColor[
              0.5837398648648648, 0.6392209054054054, 0.671765472972973], 
             UndirectedEdge[158, 160] -> 
             RGBColor[
              0.9799166891891892, 0.9426448648648648, 0.5253869594594595], 
             UndirectedEdge[138, 153] -> 
             RGBColor[
              0.9429710675675675, 0.8172415675675676, 0.5756866216216217], 
             UndirectedEdge[26, 122] -> 
             RGBColor[
              0.9548244864864864, 0.9645291891891892, 0.9072345810810811], 
             UndirectedEdge[53, 195] -> 
             RGBColor[
              0.9895471216216216, 0.9880664324324324, 0.6863078243243242], 
             UndirectedEdge[19, 93] -> 
             RGBColor[0.9561845, 0.9083103513513514, 0.6158132432432433], 
             UndirectedEdge[11, 196] -> 
             RGBColor[
              0.9899691216216215, 0.9818767567567568, 0.6012289054054054], 
             UndirectedEdge[87, 168] -> 
             RGBColor[
              0.5658320405405405, 0.6348329864864865, 0.9491944864864865], 
             UndirectedEdge[78, 124] -> 
             RGBColor[
              0.9285357297297296, 0.9458194054054054, 0.9918739864864865], 
             UndirectedEdge[39, 117] -> 
             RGBColor[
              0.9843088513513514, 0.9707673513513513, 0.6344250405405405], 
             UndirectedEdge[42, 130] -> 
             RGBColor[
              0.9893217972972973, 0.9875844864864864, 0.6617826621621621], 
             UndirectedEdge[11, 94] -> 
             RGBColor[
              0.9261603918918919, 0.9336285135135136, 0.698449054054054], 
             UndirectedEdge[27, 168] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[30, 51] -> 
             RGBColor[
              0.9239800270270271, 0.9409701081081081, 0.949255581081081], 
             UndirectedEdge[6, 58] -> 
             RGBColor[
              0.978383445945946, 0.9507795675675677, 0.6114059594594595], 
             UndirectedEdge[6, 156] -> 
             RGBColor[
              0.9895471216216216, 0.9880664324324324, 0.6863078243243242], 
             UndirectedEdge[19, 173] -> 
             RGBColor[
              0.9715768513513514, 0.9185948378378379, 0.5362388108108107], 
             UndirectedEdge[57, 200] -> 
             RGBColor[
              0.9789774864864864, 0.9403774324324323, 0.4043650270270268], 
             UndirectedEdge[37, 50] -> 
             RGBColor[
              0.9741947837837837, 0.9796775405405406, 0.9018060810810811], 
             UndirectedEdge[49, 171] -> 
             RGBColor[
              0.9448733513513513, 0.9584072162162163, 0.9781992162162162], 
             UndirectedEdge[5, 127] -> 
             RGBColor[0.9706776621621622, 0.918223, 0.5511407027027027], 
             UndirectedEdge[85, 152] -> 
             RGBColor[
              0.9861072297297298, 0.9715110270270271, 0.6046212567567566], 
             UndirectedEdge[130, 131] -> 
             RGBColor[
              0.9688792837837839, 0.9174793243243244, 0.5809444864864866], 
             UndirectedEdge[33, 58] -> 
             RGBColor[
              0.8985076891891892, 0.8886844594594595, 0.6621306486486487], 
             UndirectedEdge[82, 98] -> RGBColor[0.178927, 0.305394, 0.933501],
              UndirectedEdge[74, 173] -> 
             RGBColor[0.9920193648648649, 0.9887, 0.6170769864864863], 
             UndirectedEdge[118, 146] -> 
             RGBColor[
              0.8909888783783784, 0.8038224864864865, 0.6199579864864865], 
             UndirectedEdge[23, 115] -> 
             RGBColor[
              0.9912789459459459, 0.981316891891892, 0.4994535135135135], 
             UndirectedEdge[49, 65] -> 
             RGBColor[
              0.9652820675675675, 0.9705822702702702, 0.765668608108108], 
             UndirectedEdge[21, 23] -> 
             RGBColor[
              0.9906029729729731, 0.9798710540540541, 0.42587802702702693`], 
             UndirectedEdge[40, 171] -> 
             RGBColor[
              0.9693637297297297, 0.9763733243243243, 0.9233635945945946], 
             UndirectedEdge[104, 158] -> 
             RGBColor[
              0.9781183108108107, 0.9419011891891891, 0.5551907432432431], 
             UndirectedEdge[53, 155] -> 
             RGBColor[
              0.9190536621621622, 0.9334525135135135, 0.7379274054054052], 
             UndirectedEdge[164, 200] -> 
             RGBColor[
              0.947200554054054, 0.955896081081081, 0.740612081081081], 
             UndirectedEdge[81, 142] -> 
             RGBColor[
              0.9509303648648648, 0.9228195675675674, 0.6547320405405405], 
             UndirectedEdge[39, 85] -> 
             RGBColor[
              0.9877887567567567, 0.9892183513513514, 0.8520354324324324], 
             UndirectedEdge[107, 142] -> 
             RGBColor[
              0.5579683108108109, 0.6289682297297297, 0.9625057297297297], 
             UndirectedEdge[121, 161] -> 
             RGBColor[
              0.9886879459459459, 0.9895901891891892, 0.8371335405405406], 
             UndirectedEdge[1, 196] -> 
             RGBColor[
              0.5851562567567568, 0.6480498513513513, 0.8629644324324324], 
             UndirectedEdge[88, 121] -> 
             RGBColor[
              0.9606008108108108, 0.9701367297297298, 0.9515767297297297], 
             UndirectedEdge[85, 133] -> 
             RGBColor[
              0.9360598918918919, 0.9495668108108108, 0.9054447972972972], 
             UndirectedEdge[118, 127] -> 
             RGBColor[
              0.9266775945945946, 0.9420856216216217, 0.9045499054054054], 
             UndirectedEdge[100, 187] -> 
             RGBColor[
              0.5857901081081082, 0.6460441486486487, 0.687613554054054], 
             UndirectedEdge[26, 116] -> 
             RGBColor[
              0.956357527027027, 0.9628953243243243, 0.7169818108108107], 
             UndirectedEdge[131, 147] -> 
             RGBColor[
              0.9679800945945947, 0.9171074864864865, 0.5958463783783783], 
             UndirectedEdge[134, 160] -> 
             RGBColor[
              0.9922847027027026, 0.9910775405405405, 0.7775259729729731], 
             UndirectedEdge[3, 5] -> 
             RGBColor[
              0.955346945945946, 0.8597964324324325, 0.2874921486486487], 
             UndirectedEdge[16, 100] -> 
             RGBColor[
              0.9938177432432433, 0.9894436756756757, 0.5872732027027027], 
             UndirectedEdge[75, 147] -> 
             RGBColor[
              0.9239800270270271, 0.9409701081081081, 0.949255581081081], 
             UndirectedEdge[72, 76] -> 
             RGBColor[
              0.9913476081081081, 0.9903660540540541, 0.769506581081081], 
             UndirectedEdge[40, 69] -> 
             RGBColor[
              0.9562948513513514, 0.8675862432432433, 0.5708187567567569], 
             UndirectedEdge[177, 179] -> 
             RGBColor[
              0.9588081351351352, 0.866509945945946, 0.32677982432432423`], 
             UndirectedEdge[98, 100] -> 
             RGBColor[
              0.585790108108108, 0.6460441486486486, 0.687613554054054], 
             UndirectedEdge[136, 187] -> 
             RGBColor[
              0.5862407567567568, 0.6470080405405405, 0.7366638783783783], 
             UndirectedEdge[54, 199] -> 
             RGBColor[
              0.5842570675675676, 0.6476780135135135, 0.8778663243243243], 
             UndirectedEdge[166, 198] -> 
             RGBColor[0.9917675, 0.9826204324324324, 0.5714251216216217], 
             UndirectedEdge[48, 104] -> 
             RGBColor[
              0.9463413783783783, 0.9574198378378378, 0.8914377972972973], 
             UndirectedEdge[187, 198] -> 
             RGBColor[
              0.5869546351351351, 0.6487935270270271, 0.8331606486486487], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.9885527297297297, 0.9730478108108108, 0.4100299459459459], 
             UndirectedEdge[103, 117] -> 
             RGBColor[
              0.5807771621621622, 0.6292270135135134, 0.6602559324324324], 
             UndirectedEdge[85, 140] -> 
             RGBColor[
              0.9920214729729729, 0.9902559459459459, 0.730079527027027], 
             UndirectedEdge[36, 70] -> 
             RGBColor[
              0.9504185135135135, 0.8332478918918917, 0.3200293378378377], 
             UndirectedEdge[54, 171] -> 
             RGBColor[0.9711621081081081, 0.977117, 0.8935598108108107], 
             UndirectedEdge[120, 125] -> 
             RGBColor[
              0.9940051621621622, 0.989585972972973, 0.5888770810810809], 
             UndirectedEdge[81, 104] -> 
             RGBColor[
              0.9781183108108107, 0.9419011891891891, 0.5551907432432431], 
             UndirectedEdge[93, 162] -> 
             RGBColor[
              0.5697639054054053, 0.6377653648648649, 0.9425388648648649], 
             UndirectedEdge[73, 168] -> 
             RGBColor[
              0.5579683108108108, 0.6289682297297298, 0.9625057297297297], 
             UndirectedEdge[119, 199] -> 
             RGBColor[
              0.5485683513513514, 0.5094148783783783, 0.5932744054054053], 
             UndirectedEdge[17, 107] -> 
             RGBColor[
              0.5869546351351351, 0.648793527027027, 0.8331606486486487], 
             UndirectedEdge[14, 48] -> 
             RGBColor[
              0.9389995810810811, 0.9286031081081081, 0.6772197567567566], 
             UndirectedEdge[64, 182] -> 
             RGBColor[
              0.521347527027027, 0.5998016081081081, 0.9601845810810811], 
             UndirectedEdge[71, 129] -> 
             RGBColor[
              0.969778472972973, 0.9178511621621622, 0.5660425945945945], 
             UndirectedEdge[80, 100] -> 
             RGBColor[
              0.9938177432432433, 0.9894436756756757, 0.5872732027027027], 
             UndirectedEdge[18, 178] -> 
             RGBColor[
              0.5860154324324325, 0.6465260945945945, 0.712138716216216], 
             UndirectedEdge[174, 186] -> 
             RGBColor[
              0.9796534594594595, 0.9418232702702702, 0.4779405135135134], 
             UndirectedEdge[115, 165] -> 
             RGBColor[
              0.9940051621621622, 0.989585972972973, 0.5888770810810812], 
             UndirectedEdge[113, 198] -> 
             RGBColor[
              0.9947190405405406, 0.9913714594594594, 0.6853738513513514], 
             UndirectedEdge[67, 100] -> 
             RGBColor[
              0.9469752297297298, 0.9554141351351351, 0.7160869189189188], 
             UndirectedEdge[106, 147] -> 
             RGBColor[
              0.9863723648648648, 0.9803894054054054, 0.660836472972973], 
             UndirectedEdge[75, 129] -> 
             RGBColor[
              0.9077681216216217, 0.8703465945945947, 0.6334589594594594], 
             UndirectedEdge[175, 183] -> 
             RGBColor[
              0.9790174999999999, 0.942273027027027, 0.5402888513513513], 
             UndirectedEdge[105, 144] -> 
             RGBColor[
              0.9757894594594595, 0.9299015945945945, 0.3683303243243242], 
             UndirectedEdge[44, 128] -> 
             RGBColor[
              0.9924700135135135, 0.9896638918918919, 0.6661273108108107], 
             UndirectedEdge[70, 138] -> 
             RGBColor[
              0.9834096621621622, 0.9703955135135135, 0.6493269324324323], 
             UndirectedEdge[110, 145] -> 
             RGBColor[
              0.977753635135135, 0.9808252432432433, 0.8192772297297297], 
             UndirectedEdge[49, 118] -> 
             RGBColor[
              0.9003888378378379, 0.9233758378378378, 0.9891893108108107], 
             UndirectedEdge[70, 185] -> 
             RGBColor[
              0.976701918918919, 0.9330722432432432, 0.3639917837837837], 
             UndirectedEdge[11, 138] -> 
             RGBColor[
              0.9863723648648648, 0.9803894054054054, 0.660836472972973], 
             UndirectedEdge[120, 187] -> 
             RGBColor[
              0.5866914054054054, 0.6479719324324325, 0.7857142027027026], 
             UndirectedEdge[71, 127] -> 
             RGBColor[
              0.9886879459459459, 0.9895901891891892, 0.8371335405405405], 
             UndirectedEdge[4, 182] -> 
             RGBColor[
              0.5869546351351351, 0.648793527027027, 0.8331606486486487], 
             UndirectedEdge[29, 71] -> 
             RGBColor[
              0.9881707432432432, 0.9811330810810811, 0.6310326891891891], 
             UndirectedEdge[63, 185] -> 
             RGBColor[
              0.9817148648648649, 0.9498893783783784, 0.39134940540540536`], 
             UndirectedEdge[83, 175] -> 
             RGBColor[
              0.9895871351351351, 0.9899620270270271, 0.8222316486486487], 
             UndirectedEdge[79, 126] -> 
             RGBColor[
              0.9931038648648649, 0.9876581891891892, 0.4907764324324322], 
             UndirectedEdge[107, 154] -> 
             RGBColor[
              0.5842570675675676, 0.6476780135135136, 0.8778663243243243], 
             UndirectedEdge[34, 64] -> 
             RGBColor[
              0.9291119324324324, 0.9423795405405406, 0.8123977837837837], 
             UndirectedEdge[159, 180] -> 
             RGBColor[
              0.9796646216216216, 0.9430661351351353, 0.37550132432432437`], 
             UndirectedEdge[3, 123] -> 
             RGBColor[
              0.9636951216216216, 0.9245551891891892, 0.6166000135135135], 
             UndirectedEdge[50, 97] -> 
             RGBColor[
              0.9822453378378377, 0.9611452972972974, 0.608013608108108], 
             UndirectedEdge[87, 89] -> 
             RGBColor[
              0.9720612972972973, 0.9774888378378379, 0.8786579189189189], 
             UndirectedEdge[123, 191] -> 
             RGBColor[
              0.9807842027027027, 0.9818298378378378, 0.7145209594594593], 
             UndirectedEdge[108, 151] -> 
             RGBColor[
              0.9810810135135135, 0.9518950810810811, 0.5667002837837838], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.5869546351351351, 0.648793527027027, 0.8331606486486487], 
             UndirectedEdge[19, 33] -> 
             RGBColor[
              0.8890035270270271, 0.8553842162162162, 0.6316691756756756], 
             UndirectedEdge[156, 199] -> 
             RGBColor[
              0.5860154324324325, 0.6465260945945946, 0.712138716216216], 
             UndirectedEdge[47, 144] -> 
             RGBColor[
              0.8925822837837838, 0.8686966756756757, 0.6391115675675676], 
             UndirectedEdge[123, 127] -> 
             RGBColor[
              0.9790258378378378, 0.9829817567567568, 0.8802485675675675], 
             UndirectedEdge[82, 120] -> 
             RGBColor[
              0.5866914054054053, 0.6479719324324325, 0.7857142027027026], 
             UndirectedEdge[120, 137] -> 
             RGBColor[
              0.9920214729729729, 0.9902559459459459, 0.730079527027027], 
             UndirectedEdge[122, 179] -> 
             RGBColor[
              0.9861072297297298, 0.9715110270270271, 0.6046212567567566], 
             UndirectedEdge[52, 124] -> 
             RGBColor[
              0.9627811756756757, 0.9627951351351351, 0.7007702027027027], 
             UndirectedEdge[17, 106] -> 
             RGBColor[0.9917675, 0.9826204324324324, 0.5714251216216217], 
             UndirectedEdge[125, 166] -> 
             RGBColor[
              0.9910536216216217, 0.980834945945946, 0.4749283513513512], 
             UndirectedEdge[7, 79] -> 
             RGBColor[
              0.9565828513513513, 0.9633772702702703, 0.7415069729729729], 
             UndirectedEdge[49, 127] -> 
             RGBColor[
              0.9632983783783784, 0.9712522432432433, 0.9068710540540541], 
             UndirectedEdge[121, 200] -> 
             RGBColor[
              0.9886479324324324, 0.9876945945945946, 0.7012097162162161], 
             UndirectedEdge[56, 193] -> 
             RGBColor[
              0.7824202972972973, 0.8296027297297297, 0.9498167702702702], 
             UndirectedEdge[149, 194] -> 
             RGBColor[
              0.9547976081081081, 0.8520707297297296, 0.5227378378378378], 
             UndirectedEdge[108, 133] -> 
             RGBColor[
              0.9369590810810811, 0.9499386486486486, 0.8905429054054054], 
             UndirectedEdge[41, 140] -> 
             RGBColor[
              0.9826161621621622, 0.9518171621621623, 0.48945005405405406`], 
             UndirectedEdge[36, 185] -> 
             RGBColor[
              0.9444931081081082, 0.8132601081081081, 0.2970102567567568], 
             UndirectedEdge[108, 111] -> 
             RGBColor[
              0.958992418918919, 0.8687017567567568, 0.526113081081081], 
             UndirectedEdge[72, 154] -> 
             RGBColor[
              0.9886879459459459, 0.9895901891891892, 0.8371335405405405], 
             UndirectedEdge[63, 110] -> 
             RGBColor[
              0.9766270135135136, 0.9784155135135135, 0.6966514189189188], 
             UndirectedEdge[15, 186] -> 
             RGBColor[
              0.9942304864864865, 0.990067918918919, 0.6134022432432433], 
             UndirectedEdge[54, 155] -> 
             RGBColor[
              0.9172952972972973, 0.9346044324324325, 0.9036550135135135], 
             UndirectedEdge[18, 108] -> 
             RGBColor[
              0.5851562567567568, 0.6480498513513513, 0.8629644324324324], 
             UndirectedEdge[44, 102] -> 
             RGBColor[
              0.994268391891892, 0.9904075675675675, 0.636323527027027], 
             UndirectedEdge[8, 122] -> 
             RGBColor[
              0.9622880405405405, 0.884960945945946, 0.5443902162162162], 
             UndirectedEdge[42, 197] -> 
             RGBColor[
              0.9638210810810811, 0.8833270810810812, 0.3541374459459459], 
             UndirectedEdge[48, 147] -> 
             RGBColor[
              0.9427446216216215, 0.9559324864864864, 0.9510453648648649], 
             UndirectedEdge[34, 54] -> 
             RGBColor[
              0.9920214729729729, 0.9902559459459459, 0.730079527027027], 
             UndirectedEdge[5, 75] -> 
             RGBColor[
              0.9077681216216217, 0.8703465945945947, 0.6334589594594595], 
             UndirectedEdge[55, 115] -> 
             RGBColor[
              0.979428135135135, 0.9413413243243243, 0.4534153513513513], 
             UndirectedEdge[49, 155] -> 
             RGBColor[
              0.8910065405405405, 0.9158946486486487, 0.9882944189189189], 
             UndirectedEdge[66, 136] -> 
             RGBColor[
              0.994268391891892, 0.9904075675675675, 0.636323527027027], 
             UndirectedEdge[136, 148] -> 
             RGBColor[
              0.938043581081081, 0.9488968378378377, 0.7642423513513512], 
             UndirectedEdge[130, 189] -> 
             RGBColor[
              0.9646844729729729, 0.9008482972972973, 0.5775692432432433], 
             UndirectedEdge[48, 76] -> 
             RGBColor[
              0.9481018513513513, 0.9578238648648649, 0.8387127297297297], 
             UndirectedEdge[29, 141] -> 
             RGBColor[
              0.985590027027027, 0.9630539189189189, 0.3985204054054053], 
             UndirectedEdge[133, 163] -> 
             RGBColor[
              0.9045659864864865, 0.8279347027027026, 0.6242281216216217], 
             UndirectedEdge[111, 169] -> 
             RGBColor[
              0.9357363378378378, 0.8525525135135136, 0.6189987567567568], 
             UndirectedEdge[76, 142] -> 
             RGBColor[
              0.9659580405405406, 0.9720281081081081, 0.8392440945945946], 
             UndirectedEdge[78, 98] -> 
             RGBColor[
              0.5494944189189189, 0.6222451756756757, 0.9628692567567567], 
             UndirectedEdge[21, 170] -> 
             RGBColor[
              0.9049861081081081, 0.5604106486486486, 0.302972054054054], 
             UndirectedEdge[92, 139] -> 
             RGBColor[
              0.8825326486486487, 0.9091715945945946, 0.9886579459459459], 
             UndirectedEdge[63, 70] -> 
             RGBColor[
              0.9876402702702702, 0.9698771621621621, 0.4143684864864863], 
             UndirectedEdge[71, 197] -> 
             RGBColor[
              0.9613888513513513, 0.8845891081081081, 0.559292108108108], 
             UndirectedEdge[127, 141] -> 
             RGBColor[
              0.9861072297297298, 0.9715110270270271, 0.6046212567567566], 
             UndirectedEdge[64, 138] -> 
             RGBColor[
              0.9239800270270271, 0.9409701081081081, 0.949255581081081], 
             UndirectedEdge[39, 108] -> 
             RGBColor[
              0.9886879459459459, 0.9895901891891892, 0.8371335405405406], 
             UndirectedEdge[24, 165] -> 
             RGBColor[
              0.9935545135135135, 0.9886220810810811, 0.5398267567567567], 
             UndirectedEdge[132, 182] -> 
             RGBColor[
              0.5611527837837837, 0.5593079594594594, 0.6034001351351351], 
             UndirectedEdge[77, 181] -> 
             RGBColor[
              0.9737392162162162, 0.9230783513513512, 0.35248224324324307`], 
             UndirectedEdge[20, 47] -> 
             RGBColor[
              0.8890035270270271, 0.8553842162162162, 0.6316691756756756], 
             UndirectedEdge[191, 199] -> 
             RGBColor[
              0.5860154324324325, 0.6465260945945946, 0.712138716216216], 
             UndirectedEdge[89, 154] -> 
             RGBColor[
              0.9904863243243243, 0.990333864864865, 0.8073297567567568], 
             UndirectedEdge[93, 164] -> 
             RGBColor[
              0.930949027027027, 0.9471353513513514, 0.9710122297297297], 
             UndirectedEdge[26, 187] -> 
             RGBColor[
              0.5494944189189189, 0.6222451756756757, 0.9628692567567567], 
             UndirectedEdge[5, 188] -> 
             RGBColor[0.9706776621621622, 0.918223, 0.5511407027027027], 
             UndirectedEdge[7, 16] -> 
             RGBColor[
              0.9575220540540541, 0.9656447027027026, 0.8625289054054055], 
             UndirectedEdge[154, 160] -> 
             RGBColor[
              0.9922847027027026, 0.9910775405405405, 0.7775259729729731], 
             UndirectedEdge[88, 152] -> 
             RGBColor[
              0.959818472972973, 0.9528012432432432, 0.6892606621621621], 
             UndirectedEdge[9, 18] -> 
             RGBColor[
              0.5494944189189189, 0.6222451756756757, 0.9628692567567567], 
             UndirectedEdge[9, 200] -> 
             RGBColor[
              0.9565828513513513, 0.9633772702702703, 0.7415069729729729], 
             UndirectedEdge[55, 183] -> 
             RGBColor[
              0.964851108108108, 0.8930966756756755, 0.31795362162162144`], 
             UndirectedEdge[72, 104] -> 
             RGBColor[
              0.9895871351351351, 0.9899620270270271, 0.8222316486486485], 
             UndirectedEdge[112, 181] -> 
             RGBColor[
              0.9637503378378378, 0.9557336216216217, 0.6826050405405404], 
             UndirectedEdge[136, 193] -> 
             RGBColor[
              0.981009527027027, 0.9823117837837838, 0.7390461216216215], 
             UndirectedEdge[80, 198] -> 
             RGBColor[
              0.9949822702702703, 0.992193054054054, 0.7328202972972975], 
             UndirectedEdge[42, 131] -> 
             RGBColor[
              0.9722107027027027, 0.9165891351351352, 0.36088793243243233`], 
             UndirectedEdge[65, 156] -> 
             RGBColor[
              0.9933291891891892, 0.9881401351351351, 0.5153015945945943], 
             UndirectedEdge[26, 192] -> 
             RGBColor[
              0.9285357297297296, 0.9458194054054054, 0.9918739864864865], 
             UndirectedEdge[65, 155] -> 
             RGBColor[
              0.9192789864864865, 0.9339344594594594, 0.7624525675675675], 
             UndirectedEdge[59, 62] -> 
             RGBColor[
              0.9796646216216216, 0.9430661351351353, 0.37550132432432437`], 
             UndirectedEdge[82, 187] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[4, 86] -> 
             RGBColor[
              0.9828793918918919, 0.9526387567567568, 0.5368965000000001], 
             UndirectedEdge[73, 167] -> 
             RGBColor[
              0.9648314189189189, 0.9696183783783784, 0.7166182837837837], 
             UndirectedEdge[74, 159] -> 
             RGBColor[
              0.9906029729729731, 0.9798710540540541, 0.42587802702702693`], 
             UndirectedEdge[25, 60] -> 
             RGBColor[
              0.5619001756756756, 0.6319006081081081, 0.9558501081081081], 
             UndirectedEdge[159, 162] -> 
             RGBColor[
              0.5837398648648648, 0.6392209054054054, 0.671765472972973], 
             UndirectedEdge[10, 147] -> 
             RGBColor[
              0.9521269189189189, 0.9634136756756757, 0.9519402567567568], 
             UndirectedEdge[23, 163] -> 
             RGBColor[
              0.957576027027027, 0.8598728108108109, 0.3349141216216216], 
             UndirectedEdge[40, 54] -> 
             RGBColor[
              0.9877887567567567, 0.9892183513513514, 0.8520354324324324], 
             UndirectedEdge[123, 129] -> 
             RGBColor[
              0.960116364864865, 0.9112427297297299, 0.6091576216216216], 
             UndirectedEdge[25, 165] -> 
             RGBColor[
              0.9694392567567567, 0.9739965945945946, 0.7835381486486487], 
             UndirectedEdge[39, 178] -> 
             RGBColor[
              0.9895471216216216, 0.9880664324324324, 0.6863078243243242], 
             UndirectedEdge[76, 107] -> 
             RGBColor[
              0.5869167297297297, 0.6484538783783784, 0.8102393648648649], 
             UndirectedEdge[63, 138] -> 
             RGBColor[
              0.9884226081081081, 0.9872126486486487, 0.6766845540540539], 
             UndirectedEdge[71, 81] -> 
             RGBColor[
              0.9763199324324323, 0.9411575135135135, 0.5849945270270269], 
             UndirectedEdge[8, 83] -> 
             RGBColor[
              0.9604896621621621, 0.8842172702702703, 0.5741940000000001], 
             UndirectedEdge[10, 149] -> 
             RGBColor[
              0.9191357702702703, 0.8262660540540541, 0.6226426621621621], 
             UndirectedEdge[119, 172] -> 
             RGBColor[
              0.5485683513513514, 0.5094148783783783, 0.5932744054054053], 
             UndirectedEdge[106, 130] -> 
             RGBColor[
              0.987271554054054, 0.9807612432432433, 0.645934581081081], 
             UndirectedEdge[147, 176] -> 
             RGBColor[
              0.9886479324324324, 0.9876945945945946, 0.7012097162162161], 
             UndirectedEdge[27, 197] -> 
             RGBColor[
              0.556957972972973, 0.5426769324324324, 0.6000248918918919], 
             UndirectedEdge[72, 176] -> 
             RGBColor[
              0.9904463108108108, 0.9884382702702703, 0.6714059324324322], 
             UndirectedEdge[92, 118] -> 
             RGBColor[
              0.8919149459459459, 0.9166527837837839, 0.9895528378378378], 
             UndirectedEdge[123, 171] -> 
             RGBColor[
              0.9606008108108108, 0.9701367297297298, 0.9515767297297297], 
             UndirectedEdge[66, 113] -> 
             RGBColor[
              0.9947190405405406, 0.9913714594594594, 0.6853738513513514], 
             UndirectedEdge[67, 179] -> 
             RGBColor[
              0.9419622837837838, 0.9385969999999999, 0.6887292972972971], 
             UndirectedEdge[130, 197] -> 
             RGBColor[
              0.9604896621621621, 0.8842172702702703, 0.5741940000000001], 
             UndirectedEdge[15, 194] -> 
             RGBColor[
              0.9926953378378378, 0.9901458378378378, 0.690652472972973], 
             UndirectedEdge[47, 135] -> 
             RGBColor[
              0.8251102297297297, 0.5248115405405405, 0.5769433513513513], 
             UndirectedEdge[8, 170] -> 
             RGBColor[
              0.876153972972973, 0.45704343243243245`, 0.21538339189189187`], 
             UndirectedEdge[17, 149] -> 
             RGBColor[
              0.9565959864864866, 0.8528144054054053, 0.4929340540540541], 
             UndirectedEdge[13, 97] -> 
             RGBColor[
              0.9804469594594594, 0.9604016216216216, 0.6378173918918918], 
             UndirectedEdge[11, 86] -> 
             RGBColor[
              0.9796646216216216, 0.9430661351351353, 0.37550132432432437`], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.9912789459459459, 0.981316891891892, 0.4994535135135135], 
             UndirectedEdge[37, 160] -> 
             RGBColor[
              0.9777915405405405, 0.9811648918918918, 0.8421985135135136], 
             UndirectedEdge[46, 50] -> 
             RGBColor[
              0.9913476081081081, 0.9903660540540541, 0.769506581081081], 
             UndirectedEdge[49, 53] -> 
             RGBColor[
              0.9650567432432433, 0.9701003243243244, 0.7411434459459458], 
             UndirectedEdge[52, 120] -> 
             RGBColor[
              0.9915042702702703, 0.9817988378378378, 0.5239786756756757], 
             UndirectedEdge[81, 147] -> 
             RGBColor[
              0.9745215540540539, 0.9404138378378377, 0.6147983108108107], 
             UndirectedEdge[49, 123] -> 
             RGBColor[
              0.9527370810810811, 0.964271972972973, 0.9648879729729729], 
             UndirectedEdge[127, 140] -> 
             RGBColor[
              0.9920214729729729, 0.9902559459459459, 0.730079527027027], 
             UndirectedEdge[31, 132] -> 
             RGBColor[
              0.9682412162162162, 0.900440054054054, 0.3820378513513512], 
             UndirectedEdge[146, 186] -> 
             RGBColor[
              0.9563327567567568, 0.8519928108108108, 0.44548760810810806`], 
             UndirectedEdge[98, 124] -> 
             RGBColor[
              0.5579683108108109, 0.6289682297297297, 0.9625057297297297], 
             UndirectedEdge[4, 53] -> 
             RGBColor[
              0.9940430675675676, 0.9899256216216217, 0.6117983648648648], 
             UndirectedEdge[82, 137] -> 
             RGBColor[
              0.5842570675675676, 0.6476780135135136, 0.8778663243243243], 
             UndirectedEdge[42, 107] -> 
             RGBColor[
              0.5857901081081082, 0.6460441486486487, 0.687613554054054], 
             UndirectedEdge[99, 102] -> 
             RGBColor[
              0.5869546351351351, 0.6487935270270271, 0.8331606486486487], 
             UndirectedEdge[57, 88] -> 
             RGBColor[
              0.9509303648648648, 0.9228195675675674, 0.6547320405405405], 
             UndirectedEdge[40, 49] -> 
             RGBColor[0.9615, 0.9705085675675675, 0.9366748378378379], 
             UndirectedEdge[21, 90] -> 
             RGBColor[
              0.9757894594594595, 0.9299015945945945, 0.3683303243243242], 
             UndirectedEdge[143, 158] -> 
             RGBColor[
              0.9333006216216215, 0.7699244054054053, 0.2788419324324324], 
             UndirectedEdge[24, 111] -> 
             RGBColor[0.9598515945945947, 0.867178, 0.37528736486486475`], 
             UndirectedEdge[139, 155] -> 
             RGBColor[
              0.8450034594594595, 0.8792468378378379, 0.9850783783783784], 
             UndirectedEdge[94, 174] -> 
             RGBColor[
              0.9143095810810811, 0.8936529459459459, 0.6524108918918918], 
             UndirectedEdge[4, 118] -> 
             RGBColor[
              0.9293751621621622, 0.9432011351351351, 0.8598442297297297], 
             UndirectedEdge[121, 159] -> 
             RGBColor[
              0.9863723648648648, 0.9803894054054054, 0.660836472972973], 
             UndirectedEdge[5, 76] -> 
             RGBColor[
              0.9733373243243244, 0.9189988648648649, 0.48351374324324325`], 
             UndirectedEdge[27, 194] -> 
             RGBColor[
              0.5851562567567568, 0.6480498513513513, 0.8629644324324324], 
             UndirectedEdge[77, 160] -> 
             RGBColor[
              0.9799166891891892, 0.9426448648648648, 0.5253869594594595], 
             UndirectedEdge[2, 80] -> 
             RGBColor[
              0.9777915405405405, 0.9811648918918918, 0.8421985135135136], 
             UndirectedEdge[74, 85] -> 
             RGBColor[
              0.9911201756756757, 0.9883281621621622, 0.6319788783783783], 
             UndirectedEdge[35, 110] -> 
             RGBColor[
              0.977753635135135, 0.9808252432432433, 0.8192772297297297], 
             UndirectedEdge[143, 154] -> 
             RGBColor[
              0.9456686351351351, 0.8183570810810812, 0.530980945945946], 
             UndirectedEdge[53, 129] -> 
             RGBColor[
              0.9724360270270271, 0.9170710810810812, 0.3854130945945945], 
             UndirectedEdge[80, 187] -> 
             RGBColor[
              0.5869546351351351, 0.648793527027027, 0.8331606486486487], 
             UndirectedEdge[30, 87] -> 
             RGBColor[
              0.9082525675675676, 0.9292405945945946, 0.9758780675675676], 
             UndirectedEdge[29, 197] -> 
             RGBColor[
              0.9617708378378378, 0.8765038378378378, 0.3382893648648648], 
             UndirectedEdge[74, 121] -> 
             RGBColor[
              0.9884226081081081, 0.9872126486486487, 0.6766845540540539], 
             UndirectedEdge[127, 199] -> 
             RGBColor[
              0.5842570675675676, 0.6476780135135135, 0.8778663243243243], 
             UndirectedEdge[52, 80] -> 
             RGBColor[0.9917675, 0.9826204324324324, 0.5714251216216217], 
             UndirectedEdge[125, 187] -> 
             RGBColor[
              0.5862407567567568, 0.6470080405405405, 0.7366638783783783], 
             UndirectedEdge[57, 152] -> 
             RGBColor[
              0.9737392162162162, 0.9230783513513512, 0.35248224324324307`], 
             UndirectedEdge[128, 193] -> 
             RGBColor[
              0.979925027027027, 0.9833535945945946, 0.8653466756756756], 
             UndirectedEdge[151, 172] -> 
             RGBColor[
              0.5748517567567568, 0.6092392297297298, 0.6372368513513513], 
             UndirectedEdge[5, 27] -> 
             RGBColor[
              0.5653475945945946, 0.5759389864864866, 0.6067753783783785], 
             UndirectedEdge[65, 118] -> 
             RGBColor[
              0.9286612837837838, 0.9414156486486487, 0.7633474594594594], 
             UndirectedEdge[78, 80] -> 
             RGBColor[
              0.9575220540540541, 0.9656447027027026, 0.8625289054054055], 
             UndirectedEdge[40, 199] -> 
             RGBColor[
              0.5824586891891892, 0.6469343378378378, 0.9076701081081082], 
             UndirectedEdge[5, 42] -> 
             RGBColor[
              0.9722107027027027, 0.9165891351351352, 0.36088793243243233`], 
             UndirectedEdge[123, 196] -> 
             RGBColor[
              0.979925027027027, 0.9833535945945946, 0.8653466756756756], 
             UndirectedEdge[80, 124] -> 
             RGBColor[
              0.965995945945946, 0.9723677567567568, 0.8621653783783785], 
             UndirectedEdge[22, 48] -> 
             RGBColor[0.9223379054054054, 0.8686779459459459, 0.6318735], 
             UndirectedEdge[69, 86] -> 
             RGBColor[
              0.948687918918919, 0.8298911351351352, 0.3003855000000001], 
             UndirectedEdge[81, 143] -> 
             RGBColor[
              0.9333006216216215, 0.7699244054054053, 0.2788419324324324], 
             UndirectedEdge[80, 116] -> 
             RGBColor[
              0.9938177432432433, 0.9894436756756757, 0.5872732027027027], 
             UndirectedEdge[90, 169] -> 
             RGBColor[
              0.951899527027027, 0.9157580540540541, 0.6365668783783784], 
             UndirectedEdge[121, 173] -> 
             RGBColor[
              0.9877887567567567, 0.9892183513513514, 0.8520354324324324], 
             UndirectedEdge[8, 179] -> 
             RGBColor[
              0.9588081351351352, 0.866509945945946, 0.32677982432432423`], 
             UndirectedEdge[29, 167] -> 
             RGBColor[
              0.9906029729729731, 0.9798710540540541, 0.42587802702702693`], 
             UndirectedEdge[76, 87] -> 
             RGBColor[
              0.9738217702702703, 0.9778928648648648, 0.8259328513513513], 
             UndirectedEdge[111, 163] -> 
             RGBColor[
              0.9265993243243243, 0.7466978108108109, 0.2597982972972973], 
             UndirectedEdge[130, 149] -> 
             RGBColor[
              0.9521000405405405, 0.8509552162162162, 0.5674435135135135], 
             UndirectedEdge[7, 122] -> 
             RGBColor[
              0.9548244864864864, 0.9645291891891892, 0.9072345810810811], 
             UndirectedEdge[89, 142] -> 
             RGBColor[
              0.9641975675675676, 0.9716240810810811, 0.8919691621621622], 
             UndirectedEdge[44, 172] -> 
             RGBColor[
              0.5862407567567568, 0.6470080405405405, 0.7366638783783783], 
             UndirectedEdge[7, 179] -> 
             RGBColor[
              0.951344581081081, 0.9460781891891892, 0.6896241891891891], 
             UndirectedEdge[73, 188] -> 
             RGBColor[
              0.9632983783783784, 0.9712522432432433, 0.9068710540540541], 
             UndirectedEdge[16, 120] -> 
             RGBColor[
              0.9947190405405406, 0.9913714594594594, 0.6853738513513514], 
             UndirectedEdge[98, 116] -> 
             RGBColor[
              0.585790108108108, 0.6460441486486486, 0.687613554054054], 
             UndirectedEdge[5, 81] -> 
             RGBColor[
              0.9583096486486486, 0.8697903243243243, 0.2990016891891891], 
             UndirectedEdge[76, 106] -> 
             RGBColor[
              0.9917295945945945, 0.9822807837837838, 0.5485038378378377], 
             UndirectedEdge[135, 144] -> 
             RGBColor[
              0.8914536486486486, 0.5292237567567567, 0.23276632432432434`], 
             UndirectedEdge[194, 197] -> 
             RGBColor[
              0.9631872297297297, 0.8853327837837839, 0.5294883243243242], 
             UndirectedEdge[27, 29] -> 
             RGBColor[
              0.5837398648648648, 0.6392209054054054, 0.671765472972973], 
             UndirectedEdge[44, 58] -> 
             RGBColor[
              0.9821655135135136, 0.9508532702702703, 0.4403997297297296], 
             UndirectedEdge[53, 92] -> 
             RGBColor[
              0.9565828513513513, 0.9633772702702703, 0.7415069729729729], 
             UndirectedEdge[83, 122] -> 
             RGBColor[
              0.9877887567567567, 0.9892183513513514, 0.8520354324324324], 
             UndirectedEdge[9, 178] -> 
             RGBColor[
              0.9565828513513513, 0.9633772702702703, 0.7415069729729729], 
             UndirectedEdge[12, 99] -> 
             RGBColor[
              0.571889054054054, 0.5992453378378377, 0.6257273108108108], 
             UndirectedEdge[7, 126] -> 
             RGBColor[
              0.9565828513513513, 0.9633772702702703, 0.7415069729729729], 
             UndirectedEdge[139, 146] -> 
             RGBColor[
              0.8816065810810811, 0.7963412972972972, 0.6190630945945946], 
             UndirectedEdge[100, 198] -> 
             RGBColor[
              0.9938177432432433, 0.9894436756756757, 0.5872732027027027], 
             UndirectedEdge[56, 109] -> 
             RGBColor[
              0.7530980675675676, 0.6816888378378378, 0.6038326891891892], 
             UndirectedEdge[9, 159] -> 
             RGBColor[
              0.9543072837837838, 0.9560720810810811, 0.7011337297297298], 
             UndirectedEdge[2, 98] -> 
             RGBColor[
              0.5697639054054053, 0.6377653648648649, 0.9425388648648649], 
             UndirectedEdge[95, 164] -> 
             RGBColor[
              0.9139482837837838, 0.8354158918918919, 0.6251230135135135], 
             UndirectedEdge[108, 163] -> 
             RGBColor[
              0.958992418918919, 0.8687017567567568, 0.526113081081081], 
             UndirectedEdge[85, 121] -> 
             RGBColor[
              0.9868895675675675, 0.9888465135135136, 0.8669373243243244], 
             UndirectedEdge[55, 177] -> 
             RGBColor[
              0.9499200270270269, 0.8365282702702702, 0.2922512027027026], 
             UndirectedEdge[118, 141] -> 
             RGBColor[
              0.9231976891891892, 0.9236346216216216, 0.6869395135135135], 
             UndirectedEdge[58, 77] -> 
             RGBColor[
              0.9678138108108107, 0.9030905675675676, 0.3294631621621621], 
             UndirectedEdge[142, 154] -> 
             RGBColor[
              0.9632983783783784, 0.9712522432432433, 0.9068710540540541], 
             UndirectedEdge[103, 178] -> 
             RGBColor[
              0.5860154324324325, 0.6465260945945945, 0.712138716216216], 
             UndirectedEdge[48, 154] -> 
             RGBColor[0.9454421891891891, 0.957048, 0.9063396891891892], 
             UndirectedEdge[72, 181] -> 
             RGBColor[
              0.9852080405405406, 0.9711391891891892, 0.6195231486486485], 
             UndirectedEdge[45, 132] -> 
             RGBColor[
              0.9691804189189189, 0.9027074864864865, 0.5030597837837838], 
             UndirectedEdge[103, 200] -> 
             RGBColor[
              0.5860154324324325, 0.6465260945945945, 0.712138716216216], 
             UndirectedEdge[21, 61] -> 
             RGBColor[
              0.9726951486486486, 0.9754831351351352, 0.7033070405405404], 
             UndirectedEdge[51, 73] -> 
             RGBColor[
              0.9606008108108108, 0.9701367297297298, 0.9515767297297297], 
             UndirectedEdge[18, 41] -> 
             RGBColor[
              0.5748517567567568, 0.6092392297297298, 0.6372368513513514], 
             UndirectedEdge[27, 42] -> 
             RGBColor[
              0.585790108108108, 0.6460441486486486, 0.687613554054054], 
             UndirectedEdge[90, 165] -> 
             RGBColor[
              0.9764654324324324, 0.9313474324324325, 0.4419058108108109], 
             UndirectedEdge[50, 135] -> 
             RGBColor[
              0.9058851756756756, 0.5872784864864864, 0.5113167702702702], 
             UndirectedEdge[93, 121] -> 
             RGBColor[
              0.9723964054054053, 0.9789338648648649, 0.9316098648648649], 
             UndirectedEdge[23, 175] -> 
             RGBColor[
              0.9908683108108107, 0.9822485945945947, 0.5863270135135135], 
             UndirectedEdge[57, 164] -> 
             RGBColor[
              0.9330741756756756, 0.9086153243243242, 0.6542006756756755], 
             UndirectedEdge[54, 172] -> 
             RGBColor[
              0.5842570675675676, 0.6476780135135135, 0.8778663243243243], 
             UndirectedEdge[99, 198] -> 
             RGBColor[
              0.5869546351351351, 0.6487935270270271, 0.8331606486486487], 
             UndirectedEdge[45, 112] -> 
             RGBColor[
              0.9699278108108108, 0.9753001351351351, 0.8555097567567569], 
             UndirectedEdge[88, 173] -> 
             RGBColor[
              0.9641975675675676, 0.9716240810810811, 0.8919691621621622], 
             UndirectedEdge[14, 22] -> 
             RGBColor[
              0.9600402432432432, 0.8731470810810811, 0.318645527027027], 
             UndirectedEdge[7, 67] -> 
             RGBColor[
              0.9106795405405406, 0.9316151621621622, 0.9913426216216217], 
             UndirectedEdge[105, 135] -> 
             RGBColor[
              0.9083174054054055, 0.5860164594594595, 0.306162108108108], 
             UndirectedEdge[104, 176] -> 
             RGBColor[
              0.9922446891891892, 0.989181945945946, 0.6416021486486485], 
             UndirectedEdge[57, 91] -> 
             RGBColor[
              0.942456472972973, 0.9160965135135135, 0.6550955675675675], 
             UndirectedEdge[34, 185] -> 
             RGBColor[
              0.9826161621621622, 0.9518171621621623, 0.48945005405405406`], 
             UndirectedEdge[65, 172] -> 
             RGBColor[
              0.5862407567567568, 0.6470080405405405, 0.7366638783783783], 
             UndirectedEdge[66, 120] -> 
             RGBColor[
              0.9947190405405406, 0.9913714594594594, 0.6853738513513514], 
             UndirectedEdge[91, 117] -> 
             RGBColor[
              0.951344581081081, 0.9460781891891892, 0.6896241891891891], 
             UndirectedEdge[27, 141] -> 
             RGBColor[
              0.5807771621621622, 0.6292270135135134, 0.6602559324324324], 
             UndirectedEdge[13, 145] -> 
             RGBColor[
              0.9895492297297297, 0.9896223783783784, 0.7993103648648648], 
             UndirectedEdge[1, 174] -> 
             RGBColor[
              0.571889054054054, 0.5992453378378377, 0.6257273108108108], 
             UndirectedEdge[182, 196] -> 
             RGBColor[
              0.5851562567567568, 0.6480498513513513, 0.8629644324324324], 
             UndirectedEdge[96, 137] -> 
             RGBColor[
              0.9890699324324324, 0.9815049189189189, 0.6161307972972973], 
             UndirectedEdge[89, 157] -> 
             RGBColor[
              0.9369590810810811, 0.9499386486486486, 0.8905429054054054], 
             UndirectedEdge[119, 191] -> 
             RGBColor[
              0.9556567837837838, 0.8505469729729729, 0.37191212162162146`], 
             UndirectedEdge[51, 157] -> 
             RGBColor[
              0.9333623243243243, 0.9484512972972973, 0.950150472972973], 
             UndirectedEdge[127, 195] -> 
             RGBColor[
              0.9877887567567567, 0.9892183513513514, 0.8520354324324324], 
             UndirectedEdge[27, 62] -> 
             RGBColor[
              0.5837398648648648, 0.6392209054054054, 0.671765472972973], 
             UndirectedEdge[4, 40] -> 
             RGBColor[
              0.9904863243243243, 0.9903338648648649, 0.8073297567567569], 
             UndirectedEdge[161, 164] -> 
             RGBColor[
              0.9472405675675675, 0.9577916756756757, 0.8765359054054054], 
             UndirectedEdge[20, 101] -> 
             RGBColor[
              0.5653475945945946, 0.5759389864864866, 0.6067753783783785], 
             UndirectedEdge[13, 36] -> 
             RGBColor[
              0.9512008513513514, 0.8505833783783783, 0.5823454054054054], 
             UndirectedEdge[182, 195] -> 
             RGBColor[
              0.5824586891891892, 0.6469343378378378, 0.9076701081081082], 
             UndirectedEdge[184, 186] -> 
             RGBColor[
              0.9938198513513513, 0.9909996216216217, 0.7002757432432433], 
             UndirectedEdge[96, 166] -> 
             RGBColor[
              0.9885527297297297, 0.9730478108108108, 0.4100299459459459], 
             UndirectedEdge[38, 43] -> 
             RGBColor[
              0.9627811756756757, 0.9627951351351351, 0.7007702027027027], 
             UndirectedEdge[30, 176] -> 
             RGBColor[
              0.9284359594594596, 0.9409337027027027, 0.7388222972972971], 
             UndirectedEdge[171, 174] -> 
             RGBColor[
              0.9587940945945945, 0.9286843243243242, 0.6414207972972972], 
             UndirectedEdge[100, 125] -> 
             RGBColor[
              0.9931038648648649, 0.9876581891891891, 0.4907764324324322], 
             UndirectedEdge[17, 188] -> 
             RGBColor[
              0.9922847027027026, 0.9910775405405405, 0.7775259729729731], 
             UndirectedEdge[87, 107] -> 
             RGBColor[
              0.5658320405405405, 0.6348329864864865, 0.9491944864864865], 
             UndirectedEdge[62, 184] -> 
             RGBColor[
              0.9908683108108107, 0.9822485945945947, 0.5863270135135135], 
             UndirectedEdge[12, 33] -> 
             RGBColor[
              0.8955449864864864, 0.8786905675675675, 0.650621108108108], 
             UndirectedEdge[32, 57] -> 
             RGBColor[
              0.8396101216216216, 0.8349432702702702, 0.6450594594594594], 
             UndirectedEdge[17, 87] -> 
             RGBColor[
              0.9738596756756757, 0.9782325135135135, 0.8488541351351352], 
             UndirectedEdge[42, 149] -> 
             RGBColor[
              0.9554314594594595, 0.8500650270270269, 0.34738695945945935`], 
             UndirectedEdge[87, 130] -> 
             RGBColor[
              0.9693637297297297, 0.9763733243243243, 0.9233635945945946], 
             UndirectedEdge[58, 170] -> 
             RGBColor[
              0.8940477567567569, 0.5236057297297299, 0.2525953513513514], 
             UndirectedEdge[118, 196] -> 
             RGBColor[
              0.9275767837837838, 0.9424574594594595, 0.8896480135135134], 
             UndirectedEdge[41, 159] -> 
             RGBColor[
              0.9796646216216216, 0.9430661351351353, 0.37550132432432437`], 
             UndirectedEdge[107, 157] -> 
             RGBColor[
              0.5307298243243244, 0.6072827972972972, 0.961079472972973], 
             UndirectedEdge[161, 173] -> 
             RGBColor[
              0.9922847027027026, 0.9910775405405405, 0.777525972972973], 
             UndirectedEdge[15, 184] -> 
             RGBColor[
              0.993594527027027, 0.9905176756756757, 0.6757505810810811], 
             UndirectedEdge[106, 142] -> 
             RGBColor[
              0.9627811756756757, 0.9627951351351351, 0.7007702027027027], 
             UndirectedEdge[24, 39] -> 
             RGBColor[
              0.9895471216216216, 0.9880664324324324, 0.6863078243243242], 
             UndirectedEdge[45, 134] -> 
             RGBColor[
              0.9922847027027026, 0.9910775405405405, 0.7775259729729731], 
             UndirectedEdge[5, 73] -> 
             RGBColor[
              0.9443889054054054, 0.8995132162162163, 0.635780108108108], 
             UndirectedEdge[147, 154] -> 
             RGBColor[
              0.9868895675675675, 0.9888465135135136, 0.8669373243243244], 
             UndirectedEdge[76, 143] -> 
             RGBColor[
              0.9483282972972973, 0.819132945945946, 0.4633539864864865], 
             UndirectedEdge[5, 197] -> 
             RGBColor[
              0.9433785675675677, 0.8132219189189189, 0.27329927027027023`], 
             UndirectedEdge[152, 159] -> 
             RGBColor[
              0.985590027027027, 0.9630539189189189, 0.3985204054054053], 
             UndirectedEdge[108, 115] -> 
             RGBColor[
              0.9926953378378378, 0.9901458378378378, 0.690652472972973], 
             UndirectedEdge[65, 123] -> 
             RGBColor[
              0.981009527027027, 0.9823117837837838, 0.7390461216216215], 
             UndirectedEdge[8, 67] -> 
             RGBColor[
              0.9181430945945945, 0.8520469189189189, 0.6284982567567567], 
             UndirectedEdge[9, 41] -> 
             RGBColor[
              0.9454191756756757, 0.9260904054054055, 0.6666051081081081], 
             UndirectedEdge[111, 165] -> 
             RGBColor[
              0.9603022432432433, 0.868141891891892, 0.42433768918918924`], 
             UndirectedEdge[146, 195] -> 
             RGBColor[
              0.9521000405405405, 0.8509552162162162, 0.5674435135135136], 
             UndirectedEdge[104, 188] -> 
             RGBColor[
              0.9904863243243243, 0.990333864864865, 0.8073297567567568], 
             UndirectedEdge[37, 105] -> 
             RGBColor[
              0.9766270135135136, 0.9784155135135135, 0.6966514189189188], 
             UndirectedEdge[3, 75] -> 
             RGBColor[
              0.9113468783783785, 0.8836590540540541, 0.6409013513513513], 
             UndirectedEdge[40, 132] -> 
             RGBColor[
              0.9646844729729729, 0.9008482972972973, 0.5775692432432433], 
             UndirectedEdge[154, 157] -> 
             RGBColor[
              0.9360598918918919, 0.9495668108108108, 0.9054447972972972], 
             UndirectedEdge[116, 148] -> 
             RGBColor[
              0.9375929324324324, 0.9479329459459459, 0.7151920270270269], 
             UndirectedEdge[132, 185] -> 
             RGBColor[
              0.9570775405405405, 0.8631531891891893, 0.30713598648648655`], 
             UndirectedEdge[92, 123] -> 
             RGBColor[
              0.9442631891891892, 0.957548918918919, 0.9652514999999999], 
             UndirectedEdge[53, 139] -> 
             RGBColor[
              0.9190536621621622, 0.9334525135135135, 0.7379274054054052], 
             UndirectedEdge[40, 196] -> 
             RGBColor[
              0.9886879459459459, 0.9895901891891892, 0.8371335405405406], 
             UndirectedEdge[27, 73] -> 
             RGBColor[
              0.5579683108108109, 0.6289682297297297, 0.9625057297297297], 
             UndirectedEdge[57, 103] -> 
             RGBColor[
              0.571889054054054, 0.5992453378378377, 0.6257273108108108], 
             UndirectedEdge[44, 77] -> 
             RGBColor[
              0.9792028108108108, 0.9408593783783783, 0.428890189189189], 
             UndirectedEdge[88, 91] -> 
             RGBColor[
              0.9285357297297296, 0.9458194054054054, 0.9918739864864865], 
             UndirectedEdge[69, 146] -> 
             RGBColor[
              0.9224045135135135, 0.7300667837837838, 0.2564230540540541], 
             UndirectedEdge[65, 199] -> 
             RGBColor[
              0.5862407567567568, 0.6470080405405405, 0.7366638783783783], 
             UndirectedEdge[27, 75] -> 
             RGBColor[
              0.5213475270270271, 0.5998016081081081, 0.9601845810810811], 
             UndirectedEdge[4, 65] -> 
             RGBColor[
              0.994268391891892, 0.9904075675675675, 0.636323527027027], 
             UndirectedEdge[58, 102] -> 
             RGBColor[
              0.9828793918918919, 0.9526387567567568, 0.5368965000000001], 
             UndirectedEdge[107, 168] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[9, 85] -> 
             RGBColor[
              0.9548244864864864, 0.9645291891891892, 0.9072345810810811], 
             UndirectedEdge[22, 144] -> 
             RGBColor[
              0.9511521351351351, 0.8431654054054054, 0.2841169054054054], 
             UndirectedEdge[110, 138] -> 
             RGBColor[
              0.9723964054054053, 0.9789338648648649, 0.9316098648648649], 
             UndirectedEdge[34, 132] -> 
             RGBColor[
              0.9689171891891892, 0.9018858918918919, 0.4556133378378378], 
             UndirectedEdge[48, 158] -> 
             RGBColor[
              0.9330741756756756, 0.9086153243243242, 0.6542006756756755], 
             UndirectedEdge[19, 95] -> 
             RGBColor[
              0.9391837567567568, 0.796590891891892, 0.269924027027027], 
             UndirectedEdge[122, 137] -> 
             RGBColor[
              0.9895871351351351, 0.9899620270270271, 0.8222316486486486], 
             UndirectedEdge[8, 198] -> 
             RGBColor[
              0.9649856081081081, 0.8860764594594595, 0.4996845405405406], 
             UndirectedEdge[92, 174] -> 
             RGBColor[
              0.942456472972973, 0.9160965135135135, 0.6550955675675675], 
             UndirectedEdge[39, 133] -> 
             RGBColor[
              0.9342615135135135, 0.948823135135135, 0.9352485810810811], 
             UndirectedEdge[120, 198] -> 
             RGBColor[
              0.9947190405405406, 0.9913714594594594, 0.6853738513513514], 
             UndirectedEdge[4, 34] -> 
             RGBColor[
              0.9947190405405406, 0.9913714594594594, 0.6853738513513514], 
             UndirectedEdge[31, 34] -> 
             RGBColor[
              0.9937798378378379, 0.989104027027027, 0.5643519189189188], 
             UndirectedEdge[41, 152] -> 
             RGBColor[
              0.976701918918919, 0.9330722432432432, 0.3639917837837837], 
             UndirectedEdge[95, 121] -> 
             RGBColor[
              0.9553956621621622, 0.8672144054054054, 0.5857206486486486], 
             UndirectedEdge[3, 129] -> 
             RGBColor[
              0.955346945945946, 0.8597964324324325, 0.2874921486486487], 
             UndirectedEdge[49, 199] -> 
             RGBColor[
              0.5579683108108108, 0.6289682297297298, 0.9625057297297297], 
             UndirectedEdge[171, 182] -> 
             RGBColor[
              0.5658320405405405, 0.6348329864864865, 0.9491944864864865], 
             UndirectedEdge[56, 150] -> 
             RGBColor[
              0.7394543513513513, 0.7961877837837837, 0.9750129999999999], 
             UndirectedEdge[179, 183] -> 
             RGBColor[
              0.9737392162162162, 0.9230783513513512, 0.35248224324324307`], 
             UndirectedEdge[31, 156] -> 
             RGBColor[
              0.9931038648648649, 0.9876581891891892, 0.4907764324324322], 
             UndirectedEdge[132, 153] -> 
             RGBColor[
              0.9225643513513513, 0.729987027027027, 0.2565147567567567], 
             UndirectedEdge[78, 136] -> 
             RGBColor[
              0.9568081756756757, 0.9638592162162163, 0.766032135135135], 
             UndirectedEdge[27, 167] -> 
             RGBColor[
              0.585790108108108, 0.6460441486486486, 0.687613554054054], 
             UndirectedEdge[35, 174] -> 
             RGBColor[
              0.9798787837837837, 0.9423052162162162, 0.5024656756756756], 
             UndirectedEdge[61, 190] -> 
             RGBColor[
              0.8988702702702702, 0.9217594054054055, 0.9749831756756757], 
             UndirectedEdge[18, 103] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[146, 155] -> 
             RGBColor[
              0.8816065810810811, 0.7963412972972972, 0.6190630945945945], 
             UndirectedEdge[77, 166] -> 
             RGBColor[
              0.9767019189189189, 0.9330722432432432, 0.36399178378378366`], 
             UndirectedEdge[85, 159] -> 
             RGBColor[
              0.9890699324324324, 0.9815049189189189, 0.6161307972972973], 
             UndirectedEdge[39, 88] -> 
             RGBColor[0.9615, 0.9705085675675675, 0.9366748378378379], 
             UndirectedEdge[66, 80] -> 
             RGBColor[
              0.9949822702702703, 0.992193054054054, 0.7328202972972975], 
             UndirectedEdge[62, 141] -> 
             RGBColor[
              0.985590027027027, 0.9630539189189189, 0.3985204054054053], 
             UndirectedEdge[91, 103] -> 
             RGBColor[
              0.5494944189189189, 0.6222451756756757, 0.9628692567567567], 
             UndirectedEdge[149, 189] -> 
             RGBColor[
              0.9307941351351352, 0.7633288378378378, 0.26317354054054054`], 
             UndirectedEdge[4, 69] -> 
             RGBColor[
              0.9607907972972973, 0.8694454324324324, 0.4963092972972974], 
             UndirectedEdge[23, 169] -> 
             RGBColor[
              0.9667130405405405, 0.9657275135135135, 0.694114581081081], 
             UndirectedEdge[32, 152] -> 
             RGBColor[
              0.8484982297297297, 0.8649249459459459, 0.679588081081081], 
             UndirectedEdge[100, 124] -> 
             RGBColor[
              0.9648314189189189, 0.9696183783783784, 0.7166182837837838], 
             UndirectedEdge[129, 139] -> 
             RGBColor[
              0.8983858243243243, 0.8628654054054055, 0.6325640675675677], 
             UndirectedEdge[29, 73] -> 
             RGBColor[
              0.9627811756756757, 0.9627951351351351, 0.7007702027027027], 
             UndirectedEdge[32, 178] -> 
             RGBColor[0.8537365, 0.8822240270270271, 0.7314708648648647], 
             UndirectedEdge[8, 61] -> 
             RGBColor[
              0.9438630135135135, 0.8721159189189189, 0.6157183783783784], 
             UndirectedEdge[10, 27] -> 
             RGBColor[
              0.5494944189189189, 0.6222451756756757, 0.9628692567567567], 
             UndirectedEdge[72, 160] -> 
             RGBColor[
              0.9913855135135134, 0.9907057027027026, 0.7924278648648648], 
             UndirectedEdge[72, 144] -> 
             RGBColor[
              0.9733572297297297, 0.9311636216216217, 0.5734849864864864], 
             UndirectedEdge[134, 135] -> 
             RGBColor[
              0.9067843648648648, 0.5876503243243243, 0.4964148783783784], 
             UndirectedEdge[95, 150] -> 
             RGBColor[
              0.9045659864864865, 0.8279347027027026, 0.6242281216216217], 
             UndirectedEdge[68, 71] -> 
             RGBColor[
              0.9571940405405406, 0.8679580810810812, 0.5559168648648648], 
             UndirectedEdge[118, 123] -> 
             RGBColor[
              0.9161162972972974, 0.9351053513513514, 0.9625668243243243], 
             UndirectedEdge[89, 168] -> 
             RGBColor[
              0.5851562567567568, 0.6480498513513514, 0.8629644324324324], 
             UndirectedEdge[44, 99] -> 
             RGBColor[
              0.5862407567567568, 0.6470080405405405, 0.7366638783783783], 
             UndirectedEdge[121, 180] -> 
             RGBColor[
              0.9774842567567568, 0.9504077297297298, 0.6263078513513514], 
             UndirectedEdge[10, 141] -> 
             RGBColor[
              0.951344581081081, 0.9460781891891892, 0.6896241891891891], 
             UndirectedEdge[6, 170] -> 
             RGBColor[
              0.9016546891891892, 0.5613008378378379, 0.5230286081081081], 
             UndirectedEdge[12, 77] -> 
             RGBColor[
              0.964851108108108, 0.8930966756756755, 0.31795362162162144`], 
             UndirectedEdge[112, 143] -> 
             RGBColor[
              0.9233117432432432, 0.8025796756756758, 0.6089647297297297], 
             UndirectedEdge[67, 125] -> 
             RGBColor[
              0.9474258783783784, 0.956378027027027, 0.7651372432432431], 
             UndirectedEdge[3, 10] -> 
             RGBColor[
              0.9394937702702703, 0.9061026216216217, 0.643586027027027], 
             UndirectedEdge[124, 125] -> 
             RGBColor[
              0.9652820675675675, 0.9705822702702702, 0.765668608108108], 
             UndirectedEdge[11, 174] -> 
             RGBColor[
              0.9767019189189189, 0.9330722432432432, 0.36399178378378366`], 
             UndirectedEdge[71, 87] -> 
             RGBColor[
              0.9702629189189189, 0.9767451621621621, 0.9084617027027027], 
             UndirectedEdge[7, 192] -> 
             RGBColor[
              0.9285357297297296, 0.9458194054054054, 0.9918739864864865], 
             UndirectedEdge[56, 148] -> 
             RGBColor[
              0.7394543513513513, 0.7961877837837837, 0.9750129999999999], 
             UndirectedEdge[30, 71] -> 
             RGBColor[
              0.9257784054054055, 0.9417137837837839, 0.9194517972972972], 
             UndirectedEdge[35, 86] -> 
             RGBColor[
              0.9828414864864865, 0.9522991081081082, 0.5139752162162162], 
             UndirectedEdge[68, 127] -> 
             RGBColor[
              0.9580932297297298, 0.868329918918919, 0.541014972972973], 
             UndirectedEdge[10, 30] -> 
             RGBColor[
              0.8919149459459459, 0.9166527837837839, 0.9895528378378378], 
             UndirectedEdge[89, 176] -> 
             RGBColor[
              0.9922446891891892, 0.989181945945946, 0.6416021486486485], 
             UndirectedEdge[71, 76] -> 
             RGBColor[
              0.9913476081081081, 0.9903660540540541, 0.769506581081081], 
             UndirectedEdge[49, 119] -> 
             RGBColor[
              0.9276096621621621, 0.832989108108108, 0.6222791351351351], 
             UndirectedEdge[87, 106] -> 
             RGBColor[
              0.9706449054054054, 0.9686598918918918, 0.6874589594594593], 
             UndirectedEdge[86, 196] -> 
             RGBColor[
              0.9810810135135135, 0.9518950810810811, 0.5667002837837838], 
             UndirectedEdge[53, 123] -> 
             RGBColor[
              0.9807842027027027, 0.9818298378378378, 0.7145209594594593], 
             UndirectedEdge[68, 102] -> 
             RGBColor[
              0.9607907972972973, 0.8694454324324324, 0.4963092972972974], 
             UndirectedEdge[107, 130] -> 
             RGBColor[
              0.5824586891891892, 0.6469343378378378, 0.9076701081081082], 
             UndirectedEdge[42, 157] -> 
             RGBColor[
              0.9375929324324324, 0.9479329459459459, 0.7151920270270269], 
             UndirectedEdge[96, 99] -> 
             RGBColor[
              0.5837398648648648, 0.6392209054054054, 0.671765472972973], 
             UndirectedEdge[62, 194] -> 
             RGBColor[
              0.9899691216216215, 0.9818767567567568, 0.6012289054054054], 
             UndirectedEdge[57, 117] -> 
             RGBColor[
              0.9737392162162162, 0.9230783513513512, 0.35248224324324307`], 
             UndirectedEdge[102, 128] -> 
             RGBColor[
              0.9931838918918918, 0.9914493783783784, 0.7626240810810812], 
             UndirectedEdge[46, 47] -> 
             RGBColor[
              0.9105726621621621, 0.927899108108108, 0.8351331621621622], 
             UndirectedEdge[28, 105] -> 
             RGBColor[
              0.9884226081081081, 0.9872126486486487, 0.6766845540540539], 
             UndirectedEdge[40, 182] -> 
             RGBColor[
              0.5824586891891892, 0.6469343378378378, 0.9076701081081082], 
             UndirectedEdge[79, 179] -> 
             RGBColor[
              0.9878655945945947, 0.9703591081081081, 0.43889364864864844`], 
             UndirectedEdge[36, 63] -> 
             RGBColor[
              0.9554314594594595, 0.8500650270270269, 0.34738695945945935`], 
             UndirectedEdge[118, 129] -> 
             RGBColor[
              0.9077681216216217, 0.8703465945945947, 0.6334589594594594], 
             UndirectedEdge[74, 161] -> 
             RGBColor[
              0.992918554054054, 0.9890718378378378, 0.6021750945945945], 
             UndirectedEdge[66, 187] -> 
             RGBColor[
              0.5869546351351351, 0.648793527027027, 0.8331606486486487], 
             UndirectedEdge[10, 29] -> 
             RGBColor[
              0.9543072837837838, 0.9560720810810811, 0.7011337297297298], 
             UndirectedEdge[30, 147] -> 
             RGBColor[
              0.9239800270270271, 0.9409701081081081, 0.949255581081081], 
             UndirectedEdge[109, 116] -> 
             RGBColor[0.9512366486486487, 0.833434, 0.3440117162162161], 
             UndirectedEdge[81, 154] -> 
             RGBColor[
              0.9772191216216215, 0.9415293513513513, 0.570092635135135], 
             UndirectedEdge[89, 188] -> 
             RGBColor[
              0.9904863243243243, 0.990333864864865, 0.8073297567567568], 
             UndirectedEdge[24, 163] -> 
             RGBColor[0.9598515945945947, 0.867178, 0.37528736486486475`], 
             UndirectedEdge[91, 159] -> 
             RGBColor[
              0.9543072837837838, 0.9560720810810811, 0.7011337297297298], 
             UndirectedEdge[121, 164] -> 
             RGBColor[
              0.9427446216216215, 0.9559324864864864, 0.9510453648648649], 
             UndirectedEdge[4, 54] -> 
             RGBColor[
              0.9922847027027026, 0.9910775405405405, 0.7775259729729731], 
             UndirectedEdge[51, 130] -> 
             RGBColor[
              0.9850911891891891, 0.9881028378378378, 0.8967411081081081], 
             UndirectedEdge[69, 186] -> 
             RGBColor[
              0.9605275675675675, 0.8686238378378379, 0.44886285135135134`], 
             UndirectedEdge[137, 179] -> 
             RGBColor[
              0.9861072297297298, 0.9715110270270271, 0.6046212567567566], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.9737392162162162, 0.9230783513513512, 0.35248224324324307`], 
             UndirectedEdge[22, 176] -> 
             RGBColor[
              0.9682412162162162, 0.900440054054054, 0.3820378513513512], 
             UndirectedEdge[128, 198] -> 
             RGBColor[
              0.9931838918918918, 0.9914493783783784, 0.7626240810810812], 
             UndirectedEdge[107, 131] -> 
             RGBColor[
              0.5653475945945947, 0.5759389864864866, 0.6067753783783784], 
             UndirectedEdge[26, 125] -> 
             RGBColor[
              0.9568081756756757, 0.9638592162162163, 0.766032135135135], 
             UndirectedEdge[47, 105] -> 
             RGBColor[
              0.9094460405405406, 0.9254893783783784, 0.7125073513513512], 
             UndirectedEdge[23, 60] -> 
             RGBColor[
              0.5837398648648648, 0.6392209054054054, 0.671765472972973], 
             UndirectedEdge[43, 111] -> 
             RGBColor[
              0.931804472972973, 0.8496201351351351, 0.6256543783783783], 
             UndirectedEdge[73, 142] -> 
             RGBColor[
              0.9370096216216216, 0.9525424594594595, 0.9915104594594595], 
             UndirectedEdge[43, 115] -> 
             RGBColor[
              0.9655073918918919, 0.9710642162162162, 0.7901937702702704], 
             UndirectedEdge[61, 122] -> 
             RGBColor[0.9711621081081081, 0.977117, 0.8935598108108107], 
             UndirectedEdge[64, 65] -> 
             RGBColor[
              0.9286612837837838, 0.9414156486486487, 0.7633474594594594], 
             UndirectedEdge[147, 157] -> 
             RGBColor[
              0.9333623243243243, 0.9484512972972973, 0.950150472972973], 
             UndirectedEdge[53, 69] -> 
             RGBColor[0.9598515945945947, 0.867178, 0.37528736486486475`], 
             UndirectedEdge[27, 188] -> 
             RGBColor[
              0.5842570675675676, 0.6476780135135136, 0.8778663243243243], 
             UndirectedEdge[88, 159] -> 
             RGBColor[
              0.9627811756756757, 0.9627951351351351, 0.7007702027027027], 
             UndirectedEdge[16, 61] -> 
             RGBColor[
              0.9738596756756757, 0.9782325135135135, 0.8488541351351352], 
             UndirectedEdge[138, 185] -> 
             RGBColor[
              0.9774842567567568, 0.9504077297297298, 0.6263078513513514], 
             UndirectedEdge[26, 128] -> 
             RGBColor[
              0.9557236756756756, 0.9649010270270271, 0.8923326891891892], 
             UndirectedEdge[68, 75] -> 
             RGBColor[
              0.8951836891891892, 0.8204535135135136, 0.6233332297297297], 
             UndirectedEdge[10, 107] -> 
             RGBColor[
              0.5494944189189189, 0.6222451756756757, 0.9628692567567567], 
             UndirectedEdge[69, 123] -> 
             RGBColor[
              0.9475319324324325, 0.8613496486486487, 0.5990318918918919], 
             UndirectedEdge[109, 113] -> 
             RGBColor[
              0.9521379459459459, 0.8353617837837838, 0.4421123648648648], 
             UndirectedEdge[49, 196] -> 
             RGBColor[
              0.9641975675675676, 0.9716240810810811, 0.8919691621621622], 
             UndirectedEdge[8, 26] -> 
             RGBColor[
              0.9275253918918919, 0.8595281081081081, 0.6293931486486486], 
             UndirectedEdge[30, 73] -> 
             RGBColor[
              0.9003888378378379, 0.9233758378378378, 0.9891893108108107], 
             UndirectedEdge[46, 144] -> 
             RGBColor[
              0.9769160810810811, 0.9323113243243244, 0.49095613513513514`], 
             UndirectedEdge[81, 176] -> 
             RGBColor[
              0.9789774864864864, 0.9403774324324323, 0.4043650270270268], 
             UndirectedEdge[104, 181] -> 
             RGBColor[
              0.9870064189189189, 0.9718828648648649, 0.5897193648648648], 
             UndirectedEdge[65, 171] -> 
             RGBColor[
              0.9731457972972972, 0.976447027027027, 0.7523573648648647], 
             UndirectedEdge[67, 82] -> 
             RGBColor[
              0.5401121216216216, 0.6147639864864864, 0.9619743648648649], 
             UndirectedEdge[13, 63] -> 
             RGBColor[
              0.9884226081081081, 0.9872126486486487, 0.6766845540540539], 
             UndirectedEdge[153, 182] -> 
             RGBColor[
              0.5403385675675676, 0.4760730675675676, 0.5866156216216216], 
             UndirectedEdge[87, 157] -> 
             RGBColor[
              0.9176348648648648, 0.9367217837837838, 0.9767729594594594], 
             UndirectedEdge[30, 157] -> 
             RGBColor[
              0.8731503513513513, 0.9016904054054053, 0.9877630540540541], 
             UndirectedEdge[64, 185] -> 
             RGBColor[
              0.9172722837837839, 0.903646837837838, 0.6639204324324325], 
             UndirectedEdge[9, 103] -> 
             RGBColor[
              0.5494944189189189, 0.6222451756756757, 0.9628692567567567], 
             UndirectedEdge[18, 117] -> 
             RGBColor[
              0.5807771621621622, 0.6292270135135134, 0.6602559324324324], 
             UndirectedEdge[52, 66] -> 
             RGBColor[0.9917675, 0.9826204324324324, 0.5714251216216217], 
             UndirectedEdge[128, 162] -> 
             RGBColor[
              0.5851562567567568, 0.6480498513513514, 0.8629644324324324], 
             UndirectedEdge[23, 177] -> 
             RGBColor[
              0.9617708378378378, 0.8765038378378378, 0.3382893648648648], 
             UndirectedEdge[11, 110] -> 
             RGBColor[
              0.9745767702702702, 0.9715922702702703, 0.6808033378378378], 
             UndirectedEdge[79, 177] -> 
             RGBColor[
              0.9640464054054054, 0.8838090270270271, 0.378662608108108], 
             UndirectedEdge[8, 166] -> 
             RGBColor[
              0.9617708378378378, 0.8765038378378378, 0.3382893648648648], 
             UndirectedEdge[162, 173] -> 
             RGBColor[
              0.5851562567567568, 0.6480498513513513, 0.8629644324324324], 
             UndirectedEdge[100, 137] -> 
             RGBColor[
              0.9911201756756757, 0.9883281621621622, 0.6319788783783783], 
             UndirectedEdge[88, 117] -> 
             RGBColor[
              0.959818472972973, 0.9528012432432432, 0.6892606621621621], 
             UndirectedEdge[149, 168] -> 
             RGBColor[
              0.5485683513513514, 0.5094148783783783, 0.5932744054054053], 
             UndirectedEdge[36, 110] -> 
             RGBColor[
              0.9394052567567568, 0.8417862432432432, 0.6023122702702703], 
             UndirectedEdge[76, 104] -> 
             RGBColor[
              0.9931459864864864, 0.9911097297297298, 0.7397027972972973], 
             UndirectedEdge[4, 196] -> 
             RGBColor[
              0.9931838918918918, 0.9914493783783784, 0.7626240810810812], 
             UndirectedEdge[61, 79] -> 
             RGBColor[
              0.972920472972973, 0.9759650810810812, 0.7278322027027025], 
             UndirectedEdge[76, 147] -> 
             RGBColor[
              0.9895492297297297, 0.9896223783783784, 0.7993103648648648], 
             UndirectedEdge[2, 120] -> 
             RGBColor[
              0.9775283108108108, 0.9803432972972973, 0.7947520675675676], 
             UndirectedEdge[87, 176] -> 
             RGBColor[
              0.972920472972973, 0.9759650810810812, 0.7278322027027025], 
             UndirectedEdge[142, 157] -> 
             RGBColor[
              0.9097711351351351, 0.930857027027027, 0.9900842027027027], 
             UndirectedEdge[65, 191] -> 
             RGBColor[
              0.9933291891891892, 0.9881401351351351, 0.5153015945945943], 
             UndirectedEdge[73, 147] -> 
             RGBColor[
              0.9606008108108108, 0.9701367297297298, 0.9515767297297297], 
             UndirectedEdge[26, 120] -> 
             RGBColor[
              0.9572588243243243, 0.9648231081081081, 0.8150824594594595], 
             UndirectedEdge[113, 116] -> 
             RGBColor[
              0.9935545135135135, 0.9886220810810811, 0.5398267567567566], 
             UndirectedEdge[35, 94] -> 
             RGBColor[
              0.9293372567567568, 0.9428614864864866, 0.836922945945946], 
             UndirectedEdge[31, 45] -> 
             RGBColor[
              0.9940430675675676, 0.9899256216216217, 0.6117983648648648], 
             UndirectedEdge[52, 82] -> 
             RGBColor[
              0.5837398648648648, 0.6392209054054054, 0.671765472972973], 
             UndirectedEdge[95, 162] -> 
             RGBColor[
              0.5527631621621621, 0.5260459054054054, 0.5966496486486487], 
             UndirectedEdge[17, 73] -> 
             RGBColor[
              0.965995945945946, 0.9723677567567568, 0.8621653783783785], 
             UndirectedEdge[103, 152] -> 
             RGBColor[
              0.5807771621621622, 0.6292270135135134, 0.6602559324324324], 
             UndirectedEdge[88, 103] -> 
             RGBColor[
              0.5579683108108108, 0.6289682297297298, 0.9625057297297297], 
             UndirectedEdge[26, 170] -> 
             RGBColor[
              0.8686904189189188, 0.5366116756756757, 0.5782277567567568], 
             UndirectedEdge[89, 106] -> 
             RGBColor[
              0.9899691216216215, 0.9818767567567568, 0.6012289054054054], 
             UndirectedEdge[19, 74] -> 
             RGBColor[
              0.9722107027027027, 0.9165891351351352, 0.36088793243243233`], 
             UndirectedEdge[117, 152] -> 
             RGBColor[
              0.9826273243243243, 0.953060027027027, 0.3870108648648647], 
             UndirectedEdge[157, 176] -> 
             RGBColor[
              0.9378182567567568, 0.9484148918918919, 0.739717189189189], 
             UndirectedEdge[49, 139] -> 
             RGBColor[
              0.8910065405405405, 0.9158946486486487, 0.9882944189189189], 
             UndirectedEdge[48, 106] -> 
             RGBColor[
              0.9449249864864865, 0.9485908918918919, 0.7002388378378378], 
             UndirectedEdge[69, 118] -> 
             RGBColor[
              0.8951836891891892, 0.8204535135135136, 0.6233332297297297], 
             UndirectedEdge[117, 200] -> 
             RGBColor[
              0.9878655945945947, 0.9703591081081081, 0.43889364864864844`], 
             UndirectedEdge[64, 153] -> 
             RGBColor[
              0.8827590945945947, 0.7704806756756757, 0.6132992027027027], 
             UndirectedEdge[73, 87] -> 
             RGBColor[
              0.9448733513513513, 0.9584072162162163, 0.9781992162162162], 
             UndirectedEdge[132, 138] -> 
             RGBColor[
              0.9637852837837837, 0.9004764594594594, 0.592471135135135], 
             UndirectedEdge[6, 96] -> 
             RGBColor[
              0.987271554054054, 0.9807612432432433, 0.645934581081081], 
             UndirectedEdge[34, 65] -> 
             RGBColor[
              0.9940051621621622, 0.989585972972973, 0.5888770810810809], 
             UndirectedEdge[2, 16] -> 
             RGBColor[
              0.9777915405405405, 0.9811648918918918, 0.8421985135135136], 
             UndirectedEdge[21, 122] -> 
             RGBColor[
              0.9911201756756757, 0.9883281621621622, 0.6319788783783783], 
             UndirectedEdge[90, 175] -> 
             RGBColor[
              0.9760547972972973, 0.9322791351351352, 0.5287793108108109], 
             UndirectedEdge[6, 179] -> 
             RGBColor[
              0.9843088513513514, 0.9707673513513513, 0.6344250405405405], 
             UndirectedEdge[8, 137] -> 
             RGBColor[
              0.9622880405405405, 0.884960945945946, 0.5443902162162162], 
             UndirectedEdge[3, 127] -> 
             RGBColor[
              0.9742564189189189, 0.9315354594594595, 0.5585830945945947], 
             UndirectedEdge[31, 65] -> 
             RGBColor[
              0.9933291891891892, 0.9881401351351351, 0.5153015945945943], 
             UndirectedEdge[3, 71] -> 
             RGBColor[
              0.9733572297297297, 0.9311636216216217, 0.5734849864864864], 
             UndirectedEdge[146, 184] -> 
             RGBColor[
              0.9556967972972973, 0.8524425675675675, 0.507835945945946], 
             UndirectedEdge[33, 99] -> 
             RGBColor[
              0.5025829324324325, 0.5848392297297297, 0.9583947972972973], 
             UndirectedEdge[10, 130] -> 
             RGBColor[
              0.9530261081081081, 0.9637855135135136, 0.9370383648648649], 
             UndirectedEdge[112, 160] -> 
             RGBColor[
              0.9699278108108108, 0.9753001351351351, 0.8555097567567569], 
             UndirectedEdge[73, 157] -> 
             RGBColor[
              0.9097711351351351, 0.930857027027027, 0.9900842027027027], 
             UndirectedEdge[157, 188] -> 
             RGBColor[
              0.9360598918918919, 0.9495668108108108, 0.9054447972972972], 
             UndirectedEdge[70, 132] -> 
             RGBColor[
              0.9630029459459459, 0.8831409729729729, 0.33015506756756746`], 
             UndirectedEdge[141, 191] -> 
             RGBColor[
              0.9878655945945947, 0.9703591081081081, 0.43889364864864844`], 
             UndirectedEdge[26, 80] -> 
             RGBColor[
              0.9575220540540541, 0.9656447027027026, 0.8625289054054055], 
             UndirectedEdge[171, 199] -> 
             RGBColor[
              0.5658320405405405, 0.6348329864864865, 0.9491944864864865], 
             UndirectedEdge[23, 43] -> 
             RGBColor[
              0.9627811756756757, 0.9627951351351351, 0.7007702027027027], 
             UndirectedEdge[75, 81] -> 
             RGBColor[
              0.9143095810810811, 0.8936529459459459, 0.6524108918918918], 
             UndirectedEdge[33, 172] -> 
             RGBColor[
              0.5025829324324325, 0.5848392297297297, 0.9583947972972973], 
             UndirectedEdge[156, 166] -> 
             RGBColor[0.9908282972972973, 0.980353, 0.45040318918918903`], 
             UndirectedEdge[151, 175] -> 
             RGBColor[
              0.9819802027027027, 0.952266918918919, 0.551798391891892], 
             UndirectedEdge[34, 199] -> 
             RGBColor[
              0.5866914054054054, 0.6479719324324325, 0.7857142027027026], 
             UndirectedEdge[38, 169] -> 
             RGBColor[
              0.9667130405405405, 0.9657275135135135, 0.694114581081081], 
             UndirectedEdge[10, 142] -> 
             RGBColor[
              0.9285357297297296, 0.9458194054054054, 0.9918739864864865], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.9632983783783784, 0.9712522432432433, 0.9068710540540541], 
             UndirectedEdge[12, 128] -> 
             RGBColor[
              0.9781183108108107, 0.9419011891891891, 0.5551907432432431], 
             UndirectedEdge[19, 172] -> 
             RGBColor[
              0.5653475945945946, 0.5759389864864866, 0.6067753783783785], 
             UndirectedEdge[109, 124] -> 
             RGBColor[
              0.9234148513513514, 0.8163580810810811, 0.6189038918918919], 
             UndirectedEdge[75, 127] -> 
             RGBColor[
              0.9266775945945946, 0.9420856216216217, 0.9045499054054054], 
             UndirectedEdge[4, 191] -> 
             RGBColor[
              0.9940430675675676, 0.9899256216216217, 0.6117983648648648], 
             UndirectedEdge[68, 172] -> 
             RGBColor[
              0.5527631621621621, 0.5260459054054054, 0.5966496486486487], 
             UndirectedEdge[97, 105] -> 
             RGBColor[
              0.9846775675675676, 0.9598832702702702, 0.4028589459459458], 
             UndirectedEdge[120, 136] -> 
             RGBColor[
              0.9940051621621622, 0.989585972972973, 0.5888770810810809], 
             UndirectedEdge[117, 159] -> 
             RGBColor[
              0.985590027027027, 0.9630539189189189, 0.3985204054054053], 
             UndirectedEdge[183, 192] -> 
             RGBColor[
              0.9509303648648648, 0.9228195675675674, 0.6547320405405405], 
             UndirectedEdge[71, 188] -> 
             RGBColor[
              0.9886879459459459, 0.9895901891891892, 0.8371335405405405], 
             UndirectedEdge[14, 106] -> 
             RGBColor[
              0.9826273243243243, 0.9530600270270271, 0.3870108648648648], 
             UndirectedEdge[141, 194] -> 
             RGBColor[
              0.9870064189189189, 0.9718828648648649, 0.5897193648648648], 
             UndirectedEdge[50, 105] -> 
             RGBColor[
              0.9902209864864865, 0.9879563243243243, 0.6468807702702701], 
             UndirectedEdge[98, 125] -> 
             RGBColor[
              0.5862407567567567, 0.6470080405405405, 0.7366638783783783], 
             UndirectedEdge[118, 119] -> 
             RGBColor[
              0.8909888783783784, 0.8038224864864865, 0.6199579864864865], 
             UndirectedEdge[137, 166] -> 
             RGBColor[
              0.9890699324324324, 0.9815049189189189, 0.6161307972972973], 
             UndirectedEdge[6, 112] -> 
             RGBColor[
              0.9654318648648648, 0.973440945945946, 0.9300192162162162], 
             UndirectedEdge[65, 119] -> 
             RGBColor[
              0.9558821081081081, 0.8510289189189189, 0.3964372837837836], 
             UndirectedEdge[170, 183] -> 
             RGBColor[
              0.891085054054054, 0.5136118378378378, 0.2410858108108107], 
             UndirectedEdge[14, 131] -> 
             RGBColor[
              0.9642350540540541, 0.8897781081081082, 0.3220207702702702], 
             UndirectedEdge[9, 164] -> 
             RGBColor[
              0.9106795405405406, 0.9316151621621622, 0.9913426216216217], 
             UndirectedEdge[96, 170] -> 
             RGBColor[
              0.9029358648648649, 0.5535874054054054, 0.28712397297297293`], 
             UndirectedEdge[117, 178] -> 
             RGBColor[
              0.9878655945945947, 0.9703591081081081, 0.43889364864864844`], 
             UndirectedEdge[18, 24] -> 
             RGBColor[
              0.5860154324324325, 0.6465260945945945, 0.712138716216216], 
             UndirectedEdge[18, 133] -> 
             RGBColor[
              0.5307298243243244, 0.6072827972972972, 0.961079472972973], 
             UndirectedEdge[49, 129] -> 
             RGBColor[
              0.9443889054054054, 0.8995132162162163, 0.6357801081081081], 
             UndirectedEdge[124, 198] -> 
             RGBColor[
              0.965995945945946, 0.9723677567567568, 0.8621653783783785], 
             UndirectedEdge[113, 124] -> 
             RGBColor[
              0.9657327162162161, 0.9715461621621622, 0.8147189324324324], 
             UndirectedEdge[176, 188] -> 
             RGBColor[0.9913455, 0.9888101081081082, 0.6565040405405405], 
             UndirectedEdge[37, 97] -> 
             RGBColor[
              0.9686513648648648, 0.9516044864864865, 0.6577842567567567], 
             UndirectedEdge[77, 143] -> 
             RGBColor[
              0.9333006216216215, 0.7699244054054053, 0.2788419324324324], 
             UndirectedEdge[79, 84] -> 
             RGBColor[
              0.5860154324324325, 0.6465260945945946, 0.712138716216216], 
             UndirectedEdge[151, 199] -> 
             RGBColor[
              0.5748517567567568, 0.6092392297297298, 0.6372368513513513], 
             UndirectedEdge[48, 87] -> 
             RGBColor[
              0.9270171621621621, 0.944202972972973, 0.9776678513513513], 
             UndirectedEdge[27, 30] -> 
             RGBColor[
              0.5213475270270271, 0.5998016081081081, 0.9601845810810811], 
             UndirectedEdge[5, 87] -> 
             RGBColor[
              0.9522526351351351, 0.905377972972973, 0.6224688648648649], 
             UndirectedEdge[68, 81] -> 
             RGBColor[
              0.9457252162162162, 0.8198972432432432, 0.2888759594594594], 
             UndirectedEdge[155, 172] -> 
             RGBColor[
              0.5119652297297298, 0.592320418918919, 0.9592896891891892], 
             UndirectedEdge[143, 188] -> 
             RGBColor[
              0.9456686351351351, 0.8183570810810812, 0.530980945945946], 
             UndirectedEdge[102, 180] -> 
             RGBColor[
              0.9828793918918919, 0.9526387567567568, 0.5368965000000001], 
             UndirectedEdge[80, 136] -> 
             RGBColor[
              0.994268391891892, 0.9904075675675675, 0.636323527027027], 
             UndirectedEdge[66, 78] -> 
             RGBColor[
              0.9575220540540541, 0.9656447027027026, 0.8625289054054055], 
             UndirectedEdge[50, 101] -> 
             RGBColor[
              0.5833578783783784, 0.6473061756756757, 0.8927682162162162], 
             UndirectedEdge[41, 85] -> 
             RGBColor[
              0.9801818243243243, 0.9515232432432433, 0.5816021756756757], 
             UndirectedEdge[5, 30] -> 
             RGBColor[
              0.9077681216216217, 0.8703465945945947, 0.6334589594594595], 
             UndirectedEdge[32, 133] -> 
             RGBColor[
              0.7984508918918918, 0.8429807297297297, 0.9804116216216217], 
             UndirectedEdge[159, 161] -> 
             RGBColor[
              0.9908683108108107, 0.9822485945945947, 0.5863270135135135], 
             UndirectedEdge[3, 195] -> 
             RGBColor[
              0.9724580405405405, 0.9307917837837838, 0.5883868783783784], 
             UndirectedEdge[173, 180] -> 
             RGBColor[
              0.9810810135135135, 0.9518950810810811, 0.5667002837837838], 
             UndirectedEdge[129, 141] -> 
             RGBColor[0.9671977567567568, 0.899772, 0.33353031081081075`], 
             UndirectedEdge[53, 199] -> 
             RGBColor[
              0.5860154324324325, 0.6465260945945946, 0.712138716216216], 
             UndirectedEdge[88, 95] -> 
             RGBColor[
              0.931804472972973, 0.8496201351351351, 0.6256543783783783], 
             UndirectedEdge[93, 95] -> 
             RGBColor[
              0.9436000675675675, 0.8584172702702704, 0.6056875135135136], 
             UndirectedEdge[3, 29] -> 
             RGBColor[
              0.9737392162162162, 0.9230783513513514, 0.35248224324324323`], 
             UndirectedEdge[52, 125] -> 
             RGBColor[
              0.9910536216216217, 0.980834945945946, 0.4749283513513512], 
             UndirectedEdge[82, 136] -> 
             RGBColor[
              0.5862407567567567, 0.6470080405405405, 0.7366638783783783], 
             UndirectedEdge[116, 193] -> 
             RGBColor[
              0.9805588783783784, 0.9813478918918919, 0.6899957972972972], 
             UndirectedEdge[19, 159] -> 
             RGBColor[
              0.9701604594594595, 0.9097658918918919, 0.3450398513513513], 
             UndirectedEdge[77, 99] -> 
             RGBColor[
              0.571889054054054, 0.5992453378378377, 0.6257273108108108], 
             UndirectedEdge[53, 196] -> 
             RGBColor[
              0.9922446891891892, 0.989181945945946, 0.6416021486486485], 
             UndirectedEdge[58, 137] -> 
             RGBColor[
              0.9801818243243243, 0.9515232432432433, 0.5816021756756757], 
             UndirectedEdge[159, 200] -> 
             RGBColor[0.9908282972972973, 0.980353, 0.45040318918918903`], 
             UndirectedEdge[3, 62] -> 
             RGBColor[
              0.9737392162162162, 0.9230783513513514, 0.35248224324324323`], 
             UndirectedEdge[48, 157] -> 
             RGBColor[
              0.8919149459459459, 0.9166527837837837, 0.9895528378378378], 
             UndirectedEdge[130, 168] -> 
             RGBColor[
              0.5824586891891892, 0.6469343378378378, 0.9076701081081082], 
             UndirectedEdge[140, 180] -> 
             RGBColor[
              0.9826161621621622, 0.9518171621621623, 0.48945005405405406`], 
             UndirectedEdge[146, 171] -> 
             RGBColor[
              0.9354733918918918, 0.8388538648648648, 0.6089678918918919], 
             UndirectedEdge[26, 100] -> 
             RGBColor[
              0.956357527027027, 0.9628953243243243, 0.7169818108108107], 
             UndirectedEdge[45, 153] -> 
             RGBColor[
              0.9483662027027027, 0.8194725945945946, 0.4862752702702704], 
             UndirectedEdge[165, 177] -> 
             RGBColor[
              0.9644970540540541, 0.884772918918919, 0.42771293243243247`], 
             UndirectedEdge[123, 139] -> 
             RGBColor[0.906734, 0.9276241621621621, 0.9616719324324324], 
             UndirectedEdge[13, 34] -> 
             RGBColor[
              0.9893239054054054, 0.9891404324324324, 0.7747852027027027], 
             UndirectedEdge[48, 72] -> 
             RGBColor[
              0.9445429999999999, 0.9566761621621622, 0.921241581081081], 
             UndirectedEdge[127, 191] -> 
             RGBColor[0.9913455, 0.9888101081081082, 0.6565040405405405], 
             UndirectedEdge[58, 125] -> 
             RGBColor[
              0.9821655135135136, 0.9508532702702703, 0.4403997297297296], 
             UndirectedEdge[165, 169] -> 
             RGBColor[
              0.9694392567567567, 0.9739965945945946, 0.7835381486486487], 
             UndirectedEdge[119, 156] -> 
             RGBColor[
              0.9556567837837838, 0.8505469729729729, 0.37191212162162146`], 
             UndirectedEdge[139, 191] -> 
             RGBColor[
              0.9190536621621622, 0.9334525135135135, 0.7379274054054052], 
             UndirectedEdge[48, 81] -> 
             RGBColor[
              0.9330741756756756, 0.9086153243243242, 0.6542006756756755], 
             UndirectedEdge[85, 161] -> 
             RGBColor[
              0.9913855135135134, 0.9907057027027028, 0.7924278648648648], 
             UndirectedEdge[30, 106] -> 
             RGBColor[
              0.9261603918918919, 0.9336285135135136, 0.698449054054054], 
             UndirectedEdge[118, 195] -> 
             RGBColor[
              0.9248792162162163, 0.941341945945946, 0.9343536891891893], 
             UndirectedEdge[132, 145] -> 
             RGBColor[
              0.9691425135135134, 0.9023678378378379, 0.48013849999999997`], 
             UndirectedEdge[124, 137] -> 
             RGBColor[
              0.9632983783783784, 0.9712522432432433, 0.9068710540540541], 
             UndirectedEdge[53, 182] -> 
             RGBColor[
              0.5860154324324325, 0.6465260945945946, 0.712138716216216], 
             UndirectedEdge[31, 40] -> 
             RGBColor[
              0.9895471216216216, 0.9880664324324324, 0.6863078243243242], 
             UndirectedEdge[130, 157] -> 
             RGBColor[
              0.9342615135135135, 0.948823135135135, 0.9352485810810811], 
             UndirectedEdge[83, 166] -> 
             RGBColor[
              0.987271554054054, 0.9807612432432433, 0.645934581081081], 
             UndirectedEdge[76, 176] -> 
             RGBColor[
              0.9940051621621622, 0.989585972972973, 0.5888770810810809], 
             UndirectedEdge[100, 113] -> 
             RGBColor[
              0.9935545135135135, 0.9886220810810811, 0.5398267567567566], 
             UndirectedEdge[53, 118] -> 
             RGBColor[
              0.9284359594594596, 0.9409337027027027, 0.7388222972972971], 
             UndirectedEdge[18, 85] -> 
             RGBColor[
              0.5842570675675676, 0.6476780135135136, 0.8778663243243243], 
             UndirectedEdge[90, 177] -> 
             RGBColor[
              0.9469573243243243, 0.8265343783783784, 0.2807416621621622], 
             UndirectedEdge[55, 165] -> 
             RGBColor[
              0.979428135135135, 0.9413413243243243, 0.4534153513513513], 
             UndirectedEdge[9, 121] -> 
             RGBColor[
              0.9521269189189189, 0.9634136756756757, 0.9519402567567568], 
             UndirectedEdge[70, 110] -> 
             RGBColor[
              0.9716140675675675, 0.9615983783783784, 0.6692937972972972], 
             UndirectedEdge[51, 147] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[81, 188] -> 
             RGBColor[
              0.9772191216216215, 0.9415293513513513, 0.570092635135135], 
             UndirectedEdge[63, 132] -> 
             RGBColor[
              0.968015891891892, 0.8999581081081081, 0.3575126891891891], 
             UndirectedEdge[68, 143] -> 
             RGBColor[
              0.9141747297297298, 0.696724972972973, 0.2497642702702703], 
             UndirectedEdge[76, 81] -> 
             RGBColor[
              0.9798787837837837, 0.9423052162162162, 0.5024656756756756], 
             UndirectedEdge[55, 163] -> 
             RGBColor[
              0.9457252162162162, 0.8198972432432432, 0.2888759594594594], 
             UndirectedEdge[86, 94] -> 
             RGBColor[
              0.9172722837837839, 0.903646837837838, 0.6639204324324324], 
             UndirectedEdge[3, 167] -> 
             RGBColor[
              0.9757894594594595, 0.9299015945945945, 0.3683303243243242], 
             UndirectedEdge[16, 82] -> 
             RGBColor[
              0.5869546351351351, 0.648793527027027, 0.8331606486486487], 
             UndirectedEdge[51, 107] -> 
             RGBColor[0.5815595, 0.6465625, 0.922572], 
             UndirectedEdge[53, 171] -> 
             RGBColor[
              0.972920472972973, 0.9759650810810812, 0.7278322027027025], 
             UndirectedEdge[78, 82] -> 
             RGBColor[
              0.5494944189189189, 0.6222451756756757, 0.9628692567567567], 
             UndirectedEdge[92, 186] -> 
             RGBColor[
              0.9572588243243243, 0.9648231081081081, 0.8150824594594595], 
             UndirectedEdge[75, 118] -> 
             RGBColor[
              0.8637680540540541, 0.8942092162162163, 0.9868681621621621], 
             UndirectedEdge[77, 83] -> 
             RGBColor[
              0.9754207432432431, 0.9407856756756756, 0.5998964189189189], 
             UndirectedEdge[42, 176] -> 
             RGBColor[
              0.9928785405405406, 0.9871762432432433, 0.46625127027027], 
             UndirectedEdge[20, 144] -> 
             RGBColor[
              0.955346945945946, 0.8597964324324325, 0.2874921486486487], 
             UndirectedEdge[26, 98] -> 
             RGBColor[
              0.5494944189189189, 0.6222451756756757, 0.9628692567567567], 
             UndirectedEdge[16, 84] -> 
             RGBColor[
              0.5869546351351351, 0.648793527027027, 0.8331606486486487], 
             UndirectedEdge[55, 175] -> 
             RGBColor[
              0.9790174999999999, 0.942273027027027, 0.5402888513513513], 
             UndirectedEdge[113, 128] -> 
             RGBColor[
              0.9929206621621621, 0.9906277837837838, 0.7151776351351351], 
             UndirectedEdge[142, 147] -> 
             RGBColor[
              0.9606008108108108, 0.9701367297297298, 0.9515767297297297], 
             UndirectedEdge[10, 42] -> 
             RGBColor[
              0.956357527027027, 0.9628953243243243, 0.7169818108108107], 
             UndirectedEdge[98, 120] -> 
             RGBColor[
              0.5866914054054053, 0.6479719324324325, 0.7857142027027026], 
             UndirectedEdge[195, 199] -> 
             RGBColor[
              0.5824586891891892, 0.6469343378378378, 0.9076701081081082], 
             UndirectedEdge[49, 195] -> 
             RGBColor[0.9615, 0.9705085675675675, 0.9366748378378379], 
             UndirectedEdge[25, 43] -> 
             RGBColor[
              0.9409414864864865, 0.9554748378378379, 0.9848548378378379], 
             UndirectedEdge[91, 121] -> 
             RGBColor[
              0.9521269189189189, 0.9634136756756757, 0.9519402567567568], 
             UndirectedEdge[8, 21] -> 
             RGBColor[
              0.9638210810810811, 0.8833270810810812, 0.3541374459459459], 
             UndirectedEdge[2, 124] -> 
             RGBColor[
              0.9488052162162162, 0.9613395945945946, 0.9715435945945946], 
             UndirectedEdge[80, 125] -> 
             RGBColor[
              0.994268391891892, 0.9904075675675675, 0.636323527027027], 
             UndirectedEdge[33, 180] -> 
             RGBColor[
              0.8985076891891892, 0.8886844594594595, 0.6621306486486487], 
             UndirectedEdge[5, 155] -> 
             RGBColor[
              0.8983858243243243, 0.8628654054054055, 0.6325640675675677], 
             UndirectedEdge[179, 192] -> 
             RGBColor[
              0.959818472972973, 0.9528012432432432, 0.6892606621621621], 
             UndirectedEdge[59, 146] -> 
             RGBColor[
              0.9444931081081082, 0.8132601081081081, 0.2970102567567568], 
             UndirectedEdge[3, 68] -> 
             RGBColor[
              0.9427625135135136, 0.8099033513513514, 0.27736641891891894`], 
             UndirectedEdge[131, 157] -> 
             RGBColor[
              0.9171504189189189, 0.8778277837837838, 0.6343538513513514], 
             UndirectedEdge[85, 200] -> 
             RGBColor[0.9913455, 0.9888101081081082, 0.6565040405405405], 
             UndirectedEdge[23, 38] -> 
             RGBColor[
              0.9885527297297297, 0.9730478108108108, 0.4100299459459459], 
             UndirectedEdge[92, 191] -> 
             RGBColor[
              0.9565828513513513, 0.9633772702702703, 0.7415069729729729], 
             UndirectedEdge[97, 153] -> 
             RGBColor[
              0.939226027027027, 0.7899121891891892, 0.30186101351351347`], 
             UndirectedEdge[95, 161] -> 
             RGBColor[
              0.9598916081081081, 0.8690735945945947, 0.5112111891891893], 
             UndirectedEdge[139, 196] -> 
             RGBColor[
              0.9181944864864865, 0.9349762702702703, 0.8887531216216216], 
             UndirectedEdge[1, 94] -> 
             RGBColor[
              0.5213475270270271, 0.5998016081081081, 0.9601845810810811], 
             UndirectedEdge[189, 194] -> 
             RGBColor[
              0.9673820405405404, 0.9019638108108108, 0.5328635675675675], 
             UndirectedEdge[42, 76] -> 
             RGBColor[
              0.9937798378378379, 0.989104027027027, 0.5643519189189188], 
             UndirectedEdge[84, 190] -> 
             RGBColor[
              0.5119652297297297, 0.5923204189189188, 0.9592896891891892], 
             UndirectedEdge[37, 134] -> 
             RGBColor[
              0.9750939729729728, 0.9800493783783784, 0.8869041891891891], 
             UndirectedEdge[140, 161] -> 
             RGBColor[
              0.9938198513513513, 0.9909996216216217, 0.7002757432432433], 
             UndirectedEdge[10, 51] -> 
             RGBColor[
              0.9521269189189189, 0.9634136756756757, 0.9519402567567568], 
             UndirectedEdge[146, 191] -> 
             RGBColor[
              0.9556567837837838, 0.8505469729729729, 0.37191212162162146`], 
             UndirectedEdge[21, 175] -> 
             RGBColor[
              0.992918554054054, 0.9890718378378378, 0.6021750945945945], 
             UndirectedEdge[49, 141] -> 
             RGBColor[
              0.959818472972973, 0.9528012432432432, 0.6892606621621621], 
             UndirectedEdge[111, 177] -> 
             RGBColor[
              0.9307941351351352, 0.7633288378378379, 0.26317354054054054`], 
             UndirectedEdge[69, 191] -> 
             RGBColor[0.9598515945945947, 0.867178, 0.37528736486486475`], 
             UndirectedEdge[111, 175] -> 
             RGBColor[
              0.9598916081081081, 0.8690735945945947, 0.5112111891891893], 
             UndirectedEdge[77, 170] -> 
             RGBColor[
              0.891085054054054, 0.5136118378378378, 0.2410858108108107], 
             UndirectedEdge[104, 154] -> 
             RGBColor[
              0.9904863243243243, 0.990333864864865, 0.8073297567567568], 
             UndirectedEdge[13, 138] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[21, 67] -> 
             RGBColor[
              0.9469752297297298, 0.9554141351351351, 0.7160869189189187], 
             UndirectedEdge[73, 197] -> 
             RGBColor[
              0.9359992837837838, 0.8662511621621622, 0.6290296216216216], 
             UndirectedEdge[67, 192] -> 
             RGBColor[
              0.9191534324324324, 0.9383382162162162, 0.9909790945945947], 
             UndirectedEdge[37, 101] -> 
             RGBColor[
              0.5697639054054053, 0.6377653648648649, 0.9425388648648649], 
             UndirectedEdge[6, 44] -> 
             RGBColor[
              0.9897724459459459, 0.9885483783783784, 0.7108329864864864], 
             UndirectedEdge[75, 89] -> 
             RGBColor[
              0.9275767837837838, 0.9424574594594595, 0.8896480135135134], 
             UndirectedEdge[76, 188] -> 
             RGBColor[
              0.9922467972972973, 0.9907378918918919, 0.7546046891891891], 
             UndirectedEdge[42, 71] -> 
             RGBColor[
              0.9902209864864865, 0.9879563243243243, 0.6468807702702701], 
             UndirectedEdge[6, 192] -> 
             RGBColor[0.9615, 0.9705085675675675, 0.9366748378378379], 
             UndirectedEdge[2, 100] -> 
             RGBColor[
              0.9766270135135136, 0.9784155135135135, 0.6966514189189188], 
             UndirectedEdge[7, 8] -> 
             RGBColor[
              0.9275253918918919, 0.8595281081081081, 0.6293931486486486], 
             UndirectedEdge[69, 92] -> 
             RGBColor[
              0.923330581081081, 0.8428970810810812, 0.6260179054054054], 
             UndirectedEdge[104, 160] -> 
             RGBColor[
              0.9931838918918918, 0.9914493783783784, 0.7626240810810812], 
             UndirectedEdge[17, 30] -> 
             RGBColor[
              0.9293751621621622, 0.9432011351351351, 0.8598442297297297], 
             UndirectedEdge[88, 164] -> 
             RGBColor[
              0.9191534324324324, 0.9383382162162162, 0.9909790945945947], 
             UndirectedEdge[43, 60] -> 
             RGBColor[
              0.5579683108108108, 0.6289682297297298, 0.9625057297297297], 
             UndirectedEdge[149, 197] -> 
             RGBColor[
              0.9265993243243243, 0.7466978108108108, 0.2597982972972973], 
             UndirectedEdge[167, 197] -> 
             RGBColor[
              0.9638210810810811, 0.8833270810810812, 0.3541374459459459], 
             UndirectedEdge[54, 127] -> 
             RGBColor[
              0.9895871351351351, 0.9899620270270271, 0.8222316486486486], 
             UndirectedEdge[107, 147] -> 
             RGBColor[0.5815595, 0.6465624999999999, 0.922572], 
             UndirectedEdge[78, 113] -> 
             RGBColor[
              0.9572588243243243, 0.9648231081081081, 0.8150824594594595], 
             UndirectedEdge[81, 87] -> 
             RGBColor[
              0.9587940945945945, 0.9286843243243242, 0.6414207972972972], 
             UndirectedEdge[83, 179] -> 
             RGBColor[
              0.9843088513513514, 0.9707673513513513, 0.6344250405405405], 
             UndirectedEdge[82, 198] -> 
             RGBColor[
              0.5869546351351351, 0.6487935270270271, 0.8331606486486487], 
             UndirectedEdge[30, 107] -> 
             RGBColor[
              0.521347527027027, 0.5998016081081081, 0.9601845810810811], 
             UndirectedEdge[47, 134] -> 
             RGBColor[0.907913, 0.9271232432432432, 0.9027601216216217], 
             UndirectedEdge[5, 142] -> 
             RGBColor[
              0.9443889054054054, 0.8995132162162163, 0.635780108108108], 
             UndirectedEdge[169, 190] -> 
             RGBColor[
              0.8949384054054055, 0.9188270270270271, 0.9816387972972973], 
             UndirectedEdge[121, 152] -> 
             RGBColor[
              0.9834096621621622, 0.9703955135135135, 0.6493269324324323], 
             UndirectedEdge[31, 64] -> 
             RGBColor[
              0.9284359594594596, 0.9409337027027027, 0.7388222972972971], 
             UndirectedEdge[105, 134] -> 
             RGBColor[
              0.9911201756756757, 0.9883281621621622, 0.6319788783783783], 
             UndirectedEdge[83, 192] -> 
             RGBColor[0.9615, 0.9705085675675675, 0.9366748378378379], 
             UndirectedEdge[77, 112] -> 
             RGBColor[
              0.9548622297297297, 0.9257519459459459, 0.6480764189189188], 
             UndirectedEdge[195, 196] -> 
             RGBColor[
              0.9886879459459459, 0.9895901891891892, 0.8371335405405406], 
             UndirectedEdge[92, 171] -> 
             RGBColor[
              0.9363994594594593, 0.9516841621621621, 0.9785627432432432], 
             UndirectedEdge[166, 183] -> 
             RGBColor[
              0.9767019189189189, 0.9330722432432432, 0.36399178378378366`], 
             UndirectedEdge[139, 195] -> 
             RGBColor[
              0.9154969189189189, 0.9338607567567567, 0.9334587972972974], 
             UndirectedEdge[177, 190] -> 
             RGBColor[
              0.8899962027027027, 0.8296033513513514, 0.6258135810810811], 
             UndirectedEdge[29, 149] -> 
             RGBColor[
              0.9533812162162163, 0.8432417837837838, 0.33153887837837837`], 
             UndirectedEdge[119, 155] -> 
             RGBColor[
              0.8816065810810811, 0.7963412972972972, 0.6190630945945945], 
             UndirectedEdge[12, 162] -> 
             RGBColor[
              0.571889054054054, 0.5992453378378377, 0.6257273108108108], 
             UndirectedEdge[85, 173] -> 
             RGBColor[
              0.9904863243243243, 0.990333864864865, 0.8073297567567568], 
             UndirectedEdge[92, 141] -> 
             RGBColor[
              0.951344581081081, 0.9460781891891892, 0.6896241891891891], 
             UndirectedEdge[5, 29] -> 
             RGBColor[
              0.9701604594594595, 0.9097658918918919, 0.3450398513513513], 
             UndirectedEdge[51, 87] -> 
             RGBColor[
              0.9684645405405405, 0.9760014864864865, 0.9382654864864864], 
             UndirectedEdge[145, 153] -> 
             RGBColor[
              0.9483282972972973, 0.819132945945946, 0.4633539864864865], 
             UndirectedEdge[118, 191] -> 
             RGBColor[
              0.9284359594594596, 0.9409337027027027, 0.7388222972972971], 
             UndirectedEdge[117, 164] -> 
             RGBColor[
              0.9419622837837838, 0.9385969999999999, 0.6887292972972971], 
             UndirectedEdge[145, 185] -> 
             RGBColor[
              0.9828414864864865, 0.9522991081081082, 0.5139752162162162], 
             UndirectedEdge[99, 137] -> 
             RGBColor[
              0.5842570675675676, 0.6476780135135136, 0.8778663243243243], 
             UndirectedEdge[48, 176] -> 
             RGBColor[
              0.947200554054054, 0.955896081081081, 0.740612081081081], 
             UndirectedEdge[50, 144] -> 
             RGBColor[
              0.9733572297297297, 0.9311636216216217, 0.5734849864864864], 
             UndirectedEdge[3, 53] -> 
             RGBColor[
              0.9760147837837838, 0.9303835405405405, 0.3928554864864864], 
             UndirectedEdge[169, 177] -> 
             RGBColor[0.9399311486486486, 0.8691835405405406, 0.622374], 
             UndirectedEdge[20, 135] -> 
             RGBColor[
              0.887874891891892, 0.5159112972972972, 0.22532393243243243`], 
             UndirectedEdge[166, 170] -> 
             RGBColor[
              0.9029358648648649, 0.5535874054054054, 0.28712397297297293`], 
             UndirectedEdge[17, 42] -> 
             RGBColor[
              0.9938177432432433, 0.9894436756756757, 0.5872732027027027], 
             UndirectedEdge[129, 195] -> 
             RGBColor[
              0.9688792837837839, 0.9174793243243244, 0.5809444864864866], 
             UndirectedEdge[74, 93] -> 
             RGBColor[
              0.9766270135135136, 0.9784155135135135, 0.6966514189189188], 
             UndirectedEdge[37, 45] -> 
             RGBColor[
              0.9777915405405405, 0.9811648918918918, 0.8421985135135136], 
             UndirectedEdge[49, 92] -> 
             RGBColor[
              0.9285357297297296, 0.9458194054054054, 0.9918739864864865], 
             UndirectedEdge[163, 177] -> 
             RGBColor[
              0.9307941351351352, 0.7633288378378379, 0.26317354054054054`], 
             UndirectedEdge[6, 45] -> 
             RGBColor[
              0.9904863243243243, 0.9903338648648649, 0.8073297567567569], 
             UndirectedEdge[6, 166] -> 
             RGBColor[
              0.987271554054054, 0.9807612432432433, 0.645934581081081], 
             UndirectedEdge[65, 127] -> 
             RGBColor[
              0.9915708243243243, 0.9892920540540541, 0.6810292027027025], 
             UndirectedEdge[15, 59] -> 
             RGBColor[
              0.9823908378378379, 0.9513352162162163, 0.464924891891892], 
             UndirectedEdge[100, 136] -> 
             RGBColor[
              0.9931038648648649, 0.9876581891891891, 0.4907764324324322], 
             UndirectedEdge[83, 183] -> 
             RGBColor[
              0.9754207432432431, 0.9407856756756756, 0.5998964189189189], 
             UndirectedEdge[53, 119] -> 
             RGBColor[
              0.9556567837837838, 0.8505469729729729, 0.37191212162162146`], 
             UndirectedEdge[5, 68] -> 
             RGBColor[
              0.9391837567567568, 0.796590891891892, 0.269924027027027], 
             UndirectedEdge[49, 54] -> 
             RGBColor[
              0.9632983783783784, 0.9712522432432433, 0.9068710540540541], 
             UndirectedEdge[153, 185] -> 
             RGBColor[
              0.9362633243243244, 0.7799182972972973, 0.29035147297297303`], 
             UndirectedEdge[101, 144] -> 
             RGBColor[
              0.5689263513513514, 0.5892514459459459, 0.6142177702702702], 
             UndirectedEdge[19, 102] -> 
             RGBColor[
              0.9733752297297298, 0.9193385135135135, 0.5064350270270271], 
             UndirectedEdge[102, 172] -> 
             RGBColor[
              0.5869546351351351, 0.648793527027027, 0.8331606486486487], 
             UndirectedEdge[102, 140] -> 
             RGBColor[
              0.9947190405405406, 0.9913714594594594, 0.6853738513513514], 
             UndirectedEdge[71, 107] -> 
             RGBColor[
              0.5833578783783784, 0.6473061756756757, 0.8927682162162162], 
             UndirectedEdge[5, 168] -> 
             RGBColor[
              0.5653475945945946, 0.5759389864864866, 0.6067753783783785], 
             UndirectedEdge[79, 122] -> 
             RGBColor[0.9913455, 0.9888101081081082, 0.6565040405405405], 
             UndirectedEdge[136, 198] -> 
             RGBColor[
              0.994268391891892, 0.9904075675675675, 0.636323527027027], 
             UndirectedEdge[97, 135] -> 
             RGBColor[
              0.9003417567567568, 0.5592054324324324, 0.2672949459459459], 
             UndirectedEdge[19, 164] -> 
             RGBColor[
              0.9265327162162162, 0.8853089729729731, 0.6352487432432432], 
             UndirectedEdge[118, 139] -> 
             RGBColor[
              0.8543857567567568, 0.886728027027027, 0.9859732702702703], 
             UndirectedEdge[26, 137] -> 
             RGBColor[
              0.9548244864864864, 0.9645291891891892, 0.9072345810810811], 
             UndirectedEdge[142, 168] -> 
             RGBColor[
              0.5579683108108108, 0.6289682297297298, 0.9625057297297297], 
             UndirectedEdge[3, 194] -> 
             RGBColor[
              0.9751556081081081, 0.9319072972972973, 0.5436812027027027], 
             UndirectedEdge[65, 195] -> 
             RGBColor[
              0.9897724459459459, 0.9885483783783784, 0.7108329864864864], 
             UndirectedEdge[73, 107] -> 
             RGBColor[
              0.5579683108108108, 0.6289682297297298, 0.9625057297297297], 
             UndirectedEdge[162, 172] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[68, 140] -> 
             RGBColor[
              0.9605275675675675, 0.8686238378378379, 0.44886285135135134`], 
             UndirectedEdge[38, 165] -> 
             RGBColor[
              0.9912789459459459, 0.981316891891892, 0.4994535135135135], 
             UndirectedEdge[86, 92] -> 
             RGBColor[
              0.9454191756756757, 0.9260904054054055, 0.6666051081081081], 
             UndirectedEdge[90, 115] -> 
             RGBColor[
              0.9764654324324324, 0.9313474324324325, 0.4419058108108109], 
             UndirectedEdge[11, 70] -> 
             RGBColor[
              0.985590027027027, 0.9630539189189189, 0.3985204054054053], 
             UndirectedEdge[54, 123] -> 
             RGBColor[
              0.9790258378378378, 0.9829817567567568, 0.8802485675675675], 
             UndirectedEdge[107, 176] -> 
             RGBColor[
              0.5860154324324325, 0.6465260945945945, 0.712138716216216], 
             UndirectedEdge[30, 76] -> 
             RGBColor[
              0.9293372567567568, 0.9428614864864866, 0.836922945945946], 
             UndirectedEdge[129, 191] -> 
             RGBColor[
              0.9724360270270271, 0.9170710810810812, 0.3854130945945945], 
             UndirectedEdge[7, 125] -> 
             RGBColor[
              0.9568081756756757, 0.9638592162162163, 0.766032135135135], 
             UndirectedEdge[3, 155] -> 
             RGBColor[
              0.9019645810810811, 0.8761778648648648, 0.6400064594594594], 
             UndirectedEdge[54, 118] -> 
             RGBColor[
              0.9266775945945946, 0.9420856216216217, 0.9045499054054054], 
             UndirectedEdge[4, 171] -> 
             RGBColor[
              0.9738596756756757, 0.9782325135135135, 0.8488541351351352], 
             UndirectedEdge[167, 189] -> 
             RGBColor[
              0.968015891891892, 0.8999581081081081, 0.3575126891891891], 
             UndirectedEdge[42, 81] -> 
             RGBColor[
              0.9787521621621622, 0.9398954864864864, 0.37983986486486465`], 
             UndirectedEdge[5, 129] -> 
             RGBColor[
              0.9517681891891893, 0.8464839729729731, 0.28004975675675675`], 
             UndirectedEdge[115, 133] -> 
             RGBColor[
              0.9382689054054054, 0.9493787837837837, 0.7887675135135135], 
             UndirectedEdge[92, 146] -> 
             RGBColor[
              0.9191357702702703, 0.8262660540540541, 0.6226426621621621], 
             UndirectedEdge[65, 151] -> 
             RGBColor[
              0.9821655135135136, 0.9508532702702703, 0.4403997297297296], 
             UndirectedEdge[45, 156] -> 
             RGBColor[
              0.9940430675675676, 0.9899256216216217, 0.6117983648648648], 
             UndirectedEdge[74, 172] -> 
             RGBColor[
              0.5857901081081082, 0.6460441486486487, 0.687613554054054], 
             UndirectedEdge[31, 138] -> 
             RGBColor[
              0.9886479324324324, 0.9876945945945946, 0.7012097162162161], 
             UndirectedEdge[116, 198] -> 
             RGBColor[
              0.9938177432432433, 0.9894436756756757, 0.5872732027027027], 
             UndirectedEdge[42, 142] -> 
             RGBColor[
              0.9648314189189189, 0.9696183783783784, 0.7166182837837838], 
             UndirectedEdge[10, 129] -> 
             RGBColor[
              0.9359150135135135, 0.8927901621621622, 0.6361436351351352], 
             UndirectedEdge[3, 141] -> 
             RGBColor[
              0.9707765135135136, 0.9130844594594594, 0.34097270270270263`], 
             UndirectedEdge[161, 162] -> 
             RGBColor[
              0.5860554459459459, 0.6484216891891892, 0.8480625405405406], 
             UndirectedEdge[6, 77] -> 
             RGBColor[
              0.9754207432432431, 0.9407856756756756, 0.5998964189189189], 
             UndirectedEdge[98, 113] -> 
             RGBColor[
              0.5866914054054053, 0.6479719324324325, 0.7857142027027026], 
             UndirectedEdge[3, 139] -> 
             RGBColor[
              0.9019645810810811, 0.8761778648648648, 0.6400064594594594], 
             UndirectedEdge[34, 138] -> 
             RGBColor[
              0.9893239054054054, 0.9891404324324324, 0.7747852027027027], 
             UndirectedEdge[22, 72] -> 
             RGBColor[
              0.9655836621621621, 0.9012201351351352, 0.5626673513513513], 
             UndirectedEdge[34, 40] -> 
             RGBColor[
              0.9902230945945946, 0.9895122702702703, 0.7598833108108108], 
             UndirectedEdge[41, 74] -> 
             RGBColor[
              0.9817148648648649, 0.9498893783783784, 0.39134940540540536`], 
             UndirectedEdge[141, 146] -> 
             RGBColor[
              0.9504185135135135, 0.8332478918918917, 0.3200293378378377], 
             UndirectedEdge[90, 111] -> 
             RGBColor[
              0.9427625135135136, 0.8099033513513514, 0.27736641891891894`], 
             UndirectedEdge[66, 82] -> 
             RGBColor[
              0.5869546351351351, 0.648793527027027, 0.8331606486486487], 
             UndirectedEdge[119, 151] -> 
             RGBColor[
              0.9444931081081082, 0.8132601081081081, 0.2970102567567568], 
             UndirectedEdge[4, 139] -> 
             RGBColor[
              0.919992864864865, 0.935719945945946, 0.8589493378378379], 
             UndirectedEdge[165, 175] -> 
             RGBColor[
              0.993594527027027, 0.9905176756756757, 0.6757505810810811], 
             UndirectedEdge[127, 139] -> 
             RGBColor[
              0.9172952972972973, 0.9346044324324325, 0.9036550135135135], 
             UndirectedEdge[85, 117] -> 
             RGBColor[
              0.9861072297297298, 0.9715110270270271, 0.6046212567567566], 
             UndirectedEdge[141, 155] -> 
             RGBColor[
              0.9138153918918919, 0.9161534324324324, 0.6860446216216216], 
             UndirectedEdge[168, 189] -> 
             RGBColor[
              0.5611527837837837, 0.5593079594594594, 0.6034001351351351], 
             UndirectedEdge[24, 175] -> 
             RGBColor[
              0.9931438783783784, 0.9895537837837838, 0.6267002567567567], 
             UndirectedEdge[106, 176] -> 
             RGBColor[0.9908282972972973, 0.980353, 0.45040318918918903`], 
             UndirectedEdge[40, 53] -> 
             RGBColor[
              0.9895471216216216, 0.9880664324324324, 0.6863078243243242], 
             UndirectedEdge[27, 155] -> 
             RGBColor[
              0.5119652297297297, 0.5923204189189188, 0.9592896891891892], 
             UndirectedEdge[33, 77] -> 
             RGBColor[
              0.8955449864864864, 0.8786905675675675, 0.650621108108108], 
             UndirectedEdge[67, 137] -> 
             RGBColor[0.9454421891891891, 0.957048, 0.9063396891891892], 
             UndirectedEdge[68, 129] -> 
             RGBColor[
              0.9391837567567568, 0.796590891891892, 0.269924027027027], 
             UndirectedEdge[137, 192] -> 
             RGBColor[
              0.9632983783783784, 0.9712522432432433, 0.9068710540540541], 
             UndirectedEdge[58, 128] -> 
             RGBColor[
              0.9810810135135135, 0.9518950810810811, 0.5667002837837838], 
             UndirectedEdge[55, 90] -> 
             RGBColor[
              0.9618884054054053, 0.8831027837837837, 0.306444081081081], 
             UndirectedEdge[26, 82] -> 
             RGBColor[
              0.5494944189189189, 0.6222451756756757, 0.9628692567567567], 
             UndirectedEdge[43, 165] -> 
             RGBColor[
              0.9655073918918919, 0.9710642162162162, 0.7901937702702704], 
             UndirectedEdge[123, 199] -> 
             RGBColor[
              0.5736957702702703, 0.6406977432432432, 0.9358832432432432], 
             UndirectedEdge[34, 45] -> 
             RGBColor[
              0.9947190405405406, 0.9913714594594594, 0.6853738513513514], 
             UndirectedEdge[133, 178] -> 
             RGBColor[
              0.9378182567567568, 0.9484148918918919, 0.739717189189189], 
             UndirectedEdge[29, 189] -> 
             RGBColor[
              0.9659656486486486, 0.8931348648648649, 0.34166460810810806`], 
             UndirectedEdge[91, 164] -> 
             RGBColor[
              0.9106795405405406, 0.9316151621621622, 0.9913426216216217], 
             UndirectedEdge[116, 124] -> 
             RGBColor[
              0.9648314189189189, 0.9696183783783784, 0.7166182837837838], 
             UndirectedEdge[80, 113] -> 
             RGBColor[
              0.9947190405405406, 0.9913714594594594, 0.6853738513513514], 
             UndirectedEdge[10, 75] -> 
             RGBColor[
              0.8919149459459459, 0.9166527837837839, 0.9895528378378378], 
             UndirectedEdge[74, 180] -> 
             RGBColor[
              0.9817148648648649, 0.9498893783783784, 0.39134940540540536`], 
             UndirectedEdge[27, 149] -> 
             RGBColor[
              0.5485683513513513, 0.5094148783783783, 0.5932744054054054], 
             UndirectedEdge[4, 49] -> 
             RGBColor[
              0.965995945945946, 0.9723677567567568, 0.8621653783783785], 
             UndirectedEdge[9, 152] -> 
             RGBColor[
              0.951344581081081, 0.9460781891891892, 0.6896241891891891], 
             UndirectedEdge[19, 85] -> 
             RGBColor[0.9706776621621622, 0.918223, 0.5511407027027027], 
             UndirectedEdge[189, 197] -> 
             RGBColor[
              0.9391837567567567, 0.7965908918918919, 0.269924027027027], 
             UndirectedEdge[69, 195] -> 
             RGBColor[
              0.9562948513513514, 0.8675862432432433, 0.5708187567567569], 
             UndirectedEdge[75, 191] -> 
             RGBColor[
              0.9284359594594596, 0.9409337027027027, 0.7388222972972971], 
             UndirectedEdge[73, 75] -> 
             RGBColor[
              0.9003888378378379, 0.9233758378378378, 0.9891893108108107], 
             UndirectedEdge[68, 188] -> 
             RGBColor[
              0.9580932297297298, 0.868329918918919, 0.541014972972973], 
             UndirectedEdge[4, 123] -> 
             RGBColor[
              0.9817234054054054, 0.9840972702702703, 0.8355428918918919], 
             UndirectedEdge[7, 84] -> 
             RGBColor[
              0.5494944189189189, 0.6222451756756757, 0.9628692567567567], 
             UndirectedEdge[171, 195] -> 
             RGBColor[
              0.9693637297297297, 0.9763733243243243, 0.9233635945945946], 
             UndirectedEdge[62, 167] -> 
             RGBColor[
              0.9906029729729731, 0.9798710540540541, 0.42587802702702693`], 
             UndirectedEdge[91, 152] -> 
             RGBColor[
              0.951344581081081, 0.9460781891891892, 0.6896241891891891], 
             UndirectedEdge[38, 90] -> 
             RGBColor[
              0.9737392162162162, 0.9230783513513514, 0.35248224324324323`], 
             UndirectedEdge[3, 118] -> 
             RGBColor[
              0.9113468783783785, 0.8836590540540541, 0.6409013513513513], 
             UndirectedEdge[143, 181] -> 
             RGBColor[
              0.9421887297297298, 0.7999060810810811, 0.313370554054054], 
             UndirectedEdge[20, 50] -> 
             RGBColor[
              0.969778472972973, 0.9178511621621622, 0.5660425945945946], 
             UndirectedEdge[128, 136] -> 
             RGBColor[
              0.9924700135135135, 0.9896638918918919, 0.6661273108108107], 
             UndirectedEdge[19, 161] -> 
             RGBColor[
              0.9724760405405406, 0.9189666756756758, 0.521336918918919], 
             UndirectedEdge[19, 140] -> 
             RGBColor[0.973112, 0.918516918918919, 0.4589885810810811], 
             UndirectedEdge[39, 159] -> 
             RGBColor[
              0.987271554054054, 0.9807612432432433, 0.645934581081081], 
             UndirectedEdge[87, 154] -> 
             RGBColor[0.9711621081081081, 0.977117, 0.8935598108108107], 
             UndirectedEdge[104, 143] -> 
             RGBColor[
              0.9465678243243243, 0.818728918918919, 0.5160790540540541], 
             UndirectedEdge[6, 183] -> 
             RGBColor[
              0.9754207432432431, 0.9407856756756756, 0.5998964189189189], 
             UndirectedEdge[17, 89] -> 
             RGBColor[
              0.9931838918918918, 0.9914493783783784, 0.7626240810810812], 
             UndirectedEdge[131, 176] -> 
             RGBColor[
              0.9724360270270271, 0.9170710810810812, 0.3854130945945945], 
             UndirectedEdge[44, 143] -> 
             RGBColor[
              0.9476523243243243, 0.8176871081081081, 0.3897784999999999], 
             UndirectedEdge[140, 173] -> 
             RGBColor[
              0.9929206621621621, 0.9906277837837838, 0.7151776351351351], 
             UndirectedEdge[123, 195] -> 
             RGBColor[
              0.9772274594594594, 0.9822380810810811, 0.9100523513513514], 
             UndirectedEdge[96, 125] -> 
             RGBColor[
              0.9910536216216217, 0.980834945945946, 0.4749283513513512], 
             UndirectedEdge[95, 159] -> 
             RGBColor[
              0.957576027027027, 0.8598728108108109, 0.3349141216216216], 
             UndirectedEdge[171, 191] -> 
             RGBColor[
              0.972920472972973, 0.9759650810810812, 0.7278322027027025], 
             UndirectedEdge[124, 187] -> 
             RGBColor[
              0.5579683108108108, 0.6289682297297298, 0.9625057297297297], 
             UndirectedEdge[54, 191] -> 
             RGBColor[0.9913455, 0.9888101081081082, 0.6565040405405405], 
             UndirectedEdge[24, 55] -> 
             RGBColor[
              0.9789774864864864, 0.9403774324324323, 0.4043650270270268], 
             UndirectedEdge[61, 126] -> 
             RGBColor[
              0.972920472972973, 0.9759650810810812, 0.7278322027027025], 
             UndirectedEdge[46, 101] -> 
             RGBColor[
              0.5869167297297297, 0.6484538783783784, 0.8102393648648649], 
             UndirectedEdge[158, 176] -> 
             RGBColor[
              0.9789774864864864, 0.9403774324324323, 0.4043650270270268], 
             UndirectedEdge[91, 200] -> 
             RGBColor[
              0.9565828513513513, 0.9633772702702703, 0.7415069729729729], 
             UndirectedEdge[29, 129] -> 
             RGBColor[
              0.9701604594594595, 0.9097658918918919, 0.3450398513513513], 
             UndirectedEdge[37, 47] -> 
             RGBColor[
              0.8934198378378377, 0.9172105945945945, 0.9674326621621622], 
             UndirectedEdge[25, 38] -> 
             RGBColor[
              0.9667130405405405, 0.9657275135135135, 0.694114581081081], 
             UndirectedEdge[95, 173] -> 
             RGBColor[
              0.958992418918919, 0.8687017567567568, 0.526113081081081], 
             UndirectedEdge[86, 174] -> 
             RGBColor[
              0.9678138108108107, 0.9030905675675676, 0.3294631621621621], 
             UndirectedEdge[4, 146] -> 
             RGBColor[
              0.9565959864864866, 0.8528144054054053, 0.4929340540540541], 
             UndirectedEdge[114, 186] -> 
             RGBColor[
              0.9920214729729729, 0.9902559459459459, 0.730079527027027], 
             UndirectedEdge[155, 199] -> 
             RGBColor[
              0.5119652297297298, 0.592320418918919, 0.9592896891891892], 
             UndirectedEdge[114, 194] -> 
             RGBColor[
              0.9904863243243243, 0.990333864864865, 0.8073297567567568], 
             UndirectedEdge[59, 186] -> 
             RGBColor[
              0.9826161621621622, 0.9518171621621623, 0.48945005405405406`], 
             UndirectedEdge[99, 193] -> 
             RGBColor[
              0.5736957702702703, 0.6406977432432432, 0.9358832432432432], 
             UndirectedEdge[109, 136] -> 
             RGBColor[
              0.9516872972972973, 0.834397891891892, 0.3930620405405404], 
             UndirectedEdge[50, 134] -> 
             RGBColor[
              0.9886879459459459, 0.9895901891891892, 0.8371335405405405], 
             UndirectedEdge[112, 183] -> 
             RGBColor[
              0.9548622297297297, 0.9257519459459459, 0.6480764189189188], 
             UndirectedEdge[42, 73] -> 
             RGBColor[
              0.9648314189189189, 0.9696183783783784, 0.7166182837837838], 
             UndirectedEdge[42, 147] -> 
             RGBColor[
              0.9884226081081081, 0.9872126486486487, 0.6766845540540539], 
             UndirectedEdge[87, 131] -> 
             RGBColor[
              0.9522526351351351, 0.905377972972973, 0.6224688648648649], 
             UndirectedEdge[1, 11] -> 
             RGBColor[
              0.5837398648648648, 0.6392209054054054, 0.671765472972973], 
             UndirectedEdge[30, 81] -> 
             RGBColor[
              0.9143095810810811, 0.8936529459459459, 0.6524108918918918], 
             UndirectedEdge[154, 188] -> 
             RGBColor[
              0.9895871351351351, 0.9899620270270271, 0.8222316486486486], 
             UndirectedEdge[83, 156] -> 
             RGBColor[
              0.9895471216216216, 0.9880664324324324, 0.6863078243243242], 
             UndirectedEdge[5, 107] -> 
             RGBColor[
              0.5653475945945946, 0.5759389864864866, 0.6067753783783785], 
             UndirectedEdge[93, 180] -> 
             RGBColor[
              0.9656886621621621, 0.9416105945945947, 0.6462747162162162], 
             UndirectedEdge[10, 17] -> 
             RGBColor[
              0.9575220540540541, 0.9656447027027026, 0.8625289054054055], 
             UndirectedEdge[75, 141] -> 
             RGBColor[
              0.9231976891891892, 0.9236346216216216, 0.6869395135135135], 
             UndirectedEdge[123, 141] -> 
             RGBColor[
              0.9755459324324325, 0.9645307567567567, 0.6626381756756756], 
             UndirectedEdge[40, 119] -> 
             RGBColor[
              0.9521000405405405, 0.8509552162162162, 0.5674435135135135], 
             UndirectedEdge[16, 80] -> 
             RGBColor[
              0.9949822702702703, 0.992193054054054, 0.7328202972972975], 
             UndirectedEdge[88, 180] -> 
             RGBColor[
              0.9538930675675676, 0.9328134594594595, 0.6662415810810811], 
             UndirectedEdge[24, 41] -> 
             RGBColor[
              0.9819401891891892, 0.9503713243243244, 0.41587456756756747`], 
             UndirectedEdge[4, 119] -> 
             RGBColor[
              0.9565959864864866, 0.8528144054054053, 0.4929340540540541], 
             UndirectedEdge[99, 136] -> 
             RGBColor[
              0.5862407567567567, 0.6470080405405405, 0.7366638783783783], 
             UndirectedEdge[10, 194] -> 
             RGBColor[
              0.9557236756756756, 0.9649010270270271, 0.8923326891891892], 
             UndirectedEdge[96, 102] -> 
             RGBColor[0.9917675, 0.9826204324324324, 0.5714251216216217], 
             UndirectedEdge[9, 88] -> 
             RGBColor[
              0.9285357297297296, 0.9458194054054054, 0.9918739864864865], 
             UndirectedEdge[55, 108] -> 
             RGBColor[
              0.9781183108108107, 0.9419011891891891, 0.5551907432432431], 
             UndirectedEdge[62, 197] -> 
             RGBColor[
              0.9617708378378378, 0.8765038378378378, 0.3382893648648648], 
             UndirectedEdge[147, 168] -> 
             RGBColor[0.5815595, 0.6465625, 0.922572], 
             UndirectedEdge[51, 106] -> 
             RGBColor[
              0.9863723648648648, 0.9803894054054054, 0.660836472972973], 
             UndirectedEdge[123, 155] -> 
             RGBColor[0.906734, 0.9276241621621621, 0.9616719324324324], 
             UndirectedEdge[75, 142] -> 
             RGBColor[
              0.9003888378378379, 0.9233758378378378, 0.9891893108108107], 
             UndirectedEdge[31, 182] -> 
             RGBColor[
              0.5860154324324325, 0.6465260945945946, 0.712138716216216], 
             UndirectedEdge[65, 140] -> 
             RGBColor[
              0.9940051621621622, 0.989585972972973, 0.5888770810810809]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 71 -> 
             RGBColor[
              0.9877887567567567, 0.9892183513513514, 0.8520354324324323], 10 -> 
             RGBColor[
              0.9200618378378378, 0.9390963513513514, 0.9922375135135135], 68 -> 
             RGBColor[
              0.9265993243243243, 0.7466978108108109, 0.2597982972972973], 
             155 -> RGBColor[
              0.8450034594594595, 0.8792468378378379, 0.9850783783783784], 
             132 -> RGBColor[
              0.9433785675675675, 0.8132219189189189, 0.27329927027027023`], 
             26 -> RGBColor[
              0.9200618378378378, 0.9390963513513514, 0.9922375135135135], 29 -> 
             RGBColor[
              0.9885527297297297, 0.9730478108108108, 0.4100299459459459], 
             113 -> RGBColor[
              0.9944558108108108, 0.9905498648648648, 0.6379274054054054], 50 -> 
             RGBColor[
              0.9877887567567567, 0.9892183513513514, 0.8520354324324323], 
             173 -> RGBColor[
              0.9913855135135134, 0.9907057027027028, 0.7924278648648648], 
             192 -> RGBColor[
              0.9370096216216216, 0.9525424594594595, 0.9915104594594595], 
             165 -> RGBColor[
              0.9940051621621622, 0.989585972972973, 0.5888770810810812], 92 -> 
             RGBColor[
              0.9200618378378378, 0.9390963513513514, 0.9922375135135135], 11 -> 
             RGBColor[
              0.9885527297297297, 0.9730478108108108, 0.4100299459459459], 
             137 -> RGBColor[
              0.9895871351351351, 0.9899620270270271, 0.8222316486486486], 
             120 -> RGBColor[
              0.9944558108108108, 0.9905498648648648, 0.6379274054054054], 51 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 72 -> 
             RGBColor[
              0.9877887567567567, 0.9892183513513514, 0.8520354324324323], 64 -> 
             RGBColor[
              0.8637680540540541, 0.8942092162162163, 0.9868681621621621], 41 -> 
             RGBColor[
              0.9707765135135136, 0.9130844594594596, 0.3409727027027028], 
             103 -> RGBColor[0.178927, 0.305394, 0.933501], 162 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 196 -> 
             RGBColor[
              0.9913855135135134, 0.9907057027027028, 0.7924278648648648], 
             179 -> RGBColor[
              0.9826273243243243, 0.953060027027027, 0.3870108648648647], 160 -> 
             RGBColor[
              0.9949822702702703, 0.992193054054054, 0.7328202972972975], 123 -> 
             RGBColor[
              0.9684645405405405, 0.9760014864864865, 0.9382654864864864], 
             150 -> RGBColor[
              0.8825326486486486, 0.9091715945945945, 0.9886579459459459], 
             188 -> RGBColor[
              0.9895871351351351, 0.9899620270270271, 0.8222316486486486], 46 -> 
             RGBColor[
              0.9949064594594594, 0.9915137567567568, 0.6869777297297297], 
             182 -> RGBColor[0.178927, 0.305394, 0.933501], 6 -> 
             RGBColor[
              0.9859903783783783, 0.9884746756756757, 0.8818392162162163], 
             131 -> RGBColor[
              0.9517681891891893, 0.8464839729729731, 0.28004975675675675`], 
             45 -> RGBColor[
              0.9949822702702703, 0.992193054054054, 0.7328202972972975], 195 -> 
             RGBColor[
              0.9859903783783783, 0.9884746756756757, 0.8818392162162163], 
             148 -> RGBColor[
              0.8825326486486486, 0.9091715945945945, 0.9886579459459459], 
             161 -> RGBColor[
              0.9931838918918918, 0.9914493783783784, 0.7626240810810812], 1 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 101 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 12 -> 
             RGBColor[
              0.964851108108108, 0.8930966756756755, 0.31795362162162144`], 
             39 -> RGBColor[
              0.9859903783783783, 0.9884746756756757, 0.8818392162162163], 48 -> 
             RGBColor[
              0.9012972432432432, 0.924133972972973, 0.9904477297297297], 77 -> 
             RGBColor[
              0.964851108108108, 0.8930966756756755, 0.31795362162162144`], 
             56 -> RGBColor[
              0.596376054054054, 0.683203972972973, 0.961368054054054], 110 -> 
             RGBColor[
              0.9606008108108107, 0.9701367297297298, 0.9515767297297297], 73 -> 
             RGBColor[
              0.9370096216216216, 0.9525424594594595, 0.9915104594594595], 37 -> 
             RGBColor[
              0.9606008108108107, 0.9701367297297298, 0.9515767297297297], 
             130 -> RGBColor[
              0.9859903783783783, 0.9884746756756757, 0.8818392162162163], 
             107 -> RGBColor[0.178927, 0.305394, 0.933501], 59 -> 
             RGBColor[
              0.9707765135135136, 0.9130844594594596, 0.3409727027027028], 47 -> 
             RGBColor[
              0.8262388648648649, 0.8642844594594594, 0.9832885945945946], 
             159 -> 
             RGBColor[
              0.9885527297297297, 0.9730478108108108, 0.4100299459459459], 55 -> 
             RGBColor[
              0.964851108108108, 0.8930966756756755, 0.31795362162162144`], 
             49 -> RGBColor[
              0.9370096216216216, 0.9525424594594595, 0.9915104594594595], 82 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 199 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 89 -> 
             RGBColor[
              0.9913855135135134, 0.9907057027027028, 0.7924278648648648], 
             144 -> RGBColor[
              0.9589257027027027, 0.8731088918918919, 0.2949345405405406], 78 -> 
             RGBColor[
              0.9200618378378378, 0.9390963513513514, 0.9922375135135135], 42 -> 
             RGBColor[
              0.9926532162162163, 0.9866942972972973, 0.4417261081081079], 
             154 -> RGBColor[
              0.9895871351351351, 0.9899620270270271, 0.8222316486486486], 
             168 -> RGBColor[0.178927, 0.305394, 0.933501], 121 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 128 -> 
             RGBColor[
              0.9913855135135134, 0.9907057027027028, 0.7924278648648648], 
             115 -> RGBColor[
              0.9940051621621622, 0.989585972972973, 0.5888770810810812], 61 -> 
             RGBColor[
              0.952737081081081, 0.964271972972973, 0.9648879729729729], 93 -> 
             RGBColor[
              0.9606008108108107, 0.9701367297297298, 0.9515767297297297], 88 -> 
             RGBColor[
              0.9370096216216216, 0.9525424594594595, 0.9915104594594595], 21 -> 
             RGBColor[
              0.9926532162162163, 0.9866942972972973, 0.4417261081081079], 62 -> 
             RGBColor[
              0.9885527297297297, 0.9730478108108108, 0.4100299459459459], 
             136 -> RGBColor[
              0.9935545135135135, 0.9886220810810811, 0.5398267567567565], 
             190 -> RGBColor[
              0.8450034594594595, 0.8792468378378379, 0.9850783783783784], 57 -> 
             RGBColor[
              0.964851108108108, 0.8930966756756755, 0.31795362162162144`], 
             111 -> RGBColor[
              0.9265993243243243, 0.7466978108108109, 0.2597982972972973], 63 -> 
             RGBColor[
              0.9926532162162163, 0.9866942972972973, 0.4417261081081079], 75 -> 
             RGBColor[
              0.8637680540540541, 0.8942092162162163, 0.9868681621621621], 30 -> 
             RGBColor[
              0.8637680540540541, 0.8942092162162163, 0.9868681621621621], 5 -> 
             RGBColor[
              0.9517681891891893, 0.8464839729729731, 0.28004975675675675`], 
             171 -> RGBColor[
              0.952737081081081, 0.964271972972973, 0.9648879729729729], 102 -> 
             RGBColor[
              0.9949822702702703, 0.992193054054054, 0.7328202972972975], 31 -> 
             RGBColor[
              0.9931038648648649, 0.9876581891891892, 0.4907764324324322], 96 -> 
             RGBColor[
              0.9885527297297297, 0.9730478108108108, 0.4100299459459459], 70 -> 
             RGBColor[
              0.9826273243243243, 0.953060027027027, 0.3870108648648647], 52 -> 
             RGBColor[
              0.9885527297297297, 0.9730478108108108, 0.4100299459459459], 
             183 -> RGBColor[
              0.964851108108108, 0.8930966756756755, 0.31795362162162144`], 
             158 -> RGBColor[
              0.964851108108108, 0.8930966756756755, 0.31795362162162144`], 
             13 -> RGBColor[0.984192, 0.987731, 0.911643], 170 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 86 -> 
             RGBColor[
              0.9707765135135136, 0.9130844594594596, 0.3409727027027028], 18 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 153 -> 
             RGBColor[
              0.9017501351351351, 0.6467521351351352, 0.23973024324324327`], 
             58 -> RGBColor[
              0.9707765135135136, 0.9130844594594596, 0.3409727027027028], 22 -> 
             RGBColor[
              0.9433785675675675, 0.8132219189189189, 0.27329927027027023`], 
             66 -> RGBColor[
              0.9949822702702703, 0.992193054054054, 0.7328202972972975], 143 -> 
             RGBColor[
              0.9017501351351351, 0.6467521351351352, 0.23973024324324327`], 
             119 -> RGBColor[
              0.9182097027027027, 0.7134357567567566, 0.2530478108108108], 
             145 -> RGBColor[
              0.9949064594594594, 0.9915137567567568, 0.6869777297297297], 91 -> 
             RGBColor[
              0.9200618378378378, 0.9390963513513514, 0.9922375135135135], 
             177 -> RGBColor[
              0.934988945945946, 0.7799598648648649, 0.26654878378378377`], 
             200 -> RGBColor[
              0.9931038648648649, 0.9876581891891892, 0.4907764324324322], 
             114 -> RGBColor[
              0.9895871351351351, 0.9899620270270271, 0.8222316486486486], 24 -> 
             RGBColor[
              0.9931038648648649, 0.9876581891891892, 0.4907764324324322], 
             176 -> RGBColor[
              0.9931038648648649, 0.9876581891891892, 0.4907764324324322], 79 -> 
             RGBColor[
              0.9931038648648649, 0.9876581891891892, 0.4907764324324322], 
             109 -> RGBColor[
              0.909820081081081, 0.6801737027027027, 0.24629732432432433`], 
             135 -> RGBColor[
              0.8239815945945946, 0.1853386216216215, 0.1705981081081081], 
             108 -> RGBColor[
              0.9913855135135134, 0.9907057027027028, 0.7924278648648648], 
             191 -> RGBColor[
              0.9931038648648649, 0.9876581891891892, 0.4907764324324322], 14 -> 
             RGBColor[
              0.9767019189189189, 0.9330722432432432, 0.36399178378378366`], 
             185 -> RGBColor[
              0.9707765135135136, 0.9130844594594596, 0.3409727027027028], 32 -> 
             RGBColor[
              0.7143691351351351, 0.7767898648648649, 0.9721652972972973], 
             122 -> RGBColor[
              0.9895871351351351, 0.9899620270270271, 0.8222316486486486], 
             187 -> RGBColor[0.178927, 0.305394, 0.933501], 193 -> 
             RGBColor[
              0.9684645405405405, 0.9760014864864865, 0.9382654864864864], 
             100 -> RGBColor[
              0.9926532162162163, 0.9866942972972973, 0.4417261081081079], 
             180 -> RGBColor[
              0.9707765135135136, 0.9130844594594596, 0.3409727027027028], 7 -> 
             RGBColor[
              0.9200618378378378, 0.9390963513513514, 0.9922375135135135], 
             175 -> RGBColor[
              0.9931838918918918, 0.9914493783783784, 0.7626240810810812], 9 -> 
             RGBColor[
              0.9200618378378378, 0.9390963513513514, 0.9922375135135135], 90 -> 
             RGBColor[
              0.9589257027027027, 0.8731088918918919, 0.2949345405405406], 
             174 -> RGBColor[
              0.964851108108108, 0.8930966756756755, 0.31795362162162144`], 
             142 -> RGBColor[
              0.9370096216216216, 0.9525424594594595, 0.9915104594594595], 
             134 -> RGBColor[
              0.9895871351351351, 0.9899620270270271, 0.8222316486486486], 
             105 -> RGBColor[
              0.9926532162162163, 0.9866942972972973, 0.4417261081081079], 16 -> 
             RGBColor[
              0.9949822702702703, 0.992193054054054, 0.7328202972972975], 139 -> 
             RGBColor[
              0.8450034594594595, 0.8792468378378379, 0.9850783783783784], 
             146 -> RGBColor[
              0.9182097027027027, 0.7134357567567566, 0.2530478108108108], 
             126 -> RGBColor[
              0.9931038648648649, 0.9876581891891892, 0.4907764324324322], 
             198 -> 
             RGBColor[
              0.9949822702702703, 0.992193054054054, 0.7328202972972975], 40 -> 
             RGBColor[
              0.9859903783783783, 0.9884746756756757, 0.8818392162162163], 
             104 -> RGBColor[
              0.9913855135135134, 0.9907057027027028, 0.7924278648648648], 
             181 -> RGBColor[
              0.9826273243243243, 0.953060027027027, 0.3870108648648647], 127 -> 
             RGBColor[
              0.9895871351351351, 0.9899620270270271, 0.8222316486486486], 76 -> 
             RGBColor[
              0.9949064594594594, 0.9915137567567568, 0.6869777297297297], 
             172 -> RGBColor[0.178927, 0.305394, 0.933501], 84 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 184 -> 
             RGBColor[
              0.9931838918918918, 0.9914493783783784, 0.7626240810810812], 
             151 -> RGBColor[
              0.9707765135135136, 0.9130844594594596, 0.3409727027027028], 35 -> 
             RGBColor[
              0.9949064594594594, 0.9915137567567568, 0.6869777297297297], 36 -> 
             RGBColor[
              0.9182097027027027, 0.7134357567567566, 0.2530478108108108], 34 -> 
             RGBColor[
              0.9944558108108108, 0.9905498648648648, 0.6379274054054054], 38 -> 
             RGBColor[
              0.9885527297297297, 0.9730478108108108, 0.4100299459459459], 54 -> 
             RGBColor[
              0.9895871351351351, 0.9899620270270271, 0.8222316486486486], 60 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 87 -> 
             RGBColor[
              0.952737081081081, 0.964271972972973, 0.9648879729729729], 141 -> 
             RGBColor[
              0.9826273243243243, 0.953060027027027, 0.3870108648648647], 67 -> 
             RGBColor[
              0.9012972432432432, 0.924133972972973, 0.9904477297297297], 133 -> 
             RGBColor[
              0.8825326486486486, 0.9091715945945945, 0.9886579459459459], 98 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 3 -> 
             RGBColor[
              0.9589257027027027, 0.8731088918918919, 0.2949345405405406], 27 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 163 -> 
             RGBColor[
              0.9265993243243243, 0.7466978108108109, 0.2597982972972973], 85 -> 
             RGBColor[
              0.9895871351351351, 0.9899620270270271, 0.8222316486486486], 83 -> 
             RGBColor[
              0.9859903783783783, 0.9884746756756757, 0.8818392162162163], 28 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 44 -> 
             RGBColor[
              0.9935545135135135, 0.9886220810810811, 0.5398267567567565], 
             189 -> RGBColor[
              0.9433785675675675, 0.8132219189189189, 0.27329927027027023`], 
             15 -> RGBColor[
              0.9940051621621622, 0.989585972972973, 0.5888770810810812], 80 -> 
             RGBColor[
              0.9949822702702703, 0.992193054054054, 0.7328202972972975], 112 -> 
             RGBColor[
              0.9448733513513513, 0.9584072162162163, 0.9781992162162162], 
             169 -> RGBColor[
              0.9448733513513513, 0.9584072162162163, 0.9781992162162162], 69 -> 
             RGBColor[
              0.9265993243243243, 0.7466978108108109, 0.2597982972972973], 20 -> 
             RGBColor[
              0.9517681891891893, 0.8464839729729731, 0.28004975675675675`], 
             8 -> RGBColor[
              0.934988945945946, 0.7799598648648649, 0.26654878378378377`], 
             116 -> RGBColor[
              0.9926532162162163, 0.9866942972972973, 0.4417261081081079], 97 -> 
             RGBColor[
              0.9767019189189189, 0.9330722432432432, 0.36399178378378366`], 
             118 -> RGBColor[
              0.8637680540540541, 0.8942092162162163, 0.9868681621621621], 
             178 -> RGBColor[
              0.9931038648648649, 0.9876581891891892, 0.4907764324324322], 81 -> 
             RGBColor[
              0.964851108108108, 0.8930966756756755, 0.31795362162162144`], 
             166 -> RGBColor[
              0.9885527297297297, 0.9730478108108108, 0.4100299459459459], 
             125 -> RGBColor[
              0.9935545135135135, 0.9886220810810811, 0.5398267567567565], 95 -> 
             RGBColor[
              0.9265993243243243, 0.7466978108108109, 0.2597982972972973], 
             157 -> RGBColor[
              0.8825326486486486, 0.9091715945945945, 0.9886579459459459], 74 -> 
             RGBColor[
              0.9926532162162163, 0.9866942972972973, 0.4417261081081079], 19 -> 
             RGBColor[
              0.9517681891891893, 0.8464839729729731, 0.28004975675675675`], 
             156 -> RGBColor[
              0.9931038648648649, 0.9876581891891892, 0.4907764324324322], 
             167 -> RGBColor[
              0.9926532162162163, 0.9866942972972973, 0.4417261081081079], 33 -> 
             RGBColor[
              0.8262388648648649, 0.8642844594594594, 0.9832885945945946], 43 -> 
             RGBColor[
              0.9370096216216216, 0.9525424594594595, 0.9915104594594595], 
             140 -> RGBColor[
              0.9944558108108108, 0.9905498648648648, 0.6379274054054054], 
             186 -> RGBColor[
              0.9944558108108108, 0.9905498648648648, 0.6379274054054054], 
             117 -> RGBColor[
              0.9826273243243243, 0.953060027027027, 0.3870108648648647], 4 -> 
             RGBColor[
              0.9949822702702703, 0.992193054054054, 0.7328202972972975], 106 -> 
             RGBColor[
              0.9885527297297297, 0.9730478108108108, 0.4100299459459459], 65 -> 
             RGBColor[
              0.9935545135135135, 0.9886220810810811, 0.5398267567567565], 53 -> 
             RGBColor[
              0.9931038648648649, 0.9876581891891892, 0.4907764324324322], 2 -> 
             RGBColor[
              0.9606008108108107, 0.9701367297297298, 0.9515767297297297], 
             147 -> RGBColor[0.984192, 0.987731, 0.911643], 94 -> 
             RGBColor[
              0.8637680540540541, 0.8942092162162163, 0.9868681621621621], 23 -> 
             RGBColor[
              0.9885527297297297, 0.9730478108108108, 0.4100299459459459], 
             194 -> RGBColor[
              0.9913855135135134, 0.9907057027027028, 0.7924278648648648], 
             129 -> RGBColor[
              0.9517681891891893, 0.8464839729729731, 0.28004975675675675`], 
             99 -> RGBColor[0.178927, 0.305394, 0.933501], 25 -> 
             RGBColor[
              0.9448733513513513, 0.9584072162162163, 0.9781992162162162], 
             138 -> RGBColor[0.984192, 0.987731, 0.911643], 124 -> 
             RGBColor[
              0.9370096216216216, 0.9525424594594595, 0.9915104594594595], 
             197 -> RGBColor[
              0.934988945945946, 0.7799598648648649, 0.26654878378378377`], 
             164 -> RGBColor[
              0.9012972432432432, 0.924133972972973, 0.9904477297297297], 152 -> 
             RGBColor[
              0.9826273243243243, 0.953060027027027, 0.3870108648648647], 17 -> 
             RGBColor[
              0.9949822702702703, 0.992193054054054, 0.7328202972972975], 149 -> 
             RGBColor[
              0.9182097027027027, 0.7134357567567566, 
               0.2530478108108108]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw1Vnk41Iv7HWbGjH3MjDGYYWbMlDYVokV9jgp1K023DRVaCFlSpNQNyVKW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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 11}], {
             RGBColor[
             0.5837398648648648, 0.6392209054054054, 0.671765472972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 35}], {
             RGBColor[
             0.5869167297297297, 0.6484538783783784, 0.8102393648648649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 86}], {
             RGBColor[
             0.5748517567567568, 0.6092392297297298, 0.6372368513513514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 94}], {
             RGBColor[
             0.5213475270270271, 0.5998016081081081, 0.9601845810810811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 174}], {
             RGBColor[
             0.571889054054054, 0.5992453378378377, 0.6257273108108108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 196}], {
             RGBColor[
             0.5851562567567568, 0.6480498513513513, 0.8629644324324324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 16}], {
             RGBColor[
             0.9777915405405405, 0.9811648918918918, 0.8421985135135136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 52}], {
             RGBColor[
             0.9745767702702702, 0.9715922702702703, 0.6808033378378378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[
             0.9777915405405405, 0.9811648918918918, 0.8421985135135136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 78}], {
             RGBColor[
             0.9403313243243243, 0.9546165405405406, 0.9719071216216216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 80}], {
             RGBColor[
             0.9777915405405405, 0.9811648918918918, 0.8421985135135136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 82}], {
             RGBColor[
             0.5697639054054053, 0.6377653648648649, 0.9425388648648649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 98}], {
             RGBColor[
             0.5697639054054053, 0.6377653648648649, 0.9425388648648649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 100}], {
             RGBColor[
             0.9766270135135136, 0.9784155135135135, 0.6966514189189188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 120}], {
             RGBColor[
             0.9775283108108108, 0.9803432972972973, 0.7947520675675676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 124}], {
             RGBColor[
             0.9488052162162162, 0.9613395945945946, 0.9715435945945946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 187}], {
             RGBColor[
             0.5697639054054053, 0.6377653648648649, 0.9425388648648649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 5}], {
             RGBColor[
             0.955346945945946, 0.8597964324324325, 0.2874921486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 10}], {
             RGBColor[
             0.9394937702702703, 0.9061026216216217, 0.643586027027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 27}], {
             RGBColor[
             0.5689263513513514, 0.5892514459459459, 0.6142177702702702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 29}], {
             RGBColor[
             0.9737392162162162, 0.9230783513513514, 0.35248224324324323`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 49}], {
             RGBColor[0.9479676621621622, 0.9128256756756756, 0.6432225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 53}], {
             RGBColor[
             0.9760147837837838, 0.9303835405405405, 0.3928554864864864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 62}], {
             RGBColor[
             0.9737392162162162, 0.9230783513513514, 0.35248224324324323`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 68}], {
             RGBColor[
             0.9427625135135136, 0.8099033513513514, 0.27736641891891894`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 71}], {
             RGBColor[
             0.9733572297297297, 0.9311636216216217, 0.5734849864864864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 75}], {
             RGBColor[
             0.9113468783783785, 0.8836590540540541, 0.6409013513513513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 118}], {
             RGBColor[
             0.9113468783783785, 0.8836590540540541, 0.6409013513513513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[
             0.9636951216216216, 0.9245551891891892, 0.6166000135135135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 127}], {
             RGBColor[
             0.9742564189189189, 0.9315354594594595, 0.5585830945945947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 129}], {
             RGBColor[
             0.955346945945946, 0.8597964324324325, 0.2874921486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 139}], {
             RGBColor[
             0.9019645810810811, 0.8761778648648648, 0.6400064594594594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 141}], {
             RGBColor[
             0.9707765135135136, 0.9130844594594594, 0.34097270270270263`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 146}], {
             RGBColor[
             0.9385677027027027, 0.7932723243243243, 0.27399117567567566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 155}], {
             RGBColor[
             0.9019645810810811, 0.8761778648648648, 0.6400064594594594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 167}], {
             RGBColor[
             0.9757894594594595, 0.9299015945945945, 0.3683303243243242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 191}], {
             RGBColor[
             0.9760147837837838, 0.9303835405405405, 0.3928554864864864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 194}], {
             RGBColor[
             0.9751556081081081, 0.9319072972972973, 0.5436812027027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 195}], {
             RGBColor[
             0.9724580405405405, 0.9307917837837838, 0.5883868783783784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 34}], {
             RGBColor[
             0.9947190405405406, 0.9913714594594594, 0.6853738513513514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 40}], {
             RGBColor[
             0.9904863243243243, 0.9903338648648649, 0.8073297567567569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 49}], {
             RGBColor[
             0.965995945945946, 0.9723677567567568, 0.8621653783783785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 53}], {
             RGBColor[
             0.9940430675675676, 0.9899256216216217, 0.6117983648648648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 54}], {
             RGBColor[
             0.9922847027027026, 0.9910775405405405, 0.7775259729729731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 65}], {
             RGBColor[
             0.994268391891892, 0.9904075675675675, 0.636323527027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 69}], {
             RGBColor[
             0.9607907972972973, 0.8694454324324324, 0.4963092972972974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 86}], {
             RGBColor[
             0.9828793918918919, 0.9526387567567568, 0.5368965000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 92}], {
             RGBColor[
             0.9575220540540541, 0.9656447027027026, 0.8625289054054055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 118}], {
             RGBColor[
             0.9293751621621622, 0.9432011351351351, 0.8598442297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 119}], {
             RGBColor[
             0.9565959864864866, 0.8528144054054053, 0.4929340540540541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 123}], {
             RGBColor[
             0.9817234054054054, 0.9840972702702703, 0.8355428918918919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 139}], {
             RGBColor[
             0.919992864864865, 0.935719945945946, 0.8589493378378379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 146}], {
             RGBColor[
             0.9565959864864866, 0.8528144054054053, 0.4929340540540541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 171}], {
             RGBColor[
             0.9738596756756757, 0.9782325135135135, 0.8488541351351352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 182}], {
             RGBColor[
             0.5869546351351351, 0.648793527027027, 0.8331606486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 191}], {
             RGBColor[
             0.9940430675675676, 0.9899256216216217, 0.6117983648648648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 195}], {
             RGBColor[
             0.9904863243243243, 0.9903338648648649, 0.8073297567567569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 196}], {
             RGBColor[
             0.9931838918918918, 0.9914493783783784, 0.7626240810810812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 199}], {
             RGBColor[
             0.5869546351351351, 0.648793527027027, 0.8331606486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 10}], {
             RGBColor[
             0.9359150135135135, 0.8927901621621622, 0.636143635135135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 27}], {
             RGBColor[
             0.5653475945945946, 0.5759389864864866, 0.6067753783783785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.9701604594594595, 0.9097658918918919, 0.3450398513513513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 30}], {
             RGBColor[
             0.9077681216216217, 0.8703465945945947, 0.6334589594594595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 42}], {
             RGBColor[
             0.9722107027027027, 0.9165891351351352, 0.36088793243243233`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 68}], {
             RGBColor[
             0.9391837567567568, 0.796590891891892, 0.269924027027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 71}], {
             RGBColor[
             0.969778472972973, 0.9178511621621622, 0.5660425945945946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 73}], {
             RGBColor[
             0.9443889054054054, 0.8995132162162163, 0.635780108108108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 75}], {
             RGBColor[
             0.9077681216216217, 0.8703465945945947, 0.6334589594594595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 76}], {
             RGBColor[
             0.9733373243243244, 0.9189988648648649, 0.48351374324324325`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 81}], {
             RGBColor[
             0.9583096486486486, 0.8697903243243243, 0.2990016891891891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 87}], {
             RGBColor[
             0.9522526351351351, 0.905377972972973, 0.6224688648648649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 89}], {
             RGBColor[
             0.9715768513513514, 0.9185948378378379, 0.5362388108108107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 107}], {
             RGBColor[
             0.5653475945945946, 0.5759389864864866, 0.6067753783783785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 127}], {
             RGBColor[0.9706776621621622, 0.918223, 0.5511407027027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 129}], {
             RGBColor[
             0.9517681891891893, 0.8464839729729731, 0.28004975675675675`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 141}], {
             RGBColor[0.9671977567567568, 0.899772, 0.33353031081081075`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 142}], {
             RGBColor[
             0.9443889054054054, 0.8995132162162163, 0.635780108108108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 147}], {
             RGBColor[
             0.9679800945945947, 0.9171074864864865, 0.5958463783783783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 155}], {
             RGBColor[
             0.8983858243243243, 0.8628654054054055, 0.6325640675675677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 157}], {
             RGBColor[
             0.9171504189189189, 0.8778277837837838, 0.6343538513513514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 168}], {
             RGBColor[
             0.5653475945945946, 0.5759389864864866, 0.6067753783783785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 188}], {
             RGBColor[0.9706776621621622, 0.918223, 0.5511407027027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 197}], {
             RGBColor[
             0.9433785675675677, 0.8132219189189189, 0.27329927027027023`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 44}], {
             RGBColor[
             0.9897724459459459, 0.9885483783783784, 0.7108329864864864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 45}], {
             RGBColor[
             0.9904863243243243, 0.9903338648648649, 0.8073297567567569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 58}], {
             RGBColor[
             0.978383445945946, 0.9507795675675677, 0.6114059594594595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 77}], {
             RGBColor[
             0.9754207432432431, 0.9407856756756756, 0.5998964189189189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 83}], {
             RGBColor[
             0.9859903783783783, 0.9884746756756757, 0.8818392162162163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 96}], {
             RGBColor[
             0.987271554054054, 0.9807612432432433, 0.645934581081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 112}], {
             RGBColor[
             0.9654318648648648, 0.973440945945946, 0.9300192162162162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 156}], {
             RGBColor[
             0.9895471216216216, 0.9880664324324324, 0.6863078243243242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 166}], {
             RGBColor[
             0.987271554054054, 0.9807612432432433, 0.645934581081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 170}], {
             RGBColor[
             0.9016546891891892, 0.5613008378378379, 0.5230286081081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 179}], {
             RGBColor[
             0.9843088513513514, 0.9707673513513513, 0.6344250405405405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 183}], {
             RGBColor[
             0.9754207432432431, 0.9407856756756756, 0.5998964189189189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 192}], {
             RGBColor[0.9615, 0.9705085675675675, 0.9366748378378379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 8}], {
             RGBColor[
             0.9275253918918919, 0.8595281081081081, 0.6293931486486486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 16}], {
             RGBColor[
             0.9575220540540541, 0.9656447027027026, 0.8625289054054055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 52}], {
             RGBColor[
             0.9543072837837838, 0.9560720810810811, 0.7011337297297298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.9363994594594593, 0.9516841621621621, 0.9785627432432432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 67}], {
             RGBColor[
             0.9106795405405406, 0.9316151621621622, 0.9913426216216217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 79}], {
             RGBColor[
             0.9565828513513513, 0.9633772702702703, 0.7415069729729729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.5494944189189189, 0.6222451756756757, 0.9628692567567567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 122}], {
             RGBColor[
             0.9548244864864864, 0.9645291891891892, 0.9072345810810811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 125}], {
             RGBColor[
             0.9568081756756757, 0.9638592162162163, 0.766032135135135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 126}], {
             RGBColor[
             0.9565828513513513, 0.9633772702702703, 0.7415069729729729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 137}], {
             RGBColor[
             0.9548244864864864, 0.9645291891891892, 0.9072345810810811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 179}], {
             RGBColor[
             0.951344581081081, 0.9460781891891892, 0.6896241891891891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 192}], {
             RGBColor[
             0.9285357297297296, 0.9458194054054054, 0.9918739864864865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.9638210810810811, 0.8833270810810812, 0.3541374459459459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 26}], {
             RGBColor[
             0.9275253918918919, 0.8595281081081081, 0.6293931486486486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 61}], {
             RGBColor[
             0.9438630135135135, 0.8721159189189189, 0.6157183783783784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 67}], {
             RGBColor[
             0.9181430945945945, 0.8520469189189189, 0.6284982567567567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 79}], {
             RGBColor[
             0.9640464054054054, 0.8838090270270271, 0.378662608108108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.556957972972973, 0.5426769324324324, 0.6000248918918919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 83}], {
             RGBColor[
             0.9604896621621621, 0.8842172702702703, 0.5741940000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 122}], {
             RGBColor[
             0.9622880405405405, 0.884960945945946, 0.5443902162162162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 125}], {
             RGBColor[
             0.9642717297297297, 0.884290972972973, 0.40318777027027014`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 137}], {
             RGBColor[
             0.9622880405405405, 0.884960945945946, 0.5443902162162162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 166}], {
             RGBColor[
             0.9617708378378378, 0.8765038378378378, 0.3382893648648648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 170}], {
             RGBColor[
             0.876153972972973, 0.45704343243243245`, 0.21538339189189187`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 179}], {
             RGBColor[
             0.9588081351351352, 0.866509945945946, 0.32677982432432423`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 192}], {
             RGBColor[
             0.9359992837837838, 0.8662511621621622, 0.6290296216216216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 198}], {
             RGBColor[
             0.9649856081081081, 0.8860764594594595, 0.4996845405405406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 18}], {
             RGBColor[
             0.5494944189189189, 0.6222451756756757, 0.9628692567567567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 32}], {
             RGBColor[
             0.8172154864864865, 0.8579431081081081, 0.9822014054054053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 39}], {
             RGBColor[
             0.9530261081081081, 0.9637855135135136, 0.9370383648648649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 41}], {
             RGBColor[
             0.9454191756756757, 0.9260904054054055, 0.6666051081081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 57}], {
             RGBColor[
             0.942456472972973, 0.9160965135135135, 0.6550955675675675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 85}], {
             RGBColor[
             0.9548244864864864, 0.9645291891891892, 0.9072345810810811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 88}], {
             RGBColor[
             0.9285357297297296, 0.9458194054054054, 0.9918739864864865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 91}], {
             RGBColor[
             0.9200618378378378, 0.9390963513513514, 0.9922375135135135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 103}], {
             RGBColor[
             0.5494944189189189, 0.6222451756756757, 0.9628692567567567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 117}], {
             RGBColor[
             0.951344581081081, 0.9460781891891892, 0.6896241891891891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 121}], {
             RGBColor[
             0.9521269189189189, 0.9634136756756757, 0.9519402567567568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 152}], {
             RGBColor[
             0.951344581081081, 0.9460781891891892, 0.6896241891891891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 159}], {
             RGBColor[
             0.9543072837837838, 0.9560720810810811, 0.7011337297297298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 164}], {
             RGBColor[
             0.9106795405405406, 0.9316151621621622, 0.9913426216216217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 178}], {
             RGBColor[
             0.9565828513513513, 0.9633772702702703, 0.7415069729729729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 200}], {
             RGBColor[
             0.9565828513513513, 0.9633772702702703, 0.7415069729729729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 17}], {
             RGBColor[
             0.9575220540540541, 0.9656447027027026, 0.8625289054054055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 27}], {
             RGBColor[
             0.5494944189189189, 0.6222451756756757, 0.9628692567567567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 29}], {
             RGBColor[
             0.9543072837837838, 0.9560720810810811, 0.7011337297297298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 30}], {
             RGBColor[
             0.8919149459459459, 0.9166527837837839, 0.9895528378378378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 42}], {
             RGBColor[
             0.956357527027027, 0.9628953243243243, 0.7169818108108107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 51}], {
             RGBColor[
             0.9521269189189189, 0.9634136756756757, 0.9519402567567568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 62}], {
             RGBColor[
             0.9543072837837838, 0.9560720810810811, 0.7011337297297298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 71}], {
             RGBColor[
             0.9539252972972972, 0.9641573513513514, 0.9221364729729729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 73}], {
             RGBColor[
             0.9285357297297296, 0.9458194054054054, 0.9918739864864865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 75}], {
             RGBColor[
             0.8919149459459459, 0.9166527837837839, 0.9895528378378378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 89}], {
             RGBColor[
             0.9557236756756756, 0.9649010270270271, 0.8923326891891892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 107}], {
             RGBColor[
             0.5494944189189189, 0.6222451756756757, 0.9628692567567567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.9359150135135135, 0.8927901621621622, 0.6361436351351352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 130}], {
             RGBColor[
             0.9530261081081081, 0.9637855135135136, 0.9370383648648649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 141}], {
             RGBColor[
             0.951344581081081, 0.9460781891891892, 0.6896241891891891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 142}], {
             RGBColor[
             0.9285357297297296, 0.9458194054054054, 0.9918739864864865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 147}], {
             RGBColor[
             0.9521269189189189, 0.9634136756756757, 0.9519402567567568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 149}], {
             RGBColor[
             0.9191357702702703, 0.8262660540540541, 0.6226426621621621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 167}], {
             RGBColor[
             0.956357527027027, 0.9628953243243243, 0.7169818108108107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 168}], {
             RGBColor[
             0.5494944189189189, 0.6222451756756757, 0.9628692567567567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 188}], {
             RGBColor[
             0.9548244864864864, 0.9645291891891892, 0.9072345810810811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.9317202027027027, 0.8761591351351352, 0.6327683918918918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 194}], {
             RGBColor[
             0.9557236756756756, 0.9649010270270271, 0.8923326891891892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 197}], {
             RGBColor[
             0.9275253918918919, 0.8595281081081081, 0.6293931486486486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 35}], {
             RGBColor[
             0.9917295945945945, 0.9822807837837838, 0.5485038378378377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 70}], {
             RGBColor[
             0.985590027027027, 0.9630539189189189, 0.3985204054054053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 86}], {
             RGBColor[
             0.9796646216216216, 0.9430661351351353, 0.37550132432432437`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 94}], {
             RGBColor[
             0.9261603918918919, 0.9336285135135136, 0.698449054054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 110}], {
             RGBColor[
             0.9745767702702702, 0.9715922702702703, 0.6808033378378378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 138}], {
             RGBColor[
             0.9863723648648648, 0.9803894054054054, 0.660836472972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 174}], {
             RGBColor[
             0.9767019189189189, 0.9330722432432432, 0.36399178378378366`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 182}], {
             RGBColor[
             0.5837398648648648, 0.6392209054054054, 0.671765472972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 196}], {
             RGBColor[
             0.9899691216216215, 0.9818767567567568, 0.6012289054054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 33}], {
             RGBColor[
             0.8955449864864864, 0.8786905675675675, 0.650621108108108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 44}], {
             RGBColor[
             0.9792028108108108, 0.9408593783783783, 0.428890189189189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 58}], {
             RGBColor[
             0.9678138108108107, 0.9030905675675676, 0.3294631621621621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 68}], {
             RGBColor[
             0.9457252162162162, 0.8198972432432432, 0.2888759594594594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 77}], {
             RGBColor[
             0.964851108108108, 0.8930966756756755, 0.31795362162162144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 96}], {
             RGBColor[
             0.9767019189189189, 0.9330722432432432, 0.36399178378378366`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 99}], {
             RGBColor[
             0.571889054054054, 0.5992453378378377, 0.6257273108108108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 102}], {
             RGBColor[
             0.9799166891891892, 0.9426448648648648, 0.5253869594594595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 128}], {
             RGBColor[
             0.9781183108108107, 0.9419011891891891, 0.5551907432432431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 140}], {
             RGBColor[
             0.9796534594594595, 0.9418232702702702, 0.4779405135135134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 162}], {
             RGBColor[
             0.571889054054054, 0.5992453378378377, 0.6257273108108108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 172}], {
             RGBColor[
             0.571889054054054, 0.5992453378378377, 0.6257273108108108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 31}], {
             RGBColor[
             0.9886479324324324, 0.9876945945945946, 0.7012097162162161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 34}], {
             RGBColor[
             0.9893239054054054, 0.9891404324324324, 0.7747852027027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 36}], {
             RGBColor[
             0.9512008513513514, 0.8505833783783783, 0.5823454054054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 63}], {
             RGBColor[
             0.9884226081081081, 0.9872126486486487, 0.6766845540540539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 64}], {
             RGBColor[
             0.9239800270270271, 0.9409701081081081, 0.949255581081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 70}], {
             RGBColor[
             0.9834096621621622, 0.9703955135135135, 0.6493269324324323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 97}], {
             RGBColor[
             0.9804469594594594, 0.9604016216216216, 0.6378173918918918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 132}], {
             RGBColor[
             0.9637852837837837, 0.9004764594594594, 0.592471135135135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 138}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 145}], {
             RGBColor[
             0.9895492297297297, 0.9896223783783784, 0.7993103648648648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 153}], {
             RGBColor[
             0.9429710675675675, 0.8172415675675676, 0.5756866216216217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 185}], {
             RGBColor[
             0.9774842567567568, 0.9504077297297298, 0.6263078513513514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 22}], {
             RGBColor[
             0.9600402432432432, 0.8731470810810811, 0.318645527027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 48}], {
             RGBColor[
             0.9389995810810811, 0.9286031081081081, 0.6772197567567566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 106}], {
             RGBColor[
             0.9826273243243243, 0.9530600270270271, 0.3870108648648648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 131}], {
             RGBColor[
             0.9642350540540541, 0.8897781081081082, 0.3220207702702702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 176}], {
             RGBColor[
             0.9849028918918918, 0.9603652162162162, 0.4273841081081079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 59}], {
             RGBColor[
             0.9823908378378379, 0.9513352162162163, 0.464924891891892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.9912789459459459, 0.981316891891892, 0.4994535135135135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 114}], {
             RGBColor[0.9917961486486486, 0.989774, 0.7055543648648649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 167}], {
             RGBColor[
             0.9933291891891892, 0.9881401351351351, 0.5153015945945946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 184}], {
             RGBColor[
             0.993594527027027, 0.9905176756756757, 0.6757505810810811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 186}], {
             RGBColor[
             0.9942304864864865, 0.990067918918919, 0.6134022432432433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 194}], {
             RGBColor[
             0.9926953378378378, 0.9901458378378378, 0.690652472972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 52}], {
             RGBColor[0.9917675, 0.9826204324324324, 0.5714251216216217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 61}], {
             RGBColor[
             0.9738596756756757, 0.9782325135135135, 0.8488541351351352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 67}], {
             RGBColor[
             0.9481397567567568, 0.9581635135135135, 0.8616340135135137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 80}], {
             RGBColor[
             0.9949822702702703, 0.992193054054054, 0.7328202972972975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 82}], {
             RGBColor[
             0.5869546351351351, 0.648793527027027, 0.8331606486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 84}], {
             RGBColor[
             0.5869546351351351, 0.648793527027027, 0.8331606486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 100}], {
             RGBColor[
             0.9938177432432433, 0.9894436756756757, 0.5872732027027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 120}], {
             RGBColor[
             0.9947190405405406, 0.9913714594594594, 0.6853738513513514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 125}], {
             RGBColor[
             0.994268391891892, 0.9904075675675675, 0.636323527027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.5869546351351351, 0.648793527027027, 0.8331606486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 30}], {
             RGBColor[
             0.9293751621621622, 0.9432011351351351, 0.8598442297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[
             0.9938177432432433, 0.9894436756756757, 0.5872732027027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 51}], {
             RGBColor[
             0.9895871351351351, 0.9899620270270271, 0.8222316486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 73}], {
             RGBColor[
             0.965995945945946, 0.9723677567567568, 0.8621653783783785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 87}], {
             RGBColor[
             0.9738596756756757, 0.9782325135135135, 0.8488541351351352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 89}], {
             RGBColor[
             0.9931838918918918, 0.9914493783783784, 0.7626240810810812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 106}], {
             RGBColor[0.9917675, 0.9826204324324324, 0.5714251216216217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 107}], {
             RGBColor[
             0.5869546351351351, 0.648793527027027, 0.8331606486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 130}], {
             RGBColor[
             0.9904863243243243, 0.9903338648648649, 0.8073297567567569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 131}], {
             RGBColor[
             0.9733752297297298, 0.9193385135135135, 0.5064350270270271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 142}], {
             RGBColor[
             0.965995945945946, 0.9723677567567568, 0.8621653783783785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 147}], {
             RGBColor[
             0.9895871351351351, 0.9899620270270271, 0.8222316486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 149}], {
             RGBColor[
             0.9565959864864866, 0.8528144054054053, 0.4929340540540541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 157}], {
             RGBColor[
             0.9387574594594594, 0.9506823243243243, 0.8607391216216217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 168}], {
             RGBColor[
             0.5869546351351351, 0.648793527027027, 0.8331606486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 188}], {
             RGBColor[
             0.9922847027027026, 0.9910775405405405, 0.7775259729729731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 189}], {
             RGBColor[
             0.9691804189189189, 0.9027074864864865, 0.5030597837837838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 197}], {
             RGBColor[
             0.9649856081081081, 0.8860764594594595, 0.4996845405405406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 24}], {
             RGBColor[
             0.5860154324324325, 0.6465260945945945, 0.712138716216216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 32}], {
             RGBColor[
             0.44664806756756753`, 0.5410919324324325, 0.9528331486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 39}], {
             RGBColor[
             0.5824586891891892, 0.6469343378378378, 0.9076701081081082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 41}], {
             RGBColor[
             0.5748517567567568, 0.6092392297297298, 0.6372368513513514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 85}], {
             RGBColor[
             0.5842570675675676, 0.6476780135135136, 0.8778663243243243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 103}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 108}], {
             RGBColor[
             0.5851562567567568, 0.6480498513513513, 0.8629644324324324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 117}], {
             RGBColor[
             0.5807771621621622, 0.6292270135135134, 0.6602559324324324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 133}], {
             RGBColor[
             0.5307298243243244, 0.6072827972972972, 0.961079472972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 152}], {
             RGBColor[
             0.5807771621621622, 0.6292270135135134, 0.6602559324324324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 178}], {
             RGBColor[
             0.5860154324324325, 0.6465260945945945, 0.712138716216216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 33}], {
             RGBColor[
             0.8890035270270271, 0.8553842162162162, 0.6316691756756756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 74}], {
             RGBColor[
             0.9722107027027027, 0.9165891351351352, 0.36088793243243233`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 85}], {
             RGBColor[0.9706776621621622, 0.918223, 0.5511407027027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 88}], {
             RGBColor[
             0.9443889054054054, 0.8995132162162163, 0.635780108108108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 93}], {
             RGBColor[0.9561845, 0.9083103513513514, 0.6158132432432433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 95}], {
             RGBColor[
             0.9391837567567568, 0.796590891891892, 0.269924027027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 102}], {
             RGBColor[
             0.9733752297297298, 0.9193385135135135, 0.5064350270270271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 121}], {
             RGBColor[
             0.9679800945945947, 0.9171074864864865, 0.5958463783783783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 140}], {
             RGBColor[0.973112, 0.918516918918919, 0.4589885810810811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 159}], {
             RGBColor[
             0.9701604594594595, 0.9097658918918919, 0.3450398513513513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 161}], {
             RGBColor[
             0.9724760405405406, 0.9189666756756758, 0.521336918918919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 162}], {
             RGBColor[
             0.5653475945945946, 0.5759389864864866, 0.6067753783783785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 164}], {
             RGBColor[
             0.9265327162162162, 0.8853089729729731, 0.6352487432432432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 172}], {
             RGBColor[
             0.5653475945945946, 0.5759389864864866, 0.6067753783783785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 173}], {
             RGBColor[
             0.9715768513513514, 0.9185948378378379, 0.5362388108108107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 180}], {
             RGBColor[
             0.9612723513513515, 0.8797842162162164, 0.3105112297297298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 22}], {
             RGBColor[
             0.9475733783783784, 0.829852945945946, 0.27667451351351346`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 46}], {
             RGBColor[
             0.9733373243243244, 0.9189988648648649, 0.48351374324324325`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 47}], {
             RGBColor[
             0.8890035270270271, 0.8553842162162162, 0.6316691756756756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 50}], {
             RGBColor[
             0.969778472972973, 0.9178511621621622, 0.5660425945945946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 101}], {
             RGBColor[
             0.5653475945945946, 0.5759389864864866, 0.6067753783783785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 135}], {
             RGBColor[
             0.887874891891892, 0.5159112972972972, 0.22532393243243243`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 144}], {
             RGBColor[
             0.955346945945946, 0.8597964324324325, 0.2874921486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 23}], {
             RGBColor[
             0.9906029729729731, 0.9798710540540541, 0.42587802702702693`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 55}], {
             RGBColor[
             0.9787521621621622, 0.9398954864864864, 0.37983986486486465`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 61}], {
             RGBColor[
             0.9726951486486486, 0.9754831351351352, 0.7033070405405404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 67}], {
             RGBColor[
             0.9469752297297298, 0.9554141351351351, 0.7160869189189187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 83}], {
             RGBColor[
             0.9893217972972973, 0.9875844864864864, 0.6617826621621621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 90}], {
             RGBColor[
             0.9757894594594595, 0.9299015945945945, 0.3683303243243242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 122}], {
             RGBColor[
             0.9911201756756757, 0.9883281621621622, 0.6319788783783783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 166}], {
             RGBColor[
             0.9906029729729731, 0.9798710540540541, 0.42587802702702693`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 170}], {
             RGBColor[
             0.9049861081081081, 0.5604106486486486, 0.302972054054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 175}], {
             RGBColor[
             0.992918554054054, 0.9890718378378378, 0.6021750945945945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 177}], {
             RGBColor[
             0.9638210810810811, 0.8833270810810812, 0.3541374459459459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 179}], {
             RGBColor[
             0.9876402702702702, 0.9698771621621621, 0.4143684864864863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 183}], {
             RGBColor[
             0.9787521621621622, 0.9398954864864864, 0.37983986486486465`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 192}], {
             RGBColor[
             0.9648314189189189, 0.9696183783783784, 0.7166182837837838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[0.9223379054054054, 0.8686779459459459, 0.6318735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 72}], {
             RGBColor[
             0.9655836621621621, 0.9012201351351352, 0.5626673513513513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 144}], {
             RGBColor[
             0.9511521351351351, 0.8431654054054054, 0.2841169054054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 176}], {
             RGBColor[
             0.9682412162162162, 0.900440054054054, 0.3820378513513512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 38}], {
             RGBColor[
             0.9885527297297297, 0.9730478108108108, 0.4100299459459459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 43}], {
             RGBColor[
             0.9627811756756757, 0.9627951351351351, 0.7007702027027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 55}], {
             RGBColor[
             0.9767019189189189, 0.9330722432432432, 0.36399178378378366`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 60}], {
             RGBColor[
             0.5837398648648648, 0.6392209054054054, 0.671765472972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 90}], {
             RGBColor[
             0.9737392162162162, 0.9230783513513514, 0.35248224324324323`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 111}], {
             RGBColor[
             0.957576027027027, 0.8598728108108109, 0.3349141216216216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 115}], {
             RGBColor[
             0.9912789459459459, 0.981316891891892, 0.4994535135135135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 163}], {
             RGBColor[
             0.957576027027027, 0.8598728108108109, 0.3349141216216216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 165}], {
             RGBColor[
             0.9912789459459459, 0.981316891891892, 0.4994535135135135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 169}], {
             RGBColor[
             0.9667130405405405, 0.9657275135135135, 0.694114581081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 175}], {
             RGBColor[
             0.9908683108108107, 0.9822485945945947, 0.5863270135135135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 177}], {
             RGBColor[
             0.9617708378378378, 0.8765038378378378, 0.3382893648648648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 39}], {
             RGBColor[
             0.9895471216216216, 0.9880664324324324, 0.6863078243243242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 41}], {
             RGBColor[
             0.9819401891891892, 0.9503713243243244, 0.41587456756756747`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 55}], {
             RGBColor[
             0.9789774864864864, 0.9403774324324323, 0.4043650270270268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 108}], {
             RGBColor[
             0.9922446891891892, 0.989181945945946, 0.6416021486486485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 111}], {
             RGBColor[0.9598515945945947, 0.867178, 0.37528736486486475`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 115}], {
             RGBColor[
             0.9935545135135135, 0.9886220810810811, 0.5398267567567567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 133}], {
             RGBColor[
             0.9378182567567568, 0.9484148918918919, 0.739717189189189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 163}], {
             RGBColor[0.9598515945945947, 0.867178, 0.37528736486486475`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 165}], {
             RGBColor[
             0.9935545135135135, 0.9886220810810811, 0.5398267567567567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 175}], {
             RGBColor[
             0.9931438783783784, 0.9895537837837838, 0.6267002567567567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 38}], {
             RGBColor[
             0.9667130405405405, 0.9657275135135135, 0.694114581081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[
             0.9409414864864865, 0.9554748378378379, 0.9848548378378379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 60}], {
             RGBColor[
             0.5619001756756756, 0.6319006081081081, 0.9558501081081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 111}], {
             RGBColor[
             0.9357363378378378, 0.8525525135135136, 0.6189987567567568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 165}], {
             RGBColor[
             0.9694392567567567, 0.9739965945945946, 0.7835381486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 58}], {
             RGBColor[
             0.9454191756756757, 0.9260904054054055, 0.6666051081081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 67}], {
             RGBColor[
             0.9106795405405406, 0.9316151621621622, 0.9913426216216217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 80}], {
             RGBColor[
             0.9575220540540541, 0.9656447027027026, 0.8625289054054055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 82}], {
             RGBColor[
             0.5494944189189189, 0.6222451756756757, 0.9628692567567567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 96}], {
             RGBColor[
             0.9543072837837838, 0.9560720810810811, 0.7011337297297298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 98}], {
             RGBColor[
             0.5494944189189189, 0.6222451756756757, 0.9628692567567567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 99}], {
             RGBColor[
             0.5494944189189189, 0.6222451756756757, 0.9628692567567567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[
             0.956357527027027, 0.9628953243243243, 0.7169818108108107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 116}], {
             RGBColor[
             0.956357527027027, 0.9628953243243243, 0.7169818108108107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 120}], {
             RGBColor[
             0.9572588243243243, 0.9648231081081081, 0.8150824594594595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 122}], {
             RGBColor[
             0.9548244864864864, 0.9645291891891892, 0.9072345810810811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 124}], {
             RGBColor[
             0.9285357297297296, 0.9458194054054054, 0.9918739864864865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 125}], {
             RGBColor[
             0.9568081756756757, 0.9638592162162163, 0.766032135135135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 128}], {
             RGBColor[
             0.9557236756756756, 0.9649010270270271, 0.8923326891891892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 136}], {
             RGBColor[
             0.9568081756756757, 0.9638592162162163, 0.766032135135135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 137}], {
             RGBColor[
             0.9548244864864864, 0.9645291891891892, 0.9072345810810811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.9543072837837838, 0.9560720810810811, 0.7011337297297298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 170}], {
             RGBColor[
             0.8686904189189188, 0.5366116756756757, 0.5782277567567568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 187}], {
             RGBColor[
             0.5494944189189189, 0.6222451756756757, 0.9628692567567567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 192}], {
             RGBColor[
             0.9285357297297296, 0.9458194054054054, 0.9918739864864865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 198}], {
             RGBColor[
             0.9575220540540541, 0.9656447027027026, 0.8625289054054055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 29}], {
             RGBColor[
             0.5837398648648648, 0.6392209054054054, 0.671765472972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 30}], {
             RGBColor[
             0.5213475270270271, 0.5998016081081081, 0.9601845810810811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 42}], {
             RGBColor[
             0.585790108108108, 0.6460441486486486, 0.687613554054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 62}], {
             RGBColor[
             0.5837398648648648, 0.6392209054054054, 0.671765472972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 71}], {
             RGBColor[
             0.5833578783783784, 0.6473061756756757, 0.8927682162162162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 73}], {
             RGBColor[
             0.5579683108108109, 0.6289682297297297, 0.9625057297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 75}], {
             RGBColor[
             0.5213475270270271, 0.5998016081081081, 0.9601845810810811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 89}], {
             RGBColor[
             0.5851562567567568, 0.6480498513513513, 0.8629644324324324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 127}], {
             RGBColor[
             0.5842570675675676, 0.6476780135135136, 0.8778663243243243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 129}], {
             RGBColor[
             0.5653475945945947, 0.5759389864864866, 0.6067753783783784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 141}], {
             RGBColor[
             0.5807771621621622, 0.6292270135135134, 0.6602559324324324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 142}], {
             RGBColor[
             0.5579683108108109, 0.6289682297297297, 0.9625057297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 147}], {
             RGBColor[0.5815595, 0.6465624999999999, 0.922572]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{27, 149}], {
             RGBColor[
             0.5485683513513513, 0.5094148783783783, 0.5932744054054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 155}], {
             RGBColor[
             0.5119652297297297, 0.5923204189189188, 0.9592896891891892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 167}], {
             RGBColor[
             0.585790108108108, 0.6460441486486486, 0.687613554054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 168}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 188}], {
             RGBColor[
             0.5842570675675676, 0.6476780135135136, 0.8778663243243243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 189}], {
             RGBColor[
             0.5611527837837837, 0.5593079594594594, 0.6034001351351351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[
             0.5851562567567568, 0.6480498513513513, 0.8629644324324324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 197}], {
             RGBColor[
             0.556957972972973, 0.5426769324324324, 0.6000248918918919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 97}], {
             RGBColor[
             0.9804469594594594, 0.9604016216216216, 0.6378173918918918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 105}], {
             RGBColor[
             0.9884226081081081, 0.9872126486486487, 0.6766845540540539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.9885527297297297, 0.9730478108108108, 0.4100299459459459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 71}], {
             RGBColor[
             0.9881707432432432, 0.9811330810810811, 0.6310326891891891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 73}], {
             RGBColor[
             0.9627811756756757, 0.9627951351351351, 0.7007702027027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 129}], {
             RGBColor[
             0.9701604594594595, 0.9097658918918919, 0.3450398513513513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 141}], {
             RGBColor[
             0.985590027027027, 0.9630539189189189, 0.3985204054054053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 149}], {
             RGBColor[
             0.9533812162162163, 0.8432417837837838, 0.33153887837837837`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 167}], {
             RGBColor[
             0.9906029729729731, 0.9798710540540541, 0.42587802702702693`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 168}], {
             RGBColor[
             0.5837398648648648, 0.6392209054054054, 0.671765472972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 189}], {
             RGBColor[
             0.9659656486486486, 0.8931348648648649, 0.34166460810810806`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 194}], {
             RGBColor[
             0.9899691216216215, 0.9818767567567568, 0.6012289054054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 197}], {
             RGBColor[
             0.9617708378378378, 0.8765038378378378, 0.3382893648648648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 42}], {
             RGBColor[
             0.9282106351351351, 0.9404517567567567, 0.714297135135135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 51}], {
             RGBColor[
             0.9239800270270271, 0.9409701081081081, 0.949255581081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 71}], {
             RGBColor[
             0.9257784054054055, 0.9417137837837839, 0.9194517972972972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 73}], {
             RGBColor[
             0.9003888378378379, 0.9233758378378378, 0.9891893108108107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 76}], {
             RGBColor[
             0.9293372567567568, 0.9428614864864866, 0.836922945945946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 81}], {
             RGBColor[
             0.9143095810810811, 0.8936529459459459, 0.6524108918918918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 87}], {
             RGBColor[
             0.9082525675675676, 0.9292405945945946, 0.9758780675675676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 89}], {
             RGBColor[
             0.9275767837837838, 0.9424574594594595, 0.8896480135135134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 106}], {
             RGBColor[
             0.9261603918918919, 0.9336285135135136, 0.698449054054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 107}], {
             RGBColor[
             0.521347527027027, 0.5998016081081081, 0.9601845810810811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 130}], {
             RGBColor[
             0.9248792162162163, 0.941341945945946, 0.9343536891891893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 131}], {
             RGBColor[
             0.9077681216216217, 0.8703465945945947, 0.6334589594594594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 142}], {
             RGBColor[
             0.9003888378378379, 0.9233758378378378, 0.9891893108108107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 147}], {
             RGBColor[
             0.9239800270270271, 0.9409701081081081, 0.949255581081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 157}], {
             RGBColor[
             0.8731503513513513, 0.9016904054054053, 0.9877630540540541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 168}], {
             RGBColor[
             0.521347527027027, 0.5998016081081081, 0.9601845810810811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 176}], {
             RGBColor[
             0.9284359594594596, 0.9409337027027027, 0.7388222972972971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 188}], {
             RGBColor[
             0.9266775945945946, 0.9420856216216217, 0.9045499054054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 197}], {
             RGBColor[
             0.8993785000000001, 0.8370845405405406, 0.6267084729729729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 34}], {
             RGBColor[
             0.9937798378378379, 0.989104027027027, 0.5643519189189188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[
             0.9895471216216216, 0.9880664324324324, 0.6863078243243242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 45}], {
             RGBColor[
             0.9940430675675676, 0.9899256216216217, 0.6117983648648648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 64}], {
             RGBColor[
             0.9284359594594596, 0.9409337027027027, 0.7388222972972971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 65}], {
             RGBColor[
             0.9933291891891892, 0.9881401351351351, 0.5153015945945943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 132}], {
             RGBColor[
             0.9682412162162162, 0.900440054054054, 0.3820378513513512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 138}], {
             RGBColor[
             0.9886479324324324, 0.9876945945945946, 0.7012097162162161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 153}], {
             RGBColor[0.947427, 0.8172051621621622, 0.36525333783783775`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 156}], {
             RGBColor[
             0.9931038648648649, 0.9876581891891892, 0.4907764324324322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 182}], {
             RGBColor[
             0.5860154324324325, 0.6465260945945946, 0.712138716216216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 185}], {
             RGBColor[
             0.9819401891891892, 0.9503713243243244, 0.41587456756756747`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 199}], {
             RGBColor[
             0.5860154324324325, 0.6465260945945946, 0.712138716216216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 39}], {
             RGBColor[
             0.8501797567567567, 0.8826322702702702, 0.9270022567567568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 57}], {
             RGBColor[
             0.8396101216216216, 0.8349432702702702, 0.6450594594594594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 103}], {
             RGBColor[
             0.4466480675675676, 0.5410919324324325, 0.9528331486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 117}], {
             RGBColor[
             0.8484982297297297, 0.8649249459459459, 0.679588081081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 133}], {
             RGBColor[
             0.7984508918918918, 0.8429807297297297, 0.9804116216216217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 152}], {
             RGBColor[
             0.8484982297297297, 0.8649249459459459, 0.679588081081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 178}], {
             RGBColor[0.8537365, 0.8822240270270271, 0.7314708648648647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 44}], {
             RGBColor[
             0.9098966891891892, 0.9264532702702702, 0.7615576756756756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 58}], {
             RGBColor[
             0.8985076891891892, 0.8886844594594595, 0.6621306486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 68}], {
             RGBColor[
             0.8764190945945947, 0.8054911351351352, 0.6215434459459459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 77}], {
             RGBColor[
             0.8955449864864864, 0.8786905675675675, 0.650621108108108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 96}], {
             RGBColor[
             0.9073957972972972, 0.9186661351351351, 0.6966592702702703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 99}], {
             RGBColor[
             0.5025829324324325, 0.5848392297297297, 0.9583947972972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 102}], {
             RGBColor[
             0.9106105675675675, 0.9282387567567567, 0.858054445945946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 128}], {
             RGBColor[
             0.9088121891891892, 0.9274950810810811, 0.8878582297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 140}], {
             RGBColor[0.9103473378378378, 0.9274171621621621, 0.810608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 162}], {
             RGBColor[
             0.5025829324324325, 0.5848392297297297, 0.9583947972972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 172}], {
             RGBColor[
             0.5025829324324325, 0.5848392297297297, 0.9583947972972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 180}], {
             RGBColor[
             0.8985076891891892, 0.8886844594594595, 0.6621306486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 40}], {
             RGBColor[
             0.9902230945945946, 0.9895122702702703, 0.7598833108108108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 45}], {
             RGBColor[
             0.9947190405405406, 0.9913714594594594, 0.6853738513513514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 54}], {
             RGBColor[
             0.9920214729729729, 0.9902559459459459, 0.730079527027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 64}], {
             RGBColor[
             0.9291119324324324, 0.9423795405405406, 0.8123977837837837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 65}], {
             RGBColor[
             0.9940051621621622, 0.989585972972973, 0.5888770810810809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 132}], {
             RGBColor[
             0.9689171891891892, 0.9018858918918919, 0.4556133378378378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 138}], {
             RGBColor[
             0.9893239054054054, 0.9891404324324324, 0.7747852027027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 153}], {
             RGBColor[0.948102972972973, 0.818651, 0.43882882432432435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 182}], {
             RGBColor[
             0.5866914054054054, 0.6479719324324325, 0.7857142027027026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 185}], {
             RGBColor[
             0.9826161621621622, 0.9518171621621623, 0.48945005405405406`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 199}], {
             RGBColor[
             0.5866914054054054, 0.6479719324324325, 0.7857142027027026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 86}], {
             RGBColor[
             0.9828414864864865, 0.9522991081081082, 0.5139752162162162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.9293372567567568, 0.9428614864864866, 0.836922945945946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 110}], {
             RGBColor[
             0.977753635135135, 0.9808252432432433, 0.8192772297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 174}], {
             RGBColor[
             0.9798787837837837, 0.9423052162162162, 0.5024656756756756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 63}], {
             RGBColor[
             0.9554314594594595, 0.8500650270270269, 0.34738695945945935`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 70}], {
             RGBColor[
             0.9504185135135135, 0.8332478918918917, 0.3200293378378377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 110}], {
             RGBColor[
             0.9394052567567568, 0.8417862432432432, 0.6023122702702703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 138}], {
             RGBColor[
             0.9512008513513514, 0.8505833783783783, 0.5823454054054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 145}], {
             RGBColor[
             0.9565580810810811, 0.8524747567567568, 0.4700127702702702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 185}], {
             RGBColor[
             0.9444931081081082, 0.8132601081081081, 0.2970102567567568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 45}], {
             RGBColor[
             0.9777915405405405, 0.9811648918918918, 0.8421985135135136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 47}], {
             RGBColor[
             0.8934198378378377, 0.9172105945945945, 0.9674326621621622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 50}], {
             RGBColor[
             0.9741947837837837, 0.9796775405405406, 0.9018060810810811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 97}], {
             RGBColor[
             0.9686513648648648, 0.9516044864864865, 0.6577842567567567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 101}], {
             RGBColor[
             0.5697639054054053, 0.6377653648648649, 0.9425388648648649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 105}], {
             RGBColor[
             0.9766270135135136, 0.9784155135135135, 0.6966514189189188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 134}], {
             RGBColor[
             0.9750939729729728, 0.9800493783783784, 0.8869041891891891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 135}], {
             RGBColor[
             0.8922912027027027, 0.5777376756756756, 0.5610874189189189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 160}], {
             RGBColor[
             0.9777915405405405, 0.9811648918918918, 0.8421985135135136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 43}], {
             RGBColor[
             0.9627811756756757, 0.9627951351351351, 0.7007702027027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 60}], {
             RGBColor[
             0.5837398648648648, 0.6392209054054054, 0.671765472972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 90}], {
             RGBColor[
             0.9737392162162162, 0.9230783513513514, 0.35248224324324323`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 111}], {
             RGBColor[
             0.957576027027027, 0.8598728108108109, 0.3349141216216216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 165}], {
             RGBColor[
             0.9912789459459459, 0.981316891891892, 0.4994535135135135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 169}], {
             RGBColor[
             0.9667130405405405, 0.9657275135135135, 0.694114581081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 41}], {
             RGBColor[
             0.978383445945946, 0.9507795675675677, 0.6114059594594595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 74}], {
             RGBColor[
             0.9893217972972973, 0.9875844864864864, 0.6617826621621621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 85}], {
             RGBColor[
             0.9877887567567567, 0.9892183513513514, 0.8520354324324324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 88}], {
             RGBColor[0.9615, 0.9705085675675675, 0.9366748378378379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 108}], {
             RGBColor[
             0.9886879459459459, 0.9895901891891892, 0.8371335405405406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 117}], {
             RGBColor[
             0.9843088513513514, 0.9707673513513513, 0.6344250405405405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 133}], {
             RGBColor[
             0.9342615135135135, 0.948823135135135, 0.9352485810810811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 152}], {
             RGBColor[
             0.9843088513513514, 0.9707673513513513, 0.6344250405405405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 159}], {
             RGBColor[
             0.987271554054054, 0.9807612432432433, 0.645934581081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 173}], {
             RGBColor[
             0.9886879459459459, 0.9895901891891892, 0.8371335405405406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 178}], {
             RGBColor[
             0.9895471216216216, 0.9880664324324324, 0.6863078243243242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 49}], {
             RGBColor[0.9615, 0.9705085675675675, 0.9366748378378379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 53}], {
             RGBColor[
             0.9895471216216216, 0.9880664324324324, 0.6863078243243242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 54}], {
             RGBColor[
             0.9877887567567567, 0.9892183513513514, 0.8520354324324324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 64}], {
             RGBColor[
             0.9248792162162163, 0.941341945945946, 0.9343536891891893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.9897724459459459, 0.9885483783783784, 0.7108329864864864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 69}], {
             RGBColor[
             0.9562948513513514, 0.8675862432432433, 0.5708187567567569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 119}], {
             RGBColor[
             0.9521000405405405, 0.8509552162162162, 0.5674435135135135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 123}], {
             RGBColor[
             0.9772274594594594, 0.9822380810810811, 0.9100523513513514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 132}], {
             RGBColor[
             0.9646844729729729, 0.9008482972972973, 0.5775692432432433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 171}], {
             RGBColor[
             0.9693637297297297, 0.9763733243243243, 0.9233635945945946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 182}], {
             RGBColor[
             0.5824586891891892, 0.6469343378378378, 0.9076701081081082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 191}], {
             RGBColor[
             0.9895471216216216, 0.9880664324324324, 0.6863078243243242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 195}], {
             RGBColor[
             0.9859903783783783, 0.9884746756756757, 0.8818392162162163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 196}], {
             RGBColor[
             0.9886879459459459, 0.9895901891891892, 0.8371335405405406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 199}], {
             RGBColor[
             0.5824586891891892, 0.6469343378378378, 0.9076701081081082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 74}], {
             RGBColor[
             0.9817148648648649, 0.9498893783783784, 0.39134940540540536`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 85}], {
             RGBColor[
             0.9801818243243243, 0.9515232432432433, 0.5816021756756757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.9538930675675676, 0.9328134594594595, 0.6662415810810811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 108}], {
             RGBColor[
             0.9810810135135135, 0.9518950810810811, 0.5667002837837838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 121}], {
             RGBColor[
             0.9774842567567568, 0.9504077297297298, 0.6263078513513514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 133}], {
             RGBColor[
             0.9266545810810811, 0.911128027027027, 0.6648153243243244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 140}], {
             RGBColor[
             0.9826161621621622, 0.9518171621621623, 0.48945005405405406`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 151}], {
             RGBColor[
             0.9707765135135136, 0.9130844594594596, 0.3409727027027028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 152}], {
             RGBColor[
             0.976701918918919, 0.9330722432432432, 0.3639917837837837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 159}], {
             RGBColor[
             0.9796646216216216, 0.9430661351351353, 0.37550132432432437`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 161}], {
             RGBColor[
             0.9819802027027027, 0.952266918918919, 0.551798391891892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 173}], {
             RGBColor[
             0.9810810135135135, 0.9518950810810811, 0.5667002837837838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 51}], {
             RGBColor[
             0.9884226081081081, 0.9872126486486487, 0.6766845540540539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 71}], {
             RGBColor[
             0.9902209864864865, 0.9879563243243243, 0.6468807702702701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 73}], {
             RGBColor[
             0.9648314189189189, 0.9696183783783784, 0.7166182837837838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 76}], {
             RGBColor[
             0.9937798378378379, 0.989104027027027, 0.5643519189189188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 81}], {
             RGBColor[
             0.9787521621621622, 0.9398954864864864, 0.37983986486486465`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 87}], {
             RGBColor[
             0.9726951486486486, 0.9754831351351352, 0.7033070405405404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 89}], {
             RGBColor[0.9920193648648649, 0.9887, 0.6170769864864863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 106}], {
             RGBColor[
             0.9906029729729731, 0.9798710540540541, 0.42587802702702693`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 107}], {
             RGBColor[
             0.5857901081081082, 0.6460441486486487, 0.687613554054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 130}], {
             RGBColor[
             0.9893217972972973, 0.9875844864864864, 0.6617826621621621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 131}], {
             RGBColor[
             0.9722107027027027, 0.9165891351351352, 0.36088793243243233`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 142}], {
             RGBColor[
             0.9648314189189189, 0.9696183783783784, 0.7166182837837838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 147}], {
             RGBColor[
             0.9884226081081081, 0.9872126486486487, 0.6766845540540539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 149}], {
             RGBColor[
             0.9554314594594595, 0.8500650270270269, 0.34738695945945935`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 157}], {
             RGBColor[
             0.9375929324324324, 0.9479329459459459, 0.7151920270270269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 168}], {
             RGBColor[
             0.5857901081081082, 0.6460441486486487, 0.687613554054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 176}], {
             RGBColor[
             0.9928785405405406, 0.9871762432432433, 0.46625127027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 188}], {
             RGBColor[
             0.9911201756756757, 0.9883281621621622, 0.6319788783783783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 189}], {
             RGBColor[
             0.968015891891892, 0.8999581081081081, 0.3575126891891891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 197}], {
             RGBColor[
             0.9638210810810811, 0.8833270810810812, 0.3541374459459459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 60}], {
             RGBColor[
             0.5579683108108108, 0.6289682297297298, 0.9625057297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[0.9479676621621622, 0.9128256756756756, 0.6432225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 111}], {
             RGBColor[
             0.931804472972973, 0.8496201351351351, 0.6256543783783783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 115}], {
             RGBColor[
             0.9655073918918919, 0.9710642162162162, 0.7901937702702704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 163}], {
             RGBColor[
             0.931804472972973, 0.8496201351351351, 0.6256543783783783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 165}], {
             RGBColor[
             0.9655073918918919, 0.9710642162162162, 0.7901937702702704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 169}], {
             RGBColor[
             0.9409414864864865, 0.9554748378378379, 0.9848548378378379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 58}], {
             RGBColor[
             0.9821655135135136, 0.9508532702702703, 0.4403997297297296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 68}], {
             RGBColor[
             0.9600769189189189, 0.867659945945946, 0.3998125270270269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 77}], {
             RGBColor[
             0.9792028108108108, 0.9408593783783783, 0.428890189189189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 96}], {
             RGBColor[
             0.9910536216216217, 0.980834945945946, 0.4749283513513512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 99}], {
             RGBColor[
             0.5862407567567568, 0.6470080405405405, 0.7366638783783783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 102}], {
             RGBColor[
             0.994268391891892, 0.9904075675675675, 0.636323527027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[
             0.9924700135135135, 0.9896638918918919, 0.6661273108108107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 143}], {
             RGBColor[
             0.9476523243243243, 0.8176871081081081, 0.3897784999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 166}], {
             RGBColor[
             0.9910536216216217, 0.980834945945946, 0.4749283513513512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 172}], {
             RGBColor[
             0.5862407567567568, 0.6470080405405405, 0.7366638783783783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 198}], {
             RGBColor[
             0.994268391891892, 0.9904075675675675, 0.636323527027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 64}], {
             RGBColor[
             0.9293751621621622, 0.9432011351351351, 0.8598442297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 112}], {
             RGBColor[
             0.9699278108108108, 0.9753001351351351, 0.8555097567567569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 132}], {
             RGBColor[
             0.9691804189189189, 0.9027074864864865, 0.5030597837837838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 134}], {
             RGBColor[
             0.9922847027027026, 0.9910775405405405, 0.7775259729729731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 153}], {
             RGBColor[
             0.9483662027027027, 0.8194725945945946, 0.4862752702702704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 156}], {
             RGBColor[
             0.9940430675675676, 0.9899256216216217, 0.6117983648648648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 183}], {
             RGBColor[
             0.9799166891891892, 0.9426448648648648, 0.5253869594594595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 47}], {
             RGBColor[
             0.9105726621621621, 0.927899108108108, 0.8351331621621622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 50}], {
             RGBColor[
             0.9913476081081081, 0.9903660540540541, 0.769506581081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 101}], {
             RGBColor[
             0.5869167297297297, 0.6484538783783784, 0.8102393648648649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 105}], {
             RGBColor[
             0.9937798378378379, 0.989104027027027, 0.5643519189189188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 135}], {
             RGBColor[
             0.909444027027027, 0.5884261891891891, 0.4287879189189189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 144}], {
             RGBColor[
             0.9769160810810811, 0.9323113243243244, 0.49095613513513514`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 50}], {
             RGBColor[
             0.9070138108108108, 0.9267514054054053, 0.9176620135135134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 101}], {
             RGBColor[
             0.5025829324324325, 0.5848392297297297, 0.9583947972972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 105}], {
             RGBColor[
             0.9094460405405406, 0.9254893783783784, 0.7125073513513512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 134}], {
             RGBColor[0.907913, 0.9271232432432432, 0.9027601216216217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 135}], {
             RGBColor[
             0.8251102297297297, 0.5248115405405405, 0.5769433513513513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 144}], {
             RGBColor[
             0.8925822837837838, 0.8686966756756757, 0.6391115675675676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 72}], {
             RGBColor[
             0.9445429999999999, 0.9566761621621622, 0.921241581081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 76}], {
             RGBColor[
             0.9481018513513513, 0.9578238648648649, 0.8387127297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 81}], {
             RGBColor[
             0.9330741756756756, 0.9086153243243242, 0.6542006756756755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 87}], {
             RGBColor[
             0.9270171621621621, 0.944202972972973, 0.9776678513513513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 104}], {
             RGBColor[
             0.9463413783783783, 0.9574198378378378, 0.8914377972972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 106}], {
             RGBColor[
             0.9449249864864865, 0.9485908918918919, 0.7002388378378378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 147}], {
             RGBColor[
             0.9427446216216215, 0.9559324864864864, 0.9510453648648649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 154}], {
             RGBColor[0.9454421891891891, 0.957048, 0.9063396891891892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 157}], {
             RGBColor[
             0.8919149459459459, 0.9166527837837837, 0.9895528378378378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 158}], {
             RGBColor[
             0.9330741756756756, 0.9086153243243242, 0.6542006756756755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 176}], {
             RGBColor[
             0.947200554054054, 0.955896081081081, 0.740612081081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 53}], {
             RGBColor[
             0.9650567432432433, 0.9701003243243244, 0.7411434459459458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 54}], {
             RGBColor[
             0.9632983783783784, 0.9712522432432433, 0.9068710540540541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 65}], {
             RGBColor[
             0.9652820675675675, 0.9705822702702702, 0.765668608108108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 69}], {
             RGBColor[
             0.931804472972973, 0.8496201351351351, 0.6256543783783783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 92}], {
             RGBColor[
             0.9285357297297296, 0.9458194054054054, 0.9918739864864865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 118}], {
             RGBColor[
             0.9003888378378379, 0.9233758378378378, 0.9891893108108107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 119}], {
             RGBColor[
             0.9276096621621621, 0.832989108108108, 0.6222791351351351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 123}], {
             RGBColor[
             0.9527370810810811, 0.964271972972973, 0.9648879729729729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 127}], {
             RGBColor[
             0.9632983783783784, 0.9712522432432433, 0.9068710540540541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[
             0.9443889054054054, 0.8995132162162163, 0.6357801081081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 139}], {
             RGBColor[
             0.8910065405405405, 0.9158946486486487, 0.9882944189189189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 141}], {
             RGBColor[
             0.959818472972973, 0.9528012432432432, 0.6892606621621621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 146}], {
             RGBColor[
             0.9276096621621621, 0.832989108108108, 0.6222791351351351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 155}], {
             RGBColor[
             0.8910065405405405, 0.9158946486486487, 0.9882944189189189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 171}], {
             RGBColor[
             0.9448733513513513, 0.9584072162162163, 0.9781992162162162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 191}], {
             RGBColor[
             0.9650567432432433, 0.9701003243243244, 0.7411434459459458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 195}], {
             RGBColor[0.9615, 0.9705085675675675, 0.9366748378378379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 196}], {
             RGBColor[
             0.9641975675675676, 0.9716240810810811, 0.8919691621621622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 199}], {
             RGBColor[
             0.5579683108108108, 0.6289682297297298, 0.9625057297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 97}], {
             RGBColor[
             0.9822453378378377, 0.9611452972972974, 0.608013608108108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 101}], {
             RGBColor[
             0.5833578783783784, 0.6473061756756757, 0.8927682162162162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 105}], {
             RGBColor[
             0.9902209864864865, 0.9879563243243243, 0.6468807702702701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 134}], {
             RGBColor[
             0.9886879459459459, 0.9895901891891892, 0.8371335405405405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 135}], {
             RGBColor[
             0.9058851756756756, 0.5872784864864864, 0.5113167702702702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 144}], {
             RGBColor[
             0.9733572297297297, 0.9311636216216217, 0.5734849864864864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 73}], {
             RGBColor[
             0.9606008108108108, 0.9701367297297298, 0.9515767297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 87}], {
             RGBColor[
             0.9684645405405405, 0.9760014864864865, 0.9382654864864864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 106}], {
             RGBColor[
             0.9863723648648648, 0.9803894054054054, 0.660836472972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[0.5815595, 0.6465625, 0.922572]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{51, 130}], {
             RGBColor[
             0.9850911891891891, 0.9881028378378378, 0.8967411081081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 131}], {
             RGBColor[
             0.9679800945945947, 0.9171074864864865, 0.5958463783783784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 147}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 157}], {
             RGBColor[
             0.9333623243243243, 0.9484512972972973, 0.950150472972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 168}], {
             RGBColor[0.5815595, 0.6465625, 0.922572]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{51, 189}], {
             RGBColor[
             0.9637852837837837, 0.9004764594594594, 0.592471135135135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 197}], {
             RGBColor[
             0.959590472972973, 0.8838454324324325, 0.5890958918918918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 66}], {
             RGBColor[0.9917675, 0.9826204324324324, 0.5714251216216217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 80}], {
             RGBColor[0.9917675, 0.9826204324324324, 0.5714251216216217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 82}], {
             RGBColor[
             0.5837398648648648, 0.6392209054054054, 0.671765472972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 100}], {
             RGBColor[
             0.9906029729729731, 0.9798710540540541, 0.42587802702702693`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 120}], {
             RGBColor[
             0.9915042702702703, 0.9817988378378378, 0.5239786756756757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 124}], {
             RGBColor[
             0.9627811756756757, 0.9627951351351351, 0.7007702027027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 125}], {
             RGBColor[
             0.9910536216216217, 0.980834945945946, 0.4749283513513512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 187}], {
             RGBColor[
             0.5837398648648648, 0.6392209054054054, 0.671765472972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 54}], {
             RGBColor[0.9913455, 0.9888101081081082, 0.6565040405405405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 65}], {
             RGBColor[
             0.9933291891891892, 0.9881401351351351, 0.5153015945945943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 69}], {
             RGBColor[0.9598515945945947, 0.867178, 0.37528736486486475`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 92}], {
             RGBColor[
             0.9565828513513513, 0.9633772702702703, 0.7415069729729729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 118}], {
             RGBColor[
             0.9284359594594596, 0.9409337027027027, 0.7388222972972971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 119}], {
             RGBColor[
             0.9556567837837838, 0.8505469729729729, 0.37191212162162146`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 123}], {
             RGBColor[
             0.9807842027027027, 0.9818298378378378, 0.7145209594594593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 127}], {
             RGBColor[0.9913455, 0.9888101081081082, 0.6565040405405405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 129}], {
             RGBColor[
             0.9724360270270271, 0.9170710810810812, 0.3854130945945945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 139}], {
             RGBColor[
             0.9190536621621622, 0.9334525135135135, 0.7379274054054052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 141}], {
             RGBColor[
             0.9878655945945947, 0.9703591081081081, 0.43889364864864844`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 146}], {
             RGBColor[
             0.9556567837837838, 0.8505469729729729, 0.37191212162162146`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 155}], {
             RGBColor[
             0.9190536621621622, 0.9334525135135135, 0.7379274054054052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 171}], {
             RGBColor[
             0.972920472972973, 0.9759650810810812, 0.7278322027027025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 182}], {
             RGBColor[
             0.5860154324324325, 0.6465260945945946, 0.712138716216216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 191}], {
             RGBColor[
             0.9931038648648649, 0.9876581891891892, 0.4907764324324322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 195}], {
             RGBColor[
             0.9895471216216216, 0.9880664324324324, 0.6863078243243242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 196}], {
             RGBColor[
             0.9922446891891892, 0.989181945945946, 0.6416021486486485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 199}], {
             RGBColor[
             0.5860154324324325, 0.6465260945945946, 0.712138716216216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 64}], {
             RGBColor[
             0.9266775945945946, 0.9420856216216217, 0.9045499054054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 65}], {
             RGBColor[
             0.9915708243243243, 0.9892920540540541, 0.6810292027027025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 118}], {
             RGBColor[
             0.9266775945945946, 0.9420856216216217, 0.9045499054054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 119}], {
             RGBColor[
             0.9538984189189189, 0.8516988918918919, 0.5376397297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 123}], {
             RGBColor[
             0.9790258378378378, 0.9829817567567568, 0.8802485675675675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 127}], {
             RGBColor[
             0.9895871351351351, 0.9899620270270271, 0.8222316486486486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 140}], {
             RGBColor[
             0.9920214729729729, 0.9902559459459459, 0.730079527027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 151}], {
             RGBColor[
             0.9801818243243243, 0.9515232432432433, 0.5816021756756757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 155}], {
             RGBColor[
             0.9172952972972973, 0.9346044324324325, 0.9036550135135135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 171}], {
             RGBColor[0.9711621081081081, 0.977117, 0.8935598108108107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 172}], {
             RGBColor[
             0.5842570675675676, 0.6476780135135135, 0.8778663243243243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 191}], {
             RGBColor[0.9913455, 0.9888101081081082, 0.6565040405405405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 195}], {
             RGBColor[
             0.9877887567567567, 0.9892183513513514, 0.8520354324324324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 199}], {
             RGBColor[
             0.5842570675675676, 0.6476780135135135, 0.8778663243243243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 90}], {
             RGBColor[
             0.9618884054054053, 0.8831027837837837, 0.306444081081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 108}], {
             RGBColor[
             0.9781183108108107, 0.9419011891891891, 0.5551907432432431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 111}], {
             RGBColor[
             0.9457252162162162, 0.8198972432432432, 0.2888759594594594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 115}], {
             RGBColor[
             0.979428135135135, 0.9413413243243243, 0.4534153513513513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 163}], {
             RGBColor[
             0.9457252162162162, 0.8198972432432432, 0.2888759594594594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.979428135135135, 0.9413413243243243, 0.4534153513513513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 175}], {
             RGBColor[
             0.9790174999999999, 0.942273027027027, 0.5402888513513513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 177}], {
             RGBColor[
             0.9499200270270269, 0.8365282702702702, 0.2922512027027026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 183}], {
             RGBColor[
             0.964851108108108, 0.8930966756756755, 0.31795362162162144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 109}], {
             RGBColor[
             0.7530980675675676, 0.6816888378378378, 0.6038326891891892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 148}], {
             RGBColor[
             0.7394543513513513, 0.7961877837837837, 0.9750129999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 150}], {
             RGBColor[
             0.7394543513513513, 0.7961877837837837, 0.9750129999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 193}], {
             RGBColor[
             0.7824202972972973, 0.8296027297297297, 0.9498167702702702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 88}], {
             RGBColor[
             0.9509303648648648, 0.9228195675675674, 0.6547320405405405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 91}], {
             RGBColor[
             0.942456472972973, 0.9160965135135135, 0.6550955675675675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 103}], {
             RGBColor[
             0.571889054054054, 0.5992453378378377, 0.6257273108108108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 117}], {
             RGBColor[
             0.9737392162162162, 0.9230783513513512, 0.35248224324324307`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 121}], {
             RGBColor[
             0.9745215540540539, 0.9404138378378377, 0.6147983108108107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 152}], {
             RGBColor[
             0.9737392162162162, 0.9230783513513512, 0.35248224324324307`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 164}], {
             RGBColor[
             0.9330741756756756, 0.9086153243243242, 0.6542006756756755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 178}], {
             RGBColor[
             0.9789774864864864, 0.9403774324324323, 0.4043650270270268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 200}], {
             RGBColor[
             0.9789774864864864, 0.9403774324324323, 0.4043650270270268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 77}], {
             RGBColor[
             0.9678138108108107, 0.9030905675675676, 0.3294631621621621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 96}], {
             RGBColor[
             0.9796646216216216, 0.9430661351351353, 0.37550132432432437`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 99}], {
             RGBColor[
             0.5748517567567568, 0.6092392297297298, 0.6372368513513513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 102}], {
             RGBColor[
             0.9828793918918919, 0.9526387567567568, 0.5368965000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 125}], {
             RGBColor[
             0.9821655135135136, 0.9508532702702703, 0.4403997297297296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 128}], {
             RGBColor[
             0.9810810135135135, 0.9518950810810811, 0.5667002837837838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 137}], {
             RGBColor[
             0.9801818243243243, 0.9515232432432433, 0.5816021756756757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 166}], {
             RGBColor[
             0.9796646216216216, 0.9430661351351353, 0.37550132432432437`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 170}], {
             RGBColor[
             0.8940477567567569, 0.5236057297297299, 0.2525953513513514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 192}], {
             RGBColor[
             0.9538930675675676, 0.9328134594594595, 0.6662415810810811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 198}], {
             RGBColor[
             0.9828793918918919, 0.9526387567567568, 0.5368965000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 62}], {
             RGBColor[
             0.9796646216216216, 0.9430661351351353, 0.37550132432432437`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 92}], {
             RGBColor[
             0.9454191756756757, 0.9260904054054055, 0.6666051081081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 114}], {
             RGBColor[
             0.9801818243243243, 0.9515232432432433, 0.5816021756756757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 146}], {
             RGBColor[
             0.9444931081081082, 0.8132601081081081, 0.2970102567567568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 184}], {
             RGBColor[
             0.9819802027027027, 0.952266918918919, 0.551798391891892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 186}], {
             RGBColor[
             0.9826161621621622, 0.9518171621621623, 0.48945005405405406`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[
             0.9810810135135135, 0.9518950810810811, 0.5667002837837838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 90}], {
             RGBColor[
             0.5689263513513514, 0.5892514459459459, 0.6142177702702702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 111}], {
             RGBColor[
             0.5527631621621623, 0.5260459054054054, 0.5966496486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 165}], {
             RGBColor[
             0.5864660810810811, 0.6474899864864865, 0.7611890405405406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 169}], {
             RGBColor[
             0.5619001756756756, 0.6319006081081082, 0.9558501081081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 67}], {
             RGBColor[
             0.9270171621621621, 0.944202972972973, 0.9776678513513513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 79}], {
             RGBColor[
             0.972920472972973, 0.9759650810810812, 0.7278322027027025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 84}], {
             RGBColor[
             0.5658320405405405, 0.6348329864864865, 0.9491944864864865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 122}], {
             RGBColor[0.9711621081081081, 0.977117, 0.8935598108108107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 126}], {
             RGBColor[
             0.972920472972973, 0.9759650810810812, 0.7278322027027025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 179}], {
             RGBColor[0.9676822027027027, 0.958666, 0.6759494189189188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 190}], {
             RGBColor[
             0.8988702702702702, 0.9217594054054055, 0.9749831756756757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 192}], {
             RGBColor[
             0.9448733513513513, 0.9584072162162163, 0.9781992162162162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 114}], {
             RGBColor[
             0.9890699324324324, 0.9815049189189189, 0.6161307972972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 141}], {
             RGBColor[
             0.985590027027027, 0.9630539189189189, 0.3985204054054053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 149}], {
             RGBColor[
             0.9533812162162163, 0.8432417837837838, 0.33153887837837837`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 167}], {
             RGBColor[
             0.9906029729729731, 0.9798710540540541, 0.42587802702702693`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 184}], {
             RGBColor[
             0.9908683108108107, 0.9822485945945947, 0.5863270135135135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 189}], {
             RGBColor[
             0.9659656486486486, 0.8931348648648649, 0.34166460810810806`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 194}], {
             RGBColor[
             0.9899691216216215, 0.9818767567567568, 0.6012289054054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 197}], {
             RGBColor[
             0.9617708378378378, 0.8765038378378378, 0.3382893648648648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 70}], {
             RGBColor[
             0.9876402702702702, 0.9698771621621621, 0.4143684864864863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 110}], {
             RGBColor[
             0.9766270135135136, 0.9784155135135135, 0.6966514189189188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 132}], {
             RGBColor[
             0.968015891891892, 0.8999581081081081, 0.3575126891891891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 138}], {
             RGBColor[
             0.9884226081081081, 0.9872126486486487, 0.6766845540540539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 145}], {
             RGBColor[
             0.9937798378378379, 0.989104027027027, 0.5643519189189188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 153}], {
             RGBColor[
             0.9472016756756757, 0.8167232162162162, 0.3407281756756756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 185}], {
             RGBColor[
             0.9817148648648649, 0.9498893783783784, 0.39134940540540536`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 65}], {
             RGBColor[
             0.9286612837837838, 0.9414156486486487, 0.7633474594594594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 132}], {
             RGBColor[
             0.9035733108108108, 0.8537155675675676, 0.6300837162162162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 138}], {
             RGBColor[
             0.9239800270270271, 0.9409701081081081, 0.949255581081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 153}], {
             RGBColor[
             0.8827590945945947, 0.7704806756756757, 0.6132992027027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 156}], {
             RGBColor[
             0.9284359594594596, 0.9409337027027027, 0.7388222972972971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 182}], {
             RGBColor[
             0.521347527027027, 0.5998016081081081, 0.9601845810810811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 185}], {
             RGBColor[
             0.9172722837837839, 0.903646837837838, 0.6639204324324325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 199}], {
             RGBColor[
             0.521347527027027, 0.5998016081081081, 0.9601845810810811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 118}], {
             RGBColor[
             0.9286612837837838, 0.9414156486486487, 0.7633474594594594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 119}], {
             RGBColor[
             0.9558821081081081, 0.8510289189189189, 0.3964372837837836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 123}], {
             RGBColor[
             0.981009527027027, 0.9823117837837838, 0.7390461216216215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 127}], {
             RGBColor[
             0.9915708243243243, 0.9892920540540541, 0.6810292027027025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 140}], {
             RGBColor[
             0.9940051621621622, 0.989585972972973, 0.5888770810810809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 151}], {
             RGBColor[
             0.9821655135135136, 0.9508532702702703, 0.4403997297297296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 155}], {
             RGBColor[
             0.9192789864864865, 0.9339344594594594, 0.7624525675675675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 156}], {
             RGBColor[
             0.9933291891891892, 0.9881401351351351, 0.5153015945945943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 171}], {
             RGBColor[
             0.9731457972972972, 0.976447027027027, 0.7523573648648647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 172}], {
             RGBColor[
             0.5862407567567568, 0.6470080405405405, 0.7366638783783783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 191}], {
             RGBColor[
             0.9933291891891892, 0.9881401351351351, 0.5153015945945943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 195}], {
             RGBColor[
             0.9897724459459459, 0.9885483783783784, 0.7108329864864864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 199}], {
             RGBColor[
             0.5862407567567568, 0.6470080405405405, 0.7366638783783783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 78}], {
             RGBColor[
             0.9575220540540541, 0.9656447027027026, 0.8625289054054055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 80}], {
             RGBColor[
             0.9949822702702703, 0.992193054054054, 0.7328202972972975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 82}], {
             RGBColor[
             0.5869546351351351, 0.648793527027027, 0.8331606486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[
             0.5869546351351351, 0.648793527027027, 0.8331606486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 100}], {
             RGBColor[
             0.9938177432432433, 0.9894436756756757, 0.5872732027027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 113}], {
             RGBColor[
             0.9947190405405406, 0.9913714594594594, 0.6853738513513514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 120}], {
             RGBColor[
             0.9947190405405406, 0.9913714594594594, 0.6853738513513514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 124}], {
             RGBColor[
             0.965995945945946, 0.9723677567567568, 0.8621653783783785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 136}], {
             RGBColor[
             0.994268391891892, 0.9904075675675675, 0.636323527027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 187}], {
             RGBColor[
             0.5869546351351351, 0.648793527027027, 0.8331606486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 79}], {
             RGBColor[
             0.947200554054054, 0.955896081081081, 0.740612081081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 82}], {
             RGBColor[
             0.5401121216216216, 0.6147639864864864, 0.9619743648648649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 100}], {
             RGBColor[
             0.9469752297297298, 0.9554141351351351, 0.7160869189189188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 122}], {
             RGBColor[0.9454421891891891, 0.957048, 0.9063396891891892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 125}], {
             RGBColor[
             0.9474258783783784, 0.956378027027027, 0.7651372432432431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 137}], {
             RGBColor[0.9454421891891891, 0.957048, 0.9063396891891892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 166}], {
             RGBColor[
             0.9449249864864865, 0.9485908918918919, 0.7002388378378378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 170}], {
             RGBColor[
             0.8593081216216216, 0.5291304864864865, 0.5773328648648648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 179}], {
             RGBColor[
             0.9419622837837838, 0.9385969999999999, 0.6887292972972971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 192}], {
             RGBColor[
             0.9191534324324324, 0.9383382162162162, 0.9909790945945947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 71}], {
             RGBColor[
             0.9571940405405406, 0.8679580810810812, 0.5559168648648648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 75}], {
             RGBColor[
             0.8951836891891892, 0.8204535135135136, 0.6233332297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 81}], {
             RGBColor[
             0.9457252162162162, 0.8198972432432432, 0.2888759594594594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 102}], {
             RGBColor[
             0.9607907972972973, 0.8694454324324324, 0.4963092972972974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 127}], {
             RGBColor[
             0.9580932297297298, 0.868329918918919, 0.541014972972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 129}], {
             RGBColor[
             0.9391837567567568, 0.796590891891892, 0.269924027027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 140}], {
             RGBColor[
             0.9605275675675675, 0.8686238378378379, 0.44886285135135134`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 143}], {
             RGBColor[
             0.9141747297297298, 0.696724972972973, 0.2497642702702703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 155}], {
             RGBColor[
             0.8858013918918919, 0.8129723243243243, 0.6224383378378379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 172}], {
             RGBColor[
             0.5527631621621621, 0.5260459054054054, 0.5966496486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 188}], {
             RGBColor[
             0.9580932297297298, 0.868329918918919, 0.541014972972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 86}], {
             RGBColor[
             0.948687918918919, 0.8298911351351352, 0.3003855000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 92}], {
             RGBColor[
             0.923330581081081, 0.8428970810810812, 0.6260179054054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 118}], {
             RGBColor[
             0.8951836891891892, 0.8204535135135136, 0.6233332297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 123}], {
             RGBColor[
             0.9475319324324325, 0.8613496486486487, 0.5990318918918919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 139}], {
             RGBColor[
             0.8858013918918919, 0.8129723243243243, 0.6224383378378379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 146}], {
             RGBColor[
             0.9224045135135135, 0.7300667837837838, 0.2564230540540541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 171}], {
             RGBColor[
             0.9396682027027027, 0.8554848918918919, 0.6123431351351352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 174}], {
             RGBColor[
             0.9457252162162162, 0.8198972432432432, 0.2888759594594594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 186}], {
             RGBColor[
             0.9605275675675675, 0.8686238378378379, 0.44886285135135134`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 191}], {
             RGBColor[0.9598515945945947, 0.867178, 0.37528736486486475`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 195}], {
             RGBColor[
             0.9562948513513514, 0.8675862432432433, 0.5708187567567569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 196}], {
             RGBColor[
             0.958992418918919, 0.8687017567567568, 0.526113081081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 110}], {
             RGBColor[
             0.9716140675675675, 0.9615983783783784, 0.6692937972972972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 132}], {
             RGBColor[
             0.9630029459459459, 0.8831409729729729, 0.33015506756756746`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 138}], {
             RGBColor[
             0.9834096621621622, 0.9703955135135135, 0.6493269324324323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.9887668918918919, 0.9722868918918919, 0.5369942972972972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 185}], {
             RGBColor[
             0.976701918918919, 0.9330722432432432, 0.3639917837837837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 73}], {
             RGBColor[
             0.9623991891891892, 0.9708804054054054, 0.9217729459459458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 75}], {
             RGBColor[
             0.9257784054054055, 0.9417137837837839, 0.9194517972972972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 76}], {
             RGBColor[
             0.9913476081081081, 0.9903660540540541, 0.769506581081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 81}], {
             RGBColor[
             0.9763199324324323, 0.9411575135135135, 0.5849945270270269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 87}], {
             RGBColor[
             0.9702629189189189, 0.9767451621621621, 0.9084617027027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 89}], {
             RGBColor[
             0.9895871351351351, 0.9899620270270271, 0.8222316486486485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 107}], {
             RGBColor[
             0.5833578783783784, 0.6473061756756757, 0.8927682162162162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 127}], {
             RGBColor[
             0.9886879459459459, 0.9895901891891892, 0.8371335405405405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 129}], {
             RGBColor[
             0.969778472972973, 0.9178511621621622, 0.5660425945945945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 141}], {
             RGBColor[
             0.9852080405405406, 0.9711391891891892, 0.6195231486486485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 142}], {
             RGBColor[
             0.9623991891891892, 0.9708804054054054, 0.9217729459459458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 147}], {
             RGBColor[
             0.9859903783783783, 0.9884746756756757, 0.8818392162162161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 155}], {
             RGBColor[
             0.9163961081081081, 0.9342325945945946, 0.9185569054054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 168}], {
             RGBColor[
             0.5833578783783784, 0.6473061756756757, 0.8927682162162162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 188}], {
             RGBColor[
             0.9886879459459459, 0.9895901891891892, 0.8371335405405405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 197}], {
             RGBColor[
             0.9613888513513513, 0.8845891081081081, 0.559292108108108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 76}], {
             RGBColor[
             0.9913476081081081, 0.9903660540540541, 0.769506581081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 81}], {
             RGBColor[
             0.9763199324324323, 0.9411575135135135, 0.5849945270270269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 104}], {
             RGBColor[
             0.9895871351351351, 0.9899620270270271, 0.8222316486486485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 143}], {
             RGBColor[
             0.9447694459459459, 0.8179852432432433, 0.5458828378378378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 144}], {
             RGBColor[
             0.9733572297297297, 0.9311636216216217, 0.5734849864864864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 154}], {
             RGBColor[
             0.9886879459459459, 0.9895901891891892, 0.8371335405405405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 158}], {
             RGBColor[
             0.9763199324324323, 0.9411575135135135, 0.5849945270270269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 160}], {
             RGBColor[
             0.9913855135135134, 0.9907057027027026, 0.7924278648648648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 176}], {
             RGBColor[
             0.9904463108108108, 0.9884382702702703, 0.6714059324324322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 181}], {
             RGBColor[
             0.9852080405405406, 0.9711391891891892, 0.6195231486486485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 75}], {
             RGBColor[
             0.9003888378378379, 0.9233758378378378, 0.9891893108108107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 87}], {
             RGBColor[
             0.9448733513513513, 0.9584072162162163, 0.9781992162162162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.9641975675675676, 0.9716240810810811, 0.8919691621621622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 107}], {
             RGBColor[
             0.5579683108108108, 0.6289682297297298, 0.9625057297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 130}], {
             RGBColor[0.9615, 0.9705085675675675, 0.9366748378378379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 142}], {
             RGBColor[
             0.9370096216216216, 0.9525424594594595, 0.9915104594594595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 147}], {
             RGBColor[
             0.9606008108108108, 0.9701367297297298, 0.9515767297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 149}], {
             RGBColor[
             0.9276096621621621, 0.832989108108108, 0.6222791351351351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 157}], {
             RGBColor[
             0.9097711351351351, 0.930857027027027, 0.9900842027027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 167}], {
             RGBColor[
             0.9648314189189189, 0.9696183783783784, 0.7166182837837837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 168}], {
             RGBColor[
             0.5579683108108108, 0.6289682297297298, 0.9625057297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 188}], {
             RGBColor[
             0.9632983783783784, 0.9712522432432433, 0.9068710540540541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 189}], {
             RGBColor[
             0.9401940945945946, 0.8828821891891891, 0.6324048648648648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 197}], {
             RGBColor[
             0.9359992837837838, 0.8662511621621622, 0.6290296216216216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 85}], {
             RGBColor[
             0.9911201756756757, 0.9883281621621622, 0.6319788783783783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 88}], {
             RGBColor[
             0.9648314189189189, 0.9696183783783784, 0.7166182837837838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 93}], {
             RGBColor[
             0.9766270135135136, 0.9784155135135135, 0.6966514189189188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 95}], {
             RGBColor[
             0.9596262702702703, 0.866696054054054, 0.35076220270270264`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 121}], {
             RGBColor[
             0.9884226081081081, 0.9872126486486487, 0.6766845540540539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 140}], {
             RGBColor[
             0.9935545135135135, 0.9886220810810811, 0.5398267567567566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 152}], {
             RGBColor[
             0.9876402702702702, 0.9698771621621621, 0.4143684864864863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 159}], {
             RGBColor[
             0.9906029729729731, 0.9798710540540541, 0.42587802702702693`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 161}], {
             RGBColor[
             0.992918554054054, 0.9890718378378378, 0.6021750945945945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 162}], {
             RGBColor[
             0.5857901081081082, 0.6460441486486487, 0.687613554054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 164}], {
             RGBColor[
             0.9469752297297298, 0.9554141351351351, 0.7160869189189187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 172}], {
             RGBColor[
             0.5857901081081082, 0.6460441486486487, 0.687613554054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 173}], {
             RGBColor[0.9920193648648649, 0.9887, 0.6170769864864863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 180}], {
             RGBColor[
             0.9817148648648649, 0.9498893783783784, 0.39134940540540536`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 81}], {
             RGBColor[
             0.9143095810810811, 0.8936529459459459, 0.6524108918918918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 89}], {
             RGBColor[
             0.9275767837837838, 0.9424574594594595, 0.8896480135135134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 118}], {
             RGBColor[
             0.8637680540540541, 0.8942092162162163, 0.9868681621621621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 127}], {
             RGBColor[
             0.9266775945945946, 0.9420856216216217, 0.9045499054054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 129}], {
             RGBColor[
             0.9077681216216217, 0.8703465945945947, 0.6334589594594594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 141}], {
             RGBColor[
             0.9231976891891892, 0.9236346216216216, 0.6869395135135135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 142}], {
             RGBColor[
             0.9003888378378379, 0.9233758378378378, 0.9891893108108107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 147}], {
             RGBColor[
             0.9239800270270271, 0.9409701081081081, 0.949255581081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 155}], {
             RGBColor[
             0.8543857567567568, 0.886728027027027, 0.9859732702702703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 168}], {
             RGBColor[
             0.521347527027027, 0.5998016081081081, 0.9601845810810811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 188}], {
             RGBColor[
             0.9266775945945946, 0.9420856216216217, 0.9045499054054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 191}], {
             RGBColor[
             0.9284359594594596, 0.9409337027027027, 0.7388222972972971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 81}], {
             RGBColor[
             0.9798787837837837, 0.9423052162162162, 0.5024656756756756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 87}], {
             RGBColor[
             0.9738217702702703, 0.9778928648648648, 0.8259328513513513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 89}], {
             RGBColor[
             0.9931459864864864, 0.9911097297297298, 0.7397027972972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[
             0.9931459864864864, 0.9911097297297298, 0.7397027972972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 106}], {
             RGBColor[
             0.9917295945945945, 0.9822807837837838, 0.5485038378378377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 107}], {
             RGBColor[
             0.5869167297297297, 0.6484538783783784, 0.8102393648648649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 142}], {
             RGBColor[
             0.9659580405405406, 0.9720281081081081, 0.8392440945945946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 143}], {
             RGBColor[
             0.9483282972972973, 0.819132945945946, 0.4633539864864865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 147}], {
             RGBColor[
             0.9895492297297297, 0.9896223783783784, 0.7993103648648648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 154}], {
             RGBColor[
             0.9922467972972973, 0.9907378918918919, 0.7546046891891891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[
             0.938719554054054, 0.9503426756756757, 0.8378178378378378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 158}], {
             RGBColor[
             0.9798787837837837, 0.9423052162162162, 0.5024656756756756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 176}], {
             RGBColor[
             0.9940051621621622, 0.989585972972973, 0.5888770810810809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 181}], {
             RGBColor[
             0.9887668918918919, 0.9722868918918919, 0.5369942972972972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 188}], {
             RGBColor[
             0.9922467972972973, 0.9907378918918919, 0.7546046891891891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 83}], {
             RGBColor[
             0.9754207432432431, 0.9407856756756756, 0.5998964189189189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 96}], {
             RGBColor[
             0.9767019189189189, 0.9330722432432432, 0.36399178378378366`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 99}], {
             RGBColor[
             0.571889054054054, 0.5992453378378377, 0.6257273108108108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 112}], {
             RGBColor[
             0.9548622297297297, 0.9257519459459459, 0.6480764189189188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 143}], {
             RGBColor[
             0.9333006216216215, 0.7699244054054053, 0.2788419324324324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 156}], {
             RGBColor[
             0.9789774864864864, 0.9403774324324323, 0.4043650270270268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 160}], {
             RGBColor[
             0.9799166891891892, 0.9426448648648648, 0.5253869594594595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 166}], {
             RGBColor[
             0.9767019189189189, 0.9330722432432432, 0.36399178378378366`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 170}], {
             RGBColor[
             0.891085054054054, 0.5136118378378378, 0.2410858108108107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 181}], {
             RGBColor[
             0.9737392162162162, 0.9230783513513512, 0.35248224324324307`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 183}], {
             RGBColor[
             0.964851108108108, 0.8930966756756755, 0.31795362162162144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 192}], {
             RGBColor[
             0.9509303648648648, 0.9228195675675674, 0.6547320405405405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 80}], {
             RGBColor[
             0.9575220540540541, 0.9656447027027026, 0.8625289054054055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 82}], {
             RGBColor[
             0.5494944189189189, 0.6222451756756757, 0.9628692567567567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 98}], {
             RGBColor[
             0.5494944189189189, 0.6222451756756757, 0.9628692567567567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 100}], {
             RGBColor[
             0.956357527027027, 0.9628953243243243, 0.7169818108108107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 113}], {
             RGBColor[
             0.9572588243243243, 0.9648231081081081, 0.8150824594594595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 120}], {
             RGBColor[
             0.9572588243243243, 0.9648231081081081, 0.8150824594594595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 124}], {
             RGBColor[
             0.9285357297297296, 0.9458194054054054, 0.9918739864864865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 136}], {
             RGBColor[
             0.9568081756756757, 0.9638592162162163, 0.766032135135135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 187}], {
             RGBColor[
             0.5494944189189189, 0.6222451756756757, 0.9628692567567567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 84}], {
             RGBColor[
             0.5860154324324325, 0.6465260945945946, 0.712138716216216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 122}], {
             RGBColor[0.9913455, 0.9888101081081082, 0.6565040405405405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 126}], {
             RGBColor[
             0.9931038648648649, 0.9876581891891892, 0.4907764324324322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 177}], {
             RGBColor[
             0.9640464054054054, 0.8838090270270271, 0.378662608108108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 179}], {
             RGBColor[
             0.9878655945945947, 0.9703591081081081, 0.43889364864864844`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 190}], {
             RGBColor[
             0.9190536621621622, 0.9334525135135135, 0.7379274054054052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 82}], {
             RGBColor[
             0.5869546351351351, 0.648793527027027, 0.8331606486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 98}], {
             RGBColor[
             0.5869546351351351, 0.648793527027027, 0.8331606486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 100}], {
             RGBColor[
             0.9938177432432433, 0.9894436756756757, 0.5872732027027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 113}], {
             RGBColor[
             0.9947190405405406, 0.9913714594594594, 0.6853738513513514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 116}], {
             RGBColor[
             0.9938177432432433, 0.9894436756756757, 0.5872732027027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 120}], {
             RGBColor[
             0.9947190405405406, 0.9913714594594594, 0.6853738513513514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 124}], {
             RGBColor[
             0.965995945945946, 0.9723677567567568, 0.8621653783783785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 125}], {
             RGBColor[
             0.994268391891892, 0.9904075675675675, 0.636323527027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 136}], {
             RGBColor[
             0.994268391891892, 0.9904075675675675, 0.636323527027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 137}], {
             RGBColor[
             0.9922847027027026, 0.9910775405405405, 0.7775259729729731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 187}], {
             RGBColor[
             0.5869546351351351, 0.648793527027027, 0.8331606486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 198}], {
             RGBColor[
             0.9949822702702703, 0.992193054054054, 0.7328202972972975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 87}], {
             RGBColor[
             0.9587940945945945, 0.9286843243243242, 0.6414207972972972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 89}], {
             RGBColor[
             0.9781183108108107, 0.9419011891891891, 0.5551907432432431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 104}], {
             RGBColor[
             0.9781183108108107, 0.9419011891891891, 0.5551907432432431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 107}], {
             RGBColor[
             0.571889054054054, 0.5992453378378377, 0.6257273108108108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 142}], {
             RGBColor[
             0.9509303648648648, 0.9228195675675674, 0.6547320405405405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 143}], {
             RGBColor[
             0.9333006216216215, 0.7699244054054053, 0.2788419324324324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 147}], {
             RGBColor[
             0.9745215540540539, 0.9404138378378377, 0.6147983108108107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 154}], {
             RGBColor[
             0.9772191216216215, 0.9415293513513513, 0.570092635135135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 157}], {
             RGBColor[
             0.9236918783783783, 0.901134135135135, 0.6533057837837837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 158}], {
             RGBColor[
             0.964851108108108, 0.8930966756756755, 0.31795362162162144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 168}], {
             RGBColor[
             0.571889054054054, 0.5992453378378377, 0.6257273108108108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 176}], {
             RGBColor[
             0.9789774864864864, 0.9403774324324323, 0.4043650270270268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 188}], {
             RGBColor[
             0.9772191216216215, 0.9415293513513513, 0.570092635135135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 98}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 100}], {
             RGBColor[
             0.585790108108108, 0.6460441486486486, 0.687613554054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 120}], {
             RGBColor[
             0.5866914054054053, 0.6479719324324325, 0.7857142027027026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 124}], {
             RGBColor[
             0.5579683108108109, 0.6289682297297297, 0.9625057297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 125}], {
             RGBColor[
             0.5862407567567567, 0.6470080405405405, 0.7366638783783783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 136}], {
             RGBColor[
             0.5862407567567567, 0.6470080405405405, 0.7366638783783783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 137}], {
             RGBColor[
             0.5842570675675676, 0.6476780135135136, 0.8778663243243243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 187}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 198}], {
             RGBColor[
             0.5869546351351351, 0.6487935270270271, 0.8331606486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 122}], {
             RGBColor[
             0.9877887567567567, 0.9892183513513514, 0.8520354324324324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 156}], {
             RGBColor[
             0.9895471216216216, 0.9880664324324324, 0.6863078243243242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 166}], {
             RGBColor[
             0.987271554054054, 0.9807612432432433, 0.645934581081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 170}], {
             RGBColor[
             0.9016546891891892, 0.5613008378378379, 0.5230286081081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 175}], {
             RGBColor[
             0.9895871351351351, 0.9899620270270271, 0.8222316486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 179}], {
             RGBColor[
             0.9843088513513514, 0.9707673513513513, 0.6344250405405405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 183}], {
             RGBColor[
             0.9754207432432431, 0.9407856756756756, 0.5998964189189189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 192}], {
             RGBColor[0.9615, 0.9705085675675675, 0.9366748378378379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 126}], {
             RGBColor[
             0.5860154324324325, 0.6465260945945945, 0.712138716216216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 190}], {
             RGBColor[
             0.5119652297297297, 0.5923204189189188, 0.9592896891891892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 88}], {
             RGBColor[
             0.9632983783783784, 0.9712522432432433, 0.9068710540540541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 117}], {
             RGBColor[
             0.9861072297297298, 0.9715110270270271, 0.6046212567567566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[
             0.9868895675675675, 0.9888465135135136, 0.8669373243243244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 133}], {
             RGBColor[
             0.9360598918918919, 0.9495668108108108, 0.9054447972972972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 140}], {
             RGBColor[
             0.9920214729729729, 0.9902559459459459, 0.730079527027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 152}], {
             RGBColor[
             0.9861072297297298, 0.9715110270270271, 0.6046212567567566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 159}], {
             RGBColor[
             0.9890699324324324, 0.9815049189189189, 0.6161307972972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 161}], {
             RGBColor[
             0.9913855135135134, 0.9907057027027028, 0.7924278648648648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 173}], {
             RGBColor[
             0.9904863243243243, 0.990333864864865, 0.8073297567567568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 200}], {
             RGBColor[0.9913455, 0.9888101081081082, 0.6565040405405405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 92}], {
             RGBColor[
             0.9454191756756757, 0.9260904054054055, 0.6666051081081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[
             0.9172722837837839, 0.903646837837838, 0.6639204324324324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 171}], {
             RGBColor[
             0.9617567972972974, 0.9386782162162163, 0.6529303378378379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 174}], {
             RGBColor[
             0.9678138108108107, 0.9030905675675676, 0.3294631621621621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 196}], {
             RGBColor[
             0.9810810135135135, 0.9518950810810811, 0.5667002837837838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 89}], {
             RGBColor[
             0.9720612972972973, 0.9774888378378379, 0.8786579189189189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 106}], {
             RGBColor[
             0.9706449054054054, 0.9686598918918918, 0.6874589594594593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 107}], {
             RGBColor[
             0.5658320405405405, 0.6348329864864865, 0.9491944864864865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 130}], {
             RGBColor[
             0.9693637297297297, 0.9763733243243243, 0.9233635945945946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 131}], {
             RGBColor[
             0.9522526351351351, 0.905377972972973, 0.6224688648648649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 142}], {
             RGBColor[
             0.9448733513513513, 0.9584072162162163, 0.9781992162162162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 147}], {
             RGBColor[
             0.9684645405405405, 0.9760014864864865, 0.9382654864864864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[0.9711621081081081, 0.977117, 0.8935598108108107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 157}], {
             RGBColor[
             0.9176348648648648, 0.9367217837837838, 0.9767729594594594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 168}], {
             RGBColor[
             0.5658320405405405, 0.6348329864864865, 0.9491944864864865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 176}], {
             RGBColor[
             0.972920472972973, 0.9759650810810812, 0.7278322027027025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 188}], {
             RGBColor[0.9711621081081081, 0.977117, 0.8935598108108107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 91}], {
             RGBColor[
             0.9285357297297296, 0.9458194054054054, 0.9918739864864865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 93}], {
             RGBColor[
             0.9488052162162162, 0.9613395945945946, 0.9715435945945946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 95}], {
             RGBColor[
             0.931804472972973, 0.8496201351351351, 0.6256543783783783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 103}], {
             RGBColor[
             0.5579683108108108, 0.6289682297297298, 0.9625057297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 117}], {
             RGBColor[
             0.959818472972973, 0.9528012432432432, 0.6892606621621621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 121}], {
             RGBColor[
             0.9606008108108108, 0.9701367297297298, 0.9515767297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 152}], {
             RGBColor[
             0.959818472972973, 0.9528012432432432, 0.6892606621621621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 159}], {
             RGBColor[
             0.9627811756756757, 0.9627951351351351, 0.7007702027027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 161}], {
             RGBColor[
             0.9650967567567568, 0.9719959189189189, 0.8770672702702703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 164}], {
             RGBColor[
             0.9191534324324324, 0.9383382162162162, 0.9909790945945947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 173}], {
             RGBColor[
             0.9641975675675676, 0.9716240810810811, 0.8919691621621622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 180}], {
             RGBColor[
             0.9538930675675676, 0.9328134594594595, 0.6662415810810811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 200}], {
             RGBColor[
             0.9650567432432433, 0.9701003243243244, 0.7411434459459458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 106}], {
             RGBColor[
             0.9899691216216215, 0.9818767567567568, 0.6012289054054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 107}], {
             RGBColor[
             0.5851562567567568, 0.6480498513513514, 0.8629644324324324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 142}], {
             RGBColor[
             0.9641975675675676, 0.9716240810810811, 0.8919691621621622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 147}], {
             RGBColor[
             0.9877887567567567, 0.9892183513513514, 0.8520354324324324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 154}], {
             RGBColor[
             0.9904863243243243, 0.990333864864865, 0.8073297567567568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 157}], {
             RGBColor[
             0.9369590810810811, 0.9499386486486486, 0.8905429054054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 168}], {
             RGBColor[
             0.5851562567567568, 0.6480498513513514, 0.8629644324324324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 176}], {
             RGBColor[
             0.9922446891891892, 0.989181945945946, 0.6416021486486485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 188}], {
             RGBColor[
             0.9904863243243243, 0.990333864864865, 0.8073297567567568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 111}], {
             RGBColor[
             0.9427625135135136, 0.8099033513513514, 0.27736641891891894`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 115}], {
             RGBColor[
             0.9764654324324324, 0.9313474324324325, 0.4419058108108109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 163}], {
             RGBColor[
             0.9427625135135136, 0.8099033513513514, 0.27736641891891894`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 165}], {
             RGBColor[
             0.9764654324324324, 0.9313474324324325, 0.4419058108108109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 169}], {
             RGBColor[
             0.951899527027027, 0.9157580540540541, 0.6365668783783784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 175}], {
             RGBColor[
             0.9760547972972973, 0.9322791351351352, 0.5287793108108109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 177}], {
             RGBColor[
             0.9469573243243243, 0.8265343783783784, 0.2807416621621622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 103}], {
             RGBColor[
             0.5494944189189189, 0.6222451756756757, 0.9628692567567567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 117}], {
             RGBColor[
             0.951344581081081, 0.9460781891891892, 0.6896241891891891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 121}], {
             RGBColor[
             0.9521269189189189, 0.9634136756756757, 0.9519402567567568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 152}], {
             RGBColor[
             0.951344581081081, 0.9460781891891892, 0.6896241891891891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 159}], {
             RGBColor[
             0.9543072837837838, 0.9560720810810811, 0.7011337297297298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 164}], {
             RGBColor[
             0.9106795405405406, 0.9316151621621622, 0.9913426216216217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 200}], {
             RGBColor[
             0.9565828513513513, 0.9633772702702703, 0.7415069729729729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 118}], {
             RGBColor[
             0.8919149459459459, 0.9166527837837839, 0.9895528378378378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 123}], {
             RGBColor[
             0.9442631891891892, 0.957548918918919, 0.9652514999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 139}], {
             RGBColor[
             0.8825326486486487, 0.9091715945945946, 0.9886579459459459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 141}], {
             RGBColor[
             0.951344581081081, 0.9460781891891892, 0.6896241891891891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 146}], {
             RGBColor[
             0.9191357702702703, 0.8262660540540541, 0.6226426621621621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 171}], {
             RGBColor[
             0.9363994594594593, 0.9516841621621621, 0.9785627432432432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 174}], {
             RGBColor[
             0.942456472972973, 0.9160965135135135, 0.6550955675675675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 186}], {
             RGBColor[
             0.9572588243243243, 0.9648231081081081, 0.8150824594594595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 191}], {
             RGBColor[
             0.9565828513513513, 0.9633772702702703, 0.7415069729729729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 195}], {
             RGBColor[
             0.9530261081081081, 0.9637855135135136, 0.9370383648648649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 196}], {
             RGBColor[
             0.9557236756756756, 0.9649010270270271, 0.8923326891891892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 95}], {
             RGBColor[
             0.9436000675675675, 0.8584172702702704, 0.6056875135135136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 121}], {
             RGBColor[
             0.9723964054054053, 0.9789338648648649, 0.9316098648648649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 150}], {
             RGBColor[
             0.9215667297297296, 0.9396541621621621, 0.9701173378378378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 159}], {
             RGBColor[
             0.9745767702702702, 0.9715922702702703, 0.6808033378378378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 161}], {
             RGBColor[
             0.9768923513513512, 0.9807930540540541, 0.8571004054054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 162}], {
             RGBColor[
             0.5697639054054053, 0.6377653648648649, 0.9425388648648649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 164}], {
             RGBColor[
             0.930949027027027, 0.9471353513513514, 0.9710122297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 173}], {
             RGBColor[
             0.975993162162162, 0.9804212162162163, 0.8720022972972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 180}], {
             RGBColor[
             0.9656886621621621, 0.9416105945945947, 0.6462747162162162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 200}], {
             RGBColor[
             0.9768523378378378, 0.9788974594594595, 0.721176581081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 174}], {
             RGBColor[
             0.9143095810810811, 0.8936529459459459, 0.6524108918918918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 196}], {
             RGBColor[
             0.9275767837837838, 0.9424574594594595, 0.8896480135135134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 121}], {
             RGBColor[
             0.9553956621621622, 0.8672144054054054, 0.5857206486486486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 150}], {
             RGBColor[
             0.9045659864864865, 0.8279347027027026, 0.6242281216216217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 159}], {
             RGBColor[
             0.957576027027027, 0.8598728108108109, 0.3349141216216216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 161}], {
             RGBColor[
             0.9598916081081081, 0.8690735945945947, 0.5112111891891893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 162}], {
             RGBColor[
             0.5527631621621621, 0.5260459054054054, 0.5966496486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 164}], {
             RGBColor[
             0.9139482837837838, 0.8354158918918919, 0.6251230135135135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 173}], {
             RGBColor[
             0.958992418918919, 0.8687017567567568, 0.526113081081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 180}], {
             RGBColor[
             0.948687918918919, 0.8298911351351352, 0.3003855000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 99}], {
             RGBColor[
             0.5837398648648648, 0.6392209054054054, 0.671765472972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 102}], {
             RGBColor[0.9917675, 0.9826204324324324, 0.5714251216216217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 125}], {
             RGBColor[
             0.9910536216216217, 0.980834945945946, 0.4749283513513512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 128}], {
             RGBColor[
             0.9899691216216215, 0.9818767567567568, 0.6012289054054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 137}], {
             RGBColor[
             0.9890699324324324, 0.9815049189189189, 0.6161307972972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 166}], {
             RGBColor[
             0.9885527297297297, 0.9730478108108108, 0.4100299459459459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 170}], {
             RGBColor[
             0.9029358648648649, 0.5535874054054054, 0.28712397297297293`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 198}], {
             RGBColor[0.9917675, 0.9826204324324324, 0.5714251216216217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 105}], {
             RGBColor[
             0.9846775675675676, 0.9598832702702702, 0.4028589459459458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 134}], {
             RGBColor[
             0.9831445270270269, 0.9615171351351351, 0.5931117162162162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 135}], {
             RGBColor[
             0.9003417567567568, 0.5592054324324324, 0.2672949459459459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 153}], {
             RGBColor[
             0.939226027027027, 0.7899121891891892, 0.30186101351351347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 100}], {
             RGBColor[
             0.585790108108108, 0.6460441486486486, 0.687613554054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 109}], {
             RGBColor[
             0.5443735405405405, 0.4927838513513514, 0.5898991621621622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 113}], {
             RGBColor[
             0.5866914054054053, 0.6479719324324325, 0.7857142027027026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 116}], {
             RGBColor[
             0.585790108108108, 0.6460441486486486, 0.687613554054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 120}], {
             RGBColor[
             0.5866914054054053, 0.6479719324324325, 0.7857142027027026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 124}], {
             RGBColor[
             0.5579683108108109, 0.6289682297297297, 0.9625057297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 125}], {
             RGBColor[
             0.5862407567567567, 0.6470080405405405, 0.7366638783783783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 136}], {
             RGBColor[
             0.5862407567567567, 0.6470080405405405, 0.7366638783783783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 187}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 102}], {
             RGBColor[
             0.5869546351351351, 0.6487935270270271, 0.8331606486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 109}], {
             RGBColor[
             0.5443735405405405, 0.4927838513513514, 0.5898991621621622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 116}], {
             RGBColor[
             0.585790108108108, 0.6460441486486486, 0.687613554054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 128}], {
             RGBColor[
             0.5851562567567568, 0.6480498513513513, 0.8629644324324324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 136}], {
             RGBColor[
             0.5862407567567567, 0.6470080405405405, 0.7366638783783783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 137}], {
             RGBColor[
             0.5842570675675676, 0.6476780135135136, 0.8778663243243243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 162}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 193}], {
             RGBColor[
             0.5736957702702703, 0.6406977432432432, 0.9358832432432432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 198}], {
             RGBColor[
             0.5869546351351351, 0.6487935270270271, 0.8331606486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 113}], {
             RGBColor[
             0.9935545135135135, 0.9886220810810811, 0.5398267567567566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 120}], {
             RGBColor[
             0.9935545135135135, 0.9886220810810811, 0.5398267567567566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 124}], {
             RGBColor[
             0.9648314189189189, 0.9696183783783784, 0.7166182837837838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 125}], {
             RGBColor[
             0.9931038648648649, 0.9876581891891891, 0.4907764324324322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 136}], {
             RGBColor[
             0.9931038648648649, 0.9876581891891891, 0.4907764324324322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 137}], {
             RGBColor[
             0.9911201756756757, 0.9883281621621622, 0.6319788783783783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 187}], {
             RGBColor[
             0.5857901081081082, 0.6460441486486487, 0.687613554054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 198}], {
             RGBColor[
             0.9938177432432433, 0.9894436756756757, 0.5872732027027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 105}], {
             RGBColor[
             0.585790108108108, 0.6460441486486486, 0.687613554054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 134}], {
             RGBColor[
             0.5842570675675676, 0.6476780135135136, 0.8778663243243243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 135}], {
             RGBColor[
             0.5014542972972973, 0.24536631081081076`, 0.5520495540540541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 144}], {
             RGBColor[
             0.5689263513513514, 0.5892514459459459, 0.6142177702702702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 128}], {
             RGBColor[
             0.9931838918918918, 0.9914493783783784, 0.7626240810810812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 140}], {
             RGBColor[
             0.9947190405405406, 0.9913714594594594, 0.6853738513513514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 162}], {
             RGBColor[
             0.5869546351351351, 0.648793527027027, 0.8331606486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 172}], {
             RGBColor[
             0.5869546351351351, 0.648793527027027, 0.8331606486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 180}], {
             RGBColor[
             0.9828793918918919, 0.9526387567567568, 0.5368965000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 117}], {
             RGBColor[
             0.5807771621621622, 0.6292270135135134, 0.6602559324324324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 152}], {
             RGBColor[
             0.5807771621621622, 0.6292270135135134, 0.6602559324324324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 178}], {
             RGBColor[
             0.5860154324324325, 0.6465260945945945, 0.712138716216216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 200}], {
             RGBColor[
             0.5860154324324325, 0.6465260945945945, 0.712138716216216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 143}], {
             RGBColor[
             0.9465678243243243, 0.818728918918919, 0.5160790540540541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 154}], {
             RGBColor[
             0.9904863243243243, 0.990333864864865, 0.8073297567567568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 158}], {
             RGBColor[
             0.9781183108108107, 0.9419011891891891, 0.5551907432432431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 160}], {
             RGBColor[
             0.9931838918918918, 0.9914493783783784, 0.7626240810810812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 176}], {
             RGBColor[
             0.9922446891891892, 0.989181945945946, 0.6416021486486485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 181}], {
             RGBColor[
             0.9870064189189189, 0.9718828648648649, 0.5897193648648648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 188}], {
             RGBColor[
             0.9904863243243243, 0.990333864864865, 0.8073297567567568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 134}], {
             RGBColor[
             0.9911201756756757, 0.9883281621621622, 0.6319788783783783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 135}], {
             RGBColor[
             0.9083174054054055, 0.5860164594594595, 0.306162108108108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 144}], {
             RGBColor[
             0.9757894594594595, 0.9299015945945945, 0.3683303243243242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.5837398648648648, 0.6392209054054054, 0.671765472972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 130}], {
             RGBColor[
             0.987271554054054, 0.9807612432432433, 0.645934581081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 131}], {
             RGBColor[
             0.9701604594594595, 0.9097658918918919, 0.3450398513513513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 142}], {
             RGBColor[
             0.9627811756756757, 0.9627951351351351, 0.7007702027027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 147}], {
             RGBColor[
             0.9863723648648648, 0.9803894054054054, 0.660836472972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 157}], {
             RGBColor[
             0.9355426891891891, 0.9411097027027027, 0.6993439459459458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 176}], {
             RGBColor[0.9908282972972973, 0.980353, 0.45040318918918903`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 130}], {
             RGBColor[
             0.5824586891891892, 0.6469343378378378, 0.9076701081081082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 131}], {
             RGBColor[
             0.5653475945945947, 0.5759389864864866, 0.6067753783783784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 142}], {
             RGBColor[
             0.5579683108108109, 0.6289682297297297, 0.9625057297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[0.5815595, 0.6465624999999999, 0.922572]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{107, 154}], {
             RGBColor[
             0.5842570675675676, 0.6476780135135136, 0.8778663243243243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.5307298243243244, 0.6072827972972972, 0.961079472972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 168}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 176}], {
             RGBColor[
             0.5860154324324325, 0.6465260945945945, 0.712138716216216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 188}], {
             RGBColor[
             0.5842570675675676, 0.6476780135135136, 0.8778663243243243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 111}], {
             RGBColor[
             0.958992418918919, 0.8687017567567568, 0.526113081081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 115}], {
             RGBColor[
             0.9926953378378378, 0.9901458378378378, 0.690652472972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 133}], {
             RGBColor[
             0.9369590810810811, 0.9499386486486486, 0.8905429054054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 151}], {
             RGBColor[
             0.9810810135135135, 0.9518950810810811, 0.5667002837837838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 163}], {
             RGBColor[
             0.958992418918919, 0.8687017567567568, 0.526113081081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 165}], {
             RGBColor[
             0.9926953378378378, 0.9901458378378378, 0.690652472972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 175}], {
             RGBColor[
             0.9922847027027026, 0.9910775405405405, 0.777525972972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 113}], {
             RGBColor[
             0.9521379459459459, 0.8353617837837838, 0.4421123648648648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 116}], {
             RGBColor[0.9512366486486487, 0.833434, 0.3440117162162161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 124}], {
             RGBColor[
             0.9234148513513514, 0.8163580810810811, 0.6189038918918919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 128}], {
             RGBColor[
             0.9506027972972972, 0.8354397027027027, 0.5193625945945946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 136}], {
             RGBColor[
             0.9516872972972973, 0.834397891891892, 0.3930620405405404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 148}], {
             RGBColor[
             0.8961763648648648, 0.7946726486486486, 0.6174776351351352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 193}], {
             RGBColor[
             0.9391423108108108, 0.8280875945945947, 0.5922814054054053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 138}], {
             RGBColor[
             0.9723964054054053, 0.9789338648648649, 0.9316098648648649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 145}], {
             RGBColor[
             0.977753635135135, 0.9808252432432433, 0.8192772297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 115}], {
             RGBColor[
             0.9603022432432433, 0.868141891891892, 0.42433768918918924`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 163}], {
             RGBColor[
             0.9265993243243243, 0.7466978108108109, 0.2597982972972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 165}], {
             RGBColor[
             0.9603022432432433, 0.868141891891892, 0.42433768918918924`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 169}], {
             RGBColor[
             0.9357363378378378, 0.8525525135135136, 0.6189987567567568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 175}], {
             RGBColor[
             0.9598916081081081, 0.8690735945945947, 0.5112111891891893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 177}], {
             RGBColor[
             0.9307941351351352, 0.7633288378378379, 0.26317354054054054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 134}], {
             RGBColor[
             0.9672302432432431, 0.9741846216216217, 0.9002154324324324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 143}], {
             RGBColor[
             0.9233117432432432, 0.8025796756756758, 0.6089647297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 156}], {
             RGBColor[
             0.968988608108108, 0.9730327027027028, 0.7344878243243242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 160}], {
             RGBColor[
             0.9699278108108108, 0.9753001351351351, 0.8555097567567569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 181}], {
             RGBColor[
             0.9637503378378378, 0.9557336216216217, 0.6826050405405404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 183}], {
             RGBColor[
             0.9548622297297297, 0.9257519459459459, 0.6480764189189188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 116}], {
             RGBColor[
             0.9935545135135135, 0.9886220810810811, 0.5398267567567566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 124}], {
             RGBColor[
             0.9657327162162161, 0.9715461621621622, 0.8147189324324324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 128}], {
             RGBColor[
             0.9929206621621621, 0.9906277837837838, 0.7151776351351351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 136}], {
             RGBColor[
             0.9940051621621622, 0.989585972972973, 0.5888770810810809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 148}], {
             RGBColor[
             0.9384942297297296, 0.9498607297297297, 0.8132926756756756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 187}], {
             RGBColor[
             0.5866914054054054, 0.6479719324324325, 0.7857142027027026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 193}], {
             RGBColor[
             0.9814601756756757, 0.9832756756756758, 0.7880964459459459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 198}], {
             RGBColor[
             0.9947190405405406, 0.9913714594594594, 0.6853738513513514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 167}], {
             RGBColor[
             0.9911201756756757, 0.9883281621621622, 0.6319788783783783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 184}], {
             RGBColor[
             0.9913855135135134, 0.9907057027027028, 0.7924278648648648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 186}], {
             RGBColor[
             0.9920214729729729, 0.9902559459459459, 0.730079527027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 194}], {
             RGBColor[
             0.9904863243243243, 0.990333864864865, 0.8073297567567568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 133}], {
             RGBColor[
             0.9382689054054054, 0.9493787837837837, 0.7887675135135135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 163}], {
             RGBColor[
             0.9603022432432433, 0.868141891891892, 0.42433768918918924`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 165}], {
             RGBColor[
             0.9940051621621622, 0.989585972972973, 0.5888770810810812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 175}], {
             RGBColor[
             0.993594527027027, 0.9905176756756757, 0.6757505810810811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 124}], {
             RGBColor[
             0.9648314189189189, 0.9696183783783784, 0.7166182837837838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 128}], {
             RGBColor[0.9920193648648649, 0.9887, 0.6170769864864863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 136}], {
             RGBColor[
             0.9931038648648649, 0.9876581891891891, 0.4907764324324322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 148}], {
             RGBColor[
             0.9375929324324324, 0.9479329459459459, 0.7151920270270269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 193}], {
             RGBColor[
             0.9805588783783784, 0.9813478918918919, 0.6899957972972972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 198}], {
             RGBColor[
             0.9938177432432433, 0.9894436756756757, 0.5872732027027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 121}], {
             RGBColor[
             0.9834096621621622, 0.9703955135135135, 0.6493269324324323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 152}], {
             RGBColor[
             0.9826273243243243, 0.953060027027027, 0.3870108648648647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 159}], {
             RGBColor[
             0.985590027027027, 0.9630539189189189, 0.3985204054054053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 164}], {
             RGBColor[
             0.9419622837837838, 0.9385969999999999, 0.6887292972972971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 178}], {
             RGBColor[
             0.9878655945945947, 0.9703591081081081, 0.43889364864864844`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 200}], {
             RGBColor[
             0.9878655945945947, 0.9703591081081081, 0.43889364864864844`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 119}], {
             RGBColor[
             0.8909888783783784, 0.8038224864864865, 0.6199579864864865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 123}], {
             RGBColor[
             0.9161162972972974, 0.9351053513513514, 0.9625668243243243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 127}], {
             RGBColor[
             0.9266775945945946, 0.9420856216216217, 0.9045499054054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 129}], {
             RGBColor[
             0.9077681216216217, 0.8703465945945947, 0.6334589594594594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 139}], {
             RGBColor[
             0.8543857567567568, 0.886728027027027, 0.9859732702702703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[
             0.9231976891891892, 0.9236346216216216, 0.6869395135135135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 146}], {
             RGBColor[
             0.8909888783783784, 0.8038224864864865, 0.6199579864864865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 155}], {
             RGBColor[
             0.8543857567567568, 0.886728027027027, 0.9859732702702703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 171}], {
             RGBColor[
             0.9082525675675676, 0.9292405945945946, 0.9758780675675676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 191}], {
             RGBColor[
             0.9284359594594596, 0.9409337027027027, 0.7388222972972971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.9248792162162163, 0.941341945945946, 0.9343536891891893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 196}], {
             RGBColor[
             0.9275767837837838, 0.9424574594594595, 0.8896480135135134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[
             0.521347527027027, 0.5998016081081081, 0.9601845810810811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 123}], {
             RGBColor[
             0.9433371216216216, 0.8447186216216216, 0.5956566486486485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 127}], {
             RGBColor[
             0.9538984189189189, 0.8516988918918919, 0.5376397297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 140}], {
             RGBColor[
             0.9563327567567568, 0.8519928108108108, 0.44548760810810806`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 151}], {
             RGBColor[
             0.9444931081081082, 0.8132601081081081, 0.2970102567567568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 155}], {
             RGBColor[
             0.8816065810810811, 0.7963412972972972, 0.6190630945945945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 156}], {
             RGBColor[
             0.9556567837837838, 0.8505469729729729, 0.37191212162162146`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 172}], {
             RGBColor[
             0.5485683513513514, 0.5094148783783783, 0.5932744054054053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 191}], {
             RGBColor[
             0.9556567837837838, 0.8505469729729729, 0.37191212162162146`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 195}], {
             RGBColor[
             0.9521000405405405, 0.8509552162162162, 0.5674435135135136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 199}], {
             RGBColor[
             0.5485683513513514, 0.5094148783783783, 0.5932744054054053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 124}], {
             RGBColor[
             0.9657327162162161, 0.9715461621621622, 0.8147189324324324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 125}], {
             RGBColor[
             0.9940051621621622, 0.989585972972973, 0.5888770810810809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 136}], {
             RGBColor[
             0.9940051621621622, 0.989585972972973, 0.5888770810810809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 137}], {
             RGBColor[
             0.9920214729729729, 0.9902559459459459, 0.730079527027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 187}], {
             RGBColor[
             0.5866914054054054, 0.6479719324324325, 0.7857142027027026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 198}], {
             RGBColor[
             0.9947190405405406, 0.9913714594594594, 0.6853738513513514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 152}], {
             RGBColor[
             0.9834096621621622, 0.9703955135135135, 0.6493269324324323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 159}], {
             RGBColor[
             0.9863723648648648, 0.9803894054054054, 0.660836472972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 161}], {
             RGBColor[
             0.9886879459459459, 0.9895901891891892, 0.8371335405405406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 164}], {
             RGBColor[
             0.9427446216216215, 0.9559324864864864, 0.9510453648648649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 173}], {
             RGBColor[
             0.9877887567567567, 0.9892183513513514, 0.8520354324324324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 180}], {
             RGBColor[
             0.9774842567567568, 0.9504077297297298, 0.6263078513513514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[
             0.9886479324324324, 0.9876945945945946, 0.7012097162162161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 125}], {
             RGBColor[
             0.9915708243243243, 0.9892920540540541, 0.6810292027027025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 137}], {
             RGBColor[
             0.9895871351351351, 0.9899620270270271, 0.8222316486486486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 166}], {
             RGBColor[
             0.9890699324324324, 0.9815049189189189, 0.6161307972972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 170}], {
             RGBColor[
             0.9034530675675676, 0.5620445135135135, 0.4932248243243243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 179}], {
             RGBColor[
             0.9861072297297298, 0.9715110270270271, 0.6046212567567566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 192}], {
             RGBColor[
             0.9632983783783784, 0.9712522432432433, 0.9068710540540541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 127}], {
             RGBColor[
             0.9790258378378378, 0.9829817567567568, 0.8802485675675675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 129}], {
             RGBColor[
             0.960116364864865, 0.9112427297297299, 0.6091576216216216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 139}], {
             RGBColor[0.906734, 0.9276241621621621, 0.9616719324324324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 141}], {
             RGBColor[
             0.9755459324324325, 0.9645307567567567, 0.6626381756756756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 146}], {
             RGBColor[
             0.9433371216216216, 0.8447186216216216, 0.5956566486486486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 155}], {
             RGBColor[0.906734, 0.9276241621621621, 0.9616719324324324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 171}], {
             RGBColor[
             0.9606008108108108, 0.9701367297297298, 0.9515767297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 191}], {
             RGBColor[
             0.9807842027027027, 0.9818298378378378, 0.7145209594594593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 195}], {
             RGBColor[
             0.9772274594594594, 0.9822380810810811, 0.9100523513513514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 196}], {
             RGBColor[
             0.979925027027027, 0.9833535945945946, 0.8653466756756756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 199}], {
             RGBColor[
             0.5736957702702703, 0.6406977432432432, 0.9358832432432432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 125}], {
             RGBColor[
             0.9652820675675675, 0.9705822702702702, 0.765668608108108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 136}], {
             RGBColor[
             0.9652820675675675, 0.9705822702702702, 0.765668608108108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.9632983783783784, 0.9712522432432433, 0.9068710540540541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 187}], {
             RGBColor[
             0.5579683108108108, 0.6289682297297298, 0.9625057297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 198}], {
             RGBColor[
             0.965995945945946, 0.9723677567567568, 0.8621653783783785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 136}], {
             RGBColor[
             0.9935545135135135, 0.9886220810810811, 0.5398267567567565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 137}], {
             RGBColor[
             0.9915708243243243, 0.9892920540540541, 0.6810292027027025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 166}], {
             RGBColor[
             0.9910536216216217, 0.980834945945946, 0.4749283513513512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[
             0.9054367567567567, 0.5613745405405406, 0.35202237837837824`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 187}], {
             RGBColor[
             0.5862407567567568, 0.6470080405405405, 0.7366638783783783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 192}], {
             RGBColor[
             0.9652820675675675, 0.9705822702702702, 0.765668608108108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 198}], {
             RGBColor[
             0.994268391891892, 0.9904075675675675, 0.636323527027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 190}], {
             RGBColor[
             0.9190536621621622, 0.9334525135135135, 0.7379274054054052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 129}], {
             RGBColor[0.9706776621621622, 0.918223, 0.5511407027027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 139}], {
             RGBColor[
             0.9172952972972973, 0.9346044324324325, 0.9036550135135135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 140}], {
             RGBColor[
             0.9920214729729729, 0.9902559459459459, 0.730079527027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 141}], {
             RGBColor[
             0.9861072297297298, 0.9715110270270271, 0.6046212567567566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 155}], {
             RGBColor[
             0.9172952972972973, 0.9346044324324325, 0.9036550135135135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 172}], {
             RGBColor[
             0.5842570675675676, 0.6476780135135135, 0.8778663243243243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 191}], {
             RGBColor[0.9913455, 0.9888101081081082, 0.6565040405405405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 195}], {
             RGBColor[
             0.9877887567567567, 0.9892183513513514, 0.8520354324324324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 199}], {
             RGBColor[
             0.5842570675675676, 0.6476780135135135, 0.8778663243243243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 136}], {
             RGBColor[
             0.9924700135135135, 0.9896638918918919, 0.6661273108108107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 162}], {
             RGBColor[
             0.5851562567567568, 0.6480498513513514, 0.8629644324324324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 193}], {
             RGBColor[
             0.979925027027027, 0.9833535945945946, 0.8653466756756756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 198}], {
             RGBColor[
             0.9931838918918918, 0.9914493783783784, 0.7626240810810812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 139}], {
             RGBColor[
             0.8983858243243243, 0.8628654054054055, 0.6325640675675677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 141}], {
             RGBColor[0.9671977567567568, 0.899772, 0.33353031081081075`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 146}], {
             RGBColor[
             0.934988945945946, 0.7799598648648649, 0.26654878378378377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 155}], {
             RGBColor[
             0.8983858243243243, 0.8628654054054055, 0.6325640675675677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 191}], {
             RGBColor[
             0.9724360270270271, 0.9170710810810812, 0.3854130945945945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 195}], {
             RGBColor[
             0.9688792837837839, 0.9174793243243244, 0.5809444864864866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 131}], {
             RGBColor[
             0.9688792837837839, 0.9174793243243244, 0.5809444864864866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 149}], {
             RGBColor[
             0.9521000405405405, 0.8509552162162162, 0.5674435135135135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 157}], {
             RGBColor[
             0.9342615135135135, 0.948823135135135, 0.9352485810810811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 168}], {
             RGBColor[
             0.5824586891891892, 0.6469343378378378, 0.9076701081081082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 189}], {
             RGBColor[
             0.9646844729729729, 0.9008482972972973, 0.5775692432432433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 197}], {
             RGBColor[
             0.9604896621621621, 0.8842172702702703, 0.5741940000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 147}], {
             RGBColor[
             0.9679800945945947, 0.9171074864864865, 0.5958463783783783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 157}], {
             RGBColor[
             0.9171504189189189, 0.8778277837837838, 0.6343538513513514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 176}], {
             RGBColor[
             0.9724360270270271, 0.9170710810810812, 0.3854130945945945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 138}], {
             RGBColor[
             0.9637852837837837, 0.9004764594594594, 0.592471135135135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 145}], {
             RGBColor[
             0.9691425135135134, 0.9023678378378379, 0.48013849999999997`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 153}], {
             RGBColor[
             0.9225643513513513, 0.729987027027027, 0.2565147567567567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 182}], {
             RGBColor[
             0.5611527837837837, 0.5593079594594594, 0.6034001351351351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 185}], {
             RGBColor[
             0.9570775405405405, 0.8631531891891893, 0.30713598648648655`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 163}], {
             RGBColor[
             0.9045659864864865, 0.8279347027027026, 0.6242281216216217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 178}], {
             RGBColor[
             0.9378182567567568, 0.9484148918918919, 0.739717189189189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 135}], {
             RGBColor[
             0.9067843648648648, 0.5876503243243243, 0.4964148783783784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 160}], {
             RGBColor[
             0.9922847027027026, 0.9910775405405405, 0.7775259729729731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 144}], {
             RGBColor[
             0.8914536486486486, 0.5292237567567567, 0.23276632432432434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 148}], {
             RGBColor[
             0.938043581081081, 0.9488968378378377, 0.7642423513513512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 187}], {
             RGBColor[
             0.5862407567567568, 0.6470080405405405, 0.7366638783783783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 193}], {
             RGBColor[
             0.981009527027027, 0.9823117837837838, 0.7390461216216215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 198}], {
             RGBColor[
             0.994268391891892, 0.9904075675675675, 0.636323527027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 166}], {
             RGBColor[
             0.9890699324324324, 0.9815049189189189, 0.6161307972972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 170}], {
             RGBColor[
             0.9034530675675676, 0.5620445135135135, 0.4932248243243243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 179}], {
             RGBColor[
             0.9861072297297298, 0.9715110270270271, 0.6046212567567566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 187}], {
             RGBColor[
             0.5842570675675676, 0.6476780135135135, 0.8778663243243243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 192}], {
             RGBColor[
             0.9632983783783784, 0.9712522432432433, 0.9068710540540541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 198}], {
             RGBColor[
             0.9922847027027026, 0.9910775405405405, 0.7775259729729731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 145}], {
             RGBColor[
             0.9895492297297297, 0.9896223783783784, 0.7993103648648648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 153}], {
             RGBColor[
             0.9429710675675675, 0.8172415675675676, 0.5756866216216217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 182}], {
             RGBColor[0.5815595, 0.6465625, 0.922572]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{138, 185}], {
             RGBColor[
             0.9774842567567568, 0.9504077297297298, 0.6263078513513514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 141}], {
             RGBColor[
             0.9138153918918919, 0.9161534324324324, 0.6860446216216216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 146}], {
             RGBColor[
             0.8816065810810811, 0.7963412972972972, 0.6190630945945946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 155}], {
             RGBColor[
             0.8450034594594595, 0.8792468378378379, 0.9850783783783784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 171}], {
             RGBColor[
             0.8988702702702702, 0.9217594054054055, 0.9749831756756757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 191}], {
             RGBColor[
             0.9190536621621622, 0.9334525135135135, 0.7379274054054052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 194}], {
             RGBColor[
             0.9181944864864865, 0.9349762702702703, 0.8887531216216216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 195}], {
             RGBColor[
             0.9154969189189189, 0.9338607567567567, 0.9334587972972974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 196}], {
             RGBColor[
             0.9181944864864865, 0.9349762702702703, 0.8887531216216216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 151}], {
             RGBColor[
             0.9826161621621622, 0.9518171621621623, 0.48945005405405406`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 161}], {
             RGBColor[
             0.9938198513513513, 0.9909996216216217, 0.7002757432432433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 162}], {
             RGBColor[
             0.5866914054054054, 0.6479719324324325, 0.7857142027027026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 172}], {
             RGBColor[
             0.5866914054054054, 0.6479719324324325, 0.7857142027027026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 173}], {
             RGBColor[
             0.9929206621621621, 0.9906277837837838, 0.7151776351351351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 180}], {
             RGBColor[
             0.9826161621621622, 0.9518171621621623, 0.48945005405405406`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 191}], {
             RGBColor[
             0.9937798378378379, 0.989104027027027, 0.5643519189189188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 146}], {
             RGBColor[
             0.9504185135135135, 0.8332478918918917, 0.3200293378378377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 155}], {
             RGBColor[
             0.9138153918918919, 0.9161534324324324, 0.6860446216216216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 167}], {
             RGBColor[
             0.9876402702702702, 0.9698771621621621, 0.4143684864864863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 191}], {
             RGBColor[
             0.9878655945945947, 0.9703591081081081, 0.43889364864864844`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 194}], {
             RGBColor[
             0.9870064189189189, 0.9718828648648649, 0.5897193648648648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 195}], {
             RGBColor[
             0.9843088513513514, 0.9707673513513513, 0.6344250405405405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 147}], {
             RGBColor[
             0.9606008108108108, 0.9701367297297298, 0.9515767297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 154}], {
             RGBColor[
             0.9632983783783784, 0.9712522432432433, 0.9068710540540541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 157}], {
             RGBColor[
             0.9097711351351351, 0.930857027027027, 0.9900842027027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 168}], {
             RGBColor[
             0.5579683108108108, 0.6289682297297298, 0.9625057297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 176}], {
             RGBColor[
             0.9650567432432433, 0.9701003243243244, 0.7411434459459458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.9632983783783784, 0.9712522432432433, 0.9068710540540541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 154}], {
             RGBColor[
             0.9456686351351351, 0.8183570810810812, 0.530980945945946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 158}], {
             RGBColor[
             0.9333006216216215, 0.7699244054054053, 0.2788419324324324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 160}], {
             RGBColor[
             0.9483662027027027, 0.8194725945945946, 0.4862752702702704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 181}], {
             RGBColor[
             0.9421887297297298, 0.7999060810810811, 0.313370554054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 188}], {
             RGBColor[
             0.9456686351351351, 0.8183570810810812, 0.530980945945946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 158}], {
             RGBColor[
             0.9618884054054053, 0.8831027837837837, 0.306444081081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 153}], {
             RGBColor[
             0.9483282972972973, 0.819132945945946, 0.4633539864864865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 185}], {
             RGBColor[
             0.9828414864864865, 0.9522991081081082, 0.5139752162162162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 155}], {
             RGBColor[
             0.8816065810810811, 0.7963412972972972, 0.6190630945945945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 171}], {
             RGBColor[
             0.9354733918918918, 0.8388538648648648, 0.6089678918918919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 184}], {
             RGBColor[
             0.9556967972972973, 0.8524425675675675, 0.507835945945946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 186}], {
             RGBColor[
             0.9563327567567568, 0.8519928108108108, 0.44548760810810806`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 191}], {
             RGBColor[
             0.9556567837837838, 0.8505469729729729, 0.37191212162162146`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 194}], {
             RGBColor[
             0.9547976081081081, 0.8520707297297296, 0.5227378378378378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 195}], {
             RGBColor[
             0.9521000405405405, 0.8509552162162162, 0.5674435135135136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 196}], {
             RGBColor[
             0.9547976081081081, 0.8520707297297296, 0.5227378378378378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 154}], {
             RGBColor[
             0.9868895675675675, 0.9888465135135136, 0.8669373243243244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 157}], {
             RGBColor[
             0.9333623243243243, 0.9484512972972973, 0.950150472972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 168}], {
             RGBColor[0.5815595, 0.6465625, 0.922572]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{147, 176}], {
             RGBColor[
             0.9886479324324324, 0.9876945945945946, 0.7012097162162161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 188}], {
             RGBColor[
             0.9868895675675675, 0.9888465135135136, 0.8669373243243244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 150}], {
             RGBColor[
             0.8825326486486486, 0.9091715945945945, 0.9886579459459459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 193}], {
             RGBColor[
             0.9254985945945946, 0.9425865405405405, 0.9634617162162162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 167}], {
             RGBColor[
             0.9554314594594595, 0.8500650270270269, 0.34738695945945935`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 168}], {
             RGBColor[
             0.5485683513513514, 0.5094148783783783, 0.5932744054054053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 189}], {
             RGBColor[
             0.9307941351351352, 0.7633288378378378, 0.26317354054054054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 194}], {
             RGBColor[
             0.9547976081081081, 0.8520707297297296, 0.5227378378378378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.9265993243243243, 0.7466978108108108, 0.2597982972972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 156}], {
             RGBColor[
             0.9819401891891892, 0.9503713243243244, 0.41587456756756747`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 172}], {
             RGBColor[
             0.5748517567567568, 0.6092392297297298, 0.6372368513513513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 175}], {
             RGBColor[
             0.9819802027027027, 0.952266918918919, 0.551798391891892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 183}], {
             RGBColor[
             0.9678138108108107, 0.9030905675675676, 0.3294631621621621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 199}], {
             RGBColor[
             0.5748517567567568, 0.6092392297297298, 0.6372368513513513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 159}], {
             RGBColor[
             0.985590027027027, 0.9630539189189189, 0.3985204054054053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 178}], {
             RGBColor[
             0.9878655945945947, 0.9703591081081081, 0.43889364864864844`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 200}], {
             RGBColor[
             0.9878655945945947, 0.9703591081081081, 0.43889364864864844`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 182}], {
             RGBColor[
             0.5403385675675676, 0.4760730675675676, 0.5866156216216216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 185}], {
             RGBColor[
             0.9362633243243244, 0.7799182972972973, 0.29035147297297303`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 157}], {
             RGBColor[
             0.9360598918918919, 0.9495668108108108, 0.9054447972972972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 158}], {
             RGBColor[
             0.9772191216216215, 0.9415293513513513, 0.570092635135135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 160}], {
             RGBColor[
             0.9922847027027026, 0.9910775405405405, 0.7775259729729731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 176}], {
             RGBColor[0.9913455, 0.9888101081081082, 0.6565040405405405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 181}], {
             RGBColor[
             0.9861072297297298, 0.9715110270270271, 0.6046212567567566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 188}], {
             RGBColor[
             0.9895871351351351, 0.9899620270270271, 0.8222316486486486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 172}], {
             RGBColor[
             0.5119652297297298, 0.592320418918919, 0.9592896891891892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 191}], {
             RGBColor[
             0.9190536621621622, 0.9334525135135135, 0.7379274054054052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 195}], {
             RGBColor[
             0.9154969189189189, 0.9338607567567567, 0.9334587972972974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 199}], {
             RGBColor[
             0.5119652297297298, 0.592320418918919, 0.9592896891891892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 166}], {
             RGBColor[0.9908282972972973, 0.980353, 0.45040318918918903`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 170}], {
             RGBColor[
             0.9052114324324325, 0.5608925945945946, 0.3274972162162161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 175}], {
             RGBColor[
             0.9931438783783784, 0.9895537837837838, 0.6267002567567567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 183}], {
             RGBColor[
             0.9789774864864864, 0.9403774324324323, 0.4043650270270268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 199}], {
             RGBColor[
             0.5860154324324325, 0.6465260945945946, 0.712138716216216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 168}], {
             RGBColor[
             0.5307298243243243, 0.6072827972972973, 0.961079472972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 176}], {
             RGBColor[
             0.9378182567567568, 0.9484148918918919, 0.739717189189189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 188}], {
             RGBColor[
             0.9360598918918919, 0.9495668108108108, 0.9054447972972972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 160}], {
             RGBColor[
             0.9799166891891892, 0.9426448648648648, 0.5253869594594595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 176}], {
             RGBColor[
             0.9789774864864864, 0.9403774324324323, 0.4043650270270268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.9737392162162162, 0.9230783513513512, 0.35248224324324307`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 161}], {
             RGBColor[
             0.9908683108108107, 0.9822485945945947, 0.5863270135135135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 162}], {
             RGBColor[
             0.5837398648648648, 0.6392209054054054, 0.671765472972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 164}], {
             RGBColor[
             0.9449249864864865, 0.9485908918918919, 0.7002388378378378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 173}], {
             RGBColor[
             0.9899691216216215, 0.9818767567567568, 0.6012289054054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 180}], {
             RGBColor[
             0.9796646216216216, 0.9430661351351353, 0.37550132432432437`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 200}], {
             RGBColor[0.9908282972972973, 0.980353, 0.45040318918918903`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[
             0.9888047972972973, 0.9726265405405405, 0.5599155810810811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 162}], {
             RGBColor[
             0.5860554459459459, 0.6484216891891892, 0.8480625405405406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 164}], {
             RGBColor[
             0.9472405675675675, 0.9577916756756757, 0.8765359054054054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 173}], {
             RGBColor[
             0.9922847027027026, 0.9910775405405405, 0.777525972972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 180}], {
             RGBColor[
             0.9819802027027027, 0.952266918918919, 0.551798391891892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 200}], {
             RGBColor[
             0.9931438783783784, 0.9895537837837838, 0.6267002567567567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 172}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 173}], {
             RGBColor[
             0.5851562567567568, 0.6480498513513513, 0.8629644324324324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 180}], {
             RGBColor[
             0.5748517567567568, 0.6092392297297298, 0.6372368513513514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 165}], {
             RGBColor[
             0.9603022432432433, 0.868141891891892, 0.42433768918918924`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 175}], {
             RGBColor[
             0.9598916081081081, 0.8690735945945947, 0.5112111891891893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 177}], {
             RGBColor[
             0.9307941351351352, 0.7633288378378379, 0.26317354054054054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 200}], {
             RGBColor[
             0.947200554054054, 0.955896081081081, 0.740612081081081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 169}], {
             RGBColor[
             0.9694392567567567, 0.9739965945945946, 0.7835381486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 175}], {
             RGBColor[
             0.993594527027027, 0.9905176756756757, 0.6757505810810811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 177}], {
             RGBColor[
             0.9644970540540541, 0.884772918918919, 0.42771293243243247`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 170}], {
             RGBColor[
             0.9029358648648649, 0.5535874054054054, 0.28712397297297293`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 179}], {
             RGBColor[
             0.985590027027027, 0.9630539189189189, 0.3985204054054053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 183}], {
             RGBColor[
             0.9767019189189189, 0.9330722432432432, 0.36399178378378366`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 192}], {
             RGBColor[
             0.9627811756756757, 0.9627951351351351, 0.7007702027027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 198}], {
             RGBColor[0.9917675, 0.9826204324324324, 0.5714251216216217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 189}], {
             RGBColor[
             0.968015891891892, 0.8999581081081081, 0.3575126891891891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 194}], {
             RGBColor[0.9920193648648649, 0.9887, 0.6170769864864863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 197}], {
             RGBColor[
             0.9638210810810811, 0.8833270810810812, 0.3541374459459459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 188}], {
             RGBColor[
             0.5842570675675676, 0.6476780135135136, 0.8778663243243243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 189}], {
             RGBColor[
             0.5611527837837837, 0.5593079594594594, 0.6034001351351351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 197}], {
             RGBColor[
             0.556957972972973, 0.5426769324324324, 0.6000248918918919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 177}], {
             RGBColor[0.9399311486486486, 0.8691835405405406, 0.622374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 190}], {
             RGBColor[
             0.8949384054054055, 0.9188270270270271, 0.9816387972972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 179}], {
             RGBColor[
             0.8999731621621622, 0.5435935135135135, 0.27561443243243233`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 183}], {
             RGBColor[
             0.891085054054054, 0.5136118378378378, 0.2410858108108107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[
             0.8771643108108108, 0.5433347297297297, 0.5778642297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 198}], {
             RGBColor[
             0.9061506351351352, 0.5631600270270269, 0.4485191486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 174}], {
             RGBColor[
             0.9587940945945945, 0.9286843243243242, 0.6414207972972972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 182}], {
             RGBColor[
             0.5658320405405405, 0.6348329864864865, 0.9491944864864865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 191}], {
             RGBColor[
             0.972920472972973, 0.9759650810810812, 0.7278322027027025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 195}], {
             RGBColor[
             0.9693637297297297, 0.9763733243243243, 0.9233635945945946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 196}], {
             RGBColor[
             0.9720612972972973, 0.9774888378378379, 0.8786579189189189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 199}], {
             RGBColor[
             0.5658320405405405, 0.6348329864864865, 0.9491944864864865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 173}], {
             RGBColor[
             0.5851562567567568, 0.6480498513513513, 0.8629644324324324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 180}], {
             RGBColor[
             0.5748517567567568, 0.6092392297297298, 0.6372368513513514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 191}], {
             RGBColor[
             0.5860154324324325, 0.6465260945945945, 0.712138716216216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 180}], {
             RGBColor[
             0.9810810135135135, 0.9518950810810811, 0.5667002837837838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 186}], {
             RGBColor[
             0.9796534594594595, 0.9418232702702702, 0.4779405135135134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 196}], {
             RGBColor[
             0.9781183108108107, 0.9419011891891891, 0.5551907432432431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 183}], {
             RGBColor[
             0.9790174999999999, 0.942273027027027, 0.5402888513513513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 188}], {
             RGBColor[0.9913455, 0.9888101081081082, 0.6565040405405405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 179}], {
             RGBColor[
             0.9588081351351352, 0.866509945945946, 0.32677982432432423`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 190}], {
             RGBColor[
             0.8899962027027027, 0.8296033513513514, 0.6258135810810811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 183}], {
             RGBColor[
             0.9737392162162162, 0.9230783513513512, 0.35248224324324307`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 192}], {
             RGBColor[
             0.959818472972973, 0.9528012432432432, 0.6892606621621621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 185}], {
             RGBColor[
             0.5748517567567568, 0.6092392297297298, 0.6372368513513514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 195}], {
             RGBColor[
             0.5824586891891892, 0.6469343378378378, 0.9076701081081082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 196}], {
             RGBColor[
             0.5851562567567568, 0.6480498513513513, 0.8629644324324324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 199}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 192}], {
             RGBColor[
             0.9509303648648648, 0.9228195675675674, 0.6547320405405405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 186}], {
             RGBColor[
             0.9938198513513513, 0.9909996216216217, 0.7002757432432433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 194}], {
             RGBColor[
             0.9922847027027026, 0.9910775405405405, 0.777525972972973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 198}], {
             RGBColor[
             0.5869546351351351, 0.6487935270270271, 0.8331606486486487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 194}], {
             RGBColor[
             0.9673820405405404, 0.9019638108108108, 0.5328635675675675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 197}], {
             RGBColor[
             0.9391837567567567, 0.7965908918918919, 0.269924027027027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 195}], {
             RGBColor[
             0.9895471216216216, 0.9880664324324324, 0.6863078243243242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 199}], {
             RGBColor[
             0.5860154324324325, 0.6465260945945946, 0.712138716216216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 197}], {
             RGBColor[
             0.9631872297297297, 0.8853327837837839, 0.5294883243243242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 196}], {
             RGBColor[
             0.9886879459459459, 0.9895901891891892, 0.8371335405405406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 199}], {
             RGBColor[
             0.5824586891891892, 0.6469343378378378, 0.9076701081081082]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.04610843439966642], {
             RGBColor[
             0.9606008108108107, 0.9701367297297298, 0.9515767297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.04610843439966642], {
             RGBColor[
             0.9589257027027027, 0.8731088918918919, 0.2949345405405406]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.04610843439966642], {
             RGBColor[
             0.9949822702702703, 0.992193054054054, 0.7328202972972975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.04610843439966642], {
             RGBColor[
             0.9517681891891893, 0.8464839729729731, 0.28004975675675675`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.04610843439966642], {
             RGBColor[
             0.9859903783783783, 0.9884746756756757, 0.8818392162162163]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.04610843439966642], {
             RGBColor[
             0.9200618378378378, 0.9390963513513514, 0.9922375135135135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.04610843439966642], {
             RGBColor[
             0.934988945945946, 0.7799598648648649, 0.26654878378378377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.04610843439966642], {
             RGBColor[
             0.9200618378378378, 0.9390963513513514, 0.9922375135135135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.04610843439966642], {
             RGBColor[
             0.9200618378378378, 0.9390963513513514, 0.9922375135135135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.04610843439966642], {
             RGBColor[
             0.9885527297297297, 0.9730478108108108, 0.4100299459459459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.04610843439966642], {
             RGBColor[
             0.964851108108108, 0.8930966756756755, 0.31795362162162144`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.04610843439966642], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.04610843439966642], {
             RGBColor[
             0.9767019189189189, 0.9330722432432432, 0.36399178378378366`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.04610843439966642], {
             RGBColor[
             0.9940051621621622, 0.989585972972973, 0.5888770810810812]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.04610843439966642], {
             RGBColor[
             0.9949822702702703, 0.992193054054054, 0.7328202972972975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.04610843439966642], {
             RGBColor[
             0.9949822702702703, 0.992193054054054, 0.7328202972972975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.04610843439966642], {
             RGBColor[
             0.9517681891891893, 0.8464839729729731, 0.28004975675675675`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.04610843439966642], {
             RGBColor[
             0.9517681891891893, 0.8464839729729731, 0.28004975675675675`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.04610843439966642], {
             RGBColor[
             0.9926532162162163, 0.9866942972972973, 0.4417261081081079]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.04610843439966642], {
             RGBColor[
             0.9433785675675675, 0.8132219189189189, 0.27329927027027023`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.04610843439966642], {
             RGBColor[
             0.9885527297297297, 0.9730478108108108, 0.4100299459459459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.04610843439966642], {
             RGBColor[
             0.9931038648648649, 0.9876581891891892, 0.4907764324324322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.04610843439966642], {
             RGBColor[
             0.9448733513513513, 0.9584072162162163, 0.9781992162162162]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.04610843439966642], {
             RGBColor[
             0.9200618378378378, 0.9390963513513514, 0.9922375135135135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.04610843439966642], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.04610843439966642], {
             RGBColor[
             0.9885527297297297, 0.9730478108108108, 0.4100299459459459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.04610843439966642], {
             RGBColor[
             0.8637680540540541, 0.8942092162162163, 0.9868681621621621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.04610843439966642], {
             RGBColor[
             0.9931038648648649, 0.9876581891891892, 0.4907764324324322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.04610843439966642], {
             RGBColor[
             0.7143691351351351, 0.7767898648648649, 0.9721652972972973]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.04610843439966642], {
             RGBColor[
             0.8262388648648649, 0.8642844594594594, 0.9832885945945946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.04610843439966642], {
             RGBColor[
             0.9944558108108108, 0.9905498648648648, 0.6379274054054054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.04610843439966642], {
             RGBColor[
             0.9949064594594594, 0.9915137567567568, 0.6869777297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.04610843439966642], {
             RGBColor[
             0.9182097027027027, 0.7134357567567566, 0.2530478108108108]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.04610843439966642], {
             RGBColor[
             0.9606008108108107, 0.9701367297297298, 0.9515767297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.04610843439966642], {
             RGBColor[
             0.9885527297297297, 0.9730478108108108, 0.4100299459459459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.04610843439966642], {
             RGBColor[
             0.9859903783783783, 0.9884746756756757, 0.8818392162162163]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.04610843439966642], {
             RGBColor[
             0.9859903783783783, 0.9884746756756757, 0.8818392162162163]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.04610843439966642], {
             RGBColor[
             0.9707765135135136, 0.9130844594594596, 0.3409727027027028]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.04610843439966642], {
             RGBColor[
             0.9926532162162163, 0.9866942972972973, 0.4417261081081079]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.04610843439966642], {
             RGBColor[
             0.9370096216216216, 0.9525424594594595, 0.9915104594594595]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.04610843439966642], {
             RGBColor[
             0.9935545135135135, 0.9886220810810811, 0.5398267567567565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.04610843439966642], {
             RGBColor[
             0.9949822702702703, 0.992193054054054, 0.7328202972972975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.04610843439966642], {
             RGBColor[
             0.9949064594594594, 0.9915137567567568, 0.6869777297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.04610843439966642], {
             RGBColor[
             0.8262388648648649, 0.8642844594594594, 0.9832885945945946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.04610843439966642], {
             RGBColor[
             0.9012972432432432, 0.924133972972973, 0.9904477297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.04610843439966642], {
             RGBColor[
             0.9370096216216216, 0.9525424594594595, 0.9915104594594595]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.04610843439966642], {
             RGBColor[
             0.9877887567567567, 0.9892183513513514, 0.8520354324324323]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.04610843439966642], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.04610843439966642], {
             RGBColor[
             0.9885527297297297, 0.9730478108108108, 0.4100299459459459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.04610843439966642], {
             RGBColor[
             0.9931038648648649, 0.9876581891891892, 0.4907764324324322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.04610843439966642], {
             RGBColor[
             0.9895871351351351, 0.9899620270270271, 0.8222316486486486]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.04610843439966642], {
             RGBColor[
             0.964851108108108, 0.8930966756756755, 0.31795362162162144`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.04610843439966642], {
             RGBColor[
             0.596376054054054, 0.683203972972973, 0.961368054054054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.04610843439966642], {
             RGBColor[
             0.964851108108108, 0.8930966756756755, 0.31795362162162144`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.04610843439966642], {
             RGBColor[
             0.9707765135135136, 0.9130844594594596, 0.3409727027027028]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.04610843439966642], {
             RGBColor[
             0.9707765135135136, 0.9130844594594596, 0.3409727027027028]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.04610843439966642], {
             RGBColor[
             0.952737081081081, 0.964271972972973, 0.9648879729729729]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.04610843439966642], {
             RGBColor[
             0.9885527297297297, 0.9730478108108108, 0.4100299459459459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.04610843439966642], {
             RGBColor[
             0.9926532162162163, 0.9866942972972973, 0.4417261081081079]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.04610843439966642], {
             RGBColor[
             0.8637680540540541, 0.8942092162162163, 0.9868681621621621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.04610843439966642], {
             RGBColor[
             0.9935545135135135, 0.9886220810810811, 0.5398267567567565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.04610843439966642], {
             RGBColor[
             0.9949822702702703, 0.992193054054054, 0.7328202972972975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.04610843439966642], {
             RGBColor[
             0.9012972432432432, 0.924133972972973, 0.9904477297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.04610843439966642], {
             RGBColor[
             0.9265993243243243, 0.7466978108108109, 0.2597982972972973]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.04610843439966642], {
             RGBColor[
             0.9265993243243243, 0.7466978108108109, 0.2597982972972973]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.04610843439966642], {
             RGBColor[
             0.9826273243243243, 0.953060027027027, 0.3870108648648647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.04610843439966642], {
             RGBColor[
             0.9877887567567567, 0.9892183513513514, 0.8520354324324323]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.04610843439966642], {
             RGBColor[
             0.9877887567567567, 0.9892183513513514, 0.8520354324324323]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.04610843439966642], {
             RGBColor[
             0.9370096216216216, 0.9525424594594595, 0.9915104594594595]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.04610843439966642], {
             RGBColor[
             0.9926532162162163, 0.9866942972972973, 0.4417261081081079]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.04610843439966642], {
             RGBColor[
             0.8637680540540541, 0.8942092162162163, 0.9868681621621621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.04610843439966642], {
             RGBColor[
             0.9949064594594594, 0.9915137567567568, 0.6869777297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.04610843439966642], {
             RGBColor[
             0.964851108108108, 0.8930966756756755, 0.31795362162162144`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.04610843439966642], {
             RGBColor[
             0.9200618378378378, 0.9390963513513514, 0.9922375135135135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.04610843439966642], {
             RGBColor[
             0.9931038648648649, 0.9876581891891892, 0.4907764324324322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.04610843439966642], {
             RGBColor[
             0.9949822702702703, 0.992193054054054, 0.7328202972972975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.04610843439966642], {
             RGBColor[
             0.964851108108108, 0.8930966756756755, 0.31795362162162144`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.04610843439966642], {
             RGBColor[
             0.9859903783783783, 0.9884746756756757, 0.8818392162162163]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.04610843439966642], {
             RGBColor[
             0.9895871351351351, 0.9899620270270271, 0.8222316486486486]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.04610843439966642], {
             RGBColor[
             0.9707765135135136, 0.9130844594594596, 0.3409727027027028]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.04610843439966642], {
             RGBColor[
             0.952737081081081, 0.964271972972973, 0.9648879729729729]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.04610843439966642], {
             RGBColor[
             0.9370096216216216, 0.9525424594594595, 0.9915104594594595]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.04610843439966642], {
             RGBColor[
             0.9913855135135134, 0.9907057027027028, 0.7924278648648648]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.04610843439966642], {
             RGBColor[
             0.9589257027027027, 0.8731088918918919, 0.2949345405405406]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.04610843439966642], {
             RGBColor[
             0.9200618378378378, 0.9390963513513514, 0.9922375135135135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.04610843439966642], {
             RGBColor[
             0.9200618378378378, 0.9390963513513514, 0.9922375135135135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.04610843439966642], {
             RGBColor[
             0.9606008108108107, 0.9701367297297298, 0.9515767297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.04610843439966642], {
             RGBColor[
             0.8637680540540541, 0.8942092162162163, 0.9868681621621621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.04610843439966642], {
             RGBColor[
             0.9265993243243243, 0.7466978108108109, 0.2597982972972973]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.04610843439966642], {
             RGBColor[
             0.9885527297297297, 0.9730478108108108, 0.4100299459459459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.04610843439966642], {
             RGBColor[
             0.9767019189189189, 0.9330722432432432, 0.36399178378378366`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.04610843439966642], {
             RGBColor[
             0.9926532162162163, 0.9866942972972973, 0.4417261081081079]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.04610843439966642], {
             RGBColor[
             0.9949822702702703, 0.992193054054054, 0.7328202972972975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.04610843439966642], {
             RGBColor[
             0.9913855135135134, 0.9907057027027028, 0.7924278648648648]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.04610843439966642], {
             RGBColor[
             0.9926532162162163, 0.9866942972972973, 0.4417261081081079]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.04610843439966642], {
             RGBColor[
             0.9885527297297297, 0.9730478108108108, 0.4100299459459459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.04610843439966642], {
             RGBColor[
             0.9913855135135134, 0.9907057027027028, 0.7924278648648648]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.04610843439966642], {
             RGBColor[
             0.909820081081081, 0.6801737027027027, 0.24629732432432433`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.04610843439966642], {
             RGBColor[
             0.9606008108108107, 0.9701367297297298, 0.9515767297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.04610843439966642], {
             RGBColor[
             0.9265993243243243, 0.7466978108108109, 0.2597982972972973]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.04610843439966642], {
             RGBColor[
             0.9448733513513513, 0.9584072162162163, 0.9781992162162162]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.04610843439966642], {
             RGBColor[
             0.9944558108108108, 0.9905498648648648, 0.6379274054054054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.04610843439966642], {
             RGBColor[
             0.9895871351351351, 0.9899620270270271, 0.8222316486486486]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.04610843439966642], {
             RGBColor[
             0.9940051621621622, 0.989585972972973, 0.5888770810810812]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.04610843439966642], {
             RGBColor[
             0.9926532162162163, 0.9866942972972973, 0.4417261081081079]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.04610843439966642], {
             RGBColor[
             0.9826273243243243, 0.953060027027027, 0.3870108648648647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.04610843439966642], {
             RGBColor[
             0.8637680540540541, 0.8942092162162163, 0.9868681621621621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.04610843439966642], {
             RGBColor[
             0.9182097027027027, 0.7134357567567566, 0.2530478108108108]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.04610843439966642], {
             RGBColor[
             0.9944558108108108, 0.9905498648648648, 0.6379274054054054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.04610843439966642], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.04610843439966642], {
             RGBColor[
             0.9895871351351351, 0.9899620270270271, 0.8222316486486486]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.04610843439966642], {
             RGBColor[
             0.9684645405405405, 0.9760014864864865, 0.9382654864864864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.04610843439966642], {
             RGBColor[
             0.9370096216216216, 0.9525424594594595, 0.9915104594594595]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.04610843439966642], {
             RGBColor[
             0.9935545135135135, 0.9886220810810811, 0.5398267567567565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.04610843439966642], {
             RGBColor[
             0.9931038648648649, 0.9876581891891892, 0.4907764324324322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.04610843439966642], {
             RGBColor[
             0.9895871351351351, 0.9899620270270271, 0.8222316486486486]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.04610843439966642], {
             RGBColor[
             0.9913855135135134, 0.9907057027027028, 0.7924278648648648]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.04610843439966642], {
             RGBColor[
             0.9517681891891893, 0.8464839729729731, 0.28004975675675675`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.04610843439966642], {
             RGBColor[
             0.9859903783783783, 0.9884746756756757, 0.8818392162162163]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.04610843439966642], {
             RGBColor[
             0.9517681891891893, 0.8464839729729731, 0.28004975675675675`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.04610843439966642], {
             RGBColor[
             0.9433785675675675, 0.8132219189189189, 0.27329927027027023`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.04610843439966642], {
             RGBColor[
             0.8825326486486486, 0.9091715945945945, 0.9886579459459459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.04610843439966642], {
             RGBColor[
             0.9895871351351351, 0.9899620270270271, 0.8222316486486486]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.04610843439966642], {
             RGBColor[
             0.8239815945945946, 0.1853386216216215, 0.1705981081081081]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.04610843439966642], {
             RGBColor[
             0.9935545135135135, 0.9886220810810811, 0.5398267567567565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.04610843439966642], {
             RGBColor[
             0.9895871351351351, 0.9899620270270271, 0.8222316486486486]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.04610843439966642], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.04610843439966642], {
             RGBColor[
             0.8450034594594595, 0.8792468378378379, 0.9850783783783784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.04610843439966642], {
             RGBColor[
             0.9944558108108108, 0.9905498648648648, 0.6379274054054054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.04610843439966642], {
             RGBColor[
             0.9826273243243243, 0.953060027027027, 0.3870108648648647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.04610843439966642], {
             RGBColor[
             0.9370096216216216, 0.9525424594594595, 0.9915104594594595]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.04610843439966642], {
             RGBColor[
             0.9017501351351351, 0.6467521351351352, 0.23973024324324327`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.04610843439966642], {
             RGBColor[
             0.9589257027027027, 0.8731088918918919, 0.2949345405405406]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.04610843439966642], {
             RGBColor[
             0.9949064594594594, 0.9915137567567568, 0.6869777297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.04610843439966642], {
             RGBColor[
             0.9182097027027027, 0.7134357567567566, 0.2530478108108108]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.04610843439966642], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.04610843439966642], {
             RGBColor[
             0.8825326486486486, 0.9091715945945945, 0.9886579459459459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.04610843439966642], {
             RGBColor[
             0.9182097027027027, 0.7134357567567566, 0.2530478108108108]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.04610843439966642], {
             RGBColor[
             0.8825326486486486, 0.9091715945945945, 0.9886579459459459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.04610843439966642], {
             RGBColor[
             0.9707765135135136, 0.9130844594594596, 0.3409727027027028]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.04610843439966642], {
             RGBColor[
             0.9826273243243243, 0.953060027027027, 0.3870108648648647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.04610843439966642], {
             RGBColor[
             0.9017501351351351, 0.6467521351351352, 0.23973024324324327`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.04610843439966642], {
             RGBColor[
             0.9895871351351351, 0.9899620270270271, 0.8222316486486486]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.04610843439966642], {
             RGBColor[
             0.8450034594594595, 0.8792468378378379, 0.9850783783783784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.04610843439966642], {
             RGBColor[
             0.9931038648648649, 0.9876581891891892, 0.4907764324324322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.04610843439966642], {
             RGBColor[
             0.8825326486486486, 0.9091715945945945, 0.9886579459459459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.04610843439966642], {
             RGBColor[
             0.964851108108108, 0.8930966756756755, 0.31795362162162144`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.04610843439966642], {
             RGBColor[
             0.9885527297297297, 0.9730478108108108, 0.4100299459459459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.04610843439966642], {
             RGBColor[
             0.9949822702702703, 0.992193054054054, 0.7328202972972975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.04610843439966642], {
             RGBColor[
             0.9931838918918918, 0.9914493783783784, 0.7626240810810812]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.04610843439966642], {
             RGBColor[
             0.9265993243243243, 0.7466978108108109, 0.2597982972972973]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.04610843439966642], {
             RGBColor[
             0.9012972432432432, 0.924133972972973, 0.9904477297297297]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.04610843439966642], {
             RGBColor[
             0.9940051621621622, 0.989585972972973, 0.5888770810810812]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.04610843439966642], {
             RGBColor[
             0.9885527297297297, 0.9730478108108108, 0.4100299459459459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.04610843439966642], {
             RGBColor[
             0.9926532162162163, 0.9866942972972973, 0.4417261081081079]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.04610843439966642], {
             RGBColor[
             0.9448733513513513, 0.9584072162162163, 0.9781992162162162]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.04610843439966642], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.04610843439966642], {
             RGBColor[
             0.952737081081081, 0.964271972972973, 0.9648879729729729]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.04610843439966642], {
             RGBColor[
             0.9913855135135134, 0.9907057027027028, 0.7924278648648648]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.04610843439966642], {
             RGBColor[
             0.964851108108108, 0.8930966756756755, 0.31795362162162144`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.04610843439966642], {
             RGBColor[
             0.9931838918918918, 0.9914493783783784, 0.7626240810810812]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.04610843439966642], {
             RGBColor[
             0.9931038648648649, 0.9876581891891892, 0.4907764324324322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.04610843439966642], {
             RGBColor[
             0.934988945945946, 0.7799598648648649, 0.26654878378378377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.04610843439966642], {
             RGBColor[
             0.9931038648648649, 0.9876581891891892, 0.4907764324324322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.04610843439966642], {
             RGBColor[
             0.9826273243243243, 0.953060027027027, 0.3870108648648647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.04610843439966642], {
             RGBColor[
             0.9707765135135136, 0.9130844594594596, 0.3409727027027028]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.04610843439966642], {
             RGBColor[
             0.9826273243243243, 0.953060027027027, 0.3870108648648647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.04610843439966642], {
             RGBColor[
             0.964851108108108, 0.8930966756756755, 0.31795362162162144`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.04610843439966642], {
             RGBColor[
             0.9931838918918918, 0.9914493783783784, 0.7626240810810812]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.04610843439966642], {
             RGBColor[
             0.9707765135135136, 0.9130844594594596, 0.3409727027027028]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.04610843439966642], {
             RGBColor[
             0.9944558108108108, 0.9905498648648648, 0.6379274054054054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.04610843439966642], {
             RGBColor[
             0.9895871351351351, 0.9899620270270271, 0.8222316486486486]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.04610843439966642], {
             RGBColor[
             0.9433785675675675, 0.8132219189189189, 0.27329927027027023`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.04610843439966642], {
             RGBColor[
             0.8450034594594595, 0.8792468378378379, 0.9850783783783784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.04610843439966642], {
             RGBColor[
             0.9931038648648649, 0.9876581891891892, 0.4907764324324322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.04610843439966642], {
             RGBColor[
             0.9370096216216216, 0.9525424594594595, 0.9915104594594595]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.04610843439966642], {
             RGBColor[
             0.9684645405405405, 0.9760014864864865, 0.9382654864864864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.04610843439966642], {
             RGBColor[
             0.9913855135135134, 0.9907057027027028, 0.7924278648648648]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.04610843439966642], {
             RGBColor[
             0.9859903783783783, 0.9884746756756757, 0.8818392162162163]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.04610843439966642], {
             RGBColor[
             0.9913855135135134, 0.9907057027027028, 0.7924278648648648]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.04610843439966642], {
             RGBColor[
             0.934988945945946, 0.7799598648648649, 0.26654878378378377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.04610843439966642], {
             RGBColor[
             0.9949822702702703, 0.992193054054054, 0.7328202972972975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.04610843439966642], {
             RGBColor[
             0.9931038648648649, 0.9876581891891892, 0.4907764324324322]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
          103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
          129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 
          142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 
          155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 
          168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 
          181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 
          194, 195, 196, 197, 198, 199, 200}, {Null, CompressedData["
1:eJwVxfk/Gg4DAOBN5QibNGP1lWNDwghlmCNXuqiMigzJGcNQUi05SwdqhpKc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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[21, 55] -> 
             RGBColor[
              0.34859095953566543`, 0.47635370128389704`, 0.9434328855880982],
              UndirectedEdge[64, 132] -> 
             RGBColor[
              0.4650482384089718, 0.5716822037632778, 0.9522031318796592], 
             UndirectedEdge[42, 188] -> 
             RGBColor[
              0.2579862693567474, 0.38807828505832953`, 0.9380183944910747], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.5482557857976138, 0.6358309000327967, 0.9605283874597037], 
             UndirectedEdge[33, 68] -> 
             RGBColor[
              0.9768074272678445, 0.9356471682387506, 0.5374347809068445], 
             UndirectedEdge[168, 188] -> 
             RGBColor[
              0.2612998708737691, 0.39156109034719, 0.938207099195435], 
             UndirectedEdge[41, 161] -> 
             RGBColor[
              0.2872671394725109, 0.41926635574719545`, 0.9396708106680862], 
             UndirectedEdge[44, 68] -> 
             RGBColor[
              0.9298826077939246, 0.7566572199616033, 0.27010292258186963`], 
             UndirectedEdge[26, 136] -> 
             RGBColor[
              0.2577972163446346, 0.3882915980387517, 0.9379925421427979], 
             UndirectedEdge[9, 32] -> 
             RGBColor[
              0.18966018913671598`, 0.3166752623061849, 0.9341122392430056], 
             UndirectedEdge[71, 141] -> 
             RGBColor[
              0.3537772547746116, 0.4808458095490941, 0.9437633517346631], 
             UndirectedEdge[52, 100] -> 
             RGBColor[
              0.1956898688928864, 0.3230128380336974, 0.9344556205850076], 
             UndirectedEdge[172, 180] -> 
             RGBColor[
              0.6056868100783286, 0.4851310394922843, 0.577851031637082], 
             UndirectedEdge[168, 197] -> 
             RGBColor[
              0.20505165545148296`, 0.3328526692783333, 0.9349887604799977], 
             UndirectedEdge[125, 137] -> 
             RGBColor[
              0.29408774568202667`, 0.42503485891778914`, 0.9401105091078588],
              UndirectedEdge[17, 147] -> 
             RGBColor[
              0.22049695582396892`, 0.34908665925842064`, 0.9358683474869365],
              UndirectedEdge[10, 71] -> 
             RGBColor[
              0.2908445212370684, 0.4179419677193835, 0.9400607036352882], 
             UndirectedEdge[27, 129] -> 
             RGBColor[
              0.36049570993893, 0.4827296556793453, 0.9443430413040212], 
             UndirectedEdge[67, 166] -> 
             RGBColor[
              0.5298097305765306, 0.6164429264479874, 0.9594779119033563], 
             UndirectedEdge[3, 49] -> 
             RGBColor[
              0.42052372581365627`, 0.5386582479879358, 0.9480163778476842], 
             UndirectedEdge[151, 183] -> 
             RGBColor[
              0.9651436444656913, 0.888619018725243, 0.5091874749108671], 
             UndirectedEdge[125, 136] -> 
             RGBColor[
              0.24354766177349693`, 0.373314412710544, 0.9371810510902985], 
             UndirectedEdge[139, 194] -> 
             RGBColor[
              0.2435950267958037, 0.37336419635210427`, 0.9371837484582486], 
             UndirectedEdge[24, 108] -> 
             RGBColor[
              0.28258697373339425`, 0.41434720481573717`, 0.9394042821529283],
              UndirectedEdge[21, 192] -> 
             RGBColor[
              0.4135089355037963, 0.532245803699352, 0.9476624011874208], 
             UndirectedEdge[16, 52] -> 
             RGBColor[
              0.18638226183152043`, 0.31322995287582944`, 0.9339255661322337],
              UndirectedEdge[44, 166] -> 
             RGBColor[
              0.8512516278317916, 0.7399182542257667, 0.6091593456597434], 
             UndirectedEdge[78, 187] -> 
             RGBColor[
              0.19320618779608617`, 0.3204023317264835, 0.9343141786208218], 
             UndirectedEdge[99, 162] -> 
             RGBColor[
              0.5016163434350541, 0.6062220183620153, 0.9539225219304044], 
             UndirectedEdge[93, 150] -> 
             RGBColor[
              0.21197440955790398`, 0.3401289227721434, 0.9353830010850614], 
             UndirectedEdge[118, 155] -> 
             RGBColor[
              0.5320287520312512, 0.6287959624909311, 0.9570938290152922], 
             UndirectedEdge[16, 125] -> 
             RGBColor[
              0.22572938407249296`, 0.3545862731027316, 0.936166326535006], 
             UndirectedEdge[61, 179] -> 
             RGBColor[
              0.2879403991921272, 0.41444560530367136`, 0.9399115732194068], 
             UndirectedEdge[51, 197] -> 
             RGBColor[
              0.1914512391651612, 0.3185577694452115, 0.9342142368925045], 
             UndirectedEdge[80, 120] -> 
             RGBColor[
              0.20786563933481106`, 0.33581034475659416`, 0.9351490126992371],
              UndirectedEdge[21, 183] -> 
             RGBColor[
              0.6488438964095984, 0.6364280199535685, 0.605957146255827], 
             UndirectedEdge[182, 199] -> 
             RGBColor[
              0.668046802775716, 0.7309711261041182, 0.8355721890992451], 
             UndirectedEdge[17, 189] -> 
             RGBColor[
              0.19295037100619816`, 0.32013345206058996`, 0.9342996102330847],
              UndirectedEdge[116, 136] -> 
             RGBColor[
              0.23171997218972168`, 0.36088276103916334`, 0.9365074816660013],
              UndirectedEdge[119, 123] -> 
             RGBColor[
              0.6489751309922214, 0.46304637074551996`, 0.5712200187466816], 
             UndirectedEdge[71, 89] -> 
             RGBColor[
              0.315626713124748, 0.4439896226750534, 0.9414720128013241], 
             UndirectedEdge[7, 61] -> 
             RGBColor[
              0.2079174287175954, 0.335864778681537, 0.9351519620279711], 
             UndirectedEdge[3, 27] -> 
             RGBColor[
              0.3426067292683088, 0.4672664245880422, 0.9431945216539286], 
             UndirectedEdge[41, 108] -> 
             RGBColor[
              0.29936649893310274`, 0.4319835496839754, 0.9403598512899686], 
             UndirectedEdge[66, 98] -> 
             RGBColor[
              0.18802367047876978`, 0.3149551774354076, 0.9340190419264479], 
             UndirectedEdge[119, 127] -> 
             RGBColor[
              0.8608066453023939, 0.6319627472541103, 0.5901965057147129], 
             UndirectedEdge[15, 167] -> 
             RGBColor[
              0.18913040232451964`, 0.31611842277614255`, 0.9340820686678004],
              UndirectedEdge[12, 96] -> 
             RGBColor[
              0.9432592874949708, 0.8959893159471047, 0.6356118637427102], 
             UndirectedEdge[7, 52] -> 
             RGBColor[
              0.19704159904264756`, 0.32443359212573797`, 0.934532599617331], 
             UndirectedEdge[163, 165] -> 
             RGBColor[
              0.24378292836413576`, 0.3735616928140688, 0.9371944491745896], 
             UndirectedEdge[71, 73] -> 
             RGBColor[
              0.29060892456725834`, 0.41769434068172157`, 0.9400472867534765],
              UndirectedEdge[60, 165] -> 
             RGBColor[
              0.1933919500064047, 0.32059757958753266`, 0.9343247575038889], 
             UndirectedEdge[120, 124] -> 
             RGBColor[
              0.20998768265750406`, 0.3380407468340621, 0.9352698599271827], 
             UndirectedEdge[43, 163] -> 
             RGBColor[
              0.2357550055079826, 0.36512383689254435`, 0.9367372708441793], 
             UndirectedEdge[146, 194] -> 
             RGBColor[
              0.22346288152433108`, 0.352204035220052, 0.9360372525678782], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.24761466346370808`, 0.37758908934975655`, 0.9374126608199662],
              UndirectedEdge[81, 157] -> 
             RGBColor[
              0.25622740358141927`, 0.3866416252927345, 0.9379031436282628], 
             UndirectedEdge[59, 114] -> 
             RGBColor[
              0.1828190891221793, 0.3094848324401137, 0.9337226487176782], 
             UndirectedEdge[31, 185] -> 
             RGBColor[
              0.38200599992585305`, 0.49606971836717273`, 0.9464117075671216],
              UndirectedEdge[58, 198] -> 
             RGBColor[
              0.6531000789032383, 0.7219510755774461, 0.9474306913916395], 
             UndirectedEdge[30, 142] -> 
             RGBColor[
              0.23578204115771023`, 0.3651522530745672, 0.9367388104844356], 
             UndirectedEdge[26, 96] -> 
             RGBColor[
              0.6145993386243387, 0.6885815666825401, 0.9662497087986179], 
             UndirectedEdge[25, 111] -> 
             RGBColor[
              0.19983749274486573`, 0.32737225367666856`, 0.9346918216275183],
              UndirectedEdge[89, 107] -> 
             RGBColor[
              0.24257389966697504`, 0.37229092699650596`, 0.9371255967788841],
              UndirectedEdge[51, 189] -> 
             RGBColor[
              0.18831403886767445`, 0.3152603730225656, 0.9340355779766345], 
             UndirectedEdge[81, 158] -> 
             RGBColor[
              0.3111871249613185, 0.44370525612704076`, 0.9410587411898188], 
             UndirectedEdge[93, 159] -> 
             RGBColor[
              0.24313944261504272`, 0.37288534849241906`, 0.9371578036131307],
              UndirectedEdge[191, 195] -> 
             RGBColor[
              0.6555677203865065, 0.728688801139147, 0.9677847110498968], 
             UndirectedEdge[17, 131] -> 
             RGBColor[
              0.18648216780881113`, 0.31333496039236675`, 0.9339312556298427],
              UndirectedEdge[18, 32] -> 
             RGBColor[
              0.20453729510132862`, 0.33231204393799124`, 0.9349594684189844],
              UndirectedEdge[59, 184] -> 
             RGBColor[
              0.1830159493280225, 0.30969174499811286`, 0.9337338596151724], 
             UndirectedEdge[156, 175] -> 
             RGBColor[
              0.6596444744105936, 0.3751515803022144, 0.5596916614795366], 
             UndirectedEdge[2, 82] -> 
             RGBColor[
              0.19716931432443496`, 0.3245678289845131, 0.934539872813691], 
             UndirectedEdge[12, 44] -> 
             RGBColor[
              0.9244380104653778, 0.7365581580535521, 0.25797799946440303`], 
             UndirectedEdge[115, 175] -> 
             RGBColor[
              0.4077982725568444, 0.5263530627871394, 0.9475600302171414], 
             UndirectedEdge[30, 131] -> 
             RGBColor[
              0.19553065372363834`, 0.3228454927959929, 0.9344465535166567], 
             UndirectedEdge[53, 65] -> 
             RGBColor[
              0.7940608836370591, 0.7881654857639895, 0.6245197254205552], 
             UndirectedEdge[17, 51] -> 
             RGBColor[
              0.18683289480672916`, 0.31370359670455467`, 0.9339512290135199],
              UndirectedEdge[109, 128] -> 
             RGBColor[
              0.32435782382982603`, 0.44691944921604004`, 0.9421979744658333],
              UndirectedEdge[101, 135] -> 
             RGBColor[
              0.1965653140451214, 0.3239329863951249, 0.9345054758913225], 
             UndirectedEdge[54, 195] -> 
             RGBColor[
              0.7447123095700184, 0.789153733450638, 0.681635360097179], 
             UndirectedEdge[122, 192] -> 
             RGBColor[
              0.3718189687016956, 0.49328632243521403`, 0.9451102958483188], 
             UndirectedEdge[155, 195] -> 
             RGBColor[
              0.5871109616069528, 0.6752098608899229, 0.9609615810995339], 
             UndirectedEdge[42, 87] -> 
             RGBColor[
              0.20973659970745412`, 0.3377768427339811, 0.9352555611246214], 
             UndirectedEdge[31, 153] -> 
             RGBColor[
              0.4071092490619125, 0.522454824847095, 0.9478413004684911], 
             UndirectedEdge[64, 199] -> 
             RGBColor[
              0.8123958459095635, 0.8512144164818124, 0.8460919805023865], 
             UndirectedEdge[107, 188] -> 
             RGBColor[
              0.2654176677513521, 0.39588915594893126`, 0.9384416016358788], 
             UndirectedEdge[27, 189] -> 
             RGBColor[
              0.23047600087590087`, 0.35957526831600095`, 0.9364366393399698],
              UndirectedEdge[14, 176] -> 
             RGBColor[
              0.20667251283261232`, 0.3345562931541938, 0.9350810659100094], 
             UndirectedEdge[123, 146] -> 
             RGBColor[
              0.34826410267529395`, 0.47021417637892043`, 0.9436264907064373],
              UndirectedEdge[30, 130] -> 
             RGBColor[
              0.1969307686942434, 0.3243171024025152, 0.9345262879929481], 
             UndirectedEdge[72, 143] -> 
             RGBColor[
              0.5544319884729032, 0.6356036049331575, 0.9619129375714212], 
             UndirectedEdge[68, 155] -> 
             RGBColor[
              0.817090690205986, 0.812348570970784, 0.6355099976070364], 
             UndirectedEdge[32, 39] -> 
             RGBColor[
              0.2190345544466123, 0.34754958268921615`, 0.9357850658919249], 
             UndirectedEdge[184, 194] -> 
             RGBColor[
              0.19166541671322765`, 0.3187828836278702, 0.9342264339870195], 
             UndirectedEdge[74, 152] -> 
             RGBColor[
              0.2730580915689248, 0.4008937800418094, 0.9389875071669056], 
             UndirectedEdge[71, 147] -> 
             RGBColor[
              0.3066316503071229, 0.4345352413338067, 0.9409597572808632], 
             UndirectedEdge[39, 173] -> 
             RGBColor[
              0.3099077362629189, 0.437607436708477, 0.9411599161992759], 
             UndirectedEdge[139, 171] -> 
             RGBColor[
              0.2967091465842705, 0.42919050387948254`, 0.940208519004903], 
             UndirectedEdge[73, 189] -> 
             RGBColor[
              0.20595537414504966`, 0.3338025349243465, 0.9350402259226642], 
             UndirectedEdge[20, 22] -> 
             RGBColor[
              0.1854064647205249, 0.3122043282430629, 0.9338699959303249], 
             UndirectedEdge[17, 168] -> 
             RGBColor[
              0.2004333110930509, 0.32799849653767643`, 0.9347257526010131], 
             UndirectedEdge[13, 132] -> 
             RGBColor[
              0.26083574153477407`, 0.39148528066721244`, 0.9381655816572811],
              UndirectedEdge[99, 109] -> 
             RGBColor[
              0.38461485844464394`, 0.49643648481667146`, 0.9467764936235569],
              UndirectedEdge[119, 195] -> 
             RGBColor[
              0.6739288625041259, 0.48336449574698853`, 0.5731680108502653], 
             UndirectedEdge[10, 188] -> 
             RGBColor[
              0.26557638653463256`, 0.3960559794535111, 0.9384506404357832], 
             UndirectedEdge[182, 185] -> 
             RGBColor[
              0.28644155976238705`, 0.41543196640215296`, 0.9397324188136974],
              UndirectedEdge[98, 187] -> 
             RGBColor[
              0.1979911315151781, 0.3254316109582035, 0.9345866740869342], 
             UndirectedEdge[10, 167] -> 
             RGBColor[
              0.2086421156058076, 0.33662647054885053`, 0.9351932318741767], 
             UndirectedEdge[113, 187] -> 
             RGBColor[
              0.20396723113485943`, 0.331712870565089, 0.934927004119428], 
             UndirectedEdge[83, 170] -> 
             RGBColor[
              0.7907969761749707, 0.8373558827785927, 0.9795546906537492], 
             UndirectedEdge[39, 41] -> 
             RGBColor[
              0.2713842645263738, 0.40257244714637036`, 0.9387663044365115], 
             UndirectedEdge[138, 145] -> 
             RGBColor[
              0.20603341116594734`, 0.3338845567811428, 0.935044670015559], 
             UndirectedEdge[75, 155] -> 
             RGBColor[
              0.5876661844347633, 0.6756606157940428, 0.9610052902743873], 
             UndirectedEdge[90, 163] -> 
             RGBColor[
              0.2545166466581612, 0.38484351129813643`, 0.9378057185523212], 
             UndirectedEdge[2, 66] -> 
             RGBColor[
              0.1829598466238134, 0.3096327774988722, 0.9337306646491643], 
             UndirectedEdge[88, 200] -> 
             RGBColor[
              0.20358824889509092`, 0.3313145362022305, 0.9349054216415271], 
             UndirectedEdge[67, 170] -> 
             RGBColor[
              0.45554903905121463`, 0.5584299098262512, 0.952076300177731], 
             UndirectedEdge[124, 136] -> 
             RGBColor[
              0.22442474851543817`, 0.35321501841359515`, 0.9360920294700671],
              UndirectedEdge[129, 155] -> 
             RGBColor[
              0.5638305008231241, 0.6563097340528043, 0.959128857947493], 
             UndirectedEdge[149, 167] -> 
             RGBColor[
              0.19241882352516138`, 0.31957476195596346`, 0.9342693393903937],
              UndirectedEdge[172, 173] -> 
             RGBColor[
              0.6185469880325928, 0.49626987926492994`, 0.5786704708045187], 
             UndirectedEdge[143, 160] -> 
             RGBColor[
              0.6494266978782655, 0.7230187336619522, 0.967777881154406], 
             UndirectedEdge[27, 89] -> 
             RGBColor[
              0.2670176485112967, 0.3979828568550783, 0.9385176321142823], 
             UndirectedEdge[172, 191] -> 
             RGBColor[
              0.8397221650752837, 0.6755835027616839, 0.59719713282006], 
             UndirectedEdge[11, 182] -> 
             RGBColor[
              0.27189457932291083`, 0.4001421676284322, 0.9389039897979983], 
             UndirectedEdge[159, 164] -> 
             RGBColor[
              0.22503263737217588`, 0.35385394814440607`, 0.9361266478411673],
              UndirectedEdge[151, 156] -> 
             RGBColor[
              0.9063104280310577, 0.5683123234196433, 0.4581304793295804], 
             UndirectedEdge[94, 196] -> 
             RGBColor[
              0.21169845343388266`, 0.3398388753891681, 0.9353672857920389], 
             UndirectedEdge[69, 139] -> 
             RGBColor[
              0.2677410752801248, 0.398743224257023, 0.938558830198553], 
             UndirectedEdge[53, 127] -> 
             RGBColor[
              0.7532853090466265, 0.8074724235406385, 0.9760373166313029], 
             UndirectedEdge[171, 196] -> 
             RGBColor[
              0.2703681630861383, 0.4015044601081305, 0.9387084389626774], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.7310843955752011, 0.737038335696917, 0.6195619855898489], 
             UndirectedEdge[74, 162] -> 
             RGBColor[
              0.39867126833608224`, 0.5197307476573095, 0.9466239585805827], 
             UndirectedEdge[34, 153] -> 
             RGBColor[
              0.3561569436366287, 0.48045786172119975`, 0.9440046574916221], 
             UndirectedEdge[98, 109] -> 
             RGBColor[
              0.2049550918267402, 0.33275117478624117`, 0.9349832613244216], 
             UndirectedEdge[77, 183] -> 
             RGBColor[
              0.8768515535875127, 0.45980910711412243`, 0.21594468162867203`],
              UndirectedEdge[2, 78] -> 
             RGBColor[
              0.1826523965739446, 0.3093096280030011, 0.9337131558236558], 
             UndirectedEdge[113, 193] -> 
             RGBColor[
              0.21695734101669506`, 0.34536629967143495`, 0.9356667716600531],
              UndirectedEdge[100, 120] -> 
             RGBColor[
              0.199864476631129, 0.3274006154520085, 0.934693358319922], 
             UndirectedEdge[1, 35] -> 
             RGBColor[
              0.1803467482579951, 0.30688624543639154`, 0.9335818525629636], 
             UndirectedEdge[154, 176] -> 
             RGBColor[
              0.28297932105843965`, 0.41262153691639003`, 0.9395049102298585],
              UndirectedEdge[13, 31] -> 
             RGBColor[
              0.37653388192589077`, 0.49031817539689215`, 0.9461000785422968],
              UndirectedEdge[92, 196] -> 
             RGBColor[
              0.23871657724306206`, 0.3682366365606061, 0.9369059279732393], 
             UndirectedEdge[66, 124] -> 
             RGBColor[
              0.2047917303558609, 0.33257947152263156`, 0.9349739581303267], 
             UndirectedEdge[141, 167] -> 
             RGBColor[
              0.27157484914335084`, 0.3995303123785612, 0.9388958799735516], 
             UndirectedEdge[76, 158] -> 
             RGBColor[
              0.2902964087900912, 0.4217477888831733, 0.9398690458089125], 
             UndirectedEdge[101, 134] -> 
             RGBColor[
              0.22153377048940157`, 0.350176417209637, 0.9359273925483029], 
             UndirectedEdge[139, 141] -> 
             RGBColor[
              0.31474199889707277`, 0.4449017237250964, 0.9413541852919508], 
             UndirectedEdge[88, 93] -> 
             RGBColor[
              0.22397479227765688`, 0.3527420858788138, 0.936066405127976], 
             UndirectedEdge[17, 130] -> 
             RGBColor[
              0.18788228277941618`, 0.31480656999888906`, 0.9340109901061341],
              UndirectedEdge[32, 117] -> 
             RGBColor[
              0.1856648230786062, 0.31247587925827236`, 0.9338847090566107], 
             UndirectedEdge[32, 103] -> 
             RGBColor[
              0.1835438669532831, 0.31024661989417246`, 0.9337639237429469], 
             UndirectedEdge[148, 150] -> 
             RGBColor[
              0.19306951159997304`, 0.3202586763785973, 0.9343063951136474], 
             UndirectedEdge[77, 156] -> 
             RGBColor[
              0.8180183371528791, 0.13950241180852277`, 0.1648876860473853], 
             UndirectedEdge[76, 89] -> 
             RGBColor[
              0.2658816302529869, 0.396788829637877, 0.93845293755506], 
             UndirectedEdge[42, 51] -> 
             RGBColor[
              0.1924833774375055, 0.31964261221079154`, 0.9342730156402028], 
             UndirectedEdge[82, 124] -> 
             RGBColor[
              0.21900119805648247`, 0.34751452300827246`, 0.9357831662948535],
              UndirectedEdge[15, 114] -> 
             RGBColor[
              0.1801710817898224, 0.3067016088404447, 0.9335718486174763], 
             UndirectedEdge[41, 173] -> 
             RGBColor[
              0.32922976019022715`, 0.45791610894315266`, 0.9422602768775632],
              UndirectedEdge[41, 133] -> 
             RGBColor[
              0.2699147403652278, 0.4010278840797926, 0.9386826172095004], 
             UndirectedEdge[27, 147] -> 
             RGBColor[
              0.25802258569367165`, 0.38852847551383163`, 0.9380053765938214],
              UndirectedEdge[19, 88] -> 
             RGBColor[
              0.28388973519432037`, 0.4117897874343075, 0.939622248296642], 
             UndirectedEdge[127, 172] -> 
             RGBColor[
              0.8720640822479042, 0.7012922099091854, 0.6003031260629946], 
             UndirectedEdge[69, 174] -> 
             RGBColor[
              0.21992361240255348`, 0.34848403897044045`, 0.9358356964272725],
              UndirectedEdge[117, 121] -> 
             RGBColor[
              0.2013378942582586, 0.3289492707981949, 0.9347772672740609], 
             UndirectedEdge[69, 196] -> 
             RGBColor[
              0.24140009178199262`, 0.37105718048567105`, 0.9370587501563274],
              UndirectedEdge[92, 195] -> 
             RGBColor[
              0.372739436043382, 0.49002947459904367`, 0.9455472387434574], 
             UndirectedEdge[144, 158] -> 
             RGBColor[
              0.2574165112915451, 0.3871889319062931, 0.9379965842878197], 
             UndirectedEdge[81, 168] -> 
             RGBColor[
              0.2577136388756711, 0.38820375281975344`, 0.9379877825295823], 
             UndirectedEdge[87, 188] -> 
             RGBColor[
              0.264952676857396, 0.39540042103725787`, 0.9384151210923604], 
             UndirectedEdge[74, 88] -> 
             RGBColor[
              0.2812466810785635, 0.40950050680300143`, 0.9394538352255469], 
             UndirectedEdge[74, 140] -> 
             RGBColor[
              0.6698268935487197, 0.7315161778042003, 0.7507274751968138], 
             UndirectedEdge[152, 178] -> 
             RGBColor[
              0.19191650879429833`, 0.319046797325233, 0.9342407333095791], 
             UndirectedEdge[63, 153] -> 
             RGBColor[
              0.23696466171985112`, 0.36639526226785174`, 0.9368061589759192],
              UndirectedEdge[154, 158] -> 
             RGBColor[
              0.3241076056222659, 0.45514745069325846`, 0.9418728279265163], 
             UndirectedEdge[23, 90] -> 
             RGBColor[
              0.22545415356299398`, 0.354296988386626, 0.936150652564657], 
             UndirectedEdge[51, 131] -> 
             RGBColor[
              0.18184583567028742`, 0.3084618813543424, 0.9336672233733925], 
             UndirectedEdge[21, 83] -> 
             RGBColor[
              0.6438448345050425, 0.715751939504987, 0.9685418227069613], 
             UndirectedEdge[57, 178] -> 
             RGBColor[
              0.1827435050835432, 0.30940538882320234`, 0.9337183443184945], 
             UndirectedEdge[17, 197] -> 
             RGBColor[
              0.19608757130368493`, 0.3234308484832359, 0.9344782691489546], 
             UndirectedEdge[64, 156] -> 
             RGBColor[
              0.724124328038114, 0.42749923026133874`, 0.5647677517545815], 
             UndirectedEdge[40, 123] -> 
             RGBColor[
              0.4784773066745961, 0.5874288969649759, 0.9521030898325651], 
             UndirectedEdge[26, 99] -> 
             RGBColor[
              0.42230145847218425`, 0.5360474909140672, 0.9489226897427967], 
             UndirectedEdge[114, 167] -> 
             RGBColor[
              0.19037448411434205`, 0.3174260316165872, 0.9341529172852767], 
             UndirectedEdge[75, 168] -> 
             RGBColor[
              0.3557698478286644, 0.47206054196027025`, 0.9445929358550735], 
             UndirectedEdge[55, 111] -> 
             RGBColor[
              0.27800719710349053`, 0.40702500884009835`, 0.9392353213324036],
              UndirectedEdge[67, 122] -> 
             RGBColor[
              0.26690693057918574`, 0.3978664852885073, 0.9385113268918411], 
             UndirectedEdge[127, 129] -> 
             RGBColor[
              0.6646291767752983, 0.7354973814495299, 0.9690579811407907], 
             UndirectedEdge[96, 198] -> 
             RGBColor[
              0.6410199693439192, 0.7129417496474699, 0.9678791658783956], 
             UndirectedEdge[154, 181] -> 
             RGBColor[
              0.3850218870849109, 0.5079083396553941, 0.9457542320769319], 
             UndirectedEdge[9, 91] -> 
             RGBColor[
              0.1897739422401799, 0.3167948240302888, 0.9341187173139652], 
             UndirectedEdge[39, 152] -> 
             RGBColor[
              0.22612393827552923`, 0.3550009745863041, 0.9361887958131783], 
             UndirectedEdge[54, 65] -> 
             RGBColor[
              0.9723656669587191, 0.9184450471811106, 0.347146263750879], 
             UndirectedEdge[116, 128] -> 
             RGBColor[
              0.33596717970245343`, 0.45912161831384746`, 0.9428591101082765],
              UndirectedEdge[74, 95] -> 
             RGBColor[
              0.29756419393855826`, 0.4266512474089263, 0.9403830934433266], 
             UndirectedEdge[152, 200] -> 
             RGBColor[
              0.19539965938545223`, 0.3227078094410386, 0.9344390935828858], 
             UndirectedEdge[140, 191] -> 
             RGBColor[
              0.9019134129618684, 0.9202806576422312, 0.7699493982996792], 
             UndirectedEdge[109, 193] -> 
             RGBColor[
              0.223435169075761, 0.3521749076795341, 0.936035674384929], 
             UndirectedEdge[80, 137] -> 
             RGBColor[
              0.2728427891012749, 0.40270506254337235`, 0.9389006402596817], 
             UndirectedEdge[118, 199] -> 
             RGBColor[
              0.6930640728290565, 0.752639828019768, 0.8371662674251406], 
             UndirectedEdge[45, 64] -> 
             RGBColor[
              0.6702869821102313, 0.7421560430065834, 0.9679059544483493], 
             UndirectedEdge[125, 170] -> 
             RGBColor[
              0.4597455397011603, 0.5628406980828529, 0.952315284681579], 
             UndirectedEdge[70, 145] -> 
             RGBColor[
              0.19062187863577218`, 0.31768605894432894`, 0.9341670060372848],
              UndirectedEdge[17, 142] -> 
             RGBColor[
              0.22673355524288302`, 0.35564172067094113`, 0.9362235125976215],
              UndirectedEdge[95, 180] -> 
             RGBColor[
              0.2956153583547517, 0.42496326397755757`, 0.9402589153632142], 
             UndirectedEdge[41, 121] -> 
             RGBColor[
              0.25402964955357293`, 0.38433164646381435`, 0.9377779847876626],
              UndirectedEdge[5, 10] -> 
             RGBColor[
              0.28614225358776674`, 0.41386909982440245`, 0.9397610792987268],
              UndirectedEdge[167, 194] -> 
             RGBColor[
              0.2004278770420817, 0.327992785005569, 0.9347254431398494], 
             UndirectedEdge[78, 100] -> 
             RGBColor[
              0.1943610742796171, 0.3216161906447068, 0.9343799476975574], 
             UndirectedEdge[106, 157] -> 
             RGBColor[
              0.1957274974930852, 0.3230523880782974, 0.9344577634781225], 
             UndirectedEdge[24, 115] -> 
             RGBColor[
              0.28608625432626233`, 0.41744460911573256`, 0.9396248182053492],
              UndirectedEdge[74, 164] -> 
             RGBColor[
              0.2705518531420833, 0.3982595645505048, 0.9388447805961444], 
             UndirectedEdge[46, 135] -> 
             RGBColor[
              0.18995764910618526`, 0.3169879115941485, 0.9341291791482143], 
             UndirectedEdge[126, 190] -> 
             RGBColor[
              0.18192592123823295`, 0.3085460563639715, 0.933671784128011], 
             UndirectedEdge[21, 177] -> 
             RGBColor[
              0.28934680274084895`, 0.4165928965590511, 0.9399671678191333], 
             UndirectedEdge[24, 133] -> 
             RGBColor[
              0.2531352151655193, 0.3833915392115544, 0.93772704807246], 
             UndirectedEdge[30, 188] -> 
             RGBColor[
              0.2613842726407983, 0.39164980195571875`, 0.938211905751206], 
             UndirectedEdge[80, 98] -> 
             RGBColor[
              0.2071471807023911, 0.33505519918101245`, 0.9351080975429851], 
             UndirectedEdge[12, 102] -> 
             RGBColor[
              0.9596388825040008, 0.9082051910857141, 0.6078854818749925], 
             UndirectedEdge[51, 168] -> 
             RGBColor[
              0.1957969789545272, 0.32312541749965207`, 0.934461720344563], 
             UndirectedEdge[42, 189] -> 
             RGBColor[
              0.19860085363697447`, 0.32607246756682684`, 0.9346213968597675],
              UndirectedEdge[52, 187] -> 
             RGBColor[
              0.19453498240935546`, 0.32179897911547406`, 0.934389851508272], 
             UndirectedEdge[10, 89] -> 
             RGBColor[
              0.2427326184502555, 0.3724577505010858, 0.9371346355787884], 
             UndirectedEdge[148, 193] -> 
             RGBColor[
              0.21151914615710812`, 0.33965041207254015`, 0.9353570745078879],
              UndirectedEdge[4, 92] -> 
             RGBColor[
              0.28937728391046563`, 0.41912091134823404`, 0.9398775137264412],
              UndirectedEdge[28, 97] -> 
             RGBColor[
              0.19804503866908396`, 0.3254882707948695, 0.9345897440196007], 
             UndirectedEdge[60, 169] -> 
             RGBColor[
              0.18653686033276015`, 0.3133924457027435, 0.9339343702881713], 
             UndirectedEdge[44, 198] -> 
             RGBColor[
              0.6221986923143263, 0.5535105917539171, 0.5902453016000886], 
             UndirectedEdge[13, 64] -> 
             RGBColor[
              0.4253184848962721, 0.5299237138095665, 0.9499405811920143], 
             UndirectedEdge[42, 106] -> 
             RGBColor[
              0.19390013127031533`, 0.3211317103164559, 0.9343536976750818], 
             UndirectedEdge[43, 90] -> 
             RGBColor[
              0.20850897767362986`, 0.33648653414069934`, 0.935185649865899], 
             UndirectedEdge[166, 192] -> 
             RGBColor[
              0.6347217686990404, 0.711862763594694, 0.9660768808598341], 
             UndirectedEdge[5, 89] -> 
             RGBColor[
              0.31092444547544634`, 0.4399167547800723, 0.9411723884647626], 
             UndirectedEdge[114, 184] -> 
             RGBColor[
              0.18161202378548802`, 0.3082161302388885, 0.9336539081324469], 
             UndirectedEdge[58, 192] -> 
             RGBColor[
              0.7131454310850844, 0.7736227561744136, 0.951349727711992], 
             UndirectedEdge[17, 157] -> 
             RGBColor[
              0.19894707579879906`, 0.3264363690106574, 0.9346411136996936], 
             UndirectedEdge[38, 111] -> 
             RGBColor[
              0.200630301320241, 0.32820554575635497`, 0.9347369709030307], 
             UndirectedEdge[3, 191] -> 
             RGBColor[
              0.6143982789320568, 0.6943254432107253, 0.9648034682477634], 
             UndirectedEdge[40, 195] -> 
             RGBColor[
              0.5034310381865006, 0.6077470219664445, 0.9540510819361487], 
             UndirectedEdge[113, 136] -> 
             RGBColor[
              0.21363278825802834`, 0.3418719839332567, 0.9354774432986821], 
             UndirectedEdge[53, 141] -> 
             RGBColor[
              0.4877995456867602, 0.5920834332461721, 0.9536420283584146], 
             UndirectedEdge[142, 176] -> 
             RGBColor[
              0.24804284091250217`, 0.37803913099645736`, 0.9374370448922433],
              UndirectedEdge[99, 128] -> 
             RGBColor[
              0.49156366276898256`, 0.5975148916314856, 0.9532819740075988], 
             UndirectedEdge[41, 151] -> 
             RGBColor[
              0.6423047351050197, 0.7073139713016436, 0.8452851258395946], 
             UndirectedEdge[5, 157] -> 
             RGBColor[
              0.28037950263265143`, 0.40781208319106244`, 0.939432899157059], 
             UndirectedEdge[39, 74] -> 
             RGBColor[
              0.29899639389246113`, 0.42815658036720006`, 0.9404646551119514],
              UndirectedEdge[86, 171] -> 
             RGBColor[
              0.25492345163412733`, 0.3852710891208021, 0.9378288854938884], 
             UndirectedEdge[162, 180] -> 
             RGBColor[
              0.3967224327522758, 0.5180427642259409, 0.9464997805004701], 
             UndirectedEdge[27, 127] -> 
             RGBColor[
              0.5706539535210267, 0.6502280340235855, 0.9632042593205097], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.2536345517124762, 0.3839163735821717, 0.937755484550107], 
             UndirectedEdge[155, 191] -> 
             RGBColor[
              0.7416468272326004, 0.7980994052495431, 0.9748840827210469], 
             UndirectedEdge[46, 105] -> 
             RGBColor[
              0.19436779950481975`, 0.32162325928279867`, 0.9343803306891837],
              UndirectedEdge[30, 168] -> 
             RGBColor[
              0.2094817970078781, 0.3375090289413025, 0.9352410504878272], 
             UndirectedEdge[161, 180] -> 
             RGBColor[
              0.31293043325479175`, 0.4431625055366565, 0.9412449832634135], 
             UndirectedEdge[125, 192] -> 
             RGBColor[
              0.364998647890857, 0.48611773282970705`, 0.9447218886679021], 
             UndirectedEdge[33, 140] -> 
             RGBColor[
              0.9931733912441731, 0.9901003146609737, 0.6650510516491244], 
             UndirectedEdge[12, 58] -> 
             RGBColor[
              0.9553393970542898, 0.9049986418770809, 0.615163389255954], 
             UndirectedEdge[127, 155] -> 
             RGBColor[
              0.7739887444052208, 0.8238081123970447, 0.9779900759639816], 
             UndirectedEdge[78, 120] -> 
             RGBColor[
              0.188434679061321, 0.31538717351511814`, 0.9340424482571915], 
             UndirectedEdge[45, 183] -> 
             RGBColor[
              0.823713544812509, 0.7798413316678898, 0.6197525703698252], 
             UndirectedEdge[98, 136] -> 
             RGBColor[
              0.20765668863834705`, 0.33559072432637116`, 0.9351371132661883],
              UndirectedEdge[59, 92] -> 
             RGBColor[
              0.21433501599530952`, 0.3426100698089493, 0.9355174341294674], 
             UndirectedEdge[81, 89] -> 
             RGBColor[
              0.2867723464242142, 0.41874629688174436`, 0.9396426329359664], 
             UndirectedEdge[161, 200] -> 
             RGBColor[
              0.23722083665512567`, 0.36666451836725433`, 0.9368207477595063],
              UndirectedEdge[125, 198] -> 
             RGBColor[
              0.30495329570901086`, 0.43444605223273947`, 0.9408028523475496],
              UndirectedEdge[159, 173] -> 
             RGBColor[
              0.3113226737864071, 0.4390946257578836, 0.941240494798026], 
             UndirectedEdge[54, 151] -> 
             RGBColor[
              0.9911479730677677, 0.9821275166719952, 0.580056048665182], 
             UndirectedEdge[61, 192] -> 
             RGBColor[
              0.33652735532483224`, 0.4561925991586039, 0.9431004906757697], 
             UndirectedEdge[59, 194] -> 
             RGBColor[
              0.19287248204991897`, 0.32005158582909543`, 0.934295174572251], 
             UndirectedEdge[80, 82] -> 
             RGBColor[
              0.2168791547337895, 0.3452841209308045, 0.9356623190669078], 
             UndirectedEdge[157, 168] -> 
             RGBColor[
              0.2079111599465971, 0.33585818980575477`, 0.9351516050307367], 
             UndirectedEdge[122, 170] -> 
             RGBColor[
              0.4665658605119989, 0.5700092876883599, 0.9527036918619959], 
             UndirectedEdge[26, 67] -> 
             RGBColor[
              0.2743361643394848, 0.4056750810112081, 0.9389344107639237], 
             UndirectedEdge[160, 181] -> 
             RGBColor[
              0.4406818300512263, 0.5561181847027405, 0.9493008344245906], 
             UndirectedEdge[42, 168] -> 
             RGBColor[
              0.20608379372382724`, 0.3339375120439133, 0.935047539227696], 
             UndirectedEdge[61, 67] -> 
             RGBColor[
              0.2316153172023224, 0.36077276201189723`, 0.936501521719292], 
             UndirectedEdge[9, 39] -> 
             RGBColor[
              0.22268787528916928`, 0.3513894545286635, 0.9359931171093048], 
             UndirectedEdge[118, 171] -> 
             RGBColor[
              0.3493088123107567, 0.4768833997475762, 0.9434819976486537], 
             UndirectedEdge[97, 134] -> 
             RGBColor[
              0.23183626588337625`, 0.3610049930846403, 0.9365141044198138], 
             UndirectedEdge[79, 190] -> 
             RGBColor[
              0.18918203979750087`, 0.31617269703425077`, 0.9340850093454959],
              UndirectedEdge[47, 50] -> 
             RGBColor[
              0.2000038325739316, 0.3275470873835711, 0.9347012944347058], 
             UndirectedEdge[36, 145] -> 
             RGBColor[
              0.1863723647153286, 0.3132195503791984, 0.9339250025061079], 
             UndirectedEdge[170, 179] -> 
             RGBColor[
              0.5118741210410194, 0.6121027531180253, 0.9554863516778458], 
             UndirectedEdge[26, 198] -> 
             RGBColor[
              0.3192028502801486, 0.44942323756094715`, 0.9416143434000489], 
             UndirectedEdge[5, 141] -> 
             RGBColor[
              0.34907498712530993`, 0.4767729416541131, 0.9434637273981017], 
             UndirectedEdge[18, 39] -> 
             RGBColor[
              0.2375649812537819, 0.3670262361604698, 0.9368403462852835], 
             UndirectedEdge[19, 180] -> 
             RGBColor[
              0.3466247657178071, 0.47465068302264285`, 0.9433076014566613], 
             UndirectedEdge[170, 198] -> 
             RGBColor[
              0.5004157249918784, 0.6021780663759904, 0.9547562328138562], 
             UndirectedEdge[12, 172] -> 
             RGBColor[
              0.9097214307201227, 0.6697336065748736, 0.2456981245885829], 
             UndirectedEdge[47, 101] -> 
             RGBColor[
              0.19622767860092072`, 0.3235781101359464, 0.934486248052262], 
             UndirectedEdge[53, 54] -> 
             RGBColor[
              0.810087981057518, 0.842228648704628, 0.6867819724356502], 
             UndirectedEdge[57, 121] -> 
             RGBColor[
              0.1995963195919732, 0.32711876540171747`, 0.9346780871732447], 
             UndirectedEdge[19, 121] -> 
             RGBColor[
              0.28428483303541713`, 0.41220506031595017`, 0.9396447485341975],
              UndirectedEdge[170, 192] -> 
             RGBColor[
              0.5604610771737245, 0.6538497469729578, 0.9586752691342088], 
             UndirectedEdge[7, 137] -> 
             RGBColor[
              0.266193356547354, 0.39571608733082725`, 0.9385219649126898], 
             UndirectedEdge[111, 115] -> 
             RGBColor[
              0.26758071568904057`, 0.3979941146890951, 0.9385709551564505], 
             UndirectedEdge[140, 162] -> 
             RGBColor[
              0.7225676146989453, 0.7771975396388044, 0.7540880673117176], 
             UndirectedEdge[8, 79] -> 
             RGBColor[
              0.2387210212797669, 0.3682413075249512, 0.9369061810545554], 
             UndirectedEdge[2, 52] -> 
             RGBColor[
              0.1839811911872139, 0.31070627539199164`, 0.933788828711106], 
             UndirectedEdge[18, 152] -> 
             RGBColor[
              0.21162667893024556`, 0.3397634358350792, 0.9353631983402376], 
             UndirectedEdge[4, 195] -> 
             RGBColor[
              0.41766970262794245`, 0.5348906935287172, 0.9481924844113676], 
             UndirectedEdge[81, 107] -> 
             RGBColor[
              0.26183143575325407`, 0.39253181842149465`, 0.938222284970026], 
             UndirectedEdge[108, 175] -> 
             RGBColor[
              0.4042989919639763, 0.5232556584871441, 0.9473394941647204], 
             UndirectedEdge[49, 191] -> 
             RGBColor[
              0.6162290328937537, 0.6959111502759776, 0.9649201222713306], 
             UndirectedEdge[77, 192] -> 
             RGBColor[
              0.6415165926817106, 0.355626890859906, 0.5576499365602658], 
             UndirectedEdge[21, 166] -> 
             RGBColor[
              0.5825165188394155, 0.666981785574234, 0.9626574089267232], 
             UndirectedEdge[8, 192] -> 
             RGBColor[
              0.37448920004002384`, 0.4960929048742423, 0.9452623615727833], 
             UndirectedEdge[108, 165] -> 
             RGBColor[
              0.25691494582414054`, 0.38736427578253046`, 0.937942298141858], 
             UndirectedEdge[29, 194] -> 
             RGBColor[
              0.2042163465061234, 0.3319747066151143, 0.9349411908712882], 
             UndirectedEdge[106, 131] -> 
             RGBColor[
              0.18326258950309726`, 0.3099509794600067, 0.9337479054082716], 
             UndirectedEdge[12, 68] -> 
             RGBColor[
              0.9555467146303788, 0.8599776150331977, 0.2908341193259223], 
             UndirectedEdge[71, 168] -> 
             RGBColor[
              0.2865680055762049, 0.4134470786130624, 0.93981716239494], 
             UndirectedEdge[49, 146] -> 
             RGBColor[
              0.3338791466944457, 0.45775465051721964`, 0.9427098940314549], 
             UndirectedEdge[112, 134] -> 
             RGBColor[
              0.5941420485372255, 0.6663173396662936, 0.9607153178159171], 
             UndirectedEdge[84, 126] -> 
             RGBColor[
              0.1804502852518648, 0.30699506938157317`, 0.9335877488415951], 
             UndirectedEdge[10, 62] -> 
             RGBColor[
              0.2089259147709481, 0.3369247614653196, 0.9352093938167881], 
             UndirectedEdge[34, 182] -> 
             RGBColor[
              0.3854450302409573, 0.5082748449893679, 0.9457811943846643], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.20133152966492007`, 0.3289425812070576, 0.9347769048198857], 
             UndirectedEdge[67, 79] -> 
             RGBColor[
              0.22503396848065443`, 0.3538553472238142, 0.9361267236458259], 
             UndirectedEdge[33, 96] -> 
             RGBColor[
              0.9645200001324366, 0.9716588691526575, 0.8822125253236324], 
             UndirectedEdge[12, 140] -> 
             RGBColor[
              0.9719126786067074, 0.9144307614554209, 0.4184503900682022], 
             UndirectedEdge[26, 124] -> 
             RGBColor[
              0.25940975173137165`, 0.3899864749708609, 0.9380843736475403], 
             UndirectedEdge[13, 70] -> 
             RGBColor[
              0.20607827017508945`, 0.33393170644397663`, 0.9350472246697668],
              UndirectedEdge[53, 146] -> 
             RGBColor[
              0.438593505674698, 0.543607216634379, 0.9507210951484925], 
             UndirectedEdge[87, 147] -> 
             RGBColor[
              0.23311384595539386`, 0.3623478107435859, 0.9365868607149048], 
             UndirectedEdge[93, 200] -> 
             RGBColor[
              0.21100022620147757`, 0.339104994297747, 0.935327522784088], 
             UndirectedEdge[9, 117] -> 
             RGBColor[
              0.1893181439211632, 0.3163157510977197, 0.9340927602739904], 
             UndirectedEdge[99, 116] -> 
             RGBColor[
              0.39622421431727134`, 0.5086386539144789, 0.9474376292660001], 
             UndirectedEdge[71, 155] -> 
             RGBColor[
              0.5184643421823038, 0.6170471524468351, 0.9562295168142538], 
             UndirectedEdge[54, 140] -> 
             RGBColor[
              0.9910580021453803, 0.9807455899537222, 0.48380004734696136`], 
             UndirectedEdge[76, 154] -> 
             RGBColor[
              0.29805964700021337`, 0.42847191562908343`, 0.9403637124828994],
              UndirectedEdge[33, 128] -> 
             RGBColor[
              0.7119650853654641, 0.7696077577835532, 0.8603069871100877], 
             UndirectedEdge[109, 148] -> 
             RGBColor[
              0.20549299658683456`, 0.33331654679423195`, 0.9350138942047502],
              UndirectedEdge[27, 142] -> 
             RGBColor[
              0.2642591851125857, 0.3950835369263521, 0.9383605417045067], 
             UndirectedEdge[49, 69] -> 
             RGBColor[
              0.33608426308955985`, 0.46007236766093923`, 0.9428354721479792],
              UndirectedEdge[60, 90] -> 
             RGBColor[
              0.2041256683004301, 0.33187939807160033`, 0.9349360268816205], 
             UndirectedEdge[40, 191] -> 
             RGBColor[
              0.6579669038121483, 0.7306365663260646, 0.9679735835576617], 
             UndirectedEdge[58, 166] -> 
             RGBColor[
              0.8821530144207035, 0.9083587380492957, 0.9663447354512944], 
             UndirectedEdge[38, 60] -> 
             RGBColor[
              0.18105257981885614`, 0.3076281191591622, 0.9336220486261704], 
             UndirectedEdge[54, 119] -> 
             RGBColor[
              0.9176093173132854, 0.6667189724180997, 0.30094116151906036`], 
             UndirectedEdge[3, 146] -> 
             RGBColor[
              0.33204839273274867`, 0.4561689434519673, 0.9425932400078877], 
             UndirectedEdge[115, 163] -> 
             RGBColor[
              0.2983939725453868, 0.4303808013184385, 0.9403257245502908], 
             UndirectedEdge[137, 170] -> 
             RGBColor[
              0.48955017496489417`, 0.59276687306104, 0.9540638895741654], 
             UndirectedEdge[58, 99] -> 
             RGBColor[
              0.7561986870952739, 0.8085753289305662, 0.9547390377343874], 
             UndirectedEdge[40, 64] -> 
             RGBColor[
              0.5676806016913061, 0.6599077120294969, 0.959109042929153], 
             UndirectedEdge[77, 96] -> 
             RGBColor[
              0.8768677288440547, 0.5431135393845314, 0.5783662656384824], 
             UndirectedEdge[141, 195] -> 
             RGBColor[
              0.42242387419926064`, 0.539008517992182, 0.9484954160199432], 
             UndirectedEdge[138, 182] -> 
             RGBColor[
              0.28135325644561493`, 0.4100838369991616, 0.9394426474672775], 
             UndirectedEdge[33, 102] -> 
             RGBColor[
              0.9808995951414665, 0.9838747442912669, 0.8544861434559147], 
             UndirectedEdge[137, 198] -> 
             RGBColor[
              0.3347579309727448, 0.4643722272109265, 0.9425514572401359], 
             UndirectedEdge[69, 171] -> 
             RGBColor[
              0.27878211770791206`, 0.41034805989114986`, 0.939187601231057], 
             UndirectedEdge[20, 46] -> 
             RGBColor[
              0.182651270158183, 0.3093084440686167, 0.9337130916759446], 
             UndirectedEdge[76, 157] -> 
             RGBColor[
              0.23533668741019195`, 0.36468415804886706`, 0.9367134482473564],
              UndirectedEdge[10, 168] -> 
             RGBColor[
              0.21367391090171242`, 0.3419152064390949, 0.9354797851724044], 
             UndirectedEdge[82, 100] -> 
             RGBColor[
              0.20887799203010743`, 0.3368743916262188, 0.9352066646875926], 
             UndirectedEdge[9, 57] -> 
             RGBColor[
              0.18757656925487778`, 0.3144852457012422, 0.9339935801731742], 
             UndirectedEdge[27, 71] -> 
             RGBColor[
              0.3151295512981096, 0.44346707407337604`, 0.941443700170782], 
             UndirectedEdge[122, 125] -> 
             RGBColor[
              0.2711034312291314, 0.40227727354510906`, 0.9387503113956892], 
             UndirectedEdge[5, 147] -> 
             RGBColor[
              0.30192938265782127`, 0.43046237343882565`, 0.9406601329443018],
              UndirectedEdge[5, 71] -> 
             RGBColor[
              0.35903634826225916`, 0.48540097199837007`, 0.9440984565212622],
              UndirectedEdge[61, 84] -> 
             RGBColor[
              0.19428775253280067`, 0.3215391248399355, 0.9343757721325461], 
             UndirectedEdge[62, 149] -> 
             RGBColor[
              0.19270262269030192`, 0.3198730528724325, 0.9342855013330051], 
             UndirectedEdge[36, 138] -> 
             RGBColor[
              0.20221257093783607`, 0.32986861144613544`, 0.9348270788169946],
              UndirectedEdge[33, 162] -> 
             RGBColor[
              0.7220177660315357, 0.778314884514083, 0.8609475350328932], 
             UndirectedEdge[63, 145] -> 
             RGBColor[
              0.1909329030445121, 0.31801296531800116`, 0.9341847184172432], 
             UndirectedEdge[93, 173] -> 
             RGBColor[
              0.29957000075540785`, 0.42674182123979476`, 0.9405711974554323],
              UndirectedEdge[23, 55] -> 
             RGBColor[
              0.27975796086466953`, 0.40886517255793126`, 0.9393350247385799],
              UndirectedEdge[23, 165] -> 
             RGBColor[
              0.21472043526896856`, 0.3430151699025583, 0.9355393831869255], 
             UndirectedEdge[54, 64] -> 
             RGBColor[
              0.8089618730748239, 0.8413144235136905, 0.6866933210901831], 
             UndirectedEdge[72, 158] -> 
             RGBColor[
              0.284772839183219, 0.41594216701181014`, 0.93955448669119], 
             UndirectedEdge[73, 149] -> 
             RGBColor[
              0.2014915378121197, 0.32911075991486693`, 0.934786017047158], 
             UndirectedEdge[10, 197] -> 
             RGBColor[
              0.20932817111234645`, 0.33734755838465436`, 0.9352323017203459],
              UndirectedEdge[37, 135] -> 
             RGBColor[
              0.21639131765151565`, 0.3447713732266772, 0.9356345374667627], 
             UndirectedEdge[58, 96] -> 
             RGBColor[
              0.9484965672474285, 0.961109404699039, 0.9720660567902085], 
             UndirectedEdge[112, 156] -> 
             RGBColor[
              0.880064299434007, 0.550351383801579, 0.5748087868596949], 
             UndirectedEdge[2, 187] -> 
             RGBColor[
              0.1929273076602217, 0.3201092110216681, 0.9342982968096505], 
             UndirectedEdge[43, 169] -> 
             RGBColor[
              0.19092016970595993`, 0.3179995817718425, 0.9341839932724498], 
             UndirectedEdge[44, 96] -> 
             RGBColor[
              0.9175951806585165, 0.7926689208755102, 0.6148806669986575], 
             UndirectedEdge[88, 161] -> 
             RGBColor[
              0.25019540273130497`, 0.38030160994832113`, 0.9375596301033943],
              UndirectedEdge[129, 146] -> 
             RGBColor[
              0.3499373734033699, 0.4716321745432704, 0.9437417596579802], 
             UndirectedEdge[23, 111] -> 
             RGBColor[
              0.2218869245410005, 0.3505476045091276, 0.935947504149097], 
             UndirectedEdge[174, 196] -> 
             RGBColor[
              0.21150965778077974`, 0.33964043918742115`, 0.9353565341588927],
              UndirectedEdge[66, 100] -> 
             RGBColor[
              0.1946685243294859, 0.3219393401405779, 0.9343974565230659], 
             UndirectedEdge[10, 73] -> 
             RGBColor[
              0.2177148298927659, 0.346162468507754, 0.9357099095309409], 
             UndirectedEdge[147, 188] -> 
             RGBColor[
              0.2813635156046871, 0.41264925306793426`, 0.9393496940813583], 
             UndirectedEdge[62, 189] -> 
             RGBColor[
              0.19716645902323188`, 0.3245648278819121, 0.9345397102085116], 
             UndirectedEdge[42, 89] -> 
             RGBColor[
              0.2351425012723703, 0.3644800561059042, 0.93670238963408], 
             UndirectedEdge[119, 140] -> 
             RGBColor[
              0.9202745550794877, 0.6749563522500728, 0.37533269810004777`], 
             UndirectedEdge[140, 151] -> 
             RGBColor[
              0.9938132108339699, 0.9903648965039682, 0.6544475852461695], 
             UndirectedEdge[1, 86] -> 
             RGBColor[
              0.19100632204633058`, 0.3180901333439459, 0.934188899520783], 
             UndirectedEdge[76, 181] -> 
             RGBColor[
              0.3512106902527362, 0.4745086778453089, 0.9437504499593281], 
             UndirectedEdge[122, 166] -> 
             RGBColor[
              0.5408265520373148, 0.6280223043100961, 0.9601053035876213], 
             UndirectedEdge[10, 189] -> 
             RGBColor[
              0.20619097081485965`, 0.33405016196200843`, 0.935053642804476], 
             UndirectedEdge[102, 162] -> 
             RGBColor[
              0.7102938185962386, 0.7709719692690975, 0.9435231591185078], 
             UndirectedEdge[156, 183] -> 
             RGBColor[
              0.8775508907403917, 0.4651845189226452, 0.21661436767605732`], 
             UndirectedEdge[31, 199] -> 
             RGBColor[
              0.763611242939182, 0.811608878069138, 0.8422514778526693], 
             UndirectedEdge[73, 130] -> 
             RGBColor[
              0.20088728591826768`, 0.3284756528626456, 0.9347516057957137], 
             UndirectedEdge[4, 199] -> 
             RGBColor[
              0.6647841302718416, 0.7281451631679503, 0.8353642944923663], 
             UndirectedEdge[6, 83] -> 
             RGBColor[
              0.8789095063816696, 0.593376334043407, 0.5852871633250518], 
             UndirectedEdge[73, 89] -> 
             RGBColor[
              0.2424970217804455, 0.37221012346342386`, 0.9371212186969768], 
             UndirectedEdge[60, 111] -> 
             RGBColor[
              0.20055843927843664`, 0.3281300141941019, 0.9347328784660603], 
             UndirectedEdge[166, 179] -> 
             RGBColor[
              0.5861348125663353, 0.6701157697397615, 0.962887963403471], 
             UndirectedEdge[30, 197] -> 
             RGBColor[
              0.20513605721851214`, 0.33294138088686204`, 0.9349935670357687],
              UndirectedEdge[26, 58] -> 
             RGBColor[
              0.6266794481836577, 0.6975908926125163, 0.9458012343118618], 
             UndirectedEdge[11, 35] -> 
             RGBColor[
              0.19186691491128627`, 0.3189946710097535, 0.9342379090113091], 
             UndirectedEdge[137, 187] -> 
             RGBColor[
              0.2636867399140619, 0.3930814743205634, 0.9383792168036308], 
             UndirectedEdge[13, 153] -> 
             RGBColor[
              0.2516813551580962, 0.3818634401637041, 0.9376442528958304], 
             UndirectedEdge[71, 75] -> 
             RGBColor[
              0.4329404581640204, 0.5480873032405589, 0.9491738543179573], 
             UndirectedEdge[16, 67] -> 
             RGBColor[
              0.22153288342254734`, 0.3501754848461299, 0.935927342031158], 
             UndirectedEdge[156, 170] -> 
             RGBColor[
              0.7369628216448929, 0.4377252679215747, 0.5659130186213281], 
             UndirectedEdge[96, 128] -> 
             RGBColor[
              0.683861542921137, 0.7500489673999585, 0.97060899306342], 
             UndirectedEdge[62, 114] -> 
             RGBColor[
              0.19065828327948256`, 0.31772432253305627`, 0.9341690792278882],
              UndirectedEdge[101, 105] -> 
             RGBColor[
              0.20097546444375586`, 0.32856833408377506`, 0.9347566274322918],
              UndirectedEdge[30, 89] -> 
             RGBColor[
              0.2385405045564212, 0.3680515730032935, 0.9368959008942113], 
             UndirectedEdge[53, 191] -> 
             RGBColor[
              0.720943391874006, 0.781763716393137, 0.9729313233883682], 
             UndirectedEdge[72, 81] -> 
             RGBColor[
              0.2796155967323937, 0.4112240991915025, 0.9392350666284796], 
             UndirectedEdge[163, 175] -> 
             RGBColor[
              0.39116697450397153`, 0.5094530755186824, 0.9465916451974521], 
             UndirectedEdge[82, 125] -> 
             RGBColor[
              0.23812411131454123`, 0.3676139173052213, 0.9368721879150849], 
             UndirectedEdge[113, 148] -> 
             RGBColor[
              0.19901516852776863`, 0.3265079387861328, 0.9346449914798742], 
             UndirectedEdge[33, 44] -> 
             RGBColor[
              0.9456987231028435, 0.812227711259105, 0.5045786610453252], 
             UndirectedEdge[21, 179] -> 
             RGBColor[
              0.3649219793710912, 0.49049880984441946`, 0.9444734837310578], 
             UndirectedEdge[75, 188] -> 
             RGBColor[
              0.40767232346158455`, 0.5262013149746865, 0.9475637911184522], 
             UndirectedEdge[85, 88] -> 
             RGBColor[
              0.24351738394062986`, 0.3732825887884752, 0.9371793268125088], 
             UndirectedEdge[13, 185] -> 
             RGBColor[
              0.22657810602203676`, 0.3554783336837818, 0.936214659994461], 
             UndirectedEdge[93, 161] -> 
             RGBColor[
              0.2576073800376916, 0.38809206804383756`, 0.9379817312459552], 
             UndirectedEdge[146, 196] -> 
             RGBColor[
              0.23919497538687848`, 0.3687394633419514, 0.9369331720398031], 
             UndirectedEdge[19, 162] -> 
             RGBColor[
              0.4013143224518391, 0.5220200282886156, 0.9467923716516777], 
             UndirectedEdge[140, 172] -> 
             RGBColor[
              0.931531992024998, 0.7442858149051479, 0.38543931844832946`], 
             UndirectedEdge[71, 142] -> 
             RGBColor[
              0.312868249726037, 0.44109030274632716`, 0.9413149223915483], 
             UndirectedEdge[87, 142] -> 
             RGBColor[
              0.23935044537430794`, 0.3689028721561064, 0.9369420258255899], 
             UndirectedEdge[89, 147] -> 
             RGBColor[
              0.25851974752031004`, 0.38905102411550896`, 0.9380336892243635],
              UndirectedEdge[30, 42] -> 
             RGBColor[
              0.2061681954908564, 0.33402622365244206`, 0.935052345783467], 
             UndirectedEdge[8, 125] -> 
             RGBColor[
              0.2737736625674596, 0.4050838559841373, 0.9389023771201537], 
             UndirectedEdge[29, 168] -> 
             RGBColor[
              0.2081540694089858, 0.33611350305207477`, 0.9351654383652672], 
             UndirectedEdge[158, 160] -> 
             RGBColor[
              0.3797675485885813, 0.503357295740605, 0.945419430274175], 
             UndirectedEdge[138, 153] -> 
             RGBColor[
              0.25206516984128635`, 0.38226685373099345`, 0.9376661105742352],
              UndirectedEdge[26, 122] -> 
             RGBColor[
              0.285352985800269, 0.4172544588733168, 0.9395618024481885], 
             UndirectedEdge[53, 195] -> 
             RGBColor[
              0.5664075262483584, 0.658874172033517, 0.9590088217668552], 
             UndirectedEdge[19, 93] -> 
             RGBColor[
              0.291301712500707, 0.4195802455298239, 0.9400443494392029], 
             UndirectedEdge[11, 196] -> 
             RGBColor[
              0.21797120015163274`, 0.34643192990463634`, 0.9357245094379176],
              UndirectedEdge[87, 168] -> 
             RGBColor[
              0.21305020122447582`, 0.34125964802284164`, 0.9354442658289815],
              UndirectedEdge[78, 124] -> 
             RGBColor[
              0.20448428030599214`, 0.3322563220267605, 0.9349564493048182], 
             UndirectedEdge[39, 117] -> 
             RGBColor[
              0.21869250923105948`, 0.34719007148075093`, 0.9357655869229098],
              UndirectedEdge[42, 130] -> 
             RGBColor[
              0.1935327654101925, 0.32074558550512594`, 0.9343327767328169], 
             UndirectedEdge[11, 94] -> 
             RGBColor[
              0.19668351642529655`, 0.32405722459115277`, 0.9345122073420087],
              UndirectedEdge[27, 168] -> 
             RGBColor[
              0.23795894096275363`, 0.36744031279308736`, 0.9368627817078983],
              UndirectedEdge[30, 51] -> 
             RGBColor[
              0.19588138072155636`, 0.3232141291081808, 0.934466526900334], 
             UndirectedEdge[6, 58] -> 
             RGBColor[
              0.8960048531020866, 0.6063661726923737, 0.5646755963969717], 
             UndirectedEdge[6, 156] -> 
             RGBColor[
              0.8250753518515919, 0.1937457191863889, 0.17164549129263085`], 
             UndirectedEdge[19, 173] -> 
             RGBColor[
              0.35948494367207134`, 0.4857895227952885, 0.9441270406240982], 
             UndirectedEdge[57, 200] -> 
             RGBColor[
              0.1862266556746971, 0.31306640093900795`, 0.9339167045918012], 
             UndirectedEdge[37, 50] -> 
             RGBColor[
              0.21979652604601302`, 0.3483504631519761, 0.935828459047275], 
             UndirectedEdge[49, 171] -> 
             RGBColor[
              0.36505233439370555`, 0.4905196472833987, 0.9444851609543292], 
             UndirectedEdge[5, 127] -> 
             RGBColor[
              0.6145607504851762, 0.6921619319485797, 0.9658590156709901], 
             UndirectedEdge[85, 152] -> 
             RGBColor[
              0.2353287944309912, 0.36467586202728325`, 0.9367129987538674], 
             UndirectedEdge[130, 131] -> 
             RGBColor[
              0.18289522364297445`, 0.3095648546486768, 0.9337269844660065], 
             UndirectedEdge[33, 58] -> 
             RGBColor[
              0.9766001096917556, 0.9806681950826337, 0.8617640508368762], 
             UndirectedEdge[82, 98] -> 
             RGBColor[
              0.20223313817939134`, 0.32989022892104847`, 0.9348282500909746],
              UndirectedEdge[74, 173] -> 
             RGBColor[
              0.35684188955631446`, 0.48350024216398235`, 0.9439586275530032],
              UndirectedEdge[118, 146] -> 
             RGBColor[
              0.3181356246114969, 0.44411840298139715`, 0.9417067307257794], 
             UndirectedEdge[23, 115] -> 
             RGBColor[
              0.26933147945021957`, 0.39983427840692803`, 0.9386706585626268],
              UndirectedEdge[49, 65] -> 
             RGBColor[
              0.6893465246568067, 0.7023129196468301, 0.6165085243035178], 
             UndirectedEdge[21, 23] -> 
             RGBColor[
              0.2924706869731754, 0.4198762969529263, 0.9401450684047916], 
             UndirectedEdge[40, 171] -> 
             RGBColor[
              0.40679020531210003`, 0.5252450633334856, 0.9475386222406603], 
             UndirectedEdge[104, 158] -> 
             RGBColor[
              0.3417223041341413, 0.47040441720375525`, 0.9429952209396267], 
             UndirectedEdge[53, 155] -> 
             RGBColor[
              0.6524866330944523, 0.728284776143913, 0.9661081934380052], 
             UndirectedEdge[164, 200] -> 
             RGBColor[
              0.19289342095861073`, 0.320073593949734, 0.9342963670121247], 
             UndirectedEdge[81, 142] -> 
             RGBColor[
              0.28401388302550323`, 0.4158469769530182, 0.9394855425261907], 
             UndirectedEdge[39, 85] -> 
             RGBColor[
              0.26126709675452753`, 0.3919386623526739, 0.9381901466989133], 
             UndirectedEdge[107, 142] -> 
             RGBColor[
              0.23981543626826407`, 0.36939160706777974`, 0.9369685063691083],
              UndirectedEdge[121, 161] -> 
             RGBColor[
              0.25059050057240173`, 0.38071688282996385`, 0.9375821303409498],
              UndirectedEdge[1, 196] -> 
             RGBColor[
              0.20645103349834157`, 0.33432350433127433`, 0.935068452989572], 
             UndirectedEdge[88, 121] -> 
             RGBColor[
              0.21695791281236698`, 0.34536690066494, 0.9356668042229707], 
             UndirectedEdge[85, 133] -> 
             RGBColor[
              0.25979757259338154`, 0.39039409928609614`, 0.9381064594719022],
              UndirectedEdge[118, 127] -> 
             RGBColor[
              0.6328274279834254, 0.7079836098876566, 0.9670229522085898], 
             UndirectedEdge[100, 187] -> 
             RGBColor[
              0.2046359853658942, 0.3324157736633738, 0.9349650886835521], 
             UndirectedEdge[26, 116] -> 
             RGBColor[
              0.2667049754056552, 0.39765421759642916`, 0.9384998258434745], 
             UndirectedEdge[131, 147] -> 
             RGBColor[
              0.21550989668752718`, 0.3438449439082084, 0.9355843418468089], 
             UndirectedEdge[134, 160] -> 
             RGBColor[
              0.3450319511386071, 0.4675505014401682, 0.9434155666515178], 
             UndirectedEdge[3, 5] -> 
             RGBColor[
              0.38651352623245844`, 0.5092003225130362, 0.945849278004409], 
             UndirectedEdge[16, 100] -> 
             RGBColor[
              0.19648326478805916`, 0.32384674742372915`, 0.9345008033075137],
              UndirectedEdge[75, 147] -> 
             RGBColor[
              0.3758334925595824, 0.4931487046810145, 0.9457355307409967], 
             UndirectedEdge[72, 76] -> 
             RGBColor[
              0.25872488056116644`, 0.3892666319476351, 0.9380453712475731], 
             UndirectedEdge[40, 69] -> 
             RGBColor[
              0.37782213400795434`, 0.4947977837110262, 0.9458889334343104], 
             UndirectedEdge[177, 179] -> 
             RGBColor[
              0.2929650964677688, 0.41972688072457853`, 0.940197722295881], 
             UndirectedEdge[98, 100] -> 
             RGBColor[
              0.19914601799870904`, 0.3266454698764268, 0.9346524431636698], 
             UndirectedEdge[136, 187] -> 
             RGBColor[
              0.2131466560055322, 0.3413610281133182, 0.9354497587860706], 
             UndirectedEdge[54, 199] -> 
             RGBColor[
              0.9918267372139176, 0.9824082030898711, 0.5688071701781774], 
             UndirectedEdge[166, 198] -> 
             RGBColor[
              0.5746764165171943, 0.6601910829977264, 0.9621578445394816], 
             UndirectedEdge[48, 104] -> 
             RGBColor[
              0.28879698411440874`, 0.4154790711874804, 0.939955479525905], 
             UndirectedEdge[187, 198] -> 
             RGBColor[
              0.2745522899410462, 0.4024926676355137, 0.9390715600433216], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.20340607327822147`, 0.3311230580782995, 0.9348950470096511], 
             UndirectedEdge[103, 117] -> 
             RGBColor[
              0.1832018217377303, 0.30988710868570724`, 0.9337444447739318], 
             UndirectedEdge[85, 140] -> 
             RGBColor[
              0.632097596410786, 0.6952982597896742, 0.7484529667837756], 
             UndirectedEdge[36, 70] -> 
             RGBColor[
              0.18680103840766088`, 0.3136701136093215, 0.9339494148387204], 
             UndirectedEdge[54, 171] -> 
             RGBColor[
              0.6480714766956179, 0.7066517748176793, 0.6751229004016905], 
             UndirectedEdge[120, 125] -> 
             RGBColor[
              0.22911059591556282`, 0.35814014113101095`, 0.9363588815474142],
              UndirectedEdge[81, 104] -> 
             RGBColor[
              0.336565061683316, 0.46568634938344766`, 0.9426758008769163], 
             UndirectedEdge[93, 162] -> 
             RGBColor[
              0.34139937953517563`, 0.46297232673312194`, 0.9432365284830118],
              UndirectedEdge[73, 168] -> 
             RGBColor[
              0.2134383142319024, 0.3416675794014329, 0.9354663682905927], 
             UndirectedEdge[119, 199] -> 
             RGBColor[
              0.921043290148025, 0.6766189653862216, 0.46033982093126385`], 
             UndirectedEdge[17, 107] -> 
             RGBColor[
              0.20455110797063392`, 0.33232656213941764`, 0.9349602550414569],
              UndirectedEdge[14, 48] -> 
             RGBColor[
              0.19487547737670605`, 0.3221568609147874, 0.9344092421929455], 
             UndirectedEdge[64, 182] -> 
             RGBColor[
              0.48518193863662246`, 0.5898773465279377, 0.9534583400112507], 
             UndirectedEdge[71, 129] -> 
             RGBColor[
              0.40910477455238126`, 0.5287364214993203, 0.947297421991063], 
             UndirectedEdge[80, 100] -> 
             RGBColor[
              0.2137920345531072, 0.3420393618861828, 0.935486512139603], 
             UndirectedEdge[18, 178] -> 
             RGBColor[
              0.20335755177255102`, 0.3310720588993987, 0.9348922837816843], 
             UndirectedEdge[174, 186] -> 
             RGBColor[
              0.18655058120662976`, 0.3134068672111341, 0.9339351516716399], 
             UndirectedEdge[115, 165] -> 
             RGBColor[
              0.2604142264170086, 0.39046168008252585`, 0.9381628341942789], 
             UndirectedEdge[113, 198] -> 
             RGBColor[
              0.2750384221935423, 0.4030036234554522, 0.939099244555933], 
             UndirectedEdge[67, 100] -> 
             RGBColor[
              0.2308404904839133, 0.3599583700039979, 0.936457396483932], 
             UndirectedEdge[106, 147] -> 
             RGBColor[
              0.21727737751825504`, 0.3457026783260606, 0.9356849972653654], 
             UndirectedEdge[75, 129] -> 
             RGBColor[
              0.47830661680484077`, 0.5873498848465282, 0.9520731954511965], 
             UndirectedEdge[175, 183] -> 
             RGBColor[
              0.7184776908452273, 0.695458275607814, 0.6107486570608233], 
             UndirectedEdge[105, 144] -> 
             RGBColor[
              0.20212260779592514`, 0.3297740544799944, 0.9348219555491514], 
             UndirectedEdge[44, 128] -> 
             RGBColor[
              0.6650402658915442, 0.5906178095064059, 0.5929751287851128], 
             UndirectedEdge[70, 138] -> 
             RGBColor[
              0.2064620848582796, 0.334335120011266, 0.9350690823481714], 
             UndirectedEdge[110, 145] -> 
             RGBColor[
              0.18515978669395372`, 0.31194505399684636`, 0.9338559479816391],
              UndirectedEdge[49, 118] -> 
             RGBColor[
              0.4066109576924045, 0.5266077075173656, 0.9471298685655758], 
             UndirectedEdge[70, 185] -> 
             RGBColor[
              0.21155038817505178`, 0.3396832494142572, 0.9353588536945914], 
             UndirectedEdge[11, 138] -> 
             RGBColor[
              0.2124149402657507, 0.3405919484773504, 0.9354080886571665], 
             UndirectedEdge[120, 187] -> 
             RGBColor[
              0.1987095901475981, 0.32618675653378515`, 0.9346275892431862], 
             UndirectedEdge[71, 127] -> 
             RGBColor[
              0.6192630181344778, 0.6962347998435606, 0.9661586400075515], 
             UndirectedEdge[4, 182] -> 
             RGBColor[
              0.33757022299890055`, 0.4668080932140755, 0.9427306540012304], 
             UndirectedEdge[29, 71] -> 
             RGBColor[
              0.2853246797443417, 0.4121402643323634, 0.939746356828151], 
             UndirectedEdge[63, 185] -> 
             RGBColor[
              0.2118614125837917, 0.3400101557879294, 0.9353765660745497], 
             UndirectedEdge[83, 175] -> 
             RGBColor[
              0.7134786289406714, 0.7747821951592325, 0.9733333335119576], 
             UndirectedEdge[79, 126] -> 
             RGBColor[
              0.1869217092836395, 0.3137969463509505, 0.9339562868665908], 
             UndirectedEdge[107, 154] -> 
             RGBColor[
              0.27475191641420155`, 0.4039740129877124, 0.9390363717067235], 
             UndirectedEdge[34, 64] -> 
             RGBColor[
              0.5297940733748047, 0.6285181353670621, 0.956300985787806], 
             UndirectedEdge[159, 180] -> 
             RGBColor[
              0.29846249583214285`, 0.427955785985238, 0.9404210556305891], 
             UndirectedEdge[3, 123] -> 
             RGBColor[
              0.4349086817945046, 0.5511177738496366, 0.9489329745226667], 
             UndirectedEdge[50, 97] -> 
             RGBColor[
              0.21027301783359342`, 0.33834065219542714`, 0.9352861093433454],
              UndirectedEdge[87, 89] -> 
             RGBColor[
              0.24210890877301894`, 0.37180219208483256`, 0.9370991162353657],
              UndirectedEdge[123, 191] -> 
             RGBColor[
              0.6306139888746021, 0.7083706761376785, 0.9658367189463131], 
             UndirectedEdge[108, 151] -> 
             RGBColor[
              0.6509649455844404, 0.716416401604573, 0.8457783120147642], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.19532837830452823`, 0.32263288850550587`, 0.9344350342307781],
              UndirectedEdge[19, 33] -> 
             RGBColor[
              0.6719200989970671, 0.734922803310785, 0.8577553559890845], 
             UndirectedEdge[156, 199] -> 
             RGBColor[
              0.9069891921772075, 0.5685930098375191, 0.4468816008425758], 
             UndirectedEdge[47, 144] -> 
             RGBColor[
              0.19737482195309003`, 0.32478383053216575`, 0.9345515761691217],
              UndirectedEdge[123, 127] -> 
             RGBColor[
              0.6629559060472224, 0.73407938328518, 0.9689427121892478], 
             UndirectedEdge[82, 120] -> 
             RGBColor[
              0.2029515968118113, 0.3306453744966301, 0.9348691652472267], 
             UndirectedEdge[120, 137] -> 
             RGBColor[
              0.2589152311792967, 0.38806631610919806`, 0.9381074864400005], 
             UndirectedEdge[122, 179] -> 
             RGBColor[
              0.32323201256899053`, 0.45153932858028145`, 0.9419213783919558],
              UndirectedEdge[52, 124] -> 
             RGBColor[
              0.20581307491926143`, 0.333652969415751, 0.9350321221922685], 
             UndirectedEdge[17, 106] -> 
             RGBColor[
              0.18824964863953902`, 0.315192694810219, 0.934031911048399], 
             UndirectedEdge[125, 166] -> 
             RGBColor[
              0.5340062312264762, 0.620853714704589, 0.9597168964072044], 
             UndirectedEdge[7, 79] -> 
             RGBColor[
              0.20133607999592745`, 0.328947363893454, 0.934777163954505], 
             UndirectedEdge[49, 127] -> 
             RGBColor[
              0.6485709500663741, 0.7216198574234791, 0.9680261155142653], 
             UndirectedEdge[121, 200] -> 
             RGBColor[
              0.20398334673618768`, 0.33172980908387323`, 0.9349279218790827],
              UndirectedEdge[56, 193] -> 
             RGBColor[
              0.2060154437903921, 0.33386567193023686`, 0.9350436468001014], 
             UndirectedEdge[149, 194] -> 
             RGBColor[
              0.1935128959182038, 0.3207247014092473, 0.9343316451946424], 
             UndirectedEdge[108, 133] -> 
             RGBColor[
              0.27857495084464845`, 0.41013031438272207`, 0.9391758033846701],
              UndirectedEdge[41, 140] -> 
             RGBColor[
              0.6422147641826323, 0.7059320445833706, 0.7490291245213738], 
             UndirectedEdge[36, 185] -> 
             RGBColor[
              0.2073008742546082, 0.33521674084912667`, 0.9351168501634146], 
             UndirectedEdge[108, 111] -> 
             RGBColor[
              0.26408143509617243`, 0.39489671038909974`, 0.9383504191040295],
              UndirectedEdge[72, 154] -> 
             RGBColor[
              0.2925360773933412, 0.42266629375772025`, 0.940049153365177], 
             UndirectedEdge[63, 110] -> 
             RGBColor[
              0.18589948479502594`, 0.3127225236006417, 0.9338980726942099], 
             UndirectedEdge[15, 186] -> 
             RGBColor[
              0.18099749200595946`, 0.30757021837503873`, 0.933618911456721], 
             UndirectedEdge[54, 155] -> 
             RGBColor[
              0.8307914164161123, 0.8585643375610341, 0.688734731768329], 
             UndirectedEdge[18, 108] -> 
             RGBColor[
              0.2655472156605108, 0.39643733869807485`, 0.9384338931387406], 
             UndirectedEdge[44, 102] -> 
             RGBColor[
              0.9339747756675465, 0.8048847960141194, 0.5871542851309398], 
             UndirectedEdge[8, 122] -> 
             RGBColor[
              0.2805939833782982, 0.4122524455896443, 0.9392907843005704], 
             UndirectedEdge[42, 197] -> 
             RGBColor[
              0.20173805393446126`, 0.32936986398947277`, 0.9348000557756375],
              UndirectedEdge[48, 147] -> 
             RGBColor[
              0.2300092060376818, 0.3590846373445305, 0.9364100560644943], 
             UndirectedEdge[34, 54] -> 
             RGBColor[
              0.7092249646791587, 0.7597119219751208, 0.6790161754635967], 
             UndirectedEdge[5, 75] -> 
             RGBColor[
              0.42823819051471873`, 0.5440144353455778, 0.9488742299813958], 
             UndirectedEdge[55, 115] -> 
             RGBColor[
              0.3254517520127096, 0.4563116827378988, 0.9419584757459334], 
             UndirectedEdge[49, 155] -> 
             RGBColor[
              0.5477722741141999, 0.6424322100267535, 0.9580969923209677], 
             UndirectedEdge[66, 136] -> 
             RGBColor[
              0.2031791949691239, 0.33088459459052233`, 0.9348821266255843], 
             UndirectedEdge[136, 148] -> 
             RGBColor[
              0.2081945933984414, 0.33615609633436194`, 0.9351677461465169], 
             UndirectedEdge[130, 189] -> 
             RGBColor[
              0.18936342684036145`, 0.3163633463169, 0.9340953390692487], 
             UndirectedEdge[48, 76] -> 
             RGBColor[
              0.23737108877035865`, 0.36682244286689847`, 0.9368293043951907],
              UndirectedEdge[29, 141] -> 
             RGBColor[
              0.2753633186073925, 0.40351223398810643`, 0.9391116277049905], 
             UndirectedEdge[133, 163] -> 
             RGBColor[
              0.26544293338464375`, 0.39632773141426036`, 0.9384279544174017],
              UndirectedEdge[111, 169] -> 
             RGBColor[
              0.20611458183414505`, 0.33396987229993624`, 0.9350492925650316],
              UndirectedEdge[76, 142] -> 
             RGBColor[
              0.26312316685427595`, 0.39388950970915076`, 0.9382958471452842],
              UndirectedEdge[78, 98] -> 
             RGBColor[
              0.18771622042890102`, 0.3146320279395365, 0.9340015331009395], 
             UndirectedEdge[21, 170] -> 
             RGBColor[
              0.5082558273140996, 0.6089687689524979, 0.9552557972010979], 
             UndirectedEdge[92, 139] -> 
             RGBColor[
              0.26505756074119424`, 0.3959226803319581, 0.938406008015465], 
             UndirectedEdge[63, 70] -> 
             RGBColor[
              0.1913615767368444, 0.3184635285481242, 0.9342091307498555], 
             UndirectedEdge[71, 197] -> 
             RGBColor[
              0.2822222657868389, 0.40887943055862197`, 0.9395696789428815], 
             UndirectedEdge[127, 141] -> 
             RGBColor[
              0.6093016569975287, 0.6876067694993037, 0.9655239108843909], 
             UndirectedEdge[64, 138] -> 
             RGBColor[
              0.4257022995794623, 0.5303271273768558, 0.949962438870419], 
             UndirectedEdge[39, 108] -> 
             RGBColor[
              0.2800444750057945, 0.41167487744929976`, 0.9392594906116811], 
             UndirectedEdge[24, 165] -> 
             RGBColor[
              0.23147521014501135`, 0.3606255006113628, 0.9364935428296479], 
             UndirectedEdge[132, 182] -> 
             RGBColor[
              0.3206991952751244, 0.45143891338558356`, 0.9416833404765177], 
             UndirectedEdge[77, 181] -> 
             RGBColor[
              0.627745965168717, 0.3440360509358098, 0.5566794847766803], 
             UndirectedEdge[20, 47] -> 
             RGBColor[
              0.189292245231432, 0.3162885299327404, 0.9340912853819239], 
             UndirectedEdge[191, 199] -> 
             RGBColor[
              0.9026821480304056, 0.9219432707783801, 0.8549565211308954], 
             UndirectedEdge[89, 154] -> 
             RGBColor[
              0.29969282708516165`, 0.4301884914479621, 0.9404567196726639], 
             UndirectedEdge[93, 164] -> 
             RGBColor[
              0.2132799643411767, 0.3415011436263172, 0.9354573504985735], 
             UndirectedEdge[26, 187] -> 
             RGBColor[
              0.24813165922146568`, 0.378132484670584, 0.9374421029635438], 
             UndirectedEdge[5, 188] -> 
             RGBColor[
              0.33376821355982345`, 0.4635149837324976, 0.9424883933217574], 
             UndirectedEdge[7, 16] -> 
             RGBColor[
              0.19783499493782034`, 0.3252675015157697, 0.9345777823398371], 
             UndirectedEdge[154, 160] -> 
             RGBColor[
              0.38753078679870345`, 0.510081422486515, 0.9459140969481619], 
             UndirectedEdge[88, 152] -> 
             RGBColor[
              0.20837422546163153`, 0.3363449010221054, 0.9351779759267738], 
             UndirectedEdge[9, 18] -> 
             RGBColor[
              0.2081906159438856, 0.3361519157774386, 0.935167519636364], 
             UndirectedEdge[9, 200] -> 
             RGBColor[
              0.19196359639909227`, 0.31909628938339796`, 0.9342434148790122],
              UndirectedEdge[55, 183] -> 
             RGBColor[
              0.6361311703010923, 0.6254168955585735, 0.6051471025896153], 
             UndirectedEdge[72, 104] -> 
             RGBColor[
              0.31015077590521656`, 0.43792326026821704`, 0.9411715463782875],
              UndirectedEdge[112, 181] -> 
             RGBColor[
              0.6897919274498447, 0.754885022928866, 0.9666005855889899], 
             UndirectedEdge[136, 193] -> 
             RGBColor[
              0.22613676588736786`, 0.35501445721966407`, 0.9361895263266957],
              UndirectedEdge[80, 198] -> 
             RGBColor[
              0.28370833912825916`, 0.4121162558583227, 0.9395929834993725], 
             UndirectedEdge[42, 131] -> 
             RGBColor[
              0.19213265043958744`, 0.3192739758986036, 0.9342530422565254], 
             UndirectedEdge[65, 156] -> 
             RGBColor[
              0.887528121922009, 0.5046298539287588, 0.2252206944152773], 
             UndirectedEdge[26, 192] -> 
             RGBColor[
              0.37924820246199464`, 0.5010949181579147, 0.9455333797204014], 
             UndirectedEdge[65, 155] -> 
             RGBColor[
              0.8147643189956533, 0.8045011746203956, 0.6264724847532339], 
             UndirectedEdge[59, 62] -> 
             RGBColor[
              0.19206220882201708`, 0.3191999372922807, 0.9342490307106137], 
             UndirectedEdge[82, 187] -> 
             RGBColor[
              0.2077231055465765, 0.3356605327079955, 0.9351408956108569], 
             UndirectedEdge[4, 86] -> 
             RGBColor[
              0.26820213237561147`, 0.3968644845029512, 0.9386716201723606], 
             UndirectedEdge[73, 167] -> 
             RGBColor[
              0.20840651893599757`, 0.33637884351118863`, 0.9351798149923649],
              UndirectedEdge[74, 159] -> 
             RGBColor[
              0.30041133141594933`, 0.42964376941660665`, 0.9405452337107016],
              UndirectedEdge[25, 60] -> 
             RGBColor[
              0.18025977124348086`, 0.3067948270794758, 0.9335768993506579], 
             UndirectedEdge[159, 162] -> 
             RGBColor[
              0.3531520525661749, 0.4753251312512108, 0.9439058258256054], 
             UndirectedEdge[10, 147] -> 
             RGBColor[
              0.23373755563263043`, 0.3630033691598391, 0.9366223800583277], 
             UndirectedEdge[23, 163] -> 
             RGBColor[
              0.2527001813973467, 0.382934291138471, 0.9377022735429374], 
             UndirectedEdge[40, 54] -> 
             RGBColor[
              0.7471114929956602, 0.7911014986375555, 0.6818242326049438], 
             UndirectedEdge[123, 129] -> 
             RGBColor[
              0.45279766246512576`, 0.5665810049409397, 0.9500814941727593], 
             UndirectedEdge[25, 165] -> 
             RGBColor[
              0.19267100347283378`, 0.3198398190700993, 0.9342837006653468], 
             UndirectedEdge[39, 178] -> 
             RGBColor[
              0.21785481111783467`, 0.34630959765062364`, 0.935717881254625], 
             UndirectedEdge[76, 107] -> 
             RGBColor[
              0.2409407195820268, 0.37057435117762727`, 0.9370325895891196], 
             UndirectedEdge[63, 138] -> 
             RGBColor[
              0.20677310926701956`, 0.33466202638493814`, 0.9350867947281298],
              UndirectedEdge[71, 81] -> 
             RGBColor[
              0.334884249211027, 0.4642305141000421, 0.942568700992466], 
             UndirectedEdge[8, 83] -> 
             RGBColor[
              0.60482509904127, 0.6795990406798771, 0.9661417830923238], 
             UndirectedEdge[10, 149] -> 
             RGBColor[
              0.2017271344819297, 0.32935838695252884`, 0.9347994339289696], 
             UndirectedEdge[119, 172] -> 
             RGBColor[
              0.858083307192903, 0.43025919736952545`, 0.20258043262042846`], 
             UndirectedEdge[106, 130] -> 
             RGBColor[
              0.1846627044737023, 0.31142258906652903`, 0.933827639884563], 
             UndirectedEdge[147, 176] -> 
             RGBColor[
              0.24180624149358806`, 0.37148406958393687`, 0.9370818797815581],
              UndirectedEdge[27, 197] -> 
             RGBColor[
              0.23361320117338766`, 0.3628726647386469, 0.9366152982558398], 
             UndirectedEdge[72, 176] -> 
             RGBColor[
              0.2436445546193927, 0.37341625323494165`, 0.9371865689945322], 
             UndirectedEdge[92, 118] -> 
             RGBColor[
              0.31765722646768046`, 0.4436155762000519, 0.9416794866592155], 
             UndirectedEdge[123, 171] -> 
             RGBColor[
              0.3794372903745538, 0.5029791731450995, 0.9454017576293117], 
             UndirectedEdge[66, 113] -> 
             RGBColor[
              0.1939997700984511, 0.32123643704229315`, 0.9343593719589416], 
             UndirectedEdge[67, 179] -> 
             RGBColor[
              0.3122151911082063, 0.43995995071817273`, 0.941293986707691], 
             UndirectedEdge[130, 197] -> 
             RGBColor[
              0.19250062713784824`, 0.3196607427395459, 0.9342739979851187], 
             UndirectedEdge[15, 194] -> 
             RGBColor[
              0.19022447471756204`, 0.31726836222942645`, 0.934144374472049], 
             UndirectedEdge[47, 135] -> 
             RGBColor[
              0.19659862417943424`, 0.3239679974582722, 0.9345073728541936], 
             UndirectedEdge[8, 170] -> 
             RGBColor[
              0.4692360918503271, 0.5728158701273882, 0.9528557575864605], 
             UndirectedEdge[17, 149] -> 
             RGBColor[
              0.1884865346732682, 0.31544167705111037`, 0.9340454013575784], 
             UndirectedEdge[13, 97] -> 
             RGBColor[
              0.21895267363831583`, 0.3474635207681535, 0.9357804029010244], 
             UndirectedEdge[11, 86] -> 
             RGBColor[
              0.20252648869962175`, 0.33019855891730787`, 0.9348449559691285],
              UndirectedEdge[15, 62] -> 
             RGBColor[
              0.18941420148966015`, 0.3164167136926116, 0.9340982306104119], 
             UndirectedEdge[37, 160] -> 
             RGBColor[
              0.33951855272220766`, 0.4617555701348826, 0.9431015867680459], 
             UndirectedEdge[46, 50] -> 
             RGBColor[
              0.1933628575006826, 0.3205670015194474, 0.9343231007287265], 
             UndirectedEdge[49, 53] -> 
             RGBColor[
              0.5270688387556056, 0.6260965211703475, 0.956144232988289], 
             UndirectedEdge[52, 120] -> 
             RGBColor[
              0.1897634736745903, 0.3167838209041087, 0.9341181211446418], 
             UndirectedEdge[81, 147] -> 
             RGBColor[
              0.2777772836065891, 0.4092919155404977, 0.9391303774155055], 
             UndirectedEdge[49, 123] -> 
             RGBColor[
              0.43673943575620155`, 0.552703480914889, 0.949049628546234], 
             UndirectedEdge[127, 140] -> 
             RGBColor[
              0.9342553301344888, 0.9459893647897327, 0.7730553915426139], 
             UndirectedEdge[31, 132] -> 
             RGBColor[
              0.4162636354385904, 0.5320766653506034, 0.9483626292299419], 
             UndirectedEdge[146, 186] -> 
             RGBColor[
              0.2142358988127285, 0.34250589136566434`, 0.9355117895525502], 
             UndirectedEdge[98, 124] -> 
             RGBColor[
              0.20926922402508408`, 0.3372856012584804, 0.9352289447709307], 
             UndirectedEdge[4, 53] -> 
             RGBColor[
              0.483045374115442, 0.5879656087827072, 0.953339096749839], 
             UndirectedEdge[82, 137] -> 
             RGBColor[
              0.26792874657827515`, 0.39754009228340836`, 0.9386207928076713],
              UndirectedEdge[42, 107] -> 
             RGBColor[
              0.21020159060141025`, 0.3382655776456545, 0.9352820416681398], 
             UndirectedEdge[99, 102] -> 
             RGBColor[
              0.7604981725449849, 0.8117818781391992, 0.9474611303534258], 
             UndirectedEdge[57, 88] -> 
             RGBColor[
              0.1992012217508764, 0.32670349252007475`, 0.9346555869356892], 
             UndirectedEdge[40, 49] -> 
             RGBColor[
              0.46409235069374777`, 0.5749693711032751, 0.9511864931575826], 
             UndirectedEdge[21, 90] -> 
             RGBColor[
              0.29428715223398993`, 0.42178551711259177`, 0.9402485134141754],
              UndirectedEdge[143, 158] -> 
             RGBColor[
              0.5860035167018279, 0.6680847618686957, 0.9637366121327604], 
             UndirectedEdge[24, 111] -> 
             RGBColor[
              0.2386416994170433, 0.36815793521793205`, 0.9369016637918195], 
             UndirectedEdge[139, 155] -> 
             RGBColor[
              0.47942908630476494`, 0.5811030666228374, 0.9538203503715414], 
             UndirectedEdge[94, 174] -> 
             RGBColor[
              0.19022197405444352`, 0.31726573387393764`, 0.9341442320629838],
              UndirectedEdge[4, 118] -> 
             RGBColor[
              0.3625874930522409, 0.48847679512972536`, 0.9443247323271259], 
             UndirectedEdge[121, 159] -> 
             RGBColor[
              0.23612256314975283`, 0.36551016327854535`, 0.9367582027081254],
              UndirectedEdge[5, 76] -> 
             RGBColor[
              0.3092912653904981, 0.4382001789611937, 0.9410793812749982], 
             UndirectedEdge[27, 194] -> 
             RGBColor[
              0.23402121805989123`, 0.3633015163561269, 0.9366385342139192], 
             UndirectedEdge[77, 160] -> 
             RGBColor[
              0.6302548648825095, 0.34620913376693074`, 0.5568393496479103], 
             UndirectedEdge[2, 80] -> 
             RGBColor[
              0.20208335684743473`, 0.32973279924447707`, 0.9348197202657014],
              UndirectedEdge[74, 85] -> 
             RGBColor[
              0.3082012500479231, 0.4378314678081793, 0.9409888580526407], 
             UndirectedEdge[35, 110] -> 
             RGBColor[
              0.18045196756199675`, 0.30699683759618646`, 0.9335878446466683],
              UndirectedEdge[143, 154] -> 
             RGBColor[
              0.5937667549119501, 0.6748088886146058, 0.9642312788067474], 
             UndirectedEdge[53, 129] -> 
             RGBColor[
              0.5431270654645298, 0.6399740451963982, 0.9571760986148143], 
             UndirectedEdge[80, 187] -> 
             RGBColor[
              0.21263714806957626`, 0.34082550296795955`, 0.9354207430628674],
              UndirectedEdge[30, 87] -> 
             RGBColor[
              0.213134602991505, 0.3413483596313704, 0.9354490723847526], 
             UndirectedEdge[29, 197] -> 
             RGBColor[
              0.2038083296196198, 0.3315458549976343, 0.9349179549132087], 
             UndirectedEdge[74, 121] -> 
             RGBColor[
              0.28164177891966025`, 0.4099157796846441, 0.9394763354631025], 
             UndirectedEdge[127, 199] -> 
             RGBColor[
              0.935024065203026, 0.9476519779258816, 0.8580625143738301], 
             UndirectedEdge[52, 80] -> 
             RGBColor[
              0.20369103159656846`, 0.33142256733828307`, 0.9349112749643229],
              UndirectedEdge[125, 187] -> 
             RGBColor[
              0.233882104650328, 0.36315529934237634`, 0.9366306119110444], 
             UndirectedEdge[57, 152] -> 
             RGBColor[
              0.19101263224123774`, 0.3180967657588828, 0.9341892588770478], 
             UndirectedEdge[128, 193] -> 
             RGBColor[
              0.3303839734000996, 0.45325331449434825`, 0.942541154768971], 
             UndirectedEdge[151, 172] -> 
             RGBColor[
              0.9316219629473853, 0.7456677416234209, 0.4816953197665501], 
             UndirectedEdge[5, 27] -> 
             RGBColor[
              0.31042728364880795`, 0.439394206178395, 0.9411440758342206], 
             UndirectedEdge[65, 118] -> 
             RGBColor[
              0.6736030025738579, 0.6886766721110076, 0.6155053609978421], 
             UndirectedEdge[78, 80] -> 
             RGBColor[
              0.20236223698329917`, 0.33002591994929253`, 0.9348356020768727],
              UndirectedEdge[40, 199] -> 
             RGBColor[
              0.7505454658303996, 0.8010014916056775, 0.8412228920171474], 
             UndirectedEdge[5, 42] -> 
             RGBColor[
              0.2785521364098815, 0.40589140542922086`, 0.9393288333540183], 
             UndirectedEdge[123, 196] -> 
             RGBColor[
              0.3420552644486344, 0.4636882937396207, 0.9432729065545822], 
             UndirectedEdge[80, 124] -> 
             RGBColor[
              0.22391524057948223`, 0.35267949326823644`, 0.9360630137468638],
              UndirectedEdge[22, 48] -> 
             RGBColor[
              0.19949157754304903`, 0.3270086748672687, 0.9346721222685106], 
             UndirectedEdge[69, 86] -> 
             RGBColor[
              0.22595538032998164`, 0.3548238094983426, 0.9361791966875385], 
             UndirectedEdge[81, 143] -> 
             RGBColor[
              0.5808462742510027, 0.663366694048388, 0.9634171920700499], 
             UndirectedEdge[80, 116] -> 
             RGBColor[
              0.23121046425376574`, 0.3603472358938047, 0.936478465942798], 
             UndirectedEdge[90, 169] -> 
             RGBColor[
              0.20968181085613852`, 0.3377192561774346, 0.9352524409805917], 
             UndirectedEdge[121, 173] -> 
             RGBColor[
              0.292553121290118, 0.41936663602592106`, 0.9401715965504269], 
             UndirectedEdge[8, 179] -> 
             RGBColor[
              0.32590224390731876`, 0.4543459110193097, 0.9420734441164204], 
             UndirectedEdge[29, 167] -> 
             RGBColor[
              0.20312227411308098`, 0.33082476716183046`, 0.9348788850670395],
              UndirectedEdge[76, 87] -> 
             RGBColor[
              0.2404757286880707, 0.37008561626595393`, 0.9370061090456012], 
             UndirectedEdge[111, 163] -> 
             RGBColor[
              0.25094941763616774`, 0.3810941274206381, 0.9376025701367612], 
             UndirectedEdge[130, 149] -> 
             RGBColor[
              0.1848995905074315, 0.3116715713074204, 0.9338411301937424], 
             UndirectedEdge[7, 122] -> 
             RGBColor[
              0.24320904209445873`, 0.37295850195814717`, 0.9371617672005202],
              UndirectedEdge[89, 142] -> 
             RGBColor[
              0.2647563469392241, 0.39560608552802945`, 0.9383888543350487], 
             UndirectedEdge[44, 172] -> 
             RGBColor[
              0.8840573238836684, 0.5664132115032791, 0.22496692784453026`], 
             UndirectedEdge[7, 179] -> 
             RGBColor[
              0.2885173026234793, 0.4150519673878126, 0.9399444270163702], 
             UndirectedEdge[73, 188] -> 
             RGBColor[
              0.26534078986482257`, 0.3958083524158491, 0.9384372235539715], 
             UndirectedEdge[16, 120] -> 
             RGBColor[
              0.19055686956976303`, 0.31761773029414053`, 0.9341633038671477],
              UndirectedEdge[98, 116] -> 
             RGBColor[
              0.21656444769936758`, 0.34495334388404864`, 0.9356443969668649],
              UndirectedEdge[5, 81] -> 
             RGBColor[
              0.3301819815617254, 0.46015764620506105`, 0.9422690766559045], 
             UndirectedEdge[76, 106] -> 
             RGBColor[
              0.2246392602509319, 0.35344048384842863`, 0.9361042455960618], 
             UndirectedEdge[135, 144] -> 
             RGBColor[
              0.19771245739729065`, 0.32513870679134427`, 0.9345708040081819],
              UndirectedEdge[194, 197] -> 
             RGBColor[
              0.20111393254862053`, 0.3287138728413728, 0.9347645129860187], 
             UndirectedEdge[27, 29] -> 
             RGBColor[
              0.2367156151308905, 0.36613349851238836`, 0.9367919761411093], 
             UndirectedEdge[44, 58] -> 
             RGBColor[
              0.9296752902178356, 0.8016782468054864, 0.5944321925119014], 
             UndirectedEdge[53, 92] -> 
             RGBColor[
              0.4381151075308816, 0.5431043898530338, 0.9506938510819287], 
             UndirectedEdge[83, 122] -> 
             RGBColor[
              0.6021548677029418, 0.6767924582408489, 0.9659897173678593], 
             UndirectedEdge[9, 178] -> 
             RGBColor[
              0.18848044580793838`, 0.31543527726759235`, 0.9340450546057055],
              UndirectedEdge[12, 99] -> 
             RGBColor[
              0.7509614073428162, 0.7434552401786318, 0.618284844686889], 
             UndirectedEdge[7, 126] -> 
             RGBColor[
              0.19407996143665954`, 0.32132072322317473`, 0.9343639387370202],
              UndirectedEdge[139, 146] -> 
             RGBColor[
              0.2655359588850107, 0.39642550711330343`, 0.9384332520820287], 
             UndirectedEdge[100, 198] -> 
             RGBColor[
              0.2757071764245771, 0.40370652655373696`, 0.9391373291200573], 
             UndirectedEdge[56, 109] -> 
             RGBColor[
              0.19998929422011852`, 0.3275318066519287, 0.9347004664969638], 
             UndirectedEdge[9, 159] -> 
             RGBColor[
              0.22410281281265743`, 0.3528766435780701, 0.9360736957080549], 
             UndirectedEdge[2, 98] -> 
             RGBColor[
              0.18743734029303655`, 0.314338907234721, 0.9339856512897682], 
             UndirectedEdge[95, 164] -> 
             RGBColor[
              0.22218549989478478`, 0.35086142613672566`, 0.9359645075737923],
              UndirectedEdge[108, 163] -> 
             RGBColor[
              0.29489469195251866`, 0.4272833970184431, 0.94010518849787], 
             UndirectedEdge[85, 121] -> 
             RGBColor[
              0.24391248178172664`, 0.37369786167011787`, 0.9372018270500644],
              UndirectedEdge[55, 177] -> 
             RGBColor[
              0.2766340766323431, 0.4055817721640561, 0.9391571241529215], 
             UndirectedEdge[118, 141] -> 
             RGBColor[
              0.36734166462355905`, 0.4925946195931902, 0.9446276639357014], 
             UndirectedEdge[58, 77] -> 
             RGBColor[
              0.8889478384033738, 0.5521228653145076, 0.5579177911517261], 
             UndirectedEdge[142, 154] -> 
             RGBColor[
              0.29693436368645065`, 0.4272891715192359, 0.9402996292628881], 
             UndirectedEdge[103, 178] -> 
             RGBColor[
              0.1823641236245055, 0.3090066348555799, 0.933696739105647], 
             UndirectedEdge[48, 154] -> 
             RGBColor[
              0.2711822856025334, 0.4002221046769836, 0.9388330865127945], 
             UndirectedEdge[72, 181] -> 
             RGBColor[
              0.345687120645864, 0.46870305597394574`, 0.9434358908416056], 
             UndirectedEdge[45, 132] -> 
             RGBColor[
              0.5058042387487333, 0.6037176098642293, 0.9561309549136163], 
             UndirectedEdge[103, 200] -> 
             RGBColor[
              0.18584727421565939`, 0.3126676469713855, 0.9338950993789537], 
             UndirectedEdge[21, 61] -> 
             RGBColor[
              0.2843221054652073, 0.4113116211381439, 0.9396810187426589], 
             UndirectedEdge[51, 73] -> 
             RGBColor[
              0.19983789794558066`, 0.3273726795683112, 0.9346918447030995], 
             UndirectedEdge[18, 41] -> 
             RGBColor[
              0.25688700518109014`, 0.38733490839514545`, 0.9379407069635708],
              UndirectedEdge[27, 42] -> 
             RGBColor[
              0.2346453394457319, 0.36395750750422684`, 0.936674077003538], 
             UndirectedEdge[90, 165] -> 
             RGBColor[
              0.21653690052978303`, 0.3449243900622238, 0.9356428281963094], 
             UndirectedEdge[50, 135] -> 
             RGBColor[
              0.20034146801813224`, 0.3279019636427496, 0.9347205222737662], 
             UndirectedEdge[93, 121] -> 
             RGBColor[
              0.22436989011875363`, 0.3531573587604565, 0.9360889053655316], 
             UndirectedEdge[23, 175] -> 
             RGBColor[
              0.36210448140880436`, 0.4789065526071719, 0.9449365792097879], 
             UndirectedEdge[57, 164] -> 
             RGBColor[
              0.1885063938143962, 0.3154625502675782, 0.9340465323062868], 
             UndirectedEdge[54, 172] -> 
             RGBColor[
              0.9288667542587956, 0.7360484350731749, 0.311047781867342], 
             UndirectedEdge[99, 198] -> 
             RGBColor[
              0.44872208919176476`, 0.5604076738789969, 0.9505521468225746], 
             UndirectedEdge[45, 112] -> 
             RGBColor[
              0.8262269535061243, 0.8650081965468237, 0.9779469895534628], 
             UndirectedEdge[88, 173] -> 
             RGBColor[
              0.2921580234490212, 0.41895136314427833`, 0.9401490963128714], 
             UndirectedEdge[14, 22] -> 
             RGBColor[
              0.18387332754707644`, 0.31059290386725735`, 0.9337826860363703],
              UndirectedEdge[7, 67] -> 
             RGBColor[
              0.23219222063367448`, 0.36137912409603845`, 0.9365343755162554],
              UndirectedEdge[105, 135] -> 
             RGBColor[
              0.20134641002226938`, 0.32895822140610087`, 0.9347777522342233],
              UndirectedEdge[104, 176] -> 
             RGBColor[
              0.300594019570315, 0.4278785034268868, 0.9406273032429688], 
             UndirectedEdge[57, 91] -> 
             RGBColor[
              0.18403700151578473`, 0.31076493558589874`, 0.9337920070267542],
              UndirectedEdge[34, 185] -> 
             RGBColor[
              0.3310536945005693, 0.45407275524127744`, 0.9425750645902526], 
             UndirectedEdge[65, 172] -> 
             RGBColor[
              0.9128396568383367, 0.6819852721325363, 0.24878553485224705`], 
             UndirectedEdge[66, 120] -> 
             RGBColor[
              0.18874212911118976`, 0.3157103230109893, 0.9340599570827], 
             UndirectedEdge[91, 117] -> 
             RGBColor[
              0.1857785761820701, 0.31259544098237624`, 0.9338911871275704], 
             UndirectedEdge[27, 141] -> 
             RGBColor[
              0.30516819016116037`, 0.4348390437291191, 0.9408089710476214], 
             UndirectedEdge[13, 145] -> 
             RGBColor[
              0.20564959648275716`, 0.3334811432138535, 0.9350228123371542], 
             UndirectedEdge[1, 174] -> 
             RGBColor[
              0.1849745541189024, 0.31175036281604385`, 0.9338453992605169], 
             UndirectedEdge[182, 196] -> 
             RGBColor[
              0.28690951633149697`, 0.41592381842644754`, 0.9397590682480286],
              UndirectedEdge[96, 137] -> 
             RGBColor[
              0.630154419316935, 0.7035305563325196, 0.9671868226387048], 
             UndirectedEdge[89, 157] -> 
             RGBColor[
              0.23696986749514018`, 0.36640073386774574`, 0.9368064554371207],
              UndirectedEdge[119, 191] -> 
             RGBColor[
              0.8284647281297735, 0.6062540401066088, 0.5870905124717782], 
             UndirectedEdge[51, 157] -> 
             RGBColor[
              0.19431074366027534`, 0.32156328997263306`, 0.9343770814432435],
              UndirectedEdge[127, 195] -> 
             RGBColor[
              0.6879096375591269, 0.7543975082866485, 0.9708907042928315], 
             UndirectedEdge[27, 62] -> 
             RGBColor[
              0.23321094483198931`, 0.3624498678193121, 0.9365923903522819], 
             UndirectedEdge[4, 40] -> 
             RGBColor[
              0.42006888605358417`, 0.5368384587156347, 0.9483813569191326], 
             UndirectedEdge[161, 164] -> 
             RGBColor[
              0.23950057479482478`, 0.3690606676958246, 0.9369505754739917], 
             UndirectedEdge[20, 101] -> 
             RGBColor[
              0.18925893509711914`, 0.3162535188695931, 0.9340893884190526], 
             UndirectedEdge[13, 36] -> 
             RGBColor[
              0.20182875625464586`, 0.3294651978788461, 0.9348052211385899], 
             UndirectedEdge[182, 195] -> 
             RGBColor[
              0.42093237513181697`, 0.5377166564648852, 0.9484003790182465], 
             UndirectedEdge[184, 186] -> 
             RGBColor[
              0.18243843400162507`, 0.3090847397734826, 0.9337009709716915], 
             UndirectedEdge[96, 166] -> 
             RGBColor[
              0.8700729048613844, 0.8993494121193195, 0.9867932099380505], 
             UndirectedEdge[38, 43] -> 
             RGBColor[
              0.1854358891920559, 0.31223525522826123`, 0.9338716716104489], 
             UndirectedEdge[30, 176] -> 
             RGBColor[
              0.22182699852969923`, 0.3504846184717214, 0.9359440914514059], 
             UndirectedEdge[171, 174] -> 
             RGBColor[
              0.24889168370669917`, 0.37893131859289997`, 0.9374853852336225],
              UndirectedEdge[100, 125] -> 
             RGBColor[
              0.23503699113385892`, 0.36436915826059957`, 0.9366963809877801],
              UndirectedEdge[17, 188] -> 
             RGBColor[
              0.25233578672597107`, 0.38213926955209265`, 0.937696607864392], 
             UndirectedEdge[87, 107] -> 
             RGBColor[
              0.21716799810205883`, 0.34558771362458285`, 0.9356787682694253],
              UndirectedEdge[62, 184] -> 
             RGBColor[
              0.19085514348532573`, 0.3179312350910555, 0.9341802901253824], 
             UndirectedEdge[12, 33] -> 
             RGBColor[
              0.9713628299392978, 0.9155481063306994, 0.5253098577893779], 
             UndirectedEdge[32, 57] -> 
             RGBColor[
              0.1839232484123208, 0.31064537386179486`, 0.9337855289557946], 
             UndirectedEdge[17, 87] -> 
             RGBColor[
              0.2040861170766778, 0.33183782722774424`, 0.9349337744979385], 
             UndirectedEdge[42, 149] -> 
             RGBColor[
              0.1941370173040445, 0.32138069255734725`, 0.9343671879842612], 
             UndirectedEdge[87, 130] -> 
             RGBColor[
              0.20049917291084113`, 0.3280677214840543, 0.9347295033341025], 
             UndirectedEdge[58, 170] -> 
             RGBColor[
              0.8078923228953876, 0.8503457214275595, 0.9589431237256691], 
             UndirectedEdge[118, 196] -> 
             RGBColor[
              0.3119267863848373, 0.4375925203420974, 0.941353146573924], 
             UndirectedEdge[41, 159] -> 
             RGBColor[
              0.27279920204986197`, 0.40405963619577695`, 0.9388468830352616],
              UndirectedEdge[107, 157] -> 
             RGBColor[
              0.2120289568241801, 0.34018625540749603`, 0.9353861074711805], 
             UndirectedEdge[161, 173] -> 
             RGBColor[
              0.32579061120905595`, 0.4543013453093021, 0.9420644224308505], 
             UndirectedEdge[15, 184] -> 
             RGBColor[
              0.18036794199566558`, 0.3069085213984438, 0.9335830595149706], 
             UndirectedEdge[106, 142] -> 
             RGBColor[
              0.22351397693716918`, 0.3522577397385811, 0.9360401623760504], 
             UndirectedEdge[24, 39] -> 
             RGBColor[
              0.25460473932666533`, 0.38493610227813213`, 0.9378107352994711],
              UndirectedEdge[45, 134] -> 
             RGBColor[
              0.478958077481094, 0.5755005922270049, 0.9546021057447607], 
             UndirectedEdge[5, 73] -> 
             RGBColor[
              0.2859066569179567, 0.41362147278674055`, 0.939747662416915], 
             UndirectedEdge[147, 154] -> 
             RGBColor[
              0.2906977642675366, 0.42073411010671546`, 0.939944464152203], 
             UndirectedEdge[76, 143] -> 
             RGBColor[
              0.5599555580797754, 0.6414092268045206, 0.9622274966891435], 
             UndirectedEdge[5, 197] -> 
             RGBColor[
              0.27751999813753725`, 0.4048065626636409, 0.93927005460632], 
             UndirectedEdge[152, 159] -> 
             RGBColor[
              0.22753887579901738`, 0.3564881636357107, 0.9362693744119284], 
             UndirectedEdge[108, 115] -> 
             RGBColor[
              0.3115259900053915, 0.4441833842869002, 0.9410735735175593], 
             UndirectedEdge[65, 123] -> 
             RGBColor[
              0.7037314806376549, 0.7147724455085309, 0.6174251209785002], 
             UndirectedEdge[8, 67] -> 
             RGBColor[
              0.26957716191751396`, 0.4006730677275356, 0.9386633926163057], 
             UndirectedEdge[9, 41] -> 
             RGBColor[
              0.24200989921647753`, 0.37169812676333913`, 0.9370934777875921],
              UndirectedEdge[111, 165] -> 
             RGBColor[
              0.21296967150778956`, 0.3411750061847254, 0.9354396797807493], 
             UndirectedEdge[146, 195] -> 
             RGBColor[
              0.37321783418719845`, 0.490532301380389, 0.9455744828100211], 
             UndirectedEdge[104, 188] -> 
             RGBColor[
              0.34015129368141406`, 0.46904368691088416`, 0.9428951175427689],
              UndirectedEdge[37, 105] -> 
             RGBColor[
              0.22080146805015013`, 0.3494067209153274, 0.9358856890077321], 
             UndirectedEdge[3, 75] -> 
             RGBColor[
              0.4604176361342196, 0.5718866537552251, 0.9509246758011038], 
             UndirectedEdge[40, 132] -> 
             RGBColor[
              0.40319785832980803`, 0.5214692788871429, 0.94733404339442], 
             UndirectedEdge[154, 157] -> 
             RGBColor[
              0.2691478842423667, 0.3980838198589522, 0.9387172303649602], 
             UndirectedEdge[116, 148] -> 
             RGBColor[
              0.21710235245946194`, 0.3455187158920394, 0.9356750298471934], 
             UndirectedEdge[132, 185] -> 
             RGBColor[
              0.26630785953473646`, 0.397236823637493, 0.9384772106821059], 
             UndirectedEdge[92, 123] -> 
             RGBColor[
              0.34778570453147756`, 0.4697113495975751, 0.9435992466398737], 
             UndirectedEdge[53, 139] -> 
             RGBColor[
              0.4587256509461706, 0.5647673777664313, 0.9518675910388628], 
             UndirectedEdge[40, 196] -> 
             RGBColor[
              0.3694081793861806, 0.4859541839280068, 0.9454097711659308], 
             UndirectedEdge[27, 73] -> 
             RGBColor[
              0.2419998599538071, 0.37168757486174653`, 0.9370929060664348], 
             UndirectedEdge[57, 103] -> 
             RGBColor[
              0.1814602470714449, 0.3080566032892297, 0.9336452646731157], 
             UndirectedEdge[44, 77] -> 
             RGBColor[
              0.8580464518144618, 0.3836823814909788, 0.2007324013601752], 
             UndirectedEdge[88, 91] -> 
             RGBColor[
              0.20139859473617852`, 0.32901307084912135`, 0.93478072407648], 
             UndirectedEdge[69, 146] -> 
             RGBColor[
              0.24760893000865222`, 0.37758306312497075`, 0.9374123343081827],
              UndirectedEdge[65, 199] -> 
             RGBColor[
              0.9757996397934585, 0.9283450401492326, 0.5065449231630825], 
             UndirectedEdge[27, 75] -> 
             RGBColor[
              0.3843313935505691, 0.5020805374205839, 0.9462194736309155], 
             UndirectedEdge[4, 65] -> 
             RGBColor[
              0.6453230600166431, 0.6641820072591899, 0.6137033880650677], 
             UndirectedEdge[58, 102] -> 
             RGBColor[
              0.9648761622564584, 0.9733252798376484, 0.9443396749224908], 
             UndirectedEdge[107, 168] -> 
             RGBColor[
              0.21351519211843195`, 0.34174838293451504`, 0.9354707463724999],
              UndirectedEdge[9, 85] -> 
             RGBColor[
              0.23189273144463124`, 0.36106434196964265`, 0.9365173200499939],
              UndirectedEdge[22, 144] -> 
             RGBColor[
              0.19348904144218293`, 0.3206996288424882, 0.9343302867175226], 
             UndirectedEdge[110, 138] -> 
             RGBColor[
              0.20099999291646117`, 0.32859411506378333`, 0.9347580242925257],
              UndirectedEdge[34, 132] -> 
             RGBColor[
              0.3653113300133066, 0.4900797022247081, 0.9445259862530728], 
             UndirectedEdge[48, 158] -> 
             RGBColor[
              0.2634190473924112, 0.39349797793107355`, 0.9383384198388076], 
             UndirectedEdge[19, 95] -> 
             RGBColor[
              0.3002072480543151, 0.4289405280402324, 0.9405515065144217], 
             UndirectedEdge[122, 137] -> 
             RGBColor[
              0.3009080664928653, 0.4322034485232962, 0.9404989162882755], 
             UndirectedEdge[8, 198] -> 
             RGBColor[
              0.31444384785817775`, 0.4444212242772747, 0.9413433252524308], 
             UndirectedEdge[92, 174] -> 
             RGBColor[
              0.2172400978636229, 0.3456634950453756, 0.9356828742441843], 
             UndirectedEdge[39, 133] -> 
             RGBColor[
              0.2505927164379196, 0.38071921184511703`, 0.9375822565312131], 
             UndirectedEdge[120, 198] -> 
             RGBColor[
              0.26978078120628096`, 0.39747750942414833`, 0.9387998296796913],
              UndirectedEdge[4, 34] -> 
             RGBColor[
              0.38218235773708276`, 0.5054488820532, 0.9455732997777855], 
             UndirectedEdge[31, 34] -> 
             RGBColor[
              0.48100947040442327`, 0.5889125969543878, 0.9524604831380885], 
             UndirectedEdge[41, 152] -> 
             RGBColor[
              0.2454459622028375, 0.3753096468209797, 0.9372891564914656], 
             UndirectedEdge[95, 121] -> 
             RGBColor[
              0.23327542567236176`, 0.36251764127086494`, 0.9365960624407503],
              UndirectedEdge[3, 129] -> 
             RGBColor[
              0.4365819525225805, 0.5525357720139865, 0.9490482434742096], 
             UndirectedEdge[49, 199] -> 
             RGBColor[
              0.7088075949120052, 0.7662760755555905, 0.8381694307308162], 
             UndirectedEdge[171, 182] -> 
             RGBColor[
              0.3242915422574164, 0.45521469783192636`, 0.9418879193227581], 
             UndirectedEdge[56, 150] -> 
             RGBColor[
              0.18756580923325702`, 0.31447393623629405`, 0.933992967405861], 
             UndirectedEdge[179, 183] -> 
             RGBColor[
              0.6524621901365182, 0.6395620041190959, 0.6061877007325749], 
             UndirectedEdge[31, 156] -> 
             RGBColor[
              0.6753397250677327, 0.3878936918486643, 0.560927249104864], 
             UndirectedEdge[132, 153] -> 
             RGBColor[
              0.29141110867079584`, 0.42362193011741534`, 0.9399068035834754],
              UndirectedEdge[78, 136] -> 
             RGBColor[
              0.2028717449192551, 0.3305614450946512, 0.9348646178000759], 
             UndirectedEdge[27, 167] -> 
             RGBColor[
              0.2329271456668488, 0.36215157690284305`, 0.9365762284096705], 
             UndirectedEdge[35, 174] -> 
             RGBColor[
              0.18540537254043327`, 0.31220318029253835`, 0.9338699337322844],
              UndirectedEdge[61, 190] -> 
             RGBColor[
              0.1957633885191688, 0.3230901118223337, 0.9344598074189618], 
             UndirectedEdge[18, 103] -> 
             RGBColor[
              0.20207429376045272`, 0.32972327336542606`, 0.9348192041363055],
              UndirectedEdge[146, 155] -> 
             RGBColor[
              0.4592969410332923, 0.5599429054907851, 0.9526738544811711], 
             UndirectedEdge[77, 166] -> 
             RGBColor[
              0.8105241760173298, 0.490362872734788, 0.5726449442995682], 
             UndirectedEdge[85, 159] -> 
             RGBColor[
              0.26268203427801573`, 0.3934258514020805, 0.9382707252976634], 
             UndirectedEdge[39, 88] -> 
             RGBColor[
              0.2343125277851679, 0.36360770134749604`, 0.9366551238718196], 
             UndirectedEdge[66, 80] -> 
             RGBColor[
              0.20266968703316796`, 0.3303490694451636, 0.9348531109023811], 
             UndirectedEdge[62, 141] -> 
             RGBColor[
              0.2718586483084913, 0.3998286032950302, 0.9389120419161632], 
             UndirectedEdge[91, 103] -> 
             RGBColor[
              0.18365762005674702`, 0.31036618161827634`, 0.9337704018139066],
              UndirectedEdge[149, 189] -> 
             RGBColor[
              0.18996767873421347`, 0.31699845336912136`, 0.934129750320693], 
             UndirectedEdge[4, 69] -> 
             RGBColor[
              0.2920607984493962, 0.42194145527329896`, 0.9400303359095292], 
             UndirectedEdge[23, 169] -> 
             RGBColor[
              0.20786534559532402`, 0.33581003601776915`, 0.9351489959712078],
              UndirectedEdge[32, 152] -> 
             RGBColor[
              0.19309625212307593`, 0.3202867823638255, 0.9343079179468792], 
             UndirectedEdge[100, 124] -> 
             RGBColor[
              0.21591407787580016`, 0.3442697639636507, 0.9356073593675487], 
             UndirectedEdge[129, 139] -> 
             RGBColor[
              0.3700695186748425, 0.49279233567532266`, 0.9448882555483507], 
             UndirectedEdge[29, 73] -> 
             RGBColor[
              0.21219498840003925`, 0.3403607651207339, 0.9353955627238038], 
             UndirectedEdge[32, 178] -> 
             RGBColor[
              0.1848271249653814, 0.311595405428145, 0.9338370033883259], 
             UndirectedEdge[8, 61] -> 
             RGBColor[
              0.24530237000143487`, 0.37515872231303415`, 0.9372809791280214],
              UndirectedEdge[10, 27] -> 
             RGBColor[
              0.24223545662361712`, 0.37193520189940843`, 0.9371063229482464],
              UndirectedEdge[72, 160] -> 
             RGBColor[
              0.3481960203596565, 0.4708761388050667, 0.9435957557128356], 
             UndirectedEdge[72, 144] -> 
             RGBColor[
              0.22584498306262032`, 0.3547077749707548, 0.9361729097264804], 
             UndirectedEdge[134, 135] -> 
             RGBColor[
              0.22190471606791506`, 0.3505663045319628, 0.9359485173502345], 
             UndirectedEdge[95, 150] -> 
             RGBColor[
              0.2208799451115121, 0.3494892052825519, 0.9358901581602801], 
             UndirectedEdge[68, 71] -> 
             RGBColor[
              0.6623649639352431, 0.6847752584173, 0.6236785616506062], 
             UndirectedEdge[118, 123] -> 
             RGBColor[
              0.42099591367325284`, 0.5390672333790665, 0.9480464652405584], 
             UndirectedEdge[89, 168] -> 
             RGBColor[
              0.23845610278939203`, 0.36796286139476475`, 0.9368910943384403],
              UndirectedEdge[44, 99] -> 
             RGBColor[
              0.7252973005063621, 0.6401348451070372, 0.5975536479428364], 
             UndirectedEdge[121, 180] -> 
             RGBColor[
              0.27969294333585376`, 0.40822779625327543`, 0.9393521573829899],
              UndirectedEdge[10, 141] -> 
             RGBColor[
              0.28088316010011916`, 0.40931393737512656`, 0.9394259745121276],
              UndirectedEdge[6, 170] -> 
             RGBColor[
              0.7433204991907267, 0.48659316349091797`, 0.5720011378191884], 
             UndirectedEdge[12, 77] -> 
             RGBColor[
              0.883710558650916, 0.4870027765625733, 0.22146359810422783`], 
             UndirectedEdge[112, 143] -> 
             RGBColor[
              0.8985367952768839, 0.9217855718880776, 0.9850776323188054], 
             UndirectedEdge[67, 125] -> 
             RGBColor[
              0.2600866097683471, 0.39069789568300034`, 0.9381229197114243], 
             UndirectedEdge[3, 10] -> 
             RGBColor[
              0.3183216992072676, 0.4417413182340497, 0.9418115251184348], 
             UndirectedEdge[124, 125] -> 
             RGBColor[
              0.24516019716023396`, 0.37500928964265323`, 0.9372728825950409],
              UndirectedEdge[11, 174] -> 
             RGBColor[
              0.1964947207721936, 0.32385878838940574`, 0.9345014557088626], 
             UndirectedEdge[71, 87] -> 
             RGBColor[
              0.29022081155983176`, 0.4172864093031303, 0.9400251842918653], 
             UndirectedEdge[7, 192] -> 
             RGBColor[
              0.3371042587561843, 0.4567989612427451, 0.9431333444727331], 
             UndirectedEdge[56, 148] -> 
             RGBColor[
              0.18807327130146562`, 0.31500731104493473`, 0.9340218666199227],
              UndirectedEdge[30, 71] -> 
             RGBColor[
              0.28665240734323405`, 0.41353579022159115`, 0.939821968950711], 
             UndirectedEdge[35, 86] -> 
             RGBColor[
              0.19143714046786142`, 0.31854295082044043`, 0.9342134339925504],
              UndirectedEdge[68, 127] -> 
             RGBColor[
              0.9178893661581602, 0.8915362183675095, 0.645439120800334], 
             UndirectedEdge[10, 30] -> 
             RGBColor[
              0.2137583126687416, 0.34200391804762365`, 0.9354845917281754], 
             UndirectedEdge[89, 176] -> 
             RGBColor[
              0.25080130431121317`, 0.3809384509251836, 0.937594135302019], 
             UndirectedEdge[71, 76] -> 
             RGBColor[
              0.3139935330397997, 0.4422730468561747, 0.9413790056115596], 
             UndirectedEdge[49, 119] -> 
             RGBColor[
              0.634590175011373, 0.45058684488381917`, 0.5703034220716992], 
             UndirectedEdge[87, 106] -> 
             RGBColor[
              0.20086653877096394`, 0.3284538462953842, 0.9347504242763673], 
             UndirectedEdge[86, 196] -> 
             RGBColor[
              0.2175414257082079, 0.3459802097153233, 0.9357000344191588], 
             UndirectedEdge[53, 123] -> 
             RGBColor[
              0.5414537947364539, 0.6385560470320484, 0.9570608296632714], 
             UndirectedEdge[68, 102] -> 
             RGBColor[
              0.9650834798325474, 0.9283042529937652, 0.6200104049924591], 
             UndirectedEdge[107, 130] -> 
             RGBColor[
              0.20096416380479723`, 0.32855645639572767`, 0.9347559838776209],
              UndirectedEdge[42, 157] -> 
             RGBColor[
              0.2045975584295754, 0.3323753845168943, 0.9349629003263764], 
             UndirectedEdge[96, 99] -> 
             RGBColor[
              0.7441185775359549, 0.79956600300059, 0.9751875122211435], 
             UndirectedEdge[62, 194] -> 
             RGBColor[
              0.2007116762072222, 0.32829107592203804`, 0.9347416050824608], 
             UndirectedEdge[57, 117] -> 
             RGBColor[
              0.18358120319676802`, 0.31028586265332964`, 0.9337660499867794],
              UndirectedEdge[102, 128] -> 
             RGBColor[
              0.700241137930167, 0.7622648425385679, 0.9428826111957023], 
             UndirectedEdge[46, 47] -> 
             RGBColor[
              0.1896200136619846, 0.31663303533497, 0.934109951309154], 
             UndirectedEdge[28, 105] -> 
             RGBColor[
              0.19252363925225727`, 0.3196849299308422, 0.9342753084909909], 
             UndirectedEdge[40, 182] -> 
             RGBColor[
              0.4233315585574587, 0.5396644216518027, 0.9485892515260115], 
             UndirectedEdge[79, 179] -> 
             RGBColor[
              0.2813590504704592, 0.4075281905155883, 0.9395367751459407], 
             UndirectedEdge[36, 63] -> 
             RGBColor[
              0.1871120628164008, 0.3139970199829937, 0.9339671272186787], 
             UndirectedEdge[118, 129] -> 
             RGBColor[
              0.4226691844013287, 0.5404852315434163, 0.9481617341921013], 
             UndirectedEdge[74, 161] -> 
             RGBColor[
              0.31487926883859824`, 0.44485048896802515`, 0.9413691613435261],
              UndirectedEdge[66, 187] -> 
             RGBColor[
              0.19351363784595493`, 0.32072548122235467`, 0.9343316874463302],
              UndirectedEdge[10, 29] -> 
             RGBColor[
              0.2124305850698493, 0.3406083921583959, 0.9354089796056155], 
             UndirectedEdge[30, 147] -> 
             RGBColor[
              0.22954544173879612`, 0.3585971916620468, 0.9363836453737505], 
             UndirectedEdge[109, 116] -> 
             RGBColor[
              0.2290183753781148, 0.3580432114990334, 0.9363536297242345], 
             UndirectedEdge[81, 154] -> 
             RGBColor[
              0.31895036317144065`, 0.45042938287295087`, 0.9415534078638058],
              UndirectedEdge[89, 188] -> 
             RGBColor[
              0.29035857842231216`, 0.42210363440918097`, 0.939861949601819], 
             UndirectedEdge[24, 163] -> 
             RGBColor[
              0.2694549562733895, 0.40054462184727546`, 0.9386564331856598], 
             UndirectedEdge[91, 159] -> 
             RGBColor[
              0.22056324507356437`, 0.3491563334627266, 0.9358721225616348], 
             UndirectedEdge[121, 164] -> 
             RGBColor[
              0.2062630848758868, 0.3341259584124435, 0.9350577495935681], 
             UndirectedEdge[4, 54] -> 
             RGBColor[
              0.661350157437102, 0.7182451701998284, 0.6759656350801627], 
             UndirectedEdge[51, 130] -> 
             RGBColor[
              0.18324595064089247`, 0.3099334909608647, 0.933746957849684], 
             UndirectedEdge[69, 186] -> 
             RGBColor[
              0.21644101520784265`, 0.3448236085093839, 0.9356373676690746], 
             UndirectedEdge[137, 179] -> 
             RGBColor[
              0.3462163270218858, 0.4742969139529616, 0.9432815761041253], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.37725864887478877`, 0.501184212909484, 0.945259565402945], 
             UndirectedEdge[22, 176] -> 
             RGBColor[
              0.2112886129989553, 0.33940810710667507`, 0.9353439459855744], 
             UndirectedEdge[128, 198] -> 
             RGBColor[
              0.38846505457694686`, 0.5108906382783656, 0.9459736276648509], 
             UndirectedEdge[107, 131] -> 
             RGBColor[
              0.19956404883419218`, 0.32708484678920535`, 0.9346762494013294],
              UndirectedEdge[26, 125] -> 
             RGBColor[
              0.2785326649894304, 0.41008586926780977`, 0.9391733952677717], 
             UndirectedEdge[47, 105] -> 
             RGBColor[
              0.2010087745780687, 0.32860334514692235`, 0.934758524395163], 
             UndirectedEdge[23, 60] -> 
             RGBColor[
              0.2023092030396156, 0.32997017791193484`, 0.9348325818722366], 
             UndirectedEdge[43, 111] -> 
             RGBColor[
              0.2049417486516364, 0.33273715026320094`, 0.934982501450339], 
             UndirectedEdge[73, 142] -> 
             RGBColor[
              0.23973855838173452`, 0.36931080353469764`, 0.9369641282872011],
              UndirectedEdge[43, 115] -> 
             RGBColor[
              0.25238630356085545`, 0.3820238241610014, 0.9377056558638687], 
             UndirectedEdge[61, 122] -> 
             RGBColor[
              0.24263213866310665`, 0.37235213987400595`, 0.9371289134035569],
              UndirectedEdge[64, 65] -> 
             RGBColor[
              0.792934775654365, 0.787251260573052, 0.6244310740750881], 
             UndirectedEdge[147, 157] -> 
             RGBColor[
              0.2279748046775151, 0.3569463525264991, 0.9362941999166599], 
             UndirectedEdge[53, 69] -> 
             RGBColor[
              0.4407986220698122, 0.5459249337780987, 0.9508466732650168], 
             UndirectedEdge[27, 188] -> 
             RGBColor[
              0.28986141659567377`, 0.4215810858075036, 0.939833636971277], 
             UndirectedEdge[88, 159] -> 
             RGBColor[
              0.23572746530865607`, 0.3650948903969026, 0.9367357024705698], 
             UndirectedEdge[16, 61] -> 
             RGBColor[
              0.19725809150646825`, 0.3246611394316285, 0.9345449285428737], 
             UndirectedEdge[138, 185] -> 
             RGBColor[
              0.22696192070522694`, 0.35588174725107113`, 0.9362365176728656],
              UndirectedEdge[26, 128] -> 
             RGBColor[
              0.36204442385736635`, 0.48653045531343586`, 0.9443441705850733],
              UndirectedEdge[68, 75] -> 
             RGBColor[
              0.7315668061877028, 0.7433887217645079, 0.6284543351107399], 
             UndirectedEdge[10, 107] -> 
             RGBColor[
              0.21779170777929543`, 0.3462432720408361, 0.9357142876128481], 
             UndirectedEdge[69, 123] -> 
             RGBColor[
              0.3504692190704081, 0.47253189352264, 0.9437520688229617], 
             UndirectedEdge[109, 113] -> 
             RGBColor[
              0.2109311914464215, 0.33903243439312675`, 0.9353235913569153], 
             UndirectedEdge[49, 196] -> 
             RGBColor[
              0.3276703084677861, 0.4512287678779199, 0.9423563098795996], 
             UndirectedEdge[8, 26] -> 
             RGBColor[
              0.28802321713859724`, 0.420061041312345, 0.9397138681726531], 
             UndirectedEdge[30, 73] -> 
             RGBColor[
              0.21352271599893158`, 0.34175629100996163`, 0.9354711748463638],
              UndirectedEdge[46, 144] -> 
             RGBColor[
              0.19073384687984102`, 0.31780374466804207`, 0.9341733824631423],
              UndirectedEdge[81, 176] -> 
             RGBColor[
              0.2700588403974922, 0.4011793423501723, 0.938690823493161], 
             UndirectedEdge[104, 181] -> 
             RGBColor[
              0.4026365855967863, 0.5231653061658909, 0.9468766250900423], 
             UndirectedEdge[65, 171] -> 
             RGBColor[
              0.6320443792751589, 0.6525886118770408, 0.6128606533865955], 
             UndirectedEdge[67, 82] -> 
             RGBColor[
              0.2339276106645956, 0.3632031290486195, 0.9366332034112368], 
             UndirectedEdge[13, 63] -> 
             RGBColor[
              0.20638929458382937`, 0.3342586128176488, 0.935064937049725], 
             UndirectedEdge[153, 182] -> 
             RGBColor[
              0.3115448088984465, 0.4418170728820753, 0.941162011715067], 
             UndirectedEdge[87, 157] -> 
             RGBColor[
              0.21156396593022397`, 0.3396975204958227, 0.9353596269276621], 
             UndirectedEdge[30, 157] -> 
             RGBColor[
              0.20799556171362626`, 0.3359469014142835, 0.9351564115865076], 
             UndirectedEdge[64, 185] -> 
             RGBColor[
              0.4307906028962345, 0.5356752567798472, 0.9502522102168389], 
             UndirectedEdge[9, 103] -> 
             RGBColor[
              0.18719718779584008`, 0.3140864917336198, 0.9339719749603267], 
             UndirectedEdge[18, 117] -> 
             RGBColor[
              0.2041952498857758, 0.331952532729526, 0.9349399894499691], 
             UndirectedEdge[52, 66] -> 
             RGBColor[
              0.18456752137294713`, 0.3113225455926782, 0.9338222193477858], 
             UndirectedEdge[128, 162] -> 
             RGBColor[
              0.4413593088202362, 0.5567049827613839, 0.9493440027726809], 
             UndirectedEdge[23, 177] -> 
             RGBColor[
              0.22051380406985302`, 0.3491043678330853, 0.9358693069696149], 
             UndirectedEdge[11, 110] -> 
             RGBColor[
              0.1915413157937571, 0.3186524456930539, 0.9342193666232466], 
             UndirectedEdge[79, 177] -> 
             RGBColor[
              0.20578387384021699`, 0.33362227723022, 0.9350304592340161], 
             UndirectedEdge[8, 166] -> 
             RGBColor[
              0.543496783375643, 0.6308288867491243, 0.9602573693120857], 
             UndirectedEdge[162, 173] -> 
             RGBColor[
              0.40958261070654, 0.5291816039985865, 0.947319219667907], 
             UndirectedEdge[100, 137] -> 
             RGBColor[
              0.26484162639759284`, 0.3942953332387867, 0.9384449858803665], 
             UndirectedEdge[88, 117] -> 
             RGBColor[
              0.2009427964171618, 0.32853399791655225`, 0.9347547670365053], 
             UndirectedEdge[149, 168] -> 
             RGBColor[
              0.19745061882106624`, 0.32486349784620777`, 0.9345558926886215],
              UndirectedEdge[36, 110] -> 
             RGBColor[
              0.18133894646584242`, 0.3079291086618389, 0.9336383567830746], 
             UndirectedEdge[76, 104] -> 
             RGBColor[
              0.3156743455120887, 0.4437288821395802, 0.9414861054960099], 
             UndirectedEdge[4, 196] -> 
             RGBColor[
              0.28364684382762245`, 0.41309785549027966`, 0.9395511736411497],
              UndirectedEdge[61, 79] -> 
             RGBColor[
              0.20075917656457537`, 0.3283410018093128, 0.9347443101575417], 
             UndirectedEdge[76, 147] -> 
             RGBColor[
              0.2568865674353618, 0.38733444829663033`, 0.9379406820345992], 
             UndirectedEdge[2, 120] -> 
             RGBColor[
              0.18815579892545653`, 0.3150940528103027, 0.9340265664460203], 
             UndirectedEdge[87, 176] -> 
             RGBColor[
              0.22539540274629694`, 0.3542352375532605, 0.9361473067925603], 
             UndirectedEdge[142, 157] -> 
             RGBColor[
              0.2342114040964292, 0.3635014139390195, 0.9366493650273451], 
             UndirectedEdge[65, 191] -> 
             RGBColor[
              0.8832210777752071, 0.8579801148696197, 0.6332956147035969], 
             UndirectedEdge[73, 147] -> 
             RGBColor[
              0.23350195896282042`, 0.3627557421221772, 0.936608963176516], 
             UndirectedEdge[26, 120] -> 
             RGBColor[
              0.2433601504867005, 0.3731173264592187, 0.9371703725999135], 
             UndirectedEdge[113, 116] -> 
             RGBColor[
              0.22254054731904888`, 0.35123460349093416`, 0.9359847269993585],
              UndirectedEdge[35, 94] -> 
             RGBColor[
              0.1855941681935362, 0.31240161649428533`, 0.9338806853654305], 
             UndirectedEdge[31, 45] -> 
             RGBColor[0.62150237913985, 0.702550504593909, 0.964065451798632],
              UndirectedEdge[52, 82] -> 
             RGBColor[
              0.1987769890735687, 0.32625759707831903`, 0.9346314275123124], 
             UndirectedEdge[95, 162] -> 
             RGBColor[
              0.35030491508878375`, 0.4723326092435304, 0.9437436855582304], 
             UndirectedEdge[17, 73] -> 
             RGBColor[
              0.20447423008410437`, 0.33224575860633554`, 0.9349558769595496],
              UndirectedEdge[103, 152] -> 
             RGBColor[
              0.19063325078220003`, 0.31769801179126034`, 0.9341676536642003],
              UndirectedEdge[88, 103] -> 
             RGBColor[
              0.1988218402918387, 0.32630473855245234`, 0.9346339817228415], 
             UndirectedEdge[26, 170] -> 
             RGBColor[
              0.4739950942722979, 0.5778178834110607, 0.9531267757340784], 
             UndirectedEdge[89, 106] -> 
             RGBColor[
              0.22627244033588012`, 0.3551570596673073, 0.9361972527858261], 
             UndirectedEdge[19, 74] -> 
             RGBColor[
              0.34857360130161363`, 0.4763386664540116, 0.9434317795367738], 
             UndirectedEdge[117, 152] -> 
             RGBColor[
              0.19275420690752315`, 0.3199272711553603, 0.934288438977864], 
             UndirectedEdge[157, 176] -> 
             RGBColor[
              0.2202563614684182, 0.34883377933617365`, 0.9358546459943153], 
             UndirectedEdge[49, 139] -> 
             RGBColor[
              0.3540112919659183, 0.4789148116492719, 0.9438563899218253], 
             UndirectedEdge[48, 106] -> 
             RGBColor[
              0.1977618988532519, 0.32519067289632886`, 0.9345736196259569], 
             UndirectedEdge[69, 118] -> 
             RGBColor[
              0.32034074100661103`, 0.44643612012511674`, 0.9418323088423037],
              UndirectedEdge[117, 200] -> 
             RGBColor[
              0.1879682303409825, 0.3148969063354854, 0.9340158846926173], 
             UndirectedEdge[64, 153] -> 
             RGBColor[
              0.4558938520322939, 0.5620603632597695, 0.9516818031182084], 
             UndirectedEdge[73, 87] -> 
             RGBColor[
              0.2170911202155293, 0.3455069100915008, 0.9356743901875181], 
             UndirectedEdge[132, 138] -> 
             RGBColor[
              0.2612195562179643, 0.3918886942345018, 0.9381874393356859], 
             UndirectedEdge[6, 96] -> 
             RGBColor[
              0.8839247435427675, 0.5973568467623975, 0.5851240708837279], 
             UndirectedEdge[34, 65] -> 
             RGBColor[
              0.6931978672586998, 0.7056487590344823, 0.6167539284485017], 
             UndirectedEdge[2, 16] -> 
             RGBColor[
              0.1847745870823867, 0.3115401847820234, 0.9338340114336121], 
             UndirectedEdge[21, 122] -> 
             RGBColor[
              0.3196137188420707, 0.44840534441475405`, 0.941690823915208], 
             UndirectedEdge[90, 175] -> 
             RGBColor[
              0.36392094666961883`, 0.4808157727668374, 0.9450400242191717], 
             UndirectedEdge[6, 179] -> 
             RGBColor[
              0.5999866512477183, 0.3681232043828395, 0.5612188243491484], 
             UndirectedEdge[8, 137] -> 
             RGBColor[
              0.3035782978311935, 0.4350100309623244, 0.94065098201274], 
             UndirectedEdge[3, 127] -> 
             RGBColor[
              0.6467401961046771, 0.7200341503582268, 0.9679094614906981], 
             UndirectedEdge[31, 65] -> 
             RGBColor[
              0.7441501726839835, 0.7476457221603776, 0.6205905714253708], 
             UndirectedEdge[3, 71] -> 
             RGBColor[
              0.3912157938817601, 0.5132731904080172, 0.9461489023409704], 
             UndirectedEdge[146, 184] -> 
             RGBColor[
              0.21360634880243462`, 0.34184419438906943`, 0.9354759376107997],
              UndirectedEdge[33, 99] -> 
             RGBColor[
              0.772222119980282, 0.8191247933841846, 0.8648855062678112], 
             UndirectedEdge[10, 130] -> 
             RGBColor[
              0.2011228825880777, 0.32872327990030753`, 0.9347650226775253], 
             UndirectedEdge[112, 160] -> 
             RGBColor[
              0.6923008271636373, 0.757058105759987, 0.9667604504602199], 
             UndirectedEdge[73, 157] -> 
             RGBColor[
              0.21195207893765056`, 0.34010545187441393`, 0.9353817293892732],
              UndirectedEdge[157, 188] -> 
             RGBColor[
              0.25981363557951725`, 0.389998962820171, 0.9381224602941154], 
             UndirectedEdge[70, 132] -> 
             RGBColor[
              0.2458080236877891, 0.37569019639768786`, 0.9373097753574117], 
             UndirectedEdge[141, 191] -> 
             RGBColor[
              0.5769597398249082, 0.6618980623518022, 0.9624179176414562], 
             UndirectedEdge[26, 80] -> 
             RGBColor[
              0.25728770840867865`, 0.387756072893393, 0.9379635264195947], 
             UndirectedEdge[171, 199] -> 
             RGBColor[
              0.6515054495303574, 0.7165517677858011, 0.834521559813894], 
             UndirectedEdge[23, 43] -> 
             RGBColor[
              0.2066925124128154, 0.33457731398103385`, 0.9350822048565153], 
             UndirectedEdge[75, 81] -> 
             RGBColor[
              0.40408609146348656`, 0.52284397744725, 0.9473444744525996], 
             UndirectedEdge[33, 172] -> 
             RGBColor[
              0.9309821433575884, 0.7454031597804265, 0.49229878616950506`], 
             UndirectedEdge[156, 166] -> 
             RGBColor[
              0.8112235131702088, 0.49573828454331076`, 0.5733146303469535], 
             UndirectedEdge[151, 175] -> 
             RGBColor[
              0.7472372281358932, 0.7985860801048122, 0.8522647687143463], 
             UndirectedEdge[34, 199] -> 
             RGBColor[
              0.7126589375138983, 0.7696119149432428, 0.8384148348758003], 
             UndirectedEdge[38, 169] -> 
             RGBColor[
              0.18660872237456455`, 0.31346797726499653`, 0.9339384627251416],
              UndirectedEdge[10, 142] -> 
             RGBColor[
              0.23997415505154454`, 0.3695584305723596, 0.9369775451690128], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.2876001150236012, 0.4192043144804547, 0.9397048591920434], 
             UndirectedEdge[12, 128] -> 
             RGBColor[
              0.6907043727279983, 0.6939382045780004, 0.6137063255291655], 
             UndirectedEdge[19, 172] -> 
             RGBColor[
              0.610278699777892, 0.48910830355495916`, 0.5781436227882895], 
             UndirectedEdge[109, 124] -> 
             RGBColor[
              0.22172315170383133`, 0.35037546887346516`, 0.9359381775283004],
              UndirectedEdge[75, 127] -> 
             RGBColor[
              0.6884648603869374, 0.7548482631907685, 0.9709344134676849], 
             UndirectedEdge[4, 191] -> 
             RGBColor[
              0.57220556825359, 0.6577802378883374, 0.9621149860328806], 
             UndirectedEdge[68, 172] -> 
             RGBColor[
              0.9151660280486694, 0.6898326684829248, 0.25782304770604947`], 
             UndirectedEdge[97, 105] -> 
             RGBColor[
              0.21127795983773054`, 0.3393969099587784, 0.9353433393038026], 
             UndirectedEdge[120, 136] -> 
             RGBColor[
              0.208375147270767, 0.3363458699019528, 0.9351780284224404], 
             UndirectedEdge[117, 159] -> 
             RGBColor[
              0.22010744675454766`, 0.3486772605301575, 0.9358461655216599], 
             UndirectedEdge[183, 192] -> 
             RGBColor[
              0.7010491462692232, 0.6813089979740284, 0.609376618188938], 
             UndirectedEdge[71, 188] -> 
             RGBColor[
              0.33847048120912504`, 0.4675878516274786, 0.9427880176583188], 
             UndirectedEdge[14, 106] -> 
             RGBColor[
              0.1821436488572793, 0.3087749018963175, 0.9336841833938165], 
             UndirectedEdge[141, 194] -> 
             RGBColor[
              0.2726689215363932, 0.40068025183184497`, 0.9389581857778003], 
             UndirectedEdge[50, 105] -> 
             RGBColor[
              0.2047516184167667, 0.33253731133139974`, 0.9349716738147356], 
             UndirectedEdge[98, 125] -> 
             RGBColor[
              0.22839213728314284`, 0.35738499555542924`, 0.936317966391162], 
             UndirectedEdge[118, 119] -> 
             RGBColor[
              0.6188466529284243, 0.4369505973479967, 0.5693002587660235], 
             UndirectedEdge[137, 166] -> 
             RGBColor[
              0.5638108664902101, 0.6507798896827761, 0.9614655012997908], 
             UndirectedEdge[6, 112] -> 
             RGBColor[
              0.8864219769798407, 0.5992192793709223, 0.5808969060575552], 
             UndirectedEdge[65, 119] -> 
             RGBColor[
              0.9015822198928265, 0.6126558094774612, 0.23867891450396542`], 
             UndirectedEdge[170, 183] -> 
             RGBColor[
              0.7957960380795266, 0.7580319632271744, 0.6169700142026149], 
             UndirectedEdge[14, 131] -> 
             RGBColor[
              0.18037616802655143`, 0.3069171674784653, 0.9335835279752602], 
             UndirectedEdge[9, 164] -> 
             RGBColor[
              0.1942433345387914, 0.32149243871196825`, 0.9343732425934977], 
             UndirectedEdge[96, 170] -> 
             RGBColor[
              0.7958122133360686, 0.8413363954975833, 0.9793915982124253], 
             UndirectedEdge[117, 178] -> 
             RGBColor[
              0.18448507974982858`, 0.3112358942196798, 0.9338175244193107], 
             UndirectedEdge[18, 24] -> 
             RGBColor[
              0.24010747998138166`, 0.3696985635269072, 0.9369851378265305], 
             UndirectedEdge[18, 133] -> 
             RGBColor[
              0.2360954570926359, 0.3654816730938921, 0.9367566590582723], 
             UndirectedEdge[49, 129] -> 
             RGBColor[
              0.4384127064842775, 0.5541214790792388, 0.9491648974977769], 
             UndirectedEdge[124, 198] -> 
             RGBColor[
              0.28583038245095216`, 0.4143466579357906, 0.9397138307273181], 
             UndirectedEdge[113, 124] -> 
             RGBColor[
              0.2152453236447654, 0.343566860865366, 0.9355692748034243], 
             UndirectedEdge[176, 188] -> 
             RGBColor[
              0.2736450723955902, 0.4045366798776089, 0.9389101401590136], 
             UndirectedEdge[37, 97] -> 
             RGBColor[
              0.22632286746697683`, 0.35521006177935477`, 0.9362001245363418],
              UndirectedEdge[77, 143] -> 
             RGBColor[
              0.8364908329957561, 0.5109365998950215, 0.5751565315064958], 
             UndirectedEdge[79, 84] -> 
             RGBColor[
              0.1877064038111327, 0.31462171005185247`, 0.93400097405908], 
             UndirectedEdge[151, 199] -> 
             RGBColor[
              0.9945819459025071, 0.992027509640117, 0.7394547080773856], 
             UndirectedEdge[48, 87] -> 
             RGBColor[
              0.21359836729039067`, 0.3418358053138541, 0.9354754830754963], 
             UndirectedEdge[27, 30] -> 
             RGBColor[
              0.2380433427297828, 0.3675290244016161, 0.9368675882636692], 
             UndirectedEdge[5, 87] -> 
             RGBColor[
              0.28551854391053016`, 0.41321354140814925`, 0.9397255599553038],
              UndirectedEdge[68, 81] -> 
             RGBColor[
              0.6335105972347094, 0.659531932623991, 0.6218491817852485], 
             UndirectedEdge[155, 172] -> 
             RGBColor[
              0.77126540629573, 0.6221045625124598, 0.590374002869697], 
             UndirectedEdge[143, 188] -> 
             RGBColor[
              0.5844325062491007, 0.6667240315758246, 0.9636365087359027], 
             UndirectedEdge[102, 180] -> 
             RGBColor[
              0.6556042618622065, 0.7236026240031248, 0.9400383889234916], 
             UndirectedEdge[80, 136] -> 
             RGBColor[
              0.2223027051927452, 0.3509846163361272, 0.9359711822421215], 
             UndirectedEdge[66, 78] -> 
             RGBColor[
              0.18323872675967784`, 0.30992589820368766`, 0.9337465464603355],
              UndirectedEdge[50, 101] -> 
             RGBColor[
              0.19997052243961871`, 0.3275120763204238, 0.9346993974718347], 
             UndirectedEdge[41, 85] -> 
             RGBColor[
              0.2805891206818358, 0.4122473345873495, 0.9392905073772007], 
             UndirectedEdge[5, 30] -> 
             RGBColor[
              0.28195013969393246`, 0.40946292232661013`, 0.9395223446141496],
              UndirectedEdge[32, 133] -> 
             RGBColor[
              0.21756503028546625`, 0.3460050196226384, 0.9357013786649139], 
             UndirectedEdge[159, 161] -> 
             RGBColor[
              0.2693600530686908, 0.4004448725619264, 0.938651028588549], 
             UndirectedEdge[3, 195] -> 
             RGBColor[
              0.4598624133064091, 0.5714358988511051, 0.9508809666262504], 
             UndirectedEdge[173, 180] -> 
             RGBColor[
              0.35489305397250803`, 0.4818122587326137, 0.9438344494728906], 
             UndirectedEdge[129, 141] -> 
             RGBColor[
              0.399143413415432, 0.5201083911550634, 0.9466626928679024], 
             UndirectedEdge[53, 199] -> 
             RGBColor[
              0.8135219538922576, 0.8521286416727499, 0.8461806318478537], 
             UndirectedEdge[88, 95] -> 
             RGBColor[
              0.23288032783126497`, 0.3621023683892223, 0.9365735622031948], 
             UndirectedEdge[93, 95] -> 
             RGBColor[
              0.24029230513765162`, 0.36989282648473865`, 0.9369956633457557],
              UndirectedEdge[3, 29] -> 
             RGBColor[
              0.312801857714541, 0.4359396148470296, 0.9414971783112978], 
             UndirectedEdge[52, 125] -> 
             RGBColor[
              0.2249359881773202, 0.35375236371269986`, 0.9361211438124999], 
             UndirectedEdge[82, 136] -> 
             RGBColor[
              0.21738866266974544`, 0.34581964607616317`, 0.935691334790111], 
             UndirectedEdge[116, 193] -> 
             RGBColor[
              0.2350445249483884, 0.36437707677734155`, 0.9366968100273723], 
             UndirectedEdge[19, 159] -> 
             RGBColor[
              0.30305438553170616`, 0.43193305004791277`, 0.9407136467817967],
              UndirectedEdge[77, 99] -> 
             RGBColor[
              0.6845698486919003, 0.3905794636160585, 0.5610392465826612], 
             UndirectedEdge[53, 196] -> 
             RGBColor[
              0.43238466744803844`, 0.5370813339950793, 0.9503675109966372], 
             UndirectedEdge[58, 137] -> 
             RGBColor[
              0.6422345288762541, 0.7125398822624958, 0.9467383481519487], 
             UndirectedEdge[159, 200] -> 
             RGBColor[
              0.22275289923247676`, 0.35145779881583583`, 0.9359968201266817],
              UndirectedEdge[3, 62] -> 
             RGBColor[
              0.30929718741563983`, 0.43225598415395333`, 0.9412975925224704],
              UndirectedEdge[48, 157] -> 
             RGBColor[
              0.20845932601251194`, 0.33643434709676723`, 0.9351828222772515],
              UndirectedEdge[130, 168] -> 
             RGBColor[
              0.19684636692721422`, 0.32422839079398647`, 0.9345214814371772],
              UndirectedEdge[140, 180] -> 
             RGBColor[
              0.6678780579649132, 0.7298281943728316, 0.7506032971167013], 
             UndirectedEdge[146, 171] -> 
             RGBColor[
              0.27657700131279794`, 0.4080303427474302, 0.9390620231145327], 
             UndirectedEdge[26, 100] -> 
             RGBColor[
              0.24928654570499661`, 0.3793463435888073, 0.9375078720402794], 
             UndirectedEdge[45, 153] -> 
             RGBColor[
              0.49664985237205533`, 0.594095769360721, 0.9556096261521655], 
             UndirectedEdge[165, 177] -> 
             RGBColor[
              0.2115965510366421, 0.3397317695086831, 0.9353614826012671], 
             UndirectedEdge[123, 139] -> 
             RGBColor[
              0.36839624794676656`, 0.4913743375109727, 0.9447729865968078], 
             UndirectedEdge[13, 34] -> 
             RGBColor[
              0.32558157650060693`, 0.44832121227099686`, 0.9422634355654279],
              UndirectedEdge[48, 72] -> 
             RGBColor[
              0.23184751916348642`, 0.3610168209955353, 0.9365147452774683], 
             UndirectedEdge[127, 191] -> 
             RGBColor[
              0.8424455031847746, 0.8772870526462687, 0.9848132059143445], 
             UndirectedEdge[58, 125] -> 
             RGBColor[
              0.6124298936125201, 0.6826137072843086, 0.9449897432593624], 
             UndirectedEdge[165, 169] -> 
             RGBColor[
              0.1989480925621131, 0.32643743769336697`, 0.9346411716028602], 
             UndirectedEdge[119, 156] -> 
             RGBColor[
              0.8327717722765755, 0.2529037791657479, 0.17901559218345872`], 
             UndirectedEdge[139, 191] -> 
             RGBColor[
              0.5478858450843187, 0.6345820068720615, 0.9606434803219044], 
             UndirectedEdge[48, 81] -> 
             RGBColor[
              0.2582618049415859, 0.3887799101107659, 0.938018999776097], 
             UndirectedEdge[85, 161] -> 
             RGBColor[
              0.2771499717006646, 0.408632570953499, 0.939094652930488], 
             UndirectedEdge[30, 106] -> 
             RGBColor[
              0.19729813455436623`, 0.32470322721384515`, 0.9345472089352131],
              UndirectedEdge[118, 195] -> 
             RGBColor[
              0.44594964518515734`, 0.559385358380535, 0.9499944573441421], 
             UndirectedEdge[132, 145] -> 
             RGBColor[
              0.24537934999545682`, 0.37523963316756476`, 0.9372853630247993],
              UndirectedEdge[124, 137] -> 
             RGBColor[
              0.27496483242396785`, 0.4049354646208403, 0.9390214874876273], 
             UndirectedEdge[53, 182] -> 
             RGBColor[
              0.48630804661931654`, 0.5907915717188752, 0.9535469913567178], 
             UndirectedEdge[31, 40] -> 
             RGBColor[
              0.5188959987209247, 0.6203021736168226, 0.9552685402794356], 
             UndirectedEdge[130, 157] -> 
             RGBColor[
              0.19536013163296237`, 0.32266626326696746`, 0.9344368425358576],
              UndirectedEdge[83, 166] -> 
             RGBColor[
              0.8650576677002866, 0.8953688994003288, 0.9869563023793746], 
             UndirectedEdge[76, 176] -> 
             RGBColor[
              0.24916812422626491`, 0.3792218751063049, 0.9375011281122546], 
             UndirectedEdge[100, 113] -> 
             RGBColor[
              0.20512211761839033`, 0.33292672948331237`, 0.9349927731961636],
              UndirectedEdge[53, 118] -> 
             RGBColor[
              0.5113253166726569, 0.612460273634525, 0.9551410696826135], 
             UndirectedEdge[18, 85] -> 
             RGBColor[
              0.24676983740924385`, 0.376701123601449, 0.9373645492259726], 
             UndirectedEdge[90, 177] -> 
             RGBColor[
              0.22233026933066752`, 0.35101358799275084`, 0.9359727519789987],
              UndirectedEdge[55, 165] -> 
             RGBColor[
              0.2708407078314586, 0.3994925742335291, 0.9388272003702323], 
             UndirectedEdge[9, 121] -> 
             RGBColor[
              0.20533326031636837`, 0.3331486538461075, 0.9350047974604558], 
             UndirectedEdge[70, 110] -> 
             RGBColor[
              0.185588460386286, 0.31239561722696946`, 0.9338803603142515], 
             UndirectedEdge[51, 147] -> 
             RGBColor[
              0.2158606236854452, 0.3442135802203963, 0.9356043152304863], 
             UndirectedEdge[81, 188] -> 
             RGBColor[
              0.3096161145085913, 0.44234452583416967`, 0.9409586377929611], 
             UndirectedEdge[63, 132] -> 
             RGBColor[
              0.24611904809652904`, 0.37601710277136, 0.9373274877373701], 
             UndirectedEdge[68, 143] -> 
             RGBColor[
              0.9083269889752188, 0.8839114383656459, 0.6445270527281901], 
             UndirectedEdge[76, 81] -> 
             RGBColor[
              0.28513916633926595`, 0.41702972106286573`, 0.9395496257462019],
              UndirectedEdge[55, 163] -> 
             RGBColor[
              0.3088204539598367, 0.4394116954694417, 0.9409900907262441], 
             UndirectedEdge[86, 94] -> 
             RGBColor[
              0.19625374198187168`, 0.3236055044018397, 0.9344877323232499], 
             UndirectedEdge[3, 167] -> 
             RGBColor[
              0.3090133882504993, 0.4319576932374843, 0.9412814305798589], 
             UndirectedEdge[16, 82] -> 
             RGBColor[
              0.19957038496874147`, 0.32709150646835083`, 0.9346766102348185],
              UndirectedEdge[51, 107] -> 
             RGBColor[
              0.1999147758321102, 0.3274534831013933, 0.9346962227850067], 
             UndirectedEdge[53, 171] -> 
             RGBColor[
              0.4697666933739579, 0.5763722134005581, 0.9524963620713668], 
             UndirectedEdge[78, 82] -> 
             RGBColor[
              0.1974481944602994, 0.3248609496893285, 0.9345557546248622], 
             UndirectedEdge[92, 186] -> 
             RGBColor[
              0.21375750066891208`, 0.34200306458431906`, 0.9354845454859864],
              UndirectedEdge[75, 118] -> 
             RGBColor[
              0.44650486801296785`, 0.559836113284655, 0.9500381665189955], 
             UndirectedEdge[77, 83] -> 
             RGBColor[
              0.8718524916829569, 0.5391330266655409, 0.5785293580798063], 
             UndirectedEdge[42, 176] -> 
             RGBColor[
              0.21842899524564835`, 0.34691310157433214`, 0.9357505801912747],
              UndirectedEdge[20, 144] -> 
             RGBColor[
              0.19040607844928842`, 0.31745923926581243`, 0.9341547165359123],
              UndirectedEdge[26, 98] -> 
             RGBColor[
              0.24264169185428053`, 0.372362180883637, 0.9371294574436615], 
             UndirectedEdge[16, 84] -> 
             RGBColor[
              0.1842053187530256, 0.3109418476741682, 0.933801592444412], 
             UndirectedEdge[55, 175] -> 
             RGBColor[
              0.4182247539712943, 0.5353839569381427, 0.9482243963930945], 
             UndirectedEdge[113, 128] -> 
             RGBColor[
              0.3178799957707601, 0.44011084120794086`, 0.9418290717409573], 
             UndirectedEdge[142, 147] -> 
             RGBColor[
              0.25576128412159904`, 0.3861517041867828, 0.9378765988145878], 
             UndirectedEdge[10, 42] -> 
             RGBColor[
              0.2103603093846907, 0.3384324011502344, 0.9352910804680441], 
             UndirectedEdge[98, 120] -> 
             RGBColor[
              0.19321962278041294`, 0.32041645274683817`, 0.9343149437233039],
              UndirectedEdge[195, 199] -> 
             RGBColor[
              0.748146282404758, 0.7990537264187598, 0.8410340195093824], 
             UndirectedEdge[49, 195] -> 
             RGBColor[
              0.46169316726810605`, 0.5730216059163575, 0.9509976206498176], 
             UndirectedEdge[25, 43] -> 
             RGBColor[
              0.1846430806166806, 0.3114019631485748, 0.9338265223349365], 
             UndirectedEdge[91, 121] -> 
             RGBColor[
              0.2017936925772753, 0.329428343730764, 0.9348032243140356], 
             UndirectedEdge[8, 21] -> 
             RGBColor[
              0.3222839501803989, 0.4512119268537823, 0.9418428896396724], 
             UndirectedEdge[2, 124] -> 
             RGBColor[
              0.20420540017012767`, 0.331963201321945, 0.9349405674936471], 
             UndirectedEdge[80, 125] -> 
             RGBColor[
              0.243038153837541, 0.3727788875651853, 0.9371520353670952], 
             UndirectedEdge[33, 180] -> 
             RGBColor[
              0.6673282092975037, 0.7309455392481101, 0.857462764837877], 
             UndirectedEdge[5, 155] -> 
             RGBColor[
              0.513762074533002, 0.612974284551854, 0.9559298924776924], 
             UndirectedEdge[179, 192] -> 
             RGBColor[
              0.41712722923071616`, 0.5353797878648794, 0.9478929556641686], 
             UndirectedEdge[59, 146] -> 
             RGBColor[
              0.21481341413912597`, 0.34311289659029465`, 0.935544678196031], 
             UndirectedEdge[3, 68] -> 
             RGBColor[
              0.6898421419054424, 0.7085746089319662, 0.625429383133753], 
             UndirectedEdge[131, 157] -> 
             RGBColor[
              0.19396001666235732`, 0.3211946536604452, 0.9343571080595661], 
             UndirectedEdge[85, 200] -> 
             RGBColor[
              0.23054281786445055`, 0.35964549720740835`, 0.9364404444686207],
              UndirectedEdge[23, 38] -> 
             RGBColor[
              0.20238106508142, 0.3300457094741879, 0.9348366743092069], 
             UndirectedEdge[92, 191] -> 
             RGBColor[
              0.5272753016690297, 0.6129190189586639, 0.9594697403649703], 
             UndirectedEdge[97, 153] -> 
             RGBColor[
              0.24952804077433757`, 0.37960017021835646`, 0.9375216248272185],
              UndirectedEdge[95, 161] -> 
             RGBColor[
              0.26651291559129975`, 0.397452350554246, 0.9384888883211739], 
             UndirectedEdge[139, 196] -> 
             RGBColor[
              0.25932712065835106`, 0.3898996244740037, 0.9380796679301735], 
             UndirectedEdge[1, 94] -> 
             RGBColor[
              0.18516334977200538`, 0.3119487990177908, 0.933856150893663], 
             UndirectedEdge[189, 194] -> 
             RGBColor[
              0.19797673225113377`, 0.32541647641872684`, 0.9345858540701487],
              UndirectedEdge[42, 76] -> 
             RGBColor[
              0.23350932118742207`, 0.36276348028702554`, 0.9366093824443157],
              UndirectedEdge[84, 190] -> 
             RGBColor[
              0.18271061576572617`, 0.30937082006487343`, 0.9337164713205002],
              UndirectedEdge[37, 134] -> 
             RGBColor[
              0.24135977409579584`, 0.37101480404118925`, 0.9370564541237432],
              UndirectedEdge[140, 161] -> 
             RGBColor[
              0.6387756152014612, 0.7023172809495201, 0.7488332700746612], 
             UndirectedEdge[10, 51] -> 
             RGBColor[
              0.20007349461539067`, 0.32762030660597313`, 0.9347052615849112],
              UndirectedEdge[146, 191] -> 
             RGBColor[
              0.527753699812846, 0.6134218457400091, 0.9594969844315341], 
             UndirectedEdge[21, 175] -> 
             RGBColor[
              0.43093748007980026`, 0.5463950813331377, 0.9490344400593063], 
             UndirectedEdge[49, 141] -> 
             RGBColor[
              0.3830851867065078, 0.5062308671290127, 0.9456308272413769], 
             UndirectedEdge[111, 177] -> 
             RGBColor[
              0.21876304030867405`, 0.3472642041152524, 0.9357696035634386], 
             UndirectedEdge[69, 191] -> 
             RGBColor[
              0.5299588162079603, 0.6157395628837288, 0.9596225625480584], 
             UndirectedEdge[111, 175] -> 
             RGBColor[
              0.36035371764762536`, 0.477066388889339, 0.9448368758036116], 
             UndirectedEdge[77, 170] -> 
             RGBColor[
              0.736263484492014, 0.4323498561130519, 0.5652433325739429], 
             UndirectedEdge[104, 154] -> 
             RGBColor[
              0.3494855423442635, 0.47712854394966536`, 0.9434898876136137], 
             UndirectedEdge[13, 138] -> 
             RGBColor[
              0.2214898027052646, 0.35013020428079056`, 0.9359248886480409], 
             UndirectedEdge[21, 67] -> 
             RGBColor[
              0.30859689738128643`, 0.43682596655264533`, 0.9410634322309431],
              UndirectedEdge[73, 197] -> 
             RGBColor[
              0.20909257444253643`, 0.33709993134699245`, 0.9352188848385342],
              UndirectedEdge[67, 192] -> 
             RGBColor[
              0.36080214724091136`, 0.4817069445731053, 0.944482904164054], 
             UndirectedEdge[37, 101] -> 
             RGBColor[
              0.21602037207300215`, 0.3443814859043514, 0.9356134126648311], 
             UndirectedEdge[6, 44] -> 
             RGBColor[
              0.8651034665131747, 0.43792568886884486`, 0.20749020660542072`],
              UndirectedEdge[75, 89] -> 
             RGBColor[
              0.3848285553772075, 0.5026030860222612, 0.9462477862614576], 
             UndirectedEdge[76, 188] -> 
             RGBColor[
              0.288725398337364, 0.42038705859030223`, 0.9397689424120548], 
             UndirectedEdge[42, 71] -> 
             RGBColor[
              0.2832544040591832, 0.40996427332420193`, 0.9396284576905798], 
             UndirectedEdge[6, 192] -> 
             RGBColor[
              0.6485736073804235, 0.40987019823777215`, 0.5644077418055113], 
             UndirectedEdge[2, 100] -> 
             RGBColor[
              0.19408219414375266`, 0.32132306993989135`, 0.9343640658863862],
              UndirectedEdge[7, 8] -> 
             RGBColor[
              0.24587927343278695`, 0.3757650843971754, 0.9373138329249848], 
             UndirectedEdge[69, 92] -> 
             RGBColor[
              0.2471305318648358, 0.3770802363436254, 0.937385090241619], 
             UndirectedEdge[104, 160] -> 
             RGBColor[
              0.4051454853105788, 0.5253383889970118, 0.9470364899612722], 
             UndirectedEdge[17, 30] -> 
             RGBColor[
              0.20051771286008008`, 0.3280872081462052, 0.9347305591567843], 
             UndirectedEdge[88, 164] -> 
             RGBColor[
              0.20586798703479003`, 0.3337106855308008, 0.9350352493560126], 
             UndirectedEdge[43, 60] -> 
             RGBColor[
              0.18536402715025152`, 0.3121597236660082, 0.9338675791734785], 
             UndirectedEdge[149, 197] -> 
             RGBColor[
              0.19310487903170026`, 0.3202958497917673, 0.934308409236563], 
             UndirectedEdge[167, 197] -> 
             RGBColor[
              0.20001986015557813`, 0.327563933388089, 0.9347022071817699], 
             UndirectedEdge[54, 127] -> 
             RGBColor[
              0.9315900923682865, 0.9377519849577597, 0.6986638549616266], 
             UndirectedEdge[107, 147] -> 
             RGBColor[
              0.23357883684934996`, 0.36283654565525925`, 0.9366133412584232],
              UndirectedEdge[78, 113] -> 
             RGBColor[
              0.19369232004858233`, 0.320913287546422, 0.9343418631334333], 
             UndirectedEdge[81, 87] -> 
             RGBColor[
              0.261366444859298, 0.3920430835098213, 0.9381958044265076], 
             UndirectedEdge[83, 179] -> 
             RGBColor[
              0.6474631282319623, 0.7188859236705143, 0.9687723771837091], 
             UndirectedEdge[82, 198] -> 
             RGBColor[
              0.2787942966052594, 0.4069512855983587, 0.9393131360473621], 
             UndirectedEdge[30, 107] -> 
             RGBColor[
              0.21359959388546113`, 0.3418370945430438, 0.935475552928271], 
             UndirectedEdge[47, 134] -> 
             RGBColor[
              0.22156708062371444`, 0.3502114282727843, 0.9359292895111742], 
             UndirectedEdge[5, 142] -> 
             RGBColor[
              0.3081659820767354, 0.43701743485134614`, 0.9410152980549868], 
             UndirectedEdge[169, 190] -> 
             RGBColor[
              0.18813962732028144`, 0.31507705542792475`, 0.9340256454970293],
              UndirectedEdge[121, 152] -> 
             RGBColor[
              0.20876932330272832`, 0.33676017390374813`, 0.9352004761643293],
              UndirectedEdge[31, 64] -> 
             RGBColor[
              0.5807463788000884, 0.6705150984929575, 0.9601376287646749], 
             UndirectedEdge[105, 134] -> 
             RGBColor[
              0.22631486646654955`, 0.35520165222061295`, 0.936199668891204], 
             UndirectedEdge[83, 192] -> 
             RGBColor[
              0.6960500843646674, 0.7606329175254469, 0.9719612946400722], 
             UndirectedEdge[77, 112] -> 
             RGBColor[
              0.8793649622811279, 0.5449759719930563, 0.5741391008123097], 
             UndirectedEdge[195, 196] -> 
             RGBColor[
              0.3670089959605389, 0.4840064187410893, 0.9452208986581658], 
             UndirectedEdge[92, 171] -> 
             RGBColor[
              0.2760986031689815, 0.40752751596608494`, 0.939034779047969], 
             UndirectedEdge[166, 183] -> 
             RGBColor[
              0.8700567296048425, 0.8160449798489104, 0.6243716259282402], 
             UndirectedEdge[139, 195] -> 
             RGBColor[
              0.39334997945867106`, 0.5116924625124413, 0.9467209787003914], 
             UndirectedEdge[177, 190] -> 
             RGBColor[
              0.20078808579481044`, 0.3283713872432409, 0.9347459564954362], 
             UndirectedEdge[29, 149] -> 
             RGBColor[
              0.19620729298920309`, 0.32355668356550876`, 0.9344850871218325],
              UndirectedEdge[119, 155] -> 
             RGBColor[
              0.7600079693502197, 0.5527750998573846, 0.5802673825214153], 
             UndirectedEdge[12, 162] -> 
             RGBColor[
              0.7007570533940699, 0.7026453313085301, 0.614346873451971], 
             UndirectedEdge[85, 173] -> 
             RGBColor[
              0.31911259241838086`, 0.4472823241494562, 0.941684119139965], 
             UndirectedEdge[92, 141] -> 
             RGBColor[
              0.29413145548178377`, 0.42323873581169885`, 0.9401804453350167],
              UndirectedEdge[5, 29] -> 
             RGBColor[
              0.28062241209504013`, 0.4080673964373824, 0.9394467324915896], 
             UndirectedEdge[51, 87] -> 
             RGBColor[
              0.19944978493815407`, 0.3269647481897199, 0.9346697422414884], 
             UndirectedEdge[145, 153] -> 
             RGBColor[
              0.2362249636187789, 0.3656177926640565, 0.9367640342633485], 
             UndirectedEdge[118, 191] -> 
             RGBColor[
              0.6004855108108049, 0.6822749027401551, 0.9639169589656551], 
             UndirectedEdge[117, 164] -> 
             RGBColor[
              0.19024796848068162`, 0.3172930556640557, 0.9341457124071029], 
             UndirectedEdge[145, 185] -> 
             RGBColor[
              0.2111217144827195, 0.33923268618413416`, 0.935334441361979], 
             UndirectedEdge[99, 137] -> 
             RGBColor[
              0.4378565391647805, 0.5509964805640466, 0.9498598035828838], 
             UndirectedEdge[48, 176] -> 
             RGBColor[
              0.2222907628285849, 0.3509720641542051, 0.9359705021421497], 
             UndirectedEdge[50, 144] -> 
             RGBColor[
              0.20111766579178803`, 0.32871779671664314`, 0.9347647255886942],
              UndirectedEdge[3, 53] -> 
             RGBColor[
              0.5252380847939087, 0.6245108141050952, 0.9560275789647218], 
             UndirectedEdge[169, 177] -> 
             RGBColor[
              0.20474146136299756`, 0.33252663562389395`, 0.9349710953855495],
              UndirectedEdge[20, 135] -> 
             RGBColor[
              0.18962988067563263`, 0.3166434061919189, 0.9341105132209843], 
             UndirectedEdge[166, 170] -> 
             RGBColor[
              0.7294686605093437, 0.78858572884784, 0.973670276873511], 
             UndirectedEdge[17, 42] -> 
             RGBColor[
              0.1971197095760292, 0.3245156912488159, 0.9345370478966529], 
             UndirectedEdge[129, 195] -> 
             RGBColor[
              0.47775139397703026`, 0.5868991299424082, 0.952029486276343], 
             UndirectedEdge[74, 93] -> 
             RGBColor[
              0.28865865838495014`, 0.4172909648985178, 0.9398759363681078], 
             UndirectedEdge[37, 45] -> 
             RGBColor[
              0.47344467906469456`, 0.5697056609217193, 0.9542881258612889], 
             UndirectedEdge[49, 92] -> 
             RGBColor[
              0.33340074855062923`, 0.45725182373587436`, 0.9426826499648912],
              UndirectedEdge[163, 177] -> 
             RGBColor[
              0.24957629716502022`, 0.3796508907445958, 0.937524372957279], 
             UndirectedEdge[6, 45] -> 
             RGBColor[
              0.7712380059237092, 0.5084025319316335, 0.5747836939863987], 
             UndirectedEdge[6, 166] -> 
             RGBColor[
              0.8175811907160426, 0.5446061801126542, 0.5794027495448137], 
             UndirectedEdge[65, 127] -> 
             RGBColor[
              0.9155629949478274, 0.8836888220171212, 0.6364016079465316], 
             UndirectedEdge[15, 59] -> 
             RGBColor[
              0.18157500733235693`, 0.30817722359966904`, 0.9336518001002019],
              UndirectedEdge[100, 136] -> 
             RGBColor[
              0.21430154248906313`, 0.3425748870315415, 0.9355155278628062], 
             UndirectedEdge[83, 183] -> 
             RGBColor[
              0.9313850452704695, 0.8648151337796632, 0.6302560397084783], 
             UndirectedEdge[53, 119] -> 
             RGBColor[
              0.7393045339916254, 0.5364394110009786, 0.5783146231887367], 
             UndirectedEdge[5, 68] -> 
             RGBColor[
              0.6576626962859415, 0.680702390522319, 0.6233789373140448], 
             UndirectedEdge[49, 54] -> 
             RGBColor[
              0.7053736220772657, 0.7563760825874686, 0.6787707713186126], 
             UndirectedEdge[153, 185] -> 
             RGBColor[
              0.2571534731580585, 0.38761498313398474`, 0.937955881920655], 
             UndirectedEdge[101, 144] -> 
             RGBColor[
              0.19734151181877715`, 0.32474881946901846`, 0.9345496792062504],
              UndirectedEdge[19, 102] -> 
             RGBColor[
              0.6601961515617699, 0.7275798880657995, 0.9403309800746991], 
             UndirectedEdge[102, 172] -> 
             RGBColor[
              0.9192581959222914, 0.7380602445354411, 0.5748744102551196], 
             UndirectedEdge[102, 140] -> 
             RGBColor[
              0.981449443808876, 0.9827573994159884, 0.747626675734739], 
             UndirectedEdge[71, 107] -> 
             RGBColor[
              0.2906858024537879, 0.41777514421480366`, 0.9400516648353837], 
             UndirectedEdge[5, 168] -> 
             RGBColor[
              0.2818657379269033, 0.4093742107180814, 0.9395175380583785], 
             UndirectedEdge[79, 122] -> 
             RGBColor[
              0.2360507899414387, 0.3654347250859229, 0.9367541153300909], 
             UndirectedEdge[136, 198] -> 
             RGBColor[
              0.2842178470642151, 0.4126517810036814, 0.9396219992225757], 
             UndirectedEdge[97, 135] -> 
             RGBColor[
              0.20686780943909605`, 0.33476156227012827`, 0.9350921877628332],
              UndirectedEdge[19, 164] -> 
             RGBColor[
              0.2731949072578401, 0.40054884518181094`, 0.9390131936672395], 
             UndirectedEdge[118, 139] -> 
             RGBColor[
              0.33826776988296947`, 0.4652785641134494, 0.9428532266161497], 
             UndirectedEdge[26, 137] -> 
             RGBColor[
              0.3083373002531643, 0.4400120442459969, 0.9409220001603581], 
             UndirectedEdge[142, 168] -> 
             RGBColor[
              0.23569763939068106`, 0.3650635414660385, 0.9367340039286646], 
             UndirectedEdge[3, 194] -> 
             RGBColor[
              0.3101074606435417, 0.43310763269076813`, 0.9413437363841075], 
             UndirectedEdge[65, 195] -> 
             RGBColor[
              0.7286852121495595, 0.7350905705099995, 0.6193731130820839], 
             UndirectedEdge[73, 107] -> 
             RGBColor[
              0.21755611110948542`, 0.34599564500317415`, 0.9357008707310365],
              UndirectedEdge[162, 172] -> 
             RGBColor[
              0.6603763668123606, 0.5325003847582571, 0.5813358018320983], 
             UndirectedEdge[68, 140] -> 
             RGBColor[
              0.977357275935254, 0.934529823363472, 0.4305753131856688], 
             UndirectedEdge[38, 165] -> 
             RGBColor[
              0.19346381204820906`, 0.3206731111497857, 0.9343288499408593], 
             UndirectedEdge[86, 92] -> 
             RGBColor[
              0.22327186579105107`, 0.35200326557327766`, 0.9360263745044504],
              UndirectedEdge[90, 115] -> 
             RGBColor[
              0.27114794471103404`, 0.4017434985665935, 0.9387741035720105], 
             UndirectedEdge[11, 70] -> 
             RGBColor[
              0.19700340773557554`, 0.3243934506405365, 0.9345304246788922], 
             UndirectedEdge[54, 123] -> 
             RGBColor[
              0.7197585780581139, 0.7688356084491694, 0.6796873679935951], 
             UndirectedEdge[107, 176] -> 
             RGBColor[
              0.22586039364025307`, 0.35472397246493387`, 0.9361737873360787],
              UndirectedEdge[30, 76] -> 
             RGBColor[
              0.23690732447147297`, 0.36633499718441476`, 0.936802893704447], 
             UndirectedEdge[129, 191] -> 
             RGBColor[
              0.632287259602678, 0.7097886743020284, 0.965951987897856], 
             UndirectedEdge[7, 125] -> 
             RGBColor[
              0.2363887212836201, 0.36578991235264013`, 0.9367733600201034], 
             UndirectedEdge[3, 155] -> 
             RGBColor[
              0.545941520152503, 0.6408465029615011, 0.9579803382974005], 
             UndirectedEdge[54, 118] -> 
             RGBColor[
              0.6896300999943169, 0.7427398350516461, 0.6777676080129371], 
             UndirectedEdge[4, 171] -> 
             RGBColor[
              0.3210288697535419, 0.4523887348957585, 0.9416800247158792], 
             UndirectedEdge[167, 189] -> 
             RGBColor[
              0.19688265985809134`, 0.32426653696544305`, 0.9345235482659], 
             UndirectedEdge[42, 81] -> 
             RGBColor[
              0.25440003735864936`, 0.3847209475308929, 0.9377990778252221], 
             UndirectedEdge[5, 129] -> 
             RGBColor[
              0.40440250690307966`, 0.5246635536043394, 0.9469977976545015], 
             UndirectedEdge[115, 133] -> 
             RGBColor[
              0.2820742314375166, 0.41322771868271746`, 0.939396339437091], 
             UndirectedEdge[92, 146] -> 
             RGBColor[
              0.24492541546972163`, 0.3747625191999059, 0.9372595121250946], 
             UndirectedEdge[65, 151] -> 
             RGBColor[
              0.9751208756473086, 0.9280643537313567, 0.5177938016500871], 
             UndirectedEdge[45, 156] -> 
             RGBColor[
              0.7648803283778755, 0.4595346363622902, 0.5686955747885385], 
             UndirectedEdge[74, 172] -> 
             RGBColor[
              0.607635645662135, 0.48681902292365303`, 0.5779752097171944], 
             UndirectedEdge[31, 138] -> 
             RGBColor[
              0.3769176966090809, 0.4907215889641815, 0.9461219362207016], 
             UndirectedEdge[116, 198] -> 
             RGBColor[
              0.29312560612523564`, 0.42201440056135886`, 0.9401292829232522],
              UndirectedEdge[42, 142] -> 
             RGBColor[
              0.23238403787365935`, 0.361580736177178, 0.9365452992243044], 
             UndirectedEdge[10, 129] -> 
             RGBColor[
              0.3362106798778888, 0.4572045493253528, 0.9429600447685274], 
             UndirectedEdge[3, 141] -> 
             RGBColor[
              0.38125443274481086`, 0.5046451600637603, 0.9455141732178098], 
             UndirectedEdge[161, 162] -> 
             RGBColor[
              0.3676199899888237, 0.4905318508026293, 0.94472975345843], 
             UndirectedEdge[6, 77] -> 
             RGBColor[
              0.8243760146987129, 0.18837030737786614`, 0.17097580524524553`],
              UndirectedEdge[98, 113] -> 
             RGBColor[
              0.19847726376767427`, 0.32594256677814204`, 0.9346143585995457],
              UndirectedEdge[3, 139] -> 
             RGBColor[
              0.3521805380042213, 0.47732910458401956`, 0.943739735898258], 
             UndirectedEdge[34, 138] -> 
             RGBColor[
              0.32596539118379714`, 0.4487246258382862, 0.9422852932438326], 
             UndirectedEdge[22, 72] -> 
             RGBColor[
              0.22084536933385682`, 0.34945286394800523`, 0.935888189120893], 
             UndirectedEdge[34, 40] -> 
             RGBColor[
              0.4679436932956409, 0.5783052104909272, 0.9514318973025666], 
             UndirectedEdge[41, 74] -> 
             RGBColor[
              0.31831841781976944`, 0.44846525260187575`, 0.9415650157902389],
              UndirectedEdge[141, 146] -> 
             RGBColor[
              0.2946098536256002, 0.4237415625930442, 0.9402076894015805], 
             UndirectedEdge[90, 111] -> 
             RGBColor[
              0.22370338980181498`, 0.3524568246687931, 0.9360509491584807], 
             UndirectedEdge[66, 82] -> 
             RGBColor[
              0.1977556445101682, 0.32518409918519964`, 0.9345732634503707], 
             UndirectedEdge[119, 151] -> 
             RGBColor[
              0.9203645260018751, 0.6763382789683456, 0.4715886994182685], 
             UndirectedEdge[4, 139] -> 
             RGBColor[
              0.30998782732575464`, 0.44078389926163164`, 0.9410512536833753],
              UndirectedEdge[165, 175] -> 
             RGBColor[
              0.35318722837559335`, 0.4695339542827697, 0.9444287548414402], 
             UndirectedEdge[127, 139] -> 
             RGBColor[
              0.5802277622569392, 0.660290714019563, 0.9637494735648391], 
             UndirectedEdge[85, 117] -> 
             RGBColor[
              0.22789736538652144`, 0.3568649589217301, 0.9362897898635989], 
             UndirectedEdge[141, 155] -> 
             RGBColor[
              0.5085029810453545, 0.6084191221025781, 0.9555947876910933], 
             UndirectedEdge[168, 189] -> 
             RGBColor[
              0.2019144551539962, 0.3295552728556873, 0.9348101015641277], 
             UndirectedEdge[24, 175] -> 
             RGBColor[
              0.3788592562848471, 0.49651688331597643`, 0.9458907388525104], 
             UndirectedEdge[106, 176] -> 
             RGBColor[
              0.20955893430915817`, 0.33759010513573523`, 0.9352454433430207],
              UndirectedEdge[40, 53] -> 
             RGBColor[
              0.5688067096740002, 0.6608219372204345, 0.9591976942746201], 
             UndirectedEdge[27, 155] -> 
             RGBColor[
              0.4698552775688525, 0.57104038662686, 0.953275136127212], 
             UndirectedEdge[33, 77] -> 
             RGBColor[
              0.9049712712883817, 0.5626723297681262, 0.46806425968515003`], 
             UndirectedEdge[67, 137] -> 
             RGBColor[
              0.289891245032081, 0.42062407066118745`, 0.9398715246040107], 
             UndirectedEdge[68, 129] -> 
             RGBColor[
              0.7077311225760636, 0.7240378400232692, 0.6265779027838456], 
             UndirectedEdge[137, 192] -> 
             RGBColor[
              0.3948032831545909, 0.5160439078078941, 0.9464704935604884], 
             UndirectedEdge[58, 128] -> 
             RGBColor[
              0.695941652480456, 0.7590582933299347, 0.9501605185766638], 
             UndirectedEdge[55, 90] -> 
             RGBColor[
              0.281574426125484, 0.41077439271759675`, 0.9394384697479637], 
             UndirectedEdge[26, 82] -> 
             RGBColor[
              0.2523736658856789, 0.382591102633429, 0.9376836789675842], 
             UndirectedEdge[43, 165] -> 
             RGBColor[
              0.19777525937960444`, 0.32520471565663167`, 0.9345743804881674],
              UndirectedEdge[123, 199] -> 
             RGBColor[
              0.7231925508928534, 0.7787356014172913, 0.8390860274057987], 
             UndirectedEdge[34, 45] -> 
             RGBColor[
              0.5705500737145661, 0.6605535414680137, 0.960228808821763], 
             UndirectedEdge[133, 178] -> 
             RGBColor[
              0.21638528695668868`, 0.3447650345840459, 0.9356341940276138], 
             UndirectedEdge[29, 189] -> 
             RGBColor[
              0.20067112932213305`, 0.3282484585749883, 0.9347392959973388], 
             UndirectedEdge[91, 164] -> 
             RGBColor[
              0.19070376679969833`, 0.3177721285966248, 0.9341716694470776], 
             UndirectedEdge[116, 124] -> 
             RGBColor[
              0.2333325075764587, 0.3625776379712726, 0.9365993131707435], 
             UndirectedEdge[80, 113] -> 
             RGBColor[
              0.2131232803220724, 0.34133645878789803`, 0.9354484275754789], 
             UndirectedEdge[10, 75] -> 
             RGBColor[
              0.3600463634895279, 0.4765554310665914, 0.9448364770954216], 
             UndirectedEdge[74, 180] -> 
             RGBColor[
              0.34398171160205027`, 0.4723614023913367, 0.9431391883855662], 
             UndirectedEdge[27, 149] -> 
             RGBColor[
              0.2260121645429709, 0.35488349330652136`, 0.9361824304644635], 
             UndirectedEdge[4, 49] -> 
             RGBColor[
              0.37833101513518963`, 0.5021130426655478, 0.9453278956328015], 
             UndirectedEdge[9, 152] -> 
             RGBColor[
              0.19674957296563292`, 0.32412665420327286`, 0.9345159691642588],
              UndirectedEdge[19, 85] -> 
             RGBColor[
              0.31084430416368, 0.44012074843948534`, 0.9411572711237357], 
             UndirectedEdge[189, 197] -> 
             RGBColor[
              0.19756871536463022`, 0.3249876248012469, 0.9345626181120692], 
             UndirectedEdge[69, 195] -> 
             RGBColor[
              0.3754229505823126, 0.4928500185241086, 0.9457000609265455], 
             UndirectedEdge[75, 191] -> 
             RGBColor[
              0.656122943214317, 0.729139556043267, 0.9678284202247502], 
             UndirectedEdge[73, 75] -> 
             RGBColor[
              0.3598107668197179, 0.47630780402892936`, 0.9448230602136101], 
             UndirectedEdge[68, 188] -> 
             RGBColor[
              0.6370968292328074, 0.6628892701514275, 0.6220684984511013], 
             UndirectedEdge[4, 123] -> 
             RGBColor[
              0.39271597111603795`, 0.5145725685272486, 0.946244492307784], 
             UndirectedEdge[7, 84] -> 
             RGBColor[
              0.19486465596415276`, 0.32214548692407674`, 0.9344086259295095],
              UndirectedEdge[171, 195] -> 
             RGBColor[
              0.4043910218864583, 0.5232972981465681, 0.9473497497328954], 
             UndirectedEdge[62, 167] -> 
             RGBColor[
              0.19961760381417978`, 0.3271411364687542, 0.9346792992782123], 
             UndirectedEdge[91, 152] -> 
             RGBColor[
              0.19321000522653986`, 0.3204063440879294, 0.9343143960178388], 
             UndirectedEdge[38, 90] -> 
             RGBColor[
              0.20419753034223448`, 0.33195492963385337`, 0.9349401193185908],
              UndirectedEdge[3, 118] -> 
             RGBColor[
              0.40478020373070756`, 0.5250220004521133, 0.9470132145420087], 
             UndirectedEdge[143, 181] -> 
             RGBColor[
              0.6469177981644729, 0.7208456508308313, 0.967618016283176], 
             UndirectedEdge[20, 50] -> 
             RGBColor[
              0.19303508907013, 0.32022249611721776`, 0.9343044348014965], 
             UndirectedEdge[128, 136] -> 
             RGBColor[
              0.3270594206414329, 0.44975899875617, 0.9423518264076001], 
             UndirectedEdge[19, 161] -> 
             RGBColor[
              0.3175223229543551, 0.44713976959933127`, 0.9415375744146212], 
             UndirectedEdge[19, 140] -> 
             RGBColor[
              0.6724699476644765, 0.7338054584355065, 0.7508958882679089], 
             UndirectedEdge[39, 159] -> 
             RGBColor[
              0.25347717812255377`, 0.3837509639611013, 0.9377465223569743], 
             UndirectedEdge[87, 154] -> 
             RGBColor[
              0.2742869255202454, 0.40348527807603907`, 0.9390098911632051], 
             UndirectedEdge[104, 143] -> 
             RGBColor[
              0.6113814534238254, 0.6900658551251025, 0.9653536718198579], 
             UndirectedEdge[6, 183] -> 
             RGBColor[
              0.8839085682862255, 0.5140524144919886, 0.22270248687391753`], 
             UndirectedEdge[17, 89] -> 
             RGBColor[
              0.229492018641594, 0.35854104059966735`, 0.9363806030073972], 
             UndirectedEdge[131, 176] -> 
             RGBColor[
              0.20779145347843028`, 0.335732370717883, 0.9351447879244643], 
             UndirectedEdge[44, 143] -> 
             RGBColor[
              0.8772182848102179, 0.7604919813860003, 0.611670932866671], 
             UndirectedEdge[140, 173] -> 
             RGBColor[
              0.6807382359191774, 0.7409670341454773, 0.7514227362841381], 
             UndirectedEdge[123, 195] -> 
             RGBColor[
              0.4760781232489544, 0.5854811317780583, 0.9519142173248001], 
             UndirectedEdge[96, 125] -> 
             RGBColor[
              0.600349784053201, 0.6736043813543324, 0.9654382177461185], 
             UndirectedEdge[95, 159] -> 
             RGBColor[
              0.2520449781686508, 0.3822456310028275, 0.9376649606883494], 
             UndirectedEdge[171, 191] -> 
             RGBColor[
              0.558926887512106, 0.6461868425061883, 0.9612722513544084], 
             UndirectedEdge[124, 187] -> 
             RGBColor[
              0.21475919139226923`, 0.3430559050454275, 0.935541590290813], 
             UndirectedEdge[54, 191] -> 
             RGBColor[
              0.899248175195666, 0.9120432778102582, 0.6955578617186919], 
             UndirectedEdge[24, 55] -> 
             RGBColor[
              0.29651273574071235`, 0.4264755032667358, 0.9402891843813024], 
             UndirectedEdge[61, 126] -> 
             RGBColor[
              0.19350305800530745`, 0.3207143611390335, 0.9343310849400568], 
             UndirectedEdge[46, 101] -> 
             RGBColor[
              0.18958670352767176`, 0.3165980242718227, 0.9341080543462827], 
             UndirectedEdge[158, 176] -> 
             RGBColor[
              0.27521608284831744`, 0.40589741017048, 0.9390102435558715], 
             UndirectedEdge[91, 200] -> 
             RGBColor[
              0.18842402865999922`, 0.3153759792680545, 0.9340418417325922], 
             UndirectedEdge[29, 129] -> 
             RGBColor[
              0.33069083838516217`, 0.4514028459383327, 0.9426456979613903], 
             UndirectedEdge[37, 47] -> 
             RGBColor[
              0.21605368220731502`, 0.34441649696749876`, 0.9356153096277022],
              UndirectedEdge[25, 38] -> 
             RGBColor[
              0.18033163328528526`, 0.30687035864172885`, 0.9335809917876283],
              UndirectedEdge[95, 173] -> 
             RGBColor[
              0.308475536309016, 0.4361021037502032, 0.9410783545306509], 
             UndirectedEdge[86, 174] -> 
             RGBColor[
              0.19606494632876875`, 0.3234070682000927, 0.9344769806901039], 
             UndirectedEdge[4, 146] -> 
             RGBColor[
              0.289855682054282, 0.41962373812957937`, 0.9399047577930049], 
             UndirectedEdge[114, 186] -> 
             RGBColor[
              0.18224157379578187`, 0.3088778272154834, 0.9336897600741974], 
             UndirectedEdge[155, 199] -> 
             RGBColor[
              0.8342253892508518, 0.868464330529156, 0.8481333911805324], 
             UndirectedEdge[114, 194] -> 
             RGBColor[
              0.19146855650738448`, 0.3185759710698711, 0.9342152230895253], 
             UndirectedEdge[59, 186] -> 
             RGBColor[
              0.18364549933831636`, 0.3103534419747078, 0.9337697115569229], 
             UndirectedEdge[99, 193] -> 
             RGBColor[
              0.3906410080149175, 0.5027703500949796, 0.9471196739266945], 
             UndirectedEdge[109, 136] -> 
             RGBColor[
              0.22011061631709428`, 0.3486805919413559, 0.935846346023558], 
             UndirectedEdge[50, 134] -> 
             RGBColor[
              0.22530992446241244`, 0.3541453944572617, 0.9361424389307468], 
             UndirectedEdge[112, 183] -> 
             RGBColor[
              0.9388975158686406, 0.8706580791071786, 0.6258657824409817], 
             UndirectedEdge[42, 73] -> 
             RGBColor[
              0.2101247127148807, 0.3381847741125724, 0.9352776635862325], 
             UndirectedEdge[42, 147] -> 
             RGBColor[
              0.22614743845474522`, 0.3550256747646575, 0.9361901341136192], 
             UndirectedEdge[87, 131] -> 
             RGBColor[
              0.19909905794023608`, 0.326596111877532, 0.934649768857811], 
             UndirectedEdge[1, 11] -> 
             RGBColor[
              0.19143609648975546`, 0.318541853533259, 0.9342133745395418], 
             UndirectedEdge[30, 81] -> 
             RGBColor[
              0.2577980406427003, 0.3882924644282822, 0.9379925890853533], 
             UndirectedEdge[154, 188] -> 
             RGBColor[
              0.3225365951695387, 0.45378672040038737`, 0.9417727245296585], 
             UndirectedEdge[83, 156] -> 
             RGBColor[
              0.8725518288358358, 0.5445084384740636, 0.5791990441271917], 
             UndirectedEdge[5, 107] -> 
             RGBColor[
              0.28598353480448624`, 0.4137022763198226, 0.9397520404988222], 
             UndirectedEdge[93, 180] -> 
             RGBColor[
              0.28670982280114365`, 0.41560298146714914`, 0.9397517582879953],
              UndirectedEdge[10, 17] -> 
             RGBColor[
              0.2047098267539144, 0.3324933856439975, 0.9349692938413614], 
             UndirectedEdge[75, 141] -> 
             RGBColor[
              0.42297909702707115`, 0.5394592728963019, 0.9485391251947967], 
             UndirectedEdge[123, 141] -> 
             RGBColor[
              0.39747014268735614`, 0.5186903929907134, 0.9465474239163595], 
             UndirectedEdge[40, 119] -> 
             RGBColor[
              0.6763280459297676, 0.4853122609339061, 0.5733568833580303], 
             UndirectedEdge[16, 80] -> 
             RGBColor[
              0.20448442749174123`, 0.3322564767283148, 0.934956457686829], 
             UndirectedEdge[88, 180] -> 
             RGBColor[
              0.279297845494757, 0.4078125233716327, 0.9393296571454344], 
             UndirectedEdge[24, 41] -> 
             RGBColor[
              0.2739267632539736, 0.4052447745128077, 0.9389110959777585], 
             UndirectedEdge[4, 119] -> 
             RGBColor[
              0.5905667103712094, 0.4124559324961789, 0.5674982858332491], 
             UndirectedEdge[99, 136] -> 
             RGBColor[
              0.3873164552562508, 0.49927603435680146`, 0.9469303455653235], 
             UndirectedEdge[10, 194] -> 
             RGBColor[
              0.20973618799885002`, 0.33777641000213443`, 0.9352555376784253],
              UndirectedEdge[96, 102] -> 
             RGBColor[
              0.9527960526971394, 0.9643159539076722, 0.964788149409247], 
             UndirectedEdge[9, 88] -> 
             RGBColor[
              0.20493816247527158`, 0.3327333809644648, 0.9349822972229003], 
             UndirectedEdge[55, 108] -> 
             RGBColor[
              0.3219524714198415, 0.4532142784379034, 0.9417379396935124], 
             UndirectedEdge[62, 197] -> 
             RGBColor[
              0.20030365932071864`, 0.327862224304558, 0.9347183691243814], 
             UndirectedEdge[147, 168] -> 
             RGBColor[
              0.22946103997176695`, 0.35850848005351804`, 0.9363788388179795],
              UndirectedEdge[51, 106] -> 
             RGBColor[
              0.1836133165010153, 0.31031961577219463`, 0.9337678787919488], 
             UndirectedEdge[123, 155] -> 
             RGBColor[
              0.5621572300950483, 0.6548917358884543, 0.9590135889959501], 
             UndirectedEdge[75, 142] -> 
             RGBColor[
              0.3820700919784965, 0.49970376609353495`, 0.9460906958516819], 
             UndirectedEdge[31, 182] -> 
             RGBColor[
              0.43639733566624106`, 0.5502718081152633, 0.9496178373615334], 
             UndirectedEdge[65, 140] -> 
             RGBColor[
              0.9750309047249213, 0.9266824270130837, 0.4215378003318664]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 71 -> 
             RGBColor[
              0.3637386159115608, 0.4894738398933511, 0.9443980808578237], 10 -> 
             RGBColor[
              0.2179504265625759, 0.34641009554541596`, 0.9357233264127526], 
             68 -> RGBColor[
              0.9609913119589255, 0.8800766769412489, 0.30295904244338884`], 
             155 -> RGBColor[
              0.6731900684530466, 0.744620465000319, 0.9680609527706839], 132 -> 
             RGBColor[
              0.30056549504747376`, 0.4332437706209237, 0.9404281323449262], 
             26 -> RGBColor[
              0.2927822195605681, 0.4250630545960175, 0.9399848863202711], 29 -> 
             RGBColor[
              0.20691074357712266`, 0.33480668877137576`, 0.9350946327984784],
              113 -> RGBColor[
              0.20445336338735556`, 0.33222382638502757`, 0.9349546886320393],
              50 -> RGBColor[
              0.20374667641262958`, 0.33148105356804847`, 0.9349144438542785],
              173 -> RGBColor[
              0.36775323192677223`, 0.4929510985052593, 0.9446538886403275], 
             192 -> RGBColor[
              0.46571418536342124`, 0.577126781719812, 0.9510818731205317], 
             165 -> RGBColor[
              0.2058031822357576, 0.33364257157815613`, 0.9350315588185778], 
             92 -> RGBColor[
              0.2444470173259052, 0.37425969241856055`, 0.9372322680585309], 
             11 -> RGBColor[
              0.20295626314304663`, 0.3306502791066209, 0.9348694309878873], 
             137 -> RGBColor[
              0.32389238094576056`, 0.45496103389597625`, 0.9418591140004451],
              120 -> RGBColor[
              0.1939380814128329, 0.3211715983224198, 0.934355858879556], 51 -> 
             RGBColor[
              0.18219656266820544`, 0.3088305176665303, 0.9336871967570698], 
             72 -> RGBColor[
              0.2532013109542942, 0.38346101007627187`, 0.9377308121298508], 
             64 -> RGBColor[
              0.6295309817704698, 0.7101206369056319, 0.9639781314143923], 41 -> 
             RGBColor[
              0.29070628845368207`, 0.422881119381046, 0.9398666651147989], 
             103 -> RGBColor[
              0.1810808656124072, 0.3076578493216073, 0.933623659460268], 162 -> 
             RGBColor[
              0.4514119894863078, 0.5654121094919137, 0.9499845506954865], 
             196 -> RGBColor[
              0.23298613716021888`, 0.3622135807026517, 0.9365795878879478], 
             179 -> RGBColor[
              0.3685402730980111, 0.49363279400994686`, 0.9447040382078057], 
             160 -> RGBColor[
              0.44319072976501883`, 0.5582912675338615, 0.9494606992958204], 
             123 -> RGBColor[
              0.4511243917370499, 0.5651630067765897, 0.9499662252212164], 
             150 -> RGBColor[
              0.19256204953176445`, 0.3197253015699566, 0.9342774958995859], 
             188 -> RGBColor[
              0.31320234650668927`, 0.4457018633616062, 0.9411779544588138], 
             46 -> RGBColor[
              0.18297903858873563`, 0.3096529494708463, 0.9337317576031746], 
             182 -> RGBColor[
              0.34083289550277507`, 0.46963405615024345`, 0.9429385486081092],
              6 -> RGBColor[
              0.8314330293974257, 0.24261361475573226`, 0.17773361049049105`],
              131 -> 
             RGBColor[
              0.1814951086723694, 0.3080932450421545, 0.9336472499897152], 45 -> 
             RGBColor[
              0.7110429824499928, 0.7741914491075349, 0.9718337774823064], 
             195 -> RGBColor[
              0.5010318547608589, 0.6057992567795268, 0.9538622094283838], 
             148 -> RGBColor[
              0.19357697366818166`, 0.320792051187238, 0.9343352943277091], 
             161 -> RGBColor[
              0.2838279904913397, 0.4156515921133449, 0.9394749562213734], 1 -> 
             RGBColor[
              0.17991592983646426`, 0.30643342795989703`, 0.9335573180911961],
              101 -> RGBColor[
              0.19619436846660787`, 0.3235430990727991, 0.9344843510893909], 
             12 -> RGBColor[
              0.950102117301832, 0.8398785531251466, 0.2787091962084557], 39 -> 
             RGBColor[
              0.25206224059906557`, 0.3822637749116947, 0.9376659437582241], 
             48 -> RGBColor[
              0.21049372737267863`, 0.3385726319147987, 0.9352986784250858], 
             77 -> RGBColor[0.817319, 0.134127, 0.164218], 56 -> 
             RGBColor[
              0.1825695689347496, 0.30922257090263144`, 0.9337084389121362], 
             110 -> RGBColor[
              0.18012636844446756`, 0.30665461227948687`, 0.9335693022586058],
              73 -> RGBColor[
              0.21747923322295587`, 0.34591484147009205`, 0.9356964926491292],
              37 -> RGBColor[
              0.23584637567939642`, 0.36521987273590373`, 0.9367424742402714],
              130 -> RGBColor[
              0.1842953386135795, 0.3110364642551991, 0.933806718942298], 107 -> 
             RGBColor[
              0.21763298899601496`, 0.34607644853625624`, 0.9357052488129437],
              59 -> RGBColor[
              0.18422301466471383`, 0.3109604471993381, 0.9338026002004038], 
             47 -> RGBColor[
              0.1962609887352336, 0.32361312119909375`, 0.9344881450151332], 
             159 -> RGBColor[
              0.2548921156460419, 0.3852381530105079, 0.9378271009557244], 55 -> 
             RGBColor[
              0.33587823342715956`, 0.465342576888902, 0.9426228419218866], 
             49 -> RGBColor[
              0.4223544797753533, 0.5402439550531881, 0.9481330318712514], 82 -> 
             RGBColor[
              0.21196511221078973`, 0.3401191506708405, 0.9353824716148974], 
             199 -> RGBColor[
              0.995260710048657, 0.9923081960579929, 0.7282058295903809], 89 -> 
             RGBColor[
              0.2675148103379351, 0.39850540545675567`, 0.9385459447448243], 
             144 -> RGBColor[
              0.19848865517094644`, 0.32595453986523776`, 0.93461500732311], 
             78 -> RGBColor[
              0.18293127670980908`, 0.3096027487078165, 0.9337290376348271], 
             42 -> RGBColor[
              0.2027701922068055, 0.3304547067550528, 0.9348588345233357], 
             154 -> RGBColor[
              0.33187084383238813`, 0.46187157743916857`, 0.9423674946005033],
              168 -> RGBColor[
              0.20939739524084894`, 0.3374203173327738, 0.9352362439320562], 
             121 -> RGBColor[
              0.21735301065346377`, 0.34578217354658275`, 0.9356893044605262],
              128 -> RGBColor[
              0.43130662815416465`, 0.5479978560308542, 0.9487034548498753], 
             115 -> RGBColor[
              0.31502527059825963`, 0.4472807885868956, 0.9412941095699802], 
             61 -> RGBColor[
              0.2073405252862433, 0.3352584165973958, 0.9351191082310077], 93 -> 
             RGBColor[
              0.23138676958404353`, 0.3605325439743302, 0.9364885062705369], 
             88 -> RGBColor[
              0.21656281497127022`, 0.34495162778329735`, 0.9356443039854151],
              21 -> RGBColor[
              0.36130368564417137`, 0.48736482567889206`, 0.94424292925431], 
             62 -> RGBColor[
              0.1999014029793203, 0.32743942738522325`, 0.9346954612208237], 
             136 -> RGBColor[
              0.22281221312870114`, 0.35152014148148586`, 0.9360001979653247],
              190 -> RGBColor[
              0.1841862517520943, 0.3109218070472717, 0.933800506606916], 57 -> 
             RGBColor[
              0.1818396285304826, 0.30845535725685214`, 0.9336668698859633], 
             111 -> RGBColor[
              0.2201361607798215, 0.3487074407912947, 0.9358478007429207], 63 -> 
             RGBColor[
              0.19167260114558432`, 0.31879043492179643`, 0.9342268431298139],
              75 -> RGBColor[
              0.5021423004164799, 0.6067007665877667, 0.9539496277780908], 30 -> 
             RGBColor[
              0.2095661987749073, 0.33759774054983127`, 0.9352458570435983], 
             5 -> RGBColor[
              0.35433408061295757`, 0.481328104103389, 0.9437988321847008], 
             171 -> RGBColor[
              0.30775018901205775`, 0.44079533951360933`, 0.940837290037407], 
             102 -> RGBColor[
              0.9691756477061694, 0.9765318290462814, 0.9370617675415293], 31 -> 
             RGBColor[
              0.531961775829707, 0.6309095600802831, 0.9562971261149575], 96 -> 
             RGBColor[
              0.9364164576881094, 0.9521000787690629, 0.9925145312769647], 70 -> 
             RGBColor[
              0.19105055232810444`, 0.31813662217445204`, 0.9341914183698972],
              52 -> RGBColor[
              0.18558886593634766`, 0.31239604348579764`, 0.9338803834097276],
              183 -> RGBColor[
              0.9363841071750253, 0.7854912142282449, 0.26767136325734403`], 
             158 -> RGBColor[
              0.3163443674121438, 0.4484233239473484, 0.9413781612525294], 13 -> 
             RGBColor[
              0.22110598802207443`, 0.3497267907135012, 0.9359030309696362], 
             170 -> RGBColor[
              0.6552079689840278, 0.7305727122261038, 0.9662686651478858], 86 -> 
             RGBColor[
              0.2020967142561969, 0.3297468387279948, 0.9348204809503698], 18 -> 
             RGBColor[
              0.22306772190849825`, 0.3517886974092449, 0.9360147488123428], 
             153 -> RGBColor[
              0.2822567222941179, 0.41400008961390705`, 0.9393854748220246], 
             58 -> RGBColor[
              0.9605766768067475, 0.9701187306290152, 0.9516175823034524], 22 -> 
             RGBColor[
              0.18848942771341942`, 0.31544471781973865`, 0.9340455661119352],
              66 -> RGBColor[
              0.18354617680954663`, 0.31024904769955874`, 0.9337640552858439],
              143 -> RGBColor[
              0.8556626659915121, 0.887746199790043, 0.9860950630129915], 119 -> 
             RGBColor[
              0.8468258702473929, 0.3609297347144502, 0.19247381227214683`], 
             145 -> RGBColor[
              0.1901932049434399, 0.31723549571420584`, 0.9341425937046723], 
             91 -> RGBColor[
              0.18623437450108682`, 0.31307451391494534`, 0.9339171441675451],
              177 -> RGBColor[
              0.21738991983752656`, 0.34582096743921015`, 0.9356914063839564],
              200 -> RGBColor[
              0.1906136828189116, 0.3176774446211637, 0.9341665392976392], 
             114 -> RGBColor[
              0.18141516357964482`, 0.30800921768088935`, 0.9336426972349526],
              24 -> RGBColor[
              0.2571472380542651, 0.3876084296445695, 0.9379555268407181], 
             176 -> RGBColor[
              0.23408779828449117`, 0.3633714963936115, 0.9366423258592136], 
             79 -> RGBColor[
              0.1941778278429074, 0.3214235870212298, 0.9343695120840757], 
             109 -> 
             RGBColor[
              0.21740901950548744`, 0.34584104240122593`, 0.9356924940817913],
              135 -> RGBColor[
              0.1969362596236349, 0.3243228737174507, 0.934526600693254], 108 -> 
             RGBColor[
              0.3080267094125234, 0.4410859799869048, 0.9408530374651383], 
             191 -> RGBColor[
              0.8101035860121542, 0.8515783454987672, 0.9817072126714098], 14 -> 
             RGBColor[
              0.17925722738073346`, 0.3057410899147761, 0.9335198059608052], 
             185 -> RGBColor[
              0.2320502240219991, 0.3612298766540624, 0.9365262890192856], 32 -> 
             RGBColor[
              0.186006868294159, 0.3128353904667376, 0.9339041880256258], 122 -> 
             RGBColor[
              0.27792375203997, 0.40944586315061604`, 0.939138718576106], 187 -> 
             RGBColor[
              0.20348109888236326`, 0.33120191474515054`, 0.9348993196068165],
              193 -> RGBColor[
              0.22946131864603458`, 0.3585087729578423, 0.9363788546880667], 
             100 -> RGBColor[
              0.20579087184942513`, 0.3336296325815971, 0.9350308577602878], 
             180 -> RGBColor[
              0.3420328760182438, 0.47067341895996806`, 0.9430150103054538], 
             7 -> RGBColor[
              0.20849433214894747`, 0.33647114076567824`, 0.9351848158249345],
              175 -> RGBColor[
              0.5005712745154292, 0.6054253369873833, 0.9538259508643026], 9 -> 
             RGBColor[
              0.19331350997927296`, 0.32051513414563226`, 0.9343202904603853],
              90 -> RGBColor[
              0.22727061882380845`, 0.3562062085462915, 0.9362540975740409], 
             174 -> RGBColor[
              0.19003317840134057`, 0.3170672976721906, 0.9341334804298378], 
             142 -> RGBColor[
              0.2619978835405132, 0.39270676559930323`, 0.938231763925273], 
             134 -> RGBColor[
              0.24687317251219526`, 0.37680973534647483`, 0.9373704340072151],
              105 -> RGBColor[
              0.20575656042090384`, 0.333593569094751, 0.9350289037751928], 
             16 -> RGBColor[
              0.1871756577266932, 0.3140638622658612, 0.9339707488547396], 
             139 -> RGBColor[
              0.28566810415648325`, 0.4175856682453557, 0.9395797479723991], 
             146 -> RGBColor[
              0.24540381361353808`, 0.37526534598125116`, 0.9372867561916584],
              126 -> RGBColor[
              0.1796655907243716, 0.3061703056806712, 0.9335430616491059], 
             198 -> 
             RGBColor[
              0.34562348099972906`, 0.47378342052587685`, 0.9432438004798267],
              40 -> RGBColor[
              0.5058302216121423, 0.609694787153362, 0.9542399544439137], 104 -> 
             RGBColor[
              0.36710024085613885`, 0.49238551046016216`, 0.9446122806267241],
              181 -> RGBColor[
              0.43817293033743376`, 0.5539451018716196, 0.9491409695533606], 
             127 -> RGBColor[
              0.874787420357395, 0.9029957597937702, 0.9879191991572792], 76 -> 
             RGBColor[
              0.26424845016803866`, 0.3950722538189983, 0.9383599303652956], 
             172 -> RGBColor[
              0.8693407441384133, 0.4995886600246006, 0.2126870529687101], 84 -> 
             RGBColor[
              0.181234979779358, 0.3078198330824752, 0.9336324360340843], 184 -> 
             RGBColor[
              0.1818088839913312, 0.30842304279688765`, 0.933665119029941], 
             151 -> RGBColor[
              0.9939031817563573, 0.9917468232222412, 0.7507035865643902], 35 -> 
             RGBColor[
              0.18077756667952594`, 0.30733906291288604`, 0.933606387034731], 
             36 -> RGBColor[
              0.18255152448721731`, 0.309203605044191, 0.9337074113075435], 
             34 -> RGBColor[
              0.4300571649791395, 0.5469156338284925, 0.9486238401612196], 38 -> 
             RGBColor[
              0.18112444186066054`, 0.30770365072141526`, 0.9336261410631407],
              54 -> RGBColor[
              0.988392764379178, 0.9725082101217492, 0.4094085107659739], 60 -> 
             RGBColor[
              0.18098071777705174`, 0.3075525875969092, 0.9336179561892], 87 -> 
             RGBColor[
              0.21670300720810273`, 0.3450989787129095, 0.9356522877259069], 
             141 -> RGBColor[
              0.34381589363766235`, 0.47221777920483715`, 0.9431286226115025],
              67 -> RGBColor[
              0.2558901091184015, 0.3862871074263986, 0.9378839352075763], 
             133 -> RGBColor[
              0.24912319227677354`, 0.3791746487785393, 0.937498569304202], 
             98 -> RGBColor[
              0.19250116414799295`, 0.31966130717125646`, 0.9342740285670519],
              3 -> RGBColor[
              0.4186929718519593, 0.5370725409226834, 0.947899723824117], 27 -> 
             RGBColor[
              0.26652048668465833`, 0.39746030825340095`, 0.9384893194837403],
              163 -> RGBColor[
              0.2817626744925139, 0.41348081404998144`, 0.9393573395306015], 
             85 -> 
             RGBColor[
              0.2704719529099895, 0.40161354979365305`, 0.9387143496396024], 
             83 -> RGBColor[
              0.9263859833659136, 0.9441390533310817, 0.9928407161596127], 28 -> 
             RGBColor[
              0.1792907180836107, 0.3057762907669333, 0.933521713206789], 44 -> 
             RGBColor[
              0.8987739036289236, 0.6332377629819576, 0.2372468027203504], 
             189 -> RGBColor[
              0.19443151506714343`, 0.3216902283786009, 0.9343839591961993], 
             15 -> RGBColor[0.178927, 0.305394, 0.933501], 80 -> 
             RGBColor[
              0.22179319725678925`, 0.3504490911907685, 0.9359421665189183], 
             112 -> RGBColor[
              0.9414109245622558, 0.9558249439861124, 0.9840602016246193], 
             169 -> RGBColor[
              0.19209300288846856`, 0.31923230380857776`, 0.9342507843871425],
              69 -> RGBColor[
              0.24981404640376637`, 0.37990078026869034`, 0.9375379124247071],
              20 -> RGBColor[
              0.1823235017276304, 0.3089639386663871, 0.9336944257487145], 8 -> 
             RGBColor[
              0.28326421471662644`, 0.41505902802867256`, 0.939442850025035], 
             116 -> RGBColor[
              0.24062773125074222`, 0.3702453805968408, 0.9370147653666777], 
             97 -> RGBColor[
              0.21679935925455723`, 0.3452002508228058, 0.9356577748324124], 
             118 -> RGBColor[
              0.39086743560945575`, 0.5129714599815431, 0.9461267052599003], 
             178 -> RGBColor[
              0.1836473816366038, 0.3103554203895525, 0.9337698187510258], 81 -> 
             RGBColor[
              0.30602988251049323`, 0.4389871883067331, 0.9407393211271083], 
             166 -> RGBColor[
              0.8037293520346596, 0.846598745469576, 0.9810718885991364], 125 -> 
             RGBColor[
              0.2642831104182927, 0.3951086839396021, 0.9383619042152723], 95 -> 
             RGBColor[
              0.24919784069125972`, 0.37925310899514714`, 0.9375028204209744],
              157 -> RGBColor[
              0.20642492465234524`, 0.3342960622787358, 0.9350669661294171], 
             74 -> RGBColor[
              0.34593054718585675`, 0.47404938582270545`, 0.9432633664656788],
              19 -> RGBColor[
              0.35121665541737046`, 0.47862794708531764`, 0.9436001926078689],
              156 -> RGBColor[
              0.8187176743057581, 0.14487782361704554`, 0.16555737209477062`],
              167 -> RGBColor[
              0.19933380464903927`, 0.32684284555228516`, 0.9346631373356007],
              33 -> RGBColor[
              0.9926235425767636, 0.9912176595362523, 0.7719105193703001], 43 -> 
             RGBColor[
              0.18974733652345127`, 0.3167668597351072, 0.9341172021577572], 
             140 -> RGBColor[
              0.9937232399115826, 0.9889829697856952, 0.5581915839279488], 
             186 -> RGBColor[
              0.18306798401191893`, 0.3097464367500775, 0.933736822913442], 
             117 -> RGBColor[
              0.1853227778630534, 0.31211636804980714`, 0.9338652300875955], 
             4 -> RGBColor[
              0.33430755049502603`, 0.4639821302779076, 0.9425227593943515], 
             106 -> RGBColor[
              0.18503007033382515`, 0.31180871387785897`, 0.9338485608268279],
              65 -> RGBColor[
              0.95633856953826, 0.8643818842404721, 0.284884016735784], 53 -> 
             RGBColor[
              0.631783197735858, 0.7119490872875069, 0.9641554341053266], 2 -> 
             RGBColor[
              0.18237351643808017`, 0.30901650729818564`, 0.9336972740124846],
              147 -> RGBColor[
              0.24952468470268496`, 0.3795966427742623, 0.9375214337039027], 
             94 -> RGBColor[
              0.19041076970754647`, 0.3174641700756846, 0.9341549836961299], 
             23 -> RGBColor[
              0.22363768830217948`, 0.3523877682269605, 0.9360472075552733], 
             194 -> RGBColor[
              0.2015219494351241, 0.32914272445885284`, 0.9347877489440981], 
             129 -> RGBColor[
              0.4544709331932017, 0.5679990031052896, 0.9501967631243022], 99 -> 
             RGBColor[
              0.5518206973838005, 0.647031927232117, 0.9578604931653224], 25 -> 
             RGBColor[
              0.17953882470990998`, 0.3060370665620425, 0.9335358425121159], 
             138 -> RGBColor[
              0.2218736173884548, 0.35053361784807985`, 0.9359467463264457], 
             124 -> RGBColor[
              0.2260372839021752, 0.3549098953457044, 0.9361838609748094], 
             197 -> RGBColor[
              0.20070591566211698`, 0.3282850212238928, 0.9347412770279392], 
             164 -> RGBColor[
              0.19517315909830985`, 0.32246974327830424`, 0.9344261947266101],
              152 -> RGBColor[
              0.20018563595199287`, 0.32773817426091345`, 0.9347116478681324],
              17 -> RGBColor[
              0.19146922694525287`, 0.31857667574257903`, 0.9342152612699701],
              149 -> 
             RGBColor[
              0.1855038424012835, 0.31230667835964177`, 
               0.9338755414451867]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw1Vnk41Iv7HWbGjH3MjDGYYWbMlDYVokV9jgp1K023DRVaCFlSpNQNyVKW
Fl/LlZIoW4UWZQltV6QUkeVmyfKlBRcVruHn9zy/3/s87/P++55z3uecV7jP
53cXeRKJ9Gqm/3fGekx5W4yIkCVkxxsVNBLRRZalFQGTxDcd32MF2jz0XpOr
v7RJhDe70im2SUpoep1wcdN5AY5tNt6jayeHpes66XM+inC+w/BFyDYNqPW1
2xv0aiBKJ29pnw8Tr0ak8AqeJOZrkaJlIg64Z+vn0g9SkK6Q4KLfysaVTWu6
+R6KUOnNqZc+6CGyKvurUsViqEdeiU7LZaBLalwcfEqIMaqPLGt2N+E2Ry32
mx8blaz4/r13GSjbUW47lscHbbS3qOQoCfPOLk8KVZVg8Gno3CM6Oki49uhJ
nNsshB73NjBeQcWr7/Z2O1ZOEJHZHvPxmYv2+Hm/jNgS3Fd2etcRykJOgt7w
ugQqnK3BjfT5Tlx3nrfyUb8GJi7nPDZPlMNIwJsfweMCZFQpX/B/pofUBgVO
tzoZUgMFd5cUBritRZWVWgbQiFIOrxjVxXHPOb6txDBxpGr77AsdNJTnnH9+
rYcE/1NBRy3TpwjS/9Vfnkadl0ly2EGxcNyjSEdU4PdfG0RakAjubaVEG+DG
mRf2C4vVUa0oXLQjk4fdSmUfhRU6mN3SdkJvqRjSJ663vtHV4FHydu2/m8Ro
yquPj8xnoWM8gnJzkS4Sgl9nZhfL45XAaZ10KwX5bcoXqQGNRHl7juHnIRbu
lOcl7lugjkqqzcuqv3kY6BSQIrLlQGzYdj8mVYT/35NtnnQqYZkeat4Nya84
3Uncupw1Oi3lQ2VT6ZeNEVwwxqtG7iyoI1zirDavv0IGxQx9BS/puGz0ZWnG
52Eivus0mXdcHxbaqV2RD+Xg9DI6a59IFXSDFR5BbhPEfFuzwiWBYjBPRh0s
Wc9Cn7+DV/d/PhPl9dqUvB/ysKEYD31KZqNY6b4ut4YJ1WrrhqRd2ggVlnn6
16ghOjTwgC5LgEI4DZA19PH5zYUHgX76SA4MjbFi85FhXjW6bLcBIoN7ez2U
uTjFMuGLJwWgL+hX35dOAT07Z2VNqj4e2PtHOtnM6PfBbWf2SQkUK4eIAEU2
xKZe/gHSSWLrH5m/fC/rwMAoc5Z/rQA268KdtzST0e1Q/H40kY/HmTK79jQK
aviRg/n908QXfX7H1jc0JLM7fX7Jpokbeea3Q0uZqLPd5drcqojDLY6fSCtr
iNjw6gt7TRj4sTHF8dskC40mxxcUciQwM58g152Uh/PUO2vZxreErVrM0WdU
KvyKattbcseJ2o1TFbGX2Xjw4kyCh0SC9xdXyW1lKqFwFnjuMXyURn7109IZ
JK5VZR3dHDSDa4XLxYBoMug7XZNGRnmgDBTHdVZS8XHsjxe5ViRETZ3Ruzqo
i5Ink6zpdHkYhdT+dT9ZE43LvS6EH+cj6K6vxVllBry74/0edQkxXberaucM
zhvCYV7gLH2wacstJDl9BNnVUr/7hQjI2JTrLWPgwfTwjq/RQhwxvXJX/SAX
kW9d2vacEUM0eGvyaZ8GvnhaHRNYaWA8QC9gi9UkIXMstU9aIcLjtEs7DeUZ
KL+W/XRTlghf9+qENB3SRFjyvZFDpWzE25evV3zFQtCC2ccFmTO+FPLPturf
ebDT4rs35PwgXgurljnXssDacCh4F4+MwjjV1JR/tGFUuXAlw1uEV8fSczV2
sTGPylQhnskh41EAS0LXhtkRskmyvQp+gqedc1IDziyz1/cDeol9GV3Xey05
yFSgtBxiqoFjaq0T5/+DWLlH2+nLFhH6Qi2eGYwMEbq/1Mp6aWJ4R3W6tHax
UdBDL8mPVsXqW91M0oZhgjP7CHfskgE4+kvO1uSxcOC6OG/V0REiSXGVg+Ui
GgpiLAa5Lip4l5BoHl9eR2TqD1i67xLhUYKYt5cqhzqXBuqTCVXomI1PfBBP
Eb9WH7z90nbmvh1eB8e6tRKc9Yui76xQw1SJasjy3SSMbXFjV4Yx0DB0eV2T
PRs5LgEy01I+ypmGw9fms0E6+8JoyEsO1ntKDO+G6OBG2tLCkLnqEF/5U9Vj
ht89nlGFsjA5pI91eGjGaaN7G2EhV6uH80VH3p35nQ+zq1EljkUsjF/cfz/d
SQ0MU9uXq3/RcL1pgXhzSgXxn44TzSf8hFDUOuQhfMJBo6vV96Ueegj8U6Gi
1EwXA94x9s2VYtjscma+MuLAzjJqVLpEjFO9WnZ+u9m4dcG0+59ECgrdespW
DZCgm3fyTXEDBWHGfpophRw0RBj7qa4XwDnn16w/KquJD4V7HQ5fHSYel4xu
dY2lILDeVvxoCxfBA1aDBk9ZYDr4yjVHUFDWGtVY9omLcdlviRS7WfDwPHAu
bIgMw+EXo4GDY8Tg11n3bFLloPung0fpewXoWN0OTrytBbtZjhV7SxTBlt4K
K1neQeQo2BwcpgnR73A6TGWOArq59Gfb63lwU34avbhTAZaX/IZlTmSs2/X4
+5wZ/74XKmPmqKljlYv1p6bDw8Tz5x32FXQKHPR9J8Nms5Fwc/wqdcZf5J8O
nEuxpcLw0Gf3E8coyKrla48QOvhVFXi+LJGKlM8ugRsdtSBdc9RQzbyDaFsc
eZoBTZwuDB6xNBKglmaiflBVCZfyL3yyWKUGyZ73yglUNkKNNBb3fBCCGdPP
W6esDGtpX1dLhgRKpRrfc11m+NncXPlmjwTfSr5mLbHmwLBgW7R7Ag/ZG8dk
cU4ywpf2co7xN3lEhpvk1GaPEr1RRf+Nj+TBerXcDcY8LsK9HPb/raMPXw+T
Fc5XdaEnSFg3PU5FuK7esZhMLp48vLxlWp+GvsRTR7xucKC4ol9ww0IPZeKI
imL2DyIWzsKsASHclUQ/vylScUkia+/J58zkQvJreyMqAn/aup9InPlPrBNs
Np5URFh2V1znfQO8WE6vMNzCgof+IvPK83pQuJbYOqebjWhiy1bM5PcBaQFT
WsGDv8X2fVu36sFWWht+ZekQYTNSQF17UQTjDlnXx0kyGj0d9mfUG+BDfO4B
KZcN07WxnLhbclDbl+2f9JSNpLBCcXiIBAF5rMmn+gzEnY2aE1ZMxRVRF/eN
mjI2o27tzZYZnoNouvLnqNide3OiMUcJjCPF2r7MPsL/9EGT4g88/OZlF2Rx
mYxtlzq1G8QibF+SlFnJ4CDiikZORIYA+SoFjQ3TinD65rp9zFITDUUdJXN7
VLA2yDI3FmIUVx82llpoosP9X5PGLUK4GrZObfxbCzZknwTZJzUkr5m81XX0
J9ETP6RlWs7H0GEMGmVxkObiltY7xcBkQER+G2mC4Kal9xgVasBzSSz1Xj8N
H6gr0/I1x4lIpJ56LyUj5KbsEGW7Gj7w1ixr0h4kxnzcLWcfHSbavmjVtN0h
415af5voowrW+LdUqt1ggZ5RvttfR4JF7RQbx2/K+FEVRx62EiOQeoA2JWXi
4tnxSwbtLcS/66vXtdTSsfCdwEb4X2Vo/pWyyfUSC1PnxjVHZvTqjAtfePcg
CfzA5rUFSlw4PrI1ZxrS8fa380HF8Rp4XPJ61c0LUwRfknni9cw/a2GxttmV
/g9hdvrBrcNNVHy65+H5qIeGVW7epnWxBvAd13pI6eBgPtPJQW3uKHH9qzU/
7p0KDB57VycKqLhoTXn5+0QNQeoyHfi8kIrb18xOLK5jIpCb3Dl/KRO3owIz
je7Iw2fD6gDadT3c8EksHpzHAT0FRUk79XFmsclyneJJom9pTcTD5Qzs/3nM
jLmIAcPx2qmj+RKI9rL9yffkIVvJ2Rs3yUOK1V8ts1//JN4O5oY8ThHjeMFE
9W/KUwRtorm2P0AeC3Pze30cdNBCen4xoFyETL2989McWZC/QqtLTZSg03d+
C/sBA6Tcii+mj9uIRK+QslWzmZDPjXm+liNAhd6pkdPbFXCXXeKqJVGEUavh
yzplNnTPbbBLPqiAw+M7v6qWa6Lp/P7nlAwx/v3Yf6bdWBGLlygt8r4tgDcj
7457CAU0qiMt44kQx9S9XM9GThC66RHLaZNiLLuT+DCtgoEiSRlxTlEJ9R4b
65/O00J4v+PX73f5+Ht9d6rPjE9J1/f38kZV8EBRSbf6Yw/xP3H5XR4=
         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 11}], {
             RGBColor[
             0.19143609648975546`, 0.318541853533259, 0.9342133745395418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 35}], {
             RGBColor[
             0.1803467482579951, 0.30688624543639154`, 0.9335818525629636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 86}], {
             RGBColor[
             0.19100632204633058`, 0.3180901333439459, 0.934188899520783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 94}], {
             RGBColor[
             0.18516334977200538`, 0.3119487990177908, 0.933856150893663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 174}], {
             RGBColor[
             0.1849745541189024, 0.31175036281604385`, 0.9338453992605169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 196}], {
             RGBColor[
             0.20645103349834157`, 0.33432350433127433`, 0.935068452989572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 16}], {
             RGBColor[
             0.1847745870823867, 0.3115401847820234, 0.9338340114336121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 52}], {
             RGBColor[
             0.1839811911872139, 0.31070627539199164`, 0.933788828711106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[
             0.1829598466238134, 0.3096327774988722, 0.9337306646491643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 78}], {
             RGBColor[
             0.1826523965739446, 0.3093096280030011, 0.9337131558236558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 80}], {
             RGBColor[
             0.20208335684743473`, 0.32973279924447707`, 0.9348197202657014]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 82}], {
             RGBColor[
             0.19716931432443496`, 0.3245678289845131, 0.934539872813691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 98}], {
             RGBColor[
             0.18743734029303655`, 0.314338907234721, 0.9339856512897682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 100}], {
             RGBColor[
             0.19408219414375266`, 0.32132306993989135`, 0.9343640658863862]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 120}], {
             RGBColor[
             0.18815579892545653`, 0.3150940528103027, 0.9340265664460203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 124}], {
             RGBColor[
             0.20420540017012767`, 0.331963201321945, 0.9349405674936471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 187}], {
             RGBColor[
             0.1929273076602217, 0.3201092110216681, 0.9342982968096505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 5}], {
             RGBColor[
             0.38651352623245844`, 0.5092003225130362, 0.945849278004409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 10}], {
             RGBColor[
             0.3183216992072676, 0.4417413182340497, 0.9418115251184348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 27}], {
             RGBColor[
             0.3426067292683088, 0.4672664245880422, 0.9431945216539286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 29}], {
             RGBColor[
             0.312801857714541, 0.4359396148470296, 0.9414971783112978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 49}], {
             RGBColor[
             0.42052372581365627`, 0.5386582479879358, 0.9480163778476842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 53}], {
             RGBColor[
             0.5252380847939087, 0.6245108141050952, 0.9560275789647218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 62}], {
             RGBColor[
             0.30929718741563983`, 0.43225598415395333`, 0.9412975925224704]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 68}], {
             RGBColor[
             0.6898421419054424, 0.7085746089319662, 0.625429383133753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 71}], {
             RGBColor[
             0.3912157938817601, 0.5132731904080172, 0.9461489023409704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 75}], {
             RGBColor[
             0.4604176361342196, 0.5718866537552251, 0.9509246758011038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 118}], {
             RGBColor[
             0.40478020373070756`, 0.5250220004521133, 0.9470132145420087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[
             0.4349086817945046, 0.5511177738496366, 0.9489329745226667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 127}], {
             RGBColor[
             0.6467401961046771, 0.7200341503582268, 0.9679094614906981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 129}], {
             RGBColor[
             0.4365819525225805, 0.5525357720139865, 0.9490482434742096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 139}], {
             RGBColor[
             0.3521805380042213, 0.47732910458401956`, 0.943739735898258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 141}], {
             RGBColor[
             0.38125443274481086`, 0.5046451600637603, 0.9455141732178098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 146}], {
             RGBColor[
             0.33204839273274867`, 0.4561689434519673, 0.9425932400078877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 155}], {
             RGBColor[
             0.545941520152503, 0.6408465029615011, 0.9579803382974005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 167}], {
             RGBColor[
             0.3090133882504993, 0.4319576932374843, 0.9412814305798589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 191}], {
             RGBColor[
             0.6143982789320568, 0.6943254432107253, 0.9648034682477634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 194}], {
             RGBColor[
             0.3101074606435417, 0.43310763269076813`, 0.9413437363841075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 195}], {
             RGBColor[
             0.4598624133064091, 0.5714358988511051, 0.9508809666262504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 34}], {
             RGBColor[
             0.38218235773708276`, 0.5054488820532, 0.9455732997777855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 40}], {
             RGBColor[
             0.42006888605358417`, 0.5368384587156347, 0.9483813569191326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 49}], {
             RGBColor[
             0.37833101513518963`, 0.5021130426655478, 0.9453278956328015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 53}], {
             RGBColor[
             0.483045374115442, 0.5879656087827072, 0.953339096749839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 54}], {
             RGBColor[
             0.661350157437102, 0.7182451701998284, 0.6759656350801627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 65}], {
             RGBColor[
             0.6453230600166431, 0.6641820072591899, 0.6137033880650677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 69}], {
             RGBColor[
             0.2920607984493962, 0.42194145527329896`, 0.9400303359095292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 86}], {
             RGBColor[
             0.26820213237561147`, 0.3968644845029512, 0.9386716201723606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 92}], {
             RGBColor[
             0.28937728391046563`, 0.41912091134823404`, 0.9398775137264412]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 118}], {
             RGBColor[
             0.3625874930522409, 0.48847679512972536`, 0.9443247323271259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 119}], {
             RGBColor[
             0.5905667103712094, 0.4124559324961789, 0.5674982858332491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 123}], {
             RGBColor[
             0.39271597111603795`, 0.5145725685272486, 0.946244492307784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 139}], {
             RGBColor[
             0.30998782732575464`, 0.44078389926163164`, 0.9410512536833753]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 146}], {
             RGBColor[
             0.289855682054282, 0.41962373812957937`, 0.9399047577930049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 171}], {
             RGBColor[
             0.3210288697535419, 0.4523887348957585, 0.9416800247158792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 182}], {
             RGBColor[
             0.33757022299890055`, 0.4668080932140755, 0.9427306540012304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 191}], {
             RGBColor[
             0.57220556825359, 0.6577802378883374, 0.9621149860328806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 195}], {
             RGBColor[
             0.41766970262794245`, 0.5348906935287172, 0.9481924844113676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 196}], {
             RGBColor[
             0.28364684382762245`, 0.41309785549027966`, 0.9395511736411497]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 199}], {
             RGBColor[
             0.6647841302718416, 0.7281451631679503, 0.8353642944923663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 10}], {
             RGBColor[
             0.28614225358776674`, 0.41386909982440245`, 0.9397610792987268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 27}], {
             RGBColor[
             0.31042728364880795`, 0.439394206178395, 0.9411440758342206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.28062241209504013`, 0.4080673964373824, 0.9394467324915896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 30}], {
             RGBColor[
             0.28195013969393246`, 0.40946292232661013`, 0.9395223446141496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 42}], {
             RGBColor[
             0.2785521364098815, 0.40589140542922086`, 0.9393288333540183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 68}], {
             RGBColor[
             0.6576626962859415, 0.680702390522319, 0.6233789373140448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 71}], {
             RGBColor[
             0.35903634826225916`, 0.48540097199837007`, 0.9440984565212622]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 73}], {
             RGBColor[
             0.2859066569179567, 0.41362147278674055`, 0.939747662416915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 75}], {
             RGBColor[
             0.42823819051471873`, 0.5440144353455778, 0.9488742299813958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 76}], {
             RGBColor[
             0.3092912653904981, 0.4382001789611937, 0.9410793812749982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 81}], {
             RGBColor[
             0.3301819815617254, 0.46015764620506105`, 0.9422690766559045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 87}], {
             RGBColor[
             0.28551854391053016`, 0.41321354140814925`, 0.9397255599553038]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 89}], {
             RGBColor[
             0.31092444547544634`, 0.4399167547800723, 0.9411723884647626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 107}], {
             RGBColor[
             0.28598353480448624`, 0.4137022763198226, 0.9397520404988222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 127}], {
             RGBColor[
             0.6145607504851762, 0.6921619319485797, 0.9658590156709901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 129}], {
             RGBColor[
             0.40440250690307966`, 0.5246635536043394, 0.9469977976545015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 141}], {
             RGBColor[
             0.34907498712530993`, 0.4767729416541131, 0.9434637273981017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 142}], {
             RGBColor[
             0.3081659820767354, 0.43701743485134614`, 0.9410152980549868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 147}], {
             RGBColor[
             0.30192938265782127`, 0.43046237343882565`, 0.9406601329443018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 155}], {
             RGBColor[
             0.513762074533002, 0.612974284551854, 0.9559298924776924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 157}], {
             RGBColor[
             0.28037950263265143`, 0.40781208319106244`, 0.939432899157059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 168}], {
             RGBColor[
             0.2818657379269033, 0.4093742107180814, 0.9395175380583785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 188}], {
             RGBColor[
             0.33376821355982345`, 0.4635149837324976, 0.9424883933217574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 197}], {
             RGBColor[
             0.27751999813753725`, 0.4048065626636409, 0.93927005460632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 44}], {
             RGBColor[
             0.8651034665131747, 0.43792568886884486`, 0.20749020660542072`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 45}], {
             RGBColor[
             0.7712380059237092, 0.5084025319316335, 0.5747836939863987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 58}], {
             RGBColor[
             0.8960048531020866, 0.6063661726923737, 0.5646755963969717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 77}], {
             RGBColor[
             0.8243760146987129, 0.18837030737786614`, 0.17097580524524553`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 83}], {
             RGBColor[
             0.8789095063816696, 0.593376334043407, 0.5852871633250518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 96}], {
             RGBColor[
             0.8839247435427675, 0.5973568467623975, 0.5851240708837279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 112}], {
             RGBColor[
             0.8864219769798407, 0.5992192793709223, 0.5808969060575552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 156}], {
             RGBColor[
             0.8250753518515919, 0.1937457191863889, 0.17164549129263085`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 166}], {
             RGBColor[
             0.8175811907160426, 0.5446061801126542, 0.5794027495448137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 170}], {
             RGBColor[
             0.7433204991907267, 0.48659316349091797`, 0.5720011378191884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 179}], {
             RGBColor[
             0.5999866512477183, 0.3681232043828395, 0.5612188243491484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 183}], {
             RGBColor[
             0.8839085682862255, 0.5140524144919886, 0.22270248687391753`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 192}], {
             RGBColor[
             0.6485736073804235, 0.40987019823777215`, 0.5644077418055113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 8}], {
             RGBColor[
             0.24587927343278695`, 0.3757650843971754, 0.9373138329249848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 16}], {
             RGBColor[
             0.19783499493782034`, 0.3252675015157697, 0.9345777823398371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 52}], {
             RGBColor[
             0.19704159904264756`, 0.32443359212573797`, 0.934532599617331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.2079174287175954, 0.335864778681537, 0.9351519620279711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 67}], {
             RGBColor[
             0.23219222063367448`, 0.36137912409603845`, 0.9365343755162554]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 79}], {
             RGBColor[
             0.20133607999592745`, 0.328947363893454, 0.934777163954505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.19486465596415276`, 0.32214548692407674`, 0.9344086259295095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 122}], {
             RGBColor[
             0.24320904209445873`, 0.37295850195814717`, 0.9371617672005202]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 125}], {
             RGBColor[
             0.2363887212836201, 0.36578991235264013`, 0.9367733600201034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 126}], {
             RGBColor[
             0.19407996143665954`, 0.32132072322317473`, 0.9343639387370202]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 137}], {
             RGBColor[
             0.266193356547354, 0.39571608733082725`, 0.9385219649126898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 179}], {
             RGBColor[
             0.2885173026234793, 0.4150519673878126, 0.9399444270163702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 192}], {
             RGBColor[
             0.3371042587561843, 0.4567989612427451, 0.9431333444727331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.3222839501803989, 0.4512119268537823, 0.9418428896396724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 26}], {
             RGBColor[
             0.28802321713859724`, 0.420061041312345, 0.9397138681726531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 61}], {
             RGBColor[
             0.24530237000143487`, 0.37515872231303415`, 0.9372809791280214]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 67}], {
             RGBColor[
             0.26957716191751396`, 0.4006730677275356, 0.9386633926163057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 79}], {
             RGBColor[
             0.2387210212797669, 0.3682413075249512, 0.9369061810545554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.24761466346370808`, 0.37758908934975655`, 0.9374126608199662]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 83}], {
             RGBColor[
             0.60482509904127, 0.6795990406798771, 0.9661417830923238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 122}], {
             RGBColor[
             0.2805939833782982, 0.4122524455896443, 0.9392907843005704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 125}], {
             RGBColor[
             0.2737736625674596, 0.4050838559841373, 0.9389023771201537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 137}], {
             RGBColor[
             0.3035782978311935, 0.4350100309623244, 0.94065098201274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 166}], {
             RGBColor[
             0.543496783375643, 0.6308288867491243, 0.9602573693120857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 170}], {
             RGBColor[
             0.4692360918503271, 0.5728158701273882, 0.9528557575864605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 179}], {
             RGBColor[
             0.32590224390731876`, 0.4543459110193097, 0.9420734441164204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 192}], {
             RGBColor[
             0.37448920004002384`, 0.4960929048742423, 0.9452623615727833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 198}], {
             RGBColor[
             0.31444384785817775`, 0.4444212242772747, 0.9413433252524308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 18}], {
             RGBColor[
             0.2081906159438856, 0.3361519157774386, 0.935167519636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 32}], {
             RGBColor[
             0.18966018913671598`, 0.3166752623061849, 0.9341122392430056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 39}], {
             RGBColor[
             0.22268787528916928`, 0.3513894545286635, 0.9359931171093048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 41}], {
             RGBColor[
             0.24200989921647753`, 0.37169812676333913`, 0.9370934777875921]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 57}], {
             RGBColor[
             0.18757656925487778`, 0.3144852457012422, 0.9339935801731742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 85}], {
             RGBColor[
             0.23189273144463124`, 0.36106434196964265`, 0.9365173200499939]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 88}], {
             RGBColor[
             0.20493816247527158`, 0.3327333809644648, 0.9349822972229003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 91}], {
             RGBColor[
             0.1897739422401799, 0.3167948240302888, 0.9341187173139652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 103}], {
             RGBColor[
             0.18719718779584008`, 0.3140864917336198, 0.9339719749603267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 117}], {
             RGBColor[
             0.1893181439211632, 0.3163157510977197, 0.9340927602739904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 121}], {
             RGBColor[
             0.20533326031636837`, 0.3331486538461075, 0.9350047974604558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 152}], {
             RGBColor[
             0.19674957296563292`, 0.32412665420327286`, 0.9345159691642588]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 159}], {
             RGBColor[
             0.22410281281265743`, 0.3528766435780701, 0.9360736957080549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 164}], {
             RGBColor[
             0.1942433345387914, 0.32149243871196825`, 0.9343732425934977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 178}], {
             RGBColor[
             0.18848044580793838`, 0.31543527726759235`, 0.9340450546057055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 200}], {
             RGBColor[
             0.19196359639909227`, 0.31909628938339796`, 0.9342434148790122]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 17}], {
             RGBColor[
             0.2047098267539144, 0.3324933856439975, 0.9349692938413614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 27}], {
             RGBColor[
             0.24223545662361712`, 0.37193520189940843`, 0.9371063229482464]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 29}], {
             RGBColor[
             0.2124305850698493, 0.3406083921583959, 0.9354089796056155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 30}], {
             RGBColor[
             0.2137583126687416, 0.34200391804762365`, 0.9354845917281754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 42}], {
             RGBColor[
             0.2103603093846907, 0.3384324011502344, 0.9352910804680441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 51}], {
             RGBColor[
             0.20007349461539067`, 0.32762030660597313`, 0.9347052615849112]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 62}], {
             RGBColor[
             0.2089259147709481, 0.3369247614653196, 0.9352093938167881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 71}], {
             RGBColor[
             0.2908445212370684, 0.4179419677193835, 0.9400607036352882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 73}], {
             RGBColor[
             0.2177148298927659, 0.346162468507754, 0.9357099095309409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 75}], {
             RGBColor[
             0.3600463634895279, 0.4765554310665914, 0.9448364770954216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 89}], {
             RGBColor[
             0.2427326184502555, 0.3724577505010858, 0.9371346355787884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 107}], {
             RGBColor[
             0.21779170777929543`, 0.3462432720408361, 0.9357142876128481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.3362106798778888, 0.4572045493253528, 0.9429600447685274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 130}], {
             RGBColor[
             0.2011228825880777, 0.32872327990030753`, 0.9347650226775253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 141}], {
             RGBColor[
             0.28088316010011916`, 0.40931393737512656`, 0.9394259745121276]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 142}], {
             RGBColor[
             0.23997415505154454`, 0.3695584305723596, 0.9369775451690128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 147}], {
             RGBColor[
             0.23373755563263043`, 0.3630033691598391, 0.9366223800583277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 149}], {
             RGBColor[
             0.2017271344819297, 0.32935838695252884`, 0.9347994339289696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 167}], {
             RGBColor[
             0.2086421156058076, 0.33662647054885053`, 0.9351932318741767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 168}], {
             RGBColor[
             0.21367391090171242`, 0.3419152064390949, 0.9354797851724044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 188}], {
             RGBColor[
             0.26557638653463256`, 0.3960559794535111, 0.9384506404357832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.20619097081485965`, 0.33405016196200843`, 0.935053642804476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 194}], {
             RGBColor[
             0.20973618799885002`, 0.33777641000213443`, 0.9352555376784253]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 197}], {
             RGBColor[
             0.20932817111234645`, 0.33734755838465436`, 0.9352323017203459]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 35}], {
             RGBColor[
             0.19186691491128627`, 0.3189946710097535, 0.9342379090113091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 70}], {
             RGBColor[
             0.19700340773557554`, 0.3243934506405365, 0.9345304246788922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 86}], {
             RGBColor[
             0.20252648869962175`, 0.33019855891730787`, 0.9348449559691285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 94}], {
             RGBColor[
             0.19668351642529655`, 0.32405722459115277`, 0.9345122073420087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 110}], {
             RGBColor[
             0.1915413157937571, 0.3186524456930539, 0.9342193666232466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 138}], {
             RGBColor[
             0.2124149402657507, 0.3405919484773504, 0.9354080886571665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 174}], {
             RGBColor[
             0.1964947207721936, 0.32385878838940574`, 0.9345014557088626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 182}], {
             RGBColor[
             0.27189457932291083`, 0.4001421676284322, 0.9389039897979983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 196}], {
             RGBColor[
             0.21797120015163274`, 0.34643192990463634`, 0.9357245094379176]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 33}], {
             RGBColor[
             0.9713628299392978, 0.9155481063306994, 0.5253098577893779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 44}], {
             RGBColor[
             0.9244380104653778, 0.7365581580535521, 0.25797799946440303`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 58}], {
             RGBColor[
             0.9553393970542898, 0.9049986418770809, 0.615163389255954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 68}], {
             RGBColor[
             0.9555467146303788, 0.8599776150331977, 0.2908341193259223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 77}], {
             RGBColor[
             0.883710558650916, 0.4870027765625733, 0.22146359810422783`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 96}], {
             RGBColor[
             0.9432592874949708, 0.8959893159471047, 0.6356118637427102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 99}], {
             RGBColor[
             0.7509614073428162, 0.7434552401786318, 0.618284844686889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 102}], {
             RGBColor[
             0.9596388825040008, 0.9082051910857141, 0.6078854818749925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 128}], {
             RGBColor[
             0.6907043727279983, 0.6939382045780004, 0.6137063255291655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 140}], {
             RGBColor[
             0.9719126786067074, 0.9144307614554209, 0.4184503900682022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 162}], {
             RGBColor[
             0.7007570533940699, 0.7026453313085301, 0.614346873451971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 172}], {
             RGBColor[
             0.9097214307201227, 0.6697336065748736, 0.2456981245885829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 31}], {
             RGBColor[
             0.37653388192589077`, 0.49031817539689215`, 0.9461000785422968]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 34}], {
             RGBColor[
             0.32558157650060693`, 0.44832121227099686`, 0.9422634355654279]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 36}], {
             RGBColor[
             0.20182875625464586`, 0.3294651978788461, 0.9348052211385899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 63}], {
             RGBColor[
             0.20638929458382937`, 0.3342586128176488, 0.935064937049725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 64}], {
             RGBColor[
             0.4253184848962721, 0.5299237138095665, 0.9499405811920143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 70}], {
             RGBColor[
             0.20607827017508945`, 0.33393170644397663`, 0.9350472246697668]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 97}], {
             RGBColor[
             0.21895267363831583`, 0.3474635207681535, 0.9357804029010244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 132}], {
             RGBColor[
             0.26083574153477407`, 0.39148528066721244`, 0.9381655816572811]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 138}], {
             RGBColor[
             0.2214898027052646, 0.35013020428079056`, 0.9359248886480409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 145}], {
             RGBColor[
             0.20564959648275716`, 0.3334811432138535, 0.9350228123371542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 153}], {
             RGBColor[
             0.2516813551580962, 0.3818634401637041, 0.9376442528958304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 185}], {
             RGBColor[
             0.22657810602203676`, 0.3554783336837818, 0.936214659994461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 22}], {
             RGBColor[
             0.18387332754707644`, 0.31059290386725735`, 0.9337826860363703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 48}], {
             RGBColor[
             0.19487547737670605`, 0.3221568609147874, 0.9344092421929455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 106}], {
             RGBColor[
             0.1821436488572793, 0.3087749018963175, 0.9336841833938165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 131}], {
             RGBColor[
             0.18037616802655143`, 0.3069171674784653, 0.9335835279752602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 176}], {
             RGBColor[
             0.20667251283261232`, 0.3345562931541938, 0.9350810659100094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 59}], {
             RGBColor[
             0.18157500733235693`, 0.30817722359966904`, 0.9336518001002019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.18941420148966015`, 0.3164167136926116, 0.9340982306104119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 114}], {
             RGBColor[
             0.1801710817898224, 0.3067016088404447, 0.9335718486174763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 167}], {
             RGBColor[
             0.18913040232451964`, 0.31611842277614255`, 0.9340820686678004]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 184}], {
             RGBColor[
             0.18036794199566558`, 0.3069085213984438, 0.9335830595149706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 186}], {
             RGBColor[
             0.18099749200595946`, 0.30757021837503873`, 0.933618911456721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 194}], {
             RGBColor[
             0.19022447471756204`, 0.31726836222942645`, 0.934144374472049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 52}], {
             RGBColor[
             0.18638226183152043`, 0.31322995287582944`, 0.9339255661322337]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 61}], {
             RGBColor[
             0.19725809150646825`, 0.3246611394316285, 0.9345449285428737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 67}], {
             RGBColor[
             0.22153288342254734`, 0.3501754848461299, 0.935927342031158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 80}], {
             RGBColor[
             0.20448442749174123`, 0.3322564767283148, 0.934956457686829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 82}], {
             RGBColor[
             0.19957038496874147`, 0.32709150646835083`, 0.9346766102348185]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 84}], {
             RGBColor[
             0.1842053187530256, 0.3109418476741682, 0.933801592444412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 100}], {
             RGBColor[
             0.19648326478805916`, 0.32384674742372915`, 0.9345008033075137]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 120}], {
             RGBColor[
             0.19055686956976303`, 0.31761773029414053`, 0.9341633038671477]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 125}], {
             RGBColor[
             0.22572938407249296`, 0.3545862731027316, 0.936166326535006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.19532837830452823`, 0.32263288850550587`, 0.9344350342307781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 30}], {
             RGBColor[
             0.20051771286008008`, 0.3280872081462052, 0.9347305591567843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[
             0.1971197095760292, 0.3245156912488159, 0.9345370478966529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 51}], {
             RGBColor[
             0.18683289480672916`, 0.31370359670455467`, 0.9339512290135199]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 73}], {
             RGBColor[
             0.20447423008410437`, 0.33224575860633554`, 0.9349558769595496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 87}], {
             RGBColor[
             0.2040861170766778, 0.33183782722774424`, 0.9349337744979385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 89}], {
             RGBColor[
             0.229492018641594, 0.35854104059966735`, 0.9363806030073972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 106}], {
             RGBColor[
             0.18824964863953902`, 0.315192694810219, 0.934031911048399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 107}], {
             RGBColor[
             0.20455110797063392`, 0.33232656213941764`, 0.9349602550414569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 130}], {
             RGBColor[
             0.18788228277941618`, 0.31480656999888906`, 0.9340109901061341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 131}], {
             RGBColor[
             0.18648216780881113`, 0.31333496039236675`, 0.9339312556298427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 142}], {
             RGBColor[
             0.22673355524288302`, 0.35564172067094113`, 0.9362235125976215]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 147}], {
             RGBColor[
             0.22049695582396892`, 0.34908665925842064`, 0.9358683474869365]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 149}], {
             RGBColor[
             0.1884865346732682, 0.31544167705111037`, 0.9340454013575784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 157}], {
             RGBColor[
             0.19894707579879906`, 0.3264363690106574, 0.9346411136996936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 168}], {
             RGBColor[
             0.2004333110930509, 0.32799849653767643`, 0.9347257526010131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 188}], {
             RGBColor[
             0.25233578672597107`, 0.38213926955209265`, 0.937696607864392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 189}], {
             RGBColor[
             0.19295037100619816`, 0.32013345206058996`, 0.9342996102330847]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 197}], {
             RGBColor[
             0.19608757130368493`, 0.3234308484832359, 0.9344782691489546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 24}], {
             RGBColor[
             0.24010747998138166`, 0.3696985635269072, 0.9369851378265305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 32}], {
             RGBColor[
             0.20453729510132862`, 0.33231204393799124`, 0.9349594684189844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 39}], {
             RGBColor[
             0.2375649812537819, 0.3670262361604698, 0.9368403462852835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 41}], {
             RGBColor[
             0.25688700518109014`, 0.38733490839514545`, 0.9379407069635708]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 85}], {
             RGBColor[
             0.24676983740924385`, 0.376701123601449, 0.9373645492259726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 103}], {
             RGBColor[
             0.20207429376045272`, 0.32972327336542606`, 0.9348192041363055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 108}], {
             RGBColor[
             0.2655472156605108, 0.39643733869807485`, 0.9384338931387406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 117}], {
             RGBColor[
             0.2041952498857758, 0.331952532729526, 0.9349399894499691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 133}], {
             RGBColor[
             0.2360954570926359, 0.3654816730938921, 0.9367566590582723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 152}], {
             RGBColor[
             0.21162667893024556`, 0.3397634358350792, 0.9353631983402376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 178}], {
             RGBColor[
             0.20335755177255102`, 0.3310720588993987, 0.9348922837816843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 33}], {
             RGBColor[
             0.6719200989970671, 0.734922803310785, 0.8577553559890845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 74}], {
             RGBColor[
             0.34857360130161363`, 0.4763386664540116, 0.9434317795367738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 85}], {
             RGBColor[
             0.31084430416368, 0.44012074843948534`, 0.9411572711237357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 88}], {
             RGBColor[
             0.28388973519432037`, 0.4117897874343075, 0.939622248296642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 93}], {
             RGBColor[
             0.291301712500707, 0.4195802455298239, 0.9400443494392029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 95}], {
             RGBColor[
             0.3002072480543151, 0.4289405280402324, 0.9405515065144217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 102}], {
             RGBColor[
             0.6601961515617699, 0.7275798880657995, 0.9403309800746991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 121}], {
             RGBColor[
             0.28428483303541713`, 0.41220506031595017`, 0.9396447485341975]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 140}], {
             RGBColor[
             0.6724699476644765, 0.7338054584355065, 0.7508958882679089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 159}], {
             RGBColor[
             0.30305438553170616`, 0.43193305004791277`, 0.9407136467817967]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 161}], {
             RGBColor[
             0.3175223229543551, 0.44713976959933127`, 0.9415375744146212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 162}], {
             RGBColor[
             0.4013143224518391, 0.5220200282886156, 0.9467923716516777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 164}], {
             RGBColor[
             0.2731949072578401, 0.40054884518181094`, 0.9390131936672395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 172}], {
             RGBColor[
             0.610278699777892, 0.48910830355495916`, 0.5781436227882895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 173}], {
             RGBColor[
             0.35948494367207134`, 0.4857895227952885, 0.9441270406240982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 180}], {
             RGBColor[
             0.3466247657178071, 0.47465068302264285`, 0.9433076014566613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 22}], {
             RGBColor[
             0.1854064647205249, 0.3122043282430629, 0.9338699959303249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 46}], {
             RGBColor[
             0.182651270158183, 0.3093084440686167, 0.9337130916759446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 47}], {
             RGBColor[
             0.189292245231432, 0.3162885299327404, 0.9340912853819239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 50}], {
             RGBColor[
             0.19303508907013, 0.32022249611721776`, 0.9343044348014965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 101}], {
             RGBColor[
             0.18925893509711914`, 0.3162535188695931, 0.9340893884190526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 135}], {
             RGBColor[
             0.18962988067563263`, 0.3166434061919189, 0.9341105132209843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 144}], {
             RGBColor[
             0.19040607844928842`, 0.31745923926581243`, 0.9341547165359123]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 23}], {
             RGBColor[
             0.2924706869731754, 0.4198762969529263, 0.9401450684047916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 55}], {
             RGBColor[
             0.34859095953566543`, 0.47635370128389704`, 0.9434328855880982]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 61}], {
             RGBColor[
             0.2843221054652073, 0.4113116211381439, 0.9396810187426589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 67}], {
             RGBColor[
             0.30859689738128643`, 0.43682596655264533`, 0.9410634322309431]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 83}], {
             RGBColor[
             0.6438448345050425, 0.715751939504987, 0.9685418227069613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 90}], {
             RGBColor[
             0.29428715223398993`, 0.42178551711259177`, 0.9402485134141754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 122}], {
             RGBColor[
             0.3196137188420707, 0.44840534441475405`, 0.941690823915208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 166}], {
             RGBColor[
             0.5825165188394155, 0.666981785574234, 0.9626574089267232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 170}], {
             RGBColor[
             0.5082558273140996, 0.6089687689524979, 0.9552557972010979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 175}], {
             RGBColor[
             0.43093748007980026`, 0.5463950813331377, 0.9490344400593063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 177}], {
             RGBColor[
             0.28934680274084895`, 0.4165928965590511, 0.9399671678191333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 179}], {
             RGBColor[
             0.3649219793710912, 0.49049880984441946`, 0.9444734837310578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 183}], {
             RGBColor[
             0.6488438964095984, 0.6364280199535685, 0.605957146255827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 192}], {
             RGBColor[
             0.4135089355037963, 0.532245803699352, 0.9476624011874208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.19949157754304903`, 0.3270086748672687, 0.9346721222685106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 72}], {
             RGBColor[
             0.22084536933385682`, 0.34945286394800523`, 0.935888189120893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 144}], {
             RGBColor[
             0.19348904144218293`, 0.3206996288424882, 0.9343302867175226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 176}], {
             RGBColor[
             0.2112886129989553, 0.33940810710667507`, 0.9353439459855744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 38}], {
             RGBColor[
             0.20238106508142, 0.3300457094741879, 0.9348366743092069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 43}], {
             RGBColor[
             0.2066925124128154, 0.33457731398103385`, 0.9350822048565153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 55}], {
             RGBColor[
             0.27975796086466953`, 0.40886517255793126`, 0.9393350247385799]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 60}], {
             RGBColor[
             0.2023092030396156, 0.32997017791193484`, 0.9348325818722366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 90}], {
             RGBColor[
             0.22545415356299398`, 0.354296988386626, 0.936150652564657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 111}], {
             RGBColor[
             0.2218869245410005, 0.3505476045091276, 0.935947504149097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 115}], {
             RGBColor[
             0.26933147945021957`, 0.39983427840692803`, 0.9386706585626268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 163}], {
             RGBColor[
             0.2527001813973467, 0.382934291138471, 0.9377022735429374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 165}], {
             RGBColor[
             0.21472043526896856`, 0.3430151699025583, 0.9355393831869255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 169}], {
             RGBColor[
             0.20786534559532402`, 0.33581003601776915`, 0.9351489959712078]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 175}], {
             RGBColor[
             0.36210448140880436`, 0.4789065526071719, 0.9449365792097879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 177}], {
             RGBColor[
             0.22051380406985302`, 0.3491043678330853, 0.9358693069696149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 39}], {
             RGBColor[
             0.25460473932666533`, 0.38493610227813213`, 0.9378107352994711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 41}], {
             RGBColor[
             0.2739267632539736, 0.4052447745128077, 0.9389110959777585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 55}], {
             RGBColor[
             0.29651273574071235`, 0.4264755032667358, 0.9402891843813024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 108}], {
             RGBColor[
             0.28258697373339425`, 0.41434720481573717`, 0.9394042821529283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 111}], {
             RGBColor[
             0.2386416994170433, 0.36815793521793205`, 0.9369016637918195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 115}], {
             RGBColor[
             0.28608625432626233`, 0.41744460911573256`, 0.9396248182053492]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 133}], {
             RGBColor[
             0.2531352151655193, 0.3833915392115544, 0.93772704807246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 163}], {
             RGBColor[
             0.2694549562733895, 0.40054462184727546`, 0.9386564331856598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 165}], {
             RGBColor[
             0.23147521014501135`, 0.3606255006113628, 0.9364935428296479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 175}], {
             RGBColor[
             0.3788592562848471, 0.49651688331597643`, 0.9458907388525104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 38}], {
             RGBColor[
             0.18033163328528526`, 0.30687035864172885`, 0.9335809917876283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[
             0.1846430806166806, 0.3114019631485748, 0.9338265223349365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 60}], {
             RGBColor[
             0.18025977124348086`, 0.3067948270794758, 0.9335768993506579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 111}], {
             RGBColor[
             0.19983749274486573`, 0.32737225367666856`, 0.9346918216275183]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 165}], {
             RGBColor[
             0.19267100347283378`, 0.3198398190700993, 0.9342837006653468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 58}], {
             RGBColor[
             0.6266794481836577, 0.6975908926125163, 0.9458012343118618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 67}], {
             RGBColor[
             0.2743361643394848, 0.4056750810112081, 0.9389344107639237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 80}], {
             RGBColor[
             0.25728770840867865`, 0.387756072893393, 0.9379635264195947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 82}], {
             RGBColor[
             0.2523736658856789, 0.382591102633429, 0.9376836789675842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 96}], {
             RGBColor[
             0.6145993386243387, 0.6885815666825401, 0.9662497087986179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 98}], {
             RGBColor[
             0.24264169185428053`, 0.372362180883637, 0.9371294574436615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 99}], {
             RGBColor[
             0.42230145847218425`, 0.5360474909140672, 0.9489226897427967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[
             0.24928654570499661`, 0.3793463435888073, 0.9375078720402794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 116}], {
             RGBColor[
             0.2667049754056552, 0.39765421759642916`, 0.9384998258434745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 120}], {
             RGBColor[
             0.2433601504867005, 0.3731173264592187, 0.9371703725999135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 122}], {
             RGBColor[
             0.285352985800269, 0.4172544588733168, 0.9395618024481885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 124}], {
             RGBColor[
             0.25940975173137165`, 0.3899864749708609, 0.9380843736475403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 125}], {
             RGBColor[
             0.2785326649894304, 0.41008586926780977`, 0.9391733952677717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 128}], {
             RGBColor[
             0.36204442385736635`, 0.48653045531343586`, 0.9443441705850733]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 136}], {
             RGBColor[
             0.2577972163446346, 0.3882915980387517, 0.9379925421427979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 137}], {
             RGBColor[
             0.3083373002531643, 0.4400120442459969, 0.9409220001603581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.5482557857976138, 0.6358309000327967, 0.9605283874597037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 170}], {
             RGBColor[
             0.4739950942722979, 0.5778178834110607, 0.9531267757340784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 187}], {
             RGBColor[
             0.24813165922146568`, 0.378132484670584, 0.9374421029635438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 192}], {
             RGBColor[
             0.37924820246199464`, 0.5010949181579147, 0.9455333797204014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 198}], {
             RGBColor[
             0.3192028502801486, 0.44942323756094715`, 0.9416143434000489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 29}], {
             RGBColor[
             0.2367156151308905, 0.36613349851238836`, 0.9367919761411093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 30}], {
             RGBColor[
             0.2380433427297828, 0.3675290244016161, 0.9368675882636692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 42}], {
             RGBColor[
             0.2346453394457319, 0.36395750750422684`, 0.936674077003538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 62}], {
             RGBColor[
             0.23321094483198931`, 0.3624498678193121, 0.9365923903522819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 71}], {
             RGBColor[
             0.3151295512981096, 0.44346707407337604`, 0.941443700170782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 73}], {
             RGBColor[
             0.2419998599538071, 0.37168757486174653`, 0.9370929060664348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 75}], {
             RGBColor[
             0.3843313935505691, 0.5020805374205839, 0.9462194736309155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 89}], {
             RGBColor[
             0.2670176485112967, 0.3979828568550783, 0.9385176321142823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 127}], {
             RGBColor[
             0.5706539535210267, 0.6502280340235855, 0.9632042593205097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 129}], {
             RGBColor[
             0.36049570993893, 0.4827296556793453, 0.9443430413040212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 141}], {
             RGBColor[
             0.30516819016116037`, 0.4348390437291191, 0.9408089710476214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 142}], {
             RGBColor[
             0.2642591851125857, 0.3950835369263521, 0.9383605417045067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 147}], {
             RGBColor[
             0.25802258569367165`, 0.38852847551383163`, 0.9380053765938214]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 149}], {
             RGBColor[
             0.2260121645429709, 0.35488349330652136`, 0.9361824304644635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 155}], {
             RGBColor[
             0.4698552775688525, 0.57104038662686, 0.953275136127212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 167}], {
             RGBColor[
             0.2329271456668488, 0.36215157690284305`, 0.9365762284096705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 168}], {
             RGBColor[
             0.23795894096275363`, 0.36744031279308736`, 0.9368627817078983]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 188}], {
             RGBColor[
             0.28986141659567377`, 0.4215810858075036, 0.939833636971277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 189}], {
             RGBColor[
             0.23047600087590087`, 0.35957526831600095`, 0.9364366393399698]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[
             0.23402121805989123`, 0.3633015163561269, 0.9366385342139192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 197}], {
             RGBColor[
             0.23361320117338766`, 0.3628726647386469, 0.9366152982558398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 97}], {
             RGBColor[
             0.19804503866908396`, 0.3254882707948695, 0.9345897440196007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 105}], {
             RGBColor[
             0.19252363925225727`, 0.3196849299308422, 0.9342753084909909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.20340607327822147`, 0.3311230580782995, 0.9348950470096511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 71}], {
             RGBColor[
             0.2853246797443417, 0.4121402643323634, 0.939746356828151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 73}], {
             RGBColor[
             0.21219498840003925`, 0.3403607651207339, 0.9353955627238038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 129}], {
             RGBColor[
             0.33069083838516217`, 0.4514028459383327, 0.9426456979613903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 141}], {
             RGBColor[
             0.2753633186073925, 0.40351223398810643`, 0.9391116277049905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 149}], {
             RGBColor[
             0.19620729298920309`, 0.32355668356550876`, 0.9344850871218325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 167}], {
             RGBColor[
             0.20312227411308098`, 0.33082476716183046`, 0.9348788850670395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 168}], {
             RGBColor[
             0.2081540694089858, 0.33611350305207477`, 0.9351654383652672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 189}], {
             RGBColor[
             0.20067112932213305`, 0.3282484585749883, 0.9347392959973388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 194}], {
             RGBColor[
             0.2042163465061234, 0.3319747066151143, 0.9349411908712882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 197}], {
             RGBColor[
             0.2038083296196198, 0.3315458549976343, 0.9349179549132087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 42}], {
             RGBColor[
             0.2061681954908564, 0.33402622365244206`, 0.935052345783467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 51}], {
             RGBColor[
             0.19588138072155636`, 0.3232141291081808, 0.934466526900334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 71}], {
             RGBColor[
             0.28665240734323405`, 0.41353579022159115`, 0.939821968950711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 73}], {
             RGBColor[
             0.21352271599893158`, 0.34175629100996163`, 0.9354711748463638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 76}], {
             RGBColor[
             0.23690732447147297`, 0.36633499718441476`, 0.936802893704447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 81}], {
             RGBColor[
             0.2577980406427003, 0.3882924644282822, 0.9379925890853533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 87}], {
             RGBColor[
             0.213134602991505, 0.3413483596313704, 0.9354490723847526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 89}], {
             RGBColor[
             0.2385405045564212, 0.3680515730032935, 0.9368959008942113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 106}], {
             RGBColor[
             0.19729813455436623`, 0.32470322721384515`, 0.9345472089352131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 107}], {
             RGBColor[
             0.21359959388546113`, 0.3418370945430438, 0.935475552928271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 130}], {
             RGBColor[
             0.1969307686942434, 0.3243171024025152, 0.9345262879929481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 131}], {
             RGBColor[
             0.19553065372363834`, 0.3228454927959929, 0.9344465535166567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 142}], {
             RGBColor[
             0.23578204115771023`, 0.3651522530745672, 0.9367388104844356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 147}], {
             RGBColor[
             0.22954544173879612`, 0.3585971916620468, 0.9363836453737505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 157}], {
             RGBColor[
             0.20799556171362626`, 0.3359469014142835, 0.9351564115865076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 168}], {
             RGBColor[
             0.2094817970078781, 0.3375090289413025, 0.9352410504878272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 176}], {
             RGBColor[
             0.22182699852969923`, 0.3504846184717214, 0.9359440914514059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 188}], {
             RGBColor[
             0.2613842726407983, 0.39164980195571875`, 0.938211905751206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 197}], {
             RGBColor[
             0.20513605721851214`, 0.33294138088686204`, 0.9349935670357687]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 34}], {
             RGBColor[
             0.48100947040442327`, 0.5889125969543878, 0.9524604831380885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[
             0.5188959987209247, 0.6203021736168226, 0.9552685402794356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 45}], {
             RGBColor[
             0.62150237913985, 0.702550504593909, 0.964065451798632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 64}], {
             RGBColor[
             0.5807463788000884, 0.6705150984929575, 0.9601376287646749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 65}], {
             RGBColor[
             0.7441501726839835, 0.7476457221603776, 0.6205905714253708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 132}], {
             RGBColor[
             0.4162636354385904, 0.5320766653506034, 0.9483626292299419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 138}], {
             RGBColor[
             0.3769176966090809, 0.4907215889641815, 0.9461219362207016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 153}], {
             RGBColor[
             0.4071092490619125, 0.522454824847095, 0.9478413004684911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 156}], {
             RGBColor[
             0.6753397250677327, 0.3878936918486643, 0.560927249104864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 182}], {
             RGBColor[
             0.43639733566624106`, 0.5502718081152633, 0.9496178373615334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 185}], {
             RGBColor[
             0.38200599992585305`, 0.49606971836717273`, 0.9464117075671216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 199}], {
             RGBColor[
             0.763611242939182, 0.811608878069138, 0.8422514778526693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 39}], {
             RGBColor[
             0.2190345544466123, 0.34754958268921615`, 0.9357850658919249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 57}], {
             RGBColor[
             0.1839232484123208, 0.31064537386179486`, 0.9337855289557946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 103}], {
             RGBColor[
             0.1835438669532831, 0.31024661989417246`, 0.9337639237429469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 117}], {
             RGBColor[
             0.1856648230786062, 0.31247587925827236`, 0.9338847090566107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 133}], {
             RGBColor[
             0.21756503028546625`, 0.3460050196226384, 0.9357013786649139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 152}], {
             RGBColor[
             0.19309625212307593`, 0.3202867823638255, 0.9343079179468792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 178}], {
             RGBColor[
             0.1848271249653814, 0.311595405428145, 0.9338370033883259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 44}], {
             RGBColor[
             0.9456987231028435, 0.812227711259105, 0.5045786610453252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 58}], {
             RGBColor[
             0.9766001096917556, 0.9806681950826337, 0.8617640508368762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 68}], {
             RGBColor[
             0.9768074272678445, 0.9356471682387506, 0.5374347809068445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 77}], {
             RGBColor[
             0.9049712712883817, 0.5626723297681262, 0.46806425968515003`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 96}], {
             RGBColor[
             0.9645200001324366, 0.9716588691526575, 0.8822125253236324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 99}], {
             RGBColor[
             0.772222119980282, 0.8191247933841846, 0.8648855062678112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 102}], {
             RGBColor[
             0.9808995951414665, 0.9838747442912669, 0.8544861434559147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 128}], {
             RGBColor[
             0.7119650853654641, 0.7696077577835532, 0.8603069871100877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 140}], {
             RGBColor[
             0.9931733912441731, 0.9901003146609737, 0.6650510516491244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 162}], {
             RGBColor[
             0.7220177660315357, 0.778314884514083, 0.8609475350328932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 172}], {
             RGBColor[
             0.9309821433575884, 0.7454031597804265, 0.49229878616950506`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 180}], {
             RGBColor[
             0.6673282092975037, 0.7309455392481101, 0.857462764837877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 40}], {
             RGBColor[
             0.4679436932956409, 0.5783052104909272, 0.9514318973025666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 45}], {
             RGBColor[
             0.5705500737145661, 0.6605535414680137, 0.960228808821763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 54}], {
             RGBColor[
             0.7092249646791587, 0.7597119219751208, 0.6790161754635967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 64}], {
             RGBColor[
             0.5297940733748047, 0.6285181353670621, 0.956300985787806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 65}], {
             RGBColor[
             0.6931978672586998, 0.7056487590344823, 0.6167539284485017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 132}], {
             RGBColor[
             0.3653113300133066, 0.4900797022247081, 0.9445259862530728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 138}], {
             RGBColor[
             0.32596539118379714`, 0.4487246258382862, 0.9422852932438326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 153}], {
             RGBColor[
             0.3561569436366287, 0.48045786172119975`, 0.9440046574916221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 182}], {
             RGBColor[
             0.3854450302409573, 0.5082748449893679, 0.9457811943846643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 185}], {
             RGBColor[
             0.3310536945005693, 0.45407275524127744`, 0.9425750645902526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 199}], {
             RGBColor[
             0.7126589375138983, 0.7696119149432428, 0.8384148348758003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 86}], {
             RGBColor[
             0.19143714046786142`, 0.31854295082044043`, 0.9342134339925504]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.1855941681935362, 0.31240161649428533`, 0.9338806853654305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 110}], {
             RGBColor[
             0.18045196756199675`, 0.30699683759618646`, 0.9335878446466683]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 174}], {
             RGBColor[
             0.18540537254043327`, 0.31220318029253835`, 0.9338699337322844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 63}], {
             RGBColor[
             0.1871120628164008, 0.3139970199829937, 0.9339671272186787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 70}], {
             RGBColor[
             0.18680103840766088`, 0.3136701136093215, 0.9339494148387204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 110}], {
             RGBColor[
             0.18133894646584242`, 0.3079291086618389, 0.9336383567830746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 138}], {
             RGBColor[
             0.20221257093783607`, 0.32986861144613544`, 0.9348270788169946]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 145}], {
             RGBColor[
             0.1863723647153286, 0.3132195503791984, 0.9339250025061079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 185}], {
             RGBColor[
             0.2073008742546082, 0.33521674084912667`, 0.9351168501634146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 45}], {
             RGBColor[
             0.47344467906469456`, 0.5697056609217193, 0.9542881258612889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 47}], {
             RGBColor[
             0.21605368220731502`, 0.34441649696749876`, 0.9356153096277022]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 50}], {
             RGBColor[
             0.21979652604601302`, 0.3483504631519761, 0.935828459047275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 97}], {
             RGBColor[
             0.22632286746697683`, 0.35521006177935477`, 0.9362001245363418]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 101}], {
             RGBColor[
             0.21602037207300215`, 0.3443814859043514, 0.9356134126648311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 105}], {
             RGBColor[
             0.22080146805015013`, 0.3494067209153274, 0.9358856890077321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 134}], {
             RGBColor[
             0.24135977409579584`, 0.37101480404118925`, 0.9370564541237432]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 135}], {
             RGBColor[
             0.21639131765151565`, 0.3447713732266772, 0.9356345374667627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 160}], {
             RGBColor[
             0.33951855272220766`, 0.4617555701348826, 0.9431015867680459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 43}], {
             RGBColor[
             0.1854358891920559, 0.31223525522826123`, 0.9338716716104489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 60}], {
             RGBColor[
             0.18105257981885614`, 0.3076281191591622, 0.9336220486261704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 90}], {
             RGBColor[
             0.20419753034223448`, 0.33195492963385337`, 0.9349401193185908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 111}], {
             RGBColor[
             0.200630301320241, 0.32820554575635497`, 0.9347369709030307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 165}], {
             RGBColor[
             0.19346381204820906`, 0.3206731111497857, 0.9343288499408593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 169}], {
             RGBColor[
             0.18660872237456455`, 0.31346797726499653`, 0.9339384627251416]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 41}], {
             RGBColor[
             0.2713842645263738, 0.40257244714637036`, 0.9387663044365115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 74}], {
             RGBColor[
             0.29899639389246113`, 0.42815658036720006`, 0.9404646551119514]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 85}], {
             RGBColor[
             0.26126709675452753`, 0.3919386623526739, 0.9381901466989133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 88}], {
             RGBColor[
             0.2343125277851679, 0.36360770134749604`, 0.9366551238718196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 108}], {
             RGBColor[
             0.2800444750057945, 0.41167487744929976`, 0.9392594906116811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 117}], {
             RGBColor[
             0.21869250923105948`, 0.34719007148075093`, 0.9357655869229098]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 133}], {
             RGBColor[
             0.2505927164379196, 0.38071921184511703`, 0.9375822565312131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 152}], {
             RGBColor[
             0.22612393827552923`, 0.3550009745863041, 0.9361887958131783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 159}], {
             RGBColor[
             0.25347717812255377`, 0.3837509639611013, 0.9377465223569743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 173}], {
             RGBColor[
             0.3099077362629189, 0.437607436708477, 0.9411599161992759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 178}], {
             RGBColor[
             0.21785481111783467`, 0.34630959765062364`, 0.935717881254625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 49}], {
             RGBColor[
             0.46409235069374777`, 0.5749693711032751, 0.9511864931575826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 53}], {
             RGBColor[
             0.5688067096740002, 0.6608219372204345, 0.9591976942746201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 54}], {
             RGBColor[
             0.7471114929956602, 0.7911014986375555, 0.6818242326049438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 64}], {
             RGBColor[
             0.5676806016913061, 0.6599077120294969, 0.959109042929153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.7310843955752011, 0.737038335696917, 0.6195619855898489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 69}], {
             RGBColor[
             0.37782213400795434`, 0.4947977837110262, 0.9458889334343104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 119}], {
             RGBColor[
             0.6763280459297676, 0.4853122609339061, 0.5733568833580303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 123}], {
             RGBColor[
             0.4784773066745961, 0.5874288969649759, 0.9521030898325651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 132}], {
             RGBColor[
             0.40319785832980803`, 0.5214692788871429, 0.94733404339442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 171}], {
             RGBColor[
             0.40679020531210003`, 0.5252450633334856, 0.9475386222406603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 182}], {
             RGBColor[
             0.4233315585574587, 0.5396644216518027, 0.9485892515260115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 191}], {
             RGBColor[
             0.6579669038121483, 0.7306365663260646, 0.9679735835576617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 195}], {
             RGBColor[
             0.5034310381865006, 0.6077470219664445, 0.9540510819361487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 196}], {
             RGBColor[
             0.3694081793861806, 0.4859541839280068, 0.9454097711659308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 199}], {
             RGBColor[
             0.7505454658303996, 0.8010014916056775, 0.8412228920171474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 74}], {
             RGBColor[
             0.31831841781976944`, 0.44846525260187575`, 0.9415650157902389]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 85}], {
             RGBColor[
             0.2805891206818358, 0.4122473345873495, 0.9392905073772007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.2536345517124762, 0.3839163735821717, 0.937755484550107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 108}], {
             RGBColor[
             0.29936649893310274`, 0.4319835496839754, 0.9403598512899686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 121}], {
             RGBColor[
             0.25402964955357293`, 0.38433164646381435`, 0.9377779847876626]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 133}], {
             RGBColor[
             0.2699147403652278, 0.4010278840797926, 0.9386826172095004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 140}], {
             RGBColor[
             0.6422147641826323, 0.7059320445833706, 0.7490291245213738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 151}], {
             RGBColor[
             0.6423047351050197, 0.7073139713016436, 0.8452851258395946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 152}], {
             RGBColor[
             0.2454459622028375, 0.3753096468209797, 0.9372891564914656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 159}], {
             RGBColor[
             0.27279920204986197`, 0.40405963619577695`, 0.9388468830352616]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 161}], {
             RGBColor[
             0.2872671394725109, 0.41926635574719545`, 0.9396708106680862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 173}], {
             RGBColor[
             0.32922976019022715`, 0.45791610894315266`, 0.9422602768775632]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 51}], {
             RGBColor[
             0.1924833774375055, 0.31964261221079154`, 0.9342730156402028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 71}], {
             RGBColor[
             0.2832544040591832, 0.40996427332420193`, 0.9396284576905798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 73}], {
             RGBColor[
             0.2101247127148807, 0.3381847741125724, 0.9352776635862325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 76}], {
             RGBColor[
             0.23350932118742207`, 0.36276348028702554`, 0.9366093824443157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 81}], {
             RGBColor[
             0.25440003735864936`, 0.3847209475308929, 0.9377990778252221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 87}], {
             RGBColor[
             0.20973659970745412`, 0.3377768427339811, 0.9352555611246214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 89}], {
             RGBColor[
             0.2351425012723703, 0.3644800561059042, 0.93670238963408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 106}], {
             RGBColor[
             0.19390013127031533`, 0.3211317103164559, 0.9343536976750818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 107}], {
             RGBColor[
             0.21020159060141025`, 0.3382655776456545, 0.9352820416681398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 130}], {
             RGBColor[
             0.1935327654101925, 0.32074558550512594`, 0.9343327767328169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 131}], {
             RGBColor[
             0.19213265043958744`, 0.3192739758986036, 0.9342530422565254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 142}], {
             RGBColor[
             0.23238403787365935`, 0.361580736177178, 0.9365452992243044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 147}], {
             RGBColor[
             0.22614743845474522`, 0.3550256747646575, 0.9361901341136192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 149}], {
             RGBColor[
             0.1941370173040445, 0.32138069255734725`, 0.9343671879842612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 157}], {
             RGBColor[
             0.2045975584295754, 0.3323753845168943, 0.9349629003263764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 168}], {
             RGBColor[
             0.20608379372382724`, 0.3339375120439133, 0.935047539227696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 176}], {
             RGBColor[
             0.21842899524564835`, 0.34691310157433214`, 0.9357505801912747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 188}], {
             RGBColor[
             0.2579862693567474, 0.38807828505832953`, 0.9380183944910747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 189}], {
             RGBColor[
             0.19860085363697447`, 0.32607246756682684`, 0.9346213968597675]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 197}], {
             RGBColor[
             0.20173805393446126`, 0.32936986398947277`, 0.9348000557756375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 60}], {
             RGBColor[
             0.18536402715025152`, 0.3121597236660082, 0.9338675791734785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[
             0.20850897767362986`, 0.33648653414069934`, 0.935185649865899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 111}], {
             RGBColor[
             0.2049417486516364, 0.33273715026320094`, 0.934982501450339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 115}], {
             RGBColor[
             0.25238630356085545`, 0.3820238241610014, 0.9377056558638687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 163}], {
             RGBColor[
             0.2357550055079826, 0.36512383689254435`, 0.9367372708441793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 165}], {
             RGBColor[
             0.19777525937960444`, 0.32520471565663167`, 0.9345743804881674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 169}], {
             RGBColor[
             0.19092016970595993`, 0.3179995817718425, 0.9341839932724498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 58}], {
             RGBColor[
             0.9296752902178356, 0.8016782468054864, 0.5944321925119014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 68}], {
             RGBColor[
             0.9298826077939246, 0.7566572199616033, 0.27010292258186963`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 77}], {
             RGBColor[
             0.8580464518144618, 0.3836823814909788, 0.2007324013601752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 96}], {
             RGBColor[
             0.9175951806585165, 0.7926689208755102, 0.6148806669986575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 99}], {
             RGBColor[
             0.7252973005063621, 0.6401348451070372, 0.5975536479428364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 102}], {
             RGBColor[
             0.9339747756675465, 0.8048847960141194, 0.5871542851309398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[
             0.6650402658915442, 0.5906178095064059, 0.5929751287851128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 143}], {
             RGBColor[
             0.8772182848102179, 0.7604919813860003, 0.611670932866671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 166}], {
             RGBColor[
             0.8512516278317916, 0.7399182542257667, 0.6091593456597434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 172}], {
             RGBColor[
             0.8840573238836684, 0.5664132115032791, 0.22496692784453026`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 198}], {
             RGBColor[
             0.6221986923143263, 0.5535105917539171, 0.5902453016000886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 64}], {
             RGBColor[
             0.6702869821102313, 0.7421560430065834, 0.9679059544483493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 112}], {
             RGBColor[
             0.8262269535061243, 0.8650081965468237, 0.9779469895534628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 132}], {
             RGBColor[
             0.5058042387487333, 0.6037176098642293, 0.9561309549136163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 134}], {
             RGBColor[
             0.478958077481094, 0.5755005922270049, 0.9546021057447607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 153}], {
             RGBColor[
             0.49664985237205533`, 0.594095769360721, 0.9556096261521655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 156}], {
             RGBColor[
             0.7648803283778755, 0.4595346363622902, 0.5686955747885385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 183}], {
             RGBColor[
             0.823713544812509, 0.7798413316678898, 0.6197525703698252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 47}], {
             RGBColor[
             0.1896200136619846, 0.31663303533497, 0.934109951309154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 50}], {
             RGBColor[
             0.1933628575006826, 0.3205670015194474, 0.9343231007287265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 101}], {
             RGBColor[
             0.18958670352767176`, 0.3165980242718227, 0.9341080543462827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 105}], {
             RGBColor[
             0.19436779950481975`, 0.32162325928279867`, 0.9343803306891837]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 135}], {
             RGBColor[
             0.18995764910618526`, 0.3169879115941485, 0.9341291791482143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 144}], {
             RGBColor[
             0.19073384687984102`, 0.31780374466804207`, 0.9341733824631423]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 50}], {
             RGBColor[
             0.2000038325739316, 0.3275470873835711, 0.9347012944347058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 101}], {
             RGBColor[
             0.19622767860092072`, 0.3235781101359464, 0.934486248052262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 105}], {
             RGBColor[
             0.2010087745780687, 0.32860334514692235`, 0.934758524395163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 134}], {
             RGBColor[
             0.22156708062371444`, 0.3502114282727843, 0.9359292895111742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 135}], {
             RGBColor[
             0.19659862417943424`, 0.3239679974582722, 0.9345073728541936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 144}], {
             RGBColor[
             0.19737482195309003`, 0.32478383053216575`, 0.9345515761691217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 72}], {
             RGBColor[
             0.23184751916348642`, 0.3610168209955353, 0.9365147452774683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 76}], {
             RGBColor[
             0.23737108877035865`, 0.36682244286689847`, 0.9368293043951907]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 81}], {
             RGBColor[
             0.2582618049415859, 0.3887799101107659, 0.938018999776097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 87}], {
             RGBColor[
             0.21359836729039067`, 0.3418358053138541, 0.9354754830754963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 104}], {
             RGBColor[
             0.28879698411440874`, 0.4154790711874804, 0.939955479525905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 106}], {
             RGBColor[
             0.1977618988532519, 0.32519067289632886`, 0.9345736196259569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 147}], {
             RGBColor[
             0.2300092060376818, 0.3590846373445305, 0.9364100560644943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 154}], {
             RGBColor[
             0.2711822856025334, 0.4002221046769836, 0.9388330865127945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 157}], {
             RGBColor[
             0.20845932601251194`, 0.33643434709676723`, 0.9351828222772515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 158}], {
             RGBColor[
             0.2634190473924112, 0.39349797793107355`, 0.9383384198388076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 176}], {
             RGBColor[
             0.2222907628285849, 0.3509720641542051, 0.9359705021421497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 53}], {
             RGBColor[
             0.5270688387556056, 0.6260965211703475, 0.956144232988289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 54}], {
             RGBColor[
             0.7053736220772657, 0.7563760825874686, 0.6787707713186126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 65}], {
             RGBColor[
             0.6893465246568067, 0.7023129196468301, 0.6165085243035178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 69}], {
             RGBColor[
             0.33608426308955985`, 0.46007236766093923`, 0.9428354721479792]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 92}], {
             RGBColor[
             0.33340074855062923`, 0.45725182373587436`, 0.9426826499648912]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 118}], {
             RGBColor[
             0.4066109576924045, 0.5266077075173656, 0.9471298685655758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 119}], {
             RGBColor[
             0.634590175011373, 0.45058684488381917`, 0.5703034220716992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 123}], {
             RGBColor[
             0.43673943575620155`, 0.552703480914889, 0.949049628546234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 127}], {
             RGBColor[
             0.6485709500663741, 0.7216198574234791, 0.9680261155142653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[
             0.4384127064842775, 0.5541214790792388, 0.9491648974977769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 139}], {
             RGBColor[
             0.3540112919659183, 0.4789148116492719, 0.9438563899218253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 141}], {
             RGBColor[
             0.3830851867065078, 0.5062308671290127, 0.9456308272413769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 146}], {
             RGBColor[
             0.3338791466944457, 0.45775465051721964`, 0.9427098940314549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 155}], {
             RGBColor[
             0.5477722741141999, 0.6424322100267535, 0.9580969923209677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 171}], {
             RGBColor[
             0.36505233439370555`, 0.4905196472833987, 0.9444851609543292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 191}], {
             RGBColor[
             0.6162290328937537, 0.6959111502759776, 0.9649201222713306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 195}], {
             RGBColor[
             0.46169316726810605`, 0.5730216059163575, 0.9509976206498176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 196}], {
             RGBColor[
             0.3276703084677861, 0.4512287678779199, 0.9423563098795996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 199}], {
             RGBColor[
             0.7088075949120052, 0.7662760755555905, 0.8381694307308162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 97}], {
             RGBColor[
             0.21027301783359342`, 0.33834065219542714`, 0.9352861093433454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 101}], {
             RGBColor[
             0.19997052243961871`, 0.3275120763204238, 0.9346993974718347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 105}], {
             RGBColor[
             0.2047516184167667, 0.33253731133139974`, 0.9349716738147356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 134}], {
             RGBColor[
             0.22530992446241244`, 0.3541453944572617, 0.9361424389307468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 135}], {
             RGBColor[
             0.20034146801813224`, 0.3279019636427496, 0.9347205222737662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 144}], {
             RGBColor[
             0.20111766579178803`, 0.32871779671664314`, 0.9347647255886942]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 73}], {
             RGBColor[
             0.19983789794558066`, 0.3273726795683112, 0.9346918447030995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 87}], {
             RGBColor[
             0.19944978493815407`, 0.3269647481897199, 0.9346697422414884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 106}], {
             RGBColor[
             0.1836133165010153, 0.31031961577219463`, 0.9337678787919488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[
             0.1999147758321102, 0.3274534831013933, 0.9346962227850067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 130}], {
             RGBColor[
             0.18324595064089247`, 0.3099334909608647, 0.933746957849684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 131}], {
             RGBColor[
             0.18184583567028742`, 0.3084618813543424, 0.9336672233733925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 147}], {
             RGBColor[
             0.2158606236854452, 0.3442135802203963, 0.9356043152304863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 157}], {
             RGBColor[
             0.19431074366027534`, 0.32156328997263306`, 0.9343770814432435]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 168}], {
             RGBColor[
             0.1957969789545272, 0.32312541749965207`, 0.934461720344563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 189}], {
             RGBColor[
             0.18831403886767445`, 0.3152603730225656, 0.9340355779766345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 197}], {
             RGBColor[
             0.1914512391651612, 0.3185577694452115, 0.9342142368925045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 66}], {
             RGBColor[
             0.18456752137294713`, 0.3113225455926782, 0.9338222193477858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 80}], {
             RGBColor[
             0.20369103159656846`, 0.33142256733828307`, 0.9349112749643229]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 82}], {
             RGBColor[
             0.1987769890735687, 0.32625759707831903`, 0.9346314275123124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 100}], {
             RGBColor[
             0.1956898688928864, 0.3230128380336974, 0.9344556205850076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 120}], {
             RGBColor[
             0.1897634736745903, 0.3167838209041087, 0.9341181211446418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 124}], {
             RGBColor[
             0.20581307491926143`, 0.333652969415751, 0.9350321221922685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 125}], {
             RGBColor[
             0.2249359881773202, 0.35375236371269986`, 0.9361211438124999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 187}], {
             RGBColor[
             0.19453498240935546`, 0.32179897911547406`, 0.934389851508272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 54}], {
             RGBColor[
             0.810087981057518, 0.842228648704628, 0.6867819724356502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 65}], {
             RGBColor[
             0.7940608836370591, 0.7881654857639895, 0.6245197254205552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 69}], {
             RGBColor[
             0.4407986220698122, 0.5459249337780987, 0.9508466732650168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 92}], {
             RGBColor[
             0.4381151075308816, 0.5431043898530338, 0.9506938510819287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 118}], {
             RGBColor[
             0.5113253166726569, 0.612460273634525, 0.9551410696826135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 119}], {
             RGBColor[
             0.7393045339916254, 0.5364394110009786, 0.5783146231887367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 123}], {
             RGBColor[
             0.5414537947364539, 0.6385560470320484, 0.9570608296632714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 127}], {
             RGBColor[
             0.7532853090466265, 0.8074724235406385, 0.9760373166313029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 129}], {
             RGBColor[
             0.5431270654645298, 0.6399740451963982, 0.9571760986148143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 139}], {
             RGBColor[
             0.4587256509461706, 0.5647673777664313, 0.9518675910388628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 141}], {
             RGBColor[
             0.4877995456867602, 0.5920834332461721, 0.9536420283584146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 146}], {
             RGBColor[
             0.438593505674698, 0.543607216634379, 0.9507210951484925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 155}], {
             RGBColor[
             0.6524866330944523, 0.728284776143913, 0.9661081934380052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 171}], {
             RGBColor[
             0.4697666933739579, 0.5763722134005581, 0.9524963620713668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 182}], {
             RGBColor[
             0.48630804661931654`, 0.5907915717188752, 0.9535469913567178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 191}], {
             RGBColor[
             0.720943391874006, 0.781763716393137, 0.9729313233883682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 195}], {
             RGBColor[
             0.5664075262483584, 0.658874172033517, 0.9590088217668552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 196}], {
             RGBColor[
             0.43238466744803844`, 0.5370813339950793, 0.9503675109966372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 199}], {
             RGBColor[
             0.8135219538922576, 0.8521286416727499, 0.8461806318478537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 64}], {
             RGBColor[
             0.8089618730748239, 0.8413144235136905, 0.6866933210901831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 65}], {
             RGBColor[
             0.9723656669587191, 0.9184450471811106, 0.347146263750879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 118}], {
             RGBColor[
             0.6896300999943169, 0.7427398350516461, 0.6777676080129371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 119}], {
             RGBColor[
             0.9176093173132854, 0.6667189724180997, 0.30094116151906036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 123}], {
             RGBColor[
             0.7197585780581139, 0.7688356084491694, 0.6796873679935951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 127}], {
             RGBColor[
             0.9315900923682865, 0.9377519849577597, 0.6986638549616266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 140}], {
             RGBColor[
             0.9910580021453803, 0.9807455899537222, 0.48380004734696136`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 151}], {
             RGBColor[
             0.9911479730677677, 0.9821275166719952, 0.580056048665182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 155}], {
             RGBColor[
             0.8307914164161123, 0.8585643375610341, 0.688734731768329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 171}], {
             RGBColor[
             0.6480714766956179, 0.7066517748176793, 0.6751229004016905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 172}], {
             RGBColor[
             0.9288667542587956, 0.7360484350731749, 0.311047781867342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 191}], {
             RGBColor[
             0.899248175195666, 0.9120432778102582, 0.6955578617186919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 195}], {
             RGBColor[
             0.7447123095700184, 0.789153733450638, 0.681635360097179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 199}], {
             RGBColor[
             0.9918267372139176, 0.9824082030898711, 0.5688071701781774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 90}], {
             RGBColor[
             0.281574426125484, 0.41077439271759675`, 0.9394384697479637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 108}], {
             RGBColor[
             0.3219524714198415, 0.4532142784379034, 0.9417379396935124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 111}], {
             RGBColor[
             0.27800719710349053`, 0.40702500884009835`, 0.9392353213324036]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 115}], {
             RGBColor[
             0.3254517520127096, 0.4563116827378988, 0.9419584757459334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 163}], {
             RGBColor[
             0.3088204539598367, 0.4394116954694417, 0.9409900907262441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.2708407078314586, 0.3994925742335291, 0.9388272003702323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 175}], {
             RGBColor[
             0.4182247539712943, 0.5353839569381427, 0.9482243963930945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 177}], {
             RGBColor[
             0.2766340766323431, 0.4055817721640561, 0.9391571241529215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 183}], {
             RGBColor[
             0.6361311703010923, 0.6254168955585735, 0.6051471025896153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 109}], {
             RGBColor[
             0.19998929422011852`, 0.3275318066519287, 0.9347004664969638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 148}], {
             RGBColor[
             0.18807327130146562`, 0.31500731104493473`, 0.9340218666199227]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 150}], {
             RGBColor[
             0.18756580923325702`, 0.31447393623629405`, 0.933992967405861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 193}], {
             RGBColor[
             0.2060154437903921, 0.33386567193023686`, 0.9350436468001014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 88}], {
             RGBColor[
             0.1992012217508764, 0.32670349252007475`, 0.9346555869356892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 91}], {
             RGBColor[
             0.18403700151578473`, 0.31076493558589874`, 0.9337920070267542]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 103}], {
             RGBColor[
             0.1814602470714449, 0.3080566032892297, 0.9336452646731157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 117}], {
             RGBColor[
             0.18358120319676802`, 0.31028586265332964`, 0.9337660499867794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 121}], {
             RGBColor[
             0.1995963195919732, 0.32711876540171747`, 0.9346780871732447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 152}], {
             RGBColor[
             0.19101263224123774`, 0.3180967657588828, 0.9341892588770478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 164}], {
             RGBColor[
             0.1885063938143962, 0.3154625502675782, 0.9340465323062868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 178}], {
             RGBColor[
             0.1827435050835432, 0.30940538882320234`, 0.9337183443184945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 200}], {
             RGBColor[
             0.1862266556746971, 0.31306640093900795`, 0.9339167045918012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 77}], {
             RGBColor[
             0.8889478384033738, 0.5521228653145076, 0.5579177911517261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 96}], {
             RGBColor[
             0.9484965672474285, 0.961109404699039, 0.9720660567902085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 99}], {
             RGBColor[
             0.7561986870952739, 0.8085753289305662, 0.9547390377343874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 102}], {
             RGBColor[
             0.9648761622564584, 0.9733252798376484, 0.9443396749224908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 125}], {
             RGBColor[
             0.6124298936125201, 0.6826137072843086, 0.9449897432593624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 128}], {
             RGBColor[
             0.695941652480456, 0.7590582933299347, 0.9501605185766638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 137}], {
             RGBColor[
             0.6422345288762541, 0.7125398822624958, 0.9467383481519487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 166}], {
             RGBColor[
             0.8821530144207035, 0.9083587380492957, 0.9663447354512944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 170}], {
             RGBColor[
             0.8078923228953876, 0.8503457214275595, 0.9589431237256691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 192}], {
             RGBColor[
             0.7131454310850844, 0.7736227561744136, 0.951349727711992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 198}], {
             RGBColor[
             0.6531000789032383, 0.7219510755774461, 0.9474306913916395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 62}], {
             RGBColor[
             0.19206220882201708`, 0.3191999372922807, 0.9342490307106137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 92}], {
             RGBColor[
             0.21433501599530952`, 0.3426100698089493, 0.9355174341294674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 114}], {
             RGBColor[
             0.1828190891221793, 0.3094848324401137, 0.9337226487176782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 146}], {
             RGBColor[
             0.21481341413912597`, 0.34311289659029465`, 0.935544678196031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 184}], {
             RGBColor[
             0.1830159493280225, 0.30969174499811286`, 0.9337338596151724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 186}], {
             RGBColor[
             0.18364549933831636`, 0.3103534419747078, 0.9337697115569229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[
             0.19287248204991897`, 0.32005158582909543`, 0.934295174572251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 90}], {
             RGBColor[
             0.2041256683004301, 0.33187939807160033`, 0.9349360268816205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 111}], {
             RGBColor[
             0.20055843927843664`, 0.3281300141941019, 0.9347328784660603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 165}], {
             RGBColor[
             0.1933919500064047, 0.32059757958753266`, 0.9343247575038889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 169}], {
             RGBColor[
             0.18653686033276015`, 0.3133924457027435, 0.9339343702881713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 67}], {
             RGBColor[
             0.2316153172023224, 0.36077276201189723`, 0.936501521719292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 79}], {
             RGBColor[
             0.20075917656457537`, 0.3283410018093128, 0.9347443101575417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 84}], {
             RGBColor[
             0.19428775253280067`, 0.3215391248399355, 0.9343757721325461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 122}], {
             RGBColor[
             0.24263213866310665`, 0.37235213987400595`, 0.9371289134035569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 126}], {
             RGBColor[
             0.19350305800530745`, 0.3207143611390335, 0.9343310849400568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 179}], {
             RGBColor[
             0.2879403991921272, 0.41444560530367136`, 0.9399115732194068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 190}], {
             RGBColor[
             0.1957633885191688, 0.3230901118223337, 0.9344598074189618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 192}], {
             RGBColor[
             0.33652735532483224`, 0.4561925991586039, 0.9431004906757697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 114}], {
             RGBColor[
             0.19065828327948256`, 0.31772432253305627`, 0.9341690792278882]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 141}], {
             RGBColor[
             0.2718586483084913, 0.3998286032950302, 0.9389120419161632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 149}], {
             RGBColor[
             0.19270262269030192`, 0.3198730528724325, 0.9342855013330051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 167}], {
             RGBColor[
             0.19961760381417978`, 0.3271411364687542, 0.9346792992782123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 184}], {
             RGBColor[
             0.19085514348532573`, 0.3179312350910555, 0.9341802901253824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 189}], {
             RGBColor[
             0.19716645902323188`, 0.3245648278819121, 0.9345397102085116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 194}], {
             RGBColor[
             0.2007116762072222, 0.32829107592203804`, 0.9347416050824608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 197}], {
             RGBColor[
             0.20030365932071864`, 0.327862224304558, 0.9347183691243814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 70}], {
             RGBColor[
             0.1913615767368444, 0.3184635285481242, 0.9342091307498555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 110}], {
             RGBColor[
             0.18589948479502594`, 0.3127225236006417, 0.9338980726942099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 132}], {
             RGBColor[
             0.24611904809652904`, 0.37601710277136, 0.9373274877373701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 138}], {
             RGBColor[
             0.20677310926701956`, 0.33466202638493814`, 0.9350867947281298]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 145}], {
             RGBColor[
             0.1909329030445121, 0.31801296531800116`, 0.9341847184172432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 153}], {
             RGBColor[
             0.23696466171985112`, 0.36639526226785174`, 0.9368061589759192]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 185}], {
             RGBColor[
             0.2118614125837917, 0.3400101557879294, 0.9353765660745497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 65}], {
             RGBColor[
             0.792934775654365, 0.787251260573052, 0.6244310740750881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 132}], {
             RGBColor[
             0.4650482384089718, 0.5716822037632778, 0.9522031318796592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 138}], {
             RGBColor[
             0.4257022995794623, 0.5303271273768558, 0.949962438870419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 153}], {
             RGBColor[
             0.4558938520322939, 0.5620603632597695, 0.9516818031182084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 156}], {
             RGBColor[
             0.724124328038114, 0.42749923026133874`, 0.5647677517545815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 182}], {
             RGBColor[
             0.48518193863662246`, 0.5898773465279377, 0.9534583400112507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 185}], {
             RGBColor[
             0.4307906028962345, 0.5356752567798472, 0.9502522102168389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 199}], {
             RGBColor[
             0.8123958459095635, 0.8512144164818124, 0.8460919805023865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 118}], {
             RGBColor[
             0.6736030025738579, 0.6886766721110076, 0.6155053609978421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 119}], {
             RGBColor[
             0.9015822198928265, 0.6126558094774612, 0.23867891450396542`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 123}], {
             RGBColor[
             0.7037314806376549, 0.7147724455085309, 0.6174251209785002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 127}], {
             RGBColor[
             0.9155629949478274, 0.8836888220171212, 0.6364016079465316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 140}], {
             RGBColor[
             0.9750309047249213, 0.9266824270130837, 0.4215378003318664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 151}], {
             RGBColor[
             0.9751208756473086, 0.9280643537313567, 0.5177938016500871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 155}], {
             RGBColor[
             0.8147643189956533, 0.8045011746203956, 0.6264724847532339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 156}], {
             RGBColor[
             0.887528121922009, 0.5046298539287588, 0.2252206944152773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 171}], {
             RGBColor[
             0.6320443792751589, 0.6525886118770408, 0.6128606533865955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 172}], {
             RGBColor[
             0.9128396568383367, 0.6819852721325363, 0.24878553485224705`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 191}], {
             RGBColor[
             0.8832210777752071, 0.8579801148696197, 0.6332956147035969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 195}], {
             RGBColor[
             0.7286852121495595, 0.7350905705099995, 0.6193731130820839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 199}], {
             RGBColor[
             0.9757996397934585, 0.9283450401492326, 0.5065449231630825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 78}], {
             RGBColor[
             0.18323872675967784`, 0.30992589820368766`, 0.9337465464603355]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 80}], {
             RGBColor[
             0.20266968703316796`, 0.3303490694451636, 0.9348531109023811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 82}], {
             RGBColor[
             0.1977556445101682, 0.32518409918519964`, 0.9345732634503707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[
             0.18802367047876978`, 0.3149551774354076, 0.9340190419264479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 100}], {
             RGBColor[
             0.1946685243294859, 0.3219393401405779, 0.9343974565230659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 113}], {
             RGBColor[
             0.1939997700984511, 0.32123643704229315`, 0.9343593719589416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 120}], {
             RGBColor[
             0.18874212911118976`, 0.3157103230109893, 0.9340599570827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 124}], {
             RGBColor[
             0.2047917303558609, 0.33257947152263156`, 0.9349739581303267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 136}], {
             RGBColor[
             0.2031791949691239, 0.33088459459052233`, 0.9348821266255843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 187}], {
             RGBColor[
             0.19351363784595493`, 0.32072548122235467`, 0.9343316874463302]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 79}], {
             RGBColor[
             0.22503396848065443`, 0.3538553472238142, 0.9361267236458259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 82}], {
             RGBColor[
             0.2339276106645956, 0.3632031290486195, 0.9366332034112368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 100}], {
             RGBColor[
             0.2308404904839133, 0.3599583700039979, 0.936457396483932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 122}], {
             RGBColor[
             0.26690693057918574`, 0.3978664852885073, 0.9385113268918411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 125}], {
             RGBColor[
             0.2600866097683471, 0.39069789568300034`, 0.9381229197114243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 137}], {
             RGBColor[
             0.289891245032081, 0.42062407066118745`, 0.9398715246040107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 166}], {
             RGBColor[
             0.5298097305765306, 0.6164429264479874, 0.9594779119033563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 170}], {
             RGBColor[
             0.45554903905121463`, 0.5584299098262512, 0.952076300177731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 179}], {
             RGBColor[
             0.3122151911082063, 0.43995995071817273`, 0.941293986707691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 192}], {
             RGBColor[
             0.36080214724091136`, 0.4817069445731053, 0.944482904164054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 71}], {
             RGBColor[
             0.6623649639352431, 0.6847752584173, 0.6236785616506062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 75}], {
             RGBColor[
             0.7315668061877028, 0.7433887217645079, 0.6284543351107399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 81}], {
             RGBColor[
             0.6335105972347094, 0.659531932623991, 0.6218491817852485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 102}], {
             RGBColor[
             0.9650834798325474, 0.9283042529937652, 0.6200104049924591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 127}], {
             RGBColor[
             0.9178893661581602, 0.8915362183675095, 0.645439120800334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 129}], {
             RGBColor[
             0.7077311225760636, 0.7240378400232692, 0.6265779027838456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 140}], {
             RGBColor[
             0.977357275935254, 0.934529823363472, 0.4305753131856688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 143}], {
             RGBColor[
             0.9083269889752188, 0.8839114383656459, 0.6445270527281901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 155}], {
             RGBColor[
             0.817090690205986, 0.812348570970784, 0.6355099976070364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 172}], {
             RGBColor[
             0.9151660280486694, 0.6898326684829248, 0.25782304770604947`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 188}], {
             RGBColor[
             0.6370968292328074, 0.6628892701514275, 0.6220684984511013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 86}], {
             RGBColor[
             0.22595538032998164`, 0.3548238094983426, 0.9361791966875385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 92}], {
             RGBColor[
             0.2471305318648358, 0.3770802363436254, 0.937385090241619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 118}], {
             RGBColor[
             0.32034074100661103`, 0.44643612012511674`, 0.9418323088423037]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 123}], {
             RGBColor[
             0.3504692190704081, 0.47253189352264, 0.9437520688229617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 139}], {
             RGBColor[
             0.2677410752801248, 0.398743224257023, 0.938558830198553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 146}], {
             RGBColor[
             0.24760893000865222`, 0.37758306312497075`, 0.9374123343081827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 171}], {
             RGBColor[
             0.27878211770791206`, 0.41034805989114986`, 0.939187601231057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 174}], {
             RGBColor[
             0.21992361240255348`, 0.34848403897044045`, 0.9358356964272725]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 186}], {
             RGBColor[
             0.21644101520784265`, 0.3448236085093839, 0.9356373676690746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 191}], {
             RGBColor[
             0.5299588162079603, 0.6157395628837288, 0.9596225625480584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 195}], {
             RGBColor[
             0.3754229505823126, 0.4928500185241086, 0.9457000609265455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 196}], {
             RGBColor[
             0.24140009178199262`, 0.37105718048567105`, 0.9370587501563274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 110}], {
             RGBColor[
             0.185588460386286, 0.31239561722696946`, 0.9338803603142515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 132}], {
             RGBColor[
             0.2458080236877891, 0.37569019639768786`, 0.9373097753574117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 138}], {
             RGBColor[
             0.2064620848582796, 0.334335120011266, 0.9350690823481714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.19062187863577218`, 0.31768605894432894`, 0.9341670060372848]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 185}], {
             RGBColor[
             0.21155038817505178`, 0.3396832494142572, 0.9353588536945914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 73}], {
             RGBColor[
             0.29060892456725834`, 0.41769434068172157`, 0.9400472867534765]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 75}], {
             RGBColor[
             0.4329404581640204, 0.5480873032405589, 0.9491738543179573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 76}], {
             RGBColor[
             0.3139935330397997, 0.4422730468561747, 0.9413790056115596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 81}], {
             RGBColor[
             0.334884249211027, 0.4642305141000421, 0.942568700992466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 87}], {
             RGBColor[
             0.29022081155983176`, 0.4172864093031303, 0.9400251842918653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 89}], {
             RGBColor[
             0.315626713124748, 0.4439896226750534, 0.9414720128013241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 107}], {
             RGBColor[
             0.2906858024537879, 0.41777514421480366`, 0.9400516648353837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 127}], {
             RGBColor[
             0.6192630181344778, 0.6962347998435606, 0.9661586400075515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 129}], {
             RGBColor[
             0.40910477455238126`, 0.5287364214993203, 0.947297421991063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 141}], {
             RGBColor[
             0.3537772547746116, 0.4808458095490941, 0.9437633517346631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 142}], {
             RGBColor[
             0.312868249726037, 0.44109030274632716`, 0.9413149223915483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 147}], {
             RGBColor[
             0.3066316503071229, 0.4345352413338067, 0.9409597572808632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 155}], {
             RGBColor[
             0.5184643421823038, 0.6170471524468351, 0.9562295168142538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 168}], {
             RGBColor[
             0.2865680055762049, 0.4134470786130624, 0.93981716239494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 188}], {
             RGBColor[
             0.33847048120912504`, 0.4675878516274786, 0.9427880176583188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 197}], {
             RGBColor[
             0.2822222657868389, 0.40887943055862197`, 0.9395696789428815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 76}], {
             RGBColor[
             0.25872488056116644`, 0.3892666319476351, 0.9380453712475731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 81}], {
             RGBColor[
             0.2796155967323937, 0.4112240991915025, 0.9392350666284796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 104}], {
             RGBColor[
             0.31015077590521656`, 0.43792326026821704`, 0.9411715463782875]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 143}], {
             RGBColor[
             0.5544319884729032, 0.6356036049331575, 0.9619129375714212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 144}], {
             RGBColor[
             0.22584498306262032`, 0.3547077749707548, 0.9361729097264804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 154}], {
             RGBColor[
             0.2925360773933412, 0.42266629375772025`, 0.940049153365177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 158}], {
             RGBColor[
             0.284772839183219, 0.41594216701181014`, 0.93955448669119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 160}], {
             RGBColor[
             0.3481960203596565, 0.4708761388050667, 0.9435957557128356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 176}], {
             RGBColor[
             0.2436445546193927, 0.37341625323494165`, 0.9371865689945322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 181}], {
             RGBColor[
             0.345687120645864, 0.46870305597394574`, 0.9434358908416056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 75}], {
             RGBColor[
             0.3598107668197179, 0.47630780402892936`, 0.9448230602136101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 87}], {
             RGBColor[
             0.2170911202155293, 0.3455069100915008, 0.9356743901875181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.2424970217804455, 0.37221012346342386`, 0.9371212186969768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 107}], {
             RGBColor[
             0.21755611110948542`, 0.34599564500317415`, 0.9357008707310365]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 130}], {
             RGBColor[
             0.20088728591826768`, 0.3284756528626456, 0.9347516057957137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 142}], {
             RGBColor[
             0.23973855838173452`, 0.36931080353469764`, 0.9369641282872011]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 147}], {
             RGBColor[
             0.23350195896282042`, 0.3627557421221772, 0.936608963176516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 149}], {
             RGBColor[
             0.2014915378121197, 0.32911075991486693`, 0.934786017047158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 157}], {
             RGBColor[
             0.21195207893765056`, 0.34010545187441393`, 0.9353817293892732]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 167}], {
             RGBColor[
             0.20840651893599757`, 0.33637884351118863`, 0.9351798149923649]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 168}], {
             RGBColor[
             0.2134383142319024, 0.3416675794014329, 0.9354663682905927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 188}], {
             RGBColor[
             0.26534078986482257`, 0.3958083524158491, 0.9384372235539715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 189}], {
             RGBColor[
             0.20595537414504966`, 0.3338025349243465, 0.9350402259226642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 197}], {
             RGBColor[
             0.20909257444253643`, 0.33709993134699245`, 0.9352188848385342]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 85}], {
             RGBColor[
             0.3082012500479231, 0.4378314678081793, 0.9409888580526407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 88}], {
             RGBColor[
             0.2812466810785635, 0.40950050680300143`, 0.9394538352255469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 93}], {
             RGBColor[
             0.28865865838495014`, 0.4172909648985178, 0.9398759363681078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 95}], {
             RGBColor[
             0.29756419393855826`, 0.4266512474089263, 0.9403830934433266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 121}], {
             RGBColor[
             0.28164177891966025`, 0.4099157796846441, 0.9394763354631025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 140}], {
             RGBColor[
             0.6698268935487197, 0.7315161778042003, 0.7507274751968138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 152}], {
             RGBColor[
             0.2730580915689248, 0.4008937800418094, 0.9389875071669056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 159}], {
             RGBColor[
             0.30041133141594933`, 0.42964376941660665`, 0.9405452337107016]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 161}], {
             RGBColor[
             0.31487926883859824`, 0.44485048896802515`, 0.9413691613435261]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 162}], {
             RGBColor[
             0.39867126833608224`, 0.5197307476573095, 0.9466239585805827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 164}], {
             RGBColor[
             0.2705518531420833, 0.3982595645505048, 0.9388447805961444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 172}], {
             RGBColor[
             0.607635645662135, 0.48681902292365303`, 0.5779752097171944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 173}], {
             RGBColor[
             0.35684188955631446`, 0.48350024216398235`, 0.9439586275530032]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 180}], {
             RGBColor[
             0.34398171160205027`, 0.4723614023913367, 0.9431391883855662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 81}], {
             RGBColor[
             0.40408609146348656`, 0.52284397744725, 0.9473444744525996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 89}], {
             RGBColor[
             0.3848285553772075, 0.5026030860222612, 0.9462477862614576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 118}], {
             RGBColor[
             0.44650486801296785`, 0.559836113284655, 0.9500381665189955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 127}], {
             RGBColor[
             0.6884648603869374, 0.7548482631907685, 0.9709344134676849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 129}], {
             RGBColor[
             0.47830661680484077`, 0.5873498848465282, 0.9520731954511965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 141}], {
             RGBColor[
             0.42297909702707115`, 0.5394592728963019, 0.9485391251947967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 142}], {
             RGBColor[
             0.3820700919784965, 0.49970376609353495`, 0.9460906958516819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 147}], {
             RGBColor[
             0.3758334925595824, 0.4931487046810145, 0.9457355307409967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 155}], {
             RGBColor[
             0.5876661844347633, 0.6756606157940428, 0.9610052902743873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 168}], {
             RGBColor[
             0.3557698478286644, 0.47206054196027025`, 0.9445929358550735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 188}], {
             RGBColor[
             0.40767232346158455`, 0.5262013149746865, 0.9475637911184522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 191}], {
             RGBColor[
             0.656122943214317, 0.729139556043267, 0.9678284202247502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 81}], {
             RGBColor[
             0.28513916633926595`, 0.41702972106286573`, 0.9395496257462019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 87}], {
             RGBColor[
             0.2404757286880707, 0.37008561626595393`, 0.9370061090456012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 89}], {
             RGBColor[
             0.2658816302529869, 0.396788829637877, 0.93845293755506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[
             0.3156743455120887, 0.4437288821395802, 0.9414861054960099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 106}], {
             RGBColor[
             0.2246392602509319, 0.35344048384842863`, 0.9361042455960618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 107}], {
             RGBColor[
             0.2409407195820268, 0.37057435117762727`, 0.9370325895891196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 142}], {
             RGBColor[
             0.26312316685427595`, 0.39388950970915076`, 0.9382958471452842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 143}], {
             RGBColor[
             0.5599555580797754, 0.6414092268045206, 0.9622274966891435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 147}], {
             RGBColor[
             0.2568865674353618, 0.38733444829663033`, 0.9379406820345992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 154}], {
             RGBColor[
             0.29805964700021337`, 0.42847191562908343`, 0.9403637124828994]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[
             0.23533668741019195`, 0.36468415804886706`, 0.9367134482473564]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 158}], {
             RGBColor[
             0.2902964087900912, 0.4217477888831733, 0.9398690458089125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 176}], {
             RGBColor[
             0.24916812422626491`, 0.3792218751063049, 0.9375011281122546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 181}], {
             RGBColor[
             0.3512106902527362, 0.4745086778453089, 0.9437504499593281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 188}], {
             RGBColor[
             0.288725398337364, 0.42038705859030223`, 0.9397689424120548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 83}], {
             RGBColor[
             0.8718524916829569, 0.5391330266655409, 0.5785293580798063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 96}], {
             RGBColor[
             0.8768677288440547, 0.5431135393845314, 0.5783662656384824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 99}], {
             RGBColor[
             0.6845698486919003, 0.3905794636160585, 0.5610392465826612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 112}], {
             RGBColor[
             0.8793649622811279, 0.5449759719930563, 0.5741391008123097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 143}], {
             RGBColor[
             0.8364908329957561, 0.5109365998950215, 0.5751565315064958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 156}], {
             RGBColor[
             0.8180183371528791, 0.13950241180852277`, 0.1648876860473853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 160}], {
             RGBColor[
             0.6302548648825095, 0.34620913376693074`, 0.5568393496479103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 166}], {
             RGBColor[
             0.8105241760173298, 0.490362872734788, 0.5726449442995682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 170}], {
             RGBColor[
             0.736263484492014, 0.4323498561130519, 0.5652433325739429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 181}], {
             RGBColor[
             0.627745965168717, 0.3440360509358098, 0.5566794847766803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 183}], {
             RGBColor[
             0.8768515535875127, 0.45980910711412243`, 0.21594468162867203`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 192}], {
             RGBColor[
             0.6415165926817106, 0.355626890859906, 0.5576499365602658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 80}], {
             RGBColor[
             0.20236223698329917`, 0.33002591994929253`, 0.9348356020768727]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 82}], {
             RGBColor[
             0.1974481944602994, 0.3248609496893285, 0.9345557546248622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 98}], {
             RGBColor[
             0.18771622042890102`, 0.3146320279395365, 0.9340015331009395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 100}], {
             RGBColor[
             0.1943610742796171, 0.3216161906447068, 0.9343799476975574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 113}], {
             RGBColor[
             0.19369232004858233`, 0.320913287546422, 0.9343418631334333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 120}], {
             RGBColor[
             0.188434679061321, 0.31538717351511814`, 0.9340424482571915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 124}], {
             RGBColor[
             0.20448428030599214`, 0.3322563220267605, 0.9349564493048182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 136}], {
             RGBColor[
             0.2028717449192551, 0.3305614450946512, 0.9348646178000759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 187}], {
             RGBColor[
             0.19320618779608617`, 0.3204023317264835, 0.9343141786208218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 84}], {
             RGBColor[
             0.1877064038111327, 0.31462171005185247`, 0.93400097405908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 122}], {
             RGBColor[
             0.2360507899414387, 0.3654347250859229, 0.9367541153300909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 126}], {
             RGBColor[
             0.1869217092836395, 0.3137969463509505, 0.9339562868665908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 177}], {
             RGBColor[
             0.20578387384021699`, 0.33362227723022, 0.9350304592340161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 179}], {
             RGBColor[
             0.2813590504704592, 0.4075281905155883, 0.9395367751459407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 190}], {
             RGBColor[
             0.18918203979750087`, 0.31617269703425077`, 0.9340850093454959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 82}], {
             RGBColor[
             0.2168791547337895, 0.3452841209308045, 0.9356623190669078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 98}], {
             RGBColor[
             0.2071471807023911, 0.33505519918101245`, 0.9351080975429851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 100}], {
             RGBColor[
             0.2137920345531072, 0.3420393618861828, 0.935486512139603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 113}], {
             RGBColor[
             0.2131232803220724, 0.34133645878789803`, 0.9354484275754789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 116}], {
             RGBColor[
             0.23121046425376574`, 0.3603472358938047, 0.936478465942798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 120}], {
             RGBColor[
             0.20786563933481106`, 0.33581034475659416`, 0.9351490126992371]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 124}], {
             RGBColor[
             0.22391524057948223`, 0.35267949326823644`, 0.9360630137468638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 125}], {
             RGBColor[
             0.243038153837541, 0.3727788875651853, 0.9371520353670952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 136}], {
             RGBColor[
             0.2223027051927452, 0.3509846163361272, 0.9359711822421215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 137}], {
             RGBColor[
             0.2728427891012749, 0.40270506254337235`, 0.9389006402596817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 187}], {
             RGBColor[
             0.21263714806957626`, 0.34082550296795955`, 0.9354207430628674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 198}], {
             RGBColor[
             0.28370833912825916`, 0.4121162558583227, 0.9395929834993725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 87}], {
             RGBColor[
             0.261366444859298, 0.3920430835098213, 0.9381958044265076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 89}], {
             RGBColor[
             0.2867723464242142, 0.41874629688174436`, 0.9396426329359664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 104}], {
             RGBColor[
             0.336565061683316, 0.46568634938344766`, 0.9426758008769163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 107}], {
             RGBColor[
             0.26183143575325407`, 0.39253181842149465`, 0.938222284970026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 142}], {
             RGBColor[
             0.28401388302550323`, 0.4158469769530182, 0.9394855425261907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 143}], {
             RGBColor[
             0.5808462742510027, 0.663366694048388, 0.9634171920700499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 147}], {
             RGBColor[
             0.2777772836065891, 0.4092919155404977, 0.9391303774155055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 154}], {
             RGBColor[
             0.31895036317144065`, 0.45042938287295087`, 0.9415534078638058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 157}], {
             RGBColor[
             0.25622740358141927`, 0.3866416252927345, 0.9379031436282628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 158}], {
             RGBColor[
             0.3111871249613185, 0.44370525612704076`, 0.9410587411898188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 168}], {
             RGBColor[
             0.2577136388756711, 0.38820375281975344`, 0.9379877825295823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 176}], {
             RGBColor[
             0.2700588403974922, 0.4011793423501723, 0.938690823493161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 188}], {
             RGBColor[
             0.3096161145085913, 0.44234452583416967`, 0.9409586377929611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 98}], {
             RGBColor[
             0.20223313817939134`, 0.32989022892104847`, 0.9348282500909746]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 100}], {
             RGBColor[
             0.20887799203010743`, 0.3368743916262188, 0.9352066646875926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 120}], {
             RGBColor[
             0.2029515968118113, 0.3306453744966301, 0.9348691652472267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 124}], {
             RGBColor[
             0.21900119805648247`, 0.34751452300827246`, 0.9357831662948535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 125}], {
             RGBColor[
             0.23812411131454123`, 0.3676139173052213, 0.9368721879150849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 136}], {
             RGBColor[
             0.21738866266974544`, 0.34581964607616317`, 0.935691334790111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 137}], {
             RGBColor[
             0.26792874657827515`, 0.39754009228340836`, 0.9386207928076713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 187}], {
             RGBColor[
             0.2077231055465765, 0.3356605327079955, 0.9351408956108569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 198}], {
             RGBColor[
             0.2787942966052594, 0.4069512855983587, 0.9393131360473621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 122}], {
             RGBColor[
             0.6021548677029418, 0.6767924582408489, 0.9659897173678593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 156}], {
             RGBColor[
             0.8725518288358358, 0.5445084384740636, 0.5791990441271917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 166}], {
             RGBColor[
             0.8650576677002866, 0.8953688994003288, 0.9869563023793746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 170}], {
             RGBColor[
             0.7907969761749707, 0.8373558827785927, 0.9795546906537492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 175}], {
             RGBColor[
             0.7134786289406714, 0.7747821951592325, 0.9733333335119576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 179}], {
             RGBColor[
             0.6474631282319623, 0.7188859236705143, 0.9687723771837091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 183}], {
             RGBColor[
             0.9313850452704695, 0.8648151337796632, 0.6302560397084783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 192}], {
             RGBColor[
             0.6960500843646674, 0.7606329175254469, 0.9719612946400722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 126}], {
             RGBColor[
             0.1804502852518648, 0.30699506938157317`, 0.9335877488415951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 190}], {
             RGBColor[
             0.18271061576572617`, 0.30937082006487343`, 0.9337164713205002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 88}], {
             RGBColor[
             0.24351738394062986`, 0.3732825887884752, 0.9371793268125088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 117}], {
             RGBColor[
             0.22789736538652144`, 0.3568649589217301, 0.9362897898635989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[
             0.24391248178172664`, 0.37369786167011787`, 0.9372018270500644]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 133}], {
             RGBColor[
             0.25979757259338154`, 0.39039409928609614`, 0.9381064594719022]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 140}], {
             RGBColor[
             0.632097596410786, 0.6952982597896742, 0.7484529667837756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 152}], {
             RGBColor[
             0.2353287944309912, 0.36467586202728325`, 0.9367129987538674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 159}], {
             RGBColor[
             0.26268203427801573`, 0.3934258514020805, 0.9382707252976634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 161}], {
             RGBColor[
             0.2771499717006646, 0.408632570953499, 0.939094652930488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 173}], {
             RGBColor[
             0.31911259241838086`, 0.4472823241494562, 0.941684119139965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 200}], {
             RGBColor[
             0.23054281786445055`, 0.35964549720740835`, 0.9364404444686207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 92}], {
             RGBColor[
             0.22327186579105107`, 0.35200326557327766`, 0.9360263745044504]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[
             0.19625374198187168`, 0.3236055044018397, 0.9344877323232499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 171}], {
             RGBColor[
             0.25492345163412733`, 0.3852710891208021, 0.9378288854938884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 174}], {
             RGBColor[
             0.19606494632876875`, 0.3234070682000927, 0.9344769806901039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 196}], {
             RGBColor[
             0.2175414257082079, 0.3459802097153233, 0.9357000344191588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 89}], {
             RGBColor[
             0.24210890877301894`, 0.37180219208483256`, 0.9370991162353657]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 106}], {
             RGBColor[
             0.20086653877096394`, 0.3284538462953842, 0.9347504242763673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 107}], {
             RGBColor[
             0.21716799810205883`, 0.34558771362458285`, 0.9356787682694253]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 130}], {
             RGBColor[
             0.20049917291084113`, 0.3280677214840543, 0.9347295033341025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 131}], {
             RGBColor[
             0.19909905794023608`, 0.326596111877532, 0.934649768857811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 142}], {
             RGBColor[
             0.23935044537430794`, 0.3689028721561064, 0.9369420258255899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 147}], {
             RGBColor[
             0.23311384595539386`, 0.3623478107435859, 0.9365868607149048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[
             0.2742869255202454, 0.40348527807603907`, 0.9390098911632051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 157}], {
             RGBColor[
             0.21156396593022397`, 0.3396975204958227, 0.9353596269276621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 168}], {
             RGBColor[
             0.21305020122447582`, 0.34125964802284164`, 0.9354442658289815]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 176}], {
             RGBColor[
             0.22539540274629694`, 0.3542352375532605, 0.9361473067925603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 188}], {
             RGBColor[
             0.264952676857396, 0.39540042103725787`, 0.9384151210923604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 91}], {
             RGBColor[
             0.20139859473617852`, 0.32901307084912135`, 0.93478072407648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 93}], {
             RGBColor[
             0.22397479227765688`, 0.3527420858788138, 0.936066405127976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 95}], {
             RGBColor[
             0.23288032783126497`, 0.3621023683892223, 0.9365735622031948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 103}], {
             RGBColor[
             0.1988218402918387, 0.32630473855245234`, 0.9346339817228415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 117}], {
             RGBColor[
             0.2009427964171618, 0.32853399791655225`, 0.9347547670365053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 121}], {
             RGBColor[
             0.21695791281236698`, 0.34536690066494, 0.9356668042229707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 152}], {
             RGBColor[
             0.20837422546163153`, 0.3363449010221054, 0.9351779759267738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 159}], {
             RGBColor[
             0.23572746530865607`, 0.3650948903969026, 0.9367357024705698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 161}], {
             RGBColor[
             0.25019540273130497`, 0.38030160994832113`, 0.9375596301033943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 164}], {
             RGBColor[
             0.20586798703479003`, 0.3337106855308008, 0.9350352493560126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 173}], {
             RGBColor[
             0.2921580234490212, 0.41895136314427833`, 0.9401490963128714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 180}], {
             RGBColor[
             0.279297845494757, 0.4078125233716327, 0.9393296571454344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 200}], {
             RGBColor[
             0.20358824889509092`, 0.3313145362022305, 0.9349054216415271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 106}], {
             RGBColor[
             0.22627244033588012`, 0.3551570596673073, 0.9361972527858261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 107}], {
             RGBColor[
             0.24257389966697504`, 0.37229092699650596`, 0.9371255967788841]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 142}], {
             RGBColor[
             0.2647563469392241, 0.39560608552802945`, 0.9383888543350487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 147}], {
             RGBColor[
             0.25851974752031004`, 0.38905102411550896`, 0.9380336892243635]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 154}], {
             RGBColor[
             0.29969282708516165`, 0.4301884914479621, 0.9404567196726639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 157}], {
             RGBColor[
             0.23696986749514018`, 0.36640073386774574`, 0.9368064554371207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 168}], {
             RGBColor[
             0.23845610278939203`, 0.36796286139476475`, 0.9368910943384403]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 176}], {
             RGBColor[
             0.25080130431121317`, 0.3809384509251836, 0.937594135302019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 188}], {
             RGBColor[
             0.29035857842231216`, 0.42210363440918097`, 0.939861949601819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 111}], {
             RGBColor[
             0.22370338980181498`, 0.3524568246687931, 0.9360509491584807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 115}], {
             RGBColor[
             0.27114794471103404`, 0.4017434985665935, 0.9387741035720105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 163}], {
             RGBColor[
             0.2545166466581612, 0.38484351129813643`, 0.9378057185523212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 165}], {
             RGBColor[
             0.21653690052978303`, 0.3449243900622238, 0.9356428281963094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 169}], {
             RGBColor[
             0.20968181085613852`, 0.3377192561774346, 0.9352524409805917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 175}], {
             RGBColor[
             0.36392094666961883`, 0.4808157727668374, 0.9450400242191717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 177}], {
             RGBColor[
             0.22233026933066752`, 0.35101358799275084`, 0.9359727519789987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 103}], {
             RGBColor[
             0.18365762005674702`, 0.31036618161827634`, 0.9337704018139066]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 117}], {
             RGBColor[
             0.1857785761820701, 0.31259544098237624`, 0.9338911871275704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 121}], {
             RGBColor[
             0.2017936925772753, 0.329428343730764, 0.9348032243140356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 152}], {
             RGBColor[
             0.19321000522653986`, 0.3204063440879294, 0.9343143960178388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 159}], {
             RGBColor[
             0.22056324507356437`, 0.3491563334627266, 0.9358721225616348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 164}], {
             RGBColor[
             0.19070376679969833`, 0.3177721285966248, 0.9341716694470776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 200}], {
             RGBColor[
             0.18842402865999922`, 0.3153759792680545, 0.9340418417325922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 118}], {
             RGBColor[
             0.31765722646768046`, 0.4436155762000519, 0.9416794866592155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 123}], {
             RGBColor[
             0.34778570453147756`, 0.4697113495975751, 0.9435992466398737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 139}], {
             RGBColor[
             0.26505756074119424`, 0.3959226803319581, 0.938406008015465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 141}], {
             RGBColor[
             0.29413145548178377`, 0.42323873581169885`, 0.9401804453350167]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 146}], {
             RGBColor[
             0.24492541546972163`, 0.3747625191999059, 0.9372595121250946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 171}], {
             RGBColor[
             0.2760986031689815, 0.40752751596608494`, 0.939034779047969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 174}], {
             RGBColor[
             0.2172400978636229, 0.3456634950453756, 0.9356828742441843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 186}], {
             RGBColor[
             0.21375750066891208`, 0.34200306458431906`, 0.9354845454859864]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 191}], {
             RGBColor[
             0.5272753016690297, 0.6129190189586639, 0.9594697403649703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 195}], {
             RGBColor[
             0.372739436043382, 0.49002947459904367`, 0.9455472387434574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 196}], {
             RGBColor[
             0.23871657724306206`, 0.3682366365606061, 0.9369059279732393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 95}], {
             RGBColor[
             0.24029230513765162`, 0.36989282648473865`, 0.9369956633457557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 121}], {
             RGBColor[
             0.22436989011875363`, 0.3531573587604565, 0.9360889053655316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 150}], {
             RGBColor[
             0.21197440955790398`, 0.3401289227721434, 0.9353830010850614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 159}], {
             RGBColor[
             0.24313944261504272`, 0.37288534849241906`, 0.9371578036131307]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 161}], {
             RGBColor[
             0.2576073800376916, 0.38809206804383756`, 0.9379817312459552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 162}], {
             RGBColor[
             0.34139937953517563`, 0.46297232673312194`, 0.9432365284830118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 164}], {
             RGBColor[
             0.2132799643411767, 0.3415011436263172, 0.9354573504985735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 173}], {
             RGBColor[
             0.29957000075540785`, 0.42674182123979476`, 0.9405711974554323]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 180}], {
             RGBColor[
             0.28670982280114365`, 0.41560298146714914`, 0.9397517582879953]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 200}], {
             RGBColor[
             0.21100022620147757`, 0.339104994297747, 0.935327522784088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 174}], {
             RGBColor[
             0.19022197405444352`, 0.31726573387393764`, 0.9341442320629838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 196}], {
             RGBColor[
             0.21169845343388266`, 0.3398388753891681, 0.9353672857920389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 121}], {
             RGBColor[
             0.23327542567236176`, 0.36251764127086494`, 0.9365960624407503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 150}], {
             RGBColor[
             0.2208799451115121, 0.3494892052825519, 0.9358901581602801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 159}], {
             RGBColor[
             0.2520449781686508, 0.3822456310028275, 0.9376649606883494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 161}], {
             RGBColor[
             0.26651291559129975`, 0.397452350554246, 0.9384888883211739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 162}], {
             RGBColor[
             0.35030491508878375`, 0.4723326092435304, 0.9437436855582304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 164}], {
             RGBColor[
             0.22218549989478478`, 0.35086142613672566`, 0.9359645075737923]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 173}], {
             RGBColor[
             0.308475536309016, 0.4361021037502032, 0.9410783545306509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 180}], {
             RGBColor[
             0.2956153583547517, 0.42496326397755757`, 0.9402589153632142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 99}], {
             RGBColor[
             0.7441185775359549, 0.79956600300059, 0.9751875122211435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 102}], {
             RGBColor[
             0.9527960526971394, 0.9643159539076722, 0.964788149409247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 125}], {
             RGBColor[
             0.600349784053201, 0.6736043813543324, 0.9654382177461185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 128}], {
             RGBColor[
             0.683861542921137, 0.7500489673999585, 0.97060899306342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 137}], {
             RGBColor[
             0.630154419316935, 0.7035305563325196, 0.9671868226387048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 166}], {
             RGBColor[
             0.8700729048613844, 0.8993494121193195, 0.9867932099380505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 170}], {
             RGBColor[
             0.7958122133360686, 0.8413363954975833, 0.9793915982124253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 198}], {
             RGBColor[
             0.6410199693439192, 0.7129417496474699, 0.9678791658783956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 105}], {
             RGBColor[
             0.21127795983773054`, 0.3393969099587784, 0.9353433393038026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 134}], {
             RGBColor[
             0.23183626588337625`, 0.3610049930846403, 0.9365141044198138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 135}], {
             RGBColor[
             0.20686780943909605`, 0.33476156227012827`, 0.9350921877628332]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 153}], {
             RGBColor[
             0.24952804077433757`, 0.37960017021835646`, 0.9375216248272185]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 100}], {
             RGBColor[
             0.19914601799870904`, 0.3266454698764268, 0.9346524431636698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 109}], {
             RGBColor[
             0.2049550918267402, 0.33275117478624117`, 0.9349832613244216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 113}], {
             RGBColor[
             0.19847726376767427`, 0.32594256677814204`, 0.9346143585995457]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 116}], {
             RGBColor[
             0.21656444769936758`, 0.34495334388404864`, 0.9356443969668649]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 120}], {
             RGBColor[
             0.19321962278041294`, 0.32041645274683817`, 0.9343149437233039]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 124}], {
             RGBColor[
             0.20926922402508408`, 0.3372856012584804, 0.9352289447709307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 125}], {
             RGBColor[
             0.22839213728314284`, 0.35738499555542924`, 0.936317966391162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 136}], {
             RGBColor[
             0.20765668863834705`, 0.33559072432637116`, 0.9351371132661883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 187}], {
             RGBColor[
             0.1979911315151781, 0.3254316109582035, 0.9345866740869342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 102}], {
             RGBColor[
             0.7604981725449849, 0.8117818781391992, 0.9474611303534258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 109}], {
             RGBColor[
             0.38461485844464394`, 0.49643648481667146`, 0.9467764936235569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 116}], {
             RGBColor[
             0.39622421431727134`, 0.5086386539144789, 0.9474376292660001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 128}], {
             RGBColor[
             0.49156366276898256`, 0.5975148916314856, 0.9532819740075988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 136}], {
             RGBColor[
             0.3873164552562508, 0.49927603435680146`, 0.9469303455653235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 137}], {
             RGBColor[
             0.4378565391647805, 0.5509964805640466, 0.9498598035828838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 162}], {
             RGBColor[
             0.5016163434350541, 0.6062220183620153, 0.9539225219304044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 193}], {
             RGBColor[
             0.3906410080149175, 0.5027703500949796, 0.9471196739266945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 198}], {
             RGBColor[
             0.44872208919176476`, 0.5604076738789969, 0.9505521468225746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 113}], {
             RGBColor[
             0.20512211761839033`, 0.33292672948331237`, 0.9349927731961636]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 120}], {
             RGBColor[
             0.199864476631129, 0.3274006154520085, 0.934693358319922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 124}], {
             RGBColor[
             0.21591407787580016`, 0.3442697639636507, 0.9356073593675487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 125}], {
             RGBColor[
             0.23503699113385892`, 0.36436915826059957`, 0.9366963809877801]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 136}], {
             RGBColor[
             0.21430154248906313`, 0.3425748870315415, 0.9355155278628062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 137}], {
             RGBColor[
             0.26484162639759284`, 0.3942953332387867, 0.9384449858803665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 187}], {
             RGBColor[
             0.2046359853658942, 0.3324157736633738, 0.9349650886835521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 198}], {
             RGBColor[
             0.2757071764245771, 0.40370652655373696`, 0.9391373291200573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 105}], {
             RGBColor[
             0.20097546444375586`, 0.32856833408377506`, 0.9347566274322918]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 134}], {
             RGBColor[
             0.22153377048940157`, 0.350176417209637, 0.9359273925483029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 135}], {
             RGBColor[
             0.1965653140451214, 0.3239329863951249, 0.9345054758913225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 144}], {
             RGBColor[
             0.19734151181877715`, 0.32474881946901846`, 0.9345496792062504]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 128}], {
             RGBColor[
             0.700241137930167, 0.7622648425385679, 0.9428826111957023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 140}], {
             RGBColor[
             0.981449443808876, 0.9827573994159884, 0.747626675734739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 162}], {
             RGBColor[
             0.7102938185962386, 0.7709719692690975, 0.9435231591185078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 172}], {
             RGBColor[
             0.9192581959222914, 0.7380602445354411, 0.5748744102551196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 180}], {
             RGBColor[
             0.6556042618622065, 0.7236026240031248, 0.9400383889234916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 117}], {
             RGBColor[
             0.1832018217377303, 0.30988710868570724`, 0.9337444447739318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 152}], {
             RGBColor[
             0.19063325078220003`, 0.31769801179126034`, 0.9341676536642003]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 178}], {
             RGBColor[
             0.1823641236245055, 0.3090066348555799, 0.933696739105647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 200}], {
             RGBColor[
             0.18584727421565939`, 0.3126676469713855, 0.9338950993789537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 143}], {
             RGBColor[
             0.6113814534238254, 0.6900658551251025, 0.9653536718198579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 154}], {
             RGBColor[
             0.3494855423442635, 0.47712854394966536`, 0.9434898876136137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 158}], {
             RGBColor[
             0.3417223041341413, 0.47040441720375525`, 0.9429952209396267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 160}], {
             RGBColor[
             0.4051454853105788, 0.5253383889970118, 0.9470364899612722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 176}], {
             RGBColor[
             0.300594019570315, 0.4278785034268868, 0.9406273032429688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 181}], {
             RGBColor[
             0.4026365855967863, 0.5231653061658909, 0.9468766250900423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 188}], {
             RGBColor[
             0.34015129368141406`, 0.46904368691088416`, 0.9428951175427689]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 134}], {
             RGBColor[
             0.22631486646654955`, 0.35520165222061295`, 0.936199668891204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 135}], {
             RGBColor[
             0.20134641002226938`, 0.32895822140610087`, 0.9347777522342233]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 144}], {
             RGBColor[
             0.20212260779592514`, 0.3297740544799944, 0.9348219555491514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.20133152966492007`, 0.3289425812070576, 0.9347769048198857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 130}], {
             RGBColor[
             0.1846627044737023, 0.31142258906652903`, 0.933827639884563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 131}], {
             RGBColor[
             0.18326258950309726`, 0.3099509794600067, 0.9337479054082716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 142}], {
             RGBColor[
             0.22351397693716918`, 0.3522577397385811, 0.9360401623760504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 147}], {
             RGBColor[
             0.21727737751825504`, 0.3457026783260606, 0.9356849972653654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 157}], {
             RGBColor[
             0.1957274974930852, 0.3230523880782974, 0.9344577634781225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 176}], {
             RGBColor[
             0.20955893430915817`, 0.33759010513573523`, 0.9352454433430207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 130}], {
             RGBColor[
             0.20096416380479723`, 0.32855645639572767`, 0.9347559838776209]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 131}], {
             RGBColor[
             0.19956404883419218`, 0.32708484678920535`, 0.9346762494013294]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 142}], {
             RGBColor[
             0.23981543626826407`, 0.36939160706777974`, 0.9369685063691083]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[
             0.23357883684934996`, 0.36283654565525925`, 0.9366133412584232]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 154}], {
             RGBColor[
             0.27475191641420155`, 0.4039740129877124, 0.9390363717067235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.2120289568241801, 0.34018625540749603`, 0.9353861074711805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 168}], {
             RGBColor[
             0.21351519211843195`, 0.34174838293451504`, 0.9354707463724999]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 176}], {
             RGBColor[
             0.22586039364025307`, 0.35472397246493387`, 0.9361737873360787]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 188}], {
             RGBColor[
             0.2654176677513521, 0.39588915594893126`, 0.9384416016358788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 111}], {
             RGBColor[
             0.26408143509617243`, 0.39489671038909974`, 0.9383504191040295]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 115}], {
             RGBColor[
             0.3115259900053915, 0.4441833842869002, 0.9410735735175593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 133}], {
             RGBColor[
             0.27857495084464845`, 0.41013031438272207`, 0.9391758033846701]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 151}], {
             RGBColor[
             0.6509649455844404, 0.716416401604573, 0.8457783120147642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 163}], {
             RGBColor[
             0.29489469195251866`, 0.4272833970184431, 0.94010518849787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 165}], {
             RGBColor[
             0.25691494582414054`, 0.38736427578253046`, 0.937942298141858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 175}], {
             RGBColor[
             0.4042989919639763, 0.5232556584871441, 0.9473394941647204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 113}], {
             RGBColor[
             0.2109311914464215, 0.33903243439312675`, 0.9353235913569153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 116}], {
             RGBColor[
             0.2290183753781148, 0.3580432114990334, 0.9363536297242345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 124}], {
             RGBColor[
             0.22172315170383133`, 0.35037546887346516`, 0.9359381775283004]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 128}], {
             RGBColor[
             0.32435782382982603`, 0.44691944921604004`, 0.9421979744658333]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 136}], {
             RGBColor[
             0.22011061631709428`, 0.3486805919413559, 0.935846346023558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 148}], {
             RGBColor[
             0.20549299658683456`, 0.33331654679423195`, 0.9350138942047502]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 193}], {
             RGBColor[
             0.223435169075761, 0.3521749076795341, 0.936035674384929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 138}], {
             RGBColor[
             0.20099999291646117`, 0.32859411506378333`, 0.9347580242925257]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 145}], {
             RGBColor[
             0.18515978669395372`, 0.31194505399684636`, 0.9338559479816391]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 115}], {
             RGBColor[
             0.26758071568904057`, 0.3979941146890951, 0.9385709551564505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 163}], {
             RGBColor[
             0.25094941763616774`, 0.3810941274206381, 0.9376025701367612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 165}], {
             RGBColor[
             0.21296967150778956`, 0.3411750061847254, 0.9354396797807493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 169}], {
             RGBColor[
             0.20611458183414505`, 0.33396987229993624`, 0.9350492925650316]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 175}], {
             RGBColor[
             0.36035371764762536`, 0.477066388889339, 0.9448368758036116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 177}], {
             RGBColor[
             0.21876304030867405`, 0.3472642041152524, 0.9357696035634386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 134}], {
             RGBColor[
             0.5941420485372255, 0.6663173396662936, 0.9607153178159171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 143}], {
             RGBColor[
             0.8985367952768839, 0.9217855718880776, 0.9850776323188054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 156}], {
             RGBColor[
             0.880064299434007, 0.550351383801579, 0.5748087868596949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 160}], {
             RGBColor[
             0.6923008271636373, 0.757058105759987, 0.9667604504602199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 181}], {
             RGBColor[
             0.6897919274498447, 0.754885022928866, 0.9666005855889899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 183}], {
             RGBColor[
             0.9388975158686406, 0.8706580791071786, 0.6258657824409817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 116}], {
             RGBColor[
             0.22254054731904888`, 0.35123460349093416`, 0.9359847269993585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 124}], {
             RGBColor[
             0.2152453236447654, 0.343566860865366, 0.9355692748034243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 128}], {
             RGBColor[
             0.3178799957707601, 0.44011084120794086`, 0.9418290717409573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 136}], {
             RGBColor[
             0.21363278825802834`, 0.3418719839332567, 0.9354774432986821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 148}], {
             RGBColor[
             0.19901516852776863`, 0.3265079387861328, 0.9346449914798742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 187}], {
             RGBColor[
             0.20396723113485943`, 0.331712870565089, 0.934927004119428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 193}], {
             RGBColor[
             0.21695734101669506`, 0.34536629967143495`, 0.9356667716600531]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 198}], {
             RGBColor[
             0.2750384221935423, 0.4030036234554522, 0.939099244555933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 167}], {
             RGBColor[
             0.19037448411434205`, 0.3174260316165872, 0.9341529172852767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 184}], {
             RGBColor[
             0.18161202378548802`, 0.3082161302388885, 0.9336539081324469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 186}], {
             RGBColor[
             0.18224157379578187`, 0.3088778272154834, 0.9336897600741974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 194}], {
             RGBColor[
             0.19146855650738448`, 0.3185759710698711, 0.9342152230895253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 133}], {
             RGBColor[
             0.2820742314375166, 0.41322771868271746`, 0.939396339437091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 163}], {
             RGBColor[
             0.2983939725453868, 0.4303808013184385, 0.9403257245502908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 165}], {
             RGBColor[
             0.2604142264170086, 0.39046168008252585`, 0.9381628341942789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 175}], {
             RGBColor[
             0.4077982725568444, 0.5263530627871394, 0.9475600302171414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 124}], {
             RGBColor[
             0.2333325075764587, 0.3625776379712726, 0.9365993131707435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 128}], {
             RGBColor[
             0.33596717970245343`, 0.45912161831384746`, 0.9428591101082765]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 136}], {
             RGBColor[
             0.23171997218972168`, 0.36088276103916334`, 0.9365074816660013]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 148}], {
             RGBColor[
             0.21710235245946194`, 0.3455187158920394, 0.9356750298471934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 193}], {
             RGBColor[
             0.2350445249483884, 0.36437707677734155`, 0.9366968100273723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 198}], {
             RGBColor[
             0.29312560612523564`, 0.42201440056135886`, 0.9401292829232522]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 121}], {
             RGBColor[
             0.2013378942582586, 0.3289492707981949, 0.9347772672740609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 152}], {
             RGBColor[
             0.19275420690752315`, 0.3199272711553603, 0.934288438977864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 159}], {
             RGBColor[
             0.22010744675454766`, 0.3486772605301575, 0.9358461655216599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 164}], {
             RGBColor[
             0.19024796848068162`, 0.3172930556640557, 0.9341457124071029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 178}], {
             RGBColor[
             0.18448507974982858`, 0.3112358942196798, 0.9338175244193107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 200}], {
             RGBColor[
             0.1879682303409825, 0.3148969063354854, 0.9340158846926173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 119}], {
             RGBColor[
             0.6188466529284243, 0.4369505973479967, 0.5693002587660235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 123}], {
             RGBColor[
             0.42099591367325284`, 0.5390672333790665, 0.9480464652405584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 127}], {
             RGBColor[
             0.6328274279834254, 0.7079836098876566, 0.9670229522085898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 129}], {
             RGBColor[
             0.4226691844013287, 0.5404852315434163, 0.9481617341921013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 139}], {
             RGBColor[
             0.33826776988296947`, 0.4652785641134494, 0.9428532266161497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[
             0.36734166462355905`, 0.4925946195931902, 0.9446276639357014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 146}], {
             RGBColor[
             0.3181356246114969, 0.44411840298139715`, 0.9417067307257794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 155}], {
             RGBColor[
             0.5320287520312512, 0.6287959624909311, 0.9570938290152922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 171}], {
             RGBColor[
             0.3493088123107567, 0.4768833997475762, 0.9434819976486537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 191}], {
             RGBColor[
             0.6004855108108049, 0.6822749027401551, 0.9639169589656551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.44594964518515734`, 0.559385358380535, 0.9499944573441421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 196}], {
             RGBColor[
             0.3119267863848373, 0.4375925203420974, 0.941353146573924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[
             0.6930640728290565, 0.752639828019768, 0.8371662674251406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 123}], {
             RGBColor[
             0.6489751309922214, 0.46304637074551996`, 0.5712200187466816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 127}], {
             RGBColor[
             0.8608066453023939, 0.6319627472541103, 0.5901965057147129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 140}], {
             RGBColor[
             0.9202745550794877, 0.6749563522500728, 0.37533269810004777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 151}], {
             RGBColor[
             0.9203645260018751, 0.6763382789683456, 0.4715886994182685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 155}], {
             RGBColor[
             0.7600079693502197, 0.5527750998573846, 0.5802673825214153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 156}], {
             RGBColor[
             0.8327717722765755, 0.2529037791657479, 0.17901559218345872`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 172}], {
             RGBColor[
             0.858083307192903, 0.43025919736952545`, 0.20258043262042846`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 191}], {
             RGBColor[
             0.8284647281297735, 0.6062540401066088, 0.5870905124717782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 195}], {
             RGBColor[
             0.6739288625041259, 0.48336449574698853`, 0.5731680108502653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 199}], {
             RGBColor[
             0.921043290148025, 0.6766189653862216, 0.46033982093126385`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 124}], {
             RGBColor[
             0.20998768265750406`, 0.3380407468340621, 0.9352698599271827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 125}], {
             RGBColor[
             0.22911059591556282`, 0.35814014113101095`, 0.9363588815474142]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 136}], {
             RGBColor[
             0.208375147270767, 0.3363458699019528, 0.9351780284224404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 137}], {
             RGBColor[
             0.2589152311792967, 0.38806631610919806`, 0.9381074864400005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 187}], {
             RGBColor[
             0.1987095901475981, 0.32618675653378515`, 0.9346275892431862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 198}], {
             RGBColor[
             0.26978078120628096`, 0.39747750942414833`, 0.9387998296796913]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 152}], {
             RGBColor[
             0.20876932330272832`, 0.33676017390374813`, 0.9352004761643293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 159}], {
             RGBColor[
             0.23612256314975283`, 0.36551016327854535`, 0.9367582027081254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 161}], {
             RGBColor[
             0.25059050057240173`, 0.38071688282996385`, 0.9375821303409498]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 164}], {
             RGBColor[
             0.2062630848758868, 0.3341259584124435, 0.9350577495935681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 173}], {
             RGBColor[
             0.292553121290118, 0.41936663602592106`, 0.9401715965504269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 180}], {
             RGBColor[
             0.27969294333585376`, 0.40822779625327543`, 0.9393521573829899]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[
             0.20398334673618768`, 0.33172980908387323`, 0.9349279218790827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 125}], {
             RGBColor[
             0.2711034312291314, 0.40227727354510906`, 0.9387503113956892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 137}], {
             RGBColor[
             0.3009080664928653, 0.4322034485232962, 0.9404989162882755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 166}], {
             RGBColor[
             0.5408265520373148, 0.6280223043100961, 0.9601053035876213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 170}], {
             RGBColor[
             0.4665658605119989, 0.5700092876883599, 0.9527036918619959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 179}], {
             RGBColor[
             0.32323201256899053`, 0.45153932858028145`, 0.9419213783919558]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 192}], {
             RGBColor[
             0.3718189687016956, 0.49328632243521403`, 0.9451102958483188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 127}], {
             RGBColor[
             0.6629559060472224, 0.73407938328518, 0.9689427121892478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 129}], {
             RGBColor[
             0.45279766246512576`, 0.5665810049409397, 0.9500814941727593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 139}], {
             RGBColor[
             0.36839624794676656`, 0.4913743375109727, 0.9447729865968078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 141}], {
             RGBColor[
             0.39747014268735614`, 0.5186903929907134, 0.9465474239163595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 146}], {
             RGBColor[
             0.34826410267529395`, 0.47021417637892043`, 0.9436264907064373]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 155}], {
             RGBColor[
             0.5621572300950483, 0.6548917358884543, 0.9590135889959501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 171}], {
             RGBColor[
             0.3794372903745538, 0.5029791731450995, 0.9454017576293117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 191}], {
             RGBColor[
             0.6306139888746021, 0.7083706761376785, 0.9658367189463131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 195}], {
             RGBColor[
             0.4760781232489544, 0.5854811317780583, 0.9519142173248001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 196}], {
             RGBColor[
             0.3420552644486344, 0.4636882937396207, 0.9432729065545822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 199}], {
             RGBColor[
             0.7231925508928534, 0.7787356014172913, 0.8390860274057987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 125}], {
             RGBColor[
             0.24516019716023396`, 0.37500928964265323`, 0.9372728825950409]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 136}], {
             RGBColor[
             0.22442474851543817`, 0.35321501841359515`, 0.9360920294700671]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.27496483242396785`, 0.4049354646208403, 0.9390214874876273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 187}], {
             RGBColor[
             0.21475919139226923`, 0.3430559050454275, 0.935541590290813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 198}], {
             RGBColor[
             0.28583038245095216`, 0.4143466579357906, 0.9397138307273181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 136}], {
             RGBColor[
             0.24354766177349693`, 0.373314412710544, 0.9371810510902985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 137}], {
             RGBColor[
             0.29408774568202667`, 0.42503485891778914`, 0.9401105091078588]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 166}], {
             RGBColor[
             0.5340062312264762, 0.620853714704589, 0.9597168964072044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[
             0.4597455397011603, 0.5628406980828529, 0.952315284681579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 187}], {
             RGBColor[
             0.233882104650328, 0.36315529934237634`, 0.9366306119110444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 192}], {
             RGBColor[
             0.364998647890857, 0.48611773282970705`, 0.9447218886679021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 198}], {
             RGBColor[
             0.30495329570901086`, 0.43444605223273947`, 0.9408028523475496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 190}], {
             RGBColor[
             0.18192592123823295`, 0.3085460563639715, 0.933671784128011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 129}], {
             RGBColor[
             0.6646291767752983, 0.7354973814495299, 0.9690579811407907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 139}], {
             RGBColor[
             0.5802277622569392, 0.660290714019563, 0.9637494735648391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 140}], {
             RGBColor[
             0.9342553301344888, 0.9459893647897327, 0.7730553915426139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 141}], {
             RGBColor[
             0.6093016569975287, 0.6876067694993037, 0.9655239108843909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 155}], {
             RGBColor[
             0.7739887444052208, 0.8238081123970447, 0.9779900759639816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 172}], {
             RGBColor[
             0.8720640822479042, 0.7012922099091854, 0.6003031260629946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 191}], {
             RGBColor[
             0.8424455031847746, 0.8772870526462687, 0.9848132059143445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 195}], {
             RGBColor[
             0.6879096375591269, 0.7543975082866485, 0.9708907042928315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 199}], {
             RGBColor[
             0.935024065203026, 0.9476519779258816, 0.8580625143738301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 136}], {
             RGBColor[
             0.3270594206414329, 0.44975899875617, 0.9423518264076001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 162}], {
             RGBColor[
             0.4413593088202362, 0.5567049827613839, 0.9493440027726809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 193}], {
             RGBColor[
             0.3303839734000996, 0.45325331449434825`, 0.942541154768971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 198}], {
             RGBColor[
             0.38846505457694686`, 0.5108906382783656, 0.9459736276648509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 139}], {
             RGBColor[
             0.3700695186748425, 0.49279233567532266`, 0.9448882555483507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 141}], {
             RGBColor[
             0.399143413415432, 0.5201083911550634, 0.9466626928679024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 146}], {
             RGBColor[
             0.3499373734033699, 0.4716321745432704, 0.9437417596579802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 155}], {
             RGBColor[
             0.5638305008231241, 0.6563097340528043, 0.959128857947493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 191}], {
             RGBColor[
             0.632287259602678, 0.7097886743020284, 0.965951987897856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 195}], {
             RGBColor[
             0.47775139397703026`, 0.5868991299424082, 0.952029486276343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 131}], {
             RGBColor[
             0.18289522364297445`, 0.3095648546486768, 0.9337269844660065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 149}], {
             RGBColor[
             0.1848995905074315, 0.3116715713074204, 0.9338411301937424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 157}], {
             RGBColor[
             0.19536013163296237`, 0.32266626326696746`, 0.9344368425358576]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 168}], {
             RGBColor[
             0.19684636692721422`, 0.32422839079398647`, 0.9345214814371772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 189}], {
             RGBColor[
             0.18936342684036145`, 0.3163633463169, 0.9340953390692487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 197}], {
             RGBColor[
             0.19250062713784824`, 0.3196607427395459, 0.9342739979851187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 147}], {
             RGBColor[
             0.21550989668752718`, 0.3438449439082084, 0.9355843418468089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 157}], {
             RGBColor[
             0.19396001666235732`, 0.3211946536604452, 0.9343571080595661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 176}], {
             RGBColor[
             0.20779145347843028`, 0.335732370717883, 0.9351447879244643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 138}], {
             RGBColor[
             0.2612195562179643, 0.3918886942345018, 0.9381874393356859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 145}], {
             RGBColor[
             0.24537934999545682`, 0.37523963316756476`, 0.9372853630247993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 153}], {
             RGBColor[
             0.29141110867079584`, 0.42362193011741534`, 0.9399068035834754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 182}], {
             RGBColor[
             0.3206991952751244, 0.45143891338558356`, 0.9416833404765177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 185}], {
             RGBColor[
             0.26630785953473646`, 0.397236823637493, 0.9384772106821059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 163}], {
             RGBColor[
             0.26544293338464375`, 0.39632773141426036`, 0.9384279544174017]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 178}], {
             RGBColor[
             0.21638528695668868`, 0.3447650345840459, 0.9356341940276138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 135}], {
             RGBColor[
             0.22190471606791506`, 0.3505663045319628, 0.9359485173502345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 160}], {
             RGBColor[
             0.3450319511386071, 0.4675505014401682, 0.9434155666515178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 144}], {
             RGBColor[
             0.19771245739729065`, 0.32513870679134427`, 0.9345708040081819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 148}], {
             RGBColor[
             0.2081945933984414, 0.33615609633436194`, 0.9351677461465169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 187}], {
             RGBColor[
             0.2131466560055322, 0.3413610281133182, 0.9354497587860706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 193}], {
             RGBColor[
             0.22613676588736786`, 0.35501445721966407`, 0.9361895263266957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 198}], {
             RGBColor[
             0.2842178470642151, 0.4126517810036814, 0.9396219992225757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 166}], {
             RGBColor[
             0.5638108664902101, 0.6507798896827761, 0.9614655012997908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 170}], {
             RGBColor[
             0.48955017496489417`, 0.59276687306104, 0.9540638895741654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 179}], {
             RGBColor[
             0.3462163270218858, 0.4742969139529616, 0.9432815761041253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 187}], {
             RGBColor[
             0.2636867399140619, 0.3930814743205634, 0.9383792168036308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 192}], {
             RGBColor[
             0.3948032831545909, 0.5160439078078941, 0.9464704935604884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 198}], {
             RGBColor[
             0.3347579309727448, 0.4643722272109265, 0.9425514572401359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 145}], {
             RGBColor[
             0.20603341116594734`, 0.3338845567811428, 0.935044670015559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 153}], {
             RGBColor[
             0.25206516984128635`, 0.38226685373099345`, 0.9376661105742352]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 182}], {
             RGBColor[
             0.28135325644561493`, 0.4100838369991616, 0.9394426474672775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 185}], {
             RGBColor[
             0.22696192070522694`, 0.35588174725107113`, 0.9362365176728656]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 141}], {
             RGBColor[
             0.31474199889707277`, 0.4449017237250964, 0.9413541852919508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 146}], {
             RGBColor[
             0.2655359588850107, 0.39642550711330343`, 0.9384332520820287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 155}], {
             RGBColor[
             0.47942908630476494`, 0.5811030666228374, 0.9538203503715414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 171}], {
             RGBColor[
             0.2967091465842705, 0.42919050387948254`, 0.940208519004903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 191}], {
             RGBColor[
             0.5478858450843187, 0.6345820068720615, 0.9606434803219044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 194}], {
             RGBColor[
             0.2435950267958037, 0.37336419635210427`, 0.9371837484582486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 195}], {
             RGBColor[
             0.39334997945867106`, 0.5116924625124413, 0.9467209787003914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 196}], {
             RGBColor[
             0.25932712065835106`, 0.3898996244740037, 0.9380796679301735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 151}], {
             RGBColor[
             0.9938132108339699, 0.9903648965039682, 0.6544475852461695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 161}], {
             RGBColor[
             0.6387756152014612, 0.7023172809495201, 0.7488332700746612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 162}], {
             RGBColor[
             0.7225676146989453, 0.7771975396388044, 0.7540880673117176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 172}], {
             RGBColor[
             0.931531992024998, 0.7442858149051479, 0.38543931844832946`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 173}], {
             RGBColor[
             0.6807382359191774, 0.7409670341454773, 0.7514227362841381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 180}], {
             RGBColor[
             0.6678780579649132, 0.7298281943728316, 0.7506032971167013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 191}], {
             RGBColor[
             0.9019134129618684, 0.9202806576422312, 0.7699493982996792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 146}], {
             RGBColor[
             0.2946098536256002, 0.4237415625930442, 0.9402076894015805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 155}], {
             RGBColor[
             0.5085029810453545, 0.6084191221025781, 0.9555947876910933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 167}], {
             RGBColor[
             0.27157484914335084`, 0.3995303123785612, 0.9388958799735516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 191}], {
             RGBColor[
             0.5769597398249082, 0.6618980623518022, 0.9624179176414562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 194}], {
             RGBColor[
             0.2726689215363932, 0.40068025183184497`, 0.9389581857778003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 195}], {
             RGBColor[
             0.42242387419926064`, 0.539008517992182, 0.9484954160199432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 147}], {
             RGBColor[
             0.25576128412159904`, 0.3861517041867828, 0.9378765988145878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 154}], {
             RGBColor[
             0.29693436368645065`, 0.4272891715192359, 0.9402996292628881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 157}], {
             RGBColor[
             0.2342114040964292, 0.3635014139390195, 0.9366493650273451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 168}], {
             RGBColor[
             0.23569763939068106`, 0.3650635414660385, 0.9367340039286646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 176}], {
             RGBColor[
             0.24804284091250217`, 0.37803913099645736`, 0.9374370448922433]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.2876001150236012, 0.4192043144804547, 0.9397048591920434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 154}], {
             RGBColor[
             0.5937667549119501, 0.6748088886146058, 0.9642312788067474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 158}], {
             RGBColor[
             0.5860035167018279, 0.6680847618686957, 0.9637366121327604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 160}], {
             RGBColor[
             0.6494266978782655, 0.7230187336619522, 0.967777881154406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 181}], {
             RGBColor[
             0.6469177981644729, 0.7208456508308313, 0.967618016283176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 188}], {
             RGBColor[
             0.5844325062491007, 0.6667240315758246, 0.9636365087359027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 158}], {
             RGBColor[
             0.2574165112915451, 0.3871889319062931, 0.9379965842878197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 153}], {
             RGBColor[
             0.2362249636187789, 0.3656177926640565, 0.9367640342633485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 185}], {
             RGBColor[
             0.2111217144827195, 0.33923268618413416`, 0.935334441361979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 155}], {
             RGBColor[
             0.4592969410332923, 0.5599429054907851, 0.9526738544811711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 171}], {
             RGBColor[
             0.27657700131279794`, 0.4080303427474302, 0.9390620231145327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 184}], {
             RGBColor[
             0.21360634880243462`, 0.34184419438906943`, 0.9354759376107997]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 186}], {
             RGBColor[
             0.2142358988127285, 0.34250589136566434`, 0.9355117895525502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 191}], {
             RGBColor[
             0.527753699812846, 0.6134218457400091, 0.9594969844315341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 194}], {
             RGBColor[
             0.22346288152433108`, 0.352204035220052, 0.9360372525678782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 195}], {
             RGBColor[
             0.37321783418719845`, 0.490532301380389, 0.9455744828100211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 196}], {
             RGBColor[
             0.23919497538687848`, 0.3687394633419514, 0.9369331720398031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 154}], {
             RGBColor[
             0.2906977642675366, 0.42073411010671546`, 0.939944464152203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 157}], {
             RGBColor[
             0.2279748046775151, 0.3569463525264991, 0.9362941999166599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 168}], {
             RGBColor[
             0.22946103997176695`, 0.35850848005351804`, 0.9363788388179795]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 176}], {
             RGBColor[
             0.24180624149358806`, 0.37148406958393687`, 0.9370818797815581]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 188}], {
             RGBColor[
             0.2813635156046871, 0.41264925306793426`, 0.9393496940813583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 150}], {
             RGBColor[
             0.19306951159997304`, 0.3202586763785973, 0.9343063951136474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 193}], {
             RGBColor[
             0.21151914615710812`, 0.33965041207254015`, 0.9353570745078879]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 167}], {
             RGBColor[
             0.19241882352516138`, 0.31957476195596346`, 0.9342693393903937]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 168}], {
             RGBColor[
             0.19745061882106624`, 0.32486349784620777`, 0.9345558926886215]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 189}], {
             RGBColor[
             0.18996767873421347`, 0.31699845336912136`, 0.934129750320693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 194}], {
             RGBColor[
             0.1935128959182038, 0.3207247014092473, 0.9343316451946424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.19310487903170026`, 0.3202958497917673, 0.934308409236563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 156}], {
             RGBColor[
             0.9063104280310577, 0.5683123234196433, 0.4581304793295804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 172}], {
             RGBColor[
             0.9316219629473853, 0.7456677416234209, 0.4816953197665501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 175}], {
             RGBColor[
             0.7472372281358932, 0.7985860801048122, 0.8522647687143463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 183}], {
             RGBColor[
             0.9651436444656913, 0.888619018725243, 0.5091874749108671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 199}], {
             RGBColor[
             0.9945819459025071, 0.992027509640117, 0.7394547080773856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 159}], {
             RGBColor[
             0.22753887579901738`, 0.3564881636357107, 0.9362693744119284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 178}], {
             RGBColor[
             0.19191650879429833`, 0.319046797325233, 0.9342407333095791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 200}], {
             RGBColor[
             0.19539965938545223`, 0.3227078094410386, 0.9344390935828858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 182}], {
             RGBColor[
             0.3115448088984465, 0.4418170728820753, 0.941162011715067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 185}], {
             RGBColor[
             0.2571534731580585, 0.38761498313398474`, 0.937955881920655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 157}], {
             RGBColor[
             0.2691478842423667, 0.3980838198589522, 0.9387172303649602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 158}], {
             RGBColor[
             0.3241076056222659, 0.45514745069325846`, 0.9418728279265163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 160}], {
             RGBColor[
             0.38753078679870345`, 0.510081422486515, 0.9459140969481619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 176}], {
             RGBColor[
             0.28297932105843965`, 0.41262153691639003`, 0.9395049102298585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 181}], {
             RGBColor[
             0.3850218870849109, 0.5079083396553941, 0.9457542320769319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 188}], {
             RGBColor[
             0.3225365951695387, 0.45378672040038737`, 0.9417727245296585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 172}], {
             RGBColor[
             0.77126540629573, 0.6221045625124598, 0.590374002869697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 191}], {
             RGBColor[
             0.7416468272326004, 0.7980994052495431, 0.9748840827210469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 195}], {
             RGBColor[
             0.5871109616069528, 0.6752098608899229, 0.9609615810995339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 199}], {
             RGBColor[
             0.8342253892508518, 0.868464330529156, 0.8481333911805324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 166}], {
             RGBColor[
             0.8112235131702088, 0.49573828454331076`, 0.5733146303469535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 170}], {
             RGBColor[
             0.7369628216448929, 0.4377252679215747, 0.5659130186213281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 175}], {
             RGBColor[
             0.6596444744105936, 0.3751515803022144, 0.5596916614795366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 183}], {
             RGBColor[
             0.8775508907403917, 0.4651845189226452, 0.21661436767605732`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 199}], {
             RGBColor[
             0.9069891921772075, 0.5685930098375191, 0.4468816008425758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 168}], {
             RGBColor[
             0.2079111599465971, 0.33585818980575477`, 0.9351516050307367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 176}], {
             RGBColor[
             0.2202563614684182, 0.34883377933617365`, 0.9358546459943153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 188}], {
             RGBColor[
             0.25981363557951725`, 0.389998962820171, 0.9381224602941154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 160}], {
             RGBColor[
             0.3797675485885813, 0.503357295740605, 0.945419430274175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 176}], {
             RGBColor[
             0.27521608284831744`, 0.40589741017048, 0.9390102435558715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.37725864887478877`, 0.501184212909484, 0.945259565402945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 161}], {
             RGBColor[
             0.2693600530686908, 0.4004448725619264, 0.938651028588549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 162}], {
             RGBColor[
             0.3531520525661749, 0.4753251312512108, 0.9439058258256054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 164}], {
             RGBColor[
             0.22503263737217588`, 0.35385394814440607`, 0.9361266478411673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 173}], {
             RGBColor[
             0.3113226737864071, 0.4390946257578836, 0.941240494798026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 180}], {
             RGBColor[
             0.29846249583214285`, 0.427955785985238, 0.9404210556305891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 200}], {
             RGBColor[
             0.22275289923247676`, 0.35145779881583583`, 0.9359968201266817]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[
             0.4406818300512263, 0.5561181847027405, 0.9493008344245906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 162}], {
             RGBColor[
             0.3676199899888237, 0.4905318508026293, 0.94472975345843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 164}], {
             RGBColor[
             0.23950057479482478`, 0.3690606676958246, 0.9369505754739917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 173}], {
             RGBColor[
             0.32579061120905595`, 0.4543013453093021, 0.9420644224308505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 180}], {
             RGBColor[
             0.31293043325479175`, 0.4431625055366565, 0.9412449832634135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 200}], {
             RGBColor[
             0.23722083665512567`, 0.36666451836725433`, 0.9368207477595063]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 172}], {
             RGBColor[
             0.6603763668123606, 0.5325003847582571, 0.5813358018320983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 173}], {
             RGBColor[
             0.40958261070654, 0.5291816039985865, 0.947319219667907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 180}], {
             RGBColor[
             0.3967224327522758, 0.5180427642259409, 0.9464997805004701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 165}], {
             RGBColor[
             0.24378292836413576`, 0.3735616928140688, 0.9371944491745896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 175}], {
             RGBColor[
             0.39116697450397153`, 0.5094530755186824, 0.9465916451974521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 177}], {
             RGBColor[
             0.24957629716502022`, 0.3796508907445958, 0.937524372957279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 200}], {
             RGBColor[
             0.19289342095861073`, 0.320073593949734, 0.9342963670121247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 169}], {
             RGBColor[
             0.1989480925621131, 0.32643743769336697`, 0.9346411716028602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 175}], {
             RGBColor[
             0.35318722837559335`, 0.4695339542827697, 0.9444287548414402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 177}], {
             RGBColor[
             0.2115965510366421, 0.3397317695086831, 0.9353614826012671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 170}], {
             RGBColor[
             0.7294686605093437, 0.78858572884784, 0.973670276873511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 179}], {
             RGBColor[
             0.5861348125663353, 0.6701157697397615, 0.962887963403471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 183}], {
             RGBColor[
             0.8700567296048425, 0.8160449798489104, 0.6243716259282402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 192}], {
             RGBColor[
             0.6347217686990404, 0.711862763594694, 0.9660768808598341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 198}], {
             RGBColor[
             0.5746764165171943, 0.6601910829977264, 0.9621578445394816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 189}], {
             RGBColor[
             0.19688265985809134`, 0.32426653696544305`, 0.9345235482659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 194}], {
             RGBColor[
             0.2004278770420817, 0.327992785005569, 0.9347254431398494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 197}], {
             RGBColor[
             0.20001986015557813`, 0.327563933388089, 0.9347022071817699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 188}], {
             RGBColor[
             0.2612998708737691, 0.39156109034719, 0.938207099195435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 189}], {
             RGBColor[
             0.2019144551539962, 0.3295552728556873, 0.9348101015641277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 197}], {
             RGBColor[
             0.20505165545148296`, 0.3328526692783333, 0.9349887604799977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 177}], {
             RGBColor[
             0.20474146136299756`, 0.33252663562389395`, 0.9349710953855495]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 190}], {
             RGBColor[
             0.18813962732028144`, 0.31507705542792475`, 0.9340256454970293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 179}], {
             RGBColor[
             0.5118741210410194, 0.6121027531180253, 0.9554863516778458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 183}], {
             RGBColor[
             0.7957960380795266, 0.7580319632271744, 0.6169700142026149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[
             0.5604610771737245, 0.6538497469729578, 0.9586752691342088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 198}], {
             RGBColor[
             0.5004157249918784, 0.6021780663759904, 0.9547562328138562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 174}], {
             RGBColor[
             0.24889168370669917`, 0.37893131859289997`, 0.9374853852336225]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 182}], {
             RGBColor[
             0.3242915422574164, 0.45521469783192636`, 0.9418879193227581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 191}], {
             RGBColor[
             0.558926887512106, 0.6461868425061883, 0.9612722513544084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 195}], {
             RGBColor[
             0.4043910218864583, 0.5232972981465681, 0.9473497497328954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 196}], {
             RGBColor[
             0.2703681630861383, 0.4015044601081305, 0.9387084389626774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 199}], {
             RGBColor[
             0.6515054495303574, 0.7165517677858011, 0.834521559813894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 173}], {
             RGBColor[
             0.6185469880325928, 0.49626987926492994`, 0.5786704708045187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 180}], {
             RGBColor[
             0.6056868100783286, 0.4851310394922843, 0.577851031637082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 191}], {
             RGBColor[
             0.8397221650752837, 0.6755835027616839, 0.59719713282006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 180}], {
             RGBColor[
             0.35489305397250803`, 0.4818122587326137, 0.9438344494728906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 186}], {
             RGBColor[
             0.18655058120662976`, 0.3134068672111341, 0.9339351516716399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 196}], {
             RGBColor[
             0.21150965778077974`, 0.33964043918742115`, 0.9353565341588927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 183}], {
             RGBColor[
             0.7184776908452273, 0.695458275607814, 0.6107486570608233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 188}], {
             RGBColor[
             0.2736450723955902, 0.4045366798776089, 0.9389101401590136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 179}], {
             RGBColor[
             0.2929650964677688, 0.41972688072457853`, 0.940197722295881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 190}], {
             RGBColor[
             0.20078808579481044`, 0.3283713872432409, 0.9347459564954362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 183}], {
             RGBColor[
             0.6524621901365182, 0.6395620041190959, 0.6061877007325749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 192}], {
             RGBColor[
             0.41712722923071616`, 0.5353797878648794, 0.9478929556641686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 185}], {
             RGBColor[
             0.28644155976238705`, 0.41543196640215296`, 0.9397324188136974]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 195}], {
             RGBColor[
             0.42093237513181697`, 0.5377166564648852, 0.9484003790182465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 196}], {
             RGBColor[
             0.28690951633149697`, 0.41592381842644754`, 0.9397590682480286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 199}], {
             RGBColor[
             0.668046802775716, 0.7309711261041182, 0.8355721890992451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 192}], {
             RGBColor[
             0.7010491462692232, 0.6813089979740284, 0.609376618188938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 186}], {
             RGBColor[
             0.18243843400162507`, 0.3090847397734826, 0.9337009709716915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 194}], {
             RGBColor[
             0.19166541671322765`, 0.3187828836278702, 0.9342264339870195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 198}], {
             RGBColor[
             0.2745522899410462, 0.4024926676355137, 0.9390715600433216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 194}], {
             RGBColor[
             0.19797673225113377`, 0.32541647641872684`, 0.9345858540701487]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 197}], {
             RGBColor[
             0.19756871536463022`, 0.3249876248012469, 0.9345626181120692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 195}], {
             RGBColor[
             0.6555677203865065, 0.728688801139147, 0.9677847110498968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 199}], {
             RGBColor[
             0.9026821480304056, 0.9219432707783801, 0.8549565211308954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 197}], {
             RGBColor[
             0.20111393254862053`, 0.3287138728413728, 0.9347645129860187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 196}], {
             RGBColor[
             0.3670089959605389, 0.4840064187410893, 0.9452208986581658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 199}], {
             RGBColor[
             0.748146282404758, 0.7990537264187598, 0.8410340195093824]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.04610843439966642], {
             RGBColor[
             0.17991592983646426`, 0.30643342795989703`, 0.9335573180911961]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.04610843439966642], {
             RGBColor[
             0.18237351643808017`, 0.30901650729818564`, 0.9336972740124846]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.04610843439966642], {
             RGBColor[
             0.4186929718519593, 0.5370725409226834, 0.947899723824117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.04610843439966642], {
             RGBColor[
             0.33430755049502603`, 0.4639821302779076, 0.9425227593943515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.04610843439966642], {
             RGBColor[
             0.35433408061295757`, 0.481328104103389, 0.9437988321847008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.04610843439966642], {
             RGBColor[
             0.8314330293974257, 0.24261361475573226`, 0.17773361049049105`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.04610843439966642], {
             RGBColor[
             0.20849433214894747`, 0.33647114076567824`, 0.9351848158249345]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.04610843439966642], {
             RGBColor[
             0.28326421471662644`, 0.41505902802867256`, 0.939442850025035]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.04610843439966642], {
             RGBColor[
             0.19331350997927296`, 0.32051513414563226`, 0.9343202904603853]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.04610843439966642], {
             RGBColor[
             0.2179504265625759, 0.34641009554541596`, 0.9357233264127526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.04610843439966642], {
             RGBColor[
             0.20295626314304663`, 0.3306502791066209, 0.9348694309878873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.04610843439966642], {
             RGBColor[
             0.950102117301832, 0.8398785531251466, 0.2787091962084557]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.04610843439966642], {
             RGBColor[
             0.22110598802207443`, 0.3497267907135012, 0.9359030309696362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.04610843439966642], {
             RGBColor[
             0.17925722738073346`, 0.3057410899147761, 0.9335198059608052]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.04610843439966642], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.04610843439966642], {
             RGBColor[
             0.1871756577266932, 0.3140638622658612, 0.9339707488547396]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.04610843439966642], {
             RGBColor[
             0.19146922694525287`, 0.31857667574257903`, 0.9342152612699701]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.04610843439966642], {
             RGBColor[
             0.22306772190849825`, 0.3517886974092449, 0.9360147488123428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.04610843439966642], {
             RGBColor[
             0.35121665541737046`, 0.47862794708531764`, 0.9436001926078689]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.04610843439966642], {
             RGBColor[
             0.1823235017276304, 0.3089639386663871, 0.9336944257487145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.04610843439966642], {
             RGBColor[
             0.36130368564417137`, 0.48736482567889206`, 0.94424292925431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.04610843439966642], {
             RGBColor[
             0.18848942771341942`, 0.31544471781973865`, 0.9340455661119352]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.04610843439966642], {
             RGBColor[
             0.22363768830217948`, 0.3523877682269605, 0.9360472075552733]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.04610843439966642], {
             RGBColor[
             0.2571472380542651, 0.3876084296445695, 0.9379555268407181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.04610843439966642], {
             RGBColor[
             0.17953882470990998`, 0.3060370665620425, 0.9335358425121159]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.04610843439966642], {
             RGBColor[
             0.2927822195605681, 0.4250630545960175, 0.9399848863202711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.04610843439966642], {
             RGBColor[
             0.26652048668465833`, 0.39746030825340095`, 0.9384893194837403]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.04610843439966642], {
             RGBColor[
             0.1792907180836107, 0.3057762907669333, 0.933521713206789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.04610843439966642], {
             RGBColor[
             0.20691074357712266`, 0.33480668877137576`, 0.9350946327984784]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.04610843439966642], {
             RGBColor[
             0.2095661987749073, 0.33759774054983127`, 0.9352458570435983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.04610843439966642], {
             RGBColor[
             0.531961775829707, 0.6309095600802831, 0.9562971261149575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.04610843439966642], {
             RGBColor[
             0.186006868294159, 0.3128353904667376, 0.9339041880256258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.04610843439966642], {
             RGBColor[
             0.9926235425767636, 0.9912176595362523, 0.7719105193703001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.04610843439966642], {
             RGBColor[
             0.4300571649791395, 0.5469156338284925, 0.9486238401612196]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.04610843439966642], {
             RGBColor[
             0.18077756667952594`, 0.30733906291288604`, 0.933606387034731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.04610843439966642], {
             RGBColor[
             0.18255152448721731`, 0.309203605044191, 0.9337074113075435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.04610843439966642], {
             RGBColor[
             0.23584637567939642`, 0.36521987273590373`, 0.9367424742402714]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.04610843439966642], {
             RGBColor[
             0.18112444186066054`, 0.30770365072141526`, 0.9336261410631407]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.04610843439966642], {
             RGBColor[
             0.25206224059906557`, 0.3822637749116947, 0.9376659437582241]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.04610843439966642], {
             RGBColor[
             0.5058302216121423, 0.609694787153362, 0.9542399544439137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.04610843439966642], {
             RGBColor[
             0.29070628845368207`, 0.422881119381046, 0.9398666651147989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.04610843439966642], {
             RGBColor[
             0.2027701922068055, 0.3304547067550528, 0.9348588345233357]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.04610843439966642], {
             RGBColor[
             0.18974733652345127`, 0.3167668597351072, 0.9341172021577572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.04610843439966642], {
             RGBColor[
             0.8987739036289236, 0.6332377629819576, 0.2372468027203504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.04610843439966642], {
             RGBColor[
             0.7110429824499928, 0.7741914491075349, 0.9718337774823064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.04610843439966642], {
             RGBColor[
             0.18297903858873563`, 0.3096529494708463, 0.9337317576031746]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.04610843439966642], {
             RGBColor[
             0.1962609887352336, 0.32361312119909375`, 0.9344881450151332]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.04610843439966642], {
             RGBColor[
             0.21049372737267863`, 0.3385726319147987, 0.9352986784250858]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.04610843439966642], {
             RGBColor[
             0.4223544797753533, 0.5402439550531881, 0.9481330318712514]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.04610843439966642], {
             RGBColor[
             0.20374667641262958`, 0.33148105356804847`, 0.9349144438542785]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.04610843439966642], {
             RGBColor[
             0.18219656266820544`, 0.3088305176665303, 0.9336871967570698]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.04610843439966642], {
             RGBColor[
             0.18558886593634766`, 0.31239604348579764`, 0.9338803834097276]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.04610843439966642], {
             RGBColor[
             0.631783197735858, 0.7119490872875069, 0.9641554341053266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.04610843439966642], {
             RGBColor[
             0.988392764379178, 0.9725082101217492, 0.4094085107659739]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.04610843439966642], {
             RGBColor[
             0.33587823342715956`, 0.465342576888902, 0.9426228419218866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.04610843439966642], {
             RGBColor[
             0.1825695689347496, 0.30922257090263144`, 0.9337084389121362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.04610843439966642], {
             RGBColor[
             0.1818396285304826, 0.30845535725685214`, 0.9336668698859633]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.04610843439966642], {
             RGBColor[
             0.9605766768067475, 0.9701187306290152, 0.9516175823034524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.04610843439966642], {
             RGBColor[
             0.18422301466471383`, 0.3109604471993381, 0.9338026002004038]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.04610843439966642], {
             RGBColor[
             0.18098071777705174`, 0.3075525875969092, 0.9336179561892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.04610843439966642], {
             RGBColor[
             0.2073405252862433, 0.3352584165973958, 0.9351191082310077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.04610843439966642], {
             RGBColor[
             0.1999014029793203, 0.32743942738522325`, 0.9346954612208237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.04610843439966642], {
             RGBColor[
             0.19167260114558432`, 0.31879043492179643`, 0.9342268431298139]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.04610843439966642], {
             RGBColor[
             0.6295309817704698, 0.7101206369056319, 0.9639781314143923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.04610843439966642], {
             RGBColor[
             0.95633856953826, 0.8643818842404721, 0.284884016735784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.04610843439966642], {
             RGBColor[
             0.18354617680954663`, 0.31024904769955874`, 0.9337640552858439]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.04610843439966642], {
             RGBColor[
             0.2558901091184015, 0.3862871074263986, 0.9378839352075763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.04610843439966642], {
             RGBColor[
             0.9609913119589255, 0.8800766769412489, 0.30295904244338884`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.04610843439966642], {
             RGBColor[
             0.24981404640376637`, 0.37990078026869034`, 0.9375379124247071]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.04610843439966642], {
             RGBColor[
             0.19105055232810444`, 0.31813662217445204`, 0.9341914183698972]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.04610843439966642], {
             RGBColor[
             0.3637386159115608, 0.4894738398933511, 0.9443980808578237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.04610843439966642], {
             RGBColor[
             0.2532013109542942, 0.38346101007627187`, 0.9377308121298508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.04610843439966642], {
             RGBColor[
             0.21747923322295587`, 0.34591484147009205`, 0.9356964926491292]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.04610843439966642], {
             RGBColor[
             0.34593054718585675`, 0.47404938582270545`, 0.9432633664656788]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.04610843439966642], {
             RGBColor[
             0.5021423004164799, 0.6067007665877667, 0.9539496277780908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.04610843439966642], {
             RGBColor[
             0.26424845016803866`, 0.3950722538189983, 0.9383599303652956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.04610843439966642], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.04610843439966642], {
             RGBColor[
             0.18293127670980908`, 0.3096027487078165, 0.9337290376348271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.04610843439966642], {
             RGBColor[
             0.1941778278429074, 0.3214235870212298, 0.9343695120840757]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.04610843439966642], {
             RGBColor[
             0.22179319725678925`, 0.3504490911907685, 0.9359421665189183]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.04610843439966642], {
             RGBColor[
             0.30602988251049323`, 0.4389871883067331, 0.9407393211271083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.04610843439966642], {
             RGBColor[
             0.21196511221078973`, 0.3401191506708405, 0.9353824716148974]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.04610843439966642], {
             RGBColor[
             0.9263859833659136, 0.9441390533310817, 0.9928407161596127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.04610843439966642], {
             RGBColor[
             0.181234979779358, 0.3078198330824752, 0.9336324360340843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.04610843439966642], {
             RGBColor[
             0.2704719529099895, 0.40161354979365305`, 0.9387143496396024]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.04610843439966642], {
             RGBColor[
             0.2020967142561969, 0.3297468387279948, 0.9348204809503698]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.04610843439966642], {
             RGBColor[
             0.21670300720810273`, 0.3450989787129095, 0.9356522877259069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.04610843439966642], {
             RGBColor[
             0.21656281497127022`, 0.34495162778329735`, 0.9356443039854151]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.04610843439966642], {
             RGBColor[
             0.2675148103379351, 0.39850540545675567`, 0.9385459447448243]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.04610843439966642], {
             RGBColor[
             0.22727061882380845`, 0.3562062085462915, 0.9362540975740409]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.04610843439966642], {
             RGBColor[
             0.18623437450108682`, 0.31307451391494534`, 0.9339171441675451]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.04610843439966642], {
             RGBColor[
             0.2444470173259052, 0.37425969241856055`, 0.9372322680585309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.04610843439966642], {
             RGBColor[
             0.23138676958404353`, 0.3605325439743302, 0.9364885062705369]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.04610843439966642], {
             RGBColor[
             0.19041076970754647`, 0.3174641700756846, 0.9341549836961299]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.04610843439966642], {
             RGBColor[
             0.24919784069125972`, 0.37925310899514714`, 0.9375028204209744]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.04610843439966642], {
             RGBColor[
             0.9364164576881094, 0.9521000787690629, 0.9925145312769647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.04610843439966642], {
             RGBColor[
             0.21679935925455723`, 0.3452002508228058, 0.9356577748324124]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.04610843439966642], {
             RGBColor[
             0.19250116414799295`, 0.31966130717125646`, 0.9342740285670519]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.04610843439966642], {
             RGBColor[
             0.5518206973838005, 0.647031927232117, 0.9578604931653224]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.04610843439966642], {
             RGBColor[
             0.20579087184942513`, 0.3336296325815971, 0.9350308577602878]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.04610843439966642], {
             RGBColor[
             0.19619436846660787`, 0.3235430990727991, 0.9344843510893909]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.04610843439966642], {
             RGBColor[
             0.9691756477061694, 0.9765318290462814, 0.9370617675415293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.04610843439966642], {
             RGBColor[
             0.1810808656124072, 0.3076578493216073, 0.933623659460268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.04610843439966642], {
             RGBColor[
             0.36710024085613885`, 0.49238551046016216`, 0.9446122806267241]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.04610843439966642], {
             RGBColor[
             0.20575656042090384`, 0.333593569094751, 0.9350289037751928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.04610843439966642], {
             RGBColor[
             0.18503007033382515`, 0.31180871387785897`, 0.9338485608268279]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.04610843439966642], {
             RGBColor[
             0.21763298899601496`, 0.34607644853625624`, 0.9357052488129437]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.04610843439966642], {
             RGBColor[
             0.3080267094125234, 0.4410859799869048, 0.9408530374651383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.04610843439966642], {
             RGBColor[
             0.21740901950548744`, 0.34584104240122593`, 0.9356924940817913]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.04610843439966642], {
             RGBColor[
             0.18012636844446756`, 0.30665461227948687`, 0.9335693022586058]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.04610843439966642], {
             RGBColor[
             0.2201361607798215, 0.3487074407912947, 0.9358478007429207]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.04610843439966642], {
             RGBColor[
             0.9414109245622558, 0.9558249439861124, 0.9840602016246193]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.04610843439966642], {
             RGBColor[
             0.20445336338735556`, 0.33222382638502757`, 0.9349546886320393]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.04610843439966642], {
             RGBColor[
             0.18141516357964482`, 0.30800921768088935`, 0.9336426972349526]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.04610843439966642], {
             RGBColor[
             0.31502527059825963`, 0.4472807885868956, 0.9412941095699802]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.04610843439966642], {
             RGBColor[
             0.24062773125074222`, 0.3702453805968408, 0.9370147653666777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.04610843439966642], {
             RGBColor[
             0.1853227778630534, 0.31211636804980714`, 0.9338652300875955]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.04610843439966642], {
             RGBColor[
             0.39086743560945575`, 0.5129714599815431, 0.9461267052599003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.04610843439966642], {
             RGBColor[
             0.8468258702473929, 0.3609297347144502, 0.19247381227214683`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.04610843439966642], {
             RGBColor[
             0.1939380814128329, 0.3211715983224198, 0.934355858879556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.04610843439966642], {
             RGBColor[
             0.21735301065346377`, 0.34578217354658275`, 0.9356893044605262]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.04610843439966642], {
             RGBColor[
             0.27792375203997, 0.40944586315061604`, 0.939138718576106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.04610843439966642], {
             RGBColor[
             0.4511243917370499, 0.5651630067765897, 0.9499662252212164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.04610843439966642], {
             RGBColor[
             0.2260372839021752, 0.3549098953457044, 0.9361838609748094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.04610843439966642], {
             RGBColor[
             0.2642831104182927, 0.3951086839396021, 0.9383619042152723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.04610843439966642], {
             RGBColor[
             0.1796655907243716, 0.3061703056806712, 0.9335430616491059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.04610843439966642], {
             RGBColor[
             0.874787420357395, 0.9029957597937702, 0.9879191991572792]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.04610843439966642], {
             RGBColor[
             0.43130662815416465`, 0.5479978560308542, 0.9487034548498753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.04610843439966642], {
             RGBColor[
             0.4544709331932017, 0.5679990031052896, 0.9501967631243022]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.04610843439966642], {
             RGBColor[
             0.1842953386135795, 0.3110364642551991, 0.933806718942298]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.04610843439966642], {
             RGBColor[
             0.1814951086723694, 0.3080932450421545, 0.9336472499897152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.04610843439966642], {
             RGBColor[
             0.30056549504747376`, 0.4332437706209237, 0.9404281323449262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.04610843439966642], {
             RGBColor[
             0.24912319227677354`, 0.3791746487785393, 0.937498569304202]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.04610843439966642], {
             RGBColor[
             0.24687317251219526`, 0.37680973534647483`, 0.9373704340072151]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.04610843439966642], {
             RGBColor[
             0.1969362596236349, 0.3243228737174507, 0.934526600693254]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.04610843439966642], {
             RGBColor[
             0.22281221312870114`, 0.35152014148148586`, 0.9360001979653247]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.04610843439966642], {
             RGBColor[
             0.32389238094576056`, 0.45496103389597625`, 0.9418591140004451]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.04610843439966642], {
             RGBColor[
             0.2218736173884548, 0.35053361784807985`, 0.9359467463264457]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.04610843439966642], {
             RGBColor[
             0.28566810415648325`, 0.4175856682453557, 0.9395797479723991]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.04610843439966642], {
             RGBColor[
             0.9937232399115826, 0.9889829697856952, 0.5581915839279488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.04610843439966642], {
             RGBColor[
             0.34381589363766235`, 0.47221777920483715`, 0.9431286226115025]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.04610843439966642], {
             RGBColor[
             0.2619978835405132, 0.39270676559930323`, 0.938231763925273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.04610843439966642], {
             RGBColor[
             0.8556626659915121, 0.887746199790043, 0.9860950630129915]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.04610843439966642], {
             RGBColor[
             0.19848865517094644`, 0.32595453986523776`, 0.93461500732311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.04610843439966642], {
             RGBColor[
             0.1901932049434399, 0.31723549571420584`, 0.9341425937046723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.04610843439966642], {
             RGBColor[
             0.24540381361353808`, 0.37526534598125116`, 0.9372867561916584]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.04610843439966642], {
             RGBColor[
             0.24952468470268496`, 0.3795966427742623, 0.9375214337039027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.04610843439966642], {
             RGBColor[
             0.19357697366818166`, 0.320792051187238, 0.9343352943277091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.04610843439966642], {
             RGBColor[
             0.1855038424012835, 0.31230667835964177`, 0.9338755414451867]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.04610843439966642], {
             RGBColor[
             0.19256204953176445`, 0.3197253015699566, 0.9342774958995859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.04610843439966642], {
             RGBColor[
             0.9939031817563573, 0.9917468232222412, 0.7507035865643902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.04610843439966642], {
             RGBColor[
             0.20018563595199287`, 0.32773817426091345`, 0.9347116478681324]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.04610843439966642], {
             RGBColor[
             0.2822567222941179, 0.41400008961390705`, 0.9393854748220246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.04610843439966642], {
             RGBColor[
             0.33187084383238813`, 0.46187157743916857`, 0.9423674946005033]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.04610843439966642], {
             RGBColor[
             0.6731900684530466, 0.744620465000319, 0.9680609527706839]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.04610843439966642], {
             RGBColor[
             0.8187176743057581, 0.14487782361704554`, 0.16555737209477062`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.04610843439966642], {
             RGBColor[
             0.20642492465234524`, 0.3342960622787358, 0.9350669661294171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.04610843439966642], {
             RGBColor[
             0.3163443674121438, 0.4484233239473484, 0.9413781612525294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.04610843439966642], {
             RGBColor[
             0.2548921156460419, 0.3852381530105079, 0.9378271009557244]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.04610843439966642], {
             RGBColor[
             0.44319072976501883`, 0.5582912675338615, 0.9494606992958204]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.04610843439966642], {
             RGBColor[
             0.2838279904913397, 0.4156515921133449, 0.9394749562213734]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.04610843439966642], {
             RGBColor[
             0.4514119894863078, 0.5654121094919137, 0.9499845506954865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.04610843439966642], {
             RGBColor[
             0.2817626744925139, 0.41348081404998144`, 0.9393573395306015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.04610843439966642], {
             RGBColor[
             0.19517315909830985`, 0.32246974327830424`, 0.9344261947266101]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.04610843439966642], {
             RGBColor[
             0.2058031822357576, 0.33364257157815613`, 0.9350315588185778]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.04610843439966642], {
             RGBColor[
             0.8037293520346596, 0.846598745469576, 0.9810718885991364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.04610843439966642], {
             RGBColor[
             0.19933380464903927`, 0.32684284555228516`, 0.9346631373356007]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.04610843439966642], {
             RGBColor[
             0.20939739524084894`, 0.3374203173327738, 0.9352362439320562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.04610843439966642], {
             RGBColor[
             0.19209300288846856`, 0.31923230380857776`, 0.9342507843871425]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.04610843439966642], {
             RGBColor[
             0.6552079689840278, 0.7305727122261038, 0.9662686651478858]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.04610843439966642], {
             RGBColor[
             0.30775018901205775`, 0.44079533951360933`, 0.940837290037407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.04610843439966642], {
             RGBColor[
             0.8693407441384133, 0.4995886600246006, 0.2126870529687101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.04610843439966642], {
             RGBColor[
             0.36775323192677223`, 0.4929510985052593, 0.9446538886403275]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.04610843439966642], {
             RGBColor[
             0.19003317840134057`, 0.3170672976721906, 0.9341334804298378]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.04610843439966642], {
             RGBColor[
             0.5005712745154292, 0.6054253369873833, 0.9538259508643026]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.04610843439966642], {
             RGBColor[
             0.23408779828449117`, 0.3633714963936115, 0.9366423258592136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.04610843439966642], {
             RGBColor[
             0.21738991983752656`, 0.34582096743921015`, 0.9356914063839564]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.04610843439966642], {
             RGBColor[
             0.1836473816366038, 0.3103554203895525, 0.9337698187510258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.04610843439966642], {
             RGBColor[
             0.3685402730980111, 0.49363279400994686`, 0.9447040382078057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.04610843439966642], {
             RGBColor[
             0.3420328760182438, 0.47067341895996806`, 0.9430150103054538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.04610843439966642], {
             RGBColor[
             0.43817293033743376`, 0.5539451018716196, 0.9491409695533606]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.04610843439966642], {
             RGBColor[
             0.34083289550277507`, 0.46963405615024345`, 0.9429385486081092]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.04610843439966642], {
             RGBColor[
             0.9363841071750253, 0.7854912142282449, 0.26767136325734403`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.04610843439966642], {
             RGBColor[
             0.1818088839913312, 0.30842304279688765`, 0.933665119029941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.04610843439966642], {
             RGBColor[
             0.2320502240219991, 0.3612298766540624, 0.9365262890192856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.04610843439966642], {
             RGBColor[
             0.18306798401191893`, 0.3097464367500775, 0.933736822913442]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.04610843439966642], {
             RGBColor[
             0.20348109888236326`, 0.33120191474515054`, 0.9348993196068165]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.04610843439966642], {
             RGBColor[
             0.31320234650668927`, 0.4457018633616062, 0.9411779544588138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.04610843439966642], {
             RGBColor[
             0.19443151506714343`, 0.3216902283786009, 0.9343839591961993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.04610843439966642], {
             RGBColor[
             0.1841862517520943, 0.3109218070472717, 0.933800506606916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.04610843439966642], {
             RGBColor[
             0.8101035860121542, 0.8515783454987672, 0.9817072126714098]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.04610843439966642], {
             RGBColor[
             0.46571418536342124`, 0.577126781719812, 0.9510818731205317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.04610843439966642], {
             RGBColor[
             0.22946131864603458`, 0.3585087729578423, 0.9363788546880667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.04610843439966642], {
             RGBColor[
             0.2015219494351241, 0.32914272445885284`, 0.9347877489440981]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.04610843439966642], {
             RGBColor[
             0.5010318547608589, 0.6057992567795268, 0.9538622094283838]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.04610843439966642], {
             RGBColor[
             0.23298613716021888`, 0.3622135807026517, 0.9365795878879478]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.04610843439966642], {
             RGBColor[
             0.20070591566211698`, 0.3282850212238928, 0.9347412770279392]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.04610843439966642], {
             RGBColor[
             0.34562348099972906`, 0.47378342052587685`, 0.9432438004798267]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.04610843439966642], {
             RGBColor[
             0.995260710048657, 0.9923081960579929, 0.7282058295903809]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.04610843439966642], {
             RGBColor[
             0.1906136828189116, 0.3176774446211637, 0.9341665392976392]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{{3.8349502435193233`*^9, 3.8349502581408367`*^9}, 
   3.834950528174912*^9, 3.835023875275108*^9},
 CellLabel->
  "Out[127]=",ExpressionUUID->"7eb2dce6-8fe5-4067-a7a9-3fe987b51507"]
}, Open  ]],

Cell["r = 3 :", "Text",
 CellChangeTimes->{{3.834793779215767*^9, 3.8347938725231647`*^9}, {
  3.8347953347101345`*^9, 3.8347953431477337`*^9}, {3.8348851911359825`*^9, 
  3.83488519180678*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"1d18d146-e61b-4a93-be24-b6599519ad23"],

Cell["Cubic Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.834795179278664*^9}},ExpressionUUID->"59d03372-9a06-461c-a577-\
be4db4aa6d17"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c\[Rho]3i2", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"CMDi3200", ",", "kri2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.834947911760502*^9, 
   3.834947914304406*^9}, {3.834947957535968*^9, 3.8349479704802837`*^9}, {
   3.8349480487781425`*^9, 3.834948105065866*^9}, {3.8349497992119355`*^9, 
   3.83494980454772*^9}},
 CellLabel->
  "In[128]:=",ExpressionUUID->"d386c7ba-c4df-484a-a2ec-67fa9ac3a4ec"],

Cell[BoxData["0.07340907462947431`"], "Output",
 CellChangeTimes->{
  3.834948013482303*^9, {3.834948049945756*^9, 3.834948058990469*^9}, 
   3.8349481059508953`*^9, 3.8349499476386404`*^9, 3.8350238755670753`*^9},
 CellLabel->
  "Out[128]=",ExpressionUUID->"14d6666b-2753-4c56-b873-94188d4dd85c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CP3i2", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"CMDi3200", ",", "kri2"}], "}"}], "]"}], ",", "c\[Rho]3i2"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8349481210775223`*^9, 3.834948150679065*^9}, {
  3.8349481924167476`*^9, 3.8349481986802473`*^9}, {3.834949807949147*^9, 
  3.834949815491851*^9}},
 CellLabel->
  "In[129]:=",ExpressionUUID->"6655309e-b10d-4792-a8a6-27ed1a0b7593"],

Cell[BoxData["0.018608322889665435`"], "Output",
 CellChangeTimes->{3.8349481513130674`*^9, 3.8349482002632475`*^9, 
  3.8349499490044084`*^9, 3.8350238755830746`*^9},
 CellLabel->
  "Out[129]=",ExpressionUUID->"02977a12-72ff-438f-81e1-9ab1a6815332"]
}, Open  ]],

Cell["Absolute Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.8347951985065947`*^9}},ExpressionUUID->"7cf4c1b2-f799-4fc6-808b-\
6a5846e4260e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a\[Rho]3i2", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"AMDi3200", ",", "kri2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.8348873709111376`*^9, 
   3.8348873755217657`*^9}, {3.8349481641806583`*^9, 
   3.8349481824982553`*^9}, {3.834949818653184*^9, 3.8349498238056817`*^9}},
 CellLabel->
  "In[130]:=",ExpressionUUID->"5fbecfd0-646a-4239-996c-9d0962f34a7e"],

Cell[BoxData["0.03808644288910689`"], "Output",
 CellChangeTimes->{3.834948182946122*^9, 3.83494995054953*^9, 
  3.8350238755950775`*^9},
 CellLabel->
  "Out[130]=",ExpressionUUID->"2e401a5c-113c-4e3b-a4b0-381d2709f62c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"aP3i2", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"AMDi3200", ",", "kri2"}], "}"}], "]"}], ",", "a\[Rho]3i2"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8349482041094093`*^9, 
  3.8349482202691827`*^9}, {3.8349498269490285`*^9, 3.8349498405604887`*^9}},
 CellLabel->
  "In[131]:=",ExpressionUUID->"49ef63a7-255c-4505-8fe2-8ac876622f90"],

Cell[BoxData["0.2872503924990428`"], "Output",
 CellChangeTimes->{3.834887440036944*^9, 3.8349482220989213`*^9, 
  3.8349499520491343`*^9, 3.835023875609073*^9},
 CellLabel->
  "Out[131]=",ExpressionUUID->"7ba44c38-93a5-4b93-9120-29cb619ea3bc"]
}, Open  ]],

Cell["Max-min Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 3.8347951985065947`*^9}, {
  3.8348543263190746`*^9, 
  3.834854330052075*^9}},ExpressionUUID->"cc03ccd5-e1ea-4d7c-8fcb-\
29688ff20e81"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mM\[Rho]3i2", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"mMDi3200", ",", "kri2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8348874651734295`*^9, 3.8348874872060013`*^9}, {
  3.8349482319487157`*^9, 3.834948245258479*^9}, {3.834949844516972*^9, 
  3.8349498489188633`*^9}},
 CellLabel->
  "In[132]:=",ExpressionUUID->"2233ea15-6cfa-4032-bf6a-092f7675a6d6"],

Cell[BoxData["0.07974450642658225`"], "Output",
 CellChangeTimes->{3.834948246413353*^9, 3.834949953689977*^9, 
  3.8350238756280785`*^9},
 CellLabel->
  "Out[132]=",ExpressionUUID->"b2740f37-5ac8-44fe-99cc-fb08b464678d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mMP3i2", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"mMDi3200", ",", "kri2"}], "}"}], "]"}], ",", "mM\[Rho]3i2"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8348875260806427`*^9, 
  3.8348875488478312`*^9}, {3.8349482525846663`*^9, 3.8349482707073736`*^9}, {
  3.8349498532537427`*^9, 3.834949860995207*^9}},
 CellLabel->
  "In[133]:=",ExpressionUUID->"e2e12ac0-99ca-4c41-8b0b-7037df8b7165"],

Cell[BoxData["0.01947418407112327`"], "Output",
 CellChangeTimes->{3.834887440036944*^9, 3.8348875533996215`*^9, 
  3.834948277702903*^9, 3.834949955989804*^9, 3.835023875643072*^9},
 CellLabel->
  "Out[133]=",ExpressionUUID->"2d2c8174-3546-4433-a03d-f74ab607368b"]
}, Open  ]],

Cell["r = 6 :", "Text",
 CellChangeTimes->{{3.834793779215767*^9, 3.8347938725231647`*^9}, {
  3.8347953347101345`*^9, 3.8347953431477337`*^9}, {3.8348851911359825`*^9, 
  3.83488519180678*^9}, {3.834948305866973*^9, 3.8349483068980722`*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"ca7908ef-61ff-4f21-bf57-2d35f8382cd5"],

Cell["Cubic Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.834795179278664*^9}},ExpressionUUID->"0b702b31-b7ee-4038-9778-\
35b3d338f037"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c\[Rho]6i2", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"CMDi6200", ",", "kri2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.834947911760502*^9, 
   3.834947914304406*^9}, {3.834947957535968*^9, 3.8349479704802837`*^9}, {
   3.8349480487781425`*^9, 3.834948105065866*^9}, {3.8349483158342133`*^9, 
   3.8349483193845987`*^9}, {3.834949864783629*^9, 3.834949869574106*^9}},
 CellLabel->
  "In[134]:=",ExpressionUUID->"62de27f2-e739-4673-8c2b-20dfc6d4e9ab"],

Cell[BoxData["0.16394886154329527`"], "Output",
 CellChangeTimes->{
  3.834948013482303*^9, {3.834948049945756*^9, 3.834948058990469*^9}, 
   3.8349481059508953`*^9, 3.834948360850016*^9, 3.8349499580565577`*^9, 
   3.8350238756570735`*^9},
 CellLabel->
  "Out[134]=",ExpressionUUID->"f39bdf56-d23c-4e09-96e6-2d01832b591d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CP6i2", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"CMDi6200", ",", "kri2"}], "}"}], "]"}], ",", "c\[Rho]6i2"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8349481210775223`*^9, 3.834948150679065*^9}, {
  3.8349481924167476`*^9, 3.8349481986802473`*^9}, {3.8349483230197706`*^9, 
  3.834948338654296*^9}, {3.8349498724373255`*^9, 3.8349498802583637`*^9}},
 CellLabel->
  "In[135]:=",ExpressionUUID->"5cbcb0f9-2b97-41ed-80d2-c67b5f523f1c"],

Cell[BoxData["0.204728097643479`"], "Output",
 CellChangeTimes->{3.8349481513130674`*^9, 3.8349482002632475`*^9, 
  3.834948361143017*^9, 3.8349499593900194`*^9, 3.835023875671074*^9},
 CellLabel->
  "Out[135]=",ExpressionUUID->"7d82aed2-684a-4d36-80b8-38520d653da6"]
}, Open  ]],

Cell["Absolute Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.8347951985065947`*^9}},ExpressionUUID->"b7b44779-48a8-434b-92e7-\
0a087c8b7dd8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a\[Rho]6i2", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"AMDi6200", ",", "kri2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.8348873709111376`*^9, 
   3.8348873755217657`*^9}, {3.8349481641806583`*^9, 
   3.8349481824982553`*^9}, {3.834948329127375*^9, 3.834948332212267*^9}, {
   3.834949883458797*^9, 3.8349498875077024`*^9}},
 CellLabel->
  "In[136]:=",ExpressionUUID->"bacfb75b-1dfd-44e3-966d-c2dbdb9b3094"],

Cell[BoxData["0.10493805718703002`"], "Output",
 CellChangeTimes->{3.834948182946122*^9, 3.8349483612910123`*^9, 
  3.8349499607430162`*^9, 3.8350238756900806`*^9},
 CellLabel->
  "Out[136]=",ExpressionUUID->"4bb953c3-5720-46fc-8a75-f19ba0931c9a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"aP6i2", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"AMDi6200", ",", "kri2"}], "}"}], "]"}], ",", "a\[Rho]6i2"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8349482041094093`*^9, 
  3.8349482202691827`*^9}, {3.834948340881687*^9, 3.834948354997751*^9}, {
  3.8349498907390194`*^9, 3.8349498979971194`*^9}},
 CellLabel->
  "In[137]:=",ExpressionUUID->"75530884-6c52-4607-adab-4b64cca716be"],

Cell[BoxData["0.35294570988459933`"], "Output",
 CellChangeTimes->{3.834887440036944*^9, 3.8349482220989213`*^9, 
  3.834948361458013*^9, 3.834949962307019*^9, 3.8350238757030787`*^9},
 CellLabel->
  "Out[137]=",ExpressionUUID->"af9ea8b2-1c13-4448-99bd-692b3310eb37"]
}, Open  ]],

Cell["Max-min Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 3.8347951985065947`*^9}, {
  3.8348543263190746`*^9, 
  3.834854330052075*^9}},ExpressionUUID->"cc2779bf-e3e8-4a68-ba55-\
cc99676436bc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mM\[Rho]6i2", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"mMDi6200", ",", "kri2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8348874651734295`*^9, 3.8348874872060013`*^9}, {
   3.8349482319487157`*^9, 3.834948245258479*^9}, 3.8349483527075925`*^9, {
   3.8349499042423377`*^9, 3.8349499090679235`*^9}, {3.834949978751977*^9, 
   3.8349499794842105`*^9}},
 CellLabel->
  "In[138]:=",ExpressionUUID->"2e0374b0-ad7a-465d-b2e5-aa63def522fb"],

Cell[BoxData["0.07357755508941506`"], "Output",
 CellChangeTimes->{
  3.834948246413353*^9, 3.8349483615970154`*^9, {3.834949963955017*^9, 
   3.8349499810066743`*^9}, 3.835023875718076*^9},
 CellLabel->
  "Out[138]=",ExpressionUUID->"4f455c21-afad-4b19-bd53-7531ca6f9292"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mMP6i2", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"mMDi6200", ",", "kri2"}], "}"}], "]"}], ",", "mM\[Rho]6i2"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8348875260806427`*^9, 
  3.8348875488478312`*^9}, {3.8349482525846663`*^9, 3.8349482707073736`*^9}, {
  3.83494834565068*^9, 3.8349483504716325`*^9}, {3.8349499122654495`*^9, 
  3.83494991854418*^9}},
 CellLabel->
  "In[139]:=",ExpressionUUID->"1ac24a2b-05a8-4d88-af22-8ffcc2ed2d87"],

Cell[BoxData["0.8588189031617313`"], "Output",
 CellChangeTimes->{
  3.834887440036944*^9, 3.8348875533996215`*^9, 3.834948277702903*^9, 
   3.8349483617580156`*^9, {3.834949965578516*^9, 3.8349499927811513`*^9}, 
   3.8350238757340755`*^9},
 CellLabel->
  "Out[139]=",ExpressionUUID->"7cb9698d-8193-4d7e-ae5a-f1338485213e"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3rd imported file", "Subsection",
 CellChangeTimes->{{3.834947473073307*^9, 3.8349474798089457`*^9}, {
   3.8349497159535103`*^9, 3.8349497173354855`*^9}, {3.834956622993673*^9, 
   3.834956623710862*^9}, {3.83495955651396*^9, 3.834959556949829*^9}, {
   3.8350085250441637`*^9, 3.835008527248186*^9}, 3.835201597812028*^9},
 Background->RGBColor[
  1, 1, 0],ExpressionUUID->"dd7dc054-42ed-4747-ac03-9bce886b4d0c"],

Cell["Dividing stuff", "Text",
 CellChangeTimes->{{3.83494752022309*^9, 
  3.834947523245259*^9}},ExpressionUUID->"83445021-de34-4b22-a0bb-\
18e885db3068"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data3", "=", 
   RowBox[{"StringSplit", "[", 
    RowBox[{
     RowBox[{"Import", "[", "\"\<ariadnaComputation3.txt\>\"", "]"}], ",", 
     "\"\<]\n{\>\""}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8349434033501863`*^9, 3.834943479535334*^9}, {
   3.834943567297134*^9, 3.8349435736474867`*^9}, {3.8349441109152327`*^9, 
   3.8349441401892223`*^9}, 3.834944204627252*^9, {3.834949720382628*^9, 
   3.8349497230261507`*^9}, {3.8350085306055326`*^9, 
   3.8350085308205767`*^9}, {3.83500857920323*^9, 3.835008579448225*^9}},
 CellLabel->
  "In[140]:=",ExpressionUUID->"ca1888d3-e241-4b11-b39c-86219b601246"],

Cell[BoxData[
 RowBox[{
  RowBox[{"graphi3", "=", 
   RowBox[{"ToExpression", "@", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"data3", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
       "<>", "\"\<]\>\""}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834944474381714*^9, 3.83494454689666*^9}, 
   3.8349475108233376`*^9, {3.834949726505718*^9, 3.8349497324197383`*^9}, {
   3.8350085830023518`*^9, 3.835008585658931*^9}},
 CellLabel->
  "In[141]:=",ExpressionUUID->"1a8dad2f-6668-47f2-b989-9a72525c0e29"],

Cell[BoxData[
 RowBox[{
  RowBox[{"otheri3", "=", 
   RowBox[{"ToExpression", "@", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "<>", "\"\<}}\>\""}], "&"}], ",", 
      RowBox[{"StringSplit", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\"\<{\>\"", "<>", 
          RowBox[{
          "data3", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
         ")"}], ",", "\"\<}}\>\""}], "]"}]}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834944518155362*^9, 3.8349445533517303`*^9}, 
   3.8349446259294133`*^9, {3.8349447635371876`*^9, 3.8349447780382657`*^9}, {
   3.834944820013957*^9, 3.8349448816359477`*^9}, {3.834944915595456*^9, 
   3.834944918286141*^9}, {3.8349449615053425`*^9, 3.834944967406804*^9}, {
   3.834945029266304*^9, 3.834945031628281*^9}, {3.834945108799203*^9, 
   3.8349451822852197`*^9}, 3.834945584171259*^9, {3.834949734758335*^9, 
   3.8349497379503355`*^9}, {3.83500858975801*^9, 3.835008593142612*^9}},
 CellLabel->
  "In[142]:=",ExpressionUUID->"e333022f-1f52-488d-b5cd-92362bedfe98"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "CMDi3300", "}"}], ",", 
     RowBox[{"{", "AMDi3300", "}"}], ",", 
     RowBox[{"{", "mMDi3300", "}"}], ",", 
     RowBox[{"{", "CMDi6300", "}"}], ",", 
     RowBox[{"{", "AMDi6300", "}"}], ",", 
     RowBox[{"{", "mMDi6300", "}"}]}], "}"}], "=", "otheri3"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.834945694541313*^9, 3.834945753140644*^9}, {
  3.8349459487260857`*^9, 3.8349459670133495`*^9}, {3.8349471029719105`*^9, 
  3.8349471182020655`*^9}, {3.83494974203613*^9, 3.8349497544188104`*^9}, {
  3.8350085962476587`*^9, 3.8350086141398926`*^9}},
 CellLabel->
  "In[143]:=",ExpressionUUID->"919c0dcf-598f-4fb1-8930-fa47262c5f6c"],

Cell["\[OpenCurlyDoubleQuote]Cleaning\[CloseCurlyDoubleQuote] the graph:", \
"Text",
 CellChangeTimes->{{3.8349477786156034`*^9, 
  3.8349478283202667`*^9}},ExpressionUUID->"4f92eea8-ddb7-427a-9a6c-\
f5463acbd057"],

Cell[BoxData[
 RowBox[{
  RowBox[{"graphin3", "=", 
   RowBox[{"IndexGraph", "@", "graphi3"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834946654863307*^9, 3.834946693639777*^9}, {
  3.834949757637121*^9, 3.834949759707878*^9}, {3.835008623404386*^9, 
  3.835008625832593*^9}},
 CellLabel->
  "In[144]:=",ExpressionUUID->"3cf5dbf7-87ed-4ae1-86c2-fc671c5ec254"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pointsi3", "=", 
   RowBox[{"VertexList", "@", "graphin3"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834784420352569*^9, 3.8347844264642625`*^9}, {
  3.8348756828269844`*^9, 3.8348756865131674`*^9}, {3.834878831782991*^9, 
  3.8348788488376627`*^9}, {3.8349467020325813`*^9, 3.834946739879963*^9}, {
  3.8349497621629615`*^9, 3.8349497641865125`*^9}, {3.8350086306614027`*^9, 
  3.835008632769765*^9}},
 CellLabel->
  "In[145]:=",ExpressionUUID->"3e43d2d6-6bc5-4968-936e-3cfa6a2fb72e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"coordpointsi3", "=", 
   RowBox[{"VertexList", "@", "graphi3"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834879134322084*^9, 3.834879146224797*^9}, {
  3.834946724882841*^9, 3.834946736706849*^9}, {3.834949767417904*^9, 
  3.8349497706963253`*^9}, {3.835008636685829*^9, 3.835008639024473*^9}},
 CellLabel->
  "In[146]:=",ExpressionUUID->"d53ff5bf-f590-4873-b55a-0997d574672a"],

Cell["Kretchmann \[OpenCurlyDoubleQuote]real\[CloseCurlyDoubleQuote] \
values:", "Text",
 CellChangeTimes->{
  3.8347933561184683`*^9, {3.8347935444076195`*^9, 
   3.834793546974228*^9}},ExpressionUUID->"1437b1cf-d6f6-4a66-adf6-\
7b8748d226bb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rvali3", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Sinh", "[", "\[Nu]", "]"}], "\[Equal]", "#"}], ",", 
       RowBox[{"{", "\[Nu]", "}"}]}], "]"}], "&"}], "/@", 
    RowBox[{"coordpointsi3", "\[LeftDoubleBracket]", 
     RowBox[{";;", ",", "3"}], "\[RightDoubleBracket]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834105426841242*^9, 3.8341054487325706`*^9}, {
   3.8341407674337025`*^9, 3.834140799285215*^9}, {3.8341408938375945`*^9, 
   3.834140946496229*^9}, {3.8341410168099756`*^9, 3.8341410671886864`*^9}, {
   3.8341411610986195`*^9, 3.834141210381962*^9}, {3.834141332672348*^9, 
   3.834141336755044*^9}, {3.834141461053176*^9, 3.834141468978607*^9}, {
   3.834141967115094*^9, 3.8341420256686225`*^9}, {3.8341640069512*^9, 
   3.834164012603241*^9}, {3.834164792400744*^9, 3.8341647947633886`*^9}, {
   3.83466546628111*^9, 3.834665483801684*^9}, {3.8347933895124626`*^9, 
   3.834793417249506*^9}, 3.8347960586942053`*^9, 3.834879156483405*^9, {
   3.8348862453609915`*^9, 3.8348862641404076`*^9}, 3.834886374221485*^9, {
   3.834946768449996*^9, 3.8349467823353415`*^9}, {3.8349468446168528`*^9, 
   3.834946857637892*^9}, 3.8349474594107084`*^9, {3.834949773350379*^9, 
   3.8349497766098785`*^9}, {3.835008643742739*^9, 3.8350086469135637`*^9}},
 CellLabel->
  "In[147]:=",ExpressionUUID->"a269346a-99e4-436e-b10c-325aa7596c94"],

Cell[BoxData[
 RowBox[{
  RowBox[{"kri3", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"KHyperboloid", "/.", "rvali3"}], ")"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834792366597866*^9, 3.834792376019791*^9}, {
   3.834793346399704*^9, 3.8347933590872536`*^9}, {3.834793445378667*^9, 
   3.8347934527754736`*^9}, {3.834793487784485*^9, 3.834793489659489*^9}, 
   3.8348550102643666`*^9, {3.8348863808528233`*^9, 3.83488645374378*^9}, {
   3.834886485165092*^9, 3.834886521271514*^9}, 3.8348865820814276`*^9, {
   3.83494679091998*^9, 3.8349467979310513`*^9}, {3.8349468742957215`*^9, 
   3.834946904080855*^9}, 3.8349474644429636`*^9, {3.834949779141443*^9, 
   3.834949781745859*^9}, {3.8350086522552986`*^9, 3.8350086547466764`*^9}},
 CellLabel->
  "In[148]:=",ExpressionUUID->"e6791147-4783-4e49-8c45-4f1800dc79e7"],

Cell["Estimated with cubic Mean Deviation v Calculated: (r=3)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 
  3.8349503319477153`*^9}},ExpressionUUID->"337f8761-4ff0-4ed0-ae48-\
6e5e948ce195"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraphb", "[", 
     RowBox[{"graphin3", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsi3", ",", "#"}], "}"}], "]"}], ",", "500", ",", "3"}], 
     "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"CMDi3300", ",", "kri3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.835008661710948*^9, 3.835008744963953*^9}, 
   3.83505172803014*^9},
 Background->RGBColor[1, 1, 0.85],
 CellLabel->
  "In[400]:=",ExpressionUUID->"09e620ef-3374-4bcc-af0e-c49dbae807d6"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1FO4EAYYBuBzsm2dTrZdW7WsZbtVy3bLtWxr2bat5WVjyzZXrfc8u3i/
//a7+f7gJu2rtAsMCAjIJEJuKEIThrCEIzwRiEgkIhOFqEQjOjGISSxiE4e4
xCM+CUhIIhKThKQkI4jkBJOClKQiNWlISzrSk4GMIX3JTBayko3s5CAnuchN
HvKSj/wUoCCF+IEfKUwRivITxShOCUpSitKUoSzlKE8FfqYilahMFapSjerU
oCa1qE0d6lKP+jSgIY1oTBN+oSnNaM6vtKAlrWhNG9rSjvZ0oCOd6EwXutKN
7vSgJ73ozW/0oS/96M8ABjKIwQzhd4YyjOGMYCSjGM0YxjKO8UxgIpOYzBSm
Mo3pzGAms5jNH8xhLvOYzwIWsojFLGEpy1jOClayitWsYS3rWM8GNrKJzWxh
K9vYzg52sovd7GEv+9jPAQ5yiMMc4U+OcozjnOAkpzjNX5zhLOc4zwUuconL
XOEq17jODW5yi9v8zT/c4S73uM8DHvKIxzzhKc94zgte8orXvOEt73jPBz7y
ic/8yxe+8o3/CBl/IKEITRjCEo7wRCAikYhMFKISjejEICaxiE0c4hKP+CQg
IYlITBKSkowgkhNMClKSitSkIS3pSE8GMgb+/6++Az6VhWw=
          "], {Null, CompressedData["
1:eJxN2guYllWBB/D3qyhJJoMEhjQEkUhkrd1Es1FL08DywkWybEVNDSyNClNB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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[72, 227] -> 
             RGBColor[
              0.5721912270534666, 0.6604672416338768, 0.9609715474677657], 
             UndirectedEdge[132, 236] -> 
             RGBColor[
              0.5545798371976356, 0.6492719212308204, 0.9580777027585297], 
             UndirectedEdge[187, 193] -> 
             RGBColor[
              0.5113392627454891, 0.6084991488014733, 0.9566101996951758], 
             UndirectedEdge[196, 225] -> 
             RGBColor[
              0.6620084667817787, 0.7353536792381814, 0.9673099559779559], 
             UndirectedEdge[39, 166] -> 
             RGBColor[
              0.5595723692133844, 0.6533250836322095, 0.9584707331670568], 
             UndirectedEdge[7, 216] -> 
             RGBColor[
              0.3353784911636625, 0.4601118505303513, 0.9427666724835122], 
             UndirectedEdge[92, 281] -> 
             RGBColor[
              0.6283500160905333, 0.6969026564552571, 0.9318874710817026], 
             UndirectedEdge[99, 229] -> 
             RGBColor[
              0.6352273227127441, 0.7098099845647393, 0.9672920159417839], 
             UndirectedEdge[187, 296] -> 
             RGBColor[
              0.7694328216934285, 0.819807325132663, 0.9776531886930784], 
             UndirectedEdge[100, 244] -> 
             RGBColor[
              0.4649073081354495, 0.5754261057652368, 0.9513072597912102], 
             UndirectedEdge[232, 245] -> 
             RGBColor[
              0.6940027166603455, 0.7524932360213252, 0.7554452630306123], 
             UndirectedEdge[6, 52] -> 
             RGBColor[
              0.4500978543280138, 0.5606565986492517, 0.950900278478038], 
             UndirectedEdge[113, 160] -> 
             RGBColor[
              0.6062729980189614, 0.6912387579359295, 0.9621471777366718], 
             UndirectedEdge[176, 288] -> 
             RGBColor[
              0.8314559460444662, 0.3864144174851789, 0.4383063311742307], 
             UndirectedEdge[187, 228] -> 
             RGBColor[
              0.5585962353979255, 0.6498735887750762, 0.9596051581953235], 
             UndirectedEdge[61, 268] -> 
             RGBColor[
              0.5729142709094651, 0.6623753539576496, 0.9604750803236906], 
             UndirectedEdge[51, 101] -> 
             RGBColor[
              0.43663739804163737`, 0.5509166038011604, 0.9495124266231247], 
             UndirectedEdge[207, 214] -> 
             RGBColor[
              0.3615280664238959, 0.47760755439231584`, 0.9449668480095905], 
             UndirectedEdge[17, 162] -> 
             RGBColor[
              0.6259215035741186, 0.6971397271447692, 0.9477382718559135], 
             UndirectedEdge[20, 279] -> 
             RGBColor[
              0.9178043549469971, 0.9350747646584077, 0.9065010575585328], 
             UndirectedEdge[51, 197] -> 
             RGBColor[
              0.35405705967749174`, 0.4810881624925656, 0.943781180655653], 
             UndirectedEdge[86, 94] -> 
             RGBColor[
              0.2742854923787284, 0.4051394958238438, 0.9389491853789335], 
             UndirectedEdge[55, 114] -> 
             RGBColor[
              0.8363211022417663, 0.8728832736065386, 0.9841017701843255], 
             UndirectedEdge[13, 270] -> 
             RGBColor[
              0.5101754707234025, 0.6088616544863945, 0.9561271839670242], 
             UndirectedEdge[151, 220] -> 
             RGBColor[
              0.7022264846544354, 0.7656542378851894, 0.9724394201695741], 
             UndirectedEdge[117, 225] -> 
             RGBColor[
              0.5321675028078385, 0.6270825514201336, 0.9578787322912071], 
             UndirectedEdge[13, 277] -> 
             RGBColor[
              0.6390587856114334, 0.7170205604700395, 0.9652992099849109], 
             UndirectedEdge[81, 237] -> 
             RGBColor[
              0.4924564484545949, 0.5964786408046705, 0.953838841963154], 
             UndirectedEdge[172, 174] -> 
             RGBColor[
              0.5003107353627567, 0.5895124293295138, 0.957152884405382], 
             UndirectedEdge[128, 197] -> 
             RGBColor[
              0.34385578882374046`, 0.47225233440982767`, 0.9431311646974816],
              UndirectedEdge[44, 71] -> 
             RGBColor[
              0.6482904751208631, 0.7204514352591723, 0.9684342972584405], 
             UndirectedEdge[70, 122] -> 
             RGBColor[
              0.4747139171130409, 0.5748966875060928, 0.9537497910423203], 
             UndirectedEdge[42, 293] -> 
             RGBColor[
              0.4052216738276782, 0.5254043796611771, 0.9470413446262109], 
             UndirectedEdge[154, 181] -> 
             RGBColor[
              0.49341833148561975`, 0.5981135021898993, 0.9536786128373553], 
             UndirectedEdge[42, 216] -> 
             RGBColor[
              0.30856452446822613`, 0.43688694028791686`, 0.9410581102363388],
              UndirectedEdge[125, 130] -> 
             RGBColor[
              0.8126001685820099, 0.8542363756011002, 0.9817682519585761], 
             UndirectedEdge[173, 263] -> 
             RGBColor[
              0.7899567771666666, 0.8364264785059545, 0.9693270472421658], 
             UndirectedEdge[112, 132] -> 
             RGBColor[
              0.36779854386560973`, 0.47950976879635754`, 0.9457507147551395],
              UndirectedEdge[208, 279] -> 
             RGBColor[
              0.6820725854914302, 0.744479519064022, 0.8864517423662632], 
             UndirectedEdge[271, 295] -> 
             RGBColor[
              0.4198340277531679, 0.5369727534143199, 0.9482730796999772], 
             UndirectedEdge[193, 264] -> 
             RGBColor[
              0.39896112410097917`, 0.5184352980041547, 0.9469635927565185], 
             UndirectedEdge[16, 39] -> 
             RGBColor[
              0.4684214886082073, 0.5792070696142244, 0.951327501490932], 
             UndirectedEdge[168, 282] -> 
             RGBColor[
              0.4071331874952598, 0.5270600367245657, 0.947163144586824], 
             UndirectedEdge[92, 243] -> 
             RGBColor[
              0.6098256524845249, 0.6774323757928531, 0.9308325359786805], 
             UndirectedEdge[71, 280] -> 
             RGBColor[
              0.6327579955061329, 0.7080662576323138, 0.9669527954867794], 
             UndirectedEdge[69, 118] -> 
             RGBColor[
              0.3493195553836401, 0.4769847743871206, 0.9434793110712593], 
             UndirectedEdge[175, 253] -> 
             RGBColor[
              0.43626096611795684`, 0.5522890545628245, 0.949019140883979], 
             UndirectedEdge[137, 179] -> 
             RGBColor[
              0.42274982670952144`, 0.5405863846968499, 0.948158223028305], 
             UndirectedEdge[134, 221] -> 
             RGBColor[
              0.5418443086528845, 0.6376630634132983, 0.9575646303075331], 
             UndirectedEdge[91, 163] -> 
             RGBColor[
              0.3569343643173082, 0.4796521993005819, 0.9441083484055053], 
             UndirectedEdge[160, 232] -> 
             RGBColor[
              0.48996702947505244`, 0.5952117864184265, 0.9534344868921732], 
             UndirectedEdge[135, 263] -> 
             RGBColor[
              0.4919605441573054, 0.5956596965016462, 0.9539148404366498], 
             UndirectedEdge[160, 297] -> 
             RGBColor[
              0.5016413203803652, 0.6053234704336865, 0.9541783623854897], 
             UndirectedEdge[179, 274] -> 
             RGBColor[
              0.31069223160972353`, 0.43222462402352485`, 0.9414318741633849],
              UndirectedEdge[209, 259] -> 
             RGBColor[
              0.44794918508180437`, 0.5611763003664655, 0.9501055530464901], 
             UndirectedEdge[14, 173] -> 
             RGBColor[
              0.643918331382154, 0.7148088498897874, 0.9586750349202973], 
             UndirectedEdge[260, 267] -> 
             RGBColor[
              0.6322663265942646, 0.7076761997677121, 0.9669049855956348], 
             UndirectedEdge[203, 216] -> 
             RGBColor[
              0.5969164128198976, 0.6699096818982188, 0.9647497168195958], 
             UndirectedEdge[37, 279] -> 
             RGBColor[
              0.6833528076407456, 0.745588383143923, 0.8865333169895617], 
             UndirectedEdge[192, 220] -> 
             RGBColor[
              0.37299328534229037`, 0.49292672161318835`, 0.9453222565031503],
              UndirectedEdge[60, 225] -> 
             RGBColor[
              0.7577324462304023, 0.8106656130658583, 0.9764873468940917], 
             UndirectedEdge[177, 226] -> 
             RGBColor[
              0.6407085945062809, 0.7176624583852251, 0.9659059675743182], 
             UndirectedEdge[91, 273] -> 
             RGBColor[
              0.4499677550995339, 0.564161186255421, 0.9498925253574475], 
             UndirectedEdge[52, 273] -> 
             RGBColor[
              0.5194329826442589, 0.6207112019119064, 0.9553182515437026], 
             UndirectedEdge[21, 114] -> 
             RGBColor[
              0.8726156147319245, 0.8986002072134722, 0.8585410684883681], 
             UndirectedEdge[7, 202] -> 
             RGBColor[
              0.7039226442665398, 0.7611868904513199, 0.7647534190348383], 
             UndirectedEdge[94, 293] -> 
             RGBColor[
              0.3820649662079593, 0.5053472034109432, 0.945565819693355], 
             UndirectedEdge[132, 133] -> 
             RGBColor[
              0.4602965812942509, 0.570602787204864, 0.9512427276324376], 
             UndirectedEdge[13, 93] -> 
             RGBColor[
              0.5241686656184439, 0.620981856586054, 0.9570188179720398], 
             UndirectedEdge[141, 178] -> 
             RGBColor[
              0.6243328896647327, 0.6917926487465865, 0.9265703669069056], 
             UndirectedEdge[245, 264] -> 
             RGBColor[
              0.7438737215077617, 0.7945853111490071, 0.7589279501736323], 
             UndirectedEdge[5, 83] -> 
             RGBColor[
              0.5434237800047366, 0.6319325386124813, 0.9600663399214535], 
             UndirectedEdge[210, 226] -> 
             RGBColor[
              0.8220348151378188, 0.8615592585038485, 0.9827212236013376], 
             UndirectedEdge[91, 298] -> 
             RGBColor[
              0.7031935542767329, 0.7654477522055178, 0.9522020992675853], 
             UndirectedEdge[126, 192] -> 
             RGBColor[
              0.4371517205964917, 0.5450134296571194, 0.9503730435464531], 
             UndirectedEdge[127, 156] -> 
             RGBColor[
              0.912559419492454, 0.9305684416564162, 0.8919249120150423], 
             UndirectedEdge[36, 268] -> 
             RGBColor[
              0.3041963950004306, 0.4258987072728392, 0.941043579135268], 
             UndirectedEdge[25, 221] -> 
             RGBColor[
              0.6275750153397639, 0.7081921825542098, 0.9640569609563108], 
             UndirectedEdge[69, 249] -> 
             RGBColor[
              0.2800119943390219, 0.4113181863645, 0.9392694510888504], 
             UndirectedEdge[22, 161] -> 
             RGBColor[
              0.28753204192056675`, 0.41954478501588743`, 0.9396858964706148],
              UndirectedEdge[96, 112] -> 
             RGBColor[
              0.2577091809258098, 0.38666060502869226`, 0.9380438592935316], 
             UndirectedEdge[219, 250] -> 
             RGBColor[
              0.44777326297599374`, 0.5514584316531175, 0.9514432890286693], 
             UndirectedEdge[41, 219] -> 
             RGBColor[
              0.6654044233554353, 0.7385382598769707, 0.9672849524283441], 
             UndirectedEdge[202, 237] -> 
             RGBColor[
              0.8062028627571736, 0.8452927588635688, 0.7725095987506138], 
             UndirectedEdge[91, 235] -> 
             RGBColor[
              0.49859011172720624`, 0.6036619252226986, 0.9537128174579538], 
             UndirectedEdge[69, 263] -> 
             RGBColor[
              0.47252057695723015`, 0.5788217739941024, 0.952676142916749], 
             UndirectedEdge[12, 239] -> 
             RGBColor[
              0.21352035834000382`, 0.3417538129609444, 0.9354710405811757], 
             UndirectedEdge[122, 266] -> 
             RGBColor[
              0.7261818096928285, 0.7860180160089868, 0.9733426743014881], 
             UndirectedEdge[206, 254] -> 
             RGBColor[
              0.6562184753779405, 0.7288749186440274, 0.9681590759573775], 
             UndirectedEdge[137, 270] -> 
             RGBColor[
              0.3670401819334772, 0.49233349044000185`, 0.9446084537252801], 
             UndirectedEdge[25, 58] -> 
             RGBColor[
              0.606581158689487, 0.6914889366507422, 0.9621714372734853], 
             UndirectedEdge[107, 156] -> 
             RGBColor[
              0.7379309547207209, 0.7953009177778874, 0.9744903487500766], 
             UndirectedEdge[136, 194] -> 
             RGBColor[
              0.4923004349595713, 0.5944705803048733, 0.9545262773255293], 
             UndirectedEdge[45, 281] -> 
             RGBColor[
              0.5268820228515531, 0.6174237620409061, 0.9586687356725854], 
             UndirectedEdge[137, 147] -> 
             RGBColor[
              0.38784056704739167`, 0.5103497385679208, 0.9459338358716803], 
             UndirectedEdge[164, 187] -> 
             RGBColor[
              0.569597628587402, 0.6594024426097014, 0.960306157241207], 
             UndirectedEdge[199, 229] -> 
             RGBColor[
              0.575798210027395, 0.6547043634100054, 0.9636381981842286], 
             UndirectedEdge[191, 271] -> 
             RGBColor[
              0.5933587264468407, 0.6749788982539318, 0.9639643190575009], 
             UndirectedEdge[153, 222] -> 
             RGBColor[
              0.6754033822564445, 0.7444894947782827, 0.9696240282926407], 
             UndirectedEdge[158, 186] -> 
             RGBColor[
              0.4090931958410822, 0.5287576974408333, 0.9472880345854526], 
             UndirectedEdge[16, 192] -> 
             RGBColor[
              0.35796633786100795`, 0.48060954584928745`, 0.9441717796936935],
              UndirectedEdge[75, 143] -> 
             RGBColor[
              0.4787151286872626, 0.5847559860146312, 0.9529136924058749], 
             UndirectedEdge[204, 226] -> 
             RGBColor[
              0.7882479764223962, 0.8346185504314757, 0.9794986047627936], 
             UndirectedEdge[137, 191] -> 
             RGBColor[
              0.6255250873748657, 0.7028397833614782, 0.9660139311322384], 
             UndirectedEdge[197, 198] -> 
             RGBColor[
              0.5521535681261918, 0.6428121634814156, 0.9598215133879044], 
             UndirectedEdge[80, 156] -> 
             RGBColor[
              0.6209061762217314, 0.6990545016096426, 0.9656204637604653], 
             UndirectedEdge[103, 159] -> 
             RGBColor[
              0.7142689342262781, 0.775889470017421, 0.9728595722722022], 
             UndirectedEdge[28, 288] -> 
             RGBColor[
              0.6907641589970659, 0.2739166812137776, 0.42584797805486296`], 
             UndirectedEdge[118, 263] -> 
             RGBColor[
              0.509605457294456, 0.6109428334019252, 0.9550391586989649], 
             UndirectedEdge[68, 83] -> 
             RGBColor[
              0.23539672905744033`, 0.3647472656269854, 0.9367168675303434], 
             UndirectedEdge[64, 90] -> 
             RGBColor[
              0.6523556954485195, 0.7196871518600452, 0.9193620921599537], 
             UndirectedEdge[213, 263] -> 
             RGBColor[
              0.4471748762987453, 0.5525043874364252, 0.9512209325567611], 
             UndirectedEdge[52, 53] -> 
             RGBColor[
              0.6043476458167417, 0.6896756702820392, 0.9619956069585156], 
             UndirectedEdge[245, 297] -> 
             RGBColor[
              0.7056770075656584, 0.7626049200365853, 0.7561891385239288], 
             UndirectedEdge[189, 267] -> 
             RGBColor[
              0.6295039536077316, 0.7052835711276806, 0.9667289696316035], 
             UndirectedEdge[145, 203] -> 
             RGBColor[
              0.8407050318602166, 0.8763970299535532, 0.9833610823157859], 
             UndirectedEdge[136, 279] -> 
             RGBColor[
              0.8302166789812515, 0.8664374413633094, 0.8978277040454756], 
             UndirectedEdge[80, 256] -> 
             RGBColor[
              0.29883326111608527`, 0.4222802163331391, 0.9406642493186598], 
             UndirectedEdge[40, 130] -> 
             RGBColor[
              0.598156912017942, 0.6834962299722438, 0.9622969201855469], 
             UndirectedEdge[83, 101] -> 
             RGBColor[
              0.40386940242109715`, 0.5209739839842049, 0.9474816211895916], 
             UndirectedEdge[83, 194] -> 
             RGBColor[
              0.30264271633582096`, 0.43499501347225344`, 0.9405622464336473],
              UndirectedEdge[149, 197] -> 
             RGBColor[
              0.5037666322314047, 0.6050119214060745, 0.9549987558195367], 
             UndirectedEdge[23, 44] -> 
             RGBColor[
              0.5403136046196759, 0.6149246435600246, 0.9619935824930852], 
             UndirectedEdge[97, 284] -> 
             RGBColor[
              0.47872640294029994`, 0.5876906861424438, 0.9521062425535072], 
             UndirectedEdge[135, 276] -> 
             RGBColor[
              0.2987173466155263, 0.42738398201009453`, 0.9404663133756193], 
             UndirectedEdge[142, 150] -> 
             RGBColor[
              0.7997965965643764, 0.84361171910198, 0.9806572796951893], 
             UndirectedEdge[46, 214] -> 
             RGBColor[
              0.5099328121459373, 0.6130254549682941, 0.9545629253990184], 
             UndirectedEdge[5, 243] -> 
             RGBColor[
              0.5190213506257246, 0.6062840381317549, 0.958676657668478], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.6054501362682607, 0.680290294204393, 0.9661721818587483], 
             UndirectedEdge[198, 243] -> 
             RGBColor[
              0.4983285328051089, 0.5901186515790496, 0.956614190973496], 
             UndirectedEdge[13, 32] -> 
             RGBColor[
              0.6562504073791934, 0.7309774934948418, 0.9666525974254546], 
             UndirectedEdge[86, 140] -> 
             RGBColor[
              0.24376074838587775`, 0.3735383802506278, 0.9371931860576402], 
             UndirectedEdge[171, 275] -> 
             RGBColor[
              0.30597208521681296`, 0.4372239881208788, 0.9407983647482198], 
             UndirectedEdge[36, 250] -> 
             RGBColor[
              0.21408462083664417`, 0.34234688862122203`, 0.9355031744956078],
              UndirectedEdge[168, 203] -> 
             RGBColor[
              0.6762067542313199, 0.7433848651080431, 0.9696263535638847], 
             UndirectedEdge[17, 169] -> 
             RGBColor[
              0.3709288919875867, 0.49429485597649614`, 0.9449077501828083], 
             UndirectedEdge[191, 246] -> 
             RGBColor[
              0.6316888837907219, 0.708178554015477, 0.9664066827894257], 
             UndirectedEdge[17, 178] -> 
             RGBColor[
              0.27989480876964806`, 0.41151756874572243`, 0.939250967340944], 
             UndirectedEdge[9, 132] -> 
             RGBColor[
              0.41418264450075976`, 0.52826239948574, 0.9483922206671838], 
             UndirectedEdge[11, 283] -> 
             RGBColor[
              0.39377544247573815`, 0.5153507216632685, 0.9463505472805732], 
             UndirectedEdge[64, 69] -> 
             RGBColor[
              0.3159393455177574, 0.44807251433942324`, 0.9413523536155658], 
             UndirectedEdge[193, 288] -> 
             RGBColor[
              0.6461981541670827, 0.23502063080486496`, 0.4230190809749773], 
             UndirectedEdge[221, 288] -> 
             RGBColor[
              0.7664085090926483, 0.335384698150865, 0.43187984395388923`], 
             UndirectedEdge[65, 264] -> 
             RGBColor[
              0.6049225351095903, 0.6890161543172006, 0.9628108787313925], 
             UndirectedEdge[27, 151] -> 
             RGBColor[
              0.7257554619673245, 0.7847561216361414, 0.9742917074531285], 
             UndirectedEdge[201, 293] -> 
             RGBColor[
              0.4895214007105023, 0.5963689990979355, 0.952979702744021], 
             UndirectedEdge[43, 99] -> 
             RGBColor[
              0.6067350478724451, 0.6870910180092824, 0.9645743973321623], 
             UndirectedEdge[77, 293] -> 
             RGBColor[
              0.5522092672936887, 0.6470796573196894, 0.9580392759106984], 
             UndirectedEdge[61, 280] -> 
             RGBColor[
              0.7934990009139801, 0.8390161126179765, 0.9799435819098465], 
             UndirectedEdge[20, 55] -> 
             RGBColor[
              0.8841197207193141, 0.9104370827838195, 0.9888093222968419], 
             UndirectedEdge[208, 242] -> 
             RGBColor[
              0.5241802662883136, 0.6219862445045609, 0.9565987053412639], 
             UndirectedEdge[29, 261] -> 
             RGBColor[
              0.7106096894455265, 0.7718708447619048, 0.9593766996152394], 
             UndirectedEdge[12, 76] -> 
             RGBColor[
              0.2575672692449994, 0.3855666201817237, 0.938070372366085], 
             UndirectedEdge[168, 276] -> 
             RGBColor[
              0.33087681670198643`, 0.4552388986170213, 0.9425154863720256], 
             UndirectedEdge[148, 271] -> 
             RGBColor[
              0.5399987556731106, 0.6331283311127709, 0.958689775296711], 
             UndirectedEdge[131, 170] -> 
             RGBColor[
              0.6696695451818857, 0.7365976148176343, 0.9527903821525159], 
             UndirectedEdge[141, 261] -> 
             RGBColor[
              0.7261682983764313, 0.7834744298276897, 0.933040033030325], 
             UndirectedEdge[129, 184] -> 
             RGBColor[
              0.4344199924040152, 0.5506944956618376, 0.9489018356668358], 
             UndirectedEdge[111, 185] -> 
             RGBColor[
              0.5331750725981578, 0.6279236321634323, 0.9579563191861937], 
             UndirectedEdge[234, 239] -> 
             RGBColor[
              0.27197493370579084`, 0.4031932779045267, 0.9387999421724625], 
             UndirectedEdge[103, 203] -> 
             RGBColor[
              0.7517427592913726, 0.8057370485229525, 0.9752886050642526], 
             UndirectedEdge[28, 160] -> 
             RGBColor[
              0.5116823799677122, 0.6140205315699174, 0.954818169823435], 
             UndirectedEdge[133, 170] -> 
             RGBColor[
              0.6653523340871772, 0.7328582635567367, 0.952515293279121], 
             UndirectedEdge[87, 299] -> 
             RGBColor[
              0.7376240202118907, 0.7946276530041814, 0.9749542957837363], 
             UndirectedEdge[5, 290] -> 
             RGBColor[
              0.8480183017537897, 0.88185288036495, 0.9853123084897253], 
             UndirectedEdge[183, 253] -> 
             RGBColor[
              0.472077688932644, 0.5820640553938583, 0.9516460786194657], 
             UndirectedEdge[176, 245] -> 
             RGBColor[
              0.9267557477241057, 0.9400485855799181, 0.7755164756409259], 
             UndirectedEdge[29, 190] -> 
             RGBColor[
              0.9724399366538601, 0.9759460870721215, 0.755574706028256], 
             UndirectedEdge[159, 168] -> 
             RGBColor[
              0.6387329291662254, 0.7135372866025118, 0.9671973207718343], 
             UndirectedEdge[202, 299] -> 
             RGBColor[
              0.9433629826790648, 0.9533977411650625, 0.7857740302503282], 
             UndirectedEdge[65, 115] -> 
             RGBColor[
              0.6184184325720177, 0.6999727318604513, 0.963873325216736], 
             UndirectedEdge[51, 142] -> 
             RGBColor[
              0.5632307981444653, 0.6517499443143495, 0.9608053162469203], 
             UndirectedEdge[134, 187] -> 
             RGBColor[
              0.5689115765087771, 0.6588082187811766, 0.9602624426094091], 
             UndirectedEdge[85, 239] -> 
             RGBColor[
              0.349683775209344, 0.4716386564369395, 0.9437098172652891], 
             UndirectedEdge[120, 284] -> 
             RGBColor[
              0.4441269609779991, 0.5584336498257798, 0.9497050730924148], 
             UndirectedEdge[31, 61] -> 
             RGBColor[
              0.5574073520745995, 0.6489440402632918, 0.9594869931677628], 
             UndirectedEdge[217, 247] -> 
             RGBColor[
              0.6876213867726964, 0.7558943205537109, 0.9694993317124493], 
             UndirectedEdge[66, 169] -> 
             RGBColor[
              0.4269959594287486, 0.5442641714414086, 0.9484287828504664], 
             UndirectedEdge[168, 293] -> 
             RGBColor[
              0.4328003575675147, 0.5492916493716747, 0.9487986339672408], 
             UndirectedEdge[93, 105] -> 
             RGBColor[
              0.2835813791092368, 0.4114433407616187, 0.939605506029151], 
             UndirectedEdge[169, 193] -> 
             RGBColor[
              0.3761422124466848, 0.4997743863226166, 0.9452046410705375], 
             UndirectedEdge[87, 216] -> 
             RGBColor[
              0.4196580574323434, 0.5296039785486776, 0.9491057749178138], 
             UndirectedEdge[81, 201] -> 
             RGBColor[
              0.447661990151349, 0.5601124815867455, 0.9503124581180151], 
             UndirectedEdge[63, 244] -> 
             RGBColor[
              0.6106388083948924, 0.6938040577927881, 0.9631602601423415], 
             UndirectedEdge[32, 150] -> 
             RGBColor[
              0.7230779320755697, 0.7832689357914879, 0.973290711956106], 
             UndirectedEdge[95, 282] -> 
             RGBColor[
              0.6759778248210095, 0.7422151699266495, 0.955434631611197], 
             UndirectedEdge[126, 239] -> 
             RGBColor[
              0.4274339426487111, 0.5347994288912934, 0.9498196304684912], 
             UndirectedEdge[149, 150] -> 
             RGBColor[
              0.7436778203297851, 0.7997713045890209, 0.975063884539906], 
             UndirectedEdge[16, 222] -> 
             RGBColor[
              0.479440549476439, 0.5881528396300899, 0.9521949623266293], 
             UndirectedEdge[192, 262] -> 
             RGBColor[
              0.3328897300296925, 0.458889448532759, 0.9425739204170558], 
             UndirectedEdge[214, 276] -> 
             RGBColor[
              0.3763432390854653, 0.4931792401958255, 0.9458105501755829], 
             UndirectedEdge[48, 100] -> 
             RGBColor[
              0.5796433801829907, 0.6670096847181374, 0.9614092467838601], 
             UndirectedEdge[105, 143] -> 
             RGBColor[
              0.41378116873439585`, 0.5199111241457566, 0.9490911313166344], 
             UndirectedEdge[268, 279] -> 
             RGBColor[
              0.7093586263004913, 0.7681133161765433, 0.8881903847585182], 
             UndirectedEdge[24, 106] -> 
             RGBColor[
              0.3919192135354385, 0.5103937097647457, 0.9466208316819581], 
             UndirectedEdge[33, 222] -> 
             RGBColor[
              0.526301536465051, 0.6263143227731778, 0.9558515313380319], 
             UndirectedEdge[155, 291] -> 
             RGBColor[
              0.7031130140903812, 0.7650715200494662, 0.9477241825759897], 
             UndirectedEdge[99, 233] -> 
             RGBColor[
              0.30201753495307765`, 0.42741181232541803`, 0.9407802415770681],
              UndirectedEdge[237, 269] -> 
             RGBColor[
              0.541967273392181, 0.639032473744028, 0.9570847955344208], 
             UndirectedEdge[85, 135] -> 
             RGBColor[
              0.40148554053623176`, 0.5221683287876454, 0.946803281516613], 
             UndirectedEdge[126, 248] -> 
             RGBColor[
              0.6484709072407683, 0.7247734794260625, 0.9659637731168933], 
             UndirectedEdge[188, 261] -> 
             RGBColor[
              0.5039713631616417, 0.6081856821226267, 0.9540936182974675], 
             UndirectedEdge[37, 177] -> 
             RGBColor[
              0.45823020181828833`, 0.5689910654087946, 0.9510618578671113], 
             UndirectedEdge[160, 180] -> 
             RGBColor[
              0.4705636044134416, 0.5784055148745594, 0.9521981178050225], 
             UndirectedEdge[23, 194] -> 
             RGBColor[
              0.2461729872783806, 0.37564174784526805`, 0.9373463789033039], 
             UndirectedEdge[51, 243] -> 
             RGBColor[
              0.30023202435640883`, 0.42839465059019965`, 0.9405738582412444],
              UndirectedEdge[108, 208] -> 
             RGBColor[
              0.6204626130011763, 0.6975749304719737, 0.9660964634118446], 
             UndirectedEdge[179, 251] -> 
             RGBColor[
              0.41922227608759355`, 0.5375309976479854, 0.9479334506219663], 
             UndirectedEdge[26, 224] -> 
             RGBColor[
              0.5072535048426765, 0.6103551812390287, 0.9544887957311134], 
             UndirectedEdge[106, 291] -> 
             RGBColor[
              0.6241961160745462, 0.6944779117174174, 0.942777676120822], 
             UndirectedEdge[48, 161] -> 
             RGBColor[
              0.5234379121416336, 0.617740399247265, 0.9578493745905365], 
             UndirectedEdge[227, 299] -> 
             RGBColor[
              0.8196646104299155, 0.8596359121427908, 0.982504017205014], 
             UndirectedEdge[162, 299] -> 
             RGBColor[
              0.92554898896046, 0.9428884991333912, 0.972542443563639], 
             UndirectedEdge[200, 227] -> 
             RGBColor[
              0.7282680248664639, 0.7876477831584532, 0.9735506087332069], 
             UndirectedEdge[202, 293] -> 
             RGBColor[
              0.7220541692589697, 0.776891506082819, 0.765908743774278], 
             UndirectedEdge[3, 155] -> 
             RGBColor[
              0.6682145683679741, 0.7379709285037763, 0.9695831170432081], 
             UndirectedEdge[39, 234] -> 
             RGBColor[
              0.3921478624007709, 0.5120048024352897, 0.946509077047663], 
             UndirectedEdge[144, 176] -> 
             RGBColor[
              0.5740471623875799, 0.6557044948267216, 0.9631081482443438], 
             UndirectedEdge[140, 162] -> 
             RGBColor[
              0.605613232239929, 0.6757944463537642, 0.9465817458468264], 
             UndirectedEdge[123, 257] -> 
             RGBColor[
              0.39511219369392203`, 0.5166480560865632, 0.9463971774915503], 
             UndirectedEdge[121, 286] -> 
             RGBColor[
              0.7262793774682124, 0.7854934635679224, 0.973973841434262], 
             UndirectedEdge[176, 230] -> 
             RGBColor[
              0.6390609813991405, 0.7139006073328966, 0.9671817738150387], 
             UndirectedEdge[39, 64] -> 
             RGBColor[
              0.40375047608592485`, 0.523192289027024, 0.9472067217593432], 
             UndirectedEdge[269, 277] -> 
             RGBColor[
              0.5233542843461231, 0.6239216107308372, 0.9556195128550896], 
             UndirectedEdge[154, 203] -> 
             RGBColor[
              0.6674395230975831, 0.7357911301538498, 0.9690677133486012], 
             UndirectedEdge[107, 137] -> 
             RGBColor[
              0.5261459628964198, 0.6250283558898411, 0.956159702981125], 
             UndirectedEdge[192, 218] -> 
             RGBColor[
              0.28959065486738234`, 0.4213859659019616, 0.9398149416355821], 
             UndirectedEdge[247, 270] -> 
             RGBColor[
              0.4904365617237201, 0.5934414687545779, 0.954159793988528], 
             UndirectedEdge[28, 240] -> 
             RGBColor[
              0.3495988753603211, 0.47286249275263803`, 0.9436569043668281], 
             UndirectedEdge[31, 194] -> 
             RGBColor[
              0.35593546344394555`, 0.4827151414237495, 0.9439008708826442], 
             UndirectedEdge[58, 187] -> 
             RGBColor[
              0.6706609384835608, 0.7423420039170058, 0.9680158204807183], 
             UndirectedEdge[8, 121] -> 
             RGBColor[
              0.601778877968072, 0.6808327303745073, 0.9651634232706271], 
             UndirectedEdge[62, 186] -> 
             RGBColor[
              0.6453860443462527, 0.7197748708645464, 0.967402587267705], 
             UndirectedEdge[271, 289] -> 
             RGBColor[
              0.6700300389089477, 0.7317310403893613, 0.7540658567161816], 
             UndirectedEdge[236, 294] -> 
             RGBColor[
              0.745708759897771, 0.8009376736571681, 0.9758825705153689], 
             UndirectedEdge[115, 211] -> 
             RGBColor[
              0.6898745909703932, 0.7561084932823491, 0.9709121696080965], 
             UndirectedEdge[43, 284] -> 
             RGBColor[
              0.6515395241199347, 0.7252298692679875, 0.9676140169111896], 
             UndirectedEdge[87, 181] -> 
             RGBColor[
              0.5857004118436373, 0.6745370056943558, 0.9605276283930841], 
             UndirectedEdge[77, 205] -> 
             RGBColor[
              0.5746361292976588, 0.6653723467565984, 0.9597811622172896], 
             UndirectedEdge[132, 267] -> 
             RGBColor[
              0.7075793437575822, 0.7704038407337499, 0.9723959230558803], 
             UndirectedEdge[108, 280] -> 
             RGBColor[
              0.8683333838147523, 0.8978494862448219, 0.9873036073902556], 
             UndirectedEdge[40, 97] -> 
             RGBColor[
              0.4790832401292405, 0.5879803826477579, 0.9521343340841583], 
             UndirectedEdge[35, 262] -> 
             RGBColor[
              0.507046093842132, 0.6092024867710034, 0.9547444350520221], 
             UndirectedEdge[201, 216] -> 
             RGBColor[
              0.3928642513510503, 0.5078515597246752, 0.9469964683541487], 
             UndirectedEdge[244, 279] -> 
             RGBColor[
              0.7521286690035455, 0.8034836070349519, 0.8913784533843352], 
             UndirectedEdge[143, 163] -> 
             RGBColor[
              0.4390588548202097, 0.5464795749198122, 0.9505306581442361], 
             UndirectedEdge[102, 165] -> 
             RGBColor[
              0.6689252300669783, 0.7351068985708447, 0.9403956702605946], 
             UndirectedEdge[7, 282] -> 
             RGBColor[
              0.4063684704508596, 0.5263976772565025, 0.9471144174929677], 
             UndirectedEdge[10, 122] -> 
             RGBColor[
              0.7620202439180336, 0.8141898496512738, 0.976868387275511], 
             UndirectedEdge[113, 193] -> 
             RGBColor[
              0.46539608779747205`, 0.5723701943939759, 0.9521935964579971], 
             UndirectedEdge[22, 100] -> 
             RGBColor[
              0.34373750996192387`, 0.4688140704867598, 0.9432457686639384], 
             UndirectedEdge[116, 254] -> 
             RGBColor[
              0.9177702029399932, 0.935060641925845, 0.9070670446971469], 
             UndirectedEdge[174, 298] -> 
             RGBColor[
              0.5929351271406582, 0.6623979814131278, 0.9454529526089803], 
             UndirectedEdge[159, 271] -> 
             RGBColor[
              0.604154003040048, 0.6835867587793782, 0.9649939821760181], 
             UndirectedEdge[11, 101] -> 
             RGBColor[
              0.42248363500902664`, 0.5386573256511274, 0.948610561358368], 
             UndirectedEdge[148, 225] -> 
             RGBColor[
              0.7250422828985801, 0.7851278090165954, 0.9732290969201207], 
             UndirectedEdge[239, 248] -> 
             RGBColor[
              0.4685480433848464, 0.5674542658277424, 0.9535509044745992], 
             UndirectedEdge[22, 119] -> 
             RGBColor[
              0.6316507310781312, 0.6971576737490663, 0.8718510474689316], 
             UndirectedEdge[38, 247] -> 
             RGBColor[
              0.8220413193623095, 0.8605232600298665, 0.9184367352000224], 
             UndirectedEdge[157, 222] -> 
             RGBColor[
              0.48392357112483964`, 0.5919099814044115, 0.9525153826708485], 
             UndirectedEdge[42, 203] -> 
             RGBColor[
              0.6486280704914834, 0.7194975953975455, 0.9678690642228549], 
             UndirectedEdge[155, 241] -> 
             RGBColor[
              0.35608634574890863`, 0.4792466498304612, 0.944042268516889], 
             UndirectedEdge[103, 154] -> 
             RGBColor[
              0.4822023235458009, 0.5890078416689548, 0.952795647606742], 
             UndirectedEdge[88, 107] -> 
             RGBColor[
              0.44194089372503814`, 0.545941365919422, 0.9510195142637086], 
             UndirectedEdge[58, 176] -> 
             RGBColor[
              0.7411648260553949, 0.7977414275505983, 0.9749577390093545], 
             UndirectedEdge[48, 119] -> 
             RGBColor[
              0.867556601299198, 0.8953532879804439, 0.8900145255888534], 
             UndirectedEdge[206, 219] -> 
             RGBColor[
              0.5561919938703538, 0.6505203059212192, 0.9582459385551562], 
             UndirectedEdge[1, 125] -> 
             RGBColor[
              0.7969385772778106, 0.8420014214417573, 0.9802072509032655], 
             UndirectedEdge[191, 278] -> 
             RGBColor[
              0.9065320908217145, 0.9273559448436488, 0.9579352748704808], 
             UndirectedEdge[90, 118] -> 
             RGBColor[
              0.6857359053144021, 0.7485994119077425, 0.9214890496156471], 
             UndirectedEdge[101, 283] -> 
             RGBColor[
              0.48716415419402515`, 0.5945408327265801, 0.9527704932407016], 
             UndirectedEdge[5, 226] -> 
             RGBColor[
              0.7686960199759738, 0.8192304402021453, 0.9775800934646285], 
             UndirectedEdge[3, 241] -> 
             RGBColor[
              0.5819460205321136, 0.6596502700893605, 0.9642179450065813], 
             UndirectedEdge[194, 241] -> 
             RGBColor[
              0.29161838623490466`, 0.42340774355329075`, 0.9399344271434349],
              UndirectedEdge[139, 235] -> 
             RGBColor[
              0.6615503415476656, 0.7341060325125296, 0.9678726252433447], 
             UndirectedEdge[40, 94] -> 
             RGBColor[
              0.39630801994738657`, 0.5169959086223354, 0.9466634466350841], 
             UndirectedEdge[161, 177] -> 
             RGBColor[
              0.420702027868211, 0.5358991133316924, 0.9486920863376015], 
             UndirectedEdge[34, 295] -> 
             RGBColor[
              0.41633288234289956`, 0.5339402372326305, 0.9480499898103762], 
             UndirectedEdge[1, 281] -> 
             RGBColor[
              0.4832238475009798, 0.5833176636426163, 0.9543172967624852], 
             UndirectedEdge[191, 295] -> 
             RGBColor[
              0.6669170568328786, 0.7376033141062799, 0.9689520396274528], 
             UndirectedEdge[144, 297] -> 
             RGBColor[
              0.3529684222291325, 0.47826082928338876`, 0.9437808111273467], 
             UndirectedEdge[141, 294] -> 
             RGBColor[
              0.9551141719221107, 0.9658416865846711, 0.9538219896857809], 
             UndirectedEdge[80, 201] -> 
             RGBColor[
              0.4682547927385704, 0.5779489321634441, 0.9516246132893724], 
             UndirectedEdge[113, 115] -> 
             RGBColor[
              0.5738966468596305, 0.6649541775267864, 0.9595983927749272], 
             UndirectedEdge[129, 253] -> 
             RGBColor[
              0.4436262602934832, 0.5586685021872164, 0.9494884509159697], 
             UndirectedEdge[37, 108] -> 
             RGBColor[
              0.6217428351504918, 0.6986837945518746, 0.966178038035143], 
             UndirectedEdge[265, 276] -> 
             RGBColor[
              0.29774741033585084`, 0.42654387195505455`, 0.9404045098935593],
              UndirectedEdge[59, 194] -> 
             RGBColor[
              0.48734558042428133`, 0.5905998102836156, 0.9540324237311999], 
             UndirectedEdge[103, 225] -> 
             RGBColor[
              0.6414341557788297, 0.7186505267038392, 0.9656902708496192], 
             UndirectedEdge[46, 265] -> 
             RGBColor[
              0.43133698339632287`, 0.5463900867275232, 0.9491568851169947], 
             UndirectedEdge[51, 149] -> 
             RGBColor[
              0.5071120219098741, 0.6079095298013906, 0.955211921091637], 
             UndirectedEdge[52, 124] -> 
             RGBColor[
              0.49679759356149733`, 0.6011055655761535, 0.9538759445670377], 
             UndirectedEdge[82, 258] -> 
             RGBColor[
              0.34192791248863885`, 0.4701217302929854, 0.9430251933349854], 
             UndirectedEdge[45, 132] -> 
             RGBColor[
              0.6596091171024812, 0.7325281545285255, 0.9677211070804388], 
             UndirectedEdge[74, 287] -> 
             RGBColor[
              0.7734631601808502, 0.8232425952119107, 0.9735639507144203], 
             UndirectedEdge[128, 269] -> 
             RGBColor[
              0.40123495096043427`, 0.5216213255569258, 0.9468784817573781], 
             UndirectedEdge[14, 249] -> 
             RGBColor[
              0.2942594504653253, 0.42365861676313765`, 0.9401772863946878], 
             UndirectedEdge[101, 198] -> 
             RGBColor[
              0.6347339064903375, 0.7126406047900102, 0.9655527593553763], 
             UndirectedEdge[164, 297] -> 
             RGBColor[
              0.41902277600078874`, 0.537358200699961, 0.9479207386528461], 
             UndirectedEdge[68, 235] -> 
             RGBColor[
              0.3642491453880201, 0.47529987880666213`, 0.9455922058186559], 
             UndirectedEdge[108, 177] -> 
             RGBColor[
              0.7025188842874102, 0.7663213114802316, 0.9719678731696313], 
             UndirectedEdge[62, 276] -> 
             RGBColor[
              0.54726994710014, 0.6290199364053501, 0.9613620466131287], 
             UndirectedEdge[13, 107] -> 
             RGBColor[
              0.6692812516863451, 0.7415565199362338, 0.9676784332228691], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.5719193123989241, 0.6506056609046609, 0.9634205934299858], 
             UndirectedEdge[62, 135] -> 
             RGBColor[
              0.5996672099311784, 0.680175514389641, 0.9644894235663544], 
             UndirectedEdge[18, 35] -> 
             RGBColor[
              0.5286551086278239, 0.6279191292777069, 0.9561213423660648], 
             UndirectedEdge[42, 202] -> 
             RGBColor[
              0.6771086775711035, 0.7379619802088855, 0.7630448567876649], 
             UndirectedEdge[121, 255] -> 
             RGBColor[
              0.6419419061175453, 0.7156199267050913, 0.9677225759095403], 
             UndirectedEdge[128, 281] -> 
             RGBColor[
              0.308555117108666, 0.43902910316986576`, 0.940978777386095], 
             UndirectedEdge[82, 181] -> 
             RGBColor[
              0.44634995177926073`, 0.5568844628805425, 0.9506963285162225], 
             UndirectedEdge[136, 204] -> 
             RGBColor[
              0.7526334550749094, 0.8067962156744316, 0.9759488821115005], 
             UndirectedEdge[118, 166] -> 
             RGBColor[
              0.5088461189824427, 0.6103263683524317, 0.9549793808054954], 
             UndirectedEdge[39, 263] -> 
             RGBColor[
              0.5603317075253976, 0.6539415486817031, 0.9585305110605263], 
             UndirectedEdge[52, 84] -> 
             RGBColor[
              0.6408739617469768, 0.7185197915628228, 0.9654246117326477], 
             UndirectedEdge[129, 165] -> 
             RGBColor[
              0.7060501207202641, 0.7672626129034615, 0.9427612354647701], 
             UndirectedEdge[141, 236] -> 
             RGBColor[
              0.7730005713488813, 0.8214949787965792, 0.9367268411109848], 
             UndirectedEdge[97, 178] -> 
             RGBColor[
              0.3728865016101631, 0.49275787755335587`, 0.9453213281022246], 
             UndirectedEdge[115, 227] -> 
             RGBColor[
              0.6337510045648305, 0.7119506536331, 0.9654015327019478], 
             UndirectedEdge[256, 281] -> 
             RGBColor[
              0.23507144961468163`, 0.36440537630873815`, 0.9366983433472862],
              UndirectedEdge[221, 297] -> 
             RGBColor[
              0.5410799425472244, 0.637001007910733, 0.9575159255751828], 
             UndirectedEdge[224, 262] -> 
             RGBColor[
              0.48912783482765765`, 0.5946556368946834, 0.9533338440656571], 
             UndirectedEdge[73, 119] -> 
             RGBColor[
              0.6340452074432155, 0.6996744202273402, 0.8719874093556128], 
             UndirectedEdge[3, 227] -> 
             RGBColor[
              0.8203093358276377, 0.8601499986743297, 0.982565511689002], 
             UndirectedEdge[45, 188] -> 
             RGBColor[
              0.6558329160389373, 0.7294624643892214, 0.9674238307000363], 
             UndirectedEdge[260, 300] -> 
             RGBColor[
              0.6416739284611866, 0.7151775661338459, 0.9678022910599671], 
             UndirectedEdge[23, 291] -> 
             RGBColor[
              0.5713990672979967, 0.6389848659270276, 0.9397709622992316], 
             UndirectedEdge[142, 149] -> 
             RGBColor[
              0.7129403706983783, 0.7756737032278584, 0.9720228914108041], 
             UndirectedEdge[81, 97] -> 
             RGBColor[
              0.42298077583065985`, 0.5400751599251759, 0.9483694625164234], 
             UndirectedEdge[181, 201] -> 
             RGBColor[
              0.5589066057623442, 0.6527845868703535, 0.9584183218294191], 
             UndirectedEdge[56, 57] -> 
             RGBColor[
              0.43673405937270965`, 0.5520434600407205, 0.9492303650271263], 
             UndirectedEdge[197, 243] -> 
             RGBColor[
              0.2968866346779395, 0.4254970421948837, 0.9403606929691444], 
             UndirectedEdge[65, 200] -> 
             RGBColor[
              0.7129354528736509, 0.7756698613858046, 0.972022401247995], 
             UndirectedEdge[8, 173] -> 
             RGBColor[
              0.6341847401665137, 0.7063781024033191, 0.9580548190951135], 
             UndirectedEdge[53, 273] -> 
             RGBColor[
              0.5372412406931786, 0.6351687480489021, 0.9567201828511123], 
             UndirectedEdge[26, 253] -> 
             RGBColor[
              0.43998588139814765`, 0.5555153889588402, 0.9492564891918196], 
             UndirectedEdge[114, 206] -> 
             RGBColor[
              0.6084198569003928, 0.6913211094667465, 0.9634515238448609], 
             UndirectedEdge[9, 45] -> 
             RGBColor[
              0.5282272465325113, 0.6188376774217009, 0.958745344171136], 
             UndirectedEdge[47, 190] -> 
             RGBColor[
              0.7418460538170806, 0.792812724437679, 0.7484057555465451], 
             UndirectedEdge[191, 282] -> 
             RGBColor[
              0.619637290448793, 0.6977400695933922, 0.9656387659184835], 
             UndirectedEdge[59, 155] -> 
             RGBColor[
              0.5518135399382853, 0.6464387165607861, 0.958140265104654], 
             UndirectedEdge[214, 265] -> 
             RGBColor[
              0.42777056563682825`, 0.5434947081250763, 0.9488761236467487], 
             UndirectedEdge[167, 282] -> 
             RGBColor[
              0.32050524533964253`, 0.44587256990183477`, 0.9418686423351608],
              UndirectedEdge[28, 221] -> 
             RGBColor[
              0.5511210021345713, 0.6456980690469639, 0.9581557330131283], 
             UndirectedEdge[136, 197] -> 
             RGBColor[
              0.5109467826807019, 0.6106211095082301, 0.9557144061140019], 
             UndirectedEdge[121, 234] -> 
             RGBColor[
              0.5893670698435981, 0.6689443602307292, 0.964414217404816], 
             UndirectedEdge[141, 146] -> 
             RGBColor[
              0.8255977025679195, 0.8637908190418423, 0.9411442988581802], 
             UndirectedEdge[32, 167] -> 
             RGBColor[
              0.4288997416318032, 0.5353515053413052, 0.9499930914531258], 
             UndirectedEdge[101, 136] -> 
             RGBColor[
              0.5935271210448476, 0.6804495508168249, 0.9614456520814736], 
             UndirectedEdge[91, 274] -> 
             RGBColor[
              0.3170510808509781, 0.43773233963124375`, 0.9418370544141281], 
             UndirectedEdge[84, 295] -> 
             RGBColor[
              0.5943004469326686, 0.6807093141236351, 0.9617581740420593], 
             UndirectedEdge[73, 122] -> 
             RGBColor[
              0.4799563742126712, 0.5804068423087824, 0.954048341218624], 
             UndirectedEdge[157, 248] -> 
             RGBColor[
              0.5737685461536851, 0.6641267373925521, 0.9600829296083528], 
             UndirectedEdge[125, 167] -> 
             RGBColor[
              0.5748587257153926, 0.6504930333891924, 0.9640730904303356], 
             UndirectedEdge[20, 208] -> 
             RGBColor[
              0.6106254778383059, 0.6897310659150214, 0.9651581886782958], 
             UndirectedEdge[77, 103] -> 
             RGBColor[
              0.6103784644057115, 0.694389584571163, 0.9625949297654831], 
             UndirectedEdge[46, 276] -> 
             RGBColor[
              0.3799096568449599, 0.49607461879827236`, 0.9460913116458292], 
             UndirectedEdge[3, 291] -> 
             RGBColor[
              0.9289726888735863, 0.9454751403083654, 0.9678998590656818], 
             UndirectedEdge[79, 297] -> 
             RGBColor[
              0.5174917893094586, 0.6181915951658126, 0.9554261693617687], 
             UndirectedEdge[18, 262] -> 
             RGBColor[
              0.4204418401567265, 0.5385873227475959, 0.9480111601660333], 
             UndirectedEdge[127, 225] -> 
             RGBColor[
              0.8536515939655973, 0.8844344725646478, 0.8860839757947631], 
             UndirectedEdge[109, 292] -> 
             RGBColor[
              0.40307410702298885`, 0.5182760286819755, 0.9476058256124628], 
             UndirectedEdge[267, 287] -> 
             RGBColor[
              0.9052258948593498, 0.9271335465958106, 0.9862103345364046], 
             UndirectedEdge[218, 262] -> 
             RGBColor[
              0.3555337502087244, 0.48236719761009517`, 0.943875274070517], 
             UndirectedEdge[207, 225] -> 
             RGBColor[
              0.4665262451397091, 0.5617161628942026, 0.9540077672336268], 
             UndirectedEdge[203, 299] -> 
             RGBColor[
              0.9148823755994449, 0.9349333563537225, 0.9905982376855182], 
             UndirectedEdge[142, 163] -> 
             RGBColor[
              0.5176594714446069, 0.6083502117549542, 0.958045380049251], 
             UndirectedEdge[2, 54] -> 
             RGBColor[
              0.4860087262822762, 0.5926749392968663, 0.9529359055869602], 
             UndirectedEdge[90, 195] -> 
             RGBColor[
              0.9875041117872957, 0.9891006433414372, 0.8567527362139689], 
             UndirectedEdge[88, 93] -> 
             RGBColor[
              0.29682830765713686`, 0.42536670256924214`, 0.9403598990128794],
              UndirectedEdge[77, 82] -> 
             RGBColor[
              0.4790068485055631, 0.5832146268927033, 0.9533917537286988], 
             UndirectedEdge[167, 168] -> 
             RGBColor[
              0.32880560746386767`, 0.453061926385508, 0.9423975340699943], 
             UndirectedEdge[18, 26] -> 
             RGBColor[
              0.43856751017174533`, 0.5542868670919412, 0.9491661118314896], 
             UndirectedEdge[129, 224] -> 
             RGBColor[
              0.510893883738012, 0.6135082944674048, 0.9547207574552636], 
             UndirectedEdge[38, 289] -> 
             RGBColor[
              0.9902329201858594, 0.9889370994351334, 0.7176162804481934], 
             UndirectedEdge[31, 241] -> 
             RGBColor[
              0.33413487512208906`, 0.4602333892865041, 0.9426435402194714], 
             UndirectedEdge[5, 197] -> 
             RGBColor[
              0.5728463859468075, 0.6589775500341208, 0.9618839800828864], 
             UndirectedEdge[59, 241] -> 
             RGBColor[
              0.4655449921024247, 0.5681180581463702, 0.9527750930680271], 
             UndirectedEdge[155, 226] -> 
             RGBColor[
              0.5923829158210621, 0.6781318213390879, 0.9621838413502763], 
             UndirectedEdge[15, 186] -> 
             RGBColor[
              0.42720606161262165`, 0.5444461513930366, 0.9484421703758368], 
             UndirectedEdge[198, 256] -> 
             RGBColor[
              0.4718140194569256, 0.562250216932866, 0.9551042286630242], 
             UndirectedEdge[72, 291] -> 
             RGBColor[
              0.6808545800994152, 0.7457923832679125, 0.9463058948444456], 
             UndirectedEdge[230, 297] -> 
             RGBColor[
              0.41798224124069305`, 0.5364569417895638, 0.9478544366980416], 
             UndirectedEdge[138, 231] -> 
             RGBColor[
              0.4296462076445151, 0.5398674304857949, 0.9496959516278813], 
             UndirectedEdge[54, 165] -> 
             RGBColor[
              0.7613036631429027, 0.8124173295009969, 0.9470288237446793], 
             UndirectedEdge[103, 167] -> 
             RGBColor[
              0.4043416125239204, 0.5154141098004172, 0.9480597855703622], 
             UndirectedEdge[78, 131] -> 
             RGBColor[
              0.607612356990576, 0.6876300498081174, 0.9647319677407571], 
             UndirectedEdge[16, 239] -> 
             RGBColor[
              0.34824855991322734`, 0.4703955450834614, 0.9436183666157316], 
             UndirectedEdge[12, 87] -> 
             RGBColor[
              0.38099644297763247`, 0.4889681704688402, 0.9469040531693511], 
             UndirectedEdge[125, 281] -> 
             RGBColor[
              0.5938250563457041, 0.6704278494164668, 0.9651531949015602], 
             UndirectedEdge[148, 205] -> 
             RGBColor[
              0.6143713517512881, 0.6964138045362493, 0.9637415978447016], 
             UndirectedEdge[103, 269] -> 
             RGBColor[
              0.5159877770060002, 0.6179411482147517, 0.9550395944128697], 
             UndirectedEdge[40, 169] -> 
             RGBColor[
              0.4634906176932603, 0.5751860980942667, 0.9509442623562125], 
             UndirectedEdge[38, 53] -> 
             RGBColor[
              0.8044186818933073, 0.8464468360362756, 0.916891872429987], 
             UndirectedEdge[118, 285] -> 
             RGBColor[
              0.44554845003095644`, 0.5589384691701247, 0.9499963564386331], 
             UndirectedEdge[74, 267] -> 
             RGBColor[
              0.7378314377659354, 0.7949638534910353, 0.9747774787132895], 
             UndirectedEdge[3, 200] -> 
             RGBColor[
              0.8020329321900055, 0.8458723332467991, 0.9807438905771053], 
             UndirectedEdge[124, 273] -> 
             RGBColor[
              0.4296911884379342, 0.5465986433430163, 0.9486005204596343], 
             UndirectedEdge[131, 182] -> 
             RGBColor[
              0.36267751008105403`, 0.4885547633556959, 0.944330468132603], 
             UndirectedEdge[62, 207] -> 
             RGBColor[
              0.5324547744385706, 0.6134482506018405, 0.9605183444471361], 
             UndirectedEdge[75, 262] -> 
             RGBColor[
              0.37220258453069244`, 0.4968049040998107, 0.9449373974538413], 
             UndirectedEdge[197, 283] -> 
             RGBColor[
              0.40458381582987957`, 0.5247123914179854, 0.9470392472732299], 
             UndirectedEdge[246, 278] -> 
             RGBColor[
              0.6977792190858849, 0.7599250399132342, 0.93969867867493], 
             UndirectedEdge[225, 265] -> 
             RGBColor[
              0.5327687443526414, 0.6276033166269631, 0.9579170428707849], 
             UndirectedEdge[101, 204] -> 
             RGBColor[
              0.6749786807573754, 0.7441941015720459, 0.9695337373485233], 
             UndirectedEdge[87, 140] -> 
             RGBColor[
              0.4176882634913597, 0.5275336002245543, 0.9489935980669237], 
             UndirectedEdge[57, 247] -> 
             RGBColor[
              0.5267073700963316, 0.6248574199430985, 0.9564709378250142], 
             UndirectedEdge[40, 66] -> 
             RGBColor[
              0.44215861472988727`, 0.5567093893050368, 0.949585005990536], 
             UndirectedEdge[167, 293] -> 
             RGBColor[
              0.34617241541189747`, 0.4681041825489438, 0.9435041317155775], 
             UndirectedEdge[42, 140] -> 
             RGBColor[
              0.3065947305272424, 0.4348165619637937, 0.9409459333854487], 
             UndirectedEdge[107, 150] -> 
             RGBColor[
              0.7361087763827214, 0.79384796223288, 0.9743165477535204], 
             UndirectedEdge[91, 143] -> 
             RGBColor[
              0.5297334231812736, 0.6289454684513032, 0.9561645330173267], 
             UndirectedEdge[91, 142] -> 
             RGBColor[
              0.6083340398056708, 0.6908161052864452, 0.9636792549223416], 
             UndirectedEdge[44, 283] -> 
             RGBColor[
              0.6800780854500442, 0.7478447579293852, 0.9704983220745387], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.5505170325124016, 0.6345458386988321, 0.9612268569040749], 
             UndirectedEdge[199, 233] -> 
             RGBColor[
              0.2425884222677286, 0.37230619117068403`, 0.9371264238195127], 
             UndirectedEdge[249, 286] -> 
             RGBColor[
              0.40902635874982535`, 0.5198886024700843, 0.9483674887331388], 
             UndirectedEdge[48, 266] -> 
             RGBColor[
              0.7571920611262268, 0.8102434601153976, 0.9764334863570934], 
             UndirectedEdge[113, 169] -> 
             RGBColor[
              0.5375818377429088, 0.6353366883019975, 0.9567769946036025], 
             UndirectedEdge[18, 33] -> 
             RGBColor[
              0.49237943497665393`, 0.5984689032072122, 0.9532655884540737], 
             UndirectedEdge[269, 293] -> 
             RGBColor[
              0.45781857989397723`, 0.5706312209632782, 0.9504839405580849], 
             UndirectedEdge[189, 257] -> 
             RGBColor[
              0.41873813301909746`, 0.5371116572557922, 0.9479026014537526], 
             UndirectedEdge[11, 197] -> 
             RGBColor[
              0.33990329664488095`, 0.46882888434253267`, 0.9428793153908962],
              UndirectedEdge[221, 296] -> 
             RGBColor[
              0.7423655538375359, 0.7986621697647847, 0.9749553763912024], 
             UndirectedEdge[126, 157] -> 
             RGBColor[
              0.5326544454175498, 0.6314719004561031, 0.9563516556022449], 
             UndirectedEdge[24, 87] -> 
             RGBColor[
              0.5408902887929123, 0.6381581291287384, 0.9570000113616417], 
             UndirectedEdge[53, 137] -> 
             RGBColor[
              0.5163821615444206, 0.6171016620980498, 0.9553910607727127], 
             UndirectedEdge[27, 140] -> 
             RGBColor[
              0.3895055847683408, 0.5046536320219996, 0.946774954361294], 
             UndirectedEdge[115, 200] -> 
             RGBColor[
              0.6154746009271983, 0.6976729882055693, 0.9635799115900512], 
             UndirectedEdge[1, 5] -> 
             RGBColor[
              0.7406592351638395, 0.7973278908194492, 0.9747856487732054], 
             UndirectedEdge[40, 42] -> 
             RGBColor[
              0.41946472756710546`, 0.5370530848725692, 0.94813897156794], 
             UndirectedEdge[82, 167] -> 
             RGBColor[
              0.27296999662377186`, 0.4042391521219577, 0.9388566095335779], 
             UndirectedEdge[52, 57] -> 
             RGBColor[
              0.49127647457840984`, 0.5963234498125118, 0.9535241437475692], 
             UndirectedEdge[27, 203] -> 
             RGBColor[
              0.7315389247325819, 0.7893346654557514, 0.9736980851987], 
             UndirectedEdge[251, 270] -> 
             RGBColor[
              0.36351263131154926`, 0.48927810339113736`, 0.9443836813189415],
              UndirectedEdge[200, 264] -> 
             RGBColor[
              0.601978703464771, 0.6867164106623187, 0.9625174651047077], 
             UndirectedEdge[84, 271] -> 
             RGBColor[
              0.5207421165466307, 0.618084898271287, 0.9567704534721073], 
             UndirectedEdge[80, 145] -> 
             RGBColor[
              0.5760320272244794, 0.6638837472826934, 0.9611782732644936], 
             UndirectedEdge[199, 259] -> 
             RGBColor[
              0.33325668592635593`, 0.4594408134657756, 0.942588751984933], 
             UndirectedEdge[273, 274] -> 
             RGBColor[
              0.3194099032721399, 0.439775433054592, 0.9419873564929797], 
             UndirectedEdge[281, 294] -> 
             RGBColor[
              0.6039663435199368, 0.6785142365312928, 0.9661204799254723], 
             UndirectedEdge[18, 183] -> 
             RGBColor[
              0.47065931770624175`, 0.5808355335269593, 0.9515557012591358], 
             UndirectedEdge[77, 269] -> 
             RGBColor[
              0.5598606816721214, 0.6533769727478571, 0.9586179848559593], 
             UndirectedEdge[134, 144] -> 
             RGBColor[
              0.3537327883347926, 0.478922884785954, 0.9438295158596969], 
             UndirectedEdge[200, 210] -> 
             RGBColor[
              0.8058251567235571, 0.8488961501526605, 0.9811055963384743], 
             UndirectedEdge[87, 151] -> 
             RGBColor[
              0.7539381406903435, 0.8076360898386962, 0.9765103511587583], 
             UndirectedEdge[109, 290] -> 
             RGBColor[
              0.5878817942179574, 0.6650036049407313, 0.9646901316981882], 
             UndirectedEdge[247, 278] -> 
             RGBColor[
              0.8150118024602716, 0.8556942475738114, 0.9488572672809906], 
             UndirectedEdge[156, 205] -> 
             RGBColor[
              0.6645996461976336, 0.735767257981043, 0.9687174395217051], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.5456110485575645, 0.6396251172302911, 0.958355079829111], 
             UndirectedEdge[64, 121] -> 
             RGBColor[
              0.6009696835287521, 0.6801318468224635, 0.9651118621164962], 
             UndirectedEdge[106, 264] -> 
             RGBColor[
              0.3892434416269046, 0.5082213975872472, 0.9464101851156428], 
             UndirectedEdge[91, 107] -> 
             RGBColor[
              0.5446462196240159, 0.6410523484173452, 0.9573385229806728], 
             UndirectedEdge[7, 299] -> 
             RGBColor[
              0.6533444539432097, 0.7251355249858551, 0.9686151933494347], 
             UndirectedEdge[160, 221] -> 
             RGBColor[
              0.6251489051110858, 0.7062225569755487, 0.9638659686719746], 
             UndirectedEdge[8, 234] -> 
             RGBColor[
              0.3088505967432664, 0.44079471065985815`, 0.9409423283845391], 
             UndirectedEdge[49, 174] -> 
             RGBColor[
              0.26663225688413655`, 0.3975777858196925, 0.9384956846312513], 
             UndirectedEdge[79, 245] -> 
             RGBColor[
              0.8055964390586132, 0.8446945938335269, 0.7637869885969997], 
             UndirectedEdge[13, 147] -> 
             RGBColor[
              0.5309758558373171, 0.6268779026143134, 0.9574525661134244], 
             UndirectedEdge[1, 197] -> 
             RGBColor[
              0.5185245192160544, 0.6165408948825781, 0.9564696840738718], 
             UndirectedEdge[129, 175] -> 
             RGBColor[
              0.434999629016217, 0.5511965477619436, 0.9489387695992129], 
             UndirectedEdge[116, 283] -> 
             RGBColor[
              0.7238195601234252, 0.780514600540502, 0.8897185323433177], 
             UndirectedEdge[62, 265] -> 
             RGBColor[
              0.5986972736515029, 0.6793354043346009, 0.9644276200842943], 
             UndirectedEdge[31, 291] -> 
             RGBColor[
              0.6811615434635616, 0.746058259505509, 0.946325454278572], 
             UndirectedEdge[92, 277] -> 
             RGBColor[
              0.7789141400160147, 0.8264879531817084, 0.9423440388047293], 
             UndirectedEdge[124, 289] -> 
             RGBColor[
              0.7004200899029691, 0.7580533751120071, 0.7560022838926537], 
             UndirectedEdge[80, 277] -> 
             RGBColor[
              0.4944362619957584, 0.5992042283681782, 0.9536857144551802], 
             UndirectedEdge[119, 244] -> 
             RGBColor[
              0.7528205292516568, 0.8037697090275433, 0.8799125385962034], 
             UndirectedEdge[252, 268] -> 
             RGBColor[
              0.7055649135574729, 0.766124531982261, 0.9322541700190373], 
             UndirectedEdge[3, 194] -> 
             RGBColor[
              0.6037466088539702, 0.6821320222266058, 0.965475275669754], 
             UndirectedEdge[1, 237] -> 
             RGBColor[
              0.6524009604725192, 0.7280138233822584, 0.9662391471648432], 
             UndirectedEdge[149, 281] -> 
             RGBColor[
              0.4684659605163302, 0.5717886901661127, 0.9528463685081503], 
             UndirectedEdge[29, 209] -> 
             RGBColor[
              0.7250730922865745, 0.7836128867571404, 0.9605153116680771], 
             UndirectedEdge[123, 287] -> 
             RGBColor[
              0.6415097366974711, 0.7130987116793269, 0.9640100176705317], 
             UndirectedEdge[17, 81] -> 
             RGBColor[
              0.32998908299014484`, 0.4588348511175423, 0.942299101755143], 
             UndirectedEdge[176, 187] -> 
             RGBColor[
              0.7892259505615644, 0.8355898288219441, 0.9795410749940558], 
             UndirectedEdge[246, 270] -> 
             RGBColor[
              0.37320397834933333`, 0.4976722610940007, 0.9450012053824672], 
             UndirectedEdge[45, 131] -> 
             RGBColor[
              0.5786583944207111, 0.6649174164017226, 0.9618709400097848], 
             UndirectedEdge[4, 158] -> 
             RGBColor[
              0.4600487033443955, 0.570417988536778, 0.951218671401417], 
             UndirectedEdge[169, 264] -> 
             RGBColor[
              0.4711468740464159, 0.5814017919121766, 0.951546990902124], 
             UndirectedEdge[42, 181] -> 
             RGBColor[
              0.47460687887952, 0.5818199674335951, 0.952479963711609], 
             UndirectedEdge[8, 263] -> 
             RGBColor[
              0.4770344418678932, 0.5827314569062716, 0.9529637623974023], 
             UndirectedEdge[145, 205] -> 
             RGBColor[
              0.6197254972003816, 0.7005965036540938, 0.9642752490257334], 
             UndirectedEdge[167, 269] -> 
             RGBColor[
              0.3538238297903302, 0.4744014979771114, 0.9440828406608384], 
             UndirectedEdge[187, 288] -> 
             RGBColor[
              0.7844533543299101, 0.3494814683961172, 0.43367838548847326`], 
             UndirectedEdge[47, 131] -> 
             RGBColor[
              0.43688203477252086`, 0.5518282483312932, 0.9493346709614912], 
             UndirectedEdge[43, 97] -> 
             RGBColor[
              0.6523263284437167, 0.7258686324631647, 0.967675957029717], 
             UndirectedEdge[104, 114] -> 
             RGBColor[
              0.8416568833908946, 0.8771378806589326, 0.9846107017536374], 
             UndirectedEdge[26, 129] -> 
             RGBColor[
              0.43872454429640784`, 0.5544228821579593, 0.9491761179070533], 
             UndirectedEdge[28, 79] -> 
             RGBColor[
              0.5275328488968056, 0.6268886563020435, 0.9560659767997142], 
             UndirectedEdge[53, 247] -> 
             RGBColor[
              0.6397785413346635, 0.7182096404126259, 0.9649424010359607], 
             UndirectedEdge[150, 281] -> 
             RGBColor[
              0.5553221863823283, 0.6397267060402342, 0.9614807567925355], 
             UndirectedEdge[76, 248] -> 
             RGBColor[
              0.5125949542898419, 0.6112670730485217, 0.9561502362595086], 
             UndirectedEdge[194, 210] -> 
             RGBColor[
              0.607538833387522, 0.6851558391324672, 0.965836981431123], 
             UndirectedEdge[60, 265] -> 
             RGBColor[
              0.5741384387649746, 0.6599216363232006, 0.9620403873880317], 
             UndirectedEdge[78, 178] -> 
             RGBColor[
              0.5489107201151034, 0.6328575025231834, 0.9611353797893751], 
             UndirectedEdge[120, 190] -> 
             RGBColor[
              0.7019527155678944, 0.7592578646280118, 0.7455878311775682], 
             UndirectedEdge[96, 267] -> 
             RGBColor[
              0.5974899808177823, 0.6775546769660846, 0.9646890675942724], 
             UndirectedEdge[159, 212] -> 
             RGBColor[
              0.569373366212368, 0.6504999811993091, 0.9628862271694334], 
             UndirectedEdge[34, 147] -> 
             RGBColor[
              0.35217306070909843`, 0.47945633727868475`, 0.9436611339073417],
              UndirectedEdge[41, 250] -> 
             RGBColor[
              0.4668734020527299, 0.5663796054662973, 0.9533470123908905], 
             UndirectedEdge[146, 236] -> 
             RGBColor[
              0.6161922905435797, 0.6988868061143394, 0.9632048796877681], 
             UndirectedEdge[82, 103] -> 
             RGBColor[
              0.4351339438394419, 0.547778802359598, 0.9498133632856092], 
             UndirectedEdge[179, 289] -> 
             RGBColor[
              0.7143378073233142, 0.7701082024166929, 0.7568891085397238], 
             UndirectedEdge[124, 247] -> 
             RGBColor[
              0.5322284890794191, 0.6296395357067401, 0.9568227386444828], 
             UndirectedEdge[162, 227] -> 
             RGBColor[
              0.8524288070346406, 0.8851780355765843, 0.9654106562037285], 
             UndirectedEdge[156, 191] -> 
             RGBColor[
              0.8373100791991669, 0.8731123452495245, 0.98434457690119], 
             UndirectedEdge[1, 51] -> 
             RGBColor[
              0.5218699088945237, 0.6194385032778941, 0.9566828493459718], 
             UndirectedEdge[23, 198] -> 
             RGBColor[
              0.4662612331266806, 0.5564138864327908, 0.9547880056961281], 
             UndirectedEdge[77, 159] -> 
             RGBColor[
              0.7581418388923993, 0.8113252945505265, 0.9764379627152919], 
             UndirectedEdge[2, 238] -> 
             RGBColor[
              0.6780627016853433, 0.7449923935100868, 0.9697446128945053], 
             UndirectedEdge[113, 245] -> 
             RGBColor[
              0.8103086852042546, 0.8485202075388283, 0.7641579538751109], 
             UndirectedEdge[167, 201] -> 
             RGBColor[
              0.3855266506068553, 0.5001392761117687, 0.9465786028467744], 
             UndirectedEdge[125, 150] -> 
             RGBColor[
              0.8690369161591591, 0.8984104638393751, 0.9873707109333159], 
             UndirectedEdge[142, 198] -> 
             RGBColor[
              0.7613273065931654, 0.8134739453031995, 0.9768456489791718], 
             UndirectedEdge[34, 52] -> 
             RGBColor[
              0.4629063971572077, 0.5717507146718181, 0.9517164275009646], 
             UndirectedEdge[13, 251] -> 
             RGBColor[
              0.5502161573911774, 0.643542884774593, 0.9586785411149058], 
             UndirectedEdge[120, 188] -> 
             RGBColor[
              0.47416321814156104`, 0.5828184365091247, 0.9520696372827657], 
             UndirectedEdge[67, 173] -> 
             RGBColor[
              0.7613383700635402, 0.8131927663750886, 0.9670741014023283], 
             UndirectedEdge[20, 280] -> 
             RGBColor[
              0.8584962486518819, 0.8900056216878697, 0.9863653326567068], 
             UndirectedEdge[32, 107] -> 
             RGBColor[
              0.6286526622625079, 0.7094075775612254, 0.9639089868853351], 
             UndirectedEdge[189, 287] -> 
             RGBColor[
              0.6651356760226466, 0.733562312848556, 0.9655154416327342], 
             UndirectedEdge[159, 205] -> 
             RGBColor[
              0.6785265991182254, 0.7468722322028567, 0.9700458047240088], 
             UndirectedEdge[66, 86] -> 
             RGBColor[
              0.3201360871612291, 0.4448529765065453, 0.9418707447343854], 
             UndirectedEdge[119, 266] -> 
             RGBColor[
              0.8802706429233729, 0.9052855939275446, 0.8912817424384769], 
             UndirectedEdge[28, 230] -> 
             RGBColor[
              0.42802330082803997`, 0.5451540029257947, 0.9484942441359869], 
             UndirectedEdge[83, 142] -> 
             RGBColor[
              0.5304628025239251, 0.6218073244973942, 0.9587745108133872], 
             UndirectedEdge[191, 217] -> 
             RGBColor[
              0.7791416751341392, 0.8275560178235484, 0.9785773393019395], 
             UndirectedEdge[43, 233] -> 
             RGBColor[
              0.520421936703984, 0.603728609904844, 0.9593895756323053], 
             UndirectedEdge[113, 297] -> 
             RGBColor[0.5222040354551, 0.6220172088711138, 0.95579713463988], 
             UndirectedEdge[158, 207] -> 
             RGBColor[
              0.29616192593340007`, 0.42243107717812745`, 0.9404037917648839],
              UndirectedEdge[40, 201] -> 
             RGBColor[
              0.5037644544499296, 0.6080177043093276, 0.9540773296857499], 
             UndirectedEdge[194, 226] -> 
             RGBColor[
              0.5279149563070581, 0.6222929150619174, 0.9580759999768222], 
             UndirectedEdge[134, 230] -> 
             RGBColor[
              0.41874660734635316`, 0.5371189972921291, 0.9479031414303918], 
             UndirectedEdge[134, 264] -> 
             RGBColor[
              0.45653343786426714`, 0.568744367983858, 0.9506158356707517], 
             UndirectedEdge[59, 226] -> 
             RGBColor[
              0.7018415621745782, 0.7670032296549969, 0.9709166659014143], 
             UndirectedEdge[42, 201] -> 
             RGBColor[
              0.44457590902263605`, 0.557439473224002, 0.9501158157574079], 
             UndirectedEdge[217, 295] -> 
             RGBColor[
              0.6056169764404664, 0.6895498729839364, 0.9628860999444158], 
             UndirectedEdge[45, 94] -> 
             RGBColor[
              0.5438082430173035, 0.634731966875631, 0.9596503191791386], 
             UndirectedEdge[197, 254] -> 
             RGBColor[
              0.5985344586464476, 0.6792584328033284, 0.9643877596270591], 
             UndirectedEdge[30, 189] -> 
             RGBColor[
              0.3580954861919221, 0.4845860445621467, 0.9440385056221121], 
             UndirectedEdge[92, 179] -> 
             RGBColor[
              0.7057404699040281, 0.7665819414549117, 0.9367217820898674], 
             UndirectedEdge[134, 288] -> 
             RGBColor[
              0.6845796966759413, 0.26856001079133385`, 0.42545390958446616`],
              UndirectedEdge[59, 83] -> 
             RGBColor[
              0.47656932220334103`, 0.5797053280653329, 0.9534029123582395], 
             UndirectedEdge[10, 22] -> 
             RGBColor[
              0.557124625130365, 0.6402196795263071, 0.9617957212111945], 
             UndirectedEdge[148, 168] -> 
             RGBColor[
              0.574577681799288, 0.6630788589359045, 0.9608931138925272], 
             UndirectedEdge[130, 216] -> 
             RGBColor[
              0.4872567089190626, 0.5833300853875913, 0.9552160588539458], 
             UndirectedEdge[158, 196] -> 
             RGBColor[
              0.4916441475754697, 0.5960685935221062, 0.953705980509213], 
             UndirectedEdge[203, 237] -> 
             RGBColor[
              0.7777222556775535, 0.8268283740522289, 0.9773338061858038], 
             UndirectedEdge[160, 193] -> 
             RGBColor[
              0.4448333727227373, 0.5556764559565486, 0.9505748242036067], 
             UndirectedEdge[38, 88] -> 
             RGBColor[
              0.6144398704006849, 0.6803282917448712, 0.9037452062193583], 
             UndirectedEdge[22, 73] -> 
             RGBColor[
              0.27506075542500263`, 0.40643667218381563`, 0.9389756751543075],
              UndirectedEdge[181, 227] -> 
             RGBColor[
              0.6677410020616621, 0.7395452648329652, 0.9680773498143619], 
             UndirectedEdge[85, 255] -> 
             RGBColor[
              0.42672246639629285`, 0.544027285522855, 0.9484113561162788], 
             UndirectedEdge[106, 227] -> 
             RGBColor[
              0.5155327630285975, 0.6091527700833818, 0.9574433287441421], 
             UndirectedEdge[131, 261] -> 
             RGBColor[
              0.42679684154341546`, 0.543640634135128, 0.948540727607216], 
             UndirectedEdge[81, 94] -> 
             RGBColor[
              0.34020555564880595`, 0.4690906858997533, 0.9428985750673491], 
             UndirectedEdge[77, 154] -> 
             RGBColor[
              0.5260752282119221, 0.6244436662020603, 0.9563740380498316], 
             UndirectedEdge[167, 277] -> 
             RGBColor[
              0.4117081198640433, 0.5213945723165029, 0.9486397040125821], 
             UndirectedEdge[113, 176] -> 
             RGBColor[
              0.7432827756135474, 0.7994608744144467, 0.9751244717568771], 
             UndirectedEdge[4, 276] -> 
             RGBColor[
              0.39539168853391393`, 0.5086436295809447, 0.9473101138929343], 
             UndirectedEdge[101, 243] -> 
             RGBColor[
              0.3794669730420851, 0.49532548350347844`, 0.946091938936616], 
             UndirectedEdge[52, 271] -> 
             RGBColor[
              0.466407542567476, 0.5747832308535077, 0.9519395173905656], 
             UndirectedEdge[37, 71] -> 
             RGBColor[
              0.38616744684187226`, 0.5089005659393664, 0.9458272261316667], 
             UndirectedEdge[83, 291] -> 
             RGBColor[
              0.627868796355437, 0.6983381315540129, 0.9429868298295752], 
             UndirectedEdge[80, 149] -> 
             RGBColor[
              0.5322277720177339, 0.6296635301905136, 0.956812274479524], 
             UndirectedEdge[104, 206] -> 
             RGBColor[
              0.6993167299525103, 0.7632402969708338, 0.9722698259529658], 
             UndirectedEdge[61, 108] -> 
             RGBColor[
              0.7911971347188413, 0.8371806669964662, 0.979724027857254], 
             UndirectedEdge[115, 264] -> 
             RGBColor[
              0.5074616831631377, 0.6110192811369652, 0.9543683890734487], 
             UndirectedEdge[38, 52] -> 
             RGBColor[
              0.7866104238443876, 0.8319892898992798, 0.9154899411225774], 
             UndirectedEdge[33, 285] -> 
             RGBColor[
              0.5237002396759682, 0.6242024728527156, 0.9556467477259312], 
             UndirectedEdge[100, 122] -> 
             RGBColor[
              0.5486331287495925, 0.6427842406117266, 0.9583184347282548], 
             UndirectedEdge[205, 269] -> 
             RGBColor[
              0.48024544189794743`, 0.5889239104001872, 0.9522258268646762], 
             UndirectedEdge[177, 252] -> 
             RGBColor[
              0.7603351440346456, 0.8112371158779976, 0.936386937384569], 
             UndirectedEdge[152, 244] -> 
             RGBColor[
              0.515967874757115, 0.6179249906725206, 0.9550380276349331], 
             UndirectedEdge[10, 71] -> 
             RGBColor[
              0.6182318561015933, 0.6964835083726839, 0.9655672793427366], 
             UndirectedEdge[233, 259] -> 
             RGBColor[
              0.3063726874432439, 0.4311840265160712, 0.9410577480426314], 
             UndirectedEdge[130, 299] -> 
             RGBColor[
              0.8052226716986098, 0.8483537598430951, 0.9810645797198682], 
             UndirectedEdge[81, 86] -> 
             RGBColor[
              0.30052828112716024`, 0.4278696804368213, 0.9406213526723965], 
             UndirectedEdge[205, 282] -> 
             RGBColor[
              0.44692685744725974`, 0.5603949823249106, 0.9500116285389986], 
             UndirectedEdge[176, 297] -> 
             RGBColor[
              0.6386510979749511, 0.7135455869122037, 0.967155656405695], 
             UndirectedEdge[92, 128] -> 
             RGBColor[
              0.6567948066303259, 0.724187668007797, 0.9336030077070178], 
             UndirectedEdge[166, 285] -> 
             RGBColor[
              0.5679901332925332, 0.6601590037276129, 0.9591334103906533], 
             UndirectedEdge[132, 146] -> 
             RGBColor[
              0.6071769684166737, 0.6915677614760836, 0.962495160505725], 
             UndirectedEdge[81, 130] -> 
             RGBColor[
              0.5420544477193613, 0.6355910072496617, 0.958532048617812], 
             UndirectedEdge[1, 128] -> 
             RGBColor[
              0.5116686380407724, 0.6106026751951561, 0.9560328333878004], 
             UndirectedEdge[296, 297] -> 
             RGBColor[
              0.6188579691068153, 0.6977630832229227, 0.9652677701047174], 
             UndirectedEdge[128, 237] -> 
             RGBColor[
              0.4777322300802054, 0.583725262909508, 0.952900627788453], 
             UndirectedEdge[112, 146] -> 
             RGBColor[
              0.42941099721155396`, 0.5291246536798765, 0.9508778916843779], 
             UndirectedEdge[116, 287] -> 
             RGBColor[
              0.9650203879301892, 0.9726036303294845, 0.9069616960306319], 
             UndirectedEdge[10, 266] -> 
             RGBColor[
              0.8057445369756069, 0.8483475997047853, 0.9812264161807398], 
             UndirectedEdge[16, 76] -> 
             RGBColor[
              0.3922954708182229, 0.5142083523042407, 0.946217698400641], 
             UndirectedEdge[23, 72] -> 
             RGBColor[
              0.28838251280141847`, 0.41220151734088495`, 0.9400359325452139],
              UndirectedEdge[237, 277] -> 
             RGBColor[
              0.5998515634658941, 0.6860255480834194, 0.9616416588861645], 
             UndirectedEdge[56, 278] -> 
             RGBColor[
              0.7250384917366496, 0.7828802876714334, 0.9416166944831027], 
             UndirectedEdge[88, 274] -> 
             RGBColor[
              0.21434575495200037`, 0.3426213571333206, 0.935518045697164], 
             UndirectedEdge[103, 282] -> 
             RGBColor[
              0.4826691925553125, 0.589412220139475, 0.952825396087192], 
             UndirectedEdge[46, 60] -> 
             RGBColor[
              0.6563006852740836, 0.7294523831664184, 0.9677271891403014], 
             UndirectedEdge[82, 216] -> 
             RGBColor[
              0.28030759736796684`, 0.41195143573486426`, 0.9392744750409523],
              UndirectedEdge[48, 70] -> 
             RGBColor[
              0.5057241685464391, 0.5991221316125036, 0.9568406030979255], 
             UndirectedEdge[143, 174] -> 
             RGBColor[
              0.41947499604519894`, 0.5258956976589131, 0.949415386358722], 
             UndirectedEdge[95, 205] -> 
             RGBColor[
              0.7240718568972346, 0.7827394720106675, 0.9588120072982049], 
             UndirectedEdge[78, 190] -> 
             RGBColor[
              0.9125763760351358, 0.9286145259145032, 0.763803052325811], 
             UndirectedEdge[68, 292] -> 
             RGBColor[
              0.3551835636115248, 0.46794003112069826`, 0.9448785300128899], 
             UndirectedEdge[145, 269] -> 
             RGBColor[
              0.6049500495748441, 0.6886011296453525, 0.9631120716644029], 
             UndirectedEdge[198, 254] -> 
             RGBColor[
              0.799976356773617, 0.8438800421874944, 0.9806412576314107], 
             UndirectedEdge[124, 147] -> 
             RGBColor[
              0.3860642571133881, 0.50881118818302, 0.9458206509734148], 
             UndirectedEdge[44, 194] -> 
             RGBColor[
              0.6075595918980564, 0.6851723914052927, 0.9658389613963891], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.5662773196750629, 0.6558895024522313, 0.9603642221576936], 
             UndirectedEdge[5, 11] -> 
             RGBColor[
              0.5620380125926661, 0.6496158802794039, 0.9611952800902299], 
             UndirectedEdge[108, 254] -> 
             RGBColor[
              0.8561943824567432, 0.8881701760663594, 0.9861457786041142], 
             UndirectedEdge[61, 71] -> 
             RGBColor[
              0.5556217464102219, 0.647397438383958, 0.9593732159537778], 
             UndirectedEdge[229, 284] -> 
             RGBColor[
              0.6800317989602336, 0.7479488358234444, 0.9703316355208114], 
             UndirectedEdge[37, 136] -> 
             RGBColor[
              0.5243180240218757, 0.6222026066998241, 0.9565664097885369], 
             UndirectedEdge[148, 159] -> 
             RGBColor[
              0.7978770613460285, 0.8423667523301774, 0.9803983983427038], 
             UndirectedEdge[164, 230] -> 
             RGBColor[
              0.41943265942497804`, 0.5377132211206539, 0.9479468560621898], 
             UndirectedEdge[176, 193] -> 
             RGBColor[
              0.5818431503173233, 0.6638985724350657, 0.963552118223812], 
             UndirectedEdge[216, 299] -> 
             RGBColor[
              0.5748188295761876, 0.652322701244094, 0.963787283699002], 
             UndirectedEdge[149, 277] -> 
             RGBColor[
              0.6190300844418116, 0.7013739868925641, 0.9633029362311771], 
             UndirectedEdge[39, 248] -> 
             RGBColor[
              0.5887209720798264, 0.6762657903585054, 0.9612600393497996], 
             UndirectedEdge[13, 137] -> 
             RGBColor[
              0.5537437080131054, 0.6465982718234575, 0.9589033135212445], 
             UndirectedEdge[68, 75] -> 
             RGBColor[
              0.2622496718451751, 0.3895665639793644, 0.938370771027846], 
             UndirectedEdge[66, 97] -> 
             RGBColor[
              0.44258858186472877`, 0.5570584559948999, 0.9496188545784121], 
             UndirectedEdge[59, 106] -> 
             RGBColor[
              0.4728966419224501, 0.5758451082287374, 0.9531937586494863], 
             UndirectedEdge[51, 198] -> 
             RGBColor[
              0.5554989578046612, 0.6457097718767315, 0.9600346786600047], 
             UndirectedEdge[193, 228] -> 
             RGBColor[
              0.35121343515368436`, 0.47818233238819774`, 0.9436162014250797],
              UndirectedEdge[30, 287] -> 
             RGBColor[
              0.6338174274435402, 0.7064360200302768, 0.9635198705269133], 
             UndirectedEdge[93, 147] -> 
             RGBColor[
              0.3582655246527303, 0.4847333233305172, 0.9440493403224757], 
             UndirectedEdge[69, 121] -> 
             RGBColor[
              0.5972650130574089, 0.6769230474623381, 0.9648758037899736], 
             UndirectedEdge[148, 251] -> 
             RGBColor[
              0.5686375659792076, 0.6579338291714529, 0.9605146149651098], 
             UndirectedEdge[125, 269] -> 
             RGBColor[
              0.6865048901974724, 0.7530200718035268, 0.9710528992728431], 
             UndirectedEdge[37, 44] -> 
             RGBColor[
              0.6395771809603608, 0.7129044178002435, 0.9678790938593967], 
             UndirectedEdge[91, 105] -> 
             RGBColor[
              0.33165667823149436`, 0.4530837485265262, 0.9426688215779035], 
             UndirectedEdge[81, 203] -> 
             RGBColor[
              0.6517141516201963, 0.7221706037602891, 0.9680657065834621], 
             UndirectedEdge[8, 69] -> 
             RGBColor[
              0.31674853995707725`, 0.448773397891467, 0.9414039147696966], 
             UndirectedEdge[52, 270] -> 
             RGBColor[
              0.45500566620579824`, 0.5649074986239913, 0.9512129999110829], 
             UndirectedEdge[108, 268] -> 
             RGBColor[
              0.6477486538102374, 0.721208727584495, 0.9678351058040995], 
             UndirectedEdge[11, 254] -> 
             RGBColor[
              0.5877260852923061, 0.6698967630486115, 0.9636990596344025], 
             UndirectedEdge[82, 255] -> 
             RGBColor[
              0.35267539455299013`, 0.47943065907297133`, 0.9437100133885006],
              UndirectedEdge[43, 66] -> 
             RGBColor[
              0.6154017030443635, 0.6945976391204436, 0.9651266289360947], 
             UndirectedEdge[252, 283] -> 
             RGBColor[
              0.7200599993874106, 0.7785399390787824, 0.9332163304652228], 
             UndirectedEdge[99, 215] -> 
             RGBColor[
              0.400600941750381, 0.5214021337805692, 0.9467469156641986], 
             UndirectedEdge[114, 283] -> 
             RGBColor[
              0.604607985999757, 0.6882264609467832, 0.9631514394042197], 
             UndirectedEdge[24, 194] -> 
             RGBColor[
              0.4063681520372697, 0.525148411819624, 0.9474594967636716], 
             UndirectedEdge[134, 228] -> 
             RGBColor[
              0.4087857489169724, 0.528491402367901, 0.9472684443393129], 
             UndirectedEdge[49, 143] -> 
             RGBColor[
              0.4590151745231127, 0.5674549322313129, 0.9516671410285871], 
             UndirectedEdge[123, 189] -> 
             RGBColor[
              0.36578779544585294`, 0.4912487362111969, 0.9445286527657306], 
             UndirectedEdge[232, 240] -> 
             RGBColor[
              0.32788352486766137`, 0.4540537476011471, 0.9422732214355662], 
             UndirectedEdge[11, 243] -> 
             RGBColor[
              0.2860782613237981, 0.41613537244016674`, 0.9396719929764876], 
             UndirectedEdge[155, 210] -> 
             RGBColor[
              0.6720067929015259, 0.7409947454096377, 0.9699448228045771], 
             UndirectedEdge[148, 156] -> 
             RGBColor[
              0.7839501084254368, 0.8312617781083638, 0.9790700331404001], 
             UndirectedEdge[15, 212] -> 
             RGBColor[
              0.34428713433015, 0.4696644061218552, 0.9432670860684916], 
             UndirectedEdge[51, 204] -> 
             RGBColor[
              0.5957437320716992, 0.6772632686587671, 0.9640156566531517], 
             UndirectedEdge[95, 156] -> 
             RGBColor[
              0.8936506135713833, 0.9175874455827819, 0.9741404425939035], 
             UndirectedEdge[87, 109] -> 
             RGBColor[
              0.4285856674454873, 0.5389874627156597, 0.9496141891008469], 
             UndirectedEdge[113, 288] -> 
             RGBColor[
              0.753824571031232, 0.32539549879111895`, 0.43073398333035406`], 
             UndirectedEdge[164, 176] -> 
             RGBColor[
              0.6401015161592362, 0.7148018662432938, 0.9672480757698432], 
             UndirectedEdge[17, 294] -> 
             RGBColor[
              0.6106760910270261, 0.6855666065838069, 0.9665025901198192], 
             UndirectedEdge[77, 212] -> 
             RGBColor[
              0.46548289639180146`, 0.5690000957530509, 0.9526215846627143], 
             UndirectedEdge[180, 296] -> 
             RGBColor[
              0.5877802531398917, 0.6708451276637954, 0.9632875255242503], 
             UndirectedEdge[217, 271] -> 
             RGBColor[
              0.5320586460544285, 0.6269254571315883, 0.9578983793744638], 
             UndirectedEdge[4, 85] -> 
             RGBColor[
              0.4981598824546194, 0.6034279763584955, 0.953647082033928], 
             UndirectedEdge[95, 127] -> 
             RGBColor[
              0.9720316301920551, 0.9775406556860406, 0.8820194797915423], 
             UndirectedEdge[54, 75] -> 
             RGBColor[
              0.4492221758636854, 0.5608122782700675, 0.9505918991233568], 
             UndirectedEdge[134, 193] -> 
             RGBColor[
              0.36152877626453594`, 0.48711696239429814`, 0.9442734858391651],
              UndirectedEdge[40, 178] -> 
             RGBColor[
              0.3724565344753216, 0.49240881086349286`, 0.9452874795143482], 
             UndirectedEdge[69, 239] -> 
             RGBColor[
              0.2798728769196017, 0.4111719651361355, 0.9392615285576202], 
             UndirectedEdge[134, 200] -> 
             RGBColor[
              0.5645463556283278, 0.6553980750524621, 0.9598273581873543], 
             UndirectedEdge[89, 141] -> 
             RGBColor[
              0.6408504668299635, 0.7091536696221241, 0.9275110184908999], 
             UndirectedEdge[38, 147] -> 
             RGBColor[
              0.6758770873962784, 0.7396949125061463, 0.9074346475289545], 
             UndirectedEdge[170, 182] -> 
             RGBColor[
              0.6486839855557505, 0.7184209778343714, 0.9514532008499403], 
             UndirectedEdge[94, 120] -> 
             RGBColor[
              0.36213854511992716`, 0.4880879389955344, 0.9442961257618679], 
             UndirectedEdge[80, 269] -> 
             RGBColor[
              0.4365519719220453, 0.5522111540287868, 0.9491288511034365], 
             UndirectedEdge[263, 286] -> 
             RGBColor[
              0.6015349413680335, 0.6873921900996867, 0.9617741805610374], 
             UndirectedEdge[130, 140] -> 
             RGBColor[
              0.48528691497807885`, 0.5812597070634682, 0.9551038820030557], 
             UndirectedEdge[25, 288] -> 
             RGBColor[
              0.7417335011338609, 0.3155794235519415, 0.4297821300169846], 
             UndirectedEdge[148, 191] -> 
             RGBColor[
              0.7870817847528213, 0.833758891804731, 0.9793687352241865], 
             UndirectedEdge[177, 268] -> 
             RGBColor[
              0.48423602047803393`, 0.591515998441415, 0.9527189256360677], 
             UndirectedEdge[69, 126] -> 
             RGBColor[
              0.4597957407755236, 0.5684911787344556, 0.9516743971999142], 
             UndirectedEdge[20, 37] -> 
             RGBColor[
              0.6119056999876213, 0.6908399299949224, 0.9652397633015942], 
             UndirectedEdge[3, 72] -> 
             RGBColor[
              0.6459561343770082, 0.7186917917222228, 0.968164829311664], 
             UndirectedEdge[87, 154] -> 
             RGBColor[
              0.49018116771002895`, 0.5954854268043086, 0.9534237714468192], 
             UndirectedEdge[11, 204] -> 
             RGBColor[
              0.5815899690390884, 0.6650039905087342, 0.9631137913883949], 
             UndirectedEdge[55, 268] -> 
             RGBColor[
              0.6756739920728083, 0.7434756343019551, 0.9704986494968273], 
             UndirectedEdge[125, 142] -> 
             RGBColor[
              0.8382994665277522, 0.8743128624782126, 0.9843297178042139], 
             UndirectedEdge[176, 221] -> 
             RGBColor[
              0.7621586827056717, 0.8144446734540658, 0.9768432626921799], 
             UndirectedEdge[29, 182] -> 
             RGBColor[
              0.6464903579831651, 0.7167849739824728, 0.9551664401406265], 
             UndirectedEdge[122, 161] -> 
             RGBColor[
              0.4924276607082353, 0.5935149551408543, 0.9547585625349313], 
             UndirectedEdge[44, 226] -> 
             RGBColor[
              0.8220555736483534, 0.861575810776674, 0.9827232035666036], 
             UndirectedEdge[89, 131] -> 
             RGBColor[
              0.3414790099969477, 0.46931987392956254`, 0.9430117130677909], 
             UndirectedEdge[56, 110] -> 
             RGBColor[
              0.5233318767831494, 0.6239034192617661, 0.9556177488496508], 
             UndirectedEdge[43, 178] -> 
             RGBColor[
              0.5456996227897979, 0.6302970606788997, 0.9608291024599069], 
             UndirectedEdge[66, 162] -> 
             RGBColor[
              0.6819885710152804, 0.7471090426096818, 0.9512593045235715], 
             UndirectedEdge[5, 142] -> 
             RGBColor[
              0.782020124413781, 0.8296393318559048, 0.9789081156741538], 
             UndirectedEdge[147, 273] -> 
             RGBColor[
              0.4086996461961496, 0.528416824518773, 0.9472629579500798], 
             UndirectedEdge[81, 167] -> 
             RGBColor[
              0.3043130048527441, 0.4318476650377539, 0.9408368870895716], 
             UndirectedEdge[95, 212] -> 
             RGBColor[
              0.6149186239913773, 0.6863672210071199, 0.9516524297436296], 
             UndirectedEdge[56, 217] -> 
             RGBColor[
              0.5976480760490743, 0.6830803606513328, 0.9622587589145614], 
             UndirectedEdge[6, 93] -> 
             RGBColor[
              0.33255732766103135`, 0.4624661752278588, 0.9424112367430306], 
             UndirectedEdge[131, 146] -> 
             RGBColor[
              0.5262262457349036, 0.6239570233492806, 0.9566449934350709], 
             UndirectedEdge[7, 80] -> 
             RGBColor[
              0.41076903255118263`, 0.5302092229691202, 0.9473948174187359], 
             UndirectedEdge[76, 239] -> 
             RGBColor[
              0.2915579896977848, 0.42129302251375267`, 0.9400060936111065], 
             UndirectedEdge[148, 278] -> 
             RGBColor[
              0.8531721200479844, 0.8855053777024879, 0.9526607311096909], 
             UndirectedEdge[29, 170] -> 
             RGBColor[
              0.9534823930839968, 0.9648278254444111, 0.9636263541605394], 
             UndirectedEdge[147, 289] -> 
             RGBColor[
              0.6794285476611845, 0.7398715562877637, 0.7546647213830993], 
             UndirectedEdge[25, 28] -> 
             RGBColor[
              0.5141084901963902, 0.6159901571485786, 0.9550091621077712], 
             UndirectedEdge[5, 149] -> 
             RGBColor[
              0.7259013481791898, 0.7857989173429457, 0.9733147205188705], 
             UndirectedEdge[140, 202] -> 
             RGBColor[
              0.6234272259585338, 0.6863036883854355, 0.7598133325335157], 
             UndirectedEdge[10, 63] -> 
             RGBColor[
              0.7739273562918134, 0.8234917763350765, 0.9780551769586378], 
             UndirectedEdge[43, 259] -> 
             RGBColor[
              0.6110902003626114, 0.6908632321999355, 0.9648519037977256], 
             UndirectedEdge[21, 50] -> 
             RGBColor[
              0.7145539252453629, 0.7714319293569587, 0.8451026885205544], 
             UndirectedEdge[87, 155] -> 
             RGBColor[
              0.5124090708264077, 0.6147381192768211, 0.9548401137780319], 
             UndirectedEdge[127, 282] -> 
             RGBColor[
              0.6948866307420801, 0.7551961660002837, 0.8732191010323358], 
             UndirectedEdge[79, 144] -> 
             RGBColor[
              0.4528878537220874, 0.5603505030803304, 0.9513786612004175], 
             UndirectedEdge[54, 298] -> 
             RGBColor[
              0.7558250919560571, 0.8083314200801845, 0.9563026157237982], 
             UndirectedEdge[234, 263] -> 
             RGBColor[
              0.4646226337434193, 0.5708430867624935, 0.9522145565315913], 
             UndirectedEdge[34, 38] -> 
             RGBColor[
              0.6629774332337732, 0.7285218804260545, 0.9066126929724361], 
             UndirectedEdge[39, 85] -> 
             RGBColor[
              0.469856703904324, 0.5804501809677024, 0.9514189521404895], 
             UndirectedEdge[20, 108] -> 
             RGBColor[
              0.8561943824567432, 0.8881701760663594, 0.9861457786041142], 
             UndirectedEdge[94, 201] -> 
             RGBColor[
              0.42141920140291717`, 0.537382296973768, 0.9486402908245519], 
             UndirectedEdge[260, 294] -> 
             RGBColor[
              0.6613804206075473, 0.7308909880528746, 0.9696819138730802], 
             UndirectedEdge[138, 266] -> 
             RGBColor[
              0.6771659012101643, 0.7468389514945534, 0.969063990794031], 
             UndirectedEdge[127, 168] -> 
             RGBColor[
              0.7031869928663053, 0.7623855224839569, 0.8737479927671694], 
             UndirectedEdge[128, 198] -> 
             RGBColor[
              0.54529768695091, 0.6368739437939936, 0.9593846627018332], 
             UndirectedEdge[145, 216] -> 
             RGBColor[
              0.5006414858369593, 0.5937863748439246, 0.9565501283292699], 
             UndirectedEdge[141, 182] -> 
             RGBColor[
              0.6620489669140699, 0.7283885590482575, 0.9288297735557121], 
             UndirectedEdge[41, 252] -> 
             RGBColor[
              0.833084299773128, 0.8696525415544971, 0.942555428779052], 
             UndirectedEdge[55, 208] -> 
             RGBColor[
              0.6483879512637472, 0.7198418371894338, 0.9687600071045723], 
             UndirectedEdge[121, 249] -> 
             RGBColor[
              0.5650423323500167, 0.6433775188475404, 0.9630289595897809], 
             UndirectedEdge[89, 120] -> 
             RGBColor[
              0.35480463681309315`, 0.48086186211222964`, 0.9438608102251265],
              UndirectedEdge[32, 142] -> 
             RGBColor[
              0.6923404824441628, 0.7591713344303255, 0.9702497188270041], 
             UndirectedEdge[7, 77] -> 
             RGBColor[
              0.5340777423012587, 0.6313750416881905, 0.9568839511712588], 
             UndirectedEdge[45, 146] -> 
             RGBColor[
              0.7212215704484253, 0.7821430394120444, 0.9728482840096773], 
             UndirectedEdge[110, 223] -> 
             RGBColor[
              0.6008473605397926, 0.6868339810081572, 0.9617200516795468], 
             UndirectedEdge[225, 276] -> 
             RGBColor[
              0.4813414178012785, 0.5772878486977122, 0.9548514693996193], 
             UndirectedEdge[65, 291] -> 
             RGBColor[
              0.8398752095572318, 0.8752726684473708, 0.9591783697365716], 
             UndirectedEdge[194, 290] -> 
             RGBColor[
              0.6072372380848738, 0.6849153552247221, 0.9658082150019192], 
             UndirectedEdge[154, 258] -> 
             RGBColor[
              0.3889962921949979, 0.5113507696023423, 0.9460074776561183], 
             UndirectedEdge[31, 280] -> 
             RGBColor[
              0.6345436011705106, 0.7096128595116475, 0.9670665727007643], 
             UndirectedEdge[156, 271] -> 
             RGBColor[
              0.5902270501194562, 0.6724817845575646, 0.9636656169737143], 
             UndirectedEdge[83, 241] -> 
             RGBColor[
              0.28084212801396435`, 0.4125132613350081, 0.9393049157704745], 
             UndirectedEdge[208, 268] -> 
             RGBColor[
              0.4021797491918001, 0.5227696174331571, 0.9468475158782812], 
             UndirectedEdge[1, 80] -> 
             RGBColor[
              0.5469856590023834, 0.6411925036670172, 0.9582832027338588], 
             UndirectedEdge[116, 206] -> 
             RGBColor[
              0.727631431024061, 0.7836092490604654, 0.8900186167839589], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.4958470280222774, 0.6014723580170374, 0.9534865404166688], 
             UndirectedEdge[108, 204] -> 
             RGBColor[
              0.8500582662035254, 0.8832774035264821, 0.9855605103581067], 
             UndirectedEdge[251, 271] -> 
             RGBColor[
              0.37491450767322704`, 0.4991538356206538, 0.9451101987984241], 
             UndirectedEdge[6, 38] -> 
             RGBColor[
              0.6501688904045795, 0.7174277644034879, 0.9057965439495095], 
             UndirectedEdge[135, 158] -> 
             RGBColor[
              0.3633743614260079, 0.4891583409659279, 0.944374870884102], 
             UndirectedEdge[25, 180] -> 
             RGBColor[
              0.4729897146421197, 0.5803751404532205, 0.9523891100893587], 
             UndirectedEdge[57, 217] -> 
             RGBColor[
              0.5569275780653623, 0.6484656760905925, 0.9594830057314674], 
             UndirectedEdge[71, 136] -> 
             RGBColor[
              0.533031318182378, 0.629749624158753, 0.9571216131875807], 
             UndirectedEdge[135, 173] -> 
             RGBColor[
              0.6491108424559259, 0.7193063419986936, 0.9590058971343609], 
             UndirectedEdge[143, 235] -> 
             RGBColor[
              0.5807146022301077, 0.6704893008419289, 0.9601351271966847], 
             UndirectedEdge[264, 288] -> 
             RGBColor[
              0.7095345952335701, 0.2894389011979049, 0.427247314196035], 
             UndirectedEdge[223, 247] -> 
             RGBColor[
              0.6449433518366867, 0.7224026662502299, 0.9653489938380042], 
             UndirectedEdge[191, 225] -> 
             RGBColor[
              0.7784022536723103, 0.8269783761577563, 0.9785036406809107], 
             UndirectedEdge[1, 243] -> 
             RGBColor[
              0.4646994838949714, 0.5638473829802122, 0.9532623616594632], 
             UndirectedEdge[29, 284] -> 
             RGBColor[
              0.7146141820639647, 0.7751218722698896, 0.9596919479431028], 
             UndirectedEdge[6, 273] -> 
             RGBColor[
              0.38299144920445066`, 0.5061496764161145, 0.9456248543706347], 
             UndirectedEdge[103, 276] -> 
             RGBColor[
              0.4064128217620392, 0.5175910820319306, 0.9481777378723936], 
             UndirectedEdge[99, 199] -> 
             RGBColor[
              0.3289015334361897, 0.45566859927512243`, 0.9423112455193696], 
             UndirectedEdge[35, 129] -> 
             RGBColor[
              0.5288121427524864, 0.6280551443437249, 0.9561313484416285], 
             UndirectedEdge[77, 145] -> 
             RGBColor[
              0.6993407369745556, 0.7650495660017637, 0.9706674070170164], 
             UndirectedEdge[72, 155] -> 
             RGBColor[
              0.42009645959380304`, 0.5382881714633235, 0.9479891528219719], 
             UndirectedEdge[20, 44] -> 
             RGBColor[
              0.8740287282666122, 0.9023907993147282, 0.987846834428368], 
             UndirectedEdge[131, 178] -> 
             RGBColor[
              0.3249614328317168, 0.45195885305402483`, 0.9420710614837966], 
             UndirectedEdge[106, 241] -> 
             RGBColor[
              0.2771694477330735, 0.40865304149841253`, 0.9390957620617214], 
             UndirectedEdge[85, 286] -> 
             RGBColor[
              0.51105993774696, 0.6139008223856859, 0.9546626216410006], 
             UndirectedEdge[86, 261] -> 
             RGBColor[
              0.3522694156183621, 0.47223417914610444`, 0.9440428843816171], 
             UndirectedEdge[256, 269] -> 
             RGBColor[
              0.32775128346645, 0.44699759869579814`, 0.9425980477185691], 
             UndirectedEdge[37, 61] -> 
             RGBColor[
              0.5469084522497195, 0.6398504209250292, 0.958818012554734], 
             UndirectedEdge[73, 244] -> 
             RGBColor[
              0.39623055359852827`, 0.5130487074622926, 0.9470371662815793], 
             UndirectedEdge[180, 193] -> 
             RGBColor[
              0.3296866941919523, 0.4595369513326057, 0.9422445365263477], 
             UndirectedEdge[8, 213] -> 
             RGBColor[
              0.29140283929859245`, 0.42245601133378974`, 0.9399487044097088],
              UndirectedEdge[48, 138] -> 
             RGBColor[
              0.6644518595859892, 0.7369066455474527, 0.9677967739444073], 
             UndirectedEdge[170, 284] -> 
             RGBColor[
              0.71680780963655, 0.7767578761217881, 0.9559787086524165], 
             UndirectedEdge[55, 219] -> 
             RGBColor[
              0.7840932392117272, 0.8320824700610113, 0.9788961848946207], 
             UndirectedEdge[111, 235] -> 
             RGBColor[
              0.6333393402402159, 0.712067383879599, 0.9650608162798142], 
             UndirectedEdge[56, 247] -> 
             RGBColor[
              0.5674278680800436, 0.6594721045038388, 0.9592466910081083], 
             UndirectedEdge[7, 82] -> 
             RGBColor[
              0.358833221734989, 0.48476425947662544`, 0.9441023846913847], 
             UndirectedEdge[182, 190] -> 
             RGBColor[
              0.6676415291256137, 0.7295392394620819, 0.743401552717657], 
             UndirectedEdge[113, 228] -> 
             RGBColor[
              0.5126530604499084, 0.6137446343675788, 0.9551885549581448], 
             UndirectedEdge[133, 146] -> 
             RGBColor[
              0.5219090346401951, 0.620217672088383, 0.956369904561676], 
             UndirectedEdge[93, 274] -> 
             RGBColor[
              0.2689757817287206, 0.3960919318663363, 0.9387737388653756], 
             UndirectedEdge[153, 220] -> 
             RGBColor[
              0.6599758212949534, 0.7319647057860432, 0.9684095141807343], 
             UndirectedEdge[90, 153] -> 
             RGBColor[
              0.9129895407508073, 0.9320385875954383, 0.9409119378575541], 
             UndirectedEdge[178, 190] -> 
             RGBColor[
              0.6299254518762765, 0.6929433291604108, 0.7411421460688505], 
             UndirectedEdge[39, 126] -> 
             RGBColor[
              0.5476068713436911, 0.6436109534220564, 0.9575287653436917], 
             UndirectedEdge[15, 77] -> 
             RGBColor[
              0.5330556070101813, 0.6304897194730728, 0.9568188216143501], 
             UndirectedEdge[103, 293] -> 
             RGBColor[
              0.5083363626275674, 0.6116438327865841, 0.9544608854676088], 
             UndirectedEdge[92, 269] -> 
             RGBColor[
              0.7210298499423016, 0.779494878842317, 0.9377871754529856], 
             UndirectedEdge[8, 14] -> 
             RGBColor[
              0.33099599608338065`, 0.4611138282901046, 0.942311750075534], 
             UndirectedEdge[157, 171] -> 
             RGBColor[
              0.3713683899324385, 0.49374115409740404`, 0.9450001256259812], 
             UndirectedEdge[198, 226] -> 
             RGBColor[
              0.7480032021553582, 0.8030650536494401, 0.9755176267696465], 
             UndirectedEdge[86, 169] -> 
             RGBColor[
              0.3414680901246021, 0.4633296852957751, 0.9432300011000619], 
             UndirectedEdge[163, 235] -> 
             RGBColor[
              0.4079155433661423, 0.5211960316912077, 0.948078942584863], 
             UndirectedEdge[31, 136] -> 
             RGBColor[
              0.5348169238467557, 0.6312962260380868, 0.9572353904015658], 
             UndirectedEdge[111, 292] -> 
             RGBColor[
              0.6242737584637206, 0.704707536193635, 0.9643471404740482], 
             UndirectedEdge[48, 122] -> 
             RGBColor[
              0.7134677680686536, 0.7760857100618861, 0.9720754574518645], 
             UndirectedEdge[246, 295] -> 
             RGBColor[
              0.458164185097049, 0.5701724091758653, 0.950715443431902], 
             UndirectedEdge[258, 263] -> 
             RGBColor[
              0.5064499879530152, 0.6082097244568697, 0.9548380949828004], 
             UndirectedEdge[24, 299] -> 
             RGBColor[
              0.6960510609367565, 0.7608768518241548, 0.97168152014283], 
             UndirectedEdge[66, 193] -> 
             RGBColor[
              0.35481020948331177`, 0.4812976775333868, 0.9438453847048609], 
             UndirectedEdge[29, 199] -> 
             RGBColor[
              0.610380593131126, 0.6818773998564505, 0.95299851060652], 
             UndirectedEdge[27, 87] -> 
             RGBColor[
              0.5542805693450277, 0.6490289621062102, 0.9580541432969181], 
             UndirectedEdge[164, 180] -> 
             RGBColor[
              0.38794506003386514`, 0.5104402451408339, 0.9459404940723789], 
             UndirectedEdge[106, 200] -> 
             RGBColor[
              0.49725635939096524`, 0.5948751046558511, 0.9556217076322454], 
             UndirectedEdge[69, 285] -> 
             RGBColor[
              0.4084635696937306, 0.5268174097623018, 0.947633340656417], 
             UndirectedEdge[88, 137] -> 
             RGBColor[
              0.32640335005179827`, 0.45098311780664563`, 0.942244394562084], 
             UndirectedEdge[43, 261] -> 
             RGBColor[
              0.6475350315014965, 0.7219788417600028, 0.9672987685833263], 
             UndirectedEdge[224, 253] -> 
             RGBColor[
              0.5121552208397518, 0.6146008012682858, 0.9548011287400299], 
             UndirectedEdge[5, 23] -> 
             RGBColor[
              0.48695405094729627`, 0.5725792729854959, 0.9568504723911101], 
             UndirectedEdge[42, 162] -> 
             RGBColor[
              0.6592946838524986, 0.7274527381772142, 0.9498132701009756], 
             UndirectedEdge[29, 131] -> 
             RGBColor[
              0.6674759176093004, 0.7349616109657356, 0.9565036214432021], 
             UndirectedEdge[12, 192] -> 
             RGBColor[
              0.22323813628778444`, 0.35196781372677044`, 0.9360244536591377],
              UndirectedEdge[69, 76] -> 
             RGBColor[
              0.3239197878245973, 0.45498477235691487`, 0.9418608603425296], 
             UndirectedEdge[176, 180] -> 
             RGBColor[
              0.6075733820080276, 0.6866276313530766, 0.9651754118252278], 
             UndirectedEdge[101, 116] -> 
             RGBColor[
              0.7525277526567137, 0.803821204528361, 0.8919785464211123], 
             UndirectedEdge[125, 293] -> 
             RGBColor[
              0.6788534758190397, 0.7467227563753591, 0.9704741903275822], 
             UndirectedEdge[30, 300] -> 
             RGBColor[
              0.6075933068955475, 0.6856586446755351, 0.965630703990115], 
             UndirectedEdge[155, 290] -> 
             RGBColor[
              0.6717051975988779, 0.7407542615018926, 0.9699160563753733], 
             UndirectedEdge[217, 246] -> 
             RGBColor[
              0.5703888033983096, 0.6601251128931337, 0.9603407431063886], 
             UndirectedEdge[42, 82] -> 
             RGBColor[
              0.33201925503955265`, 0.461539349234191, 0.9423938224442114], 
             UndirectedEdge[122, 138] -> 
             RGBColor[
              0.633441608152591, 0.7126812014410419, 0.9647059618888021], 
             UndirectedEdge[58, 160] -> 
             RGBColor[
              0.6041550484608089, 0.6895193110720811, 0.9619804449891491], 
             UndirectedEdge[158, 225] -> 
             RGBColor[
              0.5459984326117601, 0.6390622076535457, 0.958760026908102], 
             UndirectedEdge[197, 204] -> 
             RGBColor[
              0.5923983423932297, 0.6743656602634511, 0.9638024913810516], 
             UndirectedEdge[40, 182] -> 
             RGBColor[
              0.41017261172465885`, 0.529004721165164, 0.9475468861631546], 
             UndirectedEdge[1, 149] -> 
             RGBColor[
              0.6715794814484366, 0.7433622621914031, 0.9679004245098557], 
             UndirectedEdge[32, 156] -> 
             RGBColor[
              0.7249001104135692, 0.7847218913364953, 0.9734645129526621], 
             UndirectedEdge[258, 286] -> 
             RGBColor[
              0.4751784504530027, 0.5828220815476494, 0.9523762849993831], 
             UndirectedEdge[101, 197] -> 
             RGBColor[
              0.433292008363168, 0.5480189954058443, 0.9492992613510246], 
             UndirectedEdge[53, 271] -> 
             RGBColor[
              0.48421580061639574`, 0.5892407769905035, 0.9533414486979752], 
             UndirectedEdge[22, 70] -> 
             RGBColor[
              0.2698182983253723, 0.40092651738112606`, 0.9386771249780038], 
             UndirectedEdge[76, 258] -> 
             RGBColor[
              0.35784919882038235`, 0.4843727228196822, 0.944022812408581], 
             UndirectedEdge[232, 297] -> 
             RGBColor[
              0.40589806691119096`, 0.525990237353611, 0.9470844437953815], 
             UndirectedEdge[178, 261] -> 
             RGBColor[
              0.3680952046679429, 0.488868086850194, 0.9449441396558339], 
             UndirectedEdge[155, 227] -> 
             RGBColor[
              0.5944496610444325, 0.6797463784154305, 0.9623898351993097], 
             UndirectedEdge[178, 182] -> 
             RGBColor[
              0.3039758732055815, 0.43378221607076195`, 0.940733880181221], 
             UndirectedEdge[5, 51] -> 
             RGBColor[
              0.5761917756252768, 0.6618751584294367, 0.9620971453549867], 
             UndirectedEdge[110, 295] -> 
             RGBColor[
              0.5313007771745415, 0.6303729315943698, 0.9562450898795052], 
             UndirectedEdge[186, 286] -> 
             RGBColor[
              0.5064078410723672, 0.6098714100673313, 0.9543661941545831], 
             UndirectedEdge[34, 270] -> 
             RGBColor[
              0.3313726755951839, 0.4614400891507659, 0.9423357517609415], 
             UndirectedEdge[4, 8] -> 
             RGBColor[
              0.4328628490755401, 0.5468709679698609, 0.9494864128069125], 
             UndirectedEdge[69, 166] -> 
             RGBColor[
              0.47176123864521685`, 0.5782053089446089, 0.9526163650232794], 
             UndirectedEdge[25, 176] -> 
             RGBColor[
              0.7251461707674907, 0.7847367615556805, 0.9736966917868229], 
             UndirectedEdge[32, 149] -> 
             RGBColor[
              0.6362217062095716, 0.7153309199173664, 0.9646563236717207], 
             UndirectedEdge[16, 153] -> 
             RGBColor[
              0.6449488738136709, 0.7196475300221423, 0.9672590373712775], 
             UndirectedEdge[169, 299] -> 
             RGBColor[
              0.6705563773739281, 0.740043627965118, 0.9697119218905337], 
             UndirectedEdge[187, 229] -> 
             RGBColor[
              0.8004230311468398, 0.8445180769439868, 0.9806090625360313], 
             UndirectedEdge[15, 82] -> 
             RGBColor[
              0.35781108644391163`, 0.4838789372615077, 0.9440372551344761], 
             UndirectedEdge[44, 280] -> 
             RGBColor[
              0.8861677296246213, 0.9120701094931908, 0.9890046632145093], 
             UndirectedEdge[186, 265] -> 
             RGBColor[
              0.3958635075819636, 0.5172988064142507, 0.9464450505481355], 
             UndirectedEdge[117, 265] -> 
             RGBColor[
              0.3485734953424109, 0.47633857467747587`, 0.9434317727851471], 
             UndirectedEdge[106, 162] -> 
             RGBColor[
              0.6214171415591421, 0.6924053570739821, 0.947481755102767], 
             UndirectedEdge[9, 146] -> 
             RGBColor[
              0.47579509784670393`, 0.577877284369259, 0.9535193975964221], 
             UndirectedEdge[130, 294] -> 
             RGBColor[
              0.8227414557562426, 0.8623227627159262, 0.9827355369824884], 
             UndirectedEdge[13, 53] -> 
             RGBColor[
              0.6595174503343461, 0.7336298261444426, 0.9669097910144568], 
             UndirectedEdge[34, 57] -> 
             RGBColor[
              0.36764348396779556`, 0.4928560403392865, 0.9446468955974279], 
             UndirectedEdge[25, 144] -> 
             RGBColor[
              0.43946349502167203`, 0.5494520039268656, 0.9503218465084746], 
             UndirectedEdge[206, 283] -> 
             RGBColor[
              0.46226783256137255`, 0.5743288772586844, 0.9508105636035482], 
             UndirectedEdge[107, 273] -> 
             RGBColor[
              0.5470050420451777, 0.6430954418406933, 0.9574888250595244], 
             UndirectedEdge[64, 85] -> 
             RGBColor[
              0.38575024380749967`, 0.5085392056402271, 0.9458006423232347], 
             UndirectedEdge[175, 224] -> 
             RGBColor[
              0.5035285895624857, 0.6071288468430129, 0.9542514474232731], 
             UndirectedEdge[68, 163] -> 
             RGBColor[
              0.22259339797812214`, 0.35129015288454546`, 0.9359877367662073],
              UndirectedEdge[7, 237] -> 
             RGBColor[
              0.5161843340213184, 0.6170305426843614, 0.9553507618497202], 
             UndirectedEdge[76, 126] -> 
             RGBColor[
              0.4714808535537066, 0.5786122361120727, 0.9524189622534005], 
             UndirectedEdge[30, 236] -> 
             RGBColor[
              0.4451861984686787, 0.5570253588064719, 0.950415178228432], 
             UndirectedEdge[7, 269] -> 
             RGBColor[
              0.4396870549015473, 0.5549266053317792, 0.9493286158186454], 
             UndirectedEdge[237, 256] -> 
             RGBColor[
              0.404248562586221, 0.5091015360483804, 0.9486201937496441], 
             UndirectedEdge[106, 290] -> 
             RGBColor[
              0.5927882995830427, 0.6701606531698439, 0.9649695499202056], 
             UndirectedEdge[180, 288] -> 
             RGBColor[
              0.6633516419608856, 0.25017333675020553`, 0.42410127670925457`],
              UndirectedEdge[201, 237] -> 
             RGBColor[
              0.5736700942087061, 0.6647702518786853, 0.9595805577203568], 
             UndirectedEdge[10, 73] -> 
             RGBColor[
              0.5595191014954495, 0.642736426004581, 0.9619320830978757], 
             UndirectedEdge[18, 175] -> 
             RGBColor[
              0.4348425948915545, 0.5510605326959255, 0.9489287635236492], 
             UndirectedEdge[57, 295] -> 
             RGBColor[
              0.44470295976410174`, 0.5585129723733241, 0.9498577060569807], 
             UndirectedEdge[71, 161] -> 
             RGBColor[
              0.34863927289179497`, 0.47580861386226425`, 0.943457454602157], 
             UndirectedEdge[218, 220] -> 
             RGBColor[
              0.39563730552132226`, 0.5164044706905245, 0.9466236101566113], 
             UndirectedEdge[192, 248] -> 
             RGBColor[
              0.478265821332627, 0.5776682665935684, 0.9541043175525612], 
             UndirectedEdge[23, 24] -> 
             RGBColor[
              0.3391221647588891, 0.4549006639743559, 0.9436141178603679], 
             UndirectedEdge[39, 195] -> 
             RGBColor[
              0.7388988924247011, 0.7926057805084161, 0.8845973658133583], 
             UndirectedEdge[79, 232] -> 
             RGBColor[
              0.5058174984041458, 0.6080799111505525, 0.9546822938684523], 
             UndirectedEdge[12, 154] -> 
             RGBColor[
              0.2887143626196149, 0.4125446669643838, 0.9400550376136223], 
             UndirectedEdge[106, 155] -> 
             RGBColor[
              0.36343799556893397`, 0.48697369991282835`, 0.9444609340983483],
              UndirectedEdge[95, 103] -> 
             RGBColor[
              0.7598141920052874, 0.811756709825232, 0.9616257748463984], 
             UndirectedEdge[3, 228] -> 
             RGBColor[
              0.64627232547865, 0.7189656605622381, 0.9681849767290639], 
             UndirectedEdge[81, 293] -> 
             RGBColor[
              0.40830775495639116`, 0.5280773880239207, 0.9472379869868182], 
             UndirectedEdge[95, 145] -> 
             RGBColor[
              0.8487764645741314, 0.8824166912558327, 0.9696982520979317], 
             UndirectedEdge[39, 153] -> 
             RGBColor[
              0.6643843213882128, 0.7355437247624173, 0.9687565674569436], 
             UndirectedEdge[39, 90] -> 
             RGBColor[
              0.7364621555453438, 0.7915981271875203, 0.9249804019772085], 
             UndirectedEdge[120, 141] -> 
             RGBColor[
              0.6963601533563506, 0.7581071842141875, 0.9310160520156234], 
             UndirectedEdge[102, 172] -> 
             RGBColor[
              0.5708222671022314, 0.6581354370664183, 0.961369394036115], 
             UndirectedEdge[155, 194] -> 
             RGBColor[
              0.3778869340707651, 0.5017284019677066, 0.9452995991800618], 
             UndirectedEdge[53, 251] -> 
             RGBColor[
              0.5128546109224927, 0.6140462750491854, 0.9551662883663741], 
             UndirectedEdge[128, 243] -> 
             RGBColor[
              0.2900307535026576, 0.41955882250746174`, 0.939923842283073], 
             UndirectedEdge[72, 87] -> 
             RGBColor[
              0.49015063683544174`, 0.5954589824952674, 0.953421826046488], 
             UndirectedEdge[76, 90] -> 
             RGBColor[
              0.6603361377553594, 0.7265994098775368, 0.9198705988869175], 
             UndirectedEdge[3, 106] -> 
             RGBColor[
              0.5892976703521391, 0.6673773201717276, 0.9646366105880404], 
             UndirectedEdge[104, 243] -> 
             RGBColor[
              0.5878076778999344, 0.6609302992277688, 0.965291187208239], 
             UndirectedEdge[34, 217] -> 
             RGBColor[
              0.5285575006441602, 0.6238929409498989, 0.9576752894848628], 
             UndirectedEdge[31, 37] -> 
             RGBColor[
              0.3879530525062499, 0.5104471678187001, 0.9459410033456518], 
             UndirectedEdge[64, 249] -> 
             RGBColor[
              0.28371666481036506`, 0.4145269857246255, 0.939505509415373], 
             UndirectedEdge[89, 188] -> 
             RGBColor[
              0.41865353161517393`, 0.5338649219170613, 0.9485646037580424], 
             UndirectedEdge[179, 269] -> 
             RGBColor[
              0.45018061423413647`, 0.5640155990040404, 0.9499972561402277], 
             UndirectedEdge[213, 249] -> 
             RGBColor[
              0.25466629368053706`, 0.3850007998068228, 0.9378142407288625], 
             UndirectedEdge[44, 252] -> 
             RGBColor[
              0.9416821231767181, 0.9551504682694465, 0.9532041733768546], 
             UndirectedEdge[149, 198] -> 
             RGBColor[
              0.7052085303585742, 0.7696335307902404, 0.9712522538238885], 
             UndirectedEdge[158, 214] -> 
             RGBColor[
              0.4410002538959469, 0.5549535991516589, 0.9497191076840656], 
             UndirectedEdge[202, 216] -> 
             RGBColor[
              0.6253970198995177, 0.6883740667095587, 0.7599255093844057], 
             UndirectedEdge[78, 209] -> 
             RGBColor[
              0.6652095316678501, 0.736281325599522, 0.9687436579656321], 
             UndirectedEdge[77, 265] -> 
             RGBColor[
              0.5017130529795233, 0.6033423744942868, 0.9548217017866488], 
             UndirectedEdge[44, 204] -> 
             RGBColor[
              0.8678926120133945, 0.8974980267748509, 0.9872615661823604], 
             UndirectedEdge[54, 102] -> 
             RGBColor[
              0.46049357496109633`, 0.5705749976512541, 0.951310102706937], 
             UndirectedEdge[2, 253] -> 
             RGBColor[
              0.4320165209613773, 0.5486127295002119, 0.9487486885918173], 
             UndirectedEdge[40, 86] -> 
             RGBColor[
              0.3566307454257408, 0.4757749031594033, 0.9443862242401315], 
             UndirectedEdge[75, 165] -> 
             RGBColor[
              0.6576538309695674, 0.7253441791896582, 0.9396774666770145], 
             UndirectedEdge[73, 100] -> 
             RGBColor[
              0.34613198632700826`, 0.47133081696503376`, 0.9433821305506196],
              UndirectedEdge[50, 206] -> 
             RGBColor[
              0.45035816741383117`, 0.564152831610233, 0.9500131438770473], 
             UndirectedEdge[32, 277] -> 
             RGBColor[
              0.5984301961875962, 0.6848716180950309, 0.961529763647377], 
             UndirectedEdge[156, 251] -> 
             RGBColor[
              0.6188658604255531, 0.6972872826162466, 0.9654904566421133], 
             UndirectedEdge[31, 44] -> 
             RGBColor[
              0.6500760807852408, 0.7219980371385061, 0.9685480744724255], 
             UndirectedEdge[80, 92] -> 
             RGBColor[
              0.6921118275919369, 0.7547774964796581, 0.9358533770530761], 
             UndirectedEdge[11, 149] -> 
             RGBColor[
              0.4929582588772633, 0.5956502516513577, 0.9543100558268802], 
             UndirectedEdge[103, 145] -> 
             RGBColor[
              0.6554678323084344, 0.7296137414686583, 0.9670890165739268], 
             UndirectedEdge[150, 274] -> 
             RGBColor[
              0.5085136376096837, 0.5905279534467786, 0.9588150791869758], 
             UndirectedEdge[13, 156] -> 
             RGBColor[
              0.7655286998374065, 0.8168708337115038, 0.9772339592901961], 
             UndirectedEdge[84, 278] -> 
             RGBColor[
              0.8339154809215045, 0.870461944861004, 0.9507414092850872], 
             UndirectedEdge[150, 293] -> 
             RGBColor[
              0.6403506058556638, 0.7160216129991265, 0.9668017522185577], 
             UndirectedEdge[52, 137] -> 
             RGBColor[
              0.49857390349550096`, 0.6026441159610542, 0.9539891294653031], 
             UndirectedEdge[41, 152] -> 
             RGBColor[
              0.600717218269716, 0.6860827093863481, 0.9621512177691308], 
             UndirectedEdge[177, 279] -> 
             RGBColor[
              0.7641288567776641, 0.8132259000722799, 0.89232315212405], 
             UndirectedEdge[108, 279] -> 
             RGBColor[
              0.9276414901098675, 0.94291862921536, 0.9074393322920817], 
             UndirectedEdge[161, 279] -> 
             RGBColor[
              0.6458246336906683, 0.7124964310668207, 0.8841635454600518], 
             UndirectedEdge[89, 260] -> 
             RGBColor[
              0.34711671551540024`, 0.4742029710903277, 0.9433709426781993], 
             UndirectedEdge[63, 161] -> 
             RGBColor[
              0.5043347730820152, 0.6028168818246569, 0.9559453522180581], 
             UndirectedEdge[110, 148] -> 
             RGBColor[
              0.6514655050944842, 0.7265285092928208, 0.9666617854762389], 
             UndirectedEdge[200, 228] -> 
             RGBColor[
              0.5542310145174763, 0.6464634450463617, 0.9591700737732689], 
             UndirectedEdge[67, 118] -> 
             RGBColor[
              0.4809870501913297, 0.5877091212710593, 0.9527862128591275], 
             UndirectedEdge[140, 203] -> 
             RGBColor[
              0.5949466188789139, 0.6678393035740955, 0.9646375399687057], 
             UndirectedEdge[144, 231] -> 
             RGBColor[
              0.2816156011304325, 0.413326230621444, 0.9393489639202065], 
             UndirectedEdge[101, 149] -> 
             RGBColor[
              0.5863469705955504, 0.6748403627146693, 0.9607300017870086], 
             UndirectedEdge[131, 284] -> 
             RGBColor[
              0.4308013341618536, 0.5468916616431128, 0.9488559759350792], 
             UndirectedEdge[157, 275] -> 
             RGBColor[
              0.3925557796148412, 0.5143079924460676, 0.9462690512159431], 
             UndirectedEdge[113, 144] -> 
             RGBColor[
              0.4576000998677287, 0.5641761167856317, 0.9517496264785288], 
             UndirectedEdge[48, 73] -> 
             RGBColor[
              0.5109666256460694, 0.6046322864151932, 0.9571391532742293], 
             UndirectedEdge[35, 183] -> 
             RGBColor[
              0.5572635713916473, 0.6514506975503668, 0.9582889761451245], 
             UndirectedEdge[93, 107] -> 
             RGBColor[
              0.4965709205017584, 0.5994119406524376, 0.9542752074319203], 
             UndirectedEdge[23, 226] -> 
             RGBColor[
              0.46066896902867754`, 0.5520451672166494, 0.9542306210735184], 
             UndirectedEdge[200, 211] -> 
             RGBColor[
              0.7843916112720266, 0.8318056228077024, 0.9790612456393554], 
             UndirectedEdge[87, 227] -> 
             RGBColor[
              0.6645038382860713, 0.7369171894473744, 0.9678225084238257], 
             UndirectedEdge[223, 278] -> 
             RGBColor[
              0.8025539754932927, 0.8458108494178245, 0.9477189973129987], 
             UndirectedEdge[182, 229] -> 
             RGBColor[
              0.611907974879434, 0.6896119375360276, 0.9658061277183352], 
             UndirectedEdge[79, 221] -> 
             RGBColor[
              0.6409993740401791, 0.7190906817076745, 0.9651137756482537], 
             UndirectedEdge[115, 228] -> 
             RGBColor[
              0.45971399421584286`, 0.5707663155210083, 0.9510209977420099], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.31425783946044195`, 0.4346691427514325, 0.9416826453707101], 
             UndirectedEdge[9, 47] -> 
             RGBColor[
              0.38645088688432117`, 0.5057485093512715, 0.9462090751228422], 
             UndirectedEdge[18, 224] -> 
             RGBColor[
              0.5107368496133495, 0.6133722794013868, 0.9547107513797], 
             UndirectedEdge[194, 291] -> 
             RGBColor[
              0.6386450545763773, 0.7092326137722957, 0.9436163412025356], 
             UndirectedEdge[5, 198] -> 
             RGBColor[
              0.7742882840739769, 0.8235991594182868, 0.9781374780872382], 
             UndirectedEdge[49, 172] -> 
             RGBColor[
              0.5398509138406705, 0.6310716639019136, 0.9594046390752471], 
             UndirectedEdge[162, 228] -> 
             RGBColor[
              0.678391796685653, 0.7439936974644927, 0.9510301212437904], 
             UndirectedEdge[100, 161] -> 
             RGBColor[
              0.3586032728225724, 0.48443892979710557`, 0.9440923518669269], 
             UndirectedEdge[174, 235] -> 
             RGBColor[
              0.38833168459113154`, 0.5006121544303085, 0.946963670799349], 
             UndirectedEdge[14, 67] -> 
             RGBColor[
              0.4581496259804072, 0.5679284922618741, 0.9513310323827487], 
             UndirectedEdge[190, 199] -> 
             RGBColor[
              0.6315317642735747, 0.6946316653360596, 0.7412336231835503], 
             UndirectedEdge[160, 288] -> 
             RGBColor[
              0.7401160943147422, 0.3142663398328341, 0.4296548018274272], 
             UndirectedEdge[33, 275] -> 
             RGBColor[
              0.43493374495505255`, 0.5487123338148338, 0.9496051998831265], 
             UndirectedEdge[109, 218] -> 
             RGBColor[
              0.2934713809346712, 0.4254648550509261, 0.9400359432440946], 
             UndirectedEdge[231, 264] -> 
             RGBColor[
              0.384416250659907, 0.5031477138193481, 0.9461352837312613], 
             UndirectedEdge[221, 230] -> 
             RGBColor[
              0.5414898259714136, 0.6373560283314259, 0.9575420429845265], 
             UndirectedEdge[45, 236] -> 
             RGBColor[
              0.6686244392293872, 0.7398471991667813, 0.9684308262624819], 
             UndirectedEdge[279, 280] -> 
             RGBColor[
              0.9299433563050062, 0.9447540748368702, 0.9076588863446742], 
             UndirectedEdge[71, 252] -> 
             RGBColor[
              0.6882723890582296, 0.7511466164085695, 0.9311523056491245], 
             UndirectedEdge[230, 296] -> 
             RGBColor[
              0.6192678525310046, 0.6981181036436155, 0.9652938875140611], 
             UndirectedEdge[27, 154] -> 
             RGBColor[
              0.46199848898701007`, 0.5726054586017537, 0.9512051277411894], 
             UndirectedEdge[5, 101] -> 
             RGBColor[
              0.6554267243109531, 0.7288059913427155, 0.9676152260503583], 
             UndirectedEdge[68, 143] -> 
             RGBColor[
              0.39539245684208757`, 0.5005834220352667, 0.9480439213780288], 
             UndirectedEdge[58, 221] -> 
             RGBColor[
              0.6435936706276681, 0.7211968485491276, 0.9653180081788424], 
             UndirectedEdge[85, 249] -> 
             RGBColor[
              0.3498228926287642, 0.4717848776653039, 0.9437177397965193], 
             UndirectedEdge[26, 54] -> 
             RGBColor[
              0.49397808671904647`, 0.5995775987554947, 0.9534437061869625], 
             UndirectedEdge[269, 282] -> 
             RGBColor[
              0.4321514098217223, 0.5483996083161692, 0.9488484511776683], 
             UndirectedEdge[24, 210] -> 
             RGBColor[
              0.7004880108680305, 0.7644147552615551, 0.972104720388187], 
             UndirectedEdge[144, 288] -> 
             RGBColor[
              0.6410008288805871, 0.22955791239930223`, 0.42272310098866517`],
              UndirectedEdge[182, 199] -> 
             RGBColor[
              0.3055821856028797, 0.43547055224641074`, 0.9408253572959209], 
             UndirectedEdge[35, 224] -> 
             RGBColor[
              0.597341103298755, 0.6839874434247943, 0.9614440262656887], 
             UndirectedEdge[161, 280] -> 
             RGBColor[
              0.5865165273955533, 0.6674272880962827, 0.9640278205582258], 
             UndirectedEdge[27, 42] -> 
             RGBColor[
              0.44318703638091034`, 0.5563119238454495, 0.9500064786154432], 
             UndirectedEdge[13, 273] -> 
             RGBColor[
              0.5746027871618632, 0.6646653577743098, 0.9602324355996439], 
             UndirectedEdge[167, 202] -> 
             RGBColor[
              0.6180594191553226, 0.6806617830966522, 0.7595076438770314], 
             UndirectedEdge[117, 207] -> 
             RGBColor[
              0.28233099612947854`, 0.4104514209447153, 0.939522497147989], 
             UndirectedEdge[33, 248] -> 
             RGBColor[
              0.6161465114938964, 0.6985310787613184, 0.9634190782755363], 
             UndirectedEdge[23, 210] -> 
             RGBColor[
              0.5402928461091414, 0.6149080912871991, 0.9619916025278192], 
             UndirectedEdge[54, 111] -> 
             RGBColor[
              0.6349896988707061, 0.7134072193636399, 0.9651907385566694], 
             UndirectedEdge[30, 267] -> 
             RGBColor[
              0.5981857050286254, 0.6781572783094013, 0.9647333985257827], 
             UndirectedEdge[170, 199] -> 
             RGBColor[
              0.6125742207037115, 0.6835134037083491, 0.9492852713158337], 
             UndirectedEdge[169, 200] -> 
             RGBColor[
              0.5791597918104766, 0.6680554989807805, 0.9607585134187266], 
             UndirectedEdge[137, 278] -> 
             RGBColor[
              0.6916154226700287, 0.7545862692592353, 0.9393059270177426], 
             UndirectedEdge[92, 150] -> 
             RGBColor[
              0.9035618759039883, 0.9248852708781654, 0.9541049871134583], 
             UndirectedEdge[68, 185] -> 
             RGBColor[
              0.264084877745962, 0.39115612709049546`, 0.9384877087250353], 
             UndirectedEdge[26, 102] -> 
             RGBColor[
              0.4015996536431222, 0.5222671678253424, 0.9468105527028777], 
             UndirectedEdge[270, 271] -> 
             RGBColor[
              0.33487382100545227`, 0.4644726053324554, 0.9425588416505425], 
             UndirectedEdge[169, 202] -> 
             RGBColor[
              0.7211345676972583, 0.7760949934305829, 0.7658501475759374], 
             UndirectedEdge[17, 97] -> 
             RGBColor[
              0.3865215144235669, 0.5070891405299873, 0.9460978219107541], 
             UndirectedEdge[46, 158] -> 
             RGBColor[
              0.4445666716554415, 0.5578489777541058, 0.9499998691543119], 
             UndirectedEdge[98, 285] -> 
             RGBColor[
              0.715404020671579, 0.7763472715909384, 0.9734826552915148], 
             UndirectedEdge[77, 168] -> 
             RGBColor[
              0.5348424593456589, 0.6320374011562536, 0.9569326782651152], 
             UndirectedEdge[242, 268] -> 
             RGBColor[
              0.5514663070973747, 0.6456200416170822, 0.9583373477335189], 
             UndirectedEdge[115, 134] -> 
             RGBColor[
              0.47002933532669444`, 0.5797009455271087, 0.9516782821560954], 
             UndirectedEdge[99, 284] -> 
             RGBColor[
              0.43313512236902835`, 0.5489130716885615, 0.9490046828559524], 
             UndirectedEdge[204, 283] -> 
             RGBColor[
              0.646270488224087, 0.7208874975841868, 0.9672737232707286], 
             UndirectedEdge[77, 167] -> 
             RGBColor[
              0.4482145171900416, 0.5508499343335227, 0.9516381760134518], 
             UndirectedEdge[227, 290] -> 
             RGBColor[
              0.8237999650585414, 0.8629333316724459, 0.982898451021167], 
             UndirectedEdge[60, 145] -> 
             RGBColor[
              0.7717661227600068, 0.8216288278306774, 0.9778860926183992], 
             UndirectedEdge[32, 125] -> 
             RGBColor[
              0.7615808020389455, 0.8139700791677206, 0.9769631500651306], 
             UndirectedEdge[15, 60] -> 
             RGBColor[
              0.6054809927956326, 0.6870689813019863, 0.9640375072157329], 
             UndirectedEdge[30, 260] -> 
             RGBColor[
              0.3608578591784551, 0.4869786732021783, 0.9442145215861435], 
             UndirectedEdge[42, 80] -> 
             RGBColor[
              0.3839550658557463, 0.5069843127266858, 0.9456862551715626], 
             UndirectedEdge[97, 130] -> 
             RGBColor[
              0.5985868791527834, 0.6838452966621067, 0.9623307687734232], 
             UndirectedEdge[65, 211] -> 
             RGBColor[
              0.7873354429168459, 0.8341053664625844, 0.9793546592660402], 
             UndirectedEdge[1, 256] -> 
             RGBColor[
              0.43818497054678807`, 0.5359789483340285, 0.9517523993489916], 
             UndirectedEdge[5, 128] -> 
             RGBColor[
              0.5659905047715256, 0.6530393303466988, 0.9614471293968152], 
             UndirectedEdge[125, 256] -> 
             RGBColor[
              0.5487861793915124, 0.6230891341078791, 0.9625882974880664], 
             UndirectedEdge[39, 239] -> 
             RGBColor[
              0.3676840074877692, 0.4862917398237363, 0.9451158967013976], 
             UndirectedEdge[156, 269] -> 
             RGBColor[
              0.6498241985720961, 0.7237718839723015, 0.9675542621603748], 
             UndirectedEdge[78, 170] -> 
             RGBColor[
              0.8936188324652724, 0.9174962642867928, 0.9718547004580944], 
             UndirectedEdge[23, 155] -> 
             RGBColor[
              0.3106409467923845, 0.4314806541224385, 0.941454220276758], 
             UndirectedEdge[127, 251] -> 
             RGBColor[
              0.6972468770462248, 0.7572404927195053, 0.873369493839752], 
             UndirectedEdge[241, 290] -> 
             RGBColor[
              0.5854366497630175, 0.6624336030874767, 0.9645508843387464], 
             UndirectedEdge[85, 234] -> 
             RGBColor[
              0.37414763012234564`, 0.49735171904849285`, 0.9451029976115545],
              UndirectedEdge[270, 289] -> 
             RGBColor[
              0.6586281625472701, 0.7218553081598449, 0.7533393392366989], 
             UndirectedEdge[69, 258] -> 
             RGBColor[
              0.3461640860421993, 0.4742516654420651, 0.9432782473550947], 
             UndirectedEdge[52, 289] -> 
             RGBColor[
              0.7901618841092938, 0.8321659336808971, 0.762720014976722], 
             UndirectedEdge[47, 170] -> 
             RGBColor[
              0.7228885102472172, 0.7816944628099687, 0.9564574036788285], 
             UndirectedEdge[72, 241] -> 
             RGBColor[
              0.3338279117579426, 0.45996751304890765`, 0.942623980785345], 
             UndirectedEdge[115, 210] -> 
             RGBColor[
              0.7113081364219238, 0.7731990206273072, 0.9729565203072152], 
             UndirectedEdge[166, 239] -> 
             RGBColor[
              0.43939944051840435`, 0.5445135591014466, 0.9507615982918564], 
             UndirectedEdge[180, 215] -> 
             RGBColor[
              0.38414408163093994`, 0.5071480286909493, 0.9456982990896178], 
             UndirectedEdge[51, 254] -> 
             RGBColor[
              0.6018798483249169, 0.6821560411986443, 0.9646009248991593], 
             UndirectedEdge[109, 227] -> 
             RGBColor[
              0.5106262576635121, 0.6039957218542691, 0.9571639105221247], 
             UndirectedEdge[203, 255] -> 
             RGBColor[
              0.6692842100049209, 0.7373889052363258, 0.9691852551671442], 
             UndirectedEdge[257, 272] -> 
             RGBColor[
              0.417718108343846, 0.5362281631500203, 0.947837606383418], 
             UndirectedEdge[32, 128] -> 
             RGBColor[
              0.4763108628019074, 0.5825713329211195, 0.9527887325496655], 
             UndirectedEdge[39, 76] -> 
             RGBColor[
              0.41173091839276477`, 0.5301045470445156, 0.947715228486307], 
             UndirectedEdge[144, 221] -> 
             RGBColor[
              0.4764760069598531, 0.5791599158252508, 0.9534684174138315], 
             UndirectedEdge[165, 262] -> 
             RGBColor[
              0.6842840718099097, 0.7484099553307401, 0.9413743220751637], 
             UndirectedEdge[101, 226] -> 
             RGBColor[
              0.6291416423923344, 0.708271885573869, 0.9649953747327666], 
             UndirectedEdge[56, 191] -> 
             RGBColor[
              0.6589481564414865, 0.7311338017736762, 0.9683246985975984], 
             UndirectedEdge[63, 71] -> 
             RGBColor[
              0.5505762411925949, 0.643455851360688, 0.9588703271466117], 
             UndirectedEdge[137, 289] -> 
             RGBColor[
              0.7021963998369727, 0.7595919254969077, 0.7561154687909193], 
             UndirectedEdge[148, 295] -> 
             RGBColor[
              0.6135570860591485, 0.695752746965119, 0.9636774958666628], 
             UndirectedEdge[10, 119] -> 
             RGBColor[
              0.9161090771485779, 0.9334574275698317, 0.8948074554124998], 
             UndirectedEdge[115, 231] -> 
             RGBColor[
              0.39791214812233433`, 0.5141042913625987, 0.947197730216605], 
             UndirectedEdge[33, 171] -> 
             RGBColor[
              0.4137463552726498, 0.5281454954661702, 0.9483362742931647], 
             UndirectedEdge[173, 234] -> 
             RGBColor[
              0.6217729320420398, 0.694489732259541, 0.9573056132293023], 
             UndirectedEdge[69, 173] -> 
             RGBColor[
              0.6296708752558506, 0.7024684194911499, 0.9577671996144601], 
             UndirectedEdge[4, 263] -> 
             RGBColor[
              0.588634886075693, 0.6769193440724963, 0.9607586409539648], 
             UndirectedEdge[134, 160] -> 
             RGBColor[
              0.5024056864860253, 0.6059855259362519, 0.9542270671178399], 
             UndirectedEdge[7, 205] -> 
             RGBColor[
              0.45446250252708476`, 0.5669219793405206, 0.9504917931799757], 
             UndirectedEdge[23, 106] -> 
             RGBColor[
              0.23172404877654942`, 0.3608870457903898, 0.9365077138215903], 
             UndirectedEdge[45, 96] -> 
             RGBColor[
              0.5495197541626813, 0.6396789907608602, 0.960014251618831], 
             UndirectedEdge[65, 210] -> 
             RGBColor[
              0.8087689883683764, 0.8511958938075425, 0.981399009965159], 
             UndirectedEdge[138, 211] -> 
             RGBColor[
              0.721608650492574, 0.7818716324055452, 0.9734103910193728], 
             UndirectedEdge[72, 210] -> 
             RGBColor[
              0.6497483589105598, 0.7217156086280841, 0.9685265350730331], 
             UndirectedEdge[37, 41] -> 
             RGBColor[
              0.5309793575567707, 0.6274064910852941, 0.9572303492615941], 
             UndirectedEdge[52, 88] -> 
             RGBColor[
              0.4143688343241193, 0.5235571259906351, 0.9488489407478868], 
             UndirectedEdge[157, 285] -> 
             RGBColor[
              0.4813222743357568, 0.5897981314839493, 0.9523105990587477], 
             UndirectedEdge[135, 265] -> 
             RGBColor[
              0.35014467316688924`, 0.4776994499393453, 0.9435318868467849], 
             UndirectedEdge[17, 42] -> 
             RGBColor[
              0.3269030018614319, 0.45616184275479876`, 0.9421024593945357], 
             UndirectedEdge[242, 250] -> 
             RGBColor[
              0.4613545329335883, 0.562068222965465, 0.9527969430938585], 
             UndirectedEdge[81, 202] -> 
             RGBColor[
              0.6801947586998163, 0.740634988571629, 0.7632414991482721], 
             UndirectedEdge[229, 259] -> 
             RGBColor[
              0.6395824752029102, 0.7135821987553925, 0.9675695224073473], 
             UndirectedEdge[40, 81] -> 
             RGBColor[
              0.4225508086958184, 0.5397260932353128, 0.9483356139285471], 
             UndirectedEdge[100, 119] -> 
             RGBColor[
              0.7027219619801368, 0.7620518185302845, 0.8762575028652437], 
             UndirectedEdge[81, 269] -> 
             RGBColor[
              0.4159591693348239, 0.5343747034520883, 0.9478166959320791], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.46621365970616313`, 0.573748456191693, 0.9521666746696908], 
             UndirectedEdge[180, 233] -> 
             RGBColor[
              0.28556067483363656`, 0.4131577072357981, 0.9397316250024874], 
             UndirectedEdge[33, 184] -> 
             RGBColor[
              0.48459153831358814`, 0.5917234185487323, 0.9527693505652699], 
             UndirectedEdge[103, 168] -> 
             RGBColor[
              0.4909695546795377, 0.5966015766231483, 0.9533542878220256], 
             UndirectedEdge[49, 238] -> 
             RGBColor[
              0.6215761971026026, 0.6958286786999699, 0.9661540550536142], 
             UndirectedEdge[97, 120] -> 
             RGBColor[
              0.44491376530178106`, 0.559072413020957, 0.9497670132109421], 
             UndirectedEdge[117, 212] -> 
             RGBColor[
              0.31234333875468906`, 0.44199629593623985`, 0.9412316556612126],
              UndirectedEdge[270, 278] -> 
             RGBColor[
              0.648047185380326, 0.7168496519221724, 0.9365297974635224], 
             UndirectedEdge[26, 165] -> 
             RGBColor[
              0.7024097418249285, 0.7641094996750852, 0.94252927374062], 
             UndirectedEdge[65, 70] -> 
             RGBColor[
              0.49142480105464836`, 0.5879513570486985, 0.9554153757815306], 
             UndirectedEdge[56, 223] -> 
             RGBColor[
              0.5549700411130647, 0.6495887063478518, 0.9581084210401163], 
             UndirectedEdge[207, 212] -> 
             RGBColor[
              0.2467020810865596, 0.3766299074103089, 0.9373606906036323], 
             UndirectedEdge[171, 184] -> 
             RGBColor[
              0.35562987857534856`, 0.4802350728547774, 0.9439625154303631], 
             UndirectedEdge[32, 205] -> 
             RGBColor[
              0.5553213537394205, 0.649873917764381, 0.9581360776569636], 
             UndirectedEdge[23, 31] -> 
             RGBColor[
              0.28868947616556495`, 0.4124673935784814, 0.9400554919793402], 
             UndirectedEdge[235, 274] -> 
             RGBColor[
              0.3680322598998122, 0.4792761720218695, 0.945807648593486], 
             UndirectedEdge[178, 199] -> 
             RGBColor[
              0.26786610835354246`, 0.39887464194473965`, 0.9385659506471145],
              UndirectedEdge[117, 158] -> 
             RGBColor[
              0.3618031836015295, 0.4877974657040584, 0.9442747568224642], 
             UndirectedEdge[112, 190] -> 
             RGBColor[
              0.5918118402283994, 0.6528835067759405, 0.7389716322695394], 
             UndirectedEdge[64, 213] -> 
             RGBColor[
              0.2905936448592725, 0.421755127781746, 0.9398971432555779], 
             UndirectedEdge[127, 205] -> 
             RGBColor[
              0.7429806628183053, 0.7957204680843017, 0.8765964767193439], 
             UndirectedEdge[121, 263] -> 
             RGBColor[
              0.7575509149682249, 0.8108811064771427, 0.9764356514176793], 
             UndirectedEdge[14, 213] -> 
             RGBColor[
              0.3011364305142328, 0.4308867588202582, 0.9405689202348927], 
             UndirectedEdge[109, 111] -> 
             RGBColor[
              0.49590773826365986`, 0.592497502634214, 0.9556969060607314], 
             UndirectedEdge[55, 108] -> 
             RGBColor[
              0.8939568558821844, 0.9182809473407717, 0.9897475970303908], 
             UndirectedEdge[40, 162] -> 
             RGBColor[
              0.718483229279792, 0.7780309692625398, 0.9537747840293177], 
             UndirectedEdge[15, 225] -> 
             RGBColor[
              0.5641112983832994, 0.654750661605749, 0.9599141626984862], 
             UndirectedEdge[31, 59] -> 
             RGBColor[
              0.5298620693114657, 0.6274254560168289, 0.9567415368072363], 
             UndirectedEdge[210, 227] -> 
             RGBColor[
              0.8241015603611894, 0.8631738155801911, 0.9829272174503709], 
             UndirectedEdge[52, 93] -> 
             RGBColor[
              0.46899886110083955`, 0.5770277007236507, 0.9521046339160986], 
             UndirectedEdge[32, 293] -> 
             RGBColor[
              0.5328944917354503, 0.631581228327472, 0.9563941913503724], 
             UndirectedEdge[99, 209] -> 
             RGBColor[
              0.44359403259163815`, 0.5574040861758123, 0.9498280465809268], 
             UndirectedEdge[201, 299] -> 
             RGBColor[
              0.7108302141305975, 0.772875234180179, 0.9728449892200712], 
             UndirectedEdge[127, 148] -> 
             RGBColor[
              0.8623311250461084, 0.8912149882116225, 0.8869490703380389], 
             UndirectedEdge[24, 226] -> 
             RGBColor[
              0.6208641337875667, 0.7015518311910054, 0.9643437389338863], 
             UndirectedEdge[144, 264] -> 
             RGBColor[
              0.3911651361712358, 0.5102412203958107, 0.9465196227770503], 
             UndirectedEdge[148, 217] -> 
             RGBColor[
              0.7257817043604091, 0.7857054506823875, 0.9733027955411495], 
             UndirectedEdge[230, 288] -> 
             RGBColor[
              0.6843433748882941, 0.2683553207367523, 0.4254388513691284], 
             UndirectedEdge[1, 83] -> 
             RGBColor[
              0.48910191327398345`, 0.5894958834609387, 0.9546520439124387], 
             UndirectedEdge[15, 214] -> 
             RGBColor[
              0.4591131196674863, 0.5706420531038622, 0.9508732434744498], 
             UndirectedEdge[173, 249] -> 
             RGBColor[
              0.5974481945484583, 0.668922890876352, 0.9559203554142672], 
             UndirectedEdge[114, 204] -> 
             RGBColor[
              0.7924225125631073, 0.8378797297922489, 0.9799146835120414], 
             UndirectedEdge[77, 95] -> 
             RGBColor[
              0.8036870966714086, 0.8471925343583373, 0.965204165289488], 
             UndirectedEdge[52, 295] -> 
             RGBColor[
              0.539965872953514, 0.6374076467058558, 0.9569272379605176], 
             UndirectedEdge[7, 103] -> 
             RGBColor[
              0.4902048376351375, 0.595939217155085, 0.9533055607281691], 
             UndirectedEdge[29, 99] -> 
             RGBColor[
              0.6698097058164751, 0.7369830210111845, 0.9566523283640753], 
             UndirectedEdge[28, 144] -> 
             RGBColor[
              0.36300948181647946`, 0.4869578904196197, 0.944420618565292], 
             UndirectedEdge[75, 185] -> 
             RGBColor[
              0.3474075495911371, 0.47532869106985987`, 0.9433574797528813], 
             UndirectedEdge[227, 291] -> 
             RGBColor[
              0.8552077815500447, 0.8872505902200195, 0.9607065772217834], 
             UndirectedEdge[76, 192] -> 
             RGBColor[
              0.3012757676455654, 0.4315070232795787, 0.9405595066890684], 
             UndirectedEdge[59, 72] -> 
             RGBColor[
              0.5295551059473191, 0.6271595797792324, 0.9567219773731099], 
             UndirectedEdge[104, 254] -> 
             RGBColor[
              0.8894555018684425, 0.9146916898362135, 0.9893182538661539], 
             UndirectedEdge[32, 237] -> 
             RGBColor[
              0.6170431852336541, 0.6999824811082218, 0.9629950463267082], 
             UndirectedEdge[25, 232] -> 
             RGBColor[
              0.49239313970373044`, 0.5971814119970877, 0.9536254791765094], 
             UndirectedEdge[9, 141] -> 
             RGBColor[
              0.6326033786520056, 0.7004854570514988, 0.9270413590196389], 
             UndirectedEdge[22, 48] -> 
             RGBColor[
              0.508572149280985, 0.6021155399369192, 0.9570027913875481], 
             UndirectedEdge[25, 160] -> 
             RGBColor[
              0.5881363931729047, 0.6765146450771633, 0.9607193977666176], 
             UndirectedEdge[72, 106] -> 
             RGBColor[
              0.3411795615779679, 0.4676945631312748, 0.9430426463668042], 
             UndirectedEdge[4, 186] -> 
             RGBColor[
              0.4935077857800267, 0.5993985640401409, 0.9533506545475106], 
             UndirectedEdge[78, 182] -> 
             RGBColor[
              0.5866267973644407, 0.6694534128248544, 0.9633947864381815], 
             UndirectedEdge[106, 211] -> 
             RGBColor[
              0.5716563494341602, 0.6533106097326309, 0.9629539656502906], 
             UndirectedEdge[180, 245] -> 
             RGBColor[
              0.6745992915987349, 0.7356869644774582, 0.7542088939434617], 
             UndirectedEdge[136, 280] -> 
             RGBColor[
              0.7709085726861362, 0.8213682983927715, 0.9776919791436496], 
             UndirectedEdge[82, 140] -> 
             RGBColor[
              0.2783378034269831, 0.40988105741074105`, 0.9391622981900623], 
             UndirectedEdge[50, 219] -> 
             RGBColor[
              0.5404704578221765, 0.6372496117528046, 0.957148434388014], 
             UndirectedEdge[251, 278] -> 
             RGBColor[
              0.6880878720481007, 0.7515308822103708, 0.939081154611404], 
             UndirectedEdge[80, 150] -> 
             RGBColor[
              0.6190839978837319, 0.6976015460646351, 0.9654466627639091], 
             UndirectedEdge[26, 183] -> 
             RGBColor[
              0.4671759729355687, 0.5778184353646012, 0.9513337456105493], 
             UndirectedEdge[243, 256] -> 
             RGBColor[
              0.21654708600867328`, 0.3449350956463341, 0.9356434082442642], 
             UndirectedEdge[184, 248] -> 
             RGBColor[
              0.5580300347965953, 0.6506206561499256, 0.9590453194127347], 
             UndirectedEdge[4, 255] -> 
             RGBColor[
              0.47302587722501344`, 0.581658164300445, 0.9520455654458257], 
             UndirectedEdge[37, 280] -> 
             RGBColor[
              0.6240447013456305, 0.7005192401733848, 0.9663975920877356], 
             UndirectedEdge[188, 260] -> 
             RGBColor[
              0.4664752968438681, 0.5761595454872227, 0.9515797697358386], 
             UndirectedEdge[70, 266] -> 
             RGBColor[
              0.5184382101706142, 0.6090544375596043, 0.9581078199475492], 
             UndirectedEdge[103, 127] -> 
             RGBColor[
              0.778722997926358, 0.8247377058988662, 0.8794102442675373], 
             UndirectedEdge[37, 268] -> 
             RGBColor[
              0.40345997134111555`, 0.5238784815130579, 0.9469290905015795], 
             UndirectedEdge[186, 196] -> 
             RGBColor[
              0.5251032300111009, 0.625049169025469, 0.9558379636553065], 
             UndirectedEdge[139, 274] -> 
             RGBColor[
              0.48001131067143743`, 0.5681764469210748, 0.955996862199519], 
             UndirectedEdge[15, 255] -> 
             RGBColor[
              0.4067241530576084, 0.5267057516533407, 0.947137081274152], 
             UndirectedEdge[118, 195] -> 
             RGBColor[
              0.6881726421937595, 0.7496070652286382, 0.881106013451797], 
             UndirectedEdge[125, 128] -> 
             RGBColor[
              0.6222698468854968, 0.6977128609690068, 0.9668687315268754], 
             UndirectedEdge[61, 177] -> 
             RGBColor[
              0.6276845013866379, 0.7074879378533863, 0.9646078476892223], 
             UndirectedEdge[117, 276] -> 
             RGBColor[
              0.29714616879104794`, 0.42602310674822497`, 0.9403661993139815],
              UndirectedEdge[7, 154] -> 
             RGBColor[
              0.405901601441348, 0.5259932987859823, 0.9470846690125176], 
             UndirectedEdge[59, 198] -> 
             RGBColor[
              0.7074338262725813, 0.7713719488711382, 0.971474050524024], 
             UndirectedEdge[83, 197] -> 
             RGBColor[
              0.3212890640569515, 0.45114554267561024`, 0.9417503752221199], 
             UndirectedEdge[243, 283] -> 
             RGBColor[
              0.35075878050879666`, 0.47201887951561944`, 0.9438319248588214],
              UndirectedEdge[95, 225] -> 
             RGBColor[
              0.8347427880445267, 0.8714534764910136, 0.9682995063736242], 
             UndirectedEdge[21, 74] -> 
             RGBColor[
              0.8002699611062538, 0.8415273116896171, 0.8517104161112543], 
             UndirectedEdge[62, 225] -> 
             RGBColor[
              0.7822912811169306, 0.8300793810772586, 0.9788745795903544], 
             UndirectedEdge[236, 267] -> 
             RGBColor[
              0.7165946658844883, 0.7777228853720057, 0.9731056422379234], 
             UndirectedEdge[123, 300] -> 
             RGBColor[
              0.6152856161494782, 0.6923213363245851, 0.9661208511337334], 
             UndirectedEdge[111, 218] -> 
             RGBColor[
              0.5146710323754029, 0.6118963625625857, 0.9567772581056802], 
             UndirectedEdge[61, 161] -> 
             RGBColor[
              0.5093802782996422, 0.6067584688479271, 0.9564482410252242], 
             UndirectedEdge[58, 180] -> 
             RGBColor[
              0.48900836993002395`, 0.5933798064481383, 0.9536501573118903], 
             UndirectedEdge[188, 236] -> 
             RGBColor[
              0.5508036361340918, 0.6462062310915162, 0.9577804263781272], 
             UndirectedEdge[41, 268] -> 
             RGBColor[
              0.5569851762165163, 0.6499314241179145, 0.9588874170305507], 
             UndirectedEdge[65, 138] -> 
             RGBColor[
              0.6501524920941985, 0.7257358709836474, 0.9663715466280124], 
             UndirectedEdge[241, 291] -> 
             RGBColor[
              0.6168444662545207, 0.6867508616350503, 0.9423590105393628], 
             UndirectedEdge[270, 295] -> 
             RGBColor[
              0.40843215139149014`, 0.5270970211848035, 0.9475465622204944], 
             UndirectedEdge[127, 212] -> 
             RGBColor[
              0.6338274299124479, 0.6993482170807541, 0.8694368991647685], 
             UndirectedEdge[105, 274] -> 
             RGBColor[
              0.20109882640410032`, 0.32869799532569716`, 0.9347636527134358],
              UndirectedEdge[128, 142] -> 
             RGBColor[
              0.5530295272907141, 0.6429141162316117, 0.9601553002887488], 
             UndirectedEdge[38, 57] -> 
             RGBColor[
              0.6913475106549755, 0.7530946155667481, 0.9084204092190405], 
             UndirectedEdge[135, 255] -> 
             RGBColor[
              0.3763515353066258, 0.5003985167295948, 0.9452017649285107], 
             UndirectedEdge[46, 196] -> 
             RGBColor[
              0.5605767058254602, 0.6541404493387415, 0.9585497982241656], 
             UndirectedEdge[138, 210] -> 
             RGBColor[
              0.7430421959441047, 0.7989621597505034, 0.9754547417184917], 
             UndirectedEdge[72, 109] -> 
             RGBColor[
              0.33627305621288256`, 0.4625375149021622, 0.9427632281447869], 
             UndirectedEdge[277, 282] -> 
             RGBColor[
              0.4900356998954354, 0.5953926826555607, 0.9534053145294119], 
             UndirectedEdge[62, 117] -> 
             RGBColor[
              0.5980960321067, 0.6788146391277714, 0.9643893095047165], 
             UndirectedEdge[33, 126] -> 
             RGBColor[
              0.5750324107577611, 0.6658762418248694, 0.9596878042694283], 
             UndirectedEdge[217, 278] -> 
             RGBColor[
              0.8452320104293023, 0.8793025037213054, 0.9518693351874437], 
             UndirectedEdge[228, 264] -> 
             RGBColor[
              0.4462180967534155, 0.5598097379777576, 0.9499585512566663], 
             UndirectedEdge[121, 239] -> 
             RGBColor[
              0.5649032149305964, 0.6432312976191759, 0.9630210370585506], 
             UndirectedEdge[56, 84] -> 
             RGBColor[
              0.5863315465412765, 0.6742398017910314, 0.961130833012205], 
             UndirectedEdge[45, 120] -> 
             RGBColor[
              0.5919840212368565, 0.6764594045843897, 0.9627200371671205], 
             UndirectedEdge[67, 234] -> 
             RGBColor[
              0.4360042266402929, 0.5476093746316276, 0.9499616106917538], 
             UndirectedEdge[153, 192] -> 
             RGBColor[
              0.5539291706410134, 0.6369462009974802, 0.961600845659705], 
             UndirectedEdge[77, 127] -> 
             RGBColor[
              0.8225959025924792, 0.8601735304319715, 0.8829886347106269], 
             UndirectedEdge[36, 152] -> 
             RGBColor[
              0.3479284370536303, 0.46204999254127277`, 0.9443073798738482], 
             UndirectedEdge[22, 122] -> 
             RGBColor[
              0.47756189784758674`, 0.5778900958305084, 0.9539119793319428], 
             UndirectedEdge[68, 218] -> 
             RGBColor[
              0.2455808375232071, 0.37512885748964886`, 0.9373086476445216], 
             UndirectedEdge[56, 148] -> 
             RGBColor[
              0.6055881856677564, 0.6892832346325154, 0.9630501548368084], 
             UndirectedEdge[7, 130] -> 
             RGBColor[
              0.5657823332860847, 0.6561429091293526, 0.9600439685043782], 
             UndirectedEdge[58, 296] -> 
             RGBColor[
              0.721371697187259, 0.7819589238613172, 0.973069852708377], 
             UndirectedEdge[104, 116] -> 
             RGBColor[
              0.960868457514563, 0.9694260202526515, 0.9111777946927353], 
             UndirectedEdge[252, 279] -> 
             RGBColor[
              0.985457749857103, 0.987834433613126, 0.8718583965070195], 
             UndirectedEdge[64, 173] -> 
             RGBColor[
              0.6333755457271938, 0.7056772188512753, 0.9580032579409825], 
             UndirectedEdge[109, 155] -> 
             RGBColor[
              0.3585314902038486, 0.4818166516837158, 0.9441815158763309], 
             UndirectedEdge[151, 258] -> 
             RGBColor[
              0.6527532651753124, 0.72350143263673, 0.9690940573680573], 
             UndirectedEdge[167, 216] -> 
             RGBColor[
              0.2495152660524454, 0.3795867431756836, 0.9375208973257052], 
             UndirectedEdge[12, 258] -> 
             RGBColor[
              0.2798115674626014, 0.40483351326687395`, 0.9394877593786501], 
             UndirectedEdge[151, 239] -> 
             RGBColor[
              0.5864620560527148, 0.6604217323308004, 0.965077338570583], 
             UndirectedEdge[136, 226] -> 
             RGBColor[
              0.7067964167098683, 0.7708739996762547, 0.9714105194957439], 
             UndirectedEdge[59, 210] -> 
             RGBColor[
              0.781465439255042, 0.8298661537255467, 0.9786776473557152], 
             UndirectedEdge[191, 205] -> 
             RGBColor[
              0.6677313225250182, 0.7382643716774102, 0.9690161416054915], 
             UndirectedEdge[212, 276] -> 
             RGBColor[
              0.26151725374812906`, 0.39220159321381853`, 0.9382043927696248],
              UndirectedEdge[218, 292] -> 
             RGBColor[
              0.4218374011347319, 0.5376748886103472, 0.9486861776574115], 
             UndirectedEdge[144, 245] -> 
             RGBColor[
              0.6410730719782871, 0.7047638279511033, 0.7521416303625775], 
             UndirectedEdge[1, 277] -> 
             RGBColor[
              0.6337879714264611, 0.7129029603690676, 0.964773864485512], 
             UndirectedEdge[64, 239] -> 
             RGBColor[
              0.2835775473909449, 0.41438076449626104`, 0.9394975868841428], 
             UndirectedEdge[128, 256] -> 
             RGBColor[
              0.2635162401544743, 0.3916903878612781, 0.9384138799726014], 
             UndirectedEdge[7, 81] -> 
             RGBColor[
              0.3901762299639612, 0.5123727723924216, 0.9460826622473786], 
             UndirectedEdge[32, 145] -> 
             RGBColor[
              0.6800259614163172, 0.7495511370095462, 0.9690223224566903], 
             UndirectedEdge[84, 247] -> 
             RGBColor[
              0.6763048572648985, 0.7470537616934094, 0.968371405810093], 
             UndirectedEdge[215, 259] -> 
             RGBColor[
              0.40495609424054724`, 0.5251743479712224, 0.9470244221297619], 
             UndirectedEdge[187, 233] -> 
             RGBColor[
              0.4672132433871734, 0.5621199047046657, 0.9540972881713154], 
             UndirectedEdge[37, 152] -> 
             RGBColor[
              0.44719201339431525`, 0.5600297667814915, 0.9501928912401596], 
             UndirectedEdge[257, 300] -> 
             RGBColor[
              0.6682359537227227, 0.7381842573691806, 0.9694947998217556], 
             UndirectedEdge[10, 244] -> 
             RGBColor[
              0.6782944233038907, 0.746831714804784, 0.9698572123384663], 
             UndirectedEdge[98, 157] -> 
             RGBColor[
              0.692033830666289, 0.7573742985295819, 0.9716428683264715], 
             UndirectedEdge[13, 271] -> 
             RGBColor[
              0.5215773470850804, 0.6187373867159109, 0.9568537014465068], 
             UndirectedEdge[202, 203] -> 
             RGBColor[
              0.9654605659227748, 0.9709847218191874, 0.7867364633709218], 
             UndirectedEdge[166, 195] -> 
             RGBColor[
              0.8106143254553363, 0.8508275997861264, 0.8902430674038171], 
             UndirectedEdge[260, 287] -> 
             RGBColor[
              0.6678980490091795, 0.7359549414885876, 0.9656914575967654], 
             UndirectedEdge[212, 214] -> 
             RGBColor[
              0.3915404090491064, 0.5091524293838403, 0.9466760065228141], 
             UndirectedEdge[25, 113] -> 
             RGBColor[
              0.6086991082476394, 0.6932083835145906, 0.962338170021008], 
             UndirectedEdge[244, 280] -> 
             RGBColor[
              0.6928205627084303, 0.7584144640644139, 0.971242728482509], 
             UndirectedEdge[58, 134] -> 
             RGBColor[
              0.5208504520026076, 0.6209598175098308, 0.9556791066247077], 
             UndirectedEdge[64, 263] -> 
             RGBColor[
              0.4762252474285733, 0.5820305733542279, 0.9529122012432715], 
             UndirectedEdge[182, 261] -> 
             RGBColor[
              0.4058112819172801, 0.5254639971518651, 0.9472035463046403], 
             UndirectedEdge[150, 277] -> 
             RGBColor[
              0.7058863103078097, 0.7693120027666855, 0.9719373245155623], 
             UndirectedEdge[86, 202] -> 
             RGBColor[
              0.6142746954297388, 0.6766837984957195, 0.7592921094598564], 
             UndirectedEdge[257, 267] -> 
             RGBColor[
              0.6588283518558007, 0.7306828910030468, 0.9685974943574231], 
             UndirectedEdge[134, 245] -> 
             RGBColor[
              0.7064413736713184, 0.7632669755391506, 0.7562378432562791], 
             UndirectedEdge[187, 297] -> 
             RGBColor[
              0.568147210403117, 0.6581461632786112, 0.9602137378770588], 
             UndirectedEdge[75, 292] -> 
             RGBColor[
              0.43850623545669987`, 0.5521125951000627, 0.9497483010407359], 
             UndirectedEdge[54, 174] -> 
             RGBColor[
              0.3899820432216217, 0.5019519899143495, 0.947093593076204], 
             UndirectedEdge[44, 108] -> 
             RGBColor[
              0.8838658634294827, 0.9102346638716805, 0.9887851091619168], 
             UndirectedEdge[94, 141] -> 
             RGBColor[
              0.6481843751367976, 0.7163797465054289, 0.9279463340276415], 
             UndirectedEdge[185, 262] -> 
             RGBColor[
              0.37403779043147933`, 0.4983944672109417, 0.9450543351510305], 
             UndirectedEdge[40, 202] -> 
             RGBColor[
              0.736297222998397, 0.788540211294211, 0.7670063707160069], 
             UndirectedEdge[110, 191] -> 
             RGBColor[
              0.7048254758682144, 0.7683790764339815, 0.9719363292370289], 
             UndirectedEdge[92, 125] -> 
             RGBColor[
              0.9420647458673641, 0.955586414254398, 0.9577774252224829], 
             UndirectedEdge[72, 226] -> 
             RGBColor[
              0.570124481830096, 0.6588526845575344, 0.9607655536187323], 
             UndirectedEdge[130, 162] -> 
             RGBColor[
              0.837986868303335, 0.8738958832768886, 0.9639712187185826], 
             UndirectedEdge[29, 43] -> 
             RGBColor[
              0.8882141075673815, 0.9132998185906105, 0.9752616624193124], 
             UndirectedEdge[152, 268] -> 
             RGBColor[
              0.47319783205406085`, 0.582554699814112, 0.9518499590091162], 
             UndirectedEdge[4, 62] -> 
             RGBColor[
              0.696341551849566, 0.7614351619604911, 0.9713332240836694], 
             UndirectedEdge[18, 184] -> 
             RGBColor[
              0.4342629582793527, 0.5505584805958195, 0.9488918295912722], 
             UndirectedEdge[95, 159] -> 
             RGBColor[
              0.9075775664919752, 0.9286924198045956, 0.9754688077962073], 
             UndirectedEdge[154, 255] -> 
             RGBColor[
              0.39974377425934915`, 0.5206596983823282, 0.9466922977096335], 
             UndirectedEdge[140, 269] -> 
             RGBColor[
              0.3591916365935414, 0.4800434032658948, 0.9443885293173226], 
             UndirectedEdge[10, 161] -> 
             RGBColor[
              0.5719903879910135, 0.6558445388366528, 0.962642304414183], 
             UndirectedEdge[216, 293] -> 
             RGBColor[
              0.35351001615609245`, 0.47581646616185036`, 0.9439219972229518],
              UndirectedEdge[188, 294] -> 
             RGBColor[
              0.7329172367073211, 0.7905529388796081, 0.9748755749529232], 
             UndirectedEdge[32, 282] -> 
             RGBColor[
              0.5072273216631953, 0.6093496156803629, 0.9547587019699556], 
             UndirectedEdge[251, 282] -> 
             RGBColor[
              0.4011930716751793, 0.5219150069601142, 0.9467846456594068], 
             UndirectedEdge[181, 299] -> 
             RGBColor[
              0.7408611839874815, 0.7972557283897721, 0.9752091371742724], 
             UndirectedEdge[60, 159] -> 
             RGBColor[
              0.8305672246778506, 0.8679045563794401, 0.9836566483166747], 
             UndirectedEdge[137, 217] -> 
             RGBColor[
              0.5642250069824535, 0.6547863422391349, 0.9599479914492013], 
             UndirectedEdge[20, 152] -> 
             RGBColor[
              0.6816435607005666, 0.7495161482959763, 0.9701606318091309], 
             UndirectedEdge[62, 196] -> 
             RGBColor[
              0.7279369960806402, 0.7870857669458192, 0.9738205331914652], 
             UndirectedEdge[251, 289] -> 
             RGBColor[
              0.6986688492150448, 0.7565365384480432, 0.7558906963845806], 
             UndirectedEdge[104, 283] -> 
             RGBColor[
              0.6955048590518744, 0.7601456484508705, 0.9719697415123246], 
             UndirectedEdge[45, 294] -> 
             RGBColor[
              0.8507380398026165, 0.8841939069548732, 0.985525974837278], 
             UndirectedEdge[15, 158] -> 
             RGBColor[
              0.3937469791769905, 0.5154655758896738, 0.9463101872297432], 
             UndirectedEdge[150, 237] -> 
             RGBColor[
              0.7244992993538677, 0.7844228657798764, 0.9734026071948935], 
             UndirectedEdge[169, 228] -> 
             RGBColor[
              0.4233991850991211, 0.5411488262962195, 0.9481995995706852], 
             UndirectedEdge[159, 251] -> 
             RGBColor[
              0.6327928133461449, 0.7083922568380603, 0.966818821844417], 
             UndirectedEdge[203, 293] -> 
             RGBColor[
              0.6935735621793497, 0.7584271212714789, 0.970732951209468], 
             UndirectedEdge[145, 282] -> 
             RGBColor[
              0.5716314651241565, 0.6600722015700757, 0.9608978733387252], 
             UndirectedEdge[195, 234] -> 
             RGBColor[
              0.6431898186427228, 0.7095073185892065, 0.8782814112844233], 
             UndirectedEdge[156, 270] -> 
             RGBColor[
              0.5788251737577783, 0.6626060523280481, 0.9629390994942317], 
             UndirectedEdge[25, 134] -> 
             RGBColor[
              0.5048317967147034, 0.607955151514913, 0.9544180594021761], 
             UndirectedEdge[158, 276] -> 
             RGBColor[
              0.31097709859496947`, 0.4380027629816371, 0.9412474939308764], 
             UndirectedEdge[268, 280] -> 
             RGBColor[
              0.6500505200053761, 0.7230441732060053, 0.9680546598566921], 
             UndirectedEdge[8, 186] -> 
             RGBColor[
              0.38190734157222683`, 0.5052106768739162, 0.9455557759909481], 
             UndirectedEdge[32, 256] -> 
             RGBColor[
              0.402827195307923, 0.5079476060599919, 0.9485082985108566], 
             UndirectedEdge[60, 168] -> 
             RGBColor[
              0.6072678451311102, 0.6886166629851673, 0.964151363866498], 
             UndirectedEdge[162, 216] -> 
             RGBColor[
              0.6075830261809128, 0.6778648246778874, 0.9466939226977165], 
             UndirectedEdge[106, 115] -> 
             RGBColor[
              0.4027393390893319, 0.5191779751304978, 0.9474726316009865], 
             UndirectedEdge[77, 276] -> 
             RGBColor[
              0.45028572642816034`, 0.553026906565036, 0.9517561283154832], 
             UndirectedEdge[80, 281] -> 
             RGBColor[
              0.343872138070277, 0.46961893164172686`, 0.9432291467321534], 
             UndirectedEdge[130, 293] -> 
             RGBColor[
              0.5839138582785146, 0.6718475247608515, 0.9611992932438179], 
             UndirectedEdge[39, 118] -> 
             RGBColor[
              0.4371306859518076, 0.5521045490747214, 0.9493336792150366], 
             UndirectedEdge[58, 245] -> 
             RGBColor[
              0.8081907356461022, 0.8468007606749799, 0.7639912211275883], 
             UndirectedEdge[54, 143] -> 
             RGBColor[
              0.5823649608605979, 0.6718291363259699, 0.9602650494735396], 
             UndirectedEdge[239, 258] -> 
             RGBColor[
              0.3138022879153868, 0.44055991559890284`, 0.9414234806236716], 
             UndirectedEdge[184, 222] -> 
             RGBColor[
              0.4681850597677497, 0.578403900161785, 0.9514777724752304], 
             UndirectedEdge[143, 298] -> 
             RGBColor[
              0.7853180447796343, 0.8322751278247481, 0.9586244090063161], 
             UndirectedEdge[203, 269] -> 
             RGBColor[
              0.7012249765577825, 0.7647244366996466, 0.9713116601547289], 
             UndirectedEdge[107, 139] -> 
             RGBColor[
              0.7076064494444751, 0.7714964557071762, 0.9714983307660636], 
             UndirectedEdge[108, 283] -> 
             RGBColor[
              0.6622437396401751, 0.7336241346810164, 0.968797266250285], 
             UndirectedEdge[173, 186] -> 
             RGBColor[
              0.6948296768710003, 0.7589056984735991, 0.9619190608357115], 
             UndirectedEdge[164, 296] -> 
             RGBColor[
              0.6203083872911003, 0.6990193625540126, 0.9653601894688657], 
             UndirectedEdge[11, 116] -> 
             RGBColor[
              0.6591390409384266, 0.7246310934650493, 0.8855586004609839], 
             UndirectedEdge[43, 229] -> 
             RGBColor[
              0.8536317244636504, 0.8861267821441653, 0.9859013499970212], 
             UndirectedEdge[128, 149] -> 
             RGBColor[
              0.4969107510561228, 0.5990737017186526, 0.9545619051334655], 
             UndirectedEdge[221, 232] -> 
             RGBColor[
              0.5294056516419116, 0.6268893238954729, 0.9567720500818664], 
             UndirectedEdge[8, 85] -> 
             RGBColor[
              0.38655943824681954`, 0.5092400891922709, 0.9458522034773655], 
             UndirectedEdge[20, 41] -> 
             RGBColor[
              0.7654309048630221, 0.8168928725997788, 0.9771980898305654], 
             UndirectedEdge[108, 252] -> 
             RGBColor[
              0.9238477773668491, 0.9409298450210777, 0.9515031175526008], 
             UndirectedEdge[65, 241] -> 
             RGBColor[
              0.49284854121575916`, 0.5894477982283659, 0.955496455677471], 
             UndirectedEdge[231, 245] -> 
             RGBColor[
              0.6343241864669584, 0.6976703213746406, 0.7517572913167887], 
             UndirectedEdge[80, 167] -> 
             RGBColor[
              0.32490580743996555`, 0.44968411561445243`, 0.942149042260929], 
             UndirectedEdge[17, 201] -> 
             RGBColor[
              0.411202728744256, 0.5271264621915571, 0.9480408175123457], 
             UndirectedEdge[57, 223] -> 
             RGBColor[
              0.5142495431293528, 0.6149740217871116, 0.9553326678570223], 
             UndirectedEdge[162, 202] -> 
             RGBColor[
              0.97612717928379, 0.9789398645988561, 0.7686806692490427], 
             UndirectedEdge[3, 59] -> 
             RGBColor[
              0.7776732147214903, 0.8268423368196853, 0.9783159415943461], 
             UndirectedEdge[180, 187] -> 
             RGBColor[
              0.5370694944361935, 0.6312282077194841, 0.9582334932965917], 
             UndirectedEdge[193, 215] -> 
             RGBColor[
              0.3584138499402356, 0.48441896977293847`, 0.9440750054882019], 
             UndirectedEdge[43, 78] -> 
             RGBColor[
              0.8283505469486571, 0.8659682574329921, 0.9834900087168675], 
             UndirectedEdge[56, 251] -> 
             RGBColor[
              0.4405039376678728, 0.5553087391403982, 0.9494705783385218], 
             UndirectedEdge[261, 284] -> 
             RGBColor[
              0.47393510599807975`, 0.5838008954392819, 0.9517290541071166], 
             UndirectedEdge[36, 41] -> 
             RGBColor[
              0.4317157812160857, 0.5294267168450753, 0.9513448378952827], 
             UndirectedEdge[95, 168] -> 
             RGBColor[
              0.6842781869452347, 0.7494045264103226, 0.9559635233460305], 
             UndirectedEdge[194, 280] -> 
             RGBColor[
              0.592027112283326, 0.6727872137784342, 0.964357459624728], 
             UndirectedEdge[99, 182] -> 
             RGBColor[
              0.36501129828822876`, 0.4905761734011447, 0.9444791750534762], 
             UndirectedEdge[94, 97] -> 
             RGBColor[
              0.39673798708222807`, 0.5173449753121984, 0.9466972952229602], 
             UndirectedEdge[79, 240] -> 
             RGBColor[
              0.43947724726592907`, 0.5462551054133487, 0.9506149470019536], 
             UndirectedEdge[83, 198] -> 
             RGBColor[
              0.522730962184121, 0.6157671520597762, 0.9580038732264715], 
             UndirectedEdge[69, 213] -> 
             RGBColor[
              0.2868889743879294, 0.41854632842162054`, 0.9396610849290554], 
             UndirectedEdge[214, 286] -> 
             RGBColor[
              0.538314899127232, 0.6360673117781568, 0.9567972672531961], 
             UndirectedEdge[277, 293] -> 
             RGBColor[
              0.5157028699676903, 0.6176242953026696, 0.9550408039098287], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.630039827682161, 0.7064827493133868, 0.9664247399119956], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.5382873703827613, 0.6355446328096263, 0.9569333427299296], 
             UndirectedEdge[43, 199] -> 
             RGBColor[
              0.5473059351870961, 0.6319853968545484, 0.9609205795746069], 
             UndirectedEdge[192, 222] -> 
             RGBColor[
              0.3884208463037815, 0.5054515106054278, 0.9465367706150567], 
             UndirectedEdge[130, 202] -> 
             RGBColor[0.85580086202194, 0.88440512530856, 0.7772028054052718],
              UndirectedEdge[4, 265] -> 
             RGBColor[
              0.4468190150852769, 0.5589590975101955, 0.9503756873640999], 
             UndirectedEdge[121, 173] -> 
             RGBColor[
              0.9147012132668453, 0.9345277519741901, 0.9815267081153904], 
             UndirectedEdge[53, 107] -> 
             RGBColor[
              0.6319197052176606, 0.7120599102108263, 0.9641661804743373], 
             UndirectedEdge[172, 238] -> 
             RGBColor[
              0.8552546755812228, 0.8877633222097912, 0.9848112548277448], 
             UndirectedEdge[210, 211] -> 
             RGBColor[
              0.8802251467667521, 0.9073316552294403, 0.9884378543565194], 
             UndirectedEdge[180, 221] -> 
             RGBColor[
              0.5100022265803007, 0.6100830523516059, 0.9555356809947156], 
             UndirectedEdge[196, 212] -> 
             RGBColor[
              0.44218430272862924`, 0.5502674237542876, 0.9506628793479612], 
             UndirectedEdge[160, 176] -> 
             RGBColor[
              0.7227200605388127, 0.7827671359770194, 0.9735056995024868], 
             UndirectedEdge[115, 193] -> 
             RGBColor[
              0.41245702156340647`, 0.5293918755474054, 0.948026039241862], 
             UndirectedEdge[21, 300] -> 
             RGBColor[
              0.9414402976516754, 0.9529196294396509, 0.8652541053975711], 
             UndirectedEdge[75, 235] -> 
             RGBColor[
              0.4475718172331953, 0.5594724427860266, 0.9504619768465019], 
             UndirectedEdge[77, 255] -> 
             RGBColor[
              0.5279199151192598, 0.6260414412845363, 0.9564915798683746], 
             UndirectedEdge[62, 286] -> 
             RGBColor[
              0.7092416071419065, 0.7719080079876814, 0.972348763690742], 
             UndirectedEdge[46, 225] -> 
             RGBColor[
              0.6149309908617505, 0.6971340634701809, 0.9636038446230548], 
             UndirectedEdge[37, 161] -> 
             RGBColor[
              0.3399259787312926, 0.46826159640333537`, 0.9429022512031132], 
             UndirectedEdge[3, 162] -> 
             RGBColor[
              0.9261937143581822, 0.9434025856649302, 0.9726039380476268], 
             UndirectedEdge[107, 274] -> 
             RGBColor[
              0.4140883677966219, 0.5166665952165161, 0.949433354116205], 
             UndirectedEdge[6, 147] -> 
             RGBColor[
              0.3393645178799045, 0.46836222125611826`, 0.9428449848844153], 
             UndirectedEdge[8, 135] -> 
             RGBColor[
              0.3361885071571525, 0.46561132039901076`, 0.9426426122895974], 
             UndirectedEdge[186, 249] -> 
             RGBColor[
              0.3451707959541715, 0.46775546534694923`, 0.9434213123101018], 
             UndirectedEdge[277, 281] -> 
             RGBColor[
              0.43067445049435477`, 0.5413293883437773, 0.9497198084838065], 
             UndirectedEdge[256, 277] -> 
             RGBColor[
              0.3856355735401631, 0.49399067303518956`, 0.9471549110703129], 
             UndirectedEdge[8, 249] -> 
             RGBColor[
              0.28452585924968493`, 0.4152278692766692, 0.9395570705695039], 
             UndirectedEdge[114, 254] -> 
             RGBColor[
              0.7985586288163249, 0.8427725023321262, 0.9804999517580489], 
             UndirectedEdge[223, 270] -> 
             RGBColor[
              0.47797873475674113`, 0.583558070598591, 0.953021524020536], 
             UndirectedEdge[120, 294] -> 
             RGBColor[
              0.6690683419052403, 0.7375498790747765, 0.9701717814200074], 
             UndirectedEdge[23, 290] -> 
             RGBColor[
              0.5399912508064932, 0.6146676073794541, 0.9619628360986152], 
             UndirectedEdge[7, 293] -> 
             RGBColor[
              0.43203564052311455`, 0.5486292899036116, 0.9487499068733845], 
             UndirectedEdge[95, 191] -> 
             RGBColor[
              0.896782289898768, 0.9200845592791491, 0.9744391446776899], 
             UndirectedEdge[65, 194] -> 
             RGBColor[
              0.5146491295376158, 0.6119295503656114, 0.9567537863406437], 
             UndirectedEdge[94, 188] -> 
             RGBColor[
              0.425987439922008, 0.541090998800366, 0.9489999192947838], 
             UndirectedEdge[24, 162] -> 
             RGBColor[
              0.7288152575414817, 0.7864189752579482, 0.9545881591415445], 
             UndirectedEdge[34, 84] -> 
             RGBColor[
              0.5172409711363624, 0.6150523820895974, 0.9565473635825064], 
             UndirectedEdge[130, 201] -> 
             RGBColor[
              0.6232680934734725, 0.7038826183236765, 0.9642737643750148], 
             UndirectedEdge[74, 260] -> 
             RGBColor[
              0.5005035919157651, 0.6037852483838122, 0.9542586017736503], 
             UndirectedEdge[69, 85] -> 
             RGBColor[
              0.3820455733361565, 0.5053304062801016, 0.9455645839967122], 
             UndirectedEdge[220, 262] -> 
             RGBColor[
              0.4389363806836325, 0.5539079533213219, 0.9493825889380849], 
             UndirectedEdge[26, 262] -> 
             RGBColor[
              0.41695849538605345`, 0.5355702245852378, 0.9477892045174469], 
             UndirectedEdge[217, 270] -> 
             RGBColor[
              0.5206567696927507, 0.6170497249020719, 0.957171861894981], 
             UndirectedEdge[221, 245] -> 
             RGBColor[
              0.829184592296379, 0.8635040065784474, 0.7658767448104138], 
             UndirectedEdge[3, 24] -> 
             RGBColor[
              0.6966957863344787, 0.7613909383556937, 0.971743014626818], 
             UndirectedEdge[59, 197] -> 
             RGBColor[
              0.5059919281454119, 0.6067503394869723, 0.9552205525196724], 
             UndirectedEdge[54, 235] -> 
             RGBColor[
              0.5512216494065305, 0.6465455930973654, 0.9578133339141667], 
             UndirectedEdge[159, 282] -> 
             RGBColor[
              0.6304325670420002, 0.7063479301188387, 0.9666684290370008], 
             UndirectedEdge[6, 53] -> 
             RGBColor[
              0.4679061123769335, 0.5751141447862474, 0.9523022097854477], 
             UndirectedEdge[31, 210] -> 
             RGBColor[
              0.6500553222747063, 0.7219814848656806, 0.9685460945071594], 
             UndirectedEdge[137, 273] -> 
             RGBColor[
              0.4314674983719378, 0.548137193727917, 0.9487137053578998], 
             UndirectedEdge[99, 259] -> 
             RGBColor[
              0.39268579861170505`, 0.5145464346205095, 0.9462425697424883], 
             UndirectedEdge[16, 151] -> 
             RGBColor[
              0.687199537173153, 0.7533370621212885, 0.9712889433601174], 
             UndirectedEdge[24, 227] -> 
             RGBColor[
              0.6229308790109371, 0.7031663882673478, 0.9645497327829196], 
             UndirectedEdge[87, 202] -> 
             RGBColor[
              0.7882022105352207, 0.8306790184696462, 0.7710925214691399], 
             UndirectedEdge[17, 94] -> 
             RGBColor[
              0.303746294241713, 0.4361046665045648, 0.9406269344616798], 
             UndirectedEdge[5, 92] -> 
             RGBColor[
              0.8857854037533929, 0.9109128836320901, 0.9523558230924227], 
             UndirectedEdge[72, 290] -> 
             RGBColor[
              0.6494467636079118, 0.721475124720339, 0.9684977686438292], 
             UndirectedEdge[103, 212] -> 
             RGBColor[
              0.42160999172568026`, 0.5335642712199454, 0.9490431942196247], 
             UndirectedEdge[112, 133] -> 
             RGBColor[
              0.28253061008913105`, 0.40815967940865694`, 0.9396254588110906],
              UndirectedEdge[71, 244] -> 
             RGBColor[
              0.4549433082046721, 0.5667957898303955, 0.9506723625264402], 
             UndirectedEdge[142, 197] -> 
             RGBColor[
              0.5598854084659959, 0.6488523359190336, 0.9605921509748201], 
             UndirectedEdge[117, 196] -> 
             RGBColor[
              0.47781321777154817`, 0.584088937288694, 0.952824685892318], 
             UndirectedEdge[131, 188] -> 
             RGBColor[
              0.4608375913254156, 0.5712764483264575, 0.9512205401254301], 
             UndirectedEdge[13, 282] -> 
             RGBColor[
              0.5478559110870327, 0.6414985580553714, 0.9585281483074896], 
             UndirectedEdge[139, 143] -> 
             RGBColor[
              0.6926936530017329, 0.7593895757411342, 0.9703243408027177], 
             UndirectedEdge[45, 89] -> 
             RGBColor[
              0.5364743347104695, 0.6275058899923263, 0.959215003642397], 
             UndirectedEdge[127, 269] -> 
             RGBColor[
              0.7282052151927678, 0.7837250940755603, 0.8754332993580135], 
             UndirectedEdge[25, 79] -> 
             RGBColor[
              0.6039868621019981, 0.6893827698092894, 0.9619672047428967], 
             UndirectedEdge[29, 78] -> 
             RGBColor[
              0.891425204892687, 0.9158602604348942, 0.9755679397487806], 
             UndirectedEdge[150, 179] -> 
             RGBColor[
              0.6327126401958232, 0.7094059910398887, 0.9663150678007004], 
             UndirectedEdge[11, 198] -> 
             RGBColor[
              0.5413451947720505, 0.6334504937266986, 0.9591328133952479], 
             UndirectedEdge[135, 286] -> 
             RGBColor[
              0.4606890066572929, 0.5702720535924258, 0.9514530304532325], 
             UndirectedEdge[101, 104] -> 
             RGBColor[
              0.7242130515851629, 0.7834522524387295, 0.9742297555901194], 
             UndirectedEdge[3, 290] -> 
             RGBColor[
              0.8975648723820829, 0.9211578817607918, 0.9900917328650654], 
             UndirectedEdge[158, 212] -> 
             RGBColor[
              0.3261742685586106, 0.453975952169652, 0.9421129502781075], 
             UndirectedEdge[102, 175] -> 
             RGBColor[
              0.3978747383629314, 0.5190408334293267, 0.9465732043950372], 
             UndirectedEdge[103, 255] -> 
             RGBColor[
              0.48404701045313864`, 0.5906056167514309, 0.9529131894252849], 
             UndirectedEdge[3, 65] -> 
             RGBColor[
              0.8049767638348247, 0.8481720769016811, 0.9810373042037901], 
             UndirectedEdge[148, 270] -> 
             RGBColor[
              0.5285968793114328, 0.6232525988832545, 0.9579632578172281], 
             UndirectedEdge[49, 298] -> 
             RGBColor[
              0.6324753056185719, 0.7039572159855275, 0.9477047072788455], 
             UndirectedEdge[15, 103] -> 
             RGBColor[
              0.48918270234406014`, 0.5950538949399673, 0.9532404311712604], 
             UndirectedEdge[4, 15] -> 
             RGBColor[
              0.47816156911593494`, 0.5861064424889814, 0.9523728071918012], 
             UndirectedEdge[83, 290] -> 
             RGBColor[
              0.5964609798639336, 0.6740208730064394, 0.9651787036289587], 
             UndirectedEdge[182, 284] -> 
             RGBColor[
              0.4098157745357183, 0.5287150246598498, 0.9475187946325037], 
             UndirectedEdge[32, 92] -> 
             RGBColor[
              0.7961057617837746, 0.8404448862065108, 0.943697426245273], 
             UndirectedEdge[87, 203] -> 
             RGBColor[
              0.7597216034556007, 0.8122146336583062, 0.9759167289043299], 
             UndirectedEdge[115, 169] -> 
             RGBColor[
              0.4846427715088433, 0.5923583694554272, 0.9526094373874676], 
             UndirectedEdge[111, 143] -> 
             RGBColor[
              0.6644826516942833, 0.7373509271082035, 0.9675125318391873], 
             UndirectedEdge[163, 274] -> 
             RGBColor[
              0.2263765124899142, 0.3552664460997528, 0.9362031795410375], 
             UndirectedEdge[96, 260] -> 
             RGBColor[
              0.36016213496761207`, 0.48637607185886167`, 0.9441701906546333],
              UndirectedEdge[27, 227] -> 
             RGBColor[
              0.6363211595630525, 0.7140372212448196, 0.9656038647181959], 
             UndirectedEdge[103, 205] -> 
             RGBColor[
              0.5307632246315377, 0.6299365222234931, 0.9562027717742001], 
             UndirectedEdge[27, 216] -> 
             RGBColor[
              0.3914753787093246, 0.5067240103461228, 0.946887131212184], 
             UndirectedEdge[145, 293] -> 
             RGBColor[
              0.5972986351964114, 0.6823038142171848, 0.962533362719142], 
             UndirectedEdge[96, 133] -> 
             RGBColor[
              0.35020721835445096`, 0.47775362343719874`, 0.9435358721708298],
              UndirectedEdge[127, 159] -> 
             RGBColor[
              0.9264863724130458, 0.9416734158782298, 0.893253277217346], 
             UndirectedEdge[186, 214] -> 
             RGBColor[
              0.47445933633157805`, 0.5839341746550217, 0.9518510908301592], 
             UndirectedEdge[111, 262] -> 
             RGBColor[
              0.557970107537713, 0.6493998451933831, 0.9595362368871537], 
             UndirectedEdge[33, 157] -> 
             RGBColor[
              0.5003300496706781, 0.605229499791359, 0.953806960760888], 
             UndirectedEdge[112, 131] -> 
             RGBColor[
              0.2868478211838396, 0.41189903066955463`, 0.9399005476844855], 
             UndirectedEdge[37, 55] -> 
             RGBColor[
              0.6496681734130627, 0.7209507012693347, 0.9688415817278708], 
             UndirectedEdge[20, 71] -> 
             RGBColor[
              0.6206189941481237, 0.6983869474538512, 0.965794966700638], 
             UndirectedEdge[37, 252] -> 
             RGBColor[
              0.6795590948977273, 0.7435995989496407, 0.9305971022500807], 
             UndirectedEdge[120, 178] -> 
             RGBColor[
              0.3382870596478622, 0.463500841236692, 0.9429201586411322], 
             UndirectedEdge[113, 231] -> 
             RGBColor[
              0.45085121435639985`, 0.557082610209169, 0.9513652874327398], 
             UndirectedEdge[7, 181] -> 
             RGBColor[
              0.5014208455749564, 0.6050448776760295, 0.9541885259587826], 
             UndirectedEdge[42, 299] -> 
             RGBColor[
              0.6265304872477734, 0.7019106147434206, 0.9669066311022612], 
             UndirectedEdge[64, 234] -> 
             RGBColor[
              0.3080414023039465, 0.4400938271078144, 0.9408907672304081], 
             UndirectedEdge[78, 261] -> 
             RGBColor[
              0.650746128826802, 0.7245392836042865, 0.9676050459127945], 
             UndirectedEdge[10, 100] -> 
             RGBColor[
              0.6281958560323706, 0.7051138243075252, 0.9662021766075065], 
             UndirectedEdge[6, 88] -> 
             RGBColor[
              0.2779273008843111, 0.4089956004948432, 0.9391555435748189], 
             UndirectedEdge[36, 208] -> 
             RGBColor[
              0.2769103541913695, 0.4022649101603179, 0.9393049367430131], 
             UndirectedEdge[92, 142] -> 
             RGBColor[
              0.8728244262725813, 0.900787669517003, 0.9510639939843564], 
             UndirectedEdge[237, 293] -> 
             RGBColor[
              0.5343158590137482, 0.6327351583158605, 0.9565060865891599], 
             UndirectedEdge[127, 145] -> 
             RGBColor[
              0.867685270495202, 0.8953976873294669, 0.8874827215190706], 
             UndirectedEdge[90, 285] -> 
             RGBColor[
              0.7448799196244926, 0.7984320472829237, 0.925643079200805], 
             UndirectedEdge[134, 176] -> 
             RGBColor[
              0.6394154640806112, 0.714207642414769, 0.9672043611380452], 
             UndirectedEdge[28, 297] -> 
             RGBColor[
              0.4276134174038507, 0.5447989825051018, 0.9484681267266433], 
             UndirectedEdge[20, 136] -> 
             RGBColor[
              0.7587695713281271, 0.8116889882143088, 0.9765341503575082], 
             UndirectedEdge[113, 134] -> 
             RGBColor[
              0.5229684015607601, 0.6226792643736792, 0.9558458393722302], 
             UndirectedEdge[12, 181] -> 
             RGBColor[
              0.38423360675322327`, 0.491596245854431, 0.9471588945598872], 
             UndirectedEdge[84, 217] -> 
             RGBColor[
              0.7065250652339292, 0.7706620178409035, 0.9713834737165459], 
             UndirectedEdge[126, 153] -> 
             RGBColor[
              0.7241342565491546, 0.7840514138299743, 0.9734603012240372], 
             UndirectedEdge[217, 251] -> 
             RGBColor[
              0.5606974563605255, 0.6517309551902704, 0.9597232190428626], 
             UndirectedEdge[211, 266] -> 
             RGBColor[
              0.8143488520328117, 0.8552084469734902, 0.9820471034320588], 
             UndirectedEdge[156, 282] -> 
             RGBColor[
              0.6165056141214085, 0.695242955897025, 0.9653400638346971], 
             UndirectedEdge[92, 256] -> 
             RGBColor[
              0.5833111391363415, 0.6495639411466694, 0.9293225736682089], 
             UndirectedEdge[56, 246] -> 
             RGBColor[
              0.4501952847056569, 0.5637028968432616, 0.9500881024020476], 
             UndirectedEdge[223, 246] -> 
             RGBColor[
              0.5277107684622999, 0.6266334585896527, 0.9561904052319435], 
             UndirectedEdge[66, 228] -> 
             RGBColor[
              0.40206718213574816`, 0.5226721175069897, 0.9468403432050086], 
             UndirectedEdge[170, 261] -> 
             RGBColor[
              0.7128033170181118, 0.7735068486138035, 0.9556634603245533], 
             UndirectedEdge[104, 287] -> 
             RGBColor[
              0.9367056868586384, 0.952234678239853, 0.9892129051996389], 
             UndirectedEdge[255, 258] -> 
             RGBColor[
              0.3908409791023356, 0.5129485446848183, 0.9461250194746612], 
             UndirectedEdge[27, 162] -> 
             RGBColor[
              0.742205538093597, 0.7972898082354201, 0.9556422910768209], 
             UndirectedEdge[162, 169] -> 
             RGBColor[
              0.7033205739786533, 0.7655857513989115, 0.9526185608892481], 
             UndirectedEdge[90, 166] -> 
             RGBColor[
              0.8081775885759789, 0.8498199464652307, 0.9306261035676673], 
             UndirectedEdge[74, 257] -> 
             RGBColor[
              0.5270656171773012, 0.6267919396191468, 0.9559511105354388], 
             UndirectedEdge[82, 203] -> 
             RGBColor[
              0.6203711433912241, 0.6945620908444928, 0.9660854290274683], 
             UndirectedEdge[1, 142] -> 
             RGBColor[
              0.7276982576830279, 0.7872026767043621, 0.973493819665139], 
             UndirectedEdge[82, 145] -> 
             RGBColor[
              0.5240962164082859, 0.6184387837901987, 0.9578858405371424], 
             UndirectedEdge[77, 203] -> 
             RGBColor[
              0.7956156639574938, 0.8411728730560578, 0.9788669955073424], 
             UndirectedEdge[12, 27] -> 
             RGBColor[
              0.3528137642546136, 0.46608820226628545`, 0.9446854094637214], 
             UndirectedEdge[54, 185] -> 
             RGBColor[
              0.4510573817644723, 0.5624018413811986, 0.9507088368205461], 
             UndirectedEdge[35, 165] -> 
             RGBColor[
              0.7924973402810072, 0.8377417618608509, 0.9494845042751953], 
             UndirectedEdge[60, 95] -> 
             RGBColor[
              0.8761124824568598, 0.903771796187251, 0.9724228508908709], 
             UndirectedEdge[47, 112] -> 
             RGBColor[
              0.34006678624917114`, 0.456995878661889, 0.9435675692107981], 
             UndirectedEdge[24, 59] -> 
             RGBColor[
              0.5802947579047898, 0.6698587264127034, 0.9603001626882638], 
             UndirectedEdge[239, 285] -> 
             RGBColor[
              0.3761017715669181, 0.4931256599191396, 0.945778573924994], 
             UndirectedEdge[173, 286] -> 
             RGBColor[
              0.7586852396666541, 0.8110388355967342, 0.9668652372587485], 
             UndirectedEdge[17, 40] -> 
             RGBColor[
              0.3860915472887254, 0.5067400738401244, 0.9460639733228777], 
             UndirectedEdge[226, 241] -> 
             RGBColor[
              0.5061143679852016, 0.5998111629246721, 0.9568186693136496], 
             UndirectedEdge[255, 286] -> 
             RGBColor[
              0.485925932517354, 0.5921310103276354, 0.9530611050528983], 
             UndirectedEdge[95, 271] -> 
             RGBColor[
              0.6496992608190573, 0.7194539985871891, 0.9537601847502143], 
             UndirectedEdge[189, 260] -> 
             RGBColor[
              0.3921761077575614, 0.5141049660204575, 0.9462100926919643], 
             UndirectedEdge[193, 245] -> 
             RGBColor[
              0.6488690599080305, 0.7129579055594473, 0.7525856003420458], 
             UndirectedEdge[84, 223] -> 
             RGBColor[
              0.6638470302979196, 0.7371703635374225, 0.9672331358421009], 
             UndirectedEdge[44, 61] -> 
             RGBColor[
              0.8090314805287104, 0.8514012902448351, 0.9814250836815077], 
             UndirectedEdge[262, 292] -> 
             RGBColor[
              0.4651364762970421, 0.5751783712411446, 0.951445156438885], 
             UndirectedEdge[153, 248] -> 
             RGBColor[
              0.76524835728529, 0.8167062507664233, 0.9771915752301452], 
             UndirectedEdge[78, 99] -> 
             RGBColor[
              0.6099461451977507, 0.6896514598535661, 0.9648806746616303], 
             UndirectedEdge[199, 261] -> 
             RGBColor[
              0.3697015170652411, 0.4905564230258428, 0.9450356167705338], 
             UndirectedEdge[58, 215] -> 
             RGBColor[
              0.5177355256783073, 0.618261824888471, 0.9554806262737445], 
             UndirectedEdge[23, 197] -> 
             RGBColor[
              0.26481933499951116`, 0.39179227704862485`, 0.9385345076917764],
              UndirectedEdge[196, 214] -> 
             RGBColor[
              0.5570102880659655, 0.6512450707362946, 0.9582690367539195], 
             UndirectedEdge[88, 289] -> 
             RGBColor[
              0.6179913306655911, 0.6805049355264886, 0.7509752800735029], 
             UndirectedEdge[47, 96] -> 
             RGBColor[
              0.40774339451449104`, 0.5265898226904309, 0.9474779825705373], 
             UndirectedEdge[179, 205] -> 
             RGBColor[
              0.464956061859674, 0.5760109730127818, 0.9511604335015581], 
             UndirectedEdge[72, 194] -> 
             RGBColor[
              0.35562850007979907`, 0.48244926518615305`, 0.9438813114485178],
              UndirectedEdge[140, 299] -> 
             RGBColor[
              0.5728490356352038, 0.6502523229199707, 0.963675106848112], 
             UndirectedEdge[134, 297] -> 
             RGBColor[
              0.41833672392216387`, 0.5367639768714362, 0.9478770240210481], 
             UndirectedEdge[67, 195] -> 
             RGBColor[
              0.7827552566642233, 0.8282103527047541, 0.888049899457449], 
             UndirectedEdge[24, 155] -> 
             RGBColor[
              0.47083611155127364`, 0.5809873180967945, 0.9515673381371257], 
             UndirectedEdge[156, 277] -> 
             RGBColor[
              0.7077084886458092, 0.770764958311693, 0.9721111255121184], 
             UndirectedEdge[267, 272] -> 
             RGBColor[
              0.6284839289324802, 0.7044000770219085, 0.9666639745612688], 
             UndirectedEdge[71, 177] -> 
             RGBColor[
              0.4669434959787907, 0.5765380828677235, 0.951617061266155], 
             UndirectedEdge[188, 281] -> 
             RGBColor[
              0.4090612197562576, 0.5237827939656411, 0.9480183357882308], 
             UndirectedEdge[1, 150] -> 
             RGBColor[
              0.7584357073144348, 0.8113002780655245, 0.9765348127942409], 
             UndirectedEdge[84, 246] -> 
             RGBColor[
              0.5590722738905118, 0.6512845540328323, 0.9592128172040322], 
             UndirectedEdge[58, 230] -> 
             RGBColor[
              0.5204959693211368, 0.6206527824279584, 0.955656519301701], 
             UndirectedEdge[74, 189] -> 
             RGBColor[
              0.49774121892923207`, 0.6013926197437807, 0.954082585809619], 
             UndirectedEdge[48, 71] -> 
             RGBColor[
              0.5696793802522132, 0.6583793687832961, 0.9607743495190901], 
             UndirectedEdge[80, 205] -> 
             RGBColor[
              0.45132741954758276`, 0.5642065280375281, 0.9502920284647669], 
             UndirectedEdge[1, 32] -> 
             RGBColor[
              0.6509795931942212, 0.7268598933938699, 0.9661272519260556], 
             UndirectedEdge[229, 233] -> 
             RGBColor[
              0.5489142115442829, 0.6264475764603009, 0.962107194241927], 
             UndirectedEdge[54, 172] -> 
             RGBColor[
              0.6632007001781557, 0.7354458679965705, 0.9680025475201997], 
             UndirectedEdge[61, 194] -> 
             RGBColor[
              0.5148908631874152, 0.6121183945300785, 0.9567778800917264], 
             UndirectedEdge[177, 194] -> 
             RGBColor[
              0.426212612755984, 0.5412590390138439, 0.9490217254041036], 
             UndirectedEdge[7, 42] -> 
             RGBColor[
              0.3870901488352483, 0.5096997640296781, 0.9458860198867713], 
             UndirectedEdge[26, 75] -> 
             RGBColor[
              0.3903282545457113, 0.5125044484441559, 0.9460923491192976], 
             UndirectedEdge[170, 190] -> 
             RGBColor[
              0.9746335642264454, 0.9775820909240203, 0.7518614667375698], 
             UndirectedEdge[20, 36] -> 
             RGBColor[
              0.5126421236469364, 0.5928601557547035, 0.9593542519352827], 
             UndirectedEdge[119, 161] -> 
             RGBColor[
              0.6465164939387796, 0.7127825330594121, 0.8726976306719202], 
             UndirectedEdge[212, 225] -> 
             RGBColor[
              0.4965385877649196, 0.5932610378857271, 0.9557169257468504], 
             UndirectedEdge[102, 253] -> 
             RGBColor[
              0.40650136964019756`, 0.5265127878545995, 0.9471228857117941], 
             UndirectedEdge[91, 179] -> 
             RGBColor[
              0.4412500834371176, 0.5566103772243539, 0.9493370430278527], 
             UndirectedEdge[118, 239] -> 
             RGBColor[
              0.3169577572568276, 0.44329302454395836`, 0.9416245443398362], 
             UndirectedEdge[105, 298] -> 
             RGBColor[
              0.5872412998298551, 0.6564134078999712, 0.9451286975668929], 
             UndirectedEdge[90, 239] -> 
             RGBColor[
              0.6162892268503637, 0.6827866026567574, 0.9172712671020081], 
             UndirectedEdge[208, 252] -> 
             RGBColor[
              0.6782788727484117, 0.7424907348697397, 0.9305155276267825], 
             UndirectedEdge[117, 214] -> 
             RGBColor[
              0.42716932409202535`, 0.5429739429182467, 0.9488378130671709], 
             UndirectedEdge[179, 282] -> 
             RGBColor[
              0.4168620297834488, 0.5354866709287638, 0.9477830578145501], 
             UndirectedEdge[44, 268] -> 
             RGBColor[
              0.6655829996201064, 0.7354293508328639, 0.9695361616283533], 
             UndirectedEdge[53, 124] -> 
             RGBColor[
              0.514605851610417, 0.6155631117131493, 0.9552778758744473], 
             UndirectedEdge[42, 81] -> 
             RGBColor[
              0.36336226326852483`, 0.4891478621499872, 0.944374100000205], 
             UndirectedEdge[173, 213] -> 
             RGBColor[
              0.6043251745973658, 0.6761510329334726, 0.9563119892544723], 
             UndirectedEdge[119, 122] -> 
             RGBColor[
              0.8365463498657997, 0.8711278438740331, 0.8869237135332482], 
             UndirectedEdge[68, 111] -> 
             RGBColor[
              0.44801719485219577`, 0.5421615050729368, 0.9529696104611585], 
             UndirectedEdge[34, 53] -> 
             RGBColor[
              0.48071465520612744`, 0.5862082608088139, 0.9531183588083743], 
             UndirectedEdge[85, 263] -> 
             RGBColor[
              0.5423314752469724, 0.6392884652949062, 0.9571244316244178], 
             UndirectedEdge[37, 208] -> 
             RGBColor[
              0.37617393053205445`, 0.5002446844005367, 0.9451904481093246], 
             UndirectedEdge[256, 293] -> 
             RGBColor[
              0.32009986908801724`, 0.4407002832676305, 0.9420193387733082], 
             UndirectedEdge[76, 153] -> 
             RGBColor[
              0.5882583035982283, 0.6705450074524335, 0.9636467643666524], 
             UndirectedEdge[135, 213] -> 
             RGBColor[
              0.3063289415880046, 0.43538425092916433`, 0.9408997824489562], 
             UndirectedEdge[36, 55] -> 
             RGBColor[
              0.5504045970723777, 0.6229709270291159, 0.9629560703615593], 
             UndirectedEdge[121, 135] -> 
             RGBColor[
              0.6167049802574842, 0.6937609699698819, 0.9661145013098744], 
             UndirectedEdge[83, 226] -> 
             RGBColor[
              0.5171386980861179, 0.6113984328436348, 0.9574464886038618], 
             UndirectedEdge[60, 127] -> 
             RGBColor[
              0.8950212883779305, 0.9167527922608852, 0.8902073203120098], 
             UndirectedEdge[247, 271] -> 
             RGBColor[
              0.5018384380853979, 0.6033172009840944, 0.9548863114680107], 
             UndirectedEdge[202, 269] -> 
             RGBColor[
              0.7297055836374025, 0.7831888215109866, 0.7664874527195389], 
             UndirectedEdge[190, 284] -> 
             RGBColor[
              0.7357653532064133, 0.7878761377494986, 0.7479270605201331], 
             UndirectedEdge[53, 217] -> 
             RGBColor[
              0.6699987493036942, 0.74181789656012, 0.9679544689424138], 
             UndirectedEdge[42, 87] -> 
             RGBColor[
              0.4713697151039292, 0.5791918920480044, 0.9522251223210729], 
             UndirectedEdge[205, 225] -> 
             RGBColor[
              0.605691820670777, 0.6896332888892747, 0.9628765033014257], 
             UndirectedEdge[110, 246] -> 
             RGBColor[
              0.49607260413238474`, 0.6009481715035669, 0.953699733041478], 
             UndirectedEdge[191, 251] -> 
             RGBColor[
              0.6219975367529378, 0.6997843963126138, 0.9657891587258998], 
             UndirectedEdge[23, 83] -> 
             RGBColor[
              0.23539672905744033`, 0.3647472656269854, 0.9367168675303434], 
             UndirectedEdge[226, 291] -> 
             RGBColor[
              0.8531410363266743, 0.885636033143677, 0.96050058337275], 
             UndirectedEdge[60, 276] -> 
             RGBColor[
              0.5227111122136117, 0.6096061683939497, 0.958974813916866], 
             UndirectedEdge[27, 155] -> 
             RGBColor[
              0.4842263921033889, 0.5918581510742662, 0.952621470072402], 
             UndirectedEdge[167, 203] -> 
             RGBColor[
              0.5895788120757026, 0.6621973982853122, 0.9643318513122214], 
             UndirectedEdge[137, 271] -> 
             RGBColor[
              0.378442058295155, 0.5022092226695183, 0.9453349712047627], 
             UndirectedEdge[52, 247] -> 
             RGBColor[
              0.6219702832857439, 0.7037520942756301, 0.9635404697285511], 
             UndirectedEdge[81, 299] -> 
             RGBColor[
              0.6296165683764863, 0.7045836231061642, 0.9671032734628684], 
             UndirectedEdge[31, 290] -> 
             RGBColor[
              0.6497537269720584, 0.7217410009579355, 0.9685173280779555], 
             UndirectedEdge[79, 288] -> 
             RGBColor[
              0.7506830736008046, 0.3228450896542514, 0.4304866731449466], 
             UndirectedEdge[237, 281] -> 
             RGBColor[
              0.4492874395404127, 0.5564402513569681, 0.9511850911631378], 
             UndirectedEdge[43, 215] -> 
             RGBColor[
              0.6190053435012874, 0.6977189313599952, 0.9653562497194357], 
             UndirectedEdge[56, 295] -> 
             RGBColor[
              0.4854234577478137, 0.5931276569340644, 0.9526334592400747], 
             UndirectedEdge[89, 94] -> 
             RGBColor[
              0.3066288585935401, 0.43913442440347106`, 0.9407910922371445], 
             UndirectedEdge[92, 237] -> 
             RGBColor[
              0.7975271290620727, 0.8415988161948993, 0.9438093214840605], 
             UndirectedEdge[126, 285] -> 
             RGBColor[
              0.55602463542284, 0.6504448735174597, 0.958191442567288], 
             UndirectedEdge[4, 214] -> 
             RGBColor[
              0.5254148438348913, 0.6255944657509664, 0.9557817276461236], 
             UndirectedEdge[220, 222] -> 
             RGBColor[
              0.4944674969577214, 0.6004700153939908, 0.9533454391360858], 
             UndirectedEdge[199, 209] -> 
             RGBColor[
              0.3841649199062891, 0.5022984650210783, 0.9461742288233714], 
             UndirectedEdge[290, 291] -> 
             RGBColor[
              0.93246331810449, 0.9482584733064816, 0.9682327983978469], 
             UndirectedEdge[91, 150] -> 
             RGBColor[
              0.6390714894370777, 0.7149137066476077, 0.9667202480514436], 
             UndirectedEdge[60, 148] -> 
             RGBColor[
              0.7664119773109133, 0.8174461287128328, 0.9773524414373675], 
             UndirectedEdge[81, 140] -> 
             RGBColor[
              0.3096808116559553, 0.43748957032653724`, 0.9411425757460559], 
             UndirectedEdge[142, 256] -> 
             RGBColor[
              0.4795458597967297, 0.568290389370484, 0.9558748662499399], 
             UndirectedEdge[30, 123] -> 
             RGBColor[
              0.3344695468667467, 0.46412244339291764`, 0.9425330816599098], 
             UndirectedEdge[53, 289] -> 
             RGBColor[
              0.8079701421582135, 0.8466234798178929, 0.7641219462841317], 
             UndirectedEdge[274, 289] -> 
             RGBColor[
              0.5901388047371748, 0.6512301648235828, 0.7493891199259992], 
             UndirectedEdge[11, 114] -> 
             RGBColor[
              0.5399274668147583, 0.6323429538713305, 0.958991507521886], 
             UndirectedEdge[137, 247] -> 
             RGBColor[
              0.5340047990134228, 0.6311780860916407, 0.9569359235427484], 
             UndirectedEdge[84, 191] -> 
             RGBColor[
              0.7678251456263414, 0.8187154589632468, 0.977449413399583], 
             UndirectedEdge[17, 120] -> 
             RGBColor[
              0.35192207246126606`, 0.47783210421332345`, 0.9436966524496617],
              UndirectedEdge[126, 222] -> 
             RGBColor[
              0.5586259322119227, 0.6525567234379219, 0.9583962261793888], 
             UndirectedEdge[184, 224] -> 
             RGBColor[
              0.5029489529502839, 0.6066267947429069, 0.954214513490896], 
             UndirectedEdge[278, 295] -> 
             RGBColor[
              0.7330073921280417, 0.789349800004037, 0.9422440355129571], 
             UndirectedEdge[28, 245] -> 
             RGBColor[
              0.7157180671530053, 0.7713019811728162, 0.7568289459618742], 
             UndirectedEdge[14, 186] -> 
             RGBColor[
              0.3916409327878672, 0.5136414243603846, 0.946175991816132], 
             UndirectedEdge[227, 241] -> 
             RGBColor[
              0.5081811132085721, 0.6014257200010146, 0.9570246631626829], 
             UndirectedEdge[121, 154] -> 
             RGBColor[
              0.6400972192102075, 0.7140221516226153, 0.9676050340909972], 
             UndirectedEdge[187, 230] -> 
             RGBColor[
              0.5685570938273063, 0.6585011836993042, 0.9602398552864024], 
             UndirectedEdge[125, 277] -> 
             RGBColor[
              0.7443891802711855, 0.8000131461429183, 0.9756097626245869], 
             UndirectedEdge[62, 158] -> 
             RGBColor[
              0.6119269619106216, 0.6907942953611835, 0.9652706041216115], 
             UndirectedEdge[20, 61] -> 
             RGBColor[
              0.7813599995559709, 0.829336802439514, 0.9787857531237052], 
             UndirectedEdge[64, 258] -> 
             RGBColor[
              0.34986875651354243`, 0.47746046480219057`, 0.9435143056816171],
              UndirectedEdge[94, 294] -> 
             RGBColor[
              0.6208925636856872, 0.6958224413660179, 0.9671020634320254], 
             UndirectedEdge[125, 237] -> 
             RGBColor[
              0.7630021693172435, 0.815124009156109, 0.9770750453039181], 
             UndirectedEdge[267, 300] -> 
             RGBColor[
              0.879001774311357, 0.9063561712410688, 0.9883211679996062], 
             UndirectedEdge[165, 175] -> 
             RGBColor[
              0.6986848265447377, 0.7608831652790696, 0.9422919254327795], 
             UndirectedEdge[67, 263] -> 
             RGBColor[
              0.6041880717649197, 0.6895461208780411, 0.9619830447046172], 
             UndirectedEdge[163, 298] -> 
             RGBColor[
              0.6125189859156689, 0.6829818586740268, 0.9465682243944945], 
             UndirectedEdge[92, 149] -> 
             RGBColor[
              0.8167056500379901, 0.8569472550040439, 0.945470598829073], 
             UndirectedEdge[95, 276] -> 
             RGBColor[
              0.5997214540277361, 0.6703940318191051, 0.9507869733963985], 
             UndirectedEdge[70, 231] -> 
             RGBColor[
              0.270918516604965, 0.40208291655084594`, 0.9387397807813995], 
             UndirectedEdge[239, 263] -> 
             RGBColor[
              0.44015877883041765`, 0.5451300241509401, 0.9508213761853259], 
             UndirectedEdge[116, 204] -> 
             RGBColor[
              0.9116340866867755, 0.9301678693859678, 0.9064817764511393], 
             UndirectedEdge[121, 258] -> 
             RGBColor[
              0.6311944240531939, 0.7063109979251054, 0.967037755856025], 
             UndirectedEdge[95, 148] -> 
             RGBColor[
              0.8434223191250378, 0.8782339921379883, 0.9691646009168999], 
             UndirectedEdge[60, 77] -> 
             RGBColor[
              0.7266767548572841, 0.786404670933182, 0.9733920058099556], 
             UndirectedEdge[42, 269] -> 
             RGBColor[
              0.41287308820611096`, 0.5317016950893447, 0.9476200535714718], 
             UndirectedEdge[61, 136] -> 
             RGBColor[
              0.6937723235902253, 0.7606994791444157, 0.970112399610648], 
             UndirectedEdge[95, 251] -> 
             RGBColor[
              0.6783380711251542, 0.7442594966458711, 0.9555850244186133], 
             UndirectedEdge[158, 265] -> 
             RGBColor[
              0.3624044251463324, 0.488318230910888, 0.944313067402042], 
             UndirectedEdge[152, 208] -> 
             RGBColor[
              0.4459117912449998, 0.5589209027015907, 0.9501113166168613], 
             UndirectedEdge[153, 285] -> 
             RGBColor[
              0.6728020854673618, 0.7423776448578205, 0.96941924468054], 
             UndirectedEdge[61, 279] -> 
             RGBColor[
              0.8528071072090952, 0.8840852555885146, 0.9000793068116726], 
             UndirectedEdge[82, 168] -> 
             RGBColor[
              0.35959793877938917`, 0.48542661894468864`, 0.9441511117852412],
              UndirectedEdge[4, 249] -> 
             RGBColor[
              0.3961263034574848, 0.5094157564428939, 0.9473519491260662], 
             UndirectedEdge[75, 163] -> 
             RGBColor[
              0.3059160698232972, 0.43546271686390986`, 0.9408575077940533], 
             UndirectedEdge[59, 290] -> 
             RGBColor[
              0.781163843952394, 0.8296256698178015, 0.9786488809265113], 
             UndirectedEdge[205, 251] -> 
             RGBColor[
              0.44928710375140446`, 0.5624393090441322, 0.9501620213464148], 
             UndirectedEdge[183, 224] -> 
             RGBColor[
              0.5393453123771729, 0.6369038476740467, 0.9568783851587597], 
             UndirectedEdge[170, 178] -> 
             RGBColor[
              0.6109679083064132, 0.6818250675327003, 0.9491937942011339], 
             UndirectedEdge[102, 238] -> 
             RGBColor[
              0.6525475503641636, 0.7228924518644746, 0.9681188100144821], 
             UndirectedEdge[89, 236] -> 
             RGBColor[
              0.43144505480562384`, 0.5442496566946213, 0.9495715993204878], 
             UndirectedEdge[65, 231] -> 
             RGBColor[
              0.49537300006878693`, 0.592101164542834, 0.9556402198745487], 
             UndirectedEdge[25, 245] -> 
             RGBColor[
              0.792172080358198, 0.8337960946800621, 0.7627301739050567], 
             UndirectedEdge[217, 223] -> 
             RGBColor[
              0.6751635598057173, 0.746010922397724, 0.9683610617444574], 
             UndirectedEdge[254, 283] -> 
             RGBColor[
              0.6524066044773047, 0.7257802701240641, 0.9678589915167362], 
             UndirectedEdge[168, 205] -> 
             RGBColor[
              0.45522721957148493`, 0.5675843388085837, 0.9505405202738322], 
             UndirectedEdge[142, 243] -> 
             RGBColor[
              0.506060373144913, 0.5961588240166676, 0.9573848285604116], 
             UndirectedEdge[57, 278] -> 
             RGBColor[
              0.6843179937529376, 0.748265603110693, 0.9388409413000087], 
             UndirectedEdge[185, 218] -> 
             RGBColor[
              0.3307387152691691, 0.4608909845801443, 0.9422953563695569], 
             UndirectedEdge[16, 248] -> 
             RGBColor[
              0.5692855245052846, 0.6603695956182305, 0.9597625092641336], 
             UndirectedEdge[184, 275] -> 
             RGBColor[
              0.3768172682577513, 0.5008019112034411, 0.9452314410203249], 
             UndirectedEdge[127, 191] -> 
             RGBColor[
              0.9156910958198385, 0.9330655553527833, 0.8922236140988289], 
             UndirectedEdge[33, 153] -> 
             RGBColor[
              0.6918098608022829, 0.7578090131652302, 0.9709156063826803], 
             UndirectedEdge[83, 243] -> 
             RGBColor[
              0.2674640287358686, 0.3984520307732443, 0.9385430528077113], 
             UndirectedEdge[94, 281] -> 
             RGBColor[
              0.29703654673462376`, 0.42905229645205084`, 0.9402448242673329],
              UndirectedEdge[140, 293] -> 
             RGBColor[
              0.35154022221510867`, 0.47374608783772715`, 0.9438098203720617],
              UndirectedEdge[126, 220] -> 
             RGBColor[
              0.5431983712504317, 0.6400319344456824, 0.9571817120674824], 
             UndirectedEdge[76, 220] -> 
             RGBColor[
              0.40732241829950533`, 0.5265255280681416, 0.9473681752100976], 
             UndirectedEdge[90, 126] -> 
             RGBColor[
              0.7962120907062856, 0.8401058162550775, 0.9296841357443022], 
             UndirectedEdge[35, 102] -> 
             RGBColor[
              0.4916872520992007, 0.595899430011108, 0.953765783237453], 
             UndirectedEdge[105, 235] -> 
             RGBColor[
              0.3826378572803284, 0.494627580917152, 0.9466394157572614], 
             UndirectedEdge[21, 287] -> 
             RGBColor[
              0.9676644181996683, 0.9736970047943927, 0.8631432719343695], 
             UndirectedEdge[160, 245] -> 
             RGBColor[
              0.7897459701295199, 0.831826469101401, 0.7625391816207205], 
             UndirectedEdge[235, 298] -> 
             RGBColor[
              0.7541747333255668, 0.8069915845961435, 0.956172693446943], 
             UndirectedEdge[15, 196] -> 
             RGBColor[
              0.5097570133470091, 0.6117570474743095, 0.9548601162995971], 
             UndirectedEdge[13, 274] -> 
             RGBColor[
              0.4416861129133074, 0.5382365111501324, 0.9521769646563245], 
             UndirectedEdge[2, 172] -> 
             RGBColor[
              0.5963374184234113, 0.6802353787120305, 0.9629951969161381], 
             UndirectedEdge[247, 295] -> 
             RGBColor[
              0.5753967684714357, 0.6659416168364425, 0.9598740320379626], 
             UndirectedEdge[159, 225] -> 
             RGBColor[
              0.7891975302655174, 0.8355862366832028, 0.979533303799428], 
             UndirectedEdge[204, 254] -> 
             RGBColor[
              0.840221131040655, 0.8754335389695298, 0.9846222356245579], 
             UndirectedEdge[61, 252] -> 
             RGBColor[
              0.8490133944660768, 0.8820964713942323, 0.9441430920721918], 
             UndirectedEdge[4, 173] -> 
             RGBColor[
              0.7457851843743135, 0.8005659895695438, 0.9658496976516759], 
             UndirectedEdge[230, 245] -> 
             RGBColor[
              0.7060868909898477, 0.7629599404572782, 0.7562152559332724], 
             UndirectedEdge[137, 295] -> 
             RGBColor[
              0.45200038868119286`, 0.5648336385218664, 0.9503226917747147], 
             UndirectedEdge[109, 192] -> 
             RGBColor[
              0.2708273607556393, 0.4019871059735899, 0.9387345895906334], 
             UndirectedEdge[178, 229] -> 
             RGBColor[
              0.5741918976300968, 0.6530160272343566, 0.9635467210695288], 
             UndirectedEdge[91, 93] -> 
             RGBColor[
              0.3995336335561146, 0.5204776850671653, 0.9466789077298434], 
             UndirectedEdge[143, 185] -> 
             RGBColor[
              0.4805503345880495, 0.5863455491257622, 0.9530306301030641], 
             UndirectedEdge[139, 273] -> 
             RGBColor[
              0.6129279849199932, 0.694605293545252, 0.9640523331428384], 
             UndirectedEdge[130, 281] -> 
             RGBColor[
              0.4988854388051791, 0.5955526178019592, 0.9558782978177958], 
             UndirectedEdge[220, 248] -> 
             RGBColor[
              0.584312471986567, 0.6726867713821314, 0.9609129860735903], 
             UndirectedEdge[88, 273] -> 
             RGBColor[
              0.34726242920055617`, 0.4690502037574979, 0.9435735166404835], 
             UndirectedEdge[24, 218] -> 
             RGBColor[
              0.4057760022820962, 0.5246355214640048, 0.9474217655048894], 
             UndirectedEdge[66, 215] -> 
             RGBColor[
              0.4092675969222994, 0.5289087548917304, 0.9472991472681309], 
             UndirectedEdge[151, 154] -> 
             RGBColor[
              0.6616560603323259, 0.7312125863342398, 0.9696613356030296], 
             UndirectedEdge[8, 64] -> 
             RGBColor[
              0.3204532104284204, 0.4519821972515925, 0.9416399730962193], 
             UndirectedEdge[71, 108] -> 
             RGBColor[
              0.6304561293109942, 0.7062308120108034, 0.9667332414341867], 
             UndirectedEdge[43, 182] -> 
             RGBColor[
              0.5834157000391351, 0.6668929709805707, 0.9630885091087134], 
             UndirectedEdge[58, 297] -> 
             RGBColor[
              0.5200860858969475, 0.6202977620072654, 0.9556304018923574], 
             UndirectedEdge[46, 207] -> 
             RGBColor[
              0.3650944841833905, 0.48050293299476265`, 0.9452476094798365], 
             UndirectedEdge[100, 266] -> 
             RGBColor[
              0.5923574218071657, 0.6769419906652381, 0.9626764636334837], 
             UndirectedEdge[12, 151] -> 
             RGBColor[
              0.5524713355999294, 0.6246953299987714, 0.9631416173255616], 
             UndirectedEdge[196, 265] -> 
             RGBColor[
              0.47841445931635107`, 0.5846097024955237, 0.9528629964718958], 
             UndirectedEdge[93, 139] -> 
             RGBColor[
              0.5624938633765739, 0.6509217923569963, 0.9608387155152344], 
             UndirectedEdge[30, 104] -> 
             RGBColor[
              0.6296654970279141, 0.7032584099534437, 0.9677359691890168], 
             UndirectedEdge[85, 121] -> 
             RGBColor[
              0.6670759113471512, 0.7373897387631421, 0.9693240924976425], 
             UndirectedEdge[79, 160] -> 
             RGBColor[
              0.6015607518733201, 0.6874131442306282, 0.9617762124585605], 
             UndirectedEdge[60, 196] -> 
             RGBColor[
              0.7033781611941119, 0.7676719989344187, 0.9714333004952025], 
             UndirectedEdge[25, 297] -> 
             RGBColor[
              0.5040674306090432, 0.6072930960123477, 0.9543693546698259], 
             UndirectedEdge[9, 133] -> 
             RGBColor[
              0.3289147107242811, 0.45691231009803945`, 0.9422669647231348], 
             UndirectedEdge[151, 192] -> 
             RGBColor[
              0.5961798340004955, 0.6706357330966264, 0.965630751648545], 
             UndirectedEdge[45, 141] -> 
             RGBColor[
              0.8780298512537269, 0.9047512120942842, 0.9463702454328939], 
             UndirectedEdge[177, 280] -> 
             RGBColor[
              0.7048207504825489, 0.7681567571017419, 0.9721874272222238], 
             UndirectedEdge[141, 188] -> 
             RGBColor[
              0.7602090481584314, 0.8111102440190192, 0.9357198455485393], 
             UndirectedEdge[129, 183] -> 
             RGBColor[
              0.47081635183090426`, 0.5809715485929774, 0.9515657073346995], 
             UndirectedEdge[41, 55] -> 
             RGBColor[
              0.8031933782884635, 0.8470036438741912, 0.9807999082568419], 
             UndirectedEdge[120, 261] -> 
             RGBColor[
              0.44012246835956087`, 0.5551826223177951, 0.9493898247645516], 
             UndirectedEdge[71, 279] -> 
             RGBColor[
              0.692066101801248, 0.7531354006028518, 0.8870885203886054], 
             UndirectedEdge[180, 230] -> 
             RGBColor[
              0.38690452527376945`, 0.5095389862304367, 0.9458741921175744], 
             UndirectedEdge[106, 194] -> 
             RGBColor[
              0.29897003605493, 0.4311347936356579, 0.9403530927248942], 
             UndirectedEdge[90, 234] -> 
             RGBColor[
              0.6407530817633654, 0.7084996652683108, 0.9186644474482735], 
             UndirectedEdge[44, 136] -> 
             RGBColor[
              0.7864410523008666, 0.8337534760196299, 0.9791734809153108], 
             UndirectedEdge[120, 131] -> 
             RGBColor[
              0.3969886965233348, 0.518273388521626, 0.9465167465925142], 
             UndirectedEdge[44, 279] -> 
             RGBColor[
              0.9454758359197366, 0.9571392524637288, 0.9091403881163354], 
             UndirectedEdge[105, 139] -> 
             RGBColor[
              0.4946169080519537, 0.5835278558163572, 0.9568286293632944], 
             UndirectedEdge[157, 184] -> 
             RGBColor[
              0.4422135729733768, 0.5573190771799663, 0.9494332018980864], 
             UndirectedEdge[83, 149] -> 
             RGBColor[
              0.47434402628933386`, 0.5779669099844351, 0.9531811156581038], 
             UndirectedEdge[145, 168] -> 
             RGBColor[
              0.5799318272483817, 0.667261558053749, 0.9614267650735588], 
             UndirectedEdge[112, 170] -> 
             RGBColor[
              0.572854296658536, 0.6417652451482301, 0.9470232804018228], 
             UndirectedEdge[159, 270] -> 
             RGBColor[
              0.5927521266783702, 0.6737110265498618, 0.9642674646965355], 
             UndirectedEdge[86, 162] -> 
             RGBColor[
              0.5964607017111339, 0.6661745564640482, 0.9460605227731671], 
             UndirectedEdge[3, 264] -> 
             RGBColor[
              0.6940200144259447, 0.759218626178195, 0.9715323680605027], 
             UndirectedEdge[60, 282] -> 
             RGBColor[
              0.598967483006885, 0.6814273065014941, 0.9636224721316644], 
             UndirectedEdge[135, 186] -> 
             RGBColor[
              0.39683344386163905`, 0.5181389164692908, 0.9465068540301955], 
             UndirectedEdge[89, 294] -> 
             RGBColor[
              0.6135586553788532, 0.6885963644827131, 0.966666747895284], 
             UndirectedEdge[201, 203] -> 
             RGBColor[
              0.7329277973743076, 0.7904622148343039, 0.9738074223406649], 
             UndirectedEdge[181, 203] -> 
             RGBColor[
              0.7629587672311915, 0.814842709043897, 0.9761715702948661], 
             UndirectedEdge[70, 211] -> 
             RGBColor[
              0.562880959453024, 0.6440871184705963, 0.962454220172891], 
             UndirectedEdge[156, 159] -> 
             RGBColor[
              0.8481053557923741, 0.881720205774971, 0.9853742400197073], 
             UndirectedEdge[56, 270] -> 
             RGBColor[
              0.40046325100009805`, 0.5206275088521999, 0.9469192211906401], 
             UndirectedEdge[113, 264] -> 
             RGBColor[
              0.5604007493972032, 0.6539975999835357, 0.9585359462895836], 
             UndirectedEdge[144, 240] -> 
             RGBColor[
              0.27495388018560296`, 0.40632433953092495`, 0.9389695887675314],
              UndirectedEdge[231, 232] -> 
             RGBColor[
              0.3345452458124909, 0.46105563869166616`, 0.9426525965882413], 
             UndirectedEdge[90, 248] -> 
             RGBColor[
              0.8373261914424209, 0.8727606531915265, 0.9334154097504102], 
             UndirectedEdge[27, 109] -> 
             RGBColor[
              0.40040298872246843`, 0.5161074945131049, 0.9473955453952171], 
             UndirectedEdge[42, 145] -> 
             RGBColor[
              0.5523531435085451, 0.6433742883432514, 0.959669475732529], 
             UndirectedEdge[160, 230] -> 
             RGBColor[
              0.5020512038045545, 0.6056784908543795, 0.9542044797948334], 
             UndirectedEdge[247, 251] -> 
             RGBColor[
              0.5304772483914948, 0.6281226990427763, 0.9567111511364097], 
             UndirectedEdge[109, 220] -> 
             RGBColor[
              0.3768740114095792, 0.4970056107621529, 0.9455432581116626], 
             UndirectedEdge[139, 163] -> 
             RGBColor[
              0.5198945941377675, 0.6100963065904129, 0.9582681561908961], 
             UndirectedEdge[31, 279] -> 
             RGBColor[
              0.6938517074656256, 0.7546820024821855, 0.8872022976025904], 
             UndirectedEdge[9, 112] -> 
             RGBColor[
              0.23641667329563992`, 0.365819291689533, 0.9367749518458366], 
             UndirectedEdge[196, 276] -> 
             RGBColor[
              0.4269871327649881, 0.5342942345662728, 0.9497974230007302], 
             UndirectedEdge[137, 251] -> 
             RGBColor[
              0.407080868601252, 0.5270147207282003, 0.9471598108731617], 
             UndirectedEdge[162, 181] -> 
             RGBColor[
              0.7736253805922066, 0.8227978518235657, 0.9581157761729868], 
             UndirectedEdge[96, 236] -> 
             RGBColor[
              0.44449047425783567`, 0.5564227574631552, 0.9503708472969219], 
             UndirectedEdge[251, 295] -> 
             RGBColor[
              0.4484728380592649, 0.5617782514730019, 0.9500979193683761], 
             UndirectedEdge[20, 268] -> 
             RGBColor[
              0.637911518647367, 0.7133648630275428, 0.9668968310705508], 
             UndirectedEdge[187, 215] -> 
             RGBColor[
              0.5657966501844768, 0.6561102261598168, 0.9600639622584459], 
             UndirectedEdge[55, 250] -> 
             RGBColor[
              0.5855622179090219, 0.659923815650338, 0.9649582448571671], 
             UndirectedEdge[193, 230] -> 
             RGBColor[
              0.3611742935830652, 0.4868099273124258, 0.9442508985161586], 
             UndirectedEdge[55, 242] -> 
             RGBColor[
              0.7976745091693218, 0.842692261373359, 0.98024983895981], 
             UndirectedEdge[51, 116] -> 
             RGBColor[
              0.6732928039710374, 0.7368903716150823, 0.8864604657257407], 
             UndirectedEdge[130, 203] -> 
             RGBColor[
              0.8273202549423199, 0.8659407404972199, 0.9820270128404618], 
             UndirectedEdge[34, 124] -> 
             RGBColor[
              0.37316460295088305`, 0.4976381561029281, 0.9449986964168964], 
             UndirectedEdge[190, 261] -> 
             RGBColor[
              0.7317608605879752, 0.7846251102415138, 0.7476118121922699], 
             UndirectedEdge[76, 85] -> 
             RGBColor[
              0.3937306861143396, 0.5154514636577188, 0.9463091490501985], 
             UndirectedEdge[130, 237] -> 
             RGBColor[
              0.6680625517767185, 0.7402487775416015, 0.9678001482201537], 
             UndirectedEdge[175, 183] -> 
             RGBColor[
              0.46345105765537786`, 0.5745921009685855, 0.9510963973027089], 
             UndirectedEdge[93, 289] -> 
             RGBColor[
              0.6726213574423113, 0.7339755102595042, 0.7542309732417145], 
             UndirectedEdge[69, 234] -> 
             RGBColor[
              0.30433673183260335`, 0.4368850277476889, 0.9406547089038856], 
             UndirectedEdge[32, 269] -> 
             RGBColor[
              0.5405459061138831, 0.6378785437556396, 0.9569729002956333], 
             UndirectedEdge[226, 243] -> 
             RGBColor[
              0.49273626870710585`, 0.5857499323629083, 0.9560568063508863], 
             UndirectedEdge[72, 218] -> 
             RGBColor[
              0.3550363503246256, 0.48193637483053386`, 0.9438435801897356], 
             UndirectedEdge[81, 181] -> 
             RGBColor[
              0.4776929600082329, 0.5844929757963386, 0.9526766060722163], 
             UndirectedEdge[8, 67] -> 
             RGBColor[
              0.4484160347647668, 0.5594977447754057, 0.9507108165575648], 
             UndirectedEdge[145, 156] -> 
             RGBColor[
              0.7893042538745303, 0.8354444772262082, 0.9796036843214317], 
             UndirectedEdge[20, 177] -> 
             RGBColor[
              0.6926817491245397, 0.7584774469232793, 0.9710295984360825], 
             UndirectedEdge[180, 297] -> 
             RGBColor[
              0.38649464184958016`, 0.5091839658097437, 0.9458480747082307], 
             UndirectedEdge[140, 216] -> 
             RGBColor[
              0.2548830728556566, 0.3852286484644669, 0.9378265859821896], 
             UndirectedEdge[287, 300] -> 
             RGBColor[
              0.9146334967262718, 0.9346349129619443, 0.987107640000737], 
             UndirectedEdge[140, 167] -> 
             RGBColor[
              0.24754547211146163`, 0.37751636485156037`, 0.9374087204748152],
              UndirectedEdge[248, 285] -> 
             RGBColor[
              0.5971387361589753, 0.6830997104539087, 0.9619227165733961], 
             UndirectedEdge[185, 292] -> 
             RGBColor[
              0.44034144135748676`, 0.5537021582111937, 0.9498652387379252], 
             UndirectedEdge[23, 241] -> 
             RGBColor[
              0.22437239895652406`, 0.3531599957080227, 0.9360890482401312], 
             UndirectedEdge[10, 48] -> 
             RGBColor[
              0.7930304953514318, 0.8384152937576846, 0.9799591993311162], 
             UndirectedEdge[46, 62] -> 
             RGBColor[
              0.680859520160612, 0.7488661511778187, 0.9701144218365642], 
             UndirectedEdge[15, 276] -> 
             RGBColor[
              0.32908996436650895`, 0.4536912169338404, 0.9424016297212605], 
             UndirectedEdge[85, 154] -> 
             RGBColor[
              0.4248777794889551, 0.5424295104403789, 0.9482938142977357], 
             UndirectedEdge[32, 179] -> 
             RGBColor[
              0.5252565260756096, 0.6249656063682342, 0.9559075069325151], 
             UndirectedEdge[145, 277] -> 
             RGBColor[
              0.6628343396485572, 0.7355942039847438, 0.9676689350161467], 
             UndirectedEdge[58, 164] -> 
             RGBColor[
              0.5215365040812325, 0.6215540413383556, 0.9557228212565057], 
             UndirectedEdge[18, 253] -> 
             RGBColor[
              0.4434692261688207, 0.5585324871211983, 0.949478444840406], 
             UndirectedEdge[59, 136] -> 
             RGBColor[
              0.6662270408270914, 0.7391808948979528, 0.9673669432501215], 
             UndirectedEdge[232, 288] -> 
             RGBColor[
              0.676287258668626, 0.2613775177794503, 0.42492552276735507`], 
             UndirectedEdge[136, 177] -> 
             RGBColor[
              0.6050940731587942, 0.689840123628181, 0.9623562449230252], 
             UndirectedEdge[31, 65] -> 
             RGBColor[
              0.5571656184248002, 0.6487551960988247, 0.9594628994166802], 
             UndirectedEdge[62, 214] -> 
             RGBColor[
              0.6772931024011174, 0.7459707725753719, 0.969833660366318], 
             UndirectedEdge[24, 109] -> 
             RGBColor[
              0.38701270817035316`, 0.5052366615356332, 0.9463414134599407], 
             UndirectedEdge[71, 268] -> 
             RGBColor[
              0.4121732655016179, 0.5314254989719869, 0.9474842939006233], 
             UndirectedEdge[64, 118] -> 
             RGBColor[
              0.3530242258549833, 0.4801935737472461, 0.9437153693977818], 
             UndirectedEdge[21, 206] -> 
             RGBColor[
              0.7302754612935402, 0.7847026235253735, 0.8462001926876965], 
             UndirectedEdge[6, 124] -> 
             RGBColor[
              0.36035606012168914`, 0.48654404008036156`, 0.9441825473939698],
              UndirectedEdge[7, 140] -> 
             RGBColor[
              0.33340869722267874`, 0.45804147220622815`, 0.9426544956326222],
              UndirectedEdge[78, 229] -> 
             RGBColor[
              0.8568428217889559, 0.888687223988449, 0.9862076273264893], 
             UndirectedEdge[67, 213] -> 
             RGBColor[
              0.41855646919561895`, 0.5292706753055593, 0.9489679867169236], 
             UndirectedEdge[189, 300] -> 
             RGBColor[
              0.6389115554746536, 0.7127849374938142, 0.9676262750959358], 
             UndirectedEdge[77, 225] -> 
             RGBColor[
              0.6853070604449509, 0.7540863512369446, 0.9692686612927088], 
             UndirectedEdge[153, 239] -> 
             RGBColor[
              0.5442113926932328, 0.6267322002316542, 0.9610474325817431], 
             UndirectedEdge[7, 168] -> 
             RGBColor[
              0.4146688325750848, 0.5335870337401758, 0.9476433092278012], 
             UndirectedEdge[5, 256] -> 
             RGBColor[
              0.49250683727754124`, 0.5784156034855712, 0.9571666953580062], 
             UndirectedEdge[193, 200] -> 
             RGBColor[
              0.5069740418650398, 0.6050890050727588, 0.956175115273121], 
             UndirectedEdge[17, 202] -> 
             RGBColor[
              0.6437354972927234, 0.7076489691764406, 0.7609698585426027], 
             UndirectedEdge[12, 220] -> 
             RGBColor[
              0.32928478694172436`, 0.4469863185153334, 0.9428331221801669], 
             UndirectedEdge[196, 207] -> 
             RGBColor[
              0.4121719601034187, 0.5187225487627631, 0.9489537208347376], 
             UndirectedEdge[222, 285] -> 
             RGBColor[
              0.5072937611301298, 0.6108829544657681, 0.9543551696358916], 
             UndirectedEdge[169, 227] -> 
             RGBColor[
              0.5974361954481088, 0.682333164408311, 0.9625801345306233], 
             UndirectedEdge[139, 298] -> 
             RGBColor[
              0.8661537840971921, 0.8958918594953488, 0.9663619070529761], 
             UndirectedEdge[210, 241] -> 
             RGBColor[
              0.5857382450656654, 0.6626740869952219, 0.9645796507679503], 
             UndirectedEdge[58, 288] -> 
             RGBColor[
              0.7524126046591304, 0.3242492008818867, 0.43062282816533903`], 
             UndirectedEdge[85, 258] -> 
             RGBColor[
              0.4159749843319416, 0.534718356742869, 0.9477265360627636], 
             UndirectedEdge[87, 162] -> 
             RGBColor[
              0.7703882168166158, 0.8201697764379748, 0.9578609347824507], 
             UndirectedEdge[222, 248] -> 
             RGBColor[
              0.599740032948058, 0.6852115603743709, 0.9621275001854968], 
             UndirectedEdge[76, 87] -> 
             RGBColor[
              0.45903407433541343`, 0.5685073800216485, 0.951439106199282], 
             UndirectedEdge[80, 282] -> 
             RGBColor[
              0.4032333874713576, 0.5236822259535101, 0.9469146527777588], 
             UndirectedEdge[273, 289] -> 
             RGBColor[
              0.7230554789857306, 0.77765901144776, 0.7574445908693186], 
             UndirectedEdge[215, 296] -> 
             RGBColor[
              0.616507408888175, 0.6957271461041282, 0.9651179944861046], 
             UndirectedEdge[142, 277] -> 
             RGBColor[
              0.6751488606764029, 0.7452144014055231, 0.9688963313864605], 
             UndirectedEdge[134, 180] -> 
             RGBColor[
              0.38725900795524026`, 0.509846021312309, 0.945896779440581], 
             UndirectedEdge[86, 178] -> 
             RGBColor[
              0.25043400690666345`, 0.38055239806500135`, 0.9375732182581977],
              UndirectedEdge[3, 210] -> 
             RGBColor[
              0.897866467684731, 0.921398365668537, 0.9901204992942694], 
             UndirectedEdge[79, 176] -> 
             RGBColor[
              0.738570529467906, 0.7956352607091453, 0.9747535064787658], 
             UndirectedEdge[131, 141] -> 
             RGBColor[
              0.6830345265402051, 0.7465651960315205, 0.9301669548582877], 
             UndirectedEdge[150, 256] -> 
             RGBColor[
              0.5102833094281366, 0.5923879907316465, 0.9589158593790419], 
             UndirectedEdge[74, 300] -> 
             RGBColor[
              0.7472390396328574, 0.8024652198571689, 0.9756747841776219], 
             UndirectedEdge[25, 230] -> 
             RGBColor[
              0.5044773140332326, 0.6076481164330406, 0.9543954720791695], 
             UndirectedEdge[165, 253] -> 
             RGBColor[
              0.7073114578220039, 0.7683551197043424, 0.9428416067495364], 
             UndirectedEdge[223, 295] -> 
             RGBColor[
              0.5629389415044568, 0.6560582186804556, 0.9587357620699707], 
             UndirectedEdge[164, 221] -> 
             RGBColor[
              0.5425303607315093, 0.6382572872418231, 0.957608344939331], 
             UndirectedEdge[70, 138] -> 
             RGBColor[
              0.42569800863037655`, 0.5357176229916594, 0.9494711075348632], 
             UndirectedEdge[165, 224] -> 
             RGBColor[
              0.7745790812665327, 0.823194911984531, 0.9480739132888303], 
             UndirectedEdge[87, 258] -> 
             RGBColor[
              0.4812783725530154, 0.5877742731067988, 0.952856493211847], 
             UndirectedEdge[90, 222] -> 
             RGBColor[
              0.7474812164135753, 0.8005438972033859, 0.9258478628129057], 
             UndirectedEdge[163, 185] -> 
             RGBColor[
              0.3077512757240841, 0.4370522799750409, 0.9409744454912425], 
             UndirectedEdge[64, 286] -> 
             RGBColor[
              0.4449537099285608, 0.5566429304450076, 0.9504503912598542], 
             UndirectedEdge[131, 199] -> 
             RGBColor[
              0.326567745229015, 0.4536471892296736, 0.9421625385984964], 
             UndirectedEdge[2, 49] -> 
             RGBColor[
              0.36265893994479104`, 0.48830073520220935`, 0.9443379971420076],
              UndirectedEdge[51, 283] -> 
             RGBColor[
              0.4079292055083489, 0.5276099998133013, 0.94725241254533], 
             UndirectedEdge[66, 187] -> 
             RGBColor[
              0.5621930097275529, 0.6529889339202652, 0.9598343414751047], 
             UndirectedEdge[120, 170] -> 
             RGBColor[
              0.6829951719980312, 0.7481396030003014, 0.9536394793098515], 
             UndirectedEdge[17, 182] -> 
             RGBColor[
              0.3176108860189853, 0.4481134790473934, 0.9415103739897505], 
             UndirectedEdge[156, 179] -> 
             RGBColor[
              0.6345348185338227, 0.7108589465848962, 0.9664888687972566], 
             UndirectedEdge[199, 284] -> 
             RGBColor[
              0.3737060096836793, 0.4938074505338275, 0.945350865098397], 
             UndirectedEdge[210, 291] -> 
             RGBColor[
              0.9327649134071381, 0.9484989572142268, 0.9682615648270508], 
             UndirectedEdge[212, 265] -> 
             RGBColor[
              0.31294458029949196`, 0.44251706114306943`, 0.9412699662407904],
              UndirectedEdge[85, 173] -> 
             RGBColor[
              0.6994817735455929, 0.7629351107919538, 0.962215488322129], 
             UndirectedEdge[47, 146] -> 
             RGBColor[
              0.5794452108002351, 0.669053871341615, 0.9603120149613835], 
             UndirectedEdge[198, 283] -> 
             RGBColor[
              0.606025713957049, 0.6893340008021513, 0.9632927452775815], 
             UndirectedEdge[168, 212] -> 
             RGBColor[
              0.34607398666562755`, 0.4712120878050362, 0.9433809427192568], 
             UndirectedEdge[56, 271] -> 
             RGBColor[
              0.41186512736177583`, 0.5305032410817163, 0.9476457386701228], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.24958682693815948`, 0.3786543621642321, 0.9375618656391214], 
             UndirectedEdge[159, 191] -> 
             RGBColor[
              0.8512370321197587, 0.8842173194713382, 0.9856729421034938], 
             UndirectedEdge[72, 83] -> 
             RGBColor[
              0.3448522418588588, 0.47155478296787035`, 0.9432518000755574], 
             UndirectedEdge[179, 277] -> 
             RGBColor[
              0.5080649043078496, 0.6110086733434319, 0.9545541194919716], 
             UndirectedEdge[86, 182] -> 
             RGBColor[
              0.2881500841560007, 0.4171483083666724, 0.9398326249070041], 
             UndirectedEdge[80, 293] -> 
             RGBColor[
              0.42890055754361256`, 0.5459138386006192, 0.9485501421581756], 
             UndirectedEdge[9, 96] -> 
             RGBColor[
              0.3040932815609598, 0.4354132357180748, 0.9406853652055759], 
             UndirectedEdge[51, 226] -> 
             RGBColor[
              0.5499066937066581, 0.6413410526605902, 0.959477294037395], 
             UndirectedEdge[185, 235] -> 
             RGBColor[
              0.4494070231339822, 0.5610620058971576, 0.9505789145436911], 
             UndirectedEdge[136, 210] -> 
             RGBColor[
              0.7864202937903321, 0.8337369237468044, 0.9791715009500446], 
             UndirectedEdge[78, 284] -> 
             RGBColor[
              0.6547506214452403, 0.7277903111122712, 0.9679202942406577], 
             UndirectedEdge[81, 216] -> 
             RGBColor[
              0.3116506055969391, 0.43955994865066045`, 0.9412547525969459], 
             UndirectedEdge[2, 165] -> 
             RGBColor[
              0.6944403813881583, 0.7572068402164569, 0.9420214731406178], 
             UndirectedEdge[181, 216] -> 
             RGBColor[
              0.4228952212079342, 0.5322320539342683, 0.9493606163083499], 
             UndirectedEdge[7, 203] -> 
             RGBColor[
              0.6754420371869198, 0.74272250563998, 0.9695776264700283], 
             UndirectedEdge[44, 177] -> 
             RGBColor[
              0.7203532300972793, 0.7805419347286005, 0.973668928993885], 
             UndirectedEdge[140, 237] -> 
             RGBColor[
              0.4356889157133125, 0.542147340618477, 0.9504106753483976], 
             UndirectedEdge[38, 124] -> 
             RGBColor[
              0.696868629638063, 0.7578767313303897, 0.908772210038509], 
             UndirectedEdge[5, 59] -> 
             RGBColor[
              0.728126644093197, 0.7875373354238435, 0.973536517219006], 
             UndirectedEdge[35, 253] -> 
             RGBColor[
              0.5300734798542261, 0.6291476511446058, 0.9562117197263948], 
             UndirectedEdge[200, 231] -> 
             RGBColor[
              0.49242916842396767`, 0.5898014208879521, 0.9553468062478639], 
             UndirectedEdge[213, 234] -> 
             RGBColor[
              0.27899103117411855`, 0.41056764119001166`, 0.9391994985438977],
              UndirectedEdge[53, 88] -> 
             RGBColor[
              0.43217709237303903`, 0.5380146721276308, 0.9502508720552965], 
             UndirectedEdge[150, 269] -> 
             RGBColor[
              0.6480020202340966, 0.7223189284272942, 0.9673804611638186], 
             UndirectedEdge[4, 135] -> 
             RGBColor[
              0.44778895136495234`, 0.5597992075652355, 0.9504374908461599], 
             UndirectedEdge[91, 139] -> 
             RGBColor[
              0.6105691624988314, 0.6925622001219038, 0.9639020310639868], 
             UndirectedEdge[28, 232] -> 
             RGBColor[
              0.4159391264985379, 0.5346872984898419, 0.9477242512333268], 
             UndirectedEdge[127, 276] -> 
             RGBColor[
              0.6186302599488068, 0.6833750278927393, 0.8685714428175374], 
             UndirectedEdge[60, 103] -> 
             RGBColor[
              0.6828038501911629, 0.7509688464000766, 0.9698136153668659], 
             UndirectedEdge[145, 159] -> 
             RGBColor[
              0.8032312067951222, 0.8465494514480219, 0.9809320495237355], 
             UndirectedEdge[20, 252] -> 
             RGBColor[
              0.9140106422039787, 0.9330859804641254, 0.9505648428190521], 
             UndirectedEdge[80, 128] -> 
             RGBColor[
              0.3723169286100696, 0.49690394319426673`, 0.9449446833574686], 
             UndirectedEdge[167, 237] -> 
             RGBColor[
              0.4303211089101012, 0.5365054353296936, 0.9501049866919133], 
             UndirectedEdge[24, 291] -> 
             RGBColor[
              0.7315942320568858, 0.7884915299013835, 0.9498840801595995], 
             UndirectedEdge[22, 244] -> 
             RGBColor[
              0.3938360772334438, 0.5105319609840187, 0.9469008043948981], 
             UndirectedEdge[51, 83] -> 
             RGBColor[
              0.3246344537354209, 0.4540431510709262, 0.9419635404942199], 
             UndirectedEdge[29, 229] -> 
             RGBColor[
              0.9167063824076803, 0.9360187851460673, 0.9779792810289343], 
             UndirectedEdge[151, 181] -> 
             RGBColor[
              0.7571753044659343, 0.810264165224287, 0.9767651925492945], 
             UndirectedEdge[22, 63] -> 
             RGBColor[
              0.4894690102213667, 0.5871920225143111, 0.9550987690150696], 
             UndirectedEdge[163, 292] -> 
             RGBColor[
              0.3988499615896469, 0.5138361840052438, 0.947365266779097], 
             UndirectedEdge[247, 289] -> 
             RGBColor[
              0.8255927796272156, 0.8606999038114838, 0.7656668090541672], 
             UndirectedEdge[155, 299] -> 
             RGBColor[
              0.6675698429702519, 0.7374568419722374, 0.9695216225592203], 
             UndirectedEdge[31, 71] -> 
             RGBColor[
              0.39666634666675227`, 0.5179941852776291, 0.9464962067446956], 
             UndirectedEdge[45, 260] -> 
             RGBColor[
              0.5842960999391635, 0.6698005135624878, 0.9622301696201934], 
             UndirectedEdge[80, 125] -> 
             RGBColor[
              0.6575868678471077, 0.7283026894408677, 0.9691191008729337], 
             UndirectedEdge[97, 261] -> 
             RGBColor[
              0.47472191032186173`, 0.584439658634459, 0.951790994225644], 
             UndirectedEdge[107, 147] -> 
             RGBColor[
              0.5033781107206315, 0.6053079866806971, 0.9547089555733049], 
             UndirectedEdge[15, 286] -> 
             RGBColor[
              0.4910616244082755, 0.5965792885161717, 0.9533883467988737], 
             UndirectedEdge[94, 202] -> 
             RGBColor[
              0.6539519699513845, 0.7179048039586515, 0.7615693318548089], 
             UndirectedEdge[86, 130] -> 
             RGBColor[
              0.47613438444928374`, 0.5716398171737522, 0.9545826589293964], 
             UndirectedEdge[73, 161] -> 
             RGBColor[
              0.2899265182856512, 0.42206153149416137`, 0.939822258357296], 
             UndirectedEdge[7, 167] -> 
             RGBColor[
              0.3280408904194675, 0.45239956691744476`, 0.9423488069761379], 
             UndirectedEdge[288, 297] -> 
             RGBColor[
              0.6840701192721679, 0.2681186404562903, 0.42542143976289926`], 
             UndirectedEdge[15, 46] -> 
             RGBColor[
              0.4626795374269809, 0.5735374317063091, 0.951154004944696], 
             UndirectedEdge[1, 92] -> 
             RGBColor[
              0.8314635370226398, 0.8684762284805474, 0.946941527083408], 
             UndirectedEdge[85, 213] -> 
             RGBColor[
              0.35669987267767167`, 0.47901301972242444`, 0.9441093736367243],
              UndirectedEdge[2, 174] -> 
             RGBColor[
              0.3231187614668773, 0.44674150062980955`, 0.9420862424721425], 
             UndirectedEdge[104, 204] -> 
             RGBColor[
              0.8833193856152247, 0.9097989172963363, 0.9887329856201463], 
             UndirectedEdge[125, 243] -> 
             RGBColor[
              0.5753006927396958, 0.6509575687540627, 0.9640982597985381], 
             UndirectedEdge[149, 243] -> 
             RGBColor[
              0.4499415969103219, 0.5523184095037086, 0.9517914334051283], 
             UndirectedEdge[35, 175] -> 
             RGBColor[
              0.5214468485769601, 0.621675696719333, 0.9556620384096379], 
             UndirectedEdge[82, 201] -> 
             RGBColor[
              0.41631898192237676`, 0.5325039686709494, 0.9483321805620213], 
             UndirectedEdge[39, 69] -> 
             RGBColor[
              0.4000458056145817, 0.5199834896668984, 0.9469706634328207], 
             UndirectedEdge[5, 204] -> 
             RGBColor[
              0.8145330583410149, 0.8551526562003222, 0.9821184560803853], 
             UndirectedEdge[107, 277] -> 
             RGBColor[
              0.6114610404947479, 0.695450644536423, 0.9625555994447914], 
             UndirectedEdge[236, 260] -> 
             RGBColor[
              0.479266820034318, 0.5865442802647827, 0.9525867652982842], 
             UndirectedEdge[11, 51] -> 
             RGBColor[
              0.34324868632335037`, 0.4717264927378486, 0.9430924806629963], 
             UndirectedEdge[41, 242] -> 
             RGBColor[
              0.6789856933130298, 0.7491480511893183, 0.9686386064935335], 
             UndirectedEdge[53, 93] -> 
             RGBColor[
              0.48680711914975927`, 0.5914852468606464, 0.9535065652235082], 
             UndirectedEdge[82, 293] -> 
             RGBColor[
              0.3769647467274189, 0.5004688751081244, 0.9452577094308244], 
             UndirectedEdge[76, 151] -> 
             RGBColor[
              0.6305089669577104, 0.7042345395515797, 0.9676766703554923], 
             UndirectedEdge[130, 269] -> 
             RGBColor[
              0.5915652726569474, 0.6781448401890192, 0.9617780021890788], 
             UndirectedEdge[13, 289] -> 
             RGBColor[
              0.8453316886268981, 0.8761200895433005, 0.7676341990326634], 
             UndirectedEdge[86, 120] -> 
             RGBColor[
              0.32246127059828145`, 0.44686693353260243`, 0.9420189033669154],
              UndirectedEdge[86, 284] -> 
             RGBColor[
              0.3562739082368003, 0.4754852066540892, 0.9443581327094803], 
             UndirectedEdge[49, 102] -> 
             RGBColor[
              0.33714378862361116`, 0.46620079355659705`, 0.9427121942619844],
              UndirectedEdge[27, 299] -> 
             RGBColor[
              0.7094413414888718, 0.7717476848016265, 0.9727356520781064], 
             UndirectedEdge[120, 182] -> 
             RGBColor[
              0.37600313689719944`, 0.500096751538363, 0.9451795652899386], 
             UndirectedEdge[97, 182] -> 
             RGBColor[
              0.41060257885950036`, 0.529353787855027, 0.947580734751031], 
             UndirectedEdge[42, 130] -> 
             RGBColor[
              0.5389683665906484, 0.6329179988869181, 0.9583354062572049], 
             UndirectedEdge[15, 127] -> 
             RGBColor[
              0.7014001405308278, 0.760837840800776, 0.8736341361164043], 
             UndirectedEdge[28, 176] -> 
             RGBColor[
              0.6486921575622981, 0.7222426480484346, 0.9677954638436403], 
             UndirectedEdge[26, 35] -> 
             RGBColor[
              0.5251717638571509, 0.6249020311153486, 0.9558993867174784], 
             UndirectedEdge[44, 59] -> 
             RGBColor[
              0.7814861977655765, 0.8298827059983722, 0.9786796273209812], 
             UndirectedEdge[155, 218] -> 
             RGBColor[
              0.37729478431559166`, 0.5012155116120874, 0.9452618679212796], 
             UndirectedEdge[65, 155] -> 
             RGBColor[
              0.5791170890516197, 0.6677684566427818, 0.9608616277140978], 
             UndirectedEdge[55, 252] -> 
             RGBColor[
              0.95177311562942, 0.9631967517385378, 0.9541666612453286], 
             UndirectedEdge[160, 296] -> 
             RGBColor[
              0.7029269316706768, 0.7669846322877383, 0.9716178132015092], 
             UndirectedEdge[88, 147] -> 
             RGBColor[
              0.3036354978760101, 0.4312627485975016, 0.940793647154264], 
             UndirectedEdge[204, 243] -> 
             RGBColor[
              0.5385733070721469, 0.6216721483610852, 0.960595168966643], 
             UndirectedEdge[65, 106] -> 
             RGBColor[
              0.5002001910357845, 0.5971748483107331, 0.9559151212589302], 
             UndirectedEdge[115, 245] -> 
             RGBColor[
              0.7573696189701891, 0.8055418886922578, 0.759990396658976], 
             UndirectedEdge[60, 205] -> 
             RGBColor[
              0.64706151508311, 0.7219516085855121, 0.9669998478186725], 
             UndirectedEdge[75, 111] -> 
             RGBColor[
              0.5313398666973709, 0.6263340690523012, 0.9578393814890045], 
             UndirectedEdge[17, 86] -> 
             RGBColor[
              0.26406901972006724`, 0.39488366104163286`, 0.9383497120667272],
              UndirectedEdge[67, 166] -> 
             RGBColor[
              0.6034287334529065, 0.6889296558285476, 0.9619232668111476], 
             UndirectedEdge[3, 169] -> 
             RGBColor[
              0.6712011027716503, 0.740557714496657, 0.9697734163745216], 
             UndirectedEdge[7, 255] -> 
             RGBColor[
              0.40774628834868576`, 0.5275910738684584, 0.9472022108310606], 
             UndirectedEdge[211, 231] -> 
             RGBColor[
              0.5668291584671625, 0.6482369259647318, 0.9626790642659091], 
             UndirectedEdge[218, 290] -> 
             RGBColor[
              0.6066450883297004, 0.6844024648691029, 0.9657704837431369], 
             UndirectedEdge[201, 269] -> 
             RGBColor[
              0.49717281508893507`, 0.6026663145261031, 0.9535584116892819], 
             UndirectedEdge[34, 223] -> 
             RGBColor[
              0.48587946570815055`, 0.5904012866464179, 0.9535249516104178], 
             UndirectedEdge[63, 208] -> 
             RGBColor[
              0.540582724882777, 0.6347999698218582, 0.9582335491242695], 
             UndirectedEdge[131, 190] -> 
             RGBColor[
              0.688627088751749, 0.7477158764453447, 0.7447387340202325], 
             UndirectedEdge[27, 181] -> 
             RGBColor[
              0.5575177331206185, 0.6516570374918009, 0.9583089846874543], 
             UndirectedEdge[108, 136] -> 
             RGBColor[
              0.7686067064909976, 0.8195328527712611, 0.9774724250910569], 
             UndirectedEdge[101, 254] -> 
             RGBColor[
              0.6811147970105932, 0.7490868741119231, 0.9701190055945309], 
             UndirectedEdge[62, 212] -> 
             RGBColor[
              0.5624671170637812, 0.644993125593365, 0.9622275029603597], 
             UndirectedEdge[69, 195] -> 
             RGBColor[
              0.6510877618565336, 0.7174860058208153, 0.8787429976695809], 
             UndirectedEdge[136, 252] -> 
             RGBColor[
              0.826422966238233, 0.8644486571690271, 0.9418914893059948], 
             UndirectedEdge[26, 175] -> 
             RGBColor[
              0.4313592501208815, 0.5480434345335674, 0.9487068078750627], 
             UndirectedEdge[24, 27] -> 
             RGBColor[
              0.5127076100698935, 0.6152781609261837, 0.954781367656012], 
             UndirectedEdge[231, 266] -> 
             RGBColor[
              0.5223864091847528, 0.6132042450537398, 0.9583326640405674], 
             UndirectedEdge[153, 157] -> 
             RGBColor[
              0.6494318954620716, 0.723404671796464, 0.9675794577154968], 
             UndirectedEdge[161, 244] -> 
             RGBColor[
              0.4087018400940924, 0.5261568202943644, 0.9477473875978867], 
             UndirectedEdge[128, 150] -> 
             RGBColor[
              0.583766976922121, 0.6670117175927741, 0.9631962934178507], 
             UndirectedEdge[113, 200] -> 
             RGBColor[
              0.6684136671612639, 0.7406513070521397, 0.9677474688061862], 
             UndirectedEdge[211, 264] -> 
             RGBColor[
              0.6763786935079659, 0.7451519157390984, 0.9698497231227527], 
             UndirectedEdge[144, 232] -> 
             RGBColor[
              0.3412941313238197, 0.4681491452681288, 0.9430369356340302], 
             UndirectedEdge[208, 244] -> 
             RGBColor[
              0.4449497918948543, 0.5581399082915657, 0.9500355845040981], 
             UndirectedEdge[47, 133] -> 
             RGBColor[
              0.43256482367781224`, 0.5480888970703954, 0.9490595820880963], 
             UndirectedEdge[181, 258] -> 
             RGBColor[
              0.4845155363286062, 0.5904023484923895, 0.9531113346023832], 
             UndirectedEdge[53, 147] -> 
             RGBColor[
              0.4936143093686325, 0.5973812928889058, 0.9539403133648927], 
             UndirectedEdge[123, 267] -> 
             RGBColor[
              0.6058780142825562, 0.6848199699584515, 0.965223545669401], 
             UndirectedEdge[59, 227] -> 
             RGBColor[
              0.7039083073979487, 0.7686177867313394, 0.9711226597504478], 
             UndirectedEdge[213, 286] -> 
             RGBColor[
              0.41590333879873287`, 0.5271167445272048, 0.9487591225733438], 
             UndirectedEdge[16, 126] -> 
             RGBColor[
              0.5281714237691493, 0.6277147586817815, 0.9560312352580256], 
             UndirectedEdge[68, 109] -> 
             RGBColor[
              0.22681754341146407`, 0.3557299975612772, 0.9362282955995729], 
             UndirectedEdge[137, 156] -> 
             RGBColor[
              0.6223934110474811, 0.700342669665111, 0.965715229048452], 
             UndirectedEdge[181, 202] -> 
             RGBColor[
              0.7914393743108115, 0.8333070938552369, 0.7713473628596761], 
             UndirectedEdge[135, 214] -> 
             RGBColor[
              0.4287405019165037, 0.5443348181801163, 0.9489379271288085], 
             UndirectedEdge[166, 234] -> 
             RGBColor[
              0.46386329543140603`, 0.570226621713, 0.9521547786381217], 
             UndirectedEdge[63, 152] -> 
             RGBColor[
              0.6116008077450379, 0.6945850522028131, 0.9632359922551046], 
             UndirectedEdge[130, 167] -> 
             RGBColor[
              0.4799191081748676, 0.5756178017746848, 0.9547981933465713], 
             UndirectedEdge[30, 74] -> 
             RGBColor[
              0.4664229703501258, 0.5742663269255013, 0.9520870147037982], 
             UndirectedEdge[31, 177] -> 
             RGBColor[
              0.46872910164316833`, 0.5780846847470572, 0.9517308384801401], 
             UndirectedEdge[24, 72] -> 
             RGBColor[
              0.4485776775603076, 0.5617081813152409, 0.9501490504055817], 
             UndirectedEdge[39, 285] -> 
             RGBColor[
              0.4962747002618981, 0.6019371844499026, 0.9534877088001945], 
             UndirectedEdge[27, 72] -> 
             RGBColor[
              0.46196795811242286`, 0.5725790142927127, 0.9512031823408581], 
             UndirectedEdge[109, 151] -> 
             RGBColor[
              0.6000605600677843, 0.6747146222455909, 0.9658517532570573], 
             UndirectedEdge[29, 178] -> 
             RGBColor[
              0.6087742807338279, 0.6801890636808017, 0.95290703349182], 
             UndirectedEdge[149, 256] -> 
             RGBColor[
              0.4234270835621385, 0.524449974857525, 0.9502814710946565], 
             UndirectedEdge[93, 137] -> 
             RGBColor[
              0.3810333768285185, 0.5044536925396613, 0.9455000877302957], 
             UndirectedEdge[7, 145] -> 
             RGBColor[
              0.5791671102039815, 0.6665991985856858, 0.9613780379797023], 
             UndirectedEdge[271, 278] -> 
             RGBColor[
              0.6594490617420038, 0.7267253841516889, 0.9372563149430051], 
             UndirectedEdge[15, 135] -> 
             RGBColor[
              0.3814872271975473, 0.5048467949181312, 0.9455290066744861], 
             UndirectedEdge[94, 130] -> 
             RGBColor[
              0.5158116589709295, 0.6128608226366842, 0.956859881324349], 
             UndirectedEdge[265, 286] -> 
             RGBColor[
              0.45971907037761744`, 0.5694319435373858, 0.9513912269711725], 
             UndirectedEdge[140, 201] -> 
             RGBColor[
              0.3908944574100665, 0.5057811814005521, 0.9468842915032587], 
             UndirectedEdge[29, 259] -> 
             RGBColor[
              0.6741648583066413, 0.7407552352018376, 0.9569298348296387], 
             UndirectedEdge[21, 123] -> 
             RGBColor[
              0.6683165376228747, 0.7313834281570335, 0.8421564830673659], 
             UndirectedEdge[21, 189] -> 
             RGBColor[
              0.6919424769480501, 0.7518470293262626, 0.8436619070295683], 
             UndirectedEdge[107, 289] -> 
             RGBColor[
              0.8177339435102127, 0.8545501736096841, 0.7648905884925439], 
             UndirectedEdge[17, 66] -> 
             RGBColor[
              0.3495968890242137, 0.47581814718726634`, 0.9435484938171317], 
             UndirectedEdge[71, 208] -> 
             RGBColor[
              0.3848872246925568, 0.5077917018594655, 0.9457456515083684], 
             UndirectedEdge[6, 289] -> 
             RGBColor[
              0.6537203506694855, 0.7176044081851052, 0.7530266178036542], 
             UndirectedEdge[96, 132] -> 
             RGBColor[
              0.43547515213092963`, 0.5491037128248993, 0.9496611281148788], 
             UndirectedEdge[55, 283] -> 
             RGBColor[
              0.6901690779027461, 0.7558910413984765, 0.9714608099430126], 
             UndirectedEdge[48, 244] -> 
             RGBColor[
              0.6297419474545107, 0.7087275752153962, 0.9650642825148199], 
             UndirectedEdge[110, 278] -> 
             RGBColor[
              0.7709158111633774, 0.8201255623317387, 0.9452283251225331], 
             UndirectedEdge[245, 288] -> 
             RGBColor[
              0.8761398857716044, 0.4191206395681, 0.29766198591971993`], 
             UndirectedEdge[106, 210] -> 
             RGBColor[
              0.5930898948856907, 0.6704011370775891, 0.9649983163494095], 
             UndirectedEdge[176, 296] -> 
             RGBColor[
              0.8399367092652628, 0.8752067487662554, 0.9845951072217145], 
             UndirectedEdge[82, 154] -> 
             RGBColor[
              0.3508307076456524, 0.4778328839904952, 0.9435924715699576], 
             UndirectedEdge[46, 117] -> 
             RGBColor[
              0.43073574185151997`, 0.5458693215206937, 0.9491185745374169], 
             UndirectedEdge[249, 258] -> 
             RGBColor[
              0.31394140533480697`, 0.44070613682726734`, 0.9414314031549018],
              UndirectedEdge[146, 170] -> 
             RGBColor[
              0.8122327212096001, 0.8538232378279562, 0.9637677261524082], 
             UndirectedEdge[18, 129] -> 
             RGBColor[
              0.4422078890670809, 0.5574399803203174, 0.9493980735556398], 
             UndirectedEdge[13, 179] -> 
             RGBColor[
              0.5658851154994469, 0.6571145487432426, 0.9596769532700491], 
             UndirectedEdge[144, 160] -> 
             RGBColor[
              0.437037384792994, 0.5474823783482045, 0.9501308542241385], 
             UndirectedEdge[17, 130] -> 
             RGBColor[
              0.5055951863122683, 0.6026049878544733, 0.9562604080121426], 
             UndirectedEdge[111, 163] -> 
             RGBColor[
              0.49168359283031793`, 0.5880576579574822, 0.9554563472273657], 
             UndirectedEdge[107, 251] -> 
             RGBColor[
              0.5226184122744919, 0.6219729688409766, 0.9559349305747863], 
             UndirectedEdge[1, 198] -> 
             RGBColor[
              0.7199664173432238, 0.781162504266744, 0.9727231820782234], 
             UndirectedEdge[168, 269] -> 
             RGBColor[
              0.4404517719459475, 0.5555889647998424, 0.9493773429125018], 
             UndirectedEdge[145, 201] -> 
             RGBColor[
              0.6366528703913692, 0.7143389077800097, 0.9656078338503389], 
             UndirectedEdge[197, 226] -> 
             RGBColor[
              0.5465613040281887, 0.6384434442652742, 0.9592641287652948], 
             UndirectedEdge[105, 174] -> 
             RGBColor[
              0.2213982510954197, 0.35003397773413614`, 0.9359196749192987], 
             UndirectedEdge[178, 284] -> 
             RGBColor[
              0.3720996972863811, 0.4921191143581788, 0.9452593879836972], 
             UndirectedEdge[201, 202] -> 
             RGBColor[
              0.7614084044539275, 0.8089265996456438, 0.7689832149054748], 
             UndirectedEdge[24, 65] -> 
             RGBColor[
              0.6075983070181242, 0.6911884664946992, 0.9630215252977077], 
             UndirectedEdge[134, 169] -> 
             RGBColor[
              0.43371452620997275`, 0.5500834563023199, 0.9488568839847706], 
             UndirectedEdge[104, 300] -> 
             RGBColor[
              0.9104815663106456, 0.9314573028851112, 0.9913237386628405], 
             UndirectedEdge[168, 225] -> 
             RGBColor[
              0.565898150718777, 0.6562983432889299, 0.9600280193492513], 
             UndirectedEdge[27, 202] -> 
             RGBColor[
              0.7600195318122018, 0.8077990502670913, 0.76887387776351], 
             UndirectedEdge[113, 187] -> 
             RGBColor[
              0.6727788880417132, 0.7440614507808542, 0.9681825532282409], 
             UndirectedEdge[7, 201] -> 
             RGBColor[
              0.4713898757180724, 0.5806643834664365, 0.9518243780045813], 
             UndirectedEdge[51, 104] -> 
             RGBColor[
              0.6449781028994866, 0.7165214195254508, 0.9687116748947477], 
             UndirectedEdge[2, 183] -> 
             RGBColor[
              0.4592066124987984, 0.5709157759059729, 0.9508259450105471], 
             UndirectedEdge[135, 249] -> 
             RGBColor[
              0.29945196153909714`, 0.4281561088720438, 0.9405081486087512], 
             UndirectedEdge[84, 270] -> 
             RGBColor[
              0.5093402401849529, 0.6082091660417706, 0.9560439359926247], 
             UndirectedEdge[114, 116] -> 
             RGBColor[
              0.8699715844624454, 0.8975068327485641, 0.9023594925846303], 
             UndirectedEdge[15, 168] -> 
             RGBColor[
              0.41364669728400744`, 0.5327017115250581, 0.9475781796708925], 
             UndirectedEdge[42, 237] -> 
             RGBColor[
              0.489370367325882, 0.593805632441927, 0.9536421996025468], 
             UndirectedEdge[40, 140] -> 
             RGBColor[
              0.3657832759545359, 0.4853947930491193, 0.9449074473137908], 
             UndirectedEdge[42, 167] -> 
             RGBColor[
              0.30122692372403115`, 0.4291746566750103, 0.9406402447289643], 
             UndirectedEdge[16, 285] -> 
             RGBColor[
              0.4768392526873562, 0.5860409897096277, 0.9519901787145284], 
             UndirectedEdge[8, 286] -> 
             RGBColor[
              0.4457629043678807, 0.5573438139970512, 0.950501952413985], 
             UndirectedEdge[9, 236] -> 
             RGBColor[
              0.4231979666276658, 0.5355814441239959, 0.9491019398492269], 
             UndirectedEdge[54, 238] -> 
             RGBColor[
              0.7449259834400878, 0.8002028827946268, 0.9747519634985669], 
             UndirectedEdge[165, 183] -> 
             RGBColor[
              0.7345015493594249, 0.7906581661101034, 0.9449188631682661], 
             UndirectedEdge[249, 263] -> 
             RGBColor[
              0.44029789624983784`, 0.5452762453793046, 0.9508292987165561], 
             UndirectedEdge[33, 98] -> 
             RGBColor[
              0.7344117960065003, 0.791778639898348, 0.974979016993655], 
             UndirectedEdge[282, 293] -> 
             RGBColor[
              0.42449999544328954`, 0.5421022928880015, 0.9482697422324073], 
             UndirectedEdge[54, 163] -> 
             RGBColor[
              0.40956590199663245`, 0.5225358671752486, 0.9482088648617182], 
             UndirectedEdge[145, 237] -> 
             RGBColor[
              0.6814473286946152, 0.7507050669979347, 0.9691342176954778], 
             UndirectedEdge[140, 181] -> 
             RGBColor[
              0.4209254272669505, 0.5301616756101452, 0.9492484394574598], 
             UndirectedEdge[15, 265] -> 
             RGBColor[
              0.38051729091787184`, 0.5040066848630913, 0.9454672031924262], 
             UndirectedEdge[144, 230] -> 
             RGBColor[
              0.35337830565332184`, 0.47861584970408166`, 0.9438069285366903],
              UndirectedEdge[22, 266] -> 
             RGBColor[0.52128619090516, 0.61204784588402, 0.9582700082371716],
              UndirectedEdge[18, 165] -> 
             RGBColor[
              0.7058930865956017, 0.7671265978374435, 0.9427512293892064], 
             UndirectedEdge[17, 140] -> 
             RGBColor[
              0.27322155024886235`, 0.4045035509313488, 0.9388709351403866], 
             UndirectedEdge[80, 237] -> 
             RGBColor[
              0.5130492510418163, 0.6143150913813691, 0.9551509971345113], 
             UndirectedEdge[7, 127] -> 
             RGBColor[
              0.7024222758219052, 0.7617231630158937, 0.8736992656733129], 
             UndirectedEdge[60, 212] -> 
             RGBColor[
              0.5379082821772527, 0.6255793575819645, 0.9598402702640971], 
             UndirectedEdge[53, 270] -> 
             RGBColor[
              0.47281392425471797`, 0.579365044760987, 0.9526149312184925], 
             UndirectedEdge[243, 254] -> 
             RGBColor[
              0.5447094233253647, 0.6265649209009625, 0.9611804372126507], 
             UndirectedEdge[201, 277] -> 
             RGBColor[
              0.5550571051626482, 0.6496593888654945, 0.9581152750410256], 
             UndirectedEdge[288, 296] -> 
             RGBColor[
              0.8182605267990423, 0.37589274835899145`, 0.4370477403069123], 
             UndirectedEdge[93, 273] -> 
             RGBColor[
              0.4018924559772764, 0.5225207784905136, 0.9468292098086951], 
             UndirectedEdge[128, 277] -> 
             RGBColor[
              0.45911924103414736`, 0.5686143998963171, 0.9514353451091218], 
             UndirectedEdge[3, 115] -> 
             RGBColor[
              0.707515911888372, 0.7701752037214458, 0.9725948145458463], 
             UndirectedEdge[74, 123] -> 
             RGBColor[
              0.47411527960405664`, 0.5809290185745515, 0.9525771618474166], 
             UndirectedEdge[52, 147] -> 
             RGBColor[
              0.47580605131971276`, 0.5829237467519102, 0.9525383820574831], 
             UndirectedEdge[64, 76] -> 
             RGBColor[
              0.32762445829594045`, 0.45819357171704034`, 0.9420969186690521],
              UndirectedEdge[132, 260] -> 
             RGBColor[
              0.47025149790741194`, 0.5792252356265268, 0.9518770461162411], 
             UndirectedEdge[171, 285] -> 
             RGBColor[
              0.3947385799377286, 0.5127141271587605, 0.9468399125910245], 
             UndirectedEdge[226, 290] -> 
             RGBColor[
              0.8217332198351708, 0.8613187745961035, 0.9826924571721336], 
             UndirectedEdge[24, 290] -> 
             RGBColor[
              0.7001864155653824, 0.76417427135381, 0.972075953958983], 
             UndirectedEdge[103, 265] -> 
             RGBColor[
              0.4578401483134021, 0.5679065499611815, 0.9512433113435592], 
             UndirectedEdge[41, 208] -> 
             RGBColor[
              0.5296991354074553, 0.6262976270053932, 0.9571487746382958], 
             UndirectedEdge[80, 179] -> 
             RGBColor[
              0.4212625918837718, 0.5392982166413813, 0.9480634577403184], 
             UndirectedEdge[102, 183] -> 
             RGBColor[
              0.4336914611776186, 0.5488158342603605, 0.9492001421305238], 
             UndirectedEdge[16, 220] -> 
             RGBColor[
              0.4640129885149479, 0.5756280506378504, 0.9509804482147227], 
             UndirectedEdge[52, 217] -> 
             RGBColor[
              0.6521904912547745, 0.7273603504231243, 0.9665525376350041], 
             UndirectedEdge[24, 241] -> 
             RGBColor[
              0.3845675637154131, 0.5026666596823786, 0.9462021661004989], 
             UndirectedEdge[105, 163] -> 
             RGBColor[
              0.2409821098704304, 0.3706178549950353, 0.9370349467048129], 
             UndirectedEdge[2, 102] -> 
             RGBColor[
              0.3936302932063519, 0.5153645083667141, 0.9463027521028755], 
             UndirectedEdge[49, 54] -> 
             RGBColor[
              0.42952222169953547`, 0.5435112244867493, 0.9493453477460692], 
             UndirectedEdge[216, 237] -> 
             RGBColor[
              0.4376587096542962, 0.5442177189426002, 0.9505228521992877], 
             UndirectedEdge[89, 281] -> 
             RGBColor[
              0.2897026384277897, 0.4218262195687461, 0.9398095087305914], 
             UndirectedEdge[145, 167] -> 
             RGBColor[
              0.49330388509276435`, 0.5860740912310181, 0.9561322628218955], 
             UndirectedEdge[16, 90] -> 
             RGBColor[
              0.7170267079708019, 0.7757019324472455, 0.9234828718915425], 
             UndirectedEdge[210, 290] -> 
             RGBColor[
              0.9013570969156346, 0.9241816986666532, 0.9904534386264344], 
             UndirectedEdge[152, 242] -> 
             RGBColor[
              0.5951983491505743, 0.6817713268855158, 0.961601148472099], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.7253748804424335, 0.7853876367456887, 0.9732622471349913], 
             UndirectedEdge[77, 282] -> 
             RGBColor[
              0.5265420972214336, 0.6248480446725804, 0.9564037865302817], 
             UndirectedEdge[81, 162] -> 
             RGBColor[
              0.6623807649812115, 0.7301257465399578, 0.9500099124615828], 
             UndirectedEdge[34, 247] -> 
             RGBColor[
              0.4983372926751295, 0.6002846848024048, 0.9546632215784098], 
             UndirectedEdge[7, 60] -> 
             RGBColor[
              0.6065031280867099, 0.6879543035171041, 0.9641026367726415], 
             UndirectedEdge[155, 162] -> 
             RGBColor[
              0.7003340395749771, 0.762998965406031, 0.9524282615579347], 
             UndirectedEdge[234, 249] -> 
             RGBColor[
              0.27211405112521103`, 0.40333949913289113`, 0.9388078647036928],
              UndirectedEdge[118, 234] -> 
             RGBColor[
              0.34142161216982925`, 0.46900608715551173`, 0.9430177246861016],
              UndirectedEdge[223, 271] -> 
             RGBColor[
              0.4893806111184189, 0.5934338028281074, 0.9537480415000188], 
             UndirectedEdge[154, 216] -> 
             RGBColor[
              0.32737597707432586`, 0.4531804750442211, 0.942256759362085], 
             UndirectedEdge[147, 247] -> 
             RGBColor[
              0.5112369468376345, 0.6114577168824967, 0.9554851761349283], 
             UndirectedEdge[4, 286] -> 
             RGBColor[
              0.5573633485756806, 0.651531701163276, 0.9582968309705475], 
             UndirectedEdge[88, 124] -> 
             RGBColor[
              0.32462704011779464`, 0.44944456742174493`, 0.9421312096638186],
              UndirectedEdge[23, 136] -> 
             RGBColor[
              0.4250544476811907, 0.5242228324596053, 0.9506808984222255], 
             UndirectedEdge[11, 104] -> 
             RGBColor[
              0.6308243398668758, 0.7042621413754179, 0.967809809629991], 
             UndirectedEdge[4, 121] -> 
             RGBColor[
              0.7133793221758717, 0.775020617540732, 0.9729583018271895], 
             UndirectedEdge[4, 213] -> 
             RGBColor[
              0.40300328350639225`, 0.5166438985000145, 0.9477435829662713], 
             UndirectedEdge[198, 204] -> 
             RGBColor[
              0.7938402405203993, 0.838987269647617, 0.9800559893854033], 
             UndirectedEdge[156, 168] -> 
             RGBColor[
              0.6248059762456336, 0.7024323123806981, 0.9658689555695306], 
             UndirectedEdge[31, 226] -> 
             RGBColor[
              0.5704314451942425, 0.6591185607951309, 0.9607851130528586], 
             UndirectedEdge[36, 242] -> 
             RGBColor[
              0.4261969120969441, 0.525115334344243, 0.9507947685982507], 
             UndirectedEdge[216, 269] -> 
             RGBColor[
              0.3611614305345252, 0.48211378159001794`, 0.9445007061682127], 
             UndirectedEdge[97, 202] -> 
             RGBColor[
              0.7367271901332384, 0.7888892779840742, 0.7670402193038832], 
             UndirectedEdge[23, 59] -> 
             RGBColor[
              0.42009959314590073`, 0.5203520624383475, 0.950187044827896], 
             UndirectedEdge[174, 238] -> 
             RGBColor[
              0.5820360186246889, 0.65426944412757, 0.963902300383749], 
             UndirectedEdge[86, 97] -> 
             RGBColor[
              0.3570607125605823, 0.4761239698492663, 0.9444200728280077], 
             UndirectedEdge[46, 212] -> 
             RGBColor[
              0.39510682680860104`, 0.5120478079862872, 0.9469567679930602], 
             UndirectedEdge[59, 291] -> 
             RGBColor[
              0.8125716604438974, 0.8539429283653751, 0.9564570071271277], 
             UndirectedEdge[125, 149] -> 
             RGBColor[
              0.782180690293161, 0.8304724479652537, 0.9787363226489305], 
             UndirectedEdge[32, 80] -> 
             RGBColor[
              0.5116278837635184, 0.6131611613929806, 0.9550391018957238], 
             UndirectedEdge[69, 90] -> 
             RGBColor[
              0.6486510249771762, 0.7164783524999196, 0.9191260338334312], 
             UndirectedEdge[215, 229] -> 
             RGBColor[
              0.6474976183415863, 0.7204378979154522, 0.9680738683290575], 
             UndirectedEdge[187, 245] -> 
             RGBColor[
              0.8562518601522717, 0.8846491619463257, 0.7685745571122897], 
             UndirectedEdge[98, 275] -> 
             RGBColor[
              0.6266375259506635, 0.7008571325530567, 0.96744110744871], 
             UndirectedEdge[252, 280] -> 
             RGBColor[
              0.9261496435619878, 0.942765290642588, 0.9517226716051934], 
             UndirectedEdge[96, 146] -> 
             RGBColor[
              0.4970876054768738, 0.5987185977084183, 0.9547883050441172], 
             UndirectedEdge[191, 270] -> 
             RGBColor[
              0.5819568500851631, 0.6651031660244153, 0.9632378015780181], 
             UndirectedEdge[40, 120] -> 
             RGBColor[
              0.4444837981669396, 0.5587233463310939, 0.949733164623066], 
             UndirectedEdge[215, 233] -> 
             RGBColor[
              0.3142878305819199, 0.43803972567613086`, 0.9415620939643417], 
             UndirectedEdge[21, 257] -> 
             RGBColor[
              0.7212668751961192, 0.7772463492016288, 0.845530431755388], 
             UndirectedEdge[200, 245] -> 
             RGBColor[
              0.8518866392718223, 0.8812390182176112, 0.768139472690235], 
             UndirectedEdge[41, 108] -> 
             RGBColor[
              0.7752680400258926, 0.8247367371567311, 0.9781363645641141], 
             UndirectedEdge[63, 73] -> 
             RGBColor[
              0.49186348658645107`, 0.5897087689925851, 0.9552351309017508]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {3}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.7444301048772783, 0.800273722899259, 0.97516149382546], 160 -> 
             RGBColor[
              0.5857102829442267, 0.6745450194985022, 0.9605284054822815], 
             245 -> RGBColor[
              0.993781657314813, 0.9891079187042997, 0.5645499577591597], 155 -> 
             RGBColor[
              0.4423548935847691, 0.5575673082448771, 0.9494074405535159], 
             213 -> RGBColor[
              0.2615432737294446, 0.3922289418639433, 0.9382058745690676], 27 -> 
             RGBColor[
              0.5260978906220087, 0.6261489939036554, 0.9558354995912883], 19 -> 
             RGBColor[
              0.46060580264740775`, 0.5729795665009334, 0.9506797225205047], 
             164 -> RGBColor[
              0.42047319418507373`, 0.5386144800310511, 0.9480131580169943], 
             190 -> RGBColor[
              0.9935911077963088, 0.9887003525517306, 0.5438098186052865], 
             103 -> RGBColor[
              0.5665055597395904, 0.6589537600380575, 0.9590165393223935], 
             138 -> RGBColor[
              0.5844256996699266, 0.6735021369266084, 0.960427278381345], 291 -> 
             RGBColor[
              0.9638711345959934, 0.9725757318540552, 0.9460409245984633], 28 -> 
             RGBColor[
              0.43765447699119764`, 0.5534960436413328, 0.9491079341645887], 
             195 -> RGBColor[
              0.9899408486666531, 0.9901082966623329, 0.8163697000501186], 
             114 -> RGBColor[
              0.7507600103387772, 0.8052186931548453, 0.9757923996455324], 93 -> 
             RGBColor[
              0.3514583344338571, 0.47883727730225784`, 0.943615592181091], 
             34 -> RGBColor[
              0.3392734065465934, 0.46828330519859285`, 0.9428391793508233], 
             161 -> RGBColor[
              0.3023978047812153, 0.4351696443262332, 0.9405324796736034], 22 -> 
             RGBColor[
              0.2726662790599182, 0.4039199257055417, 0.9388393132676263], 
             124 -> RGBColor[
              0.40705579935517266`, 0.5269930070072634, 0.9471582134829694], 
             84 -> RGBColor[
              0.6952085357261314, 0.761821458980602, 0.9702555478141895], 46 -> 
             RGBColor[
              0.513499229905432, 0.615920833570741, 0.9548436868692646], 241 -> 
             RGBColor[
              0.2698177979130481, 0.40092599141604535`, 0.9386770964802622], 
             185 -> RGBColor[
              0.349242755491924, 0.47691825418099093`, 0.9434744174500705], 
             121 -> RGBColor[
              0.8822953510684036, 0.9089823799453784, 0.9886353122909041], 
             126 -> RGBColor[
              0.607356806504633, 0.6921186424896135, 0.9622324991107852], 236 -> 
             RGBColor[
              0.5635951593245416, 0.6565909658690763, 0.9587874219405728], 78 -> 
             RGBColor[
              0.8315616442739626, 0.8685286992772758, 0.9837962860463356], 
             254 -> RGBColor[
              0.8463572472938727, 0.8803263115094071, 0.9852075038705654], 
             290 -> RGBColor[
              0.9010555016129866, 0.9239412147589081, 0.9904246721972305], 
             251 -> RGBColor[
              0.40355331797932403`, 0.5239593336793358, 0.946935038466823], 
             165 -> RGBColor[
              0.9697353182487848, 0.9769492304205876, 0.9361143912983368], 
             100 -> RGBColor[
              0.4148087408639295, 0.533708215267978, 0.9476522240602504], 235 -> 
             RGBColor[
              0.5495712907760403, 0.6452057576133243, 0.9576834116373116], 70 -> 
             RGBColor[
              0.2669703175908264, 0.39793310905671037`, 0.9385149366883814], 
             234 -> RGBColor[
              0.2964387886187925, 0.42890634051608006`, 0.9401931225187279], 
             257 -> RGBColor[
              0.4480625312671665, 0.5625109771311585, 0.9497711261795724], 
             135 -> RGBColor[
              0.3511146094465647, 0.4785395599943853, 0.9435936903288449], 
             265 -> RGBColor[
              0.3491747368872138, 0.4768593398843054, 0.9434700833647249], 
             111 -> RGBColor[
              0.7171073897043916, 0.7789290101458736, 0.9724382209223169], 
             182 -> RGBColor[
              0.34169195045491874`, 0.470378126372433, 0.9429932868300274], 
             188 -> RGBColor[
              0.5380121129436418, 0.6358214963139562, 0.9567734308156817], 
             154 -> RGBColor[
              0.3978990873520114, 0.5190619232998521, 0.9465747558910904], 
             269 -> RGBColor[
              0.46546999427241, 0.5769285363914458, 0.9510626495033458], 208 -> 
             RGBColor[
              0.374893708382739, 0.4991358203206358, 0.9451088734860262], 86 -> 
             RGBColor[
              0.23460821785708263`, 0.3639184903609118, 0.9366719629839809], 
             119 -> RGBColor[
              0.990635183096344, 0.990395421792591, 0.804862781670237], 140 -> 
             RGBColor[
              0.25291327891467286`, 0.38315827014034376`, 0.9377144091312996],
              85 -> RGBColor[
              0.4518564716258988, 0.5657970975809056, 0.9500128727043811], 
             242 -> RGBColor[
              0.6734668241938883, 0.744836668688486, 0.9680885371965016], 117 -> 
             RGBColor[
              0.347972253797608, 0.4758178094706463, 0.9433934622055693], 47 -> 
             RGBColor[
              0.4901009998378523, 0.5969250963236276, 0.9530016924878038], 81 -> 
             RGBColor[
              0.3664483443972378, 0.49182087051273077`, 0.9445707423608123], 
             275 -> RGBColor[
              0.3271594748992157, 0.45779082646954244`, 0.9420672903381815], 
             23 -> RGBColor[0.178927, 0.305394, 0.933501], 110 -> 
             RGBColor[
              0.5692091962098773, 0.6611486939220714, 0.9592293794890812], 6 -> 
             RGBColor[
              0.3136563208882056, 0.4460950731534598, 0.9412068813049702], 
             218 -> RGBColor[
              0.3122346750464142, 0.4448637149792978, 0.9411162952890433], 
             108 -> RGBColor[
              0.8660315176196136, 0.8960140406233116, 0.987084053337663], 297 -> 
             RGBColor[
              0.41757235781650376`, 0.5361019213688709, 0.9478283192886979], 
             157 -> RGBColor[
              0.4579520843304667, 0.5708251584225928, 0.9504708120937045], 
             270 -> RGBColor[
              0.3234719446437745, 0.45459687310293895`, 0.9418323241710598], 
             33 -> RGBColor[
              0.5427080150108894, 0.6396338411601251, 0.9571431094280715], 
             252 -> RGBColor[
              0.9816640371140846, 0.9858456494188437, 0.9159221817675386], 
             260 -> RGBColor[
              0.3949384807440944, 0.5164975946604892, 0.9463861086559956], 
             159 -> RGBColor[
              0.8620323087129659, 0.8928251799967847, 0.986702605222011], 183 -> 
             RGBColor[
              0.4992677804700651, 0.6043671017996193, 0.9537233350381955], 99 -> 
             RGBColor[
              0.3883306461215388, 0.5107742204298564, 0.9459650632769251], 17 -> 
             RGBColor[
              0.29352982158305185`, 0.4258488317223539, 0.9400274611494736], 
             277 -> RGBColor[
              0.5812385744198362, 0.6709146850702287, 0.9601763762068334], 
             104 -> RGBColor[
              0.9325537564430122, 0.9490570681630199, 0.9934290038617424], 79 -> 
             RGBColor[
              0.6174112208024135, 0.7002812689627541, 0.9630240194348396], 
             191 -> RGBColor[
              0.8404417555265515, 0.8756094589458917, 0.9846432789849765], 50 -> 
             RGBColor[
              0.4346366313656539, 0.5508821374418182, 0.9489156397099051], 
             225 -> RGBColor[
              0.7163627518180691, 0.7783472933696208, 0.972364002376845], 61 -> 
             RGBColor[
              0.7163627518180691, 0.7783472933696208, 0.972364002376845], 196 -> 
             RGBColor[
              0.6076541817454884, 0.6923600651067419, 0.9622559095790667], 1 -> 
             RGBColor[
              0.6863373684330862, 0.7548912356679066, 0.9693713527641906], 
             263 -> RGBColor[
              0.6328064788680461, 0.712779833008907, 0.9642359905444546], 201 -> 
             RGBColor[
              0.5288756359054602, 0.6284040926607604, 0.9560541738752178], 
             293 -> 
             RGBColor[
              0.4501671655155445, 0.5643339055351105, 0.949905231612824], 184 -> 
             RGBColor[
              0.42647506161628695`, 0.5438129959373397, 0.9483955917024682], 
             106 -> RGBColor[
              0.28452109755309885`, 0.41638009158077965`, 0.9395144276431806],
              206 -> RGBColor[
              0.4660797034620084, 0.5774235257786478, 0.9511106480441894], 
             247 -> RGBColor[
              0.6574011788036657, 0.7322860644062168, 0.9664872638059963], 
             220 -> RGBColor[
              0.47903993599623035`, 0.5879452264017513, 0.9521309250241794], 
             107 -> RGBColor[
              0.6416835065696597, 0.7199866040026175, 0.9649348226827495], 
             131 -> RGBColor[
              0.38366306970718933`, 0.5067314003389588, 0.9456676494351786], 
             127 -> RGBColor[
              0.9909404361131257, 0.9905216517596749, 0.7998039492126812], 
             210 -> RGBColor[
              0.9016586922182827, 0.9244221825743983, 0.9904822050556383], 
             181 -> RGBColor[
              0.5889375756192281, 0.6771650810799466, 0.9607824697836203], 
             194 -> RGBColor[
              0.3134189745567612, 0.44588949569053615`, 0.9411917578066077], 
             118 -> RGBColor[
              0.38640443572086597`, 0.5091058337949435, 0.9458423268534752], 
             276 -> RGBColor[
              0.24632008378448794`, 0.3762284040258037, 0.9373389364223936], 
             280 -> RGBColor[
              0.8706352500098911, 0.8996849318663322, 0.9875231614428481], 
             189 -> RGBColor[
              0.38941373477102836`, 0.511712337380426, 0.9460340767279329], 
             168 -> RGBColor[
              0.415433549619485, 0.5342493932082389, 0.9476920363216577], 41 -> 
             RGBColor[
              0.6845045624321715, 0.7534594336901506, 0.9691886757905653], 14 -> 
             RGBColor[
              0.34072958729902103`, 0.469544575776573, 0.9429319659007178], 
             77 -> RGBColor[
              0.6542513690718328, 0.7298254091042683, 0.9661733202085727], 51 -> 
             RGBColor[
              0.3574024493559611, 0.48398577088788153`, 0.9439943459277531], 
             179 -> RGBColor[
              0.434891234195863, 0.551102661616635, 0.9489318627771096], 223 -> 
             RGBColor[
              0.6324855248697078, 0.712519268094243, 0.9642107238700123], 292 -> 
             RGBColor[
              0.5314401272230496, 0.6304860622413966, 0.9562560600257797], 
             143 -> 
             RGBColor[
              0.6118579136841751, 0.6957728440705335, 0.9625868427560577], 
             112 -> RGBColor[
              0.19003257266048992`, 0.31706666100015046`, 0.9341334459337924],
              197 -> RGBColor[
              0.35071166999902237`, 0.47819055409724964`, 0.9435680153835528],
              54 -> RGBColor[
              0.5528720080370206, 0.6478854285814063, 0.9579432561910217], 71 -> 
             RGBColor[
              0.39488074100237464`, 0.5164475833982953, 0.9463824295307105], 
             177 -> RGBColor[
              0.5390062509552067, 0.6366285823371516, 0.9568516930015996], 
             158 -> RGBColor[
              0.37563411340545105`, 0.49977712193747054`, 0.9451560514393591],
              226 -> RGBColor[
              0.742410938057355, 0.7986963344332988, 0.9749602421470368], 203 -> 
             RGBColor[
              0.9369799588431549, 0.9525203370078473, 0.9915606708061119], 
             115 -> RGBColor[
              0.520957580625565, 0.621975858680216, 0.9554308355587923], 173 -> 
             RGBColor[
              0.947107075465287, 0.9600731240030019, 0.9744181039398768], 212 -> 
             RGBColor[
              0.27671442371177013`, 0.4081747824018334, 0.9390698491168559], 
             129 -> RGBColor[
              0.4423649231917434, 0.5575759953863355, 0.9494080796312034], 
             279 -> RGBColor[
              0.9892514626001214, 0.9898232178074082, 0.8277946112465003], 26 -> 
             RGBColor[
              0.4350841654010723, 0.551269768929583, 0.9489441561829032], 40 -> 
             RGBColor[
              0.47865327299439897`, 0.5876313159578949, 0.952100485496282], 
             146 -> RGBColor[
              0.6687894217626179, 0.7411826463596025, 0.9676223374349634], 
             192 -> RGBColor[
              0.26694663468835045`, 0.3979082168246254, 0.938513587982121], 
             300 -> RGBColor[
              0.888409376178279, 0.9138575376072026, 0.9892184734639387], 221 -> 
             RGBColor[
              0.6645875272779449, 0.7379000944525951, 0.9672035318616677], 62 -> 
             RGBColor[
              0.8482198104157921, 0.8818114687848966, 0.9853851568038637], 
             286 -> RGBColor[
              0.5702634038680211, 0.6620045471904663, 0.9593123705776201], 
             152 -> RGBColor[
              0.5169298741072605, 0.6187059850825456, 0.9551137597476963], 64 -> 
             RGBColor[
              0.3196440159891005, 0.4512813136995487, 0.9415884119420883], 37 -> 
             RGBColor[
              0.3774541526813699, 0.5013535484804376, 0.945272022732623], 148 -> 
             RGBColor[
              0.7337218139790912, 0.7919083246635701, 0.9740941914633966], 
             261 -> RGBColor[
              0.46993061337964154`, 0.5805498679312971, 0.9514138057792533], 
             15 -> RGBColor[
              0.4118598449485299, 0.5311540298418771, 0.9474643230201274], 
             136 -> RGBColor[
              0.6711818953623815, 0.7430516649192106, 0.9678607968444509], 
             198 -> RGBColor[
              0.7535954662533613, 0.8074337728655815, 0.9760750113922562], 63 -> 
             RGBColor[
              0.7062717413828151, 0.7704641193230806, 0.9713582247625129], 
             171 -> RGBColor[
              0.2847846955344102, 0.4166571497722152, 0.939529439158258], 59 -> 
             RGBColor[
              0.6612721862918014, 0.735310124876695, 0.966873089655792], 229 -> 
             RGBColor[
              0.8821239993039492, 0.9088457486996222, 0.9886189686066429], 
             102 -> RGBColor[
              0.3681151418851721, 0.4932645667211018, 0.9446769492228523], 
             299 -> RGBColor[
              0.8927847923557348, 0.9173463756995976, 0.9896358045649245], 
             128 -> RGBColor[
              0.3369999076484586, 0.4663141147224057, 0.9426943140114102], 12 -> 
             RGBColor[
              0.17952963788721843`, 0.3060274106289155, 0.9335353193361543], 
             222 -> RGBColor[
              0.5098950579192125, 0.6129948043862303, 0.9545599532479924], 92 -> 
             RGBColor[
              0.9765897056121932, 0.9820612212931883, 0.9245117014026253], 
             271 -> RGBColor[
              0.34627569736713004`, 0.4743483375619718, 0.9432853591300252], 
             132 -> RGBColor[
              0.5455645150707296, 0.6419528765925646, 0.9573679835764866], 80 -> 
             RGBColor[
              0.40763394957168064`, 0.5274937716661278, 0.9471950527035271], 
             244 -> RGBColor[
              0.5150058754069695, 0.6171439962624956, 0.9549622955221699], 
             150 -> RGBColor[
              0.8305340461957833, 0.8677093204631424, 0.9836982728242912], 
             125 -> RGBColor[
              0.9075397861225349, 0.9291116072156078, 0.9910431490423404], 
             258 -> RGBColor[
              0.38009349703798434`, 0.5036396159048324, 0.945440199421146], 
             133 -> RGBColor[
              0.3750286475177722, 0.4992526978171634, 0.9451174716883887], 
             255 -> RGBColor[
              0.4015884611666869, 0.5222574734648043, 0.9468098395281764], 
             176 -> RGBColor[
              0.8597298381333985, 0.8909892524555365, 0.9864829935226921], 
             230 -> RGBColor[
              0.41839212466488235`, 0.5368119622102567, 0.9478805541073853], 
             274 -> RGBColor[
              0.1864932290235841, 0.3133465864304147, 0.9339318855496603], 87 -> 
             RGBColor[
              0.5824632480680465, 0.671908930308765, 0.9602727870025479], 130 -> 
             RGBColor[
              0.7176605510414849, 0.7793611439865926, 0.9724933548748118], 35 -> 
             RGBColor[
              0.6152593623132294, 0.6985342933011143, 0.9628546172520537], 31 -> 
             RGBColor[
              0.39845195233112995`, 0.5195407871569628, 0.9466099839586806], 
             18 -> RGBColor[
              0.4420508549424184, 0.5573039652542994, 0.9493880674800761], 24 -> 
             RGBColor[
              0.4993173295177782, 0.6044073279487119, 0.9537272357207356], 
             151 -> RGBColor[
              0.9254130333126405, 0.9433632493686274, 0.9927479153149688], 
             137 -> RGBColor[
              0.4106084192231799, 0.5300701077770648, 0.9473845832795004], 
             296 -> RGBColor[
              0.8201435803971269, 0.8594242450769743, 0.982707220920737], 266 -> 
             RGBColor[
              0.7699061027504018, 0.8201757660624983, 0.977700703206717], 283 -> 
             RGBColor[
              0.4584559616607367, 0.5712342287387211, 0.9505104791629069], 
             284 -> RGBColor[
              0.4779395986165179, 0.5870519229472666, 0.9520443024349798], 
             238 -> RGBColor[
              0.9369799588431549, 0.9525203370078473, 0.9915606708061119], 72 -> 
             RGBColor[
              0.397838025602837, 0.51900903468177, 0.9465708650904279], 288 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 172 -> 
             RGBColor[
              0.7735293923192907, 0.8230063074117349, 0.9780618388493777], 
             243 -> RGBColor[
              0.24306159935685662`, 0.3728035302925178, 0.9371533705547358], 
             88 -> RGBColor[
              0.24219828088041662`, 0.3718961278362265, 0.9371042058446677], 
             273 -> RGBColor[
              0.4523265775206957, 0.5662042796787693, 0.9500428274362992], 
             202 -> RGBColor[
              0.9939411730023949, 0.9894491066305273, 0.5819122559357318], 98 -> 
             RGBColor[
              0.9261155770021112, 0.9439234386365709, 0.9928149245592386], 30 -> 
             RGBColor[
              0.3267772376128158, 0.45745975174386744`, 0.9420429345162913], 
             116 -> RGBColor[
              0.9891831585861137, 0.989794972342283, 0.8289265855237283], 240 -> 
             RGBColor[
              0.2615432737294446, 0.3922289418639433, 0.9382058745690676], 73 -> 
             RGBColor[
              0.277455231790087, 0.4089534186620895, 0.9391120370409887], 29 -> 
             RGBColor[
              0.9512887655114114, 0.9631918215925125, 0.9673395934512256], 75 -> 
             RGBColor[
              0.3455723436903502, 0.4737391279587288, 0.9432405420556921], 
             200 -> RGBColor[
              0.7099916212288316, 0.7733701177309227, 0.9717289876213102], 
             156 -> RGBColor[
              0.8341784028717822, 0.8706152315531573, 0.9840458748174036], 25 -> 
             RGBColor[
              0.5905625034015828, 0.6784842706558245, 0.9609103900509538], 38 -> 
             RGBColor[
              0.9866814599209532, 0.988760455653516, 0.8703862065940488], 3 -> 
             RGBColor[
              0.8940742431511792, 0.9183745487626755, 0.9897587935329003], 57 -> 
             RGBColor[
              0.3960135613889977, 0.5174287754799801, 0.9464546118440323], 
             227 -> RGBColor[
              0.7465444285040961, 0.8019254485859838, 0.9753722298451035], 39 -> 
             RGBColor[
              0.4878569361827492, 0.5951032643544992, 0.952825031576598], 109 -> 
             RGBColor[
              0.27470808682292813`, 0.4060659951225544, 0.9389555911991458], 
             256 -> RGBColor[
              0.19003257266048992`, 0.31706666100015046`, 0.9341334459337924],
              287 -> RGBColor[
              0.9408576172742646, 0.9554122883166861, 0.9849968065375354], 
             239 -> RGBColor[
              0.24751107879278922`, 0.3774802152929733, 0.9374067618261972], 
             285 -> RGBColor[
              0.504692464341047, 0.6087711045453059, 0.9541503860237909], 216 -> 
             RGBColor[
              0.2568528667966404, 0.38729902678859013`, 0.9379387628330796], 
             21 -> RGBColor[
              0.9944712191250719, 0.9919817212720992, 0.7412897373312036], 
             175 -> RGBColor[
              0.4276343348406907, 0.5448171001375517, 0.9484694595672222], 7 -> 
             RGBColor[
              0.4139041155306846, 0.5329246742721125, 0.9475945821339448], 13 -> 
             RGBColor[
              0.6968789968030307, 0.7631264358698502, 0.9704220437629886], 
             294 -> RGBColor[
              0.9278223604710003, 0.94528438144526, 0.9929777190901649], 193 -> 
             RGBColor[
              0.30395646250124797`, 0.43680789241459483`, 0.9406212429249319],
              60 -> RGBColor[
              0.7991021406427353, 0.8429839327620956, 0.9806106914113384], 65 -> 
             RGBColor[
              0.7158792845184703, 0.7779696050406866, 0.9723158148746798], 69 -> 
             RGBColor[
              0.3122346750464142, 0.4448637149792978, 0.9411162952890433], 
             217 -> RGBColor[
              0.7178415947417269, 0.7795025767012049, 0.9725113996189023], 
             214 -> RGBColor[
              0.5063663943864427, 0.6101300763658473, 0.9542821639287723], 
             170 -> RGBColor[
              0.9556760206565822, 0.9664638292963098, 0.9599131148698532], 74 -> 
             RGBColor[
              0.6060687030874358, 0.6910729021071352, 0.9621310948913051], 
             246 -> RGBColor[
              0.4229360120548922, 0.5407476490850625, 0.9481700865938748], 
             264 -> RGBColor[
              0.4939657857007103, 0.6000627035937146, 0.9533059425881051], 
             278 -> RGBColor[
              0.9726224261168775, 0.9791024307414059, 0.931227270755985], 45 -> 
             RGBColor[
              0.7736537191342328, 0.8231034324644864, 0.978074230584391], 237 -> 
             RGBColor[
              0.6184645525119521, 0.7011364110966103, 0.9631069415654957], 
             228 -> RGBColor[
              0.39847040780612075`, 0.5195567723618006, 0.9466111599252275], 
             180 -> RGBColor[
              0.35541692588265655`, 0.48226601025061655`, 0.9438678301277635],
              53 -> RGBColor[
              0.6221559038656614, 0.704133216419035, 0.9633975382659252], 48 -> 
             RGBColor[
              0.7444780195020518, 0.8003111541682968, 0.9751662695074698], 5 -> 
             RGBColor[
              0.7949811018945926, 0.8397645459709919, 0.9801999447822202], 
             101 -> RGBColor[
              0.5158723467273136, 0.6178474367144391, 0.9550305073184964], 
             267 -> RGBColor[
              0.8695941724444349, 0.8988548048749352, 0.9874238625352739], 
             120 -> RGBColor[
              0.4103143233394802, 0.529815376704293, 0.9473658437498499], 147 -> 
             RGBColor[
              0.3650727148716035, 0.49062936935877666`, 0.9444830884638603], 
             89 -> RGBColor[
              0.29929495028670605`, 0.43190834752016627`, 0.940355776700403], 
             43 -> RGBColor[
              0.8251394496233515, 0.8634078155887084, 0.9831837313873995], 
             199 -> 
             RGBColor[
              0.26947242075084066`, 0.40056297812038844`, 0.9386574277618143],
              268 -> RGBColor[
              0.42946579000086116`, 0.5464034145456784, 0.948586158270536], 
             169 -> RGBColor[
              0.4483279623921215, 0.5627408802306384, 0.949788039216143], 20 -> 
             RGBColor[
              0.8463572472938727, 0.8803263115094071, 0.9852075038705654], 4 -> 
             RGBColor[
              0.54446329328334, 0.6410588551360856, 0.957281291363475], 167 -> 
             RGBColor[
              0.2421776653082504, 0.37187445956277704`, 0.9371030318183309], 
             142 -> RGBColor[
              0.7690591469329695, 0.8195141177408175, 0.9776162865660875], 16 -> 
             RGBColor[
              0.44898604103366546`, 0.5633108748739495, 0.949829971405266], 
             281 -> RGBColor[
              0.28011032656887336`, 0.4117440916173259, 0.9392632407607798], 
             289 -> RGBColor[
              0.9937843804507656, 0.9891137432167507, 0.5648463543023381], 
             178 -> RGBColor[
              0.26625979595624427`, 0.3971863057690909, 0.9384744735324145], 
             58 -> RGBColor[
              0.6225998139773913, 0.70449360264566, 0.9634324844960169], 186 -> 
             RGBColor[
              0.4425522782767134, 0.5577382729441962, 0.9494200177315462], 
             122 -> RGBColor[
              0.6824575166352553, 0.7518602659554753, 0.9689846453962593], 
             249 -> RGBColor[
              0.2477893136316296, 0.37777265774970226`, 0.9374226068886576], 
             113 -> RGBColor[
              0.6268357130936961, 0.7079324963733568, 0.9637659499910621], 52 -> 
             RGBColor[
              0.586539387767822, 0.6752181241450436, 0.960593675651106], 187 -> 
             RGBColor[
              0.7187220629897303, 0.7801904051883516, 0.9725991564654197], 
             259 -> RGBColor[
              0.39704095110187126`, 0.5183186488111627, 0.9465200762080517], 
             42 -> RGBColor[
              0.36027618213981194`, 0.48647485378724364`, 0.9441774576395979],
              134 -> RGBColor[
              0.419101090027824, 0.5374260323740014, 0.9479257287533984], 248 -> 
             RGBColor[
              0.6895850079769036, 0.7574283163625115, 0.9696950471230013], 
             174 -> RGBColor[
              0.22709207840622284`, 0.3560185512472927, 0.9362439299613863], 
             215 -> RGBColor[
              0.41287123737922327`, 0.5320300471312821, 0.947528768051472], 
             83 -> 
             RGBColor[
              0.29186645811488066`, 0.4241005312539708, 0.9399327350606869], 
             95 -> RGBColor[
              0.9531228242709844, 0.9645596596124064, 0.9642350103704034], 
             166 -> RGBColor[
              0.6312878022440195, 0.71154690290992, 0.9641164347575155], 233 -> 
             RGBColor[
              0.21570442378461654`, 0.3440494042209796, 0.9355954198772112], 
             295 -> RGBColor[
              0.4933923581392058, 0.5995971692666681, 0.9532608002699291], 
             141 -> RGBColor[
              0.982405983373221, 0.9863989917240821, 0.9146662602813969], 205 -> 
             RGBColor[
              0.4950208895234849, 0.6009192844089286, 0.9533890042260066], 
             224 -> RGBColor[
              0.5794228442842807, 0.6694405935484743, 0.9600334352793238], 
             231 -> RGBColor[
              0.27486671561910364`, 0.40623272404498145`, 0.9389646248744177],
              68 -> RGBColor[0.178927, 0.305394, 0.933501], 10 -> 
             RGBColor[
              0.8415829712008118, 0.8765194333470725, 0.9847521291547626], 
             250 -> RGBColor[
              0.24924224167328835`, 0.37929977724244407`, 0.9375053489912156],
              282 -> RGBColor[
              0.3988328253710346, 0.5198706802408926, 0.9466342528519905], 
             232 -> RGBColor[
              0.39422377600587816`, 0.5158785533383509, 0.946340568302065], 
             253 -> RGBColor[
              0.444887597395223, 0.5597610089880973, 0.9495688222007359], 55 -> 
             RGBColor[
              0.9218821941447554, 0.9405478540582318, 0.9924111407231185], 91 -> 
             RGBColor[
              0.44760893267837215`, 0.5621180928320728, 0.9497422232785959], 
             105 -> RGBColor[
              0.21570442378461654`, 0.3440494042209796, 0.9355954198772112], 
             36 -> RGBColor[0.178927, 0.305394, 0.933501], 123 -> 
             RGBColor[
              0.34216185612067757`, 0.4707851350419678, 0.9430232288035282], 
             94 -> RGBColor[
              0.31396276690037417`, 0.4463605012867758, 0.941226407773886], 
             96 -> RGBColor[
              0.3253857891911297, 0.4562545490572341, 0.9419542726532709], 2 -> 
             RGBColor[
              0.4191454445275317, 0.5374644500123263, 0.9479285549828986], 
             262 -> RGBColor[
              0.3988328253710346, 0.5198706802408926, 0.9466342528519905], 
             272 -> RGBColor[
              0.38737368542052547`, 0.509945349168882, 0.9459040865872637], 
             97 -> 
             RGBColor[
              0.479513207264082, 0.5883294493376209, 0.9521681826720345], 209 -> 
             RGBColor[
              0.49885741906173753`, 0.6040339519217682, 0.9536910298849286], 
             66 -> RGBColor[
              0.40566395646537556`, 0.5257874626521788, 0.9470695264847898], 
             139 -> RGBColor[
              0.7735293923192907, 0.8230063074117349, 0.9780618388493777], 56 -> 
             RGBColor[
              0.4774545573564216, 0.5866581446014607, 0.9520061182102204], 
             144 -> RGBColor[
              0.2883644866417613, 0.42041973719790665`, 0.9397333029659953], 
             298 -> RGBColor[
              0.9587781758750935, 0.9687774115789627, 0.9546619752565745], 
             204 -> RGBColor[
              0.8340850147874372, 0.8705407664296526, 0.9840369673785503], 
             207 -> RGBColor[
              0.21668973846134912`, 0.34508503241878435`, 0.9356515320904086],
              149 -> RGBColor[
              0.6568215944637871, 0.7318332887148995, 0.9664294962555208], 
             219 -> RGBColor[
              0.6463042842786991, 0.7236170860637908, 0.9653812290661229], 9 -> 
             RGBColor[
              0.28280077393078995`, 0.4145719223789155, 0.9394164577578809], 
             11 -> RGBColor[
              0.3290949232907396, 0.45946721458781575`, 0.9421906153982396], 
             44 -> RGBColor[
              0.9017002092393517, 0.9244552871200493, 0.9904861649861705], 
             153 -> RGBColor[
              0.8409117065936764, 0.8759841851703352, 0.9846881033372891], 32 -> 
             RGBColor[
              0.6156218179553561, 0.6988285511198333, 0.9628831510879207], 
             162 -> RGBColor[
              0.9583131855651852, 0.9684306225671847, 0.9554490825623534], 90 -> 
             RGBColor[
              0.9850673749079383, 0.9880929900205415, 0.897135772377819], 8 -> 
             RGBColor[
              0.32126240486774027`, 0.45268308080363623`, 0.9416915342503501],
              163 -> RGBColor[
              0.26625979595624427`, 0.3971863057690909, 0.9384744735324145], 
             49 -> RGBColor[
              0.3061724353620503, 0.43913702039209235`, 0.9407474393011165], 
             76 -> RGBColor[
              0.3356049006027803, 0.46510582973453196`, 0.9426054253960159], 
             82 -> RGBColor[
              0.30376232793929336`, 0.43660384468113833`, 0.9406101872488248],
              67 -> RGBColor[
              0.5755696646617934, 0.6663124087471752, 0.9597300988647797], 
             211 -> 
             RGBColor[
              0.8587916013152215, 0.8902411278844822, 
               0.9863935036574005]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJwtl3k4FGrYxsc2dmbMmGEYZp8hUUJS8qQSUSklLeLUoUhCylJkaUGShISD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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 5}], {
             RGBColor[
             0.7406592351638395, 0.7973278908194492, 0.9747856487732054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 32}], {
             RGBColor[
             0.6509795931942212, 0.7268598933938699, 0.9661272519260556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 51}], {
             RGBColor[
             0.5218699088945237, 0.6194385032778941, 0.9566828493459718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 80}], {
             RGBColor[
             0.5469856590023834, 0.6411925036670172, 0.9582832027338588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 83}], {
             RGBColor[
             0.48910191327398345`, 0.5894958834609387, 0.9546520439124387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 92}], {
             RGBColor[
             0.8314635370226398, 0.8684762284805474, 0.946941527083408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 125}], {
             RGBColor[
             0.7969385772778106, 0.8420014214417573, 0.9802072509032655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 128}], {
             RGBColor[
             0.5116686380407724, 0.6106026751951561, 0.9560328333878004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 142}], {
             RGBColor[
             0.7276982576830279, 0.7872026767043621, 0.973493819665139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 149}], {
             RGBColor[
             0.6715794814484366, 0.7433622621914031, 0.9679004245098557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 150}], {
             RGBColor[
             0.7584357073144348, 0.8113002780655245, 0.9765348127942409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 197}], {
             RGBColor[
             0.5185245192160544, 0.6165408948825781, 0.9564696840738718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 198}], {
             RGBColor[
             0.7199664173432238, 0.781162504266744, 0.9727231820782234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 237}], {
             RGBColor[
             0.6524009604725192, 0.7280138233822584, 0.9662391471648432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 243}], {
             RGBColor[
             0.4646994838949714, 0.5638473829802122, 0.9532623616594632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 256}], {
             RGBColor[
             0.43818497054678807`, 0.5359789483340285, 0.9517523993489916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 277}], {
             RGBColor[
             0.6337879714264611, 0.7129029603690676, 0.964773864485512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 281}], {
             RGBColor[
             0.4832238475009798, 0.5833176636426163, 0.9543172967624852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 49}], {
             RGBColor[
             0.36265893994479104`, 0.48830073520220935`, 0.9443379971420076]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 54}], {
             RGBColor[
             0.4860087262822762, 0.5926749392968663, 0.9529359055869602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 102}], {
             RGBColor[
             0.3936302932063519, 0.5153645083667141, 0.9463027521028755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 165}], {
             RGBColor[
             0.6944403813881583, 0.7572068402164569, 0.9420214731406178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 172}], {
             RGBColor[
             0.5963374184234113, 0.6802353787120305, 0.9629951969161381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 174}], {
             RGBColor[
             0.3231187614668773, 0.44674150062980955`, 0.9420862424721425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 183}], {
             RGBColor[
             0.4592066124987984, 0.5709157759059729, 0.9508259450105471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 238}], {
             RGBColor[
             0.6780627016853433, 0.7449923935100868, 0.9697446128945053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 253}], {
             RGBColor[
             0.4320165209613773, 0.5486127295002119, 0.9487486885918173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 24}], {
             RGBColor[
             0.6966957863344787, 0.7613909383556937, 0.971743014626818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 59}], {
             RGBColor[
             0.7776732147214903, 0.8268423368196853, 0.9783159415943461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 65}], {
             RGBColor[
             0.8049767638348247, 0.8481720769016811, 0.9810373042037901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 72}], {
             RGBColor[
             0.6459561343770082, 0.7186917917222228, 0.968164829311664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 106}], {
             RGBColor[
             0.5892976703521391, 0.6673773201717276, 0.9646366105880404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 115}], {
             RGBColor[
             0.707515911888372, 0.7701752037214458, 0.9725948145458463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 155}], {
             RGBColor[
             0.6682145683679741, 0.7379709285037763, 0.9695831170432081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[
             0.9261937143581822, 0.9434025856649302, 0.9726039380476268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 169}], {
             RGBColor[
             0.6712011027716503, 0.740557714496657, 0.9697734163745216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 194}], {
             RGBColor[
             0.6037466088539702, 0.6821320222266058, 0.965475275669754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 200}], {
             RGBColor[
             0.8020329321900055, 0.8458723332467991, 0.9807438905771053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 210}], {
             RGBColor[
             0.897866467684731, 0.921398365668537, 0.9901204992942694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 227}], {
             RGBColor[
             0.8203093358276377, 0.8601499986743297, 0.982565511689002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 228}], {
             RGBColor[
             0.64627232547865, 0.7189656605622381, 0.9681849767290639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 241}], {
             RGBColor[
             0.5819460205321136, 0.6596502700893605, 0.9642179450065813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 264}], {
             RGBColor[
             0.6940200144259447, 0.759218626178195, 0.9715323680605027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 290}], {
             RGBColor[
             0.8975648723820829, 0.9211578817607918, 0.9900917328650654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 291}], {
             RGBColor[
             0.9289726888735863, 0.9454751403083654, 0.9678998590656818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 8}], {
             RGBColor[
             0.4328628490755401, 0.5468709679698609, 0.9494864128069125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 15}], {
             RGBColor[
             0.47816156911593494`, 0.5861064424889814, 0.9523728071918012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 62}], {
             RGBColor[
             0.696341551849566, 0.7614351619604911, 0.9713332240836694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 85}], {
             RGBColor[
             0.4981598824546194, 0.6034279763584955, 0.953647082033928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 121}], {
             RGBColor[
             0.7133793221758717, 0.775020617540732, 0.9729583018271895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 135}], {
             RGBColor[
             0.44778895136495234`, 0.5597992075652355, 0.9504374908461599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 158}], {
             RGBColor[
             0.4600487033443955, 0.570417988536778, 0.951218671401417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 173}], {
             RGBColor[
             0.7457851843743135, 0.8005659895695438, 0.9658496976516759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 186}], {
             RGBColor[
             0.4935077857800267, 0.5993985640401409, 0.9533506545475106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 213}], {
             RGBColor[
             0.40300328350639225`, 0.5166438985000145, 0.9477435829662713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 214}], {
             RGBColor[
             0.5254148438348913, 0.6255944657509664, 0.9557817276461236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 249}], {
             RGBColor[
             0.3961263034574848, 0.5094157564428939, 0.9473519491260662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 255}], {
             RGBColor[
             0.47302587722501344`, 0.581658164300445, 0.9520455654458257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 263}], {
             RGBColor[
             0.588634886075693, 0.6769193440724963, 0.9607586409539648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 265}], {
             RGBColor[
             0.4468190150852769, 0.5589590975101955, 0.9503756873640999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 276}], {
             RGBColor[
             0.39539168853391393`, 0.5086436295809447, 0.9473101138929343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 286}], {
             RGBColor[
             0.5573633485756806, 0.651531701163276, 0.9582968309705475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.5620380125926661, 0.6496158802794039, 0.9611952800902299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 23}], {
             RGBColor[
             0.48695405094729627`, 0.5725792729854959, 0.9568504723911101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 51}], {
             RGBColor[
             0.5761917756252768, 0.6618751584294367, 0.9620971453549867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.728126644093197, 0.7875373354238435, 0.973536517219006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[
             0.5434237800047366, 0.6319325386124813, 0.9600663399214535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 92}], {
             RGBColor[
             0.8857854037533929, 0.9109128836320901, 0.9523558230924227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 101}], {
             RGBColor[
             0.6554267243109531, 0.7288059913427155, 0.9676152260503583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 128}], {
             RGBColor[
             0.5659905047715256, 0.6530393303466988, 0.9614471293968152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 142}], {
             RGBColor[
             0.782020124413781, 0.8296393318559048, 0.9789081156741538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 149}], {
             RGBColor[
             0.7259013481791898, 0.7857989173429457, 0.9733147205188705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 197}], {
             RGBColor[
             0.5728463859468075, 0.6589775500341208, 0.9618839800828864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 198}], {
             RGBColor[
             0.7742882840739769, 0.8235991594182868, 0.9781374780872382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 204}], {
             RGBColor[
             0.8145330583410149, 0.8551526562003222, 0.9821184560803853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 226}], {
             RGBColor[
             0.7686960199759738, 0.8192304402021453, 0.9775800934646285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 243}], {
             RGBColor[
             0.5190213506257246, 0.6062840381317549, 0.958676657668478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 256}], {
             RGBColor[
             0.49250683727754124`, 0.5784156034855712, 0.9571666953580062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 290}], {
             RGBColor[
             0.8480183017537897, 0.88185288036495, 0.9853123084897253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 38}], {
             RGBColor[
             0.6501688904045795, 0.7174277644034879, 0.9057965439495095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 52}], {
             RGBColor[
             0.4500978543280138, 0.5606565986492517, 0.950900278478038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.4679061123769335, 0.5751141447862474, 0.9523022097854477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 88}], {
             RGBColor[
             0.2779273008843111, 0.4089956004948432, 0.9391555435748189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 93}], {
             RGBColor[
             0.33255732766103135`, 0.4624661752278588, 0.9424112367430306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 124}], {
             RGBColor[
             0.36035606012168914`, 0.48654404008036156`, 0.9441825473939698]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 147}], {
             RGBColor[
             0.3393645178799045, 0.46836222125611826`, 0.9428449848844153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 273}], {
             RGBColor[
             0.38299144920445066`, 0.5061496764161145, 0.9456248543706347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 289}], {
             RGBColor[
             0.6537203506694855, 0.7176044081851052, 0.7530266178036542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 42}], {
             RGBColor[
             0.3870901488352483, 0.5096997640296781, 0.9458860198867713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 60}], {
             RGBColor[
             0.6065031280867099, 0.6879543035171041, 0.9641026367726415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 77}], {
             RGBColor[
             0.5340777423012587, 0.6313750416881905, 0.9568839511712588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 80}], {
             RGBColor[
             0.41076903255118263`, 0.5302092229691202, 0.9473948174187359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 81}], {
             RGBColor[
             0.3901762299639612, 0.5123727723924216, 0.9460826622473786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 82}], {
             RGBColor[
             0.358833221734989, 0.48476425947662544`, 0.9441023846913847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 103}], {
             RGBColor[
             0.4902048376351375, 0.595939217155085, 0.9533055607281691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 127}], {
             RGBColor[
             0.7024222758219052, 0.7617231630158937, 0.8736992656733129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 130}], {
             RGBColor[
             0.5657823332860847, 0.6561429091293526, 0.9600439685043782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 140}], {
             RGBColor[
             0.33340869722267874`, 0.45804147220622815`, 0.9426544956326222]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 145}], {
             RGBColor[
             0.5791671102039815, 0.6665991985856858, 0.9613780379797023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 154}], {
             RGBColor[
             0.405901601441348, 0.5259932987859823, 0.9470846690125176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 167}], {
             RGBColor[
             0.3280408904194675, 0.45239956691744476`, 0.9423488069761379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 168}], {
             RGBColor[
             0.4146688325750848, 0.5335870337401758, 0.9476433092278012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 181}], {
             RGBColor[
             0.5014208455749564, 0.6050448776760295, 0.9541885259587826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 201}], {
             RGBColor[
             0.4713898757180724, 0.5806643834664365, 0.9518243780045813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 202}], {
             RGBColor[
             0.7039226442665398, 0.7611868904513199, 0.7647534190348383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 203}], {
             RGBColor[
             0.6754420371869198, 0.74272250563998, 0.9695776264700283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 205}], {
             RGBColor[
             0.45446250252708476`, 0.5669219793405206, 0.9504917931799757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 216}], {
             RGBColor[
             0.3353784911636625, 0.4601118505303513, 0.9427666724835122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 237}], {
             RGBColor[
             0.5161843340213184, 0.6170305426843614, 0.9553507618497202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 255}], {
             RGBColor[
             0.40774628834868576`, 0.5275910738684584, 0.9472022108310606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 269}], {
             RGBColor[
             0.4396870549015473, 0.5549266053317792, 0.9493286158186454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 282}], {
             RGBColor[
             0.4063684704508596, 0.5263976772565025, 0.9471144174929677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 293}], {
             RGBColor[
             0.43203564052311455`, 0.5486292899036116, 0.9487499068733845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 299}], {
             RGBColor[
             0.6533444539432097, 0.7251355249858551, 0.9686151933494347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 14}], {
             RGBColor[
             0.33099599608338065`, 0.4611138282901046, 0.942311750075534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 64}], {
             RGBColor[
             0.3204532104284204, 0.4519821972515925, 0.9416399730962193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 67}], {
             RGBColor[
             0.4484160347647668, 0.5594977447754057, 0.9507108165575648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 69}], {
             RGBColor[
             0.31674853995707725`, 0.448773397891467, 0.9414039147696966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 85}], {
             RGBColor[
             0.38655943824681954`, 0.5092400891922709, 0.9458522034773655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 121}], {
             RGBColor[
             0.601778877968072, 0.6808327303745073, 0.9651634232706271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 135}], {
             RGBColor[
             0.3361885071571525, 0.46561132039901076`, 0.9426426122895974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 173}], {
             RGBColor[
             0.6341847401665137, 0.7063781024033191, 0.9580548190951135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 186}], {
             RGBColor[
             0.38190734157222683`, 0.5052106768739162, 0.9455557759909481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 213}], {
             RGBColor[
             0.29140283929859245`, 0.42245601133378974`, 0.9399487044097088]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 234}], {
             RGBColor[
             0.3088505967432664, 0.44079471065985815`, 0.9409423283845391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 249}], {
             RGBColor[
             0.28452585924968493`, 0.4152278692766692, 0.9395570705695039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 263}], {
             RGBColor[
             0.4770344418678932, 0.5827314569062716, 0.9529637623974023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 286}], {
             RGBColor[
             0.4457629043678807, 0.5573438139970512, 0.950501952413985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 45}], {
             RGBColor[
             0.5282272465325113, 0.6188376774217009, 0.958745344171136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 47}], {
             RGBColor[
             0.38645088688432117`, 0.5057485093512715, 0.9462090751228422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 96}], {
             RGBColor[
             0.3040932815609598, 0.4354132357180748, 0.9406853652055759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 112}], {
             RGBColor[
             0.23641667329563992`, 0.365819291689533, 0.9367749518458366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 132}], {
             RGBColor[
             0.41418264450075976`, 0.52826239948574, 0.9483922206671838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 133}], {
             RGBColor[
             0.3289147107242811, 0.45691231009803945`, 0.9422669647231348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 141}], {
             RGBColor[
             0.6326033786520056, 0.7004854570514988, 0.9270413590196389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 146}], {
             RGBColor[
             0.47579509784670393`, 0.577877284369259, 0.9535193975964221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 236}], {
             RGBColor[
             0.4231979666276658, 0.5355814441239959, 0.9491019398492269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 22}], {
             RGBColor[
             0.557124625130365, 0.6402196795263071, 0.9617957212111945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 48}], {
             RGBColor[
             0.7930304953514318, 0.8384152937576846, 0.9799591993311162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 63}], {
             RGBColor[
             0.7739273562918134, 0.8234917763350765, 0.9780551769586378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 71}], {
             RGBColor[
             0.6182318561015933, 0.6964835083726839, 0.9655672793427366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 73}], {
             RGBColor[
             0.5595191014954495, 0.642736426004581, 0.9619320830978757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 100}], {
             RGBColor[
             0.6281958560323706, 0.7051138243075252, 0.9662021766075065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 119}], {
             RGBColor[
             0.9161090771485779, 0.9334574275698317, 0.8948074554124998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 122}], {
             RGBColor[
             0.7620202439180336, 0.8141898496512738, 0.976868387275511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 161}], {
             RGBColor[
             0.5719903879910135, 0.6558445388366528, 0.962642304414183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 244}], {
             RGBColor[
             0.6782944233038907, 0.746831714804784, 0.9698572123384663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 266}], {
             RGBColor[
             0.8057445369756069, 0.8483475997047853, 0.9812264161807398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 51}], {
             RGBColor[
             0.34324868632335037`, 0.4717264927378486, 0.9430924806629963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 101}], {
             RGBColor[
             0.42248363500902664`, 0.5386573256511274, 0.948610561358368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 104}], {
             RGBColor[
             0.6308243398668758, 0.7042621413754179, 0.967809809629991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 114}], {
             RGBColor[
             0.5399274668147583, 0.6323429538713305, 0.958991507521886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 116}], {
             RGBColor[
             0.6591390409384266, 0.7246310934650493, 0.8855586004609839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 149}], {
             RGBColor[
             0.4929582588772633, 0.5956502516513577, 0.9543100558268802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 197}], {
             RGBColor[
             0.33990329664488095`, 0.46882888434253267`, 0.9428793153908962]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 198}], {
             RGBColor[
             0.5413451947720505, 0.6334504937266986, 0.9591328133952479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 204}], {
             RGBColor[
             0.5815899690390884, 0.6650039905087342, 0.9631137913883949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 243}], {
             RGBColor[
             0.2860782613237981, 0.41613537244016674`, 0.9396719929764876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 254}], {
             RGBColor[
             0.5877260852923061, 0.6698967630486115, 0.9636990596344025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 283}], {
             RGBColor[
             0.39377544247573815`, 0.5153507216632685, 0.9463505472805732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.31425783946044195`, 0.4346691427514325, 0.9416826453707101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 27}], {
             RGBColor[
             0.3528137642546136, 0.46608820226628545`, 0.9446854094637214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.24958682693815948`, 0.3786543621642321, 0.9375618656391214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 76}], {
             RGBColor[
             0.2575672692449994, 0.3855666201817237, 0.938070372366085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 87}], {
             RGBColor[
             0.38099644297763247`, 0.4889681704688402, 0.9469040531693511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 151}], {
             RGBColor[
             0.5524713355999294, 0.6246953299987714, 0.9631416173255616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 154}], {
             RGBColor[
             0.2887143626196149, 0.4125446669643838, 0.9400550376136223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 181}], {
             RGBColor[
             0.38423360675322327`, 0.491596245854431, 0.9471588945598872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 192}], {
             RGBColor[
             0.22323813628778444`, 0.35196781372677044`, 0.9360244536591377]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 220}], {
             RGBColor[
             0.32928478694172436`, 0.4469863185153334, 0.9428331221801669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 239}], {
             RGBColor[
             0.21352035834000382`, 0.3417538129609444, 0.9354710405811757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 258}], {
             RGBColor[
             0.2798115674626014, 0.40483351326687395`, 0.9394877593786501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 32}], {
             RGBColor[
             0.6562504073791934, 0.7309774934948418, 0.9666525974254546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 53}], {
             RGBColor[
             0.6595174503343461, 0.7336298261444426, 0.9669097910144568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 93}], {
             RGBColor[
             0.5241686656184439, 0.620981856586054, 0.9570188179720398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 107}], {
             RGBColor[
             0.6692812516863451, 0.7415565199362338, 0.9676784332228691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 137}], {
             RGBColor[
             0.5537437080131054, 0.6465982718234575, 0.9589033135212445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 147}], {
             RGBColor[
             0.5309758558373171, 0.6268779026143134, 0.9574525661134244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 156}], {
             RGBColor[
             0.7655286998374065, 0.8168708337115038, 0.9772339592901961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 179}], {
             RGBColor[
             0.5658851154994469, 0.6571145487432426, 0.9596769532700491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 251}], {
             RGBColor[
             0.5502161573911774, 0.643542884774593, 0.9586785411149058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 270}], {
             RGBColor[
             0.5101754707234025, 0.6088616544863945, 0.9561271839670242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 271}], {
             RGBColor[
             0.5215773470850804, 0.6187373867159109, 0.9568537014465068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 273}], {
             RGBColor[
             0.5746027871618632, 0.6646653577743098, 0.9602324355996439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 274}], {
             RGBColor[
             0.4416861129133074, 0.5382365111501324, 0.9521769646563245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 277}], {
             RGBColor[
             0.6390587856114334, 0.7170205604700395, 0.9652992099849109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 282}], {
             RGBColor[
             0.5478559110870327, 0.6414985580553714, 0.9585281483074896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 289}], {
             RGBColor[
             0.8453316886268981, 0.8761200895433005, 0.7676341990326634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 67}], {
             RGBColor[
             0.4581496259804072, 0.5679284922618741, 0.9513310323827487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 173}], {
             RGBColor[
             0.643918331382154, 0.7148088498897874, 0.9586750349202973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 186}], {
             RGBColor[
             0.3916409327878672, 0.5136414243603846, 0.946175991816132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.3011364305142328, 0.4308867588202582, 0.9405689202348927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 249}], {
             RGBColor[
             0.2942594504653253, 0.42365861676313765`, 0.9401772863946878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 46}], {
             RGBColor[
             0.4626795374269809, 0.5735374317063091, 0.951154004944696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 60}], {
             RGBColor[
             0.6054809927956326, 0.6870689813019863, 0.9640375072157329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.630039827682161, 0.7064827493133868, 0.9664247399119956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 77}], {
             RGBColor[
             0.5330556070101813, 0.6304897194730728, 0.9568188216143501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 82}], {
             RGBColor[
             0.35781108644391163`, 0.4838789372615077, 0.9440372551344761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 103}], {
             RGBColor[
             0.48918270234406014`, 0.5950538949399673, 0.9532404311712604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 127}], {
             RGBColor[
             0.7014001405308278, 0.760837840800776, 0.8736341361164043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 135}], {
             RGBColor[
             0.3814872271975473, 0.5048467949181312, 0.9455290066744861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 158}], {
             RGBColor[
             0.3937469791769905, 0.5154655758896738, 0.9463101872297432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 168}], {
             RGBColor[
             0.41364669728400744`, 0.5327017115250581, 0.9475781796708925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 186}], {
             RGBColor[
             0.42720606161262165`, 0.5444461513930366, 0.9484421703758368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 196}], {
             RGBColor[
             0.5097570133470091, 0.6117570474743095, 0.9548601162995971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 212}], {
             RGBColor[
             0.34428713433015, 0.4696644061218552, 0.9432670860684916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 214}], {
             RGBColor[
             0.4591131196674863, 0.5706420531038622, 0.9508732434744498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 225}], {
             RGBColor[
             0.5641112983832994, 0.654750661605749, 0.9599141626984862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 255}], {
             RGBColor[
             0.4067241530576084, 0.5267057516533407, 0.947137081274152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 265}], {
             RGBColor[
             0.38051729091787184`, 0.5040066848630913, 0.9454672031924262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 276}], {
             RGBColor[
             0.32908996436650895`, 0.4536912169338404, 0.9424016297212605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 286}], {
             RGBColor[
             0.4910616244082755, 0.5965792885161717, 0.9533883467988737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.4958470280222774, 0.6014723580170374, 0.9534865404166688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 39}], {
             RGBColor[
             0.4684214886082073, 0.5792070696142244, 0.951327501490932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 76}], {
             RGBColor[
             0.3922954708182229, 0.5142083523042407, 0.946217698400641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 90}], {
             RGBColor[
             0.7170267079708019, 0.7757019324472455, 0.9234828718915425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 126}], {
             RGBColor[
             0.5281714237691493, 0.6277147586817815, 0.9560312352580256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 151}], {
             RGBColor[
             0.687199537173153, 0.7533370621212885, 0.9712889433601174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 153}], {
             RGBColor[
             0.6449488738136709, 0.7196475300221423, 0.9672590373712775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 192}], {
             RGBColor[
             0.35796633786100795`, 0.48060954584928745`, 0.9441717796936935]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 220}], {
             RGBColor[
             0.4640129885149479, 0.5756280506378504, 0.9509804482147227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 222}], {
             RGBColor[
             0.479440549476439, 0.5881528396300899, 0.9521949623266293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 239}], {
             RGBColor[
             0.34824855991322734`, 0.4703955450834614, 0.9436183666157316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 248}], {
             RGBColor[
             0.5692855245052846, 0.6603695956182305, 0.9597625092641336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 285}], {
             RGBColor[
             0.4768392526873562, 0.5860409897096277, 0.9519901787145284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 40}], {
             RGBColor[
             0.3860915472887254, 0.5067400738401244, 0.9460639733228777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[
             0.3269030018614319, 0.45616184275479876`, 0.9421024593945357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 66}], {
             RGBColor[
             0.3495968890242137, 0.47581814718726634`, 0.9435484938171317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 81}], {
             RGBColor[
             0.32998908299014484`, 0.4588348511175423, 0.942299101755143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 86}], {
             RGBColor[
             0.26406901972006724`, 0.39488366104163286`, 0.9383497120667272]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 94}], {
             RGBColor[
             0.303746294241713, 0.4361046665045648, 0.9406269344616798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 97}], {
             RGBColor[
             0.3865215144235669, 0.5070891405299873, 0.9460978219107541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 120}], {
             RGBColor[
             0.35192207246126606`, 0.47783210421332345`, 0.9436966524496617]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 130}], {
             RGBColor[
             0.5055951863122683, 0.6026049878544733, 0.9562604080121426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 140}], {
             RGBColor[
             0.27322155024886235`, 0.4045035509313488, 0.9388709351403866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 162}], {
             RGBColor[
             0.6259215035741186, 0.6971397271447692, 0.9477382718559135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 169}], {
             RGBColor[
             0.3709288919875867, 0.49429485597649614`, 0.9449077501828083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 178}], {
             RGBColor[
             0.27989480876964806`, 0.41151756874572243`, 0.939250967340944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 182}], {
             RGBColor[
             0.3176108860189853, 0.4481134790473934, 0.9415103739897505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 201}], {
             RGBColor[
             0.411202728744256, 0.5271264621915571, 0.9480408175123457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 202}], {
             RGBColor[
             0.6437354972927234, 0.7076489691764406, 0.7609698585426027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 294}], {
             RGBColor[
             0.6106760910270261, 0.6855666065838069, 0.9665025901198192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 26}], {
             RGBColor[
             0.43856751017174533`, 0.5542868670919412, 0.9491661118314896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 33}], {
             RGBColor[
             0.49237943497665393`, 0.5984689032072122, 0.9532655884540737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 35}], {
             RGBColor[
             0.5286551086278239, 0.6279191292777069, 0.9561213423660648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 129}], {
             RGBColor[
             0.4422078890670809, 0.5574399803203174, 0.9493980735556398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 165}], {
             RGBColor[
             0.7058930865956017, 0.7671265978374435, 0.9427512293892064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 175}], {
             RGBColor[
             0.4348425948915545, 0.5510605326959255, 0.9489287635236492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 183}], {
             RGBColor[
             0.47065931770624175`, 0.5808355335269593, 0.9515557012591358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 184}], {
             RGBColor[
             0.4342629582793527, 0.5505584805958195, 0.9488918295912722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.5107368496133495, 0.6133722794013868, 0.9547107513797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 253}], {
             RGBColor[
             0.4434692261688207, 0.5585324871211983, 0.949478444840406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 262}], {
             RGBColor[
             0.4204418401567265, 0.5385873227475959, 0.9480111601660333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 36}], {
             RGBColor[
             0.5126421236469364, 0.5928601557547035, 0.9593542519352827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 37}], {
             RGBColor[
             0.6119056999876213, 0.6908399299949224, 0.9652397633015942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 41}], {
             RGBColor[
             0.7654309048630221, 0.8168928725997788, 0.9771980898305654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 44}], {
             RGBColor[
             0.8740287282666122, 0.9023907993147282, 0.987846834428368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 55}], {
             RGBColor[
             0.8841197207193141, 0.9104370827838195, 0.9888093222968419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 61}], {
             RGBColor[
             0.7813599995559709, 0.829336802439514, 0.9787857531237052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 71}], {
             RGBColor[
             0.6206189941481237, 0.6983869474538512, 0.965794966700638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 108}], {
             RGBColor[
             0.8561943824567432, 0.8881701760663594, 0.9861457786041142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 136}], {
             RGBColor[
             0.7587695713281271, 0.8116889882143088, 0.9765341503575082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 152}], {
             RGBColor[
             0.6816435607005666, 0.7495161482959763, 0.9701606318091309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 177}], {
             RGBColor[
             0.6926817491245397, 0.7584774469232793, 0.9710295984360825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 208}], {
             RGBColor[
             0.6106254778383059, 0.6897310659150214, 0.9651581886782958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 252}], {
             RGBColor[
             0.9140106422039787, 0.9330859804641254, 0.9505648428190521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 268}], {
             RGBColor[
             0.637911518647367, 0.7133648630275428, 0.9668968310705508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 279}], {
             RGBColor[
             0.9178043549469971, 0.9350747646584077, 0.9065010575585328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 280}], {
             RGBColor[
             0.8584962486518819, 0.8900056216878697, 0.9863653326567068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 50}], {
             RGBColor[
             0.7145539252453629, 0.7714319293569587, 0.8451026885205544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 74}], {
             RGBColor[
             0.8002699611062538, 0.8415273116896171, 0.8517104161112543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[
             0.8726156147319245, 0.8986002072134722, 0.8585410684883681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 123}], {
             RGBColor[
             0.6683165376228747, 0.7313834281570335, 0.8421564830673659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 189}], {
             RGBColor[
             0.6919424769480501, 0.7518470293262626, 0.8436619070295683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 206}], {
             RGBColor[
             0.7302754612935402, 0.7847026235253735, 0.8462001926876965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 257}], {
             RGBColor[
             0.7212668751961192, 0.7772463492016288, 0.845530431755388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 287}], {
             RGBColor[
             0.9676644181996683, 0.9736970047943927, 0.8631432719343695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 300}], {
             RGBColor[
             0.9414402976516754, 0.9529196294396509, 0.8652541053975711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.508572149280985, 0.6021155399369192, 0.9570027913875481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 63}], {
             RGBColor[
             0.4894690102213667, 0.5871920225143111, 0.9550987690150696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 70}], {
             RGBColor[
             0.2698182983253723, 0.40092651738112606`, 0.9386771249780038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 73}], {
             RGBColor[
             0.27506075542500263`, 0.40643667218381563`, 0.9389756751543075]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 100}], {
             RGBColor[
             0.34373750996192387`, 0.4688140704867598, 0.9432457686639384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 119}], {
             RGBColor[
             0.6316507310781312, 0.6971576737490663, 0.8718510474689316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 122}], {
             RGBColor[
             0.47756189784758674`, 0.5778900958305084, 0.9539119793319428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 161}], {
             RGBColor[
             0.28753204192056675`, 0.41954478501588743`, 0.9396858964706148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 244}], {
             RGBColor[
             0.3938360772334438, 0.5105319609840187, 0.9469008043948981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 266}], {
             RGBColor[
             0.52128619090516, 0.61204784588402, 0.9582700082371716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 24}], {
             RGBColor[
             0.3391221647588891, 0.4549006639743559, 0.9436141178603679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 31}], {
             RGBColor[
             0.28868947616556495`, 0.4124673935784814, 0.9400554919793402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 44}], {
             RGBColor[
             0.5403136046196759, 0.6149246435600246, 0.9619935824930852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 59}], {
             RGBColor[
             0.42009959314590073`, 0.5203520624383475, 0.950187044827896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 72}], {
             RGBColor[
             0.28838251280141847`, 0.41220151734088495`, 0.9400359325452139]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 83}], {
             RGBColor[
             0.23539672905744033`, 0.3647472656269854, 0.9367168675303434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 106}], {
             RGBColor[
             0.23172404877654942`, 0.3608870457903898, 0.9365077138215903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 136}], {
             RGBColor[
             0.4250544476811907, 0.5242228324596053, 0.9506808984222255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 155}], {
             RGBColor[
             0.3106409467923845, 0.4314806541224385, 0.941454220276758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 194}], {
             RGBColor[
             0.2461729872783806, 0.37564174784526805`, 0.9373463789033039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 197}], {
             RGBColor[
             0.26481933499951116`, 0.39179227704862485`, 0.9385345076917764]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 198}], {
             RGBColor[
             0.4662612331266806, 0.5564138864327908, 0.9547880056961281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 210}], {
             RGBColor[
             0.5402928461091414, 0.6149080912871991, 0.9619916025278192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 226}], {
             RGBColor[
             0.46066896902867754`, 0.5520451672166494, 0.9542306210735184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 241}], {
             RGBColor[
             0.22437239895652406`, 0.3531599957080227, 0.9360890482401312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 290}], {
             RGBColor[
             0.5399912508064932, 0.6146676073794541, 0.9619628360986152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 291}], {
             RGBColor[
             0.5713990672979967, 0.6389848659270276, 0.9397709622992316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.5127076100698935, 0.6152781609261837, 0.954781367656012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 59}], {
             RGBColor[
             0.5802947579047898, 0.6698587264127034, 0.9603001626882638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 65}], {
             RGBColor[
             0.6075983070181242, 0.6911884664946992, 0.9630215252977077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 72}], {
             RGBColor[
             0.4485776775603076, 0.5617081813152409, 0.9501490504055817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 87}], {
             RGBColor[
             0.5408902887929123, 0.6381581291287384, 0.9570000113616417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 106}], {
             RGBColor[
             0.3919192135354385, 0.5103937097647457, 0.9466208316819581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 109}], {
             RGBColor[
             0.38701270817035316`, 0.5052366615356332, 0.9463414134599407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 155}], {
             RGBColor[
             0.47083611155127364`, 0.5809873180967945, 0.9515673381371257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 162}], {
             RGBColor[
             0.7288152575414817, 0.7864189752579482, 0.9545881591415445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 194}], {
             RGBColor[
             0.4063681520372697, 0.525148411819624, 0.9474594967636716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 210}], {
             RGBColor[
             0.7004880108680305, 0.7644147552615551, 0.972104720388187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 218}], {
             RGBColor[
             0.4057760022820962, 0.5246355214640048, 0.9474217655048894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 226}], {
             RGBColor[
             0.6208641337875667, 0.7015518311910054, 0.9643437389338863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 227}], {
             RGBColor[
             0.6229308790109371, 0.7031663882673478, 0.9645497327829196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 241}], {
             RGBColor[
             0.3845675637154131, 0.5026666596823786, 0.9462021661004989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 290}], {
             RGBColor[
             0.7001864155653824, 0.76417427135381, 0.972075953958983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 291}], {
             RGBColor[
             0.7315942320568858, 0.7884915299013835, 0.9498840801595995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 299}], {
             RGBColor[
             0.6960510609367565, 0.7608768518241548, 0.97168152014283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 28}], {
             RGBColor[
             0.5141084901963902, 0.6159901571485786, 0.9550091621077712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 58}], {
             RGBColor[
             0.606581158689487, 0.6914889366507422, 0.9621714372734853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 79}], {
             RGBColor[
             0.6039868621019981, 0.6893827698092894, 0.9619672047428967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 113}], {
             RGBColor[
             0.6086991082476394, 0.6932083835145906, 0.962338170021008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 134}], {
             RGBColor[
             0.5048317967147034, 0.607955151514913, 0.9544180594021761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 144}], {
             RGBColor[
             0.43946349502167203`, 0.5494520039268656, 0.9503218465084746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 160}], {
             RGBColor[
             0.5881363931729047, 0.6765146450771633, 0.9607193977666176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 176}], {
             RGBColor[
             0.7251461707674907, 0.7847367615556805, 0.9736966917868229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.4729897146421197, 0.5803751404532205, 0.9523891100893587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 221}], {
             RGBColor[
             0.6275750153397639, 0.7081921825542098, 0.9640569609563108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 230}], {
             RGBColor[
             0.5044773140332326, 0.6076481164330406, 0.9543954720791695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 232}], {
             RGBColor[
             0.49239313970373044`, 0.5971814119970877, 0.9536254791765094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 245}], {
             RGBColor[
             0.792172080358198, 0.8337960946800621, 0.7627301739050567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 288}], {
             RGBColor[
             0.7417335011338609, 0.3155794235519415, 0.4297821300169846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 297}], {
             RGBColor[
             0.5040674306090432, 0.6072930960123477, 0.9543693546698259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 35}], {
             RGBColor[
             0.5251717638571509, 0.6249020311153486, 0.9558993867174784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 54}], {
             RGBColor[
             0.49397808671904647`, 0.5995775987554947, 0.9534437061869625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 75}], {
             RGBColor[
             0.3903282545457113, 0.5125044484441559, 0.9460923491192976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 102}], {
             RGBColor[
             0.4015996536431222, 0.5222671678253424, 0.9468105527028777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 129}], {
             RGBColor[
             0.43872454429640784`, 0.5544228821579593, 0.9491761179070533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 165}], {
             RGBColor[
             0.7024097418249285, 0.7641094996750852, 0.94252927374062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 175}], {
             RGBColor[
             0.4313592501208815, 0.5480434345335674, 0.9487068078750627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 183}], {
             RGBColor[
             0.4671759729355687, 0.5778184353646012, 0.9513337456105493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 224}], {
             RGBColor[
             0.5072535048426765, 0.6103551812390287, 0.9544887957311134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 253}], {
             RGBColor[
             0.43998588139814765`, 0.5555153889588402, 0.9492564891918196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 262}], {
             RGBColor[
             0.41695849538605345`, 0.5355702245852378, 0.9477892045174469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 42}], {
             RGBColor[
             0.44318703638091034`, 0.5563119238454495, 0.9500064786154432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 72}], {
             RGBColor[
             0.46196795811242286`, 0.5725790142927127, 0.9512031823408581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 87}], {
             RGBColor[
             0.5542805693450277, 0.6490289621062102, 0.9580541432969181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 109}], {
             RGBColor[
             0.40040298872246843`, 0.5161074945131049, 0.9473955453952171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 140}], {
             RGBColor[
             0.3895055847683408, 0.5046536320219996, 0.946774954361294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 151}], {
             RGBColor[
             0.7257554619673245, 0.7847561216361414, 0.9742917074531285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 154}], {
             RGBColor[
             0.46199848898701007`, 0.5726054586017537, 0.9512051277411894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 155}], {
             RGBColor[
             0.4842263921033889, 0.5918581510742662, 0.952621470072402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 162}], {
             RGBColor[
             0.742205538093597, 0.7972898082354201, 0.9556422910768209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 181}], {
             RGBColor[
             0.5575177331206185, 0.6516570374918009, 0.9583089846874543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 202}], {
             RGBColor[
             0.7600195318122018, 0.8077990502670913, 0.76887387776351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 203}], {
             RGBColor[
             0.7315389247325819, 0.7893346654557514, 0.9736980851987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 216}], {
             RGBColor[
             0.3914753787093246, 0.5067240103461228, 0.946887131212184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 227}], {
             RGBColor[
             0.6363211595630525, 0.7140372212448196, 0.9656038647181959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 299}], {
             RGBColor[
             0.7094413414888718, 0.7717476848016265, 0.9727356520781064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 79}], {
             RGBColor[
             0.5275328488968056, 0.6268886563020435, 0.9560659767997142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 144}], {
             RGBColor[
             0.36300948181647946`, 0.4869578904196197, 0.944420618565292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 160}], {
             RGBColor[
             0.5116823799677122, 0.6140205315699174, 0.954818169823435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 176}], {
             RGBColor[
             0.6486921575622981, 0.7222426480484346, 0.9677954638436403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 221}], {
             RGBColor[
             0.5511210021345713, 0.6456980690469639, 0.9581557330131283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 230}], {
             RGBColor[
             0.42802330082803997`, 0.5451540029257947, 0.9484942441359869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 232}], {
             RGBColor[
             0.4159391264985379, 0.5346872984898419, 0.9477242512333268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 240}], {
             RGBColor[
             0.3495988753603211, 0.47286249275263803`, 0.9436569043668281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 245}], {
             RGBColor[
             0.7157180671530053, 0.7713019811728162, 0.7568289459618742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 288}], {
             RGBColor[
             0.6907641589970659, 0.2739166812137776, 0.42584797805486296`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 297}], {
             RGBColor[
             0.4276134174038507, 0.5447989825051018, 0.9484681267266433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 43}], {
             RGBColor[
             0.8882141075673815, 0.9132998185906105, 0.9752616624193124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 78}], {
             RGBColor[
             0.891425204892687, 0.9158602604348942, 0.9755679397487806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 99}], {
             RGBColor[
             0.6698097058164751, 0.7369830210111845, 0.9566523283640753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 131}], {
             RGBColor[
             0.6674759176093004, 0.7349616109657356, 0.9565036214432021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 170}], {
             RGBColor[
             0.9534823930839968, 0.9648278254444111, 0.9636263541605394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 178}], {
             RGBColor[
             0.6087742807338279, 0.6801890636808017, 0.95290703349182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 182}], {
             RGBColor[
             0.6464903579831651, 0.7167849739824728, 0.9551664401406265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 190}], {
             RGBColor[
             0.9724399366538601, 0.9759460870721215, 0.755574706028256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 199}], {
             RGBColor[
             0.610380593131126, 0.6818773998564505, 0.95299851060652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 209}], {
             RGBColor[
             0.7250730922865745, 0.7836128867571404, 0.9605153116680771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 229}], {
             RGBColor[
             0.9167063824076803, 0.9360187851460673, 0.9779792810289343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 259}], {
             RGBColor[
             0.6741648583066413, 0.7407552352018376, 0.9569298348296387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 261}], {
             RGBColor[
             0.7106096894455265, 0.7718708447619048, 0.9593766996152394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 284}], {
             RGBColor[
             0.7146141820639647, 0.7751218722698896, 0.9596919479431028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 74}], {
             RGBColor[
             0.4664229703501258, 0.5742663269255013, 0.9520870147037982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 104}], {
             RGBColor[
             0.6296654970279141, 0.7032584099534437, 0.9677359691890168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 123}], {
             RGBColor[
             0.3344695468667467, 0.46412244339291764`, 0.9425330816599098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 189}], {
             RGBColor[
             0.3580954861919221, 0.4845860445621467, 0.9440385056221121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 236}], {
             RGBColor[
             0.4451861984686787, 0.5570253588064719, 0.950415178228432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 260}], {
             RGBColor[
             0.3608578591784551, 0.4869786732021783, 0.9442145215861435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 267}], {
             RGBColor[
             0.5981857050286254, 0.6781572783094013, 0.9647333985257827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 287}], {
             RGBColor[
             0.6338174274435402, 0.7064360200302768, 0.9635198705269133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 300}], {
             RGBColor[
             0.6075933068955475, 0.6856586446755351, 0.965630703990115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 37}], {
             RGBColor[
             0.3879530525062499, 0.5104471678187001, 0.9459410033456518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 44}], {
             RGBColor[
             0.6500760807852408, 0.7219980371385061, 0.9685480744724255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 59}], {
             RGBColor[
             0.5298620693114657, 0.6274254560168289, 0.9567415368072363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 61}], {
             RGBColor[
             0.5574073520745995, 0.6489440402632918, 0.9594869931677628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 65}], {
             RGBColor[
             0.5571656184248002, 0.6487551960988247, 0.9594628994166802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 71}], {
             RGBColor[
             0.39666634666675227`, 0.5179941852776291, 0.9464962067446956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 136}], {
             RGBColor[
             0.5348169238467557, 0.6312962260380868, 0.9572353904015658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 177}], {
             RGBColor[
             0.46872910164316833`, 0.5780846847470572, 0.9517308384801401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 194}], {
             RGBColor[
             0.35593546344394555`, 0.4827151414237495, 0.9439008708826442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 210}], {
             RGBColor[
             0.6500553222747063, 0.7219814848656806, 0.9685460945071594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 226}], {
             RGBColor[
             0.5704314451942425, 0.6591185607951309, 0.9607851130528586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 241}], {
             RGBColor[
             0.33413487512208906`, 0.4602333892865041, 0.9426435402194714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 279}], {
             RGBColor[
             0.6938517074656256, 0.7546820024821855, 0.8872022976025904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 280}], {
             RGBColor[
             0.6345436011705106, 0.7096128595116475, 0.9670665727007643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 290}], {
             RGBColor[
             0.6497537269720584, 0.7217410009579355, 0.9685173280779555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 291}], {
             RGBColor[
             0.6811615434635616, 0.746058259505509, 0.946325454278572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 80}], {
             RGBColor[
             0.5116278837635184, 0.6131611613929806, 0.9550391018957238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 92}], {
             RGBColor[
             0.7961057617837746, 0.8404448862065108, 0.943697426245273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 107}], {
             RGBColor[
             0.6286526622625079, 0.7094075775612254, 0.9639089868853351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 125}], {
             RGBColor[
             0.7615808020389455, 0.8139700791677206, 0.9769631500651306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 128}], {
             RGBColor[
             0.4763108628019074, 0.5825713329211195, 0.9527887325496655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 142}], {
             RGBColor[
             0.6923404824441628, 0.7591713344303255, 0.9702497188270041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 145}], {
             RGBColor[
             0.6800259614163172, 0.7495511370095462, 0.9690223224566903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 149}], {
             RGBColor[
             0.6362217062095716, 0.7153309199173664, 0.9646563236717207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 150}], {
             RGBColor[
             0.7230779320755697, 0.7832689357914879, 0.973290711956106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 156}], {
             RGBColor[
             0.7249001104135692, 0.7847218913364953, 0.9734645129526621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 167}], {
             RGBColor[
             0.4288997416318032, 0.5353515053413052, 0.9499930914531258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 179}], {
             RGBColor[
             0.5252565260756096, 0.6249656063682342, 0.9559075069325151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 205}], {
             RGBColor[
             0.5553213537394205, 0.649873917764381, 0.9581360776569636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 237}], {
             RGBColor[
             0.6170431852336541, 0.6999824811082218, 0.9629950463267082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 256}], {
             RGBColor[
             0.402827195307923, 0.5079476060599919, 0.9485082985108566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 269}], {
             RGBColor[
             0.5405459061138831, 0.6378785437556396, 0.9569729002956333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 277}], {
             RGBColor[
             0.5984301961875962, 0.6848716180950309, 0.961529763647377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 282}], {
             RGBColor[
             0.5072273216631953, 0.6093496156803629, 0.9547587019699556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 293}], {
             RGBColor[
             0.5328944917354503, 0.631581228327472, 0.9563941913503724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 98}], {
             RGBColor[
             0.7344117960065003, 0.791778639898348, 0.974979016993655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 126}], {
             RGBColor[
             0.5750324107577611, 0.6658762418248694, 0.9596878042694283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 153}], {
             RGBColor[
             0.6918098608022829, 0.7578090131652302, 0.9709156063826803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 157}], {
             RGBColor[
             0.5003300496706781, 0.605229499791359, 0.953806960760888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 171}], {
             RGBColor[
             0.4137463552726498, 0.5281454954661702, 0.9483362742931647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 184}], {
             RGBColor[
             0.48459153831358814`, 0.5917234185487323, 0.9527693505652699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 222}], {
             RGBColor[
             0.526301536465051, 0.6263143227731778, 0.9558515313380319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 248}], {
             RGBColor[
             0.6161465114938964, 0.6985310787613184, 0.9634190782755363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 275}], {
             RGBColor[
             0.43493374495505255`, 0.5487123338148338, 0.9496051998831265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 285}], {
             RGBColor[
             0.5237002396759682, 0.6242024728527156, 0.9556467477259312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 38}], {
             RGBColor[
             0.6629774332337732, 0.7285218804260545, 0.9066126929724361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 52}], {
             RGBColor[
             0.4629063971572077, 0.5717507146718181, 0.9517164275009646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 53}], {
             RGBColor[
             0.48071465520612744`, 0.5862082608088139, 0.9531183588083743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 57}], {
             RGBColor[
             0.36764348396779556`, 0.4928560403392865, 0.9446468955974279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 84}], {
             RGBColor[
             0.5172409711363624, 0.6150523820895974, 0.9565473635825064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 124}], {
             RGBColor[
             0.37316460295088305`, 0.4976381561029281, 0.9449986964168964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 147}], {
             RGBColor[
             0.35217306070909843`, 0.47945633727868475`, 0.9436611339073417]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 217}], {
             RGBColor[
             0.5285575006441602, 0.6238929409498989, 0.9576752894848628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 223}], {
             RGBColor[
             0.48587946570815055`, 0.5904012866464179, 0.9535249516104178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 247}], {
             RGBColor[
             0.4983372926751295, 0.6002846848024048, 0.9546632215784098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 270}], {
             RGBColor[
             0.3313726755951839, 0.4614400891507659, 0.9423357517609415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 295}], {
             RGBColor[
             0.41633288234289956`, 0.5339402372326305, 0.9480499898103762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 102}], {
             RGBColor[
             0.4916872520992007, 0.595899430011108, 0.953765783237453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 129}], {
             RGBColor[
             0.5288121427524864, 0.6280551443437249, 0.9561313484416285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 165}], {
             RGBColor[
             0.7924973402810072, 0.8377417618608509, 0.9494845042751953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 175}], {
             RGBColor[
             0.5214468485769601, 0.621675696719333, 0.9556620384096379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 183}], {
             RGBColor[
             0.5572635713916473, 0.6514506975503668, 0.9582889761451245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 224}], {
             RGBColor[
             0.597341103298755, 0.6839874434247943, 0.9614440262656887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 253}], {
             RGBColor[
             0.5300734798542261, 0.6291476511446058, 0.9562117197263948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 262}], {
             RGBColor[
             0.507046093842132, 0.6092024867710034, 0.9547444350520221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 41}], {
             RGBColor[
             0.4317157812160857, 0.5294267168450753, 0.9513448378952827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 55}], {
             RGBColor[
             0.5504045970723777, 0.6229709270291159, 0.9629560703615593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 152}], {
             RGBColor[
             0.3479284370536303, 0.46204999254127277`, 0.9443073798738482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 208}], {
             RGBColor[
             0.2769103541913695, 0.4022649101603179, 0.9393049367430131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 242}], {
             RGBColor[
             0.4261969120969441, 0.525115334344243, 0.9507947685982507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 250}], {
             RGBColor[
             0.21408462083664417`, 0.34234688862122203`, 0.9355031744956078]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 268}], {
             RGBColor[
             0.3041963950004306, 0.4258987072728392, 0.941043579135268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 41}], {
             RGBColor[
             0.5309793575567707, 0.6274064910852941, 0.9572303492615941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 44}], {
             RGBColor[
             0.6395771809603608, 0.7129044178002435, 0.9678790938593967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 55}], {
             RGBColor[
             0.6496681734130627, 0.7209507012693347, 0.9688415817278708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 61}], {
             RGBColor[
             0.5469084522497195, 0.6398504209250292, 0.958818012554734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 71}], {
             RGBColor[
             0.38616744684187226`, 0.5089005659393664, 0.9458272261316667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 108}], {
             RGBColor[
             0.6217428351504918, 0.6986837945518746, 0.966178038035143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 136}], {
             RGBColor[
             0.5243180240218757, 0.6222026066998241, 0.9565664097885369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 152}], {
             RGBColor[
             0.44719201339431525`, 0.5600297667814915, 0.9501928912401596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 161}], {
             RGBColor[
             0.3399259787312926, 0.46826159640333537`, 0.9429022512031132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 177}], {
             RGBColor[
             0.45823020181828833`, 0.5689910654087946, 0.9510618578671113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 208}], {
             RGBColor[
             0.37617393053205445`, 0.5002446844005367, 0.9451904481093246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 252}], {
             RGBColor[
             0.6795590948977273, 0.7435995989496407, 0.9305971022500807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 268}], {
             RGBColor[
             0.40345997134111555`, 0.5238784815130579, 0.9469290905015795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 279}], {
             RGBColor[
             0.6833528076407456, 0.745588383143923, 0.8865333169895617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 280}], {
             RGBColor[
             0.6240447013456305, 0.7005192401733848, 0.9663975920877356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 52}], {
             RGBColor[
             0.7866104238443876, 0.8319892898992798, 0.9154899411225774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 53}], {
             RGBColor[
             0.8044186818933073, 0.8464468360362756, 0.916891872429987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 57}], {
             RGBColor[
             0.6913475106549755, 0.7530946155667481, 0.9084204092190405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 88}], {
             RGBColor[
             0.6144398704006849, 0.6803282917448712, 0.9037452062193583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 124}], {
             RGBColor[
             0.696868629638063, 0.7578767313303897, 0.908772210038509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 147}], {
             RGBColor[
             0.6758770873962784, 0.7396949125061463, 0.9074346475289545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 247}], {
             RGBColor[
             0.8220413193623095, 0.8605232600298665, 0.9184367352000224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 289}], {
             RGBColor[
             0.9902329201858594, 0.9889370994351334, 0.7176162804481934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 64}], {
             RGBColor[
             0.40375047608592485`, 0.523192289027024, 0.9472067217593432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 69}], {
             RGBColor[
             0.4000458056145817, 0.5199834896668984, 0.9469706634328207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 76}], {
             RGBColor[
             0.41173091839276477`, 0.5301045470445156, 0.947715228486307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 85}], {
             RGBColor[
             0.469856703904324, 0.5804501809677024, 0.9514189521404895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 90}], {
             RGBColor[
             0.7364621555453438, 0.7915981271875203, 0.9249804019772085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 118}], {
             RGBColor[
             0.4371306859518076, 0.5521045490747214, 0.9493336792150366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 126}], {
             RGBColor[
             0.5476068713436911, 0.6436109534220564, 0.9575287653436917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 153}], {
             RGBColor[
             0.6643843213882128, 0.7355437247624173, 0.9687565674569436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 166}], {
             RGBColor[
             0.5595723692133844, 0.6533250836322095, 0.9584707331670568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 195}], {
             RGBColor[
             0.7388988924247011, 0.7926057805084161, 0.8845973658133583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 234}], {
             RGBColor[
             0.3921478624007709, 0.5120048024352897, 0.946509077047663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 239}], {
             RGBColor[
             0.3676840074877692, 0.4862917398237363, 0.9451158967013976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 248}], {
             RGBColor[
             0.5887209720798264, 0.6762657903585054, 0.9612600393497996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 263}], {
             RGBColor[
             0.5603317075253976, 0.6539415486817031, 0.9585305110605263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 285}], {
             RGBColor[
             0.4962747002618981, 0.6019371844499026, 0.9534877088001945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 42}], {
             RGBColor[
             0.41946472756710546`, 0.5370530848725692, 0.94813897156794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 66}], {
             RGBColor[
             0.44215861472988727`, 0.5567093893050368, 0.949585005990536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 81}], {
             RGBColor[
             0.4225508086958184, 0.5397260932353128, 0.9483356139285471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 86}], {
             RGBColor[
             0.3566307454257408, 0.4757749031594033, 0.9443862242401315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 94}], {
             RGBColor[
             0.39630801994738657`, 0.5169959086223354, 0.9466634466350841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 97}], {
             RGBColor[
             0.4790832401292405, 0.5879803826477579, 0.9521343340841583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 120}], {
             RGBColor[
             0.4444837981669396, 0.5587233463310939, 0.949733164623066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 130}], {
             RGBColor[
             0.598156912017942, 0.6834962299722438, 0.9622969201855469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 140}], {
             RGBColor[
             0.3657832759545359, 0.4853947930491193, 0.9449074473137908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 162}], {
             RGBColor[
             0.718483229279792, 0.7780309692625398, 0.9537747840293177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 169}], {
             RGBColor[
             0.4634906176932603, 0.5751860980942667, 0.9509442623562125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 178}], {
             RGBColor[
             0.3724565344753216, 0.49240881086349286`, 0.9452874795143482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 182}], {
             RGBColor[
             0.41017261172465885`, 0.529004721165164, 0.9475468861631546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 201}], {
             RGBColor[
             0.5037644544499296, 0.6080177043093276, 0.9540773296857499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 202}], {
             RGBColor[
             0.736297222998397, 0.788540211294211, 0.7670063707160069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 55}], {
             RGBColor[
             0.8031933782884635, 0.8470036438741912, 0.9807999082568419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 108}], {
             RGBColor[
             0.7752680400258926, 0.8247367371567311, 0.9781363645641141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 152}], {
             RGBColor[
             0.600717218269716, 0.6860827093863481, 0.9621512177691308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 208}], {
             RGBColor[
             0.5296991354074553, 0.6262976270053932, 0.9571487746382958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 219}], {
             RGBColor[
             0.6654044233554353, 0.7385382598769707, 0.9672849524283441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 242}], {
             RGBColor[
             0.6789856933130298, 0.7491480511893183, 0.9686386064935335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.4668734020527299, 0.5663796054662973, 0.9533470123908905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 252}], {
             RGBColor[
             0.833084299773128, 0.8696525415544971, 0.942555428779052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 268}], {
             RGBColor[
             0.5569851762165163, 0.6499314241179145, 0.9588874170305507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 80}], {
             RGBColor[
             0.3839550658557463, 0.5069843127266858, 0.9456862551715626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 81}], {
             RGBColor[
             0.36336226326852483`, 0.4891478621499872, 0.944374100000205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 82}], {
             RGBColor[
             0.33201925503955265`, 0.461539349234191, 0.9423938224442114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 87}], {
             RGBColor[
             0.4713697151039292, 0.5791918920480044, 0.9522251223210729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 130}], {
             RGBColor[
             0.5389683665906484, 0.6329179988869181, 0.9583354062572049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 140}], {
             RGBColor[
             0.3065947305272424, 0.4348165619637937, 0.9409459333854487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 145}], {
             RGBColor[
             0.5523531435085451, 0.6433742883432514, 0.959669475732529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 162}], {
             RGBColor[
             0.6592946838524986, 0.7274527381772142, 0.9498132701009756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 167}], {
             RGBColor[
             0.30122692372403115`, 0.4291746566750103, 0.9406402447289643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 181}], {
             RGBColor[
             0.47460687887952, 0.5818199674335951, 0.952479963711609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 201}], {
             RGBColor[
             0.44457590902263605`, 0.557439473224002, 0.9501158157574079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 202}], {
             RGBColor[
             0.6771086775711035, 0.7379619802088855, 0.7630448567876649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 203}], {
             RGBColor[
             0.6486280704914834, 0.7194975953975455, 0.9678690642228549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 216}], {
             RGBColor[
             0.30856452446822613`, 0.43688694028791686`, 0.9410581102363388]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 237}], {
             RGBColor[
             0.489370367325882, 0.593805632441927, 0.9536421996025468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 269}], {
             RGBColor[
             0.41287308820611096`, 0.5317016950893447, 0.9476200535714718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 293}], {
             RGBColor[
             0.4052216738276782, 0.5254043796611771, 0.9470413446262109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 299}], {
             RGBColor[
             0.6265304872477734, 0.7019106147434206, 0.9669066311022612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 66}], {
             RGBColor[
             0.6154017030443635, 0.6945976391204436, 0.9651266289360947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 78}], {
             RGBColor[
             0.8283505469486571, 0.8659682574329921, 0.9834900087168675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 97}], {
             RGBColor[
             0.6523263284437167, 0.7258686324631647, 0.967675957029717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 99}], {
             RGBColor[
             0.6067350478724451, 0.6870910180092824, 0.9645743973321623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 178}], {
             RGBColor[
             0.5456996227897979, 0.6302970606788997, 0.9608291024599069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 182}], {
             RGBColor[
             0.5834157000391351, 0.6668929709805707, 0.9630885091087134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 199}], {
             RGBColor[
             0.5473059351870961, 0.6319853968545484, 0.9609205795746069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 215}], {
             RGBColor[
             0.6190053435012874, 0.6977189313599952, 0.9653562497194357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 229}], {
             RGBColor[
             0.8536317244636504, 0.8861267821441653, 0.9859013499970212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 233}], {
             RGBColor[
             0.520421936703984, 0.603728609904844, 0.9593895756323053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 259}], {
             RGBColor[
             0.6110902003626114, 0.6908632321999355, 0.9648519037977256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 261}], {
             RGBColor[
             0.6475350315014965, 0.7219788417600028, 0.9672987685833263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 284}], {
             RGBColor[
             0.6515395241199347, 0.7252298692679875, 0.9676140169111896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 59}], {
             RGBColor[
             0.7814861977655765, 0.8298827059983722, 0.9786796273209812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 61}], {
             RGBColor[
             0.8090314805287104, 0.8514012902448351, 0.9814250836815077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 71}], {
             RGBColor[
             0.6482904751208631, 0.7204514352591723, 0.9684342972584405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 108}], {
             RGBColor[
             0.8838658634294827, 0.9102346638716805, 0.9887851091619168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 136}], {
             RGBColor[
             0.7864410523008666, 0.8337534760196299, 0.9791734809153108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 177}], {
             RGBColor[
             0.7203532300972793, 0.7805419347286005, 0.973668928993885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 194}], {
             RGBColor[
             0.6075595918980564, 0.6851723914052927, 0.9658389613963891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 204}], {
             RGBColor[
             0.8678926120133945, 0.8974980267748509, 0.9872615661823604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 226}], {
             RGBColor[
             0.8220555736483534, 0.861575810776674, 0.9827232035666036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 252}], {
             RGBColor[
             0.9416821231767181, 0.9551504682694465, 0.9532041733768546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 268}], {
             RGBColor[
             0.6655829996201064, 0.7354293508328639, 0.9695361616283533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 279}], {
             RGBColor[
             0.9454758359197366, 0.9571392524637288, 0.9091403881163354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 280}], {
             RGBColor[
             0.8861677296246213, 0.9120701094931908, 0.9890046632145093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 283}], {
             RGBColor[
             0.6800780854500442, 0.7478447579293852, 0.9704983220745387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 89}], {
             RGBColor[
             0.5364743347104695, 0.6275058899923263, 0.959215003642397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 94}], {
             RGBColor[
             0.5438082430173035, 0.634731966875631, 0.9596503191791386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 96}], {
             RGBColor[
             0.5495197541626813, 0.6396789907608602, 0.960014251618831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 120}], {
             RGBColor[
             0.5919840212368565, 0.6764594045843897, 0.9627200371671205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 131}], {
             RGBColor[
             0.5786583944207111, 0.6649174164017226, 0.9618709400097848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 132}], {
             RGBColor[
             0.6596091171024812, 0.7325281545285255, 0.9677211070804388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 141}], {
             RGBColor[
             0.8780298512537269, 0.9047512120942842, 0.9463702454328939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 146}], {
             RGBColor[
             0.7212215704484253, 0.7821430394120444, 0.9728482840096773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 188}], {
             RGBColor[
             0.6558329160389373, 0.7294624643892214, 0.9674238307000363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 236}], {
             RGBColor[
             0.6686244392293872, 0.7398471991667813, 0.9684308262624819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 260}], {
             RGBColor[
             0.5842960999391635, 0.6698005135624878, 0.9622301696201934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 281}], {
             RGBColor[
             0.5268820228515531, 0.6174237620409061, 0.9586687356725854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 294}], {
             RGBColor[
             0.8507380398026165, 0.8841939069548732, 0.985525974837278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 60}], {
             RGBColor[
             0.6563006852740836, 0.7294523831664184, 0.9677271891403014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 62}], {
             RGBColor[
             0.680859520160612, 0.7488661511778187, 0.9701144218365642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 117}], {
             RGBColor[
             0.43073574185151997`, 0.5458693215206937, 0.9491185745374169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 158}], {
             RGBColor[
             0.4445666716554415, 0.5578489777541058, 0.9499998691543119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 196}], {
             RGBColor[
             0.5605767058254602, 0.6541404493387415, 0.9585497982241656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 207}], {
             RGBColor[
             0.3650944841833905, 0.48050293299476265`, 0.9452476094798365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 212}], {
             RGBColor[
             0.39510682680860104`, 0.5120478079862872, 0.9469567679930602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 214}], {
             RGBColor[
             0.5099328121459373, 0.6130254549682941, 0.9545629253990184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 225}], {
             RGBColor[
             0.6149309908617505, 0.6971340634701809, 0.9636038446230548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 265}], {
             RGBColor[
             0.43133698339632287`, 0.5463900867275232, 0.9491568851169947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 276}], {
             RGBColor[
             0.3799096568449599, 0.49607461879827236`, 0.9460913116458292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.40774339451449104`, 0.5265898226904309, 0.9474779825705373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 112}], {
             RGBColor[
             0.34006678624917114`, 0.456995878661889, 0.9435675692107981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 131}], {
             RGBColor[
             0.43688203477252086`, 0.5518282483312932, 0.9493346709614912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 133}], {
             RGBColor[
             0.43256482367781224`, 0.5480888970703954, 0.9490595820880963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 146}], {
             RGBColor[
             0.5794452108002351, 0.669053871341615, 0.9603120149613835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 170}], {
             RGBColor[
             0.7228885102472172, 0.7816944628099687, 0.9564574036788285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 190}], {
             RGBColor[
             0.7418460538170806, 0.792812724437679, 0.7484057555465451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.7253748804424335, 0.7853876367456887, 0.9732622471349913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 70}], {
             RGBColor[
             0.5057241685464391, 0.5991221316125036, 0.9568406030979255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 71}], {
             RGBColor[
             0.5696793802522132, 0.6583793687832961, 0.9607743495190901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 73}], {
             RGBColor[
             0.5109666256460694, 0.6046322864151932, 0.9571391532742293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 100}], {
             RGBColor[
             0.5796433801829907, 0.6670096847181374, 0.9614092467838601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 119}], {
             RGBColor[
             0.867556601299198, 0.8953532879804439, 0.8900145255888534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 122}], {
             RGBColor[
             0.7134677680686536, 0.7760857100618861, 0.9720754574518645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 138}], {
             RGBColor[
             0.6644518595859892, 0.7369066455474527, 0.9677967739444073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 161}], {
             RGBColor[
             0.5234379121416336, 0.617740399247265, 0.9578493745905365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 244}], {
             RGBColor[
             0.6297419474545107, 0.7087275752153962, 0.9650642825148199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 266}], {
             RGBColor[
             0.7571920611262268, 0.8102434601153976, 0.9764334863570934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 54}], {
             RGBColor[
             0.42952222169953547`, 0.5435112244867493, 0.9493453477460692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 102}], {
             RGBColor[
             0.33714378862361116`, 0.46620079355659705`, 0.9427121942619844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 143}], {
             RGBColor[
             0.4590151745231127, 0.5674549322313129, 0.9516671410285871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 172}], {
             RGBColor[
             0.5398509138406705, 0.6310716639019136, 0.9594046390752471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 174}], {
             RGBColor[
             0.26663225688413655`, 0.3975777858196925, 0.9384956846312513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 238}], {
             RGBColor[
             0.6215761971026026, 0.6958286786999699, 0.9661540550536142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 298}], {
             RGBColor[
             0.6324753056185719, 0.7039572159855275, 0.9477047072788455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 206}], {
             RGBColor[
             0.45035816741383117`, 0.564152831610233, 0.9500131438770473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 219}], {
             RGBColor[
             0.5404704578221765, 0.6372496117528046, 0.957148434388014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 83}], {
             RGBColor[
             0.3246344537354209, 0.4540431510709262, 0.9419635404942199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 101}], {
             RGBColor[
             0.43663739804163737`, 0.5509166038011604, 0.9495124266231247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 104}], {
             RGBColor[
             0.6449781028994866, 0.7165214195254508, 0.9687116748947477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 116}], {
             RGBColor[
             0.6732928039710374, 0.7368903716150823, 0.8864604657257407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 142}], {
             RGBColor[
             0.5632307981444653, 0.6517499443143495, 0.9608053162469203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 149}], {
             RGBColor[
             0.5071120219098741, 0.6079095298013906, 0.955211921091637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 197}], {
             RGBColor[
             0.35405705967749174`, 0.4810881624925656, 0.943781180655653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 198}], {
             RGBColor[
             0.5554989578046612, 0.6457097718767315, 0.9600346786600047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 204}], {
             RGBColor[
             0.5957437320716992, 0.6772632686587671, 0.9640156566531517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 226}], {
             RGBColor[
             0.5499066937066581, 0.6413410526605902, 0.959477294037395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 243}], {
             RGBColor[
             0.30023202435640883`, 0.42839465059019965`, 0.9405738582412444]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 254}], {
             RGBColor[
             0.6018798483249169, 0.6821560411986443, 0.9646009248991593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 283}], {
             RGBColor[
             0.4079292055083489, 0.5276099998133013, 0.94725241254533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 53}], {
             RGBColor[
             0.6043476458167417, 0.6896756702820392, 0.9619956069585156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 57}], {
             RGBColor[
             0.49127647457840984`, 0.5963234498125118, 0.9535241437475692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 84}], {
             RGBColor[
             0.6408739617469768, 0.7185197915628228, 0.9654246117326477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 88}], {
             RGBColor[
             0.4143688343241193, 0.5235571259906351, 0.9488489407478868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 93}], {
             RGBColor[
             0.46899886110083955`, 0.5770277007236507, 0.9521046339160986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 124}], {
             RGBColor[
             0.49679759356149733`, 0.6011055655761535, 0.9538759445670377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 137}], {
             RGBColor[
             0.49857390349550096`, 0.6026441159610542, 0.9539891294653031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 147}], {
             RGBColor[
             0.47580605131971276`, 0.5829237467519102, 0.9525383820574831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 217}], {
             RGBColor[
             0.6521904912547745, 0.7273603504231243, 0.9665525376350041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 247}], {
             RGBColor[
             0.6219702832857439, 0.7037520942756301, 0.9635404697285511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 270}], {
             RGBColor[
             0.45500566620579824`, 0.5649074986239913, 0.9512129999110829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 271}], {
             RGBColor[
             0.466407542567476, 0.5747832308535077, 0.9519395173905656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 273}], {
             RGBColor[
             0.5194329826442589, 0.6207112019119064, 0.9553182515437026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 289}], {
             RGBColor[
             0.7901618841092938, 0.8321659336808971, 0.762720014976722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 295}], {
             RGBColor[
             0.539965872953514, 0.6374076467058558, 0.9569272379605176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 88}], {
             RGBColor[
             0.43217709237303903`, 0.5380146721276308, 0.9502508720552965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 93}], {
             RGBColor[
             0.48680711914975927`, 0.5914852468606464, 0.9535065652235082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 107}], {
             RGBColor[
             0.6319197052176606, 0.7120599102108263, 0.9641661804743373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 124}], {
             RGBColor[
             0.514605851610417, 0.6155631117131493, 0.9552778758744473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 137}], {
             RGBColor[
             0.5163821615444206, 0.6171016620980498, 0.9553910607727127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 147}], {
             RGBColor[
             0.4936143093686325, 0.5973812928889058, 0.9539403133648927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 217}], {
             RGBColor[
             0.6699987493036942, 0.74181789656012, 0.9679544689424138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 247}], {
             RGBColor[
             0.6397785413346635, 0.7182096404126259, 0.9649424010359607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 251}], {
             RGBColor[
             0.5128546109224927, 0.6140462750491854, 0.9551662883663741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 270}], {
             RGBColor[
             0.47281392425471797`, 0.579365044760987, 0.9526149312184925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 271}], {
             RGBColor[
             0.48421580061639574`, 0.5892407769905035, 0.9533414486979752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 273}], {
             RGBColor[
             0.5372412406931786, 0.6351687480489021, 0.9567201828511123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 289}], {
             RGBColor[
             0.8079701421582135, 0.8466234798178929, 0.7641219462841317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 75}], {
             RGBColor[
             0.4492221758636854, 0.5608122782700675, 0.9505918991233568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 102}], {
             RGBColor[
             0.46049357496109633`, 0.5705749976512541, 0.951310102706937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 111}], {
             RGBColor[
             0.6349896988707061, 0.7134072193636399, 0.9651907385566694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 143}], {
             RGBColor[
             0.5823649608605979, 0.6718291363259699, 0.9602650494735396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 163}], {
             RGBColor[
             0.40956590199663245`, 0.5225358671752486, 0.9482088648617182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 165}], {
             RGBColor[
             0.7613036631429027, 0.8124173295009969, 0.9470288237446793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 172}], {
             RGBColor[
             0.6632007001781557, 0.7354458679965705, 0.9680025475201997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 174}], {
             RGBColor[
             0.3899820432216217, 0.5019519899143495, 0.947093593076204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 185}], {
             RGBColor[
             0.4510573817644723, 0.5624018413811986, 0.9507088368205461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 235}], {
             RGBColor[
             0.5512216494065305, 0.6465455930973654, 0.9578133339141667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 238}], {
             RGBColor[
             0.7449259834400878, 0.8002028827946268, 0.9747519634985669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 298}], {
             RGBColor[
             0.7558250919560571, 0.8083314200801845, 0.9563026157237982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 108}], {
             RGBColor[
             0.8939568558821844, 0.9182809473407717, 0.9897475970303908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 114}], {
             RGBColor[
             0.8363211022417663, 0.8728832736065386, 0.9841017701843255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 208}], {
             RGBColor[
             0.6483879512637472, 0.7198418371894338, 0.9687600071045723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 219}], {
             RGBColor[
             0.7840932392117272, 0.8320824700610113, 0.9788961848946207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 242}], {
             RGBColor[
             0.7976745091693218, 0.842692261373359, 0.98024983895981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 250}], {
             RGBColor[
             0.5855622179090219, 0.659923815650338, 0.9649582448571671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 252}], {
             RGBColor[
             0.95177311562942, 0.9631967517385378, 0.9541666612453286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 268}], {
             RGBColor[
             0.6756739920728083, 0.7434756343019551, 0.9704986494968273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 283}], {
             RGBColor[
             0.6901690779027461, 0.7558910413984765, 0.9714608099430126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 57}], {
             RGBColor[
             0.43673405937270965`, 0.5520434600407205, 0.9492303650271263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 84}], {
             RGBColor[
             0.5863315465412765, 0.6742398017910314, 0.961130833012205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 110}], {
             RGBColor[
             0.5233318767831494, 0.6239034192617661, 0.9556177488496508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 148}], {
             RGBColor[
             0.6055881856677564, 0.6892832346325154, 0.9630501548368084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 191}], {
             RGBColor[
             0.6589481564414865, 0.7311338017736762, 0.9683246985975984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 217}], {
             RGBColor[
             0.5976480760490743, 0.6830803606513328, 0.9622587589145614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 223}], {
             RGBColor[
             0.5549700411130647, 0.6495887063478518, 0.9581084210401163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 246}], {
             RGBColor[
             0.4501952847056569, 0.5637028968432616, 0.9500881024020476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 247}], {
             RGBColor[
             0.5674278680800436, 0.6594721045038388, 0.9592466910081083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 251}], {
             RGBColor[
             0.4405039376678728, 0.5553087391403982, 0.9494705783385218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 270}], {
             RGBColor[
             0.40046325100009805`, 0.5206275088521999, 0.9469192211906401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 271}], {
             RGBColor[
             0.41186512736177583`, 0.5305032410817163, 0.9476457386701228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 278}], {
             RGBColor[
             0.7250384917366496, 0.7828802876714334, 0.9416166944831027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 295}], {
             RGBColor[
             0.4854234577478137, 0.5931276569340644, 0.9526334592400747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.5456110485575645, 0.6396251172302911, 0.958355079829111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 217}], {
             RGBColor[
             0.5569275780653623, 0.6484656760905925, 0.9594830057314674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 223}], {
             RGBColor[
             0.5142495431293528, 0.6149740217871116, 0.9553326678570223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 247}], {
             RGBColor[
             0.5267073700963316, 0.6248574199430985, 0.9564709378250142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 278}], {
             RGBColor[
             0.6843179937529376, 0.748265603110693, 0.9388409413000087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 295}], {
             RGBColor[
             0.44470295976410174`, 0.5585129723733241, 0.9498577060569807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 134}], {
             RGBColor[
             0.5208504520026076, 0.6209598175098308, 0.9556791066247077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 160}], {
             RGBColor[
             0.6041550484608089, 0.6895193110720811, 0.9619804449891491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 164}], {
             RGBColor[
             0.5215365040812325, 0.6215540413383556, 0.9557228212565057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 176}], {
             RGBColor[
             0.7411648260553949, 0.7977414275505983, 0.9749577390093545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 180}], {
             RGBColor[
             0.48900836993002395`, 0.5933798064481383, 0.9536501573118903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 187}], {
             RGBColor[
             0.6706609384835608, 0.7423420039170058, 0.9680158204807183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 215}], {
             RGBColor[
             0.5177355256783073, 0.618261824888471, 0.9554806262737445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 221}], {
             RGBColor[
             0.6435936706276681, 0.7211968485491276, 0.9653180081788424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 230}], {
             RGBColor[
             0.5204959693211368, 0.6206527824279584, 0.955656519301701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[
             0.8081907356461022, 0.8468007606749799, 0.7639912211275883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 288}], {
             RGBColor[
             0.7524126046591304, 0.3242492008818867, 0.43062282816533903`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 296}], {
             RGBColor[
             0.721371697187259, 0.7819589238613172, 0.973069852708377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 297}], {
             RGBColor[
             0.5200860858969475, 0.6202977620072654, 0.9556304018923574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 72}], {
             RGBColor[
             0.5295551059473191, 0.6271595797792324, 0.9567219773731099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 83}], {
             RGBColor[
             0.47656932220334103`, 0.5797053280653329, 0.9534029123582395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 106}], {
             RGBColor[
             0.4728966419224501, 0.5758451082287374, 0.9531937586494863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 136}], {
             RGBColor[
             0.6662270408270914, 0.7391808948979528, 0.9673669432501215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 155}], {
             RGBColor[
             0.5518135399382853, 0.6464387165607861, 0.958140265104654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[
             0.48734558042428133`, 0.5905998102836156, 0.9540324237311999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 197}], {
             RGBColor[
             0.5059919281454119, 0.6067503394869723, 0.9552205525196724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 198}], {
             RGBColor[
             0.7074338262725813, 0.7713719488711382, 0.971474050524024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 210}], {
             RGBColor[
             0.781465439255042, 0.8298661537255467, 0.9786776473557152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 226}], {
             RGBColor[
             0.7018415621745782, 0.7670032296549969, 0.9709166659014143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 227}], {
             RGBColor[
             0.7039083073979487, 0.7686177867313394, 0.9711226597504478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 241}], {
             RGBColor[
             0.4655449921024247, 0.5681180581463702, 0.9527750930680271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 290}], {
             RGBColor[
             0.781163843952394, 0.8296256698178015, 0.9786488809265113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 291}], {
             RGBColor[
             0.8125716604438974, 0.8539429283653751, 0.9564570071271277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 77}], {
             RGBColor[
             0.7266767548572841, 0.786404670933182, 0.9733920058099556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 95}], {
             RGBColor[
             0.8761124824568598, 0.903771796187251, 0.9724228508908709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 103}], {
             RGBColor[
             0.6828038501911629, 0.7509688464000766, 0.9698136153668659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 127}], {
             RGBColor[
             0.8950212883779305, 0.9167527922608852, 0.8902073203120098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 145}], {
             RGBColor[
             0.7717661227600068, 0.8216288278306774, 0.9778860926183992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 148}], {
             RGBColor[
             0.7664119773109133, 0.8174461287128328, 0.9773524414373675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 159}], {
             RGBColor[
             0.8305672246778506, 0.8679045563794401, 0.9836566483166747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 168}], {
             RGBColor[
             0.6072678451311102, 0.6886166629851673, 0.964151363866498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 196}], {
             RGBColor[
             0.7033781611941119, 0.7676719989344187, 0.9714333004952025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 205}], {
             RGBColor[
             0.64706151508311, 0.7219516085855121, 0.9669998478186725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 212}], {
             RGBColor[
             0.5379082821772527, 0.6255793575819645, 0.9598402702640971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 225}], {
             RGBColor[
             0.7577324462304023, 0.8106656130658583, 0.9764873468940917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 265}], {
             RGBColor[
             0.5741384387649746, 0.6599216363232006, 0.9620403873880317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 276}], {
             RGBColor[
             0.5227111122136117, 0.6096061683939497, 0.958974813916866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 282}], {
             RGBColor[
             0.598967483006885, 0.6814273065014941, 0.9636224721316644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 71}], {
             RGBColor[
             0.5556217464102219, 0.647397438383958, 0.9593732159537778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 108}], {
             RGBColor[
             0.7911971347188413, 0.8371806669964662, 0.979724027857254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 136}], {
             RGBColor[
             0.6937723235902253, 0.7606994791444157, 0.970112399610648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 161}], {
             RGBColor[
             0.5093802782996422, 0.6067584688479271, 0.9564482410252242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 177}], {
             RGBColor[
             0.6276845013866379, 0.7074879378533863, 0.9646078476892223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 194}], {
             RGBColor[
             0.5148908631874152, 0.6121183945300785, 0.9567778800917264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 252}], {
             RGBColor[
             0.8490133944660768, 0.8820964713942323, 0.9441430920721918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 268}], {
             RGBColor[
             0.5729142709094651, 0.6623753539576496, 0.9604750803236906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 279}], {
             RGBColor[
             0.8528071072090952, 0.8840852555885146, 0.9000793068116726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 280}], {
             RGBColor[
             0.7934990009139801, 0.8390161126179765, 0.9799435819098465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 117}], {
             RGBColor[
             0.5980960321067, 0.6788146391277714, 0.9643893095047165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 135}], {
             RGBColor[
             0.5996672099311784, 0.680175514389641, 0.9644894235663544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 158}], {
             RGBColor[
             0.6119269619106216, 0.6907942953611835, 0.9652706041216115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 186}], {
             RGBColor[
             0.6453860443462527, 0.7197748708645464, 0.967402587267705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 196}], {
             RGBColor[
             0.7279369960806402, 0.7870857669458192, 0.9738205331914652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 207}], {
             RGBColor[
             0.5324547744385706, 0.6134482506018405, 0.9605183444471361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 212}], {
             RGBColor[
             0.5624671170637812, 0.644993125593365, 0.9622275029603597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 214}], {
             RGBColor[
             0.6772931024011174, 0.7459707725753719, 0.969833660366318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 225}], {
             RGBColor[
             0.7822912811169306, 0.8300793810772586, 0.9788745795903544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 265}], {
             RGBColor[
             0.5986972736515029, 0.6793354043346009, 0.9644276200842943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 276}], {
             RGBColor[
             0.54726994710014, 0.6290199364053501, 0.9613620466131287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 286}], {
             RGBColor[
             0.7092416071419065, 0.7719080079876814, 0.972348763690742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 71}], {
             RGBColor[
             0.5505762411925949, 0.643455851360688, 0.9588703271466117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 73}], {
             RGBColor[
             0.49186348658645107`, 0.5897087689925851, 0.9552351309017508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 152}], {
             RGBColor[
             0.6116008077450379, 0.6945850522028131, 0.9632359922551046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 161}], {
             RGBColor[
             0.5043347730820152, 0.6028168818246569, 0.9559453522180581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 208}], {
             RGBColor[
             0.540582724882777, 0.6347999698218582, 0.9582335491242695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 244}], {
             RGBColor[
             0.6106388083948924, 0.6938040577927881, 0.9631602601423415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 69}], {
             RGBColor[
             0.3159393455177574, 0.44807251433942324`, 0.9413523536155658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 76}], {
             RGBColor[
             0.32762445829594045`, 0.45819357171704034`, 0.9420969186690521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 85}], {
             RGBColor[
             0.38575024380749967`, 0.5085392056402271, 0.9458006423232347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 90}], {
             RGBColor[
             0.6523556954485195, 0.7196871518600452, 0.9193620921599537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 118}], {
             RGBColor[
             0.3530242258549833, 0.4801935737472461, 0.9437153693977818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 121}], {
             RGBColor[
             0.6009696835287521, 0.6801318468224635, 0.9651118621164962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 173}], {
             RGBColor[
             0.6333755457271938, 0.7056772188512753, 0.9580032579409825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 213}], {
             RGBColor[
             0.2905936448592725, 0.421755127781746, 0.9398971432555779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 234}], {
             RGBColor[
             0.3080414023039465, 0.4400938271078144, 0.9408907672304081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 239}], {
             RGBColor[
             0.2835775473909449, 0.41438076449626104`, 0.9394975868841428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 249}], {
             RGBColor[
             0.28371666481036506`, 0.4145269857246255, 0.939505509415373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 258}], {
             RGBColor[
             0.34986875651354243`, 0.47746046480219057`, 0.9435143056816171]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 263}], {
             RGBColor[
             0.4762252474285733, 0.5820305733542279, 0.9529122012432715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 286}], {
             RGBColor[
             0.4449537099285608, 0.5566429304450076, 0.9504503912598542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 70}], {
             RGBColor[
             0.49142480105464836`, 0.5879513570486985, 0.9554153757815306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 106}], {
             RGBColor[
             0.5002001910357845, 0.5971748483107331, 0.9559151212589302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 115}], {
             RGBColor[
             0.6184184325720177, 0.6999727318604513, 0.963873325216736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 138}], {
             RGBColor[
             0.6501524920941985, 0.7257358709836474, 0.9663715466280124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 155}], {
             RGBColor[
             0.5791170890516197, 0.6677684566427818, 0.9608616277140978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 194}], {
             RGBColor[
             0.5146491295376158, 0.6119295503656114, 0.9567537863406437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 200}], {
             RGBColor[
             0.7129354528736509, 0.7756698613858046, 0.972022401247995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[
             0.8087689883683764, 0.8511958938075425, 0.981399009965159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 211}], {
             RGBColor[
             0.7873354429168459, 0.8341053664625844, 0.9793546592660402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 231}], {
             RGBColor[
             0.49537300006878693`, 0.592101164542834, 0.9556402198745487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 241}], {
             RGBColor[
             0.49284854121575916`, 0.5894477982283659, 0.955496455677471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 264}], {
             RGBColor[
             0.6049225351095903, 0.6890161543172006, 0.9628108787313925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 291}], {
             RGBColor[
             0.8398752095572318, 0.8752726684473708, 0.9591783697365716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 86}], {
             RGBColor[
             0.3201360871612291, 0.4448529765065453, 0.9418707447343854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 97}], {
             RGBColor[
             0.44258858186472877`, 0.5570584559948999, 0.9496188545784121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 162}], {
             RGBColor[
             0.6819885710152804, 0.7471090426096818, 0.9512593045235715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 169}], {
             RGBColor[
             0.4269959594287486, 0.5442641714414086, 0.9484287828504664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 187}], {
             RGBColor[
             0.5621930097275529, 0.6529889339202652, 0.9598343414751047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 193}], {
             RGBColor[
             0.35481020948331177`, 0.4812976775333868, 0.9438453847048609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 215}], {
             RGBColor[
             0.4092675969222994, 0.5289087548917304, 0.9472991472681309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 228}], {
             RGBColor[
             0.40206718213574816`, 0.5226721175069897, 0.9468403432050086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 118}], {
             RGBColor[
             0.4809870501913297, 0.5877091212710593, 0.9527862128591275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 166}], {
             RGBColor[
             0.6034287334529065, 0.6889296558285476, 0.9619232668111476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 173}], {
             RGBColor[
             0.7613383700635402, 0.8131927663750886, 0.9670741014023283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 195}], {
             RGBColor[
             0.7827552566642233, 0.8282103527047541, 0.888049899457449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 213}], {
             RGBColor[
             0.41855646919561895`, 0.5292706753055593, 0.9489679867169236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 234}], {
             RGBColor[
             0.4360042266402929, 0.5476093746316276, 0.9499616106917538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 263}], {
             RGBColor[
             0.6041880717649197, 0.6895461208780411, 0.9619830447046172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 75}], {
             RGBColor[
             0.2622496718451751, 0.3895665639793644, 0.938370771027846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 83}], {
             RGBColor[
             0.23539672905744033`, 0.3647472656269854, 0.9367168675303434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 109}], {
             RGBColor[
             0.22681754341146407`, 0.3557299975612772, 0.9362282955995729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 111}], {
             RGBColor[
             0.44801719485219577`, 0.5421615050729368, 0.9529696104611585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 143}], {
             RGBColor[
             0.39539245684208757`, 0.5005834220352667, 0.9480439213780288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 163}], {
             RGBColor[
             0.22259339797812214`, 0.35129015288454546`, 0.9359877367662073]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 185}], {
             RGBColor[
             0.264084877745962, 0.39115612709049546`, 0.9384877087250353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 218}], {
             RGBColor[
             0.2455808375232071, 0.37512885748964886`, 0.9373086476445216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 235}], {
             RGBColor[
             0.3642491453880201, 0.47529987880666213`, 0.9455922058186559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 292}], {
             RGBColor[
             0.3551835636115248, 0.46794003112069826`, 0.9448785300128899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 76}], {
             RGBColor[
             0.3239197878245973, 0.45498477235691487`, 0.9418608603425296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 85}], {
             RGBColor[
             0.3820455733361565, 0.5053304062801016, 0.9455645839967122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 90}], {
             RGBColor[
             0.6486510249771762, 0.7164783524999196, 0.9191260338334312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 118}], {
             RGBColor[
             0.3493195553836401, 0.4769847743871206, 0.9434793110712593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 121}], {
             RGBColor[
             0.5972650130574089, 0.6769230474623381, 0.9648758037899736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 126}], {
             RGBColor[
             0.4597957407755236, 0.5684911787344556, 0.9516743971999142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 166}], {
             RGBColor[
             0.47176123864521685`, 0.5782053089446089, 0.9526163650232794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 173}], {
             RGBColor[
             0.6296708752558506, 0.7024684194911499, 0.9577671996144601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 195}], {
             RGBColor[
             0.6510877618565336, 0.7174860058208153, 0.8787429976695809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 213}], {
             RGBColor[
             0.2868889743879294, 0.41854632842162054`, 0.9396610849290554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 234}], {
             RGBColor[
             0.30433673183260335`, 0.4368850277476889, 0.9406547089038856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 239}], {
             RGBColor[
             0.2798728769196017, 0.4111719651361355, 0.9392615285576202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 249}], {
             RGBColor[
             0.2800119943390219, 0.4113181863645, 0.9392694510888504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 258}], {
             RGBColor[
             0.3461640860421993, 0.4742516654420651, 0.9432782473550947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 263}], {
             RGBColor[
             0.47252057695723015`, 0.5788217739941024, 0.952676142916749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 285}], {
             RGBColor[
             0.4084635696937306, 0.5268174097623018, 0.947633340656417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 122}], {
             RGBColor[
             0.4747139171130409, 0.5748966875060928, 0.9537497910423203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 138}], {
             RGBColor[
             0.42569800863037655`, 0.5357176229916594, 0.9494711075348632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 211}], {
             RGBColor[
             0.562880959453024, 0.6440871184705963, 0.962454220172891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 231}], {
             RGBColor[
             0.270918516604965, 0.40208291655084594`, 0.9387397807813995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 266}], {
             RGBColor[
             0.5184382101706142, 0.6090544375596043, 0.9581078199475492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 108}], {
             RGBColor[
             0.6304561293109942, 0.7062308120108034, 0.9667332414341867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 136}], {
             RGBColor[
             0.533031318182378, 0.629749624158753, 0.9571216131875807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 161}], {
             RGBColor[
             0.34863927289179497`, 0.47580861386226425`, 0.943457454602157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 177}], {
             RGBColor[
             0.4669434959787907, 0.5765380828677235, 0.951617061266155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 208}], {
             RGBColor[
             0.3848872246925568, 0.5077917018594655, 0.9457456515083684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 244}], {
             RGBColor[
             0.4549433082046721, 0.5667957898303955, 0.9506723625264402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 252}], {
             RGBColor[
             0.6882723890582296, 0.7511466164085695, 0.9311523056491245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 268}], {
             RGBColor[
             0.4121732655016179, 0.5314254989719869, 0.9474842939006233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 279}], {
             RGBColor[
             0.692066101801248, 0.7531354006028518, 0.8870885203886054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 280}], {
             RGBColor[
             0.6327579955061329, 0.7080662576323138, 0.9669527954867794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 83}], {
             RGBColor[
             0.3448522418588588, 0.47155478296787035`, 0.9432518000755574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 87}], {
             RGBColor[
             0.49015063683544174`, 0.5954589824952674, 0.953421826046488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 106}], {
             RGBColor[
             0.3411795615779679, 0.4676945631312748, 0.9430426463668042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 109}], {
             RGBColor[
             0.33627305621288256`, 0.4625375149021622, 0.9427632281447869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 155}], {
             RGBColor[
             0.42009645959380304`, 0.5382881714633235, 0.9479891528219719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 194}], {
             RGBColor[
             0.35562850007979907`, 0.48244926518615305`, 0.9438813114485178]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 210}], {
             RGBColor[
             0.6497483589105598, 0.7217156086280841, 0.9685265350730331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 218}], {
             RGBColor[
             0.3550363503246256, 0.48193637483053386`, 0.9438435801897356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 226}], {
             RGBColor[
             0.570124481830096, 0.6588526845575344, 0.9607655536187323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 227}], {
             RGBColor[
             0.5721912270534666, 0.6604672416338768, 0.9609715474677657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 241}], {
             RGBColor[
             0.3338279117579426, 0.45996751304890765`, 0.942623980785345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 290}], {
             RGBColor[
             0.6494467636079118, 0.721475124720339, 0.9684977686438292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 291}], {
             RGBColor[
             0.6808545800994152, 0.7457923832679125, 0.9463058948444456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 100}], {
             RGBColor[
             0.34613198632700826`, 0.47133081696503376`, 0.9433821305506196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 119}], {
             RGBColor[
             0.6340452074432155, 0.6996744202273402, 0.8719874093556128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 122}], {
             RGBColor[
             0.4799563742126712, 0.5804068423087824, 0.954048341218624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 161}], {
             RGBColor[
             0.2899265182856512, 0.42206153149416137`, 0.939822258357296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 244}], {
             RGBColor[
             0.39623055359852827`, 0.5130487074622926, 0.9470371662815793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 123}], {
             RGBColor[
             0.47411527960405664`, 0.5809290185745515, 0.9525771618474166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 189}], {
             RGBColor[
             0.49774121892923207`, 0.6013926197437807, 0.954082585809619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 257}], {
             RGBColor[
             0.5270656171773012, 0.6267919396191468, 0.9559511105354388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 260}], {
             RGBColor[
             0.5005035919157651, 0.6037852483838122, 0.9542586017736503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 267}], {
             RGBColor[
             0.7378314377659354, 0.7949638534910353, 0.9747774787132895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 287}], {
             RGBColor[
             0.7734631601808502, 0.8232425952119107, 0.9735639507144203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 300}], {
             RGBColor[
             0.7472390396328574, 0.8024652198571689, 0.9756747841776219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 111}], {
             RGBColor[
             0.5313398666973709, 0.6263340690523012, 0.9578393814890045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 143}], {
             RGBColor[
             0.4787151286872626, 0.5847559860146312, 0.9529136924058749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.3059160698232972, 0.43546271686390986`, 0.9408575077940533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 165}], {
             RGBColor[
             0.6576538309695674, 0.7253441791896582, 0.9396774666770145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 185}], {
             RGBColor[
             0.3474075495911371, 0.47532869106985987`, 0.9433574797528813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 235}], {
             RGBColor[
             0.4475718172331953, 0.5594724427860266, 0.9504619768465019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 262}], {
             RGBColor[
             0.37220258453069244`, 0.4968049040998107, 0.9449373974538413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 292}], {
             RGBColor[
             0.43850623545669987`, 0.5521125951000627, 0.9497483010407359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 85}], {
             RGBColor[
             0.3937306861143396, 0.5154514636577188, 0.9463091490501985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 87}], {
             RGBColor[
             0.45903407433541343`, 0.5685073800216485, 0.951439106199282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 90}], {
             RGBColor[
             0.6603361377553594, 0.7265994098775368, 0.9198705988869175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 126}], {
             RGBColor[
             0.4714808535537066, 0.5786122361120727, 0.9524189622534005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 151}], {
             RGBColor[
             0.6305089669577104, 0.7042345395515797, 0.9676766703554923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 153}], {
             RGBColor[
             0.5882583035982283, 0.6705450074524335, 0.9636467643666524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 192}], {
             RGBColor[
             0.3012757676455654, 0.4315070232795787, 0.9405595066890684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 220}], {
             RGBColor[
             0.40732241829950533`, 0.5265255280681416, 0.9473681752100976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 239}], {
             RGBColor[
             0.2915579896977848, 0.42129302251375267`, 0.9400060936111065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 248}], {
             RGBColor[
             0.5125949542898419, 0.6112670730485217, 0.9561502362595086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 258}], {
             RGBColor[
             0.35784919882038235`, 0.4843727228196822, 0.944022812408581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 82}], {
             RGBColor[
             0.4790068485055631, 0.5832146268927033, 0.9533917537286988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 95}], {
             RGBColor[
             0.8036870966714086, 0.8471925343583373, 0.965204165289488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 103}], {
             RGBColor[
             0.6103784644057115, 0.694389584571163, 0.9625949297654831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 127}], {
             RGBColor[
             0.8225959025924792, 0.8601735304319715, 0.8829886347106269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 145}], {
             RGBColor[
             0.6993407369745556, 0.7650495660017637, 0.9706674070170164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 154}], {
             RGBColor[
             0.5260752282119221, 0.6244436662020603, 0.9563740380498316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 159}], {
             RGBColor[
             0.7581418388923993, 0.8113252945505265, 0.9764379627152919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 167}], {
             RGBColor[
             0.4482145171900416, 0.5508499343335227, 0.9516381760134518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 168}], {
             RGBColor[
             0.5348424593456589, 0.6320374011562536, 0.9569326782651152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 203}], {
             RGBColor[
             0.7956156639574938, 0.8411728730560578, 0.9788669955073424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 205}], {
             RGBColor[
             0.5746361292976588, 0.6653723467565984, 0.9597811622172896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 212}], {
             RGBColor[
             0.46548289639180146`, 0.5690000957530509, 0.9526215846627143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 225}], {
             RGBColor[
             0.6853070604449509, 0.7540863512369446, 0.9692686612927088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 255}], {
             RGBColor[
             0.5279199151192598, 0.6260414412845363, 0.9564915798683746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 265}], {
             RGBColor[
             0.5017130529795233, 0.6033423744942868, 0.9548217017866488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 269}], {
             RGBColor[
             0.5598606816721214, 0.6533769727478571, 0.9586179848559593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 276}], {
             RGBColor[
             0.45028572642816034`, 0.553026906565036, 0.9517561283154832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 282}], {
             RGBColor[
             0.5265420972214336, 0.6248480446725804, 0.9564037865302817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 293}], {
             RGBColor[
             0.5522092672936887, 0.6470796573196894, 0.9580392759106984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 99}], {
             RGBColor[
             0.6099461451977507, 0.6896514598535661, 0.9648806746616303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 131}], {
             RGBColor[
             0.607612356990576, 0.6876300498081174, 0.9647319677407571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 170}], {
             RGBColor[
             0.8936188324652724, 0.9174962642867928, 0.9718547004580944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 178}], {
             RGBColor[
             0.5489107201151034, 0.6328575025231834, 0.9611353797893751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 182}], {
             RGBColor[
             0.5866267973644407, 0.6694534128248544, 0.9633947864381815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 190}], {
             RGBColor[
             0.9125763760351358, 0.9286145259145032, 0.763803052325811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.5505170325124016, 0.6345458386988321, 0.9612268569040749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 209}], {
             RGBColor[
             0.6652095316678501, 0.736281325599522, 0.9687436579656321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 229}], {
             RGBColor[
             0.8568428217889559, 0.888687223988449, 0.9862076273264893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 261}], {
             RGBColor[
             0.650746128826802, 0.7245392836042865, 0.9676050459127945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 284}], {
             RGBColor[
             0.6547506214452403, 0.7277903111122712, 0.9679202942406577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 144}], {
             RGBColor[
             0.4528878537220874, 0.5603505030803304, 0.9513786612004175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 160}], {
             RGBColor[
             0.6015607518733201, 0.6874131442306282, 0.9617762124585605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 176}], {
             RGBColor[
             0.738570529467906, 0.7956352607091453, 0.9747535064787658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 221}], {
             RGBColor[
             0.6409993740401791, 0.7190906817076745, 0.9651137756482537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 232}], {
             RGBColor[
             0.5058174984041458, 0.6080799111505525, 0.9546822938684523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 240}], {
             RGBColor[
             0.43947724726592907`, 0.5462551054133487, 0.9506149470019536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 245}], {
             RGBColor[
             0.8055964390586132, 0.8446945938335269, 0.7637869885969997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 288}], {
             RGBColor[
             0.7506830736008046, 0.3228450896542514, 0.4304866731449466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 297}], {
             RGBColor[
             0.5174917893094586, 0.6181915951658126, 0.9554261693617687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 92}], {
             RGBColor[
             0.6921118275919369, 0.7547774964796581, 0.9358533770530761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 125}], {
             RGBColor[
             0.6575868678471077, 0.7283026894408677, 0.9691191008729337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 128}], {
             RGBColor[
             0.3723169286100696, 0.49690394319426673`, 0.9449446833574686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 145}], {
             RGBColor[
             0.5760320272244794, 0.6638837472826934, 0.9611782732644936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 149}], {
             RGBColor[
             0.5322277720177339, 0.6296635301905136, 0.956812274479524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 150}], {
             RGBColor[
             0.6190839978837319, 0.6976015460646351, 0.9654466627639091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 156}], {
             RGBColor[
             0.6209061762217314, 0.6990545016096426, 0.9656204637604653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 167}], {
             RGBColor[
             0.32490580743996555`, 0.44968411561445243`, 0.942149042260929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 179}], {
             RGBColor[
             0.4212625918837718, 0.5392982166413813, 0.9480634577403184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 201}], {
             RGBColor[
             0.4682547927385704, 0.5779489321634441, 0.9516246132893724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 205}], {
             RGBColor[
             0.45132741954758276`, 0.5642065280375281, 0.9502920284647669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 237}], {
             RGBColor[
             0.5130492510418163, 0.6143150913813691, 0.9551509971345113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 256}], {
             RGBColor[
             0.29883326111608527`, 0.4222802163331391, 0.9406642493186598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 269}], {
             RGBColor[
             0.4365519719220453, 0.5522111540287868, 0.9491288511034365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 277}], {
             RGBColor[
             0.4944362619957584, 0.5992042283681782, 0.9536857144551802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 281}], {
             RGBColor[
             0.343872138070277, 0.46961893164172686`, 0.9432291467321534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 282}], {
             RGBColor[
             0.4032333874713576, 0.5236822259535101, 0.9469146527777588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 293}], {
             RGBColor[
             0.42890055754361256`, 0.5459138386006192, 0.9485501421581756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 86}], {
             RGBColor[
             0.30052828112716024`, 0.4278696804368213, 0.9406213526723965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 94}], {
             RGBColor[
             0.34020555564880595`, 0.4690906858997533, 0.9428985750673491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 97}], {
             RGBColor[
             0.42298077583065985`, 0.5400751599251759, 0.9483694625164234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.5420544477193613, 0.6355910072496617, 0.958532048617812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 140}], {
             RGBColor[
             0.3096808116559553, 0.43748957032653724`, 0.9411425757460559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 162}], {
             RGBColor[
             0.6623807649812115, 0.7301257465399578, 0.9500099124615828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 167}], {
             RGBColor[
             0.3043130048527441, 0.4318476650377539, 0.9408368870895716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 181}], {
             RGBColor[
             0.4776929600082329, 0.5844929757963386, 0.9526766060722163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 201}], {
             RGBColor[
             0.447661990151349, 0.5601124815867455, 0.9503124581180151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 202}], {
             RGBColor[
             0.6801947586998163, 0.740634988571629, 0.7632414991482721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 203}], {
             RGBColor[
             0.6517141516201963, 0.7221706037602891, 0.9680657065834621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 216}], {
             RGBColor[
             0.3116506055969391, 0.43955994865066045`, 0.9412547525969459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 237}], {
             RGBColor[
             0.4924564484545949, 0.5964786408046705, 0.953838841963154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 269}], {
             RGBColor[
             0.4159591693348239, 0.5343747034520883, 0.9478166959320791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 293}], {
             RGBColor[
             0.40830775495639116`, 0.5280773880239207, 0.9472379869868182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 299}], {
             RGBColor[
             0.6296165683764863, 0.7045836231061642, 0.9671032734628684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 103}], {
             RGBColor[
             0.4351339438394419, 0.547778802359598, 0.9498133632856092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 140}], {
             RGBColor[
             0.2783378034269831, 0.40988105741074105`, 0.9391622981900623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 145}], {
             RGBColor[
             0.5240962164082859, 0.6184387837901987, 0.9578858405371424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 154}], {
             RGBColor[
             0.3508307076456524, 0.4778328839904952, 0.9435924715699576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 167}], {
             RGBColor[
             0.27296999662377186`, 0.4042391521219577, 0.9388566095335779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 168}], {
             RGBColor[
             0.35959793877938917`, 0.48542661894468864`, 0.9441511117852412]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 181}], {
             RGBColor[
             0.44634995177926073`, 0.5568844628805425, 0.9506963285162225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 201}], {
             RGBColor[
             0.41631898192237676`, 0.5325039686709494, 0.9483321805620213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 203}], {
             RGBColor[
             0.6203711433912241, 0.6945620908444928, 0.9660854290274683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 216}], {
             RGBColor[
             0.28030759736796684`, 0.41195143573486426`, 0.9392744750409523]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 255}], {
             RGBColor[
             0.35267539455299013`, 0.47943065907297133`, 0.9437100133885006]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 258}], {
             RGBColor[
             0.34192791248863885`, 0.4701217302929854, 0.9430251933349854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 293}], {
             RGBColor[
             0.3769647467274189, 0.5004688751081244, 0.9452577094308244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 101}], {
             RGBColor[
             0.40386940242109715`, 0.5209739839842049, 0.9474816211895916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 142}], {
             RGBColor[
             0.5304628025239251, 0.6218073244973942, 0.9587745108133872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 149}], {
             RGBColor[
             0.47434402628933386`, 0.5779669099844351, 0.9531811156581038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 194}], {
             RGBColor[
             0.30264271633582096`, 0.43499501347225344`, 0.9405622464336473]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[
             0.3212890640569515, 0.45114554267561024`, 0.9417503752221199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 198}], {
             RGBColor[
             0.522730962184121, 0.6157671520597762, 0.9580038732264715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 226}], {
             RGBColor[
             0.5171386980861179, 0.6113984328436348, 0.9574464886038618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 241}], {
             RGBColor[
             0.28084212801396435`, 0.4125132613350081, 0.9393049157704745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 243}], {
             RGBColor[
             0.2674640287358686, 0.3984520307732443, 0.9385430528077113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 290}], {
             RGBColor[
             0.5964609798639336, 0.6740208730064394, 0.9651787036289587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 291}], {
             RGBColor[
             0.627868796355437, 0.6983381315540129, 0.9429868298295752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 191}], {
             RGBColor[
             0.7678251456263414, 0.8187154589632468, 0.977449413399583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 217}], {
             RGBColor[
             0.7065250652339292, 0.7706620178409035, 0.9713834737165459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 223}], {
             RGBColor[
             0.6638470302979196, 0.7371703635374225, 0.9672331358421009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 246}], {
             RGBColor[
             0.5590722738905118, 0.6512845540328323, 0.9592128172040322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 247}], {
             RGBColor[
             0.6763048572648985, 0.7470537616934094, 0.968371405810093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 270}], {
             RGBColor[
             0.5093402401849529, 0.6082091660417706, 0.9560439359926247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 271}], {
             RGBColor[
             0.5207421165466307, 0.618084898271287, 0.9567704534721073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 278}], {
             RGBColor[
             0.8339154809215045, 0.870461944861004, 0.9507414092850872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 295}], {
             RGBColor[
             0.5943004469326686, 0.6807093141236351, 0.9617581740420593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[
             0.6670759113471512, 0.7373897387631421, 0.9693240924976425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 135}], {
             RGBColor[
             0.40148554053623176`, 0.5221683287876454, 0.946803281516613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 154}], {
             RGBColor[
             0.4248777794889551, 0.5424295104403789, 0.9482938142977357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 173}], {
             RGBColor[
             0.6994817735455929, 0.7629351107919538, 0.962215488322129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 213}], {
             RGBColor[
             0.35669987267767167`, 0.47901301972242444`, 0.9441093736367243]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 234}], {
             RGBColor[
             0.37414763012234564`, 0.49735171904849285`, 0.9451029976115545]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 239}], {
             RGBColor[
             0.349683775209344, 0.4716386564369395, 0.9437098172652891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 249}], {
             RGBColor[
             0.3498228926287642, 0.4717848776653039, 0.9437177397965193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 255}], {
             RGBColor[
             0.42672246639629285`, 0.544027285522855, 0.9484113561162788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 258}], {
             RGBColor[
             0.4159749843319416, 0.534718356742869, 0.9477265360627636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 263}], {
             RGBColor[
             0.5423314752469724, 0.6392884652949062, 0.9571244316244178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 286}], {
             RGBColor[
             0.51105993774696, 0.6139008223856859, 0.9546626216410006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[
             0.2742854923787284, 0.4051394958238438, 0.9389491853789335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 97}], {
             RGBColor[
             0.3570607125605823, 0.4761239698492663, 0.9444200728280077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 120}], {
             RGBColor[
             0.32246127059828145`, 0.44686693353260243`, 0.9420189033669154]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 130}], {
             RGBColor[
             0.47613438444928374`, 0.5716398171737522, 0.9545826589293964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 140}], {
             RGBColor[
             0.24376074838587775`, 0.3735383802506278, 0.9371931860576402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 162}], {
             RGBColor[
             0.5964607017111339, 0.6661745564640482, 0.9460605227731671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 169}], {
             RGBColor[
             0.3414680901246021, 0.4633296852957751, 0.9432300011000619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[
             0.25043400690666345`, 0.38055239806500135`, 0.9375732182581977]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 182}], {
             RGBColor[
             0.2881500841560007, 0.4171483083666724, 0.9398326249070041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 202}], {
             RGBColor[
             0.6142746954297388, 0.6766837984957195, 0.7592921094598564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 261}], {
             RGBColor[
             0.3522694156183621, 0.47223417914610444`, 0.9440428843816171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 284}], {
             RGBColor[
             0.3562739082368003, 0.4754852066540892, 0.9443581327094803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 109}], {
             RGBColor[
             0.4285856674454873, 0.5389874627156597, 0.9496141891008469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 140}], {
             RGBColor[
             0.4176882634913597, 0.5275336002245543, 0.9489935980669237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 151}], {
             RGBColor[
             0.7539381406903435, 0.8076360898386962, 0.9765103511587583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[
             0.49018116771002895`, 0.5954854268043086, 0.9534237714468192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 155}], {
             RGBColor[
             0.5124090708264077, 0.6147381192768211, 0.9548401137780319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 162}], {
             RGBColor[
             0.7703882168166158, 0.8201697764379748, 0.9578609347824507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 181}], {
             RGBColor[
             0.5857004118436373, 0.6745370056943558, 0.9605276283930841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 202}], {
             RGBColor[
             0.7882022105352207, 0.8306790184696462, 0.7710925214691399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 203}], {
             RGBColor[
             0.7597216034556007, 0.8122146336583062, 0.9759167289043299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 216}], {
             RGBColor[
             0.4196580574323434, 0.5296039785486776, 0.9491057749178138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 227}], {
             RGBColor[
             0.6645038382860713, 0.7369171894473744, 0.9678225084238257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 258}], {
             RGBColor[
             0.4812783725530154, 0.5877742731067988, 0.952856493211847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 299}], {
             RGBColor[
             0.7376240202118907, 0.7946276530041814, 0.9749542957837363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 93}], {
             RGBColor[
             0.29682830765713686`, 0.42536670256924214`, 0.9403598990128794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 107}], {
             RGBColor[
             0.44194089372503814`, 0.545941365919422, 0.9510195142637086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 124}], {
             RGBColor[
             0.32462704011779464`, 0.44944456742174493`, 0.9421312096638186]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 137}], {
             RGBColor[
             0.32640335005179827`, 0.45098311780664563`, 0.942244394562084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 147}], {
             RGBColor[
             0.3036354978760101, 0.4312627485975016, 0.940793647154264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 273}], {
             RGBColor[
             0.34726242920055617`, 0.4690502037574979, 0.9435735166404835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 274}], {
             RGBColor[
             0.21434575495200037`, 0.3426213571333206, 0.935518045697164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 289}], {
             RGBColor[
             0.6179913306655911, 0.6805049355264886, 0.7509752800735029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 94}], {
             RGBColor[
             0.3066288585935401, 0.43913442440347106`, 0.9407910922371445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 120}], {
             RGBColor[
             0.35480463681309315`, 0.48086186211222964`, 0.9438608102251265]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 131}], {
             RGBColor[
             0.3414790099969477, 0.46931987392956254`, 0.9430117130677909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 141}], {
             RGBColor[
             0.6408504668299635, 0.7091536696221241, 0.9275110184908999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 188}], {
             RGBColor[
             0.41865353161517393`, 0.5338649219170613, 0.9485646037580424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 236}], {
             RGBColor[
             0.43144505480562384`, 0.5442496566946213, 0.9495715993204878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 260}], {
             RGBColor[
             0.34711671551540024`, 0.4742029710903277, 0.9433709426781993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 281}], {
             RGBColor[
             0.2897026384277897, 0.4218262195687461, 0.9398095087305914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 294}], {
             RGBColor[
             0.6135586553788532, 0.6885963644827131, 0.966666747895284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 118}], {
             RGBColor[
             0.6857359053144021, 0.7485994119077425, 0.9214890496156471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 126}], {
             RGBColor[
             0.7962120907062856, 0.8401058162550775, 0.9296841357443022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 153}], {
             RGBColor[
             0.9129895407508073, 0.9320385875954383, 0.9409119378575541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.8081775885759789, 0.8498199464652307, 0.9306261035676673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 195}], {
             RGBColor[
             0.9875041117872957, 0.9891006433414372, 0.8567527362139689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 222}], {
             RGBColor[
             0.7474812164135753, 0.8005438972033859, 0.9258478628129057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 234}], {
             RGBColor[
             0.6407530817633654, 0.7084996652683108, 0.9186644474482735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 239}], {
             RGBColor[
             0.6162892268503637, 0.6827866026567574, 0.9172712671020081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 248}], {
             RGBColor[
             0.8373261914424209, 0.8727606531915265, 0.9334154097504102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 285}], {
             RGBColor[
             0.7448799196244926, 0.7984320472829237, 0.925643079200805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 93}], {
             RGBColor[
             0.3995336335561146, 0.5204776850671653, 0.9466789077298434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 105}], {
             RGBColor[
             0.33165667823149436`, 0.4530837485265262, 0.9426688215779035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 107}], {
             RGBColor[
             0.5446462196240159, 0.6410523484173452, 0.9573385229806728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 139}], {
             RGBColor[
             0.6105691624988314, 0.6925622001219038, 0.9639020310639868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 142}], {
             RGBColor[
             0.6083340398056708, 0.6908161052864452, 0.9636792549223416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 143}], {
             RGBColor[
             0.5297334231812736, 0.6289454684513032, 0.9561645330173267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 150}], {
             RGBColor[
             0.6390714894370777, 0.7149137066476077, 0.9667202480514436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 163}], {
             RGBColor[
             0.3569343643173082, 0.4796521993005819, 0.9441083484055053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 179}], {
             RGBColor[
             0.4412500834371176, 0.5566103772243539, 0.9493370430278527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 235}], {
             RGBColor[
             0.49859011172720624`, 0.6036619252226986, 0.9537128174579538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 273}], {
             RGBColor[
             0.4499677550995339, 0.564161186255421, 0.9498925253574475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 274}], {
             RGBColor[
             0.3170510808509781, 0.43773233963124375`, 0.9418370544141281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 298}], {
             RGBColor[
             0.7031935542767329, 0.7654477522055178, 0.9522020992675853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 125}], {
             RGBColor[
             0.9420647458673641, 0.955586414254398, 0.9577774252224829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 128}], {
             RGBColor[
             0.6567948066303259, 0.724187668007797, 0.9336030077070178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 142}], {
             RGBColor[
             0.8728244262725813, 0.900787669517003, 0.9510639939843564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 149}], {
             RGBColor[
             0.8167056500379901, 0.8569472550040439, 0.945470598829073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 150}], {
             RGBColor[
             0.9035618759039883, 0.9248852708781654, 0.9541049871134583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 179}], {
             RGBColor[
             0.7057404699040281, 0.7665819414549117, 0.9367217820898674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 237}], {
             RGBColor[
             0.7975271290620727, 0.8415988161948993, 0.9438093214840605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 243}], {
             RGBColor[
             0.6098256524845249, 0.6774323757928531, 0.9308325359786805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 256}], {
             RGBColor[
             0.5833111391363415, 0.6495639411466694, 0.9293225736682089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 269}], {
             RGBColor[
             0.7210298499423016, 0.779494878842317, 0.9377871754529856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 277}], {
             RGBColor[
             0.7789141400160147, 0.8264879531817084, 0.9423440388047293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 281}], {
             RGBColor[
             0.6283500160905333, 0.6969026564552571, 0.9318874710817026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 105}], {
             RGBColor[
             0.2835813791092368, 0.4114433407616187, 0.939605506029151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 107}], {
             RGBColor[
             0.4965709205017584, 0.5994119406524376, 0.9542752074319203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 137}], {
             RGBColor[
             0.3810333768285185, 0.5044536925396613, 0.9455000877302957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 139}], {
             RGBColor[
             0.5624938633765739, 0.6509217923569963, 0.9608387155152344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 147}], {
             RGBColor[
             0.3582655246527303, 0.4847333233305172, 0.9440493403224757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 273}], {
             RGBColor[
             0.4018924559772764, 0.5225207784905136, 0.9468292098086951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 274}], {
             RGBColor[
             0.2689757817287206, 0.3960919318663363, 0.9387737388653756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 289}], {
             RGBColor[
             0.6726213574423113, 0.7339755102595042, 0.7542309732417145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 97}], {
             RGBColor[
             0.39673798708222807`, 0.5173449753121984, 0.9466972952229602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 120}], {
             RGBColor[
             0.36213854511992716`, 0.4880879389955344, 0.9442961257618679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 130}], {
             RGBColor[
             0.5158116589709295, 0.6128608226366842, 0.956859881324349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 141}], {
             RGBColor[
             0.6481843751367976, 0.7163797465054289, 0.9279463340276415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 188}], {
             RGBColor[
             0.425987439922008, 0.541090998800366, 0.9489999192947838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 201}], {
             RGBColor[
             0.42141920140291717`, 0.537382296973768, 0.9486402908245519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 202}], {
             RGBColor[
             0.6539519699513845, 0.7179048039586515, 0.7615693318548089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.46621365970616313`, 0.573748456191693, 0.9521666746696908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 281}], {
             RGBColor[
             0.29703654673462376`, 0.42905229645205084`, 0.9402448242673329]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 293}], {
             RGBColor[
             0.3820649662079593, 0.5053472034109432, 0.945565819693355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 294}], {
             RGBColor[
             0.6208925636856872, 0.6958224413660179, 0.9671020634320254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 103}], {
             RGBColor[
             0.7598141920052874, 0.811756709825232, 0.9616257748463984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 127}], {
             RGBColor[
             0.9720316301920551, 0.9775406556860406, 0.8820194797915423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 145}], {
             RGBColor[
             0.8487764645741314, 0.8824166912558327, 0.9696982520979317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 148}], {
             RGBColor[
             0.8434223191250378, 0.8782339921379883, 0.9691646009168999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 156}], {
             RGBColor[
             0.8936506135713833, 0.9175874455827819, 0.9741404425939035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 159}], {
             RGBColor[
             0.9075775664919752, 0.9286924198045956, 0.9754688077962073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 168}], {
             RGBColor[
             0.6842781869452347, 0.7494045264103226, 0.9559635233460305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 191}], {
             RGBColor[
             0.896782289898768, 0.9200845592791491, 0.9744391446776899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 205}], {
             RGBColor[
             0.7240718568972346, 0.7827394720106675, 0.9588120072982049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 212}], {
             RGBColor[
             0.6149186239913773, 0.6863672210071199, 0.9516524297436296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 225}], {
             RGBColor[
             0.8347427880445267, 0.8714534764910136, 0.9682995063736242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 251}], {
             RGBColor[
             0.6783380711251542, 0.7442594966458711, 0.9555850244186133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 271}], {
             RGBColor[
             0.6496992608190573, 0.7194539985871891, 0.9537601847502143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 276}], {
             RGBColor[
             0.5997214540277361, 0.6703940318191051, 0.9507869733963985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 282}], {
             RGBColor[
             0.6759778248210095, 0.7422151699266495, 0.955434631611197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 112}], {
             RGBColor[
             0.2577091809258098, 0.38666060502869226`, 0.9380438592935316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 132}], {
             RGBColor[
             0.43547515213092963`, 0.5491037128248993, 0.9496611281148788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 133}], {
             RGBColor[
             0.35020721835445096`, 0.47775362343719874`, 0.9435358721708298]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 146}], {
             RGBColor[
             0.4970876054768738, 0.5987185977084183, 0.9547883050441172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 236}], {
             RGBColor[
             0.44449047425783567`, 0.5564227574631552, 0.9503708472969219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 260}], {
             RGBColor[
             0.36016213496761207`, 0.48637607185886167`, 0.9441701906546333]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 267}], {
             RGBColor[
             0.5974899808177823, 0.6775546769660846, 0.9646890675942724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 120}], {
             RGBColor[
             0.44491376530178106`, 0.559072413020957, 0.9497670132109421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 130}], {
             RGBColor[
             0.5985868791527834, 0.6838452966621067, 0.9623307687734232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 178}], {
             RGBColor[
             0.3728865016101631, 0.49275787755335587`, 0.9453213281022246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 182}], {
             RGBColor[
             0.41060257885950036`, 0.529353787855027, 0.947580734751031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 202}], {
             RGBColor[
             0.7367271901332384, 0.7888892779840742, 0.7670402193038832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 261}], {
             RGBColor[
             0.47472191032186173`, 0.584439658634459, 0.951790994225644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 284}], {
             RGBColor[
             0.47872640294029994`, 0.5876906861424438, 0.9521062425535072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 157}], {
             RGBColor[
             0.692033830666289, 0.7573742985295819, 0.9716428683264715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.6054501362682607, 0.680290294204393, 0.9661721818587483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 275}], {
             RGBColor[
             0.6266375259506635, 0.7008571325530567, 0.96744110744871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 285}], {
             RGBColor[
             0.715404020671579, 0.7763472715909384, 0.9734826552915148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 182}], {
             RGBColor[
             0.36501129828822876`, 0.4905761734011447, 0.9444791750534762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 199}], {
             RGBColor[
             0.3289015334361897, 0.45566859927512243`, 0.9423112455193696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 209}], {
             RGBColor[
             0.44359403259163815`, 0.5574040861758123, 0.9498280465809268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 215}], {
             RGBColor[
             0.400600941750381, 0.5214021337805692, 0.9467469156641986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 229}], {
             RGBColor[
             0.6352273227127441, 0.7098099845647393, 0.9672920159417839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 233}], {
             RGBColor[
             0.30201753495307765`, 0.42741181232541803`, 0.9407802415770681]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 259}], {
             RGBColor[
             0.39268579861170505`, 0.5145464346205095, 0.9462425697424883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 284}], {
             RGBColor[
             0.43313512236902835`, 0.5489130716885615, 0.9490046828559524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 119}], {
             RGBColor[
             0.7027219619801368, 0.7620518185302845, 0.8762575028652437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 122}], {
             RGBColor[
             0.5486331287495925, 0.6427842406117266, 0.9583184347282548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 161}], {
             RGBColor[
             0.3586032728225724, 0.48443892979710557`, 0.9440923518669269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 244}], {
             RGBColor[
             0.4649073081354495, 0.5754261057652368, 0.9513072597912102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 266}], {
             RGBColor[
             0.5923574218071657, 0.6769419906652381, 0.9626764636334837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 104}], {
             RGBColor[
             0.7242130515851629, 0.7834522524387295, 0.9742297555901194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 116}], {
             RGBColor[
             0.7525277526567137, 0.803821204528361, 0.8919785464211123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 136}], {
             RGBColor[
             0.5935271210448476, 0.6804495508168249, 0.9614456520814736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 149}], {
             RGBColor[
             0.5863469705955504, 0.6748403627146693, 0.9607300017870086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 197}], {
             RGBColor[
             0.433292008363168, 0.5480189954058443, 0.9492992613510246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 198}], {
             RGBColor[
             0.6347339064903375, 0.7126406047900102, 0.9655527593553763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[
             0.6749786807573754, 0.7441941015720459, 0.9695337373485233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 226}], {
             RGBColor[
             0.6291416423923344, 0.708271885573869, 0.9649953747327666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 243}], {
             RGBColor[
             0.3794669730420851, 0.49532548350347844`, 0.946091938936616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 254}], {
             RGBColor[
             0.6811147970105932, 0.7490868741119231, 0.9701190055945309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 283}], {
             RGBColor[
             0.48716415419402515`, 0.5945408327265801, 0.9527704932407016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 165}], {
             RGBColor[
             0.6689252300669783, 0.7351068985708447, 0.9403956702605946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 172}], {
             RGBColor[
             0.5708222671022314, 0.6581354370664183, 0.961369394036115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 175}], {
             RGBColor[
             0.3978747383629314, 0.5190408334293267, 0.9465732043950372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 183}], {
             RGBColor[
             0.4336914611776186, 0.5488158342603605, 0.9492001421305238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 238}], {
             RGBColor[
             0.6525475503641636, 0.7228924518644746, 0.9681188100144821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 253}], {
             RGBColor[
             0.40650136964019756`, 0.5265127878545995, 0.9471228857117941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 127}], {
             RGBColor[
             0.778722997926358, 0.8247377058988662, 0.8794102442675373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 145}], {
             RGBColor[
             0.6554678323084344, 0.7296137414686583, 0.9670890165739268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 154}], {
             RGBColor[
             0.4822023235458009, 0.5890078416689548, 0.952795647606742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 159}], {
             RGBColor[
             0.7142689342262781, 0.775889470017421, 0.9728595722722022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 167}], {
             RGBColor[
             0.4043416125239204, 0.5154141098004172, 0.9480597855703622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 168}], {
             RGBColor[
             0.4909695546795377, 0.5966015766231483, 0.9533542878220256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 203}], {
             RGBColor[
             0.7517427592913726, 0.8057370485229525, 0.9752886050642526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 205}], {
             RGBColor[
             0.5307632246315377, 0.6299365222234931, 0.9562027717742001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 212}], {
             RGBColor[
             0.42160999172568026`, 0.5335642712199454, 0.9490431942196247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 225}], {
             RGBColor[
             0.6414341557788297, 0.7186505267038392, 0.9656902708496192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 255}], {
             RGBColor[
             0.48404701045313864`, 0.5906056167514309, 0.9529131894252849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 265}], {
             RGBColor[
             0.4578401483134021, 0.5679065499611815, 0.9512433113435592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 269}], {
             RGBColor[
             0.5159877770060002, 0.6179411482147517, 0.9550395944128697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 276}], {
             RGBColor[
             0.4064128217620392, 0.5175910820319306, 0.9481777378723936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 282}], {
             RGBColor[
             0.4826691925553125, 0.589412220139475, 0.952825396087192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 293}], {
             RGBColor[
             0.5083363626275674, 0.6116438327865841, 0.9544608854676088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 114}], {
             RGBColor[
             0.8416568833908946, 0.8771378806589326, 0.9846107017536374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 116}], {
             RGBColor[
             0.960868457514563, 0.9694260202526515, 0.9111777946927353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 204}], {
             RGBColor[
             0.8833193856152247, 0.9097989172963363, 0.9887329856201463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 206}], {
             RGBColor[
             0.6993167299525103, 0.7632402969708338, 0.9722698259529658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 243}], {
             RGBColor[
             0.5878076778999344, 0.6609302992277688, 0.965291187208239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 254}], {
             RGBColor[
             0.8894555018684425, 0.9146916898362135, 0.9893182538661539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 283}], {
             RGBColor[
             0.6955048590518744, 0.7601456484508705, 0.9719697415123246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 287}], {
             RGBColor[
             0.9367056868586384, 0.952234678239853, 0.9892129051996389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 300}], {
             RGBColor[
             0.9104815663106456, 0.9314573028851112, 0.9913237386628405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 139}], {
             RGBColor[
             0.4946169080519537, 0.5835278558163572, 0.9568286293632944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 143}], {
             RGBColor[
             0.41378116873439585`, 0.5199111241457566, 0.9490911313166344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 163}], {
             RGBColor[
             0.2409821098704304, 0.3706178549950353, 0.9370349467048129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 174}], {
             RGBColor[
             0.2213982510954197, 0.35003397773413614`, 0.9359196749192987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 235}], {
             RGBColor[
             0.3826378572803284, 0.494627580917152, 0.9466394157572614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 274}], {
             RGBColor[
             0.20109882640410032`, 0.32869799532569716`, 0.9347636527134358]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 298}], {
             RGBColor[
             0.5872412998298551, 0.6564134078999712, 0.9451286975668929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 115}], {
             RGBColor[
             0.4027393390893319, 0.5191779751304978, 0.9474726316009865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 155}], {
             RGBColor[
             0.36343799556893397`, 0.48697369991282835`, 0.9444609340983483]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 162}], {
             RGBColor[
             0.6214171415591421, 0.6924053570739821, 0.947481755102767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 194}], {
             RGBColor[
             0.29897003605493, 0.4311347936356579, 0.9403530927248942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 200}], {
             RGBColor[
             0.49725635939096524`, 0.5948751046558511, 0.9556217076322454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 210}], {
             RGBColor[
             0.5930898948856907, 0.6704011370775891, 0.9649983163494095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 211}], {
             RGBColor[
             0.5716563494341602, 0.6533106097326309, 0.9629539656502906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 227}], {
             RGBColor[
             0.5155327630285975, 0.6091527700833818, 0.9574433287441421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 241}], {
             RGBColor[
             0.2771694477330735, 0.40865304149841253`, 0.9390957620617214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 264}], {
             RGBColor[
             0.3892434416269046, 0.5082213975872472, 0.9464101851156428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 290}], {
             RGBColor[
             0.5927882995830427, 0.6701606531698439, 0.9649695499202056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 291}], {
             RGBColor[
             0.6241961160745462, 0.6944779117174174, 0.942777676120822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 137}], {
             RGBColor[
             0.5261459628964198, 0.6250283558898411, 0.956159702981125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 139}], {
             RGBColor[
             0.7076064494444751, 0.7714964557071762, 0.9714983307660636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[
             0.5033781107206315, 0.6053079866806971, 0.9547089555733049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 150}], {
             RGBColor[
             0.7361087763827214, 0.79384796223288, 0.9743165477535204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.7379309547207209, 0.7953009177778874, 0.9744903487500766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.5382873703827613, 0.6355446328096263, 0.9569333427299296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 251}], {
             RGBColor[
             0.5226184122744919, 0.6219729688409766, 0.9559349305747863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 273}], {
             RGBColor[
             0.5470050420451777, 0.6430954418406933, 0.9574888250595244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 274}], {
             RGBColor[
             0.4140883677966219, 0.5166665952165161, 0.949433354116205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 277}], {
             RGBColor[
             0.6114610404947479, 0.695450644536423, 0.9625555994447914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 289}], {
             RGBColor[
             0.8177339435102127, 0.8545501736096841, 0.7648905884925439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 136}], {
             RGBColor[
             0.7686067064909976, 0.8195328527712611, 0.9774724250910569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 177}], {
             RGBColor[
             0.7025188842874102, 0.7663213114802316, 0.9719678731696313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 204}], {
             RGBColor[
             0.8500582662035254, 0.8832774035264821, 0.9855605103581067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 208}], {
             RGBColor[
             0.6204626130011763, 0.6975749304719737, 0.9660964634118446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 252}], {
             RGBColor[
             0.9238477773668491, 0.9409298450210777, 0.9515031175526008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 254}], {
             RGBColor[
             0.8561943824567432, 0.8881701760663594, 0.9861457786041142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 268}], {
             RGBColor[
             0.6477486538102374, 0.721208727584495, 0.9678351058040995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 279}], {
             RGBColor[
             0.9276414901098675, 0.94291862921536, 0.9074393322920817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 280}], {
             RGBColor[
             0.8683333838147523, 0.8978494862448219, 0.9873036073902556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 283}], {
             RGBColor[
             0.6622437396401751, 0.7336241346810164, 0.968797266250285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 111}], {
             RGBColor[
             0.49590773826365986`, 0.592497502634214, 0.9556969060607314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 151}], {
             RGBColor[
             0.6000605600677843, 0.6747146222455909, 0.9658517532570573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 155}], {
             RGBColor[
             0.3585314902038486, 0.4818166516837158, 0.9441815158763309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 192}], {
             RGBColor[
             0.2708273607556393, 0.4019871059735899, 0.9387345895906334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 218}], {
             RGBColor[
             0.2934713809346712, 0.4254648550509261, 0.9400359432440946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 220}], {
             RGBColor[
             0.3768740114095792, 0.4970056107621529, 0.9455432581116626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 227}], {
             RGBColor[
             0.5106262576635121, 0.6039957218542691, 0.9571639105221247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 290}], {
             RGBColor[
             0.5878817942179574, 0.6650036049407313, 0.9646901316981882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 292}], {
             RGBColor[
             0.40307410702298885`, 0.5182760286819755, 0.9476058256124628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 148}], {
             RGBColor[
             0.6514655050944842, 0.7265285092928208, 0.9666617854762389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 191}], {
             RGBColor[
             0.7048254758682144, 0.7683790764339815, 0.9719363292370289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 223}], {
             RGBColor[
             0.6008473605397926, 0.6868339810081572, 0.9617200516795468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 246}], {
             RGBColor[
             0.49607260413238474`, 0.6009481715035669, 0.953699733041478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 278}], {
             RGBColor[
             0.7709158111633774, 0.8201255623317387, 0.9452283251225331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 295}], {
             RGBColor[
             0.5313007771745415, 0.6303729315943698, 0.9562450898795052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 143}], {
             RGBColor[
             0.6644826516942833, 0.7373509271082035, 0.9675125318391873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 163}], {
             RGBColor[
             0.49168359283031793`, 0.5880576579574822, 0.9554563472273657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.5331750725981578, 0.6279236321634323, 0.9579563191861937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 218}], {
             RGBColor[
             0.5146710323754029, 0.6118963625625857, 0.9567772581056802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 235}], {
             RGBColor[
             0.6333393402402159, 0.712067383879599, 0.9650608162798142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 262}], {
             RGBColor[
             0.557970107537713, 0.6493998451933831, 0.9595362368871537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 292}], {
             RGBColor[
             0.6242737584637206, 0.704707536193635, 0.9643471404740482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 131}], {
             RGBColor[
             0.2868478211838396, 0.41189903066955463`, 0.9399005476844855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 132}], {
             RGBColor[
             0.36779854386560973`, 0.47950976879635754`, 0.9457507147551395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 133}], {
             RGBColor[
             0.28253061008913105`, 0.40815967940865694`, 0.9396254588110906]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 146}], {
             RGBColor[
             0.42941099721155396`, 0.5291246536798765, 0.9508778916843779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 170}], {
             RGBColor[
             0.572854296658536, 0.6417652451482301, 0.9470232804018228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 190}], {
             RGBColor[
             0.5918118402283994, 0.6528835067759405, 0.7389716322695394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 115}], {
             RGBColor[
             0.5738966468596305, 0.6649541775267864, 0.9595983927749272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 134}], {
             RGBColor[
             0.5229684015607601, 0.6226792643736792, 0.9558458393722302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 144}], {
             RGBColor[
             0.4576000998677287, 0.5641761167856317, 0.9517496264785288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 160}], {
             RGBColor[
             0.6062729980189614, 0.6912387579359295, 0.9621471777366718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 169}], {
             RGBColor[
             0.5375818377429088, 0.6353366883019975, 0.9567769946036025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 176}], {
             RGBColor[
             0.7432827756135474, 0.7994608744144467, 0.9751244717568771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 187}], {
             RGBColor[
             0.6727788880417132, 0.7440614507808542, 0.9681825532282409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 193}], {
             RGBColor[
             0.46539608779747205`, 0.5723701943939759, 0.9521935964579971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 200}], {
             RGBColor[
             0.6684136671612639, 0.7406513070521397, 0.9677474688061862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 228}], {
             RGBColor[
             0.5126530604499084, 0.6137446343675788, 0.9551885549581448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 231}], {
             RGBColor[
             0.45085121435639985`, 0.557082610209169, 0.9513652874327398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 245}], {
             RGBColor[
             0.8103086852042546, 0.8485202075388283, 0.7641579538751109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 264}], {
             RGBColor[
             0.5604007493972032, 0.6539975999835357, 0.9585359462895836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 288}], {
             RGBColor[
             0.753824571031232, 0.32539549879111895`, 0.43073398333035406`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 297}], {
             RGBColor[0.5222040354551, 0.6220172088711138, 0.95579713463988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 116}], {
             RGBColor[
             0.8699715844624454, 0.8975068327485641, 0.9023594925846303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 204}], {
             RGBColor[
             0.7924225125631073, 0.8378797297922489, 0.9799146835120414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 206}], {
             RGBColor[
             0.6084198569003928, 0.6913211094667465, 0.9634515238448609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 254}], {
             RGBColor[
             0.7985586288163249, 0.8427725023321262, 0.9804999517580489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 283}], {
             RGBColor[
             0.604607985999757, 0.6882264609467832, 0.9631514394042197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 134}], {
             RGBColor[
             0.47002933532669444`, 0.5797009455271087, 0.9516782821560954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 169}], {
             RGBColor[
             0.4846427715088433, 0.5923583694554272, 0.9526094373874676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 193}], {
             RGBColor[
             0.41245702156340647`, 0.5293918755474054, 0.948026039241862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 200}], {
             RGBColor[
             0.6154746009271983, 0.6976729882055693, 0.9635799115900512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 210}], {
             RGBColor[
             0.7113081364219238, 0.7731990206273072, 0.9729565203072152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 211}], {
             RGBColor[
             0.6898745909703932, 0.7561084932823491, 0.9709121696080965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 227}], {
             RGBColor[
             0.6337510045648305, 0.7119506536331, 0.9654015327019478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 228}], {
             RGBColor[
             0.45971399421584286`, 0.5707663155210083, 0.9510209977420099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 231}], {
             RGBColor[
             0.39791214812233433`, 0.5141042913625987, 0.947197730216605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 245}], {
             RGBColor[
             0.7573696189701891, 0.8055418886922578, 0.759990396658976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 264}], {
             RGBColor[
             0.5074616831631377, 0.6110192811369652, 0.9543683890734487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 204}], {
             RGBColor[
             0.9116340866867755, 0.9301678693859678, 0.9064817764511393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 206}], {
             RGBColor[
             0.727631431024061, 0.7836092490604654, 0.8900186167839589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 254}], {
             RGBColor[
             0.9177702029399932, 0.935060641925845, 0.9070670446971469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 283}], {
             RGBColor[
             0.7238195601234252, 0.780514600540502, 0.8897185323433177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 287}], {
             RGBColor[
             0.9650203879301892, 0.9726036303294845, 0.9069616960306319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 158}], {
             RGBColor[
             0.3618031836015295, 0.4877974657040584, 0.9442747568224642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 196}], {
             RGBColor[
             0.47781321777154817`, 0.584088937288694, 0.952824685892318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 207}], {
             RGBColor[
             0.28233099612947854`, 0.4104514209447153, 0.939522497147989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 212}], {
             RGBColor[
             0.31234333875468906`, 0.44199629593623985`, 0.9412316556612126]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 214}], {
             RGBColor[
             0.42716932409202535`, 0.5429739429182467, 0.9488378130671709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 225}], {
             RGBColor[
             0.5321675028078385, 0.6270825514201336, 0.9578787322912071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 265}], {
             RGBColor[
             0.3485734953424109, 0.47633857467747587`, 0.9434317727851471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 276}], {
             RGBColor[
             0.29714616879104794`, 0.42602310674822497`, 0.9403661993139815]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 166}], {
             RGBColor[
             0.5088461189824427, 0.6103263683524317, 0.9549793808054954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.6881726421937595, 0.7496070652286382, 0.881106013451797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 234}], {
             RGBColor[
             0.34142161216982925`, 0.46900608715551173`, 0.9430177246861016]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 239}], {
             RGBColor[
             0.3169577572568276, 0.44329302454395836`, 0.9416245443398362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 263}], {
             RGBColor[
             0.509605457294456, 0.6109428334019252, 0.9550391586989649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 285}], {
             RGBColor[
             0.44554845003095644`, 0.5589384691701247, 0.9499963564386331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 122}], {
             RGBColor[
             0.8365463498657997, 0.8711278438740331, 0.8869237135332482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 161}], {
             RGBColor[
             0.6465164939387796, 0.7127825330594121, 0.8726976306719202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 244}], {
             RGBColor[
             0.7528205292516568, 0.8037697090275433, 0.8799125385962034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 266}], {
             RGBColor[
             0.8802706429233729, 0.9052855939275446, 0.8912817424384769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 131}], {
             RGBColor[
             0.3969886965233348, 0.518273388521626, 0.9465167465925142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 141}], {
             RGBColor[
             0.6963601533563506, 0.7581071842141875, 0.9310160520156234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 170}], {
             RGBColor[
             0.6829951719980312, 0.7481396030003014, 0.9536394793098515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 178}], {
             RGBColor[
             0.3382870596478622, 0.463500841236692, 0.9429201586411322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 182}], {
             RGBColor[
             0.37600313689719944`, 0.500096751538363, 0.9451795652899386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 188}], {
             RGBColor[
             0.47416321814156104`, 0.5828184365091247, 0.9520696372827657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 190}], {
             RGBColor[
             0.7019527155678944, 0.7592578646280118, 0.7455878311775682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 261}], {
             RGBColor[
             0.44012246835956087`, 0.5551826223177951, 0.9493898247645516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 284}], {
             RGBColor[
             0.4441269609779991, 0.5584336498257798, 0.9497050730924148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 294}], {
             RGBColor[
             0.6690683419052403, 0.7375498790747765, 0.9701717814200074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 135}], {
             RGBColor[
             0.6167049802574842, 0.6937609699698819, 0.9661145013098744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 154}], {
             RGBColor[
             0.6400972192102075, 0.7140221516226153, 0.9676050340909972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 173}], {
             RGBColor[
             0.9147012132668453, 0.9345277519741901, 0.9815267081153904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.5719193123989241, 0.6506056609046609, 0.9634205934299858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 234}], {
             RGBColor[
             0.5893670698435981, 0.6689443602307292, 0.964414217404816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 239}], {
             RGBColor[
             0.5649032149305964, 0.6432312976191759, 0.9630210370585506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 249}], {
             RGBColor[
             0.5650423323500167, 0.6433775188475404, 0.9630289595897809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 255}], {
             RGBColor[
             0.6419419061175453, 0.7156199267050913, 0.9677225759095403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 258}], {
             RGBColor[
             0.6311944240531939, 0.7063109979251054, 0.967037755856025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 263}], {
             RGBColor[
             0.7575509149682249, 0.8108811064771427, 0.9764356514176793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 286}], {
             RGBColor[
             0.7262793774682124, 0.7854934635679224, 0.973973841434262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 138}], {
             RGBColor[
             0.633441608152591, 0.7126812014410419, 0.9647059618888021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 161}], {
             RGBColor[
             0.4924276607082353, 0.5935149551408543, 0.9547585625349313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 266}], {
             RGBColor[
             0.7261818096928285, 0.7860180160089868, 0.9733426743014881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 189}], {
             RGBColor[
             0.36578779544585294`, 0.4912487362111969, 0.9445286527657306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 257}], {
             RGBColor[
             0.39511219369392203`, 0.5166480560865632, 0.9463971774915503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 267}], {
             RGBColor[
             0.6058780142825562, 0.6848199699584515, 0.965223545669401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 287}], {
             RGBColor[
             0.6415097366974711, 0.7130987116793269, 0.9640100176705317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 300}], {
             RGBColor[
             0.6152856161494782, 0.6923213363245851, 0.9661208511337334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 147}], {
             RGBColor[
             0.3860642571133881, 0.50881118818302, 0.9458206509734148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 247}], {
             RGBColor[
             0.5322284890794191, 0.6296395357067401, 0.9568227386444828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 273}], {
             RGBColor[
             0.4296911884379342, 0.5465986433430163, 0.9486005204596343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 289}], {
             RGBColor[
             0.7004200899029691, 0.7580533751120071, 0.7560022838926537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 128}], {
             RGBColor[
             0.6222698468854968, 0.6977128609690068, 0.9668687315268754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 130}], {
             RGBColor[
             0.8126001685820099, 0.8542363756011002, 0.9817682519585761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 142}], {
             RGBColor[
             0.8382994665277522, 0.8743128624782126, 0.9843297178042139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.782180690293161, 0.8304724479652537, 0.9787363226489305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 150}], {
             RGBColor[
             0.8690369161591591, 0.8984104638393751, 0.9873707109333159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 167}], {
             RGBColor[
             0.5748587257153926, 0.6504930333891924, 0.9640730904303356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 237}], {
             RGBColor[
             0.7630021693172435, 0.815124009156109, 0.9770750453039181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 243}], {
             RGBColor[
             0.5753006927396958, 0.6509575687540627, 0.9640982597985381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 256}], {
             RGBColor[
             0.5487861793915124, 0.6230891341078791, 0.9625882974880664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 269}], {
             RGBColor[
             0.6865048901974724, 0.7530200718035268, 0.9710528992728431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 277}], {
             RGBColor[
             0.7443891802711855, 0.8000131461429183, 0.9756097626245869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 281}], {
             RGBColor[
             0.5938250563457041, 0.6704278494164668, 0.9651531949015602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 293}], {
             RGBColor[
             0.6788534758190397, 0.7467227563753591, 0.9704741903275822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 153}], {
             RGBColor[
             0.7241342565491546, 0.7840514138299743, 0.9734603012240372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 157}], {
             RGBColor[
             0.5326544454175498, 0.6314719004561031, 0.9563516556022449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 192}], {
             RGBColor[
             0.4371517205964917, 0.5450134296571194, 0.9503730435464531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 220}], {
             RGBColor[
             0.5431983712504317, 0.6400319344456824, 0.9571817120674824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 222}], {
             RGBColor[
             0.5586259322119227, 0.6525567234379219, 0.9583962261793888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 239}], {
             RGBColor[
             0.4274339426487111, 0.5347994288912934, 0.9498196304684912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 248}], {
             RGBColor[
             0.6484709072407683, 0.7247734794260625, 0.9659637731168933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 285}], {
             RGBColor[
             0.55602463542284, 0.6504448735174597, 0.958191442567288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 145}], {
             RGBColor[
             0.867685270495202, 0.8953976873294669, 0.8874827215190706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 148}], {
             RGBColor[
             0.8623311250461084, 0.8912149882116225, 0.8869490703380389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 156}], {
             RGBColor[
             0.912559419492454, 0.9305684416564162, 0.8919249120150423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 159}], {
             RGBColor[
             0.9264863724130458, 0.9416734158782298, 0.893253277217346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 168}], {
             RGBColor[
             0.7031869928663053, 0.7623855224839569, 0.8737479927671694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 191}], {
             RGBColor[
             0.9156910958198385, 0.9330655553527833, 0.8922236140988289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 205}], {
             RGBColor[
             0.7429806628183053, 0.7957204680843017, 0.8765964767193439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 212}], {
             RGBColor[
             0.6338274299124479, 0.6993482170807541, 0.8694368991647685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 225}], {
             RGBColor[
             0.8536515939655973, 0.8844344725646478, 0.8860839757947631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 251}], {
             RGBColor[
             0.6972468770462248, 0.7572404927195053, 0.873369493839752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 269}], {
             RGBColor[
             0.7282052151927678, 0.7837250940755603, 0.8754332993580135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 276}], {
             RGBColor[
             0.6186302599488068, 0.6833750278927393, 0.8685714428175374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 282}], {
             RGBColor[
             0.6948866307420801, 0.7551961660002837, 0.8732191010323358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 142}], {
             RGBColor[
             0.5530295272907141, 0.6429141162316117, 0.9601553002887488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 149}], {
             RGBColor[
             0.4969107510561228, 0.5990737017186526, 0.9545619051334655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 150}], {
             RGBColor[
             0.583766976922121, 0.6670117175927741, 0.9631962934178507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 197}], {
             RGBColor[
             0.34385578882374046`, 0.47225233440982767`, 0.9431311646974816]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 198}], {
             RGBColor[
             0.54529768695091, 0.6368739437939936, 0.9593846627018332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 237}], {
             RGBColor[
             0.4777322300802054, 0.583725262909508, 0.952900627788453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 243}], {
             RGBColor[
             0.2900307535026576, 0.41955882250746174`, 0.939923842283073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 256}], {
             RGBColor[
             0.2635162401544743, 0.3916903878612781, 0.9384138799726014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 269}], {
             RGBColor[
             0.40123495096043427`, 0.5216213255569258, 0.9468784817573781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 277}], {
             RGBColor[
             0.45911924103414736`, 0.5686143998963171, 0.9514353451091218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 281}], {
             RGBColor[
             0.308555117108666, 0.43902910316986576`, 0.940978777386095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 165}], {
             RGBColor[
             0.7060501207202641, 0.7672626129034615, 0.9427612354647701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 175}], {
             RGBColor[
             0.434999629016217, 0.5511965477619436, 0.9489387695992129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 183}], {
             RGBColor[
             0.47081635183090426`, 0.5809715485929774, 0.9515657073346995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 184}], {
             RGBColor[
             0.4344199924040152, 0.5506944956618376, 0.9489018356668358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 224}], {
             RGBColor[
             0.510893883738012, 0.6135082944674048, 0.9547207574552636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 253}], {
             RGBColor[
             0.4436262602934832, 0.5586685021872164, 0.9494884509159697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 140}], {
             RGBColor[
             0.48528691497807885`, 0.5812597070634682, 0.9551038820030557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 162}], {
             RGBColor[
             0.837986868303335, 0.8738958832768886, 0.9639712187185826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 167}], {
             RGBColor[
             0.4799191081748676, 0.5756178017746848, 0.9547981933465713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 201}], {
             RGBColor[
             0.6232680934734725, 0.7038826183236765, 0.9642737643750148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 202}], {
             RGBColor[
             0.85580086202194, 0.88440512530856, 0.7772028054052718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 203}], {
             RGBColor[
             0.8273202549423199, 0.8659407404972199, 0.9820270128404618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 216}], {
             RGBColor[
             0.4872567089190626, 0.5833300853875913, 0.9552160588539458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 237}], {
             RGBColor[
             0.6680625517767185, 0.7402487775416015, 0.9678001482201537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 269}], {
             RGBColor[
             0.5915652726569474, 0.6781448401890192, 0.9617780021890788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 281}], {
             RGBColor[
             0.4988854388051791, 0.5955526178019592, 0.9558782978177958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 293}], {
             RGBColor[
             0.5839138582785146, 0.6718475247608515, 0.9611992932438179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 294}], {
             RGBColor[
             0.8227414557562426, 0.8623227627159262, 0.9827355369824884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 299}], {
             RGBColor[
             0.8052226716986098, 0.8483537598430951, 0.9810645797198682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 141}], {
             RGBColor[
             0.6830345265402051, 0.7465651960315205, 0.9301669548582877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 146}], {
             RGBColor[
             0.5262262457349036, 0.6239570233492806, 0.9566449934350709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 170}], {
             RGBColor[
             0.6696695451818857, 0.7365976148176343, 0.9527903821525159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 178}], {
             RGBColor[
             0.3249614328317168, 0.45195885305402483`, 0.9420710614837966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 182}], {
             RGBColor[
             0.36267751008105403`, 0.4885547633556959, 0.944330468132603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 188}], {
             RGBColor[
             0.4608375913254156, 0.5712764483264575, 0.9512205401254301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 190}], {
             RGBColor[
             0.688627088751749, 0.7477158764453447, 0.7447387340202325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 199}], {
             RGBColor[
             0.326567745229015, 0.4536471892296736, 0.9421625385984964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 261}], {
             RGBColor[
             0.42679684154341546`, 0.543640634135128, 0.948540727607216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 284}], {
             RGBColor[
             0.4308013341618536, 0.5468916616431128, 0.9488559759350792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 133}], {
             RGBColor[
             0.4602965812942509, 0.570602787204864, 0.9512427276324376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 146}], {
             RGBColor[
             0.6071769684166737, 0.6915677614760836, 0.962495160505725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 236}], {
             RGBColor[
             0.5545798371976356, 0.6492719212308204, 0.9580777027585297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 260}], {
             RGBColor[
             0.47025149790741194`, 0.5792252356265268, 0.9518770461162411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 267}], {
             RGBColor[
             0.7075793437575822, 0.7704038407337499, 0.9723959230558803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 146}], {
             RGBColor[
             0.5219090346401951, 0.620217672088383, 0.956369904561676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 170}], {
             RGBColor[
             0.6653523340871772, 0.7328582635567367, 0.952515293279121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 144}], {
             RGBColor[
             0.3537327883347926, 0.478922884785954, 0.9438295158596969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 160}], {
             RGBColor[
             0.5024056864860253, 0.6059855259362519, 0.9542270671178399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 169}], {
             RGBColor[
             0.43371452620997275`, 0.5500834563023199, 0.9488568839847706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 176}], {
             RGBColor[
             0.6394154640806112, 0.714207642414769, 0.9672043611380452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 180}], {
             RGBColor[
             0.38725900795524026`, 0.509846021312309, 0.945896779440581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 187}], {
             RGBColor[
             0.5689115765087771, 0.6588082187811766, 0.9602624426094091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 193}], {
             RGBColor[
             0.36152877626453594`, 0.48711696239429814`, 0.9442734858391651]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 200}], {
             RGBColor[
             0.5645463556283278, 0.6553980750524621, 0.9598273581873543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 221}], {
             RGBColor[
             0.5418443086528845, 0.6376630634132983, 0.9575646303075331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 228}], {
             RGBColor[
             0.4087857489169724, 0.528491402367901, 0.9472684443393129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 230}], {
             RGBColor[
             0.41874660734635316`, 0.5371189972921291, 0.9479031414303918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 245}], {
             RGBColor[
             0.7064413736713184, 0.7632669755391506, 0.7562378432562791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 264}], {
             RGBColor[
             0.45653343786426714`, 0.568744367983858, 0.9506158356707517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 288}], {
             RGBColor[
             0.6845796966759413, 0.26856001079133385`, 0.42545390958446616`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 297}], {
             RGBColor[
             0.41833672392216387`, 0.5367639768714362, 0.9478770240210481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 158}], {
             RGBColor[
             0.3633743614260079, 0.4891583409659279, 0.944374870884102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 173}], {
             RGBColor[
             0.6491108424559259, 0.7193063419986936, 0.9590058971343609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 186}], {
             RGBColor[
             0.39683344386163905`, 0.5181389164692908, 0.9465068540301955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 213}], {
             RGBColor[
             0.3063289415880046, 0.43538425092916433`, 0.9408997824489562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 214}], {
             RGBColor[
             0.4287405019165037, 0.5443348181801163, 0.9489379271288085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 249}], {
             RGBColor[
             0.29945196153909714`, 0.4281561088720438, 0.9405081486087512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 255}], {
             RGBColor[
             0.3763515353066258, 0.5003985167295948, 0.9452017649285107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 263}], {
             RGBColor[
             0.4919605441573054, 0.5956596965016462, 0.9539148404366498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 265}], {
             RGBColor[
             0.35014467316688924`, 0.4776994499393453, 0.9435318868467849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 276}], {
             RGBColor[
             0.2987173466155263, 0.42738398201009453`, 0.9404663133756193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 286}], {
             RGBColor[
             0.4606890066572929, 0.5702720535924258, 0.9514530304532325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 177}], {
             RGBColor[
             0.6050940731587942, 0.689840123628181, 0.9623562449230252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 194}], {
             RGBColor[
             0.4923004349595713, 0.5944705803048733, 0.9545262773255293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 197}], {
             RGBColor[
             0.5109467826807019, 0.6106211095082301, 0.9557144061140019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 204}], {
             RGBColor[
             0.7526334550749094, 0.8067962156744316, 0.9759488821115005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 210}], {
             RGBColor[
             0.7864202937903321, 0.8337369237468044, 0.9791715009500446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 226}], {
             RGBColor[
             0.7067964167098683, 0.7708739996762547, 0.9714105194957439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 252}], {
             RGBColor[
             0.826422966238233, 0.8644486571690271, 0.9418914893059948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 279}], {
             RGBColor[
             0.8302166789812515, 0.8664374413633094, 0.8978277040454756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 280}], {
             RGBColor[
             0.7709085726861362, 0.8213682983927715, 0.9776919791436496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 147}], {
             RGBColor[
             0.38784056704739167`, 0.5103497385679208, 0.9459338358716803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 156}], {
             RGBColor[
             0.6223934110474811, 0.700342669665111, 0.965715229048452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 179}], {
             RGBColor[
             0.42274982670952144`, 0.5405863846968499, 0.948158223028305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 191}], {
             RGBColor[
             0.6255250873748657, 0.7028397833614782, 0.9660139311322384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 217}], {
             RGBColor[
             0.5642250069824535, 0.6547863422391349, 0.9599479914492013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 247}], {
             RGBColor[
             0.5340047990134228, 0.6311780860916407, 0.9569359235427484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 251}], {
             RGBColor[
             0.407080868601252, 0.5270147207282003, 0.9471598108731617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 270}], {
             RGBColor[
             0.3670401819334772, 0.49233349044000185`, 0.9446084537252801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 271}], {
             RGBColor[
             0.378442058295155, 0.5022092226695183, 0.9453349712047627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 273}], {
             RGBColor[
             0.4314674983719378, 0.548137193727917, 0.9487137053578998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 278}], {
             RGBColor[
             0.6916154226700287, 0.7545862692592353, 0.9393059270177426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 289}], {
             RGBColor[
             0.7021963998369727, 0.7595919254969077, 0.7561154687909193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 295}], {
             RGBColor[
             0.45200038868119286`, 0.5648336385218664, 0.9503226917747147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 210}], {
             RGBColor[
             0.7430421959441047, 0.7989621597505034, 0.9754547417184917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 211}], {
             RGBColor[
             0.721608650492574, 0.7818716324055452, 0.9734103910193728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 231}], {
             RGBColor[
             0.4296462076445151, 0.5398674304857949, 0.9496959516278813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 266}], {
             RGBColor[
             0.6771659012101643, 0.7468389514945534, 0.969063990794031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 143}], {
             RGBColor[
             0.6926936530017329, 0.7593895757411342, 0.9703243408027177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 163}], {
             RGBColor[
             0.5198945941377675, 0.6100963065904129, 0.9582681561908961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 235}], {
             RGBColor[
             0.6615503415476656, 0.7341060325125296, 0.9678726252433447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 273}], {
             RGBColor[
             0.6129279849199932, 0.694605293545252, 0.9640523331428384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 274}], {
             RGBColor[
             0.48001131067143743`, 0.5681764469210748, 0.955996862199519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 298}], {
             RGBColor[
             0.8661537840971921, 0.8958918594953488, 0.9663619070529761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 162}], {
             RGBColor[
             0.605613232239929, 0.6757944463537642, 0.9465817458468264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 167}], {
             RGBColor[
             0.24754547211146163`, 0.37751636485156037`, 0.9374087204748152]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 181}], {
             RGBColor[
             0.4209254272669505, 0.5301616756101452, 0.9492484394574598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 201}], {
             RGBColor[
             0.3908944574100665, 0.5057811814005521, 0.9468842915032587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 202}], {
             RGBColor[
             0.6234272259585338, 0.6863036883854355, 0.7598133325335157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 203}], {
             RGBColor[
             0.5949466188789139, 0.6678393035740955, 0.9646375399687057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 216}], {
             RGBColor[
             0.2548830728556566, 0.3852286484644669, 0.9378265859821896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 237}], {
             RGBColor[
             0.4356889157133125, 0.542147340618477, 0.9504106753483976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 269}], {
             RGBColor[
             0.3591916365935414, 0.4800434032658948, 0.9443885293173226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 293}], {
             RGBColor[
             0.35154022221510867`, 0.47374608783772715`, 0.9438098203720617]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 299}], {
             RGBColor[
             0.5728490356352038, 0.6502523229199707, 0.963675106848112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 146}], {
             RGBColor[
             0.8255977025679195, 0.8637908190418423, 0.9411442988581802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 178}], {
             RGBColor[
             0.6243328896647327, 0.6917926487465865, 0.9265703669069056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 182}], {
             RGBColor[
             0.6620489669140699, 0.7283885590482575, 0.9288297735557121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 188}], {
             RGBColor[
             0.7602090481584314, 0.8111102440190192, 0.9357198455485393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 236}], {
             RGBColor[
             0.7730005713488813, 0.8214949787965792, 0.9367268411109848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 261}], {
             RGBColor[
             0.7261682983764313, 0.7834744298276897, 0.933040033030325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 294}], {
             RGBColor[
             0.9551141719221107, 0.9658416865846711, 0.9538219896857809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 149}], {
             RGBColor[
             0.7129403706983783, 0.7756737032278584, 0.9720228914108041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[
             0.7997965965643764, 0.84361171910198, 0.9806572796951893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 163}], {
             RGBColor[
             0.5176594714446069, 0.6083502117549542, 0.958045380049251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 197}], {
             RGBColor[
             0.5598854084659959, 0.6488523359190336, 0.9605921509748201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 198}], {
             RGBColor[
             0.7613273065931654, 0.8134739453031995, 0.9768456489791718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 243}], {
             RGBColor[
             0.506060373144913, 0.5961588240166676, 0.9573848285604116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 256}], {
             RGBColor[
             0.4795458597967297, 0.568290389370484, 0.9558748662499399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 277}], {
             RGBColor[
             0.6751488606764029, 0.7452144014055231, 0.9688963313864605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 163}], {
             RGBColor[
             0.4390588548202097, 0.5464795749198122, 0.9505306581442361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 174}], {
             RGBColor[
             0.41947499604519894`, 0.5258956976589131, 0.949415386358722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 185}], {
             RGBColor[
             0.4805503345880495, 0.5863455491257622, 0.9530306301030641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 235}], {
             RGBColor[
             0.5807146022301077, 0.6704893008419289, 0.9601351271966847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 298}], {
             RGBColor[
             0.7853180447796343, 0.8322751278247481, 0.9586244090063161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 160}], {
             RGBColor[
             0.437037384792994, 0.5474823783482045, 0.9501308542241385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 176}], {
             RGBColor[
             0.5740471623875799, 0.6557044948267216, 0.9631081482443438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 221}], {
             RGBColor[
             0.4764760069598531, 0.5791599158252508, 0.9534684174138315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 230}], {
             RGBColor[
             0.35337830565332184`, 0.47861584970408166`, 0.9438069285366903]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 231}], {
             RGBColor[
             0.2816156011304325, 0.413326230621444, 0.9393489639202065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 232}], {
             RGBColor[
             0.3412941313238197, 0.4681491452681288, 0.9430369356340302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 240}], {
             RGBColor[
             0.27495388018560296`, 0.40632433953092495`, 0.9389695887675314]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 245}], {
             RGBColor[
             0.6410730719782871, 0.7047638279511033, 0.7521416303625775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 264}], {
             RGBColor[
             0.3911651361712358, 0.5102412203958107, 0.9465196227770503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 288}], {
             RGBColor[
             0.6410008288805871, 0.22955791239930223`, 0.42272310098866517`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 297}], {
             RGBColor[
             0.3529684222291325, 0.47826082928338876`, 0.9437808111273467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 156}], {
             RGBColor[
             0.7893042538745303, 0.8354444772262082, 0.9796036843214317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 159}], {
             RGBColor[
             0.8032312067951222, 0.8465494514480219, 0.9809320495237355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 167}], {
             RGBColor[
             0.49330388509276435`, 0.5860740912310181, 0.9561322628218955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 168}], {
             RGBColor[
             0.5799318272483817, 0.667261558053749, 0.9614267650735588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 201}], {
             RGBColor[
             0.6366528703913692, 0.7143389077800097, 0.9656078338503389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 203}], {
             RGBColor[
             0.8407050318602166, 0.8763970299535532, 0.9833610823157859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 205}], {
             RGBColor[
             0.6197254972003816, 0.7005965036540938, 0.9642752490257334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 216}], {
             RGBColor[
             0.5006414858369593, 0.5937863748439246, 0.9565501283292699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 237}], {
             RGBColor[
             0.6814473286946152, 0.7507050669979347, 0.9691342176954778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 269}], {
             RGBColor[
             0.6049500495748441, 0.6886011296453525, 0.9631120716644029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 277}], {
             RGBColor[
             0.6628343396485572, 0.7355942039847438, 0.9676689350161467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 282}], {
             RGBColor[
             0.5716314651241565, 0.6600722015700757, 0.9608978733387252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 293}], {
             RGBColor[
             0.5972986351964114, 0.6823038142171848, 0.962533362719142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 170}], {
             RGBColor[
             0.8122327212096001, 0.8538232378279562, 0.9637677261524082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 236}], {
             RGBColor[
             0.6161922905435797, 0.6988868061143394, 0.9632048796877681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 247}], {
             RGBColor[
             0.5112369468376345, 0.6114577168824967, 0.9554851761349283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 273}], {
             RGBColor[
             0.4086996461961496, 0.528416824518773, 0.9472629579500798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 289}], {
             RGBColor[
             0.6794285476611845, 0.7398715562877637, 0.7546647213830993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 156}], {
             RGBColor[
             0.7839501084254368, 0.8312617781083638, 0.9790700331404001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 159}], {
             RGBColor[
             0.7978770613460285, 0.8423667523301774, 0.9803983983427038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 168}], {
             RGBColor[
             0.574577681799288, 0.6630788589359045, 0.9608931138925272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 191}], {
             RGBColor[
             0.7870817847528213, 0.833758891804731, 0.9793687352241865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 205}], {
             RGBColor[
             0.6143713517512881, 0.6964138045362493, 0.9637415978447016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 217}], {
             RGBColor[
             0.7257817043604091, 0.7857054506823875, 0.9733027955411495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 225}], {
             RGBColor[
             0.7250422828985801, 0.7851278090165954, 0.9732290969201207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 251}], {
             RGBColor[
             0.5686375659792076, 0.6579338291714529, 0.9605146149651098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 270}], {
             RGBColor[
             0.5285968793114328, 0.6232525988832545, 0.9579632578172281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 271}], {
             RGBColor[
             0.5399987556731106, 0.6331283311127709, 0.958689775296711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 278}], {
             RGBColor[
             0.8531721200479844, 0.8855053777024879, 0.9526607311096909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.5662773196750629, 0.6558895024522313, 0.9603642221576936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 295}], {
             RGBColor[
             0.6135570860591485, 0.695752746965119, 0.9636774958666628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 150}], {
             RGBColor[
             0.7436778203297851, 0.7997713045890209, 0.975063884539906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.5037666322314047, 0.6050119214060745, 0.9549987558195367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 198}], {
             RGBColor[
             0.7052085303585742, 0.7696335307902404, 0.9712522538238885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 243}], {
             RGBColor[
             0.4499415969103219, 0.5523184095037086, 0.9517914334051283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 256}], {
             RGBColor[
             0.4234270835621385, 0.524449974857525, 0.9502814710946565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 277}], {
             RGBColor[
             0.6190300844418116, 0.7013739868925641, 0.9633029362311771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 281}], {
             RGBColor[
             0.4684659605163302, 0.5717886901661127, 0.9528463685081503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 179}], {
             RGBColor[
             0.6327126401958232, 0.7094059910398887, 0.9663150678007004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 237}], {
             RGBColor[
             0.7244992993538677, 0.7844228657798764, 0.9734026071948935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 256}], {
             RGBColor[
             0.5102833094281366, 0.5923879907316465, 0.9589158593790419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 269}], {
             RGBColor[
             0.6480020202340966, 0.7223189284272942, 0.9673804611638186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 274}], {
             RGBColor[
             0.5085136376096837, 0.5905279534467786, 0.9588150791869758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 277}], {
             RGBColor[
             0.7058863103078097, 0.7693120027666855, 0.9719373245155623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 281}], {
             RGBColor[
             0.5553221863823283, 0.6397267060402342, 0.9614807567925355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 293}], {
             RGBColor[
             0.6403506058556638, 0.7160216129991265, 0.9668017522185577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 154}], {
             RGBColor[
             0.6616560603323259, 0.7312125863342398, 0.9696613356030296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 181}], {
             RGBColor[
             0.7571753044659343, 0.810264165224287, 0.9767651925492945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 192}], {
             RGBColor[
             0.5961798340004955, 0.6706357330966264, 0.965630751648545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 220}], {
             RGBColor[
             0.7022264846544354, 0.7656542378851894, 0.9724394201695741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 239}], {
             RGBColor[
             0.5864620560527148, 0.6604217323308004, 0.965077338570583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 258}], {
             RGBColor[
             0.6527532651753124, 0.72350143263673, 0.9690940573680573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 208}], {
             RGBColor[
             0.4459117912449998, 0.5589209027015907, 0.9501113166168613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 242}], {
             RGBColor[
             0.5951983491505743, 0.6817713268855158, 0.961601148472099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 244}], {
             RGBColor[
             0.515967874757115, 0.6179249906725206, 0.9550380276349331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 268}], {
             RGBColor[
             0.47319783205406085`, 0.582554699814112, 0.9518499590091162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 157}], {
             RGBColor[
             0.6494318954620716, 0.723404671796464, 0.9675794577154968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 192}], {
             RGBColor[
             0.5539291706410134, 0.6369462009974802, 0.961600845659705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 220}], {
             RGBColor[
             0.6599758212949534, 0.7319647057860432, 0.9684095141807343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 222}], {
             RGBColor[
             0.6754033822564445, 0.7444894947782827, 0.9696240282926407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 239}], {
             RGBColor[
             0.5442113926932328, 0.6267322002316542, 0.9610474325817431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 248}], {
             RGBColor[
             0.76524835728529, 0.8167062507664233, 0.9771915752301452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 285}], {
             RGBColor[
             0.6728020854673618, 0.7423776448578205, 0.96941924468054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 181}], {
             RGBColor[
             0.49341833148561975`, 0.5981135021898993, 0.9536786128373553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[
             0.6674395230975831, 0.7357911301538498, 0.9690677133486012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 216}], {
             RGBColor[
             0.32737597707432586`, 0.4531804750442211, 0.942256759362085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 255}], {
             RGBColor[
             0.39974377425934915`, 0.5206596983823282, 0.9466922977096335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 258}], {
             RGBColor[
             0.3889962921949979, 0.5113507696023423, 0.9460074776561183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 162}], {
             RGBColor[
             0.7003340395749771, 0.762998965406031, 0.9524282615579347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 194}], {
             RGBColor[
             0.3778869340707651, 0.5017284019677066, 0.9452995991800618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 210}], {
             RGBColor[
             0.6720067929015259, 0.7409947454096377, 0.9699448228045771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 218}], {
             RGBColor[
             0.37729478431559166`, 0.5012155116120874, 0.9452618679212796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 226}], {
             RGBColor[
             0.5923829158210621, 0.6781318213390879, 0.9621838413502763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 227}], {
             RGBColor[
             0.5944496610444325, 0.6797463784154305, 0.9623898351993097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 241}], {
             RGBColor[
             0.35608634574890863`, 0.4792466498304612, 0.944042268516889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 290}], {
             RGBColor[
             0.6717051975988779, 0.7407542615018926, 0.9699160563753733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 291}], {
             RGBColor[
             0.7031130140903812, 0.7650715200494662, 0.9477241825759897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.6675698429702519, 0.7374568419722374, 0.9695216225592203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 159}], {
             RGBColor[
             0.8481053557923741, 0.881720205774971, 0.9853742400197073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 168}], {
             RGBColor[
             0.6248059762456336, 0.7024323123806981, 0.9658689555695306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.6345348185338227, 0.7108589465848962, 0.9664888687972566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 191}], {
             RGBColor[
             0.8373100791991669, 0.8731123452495245, 0.98434457690119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 205}], {
             RGBColor[
             0.6645996461976336, 0.735767257981043, 0.9687174395217051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 251}], {
             RGBColor[
             0.6188658604255531, 0.6972872826162466, 0.9654904566421133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 269}], {
             RGBColor[
             0.6498241985720961, 0.7237718839723015, 0.9675542621603748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 270}], {
             RGBColor[
             0.5788251737577783, 0.6626060523280481, 0.9629390994942317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 271}], {
             RGBColor[
             0.5902270501194562, 0.6724817845575646, 0.9636656169737143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 277}], {
             RGBColor[
             0.7077084886458092, 0.770764958311693, 0.9721111255121184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 282}], {
             RGBColor[
             0.6165056141214085, 0.695242955897025, 0.9653400638346971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 171}], {
             RGBColor[
             0.3713683899324385, 0.49374115409740404`, 0.9450001256259812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 184}], {
             RGBColor[
             0.4422135729733768, 0.5573190771799663, 0.9494332018980864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 222}], {
             RGBColor[
             0.48392357112483964`, 0.5919099814044115, 0.9525153826708485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 248}], {
             RGBColor[
             0.5737685461536851, 0.6641267373925521, 0.9600829296083528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 275}], {
             RGBColor[
             0.3925557796148412, 0.5143079924460676, 0.9462690512159431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 285}], {
             RGBColor[
             0.4813222743357568, 0.5897981314839493, 0.9523105990587477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 186}], {
             RGBColor[
             0.4090931958410822, 0.5287576974408333, 0.9472880345854526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 196}], {
             RGBColor[
             0.4916441475754697, 0.5960685935221062, 0.953705980509213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 207}], {
             RGBColor[
             0.29616192593340007`, 0.42243107717812745`, 0.9404037917648839]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 212}], {
             RGBColor[
             0.3261742685586106, 0.453975952169652, 0.9421129502781075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 214}], {
             RGBColor[
             0.4410002538959469, 0.5549535991516589, 0.9497191076840656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 225}], {
             RGBColor[
             0.5459984326117601, 0.6390622076535457, 0.958760026908102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 265}], {
             RGBColor[
             0.3624044251463324, 0.488318230910888, 0.944313067402042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 276}], {
             RGBColor[
             0.31097709859496947`, 0.4380027629816371, 0.9412474939308764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 168}], {
             RGBColor[
             0.6387329291662254, 0.7135372866025118, 0.9671973207718343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 191}], {
             RGBColor[
             0.8512370321197587, 0.8842173194713382, 0.9856729421034938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 205}], {
             RGBColor[
             0.6785265991182254, 0.7468722322028567, 0.9700458047240088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 212}], {
             RGBColor[
             0.569373366212368, 0.6504999811993091, 0.9628862271694334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 225}], {
             RGBColor[
             0.7891975302655174, 0.8355862366832028, 0.979533303799428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 251}], {
             RGBColor[
             0.6327928133461449, 0.7083922568380603, 0.966818821844417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 270}], {
             RGBColor[
             0.5927521266783702, 0.6737110265498618, 0.9642674646965355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 271}], {
             RGBColor[
             0.604154003040048, 0.6835867587793782, 0.9649939821760181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 282}], {
             RGBColor[
             0.6304325670420002, 0.7063479301188387, 0.9666684290370008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 176}], {
             RGBColor[
             0.7227200605388127, 0.7827671359770194, 0.9735056995024868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 180}], {
             RGBColor[
             0.4705636044134416, 0.5784055148745594, 0.9521981178050225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 193}], {
             RGBColor[
             0.4448333727227373, 0.5556764559565486, 0.9505748242036067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 221}], {
             RGBColor[
             0.6251489051110858, 0.7062225569755487, 0.9638659686719746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 230}], {
             RGBColor[
             0.5020512038045545, 0.6056784908543795, 0.9542044797948334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 232}], {
             RGBColor[
             0.48996702947505244`, 0.5952117864184265, 0.9534344868921732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 245}], {
             RGBColor[
             0.7897459701295199, 0.831826469101401, 0.7625391816207205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 288}], {
             RGBColor[
             0.7401160943147422, 0.3142663398328341, 0.4296548018274272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 296}], {
             RGBColor[
             0.7029269316706768, 0.7669846322877383, 0.9716178132015092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 297}], {
             RGBColor[
             0.5016413203803652, 0.6053234704336865, 0.9541783623854897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 177}], {
             RGBColor[
             0.420702027868211, 0.5358991133316924, 0.9486920863376015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 244}], {
             RGBColor[
             0.4087018400940924, 0.5261568202943644, 0.9477473875978867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 279}], {
             RGBColor[
             0.6458246336906683, 0.7124964310668207, 0.8841635454600518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 280}], {
             RGBColor[
             0.5865165273955533, 0.6674272880962827, 0.9640278205582258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 169}], {
             RGBColor[
             0.7033205739786533, 0.7655857513989115, 0.9526185608892481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 181}], {
             RGBColor[
             0.7736253805922066, 0.8227978518235657, 0.9581157761729868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 202}], {
             RGBColor[
             0.97612717928379, 0.9789398645988561, 0.7686806692490427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 216}], {
             RGBColor[
             0.6075830261809128, 0.6778648246778874, 0.9466939226977165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 227}], {
             RGBColor[
             0.8524288070346406, 0.8851780355765843, 0.9654106562037285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 228}], {
             RGBColor[
             0.678391796685653, 0.7439936974644927, 0.9510301212437904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 299}], {
             RGBColor[
             0.92554898896046, 0.9428884991333912, 0.972542443563639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 185}], {
             RGBColor[
             0.3077512757240841, 0.4370522799750409, 0.9409744454912425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 235}], {
             RGBColor[
             0.4079155433661423, 0.5211960316912077, 0.948078942584863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 274}], {
             RGBColor[
             0.2263765124899142, 0.3552664460997528, 0.9362031795410375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 292}], {
             RGBColor[
             0.3988499615896469, 0.5138361840052438, 0.947365266779097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 298}], {
             RGBColor[
             0.6125189859156689, 0.6829818586740268, 0.9465682243944945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 176}], {
             RGBColor[
             0.6401015161592362, 0.7148018662432938, 0.9672480757698432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 180}], {
             RGBColor[
             0.38794506003386514`, 0.5104402451408339, 0.9459404940723789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 187}], {
             RGBColor[
             0.569597628587402, 0.6594024426097014, 0.960306157241207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 221}], {
             RGBColor[
             0.5425303607315093, 0.6382572872418231, 0.957608344939331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 230}], {
             RGBColor[
             0.41943265942497804`, 0.5377132211206539, 0.9479468560621898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 296}], {
             RGBColor[
             0.6203083872911003, 0.6990193625540126, 0.9653601894688657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 297}], {
             RGBColor[
             0.41902277600078874`, 0.537358200699961, 0.9479207386528461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 175}], {
             RGBColor[
             0.6986848265447377, 0.7608831652790696, 0.9422919254327795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 183}], {
             RGBColor[
             0.7345015493594249, 0.7906581661101034, 0.9449188631682661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 224}], {
             RGBColor[
             0.7745790812665327, 0.823194911984531, 0.9480739132888303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 253}], {
             RGBColor[
             0.7073114578220039, 0.7683551197043424, 0.9428416067495364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 262}], {
             RGBColor[
             0.6842840718099097, 0.7484099553307401, 0.9413743220751637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 195}], {
             RGBColor[
             0.8106143254553363, 0.8508275997861264, 0.8902430674038171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 234}], {
             RGBColor[
             0.46386329543140603`, 0.570226621713, 0.9521547786381217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.43939944051840435`, 0.5445135591014466, 0.9507615982918564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 285}], {
             RGBColor[
             0.5679901332925332, 0.6601590037276129, 0.9591334103906533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 168}], {
             RGBColor[
             0.32880560746386767`, 0.453061926385508, 0.9423975340699943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[
             0.3855266506068553, 0.5001392761117687, 0.9465786028467744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 202}], {
             RGBColor[
             0.6180594191553226, 0.6806617830966522, 0.7595076438770314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.5895788120757026, 0.6621973982853122, 0.9643318513122214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 216}], {
             RGBColor[
             0.2495152660524454, 0.3795867431756836, 0.9375208973257052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 237}], {
             RGBColor[
             0.4303211089101012, 0.5365054353296936, 0.9501049866919133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 269}], {
             RGBColor[
             0.3538238297903302, 0.4744014979771114, 0.9440828406608384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 277}], {
             RGBColor[
             0.4117081198640433, 0.5213945723165029, 0.9486397040125821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 282}], {
             RGBColor[
             0.32050524533964253`, 0.44587256990183477`, 0.9418686423351608]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 293}], {
             RGBColor[
             0.34617241541189747`, 0.4681041825489438, 0.9435041317155775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 203}], {
             RGBColor[
             0.6762067542313199, 0.7433848651080431, 0.9696263535638847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 205}], {
             RGBColor[
             0.45522721957148493`, 0.5675843388085837, 0.9505405202738322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 212}], {
             RGBColor[
             0.34607398666562755`, 0.4712120878050362, 0.9433809427192568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 225}], {
             RGBColor[
             0.565898150718777, 0.6562983432889299, 0.9600280193492513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 269}], {
             RGBColor[
             0.4404517719459475, 0.5555889647998424, 0.9493773429125018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 276}], {
             RGBColor[
             0.33087681670198643`, 0.4552388986170213, 0.9425154863720256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 282}], {
             RGBColor[
             0.4071331874952598, 0.5270600367245657, 0.947163144586824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 293}], {
             RGBColor[
             0.4328003575675147, 0.5492916493716747, 0.9487986339672408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 193}], {
             RGBColor[
             0.3761422124466848, 0.4997743863226166, 0.9452046410705375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 200}], {
             RGBColor[
             0.5791597918104766, 0.6680554989807805, 0.9607585134187266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 202}], {
             RGBColor[
             0.7211345676972583, 0.7760949934305829, 0.7658501475759374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 227}], {
             RGBColor[
             0.5974361954481088, 0.682333164408311, 0.9625801345306233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 228}], {
             RGBColor[
             0.4233991850991211, 0.5411488262962195, 0.9481995995706852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 264}], {
             RGBColor[
             0.4711468740464159, 0.5814017919121766, 0.951546990902124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 299}], {
             RGBColor[
             0.6705563773739281, 0.740043627965118, 0.9697119218905337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 178}], {
             RGBColor[
             0.6109679083064132, 0.6818250675327003, 0.9491937942011339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 182}], {
             RGBColor[
             0.6486839855557505, 0.7184209778343714, 0.9514532008499403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 190}], {
             RGBColor[
             0.9746335642264454, 0.9775820909240203, 0.7518614667375698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 199}], {
             RGBColor[
             0.6125742207037115, 0.6835134037083491, 0.9492852713158337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 261}], {
             RGBColor[
             0.7128033170181118, 0.7735068486138035, 0.9556634603245533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 284}], {
             RGBColor[
             0.71680780963655, 0.7767578761217881, 0.9559787086524165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 184}], {
             RGBColor[
             0.35562987857534856`, 0.4802350728547774, 0.9439625154303631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 275}], {
             RGBColor[
             0.30597208521681296`, 0.4372239881208788, 0.9407983647482198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 285}], {
             RGBColor[
             0.3947385799377286, 0.5127141271587605, 0.9468399125910245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 174}], {
             RGBColor[
             0.5003107353627567, 0.5895124293295138, 0.957152884405382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 238}], {
             RGBColor[
             0.8552546755812228, 0.8877633222097912, 0.9848112548277448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 186}], {
             RGBColor[
             0.6948296768710003, 0.7589056984735991, 0.9619190608357115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 213}], {
             RGBColor[
             0.6043251745973658, 0.6761510329334726, 0.9563119892544723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 234}], {
             RGBColor[
             0.6217729320420398, 0.694489732259541, 0.9573056132293023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 249}], {
             RGBColor[
             0.5974481945484583, 0.668922890876352, 0.9559203554142672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 263}], {
             RGBColor[
             0.7899567771666666, 0.8364264785059545, 0.9693270472421658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 286}], {
             RGBColor[
             0.7586852396666541, 0.8110388355967342, 0.9668652372587485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 235}], {
             RGBColor[
             0.38833168459113154`, 0.5006121544303085, 0.946963670799349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 238}], {
             RGBColor[
             0.5820360186246889, 0.65426944412757, 0.963902300383749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 298}], {
             RGBColor[
             0.5929351271406582, 0.6623979814131278, 0.9454529526089803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 183}], {
             RGBColor[
             0.46345105765537786`, 0.5745921009685855, 0.9510963973027089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 224}], {
             RGBColor[
             0.5035285895624857, 0.6071288468430129, 0.9542514474232731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 253}], {
             RGBColor[
             0.43626096611795684`, 0.5522890545628245, 0.949019140883979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 180}], {
             RGBColor[
             0.6075733820080276, 0.6866276313530766, 0.9651754118252278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 187}], {
             RGBColor[
             0.7892259505615644, 0.8355898288219441, 0.9795410749940558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 193}], {
             RGBColor[
             0.5818431503173233, 0.6638985724350657, 0.963552118223812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 221}], {
             RGBColor[
             0.7621586827056717, 0.8144446734540658, 0.9768432626921799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 230}], {
             RGBColor[
             0.6390609813991405, 0.7139006073328966, 0.9671817738150387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 245}], {
             RGBColor[
             0.9267557477241057, 0.9400485855799181, 0.7755164756409259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 288}], {
             RGBColor[
             0.8314559460444662, 0.3864144174851789, 0.4383063311742307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 296}], {
             RGBColor[
             0.8399367092652628, 0.8752067487662554, 0.9845951072217145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 297}], {
             RGBColor[
             0.6386510979749511, 0.7135455869122037, 0.967155656405695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 194}], {
             RGBColor[
             0.426212612755984, 0.5412590390138439, 0.9490217254041036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 226}], {
             RGBColor[
             0.6407085945062809, 0.7176624583852251, 0.9659059675743182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 252}], {
             RGBColor[
             0.7603351440346456, 0.8112371158779976, 0.936386937384569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 268}], {
             RGBColor[
             0.48423602047803393`, 0.591515998441415, 0.9527189256360677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 279}], {
             RGBColor[
             0.7641288567776641, 0.8132259000722799, 0.89232315212405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 280}], {
             RGBColor[
             0.7048207504825489, 0.7681567571017419, 0.9721874272222238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 182}], {
             RGBColor[
             0.3039758732055815, 0.43378221607076195`, 0.940733880181221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 190}], {
             RGBColor[
             0.6299254518762765, 0.6929433291604108, 0.7411421460688505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 199}], {
             RGBColor[
             0.26786610835354246`, 0.39887464194473965`, 0.9385659506471145]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 229}], {
             RGBColor[
             0.5741918976300968, 0.6530160272343566, 0.9635467210695288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 261}], {
             RGBColor[
             0.3680952046679429, 0.488868086850194, 0.9449441396558339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 284}], {
             RGBColor[
             0.3720996972863811, 0.4921191143581788, 0.9452593879836972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 205}], {
             RGBColor[
             0.464956061859674, 0.5760109730127818, 0.9511604335015581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 251}], {
             RGBColor[
             0.41922227608759355`, 0.5375309976479854, 0.9479334506219663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 269}], {
             RGBColor[
             0.45018061423413647`, 0.5640155990040404, 0.9499972561402277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 274}], {
             RGBColor[
             0.31069223160972353`, 0.43222462402352485`, 0.9414318741633849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 277}], {
             RGBColor[
             0.5080649043078496, 0.6110086733434319, 0.9545541194919716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 282}], {
             RGBColor[
             0.4168620297834488, 0.5354866709287638, 0.9477830578145501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 289}], {
             RGBColor[
             0.7143378073233142, 0.7701082024166929, 0.7568891085397238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 187}], {
             RGBColor[
             0.5370694944361935, 0.6312282077194841, 0.9582334932965917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 193}], {
             RGBColor[
             0.3296866941919523, 0.4595369513326057, 0.9422445365263477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 215}], {
             RGBColor[
             0.38414408163093994`, 0.5071480286909493, 0.9456982990896178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 221}], {
             RGBColor[
             0.5100022265803007, 0.6100830523516059, 0.9555356809947156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 230}], {
             RGBColor[
             0.38690452527376945`, 0.5095389862304367, 0.9458741921175744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 233}], {
             RGBColor[
             0.28556067483363656`, 0.4131577072357981, 0.9397316250024874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 245}], {
             RGBColor[
             0.6745992915987349, 0.7356869644774582, 0.7542088939434617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 288}], {
             RGBColor[
             0.6633516419608856, 0.25017333675020553`, 0.42410127670925457`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 296}], {
             RGBColor[
             0.5877802531398917, 0.6708451276637954, 0.9632875255242503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 297}], {
             RGBColor[
             0.38649464184958016`, 0.5091839658097437, 0.9458480747082307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 201}], {
             RGBColor[
             0.5589066057623442, 0.6527845868703535, 0.9584183218294191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 202}], {
             RGBColor[
             0.7914393743108115, 0.8333070938552369, 0.7713473628596761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 203}], {
             RGBColor[
             0.7629587672311915, 0.814842709043897, 0.9761715702948661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 216}], {
             RGBColor[
             0.4228952212079342, 0.5322320539342683, 0.9493606163083499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 227}], {
             RGBColor[
             0.6677410020616621, 0.7395452648329652, 0.9680773498143619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 258}], {
             RGBColor[
             0.4845155363286062, 0.5904023484923895, 0.9531113346023832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 299}], {
             RGBColor[
             0.7408611839874815, 0.7972557283897721, 0.9752091371742724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 190}], {
             RGBColor[
             0.6676415291256137, 0.7295392394620819, 0.743401552717657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 199}], {
             RGBColor[
             0.3055821856028797, 0.43547055224641074`, 0.9408253572959209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 229}], {
             RGBColor[
             0.611907974879434, 0.6896119375360276, 0.9658061277183352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 261}], {
             RGBColor[
             0.4058112819172801, 0.5254639971518651, 0.9472035463046403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 284}], {
             RGBColor[
             0.4098157745357183, 0.5287150246598498, 0.9475187946325037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 224}], {
             RGBColor[
             0.5393453123771729, 0.6369038476740467, 0.9568783851587597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 253}], {
             RGBColor[
             0.472077688932644, 0.5820640553938583, 0.9516460786194657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 222}], {
             RGBColor[
             0.4681850597677497, 0.578403900161785, 0.9514777724752304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 224}], {
             RGBColor[
             0.5029489529502839, 0.6066267947429069, 0.954214513490896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 248}], {
             RGBColor[
             0.5580300347965953, 0.6506206561499256, 0.9590453194127347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 275}], {
             RGBColor[
             0.3768172682577513, 0.5008019112034411, 0.9452314410203249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 218}], {
             RGBColor[
             0.3307387152691691, 0.4608909845801443, 0.9422953563695569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 235}], {
             RGBColor[
             0.4494070231339822, 0.5610620058971576, 0.9505789145436911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 262}], {
             RGBColor[
             0.37403779043147933`, 0.4983944672109417, 0.9450543351510305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 292}], {
             RGBColor[
             0.44034144135748676`, 0.5537021582111937, 0.9498652387379252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 196}], {
             RGBColor[
             0.5251032300111009, 0.625049169025469, 0.9558379636553065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 214}], {
             RGBColor[
             0.47445933633157805`, 0.5839341746550217, 0.9518510908301592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 249}], {
             RGBColor[
             0.3451707959541715, 0.46775546534694923`, 0.9434213123101018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 265}], {
             RGBColor[
             0.3958635075819636, 0.5172988064142507, 0.9464450505481355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 286}], {
             RGBColor[
             0.5064078410723672, 0.6098714100673313, 0.9543661941545831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 193}], {
             RGBColor[
             0.5113392627454891, 0.6084991488014733, 0.9566101996951758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 215}], {
             RGBColor[
             0.5657966501844768, 0.6561102261598168, 0.9600639622584459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 228}], {
             RGBColor[
             0.5585962353979255, 0.6498735887750762, 0.9596051581953235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 229}], {
             RGBColor[
             0.8004230311468398, 0.8445180769439868, 0.9806090625360313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 230}], {
             RGBColor[
             0.5685570938273063, 0.6585011836993042, 0.9602398552864024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 233}], {
             RGBColor[
             0.4672132433871734, 0.5621199047046657, 0.9540972881713154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 245}], {
             RGBColor[
             0.8562518601522717, 0.8846491619463257, 0.7685745571122897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 288}], {
             RGBColor[
             0.7844533543299101, 0.3494814683961172, 0.43367838548847326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 296}], {
             RGBColor[
             0.7694328216934285, 0.819807325132663, 0.9776531886930784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 297}], {
             RGBColor[
             0.568147210403117, 0.6581461632786112, 0.9602137378770588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 236}], {
             RGBColor[
             0.5508036361340918, 0.6462062310915162, 0.9577804263781272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 260}], {
             RGBColor[
             0.4664752968438681, 0.5761595454872227, 0.9515797697358386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 261}], {
             RGBColor[
             0.5039713631616417, 0.6081856821226267, 0.9540936182974675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 281}], {
             RGBColor[
             0.4090612197562576, 0.5237827939656411, 0.9480183357882308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 294}], {
             RGBColor[
             0.7329172367073211, 0.7905529388796081, 0.9748755749529232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 257}], {
             RGBColor[
             0.41873813301909746`, 0.5371116572557922, 0.9479026014537526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 260}], {
             RGBColor[
             0.3921761077575614, 0.5141049660204575, 0.9462100926919643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 267}], {
             RGBColor[
             0.6295039536077316, 0.7052835711276806, 0.9667289696316035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 287}], {
             RGBColor[
             0.6651356760226466, 0.733562312848556, 0.9655154416327342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 300}], {
             RGBColor[
             0.6389115554746536, 0.7127849374938142, 0.9676262750959358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 199}], {
             RGBColor[
             0.6315317642735747, 0.6946316653360596, 0.7412336231835503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 261}], {
             RGBColor[
             0.7317608605879752, 0.7846251102415138, 0.7476118121922699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 284}], {
             RGBColor[
             0.7357653532064133, 0.7878761377494986, 0.7479270605201331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 205}], {
             RGBColor[
             0.6677313225250182, 0.7382643716774102, 0.9690161416054915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 217}], {
             RGBColor[
             0.7791416751341392, 0.8275560178235484, 0.9785773393019395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 225}], {
             RGBColor[
             0.7784022536723103, 0.8269783761577563, 0.9785036406809107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 246}], {
             RGBColor[
             0.6316888837907219, 0.708178554015477, 0.9664066827894257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 251}], {
             RGBColor[
             0.6219975367529378, 0.6997843963126138, 0.9657891587258998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 270}], {
             RGBColor[
             0.5819568500851631, 0.6651031660244153, 0.9632378015780181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 271}], {
             RGBColor[
             0.5933587264468407, 0.6749788982539318, 0.9639643190575009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 278}], {
             RGBColor[
             0.9065320908217145, 0.9273559448436488, 0.9579352748704808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 282}], {
             RGBColor[
             0.619637290448793, 0.6977400695933922, 0.9656387659184835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 295}], {
             RGBColor[
             0.6669170568328786, 0.7376033141062799, 0.9689520396274528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 218}], {
             RGBColor[
             0.28959065486738234`, 0.4213859659019616, 0.9398149416355821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 220}], {
             RGBColor[
             0.37299328534229037`, 0.49292672161318835`, 0.9453222565031503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 222}], {
             RGBColor[
             0.3884208463037815, 0.5054515106054278, 0.9465367706150567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 248}], {
             RGBColor[
             0.478265821332627, 0.5776682665935684, 0.9541043175525612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 262}], {
             RGBColor[
             0.3328897300296925, 0.458889448532759, 0.9425739204170558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 200}], {
             RGBColor[
             0.5069740418650398, 0.6050890050727588, 0.956175115273121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 215}], {
             RGBColor[
             0.3584138499402356, 0.48441896977293847`, 0.9440750054882019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 228}], {
             RGBColor[
             0.35121343515368436`, 0.47818233238819774`, 0.9436162014250797]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 230}], {
             RGBColor[
             0.3611742935830652, 0.4868099273124258, 0.9442508985161586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 245}], {
             RGBColor[
             0.6488690599080305, 0.7129579055594473, 0.7525856003420458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 264}], {
             RGBColor[
             0.39896112410097917`, 0.5184352980041547, 0.9469635927565185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 288}], {
             RGBColor[
             0.6461981541670827, 0.23502063080486496`, 0.4230190809749773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 210}], {
             RGBColor[
             0.607538833387522, 0.6851558391324672, 0.965836981431123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 226}], {
             RGBColor[
             0.5279149563070581, 0.6222929150619174, 0.9580759999768222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 241}], {
             RGBColor[
             0.29161838623490466`, 0.42340774355329075`, 0.9399344271434349]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 280}], {
             RGBColor[
             0.592027112283326, 0.6727872137784342, 0.964357459624728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 290}], {
             RGBColor[
             0.6072372380848738, 0.6849153552247221, 0.9658082150019192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 291}], {
             RGBColor[
             0.6386450545763773, 0.7092326137722957, 0.9436163412025356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 234}], {
             RGBColor[
             0.6431898186427228, 0.7095073185892065, 0.8782814112844233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 207}], {
             RGBColor[
             0.4121719601034187, 0.5187225487627631, 0.9489537208347376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 212}], {
             RGBColor[
             0.44218430272862924`, 0.5502674237542876, 0.9506628793479612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 214}], {
             RGBColor[
             0.5570102880659655, 0.6512450707362946, 0.9582690367539195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 225}], {
             RGBColor[
             0.6620084667817787, 0.7353536792381814, 0.9673099559779559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 265}], {
             RGBColor[
             0.47841445931635107`, 0.5846097024955237, 0.9528629964718958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 276}], {
             RGBColor[
             0.4269871327649881, 0.5342942345662728, 0.9497974230007302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 198}], {
             RGBColor[
             0.5521535681261918, 0.6428121634814156, 0.9598215133879044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 204}], {
             RGBColor[
             0.5923983423932297, 0.6743656602634511, 0.9638024913810516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 226}], {
             RGBColor[
             0.5465613040281887, 0.6384434442652742, 0.9592641287652948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 243}], {
             RGBColor[
             0.2968866346779395, 0.4254970421948837, 0.9403606929691444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 254}], {
             RGBColor[
             0.5985344586464476, 0.6792584328033284, 0.9643877596270591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 283}], {
             RGBColor[
             0.40458381582987957`, 0.5247123914179854, 0.9470392472732299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 204}], {
             RGBColor[
             0.7938402405203993, 0.838987269647617, 0.9800559893854033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 226}], {
             RGBColor[
             0.7480032021553582, 0.8030650536494401, 0.9755176267696465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 243}], {
             RGBColor[
             0.4983285328051089, 0.5901186515790496, 0.956614190973496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 254}], {
             RGBColor[
             0.799976356773617, 0.8438800421874944, 0.9806412576314107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 256}], {
             RGBColor[
             0.4718140194569256, 0.562250216932866, 0.9551042286630242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 283}], {
             RGBColor[
             0.606025713957049, 0.6893340008021513, 0.9632927452775815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 209}], {
             RGBColor[
             0.3841649199062891, 0.5022984650210783, 0.9461742288233714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 229}], {
             RGBColor[
             0.575798210027395, 0.6547043634100054, 0.9636381981842286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 233}], {
             RGBColor[
             0.2425884222677286, 0.37230619117068403`, 0.9371264238195127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 259}], {
             RGBColor[
             0.33325668592635593`, 0.4594408134657756, 0.942588751984933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 261}], {
             RGBColor[
             0.3697015170652411, 0.4905564230258428, 0.9450356167705338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 284}], {
             RGBColor[
             0.3737060096836793, 0.4938074505338275, 0.945350865098397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 210}], {
             RGBColor[
             0.8058251567235571, 0.8488961501526605, 0.9811055963384743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 211}], {
             RGBColor[
             0.7843916112720266, 0.8318056228077024, 0.9790612456393554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 227}], {
             RGBColor[
             0.7282680248664639, 0.7876477831584532, 0.9735506087332069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 228}], {
             RGBColor[
             0.5542310145174763, 0.6464634450463617, 0.9591700737732689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 231}], {
             RGBColor[
             0.49242916842396767`, 0.5898014208879521, 0.9553468062478639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 245}], {
             RGBColor[
             0.8518866392718223, 0.8812390182176112, 0.768139472690235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 264}], {
             RGBColor[
             0.601978703464771, 0.6867164106623187, 0.9625174651047077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 202}], {
             RGBColor[
             0.7614084044539275, 0.8089265996456438, 0.7689832149054748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 203}], {
             RGBColor[
             0.7329277973743076, 0.7904622148343039, 0.9738074223406649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 216}], {
             RGBColor[
             0.3928642513510503, 0.5078515597246752, 0.9469964683541487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 237}], {
             RGBColor[
             0.5736700942087061, 0.6647702518786853, 0.9595805577203568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 269}], {
             RGBColor[
             0.49717281508893507`, 0.6026663145261031, 0.9535584116892819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 277}], {
             RGBColor[
             0.5550571051626482, 0.6496593888654945, 0.9581152750410256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 293}], {
             RGBColor[
             0.4895214007105023, 0.5963689990979355, 0.952979702744021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 299}], {
             RGBColor[
             0.7108302141305975, 0.772875234180179, 0.9728449892200712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 203}], {
             RGBColor[
             0.9654605659227748, 0.9709847218191874, 0.7867364633709218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 216}], {
             RGBColor[
             0.6253970198995177, 0.6883740667095587, 0.7599255093844057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 237}], {
             RGBColor[
             0.8062028627571736, 0.8452927588635688, 0.7725095987506138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 269}], {
             RGBColor[
             0.7297055836374025, 0.7831888215109866, 0.7664874527195389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 293}], {
             RGBColor[
             0.7220541692589697, 0.776891506082819, 0.765908743774278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 299}], {
             RGBColor[
             0.9433629826790648, 0.9533977411650625, 0.7857740302503282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 216}], {
             RGBColor[
             0.5969164128198976, 0.6699096818982188, 0.9647497168195958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 237}], {
             RGBColor[
             0.7777222556775535, 0.8268283740522289, 0.9773338061858038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 255}], {
             RGBColor[
             0.6692842100049209, 0.7373889052363258, 0.9691852551671442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 269}], {
             RGBColor[
             0.7012249765577825, 0.7647244366996466, 0.9713116601547289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 293}], {
             RGBColor[
             0.6935735621793497, 0.7584271212714789, 0.970732951209468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 299}], {
             RGBColor[
             0.9148823755994449, 0.9349333563537225, 0.9905982376855182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 226}], {
             RGBColor[
             0.7882479764223962, 0.8346185504314757, 0.9794986047627936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 243}], {
             RGBColor[
             0.5385733070721469, 0.6216721483610852, 0.960595168966643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 254}], {
             RGBColor[
             0.840221131040655, 0.8754335389695298, 0.9846222356245579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 283}], {
             RGBColor[
             0.646270488224087, 0.7208874975841868, 0.9672737232707286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 225}], {
             RGBColor[
             0.605691820670777, 0.6896332888892747, 0.9628765033014257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 251}], {
             RGBColor[
             0.44928710375140446`, 0.5624393090441322, 0.9501620213464148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 269}], {
             RGBColor[
             0.48024544189794743`, 0.5889239104001872, 0.9522258268646762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 282}], {
             RGBColor[
             0.44692685744725974`, 0.5603949823249106, 0.9500116285389986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 219}], {
             RGBColor[
             0.5561919938703538, 0.6505203059212192, 0.9582459385551562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 254}], {
             RGBColor[
             0.6562184753779405, 0.7288749186440274, 0.9681590759573775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 283}], {
             RGBColor[
             0.46226783256137255`, 0.5743288772586844, 0.9508105636035482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 212}], {
             RGBColor[
             0.2467020810865596, 0.3766299074103089, 0.9373606906036323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 214}], {
             RGBColor[
             0.3615280664238959, 0.47760755439231584`, 0.9449668480095905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 225}], {
             RGBColor[
             0.4665262451397091, 0.5617161628942026, 0.9540077672336268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 242}], {
             RGBColor[
             0.5241802662883136, 0.6219862445045609, 0.9565987053412639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 244}], {
             RGBColor[
             0.4449497918948543, 0.5581399082915657, 0.9500355845040981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 252}], {
             RGBColor[
             0.6782788727484117, 0.7424907348697397, 0.9305155276267825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 268}], {
             RGBColor[
             0.4021797491918001, 0.5227696174331571, 0.9468475158782812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 279}], {
             RGBColor[
             0.6820725854914302, 0.744479519064022, 0.8864517423662632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 259}], {
             RGBColor[
             0.44794918508180437`, 0.5611763003664655, 0.9501055530464901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 211}], {
             RGBColor[
             0.8802251467667521, 0.9073316552294403, 0.9884378543565194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 226}], {
             RGBColor[
             0.8220348151378188, 0.8615592585038485, 0.9827212236013376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 227}], {
             RGBColor[
             0.8241015603611894, 0.8631738155801911, 0.9829272174503709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 241}], {
             RGBColor[
             0.5857382450656654, 0.6626740869952219, 0.9645796507679503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 290}], {
             RGBColor[
             0.9013570969156346, 0.9241816986666532, 0.9904534386264344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 291}], {
             RGBColor[
             0.9327649134071381, 0.9484989572142268, 0.9682615648270508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 231}], {
             RGBColor[
             0.5668291584671625, 0.6482369259647318, 0.9626790642659091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 264}], {
             RGBColor[
             0.6763786935079659, 0.7451519157390984, 0.9698497231227527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 266}], {
             RGBColor[
             0.8143488520328117, 0.8552084469734902, 0.9820471034320588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 214}], {
             RGBColor[
             0.3915404090491064, 0.5091524293838403, 0.9466760065228141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 225}], {
             RGBColor[
             0.4965385877649196, 0.5932610378857271, 0.9557169257468504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 265}], {
             RGBColor[
             0.31294458029949196`, 0.44251706114306943`, 0.9412699662407904]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 276}], {
             RGBColor[
             0.26151725374812906`, 0.39220159321381853`, 0.9382043927696248]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 234}], {
             RGBColor[
             0.27899103117411855`, 0.41056764119001166`, 0.9391994985438977]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 249}], {
             RGBColor[
             0.25466629368053706`, 0.3850007998068228, 0.9378142407288625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 263}], {
             RGBColor[
             0.4471748762987453, 0.5525043874364252, 0.9512209325567611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 286}], {
             RGBColor[
             0.41590333879873287`, 0.5271167445272048, 0.9487591225733438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 265}], {
             RGBColor[
             0.42777056563682825`, 0.5434947081250763, 0.9488761236467487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 276}], {
             RGBColor[
             0.3763432390854653, 0.4931792401958255, 0.9458105501755829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 286}], {
             RGBColor[
             0.538314899127232, 0.6360673117781568, 0.9567972672531961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 229}], {
             RGBColor[
             0.6474976183415863, 0.7204378979154522, 0.9680738683290575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 233}], {
             RGBColor[
             0.3142878305819199, 0.43803972567613086`, 0.9415620939643417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 259}], {
             RGBColor[
             0.40495609424054724`, 0.5251743479712224, 0.9470244221297619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 296}], {
             RGBColor[
             0.616507408888175, 0.6957271461041282, 0.9651179944861046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 237}], {
             RGBColor[
             0.4376587096542962, 0.5442177189426002, 0.9505228521992877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 269}], {
             RGBColor[
             0.3611614305345252, 0.48211378159001794`, 0.9445007061682127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 293}], {
             RGBColor[
             0.35351001615609245`, 0.47581646616185036`, 0.9439219972229518]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 299}], {
             RGBColor[
             0.5748188295761876, 0.652322701244094, 0.963787283699002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 223}], {
             RGBColor[
             0.6751635598057173, 0.746010922397724, 0.9683610617444574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 246}], {
             RGBColor[
             0.5703888033983096, 0.6601251128931337, 0.9603407431063886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 247}], {
             RGBColor[
             0.6876213867726964, 0.7558943205537109, 0.9694993317124493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 251}], {
             RGBColor[
             0.5606974563605255, 0.6517309551902704, 0.9597232190428626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 270}], {
             RGBColor[
             0.5206567696927507, 0.6170497249020719, 0.957171861894981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 271}], {
             RGBColor[
             0.5320586460544285, 0.6269254571315883, 0.9578983793744638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 278}], {
             RGBColor[
             0.8452320104293023, 0.8793025037213054, 0.9518693351874437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 295}], {
             RGBColor[
             0.6056169764404664, 0.6895498729839364, 0.9628860999444158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 220}], {
             RGBColor[
             0.39563730552132226`, 0.5164044706905245, 0.9466236101566113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 262}], {
             RGBColor[
             0.3555337502087244, 0.48236719761009517`, 0.943875274070517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 290}], {
             RGBColor[
             0.6066450883297004, 0.6844024648691029, 0.9657704837431369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 292}], {
             RGBColor[
             0.4218374011347319, 0.5376748886103472, 0.9486861776574115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 250}], {
             RGBColor[
             0.44777326297599374`, 0.5514584316531175, 0.9514432890286693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 222}], {
             RGBColor[
             0.4944674969577214, 0.6004700153939908, 0.9533454391360858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 248}], {
             RGBColor[
             0.584312471986567, 0.6726867713821314, 0.9609129860735903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 262}], {
             RGBColor[
             0.4389363806836325, 0.5539079533213219, 0.9493825889380849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 230}], {
             RGBColor[
             0.5414898259714136, 0.6373560283314259, 0.9575420429845265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 232}], {
             RGBColor[
             0.5294056516419116, 0.6268893238954729, 0.9567720500818664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 245}], {
             RGBColor[
             0.829184592296379, 0.8635040065784474, 0.7658767448104138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 288}], {
             RGBColor[
             0.7664085090926483, 0.335384698150865, 0.43187984395388923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 296}], {
             RGBColor[
             0.7423655538375359, 0.7986621697647847, 0.9749553763912024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 297}], {
             RGBColor[
             0.5410799425472244, 0.637001007910733, 0.9575159255751828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 248}], {
             RGBColor[
             0.599740032948058, 0.6852115603743709, 0.9621275001854968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 285}], {
             RGBColor[
             0.5072937611301298, 0.6108829544657681, 0.9543551696358916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 246}], {
             RGBColor[
             0.5277107684622999, 0.6266334585896527, 0.9561904052319435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 247}], {
             RGBColor[
             0.6449433518366867, 0.7224026662502299, 0.9653489938380042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 270}], {
             RGBColor[
             0.47797873475674113`, 0.583558070598591, 0.953021524020536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 271}], {
             RGBColor[
             0.4893806111184189, 0.5934338028281074, 0.9537480415000188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 278}], {
             RGBColor[
             0.8025539754932927, 0.8458108494178245, 0.9477189973129987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 295}], {
             RGBColor[
             0.5629389415044568, 0.6560582186804556, 0.9587357620699707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 253}], {
             RGBColor[
             0.5121552208397518, 0.6146008012682858, 0.9548011287400299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 262}], {
             RGBColor[
             0.48912783482765765`, 0.5946556368946834, 0.9533338440656571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 265}], {
             RGBColor[
             0.5327687443526414, 0.6276033166269631, 0.9579170428707849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 276}], {
             RGBColor[
             0.4813414178012785, 0.5772878486977122, 0.9548514693996193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 241}], {
             RGBColor[
             0.5061143679852016, 0.5998111629246721, 0.9568186693136496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 243}], {
             RGBColor[
             0.49273626870710585`, 0.5857499323629083, 0.9560568063508863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 290}], {
             RGBColor[
             0.8217332198351708, 0.8613187745961035, 0.9826924571721336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 291}], {
             RGBColor[
             0.8531410363266743, 0.885636033143677, 0.96050058337275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 241}], {
             RGBColor[
             0.5081811132085721, 0.6014257200010146, 0.9570246631626829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 290}], {
             RGBColor[
             0.8237999650585414, 0.8629333316724459, 0.982898451021167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 291}], {
             RGBColor[
             0.8552077815500447, 0.8872505902200195, 0.9607065772217834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 299}], {
             RGBColor[
             0.8196646104299155, 0.8596359121427908, 0.982504017205014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 264}], {
             RGBColor[
             0.4462180967534155, 0.5598097379777576, 0.9499585512566663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 233}], {
             RGBColor[
             0.5489142115442829, 0.6264475764603009, 0.962107194241927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 259}], {
             RGBColor[
             0.6395824752029102, 0.7135821987553925, 0.9675695224073473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 284}], {
             RGBColor[
             0.6800317989602336, 0.7479488358234444, 0.9703316355208114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 245}], {
             RGBColor[
             0.7060868909898477, 0.7629599404572782, 0.7562152559332724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 288}], {
             RGBColor[
             0.6843433748882941, 0.2683553207367523, 0.4254388513691284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 296}], {
             RGBColor[
             0.6192678525310046, 0.6981181036436155, 0.9652938875140611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 297}], {
             RGBColor[
             0.41798224124069305`, 0.5364569417895638, 0.9478544366980416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 232}], {
             RGBColor[
             0.3345452458124909, 0.46105563869166616`, 0.9426525965882413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 245}], {
             RGBColor[
             0.6343241864669584, 0.6976703213746406, 0.7517572913167887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 264}], {
             RGBColor[
             0.384416250659907, 0.5031477138193481, 0.9461352837312613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 266}], {
             RGBColor[
             0.5223864091847528, 0.6132042450537398, 0.9583326640405674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 240}], {
             RGBColor[
             0.32788352486766137`, 0.4540537476011471, 0.9422732214355662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 245}], {
             RGBColor[
             0.6940027166603455, 0.7524932360213252, 0.7554452630306123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 288}], {
             RGBColor[
             0.676287258668626, 0.2613775177794503, 0.42492552276735507`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 297}], {
             RGBColor[
             0.40589806691119096`, 0.525990237353611, 0.9470844437953815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 259}], {
             RGBColor[
             0.3063726874432439, 0.4311840265160712, 0.9410577480426314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[
             0.27197493370579084`, 0.4031932779045267, 0.9387999421724625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 249}], {
             RGBColor[
             0.27211405112521103`, 0.40333949913289113`, 0.9388078647036928]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 263}], {
             RGBColor[
             0.4646226337434193, 0.5708430867624935, 0.9522145565315913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 274}], {
             RGBColor[
             0.3680322598998122, 0.4792761720218695, 0.945807648593486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 298}], {
             RGBColor[
             0.7541747333255668, 0.8069915845961435, 0.956172693446943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 260}], {
             RGBColor[
             0.479266820034318, 0.5865442802647827, 0.9525867652982842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 267}], {
             RGBColor[
             0.7165946658844883, 0.7777228853720057, 0.9731056422379234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 294}], {
             RGBColor[
             0.745708759897771, 0.8009376736571681, 0.9758825705153689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 256}], {
             RGBColor[
             0.404248562586221, 0.5091015360483804, 0.9486201937496441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 269}], {
             RGBColor[
             0.541967273392181, 0.639032473744028, 0.9570847955344208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 277}], {
             RGBColor[
             0.5998515634658941, 0.6860255480834194, 0.9616416588861645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 281}], {
             RGBColor[
             0.4492874395404127, 0.5564402513569681, 0.9511850911631378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 293}], {
             RGBColor[
             0.5343158590137482, 0.6327351583158605, 0.9565060865891599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 248}], {
             RGBColor[
             0.4685480433848464, 0.5674542658277424, 0.9535509044745992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 258}], {
             RGBColor[
             0.3138022879153868, 0.44055991559890284`, 0.9414234806236716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 263}], {
             RGBColor[
             0.44015877883041765`, 0.5451300241509401, 0.9508213761853259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 285}], {
             RGBColor[
             0.3761017715669181, 0.4931256599191396, 0.945778573924994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 290}], {
             RGBColor[
             0.5854366497630175, 0.6624336030874767, 0.9645508843387464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 291}], {
             RGBColor[
             0.6168444662545207, 0.6867508616350503, 0.9423590105393628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 250}], {
             RGBColor[
             0.4613545329335883, 0.562068222965465, 0.9527969430938585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 268}], {
             RGBColor[
             0.5514663070973747, 0.6456200416170822, 0.9583373477335189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 254}], {
             RGBColor[
             0.5447094233253647, 0.6265649209009625, 0.9611804372126507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 256}], {
             RGBColor[
             0.21654708600867328`, 0.3449350956463341, 0.9356434082442642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 283}], {
             RGBColor[
             0.35075878050879666`, 0.47201887951561944`, 0.9438319248588214]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 279}], {
             RGBColor[
             0.7521286690035455, 0.8034836070349519, 0.8913784533843352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 280}], {
             RGBColor[
             0.6928205627084303, 0.7584144640644139, 0.971242728482509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 264}], {
             RGBColor[
             0.7438737215077617, 0.7945853111490071, 0.7589279501736323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 288}], {
             RGBColor[
             0.8761398857716044, 0.4191206395681, 0.29766198591971993`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 297}], {
             RGBColor[
             0.7056770075656584, 0.7626049200365853, 0.7561891385239288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 270}], {
             RGBColor[
             0.37320397834933333`, 0.4976722610940007, 0.9450012053824672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 278}], {
             RGBColor[
             0.6977792190858849, 0.7599250399132342, 0.93969867867493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 295}], {
             RGBColor[
             0.458164185097049, 0.5701724091758653, 0.950715443431902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 251}], {
             RGBColor[
             0.5304772483914948, 0.6281226990427763, 0.9567111511364097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 270}], {
             RGBColor[
             0.4904365617237201, 0.5934414687545779, 0.954159793988528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 271}], {
             RGBColor[
             0.5018384380853979, 0.6033172009840944, 0.9548863114680107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 278}], {
             RGBColor[
             0.8150118024602716, 0.8556942475738114, 0.9488572672809906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 289}], {
             RGBColor[
             0.8255927796272156, 0.8606999038114838, 0.7656668090541672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 295}], {
             RGBColor[
             0.5753967684714357, 0.6659416168364425, 0.9598740320379626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 285}], {
             RGBColor[
             0.5971387361589753, 0.6830997104539087, 0.9619227165733961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 258}], {
             RGBColor[
             0.31394140533480697`, 0.44070613682726734`, 0.9414314031549018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 263}], {
             RGBColor[
             0.44029789624983784`, 0.5452762453793046, 0.9508292987165561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 286}], {
             RGBColor[
             0.40902635874982535`, 0.5198886024700843, 0.9483674887331388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 270}], {
             RGBColor[
             0.36351263131154926`, 0.48927810339113736`, 0.9443836813189415]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 271}], {
             RGBColor[
             0.37491450767322704`, 0.4991538356206538, 0.9451101987984241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 278}], {
             RGBColor[
             0.6880878720481007, 0.7515308822103708, 0.939081154611404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 282}], {
             RGBColor[
             0.4011930716751793, 0.5219150069601142, 0.9467846456594068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 289}], {
             RGBColor[
             0.6986688492150448, 0.7565365384480432, 0.7558906963845806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 295}], {
             RGBColor[
             0.4484728380592649, 0.5617782514730019, 0.9500979193683761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 268}], {
             RGBColor[
             0.7055649135574729, 0.766124531982261, 0.9322541700190373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 279}], {
             RGBColor[
             0.985457749857103, 0.987834433613126, 0.8718583965070195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 280}], {
             RGBColor[
             0.9261496435619878, 0.942765290642588, 0.9517226716051934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 283}], {
             RGBColor[
             0.7200599993874106, 0.7785399390787824, 0.9332163304652228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 283}], {
             RGBColor[
             0.6524066044773047, 0.7257802701240641, 0.9678589915167362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 258}], {
             RGBColor[
             0.3908409791023356, 0.5129485446848183, 0.9461250194746612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 286}], {
             RGBColor[
             0.485925932517354, 0.5921310103276354, 0.9530611050528983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 269}], {
             RGBColor[
             0.32775128346645, 0.44699759869579814`, 0.9425980477185691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 277}], {
             RGBColor[
             0.3856355735401631, 0.49399067303518956`, 0.9471549110703129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 281}], {
             RGBColor[
             0.23507144961468163`, 0.36440537630873815`, 0.9366983433472862]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 293}], {
             RGBColor[
             0.32009986908801724`, 0.4407002832676305, 0.9420193387733082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 267}], {
             RGBColor[
             0.6588283518558007, 0.7306828910030468, 0.9685974943574231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 272}], {
             RGBColor[
             0.417718108343846, 0.5362281631500203, 0.947837606383418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 300}], {
             RGBColor[
             0.6682359537227227, 0.7381842573691806, 0.9694947998217556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 263}], {
             RGBColor[
             0.5064499879530152, 0.6082097244568697, 0.9548380949828004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 286}], {
             RGBColor[
             0.4751784504530027, 0.5828220815476494, 0.9523762849993831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 267}], {
             RGBColor[
             0.6322663265942646, 0.7076761997677121, 0.9669049855956348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 287}], {
             RGBColor[
             0.6678980490091795, 0.7359549414885876, 0.9656914575967654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 294}], {
             RGBColor[
             0.6613804206075473, 0.7308909880528746, 0.9696819138730802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 300}], {
             RGBColor[
             0.6416739284611866, 0.7151775661338459, 0.9678022910599671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 284}], {
             RGBColor[
             0.47393510599807975`, 0.5838008954392819, 0.9517290541071166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 292}], {
             RGBColor[
             0.4651364762970421, 0.5751783712411446, 0.951445156438885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 286}], {
             RGBColor[
             0.6015349413680335, 0.6873921900996867, 0.9617741805610374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 288}], {
             RGBColor[
             0.7095345952335701, 0.2894389011979049, 0.427247314196035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 276}], {
             RGBColor[
             0.29774741033585084`, 0.42654387195505455`, 0.9404045098935593]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 286}], {
             RGBColor[
             0.45971907037761744`, 0.5694319435373858, 0.9513912269711725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 272}], {
             RGBColor[
             0.6284839289324802, 0.7044000770219085, 0.9666639745612688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 287}], {
             RGBColor[
             0.9052258948593498, 0.9271335465958106, 0.9862103345364046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 300}], {
             RGBColor[
             0.879001774311357, 0.9063561712410688, 0.9883211679996062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 279}], {
             RGBColor[
             0.7093586263004913, 0.7681133161765433, 0.8881903847585182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 280}], {
             RGBColor[
             0.6500505200053761, 0.7230441732060053, 0.9680546598566921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 277}], {
             RGBColor[
             0.5233542843461231, 0.6239216107308372, 0.9556195128550896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 282}], {
             RGBColor[
             0.4321514098217223, 0.5483996083161692, 0.9488484511776683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 293}], {
             RGBColor[
             0.45781857989397723`, 0.5706312209632782, 0.9504839405580849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 271}], {
             RGBColor[
             0.33487382100545227`, 0.4644726053324554, 0.9425588416505425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 278}], {
             RGBColor[
             0.648047185380326, 0.7168496519221724, 0.9365297974635224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 289}], {
             RGBColor[
             0.6586281625472701, 0.7218553081598449, 0.7533393392366989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 295}], {
             RGBColor[
             0.40843215139149014`, 0.5270970211848035, 0.9475465622204944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 278}], {
             RGBColor[
             0.6594490617420038, 0.7267253841516889, 0.9372563149430051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 289}], {
             RGBColor[
             0.6700300389089477, 0.7317310403893613, 0.7540658567161816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 295}], {
             RGBColor[
             0.4198340277531679, 0.5369727534143199, 0.9482730796999772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 274}], {
             RGBColor[
             0.3194099032721399, 0.439775433054592, 0.9419873564929797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 289}], {
             RGBColor[
             0.7230554789857306, 0.77765901144776, 0.7574445908693186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 289}], {
             RGBColor[
             0.5901388047371748, 0.6512301648235828, 0.7493891199259992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 281}], {
             RGBColor[
             0.43067445049435477`, 0.5413293883437773, 0.9497198084838065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 282}], {
             RGBColor[
             0.4900356998954354, 0.5953926826555607, 0.9534053145294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 293}], {
             RGBColor[
             0.5157028699676903, 0.6176242953026696, 0.9550408039098287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 295}], {
             RGBColor[
             0.7330073921280417, 0.789349800004037, 0.9422440355129571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 280}], {
             RGBColor[
             0.9299433563050062, 0.9447540748368702, 0.9076588863446742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 294}], {
             RGBColor[
             0.6039663435199368, 0.6785142365312928, 0.9661204799254723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 293}], {
             RGBColor[
             0.42449999544328954`, 0.5421022928880015, 0.9482697422324073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 300}], {
             RGBColor[
             0.9146334967262718, 0.9346349129619443, 0.987107640000737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 296}], {
             RGBColor[
             0.8182605267990423, 0.37589274835899145`, 0.4370477403069123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 297}], {
             RGBColor[
             0.6840701192721679, 0.2681186404562903, 0.42542143976289926`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 291}], {
             RGBColor[
             0.93246331810449, 0.9482584733064816, 0.9682327983978469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 297}], {
             RGBColor[
             0.6188579691068153, 0.6977630832229227, 0.9652677701047174]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.09631744162763219], {
             RGBColor[
             0.6863373684330862, 0.7548912356679066, 0.9693713527641906]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.09631744162763219], {
             RGBColor[
             0.4191454445275317, 0.5374644500123263, 0.9479285549828986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.09631744162763219], {
             RGBColor[
             0.8940742431511792, 0.9183745487626755, 0.9897587935329003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.09631744162763219], {
             RGBColor[
             0.54446329328334, 0.6410588551360856, 0.957281291363475]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.09631744162763219], {
             RGBColor[
             0.7949811018945926, 0.8397645459709919, 0.9801999447822202]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.09631744162763219], {
             RGBColor[
             0.3136563208882056, 0.4460950731534598, 0.9412068813049702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.09631744162763219], {
             RGBColor[
             0.4139041155306846, 0.5329246742721125, 0.9475945821339448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.09631744162763219], {
             RGBColor[
             0.32126240486774027`, 0.45268308080363623`, 0.9416915342503501]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.09631744162763219], {
             RGBColor[
             0.28280077393078995`, 0.4145719223789155, 0.9394164577578809]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.09631744162763219], {
             RGBColor[
             0.8415829712008118, 0.8765194333470725, 0.9847521291547626]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.09631744162763219], {
             RGBColor[
             0.3290949232907396, 0.45946721458781575`, 0.9421906153982396]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.09631744162763219], {
             RGBColor[
             0.17952963788721843`, 0.3060274106289155, 0.9335353193361543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.09631744162763219], {
             RGBColor[
             0.6968789968030307, 0.7631264358698502, 0.9704220437629886]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.09631744162763219], {
             RGBColor[
             0.34072958729902103`, 0.469544575776573, 0.9429319659007178]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.09631744162763219], {
             RGBColor[
             0.4118598449485299, 0.5311540298418771, 0.9474643230201274]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.09631744162763219], {
             RGBColor[
             0.44898604103366546`, 0.5633108748739495, 0.949829971405266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.09631744162763219], {
             RGBColor[
             0.29352982158305185`, 0.4258488317223539, 0.9400274611494736]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.09631744162763219], {
             RGBColor[
             0.4420508549424184, 0.5573039652542994, 0.9493880674800761]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.09631744162763219], {
             RGBColor[
             0.46060580264740775`, 0.5729795665009334, 0.9506797225205047]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.09631744162763219], {
             RGBColor[
             0.8463572472938727, 0.8803263115094071, 0.9852075038705654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.09631744162763219], {
             RGBColor[
             0.9944712191250719, 0.9919817212720992, 0.7412897373312036]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.09631744162763219], {
             RGBColor[
             0.2726662790599182, 0.4039199257055417, 0.9388393132676263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.09631744162763219], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.09631744162763219], {
             RGBColor[
             0.4993173295177782, 0.6044073279487119, 0.9537272357207356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.09631744162763219], {
             RGBColor[
             0.5905625034015828, 0.6784842706558245, 0.9609103900509538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.09631744162763219], {
             RGBColor[
             0.4350841654010723, 0.551269768929583, 0.9489441561829032]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.09631744162763219], {
             RGBColor[
             0.5260978906220087, 0.6261489939036554, 0.9558354995912883]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.09631744162763219], {
             RGBColor[
             0.43765447699119764`, 0.5534960436413328, 0.9491079341645887]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.09631744162763219], {
             RGBColor[
             0.9512887655114114, 0.9631918215925125, 0.9673395934512256]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.09631744162763219], {
             RGBColor[
             0.3267772376128158, 0.45745975174386744`, 0.9420429345162913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.09631744162763219], {
             RGBColor[
             0.39845195233112995`, 0.5195407871569628, 0.9466099839586806]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.09631744162763219], {
             RGBColor[
             0.6156218179553561, 0.6988285511198333, 0.9628831510879207]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.09631744162763219], {
             RGBColor[
             0.5427080150108894, 0.6396338411601251, 0.9571431094280715]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.09631744162763219], {
             RGBColor[
             0.3392734065465934, 0.46828330519859285`, 0.9428391793508233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.09631744162763219], {
             RGBColor[
             0.6152593623132294, 0.6985342933011143, 0.9628546172520537]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.09631744162763219], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.09631744162763219], {
             RGBColor[
             0.3774541526813699, 0.5013535484804376, 0.945272022732623]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.09631744162763219], {
             RGBColor[
             0.9866814599209532, 0.988760455653516, 0.8703862065940488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.09631744162763219], {
             RGBColor[
             0.4878569361827492, 0.5951032643544992, 0.952825031576598]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.09631744162763219], {
             RGBColor[
             0.47865327299439897`, 0.5876313159578949, 0.952100485496282]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.09631744162763219], {
             RGBColor[
             0.6845045624321715, 0.7534594336901506, 0.9691886757905653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.09631744162763219], {
             RGBColor[
             0.36027618213981194`, 0.48647485378724364`, 0.9441774576395979]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.09631744162763219], {
             RGBColor[
             0.8251394496233515, 0.8634078155887084, 0.9831837313873995]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.09631744162763219], {
             RGBColor[
             0.9017002092393517, 0.9244552871200493, 0.9904861649861705]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.09631744162763219], {
             RGBColor[
             0.7736537191342328, 0.8231034324644864, 0.978074230584391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.09631744162763219], {
             RGBColor[
             0.513499229905432, 0.615920833570741, 0.9548436868692646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.09631744162763219], {
             RGBColor[
             0.4901009998378523, 0.5969250963236276, 0.9530016924878038]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.09631744162763219], {
             RGBColor[
             0.7444780195020518, 0.8003111541682968, 0.9751662695074698]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.09631744162763219], {
             RGBColor[
             0.3061724353620503, 0.43913702039209235`, 0.9407474393011165]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.09631744162763219], {
             RGBColor[
             0.4346366313656539, 0.5508821374418182, 0.9489156397099051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.09631744162763219], {
             RGBColor[
             0.3574024493559611, 0.48398577088788153`, 0.9439943459277531]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.09631744162763219], {
             RGBColor[
             0.586539387767822, 0.6752181241450436, 0.960593675651106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.09631744162763219], {
             RGBColor[
             0.6221559038656614, 0.704133216419035, 0.9633975382659252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.09631744162763219], {
             RGBColor[
             0.5528720080370206, 0.6478854285814063, 0.9579432561910217]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.09631744162763219], {
             RGBColor[
             0.9218821941447554, 0.9405478540582318, 0.9924111407231185]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.09631744162763219], {
             RGBColor[
             0.4774545573564216, 0.5866581446014607, 0.9520061182102204]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.09631744162763219], {
             RGBColor[
             0.3960135613889977, 0.5174287754799801, 0.9464546118440323]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.09631744162763219], {
             RGBColor[
             0.6225998139773913, 0.70449360264566, 0.9634324844960169]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.09631744162763219], {
             RGBColor[
             0.6612721862918014, 0.735310124876695, 0.966873089655792]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.09631744162763219], {
             RGBColor[
             0.7991021406427353, 0.8429839327620956, 0.9806106914113384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.09631744162763219], {
             RGBColor[
             0.7163627518180691, 0.7783472933696208, 0.972364002376845]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.09631744162763219], {
             RGBColor[
             0.8482198104157921, 0.8818114687848966, 0.9853851568038637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.09631744162763219], {
             RGBColor[
             0.7062717413828151, 0.7704641193230806, 0.9713582247625129]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.09631744162763219], {
             RGBColor[
             0.3196440159891005, 0.4512813136995487, 0.9415884119420883]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.09631744162763219], {
             RGBColor[
             0.7158792845184703, 0.7779696050406866, 0.9723158148746798]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.09631744162763219], {
             RGBColor[
             0.40566395646537556`, 0.5257874626521788, 0.9470695264847898]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.09631744162763219], {
             RGBColor[
             0.5755696646617934, 0.6663124087471752, 0.9597300988647797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.09631744162763219], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.09631744162763219], {
             RGBColor[
             0.3122346750464142, 0.4448637149792978, 0.9411162952890433]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.09631744162763219], {
             RGBColor[
             0.2669703175908264, 0.39793310905671037`, 0.9385149366883814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.09631744162763219], {
             RGBColor[
             0.39488074100237464`, 0.5164475833982953, 0.9463824295307105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.09631744162763219], {
             RGBColor[
             0.397838025602837, 0.51900903468177, 0.9465708650904279]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.09631744162763219], {
             RGBColor[
             0.277455231790087, 0.4089534186620895, 0.9391120370409887]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.09631744162763219], {
             RGBColor[
             0.6060687030874358, 0.6910729021071352, 0.9621310948913051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.09631744162763219], {
             RGBColor[
             0.3455723436903502, 0.4737391279587288, 0.9432405420556921]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.09631744162763219], {
             RGBColor[
             0.3356049006027803, 0.46510582973453196`, 0.9426054253960159]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.09631744162763219], {
             RGBColor[
             0.6542513690718328, 0.7298254091042683, 0.9661733202085727]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.09631744162763219], {
             RGBColor[
             0.8315616442739626, 0.8685286992772758, 0.9837962860463356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.09631744162763219], {
             RGBColor[
             0.6174112208024135, 0.7002812689627541, 0.9630240194348396]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.09631744162763219], {
             RGBColor[
             0.40763394957168064`, 0.5274937716661278, 0.9471950527035271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.09631744162763219], {
             RGBColor[
             0.3664483443972378, 0.49182087051273077`, 0.9445707423608123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.09631744162763219], {
             RGBColor[
             0.30376232793929336`, 0.43660384468113833`, 0.9406101872488248]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.09631744162763219], {
             RGBColor[
             0.29186645811488066`, 0.4241005312539708, 0.9399327350606869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.09631744162763219], {
             RGBColor[
             0.6952085357261314, 0.761821458980602, 0.9702555478141895]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.09631744162763219], {
             RGBColor[
             0.4518564716258988, 0.5657970975809056, 0.9500128727043811]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.09631744162763219], {
             RGBColor[
             0.23460821785708263`, 0.3639184903609118, 0.9366719629839809]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.09631744162763219], {
             RGBColor[
             0.5824632480680465, 0.671908930308765, 0.9602727870025479]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.09631744162763219], {
             RGBColor[
             0.24219828088041662`, 0.3718961278362265, 0.9371042058446677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.09631744162763219], {
             RGBColor[
             0.29929495028670605`, 0.43190834752016627`, 0.940355776700403]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.09631744162763219], {
             RGBColor[
             0.9850673749079383, 0.9880929900205415, 0.897135772377819]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.09631744162763219], {
             RGBColor[
             0.44760893267837215`, 0.5621180928320728, 0.9497422232785959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.09631744162763219], {
             RGBColor[
             0.9765897056121932, 0.9820612212931883, 0.9245117014026253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.09631744162763219], {
             RGBColor[
             0.3514583344338571, 0.47883727730225784`, 0.943615592181091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.09631744162763219], {
             RGBColor[
             0.31396276690037417`, 0.4463605012867758, 0.941226407773886]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.09631744162763219], {
             RGBColor[
             0.9531228242709844, 0.9645596596124064, 0.9642350103704034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.09631744162763219], {
             RGBColor[
             0.3253857891911297, 0.4562545490572341, 0.9419542726532709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.09631744162763219], {
             RGBColor[
             0.479513207264082, 0.5883294493376209, 0.9521681826720345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.09631744162763219], {
             RGBColor[
             0.9261155770021112, 0.9439234386365709, 0.9928149245592386]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.09631744162763219], {
             RGBColor[
             0.3883306461215388, 0.5107742204298564, 0.9459650632769251]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.09631744162763219], {
             RGBColor[
             0.4148087408639295, 0.533708215267978, 0.9476522240602504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.09631744162763219], {
             RGBColor[
             0.5158723467273136, 0.6178474367144391, 0.9550305073184964]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.09631744162763219], {
             RGBColor[
             0.3681151418851721, 0.4932645667211018, 0.9446769492228523]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.09631744162763219], {
             RGBColor[
             0.5665055597395904, 0.6589537600380575, 0.9590165393223935]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.09631744162763219], {
             RGBColor[
             0.9325537564430122, 0.9490570681630199, 0.9934290038617424]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.09631744162763219], {
             RGBColor[
             0.21570442378461654`, 0.3440494042209796, 0.9355954198772112]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.09631744162763219], {
             RGBColor[
             0.28452109755309885`, 0.41638009158077965`, 0.9395144276431806]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.09631744162763219], {
             RGBColor[
             0.6416835065696597, 0.7199866040026175, 0.9649348226827495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.09631744162763219], {
             RGBColor[
             0.8660315176196136, 0.8960140406233116, 0.987084053337663]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.09631744162763219], {
             RGBColor[
             0.27470808682292813`, 0.4060659951225544, 0.9389555911991458]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.09631744162763219], {
             RGBColor[
             0.5692091962098773, 0.6611486939220714, 0.9592293794890812]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.09631744162763219], {
             RGBColor[
             0.7171073897043916, 0.7789290101458736, 0.9724382209223169]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.09631744162763219], {
             RGBColor[
             0.19003257266048992`, 0.31706666100015046`, 0.9341334459337924]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.09631744162763219], {
             RGBColor[
             0.6268357130936961, 0.7079324963733568, 0.9637659499910621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.09631744162763219], {
             RGBColor[
             0.7507600103387772, 0.8052186931548453, 0.9757923996455324]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.09631744162763219], {
             RGBColor[
             0.520957580625565, 0.621975858680216, 0.9554308355587923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.09631744162763219], {
             RGBColor[
             0.9891831585861137, 0.989794972342283, 0.8289265855237283]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.09631744162763219], {
             RGBColor[
             0.347972253797608, 0.4758178094706463, 0.9433934622055693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.09631744162763219], {
             RGBColor[
             0.38640443572086597`, 0.5091058337949435, 0.9458423268534752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.09631744162763219], {
             RGBColor[
             0.990635183096344, 0.990395421792591, 0.804862781670237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.09631744162763219], {
             RGBColor[
             0.4103143233394802, 0.529815376704293, 0.9473658437498499]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.09631744162763219], {
             RGBColor[
             0.8822953510684036, 0.9089823799453784, 0.9886353122909041]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.09631744162763219], {
             RGBColor[
             0.6824575166352553, 0.7518602659554753, 0.9689846453962593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.09631744162763219], {
             RGBColor[
             0.34216185612067757`, 0.4707851350419678, 0.9430232288035282]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.09631744162763219], {
             RGBColor[
             0.40705579935517266`, 0.5269930070072634, 0.9471582134829694]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.09631744162763219], {
             RGBColor[
             0.9075397861225349, 0.9291116072156078, 0.9910431490423404]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.09631744162763219], {
             RGBColor[
             0.607356806504633, 0.6921186424896135, 0.9622324991107852]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.09631744162763219], {
             RGBColor[
             0.9909404361131257, 0.9905216517596749, 0.7998039492126812]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.09631744162763219], {
             RGBColor[
             0.3369999076484586, 0.4663141147224057, 0.9426943140114102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.09631744162763219], {
             RGBColor[
             0.4423649231917434, 0.5575759953863355, 0.9494080796312034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.09631744162763219], {
             RGBColor[
             0.7176605510414849, 0.7793611439865926, 0.9724933548748118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.09631744162763219], {
             RGBColor[
             0.38366306970718933`, 0.5067314003389588, 0.9456676494351786]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.09631744162763219], {
             RGBColor[
             0.5455645150707296, 0.6419528765925646, 0.9573679835764866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.09631744162763219], {
             RGBColor[
             0.3750286475177722, 0.4992526978171634, 0.9451174716883887]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.09631744162763219], {
             RGBColor[
             0.419101090027824, 0.5374260323740014, 0.9479257287533984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.09631744162763219], {
             RGBColor[
             0.3511146094465647, 0.4785395599943853, 0.9435936903288449]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.09631744162763219], {
             RGBColor[
             0.6711818953623815, 0.7430516649192106, 0.9678607968444509]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.09631744162763219], {
             RGBColor[
             0.4106084192231799, 0.5300701077770648, 0.9473845832795004]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.09631744162763219], {
             RGBColor[
             0.5844256996699266, 0.6735021369266084, 0.960427278381345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.09631744162763219], {
             RGBColor[
             0.7735293923192907, 0.8230063074117349, 0.9780618388493777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.09631744162763219], {
             RGBColor[
             0.25291327891467286`, 0.38315827014034376`, 0.9377144091312996]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.09631744162763219], {
             RGBColor[
             0.982405983373221, 0.9863989917240821, 0.9146662602813969]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.09631744162763219], {
             RGBColor[
             0.7690591469329695, 0.8195141177408175, 0.9776162865660875]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.09631744162763219], {
             RGBColor[
             0.6118579136841751, 0.6957728440705335, 0.9625868427560577]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.09631744162763219], {
             RGBColor[
             0.2883644866417613, 0.42041973719790665`, 0.9397333029659953]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.09631744162763219], {
             RGBColor[
             0.7444301048772783, 0.800273722899259, 0.97516149382546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.09631744162763219], {
             RGBColor[
             0.6687894217626179, 0.7411826463596025, 0.9676223374349634]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.09631744162763219], {
             RGBColor[
             0.3650727148716035, 0.49062936935877666`, 0.9444830884638603]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.09631744162763219], {
             RGBColor[
             0.7337218139790912, 0.7919083246635701, 0.9740941914633966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.09631744162763219], {
             RGBColor[
             0.6568215944637871, 0.7318332887148995, 0.9664294962555208]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.09631744162763219], {
             RGBColor[
             0.8305340461957833, 0.8677093204631424, 0.9836982728242912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.09631744162763219], {
             RGBColor[
             0.9254130333126405, 0.9433632493686274, 0.9927479153149688]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.09631744162763219], {
             RGBColor[
             0.5169298741072605, 0.6187059850825456, 0.9551137597476963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.09631744162763219], {
             RGBColor[
             0.8409117065936764, 0.8759841851703352, 0.9846881033372891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.09631744162763219], {
             RGBColor[
             0.3978990873520114, 0.5190619232998521, 0.9465747558910904]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.09631744162763219], {
             RGBColor[
             0.4423548935847691, 0.5575673082448771, 0.9494074405535159]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.09631744162763219], {
             RGBColor[
             0.8341784028717822, 0.8706152315531573, 0.9840458748174036]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.09631744162763219], {
             RGBColor[
             0.4579520843304667, 0.5708251584225928, 0.9504708120937045]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.09631744162763219], {
             RGBColor[
             0.37563411340545105`, 0.49977712193747054`, 0.9451560514393591]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.09631744162763219], {
             RGBColor[
             0.8620323087129659, 0.8928251799967847, 0.986702605222011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.09631744162763219], {
             RGBColor[
             0.5857102829442267, 0.6745450194985022, 0.9605284054822815]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.09631744162763219], {
             RGBColor[
             0.3023978047812153, 0.4351696443262332, 0.9405324796736034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.09631744162763219], {
             RGBColor[
             0.9583131855651852, 0.9684306225671847, 0.9554490825623534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.09631744162763219], {
             RGBColor[
             0.26625979595624427`, 0.3971863057690909, 0.9384744735324145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.09631744162763219], {
             RGBColor[
             0.42047319418507373`, 0.5386144800310511, 0.9480131580169943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.09631744162763219], {
             RGBColor[
             0.9697353182487848, 0.9769492304205876, 0.9361143912983368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.09631744162763219], {
             RGBColor[
             0.6312878022440195, 0.71154690290992, 0.9641164347575155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.09631744162763219], {
             RGBColor[
             0.2421776653082504, 0.37187445956277704`, 0.9371030318183309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.09631744162763219], {
             RGBColor[
             0.415433549619485, 0.5342493932082389, 0.9476920363216577]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.09631744162763219], {
             RGBColor[
             0.4483279623921215, 0.5627408802306384, 0.949788039216143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.09631744162763219], {
             RGBColor[
             0.9556760206565822, 0.9664638292963098, 0.9599131148698532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.09631744162763219], {
             RGBColor[
             0.2847846955344102, 0.4166571497722152, 0.939529439158258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.09631744162763219], {
             RGBColor[
             0.7735293923192907, 0.8230063074117349, 0.9780618388493777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.09631744162763219], {
             RGBColor[
             0.947107075465287, 0.9600731240030019, 0.9744181039398768]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.09631744162763219], {
             RGBColor[
             0.22709207840622284`, 0.3560185512472927, 0.9362439299613863]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.09631744162763219], {
             RGBColor[
             0.4276343348406907, 0.5448171001375517, 0.9484694595672222]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.09631744162763219], {
             RGBColor[
             0.8597298381333985, 0.8909892524555365, 0.9864829935226921]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.09631744162763219], {
             RGBColor[
             0.5390062509552067, 0.6366285823371516, 0.9568516930015996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.09631744162763219], {
             RGBColor[
             0.26625979595624427`, 0.3971863057690909, 0.9384744735324145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.09631744162763219], {
             RGBColor[
             0.434891234195863, 0.551102661616635, 0.9489318627771096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.09631744162763219], {
             RGBColor[
             0.35541692588265655`, 0.48226601025061655`, 0.9438678301277635]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.09631744162763219], {
             RGBColor[
             0.5889375756192281, 0.6771650810799466, 0.9607824697836203]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.09631744162763219], {
             RGBColor[
             0.34169195045491874`, 0.470378126372433, 0.9429932868300274]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.09631744162763219], {
             RGBColor[
             0.4992677804700651, 0.6043671017996193, 0.9537233350381955]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.09631744162763219], {
             RGBColor[
             0.42647506161628695`, 0.5438129959373397, 0.9483955917024682]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.09631744162763219], {
             RGBColor[
             0.349242755491924, 0.47691825418099093`, 0.9434744174500705]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.09631744162763219], {
             RGBColor[
             0.4425522782767134, 0.5577382729441962, 0.9494200177315462]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.09631744162763219], {
             RGBColor[
             0.7187220629897303, 0.7801904051883516, 0.9725991564654197]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.09631744162763219], {
             RGBColor[
             0.5380121129436418, 0.6358214963139562, 0.9567734308156817]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.09631744162763219], {
             RGBColor[
             0.38941373477102836`, 0.511712337380426, 0.9460340767279329]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.09631744162763219], {
             RGBColor[
             0.9935911077963088, 0.9887003525517306, 0.5438098186052865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.09631744162763219], {
             RGBColor[
             0.8404417555265515, 0.8756094589458917, 0.9846432789849765]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.09631744162763219], {
             RGBColor[
             0.26694663468835045`, 0.3979082168246254, 0.938513587982121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.09631744162763219], {
             RGBColor[
             0.30395646250124797`, 0.43680789241459483`, 0.9406212429249319]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.09631744162763219], {
             RGBColor[
             0.3134189745567612, 0.44588949569053615`, 0.9411917578066077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.09631744162763219], {
             RGBColor[
             0.9899408486666531, 0.9901082966623329, 0.8163697000501186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.09631744162763219], {
             RGBColor[
             0.6076541817454884, 0.6923600651067419, 0.9622559095790667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.09631744162763219], {
             RGBColor[
             0.35071166999902237`, 0.47819055409724964`, 0.9435680153835528]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.09631744162763219], {
             RGBColor[
             0.7535954662533613, 0.8074337728655815, 0.9760750113922562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.09631744162763219], {
             RGBColor[
             0.26947242075084066`, 0.40056297812038844`, 0.9386574277618143]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.09631744162763219], {
             RGBColor[
             0.7099916212288316, 0.7733701177309227, 0.9717289876213102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.09631744162763219], {
             RGBColor[
             0.5288756359054602, 0.6284040926607604, 0.9560541738752178]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.09631744162763219], {
             RGBColor[
             0.9939411730023949, 0.9894491066305273, 0.5819122559357318]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.09631744162763219], {
             RGBColor[
             0.9369799588431549, 0.9525203370078473, 0.9915606708061119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.09631744162763219], {
             RGBColor[
             0.8340850147874372, 0.8705407664296526, 0.9840369673785503]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.09631744162763219], {
             RGBColor[
             0.4950208895234849, 0.6009192844089286, 0.9533890042260066]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.09631744162763219], {
             RGBColor[
             0.4660797034620084, 0.5774235257786478, 0.9511106480441894]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.09631744162763219], {
             RGBColor[
             0.21668973846134912`, 0.34508503241878435`, 0.9356515320904086]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.09631744162763219], {
             RGBColor[
             0.374893708382739, 0.4991358203206358, 0.9451088734860262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.09631744162763219], {
             RGBColor[
             0.49885741906173753`, 0.6040339519217682, 0.9536910298849286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.09631744162763219], {
             RGBColor[
             0.9016586922182827, 0.9244221825743983, 0.9904822050556383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.09631744162763219], {
             RGBColor[
             0.8587916013152215, 0.8902411278844822, 0.9863935036574005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.09631744162763219], {
             RGBColor[
             0.27671442371177013`, 0.4081747824018334, 0.9390698491168559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.09631744162763219], {
             RGBColor[
             0.2615432737294446, 0.3922289418639433, 0.9382058745690676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.09631744162763219], {
             RGBColor[
             0.5063663943864427, 0.6101300763658473, 0.9542821639287723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.09631744162763219], {
             RGBColor[
             0.41287123737922327`, 0.5320300471312821, 0.947528768051472]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.09631744162763219], {
             RGBColor[
             0.2568528667966404, 0.38729902678859013`, 0.9379387628330796]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.09631744162763219], {
             RGBColor[
             0.7178415947417269, 0.7795025767012049, 0.9725113996189023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.09631744162763219], {
             RGBColor[
             0.3122346750464142, 0.4448637149792978, 0.9411162952890433]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.09631744162763219], {
             RGBColor[
             0.6463042842786991, 0.7236170860637908, 0.9653812290661229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.09631744162763219], {
             RGBColor[
             0.47903993599623035`, 0.5879452264017513, 0.9521309250241794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.09631744162763219], {
             RGBColor[
             0.6645875272779449, 0.7379000944525951, 0.9672035318616677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.09631744162763219], {
             RGBColor[
             0.5098950579192125, 0.6129948043862303, 0.9545599532479924]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.09631744162763219], {
             RGBColor[
             0.6324855248697078, 0.712519268094243, 0.9642107238700123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.09631744162763219], {
             RGBColor[
             0.5794228442842807, 0.6694405935484743, 0.9600334352793238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.09631744162763219], {
             RGBColor[
             0.7163627518180691, 0.7783472933696208, 0.972364002376845]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.09631744162763219], {
             RGBColor[
             0.742410938057355, 0.7986963344332988, 0.9749602421470368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.09631744162763219], {
             RGBColor[
             0.7465444285040961, 0.8019254485859838, 0.9753722298451035]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.09631744162763219], {
             RGBColor[
             0.39847040780612075`, 0.5195567723618006, 0.9466111599252275]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.09631744162763219], {
             RGBColor[
             0.8821239993039492, 0.9088457486996222, 0.9886189686066429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.09631744162763219], {
             RGBColor[
             0.41839212466488235`, 0.5368119622102567, 0.9478805541073853]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.09631744162763219], {
             RGBColor[
             0.27486671561910364`, 0.40623272404498145`, 0.9389646248744177]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.09631744162763219], {
             RGBColor[
             0.39422377600587816`, 0.5158785533383509, 0.946340568302065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.09631744162763219], {
             RGBColor[
             0.21570442378461654`, 0.3440494042209796, 0.9355954198772112]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.09631744162763219], {
             RGBColor[
             0.2964387886187925, 0.42890634051608006`, 0.9401931225187279]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.09631744162763219], {
             RGBColor[
             0.5495712907760403, 0.6452057576133243, 0.9576834116373116]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.09631744162763219], {
             RGBColor[
             0.5635951593245416, 0.6565909658690763, 0.9587874219405728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.09631744162763219], {
             RGBColor[
             0.6184645525119521, 0.7011364110966103, 0.9631069415654957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.09631744162763219], {
             RGBColor[
             0.9369799588431549, 0.9525203370078473, 0.9915606708061119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.09631744162763219], {
             RGBColor[
             0.24751107879278922`, 0.3774802152929733, 0.9374067618261972]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.09631744162763219], {
             RGBColor[
             0.2615432737294446, 0.3922289418639433, 0.9382058745690676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.09631744162763219], {
             RGBColor[
             0.2698177979130481, 0.40092599141604535`, 0.9386770964802622]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.09631744162763219], {
             RGBColor[
             0.6734668241938883, 0.744836668688486, 0.9680885371965016]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.09631744162763219], {
             RGBColor[
             0.24306159935685662`, 0.3728035302925178, 0.9371533705547358]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.09631744162763219], {
             RGBColor[
             0.5150058754069695, 0.6171439962624956, 0.9549622955221699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.09631744162763219], {
             RGBColor[
             0.993781657314813, 0.9891079187042997, 0.5645499577591597]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.09631744162763219], {
             RGBColor[
             0.4229360120548922, 0.5407476490850625, 0.9481700865938748]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.09631744162763219], {
             RGBColor[
             0.6574011788036657, 0.7322860644062168, 0.9664872638059963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.09631744162763219], {
             RGBColor[
             0.6895850079769036, 0.7574283163625115, 0.9696950471230013]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.09631744162763219], {
             RGBColor[
             0.2477893136316296, 0.37777265774970226`, 0.9374226068886576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.09631744162763219], {
             RGBColor[
             0.24924224167328835`, 0.37929977724244407`, 0.9375053489912156]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.09631744162763219], {
             RGBColor[
             0.40355331797932403`, 0.5239593336793358, 0.946935038466823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.09631744162763219], {
             RGBColor[
             0.9816640371140846, 0.9858456494188437, 0.9159221817675386]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.09631744162763219], {
             RGBColor[
             0.444887597395223, 0.5597610089880973, 0.9495688222007359]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.09631744162763219], {
             RGBColor[
             0.8463572472938727, 0.8803263115094071, 0.9852075038705654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.09631744162763219], {
             RGBColor[
             0.4015884611666869, 0.5222574734648043, 0.9468098395281764]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.09631744162763219], {
             RGBColor[
             0.19003257266048992`, 0.31706666100015046`, 0.9341334459337924]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.09631744162763219], {
             RGBColor[
             0.4480625312671665, 0.5625109771311585, 0.9497711261795724]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.09631744162763219], {
             RGBColor[
             0.38009349703798434`, 0.5036396159048324, 0.945440199421146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.09631744162763219], {
             RGBColor[
             0.39704095110187126`, 0.5183186488111627, 0.9465200762080517]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.09631744162763219], {
             RGBColor[
             0.3949384807440944, 0.5164975946604892, 0.9463861086559956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.09631744162763219], {
             RGBColor[
             0.46993061337964154`, 0.5805498679312971, 0.9514138057792533]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.09631744162763219], {
             RGBColor[
             0.3988328253710346, 0.5198706802408926, 0.9466342528519905]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.09631744162763219], {
             RGBColor[
             0.6328064788680461, 0.712779833008907, 0.9642359905444546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.09631744162763219], {
             RGBColor[
             0.4939657857007103, 0.6000627035937146, 0.9533059425881051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.09631744162763219], {
             RGBColor[
             0.3491747368872138, 0.4768593398843054, 0.9434700833647249]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.09631744162763219], {
             RGBColor[
             0.7699061027504018, 0.8201757660624983, 0.977700703206717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.09631744162763219], {
             RGBColor[
             0.8695941724444349, 0.8988548048749352, 0.9874238625352739]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.09631744162763219], {
             RGBColor[
             0.42946579000086116`, 0.5464034145456784, 0.948586158270536]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.09631744162763219], {
             RGBColor[
             0.46546999427241, 0.5769285363914458, 0.9510626495033458]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.09631744162763219], {
             RGBColor[
             0.3234719446437745, 0.45459687310293895`, 0.9418323241710598]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.09631744162763219], {
             RGBColor[
             0.34627569736713004`, 0.4743483375619718, 0.9432853591300252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.09631744162763219], {
             RGBColor[
             0.38737368542052547`, 0.509945349168882, 0.9459040865872637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.09631744162763219], {
             RGBColor[
             0.4523265775206957, 0.5662042796787693, 0.9500428274362992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.09631744162763219], {
             RGBColor[
             0.1864932290235841, 0.3133465864304147, 0.9339318855496603]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.09631744162763219], {
             RGBColor[
             0.3271594748992157, 0.45779082646954244`, 0.9420672903381815]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.09631744162763219], {
             RGBColor[
             0.24632008378448794`, 0.3762284040258037, 0.9373389364223936]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.09631744162763219], {
             RGBColor[
             0.5812385744198362, 0.6709146850702287, 0.9601763762068334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.09631744162763219], {
             RGBColor[
             0.9726224261168775, 0.9791024307414059, 0.931227270755985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.09631744162763219], {
             RGBColor[
             0.9892514626001214, 0.9898232178074082, 0.8277946112465003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.09631744162763219], {
             RGBColor[
             0.8706352500098911, 0.8996849318663322, 0.9875231614428481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.09631744162763219], {
             RGBColor[
             0.28011032656887336`, 0.4117440916173259, 0.9392632407607798]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.09631744162763219], {
             RGBColor[
             0.3988328253710346, 0.5198706802408926, 0.9466342528519905]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.09631744162763219], {
             RGBColor[
             0.4584559616607367, 0.5712342287387211, 0.9505104791629069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.09631744162763219], {
             RGBColor[
             0.4779395986165179, 0.5870519229472666, 0.9520443024349798]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.09631744162763219], {
             RGBColor[
             0.504692464341047, 0.6087711045453059, 0.9541503860237909]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.09631744162763219], {
             RGBColor[
             0.5702634038680211, 0.6620045471904663, 0.9593123705776201]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.09631744162763219], {
             RGBColor[
             0.9408576172742646, 0.9554122883166861, 0.9849968065375354]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.09631744162763219], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.09631744162763219], {
             RGBColor[
             0.9937843804507656, 0.9891137432167507, 0.5648463543023381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.09631744162763219], {
             RGBColor[
             0.9010555016129866, 0.9239412147589081, 0.9904246721972305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.09631744162763219], {
             RGBColor[
             0.9638711345959934, 0.9725757318540552, 0.9460409245984633]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.09631744162763219], {
             RGBColor[
             0.5314401272230496, 0.6304860622413966, 0.9562560600257797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.09631744162763219], {
             RGBColor[
             0.4501671655155445, 0.5643339055351105, 0.949905231612824]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.09631744162763219], {
             RGBColor[
             0.9278223604710003, 0.94528438144526, 0.9929777190901649]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.09631744162763219], {
             RGBColor[
             0.4933923581392058, 0.5995971692666681, 0.9532608002699291]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.09631744162763219], {
             RGBColor[
             0.8201435803971269, 0.8594242450769743, 0.982707220920737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.09631744162763219], {
             RGBColor[
             0.41757235781650376`, 0.5361019213688709, 0.9478283192886979]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.09631744162763219], {
             RGBColor[
             0.9587781758750935, 0.9687774115789627, 0.9546619752565745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.09631744162763219], {
             RGBColor[
             0.8927847923557348, 0.9173463756995976, 0.9896358045649245]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.09631744162763219], {
             RGBColor[
             0.888409376178279, 0.9138575376072026, 0.9892184734639387]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1FO4EAYYBuBzsm2dTrZdW7WsZbtVy3bLtWxr2bat5WVjyzZXrfc8u3i/
//a7+f7gJu2rtAsMCAjIJEJuKEIThrCEIzwRiEgkIhOFqEQjOjGISSxiE4e4
xCM+CUhIIhKThKQkI4jkBJOClKQiNWlISzrSk4GMIX3JTBayko3s5CAnuchN
HvKSj/wUoCCF+IEfKUwRivITxShOCUpSitKUoSzlKE8FfqYilahMFapSjerU
oCa1qE0d6lKP+jSgIY1oTBN+oSnNaM6vtKAlrWhNG9rSjvZ0oCOd6EwXutKN
7vSgJ73ozW/0oS/96M8ABjKIwQzhd4YyjOGMYCSjGM0YxjKO8UxgIpOYzBSm
Mo3pzGAms5jNH8xhLvOYzwIWsojFLGEpy1jOClayitWsYS3rWM8GNrKJzWxh
K9vYzg52sovd7GEv+9jPAQ5yiMMc4U+OcozjnOAkpzjNX5zhLOc4zwUuconL
XOEq17jODW5yi9v8zT/c4S73uM8DHvKIxzzhKc94zgte8orXvOEt73jPBz7y
ic/8yxe+8o3/CBl/IKEITRjCEo7wRCAikYhMFKISjejEICaxiE0c4hKP+CQg
IYlITBKSkowgkhNMClKSitSkIS3pSE8GMgb+/6++Az6VhWw=
          "], {Null, CompressedData["
1:eJxN2guYllWBB/D3qyhJJoMEhjQEkUhkrd1Es1FL08DywkWybEVNDSyNClNB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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[72, 227] -> 
             RGBColor[
              0.8705118000329004, 0.43480247052567644`, 0.21080209492961144`],
              UndirectedEdge[132, 236] -> 
             RGBColor[
              0.21416362323535532`, 0.3424299251513089, 0.9355076735653408], 
             UndirectedEdge[187, 193] -> 
             RGBColor[
              0.25215196023065367`, 0.38235807593304705`, 0.9376710531585147],
              UndirectedEdge[196, 225] -> 
             RGBColor[
              0.21532817540767707`, 0.3436539433212913, 0.935573993088754], 
             UndirectedEdge[39, 166] -> 
             RGBColor[
              0.19390930592620187`, 0.3211413534614994, 0.9343542201581618], 
             UndirectedEdge[7, 216] -> 
             RGBColor[
              0.8904157072945873, 0.6421896715609007, 0.4699552151052654], 
             UndirectedEdge[92, 281] -> 
             RGBColor[
              0.8805236512409333, 0.4901849175991575, 0.4256811132326063], 
             UndirectedEdge[99, 229] -> 
             RGBColor[
              0.20669327315473038`, 0.33457811356902034`, 0.9350822481796419],
              UndirectedEdge[187, 296] -> 
             RGBColor[
              0.20597365560918635`, 0.3338217499022659, 0.9350412670250019], 
             UndirectedEdge[100, 244] -> 
             RGBColor[
              0.18508330510196136`, 0.31186466699444937`, 0.9338515924681194],
              UndirectedEdge[232, 245] -> 
             RGBColor[
              0.206575126823306, 0.3344539342837832, 0.9350755199208491], 
             UndirectedEdge[6, 52] -> 
             RGBColor[
              0.20466403550360635`, 0.3324452561365908, 0.9349666860973984], 
             UndirectedEdge[113, 160] -> 
             RGBColor[
              0.23169850636271255`, 0.3608601990939647, 0.936506259218909], 
             UndirectedEdge[176, 288] -> 
             RGBColor[
              0.20152898742648828`, 0.32915012183401104`, 0.9347881497472945],
              UndirectedEdge[187, 228] -> 
             RGBColor[
              0.32549861800497937`, 0.4485853630705261, 0.9422458467242234], 
             UndirectedEdge[61, 268] -> 
             RGBColor[
              0.24115438507843467`, 0.37079892716152685`, 0.9370447575230503],
              UndirectedEdge[51, 101] -> 
             RGBColor[
              0.7293123816710212, 0.7884636426315792, 0.9736547004594159], 
             UndirectedEdge[207, 214] -> 
             RGBColor[
              0.19305906954872248`, 0.3202477011206687, 0.9343058004542764], 
             UndirectedEdge[17, 162] -> 
             RGBColor[
              0.8475057087773203, 0.8795582824939998, 0.8820715972741542], 
             UndirectedEdge[20, 279] -> 
             RGBColor[
              0.22783544818024304`, 0.35679988001215385`, 0.9362862637702997],
              UndirectedEdge[51, 197] -> 
             RGBColor[
              0.8988192263028636, 0.9205652040419037, 0.9289214218265444], 
             UndirectedEdge[86, 94] -> 
             RGBColor[
              0.6955329406462065, 0.7613368008112785, 0.9707925147289977], 
             UndirectedEdge[55, 114] -> 
             RGBColor[
              0.22063449464495144`, 0.3492312212797382, 0.9358761801193209], 
             UndirectedEdge[13, 270] -> 
             RGBColor[
              0.27306394266259, 0.4020687514269927, 0.9389450440967648], 
             UndirectedEdge[151, 220] -> 
             RGBColor[
              0.46545874896093703`, 0.5736549196510825, 0.9519637517959829], 
             UndirectedEdge[117, 225] -> 
             RGBColor[
              0.20655322702626136`, 0.33443091620856197`, 0.9350742727598051],
              UndirectedEdge[13, 277] -> 
             RGBColor[
              0.6631499633187324, 0.7252798242769541, 0.7115734484509257], 
             UndirectedEdge[81, 237] -> 
             RGBColor[
              0.8465380738337873, 0.3261495278745926, 0.19092293386380793`], 
             UndirectedEdge[172, 174] -> 
             RGBColor[
              0.21189442021644855`, 0.34004484890265657`, 0.9353784458103991],
              UndirectedEdge[128, 197] -> 
             RGBColor[
              0.8920740737202894, 0.5604973646047849, 0.4191176658739154], 
             UndirectedEdge[44, 71] -> 
             RGBColor[
              0.26976807981775686`, 0.40018277558695564`, 0.9386995645005083],
              UndirectedEdge[70, 122] -> 
             RGBColor[
              0.19740509453050553`, 0.32481564893042175`, 0.9345533001476212],
              UndirectedEdge[42, 293] -> 
             RGBColor[
              0.8583227451079464, 0.4059379610803489, 0.20178529360286196`], 
             UndirectedEdge[154, 181] -> 
             RGBColor[
              0.7417957890267707, 0.7840980478369171, 0.6774116520475943], 
             UndirectedEdge[42, 216] -> 
             RGBColor[
              0.847224395566658, 0.3555429478987492, 0.19252455870016974`], 
             UndirectedEdge[125, 130] -> 
             RGBColor[
              0.8607307087477495, 0.4103624865662075, 0.20352137280561344`], 
             UndirectedEdge[173, 263] -> 
             RGBColor[
              0.20558810816091344`, 0.33341651508901093`, 0.935019310668189], 
             UndirectedEdge[112, 132] -> 
             RGBColor[
              0.1930638232066118, 0.32025269751650964`, 0.9343060711680607], 
             UndirectedEdge[208, 279] -> 
             RGBColor[
              0.21299163292133522`, 0.34119808902279597`, 0.9354409304507616],
              UndirectedEdge[271, 295] -> 
             RGBColor[
              0.20977901412683497`, 0.3378214229779799, 0.9352579765630585], 
             UndirectedEdge[193, 264] -> 
             RGBColor[
              0.28788684943506876`, 0.4199177102097248, 0.939706102233675], 
             UndirectedEdge[16, 39] -> 
             RGBColor[
              0.22425729902189784`, 0.35303901837897317`, 0.9360824934691292],
              UndirectedEdge[168, 282] -> 
             RGBColor[
              0.42052178364044757`, 0.5386565657751188, 0.9480162540941248], 
             UndirectedEdge[92, 243] -> 
             RGBColor[
              0.8835089623946862, 0.49205410836049707`, 0.4046294016989433], 
             UndirectedEdge[71, 280] -> 
             RGBColor[
              0.2426648792276659, 0.37238655228322937`, 0.9371307779302732], 
             UndirectedEdge[69, 118] -> 
             RGBColor[
              0.19814492935345804`, 0.3255932622375819, 0.9345954326463008], 
             UndirectedEdge[175, 253] -> 
             RGBColor[
              0.18722926764301806`, 0.3141202096869836, 0.9339738018601655], 
             UndirectedEdge[137, 179] -> 
             RGBColor[
              0.3921454633437752, 0.5078279411583735, 0.9468889147894293], 
             UndirectedEdge[134, 221] -> 
             RGBColor[
              0.21549733286296777`, 0.343831738532004, 0.9355836263555868], 
             UndirectedEdge[91, 163] -> 
             RGBColor[
              0.5556545906660699, 0.6501444545135875, 0.9581623112885165], 
             UndirectedEdge[160, 232] -> 
             RGBColor[
              0.19183608079529113`, 0.31896226239884673`, 0.9342361530540182],
              UndirectedEdge[135, 263] -> 
             RGBColor[
              0.21148289076359805`, 0.33961230535523634`, 0.9353550098168626],
              UndirectedEdge[160, 297] -> 
             RGBColor[
              0.1938787777952211, 0.3211092664602433, 0.9343524816262648], 
             UndirectedEdge[179, 274] -> 
             RGBColor[
              0.4929016619374462, 0.5991987999844676, 0.9532221708674471], 
             UndirectedEdge[209, 259] -> 
             RGBColor[
              0.18280847530695815`, 0.30947367664736153`, 0.9337220442766032],
              UndirectedEdge[14, 173] -> 
             RGBColor[
              0.1907403974209291, 0.31781062970205387`, 0.9341737555067666], 
             UndirectedEdge[260, 267] -> 
             RGBColor[
              0.22718681650953165`, 0.35611812700061296`, 0.9362493251562173],
              UndirectedEdge[203, 216] -> 
             RGBColor[
              0.8900175091899872, 0.6418926960664795, 0.4706292606296545], 
             UndirectedEdge[37, 279] -> 
             RGBColor[
              0.23161750381713786`, 0.36077506028270767`, 0.936501646243771], 
             UndirectedEdge[192, 220] -> 
             RGBColor[
              0.3318533670341157, 0.4618564399149144, 0.9423663809943715], 
             UndirectedEdge[60, 225] -> 
             RGBColor[
              0.25743202099321577`, 0.38790775456968785`, 0.9379717448077927],
              UndirectedEdge[177, 226] -> 
             RGBColor[
              0.6391144281004404, 0.7063980774045702, 0.908678535889838], 
             UndirectedEdge[91, 273] -> 
             RGBColor[
              0.3645444727684772, 0.4827165664417553, 0.9449621664859775], 
             UndirectedEdge[52, 273] -> 
             RGBColor[
              0.2188316043007933, 0.34733626921817795`, 0.9357735081813584], 
             UndirectedEdge[21, 114] -> 
             RGBColor[
              0.21635493982133241`, 0.34473313782066695`, 0.9356324658031498],
              UndirectedEdge[7, 202] -> 
             RGBColor[
              0.890487052481644, 0.642513633392233, 0.47001474727817605`], 
             UndirectedEdge[94, 293] -> 
             RGBColor[
              0.8483237902546403, 0.739482330174071, 0.6092293420609014], 
             UndirectedEdge[132, 133] -> 
             RGBColor[
              0.19109281456444907`, 0.3181810424644308, 0.9341938251417357], 
             UndirectedEdge[13, 93] -> 
             RGBColor[
              0.2872094013725457, 0.41693652540503934`, 0.939750607043966], 
             UndirectedEdge[141, 178] -> 
             RGBColor[
              0.27642955220691934`, 0.4078753643883386, 0.9390536261060842], 
             UndirectedEdge[245, 264] -> 
             RGBColor[
              0.26072622472382, 0.3913701715551329, 0.938159344836913], 
             UndirectedEdge[5, 83] -> 
             RGBColor[
              0.8880392864849254, 0.5438464775091899, 0.242104808287807], 
             UndirectedEdge[210, 226] -> 
             RGBColor[
              0.7289680937933078, 0.7852771577024377, 0.9144848957128108], 
             UndirectedEdge[91, 298] -> 
             RGBColor[
              0.3751482927558811, 0.4938618535695355, 0.9455660383473143], 
             UndirectedEdge[126, 192] -> 
             RGBColor[
              0.2770528278061131, 0.40650831596386994`, 0.939163161568517], 
             UndirectedEdge[127, 156] -> 
             RGBColor[
              0.3716633849526351, 0.49633787652625627`, 0.9449030401335229], 
             UndirectedEdge[36, 268] -> 
             RGBColor[
              0.19319132437376368`, 0.32038670932722724`, 0.934313332170909], 
             UndirectedEdge[25, 221] -> 
             RGBColor[
              0.1886556188584439, 0.3156193952502866, 0.9340550304517865], 
             UndirectedEdge[69, 249] -> 
             RGBColor[
              0.20751277813074143`, 0.3354394652584245, 0.9351289177756767], 
             UndirectedEdge[22, 161] -> 
             RGBColor[
              0.1950980417525622, 0.32239079018520866`, 0.934421916904896], 
             UndirectedEdge[96, 112] -> 
             RGBColor[
              0.1950909003644823, 0.32238328413354655`, 0.9344215102134096], 
             UndirectedEdge[219, 250] -> 
             RGBColor[
              0.1834940050025886, 0.3101942118225623, 0.933761084178619], 
             UndirectedEdge[41, 219] -> 
             RGBColor[
              0.18646440411145038`, 0.3133162896201571, 0.933930244013557], 
             UndirectedEdge[202, 237] -> 
             RGBColor[
              0.8527387116152162, 0.3892539418421428, 0.19746540404923543`], 
             UndirectedEdge[91, 235] -> 
             RGBColor[
              0.44932632055040805`, 0.5626052939537676, 0.9501280434357534], 
             UndirectedEdge[69, 263] -> 
             RGBColor[
              0.2087290677202517, 0.3367178627342138, 0.9351981836684602], 
             UndirectedEdge[12, 239] -> 
             RGBColor[
              0.3335981101513706, 0.4567875043441526, 0.9427184858018454], 
             UndirectedEdge[122, 266] -> 
             RGBColor[
              0.19159505471631844`, 0.31870892870791034`, 0.9342224269753869],
              UndirectedEdge[206, 254] -> 
             RGBColor[
              0.27060222090313846`, 0.400822588016517, 0.9387557425033809], 
             UndirectedEdge[137, 270] -> 
             RGBColor[
              0.23718665422901314`, 0.36662859047011903`, 0.9368188011209075],
              UndirectedEdge[25, 58] -> 
             RGBColor[
              0.19112827338567, 0.31821831193375316`, 0.9341958444691476], 
             UndirectedEdge[107, 156] -> 
             RGBColor[
              0.4014834091317521, 0.5221664826722128, 0.9468031457054042], 
             UndirectedEdge[136, 194] -> 
             RGBColor[
              0.539310518839214, 0.6345587760249104, 0.957788184762517], 
             UndirectedEdge[45, 281] -> 
             RGBColor[
              0.6391981620742301, 0.7080190375817033, 0.9308676637061029], 
             UndirectedEdge[137, 147] -> 
             RGBColor[
              0.23746595794531072`, 0.3669221563848262, 0.9368347070543579], 
             UndirectedEdge[164, 187] -> 
             RGBColor[
              0.2033506574299822, 0.3310648125082323, 0.9348918911590742], 
             UndirectedEdge[199, 229] -> 
             RGBColor[
              0.20805355497894237`, 0.33600785601311617`, 0.9351597142171741],
              UndirectedEdge[191, 271] -> 
             RGBColor[
              0.22500596477055484`, 0.35382591354896176`, 0.9361251288759636],
              UndirectedEdge[153, 222] -> 
             RGBColor[
              0.2212473690290584, 0.3498753911159149, 0.9359110824088295], 
             UndirectedEdge[158, 186] -> 
             RGBColor[
              0.19303082310645578`, 0.3202180123189185, 0.9343041918611762], 
             UndirectedEdge[16, 192] -> 
             RGBColor[
              0.28870383608450384`, 0.4187542643810497, 0.9398266692538492], 
             UndirectedEdge[75, 143] -> 
             RGBColor[
              0.31991196504772945`, 0.4513422193006194, 0.941611753099148], 
             UndirectedEdge[204, 226] -> 
             RGBColor[
              0.734932739386402, 0.7901195256991334, 0.9149544544631159], 
             UndirectedEdge[137, 191] -> 
             RGBColor[
              0.24445543716588297`, 0.3742685422042259, 0.9372327475559615], 
             UndirectedEdge[197, 198] -> 
             RGBColor[
              0.9754663865596167, 0.9808663065126991, 0.9104194926535587], 
             UndirectedEdge[80, 156] -> 
             RGBColor[
              0.6866499660786538, 0.7281441949934098, 0.6592663633827371], 
             UndirectedEdge[103, 159] -> 
             RGBColor[
              0.35628521918114736`, 0.4813996069512451, 0.9439824173184419], 
             UndirectedEdge[28, 288] -> 
             RGBColor[
              0.19616769103516415`, 0.32351505940090497`, 0.9344828318491358],
              UndirectedEdge[118, 263] -> 
             RGBColor[
              0.19930513416780576`, 0.32681271105869525`, 0.9346615045941087],
              UndirectedEdge[68, 83] -> 
             RGBColor[
              0.8566539261889098, 0.5407679915618476, 0.4575135965364173], 
             UndirectedEdge[64, 90] -> 
             RGBColor[
              0.22549030939770529`, 0.3543349904613199, 0.936152711585956], 
             UndirectedEdge[213, 263] -> 
             RGBColor[
              0.2061321686296245, 0.3339883571370523, 0.9350502941070169], 
             UndirectedEdge[52, 53] -> 
             RGBColor[
              0.2073052253779457, 0.3352213141556316, 0.9351170979534518], 
             UndirectedEdge[245, 297] -> 
             RGBColor[
              0.20861782382323596`, 0.3366009383451798, 0.9351918484930957], 
             UndirectedEdge[189, 267] -> 
             RGBColor[
              0.20602096440657885`, 0.33387147444787646`, 0.9350439611910263],
              UndirectedEdge[145, 203] -> 
             RGBColor[
              0.9010144773435402, 0.923871728137574, 0.9891457475385399], 
             UndirectedEdge[136, 279] -> 
             RGBColor[
              0.3146411108912604, 0.44028382744269734`, 0.9415136410409652], 
             UndirectedEdge[80, 256] -> 
             RGBColor[
              0.8715548723467077, 0.4059318707085048, 0.23392588524752353`], 
             UndirectedEdge[40, 130] -> 
             RGBColor[
              0.8005184128051482, 0.7225949328330918, 0.608776500228449], 
             UndirectedEdge[83, 101] -> 
             RGBColor[
              0.7801443981327315, 0.4806917133441988, 0.4499691651133977], 
             UndirectedEdge[83, 194] -> 
             RGBColor[
              0.7930369047021925, 0.4907634374629408, 0.4512541696809177], 
             UndirectedEdge[149, 197] -> 
             RGBColor[
              0.9409227595816787, 0.803504489870005, 0.5552674312684278], 
             UndirectedEdge[23, 44] -> 
             RGBColor[
              0.6527829845870825, 0.7190887957178285, 0.883793610021852], 
             UndirectedEdge[97, 284] -> 
             RGBColor[
              0.3449079379891919, 0.4668961630433738, 0.9434276902262162], 
             UndirectedEdge[135, 276] -> 
             RGBColor[
              0.22722517815635135`, 0.3561584475236893, 0.9362515097952526], 
             UndirectedEdge[142, 150] -> 
             RGBColor[
              0.8557601994902863, 0.3776078411395296, 0.19898565697406115`], 
             UndirectedEdge[46, 214] -> 
             RGBColor[
              0.20276955741382008`, 0.3304540395473769, 0.9348587983728143], 
             UndirectedEdge[5, 243] -> 
             RGBColor[
              0.9792150980469998, 0.9514729807028455, 0.600039087887734], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.17910006852395627`, 0.30557590599185624`, 0.9335108559964074],
              UndirectedEdge[198, 243] -> 
             RGBColor[
              0.9760042846861029, 0.9810887412113525, 0.9015051286619535], 
             UndirectedEdge[13, 32] -> 
             RGBColor[
              0.6604824509868196, 0.7261357390166185, 0.898179624729629], 
             UndirectedEdge[86, 140] -> 
             RGBColor[
              0.7429383557535131, 0.3165575788102572, 0.4298769805861715], 
             UndirectedEdge[171, 275] -> 
             RGBColor[
              0.17966143058790973`, 0.3061659331134819, 0.9335428247354888], 
             UndirectedEdge[36, 250] -> 
             RGBColor[
              0.18199349180428678`, 0.3086170773131154, 0.9336756321717861], 
             UndirectedEdge[168, 203] -> 
             RGBColor[
              0.6687682561638781, 0.7369332784725033, 0.9690249189979729], 
             UndirectedEdge[17, 169] -> 
             RGBColor[
              0.654201051554568, 0.729209809683748, 0.9665623183284373], 
             UndirectedEdge[191, 246] -> 
             RGBColor[
              0.2059132617802264, 0.3337582721588391, 0.9350378276857872], 
             UndirectedEdge[17, 178] -> 
             RGBColor[
              0.4813372368134904, 0.5789969861106385, 0.9545799540531321], 
             UndirectedEdge[9, 132] -> 
             RGBColor[
              0.19792820821317225`, 0.32536547457822756`, 0.9345830906979717],
              UndirectedEdge[11, 283] -> 
             RGBColor[
              0.41881779248479195`, 0.534778825033336, 0.9485064845740085], 
             UndirectedEdge[64, 69] -> 
             RGBColor[
              0.22143670136219934`, 0.3500743914024093, 0.9359218646051097], 
             UndirectedEdge[193, 288] -> 
             RGBColor[
              0.24421454187002306`, 0.3740153459746332, 0.9372190289252349], 
             UndirectedEdge[221, 288] -> 
             RGBColor[
              0.19753047223834988`, 0.324947428850772, 0.9345604402226031], 
             UndirectedEdge[65, 264] -> 
             RGBColor[
              0.33683666992223255`, 0.4650136831097602, 0.942726350900722], 
             UndirectedEdge[27, 151] -> 
             RGBColor[
              0.7838347809145911, 0.7971566134890326, 0.6494113635450639], 
             UndirectedEdge[201, 293] -> 
             RGBColor[
              0.8634956504151338, 0.4456991780529511, 0.2067388735669856], 
             UndirectedEdge[43, 99] -> 
             RGBColor[
              0.21063039427602828`, 0.33871627749540134`, 0.9353064614030511],
              UndirectedEdge[77, 293] -> 
             RGBColor[0.6567707297143, 0.585264649646495, 0.5928277208084357],
              UndirectedEdge[61, 280] -> 
             RGBColor[
              0.2696360759953822, 0.40073499015874336`, 0.9386667476858847], 
             UndirectedEdge[20, 55] -> 
             RGBColor[
              0.21057054856025512`, 0.3386533758536862, 0.9353030532780715], 
             UndirectedEdge[208, 242] -> 
             RGBColor[
              0.18509931747274389`, 0.3118814970113848, 0.9338525043489474], 
             UndirectedEdge[29, 261] -> 
             RGBColor[
              0.21999581851421782`, 0.3485599321719316, 0.9358398084585123], 
             UndirectedEdge[12, 76] -> 
             RGBColor[
              0.3782689418854923, 0.5020592779365523, 0.9453239403802199], 
             UndirectedEdge[168, 276] -> 
             RGBColor[
              0.3208926338924916, 0.4461337879304579, 0.9418960475542608], 
             UndirectedEdge[148, 271] -> 
             RGBColor[
              0.23446623518977533`, 0.3637692575753508, 0.9366638772811222], 
             UndirectedEdge[131, 170] -> 
             RGBColor[
              0.21349214626363155`, 0.34172416027992825`, 0.9354694339451624],
              UndirectedEdge[141, 261] -> 
             RGBColor[
              0.269292107733182, 0.4003734577063236, 0.9386471592022079], 
             UndirectedEdge[129, 184] -> 
             RGBColor[
              0.19028873719925032`, 0.31733590617215746`, 0.9341480341253134],
              UndirectedEdge[111, 185] -> 
             RGBColor[
              0.5718800780485805, 0.6633170361205862, 0.9594396410911864], 
             UndirectedEdge[234, 239] -> 
             RGBColor[
              0.2158656276199601, 0.3442188396728392, 0.9356046001971543], 
             UndirectedEdge[103, 203] -> 
             RGBColor[
              0.679227364936692, 0.7459924328014227, 0.96969136416035], 
             UndirectedEdge[28, 160] -> 
             RGBColor[
              0.18961722538074013`, 0.31663010467459485`, 0.9341097925206621],
              UndirectedEdge[133, 170] -> 
             RGBColor[
              0.1914328920115927, 0.3185384854235343, 0.9342131920492509], 
             UndirectedEdge[87, 299] -> 
             RGBColor[
              0.8768452825301113, 0.42571428195008987`, 0.27555164113063385`],
              UndirectedEdge[5, 290] -> 
             RGBColor[
              0.9587118125308915, 0.8695626925266455, 0.3088146906826389], 
             UndirectedEdge[183, 253] -> 
             RGBColor[
              0.19229512745236005`, 0.31944474954066526`, 0.9342622950820396],
              UndirectedEdge[176, 245] -> 
             RGBColor[
              0.20971756780007914`, 0.3377568389926374, 0.9352544772856515], 
             UndirectedEdge[29, 190] -> 
             RGBColor[
              0.199834842245044, 0.32736946783330456`, 0.9346916706854744], 
             UndirectedEdge[159, 168] -> 
             RGBColor[
              0.3458261104083336, 0.4723404526223259, 0.943315972156065], 
             UndirectedEdge[202, 299] -> 
             RGBColor[
              0.8506117900174305, 0.3729054904185747, 0.19542866152518146`], 
             UndirectedEdge[65, 115] -> 
             RGBColor[
              0.3645960621661024, 0.4902165167425332, 0.9444527165749532], 
             UndirectedEdge[51, 142] -> 
             RGBColor[
              0.8237226416206042, 0.438239252848624, 0.4448084869772376], 
             UndirectedEdge[134, 187] -> 
             RGBColor[
              0.23476961577043198`, 0.36408812980106076`, 0.9366811543563793],
              UndirectedEdge[85, 239] -> 
             RGBColor[
              0.2348622905163943, 0.36418553683498534`, 0.936686432046062], 
             UndirectedEdge[120, 284] -> 
             RGBColor[
              0.26002401193692654`, 0.39063210139324567`, 0.9381193548575302],
              UndirectedEdge[31, 61] -> 
             RGBColor[
              0.3484538930002764, 0.47332381494877457`, 0.9435307438846312], 
             UndirectedEdge[217, 247] -> 
             RGBColor[
              0.19889732977739935`, 0.3263840827880864, 0.9346382807373675], 
             UndirectedEdge[66, 169] -> 
             RGBColor[
              0.4955403552880472, 0.5995224478502696, 0.9539323726469158], 
             UndirectedEdge[168, 293] -> 
             RGBColor[
              0.650085093471142, 0.5794738875625195, 0.5924017179788976], 
             UndirectedEdge[93, 105] -> 
             RGBColor[
              0.26248514686677915`, 0.39321891024948796`, 0.9382595128508624],
              UndirectedEdge[169, 193] -> 
             RGBColor[
              0.44215135474031986`, 0.5505814803014513, 0.9506292633518225], 
             UndirectedEdge[87, 216] -> 
             RGBColor[
              0.9086918285764461, 0.6536007359987195, 0.30538616585458284`], 
             UndirectedEdge[81, 201] -> 
             RGBColor[
              0.8600643597048547, 0.4301184883358802, 0.203875720489697], 
             UndirectedEdge[63, 244] -> 
             RGBColor[
              0.18619322197801913`, 0.31303126000398057`, 0.9339148005922362],
              UndirectedEdge[32, 150] -> 
             RGBColor[
              0.9475427884309859, 0.8298940012964792, 0.5491295264859543], 
             UndirectedEdge[95, 282] -> 
             RGBColor[
              0.36409426757402563`, 0.48782276310977274`, 0.9444924758077534],
              UndirectedEdge[126, 239] -> 
             RGBColor[
              0.2305322261132995, 0.35963436460539283`, 0.9364398412840619], 
             UndirectedEdge[149, 150] -> 
             RGBColor[
              0.901456610665, 0.644502615181237, 0.23943789960535378`], 
             UndirectedEdge[16, 222] -> 
             RGBColor[
              0.23410797445122994`, 0.3633927028240968, 0.9366434748620613], 
             UndirectedEdge[192, 262] -> 
             RGBColor[
              0.31722856394081744`, 0.4487355619302395, 0.9414511103067129], 
             UndirectedEdge[214, 276] -> 
             RGBColor[
              0.22110211631188992`, 0.34972272130061666`, 0.9359028104814688],
              UndirectedEdge[48, 100] -> 
             RGBColor[
              0.18673636136840888`, 0.31360213394030656`, 0.9339457315770161],
              UndirectedEdge[105, 143] -> 
             RGBColor[
              0.29536739445361543`, 0.4277802373181654, 0.9401321082060067], 
             UndirectedEdge[268, 279] -> 
             RGBColor[
              0.22085812887375872`, 0.34946627503344374`, 0.9358889157578143],
              UndirectedEdge[24, 106] -> 
             RGBColor[
              0.892812310133672, 0.8140725087445938, 0.6221015838690171], 
             UndirectedEdge[33, 222] -> 
             RGBColor[
              0.210965999406103, 0.33906901976570414`, 0.9353255736187255], 
             UndirectedEdge[155, 291] -> 
             RGBColor[
              0.9265943306289632, 0.845047396157727, 0.6262279650717502], 
             UndirectedEdge[99, 233] -> 
             RGBColor[
              0.20053490529032286`, 0.32810527848045334`, 0.9347315382402527],
              UndirectedEdge[237, 269] -> 
             RGBColor[
              0.8744380750181129, 0.4362072994771681, 0.23118026314495393`], 
             UndirectedEdge[85, 135] -> 
             RGBColor[
              0.22261249954375167`, 0.3513102298411313, 0.9359888245721116], 
             UndirectedEdge[126, 248] -> 
             RGBColor[
              0.22272354417989754`, 0.3514269447943572, 0.9359951483998643], 
             UndirectedEdge[188, 261] -> 
             RGBColor[
              0.30030042916823396`, 0.42860875023970424`, 0.9405725470875715],
              UndirectedEdge[37, 177] -> 
             RGBColor[
              0.2592700003340752, 0.38983958739155206`, 0.9380764150122078], 
             UndirectedEdge[160, 180] -> 
             RGBColor[
              0.19532450559808373`, 0.32262881804548893`, 0.9344348136858753],
              UndirectedEdge[23, 194] -> 
             RGBColor[
              0.8376760987270953, 0.8722472965038359, 0.8977776532625734], 
             UndirectedEdge[51, 243] -> 
             RGBColor[
              0.8993571244293498, 0.920787638740557, 0.9200070578349391], 
             UndirectedEdge[108, 208] -> 
             RGBColor[
              0.2150010029643497, 0.34331006433942324`, 0.9355553611021148], 
             UndirectedEdge[179, 251] -> 
             RGBColor[
              0.4041820274938994, 0.5204791332423994, 0.9475743793112779], 
             UndirectedEdge[26, 224] -> 
             RGBColor[
              0.21888166411978893`, 0.3473888852619182, 0.9357763590139934], 
             UndirectedEdge[106, 291] -> 
             RGBColor[
              0.8943677152627585, 0.9186085554583606, 0.9897867851648885], 
             UndirectedEdge[48, 161] -> 
             RGBColor[
              0.19723226696141938`, 0.3246339961974114, 0.9345434578732372], 
             UndirectedEdge[227, 299] -> 
             RGBColor[
              0.8633640950075484, 0.3798620775565069, 0.20395744452515618`], 
             UndirectedEdge[162, 299] -> 
             RGBColor[
              0.8762453581797867, 0.42669348450426003`, 0.3747047266637896], 
             UndirectedEdge[200, 227] -> 
             RGBColor[
              0.6591374011618665, 0.6706282245294286, 0.6126589597072597], 
             UndirectedEdge[202, 293] -> 
             RGBColor[
              0.8776334125818863, 0.5372437306244892, 0.2196066587898482], 
             UndirectedEdge[3, 155] -> 
             RGBColor[
              0.9402661035019293, 0.855471333191099, 0.6109745630706932], 
             UndirectedEdge[39, 234] -> 
             RGBColor[
              0.19793969225016772`, 0.3253775450292399, 0.9345837446968894], 
             UndirectedEdge[144, 176] -> 
             RGBColor[
              0.19591627409858087`, 0.32325080425980146`, 0.9344685140265354],
              UndirectedEdge[140, 162] -> 
             RGBColor[
              0.8753287589904273, 0.41964810147851817`, 0.3738269902449083], 
             UndirectedEdge[123, 257] -> 
             RGBColor[
              0.19133948148967972`, 0.3184403050424346, 0.9342078724582165], 
             UndirectedEdge[121, 286] -> 
             RGBColor[
              0.22317009351070355`, 0.3518962964538972, 0.9360205787236432], 
             UndirectedEdge[176, 230] -> 
             RGBColor[
              0.19313907822011844`, 0.32033179530714856`, 0.9343103568297502],
              UndirectedEdge[39, 64] -> 
             RGBColor[
              0.2185143800083959, 0.3470028463736865, 0.9357554427271977], 
             UndirectedEdge[269, 277] -> 
             RGBColor[
              0.9830880426173179, 0.9543005010685027, 0.41547009014484526`], 
             UndirectedEdge[154, 203] -> 
             RGBColor[
              0.7172113529376909, 0.7776981044453534, 0.9724416173890855], 
             UndirectedEdge[107, 137] -> 
             RGBColor[
              0.33500472849332374`, 0.4602209338581902, 0.9427270090780024], 
             UndirectedEdge[192, 218] -> 
             RGBColor[
              0.6489034320102649, 0.7179182155893853, 0.9413556495465901], 
             UndirectedEdge[247, 270] -> 
             RGBColor[
              0.20529778048290723`, 0.33311136229158844`, 0.935002776936428], 
             UndirectedEdge[28, 240] -> 
             RGBColor[
              0.18200025991928498`, 0.3086241910311017, 0.9336760176059227], 
             UndirectedEdge[31, 194] -> 
             RGBColor[
              0.552827044743554, 0.6462661114029045, 0.958649445840947], 
             UndirectedEdge[58, 187] -> 
             RGBColor[
              0.20794054512620663`, 0.3358890754926524, 0.9351532784732439], 
             UndirectedEdge[8, 121] -> 
             RGBColor[
              0.21495883648631775`, 0.3432657446975026, 0.9355529597835706], 
             UndirectedEdge[62, 186] -> 
             RGBColor[
              0.19739650616034748`, 0.3248066220088515, 0.934552811052646], 
             UndirectedEdge[271, 289] -> 
             RGBColor[
              0.23303990394891333`, 0.36227009300658086`, 0.9365826498270231],
              UndirectedEdge[236, 294] -> 
             RGBColor[
              0.38374017735760657`, 0.49740352912178454`, 0.9465549709165739],
              UndirectedEdge[115, 211] -> 
             RGBColor[
              0.3112307319414529, 0.4404795631489132, 0.9411810111605179], 
             UndirectedEdge[43, 284] -> 
             RGBColor[
              0.23327215251581435`, 0.3625142009758035, 0.9365958760393271], 
             UndirectedEdge[87, 181] -> 
             RGBColor[
              0.9897210070316473, 0.9765905802662477, 0.448420390956374], 
             UndirectedEdge[77, 205] -> 
             RGBColor[
              0.3930712028278346, 0.5148802523815419, 0.9462671273583405], 
             UndirectedEdge[132, 267] -> 
             RGBColor[
              0.19655119281637518`, 0.32391814408837505`, 0.9345046717082358],
              UndirectedEdge[108, 280] -> 
             RGBColor[
              0.2513491898337207, 0.3815143133472875, 0.9376253365720018], 
             UndirectedEdge[40, 97] -> 
             RGBColor[
              0.5690459020341019, 0.6601769695084484, 0.9597409246828227], 
             UndirectedEdge[35, 262] -> 
             RGBColor[
              0.25511664496274467`, 0.3854741475583434, 0.9378398875681493], 
             UndirectedEdge[201, 216] -> 
             RGBColor[
              0.8523973008738454, 0.3953041648713514, 0.19747813866429334`], 
             UndirectedEdge[244, 279] -> 
             RGBColor[
              0.21308524932289044`, 0.3412964857964532, 0.9354462617663373], 
             UndirectedEdge[143, 163] -> 
             RGBColor[
              0.4640224729127619, 0.5716064552084593, 0.95205347173178], 
             UndirectedEdge[102, 165] -> 
             RGBColor[
              0.20499479718794766`, 0.3327929076383356, 0.9349855224860035], 
             UndirectedEdge[7, 282] -> 
             RGBColor[
              0.6894759164963487, 0.7547973275205713, 0.9692952652700408], 
             UndirectedEdge[10, 122] -> 
             RGBColor[
              0.1877216481680741, 0.3146377328375459, 0.9340018422026558], 
             UndirectedEdge[113, 193] -> 
             RGBColor[
              0.2735981771019762, 0.40489940963349313`, 0.9388923834825018], 
             UndirectedEdge[22, 100] -> 
             RGBColor[
              0.1846021361595517, 0.3113589279281038, 0.9338241906086748], 
             UndirectedEdge[116, 254] -> 
             RGBColor[
              0.30306682721859113`, 0.43494494762898417`, 0.9406045538059649],
              UndirectedEdge[174, 298] -> 
             RGBColor[
              0.24667128016472487`, 0.3765975336885693, 0.9373589365366997], 
             UndirectedEdge[159, 271] -> 
             RGBColor[
              0.2569380089981777, 0.38738851664073326`, 0.9379436115555007], 
             UndirectedEdge[11, 101] -> 
             RGBColor[
              0.589571415450858, 0.6776035417182125, 0.9608844110153827], 
             UndirectedEdge[148, 225] -> 
             RGBColor[
              0.23694694145511846`, 0.36637663714608804`, 0.9368051498330575],
              UndirectedEdge[239, 248] -> 
             RGBColor[
              0.22976740900447992`, 0.35883049333181793`, 0.9363962860811601],
              UndirectedEdge[22, 119] -> 
             RGBColor[
              0.18469650892406414`, 0.31145811968718523`, 0.933829564998002], 
             UndirectedEdge[38, 247] -> 
             RGBColor[
              0.19193794866685385`, 0.31906933199065524`, 0.9342419542786038],
              UndirectedEdge[157, 222] -> 
             RGBColor[
              0.20198183109515816`, 0.32962608924173, 0.9348139385243031], 
             UndirectedEdge[42, 203] -> 
             RGBColor[
              0.8707781869031039, 0.5109108883536715, 0.45286742761557874`], 
             UndirectedEdge[155, 241] -> 
             RGBColor[
              0.9562190222247212, 0.8670479840915544, 0.569594959834627], 
             UndirectedEdge[103, 154] -> 
             RGBColor[
              0.45931362601150366`, 0.5710619602704519, 0.9508179830889629], 
             UndirectedEdge[88, 107] -> 
             RGBColor[
              0.3156668760979841, 0.43989562490003076`, 0.9416257469918767], 
             UndirectedEdge[58, 176] -> 
             RGBColor[
              0.19266677740688082`, 0.31983537720683475`, 0.9342834599971428],
              UndirectedEdge[48, 119] -> 
             RGBColor[
              0.1868307341329213, 0.31370132569938797`, 0.933951105966343], 
             UndirectedEdge[206, 219] -> 
             RGBColor[
              0.20337837440800324`, 0.33109394480949034`, 0.9348934695999689],
              UndirectedEdge[1, 125] -> 
             RGBColor[
              0.8241937608739676, 0.18696942461673885`, 0.17080127877684323`],
              UndirectedEdge[191, 278] -> 
             RGBColor[
              0.21400334724237668`, 0.34226146492060344`, 0.9354985460846478],
              UndirectedEdge[90, 118] -> 
             RGBColor[
              0.20219853738896398`, 0.32985386129649247`, 0.9348262796271471],
              UndirectedEdge[101, 283] -> 
             RGBColor[
              0.4765743997943146, 0.5815921216615045, 0.9531053393092228], 
             UndirectedEdge[5, 226] -> 
             RGBColor[
              0.978634912205556, 0.9512330589473125, 0.6096542687532867], 
             UndirectedEdge[3, 241] -> 
             RGBColor[
              0.9701712881509421, 0.9769533662972854, 0.9210009349471945], 
             UndirectedEdge[194, 241] -> 
             RGBColor[
              0.8360648746712487, 0.8715810139501738, 0.9244798055821426], 
             UndirectedEdge[139, 235] -> 
             RGBColor[
              0.42460849977243, 0.5421962738843169, 0.9482766560323135], 
             UndirectedEdge[40, 94] -> 
             RGBColor[
              0.7430612286953848, 0.7992043464221197, 0.9750250570405241], 
             UndirectedEdge[161, 177] -> 
             RGBColor[
              0.24681318446187503`, 0.3767466841021262, 0.9373670177764938], 
             UndirectedEdge[34, 295] -> 
             RGBColor[
              0.19030787854135572`, 0.3173560249363414, 0.9341491241964293], 
             UndirectedEdge[1, 281] -> 
             RGBColor[
              0.8719494618139193, 0.4242799404293628, 0.41747045975413577`], 
             UndirectedEdge[191, 295] -> 
             RGBColor[
              0.21214976125282442`, 0.34031322852144436`, 0.9353929871046776],
              UndirectedEdge[144, 297] -> 
             RGBColor[
              0.19481653012173772`, 0.32209490361234383`, 0.9344058852339796],
              UndirectedEdge[141, 294] -> 
             RGBColor[
              0.41494859536709305`, 0.5302055551777425, 0.9483322441534972], 
             UndirectedEdge[80, 201] -> 
             RGBColor[
              0.8898455310710746, 0.5465218886817487, 0.2514410406983216], 
             UndirectedEdge[113, 115] -> 
             RGBColor[
              0.3096806718260522, 0.43885035168813935`, 0.9410927375300542], 
             UndirectedEdge[129, 253] -> 
             RGBColor[
              0.19046881652676248`, 0.3175251809630616, 0.9341582893766117], 
             UndirectedEdge[37, 108] -> 
             RGBColor[
              0.23362687386015235`, 0.362887035599335, 0.936616076895124], 
             UndirectedEdge[265, 276] -> 
             RGBColor[
              0.23204484364859856`, 0.36122422154048306`, 0.93652598261498], 
             UndirectedEdge[59, 194] -> 
             RGBColor[
              0.8355066141794747, 0.8713501588901851, 0.9337316266626792], 
             UndirectedEdge[103, 225] -> 
             RGBColor[
              0.3244631340928782, 0.4479525778867464, 0.9421701966492211], 
             UndirectedEdge[46, 265] -> 
             RGBColor[
              0.21371228475052867`, 0.3419555397872433, 0.9354819705063254], 
             UndirectedEdge[51, 149] -> 
             RGBColor[
              0.8534002738604769, 0.7354497327448786, 0.6081721446101185], 
             UndirectedEdge[52, 124] -> 
             RGBColor[
              0.1923287617954415, 0.3194801013677844, 0.9342642105081206], 
             UndirectedEdge[82, 258] -> 
             RGBColor[
              0.47680058453134755`, 0.5830547562597531, 0.9528035659599465], 
             UndirectedEdge[45, 132] -> 
             RGBColor[
              0.24841553022607393`, 0.3784308510948885, 0.9374582689973068], 
             UndirectedEdge[74, 287] -> 
             RGBColor[
              0.2244511741859948, 0.35324279346883447`, 0.936093534372912], 
             UndirectedEdge[128, 269] -> 
             RGBColor[
              0.8876818023454497, 0.5380043911533983, 0.24386247139026226`], 
             UndirectedEdge[14, 249] -> 
             RGBColor[
              0.19382527220510481`, 0.3210530286925808, 0.9343494345620621], 
             UndirectedEdge[101, 198] -> 
             RGBColor[
              0.8059595419277743, 0.8487647451023745, 0.9551527712864303], 
             UndirectedEdge[164, 297] -> 
             RGBColor[
              0.18697714573381324`, 0.31385521357495705`, 0.9339594438904173],
              UndirectedEdge[68, 235] -> 
             RGBColor[
              0.6426752269533634, 0.7164421222894727, 0.967683202312762], 
             UndirectedEdge[108, 177] -> 
             RGBColor[
              0.2663285931328081, 0.3972586159636525, 0.9384783914298436], 
             UndirectedEdge[62, 276] -> 
             RGBColor[
              0.22152543341226616`, 0.3501676544129665, 0.9359269177640938], 
             UndirectedEdge[13, 107] -> 
             RGBColor[
              0.3708820169269006, 0.49566109481506393`, 0.9448532520538597], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.21391225518849333`, 0.3421657213964022, 0.9354933585269378], 
             UndirectedEdge[62, 135] -> 
             RGBColor[
              0.20737676424851148`, 0.33529650604442257`, 0.9351211719862982],
              UndirectedEdge[18, 35] -> 
             RGBColor[
              0.20318410319091706`, 0.3308897534428262, 0.9348824061415544], 
             UndirectedEdge[42, 202] -> 
             RGBColor[
              0.8472600681601863, 0.3557049288144153, 0.19255432478662504`], 
             UndirectedEdge[121, 255] -> 
             RGBColor[
              0.295733658786952, 0.42287002848225363`, 0.9403468487457121], 
             UndirectedEdge[128, 281] -> 
             RGBColor[
              0.8894473613175273, 0.5587764636425476, 0.4342264680798416], 
             UndirectedEdge[82, 181] -> 
             RGBColor[
              0.7998668067519439, 0.8312427160957487, 0.681983215284067], 
             UndirectedEdge[136, 204] -> 
             RGBColor[
              0.4381119186941594, 0.553069802846105, 0.9493643283826801], 
             UndirectedEdge[118, 166] -> 
             RGBColor[
              0.18740769372755933`, 0.31430774681470364`, 0.9339839629617225],
              UndirectedEdge[39, 263] -> 
             RGBColor[
              0.2058067463664483, 0.333646317705491, 0.935031761790548], 
             UndirectedEdge[52, 84] -> 
             RGBColor[
              0.1931004885069918, 0.32029123507192336`, 0.9343081592026761], 
             UndirectedEdge[129, 165] -> 
             RGBColor[
              0.20344097121398075`, 0.33115973802143944`, 0.9348970343954657],
              UndirectedEdge[141, 236] -> 
             RGBColor[
              0.2626393533607303, 0.39338099105188706`, 0.9382682946825648], 
             UndirectedEdge[97, 178] -> 
             RGBColor[
              0.353934746876465, 0.4763839115166376, 0.9439417536383794], 
             UndirectedEdge[115, 227] -> 
             RGBColor[
              0.6522166119287909, 0.6646337847447196, 0.6122179731371418], 
             UndirectedEdge[256, 281] -> 
             RGBColor[
              0.8714392611368911, 0.42035831445436117`, 0.41698189100962424`],
              UndirectedEdge[221, 297] -> 
             RGBColor[
              0.18909437890281156`, 0.31608055987591055`, 0.9340800171872259],
              UndirectedEdge[224, 262] -> 
             RGBColor[
              0.2562537795699573, 0.3866693481290222, 0.9379046457017901], 
             UndirectedEdge[73, 119] -> 
             RGBColor[
              0.18176019735719462`, 0.3083718700574992, 0.9336623463981524], 
             UndirectedEdge[3, 227] -> 
             RGBColor[
              0.9534614284413586, 0.9077863994945625, 0.6215918312510428], 
             UndirectedEdge[45, 188] -> 
             RGBColor[
              0.32789958178650086`, 0.45761720952884744`, 0.9421442779998944],
              UndirectedEdge[260, 300] -> 
             RGBColor[
              0.24190674150061214`, 0.37158970146338766`, 0.9370876031082818],
              UndirectedEdge[23, 291] -> 
             RGBColor[
              0.9581107393338224, 0.9671957118175754, 0.9095521846286824], 
             UndirectedEdge[142, 149] -> 
             RGBColor[
              0.8517916638064809, 0.3601987767340248, 0.1957058266051599], 
             UndirectedEdge[81, 97] -> 
             RGBColor[
              0.6691615275279388, 0.5770839186847934, 0.5896504800872672], 
             UndirectedEdge[181, 201] -> 
             RGBColor[
              0.8923407162696778, 0.5549387342539829, 0.2611343640187083], 
             UndirectedEdge[56, 57] -> 
             RGBColor[
              0.18951617750640207`, 0.3165238969518603, 0.9341040379937053], 
             UndirectedEdge[197, 243] -> 
             RGBColor[
              0.9868796101505515, 0.9888423958656835, 0.8671023444932484], 
             UndirectedEdge[65, 200] -> 
             RGBColor[
              0.37151685139917806`, 0.49621095652724223`, 0.9448937031450712],
              UndirectedEdge[8, 173] -> 
             RGBColor[
              0.2028775855537629, 0.3305675839718365, 0.9348649504155706], 
             UndirectedEdge[53, 273] -> 
             RGBColor[
              0.2274037724911021, 0.35634616149304726`, 0.9362616804784101], 
             UndirectedEdge[26, 253] -> 
             RGBColor[
              0.21047277090696587`, 0.3385506053406179, 0.9352974849853658], 
             UndirectedEdge[114, 206] -> 
             RGBColor[
              0.2307773334017795, 0.35989198790628496`, 0.936453799781537], 
             UndirectedEdge[9, 45] -> 
             RGBColor[
              0.24944742731977937`, 0.3795154403664275, 0.9375170340102383], 
             UndirectedEdge[47, 190] -> 
             RGBColor[
              0.1942570496898653, 0.32150685420533776`, 0.9343740236510617], 
             UndirectedEdge[191, 282] -> 
             RGBColor[
              0.3340044293562811, 0.4561964353369906, 0.9427789040351794], 
             UndirectedEdge[59, 155] -> 
             RGBColor[
              0.9556607617329471, 0.8668171290315656, 0.5788467809151635], 
             UndirectedEdge[214, 265] -> 
             RGBColor[
              0.21177311264038245`, 0.33991734694886655`, 0.9353715375234006],
              UndirectedEdge[167, 282] -> 
             RGBColor[
              0.674157084988882, 0.6138860835498305, 0.5969373306942671], 
             UndirectedEdge[28, 221] -> 
             RGBColor[
              0.18483282648833058`, 0.31160139809026205`, 0.9338373280816231],
              UndirectedEdge[136, 197] -> 
             RGBColor[
              0.689478603616865, 0.751552751257122, 0.9111273992783655], 
             UndirectedEdge[121, 234] -> 
             RGBColor[
              0.20980230497718771`, 0.3378459031384259, 0.9352593029425303], 
             UndirectedEdge[141, 146] -> 
             RGBColor[
              0.24693839801171524`, 0.3768782914820059, 0.9373741485029203], 
             UndirectedEdge[32, 167] -> 
             RGBColor[
              0.947679092916505, 0.830434403160785, 0.5492392002744804], 
             UndirectedEdge[101, 136] -> 
             RGBColor[
              0.5199717589850226, 0.6194511898467974, 0.9558606779112371], 
             UndirectedEdge[91, 274] -> 
             RGBColor[
              0.4766026768727841, 0.5859665496480654, 0.9519390550580074], 
             UndirectedEdge[84, 295] -> 
             RGBColor[
              0.19219536521772562`, 0.31933989310677346`, 0.9342566137703623],
              UndirectedEdge[73, 122] -> 
             RGBColor[
              0.18385458485627515`, 0.31057320411086997`, 0.9337816186678564],
              UndirectedEdge[157, 248] -> 
             RGBColor[
              0.20224840910221648`, 0.3299062796291701, 0.9348291197474383], 
             UndirectedEdge[125, 167] -> 
             RGBColor[
              0.859356989051198, 0.4049161457343329, 0.20241604569242247`], 
             UndirectedEdge[20, 208] -> 
             RGBColor[
              0.20416035452872197`, 0.331915855496769, 0.9349380022110079], 
             UndirectedEdge[77, 103] -> 
             RGBColor[
              0.41755616548084906`, 0.5360878963815774, 0.9478272875273883], 
             UndirectedEdge[46, 276] -> 
             RGBColor[
              0.22304128842203616`, 0.35176091413899346`, 0.9360132434643936],
              UndirectedEdge[3, 291] -> 
             RGBColor[
              0.940546596555184, 0.9549527783634579, 0.9776339401843177], 
             UndirectedEdge[79, 297] -> 
             RGBColor[
              0.1875669958551452, 0.3144751834511347, 0.9339930349822221], 
             UndirectedEdge[18, 262] -> 
             RGBColor[
              0.25190729178629806`, 0.38210091388515394`, 0.9376571196525632],
              UndirectedEdge[127, 225] -> 
             RGBColor[
              0.28821593818422175`, 0.41655707862770686`, 0.9398605573780583],
              UndirectedEdge[109, 292] -> 
             RGBColor[
              0.8832633694480486, 0.907223500639492, 0.873440789605417], 
             UndirectedEdge[267, 287] -> 
             RGBColor[
              0.2196035170740144, 0.34814759848492993`, 0.9358174674718507], 
             UndirectedEdge[218, 262] -> 
             RGBColor[
              0.6355147016275733, 0.7058679616598169, 0.9405191403190352], 
             UndirectedEdge[207, 225] -> 
             RGBColor[
              0.20644219198451136`, 0.33431421133965444`, 0.9350679494784392],
              UndirectedEdge[203, 299] -> 
             RGBColor[
              0.8581709631436525, 0.41400624201784997`, 0.4407947359057055], 
             UndirectedEdge[142, 163] -> 
             RGBColor[
              0.7603405238297619, 0.3885080681094508, 0.43863923535829075`], 
             UndirectedEdge[2, 54] -> 
             RGBColor[
              0.22131402237840694`, 0.34994544801214666`, 0.9359148782184701],
              UndirectedEdge[90, 195] -> 
             RGBColor[
              0.19970007804544365`, 0.3272278221149808, 0.934683996063673], 
             UndirectedEdge[88, 93] -> 
             RGBColor[
              0.23199426054362918`, 0.36117105549000617`, 0.9365231019819831],
              UndirectedEdge[77, 82] -> 
             RGBColor[
              0.5136111712070213, 0.6149382362843397, 0.9551491039925967], 
             UndirectedEdge[167, 168] -> 
             RGBColor[
              0.6540467218133117, 0.5964674977433942, 0.5956559161356156], 
             UndirectedEdge[18, 26] -> 
             RGBColor[
              0.21453517633612967`, 0.3428204510180499, 0.9355288329647664], 
             UndirectedEdge[129, 224] -> 
             RGBColor[
              0.19887770973958555`, 0.32636346088436186`, 0.9346371634052393],
              UndirectedEdge[38, 289] -> 
             RGBColor[
              0.21478203632197956`, 0.34307991651500525`, 0.935542891275764], 
             UndirectedEdge[31, 241] -> 
             RGBColor[
              0.7028863769460394, 0.7632151146504713, 0.9137909719699326], 
             UndirectedEdge[5, 197] -> 
             RGBColor[
              0.9786771999205136, 0.9512505460041922, 0.6089534518793391], 
             UndirectedEdge[59, 241] -> 
             RGBColor[
              0.9855659463819599, 0.9882991621377519, 0.8888731527916648], 
             UndirectedEdge[155, 226] -> 
             RGBColor[
              0.9562854870849291, 0.8670754690193194, 0.5684934650954372], 
             UndirectedEdge[15, 186] -> 
             RGBColor[
              0.22574603195372214`, 0.35460377108144014`, 0.9361672746072136],
              UndirectedEdge[198, 256] -> 
             RGBColor[
              0.866815756563354, 0.4169101123137112, 0.4248082782495014], 
             UndirectedEdge[72, 291] -> 
             RGBColor[
              0.8619019121087841, 0.4662467231049401, 0.44816350088512813`], 
             UndirectedEdge[230, 297] -> 
             RGBColor[
              0.19203933424327527`, 0.319175894659691, 0.9342477280371944], 
             UndirectedEdge[138, 231] -> 
             RGBColor[
              0.23123426787294182`, 0.3603722550067954, 0.9364798215236958], 
             UndirectedEdge[54, 165] -> 
             RGBColor[
              0.2309155676527057, 0.3600372808685661, 0.936461672017628], 
             UndirectedEdge[103, 167] -> 
             RGBColor[
              0.6645058305861254, 0.6055266520723135, 0.5963223612979925], 
             UndirectedEdge[78, 131] -> 
             RGBColor[
              0.21176961520445978`, 0.33991367092196156`, 0.9353713383495988],
              UndirectedEdge[16, 239] -> 
             RGBColor[
              0.2421832343916902, 0.3718803130225725, 0.9371033489693941], 
             UndirectedEdge[12, 87] -> 
             RGBColor[
              0.7113840896935575, 0.7671448961592477, 0.7220908533867955], 
             UndirectedEdge[125, 281] -> 
             RGBColor[
              0.8829501729358756, 0.5088362266550703, 0.4280047531480473], 
             UndirectedEdge[148, 205] -> 
             RGBColor[
              0.3093284827197305, 0.43657270388582725`, 0.9411425228750159], 
             UndirectedEdge[103, 269] -> 
             RGBColor[
              0.6972472679550255, 0.7302486647196956, 0.6491594274470608], 
             UndirectedEdge[40, 169] -> 
             RGBColor[
              0.6469863029423364, 0.7235735932337524, 0.9658432196124291], 
             UndirectedEdge[38, 53] -> 
             RGBColor[
              0.2009984379794762, 0.32859248072642344`, 0.9347579357411648], 
             UndirectedEdge[118, 285] -> 
             RGBColor[
              0.19420033164892994`, 0.32144723994818314`, 0.9343707936425373],
              UndirectedEdge[74, 267] -> 
             RGBColor[
              0.2010537316252639, 0.328650597853966, 0.9347610846324927], 
             UndirectedEdge[3, 200] -> 
             RGBColor[
              0.659894342148658, 0.7282185404316961, 0.9534476666394777], 
             UndirectedEdge[124, 273] -> 
             RGBColor[
              0.2124273089085979, 0.3406049487052001, 0.9354087930330789], 
             UndirectedEdge[131, 182] -> 
             RGBColor[
              0.24187571808972635`, 0.3715570938915489, 0.9370858363709268], 
             UndirectedEdge[62, 207] -> 
             RGBColor[
              0.19348238664909873`, 0.3206926342330184, 0.9343299077369014], 
             UndirectedEdge[75, 262] -> 
             RGBColor[
              0.318384602518598, 0.4497368644421247, 0.9415247720626443], 
             UndirectedEdge[197, 283] -> 
             RGBColor[
              0.646081244426157, 0.713693683071829, 0.9083720606763512], 
             UndirectedEdge[246, 278] -> 
             RGBColor[
              0.1925398971260588, 0.3197020179870163, 0.9342762343528525], 
             UndirectedEdge[225, 265] -> 
             RGBColor[
              0.22515623507617133`, 0.35398385716785236`, 0.9361336865475633],
              UndirectedEdge[101, 204] -> 
             RGBColor[
              0.5654681824695174, 0.6580354513456885, 0.9589869162220399], 
             UndirectedEdge[87, 140] -> 
             RGBColor[
              0.8759286833407519, 0.418668898924348, 0.2746739047117526], 
             UndirectedEdge[57, 247] -> 
             RGBColor[
              0.18871603896391997`, 0.3156829006119979, 0.9340584712874099], 
             UndirectedEdge[40, 66] -> 
             RGBColor[
              0.5377876957046065, 0.6331026822689709, 0.9577491794160538], 
             UndirectedEdge[167, 293] -> 
             RGBColor[
              0.9037203948195764, 0.6547034053372311, 0.24132279457904], 
             UndirectedEdge[42, 140] -> 
             RGBColor[
              0.8308428229488108, 0.23807702936156347`, 0.1771684281287546], 
             UndirectedEdge[107, 150] -> 
             RGBColor[
              0.657942354371067, 0.5994193570949246, 0.595803153810185], 
             UndirectedEdge[91, 143] -> 
             RGBColor[
              0.39852667636969663`, 0.5184340170227889, 0.9468974027089019], 
             UndirectedEdge[91, 142] -> 
             RGBColor[
              0.7166766594677184, 0.35305977598567057`, 0.4352018560097054], 
             UndirectedEdge[44, 283] -> 
             RGBColor[
              0.3110200455084933, 0.44354120705361005`, 0.9410488029197814], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.19626308316666907`, 0.323615322579327, 0.9344882642899051], 
             UndirectedEdge[199, 233] -> 
             RGBColor[
              0.20189518711453486`, 0.32953502092454917`, 0.9348090042777849],
              UndirectedEdge[249, 286] -> 
             RGBColor[
              0.2141737173623244, 0.342440534718758, 0.9355082484109388], 
             UndirectedEdge[48, 266] -> 
             RGBColor[
              0.19547981769013628`, 0.32279206090159157`, 0.934443658479754], 
             UndirectedEdge[113, 169] -> 
             RGBColor[
              0.4361857848874334, 0.5443112881470928, 0.9502895329739705], 
             UndirectedEdge[18, 33] -> 
             RGBColor[
              0.20024058888485757`, 0.32779593327757145`, 0.9347147773563635],
              UndirectedEdge[269, 293] -> 
             RGBColor[
              0.9364618321884765, 0.7794254179846133, 0.2941598607281082], 
             UndirectedEdge[189, 257] -> 
             RGBColor[
              0.1999558217805158, 0.327496624995631, 0.9346985602910465], 
             UndirectedEdge[11, 197] -> 
             RGBColor[
              0.7590782600827003, 0.809705103128537, 0.9161511323825111], 
             UndirectedEdge[221, 296] -> 
             RGBColor[
              0.18670137270172213`, 0.31356535863320917`, 0.9339437390242094],
              UndirectedEdge[126, 157] -> 
             RGBColor[
              0.20301322621103607`, 0.33071015090274497`, 0.93487267495034], 
             UndirectedEdge[24, 87] -> 
             RGBColor[
              0.9584560317231505, 0.8616047223377981, 0.3765513268644449], 
             UndirectedEdge[53, 137] -> 
             RGBColor[
              0.2387057780017381, 0.36822528587326325`, 0.936905312972422], 
             UndirectedEdge[27, 140] -> 
             RGBColor[
              0.8681598345506768, 0.3927281505486404, 0.22192545531754573`], 
             UndirectedEdge[115, 200] -> 
             RGBColor[
              0.35864952563609026`, 0.485065925681853, 0.9440738085255767], 
             UndirectedEdge[1, 5] -> 
             RGBColor[
              0.8694664994809802, 0.4010878979497081, 0.22431948647786654`], 
             UndirectedEdge[40, 42] -> 
             RGBColor[
              0.7881477040684427, 0.44575263857904807`, 0.445649103589277], 
             UndirectedEdge[82, 167] -> 
             RGBColor[
              0.7605608363122977, 0.684376991975076, 0.6036441777632009], 
             UndirectedEdge[52, 57] -> 
             RGBColor[
              0.18920436008623348`, 0.3161961570728968, 0.9340862804529193], 
             UndirectedEdge[27, 203] -> 
             RGBColor[
              0.9534832977574548, 0.9312795143111227, 0.6643276822065549], 
             UndirectedEdge[251, 270] -> 
             RGBColor[
              0.24922321837913736`, 0.37927978255414485`, 0.9375042656427561],
              UndirectedEdge[200, 264] -> 
             RGBColor[
              0.3308901333922204, 0.45986309204908005`, 0.9423474428513454], 
             UndirectedEdge[84, 271] -> 
             RGBColor[
              0.20505156873545605`, 0.33285257813429087`, 0.9349887555416483],
              UndirectedEdge[80, 145] -> 
             RGBColor[
              0.9218561356347152, 0.9176464031707863, 0.6795757972164687], 
             UndirectedEdge[199, 259] -> 
             RGBColor[
              0.19177802866162308`, 0.31890124592564373`, 0.9342328470708863],
              UndirectedEdge[273, 274] -> 
             RGBColor[
              0.3509883555182567, 0.4717110997619036, 0.9438949792783465], 
             UndirectedEdge[281, 294] -> 
             RGBColor[
              0.7572554970898742, 0.8088426757639791, 0.9389810177450694], 
             UndirectedEdge[18, 183] -> 
             RGBColor[
              0.19635753288152386`, 0.32371459521809726`, 0.9344936430614402],
              UndirectedEdge[77, 269] -> 
             RGBColor[
              0.6934737954253698, 0.7269802724747518, 0.6489189851142219], 
             UndirectedEdge[134, 144] -> 
             RGBColor[
              0.22121948408189393`, 0.34984608226843733`, 0.9359094944023405],
              UndirectedEdge[200, 210] -> 
             RGBColor[
              0.4186246829308158, 0.5365148469090834, 0.9480331221442837], 
             UndirectedEdge[87, 151] -> 
             RGBColor[
              0.7954880540997038, 0.8360677360525939, 0.7285340376363743], 
             UndirectedEdge[109, 290] -> 
             RGBColor[
              0.9696110495252712, 0.9082697495604787, 0.5222701846474617], 
             UndirectedEdge[247, 278] -> 
             RGBColor[
              0.19919319876560948`, 0.3266950598538726, 0.9346551300385472], 
             UndirectedEdge[156, 205] -> 
             RGBColor[
              0.38342561820827703`, 0.5065257317852604, 0.945652519235638], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.18357179140558838`, 0.31027597026405784`, 0.9337655139991952],
              UndirectedEdge[64, 121] -> 
             RGBColor[
              0.2303769927354159, 0.3594712044828725, 0.9364310009728385], 
             UndirectedEdge[106, 264] -> 
             RGBColor[
              0.579035279379287, 0.6606770441091168, 0.9634331593756991], 
             UndirectedEdge[91, 107] -> 
             RGBColor[
              0.44931704433721525`, 0.562597259364136, 0.9501274523636514], 
             UndirectedEdge[7, 299] -> 
             RGBColor[
              0.8585691612482524, 0.41430321751227117`, 0.4401206903813164], 
             UndirectedEdge[160, 221] -> 
             RGBColor[
              0.19098000658392586`, 0.31806247412446187`, 0.9341874008941293],
              UndirectedEdge[8, 234] -> 
             RGBColor[
              0.19931169581116837`, 0.32681960776190155`, 0.934661878269991], 
             UndirectedEdge[49, 174] -> 
             RGBColor[
              0.22141328802375174`, 0.3500497824992095, 0.9359205312501221], 
             UndirectedEdge[79, 245] -> 
             RGBColor[
              0.20419166956427437`, 0.3319487695846225, 0.9349397855559562], 
             UndirectedEdge[13, 147] -> 
             RGBColor[
              0.27334324637888757`, 0.4023623173416999, 0.9389609500302152], 
             UndirectedEdge[1, 197] -> 
             RGBColor[
              0.8745761742166813, 0.4260008413916001, 0.4023616575482095], 
             UndirectedEdge[129, 175] -> 
             RGBColor[
              0.18584814501363772`, 0.3126685622352725, 0.9338951489696101], 
             UndirectedEdge[116, 283] -> 
             RGBColor[
              0.29658629715284524`, 0.4290613813379507, 0.9402015229115228], 
             UndirectedEdge[62, 265] -> 
             RGBColor[
              0.2121964297407587, 0.3403622800612163, 0.9353956448060256], 
             UndirectedEdge[31, 291] -> 
             RGBColor[
              0.6732616853502813, 0.7412145267166439, 0.970423977207056], 
             UndirectedEdge[92, 277] -> 
             RGBColor[
              0.8853735220807035, 0.49151915194709656`, 0.27879642661699433`],
              UndirectedEdge[124, 289] -> 
             RGBColor[
              0.2146845283282537, 0.3429774294312355, 0.9355373383397714], 
             UndirectedEdge[80, 277] -> 
             RGBColor[
              0.9859097978901593, 0.963818944183442, 0.4264320765360633], 
             UndirectedEdge[119, 244] -> 
             RGBColor[
              0.18517767786647377`, 0.3119638587535308, 0.9338569668574466], 
             UndirectedEdge[252, 268] -> 
             RGBColor[
              0.22149590633125682`, 0.35013661957870057`, 0.9359252362405117],
              UndirectedEdge[3, 194] -> 
             RGBColor[
              0.8201119559484569, 0.8600043630497185, 0.9658594088182089], 
             UndirectedEdge[1, 237] -> 
             RGBColor[
              0.820820491401125, 0.16104099727236243`, 0.16757103212008623`], 
             UndirectedEdge[149, 281] -> 
             RGBColor[
              0.9369826909775356, 0.800923138426649, 0.5779306345773171], 
             UndirectedEdge[29, 209] -> 
             RGBColor[
              0.1878554243304431, 0.3147783400660943, 0.9340094605571987], 
             UndirectedEdge[123, 287] -> 
             RGBColor[
              0.22080206667647367`, 0.3494073501095485, 0.9358857230986155], 
             UndirectedEdge[17, 81] -> 
             RGBColor[
              0.7965640174649642, 0.6796969932787943, 0.60028868050202], 
             UndirectedEdge[176, 187] -> 
             RGBColor[
              0.20946640578711895`, 0.33749285179242483`, 0.9352401739805742],
              UndirectedEdge[246, 270] -> 
             RGBColor[
              0.19864447884335656`, 0.3261183204247322, 0.9346238812507333], 
             UndirectedEdge[45, 131] -> 
             RGBColor[
              0.2646712879230951, 0.39551668310902466`, 0.9383840103499137], 
             UndirectedEdge[4, 158] -> 
             RGBColor[
              0.2067416614051505, 0.33462897268820413`, 0.9350850038189193], 
             UndirectedEdge[169, 264] -> 
             RGBColor[
              0.450474457220526, 0.5593295887233245, 0.9511032517251437], 
             UndirectedEdge[42, 181] -> 
             RGBColor[
              0.8871678109624904, 0.5151775172813806, 0.25618078405458466`], 
             UndirectedEdge[8, 263] -> 
             RGBColor[
              0.20717874992744892`, 0.3350883804381527, 0.9351098953636496], 
             UndirectedEdge[145, 205] -> 
             RGBColor[
              0.6186317877643385, 0.696027939962637, 0.9659619530693695], 
             UndirectedEdge[167, 269] -> 
             RGBColor[
              0.9404234605306463, 0.796419028165488, 0.2974140588848261], 
             UndirectedEdge[187, 288] -> 
             RGBColor[
              0.2168027551458141, 0.3452038201198287, 0.9356579682233956], 
             UndirectedEdge[47, 131] -> 
             RGBColor[
              0.20675371716772, 0.33464164405904423`, 0.9350856903767627], 
             UndirectedEdge[43, 97] -> 
             RGBColor[
              0.33722237523593046`, 0.45881814929687276`, 0.9429900087971892],
              UndirectedEdge[104, 114] -> 
             RGBColor[
              0.28710993911342014`, 0.4166656473064825, 0.939751033226302], 
             UndirectedEdge[26, 129] -> 
             RGBColor[
              0.20909164827758553`, 0.33709895788890676`, 0.9352188320948104],
              UndirectedEdge[28, 79] -> 
             RGBColor[
              0.1833054434406642, 0.3099960216654862, 0.9337503458766192], 
             UndirectedEdge[53, 247] -> 
             RGBColor[
              0.2068169042556322, 0.33470805769473266`, 0.9350892887879424], 
             UndirectedEdge[150, 281] -> 
             RGBColor[
              0.9429354945032435, 0.8270367350349062, 0.582850380130669], 
             UndirectedEdge[76, 248] -> 
             RGBColor[
              0.2744382407386017, 0.40410226692421763`, 0.9390017406595347], 
             UndirectedEdge[194, 210] -> 
             RGBColor[
              0.5788422967306146, 0.6683006695271059, 0.9604448643230148], 
             UndirectedEdge[60, 265] -> 
             RGBColor[
              0.2549916258941355, 0.3853427445905684, 0.9378327679171411], 
             UndirectedEdge[78, 178] -> 
             RGBColor[
              0.2265713684695162, 0.3554712520888972, 0.9362142763008121], 
             UndirectedEdge[120, 190] -> 
             RGBColor[
              0.24175240008128845`, 0.37142747884586735`, 0.937078813592779], 
             UndirectedEdge[96, 267] -> 
             RGBColor[
              0.19857826997424566`, 0.3260487307054119, 0.9346201107535846], 
             UndirectedEdge[159, 212] -> 
             RGBColor[
              0.2623047179263146, 0.3930292679932042, 0.9382492376896236], 
             UndirectedEdge[34, 147] -> 
             RGBColor[
              0.19854534996450335`, 0.32601412968792354`, 0.9346182360077306],
              UndirectedEdge[41, 250] -> 
             RGBColor[
              0.18562426514456906`, 0.3124332502980778, 0.9338823993422674], 
             UndirectedEdge[146, 236] -> 
             RGBColor[
              0.2157299800022288, 0.3440762654260479, 0.9355968752659971], 
             UndirectedEdge[82, 103] -> 
             RGBColor[
              0.5173846437366769, 0.6182066285292835, 0.9553895463254356], 
             UndirectedEdge[179, 289] -> 
             RGBColor[
              0.383100677252795, 0.49832129750419296`, 0.9463738276021099], 
             UndirectedEdge[124, 247] -> 
             RGBColor[
              0.191840440673128, 0.3189668449068855, 0.9342364013426112], 
             UndirectedEdge[162, 227] -> 
             RGBColor[
              0.9720263822129245, 0.9204431940139248, 0.5369240475267748], 
             UndirectedEdge[156, 191] -> 
             RGBColor[
              0.31093411780431135`, 0.4362140910182484, 0.9413088841833633], 
             UndirectedEdge[1, 51] -> 
             RGBColor[
              0.8162278504025469, 0.38063100330818245`, 0.4376314664426699], 
             UndirectedEdge[23, 198] -> 
             RGBColor[
              0.9769688580402975, 0.9814876170817164, 0.8855196519471269], 
             UndirectedEdge[77, 159] -> 
             RGBColor[
              0.3525117466514917, 0.4781312147063014, 0.9437419749856031], 
             UndirectedEdge[2, 238] -> 
             RGBColor[
              0.19301734075154908`, 0.3202038415090809, 0.9343034240610095], 
             UndirectedEdge[113, 245] -> 
             RGBColor[
              0.24643755239072743`, 0.3763518709789012, 0.9373456260857398], 
             UndirectedEdge[167, 201] -> 
             RGBColor[
              0.8661367359765803, 0.45702825150686766`, 0.20890833900479755`],
              UndirectedEdge[125, 150] -> 
             RGBColor[
              0.8592661193941853, 0.40455587782479563`, 0.20234292983340507`],
              UndirectedEdge[142, 198] -> 
             RGBColor[
              0.8748207484584395, 0.4784399878291542, 0.43247386752858047`], 
             UndirectedEdge[34, 52] -> 
             RGBColor[
              0.1912130018306219, 0.3183073669014913, 0.934200669628743], 
             UndirectedEdge[13, 251] -> 
             RGBColor[
              0.3094480150189227, 0.44031071835692515`, 0.9410170631920465], 
             UndirectedEdge[120, 188] -> 
             RGBColor[
              0.317477361422549, 0.44666279511939655`, 0.9415507479684607], 
             UndirectedEdge[67, 173] -> 
             RGBColor[
              0.1901069718936137, 0.3171448593113474, 0.934137682860055], 
             UndirectedEdge[20, 280] -> 
             RGBColor[
              0.24050854139809294`, 0.3701201045046333, 0.9370079776808949], 
             UndirectedEdge[32, 107] -> 
             RGBColor[
              0.6980757286113448, 0.7586971466019095, 0.9005750351374335], 
             UndirectedEdge[189, 287] -> 
             RGBColor[
              0.22941840696730975`, 0.35846367006274493`, 0.9363764109314454],
              UndirectedEdge[159, 205] -> 
             RGBColor[
              0.33180025652813283`, 0.4601919629512097, 0.9424222571493942], 
             UndirectedEdge[66, 86] -> 
             RGBColor[
              0.49025940765542825`, 0.5952351366581299, 0.9535166371045274], 
             UndirectedEdge[119, 266] -> 
             RGBColor[
              0.1895006672172379, 0.3165075946545396, 0.9341031547056828], 
             UndirectedEdge[28, 230] -> 
             RGBColor[
              0.1877777818287943, 0.3146967328740425, 0.9340050389315915], 
             UndirectedEdge[83, 142] -> 
             RGBColor[
              0.8410135879259631, 0.3162539858335876, 0.18690796415711172`], 
             UndirectedEdge[191, 217] -> 
             RGBColor[
              0.21370747825416658`, 0.3419504878548173, 0.9354816967834682], 
             UndirectedEdge[43, 233] -> 
             RGBColor[
              0.2154911007768475, 0.3438251882143545, 0.9355832714475019], 
             UndirectedEdge[113, 297] -> 
             RGBColor[
              0.22981287868159825`, 0.35887828484541334`, 0.9363988755120056],
              UndirectedEdge[158, 207] -> 
             RGBColor[
              0.189116703595207, 0.3161040245430854, 0.9340812885454315], 
             UndirectedEdge[40, 201] -> 
             RGBColor[
              0.7933206093756301, 0.4855138555516503, 0.4506026835534007], 
             UndirectedEdge[194, 226] -> 
             RGBColor[
              0.8361313395314567, 0.8716084988779389, 0.9233783108429527], 
             UndirectedEdge[134, 230] -> 
             RGBColor[
              0.21844228820343148`, 0.34692707331578443`, 0.9357513372055553],
              UndirectedEdge[134, 264] -> 
             RGBColor[
              0.27050450497484707`, 0.4016477640777385, 0.9387162034315397], 
             UndirectedEdge[59, 226] -> 
             RGBColor[
              0.9856324112421679, 0.988326647065517, 0.887771658052475], 
             UndirectedEdge[42, 201] -> 
             RGBColor[
              0.84019118707681, 0.30993265252864627`, 0.18612043217519372`], 
             UndirectedEdge[217, 295] -> 
             RGBColor[
              0.19848052761044668`, 0.32594599728383544`, 0.9346145444705631],
              UndirectedEdge[45, 94] -> 
             RGBColor[
              0.5484117816822776, 0.636917841037437, 0.9603911500045271], 
             UndirectedEdge[197, 254] -> 
             RGBColor[
              0.6525617744919028, 0.7195772493628625, 0.9087750915707931], 
             UndirectedEdge[30, 189] -> 
             RGBColor[
              0.23256614809149867`, 0.36177214556258186`, 0.9365556701318023],
              UndirectedEdge[92, 179] -> 
             RGBColor[
              0.7286220477197832, 0.3701780038392919, 0.4370908994932349], 
             UndirectedEdge[134, 288] -> 
             RGBColor[
              0.22683219740980134`, 0.35574539984264686`, 0.9362291301230996],
              UndirectedEdge[59, 83] -> 
             RGBColor[
              0.8927042858426667, 0.5685755362546596, 0.4275164011539326], 
             UndirectedEdge[10, 22] -> 
             RGBColor[
              0.18947218593303478`, 0.31647765901902436`, 0.9341015327386817],
              UndirectedEdge[148, 168] -> 
             RGBColor[
              0.32335433659993124`, 0.4487211935569434, 0.9420362378816867], 
             UndirectedEdge[130, 216] -> 
             RGBColor[
              0.8815768726528278, 0.553695183078948, 0.2228219191679405], 
             UndirectedEdge[158, 196] -> 
             RGBColor[
              0.1980026870183727, 0.32544375652472224`, 0.9345873321557463], 
             UndirectedEdge[203, 237] -> 
             RGBColor[
              0.8624248063392239, 0.4467031448649862, 0.4448682209538134], 
             UndirectedEdge[160, 193] -> 
             RGBColor[
              0.23766407621559904`, 0.36713039124832314`, 0.9368459895967611],
              UndirectedEdge[38, 88] -> 
             RGBColor[
              0.20448897001762012`, 0.33226125121102634`, 0.9349567163769577],
              UndirectedEdge[22, 73] -> 
             RGBColor[
              0.1856051226212358, 0.3124131302923484, 0.9338813092038822], 
             UndirectedEdge[181, 227] -> 
             RGBColor[
              0.9694992257478029, 0.9078122736758734, 0.34102909604815745`], 
             UndirectedEdge[85, 255] -> 
             RGBColor[
              0.2990831810082368, 0.42639058870879876`, 0.9405375990810403], 
             UndirectedEdge[106, 227] -> 
             RGBColor[
              0.907282547148933, 0.8714421765894653, 0.6337446762316135], 
             UndirectedEdge[131, 261] -> 
             RGBColor[
              0.23707213530482818`, 0.36650822381988146`, 0.9368122794375908],
              UndirectedEdge[81, 94] -> 
             RGBColor[
              0.8431768541892217, 0.7161112955984645, 0.6049346124449686], 
             UndirectedEdge[77, 154] -> 
             RGBColor[
              0.455540153481848, 0.5677935680255081, 0.950577540756124], 
             UndirectedEdge[167, 277] -> 
             RGBColor[
              0.9503466052484179, 0.8295784884211206, 0.3626330239957771], 
             UndirectedEdge[113, 176] -> 
             RGBColor[
              0.23091262265844142`, 0.3600341854928709, 0.9364615043045614], 
             UndirectedEdge[4, 276] -> 
             RGBColor[
              0.23095575836688206`, 0.36007952385740394`, 0.9364639608193436],
              UndirectedEdge[101, 243] -> 
             RGBColor[
              0.8173727655187092, 0.8567408344553589, 0.91183562312612], 
             UndirectedEdge[52, 271] -> 
             RGBColor[
              0.21068413741610115`, 0.3387727649431298, 0.9353095219953723], 
             UndirectedEdge[37, 71] -> 
             RGBColor[
              0.22494256325409756`, 0.3537592745352769, 0.9361215182533955], 
             UndirectedEdge[83, 291] -> 
             RGBColor[
              0.8733266651066773, 0.5540623810054337, 0.4591038572583237], 
             UndirectedEdge[80, 149] -> 
             RGBColor[
              0.9371561077922606, 0.7792834728078644, 0.30334662593416606`], 
             UndirectedEdge[104, 206] -> 
             RGBColor[
              0.2787552105581772, 0.4078842978745366, 0.9392752437947942], 
             UndirectedEdge[61, 108] -> 
             RGBColor[
              0.25897235282054676`, 0.38952674098289125`, 0.9380594644266425],
              UndirectedEdge[115, 264] -> 
             RGBColor[
              0.32396934415914475`, 0.453868652264371, 0.9419064562812274], 
             UndirectedEdge[38, 52] -> 
             RGBColor[
              0.19242626978916738`, 0.3195825884515542, 0.934269763444113], 
             UndirectedEdge[33, 285] -> 
             RGBColor[
              0.20009304762604624`, 0.3276408580599046, 0.934706375099942], 
             UndirectedEdge[100, 122] -> 
             RGBColor[
              0.18285159839459103`, 0.3095190017466254, 0.933724500072649], 
             UndirectedEdge[205, 269] -> 
             RGBColor[
              0.6727623053020111, 0.7090410207196602, 0.647599267278013], 
             UndirectedEdge[177, 252] -> 
             RGBColor[
              0.2649570005472917, 0.39581698519228203`, 0.9384002812611878], 
             UndirectedEdge[152, 244] -> 
             RGBColor[
              0.1860116480511821, 0.312840414294423, 0.9339044602257174], 
             UndirectedEdge[10, 71] -> 
             RGBColor[
              0.20685989156236995`, 0.3347532400796667, 0.9350917368514671], 
             UndirectedEdge[233, 259] -> 
             RGBColor[
              0.1952784533382303, 0.32258041420050104`, 0.9344321910778048], 
             UndirectedEdge[130, 299] -> 
             RGBColor[
              0.849730326606493, 0.32580872903031854`, 0.19298739444399152`], 
             UndirectedEdge[81, 86] -> 
             RGBColor[
              0.7418209808035544, 0.6361932312179576, 0.5953370394744854], 
             UndirectedEdge[205, 282] -> 
             RGBColor[
              0.40649592976024684`, 0.5265080761040026, 0.947122539087454], 
             UndirectedEdge[176, 297] -> 
             RGBColor[
              0.19309289409094996`, 0.3202832528591496, 0.9343077267119173], 
             UndirectedEdge[92, 128] -> 
             RGBColor[
              0.8360165444918075, 0.27784452028027223`, 0.18212278972121096`],
              UndirectedEdge[166, 285] -> 
             RGBColor[
              0.19288702957547718`, 0.3200668762008235, 0.9342960030323104], 
             UndirectedEdge[132, 146] -> 
             RGBColor[
              0.19846266788634026`, 0.3259272255814276, 0.9346135273856964], 
             UndirectedEdge[81, 130] -> 
             RGBColor[
              0.9006340382989853, 0.6395018820094367, 0.23868605563289352`], 
             UndirectedEdge[1, 128] -> 
             RGBColor[
              0.8274423550647934, 0.21193954311047752`, 0.1739121362427404], 
             UndirectedEdge[296, 297] -> 
             RGBColor[
              0.18960014391301738`, 0.31661215096899065`, 0.934108819756345], 
             UndirectedEdge[128, 237] -> 
             RGBColor[
              0.838318390904733, 0.29553752048554727`, 0.1843270404457921], 
             UndirectedEdge[112, 146] -> 
             RGBColor[
              0.19463017997348525`, 0.32189903779124873`, 0.934395272868717], 
             UndirectedEdge[116, 287] -> 
             RGBColor[
              0.2651763885560936, 0.39604757589953593`, 0.9384127750837334], 
             UndirectedEdge[10, 266] -> 
             RGBColor[
              0.19427634422620857`, 0.3215271339863788, 0.9343751224463628], 
             UndirectedEdge[16, 76] -> 
             RGBColor[
              0.286854066125812, 0.4171520866149722, 0.9397088035477686], 
             UndirectedEdge[23, 72] -> 
             RGBColor[
              0.8827258558765204, 0.48135797009659975`, 0.3926067291806665], 
             UndirectedEdge[237, 277] -> 
             RGBColor[
              0.8810535048299607, 0.45831360631425644`, 0.27465957321892126`],
              UndirectedEdge[56, 278] -> 
             RGBColor[
              0.1999933373080916, 0.327536056193735, 0.9347006967448426], 
             UndirectedEdge[88, 274] -> 
             RGBColor[
              0.342952508633553, 0.4632649151839602, 0.9434373496862328], 
             UndirectedEdge[103, 282] -> 
             RGBColor[
              0.4309808924132613, 0.5477157201040381, 0.9486826992565017], 
             UndirectedEdge[46, 60] -> 
             RGBColor[
              0.2459880706675731, 0.3758794371890788, 0.9373200287665547], 
             UndirectedEdge[82, 216] -> 
             RGBColor[
              0.7821223617233105, 0.5567021598850534, 0.46109471540637825`], 
             UndirectedEdge[48, 70] -> 
             RGBColor[
              0.2012898575043234, 0.328898781124103, 0.9347745316519882], 
             UndirectedEdge[143, 174] -> 
             RGBColor[
              0.27004966377854045`, 0.4011696971418227, 0.9386903008982872], 
             UndirectedEdge[95, 205] -> 
             RGBColor[
              0.32995805051825455`, 0.4582556876322203, 0.9423173462424312], 
             UndirectedEdge[78, 190] -> 
             RGBColor[
              0.19927294772660503`, 0.32677888106825503`, 0.9346596716238978],
              UndirectedEdge[68, 292] -> 
             RGBColor[
              0.8252860920096456, 0.8638987146846454, 0.9830984780135097], 
             UndirectedEdge[145, 269] -> 
             RGBColor[
              0.9190343803618738, 0.908127960055847, 0.6686138108252507], 
             UndirectedEdge[198, 254] -> 
             RGBColor[
              0.6416864490274542, 0.7118235947085315, 0.9431778757394982], 
             UndirectedEdge[124, 147] -> 
             RGBColor[
              0.19966110992932296`, 0.3271868641542167, 0.9346817768871081], 
             UndirectedEdge[44, 194] -> 
             RGBColor[
              0.5011124283287507, 0.6014735099165995, 0.9553542362124354], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.3434646997755016, 0.4661397793633797, 0.9433176524403382], 
             UndirectedEdge[5, 11] -> 
             RGBColor[
              0.7514137479791486, 0.7723356879656991, 0.6490878757769967], 
             UndirectedEdge[108, 254] -> 
             RGBColor[
              0.27973365180931276`, 0.4104203008650652, 0.9392757639847461], 
             UndirectedEdge[61, 71] -> 
             RGBColor[
              0.25028804221449197`, 0.3803989799188331, 0.9375649057849139], 
             UndirectedEdge[229, 284] -> 
             RGBColor[
              0.22933503139451644`, 0.3583760370494225, 0.936371662815918], 
             UndirectedEdge[37, 136] -> 
             RGBColor[
              0.309591888135542, 0.4349767741872242, 0.9412260952746828], 
             UndirectedEdge[148, 159] -> 
             RGBColor[
              0.26876902654338763`, 0.39982366621058674`, 0.9386173705022783],
              UndirectedEdge[164, 230] -> 
             RGBColor[
              0.1870233298629817, 0.313903756022956, 0.9339620740082502], 
             UndirectedEdge[176, 193] -> 
             RGBColor[
              0.23687819251132788`, 0.36630437764722934`, 0.9368012346824135],
              UndirectedEdge[216, 299] -> 
             RGBColor[
              0.8505404448303738, 0.37258152858724236`, 0.19536912935227085`],
              UndirectedEdge[149, 277] -> 
             RGBColor[
              0.9442574972371908, 0.8029244899485575, 0.3576036046538991], 
             UndirectedEdge[39, 248] -> 
             RGBColor[
              0.21184147363468755`, 0.3399891986882186, 0.9353754305808952], 
             UndirectedEdge[13, 137] -> 
             RGBColor[
              0.2974114508687985, 0.42765952627289927`, 0.9403315986701979], 
             UndirectedEdge[68, 75] -> 
             RGBColor[
              0.6048929892039929, 0.6837170469414527, 0.9652757515328931], 
             UndirectedEdge[66, 97] -> 
             RGBColor[
              0.4175999543798127, 0.5361258241249656, 0.9478300777173092], 
             UndirectedEdge[59, 106] -> 
             RGBColor[
              0.9234341463667425, 0.9403782883321993, 0.9424056010083017], 
             UndirectedEdge[51, 198] -> 
             RGBColor[
              0.8879439008384149, 0.9128115493875727, 0.9633242059952494], 
             UndirectedEdge[193, 228] -> 
             RGBColor[
              0.35291040472918833`, 0.4773968889253306, 0.9438069074260627], 
             UndirectedEdge[30, 287] -> 
             RGBColor[
              0.24614870075893425`, 0.37604826959963533`, 0.9373291764126268],
              UndirectedEdge[93, 147] -> 
             RGBColor[
              0.22726390844905786`, 0.3561991555169663, 0.936253715428126], 
             UndirectedEdge[69, 121] -> 
             RGBColor[
              0.21650915427912054`, 0.3448952269935637, 0.9356412480883811], 
             UndirectedEdge[148, 251] -> 
             RGBColor[
              0.26595227173522773`, 0.39686307831464074`, 0.9384569604829689],
              UndirectedEdge[125, 269] -> 
             RGBColor[
              0.881184613963798, 0.48806415416592097`, 0.23764075645846794`], 
             UndirectedEdge[37, 44] -> 
             RGBColor[
              0.27139379762507876`, 0.4018915080789134, 0.9387921467246012], 
             UndirectedEdge[91, 105] -> 
             RGBColor[
              0.38699951220692347`, 0.5063182366232937, 0.9462409477627431], 
             UndirectedEdge[81, 203] -> 
             RGBColor[
              0.9132949931047244, 0.7717981514907339, 0.6103970678254644], 
             UndirectedEdge[8, 69] -> 
             RGBColor[
              0.2060185451131012, 0.33386893161703934`, 0.9350438234158418], 
             UndirectedEdge[52, 270] -> 
             RGBColor[
              0.20578610160522076`, 0.3336246187524874, 0.9350305861019373], 
             UndirectedEdge[108, 268] -> 
             RGBColor[
              0.2228674989167732, 0.351578250350071, 0.9360033464091675], 
             UndirectedEdge[11, 254] -> 
             RGBColor[
              0.4252983225505378, 0.5406623913243694, 0.9489095154684506], 
             UndirectedEdge[82, 255] -> 
             RGBColor[
              0.489728760692208, 0.5942524926612631, 0.9536273379129792], 
             UndirectedEdge[43, 66] -> 
             RGBColor[
              0.3059641689064351, 0.4317438620573953, 0.9409982635304203], 
             UndirectedEdge[252, 283] -> 
             RGBColor[
              0.27188152915805053`, 0.4030951038026612, 0.9387946229216484], 
             UndirectedEdge[99, 215] -> 
             RGBColor[
              0.21020795705683448`, 0.338272269193962, 0.9352824042283578], 
             UndirectedEdge[114, 283] -> 
             RGBColor[
              0.2724764193926355, 0.4037203711574294, 0.9388285010404467], 
             UndirectedEdge[24, 194] -> 
             RGBColor[
              0.8048847779464043, 0.7450443793025796, 0.6134276095233945], 
             UndirectedEdge[134, 228] -> 
             RGBColor[
              0.3355280602689666, 0.4591269427933443, 0.9428170086239273], 
             UndirectedEdge[49, 143] -> 
             RGBColor[
              0.2582581828615999, 0.38877610307504745`, 0.9380187935040003], 
             UndirectedEdge[123, 189] -> 
             RGBColor[
              0.2072195140090381, 0.335131226072495, 0.935112216817791], 
             UndirectedEdge[232, 240] -> 
             RGBColor[
              0.184219115333836, 0.3109563487553536, 0.933802378139279], 
             UndirectedEdge[11, 243] -> 
             RGBColor[
              0.7596161582091865, 0.8099275378271904, 0.907236768390906], 
             UndirectedEdge[155, 210] -> 
             RGBColor[
              0.698996444284087, 0.6637676396684864, 0.6055600185754992], 
             UndirectedEdge[148, 156] -> 
             RGBColor[
              0.32039438822353183`, 0.44615743504463745`, 0.9418476325885221],
              UndirectedEdge[15, 212] -> 
             RGBColor[
              0.24587235329600743`, 0.3757578108946581, 0.9373134388334325], 
             UndirectedEdge[51, 204] -> 
             RGBColor[
              0.647452541380158, 0.7220822556308867, 0.967158350930859], 
             UndirectedEdge[95, 156] -> 
             RGBColor[
              0.3410239560220559, 0.4678404187910305, 0.9430224559559374], 
             UndirectedEdge[87, 109] -> 
             RGBColor[
              0.9929796059139886, 0.9895239708410322, 0.632193448669364], 
             UndirectedEdge[113, 288] -> 
             RGBColor[
              0.23824897201713657`, 0.3677451538202748, 0.9368792985473828], 
             UndirectedEdge[164, 176] -> 
             RGBColor[
              0.1880768897106564, 0.3150111142224146, 0.9340220726829731], 
             UndirectedEdge[17, 294] -> 
             RGBColor[
              0.6198562799736641, 0.7013271769000424, 0.963858572100545], 
             UndirectedEdge[77, 212] -> 
             RGBColor[
              0.32357566422601636`, 0.4477175574235364, 0.9420941078985701], 
             UndirectedEdge[180, 296] -> 
             RGBColor[
              0.19104587171588, 0.3181317025542363, 0.9341911518159554], 
             UndirectedEdge[217, 271] -> 
             RGBColor[
              0.21133673112817714`, 0.3394586823113528, 0.9353466862418491], 
             UndirectedEdge[4, 85] -> 
             RGBColor[
              0.2263430797542824, 0.3552313061748459, 0.9362012755962026], 
             UndirectedEdge[95, 127] -> 
             RGBColor[
              0.3181958172626126, 0.4480678323732162, 0.9415678671403162], 
             UndirectedEdge[54, 75] -> 
             RGBColor[
              0.2884831291269512, 0.41830852004459096`, 0.9398219273882558], 
             UndirectedEdge[134, 193] -> 
             RGBColor[
              0.26218140249464095`, 0.39289965565586527`, 0.9382422150582186],
              UndirectedEdge[40, 178] -> 
             RGBColor[
              0.4741224882012588, 0.573360769660643, 0.953860855337124], 
             UndirectedEdge[69, 239] -> 
             RGBColor[
              0.22257247692189291`, 0.35126816352797696`, 0.935986545343005], 
             UndirectedEdge[134, 200] -> 
             RGBColor[
              0.3051846864517926, 0.4328450374952205, 0.9408835556758889], 
             UndirectedEdge[89, 141] -> 
             RGBColor[
              0.33729605784908523`, 0.4651931821113565, 0.9427636193772146], 
             UndirectedEdge[38, 147] -> 
             RGBColor[
              0.1997586179230488, 0.3272893512379864, 0.9346873298231007], 
             UndirectedEdge[170, 182] -> 
             RGBColor[
              0.2259600378398488, 0.3548287048365162, 0.9361794619258352], 
             UndirectedEdge[94, 120] -> 
             RGBColor[
              0.5379895613183256, 0.6259634266279861, 0.9597976199730934], 
             UndirectedEdge[80, 269] -> 
             RGBColor[
              0.9759866531723878, 0.9306594839278095, 0.36121311142511225`], 
             UndirectedEdge[263, 286] -> 
             RGBColor[
              0.2153900069518347, 0.3437189321945473, 0.9355775143037223], 
             UndirectedEdge[130, 140] -> 
             RGBColor[
              0.8488137274171336, 0.3187633460045766, 0.19210965802511026`], 
             UndirectedEdge[25, 288] -> 
             RGBColor[
              0.19999048340527747`, 0.32753305656092946`, 0.9347005342192993],
              UndirectedEdge[148, 191] -> 
             RGBColor[
              0.23683698231576478`, 0.36626106311881523`, 0.9367988878227413],
              UndirectedEdge[177, 268] -> 
             RGBColor[
              0.24851062539069607`, 0.37853080214228807`, 0.9374636845262513],
              UndirectedEdge[69, 126] -> 
             RGBColor[
              0.21552861209731056`, 0.34386461499051624`, 0.9355854076617092],
              UndirectedEdge[20, 37] -> 
             RGBColor[
              0.22278622542452461`, 0.3514928267566807, 0.9359987180040172], 
             UndirectedEdge[3, 72] -> 
             RGBColor[
              0.8710164273574281, 0.4731960144605215, 0.4379945662177568], 
             UndirectedEdge[87, 154] -> 
             RGBColor[
              0.7452228320173793, 0.7952601643437132, 0.7245769752264782], 
             UndirectedEdge[11, 204] -> 
             RGBColor[
              0.5077115751599948, 0.6112221547175201, 0.9543880614868259], 
             UndirectedEdge[55, 268] -> 
             RGBColor[
              0.20359322925377082`, 0.3313197708749761, 0.9349057052655861], 
             UndirectedEdge[125, 142] -> 
             RGBColor[
              0.8334415120439743, 0.25805169249981336`, 0.1796569357410828], 
             UndirectedEdge[176, 221] -> 
             RGBColor[
              0.1901941228796547, 0.3172364605233681, 0.9341426459797817], 
             UndirectedEdge[29, 182] -> 
             RGBColor[
              0.224799401299116, 0.35360880224359903`, 0.9361133653918483], 
             UndirectedEdge[122, 161] -> 
             RGBColor[
              0.19334750398760153`, 0.32055086400373023`, 0.9343222263688701],
              UndirectedEdge[44, 226] -> 
             RGBColor[
              0.6512382253914439, 0.7184499980919314, 0.9093942676022314], 
             UndirectedEdge[89, 131] -> 
             RGBColor[
              0.3050760854207314, 0.4313279482249144, 0.9409287396125976], 
             UndirectedEdge[56, 110] -> 
             RGBColor[
              0.1926369557700678, 0.31980403277574326`, 0.9342817616990433], 
             UndirectedEdge[43, 178] -> 
             RGBColor[
              0.24229896140308743`, 0.37200194944906734`, 0.9371099394514903],
              UndirectedEdge[66, 162] -> 
             RGBColor[
              0.6888450125107997, 0.7498709206605213, 0.8694416515926326], 
             UndirectedEdge[5, 142] -> 
             RGBColor[
              0.8769612906990375, 0.45869614749014964`, 0.23149650701243416`],
              UndirectedEdge[147, 273] -> 
             RGBColor[
              0.22616395243467474`, 0.35504303200461024`, 0.9361910745603459],
              UndirectedEdge[81, 167] -> 
             RGBColor[
              0.8985734587541578, 0.6313323707616247, 0.23702806496310708`], 
             UndirectedEdge[95, 212] -> 
             RGBColor[
              0.2604625119164363, 0.3910929926742148, 0.9381443267826606], 
             UndirectedEdge[56, 217] -> 
             RGBColor[
              0.19969746831988144`, 0.32722507912794885`, 0.934683847443663], 
             UndirectedEdge[6, 93] -> 
             RGBColor[
              0.2258625386311459, 0.35472622698636247`, 0.9361739094901367], 
             UndirectedEdge[131, 146] -> 
             RGBColor[
              0.2147184255833614, 0.3430130575955638, 0.9355392687383033], 
             UndirectedEdge[7, 80] -> 
             RGBColor[
              0.9585640473109542, 0.9468487152511682, 0.6807339798518178], 
             UndirectedEdge[76, 239] -> 
             RGBColor[
              0.28224692267200363`, 0.41230968673525326`, 0.9394464335437323],
              UndirectedEdge[148, 278] -> 
             RGBColor[
              0.2234636176615972, 0.35220480894699246`, 0.9360372944898065], 
             UndirectedEdge[29, 170] -> 
             RGBColor[
              0.19641582947302122`, 0.3237758686319784, 0.934496962966084], 
             UndirectedEdge[147, 289] -> 
             RGBColor[
              0.22842117185433053`, 0.35741551273064565`, 0.9363196198670385],
              UndirectedEdge[25, 28] -> 
             RGBColor[
              0.18729283765525817`, 0.3141870258004196, 0.9339774220783192], 
             UndirectedEdge[5, 149] -> 
             RGBColor[
              0.933258247478127, 0.766135074707167, 0.2882041746629133], 
             UndirectedEdge[140, 202] -> 
             RGBColor[
              0.8337362452113755, 0.25175489945285184`, 0.1796038966578704], 
             UndirectedEdge[10, 63] -> 
             RGBColor[
              0.18664280478053893`, 0.31350380003462497`, 0.9339404036677414],
              UndirectedEdge[43, 259] -> 
             RGBColor[
              0.20537394232393572`, 0.33319141321544904`, 0.9350071142406031],
              UndirectedEdge[21, 50] -> 
             RGBColor[
              0.18770061499905671`, 0.31461562564332873`, 0.9340006443947961],
              UndirectedEdge[87, 155] -> 
             RGBColor[
              0.959730943798982, 0.866659323879206, 0.37757715104669176`], 
             UndirectedEdge[127, 282] -> 
             RGBColor[
              0.3947336965046049, 0.5163202208449985, 0.9463730599853389], 
             UndirectedEdge[79, 144] -> 
             RGBColor[
              0.1903903758627761, 0.31744273485178653`, 0.9341538222968402], 
             UndirectedEdge[54, 298] -> 
             RGBColor[
              0.25208733908179476`, 0.3822901550083788, 0.9376673730796856], 
             UndirectedEdge[234, 263] -> 
             RGBColor[
              0.20202221841831886`, 0.32966853887907605`, 0.9348162385226094],
              UndirectedEdge[34, 38] -> 
             RGBColor[
              0.18490621443215238`, 0.31167853347228314`, 0.9338415074164561],
              UndirectedEdge[39, 85] -> 
             RGBColor[
              0.21693635514660192`, 0.345344242191386, 0.9356655765457971], 
             UndirectedEdge[20, 108] -> 
             RGBColor[
              0.2298448182232575, 0.3589118553287811, 0.9364006944216527], 
             UndirectedEdge[94, 201] -> 
             RGBColor[
              0.8292056662666228, 0.5135475347314276, 0.45417937065937186`], 
             UndirectedEdge[260, 294] -> 
             RGBColor[
              0.39710848893487455`, 0.5114544721894022, 0.9473162764842546], 
             UndirectedEdge[138, 266] -> 
             RGBColor[
              0.21471877848996196`, 0.3430134285227765, 0.935539288835812], 
             UndirectedEdge[127, 168] -> 
             RGBColor[
              0.3746233333290345, 0.4989016350385623, 0.9450916454266876], 
             UndirectedEdge[128, 198] -> 
             RGBColor[
              0.8848238567439902, 0.5553282615018976, 0.4420528553197187], 
             UndirectedEdge[145, 216] -> 
             RGBColor[
              0.8659437661770946, 0.6227214635073127, 0.46918309334836605`], 
             UndirectedEdge[141, 182] -> 
             RGBColor[
              0.2740956905180802, 0.4054223277779909, 0.9389207161355438], 
             UndirectedEdge[41, 252] -> 
             RGBColor[
              0.21326847287064163`, 0.3414890653621836, 0.9354566960763266], 
             UndirectedEdge[55, 208] -> 
             RGBColor[
              0.19572673330134732`, 0.32305158486432833`, 0.9344577199585336],
              UndirectedEdge[121, 249] -> 
             RGBColor[
              0.21645306950395798`, 0.3448362783388877, 0.9356380541434055], 
             UndirectedEdge[89, 120] -> 
             RGBColor[
              0.3299173264663655, 0.4574376675895273, 0.9423434115408236], 
             UndirectedEdge[32, 142] -> 
             RGBColor[
              0.8825157823171381, 0.4837930341441863, 0.4021669111922269], 
             UndirectedEdge[7, 77] -> 
             RGBColor[
              0.6760511895639363, 0.7431695037981105, 0.9684398535409274], 
             UndirectedEdge[45, 146] -> 
             RGBColor[
              0.24998188699294738`, 0.3800771913696276, 0.937547470697963], 
             UndirectedEdge[110, 223] -> 
             RGBColor[
              0.18370379552866184`, 0.31041471496695283`, 0.9337730314387216],
              UndirectedEdge[225, 276] -> 
             RGBColor[
              0.23448523874767882`, 0.3637892315196025, 0.9366649595056316], 
             UndirectedEdge[65, 291] -> 
             RGBColor[
              0.6521691058057041, 0.7229451944590042, 0.9690799766899112], 
             UndirectedEdge[194, 290] -> 
             RGBColor[
              0.8162082398567924, 0.7899381324572718, 0.622538732772305], 
             UndirectedEdge[154, 258] -> 
             RGBColor[
              0.4187295668061743, 0.5359100880009214, 0.9482320027234739], 
             UndirectedEdge[31, 280] -> 
             RGBColor[
              0.3408307300134504, 0.46531138731317084`, 0.9430966160299905], 
             UndirectedEdge[156, 271] -> 
             RGBColor[
              0.3085633706783219, 0.433722285474784, 0.9411738736417443], 
             UndirectedEdge[83, 241] -> 
             RGBColor[
              0.8930764595038494, 0.5687294396279854, 0.42134852043357485`], 
             UndirectedEdge[208, 268] -> 
             RGBColor[
              0.19718303522223768`, 0.3245822505180589, 0.9345406541985226], 
             UndirectedEdge[1, 80] -> 
             RGBColor[
              0.8720650730237359, 0.40985349668350635`, 0.23441445399203503`],
              UndirectedEdge[116, 206] -> 
             RGBColor[
              0.2548872111619892, 0.3852329980868062, 0.9378268216526131], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.22364840280037163`, 0.35239902984389887`, 0.9360478177300946],
              UndirectedEdge[108, 204] -> 
             RGBColor[
              0.36214690441876973`, 0.48098006425821577`, 0.9447543100031214],
              UndirectedEdge[251, 271] -> 
             RGBColor[
              0.25412125419001774`, 0.38442792874478726`, 0.9377832015361911],
              UndirectedEdge[6, 38] -> 
             RGBColor[
              0.19835724810513683`, 0.32581642270738265`, 0.9346075238851115],
              UndirectedEdge[135, 158] -> 
             RGBColor[
              0.20301108119461975`, 0.33070789635448955`, 0.9348725527948284],
              UndirectedEdge[25, 180] -> 
             RGBColor[
              0.1930001178726018, 0.32018573917131365`, 0.9343024432435325], 
             UndirectedEdge[57, 217] -> 
             RGBColor[
              0.18985695379830947`, 0.3168820744411198, 0.9341234446993961], 
             UndirectedEdge[71, 136] -> 
             RGBColor[
              0.3079661703282201, 0.43326804169526645`, 0.9411335130505898], 
             UndirectedEdge[135, 173] -> 
             RGBColor[
              0.20718172638991203`, 0.3350915088889201, 0.9351100648687836], 
             UndirectedEdge[143, 235] -> 
             RGBColor[
              0.3576942027971, 0.4840672946486393, 0.9440192038790169], 
             UndirectedEdge[264, 288] -> 
             RGBColor[
              0.2525376443502292, 0.38276345439650644`, 0.937693017298556], 
             UndirectedEdge[223, 247] -> 
             RGBColor[
              0.18962339324408597`, 0.3166365874900364, 0.934110143771355], 
             UndirectedEdge[191, 225] -> 
             RGBColor[
              0.22748667103589795`, 0.35643329311969896`, 0.9362664014278987],
              UndirectedEdge[1, 243] -> 
             RGBColor[
              0.8749347729676722, 0.4261491311907023, 0.39641874822047274`], 
             UndirectedEdge[29, 284] -> 
             RGBColor[
              0.21810645410068208`, 0.3465740903806829, 0.9357322119502256], 
             UndirectedEdge[6, 273] -> 
             RGBColor[
              0.22476258261676274`, 0.3535701034740064, 0.9361112686223567], 
             UndirectedEdge[103, 276] -> 
             RGBColor[
              0.33135174266530537`, 0.4551929422593771, 0.9425624927166377], 
             UndirectedEdge[99, 199] -> 
             RGBColor[
              0.19703448061371565`, 0.32442611020559603`, 0.9345321942333341],
              UndirectedEdge[35, 129] -> 
             RGBColor[
              0.19774057513237292`, 0.32516826031368307`, 0.9345724052715985],
              UndirectedEdge[77, 145] -> 
             RGBColor[
              0.6393432778876973, 0.7139671917177287, 0.9672816709055783], 
             UndirectedEdge[72, 155] -> 
             RGBColor[
              0.8617149167399476, 0.39992575965670085`, 0.20372391614271176`],
              UndirectedEdge[20, 44] -> 
             RGBColor[
              0.26761174198818394`, 0.3979163278083595, 0.93857676425113], 
             UndirectedEdge[131, 178] -> 
             RGBColor[
              0.2442095797785655, 0.3740101305018966, 0.9372187463414672], 
             UndirectedEdge[106, 241] -> 
             RGBColor[
              0.9239924068585166, 0.940609143392188, 0.9331537799277652], 
             UndirectedEdge[85, 286] -> 
             RGBColor[
              0.2265196157319883, 0.3554168566804423, 0.9362113290589713], 
             UndirectedEdge[86, 261] -> 
             RGBColor[
              0.41945675567834323`, 0.5279913173677868, 0.949221846121721], 
             UndirectedEdge[256, 269] -> 
             RGBColor[
              0.8696737021648134, 0.3995862419652118, 0.22661789432004487`], 
             UndirectedEdge[37, 61] -> 
             RGBColor[
              0.25191376002181387`, 0.38210771241079083`, 0.937657488009007], 
             UndirectedEdge[73, 244] -> 
             RGBColor[
              0.18608629156364545`, 0.31291886935869395`, 0.9339087110633268],
              UndirectedEdge[180, 193] -> 
             RGBColor[
              0.23722417633734735`, 0.3666680285850174, 0.9368209379494682], 
             UndirectedEdge[8, 213] -> 
             RGBColor[
              0.20342164602247398`, 0.3311394260198779, 0.9348959338543985], 
             UndirectedEdge[48, 138] -> 
             RGBColor[
              0.21204884540564534`, 0.34020715956762493`, 0.9353872400964722],
              UndirectedEdge[170, 284] -> 
             RGBColor[
              0.2192670906414149, 0.34779399297360003`, 0.9357983084842125], 
             UndirectedEdge[55, 219] -> 
             RGBColor[
              0.19323553565117518`, 0.3204331781829436, 0.9343158499377529], 
             UndirectedEdge[111, 235] -> 
             RGBColor[
              0.5113487817124779, 0.61295792200517, 0.9550106787741928], 
             UndirectedEdge[56, 247] -> 
             RGBColor[
              0.19855655348549195`, 0.3260259052988269, 0.9346188740316768], 
             UndirectedEdge[7, 82] -> 
             RGBColor[
              0.7758796678197641, 0.8252882359458167, 0.9760021123389747], 
             UndirectedEdge[182, 190] -> 
             RGBColor[
              0.22937905061187158`, 0.35842230403784237`, 0.9363741696452258],
              UndirectedEdge[113, 228] -> 
             RGBColor[
              0.34694483487630184`, 0.4711266967709722, 0.9434671770482106], 
             UndirectedEdge[133, 146] -> 
             RGBColor[
              0.19265917133132254`, 0.3198273827391699, 0.9342830268423918], 
             UndirectedEdge[93, 274] -> 
             RGBColor[
              0.3520883115326398, 0.4728672232742597, 0.9439576201461266], 
             UndirectedEdge[153, 220] -> 
             RGBColor[
              0.27707930337293885`, 0.40630757672797435`, 0.9391730382607208],
              UndirectedEdge[90, 153] -> 
             RGBColor[
              0.21837262298903565`, 0.3468538507584247, 0.9357473698746558], 
             UndirectedEdge[178, 190] -> 
             RGBColor[
              0.23171291230071078`, 0.36087534064819005`, 0.9365070796157662],
              UndirectedEdge[39, 126] -> 
             RGBColor[
              0.21260629074350712`, 0.3407930699617935, 0.9354189857837971], 
             UndirectedEdge[15, 77] -> 
             RGBColor[
              0.3360793820211845, 0.46085975760775527`, 0.942806176129412], 
             UndirectedEdge[103, 293] -> 
             RGBColor[
              0.6605442022439556, 0.5885330418914387, 0.5930681631412746], 
             UndirectedEdge[92, 269] -> 
             RGBColor[
              0.8787580922688558, 0.4694128451100082, 0.23531711654302695`], 
             UndirectedEdge[8, 14] -> 
             RGBColor[
              0.19233103918746458`, 0.31948249505119564`, 0.9342643402022272],
              UndirectedEdge[157, 171] -> 
             RGBColor[
              0.1808430925709541, 0.30740793477935857`, 0.9336101186373109], 
             UndirectedEdge[198, 226] -> 
             RGBColor[
              0.975424098844659, 0.9808488194558194, 0.9111203095275062], 
             UndirectedEdge[86, 169] -> 
             RGBColor[
              0.5994580148931581, 0.6857060476229113, 0.9616106773009028], 
             UndirectedEdge[163, 235] -> 
             RGBColor[
              0.5148221170934733, 0.615777732139438, 0.9552841124586315], 
             UndirectedEdge[31, 136] -> 
             RGBColor[
              0.4061320211140046, 0.526192876725208, 0.9470993511503072], 
             UndirectedEdge[111, 292] -> 
             RGBColor[
              0.6939596467687601, 0.7604145144003427, 0.9704259544749405], 
             UndirectedEdge[48, 122] -> 
             RGBColor[
              0.1889251216320018, 0.3159026597527588, 0.9340703782360471], 
             UndirectedEdge[246, 295] -> 
             RGBColor[
              0.19068631113650653`, 0.3177537815878572, 0.9341706753728822], 
             UndirectedEdge[258, 263] -> 
             RGBColor[
              0.2750253960672227, 0.40349492782139373`, 0.9390800123727585], 
             UndirectedEdge[24, 299] -> 
             RGBColor[
              0.8537172703307078, 0.34161563232659264`, 0.19619538295009195`],
              UndirectedEdge[66, 193] -> 
             RGBColor[
              0.33295274750258996`, 0.46011056933666983`, 0.9425352231554471],
              UndirectedEdge[29, 199] -> 
             RGBColor[
              0.196824977685108, 0.32420590934437654`, 0.9345202633514818], 
             UndirectedEdge[27, 87] -> 
             RGBColor[
              0.9814947768371431, 0.9488415742094825, 0.4164630400439475], 
             UndirectedEdge[164, 180] -> 
             RGBColor[
              0.18842287353667586`, 0.3153747651602027, 0.9340417759500277], 
             UndirectedEdge[106, 200] -> 
             RGBColor[
              0.6137154608562325, 0.6918743175265988, 0.9656005116200483], 
             UndirectedEdge[69, 285] -> 
             RGBColor[
              0.2036242652013759, 0.3313523916237017, 0.9349074727168887], 
             UndirectedEdge[88, 137] -> 
             RGBColor[
              0.242196310039882, 0.3718940563578661, 0.9371040936082149], 
             UndirectedEdge[43, 261] -> 
             RGBColor[
              0.23516151692935008`, 0.3645000427670523, 0.9367034725476139], 
             UndirectedEdge[224, 253] -> 
             RGBColor[
              0.20025883236896588`, 0.32781510833607297`, 0.9347158162957947],
              UndirectedEdge[5, 23] -> 
             RGBColor[
              0.9801796714011944, 0.9518718565732095, 0.5840536111729073], 
             UndirectedEdge[42, 162] -> 
             RGBColor[
              0.8888525819392381, 0.5235981308400817, 0.3867774183736629], 
             UndirectedEdge[29, 131] -> 
             RGBColor[
              0.21233150972289871`, 0.34050425768701104`, 0.9354033374111754],
              UndirectedEdge[12, 192] -> 
             RGBColor[
              0.3801187118441842, 0.5036614557026298, 0.9454418060863005], 
             UndirectedEdge[69, 76] -> 
             RGBColor[
              0.2672433086560147, 0.39653993712037666`, 0.9385919999213795], 
             UndirectedEdge[176, 180] -> 
             RGBColor[
              0.1945386218938126, 0.32180280444439524`, 0.9343900587715277], 
             UndirectedEdge[101, 116] -> 
             RGBColor[
              0.46733992011891123`, 0.5718860980228273, 0.952579449352897], 
             UndirectedEdge[125, 293] -> 
             RGBColor[
              0.8567159034897515, 0.39358707228041634`, 0.20024658025461053`],
              UndirectedEdge[30, 300] -> 
             RGBColor[
              0.23747118318928384`, 0.36692764844754155`, 0.936835004624272], 
             UndirectedEdge[155, 290] -> 
             RGBColor[
              0.9363623874102649, 0.7854051025986525, 0.2676538870247894], 
             UndirectedEdge[217, 246] -> 
             RGBColor[
              0.1922440281378487, 0.31939104092123016`, 0.9342593850516728], 
             UndirectedEdge[42, 82] -> 
             RGBColor[
              0.7628830394364272, 0.4257203521722454, 0.4433328823923026], 
             UndirectedEdge[122, 138] -> 
             RGBColor[
              0.2081640824318275, 0.3361240273739437, 0.9351660085921052], 
             UndirectedEdge[58, 160] -> 
             RGBColor[
              0.19345266111115197`, 0.32066139080792844`, 0.9343282149114902],
              UndirectedEdge[158, 225] -> 
             RGBColor[
              0.21027114178594725`, 0.3383386803504027, 0.9352860025052073], 
             UndirectedEdge[197, 204] -> 
             RGBColor[
              0.7349750271013598, 0.7901370127560131, 0.9142536375891683], 
             UndirectedEdge[40, 182] -> 
             RGBColor[
              0.47178862651241965`, 0.5709077330502953, 0.9537279453665835], 
             UndirectedEdge[1, 149] -> 
             RGBColor[
              0.8442968725884236, 0.3025905271935833, 0.18852880607059228`], 
             UndirectedEdge[32, 156] -> 
             RGBColor[
              0.691083843191671, 0.7526411268737674, 0.9001295183811735], 
             UndirectedEdge[258, 286] -> 
             RGBColor[
              0.28052613048445796`, 0.4092765484606139, 0.9393932710602128], 
             UndirectedEdge[101, 197] -> 
             RGBColor[
              0.816834867392223, 0.8565183997567056, 0.9207499871177253], 
             UndirectedEdge[53, 271] -> 
             RGBColor[
              0.21925630560640996`, 0.3477826572179991, 0.935797694292424], 
             UndirectedEdge[22, 70] -> 
             RGBColor[
              0.19915563229546623`, 0.32665557511190024`, 0.9346529906836472],
              UndirectedEdge[76, 258] -> 
             RGBColor[
              0.3335396370029857, 0.4633170022075566, 0.942473828625678], 
             UndirectedEdge[232, 297] -> 
             RGBColor[
              0.18995045311417683`, 0.3169803481502954, 0.934128769347115], 
             UndirectedEdge[178, 261] -> 
             RGBColor[
              0.2518738885698846, 0.38206580498681714`, 0.9376552173888041], 
             UndirectedEdge[155, 227] -> 
             RGBColor[
              0.9395091625151377, 0.7978810172888317, 0.27018585613847523`], 
             UndirectedEdge[178, 182] -> 
             RGBColor[
              0.2566774713547828, 0.3871146750584845, 0.9379287743221401], 
             UndirectedEdge[5, 51] -> 
             RGBColor[
              0.8911547141993119, 0.8831957888790658, 0.6618581652210298], 
             UndirectedEdge[110, 295] -> 
             RGBColor[
              0.19142001506063305`, 0.31852495093162986`, 0.9342124587259435],
              UndirectedEdge[186, 286] -> 
             RGBColor[
              0.2070033670926693, 0.3349040419588854, 0.9350999075706646], 
             UndirectedEdge[34, 270] -> 
             RGBColor[
              0.19826604624820576`, 0.32572056377321634`, 0.9346023300742803],
              UndirectedEdge[4, 8] -> 
             RGBColor[
              0.21250294836697825`, 0.34068445057177643`, 0.935413100588335], 
             UndirectedEdge[69, 166] -> 
             RGBColor[
              0.19683162728000528`, 0.3242128984902222, 0.9345206420360739], 
             UndirectedEdge[25, 176] -> 
             RGBColor[
              0.19265413404658233`, 0.31982208823352565`, 0.9342827399764779],
              UndirectedEdge[32, 149] -> 
             RGBColor[
              0.9415899849052779, 0.803780404688222, 0.5442097809326024], 
             UndirectedEdge[16, 153] -> 
             RGBColor[
              0.233929772423327, 0.36320540119410966`, 0.9366333265201985], 
             UndirectedEdge[169, 299] -> 
             RGBColor[
              0.7473755866979517, 0.32646116929742564`, 0.43103187403331167`],
              UndirectedEdge[187, 229] -> 
             RGBColor[
              0.22122626051320093`, 0.3498532047273915, 0.9359098803100787], 
             UndirectedEdge[15, 82] -> 
             RGBColor[
              0.43590786027701234`, 0.5429784897554615, 0.9503684349274593], 
             UndirectedEdge[44, 280] -> 
             RGBColor[
              0.2891161135986471, 0.42051878582686586`, 0.939801406401479], 
             UndirectedEdge[186, 265] -> 
             RGBColor[
              0.2079159163966799, 0.33586318913636815`, 0.9351518759035322], 
             UndirectedEdge[117, 265] -> 
             RGBColor[
              0.2041128319271811, 0.33186590622944256`, 0.9349352958691536], 
             UndirectedEdge[106, 162] -> 
             RGBColor[
              0.9266044419072905, 0.9416892870110949, 0.8898655994395634], 
             UndirectedEdge[9, 146] -> 
             RGBColor[
              0.1994945649800457, 0.3270118148529666, 0.9346722923986279], 
             UndirectedEdge[130, 294] -> 
             RGBColor[
              0.723926300807685, 0.6611320656306849, 0.6022559472314186], 
             UndirectedEdge[13, 53] -> 
             RGBColor[
              0.27458306643531494`, 0.40366544683013694`, 0.9390315559482794],
              UndirectedEdge[34, 57] -> 
             RGBColor[
              0.18168430472921848`, 0.3082921020936258, 0.9336580244252622], 
             UndirectedEdge[25, 144] -> 
             RGBColor[
              0.19437777007737006`, 0.3216337389867199, 0.9343808984985402], 
             UndirectedEdge[206, 283] -> 
             RGBColor[
              0.26412169083739256`, 0.3949390217254835, 0.938352711608939], 
             UndirectedEdge[107, 273] -> 
             RGBColor[
              0.32370272298268776`, 0.4483418094779742, 0.9420833765839904], 
             UndirectedEdge[64, 85] -> 
             RGBColor[
              0.2337265149567007, 0.3629917647094177, 0.9366217513081667], 
             UndirectedEdge[175, 224] -> 
             RGBColor[
              0.19563816085584113`, 0.3229584896082839, 0.9344526758887932], 
             UndirectedEdge[68, 163] -> 
             RGBColor[
              0.7490034970690254, 0.8039812828492927, 0.9757174701655251], 
             UndirectedEdge[7, 237] -> 
             RGBColor[
              0.8628230044438239, 0.4470001203594073, 0.4441941754294244], 
             UndirectedEdge[76, 126] -> 
             RGBColor[
              0.2752030578474213, 0.40490613819779253`, 0.9390452958624365], 
             UndirectedEdge[30, 236] -> 
             RGBColor[
              0.2403636886171835, 0.3699678550477007, 0.9369997285293126], 
             UndirectedEdge[7, 269] -> 
             RGBColor[
              0.9557422920381128, 0.9373302721362289, 0.6697719934605999], 
             UndirectedEdge[237, 256] -> 
             RGBColor[
              0.8226924771507464, 0.17542990005333894`, 0.16936364778802923`],
              UndirectedEdge[106, 290] -> 
             RGBColor[
              0.9041357720440601, 0.8589662618992862, 0.6312127071179277], 
             UndirectedEdge[180, 288] -> 
             RGBColor[
              0.20187497125250775`, 0.32951377277179905`, 0.9348078530143491],
              UndirectedEdge[201, 237] -> 
             RGBColor[
              0.8386009494484636, 0.2977093892706047, 0.18459761882637282`], 
             UndirectedEdge[10, 73] -> 
             RGBColor[
              0.18653587436616526`, 0.31339140938933835`, 0.9339343141388322],
              UndirectedEdge[18, 175] -> 
             RGBColor[
              0.19129167307218187`, 0.3183900553644156, 0.9342051498395663], 
             UndirectedEdge[57, 295] -> 
             RGBColor[
              0.1882992367969673, 0.3152448151077469, 0.9340347350206055], 
             UndirectedEdge[71, 161] -> 
             RGBColor[
              0.2124857473818974, 0.34066637124585103`, 0.9354121210176813], 
             UndirectedEdge[218, 220] -> 
             RGBColor[
              0.6501395047208716, 0.7189888396444919, 0.9414344110066938], 
             UndirectedEdge[192, 248] -> 
             RGBColor[
              0.27628801069729353`, 0.4057044446902951, 0.9391196063656152], 
             UndirectedEdge[23, 24] -> 
             RGBColor[
              0.956555334204736, 0.8626596651038085, 0.541866983332811], 
             UndirectedEdge[39, 195] -> 
             RGBColor[
              0.1927241486561343, 0.3198956780273474, 0.9342867272049146], 
             UndirectedEdge[79, 232] -> 
             RGBColor[
              0.1855242988552152, 0.31232817938973806`, 0.9338767064099756], 
             UndirectedEdge[12, 154] -> 
             RGBColor[
              0.46345887168868094`, 0.5746523637299171, 0.9510821144780158], 
             UndirectedEdge[106, 155] -> 
             RGBColor[
              0.8940872222095038, 0.8191271102860018, 0.6231274080512639], 
             UndirectedEdge[95, 103] -> 
             RGBColor[
              0.35444301317126903`, 0.47946333163225574`, 0.9438775064114789],
              UndirectedEdge[3, 228] -> 
             RGBColor[
              0.690237715965832, 0.7545004457298199, 0.955381119587516], 
             UndirectedEdge[81, 293] -> 
             RGBColor[
              0.8946118304119881, 0.61433876058075, 0.23377386680638917`], 
             UndirectedEdge[95, 145] -> 
             RGBColor[
              0.5762301255781173, 0.6573426269684071, 0.963331889789669], 
             UndirectedEdge[39, 153] -> 
             RGBColor[
              0.2113966935997263, 0.3395217066707913, 0.9353501010158973], 
             UndirectedEdge[39, 90] -> 
             RGBColor[
              0.20870014958760652`, 0.3366874679432882, 0.9351965368235865], 
             UndirectedEdge[120, 141] -> 
             RGBColor[
              0.28646903998749706`, 0.4184275025860159, 0.939625360083097], 
             UndirectedEdge[102, 172] -> 
             RGBColor[
              0.19138970866876043`, 0.3184930969922355, 0.9342107328217606], 
             UndirectedEdge[155, 194] -> 
             RGBColor[
              0.8061596900222359, 0.7500989808439875, 0.6144534337056413], 
             UndirectedEdge[53, 251] -> 
             RGBColor[
              0.25074234215186236`, 0.3808764779572891, 0.9375907774942707], 
             UndirectedEdge[128, 243] -> 
             RGBColor[
              0.8924326724712802, 0.5606456544038871, 0.4131747565461786], 
             UndirectedEdge[72, 87] -> 
             RGBColor[
              0.8839929875554634, 0.4806546749192594, 0.28239629153508916`], 
             UndirectedEdge[76, 90] -> 
             RGBColor[
              0.2712969166915207, 0.40080053617928724`, 0.938822846902226], 
             UndirectedEdge[3, 106] -> 
             RGBColor[
              0.9080394881357245, 0.9290324924917327, 0.9745333831638314], 
             UndirectedEdge[104, 243] -> 
             RGBColor[
              0.6612526622734278, 0.7268613939195354, 0.9003802288706013], 
             UndirectedEdge[34, 217] -> 
             RGBColor[
              0.1918655955426979, 0.3189932842697143, 0.9342378338752199], 
             UndirectedEdge[31, 37] -> 
             RGBColor[
              0.32310841403988205`, 0.4466841095652183, 0.9420873563531128], 
             UndirectedEdge[64, 249] -> 
             RGBColor[
              0.22138061658703678`, 0.35001544274773333`, 0.9359186706601341],
              UndirectedEdge[89, 188] -> 
             RGBColor[
              0.3683043792841372, 0.49342847464473716`, 0.9446890072625783], 
             UndirectedEdge[179, 269] -> 
             RGBColor[
              0.7479608310759376, 0.7722887789067958, 0.6529117994592061], 
             UndirectedEdge[213, 249] -> 
             RGBColor[
              0.2049158790401142, 0.33270995966126304`, 0.9349810282142335], 
             UndirectedEdge[44, 252] -> 
             RGBColor[
              0.27708079783829526`, 0.4078689058796433, 0.9391160129735812], 
             UndirectedEdge[149, 198] -> 
             RGBColor[
              0.93004743411723, 0.7957508352156739, 0.5896702154371328], 
             UndirectedEdge[158, 214] -> 
             RGBColor[
              0.19688801935015837`, 0.3242721701314169, 0.9345238534810445], 
             UndirectedEdge[202, 216] -> 
             RGBColor[
              0.8665350630405979, 0.48684871744288943`, 0.21034592388715595`],
              UndirectedEdge[78, 209] -> 
             RGBColor[
              0.18729352981200414`, 0.31418775330104487`, 0.933977461495622], 
             UndirectedEdge[77, 265] -> 
             RGBColor[
              0.31824926646414226`, 0.4421191756626833, 0.9417907774257306], 
             UndirectedEdge[44, 204] -> 
             RGBColor[
              0.39991382818369614`, 0.5199845367377941, 0.9469303798325985], 
             UndirectedEdge[54, 102] -> 
             RGBColor[
              0.218116116310074, 0.34658424597537324`, 0.9357327621987566], 
             UndirectedEdge[2, 253] -> 
             RGBColor[
              0.19522054856906235`, 0.32251955261673115`, 0.9344288934868631],
              UndirectedEdge[40, 86] -> 
             RGBColor[
              0.6417053553097174, 0.7192862820416126, 0.9654274840700409], 
             UndirectedEdge[75, 165] -> 
             RGBColor[
              0.27536181000482485`, 0.4045171817075533, 0.9390746876755028], 
             UndirectedEdge[73, 100] -> 
             RGBColor[
              0.1816658245926822, 0.30827267829841776`, 0.9336569720088254], 
             UndirectedEdge[50, 206] -> 
             RGBColor[
              0.20212300857950383`, 0.32977447572894675`, 0.9348219783731833],
              UndirectedEdge[32, 277] -> 
             RGBColor[
              0.9903436750031767, 0.9883158760637997, 0.6672952315344995], 
             UndirectedEdge[156, 251] -> 
             RGBColor[
              0.3400494072237743, 0.46681610621407393`, 0.942966956843591], 
             UndirectedEdge[31, 44] -> 
             RGBColor[
              0.36793393060354135`, 0.4931076106168971, 0.9446654026002257], 
             UndirectedEdge[80, 92] -> 
             RGBColor[
              0.8806392624507501, 0.47575847385330106`, 0.24262510747050564`],
              UndirectedEdge[11, 149] -> 
             RGBColor[
              0.7136593076403137, 0.6245896318315118, 0.5954018551660852], 
             UndirectedEdge[103, 145] -> 
             RGBColor[
              0.643116750417353, 0.7172355839626725, 0.9675221132384173], 
             UndirectedEdge[150, 274] -> 
             RGBColor[
              0.6852279869066359, 0.622788647378854, 0.5976147565045411], 
             UndirectedEdge[13, 156] -> 
             RGBColor[
              0.3638901315072269, 0.4896050750869218, 0.9444077352975997], 
             UndirectedEdge[84, 278] -> 
             RGBColor[
              0.19404895120727791`, 0.32128812950593255`, 0.9343621727503324],
              UndirectedEdge[150, 293] -> 
             RGBColor[
              0.9035840903340573, 0.6541630034729253, 0.24121312079051388`], 
             UndirectedEdge[52, 137] -> 
             RGBColor[
              0.23013360981142927`, 0.35921539359839394`, 0.9364171406753703],
              UndirectedEdge[41, 152] -> 
             RGBColor[
              0.1855570941414352, 0.31236264931489655`, 0.9338785740530094], 
             UndirectedEdge[177, 279] -> 
             RGBColor[
              0.2643192230897936, 0.3951466406470252, 0.9383639607784904], 
             UndirectedEdge[108, 279] -> 
             RGBColor[
              0.23867609661587075`, 0.3681940888548081, 0.9369036226614065], 
             UndirectedEdge[161, 279] -> 
             RGBColor[
              0.2191606879449377, 0.34768215699328187`, 0.9357922490080568], 
             UndirectedEdge[89, 260] -> 
             RGBColor[
              0.3194559514168667, 0.4464420991230162, 0.9417476517079721], 
             UndirectedEdge[63, 161] -> 
             RGBColor[
              0.19226866060006637`, 0.3194169312008093, 0.9342607878339557], 
             UndirectedEdge[110, 148] -> 
             RGBColor[
              0.2161072361235734, 0.34447278552900074`, 0.9356183594440073], 
             UndirectedEdge[200, 228] -> 
             RGBColor[
              0.3959136886863399, 0.5173422707646859, 0.946448248043733], 
             UndirectedEdge[67, 118] -> 
             RGBColor[
              0.18382399790050605`, 0.31054105528103165`, 0.9337798767859746],
              UndirectedEdge[140, 203] -> 
             RGBColor[
              0.8572543639542931, 0.40696085899210804`, 0.43991699948682417`],
              UndirectedEdge[144, 231] -> 
             RGBColor[
              0.21441031983489064`, 0.34268921891888826`, 0.9355217225717294],
              UndirectedEdge[101, 149] -> 
             RGBColor[
              0.7714159149498363, 0.6714029284596804, 0.6000007099012994], 
             UndirectedEdge[131, 284] -> 
             RGBColor[
              0.23518277089129241`, 0.36452238202863274`, 0.9367046829293041],
              UndirectedEdge[157, 275] -> 
             RGBColor[
              0.18135642915031058`, 0.30794748407168115`, 0.9336393523960919],
              UndirectedEdge[113, 144] -> 
             RGBColor[
              0.23263625868922916`, 0.36184583624606526`, 0.9365596628266237],
              UndirectedEdge[48, 73] -> 
             RGBColor[
              0.187739347830093, 0.31465633630455114`, 0.9340028501722235], 
             UndirectedEdge[35, 183] -> 
             RGBColor[
              0.19956688605797046`, 0.32708782889128674`, 0.9346764109770263],
              UndirectedEdge[93, 107] -> 
             RGBColor[
              0.32480267899707094`, 0.44949793299033025`, 0.9421460174517705],
              UndirectedEdge[23, 226] -> 
             RGBColor[
              0.9878018957897885, 0.9892237846791677, 0.8518176846523693], 
             UndirectedEdge[200, 211] -> 
             RGBColor[
              0.31815152117452855`, 0.44647400293362227`, 0.9416219977306357],
              UndirectedEdge[87, 227] -> 
             RGBColor[
              0.9729262687384115, 0.9189743901826695, 0.3881944192270413], 
             UndirectedEdge[223, 278] -> 
             RGBColor[
              0.1910601770666856, 0.31814673838494456`, 0.9341919664845209], 
             UndirectedEdge[182, 229] -> 
             RGBColor[
              0.23602797859295035`, 0.36541074891233866`, 0.9367528162575407],
              UndirectedEdge[79, 221] -> 
             RGBColor[
              0.18466822464384994`, 0.3114283911153532, 0.9338279542500865], 
             UndirectedEdge[115, 228] -> 
             RGBColor[
              0.3889928994532643, 0.5113478309799768, 0.946007261473615], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.3382052536051789, 0.4616299042238716, 0.9429808558058818], 
             UndirectedEdge[9, 47] -> 
             RGBColor[
              0.1915298565644043, 0.31864040131644705`, 0.9342187140370874], 
             UndirectedEdge[18, 224] -> 
             RGBColor[
              0.2043212377981297, 0.33208495401350496`, 0.9349471642751953], 
             UndirectedEdge[194, 291] -> 
             RGBColor[
              0.8064401830754907, 0.8495804260163464, 0.9811128108192658], 
             UndirectedEdge[5, 198] -> 
             RGBColor[
              0.967801874456065, 0.9434968913498611, 0.6433562360480443], 
             UndirectedEdge[49, 172] -> 
             RGBColor[
              0.20010293929950806`, 0.3276512548358813, 0.9347069384161122], 
             UndirectedEdge[162, 228] -> 
             RGBColor[
              0.7088026697373979, 0.7671572402491821, 0.8707133358632482], 
             UndirectedEdge[100, 161] -> 
             RGBColor[
              0.1911587437240086, 0.318250338191278, 0.9341975797098391], 
             UndirectedEdge[174, 235] -> 
             RGBColor[
              0.3208493079592518, 0.4453409740728014, 0.9419209416251387], 
             UndirectedEdge[14, 67] -> 
             RGBColor[
              0.17956042552731538`, 0.30605977039070653`, 0.9335370726467116],
              UndirectedEdge[190, 199] -> 
             RGBColor[
              0.2014046269978636, 0.3290194111386199, 0.9347810676048591], 
             UndirectedEdge[160, 288] -> 
             RGBColor[
              0.20231487113075944`, 0.32997613543510473`, 0.934832904661642], 
             UndirectedEdge[33, 275] -> 
             RGBColor[
              0.19034059746125545`, 0.31739041459565537`, 0.9341509874905143],
              UndirectedEdge[109, 218] -> 
             RGBColor[
              0.9800003657513711, 0.9831729301139916, 0.8546124313811914], 
             UndirectedEdge[231, 264] -> 
             RGBColor[
              0.2636953407278438, 0.39449090072818943`, 0.9383284316009286], 
             UndirectedEdge[221, 230] -> 
             RGBColor[
              0.18914056303198, 0.3161291023239095, 0.9340826473050587], 
             UndirectedEdge[45, 236] -> 
             RGBColor[
              0.26568284234196243`, 0.3965798909395088, 0.9384416168776075], 
             UndirectedEdge[279, 280] -> 
             RGBColor[
              0.24933981979070619`, 0.37940233803066026`, 0.9375109059206487],
              UndirectedEdge[71, 252] -> 
             RGBColor[
              0.23062956346731406`, 0.3597366723360068, 0.9364453845023752], 
             UndirectedEdge[230, 296] -> 
             RGBColor[
              0.18964632804218584`, 0.3166606934169896, 0.9341114498741778], 
             UndirectedEdge[27, 154] -> 
             RGBColor[
              0.7335695588322665, 0.7563490417801518, 0.6454543011351679], 
             UndirectedEdge[5, 101] -> 
             RGBColor[
              0.8091703552886713, 0.8191489845938676, 0.6536867305122107], 
             UndirectedEdge[68, 143] -> 
             RGBColor[
              0.5918755827726521, 0.672270845358494, 0.9644525615859105], 
             UndirectedEdge[58, 221] -> 
             RGBColor[
              0.18866826221874242`, 0.3156326842235957, 0.9340557504724514], 
             UndirectedEdge[85, 249] -> 
             RGBColor[
              0.21980259172524277`, 0.34835683856543287`, 0.9358288044787336],
              UndirectedEdge[26, 54] -> 
             RGBColor[
              0.23656624471631046`, 0.3659765007360335, 0.9367834697169728], 
             UndirectedEdge[269, 282] -> 
             RGBColor[
              0.7068985223577822, 0.7386080961972126, 0.6497743968433352], 
             UndirectedEdge[24, 210] -> 
             RGBColor[
              0.6977215322082554, 0.6587130381270785, 0.6045341943932525], 
             UndirectedEdge[144, 288] -> 
             RGBColor[
              0.20325262345727604`, 0.33096177258720527`, 0.9348863082693568],
              UndirectedEdge[182, 199] -> 
             RGBColor[
              0.22636918605193562`, 0.35525874554891435`, 0.936202762311233], 
             UndirectedEdge[35, 224] -> 
             RGBColor[
              0.20753059097457632`, 0.33545818768669444`, 0.9351299321907813],
              UndirectedEdge[161, 280] -> 
             RGBColor[
              0.2318337811627876, 0.36100238148576125`, 0.9365139629186521], 
             UndirectedEdge[27, 42] -> 
             RGBColor[
              0.8816836574994876, 0.49667817991020385`, 0.23487588344630034`],
              UndirectedEdge[13, 273] -> 
             RGBColor[
              0.2861094453581625, 0.4157804018926833, 0.9396879661761859], 
             UndirectedEdge[167, 202] -> 
             RGBColor[
              0.8802744981433329, 0.5485728040784057, 0.22177612422766013`], 
             UndirectedEdge[117, 207] -> 
             RGBColor[
              0.18539878883552113`, 0.3121962604012447, 0.9338695588000294], 
             UndirectedEdge[33, 248] -> 
             RGBColor[
              0.21123257741316134`, 0.3393492101531443, 0.9353407548418606], 
             UndirectedEdge[23, 210] -> 
             RGBColor[
              0.7305128529889463, 0.7859159553283347, 0.8888842381324313], 
             UndirectedEdge[54, 111] -> 
             RGBColor[
              0.4291203016109882, 0.5357529458181629, 0.9499902123364491], 
             UndirectedEdge[30, 267] -> 
             RGBColor[
              0.22275125819820335`, 0.35145607398476686`, 0.9359967266722076],
              UndirectedEdge[170, 199] -> 
             RGBColor[
              0.19798561422584082`, 0.3254258119372937, 0.9345863598854686], 
             UndirectedEdge[169, 200] -> 
             RGBColor[
              0.4851546386974715, 0.5905268621408066, 0.9532706039694929], 
             UndirectedEdge[137, 278] -> 
             RGBColor[
              0.23108207251171536`, 0.3602122880324031, 0.9364711542230267], 
             UndirectedEdge[92, 150] -> 
             RGBColor[
              0.856839597699243, 0.38590456876888285`, 0.2000192899179641], 
             UndirectedEdge[68, 185] -> 
             RGBColor[
              0.7032065232894661, 0.766801236404889, 0.9721121646297556], 
             UndirectedEdge[26, 102] -> 
             RGBColor[
              0.21064547425155244`, 0.3387321275058029, 0.9353073201853483], 
             UndirectedEdge[270, 271] -> 
             RGBColor[
              0.217737181833685, 0.3461859618148549, 0.9357111824409096], 
             UndirectedEdge[169, 202] -> 
             RGBColor[
              0.7792934779313432, 0.5546715851773875, 0.4609259309301712], 
             UndirectedEdge[17, 97] -> 
             RGBColor[
              0.5762606506463335, 0.665813185958444, 0.9604600233988309], 
             UndirectedEdge[46, 158] -> 
             RGBColor[
              0.1988271914603046, 0.32631036296979365`, 0.9346342864639694], 
             UndirectedEdge[98, 285] -> 
             RGBColor[
              0.18936585526810354`, 0.31636589874842813`, 0.9340954773646161],
              UndirectedEdge[77, 168] -> 
             RGBColor[
              0.4070970567080353, 0.527028742052658, 0.9471608423650113], 
             UndirectedEdge[242, 268] -> 
             RGBColor[0.1929658134251674, 0.3201496830220325, 0.934300489656],
              UndirectedEdge[115, 134] -> 
             RGBColor[
              0.29826389721871693`, 0.4268505977105114, 0.940442569105771], 
             UndirectedEdge[99, 284] -> 
             RGBColor[
              0.2183159570292897, 0.34679429124190236`, 0.9357441428320781], 
             UndirectedEdge[204, 283] -> 
             RGBColor[
              0.3947145595034514, 0.515210734660812, 0.9466089897806659], 
             UndirectedEdge[77, 167] -> 
             RGBColor[
              0.6607323580564698, 0.6022582598273698, 0.5960819189651536], 
             UndirectedEdge[227, 290] -> 
             RGBColor[
              0.9495577123496941, 0.837720168902116, 0.27827115520513895`], 
             UndirectedEdge[60, 145] -> 
             RGBColor[
              0.5760856373176906, 0.6571907606456139, 0.9633236613969889], 
             UndirectedEdge[32, 125] -> 
             RGBColor[
              0.8860217022210372, 0.5107410708294523, 0.40552418405157087`], 
             UndirectedEdge[15, 60] -> 
             RGBColor[
              0.27282174145117777`, 0.4040833265356404, 0.9388481666208225], 
             UndirectedEdge[30, 260] -> 
             RGBColor[
              0.25373200019445147`, 0.38401879811531836`, 0.9377610340969933],
              UndirectedEdge[42, 80] -> 
             RGBColor[
              0.8846726257638872, 0.5067606717091464, 0.24648746073419803`], 
             UndirectedEdge[97, 130] -> 
             RGBColor[
              0.6803306714803544, 0.6256180746890865, 0.5988573985297044], 
             UndirectedEdge[65, 211] -> 
             RGBColor[
              0.3240980577045407, 0.45162459399430244`, 0.9420009057800123], 
             UndirectedEdge[1, 256] -> 
             RGBColor[
              0.8184383049744752, 0.1427304685163843, 0.1652898477076317], 
             UndirectedEdge[5, 128] -> 
             RGBColor[
              0.8869643989845882, 0.5355844211628931, 0.24107549480357243`], 
             UndirectedEdge[125, 256] -> 
             RGBColor[
              0.8294390160964316, 0.2272867547420918, 0.17582414110154324`], 
             UndirectedEdge[39, 239] -> 
             RGBColor[
              0.2196501555680895, 0.3481966184992542, 0.9358201234650929], 
             UndirectedEdge[156, 269] -> 
             RGBColor[
              0.6838282108058124, 0.7186257518784704, 0.6483043769915192], 
             UndirectedEdge[78, 170] -> 
             RGBColor[
              0.19585393495458225`, 0.32318528186692885`, 0.9344649639045073],
              UndirectedEdge[23, 155] -> 
             RGBColor[
              0.9578302462805677, 0.8677142666452164, 0.5428928075150579], 
             UndirectedEdge[127, 251] -> 
             RGBColor[
              0.31722126846433096`, 0.4470435197962596, 0.9415123680279698], 
             UndirectedEdge[241, 290] -> 
             RGBColor[
              0.9662675720592777, 0.9068871357048387, 0.5776802589012907], 
             UndirectedEdge[85, 234] -> 
             RGBColor[
              0.21315182719847248`, 0.341366463364971, 0.9354500532778585], 
             UndirectedEdge[270, 289] -> 
             RGBColor[
              0.22814186813803294`, 0.35712194681593845`, 0.9363037139335881],
              UndirectedEdge[69, 258] -> 
             RGBColor[
              0.273865191252875, 0.4022754790002804, 0.9390139404249507], 
             UndirectedEdge[52, 289] -> 
             RGBColor[
              0.22108882372044908`, 0.3497087499442134, 0.9359020534880509], 
             UndirectedEdge[47, 170] -> 
             RGBColor[
              0.1908380369178425, 0.3179132550040116, 0.9341793159316711], 
             UndirectedEdge[72, 241] -> 
             RGBColor[
              0.8816517065059561, 0.48091378172749166`, 0.4104081640603793], 
             UndirectedEdge[115, 210] -> 
             RGBColor[
              0.4117038936977402, 0.5305204071243743, 0.9475921355741658], 
             UndirectedEdge[166, 239] -> 
             RGBColor[
              0.21183524129599424`, 0.3399826481050988, 0.9353750756584267], 
             UndirectedEdge[180, 215] -> 
             RGBColor[
              0.2098131605219987, 0.33785731300430355`, 0.9352599211497481], 
             UndirectedEdge[51, 254] -> 
             RGBColor[
              0.5650392887707011, 0.6515224922377361, 0.9616798049124837], 
             UndirectedEdge[109, 227] -> 
             RGBColor[
              0.9727578246301442, 0.9207456642506578, 0.5248021537611475], 
             UndirectedEdge[203, 255] -> 
             RGBColor[
              0.651571481892223, 0.7220382969334023, 0.9679291557478935], 
             UndirectedEdge[257, 272] -> 
             RGBColor[
              0.18158199985616474`, 0.30818457318554265`, 0.9336521983140883],
              UndirectedEdge[32, 128] -> 
             RGBColor[
              0.8925188906026889, 0.5606813078169296, 0.41174589898336517`], 
             UndirectedEdge[39, 76] -> 
             RGBColor[
              0.26432098730221126`, 0.39346839209165385`, 0.9384255780434674],
              UndirectedEdge[144, 221] -> 
             RGBColor[
              0.19191775891044247`, 0.3190481112765624, 0.9342408045018441], 
             UndirectedEdge[165, 262] -> 
             RGBColor[
              0.26081704104435255`, 0.39146562526609985`, 0.9381645166920165],
              UndirectedEdge[101, 226] -> 
             RGBColor[
              0.8167925796772653, 0.8565009126998259, 0.9214508039916728], 
             UndirectedEdge[56, 191] -> 
             RGBColor[
              0.21336670196225918`, 0.34159231036555776`, 0.9354622900777774],
              UndirectedEdge[63, 71] -> 
             RGBColor[
              0.20309975866494467`, 0.3308011019982774, 0.9348776028455769], 
             UndirectedEdge[137, 289] -> 
             RGBColor[
              0.25248937634424146`, 0.382712721661845, 0.9376902685070212], 
             UndirectedEdge[148, 295] -> 
             RGBColor[
              0.2216100316720449, 0.3502565725478334, 0.9359317355098362], 
             UndirectedEdge[10, 119] -> 
             RGBColor[
              0.1856272606689936, 0.3124363987841752, 0.9338825699329518], 
             UndirectedEdge[115, 231] -> 
             RGBColor[
              0.29145473297171365`, 0.41969373436096236`, 0.9400547972751598],
              UndirectedEdge[33, 171] -> 
             RGBColor[
              0.189827260881899, 0.31685086530333273`, 0.9341217537317332], 
             UndirectedEdge[173, 234] -> 
             RGBColor[
              0.19772105404463286`, 0.3251477424127598, 0.9345712935745305], 
             UndirectedEdge[69, 173] -> 
             RGBColor[
              0.2044279033465657, 0.3321970662678976, 0.9349532387203812], 
             UndirectedEdge[4, 263] -> 
             RGBColor[
              0.21521347097412877`, 0.3435333816889509, 0.9355674608409534], 
             UndirectedEdge[134, 160] -> 
             RGBColor[
              0.22028173175537732`, 0.3488604451163368, 0.9358560907946256], 
             UndirectedEdge[7, 205] -> 
             RGBColor[
              0.6553396994405775, 0.7252302520430189, 0.9671201357047186], 
             UndirectedEdge[23, 106] -> 
             RGBColor[
              0.9256036309143629, 0.94127542594585, 0.906451627608196], 
             UndirectedEdge[45, 96] -> 
             RGBColor[
              0.2504426073839444, 0.3805614377119254, 0.9375737080426556], 
             UndirectedEdge[65, 210] -> 
             RGBColor[
              0.424571219460828, 0.5416654379697635, 0.9484120301936603], 
             UndirectedEdge[138, 211] -> 
             RGBColor[
              0.25101026684268113`, 0.38115808379474614`, 0.9376060354090536],
              UndirectedEdge[72, 210] -> 
             RGBColor[
              0.7101699878788666, 0.345393552112113, 0.4343848698876275], 
             UndirectedEdge[37, 41] -> 
             RGBColor[
              0.20758147265742513`, 0.3355116675614536, 0.9351328298273469], 
             UndirectedEdge[52, 88] -> 
             RGBColor[
              0.21079575741608964`, 0.3388900846402345, 0.9353158785892447], 
             UndirectedEdge[157, 285] -> 
             RGBColor[
              0.1911088793151014, 0.31819792753593046`, 0.9341947400055196], 
             UndirectedEdge[135, 265] -> 
             RGBColor[
              0.21789617448484386`, 0.3463530731719392, 0.9357202368371844], 
             UndirectedEdge[17, 42] -> 
             RGBColor[
              0.7929575364765972, 0.44951011621237846`, 0.44612850273328253`],
              UndirectedEdge[242, 250] -> 
             RGBColor[
              0.18176798085569046`, 0.30838005100792065`, 0.933662789656877], 
             UndirectedEdge[81, 202] -> 
             RGBColor[
              0.8742021218716074, 0.5216630409074182, 0.2167435057125596], 
             UndirectedEdge[229, 259] -> 
             RGBColor[
              0.2014368212026378, 0.32905324928906804`, 0.934782901017194], 
             UndirectedEdge[40, 81] -> 
             RGBColor[
              0.7893492688527326, 0.6740607768287987, 0.5995695817860118], 
             UndirectedEdge[100, 119] -> 
             RGBColor[
              0.1807572108955105, 0.3073176676932546, 0.933605227802945], 
             UndirectedEdge[81, 269] -> 
             RGBColor[
              0.931314896123058, 0.7560543834090069, 0.28986513111217527`], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.8156793803955554, 0.4095785742701399, 0.4412265840334828], 
             UndirectedEdge[180, 233] -> 
             RGBColor[
              0.20014010875548707`, 0.32769032229079487`, 0.9347090551616429],
              UndirectedEdge[33, 184] -> 
             RGBColor[
              0.1959981041281816, 0.3233368128092353, 0.9344731741256647], 
             UndirectedEdge[103, 168] -> 
             RGBColor[
              0.41087052923769096`, 0.5302971342976018, 0.9474012846978503], 
             UndirectedEdge[49, 238] -> 
             RGBColor[
              0.19853266531396374`, 0.3260007973159532, 0.9346175136356476], 
             UndirectedEdge[97, 120] -> 
             RGBColor[
              0.3639742346570427, 0.4869360497143149, 0.944513487615392], 
             UndirectedEdge[117, 212] -> 
             RGBColor[
              0.20943922968905518`, 0.3374642879902957, 0.935238626341993], 
             UndirectedEdge[270, 278] -> 
             RGBColor[
              0.20673456430550685`, 0.3346215131864966, 0.9350845996495938], 
             UndirectedEdge[26, 165] -> 
             RGBColor[
              0.2234449255941841, 0.3521851623989958, 0.9360362300042198], 
             UndirectedEdge[65, 70] -> 
             RGBColor[
              0.2936166091660087, 0.41958665894484415`, 0.940265032379005], 
             UndirectedEdge[56, 223] -> 
             RGBColor[
              0.19042353178656807`, 0.3174775838298989, 0.9341557104776503], 
             UndirectedEdge[207, 212] -> 
             RGBColor[
              0.20932819464730518`, 0.33734758312138824`, 0.935232303060627], 
             UndirectedEdge[171, 184] -> 
             RGBColor[
              0.1853189372548359, 0.31211233132706184`, 0.9338650113706392], 
             UndirectedEdge[32, 205] -> 
             RGBColor[
              0.6800179376878698, 0.7430563957149572, 0.8994244086676673], 
             UndirectedEdge[23, 31] -> 
             RGBColor[
              0.7044976010018857, 0.7638813972041334, 0.8870888196503636], 
             UndirectedEdge[235, 274] -> 
             RGBColor[
              0.43577020330018756`, 0.5515998272739158, 0.9490608562281224], 
             UndirectedEdge[178, 199] -> 
             RGBColor[
              0.2287030477407748, 0.357711782159262, 0.9363356722817735], 
             UndirectedEdge[117, 158] -> 
             RGBColor[
              0.189227738636957, 0.3162207294119929, 0.9340876118267976], 
             UndirectedEdge[112, 190] -> 
             RGBColor[
              0.19682291342577818`, 0.3242037396769393, 0.9345201457949667], 
             UndirectedEdge[64, 213] -> 
             RGBColor[
              0.21883980227157213`, 0.34734488580524786`, 0.9357739750436664],
              UndirectedEdge[127, 205] -> 
             RGBColor[
              0.3605974794488338, 0.48675314536744607`, 0.9441979304200168], 
             UndirectedEdge[121, 263] -> 
             RGBColor[
              0.2176693590934683, 0.34611467581467703`, 0.935707320036189], 
             UndirectedEdge[14, 213] -> 
             RGBColor[
              0.19128445788964016`, 0.31838247175009526`, 0.9342047389455943],
              UndirectedEdge[109, 111] -> 
             RGBColor[
              0.8035074391264327, 0.8444862586698714, 0.8657863480729937], 
             UndirectedEdge[55, 108] -> 
             RGBColor[
              0.22141119699588285`, 0.35004758469634045`, 0.9359204121691784],
              UndirectedEdge[40, 162] -> 
             RGBColor[
              0.8402909601650888, 0.8739220660440041, 0.881352498558146], 
             UndirectedEdge[15, 225] -> 
             RGBColor[
              0.2429863506332136, 0.37272443911292436`, 0.9371490852512447], 
             UndirectedEdge[31, 59] -> 
             RGBColor[
              0.7023281164542653, 0.7629842595904825, 0.9230427930504692], 
             UndirectedEdge[210, 227] -> 
             RGBColor[
              0.7121917692235163, 0.7160827059719499, 0.6161772867558488], 
             UndirectedEdge[52, 93] -> 
             RGBColor[
              0.21993156031517644`, 0.348492392730534, 0.9358361490491385], 
             UndirectedEdge[32, 293] -> 
             RGBColor[
              0.9437174645743351, 0.8134407929799102, 0.5459850021177625], 
             UndirectedEdge[99, 209] -> 
             RGBColor[
              0.18806492725905072`, 0.31499854092731383`, 0.934021391439051], 
             UndirectedEdge[201, 299] -> 
             RGBColor[
              0.8364740278506779, 0.2813609378470366, 0.18256087630231885`], 
             UndirectedEdge[127, 148] -> 
             RGBColor[
              0.29756624946408855`, 0.42638484862682313`, 0.9403930437729009],
              UndirectedEdge[24, 226] -> 
             RGBColor[
              0.9550105750090976, 0.8620208674779115, 0.5674676409131905], 
             UndirectedEdge[144, 264] -> 
             RGBColor[
              0.24692493102232177`, 0.3768641368222969, 0.9373733815777969], 
             UndirectedEdge[148, 217] -> 
             RGBColor[
              0.22316774867338707`, 0.35189383188120626`, 0.9360204451886269],
              UndirectedEdge[230, 288] -> 
             RGBColor[
              0.2004754275788136, 0.3280427636345524, 0.9347281510725716], 
             UndirectedEdge[1, 83] -> 
             RGBColor[
              0.827979798814962, 0.21607057128362597`, 0.1744267929848577], 
             UndirectedEdge[15, 214] -> 
             RGBColor[
              0.22960322819742474`, 0.35865792889393855`, 0.936386936227082], 
             UndirectedEdge[173, 249] -> 
             RGBColor[
              0.20437181857140313`, 0.33213811761322165`, 0.9349500447754056],
              UndirectedEdge[114, 204] -> 
             RGBColor[
              0.3613702020678383, 0.4801637008416135, 0.944710077953264], 
             UndirectedEdge[77, 95] -> 
             RGBColor[
              0.3506695406416134, 0.476194939387312, 0.94363706407864], 
             UndirectedEdge[52, 295] -> 
             RGBColor[
              0.19782793389837072`, 0.3252600799156124, 0.9345773802240863], 
             UndirectedEdge[7, 103] -> 
             RGBColor[
              0.6798246620935919, 0.7464378960430543, 0.9686802958737664], 
             UndirectedEdge[29, 99] -> 
             RGBColor[
              0.19546469586089602`, 0.32277616690028066`, 0.9344427973139495],
              UndirectedEdge[28, 144] -> 
             RGBColor[
              0.19055497770725674`, 0.3176157418266954, 0.9341631961283768], 
             UndirectedEdge[75, 185] -> 
             RGBColor[
              0.43124290556454353`, 0.5458726103470143, 0.9492713561429931], 
             UndirectedEdge[227, 291] -> 
             RGBColor[
              0.9397896555683924, 0.8973624624611904, 0.6368452332520997], 
             UndirectedEdge[76, 192] -> 
             RGBColor[
              0.32876752436481727`, 0.45918363809373036`, 0.9421697538281874],
              UndirectedEdge[59, 72] -> 
             RGBColor[
              0.8812795328447734, 0.4807598783541659, 0.416576044780737], 
             UndirectedEdge[104, 254] -> 
             RGBColor[
              0.32693482661477913`, 0.45759624741671456`, 0.942052975948146], 
             UndirectedEdge[32, 237] -> 
             RGBColor[
              0.879275163275352, 0.4588842161406994, 0.3990636907380568], 
             UndirectedEdge[25, 232] -> 
             RGBColor[
              0.1895116930698092, 0.31651918352467145`, 0.9341037826116756], 
             UndirectedEdge[9, 141] -> 
             RGBColor[
              0.24640393833854723`, 0.3763165404788058, 0.9373437118151957], 
             UndirectedEdge[22, 48] -> 
             RGBColor[
              0.19067565939696252`, 0.3177425859342372, 0.934170068772073], 
             UndirectedEdge[25, 160] -> 
             RGBColor[
              0.19344001775085345`, 0.32064810183461934`, 0.9343274948908254],
              UndirectedEdge[72, 106] -> 
             RGBColor[
              0.8402305064958111, 0.44896653252378993`, 0.44609646287147053`],
              UndirectedEdge[4, 186] -> 
             RGBColor[
              0.2068268311149634, 0.334718491453289, 0.9350898541078958], 
             UndirectedEdge[78, 182] -> 
             RGBColor[
              0.22423750678067705`, 0.3530182154785495, 0.9360813663302717], 
             UndirectedEdge[106, 211] -> 
             RGBColor[
              0.5662966671615951, 0.6472879549936589, 0.9627077142549896], 
             UndirectedEdge[180, 245] -> 
             RGBColor[
              0.2100635516260986, 0.3381204899304254, 0.9352741805527061], 
             UndirectedEdge[136, 280] -> 
             RGBColor[
              0.32731420410911033`, 0.4536040519351767, 0.9422353549515605], 
             UndirectedEdge[82, 140] -> 
             RGBColor[
              0.7493592164876164, 0.32177032281068196`, 0.43038245426354804`],
              UndirectedEdge[50, 219] -> 
             RGBColor[
              0.1830787781409705, 0.30975778206409804`, 0.9337374376231229], 
             UndirectedEdge[251, 278] -> 
             RGBColor[
              0.24311863666183964`, 0.372863480116429, 0.9371566187448754], 
             UndirectedEdge[80, 150] -> 
             RGBColor[
              0.9431089113179686, 0.8053970694161215, 0.30826637148751795`], 
             UndirectedEdge[26, 183] -> 
             RGBColor[
              0.21091795920318307`, 0.3390185264665105, 0.9353228378002383], 
             UndirectedEdge[243, 256] -> 
             RGBColor[
              0.874424572290644, 0.42222750521570074`, 0.3959301794759612], 
             UndirectedEdge[184, 248] -> 
             RGBColor[
              0.20672425378609824`, 0.33461067617687346`, 0.9350840124807664],
              UndirectedEdge[4, 255] -> 
             RGBColor[
              0.2932777706676125, 0.42028873435652747`, 0.9402069895504767], 
             UndirectedEdge[37, 280] -> 
             RGBColor[
              0.2442905970349878, 0.3740952847751871, 0.9372233601543662], 
             UndirectedEdge[188, 260] -> 
             RGBColor[
              0.3070159863730502, 0.43566722665288543`, 0.9409549881356092], 
             UndirectedEdge[70, 266] -> 
             RGBColor[
              0.20395979058864, 0.33170505007925455`, 0.934926580391328], 
             UndirectedEdge[103, 127] -> 
             RGBColor[
              0.3850824421018483, 0.5079607893674816, 0.9457580905890645], 
             UndirectedEdge[37, 268] -> 
             RGBColor[
              0.21580890611804032`, 0.3441592217779706, 0.9356013699915318], 
             UndirectedEdge[186, 196] -> 
             RGBColor[
              0.19808785672818557`, 0.32553327528980713`, 0.9345921824447229],
              UndirectedEdge[139, 274] -> 
             RGBColor[
              0.4518848560948061, 0.5655575295786147, 0.9500876676545675], 
             UndirectedEdge[15, 255] -> 
             RGBColor[
              0.31219697150637127`, 0.44017401398467865`, 0.9412844100497945],
              UndirectedEdge[118, 195] -> 
             RGBColor[
              0.18622253645749176`, 0.31306207138055164`, 0.9339164700084752],
              UndirectedEdge[125, 128] -> 
             RGBColor[
              0.8384430661867497, 0.296495829336185, 0.18444642963665195`], 
             UndirectedEdge[61, 177] -> 
             RGBColor[
              0.2846154792944696, 0.4164792927751083, 0.9395198025437264], 
             UndirectedEdge[117, 276] -> 
             RGBColor[
              0.21344183559868857`, 0.34167128058119267`, 0.9354665688272218],
              UndirectedEdge[7, 154] -> 
             RGBColor[
              0.7178086500945909, 0.778143567686985, 0.971430549102502], 
             UndirectedEdge[59, 198] -> 
             RGBColor[
              0.974799373492677, 0.9805904794680657, 0.9214736253472325], 
             UndirectedEdge[83, 197] -> 
             RGBColor[
              0.8931489612206265, 0.5687594209510818, 0.42014697935815], 
             UndirectedEdge[243, 283] -> 
             RGBColor[
              0.6466191425526432, 0.7139161177704824, 0.899457696684746], 
             UndirectedEdge[95, 225] -> 
             RGBColor[
              0.2575765092536425, 0.3880596208924811, 0.9379799732004728], 
             UndirectedEdge[21, 74] -> 
             RGBColor[
              0.19973960321144332`, 0.32726936557048675`, 0.9346862469634045],
              UndirectedEdge[62, 225] -> 
             RGBColor[
              0.21463682483983898`, 0.34292729004033573`, 0.9355346216966771],
              UndirectedEdge[236, 267] -> 
             RGBColor[
              0.21381850493226368`, 0.3420671839329953, 0.9354880195885366], 
             UndirectedEdge[123, 300] -> 
             RGBColor[
              0.21212454910682327`, 0.34028672895745476`, 0.9353915513102607],
              UndirectedEdge[111, 218] -> 
             RGBColor[
              0.7906966430720825, 0.8363639438748425, 0.9515975962507148], 
             UndirectedEdge[61, 161] -> 
             RGBColor[
              0.23945694414961366`, 0.369014809121365, 0.9369480907732928], 
             UndirectedEdge[58, 180] -> 
             RGBColor[
              0.1930127612329003, 0.32019902814462275`, 0.9343031632641974], 
             UndirectedEdge[188, 236] -> 
             RGBColor[
              0.29364767479578224`, 0.42161628358526776`, 0.9401936825679285],
              UndirectedEdge[41, 268] -> 
             RGBColor[
              0.19682209771404596`, 0.32420288231218963`, 0.9345200993413902],
              UndirectedEdge[65, 138] -> 
             RGBColor[
              0.30437559706733064`, 0.4308950373883661, 0.9408777408234891], 
             UndirectedEdge[241, 291] -> 
             RGBColor[
              0.956499515277976, 0.9665294292639133, 0.9362543369482514], 
             UndirectedEdge[270, 295] -> 
             RGBColor[
              0.20488097831595456`, 0.3326732767873375, 0.9349790406696236], 
             UndirectedEdge[127, 212] -> 
             RGBColor[
              0.2911019408470156, 0.4195904504094406, 0.9400249109602461], 
             UndirectedEdge[105, 274] -> 
             RGBColor[
              0.373443394956703, 0.4953127699434419, 0.9451737605551122], 
             UndirectedEdge[128, 142] -> 
             RGBColor[
              0.839938700425626, 0.30799192948729065`, 0.18587865067287715`], 
             UndirectedEdge[38, 57] -> 
             RGBColor[
              0.18289757268776397`, 0.30956732364368866`, 0.9337271182406324],
              UndirectedEdge[135, 255] -> 
             RGBColor[
              0.28954719045708177`, 0.4163676580228129, 0.9399945385263857], 
             UndirectedEdge[46, 196] -> 
             RGBColor[
              0.2038842250820344, 0.33162562594068223`, 0.9349222770475161], 
             UndirectedEdge[138, 210] -> 
             RGBColor[
              0.35148342859896836`, 0.4711989277702072, 0.9440171598227016], 
             UndirectedEdge[72, 109] -> 
             RGBColor[
              0.8838806914832852, 0.4818355242979183, 0.3734681145578266], 
             UndirectedEdge[277, 282] -> 
             RGBColor[
              0.7168216670755537, 0.7717675564528452, 0.7149933619542863], 
             UndirectedEdge[62, 117] -> 
             RGBColor[
              0.1935934216908487, 0.32080933910192594`, 0.9343362310182673], 
             UndirectedEdge[33, 126] -> 
             RGBColor[
              0.2119973945219809, 0.3401530814267192, 0.9353843100447624], 
             UndirectedEdge[217, 278] -> 
             RGBColor[
              0.20033411359999898`, 0.32789423368299453`, 0.9347201034505334],
              UndirectedEdge[228, 264] -> 
             RGBColor[
              0.3612335072093944, 0.48614499734720384`, 0.9442808957993838], 
             UndirectedEdge[121, 239] -> 
             RGBColor[
              0.2315127682951095, 0.3606649766084402, 0.9364956817107337], 
             UndirectedEdge[56, 84] -> 
             RGBColor[
              0.1934123059271604, 0.32061897495088687`, 0.9343259167434621], 
             UndirectedEdge[45, 120] -> 
             RGBColor[
              0.2895125289687292, 0.4216264024736376, 0.9397986822781397], 
             UndirectedEdge[67, 234] -> 
             RGBColor[
              0.18654108215101917`, 0.31339688310141245`, 0.9339346107144755],
              UndirectedEdge[153, 192] -> 
             RGBColor[
              0.2758432306623323, 0.4052369526728678, 0.9390942768006172], 
             UndirectedEdge[77, 127] -> 
             RGBColor[
              0.3813089695721926, 0.5046923971225378, 0.9455176482562255], 
             UndirectedEdge[36, 152] -> 
             RGBColor[
              0.18192632080115292`, 0.3085464763299341, 0.9336718068825283], 
             UndirectedEdge[22, 122] -> 
             RGBColor[
              0.18679089642314464`, 0.31365945374055604`, 0.9339488372677058],
              UndirectedEdge[68, 218] -> 
             RGBColor[
              0.9220230883129681, 0.9398481441591451, 0.964270119789284], 
             UndirectedEdge[56, 148] -> 
             RGBColor[
              0.2228269723814797, 0.3515356543919468, 0.936001038482936], 
             UndirectedEdge[7, 130] -> 
             RGBColor[
              0.92506143421404, 0.8207777707366587, 0.6185929179813181], 
             UndirectedEdge[58, 296] -> 
             RGBColor[
              0.18917402722894824`, 0.3161642753166758, 0.9340845530415703], 
             UndirectedEdge[104, 116] -> 
             RGBColor[
              0.3112198168736299, 0.4420066574870038, 0.9411240550973782], 
             UndirectedEdge[252, 279] -> 
             RGBColor[
              0.23730450403035436`, 0.36675245808343765`, 0.9368255124927507],
              UndirectedEdge[64, 173] -> 
             RGBColor[
              0.21829574180286104`, 0.34677304375720647`, 0.9357429916048386],
              UndirectedEdge[109, 155] -> 
             RGBColor[
              0.9595624996907148, 0.8684305979471943, 0.514184885580798], 
             UndirectedEdge[151, 258] -> 
             RGBColor[
              0.4689947888884989, 0.5767176597098022, 0.9521890651333698], 
             UndirectedEdge[167, 216] -> 
             RGBColor[
              0.8802031529562763, 0.5482488422470734, 0.22171659205474953`], 
             UndirectedEdge[12, 258] -> 
             RGBColor[
              0.3848908244823526, 0.507794819816456, 0.9457458808837911], 
             UndirectedEdge[151, 239] -> 
             RGBColor[
              0.41770207455751684`, 0.5257103442374987, 0.9491616700514242], 
             UndirectedEdge[136, 226] -> 
             RGBColor[
              0.6894363159019072, 0.7515352642002422, 0.911828216152313], 
             UndirectedEdge[59, 210] -> 
             RGBColor[
              0.7283433684413259, 0.785018817714684, 0.9248382115325371], 
             UndirectedEdge[191, 205] -> 
             RGBColor[
              0.29986821230051, 0.4266293598594382, 0.9406037744698572], 
             UndirectedEdge[212, 276] -> 
             RGBColor[
              0.23737124141047264`, 0.3668226033013362, 0.9368293130878194], 
             UndirectedEdge[218, 292] -> 
             RGBColor[
              0.8704525733936984, 0.8991011858444631, 0.9592520377831382], 
             UndirectedEdge[144, 245] -> 
             RGBColor[
              0.2114412038308669, 0.3395684897458317, 0.9353526358077138], 
             UndirectedEdge[1, 277] -> 
             RGBColor[
              0.8767993326536895, 0.4256141747773018, 0.2705857731385237], 
             UndirectedEdge[64, 239] -> 
             RGBColor[
              0.23644031537818827`, 0.3658441410172859, 0.9367762982274624], 
             UndirectedEdge[128, 256] -> 
             RGBColor[
              0.8359362044780833, 0.2772269917295691, 0.18204585603333756`], 
             UndirectedEdge[7, 81] -> 
             RGBColor[
              0.9138922902616244, 0.7722436147323656, 0.6093859995388808], 
             UndirectedEdge[32, 145] -> 
             RGBColor[
              0.9262900127477325, 0.9421433350511439, 0.920438952214905], 
             UndirectedEdge[84, 247] -> 
             RGBColor[
              0.1926121673846783, 0.3197779786110244, 0.9342803500371666], 
             UndirectedEdge[215, 259] -> 
             RGBColor[
              0.20495150510474192`, 0.33274740491400967`, 0.9349830570659099],
              UndirectedEdge[187, 233] -> 
             RGBColor[
              0.2150678926487934, 0.3433803696388245, 0.9355591703706895], 
             UndirectedEdge[37, 152] -> 
             RGBColor[
              0.20454390254542953`, 0.33231898878067745`, 0.9349598447031511],
              UndirectedEdge[257, 300] -> 
             RGBColor[
              0.20486085687830097`, 0.33265212788059073`, 0.9349778947835161],
              UndirectedEdge[10, 244] -> 
             RGBColor[
              0.1899533548754444, 0.3169833980853699, 0.9341289345981263], 
             UndirectedEdge[98, 157] -> 
             RGBColor[
              0.18079506708635712`, 0.3073574569500555, 0.9336073836570105], 
             UndirectedEdge[13, 271] -> 
             RGBColor[
              0.2779619784734704, 0.40721689761763513`, 0.9392239799901998], 
             UndirectedEdge[202, 203] -> 
             RGBColor[
              0.8900888543770439, 0.6422166578978118, 0.47068879280256504`], 
             UndirectedEdge[166, 195] -> 
             RGBColor[
              0.184909234384039, 0.31168170763319203`, 0.9338416793982484], 
             UndirectedEdge[260, 287] -> 
             RGBColor[
              0.25058425907026255`, 0.38071032261548143`, 0.9375817748966364],
              UndirectedEdge[212, 214] -> 
             RGBColor[
              0.21709951040225656`, 0.3455157287097197, 0.9356748679962401], 
             UndirectedEdge[25, 113] -> 
             RGBColor[
              0.22937411863723062`, 0.3584171202197894, 0.9363738887765662], 
             UndirectedEdge[244, 280] -> 
             RGBColor[
              0.22575834254074034`, 0.3546167102889326, 0.9361679756769326], 
             UndirectedEdge[58, 134] -> 
             RGBColor[
              0.21796998739019388`, 0.34643065521547056`, 0.9357244403729478],
              UndirectedEdge[64, 263] -> 
             RGBColor[
              0.22259690617654707`, 0.3512938402235227, 0.9359879365529176], 
             UndirectedEdge[182, 261] -> 
             RGBColor[
              0.24954002688104543`, 0.37961276837646946`, 0.9375223074182637],
              UndirectedEdge[150, 277] -> 
             RGBColor[
              0.9502103007628988, 0.8290380865568148, 0.362523350207251], 
             UndirectedEdge[86, 202] -> 
             RGBColor[
              0.7757728461762639, 0.551813377715961, 0.4606487739019124], 
             UndirectedEdge[257, 267] -> 
             RGBColor[
              0.19014093188722048`, 0.31718055341781604`, 0.9341396168314517],
              UndirectedEdge[134, 245] -> 
             RGBColor[
              0.2350207777833922, 0.3643521170012733, 0.9366954576614566], 
             UndirectedEdge[187, 297] -> 
             RGBColor[
              0.20836666181027574`, 0.33633695114496726`, 0.9351775451880184],
              UndirectedEdge[75, 292] -> 
             RGBColor[
              0.5533224742847231, 0.6429700886267707, 0.9602576695267473], 
             UndirectedEdge[54, 174] -> 
             RGBColor[
              0.23862082785776215`, 0.3681359978857943, 0.936900475187395], 
             UndirectedEdge[44, 108] -> 
             RGBColor[
              0.27845239042381165`, 0.4093105366510138, 0.9391941231422369], 
             UndirectedEdge[94, 141] -> 
             RGBColor[
              0.5453682927010454, 0.6337189411498153, 0.9602178278094844], 
             UndirectedEdge[185, 262] -> 
             RGBColor[
              0.41669813660407123`, 0.5328210539055609, 0.9483611851595068], 
             UndirectedEdge[40, 202] -> 
             RGBColor[
              0.8074583715423828, 0.5770584081231883, 0.4634704687762633], 
             UndirectedEdge[110, 191] -> 
             RGBColor[
              0.20664696570435293`, 0.3345294415026117, 0.9350796110388486], 
             UndirectedEdge[92, 125] -> 
             RGBColor[
              0.8327679503009816, 0.2528744017865336, 0.1790119322553138], 
             UndirectedEdge[72, 226] -> 
             RGBColor[
              0.8816960164127614, 0.48093210501266836`, 0.40967383423425274`],
              UndirectedEdge[130, 162] -> 
             RGBColor[
              0.9515757296113414, 0.8393631712246421, 0.5204689724050278], 
             UndirectedEdge[29, 43] -> 
             RGBColor[
              0.21042089134742065`, 0.3384960766341818, 0.9352945305211986], 
             UndirectedEdge[152, 268] -> 
             RGBColor[
              0.1937845276020504, 0.3210102035314135, 0.9343471142171944], 
             UndirectedEdge[4, 62] -> 
             RGBColor[
              0.21110734445904222`, 0.33921758237813715`, 0.9353336230103891],
              UndirectedEdge[18, 184] -> 
             RGBColor[
              0.19573226525779447`, 0.3230573993013006, 0.9344580349952694], 
             UndirectedEdge[95, 159] -> 
             RGBColor[
              0.2893985943419117, 0.4215066499569798, 0.9397921938696936], 
             UndirectedEdge[154, 255] -> 
             RGBColor[
              0.43165774296703474`, 0.5471078244024314, 0.9490557746765065], 
             UndirectedEdge[140, 269] -> 
             RGBColor[
              0.8692676326331821, 0.39646501360429004`, 0.22622904167796476`],
              UndirectedEdge[10, 161] -> 
             RGBColor[
              0.19602879349749167`, 0.3233690692821986, 0.9344749218398459], 
             UndirectedEdge[216, 293] -> 
             RGBColor[
              0.8775620673948297, 0.536919768793157, 0.2195471266169376], 
             UndirectedEdge[188, 294] -> 
             RGBColor[
              0.445956916802145, 0.5584408477111231, 0.9502576320388609], 
             UndirectedEdge[32, 282] -> 
             RGBColor[
              0.7141541547436409, 0.7726234711925095, 0.9015995382329896], 
             UndirectedEdge[251, 282] -> 
             RGBColor[
              0.363119718775744, 0.4867984505328162, 0.944436976695407], 
             UndirectedEdge[181, 299] -> 
             RGBColor[
              0.874560587203039, 0.4182728709455591, 0.2441080923447113], 
             UndirectedEdge[60, 159] -> 
             RGBColor[
              0.28925410608148494`, 0.42135478363418655`, 0.9397839654770135],
              UndirectedEdge[137, 217] -> 
             RGBColor[
              0.23078620352350526`, 0.3599013109666169, 0.9364543049218471], 
             UndirectedEdge[20, 152] -> 
             RGBColor[
              0.20076184690853469`, 0.3283438085101236, 0.9347444622296798], 
             UndirectedEdge[62, 196] -> 
             RGBColor[
              0.2023683700722644, 0.33003236621465526`, 0.9348359513472162], 
             UndirectedEdge[251, 289] -> 
             RGBColor[
              0.26452594049436573`, 0.3953639137458709, 0.9383757330288698], 
             UndirectedEdge[104, 283] -> 
             RGBColor[
              0.32045429654903324`, 0.4517126811256811, 0.9416499450537039], 
             UndirectedEdge[45, 294] -> 
             RGBColor[
              0.4179920843483252, 0.5334044550653643, 0.9485055663485399], 
             UndirectedEdge[15, 158] -> 
             RGBColor[
              0.22566086224390924`, 0.3545142523163553, 0.9361624243182372], 
             UndirectedEdge[150, 237] -> 
             RGBColor[
              0.8525195804485002, 0.35269902313604284`, 0.19588243651989107`],
              UndirectedEdge[169, 228] -> 
             RGBColor[
              0.5154980125146456, 0.6168087674389304, 0.9552040569175313], 
             UndirectedEdge[159, 251] -> 
             RGBColor[
              0.2884240455436301, 0.4204823373800232, 0.9397366947573472], 
             UndirectedEdge[203, 293] -> 
             RGBColor[
              0.9184419291701429, 0.7951691860663403, 0.6146917974413972], 
             UndirectedEdge[145, 282] -> 
             RGBColor[
              0.6527680048201097, 0.7255950154401895, 0.9681370826346918], 
             UndirectedEdge[195, 234] -> 
             RGBColor[
              0.18893962070800485`, 0.3159178992009325, 0.934071203936976], 
             UndirectedEdge[156, 270] -> 
             RGBColor[
              0.3036653348674415, 0.42857413928414156`, 0.9408949377483093], 
             UndirectedEdge[25, 134] -> 
             RGBColor[
              0.21795734402989536`, 0.34641736624216146`, 0.935723720352283], 
             UndirectedEdge[158, 276] -> 
             RGBColor[
              0.21715975035837445`, 0.34557904472303347`, 0.935678298572624], 
             UndirectedEdge[268, 280] -> 
             RGBColor[
              0.23353122209160865`, 0.3627864995259231, 0.9366106296684096], 
             UndirectedEdge[8, 186] -> 
             RGBColor[
              0.19879211006828354`, 0.3262734902024908, 0.934632288630592], 
             UndirectedEdge[32, 256] -> 
             RGBColor[
              0.8745107904220526, 0.4222631586287432, 0.39450132191314774`], 
             UndirectedEdge[60, 168] -> 
             RGBColor[
              0.3438394161380286, 0.4702523109805432, 0.9432028328564219], 
             UndirectedEdge[162, 216] -> 
             RGBColor[
              0.9080919042261215, 0.6545799385528897, 0.40453925138773855`], 
             UndirectedEdge[106, 115] -> 
             RGBColor[
              0.6067946716231568, 0.6858798777418896, 0.9651595250499304], 
             UndirectedEdge[77, 276] -> 
             RGBColor[
              0.3275782701356497, 0.45192455001443343`, 0.9423220503837988], 
             UndirectedEdge[80, 281] -> 
             RGBColor[
              0.9786349916305042, 0.9618175926615335, 0.6467591064594813], 
             UndirectedEdge[130, 293] -> 
             RGBColor[
              0.9057809743644036, 0.6628729165850431, 0.24298078524882644`], 
             UndirectedEdge[39, 118] -> 
             RGBColor[
              0.19522260799965463`, 0.322521717208859, 0.9344290107683887], 
             UndirectedEdge[58, 245] -> 
             RGBColor[
              0.20819170713916685`, 0.33615306269286493`, 0.9351675817783212],
              UndirectedEdge[54, 143] -> 
             RGBColor[
              0.2754657226956103, 0.40686231846163223`, 0.9389987374412732], 
             UndirectedEdge[239, 258] -> 
             RGBColor[
              0.28886880526886394`, 0.4180452286151569, 0.9398683740473033], 
             UndirectedEdge[184, 222] -> 
             RGBColor[
              0.2064576757790399, 0.33433048578943325`, 0.9350688312576314], 
             UndirectedEdge[143, 298] -> 
             RGBColor[
              0.28351617500257303`, 0.41532385426440727`, 0.9394571987905778],
              UndirectedEdge[203, 269] -> 
             RGBColor[
              0.9551449948812127, 0.9368848088945971, 0.6707830617471834], 
             UndirectedEdge[107, 139] -> 
             RGBColor[
              0.4245992235592372, 0.5421882392946853, 0.9482760649602114], 
             UndirectedEdge[108, 283] -> 
             RGBColor[
              0.2732531217435669, 0.4045367345740317, 0.9388727330903042], 
             UndirectedEdge[173, 186] -> 
             RGBColor[
              0.19720146830174806`, 0.32460162485334904`, 0.9345417039351314],
              UndirectedEdge[164, 296] -> 
             RGBColor[
              0.18458413953272382`, 0.31134001233225567`, 0.9338231657274008],
              UndirectedEdge[11, 116] -> 
             RGBColor[
              0.4095833128093886, 0.5250728013946587, 0.9479805946176828], 
             UndirectedEdge[43, 229] -> 
             RGBColor[
              0.221649468641255, 0.3502980233029215, 0.935933981386891], 
             UndirectedEdge[128, 149] -> 
             RGBColor[
              0.8617947720920316, 0.43708705040676815`, 0.20528481439629814`],
              UndirectedEdge[221, 232] -> 
             RGBColor[
              0.18705168190288157`, 0.31393355581451393`, 0.9339636886149794],
              UndirectedEdge[8, 85] -> 
             RGBColor[
              0.21830835870760254`, 0.3467863049240477, 0.9357437101188987], 
             UndirectedEdge[20, 41] -> 
             RGBColor[
              0.20379941702053028`, 0.3315364872908998, 0.9349174473538756], 
             UndirectedEdge[108, 252] -> 
             RGBColor[
              0.23931387407336885`, 0.3688644334000649, 0.9369399431441039], 
             UndirectedEdge[65, 241] -> 
             RGBColor[
              0.6817937974014621, 0.7449457823928316, 0.912446971452788], 
             UndirectedEdge[231, 245] -> 
             RGBColor[
              0.2282116135363889, 0.3571952536517242, 0.9363076858308454], 
             UndirectedEdge[80, 167] -> 
             RGBColor[
              0.9432452158034876, 0.8059374712804274, 0.30837604527604406`], 
             UndirectedEdge[17, 201] -> 
             RGBColor[
              0.7981304417837846, 0.4892713331849807, 0.45108208269740613`], 
             UndirectedEdge[57, 223] -> 
             RGBColor[
              0.1805830172649961, 0.30713457914306985`, 0.9335953077333836], 
             UndirectedEdge[162, 202] -> 
             RGBColor[
              0.9081632494131782, 0.6549039003842219, 0.40459878356064916`], 
             UndirectedEdge[3, 59] -> 
             RGBColor[
              0.9696130276591681, 0.9767225112372966, 0.930252756027731], 
             UndirectedEdge[180, 187] -> 
             RGBColor[
              0.20981238961313842`, 0.3378565027302129, 0.9352598772476289], 
             UndirectedEdge[193, 215] -> 
             RGBColor[
              0.252152731139514, 0.38235888620713765`, 0.9376710970606339], 
             UndirectedEdge[43, 78] -> 
             RGBColor[
              0.20985899682898168`, 0.3379054898691324, 0.9352625314596219], 
             UndirectedEdge[56, 251] -> 
             RGBColor[
              0.2424819913817221, 0.3721943255613833, 0.9371203627380049], 
             UndirectedEdge[261, 284] -> 
             RGBColor[
              0.2428470796826115, 0.3725780565135533, 0.937141153976641], 
             UndirectedEdge[36, 41] -> 
             RGBColor[
              0.18496389091314852`, 0.31173915511071026`, 0.9338447920067241],
              UndirectedEdge[95, 168] -> 
             RGBColor[
              0.3439839043984553, 0.4704041773033365, 0.943211061249102], 
             UndirectedEdge[194, 280] -> 
             RGBColor[
              0.4740092277386598, 0.5736772866128733, 0.9537854496422005], 
             UndirectedEdge[99, 182] -> 
             RGBColor[
              0.22500890422772363`, 0.3538290031048185, 0.9361252962737008], 
             UndirectedEdge[94, 97] -> 
             RGBColor[
              0.622873487370591, 0.7022274882781143, 0.9651059553417796], 
             UndirectedEdge[79, 240] -> 
             RGBColor[
              0.18183565807480434`, 0.3084511840561929, 0.9336666437743861], 
             UndirectedEdge[83, 198] -> 
             RGBColor[
              0.8858987442443274, 0.5635903178481945, 0.44308216880395335`], 
             UndirectedEdge[69, 213] -> 
             RGBColor[
              0.20497196381527677`, 0.33276890831593897`, 0.934984222159209], 
             UndirectedEdge[214, 286] -> 
             RGBColor[
              0.21086056333637188`, 0.3389581997713838, 0.9353195691905329], 
             UndirectedEdge[277, 293] -> 
             RGBColor[
              0.946384976906248, 0.8125848782402458, 0.35937882583905917`], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.23002654529780098`, 0.3591028620062883, 0.9364110435097069], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.4656160294018773, 0.5758295097005381, 0.9514105681730911], 
             UndirectedEdge[43, 199] -> 
             RGBColor[
              0.21199067610024028`, 0.34014601993949717`, 0.9353839274405833],
              UndirectedEdge[192, 222] -> 
             RGBColor[
              0.2760214326902352, 0.40542425430285495`, 0.93910442514248], 
             UndirectedEdge[130, 202] -> 
             RGBColor[
              0.8816482178398845, 0.5540191449102804, 0.2228814513408511], 
             UndirectedEdge[4, 265] -> 
             RGBColor[
              0.22162675469537457`, 0.35027414950565383`, 0.9359326878612754],
              UndirectedEdge[121, 173] -> 
             RGBColor[
              0.21336819471978227`, 0.34159387934836083`, 0.9354623750881099],
              UndirectedEdge[53, 107] -> 
             RGBColor[
              0.3121763440598402, 0.43622685441542786`, 0.9414269663560839], 
             UndirectedEdge[172, 238] -> 
             RGBColor[
              0.18901379750666059`, 0.31599586371940025`, 0.9340754281959247],
              UndirectedEdge[210, 211] -> 
             RGBColor[
              0.3712058892361785, 0.49192848437614356`, 0.9451403247792249], 
             UndirectedEdge[180, 221] -> 
             RGBColor[
              0.19054010670567417`, 0.3176001114611562, 0.9341623492468364], 
             UndirectedEdge[196, 212] -> 
             RGBColor[
              0.2182141780704709, 0.3466873151030251, 0.9357383466709418], 
             UndirectedEdge[160, 176] -> 
             RGBColor[
              0.19497852177206426`, 0.3222651671077009, 0.9344151104188206], 
             UndirectedEdge[115, 193] -> 
             RGBColor[
              0.3156462416789386, 0.4451205438424978, 0.9414324679079064], 
             UndirectedEdge[21, 300] -> 
             RGBColor[
              0.2096118710905434, 0.33764574504935696`, 0.9352484580144076], 
             UndirectedEdge[75, 235] -> 
             RGBColor[
              0.3707116092284409, 0.495513496231598, 0.9448423938259995], 
             UndirectedEdge[77, 255] -> 
             RGBColor[
              0.38990028243638014`, 0.512133760513557, 0.9460650791149319], 
             UndirectedEdge[62, 286] -> 
             RGBColor[
              0.21128388043674812`, 0.3394031328837336, 0.935343676473158], 
             UndirectedEdge[46, 225] -> 
             RGBColor[
              0.21615267984960895`, 0.3445205497663627, 0.935620947396977], 
             UndirectedEdge[37, 161] -> 
             RGBColor[
              0.21411146518921928`, 0.3423751037378088, 0.9355047032417743], 
             UndirectedEdge[3, 162] -> 
             RGBColor[
              0.972783323199716, 0.9780335099161923, 0.8777127544589929], 
             UndirectedEdge[107, 274] -> 
             RGBColor[
              0.43576092708699476`, 0.5515917926842843, 0.9490602651560203], 
             UndirectedEdge[6, 147] -> 
             RGBColor[
              0.2119963836374878, 0.34015201892302305`, 0.935384252476386], 
             UndirectedEdge[8, 135] -> 
             RGBColor[
              0.2087723681564475, 0.33676337423806185`, 0.9352006495642442], 
             UndirectedEdge[186, 249] -> 
             RGBColor[
              0.20028634308592377`, 0.3278440238438759, 0.934717382990427], 
             UndirectedEdge[277, 281] -> 
             RGBColor[
              0.9857363810754343, 0.9854586098022267, 0.7010160851792143], 
             UndirectedEdge[256, 277] -> 
             RGBColor[
              0.8762891319766611, 0.42169254880230017`, 0.2700972043940122], 
             UndirectedEdge[8, 249] -> 
             RGBColor[
              0.20596246033793864`, 0.3338099829623634, 0.9350406294708662], 
             UndirectedEdge[114, 254] -> 
             RGBColor[
              0.2789569494583814, 0.4096039374484629, 0.9392315319348887], 
             UndirectedEdge[223, 270] -> 
             RGBColor[
              0.19716475878398335`, 0.32456304082266046`, 0.9345396133824015],
              UndirectedEdge[120, 294] -> 
             RGBColor[
              0.40756986398437334`, 0.5224500406559134, 0.9479120363171062], 
             UndirectedEdge[23, 290] -> 
             RGBColor[
              0.9678787961151241, 0.9075534182585008, 0.5509781065817215], 
             UndirectedEdge[7, 293] -> 
             RGBColor[
              0.9190392263270429, 0.795614649307972, 0.6136807291548138], 
             UndirectedEdge[95, 191] -> 
             RGBColor[
              0.2574665501142888, 0.38794404686520834`, 0.9379737111901566], 
             UndirectedEdge[65, 194] -> 
             RGBColor[
              0.5317344651989768, 0.6279967791452647, 0.9573054453238024], 
             UndirectedEdge[94, 188] -> 
             RGBColor[
              0.5763766141360973, 0.661954233683196, 0.9621432156948482], 
             UndirectedEdge[24, 162] -> 
             RGBColor[
              0.9575561451976635, 0.8630735261690534, 0.5252809551641785], 
             UndirectedEdge[34, 84] -> 
             RGBColor[
              0.1855804331499768, 0.3123871800926523, 0.9338799031750189], 
             UndirectedEdge[130, 201] -> 
             RGBColor[
              0.8675104556731318, 0.4624745923387423, 0.2100136661179885], 
             UndirectedEdge[74, 260] -> 
             RGBColor[
              0.23203447362151203`, 0.3612133219845175, 0.9365253920572785], 
             UndirectedEdge[69, 85] -> 
             RGBColor[
              0.21985867650040533`, 0.3484157872201088, 0.9358319984237091], 
             UndirectedEdge[220, 262] -> 
             RGBColor[
              0.318464636651424, 0.44980618598534605`, 0.9415298717668166], 
             UndirectedEdge[26, 262] -> 
             RGBColor[
              0.26646771810795733`, 0.39740484513356716`, 0.9384863143913613],
              UndirectedEdge[217, 270] -> 
             RGBColor[
              0.20643869531729672`, 0.3343105361207104, 0.9350677503484142], 
             UndirectedEdge[221, 245] -> 
             RGBColor[
              0.20571905261194073`, 0.33355414600939837`, 0.93502676776096], 
             UndirectedEdge[3, 24] -> 
             RGBColor[
              0.9389911914260977, 0.8504167316496911, 0.6099487388884464], 
             UndirectedEdge[59, 197] -> 
             RGBColor[
              0.9856746989571257, 0.9883441341223966, 0.8870708411785275], 
             UndirectedEdge[54, 235] -> 
             RGBColor[
              0.32626536687632174`, 0.4510335953926109, 0.9422293781681247], 
             UndirectedEdge[159, 282] -> 
             RGBColor[
              0.36593647358390397`, 0.4897590384287621, 0.9445973867147164], 
             UndirectedEdge[6, 53] -> 
             RGBColor[
              0.21323620369391516`, 0.3414551484114601, 0.9354548583944501], 
             UndirectedEdge[31, 210] -> 
             RGBColor[
              0.4456637990054052, 0.5599347702274033, 0.949756030710805], 
             UndirectedEdge[137, 273] -> 
             RGBColor[
              0.25023215692458567`, 0.3803402409358096, 0.9375617232003286], 
             UndirectedEdge[99, 259] -> 
             RGBColor[
              0.19041774683741108`, 0.3174715034815479, 0.934155381033354], 
             UndirectedEdge[16, 151] -> 
             RGBColor[
              0.42230921801132515`, 0.5305527441172178, 0.9494240400554605], 
             UndirectedEdge[24, 227] -> 
             RGBColor[
              0.9382342504393061, 0.7928264157474236, 0.2691600319562284], 
             UndirectedEdge[87, 202] -> 
             RGBColor[
              0.9087631737635028, 0.6539246978300517, 0.30544569802749344`], 
             UndirectedEdge[17, 94] -> 
             RGBColor[
              0.7502759773076164, 0.8048405628721153, 0.9757441557565323], 
             UndirectedEdge[5, 92] -> 
             RGBColor[
              0.8780406889079944, 0.46699287511950294`, 0.23253013995633712`],
              UndirectedEdge[72, 290] -> 
             RGBColor[
              0.8684139499629852, 0.42648519406555707`, 0.2091141155204876], 
             UndirectedEdge[103, 212] -> 
             RGBColor[
              0.327349136755672, 0.45098594966848016`, 0.9423345502314089], 
             UndirectedEdge[112, 133] -> 
             RGBColor[
              0.18726032665159403`, 0.3141528546742519, 0.9339755706247563], 
             UndirectedEdge[71, 244] -> 
             RGBColor[
              0.20641030875985014`, 0.33428070004902233`, 0.9350661337759618],
              UndirectedEdge[142, 197] -> 
             RGBColor[
              0.8820709654347386, 0.4836090909320415, 0.4095386780827771], 
             UndirectedEdge[117, 196] -> 
             RGBColor[
              0.1942847722586868, 0.32153599238288155`, 0.9343756024103442], 
             UndirectedEdge[131, 188] -> 
             RGBColor[
              0.2926361203769149, 0.4205530757547836, 0.9401360760402346], 
             UndirectedEdge[13, 282] -> 
             RGBColor[
              0.38696044305919663`, 0.509587419405664, 0.9458777551494157], 
             UndirectedEdge[139, 143] -> 
             RGBColor[
              0.37380885559171856`, 0.49802499695333824`, 0.9450460153054621],
              UndirectedEdge[45, 89] -> 
             RGBColor[
              0.34033954683031736`, 0.4683920819989782, 0.9429369415722573], 
             UndirectedEdge[127, 269] -> 
             RGBColor[
              0.6610000720463691, 0.698853165460656, 0.646849788175898], 
             UndirectedEdge[25, 79] -> 
             RGBColor[
              0.18712823581077753`, 0.3140140188255107, 0.9339680482467827], 
             UndirectedEdge[29, 78] -> 
             RGBColor[
              0.1946932984138494, 0.3219653792740117, 0.9343988673705204], 
             UndirectedEdge[150, 179] -> 
             RGBColor[
              0.7150830892215184, 0.6470263643951079, 0.5999650595216117], 
             UndirectedEdge[11, 198] -> 
             RGBColor[
              0.7482029346182517, 0.8019514484742061, 0.9505539165512161], 
             UndirectedEdge[135, 286] -> 
             RGBColor[
              0.2169836251808333, 0.34539392599445645`, 0.9356682685043168], 
             UndirectedEdge[101, 104] -> 
             RGBColor[
              0.49120791951509923`, 0.5945373978105576, 0.9540278714950781], 
             UndirectedEdge[3, 290] -> 
             RGBColor[
              0.9503146533364857, 0.8953104848043834, 0.619059862137357], 
             UndirectedEdge[158, 212] -> 
             RGBColor[
              0.21315714444874106`, 0.34137205213213645`, 0.9354503560873951],
              UndirectedEdge[102, 175] -> 
             RGBColor[
              0.18740197098760464`, 0.3143017318521686, 0.9339836370601481], 
             UndirectedEdge[103, 255] -> 
             RGBColor[
              0.3936737549660358, 0.5154021527585007, 0.9463055214477708], 
             UndirectedEdge[3, 65] -> 
             RGBColor[
              0.6658408786786703, 0.7333691314923763, 0.9538265746888542], 
             UndirectedEdge[148, 270] -> 
             RGBColor[
              0.22956819937889494`, 0.35862111138470837`, 0.9363849413876872],
              UndirectedEdge[49, 298] -> 
             RGBColor[
              0.23487979924778435`, 0.36420393962179404`, 0.9366874291424127],
              UndirectedEdge[15, 103] -> 
             RGBColor[
              0.33985285455084013`, 0.464128149852699, 0.9430466184622509], 
             UndirectedEdge[4, 15] -> 
             RGBColor[
              0.23945687025241685`, 0.36901473145072583`, 0.9369480865649568],
              UndirectedEdge[83, 290] -> 
             RGBColor[
              0.8798387029608784, 0.5143008519660508, 0.22005447189368316`], 
             UndirectedEdge[182, 284] -> 
             RGBColor[
              0.24765066246750966`, 0.3776269265852207, 0.937414710909977], 
             UndirectedEdge[32, 92] -> 
             RGBColor[
              0.883595180526095, 0.49208976177353947`, 0.4032005441361298], 
             UndirectedEdge[87, 203] -> 
             RGBColor[
              0.9651365709425674, 0.970190636874684, 0.7434503562978652], 
             UndirectedEdge[115, 169] -> 
             RGBColor[
              0.47823384946439584`, 0.5845324223560975, 0.9528296173993749], 
             UndirectedEdge[111, 143] -> 
             RGBColor[
              0.46054913753176646`, 0.5687866450741914, 0.9517800380473413], 
             UndirectedEdge[163, 274] -> 
             RGBColor[
              0.5420984734158494, 0.6391389878337358, 0.9570951240808855], 
             UndirectedEdge[96, 260] -> 
             RGBColor[
              0.22955901197049378`, 0.3586114548359634, 0.9363844181783704], 
             UndirectedEdge[27, 227] -> 
             RGBColor[
              0.9612729955532987, 0.8800632676191081, 0.309071745135731], 
             UndirectedEdge[103, 205] -> 
             RGBColor[
              0.39684467535749024`, 0.5181486446264856, 0.9465075696911796], 
             UndirectedEdge[27, 216] -> 
             RGBColor[
              0.9009229797863709, 0.6276599876230118, 0.25263771646037597`], 
             UndirectedEdge[145, 293] -> 
             RGBColor[
              0.8823313146508039, 0.7664123372275902, 0.6125225465194646], 
             UndirectedEdge[96, 133] -> 
             RGBColor[
              0.19311989172231955`, 0.3203116290814677, 0.9343092641870845], 
             UndirectedEdge[127, 159] -> 
             RGBColor[
              0.3200380232724909, 0.45000410769220556`, 0.9416727780472791], 
             UndirectedEdge[186, 214] -> 
             RGBColor[
              0.19697318905997124`, 0.32436168889650174`, 0.9345287037700212],
              UndirectedEdge[111, 262] -> 
             RGBColor[
              0.459021775002635, 0.5671812902156966, 0.9516930570108376], 
             UndirectedEdge[33, 157] -> 
             RGBColor[
              0.19152225944429985`, 0.31863241626153205`, 0.9342182813923363],
              UndirectedEdge[112, 131] -> 
             RGBColor[
              0.20931958090363292`, 0.3373385295306458, 0.9352318125206677], 
             UndirectedEdge[37, 55] -> 
             RGBColor[
              0.21435260419714997`, 0.34262855612424004`, 0.9355184357515427],
              UndirectedEdge[20, 71] -> 
             RGBColor[
              0.22116050761720274`, 0.349784094264723, 0.9359061357799242], 
             UndirectedEdge[37, 252] -> 
             RGBColor[
              0.23225528127463596`, 0.3614454048279645, 0.9365379667264683], 
             UndirectedEdge[120, 178] -> 
             RGBColor[
              0.2690508208241996, 0.4001198498665095, 0.9386334182696933], 
             UndirectedEdge[113, 231] -> 
             RGBColor[
              0.24940666839475117`, 0.3794726001519578, 0.9375147128497554], 
             UndirectedEdge[7, 181] -> 
             RGBColor[
              0.962306825108859, 0.9594739836095195, 0.6952739648323978], 
             UndirectedEdge[42, 299] -> 
             RGBColor[
              0.8313011225434905, 0.2415997208744344, 0.17760729633819525`], 
             UndirectedEdge[64, 234] -> 
             RGBColor[
              0.2147298520602665, 0.3430250675472716, 0.9355399194592591], 
             UndirectedEdge[78, 261] -> 
             RGBColor[
              0.21943392399577888`, 0.3479693454068822, 0.9358078093969358], 
             UndirectedEdge[10, 100] -> 
             RGBColor[
              0.18553288790448116`, 0.3123372070250937, 0.9338771955436248], 
             UndirectedEdge[6, 88] -> 
             RGBColor[
              0.21672673573205908`, 0.345123918896063, 0.935653639030243], 
             UndirectedEdge[36, 208] -> 
             RGBColor[
              0.1853248284213402, 0.31211852331657947`, 0.9338653468638564], 
             UndirectedEdge[92, 142] -> 
             RGBColor[
              0.8310149903490321, 0.23940038344390055`, 0.17733329582564183`],
              UndirectedEdge[237, 293] -> 
             RGBColor[
              0.8499693645440664, 0.3417302175916635, 0.19378608694109653`], 
             UndirectedEdge[127, 145] -> 
             RGBColor[
              0.6068695545086966, 0.6858400847036329, 0.9652124739672545], 
             UndirectedEdge[90, 285] -> 
             RGBColor[
              0.20767787323688183`, 0.3356129906826123, 0.9351383196977351], 
             UndirectedEdge[134, 176] -> 
             RGBColor[
              0.21949584805110617`, 0.34803443151524305`, 0.9358113358802782],
              UndirectedEdge[28, 297] -> 
             RGBColor[
              0.18773159769962583`, 0.31464819042604353`, 0.9340024088137586],
              UndirectedEdge[20, 136] -> 
             RGBColor[
              0.3058098324986471, 0.43100159391667037`, 0.9410107128012115], 
             UndirectedEdge[113, 134] -> 
             RGBColor[
              0.25621583264175446`, 0.38662946350150684`, 0.9379024846803665],
              UndirectedEdge[12, 181] -> 
             RGBColor[
              0.707957046702949, 0.7559827796524516, 0.6749255302079116], 
             UndirectedEdge[84, 217] -> 
             RGBColor[
              0.19375308221906778`, 0.32097715244014635`, 0.9343453234491528],
              UndirectedEdge[126, 153] -> 
             RGBColor[
              0.2222787641449363, 0.35095945277692997`, 0.9359698188348664], 
             UndirectedEdge[217, 251] -> 
             RGBColor[
              0.24282276767362948`, 0.3725525030506428, 0.9371397694436958], 
             UndirectedEdge[211, 266] -> 
             RGBColor[
              0.23444123912717205`, 0.36374298512871284`, 0.9366624537923354],
              UndirectedEdge[156, 282] -> 
             RGBColor[
              0.41756183526404816`, 0.5360928072628128, 0.9478276488009602], 
             UndirectedEdge[92, 256] -> 
             RGBColor[
              0.8270124944014894, 0.208635445686179, 0.17350050118610227`], 
             UndirectedEdge[56, 246] -> 
             RGBColor[
              0.1919032518459413, 0.3190328634319706, 0.934239978345982], 
             UndirectedEdge[223, 246] -> 
             RGBColor[
              0.1829700916045353, 0.3096435456231802, 0.9337312480856603], 
             UndirectedEdge[66, 228] -> 
             RGBColor[
              0.40629940527691566`, 0.5263378564741489, 0.9471100167211559], 
             UndirectedEdge[170, 261] -> 
             RGBColor[
              0.22115645505495063`, 0.3497798347648488, 0.9359059049924991], 
             UndirectedEdge[104, 287] -> 
             RGBColor[
              0.2890443879522816, 0.41869887568726627`, 0.9398611972259145], 
             UndirectedEdge[255, 258] -> 
             RGBColor[
              0.3530896957607064, 0.48025028048897034`, 0.9437195410822816], 
             UndirectedEdge[27, 162] -> 
             RGBColor[
              0.9805948903116561, 0.9503103780407378, 0.565192668343681], 
             UndirectedEdge[162, 169] -> 
             RGBColor[
              0.7980436197485294, 0.8403418316253028, 0.877535691789008], 
             UndirectedEdge[90, 166] -> 
             RGBColor[
              0.20088523531551122`, 0.3284734975491328, 0.9347514890169203], 
             UndirectedEdge[74, 257] -> 
             RGBColor[
              0.19498858899920085`, 0.3222757484017205, 0.9344156837325129], 
             UndirectedEdge[82, 203] -> 
             RGBColor[
              0.7752823706628642, 0.824842772704185, 0.9770131806255582], 
             UndirectedEdge[1, 142] -> 
             RGBColor[
              0.822440800922018, 0.17349540627410584`, 0.16912264234717125`], 
             UndirectedEdge[82, 145] -> 
             RGBColor[
              0.7391717561435251, 0.7960859238654349, 0.9748439297036255], 
             UndirectedEdge[77, 203] -> 
             RGBColor[
              0.6754538924070363, 0.7427240405564789, 0.9694509218275109], 
             UndirectedEdge[12, 27] -> 
             RGBColor[
              0.6997308165084448, 0.7282337735956864, 0.6429681792954851], 
             UndirectedEdge[54, 185] -> 
             RGBColor[
              0.3867966632124244, 0.5013927095080272, 0.9466583404851183], 
             UndirectedEdge[35, 165] -> 
             RGBColor[
              0.2120938524489715, 0.3402544648237721, 0.9353898031810077], 
             UndirectedEdge[60, 95] -> 
             RGBColor[
              0.28741190007160666`, 0.4194185083151971, 0.9396790545700505], 
             UndirectedEdge[47, 112] -> 
             RGBColor[
              0.18666547155784385`, 0.31352762425472913`, 0.9339416945071765],
              UndirectedEdge[24, 59] -> 
             RGBColor[
              0.9543858496571156, 0.8617625274901577, 0.5778209567329167], 
             UndirectedEdge[239, 285] -> 
             RGBColor[
              0.21862787921736482`, 0.3471221412385783, 0.9357619063392415], 
             UndirectedEdge[173, 286] -> 
             RGBColor[
              0.2110888425781487, 0.3391981357282311, 0.9353325693556434], 
             UndirectedEdge[17, 40] -> 
             RGBColor[
              0.6964483919711273, 0.7627900441024493, 0.9703791250975754], 
             UndirectedEdge[226, 241] -> 
             RGBColor[
              0.9861906717339419, 0.9885575021255057, 0.8785198369719385], 
             UndirectedEdge[255, 286] -> 
             RGBColor[
              0.2934543066453184, 0.4204742848621239, 0.9402170430132455], 
             UndirectedEdge[95, 271] -> 
             RGBColor[
              0.25509580298829937`, 0.3854522413217438, 0.9378387006485376], 
             UndirectedEdge[189, 260] -> 
             RGBColor[
              0.23700170640282697`, 0.36643419857842796`, 0.936808268615812], 
             UndirectedEdge[193, 245] -> 
             RGBColor[
              0.2524031222436139, 0.38262206313325964`, 0.9376853564635919], 
             UndirectedEdge[84, 223] -> 
             RGBColor[
              0.1844791456857544, 0.31122965714209644`, 0.9338171864831403], 
             UndirectedEdge[44, 61] -> 
             RGBColor[
              0.29673927658547317`, 0.4285312134624696, 0.9402355342561197], 
             UndirectedEdge[262, 292] -> 
             RGBColor[
              0.5387777053242508, 0.6299185321853173, 0.9593474985432611], 
             UndirectedEdge[153, 248] -> 
             RGBColor[
              0.2215139470361167, 0.3501555815033551, 0.9359262636319645], 
             UndirectedEdge[78, 99] -> 
             RGBColor[
              0.19490280134245708`, 0.32218558013523124`, 0.9344107982523728],
              UndirectedEdge[199, 261] -> 
             RGBColor[
              0.22156560326703745`, 0.35020987547724697`, 0.9359292053778969],
              UndirectedEdge[58, 215] -> 
             RGBColor[
              0.20794131603506694`, 0.33588988576674306`, 0.935153322375363], 
             UndirectedEdge[23, 197] -> 
             RGBColor[
              0.9878441835047461, 0.9892412717360475, 0.8511168677784218], 
             UndirectedEdge[196, 214] -> 
             RGBColor[
              0.20194505297188817`, 0.32958743310230554`, 0.9348118440645912],
              UndirectedEdge[88, 289] -> 
             RGBColor[
              0.23315152394890182`, 0.3623874127036856, 0.9365890064208955], 
             UndirectedEdge[47, 96] -> 
             RGBColor[
              0.19252503662856937`, 0.3196863986619449, 0.9342753880695046], 
             UndirectedEdge[179, 205] -> 
             RGBColor[
              0.44755823847840226`, 0.5601887588135859, 0.9502599417033248], 
             UndirectedEdge[72, 194] -> 
             RGBColor[
              0.7816121517042992, 0.4029477795624471, 0.4403138133077221], 
             UndirectedEdge[140, 299] -> 
             RGBColor[
              0.8177772995946797, 0.13764969151287093`, 0.16465686820944062`],
              UndirectedEdge[134, 297] -> 
             RGBColor[
              0.21839610407426302`, 0.3468785308677854, 0.9357487070877224], 
             UndirectedEdge[67, 195] -> 
             RGBColor[
              0.18132553855698572`, 0.30791501609952, 0.9336375932225005], 
             UndirectedEdge[24, 155] -> 
             RGBColor[
              0.9250389254998768, 0.7405113494439601, 0.2585427637758789], 
             UndirectedEdge[156, 277] -> 
             RGBColor[
              0.6937513555235839, 0.7517852121341029, 0.7135233421024703], 
             UndirectedEdge[267, 272] -> 
             RGBColor[
              0.18764714248222777`, 0.31455942263778813`, 0.9339975992140681],
              UndirectedEdge[71, 177] -> 
             RGBColor[
              0.2576442825267533, 0.3881308548995943, 0.9379838327881149], 
             UndirectedEdge[188, 281] -> 
             RGBColor[
              0.66716299452805, 0.7330554302274623, 0.9326197293964239], 
             UndirectedEdge[1, 150] -> 
             RGBColor[
              0.848265408272229, 0.31999959159908814`, 0.19180863643949353`], 
             UndirectedEdge[84, 246] -> 
             RGBColor[
              0.1859588657451276, 0.3127849367441682, 0.9339014543514719], 
             UndirectedEdge[58, 230] -> 
             RGBColor[
              0.19161321755920613`, 0.31872801900737613`, 0.9342234613224198],
              UndirectedEdge[74, 189] -> 
             RGBColor[
              0.21086862151855923`, 0.33896666943178094`, 0.9353200280920875],
              UndirectedEdge[48, 71] -> 
             RGBColor[
              0.2080633650262977, 0.3360181669948795, 0.9351602728848583], 
             UndirectedEdge[80, 205] -> 
             RGBColor[
              0.6755840605748524, 0.7185594638345996, 0.6585612536692309], 
             UndirectedEdge[1, 32] -> 
             RGBColor[
              0.8750209910990808, 0.42618478460374476`, 0.39498989065765927`],
              UndirectedEdge[229, 233] -> 
             RGBColor[
              0.2115539796555496, 0.3396870242879735, 0.9353590582240927], 
             UndirectedEdge[54, 172] -> 
             RGBColor[
              0.21731047913351847`, 0.34573747022246615`, 0.935686882353385], 
             UndirectedEdge[61, 194] -> 
             RGBColor[
              0.4816323907254858, 0.581689714248477, 0.9542195774968412], 
             UndirectedEdge[177, 194] -> 
             RGBColor[
              0.4889886310377472, 0.5894215892292383, 0.9546385045000421], 
             UndirectedEdge[7, 42] -> 
             RGBColor[
              0.8711763850077039, 0.5112078638480927, 0.45219338209118976`], 
             UndirectedEdge[26, 75] -> 
             RGBColor[
              0.28101248706842963`, 0.4104564015750206, 0.9393964853748475], 
             UndirectedEdge[170, 190] -> 
             RGBColor[
              0.2009954787857768, 0.3285893704262217, 0.9347577672194614], 
             UndirectedEdge[20, 36] -> 
             RGBColor[
              0.200168643680248, 0.32772031430593734`, 0.9347106801833944], 
             UndirectedEdge[119, 161] -> 
             RGBColor[
              0.191253116488521, 0.3183495299503595, 0.9342029540991661], 
             UndirectedEdge[212, 225] -> 
             RGBColor[
              0.23048263283804543`, 0.3595822389287055, 0.9364370170204028], 
             UndirectedEdge[102, 253] -> 
             RGBColor[
              0.1920226425007294, 0.3191583505799577, 0.9342467774671497], 
             UndirectedEdge[91, 179] -> 
             RGBColor[
              0.5064577791876668, 0.6102042666643193, 0.9542893580750782], 
             UndirectedEdge[118, 239] -> 
             RGBColor[
              0.213148543369447, 0.34136301185245843`, 0.9354498662686535], 
             UndirectedEdge[105, 298] -> 
             RGBColor[
              0.27198901083979987`, 0.403208073864912, 0.938800743844419], 
             UndirectedEdge[90, 239] -> 
             RGBColor[
              0.2266260849573989, 0.3555287625868876, 0.9362173923238513], 
             UndirectedEdge[208, 252] -> 
             RGBColor[
              0.21362941037883332`, 0.3418684335680528, 0.935477250933459], 
             UndirectedEdge[117, 214] -> 
             RGBColor[
              0.19317010459047246`, 0.32036440598957616`, 0.9343121237356424],
              UndirectedEdge[179, 282] -> 
             RGBColor[
              0.48169445553417334`, 0.5897558342911382, 0.9524350712686471], 
             UndirectedEdge[44, 268] -> 
             RGBColor[
              0.2606344226816996, 0.39058272282964934`, 0.9381794162386446], 
             UndirectedEdge[53, 124] -> 
             RGBColor[
              0.20090092998575032`, 0.32848999364265374`, 0.9347523828051723],
              UndirectedEdge[42, 81] -> 
             RGBColor[
              0.8548914543976673, 0.39035727136327797`, 0.1989221405255734], 
             UndirectedEdge[173, 213] -> 
             RGBColor[
              0.20183100425593847`, 0.3294675606707361, 0.9348053491589379], 
             UndirectedEdge[119, 122] -> 
             RGBColor[
              0.18294597115910344`, 0.30961819350570674`, 0.933729874461976], 
             UndirectedEdge[68, 111] -> 
             RGBColor[
              0.7455301616880299, 0.8011614727150247, 0.9754440364810864], 
             UndirectedEdge[34, 53] -> 
             RGBColor[
              0.1997851700209307, 0.32731725917636056`, 0.9346888419257947], 
             UndirectedEdge[85, 263] -> 
             RGBColor[
              0.22101888131475306`, 0.34963523604122215`, 0.9358980703715171],
              UndirectedEdge[37, 208] -> 
             RGBColor[
              0.20794241016561682`, 0.3358910357673228, 0.9351533846844792], 
             UndirectedEdge[256, 293] -> 
             RGBColor[
              0.8452049916907669, 0.30510916007970723`, 0.18922371811618746`],
              UndirectedEdge[76, 153] -> 
             RGBColor[
              0.27399346070364045`, 0.40363477490679034`, 0.9389764110945367],
              UndirectedEdge[135, 213] -> 
             RGBColor[
              0.20772578685862308`, 0.3356633509369615, 0.9351410483076115], 
             UndirectedEdge[36, 55] -> 
             RGBColor[
              0.19173502245287335`, 0.3188560436734967, 0.9342303979309199], 
             UndirectedEdge[121, 135] -> 
             RGBColor[
              0.21926297732246688`, 0.3477896696145861, 0.9357980742367835], 
             UndirectedEdge[83, 226] -> 
             RGBColor[
              0.8931207694106547, 0.5687477629131621, 0.4206141906074483], 
             UndirectedEdge[60, 127] -> 
             RGBColor[
              0.3180513290021859, 0.44791596605042294`, 0.941559638747636], 
             UndirectedEdge[247, 271] -> 
             RGBColor[
              0.21019581629378764`, 0.33825950848223085`, 0.9352817128298629],
              UndirectedEdge[202, 269] -> 
             RGBColor[
              0.902102123055933, 0.6317208125099938, 0.2570008349937056], 
             UndirectedEdge[190, 284] -> 
             RGBColor[
              0.22268610341343767`, 0.3513875921749262, 0.9359930162036031], 
             UndirectedEdge[53, 217] -> 
             RGBColor[
              0.2079578190900217, 0.3359072315238546, 0.9351542621999286], 
             UndirectedEdge[42, 87] -> 
             RGBColor[
              0.8894525062895627, 0.5226189282859114, 0.2876243328405072], 
             UndirectedEdge[205, 225] -> 
             RGBColor[
              0.29997817143986366`, 0.426744933886711, 0.9406100364801734], 
             UndirectedEdge[110, 246] -> 
             RGBColor[
              0.18518351558803503`, 0.3119699945690246, 0.9338572993070533], 
             UndirectedEdge[191, 251] -> 
             RGBColor[
              0.25649200131600725`, 0.38691973428825177`, 0.9379182120778102],
              UndirectedEdge[23, 83] -> 
             RGBColor[
              0.8941506088744137, 0.5691736279970934, 0.4035470855538621], 
             UndirectedEdge[226, 291] -> 
             RGBColor[
              0.956565980138184, 0.9665569141916783, 0.9351528422090618], 
             UndirectedEdge[60, 276] -> 
             RGBColor[
              0.26432062956564295`, 0.39514811894231855`, 0.9383640408752093],
              UndirectedEdge[27, 155] -> 
             RGBColor[
              0.9480776706138694, 0.8277482013156446, 0.2984544769553814], 
             UndirectedEdge[167, 203] -> 
             RGBColor[
              0.9224035575123126, 0.8121627962472151, 0.6179459955981152], 
             UndirectedEdge[137, 271] -> 
             RGBColor[
              0.24208469003989352`, 0.37177673666076144`, 0.9370977370143425],
              UndirectedEdge[52, 247] -> 
             RGBColor[
              0.1982447360653234, 0.3256981654198634, 0.9346011164908907], 
             UndirectedEdge[81, 299] -> 
             RGBColor[
              0.8422842306382159, 0.2934526250274564, 0.1868494488157], 
             UndirectedEdge[31, 290] -> 
             RGBColor[
              0.683029742131583, 0.6815722331575694, 0.6118498991600951], 
             UndirectedEdge[79, 288] -> 
             RGBColor[
              0.19600308919068352`, 0.3233420524259961, 0.9344734580175993], 
             UndirectedEdge[237, 281] -> 
             RGBColor[
              0.8762036339901905, 0.45697937196631744`, 0.42154425983453325`],
              UndirectedEdge[43, 215] -> 
             RGBColor[
              0.22516415254335911`, 0.35399217892786317`, 0.9361341374356069],
              UndirectedEdge[56, 295] -> 
             RGBColor[
              0.19813975131853928`, 0.3255878197945759, 0.9345951377648724], 
             UndirectedEdge[89, 94] -> 
             RGBColor[
              0.5888165791799138, 0.6727291061533267, 0.962935879267211], 
             UndirectedEdge[92, 237] -> 
             RGBColor[
              0.829394680828139, 0.22694597444215714`, 0.1757816855985568], 
             UndirectedEdge[126, 285] -> 
             RGBColor[
              0.21158401439278246`, 0.3397185927011176, 0.9353607686579457], 
             UndirectedEdge[4, 214] -> 
             RGBColor[
              0.21068402735866598`, 0.33877264926578743`, 0.9353095157277642],
              UndirectedEdge[220, 222] -> 
             RGBColor[
              0.2772575054008418, 0.4064948783579615, 0.9391831866025837], 
             UndirectedEdge[199, 209] -> 
             RGBColor[
              0.1894252090832627, 0.31642828337140966`, 0.9340988574765833], 
             UndirectedEdge[290, 291] -> 
             RGBColor[
              0.9366428804635196, 0.8848865477710113, 0.6343132641384139], 
             UndirectedEdge[91, 150] -> 
             RGBColor[
              0.6987841041568563, 0.6337941140587057, 0.5986819437121721], 
             UndirectedEdge[60, 148] -> 
             RGBColor[
              0.2667823322730826, 0.39773552456880407`, 0.9385042312026353], 
             UndirectedEdge[81, 140] -> 
             RGBColor[
              0.8413676314488565, 0.2864072420017145, 0.18597171239681876`], 
             UndirectedEdge[142, 256] -> 
             RGBColor[
              0.8259330961925325, 0.20033871805682574`, 0.1724668682421993], 
             UndirectedEdge[30, 123] -> 
             RGBColor[
              0.2239498078006626, 0.3527158256093854, 0.9360649822989724], 
             UndirectedEdge[53, 289] -> 
             RGBColor[
              0.22966099191075792`, 0.3587186422190827, 0.9363902257851027], 
             UndirectedEdge[274, 289] -> 
             RGBColor[
              0.3532455749379125, 0.4740835804879391, 0.944023524585039], 
             UndirectedEdge[11, 114] -> 
             RGBColor[
              0.38547343504917886`, 0.49973179121413747`, 0.9466075727466067],
              UndirectedEdge[137, 247] -> 
             RGBColor[
              0.22964528868911577`, 0.358702137137495, 0.9363893315098609], 
             UndirectedEdge[84, 191] -> 
             RGBColor[
              0.2074223158614455, 0.3353443836777553, 0.9351237660832672], 
             UndirectedEdge[17, 120] -> 
             RGBColor[
              0.4913767245940681, 0.5895491243083159, 0.9551516880301447], 
             UndirectedEdge[126, 222] -> 
             RGBColor[
              0.22245696617283922`, 0.3511467544069171, 0.9359799671767292], 
             UndirectedEdge[184, 224] -> 
             RGBColor[
              0.20007875304145373`, 0.32762583354516883`, 0.9347055610444963],
              UndirectedEdge[278, 295] -> 
             RGBColor[
              0.1987763965986568, 0.3262569743496216, 0.9346313937717428], 
             UndirectedEdge[28, 245] -> 
             RGBColor[
              0.204356271408755, 0.33212177655953135`, 0.9349491593874928], 
             UndirectedEdge[14, 186] -> 
             RGBColor[
              0.18665492193544975`, 0.31351653593270823`, 0.9339410937217879],
              UndirectedEdge[227, 241] -> 
             RGBColor[
              0.9694143471641505, 0.9193630503950179, 0.5802122280149764], 
             UndirectedEdge[121, 154] -> 
             RGBColor[
              0.3613735298324199, 0.47852983599420473`, 0.9448593103869043], 
             UndirectedEdge[187, 230] -> 
             RGBColor[
              0.20841284593944426`, 0.3363854935929662, 0.9351801753058513], 
             UndirectedEdge[125, 277] -> 
             RGBColor[
              0.8878000437756458, 0.5101704610030093, 0.28112006653243526`], 
             UndirectedEdge[62, 158] -> 
             RGBColor[
              0.1973113364505346, 0.3247171032437667, 0.9345479607636695], 
             UndirectedEdge[20, 61] -> 
             RGBColor[
              0.248131704384919, 0.378132532140237, 0.9374421055355356], 
             UndirectedEdge[64, 258] -> 
             RGBColor[
              0.28773302970917036`, 0.41685145648958927`, 0.939803693309408], 
             UndirectedEdge[94, 294] -> 
             RGBColor[
              0.6664691166979216, 0.7377414792197128, 0.9685045040434936], 
             UndirectedEdge[125, 237] -> 
             RGBColor[
              0.8318212025230813, 0.24559728349806995`, 0.17810532551399777`],
              UndirectedEdge[267, 300] -> 
             RGBColor[
              0.210925999504364, 0.33902697733283615`, 0.935323295683496], 
             UndirectedEdge[165, 175] -> 
             RGBColor[
              0.2002014223302363, 0.3277547667453615, 0.9347125468790196], 
             UndirectedEdge[67, 263] -> 
             RGBColor[
              0.19440813626729972`, 0.3216656557776636, 0.934382627808134], 
             UndirectedEdge[163, 298] -> 
             RGBColor[
              0.44064408929894633`, 0.5470342917552059, 0.9507221073701924], 
             UndirectedEdge[92, 149] -> 
             RGBColor[
              0.8528710620154377, 0.368495504363378, 0.19673945954906286`], 
             UndirectedEdge[95, 276] -> 
             RGBColor[
              0.2644651178260697, 0.3952999852651118, 0.9383722692678894], 
             UndirectedEdge[70, 231] -> 
             RGBColor[
              0.2204752799716199, 0.3490638765632734, 0.9358671130792118], 
             UndirectedEdge[239, 263] -> 
             RGBColor[
              0.22373268173624067`, 0.3524876123490904, 0.9360526172908128], 
             UndirectedEdge[116, 204] -> 
             RGBColor[
              0.38548007982804805`, 0.5055047110221348, 0.9460830998243401], 
             UndirectedEdge[121, 258] -> 
             RGBColor[
              0.28280548262609156`, 0.41167229208074363`, 0.9395230767926794],
              UndirectedEdge[95, 148] -> 
             RGBColor[
              0.2669268205335093, 0.3978873908915973, 0.9385124595953154], 
             UndirectedEdge[60, 77] -> 
             RGBColor[
              0.3505250523811867, 0.47604307306451876`, 0.9436288356859599], 
             UndirectedEdge[42, 269] -> 
             RGBColor[
              0.8827914555819929, 0.5004150429658535, 0.23917946980671936`], 
             UndirectedEdge[61, 136] -> 
             RGBColor[
              0.33493736709593636`, 0.46161647957078045`, 0.9426694828062012],
              UndirectedEdge[95, 251] -> 
             RGBColor[
              0.2865818395337517, 0.41854606206103384`, 0.9396317838503843], 
             UndirectedEdge[158, 265] -> 
             RGBColor[
              0.20783074668686696`, 0.3357736703712833, 0.9351470256145558], 
             UndirectedEdge[152, 208] -> 
             RGBColor[
              0.1859180316496269, 0.31274201752076575`, 0.9338991289101417], 
             UndirectedEdge[153, 285] -> 
             RGBColor[
              0.21037441724900163`, 0.3384472294101154, 0.9352918838900459], 
             UndirectedEdge[61, 279] -> 
             RGBColor[
              0.25696298277753227`, 0.387414765666264, 0.9379450337752894], 
             UndirectedEdge[82, 168] -> 
             RGBColor[
              0.5069255349638632, 0.6091474742003642, 0.9547231011630586], 
             UndirectedEdge[4, 249] -> 
             RGBColor[
              0.21399718138461848`, 0.3422549842131616, 0.93549819494817], 
             UndirectedEdge[75, 163] -> 
             RGBColor[
              0.47703987934410275`, 0.583052656791418, 0.9528766616787626], 
             UndirectedEdge[59, 290] -> 
             RGBColor[
              0.9657093115675036, 0.9066562806448499, 0.5869320799818273], 
             UndirectedEdge[205, 251] -> 
             RGBColor[
              0.3289835017199729, 0.45723137505526373`, 0.9422618471300848], 
             UndirectedEdge[183, 224] -> 
             RGBColor[
              0.2007040206651831, 0.3282830294619655, 0.9347411691106672], 
             UndirectedEdge[170, 178] -> 
             RGBColor[
              0.228293899528688, 0.35728174144686387`, 0.9363123718963757], 
             UndirectedEdge[102, 238] -> 
             RGBColor[
              0.18981943468321613`, 0.3168426394723074, 0.9341213080412961], 
             UndirectedEdge[89, 236] -> 
             RGBColor[
              0.30608763983959875`, 0.4323911560553985, 0.9409863461402914], 
             UndirectedEdge[65, 231] -> 
             RGBColor[
              0.30432205873480145`, 0.4308387652063516, 0.9408746918946544], 
             UndirectedEdge[25, 245] -> 
             RGBColor[
              0.2081790637788683, 0.33613977371955583`, 0.9351668617576563], 
             UndirectedEdge[217, 223] -> 
             RGBColor[
              0.19076430807847547`, 0.31783576131915836`, 0.9341751171833412],
              UndirectedEdge[254, 283] -> 
             RGBColor[
              0.3123013068939945, 0.44465097126766145`, 0.9411304437622906], 
             UndirectedEdge[168, 205] -> 
             RGBColor[
              0.3863855665846765, 0.5090894902975664, 0.9458411245288025], 
             UndirectedEdge[142, 243] -> 
             RGBColor[
              0.8824295641857295, 0.48375738073114377`, 0.40359576875504033`],
              UndirectedEdge[57, 278] -> 
             RGBColor[
              0.19015282278651957`, 0.31719305150690597`, 0.9341402940005757],
              UndirectedEdge[185, 218] -> 
             RGBColor[
              0.7483730046735189, 0.8020037075647066, 0.948265724399384], 
             UndirectedEdge[16, 248] -> 
             RGBColor[
              0.23437455245828825`, 0.36367289321153695`, 0.9366586560851965],
              UndirectedEdge[184, 275] -> 
             RGBColor[
              0.18583227383419235`, 0.31265188061938454`, 0.9338942451294201],
              UndirectedEdge[127, 191] -> 
             RGBColor[
              0.28810597904486807`, 0.41644150460043405`, 0.9398542953677421],
              UndirectedEdge[33, 153] -> 
             RGBColor[
              0.21078779737820008`, 0.338881718135717, 0.9353154252768627], 
             UndirectedEdge[83, 243] -> 
             RGBColor[
              0.8935075599716172, 0.5689077107501841, 0.41420407003041315`], 
             UndirectedEdge[94, 281] -> 
             RGBColor[
              0.8876751944238266, 0.9123560617360518, 0.9508666014010566], 
             UndirectedEdge[140, 293] -> 
             RGBColor[
              0.8447989221591355, 0.30198793171878546`, 0.18883486547410736`],
              UndirectedEdge[126, 220] -> 
             RGBColor[
              0.27828890051671973`, 0.40757894001897654`, 0.9392419230286206],
              UndirectedEdge[76, 220] -> 
             RGBColor[
              0.3300035970754238, 0.4602542621488369, 0.942248515288291], 
             UndirectedEdge[90, 126] -> 
             RGBColor[
              0.2195822201328165, 0.34812521404942687`, 0.9358162546425555], 
             UndirectedEdge[35, 102] -> 
             RGBColor[
              0.19929440110633984`, 0.32680142993057915`, 0.9346608933621363],
              UndirectedEdge[105, 235] -> 
             RGBColor[
              0.34616703863432685`, 0.47195151424914406`, 0.9433627489328582],
              UndirectedEdge[21, 287] -> 
             RGBColor[
              0.21828938866019382`, 0.34676636620145074`, 0.9357426298027625],
              UndirectedEdge[160, 245] -> 
             RGBColor[
              0.2105034515043503, 0.33858285259373117`, 0.935299232199999], 
             UndirectedEdge[235, 298] -> 
             RGBColor[
              0.33431581918328446`, 0.4594951311953859, 0.9426878395174293], 
             UndirectedEdge[15, 196] -> 
             RGBColor[
              0.23071789586563907`, 0.35982951528724394`, 0.9364504149017838],
              UndirectedEdge[13, 274] -> 
             RGBColor[
              0.3981676494624695, 0.5190303850989934, 0.9466648547482157], 
             UndirectedEdge[2, 172] -> 
             RGBColor[
              0.19458761473709335`, 0.321854299029009, 0.9343928488414741], 
             UndirectedEdge[247, 295] -> 
             RGBColor[
              0.1973396127760572, 0.3247468234547135, 0.9345495710585769], 
             UndirectedEdge[159, 225] -> 
             RGBColor[
              0.2594187152635208, 0.38999589621147046`, 0.9380848841074358], 
             UndirectedEdge[204, 254] -> 
             RGBColor[
              0.40119508956919725`, 0.5210943009518455, 0.9470120206751078], 
             UndirectedEdge[61, 252] -> 
             RGBColor[
              0.2576007602350303, 0.3880851102115208, 0.9379813542579867], 
             UndirectedEdge[4, 173] -> 
             RGBColor[
              0.21091230660044274`, 0.33901258522263467`, 0.9353225158928745],
              UndirectedEdge[230, 245] -> 
             RGBColor[
              0.20866400795240445`, 0.3366494807931788, 0.9351944786109285], 
             UndirectedEdge[137, 295] -> 
             RGBColor[
              0.2292284865221631, 0.35826405163324404`, 0.9363655952430565], 
             UndirectedEdge[109, 192] -> 
             RGBColor[
              0.6617142280646152, 0.7260405303844142, 0.8555444013688691], 
             UndirectedEdge[178, 229] -> 
             RGBColor[
              0.23836184028178953`, 0.36786378552268634`, 0.9368857262280812],
              UndirectedEdge[91, 93] -> 
             RGBColor[
              0.3656444287828603, 0.48387268995411137`, 0.9450248073537576], 
             UndirectedEdge[143, 185] -> 
             RGBColor[
              0.41822549913320267`, 0.5344264087640556, 0.9484481661960105], 
             UndirectedEdge[139, 273] -> 
             RGBColor[
              0.3398266519904991, 0.46230754637230465`, 0.9431107790825377], 
             UndirectedEdge[130, 281] -> 
             RGBColor[
              0.9451323785335899, 0.8357466481470239, 0.5846180445889815], 
             UndirectedEdge[220, 248] -> 
             RGBColor[
              0.27752408340790014`, 0.40677506874540165`, 0.9391983678257189],
              UndirectedEdge[88, 273] -> 
             RGBColor[
              0.23089430452924603`, 0.3600149319776501, 0.936460461114203], 
             UndirectedEdge[24, 218] -> 
             RGBColor[
              0.945476791560533, 0.8552536816107574, 0.5989703095762722], 
             UndirectedEdge[66, 215] -> 
             RGBColor[
              0.3055417316872413, 0.4312998537559559, 0.940974206355727], 
             UndirectedEdge[151, 154] -> 
             RGBColor[
              0.5475628360948273, 0.6435752036232633, 0.9575252987275946], 
             UndirectedEdge[8, 64] -> 
             RGBColor[
              0.21988638356939655`, 0.34844490910634823`, 0.9358335763002992],
              UndirectedEdge[71, 108] -> 
             RGBColor[
              0.23200115605283045`, 0.3611783031073773, 0.936523494671031], 
             UndirectedEdge[43, 182] -> 
             RGBColor[
              0.23996509971424826`, 0.36954891283871966`, 0.9369770294809499],
              UndirectedEdge[58, 297] -> 
             RGBColor[
              0.19156703343003767`, 0.3186794765593771, 0.934220831204587], 
             UndirectedEdge[46, 207] -> 
             RGBColor[
              0.1949982416588687, 0.3222858939590454, 0.9344162334372013], 
             UndirectedEdge[100, 266] -> 
             RGBColor[
              0.1894062944527255, 0.3164084028954582, 0.9340977803163559], 
             UndirectedEdge[12, 151] -> 
             RGBColor[
              0.5137240937710055, 0.6154599354387978, 0.9550391768879118], 
             UndirectedEdge[196, 265] -> 
             RGBColor[
              0.21288778030859679`, 0.34108893334217194`, 0.9354350161981024],
              UndirectedEdge[93, 139] -> 
             RGBColor[
              0.3409266080048823, 0.4634636698846607, 0.9431734199503177], 
             UndirectedEdge[30, 104] -> 
             RGBColor[
              0.2921921290764705, 0.4220073511871032, 0.9400404564262714], 
             UndirectedEdge[85, 121] -> 
             RGBColor[
              0.22879896787362192`, 0.35781260030057205`, 0.936341134791438], 
             UndirectedEdge[79, 160] -> 
             RGBColor[
              0.1894526235362595, 0.316457097699686, 0.9341004186891254], 
             UndirectedEdge[60, 196] -> 
             RGBColor[
              0.24516356622564123`, 0.3750128307440074, 0.9372730744583317], 
             UndirectedEdge[25, 297] -> 
             RGBColor[
              0.19155439006973912`, 0.318666187586068, 0.9342201111839221], 
             UndirectedEdge[9, 133] -> 
             RGBColor[
              0.19212471165815448`, 0.3192656317359698, 0.9342525901546672], 
             UndirectedEdge[151, 192] -> 
             RGBColor[
              0.4642226762503304, 0.5725842955959759, 0.9518849903358793], 
             UndirectedEdge[45, 141] -> 
             RGBColor[
              0.2968912603514489, 0.4293819169954668, 0.9402188901145307], 
             UndirectedEdge[177, 280] -> 
             RGBColor[
              0.27699231630764354`, 0.4084668651395046, 0.9390856746890857], 
             UndirectedEdge[141, 188] -> 
             RGBColor[
              0.3248560928052687, 0.45441830964122576`, 0.9419709558048517], 
             UndirectedEdge[129, 183] -> 
             RGBColor[
              0.1909140048229797, 0.31799310208895415`, 0.9341836421914842], 
             UndirectedEdge[41, 55] -> 
             RGBColor[
              0.19536579579315563`, 0.32267221665845913`, 0.9344371651014012],
              UndirectedEdge[120, 261] -> 
             RGBColor[
              0.2619133763504623, 0.3926179431844944, 0.9382269513658168], 
             UndirectedEdge[71, 279] -> 
             RGBColor[
              0.22999178600981598`, 0.35906632779075, 0.9364090640196779], 
             UndirectedEdge[180, 230] -> 
             RGBColor[
              0.1934850620461379, 0.3206954462449366, 0.9343300600968047], 
             UndirectedEdge[106, 194] -> 
             RGBColor[
              0.7739330746560312, 0.8236601401446212, 0.9780122537987794], 
             UndirectedEdge[90, 234] -> 
             RGBColor[
              0.20491562163947707`, 0.33270968911687326`, 0.9349810135556479],
              UndirectedEdge[44, 136] -> 
             RGBColor[
              0.3544174046992013, 0.48140027523890294`, 0.9438041415217957], 
             UndirectedEdge[120, 131] -> 
             RGBColor[
              0.2542490675591432, 0.38456226869957383`, 0.93779048031848], 
             UndirectedEdge[44, 279] -> 
             RGBColor[
              0.27644302038079716`, 0.4071985613343865, 0.9390796924908837], 
             UndirectedEdge[105, 139] -> 
             RGBColor[
              0.3622816914289454, 0.48590921655384295`, 0.9443895603593033], 
             UndirectedEdge[157, 184] -> 
             RGBColor[
              0.18701393581723674`, 0.31389388228526116`, 0.9339615390312422],
              UndirectedEdge[83, 149] -> 
             RGBColor[
              0.8628696595923687, 0.44534910675306505`, 0.20631412788053274`],
              UndirectedEdge[145, 168] -> 
             RGBColor[
              0.6326576416445393, 0.7081764296337532, 0.9668556680760403], 
             UndirectedEdge[112, 170] -> 
             RGBColor[
              0.1934039006537554, 0.3206101404756131, 0.9343254380755761], 
             UndirectedEdge[159, 270] -> 
             RGBColor[
              0.2520399731872973, 0.38224037045009085`, 0.9376646756620657], 
             UndirectedEdge[86, 162] -> 
             RGBColor[
              0.7927626721159106, 0.8360545204331631, 0.8771199562466196], 
             UndirectedEdge[3, 264] -> 
             RGBColor[
              0.6252141606717125, 0.697021267014214, 0.9512803143951285], 
             UndirectedEdge[60, 282] -> 
             RGBColor[
              0.36394977931359895`, 0.4876708967869795, 0.9444842474150733], 
             UndirectedEdge[135, 186] -> 
             RGBColor[
              0.20309625090443267`, 0.3307974151195744, 0.934877403083805], 
             UndirectedEdge[89, 294] -> 
             RGBColor[
              0.4583968818459615, 0.569215720181254, 0.9510502956112238], 
             UndirectedEdge[201, 203] -> 
             RGBColor[
              0.8759510922102913, 0.5506721053262738, 0.4578210075797024], 
             UndirectedEdge[181, 203] -> 
             RGBColor[
              0.961709527951959, 0.9590285203678879, 0.6962850331189814], 
             UndirectedEdge[70, 211] -> 
             RGBColor[
              0.24025127894135917`, 0.3698497053512242, 0.9369933269645696], 
             UndirectedEdge[156, 159] -> 
             RGBColor[
              0.3428661620319342, 0.4697766941100199, 0.9431273668629003], 
             UndirectedEdge[56, 270] -> 
             RGBColor[
              0.20609791902538932`, 0.3339523586314509, 0.9350483436427234], 
             UndirectedEdge[113, 264] -> 
             RGBColor[
              0.28192127958218227`, 0.41364751805536637`, 0.939366371855823], 
             UndirectedEdge[144, 240] -> 
             RGBColor[
              0.18908519234139687`, 0.31607090421740214`, 0.9340794940261437],
              UndirectedEdge[231, 232] -> 
             RGBColor[
              0.20954424282732975`, 0.33757466345683984`, 0.9352446066848648],
              UndirectedEdge[90, 248] -> 
             RGBColor[
              0.21881740302399694`, 0.347321342775852, 0.9357726994396538], 
             UndirectedEdge[27, 109] -> 
             RGBColor[
              0.9813263327288758, 0.9506128482774708, 0.5530707745780536], 
             UndirectedEdge[42, 145] -> 
             RGBColor[
              0.8467044438902113, 0.49173965579450474`, 0.4514212603342903], 
             UndirectedEdge[160, 230] -> 
             RGBColor[
              0.19392496192438957`, 0.3211578089082423, 0.9343551117440977], 
             UndirectedEdge[247, 251] -> 
             RGBColor[
              0.24168185283923999`, 0.37135332922152087`, 0.9370747960317096],
              UndirectedEdge[109, 220] -> 
             RGBColor[
              0.6629503007752218, 0.7271111544395208, 0.8556231628289728], 
             UndirectedEdge[139, 163] -> 
             RGBColor[
              0.5309367698880918, 0.6297354344441368, 0.9563109238850767], 
             UndirectedEdge[31, 279] -> 
             RGBColor[
              0.32815763679560045`, 0.4519911628206914, 0.9423749021193952], 
             UndirectedEdge[9, 112] -> 
             RGBColor[
              0.19409572030031721`, 0.3213372867880486, 0.9343648361809924], 
             UndirectedEdge[196, 276] -> 
             RGBColor[
              0.22221678398010425`, 0.35089430769392205`, 0.9359662891561706],
              UndirectedEdge[137, 251] -> 
             RGBColor[
              0.27357072658534587`, 0.4048705574000514, 0.9388908202161892], 
             UndirectedEdge[162, 181] -> 
             RGBColor[
              0.9888211205061603, 0.9780593840975029, 0.5971500192561076], 
             UndirectedEdge[96, 236] -> 
             RGBColor[
              0.2161907003932258, 0.34456051176834573`, 0.9356231126106896], 
             UndirectedEdge[251, 295] -> 
             RGBColor[
              0.24126505067228732`, 0.3709152437172699, 0.9370510597649051], 
             UndirectedEdge[20, 268] -> 
             RGBColor[
              0.21202685048114545`, 0.34018404150741677`, 0.9353859875180606],
              UndirectedEdge[187, 215] -> 
             RGBColor[
              0.224740944415305, 0.35354736035233314`, 0.9361100363587946], 
             UndirectedEdge[55, 250] -> 
             RGBColor[
              0.1923953966842939, 0.31955013886086425`, 0.9342680052664631], 
             UndirectedEdge[193, 230] -> 
             RGBColor[
              0.2358246326636532, 0.3651970194477707, 0.9367412360076905], 
             UndirectedEdge[55, 242] -> 
             RGBColor[
              0.19150951150427703`, 0.318619017368302, 0.9342175554160109], 
             UndirectedEdge[51, 116] -> 
             RGBColor[
              0.5493242790295518, 0.6359329023080253, 0.960750884061716], 
             UndirectedEdge[130, 203] -> 
             RGBColor[
              0.92446413705714, 0.8203323074950271, 0.6196039862679017], 
             UndirectedEdge[34, 124] -> 
             RGBColor[
              0.1848087064384265, 0.3115760463885134, 0.9338359544804635], 
             UndirectedEdge[190, 261] -> 
             RGBColor[
              0.2245754678269734, 0.353373433966175, 0.9361006127118898], 
             UndirectedEdge[76, 85] -> 
             RGBColor[
              0.2795331222505161, 0.40945731042738504`, 0.9392918866244364], 
             UndirectedEdge[130, 237] -> 
             RGBColor[
              0.8539841698020644, 0.35850563187745466`, 0.19706087949209944`],
              UndirectedEdge[175, 183] -> 
             RGBColor[
              0.18767445593923526`, 0.3145881308128762, 0.9339991546750381], 
             UndirectedEdge[93, 289] -> 
             RGBColor[
              0.24228732684798865`, 0.37198972079398507`, 0.9371092768807893],
              UndirectedEdge[69, 234] -> 
             RGBColor[
              0.20086201360397116`, 0.32844909005796263`, 0.9347501665748015],
              UndirectedEdge[32, 269] -> 
             RGBColor[
              0.980420530285405, 0.9551564158081671, 0.6020762664235486], 
             UndirectedEdge[226, 243] -> 
             RGBColor[
              0.9868373224355939, 0.9888249088088037, 0.8678031613671959], 
             UndirectedEdge[72, 218] -> 
             RGBColor[
              0.875340160780385, 0.47642064776789905`, 0.430675613342974], 
             UndirectedEdge[81, 181] -> 
             RGBColor[
              0.9378794291938042, 0.7781980948822975, 0.31536710248397326`], 
             UndirectedEdge[8, 67] -> 
             RGBColor[
              0.1916976136601492, 0.31881672466048916`, 0.9342282675555156], 
             UndirectedEdge[145, 156] -> 
             RGBColor[
              0.6296976932681398, 0.7056126711214472, 0.9666670627828757], 
             UndirectedEdge[20, 177] -> 
             RGBColor[
              0.2554879446971804, 0.38586440712099823`, 0.9378610325387366], 
             UndirectedEdge[180, 297] -> 
             RGBColor[
              0.19343887791696943`, 0.3206469037969376, 0.9343274299789719], 
             UndirectedEdge[140, 216] -> 
             RGBColor[
              0.8337005726178471, 0.2515929185371857, 0.1795741305714151], 
             UndirectedEdge[287, 300] -> 
             RGBColor[
              0.2343234420650949, 0.3636191729477046, 0.9366557454239152], 
             UndirectedEdge[140, 167] -> 
             RGBColor[
              0.847440007720582, 0.31331700517270195`, 0.1910043309119193], 
             UndirectedEdge[248, 285] -> 
             RGBColor[
              0.21081919728396287`, 0.3389147214275427, 0.9353172134550438], 
             UndirectedEdge[185, 292] -> 
             RGBColor[
              0.6516360083701964, 0.726054278090207, 0.9670940826236099], 
             UndirectedEdge[23, 241] -> 
             RGBColor[
              0.9877354309295805, 0.9891962997514028, 0.8529191793915591], 
             UndirectedEdge[10, 48] -> 
             RGBColor[
              0.19160641114189197`, 0.3187208650312271, 0.934223073707023], 
             UndirectedEdge[46, 62] -> 
             RGBColor[
              0.20319287451419632`, 0.3308989726597267, 0.9348829056554392], 
             UndirectedEdge[15, 276] -> 
             RGBColor[
              0.24987495920564082`, 0.37996480348555506`, 0.9375413813186614],
              UndirectedEdge[85, 154] -> 
             RGBColor[
              0.36472305205370464`, 0.48205039622074985`, 0.9450500607222323],
              UndirectedEdge[32, 179] -> 
             RGBColor[
              0.7552164634617963, 0.8063041539020928, 0.9047369408488604], 
             UndirectedEdge[145, 277] -> 
             RGBColor[
              0.9289575250796454, 0.9412874203114796, 0.7338327759362018], 
             UndirectedEdge[58, 164] -> 
             RGBColor[
              0.1865510290497441, 0.3134073379226422, 0.9339351771756428], 
             UndirectedEdge[18, 253] -> 
             RGBColor[
              0.19591234458530662`, 0.3232466740922047, 0.9344682902465677], 
             UndirectedEdge[59, 136] -> 
             RGBColor[
              0.6888115905499252, 0.7512769242124885, 0.9221815319720392], 
             UndirectedEdge[232, 288] -> 
             RGBColor[
              0.19838654644971515`, 0.32584721712515685`, 0.9346091923824922],
              UndirectedEdge[136, 177] -> 
             RGBColor[
              0.34229360740819775`, 0.46934835455154167`, 0.9430884098094023],
              UndirectedEdge[31, 65] -> 
             RGBColor[
              0.3985559674737674, 0.5196308798455622, 0.9466166117115924], 
             UndirectedEdge[62, 214] -> 
             RGBColor[
              0.20125370240405008`, 0.3288607798213499, 0.9347724726725144], 
             UndirectedEdge[24, 109] -> 
             RGBColor[
              0.9582875876148832, 0.8633759964057863, 0.5131590613985512], 
             UndirectedEdge[71, 268] -> 
             RGBColor[
              0.21418318831071842`, 0.34245048928601285`, 0.9355087877674388],
              UndirectedEdge[64, 118] -> 
             RGBColor[
              0.2120127678097534, 0.3401692397268907, 0.9353851855307582], 
             UndirectedEdge[21, 206] -> 
             RGBColor[
              0.20800021126608947`, 0.33595178838872103`, 0.9351566763716421],
              UndirectedEdge[6, 124] -> 
             RGBColor[
              0.19825974011141095`, 0.3257139356236129, 0.9346019709491189], 
             UndirectedEdge[7, 140] -> 
             RGBColor[
              0.8576525620588931, 0.4072578344865292, 0.4392429539624352], 
             UndirectedEdge[78, 229] -> 
             RGBColor[
              0.20592187570768378`, 0.3337673259427514, 0.9350383182362128], 
             UndirectedEdge[67, 213] -> 
             RGBColor[
              0.19065103236232478`, 0.3177167013593888, 0.9341686662988828], 
             UndirectedEdge[189, 300] -> 
             RGBColor[
              0.22074088939765935`, 0.34934304891065115`, 0.9358822391430908],
              UndirectedEdge[77, 225] -> 
             RGBColor[
              0.32068966156322254`, 0.4446841856418027, 0.9419297543163823], 
             UndirectedEdge[153, 239] -> 
             RGBColor[
              0.22932262896951866`, 0.3583630013143907, 0.9363709565161622], 
             UndirectedEdge[7, 168] -> 
             RGBColor[
              0.6693655533207783, 0.7373787417141351, 0.9680138507113893], 
             UndirectedEdge[5, 256] -> 
             RGBColor[
              0.868956298803952, 0.39716627197470655`, 0.223830917733355], 
             UndirectedEdge[193, 200] -> 
             RGBColor[
              0.3225670309120143, 0.4511149836272068, 0.9418734544780243], 
             UndirectedEdge[17, 202] -> 
             RGBColor[
              0.8122682039505371, 0.5808158857565188, 0.4639498679202687], 
             UndirectedEdge[12, 220] -> 
             RGBColor[
              0.38135478455479077`, 0.5047320797577364, 0.9455205675464041], 
             UndirectedEdge[196, 207] -> 
             RGBColor[
              0.19417373721693681`, 0.32141928751397403`, 0.9343692791289782],
              UndirectedEdge[222, 285] -> 
             RGBColor[
              0.21055261927690455`, 0.33863453104010255`, 0.9353020322319088],
              UndirectedEdge[169, 227] -> 
             RGBColor[
              0.7787217249901721, 0.7700947212036731, 0.6214147685810579], 
             UndirectedEdge[139, 298] -> 
             RGBColor[
              0.350430471977903, 0.4734528335000848, 0.9437146509438744], 
             UndirectedEdge[210, 241] -> 
             RGBColor[
              0.7289016289330998, 0.7852496727746727, 0.9155863904520005], 
             UndirectedEdge[58, 288] -> 
             RGBColor[
              0.200003126765576, 0.32754634553423856`, 0.9347012542399642], 
             UndirectedEdge[85, 258] -> 
             RGBColor[
              0.2861550048473763, 0.41519285230728875`, 0.9397138271280076], 
             UndirectedEdge[87, 162] -> 
             RGBColor[
              0.9922481634967688, 0.9892215006042993, 0.6443153424349913], 
             UndirectedEdge[222, 248] -> 
             RGBColor[
              0.22169214906401963`, 0.3503428831333422, 0.9359364119738274], 
             UndirectedEdge[76, 87] -> 
             RGBColor[
              0.6600329022141906, 0.7226670785503484, 0.7188188011286823], 
             UndirectedEdge[80, 282] -> 
             RGBColor[
              0.7097202776306235, 0.7481265393121519, 0.6607363832345532], 
             UndirectedEdge[273, 289] -> 
             RGBColor[
              0.24118737083360547`, 0.370833597281629, 0.9370466360130092], 
             UndirectedEdge[215, 296] -> 
             RGBColor[
              0.20597442651804665`, 0.33382256017635653`, 0.935041310927121], 
             UndirectedEdge[142, 277] -> 
             RGBColor[
              0.8842941238717467, 0.48322242431774326`, 0.2777627936730913], 
             UndirectedEdge[134, 180] -> 
             RGBColor[
              0.21984183187712564`, 0.34839808245303105`, 0.9358310391473328],
              UndirectedEdge[86, 178] -> 
             RGBColor[
              0.4265942001520806, 0.5354932240498018, 0.9496283130255976], 
             UndirectedEdge[3, 210] -> 
             RGBColor[
              0.7129487102103079, 0.7736730218742174, 0.9569659936880668], 
             UndirectedEdge[79, 176] -> 
             RGBColor[
              0.18866673983198834`, 0.31563108409859225`, 0.9340556637747779],
              UndirectedEdge[131, 141] -> 
             RGBColor[
              0.26162779894186294`, 0.392317783221403, 0.938210688154871], 
             UndirectedEdge[150, 256] -> 
             RGBColor[
              0.8477552075952007, 0.3160779656240866, 0.191320067694982], 
             UndirectedEdge[74, 300] -> 
             RGBColor[
              0.2157736566163444, 0.3441221723167407, 0.9355993625845572], 
             UndirectedEdge[25, 230] -> 
             RGBColor[
              0.19160057419890764`, 0.31871473003406703`, 0.934222741301755], 
             UndirectedEdge[165, 253] -> 
             RGBColor[
              0.20482209384336109`, 0.3326113854731506, 0.9349756872860211], 
             UndirectedEdge[223, 295] -> 
             RGBColor[
              0.1892065910771333, 0.3161985019857855, 0.9340864075045505], 
             UndirectedEdge[164, 221] -> 
             RGBColor[
              0.184078374522518, 0.31080842123917557`, 0.9337943631582817], 
             UndirectedEdge[70, 138] -> 
             RGBColor[
              0.22052881830414905`, 0.3491201487452879, 0.9358701620080464], 
             UndirectedEdge[165, 224] -> 
             RGBColor[
              0.21323098705618415`, 0.3414496653944509, 0.9354545613146487], 
             UndirectedEdge[87, 258] -> 
             RGBColor[
              0.6666547848110509, 0.7284026204302521, 0.7192407416322534], 
             UndirectedEdge[90, 222] -> 
             RGBColor[
              0.2185508250169386, 0.3470411523884118, 0.9357575182165185], 
             UndirectedEdge[163, 185] -> 
             RGBColor[
              0.5753534134295759, 0.6661368462548543, 0.9597130747756251], 
             UndirectedEdge[64, 286] -> 
             RGBColor[
              0.22809764059378232`, 0.35707546086274283`, 0.9363011952403719],
              UndirectedEdge[131, 199] -> 
             RGBColor[
              0.21390129447571837`, 0.3421542009923264, 0.9354927343305601], 
             UndirectedEdge[2, 49] -> 
             RGBColor[
              0.20410648254439653`, 0.3318592326255619, 0.934934934281197], 
             UndirectedEdge[51, 283] -> 
             RGBColor[
              0.5585587587049552, 0.6456389259467026, 0.9612767740180419], 
             UndirectedEdge[66, 187] -> 
             RGBColor[
              0.305540960778381, 0.4312990434818653, 0.9409741624536079], 
             UndirectedEdge[120, 170] -> 
             RGBColor[
              0.23833338730926568`, 0.3678338796445412, 0.9368841058733883], 
             UndirectedEdge[17, 182] -> 
             RGBColor[
              0.47900337512465124`, 0.5765439495002909, 0.9544470440825916], 
             UndirectedEdge[156, 179] -> 
             RGBColor[
              0.4586241439822036, 0.5697734899723961, 0.9509650514168311], 
             UndirectedEdge[199, 284] -> 
             RGBColor[
              0.21967623885350168`, 0.3482240336859982, 0.9358216088696103], 
             UndirectedEdge[210, 291] -> 
             RGBColor[
              0.6992769373373419, 0.7632490848408453, 0.9722193956891239], 
             UndirectedEdge[212, 265] -> 
             RGBColor[
              0.22804223773896515`, 0.3570172289495861, 0.9362980401297512], 
             UndirectedEdge[85, 173] -> 
             RGBColor[
              0.21671771694106706`, 0.34511443957490595`, 0.9356531254234381],
              UndirectedEdge[47, 146] -> 
             RGBColor[
              0.19206431623757236`, 0.3192021523196471, 0.9342491507248121], 
             UndirectedEdge[198, 283] -> 
             RGBColor[
              0.6352059189617083, 0.705940028417498, 0.9427748448450561], 
             UndirectedEdge[168, 212] -> 
             RGBColor[
              0.31689002798285826`, 0.4419267953395609, 0.941668105069032], 
             UndirectedEdge[56, 271] -> 
             RGBColor[
              0.21099595483626973`, 0.3391005048220933, 0.9353272795361584], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.33246233459167696`, 0.45559373221858496`, 0.9426538050639501],
              UndirectedEdge[159, 191] -> 
             RGBColor[
              0.25930875612416715`, 0.38988032218419766`, 0.9380786220971196],
              UndirectedEdge[72, 83] -> 
             RGBColor[
              0.8351278328210138, 0.271013492942614, 0.1812717584216026], 
             UndirectedEdge[179, 277] -> 
             RGBColor[
              0.7578839757937091, 0.8054482391624284, 0.7181307645701571], 
             UndirectedEdge[86, 182] -> 
             RGBColor[
              0.4242603384632414, 0.5330401874394541, 0.9494954030550571], 
             UndirectedEdge[80, 293] -> 
             RGBColor[
              0.9392835874613179, 0.7889438610995526, 0.30512184711932616`], 
             UndirectedEdge[9, 96] -> 
             RGBColor[
              0.19995528537104273`, 0.3274960611952644, 0.9346985297433206], 
             UndirectedEdge[51, 226] -> 
             RGBColor[
              0.8987769385879059, 0.920547716985024, 0.9296222387004919], 
             UndirectedEdge[185, 235] -> 
             RGBColor[
              0.4690251433139141, 0.5785976856950342, 0.951678806922862], 
             UndirectedEdge[136, 210] -> 
             RGBColor[
              0.43214727310106515`, 0.5482274348494092, 0.9488947696323751], 
             UndirectedEdge[78, 284] -> 
             RGBColor[
              0.2175445595822431, 0.34598350361563335`, 0.935700212888649], 
             UndirectedEdge[81, 216] -> 
             RGBColor[
              0.8741307766845507, 0.521339079076086, 0.216683973539649], 
             UndirectedEdge[2, 165] -> 
             RGBColor[
              0.2081927032562806, 0.336154109675109, 0.935167638505717], 
             UndirectedEdge[181, 216] -> 
             RGBColor[
              0.9064071332493737, 0.6461593249941886, 0.2739426170686603], 
             UndirectedEdge[7, 203] -> 
             RGBColor[
              0.9377223890197792, 0.9530740402179558, 0.990303930173889], 
             UndirectedEdge[44, 177] -> 
             RGBColor[
              0.3040955168977345, 0.4362630884432308, 0.9406544612593207], 
             UndirectedEdge[140, 237] -> 
             RGBColor[
              0.8199042211924654, 0.15399814293643901`, 0.1666936107334946], 
             UndirectedEdge[38, 124] -> 
             RGBColor[
              0.186021974396972, 0.31285126793857626`, 0.9339050482958335], 
             UndirectedEdge[5, 59] -> 
             RGBColor[
              0.978010186853574, 0.9509747189595588, 0.6200075845730131], 
             UndirectedEdge[35, 253] -> 
             RGBColor[
              0.19912169776175326`, 0.3266199077653942, 0.9346510581621539], 
             UndirectedEdge[200, 231] -> 
             RGBColor[
              0.2983755222047893, 0.4256881741456715, 0.9404957838452779], 
             UndirectedEdge[213, 234] -> 
             RGBColor[
              0.19826511451334394`, 0.3257195844608012, 0.9346022770133582], 
             UndirectedEdge[53, 88] -> 
             RGBColor[
              0.21936792560639845`, 0.34789997691510377`, 0.9358040508862964],
              UndirectedEdge[150, 269] -> 
             RGBColor[
              0.9402871560451271, 0.7958786263011822, 0.2973043850963], 
             UndirectedEdge[4, 135] -> 
             RGBColor[
              0.21680708920312736`, 0.3452083754888601, 0.935658215041548], 
             UndirectedEdge[91, 139] -> 
             RGBColor[
              0.4654409733450266, 0.5765629962584664, 0.9511548548621985], 
             UndirectedEdge[28, 232] -> 
             RGBColor[
              0.18568890069969585`, 0.3125011863646469, 0.9338860802415121], 
             UndirectedEdge[127, 276] -> 
             RGBColor[
              0.29510454675664893`, 0.4237974430003376, 0.9402528534454749], 
             UndirectedEdge[60, 103] -> 
             RGBColor[
              0.35429852491084235`, 0.47931146530946245`, 0.9438692780187988],
              UndirectedEdge[145, 159] -> 
             RGBColor[
              0.5780723315879956, 0.6592789022873965, 0.963436800696632], 
             UndirectedEdge[20, 252] -> 
             RGBColor[
              0.2284732256377411, 0.3574702245574107, 0.936322584252997], 
             UndirectedEdge[80, 128] -> 
             RGBColor[
              0.889562972527344, 0.5443500198966912, 0.25117046231774093`], 
             UndirectedEdge[167, 237] -> 
             RGBColor[
              0.8526104501055128, 0.35305929104558004`, 0.1959555523789085], 
             UndirectedEdge[24, 291] -> 
             RGBColor[
              0.9253194185531315, 0.839992794616319, 0.6252021408895034], 
             UndirectedEdge[22, 244] -> 
             RGBColor[
              0.18902260313051494`, 0.31600511898838, 0.9340759296631764], 
             UndirectedEdge[51, 83] -> 
             RGBColor[
              0.8348006374064919, 0.5233895828676642, 0.45541678825261045`], 
             UndirectedEdge[29, 229] -> 
             RGBColor[
              0.20648377022612274`, 0.3343579127078008, 0.9350703172977894], 
             UndirectedEdge[151, 181] -> 
             RGBColor[
              0.7920610111090953, 0.8249056195457978, 0.6813687144574905], 
             UndirectedEdge[22, 63] -> 
             RGBColor[
              0.18571205303560948`, 0.312525520937635, 0.9338873987327916], 
             UndirectedEdge[163, 292] -> 
             RGBColor[
              0.6974329821497556, 0.7632343245346107, 0.9706993881593793], 
             UndirectedEdge[247, 289] -> 
             RGBColor[
              0.22060050259813557`, 0.34919549348331447`, 0.9358742443225416],
              UndirectedEdge[155, 299] -> 
             RGBColor[
              0.8545672117145955, 0.3449853666875312, 0.19687926573825648`], 
             UndirectedEdge[31, 71] -> 
             RGBColor[
              0.32148269623256015`, 0.4449753770732606, 0.9419947741290198], 
             UndirectedEdge[45, 260] -> 
             RGBColor[
              0.2790511539192304, 0.41063083400712647`, 0.9392029224452882], 
             UndirectedEdge[80, 125] -> 
             RGBColor[
              0.8830657841456923, 0.4944097829092139, 0.2449487473859466], 
             UndirectedEdge[97, 261] -> 
             RGBColor[
              0.34679730240272766`, 0.46888200483462256`, 0.9435352867345028],
              UndirectedEdge[107, 147] -> 
             RGBColor[
              0.3109365240034128, 0.43492372492699083`, 0.9413563604380197], 
             UndirectedEdge[15, 286] -> 
             RGBColor[
              0.23963340623012278`, 0.3692002819563222, 0.9369581400277256], 
             UndirectedEdge[94, 202] -> 
             RGBColor[
              0.8433434284333755, 0.6050920873029656, 0.46704715588223444`], 
             UndirectedEdge[86, 130] -> 
             RGBColor[
              0.75299012475597, 0.6847273872222507, 0.6045439579169226], 
             UndirectedEdge[73, 161] -> 
             RGBColor[
              0.19216173018569271`, 0.31930454055552265`, 0.9342546983050465],
              UndirectedEdge[7, 167] -> 
             RGBColor[
              0.9230008546692128, 0.8126082594888467, 0.6169349273115317], 
             UndirectedEdge[288, 297] -> 
             RGBColor[
              0.20042924344964513`, 0.3279942211865534, 0.9347255209547387], 
             UndirectedEdge[15, 46] -> 
             RGBColor[
              0.23154240030757095`, 0.3606961217323153, 0.9364973692100068], 
             UndirectedEdge[1, 92] -> 
             RGBColor[
              0.8229805000264965, 0.17764377008878246`, 0.16963945881912273`],
              UndirectedEdge[85, 213] -> 
             RGBColor[
              0.21726177740977812`, 0.34568628162294734`, 0.9356841088622658],
              UndirectedEdge[2, 174] -> 
             RGBColor[
              0.21589796346133705`, 0.34425282669233714`, 0.9356064416754841],
              UndirectedEdge[104, 204] -> 
             RGBColor[
              0.40934807922423605`, 0.5281560108098651, 0.9475315219665212], 
             UndirectedEdge[125, 243] -> 
             RGBColor[
              0.8859354840896285, 0.5107054174164098, 0.4069530416143843], 
             UndirectedEdge[149, 243] -> 
             RGBColor[
              0.9414606577081649, 0.8037269245686582, 0.5463530672768225], 
             UndirectedEdge[35, 175] -> 
             RGBColor[
              0.19450102624862847`, 0.3217632890376051, 0.9343879177551523], 
             UndirectedEdge[82, 201] -> 
             RGBColor[
              0.7680559447436146, 0.4654815691448476, 0.44828646235642633`], 
             UndirectedEdge[39, 69] -> 
             RGBColor[
              0.20464654155210055`, 0.3324268688843776, 0.9349656898427401], 
             UndirectedEdge[5, 204] -> 
             RGBColor[
              0.7273105149978081, 0.7527675975931751, 0.6471903809836539], 
             UndirectedEdge[107, 277] -> 
             RGBColor[
              0.7007432409432577, 0.7578412318622451, 0.7139688588587303], 
             UndirectedEdge[236, 260] -> 
             RGBColor[
              0.2447992469285118, 0.3746299080635468, 0.9372523270133223], 
             UndirectedEdge[11, 51] -> 
             RGBColor[
              0.6715557743614986, 0.7416503460034106, 0.9690558457242018], 
             UndirectedEdge[41, 242] -> 
             RGBColor[
              0.18473837996455222`, 0.31150212880551553`, 0.933831949491815], 
             UndirectedEdge[53, 93] -> 
             RGBColor[
              0.22850372850548528`, 0.3575022850054033, 0.93632432134619], 
             UndirectedEdge[82, 293] -> 
             RGBColor[
              0.7565992079701278, 0.6673833817942012, 0.600389979606483], 
             UndirectedEdge[76, 151] -> 
             RGBColor[
              0.46237290629163863`, 0.5709821178298984, 0.9517671246297987], 
             UndirectedEdge[130, 269] -> 
             RGBColor[
              0.9424840400754735, 0.8045885394133, 0.29907204955461253`], 
             UndirectedEdge[13, 289] -> 
             RGBColor[
              0.2883666647778183, 0.41815288261871875`, 0.9398165114828785], 
             UndirectedEdge[86, 120] -> 
             RGBColor[
              0.4366336879326583, 0.5460453622474791, 0.9502000470026102], 
             UndirectedEdge[86, 284] -> 
             RGBColor[
              0.41756739126480746`, 0.526005475576538, 0.9491142496134344], 
             UndirectedEdge[49, 102] -> 
             RGBColor[
              0.20090857647606358`, 0.32849803058878846`, 0.9347528182614836],
              UndirectedEdge[27, 299] -> 
             RGBColor[
              0.8690764337400362, 0.3997735335743823, 0.222803191736427], 
             UndirectedEdge[120, 182] -> 
             RGBColor[
              0.2667169591353605, 0.3976668132561618, 0.9385005082991529], 
             UndirectedEdge[97, 182] -> 
             RGBColor[
              0.35160088518762583`, 0.47393087490628993`, 0.9438088436678389],
              UndirectedEdge[42, 130] -> 
             RGBColor[
              0.8623375503659444, 0.42271337536614007`, 0.20506008615386487`],
              UndirectedEdge[15, 127] -> 
             RGBColor[
              0.3036056586421837, 0.43273265059365945`, 0.9407369791910881], 
             UndirectedEdge[28, 176] -> 
             RGBColor[
              0.18883134167646898`, 0.3158040910735011, 0.9340650376063144], 
             UndirectedEdge[26, 35] -> 
             RGBColor[
              0.21774452951257628`, 0.3461936846912394, 0.9357116008803525], 
             UndirectedEdge[44, 59] -> 
             RGBColor[
              0.650613500039462, 0.7181916581041776, 0.9197475834219577], 
             UndirectedEdge[155, 218] -> 
             RGBColor[
              0.9467517036363646, 0.8603082831521655, 0.5999961337585191], 
             UndirectedEdge[65, 155] -> 
             RGBColor[
              0.6518886127524492, 0.6234637492866453, 0.6024205995762867], 
             UndirectedEdge[55, 252] -> 
             RGBColor[
              0.22003960441036646`, 0.34860595392497, 0.9358423020005227], 
             UndirectedEdge[160, 296] -> 
             RGBColor[
              0.1914857715941317, 0.31859406521754197`, 0.9342162034632482], 
             UndirectedEdge[88, 147] -> 
             RGBColor[
              0.21812810554997109`, 0.34659684742666674`, 0.9357334449682322],
              UndirectedEdge[204, 243] -> 
             RGBColor[
              0.7355129252278461, 0.7903594474546665, 0.9053392735975632], 
             UndirectedEdge[65, 106] -> 
             RGBColor[
              0.6196619973862446, 0.6970249085872788, 0.9659794196694249], 
             UndirectedEdge[115, 245] -> 
             RGBColor[
              0.2884856169676899, 0.4165730051879058, 0.9398857105111442], 
             UndirectedEdge[60, 205] -> 
             RGBColor[
              0.3298135622578278, 0.45810382130942706`, 0.9423091178497511], 
             UndirectedEdge[75, 111] -> 
             RGBColor[
              0.4735665439631073, 0.5802328466571501, 0.952603227994324], 
             UndirectedEdge[17, 86] -> 
             RGBColor[
              0.648920103921949, 0.7249224984916083, 0.966146582786049], 
             UndirectedEdge[67, 166] -> 
             RGBColor[
              0.1825106958270533, 0.309160691533672, 0.9337050861757479], 
             UndirectedEdge[3, 169] -> 
             RGBColor[
              0.7794786659769637, 0.8276850371059405, 0.962203475513276], 
             UndirectedEdge[7, 255] -> 
             RGBColor[
              0.6521687790491231, 0.722483760175034, 0.9669180874613099], 
             UndirectedEdge[211, 231] -> 
             RGBColor[
              0.25095672851015194`, 0.3811018116127316, 0.937602986480219], 
             UndirectedEdge[218, 290] -> 
             RGBColor[
              0.956800253470921, 0.9001474347654498, 0.6080814328251828], 
             UndirectedEdge[201, 269] -> 
             RGBColor[
              0.8879643608891803, 0.5401762599384556, 0.244133049770843], 
             UndirectedEdge[34, 223] -> 
             RGBColor[
              0.1825916590093845, 0.3092457889716643, 0.9337096969092074], 
             UndirectedEdge[63, 208] -> 
             RGBColor[
              0.1860996055764639, 0.3129328632303233, 0.9339094692766605], 
             UndirectedEdge[131, 190] -> 
             RGBColor[
              0.21691115903565433`, 0.3453177594812544, 0.9356641416645529], 
             UndirectedEdge[27, 181] -> 
             RGBColor[
              0.9780677338465346, 0.9376794577026863, 0.3692977168650637], 
             UndirectedEdge[108, 136] -> 
             RGBColor[
              0.3166504809342749, 0.4423958027593246, 0.9416280716923184], 
             UndirectedEdge[101, 254] -> 
             RGBColor[
              0.4830549298600605, 0.587475687952538, 0.9535083702036646], 
             UndirectedEdge[62, 212] -> 
             RGBColor[
              0.2175228275026328, 0.34596066182206947`, 0.9356989752788649], 
             UndirectedEdge[69, 195] -> 
             RGBColor[
              0.1956464700099377, 0.32296722305607023`, 0.9344531490828267], 
             UndirectedEdge[136, 252] -> 
             RGBColor[
              0.3152788883487585, 0.44095417198795417`, 0.9415499615236627], 
             UndirectedEdge[26, 175] -> 
             RGBColor[
              0.20585209939384108`, 0.33369398661282884`, 0.9350343445783642],
              UndirectedEdge[24, 27] -> 
             RGBColor[
              0.9468027585380377, 0.8226935997742366, 0.2974286527731346], 
             UndirectedEdge[231, 266] -> 
             RGBColor[
              0.21466524015743277`, 0.342957156340762, 0.9355362399069774], 
             UndirectedEdge[153, 157] -> 
             RGBColor[
              0.2018036290672552, 0.32943878761174283`, 0.9348037901824403], 
             UndirectedEdge[161, 244] -> 
             RGBColor[
              0.19557921069497186`, 0.3228965292515542, 0.9344493187643406], 
             UndirectedEdge[128, 150] -> 
             RGBColor[
              0.865763307775837, 0.454496114812273, 0.2085646447651994], 
             UndirectedEdge[113, 200] -> 
             RGBColor[
              0.3166014610591278, 0.4448447914728484, 0.9415337241001722], 
             UndirectedEdge[211, 264] -> 
             RGBColor[
              0.28347133969758304`, 0.41527672951614025`, 0.9394546454862865],
              UndirectedEdge[144, 232] -> 
             RGBColor[
              0.19277383312180774`, 0.31994789955094727`, 0.9342895566617331],
              UndirectedEdge[208, 244] -> 
             RGBColor[
              0.18941015567136937`, 0.31641246128106837`, 0.9340980002070455],
              UndirectedEdge[47, 133] -> 
             RGBColor[
              0.18469446291568115`, 0.3114559692026503, 0.9338294484808514], 
             UndirectedEdge[181, 258] -> 
             RGBColor[
              0.6632277418204424, 0.717240503923456, 0.6720754184533696], 
             UndirectedEdge[53, 147] -> 
             RGBColor[
              0.21463757351182716`, 0.3429280769420639, 0.9355346643324394], 
             UndirectedEdge[123, 267] -> 
             RGBColor[
              0.19740462411574278`, 0.32481515449468, 0.9345532733581963], 
             UndirectedEdge[59, 227] -> 
             RGBColor[
              0.9688560866723765, 0.9191321953350291, 0.5894640490955131], 
             UndirectedEdge[213, 286] -> 
             RGBColor[
              0.21163290304685975`, 0.3397699777762725, 0.935363552794471], 
             UndirectedEdge[16, 126] -> 
             RGBColor[
              0.23513936956710785`, 0.3644767644851118, 0.9367022112880983], 
             UndirectedEdge[68, 109] -> 
             RGBColor[
              0.9348338843673183, 0.947970458954174, 0.8784588716115629], 
             UndirectedEdge[137, 156] -> 
             RGBColor[
              0.32801284307365003`, 0.4541649141300481, 0.9422814923217423], 
             UndirectedEdge[181, 202] -> 
             RGBColor[
              0.9064784784364304, 0.6464832868255209, 0.2740021492415709], 
             UndirectedEdge[135, 214] -> 
             RGBColor[
              0.20695344714813524`, 0.3348515729320728, 0.9350970647036734], 
             UndirectedEdge[166, 234] -> 
             RGBColor[
              0.19012477797807242`, 0.3171635746350845, 0.9341386968902232], 
             UndirectedEdge[63, 152] -> 
             RGBColor[
              0.18270109795627662`, 0.30936081624367795`, 0.9337159292953324],
              UndirectedEdge[130, 167] -> 
             RGBColor[
              0.9097426027065735, 0.6798665267659179, 0.24623498340554434`], 
             UndirectedEdge[30, 74] -> 
             RGBColor[
              0.22759891531018372`, 0.3565512689686714, 0.9362727935732689], 
             UndirectedEdge[31, 177] -> 
             RGBColor[
              0.3558101333125378, 0.4810556899295358, 0.9439496708878323], 
             UndirectedEdge[24, 72] -> 
             RGBColor[
              0.8608649753560598, 0.3965560252957622, 0.20304003335454723`], 
             UndirectedEdge[39, 285] -> 
             RGBColor[
              0.20070194384757245`, 0.3282808465949789, 0.9347410508389766], 
             UndirectedEdge[27, 72] -> 
             RGBColor[
              0.8762241387653882, 0.45471392654355186`, 0.22964784214088227`],
              UndirectedEdge[109, 151] -> 
             RGBColor[
              0.7953196099914366, 0.8378390101205823, 0.8651417721704804], 
             UndirectedEdge[29, 178] -> 
             RGBColor[
              0.22713326298795516`, 0.3560618388539467, 0.9362462753623888], 
             UndirectedEdge[149, 256] -> 
             RGBColor[
              0.8437866719113953, 0.2986689012185817, 0.18804023732608074`], 
             UndirectedEdge[93, 137] -> 
             RGBColor[
              0.25133211293896884`, 0.38149636444816565`, 0.9376243640681086],
              UndirectedEdge[7, 145] -> 
             RGBColor[
              0.9016117745004403, 0.9243171913792056, 0.9881346792519563], 
             UndirectedEdge[271, 278] -> 
             RGBColor[
              0.21163260011638724`, 0.339769659377139, 0.9353635355430288], 
             UndirectedEdge[15, 135] -> 
             RGBColor[
              0.2357262900418861, 0.3650936551170112, 0.9367356355408658], 
             UndirectedEdge[94, 130] -> 
             RGBColor[
              0.8543459981416374, 0.7646454516027577, 0.6141415308874059], 
             UndirectedEdge[265, 286] -> 
             RGBColor[
              0.22180329067308052`, 0.3504597000112502, 0.9359427413240442], 
             UndirectedEdge[140, 201] -> 
             RGBColor[
              0.8266673641279991, 0.20598262316708282`, 0.17317000404643912`],
              UndirectedEdge[29, 259] -> 
             RGBColor[
              0.19020824390880345`, 0.3172513026203284, 0.9341434501515016], 
             UndirectedEdge[21, 123] -> 
             RGBColor[
              0.1960904957019222, 0.3234339222112008, 0.934478435689108], 
             UndirectedEdge[21, 189] -> 
             RGBColor[
              0.20470683599275827`, 0.3324902421643972, 0.934969123521938], 
             UndirectedEdge[107, 289] -> 
             RGBColor[
              0.32595994240234355`, 0.45071429020400966`, 0.942211921890683], 
             UndirectedEdge[17, 66] -> 
             RGBColor[
              0.5450024443168381, 0.6387388987189666, 0.9584682781320619], 
             UndirectedEdge[71, 208] -> 
             RGBColor[
              0.20631669235829492`, 0.33418230327536513`, 0.9350608024603861],
              UndirectedEdge[6, 289] -> 
             RGBColor[
              0.22701980203641853`, 0.3559425842000419, 0.9362398139290493], 
             UndirectedEdge[96, 132] -> 
             RGBColor[
              0.1989233882773373, 0.32641147192372544`, 0.9346397647303889], 
             UndirectedEdge[55, 283] -> 
             RGBColor[
              0.25397885208056453`, 0.38427825509893676`, 0.9377750919467229],
              UndirectedEdge[48, 244] -> 
             RGBColor[
              0.19115682833937214`, 0.31824832500058275`, 0.9341974706315176],
              UndirectedEdge[110, 278] -> 
             RGBColor[
              0.19327360105018532`, 0.32047318733078894`, 0.9343180177059138],
              UndirectedEdge[245, 288] -> 
             RGBColor[
              0.2170539171587743, 0.34546780732004123`, 0.9356722715284729], 
             UndirectedEdge[106, 210] -> 
             RGBColor[
              0.6667698289178824, 0.73732879896912, 0.9691188386686375], 
             UndirectedEdge[176, 296] -> 
             RGBColor[
              0.19069988788986053`, 0.3177680516164482, 0.9341714485489008], 
             UndirectedEdge[82, 154] -> 
             RGBColor[
              0.5553686317376758, 0.6499123001732142, 0.9581397995541713], 
             UndirectedEdge[46, 117] -> 
             RGBColor[
              0.1951092767006187, 0.3224025988279529, 0.9344225567185672], 
             UndirectedEdge[249, 258] -> 
             RGBColor[
              0.2738091064777124, 0.40221653034560445`, 0.9390107464799751], 
             UndirectedEdge[146, 170] -> 
             RGBColor[
              0.19880274533348388`, 0.3262846685405311, 0.9346328942932117], 
             UndirectedEdge[18, 129] -> 
             RGBColor[
              0.1945312219559263, 0.32179502664049353`, 0.9343896373560123], 
             UndirectedEdge[13, 179] -> 
             RGBColor[
              0.42802275177735205`, 0.5432681021152472, 0.9490151577652866], 
             UndirectedEdge[144, 160] -> 
             RGBColor[
              0.19670215780285202`, 0.3240768178608952, 0.934513268940883], 
             UndirectedEdge[17, 130] -> 
             RGBColor[
              0.8077331614173798, 0.7282311492830874, 0.6094955989444572], 
             UndirectedEdge[111, 163] -> 
             RGBColor[
              0.6176770518281398, 0.70049708256499, 0.9630449466269559], 
             UndirectedEdge[107, 251] -> 
             RGBColor[
              0.34704129264344796`, 0.47287212594221606`, 0.943412473599851], 
             UndirectedEdge[1, 198] -> 
             RGBColor[
              0.8673259572403823, 0.4208317382887128, 0.4252968469940128], 
             UndirectedEdge[168, 269] -> 
             RGBColor[
              0.6867881591822118, 0.7211895103907764, 0.6484929822846838], 
             UndirectedEdge[145, 201] -> 
             RGBColor[
              0.8518773491973987, 0.5315008727671069, 0.456374840298414], 
             UndirectedEdge[197, 226] -> 
             RGBColor[
              0.9862994243091077, 0.9886024741101505, 0.8767175253588012], 
             UndirectedEdge[105, 174] -> 
             RGBColor[
              0.25852249961576723`, 0.3890539167423275, 0.9380338459521285], 
             UndirectedEdge[178, 284] -> 
             RGBColor[
              0.24998452415634886`, 0.38007996319556836`, 0.9375476208805174],
              UndirectedEdge[201, 202] -> 
             RGBColor[
              0.8524329734673737, 0.3954661457870175, 0.19750790475074864`], 
             UndirectedEdge[24, 65] -> 
             RGBColor[
              0.6506137006766177, 0.6184091477452374, 0.6013947753940398], 
             UndirectedEdge[134, 169] -> 
             RGBColor[
              0.42476901028009817`, 0.532311534169465, 0.9496393645496872], 
             UndirectedEdge[104, 300] -> 
             RGBColor[
              0.2803668703826312, 0.4095782545351725, 0.9393670254375599], 
             UndirectedEdge[168, 225] -> 
             RGBColor[
              0.31400402532006444`, 0.4388934235578272, 0.9415037514868442], 
             UndirectedEdge[27, 202] -> 
             RGBColor[
              0.9009943249734276, 0.6279839494543441, 0.2526972486332866], 
             UndirectedEdge[113, 187] -> 
             RGBColor[
              0.24618639037776724`, 0.3760878837786886, 0.9373313227806626], 
             UndirectedEdge[7, 201] -> 
             RGBColor[
              0.8763492903148913, 0.5509690808206948, 0.45714696205531347`], 
             UndirectedEdge[51, 104] -> 
             RGBColor[
              0.5731922784257398, 0.6585842020957557, 0.9621993062038972], 
             UndirectedEdge[2, 183] -> 
             RGBColor[
              0.19566573686527955`, 0.3229874737426237, 0.9344542463017356], 
             UndirectedEdge[135, 249] -> 
             RGBColor[
              0.21026660117408774`, 0.33833390787944695`, 0.9352857439240791],
              UndirectedEdge[84, 270] -> 
             RGBColor[
              0.20015353292457566`, 0.32770443194364846`, 0.9347098196482133],
              UndirectedEdge[114, 116] -> 
             RGBColor[
              0.26324193971723214`, 0.3940143475187522, 0.9383026110841209], 
             UndirectedEdge[15, 168] -> 
             RGBColor[
              0.3293937457780264, 0.4550689955237798, 0.942380173299874], 
             UndirectedEdge[42, 237] -> 
             RGBColor[
              0.8334280441412762, 0.2579481722980025, 0.1796440388622492], 
             UndirectedEdge[40, 140] -> 
             RGBColor[
              0.7746238811196319, 0.3418026092174846, 0.43269867546052243`], 
             UndirectedEdge[42, 167] -> 
             RGBColor[
              0.8609638306693929, 0.4172670345342654, 0.20395475904067392`], 
             UndirectedEdge[16, 285] -> 
             RGBColor[
              0.22323502267117318`, 0.3519645411182973, 0.9360242763432778], 
             UndirectedEdge[8, 286] -> 
             RGBColor[
              0.21267948434468417`, 0.34087000107737286`, 0.9354231540511039],
              UndirectedEdge[9, 236] -> 
             RGBColor[
              0.21519552032906075`, 0.34351451442284786`, 0.9355664385782725],
              UndirectedEdge[54, 238] -> 
             RGBColor[
              0.21574020514797415`, 0.344087012702538, 0.9355974575729206], 
             UndirectedEdge[165, 183] -> 
             RGBColor[
              0.2052672821395783, 0.33307930659904317`, 0.9350010401008936], 
             UndirectedEdge[249, 263] -> 
             RGBColor[
              0.20867298294508915`, 0.33665891407953785`, 0.9351949897234846],
              UndirectedEdge[33, 98] -> 
             RGBColor[
              0.18977923539730202`, 0.3168003874740297, 0.9341190187514328], 
             UndirectedEdge[282, 293] -> 
             RGBColor[
              0.6701954566467123, 0.5968924733689558, 0.5936831325375491], 
             UndirectedEdge[54, 163] -> 
             RGBColor[
              0.4325936369919836, 0.5385727559524309, 0.9502636460208878], 
             UndirectedEdge[145, 237] -> 
             RGBColor[
              0.8383510633263312, 0.42753191230581933`, 0.44342205367252496`],
              UndirectedEdge[140, 181] -> 
             RGBColor[
              0.8736439880136796, 0.4112274879198171, 0.24323035592583006`], 
             UndirectedEdge[15, 265] -> 
             RGBColor[
              0.24054595553413333`, 0.37015942913380495`, 0.9370101083605932],
              UndirectedEdge[144, 230] -> 
             RGBColor[
              0.19486271425090618`, 0.32214344606034284`, 0.9344085153518125],
              UndirectedEdge[22, 266] -> 
             RGBColor[
              0.1933455924812791, 0.32054885488938883`, 0.9343221175114128], 
             UndirectedEdge[18, 165] -> 
             RGBColor[
              0.2088844992725249, 0.33688123115058255`, 0.9352070352654217], 
             UndirectedEdge[17, 140] -> 
             RGBColor[
              0.7794337135277863, 0.345560086850815, 0.43317807460452784`], 
             UndirectedEdge[80, 237] -> 
             RGBColor[
              0.8763192452000071, 0.442552928220461, 0.2384882540724326], 
             UndirectedEdge[7, 127] -> 
             RGBColor[
              0.6435774661849356, 0.7150423967840147, 0.9663706566026036], 
             UndirectedEdge[60, 212] -> 
             RGBColor[
              0.2603180236560096, 0.39094112635142153`, 0.9381360983899805], 
             UndirectedEdge[53, 270] -> 
             RGBColor[
              0.21435826979552958`, 0.3426345110273567, 0.935518758398989], 
             UndirectedEdge[243, 254] -> 
             RGBColor[
              0.6530996726183891, 0.7197996840615158, 0.8998607275791879], 
             UndirectedEdge[201, 277] -> 
             RGBColor[
              0.8945797907010281, 0.562282566775544, 0.2876123598448103], 
             UndirectedEdge[288, 296] -> 
             RGBColor[
              0.1980362372485557, 0.3254790199438521, 0.9345892427917222], 
             UndirectedEdge[93, 273] -> 
             RGBColor[
              0.24003010742833283`, 0.36961724006794966`, 0.9369807315740968],
              UndirectedEdge[128, 277] -> 
             RGBColor[
              0.8942972321572974, 0.5601106979904866, 0.2873417814642296], 
             UndirectedEdge[3, 115] -> 
             RGBColor[
              0.6529735529155825, 0.7222241006469869, 0.9530066800693597], 
             UndirectedEdge[74, 123] -> 
             RGBColor[
              0.20225228122772315`, 0.32991034947858455`, 0.9348293402592576],
              UndirectedEdge[52, 147] -> 
             RGBColor[
              0.20606540532151835`, 0.3339181846671946, 0.9350464920353876], 
             UndirectedEdge[64, 76] -> 
             RGBColor[
              0.28111114711231006`, 0.41111591460968555`, 0.939381752805837], 
             UndirectedEdge[132, 260] -> 
             RGBColor[
              0.2275319348126233, 0.35648086821892655`, 0.9362689791330215], 
             UndirectedEdge[171, 285] -> 
             RGBColor[
              0.18941388075270052`, 0.31641637657773114`, 0.9340982123449165],
              UndirectedEdge[226, 290] -> 
             RGBColor[
              0.9663340369194856, 0.9069146206326038, 0.576578764162101], 
             UndirectedEdge[24, 290] -> 
             RGBColor[
              0.9350874753344331, 0.7803505010572445, 0.2666280628425426], 
             UndirectedEdge[103, 265] -> 
             RGBColor[
              0.3220227389937979, 0.445387567907627, 0.9420312197585695], 
             UndirectedEdge[41, 208] -> 
             RGBColor[
              0.1889556017616225, 0.3159346963015419, 0.9340721140343375], 
             UndirectedEdge[80, 179] -> 
             RGBColor[
              0.7507825863487789, 0.7818072220217351, 0.663873785850424], 
             UndirectedEdge[102, 183] -> 
             RGBColor[
              0.19246783079694663`, 0.31962627170585023`, 0.934272130282022], 
             UndirectedEdge[16, 220] -> 
             RGBColor[
              0.2899399087951104, 0.41982488843615623`, 0.9399054307139528], 
             UndirectedEdge[52, 217] -> 
             RGBColor[
              0.19938565089971289`, 0.32689733924898534`, 0.9346660899028769],
              UndirectedEdge[24, 241] -> 
             RGBColor[
              0.9549441101488896, 0.8619933825501465, 0.5685691356523801], 
             UndirectedEdge[105, 163] -> 
             RGBColor[
              0.4524953087499887, 0.5594906748089641, 0.9513970167856213], 
             UndirectedEdge[2, 102] -> 
             RGBColor[
              0.19539325191364892`, 0.3227010747819161, 0.9344387286868456], 
             UndirectedEdge[49, 54] -> 
             RGBColor[
              0.22682934694082163`, 0.355742403819019, 0.936228967793108], 
             UndirectedEdge[216, 237] -> 
             RGBColor[
              0.8526673664281595, 0.38892998001081047`, 0.19740587187632483`],
              UndirectedEdge[89, 281] -> 
             RGBColor[
              0.6796029595718664, 0.743830302697593, 0.9334123929687868], 
             UndirectedEdge[145, 167] -> 
             RGBColor[
              0.8862929429929738, 0.7834059474084649, 0.6157767446761826], 
             UndirectedEdge[16, 90] -> 
             RGBColor[
              0.2312332284112072, 0.3603711624666066, 0.9364797623278878], 
             UndirectedEdge[210, 290] -> 
             RGBColor[
              0.7090449941186435, 0.7036067912817707, 0.613645317642163], 
             UndirectedEdge[152, 242] -> 
             RGBColor[
              0.1817008098525566, 0.3083094500247394, 0.9336589643676192], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.18784627824446665`, 0.31476872694983776`, 0.9340089397011326],
              UndirectedEdge[77, 282] -> 
             RGBColor[
              0.42720741988360567`, 0.5444473278590943, 0.9484422569236628], 
             UndirectedEdge[81, 162] -> 
             RGBColor[
              0.9404065856589258, 0.790829015220349, 0.5112620539625906], 
             UndirectedEdge[34, 247] -> 
             RGBColor[
              0.1907246807083084, 0.31779411044059236`, 0.9341728604632337], 
             UndirectedEdge[7, 60] -> 
             RGBColor[
              0.6127935489939296, 0.6863930727259957, 0.9644818440323379], 
             UndirectedEdge[155, 162] -> 
             RGBColor[
              0.9588310572734952, 0.8681281277104613, 0.5263067793464253], 
             UndirectedEdge[234, 249] -> 
             RGBColor[
              0.2008059288288086, 0.3283901414032867, 0.934746972629826], 
             UndirectedEdge[118, 234] -> 
             RGBColor[
              0.19143808005152518`, 0.3185439383824441, 0.9342134875004501], 
             UndirectedEdge[223, 271] -> 
             RGBColor[
              0.20206279459486376`, 0.3297111870133029, 0.9348185492758365], 
             UndirectedEdge[154, 216] -> 
             RGBColor[
              0.7434083499065284, 0.5252723810458323, 0.4580470065820631], 
             UndirectedEdge[147, 247] -> 
             RGBColor[
              0.2055770841992048, 0.33340492820629564`, 0.9350186828698783], 
             UndirectedEdge[4, 286] -> 
             RGBColor[
              0.22071420539136402`, 0.34931500232817103`, 0.9358807195284078],
              UndirectedEdge[88, 124] -> 
             RGBColor[
              0.20439146202389424`, 0.3321587641272566, 0.9349511634409652], 
             UndirectedEdge[23, 136] -> 
             RGBColor[
              0.6909810750975458, 0.7521740618261392, 0.8862275585719336], 
             UndirectedEdge[11, 104] -> 
             RGBColor[
              0.4334513122055766, 0.547724101182389, 0.9494290167598639], 
             UndirectedEdge[4, 121] -> 
             RGBColor[
              0.2229935575329976, 0.35171074594830076`, 0.9360105252608744], 
             UndirectedEdge[4, 213] -> 
             RGBColor[
              0.21145636706915383`, 0.33958442727067606`, 0.9353534993317023],
              UndirectedEdge[198, 204] -> 
             RGBColor[
              0.7240997016369111, 0.7823833581016821, 0.9486564217578735], 
             UndirectedEdge[156, 168] -> 
             RGBColor[
              0.3974514720884778, 0.5186742214563766, 0.9465462342423088], 
             UndirectedEdge[31, 226] -> 
             RGBColor[
              0.7029528418062473, 0.7632425995782364, 0.912689477230743], 
             UndirectedEdge[36, 242] -> 
             RGBColor[
              0.18110760662426995`, 0.30768595582055314`, 0.9336251823213337],
              UndirectedEdge[216, 269] -> 
             RGBColor[
              0.9020307778688763, 0.6313968506786615, 0.25694130282079497`], 
             UndirectedEdge[97, 202] -> 
             RGBColor[
              0.7273332106591868, 0.5124071693605181, 0.4568577343104335], 
             UndirectedEdge[23, 59] -> 
             RGBColor[
              0.9871771704378065, 0.988965444691414, 0.8621710004720957], 
             UndirectedEdge[174, 238] -> 
             RGBColor[
              0.21032414623090429`, 0.3383943913827284, 0.9352890210299346], 
             UndirectedEdge[86, 97] -> 
             RGBColor[
              0.5215176139849236, 0.6223094238976072, 0.9555083823712963], 
             UndirectedEdge[46, 212] -> 
             RGBColor[
              0.21903868251240277`, 0.34755392154809645`, 0.9357853009791648],
              UndirectedEdge[59, 291] -> 
             RGBColor[
              0.955941254786202, 0.9662985742039245, 0.945506158028788], 
             UndirectedEdge[125, 149] -> 
             RGBColor[
              0.8552975837103799, 0.3871468134192908, 0.19906309946450382`], 
             UndirectedEdge[32, 80] -> 
             RGBColor[
              0.9832422855582464, 0.9646748589231064, 0.6130382528147665], 
             UndirectedEdge[69, 90] -> 
             RGBColor[
              0.21162247094140993`, 0.33975901297201105`, 0.9353629587014987],
              UndirectedEdge[215, 229] -> 
             RGBColor[
              0.2212270314220612, 0.34985401500148217`, 0.9359099242121978], 
             UndirectedEdge[187, 245] -> 
             RGBColor[
              0.22499133551940492`, 0.35381053727845513`, 0.9361242957617526],
              UndirectedEdge[98, 275] -> 
             RGBColor[
              0.17961340510331275`, 0.30611545528417883`, 0.9335400897551883],
              UndirectedEdge[252, 280] -> 
             RGBColor[
              0.2499775972482043, 0.3800726825759171, 0.937547226403346], 
             UndirectedEdge[96, 146] -> 
             RGBColor[
              0.20048974504421074`, 0.3280578121984645, 0.9347289664310452], 
             UndirectedEdge[191, 270] -> 
             RGBColor[
              0.22010792895967446`, 0.34867776735831935`, 0.9358461929825286],
              UndirectedEdge[40, 120] -> 
             RGBColor[
              0.4841619759818365, 0.5839129078583203, 0.9544325893141365], 
             UndirectedEdge[215, 233] -> 
             RGBColor[
              0.2150686635576537, 0.34338117991291517`, 0.9355592142728086], 
             UndirectedEdge[21, 257] -> 
             RGBColor[
              0.1888268034733999, 0.3157993211343368, 0.9340647791623633], 
             UndirectedEdge[200, 245] -> 
             RGBColor[
              0.2954064062007655, 0.4225674449726149, 0.9403266970812623], 
             UndirectedEdge[41, 108] -> 
             RGBColor[
              0.21464006545615802`, 0.34293069613355404`, 0.9355348062449824],
              UndirectedEdge[63, 73] -> 
             RGBColor[
              0.18277574146873998`, 0.309439271307949, 0.933720180132942]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {3}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.8649038628242013, 0.8951148792988238, 0.9869764966166072], 
             160 -> RGBColor[
              0.19576440547633542`, 0.32309118070879467`, 0.9344598653331682],
              245 -> RGBColor[
              0.22524249753236514`, 0.35407452447866766`, 0.9361385990668298],
              155 -> RGBColor[
              0.9263138375757084, 0.7455659509853682, 0.2595685879581257], 
             213 -> RGBColor[
              0.20237506472464956`, 0.3300394027187775, 0.9348363325977657], 
             27 -> RGBColor[
              0.9698415036520304, 0.9099304516459211, 0.33734036595263717`], 
             19 -> RGBColor[
              0.18771789764902583`, 0.31463379080422954`, 0.9340016286161444],
              164 -> RGBColor[
              0.18196114135351968`, 0.30858307493822207`, 0.9336737898614731],
              190 -> RGBColor[
              0.2044144915577996, 0.3321829696275479, 0.9349524749388519], 
             103 -> RGBColor[
              0.4213296380105047, 0.5393562886265211, 0.9480677298602272], 
             138 -> RGBColor[
              0.231287806205471, 0.36042852718880986`, 0.9364828704525304], 
             291 -> RGBColor[
              0.926874823682218, 0.9445288413300859, 0.9928873421853748], 28 -> 
             RGBColor[
              0.18347004528514485`, 0.31016902864039503`, 0.9337597197081559],
              195 -> RGBColor[
              0.18372407711397143`, 0.31043603219904004`, 0.9337741864450011],
              114 -> RGBColor[
              0.23913206195702244`, 0.3686733373382309, 0.9369295892130448], 
             93 -> RGBColor[
              0.24113006344271598`, 0.3707733635803057, 0.9370433724418767], 
             34 -> RGBColor[
              0.1836929464736069, 0.31040331192222026`, 0.933772413601086], 
             161 -> RGBColor[
              0.2016546493170191, 0.3292822004483829, 0.9347953060060602], 22 -> 
             RGBColor[
              0.18854143418810532`, 0.3154993799220345, 0.9340485278037318], 
             124 -> RGBColor[
              0.1859244664032461, 0.3127487808548065, 0.9338994953598411], 84 -> 
             RGBColor[
              0.18746791982634672`, 0.31437104826308443`, 0.9339873927489519],
              46 -> RGBColor[
              0.2047087295239663, 0.33249223238575365`, 0.9349692313557391], 
             241 -> RGBColor[
              0.986124206873734, 0.9885300171977407, 0.8796213317111282], 185 -> 
             RGBColor[
              0.5295564396500168, 0.6289567998104505, 0.9561077692398556], 
             121 -> RGBColor[
              0.22544944565233713`, 0.35429204007402687`, 0.9361503844561099],
              126 -> RGBColor[
              0.22348836128871713`, 0.3522308160679321, 0.9360387036027661], 
             236 -> RGBColor[
              0.23143093535124384`, 0.3605789649959291, 0.9364910214456416], 
             78 -> RGBColor[
              0.19413140389541048`, 0.3213747925089622, 0.9343668683089438], 
             254 -> RGBColor[
              0.31878183695974033`, 0.45053453755869494`, 0.9415334746567325],
              290 -> RGBColor[
              0.9464109372448213, 0.8252442542119368, 0.27573918609145315`], 
             251 -> RGBColor[
              0.28560729073547014`, 0.4175217494840773, 0.9395762847380378], 
             165 -> RGBColor[
              0.21779424853057935`, 0.34624594253152846`, 0.935714432304875], 
             100 -> 
             RGBColor[
              0.1806628381309981, 0.3072184759341732, 0.933599853413618], 235 -> 
             RGBColor[
              0.40849384697781144`, 0.528238571579618, 0.9472498446058684], 
             70 -> RGBColor[
              0.20976983040282712`, 0.33781177030176596`, 0.9352574535635624],
              234 -> RGBColor[
              0.1941551643020383, 0.3213997662028249, 0.9343682214289508], 
             257 -> RGBColor[
              0.18407578926115742`, 0.31080570396557056`, 0.9337942159314718],
              135 -> RGBColor[
              0.21307650899259664`, 0.34128729915514544`, 0.9354457640174572],
              265 -> RGBColor[
              0.22271583997709107`, 0.35141884718873295`, 0.9359947096569118],
              111 -> RGBColor[
              0.6142037164471443, 0.6976772724307221, 0.9627715129425172], 
             182 -> RGBColor[
              0.2543436096659436, 0.38466163844813683`, 0.9377958643515997], 
             188 -> RGBColor[
              0.35586441424032067`, 0.4826536021746064, 0.9438963436902155], 
             154 -> RGBColor[
              0.4972976140125026, 0.6027676319143825, 0.9535682363176986], 
             269 -> RGBColor[
              0.9731648978995463, 0.9211410408128702, 0.3502511250338943], 
             208 -> RGBColor[
              0.18931653926981418`, 0.3163140645074111, 0.9340926688914699], 
             86 -> RGBColor[
              0.5941770672605392, 0.6814187364307716, 0.9611949417585145], 
             119 -> RGBColor[
              0.18085158366002294`, 0.307416859452336, 0.933610602192272], 
             140 -> RGBColor[0.817319, 0.134127, 0.164218], 85 -> 
             RGBColor[
              0.23214849009490668`, 0.36133316052711717`, 0.9365318851267661],
              242 -> RGBColor[
              0.18088209567567362`, 0.3074489295153584, 0.9336123398064248], 
             117 -> RGBColor[
              0.1855098238772711, 0.3123129652701522, 0.9338758820813954], 47 -> 
             RGBColor[
              0.18409960782193097`, 0.31083073878312756`, 0.9337955723632715],
              81 -> RGBColor[
              0.8894648943465696, 0.5909677260051436, 0.2294791371904563], 
             275 -> RGBColor[
              0.1801747671672662, 0.30670548240580453`, 0.9335720584942697], 
             23 -> RGBColor[
              0.989346654985427, 0.9898625823050647, 0.82621702707199], 110 -> 
             RGBColor[
              0.18591721951216156`, 0.3127411639127972, 0.9338990826601146], 
             6 -> RGBColor[
              0.2105950138195758, 0.3386790903924193, 0.9353044465383967], 
             218 -> RGBColor[
              0.9671895696970209, 0.9750506153189628, 0.9404236795589124], 
             108 -> RGBColor[
              0.24068546665888524`, 0.3703060641714354, 0.9370180533127597], 
             297 -> RGBColor[
              0.19199315011410678`, 0.319127352211692, 0.9342450979193615], 
             157 -> RGBColor[
              0.18253809113335498`, 0.30918948573755783`, 0.933706646297914], 
             270 -> RGBColor[
              0.2128391460228046, 0.3410378156242125, 0.9354322465474746], 33 -> 
             RGBColor[
              0.20050642775524471`, 0.3280753467855062, 0.9347299164867587], 
             252 -> RGBColor[
              0.23794228148785246`, 0.3674228026286945, 0.9368618329754481], 
             260 -> RGBColor[
              0.25816755850577977`, 0.38868085113116446`, 0.938013632581003], 
             159 -> RGBColor[
              0.29124080035179, 0.42344292527596916`, 0.9398971047766567], 
             183 -> RGBColor[
              0.19274031574857725`, 0.3199126706665578, 0.9342876478969121], 
             99 -> RGBColor[
              0.19567419878950365`, 0.3229963677615002, 0.9344547281958019], 
             17 -> RGBColor[
              0.7036631405833589, 0.768426260552445, 0.9710982238135836], 277 -> 
             RGBColor[
              0.9930111873350895, 0.9874599613241353, 0.4806890552557963], 
             104 -> RGBColor[
              0.3350878162698179, 0.46465795727473413`, 0.9425724772395593], 
             79 -> RGBColor[
              0.18314084159618357`, 0.3098230146905773, 0.9337409720450827], 
             191 -> RGBColor[
              0.2273767118965443, 0.3563177190924262, 0.9362601394175826], 50 -> 
             RGBColor[
              0.1818234123124711, 0.30843831298355445`, 0.9336659463963373], 
             225 -> RGBColor[
              0.2275966301752516, 0.35654886714697176`, 0.936272663438215], 
             61 -> RGBColor[
              0.2772592389822082, 0.4087474177943471, 0.9391008755405253], 
             196 -> RGBColor[
              0.2030597206401025, 0.3307590194956109, 0.934875322739293], 1 -> 
             RGBColor[
              0.8186934053129894, 0.1446912815038851, 0.16553413207988746`], 
             263 -> RGBColor[
              0.20988927253459944`, 0.3379373115553272, 0.935264255616268], 
             201 -> RGBColor[
              0.8453640923839973, 0.3496938695012485, 0.19107401213931735`], 
             293 -> 
             RGBColor[
              0.8997587664774066, 0.6377097951563564, 0.23806859642232206`], 
             184 -> RGBColor[
              0.1914897805011185, 0.3185982788329645, 0.9342164317645705], 
             106 -> RGBColor[
              0.861860606843299, 0.8926882695866354, 0.9866862281444021], 206 -> 
             RGBColor[
              0.22242260484653656`, 0.35111063847433904`, 0.9359780103500293],
              247 -> RGBColor[
              0.19775641494300986`, 0.32518490895896446`, 0.9345733073253814],
              220 -> RGBColor[
              0.33308943974472227`, 0.4629270639700209, 0.9424451424544752], 
             107 -> RGBColor[
              0.40847529455142584`, 0.5282225024003548, 0.9472486624616643], 
             131 -> RGBColor[
              0.22940782651350908`, 0.3584525493349609, 0.9363758083902539], 
             127 -> RGBColor[
              0.34883524619319184`, 0.47656529010844195`, 0.9434484513179017],
              210 -> RGBColor[
              0.4716790509924657, 0.5819693283516046, 0.9515514491928728], 
             181 -> RGBColor[
              0.9862939640410388, 0.9654284637594515, 0.4012550677774902], 
             194 -> RGBColor[
              0.6860055424687634, 0.754632010702607, 0.9693382794531569], 118 -> 
             RGBColor[
              0.1887209958010121, 0.3156881105620633, 0.9340587535719493], 
             276 -> RGBColor[
              0.24137384732010603`, 0.3710295958922332, 0.9370572555730482], 
             280 -> RGBColor[
              0.2620129130085561, 0.39272256252313964`, 0.938232619831244], 
             189 -> RGBColor[
              0.21583585429987417`, 0.3441875460256914, 0.935602904650621], 
             168 -> RGBColor[
              0.4004114204648772, 0.5212379799686826, 0.9467348395354733], 41 -> 
             RGBColor[
              0.1885946642534308, 0.31555532809567266`, 0.9340515591772053], 
             14 -> RGBColor[
              0.1801938510546308, 0.30672554078141306`, 0.9335731452934231], 
             77 -> RGBColor[
              0.4137826929511934, 0.5328195041366336, 0.9475868451945494], 51 -> 
             RGBColor[
              0.8112967405816618, 0.8525104469167772, 0.981826135168235], 179 -> 
             RGBColor[
              0.5227567642523288, 0.6234365170007214, 0.9555724738845179], 
             223 -> RGBColor[
              0.1814903715451621, 0.30808826602110845`, 0.9336469802173286], 
             292 -> RGBColor[
              0.773715577090376, 0.8231517563699634, 0.978080396007364], 143 -> 
             RGBColor[
              0.3068945586163886, 0.4398960177176607, 0.9407885631521654], 
             112 -> RGBColor[
              0.18923133529375677`, 0.3162245097263307, 0.9340878166510814], 
             197 -> RGBColor[
              0.9863417120240653, 0.9886199611670301, 0.8760167084848537], 54 -> 
             RGBColor[
              0.24403688677483204`, 0.37382861920560384`, 0.937208911730381], 
             71 -> RGBColor[
              0.22331684544677569`, 0.35205054204331915`, 0.9360289360293025],
              177 -> RGBColor[
              0.29197171960673096`, 0.42421116775586953`, 0.9399387295469274],
              158 -> RGBColor[
              0.19294565339664288`, 0.32012849355383366`, 0.9342993415721996],
              226 -> RGBColor[
              0.9862571365941499, 0.9885849870532707, 0.8774183422327487], 
             203 -> RGBColor[
              0.9371250918628792, 0.9526285769763242, 0.9913149984604726], 
             115 -> RGBColor[
              0.3517287364030146, 0.47907148589714393`, 0.9436328219554587], 
             173 -> RGBColor[
              0.20128694378722742`, 0.32889571862269473`, 0.9347743657201101],
              212 -> RGBColor[
              0.23336863550083925`, 0.36261561071043924`, 0.9366013706025906],
              129 -> RGBColor[
              0.18908769389738214`, 0.3160735335113504, 0.9340796364860563], 
             279 -> RGBColor[
              0.23666672657285628`, 0.3660821135381808, 0.9367891920100534], 
             26 -> RGBColor[
              0.2290956026577889, 0.35812438226646315`, 0.9363580277035645], 
             40 -> RGBColor[
              0.6892336433588957, 0.7571538276524538, 0.9696600263815672], 
             146 -> RGBColor[
              0.20002902465321373`, 0.3275735658561667, 0.9347027290863527], 
             192 -> RGBColor[
              0.3306172943235091, 0.4607858158598078, 0.9422876195342679], 
             300 -> RGBColor[
              0.2256459244954445, 0.3544985517956109, 0.9361615736355604], 
             221 -> RGBColor[
              0.1861956076915163, 0.31303376754012907`, 0.9339149364550904], 
             62 -> RGBColor[
              0.20167701950442632`, 0.3293057129336997, 0.9347965799551393], 
             286 -> RGBColor[
              0.22089074136906994`, 0.34950055283376746`, 0.9358907729911765],
              152 -> RGBColor[
              0.1825195240294396, 0.3091699705341204, 0.9337055889288136], 64 -> 
             RGBColor[
              0.2353045398184947, 0.3646503688917182, 0.9367116174895672], 37 -> 
             RGBColor[
              0.22656828106141946`, 0.3554680070272346, 0.9362141004774884], 
             148 -> RGBColor[
              0.2462972527349853, 0.37620440714520426`, 0.9373376362279], 261 -> 
             RGBColor[
              0.24473644409614725`, 0.3745638983048021, 0.9372487504849276], 
             15 -> RGBColor[
              0.2583760710911756, 0.38890001107887695`, 0.9380255070642746], 
             136 -> RGBColor[
              0.39261549520966454`, 0.5144855413472138, 0.9462380900718772], 
             198 -> RGBColor[
              0.964591061095168, 0.9731126518583681, 0.9448222768222637], 63 -> 
             RGBColor[
              0.18288267188311363`, 0.3095516619532356, 0.9337262696618512], 
             171 -> RGBColor[
              0.17914809400855325`, 0.30562638382115925`, 0.9335135909767078],
              59 -> RGBColor[
              0.985007685890186, 0.9880683070777632, 0.8981249738722014], 229 -> 
             RGBColor[
              0.2177123475199571, 0.3461598593765405, 0.9357097681634818], 
             102 -> RGBColor[
              0.19219534584531597`, 0.31933987274514264`, 0.9342566126671321],
              299 -> RGBColor[
              0.8186938987840391, 0.1446950745386128, 0.16553460462832187`], 
             128 -> RGBColor[
              0.8449402545684014, 0.34643606632366236`, 0.19066814456844627`],
              12 -> RGBColor[
              0.42962012936485927`, 0.5465370955454517, 0.948595992638333], 
             222 -> RGBColor[
              0.2214255710569613, 0.35006269274590207`, 0.9359212307506922], 
             92 -> RGBColor[
              0.8315546894535105, 0.24354874725857717`, 0.17785011229759332`],
              271 -> RGBColor[
              0.2226352176445654, 0.3513341080054973, 0.9359901183343445], 
             132 -> RGBColor[
              0.19689631111946682`, 0.3242808853066886, 0.9345243256850401], 
             80 -> RGBColor[
              0.9788084084452291, 0.9401779270427488, 0.37217509781633024`], 
             244 -> RGBColor[
              0.1895037720729246, 0.31651085805472556`, 0.934103331522621], 
             150 -> RGBColor[
              0.9074094141907081, 0.6706162117894943, 0.24435764515870567`], 
             125 -> RGBColor[
              0.8351944719959239, 0.27152571084244637`, 0.18133557217075477`],
              258 -> RGBColor[
              0.340161519599846, 0.46905254408746033`, 0.942895769129249], 
             133 -> RGBColor[
              0.18528931800943133`, 0.31208119962217307`, 0.9338633245984311],
              255 -> 
             RGBColor[
              0.3660178719215669, 0.49144801689048034`, 0.9445433130353144], 
             176 -> RGBColor[
              0.19419263806779313`, 0.3214391535066072, 0.9343703555044731], 
             230 -> RGBColor[
              0.19208551837244375`, 0.31922443710768994`, 0.9342503581550272],
              274 -> RGBColor[
              0.46304655962256364`, 0.5749610829682137, 0.9508718678503764], 
             87 -> RGBColor[
              0.9931480500222558, 0.9877526967730439, 0.4955857141352578], 
             130 -> RGBColor[
              0.9118031822514008, 0.6880360380137298, 0.24789297407533079`], 
             35 -> RGBColor[
              0.20639345636736367`, 0.33426298711601565`, 0.9350651740571405],
              31 -> RGBColor[
              0.41964854701834464`, 0.537900212103202, 0.9479606122287372], 
             18 -> RGBColor[
              0.19997475001447043`, 0.3275165197696367, 0.9346996382259684], 
             24 -> RGBColor[
              0.9237640134240451, 0.7354567479025522, 0.2575169395936321], 
             151 -> RGBColor[
              0.5978280581771518, 0.684382775332144, 0.9614823611374906], 137 -> 
             RGBColor[
              0.26153416243522165`, 0.3922193653160256, 0.9382053556943405], 
             296 -> RGBColor[
              0.18720713771192796`, 0.31409694972628927`, 0.9339725415933283],
              266 -> RGBColor[
              0.1981497507744529, 0.3255983298567432, 0.9345957072190938], 
             283 -> RGBColor[
              0.3058207768282486, 0.438767404976628, 0.9407274128678487], 284 -> 
             RGBColor[
              0.24095771526907575`, 0.3705922147223045, 0.9370335574683543], 
             238 -> RGBColor[
              0.1874435235211163, 0.31434540619947215`, 0.9339860034154601], 
             72 -> RGBColor[
              0.8294154563220671, 0.22710566399236717`, 0.1758015802350048], 
             288 -> RGBColor[
              0.20886533678518346`, 0.33686109016141486`, 0.9352059439901159],
              172 -> RGBColor[
              0.19058407149220488`, 0.3176463212393284, 0.9341648529763892], 
             243 -> RGBColor[
              0.9874175082770378, 0.9890648305643368, 0.8581879805016432], 88 -> 
             RGBColor[
              0.22285845764454237`, 0.35156874739970667`, 0.9360028315220893],
              273 -> RGBColor[
              0.2389301514139497, 0.3684611165555936, 0.9369180907063167], 
             202 -> RGBColor[
              0.8665707356341262, 0.4870106983585556, 0.21037568997361125`], 
             98 -> 
             RGBColor[
              0.1790520430393593, 0.3055254281625532, 0.9335081210161069], 30 -> 
             RGBColor[
              0.24929644188312317`, 0.37935674509947226`, 0.9375084356129837],
              116 -> RGBColor[
              0.2873518174774419, 0.41935535769927346`, 0.9396756329551971], 
             240 -> RGBColor[
              0.18053047455342514`, 0.3070793534218085, 0.9335923155036896], 
             73 -> RGBColor[
              0.1826688110543663, 0.3093268806626624, 0.9337140906040328], 29 -> 
             RGBColor[
              0.19525519293228838`, 0.32255596603906117`, 0.934430866432097], 
             75 -> RGBColor[
              0.3329293714790703, 0.46278842088357813`, 0.9424349430461306], 
             200 -> RGBColor[
              0.3655703148691659, 0.4910603654665621, 0.9445147950956946], 
             156 -> RGBColor[
              0.3944915237120784, 0.5161104629440706, 0.9463576289491441], 25 -> 
             RGBColor[
              0.1911156300253715, 0.31820502296044406`, 0.9341951244484827], 
             38 -> RGBColor[
              0.18611948239069784`, 0.312953755022346, 0.9339106012318261], 3 -> 
             RGBColor[
              0.9542183694281502, 0.96537671539683, 0.9623805381832607], 57 -> 
             RGBColor[
              0.17967566298483006`, 0.30618089226503126`, 0.9335436352494385],
              227 -> RGBColor[
              0.952704487454567, 0.8501960835922951, 0.28080312431882476`], 
             39 -> RGBColor[
              0.20172422019829714`, 0.3293553238556548, 0.934799267964828], 
             109 -> RGBColor[
              0.9928111618057213, 0.9912952449090205, 0.7688011832034702], 
             256 -> RGBColor[
              0.817928104297447, 0.13880884254138265`, 0.16480127896312016`], 
             287 -> RGBColor[
              0.2430009596347453, 0.3727397940997984, 0.9371499172122699], 
             239 -> RGBColor[
              0.23757609093788187`, 0.36703791314285356`, 0.9368409789653577],
              285 -> RGBColor[
              0.1996796674968478, 0.327206369334303, 0.9346828337131252], 216 -> 
             RGBColor[
              0.8664637178535413, 0.48652475561155717`, 0.21028639171424535`],
              21 -> RGBColor[
              0.19357781768564236`, 0.320792938303103, 0.9343353423932549], 
             175 -> RGBColor[
              0.18260859612989327`, 0.30926359095919453`, 0.9337106614531641],
              7 -> RGBColor[
              0.9383196861766793, 0.9535195034595876, 0.9892928618873055], 13 -> 
             RGBColor[
              0.33328873930237535`, 0.463099687229773, 0.9424578416460552], 
             294 -> RGBColor[
              0.5360494193639693, 0.63422809324764, 0.9566189203875064], 193 -> 
             RGBColor[
              0.27956374695486264`, 0.41116960178785156`, 0.939232113860354], 
             60 -> RGBColor[
              0.28726741181117993`, 0.4192666419924039, 0.9396708261773704], 
             65 -> RGBColor[
              0.3774633879291902, 0.5013615475879224, 0.9452726111944477], 69 -> 
             RGBColor[
              0.20756886290590398`, 0.3354984139131004, 0.9351321117206522], 
             217 -> RGBColor[
              0.20003824461178885`, 0.32758325661720833`, 0.9347032541493537],
              214 -> RGBColor[
              0.20083038530367384`, 0.32841584670900015`, 0.9347483653898895],
              170 -> RGBColor[
              0.19757646601375403`, 0.32499577122489554`, 0.9345630595000708],
              74 -> RGBColor[
              0.20590138873724428`, 0.3337457928378705, 0.935037151533554], 
             246 -> RGBColor[
              0.1844498116639085, 0.31119882522525194`, 0.9338155159539919], 
             264 -> RGBColor[
              0.2962099519152749, 0.42866581863159803`, 0.9401800906069961], 
             278 -> RGBColor[
              0.2006299825882091, 0.3282052107487807, 0.934736952751713], 45 -> 
             RGBColor[
              0.29993474933268105`, 0.43258081688308847`, 0.9403922123095734],
              237 -> RGBColor[
              0.8250746635773962, 0.19374042880931708`, 0.17164483220048377`],
              228 -> RGBColor[
              0.426257062503514, 0.5436241760628097, 0.9483817009917713], 180 -> 
             RGBColor[
              0.19488460571983207`, 0.32216645538218325`, 0.9344097620385824],
              53 -> RGBColor[
              0.21587739356825456`, 0.3442312064305009, 0.9356052702505034], 
             48 -> RGBColor[
              0.1928098846058197, 0.31998579194643995`, 0.9342916097404141], 
             5 -> RGBColor[
              0.9710126878169619, 0.9138811308413543, 0.3418901952738247], 
             101 -> RGBColor[
              0.6473280227603806, 0.724416838346381, 0.9654832657505968], 267 -> 
             RGBColor[
              0.1962060745132835, 0.32355540287006146`, 0.9344850177314316], 
             120 -> RGBColor[
              0.27909030860477735`, 0.41067198806418675`, 0.939205152246706], 
             147 -> RGBColor[
              0.21339775345539977`, 0.34162494745362687`, 0.9354640584143752],
              89 -> 
             RGBColor[
              0.3807443443279537, 0.5042033471148679, 0.9454816708349412], 43 -> 
             RGBColor[
              0.2255865897625529, 0.3544361872293025, 0.9361581946103001], 
             199 -> RGBColor[
              0.19839476243792764`, 0.32585585264969186`, 0.9346096602708663],
              268 -> RGBColor[
              0.20504953117466115`, 0.3328504365287066, 0.9349886395055752], 
             169 -> RGBColor[
              0.6047389625257771, 0.6899933588150511, 0.9620264128432912], 20 -> 
             RGBColor[
              0.21900416978762977`, 0.3475176464861269, 0.9357833355305459], 
             4 -> RGBColor[
              0.2205376694136581, 0.34912945182257465`, 0.935870666065639], 
             167 -> RGBColor[
              0.9076820231617462, 0.6716970155181059, 0.2445769927357579], 
             142 -> RGBColor[
              0.8299355921400753, 0.23110365581454728`, 0.17629966288173887`],
              16 -> RGBColor[
              0.24679037784549854`, 0.37672271290229153`, 0.9373657189734305],
              281 -> RGBColor[
              0.9784615748157791, 0.9834572582803182, 0.9213431151026323], 
             289 -> RGBColor[
              0.2434445902532613, 0.3732060780076645, 0.9371751813197018], 
             178 -> RGBColor[
              0.25901133304362195`, 0.3895677116688322, 0.9380616842926806], 
             58 -> RGBColor[
              0.19114091674596853`, 0.31823160090706226`, 0.9341965644898124],
              186 -> RGBColor[
              0.19311599281626868`, 0.32030753108400334`, 0.9343090421501528],
              122 -> RGBColor[
              0.18504035865818397`, 0.31181952755907755`, 0.93384914673168], 
             249 -> RGBColor[
              0.20745669335557887`, 0.3353805166037485, 0.9351257238307011], 
             113 -> RGBColor[
              0.2676326072490897, 0.3986292174791347, 0.9385526531046497], 52 -> 
             RGBColor[
              0.1987330571876369, 0.3262114218807623, 0.9346289256564001], 
             187 -> RGBColor[
              0.22474017350644473`, 0.35354655007824254`, 0.9361099924566755],
              259 -> RGBColor[
              0.18516129488531852`, 0.3119466392015956, 0.9338560338709061], 
             42 -> RGBColor[
              0.8376047344232163, 0.2900520440423452, 0.18364364219313192`], 
             134 -> RGBColor[
              0.24479905803441923`, 0.3746297095238789, 0.9372523162560832], 
             248 -> RGBColor[
              0.22195872707107797`, 0.35062307352078237`, 0.9359515931969625],
              174 -> 
             RGBColor[
              0.23320476894069225`, 0.36244337656598474`, 0.9365920386444091],
              215 -> RGBColor[
              0.22474171532416531`, 0.3535481706264238, 0.9361100802609137], 
             83 -> RGBColor[
              0.846552585818907, 0.35882915084310774`, 0.19221211479479816`], 
             95 -> RGBColor[
              0.28755638833203334`, 0.4195703746379904, 0.9396872829627306], 
             166 -> RGBColor[
              0.18609439165410657`, 0.312927383067344, 0.9339091723514956], 
             233 -> RGBColor[
              0.20539561179114207`, 0.3332141891994065, 0.9350083482847035], 
             295 -> RGBColor[
              0.19692281060910452`, 0.3243087379504625, 0.9345258347917725], 
             141 -> RGBColor[
              0.2938477713702168, 0.42618301710784506`, 0.940045567919488], 
             205 -> RGBColor[
              0.3723597127044757, 0.4969410006264502, 0.9449474095221317], 
             224 -> RGBColor[
              0.20866772558178895`, 0.33665338825737323`, 0.9351946903244223],
              231 -> RGBColor[
              0.23118072954041266`, 0.36031598282478083`, 0.9364767725948611],
              68 -> RGBColor[
              0.8768566069289154, 0.9046456729993274, 0.9881165600196555], 10 -> 
             RGBColor[
              0.19040293767796423`, 0.3174559381160143, 0.9341545376736317], 
             250 -> RGBColor[
              0.18265386603570732`, 0.30931117250048296`, 0.9337132395073293],
              282 -> RGBColor[
              0.4406321468160179, 0.5560751515815551, 0.9492976686527762], 
             232 -> RGBColor[
              0.18790775611424687`, 0.3148333440888988, 0.9340124407748683], 
             253 -> RGBColor[
              0.19184993915614282`, 0.3189768284147727, 0.9342369422671671], 
             55 -> RGBColor[
              0.20213692733288047`, 0.32978910522124555`, 0.9348227710255971],
              91 -> RGBColor[
              0.49015879412300467`, 0.5969720163279171, 0.9530062422656385], 
             105 -> RGBColor[
              0.28384023029084227`, 0.41566445691867016`, 0.9394756532598479],
              36 -> RGBColor[
              0.18133311757286624`, 0.3079229821257478, 0.9336380248362428], 
             123 -> RGBColor[
              0.19860317371820202`, 0.3260749061192986, 0.9346215289849611], 
             94 -> RGBColor[
              0.796888814031874, 0.8412548651917855, 0.9803900876994809], 96 -> 
             RGBColor[
              0.20095046543520778`, 0.32854205854076235`, 0.9347552037757377],
              2 -> 
             RGBColor[
              0.19859115798198185`, 0.32606227681868954`, 0.934620844706559], 
             262 -> RGBColor[
              0.3038398335581257, 0.4366853080006712, 0.9406146010791581], 
             272 -> RGBColor[
              0.17908821045117204`, 0.30556344240551475`, 0.9335101806967048],
              97 -> RGBColor[
              0.44885816070930806`, 0.563200111364443, 0.9498218229840781], 
             209 -> RGBColor[
              0.1804556557285978, 0.30700071409312746`, 0.9335880546823002], 
             66 -> RGBColor[
              0.3863417480503173, 0.5090515368854881, 0.9458383324505404], 
             139 -> RGBColor[
              0.4407231525670485, 0.5561539761890157, 0.9493034674587586], 56 -> 
             RGBColor[
              0.19935669202797407`, 0.3268669016386893, 0.9346644407379722], 
             144 -> RGBColor[
              0.19763991012936863`, 0.32506245501299574`, 0.9345666725485978],
              298 -> RGBColor[
              0.2601377913887575, 0.39075169081115385`, 0.9381258344289902], 
             204 -> RGBColor[
              0.4836083421786542, 0.5916540643449961, 0.9524905666934831], 
             207 -> RGBColor[
              0.18528775379377113`, 0.3120795555323372, 0.9338632355186633], 
             149 -> RGBColor[
              0.895503807139292, 0.6183890185729798, 0.2345181540520019], 219 -> 
             RGBColor[
              0.18433414396946993`, 0.31107725114464163`, 0.9338089288499086],
              9 -> RGBColor[
              0.19896010530687766`, 0.32645006384976655`, 0.9346418557109033],
              11 -> RGBColor[
              0.5318148081413353, 0.630790245090044, 0.9562855562801685], 44 -> 
             RGBColor[
              0.31621931418873805`, 0.44831500913059213`, 0.9413701929717141],
              153 -> RGBColor[
              0.22106916700115545`, 0.3496880894859278, 0.9359009340669666], 
             32 -> RGBColor[
              0.9876761626712638, 0.9891717908034641, 0.8539014078132029], 
             162 -> RGBColor[
              0.9913482769712819, 0.9906903044355545, 0.7930449707347249], 90 -> 
             RGBColor[
              0.21567607897691587`, 0.34401961203092163`, 0.935593805682345], 
             8 -> RGBColor[
              0.2044682273202984, 0.33223944932097826`, 0.9349555351110312], 
             163 -> RGBColor[
              0.6211503872091352, 0.7033168926992579, 0.9633183803113946], 49 -> 
             RGBColor[
              0.20962180710681122`, 0.3376561884324342, 0.9352490238558351], 
             76 -> 
             RGBColor[
              0.3269177544061254, 0.4575814603276529, 0.9420518881221068], 82 -> 
             RGBColor[
              0.6134396494628491, 0.6970569684320459, 0.962711362790644], 67 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 211 -> 
             RGBColor[
              0.2707327274798912, 0.4018876404006824, 
               0.9387292003655769]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJwtl3k4FGrYxsc2dmbMmGEYZp8hUUJS8qQSUSklLeLUoUhCylJkaUGShISD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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 5}], {
             RGBColor[
             0.8694664994809802, 0.4010878979497081, 0.22431948647786654`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 32}], {
             RGBColor[
             0.8750209910990808, 0.42618478460374476`, 0.39498989065765927`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 51}], {
             RGBColor[
             0.8162278504025469, 0.38063100330818245`, 0.4376314664426699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 80}], {
             RGBColor[
             0.8720650730237359, 0.40985349668350635`, 0.23441445399203503`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 83}], {
             RGBColor[
             0.827979798814962, 0.21607057128362597`, 0.1744267929848577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 92}], {
             RGBColor[
             0.8229805000264965, 0.17764377008878246`, 0.16963945881912273`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 125}], {
             RGBColor[
             0.8241937608739676, 0.18696942461673885`, 0.17080127877684323`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 128}], {
             RGBColor[
             0.8274423550647934, 0.21193954311047752`, 0.1739121362427404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 142}], {
             RGBColor[
             0.822440800922018, 0.17349540627410584`, 0.16912264234717125`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 149}], {
             RGBColor[
             0.8442968725884236, 0.3025905271935833, 0.18852880607059228`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 150}], {
             RGBColor[
             0.848265408272229, 0.31999959159908814`, 0.19180863643949353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 197}], {
             RGBColor[
             0.8745761742166813, 0.4260008413916001, 0.4023616575482095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 198}], {
             RGBColor[
             0.8673259572403823, 0.4208317382887128, 0.4252968469940128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 237}], {
             RGBColor[
             0.820820491401125, 0.16104099727236243`, 0.16757103212008623`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 243}], {
             RGBColor[
             0.8749347729676722, 0.4261491311907023, 0.39641874822047274`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 256}], {
             RGBColor[
             0.8184383049744752, 0.1427304685163843, 0.1652898477076317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 277}], {
             RGBColor[
             0.8767993326536895, 0.4256141747773018, 0.2705857731385237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 281}], {
             RGBColor[
             0.8719494618139193, 0.4242799404293628, 0.41747045975413577`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 49}], {
             RGBColor[
             0.20410648254439653`, 0.3318592326255619, 0.934934934281197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 54}], {
             RGBColor[
             0.22131402237840694`, 0.34994544801214666`, 0.9359148782184701]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 102}], {
             RGBColor[
             0.19539325191364892`, 0.3227010747819161, 0.9344387286868456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 165}], {
             RGBColor[
             0.2081927032562806, 0.336154109675109, 0.935167638505717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 172}], {
             RGBColor[
             0.19458761473709335`, 0.321854299029009, 0.9343928488414741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 174}], {
             RGBColor[
             0.21589796346133705`, 0.34425282669233714`, 0.9356064416754841]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 183}], {
             RGBColor[
             0.19566573686527955`, 0.3229874737426237, 0.9344542463017356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 238}], {
             RGBColor[
             0.19301734075154908`, 0.3202038415090809, 0.9343034240610095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 253}], {
             RGBColor[
             0.19522054856906235`, 0.32251955261673115`, 0.9344288934868631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 24}], {
             RGBColor[
             0.9389911914260977, 0.8504167316496911, 0.6099487388884464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 59}], {
             RGBColor[
             0.9696130276591681, 0.9767225112372966, 0.930252756027731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 65}], {
             RGBColor[
             0.6658408786786703, 0.7333691314923763, 0.9538265746888542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 72}], {
             RGBColor[
             0.8710164273574281, 0.4731960144605215, 0.4379945662177568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 106}], {
             RGBColor[
             0.9080394881357245, 0.9290324924917327, 0.9745333831638314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 115}], {
             RGBColor[
             0.6529735529155825, 0.7222241006469869, 0.9530066800693597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 155}], {
             RGBColor[
             0.9402661035019293, 0.855471333191099, 0.6109745630706932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[
             0.972783323199716, 0.9780335099161923, 0.8777127544589929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 169}], {
             RGBColor[
             0.7794786659769637, 0.8276850371059405, 0.962203475513276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 194}], {
             RGBColor[
             0.8201119559484569, 0.8600043630497185, 0.9658594088182089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 200}], {
             RGBColor[
             0.659894342148658, 0.7282185404316961, 0.9534476666394777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 210}], {
             RGBColor[
             0.7129487102103079, 0.7736730218742174, 0.9569659936880668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 227}], {
             RGBColor[
             0.9534614284413586, 0.9077863994945625, 0.6215918312510428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 228}], {
             RGBColor[
             0.690237715965832, 0.7545004457298199, 0.955381119587516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 241}], {
             RGBColor[
             0.9701712881509421, 0.9769533662972854, 0.9210009349471945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 264}], {
             RGBColor[
             0.6252141606717125, 0.697021267014214, 0.9512803143951285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 290}], {
             RGBColor[
             0.9503146533364857, 0.8953104848043834, 0.619059862137357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 291}], {
             RGBColor[
             0.940546596555184, 0.9549527783634579, 0.9776339401843177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 8}], {
             RGBColor[
             0.21250294836697825`, 0.34068445057177643`, 0.935413100588335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 15}], {
             RGBColor[
             0.23945687025241685`, 0.36901473145072583`, 0.9369480865649568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 62}], {
             RGBColor[
             0.21110734445904222`, 0.33921758237813715`, 0.9353336230103891]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 85}], {
             RGBColor[
             0.2263430797542824, 0.3552313061748459, 0.9362012755962026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 121}], {
             RGBColor[
             0.2229935575329976, 0.35171074594830076`, 0.9360105252608744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 135}], {
             RGBColor[
             0.21680708920312736`, 0.3452083754888601, 0.935658215041548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 158}], {
             RGBColor[
             0.2067416614051505, 0.33462897268820413`, 0.9350850038189193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 173}], {
             RGBColor[
             0.21091230660044274`, 0.33901258522263467`, 0.9353225158928745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 186}], {
             RGBColor[
             0.2068268311149634, 0.334718491453289, 0.9350898541078958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 213}], {
             RGBColor[
             0.21145636706915383`, 0.33958442727067606`, 0.9353534993317023]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 214}], {
             RGBColor[
             0.21068402735866598`, 0.33877264926578743`, 0.9353095157277642]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 249}], {
             RGBColor[
             0.21399718138461848`, 0.3422549842131616, 0.93549819494817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 255}], {
             RGBColor[
             0.2932777706676125, 0.42028873435652747`, 0.9402069895504767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 263}], {
             RGBColor[
             0.21521347097412877`, 0.3435333816889509, 0.9355674608409534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 265}], {
             RGBColor[
             0.22162675469537457`, 0.35027414950565383`, 0.9359326878612754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 276}], {
             RGBColor[
             0.23095575836688206`, 0.36007952385740394`, 0.9364639608193436]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 286}], {
             RGBColor[
             0.22071420539136402`, 0.34931500232817103`, 0.9358807195284078]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.7514137479791486, 0.7723356879656991, 0.6490878757769967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 23}], {
             RGBColor[
             0.9801796714011944, 0.9518718565732095, 0.5840536111729073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 51}], {
             RGBColor[
             0.8911547141993119, 0.8831957888790658, 0.6618581652210298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.978010186853574, 0.9509747189595588, 0.6200075845730131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[
             0.8880392864849254, 0.5438464775091899, 0.242104808287807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 92}], {
             RGBColor[
             0.8780406889079944, 0.46699287511950294`, 0.23253013995633712`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 101}], {
             RGBColor[
             0.8091703552886713, 0.8191489845938676, 0.6536867305122107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 128}], {
             RGBColor[
             0.8869643989845882, 0.5355844211628931, 0.24107549480357243`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 142}], {
             RGBColor[
             0.8769612906990375, 0.45869614749014964`, 0.23149650701243416`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 149}], {
             RGBColor[
             0.933258247478127, 0.766135074707167, 0.2882041746629133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 197}], {
             RGBColor[
             0.9786771999205136, 0.9512505460041922, 0.6089534518793391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 198}], {
             RGBColor[
             0.967801874456065, 0.9434968913498611, 0.6433562360480443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 204}], {
             RGBColor[
             0.7273105149978081, 0.7527675975931751, 0.6471903809836539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 226}], {
             RGBColor[
             0.978634912205556, 0.9512330589473125, 0.6096542687532867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 243}], {
             RGBColor[
             0.9792150980469998, 0.9514729807028455, 0.600039087887734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 256}], {
             RGBColor[
             0.868956298803952, 0.39716627197470655`, 0.223830917733355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 290}], {
             RGBColor[
             0.9587118125308915, 0.8695626925266455, 0.3088146906826389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 38}], {
             RGBColor[
             0.19835724810513683`, 0.32581642270738265`, 0.9346075238851115]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 52}], {
             RGBColor[
             0.20466403550360635`, 0.3324452561365908, 0.9349666860973984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.21323620369391516`, 0.3414551484114601, 0.9354548583944501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 88}], {
             RGBColor[
             0.21672673573205908`, 0.345123918896063, 0.935653639030243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 93}], {
             RGBColor[
             0.2258625386311459, 0.35472622698636247`, 0.9361739094901367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 124}], {
             RGBColor[
             0.19825974011141095`, 0.3257139356236129, 0.9346019709491189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 147}], {
             RGBColor[
             0.2119963836374878, 0.34015201892302305`, 0.935384252476386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 273}], {
             RGBColor[
             0.22476258261676274`, 0.3535701034740064, 0.9361112686223567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 289}], {
             RGBColor[
             0.22701980203641853`, 0.3559425842000419, 0.9362398139290493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 42}], {
             RGBColor[
             0.8711763850077039, 0.5112078638480927, 0.45219338209118976`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 60}], {
             RGBColor[
             0.6127935489939296, 0.6863930727259957, 0.9644818440323379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 77}], {
             RGBColor[
             0.6760511895639363, 0.7431695037981105, 0.9684398535409274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 80}], {
             RGBColor[
             0.9585640473109542, 0.9468487152511682, 0.6807339798518178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 81}], {
             RGBColor[
             0.9138922902616244, 0.7722436147323656, 0.6093859995388808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 82}], {
             RGBColor[
             0.7758796678197641, 0.8252882359458167, 0.9760021123389747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 103}], {
             RGBColor[
             0.6798246620935919, 0.7464378960430543, 0.9686802958737664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 127}], {
             RGBColor[
             0.6435774661849356, 0.7150423967840147, 0.9663706566026036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 130}], {
             RGBColor[
             0.92506143421404, 0.8207777707366587, 0.6185929179813181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 140}], {
             RGBColor[
             0.8576525620588931, 0.4072578344865292, 0.4392429539624352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 145}], {
             RGBColor[
             0.9016117745004403, 0.9243171913792056, 0.9881346792519563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 154}], {
             RGBColor[
             0.7178086500945909, 0.778143567686985, 0.971430549102502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 167}], {
             RGBColor[
             0.9230008546692128, 0.8126082594888467, 0.6169349273115317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 168}], {
             RGBColor[
             0.6693655533207783, 0.7373787417141351, 0.9680138507113893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 181}], {
             RGBColor[
             0.962306825108859, 0.9594739836095195, 0.6952739648323978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 201}], {
             RGBColor[
             0.8763492903148913, 0.5509690808206948, 0.45714696205531347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 202}], {
             RGBColor[
             0.890487052481644, 0.642513633392233, 0.47001474727817605`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 203}], {
             RGBColor[
             0.9377223890197792, 0.9530740402179558, 0.990303930173889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 205}], {
             RGBColor[
             0.6553396994405775, 0.7252302520430189, 0.9671201357047186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 216}], {
             RGBColor[
             0.8904157072945873, 0.6421896715609007, 0.4699552151052654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 237}], {
             RGBColor[
             0.8628230044438239, 0.4470001203594073, 0.4441941754294244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 255}], {
             RGBColor[
             0.6521687790491231, 0.722483760175034, 0.9669180874613099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 269}], {
             RGBColor[
             0.9557422920381128, 0.9373302721362289, 0.6697719934605999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 282}], {
             RGBColor[
             0.6894759164963487, 0.7547973275205713, 0.9692952652700408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 293}], {
             RGBColor[
             0.9190392263270429, 0.795614649307972, 0.6136807291548138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 299}], {
             RGBColor[
             0.8585691612482524, 0.41430321751227117`, 0.4401206903813164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 14}], {
             RGBColor[
             0.19233103918746458`, 0.31948249505119564`, 0.9342643402022272]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 64}], {
             RGBColor[
             0.21988638356939655`, 0.34844490910634823`, 0.9358335763002992]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 67}], {
             RGBColor[
             0.1916976136601492, 0.31881672466048916`, 0.9342282675555156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 69}], {
             RGBColor[
             0.2060185451131012, 0.33386893161703934`, 0.9350438234158418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 85}], {
             RGBColor[
             0.21830835870760254`, 0.3467863049240477, 0.9357437101188987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 121}], {
             RGBColor[
             0.21495883648631775`, 0.3432657446975026, 0.9355529597835706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 135}], {
             RGBColor[
             0.2087723681564475, 0.33676337423806185`, 0.9352006495642442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 173}], {
             RGBColor[
             0.2028775855537629, 0.3305675839718365, 0.9348649504155706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 186}], {
             RGBColor[
             0.19879211006828354`, 0.3262734902024908, 0.934632288630592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 213}], {
             RGBColor[
             0.20342164602247398`, 0.3311394260198779, 0.9348959338543985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 234}], {
             RGBColor[
             0.19931169581116837`, 0.32681960776190155`, 0.934661878269991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 249}], {
             RGBColor[
             0.20596246033793864`, 0.3338099829623634, 0.9350406294708662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 263}], {
             RGBColor[
             0.20717874992744892`, 0.3350883804381527, 0.9351098953636496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 286}], {
             RGBColor[
             0.21267948434468417`, 0.34087000107737286`, 0.9354231540511039]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 45}], {
             RGBColor[
             0.24944742731977937`, 0.3795154403664275, 0.9375170340102383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 47}], {
             RGBColor[
             0.1915298565644043, 0.31864040131644705`, 0.9342187140370874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 96}], {
             RGBColor[
             0.19995528537104273`, 0.3274960611952644, 0.9346985297433206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 112}], {
             RGBColor[
             0.19409572030031721`, 0.3213372867880486, 0.9343648361809924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 132}], {
             RGBColor[
             0.19792820821317225`, 0.32536547457822756`, 0.9345830906979717]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 133}], {
             RGBColor[
             0.19212471165815448`, 0.3192656317359698, 0.9342525901546672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 141}], {
             RGBColor[
             0.24640393833854723`, 0.3763165404788058, 0.9373437118151957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 146}], {
             RGBColor[
             0.1994945649800457, 0.3270118148529666, 0.9346722923986279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 236}], {
             RGBColor[
             0.21519552032906075`, 0.34351451442284786`, 0.9355664385782725]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 22}], {
             RGBColor[
             0.18947218593303478`, 0.31647765901902436`, 0.9341015327386817]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 48}], {
             RGBColor[
             0.19160641114189197`, 0.3187208650312271, 0.934223073707023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 63}], {
             RGBColor[
             0.18664280478053893`, 0.31350380003462497`, 0.9339404036677414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 71}], {
             RGBColor[
             0.20685989156236995`, 0.3347532400796667, 0.9350917368514671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 73}], {
             RGBColor[
             0.18653587436616526`, 0.31339140938933835`, 0.9339343141388322]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 100}], {
             RGBColor[
             0.18553288790448116`, 0.3123372070250937, 0.9338771955436248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 119}], {
             RGBColor[
             0.1856272606689936, 0.3124363987841752, 0.9338825699329518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 122}], {
             RGBColor[
             0.1877216481680741, 0.3146377328375459, 0.9340018422026558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 161}], {
             RGBColor[
             0.19602879349749167`, 0.3233690692821986, 0.9344749218398459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 244}], {
             RGBColor[
             0.1899533548754444, 0.3169833980853699, 0.9341289345981263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 266}], {
             RGBColor[
             0.19427634422620857`, 0.3215271339863788, 0.9343751224463628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 51}], {
             RGBColor[
             0.6715557743614986, 0.7416503460034106, 0.9690558457242018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 101}], {
             RGBColor[
             0.589571415450858, 0.6776035417182125, 0.9608844110153827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 104}], {
             RGBColor[
             0.4334513122055766, 0.547724101182389, 0.9494290167598639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 114}], {
             RGBColor[
             0.38547343504917886`, 0.49973179121413747`, 0.9466075727466067]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 116}], {
             RGBColor[
             0.4095833128093886, 0.5250728013946587, 0.9479805946176828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 149}], {
             RGBColor[
             0.7136593076403137, 0.6245896318315118, 0.5954018551660852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 197}], {
             RGBColor[
             0.7590782600827003, 0.809705103128537, 0.9161511323825111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 198}], {
             RGBColor[
             0.7482029346182517, 0.8019514484742061, 0.9505539165512161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 204}], {
             RGBColor[
             0.5077115751599948, 0.6112221547175201, 0.9543880614868259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 243}], {
             RGBColor[
             0.7596161582091865, 0.8099275378271904, 0.907236768390906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 254}], {
             RGBColor[
             0.4252983225505378, 0.5406623913243694, 0.9489095154684506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 283}], {
             RGBColor[
             0.41881779248479195`, 0.534778825033336, 0.9485064845740085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.3382052536051789, 0.4616299042238716, 0.9429808558058818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 27}], {
             RGBColor[
             0.6997308165084448, 0.7282337735956864, 0.6429681792954851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.33246233459167696`, 0.45559373221858496`, 0.9426538050639501]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 76}], {
             RGBColor[
             0.3782689418854923, 0.5020592779365523, 0.9453239403802199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 87}], {
             RGBColor[
             0.7113840896935575, 0.7671448961592477, 0.7220908533867955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 151}], {
             RGBColor[
             0.5137240937710055, 0.6154599354387978, 0.9550391768879118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 154}], {
             RGBColor[
             0.46345887168868094`, 0.5746523637299171, 0.9510821144780158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 181}], {
             RGBColor[
             0.707957046702949, 0.7559827796524516, 0.6749255302079116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 192}], {
             RGBColor[
             0.3801187118441842, 0.5036614557026298, 0.9454418060863005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 220}], {
             RGBColor[
             0.38135478455479077`, 0.5047320797577364, 0.9455205675464041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 239}], {
             RGBColor[
             0.3335981101513706, 0.4567875043441526, 0.9427184858018454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 258}], {
             RGBColor[
             0.3848908244823526, 0.507794819816456, 0.9457458808837911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 32}], {
             RGBColor[
             0.6604824509868196, 0.7261357390166185, 0.898179624729629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 53}], {
             RGBColor[
             0.27458306643531494`, 0.40366544683013694`, 0.9390315559482794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 93}], {
             RGBColor[
             0.2872094013725457, 0.41693652540503934`, 0.939750607043966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 107}], {
             RGBColor[
             0.3708820169269006, 0.49566109481506393`, 0.9448532520538597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 137}], {
             RGBColor[
             0.2974114508687985, 0.42765952627289927`, 0.9403315986701979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 147}], {
             RGBColor[
             0.27334324637888757`, 0.4023623173416999, 0.9389609500302152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 156}], {
             RGBColor[
             0.3638901315072269, 0.4896050750869218, 0.9444077352975997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 179}], {
             RGBColor[
             0.42802275177735205`, 0.5432681021152472, 0.9490151577652866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 251}], {
             RGBColor[
             0.3094480150189227, 0.44031071835692515`, 0.9410170631920465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 270}], {
             RGBColor[
             0.27306394266259, 0.4020687514269927, 0.9389450440967648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 271}], {
             RGBColor[
             0.2779619784734704, 0.40721689761763513`, 0.9392239799901998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 273}], {
             RGBColor[
             0.2861094453581625, 0.4157804018926833, 0.9396879661761859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 274}], {
             RGBColor[
             0.3981676494624695, 0.5190303850989934, 0.9466648547482157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 277}], {
             RGBColor[
             0.6631499633187324, 0.7252798242769541, 0.7115734484509257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 282}], {
             RGBColor[
             0.38696044305919663`, 0.509587419405664, 0.9458777551494157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 289}], {
             RGBColor[
             0.2883666647778183, 0.41815288261871875`, 0.9398165114828785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 67}], {
             RGBColor[
             0.17956042552731538`, 0.30605977039070653`, 0.9335370726467116]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 173}], {
             RGBColor[
             0.1907403974209291, 0.31781062970205387`, 0.9341737555067666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 186}], {
             RGBColor[
             0.18665492193544975`, 0.31351653593270823`, 0.9339410937217879]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.19128445788964016`, 0.31838247175009526`, 0.9342047389455943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 249}], {
             RGBColor[
             0.19382527220510481`, 0.3210530286925808, 0.9343494345620621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 46}], {
             RGBColor[
             0.23154240030757095`, 0.3606961217323153, 0.9364973692100068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 60}], {
             RGBColor[
             0.27282174145117777`, 0.4040833265356404, 0.9388481666208225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.23002654529780098`, 0.3591028620062883, 0.9364110435097069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 77}], {
             RGBColor[
             0.3360793820211845, 0.46085975760775527`, 0.942806176129412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 82}], {
             RGBColor[
             0.43590786027701234`, 0.5429784897554615, 0.9503684349274593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 103}], {
             RGBColor[
             0.33985285455084013`, 0.464128149852699, 0.9430466184622509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 127}], {
             RGBColor[
             0.3036056586421837, 0.43273265059365945`, 0.9407369791910881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 135}], {
             RGBColor[
             0.2357262900418861, 0.3650936551170112, 0.9367356355408658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 158}], {
             RGBColor[
             0.22566086224390924`, 0.3545142523163553, 0.9361624243182372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 168}], {
             RGBColor[
             0.3293937457780264, 0.4550689955237798, 0.942380173299874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 186}], {
             RGBColor[
             0.22574603195372214`, 0.35460377108144014`, 0.9361672746072136]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 196}], {
             RGBColor[
             0.23071789586563907`, 0.35982951528724394`, 0.9364504149017838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 212}], {
             RGBColor[
             0.24587235329600743`, 0.3757578108946581, 0.9373134388334325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 214}], {
             RGBColor[
             0.22960322819742474`, 0.35865792889393855`, 0.936386936227082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 225}], {
             RGBColor[
             0.2429863506332136, 0.37272443911292436`, 0.9371490852512447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 255}], {
             RGBColor[
             0.31219697150637127`, 0.44017401398467865`, 0.9412844100497945]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 265}], {
             RGBColor[
             0.24054595553413333`, 0.37015942913380495`, 0.9370101083605932]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 276}], {
             RGBColor[
             0.24987495920564082`, 0.37996480348555506`, 0.9375413813186614]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 286}], {
             RGBColor[
             0.23963340623012278`, 0.3692002819563222, 0.9369581400277256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.22364840280037163`, 0.35239902984389887`, 0.9360478177300946]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 39}], {
             RGBColor[
             0.22425729902189784`, 0.35303901837897317`, 0.9360824934691292]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 76}], {
             RGBColor[
             0.286854066125812, 0.4171520866149722, 0.9397088035477686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 90}], {
             RGBColor[
             0.2312332284112072, 0.3603711624666066, 0.9364797623278878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 126}], {
             RGBColor[
             0.23513936956710785`, 0.3644767644851118, 0.9367022112880983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 151}], {
             RGBColor[
             0.42230921801132515`, 0.5305527441172178, 0.9494240400554605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 153}], {
             RGBColor[
             0.233929772423327, 0.36320540119410966`, 0.9366333265201985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 192}], {
             RGBColor[
             0.28870383608450384`, 0.4187542643810497, 0.9398266692538492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 220}], {
             RGBColor[
             0.2899399087951104, 0.41982488843615623`, 0.9399054307139528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 222}], {
             RGBColor[
             0.23410797445122994`, 0.3633927028240968, 0.9366434748620613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 239}], {
             RGBColor[
             0.2421832343916902, 0.3718803130225725, 0.9371033489693941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 248}], {
             RGBColor[
             0.23437455245828825`, 0.36367289321153695`, 0.9366586560851965]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 285}], {
             RGBColor[
             0.22323502267117318`, 0.3519645411182973, 0.9360242763432778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 40}], {
             RGBColor[
             0.6964483919711273, 0.7627900441024493, 0.9703791250975754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[
             0.7929575364765972, 0.44951011621237846`, 0.44612850273328253`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 66}], {
             RGBColor[
             0.5450024443168381, 0.6387388987189666, 0.9584682781320619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 81}], {
             RGBColor[
             0.7965640174649642, 0.6796969932787943, 0.60028868050202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 86}], {
             RGBColor[
             0.648920103921949, 0.7249224984916083, 0.966146582786049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 94}], {
             RGBColor[
             0.7502759773076164, 0.8048405628721153, 0.9757441557565323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 97}], {
             RGBColor[
             0.5762606506463335, 0.665813185958444, 0.9604600233988309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 120}], {
             RGBColor[
             0.4913767245940681, 0.5895491243083159, 0.9551516880301447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 130}], {
             RGBColor[
             0.8077331614173798, 0.7282311492830874, 0.6094955989444572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 140}], {
             RGBColor[
             0.7794337135277863, 0.345560086850815, 0.43317807460452784`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 162}], {
             RGBColor[
             0.8475057087773203, 0.8795582824939998, 0.8820715972741542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 169}], {
             RGBColor[
             0.654201051554568, 0.729209809683748, 0.9665623183284373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 178}], {
             RGBColor[
             0.4813372368134904, 0.5789969861106385, 0.9545799540531321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 182}], {
             RGBColor[
             0.47900337512465124`, 0.5765439495002909, 0.9544470440825916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 201}], {
             RGBColor[
             0.7981304417837846, 0.4892713331849807, 0.45108208269740613`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 202}], {
             RGBColor[
             0.8122682039505371, 0.5808158857565188, 0.4639498679202687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 294}], {
             RGBColor[
             0.6198562799736641, 0.7013271769000424, 0.963858572100545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 26}], {
             RGBColor[
             0.21453517633612967`, 0.3428204510180499, 0.9355288329647664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 33}], {
             RGBColor[
             0.20024058888485757`, 0.32779593327757145`, 0.9347147773563635]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 35}], {
             RGBColor[
             0.20318410319091706`, 0.3308897534428262, 0.9348824061415544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 129}], {
             RGBColor[
             0.1945312219559263, 0.32179502664049353`, 0.9343896373560123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 165}], {
             RGBColor[
             0.2088844992725249, 0.33688123115058255`, 0.9352070352654217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 175}], {
             RGBColor[
             0.19129167307218187`, 0.3183900553644156, 0.9342051498395663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 183}], {
             RGBColor[
             0.19635753288152386`, 0.32371459521809726`, 0.9344936430614402]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 184}], {
             RGBColor[
             0.19573226525779447`, 0.3230573993013006, 0.9344580349952694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.2043212377981297, 0.33208495401350496`, 0.9349471642751953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 253}], {
             RGBColor[
             0.19591234458530662`, 0.3232466740922047, 0.9344682902465677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 262}], {
             RGBColor[
             0.25190729178629806`, 0.38210091388515394`, 0.9376571196525632]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 36}], {
             RGBColor[
             0.200168643680248, 0.32772031430593734`, 0.9347106801833944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 37}], {
             RGBColor[
             0.22278622542452461`, 0.3514928267566807, 0.9359987180040172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 41}], {
             RGBColor[
             0.20379941702053028`, 0.3315364872908998, 0.9349174473538756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 44}], {
             RGBColor[
             0.26761174198818394`, 0.3979163278083595, 0.93857676425113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 55}], {
             RGBColor[
             0.21057054856025512`, 0.3386533758536862, 0.9353030532780715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 61}], {
             RGBColor[
             0.248131704384919, 0.378132532140237, 0.9374421055355356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 71}], {
             RGBColor[
             0.22116050761720274`, 0.349784094264723, 0.9359061357799242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 108}], {
             RGBColor[
             0.2298448182232575, 0.3589118553287811, 0.9364006944216527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 136}], {
             RGBColor[
             0.3058098324986471, 0.43100159391667037`, 0.9410107128012115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 152}], {
             RGBColor[
             0.20076184690853469`, 0.3283438085101236, 0.9347444622296798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 177}], {
             RGBColor[
             0.2554879446971804, 0.38586440712099823`, 0.9378610325387366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 208}], {
             RGBColor[
             0.20416035452872197`, 0.331915855496769, 0.9349380022110079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 252}], {
             RGBColor[
             0.2284732256377411, 0.3574702245574107, 0.936322584252997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 268}], {
             RGBColor[
             0.21202685048114545`, 0.34018404150741677`, 0.9353859875180606]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 279}], {
             RGBColor[
             0.22783544818024304`, 0.35679988001215385`, 0.9362862637702997]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 280}], {
             RGBColor[
             0.24050854139809294`, 0.3701201045046333, 0.9370079776808949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 50}], {
             RGBColor[
             0.18770061499905671`, 0.31461562564332873`, 0.9340006443947961]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 74}], {
             RGBColor[
             0.19973960321144332`, 0.32726936557048675`, 0.9346862469634045]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[
             0.21635493982133241`, 0.34473313782066695`, 0.9356324658031498]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 123}], {
             RGBColor[
             0.1960904957019222, 0.3234339222112008, 0.934478435689108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 189}], {
             RGBColor[
             0.20470683599275827`, 0.3324902421643972, 0.934969123521938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 206}], {
             RGBColor[
             0.20800021126608947`, 0.33595178838872103`, 0.9351566763716421]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 257}], {
             RGBColor[
             0.1888268034733999, 0.3157993211343368, 0.9340647791623633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 287}], {
             RGBColor[
             0.21828938866019382`, 0.34676636620145074`, 0.9357426298027625]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 300}], {
             RGBColor[
             0.2096118710905434, 0.33764574504935696`, 0.9352484580144076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.19067565939696252`, 0.3177425859342372, 0.934170068772073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 63}], {
             RGBColor[
             0.18571205303560948`, 0.312525520937635, 0.9338873987327916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 70}], {
             RGBColor[
             0.19915563229546623`, 0.32665557511190024`, 0.9346529906836472]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 73}], {
             RGBColor[
             0.1856051226212358, 0.3124131302923484, 0.9338813092038822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 100}], {
             RGBColor[
             0.1846021361595517, 0.3113589279281038, 0.9338241906086748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 119}], {
             RGBColor[
             0.18469650892406414`, 0.31145811968718523`, 0.933829564998002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 122}], {
             RGBColor[
             0.18679089642314464`, 0.31365945374055604`, 0.9339488372677058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 161}], {
             RGBColor[
             0.1950980417525622, 0.32239079018520866`, 0.934421916904896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 244}], {
             RGBColor[
             0.18902260313051494`, 0.31600511898838, 0.9340759296631764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 266}], {
             RGBColor[
             0.1933455924812791, 0.32054885488938883`, 0.9343221175114128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 24}], {
             RGBColor[
             0.956555334204736, 0.8626596651038085, 0.541866983332811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 31}], {
             RGBColor[
             0.7044976010018857, 0.7638813972041334, 0.8870888196503636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 44}], {
             RGBColor[
             0.6527829845870825, 0.7190887957178285, 0.883793610021852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 59}], {
             RGBColor[
             0.9871771704378065, 0.988965444691414, 0.8621710004720957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 72}], {
             RGBColor[
             0.8827258558765204, 0.48135797009659975`, 0.3926067291806665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 83}], {
             RGBColor[
             0.8941506088744137, 0.5691736279970934, 0.4035470855538621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 106}], {
             RGBColor[
             0.9256036309143629, 0.94127542594585, 0.906451627608196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 136}], {
             RGBColor[
             0.6909810750975458, 0.7521740618261392, 0.8862275585719336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 155}], {
             RGBColor[
             0.9578302462805677, 0.8677142666452164, 0.5428928075150579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 194}], {
             RGBColor[
             0.8376760987270953, 0.8722472965038359, 0.8977776532625734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 197}], {
             RGBColor[
             0.9878441835047461, 0.9892412717360475, 0.8511168677784218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 198}], {
             RGBColor[
             0.9769688580402975, 0.9814876170817164, 0.8855196519471269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 210}], {
             RGBColor[
             0.7305128529889463, 0.7859159553283347, 0.8888842381324313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 226}], {
             RGBColor[
             0.9878018957897885, 0.9892237846791677, 0.8518176846523693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 241}], {
             RGBColor[
             0.9877354309295805, 0.9891962997514028, 0.8529191793915591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 290}], {
             RGBColor[
             0.9678787961151241, 0.9075534182585008, 0.5509781065817215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 291}], {
             RGBColor[
             0.9581107393338224, 0.9671957118175754, 0.9095521846286824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.9468027585380377, 0.8226935997742366, 0.2974286527731346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 59}], {
             RGBColor[
             0.9543858496571156, 0.8617625274901577, 0.5778209567329167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 65}], {
             RGBColor[
             0.6506137006766177, 0.6184091477452374, 0.6013947753940398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 72}], {
             RGBColor[
             0.8608649753560598, 0.3965560252957622, 0.20304003335454723`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 87}], {
             RGBColor[
             0.9584560317231505, 0.8616047223377981, 0.3765513268644449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 106}], {
             RGBColor[
             0.892812310133672, 0.8140725087445938, 0.6221015838690171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 109}], {
             RGBColor[
             0.9582875876148832, 0.8633759964057863, 0.5131590613985512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 155}], {
             RGBColor[
             0.9250389254998768, 0.7405113494439601, 0.2585427637758789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 162}], {
             RGBColor[
             0.9575561451976635, 0.8630735261690534, 0.5252809551641785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 194}], {
             RGBColor[
             0.8048847779464043, 0.7450443793025796, 0.6134276095233945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 210}], {
             RGBColor[
             0.6977215322082554, 0.6587130381270785, 0.6045341943932525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 218}], {
             RGBColor[
             0.945476791560533, 0.8552536816107574, 0.5989703095762722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 226}], {
             RGBColor[
             0.9550105750090976, 0.8620208674779115, 0.5674676409131905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 227}], {
             RGBColor[
             0.9382342504393061, 0.7928264157474236, 0.2691600319562284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 241}], {
             RGBColor[
             0.9549441101488896, 0.8619933825501465, 0.5685691356523801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 290}], {
             RGBColor[
             0.9350874753344331, 0.7803505010572445, 0.2666280628425426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 291}], {
             RGBColor[
             0.9253194185531315, 0.839992794616319, 0.6252021408895034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 299}], {
             RGBColor[
             0.8537172703307078, 0.34161563232659264`, 0.19619538295009195`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 28}], {
             RGBColor[
             0.18729283765525817`, 0.3141870258004196, 0.9339774220783192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 58}], {
             RGBColor[
             0.19112827338567, 0.31821831193375316`, 0.9341958444691476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 79}], {
             RGBColor[
             0.18712823581077753`, 0.3140140188255107, 0.9339680482467827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 113}], {
             RGBColor[
             0.22937411863723062`, 0.3584171202197894, 0.9363738887765662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 134}], {
             RGBColor[
             0.21795734402989536`, 0.34641736624216146`, 0.935723720352283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 144}], {
             RGBColor[
             0.19437777007737006`, 0.3216337389867199, 0.9343808984985402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 160}], {
             RGBColor[
             0.19344001775085345`, 0.32064810183461934`, 0.9343274948908254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 176}], {
             RGBColor[
             0.19265413404658233`, 0.31982208823352565`, 0.9342827399764779]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.1930001178726018, 0.32018573917131365`, 0.9343024432435325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 221}], {
             RGBColor[
             0.1886556188584439, 0.3156193952502866, 0.9340550304517865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 230}], {
             RGBColor[
             0.19160057419890764`, 0.31871473003406703`, 0.934222741301755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 232}], {
             RGBColor[
             0.1895116930698092, 0.31651918352467145`, 0.9341037826116756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 245}], {
             RGBColor[
             0.2081790637788683, 0.33613977371955583`, 0.9351668617576563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 288}], {
             RGBColor[
             0.19999048340527747`, 0.32753305656092946`, 0.9347005342192993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 297}], {
             RGBColor[
             0.19155439006973912`, 0.318666187586068, 0.9342201111839221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 35}], {
             RGBColor[
             0.21774452951257628`, 0.3461936846912394, 0.9357116008803525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 54}], {
             RGBColor[
             0.23656624471631046`, 0.3659765007360335, 0.9367834697169728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 75}], {
             RGBColor[
             0.28101248706842963`, 0.4104564015750206, 0.9393964853748475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 102}], {
             RGBColor[
             0.21064547425155244`, 0.3387321275058029, 0.9353073201853483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 129}], {
             RGBColor[
             0.20909164827758553`, 0.33709895788890676`, 0.9352188320948104]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 165}], {
             RGBColor[
             0.2234449255941841, 0.3521851623989958, 0.9360362300042198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 175}], {
             RGBColor[
             0.20585209939384108`, 0.33369398661282884`, 0.9350343445783642]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 183}], {
             RGBColor[
             0.21091795920318307`, 0.3390185264665105, 0.9353228378002383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 224}], {
             RGBColor[
             0.21888166411978893`, 0.3473888852619182, 0.9357763590139934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 253}], {
             RGBColor[
             0.21047277090696587`, 0.3385506053406179, 0.9352974849853658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 262}], {
             RGBColor[
             0.26646771810795733`, 0.39740484513356716`, 0.9384863143913613]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 42}], {
             RGBColor[
             0.8816836574994876, 0.49667817991020385`, 0.23487588344630034`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 72}], {
             RGBColor[
             0.8762241387653882, 0.45471392654355186`, 0.22964784214088227`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 87}], {
             RGBColor[
             0.9814947768371431, 0.9488415742094825, 0.4164630400439475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 109}], {
             RGBColor[
             0.9813263327288758, 0.9506128482774708, 0.5530707745780536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 140}], {
             RGBColor[
             0.8681598345506768, 0.3927281505486404, 0.22192545531754573`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 151}], {
             RGBColor[
             0.7838347809145911, 0.7971566134890326, 0.6494113635450639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 154}], {
             RGBColor[
             0.7335695588322665, 0.7563490417801518, 0.6454543011351679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 155}], {
             RGBColor[
             0.9480776706138694, 0.8277482013156446, 0.2984544769553814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 162}], {
             RGBColor[
             0.9805948903116561, 0.9503103780407378, 0.565192668343681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 181}], {
             RGBColor[
             0.9780677338465346, 0.9376794577026863, 0.3692977168650637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 202}], {
             RGBColor[
             0.9009943249734276, 0.6279839494543441, 0.2526972486332866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 203}], {
             RGBColor[
             0.9534832977574548, 0.9312795143111227, 0.6643276822065549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 216}], {
             RGBColor[
             0.9009229797863709, 0.6276599876230118, 0.25263771646037597`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 227}], {
             RGBColor[
             0.9612729955532987, 0.8800632676191081, 0.309071745135731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 299}], {
             RGBColor[
             0.8690764337400362, 0.3997735335743823, 0.222803191736427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 79}], {
             RGBColor[
             0.1833054434406642, 0.3099960216654862, 0.9337503458766192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 144}], {
             RGBColor[
             0.19055497770725674`, 0.3176157418266954, 0.9341631961283768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 160}], {
             RGBColor[
             0.18961722538074013`, 0.31663010467459485`, 0.9341097925206621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 176}], {
             RGBColor[
             0.18883134167646898`, 0.3158040910735011, 0.9340650376063144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 221}], {
             RGBColor[
             0.18483282648833058`, 0.31160139809026205`, 0.9338373280816231]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 230}], {
             RGBColor[
             0.1877777818287943, 0.3146967328740425, 0.9340050389315915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 232}], {
             RGBColor[
             0.18568890069969585`, 0.3125011863646469, 0.9338860802415121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 240}], {
             RGBColor[
             0.18200025991928498`, 0.3086241910311017, 0.9336760176059227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 245}], {
             RGBColor[
             0.204356271408755, 0.33212177655953135`, 0.9349491593874928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 288}], {
             RGBColor[
             0.19616769103516415`, 0.32351505940090497`, 0.9344828318491358]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 297}], {
             RGBColor[
             0.18773159769962583`, 0.31464819042604353`, 0.9340024088137586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 43}], {
             RGBColor[
             0.21042089134742065`, 0.3384960766341818, 0.9352945305211986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 78}], {
             RGBColor[
             0.1946932984138494, 0.3219653792740117, 0.9343988673705204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 99}], {
             RGBColor[
             0.19546469586089602`, 0.32277616690028066`, 0.9344427973139495]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 131}], {
             RGBColor[
             0.21233150972289871`, 0.34050425768701104`, 0.9354033374111754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 170}], {
             RGBColor[
             0.19641582947302122`, 0.3237758686319784, 0.934496962966084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 178}], {
             RGBColor[
             0.22713326298795516`, 0.3560618388539467, 0.9362462753623888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 182}], {
             RGBColor[
             0.224799401299116, 0.35360880224359903`, 0.9361133653918483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 190}], {
             RGBColor[
             0.199834842245044, 0.32736946783330456`, 0.9346916706854744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 199}], {
             RGBColor[
             0.196824977685108, 0.32420590934437654`, 0.9345202633514818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 209}], {
             RGBColor[
             0.1878554243304431, 0.3147783400660943, 0.9340094605571987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 229}], {
             RGBColor[
             0.20648377022612274`, 0.3343579127078008, 0.9350703172977894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 259}], {
             RGBColor[
             0.19020824390880345`, 0.3172513026203284, 0.9341434501515016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 261}], {
             RGBColor[
             0.21999581851421782`, 0.3485599321719316, 0.9358398084585123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 284}], {
             RGBColor[
             0.21810645410068208`, 0.3465740903806829, 0.9357322119502256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 74}], {
             RGBColor[
             0.22759891531018372`, 0.3565512689686714, 0.9362727935732689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 104}], {
             RGBColor[
             0.2921921290764705, 0.4220073511871032, 0.9400404564262714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 123}], {
             RGBColor[
             0.2239498078006626, 0.3527158256093854, 0.9360649822989724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 189}], {
             RGBColor[
             0.23256614809149867`, 0.36177214556258186`, 0.9365556701318023]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 236}], {
             RGBColor[
             0.2403636886171835, 0.3699678550477007, 0.9369997285293126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 260}], {
             RGBColor[
             0.25373200019445147`, 0.38401879811531836`, 0.9377610340969933]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 267}], {
             RGBColor[
             0.22275125819820335`, 0.35145607398476686`, 0.9359967266722076]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 287}], {
             RGBColor[
             0.24614870075893425`, 0.37604826959963533`, 0.9373291764126268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 300}], {
             RGBColor[
             0.23747118318928384`, 0.36692764844754155`, 0.936835004624272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 37}], {
             RGBColor[
             0.32310841403988205`, 0.4466841095652183, 0.9420873563531128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 44}], {
             RGBColor[
             0.36793393060354135`, 0.4931076106168971, 0.9446654026002257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 59}], {
             RGBColor[
             0.7023281164542653, 0.7629842595904825, 0.9230427930504692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 61}], {
             RGBColor[
             0.3484538930002764, 0.47332381494877457`, 0.9435307438846312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 65}], {
             RGBColor[
             0.3985559674737674, 0.5196308798455622, 0.9466166117115924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 71}], {
             RGBColor[
             0.32148269623256015`, 0.4449753770732606, 0.9419947741290198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 136}], {
             RGBColor[
             0.4061320211140046, 0.526192876725208, 0.9470993511503072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 177}], {
             RGBColor[
             0.3558101333125378, 0.4810556899295358, 0.9439496708878323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 194}], {
             RGBColor[
             0.552827044743554, 0.6462661114029045, 0.958649445840947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 210}], {
             RGBColor[
             0.4456637990054052, 0.5599347702274033, 0.949756030710805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 226}], {
             RGBColor[
             0.7029528418062473, 0.7632425995782364, 0.912689477230743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 241}], {
             RGBColor[
             0.7028863769460394, 0.7632151146504713, 0.9137909719699326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 279}], {
             RGBColor[
             0.32815763679560045`, 0.4519911628206914, 0.9423749021193952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 280}], {
             RGBColor[
             0.3408307300134504, 0.46531138731317084`, 0.9430966160299905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 290}], {
             RGBColor[
             0.683029742131583, 0.6815722331575694, 0.6118498991600951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 291}], {
             RGBColor[
             0.6732616853502813, 0.7412145267166439, 0.970423977207056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 80}], {
             RGBColor[
             0.9832422855582464, 0.9646748589231064, 0.6130382528147665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 92}], {
             RGBColor[
             0.883595180526095, 0.49208976177353947`, 0.4032005441361298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 107}], {
             RGBColor[
             0.6980757286113448, 0.7586971466019095, 0.9005750351374335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 125}], {
             RGBColor[
             0.8860217022210372, 0.5107410708294523, 0.40552418405157087`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 128}], {
             RGBColor[
             0.8925188906026889, 0.5606813078169296, 0.41174589898336517`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 142}], {
             RGBColor[
             0.8825157823171381, 0.4837930341441863, 0.4021669111922269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 145}], {
             RGBColor[
             0.9262900127477325, 0.9421433350511439, 0.920438952214905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 149}], {
             RGBColor[
             0.9415899849052779, 0.803780404688222, 0.5442097809326024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 150}], {
             RGBColor[
             0.9475427884309859, 0.8298940012964792, 0.5491295264859543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 156}], {
             RGBColor[
             0.691083843191671, 0.7526411268737674, 0.9001295183811735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 167}], {
             RGBColor[
             0.947679092916505, 0.830434403160785, 0.5492392002744804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 179}], {
             RGBColor[
             0.7552164634617963, 0.8063041539020928, 0.9047369408488604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 205}], {
             RGBColor[
             0.6800179376878698, 0.7430563957149572, 0.8994244086676673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 237}], {
             RGBColor[
             0.879275163275352, 0.4588842161406994, 0.3990636907380568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 256}], {
             RGBColor[
             0.8745107904220526, 0.4222631586287432, 0.39450132191314774`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 269}], {
             RGBColor[
             0.980420530285405, 0.9551564158081671, 0.6020762664235486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 277}], {
             RGBColor[
             0.9903436750031767, 0.9883158760637997, 0.6672952315344995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 282}], {
             RGBColor[
             0.7141541547436409, 0.7726234711925095, 0.9015995382329896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 293}], {
             RGBColor[
             0.9437174645743351, 0.8134407929799102, 0.5459850021177625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 98}], {
             RGBColor[
             0.18977923539730202`, 0.3168003874740297, 0.9341190187514328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 126}], {
             RGBColor[
             0.2119973945219809, 0.3401530814267192, 0.9353843100447624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 153}], {
             RGBColor[
             0.21078779737820008`, 0.338881718135717, 0.9353154252768627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 157}], {
             RGBColor[
             0.19152225944429985`, 0.31863241626153205`, 0.9342182813923363]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 171}], {
             RGBColor[
             0.189827260881899, 0.31685086530333273`, 0.9341217537317332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 184}], {
             RGBColor[
             0.1959981041281816, 0.3233368128092353, 0.9344731741256647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 222}], {
             RGBColor[
             0.210965999406103, 0.33906901976570414`, 0.9353255736187255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 248}], {
             RGBColor[
             0.21123257741316134`, 0.3393492101531443, 0.9353407548418606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 275}], {
             RGBColor[
             0.19034059746125545`, 0.31739041459565537`, 0.9341509874905143]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 285}], {
             RGBColor[
             0.20009304762604624`, 0.3276408580599046, 0.934706375099942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 38}], {
             RGBColor[
             0.18490621443215238`, 0.31167853347228314`, 0.9338415074164561]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 52}], {
             RGBColor[
             0.1912130018306219, 0.3183073669014913, 0.934200669628743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 53}], {
             RGBColor[
             0.1997851700209307, 0.32731725917636056`, 0.9346888419257947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 57}], {
             RGBColor[
             0.18168430472921848`, 0.3082921020936258, 0.9336580244252622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 84}], {
             RGBColor[
             0.1855804331499768, 0.3123871800926523, 0.9338799031750189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 124}], {
             RGBColor[
             0.1848087064384265, 0.3115760463885134, 0.9338359544804635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 147}], {
             RGBColor[
             0.19854534996450335`, 0.32601412968792354`, 0.9346182360077306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 217}], {
             RGBColor[
             0.1918655955426979, 0.3189932842697143, 0.9342378338752199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 223}], {
             RGBColor[
             0.1825916590093845, 0.3092457889716643, 0.9337096969092074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 247}], {
             RGBColor[
             0.1907246807083084, 0.31779411044059236`, 0.9341728604632337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 270}], {
             RGBColor[
             0.19826604624820576`, 0.32572056377321634`, 0.9346023300742803]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 295}], {
             RGBColor[
             0.19030787854135572`, 0.3173560249363414, 0.9341491241964293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 102}], {
             RGBColor[
             0.19929440110633984`, 0.32680142993057915`, 0.9346608933621363]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 129}], {
             RGBColor[
             0.19774057513237292`, 0.32516826031368307`, 0.9345724052715985]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 165}], {
             RGBColor[
             0.2120938524489715, 0.3402544648237721, 0.9353898031810077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 175}], {
             RGBColor[
             0.19450102624862847`, 0.3217632890376051, 0.9343879177551523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 183}], {
             RGBColor[
             0.19956688605797046`, 0.32708782889128674`, 0.9346764109770263]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 224}], {
             RGBColor[
             0.20753059097457632`, 0.33545818768669444`, 0.9351299321907813]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 253}], {
             RGBColor[
             0.19912169776175326`, 0.3266199077653942, 0.9346510581621539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 262}], {
             RGBColor[
             0.25511664496274467`, 0.3854741475583434, 0.9378398875681493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 41}], {
             RGBColor[
             0.18496389091314852`, 0.31173915511071026`, 0.9338447920067241]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 55}], {
             RGBColor[
             0.19173502245287335`, 0.3188560436734967, 0.9342303979309199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 152}], {
             RGBColor[
             0.18192632080115292`, 0.3085464763299341, 0.9336718068825283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 208}], {
             RGBColor[
             0.1853248284213402, 0.31211852331657947`, 0.9338653468638564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 242}], {
             RGBColor[
             0.18110760662426995`, 0.30768595582055314`, 0.9336251823213337]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 250}], {
             RGBColor[
             0.18199349180428678`, 0.3086170773131154, 0.9336756321717861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 268}], {
             RGBColor[
             0.19319132437376368`, 0.32038670932722724`, 0.934313332170909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 41}], {
             RGBColor[
             0.20758147265742513`, 0.3355116675614536, 0.9351328298273469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 44}], {
             RGBColor[
             0.27139379762507876`, 0.4018915080789134, 0.9387921467246012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 55}], {
             RGBColor[
             0.21435260419714997`, 0.34262855612424004`, 0.9355184357515427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 61}], {
             RGBColor[
             0.25191376002181387`, 0.38210771241079083`, 0.937657488009007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 71}], {
             RGBColor[
             0.22494256325409756`, 0.3537592745352769, 0.9361215182533955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 108}], {
             RGBColor[
             0.23362687386015235`, 0.362887035599335, 0.936616076895124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 136}], {
             RGBColor[
             0.309591888135542, 0.4349767741872242, 0.9412260952746828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 152}], {
             RGBColor[
             0.20454390254542953`, 0.33231898878067745`, 0.9349598447031511]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 161}], {
             RGBColor[
             0.21411146518921928`, 0.3423751037378088, 0.9355047032417743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 177}], {
             RGBColor[
             0.2592700003340752, 0.38983958739155206`, 0.9380764150122078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 208}], {
             RGBColor[
             0.20794241016561682`, 0.3358910357673228, 0.9351533846844792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 252}], {
             RGBColor[
             0.23225528127463596`, 0.3614454048279645, 0.9365379667264683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 268}], {
             RGBColor[
             0.21580890611804032`, 0.3441592217779706, 0.9356013699915318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 279}], {
             RGBColor[
             0.23161750381713786`, 0.36077506028270767`, 0.936501646243771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 280}], {
             RGBColor[
             0.2442905970349878, 0.3740952847751871, 0.9372233601543662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 52}], {
             RGBColor[
             0.19242626978916738`, 0.3195825884515542, 0.934269763444113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 53}], {
             RGBColor[
             0.2009984379794762, 0.32859248072642344`, 0.9347579357411648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 57}], {
             RGBColor[
             0.18289757268776397`, 0.30956732364368866`, 0.9337271182406324]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 88}], {
             RGBColor[
             0.20448897001762012`, 0.33226125121102634`, 0.9349567163769577]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 124}], {
             RGBColor[
             0.186021974396972, 0.31285126793857626`, 0.9339050482958335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 147}], {
             RGBColor[
             0.1997586179230488, 0.3272893512379864, 0.9346873298231007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 247}], {
             RGBColor[
             0.19193794866685385`, 0.31906933199065524`, 0.9342419542786038]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 289}], {
             RGBColor[
             0.21478203632197956`, 0.34307991651500525`, 0.935542891275764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 64}], {
             RGBColor[
             0.2185143800083959, 0.3470028463736865, 0.9357554427271977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 69}], {
             RGBColor[
             0.20464654155210055`, 0.3324268688843776, 0.9349656898427401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 76}], {
             RGBColor[
             0.26432098730221126`, 0.39346839209165385`, 0.9384255780434674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 85}], {
             RGBColor[
             0.21693635514660192`, 0.345344242191386, 0.9356655765457971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 90}], {
             RGBColor[
             0.20870014958760652`, 0.3366874679432882, 0.9351965368235865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 118}], {
             RGBColor[
             0.19522260799965463`, 0.322521717208859, 0.9344290107683887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 126}], {
             RGBColor[
             0.21260629074350712`, 0.3407930699617935, 0.9354189857837971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 153}], {
             RGBColor[
             0.2113966935997263, 0.3395217066707913, 0.9353501010158973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 166}], {
             RGBColor[
             0.19390930592620187`, 0.3211413534614994, 0.9343542201581618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 195}], {
             RGBColor[
             0.1927241486561343, 0.3198956780273474, 0.9342867272049146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 234}], {
             RGBColor[
             0.19793969225016772`, 0.3253775450292399, 0.9345837446968894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 239}], {
             RGBColor[
             0.2196501555680895, 0.3481966184992542, 0.9358201234650929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 248}], {
             RGBColor[
             0.21184147363468755`, 0.3399891986882186, 0.9353754305808952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 263}], {
             RGBColor[
             0.2058067463664483, 0.333646317705491, 0.935031761790548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 285}], {
             RGBColor[
             0.20070194384757245`, 0.3282808465949789, 0.9347410508389766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 42}], {
             RGBColor[
             0.7881477040684427, 0.44575263857904807`, 0.445649103589277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 66}], {
             RGBColor[
             0.5377876957046065, 0.6331026822689709, 0.9577491794160538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 81}], {
             RGBColor[
             0.7893492688527326, 0.6740607768287987, 0.5995695817860118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 86}], {
             RGBColor[
             0.6417053553097174, 0.7192862820416126, 0.9654274840700409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 94}], {
             RGBColor[
             0.7430612286953848, 0.7992043464221197, 0.9750250570405241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 97}], {
             RGBColor[
             0.5690459020341019, 0.6601769695084484, 0.9597409246828227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 120}], {
             RGBColor[
             0.4841619759818365, 0.5839129078583203, 0.9544325893141365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 130}], {
             RGBColor[
             0.8005184128051482, 0.7225949328330918, 0.608776500228449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 140}], {
             RGBColor[
             0.7746238811196319, 0.3418026092174846, 0.43269867546052243`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 162}], {
             RGBColor[
             0.8402909601650888, 0.8739220660440041, 0.881352498558146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 169}], {
             RGBColor[
             0.6469863029423364, 0.7235735932337524, 0.9658432196124291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 178}], {
             RGBColor[
             0.4741224882012588, 0.573360769660643, 0.953860855337124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 182}], {
             RGBColor[
             0.47178862651241965`, 0.5709077330502953, 0.9537279453665835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 201}], {
             RGBColor[
             0.7933206093756301, 0.4855138555516503, 0.4506026835534007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 202}], {
             RGBColor[
             0.8074583715423828, 0.5770584081231883, 0.4634704687762633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 55}], {
             RGBColor[
             0.19536579579315563`, 0.32267221665845913`, 0.9344371651014012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 108}], {
             RGBColor[
             0.21464006545615802`, 0.34293069613355404`, 0.9355348062449824]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 152}], {
             RGBColor[
             0.1855570941414352, 0.31236264931489655`, 0.9338785740530094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 208}], {
             RGBColor[
             0.1889556017616225, 0.3159346963015419, 0.9340721140343375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 219}], {
             RGBColor[
             0.18646440411145038`, 0.3133162896201571, 0.933930244013557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 242}], {
             RGBColor[
             0.18473837996455222`, 0.31150212880551553`, 0.933831949491815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.18562426514456906`, 0.3124332502980778, 0.9338823993422674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 252}], {
             RGBColor[
             0.21326847287064163`, 0.3414890653621836, 0.9354566960763266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 268}], {
             RGBColor[
             0.19682209771404596`, 0.32420288231218963`, 0.9345200993413902]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 80}], {
             RGBColor[
             0.8846726257638872, 0.5067606717091464, 0.24648746073419803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 81}], {
             RGBColor[
             0.8548914543976673, 0.39035727136327797`, 0.1989221405255734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 82}], {
             RGBColor[
             0.7628830394364272, 0.4257203521722454, 0.4433328823923026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 87}], {
             RGBColor[
             0.8894525062895627, 0.5226189282859114, 0.2876243328405072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 130}], {
             RGBColor[
             0.8623375503659444, 0.42271337536614007`, 0.20506008615386487`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 140}], {
             RGBColor[
             0.8308428229488108, 0.23807702936156347`, 0.1771684281287546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 145}], {
             RGBColor[
             0.8467044438902113, 0.49173965579450474`, 0.4514212603342903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 162}], {
             RGBColor[
             0.8888525819392381, 0.5235981308400817, 0.3867774183736629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 167}], {
             RGBColor[
             0.8609638306693929, 0.4172670345342654, 0.20395475904067392`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 181}], {
             RGBColor[
             0.8871678109624904, 0.5151775172813806, 0.25618078405458466`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 201}], {
             RGBColor[
             0.84019118707681, 0.30993265252864627`, 0.18612043217519372`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 202}], {
             RGBColor[
             0.8472600681601863, 0.3557049288144153, 0.19255432478662504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 203}], {
             RGBColor[
             0.8707781869031039, 0.5109108883536715, 0.45286742761557874`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 216}], {
             RGBColor[
             0.847224395566658, 0.3555429478987492, 0.19252455870016974`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 237}], {
             RGBColor[
             0.8334280441412762, 0.2579481722980025, 0.1796440388622492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 269}], {
             RGBColor[
             0.8827914555819929, 0.5004150429658535, 0.23917946980671936`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 293}], {
             RGBColor[
             0.8583227451079464, 0.4059379610803489, 0.20178529360286196`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 299}], {
             RGBColor[
             0.8313011225434905, 0.2415997208744344, 0.17760729633819525`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 66}], {
             RGBColor[
             0.3059641689064351, 0.4317438620573953, 0.9409982635304203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 78}], {
             RGBColor[
             0.20985899682898168`, 0.3379054898691324, 0.9352625314596219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 97}], {
             RGBColor[
             0.33722237523593046`, 0.45881814929687276`, 0.9429900087971892]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 99}], {
             RGBColor[
             0.21063039427602828`, 0.33871627749540134`, 0.9353064614030511]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 178}], {
             RGBColor[
             0.24229896140308743`, 0.37200194944906734`, 0.9371099394514903]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 182}], {
             RGBColor[
             0.23996509971424826`, 0.36954891283871966`, 0.9369770294809499]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 199}], {
             RGBColor[
             0.21199067610024028`, 0.34014601993949717`, 0.9353839274405833]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 215}], {
             RGBColor[
             0.22516415254335911`, 0.35399217892786317`, 0.9361341374356069]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 229}], {
             RGBColor[
             0.221649468641255, 0.3502980233029215, 0.935933981386891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 233}], {
             RGBColor[
             0.2154911007768475, 0.3438251882143545, 0.9355832714475019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 259}], {
             RGBColor[
             0.20537394232393572`, 0.33319141321544904`, 0.9350071142406031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 261}], {
             RGBColor[
             0.23516151692935008`, 0.3645000427670523, 0.9367034725476139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 284}], {
             RGBColor[
             0.23327215251581435`, 0.3625142009758035, 0.9365958760393271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 59}], {
             RGBColor[
             0.650613500039462, 0.7181916581041776, 0.9197475834219577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 61}], {
             RGBColor[
             0.29673927658547317`, 0.4285312134624696, 0.9402355342561197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 71}], {
             RGBColor[
             0.26976807981775686`, 0.40018277558695564`, 0.9386995645005083]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 108}], {
             RGBColor[
             0.27845239042381165`, 0.4093105366510138, 0.9391941231422369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 136}], {
             RGBColor[
             0.3544174046992013, 0.48140027523890294`, 0.9438041415217957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 177}], {
             RGBColor[
             0.3040955168977345, 0.4362630884432308, 0.9406544612593207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 194}], {
             RGBColor[
             0.5011124283287507, 0.6014735099165995, 0.9553542362124354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 204}], {
             RGBColor[
             0.39991382818369614`, 0.5199845367377941, 0.9469303798325985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 226}], {
             RGBColor[
             0.6512382253914439, 0.7184499980919314, 0.9093942676022314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 252}], {
             RGBColor[
             0.27708079783829526`, 0.4078689058796433, 0.9391160129735812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 268}], {
             RGBColor[
             0.2606344226816996, 0.39058272282964934`, 0.9381794162386446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 279}], {
             RGBColor[
             0.27644302038079716`, 0.4071985613343865, 0.9390796924908837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 280}], {
             RGBColor[
             0.2891161135986471, 0.42051878582686586`, 0.939801406401479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 283}], {
             RGBColor[
             0.3110200455084933, 0.44354120705361005`, 0.9410488029197814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 89}], {
             RGBColor[
             0.34033954683031736`, 0.4683920819989782, 0.9429369415722573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 94}], {
             RGBColor[
             0.5484117816822776, 0.636917841037437, 0.9603911500045271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 96}], {
             RGBColor[
             0.2504426073839444, 0.3805614377119254, 0.9375737080426556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 120}], {
             RGBColor[
             0.2895125289687292, 0.4216264024736376, 0.9397986822781397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 131}], {
             RGBColor[
             0.2646712879230951, 0.39551668310902466`, 0.9383840103499137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 132}], {
             RGBColor[
             0.24841553022607393`, 0.3784308510948885, 0.9374582689973068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 141}], {
             RGBColor[
             0.2968912603514489, 0.4293819169954668, 0.9402188901145307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 146}], {
             RGBColor[
             0.24998188699294738`, 0.3800771913696276, 0.937547470697963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 188}], {
             RGBColor[
             0.32789958178650086`, 0.45761720952884744`, 0.9421442779998944]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 236}], {
             RGBColor[
             0.26568284234196243`, 0.3965798909395088, 0.9384416168776075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 260}], {
             RGBColor[
             0.2790511539192304, 0.41063083400712647`, 0.9392029224452882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 281}], {
             RGBColor[
             0.6391981620742301, 0.7080190375817033, 0.9308676637061029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 294}], {
             RGBColor[
             0.4179920843483252, 0.5334044550653643, 0.9485055663485399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 60}], {
             RGBColor[
             0.2459880706675731, 0.3758794371890788, 0.9373200287665547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 62}], {
             RGBColor[
             0.20319287451419632`, 0.3308989726597267, 0.9348829056554392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 117}], {
             RGBColor[
             0.1951092767006187, 0.3224025988279529, 0.9344225567185672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 158}], {
             RGBColor[
             0.1988271914603046, 0.32631036296979365`, 0.9346342864639694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 196}], {
             RGBColor[
             0.2038842250820344, 0.33162562594068223`, 0.9349222770475161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 207}], {
             RGBColor[
             0.1949982416588687, 0.3222858939590454, 0.9344162334372013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 212}], {
             RGBColor[
             0.21903868251240277`, 0.34755392154809645`, 0.9357853009791648]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 214}], {
             RGBColor[
             0.20276955741382008`, 0.3304540395473769, 0.9348587983728143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 225}], {
             RGBColor[
             0.21615267984960895`, 0.3445205497663627, 0.935620947396977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 265}], {
             RGBColor[
             0.21371228475052867`, 0.3419555397872433, 0.9354819705063254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 276}], {
             RGBColor[
             0.22304128842203616`, 0.35176091413899346`, 0.9360132434643936]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.19252503662856937`, 0.3196863986619449, 0.9342753880695046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 112}], {
             RGBColor[
             0.18666547155784385`, 0.31352762425472913`, 0.9339416945071765]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 131}], {
             RGBColor[
             0.20675371716772, 0.33464164405904423`, 0.9350856903767627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 133}], {
             RGBColor[
             0.18469446291568115`, 0.3114559692026503, 0.9338294484808514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 146}], {
             RGBColor[
             0.19206431623757236`, 0.3192021523196471, 0.9342491507248121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 170}], {
             RGBColor[
             0.1908380369178425, 0.3179132550040116, 0.9341793159316711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 190}], {
             RGBColor[
             0.1942570496898653, 0.32150685420533776`, 0.9343740236510617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.18784627824446665`, 0.31476872694983776`, 0.9340089397011326]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 70}], {
             RGBColor[
             0.2012898575043234, 0.328898781124103, 0.9347745316519882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 71}], {
             RGBColor[
             0.2080633650262977, 0.3360181669948795, 0.9351602728848583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 73}], {
             RGBColor[
             0.187739347830093, 0.31465633630455114`, 0.9340028501722235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 100}], {
             RGBColor[
             0.18673636136840888`, 0.31360213394030656`, 0.9339457315770161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 119}], {
             RGBColor[
             0.1868307341329213, 0.31370132569938797`, 0.933951105966343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 122}], {
             RGBColor[
             0.1889251216320018, 0.3159026597527588, 0.9340703782360471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 138}], {
             RGBColor[
             0.21204884540564534`, 0.34020715956762493`, 0.9353872400964722]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 161}], {
             RGBColor[
             0.19723226696141938`, 0.3246339961974114, 0.9345434578732372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 244}], {
             RGBColor[
             0.19115682833937214`, 0.31824832500058275`, 0.9341974706315176]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 266}], {
             RGBColor[
             0.19547981769013628`, 0.32279206090159157`, 0.934443658479754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 54}], {
             RGBColor[
             0.22682934694082163`, 0.355742403819019, 0.936228967793108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 102}], {
             RGBColor[
             0.20090857647606358`, 0.32849803058878846`, 0.9347528182614836]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 143}], {
             RGBColor[
             0.2582581828615999, 0.38877610307504745`, 0.9380187935040003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 172}], {
             RGBColor[
             0.20010293929950806`, 0.3276512548358813, 0.9347069384161122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 174}], {
             RGBColor[
             0.22141328802375174`, 0.3500497824992095, 0.9359205312501221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 238}], {
             RGBColor[
             0.19853266531396374`, 0.3260007973159532, 0.9346175136356476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 298}], {
             RGBColor[
             0.23487979924778435`, 0.36420393962179404`, 0.9366874291424127]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 206}], {
             RGBColor[
             0.20212300857950383`, 0.32977447572894675`, 0.9348219783731833]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 219}], {
             RGBColor[
             0.1830787781409705, 0.30975778206409804`, 0.9337374376231229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 83}], {
             RGBColor[
             0.8348006374064919, 0.5233895828676642, 0.45541678825261045`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 101}], {
             RGBColor[
             0.7293123816710212, 0.7884636426315792, 0.9736547004594159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 104}], {
             RGBColor[
             0.5731922784257398, 0.6585842020957557, 0.9621993062038972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 116}], {
             RGBColor[
             0.5493242790295518, 0.6359329023080253, 0.960750884061716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 142}], {
             RGBColor[
             0.8237226416206042, 0.438239252848624, 0.4448084869772376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 149}], {
             RGBColor[
             0.8534002738604769, 0.7354497327448786, 0.6081721446101185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 197}], {
             RGBColor[
             0.8988192263028636, 0.9205652040419037, 0.9289214218265444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 198}], {
             RGBColor[
             0.8879439008384149, 0.9128115493875727, 0.9633242059952494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 204}], {
             RGBColor[
             0.647452541380158, 0.7220822556308867, 0.967158350930859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 226}], {
             RGBColor[
             0.8987769385879059, 0.920547716985024, 0.9296222387004919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 243}], {
             RGBColor[
             0.8993571244293498, 0.920787638740557, 0.9200070578349391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 254}], {
             RGBColor[
             0.5650392887707011, 0.6515224922377361, 0.9616798049124837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 283}], {
             RGBColor[
             0.5585587587049552, 0.6456389259467026, 0.9612767740180419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 53}], {
             RGBColor[
             0.2073052253779457, 0.3352213141556316, 0.9351170979534518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 57}], {
             RGBColor[
             0.18920436008623348`, 0.3161961570728968, 0.9340862804529193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 84}], {
             RGBColor[
             0.1931004885069918, 0.32029123507192336`, 0.9343081592026761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 88}], {
             RGBColor[
             0.21079575741608964`, 0.3388900846402345, 0.9353158785892447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 93}], {
             RGBColor[
             0.21993156031517644`, 0.348492392730534, 0.9358361490491385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 124}], {
             RGBColor[
             0.1923287617954415, 0.3194801013677844, 0.9342642105081206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 137}], {
             RGBColor[
             0.23013360981142927`, 0.35921539359839394`, 0.9364171406753703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 147}], {
             RGBColor[
             0.20606540532151835`, 0.3339181846671946, 0.9350464920353876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 217}], {
             RGBColor[
             0.19938565089971289`, 0.32689733924898534`, 0.9346660899028769]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 247}], {
             RGBColor[
             0.1982447360653234, 0.3256981654198634, 0.9346011164908907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 270}], {
             RGBColor[
             0.20578610160522076`, 0.3336246187524874, 0.9350305861019373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 271}], {
             RGBColor[
             0.21068413741610115`, 0.3387727649431298, 0.9353095219953723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 273}], {
             RGBColor[
             0.2188316043007933, 0.34733626921817795`, 0.9357735081813584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 289}], {
             RGBColor[
             0.22108882372044908`, 0.3497087499442134, 0.9359020534880509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 295}], {
             RGBColor[
             0.19782793389837072`, 0.3252600799156124, 0.9345773802240863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 88}], {
             RGBColor[
             0.21936792560639845`, 0.34789997691510377`, 0.9358040508862964]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 93}], {
             RGBColor[
             0.22850372850548528`, 0.3575022850054033, 0.93632432134619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 107}], {
             RGBColor[
             0.3121763440598402, 0.43622685441542786`, 0.9414269663560839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 124}], {
             RGBColor[
             0.20090092998575032`, 0.32848999364265374`, 0.9347523828051723]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 137}], {
             RGBColor[
             0.2387057780017381, 0.36822528587326325`, 0.936905312972422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 147}], {
             RGBColor[
             0.21463757351182716`, 0.3429280769420639, 0.9355346643324394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 217}], {
             RGBColor[
             0.2079578190900217, 0.3359072315238546, 0.9351542621999286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 247}], {
             RGBColor[
             0.2068169042556322, 0.33470805769473266`, 0.9350892887879424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 251}], {
             RGBColor[
             0.25074234215186236`, 0.3808764779572891, 0.9375907774942707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 270}], {
             RGBColor[
             0.21435826979552958`, 0.3426345110273567, 0.935518758398989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 271}], {
             RGBColor[
             0.21925630560640996`, 0.3477826572179991, 0.935797694292424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 273}], {
             RGBColor[
             0.2274037724911021, 0.35634616149304726`, 0.9362616804784101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 289}], {
             RGBColor[
             0.22966099191075792`, 0.3587186422190827, 0.9363902257851027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 75}], {
             RGBColor[
             0.2884831291269512, 0.41830852004459096`, 0.9398219273882558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 102}], {
             RGBColor[
             0.218116116310074, 0.34658424597537324`, 0.9357327621987566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 111}], {
             RGBColor[
             0.4291203016109882, 0.5357529458181629, 0.9499902123364491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 143}], {
             RGBColor[
             0.2754657226956103, 0.40686231846163223`, 0.9389987374412732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 163}], {
             RGBColor[
             0.4325936369919836, 0.5385727559524309, 0.9502636460208878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 165}], {
             RGBColor[
             0.2309155676527057, 0.3600372808685661, 0.936461672017628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 172}], {
             RGBColor[
             0.21731047913351847`, 0.34573747022246615`, 0.935686882353385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 174}], {
             RGBColor[
             0.23862082785776215`, 0.3681359978857943, 0.936900475187395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 185}], {
             RGBColor[
             0.3867966632124244, 0.5013927095080272, 0.9466583404851183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 235}], {
             RGBColor[
             0.32626536687632174`, 0.4510335953926109, 0.9422293781681247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 238}], {
             RGBColor[
             0.21574020514797415`, 0.344087012702538, 0.9355974575729206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 298}], {
             RGBColor[
             0.25208733908179476`, 0.3822901550083788, 0.9376673730796856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 108}], {
             RGBColor[
             0.22141119699588285`, 0.35004758469634045`, 0.9359204121691784]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 114}], {
             RGBColor[
             0.22063449464495144`, 0.3492312212797382, 0.9358761801193209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 208}], {
             RGBColor[
             0.19572673330134732`, 0.32305158486432833`, 0.9344577199585336]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 219}], {
             RGBColor[
             0.19323553565117518`, 0.3204331781829436, 0.9343158499377529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 242}], {
             RGBColor[
             0.19150951150427703`, 0.318619017368302, 0.9342175554160109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 250}], {
             RGBColor[
             0.1923953966842939, 0.31955013886086425`, 0.9342680052664631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 252}], {
             RGBColor[
             0.22003960441036646`, 0.34860595392497, 0.9358423020005227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 268}], {
             RGBColor[
             0.20359322925377082`, 0.3313197708749761, 0.9349057052655861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 283}], {
             RGBColor[
             0.25397885208056453`, 0.38427825509893676`, 0.9377750919467229]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 57}], {
             RGBColor[
             0.18951617750640207`, 0.3165238969518603, 0.9341040379937053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 84}], {
             RGBColor[
             0.1934123059271604, 0.32061897495088687`, 0.9343259167434621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 110}], {
             RGBColor[
             0.1926369557700678, 0.31980403277574326`, 0.9342817616990433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 148}], {
             RGBColor[
             0.2228269723814797, 0.3515356543919468, 0.936001038482936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 191}], {
             RGBColor[
             0.21336670196225918`, 0.34159231036555776`, 0.9354622900777774]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 217}], {
             RGBColor[
             0.19969746831988144`, 0.32722507912794885`, 0.934683847443663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 223}], {
             RGBColor[
             0.19042353178656807`, 0.3174775838298989, 0.9341557104776503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 246}], {
             RGBColor[
             0.1919032518459413, 0.3190328634319706, 0.934239978345982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 247}], {
             RGBColor[
             0.19855655348549195`, 0.3260259052988269, 0.9346188740316768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 251}], {
             RGBColor[
             0.2424819913817221, 0.3721943255613833, 0.9371203627380049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 270}], {
             RGBColor[
             0.20609791902538932`, 0.3339523586314509, 0.9350483436427234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 271}], {
             RGBColor[
             0.21099595483626973`, 0.3391005048220933, 0.9353272795361584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 278}], {
             RGBColor[
             0.1999933373080916, 0.327536056193735, 0.9347006967448426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 295}], {
             RGBColor[
             0.19813975131853928`, 0.3255878197945759, 0.9345951377648724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.18357179140558838`, 0.31027597026405784`, 0.9337655139991952]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 217}], {
             RGBColor[
             0.18985695379830947`, 0.3168820744411198, 0.9341234446993961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 223}], {
             RGBColor[
             0.1805830172649961, 0.30713457914306985`, 0.9335953077333836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 247}], {
             RGBColor[
             0.18871603896391997`, 0.3156829006119979, 0.9340584712874099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 278}], {
             RGBColor[
             0.19015282278651957`, 0.31719305150690597`, 0.9341402940005757]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 295}], {
             RGBColor[
             0.1882992367969673, 0.3152448151077469, 0.9340347350206055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 134}], {
             RGBColor[
             0.21796998739019388`, 0.34643065521547056`, 0.9357244403729478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 160}], {
             RGBColor[
             0.19345266111115197`, 0.32066139080792844`, 0.9343282149114902]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 164}], {
             RGBColor[
             0.1865510290497441, 0.3134073379226422, 0.9339351771756428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 176}], {
             RGBColor[
             0.19266677740688082`, 0.31983537720683475`, 0.9342834599971428]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 180}], {
             RGBColor[
             0.1930127612329003, 0.32019902814462275`, 0.9343031632641974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 187}], {
             RGBColor[
             0.20794054512620663`, 0.3358890754926524, 0.9351532784732439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 215}], {
             RGBColor[
             0.20794131603506694`, 0.33588988576674306`, 0.935153322375363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 221}], {
             RGBColor[
             0.18866826221874242`, 0.3156326842235957, 0.9340557504724514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 230}], {
             RGBColor[
             0.19161321755920613`, 0.31872801900737613`, 0.9342234613224198]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[
             0.20819170713916685`, 0.33615306269286493`, 0.9351675817783212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 288}], {
             RGBColor[
             0.200003126765576, 0.32754634553423856`, 0.9347012542399642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 296}], {
             RGBColor[
             0.18917402722894824`, 0.3161642753166758, 0.9340845530415703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 297}], {
             RGBColor[
             0.19156703343003767`, 0.3186794765593771, 0.934220831204587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 72}], {
             RGBColor[
             0.8812795328447734, 0.4807598783541659, 0.416576044780737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 83}], {
             RGBColor[
             0.8927042858426667, 0.5685755362546596, 0.4275164011539326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 106}], {
             RGBColor[
             0.9234341463667425, 0.9403782883321993, 0.9424056010083017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 136}], {
             RGBColor[
             0.6888115905499252, 0.7512769242124885, 0.9221815319720392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 155}], {
             RGBColor[
             0.9556607617329471, 0.8668171290315656, 0.5788467809151635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[
             0.8355066141794747, 0.8713501588901851, 0.9337316266626792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 197}], {
             RGBColor[
             0.9856746989571257, 0.9883441341223966, 0.8870708411785275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 198}], {
             RGBColor[
             0.974799373492677, 0.9805904794680657, 0.9214736253472325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 210}], {
             RGBColor[
             0.7283433684413259, 0.785018817714684, 0.9248382115325371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 226}], {
             RGBColor[
             0.9856324112421679, 0.988326647065517, 0.887771658052475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 227}], {
             RGBColor[
             0.9688560866723765, 0.9191321953350291, 0.5894640490955131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 241}], {
             RGBColor[
             0.9855659463819599, 0.9882991621377519, 0.8888731527916648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 290}], {
             RGBColor[
             0.9657093115675036, 0.9066562806448499, 0.5869320799818273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 291}], {
             RGBColor[
             0.955941254786202, 0.9662985742039245, 0.945506158028788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 77}], {
             RGBColor[
             0.3505250523811867, 0.47604307306451876`, 0.9436288356859599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 95}], {
             RGBColor[
             0.28741190007160666`, 0.4194185083151971, 0.9396790545700505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 103}], {
             RGBColor[
             0.35429852491084235`, 0.47931146530946245`, 0.9438692780187988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 127}], {
             RGBColor[
             0.3180513290021859, 0.44791596605042294`, 0.941559638747636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 145}], {
             RGBColor[
             0.5760856373176906, 0.6571907606456139, 0.9633236613969889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 148}], {
             RGBColor[
             0.2667823322730826, 0.39773552456880407`, 0.9385042312026353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 159}], {
             RGBColor[
             0.28925410608148494`, 0.42135478363418655`, 0.9397839654770135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 168}], {
             RGBColor[
             0.3438394161380286, 0.4702523109805432, 0.9432028328564219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 196}], {
             RGBColor[
             0.24516356622564123`, 0.3750128307440074, 0.9372730744583317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 205}], {
             RGBColor[
             0.3298135622578278, 0.45810382130942706`, 0.9423091178497511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 212}], {
             RGBColor[
             0.2603180236560096, 0.39094112635142153`, 0.9381360983899805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 225}], {
             RGBColor[
             0.25743202099321577`, 0.38790775456968785`, 0.9379717448077927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 265}], {
             RGBColor[
             0.2549916258941355, 0.3853427445905684, 0.9378327679171411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 276}], {
             RGBColor[
             0.26432062956564295`, 0.39514811894231855`, 0.9383640408752093]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 282}], {
             RGBColor[
             0.36394977931359895`, 0.4876708967869795, 0.9444842474150733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 71}], {
             RGBColor[
             0.25028804221449197`, 0.3803989799188331, 0.9375649057849139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 108}], {
             RGBColor[
             0.25897235282054676`, 0.38952674098289125`, 0.9380594644266425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 136}], {
             RGBColor[
             0.33493736709593636`, 0.46161647957078045`, 0.9426694828062012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 161}], {
             RGBColor[
             0.23945694414961366`, 0.369014809121365, 0.9369480907732928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 177}], {
             RGBColor[
             0.2846154792944696, 0.4164792927751083, 0.9395198025437264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 194}], {
             RGBColor[
             0.4816323907254858, 0.581689714248477, 0.9542195774968412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 252}], {
             RGBColor[
             0.2576007602350303, 0.3880851102115208, 0.9379813542579867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 268}], {
             RGBColor[
             0.24115438507843467`, 0.37079892716152685`, 0.9370447575230503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 279}], {
             RGBColor[
             0.25696298277753227`, 0.387414765666264, 0.9379450337752894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 280}], {
             RGBColor[
             0.2696360759953822, 0.40073499015874336`, 0.9386667476858847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 117}], {
             RGBColor[
             0.1935934216908487, 0.32080933910192594`, 0.9343362310182673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 135}], {
             RGBColor[
             0.20737676424851148`, 0.33529650604442257`, 0.9351211719862982]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 158}], {
             RGBColor[
             0.1973113364505346, 0.3247171032437667, 0.9345479607636695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 186}], {
             RGBColor[
             0.19739650616034748`, 0.3248066220088515, 0.934552811052646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 196}], {
             RGBColor[
             0.2023683700722644, 0.33003236621465526`, 0.9348359513472162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 207}], {
             RGBColor[
             0.19348238664909873`, 0.3206926342330184, 0.9343299077369014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 212}], {
             RGBColor[
             0.2175228275026328, 0.34596066182206947`, 0.9356989752788649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 214}], {
             RGBColor[
             0.20125370240405008`, 0.3288607798213499, 0.9347724726725144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 225}], {
             RGBColor[
             0.21463682483983898`, 0.34292729004033573`, 0.9355346216966771]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 265}], {
             RGBColor[
             0.2121964297407587, 0.3403622800612163, 0.9353956448060256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 276}], {
             RGBColor[
             0.22152543341226616`, 0.3501676544129665, 0.9359269177640938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 286}], {
             RGBColor[
             0.21128388043674812`, 0.3394031328837336, 0.935343676473158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 71}], {
             RGBColor[
             0.20309975866494467`, 0.3308011019982774, 0.9348776028455769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 73}], {
             RGBColor[
             0.18277574146873998`, 0.309439271307949, 0.933720180132942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 152}], {
             RGBColor[
             0.18270109795627662`, 0.30936081624367795`, 0.9337159292953324]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 161}], {
             RGBColor[
             0.19226866060006637`, 0.3194169312008093, 0.9342607878339557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 208}], {
             RGBColor[
             0.1860996055764639, 0.3129328632303233, 0.9339094692766605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 244}], {
             RGBColor[
             0.18619322197801913`, 0.31303126000398057`, 0.9339148005922362]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 69}], {
             RGBColor[
             0.22143670136219934`, 0.3500743914024093, 0.9359218646051097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 76}], {
             RGBColor[
             0.28111114711231006`, 0.41111591460968555`, 0.939381752805837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 85}], {
             RGBColor[
             0.2337265149567007, 0.3629917647094177, 0.9366217513081667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 90}], {
             RGBColor[
             0.22549030939770529`, 0.3543349904613199, 0.936152711585956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 118}], {
             RGBColor[
             0.2120127678097534, 0.3401692397268907, 0.9353851855307582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 121}], {
             RGBColor[
             0.2303769927354159, 0.3594712044828725, 0.9364310009728385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 173}], {
             RGBColor[
             0.21829574180286104`, 0.34677304375720647`, 0.9357429916048386]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 213}], {
             RGBColor[
             0.21883980227157213`, 0.34734488580524786`, 0.9357739750436664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 234}], {
             RGBColor[
             0.2147298520602665, 0.3430250675472716, 0.9355399194592591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 239}], {
             RGBColor[
             0.23644031537818827`, 0.3658441410172859, 0.9367762982274624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 249}], {
             RGBColor[
             0.22138061658703678`, 0.35001544274773333`, 0.9359186706601341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 258}], {
             RGBColor[
             0.28773302970917036`, 0.41685145648958927`, 0.939803693309408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 263}], {
             RGBColor[
             0.22259690617654707`, 0.3512938402235227, 0.9359879365529176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 286}], {
             RGBColor[
             0.22809764059378232`, 0.35707546086274283`, 0.9363011952403719]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 70}], {
             RGBColor[
             0.2936166091660087, 0.41958665894484415`, 0.940265032379005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 106}], {
             RGBColor[
             0.6196619973862446, 0.6970249085872788, 0.9659794196694249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 115}], {
             RGBColor[
             0.3645960621661024, 0.4902165167425332, 0.9444527165749532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 138}], {
             RGBColor[
             0.30437559706733064`, 0.4308950373883661, 0.9408777408234891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 155}], {
             RGBColor[
             0.6518886127524492, 0.6234637492866453, 0.6024205995762867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 194}], {
             RGBColor[
             0.5317344651989768, 0.6279967791452647, 0.9573054453238024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 200}], {
             RGBColor[
             0.37151685139917806`, 0.49621095652724223`, 0.9448937031450712]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[
             0.424571219460828, 0.5416654379697635, 0.9484120301936603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 211}], {
             RGBColor[
             0.3240980577045407, 0.45162459399430244`, 0.9420009057800123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 231}], {
             RGBColor[
             0.30432205873480145`, 0.4308387652063516, 0.9408746918946544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 241}], {
             RGBColor[
             0.6817937974014621, 0.7449457823928316, 0.912446971452788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 264}], {
             RGBColor[
             0.33683666992223255`, 0.4650136831097602, 0.942726350900722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 291}], {
             RGBColor[
             0.6521691058057041, 0.7229451944590042, 0.9690799766899112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 86}], {
             RGBColor[
             0.49025940765542825`, 0.5952351366581299, 0.9535166371045274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 97}], {
             RGBColor[
             0.4175999543798127, 0.5361258241249656, 0.9478300777173092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 162}], {
             RGBColor[
             0.6888450125107997, 0.7498709206605213, 0.8694416515926326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 169}], {
             RGBColor[
             0.4955403552880472, 0.5995224478502696, 0.9539323726469158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 187}], {
             RGBColor[
             0.305540960778381, 0.4312990434818653, 0.9409741624536079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 193}], {
             RGBColor[
             0.33295274750258996`, 0.46011056933666983`, 0.9425352231554471]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 215}], {
             RGBColor[
             0.3055417316872413, 0.4312998537559559, 0.940974206355727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 228}], {
             RGBColor[
             0.40629940527691566`, 0.5263378564741489, 0.9471100167211559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 118}], {
             RGBColor[
             0.18382399790050605`, 0.31054105528103165`, 0.9337798767859746]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 166}], {
             RGBColor[
             0.1825106958270533, 0.309160691533672, 0.9337050861757479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 173}], {
             RGBColor[
             0.1901069718936137, 0.3171448593113474, 0.934137682860055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 195}], {
             RGBColor[
             0.18132553855698572`, 0.30791501609952, 0.9336375932225005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 213}], {
             RGBColor[
             0.19065103236232478`, 0.3177167013593888, 0.9341686662988828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 234}], {
             RGBColor[
             0.18654108215101917`, 0.31339688310141245`, 0.9339346107144755]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 263}], {
             RGBColor[
             0.19440813626729972`, 0.3216656557776636, 0.934382627808134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 75}], {
             RGBColor[
             0.6048929892039929, 0.6837170469414527, 0.9652757515328931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 83}], {
             RGBColor[
             0.8566539261889098, 0.5407679915618476, 0.4575135965364173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 109}], {
             RGBColor[
             0.9348338843673183, 0.947970458954174, 0.8784588716115629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 111}], {
             RGBColor[
             0.7455301616880299, 0.8011614727150247, 0.9754440364810864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 143}], {
             RGBColor[
             0.5918755827726521, 0.672270845358494, 0.9644525615859105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 163}], {
             RGBColor[
             0.7490034970690254, 0.8039812828492927, 0.9757174701655251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 185}], {
             RGBColor[
             0.7032065232894661, 0.766801236404889, 0.9721121646297556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 218}], {
             RGBColor[
             0.9220230883129681, 0.9398481441591451, 0.964270119789284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 235}], {
             RGBColor[
             0.6426752269533634, 0.7164421222894727, 0.967683202312762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 292}], {
             RGBColor[
             0.8252860920096456, 0.8638987146846454, 0.9830984780135097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 76}], {
             RGBColor[
             0.2672433086560147, 0.39653993712037666`, 0.9385919999213795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 85}], {
             RGBColor[
             0.21985867650040533`, 0.3484157872201088, 0.9358319984237091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 90}], {
             RGBColor[
             0.21162247094140993`, 0.33975901297201105`, 0.9353629587014987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 118}], {
             RGBColor[
             0.19814492935345804`, 0.3255932622375819, 0.9345954326463008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 121}], {
             RGBColor[
             0.21650915427912054`, 0.3448952269935637, 0.9356412480883811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 126}], {
             RGBColor[
             0.21552861209731056`, 0.34386461499051624`, 0.9355854076617092]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 166}], {
             RGBColor[
             0.19683162728000528`, 0.3242128984902222, 0.9345206420360739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 173}], {
             RGBColor[
             0.2044279033465657, 0.3321970662678976, 0.9349532387203812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 195}], {
             RGBColor[
             0.1956464700099377, 0.32296722305607023`, 0.9344531490828267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 213}], {
             RGBColor[
             0.20497196381527677`, 0.33276890831593897`, 0.934984222159209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 234}], {
             RGBColor[
             0.20086201360397116`, 0.32844909005796263`, 0.9347501665748015]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 239}], {
             RGBColor[
             0.22257247692189291`, 0.35126816352797696`, 0.935986545343005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 249}], {
             RGBColor[
             0.20751277813074143`, 0.3354394652584245, 0.9351289177756767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 258}], {
             RGBColor[
             0.273865191252875, 0.4022754790002804, 0.9390139404249507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 263}], {
             RGBColor[
             0.2087290677202517, 0.3367178627342138, 0.9351981836684602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 285}], {
             RGBColor[
             0.2036242652013759, 0.3313523916237017, 0.9349074727168887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 122}], {
             RGBColor[
             0.19740509453050553`, 0.32481564893042175`, 0.9345533001476212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 138}], {
             RGBColor[
             0.22052881830414905`, 0.3491201487452879, 0.9358701620080464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 211}], {
             RGBColor[
             0.24025127894135917`, 0.3698497053512242, 0.9369933269645696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 231}], {
             RGBColor[
             0.2204752799716199, 0.3490638765632734, 0.9358671130792118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 266}], {
             RGBColor[
             0.20395979058864, 0.33170505007925455`, 0.934926580391328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 108}], {
             RGBColor[
             0.23200115605283045`, 0.3611783031073773, 0.936523494671031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 136}], {
             RGBColor[
             0.3079661703282201, 0.43326804169526645`, 0.9411335130505898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 161}], {
             RGBColor[
             0.2124857473818974, 0.34066637124585103`, 0.9354121210176813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 177}], {
             RGBColor[
             0.2576442825267533, 0.3881308548995943, 0.9379838327881149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 208}], {
             RGBColor[
             0.20631669235829492`, 0.33418230327536513`, 0.9350608024603861]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 244}], {
             RGBColor[
             0.20641030875985014`, 0.33428070004902233`, 0.9350661337759618]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 252}], {
             RGBColor[
             0.23062956346731406`, 0.3597366723360068, 0.9364453845023752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 268}], {
             RGBColor[
             0.21418318831071842`, 0.34245048928601285`, 0.9355087877674388]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 279}], {
             RGBColor[
             0.22999178600981598`, 0.35906632779075, 0.9364090640196779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 280}], {
             RGBColor[
             0.2426648792276659, 0.37238655228322937`, 0.9371307779302732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 83}], {
             RGBColor[
             0.8351278328210138, 0.271013492942614, 0.1812717584216026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 87}], {
             RGBColor[
             0.8839929875554634, 0.4806546749192594, 0.28239629153508916`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 106}], {
             RGBColor[
             0.8402305064958111, 0.44896653252378993`, 0.44609646287147053`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 109}], {
             RGBColor[
             0.8838806914832852, 0.4818355242979183, 0.3734681145578266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 155}], {
             RGBColor[
             0.8617149167399476, 0.39992575965670085`, 0.20372391614271176`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 194}], {
             RGBColor[
             0.7816121517042992, 0.4029477795624471, 0.4403138133077221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 210}], {
             RGBColor[
             0.7101699878788666, 0.345393552112113, 0.4343848698876275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 218}], {
             RGBColor[
             0.875340160780385, 0.47642064776789905`, 0.430675613342974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 226}], {
             RGBColor[
             0.8816960164127614, 0.48093210501266836`, 0.40967383423425274`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 227}], {
             RGBColor[
             0.8705118000329004, 0.43480247052567644`, 0.21080209492961144`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 241}], {
             RGBColor[
             0.8816517065059561, 0.48091378172749166`, 0.4104081640603793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 290}], {
             RGBColor[
             0.8684139499629852, 0.42648519406555707`, 0.2091141155204876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 291}], {
             RGBColor[
             0.8619019121087841, 0.4662467231049401, 0.44816350088512813`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 100}], {
             RGBColor[
             0.1816658245926822, 0.30827267829841776`, 0.9336569720088254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 119}], {
             RGBColor[
             0.18176019735719462`, 0.3083718700574992, 0.9336623463981524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 122}], {
             RGBColor[
             0.18385458485627515`, 0.31057320411086997`, 0.9337816186678564]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 161}], {
             RGBColor[
             0.19216173018569271`, 0.31930454055552265`, 0.9342546983050465]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 244}], {
             RGBColor[
             0.18608629156364545`, 0.31291886935869395`, 0.9339087110633268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 123}], {
             RGBColor[
             0.20225228122772315`, 0.32991034947858455`, 0.9348293402592576]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 189}], {
             RGBColor[
             0.21086862151855923`, 0.33896666943178094`, 0.9353200280920875]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 257}], {
             RGBColor[
             0.19498858899920085`, 0.3222757484017205, 0.9344156837325129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 260}], {
             RGBColor[
             0.23203447362151203`, 0.3612133219845175, 0.9365253920572785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 267}], {
             RGBColor[
             0.2010537316252639, 0.328650597853966, 0.9347610846324927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 287}], {
             RGBColor[
             0.2244511741859948, 0.35324279346883447`, 0.936093534372912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 300}], {
             RGBColor[
             0.2157736566163444, 0.3441221723167407, 0.9355993625845572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 111}], {
             RGBColor[
             0.4735665439631073, 0.5802328466571501, 0.952603227994324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 143}], {
             RGBColor[
             0.31991196504772945`, 0.4513422193006194, 0.941611753099148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.47703987934410275`, 0.583052656791418, 0.9528766616787626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 165}], {
             RGBColor[
             0.27536181000482485`, 0.4045171817075533, 0.9390746876755028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 185}], {
             RGBColor[
             0.43124290556454353`, 0.5458726103470143, 0.9492713561429931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 235}], {
             RGBColor[
             0.3707116092284409, 0.495513496231598, 0.9448423938259995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 262}], {
             RGBColor[
             0.318384602518598, 0.4497368644421247, 0.9415247720626443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 292}], {
             RGBColor[
             0.5533224742847231, 0.6429700886267707, 0.9602576695267473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 85}], {
             RGBColor[
             0.2795331222505161, 0.40945731042738504`, 0.9392918866244364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 87}], {
             RGBColor[
             0.6600329022141906, 0.7226670785503484, 0.7188188011286823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 90}], {
             RGBColor[
             0.2712969166915207, 0.40080053617928724`, 0.938822846902226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 126}], {
             RGBColor[
             0.2752030578474213, 0.40490613819779253`, 0.9390452958624365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 151}], {
             RGBColor[
             0.46237290629163863`, 0.5709821178298984, 0.9517671246297987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 153}], {
             RGBColor[
             0.27399346070364045`, 0.40363477490679034`, 0.9389764110945367]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 192}], {
             RGBColor[
             0.32876752436481727`, 0.45918363809373036`, 0.9421697538281874]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 220}], {
             RGBColor[
             0.3300035970754238, 0.4602542621488369, 0.942248515288291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 239}], {
             RGBColor[
             0.28224692267200363`, 0.41230968673525326`, 0.9394464335437323]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 248}], {
             RGBColor[
             0.2744382407386017, 0.40410226692421763`, 0.9390017406595347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 258}], {
             RGBColor[
             0.3335396370029857, 0.4633170022075566, 0.942473828625678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 82}], {
             RGBColor[
             0.5136111712070213, 0.6149382362843397, 0.9551491039925967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 95}], {
             RGBColor[
             0.3506695406416134, 0.476194939387312, 0.94363706407864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 103}], {
             RGBColor[
             0.41755616548084906`, 0.5360878963815774, 0.9478272875273883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 127}], {
             RGBColor[
             0.3813089695721926, 0.5046923971225378, 0.9455176482562255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 145}], {
             RGBColor[
             0.6393432778876973, 0.7139671917177287, 0.9672816709055783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 154}], {
             RGBColor[
             0.455540153481848, 0.5677935680255081, 0.950577540756124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 159}], {
             RGBColor[
             0.3525117466514917, 0.4781312147063014, 0.9437419749856031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 167}], {
             RGBColor[
             0.6607323580564698, 0.6022582598273698, 0.5960819189651536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 168}], {
             RGBColor[
             0.4070970567080353, 0.527028742052658, 0.9471608423650113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 203}], {
             RGBColor[
             0.6754538924070363, 0.7427240405564789, 0.9694509218275109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 205}], {
             RGBColor[
             0.3930712028278346, 0.5148802523815419, 0.9462671273583405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 212}], {
             RGBColor[
             0.32357566422601636`, 0.4477175574235364, 0.9420941078985701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 225}], {
             RGBColor[
             0.32068966156322254`, 0.4446841856418027, 0.9419297543163823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 255}], {
             RGBColor[
             0.38990028243638014`, 0.512133760513557, 0.9460650791149319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 265}], {
             RGBColor[
             0.31824926646414226`, 0.4421191756626833, 0.9417907774257306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 269}], {
             RGBColor[
             0.6934737954253698, 0.7269802724747518, 0.6489189851142219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 276}], {
             RGBColor[
             0.3275782701356497, 0.45192455001443343`, 0.9423220503837988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 282}], {
             RGBColor[
             0.42720741988360567`, 0.5444473278590943, 0.9484422569236628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 293}], {
             RGBColor[
             0.6567707297143, 0.585264649646495, 0.5928277208084357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 99}], {
             RGBColor[
             0.19490280134245708`, 0.32218558013523124`, 0.9344107982523728]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 131}], {
             RGBColor[
             0.21176961520445978`, 0.33991367092196156`, 0.9353713383495988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 170}], {
             RGBColor[
             0.19585393495458225`, 0.32318528186692885`, 0.9344649639045073]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 178}], {
             RGBColor[
             0.2265713684695162, 0.3554712520888972, 0.9362142763008121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 182}], {
             RGBColor[
             0.22423750678067705`, 0.3530182154785495, 0.9360813663302717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 190}], {
             RGBColor[
             0.19927294772660503`, 0.32677888106825503`, 0.9346596716238978]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.19626308316666907`, 0.323615322579327, 0.9344882642899051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 209}], {
             RGBColor[
             0.18729352981200414`, 0.31418775330104487`, 0.933977461495622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 229}], {
             RGBColor[
             0.20592187570768378`, 0.3337673259427514, 0.9350383182362128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 261}], {
             RGBColor[
             0.21943392399577888`, 0.3479693454068822, 0.9358078093969358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 284}], {
             RGBColor[
             0.2175445595822431, 0.34598350361563335`, 0.935700212888649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 144}], {
             RGBColor[
             0.1903903758627761, 0.31744273485178653`, 0.9341538222968402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 160}], {
             RGBColor[
             0.1894526235362595, 0.316457097699686, 0.9341004186891254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 176}], {
             RGBColor[
             0.18866673983198834`, 0.31563108409859225`, 0.9340556637747779]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 221}], {
             RGBColor[
             0.18466822464384994`, 0.3114283911153532, 0.9338279542500865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 232}], {
             RGBColor[
             0.1855242988552152, 0.31232817938973806`, 0.9338767064099756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 240}], {
             RGBColor[
             0.18183565807480434`, 0.3084511840561929, 0.9336666437743861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 245}], {
             RGBColor[
             0.20419166956427437`, 0.3319487695846225, 0.9349397855559562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 288}], {
             RGBColor[
             0.19600308919068352`, 0.3233420524259961, 0.9344734580175993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 297}], {
             RGBColor[
             0.1875669958551452, 0.3144751834511347, 0.9339930349822221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 92}], {
             RGBColor[
             0.8806392624507501, 0.47575847385330106`, 0.24262510747050564`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 125}], {
             RGBColor[
             0.8830657841456923, 0.4944097829092139, 0.2449487473859466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 128}], {
             RGBColor[
             0.889562972527344, 0.5443500198966912, 0.25117046231774093`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 145}], {
             RGBColor[
             0.9218561356347152, 0.9176464031707863, 0.6795757972164687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 149}], {
             RGBColor[
             0.9371561077922606, 0.7792834728078644, 0.30334662593416606`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 150}], {
             RGBColor[
             0.9431089113179686, 0.8053970694161215, 0.30826637148751795`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 156}], {
             RGBColor[
             0.6866499660786538, 0.7281441949934098, 0.6592663633827371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 167}], {
             RGBColor[
             0.9432452158034876, 0.8059374712804274, 0.30837604527604406`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 179}], {
             RGBColor[
             0.7507825863487789, 0.7818072220217351, 0.663873785850424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 201}], {
             RGBColor[
             0.8898455310710746, 0.5465218886817487, 0.2514410406983216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 205}], {
             RGBColor[
             0.6755840605748524, 0.7185594638345996, 0.6585612536692309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 237}], {
             RGBColor[
             0.8763192452000071, 0.442552928220461, 0.2384882540724326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 256}], {
             RGBColor[
             0.8715548723467077, 0.4059318707085048, 0.23392588524752353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 269}], {
             RGBColor[
             0.9759866531723878, 0.9306594839278095, 0.36121311142511225`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 277}], {
             RGBColor[
             0.9859097978901593, 0.963818944183442, 0.4264320765360633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 281}], {
             RGBColor[
             0.9786349916305042, 0.9618175926615335, 0.6467591064594813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 282}], {
             RGBColor[
             0.7097202776306235, 0.7481265393121519, 0.6607363832345532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 293}], {
             RGBColor[
             0.9392835874613179, 0.7889438610995526, 0.30512184711932616`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 86}], {
             RGBColor[
             0.7418209808035544, 0.6361932312179576, 0.5953370394744854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 94}], {
             RGBColor[
             0.8431768541892217, 0.7161112955984645, 0.6049346124449686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 97}], {
             RGBColor[
             0.6691615275279388, 0.5770839186847934, 0.5896504800872672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.9006340382989853, 0.6395018820094367, 0.23868605563289352`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 140}], {
             RGBColor[
             0.8413676314488565, 0.2864072420017145, 0.18597171239681876`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 162}], {
             RGBColor[
             0.9404065856589258, 0.790829015220349, 0.5112620539625906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 167}], {
             RGBColor[
             0.8985734587541578, 0.6313323707616247, 0.23702806496310708`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 181}], {
             RGBColor[
             0.9378794291938042, 0.7781980948822975, 0.31536710248397326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 201}], {
             RGBColor[
             0.8600643597048547, 0.4301184883358802, 0.203875720489697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 202}], {
             RGBColor[
             0.8742021218716074, 0.5216630409074182, 0.2167435057125596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 203}], {
             RGBColor[
             0.9132949931047244, 0.7717981514907339, 0.6103970678254644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 216}], {
             RGBColor[
             0.8741307766845507, 0.521339079076086, 0.216683973539649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 237}], {
             RGBColor[
             0.8465380738337873, 0.3261495278745926, 0.19092293386380793`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 269}], {
             RGBColor[
             0.931314896123058, 0.7560543834090069, 0.28986513111217527`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 293}], {
             RGBColor[
             0.8946118304119881, 0.61433876058075, 0.23377386680638917`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 299}], {
             RGBColor[
             0.8422842306382159, 0.2934526250274564, 0.1868494488157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 103}], {
             RGBColor[
             0.5173846437366769, 0.6182066285292835, 0.9553895463254356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 140}], {
             RGBColor[
             0.7493592164876164, 0.32177032281068196`, 0.43038245426354804`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 145}], {
             RGBColor[
             0.7391717561435251, 0.7960859238654349, 0.9748439297036255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 154}], {
             RGBColor[
             0.5553686317376758, 0.6499123001732142, 0.9581397995541713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 167}], {
             RGBColor[
             0.7605608363122977, 0.684376991975076, 0.6036441777632009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 168}], {
             RGBColor[
             0.5069255349638632, 0.6091474742003642, 0.9547231011630586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 181}], {
             RGBColor[
             0.7998668067519439, 0.8312427160957487, 0.681983215284067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 201}], {
             RGBColor[
             0.7680559447436146, 0.4654815691448476, 0.44828646235642633`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 203}], {
             RGBColor[
             0.7752823706628642, 0.824842772704185, 0.9770131806255582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 216}], {
             RGBColor[
             0.7821223617233105, 0.5567021598850534, 0.46109471540637825`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 255}], {
             RGBColor[
             0.489728760692208, 0.5942524926612631, 0.9536273379129792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 258}], {
             RGBColor[
             0.47680058453134755`, 0.5830547562597531, 0.9528035659599465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 293}], {
             RGBColor[
             0.7565992079701278, 0.6673833817942012, 0.600389979606483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 101}], {
             RGBColor[
             0.7801443981327315, 0.4806917133441988, 0.4499691651133977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 142}], {
             RGBColor[
             0.8410135879259631, 0.3162539858335876, 0.18690796415711172`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 149}], {
             RGBColor[
             0.8628696595923687, 0.44534910675306505`, 0.20631412788053274`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 194}], {
             RGBColor[
             0.7930369047021925, 0.4907634374629408, 0.4512541696809177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[
             0.8931489612206265, 0.5687594209510818, 0.42014697935815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 198}], {
             RGBColor[
             0.8858987442443274, 0.5635903178481945, 0.44308216880395335`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 226}], {
             RGBColor[
             0.8931207694106547, 0.5687477629131621, 0.4206141906074483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 241}], {
             RGBColor[
             0.8930764595038494, 0.5687294396279854, 0.42134852043357485`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 243}], {
             RGBColor[
             0.8935075599716172, 0.5689077107501841, 0.41420407003041315`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 290}], {
             RGBColor[
             0.8798387029608784, 0.5143008519660508, 0.22005447189368316`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 291}], {
             RGBColor[
             0.8733266651066773, 0.5540623810054337, 0.4591038572583237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 191}], {
             RGBColor[
             0.2074223158614455, 0.3353443836777553, 0.9351237660832672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 217}], {
             RGBColor[
             0.19375308221906778`, 0.32097715244014635`, 0.9343453234491528]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 223}], {
             RGBColor[
             0.1844791456857544, 0.31122965714209644`, 0.9338171864831403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 246}], {
             RGBColor[
             0.1859588657451276, 0.3127849367441682, 0.9339014543514719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 247}], {
             RGBColor[
             0.1926121673846783, 0.3197779786110244, 0.9342803500371666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 270}], {
             RGBColor[
             0.20015353292457566`, 0.32770443194364846`, 0.9347098196482133]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 271}], {
             RGBColor[
             0.20505156873545605`, 0.33285257813429087`, 0.9349887555416483]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 278}], {
             RGBColor[
             0.19404895120727791`, 0.32128812950593255`, 0.9343621727503324]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 295}], {
             RGBColor[
             0.19219536521772562`, 0.31933989310677346`, 0.9342566137703623]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[
             0.22879896787362192`, 0.35781260030057205`, 0.936341134791438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 135}], {
             RGBColor[
             0.22261249954375167`, 0.3513102298411313, 0.9359888245721116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 154}], {
             RGBColor[
             0.36472305205370464`, 0.48205039622074985`, 0.9450500607222323]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 173}], {
             RGBColor[
             0.21671771694106706`, 0.34511443957490595`, 0.9356531254234381]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 213}], {
             RGBColor[
             0.21726177740977812`, 0.34568628162294734`, 0.9356841088622658]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 234}], {
             RGBColor[
             0.21315182719847248`, 0.341366463364971, 0.9354500532778585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 239}], {
             RGBColor[
             0.2348622905163943, 0.36418553683498534`, 0.936686432046062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 249}], {
             RGBColor[
             0.21980259172524277`, 0.34835683856543287`, 0.9358288044787336]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 255}], {
             RGBColor[
             0.2990831810082368, 0.42639058870879876`, 0.9405375990810403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 258}], {
             RGBColor[
             0.2861550048473763, 0.41519285230728875`, 0.9397138271280076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 263}], {
             RGBColor[
             0.22101888131475306`, 0.34963523604122215`, 0.9358980703715171]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 286}], {
             RGBColor[
             0.2265196157319883, 0.3554168566804423, 0.9362113290589713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[
             0.6955329406462065, 0.7613368008112785, 0.9707925147289977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 97}], {
             RGBColor[
             0.5215176139849236, 0.6223094238976072, 0.9555083823712963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 120}], {
             RGBColor[
             0.4366336879326583, 0.5460453622474791, 0.9502000470026102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 130}], {
             RGBColor[
             0.75299012475597, 0.6847273872222507, 0.6045439579169226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 140}], {
             RGBColor[
             0.7429383557535131, 0.3165575788102572, 0.4298769805861715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 162}], {
             RGBColor[
             0.7927626721159106, 0.8360545204331631, 0.8771199562466196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 169}], {
             RGBColor[
             0.5994580148931581, 0.6857060476229113, 0.9616106773009028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[
             0.4265942001520806, 0.5354932240498018, 0.9496283130255976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 182}], {
             RGBColor[
             0.4242603384632414, 0.5330401874394541, 0.9494954030550571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 202}], {
             RGBColor[
             0.7757728461762639, 0.551813377715961, 0.4606487739019124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 261}], {
             RGBColor[
             0.41945675567834323`, 0.5279913173677868, 0.949221846121721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 284}], {
             RGBColor[
             0.41756739126480746`, 0.526005475576538, 0.9491142496134344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 109}], {
             RGBColor[
             0.9929796059139886, 0.9895239708410322, 0.632193448669364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 140}], {
             RGBColor[
             0.8759286833407519, 0.418668898924348, 0.2746739047117526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 151}], {
             RGBColor[
             0.7954880540997038, 0.8360677360525939, 0.7285340376363743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[
             0.7452228320173793, 0.7952601643437132, 0.7245769752264782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 155}], {
             RGBColor[
             0.959730943798982, 0.866659323879206, 0.37757715104669176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 162}], {
             RGBColor[
             0.9922481634967688, 0.9892215006042993, 0.6443153424349913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 181}], {
             RGBColor[
             0.9897210070316473, 0.9765905802662477, 0.448420390956374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 202}], {
             RGBColor[
             0.9087631737635028, 0.6539246978300517, 0.30544569802749344`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 203}], {
             RGBColor[
             0.9651365709425674, 0.970190636874684, 0.7434503562978652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 216}], {
             RGBColor[
             0.9086918285764461, 0.6536007359987195, 0.30538616585458284`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 227}], {
             RGBColor[
             0.9729262687384115, 0.9189743901826695, 0.3881944192270413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 258}], {
             RGBColor[
             0.6666547848110509, 0.7284026204302521, 0.7192407416322534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 299}], {
             RGBColor[
             0.8768452825301113, 0.42571428195008987`, 0.27555164113063385`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 93}], {
             RGBColor[
             0.23199426054362918`, 0.36117105549000617`, 0.9365231019819831]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 107}], {
             RGBColor[
             0.3156668760979841, 0.43989562490003076`, 0.9416257469918767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 124}], {
             RGBColor[
             0.20439146202389424`, 0.3321587641272566, 0.9349511634409652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 137}], {
             RGBColor[
             0.242196310039882, 0.3718940563578661, 0.9371040936082149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 147}], {
             RGBColor[
             0.21812810554997109`, 0.34659684742666674`, 0.9357334449682322]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 273}], {
             RGBColor[
             0.23089430452924603`, 0.3600149319776501, 0.936460461114203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 274}], {
             RGBColor[
             0.342952508633553, 0.4632649151839602, 0.9434373496862328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 289}], {
             RGBColor[
             0.23315152394890182`, 0.3623874127036856, 0.9365890064208955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 94}], {
             RGBColor[
             0.5888165791799138, 0.6727291061533267, 0.962935879267211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 120}], {
             RGBColor[
             0.3299173264663655, 0.4574376675895273, 0.9423434115408236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 131}], {
             RGBColor[
             0.3050760854207314, 0.4313279482249144, 0.9409287396125976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 141}], {
             RGBColor[
             0.33729605784908523`, 0.4651931821113565, 0.9427636193772146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 188}], {
             RGBColor[
             0.3683043792841372, 0.49342847464473716`, 0.9446890072625783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 236}], {
             RGBColor[
             0.30608763983959875`, 0.4323911560553985, 0.9409863461402914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 260}], {
             RGBColor[
             0.3194559514168667, 0.4464420991230162, 0.9417476517079721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 281}], {
             RGBColor[
             0.6796029595718664, 0.743830302697593, 0.9334123929687868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 294}], {
             RGBColor[
             0.4583968818459615, 0.569215720181254, 0.9510502956112238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 118}], {
             RGBColor[
             0.20219853738896398`, 0.32985386129649247`, 0.9348262796271471]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 126}], {
             RGBColor[
             0.2195822201328165, 0.34812521404942687`, 0.9358162546425555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 153}], {
             RGBColor[
             0.21837262298903565`, 0.3468538507584247, 0.9357473698746558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.20088523531551122`, 0.3284734975491328, 0.9347514890169203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 195}], {
             RGBColor[
             0.19970007804544365`, 0.3272278221149808, 0.934683996063673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 222}], {
             RGBColor[
             0.2185508250169386, 0.3470411523884118, 0.9357575182165185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 234}], {
             RGBColor[
             0.20491562163947707`, 0.33270968911687326`, 0.9349810135556479]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 239}], {
             RGBColor[
             0.2266260849573989, 0.3555287625868876, 0.9362173923238513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 248}], {
             RGBColor[
             0.21881740302399694`, 0.347321342775852, 0.9357726994396538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 285}], {
             RGBColor[
             0.20767787323688183`, 0.3356129906826123, 0.9351383196977351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 93}], {
             RGBColor[
             0.3656444287828603, 0.48387268995411137`, 0.9450248073537576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 105}], {
             RGBColor[
             0.38699951220692347`, 0.5063182366232937, 0.9462409477627431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 107}], {
             RGBColor[
             0.44931704433721525`, 0.562597259364136, 0.9501274523636514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 139}], {
             RGBColor[
             0.4654409733450266, 0.5765629962584664, 0.9511548548621985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 142}], {
             RGBColor[
             0.7166766594677184, 0.35305977598567057`, 0.4352018560097054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 143}], {
             RGBColor[
             0.39852667636969663`, 0.5184340170227889, 0.9468974027089019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 150}], {
             RGBColor[
             0.6987841041568563, 0.6337941140587057, 0.5986819437121721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 163}], {
             RGBColor[
             0.5556545906660699, 0.6501444545135875, 0.9581623112885165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 179}], {
             RGBColor[
             0.5064577791876668, 0.6102042666643193, 0.9542893580750782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 235}], {
             RGBColor[
             0.44932632055040805`, 0.5626052939537676, 0.9501280434357534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 273}], {
             RGBColor[
             0.3645444727684772, 0.4827165664417553, 0.9449621664859775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 274}], {
             RGBColor[
             0.4766026768727841, 0.5859665496480654, 0.9519390550580074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 298}], {
             RGBColor[
             0.3751482927558811, 0.4938618535695355, 0.9455660383473143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 125}], {
             RGBColor[
             0.8327679503009816, 0.2528744017865336, 0.1790119322553138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 128}], {
             RGBColor[
             0.8360165444918075, 0.27784452028027223`, 0.18212278972121096`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 142}], {
             RGBColor[
             0.8310149903490321, 0.23940038344390055`, 0.17733329582564183`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 149}], {
             RGBColor[
             0.8528710620154377, 0.368495504363378, 0.19673945954906286`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 150}], {
             RGBColor[
             0.856839597699243, 0.38590456876888285`, 0.2000192899179641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 179}], {
             RGBColor[
             0.7286220477197832, 0.3701780038392919, 0.4370908994932349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 237}], {
             RGBColor[
             0.829394680828139, 0.22694597444215714`, 0.1757816855985568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 243}], {
             RGBColor[
             0.8835089623946862, 0.49205410836049707`, 0.4046294016989433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 256}], {
             RGBColor[
             0.8270124944014894, 0.208635445686179, 0.17350050118610227`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 269}], {
             RGBColor[
             0.8787580922688558, 0.4694128451100082, 0.23531711654302695`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 277}], {
             RGBColor[
             0.8853735220807035, 0.49151915194709656`, 0.27879642661699433`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 281}], {
             RGBColor[
             0.8805236512409333, 0.4901849175991575, 0.4256811132326063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 105}], {
             RGBColor[
             0.26248514686677915`, 0.39321891024948796`, 0.9382595128508624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 107}], {
             RGBColor[
             0.32480267899707094`, 0.44949793299033025`, 0.9421460174517705]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 137}], {
             RGBColor[
             0.25133211293896884`, 0.38149636444816565`, 0.9376243640681086]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 139}], {
             RGBColor[
             0.3409266080048823, 0.4634636698846607, 0.9431734199503177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 147}], {
             RGBColor[
             0.22726390844905786`, 0.3561991555169663, 0.936253715428126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 273}], {
             RGBColor[
             0.24003010742833283`, 0.36961724006794966`, 0.9369807315740968]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 274}], {
             RGBColor[
             0.3520883115326398, 0.4728672232742597, 0.9439576201461266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 289}], {
             RGBColor[
             0.24228732684798865`, 0.37198972079398507`, 0.9371092768807893]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 97}], {
             RGBColor[
             0.622873487370591, 0.7022274882781143, 0.9651059553417796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 120}], {
             RGBColor[
             0.5379895613183256, 0.6259634266279861, 0.9597976199730934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 130}], {
             RGBColor[
             0.8543459981416374, 0.7646454516027577, 0.6141415308874059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 141}], {
             RGBColor[
             0.5453682927010454, 0.6337189411498153, 0.9602178278094844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 188}], {
             RGBColor[
             0.5763766141360973, 0.661954233683196, 0.9621432156948482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 201}], {
             RGBColor[
             0.8292056662666228, 0.5135475347314276, 0.45417937065937186`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 202}], {
             RGBColor[
             0.8433434284333755, 0.6050920873029656, 0.46704715588223444`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.8156793803955554, 0.4095785742701399, 0.4412265840334828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 281}], {
             RGBColor[
             0.8876751944238266, 0.9123560617360518, 0.9508666014010566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 293}], {
             RGBColor[
             0.8483237902546403, 0.739482330174071, 0.6092293420609014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 294}], {
             RGBColor[
             0.6664691166979216, 0.7377414792197128, 0.9685045040434936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 103}], {
             RGBColor[
             0.35444301317126903`, 0.47946333163225574`, 0.9438775064114789]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 127}], {
             RGBColor[
             0.3181958172626126, 0.4480678323732162, 0.9415678671403162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 145}], {
             RGBColor[
             0.5762301255781173, 0.6573426269684071, 0.963331889789669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 148}], {
             RGBColor[
             0.2669268205335093, 0.3978873908915973, 0.9385124595953154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 156}], {
             RGBColor[
             0.3410239560220559, 0.4678404187910305, 0.9430224559559374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 159}], {
             RGBColor[
             0.2893985943419117, 0.4215066499569798, 0.9397921938696936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 168}], {
             RGBColor[
             0.3439839043984553, 0.4704041773033365, 0.943211061249102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 191}], {
             RGBColor[
             0.2574665501142888, 0.38794404686520834`, 0.9379737111901566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 205}], {
             RGBColor[
             0.32995805051825455`, 0.4582556876322203, 0.9423173462424312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 212}], {
             RGBColor[
             0.2604625119164363, 0.3910929926742148, 0.9381443267826606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 225}], {
             RGBColor[
             0.2575765092536425, 0.3880596208924811, 0.9379799732004728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 251}], {
             RGBColor[
             0.2865818395337517, 0.41854606206103384`, 0.9396317838503843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 271}], {
             RGBColor[
             0.25509580298829937`, 0.3854522413217438, 0.9378387006485376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 276}], {
             RGBColor[
             0.2644651178260697, 0.3952999852651118, 0.9383722692678894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 282}], {
             RGBColor[
             0.36409426757402563`, 0.48782276310977274`, 0.9444924758077534]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 112}], {
             RGBColor[
             0.1950909003644823, 0.32238328413354655`, 0.9344215102134096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 132}], {
             RGBColor[
             0.1989233882773373, 0.32641147192372544`, 0.9346397647303889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 133}], {
             RGBColor[
             0.19311989172231955`, 0.3203116290814677, 0.9343092641870845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 146}], {
             RGBColor[
             0.20048974504421074`, 0.3280578121984645, 0.9347289664310452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 236}], {
             RGBColor[
             0.2161907003932258, 0.34456051176834573`, 0.9356231126106896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 260}], {
             RGBColor[
             0.22955901197049378`, 0.3586114548359634, 0.9363844181783704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 267}], {
             RGBColor[
             0.19857826997424566`, 0.3260487307054119, 0.9346201107535846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 120}], {
             RGBColor[
             0.3639742346570427, 0.4869360497143149, 0.944513487615392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 130}], {
             RGBColor[
             0.6803306714803544, 0.6256180746890865, 0.5988573985297044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 178}], {
             RGBColor[
             0.353934746876465, 0.4763839115166376, 0.9439417536383794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 182}], {
             RGBColor[
             0.35160088518762583`, 0.47393087490628993`, 0.9438088436678389]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 202}], {
             RGBColor[
             0.7273332106591868, 0.5124071693605181, 0.4568577343104335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 261}], {
             RGBColor[
             0.34679730240272766`, 0.46888200483462256`, 0.9435352867345028]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 284}], {
             RGBColor[
             0.3449079379891919, 0.4668961630433738, 0.9434276902262162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 157}], {
             RGBColor[
             0.18079506708635712`, 0.3073574569500555, 0.9336073836570105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.17910006852395627`, 0.30557590599185624`, 0.9335108559964074]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 275}], {
             RGBColor[
             0.17961340510331275`, 0.30611545528417883`, 0.9335400897551883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 285}], {
             RGBColor[
             0.18936585526810354`, 0.31636589874842813`, 0.9340954773646161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 182}], {
             RGBColor[
             0.22500890422772363`, 0.3538290031048185, 0.9361252962737008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 199}], {
             RGBColor[
             0.19703448061371565`, 0.32442611020559603`, 0.9345321942333341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 209}], {
             RGBColor[
             0.18806492725905072`, 0.31499854092731383`, 0.934021391439051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 215}], {
             RGBColor[
             0.21020795705683448`, 0.338272269193962, 0.9352824042283578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 229}], {
             RGBColor[
             0.20669327315473038`, 0.33457811356902034`, 0.9350822481796419]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 233}], {
             RGBColor[
             0.20053490529032286`, 0.32810527848045334`, 0.9347315382402527]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 259}], {
             RGBColor[
             0.19041774683741108`, 0.3174715034815479, 0.934155381033354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 284}], {
             RGBColor[
             0.2183159570292897, 0.34679429124190236`, 0.9357441428320781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 119}], {
             RGBColor[
             0.1807572108955105, 0.3073176676932546, 0.933605227802945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 122}], {
             RGBColor[
             0.18285159839459103`, 0.3095190017466254, 0.933724500072649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 161}], {
             RGBColor[
             0.1911587437240086, 0.318250338191278, 0.9341975797098391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 244}], {
             RGBColor[
             0.18508330510196136`, 0.31186466699444937`, 0.9338515924681194]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 266}], {
             RGBColor[
             0.1894062944527255, 0.3164084028954582, 0.9340977803163559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 104}], {
             RGBColor[
             0.49120791951509923`, 0.5945373978105576, 0.9540278714950781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 116}], {
             RGBColor[
             0.46733992011891123`, 0.5718860980228273, 0.952579449352897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 136}], {
             RGBColor[
             0.5199717589850226, 0.6194511898467974, 0.9558606779112371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 149}], {
             RGBColor[
             0.7714159149498363, 0.6714029284596804, 0.6000007099012994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 197}], {
             RGBColor[
             0.816834867392223, 0.8565183997567056, 0.9207499871177253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 198}], {
             RGBColor[
             0.8059595419277743, 0.8487647451023745, 0.9551527712864303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[
             0.5654681824695174, 0.6580354513456885, 0.9589869162220399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 226}], {
             RGBColor[
             0.8167925796772653, 0.8565009126998259, 0.9214508039916728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 243}], {
             RGBColor[
             0.8173727655187092, 0.8567408344553589, 0.91183562312612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 254}], {
             RGBColor[
             0.4830549298600605, 0.587475687952538, 0.9535083702036646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 283}], {
             RGBColor[
             0.4765743997943146, 0.5815921216615045, 0.9531053393092228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 165}], {
             RGBColor[
             0.20499479718794766`, 0.3327929076383356, 0.9349855224860035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 172}], {
             RGBColor[
             0.19138970866876043`, 0.3184930969922355, 0.9342107328217606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 175}], {
             RGBColor[
             0.18740197098760464`, 0.3143017318521686, 0.9339836370601481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 183}], {
             RGBColor[
             0.19246783079694663`, 0.31962627170585023`, 0.934272130282022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 238}], {
             RGBColor[
             0.18981943468321613`, 0.3168426394723074, 0.9341213080412961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 253}], {
             RGBColor[
             0.1920226425007294, 0.3191583505799577, 0.9342467774671497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 127}], {
             RGBColor[
             0.3850824421018483, 0.5079607893674816, 0.9457580905890645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 145}], {
             RGBColor[
             0.643116750417353, 0.7172355839626725, 0.9675221132384173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 154}], {
             RGBColor[
             0.45931362601150366`, 0.5710619602704519, 0.9508179830889629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 159}], {
             RGBColor[
             0.35628521918114736`, 0.4813996069512451, 0.9439824173184419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 167}], {
             RGBColor[
             0.6645058305861254, 0.6055266520723135, 0.5963223612979925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 168}], {
             RGBColor[
             0.41087052923769096`, 0.5302971342976018, 0.9474012846978503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 203}], {
             RGBColor[
             0.679227364936692, 0.7459924328014227, 0.96969136416035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 205}], {
             RGBColor[
             0.39684467535749024`, 0.5181486446264856, 0.9465075696911796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 212}], {
             RGBColor[
             0.327349136755672, 0.45098594966848016`, 0.9423345502314089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 225}], {
             RGBColor[
             0.3244631340928782, 0.4479525778867464, 0.9421701966492211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 255}], {
             RGBColor[
             0.3936737549660358, 0.5154021527585007, 0.9463055214477708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 265}], {
             RGBColor[
             0.3220227389937979, 0.445387567907627, 0.9420312197585695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 269}], {
             RGBColor[
             0.6972472679550255, 0.7302486647196956, 0.6491594274470608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 276}], {
             RGBColor[
             0.33135174266530537`, 0.4551929422593771, 0.9425624927166377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 282}], {
             RGBColor[
             0.4309808924132613, 0.5477157201040381, 0.9486826992565017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 293}], {
             RGBColor[
             0.6605442022439556, 0.5885330418914387, 0.5930681631412746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 114}], {
             RGBColor[
             0.28710993911342014`, 0.4166656473064825, 0.939751033226302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 116}], {
             RGBColor[
             0.3112198168736299, 0.4420066574870038, 0.9411240550973782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 204}], {
             RGBColor[
             0.40934807922423605`, 0.5281560108098651, 0.9475315219665212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 206}], {
             RGBColor[
             0.2787552105581772, 0.4078842978745366, 0.9392752437947942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 243}], {
             RGBColor[
             0.6612526622734278, 0.7268613939195354, 0.9003802288706013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 254}], {
             RGBColor[
             0.32693482661477913`, 0.45759624741671456`, 0.942052975948146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 283}], {
             RGBColor[
             0.32045429654903324`, 0.4517126811256811, 0.9416499450537039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 287}], {
             RGBColor[
             0.2890443879522816, 0.41869887568726627`, 0.9398611972259145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 300}], {
             RGBColor[
             0.2803668703826312, 0.4095782545351725, 0.9393670254375599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 139}], {
             RGBColor[
             0.3622816914289454, 0.48590921655384295`, 0.9443895603593033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 143}], {
             RGBColor[
             0.29536739445361543`, 0.4277802373181654, 0.9401321082060067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 163}], {
             RGBColor[
             0.4524953087499887, 0.5594906748089641, 0.9513970167856213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 174}], {
             RGBColor[
             0.25852249961576723`, 0.3890539167423275, 0.9380338459521285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 235}], {
             RGBColor[
             0.34616703863432685`, 0.47195151424914406`, 0.9433627489328582]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 274}], {
             RGBColor[
             0.373443394956703, 0.4953127699434419, 0.9451737605551122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 298}], {
             RGBColor[
             0.27198901083979987`, 0.403208073864912, 0.938800743844419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 115}], {
             RGBColor[
             0.6067946716231568, 0.6858798777418896, 0.9651595250499304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 155}], {
             RGBColor[
             0.8940872222095038, 0.8191271102860018, 0.6231274080512639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 162}], {
             RGBColor[
             0.9266044419072905, 0.9416892870110949, 0.8898655994395634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 194}], {
             RGBColor[
             0.7739330746560312, 0.8236601401446212, 0.9780122537987794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 200}], {
             RGBColor[
             0.6137154608562325, 0.6918743175265988, 0.9656005116200483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 210}], {
             RGBColor[
             0.6667698289178824, 0.73732879896912, 0.9691188386686375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 211}], {
             RGBColor[
             0.5662966671615951, 0.6472879549936589, 0.9627077142549896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 227}], {
             RGBColor[
             0.907282547148933, 0.8714421765894653, 0.6337446762316135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 241}], {
             RGBColor[
             0.9239924068585166, 0.940609143392188, 0.9331537799277652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 264}], {
             RGBColor[
             0.579035279379287, 0.6606770441091168, 0.9634331593756991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 290}], {
             RGBColor[
             0.9041357720440601, 0.8589662618992862, 0.6312127071179277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 291}], {
             RGBColor[
             0.8943677152627585, 0.9186085554583606, 0.9897867851648885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 137}], {
             RGBColor[
             0.33500472849332374`, 0.4602209338581902, 0.9427270090780024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 139}], {
             RGBColor[
             0.4245992235592372, 0.5421882392946853, 0.9482760649602114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[
             0.3109365240034128, 0.43492372492699083`, 0.9413563604380197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 150}], {
             RGBColor[
             0.657942354371067, 0.5994193570949246, 0.595803153810185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.4014834091317521, 0.5221664826722128, 0.9468031457054042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.4656160294018773, 0.5758295097005381, 0.9514105681730911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 251}], {
             RGBColor[
             0.34704129264344796`, 0.47287212594221606`, 0.943412473599851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 273}], {
             RGBColor[
             0.32370272298268776`, 0.4483418094779742, 0.9420833765839904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 274}], {
             RGBColor[
             0.43576092708699476`, 0.5515917926842843, 0.9490602651560203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 277}], {
             RGBColor[
             0.7007432409432577, 0.7578412318622451, 0.7139688588587303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 289}], {
             RGBColor[
             0.32595994240234355`, 0.45071429020400966`, 0.942211921890683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 136}], {
             RGBColor[
             0.3166504809342749, 0.4423958027593246, 0.9416280716923184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 177}], {
             RGBColor[
             0.2663285931328081, 0.3972586159636525, 0.9384783914298436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 204}], {
             RGBColor[
             0.36214690441876973`, 0.48098006425821577`, 0.9447543100031214]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 208}], {
             RGBColor[
             0.2150010029643497, 0.34331006433942324`, 0.9355553611021148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 252}], {
             RGBColor[
             0.23931387407336885`, 0.3688644334000649, 0.9369399431441039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 254}], {
             RGBColor[
             0.27973365180931276`, 0.4104203008650652, 0.9392757639847461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 268}], {
             RGBColor[
             0.2228674989167732, 0.351578250350071, 0.9360033464091675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 279}], {
             RGBColor[
             0.23867609661587075`, 0.3681940888548081, 0.9369036226614065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 280}], {
             RGBColor[
             0.2513491898337207, 0.3815143133472875, 0.9376253365720018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 283}], {
             RGBColor[
             0.2732531217435669, 0.4045367345740317, 0.9388727330903042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 111}], {
             RGBColor[
             0.8035074391264327, 0.8444862586698714, 0.8657863480729937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 151}], {
             RGBColor[
             0.7953196099914366, 0.8378390101205823, 0.8651417721704804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 155}], {
             RGBColor[
             0.9595624996907148, 0.8684305979471943, 0.514184885580798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 192}], {
             RGBColor[
             0.6617142280646152, 0.7260405303844142, 0.8555444013688691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 218}], {
             RGBColor[
             0.9800003657513711, 0.9831729301139916, 0.8546124313811914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 220}], {
             RGBColor[
             0.6629503007752218, 0.7271111544395208, 0.8556231628289728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 227}], {
             RGBColor[
             0.9727578246301442, 0.9207456642506578, 0.5248021537611475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 290}], {
             RGBColor[
             0.9696110495252712, 0.9082697495604787, 0.5222701846474617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 292}], {
             RGBColor[
             0.8832633694480486, 0.907223500639492, 0.873440789605417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 148}], {
             RGBColor[
             0.2161072361235734, 0.34447278552900074`, 0.9356183594440073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 191}], {
             RGBColor[
             0.20664696570435293`, 0.3345294415026117, 0.9350796110388486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 223}], {
             RGBColor[
             0.18370379552866184`, 0.31041471496695283`, 0.9337730314387216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 246}], {
             RGBColor[
             0.18518351558803503`, 0.3119699945690246, 0.9338572993070533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 278}], {
             RGBColor[
             0.19327360105018532`, 0.32047318733078894`, 0.9343180177059138]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 295}], {
             RGBColor[
             0.19142001506063305`, 0.31852495093162986`, 0.9342124587259435]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 143}], {
             RGBColor[
             0.46054913753176646`, 0.5687866450741914, 0.9517800380473413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 163}], {
             RGBColor[
             0.6176770518281398, 0.70049708256499, 0.9630449466269559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.5718800780485805, 0.6633170361205862, 0.9594396410911864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 218}], {
             RGBColor[
             0.7906966430720825, 0.8363639438748425, 0.9515975962507148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 235}], {
             RGBColor[
             0.5113487817124779, 0.61295792200517, 0.9550106787741928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 262}], {
             RGBColor[
             0.459021775002635, 0.5671812902156966, 0.9516930570108376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 292}], {
             RGBColor[
             0.6939596467687601, 0.7604145144003427, 0.9704259544749405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 131}], {
             RGBColor[
             0.20931958090363292`, 0.3373385295306458, 0.9352318125206677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 132}], {
             RGBColor[
             0.1930638232066118, 0.32025269751650964`, 0.9343060711680607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 133}], {
             RGBColor[
             0.18726032665159403`, 0.3141528546742519, 0.9339755706247563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 146}], {
             RGBColor[
             0.19463017997348525`, 0.32189903779124873`, 0.934395272868717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 170}], {
             RGBColor[
             0.1934039006537554, 0.3206101404756131, 0.9343254380755761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 190}], {
             RGBColor[
             0.19682291342577818`, 0.3242037396769393, 0.9345201457949667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 115}], {
             RGBColor[
             0.3096806718260522, 0.43885035168813935`, 0.9410927375300542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 134}], {
             RGBColor[
             0.25621583264175446`, 0.38662946350150684`, 0.9379024846803665]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 144}], {
             RGBColor[
             0.23263625868922916`, 0.36184583624606526`, 0.9365596628266237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 160}], {
             RGBColor[
             0.23169850636271255`, 0.3608601990939647, 0.936506259218909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 169}], {
             RGBColor[
             0.4361857848874334, 0.5443112881470928, 0.9502895329739705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 176}], {
             RGBColor[
             0.23091262265844142`, 0.3600341854928709, 0.9364615043045614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 187}], {
             RGBColor[
             0.24618639037776724`, 0.3760878837786886, 0.9373313227806626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 193}], {
             RGBColor[
             0.2735981771019762, 0.40489940963349313`, 0.9388923834825018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 200}], {
             RGBColor[
             0.3166014610591278, 0.4448447914728484, 0.9415337241001722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 228}], {
             RGBColor[
             0.34694483487630184`, 0.4711266967709722, 0.9434671770482106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 231}], {
             RGBColor[
             0.24940666839475117`, 0.3794726001519578, 0.9375147128497554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 245}], {
             RGBColor[
             0.24643755239072743`, 0.3763518709789012, 0.9373456260857398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 264}], {
             RGBColor[
             0.28192127958218227`, 0.41364751805536637`, 0.939366371855823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 288}], {
             RGBColor[
             0.23824897201713657`, 0.3677451538202748, 0.9368792985473828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 297}], {
             RGBColor[
             0.22981287868159825`, 0.35887828484541334`, 0.9363988755120056]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 116}], {
             RGBColor[
             0.26324193971723214`, 0.3940143475187522, 0.9383026110841209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 204}], {
             RGBColor[
             0.3613702020678383, 0.4801637008416135, 0.944710077953264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 206}], {
             RGBColor[
             0.2307773334017795, 0.35989198790628496`, 0.936453799781537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 254}], {
             RGBColor[
             0.2789569494583814, 0.4096039374484629, 0.9392315319348887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 283}], {
             RGBColor[
             0.2724764193926355, 0.4037203711574294, 0.9388285010404467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 134}], {
             RGBColor[
             0.29826389721871693`, 0.4268505977105114, 0.940442569105771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 169}], {
             RGBColor[
             0.47823384946439584`, 0.5845324223560975, 0.9528296173993749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 193}], {
             RGBColor[
             0.3156462416789386, 0.4451205438424978, 0.9414324679079064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 200}], {
             RGBColor[
             0.35864952563609026`, 0.485065925681853, 0.9440738085255767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 210}], {
             RGBColor[
             0.4117038936977402, 0.5305204071243743, 0.9475921355741658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 211}], {
             RGBColor[
             0.3112307319414529, 0.4404795631489132, 0.9411810111605179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 227}], {
             RGBColor[
             0.6522166119287909, 0.6646337847447196, 0.6122179731371418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 228}], {
             RGBColor[
             0.3889928994532643, 0.5113478309799768, 0.946007261473615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 231}], {
             RGBColor[
             0.29145473297171365`, 0.41969373436096236`, 0.9400547972751598]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 245}], {
             RGBColor[
             0.2884856169676899, 0.4165730051879058, 0.9398857105111442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 264}], {
             RGBColor[
             0.32396934415914475`, 0.453868652264371, 0.9419064562812274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 204}], {
             RGBColor[
             0.38548007982804805`, 0.5055047110221348, 0.9460830998243401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 206}], {
             RGBColor[
             0.2548872111619892, 0.3852329980868062, 0.9378268216526131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 254}], {
             RGBColor[
             0.30306682721859113`, 0.43494494762898417`, 0.9406045538059649]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 283}], {
             RGBColor[
             0.29658629715284524`, 0.4290613813379507, 0.9402015229115228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 287}], {
             RGBColor[
             0.2651763885560936, 0.39604757589953593`, 0.9384127750837334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 158}], {
             RGBColor[
             0.189227738636957, 0.3162207294119929, 0.9340876118267976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 196}], {
             RGBColor[
             0.1942847722586868, 0.32153599238288155`, 0.9343756024103442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 207}], {
             RGBColor[
             0.18539878883552113`, 0.3121962604012447, 0.9338695588000294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 212}], {
             RGBColor[
             0.20943922968905518`, 0.3374642879902957, 0.935238626341993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 214}], {
             RGBColor[
             0.19317010459047246`, 0.32036440598957616`, 0.9343121237356424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 225}], {
             RGBColor[
             0.20655322702626136`, 0.33443091620856197`, 0.9350742727598051]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 265}], {
             RGBColor[
             0.2041128319271811, 0.33186590622944256`, 0.9349352958691536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 276}], {
             RGBColor[
             0.21344183559868857`, 0.34167128058119267`, 0.9354665688272218]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 166}], {
             RGBColor[
             0.18740769372755933`, 0.31430774681470364`, 0.9339839629617225]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.18622253645749176`, 0.31306207138055164`, 0.9339164700084752]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 234}], {
             RGBColor[
             0.19143808005152518`, 0.3185439383824441, 0.9342134875004501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 239}], {
             RGBColor[
             0.213148543369447, 0.34136301185245843`, 0.9354498662686535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 263}], {
             RGBColor[
             0.19930513416780576`, 0.32681271105869525`, 0.9346615045941087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 285}], {
             RGBColor[
             0.19420033164892994`, 0.32144723994818314`, 0.9343707936425373]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 122}], {
             RGBColor[
             0.18294597115910344`, 0.30961819350570674`, 0.933729874461976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 161}], {
             RGBColor[
             0.191253116488521, 0.3183495299503595, 0.9342029540991661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 244}], {
             RGBColor[
             0.18517767786647377`, 0.3119638587535308, 0.9338569668574466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 266}], {
             RGBColor[
             0.1895006672172379, 0.3165075946545396, 0.9341031547056828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 131}], {
             RGBColor[
             0.2542490675591432, 0.38456226869957383`, 0.93779048031848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 141}], {
             RGBColor[
             0.28646903998749706`, 0.4184275025860159, 0.939625360083097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 170}], {
             RGBColor[
             0.23833338730926568`, 0.3678338796445412, 0.9368841058733883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 178}], {
             RGBColor[
             0.2690508208241996, 0.4001198498665095, 0.9386334182696933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 182}], {
             RGBColor[
             0.2667169591353605, 0.3976668132561618, 0.9385005082991529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 188}], {
             RGBColor[
             0.317477361422549, 0.44666279511939655`, 0.9415507479684607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 190}], {
             RGBColor[
             0.24175240008128845`, 0.37142747884586735`, 0.937078813592779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 261}], {
             RGBColor[
             0.2619133763504623, 0.3926179431844944, 0.9382269513658168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 284}], {
             RGBColor[
             0.26002401193692654`, 0.39063210139324567`, 0.9381193548575302]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 294}], {
             RGBColor[
             0.40756986398437334`, 0.5224500406559134, 0.9479120363171062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 135}], {
             RGBColor[
             0.21926297732246688`, 0.3477896696145861, 0.9357980742367835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 154}], {
             RGBColor[
             0.3613735298324199, 0.47852983599420473`, 0.9448593103869043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 173}], {
             RGBColor[
             0.21336819471978227`, 0.34159387934836083`, 0.9354623750881099]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.21391225518849333`, 0.3421657213964022, 0.9354933585269378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 234}], {
             RGBColor[
             0.20980230497718771`, 0.3378459031384259, 0.9352593029425303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 239}], {
             RGBColor[
             0.2315127682951095, 0.3606649766084402, 0.9364956817107337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 249}], {
             RGBColor[
             0.21645306950395798`, 0.3448362783388877, 0.9356380541434055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 255}], {
             RGBColor[
             0.295733658786952, 0.42287002848225363`, 0.9403468487457121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 258}], {
             RGBColor[
             0.28280548262609156`, 0.41167229208074363`, 0.9395230767926794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 263}], {
             RGBColor[
             0.2176693590934683, 0.34611467581467703`, 0.935707320036189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 286}], {
             RGBColor[
             0.22317009351070355`, 0.3518962964538972, 0.9360205787236432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 138}], {
             RGBColor[
             0.2081640824318275, 0.3361240273739437, 0.9351660085921052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 161}], {
             RGBColor[
             0.19334750398760153`, 0.32055086400373023`, 0.9343222263688701]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 266}], {
             RGBColor[
             0.19159505471631844`, 0.31870892870791034`, 0.9342224269753869]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 189}], {
             RGBColor[
             0.2072195140090381, 0.335131226072495, 0.935112216817791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 257}], {
             RGBColor[
             0.19133948148967972`, 0.3184403050424346, 0.9342078724582165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 267}], {
             RGBColor[
             0.19740462411574278`, 0.32481515449468, 0.9345532733581963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 287}], {
             RGBColor[
             0.22080206667647367`, 0.3494073501095485, 0.9358857230986155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 300}], {
             RGBColor[
             0.21212454910682327`, 0.34028672895745476`, 0.9353915513102607]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 147}], {
             RGBColor[
             0.19966110992932296`, 0.3271868641542167, 0.9346817768871081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 247}], {
             RGBColor[
             0.191840440673128, 0.3189668449068855, 0.9342364013426112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 273}], {
             RGBColor[
             0.2124273089085979, 0.3406049487052001, 0.9354087930330789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 289}], {
             RGBColor[
             0.2146845283282537, 0.3429774294312355, 0.9355373383397714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 128}], {
             RGBColor[
             0.8384430661867497, 0.296495829336185, 0.18444642963665195`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 130}], {
             RGBColor[
             0.8607307087477495, 0.4103624865662075, 0.20352137280561344`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 142}], {
             RGBColor[
             0.8334415120439743, 0.25805169249981336`, 0.1796569357410828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.8552975837103799, 0.3871468134192908, 0.19906309946450382`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 150}], {
             RGBColor[
             0.8592661193941853, 0.40455587782479563`, 0.20234292983340507`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 167}], {
             RGBColor[
             0.859356989051198, 0.4049161457343329, 0.20241604569242247`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 237}], {
             RGBColor[
             0.8318212025230813, 0.24559728349806995`, 0.17810532551399777`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 243}], {
             RGBColor[
             0.8859354840896285, 0.5107054174164098, 0.4069530416143843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 256}], {
             RGBColor[
             0.8294390160964316, 0.2272867547420918, 0.17582414110154324`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 269}], {
             RGBColor[
             0.881184613963798, 0.48806415416592097`, 0.23764075645846794`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 277}], {
             RGBColor[
             0.8878000437756458, 0.5101704610030093, 0.28112006653243526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 281}], {
             RGBColor[
             0.8829501729358756, 0.5088362266550703, 0.4280047531480473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 293}], {
             RGBColor[
             0.8567159034897515, 0.39358707228041634`, 0.20024658025461053`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 153}], {
             RGBColor[
             0.2222787641449363, 0.35095945277692997`, 0.9359698188348664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 157}], {
             RGBColor[
             0.20301322621103607`, 0.33071015090274497`, 0.93487267495034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 192}], {
             RGBColor[
             0.2770528278061131, 0.40650831596386994`, 0.939163161568517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 220}], {
             RGBColor[
             0.27828890051671973`, 0.40757894001897654`, 0.9392419230286206]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 222}], {
             RGBColor[
             0.22245696617283922`, 0.3511467544069171, 0.9359799671767292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 239}], {
             RGBColor[
             0.2305322261132995, 0.35963436460539283`, 0.9364398412840619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 248}], {
             RGBColor[
             0.22272354417989754`, 0.3514269447943572, 0.9359951483998643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 285}], {
             RGBColor[
             0.21158401439278246`, 0.3397185927011176, 0.9353607686579457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 145}], {
             RGBColor[
             0.6068695545086966, 0.6858400847036329, 0.9652124739672545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 148}], {
             RGBColor[
             0.29756624946408855`, 0.42638484862682313`, 0.9403930437729009]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 156}], {
             RGBColor[
             0.3716633849526351, 0.49633787652625627`, 0.9449030401335229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 159}], {
             RGBColor[
             0.3200380232724909, 0.45000410769220556`, 0.9416727780472791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 168}], {
             RGBColor[
             0.3746233333290345, 0.4989016350385623, 0.9450916454266876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 191}], {
             RGBColor[
             0.28810597904486807`, 0.41644150460043405`, 0.9398542953677421]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 205}], {
             RGBColor[
             0.3605974794488338, 0.48675314536744607`, 0.9441979304200168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 212}], {
             RGBColor[
             0.2911019408470156, 0.4195904504094406, 0.9400249109602461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 225}], {
             RGBColor[
             0.28821593818422175`, 0.41655707862770686`, 0.9398605573780583]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 251}], {
             RGBColor[
             0.31722126846433096`, 0.4470435197962596, 0.9415123680279698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 269}], {
             RGBColor[
             0.6610000720463691, 0.698853165460656, 0.646849788175898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 276}], {
             RGBColor[
             0.29510454675664893`, 0.4237974430003376, 0.9402528534454749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 282}], {
             RGBColor[
             0.3947336965046049, 0.5163202208449985, 0.9463730599853389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 142}], {
             RGBColor[
             0.839938700425626, 0.30799192948729065`, 0.18587865067287715`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 149}], {
             RGBColor[
             0.8617947720920316, 0.43708705040676815`, 0.20528481439629814`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 150}], {
             RGBColor[
             0.865763307775837, 0.454496114812273, 0.2085646447651994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 197}], {
             RGBColor[
             0.8920740737202894, 0.5604973646047849, 0.4191176658739154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 198}], {
             RGBColor[
             0.8848238567439902, 0.5553282615018976, 0.4420528553197187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 237}], {
             RGBColor[
             0.838318390904733, 0.29553752048554727`, 0.1843270404457921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 243}], {
             RGBColor[
             0.8924326724712802, 0.5606456544038871, 0.4131747565461786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 256}], {
             RGBColor[
             0.8359362044780833, 0.2772269917295691, 0.18204585603333756`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 269}], {
             RGBColor[
             0.8876818023454497, 0.5380043911533983, 0.24386247139026226`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 277}], {
             RGBColor[
             0.8942972321572974, 0.5601106979904866, 0.2873417814642296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 281}], {
             RGBColor[
             0.8894473613175273, 0.5587764636425476, 0.4342264680798416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 165}], {
             RGBColor[
             0.20344097121398075`, 0.33115973802143944`, 0.9348970343954657]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 175}], {
             RGBColor[
             0.18584814501363772`, 0.3126685622352725, 0.9338951489696101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 183}], {
             RGBColor[
             0.1909140048229797, 0.31799310208895415`, 0.9341836421914842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 184}], {
             RGBColor[
             0.19028873719925032`, 0.31733590617215746`, 0.9341480341253134]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 224}], {
             RGBColor[
             0.19887770973958555`, 0.32636346088436186`, 0.9346371634052393]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 253}], {
             RGBColor[
             0.19046881652676248`, 0.3175251809630616, 0.9341582893766117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 140}], {
             RGBColor[
             0.8488137274171336, 0.3187633460045766, 0.19210965802511026`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 162}], {
             RGBColor[
             0.9515757296113414, 0.8393631712246421, 0.5204689724050278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 167}], {
             RGBColor[
             0.9097426027065735, 0.6798665267659179, 0.24623498340554434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 201}], {
             RGBColor[
             0.8675104556731318, 0.4624745923387423, 0.2100136661179885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 202}], {
             RGBColor[
             0.8816482178398845, 0.5540191449102804, 0.2228814513408511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 203}], {
             RGBColor[
             0.92446413705714, 0.8203323074950271, 0.6196039862679017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 216}], {
             RGBColor[
             0.8815768726528278, 0.553695183078948, 0.2228219191679405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 237}], {
             RGBColor[
             0.8539841698020644, 0.35850563187745466`, 0.19706087949209944`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 269}], {
             RGBColor[
             0.9424840400754735, 0.8045885394133, 0.29907204955461253`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 281}], {
             RGBColor[
             0.9451323785335899, 0.8357466481470239, 0.5846180445889815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 293}], {
             RGBColor[
             0.9057809743644036, 0.6628729165850431, 0.24298078524882644`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 294}], {
             RGBColor[
             0.723926300807685, 0.6611320656306849, 0.6022559472314186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 299}], {
             RGBColor[
             0.849730326606493, 0.32580872903031854`, 0.19298739444399152`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 141}], {
             RGBColor[
             0.26162779894186294`, 0.392317783221403, 0.938210688154871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 146}], {
             RGBColor[
             0.2147184255833614, 0.3430130575955638, 0.9355392687383033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 170}], {
             RGBColor[
             0.21349214626363155`, 0.34172416027992825`, 0.9354694339451624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 178}], {
             RGBColor[
             0.2442095797785655, 0.3740101305018966, 0.9372187463414672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 182}], {
             RGBColor[
             0.24187571808972635`, 0.3715570938915489, 0.9370858363709268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 188}], {
             RGBColor[
             0.2926361203769149, 0.4205530757547836, 0.9401360760402346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 190}], {
             RGBColor[
             0.21691115903565433`, 0.3453177594812544, 0.9356641416645529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 199}], {
             RGBColor[
             0.21390129447571837`, 0.3421542009923264, 0.9354927343305601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 261}], {
             RGBColor[
             0.23707213530482818`, 0.36650822381988146`, 0.9368122794375908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 284}], {
             RGBColor[
             0.23518277089129241`, 0.36452238202863274`, 0.9367046829293041]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 133}], {
             RGBColor[
             0.19109281456444907`, 0.3181810424644308, 0.9341938251417357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 146}], {
             RGBColor[
             0.19846266788634026`, 0.3259272255814276, 0.9346135273856964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 236}], {
             RGBColor[
             0.21416362323535532`, 0.3424299251513089, 0.9355076735653408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 260}], {
             RGBColor[
             0.2275319348126233, 0.35648086821892655`, 0.9362689791330215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 267}], {
             RGBColor[
             0.19655119281637518`, 0.32391814408837505`, 0.9345046717082358]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 146}], {
             RGBColor[
             0.19265917133132254`, 0.3198273827391699, 0.9342830268423918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 170}], {
             RGBColor[
             0.1914328920115927, 0.3185384854235343, 0.9342131920492509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 144}], {
             RGBColor[
             0.22121948408189393`, 0.34984608226843733`, 0.9359094944023405]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 160}], {
             RGBColor[
             0.22028173175537732`, 0.3488604451163368, 0.9358560907946256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 169}], {
             RGBColor[
             0.42476901028009817`, 0.532311534169465, 0.9496393645496872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 176}], {
             RGBColor[
             0.21949584805110617`, 0.34803443151524305`, 0.9358113358802782]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 180}], {
             RGBColor[
             0.21984183187712564`, 0.34839808245303105`, 0.9358310391473328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 187}], {
             RGBColor[
             0.23476961577043198`, 0.36408812980106076`, 0.9366811543563793]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 193}], {
             RGBColor[
             0.26218140249464095`, 0.39289965565586527`, 0.9382422150582186]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 200}], {
             RGBColor[
             0.3051846864517926, 0.4328450374952205, 0.9408835556758889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 221}], {
             RGBColor[
             0.21549733286296777`, 0.343831738532004, 0.9355836263555868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 228}], {
             RGBColor[
             0.3355280602689666, 0.4591269427933443, 0.9428170086239273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 230}], {
             RGBColor[
             0.21844228820343148`, 0.34692707331578443`, 0.9357513372055553]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 245}], {
             RGBColor[
             0.2350207777833922, 0.3643521170012733, 0.9366954576614566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 264}], {
             RGBColor[
             0.27050450497484707`, 0.4016477640777385, 0.9387162034315397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 288}], {
             RGBColor[
             0.22683219740980134`, 0.35574539984264686`, 0.9362291301230996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 297}], {
             RGBColor[
             0.21839610407426302`, 0.3468785308677854, 0.9357487070877224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 158}], {
             RGBColor[
             0.20301108119461975`, 0.33070789635448955`, 0.9348725527948284]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 173}], {
             RGBColor[
             0.20718172638991203`, 0.3350915088889201, 0.9351100648687836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 186}], {
             RGBColor[
             0.20309625090443267`, 0.3307974151195744, 0.934877403083805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 213}], {
             RGBColor[
             0.20772578685862308`, 0.3356633509369615, 0.9351410483076115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 214}], {
             RGBColor[
             0.20695344714813524`, 0.3348515729320728, 0.9350970647036734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 249}], {
             RGBColor[
             0.21026660117408774`, 0.33833390787944695`, 0.9352857439240791]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 255}], {
             RGBColor[
             0.28954719045708177`, 0.4163676580228129, 0.9399945385263857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 263}], {
             RGBColor[
             0.21148289076359805`, 0.33961230535523634`, 0.9353550098168626]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 265}], {
             RGBColor[
             0.21789617448484386`, 0.3463530731719392, 0.9357202368371844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 276}], {
             RGBColor[
             0.22722517815635135`, 0.3561584475236893, 0.9362515097952526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 286}], {
             RGBColor[
             0.2169836251808333, 0.34539392599445645`, 0.9356682685043168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 177}], {
             RGBColor[
             0.34229360740819775`, 0.46934835455154167`, 0.9430884098094023]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 194}], {
             RGBColor[
             0.539310518839214, 0.6345587760249104, 0.957788184762517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 197}], {
             RGBColor[
             0.689478603616865, 0.751552751257122, 0.9111273992783655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 204}], {
             RGBColor[
             0.4381119186941594, 0.553069802846105, 0.9493643283826801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 210}], {
             RGBColor[
             0.43214727310106515`, 0.5482274348494092, 0.9488947696323751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 226}], {
             RGBColor[
             0.6894363159019072, 0.7515352642002422, 0.911828216152313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 252}], {
             RGBColor[
             0.3152788883487585, 0.44095417198795417`, 0.9415499615236627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 279}], {
             RGBColor[
             0.3146411108912604, 0.44028382744269734`, 0.9415136410409652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 280}], {
             RGBColor[
             0.32731420410911033`, 0.4536040519351767, 0.9422353549515605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 147}], {
             RGBColor[
             0.23746595794531072`, 0.3669221563848262, 0.9368347070543579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 156}], {
             RGBColor[
             0.32801284307365003`, 0.4541649141300481, 0.9422814923217423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 179}], {
             RGBColor[
             0.3921454633437752, 0.5078279411583735, 0.9468889147894293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 191}], {
             RGBColor[
             0.24445543716588297`, 0.3742685422042259, 0.9372327475559615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 217}], {
             RGBColor[
             0.23078620352350526`, 0.3599013109666169, 0.9364543049218471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 247}], {
             RGBColor[
             0.22964528868911577`, 0.358702137137495, 0.9363893315098609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 251}], {
             RGBColor[
             0.27357072658534587`, 0.4048705574000514, 0.9388908202161892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 270}], {
             RGBColor[
             0.23718665422901314`, 0.36662859047011903`, 0.9368188011209075]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 271}], {
             RGBColor[
             0.24208469003989352`, 0.37177673666076144`, 0.9370977370143425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 273}], {
             RGBColor[
             0.25023215692458567`, 0.3803402409358096, 0.9375617232003286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 278}], {
             RGBColor[
             0.23108207251171536`, 0.3602122880324031, 0.9364711542230267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 289}], {
             RGBColor[
             0.25248937634424146`, 0.382712721661845, 0.9376902685070212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 295}], {
             RGBColor[
             0.2292284865221631, 0.35826405163324404`, 0.9363655952430565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 210}], {
             RGBColor[
             0.35148342859896836`, 0.4711989277702072, 0.9440171598227016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 211}], {
             RGBColor[
             0.25101026684268113`, 0.38115808379474614`, 0.9376060354090536]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 231}], {
             RGBColor[
             0.23123426787294182`, 0.3603722550067954, 0.9364798215236958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 266}], {
             RGBColor[
             0.21471877848996196`, 0.3430134285227765, 0.935539288835812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 143}], {
             RGBColor[
             0.37380885559171856`, 0.49802499695333824`, 0.9450460153054621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 163}], {
             RGBColor[
             0.5309367698880918, 0.6297354344441368, 0.9563109238850767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 235}], {
             RGBColor[
             0.42460849977243, 0.5421962738843169, 0.9482766560323135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 273}], {
             RGBColor[
             0.3398266519904991, 0.46230754637230465`, 0.9431107790825377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 274}], {
             RGBColor[
             0.4518848560948061, 0.5655575295786147, 0.9500876676545675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 298}], {
             RGBColor[
             0.350430471977903, 0.4734528335000848, 0.9437146509438744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 162}], {
             RGBColor[
             0.8753287589904273, 0.41964810147851817`, 0.3738269902449083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 167}], {
             RGBColor[
             0.847440007720582, 0.31331700517270195`, 0.1910043309119193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 181}], {
             RGBColor[
             0.8736439880136796, 0.4112274879198171, 0.24323035592583006`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 201}], {
             RGBColor[
             0.8266673641279991, 0.20598262316708282`, 0.17317000404643912`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 202}], {
             RGBColor[
             0.8337362452113755, 0.25175489945285184`, 0.1796038966578704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 203}], {
             RGBColor[
             0.8572543639542931, 0.40696085899210804`, 0.43991699948682417`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 216}], {
             RGBColor[
             0.8337005726178471, 0.2515929185371857, 0.1795741305714151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 237}], {
             RGBColor[
             0.8199042211924654, 0.15399814293643901`, 0.1666936107334946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 269}], {
             RGBColor[
             0.8692676326331821, 0.39646501360429004`, 0.22622904167796476`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 293}], {
             RGBColor[
             0.8447989221591355, 0.30198793171878546`, 0.18883486547410736`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 299}], {
             RGBColor[
             0.8177772995946797, 0.13764969151287093`, 0.16465686820944062`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 146}], {
             RGBColor[
             0.24693839801171524`, 0.3768782914820059, 0.9373741485029203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 178}], {
             RGBColor[
             0.27642955220691934`, 0.4078753643883386, 0.9390536261060842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 182}], {
             RGBColor[
             0.2740956905180802, 0.4054223277779909, 0.9389207161355438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 188}], {
             RGBColor[
             0.3248560928052687, 0.45441830964122576`, 0.9419709558048517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 236}], {
             RGBColor[
             0.2626393533607303, 0.39338099105188706`, 0.9382682946825648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 261}], {
             RGBColor[
             0.269292107733182, 0.4003734577063236, 0.9386471592022079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 294}], {
             RGBColor[
             0.41494859536709305`, 0.5302055551777425, 0.9483322441534972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 149}], {
             RGBColor[
             0.8517916638064809, 0.3601987767340248, 0.1957058266051599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[
             0.8557601994902863, 0.3776078411395296, 0.19898565697406115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 163}], {
             RGBColor[
             0.7603405238297619, 0.3885080681094508, 0.43863923535829075`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 197}], {
             RGBColor[
             0.8820709654347386, 0.4836090909320415, 0.4095386780827771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 198}], {
             RGBColor[
             0.8748207484584395, 0.4784399878291542, 0.43247386752858047`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 243}], {
             RGBColor[
             0.8824295641857295, 0.48375738073114377`, 0.40359576875504033`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 256}], {
             RGBColor[
             0.8259330961925325, 0.20033871805682574`, 0.1724668682421993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 277}], {
             RGBColor[
             0.8842941238717467, 0.48322242431774326`, 0.2777627936730913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 163}], {
             RGBColor[
             0.4640224729127619, 0.5716064552084593, 0.95205347173178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 174}], {
             RGBColor[
             0.27004966377854045`, 0.4011696971418227, 0.9386903008982872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 185}], {
             RGBColor[
             0.41822549913320267`, 0.5344264087640556, 0.9484481661960105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 235}], {
             RGBColor[
             0.3576942027971, 0.4840672946486393, 0.9440192038790169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 298}], {
             RGBColor[
             0.28351617500257303`, 0.41532385426440727`, 0.9394571987905778]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 160}], {
             RGBColor[
             0.19670215780285202`, 0.3240768178608952, 0.934513268940883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 176}], {
             RGBColor[
             0.19591627409858087`, 0.32325080425980146`, 0.9344685140265354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 221}], {
             RGBColor[
             0.19191775891044247`, 0.3190481112765624, 0.9342408045018441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 230}], {
             RGBColor[
             0.19486271425090618`, 0.32214344606034284`, 0.9344085153518125]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 231}], {
             RGBColor[
             0.21441031983489064`, 0.34268921891888826`, 0.9355217225717294]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 232}], {
             RGBColor[
             0.19277383312180774`, 0.31994789955094727`, 0.9342895566617331]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 240}], {
             RGBColor[
             0.18908519234139687`, 0.31607090421740214`, 0.9340794940261437]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 245}], {
             RGBColor[
             0.2114412038308669, 0.3395684897458317, 0.9353526358077138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 264}], {
             RGBColor[
             0.24692493102232177`, 0.3768641368222969, 0.9373733815777969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 288}], {
             RGBColor[
             0.20325262345727604`, 0.33096177258720527`, 0.9348863082693568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 297}], {
             RGBColor[
             0.19481653012173772`, 0.32209490361234383`, 0.9344058852339796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 156}], {
             RGBColor[
             0.6296976932681398, 0.7056126711214472, 0.9666670627828757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 159}], {
             RGBColor[
             0.5780723315879956, 0.6592789022873965, 0.963436800696632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 167}], {
             RGBColor[
             0.8862929429929738, 0.7834059474084649, 0.6157767446761826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 168}], {
             RGBColor[
             0.6326576416445393, 0.7081764296337532, 0.9668556680760403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 201}], {
             RGBColor[
             0.8518773491973987, 0.5315008727671069, 0.456374840298414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 203}], {
             RGBColor[
             0.9010144773435402, 0.923871728137574, 0.9891457475385399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 205}], {
             RGBColor[
             0.6186317877643385, 0.696027939962637, 0.9659619530693695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 216}], {
             RGBColor[
             0.8659437661770946, 0.6227214635073127, 0.46918309334836605`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 237}], {
             RGBColor[
             0.8383510633263312, 0.42753191230581933`, 0.44342205367252496`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 269}], {
             RGBColor[
             0.9190343803618738, 0.908127960055847, 0.6686138108252507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 277}], {
             RGBColor[
             0.9289575250796454, 0.9412874203114796, 0.7338327759362018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 282}], {
             RGBColor[
             0.6527680048201097, 0.7255950154401895, 0.9681370826346918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 293}], {
             RGBColor[
             0.8823313146508039, 0.7664123372275902, 0.6125225465194646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 170}], {
             RGBColor[
             0.19880274533348388`, 0.3262846685405311, 0.9346328942932117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 236}], {
             RGBColor[
             0.2157299800022288, 0.3440762654260479, 0.9355968752659971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 247}], {
             RGBColor[
             0.2055770841992048, 0.33340492820629564`, 0.9350186828698783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 273}], {
             RGBColor[
             0.22616395243467474`, 0.35504303200461024`, 0.9361910745603459]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 289}], {
             RGBColor[
             0.22842117185433053`, 0.35741551273064565`, 0.9363196198670385]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 156}], {
             RGBColor[
             0.32039438822353183`, 0.44615743504463745`, 0.9418476325885221]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 159}], {
             RGBColor[
             0.26876902654338763`, 0.39982366621058674`, 0.9386173705022783]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 168}], {
             RGBColor[
             0.32335433659993124`, 0.4487211935569434, 0.9420362378816867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 191}], {
             RGBColor[
             0.23683698231576478`, 0.36626106311881523`, 0.9367988878227413]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 205}], {
             RGBColor[
             0.3093284827197305, 0.43657270388582725`, 0.9411425228750159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 217}], {
             RGBColor[
             0.22316774867338707`, 0.35189383188120626`, 0.9360204451886269]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 225}], {
             RGBColor[
             0.23694694145511846`, 0.36637663714608804`, 0.9368051498330575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 251}], {
             RGBColor[
             0.26595227173522773`, 0.39686307831464074`, 0.9384569604829689]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 270}], {
             RGBColor[
             0.22956819937889494`, 0.35862111138470837`, 0.9363849413876872]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 271}], {
             RGBColor[
             0.23446623518977533`, 0.3637692575753508, 0.9366638772811222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 278}], {
             RGBColor[
             0.2234636176615972, 0.35220480894699246`, 0.9360372944898065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.3434646997755016, 0.4661397793633797, 0.9433176524403382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 295}], {
             RGBColor[
             0.2216100316720449, 0.3502565725478334, 0.9359317355098362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 150}], {
             RGBColor[
             0.901456610665, 0.644502615181237, 0.23943789960535378`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.9409227595816787, 0.803504489870005, 0.5552674312684278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 198}], {
             RGBColor[
             0.93004743411723, 0.7957508352156739, 0.5896702154371328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 243}], {
             RGBColor[
             0.9414606577081649, 0.8037269245686582, 0.5463530672768225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 256}], {
             RGBColor[
             0.8437866719113953, 0.2986689012185817, 0.18804023732608074`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 277}], {
             RGBColor[
             0.9442574972371908, 0.8029244899485575, 0.3576036046538991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 281}], {
             RGBColor[
             0.9369826909775356, 0.800923138426649, 0.5779306345773171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 179}], {
             RGBColor[
             0.7150830892215184, 0.6470263643951079, 0.5999650595216117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 237}], {
             RGBColor[
             0.8525195804485002, 0.35269902313604284`, 0.19588243651989107`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 256}], {
             RGBColor[
             0.8477552075952007, 0.3160779656240866, 0.191320067694982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 269}], {
             RGBColor[
             0.9402871560451271, 0.7958786263011822, 0.2973043850963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 274}], {
             RGBColor[
             0.6852279869066359, 0.622788647378854, 0.5976147565045411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 277}], {
             RGBColor[
             0.9502103007628988, 0.8290380865568148, 0.362523350207251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 281}], {
             RGBColor[
             0.9429354945032435, 0.8270367350349062, 0.582850380130669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 293}], {
             RGBColor[
             0.9035840903340573, 0.6541630034729253, 0.24121312079051388`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 154}], {
             RGBColor[
             0.5475628360948273, 0.6435752036232633, 0.9575252987275946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 181}], {
             RGBColor[
             0.7920610111090953, 0.8249056195457978, 0.6813687144574905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 192}], {
             RGBColor[
             0.4642226762503304, 0.5725842955959759, 0.9518849903358793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 220}], {
             RGBColor[
             0.46545874896093703`, 0.5736549196510825, 0.9519637517959829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 239}], {
             RGBColor[
             0.41770207455751684`, 0.5257103442374987, 0.9491616700514242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 258}], {
             RGBColor[
             0.4689947888884989, 0.5767176597098022, 0.9521890651333698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 208}], {
             RGBColor[
             0.1859180316496269, 0.31274201752076575`, 0.9338991289101417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 242}], {
             RGBColor[
             0.1817008098525566, 0.3083094500247394, 0.9336589643676192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 244}], {
             RGBColor[
             0.1860116480511821, 0.312840414294423, 0.9339044602257174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 268}], {
             RGBColor[
             0.1937845276020504, 0.3210102035314135, 0.9343471142171944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 157}], {
             RGBColor[
             0.2018036290672552, 0.32943878761174283`, 0.9348037901824403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 192}], {
             RGBColor[
             0.2758432306623323, 0.4052369526728678, 0.9390942768006172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 220}], {
             RGBColor[
             0.27707930337293885`, 0.40630757672797435`, 0.9391730382607208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 222}], {
             RGBColor[
             0.2212473690290584, 0.3498753911159149, 0.9359110824088295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 239}], {
             RGBColor[
             0.22932262896951866`, 0.3583630013143907, 0.9363709565161622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 248}], {
             RGBColor[
             0.2215139470361167, 0.3501555815033551, 0.9359262636319645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 285}], {
             RGBColor[
             0.21037441724900163`, 0.3384472294101154, 0.9352918838900459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 181}], {
             RGBColor[
             0.7417957890267707, 0.7840980478369171, 0.6774116520475943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[
             0.7172113529376909, 0.7776981044453534, 0.9724416173890855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 216}], {
             RGBColor[
             0.7434083499065284, 0.5252723810458323, 0.4580470065820631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 255}], {
             RGBColor[
             0.43165774296703474`, 0.5471078244024314, 0.9490557746765065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 258}], {
             RGBColor[
             0.4187295668061743, 0.5359100880009214, 0.9482320027234739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 162}], {
             RGBColor[
             0.9588310572734952, 0.8681281277104613, 0.5263067793464253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 194}], {
             RGBColor[
             0.8061596900222359, 0.7500989808439875, 0.6144534337056413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 210}], {
             RGBColor[
             0.698996444284087, 0.6637676396684864, 0.6055600185754992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 218}], {
             RGBColor[
             0.9467517036363646, 0.8603082831521655, 0.5999961337585191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 226}], {
             RGBColor[
             0.9562854870849291, 0.8670754690193194, 0.5684934650954372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 227}], {
             RGBColor[
             0.9395091625151377, 0.7978810172888317, 0.27018585613847523`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 241}], {
             RGBColor[
             0.9562190222247212, 0.8670479840915544, 0.569594959834627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 290}], {
             RGBColor[
             0.9363623874102649, 0.7854051025986525, 0.2676538870247894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 291}], {
             RGBColor[
             0.9265943306289632, 0.845047396157727, 0.6262279650717502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.8545672117145955, 0.3449853666875312, 0.19687926573825648`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 159}], {
             RGBColor[
             0.3428661620319342, 0.4697766941100199, 0.9431273668629003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 168}], {
             RGBColor[
             0.3974514720884778, 0.5186742214563766, 0.9465462342423088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.4586241439822036, 0.5697734899723961, 0.9509650514168311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 191}], {
             RGBColor[
             0.31093411780431135`, 0.4362140910182484, 0.9413088841833633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 205}], {
             RGBColor[
             0.38342561820827703`, 0.5065257317852604, 0.945652519235638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 251}], {
             RGBColor[
             0.3400494072237743, 0.46681610621407393`, 0.942966956843591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 269}], {
             RGBColor[
             0.6838282108058124, 0.7186257518784704, 0.6483043769915192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 270}], {
             RGBColor[
             0.3036653348674415, 0.42857413928414156`, 0.9408949377483093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 271}], {
             RGBColor[
             0.3085633706783219, 0.433722285474784, 0.9411738736417443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 277}], {
             RGBColor[
             0.6937513555235839, 0.7517852121341029, 0.7135233421024703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 282}], {
             RGBColor[
             0.41756183526404816`, 0.5360928072628128, 0.9478276488009602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 171}], {
             RGBColor[
             0.1808430925709541, 0.30740793477935857`, 0.9336101186373109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 184}], {
             RGBColor[
             0.18701393581723674`, 0.31389388228526116`, 0.9339615390312422]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 222}], {
             RGBColor[
             0.20198183109515816`, 0.32962608924173, 0.9348139385243031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 248}], {
             RGBColor[
             0.20224840910221648`, 0.3299062796291701, 0.9348291197474383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 275}], {
             RGBColor[
             0.18135642915031058`, 0.30794748407168115`, 0.9336393523960919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 285}], {
             RGBColor[
             0.1911088793151014, 0.31819792753593046`, 0.9341947400055196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 186}], {
             RGBColor[
             0.19303082310645578`, 0.3202180123189185, 0.9343041918611762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 196}], {
             RGBColor[
             0.1980026870183727, 0.32544375652472224`, 0.9345873321557463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 207}], {
             RGBColor[
             0.189116703595207, 0.3161040245430854, 0.9340812885454315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 212}], {
             RGBColor[
             0.21315714444874106`, 0.34137205213213645`, 0.9354503560873951]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 214}], {
             RGBColor[
             0.19688801935015837`, 0.3242721701314169, 0.9345238534810445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 225}], {
             RGBColor[
             0.21027114178594725`, 0.3383386803504027, 0.9352860025052073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 265}], {
             RGBColor[
             0.20783074668686696`, 0.3357736703712833, 0.9351470256145558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 276}], {
             RGBColor[
             0.21715975035837445`, 0.34557904472303347`, 0.935678298572624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 168}], {
             RGBColor[
             0.3458261104083336, 0.4723404526223259, 0.943315972156065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 191}], {
             RGBColor[
             0.25930875612416715`, 0.38988032218419766`, 0.9380786220971196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 205}], {
             RGBColor[
             0.33180025652813283`, 0.4601919629512097, 0.9424222571493942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 212}], {
             RGBColor[
             0.2623047179263146, 0.3930292679932042, 0.9382492376896236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 225}], {
             RGBColor[
             0.2594187152635208, 0.38999589621147046`, 0.9380848841074358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 251}], {
             RGBColor[
             0.2884240455436301, 0.4204823373800232, 0.9397366947573472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 270}], {
             RGBColor[
             0.2520399731872973, 0.38224037045009085`, 0.9376646756620657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 271}], {
             RGBColor[
             0.2569380089981777, 0.38738851664073326`, 0.9379436115555007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 282}], {
             RGBColor[
             0.36593647358390397`, 0.4897590384287621, 0.9445973867147164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 176}], {
             RGBColor[
             0.19497852177206426`, 0.3222651671077009, 0.9344151104188206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 180}], {
             RGBColor[
             0.19532450559808373`, 0.32262881804548893`, 0.9344348136858753]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 193}], {
             RGBColor[
             0.23766407621559904`, 0.36713039124832314`, 0.9368459895967611]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 221}], {
             RGBColor[
             0.19098000658392586`, 0.31806247412446187`, 0.9341874008941293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 230}], {
             RGBColor[
             0.19392496192438957`, 0.3211578089082423, 0.9343551117440977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 232}], {
             RGBColor[
             0.19183608079529113`, 0.31896226239884673`, 0.9342361530540182]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 245}], {
             RGBColor[
             0.2105034515043503, 0.33858285259373117`, 0.935299232199999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 288}], {
             RGBColor[
             0.20231487113075944`, 0.32997613543510473`, 0.934832904661642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 296}], {
             RGBColor[
             0.1914857715941317, 0.31859406521754197`, 0.9342162034632482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 297}], {
             RGBColor[
             0.1938787777952211, 0.3211092664602433, 0.9343524816262648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 177}], {
             RGBColor[
             0.24681318446187503`, 0.3767466841021262, 0.9373670177764938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 244}], {
             RGBColor[
             0.19557921069497186`, 0.3228965292515542, 0.9344493187643406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 279}], {
             RGBColor[
             0.2191606879449377, 0.34768215699328187`, 0.9357922490080568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 280}], {
             RGBColor[
             0.2318337811627876, 0.36100238148576125`, 0.9365139629186521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 169}], {
             RGBColor[
             0.7980436197485294, 0.8403418316253028, 0.877535691789008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 181}], {
             RGBColor[
             0.9888211205061603, 0.9780593840975029, 0.5971500192561076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 202}], {
             RGBColor[
             0.9081632494131782, 0.6549039003842219, 0.40459878356064916`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 216}], {
             RGBColor[
             0.9080919042261215, 0.6545799385528897, 0.40453925138773855`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 227}], {
             RGBColor[
             0.9720263822129245, 0.9204431940139248, 0.5369240475267748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 228}], {
             RGBColor[
             0.7088026697373979, 0.7671572402491821, 0.8707133358632482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 299}], {
             RGBColor[
             0.8762453581797867, 0.42669348450426003`, 0.3747047266637896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 185}], {
             RGBColor[
             0.5753534134295759, 0.6661368462548543, 0.9597130747756251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 235}], {
             RGBColor[
             0.5148221170934733, 0.615777732139438, 0.9552841124586315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 274}], {
             RGBColor[
             0.5420984734158494, 0.6391389878337358, 0.9570951240808855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 292}], {
             RGBColor[
             0.6974329821497556, 0.7632343245346107, 0.9706993881593793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 298}], {
             RGBColor[
             0.44064408929894633`, 0.5470342917552059, 0.9507221073701924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 176}], {
             RGBColor[
             0.1880768897106564, 0.3150111142224146, 0.9340220726829731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 180}], {
             RGBColor[
             0.18842287353667586`, 0.3153747651602027, 0.9340417759500277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 187}], {
             RGBColor[
             0.2033506574299822, 0.3310648125082323, 0.9348918911590742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 221}], {
             RGBColor[
             0.184078374522518, 0.31080842123917557`, 0.9337943631582817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 230}], {
             RGBColor[
             0.1870233298629817, 0.313903756022956, 0.9339620740082502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 296}], {
             RGBColor[
             0.18458413953272382`, 0.31134001233225567`, 0.9338231657274008]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 297}], {
             RGBColor[
             0.18697714573381324`, 0.31385521357495705`, 0.9339594438904173]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 175}], {
             RGBColor[
             0.2002014223302363, 0.3277547667453615, 0.9347125468790196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 183}], {
             RGBColor[
             0.2052672821395783, 0.33307930659904317`, 0.9350010401008936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 224}], {
             RGBColor[
             0.21323098705618415`, 0.3414496653944509, 0.9354545613146487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 253}], {
             RGBColor[
             0.20482209384336109`, 0.3326113854731506, 0.9349756872860211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 262}], {
             RGBColor[
             0.26081704104435255`, 0.39146562526609985`, 0.9381645166920165]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 195}], {
             RGBColor[
             0.184909234384039, 0.31168170763319203`, 0.9338416793982484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 234}], {
             RGBColor[
             0.19012477797807242`, 0.3171635746350845, 0.9341386968902232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.21183524129599424`, 0.3399826481050988, 0.9353750756584267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 285}], {
             RGBColor[
             0.19288702957547718`, 0.3200668762008235, 0.9342960030323104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 168}], {
             RGBColor[
             0.6540467218133117, 0.5964674977433942, 0.5956559161356156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[
             0.8661367359765803, 0.45702825150686766`, 0.20890833900479755`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 202}], {
             RGBColor[
             0.8802744981433329, 0.5485728040784057, 0.22177612422766013`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.9224035575123126, 0.8121627962472151, 0.6179459955981152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 216}], {
             RGBColor[
             0.8802031529562763, 0.5482488422470734, 0.22171659205474953`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 237}], {
             RGBColor[
             0.8526104501055128, 0.35305929104558004`, 0.1959555523789085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 269}], {
             RGBColor[
             0.9404234605306463, 0.796419028165488, 0.2974140588848261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 277}], {
             RGBColor[
             0.9503466052484179, 0.8295784884211206, 0.3626330239957771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 282}], {
             RGBColor[
             0.674157084988882, 0.6138860835498305, 0.5969373306942671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 293}], {
             RGBColor[
             0.9037203948195764, 0.6547034053372311, 0.24132279457904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 203}], {
             RGBColor[
             0.6687682561638781, 0.7369332784725033, 0.9690249189979729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 205}], {
             RGBColor[
             0.3863855665846765, 0.5090894902975664, 0.9458411245288025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 212}], {
             RGBColor[
             0.31689002798285826`, 0.4419267953395609, 0.941668105069032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 225}], {
             RGBColor[
             0.31400402532006444`, 0.4388934235578272, 0.9415037514868442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 269}], {
             RGBColor[
             0.6867881591822118, 0.7211895103907764, 0.6484929822846838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 276}], {
             RGBColor[
             0.3208926338924916, 0.4461337879304579, 0.9418960475542608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 282}], {
             RGBColor[
             0.42052178364044757`, 0.5386565657751188, 0.9480162540941248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 293}], {
             RGBColor[
             0.650085093471142, 0.5794738875625195, 0.5924017179788976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 193}], {
             RGBColor[
             0.44215135474031986`, 0.5505814803014513, 0.9506292633518225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 200}], {
             RGBColor[
             0.4851546386974715, 0.5905268621408066, 0.9532706039694929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 202}], {
             RGBColor[
             0.7792934779313432, 0.5546715851773875, 0.4609259309301712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 227}], {
             RGBColor[
             0.7787217249901721, 0.7700947212036731, 0.6214147685810579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 228}], {
             RGBColor[
             0.5154980125146456, 0.6168087674389304, 0.9552040569175313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 264}], {
             RGBColor[
             0.450474457220526, 0.5593295887233245, 0.9511032517251437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 299}], {
             RGBColor[
             0.7473755866979517, 0.32646116929742564`, 0.43103187403331167`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 178}], {
             RGBColor[
             0.228293899528688, 0.35728174144686387`, 0.9363123718963757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 182}], {
             RGBColor[
             0.2259600378398488, 0.3548287048365162, 0.9361794619258352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 190}], {
             RGBColor[
             0.2009954787857768, 0.3285893704262217, 0.9347577672194614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 199}], {
             RGBColor[
             0.19798561422584082`, 0.3254258119372937, 0.9345863598854686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 261}], {
             RGBColor[
             0.22115645505495063`, 0.3497798347648488, 0.9359059049924991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 284}], {
             RGBColor[
             0.2192670906414149, 0.34779399297360003`, 0.9357983084842125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 184}], {
             RGBColor[
             0.1853189372548359, 0.31211233132706184`, 0.9338650113706392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 275}], {
             RGBColor[
             0.17966143058790973`, 0.3061659331134819, 0.9335428247354888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 285}], {
             RGBColor[
             0.18941388075270052`, 0.31641637657773114`, 0.9340982123449165]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 174}], {
             RGBColor[
             0.21189442021644855`, 0.34004484890265657`, 0.9353784458103991]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 238}], {
             RGBColor[
             0.18901379750666059`, 0.31599586371940025`, 0.9340754281959247]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 186}], {
             RGBColor[
             0.19720146830174806`, 0.32460162485334904`, 0.9345417039351314]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 213}], {
             RGBColor[
             0.20183100425593847`, 0.3294675606707361, 0.9348053491589379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 234}], {
             RGBColor[
             0.19772105404463286`, 0.3251477424127598, 0.9345712935745305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 249}], {
             RGBColor[
             0.20437181857140313`, 0.33213811761322165`, 0.9349500447754056]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 263}], {
             RGBColor[
             0.20558810816091344`, 0.33341651508901093`, 0.935019310668189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 286}], {
             RGBColor[
             0.2110888425781487, 0.3391981357282311, 0.9353325693556434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 235}], {
             RGBColor[
             0.3208493079592518, 0.4453409740728014, 0.9419209416251387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 238}], {
             RGBColor[
             0.21032414623090429`, 0.3383943913827284, 0.9352890210299346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 298}], {
             RGBColor[
             0.24667128016472487`, 0.3765975336885693, 0.9373589365366997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 183}], {
             RGBColor[
             0.18767445593923526`, 0.3145881308128762, 0.9339991546750381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 224}], {
             RGBColor[
             0.19563816085584113`, 0.3229584896082839, 0.9344526758887932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 253}], {
             RGBColor[
             0.18722926764301806`, 0.3141202096869836, 0.9339738018601655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 180}], {
             RGBColor[
             0.1945386218938126, 0.32180280444439524`, 0.9343900587715277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 187}], {
             RGBColor[
             0.20946640578711895`, 0.33749285179242483`, 0.9352401739805742]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 193}], {
             RGBColor[
             0.23687819251132788`, 0.36630437764722934`, 0.9368012346824135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 221}], {
             RGBColor[
             0.1901941228796547, 0.3172364605233681, 0.9341426459797817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 230}], {
             RGBColor[
             0.19313907822011844`, 0.32033179530714856`, 0.9343103568297502]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 245}], {
             RGBColor[
             0.20971756780007914`, 0.3377568389926374, 0.9352544772856515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 288}], {
             RGBColor[
             0.20152898742648828`, 0.32915012183401104`, 0.9347881497472945]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 296}], {
             RGBColor[
             0.19069988788986053`, 0.3177680516164482, 0.9341714485489008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 297}], {
             RGBColor[
             0.19309289409094996`, 0.3202832528591496, 0.9343077267119173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 194}], {
             RGBColor[
             0.4889886310377472, 0.5894215892292383, 0.9546385045000421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 226}], {
             RGBColor[
             0.6391144281004404, 0.7063980774045702, 0.908678535889838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 252}], {
             RGBColor[
             0.2649570005472917, 0.39581698519228203`, 0.9384002812611878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 268}], {
             RGBColor[
             0.24851062539069607`, 0.37853080214228807`, 0.9374636845262513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 279}], {
             RGBColor[
             0.2643192230897936, 0.3951466406470252, 0.9383639607784904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 280}], {
             RGBColor[
             0.27699231630764354`, 0.4084668651395046, 0.9390856746890857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 182}], {
             RGBColor[
             0.2566774713547828, 0.3871146750584845, 0.9379287743221401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 190}], {
             RGBColor[
             0.23171291230071078`, 0.36087534064819005`, 0.9365070796157662]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 199}], {
             RGBColor[
             0.2287030477407748, 0.357711782159262, 0.9363356722817735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 229}], {
             RGBColor[
             0.23836184028178953`, 0.36786378552268634`, 0.9368857262280812]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 261}], {
             RGBColor[
             0.2518738885698846, 0.38206580498681714`, 0.9376552173888041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 284}], {
             RGBColor[
             0.24998452415634886`, 0.38007996319556836`, 0.9375476208805174]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 205}], {
             RGBColor[
             0.44755823847840226`, 0.5601887588135859, 0.9502599417033248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 251}], {
             RGBColor[
             0.4041820274938994, 0.5204791332423994, 0.9475743793112779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 269}], {
             RGBColor[
             0.7479608310759376, 0.7722887789067958, 0.6529117994592061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 274}], {
             RGBColor[
             0.4929016619374462, 0.5991987999844676, 0.9532221708674471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 277}], {
             RGBColor[
             0.7578839757937091, 0.8054482391624284, 0.7181307645701571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 282}], {
             RGBColor[
             0.48169445553417334`, 0.5897558342911382, 0.9524350712686471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 289}], {
             RGBColor[
             0.383100677252795, 0.49832129750419296`, 0.9463738276021099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 187}], {
             RGBColor[
             0.20981238961313842`, 0.3378565027302129, 0.9352598772476289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 193}], {
             RGBColor[
             0.23722417633734735`, 0.3666680285850174, 0.9368209379494682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 215}], {
             RGBColor[
             0.2098131605219987, 0.33785731300430355`, 0.9352599211497481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 221}], {
             RGBColor[
             0.19054010670567417`, 0.3176001114611562, 0.9341623492468364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 230}], {
             RGBColor[
             0.1934850620461379, 0.3206954462449366, 0.9343300600968047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 233}], {
             RGBColor[
             0.20014010875548707`, 0.32769032229079487`, 0.9347090551616429]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 245}], {
             RGBColor[
             0.2100635516260986, 0.3381204899304254, 0.9352741805527061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 288}], {
             RGBColor[
             0.20187497125250775`, 0.32951377277179905`, 0.9348078530143491]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 296}], {
             RGBColor[
             0.19104587171588, 0.3181317025542363, 0.9341911518159554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 297}], {
             RGBColor[
             0.19343887791696943`, 0.3206469037969376, 0.9343274299789719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 201}], {
             RGBColor[
             0.8923407162696778, 0.5549387342539829, 0.2611343640187083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 202}], {
             RGBColor[
             0.9064784784364304, 0.6464832868255209, 0.2740021492415709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 203}], {
             RGBColor[
             0.961709527951959, 0.9590285203678879, 0.6962850331189814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 216}], {
             RGBColor[
             0.9064071332493737, 0.6461593249941886, 0.2739426170686603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 227}], {
             RGBColor[
             0.9694992257478029, 0.9078122736758734, 0.34102909604815745`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 258}], {
             RGBColor[
             0.6632277418204424, 0.717240503923456, 0.6720754184533696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 299}], {
             RGBColor[
             0.874560587203039, 0.4182728709455591, 0.2441080923447113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 190}], {
             RGBColor[
             0.22937905061187158`, 0.35842230403784237`, 0.9363741696452258]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 199}], {
             RGBColor[
             0.22636918605193562`, 0.35525874554891435`, 0.936202762311233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 229}], {
             RGBColor[
             0.23602797859295035`, 0.36541074891233866`, 0.9367528162575407]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 261}], {
             RGBColor[
             0.24954002688104543`, 0.37961276837646946`, 0.9375223074182637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 284}], {
             RGBColor[
             0.24765066246750966`, 0.3776269265852207, 0.937414710909977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 224}], {
             RGBColor[
             0.2007040206651831, 0.3282830294619655, 0.9347411691106672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 253}], {
             RGBColor[
             0.19229512745236005`, 0.31944474954066526`, 0.9342622950820396]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 222}], {
             RGBColor[
             0.2064576757790399, 0.33433048578943325`, 0.9350688312576314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 224}], {
             RGBColor[
             0.20007875304145373`, 0.32762583354516883`, 0.9347055610444963]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 248}], {
             RGBColor[
             0.20672425378609824`, 0.33461067617687346`, 0.9350840124807664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 275}], {
             RGBColor[
             0.18583227383419235`, 0.31265188061938454`, 0.9338942451294201]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 218}], {
             RGBColor[
             0.7483730046735189, 0.8020037075647066, 0.948265724399384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 235}], {
             RGBColor[
             0.4690251433139141, 0.5785976856950342, 0.951678806922862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 262}], {
             RGBColor[
             0.41669813660407123`, 0.5328210539055609, 0.9483611851595068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 292}], {
             RGBColor[
             0.6516360083701964, 0.726054278090207, 0.9670940826236099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 196}], {
             RGBColor[
             0.19808785672818557`, 0.32553327528980713`, 0.9345921824447229]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 214}], {
             RGBColor[
             0.19697318905997124`, 0.32436168889650174`, 0.9345287037700212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 249}], {
             RGBColor[
             0.20028634308592377`, 0.3278440238438759, 0.934717382990427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 265}], {
             RGBColor[
             0.2079159163966799, 0.33586318913636815`, 0.9351518759035322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 286}], {
             RGBColor[
             0.2070033670926693, 0.3349040419588854, 0.9350999075706646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 193}], {
             RGBColor[
             0.25215196023065367`, 0.38235807593304705`, 0.9376710531585147]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 215}], {
             RGBColor[
             0.224740944415305, 0.35354736035233314`, 0.9361100363587946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 228}], {
             RGBColor[
             0.32549861800497937`, 0.4485853630705261, 0.9422458467242234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 229}], {
             RGBColor[
             0.22122626051320093`, 0.3498532047273915, 0.9359098803100787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 230}], {
             RGBColor[
             0.20841284593944426`, 0.3363854935929662, 0.9351801753058513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 233}], {
             RGBColor[
             0.2150678926487934, 0.3433803696388245, 0.9355591703706895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 245}], {
             RGBColor[
             0.22499133551940492`, 0.35381053727845513`, 0.9361242957617526]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 288}], {
             RGBColor[
             0.2168027551458141, 0.3452038201198287, 0.9356579682233956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 296}], {
             RGBColor[
             0.20597365560918635`, 0.3338217499022659, 0.9350412670250019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 297}], {
             RGBColor[
             0.20836666181027574`, 0.33633695114496726`, 0.9351775451880184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 236}], {
             RGBColor[
             0.29364767479578224`, 0.42161628358526776`, 0.9401936825679285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 260}], {
             RGBColor[
             0.3070159863730502, 0.43566722665288543`, 0.9409549881356092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 261}], {
             RGBColor[
             0.30030042916823396`, 0.42860875023970424`, 0.9405725470875715]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 281}], {
             RGBColor[
             0.66716299452805, 0.7330554302274623, 0.9326197293964239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 294}], {
             RGBColor[
             0.445956916802145, 0.5584408477111231, 0.9502576320388609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 257}], {
             RGBColor[
             0.1999558217805158, 0.327496624995631, 0.9346985602910465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 260}], {
             RGBColor[
             0.23700170640282697`, 0.36643419857842796`, 0.936808268615812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 267}], {
             RGBColor[
             0.20602096440657885`, 0.33387147444787646`, 0.9350439611910263]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 287}], {
             RGBColor[
             0.22941840696730975`, 0.35846367006274493`, 0.9363764109314454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 300}], {
             RGBColor[
             0.22074088939765935`, 0.34934304891065115`, 0.9358822391430908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 199}], {
             RGBColor[
             0.2014046269978636, 0.3290194111386199, 0.9347810676048591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 261}], {
             RGBColor[
             0.2245754678269734, 0.353373433966175, 0.9361006127118898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 284}], {
             RGBColor[
             0.22268610341343767`, 0.3513875921749262, 0.9359930162036031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 205}], {
             RGBColor[
             0.29986821230051, 0.4266293598594382, 0.9406037744698572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 217}], {
             RGBColor[
             0.21370747825416658`, 0.3419504878548173, 0.9354816967834682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 225}], {
             RGBColor[
             0.22748667103589795`, 0.35643329311969896`, 0.9362664014278987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 246}], {
             RGBColor[
             0.2059132617802264, 0.3337582721588391, 0.9350378276857872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 251}], {
             RGBColor[
             0.25649200131600725`, 0.38691973428825177`, 0.9379182120778102]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 270}], {
             RGBColor[
             0.22010792895967446`, 0.34867776735831935`, 0.9358461929825286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 271}], {
             RGBColor[
             0.22500596477055484`, 0.35382591354896176`, 0.9361251288759636]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 278}], {
             RGBColor[
             0.21400334724237668`, 0.34226146492060344`, 0.9354985460846478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 282}], {
             RGBColor[
             0.3340044293562811, 0.4561964353369906, 0.9427789040351794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 295}], {
             RGBColor[
             0.21214976125282442`, 0.34031322852144436`, 0.9353929871046776]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 218}], {
             RGBColor[
             0.6489034320102649, 0.7179182155893853, 0.9413556495465901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 220}], {
             RGBColor[
             0.3318533670341157, 0.4618564399149144, 0.9423663809943715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 222}], {
             RGBColor[
             0.2760214326902352, 0.40542425430285495`, 0.93910442514248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 248}], {
             RGBColor[
             0.27628801069729353`, 0.4057044446902951, 0.9391196063656152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 262}], {
             RGBColor[
             0.31722856394081744`, 0.4487355619302395, 0.9414511103067129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 200}], {
             RGBColor[
             0.3225670309120143, 0.4511149836272068, 0.9418734544780243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 215}], {
             RGBColor[
             0.252152731139514, 0.38235888620713765`, 0.9376710970606339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 228}], {
             RGBColor[
             0.35291040472918833`, 0.4773968889253306, 0.9438069074260627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 230}], {
             RGBColor[
             0.2358246326636532, 0.3651970194477707, 0.9367412360076905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 245}], {
             RGBColor[
             0.2524031222436139, 0.38262206313325964`, 0.9376853564635919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 264}], {
             RGBColor[
             0.28788684943506876`, 0.4199177102097248, 0.939706102233675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 288}], {
             RGBColor[
             0.24421454187002306`, 0.3740153459746332, 0.9372190289252349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 210}], {
             RGBColor[
             0.5788422967306146, 0.6683006695271059, 0.9604448643230148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 226}], {
             RGBColor[
             0.8361313395314567, 0.8716084988779389, 0.9233783108429527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 241}], {
             RGBColor[
             0.8360648746712487, 0.8715810139501738, 0.9244798055821426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 280}], {
             RGBColor[
             0.4740092277386598, 0.5736772866128733, 0.9537854496422005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 290}], {
             RGBColor[
             0.8162082398567924, 0.7899381324572718, 0.622538732772305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 291}], {
             RGBColor[
             0.8064401830754907, 0.8495804260163464, 0.9811128108192658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 234}], {
             RGBColor[
             0.18893962070800485`, 0.3159178992009325, 0.934071203936976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 207}], {
             RGBColor[
             0.19417373721693681`, 0.32141928751397403`, 0.9343692791289782]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 212}], {
             RGBColor[
             0.2182141780704709, 0.3466873151030251, 0.9357383466709418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 214}], {
             RGBColor[
             0.20194505297188817`, 0.32958743310230554`, 0.9348118440645912]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 225}], {
             RGBColor[
             0.21532817540767707`, 0.3436539433212913, 0.935573993088754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 265}], {
             RGBColor[
             0.21288778030859679`, 0.34108893334217194`, 0.9354350161981024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 276}], {
             RGBColor[
             0.22221678398010425`, 0.35089430769392205`, 0.9359662891561706]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 198}], {
             RGBColor[
             0.9754663865596167, 0.9808663065126991, 0.9104194926535587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 204}], {
             RGBColor[
             0.7349750271013598, 0.7901370127560131, 0.9142536375891683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 226}], {
             RGBColor[
             0.9862994243091077, 0.9886024741101505, 0.8767175253588012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 243}], {
             RGBColor[
             0.9868796101505515, 0.9888423958656835, 0.8671023444932484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 254}], {
             RGBColor[
             0.6525617744919028, 0.7195772493628625, 0.9087750915707931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 283}], {
             RGBColor[
             0.646081244426157, 0.713693683071829, 0.9083720606763512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 204}], {
             RGBColor[
             0.7240997016369111, 0.7823833581016821, 0.9486564217578735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 226}], {
             RGBColor[
             0.975424098844659, 0.9808488194558194, 0.9111203095275062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 243}], {
             RGBColor[
             0.9760042846861029, 0.9810887412113525, 0.9015051286619535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 254}], {
             RGBColor[
             0.6416864490274542, 0.7118235947085315, 0.9431778757394982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 256}], {
             RGBColor[
             0.866815756563354, 0.4169101123137112, 0.4248082782495014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 283}], {
             RGBColor[
             0.6352059189617083, 0.705940028417498, 0.9427748448450561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 209}], {
             RGBColor[
             0.1894252090832627, 0.31642828337140966`, 0.9340988574765833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 229}], {
             RGBColor[
             0.20805355497894237`, 0.33600785601311617`, 0.9351597142171741]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 233}], {
             RGBColor[
             0.20189518711453486`, 0.32953502092454917`, 0.9348090042777849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 259}], {
             RGBColor[
             0.19177802866162308`, 0.31890124592564373`, 0.9342328470708863]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 261}], {
             RGBColor[
             0.22156560326703745`, 0.35020987547724697`, 0.9359292053778969]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 284}], {
             RGBColor[
             0.21967623885350168`, 0.3482240336859982, 0.9358216088696103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 210}], {
             RGBColor[
             0.4186246829308158, 0.5365148469090834, 0.9480331221442837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 211}], {
             RGBColor[
             0.31815152117452855`, 0.44647400293362227`, 0.9416219977306357]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 227}], {
             RGBColor[
             0.6591374011618665, 0.6706282245294286, 0.6126589597072597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 228}], {
             RGBColor[
             0.3959136886863399, 0.5173422707646859, 0.946448248043733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 231}], {
             RGBColor[
             0.2983755222047893, 0.4256881741456715, 0.9404957838452779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 245}], {
             RGBColor[
             0.2954064062007655, 0.4225674449726149, 0.9403266970812623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 264}], {
             RGBColor[
             0.3308901333922204, 0.45986309204908005`, 0.9423474428513454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 202}], {
             RGBColor[
             0.8524329734673737, 0.3954661457870175, 0.19750790475074864`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 203}], {
             RGBColor[
             0.8759510922102913, 0.5506721053262738, 0.4578210075797024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 216}], {
             RGBColor[
             0.8523973008738454, 0.3953041648713514, 0.19747813866429334`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 237}], {
             RGBColor[
             0.8386009494484636, 0.2977093892706047, 0.18459761882637282`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 269}], {
             RGBColor[
             0.8879643608891803, 0.5401762599384556, 0.244133049770843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 277}], {
             RGBColor[
             0.8945797907010281, 0.562282566775544, 0.2876123598448103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 293}], {
             RGBColor[
             0.8634956504151338, 0.4456991780529511, 0.2067388735669856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 299}], {
             RGBColor[
             0.8364740278506779, 0.2813609378470366, 0.18256087630231885`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 203}], {
             RGBColor[
             0.8900888543770439, 0.6422166578978118, 0.47068879280256504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 216}], {
             RGBColor[
             0.8665350630405979, 0.48684871744288943`, 0.21034592388715595`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 237}], {
             RGBColor[
             0.8527387116152162, 0.3892539418421428, 0.19746540404923543`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 269}], {
             RGBColor[
             0.902102123055933, 0.6317208125099938, 0.2570008349937056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 293}], {
             RGBColor[
             0.8776334125818863, 0.5372437306244892, 0.2196066587898482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 299}], {
             RGBColor[
             0.8506117900174305, 0.3729054904185747, 0.19542866152518146`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 216}], {
             RGBColor[
             0.8900175091899872, 0.6418926960664795, 0.4706292606296545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 237}], {
             RGBColor[
             0.8624248063392239, 0.4467031448649862, 0.4448682209538134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 255}], {
             RGBColor[
             0.651571481892223, 0.7220382969334023, 0.9679291557478935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 269}], {
             RGBColor[
             0.9551449948812127, 0.9368848088945971, 0.6707830617471834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 293}], {
             RGBColor[
             0.9184419291701429, 0.7951691860663403, 0.6146917974413972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 299}], {
             RGBColor[
             0.8581709631436525, 0.41400624201784997`, 0.4407947359057055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 226}], {
             RGBColor[
             0.734932739386402, 0.7901195256991334, 0.9149544544631159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 243}], {
             RGBColor[
             0.7355129252278461, 0.7903594474546665, 0.9053392735975632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 254}], {
             RGBColor[
             0.40119508956919725`, 0.5210943009518455, 0.9470120206751078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 283}], {
             RGBColor[
             0.3947145595034514, 0.515210734660812, 0.9466089897806659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 225}], {
             RGBColor[
             0.29997817143986366`, 0.426744933886711, 0.9406100364801734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 251}], {
             RGBColor[
             0.3289835017199729, 0.45723137505526373`, 0.9422618471300848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 269}], {
             RGBColor[
             0.6727623053020111, 0.7090410207196602, 0.647599267278013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 282}], {
             RGBColor[
             0.40649592976024684`, 0.5265080761040026, 0.947122539087454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 219}], {
             RGBColor[
             0.20337837440800324`, 0.33109394480949034`, 0.9348934695999689]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 254}], {
             RGBColor[
             0.27060222090313846`, 0.400822588016517, 0.9387557425033809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 283}], {
             RGBColor[
             0.26412169083739256`, 0.3949390217254835, 0.938352711608939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 212}], {
             RGBColor[
             0.20932819464730518`, 0.33734758312138824`, 0.935232303060627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 214}], {
             RGBColor[
             0.19305906954872248`, 0.3202477011206687, 0.9343058004542764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 225}], {
             RGBColor[
             0.20644219198451136`, 0.33431421133965444`, 0.9350679494784392]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 242}], {
             RGBColor[
             0.18509931747274389`, 0.3118814970113848, 0.9338525043489474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 244}], {
             RGBColor[
             0.18941015567136937`, 0.31641246128106837`, 0.9340980002070455]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 252}], {
             RGBColor[
             0.21362941037883332`, 0.3418684335680528, 0.935477250933459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 268}], {
             RGBColor[
             0.19718303522223768`, 0.3245822505180589, 0.9345406541985226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 279}], {
             RGBColor[
             0.21299163292133522`, 0.34119808902279597`, 0.9354409304507616]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 259}], {
             RGBColor[
             0.18280847530695815`, 0.30947367664736153`, 0.9337220442766032]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 211}], {
             RGBColor[
             0.3712058892361785, 0.49192848437614356`, 0.9451403247792249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 226}], {
             RGBColor[
             0.7289680937933078, 0.7852771577024377, 0.9144848957128108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 227}], {
             RGBColor[
             0.7121917692235163, 0.7160827059719499, 0.6161772867558488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 241}], {
             RGBColor[
             0.7289016289330998, 0.7852496727746727, 0.9155863904520005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 290}], {
             RGBColor[
             0.7090449941186435, 0.7036067912817707, 0.613645317642163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 291}], {
             RGBColor[
             0.6992769373373419, 0.7632490848408453, 0.9722193956891239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 231}], {
             RGBColor[
             0.25095672851015194`, 0.3811018116127316, 0.937602986480219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 264}], {
             RGBColor[
             0.28347133969758304`, 0.41527672951614025`, 0.9394546454862865]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 266}], {
             RGBColor[
             0.23444123912717205`, 0.36374298512871284`, 0.9366624537923354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 214}], {
             RGBColor[
             0.21709951040225656`, 0.3455157287097197, 0.9356748679962401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 225}], {
             RGBColor[
             0.23048263283804543`, 0.3595822389287055, 0.9364370170204028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 265}], {
             RGBColor[
             0.22804223773896515`, 0.3570172289495861, 0.9362980401297512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 276}], {
             RGBColor[
             0.23737124141047264`, 0.3668226033013362, 0.9368293130878194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 234}], {
             RGBColor[
             0.19826511451334394`, 0.3257195844608012, 0.9346022770133582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 249}], {
             RGBColor[
             0.2049158790401142, 0.33270995966126304`, 0.9349810282142335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 263}], {
             RGBColor[
             0.2061321686296245, 0.3339883571370523, 0.9350502941070169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 286}], {
             RGBColor[
             0.21163290304685975`, 0.3397699777762725, 0.935363552794471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 265}], {
             RGBColor[
             0.21177311264038245`, 0.33991734694886655`, 0.9353715375234006]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 276}], {
             RGBColor[
             0.22110211631188992`, 0.34972272130061666`, 0.9359028104814688]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 286}], {
             RGBColor[
             0.21086056333637188`, 0.3389581997713838, 0.9353195691905329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 229}], {
             RGBColor[
             0.2212270314220612, 0.34985401500148217`, 0.9359099242121978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 233}], {
             RGBColor[
             0.2150686635576537, 0.34338117991291517`, 0.9355592142728086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 259}], {
             RGBColor[
             0.20495150510474192`, 0.33274740491400967`, 0.9349830570659099]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 296}], {
             RGBColor[
             0.20597442651804665`, 0.33382256017635653`, 0.935041310927121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 237}], {
             RGBColor[
             0.8526673664281595, 0.38892998001081047`, 0.19740587187632483`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 269}], {
             RGBColor[
             0.9020307778688763, 0.6313968506786615, 0.25694130282079497`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 293}], {
             RGBColor[
             0.8775620673948297, 0.536919768793157, 0.2195471266169376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 299}], {
             RGBColor[
             0.8505404448303738, 0.37258152858724236`, 0.19536912935227085`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 223}], {
             RGBColor[
             0.19076430807847547`, 0.31783576131915836`, 0.9341751171833412]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 246}], {
             RGBColor[
             0.1922440281378487, 0.31939104092123016`, 0.9342593850516728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 247}], {
             RGBColor[
             0.19889732977739935`, 0.3263840827880864, 0.9346382807373675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 251}], {
             RGBColor[
             0.24282276767362948`, 0.3725525030506428, 0.9371397694436958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 270}], {
             RGBColor[
             0.20643869531729672`, 0.3343105361207104, 0.9350677503484142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 271}], {
             RGBColor[
             0.21133673112817714`, 0.3394586823113528, 0.9353466862418491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 278}], {
             RGBColor[
             0.20033411359999898`, 0.32789423368299453`, 0.9347201034505334]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 295}], {
             RGBColor[
             0.19848052761044668`, 0.32594599728383544`, 0.9346145444705631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 220}], {
             RGBColor[
             0.6501395047208716, 0.7189888396444919, 0.9414344110066938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 262}], {
             RGBColor[
             0.6355147016275733, 0.7058679616598169, 0.9405191403190352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 290}], {
             RGBColor[
             0.956800253470921, 0.9001474347654498, 0.6080814328251828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 292}], {
             RGBColor[
             0.8704525733936984, 0.8991011858444631, 0.9592520377831382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 250}], {
             RGBColor[
             0.1834940050025886, 0.3101942118225623, 0.933761084178619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 222}], {
             RGBColor[
             0.2772575054008418, 0.4064948783579615, 0.9391831866025837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 248}], {
             RGBColor[
             0.27752408340790014`, 0.40677506874540165`, 0.9391983678257189]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 262}], {
             RGBColor[
             0.318464636651424, 0.44980618598534605`, 0.9415298717668166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 230}], {
             RGBColor[
             0.18914056303198, 0.3161291023239095, 0.9340826473050587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 232}], {
             RGBColor[
             0.18705168190288157`, 0.31393355581451393`, 0.9339636886149794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 245}], {
             RGBColor[
             0.20571905261194073`, 0.33355414600939837`, 0.93502676776096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 288}], {
             RGBColor[
             0.19753047223834988`, 0.324947428850772, 0.9345604402226031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 296}], {
             RGBColor[
             0.18670137270172213`, 0.31356535863320917`, 0.9339437390242094]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 297}], {
             RGBColor[
             0.18909437890281156`, 0.31608055987591055`, 0.9340800171872259]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 248}], {
             RGBColor[
             0.22169214906401963`, 0.3503428831333422, 0.9359364119738274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 285}], {
             RGBColor[
             0.21055261927690455`, 0.33863453104010255`, 0.9353020322319088]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 246}], {
             RGBColor[
             0.1829700916045353, 0.3096435456231802, 0.9337312480856603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 247}], {
             RGBColor[
             0.18962339324408597`, 0.3166365874900364, 0.934110143771355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 270}], {
             RGBColor[
             0.19716475878398335`, 0.32456304082266046`, 0.9345396133824015]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 271}], {
             RGBColor[
             0.20206279459486376`, 0.3297111870133029, 0.9348185492758365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 278}], {
             RGBColor[
             0.1910601770666856, 0.31814673838494456`, 0.9341919664845209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 295}], {
             RGBColor[
             0.1892065910771333, 0.3161985019857855, 0.9340864075045505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 253}], {
             RGBColor[
             0.20025883236896588`, 0.32781510833607297`, 0.9347158162957947]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 262}], {
             RGBColor[
             0.2562537795699573, 0.3866693481290222, 0.9379046457017901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 265}], {
             RGBColor[
             0.22515623507617133`, 0.35398385716785236`, 0.9361336865475633]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 276}], {
             RGBColor[
             0.23448523874767882`, 0.3637892315196025, 0.9366649595056316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 241}], {
             RGBColor[
             0.9861906717339419, 0.9885575021255057, 0.8785198369719385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 243}], {
             RGBColor[
             0.9868373224355939, 0.9888249088088037, 0.8678031613671959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 290}], {
             RGBColor[
             0.9663340369194856, 0.9069146206326038, 0.576578764162101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 291}], {
             RGBColor[
             0.956565980138184, 0.9665569141916783, 0.9351528422090618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 241}], {
             RGBColor[
             0.9694143471641505, 0.9193630503950179, 0.5802122280149764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 290}], {
             RGBColor[
             0.9495577123496941, 0.837720168902116, 0.27827115520513895`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 291}], {
             RGBColor[
             0.9397896555683924, 0.8973624624611904, 0.6368452332520997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 299}], {
             RGBColor[
             0.8633640950075484, 0.3798620775565069, 0.20395744452515618`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 264}], {
             RGBColor[
             0.3612335072093944, 0.48614499734720384`, 0.9442808957993838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 233}], {
             RGBColor[
             0.2115539796555496, 0.3396870242879735, 0.9353590582240927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 259}], {
             RGBColor[
             0.2014368212026378, 0.32905324928906804`, 0.934782901017194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 284}], {
             RGBColor[
             0.22933503139451644`, 0.3583760370494225, 0.936371662815918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 245}], {
             RGBColor[
             0.20866400795240445`, 0.3366494807931788, 0.9351944786109285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 288}], {
             RGBColor[
             0.2004754275788136, 0.3280427636345524, 0.9347281510725716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 296}], {
             RGBColor[
             0.18964632804218584`, 0.3166606934169896, 0.9341114498741778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 297}], {
             RGBColor[
             0.19203933424327527`, 0.319175894659691, 0.9342477280371944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 232}], {
             RGBColor[
             0.20954424282732975`, 0.33757466345683984`, 0.9352446066848648]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 245}], {
             RGBColor[
             0.2282116135363889, 0.3571952536517242, 0.9363076858308454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 264}], {
             RGBColor[
             0.2636953407278438, 0.39449090072818943`, 0.9383284316009286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 266}], {
             RGBColor[
             0.21466524015743277`, 0.342957156340762, 0.9355362399069774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 240}], {
             RGBColor[
             0.184219115333836, 0.3109563487553536, 0.933802378139279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 245}], {
             RGBColor[
             0.206575126823306, 0.3344539342837832, 0.9350755199208491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 288}], {
             RGBColor[
             0.19838654644971515`, 0.32584721712515685`, 0.9346091923824922]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 297}], {
             RGBColor[
             0.18995045311417683`, 0.3169803481502954, 0.934128769347115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 259}], {
             RGBColor[
             0.1952784533382303, 0.32258041420050104`, 0.9344321910778048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[
             0.2158656276199601, 0.3442188396728392, 0.9356046001971543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 249}], {
             RGBColor[
             0.2008059288288086, 0.3283901414032867, 0.934746972629826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 263}], {
             RGBColor[
             0.20202221841831886`, 0.32966853887907605`, 0.9348162385226094]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 274}], {
             RGBColor[
             0.43577020330018756`, 0.5515998272739158, 0.9490608562281224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 298}], {
             RGBColor[
             0.33431581918328446`, 0.4594951311953859, 0.9426878395174293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 260}], {
             RGBColor[
             0.2447992469285118, 0.3746299080635468, 0.9372523270133223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 267}], {
             RGBColor[
             0.21381850493226368`, 0.3420671839329953, 0.9354880195885366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 294}], {
             RGBColor[
             0.38374017735760657`, 0.49740352912178454`, 0.9465549709165739]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 256}], {
             RGBColor[
             0.8226924771507464, 0.17542990005333894`, 0.16936364778802923`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 269}], {
             RGBColor[
             0.8744380750181129, 0.4362072994771681, 0.23118026314495393`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 277}], {
             RGBColor[
             0.8810535048299607, 0.45831360631425644`, 0.27465957321892126`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 281}], {
             RGBColor[
             0.8762036339901905, 0.45697937196631744`, 0.42154425983453325`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 293}], {
             RGBColor[
             0.8499693645440664, 0.3417302175916635, 0.19378608694109653`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 248}], {
             RGBColor[
             0.22976740900447992`, 0.35883049333181793`, 0.9363962860811601]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 258}], {
             RGBColor[
             0.28886880526886394`, 0.4180452286151569, 0.9398683740473033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 263}], {
             RGBColor[
             0.22373268173624067`, 0.3524876123490904, 0.9360526172908128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 285}], {
             RGBColor[
             0.21862787921736482`, 0.3471221412385783, 0.9357619063392415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 290}], {
             RGBColor[
             0.9662675720592777, 0.9068871357048387, 0.5776802589012907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 291}], {
             RGBColor[
             0.956499515277976, 0.9665294292639133, 0.9362543369482514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 250}], {
             RGBColor[
             0.18176798085569046`, 0.30838005100792065`, 0.933662789656877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 268}], {
             RGBColor[
             0.1929658134251674, 0.3201496830220325, 0.934300489656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 254}], {
             RGBColor[
             0.6530996726183891, 0.7197996840615158, 0.8998607275791879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 256}], {
             RGBColor[
             0.874424572290644, 0.42222750521570074`, 0.3959301794759612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 283}], {
             RGBColor[
             0.6466191425526432, 0.7139161177704824, 0.899457696684746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 279}], {
             RGBColor[
             0.21308524932289044`, 0.3412964857964532, 0.9354462617663373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 280}], {
             RGBColor[
             0.22575834254074034`, 0.3546167102889326, 0.9361679756769326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 264}], {
             RGBColor[
             0.26072622472382, 0.3913701715551329, 0.938159344836913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 288}], {
             RGBColor[
             0.2170539171587743, 0.34546780732004123`, 0.9356722715284729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 297}], {
             RGBColor[
             0.20861782382323596`, 0.3366009383451798, 0.9351918484930957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 270}], {
             RGBColor[
             0.19864447884335656`, 0.3261183204247322, 0.9346238812507333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 278}], {
             RGBColor[
             0.1925398971260588, 0.3197020179870163, 0.9342762343528525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 295}], {
             RGBColor[
             0.19068631113650653`, 0.3177537815878572, 0.9341706753728822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 251}], {
             RGBColor[
             0.24168185283923999`, 0.37135332922152087`, 0.9370747960317096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 270}], {
             RGBColor[
             0.20529778048290723`, 0.33311136229158844`, 0.935002776936428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 271}], {
             RGBColor[
             0.21019581629378764`, 0.33825950848223085`, 0.9352817128298629]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 278}], {
             RGBColor[
             0.19919319876560948`, 0.3266950598538726, 0.9346551300385472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 289}], {
             RGBColor[
             0.22060050259813557`, 0.34919549348331447`, 0.9358742443225416]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 295}], {
             RGBColor[
             0.1973396127760572, 0.3247468234547135, 0.9345495710585769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 285}], {
             RGBColor[
             0.21081919728396287`, 0.3389147214275427, 0.9353172134550438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 258}], {
             RGBColor[
             0.2738091064777124, 0.40221653034560445`, 0.9390107464799751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 263}], {
             RGBColor[
             0.20867298294508915`, 0.33665891407953785`, 0.9351949897234846]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 286}], {
             RGBColor[
             0.2141737173623244, 0.342440534718758, 0.9355082484109388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 270}], {
             RGBColor[
             0.24922321837913736`, 0.37927978255414485`, 0.9375042656427561]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 271}], {
             RGBColor[
             0.25412125419001774`, 0.38442792874478726`, 0.9377832015361911]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 278}], {
             RGBColor[
             0.24311863666183964`, 0.372863480116429, 0.9371566187448754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 282}], {
             RGBColor[
             0.363119718775744, 0.4867984505328162, 0.944436976695407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 289}], {
             RGBColor[
             0.26452594049436573`, 0.3953639137458709, 0.9383757330288698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 295}], {
             RGBColor[
             0.24126505067228732`, 0.3709152437172699, 0.9370510597649051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 268}], {
             RGBColor[
             0.22149590633125682`, 0.35013661957870057`, 0.9359252362405117]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 279}], {
             RGBColor[
             0.23730450403035436`, 0.36675245808343765`, 0.9368255124927507]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 280}], {
             RGBColor[
             0.2499775972482043, 0.3800726825759171, 0.937547226403346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 283}], {
             RGBColor[
             0.27188152915805053`, 0.4030951038026612, 0.9387946229216484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 283}], {
             RGBColor[
             0.3123013068939945, 0.44465097126766145`, 0.9411304437622906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 258}], {
             RGBColor[
             0.3530896957607064, 0.48025028048897034`, 0.9437195410822816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 286}], {
             RGBColor[
             0.2934543066453184, 0.4204742848621239, 0.9402170430132455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 269}], {
             RGBColor[
             0.8696737021648134, 0.3995862419652118, 0.22661789432004487`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 277}], {
             RGBColor[
             0.8762891319766611, 0.42169254880230017`, 0.2700972043940122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 281}], {
             RGBColor[
             0.8714392611368911, 0.42035831445436117`, 0.41698189100962424`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 293}], {
             RGBColor[
             0.8452049916907669, 0.30510916007970723`, 0.18922371811618746`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 267}], {
             RGBColor[
             0.19014093188722048`, 0.31718055341781604`, 0.9341396168314517]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 272}], {
             RGBColor[
             0.18158199985616474`, 0.30818457318554265`, 0.9336521983140883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 300}], {
             RGBColor[
             0.20486085687830097`, 0.33265212788059073`, 0.9349778947835161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 263}], {
             RGBColor[
             0.2750253960672227, 0.40349492782139373`, 0.9390800123727585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 286}], {
             RGBColor[
             0.28052613048445796`, 0.4092765484606139, 0.9393932710602128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 267}], {
             RGBColor[
             0.22718681650953165`, 0.35611812700061296`, 0.9362493251562173]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 287}], {
             RGBColor[
             0.25058425907026255`, 0.38071032261548143`, 0.9375817748966364]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 294}], {
             RGBColor[
             0.39710848893487455`, 0.5114544721894022, 0.9473162764842546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 300}], {
             RGBColor[
             0.24190674150061214`, 0.37158970146338766`, 0.9370876031082818]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 284}], {
             RGBColor[
             0.2428470796826115, 0.3725780565135533, 0.937141153976641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 292}], {
             RGBColor[
             0.5387777053242508, 0.6299185321853173, 0.9593474985432611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 286}], {
             RGBColor[
             0.2153900069518347, 0.3437189321945473, 0.9355775143037223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 288}], {
             RGBColor[
             0.2525376443502292, 0.38276345439650644`, 0.937693017298556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 276}], {
             RGBColor[
             0.23204484364859856`, 0.36122422154048306`, 0.93652598261498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 286}], {
             RGBColor[
             0.22180329067308052`, 0.3504597000112502, 0.9359427413240442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 272}], {
             RGBColor[
             0.18764714248222777`, 0.31455942263778813`, 0.9339975992140681]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 287}], {
             RGBColor[
             0.2196035170740144, 0.34814759848492993`, 0.9358174674718507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 300}], {
             RGBColor[
             0.210925999504364, 0.33902697733283615`, 0.935323295683496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 279}], {
             RGBColor[
             0.22085812887375872`, 0.34946627503344374`, 0.9358889157578143]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 280}], {
             RGBColor[
             0.23353122209160865`, 0.3627864995259231, 0.9366106296684096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 277}], {
             RGBColor[
             0.9830880426173179, 0.9543005010685027, 0.41547009014484526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 282}], {
             RGBColor[
             0.7068985223577822, 0.7386080961972126, 0.6497743968433352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 293}], {
             RGBColor[
             0.9364618321884765, 0.7794254179846133, 0.2941598607281082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 271}], {
             RGBColor[
             0.217737181833685, 0.3461859618148549, 0.9357111824409096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 278}], {
             RGBColor[
             0.20673456430550685`, 0.3346215131864966, 0.9350845996495938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 289}], {
             RGBColor[
             0.22814186813803294`, 0.35712194681593845`, 0.9363037139335881]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 295}], {
             RGBColor[
             0.20488097831595456`, 0.3326732767873375, 0.9349790406696236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 278}], {
             RGBColor[
             0.21163260011638724`, 0.339769659377139, 0.9353635355430288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 289}], {
             RGBColor[
             0.23303990394891333`, 0.36227009300658086`, 0.9365826498270231]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 295}], {
             RGBColor[
             0.20977901412683497`, 0.3378214229779799, 0.9352579765630585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 274}], {
             RGBColor[
             0.3509883555182567, 0.4717110997619036, 0.9438949792783465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 289}], {
             RGBColor[
             0.24118737083360547`, 0.370833597281629, 0.9370466360130092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 289}], {
             RGBColor[
             0.3532455749379125, 0.4740835804879391, 0.944023524585039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 281}], {
             RGBColor[
             0.9857363810754343, 0.9854586098022267, 0.7010160851792143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 282}], {
             RGBColor[
             0.7168216670755537, 0.7717675564528452, 0.7149933619542863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 293}], {
             RGBColor[
             0.946384976906248, 0.8125848782402458, 0.35937882583905917`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 295}], {
             RGBColor[
             0.1987763965986568, 0.3262569743496216, 0.9346313937717428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 280}], {
             RGBColor[
             0.24933981979070619`, 0.37940233803066026`, 0.9375109059206487]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 294}], {
             RGBColor[
             0.7572554970898742, 0.8088426757639791, 0.9389810177450694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 293}], {
             RGBColor[
             0.6701954566467123, 0.5968924733689558, 0.5936831325375491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 300}], {
             RGBColor[
             0.2343234420650949, 0.3636191729477046, 0.9366557454239152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 296}], {
             RGBColor[
             0.1980362372485557, 0.3254790199438521, 0.9345892427917222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 297}], {
             RGBColor[
             0.20042924344964513`, 0.3279942211865534, 0.9347255209547387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 291}], {
             RGBColor[
             0.9366428804635196, 0.8848865477710113, 0.6343132641384139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 297}], {
             RGBColor[
             0.18960014391301738`, 0.31661215096899065`, 0.934108819756345]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.09631744162763219], {
             RGBColor[
             0.8186934053129894, 0.1446912815038851, 0.16553413207988746`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.09631744162763219], {
             RGBColor[
             0.19859115798198185`, 0.32606227681868954`, 0.934620844706559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.09631744162763219], {
             RGBColor[
             0.9542183694281502, 0.96537671539683, 0.9623805381832607]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.09631744162763219], {
             RGBColor[
             0.2205376694136581, 0.34912945182257465`, 0.935870666065639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.09631744162763219], {
             RGBColor[
             0.9710126878169619, 0.9138811308413543, 0.3418901952738247]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.09631744162763219], {
             RGBColor[
             0.2105950138195758, 0.3386790903924193, 0.9353044465383967]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.09631744162763219], {
             RGBColor[
             0.9383196861766793, 0.9535195034595876, 0.9892928618873055]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.09631744162763219], {
             RGBColor[
             0.2044682273202984, 0.33223944932097826`, 0.9349555351110312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.09631744162763219], {
             RGBColor[
             0.19896010530687766`, 0.32645006384976655`, 0.9346418557109033]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.09631744162763219], {
             RGBColor[
             0.19040293767796423`, 0.3174559381160143, 0.9341545376736317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.09631744162763219], {
             RGBColor[
             0.5318148081413353, 0.630790245090044, 0.9562855562801685]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.09631744162763219], {
             RGBColor[
             0.42962012936485927`, 0.5465370955454517, 0.948595992638333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.09631744162763219], {
             RGBColor[
             0.33328873930237535`, 0.463099687229773, 0.9424578416460552]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.09631744162763219], {
             RGBColor[
             0.1801938510546308, 0.30672554078141306`, 0.9335731452934231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.09631744162763219], {
             RGBColor[
             0.2583760710911756, 0.38890001107887695`, 0.9380255070642746]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.09631744162763219], {
             RGBColor[
             0.24679037784549854`, 0.37672271290229153`, 0.9373657189734305]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.09631744162763219], {
             RGBColor[
             0.7036631405833589, 0.768426260552445, 0.9710982238135836]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.09631744162763219], {
             RGBColor[
             0.19997475001447043`, 0.3275165197696367, 0.9346996382259684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.09631744162763219], {
             RGBColor[
             0.18771789764902583`, 0.31463379080422954`, 0.9340016286161444]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.09631744162763219], {
             RGBColor[
             0.21900416978762977`, 0.3475176464861269, 0.9357833355305459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.09631744162763219], {
             RGBColor[
             0.19357781768564236`, 0.320792938303103, 0.9343353423932549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.09631744162763219], {
             RGBColor[
             0.18854143418810532`, 0.3154993799220345, 0.9340485278037318]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.09631744162763219], {
             RGBColor[
             0.989346654985427, 0.9898625823050647, 0.82621702707199]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.09631744162763219], {
             RGBColor[
             0.9237640134240451, 0.7354567479025522, 0.2575169395936321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.09631744162763219], {
             RGBColor[
             0.1911156300253715, 0.31820502296044406`, 0.9341951244484827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.09631744162763219], {
             RGBColor[
             0.2290956026577889, 0.35812438226646315`, 0.9363580277035645]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.09631744162763219], {
             RGBColor[
             0.9698415036520304, 0.9099304516459211, 0.33734036595263717`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.09631744162763219], {
             RGBColor[
             0.18347004528514485`, 0.31016902864039503`, 0.9337597197081559]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.09631744162763219], {
             RGBColor[
             0.19525519293228838`, 0.32255596603906117`, 0.934430866432097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.09631744162763219], {
             RGBColor[
             0.24929644188312317`, 0.37935674509947226`, 0.9375084356129837]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.09631744162763219], {
             RGBColor[
             0.41964854701834464`, 0.537900212103202, 0.9479606122287372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.09631744162763219], {
             RGBColor[
             0.9876761626712638, 0.9891717908034641, 0.8539014078132029]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.09631744162763219], {
             RGBColor[
             0.20050642775524471`, 0.3280753467855062, 0.9347299164867587]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.09631744162763219], {
             RGBColor[
             0.1836929464736069, 0.31040331192222026`, 0.933772413601086]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.09631744162763219], {
             RGBColor[
             0.20639345636736367`, 0.33426298711601565`, 0.9350651740571405]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.09631744162763219], {
             RGBColor[
             0.18133311757286624`, 0.3079229821257478, 0.9336380248362428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.09631744162763219], {
             RGBColor[
             0.22656828106141946`, 0.3554680070272346, 0.9362141004774884]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.09631744162763219], {
             RGBColor[
             0.18611948239069784`, 0.312953755022346, 0.9339106012318261]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.09631744162763219], {
             RGBColor[
             0.20172422019829714`, 0.3293553238556548, 0.934799267964828]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.09631744162763219], {
             RGBColor[
             0.6892336433588957, 0.7571538276524538, 0.9696600263815672]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.09631744162763219], {
             RGBColor[
             0.1885946642534308, 0.31555532809567266`, 0.9340515591772053]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.09631744162763219], {
             RGBColor[
             0.8376047344232163, 0.2900520440423452, 0.18364364219313192`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.09631744162763219], {
             RGBColor[
             0.2255865897625529, 0.3544361872293025, 0.9361581946103001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.09631744162763219], {
             RGBColor[
             0.31621931418873805`, 0.44831500913059213`, 0.9413701929717141]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.09631744162763219], {
             RGBColor[
             0.29993474933268105`, 0.43258081688308847`, 0.9403922123095734]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.09631744162763219], {
             RGBColor[
             0.2047087295239663, 0.33249223238575365`, 0.9349692313557391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.09631744162763219], {
             RGBColor[
             0.18409960782193097`, 0.31083073878312756`, 0.9337955723632715]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.09631744162763219], {
             RGBColor[
             0.1928098846058197, 0.31998579194643995`, 0.9342916097404141]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.09631744162763219], {
             RGBColor[
             0.20962180710681122`, 0.3376561884324342, 0.9352490238558351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.09631744162763219], {
             RGBColor[
             0.1818234123124711, 0.30843831298355445`, 0.9336659463963373]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.09631744162763219], {
             RGBColor[
             0.8112967405816618, 0.8525104469167772, 0.981826135168235]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.09631744162763219], {
             RGBColor[
             0.1987330571876369, 0.3262114218807623, 0.9346289256564001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.09631744162763219], {
             RGBColor[
             0.21587739356825456`, 0.3442312064305009, 0.9356052702505034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.09631744162763219], {
             RGBColor[
             0.24403688677483204`, 0.37382861920560384`, 0.937208911730381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.09631744162763219], {
             RGBColor[
             0.20213692733288047`, 0.32978910522124555`, 0.9348227710255971]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.09631744162763219], {
             RGBColor[
             0.19935669202797407`, 0.3268669016386893, 0.9346644407379722]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.09631744162763219], {
             RGBColor[
             0.17967566298483006`, 0.30618089226503126`, 0.9335436352494385]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.09631744162763219], {
             RGBColor[
             0.19114091674596853`, 0.31823160090706226`, 0.9341965644898124]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.09631744162763219], {
             RGBColor[
             0.985007685890186, 0.9880683070777632, 0.8981249738722014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.09631744162763219], {
             RGBColor[
             0.28726741181117993`, 0.4192666419924039, 0.9396708261773704]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.09631744162763219], {
             RGBColor[
             0.2772592389822082, 0.4087474177943471, 0.9391008755405253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.09631744162763219], {
             RGBColor[
             0.20167701950442632`, 0.3293057129336997, 0.9347965799551393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.09631744162763219], {
             RGBColor[
             0.18288267188311363`, 0.3095516619532356, 0.9337262696618512]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.09631744162763219], {
             RGBColor[
             0.2353045398184947, 0.3646503688917182, 0.9367116174895672]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.09631744162763219], {
             RGBColor[
             0.3774633879291902, 0.5013615475879224, 0.9452726111944477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.09631744162763219], {
             RGBColor[
             0.3863417480503173, 0.5090515368854881, 0.9458383324505404]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.09631744162763219], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.09631744162763219], {
             RGBColor[
             0.8768566069289154, 0.9046456729993274, 0.9881165600196555]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.09631744162763219], {
             RGBColor[
             0.20756886290590398`, 0.3354984139131004, 0.9351321117206522]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.09631744162763219], {
             RGBColor[
             0.20976983040282712`, 0.33781177030176596`, 0.9352574535635624]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.09631744162763219], {
             RGBColor[
             0.22331684544677569`, 0.35205054204331915`, 0.9360289360293025]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.09631744162763219], {
             RGBColor[
             0.8294154563220671, 0.22710566399236717`, 0.1758015802350048]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.09631744162763219], {
             RGBColor[
             0.1826688110543663, 0.3093268806626624, 0.9337140906040328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.09631744162763219], {
             RGBColor[
             0.20590138873724428`, 0.3337457928378705, 0.935037151533554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.09631744162763219], {
             RGBColor[
             0.3329293714790703, 0.46278842088357813`, 0.9424349430461306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.09631744162763219], {
             RGBColor[
             0.3269177544061254, 0.4575814603276529, 0.9420518881221068]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.09631744162763219], {
             RGBColor[
             0.4137826929511934, 0.5328195041366336, 0.9475868451945494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.09631744162763219], {
             RGBColor[
             0.19413140389541048`, 0.3213747925089622, 0.9343668683089438]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.09631744162763219], {
             RGBColor[
             0.18314084159618357`, 0.3098230146905773, 0.9337409720450827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.09631744162763219], {
             RGBColor[
             0.9788084084452291, 0.9401779270427488, 0.37217509781633024`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.09631744162763219], {
             RGBColor[
             0.8894648943465696, 0.5909677260051436, 0.2294791371904563]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.09631744162763219], {
             RGBColor[
             0.6134396494628491, 0.6970569684320459, 0.962711362790644]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.09631744162763219], {
             RGBColor[
             0.846552585818907, 0.35882915084310774`, 0.19221211479479816`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.09631744162763219], {
             RGBColor[
             0.18746791982634672`, 0.31437104826308443`, 0.9339873927489519]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.09631744162763219], {
             RGBColor[
             0.23214849009490668`, 0.36133316052711717`, 0.9365318851267661]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.09631744162763219], {
             RGBColor[
             0.5941770672605392, 0.6814187364307716, 0.9611949417585145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.09631744162763219], {
             RGBColor[
             0.9931480500222558, 0.9877526967730439, 0.4955857141352578]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.09631744162763219], {
             RGBColor[
             0.22285845764454237`, 0.35156874739970667`, 0.9360028315220893]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.09631744162763219], {
             RGBColor[
             0.3807443443279537, 0.5042033471148679, 0.9454816708349412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.09631744162763219], {
             RGBColor[
             0.21567607897691587`, 0.34401961203092163`, 0.935593805682345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.09631744162763219], {
             RGBColor[
             0.49015879412300467`, 0.5969720163279171, 0.9530062422656385]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.09631744162763219], {
             RGBColor[
             0.8315546894535105, 0.24354874725857717`, 0.17785011229759332`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.09631744162763219], {
             RGBColor[
             0.24113006344271598`, 0.3707733635803057, 0.9370433724418767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.09631744162763219], {
             RGBColor[
             0.796888814031874, 0.8412548651917855, 0.9803900876994809]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.09631744162763219], {
             RGBColor[
             0.28755638833203334`, 0.4195703746379904, 0.9396872829627306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.09631744162763219], {
             RGBColor[
             0.20095046543520778`, 0.32854205854076235`, 0.9347552037757377]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.09631744162763219], {
             RGBColor[
             0.44885816070930806`, 0.563200111364443, 0.9498218229840781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.09631744162763219], {
             RGBColor[
             0.1790520430393593, 0.3055254281625532, 0.9335081210161069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.09631744162763219], {
             RGBColor[
             0.19567419878950365`, 0.3229963677615002, 0.9344547281958019]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.09631744162763219], {
             RGBColor[
             0.1806628381309981, 0.3072184759341732, 0.933599853413618]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.09631744162763219], {
             RGBColor[
             0.6473280227603806, 0.724416838346381, 0.9654832657505968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.09631744162763219], {
             RGBColor[
             0.19219534584531597`, 0.31933987274514264`, 0.9342566126671321]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.09631744162763219], {
             RGBColor[
             0.4213296380105047, 0.5393562886265211, 0.9480677298602272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.09631744162763219], {
             RGBColor[
             0.3350878162698179, 0.46465795727473413`, 0.9425724772395593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.09631744162763219], {
             RGBColor[
             0.28384023029084227`, 0.41566445691867016`, 0.9394756532598479]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.09631744162763219], {
             RGBColor[
             0.861860606843299, 0.8926882695866354, 0.9866862281444021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.09631744162763219], {
             RGBColor[
             0.40847529455142584`, 0.5282225024003548, 0.9472486624616643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.09631744162763219], {
             RGBColor[
             0.24068546665888524`, 0.3703060641714354, 0.9370180533127597]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.09631744162763219], {
             RGBColor[
             0.9928111618057213, 0.9912952449090205, 0.7688011832034702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.09631744162763219], {
             RGBColor[
             0.18591721951216156`, 0.3127411639127972, 0.9338990826601146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.09631744162763219], {
             RGBColor[
             0.6142037164471443, 0.6976772724307221, 0.9627715129425172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.09631744162763219], {
             RGBColor[
             0.18923133529375677`, 0.3162245097263307, 0.9340878166510814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.09631744162763219], {
             RGBColor[
             0.2676326072490897, 0.3986292174791347, 0.9385526531046497]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.09631744162763219], {
             RGBColor[
             0.23913206195702244`, 0.3686733373382309, 0.9369295892130448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.09631744162763219], {
             RGBColor[
             0.3517287364030146, 0.47907148589714393`, 0.9436328219554587]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.09631744162763219], {
             RGBColor[
             0.2873518174774419, 0.41935535769927346`, 0.9396756329551971]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.09631744162763219], {
             RGBColor[
             0.1855098238772711, 0.3123129652701522, 0.9338758820813954]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.09631744162763219], {
             RGBColor[
             0.1887209958010121, 0.3156881105620633, 0.9340587535719493]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.09631744162763219], {
             RGBColor[
             0.18085158366002294`, 0.307416859452336, 0.933610602192272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.09631744162763219], {
             RGBColor[
             0.27909030860477735`, 0.41067198806418675`, 0.939205152246706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.09631744162763219], {
             RGBColor[
             0.22544944565233713`, 0.35429204007402687`, 0.9361503844561099]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.09631744162763219], {
             RGBColor[
             0.18504035865818397`, 0.31181952755907755`, 0.93384914673168]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.09631744162763219], {
             RGBColor[
             0.19860317371820202`, 0.3260749061192986, 0.9346215289849611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.09631744162763219], {
             RGBColor[
             0.1859244664032461, 0.3127487808548065, 0.9338994953598411]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.09631744162763219], {
             RGBColor[
             0.8351944719959239, 0.27152571084244637`, 0.18133557217075477`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.09631744162763219], {
             RGBColor[
             0.22348836128871713`, 0.3522308160679321, 0.9360387036027661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.09631744162763219], {
             RGBColor[
             0.34883524619319184`, 0.47656529010844195`, 0.9434484513179017]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.09631744162763219], {
             RGBColor[
             0.8449402545684014, 0.34643606632366236`, 0.19066814456844627`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.09631744162763219], {
             RGBColor[
             0.18908769389738214`, 0.3160735335113504, 0.9340796364860563]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.09631744162763219], {
             RGBColor[
             0.9118031822514008, 0.6880360380137298, 0.24789297407533079`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.09631744162763219], {
             RGBColor[
             0.22940782651350908`, 0.3584525493349609, 0.9363758083902539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.09631744162763219], {
             RGBColor[
             0.19689631111946682`, 0.3242808853066886, 0.9345243256850401]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.09631744162763219], {
             RGBColor[
             0.18528931800943133`, 0.31208119962217307`, 0.9338633245984311]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.09631744162763219], {
             RGBColor[
             0.24479905803441923`, 0.3746297095238789, 0.9372523162560832]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.09631744162763219], {
             RGBColor[
             0.21307650899259664`, 0.34128729915514544`, 0.9354457640174572]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.09631744162763219], {
             RGBColor[
             0.39261549520966454`, 0.5144855413472138, 0.9462380900718772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.09631744162763219], {
             RGBColor[
             0.26153416243522165`, 0.3922193653160256, 0.9382053556943405]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.09631744162763219], {
             RGBColor[
             0.231287806205471, 0.36042852718880986`, 0.9364828704525304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.09631744162763219], {
             RGBColor[
             0.4407231525670485, 0.5561539761890157, 0.9493034674587586]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.09631744162763219], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.09631744162763219], {
             RGBColor[
             0.2938477713702168, 0.42618301710784506`, 0.940045567919488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.09631744162763219], {
             RGBColor[
             0.8299355921400753, 0.23110365581454728`, 0.17629966288173887`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.09631744162763219], {
             RGBColor[
             0.3068945586163886, 0.4398960177176607, 0.9407885631521654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.09631744162763219], {
             RGBColor[
             0.19763991012936863`, 0.32506245501299574`, 0.9345666725485978]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.09631744162763219], {
             RGBColor[
             0.8649038628242013, 0.8951148792988238, 0.9869764966166072]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.09631744162763219], {
             RGBColor[
             0.20002902465321373`, 0.3275735658561667, 0.9347027290863527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.09631744162763219], {
             RGBColor[
             0.21339775345539977`, 0.34162494745362687`, 0.9354640584143752]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.09631744162763219], {
             RGBColor[
             0.2462972527349853, 0.37620440714520426`, 0.9373376362279]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.09631744162763219], {
             RGBColor[
             0.895503807139292, 0.6183890185729798, 0.2345181540520019]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.09631744162763219], {
             RGBColor[
             0.9074094141907081, 0.6706162117894943, 0.24435764515870567`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.09631744162763219], {
             RGBColor[
             0.5978280581771518, 0.684382775332144, 0.9614823611374906]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.09631744162763219], {
             RGBColor[
             0.1825195240294396, 0.3091699705341204, 0.9337055889288136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.09631744162763219], {
             RGBColor[
             0.22106916700115545`, 0.3496880894859278, 0.9359009340669666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.09631744162763219], {
             RGBColor[
             0.4972976140125026, 0.6027676319143825, 0.9535682363176986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.09631744162763219], {
             RGBColor[
             0.9263138375757084, 0.7455659509853682, 0.2595685879581257]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.09631744162763219], {
             RGBColor[
             0.3944915237120784, 0.5161104629440706, 0.9463576289491441]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.09631744162763219], {
             RGBColor[
             0.18253809113335498`, 0.30918948573755783`, 0.933706646297914]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.09631744162763219], {
             RGBColor[
             0.19294565339664288`, 0.32012849355383366`, 0.9342993415721996]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.09631744162763219], {
             RGBColor[
             0.29124080035179, 0.42344292527596916`, 0.9398971047766567]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.09631744162763219], {
             RGBColor[
             0.19576440547633542`, 0.32309118070879467`, 0.9344598653331682]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.09631744162763219], {
             RGBColor[
             0.2016546493170191, 0.3292822004483829, 0.9347953060060602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.09631744162763219], {
             RGBColor[
             0.9913482769712819, 0.9906903044355545, 0.7930449707347249]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.09631744162763219], {
             RGBColor[
             0.6211503872091352, 0.7033168926992579, 0.9633183803113946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.09631744162763219], {
             RGBColor[
             0.18196114135351968`, 0.30858307493822207`, 0.9336737898614731]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.09631744162763219], {
             RGBColor[
             0.21779424853057935`, 0.34624594253152846`, 0.935714432304875]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.09631744162763219], {
             RGBColor[
             0.18609439165410657`, 0.312927383067344, 0.9339091723514956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.09631744162763219], {
             RGBColor[
             0.9076820231617462, 0.6716970155181059, 0.2445769927357579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.09631744162763219], {
             RGBColor[
             0.4004114204648772, 0.5212379799686826, 0.9467348395354733]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.09631744162763219], {
             RGBColor[
             0.6047389625257771, 0.6899933588150511, 0.9620264128432912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.09631744162763219], {
             RGBColor[
             0.19757646601375403`, 0.32499577122489554`, 0.9345630595000708]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.09631744162763219], {
             RGBColor[
             0.17914809400855325`, 0.30562638382115925`, 0.9335135909767078]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.09631744162763219], {
             RGBColor[
             0.19058407149220488`, 0.3176463212393284, 0.9341648529763892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.09631744162763219], {
             RGBColor[
             0.20128694378722742`, 0.32889571862269473`, 0.9347743657201101]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.09631744162763219], {
             RGBColor[
             0.23320476894069225`, 0.36244337656598474`, 0.9365920386444091]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.09631744162763219], {
             RGBColor[
             0.18260859612989327`, 0.30926359095919453`, 0.9337106614531641]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.09631744162763219], {
             RGBColor[
             0.19419263806779313`, 0.3214391535066072, 0.9343703555044731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.09631744162763219], {
             RGBColor[
             0.29197171960673096`, 0.42421116775586953`, 0.9399387295469274]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.09631744162763219], {
             RGBColor[
             0.25901133304362195`, 0.3895677116688322, 0.9380616842926806]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.09631744162763219], {
             RGBColor[
             0.5227567642523288, 0.6234365170007214, 0.9555724738845179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.09631744162763219], {
             RGBColor[
             0.19488460571983207`, 0.32216645538218325`, 0.9344097620385824]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.09631744162763219], {
             RGBColor[
             0.9862939640410388, 0.9654284637594515, 0.4012550677774902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.09631744162763219], {
             RGBColor[
             0.2543436096659436, 0.38466163844813683`, 0.9377958643515997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.09631744162763219], {
             RGBColor[
             0.19274031574857725`, 0.3199126706665578, 0.9342876478969121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.09631744162763219], {
             RGBColor[
             0.1914897805011185, 0.3185982788329645, 0.9342164317645705]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.09631744162763219], {
             RGBColor[
             0.5295564396500168, 0.6289567998104505, 0.9561077692398556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.09631744162763219], {
             RGBColor[
             0.19311599281626868`, 0.32030753108400334`, 0.9343090421501528]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.09631744162763219], {
             RGBColor[
             0.22474017350644473`, 0.35354655007824254`, 0.9361099924566755]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.09631744162763219], {
             RGBColor[
             0.35586441424032067`, 0.4826536021746064, 0.9438963436902155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.09631744162763219], {
             RGBColor[
             0.21583585429987417`, 0.3441875460256914, 0.935602904650621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.09631744162763219], {
             RGBColor[
             0.2044144915577996, 0.3321829696275479, 0.9349524749388519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.09631744162763219], {
             RGBColor[
             0.2273767118965443, 0.3563177190924262, 0.9362601394175826]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.09631744162763219], {
             RGBColor[
             0.3306172943235091, 0.4607858158598078, 0.9422876195342679]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.09631744162763219], {
             RGBColor[
             0.27956374695486264`, 0.41116960178785156`, 0.939232113860354]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.09631744162763219], {
             RGBColor[
             0.6860055424687634, 0.754632010702607, 0.9693382794531569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.09631744162763219], {
             RGBColor[
             0.18372407711397143`, 0.31043603219904004`, 0.9337741864450011]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.09631744162763219], {
             RGBColor[
             0.2030597206401025, 0.3307590194956109, 0.934875322739293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.09631744162763219], {
             RGBColor[
             0.9863417120240653, 0.9886199611670301, 0.8760167084848537]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.09631744162763219], {
             RGBColor[
             0.964591061095168, 0.9731126518583681, 0.9448222768222637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.09631744162763219], {
             RGBColor[
             0.19839476243792764`, 0.32585585264969186`, 0.9346096602708663]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.09631744162763219], {
             RGBColor[
             0.3655703148691659, 0.4910603654665621, 0.9445147950956946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.09631744162763219], {
             RGBColor[
             0.8453640923839973, 0.3496938695012485, 0.19107401213931735`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.09631744162763219], {
             RGBColor[
             0.8665707356341262, 0.4870106983585556, 0.21037568997361125`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.09631744162763219], {
             RGBColor[
             0.9371250918628792, 0.9526285769763242, 0.9913149984604726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.09631744162763219], {
             RGBColor[
             0.4836083421786542, 0.5916540643449961, 0.9524905666934831]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.09631744162763219], {
             RGBColor[
             0.3723597127044757, 0.4969410006264502, 0.9449474095221317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.09631744162763219], {
             RGBColor[
             0.22242260484653656`, 0.35111063847433904`, 0.9359780103500293]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.09631744162763219], {
             RGBColor[
             0.18528775379377113`, 0.3120795555323372, 0.9338632355186633]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.09631744162763219], {
             RGBColor[
             0.18931653926981418`, 0.3163140645074111, 0.9340926688914699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.09631744162763219], {
             RGBColor[
             0.1804556557285978, 0.30700071409312746`, 0.9335880546823002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.09631744162763219], {
             RGBColor[
             0.4716790509924657, 0.5819693283516046, 0.9515514491928728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.09631744162763219], {
             RGBColor[
             0.2707327274798912, 0.4018876404006824, 0.9387292003655769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.09631744162763219], {
             RGBColor[
             0.23336863550083925`, 0.36261561071043924`, 0.9366013706025906]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.09631744162763219], {
             RGBColor[
             0.20237506472464956`, 0.3300394027187775, 0.9348363325977657]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.09631744162763219], {
             RGBColor[
             0.20083038530367384`, 0.32841584670900015`, 0.9347483653898895]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.09631744162763219], {
             RGBColor[
             0.22474171532416531`, 0.3535481706264238, 0.9361100802609137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.09631744162763219], {
             RGBColor[
             0.8664637178535413, 0.48652475561155717`, 0.21028639171424535`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.09631744162763219], {
             RGBColor[
             0.20003824461178885`, 0.32758325661720833`, 0.9347032541493537]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.09631744162763219], {
             RGBColor[
             0.9671895696970209, 0.9750506153189628, 0.9404236795589124]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.09631744162763219], {
             RGBColor[
             0.18433414396946993`, 0.31107725114464163`, 0.9338089288499086]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.09631744162763219], {
             RGBColor[
             0.33308943974472227`, 0.4629270639700209, 0.9424451424544752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.09631744162763219], {
             RGBColor[
             0.1861956076915163, 0.31303376754012907`, 0.9339149364550904]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.09631744162763219], {
             RGBColor[
             0.2214255710569613, 0.35006269274590207`, 0.9359212307506922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.09631744162763219], {
             RGBColor[
             0.1814903715451621, 0.30808826602110845`, 0.9336469802173286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.09631744162763219], {
             RGBColor[
             0.20866772558178895`, 0.33665338825737323`, 0.9351946903244223]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.09631744162763219], {
             RGBColor[
             0.2275966301752516, 0.35654886714697176`, 0.936272663438215]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.09631744162763219], {
             RGBColor[
             0.9862571365941499, 0.9885849870532707, 0.8774183422327487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.09631744162763219], {
             RGBColor[
             0.952704487454567, 0.8501960835922951, 0.28080312431882476`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.09631744162763219], {
             RGBColor[
             0.426257062503514, 0.5436241760628097, 0.9483817009917713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.09631744162763219], {
             RGBColor[
             0.2177123475199571, 0.3461598593765405, 0.9357097681634818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.09631744162763219], {
             RGBColor[
             0.19208551837244375`, 0.31922443710768994`, 0.9342503581550272]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.09631744162763219], {
             RGBColor[
             0.23118072954041266`, 0.36031598282478083`, 0.9364767725948611]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.09631744162763219], {
             RGBColor[
             0.18790775611424687`, 0.3148333440888988, 0.9340124407748683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.09631744162763219], {
             RGBColor[
             0.20539561179114207`, 0.3332141891994065, 0.9350083482847035]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.09631744162763219], {
             RGBColor[
             0.1941551643020383, 0.3213997662028249, 0.9343682214289508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.09631744162763219], {
             RGBColor[
             0.40849384697781144`, 0.528238571579618, 0.9472498446058684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.09631744162763219], {
             RGBColor[
             0.23143093535124384`, 0.3605789649959291, 0.9364910214456416]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.09631744162763219], {
             RGBColor[
             0.8250746635773962, 0.19374042880931708`, 0.17164483220048377`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.09631744162763219], {
             RGBColor[
             0.1874435235211163, 0.31434540619947215`, 0.9339860034154601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.09631744162763219], {
             RGBColor[
             0.23757609093788187`, 0.36703791314285356`, 0.9368409789653577]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.09631744162763219], {
             RGBColor[
             0.18053047455342514`, 0.3070793534218085, 0.9335923155036896]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.09631744162763219], {
             RGBColor[
             0.986124206873734, 0.9885300171977407, 0.8796213317111282]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.09631744162763219], {
             RGBColor[
             0.18088209567567362`, 0.3074489295153584, 0.9336123398064248]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.09631744162763219], {
             RGBColor[
             0.9874175082770378, 0.9890648305643368, 0.8581879805016432]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.09631744162763219], {
             RGBColor[
             0.1895037720729246, 0.31651085805472556`, 0.934103331522621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.09631744162763219], {
             RGBColor[
             0.22524249753236514`, 0.35407452447866766`, 0.9361385990668298]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.09631744162763219], {
             RGBColor[
             0.1844498116639085, 0.31119882522525194`, 0.9338155159539919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.09631744162763219], {
             RGBColor[
             0.19775641494300986`, 0.32518490895896446`, 0.9345733073253814]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.09631744162763219], {
             RGBColor[
             0.22195872707107797`, 0.35062307352078237`, 0.9359515931969625]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.09631744162763219], {
             RGBColor[
             0.20745669335557887`, 0.3353805166037485, 0.9351257238307011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.09631744162763219], {
             RGBColor[
             0.18265386603570732`, 0.30931117250048296`, 0.9337132395073293]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.09631744162763219], {
             RGBColor[
             0.28560729073547014`, 0.4175217494840773, 0.9395762847380378]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.09631744162763219], {
             RGBColor[
             0.23794228148785246`, 0.3674228026286945, 0.9368618329754481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.09631744162763219], {
             RGBColor[
             0.19184993915614282`, 0.3189768284147727, 0.9342369422671671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.09631744162763219], {
             RGBColor[
             0.31878183695974033`, 0.45053453755869494`, 0.9415334746567325]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.09631744162763219], {
             RGBColor[
             0.3660178719215669, 0.49144801689048034`, 0.9445433130353144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.09631744162763219], {
             RGBColor[
             0.817928104297447, 0.13880884254138265`, 0.16480127896312016`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.09631744162763219], {
             RGBColor[
             0.18407578926115742`, 0.31080570396557056`, 0.9337942159314718]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.09631744162763219], {
             RGBColor[
             0.340161519599846, 0.46905254408746033`, 0.942895769129249]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.09631744162763219], {
             RGBColor[
             0.18516129488531852`, 0.3119466392015956, 0.9338560338709061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.09631744162763219], {
             RGBColor[
             0.25816755850577977`, 0.38868085113116446`, 0.938013632581003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.09631744162763219], {
             RGBColor[
             0.24473644409614725`, 0.3745638983048021, 0.9372487504849276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.09631744162763219], {
             RGBColor[
             0.3038398335581257, 0.4366853080006712, 0.9406146010791581]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.09631744162763219], {
             RGBColor[
             0.20988927253459944`, 0.3379373115553272, 0.935264255616268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.09631744162763219], {
             RGBColor[
             0.2962099519152749, 0.42866581863159803`, 0.9401800906069961]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.09631744162763219], {
             RGBColor[
             0.22271583997709107`, 0.35141884718873295`, 0.9359947096569118]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.09631744162763219], {
             RGBColor[
             0.1981497507744529, 0.3255983298567432, 0.9345957072190938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.09631744162763219], {
             RGBColor[
             0.1962060745132835, 0.32355540287006146`, 0.9344850177314316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.09631744162763219], {
             RGBColor[
             0.20504953117466115`, 0.3328504365287066, 0.9349886395055752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.09631744162763219], {
             RGBColor[
             0.9731648978995463, 0.9211410408128702, 0.3502511250338943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.09631744162763219], {
             RGBColor[
             0.2128391460228046, 0.3410378156242125, 0.9354322465474746]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.09631744162763219], {
             RGBColor[
             0.2226352176445654, 0.3513341080054973, 0.9359901183343445]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.09631744162763219], {
             RGBColor[
             0.17908821045117204`, 0.30556344240551475`, 0.9335101806967048]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.09631744162763219], {
             RGBColor[
             0.2389301514139497, 0.3684611165555936, 0.9369180907063167]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.09631744162763219], {
             RGBColor[
             0.46304655962256364`, 0.5749610829682137, 0.9508718678503764]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.09631744162763219], {
             RGBColor[
             0.1801747671672662, 0.30670548240580453`, 0.9335720584942697]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.09631744162763219], {
             RGBColor[
             0.24137384732010603`, 0.3710295958922332, 0.9370572555730482]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.09631744162763219], {
             RGBColor[
             0.9930111873350895, 0.9874599613241353, 0.4806890552557963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.09631744162763219], {
             RGBColor[
             0.2006299825882091, 0.3282052107487807, 0.934736952751713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.09631744162763219], {
             RGBColor[
             0.23666672657285628`, 0.3660821135381808, 0.9367891920100534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.09631744162763219], {
             RGBColor[
             0.2620129130085561, 0.39272256252313964`, 0.938232619831244]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.09631744162763219], {
             RGBColor[
             0.9784615748157791, 0.9834572582803182, 0.9213431151026323]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.09631744162763219], {
             RGBColor[
             0.4406321468160179, 0.5560751515815551, 0.9492976686527762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.09631744162763219], {
             RGBColor[
             0.3058207768282486, 0.438767404976628, 0.9407274128678487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.09631744162763219], {
             RGBColor[
             0.24095771526907575`, 0.3705922147223045, 0.9370335574683543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.09631744162763219], {
             RGBColor[
             0.1996796674968478, 0.327206369334303, 0.9346828337131252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.09631744162763219], {
             RGBColor[
             0.22089074136906994`, 0.34950055283376746`, 0.9358907729911765]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.09631744162763219], {
             RGBColor[
             0.2430009596347453, 0.3727397940997984, 0.9371499172122699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.09631744162763219], {
             RGBColor[
             0.20886533678518346`, 0.33686109016141486`, 0.9352059439901159]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.09631744162763219], {
             RGBColor[
             0.2434445902532613, 0.3732060780076645, 0.9371751813197018]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.09631744162763219], {
             RGBColor[
             0.9464109372448213, 0.8252442542119368, 0.27573918609145315`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.09631744162763219], {
             RGBColor[
             0.926874823682218, 0.9445288413300859, 0.9928873421853748]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.09631744162763219], {
             RGBColor[
             0.773715577090376, 0.8231517563699634, 0.978080396007364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.09631744162763219], {
             RGBColor[
             0.8997587664774066, 0.6377097951563564, 0.23806859642232206`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.09631744162763219], {
             RGBColor[
             0.5360494193639693, 0.63422809324764, 0.9566189203875064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.09631744162763219], {
             RGBColor[
             0.19692281060910452`, 0.3243087379504625, 0.9345258347917725]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.09631744162763219], {
             RGBColor[
             0.18720713771192796`, 0.31409694972628927`, 0.9339725415933283]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.09631744162763219], {
             RGBColor[
             0.19199315011410678`, 0.319127352211692, 0.9342450979193615]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.09631744162763219], {
             RGBColor[
             0.2601377913887575, 0.39075169081115385`, 0.9381258344289902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.09631744162763219], {
             RGBColor[
             0.8186938987840391, 0.1446950745386128, 0.16553460462832187`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.09631744162763219], {
             RGBColor[
             0.2256459244954445, 0.3544985517956109, 0.9361615736355604]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{{3.834946926643799*^9, 3.8349469478612347`*^9}, 
   3.834947050298876*^9, {3.8349471234738255`*^9, 3.8349471300172663`*^9}, {
   3.8349471617829676`*^9, 3.834947218900016*^9}, {3.8349472753220577`*^9, 
   3.834947307624898*^9}, 3.83494993428115*^9, {3.8350086729104595`*^9, 
   3.835008748621455*^9}, 3.8350238803114977`*^9, 3.8350517312731376`*^9},
 Background->RGBColor[1, 1, 0.85],
 CellLabel->
  "Out[400]=",ExpressionUUID->"2d32cc3f-5227-4eb1-a0a6-88507b6f0352"]
}, Open  ]],

Cell["Estimated with cubic Mean Deviation v Calculated: (r=6)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 
  3.834950339812094*^9}},ExpressionUUID->"6db8d9cc-ee85-452b-a190-\
b637ddc73c11"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraphb", "[", 
     RowBox[{"graphin3", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsi3", ",", "#"}], "}"}], "]"}], ",", "500", ",", "3"}], 
     "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"CMDi6300", ",", "kri3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.834950273560528*^9, 3.834950273964845*^9}, {
   3.835008763130588*^9, 3.8350087840842075`*^9}, 3.835051760058012*^9},
 CellLabel->
  "In[401]:=",ExpressionUUID->"77514eb2-2b53-4011-b4ca-3886c39db7a2"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1FO4EAYYBuBzsm2dTrZdW7WsZbtVy3bLtWxr2bat5WVjyzZXrfc8u3i/
//a7+f7gJu2rtAsMCAjIJEJuKEIThrCEIzwRiEgkIhOFqEQjOjGISSxiE4e4
xCM+CUhIIhKThKQkI4jkBJOClKQiNWlISzrSk4GMIX3JTBayko3s5CAnuchN
HvKSj/wUoCCF+IEfKUwRivITxShOCUpSitKUoSzlKE8FfqYilahMFapSjerU
oCa1qE0d6lKP+jSgIY1oTBN+oSnNaM6vtKAlrWhNG9rSjvZ0oCOd6EwXutKN
7vSgJ73ozW/0oS/96M8ABjKIwQzhd4YyjOGMYCSjGM0YxjKO8UxgIpOYzBSm
Mo3pzGAms5jNH8xhLvOYzwIWsojFLGEpy1jOClayitWsYS3rWM8GNrKJzWxh
K9vYzg52sovd7GEv+9jPAQ5yiMMc4U+OcozjnOAkpzjNX5zhLOc4zwUuconL
XOEq17jODW5yi9v8zT/c4S73uM8DHvKIxzzhKc94zgte8orXvOEt73jPBz7y
ic/8yxe+8o3/CBl/IKEITRjCEo7wRCAikYhMFKISjejEICaxiE0c4hKP+CQg
IYlITBKSkowgkhNMClKSitSkIS3pSE8GMgb+/6++Az6VhWw=
          "], {Null, CompressedData["
1:eJxN2guYllWBB/D3qyhJJoMEhjQEkUhkrd1Es1FL08DywkWybEVNDSyNClNB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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[72, 227] -> 
             RGBColor[
              0.7585504718114455, 0.8114010956402093, 0.9765432892154127], 
             UndirectedEdge[132, 236] -> 
             RGBColor[
              0.5161006963173367, 0.617740814113529, 0.9551291662623501], 
             UndirectedEdge[187, 193] -> 
             RGBColor[
              0.650729147378852, 0.7243658404931125, 0.9677600587119612], 
             UndirectedEdge[196, 225] -> 
             RGBColor[
              0.9793988904083151, 0.9809862461982396, 0.7319076592983352], 
             UndirectedEdge[39, 166] -> 
             RGBColor[
              0.6452572665372858, 0.7182548382706837, 0.9680427877685633], 
             UndirectedEdge[7, 216] -> 
             RGBColor[
              0.8135124498567897, 0.854264213574268, 0.9820409159299897], 
             UndirectedEdge[92, 281] -> 
             RGBColor[
              0.3183419984677002, 0.44139802399185757`, 0.9418260320236729], 
             UndirectedEdge[99, 229] -> 
             RGBColor[
              0.6112764043555527, 0.6937980334942706, 0.9635684787370247], 
             UndirectedEdge[187, 296] -> 
             RGBColor[
              0.6877187069295674, 0.7544269712805022, 0.9706633530062099], 
             UndirectedEdge[100, 244] -> 
             RGBColor[
              0.5197633961734479, 0.6202709196930796, 0.9555400309748359], 
             UndirectedEdge[232, 245] -> 
             RGBColor[
              0.4859260105741351, 0.592140790246307, 0.9530584264864687], 
             UndirectedEdge[6, 52] -> 
             RGBColor[
              0.6496138251785487, 0.7245034139320219, 0.9668727843952472], 
             UndirectedEdge[113, 160] -> 
             RGBColor[
              0.9822641856218481, 0.9862932391932807, 0.9149062868876945], 
             UndirectedEdge[176, 288] -> 
             RGBColor[
              0.5551042377074124, 0.6491984044204511, 0.9583882701496319], 
             UndirectedEdge[187, 228] -> 
             RGBColor[
              0.7063207918589443, 0.7695289818405464, 0.9721277772735327], 
             UndirectedEdge[61, 268] -> 
             RGBColor[
              0.8011901526297445, 0.8449414267283898, 0.9539894905032218], 
             UndirectedEdge[51, 101] -> 
             RGBColor[
              0.6971953372012774, 0.7622098268200721, 0.9713066052000929], 
             UndirectedEdge[207, 214] -> 
             RGBColor[
              0.7866757372809401, 0.8329549364430773, 0.9474012108940646], 
             UndirectedEdge[17, 162] -> 
             RGBColor[
              0.7944466750793241, 0.83934704768111, 0.9801466781117768], 
             UndirectedEdge[20, 279] -> 
             RGBColor[
              0.5662565673229568, 0.6581021018046017, 0.9594188152029395], 
             UndirectedEdge[51, 197] -> 
             RGBColor[
              0.5977314717630253, 0.6843043621299878, 0.9614747575011628], 
             UndirectedEdge[86, 94] -> 
             RGBColor[
              0.5633989908707887, 0.6554886836003657, 0.9592952803925809], 
             UndirectedEdge[55, 114] -> 
             RGBColor[
              0.5200453968670756, 0.6172569342292017, 0.956821078350901], 
             UndirectedEdge[13, 270] -> 
             RGBColor[
              0.7609347530136068, 0.8133646770724166, 0.976754139650952], 
             UndirectedEdge[151, 220] -> 
             RGBColor[
              0.7571457324052928, 0.8102072677664927, 0.9764288687431573], 
             UndirectedEdge[117, 225] -> 
             RGBColor[
              0.9122236248781688, 0.9320799050230855, 0.9649159683862735], 
             UndirectedEdge[13, 277] -> 
             RGBColor[
              0.7660518294088576, 0.8174448948906512, 0.9772422109655992], 
             UndirectedEdge[81, 237] -> 
             RGBColor[
              0.6806627723698435, 0.750458198094774, 0.9688057620607218], 
             UndirectedEdge[172, 174] -> 
             RGBColor[
              0.7734700675331163, 0.8233790022013943, 0.9779447256401717], 
             UndirectedEdge[128, 197] -> 
             RGBColor[
              0.7473139119421042, 0.8027561660952995, 0.9754157667066958], 
             UndirectedEdge[44, 71] -> 
             RGBColor[
              0.541820497374335, 0.6363354221988186, 0.9581163046488677], 
             UndirectedEdge[70, 122] -> 
             RGBColor[
              0.7569311891683828, 0.8100396649592294, 0.9764074850783225], 
             UndirectedEdge[42, 293] -> 
             RGBColor[
              0.41033716453562147`, 0.5250342337333245, 0.9480991602843132], 
             UndirectedEdge[154, 181] -> 
             RGBColor[
              0.896100673584628, 0.9194976470785008, 0.9728690846254533], 
             UndirectedEdge[42, 216] -> 
             RGBColor[
              0.5430639911626862, 0.630308417758467, 0.960243104226853], 
             UndirectedEdge[125, 130] -> 
             RGBColor[
              0.8600050583744576, 0.8909627274016705, 0.9593861042478538], 
             UndirectedEdge[173, 263] -> 
             RGBColor[
              0.804952541304887, 0.8462902154259102, 0.8922682585859025], 
             UndirectedEdge[112, 132] -> 
             RGBColor[
              0.5302779812356327, 0.6295425797747316, 0.9561645716365692], 
             UndirectedEdge[208, 279] -> 
             RGBColor[
              0.545847166711143, 0.6404245048009499, 0.958118346243279], 
             UndirectedEdge[271, 295] -> 
             RGBColor[
              0.49254387353785467`, 0.598708801370107, 0.9532491351525261], 
             UndirectedEdge[193, 264] -> 
             RGBColor[
              0.7079803621531973, 0.7692918363002756, 0.9480994751548637], 
             UndirectedEdge[16, 39] -> 
             RGBColor[
              0.6969827772695133, 0.756629573061274, 0.8593059248427425], 
             UndirectedEdge[168, 282] -> 
             RGBColor[
              0.49219307813914553`, 0.5986235397356707, 0.953166388555217], 
             UndirectedEdge[92, 243] -> 
             RGBColor[
              0.5859714533976514, 0.6552134180834019, 0.9458284376685222], 
             UndirectedEdge[71, 280] -> 
             RGBColor[
              0.6461904356915575, 0.7185499032737216, 0.9683385022703042], 
             UndirectedEdge[69, 118] -> 
             RGBColor[
              0.6711027114275616, 0.7428685148461756, 0.9679358318362126], 
             UndirectedEdge[175, 253] -> 
             RGBColor[
              0.6564377854713148, 0.7295895998937256, 0.967720265576447], 
             UndirectedEdge[137, 179] -> 
             RGBColor[
              0.6906357569408612, 0.7564631366684309, 0.9712751511124469], 
             UndirectedEdge[134, 221] -> 
             RGBColor[
              0.9043483891113263, 0.9086815834743941, 0.6852547540595664], 
             UndirectedEdge[91, 163] -> 
             RGBColor[
              0.6046515644825814, 0.6896190949985961, 0.9622269073537275], 
             UndirectedEdge[160, 232] -> 
             RGBColor[
              0.6914251372302653, 0.7539231065605885, 0.9320207176077777], 
             UndirectedEdge[135, 263] -> 
             RGBColor[
              0.6124829435663001, 0.6962802714861178, 0.9626360473979384], 
             UndirectedEdge[160, 297] -> 
             RGBColor[
              0.8449863619193356, 0.878963979832976, 0.9444228997017833], 
             UndirectedEdge[179, 274] -> 
             RGBColor[
              0.4575850036531357, 0.5698689693249552, 0.95062377027699], 
             UndirectedEdge[209, 259] -> 
             RGBColor[
              0.750125180021531, 0.8045091016655641, 0.9762463849754051], 
             UndirectedEdge[14, 173] -> 
             RGBColor[
              0.7138654123068122, 0.771928016754202, 0.8852118150720752], 
             UndirectedEdge[260, 267] -> 
             RGBColor[
              0.7312531376455162, 0.7896096710042455, 0.974275289617951], 
             UndirectedEdge[203, 216] -> 
             RGBColor[
              0.8994681220210208, 0.9190476196203405, 0.8239492976806639], 
             UndirectedEdge[37, 279] -> 
             RGBColor[
              0.8378095429027744, 0.8706732629296448, 0.8012876913312498], 
             UndirectedEdge[192, 220] -> 
             RGBColor[
              0.5509130488886548, 0.6442396076660053, 0.9586835376470213], 
             UndirectedEdge[60, 225] -> 
             RGBColor[
              0.7276079534760571, 0.7852040826151303, 0.9481968302453667], 
             UndirectedEdge[177, 226] -> 
             RGBColor[
              0.647896258224513, 0.7236219294336153, 0.966386889314225], 
             UndirectedEdge[91, 273] -> 
             RGBColor[
              0.49408861785191915`, 0.5998288595508992, 0.953407777310076], 
             UndirectedEdge[52, 273] -> 
             RGBColor[
              0.604409478427357, 0.6874709240900982, 0.9634062975550939], 
             UndirectedEdge[21, 114] -> 
             RGBColor[
              0.6890164946945937, 0.75698418946551, 0.9696383830320793], 
             UndirectedEdge[7, 202] -> 
             RGBColor[
              0.6883782976383543, 0.7551541046801349, 0.9704946951297799], 
             UndirectedEdge[94, 293] -> 
             RGBColor[
              0.6116103506845996, 0.6949269431535832, 0.9630082877316373], 
             UndirectedEdge[132, 133] -> 
             RGBColor[
              0.502293809022969, 0.6057819822934808, 0.9542494036129041], 
             UndirectedEdge[13, 93] -> 
             RGBColor[
              0.7802874226113553, 0.8287959704954393, 0.9786000145535174], 
             UndirectedEdge[141, 178] -> 
             RGBColor[
              0.7083606536497351, 0.7720959934623197, 0.9715664280152845], 
             UndirectedEdge[245, 264] -> 
             RGBColor[
              0.766851329393894, 0.8171172795965752, 0.9527253540167049], 
             UndirectedEdge[5, 83] -> 
             RGBColor[
              0.6816538906167996, 0.7512324672020737, 0.9689045474650517], 
             UndirectedEdge[210, 226] -> 
             RGBColor[
              0.6887848178036264, 0.7568032017174768, 0.9696152916447314], 
             UndirectedEdge[91, 298] -> 
             RGBColor[
              0.5200097747974766, 0.6212063872108078, 0.955356220812078], 
             UndirectedEdge[126, 192] -> 
             RGBColor[
              0.6629874562290348, 0.7325919662200887, 0.9696420425184811], 
             UndirectedEdge[127, 156] -> 
             RGBColor[
              0.6043036786843685, 0.6881974007661751, 0.9629784421226182], 
             UndirectedEdge[36, 268] -> 
             RGBColor[
              0.5517943666679117, 0.6470105507707733, 0.9578584203149151], 
             UndirectedEdge[25, 221] -> 
             RGBColor[
              0.7855160148165434, 0.8149727001225067, 0.6739892933577682], 
             UndirectedEdge[69, 249] -> 
             RGBColor[
              0.5882075230518824, 0.6765723915172819, 0.9607249973712482], 
             UndirectedEdge[22, 161] -> 
             RGBColor[
              0.494553029494304, 0.6005394545603855, 0.9533521725706817], 
             UndirectedEdge[96, 112] -> 
             RGBColor[
              0.43188007847164067`, 0.5480166639094344, 0.9488720359127287], 
             UndirectedEdge[219, 250] -> 
             RGBColor[
              0.5275490310594638, 0.6273270950839132, 0.9559497386822273], 
             UndirectedEdge[41, 219] -> 
             RGBColor[
              0.6227352970183443, 0.7041552965902315, 0.9637496535238765], 
             UndirectedEdge[202, 237] -> 
             RGBColor[
              0.5990929194369852, 0.6853808509034713, 0.961601623481775], 
             UndirectedEdge[91, 235] -> 
             RGBColor[
              0.6601159867000543, 0.7329483231801076, 0.9677550826158705], 
             UndirectedEdge[69, 263] -> 
             RGBColor[
              0.627351095616238, 0.7083509071228744, 0.963806522791145], 
             UndirectedEdge[12, 239] -> 
             RGBColor[
              0.8014369750207327, 0.8448995276337952, 0.9808190968614404], 
             UndirectedEdge[122, 266] -> 
             RGBColor[
              0.6093865922316766, 0.6927403329974158, 0.9630938968233325], 
             UndirectedEdge[206, 254] -> 
             RGBColor[
              0.5556884116831101, 0.6498461782977958, 0.9583654802137891], 
             UndirectedEdge[137, 270] -> 
             RGBColor[
              0.8697929136706999, 0.8990132757340719, 0.9874428186508535], 
             UndirectedEdge[25, 58] -> 
             RGBColor[
              0.6304731531630989, 0.71042226069383, 0.9643690451464478], 
             UndirectedEdge[107, 156] -> 
             RGBColor[
              0.6451992692146334, 0.7201453469064178, 0.967054532395653], 
             UndirectedEdge[136, 194] -> 
             RGBColor[
              0.6236204038500572, 0.704782473027767, 0.9638818183799645], 
             UndirectedEdge[45, 281] -> 
             RGBColor[
              0.46952012108394336`, 0.5793835441623516, 0.9516116693905781], 
             UndirectedEdge[137, 147] -> 
             RGBColor[
              0.6607055629737651, 0.731429001762973, 0.9691221450417196], 
             UndirectedEdge[164, 187] -> 
             RGBColor[
              0.6580785170655603, 0.7303637298735646, 0.9683299686845221], 
             UndirectedEdge[199, 229] -> 
             RGBColor[
              0.686826592135103, 0.7533969041858831, 0.9709451019934411], 
             UndirectedEdge[191, 271] -> 
             RGBColor[
              0.7170489768752117, 0.7779080235474254, 0.9733528333325263], 
             UndirectedEdge[153, 222] -> 
             RGBColor[
              0.7204046364711674, 0.7815048443800824, 0.9727668596655062], 
             UndirectedEdge[158, 186] -> 
             RGBColor[
              0.8443621338611412, 0.8750619380689266, 0.7434507876884304], 
             UndirectedEdge[16, 192] -> 
             RGBColor[
              0.6998842748979844, 0.7591427044735445, 0.8594908057059351], 
             UndirectedEdge[75, 143] -> 
             RGBColor[
              0.5780216616068385, 0.6669692971827674, 0.9607284913017713], 
             UndirectedEdge[204, 226] -> 
             RGBColor[
              0.8447796214154373, 0.8792565572921176, 0.9673879875357372], 
             UndirectedEdge[137, 191] -> 
             RGBColor[
              0.8950795236614558, 0.9191761321539575, 0.9898546780853951], 
             UndirectedEdge[197, 198] -> 
             RGBColor[
              0.6701763701249523, 0.7421997627992363, 0.9678059585979857], 
             UndirectedEdge[80, 156] -> 
             RGBColor[
              0.670114254668532, 0.7399984376358872, 0.9694345131423843], 
             UndirectedEdge[103, 159] -> 
             RGBColor[
              0.6941981192869466, 0.7604886683628362, 0.9705263956821151], 
             UndirectedEdge[28, 288] -> 
             RGBColor[
              0.713175178640016, 0.772843610152091, 0.9345991341988783], 
             UndirectedEdge[118, 263] -> 
             RGBColor[
              0.6640126320899755, 0.7371124690354889, 0.9673776748189414], 
             UndirectedEdge[68, 83] -> 
             RGBColor[
              0.5934800017870587, 0.6796584137898773, 0.9619566932354141], 
             UndirectedEdge[64, 90] -> 
             RGBColor[
              0.750241786031379, 0.8050539062248314, 0.975677044982139], 
             UndirectedEdge[213, 263] -> 
             RGBColor[
              0.5943604140455949, 0.6815675856105583, 0.9612093754890554], 
             UndirectedEdge[52, 53] -> 
             RGBColor[
              0.6741077538166176, 0.7443886886393167, 0.968801036181853], 
             UndirectedEdge[245, 297] -> 
             RGBColor[
              0.6394872352632055, 0.7171816635186945, 0.9654606085804742], 
             UndirectedEdge[189, 267] -> 
             RGBColor[
              0.7649232491413365, 0.8166993192186031, 0.9770936132340877], 
             UndirectedEdge[145, 203] -> 
             RGBColor[
              0.8056459952326771, 0.8453580235610267, 0.8148680742220394], 
             UndirectedEdge[136, 279] -> 
             RGBColor[
              0.6254265033100725, 0.7061934116527953, 0.9640618334951798], 
             UndirectedEdge[80, 256] -> 
             RGBColor[
              0.6695345124790275, 0.7395277768093595, 0.9693888737135608], 
             UndirectedEdge[40, 130] -> 
             RGBColor[
              0.7416103957962125, 0.7980709447345478, 0.9748804515759388], 
             UndirectedEdge[83, 101] -> 
             RGBColor[
              0.7786417049346004, 0.8271372437759563, 0.9785349886403425], 
             UndirectedEdge[83, 194] -> 
             RGBColor[
              0.6989597936575789, 0.7647519701872652, 0.9706294381472977], 
             UndirectedEdge[149, 197] -> 
             RGBColor[
              0.7512674459000004, 0.8059086067575056, 0.9757928583049613], 
             UndirectedEdge[23, 44] -> 
             RGBColor[
              0.5809960024420958, 0.6699058186196832, 0.9607124048503151], 
             UndirectedEdge[97, 284] -> 
             RGBColor[
              0.7395587376211133, 0.7953402387035109, 0.9607773416297416], 
             UndirectedEdge[135, 276] -> 
             RGBColor[
              0.5512522674103033, 0.6465704501721534, 0.9578157442755811], 
             UndirectedEdge[142, 150] -> 
             RGBColor[
              0.6917257404098023, 0.758597229368495, 0.9702526223556388], 
             UndirectedEdge[46, 214] -> 
             RGBColor[
              0.9052128526536327, 0.9263311604683118, 0.9587504170392137], 
             UndirectedEdge[5, 243] -> 
             RGBColor[
              0.8004368159892468, 0.8445688889953451, 0.9606027611044491], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.86733296190044, 0.8955482213085187, 0.9067533787839208], 
             UndirectedEdge[198, 243] -> 
             RGBColor[
              0.8301112739424515, 0.8677508010826223, 0.9635604337496484], 
             UndirectedEdge[13, 32] -> 
             RGBColor[
              0.7818484756033772, 0.830040711777623, 0.978748909181465], 
             UndirectedEdge[86, 140] -> 
             RGBColor[
              0.4501287455929941, 0.5641757138387619, 0.9499372977199736], 
             UndirectedEdge[171, 275] -> 
             RGBColor[
              0.8628533647189943, 0.8929437477597211, 0.947313785562736], 
             UndirectedEdge[36, 250] -> 
             RGBColor[
              0.473940657653495, 0.5838054025232473, 0.9517294911537673], 
             UndirectedEdge[168, 203] -> 
             RGBColor[
              0.7306578949148579, 0.7844793055475991, 0.8089647362745583], 
             UndirectedEdge[17, 169] -> 
             RGBColor[
              0.8310159622761497, 0.6997413410019209, 0.6023799260457661], 
             UndirectedEdge[191, 246] -> 
             RGBColor[
              0.7266756126594998, 0.7857233601521103, 0.9741106773649942], 
             UndirectedEdge[17, 178] -> 
             RGBColor[
              0.7191902773277048, 0.780556177787738, 0.9726458236949173], 
             UndirectedEdge[9, 132] -> 
             RGBColor[
              0.5497998629115997, 0.6453913227700288, 0.9577014056731101], 
             UndirectedEdge[11, 283] -> 
             RGBColor[
              0.6995969795715613, 0.763952061791654, 0.9717345304772542], 
             UndirectedEdge[64, 69] -> 
             RGBColor[
              0.6426203862350867, 0.720617905932125, 0.9650969798434887], 
             UndirectedEdge[193, 288] -> 
             RGBColor[
              0.44948402098833345`, 0.5637422000814826, 0.9498617022476311], 
             UndirectedEdge[221, 288] -> 
             RGBColor[
              0.7147456440426275, 0.757341261904761, 0.6684668583189879], 
             UndirectedEdge[65, 264] -> 
             RGBColor[
              0.9790781861028466, 0.9822279480428071, 0.8446545143216091], 
             UndirectedEdge[27, 151] -> 
             RGBColor[
              0.7681502714085997, 0.81880409727347, 0.9775256983477429], 
             UndirectedEdge[201, 293] -> 
             RGBColor[
              0.4839773146928501, 0.5912985602608798, 0.9527006065446126], 
             UndirectedEdge[43, 99] -> 
             RGBColor[
              0.7844780802029757, 0.8316283416249557, 0.9791348347716969], 
             UndirectedEdge[77, 293] -> 
             RGBColor[
              0.7151574729993382, 0.7763972095564078, 0.9731753897025881], 
             UndirectedEdge[61, 280] -> 
             RGBColor[
              0.9347617267211511, 0.9500511756522028, 0.9670656726600582], 
             UndirectedEdge[20, 55] -> 
             RGBColor[
              0.39545373098828235`, 0.5169438785247745, 0.9464189399459373], 
             UndirectedEdge[208, 242] -> 
             RGBColor[
              0.6870694340242556, 0.7511888947356047, 0.9468991779238916], 
             UndirectedEdge[29, 261] -> 
             RGBColor[
              0.4766934150803769, 0.5859973619560465, 0.9519580387293278], 
             UndirectedEdge[12, 76] -> 
             RGBColor[
              0.8437443279890269, 0.8782428405815281, 0.9849582812946887], 
             UndirectedEdge[168, 276] -> 
             RGBColor[
              0.4821972882095399, 0.5905085071656122, 0.9523794833561734], 
             UndirectedEdge[148, 271] -> 
             RGBColor[
              0.499655428256616, 0.604681811736075, 0.9537538520919533], 
             UndirectedEdge[131, 170] -> 
             RGBColor[
              0.5458890110380112, 0.6422163170371806, 0.9573935290876989], 
             UndirectedEdge[141, 261] -> 
             RGBColor[
              0.6281047108796434, 0.7072439137802911, 0.9650410114086714], 
             UndirectedEdge[129, 184] -> 
             RGBColor[
              0.7197200281837264, 0.7797544265884466, 0.9731665937376273], 
             UndirectedEdge[111, 185] -> 
             RGBColor[
              0.6125906941079813, 0.6950539413447072, 0.9635427868580877], 
             UndirectedEdge[234, 239] -> 
             RGBColor[
              0.5934996627897269, 0.6778612506368848, 0.962778912372295], 
             UndirectedEdge[103, 203] -> 
             RGBColor[
              0.8881170103875827, 0.910180044940655, 0.8228179249552121], 
             UndirectedEdge[28, 160] -> 
             RGBColor[
              0.9802250240223773, 0.984772435811216, 0.9183580555770757], 
             UndirectedEdge[133, 170] -> 
             RGBColor[
              0.5134835437318825, 0.6148663130219808, 0.9551303005185385], 
             UndirectedEdge[87, 299] -> 
             RGBColor[
              0.48831125841951234`, 0.5952725737398985, 0.9529159281858302], 
             UndirectedEdge[5, 290] -> 
             RGBColor[
              0.5631035250744809, 0.6561823533087942, 0.9587552014008556], 
             UndirectedEdge[183, 253] -> 
             RGBColor[
              0.5714348799827293, 0.662955604274784, 0.9594045934686284], 
             UndirectedEdge[176, 245] -> 
             RGBColor[
              0.6166549564336434, 0.6993449137652945, 0.9631849004065203], 
             UndirectedEdge[29, 190] -> 
             RGBColor[
              0.5237654388659725, 0.6242125514356986, 0.9556637208722346], 
             UndirectedEdge[159, 168] -> 
             RGBColor[
              0.5367390038142218, 0.6347879289697803, 0.9566732070014613], 
             UndirectedEdge[202, 299] -> 
             RGBColor[
              0.5423000555475268, 0.639302641289403, 0.9571109933647108], 
             UndirectedEdge[65, 115] -> 
             RGBColor[
              0.9036889063311238, 0.92289545196537, 0.8625701326484249], 
             UndirectedEdge[51, 142] -> 
             RGBColor[
              0.5834657515452688, 0.6727228077938411, 0.9603517077485662], 
             UndirectedEdge[134, 187] -> 
             RGBColor[
              0.8376521409620163, 0.8733850960142016, 0.9843772030574928], 
             UndirectedEdge[85, 239] -> 
             RGBColor[
              0.5763317458576347, 0.662991263874901, 0.9616849878863749], 
             UndirectedEdge[120, 284] -> 
             RGBColor[
              0.7778383943756573, 0.8264173885357344, 0.9637908564324622], 
             UndirectedEdge[31, 61] -> 
             RGBColor[
              0.953822079393069, 0.9650811629375319, 0.9630513538436587], 
             UndirectedEdge[217, 247] -> 
             RGBColor[
              0.7609769668256591, 0.8135605800165522, 0.9767151117924097], 
             UndirectedEdge[66, 169] -> 
             RGBColor[
              0.6496509417176869, 0.553470269700968, 0.5869989868766725], 
             UndirectedEdge[168, 293] -> 
             RGBColor[
              0.5026783129315194, 0.6071359256945643, 0.9539918246467531], 
             UndirectedEdge[93, 105] -> 
             RGBColor[
              0.6734398251961596, 0.7425900267796246, 0.9698209181592663], 
             UndirectedEdge[169, 193] -> 
             RGBColor[
              0.6689870516217697, 0.5702182362387427, 0.5882310667015102], 
             UndirectedEdge[87, 216] -> 
             RGBColor[
              0.6250924173182971, 0.7038382473488107, 0.9653790440163083], 
             UndirectedEdge[81, 201] -> 
             RGBColor[
              0.5731398420343378, 0.6625399825831919, 0.9605024682658894], 
             UndirectedEdge[63, 244] -> 
             RGBColor[
              0.5973894236627986, 0.6813581901545389, 0.9629726632551647], 
             UndirectedEdge[32, 150] -> 
             RGBColor[
              0.8300954800242057, 0.8677316383219889, 0.9835577196882426], 
             UndirectedEdge[95, 282] -> 
             RGBColor[
              0.72403522735796, 0.7833243455521792, 0.9741968128018184], 
             UndirectedEdge[126, 239] -> 
             RGBColor[
              0.8451959638644173, 0.8797917575316399, 0.9849928682814615], 
             UndirectedEdge[149, 150] -> 
             RGBColor[
              0.8192330454762626, 0.85907022786639, 0.9825216509840499], 
             UndirectedEdge[16, 222] -> 
             RGBColor[
              0.8710942278721265, 0.8977503412916232, 0.8737453983276201], 
             UndirectedEdge[192, 262] -> 
             RGBColor[
              0.4624653362710699, 0.5732353631904441, 0.9511725560995772], 
             UndirectedEdge[214, 276] -> 
             RGBColor[
              0.7346848095228452, 0.7907463591244515, 0.9433082946119038], 
             UndirectedEdge[48, 100] -> 
             RGBColor[
              0.5582999216113332, 0.6522920533457532, 0.9583705614306941], 
             UndirectedEdge[105, 143] -> 
             RGBColor[
              0.45372767315915297`, 0.5671341001948889, 0.9502105016951954], 
             UndirectedEdge[268, 279] -> 
             RGBColor[
              0.6590802579984473, 0.7335150457931894, 0.9667111803420141], 
             UndirectedEdge[24, 106] -> 
             RGBColor[
              0.7888490073526189, 0.8351995504574299, 0.9604534096371506], 
             UndirectedEdge[33, 222] -> 
             RGBColor[
              0.8633970038961809, 0.8934114766014828, 0.9495463335742187], 
             UndirectedEdge[155, 291] -> 
             RGBColor[
              0.76894603390279, 0.3373670318184505, 0.43213276071244655`], 
             UndirectedEdge[99, 233] -> 
             RGBColor[
              0.6021117382779051, 0.6863577447089344, 0.9628470026521143], 
             UndirectedEdge[237, 269] -> 
             RGBColor[
              0.6585593422190716, 0.7331908304687, 0.9666026987115914], 
             UndirectedEdge[85, 135] -> 
             RGBColor[
              0.4929059592910911, 0.597241592115118, 0.953764255498442], 
             UndirectedEdge[126, 248] -> 
             RGBColor[
              0.8460407665169631, 0.8804517237845466, 0.9850770703147377], 
             UndirectedEdge[188, 261] -> 
             RGBColor[
              0.46156263283016363`, 0.57289183886614, 0.9509939186639698], 
             UndirectedEdge[37, 177] -> 
             RGBColor[
              0.7779532703437871, 0.8226742691059479, 0.7961687646342653], 
             UndirectedEdge[160, 180] -> 
             RGBColor[
              0.729633677759369, 0.7863373827491622, 0.9346432294337301], 
             UndirectedEdge[23, 194] -> 
             RGBColor[
              0.5721099775032372, 0.662963988401156, 0.9598267289290339], 
             UndirectedEdge[51, 243] -> 
             RGBColor[
              0.7576663755805245, 0.8098554004133738, 0.9572292326528258], 
             UndirectedEdge[108, 208] -> 
             RGBColor[
              0.5195462892862842, 0.6196672924004626, 0.9556410231687156], 
             UndirectedEdge[179, 251] -> 
             RGBColor[
              0.6809167198539031, 0.7487134403115243, 0.970348140678806], 
             UndirectedEdge[26, 224] -> 
             RGBColor[
              0.5113860485686575, 0.6138440957951743, 0.954777119621613], 
             UndirectedEdge[106, 291] -> 
             RGBColor[
              0.814613574086645, 0.8556592587937091, 0.9627942313588207], 
             UndirectedEdge[48, 161] -> 
             RGBColor[
              0.5164680051897288, 0.6183310190883357, 0.9550773997346266], 
             UndirectedEdge[227, 299] -> 
             RGBColor[
              0.6079194379794268, 0.6919193596972913, 0.9627253381097435], 
             UndirectedEdge[162, 299] -> 
             RGBColor[
              0.6716624026215987, 0.7417158481402304, 0.9690786411134029], 
             UndirectedEdge[200, 227] -> 
             RGBColor[
              0.6998276376340694, 0.765429936497558, 0.9707159367244114], 
             UndirectedEdge[202, 293] -> 
             RGBColor[
              0.5463543878192468, 0.6425941308731727, 0.957430165252649], 
             UndirectedEdge[3, 155] -> 
             RGBColor[
              0.7623124911704019, 0.33218485781911694`, 0.4314715911668635], 
             UndirectedEdge[39, 234] -> 
             RGBColor[
              0.4083896575258733, 0.5281483279130632, 0.947243205746122], 
             UndirectedEdge[144, 176] -> 
             RGBColor[
              0.6008915070117415, 0.6865474353892906, 0.9619439439246102], 
             UndirectedEdge[140, 162] -> 
             RGBColor[
              0.6352951268895063, 0.7121912553738162, 0.9662156759500522], 
             UndirectedEdge[123, 257] -> 
             RGBColor[
              0.7157888053799351, 0.7768271064313892, 0.9733202159033152], 
             UndirectedEdge[121, 286] -> 
             RGBColor[
              0.8072501933992284, 0.8454126047778857, 0.7127265993413198], 
             UndirectedEdge[176, 230] -> 
             RGBColor[
              0.5031535623990897, 0.6042013405852446, 0.955078019057164], 
             UndirectedEdge[39, 64] -> 
             RGBColor[
              0.5260680154878385, 0.62458401933133, 0.9563115302120421], 
             UndirectedEdge[269, 277] -> 
             RGBColor[
              0.7637602576238003, 0.8156547015955737, 0.9770138085060205], 
             UndirectedEdge[154, 203] -> 
             RGBColor[
              0.974763543124898, 0.9784659702700806, 0.8140818723514924], 
             UndirectedEdge[107, 137] -> 
             RGBColor[
              0.8567501268089132, 0.8886267538997066, 0.9861952188042747], 
             UndirectedEdge[192, 218] -> 
             RGBColor[
              0.5207903018350472, 0.6205861977450365, 0.9557641110401621], 
             UndirectedEdge[247, 270] -> 
             RGBColor[
              0.8544851814696943, 0.8868073055943115, 0.9859827534881478], 
             UndirectedEdge[28, 240] -> 
             RGBColor[
              0.7740029497948854, 0.8224031980900861, 0.9393388513747047], 
             UndirectedEdge[31, 194] -> 
             RGBColor[
              0.8099060853017565, 0.8522438433773031, 0.9755930285672356], 
             UndirectedEdge[58, 187] -> 
             RGBColor[
              0.7609479087797015, 0.8134144628877142, 0.9767449665719976], 
             UndirectedEdge[8, 121] -> 
             RGBColor[
              0.5239188175486968, 0.6236429987367919, 0.9558675696824961], 
             UndirectedEdge[62, 186] -> 
             RGBColor[
              0.7773273702129564, 0.826290865707263, 0.9783561180244842], 
             UndirectedEdge[271, 289] -> 
             RGBColor[
              0.7533373815408311, 0.8060218956119207, 0.948331550827979], 
             UndirectedEdge[236, 294] -> 
             RGBColor[
              0.5985629748494392, 0.6829685945458066, 0.9627960601610841], 
             UndirectedEdge[115, 211] -> 
             RGBColor[
              0.5432473858598247, 0.6293134034370379, 0.9604415903029897], 
             UndirectedEdge[43, 284] -> 
             RGBColor[
              0.8903904765626889, 0.9150096242998558, 0.9745826542874065], 
             UndirectedEdge[87, 181] -> 
             RGBColor[
              0.6416823031343009, 0.7169391199851232, 0.9669952239755344], 
             UndirectedEdge[77, 205] -> 
             RGBColor[
              0.9433098987436308, 0.9542961377100215, 0.8604708272216175], 
             UndirectedEdge[132, 267] -> 
             RGBColor[
              0.7305572411030357, 0.7890447108412779, 0.9742205060929738], 
             UndirectedEdge[108, 280] -> 
             RGBColor[
              0.7663509546649951, 0.8178675823165149, 0.9773100394242871], 
             UndirectedEdge[40, 97] -> 
             RGBColor[
              0.6279629010706652, 0.7075190093558634, 0.9647630499105877], 
             UndirectedEdge[35, 262] -> 
             RGBColor[
              0.7492259344774431, 0.8022512951138462, 0.9364011332268729], 
             UndirectedEdge[201, 216] -> 
             RGBColor[
              0.6167041413199148, 0.6965727442860223, 0.9648445504871526], 
             UndirectedEdge[244, 279] -> 
             RGBColor[
              0.5537170237810319, 0.6472409794443703, 0.958619806576731], 
             UndirectedEdge[143, 163] -> 
             RGBColor[
              0.5529232253296573, 0.6473622080078528, 0.9582269137318841], 
             UndirectedEdge[102, 165] -> 
             RGBColor[
              0.5805306797171799, 0.6703399842603195, 0.9601206481427366], 
             UndirectedEdge[7, 282] -> 
             RGBColor[
              0.6703003884373511, 0.7404776435902318, 0.9690715358959137], 
             UndirectedEdge[10, 122] -> 
             RGBColor[
              0.7182705248912947, 0.7798376601940371, 0.9725541513676311], 
             UndirectedEdge[113, 193] -> 
             RGBColor[
              0.7178940917250212, 0.7766854795826996, 0.9313181169045441], 
             UndirectedEdge[22, 100] -> 
             RGBColor[
              0.5363849459159085, 0.634500488817803, 0.9566453342667492], 
             UndirectedEdge[116, 254] -> 
             RGBColor[
              0.6061556404399435, 0.6892715609677786, 0.9633955819332034], 
             UndirectedEdge[174, 298] -> 
             RGBColor[
              0.5839935101011253, 0.6726495373124897, 0.9607362894550593], 
             UndirectedEdge[159, 271] -> 
             RGBColor[
              0.5730006871399421, 0.6642267970638178, 0.9595278595437847], 
             UndirectedEdge[11, 101] -> 
             RGBColor[
              0.6852573085609408, 0.7525179973677856, 0.9703667998550858], 
             UndirectedEdge[148, 225] -> 
             RGBColor[
              0.7128071674828762, 0.7731881377780554, 0.9470316581549181], 
             UndirectedEdge[239, 248] -> 
             RGBColor[
              0.7724012466395811, 0.822124991432521, 0.9779493958311452], 
             UndirectedEdge[22, 119] -> 
             RGBColor[
              0.7228433757486673, 0.7803139101599701, 0.9143820844044266], 
             UndirectedEdge[38, 247] -> 
             RGBColor[
              0.8666868716901446, 0.8965366021700407, 0.9871465615939518], 
             UndirectedEdge[157, 222] -> 
             RGBColor[
              0.6433652067011739, 0.7197097115250793, 0.9661899745187328], 
             UndirectedEdge[42, 203] -> 
             RGBColor[
              0.63831674651896, 0.7023776135863593, 0.8030720719121183], 
             UndirectedEdge[155, 241] -> 
             RGBColor[
              0.6720975209319928, 0.2577485775343202, 0.4246585563836164], 
             UndirectedEdge[103, 154] -> 
             RGBColor[
              0.8681596761351862, 0.897529199762503, 0.9701215319407752], 
             UndirectedEdge[88, 107] -> 
             RGBColor[
              0.8259558312494903, 0.864072218509508, 0.9832580314034248], 
             UndirectedEdge[58, 176] -> 
             RGBColor[
              0.6680027505937963, 0.7405680928635967, 0.9675439294047153], 
             UndirectedEdge[48, 119] -> 
             RGBColor[
              0.7447583514440921, 0.7981054746879203, 0.9161073115683714], 
             UndirectedEdge[206, 219] -> 
             RGBColor[
              0.6169562947293747, 0.6996406960800443, 0.9631736565835589], 
             UndirectedEdge[1, 125] -> 
             RGBColor[
              0.9206380045586022, 0.9387775360706481, 0.96531057336679], 
             UndirectedEdge[191, 278] -> 
             RGBColor[
              0.8883377458574377, 0.913800421533717, 0.9892116412999917], 
             UndirectedEdge[90, 118] -> 
             RGBColor[
              0.7787241112238541, 0.8273045151388819, 0.9785158969748629], 
             UndirectedEdge[101, 283] -> 
             RGBColor[
              0.8512932629384209, 0.8842621563997944, 0.9856783054491756], 
             UndirectedEdge[5, 226] -> 
             RGBColor[
              0.6886405282827056, 0.7566904816470925, 0.9696009102137482], 
             UndirectedEdge[3, 241] -> 
             RGBColor[
              0.5169770181535922, 0.6166461530301557, 0.9557592213257198], 
             UndirectedEdge[194, 241] -> 
             RGBColor[
              0.529622166084868, 0.6265246387007521, 0.9570195714958833], 
             UndirectedEdge[139, 235] -> 
             RGBColor[
              0.8224581508371408, 0.8616488652017209, 0.9828273999642503], 
             UndirectedEdge[40, 94] -> 
             RGBColor[
              0.7067738638005746, 0.770856381172106, 0.9714082716325143], 
             UndirectedEdge[161, 177] -> 
             RGBColor[
              0.5455601517056125, 0.6419493342161953, 0.9573676400764011], 
             UndirectedEdge[34, 295] -> 
             RGBColor[
              0.6240177673577714, 0.7029987226320057, 0.9652719329514179], 
             UndirectedEdge[1, 281] -> 
             RGBColor[
              0.6490173515722695, 0.7219855130036413, 0.9680642249602255], 
             UndirectedEdge[191, 295] -> 
             RGBColor[
              0.6704745713092044, 0.7398972930824917, 0.969741456217218], 
             UndirectedEdge[144, 297] -> 
             RGBColor[
              0.6237237858413034, 0.7043841851426906, 0.9642196520985642], 
             UndirectedEdge[141, 294] -> 
             RGBColor[
              0.7545623464266888, 0.8081891070055465, 0.9761713809719246], 
             UndirectedEdge[80, 201] -> 
             RGBColor[
              0.648671883912178, 0.7219355024949218, 0.9679274841536731], 
             UndirectedEdge[113, 115] -> 
             RGBColor[
              0.8983214016326277, 0.9205815536755118, 0.9473007567435454], 
             UndirectedEdge[129, 253] -> 
             RGBColor[
              0.7259972757311244, 0.7848505789342035, 0.9736607616588739], 
             UndirectedEdge[37, 108] -> 
             RGBColor[
              0.8115086654779157, 0.8499160505291574, 0.7988103682566864], 
             UndirectedEdge[265, 276] -> 
             RGBColor[
              0.555802700822692, 0.6502646970110197, 0.9581739710625912], 
             UndirectedEdge[59, 194] -> 
             RGBColor[
              0.6111987617618184, 0.6946980243919356, 0.9629039412128041], 
             UndirectedEdge[103, 225] -> 
             RGBColor[
              0.8734674504771267, 0.9014877291760393, 0.9611368544691292], 
             UndirectedEdge[46, 265] -> 
             RGBColor[
              0.7263307439534795, 0.7858494983548802, 0.9736160934899012], 
             UndirectedEdge[51, 149] -> 
             RGBColor[
              0.7109730566117293, 0.773195806291736, 0.9726207363769772], 
             UndirectedEdge[52, 124] -> 
             RGBColor[
              0.8809329019438747, 0.9051696729849051, 0.8626320226883919], 
             UndirectedEdge[82, 258] -> 
             RGBColor[
              0.5888943932956637, 0.6765015548867787, 0.9612087578895476], 
             UndirectedEdge[45, 132] -> 
             RGBColor[
              0.553020636351989, 0.648006091743127, 0.9579549567564194], 
             UndirectedEdge[74, 287] -> 
             RGBColor[
              0.7606818803003881, 0.8121945572890492, 0.954544014473008], 
             UndirectedEdge[128, 269] -> 
             RGBColor[
              0.7647409353124806, 0.8164366673647407, 0.9771073464194282], 
             UndirectedEdge[14, 249] -> 
             RGBColor[
              0.4900303147162213, 0.596454147034887, 0.9531103968401496], 
             UndirectedEdge[101, 198] -> 
             RGBColor[
              0.7696402355632044, 0.8201052274893206, 0.9776378062969157], 
             UndirectedEdge[164, 297] -> 
             RGBColor[
              0.5879656377092171, 0.675354109602847, 0.9614046396911938], 
             UndirectedEdge[68, 235] -> 
             RGBColor[
              0.6198589954702223, 0.7002658841429422, 0.9645859048000403], 
             UndirectedEdge[108, 177] -> 
             RGBColor[
              0.5950448183099422, 0.6821232158244162, 0.9612632542998003], 
             UndirectedEdge[62, 276] -> 
             RGBColor[
              0.6785357590738816, 0.7468996435839399, 0.9700235350668173], 
             UndirectedEdge[13, 107] -> 
             RGBColor[
              0.7478919661518202, 0.8029781552380513, 0.9755065398043734], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.5950599232423275, 0.6821354786889959, 0.9612644434154088], 
             UndirectedEdge[62, 135] -> 
             RGBColor[
              0.7319883625175265, 0.7902948750718344, 0.9742315198132391], 
             UndirectedEdge[18, 35] -> 
             RGBColor[
              0.7118982346692948, 0.7716705174138395, 0.9335389492816302], 
             UndirectedEdge[42, 202] -> 
             RGBColor[
              0.4179298389442508, 0.531198308864334, 0.9486968834266432], 
             UndirectedEdge[121, 255] -> 
             RGBColor[
              0.7547464447791508, 0.8085642413236015, 0.9762609929875063], 
             UndirectedEdge[128, 281] -> 
             RGBColor[
              0.6396193608296522, 0.7144918102871411, 0.9671678362135092], 
             UndirectedEdge[82, 181] -> 
             RGBColor[
              0.6658993696813567, 0.7367991554478269, 0.9688465494656395], 
             UndirectedEdge[136, 204] -> 
             RGBColor[
              0.7624535939420096, 0.8138290456876006, 0.9599440050197076], 
             UndirectedEdge[118, 166] -> 
             RGBColor[
              0.7984711737582714, 0.8430502867840932, 0.9803993894278065], 
             UndirectedEdge[39, 263] -> 
             RGBColor[
              0.5107987248689899, 0.6123170205220794, 0.9550210731596984], 
             UndirectedEdge[52, 84] -> 
             RGBColor[
              0.7379857231062439, 0.7952393228806114, 0.9745191780766949], 
             UndirectedEdge[129, 165] -> 
             RGBColor[
              0.7887613411852208, 0.835805274758766, 0.9786017788037676], 
             UndirectedEdge[141, 236] -> 
             RGBColor[
              0.5985629748494392, 0.6829685945458066, 0.9627960601610841], 
             UndirectedEdge[97, 178] -> 
             RGBColor[
              0.5944980116857721, 0.6813759834258055, 0.9614275824838733], 
             UndirectedEdge[115, 227] -> 
             RGBColor[
              0.7491021096903787, 0.8039235285678048, 0.9756271556028626], 
             UndirectedEdge[256, 281] -> 
             RGBColor[
              0.44677746596758705`, 0.5609200321939563, 0.9498212842707279], 
             UndirectedEdge[221, 297] -> 
             RGBColor[
              0.8458778910768028, 0.8629552820456735, 0.6794398857899897], 
             UndirectedEdge[224, 262] -> 
             RGBColor[
              0.47890396291932114`, 0.5874736753637602, 0.9522200108534971], 
             UndirectedEdge[73, 119] -> 
             RGBColor[
              0.8214909372750874, 0.8601796818655898, 0.922298918512833], 
             UndirectedEdge[3, 227] -> 
             RGBColor[
              0.6687426503014411, 0.7411461081386548, 0.9676176756928174], 
             UndirectedEdge[45, 188] -> 
             RGBColor[
              0.46894083683461174`, 0.5788817972612537, 0.9515747579104517], 
             UndirectedEdge[260, 300] -> 
             RGBColor[
              0.6270779720032561, 0.7078110435773318, 0.9640025283712954], 
             UndirectedEdge[23, 291] -> 
             RGBColor[
              0.5694151436705435, 0.66085876372956, 0.959558133077245], 
             UndirectedEdge[142, 149] -> 
             RGBColor[
              0.7370017256822439, 0.7943270524213588, 0.9746698085523645], 
             UndirectedEdge[81, 97] -> 
             RGBColor[
              0.6219619152961778, 0.7028309936596527, 0.9641649277309873], 
             UndirectedEdge[181, 201] -> 
             RGBColor[
              0.6332940271359185, 0.7096736169223348, 0.9664607304463788], 
             UndirectedEdge[56, 57] -> 
             RGBColor[
              0.826895781760868, 0.8650909591219876, 0.9557545337401362], 
             UndirectedEdge[197, 243] -> 
             RGBColor[
              0.7979607648687956, 0.8425682008791434, 0.9604013545808099], 
             UndirectedEdge[65, 200] -> 
             RGBColor[
              0.8544144342748146, 0.8844018598951233, 0.8576589137699736], 
             UndirectedEdge[8, 173] -> 
             RGBColor[
              0.7079108333781993, 0.7667704597720766, 0.8848323945681714], 
             UndirectedEdge[53, 273] -> 
             RGBColor[
              0.5107313430007177, 0.6133401735729178, 0.9547179535981003], 
             UndirectedEdge[26, 253] -> 
             RGBColor[
              0.5491102049680476, 0.644831427382717, 0.9576471132734935], 
             UndirectedEdge[114, 206] -> 
             RGBColor[
              0.6802800775619033, 0.750159234002223, 0.9687676186187526], 
             UndirectedEdge[9, 45] -> 
             RGBColor[
              0.5131827099011048, 0.6156638683721645, 0.9548187692550729], 
             UndirectedEdge[47, 190] -> 
             RGBColor[
              0.773085763831172, 0.822621733572338, 0.9650996086993079], 
             UndirectedEdge[191, 282] -> 
             RGBColor[
              0.7063854592362157, 0.7692508995420932, 0.9725133621622324], 
             UndirectedEdge[59, 155] -> 
             RGBColor[
              0.7264819180499598, 0.3031975013284425, 0.4285814695282302], 
             UndirectedEdge[214, 265] -> 
             RGBColor[
              0.7926878463788788, 0.8378358374512123, 0.9478745061453355], 
             UndirectedEdge[167, 282] -> 
             RGBColor[
              0.45285399758263634`, 0.5649105046984515, 0.9505601300973233], 
             UndirectedEdge[28, 221] -> 
             RGBColor[
              0.9811165531798445, 0.9687637380239136, 0.6533750416652822], 
             UndirectedEdge[136, 197] -> 
             RGBColor[
              0.6038384496888267, 0.6892622819263738, 0.9619555211740792], 
             UndirectedEdge[121, 234] -> 
             RGBColor[
              0.5185514581322679, 0.6189940617816094, 0.9555255662866509], 
             UndirectedEdge[141, 146] -> 
             RGBColor[
              0.5710183753244135, 0.6591108468690556, 0.9610409426360824], 
             UndirectedEdge[32, 167] -> 
             RGBColor[
              0.6370753255919968, 0.7112692987014892, 0.9674748324282805], 
             UndirectedEdge[101, 136] -> 
             RGBColor[
              0.7033023151270787, 0.7671677466164581, 0.9717873688730092], 
             UndirectedEdge[91, 274] -> 
             RGBColor[
              0.48811101709664007`, 0.5946513622196262, 0.9530268898757344], 
             UndirectedEdge[84, 295] -> 
             RGBColor[
              0.5770775124705391, 0.6663286387549494, 0.9605933670258806], 
             UndirectedEdge[73, 122] -> 
             RGBColor[
              0.6830589858702066, 0.7523301382931548, 0.9690445942285497], 
             UndirectedEdge[157, 248] -> 
             RGBColor[
              0.6552085640149601, 0.7289618322714585, 0.9673704096933043], 
             UndirectedEdge[125, 167] -> 
             RGBColor[
              0.6768974080692305, 0.7422441113429906, 0.9442912027616517], 
             UndirectedEdge[20, 208] -> 
             RGBColor[
              0.4309017657403116, 0.5476471845569513, 0.9486776573748703], 
             UndirectedEdge[77, 103] -> 
             RGBColor[
              0.8365331879929649, 0.8728038189018648, 0.9841879609196761], 
             UndirectedEdge[46, 276] -> 
             RGBColor[
              0.6683277070974459, 0.7387600200281194, 0.9690498819564692], 
             UndirectedEdge[3, 291] -> 
             RGBColor[
              0.6622497876097879, 0.7360738344563512, 0.9669705278189651], 
             UndirectedEdge[79, 297] -> 
             RGBColor[
              0.6657243633556882, 0.7384821460733231, 0.9675260914136814], 
             UndirectedEdge[18, 262] -> 
             RGBColor[
              0.4804635440177215, 0.5888245061243694, 0.9523193859820036], 
             UndirectedEdge[127, 225] -> 
             RGBColor[
              0.8509757287186643, 0.883917025194912, 0.9588950898413358], 
             UndirectedEdge[109, 292] -> 
             RGBColor[
              0.5472483273776503, 0.6433198712782029, 0.957500539449295], 
             UndirectedEdge[267, 287] -> 
             RGBColor[
              0.9163360092131027, 0.9354679967073396, 0.9690868951534186], 
             UndirectedEdge[218, 262] -> 
             RGBColor[
              0.576116209389847, 0.6667561183789685, 0.9597731248678314], 
             UndirectedEdge[207, 225] -> 
             RGBColor[
              0.7836016385196154, 0.830662278620256, 0.9526048582436224], 
             UndirectedEdge[203, 299] -> 
             RGBColor[
              0.7626869631222359, 0.8104819460114283, 0.8114861818501858], 
             UndirectedEdge[142, 163] -> 
             RGBColor[
              0.6358266907442824, 0.7149284669212785, 0.964681127491299], 
             UndirectedEdge[2, 54] -> 
             RGBColor[
              0.9737285830285007, 0.9543207708102718, 0.6469178134862644], 
             UndirectedEdge[90, 195] -> 
             RGBColor[
              0.8967407808773975, 0.9202919332993843, 0.9827725071958746], 
             UndirectedEdge[88, 93] -> 
             RGBColor[
              0.8583512877090256, 0.889890033766896, 0.986351506152569], 
             UndirectedEdge[77, 82] -> 
             RGBColor[
              0.6929784168270089, 0.7583912526006165, 0.9714293731561426], 
             UndirectedEdge[167, 168] -> 
             RGBColor[
              0.42725583189591215`, 0.5441287606097462, 0.9485449487252938], 
             UndirectedEdge[18, 26] -> 
             RGBColor[
              0.5129456296670579, 0.6151949265557836, 0.9548764947501197], 
             UndirectedEdge[129, 224] -> 
             RGBColor[
              0.6882731193317342, 0.7538632473466609, 0.9707907680069934], 
             UndirectedEdge[38, 289] -> 
             RGBColor[
              0.9181831595418751, 0.9367768274801491, 0.9635758205639335], 
             UndirectedEdge[31, 241] -> 
             RGBColor[
              0.661938482012867, 0.7307109372795115, 0.9641131262222014], 
             UndirectedEdge[5, 197] -> 
             RGBColor[
              0.6405019121717477, 0.7190178507119591, 0.9648482859527863], 
             UndirectedEdge[59, 241] -> 
             RGBColor[
              0.4632311584729289, 0.573165118294144, 0.9514240388677698], 
             UndirectedEdge[155, 226] -> 
             RGBColor[
              0.7896470310910708, 0.35353880815534133`, 0.43419604265035694`],
              UndirectedEdge[15, 186] -> 
             RGBColor[
              0.7927057057478641, 0.6777423526166815, 0.6001111850386986], 
             UndirectedEdge[198, 256] -> 
             RGBColor[
              0.5866225261536949, 0.6743669882055935, 0.961228293932753], 
             UndirectedEdge[72, 291] -> 
             RGBColor[
              0.7520576091197924, 0.8063288219579058, 0.9758961413415603], 
             UndirectedEdge[230, 297] -> 
             RGBColor[
              0.5259858412286517, 0.6220380903386445, 0.957353727231118], 
             UndirectedEdge[138, 231] -> 
             RGBColor[
              0.5226693196145267, 0.6227696150922759, 0.9557302417447009], 
             UndirectedEdge[54, 165] -> 
             RGBColor[
              0.8062815403993888, 0.8488718106459991, 0.9489446515339721], 
             UndirectedEdge[103, 167] -> 
             RGBColor[
              0.5847149473686369, 0.6698295000028022, 0.9623981374059476], 
             UndirectedEdge[78, 131] -> 
             RGBColor[
              0.49703153183632265`, 0.6025516144168942, 0.9535472893540986], 
             UndirectedEdge[16, 239] -> 
             RGBColor[
              0.882092782533367, 0.9063424957850956, 0.8748416314689156], 
             UndirectedEdge[12, 87] -> 
             RGBColor[
              0.6386434870131388, 0.7145160504965746, 0.9667053789811149], 
             UndirectedEdge[125, 281] -> 
             RGBColor[
              0.6942574118127253, 0.7572804740464474, 0.9453973668493386], 
             UndirectedEdge[148, 205] -> 
             RGBColor[
              0.7276295711542864, 0.7824360018432502, 0.841035254532225], 
             UndirectedEdge[103, 269] -> 
             RGBColor[
              0.7271965255949602, 0.7868107197838585, 0.9734438116995534], 
             UndirectedEdge[40, 169] -> 
             RGBColor[
              0.8074495352061195, 0.6813310690633337, 0.6000310448362076], 
             UndirectedEdge[38, 53] -> 
             RGBColor[
              0.7246197267479642, 0.7842436668468167, 0.9737308719823012], 
             UndirectedEdge[118, 285] -> 
             RGBColor[
              0.6085948812151379, 0.6921218423340691, 0.963014986468164], 
             UndirectedEdge[74, 267] -> 
             RGBColor[
              0.7158225639308731, 0.7770824361232741, 0.9730605383310802], 
             UndirectedEdge[3, 200] -> 
             RGBColor[
              0.6833844608438341, 0.752584401816254, 0.9690770345321843], 
             UndirectedEdge[124, 273] -> 
             RGBColor[
              0.7175564911279748, 0.7741211579185062, 0.8485489401046393], 
             UndirectedEdge[131, 182] -> 
             RGBColor[
              0.6177409577958404, 0.6988124007171245, 0.9642372755504949], 
             UndirectedEdge[62, 207] -> 
             RGBColor[
              0.7305266868319766, 0.7891082209025657, 0.9741164513489782], 
             UndirectedEdge[75, 262] -> 
             RGBColor[
              0.6150735386265068, 0.6973111710466493, 0.9635731000628327], 
             UndirectedEdge[197, 283] -> 
             RGBColor[
              0.7518293975001689, 0.8063566917097101, 0.9758464577502455], 
             UndirectedEdge[246, 278] -> 
             RGBColor[
              0.7200336838703758, 0.780427266426017, 0.9734771642677678], 
             UndirectedEdge[225, 265] -> 
             RGBColor[
              0.789613747617554, 0.835543179628391, 0.9530781534948933], 
             UndirectedEdge[101, 204] -> 
             RGBColor[
              0.8961048707427313, 0.9194893910470685, 0.9724672109737054], 
             UndirectedEdge[87, 140] -> 
             RGBColor[
              0.45194398268741987`, 0.5657479809734843, 0.9500529630224793], 
             UndirectedEdge[57, 247] -> 
             RGBColor[
              0.915405959435367, 0.9345961054259808, 0.9644807824832446], 
             UndirectedEdge[40, 66] -> 
             RGBColor[
              0.5712901461541349, 0.6604281324168431, 0.9606003519525381], 
             UndirectedEdge[167, 293] -> 
             RGBColor[
              0.46333923237501023`, 0.5734228906573451, 0.9513855661888595], 
             UndirectedEdge[42, 140] -> 
             RGBColor[
              0.36991555653180896`, 0.4922181513831406, 0.9449170232330241], 
             UndirectedEdge[107, 150] -> 
             RGBColor[
              0.7961389705726487, 0.8406690817824172, 0.9803153503111508], 
             UndirectedEdge[91, 143] -> 
             RGBColor[
              0.49541582893945724`, 0.6009784230873558, 0.9534923460269672], 
             UndirectedEdge[91, 142] -> 
             RGBColor[
              0.5783192943540824, 0.6685446820007814, 0.9599465597863821], 
             UndirectedEdge[44, 283] -> 
             RGBColor[
              0.780497376600258, 0.8288187130296305, 0.9786584308774119], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.7029291479800358, 0.7664696844326736, 0.9722127541751598], 
             UndirectedEdge[199, 233] -> 
             RGBColor[
              0.6776619260574553, 0.7459566154005469, 0.9702236259085306], 
             UndirectedEdge[249, 286] -> 
             RGBColor[
              0.76740711163814, 0.8130661960938554, 0.7095900059950695], 
             UndirectedEdge[48, 266] -> 
             RGBColor[
              0.5063653223365115, 0.6101292060274179, 0.9542820795330746], 
             UndirectedEdge[113, 169] -> 
             RGBColor[
              0.9347173708729231, 0.7808404496914157, 0.5695167299633761], 
             UndirectedEdge[18, 33] -> 
             RGBColor[
              0.7101852586686903, 0.7703929827173295, 0.9364385708349601], 
             UndirectedEdge[269, 293] -> 
             RGBColor[
              0.6058208106013334, 0.6904041104384014, 0.9624312404824654], 
             UndirectedEdge[189, 257] -> 
             RGBColor[
              0.7806722767699432, 0.8292571663536874, 0.9785957695486271], 
             UndirectedEdge[11, 197] -> 
             RGBColor[
              0.5857934431226889, 0.6746125326777013, 0.9605349521561558], 
             UndirectedEdge[221, 296] -> 
             RGBColor[
              0.7544149550788772, 0.7897234587406947, 0.6715409040082834], 
             UndirectedEdge[126, 157] -> 
             RGBColor[
              0.7280032812397963, 0.7866285983705773, 0.9744138821436208], 
             UndirectedEdge[24, 87] -> 
             RGBColor[
              0.5333202181060824, 0.6318128748439833, 0.9564591983656088], 
             UndirectedEdge[53, 137] -> 
             RGBColor[
              0.7378044955331642, 0.7947568435851207, 0.9749884469992156], 
             UndirectedEdge[27, 140] -> 
             RGBColor[
              0.5873071222353228, 0.6747026614156244, 0.9614326801195234], 
             UndirectedEdge[115, 200] -> 
             RGBColor[
              0.7637439202327716, 0.8153618222454038, 0.9770865144422294], 
             UndirectedEdge[1, 5] -> 
             RGBColor[
              0.7591879538051727, 0.8122505569280014, 0.9765135619770512], 
             UndirectedEdge[40, 42] -> 
             RGBColor[
              0.5055006776515965, 0.6009636717518473, 0.9564991441851902], 
             UndirectedEdge[82, 167] -> 
             RGBColor[
              0.4411601762026809, 0.555416933701554, 0.9496395496424141], 
             UndirectedEdge[52, 57] -> 
             RGBColor[
              0.8670169499198259, 0.8964339206199373, 0.9597534368285876], 
             UndirectedEdge[27, 203] -> 
             RGBColor[
              0.8557083122224738, 0.8848621236188431, 0.8195877287986175], 
             UndirectedEdge[251, 270] -> 
             RGBColor[
              0.8600738765837417, 0.8912635793771653, 0.9865158082172125], 
             UndirectedEdge[200, 264] -> 
             RGBColor[
              0.8391332000044945, 0.874694318322841, 0.9591708961154136], 
             UndirectedEdge[84, 271] -> 
             RGBColor[
              0.6236519180365464, 0.7043393692198832, 0.9642047441411887], 
             UndirectedEdge[80, 145] -> 
             RGBColor[
              0.7423609824686666, 0.7986515859420339, 0.9751220402032947], 
             UndirectedEdge[199, 259] -> 
             RGBColor[
              0.7310231876127278, 0.7892776914285555, 0.9744244198869034], 
             UndirectedEdge[273, 274] -> 
             RGBColor[
              0.435055466856178, 0.5512449116924263, 0.9489423275369997], 
             UndirectedEdge[281, 294] -> 
             RGBColor[
              0.5885995526265406, 0.6743387789924935, 0.9621611997073494], 
             UndirectedEdge[18, 183] -> 
             RGBColor[
              0.5352703046817395, 0.6333191034478505, 0.9566339749452546], 
             UndirectedEdge[77, 269] -> 
             RGBColor[
              0.7822165701900541, 0.830371264252646, 0.9787741880747346], 
             UndirectedEdge[134, 144] -> 
             RGBColor[
              0.682194283875827, 0.7501104865714112, 0.9700345203681409], 
             UndirectedEdge[200, 210] -> 
             RGBColor[
              0.6788679952552514, 0.7490561045720434, 0.968626875451085], 
             UndirectedEdge[87, 151] -> 
             RGBColor[
              0.6327871318606968, 0.7098494168313298, 0.966145981250699], 
             UndirectedEdge[109, 290] -> 
             RGBColor[
              0.47415758241353045`, 0.5839815118157932, 0.9517465682654989], 
             UndirectedEdge[247, 278] -> 
             RGBColor[
              0.8731298626713264, 0.9016740682881039, 0.9877610998254629], 
             UndirectedEdge[156, 205] -> 
             RGBColor[
              0.7335721111934967, 0.7872604235554592, 0.8415030730523532], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.8372167837828128, 0.8731538043440517, 0.956783234766436], 
             UndirectedEdge[64, 121] -> 
             RGBColor[
              0.6362298160942332, 0.7154297531998761, 0.964593890752571], 
             UndirectedEdge[106, 264] -> 
             RGBColor[
              0.9604119991487234, 0.9699959143012957, 0.9518963386236754], 
             UndirectedEdge[91, 107] -> 
             RGBColor[
              0.6827325245169287, 0.7506165344147037, 0.9700092877418941], 
             UndirectedEdge[7, 299] -> 
             RGBColor[
              0.676731290958005, 0.7456985399653557, 0.9695778000995117], 
             UndirectedEdge[160, 221] -> 
             RGBColor[
              0.9817954894249888, 0.9692700875638861, 0.6522257796971853], 
             UndirectedEdge[8, 234] -> 
             RGBColor[
              0.4208102410088475, 0.538906413049338, 0.9480346343425663], 
             UndirectedEdge[49, 174] -> 
             RGBColor[
              0.6617629261420941, 0.7356934945775047, 0.9669220020178444], 
             UndirectedEdge[79, 245] -> 
             RGBColor[
              0.5961428350477441, 0.6830146352772541, 0.9613496941995678], 
             UndirectedEdge[13, 147] -> 
             RGBColor[
              0.5518474023166722, 0.6457804031013178, 0.9584334660418181], 
             UndirectedEdge[1, 197] -> 
             RGBColor[
              0.7567119026847215, 0.8102498688117997, 0.976312155453412], 
             UndirectedEdge[129, 175] -> 
             RGBColor[
              0.8669700663908864, 0.8969234487496994, 0.9863825881518123], 
             UndirectedEdge[116, 283] -> 
             RGBColor[
              0.8133165242384015, 0.8544572805993086, 0.9819295368016101], 
             UndirectedEdge[62, 265] -> 
             RGBColor[
              0.7365387959299152, 0.7939891219107007, 0.9745897466002491], 
             UndirectedEdge[31, 291] -> 
             RGBColor[
              0.8072112514690627, 0.8501386187057071, 0.9753244327154467], 
             UndirectedEdge[92, 277] -> 
             RGBColor[
              0.5343439227822797, 0.6146194175303912, 0.9607493118810004], 
             UndirectedEdge[124, 289] -> 
             RGBColor[
              0.9808181993111463, 0.983572083101057, 0.8437886273130306], 
             UndirectedEdge[80, 277] -> 
             RGBColor[
              0.8613957296524124, 0.8923175891333774, 0.9866418877429346], 
             UndirectedEdge[119, 244] -> 
             RGBColor[
              0.7062218260062068, 0.7660843410352467, 0.9132767811125131], 
             UndirectedEdge[252, 268] -> 
             RGBColor[
              0.8159994741234218, 0.853975456365142, 0.8330596233887412], 
             UndirectedEdge[3, 194] -> 
             RGBColor[
              0.6649446214424817, 0.7381790591279472, 0.967239123670754], 
             UndirectedEdge[1, 237] -> 
             RGBColor[
              0.7598183604821203, 0.8127430354153011, 0.976576395023124], 
             UndirectedEdge[149, 281] -> 
             RGBColor[
              0.6435728947875484, 0.7176442509493473, 0.9675449278117748], 
             UndirectedEdge[29, 209] -> 
             RGBColor[
              0.6907498676144501, 0.7562626951695017, 0.9715839833110176], 
             UndirectedEdge[123, 287] -> 
             RGBColor[
              0.7448990941208434, 0.79938138046208, 0.9533015357307035], 
             UndirectedEdge[17, 81] -> 
             RGBColor[
              0.7466541809381104, 0.8020111880215852, 0.9753831689420313], 
             UndirectedEdge[176, 187] -> 
             RGBColor[
              0.7563493640979309, 0.809822044832081, 0.976286626613962], 
             UndirectedEdge[246, 270] -> 
             RGBColor[
              0.7013890026687437, 0.7655605037322246, 0.9716988179304527], 
             UndirectedEdge[45, 131] -> 
             RGBColor[
              0.49808212331860297`, 0.6034045319108163, 0.9536299957640271], 
             UndirectedEdge[4, 158] -> 
             RGBColor[
              0.9287213841395165, 0.9413206099539739, 0.7517643028347784], 
             UndirectedEdge[169, 264] -> 
             RGBColor[
              0.9248036413010992, 0.7734468064089918, 0.5862980882136956], 
             UndirectedEdge[42, 181] -> 
             RGBColor[
              0.5596538769786898, 0.6434092903947795, 0.9618592841860791], 
             UndirectedEdge[8, 263] -> 
             RGBColor[
              0.5232193083519642, 0.6230751056583541, 0.9558125017561427], 
             UndirectedEdge[145, 205] -> 
             RGBColor[
              0.8058188389936314, 0.8459135718616058, 0.8471906001132636], 
             UndirectedEdge[167, 269] -> 
             RGBColor[
              0.5303983295657262, 0.6273969453535833, 0.9569843645610061], 
             UndirectedEdge[187, 288] -> 
             RGBColor[
              0.6480493958933176, 0.7220447744445685, 0.9675893073169142], 
             UndirectedEdge[47, 131] -> 
             RGBColor[
              0.7150705840271333, 0.7755223970533531, 0.960532441228528], 
             UndirectedEdge[43, 97] -> 
             RGBColor[
              0.6776688014403384, 0.746418472528863, 0.9696990025667672], 
             UndirectedEdge[104, 114] -> 
             RGBColor[
              0.8424372580692678, 0.8768798216281095, 0.9396547289158926], 
             UndirectedEdge[26, 129] -> 
             RGBColor[
              0.7596424858876193, 0.8121652762386908, 0.9763094358488589], 
             UndirectedEdge[28, 79] -> 
             RGBColor[
              0.8009630254587299, 0.844290602051563, 0.9414612472889738], 
             UndirectedEdge[53, 247] -> 
             RGBColor[
              0.7224967633321586, 0.7825508734453602, 0.9735283818365099], 
             UndirectedEdge[150, 281] -> 
             RGBColor[
              0.5982969095151067, 0.6819144278964835, 0.9631277416150491], 
             UndirectedEdge[76, 248] -> 
             RGBColor[
              0.8147085996078753, 0.855468304380254, 0.9820885802643933], 
             UndirectedEdge[194, 210] -> 
             RGBColor[
              0.660428155853899, 0.7346507618837368, 0.9667889645896548], 
             UndirectedEdge[60, 265] -> 
             RGBColor[
              0.5517999435372287, 0.6470150783245199, 0.9578588593464965], 
             UndirectedEdge[78, 178] -> 
             RGBColor[
              0.5882306306248575, 0.6762878411382558, 0.9609341912885848], 
             UndirectedEdge[120, 190] -> 
             RGBColor[
              0.5995937494558199, 0.6858162430556525, 0.9616213628228876], 
             UndirectedEdge[96, 267] -> 
             RGBColor[
              0.6321593383390436, 0.7075187949759807, 0.9669279703691334], 
             UndirectedEdge[159, 212] -> 
             RGBColor[
              0.5384618121389955, 0.6361865823794621, 0.9568088327836424], 
             UndirectedEdge[34, 147] -> 
             RGBColor[
              0.6141489100074378, 0.6944508144183397, 0.9646430980877425], 
             UndirectedEdge[41, 250] -> 
             RGBColor[
              0.5764373956331534, 0.6665685745490446, 0.9601049131320334], 
             UndirectedEdge[146, 236] -> 
             RGBColor[
              0.41501900374716383`, 0.5338903344093158, 0.9476656218252419], 
             UndirectedEdge[82, 103] -> 
             RGBColor[
              0.6379583722319149, 0.714830708131829, 0.9660989967809614], 
             UndirectedEdge[179, 289] -> 
             RGBColor[
              0.7268243125915863, 0.784497391838779, 0.9462443449197229], 
             UndirectedEdge[124, 247] -> 
             RGBColor[
              0.9293219114594158, 0.9433318577909486, 0.8673593683430489], 
             UndirectedEdge[162, 227] -> 
             RGBColor[
              0.7489287917338483, 0.8037881312628979, 0.9756098808887039], 
             UndirectedEdge[156, 191] -> 
             RGBColor[
              0.6835286660671761, 0.7506947251606688, 0.9707139916767733], 
             UndirectedEdge[1, 51] -> 
             RGBColor[
              0.7164175133964503, 0.7775370683460301, 0.9731400335254279], 
             UndirectedEdge[23, 198] -> 
             RGBColor[
              0.5844785324156627, 0.6726263975032417, 0.9610595108919873], 
             UndirectedEdge[77, 159] -> 
             RGBColor[
              0.7492181638820405, 0.8040492128316237, 0.9758567720572962], 
             UndirectedEdge[2, 238] -> 
             RGBColor[
              0.9853040441776321, 0.9607204287520662, 0.513802531321905], 
             UndirectedEdge[113, 245] -> 
             RGBColor[
              0.776765058965718, 0.8245109228789992, 0.9359439957663854], 
             UndirectedEdge[167, 201] -> 
             RGBColor[
              0.40855483365724277`, 0.5282913951760617, 0.9472537306231533], 
             UndirectedEdge[125, 150] -> 
             RGBColor[
              0.8699175625014395, 0.8987064509634902, 0.9603740900216137], 
             UndirectedEdge[142, 198] -> 
             RGBColor[
              0.6559106499071958, 0.7306182084630894, 0.9666829088453888], 
             UndirectedEdge[34, 52] -> 
             RGBColor[
              0.7849259779934761, 0.8319094067576677, 0.9791977440022323], 
             UndirectedEdge[13, 251] -> 
             RGBColor[
              0.7766021749322989, 0.8258574540295431, 0.9782485123400296], 
             UndirectedEdge[120, 188] -> 
             RGBColor[
              0.51243728316779, 0.6141941718871048, 0.9549989574985323], 
             UndirectedEdge[67, 173] -> 
             RGBColor[
              0.9594454209674332, 0.9682028704735121, 0.9072008662375238], 
             UndirectedEdge[20, 280] -> 
             RGBColor[
              0.6777064311190226, 0.7458474744730037, 0.9703466736304417], 
             UndirectedEdge[32, 107] -> 
             RGBColor[
              0.8522773903930334, 0.8850603152908798, 0.9857686052120692], 
             UndirectedEdge[189, 287] -> 
             RGBColor[
              0.8097825655108515, 0.8518114403843782, 0.9585770893760154], 
             UndirectedEdge[159, 205] -> 
             RGBColor[
              0.8009748300376125, 0.841980987170993, 0.8468092619840564], 
             UndirectedEdge[66, 86] -> 
             RGBColor[
              0.427915273224349, 0.5450604348451028, 0.9484873607126048], 
             UndirectedEdge[119, 266] -> 
             RGBColor[
              0.7478185436365573, 0.8005898765698507, 0.9163482211076157], 
             UndirectedEdge[28, 230] -> 
             RGBColor[
              0.6612245033316934, 0.7278465463168846, 0.9312888831064104], 
             UndirectedEdge[83, 142] -> 
             RGBColor[
              0.664912119278592, 0.7376502247497252, 0.9675800911888157], 
             UndirectedEdge[191, 217] -> 
             RGBColor[
              0.7761848500117703, 0.8256869332621652, 0.9781656532669385], 
             UndirectedEdge[43, 233] -> 
             RGBColor[
              0.6461341984568433, 0.7208172612091864, 0.9672164831048495], 
             UndirectedEdge[113, 297] -> 
             RGBColor[
              0.8463465872736621, 0.8799784336750681, 0.9421203929804989], 
             UndirectedEdge[158, 207] -> 
             RGBColor[
              0.7975614504801614, 0.8378792932642294, 0.7392111210129244], 
             UndirectedEdge[40, 201] -> 
             RGBColor[
              0.5791408278088251, 0.6672279982794026, 0.9611005904454899], 
             UndirectedEdge[194, 226] -> 
             RGBColor[
              0.7059464313234849, 0.7702099846322839, 0.9713258008959942], 
             UndirectedEdge[134, 230] -> 
             RGBColor[
              0.5844563392631752, 0.6677643917673651, 0.9631685955006948], 
             UndirectedEdge[134, 264] -> 
             RGBColor[
              0.8949033557363617, 0.9183110918213647, 0.9647166195003951], 
             UndirectedEdge[59, 226] -> 
             RGBColor[
              0.6395554237115458, 0.7168504642256757, 0.9657302682678807], 
             UndirectedEdge[42, 201] -> 
             RGBColor[
              0.355552765817854, 0.4799027382520411, 0.9439673247186069], 
             UndirectedEdge[217, 295] -> 
             RGBColor[
              0.5516797466744132, 0.6464877110848466, 0.9580619550869384], 
             UndirectedEdge[45, 94] -> 
             RGBColor[
              0.6004312356500379, 0.6858512339551329, 0.9621282268456688], 
             UndirectedEdge[197, 254] -> 
             RGBColor[
              0.544668513701711, 0.6411709720781802, 0.9573125028818389], 
             UndirectedEdge[30, 189] -> 
             RGBColor[
              0.6052242486988234, 0.6901420708730364, 0.9622323054499986], 
             UndirectedEdge[92, 179] -> 
             RGBColor[
              0.3500696896571902, 0.4679890606465158, 0.9440935730279468], 
             UndirectedEdge[134, 288] -> 
             RGBColor[
              0.6364070145714978, 0.7127614556025716, 0.9664788465931626], 
             UndirectedEdge[59, 83] -> 
             RGBColor[
              0.6325687860456398, 0.711392449780657, 0.9650339055191843], 
             UndirectedEdge[10, 22] -> 
             RGBColor[
              0.5933342793007048, 0.679434968696089, 0.9620171069134285], 
             UndirectedEdge[148, 168] -> 
             RGBColor[
              0.4633937449308957, 0.5752429436420375, 0.9508991995496299], 
             UndirectedEdge[130, 216] -> 
             RGBColor[
              0.7791737093073021, 0.8274156907411674, 0.9786244116176015], 
             UndirectedEdge[158, 196] -> 
             RGBColor[
              0.993358702368861, 0.9882032608422129, 0.5185139220676374], 
             UndirectedEdge[203, 237] -> 
             RGBColor[
              0.8194798270116943, 0.8565601556254965, 0.8159768119672501], 
             UndirectedEdge[160, 193] -> 
             RGBColor[
              0.7165338663706948, 0.7756710257406076, 0.9336206236258285], 
             UndirectedEdge[38, 88] -> 
             RGBColor[
              0.8512003083317272, 0.8841880369196025, 0.9856694393558076], 
             UndirectedEdge[22, 73] -> 
             RGBColor[
              0.5581227402796167, 0.6519274467952066, 0.9585075497743469], 
             UndirectedEdge[181, 227] -> 
             RGBColor[
              0.7612904826942154, 0.8135859059425159, 0.9768046338994478], 
             UndirectedEdge[85, 255] -> 
             RGBColor[
              0.6344699513072092, 0.7089576688741638, 0.9673341331616565], 
             UndirectedEdge[106, 227] -> 
             RGBColor[
              0.8211064367782983, 0.8607315324760128, 0.963441379232673], 
             UndirectedEdge[131, 261] -> 
             RGBColor[
              0.4907039193141548, 0.5974145735157028, 0.9530491565175452], 
             UndirectedEdge[81, 94] -> 
             RGBColor[
              0.7007728780260872, 0.7661683654758953, 0.970810149452914], 
             UndirectedEdge[77, 154] -> 
             RGBColor[
              0.9231797207302801, 0.9410897442312904, 0.9754519083159565], 
             UndirectedEdge[167, 277] -> 
             RGBColor[
              0.6212786793974772, 0.6986734818145175, 0.9659681342124147], 
             UndirectedEdge[113, 176] -> 
             RGBColor[
              0.8235143084441001, 0.8621416839216681, 0.9398446848065449], 
             UndirectedEdge[4, 276] -> 
             RGBColor[
              0.6809505253841086, 0.7488251126926295, 0.9702538576331741], 
             UndirectedEdge[101, 243] -> 
             RGBColor[
              0.8974246303070477, 0.9204736655692277, 0.97023320227974], 
             UndirectedEdge[52, 271] -> 
             RGBColor[
              0.6534520841735595, 0.7276194854957689, 0.9671749462033404], 
             UndirectedEdge[37, 71] -> 
             RGBColor[
              0.691348146504478, 0.750598371486364, 0.7898388311027036], 
             UndirectedEdge[83, 291] -> 
             RGBColor[
              0.6962649598248851, 0.7626467455156691, 0.9703608422955089], 
             UndirectedEdge[80, 149] -> 
             RGBColor[
              0.8663299412989889, 0.8962519955647504, 0.9871125172546078], 
             UndirectedEdge[104, 206] -> 
             RGBColor[
              0.8222228375214593, 0.8610881626608751, 0.9376399443901873], 
             UndirectedEdge[61, 108] -> 
             RGBColor[
              0.7970109855002265, 0.8415485905833135, 0.9536604911579925], 
             UndirectedEdge[115, 264] -> 
             RGBColor[
              0.8884076720608038, 0.9131879103930878, 0.9640821149938649], 
             UndirectedEdge[38, 52] -> 
             RGBColor[
              0.8182978621746035, 0.8583744173639971, 0.9824192159392948], 
             UndirectedEdge[33, 285] -> 
             RGBColor[
              0.7433300938283921, 0.7975779224598223, 0.9389714643527391], 
             UndirectedEdge[100, 122] -> 
             RGBColor[
              0.6613211915064983, 0.7349031803157511, 0.9671823787209519], 
             UndirectedEdge[205, 269] -> 
             RGBColor[
              0.833973236345626, 0.8683030385920152, 0.8497266780014948], 
             UndirectedEdge[177, 252] -> 
             RGBColor[
              0.7782649118597754, 0.8233408387968562, 0.8300890204210909], 
             UndirectedEdge[152, 244] -> 
             RGBColor[
              0.5817237045897439, 0.6691200113507938, 0.9614112507824308], 
             UndirectedEdge[10, 71] -> 
             RGBColor[
              0.5577362776727042, 0.648768950732315, 0.959702640887586], 
             UndirectedEdge[233, 259] -> 
             RGBColor[
              0.517129118087045, 0.6188677403211735, 0.9551294449636396], 
             UndirectedEdge[130, 299] -> 
             RGBColor[
              0.6423925504085173, 0.7188500171322552, 0.9661612957871235], 
             UndirectedEdge[81, 86] -> 
             RGBColor[
              0.5797128809382943, 0.6682332185112578, 0.9609212964925394], 
             UndirectedEdge[205, 282] -> 
             RGBColor[
              0.7564289043625363, 0.8058165979368834, 0.843302443537812], 
             UndirectedEdge[176, 297] -> 
             RGBColor[
              0.6862364847415876, 0.7548124245613634, 0.9693612976206337], 
             UndirectedEdge[92, 128] -> 
             RGBColor[
              0.53532460047096, 0.6154013832995582, 0.9608428497944081], 
             UndirectedEdge[166, 285] -> 
             RGBColor[
              0.6993018070721102, 0.7635420523593723, 0.9719073920319614], 
             UndirectedEdge[132, 146] -> 
             RGBColor[
              0.48855609679231093`, 0.593883066436778, 0.9533740487373485], 
             UndirectedEdge[81, 130] -> 
             RGBColor[
              0.7356094100217251, 0.7933829290383371, 0.9742823293963384], 
             UndirectedEdge[1, 128] -> 
             RGBColor[
              0.8659999535755292, 0.8959888723113418, 0.9870810427309606], 
             UndirectedEdge[296, 297] -> 
             RGBColor[
              0.6176058275732241, 0.6994173510097847, 0.9637380240128814], 
             UndirectedEdge[128, 237] -> 
             RGBColor[
              0.750420369739503, 0.8052493326988011, 0.9756800062764077], 
             UndirectedEdge[112, 146] -> 
             RGBColor[
              0.4291962886654599, 0.5456921000705184, 0.9487010271994609], 
             UndirectedEdge[116, 287] -> 
             RGBColor[
              0.8610977200551897, 0.8918992291240346, 0.9636917044136113], 
             UndirectedEdge[10, 266] -> 
             RGBColor[
              0.6183094471885948, 0.6997109351059697, 0.9639832436166176], 
             UndirectedEdge[16, 76] -> 
             RGBColor[
              0.9244001355016611, 0.9396858087328286, 0.8789808159021637], 
             UndirectedEdge[23, 72] -> 
             RGBColor[
              0.649272651081966, 0.7233404902321141, 0.9674919922814655], 
             UndirectedEdge[237, 277] -> 
             RGBColor[
              0.7494396920508227, 0.804467366929634, 0.9755864683630001], 
             UndirectedEdge[56, 278] -> 
             RGBColor[
              0.7846196849968274, 0.8321689219841107, 0.9790348510823544], 
             UndirectedEdge[88, 274] -> 
             RGBColor[
              0.6313343238292017, 0.7081070463144306, 0.9662756335372651], 
             UndirectedEdge[103, 282] -> 
             RGBColor[
              0.6496521936118703, 0.7243242791287268, 0.9670195772358707], 
             UndirectedEdge[46, 60] -> 
             RGBColor[
              0.6643249498119826, 0.7355104013416195, 0.9687347702403746], 
             UndirectedEdge[82, 216] -> 
             RGBColor[
              0.6493094838653529, 0.7236982828115146, 0.9672303695064133], 
             UndirectedEdge[48, 70] -> 
             RGBColor[
              0.6539099192732177, 0.7274285379892316, 0.9675956677880648], 
             UndirectedEdge[143, 174] -> 
             RGBColor[
              0.5593995642431059, 0.6524215731890376, 0.9588724146699485], 
             UndirectedEdge[95, 205] -> 
             RGBColor[
              0.9626728878946265, 0.9697356596646866, 0.8623176864123839], 
             UndirectedEdge[78, 190] -> 
             RGBColor[
              0.5550467116403613, 0.6496509509358792, 0.9581144568248785], 
             UndirectedEdge[68, 292] -> 
             RGBColor[
              0.54802038120886, 0.6439466593590076, 0.9575613183550142], 
             UndirectedEdge[145, 269] -> 
             RGBColor[
              0.6447255104400546, 0.7219886984042301, 0.9654939609663808], 
             UndirectedEdge[198, 254] -> 
             RGBColor[
              0.5768190227753669, 0.6663535722816591, 0.9604715820506775], 
             UndirectedEdge[124, 147] -> 
             RGBColor[
              0.7101558339578364, 0.7677110806455771, 0.8480773767739023], 
             UndirectedEdge[44, 194] -> 
             RGBColor[
              0.6864757943126161, 0.7549993750170709, 0.9693851497621987], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.4889919106176199, 0.5960246877307429, 0.9529143809216594], 
             UndirectedEdge[5, 11] -> 
             RGBColor[
              0.5882694942431401, 0.676613220793903, 0.960736358679795], 
             UndirectedEdge[108, 254] -> 
             RGBColor[
              0.5399556898980981, 0.6373448894041144, 0.9569414921283761], 
             UndirectedEdge[61, 71] -> 
             RGBColor[
              0.6768504665267889, 0.7422309115405201, 0.9446889540040097], 
             UndirectedEdge[229, 284] -> 
             RGBColor[
              0.7171888007152659, 0.7771793161691707, 0.9590162982527344], 
             UndirectedEdge[37, 136] -> 
             RGBColor[
              0.7820340779190589, 0.8259872525338396, 0.7964900207550814], 
             UndirectedEdge[148, 159] -> 
             RGBColor[
              0.5335378362926961, 0.6321890769648524, 0.9564211993679037], 
             UndirectedEdge[164, 230] -> 
             RGBColor[
              0.4048827153667191, 0.5247430256267283, 0.9471213611277242], 
             UndirectedEdge[176, 193] -> 
             RGBColor[
              0.5577839891929468, 0.651519470468995, 0.958559021544679], 
             UndirectedEdge[216, 299] -> 
             RGBColor[
              0.6674342077659621, 0.738412750183536, 0.9686572141649206], 
             UndirectedEdge[149, 277] -> 
             RGBColor[
              0.8595748191021279, 0.8908656444878809, 0.9864682076691024], 
             UndirectedEdge[39, 248] -> 
             RGBColor[
              0.5872912413757274, 0.6724120687086994, 0.9624136892049721], 
             UndirectedEdge[13, 137] -> 
             RGBColor[
              0.7863212120192571, 0.8336071503864497, 0.9791755227736705], 
             UndirectedEdge[68, 75] -> 
             RGBColor[
              0.5894930095299304, 0.6765437451363454, 0.9615593071077846], 
             UndirectedEdge[66, 97] -> 
             RGBColor[
              0.47016430758223254`, 0.5796582099934977, 0.9517309919510526], 
             UndirectedEdge[59, 106] -> 
             RGBColor[
              0.7509174003073997, 0.8044049630586969, 0.9574672945824961], 
             UndirectedEdge[51, 198] -> 
             RGBColor[
              0.6298819808366812, 0.7094869623334668, 0.9646338366700015], 
             UndirectedEdge[193, 228] -> 
             RGBColor[
              0.5077554169539601, 0.6112264074774605, 0.9544001722042497], 
             UndirectedEdge[30, 287] -> 
             RGBColor[
              0.7566370087705896, 0.808910748361773, 0.9542255873693296], 
             UndirectedEdge[93, 147] -> 
             RGBColor[
              0.6546717735658634, 0.7266178218719626, 0.9685466368215665], 
             UndirectedEdge[69, 121] -> 
             RGBColor[
              0.6280506048129708, 0.7089188002013121, 0.9638615907174984], 
             UndirectedEdge[148, 251] -> 
             RGBColor[
              0.6679669379559019, 0.7382002239857006, 0.9693286864111812], 
             UndirectedEdge[125, 269] -> 
             RGBColor[
              0.8193789862955536, 0.859225331124047, 0.9553368770552575], 
             UndirectedEdge[37, 44] -> 
             RGBColor[
              0.8448894683816176, 0.8762041545231436, 0.8019933521373156], 
             UndirectedEdge[91, 105] -> 
             RGBColor[
              0.5054560123120769, 0.609390987185632, 0.9542104953170387], 
             UndirectedEdge[81, 203] -> 
             RGBColor[
              0.8559038227354436, 0.8850148579175101, 0.8196072154594007], 
             UndirectedEdge[8, 69] -> 
             RGBColor[
              0.5303093876895504, 0.6288311514690408, 0.956370658773414], 
             UndirectedEdge[52, 270] -> 
             RGBColor[
              0.8060961719541533, 0.8486451207882679, 0.9812554078334907], 
             UndirectedEdge[108, 268] -> 
             RGBColor[
              0.6327793805735885, 0.712757833392702, 0.9642338572674507], 
             UndirectedEdge[11, 254] -> 
             RGBColor[
              0.49243609577310343`, 0.598766342160124, 0.9532005756088476], 
             UndirectedEdge[82, 255] -> 
             RGBColor[
              0.6911182279760716, 0.7569079885043604, 0.97125194668293], 
             UndirectedEdge[43, 66] -> 
             RGBColor[
              0.620996046523808, 0.6993275955898426, 0.9655363046087178], 
             UndirectedEdge[252, 283] -> 
             RGBColor[
              0.9303366672463893, 0.9437482320080843, 0.8443012131180732], 
             UndirectedEdge[99, 215] -> 
             RGBColor[
              0.8430483706728282, 0.8780743214638187, 0.9758324681209967], 
             UndirectedEdge[114, 283] -> 
             RGBColor[
              0.7830637160293767, 0.8308235568965601, 0.978914219607901], 
             UndirectedEdge[24, 194] -> 
             RGBColor[
              0.6491303688070376, 0.7254926117906685, 0.9658900562674586], 
             UndirectedEdge[134, 228] -> 
             RGBColor[
              0.6946784105371244, 0.7602456629985496, 0.9710173165497811], 
             UndirectedEdge[49, 143] -> 
             RGBColor[
              0.5460508516855215, 0.6419934574850796, 0.9575419397530197], 
             UndirectedEdge[123, 189] -> 
             RGBColor[
              0.5934863340490772, 0.6806127029733434, 0.9613082538113724], 
             UndirectedEdge[232, 240] -> 
             RGBColor[
              0.4852030630027734, 0.5915538688394586, 0.9530015134054068], 
             UndirectedEdge[11, 243] -> 
             RGBColor[
              0.7457283469401881, 0.8001635709610873, 0.9562894273078186], 
             UndirectedEdge[155, 210] -> 
             RGBColor[
              0.7593015141113468, 0.3298326596563099, 0.43117148511279724`], 
             UndirectedEdge[148, 156] -> 
             RGBColor[
              0.4661351174485804, 0.5774685133493185, 0.9511150104362005], 
             UndirectedEdge[15, 212] -> 
             RGBColor[
              0.6800345271764444, 0.5870830723843935, 0.5906859516902269], 
             UndirectedEdge[51, 204] -> 
             RGBColor[
              0.7563466160162082, 0.8088711258912147, 0.9594632413467912], 
             UndirectedEdge[95, 156] -> 
             RGBColor[
              0.7011784341889205, 0.7647681711707548, 0.9723974423163593], 
             UndirectedEdge[87, 109] -> 
             RGBColor[
              0.4555277729710726, 0.5686574633736661, 0.9503350921214648], 
             UndirectedEdge[113, 288] -> 
             RGBColor[
              0.7152143402394868, 0.7743644135341556, 0.9311473655094971], 
             UndirectedEdge[164, 176] -> 
             RGBColor[
              0.565133358879655, 0.657517359849447, 0.9591289315172399], 
             UndirectedEdge[17, 294] -> 
             RGBColor[
              0.7653919701046584, 0.8166492913309646, 0.9772507766515574], 
             UndirectedEdge[77, 212] -> 
             RGBColor[
              0.6807968808450138, 0.7485017329184906, 0.9704703980212034], 
             UndirectedEdge[180, 296] -> 
             RGBColor[
              0.5022531434132576, 0.6067907539259709, 0.9539583537448284], 
             UndirectedEdge[217, 271] -> 
             RGBColor[
              0.5982541522404206, 0.6844984415497803, 0.9616733322022466], 
             UndirectedEdge[4, 85] -> 
             RGBColor[
              0.6226042172648963, 0.6994962546355938, 0.9662023688560348], 
             UndirectedEdge[95, 127] -> 
             RGBColor[
              0.8334044553854982, 0.8706726368754024, 0.9837930554826491], 
             UndirectedEdge[54, 75] -> 
             RGBColor[
              0.8419628942530879, 0.8767672789167831, 0.9524867299465335], 
             UndirectedEdge[134, 193] -> 
             RGBColor[
              0.6390867660570323, 0.7150825216511156, 0.9666495979882097], 
             UndirectedEdge[40, 178] -> 
             RGBColor[
              0.6956238502576746, 0.7621459058491509, 0.9702969424853588], 
             UndirectedEdge[69, 239] -> 
             RGBColor[
              0.7029988094704298, 0.7677859890565877, 0.9711149368031426], 
             UndirectedEdge[134, 200] -> 
             RGBColor[
              0.7702396039083295, 0.8204850036736808, 0.9777210189487596], 
             UndirectedEdge[89, 141] -> 
             RGBColor[
              0.4667446732133444, 0.5567915535027732, 0.9548361904859624], 
             UndirectedEdge[38, 147] -> 
             RGBColor[
              0.6475207941885652, 0.7209158250246692, 0.9678645700248052], 
             UndirectedEdge[170, 182] -> 
             RGBColor[
              0.6838692055381399, 0.7524982912779351, 0.9694431334485218], 
             UndirectedEdge[94, 120] -> 
             RGBColor[
              0.6439276819832161, 0.721163608580984, 0.9655524264337495], 
             UndirectedEdge[80, 269] -> 
             RGBColor[
              0.7705153798206613, 0.8210410526724434, 0.9776581180915259], 
             UndirectedEdge[263, 286] -> 
             RGBColor[
              0.8065506842024956, 0.844844711699448, 0.7126715314149663], 
             UndirectedEdge[130, 140] -> 
             RGBColor[
              0.6060252746764249, 0.6893254243658411, 0.9632983306237726], 
             UndirectedEdge[25, 288] -> 
             RGBColor[
              0.517574640276715, 0.6190525722506842, 0.9552133858913644], 
             UndirectedEdge[148, 191] -> 
             RGBColor[
              0.6775861260279659, 0.74587030344846, 0.9702461731566453], 
             UndirectedEdge[177, 268] -> 
             RGBColor[
              0.59922398543946, 0.6855160519694924, 0.9615922536450296], 
             UndirectedEdge[69, 126] -> 
             RGBColor[
              0.7766383293478119, 0.8261127214086132, 0.9782426112867352], 
             UndirectedEdge[20, 37] -> 
             RGBColor[
              0.722864141931943, 0.7778959426856461, 0.791847002462841], 
             UndirectedEdge[3, 72] -> 
             RGBColor[
              0.7421072950212102, 0.7985555609589053, 0.9749043870231856], 
             UndirectedEdge[87, 154] -> 
             RGBColor[
              0.7003878384221744, 0.7632565979985508, 0.9555116186871367], 
             UndirectedEdge[11, 204] -> 
             RGBColor[
              0.7444085873758717, 0.799179296438928, 0.9585234360017841], 
             UndirectedEdge[55, 268] -> 
             RGBColor[
              0.48827742166377275`, 0.5923568225133622, 0.9537113050850119], 
             UndirectedEdge[125, 142] -> 
             RGBColor[
              0.7876862427074207, 0.8339632755184591, 0.9525222475899283], 
             UndirectedEdge[176, 221] -> 
             RGBColor[
              0.8230456122472408, 0.8451185322922735, 0.6771641776160358], 
             UndirectedEdge[29, 182] -> 
             RGBColor[
              0.6037304535620625, 0.6873951891574681, 0.9631461577622777], 
             UndirectedEdge[122, 161] -> 
             RGBColor[
              0.6194892750848939, 0.7009421460583336, 0.9638892170248843], 
             UndirectedEdge[44, 226] -> 
             RGBColor[
              0.7148324562623435, 0.7771518148508111, 0.9722114768172753], 
             UndirectedEdge[89, 131] -> 
             RGBColor[
              0.3293438816478559, 0.44696221323818497`, 0.9428443355948359], 
             UndirectedEdge[56, 110] -> 
             RGBColor[
              0.8408386734256015, 0.872847309734729, 0.7861847143492516], 
             UndirectedEdge[43, 178] -> 
             RGBColor[
              0.7453297506273477, 0.8010453690221504, 0.9752328951415383], 
             UndirectedEdge[66, 162] -> 
             RGBColor[
              0.6130816545208613, 0.6930759763801572, 0.9647657389426834], 
             UndirectedEdge[5, 142] -> 
             RGBColor[
              0.6262361919539912, 0.7074362963758124, 0.9637252362001895], 
             UndirectedEdge[147, 273] -> 
             RGBColor[
              0.43363241044131867`, 0.5500123317507702, 0.9488516516406043], 
             UndirectedEdge[81, 167] -> 
             RGBColor[
              0.5525017597164978, 0.6446643129796572, 0.9591874279101362], 
             UndirectedEdge[95, 212] -> 
             RGBColor[
              0.7001598699960094, 0.7639412548731557, 0.9723172572119698], 
             UndirectedEdge[56, 217] -> 
             RGBColor[
              0.6724667891511601, 0.7440554337125589, 0.9679888630493012], 
             UndirectedEdge[6, 93] -> 
             RGBColor[
              0.7072767774871935, 0.7700603889868154, 0.9724846869924568], 
             UndirectedEdge[131, 146] -> 
             RGBColor[
              0.4336175837589249, 0.5492815066044674, 0.9490490877449561], 
             UndirectedEdge[7, 80] -> 
             RGBColor[
              0.8454801924490529, 0.8796269717831673, 0.9851238495965103], 
             UndirectedEdge[76, 239] -> 
             RGBColor[
              0.8138637969553295, 0.8548083381273472, 0.9820043782311172], 
             UndirectedEdge[148, 278] -> 
             RGBColor[
              0.6709441972388419, 0.7405742097223666, 0.9696126600594188], 
             UndirectedEdge[29, 170] -> 
             RGBColor[
              0.5318785068042333, 0.6307991054775244, 0.9563024112994816], 
             UndirectedEdge[147, 289] -> 
             RGBColor[
              0.6968941186244901, 0.7594632569333211, 0.9440913388489955], 
             UndirectedEdge[25, 28] -> 
             RGBColor[
              0.783945549413932, 0.8304750483698367, 0.9401215692376587], 
             UndirectedEdge[5, 149] -> 
             RGBColor[
              0.7537434970204515, 0.8079092948737073, 0.9759942648286005], 
             UndirectedEdge[140, 202] -> 
             RGBColor[
              0.5059327798154343, 0.6097780485229889, 0.9542480282013599], 
             UndirectedEdge[10, 63] -> 
             RGBColor[
              0.7478700739527673, 0.8029610528857644, 0.9755043577945661], 
             UndirectedEdge[43, 259] -> 
             RGBColor[
              0.6994954600121157, 0.764138337237195, 0.9714172770832223], 
             UndirectedEdge[21, 50] -> 
             RGBColor[
              0.8202060626578138, 0.8172218386297695, 0.6393829355932089], 
             UndirectedEdge[87, 155] -> 
             RGBColor[
              0.6935358226572824, 0.2763173569683911, 0.426024586012406], 
             UndirectedEdge[127, 282] -> 
             RGBColor[
              0.6271604718534081, 0.7067535751475993, 0.9647778126080773], 
             UndirectedEdge[79, 144] -> 
             RGBColor[
              0.5803793856258421, 0.6702171569012503, 0.9601087377176579], 
             UndirectedEdge[54, 298] -> 
             RGBColor[
              0.732222668290802, 0.7887474819540803, 0.9431144658349968], 
             UndirectedEdge[234, 263] -> 
             RGBColor[
              0.5178519489355353, 0.6184261687031716, 0.9554704983602975], 
             UndirectedEdge[34, 38] -> 
             RGBColor[
              0.8354379509248226, 0.8717643849651677, 0.9841275798026805], 
             UndirectedEdge[39, 85] -> 
             RGBColor[
              0.391221740593781, 0.5132783411510794, 0.9461492812602019], 
             UndirectedEdge[20, 108] -> 
             RGBColor[
              0.5399556898980981, 0.6373448894041144, 0.9569414921283761], 
             UndirectedEdge[94, 201] -> 
             RGBColor[
              0.5568259519668322, 0.6497954476722998, 0.958876452165931], 
             UndirectedEdge[260, 294] -> 
             RGBColor[
              0.6727959644370669, 0.7435262867362364, 0.9685592705981678], 
             UndirectedEdge[138, 266] -> 
             RGBColor[
              0.5616965383340942, 0.6550495798171301, 0.9586379555413269], 
             UndirectedEdge[127, 168] -> 
             RGBColor[
              0.6015623061666838, 0.685971831058894, 0.9627626312360478], 
             UndirectedEdge[128, 198] -> 
             RGBColor[
              0.7794644210157601, 0.8279387662987785, 0.9785748458755343], 
             UndirectedEdge[145, 216] -> 
             RGBColor[
              0.7103932398764033, 0.7732888277331345, 0.9720391065367742], 
             UndirectedEdge[141, 182] -> 
             RGBColor[
              0.7551417493613289, 0.8086417409817127, 0.9762291304416213], 
             UndirectedEdge[41, 252] -> 
             RGBColor[
              0.8333320310678856, 0.8675985096239343, 0.8347306090692426], 
             UndirectedEdge[55, 208] -> 
             RGBColor[
              0.37504433037646845`, 0.49926628152112273`, 0.945118470986277], 
             UndirectedEdge[121, 249] -> 
             RGBColor[
              0.5818169529110289, 0.671384238785033, 0.9602219082803303], 
             UndirectedEdge[89, 120] -> 
             RGBColor[
              0.39116168800392537`, 0.49714869329848255`, 0.9477108597572718],
              UndirectedEdge[32, 142] -> 
             RGBColor[
              0.747864160230187, 0.8029884628769577, 0.9757058772565572], 
             UndirectedEdge[7, 77] -> 
             RGBColor[
              0.8571813828184457, 0.8889571833633698, 0.986239919579719], 
             UndirectedEdge[45, 146] -> 
             RGBColor[
              0.45193894378181615`, 0.5641556120389137, 0.9504914123193112], 
             UndirectedEdge[110, 223] -> 
             RGBColor[
              0.9942760129481324, 0.9901652954169482, 0.6183575176366466], 
             UndirectedEdge[225, 276] -> 
             RGBColor[
              0.7316107107615204, 0.7884537013016302, 0.9485119419614615], 
             UndirectedEdge[65, 291] -> 
             RGBColor[
              0.8332797610407683, 0.8678912925352206, 0.8555524070567544], 
             UndirectedEdge[194, 290] -> 
             RGBColor[
              0.5804094281152603, 0.6697018562939856, 0.9604800920831017], 
             UndirectedEdge[154, 258] -> 
             RGBColor[
              0.819095697198935, 0.8592000465174525, 0.9652312930493614], 
             UndirectedEdge[31, 280] -> 
             RGBColor[
              0.9231620485578376, 0.9414001546707333, 0.9867009021099531], 
             UndirectedEdge[156, 271] -> 
             RGBColor[
              0.5055979682958264, 0.609506233448284, 0.9542216706120814], 
             UndirectedEdge[83, 241] -> 
             RGBColor[
              0.5509921903686894, 0.6432190640894735, 0.9591495358022635], 
             UndirectedEdge[208, 268] -> 
             RGBColor[
              0.523725456415802, 0.6230601285455388, 0.9559700225139449], 
             UndirectedEdge[1, 80] -> 
             RGBColor[
              0.8717743980837099, 0.9005932576190445, 0.9876318144030585], 
             UndirectedEdge[116, 206] -> 
             RGBColor[
              0.7105328857709282, 0.7737929577049714, 0.9717829358124617], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.9849318971037531, 0.9868811017004365, 0.8476190043865607], 
             UndirectedEdge[108, 204] -> 
             RGBColor[
              0.7919281815008664, 0.8377578436829184, 0.9622643525213126], 
             UndirectedEdge[251, 271] -> 
             RGBColor[
              0.707429788803148, 0.7702379440846662, 0.9724353465870622], 
             UndirectedEdge[6, 38] -> 
             RGBColor[
              0.7001257981098953, 0.7643583921395218, 0.9718026201956955], 
             UndirectedEdge[135, 158] -> 
             RGBColor[
              0.7990231261657114, 0.839065947433498, 0.7393261894771854], 
             UndirectedEdge[25, 180] -> 
             RGBColor[
              0.5333542031509237, 0.6320399953077829, 0.9564067430943131], 
             UndirectedEdge[57, 217] -> 
             RGBColor[
              0.8118190179866871, 0.8533128766739488, 0.9542518228274939], 
             UndirectedEdge[71, 136] -> 
             RGBColor[
              0.4789651069117762, 0.5861185202095145, 0.9526129732666335], 
             UndirectedEdge[135, 173] -> 
             RGBColor[
              0.7971744685925352, 0.8399756255998403, 0.8916559402099671], 
             UndirectedEdge[143, 235] -> 
             RGBColor[
              0.6083876475471304, 0.6906914361893643, 0.9637550889940271], 
             UndirectedEdge[264, 288] -> 
             RGBColor[
              0.7053006106676629, 0.7669707702517317, 0.9479287237598166], 
             UndirectedEdge[223, 247] -> 
             RGBColor[
              0.9294910701223711, 0.9426566481468102, 0.8103906259924469], 
             UndirectedEdge[191, 225] -> 
             RGBColor[
              0.930200716101472, 0.9464143495894057, 0.9666306393954909], 
             UndirectedEdge[1, 243] -> 
             RGBColor[
              0.9166468065022206, 0.9358009070951857, 0.9720666306050748], 
             UndirectedEdge[29, 284] -> 
             RGBColor[
              0.7020100837858099, 0.7648136969157806, 0.9578332144818091], 
             UndirectedEdge[6, 273] -> 
             RGBColor[
              0.4862374143626488, 0.593454898865623, 0.9527897018114946], 
             UndirectedEdge[103, 276] -> 
             RGBColor[
              0.6396564036822647, 0.7162092465586681, 0.9662326720368271], 
             UndirectedEdge[99, 199] -> 
             RGBColor[
              0.8160058078035878, 0.8567676958163162, 0.982141977575378], 
             UndirectedEdge[35, 129] -> 
             RGBColor[
              0.9585950908898562, 0.9686408670967468, 0.9549718903803694], 
             UndirectedEdge[77, 145] -> 
             RGBColor[
              0.7540621728380593, 0.8079817975222364, 0.9762381101865034], 
             UndirectedEdge[72, 155] -> 
             RGBColor[
              0.8221843721770716, 0.37902151615348667`, 0.4374220001819269], 
             UndirectedEdge[20, 44] -> 
             RGBColor[
              0.5733364928018, 0.6636329933981007, 0.9601244760090053], 
             UndirectedEdge[131, 178] -> 
             RGBColor[
              0.5709598620842466, 0.6622666531977315, 0.9595745731241582], 
             UndirectedEdge[106, 241] -> 
             RGBColor[
              0.6693408046304493, 0.7362315773675135, 0.9515829248655754], 
             UndirectedEdge[85, 286] -> 
             RGBColor[
              0.6869736999272867, 0.745806032328448, 0.7037997395154699], 
             UndirectedEdge[86, 261] -> 
             RGBColor[
              0.47199303455779684`, 0.5819261285953818, 0.9516585346388124], 
             UndirectedEdge[256, 269] -> 
             RGBColor[
              0.5718990404504155, 0.6628648892715557, 0.9597607944766469], 
             UndirectedEdge[37, 61] -> 
             RGBColor[
              0.9799194375340716, 0.9820996438648453, 0.7885660014924576], 
             UndirectedEdge[73, 244] -> 
             RGBColor[
              0.5415011905371563, 0.6376978776704832, 0.9574022464824337], 
             UndirectedEdge[180, 193] -> 
             RGBColor[
              0.4652635838625422, 0.5767296231385812, 0.9510550594505798], 
             UndirectedEdge[8, 213] -> 
             RGBColor[
              0.4973187061189071, 0.6020478299567247, 0.9537735114713244], 
             UndirectedEdge[48, 138] -> 
             RGBColor[
              0.5586363461416289, 0.6525651779351996, 0.9583970460020828], 
             UndirectedEdge[170, 284] -> 
             RGBColor[
              0.7821488357618873, 0.8299167990362475, 0.9641301901680533], 
             UndirectedEdge[55, 219] -> 
             RGBColor[
              0.4567216140345469, 0.566738396307023, 0.9512271163157072], 
             UndirectedEdge[111, 235] -> 
             RGBColor[
              0.7506057874260936, 0.8050982130433194, 0.9757770281468913], 
             UndirectedEdge[56, 247] -> 
             RGBColor[
              0.7760537305998401, 0.825338662464591, 0.978217822705052], 
             UndirectedEdge[7, 82] -> 
             RGBColor[
              0.6586065670573957, 0.7309840725933342, 0.9681509554410044], 
             UndirectedEdge[182, 190] -> 
             RGBColor[
              0.6757561375998791, 0.7459117372361095, 0.9688044430212748], 
             UndirectedEdge[113, 228] -> 
             RGBColor[
              0.7734857362051135, 0.8218486209301337, 0.9356858354661156], 
             UndirectedEdge[133, 146] -> 
             RGBColor[
              0.4012121164527962, 0.5219315025892676, 0.9467858591757958], 
             UndirectedEdge[93, 274] -> 
             RGBColor[
              0.6560948299807228, 0.7278504018136187, 0.9686373127179619], 
             UndirectedEdge[153, 220] -> 
             RGBColor[
              0.6929683036694099, 0.7600713726714969, 0.9700322624189344], 
             UndirectedEdge[90, 153] -> 
             RGBColor[
              0.7704669564120947, 0.8208539630432345, 0.9776929009507256], 
             UndirectedEdge[178, 190] -> 
             RGBColor[
              0.6289750418882853, 0.7093659897167165, 0.9641417405949381], 
             UndirectedEdge[39, 126] -> 
             RGBColor[
              0.6600859586005636, 0.7300788348078182, 0.9694571616552885], 
             UndirectedEdge[15, 77] -> 
             RGBColor[
              0.8907908789194896, 0.754945702836555, 0.6097338909638808], 
             UndirectedEdge[103, 293] -> 
             RGBColor[
              0.6601374284042443, 0.7328366650876204, 0.9678450133274069], 
             UndirectedEdge[92, 269] -> 
             RGBColor[
              0.44346357295052863`, 0.543342881069457, 0.9517655422295919], 
             UndirectedEdge[8, 14] -> 
             RGBColor[
              0.4321321793538893, 0.5487129069866459, 0.9487560582423155], 
             UndirectedEdge[157, 171] -> 
             RGBColor[
              0.6416062410269631, 0.7183355941717515, 0.9660146572587962], 
             UndirectedEdge[198, 226] -> 
             RGBColor[
              0.7183149862359104, 0.7798723937343696, 0.9725585828589475], 
             UndirectedEdge[86, 169] -> 
             RGBColor[
              0.6640746622763336, 0.5659633714915935, 0.5879180535962742], 
             UndirectedEdge[163, 235] -> 
             RGBColor[
              0.7176233830902545, 0.7793321081006046, 0.9724896503207874], 
             UndirectedEdge[31, 136] -> 
             RGBColor[
              0.7559367197780562, 0.8089687716065264, 0.9709753731062825], 
             UndirectedEdge[111, 292] -> 
             RGBColor[
              0.6787671731647313, 0.7487789882593848, 0.9687524417018651], 
             UndirectedEdge[48, 122] -> 
             RGBColor[
              0.6063264000392115, 0.6902559311154852, 0.9628529872840881], 
             UndirectedEdge[246, 295] -> 
             RGBColor[
              0.5021705093221427, 0.6065241379747919, 0.9540069791849941], 
             UndirectedEdge[258, 263] -> 
             RGBColor[
              0.6518231009020103, 0.7275899146275822, 0.9661627362677705], 
             UndirectedEdge[24, 299] -> 
             RGBColor[
              0.5756620085537474, 0.6663873776787086, 0.9597373685142211], 
             UndirectedEdge[66, 193] -> 
             RGBColor[
              0.43282766256978505`, 0.5493152995922519, 0.9488003738178407], 
             UndirectedEdge[29, 199] -> 
             RGBColor[
              0.671647875205647, 0.7410312849324932, 0.969762018222516], 
             UndirectedEdge[27, 87] -> 
             RGBColor[
              0.5813326075197502, 0.6696527513473134, 0.961017475134262], 
             UndirectedEdge[164, 180] -> 
             RGBColor[
              0.4726129535492505, 0.5827275125190332, 0.9516249694231407], 
             UndirectedEdge[106, 200] -> 
             RGBColor[
              0.8357482473206912, 0.8721698261536117, 0.9649007380720399], 
             UndirectedEdge[69, 285] -> 
             RGBColor[
              0.5719333447414006, 0.6633602804214547, 0.9594438344403675], 
             UndirectedEdge[88, 137] -> 
             RGBColor[
              0.8643850771169272, 0.8947012136579064, 0.986927014372722], 
             UndirectedEdge[43, 261] -> 
             RGBColor[
              0.6650738078572559, 0.7361932893401217, 0.9687074785349252], 
             UndirectedEdge[224, 253] -> 
             RGBColor[
              0.47774083841216264`, 0.586529398490687, 0.952128445431628], 
             UndirectedEdge[5, 23] -> 
             RGBColor[
              0.5548040744624579, 0.6494444854159647, 0.9581018382467879], 
             UndirectedEdge[42, 162] -> 
             RGBColor[
              0.5472921860183229, 0.6336115157151614, 0.9606645311753355], 
             UndirectedEdge[29, 131] -> 
             RGBColor[
              0.4657502590619338, 0.5771132149167137, 0.9510965534014547], 
             UndirectedEdge[12, 192] -> 
             RGBColor[
              0.6192284673853502, 0.6976997363222441, 0.9654682710984599], 
             UndirectedEdge[69, 76] -> 
             RGBColor[
              0.7453061624387239, 0.8011293020043206, 0.9752541212363908], 
             UndirectedEdge[176, 180] -> 
             RGBColor[
              0.570883800581621, 0.6621858274775496, 0.9595816273525806], 
             UndirectedEdge[101, 116] -> 
             RGBColor[
              0.798976853227781, 0.8430232161754402, 0.9805618061794417], 
             UndirectedEdge[125, 293] -> 
             RGBColor[
              0.7523198891048377, 0.8052512764278088, 0.9497380786831111], 
             UndirectedEdge[30, 300] -> 
             RGBColor[
              0.6076025267588144, 0.6919999997690841, 0.9624693499807464], 
             UndirectedEdge[155, 290] -> 
             RGBColor[
              0.705955695618921, 0.2865333892631424, 0.4269655701084286], 
             UndirectedEdge[217, 246] -> 
             RGBColor[
              0.6078807880247086, 0.6923137781544653, 0.9624311762347146], 
             UndirectedEdge[42, 82] -> 
             RGBColor[
              0.3881581083632921, 0.5070282767775334, 0.9463531437378676], 
             UndirectedEdge[122, 138] -> 
             RGBColor[
              0.661657616036794, 0.7351763049051976, 0.9672088632923405], 
             UndirectedEdge[58, 160] -> 
             RGBColor[
              0.8267526277715443, 0.8647196481352093, 0.9426055314858649], 
             UndirectedEdge[158, 225] -> 
             RGBColor[
              0.9793815695169286, 0.9809491985629746, 0.7300223871630658], 
             UndirectedEdge[197, 204] -> 
             RGBColor[
              0.7966410053044792, 0.8415839263569842, 0.9626353632747754], 
             UndirectedEdge[40, 182] -> 
             RGBColor[
              0.7424049459692683, 0.7986916533685439, 0.9749596449116955], 
             UndirectedEdge[1, 149] -> 
             RGBColor[
              0.8699534875334254, 0.8991413129735479, 0.9874581343292262], 
             UndirectedEdge[32, 156] -> 
             RGBColor[
              0.6791557786661906, 0.7472079034459894, 0.9702969017727447], 
             UndirectedEdge[258, 286] -> 
             RGBColor[
              0.8381127688258541, 0.8698397650148424, 0.7155859019088631], 
             UndirectedEdge[101, 197] -> 
             RGBColor[
              0.7374897264895484, 0.7949226272858417, 0.974478727128077], 
             UndirectedEdge[53, 271] -> 
             RGBColor[
              0.5597739487469202, 0.6534887349785885, 0.9584866022463469], 
             UndirectedEdge[22, 70] -> 
             RGBColor[
              0.631994943577793, 0.7096369734612813, 0.9658704406241199], 
             UndirectedEdge[76, 258] -> 
             RGBColor[
              0.7697781677244961, 0.8203683095090284, 0.9776103347130163], 
             UndirectedEdge[232, 297] -> 
             RGBColor[
              0.5555075388820793, 0.6476083010423759, 0.9592348237005821], 
             UndirectedEdge[178, 261] -> 
             RGBColor[
              0.5819030181026896, 0.6711508002370643, 0.9604360584520313], 
             UndirectedEdge[155, 227] -> 
             RGBColor[
              0.7732746090305588, 0.34074854760665296`, 0.4325641926283481], 
             UndirectedEdge[178, 182] -> 
             RGBColor[
              0.7089400565843753, 0.7725486274384861, 0.9716241774849812], 
             UndirectedEdge[5, 51] -> 
             RGBColor[
              0.6002075228834765, 0.6863050502461896, 0.9616761640248022], 
             UndirectedEdge[110, 295] -> 
             RGBColor[
              0.7200516309488545, 0.7752795871070167, 0.7762578063868888], 
             UndirectedEdge[186, 286] -> 
             RGBColor[
              0.8441116191855738, 0.8745261125088066, 0.716183811250276], 
             UndirectedEdge[34, 270] -> 
             RGBColor[
              0.8232362607043724, 0.8620350883894385, 0.9829637716968764], 
             UndirectedEdge[4, 8] -> 
             RGBColor[
              0.6451394936134176, 0.7190151783527603, 0.9676382967378002], 
             UndirectedEdge[69, 166] -> 
             RGBColor[
              0.761809637284534, 0.8142887248714787, 0.9768282374000101], 
             UndirectedEdge[25, 176] -> 
             RGBColor[
              0.6258746084813283, 0.7068298426381967, 0.9639107051884123], 
             UndirectedEdge[32, 149] -> 
             RGBColor[
              0.8753714652966473, 0.9034614613748526, 0.9879749058849683], 
             UndirectedEdge[16, 153] -> 
             RGBColor[
              0.8419395296787395, 0.8749744694790361, 0.8708395304778482], 
             UndirectedEdge[169, 299] -> 
             RGBColor[
              0.7082316898184244, 0.6021101414610412, 0.5913118890473923], 
             UndirectedEdge[187, 229] -> 
             RGBColor[
              0.6656958554854521, 0.736547828360018, 0.9689296334681661], 
             UndirectedEdge[15, 82] -> 
             RGBColor[
              0.6922160631584395, 0.5969725920665194, 0.5916449268251661], 
             UndirectedEdge[44, 280] -> 
             RGBColor[
              0.7997317575686971, 0.8441556863105012, 0.9804930233049163], 
             UndirectedEdge[186, 265] -> 
             RGBColor[
              0.6545943119617668, 0.7296559191343428, 0.966506554020258], 
             UndirectedEdge[117, 265] -> 
             RGBColor[
              0.7364156149393404, 0.7938909007324751, 0.9745779974874031], 
             UndirectedEdge[106, 162] -> 
             RGBColor[
              0.8848494014204702, 0.9105280209189517, 0.9697946822363326], 
             UndirectedEdge[9, 146] -> 
             RGBColor[
              0.44871817034142675`, 0.5615408430658155, 0.950237861236002], 
             UndirectedEdge[130, 294] -> 
             RGBColor[
              0.7543471991882731, 0.8080210323477166, 0.9761499371058645], 
             UndirectedEdge[13, 53] -> 
             RGBColor[
              0.6289463348760711, 0.7091082449234654, 0.9642997679993143], 
             UndirectedEdge[34, 57] -> 
             RGBColor[
              0.8841570386700451, 0.9098238882211078, 0.9614618006919733], 
             UndirectedEdge[25, 144] -> 
             RGBColor[
              0.5633619095810442, 0.6564016032195239, 0.9587690596663427], 
             UndirectedEdge[206, 283] -> 
             RGBColor[
              0.7628492954815681, 0.8150318979293256, 0.9768994350821957], 
             UndirectedEdge[107, 273] -> 
             RGBColor[
              0.6296769742764667, 0.7072100838875037, 0.9659247254031593], 
             UndirectedEdge[64, 85] -> 
             RGBColor[
              0.5159533226222915, 0.6158231807504384, 0.9556670309267211], 
             UndirectedEdge[175, 224] -> 
             RGBColor[
              0.6187136290719246, 0.6986022683061829, 0.9648502719245664], 
             UndirectedEdge[68, 163] -> 
             RGBColor[
              0.5643945732527493, 0.6569366559614307, 0.9590577295378973], 
             UndirectedEdge[7, 237] -> 
             RGBColor[
              0.7335241548474634, 0.7917767495794239, 0.9740684302165759], 
             UndirectedEdge[76, 126] -> 
             RGBColor[
              0.8875033168327116, 0.9131350704793728, 0.9891320527147097], 
             UndirectedEdge[30, 236] -> 
             RGBColor[
              0.49732114761537555`, 0.6024947304682489, 0.9536507713967781], 
             UndirectedEdge[7, 269] -> 
             RGBColor[
              0.7478447204204409, 0.8029640842453636, 0.9754957703595963], 
             UndirectedEdge[237, 256] -> 
             RGBColor[
              0.5575784748774378, 0.6516775546056162, 0.9583334543336264], 
             UndirectedEdge[106, 290] -> 
             RGBColor[
              0.7201280666608416, 0.7794087949607469, 0.9550434454527937], 
             UndirectedEdge[180, 288] -> 
             RGBColor[
              0.4625838323770078, 0.5744085570900372, 0.9508843080555327], 
             UndirectedEdge[201, 237] -> 
             RGBColor[
              0.5367158463105883, 0.6340852802911784, 0.9568720647737388], 
             UndirectedEdge[10, 73] -> 
             RGBColor[
              0.6919818408271249, 0.7593007404017087, 0.9699339410218348], 
             UndirectedEdge[18, 175] -> 
             RGBColor[
              0.620273210170325, 0.6999530990667922, 0.9649496470530732], 
             UndirectedEdge[57, 295] -> 
             RGBColor[
              0.7061087392841212, 0.7675232364942753, 0.9458276257777734], 
             UndirectedEdge[71, 161] -> 
             RGBColor[
              0.4589550278663033, 0.5698734365966114, 0.9510377065448392], 
             UndirectedEdge[218, 220] -> 
             RGBColor[
              0.6645639220074319, 0.73776036285453, 0.9672841064152753], 
             UndirectedEdge[192, 248] -> 
             RGBColor[
              0.5901927390041986, 0.6749252001209699, 0.9625985700681646], 
             UndirectedEdge[23, 24] -> 
             RGBColor[
              0.5436505769365173, 0.6403990553932808, 0.957217311355575], 
             UndirectedEdge[39, 195] -> 
             RGBColor[
              0.6725670103338568, 0.7398220464058829, 0.9634069924257778], 
             UndirectedEdge[79, 232] -> 
             RGBColor[
              0.5121631386666179, 0.6134412728009355, 0.955123909319676], 
             UndirectedEdge[12, 154] -> 
             RGBColor[
              0.8930618574634659, 0.9170745775899524, 0.9725792396310338], 
             UndirectedEdge[106, 155] -> 
             RGBColor[
              0.86388834882164, 0.4119084740440222, 0.4286873935267672], 
             UndirectedEdge[95, 103] -> 
             RGBColor[
              0.8558961771439606, 0.8882433408565298, 0.9860348201104425], 
             UndirectedEdge[3, 228] -> 
             RGBColor[
              0.607823267472629, 0.6923450611411226, 0.9623733321332057], 
             UndirectedEdge[81, 293] -> 
             RGBColor[
              0.6279242407521052, 0.7076714780644754, 0.9646343038315957], 
             UndirectedEdge[95, 145] -> 
             RGBColor[
              0.773425161989055, 0.8234213194769014, 0.97808496937727], 
             UndirectedEdge[39, 153] -> 
             RGBColor[
              0.5462931858685541, 0.6403840761497331, 0.9583273861806286], 
             UndirectedEdge[39, 90] -> 
             RGBColor[
              0.6255102040028685, 0.7025090666254725, 0.9661592953156198], 
             UndirectedEdge[120, 141] -> 
             RGBColor[
              0.6789793612172698, 0.7485462468012558, 0.9690460502432341], 
             UndirectedEdge[102, 172] -> 
             RGBColor[
              0.6959483650405841, 0.760945120457305, 0.9714988986288737], 
             UndirectedEdge[155, 194] -> 
             RGBColor[
              0.7707425897912525, 0.3387705149328479, 0.43231182461363915`], 
             UndirectedEdge[53, 251] -> 
             RGBColor[
              0.7280854584462061, 0.7870071472282141, 0.9740614365655748], 
             UndirectedEdge[128, 243] -> 
             RGBColor[
              0.9072488157596034, 0.9283072043786855, 0.9711702418583585], 
             UndirectedEdge[72, 87] -> 
             RGBColor[
              0.6389422922515311, 0.7147543096828166, 0.9667338792914992], 
             UndirectedEdge[76, 90] -> 
             RGBColor[
              0.8529275622350163, 0.8855653022970271, 0.985834186375041], 
             UndirectedEdge[3, 106] -> 
             RGBColor[
              0.804663259988063, 0.8478859977947086, 0.9618024770404461], 
             UndirectedEdge[104, 243] -> 
             RGBColor[
              0.9711378433575593, 0.9779639947246455, 0.9323414422099], 
             UndirectedEdge[34, 217] -> 
             RGBColor[
              0.7297280460603373, 0.7887883628116792, 0.9736961300011384], 
             UndirectedEdge[31, 37] -> 
             RGBColor[
              0.968319759370758, 0.9734486228833759, 0.8082012309423525], 
             UndirectedEdge[64, 249] -> 
             RGBColor[
              0.5963867343331448, 0.6830833445158458, 0.9614572974063207], 
             UndirectedEdge[89, 188] -> 
             RGBColor[
              0.30020259516386466`, 0.4224394785886223, 0.9407890977412605], 
             UndirectedEdge[179, 269] -> 
             RGBColor[
              0.5794860244987108, 0.6690243447116984, 0.960358069652967], 
             UndirectedEdge[213, 249] -> 
             RGBColor[
              0.5552168414812391, 0.6497890700049658, 0.9581278500691586], 
             UndirectedEdge[44, 252] -> 
             RGBColor[
              0.8452011098976059, 0.876870724214052, 0.8359136079241412], 
             UndirectedEdge[149, 198] -> 
             RGBColor[
              0.7834179549736563, 0.8310912069609844, 0.9789519374737998], 
             UndirectedEdge[158, 214] -> 
             RGBColor[
              0.9824556682782533, 0.9832418563857959, 0.724818739813508], 
             UndirectedEdge[202, 216] -> 
             RGBColor[
              0.6790812144463115, 0.7478683148983152, 0.9695741091951888], 
             UndirectedEdge[78, 209] -> 
             RGBColor[
              0.722031140388839, 0.7817010946696823, 0.9740347192636614], 
             UndirectedEdge[77, 265] -> 
             RGBColor[
              0.7526794851333922, 0.8068592693542164, 0.9761292599454401], 
             UndirectedEdge[44, 204] -> 
             RGBColor[
              0.8253089844045683, 0.8640459476769047, 0.9654473364019418], 
             UndirectedEdge[54, 102] -> 
             RGBColor[
              0.745819094396823, 0.7997856731789641, 0.9441848263034127], 
             UndirectedEdge[2, 253] -> 
             RGBColor[
              0.7456761028947612, 0.7739203860670647, 0.6579126181806946], 
             UndirectedEdge[40, 86] -> 
             RGBColor[
              0.5857138667127817, 0.6729212342074685, 0.9615194186721399], 
             UndirectedEdge[75, 165] -> 
             RGBColor[
              0.6766744795734448, 0.7473215899981385, 0.9684225517858573], 
             UndirectedEdge[73, 100] -> 
             RGBColor[
              0.6350325074423284, 0.7143662605234227, 0.9645621683751557], 
             UndirectedEdge[50, 206] -> 
             RGBColor[
              0.8114696455251236, 0.8103968831664824, 0.6385121711798822], 
             UndirectedEdge[32, 277] -> 
             RGBColor[
              0.8704372536500709, 0.8995270549434796, 0.9875042763732951], 
             UndirectedEdge[156, 251] -> 
             RGBColor[
              0.6739094779951122, 0.7430246456979096, 0.9697965049313093], 
             UndirectedEdge[31, 44] -> 
             RGBColor[
              0.818792110240615, 0.8591856735958303, 0.9764787044885167], 
             UndirectedEdge[80, 92] -> 
             RGBColor[
              0.5410990449791406, 0.6200057686072609, 0.9613936214665058], 
             UndirectedEdge[11, 149] -> 
             RGBColor[
              0.6990350279713928, 0.7635039768394494, 0.9716809310319701], 
             UndirectedEdge[103, 145] -> 
             RGBColor[
              0.6990421282429653, 0.764421253053449, 0.9709077338113223], 
             UndirectedEdge[150, 274] -> 
             RGBColor[
              0.60151746315236, 0.6847039095873397, 0.9633329524449912], 
             UndirectedEdge[13, 156] -> 
             RGBColor[
              0.5747703544249774, 0.665125743393161, 0.9600348363650488], 
             UndirectedEdge[84, 278] -> 
             RGBColor[
              0.7949406870187723, 0.8402317672061748, 0.9800635521086543], 
             UndirectedEdge[150, 293] -> 
             RGBColor[
              0.6563593868072193, 0.7298852302778447, 0.9674684534488216], 
             UndirectedEdge[52, 137] -> 
             RGBColor[
              0.8314826309598036, 0.8688875941023011, 0.9836767909562092], 
             UndirectedEdge[41, 152] -> 
             RGBColor[
              0.704419495751623, 0.7690171309584052, 0.9711736102282152], 
             UndirectedEdge[177, 279] -> 
             RGBColor[
              0.6213456957348009, 0.7028804282249035, 0.9637405773743637], 
             UndirectedEdge[108, 279] -> 
             RGBColor[
              0.6549010908689294, 0.730122209648113, 0.9663821809967847], 
             UndirectedEdge[161, 279] -> 
             RGBColor[
              0.6054164242645997, 0.6899483280398921, 0.9624865667733855], 
             UndirectedEdge[89, 260] -> 
             RGBColor[
              0.3849782912237224, 0.4921287332334633, 0.9472240801122055], 
             UndirectedEdge[63, 161] -> 
             RGBColor[
              0.6490888241463664, 0.7240655387500607, 0.9668394234518193], 
             UndirectedEdge[110, 148] -> 
             RGBColor[
              0.727163185667616, 0.7812525974729849, 0.776762523326316], 
             UndirectedEdge[200, 228] -> 
             RGBColor[
              0.6389082548052574, 0.7166288895000258, 0.9654715931647996], 
             UndirectedEdge[67, 118] -> 
             RGBColor[
              0.8185055117525217, 0.8590251240830906, 0.9823102824705627], 
             UndirectedEdge[140, 203] -> 
             RGBColor[
              0.7263196873901434, 0.780957353245014, 0.808623216686835], 
             UndirectedEdge[144, 231] -> 
             RGBColor[
              0.48487494260064956`, 0.5920864372151289, 0.9527549299408037], 
             UndirectedEdge[101, 149] -> 
             RGBColor[
              0.8507313113382524, 0.8838140714475899, 0.9856247060038914], 
             UndirectedEdge[131, 284] -> 
             RGBColor[
              0.7160205880195878, 0.7762309084754369, 0.9589243322700265], 
             UndirectedEdge[157, 275] -> 
             RGBColor[
              0.7584182024298245, 0.8097468604454587, 0.9380063498261273], 
             UndirectedEdge[113, 144] -> 
             RGBColor[
              0.7610016095438159, 0.8117134445029953, 0.9347030392844755], 
             UndirectedEdge[48, 73] -> 
             RGBColor[
              0.5800377159750416, 0.6697190113231568, 0.9602327769382919], 
             UndirectedEdge[35, 183] -> 
             RGBColor[
              0.8040326951414611, 0.8467458924373272, 0.9407157221901239], 
             UndirectedEdge[93, 107] -> 
             RGBColor[
              0.8507163374010114, 0.8838155740086961, 0.9856197105841217], 
             UndirectedEdge[23, 226] -> 
             RGBColor[
              0.6004666394529647, 0.6851164282348962, 0.9626530559841104], 
             UndirectedEdge[200, 211] -> 
             RGBColor[
              0.4939729138035154, 0.5908198113667911, 0.9555303714245384], 
             UndirectedEdge[87, 227] -> 
             RGBColor[
              0.5655776475317619, 0.657344856862566, 0.9594471679611312], 
             UndirectedEdge[223, 278] -> 
             RGBColor[
              0.9380570245193585, 0.9494869076663299, 0.8112076543697494], 
             UndirectedEdge[182, 229] -> 
             RGBColor[
              0.6189091704915185, 0.6997608084108582, 0.9643292415332028], 
             UndirectedEdge[79, 221] -> 
             RGBColor[
              0.8025334908613415, 0.828788253804233, 0.6753289714090834], 
             UndirectedEdge[115, 228] -> 
             RGBColor[
              0.6881827268615666, 0.7551224815702726, 0.9703828120432508], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.9119733135670645, 0.9297769982392765, 0.877795534532487], 
             UndirectedEdge[9, 47] -> 
             RGBColor[
              0.7301711706096352, 0.7877817335147013, 0.9617212147195738], 
             UndirectedEdge[18, 224] -> 
             RGBColor[
              0.4415762631111729, 0.5568928976637535, 0.9493578269082542], 
             UndirectedEdge[194, 291] -> 
             RGBColor[
              0.6748949355410637, 0.7459523201269477, 0.9682308779891287], 
             UndirectedEdge[5, 198] -> 
             RGBColor[
              0.6726524212454035, 0.7442004509154381, 0.9680073651216248], 
             UndirectedEdge[49, 172] -> 
             RGBColor[
              0.7601213549755319, 0.8129508864974362, 0.9766142507232429], 
             UndirectedEdge[162, 228] -> 
             RGBColor[
              0.6880094089050363, 0.7549870842653658, 0.9703655373290923], 
             UndirectedEdge[100, 161] -> 
             RGBColor[
              0.5714627966570157, 0.6629782682886015, 0.9594067911714903], 
             UndirectedEdge[174, 235] -> 
             RGBColor[
              0.7240997220037031, 0.7843914732817894, 0.9731351512588517], 
             UndirectedEdge[14, 67] -> 
             RGBColor[
              0.6836667669431233, 0.7501453176880813, 0.9711245299116679], 
             UndirectedEdge[190, 199] -> 
             RGBColor[
              0.7436735592434636, 0.7995478330111343, 0.9754203034815131], 
             UndirectedEdge[160, 288] -> 
             RGBColor[
              0.7138541148851604, 0.7733499596920637, 0.9334498722307815], 
             UndirectedEdge[33, 275] -> 
             RGBColor[
              0.9784499996248316, 0.9834486255218622, 0.9213627088816132], 
             UndirectedEdge[109, 218] -> 
             RGBColor[
              0.549763626462061, 0.64536190438786, 0.9576985530070641], 
             UndirectedEdge[231, 264] -> 
             RGBColor[
              0.6975840144611842, 0.7602870424650825, 0.9474370290730578], 
             UndirectedEdge[221, 230] -> 
             RGBColor[
              0.6627949687343049, 0.7123441980695546, 0.66515660722652], 
             UndirectedEdge[45, 236] -> 
             RGBColor[
              0.4794835433068419, 0.5880133597156647, 0.9522465298443128], 
             UndirectedEdge[279, 280] -> 
             RGBColor[
              0.7926518320898539, 0.8386247947170022, 0.9797873624988505], 
             UndirectedEdge[71, 252] -> 
             RGBColor[
              0.6916597880204662, 0.7512649411772724, 0.823759086889529], 
             UndirectedEdge[230, 296] -> 
             RGBColor[
              0.4345229052307262, 0.5488062670336658, 0.9494547454494118], 
             UndirectedEdge[27, 154] -> 
             RGBColor[
              0.8357509779700772, 0.872211278440691, 0.9668913357841808], 
             UndirectedEdge[5, 101] -> 
             RGBColor[
              0.7399657776099996, 0.7969233154020434, 0.9746801336517164], 
             UndirectedEdge[68, 143] -> 
             RGBColor[
              0.4551588377096252, 0.5682959840501904, 0.950323168211137], 
             UndirectedEdge[58, 221] -> 
             RGBColor[
              0.8276441569290115, 0.8487109503479068, 0.6776225175740713], 
             UndirectedEdge[85, 249] -> 
             RGBColor[
              0.4615404594390872, 0.5717776663355952, 0.9512950484544804], 
             UndirectedEdge[26, 54] -> 
             RGBColor[
              0.7771626851017873, 0.8252318121259241, 0.9466523085790634], 
             UndirectedEdge[269, 282] -> 
             RGBColor[
              0.5953355758089596, 0.6818917244795079, 0.9616058043909292], 
             UndirectedEdge[24, 210] -> 
             RGBColor[
              0.6319687552871791, 0.7120858288758616, 0.9641795470161958], 
             UndirectedEdge[144, 288] -> 
             RGBColor[
              0.4925915388071282, 0.5987701650017783, 0.9532466246275624], 
             UndirectedEdge[182, 199] -> 
             RGBColor[
              0.8236385739395535, 0.8627304707329039, 0.9829027403715562], 
             UndirectedEdge[35, 224] -> 
             RGBColor[
              0.7103386535708945, 0.7703196866532303, 0.9334395741531235], 
             UndirectedEdge[161, 280] -> 
             RGBColor[
              0.7168662880606655, 0.777693700708294, 0.9734144252008877], 
             UndirectedEdge[27, 42] -> 
             RGBColor[
              0.49930418136413923`, 0.5961229217569697, 0.9558815353448067], 
             UndirectedEdge[13, 273] -> 
             RGBColor[
              0.5592480594868106, 0.6521904803742469, 0.9589050293725552], 
             UndirectedEdge[167, 202] -> 
             RGBColor[
              0.47093190678363955`, 0.5795869657883546, 0.9519832893311897], 
             UndirectedEdge[117, 207] -> 
             RGBColor[
              0.7304035058414017, 0.7890099997243403, 0.9741047022361322], 
             UndirectedEdge[33, 248] -> 
             RGBColor[
              0.8752403612099672, 0.902663597347862, 0.9507267687487903], 
             UndirectedEdge[23, 210] -> 
             RGBColor[
              0.5549483639833788, 0.649557205486349, 0.958116219677771], 
             UndirectedEdge[54, 111] -> 
             RGBColor[
              0.8498468623117459, 0.8829262946845833, 0.9532725302027502], 
             UndirectedEdge[30, 267] -> 
             RGBColor[
              0.7117776924010746, 0.7737986271959978, 0.972742111227402], 
             UndirectedEdge[170, 199] -> 
             RGBColor[0.7517866271817244, 0.80613438705296, 0.97605899390876],
              UndirectedEdge[169, 200] -> 
             RGBColor[
              0.8001398894730669, 0.6756207182613079, 0.5993024876620601], 
             UndirectedEdge[137, 278] -> 
             RGBColor[
              0.888437594872332, 0.9138800384278642, 0.9892211649881686], 
             UndirectedEdge[92, 150] -> 
             RGBColor[
              0.4940021491564145, 0.5828240009089004, 0.9568027551959479], 
             UndirectedEdge[68, 185] -> 
             RGBColor[
              0.4818439021521098, 0.59022161244433, 0.9523516635112368], 
             UndirectedEdge[26, 102] -> 
             RGBColor[
              0.5514118244195784, 0.6466999857402443, 0.9578283051878278], 
             UndirectedEdge[270, 271] -> 
             RGBColor[
              0.6917623668844558, 0.7577451671275397, 0.9709409738979846], 
             UndirectedEdge[169, 202] -> 
             RGBColor[
              0.7198786964987738, 0.6115657061758204, 0.5922287840776606], 
             UndirectedEdge[17, 97] -> 
             RGBColor[
              0.6515293281406954, 0.7259292812944504, 0.9671119311201462], 
             UndirectedEdge[46, 158] -> 
             RGBColor[
              0.916098565852854, 0.9312555172894639, 0.7505603271580736], 
             UndirectedEdge[98, 285] -> 
             RGBColor[
              0.749025017506862, 0.801088784520186, 0.8963538268223779], 
             UndirectedEdge[77, 168] -> 
             RGBColor[
              0.6790740725202401, 0.7471030795088088, 0.9703347722390223], 
             UndirectedEdge[242, 268] -> 
             RGBColor[
              0.8003025253115599, 0.8442794357278441, 0.9554920120226266], 
             UndirectedEdge[115, 134] -> 
             RGBColor[
              0.8195140759646388, 0.8589785957439275, 0.9826322378272109], 
             UndirectedEdge[99, 284] -> 
             RGBColor[
              0.8463680163837507, 0.8805501077996037, 0.9702131738346713], 
             UndirectedEdge[204, 283] -> 
             RGBColor[
              0.9104445417533518, 0.9309234554709369, 0.9738349415958738], 
             UndirectedEdge[77, 167] -> 
             RGBColor[
              0.639734991963731, 0.7133900444715896, 0.9677285137811287], 
             UndirectedEdge[227, 290] -> 
             RGBColor[
              0.5842074569742197, 0.6726689053046931, 0.9608586441051652], 
             UndirectedEdge[60, 145] -> 
             RGBColor[
              0.5531826312418958, 0.6481376064925399, 0.9579677095875598], 
             UndirectedEdge[32, 125] -> 
             RGBColor[
              0.9260559823218242, 0.9430976844719527, 0.9658273449225321], 
             UndirectedEdge[15, 60] -> 
             RGBColor[
              0.689911337323326, 0.5951015118068586, 0.5914634903649371], 
             UndirectedEdge[30, 260] -> 
             RGBColor[
              0.5715541372030032, 0.6630524226586788, 0.9594139818338618], 
             UndirectedEdge[42, 80] -> 
             RGBColor[
              0.5750317337549493, 0.6556711759673665, 0.9633260378933737], 
             UndirectedEdge[97, 130] -> 
             RGBColor[
              0.6404845572243101, 0.7173010223112023, 0.9660110915744533], 
             UndirectedEdge[65, 211] -> 
             RGBColor[
              0.6339178999018675, 0.6983534410867573, 0.8410139896307339], 
             UndirectedEdge[1, 256] -> 
             RGBColor[
              0.6731580587134641, 0.7424170942181569, 0.9697344907881793], 
             UndirectedEdge[5, 128] -> 
             RGBColor[
              0.7497899630625553, 0.8047568542115013, 0.9756171732303349], 
             UndirectedEdge[125, 256] -> 
             RGBColor[
              0.7183981189539198, 0.7777120552609631, 0.9470676326772924], 
             UndirectedEdge[39, 239] -> 
             RGBColor[
              0.5864464387231816, 0.6717521024557926, 0.9623294871716959], 
             UndirectedEdge[156, 269] -> 
             RGBColor[
              0.57247878263992, 0.6633355500980835, 0.9598064339054702], 
             UndirectedEdge[78, 170] -> 
             RGBColor[
              0.5631597795786222, 0.6562375049777048, 0.9587531472521256], 
             UndirectedEdge[23, 155] -> 
             RGBColor[
              0.700422728544239, 0.28204147733458945`, 0.4265299946723834], 
             UndirectedEdge[127, 251] -> 
             RGBColor[
              0.80613549919169, 0.8489291114025572, 0.9811921180975991], 
             UndirectedEdge[241, 290] -> 
             RGBColor[
              0.4324418248263708, 0.5481689501961939, 0.9490001897380674], 
             UndirectedEdge[85, 234] -> 
             RGBColor[
              0.3982749646603263, 0.5193874893321717, 0.946598706460801], 
             UndirectedEdge[270, 289] -> 
             RGBColor[
              0.9059814693214249, 0.9270475309044199, 0.9624120124581295], 
             UndirectedEdge[69, 258] -> 
             RGBColor[
              0.6589131802395964, 0.7333459604382688, 0.9667208932850417], 
             UndirectedEdge[52, 289] -> 
             RGBColor[
              0.8676711866105286, 0.8969218492726491, 0.9586459847634852], 
             UndirectedEdge[47, 170] -> 
             RGBColor[
              0.7811988317694328, 0.8292082876141638, 0.9657382991265548], 
             UndirectedEdge[72, 241] -> 
             RGBColor[
              0.6067848396635966, 0.6869011405317103, 0.9646848348483149], 
             UndirectedEdge[115, 210] -> 
             RGBColor[
              0.7281424673115607, 0.7875496966422901, 0.9735380943295362], 
             UndirectedEdge[166, 239] -> 
             RGBColor[
              0.8303672718011395, 0.8679677609945053, 0.9835784943947364], 
             UndirectedEdge[180, 215] -> 
             RGBColor[
              0.7120022582864177, 0.7731878989750348, 0.9644886235907566], 
             UndirectedEdge[51, 254] -> 
             RGBColor[
              0.5043741244134399, 0.6084581716124107, 0.9541403809538547], 
             UndirectedEdge[109, 227] -> 
             RGBColor[
              0.5751359525309871, 0.6653042493310588, 0.9601445020453782], 
             UndirectedEdge[203, 255] -> 
             RGBColor[
              0.9412768661317394, 0.9522573253131863, 0.8279708748571806], 
             UndirectedEdge[257, 272] -> 
             RGBColor[
              0.90552980355977, 0.9275089016795822, 0.9908514351111712], 
             UndirectedEdge[32, 128] -> 
             RGBColor[
              0.8714179313387511, 0.9003090207126465, 0.9875978142867027], 
             UndirectedEdge[39, 76] -> 
             RGBColor[
              0.6287537916914758, 0.7050954154035256, 0.9664686716049441], 
             UndirectedEdge[144, 221] -> 
             RGBColor[
              0.7605329133469567, 0.7946902928736007, 0.6720225320939662], 
             UndirectedEdge[165, 262] -> 
             RGBColor[
              0.5793921847728077, 0.6694157027758654, 0.9600310216502712], 
             UndirectedEdge[101, 226] -> 
             RGBColor[
              0.7856283426005064, 0.832595258220975, 0.9792313513890389], 
             UndirectedEdge[56, 191] -> 
             RGBColor[
              0.7912616137859514, 0.837465015710204, 0.9796683641795809], 
             UndirectedEdge[63, 71] -> 
             RGBColor[
              0.5784129717772585, 0.6649217413154883, 0.9617635005212357], 
             UndirectedEdge[137, 289] -> 
             RGBColor[
              0.931367928327075, 0.9472900042184529, 0.9648333955808479], 
             UndirectedEdge[148, 295] -> 
             RGBColor[
              0.4530810226906087, 0.5666710812711414, 0.9501424749766452], 
             UndirectedEdge[10, 119] -> 
             RGBColor[
              0.8567024762961755, 0.887687203766472, 0.9258084756519145], 
             UndirectedEdge[115, 231] -> 
             RGBColor[
              0.6221947346894614, 0.7009545463876453, 0.9653526473998737], 
             UndirectedEdge[33, 171] -> 
             RGBColor[
              0.8616380382219702, 0.892037359248155, 0.9493710163142821], 
             UndirectedEdge[173, 234] -> 
             RGBColor[
              0.7025434739617704, 0.762121522816894, 0.8844903911723261], 
             UndirectedEdge[69, 173] -> 
             RGBColor[
              0.8120426206424731, 0.8520462612365969, 0.8928264156031738], 
             UndirectedEdge[4, 263] -> 
             RGBColor[
              0.7421812015401053, 0.7985349340065939, 0.9750741607555313], 
             UndirectedEdge[134, 160] -> 
             RGBColor[
              0.9034568599538592, 0.9246902812616966, 0.9502377679713601], 
             UndirectedEdge[7, 205] -> 
             RGBColor[
              0.9089380489740178, 0.9268889577027393, 0.8571924095064792], 
             UndirectedEdge[23, 106] -> 
             RGBColor[
              0.7118286160488185, 0.7726709270679174, 0.9543900822987259], 
             UndirectedEdge[45, 96] -> 
             RGBColor[
              0.454622733587997, 0.5664801758778297, 0.9506624210325789], 
             UndirectedEdge[65, 210] -> 
             RGBColor[
              0.8188129813536036, 0.8565897342920097, 0.8541104936572805], 
             UndirectedEdge[138, 211] -> 
             RGBColor[
              0.44372197078488995`, 0.5511284721416685, 0.9508191846478169], 
             UndirectedEdge[72, 210] -> 
             RGBColor[
              0.7375908294326277, 0.7950272637146949, 0.9744542279420862], 
             UndirectedEdge[37, 41] -> 
             RGBColor[
              0.8330203895518973, 0.866931939933026, 0.800810353282417], 
             UndirectedEdge[52, 88] -> 
             RGBColor[
              0.8006883354003806, 0.8443330587121025, 0.9807396035553593], 
             UndirectedEdge[157, 285] -> 
             RGBColor[
              0.523298296633385, 0.6238761573834188, 0.9556151052972532], 
             UndirectedEdge[135, 265] -> 
             RGBColor[
              0.6092553042663369, 0.6936599284989142, 0.962381955809013], 
             UndirectedEdge[17, 42] -> 
             RGBColor[
              0.5290671047216267, 0.6193739436904344, 0.9588480253947487], 
             UndirectedEdge[242, 250] -> 
             RGBColor[
              0.7224488162971432, 0.7810742874803182, 0.9493630828614787], 
             UndirectedEdge[81, 202] -> 
             RGBColor[
              0.6355169151607345, 0.7138355531954849, 0.9652320269739257], 
             UndirectedEdge[229, 259] -> 
             RGBColor[
              0.5262937841646927, 0.6263080291065097, 0.9558509210485501], 
             UndirectedEdge[40, 81] -> 
             RGBColor[
              0.7230877538680802, 0.7836009160829982, 0.9730342877324728], 
             UndirectedEdge[100, 119] -> 
             RGBColor[
              0.799753142911379, 0.8427527238881861, 0.9204367030052352], 
             UndirectedEdge[81, 269] -> 
             RGBColor[
              0.6949833379428211, 0.7616455327607136, 0.9702331022037421], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.6643488823023378, 0.7377136631838818, 0.9671797459607633], 
             UndirectedEdge[180, 233] -> 
             RGBColor[
              0.4710656258914946, 0.5814713222201504, 0.9515031581218742], 
             UndirectedEdge[33, 184] -> 
             RGBColor[
              0.7400725864222821, 0.7949333311985058, 0.9387150214370873], 
             UndirectedEdge[103, 168] -> 
             RGBColor[
              0.6240540279251461, 0.7035425350400214, 0.9650043958638412], 
             UndirectedEdge[49, 238] -> 
             RGBColor[
              0.8215675454809022, 0.8581910971608897, 0.8161848962334224], 
             UndirectedEdge[97, 120] -> 
             RGBColor[
              0.5651167192533068, 0.6578262367647415, 0.9589072047118228], 
             UndirectedEdge[117, 212] -> 
             RGBColor[
              0.6645330106509618, 0.7355333642967494, 0.9689191355631663], 
             UndirectedEdge[270, 278] -> 
             RGBColor[
              0.8630511358666817, 0.8936375651138313, 0.9867997818654501], 
             UndirectedEdge[26, 165] -> 
             RGBColor[
              0.6118742704221443, 0.6957861232072795, 0.9625881304183872], 
             UndirectedEdge[65, 70] -> 
             RGBColor[
              0.8994370643877778, 0.9195738807240326, 0.8621463487792341], 
             UndirectedEdge[56, 223] -> 
             RGBColor[
              0.8409808924478721, 0.873151501842817, 0.8016643772493386], 
             UndirectedEdge[207, 212] -> 
             RGBColor[
              0.5359110242924084, 0.63411573789392, 0.9566080254205153], 
             UndirectedEdge[171, 184] -> 
             RGBColor[
              0.6244759515164449, 0.7044284534363648, 0.9646660981182101], 
             UndirectedEdge[32, 205] -> 
             RGBColor[
              0.9406502323718966, 0.9521753919399212, 0.8602171458687693], 
             UndirectedEdge[23, 31] -> 
             RGBColor[
              0.7044262934312362, 0.7671502869799154, 0.9669202836553519], 
             UndirectedEdge[235, 274] -> 
             RGBColor[
              0.6010828357043132, 0.6843643753216347, 0.9632896328427942], 
             UndirectedEdge[178, 199] -> 
             RGBColor[
              0.7768574782279598, 0.8261847232135109, 0.9782400379452194], 
             UndirectedEdge[117, 158] -> 
             RGBColor[
              0.9261834368387147, 0.9392969196670589, 0.7515222311555756], 
             UndirectedEdge[112, 190] -> 
             RGBColor[
              0.5333546480062854, 0.6320403564614059, 0.9564067781149568], 
             UndirectedEdge[64, 213] -> 
             RGBColor[
              0.6096297046644434, 0.6938345844198088, 0.9624998325413991], 
             UndirectedEdge[127, 205] -> 
             RGBColor[
              0.8657981323900745, 0.8931648892601067, 0.8528986862186428], 
             UndirectedEdge[121, 263] -> 
             RGBColor[
              0.6209605254753846, 0.7031627543906255, 0.9633034337002273], 
             UndirectedEdge[14, 213] -> 
             RGBColor[
              0.50327328504752, 0.6072053869388501, 0.9541529319752282], 
             UndirectedEdge[109, 111] -> 
             RGBColor[
              0.5966049237573788, 0.6820759728233408, 0.962284328458282], 
             UndirectedEdge[55, 108] -> 
             RGBColor[
              0.4840982545342549, 0.5889639863682858, 0.9533823057397827], 
             UndirectedEdge[40, 162] -> 
             RGBColor[
              0.7708802480092939, 0.8209367757425229, 0.9777977969022184], 
             UndirectedEdge[15, 225] -> 
             RGBColor[
              0.9277251414036514, 0.7836296131107297, 0.5866827845133339], 
             UndirectedEdge[31, 59] -> 
             RGBColor[
              0.7435150776898174, 0.798884322970695, 0.9699974959391221], 
             UndirectedEdge[210, 227] -> 
             RGBColor[
              0.6642261847128585, 0.7376178108944443, 0.9671675166117182], 
             UndirectedEdge[52, 93] -> 
             RGBColor[
              0.8254488415519018, 0.8640764142112907, 0.9831012827360561], 
             UndirectedEdge[32, 293] -> 
             RGBColor[
              0.712497806627604, 0.7742764637863073, 0.9729217083497399], 
             UndirectedEdge[99, 209] -> 
             RGBColor[
              0.835107800212391, 0.8719991060533249, 0.9839639426638795], 
             UndirectedEdge[201, 299] -> 
             RGBColor[
              0.47992298242112996`, 0.5880070706771101, 0.9523814346566745], 
             UndirectedEdge[127, 148] -> 
             RGBColor[
              0.5983611386451582, 0.6833729790539661, 0.9625106236024902], 
             UndirectedEdge[24, 226] -> 
             RGBColor[
              0.677487030756765, 0.7476450516244086, 0.9687163833225352], 
             UndirectedEdge[144, 264] -> 
             RGBColor[
              0.751087879971992, 0.8043198012205713, 0.9514843975347949], 
             UndirectedEdge[148, 217] -> 
             RGBColor[
              0.5587913013931746, 0.6524607214508149, 0.9585666720263657], 
             UndirectedEdge[230, 288] -> 
             RGBColor[
              0.3948535941944764, 0.5164240701977321, 0.9463806997601162], 
             UndirectedEdge[1, 83] -> 
             RGBColor[
              0.7978638811297735, 0.8424644853019143, 0.9803684169656774], 
             UndirectedEdge[15, 214] -> 
             RGBColor[
              0.9307992401649761, 0.7859222709335509, 0.5814791371637762], 
             UndirectedEdge[173, 249] -> 
             RGBColor[
              0.7658089687405313, 0.8145116998203177, 0.8891867331660056], 
             UndirectedEdge[114, 204] -> 
             RGBColor[
              0.8278753238336871, 0.8660507915438342, 0.9657031251324308], 
             UndirectedEdge[77, 95] -> 
             RGBColor[
              0.9109162217390545, 0.9318038853253172, 0.9913651964856237], 
             UndirectedEdge[52, 295] -> 
             RGBColor[
              0.6068776786075522, 0.6896087550308352, 0.9635635690880322], 
             UndirectedEdge[7, 103] -> 
             RGBColor[
              0.8021613382233517, 0.8453966388945824, 0.9809095432045378], 
             UndirectedEdge[29, 99] -> 
             RGBColor[
              0.5960976874260967, 0.6814324142408805, 0.9623853949660995], 
             UndirectedEdge[28, 144] -> 
             RGBColor[
              0.7589624479443451, 0.8101926411209306, 0.9381548079738566], 
             UndirectedEdge[75, 185] -> 
             RGBColor[
              0.6047067260493233, 0.6888949255769071, 0.962756986601871], 
             UndirectedEdge[227, 291] -> 
             RGBColor[
              0.6786929644000232, 0.7489193691376552, 0.9686094300111922], 
             UndirectedEdge[76, 192] -> 
             RGBColor[
              0.6316552893199469, 0.7076085468157961, 0.9666535524681367], 
             UndirectedEdge[59, 72] -> 
             RGBColor[
              0.688361435340547, 0.7550745262228937, 0.9705692045652357], 
             UndirectedEdge[104, 254] -> 
             RGBColor[
              0.7178455921904746, 0.7765667659236823, 0.929252590510929], 
             UndirectedEdge[32, 237] -> 
             RGBColor[
              0.7652363382453422, 0.8170631838166058, 0.977093166578866], 
             UndirectedEdge[25, 232] -> 
             RGBColor[
              0.4951456626218199, 0.5996257191192091, 0.9537842312683606], 
             UndirectedEdge[9, 141] -> 
             RGBColor[
              0.6322621414437022, 0.7106191032023064, 0.9653682995718441], 
             UndirectedEdge[22, 48] -> 
             RGBColor[
              0.48139015444862154`, 0.5898532396175371, 0.9523159428298855], 
             UndirectedEdge[25, 160] -> 
             RGBColor[
              0.7846244856590763, 0.8309813979098093, 0.9389723072695618], 
             UndirectedEdge[72, 106] -> 
             RGBColor[
              0.8944710814980674, 0.9181409852962632, 0.9707280905630412], 
             UndirectedEdge[4, 186] -> 
             RGBColor[
              0.7797421365231834, 0.8282163348159526, 0.9785864405908409], 
             UndirectedEdge[78, 182] -> 
             RGBColor[
              0.6350117263364513, 0.7128335886576487, 0.9655968937149215], 
             UndirectedEdge[106, 211] -> 
             RGBColor[
              0.6152517129477443, 0.6861214073452458, 0.9482558139328002], 
             UndirectedEdge[180, 245] -> 
             RGBColor[
              0.5241345511032389, 0.6245550664348807, 0.9556809383124211], 
             UndirectedEdge[136, 280] -> 
             RGBColor[
              0.7368763671061384, 0.7939387843211971, 0.974989691922682], 
             UndirectedEdge[82, 140] -> 
             RGBColor[
              0.47616104923447566`, 0.5856080164361881, 0.9519042885125844], 
             UndirectedEdge[50, 219] -> 
             RGBColor[
              0.7683602832404035, 0.7756700042115382, 0.6349329936703938], 
             UndirectedEdge[251, 278] -> 
             RGBColor[
              0.8787185577853738, 0.9061303420709577, 0.9882941545545276], 
             UndirectedEdge[80, 150] -> 
             RGBColor[
              0.8210539560265472, 0.8605221725118867, 0.9826953310578821], 
             UndirectedEdge[26, 183] -> 
             RGBColor[
              0.6050800901392243, 0.6902703015792713, 0.9620532676586133], 
             UndirectedEdge[243, 256] -> 
             RGBColor[
              0.7144069208975382, 0.7747354262855006, 0.9538236899155772], 
             UndirectedEdge[184, 248] -> 
             RGBColor[
              0.638078274504442, 0.7150546915360718, 0.9660218505527183], 
             UndirectedEdge[4, 255] -> 
             RGBColor[
              0.8759671208438715, 0.9039364209395699, 0.9880317200428104], 
             UndirectedEdge[37, 280] -> 
             RGBColor[
              0.9492594066988402, 0.9584186355980466, 0.812215549758752], 
             UndirectedEdge[188, 260] -> 
             RGBColor[
              0.5062538863875871, 0.6091742118220855, 0.954512177853466], 
             UndirectedEdge[70, 266] -> 
             RGBColor[
              0.656970111465683, 0.7299129398711621, 0.967836577327309], 
             UndirectedEdge[103, 127] -> 
             RGBColor[
              0.7590214216394087, 0.81167257045195, 0.9766158199167014], 
             UndirectedEdge[37, 268] -> 
             RGBColor[
              0.8156878326074335, 0.8533088866742338, 0.7991393676019156], 
             UndirectedEdge[186, 196] -> 
             RGBColor[
              0.8443794547525277, 0.8750989857041915, 0.7453360598237], 
             UndirectedEdge[139, 274] -> 
             RGBColor[
              0.6504531812337265, 0.7233519042412395, 0.9680992072241141], 
             UndirectedEdge[15, 255] -> 
             RGBColor[
              0.8889306900685523, 0.7534624387402988, 0.6095564644906681], 
             UndirectedEdge[118, 195] -> 
             RGBColor[
              0.8257809175548425, 0.8646174949192923, 0.9757635940850208], 
             UndirectedEdge[125, 128] -> 
             RGBColor[
              0.911240013815985, 0.931283833354148, 0.9644141846200738], 
             UndirectedEdge[61, 177] -> 
             RGBColor[
              0.763455590366098, 0.8143068091601039, 0.9510188875355714], 
             UndirectedEdge[117, 276] -> 
             RGBColor[
              0.6784125780833068, 0.7468014224057143, 0.9700117859539713], 
             UndirectedEdge[7, 154] -> 
             RGBColor[
              0.888807870960667, 0.9136825642240081, 0.9721734906008181], 
             UndirectedEdge[59, 198] -> 
             RGBColor[
              0.6235673166742437, 0.7043604334940212, 0.9641367231757574], 
             UndirectedEdge[83, 197] -> 
             RGBColor[
              0.6791778394963484, 0.749231779085872, 0.9687031409414125], 
             UndirectedEdge[243, 283] -> 
             RGBColor[
              0.9117643013176682, 0.9319077299930961, 0.9716009329019084], 
             UndirectedEdge[95, 225] -> 
             RGBColor[
              0.9478504842232163, 0.9604877955994917, 0.9683140900350768], 
             UndirectedEdge[21, 74] -> 
             RGBColor[
              0.618853463148817, 0.7009132413332733, 0.9635060102851851], 
             UndirectedEdge[62, 225] -> 
             RGBColor[
              0.9123468058687436, 0.9321781262013111, 0.9649277174991194], 
             UndirectedEdge[236, 267] -> 
             RGBColor[
              0.6570201480578886, 0.7290519788138157, 0.9685120791808672], 
             UndirectedEdge[123, 300] -> 
             RGBColor[
              0.5958646121090683, 0.6824706318693912, 0.9615452983421202], 
             UndirectedEdge[111, 218] -> 
             RGBColor[
              0.6812824722491421, 0.7508210213690418, 0.9689504552596342], 
             UndirectedEdge[61, 161] -> 
             RGBColor[
              0.7475263188958969, 0.8013747089750927, 0.9497648769345932], 
             UndirectedEdge[58, 180] -> 
             RGBColor[
              0.5754823452633917, 0.6657782455331829, 0.9600399673106161], 
             UndirectedEdge[188, 236] -> 
             RGBColor[
              0.4320208967999595, 0.5486165196316557, 0.9487489674163823], 
             UndirectedEdge[41, 268] -> 
             RGBColor[
              0.6542911046475701, 0.7297737227965706, 0.9662338422931813], 
             UndirectedEdge[65, 138] -> 
             RGBColor[
              0.804163491256189, 0.8447105206700007, 0.852947726993252], 
             UndirectedEdge[241, 291] -> 
             RGBColor[
              0.5269273322521743, 0.6244194140291561, 0.9567509756440944], 
             UndirectedEdge[270, 295] -> 
             RGBColor[
              0.6451879613184485, 0.719734436662606, 0.9673295967826765], 
             UndirectedEdge[127, 212] -> 
             RGBColor[
              0.6032851144914575, 0.6873704844685758, 0.9628982570182287], 
             UndirectedEdge[105, 274] -> 
             RGBColor[
              0.4464228613163358, 0.5608070393271591, 0.9497450455439624], 
             UndirectedEdge[128, 142] -> 
             RGBColor[
              0.7330481917243477, 0.7911746117591528, 0.9742927169540989], 
             UndirectedEdge[38, 57] -> 
             RGBColor[
              0.9175289228511725, 0.9362888988274374, 0.964683272629036], 
             UndirectedEdge[135, 255] -> 
             RGBColor[
              0.7462688628700662, 0.8016817584190938, 0.9755936066852176], 
             UndirectedEdge[46, 196] -> 
             RGBColor[
              0.9161158867442405, 0.9312925649247288, 0.752445599293343], 
             UndirectedEdge[138, 210] -> 
             RGBColor[
              0.6286170522366261, 0.7093647653469208, 0.9639156886743634], 
             UndirectedEdge[72, 109] -> 
             RGBColor[
              0.6485005972507563, 0.7227137021513094, 0.9674312133757463], 
             UndirectedEdge[277, 282] -> 
             RGBColor[
              0.6862159256407105, 0.753168260940442, 0.9705895740423378], 
             UndirectedEdge[62, 117] -> 
             RGBColor[
              0.85914867319053, 0.8905258473053953, 0.9864275614916292], 
             UndirectedEdge[33, 126] -> 
             RGBColor[
              0.9480350784348034, 0.9603303634469808, 0.9577702411991067], 
             UndirectedEdge[217, 278] -> 
             RGBColor[
              0.7695429212226464, 0.820390839536072, 0.9775321401697121], 
             UndirectedEdge[228, 264] -> 
             RGBColor[
              0.7635720066332895, 0.8144549776477097, 0.9524671937164351], 
             UndirectedEdge[121, 239] -> 
             RGBColor[
              0.6966082393295763, 0.7625978363243388, 0.9706118477122248], 
             UndirectedEdge[56, 84] -> 
             RGBColor[
              0.6978645549472859, 0.7638963613826617, 0.9705202749882434], 
             UndirectedEdge[45, 120] -> 
             RGBColor[
              0.5598999296746725, 0.6535910119711139, 0.9584965199264628], 
             UndirectedEdge[67, 234] -> 
             RGBColor[
              0.6723448285980815, 0.7403388237507735, 0.9704031060119187], 
             UndirectedEdge[153, 192] -> 
             RGBColor[
              0.5491946834970253, 0.6428972075620036, 0.9585122670438212], 
             UndirectedEdge[77, 127] -> 
             RGBColor[
              0.8140414662345026, 0.8552331149207374, 0.9819461962918826], 
             UndirectedEdge[36, 152] -> 
             RGBColor[
              0.6019227577719646, 0.686253958932608, 0.962798188249949], 
             UndirectedEdge[22, 122] -> 
             RGBColor[
              0.5844114243437866, 0.6724643665875351, 0.9611277601201432], 
             UndirectedEdge[68, 218] -> 
             RGBColor[
              0.5505356802932706, 0.6459886924686646, 0.9577593319127833], 
             UndirectedEdge[56, 148] -> 
             RGBColor[
              0.5738680651673556, 0.6642388038988537, 0.960069382939008], 
             UndirectedEdge[7, 130] -> 
             RGBColor[
              0.7884707924993449, 0.8347014805229871, 0.9795449975521926], 
             UndirectedEdge[58, 296] -> 
             RGBColor[
              0.5993720934254327, 0.685173019312018, 0.9619206557969631], 
             UndirectedEdge[104, 116] -> 
             RGBColor[
              0.8726900662782927, 0.9005135453308579, 0.9426700461096017], 
             UndirectedEdge[252, 279] -> 
             RGBColor[
              0.8381211844187627, 0.871339832620553, 0.8352079471180753], 
             UndirectedEdge[64, 173] -> 
             RGBColor[
              0.8202218319237355, 0.8585572142351608, 0.8935587156382463], 
             UndirectedEdge[109, 155] -> 
             RGBColor[
              0.6999080259900993, 0.28162361861405294`, 0.42648947540190396`],
              UndirectedEdge[151, 258] -> 
             RGBColor[
              0.7514949906374575, 0.8057928653502315, 0.9758656556129235], 
             UndirectedEdge[167, 216] -> 
             RGBColor[
              0.596066059002075, 0.6786970746824876, 0.9635295101313994], 
             UndirectedEdge[12, 258] -> 
             RGBColor[
              0.7573513457898995, 0.8104594990154763, 0.9764250533433395], 
             UndirectedEdge[151, 239] -> 
             RGBColor[
              0.7955806198682908, 0.8402328939685504, 0.9802596991310244], 
             UndirectedEdge[136, 226] -> 
             RGBColor[
              0.6519770657997848, 0.726934912861507, 0.966708145435041], 
             UndirectedEdge[59, 210] -> 
             RGBColor[
              0.59403714824196, 0.6812912414771286, 0.9611934319615412], 
             UndirectedEdge[191, 205] -> 
             RGBColor[
              0.9450231197728822, 0.9556622136546006, 0.860634235772798], 
             UndirectedEdge[212, 276] -> 
             RGBColor[
              0.4839200965343135, 0.591907160575294, 0.9525151091383544], 
             UndirectedEdge[218, 292] -> 
             RGBColor[
              0.6319258758694135, 0.712064919823904, 0.9641666662506472], 
             UndirectedEdge[144, 245] -> 
             RGBColor[
              0.5541422575333593, 0.6489166743466217, 0.9580432548844506], 
             UndirectedEdge[1, 277] -> 
             RGBColor[
              0.8650192758868489, 0.8952069065421749, 0.986987504817553], 
             UndirectedEdge[64, 239] -> 
             RGBColor[
              0.7111780207516922, 0.7742969420551516, 0.9718472368382152], 
             UndirectedEdge[128, 256] -> 
             RGBColor[
              0.6637600679708467, 0.7349233915016569, 0.9688381020414631], 
             UndirectedEdge[7, 81] -> 
             RGBColor[
              0.7699481505712127, 0.8202314518714375, 0.9776988337087266], 
             UndirectedEdge[32, 145] -> 
             RGBColor[
              0.7514025064663251, 0.8058610517521361, 0.9759844288336552], 
             UndirectedEdge[84, 247] -> 
             RGBColor[
              0.7863747326217849, 0.833401507686655, 0.9792465237313519], 
             UndirectedEdge[215, 259] -> 
             RGBColor[
              0.7580657504819681, 0.810584317076058, 0.9681149104325222], 
             UndirectedEdge[187, 233] -> 
             RGBColor[
              0.6565311894078044, 0.7291075395746818, 0.9682081573832557], 
             UndirectedEdge[37, 152] -> 
             RGBColor[
              0.8658162237114864, 0.8925522948360683, 0.8040791355369497], 
             UndirectedEdge[257, 300] -> 
             RGBColor[
              0.7830505548299342, 0.8311150952497351, 0.978832814079375], 
             UndirectedEdge[10, 244] -> 
             RGBColor[
              0.5767127295582444, 0.6652053995713656, 0.9609118036215151], 
             UndirectedEdge[98, 157] -> 
             RGBColor[
              0.7628977996112702, 0.8123513339942563, 0.8974459430473121], 
             UndirectedEdge[13, 271] -> 
             RGBColor[
              0.608290665233013, 0.6923390417799176, 0.9626736780208017], 
             UndirectedEdge[202, 203] -> 
             RGBColor[
              0.7743339698025853, 0.8199375107262075, 0.8124030768804542], 
             UndirectedEdge[166, 195] -> 
             RGBColor[
              0.9164878434118147, 0.9360377049445956, 0.9846559996488182], 
             UndirectedEdge[260, 287] -> 
             RGBColor[
              0.7761124540150313, 0.8247217921700207, 0.9557587657598787], 
             UndirectedEdge[212, 214] -> 
             RGBColor[
              0.7208052420905002, 0.7794783010154864, 0.9422156442210988], 
             UndirectedEdge[25, 113] -> 
             RGBColor[
              0.7859847110134028, 0.8319958517519013, 0.9366698005482774], 
             UndirectedEdge[244, 280] -> 
             RGBColor[
              0.6651668875770977, 0.7349863521127722, 0.9695476650042332], 
             UndirectedEdge[58, 134] -> 
             RGBColor[
              0.7493055274578818, 0.8041311440457173, 0.9756345058482461], 
             UndirectedEdge[64, 263] -> 
             RGBColor[
              0.6355303068975005, 0.7148618601214384, 0.9645388228262175], 
             UndirectedEdge[182, 261] -> 
             RGBColor[
              0.6286841138142835, 0.7076965477564572, 0.9650987608783681], 
             UndirectedEdge[150, 277] -> 
             RGBColor[
              0.8142988338296862, 0.8551358214350171, 0.9820510214723767], 
             UndirectedEdge[86, 202] -> 
             RGBColor[
              0.498143028005436, 0.6031558713199552, 0.9537171579135928], 
             UndirectedEdge[257, 267] -> 
             RGBColor[
              0.8872257204721943, 0.9129137226766488, 0.9891055753260304], 
             UndirectedEdge[134, 245] -> 
             RGBColor[
              0.6979577332977289, 0.7629079649474151, 0.9712754768500509], 
             UndirectedEdge[187, 297] -> 
             RGBColor[
              0.7791816429274929, 0.827658794585481, 0.978562334787916], 
             UndirectedEdge[75, 292] -> 
             RGBColor[
              0.6708832051060734, 0.7426199724915847, 0.9679666414456485], 
             UndirectedEdge[54, 174] -> 
             RGBColor[
              0.8233407968893554, 0.8622195549230532, 0.9506306533147106], 
             UndirectedEdge[44, 108] -> 
             RGBColor[
              0.6619810163477726, 0.7356531012416119, 0.9670878418028506], 
             UndirectedEdge[94, 141] -> 
             RGBColor[
              0.7195106671926352, 0.7808064687852748, 0.9726777571624401], 
             UndirectedEdge[185, 262] -> 
             RGBColor[
              0.5074244312486862, 0.6109890383546339, 0.9543654564662849], 
             UndirectedEdge[40, 202] -> 
             RGBColor[
              0.6415179009352219, 0.7185235688916956, 0.9658301491535262], 
             UndirectedEdge[110, 191] -> 
             RGBColor[
              0.9445567342862117, 0.9544788092843353, 0.7963615045668889], 
             UndirectedEdge[92, 125] -> 
             RGBColor[
              0.589962651454033, 0.6581900470588644, 0.9390723804302374], 
             UndirectedEdge[72, 226] -> 
             RGBColor[
              0.7831091049022136, 0.830586486463242, 0.9789910642484257], 
             UndirectedEdge[130, 162] -> 
             RGBColor[
              0.7834019041629388, 0.8307187886978618, 0.979045838566084], 
             UndirectedEdge[29, 43] -> 
             RGBColor[
              0.6401201476050349, 0.7158919307411327, 0.9667548754188349], 
             UndirectedEdge[152, 268] -> 
             RGBColor[
              0.6870869388071592, 0.7553940776996129, 0.9695026245477139], 
             UndirectedEdge[4, 62] -> 
             RGBColor[
              0.8616866204913318, 0.8925495375923105, 0.986669633170832], 
             UndirectedEdge[18, 184] -> 
             RGBColor[
              0.4730231719631651, 0.5827840769055392, 0.9517336526388881], 
             UndirectedEdge[95, 159] -> 
             RGBColor[
              0.7685811530330362, 0.8194887347862887, 0.9777036312480627], 
             UndirectedEdge[154, 255] -> 
             RGBColor[
              0.9213195318793428, 0.9396064801350341, 0.9752744818427439], 
             UndirectedEdge[140, 269] -> 
             RGBColor[
              0.5653992025975209, 0.6575880280882176, 0.9592491034311763], 
             UndirectedEdge[10, 161] -> 
             RGBColor[
              0.6284121300418122, 0.7079127481668874, 0.9647785638181696], 
             UndirectedEdge[216, 293] -> 
             RGBColor[
              0.6714885400376822, 0.7417042397673057, 0.9689763860528589], 
             UndirectedEdge[188, 294] -> 
             RGBColor[
              0.5880202683772091, 0.6738370320913956, 0.9621242882272228], 
             UndirectedEdge[32, 282] -> 
             RGBColor[
              0.7020125718352301, 0.7657640778274137, 0.9720962722582036], 
             UndirectedEdge[251, 282] -> 
             RGBColor[
              0.6967662711641518, 0.7615808200793339, 0.9715958754167683], 
             UndirectedEdge[181, 299] -> 
             RGBColor[
              0.6840240935819659, 0.7515136228198485, 0.9702733941241468], 
             UndirectedEdge[60, 159] -> 
             RGBColor[
              0.548338622285877, 0.6442050218019272, 0.9575863714583526], 
             UndirectedEdge[137, 217] -> 
             RGBColor[
              0.7762846990266645, 0.8257665501563125, 0.9781751769551155], 
             UndirectedEdge[20, 152] -> 
             RGBColor[
              0.5942632481316689, 0.6799811337110253, 0.9622102594086392], 
             UndirectedEdge[62, 196] -> 
             RGBColor[
              0.9263239387206762, 0.9394321884805494, 0.753419252403691], 
             UndirectedEdge[251, 289] -> 
             RGBColor[
              0.9216488912401171, 0.9395403078615463, 0.963906385147207], 
             UndirectedEdge[104, 283] -> 
             RGBColor[
              0.9250064759889326, 0.9417524855552122, 0.9477865453793357], 
             UndirectedEdge[45, 294] -> 
             RGBColor[
              0.6354829148840915, 0.7132338721754046, 0.9656218506551534], 
             UndirectedEdge[15, 158] -> 
             RGBColor[
              0.9416849533641973, 0.7908466277547029, 0.373289047282636], 
             UndirectedEdge[150, 237] -> 
             RGBColor[
              0.7090979184249575, 0.7726719503081433, 0.9716399116779476], 
             UndirectedEdge[169, 228] -> 
             RGBColor[
              0.7245786961018619, 0.6153813775861766, 0.5925987852630815], 
             UndirectedEdge[159, 251] -> 
             RGBColor[
              0.741312196839228, 0.7977452093134434, 0.9751026938630126], 
             UndirectedEdge[203, 293] -> 
             RGBColor[
              0.7667412953939561, 0.813773435595198, 0.811805353738124], 
             UndirectedEdge[145, 282] -> 
             RGBColor[
              0.5671811784569647, 0.6595022577490983, 0.9590697265026981], 
             UndirectedEdge[195, 234] -> 
             RGBColor[
              0.6796202344004022, 0.7459311945869751, 0.9638564176263769], 
             UndirectedEdge[156, 270] -> 
             RGBColor[
              0.6582420560764202, 0.7305318687407831, 0.9683021322422318], 
             UndirectedEdge[25, 134] -> 
             RGBColor[
              0.7071773853454137, 0.7703928938203173, 0.972001281631943], 
             UndirectedEdge[158, 276] -> 
             RGBColor[
              0.7455705227220665, 0.7956707159456035, 0.7351182047307636], 
             UndirectedEdge[268, 280] -> 
             RGBColor[
              0.7705301217945131, 0.8212604184615913, 0.9776390387695163], 
             UndirectedEdge[8, 186] -> 
             RGBColor[
              0.5607802433350422, 0.6527565064677128, 0.9593247815914523], 
             UndirectedEdge[32, 256] -> 
             RGBColor[
              0.6785760364766861, 0.7467372426194616, 0.9702512623439212], 
             UndirectedEdge[60, 168] -> 
             RGBColor[
              0.4781945309240766, 0.5872588884791123, 0.9520643716400787], 
             UndirectedEdge[162, 216] -> 
             RGBColor[
              0.8084435615203835, 0.8502815217491426, 0.9815417569438811], 
             UndirectedEdge[106, 115] -> 
             RGBColor[
              0.8850227193770005, 0.9106634182238585, 0.9698119569504912], 
             UndirectedEdge[77, 276] -> 
             RGBColor[
              0.6946764482773586, 0.7597697910274556, 0.9715630484120084], 
             UndirectedEdge[80, 281] -> 
             RGBColor[
              0.6453938053378329, 0.7190961955948438, 0.967718607885607], 
             UndirectedEdge[130, 293] -> 
             RGBColor[
              0.6464468826802374, 0.722141506716025, 0.9664804676750617], 
             UndirectedEdge[39, 118] -> 
             RGBColor[
              0.5545503406803135, 0.6468346282453805, 0.959150382204766], 
             UndirectedEdge[58, 245] -> 
             RGBColor[
              0.6212535011154141, 0.7029373318209278, 0.9636432403645558], 
             UndirectedEdge[54, 143] -> 
             RGBColor[
              0.7076287224327826, 0.7685195178306282, 0.941250591049886], 
             UndirectedEdge[239, 258] -> 
             RGBColor[
              0.7274708147562019, 0.7870249965612954, 0.973471150279768], 
             UndirectedEdge[184, 222] -> 
             RGBColor[
              0.6262349171906557, 0.7058025707896927, 0.9648414153781467], 
             UndirectedEdge[143, 298] -> 
             RGBColor[
              0.4682814356445526, 0.5789495002200646, 0.9513562271902346], 
             UndirectedEdge[203, 269] -> 
             RGBColor[
              0.833800392584672, 0.8677474902914362, 0.8174041521102706], 
             UndirectedEdge[107, 139] -> 
             RGBColor[
              0.8450746886540152, 0.879317076436317, 0.9850816050902739], 
             UndirectedEdge[108, 283] -> 
             RGBColor[
              0.747116573696556, 0.8025306090356443, 0.9754754469967827], 
             UndirectedEdge[173, 186] -> 
             RGBColor[
              0.842513476287965, 0.8759716162352689, 0.8957805384212121], 
             UndirectedEdge[164, 296] -> 
             RGBColor[
              0.4965027017112915, 0.6021222862978683, 0.9535056579094876], 
             UndirectedEdge[11, 116] -> 
             RGBColor[
              0.6472805698609214, 0.7227131215672997, 0.9666180312075203], 
             UndirectedEdge[43, 229] -> 
             RGBColor[
              0.6552988645344909, 0.7282575499945226, 0.96793795918976], 
             UndirectedEdge[128, 149] -> 
             RGBColor[
              0.8605554967908081, 0.8916476102570478, 0.98656174558251], 
             UndirectedEdge[221, 232] -> 
             RGBColor[
              0.6923166663877325, 0.7379144087732861, 0.6670377036959843], 
             UndirectedEdge[8, 85] -> 
             RGBColor[
              0.4036423240767552, 0.5240364262873541, 0.9469407098566462], 
             UndirectedEdge[20, 41] -> 
             RGBColor[
              0.5614674139720797, 0.6543607788079829, 0.9589414771541067], 
             UndirectedEdge[108, 252] -> 
             RGBColor[
              0.811820306993904, 0.8505826202200657, 0.832730624043512], 
             UndirectedEdge[65, 241] -> 
             RGBColor[
              0.6880069915845726, 0.748463611109025, 0.8443411005635091], 
             UndirectedEdge[231, 245] -> 
             RGBColor[
              0.5006383920225516, 0.6048839155911327, 0.9539958864227136], 
             UndirectedEdge[80, 167] -> 
             RGBColor[
              0.6280338015943381, 0.7040598328913871, 0.96661244379792], 
             UndirectedEdge[17, 201] -> 
             RGBColor[
              0.6027072548788553, 0.6856382702179897, 0.9634494716550484], 
             UndirectedEdge[57, 223] -> 
             RGBColor[
              0.980333121283399, 0.9824089448042068, 0.7879273370275311], 
             UndirectedEdge[162, 202] -> 
             RGBColor[
              0.6833094093019482, 0.7511714128550095, 0.9699955361436713], 
             UndirectedEdge[3, 59] -> 
             RGBColor[
              0.5985536138305425, 0.6848195387213392, 0.9616435910426405], 
             UndirectedEdge[180, 187] -> 
             RGBColor[
              0.6638289587675263, 0.7350321975016672, 0.968782664519863], 
             UndirectedEdge[193, 215] -> 
             RGBColor[
              0.6989024468977434, 0.7625215419664801, 0.963466017782855], 
             UndirectedEdge[43, 78] -> 
             RGBColor[
              0.6714014203794237, 0.7413303302413131, 0.9692056113714788], 
             UndirectedEdge[56, 251] -> 
             RGBColor[
              0.7816424257138874, 0.8297949362474448, 0.9787508774341169], 
             UndirectedEdge[261, 284] -> 
             RGBColor[
              0.7269637440380309, 0.7851150555147697, 0.9597858175978996], 
             UndirectedEdge[36, 41] -> 
             RGBColor[
              0.5691269236123755, 0.6606336040295655, 0.9595294059954165], 
             UndirectedEdge[95, 168] -> 
             RGBColor[
              0.6984370616712358, 0.7625426014634739, 0.9721816314297889], 
             UndirectedEdge[194, 280] -> 
             RGBColor[
              0.7908457326298386, 0.837213856091974, 0.9796073473836351], 
             UndirectedEdge[99, 182] -> 
             RGBColor[
              0.7480883861600033, 0.8031316000412914, 0.9755261171151397], 
             UndirectedEdge[94, 97] -> 
             RGBColor[
              0.6056480252286722, 0.6900864587487605, 0.9625389116310288], 
             UndirectedEdge[79, 240] -> 
             RGBColor[
              0.5954198874763823, 0.6824277138704057, 0.9612927811185061], 
             UndirectedEdge[83, 198] -> 
             RGBColor[
              0.7113283485700044, 0.7744143792893508, 0.9718622201102511], 
             UndirectedEdge[69, 213] -> 
             RGBColor[
              0.601450493383181, 0.687323631421245, 0.9617675325063266], 
             UndirectedEdge[214, 286] -> 
             RGBColor[
              0.9822051536026857, 0.9827060308256761, 0.6975517633753535], 
             UndirectedEdge[277, 293] -> 
             RGBColor[
              0.6967011604330844, 0.7616806468993356, 0.9714150101338741], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.8746501897160126, 0.7420755553930394, 0.6081943776186897], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.6522065110734243, 0.7258341415200327, 0.9676061681431498], 
             UndirectedEdge[43, 199] -> 
             RGBColor[
              0.860028267982526, 0.8912272123165683, 0.9865114580281134], 
             UndirectedEdge[192, 222] -> 
             RGBColor[
              0.5783493816904123, 0.6656730793745907, 0.9614181348935931], 
             UndirectedEdge[130, 202] -> 
             RGBColor[
              0.6540395570888667, 0.7283055818470344, 0.9670781908173918], 
             UndirectedEdge[4, 265] -> 
             RGBColor[
              0.7389535622401422, 0.7959145910193903, 0.9748200691666059], 
             UndirectedEdge[121, 173] -> 
             RGBColor[
              0.8056520505016197, 0.846858108504348, 0.8923233265122559], 
             UndirectedEdge[53, 107] -> 
             RGBColor[
              0.6993752496657273, 0.7641278484367222, 0.9713194640299185], 
             UndirectedEdge[172, 238] -> 
             RGBColor[
              0.9332746868719244, 0.9458766047847793, 0.8272076198557496], 
             UndirectedEdge[210, 211] -> 
             RGBColor[
              0.4583714608823045, 0.5630076857636774, 0.9519819513118453], 
             UndirectedEdge[180, 221] -> 
             RGBColor[
              0.7305252069168362, 0.7703286849618597, 0.6696602155219366], 
             UndirectedEdge[196, 212] -> 
             RGBColor[
              0.731708276181108, 0.7844397054719034, 0.7359108264752281], 
             UndirectedEdge[160, 176] -> 
             RGBColor[
              0.8221540830897737, 0.861127230079576, 0.9421471915278293], 
             UndirectedEdge[115, 193] -> 
             RGBColor[
              0.6325910823814744, 0.7099593402228386, 0.9660150934816794], 
             UndirectedEdge[21, 300] -> 
             RGBColor[
              0.6703324264192714, 0.7423880533246499, 0.9677761297189402], 
             UndirectedEdge[75, 235] -> 
             RGBColor[
              0.7427218193674356, 0.7989391972755193, 0.9749912278906746], 
             UndirectedEdge[77, 255] -> 
             RGBColor[
              0.8896930437371215, 0.914881099274396, 0.9893409108216447], 
             UndirectedEdge[62, 286] -> 
             RGBColor[
              0.9260561031537222, 0.9388593152851645, 0.724267003830267], 
             UndirectedEdge[46, 225] -> 
             RGBColor[
              0.902138753892308, 0.9240385026454905, 0.9639540643887714], 
             UndirectedEdge[37, 161] -> 
             RGBColor[
              0.762023998873586, 0.8097421689209365, 0.794914754033287], 
             UndirectedEdge[3, 162] -> 
             RGBColor[
              0.732485614943613, 0.7909425965815939, 0.973970978696477], 
             UndirectedEdge[107, 274] -> 
             RGBColor[
              0.6236993735211876, 0.7020325865562308, 0.9655438379688178], 
             UndirectedEdge[6, 147] -> 
             RGBColor[
              0.47883675719251034`, 0.5870448215926939, 0.9523181384807575], 
             UndirectedEdge[8, 135] -> 
             RGBColor[
              0.5154412356396123, 0.6167605158322842, 0.9552001833802073], 
             UndirectedEdge[186, 249] -> 
             RGBColor[
              0.6186783786973742, 0.7004977465159539, 0.9636791201892865], 
             UndirectedEdge[277, 281] -> 
             RGBColor[
              0.6386386831409719, 0.7137098445179743, 0.9670742983001016], 
             UndirectedEdge[256, 277] -> 
             RGBColor[
              0.6627793902821665, 0.7341414257324899, 0.9687445641280554], 
             UndirectedEdge[8, 249] -> 
             RGBColor[
              0.48407573578760843`, 0.5912965900527616, 0.9527309763362458], 
             UndirectedEdge[114, 254] -> 
             RGBColor[
              0.5759028322309188, 0.6656378372650302, 0.9603802647394943], 
             UndirectedEdge[223, 270] -> 
             RGBColor[
              0.9194123433177264, 0.9346201449725375, 0.8094293080324343], 
             UndirectedEdge[120, 294] -> 
             RGBColor[
              0.6789793612172698, 0.7485462468012558, 0.9690460502432341], 
             UndirectedEdge[23, 290] -> 
             RGBColor[
              0.47492963624474005`, 0.5846082998965978, 0.9518073471712181], 
             UndirectedEdge[7, 293] -> 
             RGBColor[
              0.680785623229725, 0.7489900295491254, 0.9698969719874498], 
             UndirectedEdge[95, 191] -> 
             RGBColor[
              0.9126294427683059, 0.9331699612698963, 0.9915286050368042], 
             UndirectedEdge[65, 194] -> 
             RGBColor[
              0.835974594873462, 0.8699965172068166, 0.8558210029085433], 
             UndirectedEdge[94, 188] -> 
             RGBColor[
              0.5529685891431555, 0.6464543938711238, 0.9586306644177383], 
             UndirectedEdge[24, 162] -> 
             RGBColor[
              0.7166713623081689, 0.7782561492443152, 0.9726219112931815], 
             UndirectedEdge[34, 84] -> 
             RGBColor[
              0.755125811856463, 0.808629290481782, 0.9762275419400805], 
             UndirectedEdge[130, 201] -> 
             RGBColor[
              0.59166248396247, 0.6770100112347415, 0.9623486321093555], 
             UndirectedEdge[74, 260] -> 
             RGBColor[
              0.5755990087328017, 0.6663362315859551, 0.9597324089375403], 
             UndirectedEdge[69, 85] -> 
             RGBColor[
              0.5077741113410291, 0.6093122277518744, 0.9549347308916486], 
             UndirectedEdge[220, 262] -> 
             RGBColor[
              0.6062389564434546, 0.6904095282999374, 0.9626925514746905], 
             UndirectedEdge[26, 262] -> 
             RGBColor[
              0.5502733294752062, 0.6457757042557902, 0.9577386786953626], 
             UndirectedEdge[217, 270] -> 
             RGBColor[
              0.7508982400210144, 0.8055240768422794, 0.975753793832397], 
             UndirectedEdge[221, 245] -> 
             RGBColor[
              0.7762963627688586, 0.8074877712496046, 0.6732634885758761], 
             UndirectedEdge[3, 24] -> 
             RGBColor[
              0.6364852208757616, 0.715614126120072, 0.964629706097295], 
             UndirectedEdge[59, 197] -> 
             RGBColor[
              0.5914168076005879, 0.6791778332905425, 0.9609776440069189], 
             UndirectedEdge[54, 235] -> 
             RGBColor[
              0.8723288801933797, 0.90048941792338, 0.9555133276387893], 
             UndirectedEdge[159, 282] -> 
             RGBColor[
              0.562337169500946, 0.6555696730584857, 0.9586883883734908], 
             UndirectedEdge[6, 53] -> 
             RGBColor[
              0.5559356897519094, 0.6503726634148415, 0.9581844404382536], 
             UndirectedEdge[31, 210] -> 
             RGBColor[
              0.792744471781898, 0.8388370604624962, 0.9738825193159728], 
             UndirectedEdge[137, 273] -> 
             RGBColor[
              0.6681062201439036, 0.7378390790359022, 0.9695937083724566], 
             UndirectedEdge[99, 259] -> 
             RGBColor[
              0.6554729998331774, 0.7296788207369429, 0.967047796630487], 
             UndirectedEdge[16, 151] -> 
             RGBColor[
              0.9061169584146225, 0.9251103645740317, 0.877236136802071], 
             UndirectedEdge[24, 227] -> 
             RGBColor[
              0.652928397665997, 0.728459660801376, 0.9662686082895221], 
             UndirectedEdge[87, 202] -> 
             RGBColor[
              0.49995826509986174`, 0.6047281384546777, 0.9538328232160984], 
             UndirectedEdge[17, 94] -> 
             RGBColor[
              0.7303402908706048, 0.7892666531106931, 0.9737571528420728], 
             UndirectedEdge[5, 92] -> 
             RGBColor[
              0.4285126007006034, 0.5316630679162178, 0.9502753690404986], 
             UndirectedEdge[72, 290] -> 
             RGBColor[
              0.6575721016939888, 0.7300783581249437, 0.9681453554355333], 
             UndirectedEdge[103, 212] -> 
             RGBColor[
              0.6257768362499198, 0.7049411884497032, 0.9651400216460222], 
             UndirectedEdge[112, 133] -> 
             RGBColor[
              0.442934000896118, 0.557591015927221, 0.9495763820750165], 
             UndirectedEdge[71, 244] -> 
             RGBColor[
              0.4072556273827355, 0.5271660880010896, 0.9471709463481848], 
             UndirectedEdge[142, 197] -> 
             RGBColor[
              0.62376014083354, 0.7054356082596107, 0.9635238296765503], 
             UndirectedEdge[117, 196] -> 
             RGBColor[
              0.9262007577301012, 0.9393339673023238, 0.753407503290845], 
             UndirectedEdge[131, 188] -> 
             RGBColor[
              0.45061947681172054`, 0.5640076918268073, 0.9501324333360965], 
             UndirectedEdge[13, 282] -> 
             RGBColor[
              0.5976271475940169, 0.6836819177745852, 0.9618342068505078], 
             UndirectedEdge[139, 143] -> 
             RGBColor[
              0.6577579930765437, 0.7296789651089692, 0.968564663375347], 
             UndirectedEdge[45, 89] -> 
             RGBColor[
              0.3476652416707471, 0.4618363186726313, 0.944286660169191], 
             UndirectedEdge[127, 269] -> 
             RGBColor[
              0.7047048038364978, 0.769240015802731, 0.9712020470717599], 
             UndirectedEdge[25, 79] -> 
             RGBColor[
              0.605362487095429, 0.6904995641501562, 0.9620754989814599], 
             UndirectedEdge[29, 78] -> 
             RGBColor[
              0.48302102760254473`, 0.5911344028572378, 0.9524561715658814], 
             UndirectedEdge[150, 179] -> 
             RGBColor[
              0.6300246007045966, 0.7085054645511416, 0.9653952826193231], 
             UndirectedEdge[11, 198] -> 
             RGBColor[
              0.6179439521963448, 0.69979513288118, 0.9636940313249944], 
             UndirectedEdge[135, 286] -> 
             RGBColor[
              0.7987726114901439, 0.838530121873378, 0.7120592130390309], 
             UndirectedEdge[101, 104] -> 
             RGBColor[
              0.9106668049783121, 0.9303184211313438, 0.9464188147571673], 
             UndirectedEdge[3, 290] -> 
             RGBColor[
              0.5677642801839844, 0.6598233706233891, 0.9592197419129381], 
             UndirectedEdge[158, 212] -> 
             RGBColor[
              0.7316909552897215, 0.7844026578366385, 0.7340255543399588], 
             UndirectedEdge[102, 175] -> 
             RGBColor[
              0.6587394049228454, 0.7314581582512529, 0.9679014574907813], 
             UndirectedEdge[103, 255] -> 
             RGBColor[
              0.8346729991420276, 0.8713205548056085, 0.9840105344464635], 
             UndirectedEdge[3, 65] -> 
             RGBColor[
              0.8233294469421861, 0.8601180315362201, 0.8545606527383798], 
             UndirectedEdge[148, 270] -> 
             RGBColor[
              0.6522995160372098, 0.7257074470285743, 0.9678343137221037], 
             UndirectedEdge[49, 298] -> 
             RGBColor[
              0.5706447975435408, 0.6622214216085316, 0.9594058145381306], 
             UndirectedEdge[15, 103] -> 
             RGBColor[
              0.8357708343243956, 0.7113851583677676, 0.6044035145886996], 
             UndirectedEdge[4, 15] -> 
             RGBColor[
              0.8770649560262395, 0.744001024501729, 0.6084247001850465], 
             UndirectedEdge[83, 290] -> 
             RGBColor[
              0.6017794523990817, 0.6863962816827069, 0.9626100563894819], 
             UndirectedEdge[182, 284] -> 
             RGBColor[
              0.8540007825197165, 0.8865128827161914, 0.9709739366308494], 
             UndirectedEdge[32, 92] -> 
             RGBColor[
              0.5501405689767992, 0.6272152344173629, 0.9622560100968662], 
             UndirectedEdge[87, 203] -> 
             RGBColor[
              0.7203451726745709, 0.775907443176703, 0.8082080117015735], 
             UndirectedEdge[115, 169] -> 
             RGBColor[
              0.8494143615293762, 0.7141143103315546, 0.6042137065405113], 
             UndirectedEdge[111, 143] -> 
             RGBColor[
              0.5859056296654965, 0.6731283129505676, 0.961514291557988], 
             UndirectedEdge[163, 274] -> 
             RGBColor[
              0.5456184134868403, 0.6410351471401232, 0.9577614575806512], 
             UndirectedEdge[96, 260] -> 
             RGBColor[
              0.4919357831409723, 0.5967725904386616, 0.9535998409755932], 
             UndirectedEdge[27, 227] -> 
             RGBColor[
              0.7009407870796647, 0.7662995373047061, 0.9708268850581752], 
             UndirectedEdge[103, 205] -> 
             RGBColor[
              0.8882898541485369, 0.9107355932412341, 0.8551404508464363], 
             UndirectedEdge[27, 216] -> 
             RGBColor[
              0.7604555568661999, 0.8127929277909509, 0.9767587611133524], 
             UndirectedEdge[145, 293] -> 
             RGBColor[
              0.5776664132493387, 0.6680146437079919, 0.9598951625942342], 
             UndirectedEdge[96, 133] -> 
             RGBColor[
              0.403895906258977, 0.5242560664281836, 0.9469568678890635], 
             UndirectedEdge[127, 159] -> 
             RGBColor[
              0.6717063975284843, 0.7429179643817089, 0.9682846310543216], 
             UndirectedEdge[186, 214] -> 
             RGBColor[
              0.83347642066192, 0.8701375812477745, 0.9516408775695706], 
             UndirectedEdge[111, 262] -> 
             RGBColor[
              0.6229575066851648, 0.7034701868144494, 0.9643589003190494], 
             UndirectedEdge[33, 157] -> 
             RGBColor[
              0.7572028759328003, 0.8088404719338926, 0.9400635805776734], 
             UndirectedEdge[112, 131] -> 
             RGBColor[
              0.4753394682022467, 0.584941019942421, 0.9518396106441769], 
             UndirectedEdge[37, 55] -> 
             RGBColor[
              0.6670067065680999, 0.7295150396498176, 0.7882878160742477], 
             UndirectedEdge[20, 71] -> 
             RGBColor[
              0.41979517092466045`, 0.5380272103613211, 0.9479699549743932], 
             UndirectedEdge[37, 252] -> 
             RGBColor[
              0.9947287590277489, 0.9911336735015974, 0.6676361343779769], 
             UndirectedEdge[120, 178] -> 
             RGBColor[
              0.6327776684403161, 0.7124531332580291, 0.964441097286594], 
             UndirectedEdge[113, 231] -> 
             RGBColor[
              0.7074977440330081, 0.7676806857475065, 0.9306556708227385], 
             UndirectedEdge[7, 181] -> 
             RGBColor[
              0.8301023356727935, 0.8673650862105803, 0.9836570958892159], 
             UndirectedEdge[42, 299] -> 
             RGBColor[
              0.4062828322639014, 0.5217427441495548, 0.9477799883963749], 
             UndirectedEdge[64, 234] -> 
             RGBColor[
              0.5331212395543838, 0.6306931675124223, 0.9567609554126412], 
             UndirectedEdge[78, 261] -> 
             RGBColor[
              0.5079746878547657, 0.6114357614562269, 0.9544087746819718], 
             UndirectedEdge[10, 100] -> 
             RGBColor[
              0.6702440464634165, 0.7418737824243051, 0.9680717255142371], 
             UndirectedEdge[6, 88] -> 
             RGBColor[
              0.6825162713356725, 0.7503170334876272, 0.97012300781176], 
             UndirectedEdge[36, 208] -> 
             RGBColor[
              0.4385612753806074, 0.553920009778534, 0.9492655862161801], 
             UndirectedEdge[92, 142] -> 
             RGBColor[
              0.41177082936239573`, 0.5180808254638692, 0.9489509127642626], 
             UndirectedEdge[237, 293] -> 
             RGBColor[
              0.5915002450283557, 0.6792167757724619, 0.961003900339445], 
             UndirectedEdge[127, 145] -> 
             RGBColor[
              0.676550406484503, 0.7468505490723216, 0.9686659691835289], 
             UndirectedEdge[90, 285] -> 
             RGBColor[
              0.6795547445376929, 0.7477962807141612, 0.9700238995790178], 
             UndirectedEdge[134, 176] -> 
             RGBColor[
              0.7447069827761111, 0.800538725990084, 0.9751761658902105], 
             UndirectedEdge[28, 297] -> 
             RGBColor[
              0.8443074256741913, 0.8784576302930034, 0.9455721616698801], 
             UndirectedEdge[20, 136] -> 
             RGBColor[
              0.5104811023392413, 0.6134160914087966, 0.9546211446267711], 
             UndirectedEdge[113, 134] -> 
             RGBColor[
              0.9048170853081856, 0.9257047351037887, 0.9479352612500757], 
             UndirectedEdge[12, 181] -> 
             RGBColor[
              0.8343563221755923, 0.8707570995765246, 0.9840628449194315], 
             UndirectedEdge[84, 217] -> 
             RGBColor[
              0.682787791173105, 0.7521182789346229, 0.9690175640756011], 
             UndirectedEdge[126, 153] -> 
             RGBColor[
              0.8050427110097899, 0.8484237312255803, 0.9809907672903942], 
             UndirectedEdge[217, 251] -> 
             RGBColor[
              0.7665656619397065, 0.8180168537994059, 0.9772481665214745], 
             UndirectedEdge[211, 266] -> 
             RGBColor[
              0.39145094697977256`, 0.5086925002338868, 0.9467042181788088], 
             UndirectedEdge[156, 282] -> 
             RGBColor[
              0.49493445065683017`, 0.6008491094429518, 0.9533821994417875], 
             UndirectedEdge[92, 256] -> 
             RGBColor[
              0.3424827056088948, 0.4618296052063732, 0.9434962978516267], 
             UndirectedEdge[56, 246] -> 
             RGBColor[
              0.6229575517988895, 0.7040918606025042, 0.963933887147357], 
             UndirectedEdge[223, 246] -> 
             RGBColor[
              0.7763948913214205, 0.8214098462847232, 0.7961066904347519], 
             UndirectedEdge[66, 228] -> 
             RGBColor[
              0.4884193070498773, 0.5944784409396859, 0.9531680923794121], 
             UndirectedEdge[170, 261] -> 
             RGBColor[
              0.5568321670564543, 0.6511004640765135, 0.958255014415572], 
             UndirectedEdge[104, 287] -> 
             RGBColor[
              0.9727876718057208, 0.9791944340799382, 0.9295487129913369], 
             UndirectedEdge[255, 258] -> 
             RGBColor[
              0.7856090202057764, 0.8329914015605582, 0.9791202955550495], 
             UndirectedEdge[27, 162] -> 
             RGBColor[
              0.7646837517218366, 0.8160960257476453, 0.9771801880618347], 
             UndirectedEdge[162, 169] -> 
             RGBColor[
              0.8492410435728459, 0.7139789130266478, 0.6041964318263527], 
             UndirectedEdge[90, 166] -> 
             RGBColor[
              0.8694310370808264, 0.8987247251641852, 0.9874083025386604], 
             UndirectedEdge[74, 257] -> 
             RGBColor[
              0.7315715915594798, 0.7896402832583584, 0.9745626946456196], 
             UndirectedEdge[82, 203] -> 
             RGBColor[
              0.7445622392216267, 0.7957674786394068, 0.8100593371916787], 
             UndirectedEdge[1, 142] -> 
             RGBColor[
              0.742446182466965, 0.798668314475653, 0.9751891057008152], 
             UndirectedEdge[82, 145] -> 
             RGBColor[
              0.5554873570770094, 0.6500086867522008, 0.9581491460477889], 
             UndirectedEdge[77, 203] -> 
             RGBColor[
              0.9431370549826767, 0.9537405894094424, 0.8281483013303932], 
             UndirectedEdge[12, 27] -> 
             RGBColor[
              0.7740066265610417, 0.8234707309387148, 0.9780850960781589], 
             UndirectedEdge[54, 185] -> 
             RGBColor[
              0.7343137868752673, 0.7904451462247679, 0.9432790863499857], 
             UndirectedEdge[35, 165] -> 
             RGBColor[
              0.8108268754243811, 0.8522617140653355, 0.9412505849498978], 
             UndirectedEdge[60, 95] -> 
             RGBColor[
              0.710036680142891, 0.7719596942956207, 0.97309479588668], 
             UndirectedEdge[47, 112] -> 
             RGBColor[
              0.7106492889336683, 0.7719329905194041, 0.9601843806830328], 
             UndirectedEdge[24, 59] -> 
             RGBColor[
              0.5827393611950984, 0.6721330913840604, 0.9602945236393452], 
             UndirectedEdge[239, 285] -> 
             RGBColor[
              0.640490979258006, 0.7170393165444813, 0.9661940914350939], 
             UndirectedEdge[173, 286] -> 
             RGBColor[
              0.9912422092287307, 0.9885400658131704, 0.6416914242269951], 
             UndirectedEdge[17, 40] -> 
             RGBColor[
              0.7526551667125978, 0.8066992037177958, 0.9759812911216317], 
             UndirectedEdge[226, 241] -> 
             RGBColor[
              0.5579788280345954, 0.6486770785344923, 0.9598458985509599], 
             UndirectedEdge[255, 286] -> 
             RGBColor[
              0.9403366035062619, 0.950246198632424, 0.7256290907022455], 
             UndirectedEdge[95, 271] -> 
             RGBColor[
              0.7346987449969561, 0.7919814695575114, 0.9750362839721123], 
             UndirectedEdge[189, 260] -> 
             RGBColor[
              0.6246996939432651, 0.7059531146812841, 0.9637654838405476], 
             UndirectedEdge[193, 245] -> 
             RGBColor[
              0.5110347397145646, 0.6138887094263261, 0.9546583325045195], 
             UndirectedEdge[84, 223] -> 
             RGBColor[
              0.851301894469817, 0.881214347064881, 0.8026930782756384], 
             UndirectedEdge[44, 61] -> 
             RGBColor[
              0.8303917884039285, 0.8678366945772997, 0.9568434750386217], 
             UndirectedEdge[262, 292] -> 
             RGBColor[
              0.5736009103054363, 0.6647140852693115, 0.9595751113100623], 
             UndirectedEdge[153, 248] -> 
             RGBColor[
              0.7322479937849536, 0.7907569651264615, 0.9739472948400778], 
             UndirectedEdge[78, 99] -> 
             RGBColor[
              0.6273789602004856, 0.7068708137410611, 0.9648361309187434], 
             UndirectedEdge[199, 261] -> 
             RGBColor[
              0.696601535457868, 0.7613326435314822, 0.9717146213386063], 
             UndirectedEdge[58, 215] -> 
             RGBColor[
              0.809121208298593, 0.8515701643610819, 0.9724509256428914], 
             UndirectedEdge[23, 197] -> 
             RGBColor[
              0.5523280233420067, 0.6474437972997629, 0.9579004317231486], 
             UndirectedEdge[196, 214] -> 
             RGBColor[
              0.9824729891696398, 0.9832789040210609, 0.7267040119487775], 
             UndirectedEdge[88, 289] -> 
             RGBColor[
              0.9005736327676523, 0.9227354688282544, 0.961896208179998], 
             UndirectedEdge[47, 96] -> 
             RGBColor[
              0.6716111942965273, 0.7385980410203665, 0.9575648664970798], 
             UndirectedEdge[179, 205] -> 
             RGBColor[
              0.7405793530522876, 0.7929492181690739, 0.8420547087998498], 
             UndirectedEdge[72, 194] -> 
             RGBColor[
              0.7547524429524861, 0.8084340466295018, 0.9761647371933492], 
             UndirectedEdge[140, 299] -> 
             RGBColor[
              0.4942857731350849, 0.6003224838082096, 0.9533311331710916], 
             UndirectedEdge[134, 297] -> 
             RGBColor[
              0.7675392616056731, 0.818375475743484, 0.9774518740641644], 
             UndirectedEdge[67, 195] -> 
             RGBColor[
              0.9365221814060651, 0.952012542243593, 0.9865668926915745], 
             UndirectedEdge[24, 155] -> 
             RGBColor[
              0.7517696560801058, 0.3237272262609311, 0.43057221289799996`], 
             UndirectedEdge[156, 277] -> 
             RGBColor[
              0.663359132471671, 0.7346120865590177, 0.9687902035568788], 
             UndirectedEdge[267, 272] -> 
             RGBColor[
              0.8897807759311632, 0.9149510545444979, 0.9893492787966318], 
             UndirectedEdge[71, 177] -> 
             RGBColor[
              0.4748842993365045, 0.5828055367816227, 0.9522917171458174], 
             UndirectedEdge[188, 281] -> 
             RGBColor[
              0.4220574745770609, 0.5399867040783426, 0.9481141069626475], 
             UndirectedEdge[1, 150] -> 
             RGBColor[
              0.8246775022609838, 0.8634114899206842, 0.9830409481325005], 
             UndirectedEdge[84, 246] -> 
             RGBColor[
              0.6332785538208343, 0.7121547058245681, 0.9649625881736568], 
             UndirectedEdge[58, 230] -> 
             RGBColor[
              0.5077521070808604, 0.6077937586408778, 0.9555363590151996], 
             UndirectedEdge[74, 189] -> 
             RGBColor[
              0.6092691202286219, 0.6934258798003127, 0.962550732553677], 
             UndirectedEdge[48, 71] -> 
             RGBColor[
              0.44579215282062085`, 0.5591872216537632, 0.950001476804043], 
             UndirectedEdge[80, 205] -> 
             RGBColor[
              0.9316087083742381, 0.944965926129819, 0.8593547572384088], 
             UndirectedEdge[1, 32] -> 
             RGBColor[
              0.8808159220813685, 0.9078027234291467, 0.988494203033419], 
             UndirectedEdge[229, 233] -> 
             RGBColor[
              0.4729325226094203, 0.5829869530785012, 0.9516501270701774], 
             UndirectedEdge[54, 172] -> 
             RGBColor[
              0.9216992257227931, 0.9394769468429849, 0.9603229020201092], 
             UndirectedEdge[61, 194] -> 
             RGBColor[
              0.82150576346507, 0.8608948643587725, 0.9559577991173407], 
             UndirectedEdge[177, 194] -> 
             RGBColor[
              0.6195395962747856, 0.7014694895998751, 0.9635605622591484], 
             UndirectedEdge[7, 42] -> 
             RGBColor[
              0.5523610743547289, 0.6375942075402867, 0.961163690161444], 
             UndirectedEdge[26, 75] -> 
             RGBColor[
              0.6475556242758433, 0.7236815914780634, 0.9661302088309487], 
             UndirectedEdge[170, 190] -> 
             RGBColor[
              0.6039041908420499, 0.6893156535561655, 0.9619606965584788], 
             UndirectedEdge[20, 36] -> 
             RGBColor[
              0.45897067599242125`, 0.5715976067821857, 0.9505660551758405], 
             UndirectedEdge[119, 161] -> 
             RGBColor[
              0.7579212264897746, 0.8087916896307685, 0.9171435413091676], 
             UndirectedEdge[212, 225] -> 
             RGBColor[
              0.7177311433291755, 0.7771856431926651, 0.9474192915706565], 
             UndirectedEdge[102, 253] -> 
             RGBColor[
              0.5177666142630835, 0.619385288435757, 0.9551796309978429], 
             UndirectedEdge[91, 179] -> 
             RGBColor[
              0.5166181546488768, 0.6184529171834281, 0.9550892200500662], 
             UndirectedEdge[118, 239] -> 
             RGBColor[
              0.7396603459441672, 0.7965475509692022, 0.974686088830939], 
             UndirectedEdge[105, 298] -> 
             RGBColor[
              0.4783216190171723, 0.5873620643183408, 0.9520743764803061], 
             UndirectedEdge[90, 239] -> 
             RGBColor[
              0.8106202092667222, 0.8522219893492942, 0.9816950019417929], 
             UndirectedEdge[208, 252] -> 
             RGBColor[
              0.7027663828361175, 0.7608849153729027, 0.8244667892900062], 
             UndirectedEdge[117, 214] -> 
             RGBColor[
              0.9152977236394935, 0.9343725628459068, 0.9597123210367158], 
             UndirectedEdge[179, 282] -> 
             RGBColor[
              0.501941692515621, 0.6065379040565666, 0.9539338351892842], 
             UndirectedEdge[44, 268] -> 
             RGBColor[
              0.6661601834772904, 0.7390459373866882, 0.9674168411480799], 
             UndirectedEdge[53, 124] -> 
             RGBColor[
              0.7872547665172354, 0.8310389224677247, 0.8539436787313983], 
             UndirectedEdge[42, 81] -> 
             RGBColor[
              0.49949969187710913`, 0.5962756560556366, 0.9559010220055899], 
             UndirectedEdge[173, 213] -> 
             RGBColor[
              0.77905193907183, 0.8252629397242808, 0.8902292683010842], 
             UndirectedEdge[119, 122] -> 
             RGBColor[
              0.8477796213392572, 0.8807166016579182, 0.9249191288586291], 
             UndirectedEdge[68, 111] -> 
             RGBColor[
              0.5973769775885884, 0.6827027609041455, 0.9623451073640013], 
             UndirectedEdge[34, 53] -> 
             RGBColor[
              0.6912478425668368, 0.7577786562404872, 0.9705094000452387], 
             UndirectedEdge[85, 263] -> 
             RGBColor[
              0.5006840320034429, 0.6035561819411878, 0.9543765738743775], 
             UndirectedEdge[37, 208] -> 
             RGBColor[
              0.7024547413201292, 0.7602183456819943, 0.7905465335031807], 
             UndirectedEdge[256, 293] -> 
             RGBColor[
              0.5048399432596996, 0.6088908345753176, 0.9541619961045003], 
             UndirectedEdge[76, 153] -> 
             RGBColor[
              0.773710544100702, 0.8234403118212877, 0.9780022772400498], 
             UndirectedEdge[135, 213] -> 
             RGBColor[
              0.5865823413332429, 0.6752529957844884, 0.9605970571131199], 
             UndirectedEdge[36, 55] -> 
             RGBColor[
              0.4031132406285781, 0.5232167037463571, 0.947006868787247], 
             UndirectedEdge[121, 135] -> 
             RGBColor[
              0.6131824527630327, 0.6968481645645557, 0.9626911153242919], 
             UndirectedEdge[83, 226] -> 
             RGBColor[
              0.7273164556073064, 0.7869044100210052, 0.9734557652023743], 
             UndirectedEdge[60, 127] -> 
             RGBColor[
              0.6131619246383391, 0.6953889238910409, 0.9636757956929389], 
             UndirectedEdge[247, 271] -> 
             RGBColor[
              0.7018410936891005, 0.7657816703018123, 0.9719022918579974], 
             UndirectedEdge[202, 269] -> 
             RGBColor[
              0.6134134850099627, 0.6965681855694109, 0.9630289636247955], 
             UndirectedEdge[190, 284] -> 
             RGBColor[
              0.7740357678236265, 0.8233302449944219, 0.9634914997408064], 
             UndirectedEdge[53, 217] -> 
             RGBColor[
              0.6189098218834788, 0.7012676446933281, 0.9632994221807591], 
             UndirectedEdge[42, 87] -> 
             RGBColor[
              0.3639410418162364, 0.4871682413148295, 0.9445018182477626], 
             UndirectedEdge[205, 225] -> 
             RGBColor[
              0.9802441612277927, 0.9829800479841961, 0.8374197207710707], 
             UndirectedEdge[110, 246] -> 
             RGBColor[
              0.7762526722991498, 0.8211056541766353, 0.780627027534665], 
             UndirectedEdge[191, 251] -> 
             RGBColor[
              0.8853604865744977, 0.911426435797051, 0.9889276676517542], 
             UndirectedEdge[23, 83] -> 
             RGBColor[
              0.5934800017870587, 0.6796584137898773, 0.9619566932354141], 
             UndirectedEdge[226, 291] -> 
             RGBColor[
              0.7032515974907911, 0.7681047599606878, 0.9710572050442052], 
             UndirectedEdge[60, 276] -> 
             RGBColor[
              0.49379690668119514`, 0.5999255999977591, 0.9532926478130646], 
             UndirectedEdge[27, 155] -> 
             RGBColor[
              0.7837779156892177, 0.3489538105964845, 0.43361106407710204`], 
             UndirectedEdge[167, 203] -> 
             RGBColor[
              0.6913188143583487, 0.7507662705103799, 0.8063584778166647], 
             UndirectedEdge[137, 271] -> 
             RGBColor[
              0.717148825890106, 0.7779876404415728, 0.9733623570207031], 
             UndirectedEdge[52, 247] -> 
             RGBColor[
              0.816174898758798, 0.8566816239625407, 0.9822167257935035], 
             UndirectedEdge[81, 299] -> 
             RGBColor[
              0.6238699084803851, 0.7043799884807056, 0.9643151319436574], 
             UndirectedEdge[31, 290] -> 
             RGBColor[
              0.7127257440432593, 0.773888154872745, 0.9675736468094197], 
             UndirectedEdge[79, 288] -> 
             RGBColor[
              0.534592116321513, 0.6328681259324106, 0.9565530639426796], 
             UndirectedEdge[237, 281] -> 
             RGBColor[
              0.5334377677362433, 0.6312459733911004, 0.9566631885056726], 
             UndirectedEdge[43, 215] -> 
             RGBColor[
              0.8870708308517664, 0.9125338379640708, 0.9802019485737321], 
             UndirectedEdge[56, 295] -> 
             RGBColor[
              0.5667565104485942, 0.6582657935328855, 0.9595646659995807], 
             UndirectedEdge[89, 94] -> 
             RGBColor[
              0.4316929939792908, 0.5294089152825016, 0.9513425666764778], 
             UndirectedEdge[92, 237] -> 
             RGBColor[
              0.42914300737755107`, 0.5321555464035175, 0.9503382020865714], 
             UndirectedEdge[126, 285] -> 
             RGBColor[
              0.7141304991353881, 0.7753660488965068, 0.9733217659186866], 
             UndirectedEdge[4, 214] -> 
             RGBColor[
              0.9178356709402953, 0.9363962531328219, 0.9599543927159184], 
             UndirectedEdge[220, 222] -> 
             RGBColor[
              0.722123001862797, 0.7828472444840842, 0.9729381302687063], 
             UndirectedEdge[199, 209] -> 
             RGBColor[
              0.9106579879919412, 0.9315979767449374, 0.9913405659202961], 
             UndirectedEdge[290, 291] -> 
             RGBColor[
              0.5777145942825666, 0.6675966316223896, 0.9602114962313129], 
             UndirectedEdge[91, 150] -> 
             RGBColor[
              0.6605506141481011, 0.7332878574458126, 0.9677984022180675], 
             UndirectedEdge[60, 148] -> 
             RGBColor[
              0.47499336340255094`, 0.5846600364741844, 0.9518123640065211], 
             UndirectedEdge[81, 140] -> 
             RGBColor[
              0.5875026327482926, 0.6748553957142915, 0.9614521667803066], 
             UndirectedEdge[142, 256] -> 
             RGBColor[
              0.5402062968622826, 0.6376028336659678, 0.9569461650113176], 
             UndirectedEdge[30, 123] -> 
             RGBColor[
              0.5403407773088154, 0.6377120109507382, 0.9569567518046866], 
             UndirectedEdge[53, 289] -> 
             RGBColor[
              0.7739930511838893, 0.8227910987554686, 0.9499576408064916], 
             UndirectedEdge[274, 289] -> 
             RGBColor[
              0.6983171750393495, 0.7606958368749772, 0.944182014745391], 
             UndirectedEdge[11, 114] -> 
             RGBColor[
              0.6170277616518967, 0.6990793978645512, 0.9636027140138113], 
             UndirectedEdge[137, 247] -> 
             RGBColor[
              0.8798716404753446, 0.9070497789083445, 0.9884041366108662], 
             UndirectedEdge[84, 191] -> 
             RGBColor[
              0.8015826158078962, 0.8455278609322681, 0.9806970652058807], 
             UndirectedEdge[17, 120] -> 
             RGBColor[
              0.6898089848952393, 0.757006431126674, 0.9701254459228668], 
             UndirectedEdge[126, 222] -> 
             RGBColor[
              0.834197409203177, 0.8711996030381675, 0.9838966351401661], 
             UndirectedEdge[184, 224] -> 
             RGBColor[
              0.47146359086476475`, 0.5814332461449301, 0.9516342775103814], 
             UndirectedEdge[278, 295] -> 
             RGBColor[
              0.6638326425200806, 0.7346011993563984, 0.9691079431199916], 
             UndirectedEdge[28, 245] -> 
             RGBColor[
              0.7747258973662472, 0.8229901194969345, 0.9393957644557667], 
             UndirectedEdge[14, 186] -> 
             RGBColor[
              0.566734822263655, 0.6579140634498382, 0.9597042020953561], 
             UndirectedEdge[227, 241] -> 
             RGBColor[
              0.5334201949438275, 0.6294916877114598, 0.9573981235179467], 
             UndirectedEdge[121, 154] -> 
             RGBColor[
              0.7882331217723093, 0.834772886280496, 0.9623719904818182], 
             UndirectedEdge[187, 230] -> 
             RGBColor[
              0.596098720584995, 0.677047710609362, 0.9642790562244463], 
             UndirectedEdge[125, 277] -> 
             RGBColor[
              0.9102593361273047, 0.930501867584981, 0.9643206467066662], 
             UndirectedEdge[62, 158] -> 
             RGBColor[
              0.9263066178292897, 0.9393951408452844, 0.7515339802684216], 
             UndirectedEdge[20, 61] -> 
             RGBColor[
              0.708366461954254, 0.7695284827398021, 0.9466971253641472], 
             UndirectedEdge[64, 258] -> 
             RGBColor[
              0.6670923915208589, 0.7398569134368327, 0.9674531933201143], 
             UndirectedEdge[94, 294] -> 
             RGBColor[
              0.7195106671926352, 0.7808064687852748, 0.9726777571624401], 
             UndirectedEdge[125, 237] -> 
             RGBColor[
              0.805058420722576, 0.8480379964581073, 0.9539095369122371], 
             UndirectedEdge[267, 300] -> 
             RGBColor[
              0.7673015272013275, 0.8185572481146508, 0.9773306577648355], 
             UndirectedEdge[165, 175] -> 
             RGBColor[
              0.7192018509254112, 0.780544295718288, 0.9726612827213407], 
             UndirectedEdge[67, 263] -> 
             RGBColor[
              0.7747538959411981, 0.8245075163597896, 0.9781809734254951], 
             UndirectedEdge[163, 298] -> 
             RGBColor[
              0.5775171711876768, 0.6675901721313049, 0.9600907885169949], 
             UndirectedEdge[92, 149] -> 
             RGBColor[
              0.5392781344288562, 0.6185538239617641, 0.9612199413926736], 
             UndirectedEdge[95, 276] -> 
             RGBColor[
              0.7140394374283543, 0.7752093129821206, 0.9734099076027747], 
             UndirectedEdge[70, 231] -> 
             RGBColor[
              0.6179428927461155, 0.697632975146308, 0.964928863530683], 
             UndirectedEdge[239, 263] -> 
             RGBColor[
              0.6959087301328436, 0.762029943245901, 0.9705567797858714], 
             UndirectedEdge[116, 204] -> 
             RGBColor[
              0.8581281320427119, 0.8896845152465827, 0.9687184423261399], 
             UndirectedEdge[121, 258] -> 
             RGBColor[
              0.6525226100987429, 0.7281578077060198, 0.9662178041941238], 
             UndirectedEdge[95, 148] -> 
             RGBColor[
              0.6952358941497101, 0.7599437494585459, 0.9719296237962313], 
             UndirectedEdge[60, 77] -> 
             RGBColor[
              0.6906736909918954, 0.7565201723409557, 0.9712479366959136], 
             UndirectedEdge[42, 269] -> 
             RGBColor[
              0.47739626172633737`, 0.5790082884295626, 0.9536979586564596], 
             UndirectedEdge[61, 136] -> 
             RGBColor[
              0.7675363979413697, 0.8176197925879958, 0.9513401436563875], 
             UndirectedEdge[95, 251] -> 
             RGBColor[
              0.903010254696242, 0.9254998818071369, 0.9906111182913402], 
             UndirectedEdge[158, 265] -> 
             RGBColor[
              0.8035735595781001, 0.8427601942723643, 0.7396844162641955], 
             UndirectedEdge[152, 208] -> 
             RGBColor[
              0.5738538475198549, 0.6623035367073735, 0.960909790448979], 
             UndirectedEdge[153, 285] -> 
             RGBColor[
              0.6003377264033786, 0.6856712902384219, 0.9621919904440266], 
             UndirectedEdge[61, 279] -> 
             RGBColor[
              0.8233118629250853, 0.8623058029838009, 0.9561378142325558], 
             UndirectedEdge[82, 168] -> 
             RGBColor[
              0.48049925675919014`, 0.5891299687387732, 0.9522458081003078], 
             UndirectedEdge[4, 249] -> 
             RGBColor[
              0.7030376289757496, 0.7667564184010014, 0.9719926353356344], 
             UndirectedEdge[75, 163] -> 
             RGBColor[
              0.6872573971499627, 0.7556099690940077, 0.9694630526285316], 
             UndirectedEdge[59, 290] -> 
             RGBColor[
              0.5140184205033211, 0.6163423358873774, 0.9548845594549882], 
             UndirectedEdge[205, 251] -> 
             RGBColor[
              0.9354039317008184, 0.9479921341918414, 0.8597167490273339], 
             UndirectedEdge[183, 224] -> 
             RGBColor[
              0.5337107235833392, 0.6319682726872413, 0.9565345998167478], 
             UndirectedEdge[170, 178] -> 
             RGBColor[
              0.6370881098265462, 0.7159525437585421, 0.964780431022185], 
             UndirectedEdge[102, 238] -> 
             RGBColor[
              0.7573945555459543, 0.8061853311207585, 0.8110695441390532], 
             UndirectedEdge[89, 236] -> 
             RGBColor[
              0.3107453016360948, 0.43157104104303334`, 0.9414608696751218], 
             UndirectedEdge[65, 231] -> 
             RGBColor[
              0.7128652487315041, 0.7699945840373648, 0.8459250467276178], 
             UndirectedEdge[25, 245] -> 
             RGBColor[
              0.5791253590029461, 0.6691990815955278, 0.9600100161482528], 
             UndirectedEdge[217, 223] -> 
             RGBColor[
              0.825904128673691, 0.8613734193947782, 0.8001616663366962], 
             UndirectedEdge[254, 283] -> 
             RGBColor[
              0.6584720501505834, 0.7305105011921329, 0.9685120812029373], 
             UndirectedEdge[168, 205] -> 
             RGBColor[
              0.7308307386758122, 0.7850348538481782, 0.8412872621657825], 
             UndirectedEdge[142, 243] -> 
             RGBColor[
              0.7836950446510391, 0.8309866465429967, 0.9592783048282131], 
             UndirectedEdge[57, 278] -> 
             RGBColor[
              0.9239719138323543, 0.9414263649455006, 0.965297810860547], 
             UndirectedEdge[185, 218] -> 
             RGBColor[
              0.5657493968126635, 0.6583398729092265, 0.9589570114068697], 
             UndirectedEdge[16, 248] -> 
             RGBColor[
              0.8829375851859128, 0.9070024620380024, 0.8749258335021917], 
             UndirectedEdge[184, 275] -> 
             RGBColor[
              0.7412879129193064, 0.795839719710072, 0.9366577906855412], 
             UndirectedEdge[127, 191] -> 
             RGBColor[
              0.815754687263754, 0.8565991908653164, 0.9821096048430631], 
             UndirectedEdge[33, 153] -> 
             RGBColor[
              0.8342423057027939, 0.8706356047888957, 0.9466404657244468], 
             UndirectedEdge[83, 243] -> 
             RGBColor[
              0.8391127433138477, 0.874782817369258, 0.9644576160930753], 
             UndirectedEdge[94, 281] -> 
             RGBColor[
              0.553547873392487, 0.646956140772222, 0.9586675758978648], 
             UndirectedEdge[140, 293] -> 
             RGBColor[
              0.49834010540680496`, 0.6036139733919794, 0.9536503050590299], 
             UndirectedEdge[126, 220] -> 
             RGBColor[
              0.8067610764014195, 0.8497661313295821, 0.9811620378935944], 
             UndirectedEdge[76, 220] -> 
             RGBColor[
              0.7754289094923316, 0.8247827119252895, 0.9781735478432498], 
             UndirectedEdge[90, 126] -> 
             RGBColor[
              0.8842597291441042, 0.9105487217013197, 0.9888226764253855], 
             UndirectedEdge[35, 102] -> 
             RGBColor[
              0.7503644294218152, 0.8031755765983003, 0.9364907597193384], 
             UndirectedEdge[105, 235] -> 
             RGBColor[
              0.6184278309197501, 0.6991040002876405, 0.9644732382840986], 
             UndirectedEdge[21, 287] -> 
             RGBColor[
              0.8193669084310466, 0.8592988019173388, 0.9595323671075235], 
             UndirectedEdge[160, 245] -> 
             RGBColor[
              0.7754048336113915, 0.8234964690369071, 0.9382465024876698], 
             UndirectedEdge[235, 298] -> 
             RGBColor[
              0.6329815934051497, 0.7109194003128163, 0.9656189637791379], 
             UndirectedEdge[15, 196] -> 
             RGBColor[
              0.9417022742555838, 0.790883675389968, 0.37517431941790547`], 
             UndirectedEdge[13, 274] -> 
             RGBColor[
              0.5532704587315315, 0.6470129830429738, 0.9585241419382136], 
             UndirectedEdge[2, 172] -> 
             RGBColor[
              0.9238578536722619, 0.9154802180886128, 0.6742318858117254], 
             UndirectedEdge[247, 295] -> 
             RGBColor[
              0.6552666881230932, 0.7277709398368787, 0.9682909147426891], 
             UndirectedEdge[159, 225] -> 
             RGBColor[
              0.7861524263662023, 0.8327331231057982, 0.9528056656067494], 
             UndirectedEdge[204, 254] -> 
             RGBColor[
              0.7032836579548938, 0.7657377358394071, 0.9553009867274672], 
             UndirectedEdge[61, 252] -> 
             RGBColor[
              0.9802310790500599, 0.9827662135557536, 0.822486257279283], 
             UndirectedEdge[4, 173] -> 
             RGBColor[
              0.9268727265663403, 0.9422302881203164, 0.90409405356756], 
             UndirectedEdge[230, 245] -> 
             RGBColor[
              0.45640431292070754`, 0.5665705795425756, 0.9511773300170046], 
             UndirectedEdge[137, 295] -> 
             RGBColor[
              0.6705744203240986, 0.7399769099766391, 0.9697509799053949], 
             UndirectedEdge[109, 192] -> 
             RGBColor[
              0.436112753343284, 0.5518411491993354, 0.9490979842388099], 
             UndirectedEdge[178, 229] -> 
             RGBColor[
              0.5721280747799248, 0.6632150608914653, 0.9596665391068661], 
             UndirectedEdge[91, 93] -> 
             RGBColor[
              0.7151279809764639, 0.7764343496720916, 0.9731027624910382], 
             UndirectedEdge[143, 185] -> 
             RGBColor[
              0.4703725542290179, 0.5806471644907523, 0.9515208477052235], 
             UndirectedEdge[139, 273] -> 
             RGBColor[
              0.6564307819890056, 0.7285294015725126, 0.9684800946584557], 
             UndirectedEdge[130, 281] -> 
             RGBColor[
              0.5883844053881249, 0.6741707043346636, 0.9621397558412892], 
             UndirectedEdge[220, 248] -> 
             RGBColor[
              0.7339663591765833, 0.7920993652304633, 0.9741185654432778], 
             UndirectedEdge[88, 273] -> 
             RGBColor[
              0.6373119245844807, 0.7132845436457036, 0.9666565209716067], 
             UndirectedEdge[24, 218] -> 
             RGBColor[
              0.6275560715970709, 0.7085173158581772, 0.963822659251208], 
             UndirectedEdge[66, 215] -> 
             RGBColor[
              0.6795663369936606, 0.7457735754287056, 0.9622339379580175], 
             UndirectedEdge[151, 154] -> 
             RGBColor[
              0.8872055023110239, 0.9124079439247075, 0.9720198419006179], 
             UndirectedEdge[8, 64] -> 
             RGBColor[
              0.5384885989708128, 0.6353421044676048, 0.9571029588084865], 
             UndirectedEdge[71, 108] -> 
             RGBColor[
              0.5084396944706331, 0.6100473182048323, 0.9549333207682384], 
             UndirectedEdge[43, 182] -> 
             RGBColor[
              0.7921108463389415, 0.8375911165415434, 0.9798955975678751], 
             UndirectedEdge[58, 297] -> 
             RGBColor[
              0.6908350294233583, 0.7584048426169967, 0.9698196375786693], 
             UndirectedEdge[46, 207] -> 
             RGBColor[
              0.7203186348555408, 0.7809685973467453, 0.9731427982386301], 
             UndirectedEdge[100, 266] -> 
             RGBColor[
              0.5613601138037985, 0.6547764552276838, 0.9586114709699385], 
             UndirectedEdge[12, 151] -> 
             RGBColor[
              0.8254611509019882, 0.8636673964227313, 0.9832136021945959], 
             UndirectedEdge[196, 265] -> 
             RGBColor[
              0.8035908804694866, 0.8427972419076293, 0.7415696883994649], 
             UndirectedEdge[93, 139] -> 
             RGBColor[
              0.8774701451135504, 0.905134891693705, 0.988175079839418], 
             UndirectedEdge[30, 104] -> 
             RGBColor[
              0.7682293549936927, 0.8175250645685963, 0.93320392906532], 
             UndirectedEdge[85, 121] -> 
             RGBColor[
              0.5013835412001757, 0.6041240750196255, 0.9544316418007308], 
             UndirectedEdge[79, 160] -> 
             RGBColor[
              0.8016419617038744, 0.8447969515915357, 0.940311985320877], 
             UndirectedEdge[60, 196] -> 
             RGBColor[
              0.7415850863279896, 0.7924581448943686, 0.7366883651499383], 
             UndirectedEdge[25, 297] -> 
             RGBColor[
              0.6487068873108903, 0.7246665923915967, 0.9661864133623662], 
             UndirectedEdge[9, 133] -> 
             RGBColor[
              0.46245588257208486`, 0.5734397589225184, 0.9511132161115575], 
             UndirectedEdge[151, 192] -> 
             RGBColor[
              0.6133721122329082, 0.6930331026569992, 0.964908873368044], 
             UndirectedEdge[45, 141] -> 
             RGBColor[
              0.6354829148840915, 0.7132338721754046, 0.9656218506551534], 
             UndirectedEdge[177, 280] -> 
             RGBColor[
              0.7327955595308666, 0.7906258008933054, 0.974668435801866], 
             UndirectedEdge[141, 188] -> 
             RGBColor[
              0.5880202683772091, 0.6738370320913956, 0.9621242882272228], 
             UndirectedEdge[129, 183] -> 
             RGBColor[
              0.7819671609023009, 0.8302894531307579, 0.9780669160439938], 
             UndirectedEdge[41, 55] -> 
             RGBColor[
              0.5056099786082365, 0.6059798757721544, 0.9553822907655133], 
             UndirectedEdge[120, 261] -> 
             RGBColor[
              0.5525217256702243, 0.6476010535760003, 0.9579156806799809], 
             UndirectedEdge[71, 279] -> 
             RGBColor[
              0.5347405718954918, 0.6308045306053196, 0.9574106438428018], 
             UndirectedEdge[180, 230] -> 
             RGBColor[
              0.41063315706868514`, 0.5294114932548307, 0.9475740569630648], 
             UndirectedEdge[106, 194] -> 
             RGBColor[
              0.8173084079193388, 0.8577644834653051, 0.9630628272106097], 
             UndirectedEdge[90, 234] -> 
             RGBColor[
              0.6325634280694139, 0.7086182148065647, 0.9666087205162189], 
             UndirectedEdge[44, 136] -> 
             RGBColor[
              0.6325064287889157, 0.7117243032462941, 0.9647674943012456], 
             UndirectedEdge[120, 131] -> 
             RGBColor[
              0.5415785696517812, 0.6387169065366676, 0.9570541953521077], 
             UndirectedEdge[44, 279] -> 
             RGBColor[
              0.6882818937726314, 0.7564103136420992, 0.969565164877414], 
             UndirectedEdge[105, 139] -> 
             RGBColor[
              0.6677981764491634, 0.7380915292072454, 0.9692828126654185], 
             UndirectedEdge[157, 184] -> 
             RGBColor[
              0.5200407892272751, 0.6212315661221024, 0.9553586623816014], 
             UndirectedEdge[83, 149] -> 
             RGBColor[
              0.7924194243450524, 0.8381232232476201, 0.9798491198172268], 
             UndirectedEdge[145, 168] -> 
             RGBColor[
              0.5415830127702406, 0.6387205136603931, 0.9570545451306686], 
             UndirectedEdge[112, 170] -> 
             RGBColor[
              0.5414677159445462, 0.6386269105032316, 0.9570454685422037], 
             UndirectedEdge[159, 270] -> 
             RGBColor[
              0.7256447749205359, 0.785252432356317, 0.973608321173935], 
             UndirectedEdge[86, 162] -> 
             RGBColor[
              0.627505375079508, 0.7055690781707826, 0.965684805662285], 
             UndirectedEdge[3, 264] -> 
             RGBColor[
              0.8080482126718662, 0.8504104899639378, 0.9560726350838198], 
             UndirectedEdge[60, 282] -> 
             RGBColor[
              0.5037926966108007, 0.6080406325678176, 0.9540795530121082], 
             UndirectedEdge[135, 186] -> 
             RGBColor[
              0.6500438785493781, 0.7259616722954766, 0.9661483272332481], 
             UndirectedEdge[89, 294] -> 
             RGBColor[
              0.4667446732133444, 0.5567915535027732, 0.9548361904859624], 
             UndirectedEdge[201, 203] -> 
             RGBColor[
              0.7119568966761887, 0.7686419401139146, 0.8076735181724178], 
             UndirectedEdge[181, 203] -> 
             RGBColor[
              0.9160580078370244, 0.9321484922566529, 0.8255654776398902], 
             UndirectedEdge[70, 211] -> 
             RGBColor[
              0.5389955439164787, 0.6259918321957005, 0.960017806433799], 
             UndirectedEdge[156, 159] -> 
             RGBColor[
              0.5394803763319065, 0.6370134986770613, 0.9568890178880318], 
             UndirectedEdge[56, 270] -> 
             RGBColor[
              0.7659750037951953, 0.8173021592903182, 0.9772565047450393], 
             UndirectedEdge[113, 264] -> 
             RGBColor[
              0.9737106814043506, 0.9799140497529488, 0.9293851384167297], 
             UndirectedEdge[144, 240] -> 
             RGBColor[
              0.5534193099619975, 0.6483297529397734, 0.9579863418033889], 
             UndirectedEdge[231, 232] -> 
             RGBColor[
              0.4166586956414253, 0.5353105531148142, 0.9477701015428217], 
             UndirectedEdge[90, 248] -> 
             RGBColor[
              0.811465011919268, 0.8528819556022009, 0.981779203975069], 
             UndirectedEdge[27, 109] -> 
             RGBColor[
              0.5908909125189754, 0.6776121438158061, 0.9617148092185088], 
             UndirectedEdge[42, 145] -> 
             RGBColor[
              0.4492418643743426, 0.5566188216991532, 0.9511618807682285], 
             UndirectedEdge[160, 230] -> 
             RGBColor[
              0.6619034395768377, 0.7283528958568571, 0.9301396211383136], 
             UndirectedEdge[247, 251] -> 
             RGBColor[
              0.8701526033883864, 0.8993000825514379, 0.9874771261772253], 
             UndirectedEdge[109, 220] -> 
             RGBColor[
              0.5798863735156686, 0.6690153143088288, 0.9606179796139231], 
             UndirectedEdge[139, 163] -> 
             RGBColor[
              0.7669937286196677, 0.8183196370202095, 0.9772992247021073], 
             UndirectedEdge[31, 279] -> 
             RGBColor[
              0.8117121847617719, 0.8536547820023315, 0.9757730436824509], 
             UndirectedEdge[9, 112] -> 
             RGBColor[
              0.4904400547847485, 0.5972003564037691, 0.9530283841352227], 
             UndirectedEdge[196, 276] -> 
             RGBColor[
              0.745587843613453, 0.7957077635808685, 0.7370034768660331], 
             UndirectedEdge[137, 251] -> 
             RGBColor[
              0.885460335589392, 0.9115060526911983, 0.988937191339931], 
             UndirectedEdge[162, 181] -> 
             RGBColor[
              0.8250334473363873, 0.863382394385455, 0.9831579369031073], 
             UndirectedEdge[96, 236] -> 
             RGBColor[
              0.4177027935533446, 0.5362148982482318, 0.9478366305385095], 
             UndirectedEdge[251, 295] -> 
             RGBColor[
              0.6608553832371407, 0.7322272136197325, 0.968823969471754], 
             UndirectedEdge[20, 268] -> 
             RGBColor[
              0.5441348570276159, 0.6407377255491906, 0.9572704914736053], 
             UndirectedEdge[187, 215] -> 
             RGBColor[
              0.8974678218027276, 0.9208241163295661, 0.9811936228521381], 
             UndirectedEdge[55, 250] -> 
             RGBColor[
              0.41042371264935607`, 0.5291516742658362, 0.9475823759238642], 
             UndirectedEdge[193, 230] -> 
             RGBColor[
              0.3975333456800108, 0.518745136246276, 0.9465514511551633], 
             UndirectedEdge[55, 242] -> 
             RGBColor[
              0.6516213992722264, 0.720485588703428, 0.9446404604949585], 
             UndirectedEdge[51, 116] -> 
             RGBColor[
              0.659218598501258, 0.7324049510195862, 0.9675578365525275], 
             UndirectedEdge[130, 203] -> 
             RGBColor[
              0.874426464663576, 0.8994848865690597, 0.8214533793028669], 
             UndirectedEdge[34, 124] -> 
             RGBColor[
              0.8980729906940939, 0.9185596405860756, 0.8643403865517776], 
             UndirectedEdge[190, 261] -> 
             RGBColor[
              0.5487190991181935, 0.6445139100346877, 0.9576163239883251], 
             UndirectedEdge[76, 85] -> 
             RGBColor[
              0.6186390988259288, 0.696334576822634, 0.9658241723196231], 
             UndirectedEdge[130, 237] -> 
             RGBColor[
              0.6991854142979756, 0.7649282267463235, 0.9706519259041877], 
             UndirectedEdge[175, 183] -> 
             RGBColor[
              0.7124076706424913, 0.7750284740902798, 0.9721264199615668], 
             UndirectedEdge[93, 289] -> 
             RGBColor[
              0.9253341389191734, 0.9424788243274425, 0.9642578873606948], 
             UndirectedEdge[69, 234] -> 
             RGBColor[
              0.5249420282731214, 0.6241822145138582, 0.9560286553775686], 
             UndirectedEdge[32, 269] -> 
             RGBColor[
              0.7795569038183199, 0.8282505184825455, 0.9785205067218864], 
             UndirectedEdge[226, 243] -> 
             RGBColor[
              0.8460993809797537, 0.8802408318142767, 0.9651539788417718], 
             UndirectedEdge[72, 218] -> 
             RGBColor[
              0.7331781457425195, 0.7914587506970105, 0.9740973401770985], 
             UndirectedEdge[81, 181] -> 
             RGBColor[
              0.7772409531951736, 0.8260465347259303, 0.9783944277333617], 
             UndirectedEdge[8, 67] -> 
             RGBColor[
              0.6777121880145105, 0.744987760705956, 0.970745109407764], 
             UndirectedEdge[145, 156] -> 
             RGBColor[
              0.5443243852879253, 0.6409460833676741, 0.9572703560172391], 
             UndirectedEdge[20, 177] -> 
             RGBColor[
              0.5064002947639695, 0.6101031079809047, 0.954299888505955], 
             UndirectedEdge[180, 297] -> 
             RGBColor[
              0.5937160794111831, 0.6800225772309496, 0.9618573355265345], 
             UndirectedEdge[140, 216] -> 
             RGBColor[
              0.6310669320338697, 0.7088881574171219, 0.9657942490015697], 
             UndirectedEdge[287, 300] -> 
             RGBColor[
              0.8121608435708425, 0.853669369280426, 0.9588141339067632], 
             UndirectedEdge[140, 167] -> 
             RGBColor[
              0.42291762437119773`, 0.5406068083071612, 0.9482034291375705], 
             UndirectedEdge[248, 285] -> 
             RGBColor[
              0.6413357819105518, 0.717699282797388, 0.96627829346837], 
             UndirectedEdge[185, 292] -> 
             RGBColor[
              0.5632340977282527, 0.6562978397995693, 0.9587589978491007], 
             UndirectedEdge[23, 241] -> 
             RGBColor[
              0.4241423742143478, 0.5414310823033645, 0.9483468265839996], 
             UndirectedEdge[10, 48] -> 
             RGBColor[
              0.6152492549961297, 0.6972265332240393, 0.9637423340773734], 
             UndirectedEdge[46, 62] -> 
             RGBColor[
              0.8490638022046691, 0.8824844449278003, 0.9854656574941272], 
             UndirectedEdge[15, 276] -> 
             RGBColor[
              0.6939140946087894, 0.5983511304933584, 0.5917786020810317], 
             UndirectedEdge[85, 154] -> 
             RGBColor[
              0.6679566283003677, 0.7351663138310582, 0.9534451306559684], 
             UndirectedEdge[32, 179] -> 
             RGBColor[
              0.6861630205249813, 0.7528966980596041, 0.9708485375202414], 
             UndirectedEdge[145, 277] -> 
             RGBColor[
              0.7356058602718056, 0.7932652348651643, 0.9744777306177894], 
             UndirectedEdge[58, 164] -> 
             RGBColor[
              0.5697319035614257, 0.6611097779050803, 0.9595872714752754], 
             UndirectedEdge[18, 253] -> 
             RGBColor[
              0.479300419510563, 0.5878802292512962, 0.9522278205601347], 
             UndirectedEdge[59, 136] -> 
             RGBColor[
              0.5572293962381181, 0.6514229526211588, 0.958286285751851], 
             UndirectedEdge[232, 288] -> 
             RGBColor[
              0.424375291847904, 0.5419942809014635, 0.9482617962295803], 
             UndirectedEdge[136, 177] -> 
             RGBColor[
              0.5655702307510853, 0.6581944178290984, 0.9589429067981954], 
             UndirectedEdge[31, 65] -> 
             RGBColor[
              0.968290910801461, 0.974182815785576, 0.8629145576348614], 
             UndirectedEdge[62, 214] -> 
             RGBColor[
              0.9154209046300684, 0.9344707840241324, 0.9597240701495617], 
             UndirectedEdge[24, 109] -> 
             RGBColor[
              0.5428785231053077, 0.639772267312476, 0.9571565324498558], 
             UndirectedEdge[71, 268] -> 
             RGBColor[
              0.5126188616001508, 0.6134401543499086, 0.9552623201134678], 
             UndirectedEdge[64, 118] -> 
             RGBColor[
              0.679281922708824, 0.7493794678447394, 0.9686681318712851], 
             UndirectedEdge[21, 206] -> 
             RGBColor[
              0.668802074146785, 0.7411925304982756, 0.9676235985063739], 
             UndirectedEdge[6, 124] -> 
             RGBColor[
              0.7627608378791665, 0.8111536477604299, 0.8520154269447926], 
             UndirectedEdge[7, 140] -> 
             RGBColor[
              0.6403640152259125, 0.7161739471989415, 0.9667148349361607], 
             UndirectedEdge[78, 229] -> 
             RGBColor[
              0.4981997445320008, 0.6035000221106279, 0.9536392553368065], 
             UndirectedEdge[67, 213] -> 
             RGBColor[
              0.7488532937081411, 0.80348024065816, 0.9761419831406768], 
             UndirectedEdge[189, 300] -> 
             RGBColor[
              0.6607480834990763, 0.7349006917916894, 0.9668208519874322], 
             UndirectedEdge[77, 225] -> 
             RGBColor[
              0.9284874950722206, 0.9450482736448267, 0.9664672308443105], 
             UndirectedEdge[153, 239] -> 
             RGBColor[
              0.7314031911324078, 0.7900969988735548, 0.9738630928068017], 
             UndirectedEdge[7, 168] -> 
             RGBColor[
              0.6447022227506269, 0.7196958995015266, 0.9670563545238842], 
             UndirectedEdge[5, 256] -> 
             RGBColor[
              0.5569480682004903, 0.6511850761183164, 0.9582706212875536], 
             UndirectedEdge[193, 200] -> 
             RGBColor[
              0.5833166103251651, 0.6714657481525919, 0.9611038746032281], 
             UndirectedEdge[17, 202] -> 
             RGBColor[
              0.6650843280052521, 0.7369338408302826, 0.9681790303630846], 
             UndirectedEdge[12, 220] -> 
             RGBColor[
              0.7630020875577348, 0.8148739014317374, 0.9769882664735732], 
             UndirectedEdge[196, 207] -> 
             RGBColor[
              0.7975787713715479, 0.8379163408994943, 0.741096393148194], 
             UndirectedEdge[222, 285] -> 
             RGBColor[
              0.6294924245967657, 0.7084471620510089, 0.9650978582937986], 
             UndirectedEdge[169, 227] -> 
             RGBColor[
              0.785498078930674, 0.6641824245837088, 0.5978431288226933], 
             UndirectedEdge[139, 298] -> 
             RGBColor[
              0.682351938934563, 0.7499069292324212, 0.9704285381604578], 
             UndirectedEdge[210, 241] -> 
             RGBColor[
              0.5124605525650096, 0.6131178557859451, 0.9553090622446205], 
             UndirectedEdge[58, 288] -> 
             RGBColor[
              0.559702782389183, 0.6527908224760843, 0.9588466101076675], 
             UndirectedEdge[85, 258] -> 
             RGBColor[
              0.5322461166268013, 0.6285512352565821, 0.957290944368274], 
             UndirectedEdge[87, 162] -> 
             RGBColor[
              0.6293206121739338, 0.7071413453055051, 0.9658004709647907], 
             UndirectedEdge[222, 248] -> 
             RGBColor[
              0.7614026919783408, 0.8135328369390487, 0.9768531626898497], 
             UndirectedEdge[76, 87] -> 
             RGBColor[
              0.6510703089477354, 0.7244248609901267, 0.9678906603507915], 
             UndirectedEdge[80, 282] -> 
             RGBColor[
              0.6929710478375715, 0.7585546120173117, 0.9712338836278431], 
             UndirectedEdge[273, 289] -> 
             RGBColor[
              0.7042947757946286, 0.7658733342062501, 0.9445629021797326], 
             UndirectedEdge[215, 296] -> 
             RGBColor[
              0.7358920064484588, 0.7925826727538698, 0.9663693120771035], 
             UndirectedEdge[142, 277] -> 
             RGBColor[
              0.7320675140356674, 0.7903926459899859, 0.9741991790406913], 
             UndirectedEdge[134, 180] -> 
             RGBColor[
              0.6521865774457065, 0.7257488786596702, 0.9676722037961113], 
             UndirectedEdge[86, 178] -> 
             RGBColor[
              0.5522489773278887, 0.6467782082774107, 0.9581839512454254], 
             UndirectedEdge[3, 210] -> 
             RGBColor[
              0.6477830079226232, 0.7247722762131403, 0.9655286144194912], 
             UndirectedEdge[79, 176] -> 
             RGBColor[
              0.6428920845261263, 0.7206453963199231, 0.9652503832397274], 
             UndirectedEdge[131, 141] -> 
             RGBColor[
              0.6171615548612003, 0.6983597667409582, 0.9641795260807983], 
             UndirectedEdge[150, 256] -> 
             RGBColor[
              0.6224376166563014, 0.702346009110999, 0.9647980074430029], 
             UndirectedEdge[74, 300] -> 
             RGBColor[
              0.6116473982886129, 0.6952838086963604, 0.9627877770844248], 
             UndirectedEdge[25, 230] -> 
             RGBColor[
              0.46562396496839237`, 0.5740555084154777, 0.9519031347988965], 
             UndirectedEdge[165, 253] -> 
             RGBColor[
              0.5782290602656492, 0.6684714259027922, 0.9599394562284023], 
             UndirectedEdge[223, 295] -> 
             RGBColor[
              0.7201938499711251, 0.7755837792151047, 0.7917374692869756], 
             UndirectedEdge[164, 221] -> 
             RGBColor[
              0.7247747652148702, 0.7656602173337572, 0.6692075196865959], 
             UndirectedEdge[70, 138] -> 
             RGBColor[
              0.7092411352708003, 0.7723489117789438, 0.9719515437963171], 
             UndirectedEdge[165, 224] -> 
             RGBColor[
              0.5405049038662592, 0.6374840943152494, 0.9570694625765217], 
             UndirectedEdge[87, 258] -> 
             RGBColor[
              0.564677326748608, 0.6566415194240749, 0.9593574323994425], 
             UndirectedEdge[90, 222] -> 
             RGBColor[
              0.7996216546054817, 0.8436298348558218, 0.9805987688004975], 
             UndirectedEdge[163, 185] -> 
             RGBColor[
              0.5796082897721421, 0.6692878364019925, 0.9602554090319838], 
             UndirectedEdge[64, 286] -> 
             RGBColor[
              0.8218199748213443, 0.8571117105086986, 0.7139619884673101], 
             UndirectedEdge[131, 199] -> 
             RGBColor[
              0.6856583794394249, 0.7524484964921494, 0.9708531360107332], 
             UndirectedEdge[2, 49] -> 
             RGBColor[
              0.8121507122812397, 0.8277947104647232, 0.6632091621893982], 
             UndirectedEdge[51, 283] -> 
             RGBColor[
              0.7115350082118979, 0.7736438912439405, 0.9726743358222614], 
             UndirectedEdge[66, 187] -> 
             RGBColor[
              0.6313930374747692, 0.7076178739553378, 0.9665279788871237], 
             UndirectedEdge[120, 170] -> 
             RGBColor[
              0.6077068173940807, 0.6924027970974782, 0.9622600532501346], 
             UndirectedEdge[17, 182] -> 
             RGBColor[
              0.7659713730392985, 0.817101925307131, 0.977308526121254], 
             UndirectedEdge[156, 179] -> 
             RGBColor[
              0.4790848993465815, 0.5879817296751422, 0.9521344647038252], 
             UndirectedEdge[199, 284] -> 
             RGBColor[
              0.921918204163301, 0.9401489784912163, 0.9775897970910876], 
             UndirectedEdge[210, 291] -> 
             RGBColor[
              0.6577333220212053, 0.7325455372121408, 0.9665203687378658], 
             UndirectedEdge[212, 265] -> 
             RGBColor[
              0.5419231333903471, 0.6389966389020548, 0.9570813206717863], 
             UndirectedEdge[85, 173] -> 
             RGBColor[
              0.685375557029678, 0.7472515360549102, 0.883396466686406], 
             UndirectedEdge[47, 146] -> 
             RGBColor[
              0.6689274044903465, 0.7362734771814505, 0.9573938577838121], 
             UndirectedEdge[198, 283] -> 
             RGBColor[
              0.7839799065738249, 0.831539291913189, 0.9790055369190841], 
             UndirectedEdge[168, 212] -> 
             RGBColor[
              0.46831772077719497`, 0.5792404490566473, 0.9512868329653685], 
             UndirectedEdge[56, 271] -> 
             RGBColor[
              0.6133309160146015, 0.6962765239978193, 0.963176043114889], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.7410585517853896, 0.7977314445093326, 0.9748011399017866], 
             UndirectedEdge[159, 191] -> 
             RGBColor[
              0.750931384911292, 0.8054152887762027, 0.9760201806084767], 
             UndirectedEdge[72, 83] -> 
             RGBColor[
              0.7761224672363076, 0.8251284720182233, 0.9782947014997294], 
             UndirectedEdge[179, 277] -> 
             RGBColor[
              0.6703663743304619, 0.7403008811726324, 0.9693418393043756], 
             UndirectedEdge[86, 182] -> 
             RGBColor[
              0.5990300730394824, 0.6833239557968036, 0.9628466536717621], 
             UndirectedEdge[80, 293] -> 
             RGBColor[
              0.7034562826299454, 0.7670669979762053, 0.9720593197193794], 
             UndirectedEdge[9, 96] -> 
             RGBColor[
              0.4514019601476076, 0.5638654069047315, 0.9504088699492697], 
             UndirectedEdge[51, 226] -> 
             RGBColor[
              0.6458700878739834, 0.7219769930651212, 0.9662273817621247], 
             UndirectedEdge[185, 235] -> 
             RGBColor[
              0.635072711989615, 0.7126170645835039, 0.9657835842941268], 
             UndirectedEdge[136, 210] -> 
             RGBColor[
              0.6064587903301988, 0.69137569011296, 0.9621713091287016], 
             UndirectedEdge[78, 284] -> 
             RGBColor[
              0.7332913565601987, 0.7902520964159612, 0.9602839504344531], 
             UndirectedEdge[81, 216] -> 
             RGBColor[
              0.7606510673791699, 0.8129456620896178, 0.9767782477741356], 
             UndirectedEdge[2, 165] -> 
             RGBColor[
              0.8084401683488577, 0.8248750818916271, 0.6628536353255883], 
             UndirectedEdge[181, 216] -> 
             RGBColor[
              0.8208052524807506, 0.8600792964287607, 0.9827365099546248], 
             UndirectedEdge[7, 203] -> 
             RGBColor[
              0.9087652052130635, 0.9263334094021601, 0.824869883615255], 
             UndirectedEdge[44, 177] -> 
             RGBColor[
              0.6284256212136441, 0.7084113198184023, 0.9644462381804295], 
             UndirectedEdge[140, 237] -> 
             RGBColor[
              0.5510786370245433, 0.6464006934222779, 0.9578217632881559], 
             UndirectedEdge[38, 124] -> 
             RGBColor[
              0.9314448748752213, 0.9450246511924052, 0.8675618584888403], 
             UndirectedEdge[5, 59] -> 
             RGBColor[
              0.593892858721039, 0.6811785214067442, 0.961179050530558], 
             UndirectedEdge[35, 253] -> 
             RGBColor[
              0.7480628099702846, 0.801307018240773, 0.936309567805004], 
             UndirectedEdge[200, 231] -> 
             RGBColor[
              0.5729202626331521, 0.6624609543173985, 0.9604414285214224], 
             UndirectedEdge[213, 234] -> 
             RGBColor[
              0.4919513467024782, 0.5973988930015421, 0.953431508075479], 
             UndirectedEdge[53, 88] -> 
             RGBColor[
              0.7070101999737414, 0.7702023081949221, 0.9720512595983657], 
             UndirectedEdge[150, 269] -> 
             RGBColor[
              0.7234184839979352, 0.7838592849740829, 0.973067251820968], 
             UndirectedEdge[4, 135] -> 
             RGBColor[
              0.7344031288277535, 0.792220344180524, 0.9744618423795959], 
             UndirectedEdge[91, 139] -> 
             RGBColor[
              0.7094863322294677, 0.7719358520997124, 0.9725646569971904], 
             UndirectedEdge[28, 232] -> 
             RGBColor[
              0.690746200985121, 0.753416757020616, 0.9331699795758746], 
             UndirectedEdge[127, 276] -> 
             RGBColor[
              0.6171646819238024, 0.6986385425775408, 0.9639909074090336], 
             UndirectedEdge[60, 103] -> 
             RGBColor[
              0.6356536463968013, 0.7129596278721683, 0.9659175603207324], 
             UndirectedEdge[145, 159] -> 
             RGBColor[
              0.611727104132041, 0.6956666469832079, 0.9625765449489424], 
             UndirectedEdge[20, 252] -> 
             RGBColor[
              0.7231757834479313, 0.7785625123765545, 0.8257672582496666], 
             UndirectedEdge[80, 128] -> 
             RGBColor[
              0.8623764073410927, 0.8930995549025444, 0.9867354256563422], 
             UndirectedEdge[167, 237] -> 
             RGBColor[
              0.5160777639927485, 0.6162096106876437, 0.9555570244179856], 
             UndirectedEdge[24, 291] -> 
             RGBColor[
              0.6464355349743438, 0.7233873871190725, 0.9656214604156698], 
             UndirectedEdge[22, 244] -> 
             RGBColor[
              0.4428536290107362, 0.5578321059648635, 0.9494854123740272], 
             UndirectedEdge[51, 83] -> 
             RGBColor[
              0.6388834502080774, 0.7165189786201024, 0.9655310190134283], 
             UndirectedEdge[29, 229] -> 
             RGBColor[
              0.4669184717576119, 0.5780616226104474, 0.9511885193841626], 
             UndirectedEdge[151, 181] -> 
             RGBColor[
              0.8284999670231503, 0.8660904659112798, 0.9835034471890155], 
             UndirectedEdge[22, 63] -> 
             RGBColor[
              0.6140109734052592, 0.6955877592792623, 0.9640779665470782], 
             UndirectedEdge[163, 292] -> 
             RGBColor[
              0.6457847688288921, 0.72301288331667, 0.9654650638757614], 
             UndirectedEdge[247, 289] -> 
             RGBColor[
              0.9160601961260696, 0.9350840340786926, 0.9633733304181422], 
             UndirectedEdge[155, 299] -> 
             RGBColor[
              0.7217636829557258, 0.2993670255248746, 0.4282100327781475], 
             UndirectedEdge[31, 71] -> 
             RGBColor[
              0.6652507883634754, 0.7335798905590507, 0.9643241834539047], 
             UndirectedEdge[45, 260] -> 
             RGBColor[
              0.5537165328944695, 0.6485710519060945, 0.9580097402813965], 
             UndirectedEdge[80, 125] -> 
             RGBColor[
              0.9170144583241657, 0.9358882186618507, 0.9649649562921716], 
             UndirectedEdge[97, 261] -> 
             RGBColor[
              0.5142420689156804, 0.6165239037437767, 0.9549021658772603], 
             UndirectedEdge[107, 147] -> 
             RGBColor[
              0.6222763171063282, 0.7008000066145748, 0.9654531620724224], 
             UndirectedEdge[15, 286] -> 
             RGBColor[
              0.9414344386886299, 0.790310802194583, 0.34602207084448156`], 
             UndirectedEdge[94, 202] -> 
             RGBColor[
              0.6192030250932289, 0.7010910182845926, 0.9636060108739672], 
             UndirectedEdge[86, 130] -> 
             RGBColor[
              0.5982355228664266, 0.6827032471628074, 0.9627674603360055], 
             UndirectedEdge[73, 161] -> 
             RGBColor[
              0.5932005910207241, 0.6804052262660052, 0.9612690066790881], 
             UndirectedEdge[7, 167] -> 
             RGBColor[
              0.6053631421941177, 0.6859828644643073, 0.9644500960659905], 
             UndirectedEdge[288, 297] -> 
             RGBColor[
              0.5779365165369743, 0.6670351541738511, 0.9606639783235859], 
             UndirectedEdge[15, 46] -> 
             RGBColor[
              0.8644421377395768, 0.7339359318372188, 0.6072207245083417], 
             UndirectedEdge[1, 92] -> 
             RGBColor[
              0.5447225912135772, 0.6228950860160583, 0.9617392385411243], 
             UndirectedEdge[85, 213] -> 
             RGBColor[
              0.4747834297703859, 0.5825289062395582, 0.952337583589559], 
             UndirectedEdge[2, 174] -> 
             RGBColor[
              0.8254994248388241, 0.8382228261686812, 0.664539637106327], 
             UndirectedEdge[104, 204] -> 
             RGBColor[
              0.969818083793243, 0.9769797202024864, 0.9345754509038655], 
             UndirectedEdge[125, 243] -> 
             RGBColor[
              0.9618868667426764, 0.9710958681379918, 0.9493997724941879], 
             UndirectedEdge[149, 243] -> 
             RGBColor[
              0.9112023497174996, 0.9314596450408916, 0.9715473334566241], 
             UndirectedEdge[35, 175] -> 
             RGBColor[
              0.8890356006300466, 0.9133798880562689, 0.9490313942979425], 
             UndirectedEdge[82, 201] -> 
             RGBColor[
              0.46179825852052075`, 0.5732926033050887, 0.9509545899981673], 
             UndirectedEdge[39, 69] -> 
             RGBColor[
              0.5178888042065761, 0.618073066332766, 0.9555792301769696], 
             UndirectedEdge[5, 204] -> 
             RGBColor[
              0.7991170564249305, 0.843584614473186, 0.9628367697984146], 
             UndirectedEdge[107, 277] -> 
             RGBColor[
              0.8364807441985138, 0.872464498403908, 0.9842619069962033], 
             UndirectedEdge[236, 260] -> 
             RGBColor[
              0.5167965928598173, 0.6183057742764966, 0.9551839497873272], 
             UndirectedEdge[11, 51] -> 
             RGBColor[
              0.5454990538344178, 0.6418997322119316, 0.9573628302281716], 
             UndirectedEdge[41, 242] -> 
             RGBColor[
              0.8176350822560237, 0.8579024889866365, 0.957162997703128], 
             UndirectedEdge[53, 93] -> 
             RGBColor[
              0.7317707061252625, 0.7899456636941102, 0.9744129387790625], 
             UndirectedEdge[82, 293] -> 
             RGBColor[
              0.5165826572382882, 0.6184240987863721, 0.9550864255638735], 
             UndirectedEdge[76, 151] -> 
             RGBColor[
              0.8378879728365849, 0.8735762069162833, 0.9843988835642726], 
             UndirectedEdge[130, 269] -> 
             RGBColor[
              0.7135059798709533, 0.7761155614122631, 0.9720792660472082], 
             UndirectedEdge[13, 289] -> 
             RGBColor[
              0.8225097676699821, 0.8616414055567977, 0.9541447165809465], 
             UndirectedEdge[86, 120] -> 
             RGBColor[
              0.5228676848954232, 0.6232284616163466, 0.9556635734733749], 
             UndirectedEdge[86, 284] -> 
             RGBColor[
              0.6973097032632298, 0.7607424635551161, 0.9575337103912938], 
             UndirectedEdge[49, 102] -> 
             RGBColor[
              0.5842412236495619, 0.6732596128334155, 0.9604761750065465], 
             UndirectedEdge[27, 299] -> 
             RGBColor[
              0.6236743979674152, 0.7042272541820387, 0.9642956452828741], 
             UndirectedEdge[120, 182] -> 
             RGBColor[
              0.6795587641519099, 0.7489988807774219, 0.9691037997129307], 
             UndirectedEdge[97, 182] -> 
             RGBColor[
              0.6412791073973659, 0.7179217309451984, 0.96609028491021], 
             UndirectedEdge[42, 130] -> 
             RGBColor[
              0.5180223338052414, 0.6107456847071862, 0.9577471858490558], 
             UndirectedEdge[15, 127] -> 
             RGBColor[
              0.8132791125659333, 0.6938144543866402, 0.6021617499609061], 
             UndirectedEdge[28, 176] -> 
             RGBColor[
              0.8214751468446293, 0.8606208805396034, 0.9432964534959262], 
             UndirectedEdge[26, 35] -> 
             RGBColor[
              0.7817080201267796, 0.8286217155452603, 0.938958241994989], 
             UndirectedEdge[44, 59] -> 
             RGBColor[
              0.6200847867006769, 0.7016398546104627, 0.9637896171340852], 
             UndirectedEdge[155, 218] -> 
             RGBColor[
              0.7563597249846081, 0.32745365097785367`, 0.4309335599361387], 
             UndirectedEdge[65, 155] -> 
             RGBColor[
              0.8763324734577222, 0.4200631632050299, 0.35719284399205636`], 
             UndirectedEdge[55, 252] -> 
             RGBColor[
              0.6673183480840883, 0.7301816093407258, 0.8222080718610731], 
             UndirectedEdge[160, 296] -> 
             RGBColor[
              0.7535234259214101, 0.8057321565279973, 0.936523917920077], 
             UndirectedEdge[88, 147] -> 
             RGBColor[
              0.6299112674143423, 0.7068744663727745, 0.9661849576408696], 
             UndirectedEdge[204, 243] -> 
             RGBColor[
              0.9565759091219785, 0.9671349646403702, 0.9583898384264382], 
             UndirectedEdge[65, 106] -> 
             RGBColor[
              0.9756932334190433, 0.979703455873578, 0.8503843562782354], 
             UndirectedEdge[115, 245] -> 
             RGBColor[
              0.6914620496221711, 0.757784783519138, 0.9706409723435206], 
             UndirectedEdge[60, 205] -> 
             RGBColor[
              0.7424303571474673, 0.794451946680325, 0.8422004266226738], 
             UndirectedEdge[75, 111] -> 
             RGBColor[
              0.7202398014858019, 0.7813760740367226, 0.9727504304546355], 
             UndirectedEdge[17, 86] -> 
             RGBColor[
              0.6092802937828119, 0.6913315061460557, 0.9638682998816983], 
             UndirectedEdge[67, 166] -> 
             RGBColor[
              0.9092124376094941, 0.9304453341083939, 0.9912026880343602], 
             UndirectedEdge[3, 169] -> 
             RGBColor[
              0.7690549021404387, 0.6513368899024048, 0.5962042266304662], 
             UndirectedEdge[7, 255] -> 
             RGBColor[
              0.8553211939675084, 0.8874739192671137, 0.9860624931065064], 
             UndirectedEdge[211, 231] -> 
             RGBColor[
              0.35242372826020507`, 0.4764125355090326, 0.9437965043821828], 
             UndirectedEdge[218, 290] -> 
             RGBColor[
              0.5588351309052937, 0.6527265603614942, 0.958412695066851], 
             UndirectedEdge[201, 269] -> 
             RGBColor[
              0.551036411883566, 0.645272614957118, 0.9582994049167592], 
             UndirectedEdge[34, 223] -> 
             RGBColor[
              0.8982421493570492, 0.9178844309419372, 0.8073716442011758], 
             UndirectedEdge[63, 208] -> 
             RGBColor[
              0.5895195665929096, 0.6745417155111186, 0.9624712029217128], 
             UndirectedEdge[131, 190] -> 
             RGBColor[
              0.5377759430997504, 0.6356297629953549, 0.9567548386604519], 
             UndirectedEdge[27, 181] -> 
             RGBColor[
              0.7770454426822038, 0.8258938004272632, 0.9783749410725785], 
             UndirectedEdge[108, 136] -> 
             RGBColor[
              0.5991256258852138, 0.6854361992523079, 0.9615845104206164], 
             UndirectedEdge[101, 254] -> 
             RGBColor[
              0.6441323791399629, 0.7190764367682645, 0.9671443505807689], 
             UndirectedEdge[62, 212] -> 
             RGBColor[
              0.6646561916415368, 0.735631585474975, 0.9689308846760123], 
             UndirectedEdge[69, 195] -> 
             RGBColor[
              0.789119381081105, 0.8358559330066779, 0.9721924420572243], 
             UndirectedEdge[136, 252] -> 
             RGBColor[
              0.7823457194350472, 0.8266538222247479, 0.8304102765419069], 
             UndirectedEdge[26, 175] -> 
             RGBColor[
              0.6900829956278097, 0.756904297198213, 0.9703689397664319], 
             UndirectedEdge[24, 27] -> 
             RGBColor[
              0.6686833576539852, 0.7407675552861234, 0.9678389154626528], 
             UndirectedEdge[231, 266] -> 
             RGBColor[
              0.4703982958094093, 0.5803336431844942, 0.9516152752756928], 
             UndirectedEdge[153, 157] -> 
             RGBColor[
              0.6142105085077868, 0.6969338397124922, 0.9632841066689609], 
             UndirectedEdge[161, 244] -> 
             RGBColor[
              0.47793147975184347`, 0.5863098854356621, 0.9522468692787682], 
             UndirectedEdge[128, 150] -> 
             RGBColor[
              0.8152795115183664, 0.855917787204184, 0.9821445593857843], 
             UndirectedEdge[113, 200] -> 
             RGBColor[
              0.8490469295763186, 0.8820879616052649, 0.9423895378650942], 
             UndirectedEdge[211, 264] -> 
             RGBColor[
              0.6186366656315476, 0.6886458995144751, 0.9425259719761739], 
             UndirectedEdge[144, 232] -> 
             RGBColor[
              0.4701625611522331, 0.5793433118703031, 0.9518174700045587], 
             UndirectedEdge[208, 244] -> 
             RGBColor[
              0.4183622221983867, 0.5367860621967198, 0.9478786487486619], 
             UndirectedEdge[47, 133] -> 
             RGBColor[
              0.6826651167210046, 0.7481723930381533, 0.9582692126593677], 
             UndirectedEdge[181, 258] -> 
             RGBColor[
              0.7603901619110616, 0.8128825685040247, 0.9767148983377592], 
             UndirectedEdge[53, 147] -> 
             RGBColor[
              0.5033306858305793, 0.6069300962999887, 0.9542463902673632], 
             UndirectedEdge[123, 267] -> 
             RGBColor[
              0.7000397777513283, 0.7642692592963048, 0.9718180595887758], 
             UndirectedEdge[59, 227] -> 
             RGBColor[
              0.6149967906207778, 0.6976650734026432, 0.9632824932348676], 
             UndirectedEdge[213, 286] -> 
             RGBColor[
              0.7806500819694386, 0.8238174359978185, 0.710632541130148], 
             UndirectedEdge[16, 126] -> 
             RGBColor[
              0.955732302410749, 0.9646692281371212, 0.8819693059525081], 
             UndirectedEdge[68, 109] -> 
             RGBColor[
              0.4658581318015075, 0.5772436439229636, 0.951093205111431], 
             UndirectedEdge[137, 156] -> 
             RGBColor[
              0.6836285150820703, 0.7507743420548162, 0.9707235153649503], 
             UndirectedEdge[181, 202] -> 
             RGBColor[
              0.6956711002623153, 0.7609691875346276, 0.9711902891544151], 
             UndirectedEdge[135, 214] -> 
             RGBColor[
              0.7881374129664901, 0.8341415906123459, 0.9475162793583256], 
             UndirectedEdge[166, 234] -> 
             RGBColor[
              0.6523104906038311, 0.7243639864517759, 0.9684922129691624], 
             UndirectedEdge[63, 152] -> 
             RGBColor[
              0.7528810489842669, 0.8068756646651927, 0.9760038049554818], 
             UndirectedEdge[130, 167] -> 
             RGBColor[
              0.5710244016446302, 0.6591343416312068, 0.9610335917536024], 
             UndirectedEdge[30, 74] -> 
             RGBColor[
              0.55612356348836, 0.6505251877777074, 0.9581992305469912], 
             UndirectedEdge[31, 177] -> 
             RGBColor[
              0.7518559122027846, 0.8056557881786345, 0.9706541169854664], 
             UndirectedEdge[24, 72] -> 
             RGBColor[
              0.7262930423857661, 0.7858691136216266, 0.9735553196198903], 
             UndirectedEdge[39, 285] -> 
             RGBColor[
              0.45538097399415234`, 0.5673263938206596, 0.950658384808921], 
             UndirectedEdge[27, 72] -> 
             RGBColor[
              0.7743054317994339, 0.8237089901249567, 0.9781135963885433], 
             UndirectedEdge[109, 151] -> 
             RGBColor[
              0.6423454368599221, 0.7178088092998227, 0.9668433153349458], 
             UndirectedEdge[29, 178] -> 
             RGBColor[
              0.5569493578504687, 0.6508494416380752, 0.9584834553359409], 
             UndirectedEdge[149, 256] -> 
             RGBColor[
              0.667713601928743, 0.7380758321638627, 0.9692151936397286], 
             UndirectedEdge[93, 137] -> 
             RGBColor[
              0.8891455832684483, 0.9144445691570945, 0.9892886935534189], 
             UndirectedEdge[7, 145] -> 
             RGBColor[
              0.7196903230684462, 0.7805746175149542, 0.9729596924713653], 
             UndirectedEdge[271, 278] -> 
             RGBColor[
              0.7104070480860879, 0.7726119298213321, 0.9727193202352997], 
             UndirectedEdge[15, 135] -> 
             RGBColor[
              0.7473666980524343, 0.6417463619812529, 0.5959865868274535], 
             UndirectedEdge[94, 130] -> 
             RGBColor[
              0.7192955199542195, 0.7806383941274448, 0.9726563132963799], 
             UndirectedEdge[265, 286] -> 
             RGBColor[
              0.8033230449025326, 0.8422243687122444, 0.712417439826041], 
             UndirectedEdge[140, 201] -> 
             RGBColor[
              0.44355570668903754`, 0.5584824779106959, 0.9495184694933236], 
             UndirectedEdge[29, 259] -> 
             RGBColor[
              0.5111150672352367, 0.6139424098531198, 0.9546678372776249], 
             UndirectedEdge[21, 123] -> 
             RGBColor[
              0.6030706769692722, 0.688100064506304, 0.9622635315428806], 
             UndirectedEdge[21, 189] -> 
             RGBColor[
              0.6679541483592804, 0.7405301244286022, 0.9675390851881924], 
             UndirectedEdge[107, 289] -> 
             RGBColor[
              0.8929386824596381, 0.9166610090700547, 0.9611644126115507], 
             UndirectedEdge[17, 66] -> 
             RGBColor[
              0.5948565732241651, 0.6788384043554301, 0.9629492331620966], 
             UndirectedEdge[71, 208] -> 
             RGBColor[
              0.39938577031284656`, 0.5203496133576693, 0.9466694860147328], 
             UndirectedEdge[6, 289] -> 
             RGBColor[
              0.7494991225458203, 0.8029058240481738, 0.9480293890198859], 
             UndirectedEdge[96, 132] -> 
             RGBColor[
              0.4912398865984917, 0.596207630275694, 0.9535450574506161], 
             UndirectedEdge[55, 283] -> 
             RGBColor[
              0.6026146147867404, 0.6821295981563045, 0.964952894814344], 
             UndirectedEdge[48, 244] -> 
             RGBColor[
              0.464768604706161, 0.5756236704928137, 0.951210639537972], 
             UndirectedEdge[110, 278] -> 
             RGBColor[
              0.9379148054970878, 0.949182715558242, 0.7957279914696624], 
             UndirectedEdge[245, 288] -> 
             RGBColor[
              0.5083549882290301, 0.6115676433777821, 0.9544875811094724], 
             UndirectedEdge[106, 210] -> 
             RGBColor[
              0.8001467943994803, 0.8443577005504981, 0.9613523179593468], 
             UndirectedEdge[176, 296] -> 
             RGBColor[
              0.5947735487436621, 0.6815806012563848, 0.9614623158389275], 
             UndirectedEdge[82, 154] -> 
             RGBColor[
              0.7246049049692301, 0.7831166334612547, 0.9573629441772418], 
             UndirectedEdge[46, 117] -> 
             RGBColor[
              0.8489406212140942, 0.8823862237495748, 0.9854539083812812], 
             UndirectedEdge[249, 258] -> 
             RGBColor[
              0.6126795283376545, 0.6958113990219896, 0.9630812108478736], 
             UndirectedEdge[146, 170] -> 
             RGBColor[
              0.4997458315012244, 0.602967397165278, 0.954254945642983], 
             UndirectedEdge[18, 129] -> 
             RGBColor[
              0.6898327004301346, 0.75521407810727, 0.9708901431355001], 
             UndirectedEdge[13, 179] -> 
             RGBColor[
              0.5817775962837681, 0.6708145380067757, 0.9605864721125456], 
             UndirectedEdge[144, 160] -> 
             RGBColor[
              0.7596413841894896, 0.8106989906609032, 0.9370055460057598], 
             UndirectedEdge[17, 130] -> 
             RGBColor[
              0.7651768228662427, 0.8164812166731348, 0.9772293327854973], 
             UndirectedEdge[111, 163] -> 
             RGBColor[
              0.6951413652086207, 0.7617689848618079, 0.9702488528847483], 
             UndirectedEdge[107, 251] -> 
             RGBColor[
              0.8470310897219551, 0.8808770575428, 0.9852682083706339], 
             UndirectedEdge[1, 198] -> 
             RGBColor[
              0.7888624117583773, 0.8354324690152786, 0.9794712346222505], 
             UndirectedEdge[168, 269] -> 
             RGBColor[
              0.5697374101222353, 0.6611099803908025, 0.9595906230188997], 
             UndirectedEdge[145, 201] -> 
             RGBColor[
              0.5228820145315712, 0.6228831482267085, 0.9557633270285281], 
             UndirectedEdge[197, 226] -> 
             RGBColor[
              0.6861644771622544, 0.7546897935308907, 0.9693995036901089], 
             UndirectedEdge[105, 174] -> 
             RGBColor[
              0.5694397476157256, 0.6608341372873139, 0.9595905639600201], 
             UndirectedEdge[178, 284] -> 
             RGBColor[
              0.8072196868081227, 0.8499671351967985, 0.9663112342045126], 
             UndirectedEdge[201, 202] -> 
             RGBColor[
              0.4915699891014794, 0.5974626353918893, 0.9532983296869428], 
             UndirectedEdge[24, 65] -> 
             RGBColor[
              0.807515194306742, 0.8474315841989414, 0.8532115853350843], 
             UndirectedEdge[134, 169] -> 
             RGBColor[
              0.8559100452049341, 0.7192374917598316, 0.6048482110470416], 
             UndirectedEdge[104, 300] -> 
             RGBColor[
              0.8237531897939456, 0.8622836854872493, 0.9377924756027536], 
             UndirectedEdge[168, 225] -> 
             RGBColor[
              0.716008335004402, 0.7757869897829834, 0.9472836657884756], 
             UndirectedEdge[27, 202] -> 
             RGBColor[
              0.6353214046477647, 0.7136828188968178, 0.9652125403131425], 
             UndirectedEdge[113, 187] -> 
             RGBColor[
              0.9164594666300054, 0.9349880539457855, 0.9490457219738273], 
             UndirectedEdge[7, 201] -> 
             RGBColor[
              0.6260012245119576, 0.703858534067842, 0.9657651364217437], 
             UndirectedEdge[51, 104] -> 
             RGBColor[0.770908550251789, 0.81970015597549, 0.9334148451302531]
              , UndirectedEdge[2, 183] -> 
             RGBColor[
              0.8016459880659377, 0.8193592602636189, 0.6623187725658144], 
             UndirectedEdge[135, 249] -> 
             RGBColor[
              0.5733393710019443, 0.6645017558805253, 0.9595545219780415], 
             UndirectedEdge[84, 270] -> 
             RGBColor[
              0.7762960058171402, 0.8253650045123823, 0.9782852057713392], 
             UndirectedEdge[114, 116] -> 
             RGBColor[
              0.7307473063187369, 0.7895846166722058, 0.973797720338167], 
             UndirectedEdge[15, 168] -> 
             RGBColor[
              0.6783117188516707, 0.5856844189747117, 0.5905503259080458], 
             UndirectedEdge[42, 237] -> 
             RGBColor[
              0.46307569615335975`, 0.5678209537636231, 0.9522706185134392], 
             UndirectedEdge[40, 140] -> 
             RGBColor[
              0.59350361852278, 0.6795434114105021, 0.962050288959907], 
             UndirectedEdge[42, 167] -> 
             RGBColor[
              0.3349146835000142, 0.4620270686485064, 0.9426522843628538], 
             UndirectedEdge[16, 285] -> 
             RGBColor[
              0.7510273178043377, 0.8019167871499626, 0.8631705291061404], 
             UndirectedEdge[8, 286] -> 
             RGBColor[
              0.709508976275808, 0.7653249560456143, 0.7052356673972353], 
             UndirectedEdge[9, 236] -> 
             RGBColor[
              0.4762627698664525, 0.5853985907425665, 0.9519929787610035], 
             UndirectedEdge[54, 238] -> 
             RGBColor[
              0.9831454162281632, 0.9847171575064383, 0.7998935475302886], 
             UndirectedEdge[165, 183] -> 
             RGBColor[
              0.6341989454368258, 0.7139103000993463, 0.9643456106135221], 
             UndirectedEdge[249, 263] -> 
             RGBColor[
              0.5811174437142962, 0.6708163457065952, 0.9601668403539769], 
             UndirectedEdge[33, 98] -> 
             RGBColor[
              0.9829295968062772, 0.9860530990706597, 0.880802302102798], 
             UndirectedEdge[282, 293] -> 
             RGBColor[
              0.5282764786182437, 0.6279176697832697, 0.9560070060187826], 
             UndirectedEdge[54, 163] -> 
             RGBColor[
              0.8168644579759068, 0.8571601897418685, 0.9499851523766463], 
             UndirectedEdge[145, 237] -> 
             RGBColor[
              0.630404944867077, 0.7108013637382905, 0.9640666208233604], 
             UndirectedEdge[140, 181] -> 
             RGBColor[
              0.6476568178498734, 0.7219890300534342, 0.9674104289607959], 
             UndirectedEdge[15, 265] -> 
             RGBColor[
              0.751917131464823, 0.6454406088201192, 0.5963448136144636], 
             UndirectedEdge[144, 230] -> 
             RGBColor[
              0.44064086349880555`, 0.5537731011665717, 0.9499363735350945], 
             UndirectedEdge[22, 266] -> 
             RGBColor[
              0.48445034664108677`, 0.5923376414994677, 0.9525568523691297], 
             UndirectedEdge[18, 165] -> 
             RGBColor[
              0.5420644849646595, 0.6388349250758587, 0.9571688377050285], 
             UndirectedEdge[17, 140] -> 
             RGBColor[
              0.6170700455928102, 0.6979536833490891, 0.9643991701694654], 
             UndirectedEdge[80, 237] -> 
             RGBColor[
              0.7561948142476838, 0.8098537180065037, 0.9762307779485055], 
             UndirectedEdge[7, 127] -> 
             RGBColor[
              0.7796696164648894, 0.8278259349134551, 0.9786677785767444], 
             UndirectedEdge[60, 212] -> 
             RGBColor[
              0.47991733924885016`, 0.5886575418887942, 0.9521999974222597], 
             UndirectedEdge[53, 270] -> 
             RGBColor[
              0.7124180365275139, 0.7745143702710875, 0.9725670638764972], 
             UndirectedEdge[243, 254] -> 
             RGBColor[
              0.7046034175192102, 0.7667220103615662, 0.9530669780335017], 
             UndirectedEdge[201, 277] -> 
             RGBColor[
              0.641916761715317, 0.7165491514180522, 0.9672831745681678], 
             UndirectedEdge[288, 296] -> 
             RGBColor[
              0.4864735805390488, 0.5938033308688723, 0.9527649965418796], 
             UndirectedEdge[93, 273] -> 
             RGBColor[
              0.6620724307360019, 0.7330278991448917, 0.9690182001523036], 
             UndirectedEdge[128, 277] -> 
             RGBColor[
              0.8556212851442316, 0.8877132038256748, 0.9860911160708368], 
             UndirectedEdge[3, 115] -> 
             RGBColor[
              0.7326589329001434, 0.7910779938865007, 0.9739882534106356], 
             UndirectedEdge[74, 123] -> 
             RGBColor[
              0.5443856488386138, 0.6409958198780145, 0.9572751789083651], 
             UndirectedEdge[52, 147] -> 
             RGBColor[
              0.5970088212572187, 0.6810608468171692, 0.9629347342243568], 
             UndirectedEdge[64, 76] -> 
             RGBColor[
              0.7534853737199864, 0.8076402550028846, 0.9759864212714633], 
             UndirectedEdge[132, 260] -> 
             RGBColor[
              0.5903336859049644, 0.6782985063039588, 0.9608923766994338], 
             UndirectedEdge[171, 285] -> 
             RGBColor[
              0.6277334589225548, 0.7070730446976812, 0.964922541033862], 
             UndirectedEdge[226, 290] -> 
             RGBColor[
              0.6087660900649877, 0.6918542961277256, 0.9633064191381783], 
             UndirectedEdge[24, 290] -> 
             RGBColor[
              0.5519500275485403, 0.6471369232861104, 0.9578706745096428], 
             UndirectedEdge[103, 265] -> 
             RGBColor[
              0.6976594405382983, 0.7632987248854289, 0.970798883570259], 
             UndirectedEdge[41, 208] -> 
             RGBColor[
              0.5410580133602658, 0.6366831818043311, 0.9576410081944462], 
             UndirectedEdge[80, 179] -> 
             RGBColor[
              0.6771214965273229, 0.7456872322495021, 0.9699861488898809], 
             UndirectedEdge[102, 183] -> 
             RGBColor[
              0.57373649943426, 0.6648241626323113, 0.9595857853829627], 
             UndirectedEdge[16, 220] -> 
             RGBColor[
              0.843657895070369, 0.8763168695830379, 0.8710108010810482], 
             UndirectedEdge[52, 217] -> 
             RGBColor[
              0.712587957310118, 0.7753983952105086, 0.9719877661377527], 
             UndirectedEdge[24, 241] -> 
             RGBColor[
              0.5011627655181481, 0.6039597056928769, 0.9544101539224243], 
             UndirectedEdge[105, 163] -> 
             RGBColor[
              0.562963408702277, 0.6557747721061291, 0.9589450630219556], 
             UndirectedEdge[2, 102] -> 
             RGBColor[
              0.7479777223462918, 0.775788944424592, 0.6580938100950289], 
             UndirectedEdge[49, 54] -> 
             RGBColor[
              0.8099920843317708, 0.8517914392190953, 0.9493001783977819], 
             UndirectedEdge[216, 237] -> 
             RGBColor[
              0.7242270716554204, 0.7844909597976043, 0.9731478442819849], 
             UndirectedEdge[89, 281] -> 
             RGBColor[
              0.30078187941319623`, 0.42294122548972035`, 0.940826009221387], 
             UndirectedEdge[145, 167] -> 
             RGBColor[
              0.5022439322137313, 0.6050074786231738, 0.9544482866727749], 
             UndirectedEdge[16, 90] -> 
             RGBColor[
              0.9211565478130539, 0.9370994599547755, 0.8786714396128394], 
             UndirectedEdge[210, 290] -> 
             RGBColor[
              0.5632478145954019, 0.6562950733791786, 0.9587695828318388], 
             UndirectedEdge[152, 242] -> 
             RGBColor[
              0.8504309164156127, 0.8835228438896787, 0.9604317799576605], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.6359259491006839, 0.7133793238072126, 0.9658031937110231], 
             UndirectedEdge[77, 282] -> 
             RGBColor[
              0.7046722382069643, 0.7678848235975142, 0.9723499536110518], 
             UndirectedEdge[81, 162] -> 
             RGBColor[
              0.7648792622348065, 0.8162487600463122, 0.9771996747226179], 
             UndirectedEdge[34, 247] -> 
             RGBColor[
              0.8333149875090171, 0.8700715915637112, 0.9839250896568892], 
             UndirectedEdge[7, 60] -> 
             RGBColor[
              0.6563018412222822, 0.7291129923336734, 0.9679695189807753], 
             UndirectedEdge[155, 162] -> 
             RGBColor[
              0.8157699187920068, 0.3739462065686123, 0.43679972796412114`], 
             UndirectedEdge[234, 249] -> 
             RGBColor[
              0.4787083763711795, 0.586647653097579, 0.9523889729404005], 
             UndirectedEdge[118, 234] -> 
             RGBColor[
              0.5616035647468589, 0.6529437764264727, 0.9595998074053651], 
             UndirectedEdge[223, 271] -> 
             RGBColor[
              0.7667682555371325, 0.8135945096800383, 0.795348846402284], 
             UndirectedEdge[154, 216] -> 
             RGBColor[
              0.8795107877686241, 0.9063967744421884, 0.9712529046662272], 
             UndirectedEdge[147, 247] -> 
             RGBColor[
              0.6453978307727597, 0.7192230316232127, 0.9676620798790139], 
             UndirectedEdge[4, 286] -> 
             RGBColor[
              0.9284708694639491, 0.9407847843938542, 0.7244973263966239], 
             UndirectedEdge[88, 124] -> 
             RGBColor[
              0.9138353481009984, 0.9309832925405105, 0.8658822461049047], 
             UndirectedEdge[23, 136] -> 
             RGBColor[
              0.5181406119795371, 0.6196889166303792, 0.9552090734680808], 
             UndirectedEdge[11, 104] -> 
             RGBColor[
              0.7589705216114526, 0.8100083265232033, 0.9324750397852459], 
             UndirectedEdge[4, 121] -> 
             RGBColor[
              0.742880710736838, 0.7991028270850316, 0.9751292286818847], 
             UndirectedEdge[4, 213] -> 
             RGBColor[
              0.7162805993070482, 0.7775076583049644, 0.973035170470713], 
             UndirectedEdge[198, 204] -> 
             RGBColor[
              0.8287915143781353, 0.8667665265604632, 0.965794442443614], 
             UndirectedEdge[156, 168] -> 
             RGBColor[
              0.46933628497010604`, 0.5800673653542465, 0.951367018069758], 
             UndirectedEdge[31, 226] -> 
             RGBColor[
              0.8382627472514839, 0.8743962832110432, 0.9784193556223122], 
             UndirectedEdge[36, 242] -> 
             RGBColor[
              0.7151383442763652, 0.7751393169608392, 0.9487875757248617], 
             UndirectedEdge[216, 269] -> 
             RGBColor[
              0.7385476372283981, 0.7956782944635439, 0.9745751844250052], 
             UndirectedEdge[97, 202] -> 
             RGBColor[
              0.5403920623633195, 0.6377536464683501, 0.9569607891520406], 
             UndirectedEdge[23, 59] -> 
             RGBColor[
              0.5057189698912982, 0.6096044679945478, 0.9542311963009205], 
             UndirectedEdge[174, 238] -> 
             RGBColor[
              0.8349162580384866, 0.8686192128648477, 0.8175153711503512], 
             UndirectedEdge[86, 97] -> 
             RGBColor[
              0.4845880281408793, 0.5921513117841231, 0.9526500586706543], 
             UndirectedEdge[46, 212] -> 
             RGBColor[
              0.654448139665101, 0.7274919619191544, 0.9679572315656644], 
             UndirectedEdge[59, 291] -> 
             RGBColor[
              0.6085039279291247, 0.6925927997203396, 0.9626353453610152], 
             UndirectedEdge[125, 149] -> 
             RGBColor[
              0.9151935477738812, 0.934436274016354, 0.9647912762183394], 
             UndirectedEdge[32, 80] -> 
             RGBColor[
              0.8771923758469319, 0.9049134060203492, 0.9881485859588004], 
             UndirectedEdge[69, 90] -> 
             RGBColor[
              0.7420625747501166, 0.7985429532262676, 0.9749447449470665], 
             UndirectedEdge[215, 229] -> 
             RGBColor[
              0.7138691550043434, 0.7747035298333856, 0.9646355925390597], 
             UndirectedEdge[187, 245] -> 
             RGBColor[
              0.7096001146195487, 0.772191283789412, 0.9723859375738025], 
             UndirectedEdge[98, 275] -> 
             RGBColor[
              0.9841449233033015, 0.9869594875822258, 0.8787450713512519], 
             UndirectedEdge[252, 280] -> 
             RGBColor[
              0.9495710482148285, 0.959085205288955, 0.8461358055455775], 
             UndirectedEdge[96, 146] -> 
             RGBColor[
              0.39015819402831886`, 0.5123571505714808, 0.946081513013508], 
             UndirectedEdge[191, 270] -> 
             RGBColor[
              0.8696930646558056, 0.8989336588399246, 0.9874332949626766], 
             UndirectedEdge[40, 120] -> 
             RGBColor[
              0.6662425578252091, 0.738596159188087, 0.9677765647133083], 
             UndirectedEdge[215, 233] -> 
             RGBColor[
              0.7047044889266958, 0.7672632410480494, 0.9639141164541494], 
             UndirectedEdge[21, 257] -> 
             RGBColor[
              0.7902566196901382, 0.8367445278866479, 0.9795510472801352], 
             UndirectedEdge[200, 245] -> 
             RGBColor[
              0.6421875775658619, 0.7192911914488913, 0.9657297534650694], 
             UndirectedEdge[41, 108] -> 
             RGBColor[
              0.6501119375180523, 0.7263808866514943, 0.965904842947952], 
             UndirectedEdge[63, 73] -> 
             RGBColor[
              0.7126585349316792, 0.775453530984882, 0.9719948006554846]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {3}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.6165711130880598, 0.6995992316738207, 0.9629578830781497], 
             160 -> RGBColor[
              0.9809039602675217, 0.9852787853511886, 0.9172087936089789], 
             245 -> RGBColor[
              0.5699057069552613, 0.6617141527226256, 0.9592842113663607], 
             155 -> RGBColor[0.817319, 0.134127, 0.164218], 213 -> 
             RGBColor[
              0.5684598118125378, 0.6605403099089288, 0.959170385204237], 27 -> 
             RGBColor[
              0.716695747067653, 0.7786074317894535, 0.9723971922313059], 19 -> 
             RGBColor[
              0.8192455362783049, 0.8587201065280795, 0.9826183968375573], 
             164 -> RGBColor[
              0.46686251184728444`, 0.5780590448909307, 0.9511722735878], 190 -> 
             RGBColor[
              0.5957911229037891, 0.6827290995143399, 0.9613220061312318], 
             103 -> RGBColor[
              0.7815131433978709, 0.8292432744330773, 0.9788575845444949], 
             138 -> RGBColor[
              0.6139675621392116, 0.6974855517249119, 0.962752922010335], 291 -> 
             RGBColor[
              0.67220010170837, 0.7438470954553517, 0.9679622821373398], 28 -> 
             RGBColor[
              0.979546087777233, 0.9842660862712435, 0.9195073175451726], 195 -> 
             RGBColor[
              0.9437975872083858, 0.9576049130797947, 0.9800202043060325], 
             114 -> RGBColor[
              0.700494498109712, 0.7659508929694574, 0.970782403144458], 93 -> 
             RGBColor[
              0.8831117938605466, 0.9096333892660841, 0.9887131853332658], 34 -> 
             RGBColor[
              0.8020660667436953, 0.8452993743588382, 0.9809061078656179], 
             161 -> RGBColor[
              0.5296308802354113, 0.6290172340311839, 0.9561136294754228], 22 -> 
             RGBColor[
              0.45947517875319677`, 0.5720616750895869, 0.9505907156659406], 
             124 -> 
             RGBColor[
              0.9940799146444925, 0.9918199068133131, 0.7477746652379373], 84 -> 
             RGBColor[
              0.7081855569692308, 0.7719592066047257, 0.9715489760145433], 46 -> 
             RGBColor[
              0.8388557502282334, 0.8743448213719798, 0.9844920043837793], 
             241 -> RGBColor[
              0.38165456279597854`, 0.5049917326029606, 0.9455396691508491], 
             185 -> RGBColor[
              0.4970576186715026, 0.6025727928848919, 0.9535493430053232], 
             121 -> RGBColor[
              0.6216600346721173, 0.7037306474690632, 0.9633585016265807], 
             126 -> RGBColor[
              0.9188354837417994, 0.9381184898836654, 0.9921205427650541], 
             236 -> RGBColor[
              0.4425636032721896, 0.5577480820860667, 0.9494207393502435], 78 -> 
             RGBColor[
              0.5143023003769336, 0.6165728023574184, 0.9549069075185252], 
             254 -> RGBColor[
              0.4513111663521255, 0.5653247815606031, 0.9499781263345307], 
             290 -> RGBColor[
              0.483229086856763, 0.5913461677894274, 0.9524607103252858], 251 -> 
             RGBColor[
              0.8757412985024339, 0.9037563563342917, 0.9880101809062901], 
             165 -> RGBColor[
              0.6409931257197458, 0.7194261217273545, 0.964880473373296], 100 -> 
             RGBColor[
              0.6132947130786202, 0.6969393025460191, 0.9626999528675579], 
             235 -> RGBColor[
              0.7730878053077275, 0.8226613362821161, 0.9780178255829304], 70 -> 
             RGBColor[
              0.8045147084023891, 0.8472122718329758, 0.9811501655822992], 
             234 -> RGBColor[
              0.4154428815924186, 0.5342574760941555, 0.9476926309467211], 
             257 -> RGBColor[
              0.902974748100801, 0.9254715698117332, 0.9906077316405698], 135 -> 
             RGBColor[
              0.6047048708539482, 0.689965681660048, 0.962023729022003], 265 -> 
             RGBColor[
              0.6138057376787256, 0.6973541753377805, 0.962740182596023], 111 -> 
             RGBColor[
              0.7281237695444599, 0.7875350898045227, 0.9735362307108522], 
             182 -> RGBColor[
              0.755721152295969, 0.809094374957879, 0.9762868799113179], 188 -> 
             RGBColor[
              0.4214781903277293, 0.5394849571772445, 0.9480771954825211], 
             154 -> RGBColor[
              0.9548062088725014, 0.9658151250919286, 0.9613854793370556], 
             269 -> RGBColor[
              0.6728799077920493, 0.7443781651346396, 0.9680300388546119], 
             208 -> RGBColor[
              0.41049236512849774`, 0.5299695875532995, 0.9473771884152099], 
             86 -> RGBColor[
              0.4423389937829958, 0.5575535366357283, 0.9494064274322065], 
             119 -> RGBColor[
              0.9862115727441378, 0.9885661452303531, 0.8781734531429125], 
             140 -> RGBColor[
              0.45791849740299245`, 0.5707978910417955, 0.9504681680077408], 
             85 -> RGBColor[
              0.381107047728234, 0.5045175025701878, 0.945504781974881], 242 -> 
             RGBColor[
              0.9636465029200134, 0.97240820191791, 0.9464211674325732], 117 -> 
             RGBColor[
              0.859025492199955, 0.8904276261271697, 0.9864158123787833], 47 -> 
             RGBColor[
              0.9503804047585549, 0.9625143676303363, 0.968877211267384], 81 -> 
             RGBColor[
              0.7170867680935928, 0.7789129003867875, 0.9724361655528724], 
             275 -> RGBColor[
              0.9796653261218558, 0.9843550140334283, 0.9193054781300671], 23 -> 
             RGBColor[
              0.4666301856327171, 0.5778704320037683, 0.9511539840171502], 
             110 -> RGBColor[
              0.9941337939258618, 0.9898611033088602, 0.6028778547365596], 6 -> 
             RGBColor[
              0.5314417611138404, 0.6304873887075466, 0.9562561886516479], 
             218 -> RGBColor[
              0.6344411749538242, 0.7141069529335611, 0.9643646798084162], 
             108 -> RGBColor[
              0.6286002134440707, 0.7093649972476257, 0.9639048579222214], 
             297 -> RGBColor[
              0.7090687635711496, 0.7726491743147634, 0.9716370057945877], 
             157 -> RGBColor[
              0.5371710787377932, 0.6351387068574892, 0.9567072215221875], 
             270 -> RGBColor[
              0.8444064546650496, 0.8787708024200388, 0.985021435528135], 33 -> 
             RGBColor[
              0.9772346731278074, 0.9825422370102961, 0.9234199396331593], 
             252 -> RGBColor[
              0.9950404005437372, 0.9918002431925058, 0.7015563901648024], 
             260 -> RGBColor[
              0.5910295824474449, 0.6788634664669265, 0.960947160224411], 159 -> 
             RGBColor[
              0.6068830951760222, 0.6917340622925952, 0.9621952068197351], 
             183 -> RGBColor[
              0.6274047651539059, 0.7083944784713382, 0.9638107478537482], 99 -> 
             RGBColor[
              0.7404556200240375, 0.7971688251247037, 0.9747653543189616], 17 -> 
             RGBColor[
              0.776221593782628, 0.8251094756563829, 0.9783301723311901], 277 -> 
             RGBColor[
              0.8546406074555514, 0.8869312380565079, 0.9859975781574292], 
             104 -> RGBColor[
              0.9843800180288238, 0.9878087502867616, 0.9085270546873273], 79 -> 
             RGBColor[
              0.6223799631402269, 0.7043151178318826, 0.9634151770327751], 
             191 -> RGBColor[
              0.8949796746465616, 0.9190965152598103, 0.9898451543972182], 50 -> 
             RGBColor[
              0.9628736340361522, 0.8864261912979763, 0.31027150826671723`], 
             225 -> RGBColor[
              0.9654217575563825, 0.9737321839190013, 0.9434161243937637], 61 -> 
             RGBColor[
              0.9654217575563825, 0.9737321839190013, 0.9434161243937637], 
             196 -> RGBColor[
              0.9933760232602475, 0.9882403084774779, 0.5203991942029068], 1 -> 
             RGBColor[
              0.8753979443181465, 0.903482575027842, 0.9879774314776769], 263 -> 
             RGBColor[
              0.6202610162786519, 0.7025948613121877, 0.9632483657738738], 
             201 -> RGBColor[
              0.42919291597508263`, 0.5461670647795964, 0.9485687709789065], 
             293 -> RGBColor[
              0.5387617134106175, 0.6364300557421633, 0.9568324421103189], 
             184 -> RGBColor[
              0.5029104997167569, 0.6073244253867157, 0.9540101032410153], 
             106 -> RGBColor[
              0.9570270464649201, 0.9674714221320665, 0.9576261805803017], 
             206 -> RGBColor[
              0.6600656570140948, 0.7343675750349885, 0.9667528340930474], 
             247 -> RGBColor[
              0.864563908274339, 0.8948438087685842, 0.9869440714481604], 220 -> 
             RGBColor[
              0.6946866690610395, 0.7614137727754987, 0.9702035330221345], 
             107 -> RGBColor[
              0.8183208809414763, 0.8579977587513082, 0.9825262358349776], 
             131 -> RGBColor[
              0.4797607632957117, 0.58853042647637, 0.952187671189672], 127 -> 
             RGBColor[
              0.7365296998809463, 0.7941018664708226, 0.974374055288908], 210 -> 
             RGBColor[
              0.6432665423340406, 0.7212439789689298, 0.9650784553383919], 
             181 -> RGBColor[
              0.8373951382967544, 0.873180169065073, 0.984352689913851], 194 -> 
             RGBColor[
              0.6775897693737575, 0.7480575447985437, 0.9684994738409176], 
             118 -> RGBColor[
              0.7077642479012991, 0.7716300767587899, 0.971506983864009], 
             276 -> 
             RGBColor[
              0.4977996639666584, 0.6031752186842589, 0.9536077595291593], 
             280 -> RGBColor[
              0.9041016958859197, 0.9263701673854042, 0.9907152209263527], 
             189 -> RGBColor[
              0.6583698054390853, 0.7330427628956416, 0.9665838074566844], 
             168 -> RGBColor[
              0.46659491245242135`, 0.5778417956469655, 0.9511512071831875], 
             41 -> RGBColor[
              0.6716236615920339, 0.7433967760553628, 0.9679048279736826], 14 -> 
             RGBColor[
              0.4380867582825022, 0.5538704639687713, 0.9491354787462193], 77 -> 
             RGBColor[
              0.8915532325880589, 0.9163643633706522, 0.9895183372948573], 51 -> 
             RGBColor[
              0.5574370824747542, 0.6515915616642183, 0.9583026355731787], 
             179 -> RGBColor[
              0.48609214120537236`, 0.593670524288757, 0.952686100451322], 
             223 -> RGBColor[
              0.994418231970403, 0.9904694875250362, 0.6338371805367335], 292 -> 
             RGBColor[
              0.6294105767850028, 0.710022886714247, 0.9639686526928782], 143 -> 
             RGBColor[
              0.4436874897865332, 0.5587215360966126, 0.9494923524051238], 
             112 -> RGBColor[
              0.47091817310878165`, 0.5813516134084719, 0.9514915500986817], 
             197 -> RGBColor[
              0.6380258610512964, 0.7170171625957574, 0.9646468794291471], 54 -> 
             RGBColor[
              0.971569955079032, 0.9783174995646439, 0.9330088296946482], 71 -> 
             RGBColor[
              0.3882791754971954, 0.510729639162039, 0.9459617836142556], 177 -> 
             RGBColor[
              0.5614894231758136, 0.6548814344012065, 0.9586216506773793], 
             158 -> RGBColor[
              0.9933413814774745, 0.988166213206948, 0.5166286499323679], 226 -> 
             RGBColor[
              0.7343030932732124, 0.792362424466024, 0.9741521279510708], 203 -> 
             RGBColor[
              0.9947208773772945, 0.9911168154482327, 0.6667782653659292], 
             115 -> RGBColor[
              0.8130183922890809, 0.8538554143156506, 0.9819977333206806], 
             173 -> RGBColor[
              0.9896440663311221, 0.9899855695396327, 0.8212881513979312], 
             212 -> RGBColor[
              0.4700405291019686, 0.5806391024663291, 0.9514224587475495], 
             129 -> RGBColor[
              0.9365295566506959, 0.9521844277901774, 0.9923230842342393], 
             279 -> RGBColor[
              0.6812019682937882, 0.7508794220486004, 0.9688595040713481], 26 -> 
             RGBColor[
              0.5827554151245427, 0.6721461246872044, 0.9602957874634785], 40 -> 
             RGBColor[
              0.7290887396425676, 0.7882889317792088, 0.9736324099120732], 
             146 -> RGBColor[
              0.3874744042221381, 0.5100325867325648, 0.9459105043002403], 
             192 -> RGBColor[
              0.4071394287162701, 0.527065442556512, 0.947163542271908], 300 -> 
             RGBColor[
              0.6631263615590673, 0.7367586206877371, 0.96705789651818], 221 -> 
             RGBColor[
              0.982687018582456, 0.9532613897765836, 0.3872427657853917], 62 -> 
             RGBColor[
              0.8592718541811049, 0.8906240684836209, 0.9864393106044752], 
             286 -> RGBColor[
              0.9928403521263395, 0.9870945620867082, 0.4620946970560589], 
             152 -> RGBColor[
              0.7372153299112122, 0.7946374858614476, 0.9744423924827479], 64 -> 
             RGBColor[
              0.6507995975163491, 0.727128858930689, 0.9658292798785613], 37 -> 
             RGBColor[
              0.9944171175117607, 0.9904671038106891, 0.6337158785911514], 
             148 -> RGBColor[
              0.46019257740937003`, 0.5726440916371096, 0.9506471919160724], 
             261 -> RGBColor[
              0.5016470753325979, 0.6062987205550355, 0.9539106418454183], 15 -> 
             RGBColor[
              0.8900285252509202, 0.5935270423024579, 0.2299494446329042], 
             136 -> RGBColor[
              0.569651038326357, 0.6615074012569901, 0.9592641629190114], 198 -> 
             RGBColor[
              0.7023268791986083, 0.7673823630027151, 0.9709650377668242], 63 -> 
             RGBColor[
              0.7685467680573216, 0.8191138434689377, 0.9775652174282158], 
             171 -> RGBColor[
              0.7460414033161329, 0.801532481486014, 0.975322092995405], 59 -> 
             RGBColor[
              0.5448077541498793, 0.6413385039853274, 0.9573084085846906], 
             229 -> RGBColor[
              0.482097188687068, 0.5904272418638374, 0.9523716031550877], 102 -> 
             RGBColor[
              0.5200682337146141, 0.6212538467932843, 0.9553608229121772], 
             299 -> RGBColor[
              0.5306530488671773, 0.6298470765746238, 0.9561940983344425], 
             128 -> RGBColor[
              0.8566019628329119, 0.8884951695948418, 0.9861846539842445], 12 -> 
             RGBColor[
              0.8313175060544302, 0.8683340300879762, 0.9837729999250119], 
             222 -> 
             RGBColor[
              0.7495593346645545, 0.8042807161926695, 0.9756727275152781], 92 -> 
             RGBColor[
              0.21404723810900797`, 0.34230759700427454`, 0.9355010456045717],
              271 -> RGBColor[
              0.539118279103862, 0.6367195318350406, 0.9568605122678343], 132 -> 
             RGBColor[
              0.5896377893624838, 0.6777335461409912, 0.9608375931744567], 80 -> 
             RGBColor[
              0.8681508518492733, 0.8977039402102471, 0.9872861973284399], 
             244 -> RGBColor[
              0.42623207926827567`, 0.5436025368401401, 0.9483801090821138], 
             150 -> RGBColor[
              0.773957060203821, 0.8233404048135262, 0.9781044647873242], 125 -> 
             RGBColor[
              0.965878064799058, 0.9740724971134542, 0.9426437152559032], 258 -> 
             RGBColor[
              0.6833851855253686, 0.7525849679429765, 0.9690771067616671], 
             133 -> RGBColor[
              0.4149498286834543, 0.5338304184459703, 0.9476612140513514], 
             255 -> RGBColor[
              0.8878328548861842, 0.9133978351781398, 0.989163484348432], 176 -> 
             RGBColor[
              0.6634042059120256, 0.7369756748079634, 0.9670855894466798], 
             230 -> RGBColor[
              0.34290291888615376`, 0.47142700636252566`, 0.9430704486676483],
              274 -> RGBColor[
              0.429077866100899, 0.5460674143611534, 0.9485614401026581], 87 -> 
             RGBColor[
              0.44596946797184733`, 0.5606980709051732, 0.9496377580372178], 
             130 -> RGBColor[
              0.7541320519498573, 0.8078529576898866, 0.9761284932398044], 35 -> 
             RGBColor[
              0.9806606251290165, 0.9850973064033163, 0.9176206965264995], 31 -> 
             RGBColor[
              0.9422224012297554, 0.9564301419560625, 0.9826865832935536], 18 -> 
             RGBColor[
              0.44313584420957325`, 0.5582437284243628, 0.9494572020367609], 
             24 -> RGBColor[
              0.6206709682403175, 0.7029276787827933, 0.9632806386939997], 
             151 -> RGBColor[
              0.8196047957495463, 0.8590007627574865, 0.98265420446418], 137 -> 
             RGBColor[
              0.8951793726763501, 0.9192557490481049, 0.9898642017735719], 
             296 -> RGBColor[
              0.5261428915752986, 0.626185527704806, 0.9558390422311752], 266 -> 
             RGBColor[
              0.5094255145289768, 0.6126136079093484, 0.9545229890723189], 
             283 -> RGBColor[
              0.8656329339490414, 0.8956962208236628, 0.987046036071344], 284 -> 
             RGBColor[
              0.9522804127434639, 0.9639313904745038, 0.9656609933503809], 
             238 -> RGBColor[
              0.9947208773772945, 0.9911168154482327, 0.6667782653659292], 72 -> 
             RGBColor[
              0.8319151165312147, 0.8688105484604599, 0.9838300005457807], 
             288 -> RGBColor[
              0.44680426950279906`, 0.5614211340329386, 0.949690950852584], 
             172 -> RGBColor[
              0.8718284963665541, 0.9006363941213258, 0.9876369743455702], 
             243 -> RGBColor[
              0.9578956686862948, 0.9681192391625294, 0.9561558297324727], 88 -> 
             RGBColor[
              0.8335907815575044, 0.8701466782677079, 0.9839898269718721], 
             273 -> RGBColor[
              0.4410330676114571, 0.5564224090236993, 0.9493232149713412], 
             202 -> RGBColor[
              0.5539470622278762, 0.6487582060041822, 0.9580278883949791], 98 -> 
             RGBColor[
              0.9886245204847471, 0.9895639611310235, 0.8381846645724367], 30 -> 
             RGBColor[
              0.5520786919585615, 0.6472413788504311, 0.9578808034433128], 
             116 -> RGBColor[
              0.7610001145277616, 0.8132183403749543, 0.9768130375318761], 
             240 -> RGBColor[
              0.5684598118125378, 0.6605403099089288, 0.959170385204237], 73 -> 
             RGBColor[
              0.6567703018060368, 0.7317932185008263, 0.9664243838827534], 29 -> 
             RGBColor[
              0.45173975482815587`, 0.5656960033570574, 0.9500054356132375], 
             75 -> RGBColor[
              0.7123558334271439, 0.7752170582689224, 0.9719646301984188], 
             200 -> RGBColor[
              0.7144694481764624, 0.776868230175157, 0.9721752955637781], 156 -> 
             RGBColor[
              0.4720776574877907, 0.5822929350615275, 0.9515828289563285], 25 -> 
             RGBColor[
              0.588345011050631, 0.6766840104684299, 0.9607358209301448], 38 -> 
             RGBColor[
              0.8688098351059501, 0.8982293955714972, 0.9873490517397431], 3 -> 
             RGBColor[
              0.6522994735112058, 0.7283005734573508, 0.9659787735005905], 57 -> 
             RGBColor[
              0.966248010596395, 0.9743484020833775, 0.9420174935183288], 227 -> 
             RGBColor[
              0.6851858270916764, 0.7539916428199589, 0.9692565778850445], 39 -> 
             RGBColor[
              0.40133643345932796`, 0.522039179731971, 0.9467937805455229], 
             109 -> 
             RGBColor[
              0.46508607797029783`, 0.5766168558421588, 0.9510324262057118], 
             256 -> RGBColor[
              0.47091817310878165`, 0.5813516134084719, 0.9514915500986817], 
             287 -> RGBColor[
              0.9611953255826178, 0.9705801178731148, 0.9505703712953464], 
             239 -> RGBColor[
              0.7715564439870353, 0.8214650251796143, 0.977865193797869], 285 -> 
             RGBColor[
              0.5094255145289768, 0.6126136079093484, 0.9545229890723189], 
             216 -> RGBColor[
              0.8042153666647469, 0.8469784237924483, 0.9811203299953987], 21 -> 
             RGBColor[
              0.6775384912794754, 0.7480174859615627, 0.9684943629197006], 
             175 -> RGBColor[
              0.7974105761310768, 0.8416624697092214, 0.9804420920693854], 7 -> 
             RGBColor[
              0.8228095330488325, 0.8615500033560876, 0.9829615018645808], 13 -> 
             RGBColor[
              0.677463051362164, 0.7479585517247944, 0.9684868437737691], 294 -> 
             RGBColor[
              0.7545623464266888, 0.8081891070055465, 0.9761713809719246], 
             193 -> RGBColor[
              0.45216377247386785`, 0.5660632661300266, 0.9500324536426782], 
             60 -> RGBColor[
              0.4897941493957318, 0.5966759813112592, 0.9529775360969699], 65 -> 
             RGBColor[
              0.9943594203731666, 0.9919354896150895, 0.7431425319761691], 69 -> 
             RGBColor[
              0.6344411749538242, 0.7141069529335611, 0.9643646798084162], 
             217 -> RGBColor[
              0.6573900253769791, 0.7322773512645201, 0.9664861521366589], 
             214 -> RGBColor[
              0.971569955079032, 0.9783174995646439, 0.9330088296946482], 170 -> 
             RGBColor[
              0.6120172587803108, 0.6959022075979913, 0.9625993869857258], 74 -> 
             RGBColor[
              0.5601684350181585, 0.6538089967049837, 0.9585176576506695], 
             246 -> RGBColor[
              0.5583715506724379, 0.6523502050444104, 0.9583762003327703], 
             264 -> RGBColor[
              0.9637969518325267, 0.9725204064705248, 0.9461664966670491], 
             278 -> RGBColor[
              0.8816958170683138, 0.9085043278076237, 0.9885781282027652], 45 -> 
             RGBColor[
              0.5164034833414942, 0.6182786373452627, 0.9550723203383822], 
             237 -> RGBColor[
              0.6442387766460941, 0.7220034958027604, 0.9651753585685711], 
             228 -> RGBColor[
              0.5633470614340523, 0.6563895488248945, 0.958767890765821], 180 -> 
             RGBColor[
              0.4783633952512165, 0.5873959801471358, 0.9520776652584815], 53 -> 
             RGBColor[
              0.5804296183899783, 0.6702579381221363, 0.9601126922248594], 48 -> 
             RGBColor[
              0.5033051301440463, 0.6076448041454874, 0.9540411699938304], 5 -> 
             RGBColor[
              0.6429779632921988, 0.7210185388281609, 0.9650496924764255], 
             101 -> RGBColor[
              0.8369535919278004, 0.872828091975926, 0.9843105748270071], 267 -> 
             RGBColor[
              0.8714766928435875, 0.9003558755415645, 0.987603419011491], 120 -> 
             RGBColor[
              0.6033963760078507, 0.688903386596965, 0.9619207195145435], 147 -> 
             RGBColor[
              0.42623175327118024`, 0.5436022544778412, 0.9483800883098672], 
             89 -> RGBColor[0.178927, 0.305394, 0.933501], 43 -> 
             RGBColor[
              0.8285005403819139, 0.8660878581252078, 0.9835043152244323], 
             199 -> RGBColor[
              0.891555995583138, 0.9163665665079288, 0.9895186008317944], 268 -> 
             RGBColor[
              0.6369585477031063, 0.7161506695377783, 0.9645628566126799], 
             169 -> RGBColor[
              0.8858103307696715, 0.5743732063474587, 0.22642967976034203`], 
             20 -> RGBColor[
              0.4513111663521255, 0.5653247815606031, 0.9499781263345307], 4 -> 
             RGBColor[0.8641013868015587, 0.894475006701, 0.9868999557371888],
              167 -> RGBColor[
              0.38791675133940295`, 0.510415725572527, 0.9459386902674002], 
             142 -> RGBColor[
              0.6094944206157835, 0.6938540539234639, 0.9624007799239535], 16 -> 
             RGBColor[
              0.9926291210796987, 0.991219966390577, 0.7718180691399621], 281 -> 
             RGBColor[
              0.42263675882639246`, 0.5404884509794406, 0.948151018442774], 
             289 -> RGBColor[
              0.9675564839778001, 0.975324259388801, 0.9398025893881239], 178 -> 
             RGBColor[
              0.6621589608727815, 0.7360028799190931, 0.9669614750586444], 58 -> 
             RGBColor[
              0.672601295275567, 0.74416051091923, 0.9680022693627509], 186 -> 
             RGBColor[
              0.6953828862448079, 0.7619576629309052, 0.9702729254444931], 
             122 -> RGBColor[
              0.7093476699343765, 0.7728670580854832, 0.9716648045743459], 
             249 -> 
             RGBColor[
              0.5419738711499404, 0.6390378301010027, 0.95708531493408], 113 -> 
             RGBColor[
              0.9836244109761746, 0.9873076930353728, 0.9126037801664102], 52 -> 
             RGBColor[
              0.767785889243257, 0.8185194391564972, 0.9774893801388466], 187 -> 
             RGBColor[
              0.8492945222838362, 0.8826684148561984, 0.9854876637812444], 
             259 -> RGBColor[
              0.5704903796423174, 0.6621888163491821, 0.9593302389420124], 42 -> 
             RGBColor[
              0.2819126156606254, 0.4136384117244858, 0.9393658784583073], 
             134 -> RGBColor[
              0.8260097596401966, 0.8641017771722046, 0.9832667423337411], 
             248 -> RGBColor[
              0.7732460492921269, 0.8227849576854278, 0.9780335978644212], 
             174 -> RGBColor[
              0.6751116386996786, 0.7461216102814626, 0.9682524769347732], 
             215 -> RGBColor[
              0.9456411213216189, 0.9589798178029338, 0.9768995819230318], 83 -> 
             RGBColor[
              0.7203298179414004, 0.7814463955759865, 0.972759402453678], 95 -> 
             RGBColor[
              0.9302792108900502, 0.9472434072799822, 0.9932120556763901], 
             166 -> RGBColor[
              0.8891780996152436, 0.9144704968093964, 0.9892917949916039], 
             233 -> RGBColor[
              0.46376785653177266`, 0.575546664293165, 0.9509286509852669], 
             295 -> RGBColor[
              0.44596946797184733`, 0.5606980709051732, 0.9496377580372178], 
             141 -> RGBColor[
              0.7545623464266888, 0.8081891070055465, 0.9761713809719246], 
             205 -> RGBColor[
              0.9950665648992029, 0.9922279120493909, 0.7314233171483777], 
             224 -> RGBColor[
              0.4400166820127725, 0.5555420669031443, 0.9492584517797475], 
             231 -> RGBColor[
              0.4313710770898418, 0.54805367845964, 0.9487075614790667], 68 -> 
             RGBColor[
              0.4666301856327171, 0.5778704320037683, 0.9511539840171502], 10 -> 
             RGBColor[
              0.727193379848213, 0.786808262302591, 0.9734434981609164], 250 -> 
             RGBColor[
              0.48125112967427297`, 0.5897403730427263, 0.9523049982903843], 
             282 -> RGBColor[
              0.5177912438258697, 0.6194052838243761, 0.9551815699272465], 
             232 -> RGBColor[
              0.4019463141930089, 0.5225674277699884, 0.9468326416065767], 
             253 -> RGBColor[
              0.5154649948115527, 0.6175167300782297, 0.9549984390835085], 55 -> 
             RGBColor[
              0.3395962956244392, 0.468562975488946, 0.942859753557344], 91 -> 
             RGBColor[
              0.5471441680923812, 0.6432353100780991, 0.9574923396488106], 
             105 -> RGBColor[
              0.46376785653177266`, 0.575546664293165, 0.9509286509852669], 
             36 -> RGBColor[
              0.4666301856327171, 0.5778704320037683, 0.9511539840171502], 
             123 -> RGBColor[
              0.5286028626590691, 0.6281826430510452, 0.9560327001660606], 94 -> 
             RGBColor[
              0.6844589879585816, 0.7534238305650032, 0.9691841333529555], 96 -> 
             RGBColor[
              0.3928419838344997, 0.5146817144103968, 0.9462525217267757], 2 -> 
             RGBColor[
              0.9758872109779696, 0.9303240420558997, 0.3608267972778807], 
             262 -> RGBColor[
              0.5177912438258697, 0.6194052838243761, 0.9551815699272465], 
             272 -> RGBColor[
              0.9080848590187389, 0.9295462335474313, 0.9910951385817727], 97 -> 
             RGBColor[
              0.5268370624987628, 0.626749086932518, 0.9558936899091022], 209 -> 
             RGBColor[
              0.9297599804007444, 0.9468293869819461, 0.9931625310087976], 66 -> 
             RGBColor[
              0.41349155266570226`, 0.5325673330544773, 0.9475682939930031], 
             139 -> RGBColor[
              0.8718284963665541, 0.9006363941213258, 0.9876369743455702], 56 -> 
             RGBColor[
              0.6875435529253411, 0.7558335161605978, 0.9694915739619436], 
             144 -> RGBColor[
              0.5383788081114573, 0.6361191959706178, 0.9568022984025407], 
             298 -> RGBColor[
              0.49287538150257193`, 0.5991774643435166, 0.9532201019753455], 
             204 -> RGBColor[
              0.9552561495576621, 0.9661506901182111, 0.9606238471204037], 
             207 -> RGBColor[
              0.6017815194828483, 0.6875923733215107, 0.961793592093481], 149 -> 
             RGBColor[
              0.8645090307487043, 0.8948000509192537, 0.9869388371807756], 
             219 -> RGBColor[
              0.5738469324446547, 0.6649138171251001, 0.9595944790740705], 9 -> 
             RGBColor[
              0.5099619364607154, 0.6130490993990664, 0.9545652181717637], 11 -> 
             RGBColor[
              0.5335610251940813, 0.632207902759645, 0.9564230248831646], 44 -> 
             RGBColor[
              0.6953618192514746, 0.7619412052355982, 0.9702708256834798], 
             153 -> 
             RGBColor[
              0.6912499382777804, 0.7587289725674953, 0.9698609918157344], 32 -> 
             RGBColor[
              0.8862338998445904, 0.9121228718304514, 0.9890109745891609], 
             162 -> RGBColor[
              0.8126717563760202, 0.853584619705837, 0.9819631838923635], 90 -> 
             RGBColor[
              0.8496839745464091, 0.8829789535189739, 0.9855248100857168], 8 -> 
             RGBColor[
              0.4261776004252764, 0.5435553500045205, 0.9483766377384116], 
             163 -> RGBColor[
              0.6621589608727815, 0.7360028799190931, 0.9669614750586444], 49 -> 
             RGBColor[
              0.6484142135845097, 0.7252653788735467, 0.9655915271009157], 76 -> 
             RGBColor[
              0.8561711499236236, 0.8881516510750802, 0.9861435626643653], 82 -> 
             RGBColor[
              0.4944036010659589, 0.6004181418305808, 0.953340409017428], 67 -> 
             RGBColor[
              0.9292467756037445, 0.9464201714073914, 0.9931135810771164], 
             211 -> RGBColor[
              0.2734763794305684, 0.4047713925584252, 
               0.9388854472852988]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJwtl3k4FGrYxsc2dmbMmGEYZp8hUUJS8qQSUSklLeLUoUhCylJkaUGShISD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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 5}], {
             RGBColor[
             0.7591879538051727, 0.8122505569280014, 0.9765135619770512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 32}], {
             RGBColor[
             0.8808159220813685, 0.9078027234291467, 0.988494203033419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 51}], {
             RGBColor[
             0.7164175133964503, 0.7775370683460301, 0.9731400335254279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 80}], {
             RGBColor[
             0.8717743980837099, 0.9005932576190445, 0.9876318144030585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 83}], {
             RGBColor[
             0.7978638811297735, 0.8424644853019143, 0.9803684169656774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 92}], {
             RGBColor[
             0.5447225912135772, 0.6228950860160583, 0.9617392385411243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 125}], {
             RGBColor[
             0.9206380045586022, 0.9387775360706481, 0.96531057336679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 128}], {
             RGBColor[
             0.8659999535755292, 0.8959888723113418, 0.9870810427309606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 142}], {
             RGBColor[
             0.742446182466965, 0.798668314475653, 0.9751891057008152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 149}], {
             RGBColor[
             0.8699534875334254, 0.8991413129735479, 0.9874581343292262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 150}], {
             RGBColor[
             0.8246775022609838, 0.8634114899206842, 0.9830409481325005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 197}], {
             RGBColor[
             0.7567119026847215, 0.8102498688117997, 0.976312155453412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 198}], {
             RGBColor[
             0.7888624117583773, 0.8354324690152786, 0.9794712346222505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 237}], {
             RGBColor[
             0.7598183604821203, 0.8127430354153011, 0.976576395023124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 243}], {
             RGBColor[
             0.9166468065022206, 0.9358009070951857, 0.9720666306050748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 256}], {
             RGBColor[
             0.6731580587134641, 0.7424170942181569, 0.9697344907881793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 277}], {
             RGBColor[
             0.8650192758868489, 0.8952069065421749, 0.986987504817553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 281}], {
             RGBColor[
             0.6490173515722695, 0.7219855130036413, 0.9680642249602255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 49}], {
             RGBColor[
             0.8121507122812397, 0.8277947104647232, 0.6632091621893982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 54}], {
             RGBColor[
             0.9737285830285007, 0.9543207708102718, 0.6469178134862644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 102}], {
             RGBColor[
             0.7479777223462918, 0.775788944424592, 0.6580938100950289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 165}], {
             RGBColor[
             0.8084401683488577, 0.8248750818916271, 0.6628536353255883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 172}], {
             RGBColor[
             0.9238578536722619, 0.9154802180886128, 0.6742318858117254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 174}], {
             RGBColor[
             0.8254994248388241, 0.8382228261686812, 0.664539637106327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 183}], {
             RGBColor[
             0.8016459880659377, 0.8193592602636189, 0.6623187725658144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 238}], {
             RGBColor[
             0.9853040441776321, 0.9607204287520662, 0.513802531321905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 253}], {
             RGBColor[
             0.7456761028947612, 0.7739203860670647, 0.6579126181806946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 24}], {
             RGBColor[
             0.6364852208757616, 0.715614126120072, 0.964629706097295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 59}], {
             RGBColor[
             0.5985536138305425, 0.6848195387213392, 0.9616435910426405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 65}], {
             RGBColor[
             0.8233294469421861, 0.8601180315362201, 0.8545606527383798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 72}], {
             RGBColor[
             0.7421072950212102, 0.7985555609589053, 0.9749043870231856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 106}], {
             RGBColor[
             0.804663259988063, 0.8478859977947086, 0.9618024770404461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 115}], {
             RGBColor[
             0.7326589329001434, 0.7910779938865007, 0.9739882534106356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 155}], {
             RGBColor[
             0.7623124911704019, 0.33218485781911694`, 0.4314715911668635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[
             0.732485614943613, 0.7909425965815939, 0.973970978696477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 169}], {
             RGBColor[
             0.7690549021404387, 0.6513368899024048, 0.5962042266304662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 194}], {
             RGBColor[
             0.6649446214424817, 0.7381790591279472, 0.967239123670754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 200}], {
             RGBColor[
             0.6833844608438341, 0.752584401816254, 0.9690770345321843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 210}], {
             RGBColor[
             0.6477830079226232, 0.7247722762131403, 0.9655286144194912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 227}], {
             RGBColor[
             0.6687426503014411, 0.7411461081386548, 0.9676176756928174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 228}], {
             RGBColor[
             0.607823267472629, 0.6923450611411226, 0.9623733321332057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 241}], {
             RGBColor[
             0.5169770181535922, 0.6166461530301557, 0.9557592213257198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 264}], {
             RGBColor[
             0.8080482126718662, 0.8504104899639378, 0.9560726350838198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 290}], {
             RGBColor[
             0.5677642801839844, 0.6598233706233891, 0.9592197419129381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 291}], {
             RGBColor[
             0.6622497876097879, 0.7360738344563512, 0.9669705278189651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 8}], {
             RGBColor[
             0.6451394936134176, 0.7190151783527603, 0.9676382967378002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 15}], {
             RGBColor[
             0.8770649560262395, 0.744001024501729, 0.6084247001850465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 62}], {
             RGBColor[
             0.8616866204913318, 0.8925495375923105, 0.986669633170832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 85}], {
             RGBColor[
             0.6226042172648963, 0.6994962546355938, 0.9662023688560348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 121}], {
             RGBColor[
             0.742880710736838, 0.7991028270850316, 0.9751292286818847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 135}], {
             RGBColor[
             0.7344031288277535, 0.792220344180524, 0.9744618423795959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 158}], {
             RGBColor[
             0.9287213841395165, 0.9413206099539739, 0.7517643028347784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 173}], {
             RGBColor[
             0.9268727265663403, 0.9422302881203164, 0.90409405356756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 186}], {
             RGBColor[
             0.7797421365231834, 0.8282163348159526, 0.9785864405908409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 213}], {
             RGBColor[
             0.7162805993070482, 0.7775076583049644, 0.973035170470713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 214}], {
             RGBColor[
             0.9178356709402953, 0.9363962531328219, 0.9599543927159184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 249}], {
             RGBColor[
             0.7030376289757496, 0.7667564184010014, 0.9719926353356344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 255}], {
             RGBColor[
             0.8759671208438715, 0.9039364209395699, 0.9880317200428104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 263}], {
             RGBColor[
             0.7421812015401053, 0.7985349340065939, 0.9750741607555313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 265}], {
             RGBColor[
             0.7389535622401422, 0.7959145910193903, 0.9748200691666059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 276}], {
             RGBColor[
             0.6809505253841086, 0.7488251126926295, 0.9702538576331741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 286}], {
             RGBColor[
             0.9284708694639491, 0.9407847843938542, 0.7244973263966239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.5882694942431401, 0.676613220793903, 0.960736358679795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 23}], {
             RGBColor[
             0.5548040744624579, 0.6494444854159647, 0.9581018382467879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 51}], {
             RGBColor[
             0.6002075228834765, 0.6863050502461896, 0.9616761640248022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.593892858721039, 0.6811785214067442, 0.961179050530558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[
             0.6816538906167996, 0.7512324672020737, 0.9689045474650517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 92}], {
             RGBColor[
             0.4285126007006034, 0.5316630679162178, 0.9502753690404986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 101}], {
             RGBColor[
             0.7399657776099996, 0.7969233154020434, 0.9746801336517164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 128}], {
             RGBColor[
             0.7497899630625553, 0.8047568542115013, 0.9756171732303349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 142}], {
             RGBColor[
             0.6262361919539912, 0.7074362963758124, 0.9637252362001895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 149}], {
             RGBColor[
             0.7537434970204515, 0.8079092948737073, 0.9759942648286005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 197}], {
             RGBColor[
             0.6405019121717477, 0.7190178507119591, 0.9648482859527863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 198}], {
             RGBColor[
             0.6726524212454035, 0.7442004509154381, 0.9680073651216248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 204}], {
             RGBColor[
             0.7991170564249305, 0.843584614473186, 0.9628367697984146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 226}], {
             RGBColor[
             0.6886405282827056, 0.7566904816470925, 0.9696009102137482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 243}], {
             RGBColor[
             0.8004368159892468, 0.8445688889953451, 0.9606027611044491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 256}], {
             RGBColor[
             0.5569480682004903, 0.6511850761183164, 0.9582706212875536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 290}], {
             RGBColor[
             0.5631035250744809, 0.6561823533087942, 0.9587552014008556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 38}], {
             RGBColor[
             0.7001257981098953, 0.7643583921395218, 0.9718026201956955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 52}], {
             RGBColor[
             0.6496138251785487, 0.7245034139320219, 0.9668727843952472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.5559356897519094, 0.6503726634148415, 0.9581844404382536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 88}], {
             RGBColor[
             0.6825162713356725, 0.7503170334876272, 0.97012300781176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 93}], {
             RGBColor[
             0.7072767774871935, 0.7700603889868154, 0.9724846869924568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 124}], {
             RGBColor[
             0.7627608378791665, 0.8111536477604299, 0.8520154269447926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 147}], {
             RGBColor[
             0.47883675719251034`, 0.5870448215926939, 0.9523181384807575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 273}], {
             RGBColor[
             0.4862374143626488, 0.593454898865623, 0.9527897018114946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 289}], {
             RGBColor[
             0.7494991225458203, 0.8029058240481738, 0.9480293890198859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 42}], {
             RGBColor[
             0.5523610743547289, 0.6375942075402867, 0.961163690161444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 60}], {
             RGBColor[
             0.6563018412222822, 0.7291129923336734, 0.9679695189807753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 77}], {
             RGBColor[
             0.8571813828184457, 0.8889571833633698, 0.986239919579719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 80}], {
             RGBColor[
             0.8454801924490529, 0.8796269717831673, 0.9851238495965103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 81}], {
             RGBColor[
             0.7699481505712127, 0.8202314518714375, 0.9776988337087266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 82}], {
             RGBColor[
             0.6586065670573957, 0.7309840725933342, 0.9681509554410044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 103}], {
             RGBColor[
             0.8021613382233517, 0.8453966388945824, 0.9809095432045378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 127}], {
             RGBColor[
             0.7796696164648894, 0.8278259349134551, 0.9786677785767444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 130}], {
             RGBColor[
             0.7884707924993449, 0.8347014805229871, 0.9795449975521926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 140}], {
             RGBColor[
             0.6403640152259125, 0.7161739471989415, 0.9667148349361607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 145}], {
             RGBColor[
             0.7196903230684462, 0.7805746175149542, 0.9729596924713653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 154}], {
             RGBColor[
             0.888807870960667, 0.9136825642240081, 0.9721734906008181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 167}], {
             RGBColor[
             0.6053631421941177, 0.6859828644643073, 0.9644500960659905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 168}], {
             RGBColor[
             0.6447022227506269, 0.7196958995015266, 0.9670563545238842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 181}], {
             RGBColor[
             0.8301023356727935, 0.8673650862105803, 0.9836570958892159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 201}], {
             RGBColor[
             0.6260012245119576, 0.703858534067842, 0.9657651364217437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 202}], {
             RGBColor[
             0.6883782976383543, 0.7551541046801349, 0.9704946951297799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 203}], {
             RGBColor[
             0.9087652052130635, 0.9263334094021601, 0.824869883615255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 205}], {
             RGBColor[
             0.9089380489740178, 0.9268889577027393, 0.8571924095064792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 216}], {
             RGBColor[
             0.8135124498567897, 0.854264213574268, 0.9820409159299897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 237}], {
             RGBColor[
             0.7335241548474634, 0.7917767495794239, 0.9740684302165759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 255}], {
             RGBColor[
             0.8553211939675084, 0.8874739192671137, 0.9860624931065064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 269}], {
             RGBColor[
             0.7478447204204409, 0.8029640842453636, 0.9754957703595963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 282}], {
             RGBColor[
             0.6703003884373511, 0.7404776435902318, 0.9690715358959137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 293}], {
             RGBColor[
             0.680785623229725, 0.7489900295491254, 0.9698969719874498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 299}], {
             RGBColor[
             0.676731290958005, 0.7456985399653557, 0.9695778000995117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 14}], {
             RGBColor[
             0.4321321793538893, 0.5487129069866459, 0.9487560582423155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 64}], {
             RGBColor[
             0.5384885989708128, 0.6353421044676048, 0.9571029588084865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 67}], {
             RGBColor[
             0.6777121880145105, 0.744987760705956, 0.970745109407764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 69}], {
             RGBColor[
             0.5303093876895504, 0.6288311514690408, 0.956370658773414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 85}], {
             RGBColor[
             0.4036423240767552, 0.5240364262873541, 0.9469407098566462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 121}], {
             RGBColor[
             0.5239188175486968, 0.6236429987367919, 0.9558675696824961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 135}], {
             RGBColor[
             0.5154412356396123, 0.6167605158322842, 0.9552001833802073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 173}], {
             RGBColor[
             0.7079108333781993, 0.7667704597720766, 0.8848323945681714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 186}], {
             RGBColor[
             0.5607802433350422, 0.6527565064677128, 0.9593247815914523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 213}], {
             RGBColor[
             0.4973187061189071, 0.6020478299567247, 0.9537735114713244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 234}], {
             RGBColor[
             0.4208102410088475, 0.538906413049338, 0.9480346343425663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 249}], {
             RGBColor[
             0.48407573578760843`, 0.5912965900527616, 0.9527309763362458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 263}], {
             RGBColor[
             0.5232193083519642, 0.6230751056583541, 0.9558125017561427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 286}], {
             RGBColor[
             0.709508976275808, 0.7653249560456143, 0.7052356673972353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 45}], {
             RGBColor[
             0.5131827099011048, 0.6156638683721645, 0.9548187692550729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 47}], {
             RGBColor[
             0.7301711706096352, 0.7877817335147013, 0.9617212147195738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 96}], {
             RGBColor[
             0.4514019601476076, 0.5638654069047315, 0.9504088699492697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 112}], {
             RGBColor[
             0.4904400547847485, 0.5972003564037691, 0.9530283841352227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 132}], {
             RGBColor[
             0.5497998629115997, 0.6453913227700288, 0.9577014056731101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 133}], {
             RGBColor[
             0.46245588257208486`, 0.5734397589225184, 0.9511132161115575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 141}], {
             RGBColor[
             0.6322621414437022, 0.7106191032023064, 0.9653682995718441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 146}], {
             RGBColor[
             0.44871817034142675`, 0.5615408430658155, 0.950237861236002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 236}], {
             RGBColor[
             0.4762627698664525, 0.5853985907425665, 0.9519929787610035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 22}], {
             RGBColor[
             0.5933342793007048, 0.679434968696089, 0.9620171069134285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 48}], {
             RGBColor[
             0.6152492549961297, 0.6972265332240393, 0.9637423340773734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 63}], {
             RGBColor[
             0.7478700739527673, 0.8029610528857644, 0.9755043577945661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 71}], {
             RGBColor[
             0.5577362776727042, 0.648768950732315, 0.959702640887586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 73}], {
             RGBColor[
             0.6919818408271249, 0.7593007404017087, 0.9699339410218348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 100}], {
             RGBColor[
             0.6702440464634165, 0.7418737824243051, 0.9680717255142371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 119}], {
             RGBColor[
             0.8567024762961755, 0.887687203766472, 0.9258084756519145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 122}], {
             RGBColor[
             0.7182705248912947, 0.7798376601940371, 0.9725541513676311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 161}], {
             RGBColor[
             0.6284121300418122, 0.7079127481668874, 0.9647785638181696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 244}], {
             RGBColor[
             0.5767127295582444, 0.6652053995713656, 0.9609118036215151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 266}], {
             RGBColor[
             0.6183094471885948, 0.6997109351059697, 0.9639832436166176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 51}], {
             RGBColor[
             0.5454990538344178, 0.6418997322119316, 0.9573628302281716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 101}], {
             RGBColor[
             0.6852573085609408, 0.7525179973677856, 0.9703667998550858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 104}], {
             RGBColor[
             0.7589705216114526, 0.8100083265232033, 0.9324750397852459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 114}], {
             RGBColor[
             0.6170277616518967, 0.6990793978645512, 0.9636027140138113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 116}], {
             RGBColor[
             0.6472805698609214, 0.7227131215672997, 0.9666180312075203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 149}], {
             RGBColor[
             0.6990350279713928, 0.7635039768394494, 0.9716809310319701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 197}], {
             RGBColor[
             0.5857934431226889, 0.6746125326777013, 0.9605349521561558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 198}], {
             RGBColor[
             0.6179439521963448, 0.69979513288118, 0.9636940313249944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 204}], {
             RGBColor[
             0.7444085873758717, 0.799179296438928, 0.9585234360017841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 243}], {
             RGBColor[
             0.7457283469401881, 0.8001635709610873, 0.9562894273078186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 254}], {
             RGBColor[
             0.49243609577310343`, 0.598766342160124, 0.9532005756088476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 283}], {
             RGBColor[
             0.6995969795715613, 0.763952061791654, 0.9717345304772542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.9119733135670645, 0.9297769982392765, 0.877795534532487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 27}], {
             RGBColor[
             0.7740066265610417, 0.8234707309387148, 0.9780850960781589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.7410585517853896, 0.7977314445093326, 0.9748011399017866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 76}], {
             RGBColor[
             0.8437443279890269, 0.8782428405815281, 0.9849582812946887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 87}], {
             RGBColor[
             0.6386434870131388, 0.7145160504965746, 0.9667053789811149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 151}], {
             RGBColor[
             0.8254611509019882, 0.8636673964227313, 0.9832136021945959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 154}], {
             RGBColor[
             0.8930618574634659, 0.9170745775899524, 0.9725792396310338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 181}], {
             RGBColor[
             0.8343563221755923, 0.8707570995765246, 0.9840628449194315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 192}], {
             RGBColor[
             0.6192284673853502, 0.6976997363222441, 0.9654682710984599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 220}], {
             RGBColor[
             0.7630020875577348, 0.8148739014317374, 0.9769882664735732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 239}], {
             RGBColor[
             0.8014369750207327, 0.8448995276337952, 0.9808190968614404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 258}], {
             RGBColor[
             0.7573513457898995, 0.8104594990154763, 0.9764250533433395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 32}], {
             RGBColor[
             0.7818484756033772, 0.830040711777623, 0.978748909181465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 53}], {
             RGBColor[
             0.6289463348760711, 0.7091082449234654, 0.9642997679993143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 93}], {
             RGBColor[
             0.7802874226113553, 0.8287959704954393, 0.9786000145535174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 107}], {
             RGBColor[
             0.7478919661518202, 0.8029781552380513, 0.9755065398043734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 137}], {
             RGBColor[
             0.7863212120192571, 0.8336071503864497, 0.9791755227736705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 147}], {
             RGBColor[
             0.5518474023166722, 0.6457804031013178, 0.9584334660418181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 156}], {
             RGBColor[
             0.5747703544249774, 0.665125743393161, 0.9600348363650488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 179}], {
             RGBColor[
             0.5817775962837681, 0.6708145380067757, 0.9605864721125456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 251}], {
             RGBColor[
             0.7766021749322989, 0.8258574540295431, 0.9782485123400296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 270}], {
             RGBColor[
             0.7609347530136068, 0.8133646770724166, 0.976754139650952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 271}], {
             RGBColor[
             0.608290665233013, 0.6923390417799176, 0.9626736780208017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 273}], {
             RGBColor[
             0.5592480594868106, 0.6521904803742469, 0.9589050293725552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 274}], {
             RGBColor[
             0.5532704587315315, 0.6470129830429738, 0.9585241419382136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 277}], {
             RGBColor[
             0.7660518294088576, 0.8174448948906512, 0.9772422109655992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 282}], {
             RGBColor[
             0.5976271475940169, 0.6836819177745852, 0.9618342068505078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 289}], {
             RGBColor[
             0.8225097676699821, 0.8616414055567977, 0.9541447165809465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 67}], {
             RGBColor[
             0.6836667669431233, 0.7501453176880813, 0.9711245299116679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 173}], {
             RGBColor[
             0.7138654123068122, 0.771928016754202, 0.8852118150720752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 186}], {
             RGBColor[
             0.566734822263655, 0.6579140634498382, 0.9597042020953561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.50327328504752, 0.6072053869388501, 0.9541529319752282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 249}], {
             RGBColor[
             0.4900303147162213, 0.596454147034887, 0.9531103968401496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 46}], {
             RGBColor[
             0.8644421377395768, 0.7339359318372188, 0.6072207245083417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 60}], {
             RGBColor[
             0.689911337323326, 0.5951015118068586, 0.5914634903649371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.8746501897160126, 0.7420755553930394, 0.6081943776186897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 77}], {
             RGBColor[
             0.8907908789194896, 0.754945702836555, 0.6097338909638808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 82}], {
             RGBColor[
             0.6922160631584395, 0.5969725920665194, 0.5916449268251661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 103}], {
             RGBColor[
             0.8357708343243956, 0.7113851583677676, 0.6044035145886996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 127}], {
             RGBColor[
             0.8132791125659333, 0.6938144543866402, 0.6021617499609061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 135}], {
             RGBColor[
             0.7473666980524343, 0.6417463619812529, 0.5959865868274535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 158}], {
             RGBColor[
             0.9416849533641973, 0.7908466277547029, 0.373289047282636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 168}], {
             RGBColor[
             0.6783117188516707, 0.5856844189747117, 0.5905503259080458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 186}], {
             RGBColor[
             0.7927057057478641, 0.6777423526166815, 0.6001111850386986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 196}], {
             RGBColor[
             0.9417022742555838, 0.790883675389968, 0.37517431941790547`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 212}], {
             RGBColor[
             0.6800345271764444, 0.5870830723843935, 0.5906859516902269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 214}], {
             RGBColor[
             0.9307992401649761, 0.7859222709335509, 0.5814791371637762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 225}], {
             RGBColor[
             0.9277251414036514, 0.7836296131107297, 0.5866827845133339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 255}], {
             RGBColor[
             0.8889306900685523, 0.7534624387402988, 0.6095564644906681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 265}], {
             RGBColor[
             0.751917131464823, 0.6454406088201192, 0.5963448136144636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 276}], {
             RGBColor[
             0.6939140946087894, 0.5983511304933584, 0.5917786020810317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 286}], {
             RGBColor[
             0.9414344386886299, 0.790310802194583, 0.34602207084448156`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.9849318971037531, 0.9868811017004365, 0.8476190043865607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 39}], {
             RGBColor[
             0.6969827772695133, 0.756629573061274, 0.8593059248427425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 76}], {
             RGBColor[
             0.9244001355016611, 0.9396858087328286, 0.8789808159021637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 90}], {
             RGBColor[
             0.9211565478130539, 0.9370994599547755, 0.8786714396128394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 126}], {
             RGBColor[
             0.955732302410749, 0.9646692281371212, 0.8819693059525081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 151}], {
             RGBColor[
             0.9061169584146225, 0.9251103645740317, 0.877236136802071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 153}], {
             RGBColor[
             0.8419395296787395, 0.8749744694790361, 0.8708395304778482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 192}], {
             RGBColor[
             0.6998842748979844, 0.7591427044735445, 0.8594908057059351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 220}], {
             RGBColor[
             0.843657895070369, 0.8763168695830379, 0.8710108010810482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 222}], {
             RGBColor[
             0.8710942278721265, 0.8977503412916232, 0.8737453983276201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 239}], {
             RGBColor[
             0.882092782533367, 0.9063424957850956, 0.8748416314689156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 248}], {
             RGBColor[
             0.8829375851859128, 0.9070024620380024, 0.8749258335021917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 285}], {
             RGBColor[
             0.7510273178043377, 0.8019167871499626, 0.8631705291061404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 40}], {
             RGBColor[
             0.7526551667125978, 0.8066992037177958, 0.9759812911216317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[
             0.5290671047216267, 0.6193739436904344, 0.9588480253947487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 66}], {
             RGBColor[
             0.5948565732241651, 0.6788384043554301, 0.9629492331620966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 81}], {
             RGBColor[
             0.7466541809381104, 0.8020111880215852, 0.9753831689420313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 86}], {
             RGBColor[
             0.6092802937828119, 0.6913315061460557, 0.9638682998816983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 94}], {
             RGBColor[
             0.7303402908706048, 0.7892666531106931, 0.9737571528420728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 97}], {
             RGBColor[
             0.6515293281406954, 0.7259292812944504, 0.9671119311201462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 120}], {
             RGBColor[
             0.6898089848952393, 0.757006431126674, 0.9701254459228668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 130}], {
             RGBColor[
             0.7651768228662427, 0.8164812166731348, 0.9772293327854973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 140}], {
             RGBColor[
             0.6170700455928102, 0.6979536833490891, 0.9643991701694654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 162}], {
             RGBColor[
             0.7944466750793241, 0.83934704768111, 0.9801466781117768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 169}], {
             RGBColor[
             0.8310159622761497, 0.6997413410019209, 0.6023799260457661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 178}], {
             RGBColor[
             0.7191902773277048, 0.780556177787738, 0.9726458236949173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 182}], {
             RGBColor[
             0.7659713730392985, 0.817101925307131, 0.977308526121254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 201}], {
             RGBColor[
             0.6027072548788553, 0.6856382702179897, 0.9634494716550484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 202}], {
             RGBColor[
             0.6650843280052521, 0.7369338408302826, 0.9681790303630846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 294}], {
             RGBColor[
             0.7653919701046584, 0.8166492913309646, 0.9772507766515574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 26}], {
             RGBColor[
             0.5129456296670579, 0.6151949265557836, 0.9548764947501197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 33}], {
             RGBColor[
             0.7101852586686903, 0.7703929827173295, 0.9364385708349601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 35}], {
             RGBColor[
             0.7118982346692948, 0.7716705174138395, 0.9335389492816302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 129}], {
             RGBColor[
             0.6898327004301346, 0.75521407810727, 0.9708901431355001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 165}], {
             RGBColor[
             0.5420644849646595, 0.6388349250758587, 0.9571688377050285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 175}], {
             RGBColor[
             0.620273210170325, 0.6999530990667922, 0.9649496470530732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 183}], {
             RGBColor[
             0.5352703046817395, 0.6333191034478505, 0.9566339749452546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 184}], {
             RGBColor[
             0.4730231719631651, 0.5827840769055392, 0.9517336526388881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.4415762631111729, 0.5568928976637535, 0.9493578269082542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 253}], {
             RGBColor[
             0.479300419510563, 0.5878802292512962, 0.9522278205601347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 262}], {
             RGBColor[
             0.4804635440177215, 0.5888245061243694, 0.9523193859820036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 36}], {
             RGBColor[
             0.45897067599242125`, 0.5715976067821857, 0.9505660551758405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 37}], {
             RGBColor[
             0.722864141931943, 0.7778959426856461, 0.791847002462841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 41}], {
             RGBColor[
             0.5614674139720797, 0.6543607788079829, 0.9589414771541067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 44}], {
             RGBColor[
             0.5733364928018, 0.6636329933981007, 0.9601244760090053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 55}], {
             RGBColor[
             0.39545373098828235`, 0.5169438785247745, 0.9464189399459373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 61}], {
             RGBColor[
             0.708366461954254, 0.7695284827398021, 0.9466971253641472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 71}], {
             RGBColor[
             0.41979517092466045`, 0.5380272103613211, 0.9479699549743932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 108}], {
             RGBColor[
             0.5399556898980981, 0.6373448894041144, 0.9569414921283761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 136}], {
             RGBColor[
             0.5104811023392413, 0.6134160914087966, 0.9546211446267711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 152}], {
             RGBColor[
             0.5942632481316689, 0.6799811337110253, 0.9622102594086392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 177}], {
             RGBColor[
             0.5064002947639695, 0.6101031079809047, 0.954299888505955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 208}], {
             RGBColor[
             0.4309017657403116, 0.5476471845569513, 0.9486776573748703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 252}], {
             RGBColor[
             0.7231757834479313, 0.7785625123765545, 0.8257672582496666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 268}], {
             RGBColor[
             0.5441348570276159, 0.6407377255491906, 0.9572704914736053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 279}], {
             RGBColor[
             0.5662565673229568, 0.6581021018046017, 0.9594188152029395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 280}], {
             RGBColor[
             0.6777064311190226, 0.7458474744730037, 0.9703466736304417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 50}], {
             RGBColor[
             0.8202060626578138, 0.8172218386297695, 0.6393829355932089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 74}], {
             RGBColor[
             0.618853463148817, 0.7009132413332733, 0.9635060102851851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[
             0.6890164946945937, 0.75698418946551, 0.9696383830320793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 123}], {
             RGBColor[
             0.6030706769692722, 0.688100064506304, 0.9622635315428806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 189}], {
             RGBColor[
             0.6679541483592804, 0.7405301244286022, 0.9675390851881924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 206}], {
             RGBColor[
             0.668802074146785, 0.7411925304982756, 0.9676235985063739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 257}], {
             RGBColor[
             0.7902566196901382, 0.8367445278866479, 0.9795510472801352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 287}], {
             RGBColor[
             0.8193669084310466, 0.8592988019173388, 0.9595323671075235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 300}], {
             RGBColor[
             0.6703324264192714, 0.7423880533246499, 0.9677761297189402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.48139015444862154`, 0.5898532396175371, 0.9523159428298855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 63}], {
             RGBColor[
             0.6140109734052592, 0.6955877592792623, 0.9640779665470782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 70}], {
             RGBColor[
             0.631994943577793, 0.7096369734612813, 0.9658704406241199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 73}], {
             RGBColor[
             0.5581227402796167, 0.6519274467952066, 0.9585075497743469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 100}], {
             RGBColor[
             0.5363849459159085, 0.634500488817803, 0.9566453342667492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 119}], {
             RGBColor[
             0.7228433757486673, 0.7803139101599701, 0.9143820844044266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 122}], {
             RGBColor[
             0.5844114243437866, 0.6724643665875351, 0.9611277601201432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 161}], {
             RGBColor[
             0.494553029494304, 0.6005394545603855, 0.9533521725706817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 244}], {
             RGBColor[
             0.4428536290107362, 0.5578321059648635, 0.9494854123740272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 266}], {
             RGBColor[
             0.48445034664108677`, 0.5923376414994677, 0.9525568523691297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 24}], {
             RGBColor[
             0.5436505769365173, 0.6403990553932808, 0.957217311355575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 31}], {
             RGBColor[
             0.7044262934312362, 0.7671502869799154, 0.9669202836553519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 44}], {
             RGBColor[
             0.5809960024420958, 0.6699058186196832, 0.9607124048503151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 59}], {
             RGBColor[
             0.5057189698912982, 0.6096044679945478, 0.9542311963009205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 72}], {
             RGBColor[
             0.649272651081966, 0.7233404902321141, 0.9674919922814655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 83}], {
             RGBColor[
             0.5934800017870587, 0.6796584137898773, 0.9619566932354141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 106}], {
             RGBColor[
             0.7118286160488185, 0.7726709270679174, 0.9543900822987259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 136}], {
             RGBColor[
             0.5181406119795371, 0.6196889166303792, 0.9552090734680808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 155}], {
             RGBColor[
             0.700422728544239, 0.28204147733458945`, 0.4265299946723834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 194}], {
             RGBColor[
             0.5721099775032372, 0.662963988401156, 0.9598267289290339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 197}], {
             RGBColor[
             0.5523280233420067, 0.6474437972997629, 0.9579004317231486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 198}], {
             RGBColor[
             0.5844785324156627, 0.6726263975032417, 0.9610595108919873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 210}], {
             RGBColor[
             0.5549483639833788, 0.649557205486349, 0.958116219677771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 226}], {
             RGBColor[
             0.6004666394529647, 0.6851164282348962, 0.9626530559841104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 241}], {
             RGBColor[
             0.4241423742143478, 0.5414310823033645, 0.9483468265839996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 290}], {
             RGBColor[
             0.47492963624474005`, 0.5846082998965978, 0.9518073471712181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 291}], {
             RGBColor[
             0.5694151436705435, 0.66085876372956, 0.959558133077245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.6686833576539852, 0.7407675552861234, 0.9678389154626528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 59}], {
             RGBColor[
             0.5827393611950984, 0.6721330913840604, 0.9602945236393452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 65}], {
             RGBColor[
             0.807515194306742, 0.8474315841989414, 0.8532115853350843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 72}], {
             RGBColor[
             0.7262930423857661, 0.7858691136216266, 0.9735553196198903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 87}], {
             RGBColor[
             0.5333202181060824, 0.6318128748439833, 0.9564591983656088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 106}], {
             RGBColor[
             0.7888490073526189, 0.8351995504574299, 0.9604534096371506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 109}], {
             RGBColor[
             0.5428785231053077, 0.639772267312476, 0.9571565324498558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 155}], {
             RGBColor[
             0.7517696560801058, 0.3237272262609311, 0.43057221289799996`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 162}], {
             RGBColor[
             0.7166713623081689, 0.7782561492443152, 0.9726219112931815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 194}], {
             RGBColor[
             0.6491303688070376, 0.7254926117906685, 0.9658900562674586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 210}], {
             RGBColor[
             0.6319687552871791, 0.7120858288758616, 0.9641795470161958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 218}], {
             RGBColor[
             0.6275560715970709, 0.7085173158581772, 0.963822659251208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 226}], {
             RGBColor[
             0.677487030756765, 0.7476450516244086, 0.9687163833225352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 227}], {
             RGBColor[
             0.652928397665997, 0.728459660801376, 0.9662686082895221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 241}], {
             RGBColor[
             0.5011627655181481, 0.6039597056928769, 0.9544101539224243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 290}], {
             RGBColor[
             0.5519500275485403, 0.6471369232861104, 0.9578706745096428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 291}], {
             RGBColor[
             0.6464355349743438, 0.7233873871190725, 0.9656214604156698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 299}], {
             RGBColor[
             0.5756620085537474, 0.6663873776787086, 0.9597373685142211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 28}], {
             RGBColor[
             0.783945549413932, 0.8304750483698367, 0.9401215692376587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 58}], {
             RGBColor[
             0.6304731531630989, 0.71042226069383, 0.9643690451464478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 79}], {
             RGBColor[
             0.605362487095429, 0.6904995641501562, 0.9620754989814599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 113}], {
             RGBColor[
             0.7859847110134028, 0.8319958517519013, 0.9366698005482774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 134}], {
             RGBColor[
             0.7071773853454137, 0.7703928938203173, 0.972001281631943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 144}], {
             RGBColor[
             0.5633619095810442, 0.6564016032195239, 0.9587690596663427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 160}], {
             RGBColor[
             0.7846244856590763, 0.8309813979098093, 0.9389723072695618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 176}], {
             RGBColor[
             0.6258746084813283, 0.7068298426381967, 0.9639107051884123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.5333542031509237, 0.6320399953077829, 0.9564067430943131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 221}], {
             RGBColor[
             0.7855160148165434, 0.8149727001225067, 0.6739892933577682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 230}], {
             RGBColor[
             0.46562396496839237`, 0.5740555084154777, 0.9519031347988965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 232}], {
             RGBColor[
             0.4951456626218199, 0.5996257191192091, 0.9537842312683606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 245}], {
             RGBColor[
             0.5791253590029461, 0.6691990815955278, 0.9600100161482528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 288}], {
             RGBColor[
             0.517574640276715, 0.6190525722506842, 0.9552133858913644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 297}], {
             RGBColor[
             0.6487068873108903, 0.7246665923915967, 0.9661864133623662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 35}], {
             RGBColor[
             0.7817080201267796, 0.8286217155452603, 0.938958241994989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 54}], {
             RGBColor[
             0.7771626851017873, 0.8252318121259241, 0.9466523085790634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 75}], {
             RGBColor[
             0.6475556242758433, 0.7236815914780634, 0.9661302088309487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 102}], {
             RGBColor[
             0.5514118244195784, 0.6466999857402443, 0.9578283051878278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 129}], {
             RGBColor[
             0.7596424858876193, 0.8121652762386908, 0.9763094358488589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 165}], {
             RGBColor[
             0.6118742704221443, 0.6957861232072795, 0.9625881304183872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 175}], {
             RGBColor[
             0.6900829956278097, 0.756904297198213, 0.9703689397664319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 183}], {
             RGBColor[
             0.6050800901392243, 0.6902703015792713, 0.9620532676586133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 224}], {
             RGBColor[
             0.5113860485686575, 0.6138440957951743, 0.954777119621613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 253}], {
             RGBColor[
             0.5491102049680476, 0.644831427382717, 0.9576471132734935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 262}], {
             RGBColor[
             0.5502733294752062, 0.6457757042557902, 0.9577386786953626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 42}], {
             RGBColor[
             0.49930418136413923`, 0.5961229217569697, 0.9558815353448067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 72}], {
             RGBColor[
             0.7743054317994339, 0.8237089901249567, 0.9781135963885433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 87}], {
             RGBColor[
             0.5813326075197502, 0.6696527513473134, 0.961017475134262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 109}], {
             RGBColor[
             0.5908909125189754, 0.6776121438158061, 0.9617148092185088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 140}], {
             RGBColor[
             0.5873071222353228, 0.6747026614156244, 0.9614326801195234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 151}], {
             RGBColor[
             0.7681502714085997, 0.81880409727347, 0.9775256983477429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 154}], {
             RGBColor[
             0.8357509779700772, 0.872211278440691, 0.9668913357841808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 155}], {
             RGBColor[
             0.7837779156892177, 0.3489538105964845, 0.43361106407710204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 162}], {
             RGBColor[
             0.7646837517218366, 0.8160960257476453, 0.9771801880618347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 181}], {
             RGBColor[
             0.7770454426822038, 0.8258938004272632, 0.9783749410725785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 202}], {
             RGBColor[
             0.6353214046477647, 0.7136828188968178, 0.9652125403131425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 203}], {
             RGBColor[
             0.8557083122224738, 0.8848621236188431, 0.8195877287986175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 216}], {
             RGBColor[
             0.7604555568661999, 0.8127929277909509, 0.9767587611133524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 227}], {
             RGBColor[
             0.7009407870796647, 0.7662995373047061, 0.9708268850581752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 299}], {
             RGBColor[
             0.6236743979674152, 0.7042272541820387, 0.9642956452828741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 79}], {
             RGBColor[
             0.8009630254587299, 0.844290602051563, 0.9414612472889738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 144}], {
             RGBColor[
             0.7589624479443451, 0.8101926411209306, 0.9381548079738566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 160}], {
             RGBColor[
             0.9802250240223773, 0.984772435811216, 0.9183580555770757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 176}], {
             RGBColor[
             0.8214751468446293, 0.8606208805396034, 0.9432964534959262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 221}], {
             RGBColor[
             0.9811165531798445, 0.9687637380239136, 0.6533750416652822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 230}], {
             RGBColor[
             0.6612245033316934, 0.7278465463168846, 0.9312888831064104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 232}], {
             RGBColor[
             0.690746200985121, 0.753416757020616, 0.9331699795758746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 240}], {
             RGBColor[
             0.7740029497948854, 0.8224031980900861, 0.9393388513747047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 245}], {
             RGBColor[
             0.7747258973662472, 0.8229901194969345, 0.9393957644557667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 288}], {
             RGBColor[
             0.713175178640016, 0.772843610152091, 0.9345991341988783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 297}], {
             RGBColor[
             0.8443074256741913, 0.8784576302930034, 0.9455721616698801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 43}], {
             RGBColor[
             0.6401201476050349, 0.7158919307411327, 0.9667548754188349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 78}], {
             RGBColor[
             0.48302102760254473`, 0.5911344028572378, 0.9524561715658814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 99}], {
             RGBColor[
             0.5960976874260967, 0.6814324142408805, 0.9623853949660995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 131}], {
             RGBColor[
             0.4657502590619338, 0.5771132149167137, 0.9510965534014547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 170}], {
             RGBColor[
             0.5318785068042333, 0.6307991054775244, 0.9563024112994816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 178}], {
             RGBColor[
             0.5569493578504687, 0.6508494416380752, 0.9584834553359409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 182}], {
             RGBColor[
             0.6037304535620625, 0.6873951891574681, 0.9631461577622777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 190}], {
             RGBColor[
             0.5237654388659725, 0.6242125514356986, 0.9556637208722346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 199}], {
             RGBColor[
             0.671647875205647, 0.7410312849324932, 0.969762018222516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 209}], {
             RGBColor[
             0.6907498676144501, 0.7562626951695017, 0.9715839833110176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 229}], {
             RGBColor[
             0.4669184717576119, 0.5780616226104474, 0.9511885193841626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 259}], {
             RGBColor[
             0.5111150672352367, 0.6139424098531198, 0.9546678372776249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 261}], {
             RGBColor[
             0.4766934150803769, 0.5859973619560465, 0.9519580387293278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 284}], {
             RGBColor[
             0.7020100837858099, 0.7648136969157806, 0.9578332144818091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 74}], {
             RGBColor[
             0.55612356348836, 0.6505251877777074, 0.9581992305469912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 104}], {
             RGBColor[
             0.7682293549936927, 0.8175250645685963, 0.93320392906532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 123}], {
             RGBColor[
             0.5403407773088154, 0.6377120109507382, 0.9569567518046866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 189}], {
             RGBColor[
             0.6052242486988234, 0.6901420708730364, 0.9622323054499986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 236}], {
             RGBColor[
             0.49732114761537555`, 0.6024947304682489, 0.9536507713967781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 260}], {
             RGBColor[
             0.5715541372030032, 0.6630524226586788, 0.9594139818338618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 267}], {
             RGBColor[
             0.7117776924010746, 0.7737986271959978, 0.972742111227402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 287}], {
             RGBColor[
             0.7566370087705896, 0.808910748361773, 0.9542255873693296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 300}], {
             RGBColor[
             0.6076025267588144, 0.6919999997690841, 0.9624693499807464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 37}], {
             RGBColor[
             0.968319759370758, 0.9734486228833759, 0.8082012309423525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 44}], {
             RGBColor[
             0.818792110240615, 0.8591856735958303, 0.9764787044885167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 59}], {
             RGBColor[
             0.7435150776898174, 0.798884322970695, 0.9699974959391221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 61}], {
             RGBColor[
             0.953822079393069, 0.9650811629375319, 0.9630513538436587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 65}], {
             RGBColor[
             0.968290910801461, 0.974182815785576, 0.8629145576348614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 71}], {
             RGBColor[
             0.6652507883634754, 0.7335798905590507, 0.9643241834539047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 136}], {
             RGBColor[
             0.7559367197780562, 0.8089687716065264, 0.9709753731062825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 177}], {
             RGBColor[
             0.7518559122027846, 0.8056557881786345, 0.9706541169854664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 194}], {
             RGBColor[
             0.8099060853017565, 0.8522438433773031, 0.9755930285672356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 210}], {
             RGBColor[
             0.792744471781898, 0.8388370604624962, 0.9738825193159728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 226}], {
             RGBColor[
             0.8382627472514839, 0.8743962832110432, 0.9784193556223122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 241}], {
             RGBColor[
             0.661938482012867, 0.7307109372795115, 0.9641131262222014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 279}], {
             RGBColor[
             0.8117121847617719, 0.8536547820023315, 0.9757730436824509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 280}], {
             RGBColor[
             0.9231620485578376, 0.9414001546707333, 0.9867009021099531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 290}], {
             RGBColor[
             0.7127257440432593, 0.773888154872745, 0.9675736468094197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 291}], {
             RGBColor[
             0.8072112514690627, 0.8501386187057071, 0.9753244327154467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 80}], {
             RGBColor[
             0.8771923758469319, 0.9049134060203492, 0.9881485859588004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 92}], {
             RGBColor[
             0.5501405689767992, 0.6272152344173629, 0.9622560100968662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 107}], {
             RGBColor[
             0.8522773903930334, 0.8850603152908798, 0.9857686052120692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 125}], {
             RGBColor[
             0.9260559823218242, 0.9430976844719527, 0.9658273449225321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 128}], {
             RGBColor[
             0.8714179313387511, 0.9003090207126465, 0.9875978142867027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 142}], {
             RGBColor[
             0.747864160230187, 0.8029884628769577, 0.9757058772565572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 145}], {
             RGBColor[
             0.7514025064663251, 0.8058610517521361, 0.9759844288336552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 149}], {
             RGBColor[
             0.8753714652966473, 0.9034614613748526, 0.9879749058849683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 150}], {
             RGBColor[
             0.8300954800242057, 0.8677316383219889, 0.9835577196882426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 156}], {
             RGBColor[
             0.6791557786661906, 0.7472079034459894, 0.9702969017727447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 167}], {
             RGBColor[
             0.6370753255919968, 0.7112692987014892, 0.9674748324282805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 179}], {
             RGBColor[
             0.6861630205249813, 0.7528966980596041, 0.9708485375202414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 205}], {
             RGBColor[
             0.9406502323718966, 0.9521753919399212, 0.8602171458687693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 237}], {
             RGBColor[
             0.7652363382453422, 0.8170631838166058, 0.977093166578866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 256}], {
             RGBColor[
             0.6785760364766861, 0.7467372426194616, 0.9702512623439212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 269}], {
             RGBColor[
             0.7795569038183199, 0.8282505184825455, 0.9785205067218864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 277}], {
             RGBColor[
             0.8704372536500709, 0.8995270549434796, 0.9875042763732951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 282}], {
             RGBColor[
             0.7020125718352301, 0.7657640778274137, 0.9720962722582036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 293}], {
             RGBColor[
             0.712497806627604, 0.7742764637863073, 0.9729217083497399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 98}], {
             RGBColor[
             0.9829295968062772, 0.9860530990706597, 0.880802302102798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 126}], {
             RGBColor[
             0.9480350784348034, 0.9603303634469808, 0.9577702411991067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 153}], {
             RGBColor[
             0.8342423057027939, 0.8706356047888957, 0.9466404657244468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 157}], {
             RGBColor[
             0.7572028759328003, 0.8088404719338926, 0.9400635805776734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 171}], {
             RGBColor[
             0.8616380382219702, 0.892037359248155, 0.9493710163142821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 184}], {
             RGBColor[
             0.7400725864222821, 0.7949333311985058, 0.9387150214370873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 222}], {
             RGBColor[
             0.8633970038961809, 0.8934114766014828, 0.9495463335742187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 248}], {
             RGBColor[
             0.8752403612099672, 0.902663597347862, 0.9507267687487903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 275}], {
             RGBColor[
             0.9784499996248316, 0.9834486255218622, 0.9213627088816132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 285}], {
             RGBColor[
             0.7433300938283921, 0.7975779224598223, 0.9389714643527391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 38}], {
             RGBColor[
             0.8354379509248226, 0.8717643849651677, 0.9841275798026805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 52}], {
             RGBColor[
             0.7849259779934761, 0.8319094067576677, 0.9791977440022323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 53}], {
             RGBColor[
             0.6912478425668368, 0.7577786562404872, 0.9705094000452387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 57}], {
             RGBColor[
             0.8841570386700451, 0.9098238882211078, 0.9614618006919733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 84}], {
             RGBColor[
             0.755125811856463, 0.808629290481782, 0.9762275419400805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 124}], {
             RGBColor[
             0.8980729906940939, 0.9185596405860756, 0.8643403865517776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 147}], {
             RGBColor[
             0.6141489100074378, 0.6944508144183397, 0.9646430980877425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 217}], {
             RGBColor[
             0.7297280460603373, 0.7887883628116792, 0.9736961300011384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 223}], {
             RGBColor[
             0.8982421493570492, 0.9178844309419372, 0.8073716442011758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 247}], {
             RGBColor[
             0.8333149875090171, 0.8700715915637112, 0.9839250896568892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 270}], {
             RGBColor[
             0.8232362607043724, 0.8620350883894385, 0.9829637716968764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 295}], {
             RGBColor[
             0.6240177673577714, 0.7029987226320057, 0.9652719329514179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 102}], {
             RGBColor[
             0.7503644294218152, 0.8031755765983003, 0.9364907597193384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 129}], {
             RGBColor[
             0.9585950908898562, 0.9686408670967468, 0.9549718903803694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 165}], {
             RGBColor[
             0.8108268754243811, 0.8522617140653355, 0.9412505849498978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 175}], {
             RGBColor[
             0.8890356006300466, 0.9133798880562689, 0.9490313942979425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 183}], {
             RGBColor[
             0.8040326951414611, 0.8467458924373272, 0.9407157221901239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 224}], {
             RGBColor[
             0.7103386535708945, 0.7703196866532303, 0.9334395741531235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 253}], {
             RGBColor[
             0.7480628099702846, 0.801307018240773, 0.936309567805004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 262}], {
             RGBColor[
             0.7492259344774431, 0.8022512951138462, 0.9364011332268729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 41}], {
             RGBColor[
             0.5691269236123755, 0.6606336040295655, 0.9595294059954165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 55}], {
             RGBColor[
             0.4031132406285781, 0.5232167037463571, 0.947006868787247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 152}], {
             RGBColor[
             0.6019227577719646, 0.686253958932608, 0.962798188249949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 208}], {
             RGBColor[
             0.4385612753806074, 0.553920009778534, 0.9492655862161801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 242}], {
             RGBColor[
             0.7151383442763652, 0.7751393169608392, 0.9487875757248617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 250}], {
             RGBColor[
             0.473940657653495, 0.5838054025232473, 0.9517294911537673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 268}], {
             RGBColor[
             0.5517943666679117, 0.6470105507707733, 0.9578584203149151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 41}], {
             RGBColor[
             0.8330203895518973, 0.866931939933026, 0.800810353282417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 44}], {
             RGBColor[
             0.8448894683816176, 0.8762041545231436, 0.8019933521373156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 55}], {
             RGBColor[
             0.6670067065680999, 0.7295150396498176, 0.7882878160742477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 61}], {
             RGBColor[
             0.9799194375340716, 0.9820996438648453, 0.7885660014924576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 71}], {
             RGBColor[
             0.691348146504478, 0.750598371486364, 0.7898388311027036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 108}], {
             RGBColor[
             0.8115086654779157, 0.8499160505291574, 0.7988103682566864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 136}], {
             RGBColor[
             0.7820340779190589, 0.8259872525338396, 0.7964900207550814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 152}], {
             RGBColor[
             0.8658162237114864, 0.8925522948360683, 0.8040791355369497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 161}], {
             RGBColor[
             0.762023998873586, 0.8097421689209365, 0.794914754033287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 177}], {
             RGBColor[
             0.7779532703437871, 0.8226742691059479, 0.7961687646342653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 208}], {
             RGBColor[
             0.7024547413201292, 0.7602183456819943, 0.7905465335031807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 252}], {
             RGBColor[
             0.9947287590277489, 0.9911336735015974, 0.6676361343779769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 268}], {
             RGBColor[
             0.8156878326074335, 0.8533088866742338, 0.7991393676019156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 279}], {
             RGBColor[
             0.8378095429027744, 0.8706732629296448, 0.8012876913312498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 280}], {
             RGBColor[
             0.9492594066988402, 0.9584186355980466, 0.812215549758752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 52}], {
             RGBColor[
             0.8182978621746035, 0.8583744173639971, 0.9824192159392948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 53}], {
             RGBColor[
             0.7246197267479642, 0.7842436668468167, 0.9737308719823012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 57}], {
             RGBColor[
             0.9175289228511725, 0.9362888988274374, 0.964683272629036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 88}], {
             RGBColor[
             0.8512003083317272, 0.8841880369196025, 0.9856694393558076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 124}], {
             RGBColor[
             0.9314448748752213, 0.9450246511924052, 0.8675618584888403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 147}], {
             RGBColor[
             0.6475207941885652, 0.7209158250246692, 0.9678645700248052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 247}], {
             RGBColor[
             0.8666868716901446, 0.8965366021700407, 0.9871465615939518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 289}], {
             RGBColor[
             0.9181831595418751, 0.9367768274801491, 0.9635758205639335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 64}], {
             RGBColor[
             0.5260680154878385, 0.62458401933133, 0.9563115302120421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 69}], {
             RGBColor[
             0.5178888042065761, 0.618073066332766, 0.9555792301769696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 76}], {
             RGBColor[
             0.6287537916914758, 0.7050954154035256, 0.9664686716049441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 85}], {
             RGBColor[
             0.391221740593781, 0.5132783411510794, 0.9461492812602019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 90}], {
             RGBColor[
             0.6255102040028685, 0.7025090666254725, 0.9661592953156198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 118}], {
             RGBColor[
             0.5545503406803135, 0.6468346282453805, 0.959150382204766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 126}], {
             RGBColor[
             0.6600859586005636, 0.7300788348078182, 0.9694571616552885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 153}], {
             RGBColor[
             0.5462931858685541, 0.6403840761497331, 0.9583273861806286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 166}], {
             RGBColor[
             0.6452572665372858, 0.7182548382706837, 0.9680427877685633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 195}], {
             RGBColor[
             0.6725670103338568, 0.7398220464058829, 0.9634069924257778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 234}], {
             RGBColor[
             0.4083896575258733, 0.5281483279130632, 0.947243205746122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 239}], {
             RGBColor[
             0.5864464387231816, 0.6717521024557926, 0.9623294871716959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 248}], {
             RGBColor[
             0.5872912413757274, 0.6724120687086994, 0.9624136892049721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 263}], {
             RGBColor[
             0.5107987248689899, 0.6123170205220794, 0.9550210731596984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 285}], {
             RGBColor[
             0.45538097399415234`, 0.5673263938206596, 0.950658384808921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 42}], {
             RGBColor[
             0.5055006776515965, 0.6009636717518473, 0.9564991441851902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 66}], {
             RGBColor[
             0.5712901461541349, 0.6604281324168431, 0.9606003519525381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 81}], {
             RGBColor[
             0.7230877538680802, 0.7836009160829982, 0.9730342877324728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 86}], {
             RGBColor[
             0.5857138667127817, 0.6729212342074685, 0.9615194186721399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 94}], {
             RGBColor[
             0.7067738638005746, 0.770856381172106, 0.9714082716325143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 97}], {
             RGBColor[
             0.6279629010706652, 0.7075190093558634, 0.9647630499105877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 120}], {
             RGBColor[
             0.6662425578252091, 0.738596159188087, 0.9677765647133083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 130}], {
             RGBColor[
             0.7416103957962125, 0.7980709447345478, 0.9748804515759388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 140}], {
             RGBColor[
             0.59350361852278, 0.6795434114105021, 0.962050288959907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 162}], {
             RGBColor[
             0.7708802480092939, 0.8209367757425229, 0.9777977969022184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 169}], {
             RGBColor[
             0.8074495352061195, 0.6813310690633337, 0.6000310448362076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 178}], {
             RGBColor[
             0.6956238502576746, 0.7621459058491509, 0.9702969424853588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 182}], {
             RGBColor[
             0.7424049459692683, 0.7986916533685439, 0.9749596449116955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 201}], {
             RGBColor[
             0.5791408278088251, 0.6672279982794026, 0.9611005904454899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 202}], {
             RGBColor[
             0.6415179009352219, 0.7185235688916956, 0.9658301491535262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 55}], {
             RGBColor[
             0.5056099786082365, 0.6059798757721544, 0.9553822907655133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 108}], {
             RGBColor[
             0.6501119375180523, 0.7263808866514943, 0.965904842947952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 152}], {
             RGBColor[
             0.704419495751623, 0.7690171309584052, 0.9711736102282152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 208}], {
             RGBColor[
             0.5410580133602658, 0.6366831818043311, 0.9576410081944462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 219}], {
             RGBColor[
             0.6227352970183443, 0.7041552965902315, 0.9637496535238765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 242}], {
             RGBColor[
             0.8176350822560237, 0.8579024889866365, 0.957162997703128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.5764373956331534, 0.6665685745490446, 0.9601049131320334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 252}], {
             RGBColor[
             0.8333320310678856, 0.8675985096239343, 0.8347306090692426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 268}], {
             RGBColor[
             0.6542911046475701, 0.7297737227965706, 0.9662338422931813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 80}], {
             RGBColor[
             0.5750317337549493, 0.6556711759673665, 0.9633260378933737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 81}], {
             RGBColor[
             0.49949969187710913`, 0.5962756560556366, 0.9559010220055899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 82}], {
             RGBColor[
             0.3881581083632921, 0.5070282767775334, 0.9463531437378676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 87}], {
             RGBColor[
             0.3639410418162364, 0.4871682413148295, 0.9445018182477626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 130}], {
             RGBColor[
             0.5180223338052414, 0.6107456847071862, 0.9577471858490558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 140}], {
             RGBColor[
             0.36991555653180896`, 0.4922181513831406, 0.9449170232330241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 145}], {
             RGBColor[
             0.4492418643743426, 0.5566188216991532, 0.9511618807682285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 162}], {
             RGBColor[
             0.5472921860183229, 0.6336115157151614, 0.9606645311753355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 167}], {
             RGBColor[
             0.3349146835000142, 0.4620270686485064, 0.9426522843628538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 181}], {
             RGBColor[
             0.5596538769786898, 0.6434092903947795, 0.9618592841860791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 201}], {
             RGBColor[
             0.355552765817854, 0.4799027382520411, 0.9439673247186069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 202}], {
             RGBColor[
             0.4179298389442508, 0.531198308864334, 0.9486968834266432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 203}], {
             RGBColor[
             0.63831674651896, 0.7023776135863593, 0.8030720719121183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 216}], {
             RGBColor[
             0.5430639911626862, 0.630308417758467, 0.960243104226853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 237}], {
             RGBColor[
             0.46307569615335975`, 0.5678209537636231, 0.9522706185134392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 269}], {
             RGBColor[
             0.47739626172633737`, 0.5790082884295626, 0.9536979586564596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 293}], {
             RGBColor[
             0.41033716453562147`, 0.5250342337333245, 0.9480991602843132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 299}], {
             RGBColor[
             0.4062828322639014, 0.5217427441495548, 0.9477799883963749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 66}], {
             RGBColor[
             0.620996046523808, 0.6993275955898426, 0.9655363046087178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 78}], {
             RGBColor[
             0.6714014203794237, 0.7413303302413131, 0.9692056113714788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 97}], {
             RGBColor[
             0.6776688014403384, 0.746418472528863, 0.9696990025667672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 99}], {
             RGBColor[
             0.7844780802029757, 0.8316283416249557, 0.9791348347716969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 178}], {
             RGBColor[
             0.7453297506273477, 0.8010453690221504, 0.9752328951415383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 182}], {
             RGBColor[
             0.7921108463389415, 0.8375911165415434, 0.9798955975678751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 199}], {
             RGBColor[
             0.860028267982526, 0.8912272123165683, 0.9865114580281134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 215}], {
             RGBColor[
             0.8870708308517664, 0.9125338379640708, 0.9802019485737321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 229}], {
             RGBColor[
             0.6552988645344909, 0.7282575499945226, 0.96793795918976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 233}], {
             RGBColor[
             0.6461341984568433, 0.7208172612091864, 0.9672164831048495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 259}], {
             RGBColor[
             0.6994954600121157, 0.764138337237195, 0.9714172770832223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 261}], {
             RGBColor[
             0.6650738078572559, 0.7361932893401217, 0.9687074785349252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 284}], {
             RGBColor[
             0.8903904765626889, 0.9150096242998558, 0.9745826542874065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 59}], {
             RGBColor[
             0.6200847867006769, 0.7016398546104627, 0.9637896171340852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 61}], {
             RGBColor[
             0.8303917884039285, 0.8678366945772997, 0.9568434750386217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 71}], {
             RGBColor[
             0.541820497374335, 0.6363354221988186, 0.9581163046488677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 108}], {
             RGBColor[
             0.6619810163477726, 0.7356531012416119, 0.9670878418028506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 136}], {
             RGBColor[
             0.6325064287889157, 0.7117243032462941, 0.9647674943012456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 177}], {
             RGBColor[
             0.6284256212136441, 0.7084113198184023, 0.9644462381804295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 194}], {
             RGBColor[
             0.6864757943126161, 0.7549993750170709, 0.9693851497621987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 204}], {
             RGBColor[
             0.8253089844045683, 0.8640459476769047, 0.9654473364019418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 226}], {
             RGBColor[
             0.7148324562623435, 0.7771518148508111, 0.9722114768172753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 252}], {
             RGBColor[
             0.8452011098976059, 0.876870724214052, 0.8359136079241412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 268}], {
             RGBColor[
             0.6661601834772904, 0.7390459373866882, 0.9674168411480799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 279}], {
             RGBColor[
             0.6882818937726314, 0.7564103136420992, 0.969565164877414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 280}], {
             RGBColor[
             0.7997317575686971, 0.8441556863105012, 0.9804930233049163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 283}], {
             RGBColor[
             0.780497376600258, 0.8288187130296305, 0.9786584308774119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 89}], {
             RGBColor[
             0.3476652416707471, 0.4618363186726313, 0.944286660169191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 94}], {
             RGBColor[
             0.6004312356500379, 0.6858512339551329, 0.9621282268456688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 96}], {
             RGBColor[
             0.454622733587997, 0.5664801758778297, 0.9506624210325789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 120}], {
             RGBColor[
             0.5598999296746725, 0.6535910119711139, 0.9584965199264628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 131}], {
             RGBColor[
             0.49808212331860297`, 0.6034045319108163, 0.9536299957640271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 132}], {
             RGBColor[
             0.553020636351989, 0.648006091743127, 0.9579549567564194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 141}], {
             RGBColor[
             0.6354829148840915, 0.7132338721754046, 0.9656218506551534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 146}], {
             RGBColor[
             0.45193894378181615`, 0.5641556120389137, 0.9504914123193112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 188}], {
             RGBColor[
             0.46894083683461174`, 0.5788817972612537, 0.9515747579104517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 236}], {
             RGBColor[
             0.4794835433068419, 0.5880133597156647, 0.9522465298443128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 260}], {
             RGBColor[
             0.5537165328944695, 0.6485710519060945, 0.9580097402813965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 281}], {
             RGBColor[
             0.46952012108394336`, 0.5793835441623516, 0.9516116693905781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 294}], {
             RGBColor[
             0.6354829148840915, 0.7132338721754046, 0.9656218506551534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 60}], {
             RGBColor[
             0.6643249498119826, 0.7355104013416195, 0.9687347702403746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 62}], {
             RGBColor[
             0.8490638022046691, 0.8824844449278003, 0.9854656574941272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 117}], {
             RGBColor[
             0.8489406212140942, 0.8823862237495748, 0.9854539083812812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 158}], {
             RGBColor[
             0.916098565852854, 0.9312555172894639, 0.7505603271580736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 196}], {
             RGBColor[
             0.9161158867442405, 0.9312925649247288, 0.752445599293343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 207}], {
             RGBColor[
             0.7203186348555408, 0.7809685973467453, 0.9731427982386301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 212}], {
             RGBColor[
             0.654448139665101, 0.7274919619191544, 0.9679572315656644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 214}], {
             RGBColor[
             0.9052128526536327, 0.9263311604683118, 0.9587504170392137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 225}], {
             RGBColor[
             0.902138753892308, 0.9240385026454905, 0.9639540643887714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 265}], {
             RGBColor[
             0.7263307439534795, 0.7858494983548802, 0.9736160934899012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 276}], {
             RGBColor[
             0.6683277070974459, 0.7387600200281194, 0.9690498819564692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.6716111942965273, 0.7385980410203665, 0.9575648664970798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 112}], {
             RGBColor[
             0.7106492889336683, 0.7719329905194041, 0.9601843806830328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 131}], {
             RGBColor[
             0.7150705840271333, 0.7755223970533531, 0.960532441228528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 133}], {
             RGBColor[
             0.6826651167210046, 0.7481723930381533, 0.9582692126593677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 146}], {
             RGBColor[
             0.6689274044903465, 0.7362734771814505, 0.9573938577838121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 170}], {
             RGBColor[
             0.7811988317694328, 0.8292082876141638, 0.9657382991265548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 190}], {
             RGBColor[
             0.773085763831172, 0.822621733572338, 0.9650996086993079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.6359259491006839, 0.7133793238072126, 0.9658031937110231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 70}], {
             RGBColor[
             0.6539099192732177, 0.7274285379892316, 0.9675956677880648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 71}], {
             RGBColor[
             0.44579215282062085`, 0.5591872216537632, 0.950001476804043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 73}], {
             RGBColor[
             0.5800377159750416, 0.6697190113231568, 0.9602327769382919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 100}], {
             RGBColor[
             0.5582999216113332, 0.6522920533457532, 0.9583705614306941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 119}], {
             RGBColor[
             0.7447583514440921, 0.7981054746879203, 0.9161073115683714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 122}], {
             RGBColor[
             0.6063264000392115, 0.6902559311154852, 0.9628529872840881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 138}], {
             RGBColor[
             0.5586363461416289, 0.6525651779351996, 0.9583970460020828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 161}], {
             RGBColor[
             0.5164680051897288, 0.6183310190883357, 0.9550773997346266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 244}], {
             RGBColor[
             0.464768604706161, 0.5756236704928137, 0.951210639537972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 266}], {
             RGBColor[
             0.5063653223365115, 0.6101292060274179, 0.9542820795330746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 54}], {
             RGBColor[
             0.8099920843317708, 0.8517914392190953, 0.9493001783977819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 102}], {
             RGBColor[
             0.5842412236495619, 0.6732596128334155, 0.9604761750065465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 143}], {
             RGBColor[
             0.5460508516855215, 0.6419934574850796, 0.9575419397530197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 172}], {
             RGBColor[
             0.7601213549755319, 0.8129508864974362, 0.9766142507232429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 174}], {
             RGBColor[
             0.6617629261420941, 0.7356934945775047, 0.9669220020178444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 238}], {
             RGBColor[
             0.8215675454809022, 0.8581910971608897, 0.8161848962334224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 298}], {
             RGBColor[
             0.5706447975435408, 0.6622214216085316, 0.9594058145381306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 206}], {
             RGBColor[
             0.8114696455251236, 0.8103968831664824, 0.6385121711798822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 219}], {
             RGBColor[
             0.7683602832404035, 0.7756700042115382, 0.6349329936703938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 83}], {
             RGBColor[
             0.6388834502080774, 0.7165189786201024, 0.9655310190134283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 101}], {
             RGBColor[
             0.6971953372012774, 0.7622098268200721, 0.9713066052000929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 104}], {
             RGBColor[
             0.770908550251789, 0.81970015597549, 0.9334148451302531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 116}], {
             RGBColor[
             0.659218598501258, 0.7324049510195862, 0.9675578365525275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 142}], {
             RGBColor[
             0.5834657515452688, 0.6727228077938411, 0.9603517077485662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 149}], {
             RGBColor[
             0.7109730566117293, 0.773195806291736, 0.9726207363769772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 197}], {
             RGBColor[
             0.5977314717630253, 0.6843043621299878, 0.9614747575011628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 198}], {
             RGBColor[
             0.6298819808366812, 0.7094869623334668, 0.9646338366700015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 204}], {
             RGBColor[
             0.7563466160162082, 0.8088711258912147, 0.9594632413467912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 226}], {
             RGBColor[
             0.6458700878739834, 0.7219769930651212, 0.9662273817621247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 243}], {
             RGBColor[
             0.7576663755805245, 0.8098554004133738, 0.9572292326528258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 254}], {
             RGBColor[
             0.5043741244134399, 0.6084581716124107, 0.9541403809538547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 283}], {
             RGBColor[
             0.7115350082118979, 0.7736438912439405, 0.9726743358222614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 53}], {
             RGBColor[
             0.6741077538166176, 0.7443886886393167, 0.968801036181853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 57}], {
             RGBColor[
             0.8670169499198259, 0.8964339206199373, 0.9597534368285876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 84}], {
             RGBColor[
             0.7379857231062439, 0.7952393228806114, 0.9745191780766949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 88}], {
             RGBColor[
             0.8006883354003806, 0.8443330587121025, 0.9807396035553593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 93}], {
             RGBColor[
             0.8254488415519018, 0.8640764142112907, 0.9831012827360561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 124}], {
             RGBColor[
             0.8809329019438747, 0.9051696729849051, 0.8626320226883919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 137}], {
             RGBColor[
             0.8314826309598036, 0.8688875941023011, 0.9836767909562092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 147}], {
             RGBColor[
             0.5970088212572187, 0.6810608468171692, 0.9629347342243568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 217}], {
             RGBColor[
             0.712587957310118, 0.7753983952105086, 0.9719877661377527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 247}], {
             RGBColor[
             0.816174898758798, 0.8566816239625407, 0.9822167257935035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 270}], {
             RGBColor[
             0.8060961719541533, 0.8486451207882679, 0.9812554078334907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 271}], {
             RGBColor[
             0.6534520841735595, 0.7276194854957689, 0.9671749462033404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 273}], {
             RGBColor[
             0.604409478427357, 0.6874709240900982, 0.9634062975550939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 289}], {
             RGBColor[
             0.8676711866105286, 0.8969218492726491, 0.9586459847634852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 295}], {
             RGBColor[
             0.6068776786075522, 0.6896087550308352, 0.9635635690880322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 88}], {
             RGBColor[
             0.7070101999737414, 0.7702023081949221, 0.9720512595983657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 93}], {
             RGBColor[
             0.7317707061252625, 0.7899456636941102, 0.9744129387790625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 107}], {
             RGBColor[
             0.6993752496657273, 0.7641278484367222, 0.9713194640299185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 124}], {
             RGBColor[
             0.7872547665172354, 0.8310389224677247, 0.8539436787313983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 137}], {
             RGBColor[
             0.7378044955331642, 0.7947568435851207, 0.9749884469992156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 147}], {
             RGBColor[
             0.5033306858305793, 0.6069300962999887, 0.9542463902673632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 217}], {
             RGBColor[
             0.6189098218834788, 0.7012676446933281, 0.9632994221807591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 247}], {
             RGBColor[
             0.7224967633321586, 0.7825508734453602, 0.9735283818365099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 251}], {
             RGBColor[
             0.7280854584462061, 0.7870071472282141, 0.9740614365655748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 270}], {
             RGBColor[
             0.7124180365275139, 0.7745143702710875, 0.9725670638764972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 271}], {
             RGBColor[
             0.5597739487469202, 0.6534887349785885, 0.9584866022463469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 273}], {
             RGBColor[
             0.5107313430007177, 0.6133401735729178, 0.9547179535981003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 289}], {
             RGBColor[
             0.7739930511838893, 0.8227910987554686, 0.9499576408064916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 75}], {
             RGBColor[
             0.8419628942530879, 0.8767672789167831, 0.9524867299465335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 102}], {
             RGBColor[
             0.745819094396823, 0.7997856731789641, 0.9441848263034127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 111}], {
             RGBColor[
             0.8498468623117459, 0.8829262946845833, 0.9532725302027502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 143}], {
             RGBColor[
             0.7076287224327826, 0.7685195178306282, 0.941250591049886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 163}], {
             RGBColor[
             0.8168644579759068, 0.8571601897418685, 0.9499851523766463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 165}], {
             RGBColor[
             0.8062815403993888, 0.8488718106459991, 0.9489446515339721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 172}], {
             RGBColor[
             0.9216992257227931, 0.9394769468429849, 0.9603229020201092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 174}], {
             RGBColor[
             0.8233407968893554, 0.8622195549230532, 0.9506306533147106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 185}], {
             RGBColor[
             0.7343137868752673, 0.7904451462247679, 0.9432790863499857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 235}], {
             RGBColor[
             0.8723288801933797, 0.90048941792338, 0.9555133276387893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 238}], {
             RGBColor[
             0.9831454162281632, 0.9847171575064383, 0.7998935475302886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 298}], {
             RGBColor[
             0.732222668290802, 0.7887474819540803, 0.9431144658349968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 108}], {
             RGBColor[
             0.4840982545342549, 0.5889639863682858, 0.9533823057397827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 114}], {
             RGBColor[
             0.5200453968670756, 0.6172569342292017, 0.956821078350901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 208}], {
             RGBColor[
             0.37504433037646845`, 0.49926628152112273`, 0.945118470986277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 219}], {
             RGBColor[
             0.4567216140345469, 0.566738396307023, 0.9512271163157072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 242}], {
             RGBColor[
             0.6516213992722264, 0.720485588703428, 0.9446404604949585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 250}], {
             RGBColor[
             0.41042371264935607`, 0.5291516742658362, 0.9475823759238642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 252}], {
             RGBColor[
             0.6673183480840883, 0.7301816093407258, 0.8222080718610731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 268}], {
             RGBColor[
             0.48827742166377275`, 0.5923568225133622, 0.9537113050850119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 283}], {
             RGBColor[
             0.6026146147867404, 0.6821295981563045, 0.964952894814344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 57}], {
             RGBColor[
             0.826895781760868, 0.8650909591219876, 0.9557545337401362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 84}], {
             RGBColor[
             0.6978645549472859, 0.7638963613826617, 0.9705202749882434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 110}], {
             RGBColor[
             0.8408386734256015, 0.872847309734729, 0.7861847143492516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 148}], {
             RGBColor[
             0.5738680651673556, 0.6642388038988537, 0.960069382939008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 191}], {
             RGBColor[
             0.7912616137859514, 0.837465015710204, 0.9796683641795809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 217}], {
             RGBColor[
             0.6724667891511601, 0.7440554337125589, 0.9679888630493012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 223}], {
             RGBColor[
             0.8409808924478721, 0.873151501842817, 0.8016643772493386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 246}], {
             RGBColor[
             0.6229575517988895, 0.7040918606025042, 0.963933887147357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 247}], {
             RGBColor[
             0.7760537305998401, 0.825338662464591, 0.978217822705052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 251}], {
             RGBColor[
             0.7816424257138874, 0.8297949362474448, 0.9787508774341169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 270}], {
             RGBColor[
             0.7659750037951953, 0.8173021592903182, 0.9772565047450393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 271}], {
             RGBColor[
             0.6133309160146015, 0.6962765239978193, 0.963176043114889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 278}], {
             RGBColor[
             0.7846196849968274, 0.8321689219841107, 0.9790348510823544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 295}], {
             RGBColor[
             0.5667565104485942, 0.6582657935328855, 0.9595646659995807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.8372167837828128, 0.8731538043440517, 0.956783234766436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 217}], {
             RGBColor[
             0.8118190179866871, 0.8533128766739488, 0.9542518228274939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 223}], {
             RGBColor[
             0.980333121283399, 0.9824089448042068, 0.7879273370275311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 247}], {
             RGBColor[
             0.915405959435367, 0.9345961054259808, 0.9644807824832446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 278}], {
             RGBColor[
             0.9239719138323543, 0.9414263649455006, 0.965297810860547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 295}], {
             RGBColor[
             0.7061087392841212, 0.7675232364942753, 0.9458276257777734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 134}], {
             RGBColor[
             0.7493055274578818, 0.8041311440457173, 0.9756345058482461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 160}], {
             RGBColor[
             0.8267526277715443, 0.8647196481352093, 0.9426055314858649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 164}], {
             RGBColor[
             0.5697319035614257, 0.6611097779050803, 0.9595872714752754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 176}], {
             RGBColor[
             0.6680027505937963, 0.7405680928635967, 0.9675439294047153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 180}], {
             RGBColor[
             0.5754823452633917, 0.6657782455331829, 0.9600399673106161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 187}], {
             RGBColor[
             0.7609479087797015, 0.8134144628877142, 0.9767449665719976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 215}], {
             RGBColor[
             0.809121208298593, 0.8515701643610819, 0.9724509256428914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 221}], {
             RGBColor[
             0.8276441569290115, 0.8487109503479068, 0.6776225175740713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 230}], {
             RGBColor[
             0.5077521070808604, 0.6077937586408778, 0.9555363590151996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[
             0.6212535011154141, 0.7029373318209278, 0.9636432403645558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 288}], {
             RGBColor[
             0.559702782389183, 0.6527908224760843, 0.9588466101076675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 296}], {
             RGBColor[
             0.5993720934254327, 0.685173019312018, 0.9619206557969631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 297}], {
             RGBColor[
             0.6908350294233583, 0.7584048426169967, 0.9698196375786693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 72}], {
             RGBColor[
             0.688361435340547, 0.7550745262228937, 0.9705692045652357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 83}], {
             RGBColor[
             0.6325687860456398, 0.711392449780657, 0.9650339055191843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 106}], {
             RGBColor[
             0.7509174003073997, 0.8044049630586969, 0.9574672945824961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 136}], {
             RGBColor[
             0.5572293962381181, 0.6514229526211588, 0.958286285751851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 155}], {
             RGBColor[
             0.7264819180499598, 0.3031975013284425, 0.4285814695282302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[
             0.6111987617618184, 0.6946980243919356, 0.9629039412128041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 197}], {
             RGBColor[
             0.5914168076005879, 0.6791778332905425, 0.9609776440069189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 198}], {
             RGBColor[
             0.6235673166742437, 0.7043604334940212, 0.9641367231757574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 210}], {
             RGBColor[
             0.59403714824196, 0.6812912414771286, 0.9611934319615412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 226}], {
             RGBColor[
             0.6395554237115458, 0.7168504642256757, 0.9657302682678807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 227}], {
             RGBColor[
             0.6149967906207778, 0.6976650734026432, 0.9632824932348676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 241}], {
             RGBColor[
             0.4632311584729289, 0.573165118294144, 0.9514240388677698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 290}], {
             RGBColor[
             0.5140184205033211, 0.6163423358873774, 0.9548845594549882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 291}], {
             RGBColor[
             0.6085039279291247, 0.6925927997203396, 0.9626353453610152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 77}], {
             RGBColor[
             0.6906736909918954, 0.7565201723409557, 0.9712479366959136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 95}], {
             RGBColor[
             0.710036680142891, 0.7719596942956207, 0.97309479588668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 103}], {
             RGBColor[
             0.6356536463968013, 0.7129596278721683, 0.9659175603207324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 127}], {
             RGBColor[
             0.6131619246383391, 0.6953889238910409, 0.9636757956929389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 145}], {
             RGBColor[
             0.5531826312418958, 0.6481376064925399, 0.9579677095875598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 148}], {
             RGBColor[
             0.47499336340255094`, 0.5846600364741844, 0.9518123640065211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 159}], {
             RGBColor[
             0.548338622285877, 0.6442050218019272, 0.9575863714583526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 168}], {
             RGBColor[
             0.4781945309240766, 0.5872588884791123, 0.9520643716400787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 196}], {
             RGBColor[
             0.7415850863279896, 0.7924581448943686, 0.7366883651499383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 205}], {
             RGBColor[
             0.7424303571474673, 0.794451946680325, 0.8422004266226738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 212}], {
             RGBColor[
             0.47991733924885016`, 0.5886575418887942, 0.9521999974222597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 225}], {
             RGBColor[
             0.7276079534760571, 0.7852040826151303, 0.9481968302453667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 265}], {
             RGBColor[
             0.5517999435372287, 0.6470150783245199, 0.9578588593464965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 276}], {
             RGBColor[
             0.49379690668119514`, 0.5999255999977591, 0.9532926478130646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 282}], {
             RGBColor[
             0.5037926966108007, 0.6080406325678176, 0.9540795530121082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 71}], {
             RGBColor[
             0.6768504665267889, 0.7422309115405201, 0.9446889540040097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 108}], {
             RGBColor[
             0.7970109855002265, 0.8415485905833135, 0.9536604911579925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 136}], {
             RGBColor[
             0.7675363979413697, 0.8176197925879958, 0.9513401436563875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 161}], {
             RGBColor[
             0.7475263188958969, 0.8013747089750927, 0.9497648769345932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 177}], {
             RGBColor[
             0.763455590366098, 0.8143068091601039, 0.9510188875355714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 194}], {
             RGBColor[
             0.82150576346507, 0.8608948643587725, 0.9559577991173407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 252}], {
             RGBColor[
             0.9802310790500599, 0.9827662135557536, 0.822486257279283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 268}], {
             RGBColor[
             0.8011901526297445, 0.8449414267283898, 0.9539894905032218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 279}], {
             RGBColor[
             0.8233118629250853, 0.8623058029838009, 0.9561378142325558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 280}], {
             RGBColor[
             0.9347617267211511, 0.9500511756522028, 0.9670656726600582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 117}], {
             RGBColor[
             0.85914867319053, 0.8905258473053953, 0.9864275614916292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 135}], {
             RGBColor[
             0.7319883625175265, 0.7902948750718344, 0.9742315198132391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 158}], {
             RGBColor[
             0.9263066178292897, 0.9393951408452844, 0.7515339802684216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 186}], {
             RGBColor[
             0.7773273702129564, 0.826290865707263, 0.9783561180244842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 196}], {
             RGBColor[
             0.9263239387206762, 0.9394321884805494, 0.753419252403691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 207}], {
             RGBColor[
             0.7305266868319766, 0.7891082209025657, 0.9741164513489782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 212}], {
             RGBColor[
             0.6646561916415368, 0.735631585474975, 0.9689308846760123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 214}], {
             RGBColor[
             0.9154209046300684, 0.9344707840241324, 0.9597240701495617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 225}], {
             RGBColor[
             0.9123468058687436, 0.9321781262013111, 0.9649277174991194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 265}], {
             RGBColor[
             0.7365387959299152, 0.7939891219107007, 0.9745897466002491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 276}], {
             RGBColor[
             0.6785357590738816, 0.7468996435839399, 0.9700235350668173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 286}], {
             RGBColor[
             0.9260561031537222, 0.9388593152851645, 0.724267003830267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 71}], {
             RGBColor[
             0.5784129717772585, 0.6649217413154883, 0.9617635005212357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 73}], {
             RGBColor[
             0.7126585349316792, 0.775453530984882, 0.9719948006554846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 152}], {
             RGBColor[
             0.7528810489842669, 0.8068756646651927, 0.9760038049554818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 161}], {
             RGBColor[
             0.6490888241463664, 0.7240655387500607, 0.9668394234518193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 208}], {
             RGBColor[
             0.5895195665929096, 0.6745417155111186, 0.9624712029217128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 244}], {
             RGBColor[
             0.5973894236627986, 0.6813581901545389, 0.9629726632551647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 69}], {
             RGBColor[
             0.6426203862350867, 0.720617905932125, 0.9650969798434887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 76}], {
             RGBColor[
             0.7534853737199864, 0.8076402550028846, 0.9759864212714633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 85}], {
             RGBColor[
             0.5159533226222915, 0.6158231807504384, 0.9556670309267211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 90}], {
             RGBColor[
             0.750241786031379, 0.8050539062248314, 0.975677044982139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 118}], {
             RGBColor[
             0.679281922708824, 0.7493794678447394, 0.9686681318712851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 121}], {
             RGBColor[
             0.6362298160942332, 0.7154297531998761, 0.964593890752571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 173}], {
             RGBColor[
             0.8202218319237355, 0.8585572142351608, 0.8935587156382463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 213}], {
             RGBColor[
             0.6096297046644434, 0.6938345844198088, 0.9624998325413991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 234}], {
             RGBColor[
             0.5331212395543838, 0.6306931675124223, 0.9567609554126412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 239}], {
             RGBColor[
             0.7111780207516922, 0.7742969420551516, 0.9718472368382152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 249}], {
             RGBColor[
             0.5963867343331448, 0.6830833445158458, 0.9614572974063207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 258}], {
             RGBColor[
             0.6670923915208589, 0.7398569134368327, 0.9674531933201143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 263}], {
             RGBColor[
             0.6355303068975005, 0.7148618601214384, 0.9645388228262175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 286}], {
             RGBColor[
             0.8218199748213443, 0.8571117105086986, 0.7139619884673101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 70}], {
             RGBColor[
             0.8994370643877778, 0.9195738807240326, 0.8621463487792341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 106}], {
             RGBColor[
             0.9756932334190433, 0.979703455873578, 0.8503843562782354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 115}], {
             RGBColor[
             0.9036889063311238, 0.92289545196537, 0.8625701326484249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 138}], {
             RGBColor[
             0.804163491256189, 0.8447105206700007, 0.852947726993252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 155}], {
             RGBColor[
             0.8763324734577222, 0.4200631632050299, 0.35719284399205636`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 194}], {
             RGBColor[
             0.835974594873462, 0.8699965172068166, 0.8558210029085433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 200}], {
             RGBColor[
             0.8544144342748146, 0.8844018598951233, 0.8576589137699736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[
             0.8188129813536036, 0.8565897342920097, 0.8541104936572805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 211}], {
             RGBColor[
             0.6339178999018675, 0.6983534410867573, 0.8410139896307339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 231}], {
             RGBColor[
             0.7128652487315041, 0.7699945840373648, 0.8459250467276178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 241}], {
             RGBColor[
             0.6880069915845726, 0.748463611109025, 0.8443411005635091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 264}], {
             RGBColor[
             0.9790781861028466, 0.9822279480428071, 0.8446545143216091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 291}], {
             RGBColor[
             0.8332797610407683, 0.8678912925352206, 0.8555524070567544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 86}], {
             RGBColor[
             0.427915273224349, 0.5450604348451028, 0.9484873607126048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 97}], {
             RGBColor[
             0.47016430758223254`, 0.5796582099934977, 0.9517309919510526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 162}], {
             RGBColor[
             0.6130816545208613, 0.6930759763801572, 0.9647657389426834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 169}], {
             RGBColor[
             0.6496509417176869, 0.553470269700968, 0.5869989868766725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 187}], {
             RGBColor[
             0.6313930374747692, 0.7076178739553378, 0.9665279788871237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 193}], {
             RGBColor[
             0.43282766256978505`, 0.5493152995922519, 0.9488003738178407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 215}], {
             RGBColor[
             0.6795663369936606, 0.7457735754287056, 0.9622339379580175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 228}], {
             RGBColor[
             0.4884193070498773, 0.5944784409396859, 0.9531680923794121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 118}], {
             RGBColor[
             0.8185055117525217, 0.8590251240830906, 0.9823102824705627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 166}], {
             RGBColor[
             0.9092124376094941, 0.9304453341083939, 0.9912026880343602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 173}], {
             RGBColor[
             0.9594454209674332, 0.9682028704735121, 0.9072008662375238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 195}], {
             RGBColor[
             0.9365221814060651, 0.952012542243593, 0.9865668926915745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 213}], {
             RGBColor[
             0.7488532937081411, 0.80348024065816, 0.9761419831406768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 234}], {
             RGBColor[
             0.6723448285980815, 0.7403388237507735, 0.9704031060119187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 263}], {
             RGBColor[
             0.7747538959411981, 0.8245075163597896, 0.9781809734254951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 75}], {
             RGBColor[
             0.5894930095299304, 0.6765437451363454, 0.9615593071077846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 83}], {
             RGBColor[
             0.5934800017870587, 0.6796584137898773, 0.9619566932354141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 109}], {
             RGBColor[
             0.4658581318015075, 0.5772436439229636, 0.951093205111431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 111}], {
             RGBColor[
             0.5973769775885884, 0.6827027609041455, 0.9623451073640013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 143}], {
             RGBColor[
             0.4551588377096252, 0.5682959840501904, 0.950323168211137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 163}], {
             RGBColor[
             0.5643945732527493, 0.6569366559614307, 0.9590577295378973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 185}], {
             RGBColor[
             0.4818439021521098, 0.59022161244433, 0.9523516635112368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 218}], {
             RGBColor[
             0.5505356802932706, 0.6459886924686646, 0.9577593319127833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 235}], {
             RGBColor[
             0.6198589954702223, 0.7002658841429422, 0.9645859048000403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 292}], {
             RGBColor[
             0.54802038120886, 0.6439466593590076, 0.9575613183550142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 76}], {
             RGBColor[
             0.7453061624387239, 0.8011293020043206, 0.9752541212363908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 85}], {
             RGBColor[
             0.5077741113410291, 0.6093122277518744, 0.9549347308916486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 90}], {
             RGBColor[
             0.7420625747501166, 0.7985429532262676, 0.9749447449470665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 118}], {
             RGBColor[
             0.6711027114275616, 0.7428685148461756, 0.9679358318362126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 121}], {
             RGBColor[
             0.6280506048129708, 0.7089188002013121, 0.9638615907174984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 126}], {
             RGBColor[
             0.7766383293478119, 0.8261127214086132, 0.9782426112867352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 166}], {
             RGBColor[
             0.761809637284534, 0.8142887248714787, 0.9768282374000101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 173}], {
             RGBColor[
             0.8120426206424731, 0.8520462612365969, 0.8928264156031738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 195}], {
             RGBColor[
             0.789119381081105, 0.8358559330066779, 0.9721924420572243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 213}], {
             RGBColor[
             0.601450493383181, 0.687323631421245, 0.9617675325063266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 234}], {
             RGBColor[
             0.5249420282731214, 0.6241822145138582, 0.9560286553775686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 239}], {
             RGBColor[
             0.7029988094704298, 0.7677859890565877, 0.9711149368031426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 249}], {
             RGBColor[
             0.5882075230518824, 0.6765723915172819, 0.9607249973712482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 258}], {
             RGBColor[
             0.6589131802395964, 0.7333459604382688, 0.9667208932850417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 263}], {
             RGBColor[
             0.627351095616238, 0.7083509071228744, 0.963806522791145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 285}], {
             RGBColor[
             0.5719333447414006, 0.6633602804214547, 0.9594438344403675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 122}], {
             RGBColor[
             0.7569311891683828, 0.8100396649592294, 0.9764074850783225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 138}], {
             RGBColor[
             0.7092411352708003, 0.7723489117789438, 0.9719515437963171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 211}], {
             RGBColor[
             0.5389955439164787, 0.6259918321957005, 0.960017806433799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 231}], {
             RGBColor[
             0.6179428927461155, 0.697632975146308, 0.964928863530683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 266}], {
             RGBColor[
             0.656970111465683, 0.7299129398711621, 0.967836577327309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 108}], {
             RGBColor[
             0.5084396944706331, 0.6100473182048323, 0.9549333207682384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 136}], {
             RGBColor[
             0.4789651069117762, 0.5861185202095145, 0.9526129732666335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 161}], {
             RGBColor[
             0.4589550278663033, 0.5698734365966114, 0.9510377065448392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 177}], {
             RGBColor[
             0.4748842993365045, 0.5828055367816227, 0.9522917171458174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 208}], {
             RGBColor[
             0.39938577031284656`, 0.5203496133576693, 0.9466694860147328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 244}], {
             RGBColor[
             0.4072556273827355, 0.5271660880010896, 0.9471709463481848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 252}], {
             RGBColor[
             0.6916597880204662, 0.7512649411772724, 0.823759086889529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 268}], {
             RGBColor[
             0.5126188616001508, 0.6134401543499086, 0.9552623201134678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 279}], {
             RGBColor[
             0.5347405718954918, 0.6308045306053196, 0.9574106438428018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 280}], {
             RGBColor[
             0.6461904356915575, 0.7185499032737216, 0.9683385022703042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 83}], {
             RGBColor[
             0.7761224672363076, 0.8251284720182233, 0.9782947014997294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 87}], {
             RGBColor[
             0.6389422922515311, 0.7147543096828166, 0.9667338792914992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 106}], {
             RGBColor[
             0.8944710814980674, 0.9181409852962632, 0.9707280905630412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 109}], {
             RGBColor[
             0.6485005972507563, 0.7227137021513094, 0.9674312133757463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 155}], {
             RGBColor[
             0.8221843721770716, 0.37902151615348667`, 0.4374220001819269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 194}], {
             RGBColor[
             0.7547524429524861, 0.8084340466295018, 0.9761647371933492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 210}], {
             RGBColor[
             0.7375908294326277, 0.7950272637146949, 0.9744542279420862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 218}], {
             RGBColor[
             0.7331781457425195, 0.7914587506970105, 0.9740973401770985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 226}], {
             RGBColor[
             0.7831091049022136, 0.830586486463242, 0.9789910642484257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 227}], {
             RGBColor[
             0.7585504718114455, 0.8114010956402093, 0.9765432892154127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 241}], {
             RGBColor[
             0.6067848396635966, 0.6869011405317103, 0.9646848348483149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 290}], {
             RGBColor[
             0.6575721016939888, 0.7300783581249437, 0.9681453554355333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 291}], {
             RGBColor[
             0.7520576091197924, 0.8063288219579058, 0.9758961413415603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 100}], {
             RGBColor[
             0.6350325074423284, 0.7143662605234227, 0.9645621683751557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 119}], {
             RGBColor[
             0.8214909372750874, 0.8601796818655898, 0.922298918512833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 122}], {
             RGBColor[
             0.6830589858702066, 0.7523301382931548, 0.9690445942285497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 161}], {
             RGBColor[
             0.5932005910207241, 0.6804052262660052, 0.9612690066790881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 244}], {
             RGBColor[
             0.5415011905371563, 0.6376978776704832, 0.9574022464824337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 123}], {
             RGBColor[
             0.5443856488386138, 0.6409958198780145, 0.9572751789083651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 189}], {
             RGBColor[
             0.6092691202286219, 0.6934258798003127, 0.962550732553677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 257}], {
             RGBColor[
             0.7315715915594798, 0.7896402832583584, 0.9745626946456196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 260}], {
             RGBColor[
             0.5755990087328017, 0.6663362315859551, 0.9597324089375403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 267}], {
             RGBColor[
             0.7158225639308731, 0.7770824361232741, 0.9730605383310802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 287}], {
             RGBColor[
             0.7606818803003881, 0.8121945572890492, 0.954544014473008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 300}], {
             RGBColor[
             0.6116473982886129, 0.6952838086963604, 0.9627877770844248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 111}], {
             RGBColor[
             0.7202398014858019, 0.7813760740367226, 0.9727504304546355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 143}], {
             RGBColor[
             0.5780216616068385, 0.6669692971827674, 0.9607284913017713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.6872573971499627, 0.7556099690940077, 0.9694630526285316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 165}], {
             RGBColor[
             0.6766744795734448, 0.7473215899981385, 0.9684225517858573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 185}], {
             RGBColor[
             0.6047067260493233, 0.6888949255769071, 0.962756986601871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 235}], {
             RGBColor[
             0.7427218193674356, 0.7989391972755193, 0.9749912278906746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 262}], {
             RGBColor[
             0.6150735386265068, 0.6973111710466493, 0.9635731000628327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 292}], {
             RGBColor[
             0.6708832051060734, 0.7426199724915847, 0.9679666414456485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 85}], {
             RGBColor[
             0.6186390988259288, 0.696334576822634, 0.9658241723196231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 87}], {
             RGBColor[
             0.6510703089477354, 0.7244248609901267, 0.9678906603507915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 90}], {
             RGBColor[
             0.8529275622350163, 0.8855653022970271, 0.985834186375041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 126}], {
             RGBColor[
             0.8875033168327116, 0.9131350704793728, 0.9891320527147097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 151}], {
             RGBColor[
             0.8378879728365849, 0.8735762069162833, 0.9843988835642726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 153}], {
             RGBColor[
             0.773710544100702, 0.8234403118212877, 0.9780022772400498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 192}], {
             RGBColor[
             0.6316552893199469, 0.7076085468157961, 0.9666535524681367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 220}], {
             RGBColor[
             0.7754289094923316, 0.8247827119252895, 0.9781735478432498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 239}], {
             RGBColor[
             0.8138637969553295, 0.8548083381273472, 0.9820043782311172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 248}], {
             RGBColor[
             0.8147085996078753, 0.855468304380254, 0.9820885802643933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 258}], {
             RGBColor[
             0.7697781677244961, 0.8203683095090284, 0.9776103347130163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 82}], {
             RGBColor[
             0.6929784168270089, 0.7583912526006165, 0.9714293731561426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 95}], {
             RGBColor[
             0.9109162217390545, 0.9318038853253172, 0.9913651964856237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 103}], {
             RGBColor[
             0.8365331879929649, 0.8728038189018648, 0.9841879609196761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 127}], {
             RGBColor[
             0.8140414662345026, 0.8552331149207374, 0.9819461962918826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 145}], {
             RGBColor[
             0.7540621728380593, 0.8079817975222364, 0.9762381101865034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 154}], {
             RGBColor[
             0.9231797207302801, 0.9410897442312904, 0.9754519083159565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 159}], {
             RGBColor[
             0.7492181638820405, 0.8040492128316237, 0.9758567720572962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 167}], {
             RGBColor[
             0.639734991963731, 0.7133900444715896, 0.9677285137811287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 168}], {
             RGBColor[
             0.6790740725202401, 0.7471030795088088, 0.9703347722390223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 203}], {
             RGBColor[
             0.9431370549826767, 0.9537405894094424, 0.8281483013303932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 205}], {
             RGBColor[
             0.9433098987436308, 0.9542961377100215, 0.8604708272216175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 212}], {
             RGBColor[
             0.6807968808450138, 0.7485017329184906, 0.9704703980212034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 225}], {
             RGBColor[
             0.9284874950722206, 0.9450482736448267, 0.9664672308443105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 255}], {
             RGBColor[
             0.8896930437371215, 0.914881099274396, 0.9893409108216447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 265}], {
             RGBColor[
             0.7526794851333922, 0.8068592693542164, 0.9761292599454401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 269}], {
             RGBColor[
             0.7822165701900541, 0.830371264252646, 0.9787741880747346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 276}], {
             RGBColor[
             0.6946764482773586, 0.7597697910274556, 0.9715630484120084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 282}], {
             RGBColor[
             0.7046722382069643, 0.7678848235975142, 0.9723499536110518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 293}], {
             RGBColor[
             0.7151574729993382, 0.7763972095564078, 0.9731753897025881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 99}], {
             RGBColor[
             0.6273789602004856, 0.7068708137410611, 0.9648361309187434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 131}], {
             RGBColor[
             0.49703153183632265`, 0.6025516144168942, 0.9535472893540986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 170}], {
             RGBColor[
             0.5631597795786222, 0.6562375049777048, 0.9587531472521256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 178}], {
             RGBColor[
             0.5882306306248575, 0.6762878411382558, 0.9609341912885848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 182}], {
             RGBColor[
             0.6350117263364513, 0.7128335886576487, 0.9655968937149215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 190}], {
             RGBColor[
             0.5550467116403613, 0.6496509509358792, 0.9581144568248785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.7029291479800358, 0.7664696844326736, 0.9722127541751598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 209}], {
             RGBColor[
             0.722031140388839, 0.7817010946696823, 0.9740347192636614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 229}], {
             RGBColor[
             0.4981997445320008, 0.6035000221106279, 0.9536392553368065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 261}], {
             RGBColor[
             0.5079746878547657, 0.6114357614562269, 0.9544087746819718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 284}], {
             RGBColor[
             0.7332913565601987, 0.7902520964159612, 0.9602839504344531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 144}], {
             RGBColor[
             0.5803793856258421, 0.6702171569012503, 0.9601087377176579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 160}], {
             RGBColor[
             0.8016419617038744, 0.8447969515915357, 0.940311985320877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 176}], {
             RGBColor[
             0.6428920845261263, 0.7206453963199231, 0.9652503832397274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 221}], {
             RGBColor[
             0.8025334908613415, 0.828788253804233, 0.6753289714090834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 232}], {
             RGBColor[
             0.5121631386666179, 0.6134412728009355, 0.955123909319676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 240}], {
             RGBColor[
             0.5954198874763823, 0.6824277138704057, 0.9612927811185061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 245}], {
             RGBColor[
             0.5961428350477441, 0.6830146352772541, 0.9613496941995678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 288}], {
             RGBColor[
             0.534592116321513, 0.6328681259324106, 0.9565530639426796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 297}], {
             RGBColor[
             0.6657243633556882, 0.7384821460733231, 0.9675260914136814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 92}], {
             RGBColor[
             0.5410990449791406, 0.6200057686072609, 0.9613936214665058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 125}], {
             RGBColor[
             0.9170144583241657, 0.9358882186618507, 0.9649649562921716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 128}], {
             RGBColor[
             0.8623764073410927, 0.8930995549025444, 0.9867354256563422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 145}], {
             RGBColor[
             0.7423609824686666, 0.7986515859420339, 0.9751220402032947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 149}], {
             RGBColor[
             0.8663299412989889, 0.8962519955647504, 0.9871125172546078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 150}], {
             RGBColor[
             0.8210539560265472, 0.8605221725118867, 0.9826953310578821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 156}], {
             RGBColor[
             0.670114254668532, 0.7399984376358872, 0.9694345131423843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 167}], {
             RGBColor[
             0.6280338015943381, 0.7040598328913871, 0.96661244379792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 179}], {
             RGBColor[
             0.6771214965273229, 0.7456872322495021, 0.9699861488898809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 201}], {
             RGBColor[
             0.648671883912178, 0.7219355024949218, 0.9679274841536731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 205}], {
             RGBColor[
             0.9316087083742381, 0.944965926129819, 0.8593547572384088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 237}], {
             RGBColor[
             0.7561948142476838, 0.8098537180065037, 0.9762307779485055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 256}], {
             RGBColor[
             0.6695345124790275, 0.7395277768093595, 0.9693888737135608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 269}], {
             RGBColor[
             0.7705153798206613, 0.8210410526724434, 0.9776581180915259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 277}], {
             RGBColor[
             0.8613957296524124, 0.8923175891333774, 0.9866418877429346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 281}], {
             RGBColor[
             0.6453938053378329, 0.7190961955948438, 0.967718607885607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 282}], {
             RGBColor[
             0.6929710478375715, 0.7585546120173117, 0.9712338836278431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 293}], {
             RGBColor[
             0.7034562826299454, 0.7670669979762053, 0.9720593197193794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 86}], {
             RGBColor[
             0.5797128809382943, 0.6682332185112578, 0.9609212964925394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 94}], {
             RGBColor[
             0.7007728780260872, 0.7661683654758953, 0.970810149452914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 97}], {
             RGBColor[
             0.6219619152961778, 0.7028309936596527, 0.9641649277309873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.7356094100217251, 0.7933829290383371, 0.9742823293963384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 140}], {
             RGBColor[
             0.5875026327482926, 0.6748553957142915, 0.9614521667803066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 162}], {
             RGBColor[
             0.7648792622348065, 0.8162487600463122, 0.9771996747226179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 167}], {
             RGBColor[
             0.5525017597164978, 0.6446643129796572, 0.9591874279101362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 181}], {
             RGBColor[
             0.7772409531951736, 0.8260465347259303, 0.9783944277333617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 201}], {
             RGBColor[
             0.5731398420343378, 0.6625399825831919, 0.9605024682658894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 202}], {
             RGBColor[
             0.6355169151607345, 0.7138355531954849, 0.9652320269739257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 203}], {
             RGBColor[
             0.8559038227354436, 0.8850148579175101, 0.8196072154594007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 216}], {
             RGBColor[
             0.7606510673791699, 0.8129456620896178, 0.9767782477741356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 237}], {
             RGBColor[
             0.6806627723698435, 0.750458198094774, 0.9688057620607218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 269}], {
             RGBColor[
             0.6949833379428211, 0.7616455327607136, 0.9702331022037421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 293}], {
             RGBColor[
             0.6279242407521052, 0.7076714780644754, 0.9646343038315957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 299}], {
             RGBColor[
             0.6238699084803851, 0.7043799884807056, 0.9643151319436574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 103}], {
             RGBColor[
             0.6379583722319149, 0.714830708131829, 0.9660989967809614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 140}], {
             RGBColor[
             0.47616104923447566`, 0.5856080164361881, 0.9519042885125844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 145}], {
             RGBColor[
             0.5554873570770094, 0.6500086867522008, 0.9581491460477889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 154}], {
             RGBColor[
             0.7246049049692301, 0.7831166334612547, 0.9573629441772418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 167}], {
             RGBColor[
             0.4411601762026809, 0.555416933701554, 0.9496395496424141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 168}], {
             RGBColor[
             0.48049925675919014`, 0.5891299687387732, 0.9522458081003078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 181}], {
             RGBColor[
             0.6658993696813567, 0.7367991554478269, 0.9688465494656395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 201}], {
             RGBColor[
             0.46179825852052075`, 0.5732926033050887, 0.9509545899981673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 203}], {
             RGBColor[
             0.7445622392216267, 0.7957674786394068, 0.8100593371916787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 216}], {
             RGBColor[
             0.6493094838653529, 0.7236982828115146, 0.9672303695064133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 255}], {
             RGBColor[
             0.6911182279760716, 0.7569079885043604, 0.97125194668293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 258}], {
             RGBColor[
             0.5888943932956637, 0.6765015548867787, 0.9612087578895476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 293}], {
             RGBColor[
             0.5165826572382882, 0.6184240987863721, 0.9550864255638735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 101}], {
             RGBColor[
             0.7786417049346004, 0.8271372437759563, 0.9785349886403425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 142}], {
             RGBColor[
             0.664912119278592, 0.7376502247497252, 0.9675800911888157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 149}], {
             RGBColor[
             0.7924194243450524, 0.8381232232476201, 0.9798491198172268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 194}], {
             RGBColor[
             0.6989597936575789, 0.7647519701872652, 0.9706294381472977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[
             0.6791778394963484, 0.749231779085872, 0.9687031409414125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 198}], {
             RGBColor[
             0.7113283485700044, 0.7744143792893508, 0.9718622201102511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 226}], {
             RGBColor[
             0.7273164556073064, 0.7869044100210052, 0.9734557652023743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 241}], {
             RGBColor[
             0.5509921903686894, 0.6432190640894735, 0.9591495358022635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 243}], {
             RGBColor[
             0.8391127433138477, 0.874782817369258, 0.9644576160930753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 290}], {
             RGBColor[
             0.6017794523990817, 0.6863962816827069, 0.9626100563894819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 291}], {
             RGBColor[
             0.6962649598248851, 0.7626467455156691, 0.9703608422955089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 191}], {
             RGBColor[
             0.8015826158078962, 0.8455278609322681, 0.9806970652058807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 217}], {
             RGBColor[
             0.682787791173105, 0.7521182789346229, 0.9690175640756011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 223}], {
             RGBColor[
             0.851301894469817, 0.881214347064881, 0.8026930782756384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 246}], {
             RGBColor[
             0.6332785538208343, 0.7121547058245681, 0.9649625881736568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 247}], {
             RGBColor[
             0.7863747326217849, 0.833401507686655, 0.9792465237313519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 270}], {
             RGBColor[
             0.7762960058171402, 0.8253650045123823, 0.9782852057713392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 271}], {
             RGBColor[
             0.6236519180365464, 0.7043393692198832, 0.9642047441411887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 278}], {
             RGBColor[
             0.7949406870187723, 0.8402317672061748, 0.9800635521086543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 295}], {
             RGBColor[
             0.5770775124705391, 0.6663286387549494, 0.9605933670258806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[
             0.5013835412001757, 0.6041240750196255, 0.9544316418007308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 135}], {
             RGBColor[
             0.4929059592910911, 0.597241592115118, 0.953764255498442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 154}], {
             RGBColor[
             0.6679566283003677, 0.7351663138310582, 0.9534451306559684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 173}], {
             RGBColor[
             0.685375557029678, 0.7472515360549102, 0.883396466686406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 213}], {
             RGBColor[
             0.4747834297703859, 0.5825289062395582, 0.952337583589559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 234}], {
             RGBColor[
             0.3982749646603263, 0.5193874893321717, 0.946598706460801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 239}], {
             RGBColor[
             0.5763317458576347, 0.662991263874901, 0.9616849878863749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 249}], {
             RGBColor[
             0.4615404594390872, 0.5717776663355952, 0.9512950484544804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 255}], {
             RGBColor[
             0.6344699513072092, 0.7089576688741638, 0.9673341331616565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 258}], {
             RGBColor[
             0.5322461166268013, 0.6285512352565821, 0.957290944368274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 263}], {
             RGBColor[
             0.5006840320034429, 0.6035561819411878, 0.9543765738743775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 286}], {
             RGBColor[
             0.6869736999272867, 0.745806032328448, 0.7037997395154699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[
             0.5633989908707887, 0.6554886836003657, 0.9592952803925809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 97}], {
             RGBColor[
             0.4845880281408793, 0.5921513117841231, 0.9526500586706543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 120}], {
             RGBColor[
             0.5228676848954232, 0.6232284616163466, 0.9556635734733749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 130}], {
             RGBColor[
             0.5982355228664266, 0.6827032471628074, 0.9627674603360055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 140}], {
             RGBColor[
             0.4501287455929941, 0.5641757138387619, 0.9499372977199736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 162}], {
             RGBColor[
             0.627505375079508, 0.7055690781707826, 0.965684805662285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 169}], {
             RGBColor[
             0.6640746622763336, 0.5659633714915935, 0.5879180535962742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[
             0.5522489773278887, 0.6467782082774107, 0.9581839512454254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 182}], {
             RGBColor[
             0.5990300730394824, 0.6833239557968036, 0.9628466536717621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 202}], {
             RGBColor[
             0.498143028005436, 0.6031558713199552, 0.9537171579135928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 261}], {
             RGBColor[
             0.47199303455779684`, 0.5819261285953818, 0.9516585346388124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 284}], {
             RGBColor[
             0.6973097032632298, 0.7607424635551161, 0.9575337103912938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 109}], {
             RGBColor[
             0.4555277729710726, 0.5686574633736661, 0.9503350921214648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 140}], {
             RGBColor[
             0.45194398268741987`, 0.5657479809734843, 0.9500529630224793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 151}], {
             RGBColor[
             0.6327871318606968, 0.7098494168313298, 0.966145981250699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[
             0.7003878384221744, 0.7632565979985508, 0.9555116186871367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 155}], {
             RGBColor[
             0.6935358226572824, 0.2763173569683911, 0.426024586012406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 162}], {
             RGBColor[
             0.6293206121739338, 0.7071413453055051, 0.9658004709647907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 181}], {
             RGBColor[
             0.6416823031343009, 0.7169391199851232, 0.9669952239755344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 202}], {
             RGBColor[
             0.49995826509986174`, 0.6047281384546777, 0.9538328232160984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 203}], {
             RGBColor[
             0.7203451726745709, 0.775907443176703, 0.8082080117015735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 216}], {
             RGBColor[
             0.6250924173182971, 0.7038382473488107, 0.9653790440163083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 227}], {
             RGBColor[
             0.5655776475317619, 0.657344856862566, 0.9594471679611312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 258}], {
             RGBColor[
             0.564677326748608, 0.6566415194240749, 0.9593574323994425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 299}], {
             RGBColor[
             0.48831125841951234`, 0.5952725737398985, 0.9529159281858302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 93}], {
             RGBColor[
             0.8583512877090256, 0.889890033766896, 0.986351506152569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 107}], {
             RGBColor[
             0.8259558312494903, 0.864072218509508, 0.9832580314034248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 124}], {
             RGBColor[
             0.9138353481009984, 0.9309832925405105, 0.8658822461049047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 137}], {
             RGBColor[
             0.8643850771169272, 0.8947012136579064, 0.986927014372722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 147}], {
             RGBColor[
             0.6299112674143423, 0.7068744663727745, 0.9661849576408696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 273}], {
             RGBColor[
             0.6373119245844807, 0.7132845436457036, 0.9666565209716067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 274}], {
             RGBColor[
             0.6313343238292017, 0.7081070463144306, 0.9662756335372651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 289}], {
             RGBColor[
             0.9005736327676523, 0.9227354688282544, 0.961896208179998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 94}], {
             RGBColor[
             0.4316929939792908, 0.5294089152825016, 0.9513425666764778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 120}], {
             RGBColor[
             0.39116168800392537`, 0.49714869329848255`, 0.9477108597572718]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 131}], {
             RGBColor[
             0.3293438816478559, 0.44696221323818497`, 0.9428443355948359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 141}], {
             RGBColor[
             0.4667446732133444, 0.5567915535027732, 0.9548361904859624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 188}], {
             RGBColor[
             0.30020259516386466`, 0.4224394785886223, 0.9407890977412605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 236}], {
             RGBColor[
             0.3107453016360948, 0.43157104104303334`, 0.9414608696751218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 260}], {
             RGBColor[
             0.3849782912237224, 0.4921287332334633, 0.9472240801122055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 281}], {
             RGBColor[
             0.30078187941319623`, 0.42294122548972035`, 0.940826009221387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 294}], {
             RGBColor[
             0.4667446732133444, 0.5567915535027732, 0.9548361904859624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 118}], {
             RGBColor[
             0.7787241112238541, 0.8273045151388819, 0.9785158969748629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 126}], {
             RGBColor[
             0.8842597291441042, 0.9105487217013197, 0.9888226764253855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 153}], {
             RGBColor[
             0.7704669564120947, 0.8208539630432345, 0.9776929009507256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.8694310370808264, 0.8987247251641852, 0.9874083025386604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 195}], {
             RGBColor[
             0.8967407808773975, 0.9202919332993843, 0.9827725071958746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 222}], {
             RGBColor[
             0.7996216546054817, 0.8436298348558218, 0.9805987688004975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 234}], {
             RGBColor[
             0.6325634280694139, 0.7086182148065647, 0.9666087205162189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 239}], {
             RGBColor[
             0.8106202092667222, 0.8522219893492942, 0.9816950019417929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 248}], {
             RGBColor[
             0.811465011919268, 0.8528819556022009, 0.981779203975069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 285}], {
             RGBColor[
             0.6795547445376929, 0.7477962807141612, 0.9700238995790178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 93}], {
             RGBColor[
             0.7151279809764639, 0.7764343496720916, 0.9731027624910382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 105}], {
             RGBColor[
             0.5054560123120769, 0.609390987185632, 0.9542104953170387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 107}], {
             RGBColor[
             0.6827325245169287, 0.7506165344147037, 0.9700092877418941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 139}], {
             RGBColor[
             0.7094863322294677, 0.7719358520997124, 0.9725646569971904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 142}], {
             RGBColor[
             0.5783192943540824, 0.6685446820007814, 0.9599465597863821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 143}], {
             RGBColor[
             0.49541582893945724`, 0.6009784230873558, 0.9534923460269672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 150}], {
             RGBColor[
             0.6605506141481011, 0.7332878574458126, 0.9677984022180675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 163}], {
             RGBColor[
             0.6046515644825814, 0.6896190949985961, 0.9622269073537275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 179}], {
             RGBColor[
             0.5166181546488768, 0.6184529171834281, 0.9550892200500662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 235}], {
             RGBColor[
             0.6601159867000543, 0.7329483231801076, 0.9677550826158705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 273}], {
             RGBColor[
             0.49408861785191915`, 0.5998288595508992, 0.953407777310076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 274}], {
             RGBColor[
             0.48811101709664007`, 0.5946513622196262, 0.9530268898757344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 298}], {
             RGBColor[
             0.5200097747974766, 0.6212063872108078, 0.955356220812078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 125}], {
             RGBColor[
             0.589962651454033, 0.6581900470588644, 0.9390723804302374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 128}], {
             RGBColor[
             0.53532460047096, 0.6154013832995582, 0.9608428497944081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 142}], {
             RGBColor[
             0.41177082936239573`, 0.5180808254638692, 0.9489509127642626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 149}], {
             RGBColor[
             0.5392781344288562, 0.6185538239617641, 0.9612199413926736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 150}], {
             RGBColor[
             0.4940021491564145, 0.5828240009089004, 0.9568027551959479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 179}], {
             RGBColor[
             0.3500696896571902, 0.4679890606465158, 0.9440935730279468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 237}], {
             RGBColor[
             0.42914300737755107`, 0.5321555464035175, 0.9503382020865714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 243}], {
             RGBColor[
             0.5859714533976514, 0.6552134180834019, 0.9458284376685222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 256}], {
             RGBColor[
             0.3424827056088948, 0.4618296052063732, 0.9434962978516267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 269}], {
             RGBColor[
             0.44346357295052863`, 0.543342881069457, 0.9517655422295919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 277}], {
             RGBColor[
             0.5343439227822797, 0.6146194175303912, 0.9607493118810004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 281}], {
             RGBColor[
             0.3183419984677002, 0.44139802399185757`, 0.9418260320236729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 105}], {
             RGBColor[
             0.6734398251961596, 0.7425900267796246, 0.9698209181592663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 107}], {
             RGBColor[
             0.8507163374010114, 0.8838155740086961, 0.9856197105841217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 137}], {
             RGBColor[
             0.8891455832684483, 0.9144445691570945, 0.9892886935534189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 139}], {
             RGBColor[
             0.8774701451135504, 0.905134891693705, 0.988175079839418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 147}], {
             RGBColor[
             0.6546717735658634, 0.7266178218719626, 0.9685466368215665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 273}], {
             RGBColor[
             0.6620724307360019, 0.7330278991448917, 0.9690182001523036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 274}], {
             RGBColor[
             0.6560948299807228, 0.7278504018136187, 0.9686373127179619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 289}], {
             RGBColor[
             0.9253341389191734, 0.9424788243274425, 0.9642578873606948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 97}], {
             RGBColor[
             0.6056480252286722, 0.6900864587487605, 0.9625389116310288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 120}], {
             RGBColor[
             0.6439276819832161, 0.721163608580984, 0.9655524264337495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 130}], {
             RGBColor[
             0.7192955199542195, 0.7806383941274448, 0.9726563132963799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 141}], {
             RGBColor[
             0.7195106671926352, 0.7808064687852748, 0.9726777571624401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 188}], {
             RGBColor[
             0.5529685891431555, 0.6464543938711238, 0.9586306644177383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 201}], {
             RGBColor[
             0.5568259519668322, 0.6497954476722998, 0.958876452165931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 202}], {
             RGBColor[
             0.6192030250932289, 0.7010910182845926, 0.9636060108739672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.6643488823023378, 0.7377136631838818, 0.9671797459607633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 281}], {
             RGBColor[
             0.553547873392487, 0.646956140772222, 0.9586675758978648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 293}], {
             RGBColor[
             0.6116103506845996, 0.6949269431535832, 0.9630082877316373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 294}], {
             RGBColor[
             0.7195106671926352, 0.7808064687852748, 0.9726777571624401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 103}], {
             RGBColor[
             0.8558961771439606, 0.8882433408565298, 0.9860348201104425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 127}], {
             RGBColor[
             0.8334044553854982, 0.8706726368754024, 0.9837930554826491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 145}], {
             RGBColor[
             0.773425161989055, 0.8234213194769014, 0.97808496937727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 148}], {
             RGBColor[
             0.6952358941497101, 0.7599437494585459, 0.9719296237962313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 156}], {
             RGBColor[
             0.7011784341889205, 0.7647681711707548, 0.9723974423163593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 159}], {
             RGBColor[
             0.7685811530330362, 0.8194887347862887, 0.9777036312480627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 168}], {
             RGBColor[
             0.6984370616712358, 0.7625426014634739, 0.9721816314297889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 191}], {
             RGBColor[
             0.9126294427683059, 0.9331699612698963, 0.9915286050368042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 205}], {
             RGBColor[
             0.9626728878946265, 0.9697356596646866, 0.8623176864123839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 212}], {
             RGBColor[
             0.7001598699960094, 0.7639412548731557, 0.9723172572119698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 225}], {
             RGBColor[
             0.9478504842232163, 0.9604877955994917, 0.9683140900350768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 251}], {
             RGBColor[
             0.903010254696242, 0.9254998818071369, 0.9906111182913402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 271}], {
             RGBColor[
             0.7346987449969561, 0.7919814695575114, 0.9750362839721123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 276}], {
             RGBColor[
             0.7140394374283543, 0.7752093129821206, 0.9734099076027747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 282}], {
             RGBColor[
             0.72403522735796, 0.7833243455521792, 0.9741968128018184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 112}], {
             RGBColor[
             0.43188007847164067`, 0.5480166639094344, 0.9488720359127287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 132}], {
             RGBColor[
             0.4912398865984917, 0.596207630275694, 0.9535450574506161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 133}], {
             RGBColor[
             0.403895906258977, 0.5242560664281836, 0.9469568678890635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 146}], {
             RGBColor[
             0.39015819402831886`, 0.5123571505714808, 0.946081513013508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 236}], {
             RGBColor[
             0.4177027935533446, 0.5362148982482318, 0.9478366305385095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 260}], {
             RGBColor[
             0.4919357831409723, 0.5967725904386616, 0.9535998409755932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 267}], {
             RGBColor[
             0.6321593383390436, 0.7075187949759807, 0.9669279703691334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 120}], {
             RGBColor[
             0.5651167192533068, 0.6578262367647415, 0.9589072047118228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 130}], {
             RGBColor[
             0.6404845572243101, 0.7173010223112023, 0.9660110915744533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 178}], {
             RGBColor[
             0.5944980116857721, 0.6813759834258055, 0.9614275824838733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 182}], {
             RGBColor[
             0.6412791073973659, 0.7179217309451984, 0.96609028491021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 202}], {
             RGBColor[
             0.5403920623633195, 0.6377536464683501, 0.9569607891520406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 261}], {
             RGBColor[
             0.5142420689156804, 0.6165239037437767, 0.9549021658772603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 284}], {
             RGBColor[
             0.7395587376211133, 0.7953402387035109, 0.9607773416297416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 157}], {
             RGBColor[
             0.7628977996112702, 0.8123513339942563, 0.8974459430473121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.86733296190044, 0.8955482213085187, 0.9067533787839208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 275}], {
             RGBColor[
             0.9841449233033015, 0.9869594875822258, 0.8787450713512519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 285}], {
             RGBColor[
             0.749025017506862, 0.801088784520186, 0.8963538268223779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 182}], {
             RGBColor[
             0.7480883861600033, 0.8031316000412914, 0.9755261171151397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 199}], {
             RGBColor[
             0.8160058078035878, 0.8567676958163162, 0.982141977575378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 209}], {
             RGBColor[
             0.835107800212391, 0.8719991060533249, 0.9839639426638795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 215}], {
             RGBColor[
             0.8430483706728282, 0.8780743214638187, 0.9758324681209967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 229}], {
             RGBColor[
             0.6112764043555527, 0.6937980334942706, 0.9635684787370247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 233}], {
             RGBColor[
             0.6021117382779051, 0.6863577447089344, 0.9628470026521143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 259}], {
             RGBColor[
             0.6554729998331774, 0.7296788207369429, 0.967047796630487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 284}], {
             RGBColor[
             0.8463680163837507, 0.8805501077996037, 0.9702131738346713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 119}], {
             RGBColor[
             0.799753142911379, 0.8427527238881861, 0.9204367030052352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 122}], {
             RGBColor[
             0.6613211915064983, 0.7349031803157511, 0.9671823787209519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 161}], {
             RGBColor[
             0.5714627966570157, 0.6629782682886015, 0.9594067911714903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 244}], {
             RGBColor[
             0.5197633961734479, 0.6202709196930796, 0.9555400309748359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 266}], {
             RGBColor[
             0.5613601138037985, 0.6547764552276838, 0.9586114709699385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 104}], {
             RGBColor[
             0.9106668049783121, 0.9303184211313438, 0.9464188147571673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 116}], {
             RGBColor[
             0.798976853227781, 0.8430232161754402, 0.9805618061794417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 136}], {
             RGBColor[
             0.7033023151270787, 0.7671677466164581, 0.9717873688730092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 149}], {
             RGBColor[
             0.8507313113382524, 0.8838140714475899, 0.9856247060038914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 197}], {
             RGBColor[
             0.7374897264895484, 0.7949226272858417, 0.974478727128077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 198}], {
             RGBColor[
             0.7696402355632044, 0.8201052274893206, 0.9776378062969157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[
             0.8961048707427313, 0.9194893910470685, 0.9724672109737054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 226}], {
             RGBColor[
             0.7856283426005064, 0.832595258220975, 0.9792313513890389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 243}], {
             RGBColor[
             0.8974246303070477, 0.9204736655692277, 0.97023320227974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 254}], {
             RGBColor[
             0.6441323791399629, 0.7190764367682645, 0.9671443505807689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 283}], {
             RGBColor[
             0.8512932629384209, 0.8842621563997944, 0.9856783054491756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 165}], {
             RGBColor[
             0.5805306797171799, 0.6703399842603195, 0.9601206481427366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 172}], {
             RGBColor[
             0.6959483650405841, 0.760945120457305, 0.9714988986288737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 175}], {
             RGBColor[
             0.6587394049228454, 0.7314581582512529, 0.9679014574907813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 183}], {
             RGBColor[
             0.57373649943426, 0.6648241626323113, 0.9595857853829627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 238}], {
             RGBColor[
             0.7573945555459543, 0.8061853311207585, 0.8110695441390532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 253}], {
             RGBColor[
             0.5177666142630835, 0.619385288435757, 0.9551796309978429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 127}], {
             RGBColor[
             0.7590214216394087, 0.81167257045195, 0.9766158199167014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 145}], {
             RGBColor[
             0.6990421282429653, 0.764421253053449, 0.9709077338113223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 154}], {
             RGBColor[
             0.8681596761351862, 0.897529199762503, 0.9701215319407752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 159}], {
             RGBColor[
             0.6941981192869466, 0.7604886683628362, 0.9705263956821151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 167}], {
             RGBColor[
             0.5847149473686369, 0.6698295000028022, 0.9623981374059476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 168}], {
             RGBColor[
             0.6240540279251461, 0.7035425350400214, 0.9650043958638412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 203}], {
             RGBColor[
             0.8881170103875827, 0.910180044940655, 0.8228179249552121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 205}], {
             RGBColor[
             0.8882898541485369, 0.9107355932412341, 0.8551404508464363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 212}], {
             RGBColor[
             0.6257768362499198, 0.7049411884497032, 0.9651400216460222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 225}], {
             RGBColor[
             0.8734674504771267, 0.9014877291760393, 0.9611368544691292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 255}], {
             RGBColor[
             0.8346729991420276, 0.8713205548056085, 0.9840105344464635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 265}], {
             RGBColor[
             0.6976594405382983, 0.7632987248854289, 0.970798883570259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 269}], {
             RGBColor[
             0.7271965255949602, 0.7868107197838585, 0.9734438116995534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 276}], {
             RGBColor[
             0.6396564036822647, 0.7162092465586681, 0.9662326720368271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 282}], {
             RGBColor[
             0.6496521936118703, 0.7243242791287268, 0.9670195772358707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 293}], {
             RGBColor[
             0.6601374284042443, 0.7328366650876204, 0.9678450133274069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 114}], {
             RGBColor[
             0.8424372580692678, 0.8768798216281095, 0.9396547289158926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 116}], {
             RGBColor[
             0.8726900662782927, 0.9005135453308579, 0.9426700461096017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 204}], {
             RGBColor[
             0.969818083793243, 0.9769797202024864, 0.9345754509038655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 206}], {
             RGBColor[
             0.8222228375214593, 0.8610881626608751, 0.9376399443901873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 243}], {
             RGBColor[
             0.9711378433575593, 0.9779639947246455, 0.9323414422099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 254}], {
             RGBColor[
             0.7178455921904746, 0.7765667659236823, 0.929252590510929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 283}], {
             RGBColor[
             0.9250064759889326, 0.9417524855552122, 0.9477865453793357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 287}], {
             RGBColor[
             0.9727876718057208, 0.9791944340799382, 0.9295487129913369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 300}], {
             RGBColor[
             0.8237531897939456, 0.8622836854872493, 0.9377924756027536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 139}], {
             RGBColor[
             0.6677981764491634, 0.7380915292072454, 0.9692828126654185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 143}], {
             RGBColor[
             0.45372767315915297`, 0.5671341001948889, 0.9502105016951954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 163}], {
             RGBColor[
             0.562963408702277, 0.6557747721061291, 0.9589450630219556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 174}], {
             RGBColor[
             0.5694397476157256, 0.6608341372873139, 0.9595905639600201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 235}], {
             RGBColor[
             0.6184278309197501, 0.6991040002876405, 0.9644732382840986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 274}], {
             RGBColor[
             0.4464228613163358, 0.5608070393271591, 0.9497450455439624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 298}], {
             RGBColor[
             0.4783216190171723, 0.5873620643183408, 0.9520743764803061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 115}], {
             RGBColor[
             0.8850227193770005, 0.9106634182238585, 0.9698119569504912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 155}], {
             RGBColor[
             0.86388834882164, 0.4119084740440222, 0.4286873935267672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 162}], {
             RGBColor[
             0.8848494014204702, 0.9105280209189517, 0.9697946822363326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 194}], {
             RGBColor[
             0.8173084079193388, 0.8577644834653051, 0.9630628272106097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 200}], {
             RGBColor[
             0.8357482473206912, 0.8721698261536117, 0.9649007380720399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 210}], {
             RGBColor[
             0.8001467943994803, 0.8443577005504981, 0.9613523179593468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 211}], {
             RGBColor[
             0.6152517129477443, 0.6861214073452458, 0.9482558139328002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 227}], {
             RGBColor[
             0.8211064367782983, 0.8607315324760128, 0.963441379232673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 241}], {
             RGBColor[
             0.6693408046304493, 0.7362315773675135, 0.9515829248655754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 264}], {
             RGBColor[
             0.9604119991487234, 0.9699959143012957, 0.9518963386236754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 290}], {
             RGBColor[
             0.7201280666608416, 0.7794087949607469, 0.9550434454527937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 291}], {
             RGBColor[
             0.814613574086645, 0.8556592587937091, 0.9627942313588207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 137}], {
             RGBColor[
             0.8567501268089132, 0.8886267538997066, 0.9861952188042747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 139}], {
             RGBColor[
             0.8450746886540152, 0.879317076436317, 0.9850816050902739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[
             0.6222763171063282, 0.7008000066145748, 0.9654531620724224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 150}], {
             RGBColor[
             0.7961389705726487, 0.8406690817824172, 0.9803153503111508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.6451992692146334, 0.7201453469064178, 0.967054532395653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.6522065110734243, 0.7258341415200327, 0.9676061681431498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 251}], {
             RGBColor[
             0.8470310897219551, 0.8808770575428, 0.9852682083706339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 273}], {
             RGBColor[
             0.6296769742764667, 0.7072100838875037, 0.9659247254031593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 274}], {
             RGBColor[
             0.6236993735211876, 0.7020325865562308, 0.9655438379688178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 277}], {
             RGBColor[
             0.8364807441985138, 0.872464498403908, 0.9842619069962033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 289}], {
             RGBColor[
             0.8929386824596381, 0.9166610090700547, 0.9611644126115507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 136}], {
             RGBColor[
             0.5991256258852138, 0.6854361992523079, 0.9615845104206164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 177}], {
             RGBColor[
             0.5950448183099422, 0.6821232158244162, 0.9612632542998003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 204}], {
             RGBColor[
             0.7919281815008664, 0.8377578436829184, 0.9622643525213126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 208}], {
             RGBColor[
             0.5195462892862842, 0.6196672924004626, 0.9556410231687156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 252}], {
             RGBColor[
             0.811820306993904, 0.8505826202200657, 0.832730624043512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 254}], {
             RGBColor[
             0.5399556898980981, 0.6373448894041144, 0.9569414921283761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 268}], {
             RGBColor[
             0.6327793805735885, 0.712757833392702, 0.9642338572674507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 279}], {
             RGBColor[
             0.6549010908689294, 0.730122209648113, 0.9663821809967847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 280}], {
             RGBColor[
             0.7663509546649951, 0.8178675823165149, 0.9773100394242871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 283}], {
             RGBColor[
             0.747116573696556, 0.8025306090356443, 0.9754754469967827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 111}], {
             RGBColor[
             0.5966049237573788, 0.6820759728233408, 0.962284328458282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 151}], {
             RGBColor[
             0.6423454368599221, 0.7178088092998227, 0.9668433153349458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 155}], {
             RGBColor[
             0.6999080259900993, 0.28162361861405294`, 0.42648947540190396`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 192}], {
             RGBColor[
             0.436112753343284, 0.5518411491993354, 0.9490979842388099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 218}], {
             RGBColor[
             0.549763626462061, 0.64536190438786, 0.9576985530070641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 220}], {
             RGBColor[
             0.5798863735156686, 0.6690153143088288, 0.9606179796139231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 227}], {
             RGBColor[
             0.5751359525309871, 0.6653042493310588, 0.9601445020453782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 290}], {
             RGBColor[
             0.47415758241353045`, 0.5839815118157932, 0.9517465682654989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 292}], {
             RGBColor[
             0.5472483273776503, 0.6433198712782029, 0.957500539449295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 148}], {
             RGBColor[
             0.727163185667616, 0.7812525974729849, 0.776762523326316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 191}], {
             RGBColor[
             0.9445567342862117, 0.9544788092843353, 0.7963615045668889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 223}], {
             RGBColor[
             0.9942760129481324, 0.9901652954169482, 0.6183575176366466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 246}], {
             RGBColor[
             0.7762526722991498, 0.8211056541766353, 0.780627027534665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 278}], {
             RGBColor[
             0.9379148054970878, 0.949182715558242, 0.7957279914696624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 295}], {
             RGBColor[
             0.7200516309488545, 0.7752795871070167, 0.7762578063868888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 143}], {
             RGBColor[
             0.5859056296654965, 0.6731283129505676, 0.961514291557988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 163}], {
             RGBColor[
             0.6951413652086207, 0.7617689848618079, 0.9702488528847483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.6125906941079813, 0.6950539413447072, 0.9635427868580877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 218}], {
             RGBColor[
             0.6812824722491421, 0.7508210213690418, 0.9689504552596342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 235}], {
             RGBColor[
             0.7506057874260936, 0.8050982130433194, 0.9757770281468913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 262}], {
             RGBColor[
             0.6229575066851648, 0.7034701868144494, 0.9643589003190494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 292}], {
             RGBColor[
             0.6787671731647313, 0.7487789882593848, 0.9687524417018651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 131}], {
             RGBColor[
             0.4753394682022467, 0.584941019942421, 0.9518396106441769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 132}], {
             RGBColor[
             0.5302779812356327, 0.6295425797747316, 0.9561645716365692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 133}], {
             RGBColor[
             0.442934000896118, 0.557591015927221, 0.9495763820750165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 146}], {
             RGBColor[
             0.4291962886654599, 0.5456921000705184, 0.9487010271994609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 170}], {
             RGBColor[
             0.5414677159445462, 0.6386269105032316, 0.9570454685422037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 190}], {
             RGBColor[
             0.5333546480062854, 0.6320403564614059, 0.9564067781149568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 115}], {
             RGBColor[
             0.8983214016326277, 0.9205815536755118, 0.9473007567435454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 134}], {
             RGBColor[
             0.9048170853081856, 0.9257047351037887, 0.9479352612500757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 144}], {
             RGBColor[
             0.7610016095438159, 0.8117134445029953, 0.9347030392844755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 160}], {
             RGBColor[
             0.9822641856218481, 0.9862932391932807, 0.9149062868876945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 169}], {
             RGBColor[
             0.9347173708729231, 0.7808404496914157, 0.5695167299633761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 176}], {
             RGBColor[
             0.8235143084441001, 0.8621416839216681, 0.9398446848065449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 187}], {
             RGBColor[
             0.9164594666300054, 0.9349880539457855, 0.9490457219738273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 193}], {
             RGBColor[
             0.7178940917250212, 0.7766854795826996, 0.9313181169045441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 200}], {
             RGBColor[
             0.8490469295763186, 0.8820879616052649, 0.9423895378650942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 228}], {
             RGBColor[
             0.7734857362051135, 0.8218486209301337, 0.9356858354661156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 231}], {
             RGBColor[
             0.7074977440330081, 0.7676806857475065, 0.9306556708227385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 245}], {
             RGBColor[
             0.776765058965718, 0.8245109228789992, 0.9359439957663854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 264}], {
             RGBColor[
             0.9737106814043506, 0.9799140497529488, 0.9293851384167297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 288}], {
             RGBColor[
             0.7152143402394868, 0.7743644135341556, 0.9311473655094971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 297}], {
             RGBColor[
             0.8463465872736621, 0.8799784336750681, 0.9421203929804989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 116}], {
             RGBColor[
             0.7307473063187369, 0.7895846166722058, 0.973797720338167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 204}], {
             RGBColor[
             0.8278753238336871, 0.8660507915438342, 0.9657031251324308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 206}], {
             RGBColor[
             0.6802800775619033, 0.750159234002223, 0.9687676186187526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 254}], {
             RGBColor[
             0.5759028322309188, 0.6656378372650302, 0.9603802647394943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 283}], {
             RGBColor[
             0.7830637160293767, 0.8308235568965601, 0.978914219607901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 134}], {
             RGBColor[
             0.8195140759646388, 0.8589785957439275, 0.9826322378272109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 169}], {
             RGBColor[
             0.8494143615293762, 0.7141143103315546, 0.6042137065405113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 193}], {
             RGBColor[
             0.6325910823814744, 0.7099593402228386, 0.9660150934816794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 200}], {
             RGBColor[
             0.7637439202327716, 0.8153618222454038, 0.9770865144422294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 210}], {
             RGBColor[
             0.7281424673115607, 0.7875496966422901, 0.9735380943295362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 211}], {
             RGBColor[
             0.5432473858598247, 0.6293134034370379, 0.9604415903029897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 227}], {
             RGBColor[
             0.7491021096903787, 0.8039235285678048, 0.9756271556028626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 228}], {
             RGBColor[
             0.6881827268615666, 0.7551224815702726, 0.9703828120432508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 231}], {
             RGBColor[
             0.6221947346894614, 0.7009545463876453, 0.9653526473998737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 245}], {
             RGBColor[
             0.6914620496221711, 0.757784783519138, 0.9706409723435206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 264}], {
             RGBColor[
             0.8884076720608038, 0.9131879103930878, 0.9640821149938649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 204}], {
             RGBColor[
             0.8581281320427119, 0.8896845152465827, 0.9687184423261399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 206}], {
             RGBColor[
             0.7105328857709282, 0.7737929577049714, 0.9717829358124617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 254}], {
             RGBColor[
             0.6061556404399435, 0.6892715609677786, 0.9633955819332034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 283}], {
             RGBColor[
             0.8133165242384015, 0.8544572805993086, 0.9819295368016101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 287}], {
             RGBColor[
             0.8610977200551897, 0.8918992291240346, 0.9636917044136113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 158}], {
             RGBColor[
             0.9261834368387147, 0.9392969196670589, 0.7515222311555756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 196}], {
             RGBColor[
             0.9262007577301012, 0.9393339673023238, 0.753407503290845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 207}], {
             RGBColor[
             0.7304035058414017, 0.7890099997243403, 0.9741047022361322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 212}], {
             RGBColor[
             0.6645330106509618, 0.7355333642967494, 0.9689191355631663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 214}], {
             RGBColor[
             0.9152977236394935, 0.9343725628459068, 0.9597123210367158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 225}], {
             RGBColor[
             0.9122236248781688, 0.9320799050230855, 0.9649159683862735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 265}], {
             RGBColor[
             0.7364156149393404, 0.7938909007324751, 0.9745779974874031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 276}], {
             RGBColor[
             0.6784125780833068, 0.7468014224057143, 0.9700117859539713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 166}], {
             RGBColor[
             0.7984711737582714, 0.8430502867840932, 0.9803993894278065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.8257809175548425, 0.8646174949192923, 0.9757635940850208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 234}], {
             RGBColor[
             0.5616035647468589, 0.6529437764264727, 0.9595998074053651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 239}], {
             RGBColor[
             0.7396603459441672, 0.7965475509692022, 0.974686088830939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 263}], {
             RGBColor[
             0.6640126320899755, 0.7371124690354889, 0.9673776748189414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 285}], {
             RGBColor[
             0.6085948812151379, 0.6921218423340691, 0.963014986468164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 122}], {
             RGBColor[
             0.8477796213392572, 0.8807166016579182, 0.9249191288586291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 161}], {
             RGBColor[
             0.7579212264897746, 0.8087916896307685, 0.9171435413091676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 244}], {
             RGBColor[
             0.7062218260062068, 0.7660843410352467, 0.9132767811125131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 266}], {
             RGBColor[
             0.7478185436365573, 0.8005898765698507, 0.9163482211076157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 131}], {
             RGBColor[
             0.5415785696517812, 0.6387169065366676, 0.9570541953521077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 141}], {
             RGBColor[
             0.6789793612172698, 0.7485462468012558, 0.9690460502432341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 170}], {
             RGBColor[
             0.6077068173940807, 0.6924027970974782, 0.9622600532501346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 178}], {
             RGBColor[
             0.6327776684403161, 0.7124531332580291, 0.964441097286594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 182}], {
             RGBColor[
             0.6795587641519099, 0.7489988807774219, 0.9691037997129307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 188}], {
             RGBColor[
             0.51243728316779, 0.6141941718871048, 0.9549989574985323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 190}], {
             RGBColor[
             0.5995937494558199, 0.6858162430556525, 0.9616213628228876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 261}], {
             RGBColor[
             0.5525217256702243, 0.6476010535760003, 0.9579156806799809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 284}], {
             RGBColor[
             0.7778383943756573, 0.8264173885357344, 0.9637908564324622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 294}], {
             RGBColor[
             0.6789793612172698, 0.7485462468012558, 0.9690460502432341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 135}], {
             RGBColor[
             0.6131824527630327, 0.6968481645645557, 0.9626911153242919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 154}], {
             RGBColor[
             0.7882331217723093, 0.834772886280496, 0.9623719904818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 173}], {
             RGBColor[
             0.8056520505016197, 0.846858108504348, 0.8923233265122559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.5950599232423275, 0.6821354786889959, 0.9612644434154088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 234}], {
             RGBColor[
             0.5185514581322679, 0.6189940617816094, 0.9555255662866509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 239}], {
             RGBColor[
             0.6966082393295763, 0.7625978363243388, 0.9706118477122248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 249}], {
             RGBColor[
             0.5818169529110289, 0.671384238785033, 0.9602219082803303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 255}], {
             RGBColor[
             0.7547464447791508, 0.8085642413236015, 0.9762609929875063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 258}], {
             RGBColor[
             0.6525226100987429, 0.7281578077060198, 0.9662178041941238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 263}], {
             RGBColor[
             0.6209605254753846, 0.7031627543906255, 0.9633034337002273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 286}], {
             RGBColor[
             0.8072501933992284, 0.8454126047778857, 0.7127265993413198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 138}], {
             RGBColor[
             0.661657616036794, 0.7351763049051976, 0.9672088632923405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 161}], {
             RGBColor[
             0.6194892750848939, 0.7009421460583336, 0.9638892170248843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 266}], {
             RGBColor[
             0.6093865922316766, 0.6927403329974158, 0.9630938968233325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 189}], {
             RGBColor[
             0.5934863340490772, 0.6806127029733434, 0.9613082538113724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 257}], {
             RGBColor[
             0.7157888053799351, 0.7768271064313892, 0.9733202159033152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 267}], {
             RGBColor[
             0.7000397777513283, 0.7642692592963048, 0.9718180595887758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 287}], {
             RGBColor[
             0.7448990941208434, 0.79938138046208, 0.9533015357307035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 300}], {
             RGBColor[
             0.5958646121090683, 0.6824706318693912, 0.9615452983421202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 147}], {
             RGBColor[
             0.7101558339578364, 0.7677110806455771, 0.8480773767739023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 247}], {
             RGBColor[
             0.9293219114594158, 0.9433318577909486, 0.8673593683430489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 273}], {
             RGBColor[
             0.7175564911279748, 0.7741211579185062, 0.8485489401046393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 289}], {
             RGBColor[
             0.9808181993111463, 0.983572083101057, 0.8437886273130306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 128}], {
             RGBColor[
             0.911240013815985, 0.931283833354148, 0.9644141846200738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 130}], {
             RGBColor[
             0.8600050583744576, 0.8909627274016705, 0.9593861042478538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 142}], {
             RGBColor[
             0.7876862427074207, 0.8339632755184591, 0.9525222475899283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.9151935477738812, 0.934436274016354, 0.9647912762183394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 150}], {
             RGBColor[
             0.8699175625014395, 0.8987064509634902, 0.9603740900216137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 167}], {
             RGBColor[
             0.6768974080692305, 0.7422441113429906, 0.9442912027616517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 237}], {
             RGBColor[
             0.805058420722576, 0.8480379964581073, 0.9539095369122371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 243}], {
             RGBColor[
             0.9618868667426764, 0.9710958681379918, 0.9493997724941879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 256}], {
             RGBColor[
             0.7183981189539198, 0.7777120552609631, 0.9470676326772924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 269}], {
             RGBColor[
             0.8193789862955536, 0.859225331124047, 0.9553368770552575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 277}], {
             RGBColor[
             0.9102593361273047, 0.930501867584981, 0.9643206467066662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 281}], {
             RGBColor[
             0.6942574118127253, 0.7572804740464474, 0.9453973668493386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 293}], {
             RGBColor[
             0.7523198891048377, 0.8052512764278088, 0.9497380786831111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 153}], {
             RGBColor[
             0.8050427110097899, 0.8484237312255803, 0.9809907672903942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 157}], {
             RGBColor[
             0.7280032812397963, 0.7866285983705773, 0.9744138821436208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 192}], {
             RGBColor[
             0.6629874562290348, 0.7325919662200887, 0.9696420425184811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 220}], {
             RGBColor[
             0.8067610764014195, 0.8497661313295821, 0.9811620378935944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 222}], {
             RGBColor[
             0.834197409203177, 0.8711996030381675, 0.9838966351401661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 239}], {
             RGBColor[
             0.8451959638644173, 0.8797917575316399, 0.9849928682814615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 248}], {
             RGBColor[
             0.8460407665169631, 0.8804517237845466, 0.9850770703147377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 285}], {
             RGBColor[
             0.7141304991353881, 0.7753660488965068, 0.9733217659186866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 145}], {
             RGBColor[
             0.676550406484503, 0.7468505490723216, 0.9686659691835289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 148}], {
             RGBColor[
             0.5983611386451582, 0.6833729790539661, 0.9625106236024902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 156}], {
             RGBColor[
             0.6043036786843685, 0.6881974007661751, 0.9629784421226182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 159}], {
             RGBColor[
             0.6717063975284843, 0.7429179643817089, 0.9682846310543216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 168}], {
             RGBColor[
             0.6015623061666838, 0.685971831058894, 0.9627626312360478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 191}], {
             RGBColor[
             0.815754687263754, 0.8565991908653164, 0.9821096048430631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 205}], {
             RGBColor[
             0.8657981323900745, 0.8931648892601067, 0.8528986862186428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 212}], {
             RGBColor[
             0.6032851144914575, 0.6873704844685758, 0.9628982570182287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 225}], {
             RGBColor[
             0.8509757287186643, 0.883917025194912, 0.9588950898413358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 251}], {
             RGBColor[
             0.80613549919169, 0.8489291114025572, 0.9811921180975991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 269}], {
             RGBColor[
             0.7047048038364978, 0.769240015802731, 0.9712020470717599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 276}], {
             RGBColor[
             0.6171646819238024, 0.6986385425775408, 0.9639909074090336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 282}], {
             RGBColor[
             0.6271604718534081, 0.7067535751475993, 0.9647778126080773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 142}], {
             RGBColor[
             0.7330481917243477, 0.7911746117591528, 0.9742927169540989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 149}], {
             RGBColor[
             0.8605554967908081, 0.8916476102570478, 0.98656174558251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 150}], {
             RGBColor[
             0.8152795115183664, 0.855917787204184, 0.9821445593857843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 197}], {
             RGBColor[
             0.7473139119421042, 0.8027561660952995, 0.9754157667066958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 198}], {
             RGBColor[
             0.7794644210157601, 0.8279387662987785, 0.9785748458755343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 237}], {
             RGBColor[
             0.750420369739503, 0.8052493326988011, 0.9756800062764077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 243}], {
             RGBColor[
             0.9072488157596034, 0.9283072043786855, 0.9711702418583585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 256}], {
             RGBColor[
             0.6637600679708467, 0.7349233915016569, 0.9688381020414631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 269}], {
             RGBColor[
             0.7647409353124806, 0.8164366673647407, 0.9771073464194282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 277}], {
             RGBColor[
             0.8556212851442316, 0.8877132038256748, 0.9860911160708368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 281}], {
             RGBColor[
             0.6396193608296522, 0.7144918102871411, 0.9671678362135092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 165}], {
             RGBColor[
             0.7887613411852208, 0.835805274758766, 0.9786017788037676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 175}], {
             RGBColor[
             0.8669700663908864, 0.8969234487496994, 0.9863825881518123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 183}], {
             RGBColor[
             0.7819671609023009, 0.8302894531307579, 0.9780669160439938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 184}], {
             RGBColor[
             0.7197200281837264, 0.7797544265884466, 0.9731665937376273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 224}], {
             RGBColor[
             0.6882731193317342, 0.7538632473466609, 0.9707907680069934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 253}], {
             RGBColor[
             0.7259972757311244, 0.7848505789342035, 0.9736607616588739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 140}], {
             RGBColor[
             0.6060252746764249, 0.6893254243658411, 0.9632983306237726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 162}], {
             RGBColor[
             0.7834019041629388, 0.8307187886978618, 0.979045838566084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 167}], {
             RGBColor[
             0.5710244016446302, 0.6591343416312068, 0.9610335917536024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 201}], {
             RGBColor[
             0.59166248396247, 0.6770100112347415, 0.9623486321093555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 202}], {
             RGBColor[
             0.6540395570888667, 0.7283055818470344, 0.9670781908173918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 203}], {
             RGBColor[
             0.874426464663576, 0.8994848865690597, 0.8214533793028669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 216}], {
             RGBColor[
             0.7791737093073021, 0.8274156907411674, 0.9786244116176015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 237}], {
             RGBColor[
             0.6991854142979756, 0.7649282267463235, 0.9706519259041877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 269}], {
             RGBColor[
             0.7135059798709533, 0.7761155614122631, 0.9720792660472082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 281}], {
             RGBColor[
             0.5883844053881249, 0.6741707043346636, 0.9621397558412892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 293}], {
             RGBColor[
             0.6464468826802374, 0.722141506716025, 0.9664804676750617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 294}], {
             RGBColor[
             0.7543471991882731, 0.8080210323477166, 0.9761499371058645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 299}], {
             RGBColor[
             0.6423925504085173, 0.7188500171322552, 0.9661612957871235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 141}], {
             RGBColor[
             0.6171615548612003, 0.6983597667409582, 0.9641795260807983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 146}], {
             RGBColor[
             0.4336175837589249, 0.5492815066044674, 0.9490490877449561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 170}], {
             RGBColor[
             0.5458890110380112, 0.6422163170371806, 0.9573935290876989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 178}], {
             RGBColor[
             0.5709598620842466, 0.6622666531977315, 0.9595745731241582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 182}], {
             RGBColor[
             0.6177409577958404, 0.6988124007171245, 0.9642372755504949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 188}], {
             RGBColor[
             0.45061947681172054`, 0.5640076918268073, 0.9501324333360965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 190}], {
             RGBColor[
             0.5377759430997504, 0.6356297629953549, 0.9567548386604519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 199}], {
             RGBColor[
             0.6856583794394249, 0.7524484964921494, 0.9708531360107332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 261}], {
             RGBColor[
             0.4907039193141548, 0.5974145735157028, 0.9530491565175452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 284}], {
             RGBColor[
             0.7160205880195878, 0.7762309084754369, 0.9589243322700265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 133}], {
             RGBColor[
             0.502293809022969, 0.6057819822934808, 0.9542494036129041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 146}], {
             RGBColor[
             0.48855609679231093`, 0.593883066436778, 0.9533740487373485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 236}], {
             RGBColor[
             0.5161006963173367, 0.617740814113529, 0.9551291662623501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 260}], {
             RGBColor[
             0.5903336859049644, 0.6782985063039588, 0.9608923766994338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 267}], {
             RGBColor[
             0.7305572411030357, 0.7890447108412779, 0.9742205060929738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 146}], {
             RGBColor[
             0.4012121164527962, 0.5219315025892676, 0.9467858591757958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 170}], {
             RGBColor[
             0.5134835437318825, 0.6148663130219808, 0.9551303005185385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 144}], {
             RGBColor[
             0.682194283875827, 0.7501104865714112, 0.9700345203681409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 160}], {
             RGBColor[
             0.9034568599538592, 0.9246902812616966, 0.9502377679713601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 169}], {
             RGBColor[
             0.8559100452049341, 0.7192374917598316, 0.6048482110470416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 176}], {
             RGBColor[
             0.7447069827761111, 0.800538725990084, 0.9751761658902105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 180}], {
             RGBColor[
             0.6521865774457065, 0.7257488786596702, 0.9676722037961113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 187}], {
             RGBColor[
             0.8376521409620163, 0.8733850960142016, 0.9843772030574928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 193}], {
             RGBColor[
             0.6390867660570323, 0.7150825216511156, 0.9666495979882097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 200}], {
             RGBColor[
             0.7702396039083295, 0.8204850036736808, 0.9777210189487596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 221}], {
             RGBColor[
             0.9043483891113263, 0.9086815834743941, 0.6852547540595664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 228}], {
             RGBColor[
             0.6946784105371244, 0.7602456629985496, 0.9710173165497811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 230}], {
             RGBColor[
             0.5844563392631752, 0.6677643917673651, 0.9631685955006948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 245}], {
             RGBColor[
             0.6979577332977289, 0.7629079649474151, 0.9712754768500509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 264}], {
             RGBColor[
             0.8949033557363617, 0.9183110918213647, 0.9647166195003951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 288}], {
             RGBColor[
             0.6364070145714978, 0.7127614556025716, 0.9664788465931626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 297}], {
             RGBColor[
             0.7675392616056731, 0.818375475743484, 0.9774518740641644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 158}], {
             RGBColor[
             0.7990231261657114, 0.839065947433498, 0.7393261894771854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 173}], {
             RGBColor[
             0.7971744685925352, 0.8399756255998403, 0.8916559402099671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 186}], {
             RGBColor[
             0.6500438785493781, 0.7259616722954766, 0.9661483272332481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 213}], {
             RGBColor[
             0.5865823413332429, 0.6752529957844884, 0.9605970571131199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 214}], {
             RGBColor[
             0.7881374129664901, 0.8341415906123459, 0.9475162793583256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 249}], {
             RGBColor[
             0.5733393710019443, 0.6645017558805253, 0.9595545219780415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 255}], {
             RGBColor[
             0.7462688628700662, 0.8016817584190938, 0.9755936066852176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 263}], {
             RGBColor[
             0.6124829435663001, 0.6962802714861178, 0.9626360473979384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 265}], {
             RGBColor[
             0.6092553042663369, 0.6936599284989142, 0.962381955809013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 276}], {
             RGBColor[
             0.5512522674103033, 0.6465704501721534, 0.9578157442755811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 286}], {
             RGBColor[
             0.7987726114901439, 0.838530121873378, 0.7120592130390309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 177}], {
             RGBColor[
             0.5655702307510853, 0.6581944178290984, 0.9589429067981954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 194}], {
             RGBColor[
             0.6236204038500572, 0.704782473027767, 0.9638818183799645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 197}], {
             RGBColor[
             0.6038384496888267, 0.6892622819263738, 0.9619555211740792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 204}], {
             RGBColor[
             0.7624535939420096, 0.8138290456876006, 0.9599440050197076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 210}], {
             RGBColor[
             0.6064587903301988, 0.69137569011296, 0.9621713091287016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 226}], {
             RGBColor[
             0.6519770657997848, 0.726934912861507, 0.966708145435041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 252}], {
             RGBColor[
             0.7823457194350472, 0.8266538222247479, 0.8304102765419069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 279}], {
             RGBColor[
             0.6254265033100725, 0.7061934116527953, 0.9640618334951798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 280}], {
             RGBColor[
             0.7368763671061384, 0.7939387843211971, 0.974989691922682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 147}], {
             RGBColor[
             0.6607055629737651, 0.731429001762973, 0.9691221450417196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 156}], {
             RGBColor[
             0.6836285150820703, 0.7507743420548162, 0.9707235153649503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 179}], {
             RGBColor[
             0.6906357569408612, 0.7564631366684309, 0.9712751511124469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 191}], {
             RGBColor[
             0.8950795236614558, 0.9191761321539575, 0.9898546780853951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 217}], {
             RGBColor[
             0.7762846990266645, 0.8257665501563125, 0.9781751769551155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 247}], {
             RGBColor[
             0.8798716404753446, 0.9070497789083445, 0.9884041366108662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 251}], {
             RGBColor[
             0.885460335589392, 0.9115060526911983, 0.988937191339931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 270}], {
             RGBColor[
             0.8697929136706999, 0.8990132757340719, 0.9874428186508535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 271}], {
             RGBColor[
             0.717148825890106, 0.7779876404415728, 0.9733623570207031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 273}], {
             RGBColor[
             0.6681062201439036, 0.7378390790359022, 0.9695937083724566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 278}], {
             RGBColor[
             0.888437594872332, 0.9138800384278642, 0.9892211649881686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 289}], {
             RGBColor[
             0.931367928327075, 0.9472900042184529, 0.9648333955808479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 295}], {
             RGBColor[
             0.6705744203240986, 0.7399769099766391, 0.9697509799053949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 210}], {
             RGBColor[
             0.6286170522366261, 0.7093647653469208, 0.9639156886743634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 211}], {
             RGBColor[
             0.44372197078488995`, 0.5511284721416685, 0.9508191846478169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 231}], {
             RGBColor[
             0.5226693196145267, 0.6227696150922759, 0.9557302417447009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 266}], {
             RGBColor[
             0.5616965383340942, 0.6550495798171301, 0.9586379555413269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 143}], {
             RGBColor[
             0.6577579930765437, 0.7296789651089692, 0.968564663375347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 163}], {
             RGBColor[
             0.7669937286196677, 0.8183196370202095, 0.9772992247021073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 235}], {
             RGBColor[
             0.8224581508371408, 0.8616488652017209, 0.9828273999642503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 273}], {
             RGBColor[
             0.6564307819890056, 0.7285294015725126, 0.9684800946584557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 274}], {
             RGBColor[
             0.6504531812337265, 0.7233519042412395, 0.9680992072241141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 298}], {
             RGBColor[
             0.682351938934563, 0.7499069292324212, 0.9704285381604578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 162}], {
             RGBColor[
             0.6352951268895063, 0.7121912553738162, 0.9662156759500522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 167}], {
             RGBColor[
             0.42291762437119773`, 0.5406068083071612, 0.9482034291375705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 181}], {
             RGBColor[
             0.6476568178498734, 0.7219890300534342, 0.9674104289607959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 201}], {
             RGBColor[
             0.44355570668903754`, 0.5584824779106959, 0.9495184694933236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 202}], {
             RGBColor[
             0.5059327798154343, 0.6097780485229889, 0.9542480282013599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 203}], {
             RGBColor[
             0.7263196873901434, 0.780957353245014, 0.808623216686835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 216}], {
             RGBColor[
             0.6310669320338697, 0.7088881574171219, 0.9657942490015697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 237}], {
             RGBColor[
             0.5510786370245433, 0.6464006934222779, 0.9578217632881559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 269}], {
             RGBColor[
             0.5653992025975209, 0.6575880280882176, 0.9592491034311763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 293}], {
             RGBColor[
             0.49834010540680496`, 0.6036139733919794, 0.9536503050590299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 299}], {
             RGBColor[
             0.4942857731350849, 0.6003224838082096, 0.9533311331710916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 146}], {
             RGBColor[
             0.5710183753244135, 0.6591108468690556, 0.9610409426360824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 178}], {
             RGBColor[
             0.7083606536497351, 0.7720959934623197, 0.9715664280152845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 182}], {
             RGBColor[
             0.7551417493613289, 0.8086417409817127, 0.9762291304416213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 188}], {
             RGBColor[
             0.5880202683772091, 0.6738370320913956, 0.9621242882272228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 236}], {
             RGBColor[
             0.5985629748494392, 0.6829685945458066, 0.9627960601610841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 261}], {
             RGBColor[
             0.6281047108796434, 0.7072439137802911, 0.9650410114086714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 294}], {
             RGBColor[
             0.7545623464266888, 0.8081891070055465, 0.9761713809719246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 149}], {
             RGBColor[
             0.7370017256822439, 0.7943270524213588, 0.9746698085523645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[
             0.6917257404098023, 0.758597229368495, 0.9702526223556388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 163}], {
             RGBColor[
             0.6358266907442824, 0.7149284669212785, 0.964681127491299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 197}], {
             RGBColor[
             0.62376014083354, 0.7054356082596107, 0.9635238296765503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 198}], {
             RGBColor[
             0.6559106499071958, 0.7306182084630894, 0.9666829088453888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 243}], {
             RGBColor[
             0.7836950446510391, 0.8309866465429967, 0.9592783048282131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 256}], {
             RGBColor[
             0.5402062968622826, 0.6376028336659678, 0.9569461650113176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 277}], {
             RGBColor[
             0.7320675140356674, 0.7903926459899859, 0.9741991790406913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 163}], {
             RGBColor[
             0.5529232253296573, 0.6473622080078528, 0.9582269137318841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 174}], {
             RGBColor[
             0.5593995642431059, 0.6524215731890376, 0.9588724146699485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 185}], {
             RGBColor[
             0.4703725542290179, 0.5806471644907523, 0.9515208477052235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 235}], {
             RGBColor[
             0.6083876475471304, 0.6906914361893643, 0.9637550889940271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 298}], {
             RGBColor[
             0.4682814356445526, 0.5789495002200646, 0.9513562271902346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 160}], {
             RGBColor[
             0.7596413841894896, 0.8106989906609032, 0.9370055460057598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 176}], {
             RGBColor[
             0.6008915070117415, 0.6865474353892906, 0.9619439439246102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 221}], {
             RGBColor[
             0.7605329133469567, 0.7946902928736007, 0.6720225320939662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 230}], {
             RGBColor[
             0.44064086349880555`, 0.5537731011665717, 0.9499363735350945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 231}], {
             RGBColor[
             0.48487494260064956`, 0.5920864372151289, 0.9527549299408037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 232}], {
             RGBColor[
             0.4701625611522331, 0.5793433118703031, 0.9518174700045587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 240}], {
             RGBColor[
             0.5534193099619975, 0.6483297529397734, 0.9579863418033889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 245}], {
             RGBColor[
             0.5541422575333593, 0.6489166743466217, 0.9580432548844506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 264}], {
             RGBColor[
             0.751087879971992, 0.8043198012205713, 0.9514843975347949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 288}], {
             RGBColor[
             0.4925915388071282, 0.5987701650017783, 0.9532466246275624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 297}], {
             RGBColor[
             0.6237237858413034, 0.7043841851426906, 0.9642196520985642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 156}], {
             RGBColor[
             0.5443243852879253, 0.6409460833676741, 0.9572703560172391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 159}], {
             RGBColor[
             0.611727104132041, 0.6956666469832079, 0.9625765449489424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 167}], {
             RGBColor[
             0.5022439322137313, 0.6050074786231738, 0.9544482866727749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 168}], {
             RGBColor[
             0.5415830127702406, 0.6387205136603931, 0.9570545451306686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 201}], {
             RGBColor[
             0.5228820145315712, 0.6228831482267085, 0.9557633270285281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 203}], {
             RGBColor[
             0.8056459952326771, 0.8453580235610267, 0.8148680742220394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 205}], {
             RGBColor[
             0.8058188389936314, 0.8459135718616058, 0.8471906001132636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 216}], {
             RGBColor[
             0.7103932398764033, 0.7732888277331345, 0.9720391065367742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 237}], {
             RGBColor[
             0.630404944867077, 0.7108013637382905, 0.9640666208233604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 269}], {
             RGBColor[
             0.6447255104400546, 0.7219886984042301, 0.9654939609663808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 277}], {
             RGBColor[
             0.7356058602718056, 0.7932652348651643, 0.9744777306177894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 282}], {
             RGBColor[
             0.5671811784569647, 0.6595022577490983, 0.9590697265026981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 293}], {
             RGBColor[
             0.5776664132493387, 0.6680146437079919, 0.9598951625942342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 170}], {
             RGBColor[
             0.4997458315012244, 0.602967397165278, 0.954254945642983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 236}], {
             RGBColor[
             0.41501900374716383`, 0.5338903344093158, 0.9476656218252419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 247}], {
             RGBColor[
             0.6453978307727597, 0.7192230316232127, 0.9676620798790139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 273}], {
             RGBColor[
             0.43363241044131867`, 0.5500123317507702, 0.9488516516406043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 289}], {
             RGBColor[
             0.6968941186244901, 0.7594632569333211, 0.9440913388489955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 156}], {
             RGBColor[
             0.4661351174485804, 0.5774685133493185, 0.9511150104362005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 159}], {
             RGBColor[
             0.5335378362926961, 0.6321890769648524, 0.9564211993679037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 168}], {
             RGBColor[
             0.4633937449308957, 0.5752429436420375, 0.9508991995496299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 191}], {
             RGBColor[
             0.6775861260279659, 0.74587030344846, 0.9702461731566453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 205}], {
             RGBColor[
             0.7276295711542864, 0.7824360018432502, 0.841035254532225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 217}], {
             RGBColor[
             0.5587913013931746, 0.6524607214508149, 0.9585666720263657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 225}], {
             RGBColor[
             0.7128071674828762, 0.7731881377780554, 0.9470316581549181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 251}], {
             RGBColor[
             0.6679669379559019, 0.7382002239857006, 0.9693286864111812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 270}], {
             RGBColor[
             0.6522995160372098, 0.7257074470285743, 0.9678343137221037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 271}], {
             RGBColor[
             0.499655428256616, 0.604681811736075, 0.9537538520919533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 278}], {
             RGBColor[
             0.6709441972388419, 0.7405742097223666, 0.9696126600594188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.4889919106176199, 0.5960246877307429, 0.9529143809216594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 295}], {
             RGBColor[
             0.4530810226906087, 0.5666710812711414, 0.9501424749766452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 150}], {
             RGBColor[
             0.8192330454762626, 0.85907022786639, 0.9825216509840499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.7512674459000004, 0.8059086067575056, 0.9757928583049613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 198}], {
             RGBColor[
             0.7834179549736563, 0.8310912069609844, 0.9789519374737998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 243}], {
             RGBColor[
             0.9112023497174996, 0.9314596450408916, 0.9715473334566241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 256}], {
             RGBColor[
             0.667713601928743, 0.7380758321638627, 0.9692151936397286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 277}], {
             RGBColor[
             0.8595748191021279, 0.8908656444878809, 0.9864682076691024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 281}], {
             RGBColor[
             0.6435728947875484, 0.7176442509493473, 0.9675449278117748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 179}], {
             RGBColor[
             0.6300246007045966, 0.7085054645511416, 0.9653952826193231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 237}], {
             RGBColor[
             0.7090979184249575, 0.7726719503081433, 0.9716399116779476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 256}], {
             RGBColor[
             0.6224376166563014, 0.702346009110999, 0.9647980074430029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 269}], {
             RGBColor[
             0.7234184839979352, 0.7838592849740829, 0.973067251820968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 274}], {
             RGBColor[
             0.60151746315236, 0.6847039095873397, 0.9633329524449912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 277}], {
             RGBColor[
             0.8142988338296862, 0.8551358214350171, 0.9820510214723767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 281}], {
             RGBColor[
             0.5982969095151067, 0.6819144278964835, 0.9631277416150491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 293}], {
             RGBColor[
             0.6563593868072193, 0.7298852302778447, 0.9674684534488216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 154}], {
             RGBColor[
             0.8872055023110239, 0.9124079439247075, 0.9720198419006179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 181}], {
             RGBColor[
             0.8284999670231503, 0.8660904659112798, 0.9835034471890155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 192}], {
             RGBColor[
             0.6133721122329082, 0.6930331026569992, 0.964908873368044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 220}], {
             RGBColor[
             0.7571457324052928, 0.8102072677664927, 0.9764288687431573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 239}], {
             RGBColor[
             0.7955806198682908, 0.8402328939685504, 0.9802596991310244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 258}], {
             RGBColor[
             0.7514949906374575, 0.8057928653502315, 0.9758656556129235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 208}], {
             RGBColor[
             0.5738538475198549, 0.6623035367073735, 0.960909790448979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 242}], {
             RGBColor[
             0.8504309164156127, 0.8835228438896787, 0.9604317799576605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 244}], {
             RGBColor[
             0.5817237045897439, 0.6691200113507938, 0.9614112507824308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 268}], {
             RGBColor[
             0.6870869388071592, 0.7553940776996129, 0.9695026245477139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 157}], {
             RGBColor[
             0.6142105085077868, 0.6969338397124922, 0.9632841066689609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 192}], {
             RGBColor[
             0.5491946834970253, 0.6428972075620036, 0.9585122670438212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 220}], {
             RGBColor[
             0.6929683036694099, 0.7600713726714969, 0.9700322624189344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 222}], {
             RGBColor[
             0.7204046364711674, 0.7815048443800824, 0.9727668596655062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 239}], {
             RGBColor[
             0.7314031911324078, 0.7900969988735548, 0.9738630928068017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 248}], {
             RGBColor[
             0.7322479937849536, 0.7907569651264615, 0.9739472948400778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 285}], {
             RGBColor[
             0.6003377264033786, 0.6856712902384219, 0.9621919904440266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 181}], {
             RGBColor[
             0.896100673584628, 0.9194976470785008, 0.9728690846254533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[
             0.974763543124898, 0.9784659702700806, 0.8140818723514924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 216}], {
             RGBColor[
             0.8795107877686241, 0.9063967744421884, 0.9712529046662272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 255}], {
             RGBColor[
             0.9213195318793428, 0.9396064801350341, 0.9752744818427439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 258}], {
             RGBColor[
             0.819095697198935, 0.8592000465174525, 0.9652312930493614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 162}], {
             RGBColor[
             0.8157699187920068, 0.3739462065686123, 0.43679972796412114`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 194}], {
             RGBColor[
             0.7707425897912525, 0.3387705149328479, 0.43231182461363915`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 210}], {
             RGBColor[
             0.7593015141113468, 0.3298326596563099, 0.43117148511279724`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 218}], {
             RGBColor[
             0.7563597249846081, 0.32745365097785367`, 0.4309335599361387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 226}], {
             RGBColor[
             0.7896470310910708, 0.35353880815534133`, 0.43419604265035694`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 227}], {
             RGBColor[
             0.7732746090305588, 0.34074854760665296`, 0.4325641926283481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 241}], {
             RGBColor[
             0.6720975209319928, 0.2577485775343202, 0.4246585563836164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 290}], {
             RGBColor[
             0.705955695618921, 0.2865333892631424, 0.4269655701084286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 291}], {
             RGBColor[
             0.76894603390279, 0.3373670318184505, 0.43213276071244655`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.7217636829557258, 0.2993670255248746, 0.4282100327781475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 159}], {
             RGBColor[
             0.5394803763319065, 0.6370134986770613, 0.9568890178880318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 168}], {
             RGBColor[
             0.46933628497010604`, 0.5800673653542465, 0.951367018069758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.4790848993465815, 0.5879817296751422, 0.9521344647038252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 191}], {
             RGBColor[
             0.6835286660671761, 0.7506947251606688, 0.9707139916767733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 205}], {
             RGBColor[
             0.7335721111934967, 0.7872604235554592, 0.8415030730523532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 251}], {
             RGBColor[
             0.6739094779951122, 0.7430246456979096, 0.9697965049313093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 269}], {
             RGBColor[
             0.57247878263992, 0.6633355500980835, 0.9598064339054702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 270}], {
             RGBColor[
             0.6582420560764202, 0.7305318687407831, 0.9683021322422318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 271}], {
             RGBColor[
             0.5055979682958264, 0.609506233448284, 0.9542216706120814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 277}], {
             RGBColor[
             0.663359132471671, 0.7346120865590177, 0.9687902035568788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 282}], {
             RGBColor[
             0.49493445065683017`, 0.6008491094429518, 0.9533821994417875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 171}], {
             RGBColor[
             0.6416062410269631, 0.7183355941717515, 0.9660146572587962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 184}], {
             RGBColor[
             0.5200407892272751, 0.6212315661221024, 0.9553586623816014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 222}], {
             RGBColor[
             0.6433652067011739, 0.7197097115250793, 0.9661899745187328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 248}], {
             RGBColor[
             0.6552085640149601, 0.7289618322714585, 0.9673704096933043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 275}], {
             RGBColor[
             0.7584182024298245, 0.8097468604454587, 0.9380063498261273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 285}], {
             RGBColor[
             0.523298296633385, 0.6238761573834188, 0.9556151052972532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 186}], {
             RGBColor[
             0.8443621338611412, 0.8750619380689266, 0.7434507876884304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 196}], {
             RGBColor[
             0.993358702368861, 0.9882032608422129, 0.5185139220676374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 207}], {
             RGBColor[
             0.7975614504801614, 0.8378792932642294, 0.7392111210129244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 212}], {
             RGBColor[
             0.7316909552897215, 0.7844026578366385, 0.7340255543399588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 214}], {
             RGBColor[
             0.9824556682782533, 0.9832418563857959, 0.724818739813508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 225}], {
             RGBColor[
             0.9793815695169286, 0.9809491985629746, 0.7300223871630658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 265}], {
             RGBColor[
             0.8035735595781001, 0.8427601942723643, 0.7396844162641955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 276}], {
             RGBColor[
             0.7455705227220665, 0.7956707159456035, 0.7351182047307636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 168}], {
             RGBColor[
             0.5367390038142218, 0.6347879289697803, 0.9566732070014613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 191}], {
             RGBColor[
             0.750931384911292, 0.8054152887762027, 0.9760201806084767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 205}], {
             RGBColor[
             0.8009748300376125, 0.841980987170993, 0.8468092619840564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 212}], {
             RGBColor[
             0.5384618121389955, 0.6361865823794621, 0.9568088327836424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 225}], {
             RGBColor[
             0.7861524263662023, 0.8327331231057982, 0.9528056656067494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 251}], {
             RGBColor[
             0.741312196839228, 0.7977452093134434, 0.9751026938630126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 270}], {
             RGBColor[
             0.7256447749205359, 0.785252432356317, 0.973608321173935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 271}], {
             RGBColor[
             0.5730006871399421, 0.6642267970638178, 0.9595278595437847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 282}], {
             RGBColor[
             0.562337169500946, 0.6555696730584857, 0.9586883883734908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 176}], {
             RGBColor[
             0.8221540830897737, 0.861127230079576, 0.9421471915278293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 180}], {
             RGBColor[
             0.729633677759369, 0.7863373827491622, 0.9346432294337301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 193}], {
             RGBColor[
             0.7165338663706948, 0.7756710257406076, 0.9336206236258285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 221}], {
             RGBColor[
             0.9817954894249888, 0.9692700875638861, 0.6522257796971853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 230}], {
             RGBColor[
             0.6619034395768377, 0.7283528958568571, 0.9301396211383136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 232}], {
             RGBColor[
             0.6914251372302653, 0.7539231065605885, 0.9320207176077777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 245}], {
             RGBColor[
             0.7754048336113915, 0.8234964690369071, 0.9382465024876698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 288}], {
             RGBColor[
             0.7138541148851604, 0.7733499596920637, 0.9334498722307815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 296}], {
             RGBColor[
             0.7535234259214101, 0.8057321565279973, 0.936523917920077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 297}], {
             RGBColor[
             0.8449863619193356, 0.878963979832976, 0.9444228997017833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 177}], {
             RGBColor[
             0.5455601517056125, 0.6419493342161953, 0.9573676400764011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 244}], {
             RGBColor[
             0.47793147975184347`, 0.5863098854356621, 0.9522468692787682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 279}], {
             RGBColor[
             0.6054164242645997, 0.6899483280398921, 0.9624865667733855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 280}], {
             RGBColor[
             0.7168662880606655, 0.777693700708294, 0.9734144252008877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 169}], {
             RGBColor[
             0.8492410435728459, 0.7139789130266478, 0.6041964318263527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 181}], {
             RGBColor[
             0.8250334473363873, 0.863382394385455, 0.9831579369031073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 202}], {
             RGBColor[
             0.6833094093019482, 0.7511714128550095, 0.9699955361436713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 216}], {
             RGBColor[
             0.8084435615203835, 0.8502815217491426, 0.9815417569438811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 227}], {
             RGBColor[
             0.7489287917338483, 0.8037881312628979, 0.9756098808887039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 228}], {
             RGBColor[
             0.6880094089050363, 0.7549870842653658, 0.9703655373290923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 299}], {
             RGBColor[
             0.6716624026215987, 0.7417158481402304, 0.9690786411134029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 185}], {
             RGBColor[
             0.5796082897721421, 0.6692878364019925, 0.9602554090319838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 235}], {
             RGBColor[
             0.7176233830902545, 0.7793321081006046, 0.9724896503207874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 274}], {
             RGBColor[
             0.5456184134868403, 0.6410351471401232, 0.9577614575806512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 292}], {
             RGBColor[
             0.6457847688288921, 0.72301288331667, 0.9654650638757614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 298}], {
             RGBColor[
             0.5775171711876768, 0.6675901721313049, 0.9600907885169949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 176}], {
             RGBColor[
             0.565133358879655, 0.657517359849447, 0.9591289315172399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 180}], {
             RGBColor[
             0.4726129535492505, 0.5827275125190332, 0.9516249694231407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 187}], {
             RGBColor[
             0.6580785170655603, 0.7303637298735646, 0.9683299686845221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 221}], {
             RGBColor[
             0.7247747652148702, 0.7656602173337572, 0.6692075196865959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 230}], {
             RGBColor[
             0.4048827153667191, 0.5247430256267283, 0.9471213611277242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 296}], {
             RGBColor[
             0.4965027017112915, 0.6021222862978683, 0.9535056579094876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 297}], {
             RGBColor[
             0.5879656377092171, 0.675354109602847, 0.9614046396911938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 175}], {
             RGBColor[
             0.7192018509254112, 0.780544295718288, 0.9726612827213407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 183}], {
             RGBColor[
             0.6341989454368258, 0.7139103000993463, 0.9643456106135221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 224}], {
             RGBColor[
             0.5405049038662592, 0.6374840943152494, 0.9570694625765217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 253}], {
             RGBColor[
             0.5782290602656492, 0.6684714259027922, 0.9599394562284023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 262}], {
             RGBColor[
             0.5793921847728077, 0.6694157027758654, 0.9600310216502712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 195}], {
             RGBColor[
             0.9164878434118147, 0.9360377049445956, 0.9846559996488182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 234}], {
             RGBColor[
             0.6523104906038311, 0.7243639864517759, 0.9684922129691624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.8303672718011395, 0.8679677609945053, 0.9835784943947364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 285}], {
             RGBColor[
             0.6993018070721102, 0.7635420523593723, 0.9719073920319614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 168}], {
             RGBColor[
             0.42725583189591215`, 0.5441287606097462, 0.9485449487252938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[
             0.40855483365724277`, 0.5282913951760617, 0.9472537306231533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 202}], {
             RGBColor[
             0.47093190678363955`, 0.5795869657883546, 0.9519832893311897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.6913188143583487, 0.7507662705103799, 0.8063584778166647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 216}], {
             RGBColor[
             0.596066059002075, 0.6786970746824876, 0.9635295101313994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 237}], {
             RGBColor[
             0.5160777639927485, 0.6162096106876437, 0.9555570244179856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 269}], {
             RGBColor[
             0.5303983295657262, 0.6273969453535833, 0.9569843645610061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 277}], {
             RGBColor[
             0.6212786793974772, 0.6986734818145175, 0.9659681342124147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 282}], {
             RGBColor[
             0.45285399758263634`, 0.5649105046984515, 0.9505601300973233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 293}], {
             RGBColor[
             0.46333923237501023`, 0.5734228906573451, 0.9513855661888595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 203}], {
             RGBColor[
             0.7306578949148579, 0.7844793055475991, 0.8089647362745583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 205}], {
             RGBColor[
             0.7308307386758122, 0.7850348538481782, 0.8412872621657825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 212}], {
             RGBColor[
             0.46831772077719497`, 0.5792404490566473, 0.9512868329653685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 225}], {
             RGBColor[
             0.716008335004402, 0.7757869897829834, 0.9472836657884756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 269}], {
             RGBColor[
             0.5697374101222353, 0.6611099803908025, 0.9595906230188997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 276}], {
             RGBColor[
             0.4821972882095399, 0.5905085071656122, 0.9523794833561734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 282}], {
             RGBColor[
             0.49219307813914553`, 0.5986235397356707, 0.953166388555217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 293}], {
             RGBColor[
             0.5026783129315194, 0.6071359256945643, 0.9539918246467531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 193}], {
             RGBColor[
             0.6689870516217697, 0.5702182362387427, 0.5882310667015102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 200}], {
             RGBColor[
             0.8001398894730669, 0.6756207182613079, 0.5993024876620601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 202}], {
             RGBColor[
             0.7198786964987738, 0.6115657061758204, 0.5922287840776606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 227}], {
             RGBColor[
             0.785498078930674, 0.6641824245837088, 0.5978431288226933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 228}], {
             RGBColor[
             0.7245786961018619, 0.6153813775861766, 0.5925987852630815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 264}], {
             RGBColor[
             0.9248036413010992, 0.7734468064089918, 0.5862980882136956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 299}], {
             RGBColor[
             0.7082316898184244, 0.6021101414610412, 0.5913118890473923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 178}], {
             RGBColor[
             0.6370881098265462, 0.7159525437585421, 0.964780431022185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 182}], {
             RGBColor[
             0.6838692055381399, 0.7524982912779351, 0.9694431334485218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 190}], {
             RGBColor[
             0.6039041908420499, 0.6893156535561655, 0.9619606965584788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 199}], {
             RGBColor[0.7517866271817244, 0.80613438705296, 0.97605899390876]}
            , StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 261}], {
             RGBColor[
             0.5568321670564543, 0.6511004640765135, 0.958255014415572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 284}], {
             RGBColor[
             0.7821488357618873, 0.8299167990362475, 0.9641301901680533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 184}], {
             RGBColor[
             0.6244759515164449, 0.7044284534363648, 0.9646660981182101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 275}], {
             RGBColor[
             0.8628533647189943, 0.8929437477597211, 0.947313785562736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 285}], {
             RGBColor[
             0.6277334589225548, 0.7070730446976812, 0.964922541033862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 174}], {
             RGBColor[
             0.7734700675331163, 0.8233790022013943, 0.9779447256401717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 238}], {
             RGBColor[
             0.9332746868719244, 0.9458766047847793, 0.8272076198557496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 186}], {
             RGBColor[
             0.842513476287965, 0.8759716162352689, 0.8957805384212121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 213}], {
             RGBColor[
             0.77905193907183, 0.8252629397242808, 0.8902292683010842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 234}], {
             RGBColor[
             0.7025434739617704, 0.762121522816894, 0.8844903911723261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 249}], {
             RGBColor[
             0.7658089687405313, 0.8145116998203177, 0.8891867331660056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 263}], {
             RGBColor[
             0.804952541304887, 0.8462902154259102, 0.8922682585859025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 286}], {
             RGBColor[
             0.9912422092287307, 0.9885400658131704, 0.6416914242269951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 235}], {
             RGBColor[
             0.7240997220037031, 0.7843914732817894, 0.9731351512588517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 238}], {
             RGBColor[
             0.8349162580384866, 0.8686192128648477, 0.8175153711503512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 298}], {
             RGBColor[
             0.5839935101011253, 0.6726495373124897, 0.9607362894550593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 183}], {
             RGBColor[
             0.7124076706424913, 0.7750284740902798, 0.9721264199615668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 224}], {
             RGBColor[
             0.6187136290719246, 0.6986022683061829, 0.9648502719245664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 253}], {
             RGBColor[
             0.6564377854713148, 0.7295895998937256, 0.967720265576447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 180}], {
             RGBColor[
             0.570883800581621, 0.6621858274775496, 0.9595816273525806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 187}], {
             RGBColor[
             0.7563493640979309, 0.809822044832081, 0.976286626613962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 193}], {
             RGBColor[
             0.5577839891929468, 0.651519470468995, 0.958559021544679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 221}], {
             RGBColor[
             0.8230456122472408, 0.8451185322922735, 0.6771641776160358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 230}], {
             RGBColor[
             0.5031535623990897, 0.6042013405852446, 0.955078019057164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 245}], {
             RGBColor[
             0.6166549564336434, 0.6993449137652945, 0.9631849004065203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 288}], {
             RGBColor[
             0.5551042377074124, 0.6491984044204511, 0.9583882701496319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 296}], {
             RGBColor[
             0.5947735487436621, 0.6815806012563848, 0.9614623158389275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 297}], {
             RGBColor[
             0.6862364847415876, 0.7548124245613634, 0.9693612976206337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 194}], {
             RGBColor[
             0.6195395962747856, 0.7014694895998751, 0.9635605622591484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 226}], {
             RGBColor[
             0.647896258224513, 0.7236219294336153, 0.966386889314225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 252}], {
             RGBColor[
             0.7782649118597754, 0.8233408387968562, 0.8300890204210909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 268}], {
             RGBColor[
             0.59922398543946, 0.6855160519694924, 0.9615922536450296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 279}], {
             RGBColor[
             0.6213456957348009, 0.7028804282249035, 0.9637405773743637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 280}], {
             RGBColor[
             0.7327955595308666, 0.7906258008933054, 0.974668435801866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 182}], {
             RGBColor[
             0.7089400565843753, 0.7725486274384861, 0.9716241774849812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 190}], {
             RGBColor[
             0.6289750418882853, 0.7093659897167165, 0.9641417405949381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 199}], {
             RGBColor[
             0.7768574782279598, 0.8261847232135109, 0.9782400379452194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 229}], {
             RGBColor[
             0.5721280747799248, 0.6632150608914653, 0.9596665391068661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 261}], {
             RGBColor[
             0.5819030181026896, 0.6711508002370643, 0.9604360584520313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 284}], {
             RGBColor[
             0.8072196868081227, 0.8499671351967985, 0.9663112342045126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 205}], {
             RGBColor[
             0.7405793530522876, 0.7929492181690739, 0.8420547087998498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 251}], {
             RGBColor[
             0.6809167198539031, 0.7487134403115243, 0.970348140678806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 269}], {
             RGBColor[
             0.5794860244987108, 0.6690243447116984, 0.960358069652967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 274}], {
             RGBColor[
             0.4575850036531357, 0.5698689693249552, 0.95062377027699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 277}], {
             RGBColor[
             0.6703663743304619, 0.7403008811726324, 0.9693418393043756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 282}], {
             RGBColor[
             0.501941692515621, 0.6065379040565666, 0.9539338351892842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 289}], {
             RGBColor[
             0.7268243125915863, 0.784497391838779, 0.9462443449197229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 187}], {
             RGBColor[
             0.6638289587675263, 0.7350321975016672, 0.968782664519863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 193}], {
             RGBColor[
             0.4652635838625422, 0.5767296231385812, 0.9510550594505798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 215}], {
             RGBColor[
             0.7120022582864177, 0.7731878989750348, 0.9644886235907566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 221}], {
             RGBColor[
             0.7305252069168362, 0.7703286849618597, 0.6696602155219366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 230}], {
             RGBColor[
             0.41063315706868514`, 0.5294114932548307, 0.9475740569630648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 233}], {
             RGBColor[
             0.4710656258914946, 0.5814713222201504, 0.9515031581218742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 245}], {
             RGBColor[
             0.5241345511032389, 0.6245550664348807, 0.9556809383124211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 288}], {
             RGBColor[
             0.4625838323770078, 0.5744085570900372, 0.9508843080555327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 296}], {
             RGBColor[
             0.5022531434132576, 0.6067907539259709, 0.9539583537448284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 297}], {
             RGBColor[
             0.5937160794111831, 0.6800225772309496, 0.9618573355265345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 201}], {
             RGBColor[
             0.6332940271359185, 0.7096736169223348, 0.9664607304463788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 202}], {
             RGBColor[
             0.6956711002623153, 0.7609691875346276, 0.9711902891544151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 203}], {
             RGBColor[
             0.9160580078370244, 0.9321484922566529, 0.8255654776398902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 216}], {
             RGBColor[
             0.8208052524807506, 0.8600792964287607, 0.9827365099546248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 227}], {
             RGBColor[
             0.7612904826942154, 0.8135859059425159, 0.9768046338994478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 258}], {
             RGBColor[
             0.7603901619110616, 0.8128825685040247, 0.9767148983377592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 299}], {
             RGBColor[
             0.6840240935819659, 0.7515136228198485, 0.9702733941241468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 190}], {
             RGBColor[
             0.6757561375998791, 0.7459117372361095, 0.9688044430212748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 199}], {
             RGBColor[
             0.8236385739395535, 0.8627304707329039, 0.9829027403715562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 229}], {
             RGBColor[
             0.6189091704915185, 0.6997608084108582, 0.9643292415332028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 261}], {
             RGBColor[
             0.6286841138142835, 0.7076965477564572, 0.9650987608783681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 284}], {
             RGBColor[
             0.8540007825197165, 0.8865128827161914, 0.9709739366308494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 224}], {
             RGBColor[
             0.5337107235833392, 0.6319682726872413, 0.9565345998167478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 253}], {
             RGBColor[
             0.5714348799827293, 0.662955604274784, 0.9594045934686284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 222}], {
             RGBColor[
             0.6262349171906557, 0.7058025707896927, 0.9648414153781467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 224}], {
             RGBColor[
             0.47146359086476475`, 0.5814332461449301, 0.9516342775103814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 248}], {
             RGBColor[
             0.638078274504442, 0.7150546915360718, 0.9660218505527183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 275}], {
             RGBColor[
             0.7412879129193064, 0.795839719710072, 0.9366577906855412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 218}], {
             RGBColor[
             0.5657493968126635, 0.6583398729092265, 0.9589570114068697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 235}], {
             RGBColor[
             0.635072711989615, 0.7126170645835039, 0.9657835842941268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 262}], {
             RGBColor[
             0.5074244312486862, 0.6109890383546339, 0.9543654564662849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 292}], {
             RGBColor[
             0.5632340977282527, 0.6562978397995693, 0.9587589978491007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 196}], {
             RGBColor[
             0.8443794547525277, 0.8750989857041915, 0.7453360598237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 214}], {
             RGBColor[
             0.83347642066192, 0.8701375812477745, 0.9516408775695706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 249}], {
             RGBColor[
             0.6186783786973742, 0.7004977465159539, 0.9636791201892865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 265}], {
             RGBColor[
             0.6545943119617668, 0.7296559191343428, 0.966506554020258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 286}], {
             RGBColor[
             0.8441116191855738, 0.8745261125088066, 0.716183811250276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 193}], {
             RGBColor[
             0.650729147378852, 0.7243658404931125, 0.9677600587119612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 215}], {
             RGBColor[
             0.8974678218027276, 0.9208241163295661, 0.9811936228521381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 228}], {
             RGBColor[
             0.7063207918589443, 0.7695289818405464, 0.9721277772735327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 229}], {
             RGBColor[
             0.6656958554854521, 0.736547828360018, 0.9689296334681661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 230}], {
             RGBColor[
             0.596098720584995, 0.677047710609362, 0.9642790562244463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 233}], {
             RGBColor[
             0.6565311894078044, 0.7291075395746818, 0.9682081573832557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 245}], {
             RGBColor[
             0.7096001146195487, 0.772191283789412, 0.9723859375738025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 288}], {
             RGBColor[
             0.6480493958933176, 0.7220447744445685, 0.9675893073169142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 296}], {
             RGBColor[
             0.6877187069295674, 0.7544269712805022, 0.9706633530062099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 297}], {
             RGBColor[
             0.7791816429274929, 0.827658794585481, 0.978562334787916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 236}], {
             RGBColor[
             0.4320208967999595, 0.5486165196316557, 0.9487489674163823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 260}], {
             RGBColor[
             0.5062538863875871, 0.6091742118220855, 0.954512177853466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 261}], {
             RGBColor[
             0.46156263283016363`, 0.57289183886614, 0.9509939186639698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 281}], {
             RGBColor[
             0.4220574745770609, 0.5399867040783426, 0.9481141069626475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 294}], {
             RGBColor[
             0.5880202683772091, 0.6738370320913956, 0.9621242882272228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 257}], {
             RGBColor[
             0.7806722767699432, 0.8292571663536874, 0.9785957695486271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 260}], {
             RGBColor[
             0.6246996939432651, 0.7059531146812841, 0.9637654838405476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 267}], {
             RGBColor[
             0.7649232491413365, 0.8166993192186031, 0.9770936132340877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 287}], {
             RGBColor[
             0.8097825655108515, 0.8518114403843782, 0.9585770893760154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 300}], {
             RGBColor[
             0.6607480834990763, 0.7349006917916894, 0.9668208519874322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 199}], {
             RGBColor[
             0.7436735592434636, 0.7995478330111343, 0.9754203034815131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 261}], {
             RGBColor[
             0.5487190991181935, 0.6445139100346877, 0.9576163239883251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 284}], {
             RGBColor[
             0.7740357678236265, 0.8233302449944219, 0.9634914997408064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 205}], {
             RGBColor[
             0.9450231197728822, 0.9556622136546006, 0.860634235772798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 217}], {
             RGBColor[
             0.7761848500117703, 0.8256869332621652, 0.9781656532669385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 225}], {
             RGBColor[
             0.930200716101472, 0.9464143495894057, 0.9666306393954909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 246}], {
             RGBColor[
             0.7266756126594998, 0.7857233601521103, 0.9741106773649942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 251}], {
             RGBColor[
             0.8853604865744977, 0.911426435797051, 0.9889276676517542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 270}], {
             RGBColor[
             0.8696930646558056, 0.8989336588399246, 0.9874332949626766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 271}], {
             RGBColor[
             0.7170489768752117, 0.7779080235474254, 0.9733528333325263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 278}], {
             RGBColor[
             0.8883377458574377, 0.913800421533717, 0.9892116412999917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 282}], {
             RGBColor[
             0.7063854592362157, 0.7692508995420932, 0.9725133621622324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 295}], {
             RGBColor[
             0.6704745713092044, 0.7398972930824917, 0.969741456217218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 218}], {
             RGBColor[
             0.5207903018350472, 0.6205861977450365, 0.9557641110401621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 220}], {
             RGBColor[
             0.5509130488886548, 0.6442396076660053, 0.9586835376470213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 222}], {
             RGBColor[
             0.5783493816904123, 0.6656730793745907, 0.9614181348935931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 248}], {
             RGBColor[
             0.5901927390041986, 0.6749252001209699, 0.9625985700681646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 262}], {
             RGBColor[
             0.4624653362710699, 0.5732353631904441, 0.9511725560995772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 200}], {
             RGBColor[
             0.5833166103251651, 0.6714657481525919, 0.9611038746032281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 215}], {
             RGBColor[
             0.6989024468977434, 0.7625215419664801, 0.963466017782855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 228}], {
             RGBColor[
             0.5077554169539601, 0.6112264074774605, 0.9544001722042497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 230}], {
             RGBColor[
             0.3975333456800108, 0.518745136246276, 0.9465514511551633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 245}], {
             RGBColor[
             0.5110347397145646, 0.6138887094263261, 0.9546583325045195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 264}], {
             RGBColor[
             0.7079803621531973, 0.7692918363002756, 0.9480994751548637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 288}], {
             RGBColor[
             0.44948402098833345`, 0.5637422000814826, 0.9498617022476311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 210}], {
             RGBColor[
             0.660428155853899, 0.7346507618837368, 0.9667889645896548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 226}], {
             RGBColor[
             0.7059464313234849, 0.7702099846322839, 0.9713258008959942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 241}], {
             RGBColor[
             0.529622166084868, 0.6265246387007521, 0.9570195714958833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 280}], {
             RGBColor[
             0.7908457326298386, 0.837213856091974, 0.9796073473836351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 290}], {
             RGBColor[
             0.5804094281152603, 0.6697018562939856, 0.9604800920831017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 291}], {
             RGBColor[
             0.6748949355410637, 0.7459523201269477, 0.9682308779891287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 234}], {
             RGBColor[
             0.6796202344004022, 0.7459311945869751, 0.9638564176263769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 207}], {
             RGBColor[
             0.7975787713715479, 0.8379163408994943, 0.741096393148194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 212}], {
             RGBColor[
             0.731708276181108, 0.7844397054719034, 0.7359108264752281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 214}], {
             RGBColor[
             0.9824729891696398, 0.9832789040210609, 0.7267040119487775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 225}], {
             RGBColor[
             0.9793988904083151, 0.9809862461982396, 0.7319076592983352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 265}], {
             RGBColor[
             0.8035908804694866, 0.8427972419076293, 0.7415696883994649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 276}], {
             RGBColor[
             0.745587843613453, 0.7957077635808685, 0.7370034768660331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 198}], {
             RGBColor[
             0.6701763701249523, 0.7421997627992363, 0.9678059585979857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 204}], {
             RGBColor[
             0.7966410053044792, 0.8415839263569842, 0.9626353632747754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 226}], {
             RGBColor[
             0.6861644771622544, 0.7546897935308907, 0.9693995036901089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 243}], {
             RGBColor[
             0.7979607648687956, 0.8425682008791434, 0.9604013545808099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 254}], {
             RGBColor[
             0.544668513701711, 0.6411709720781802, 0.9573125028818389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 283}], {
             RGBColor[
             0.7518293975001689, 0.8063566917097101, 0.9758464577502455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 204}], {
             RGBColor[
             0.8287915143781353, 0.8667665265604632, 0.965794442443614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 226}], {
             RGBColor[
             0.7183149862359104, 0.7798723937343696, 0.9725585828589475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 243}], {
             RGBColor[
             0.8301112739424515, 0.8677508010826223, 0.9635604337496484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 254}], {
             RGBColor[
             0.5768190227753669, 0.6663535722816591, 0.9604715820506775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 256}], {
             RGBColor[
             0.5866225261536949, 0.6743669882055935, 0.961228293932753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 283}], {
             RGBColor[
             0.7839799065738249, 0.831539291913189, 0.9790055369190841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 209}], {
             RGBColor[
             0.9106579879919412, 0.9315979767449374, 0.9913405659202961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 229}], {
             RGBColor[
             0.686826592135103, 0.7533969041858831, 0.9709451019934411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 233}], {
             RGBColor[
             0.6776619260574553, 0.7459566154005469, 0.9702236259085306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 259}], {
             RGBColor[
             0.7310231876127278, 0.7892776914285555, 0.9744244198869034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 261}], {
             RGBColor[
             0.696601535457868, 0.7613326435314822, 0.9717146213386063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 284}], {
             RGBColor[
             0.921918204163301, 0.9401489784912163, 0.9775897970910876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 210}], {
             RGBColor[
             0.6788679952552514, 0.7490561045720434, 0.968626875451085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 211}], {
             RGBColor[
             0.4939729138035154, 0.5908198113667911, 0.9555303714245384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 227}], {
             RGBColor[
             0.6998276376340694, 0.765429936497558, 0.9707159367244114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 228}], {
             RGBColor[
             0.6389082548052574, 0.7166288895000258, 0.9654715931647996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 231}], {
             RGBColor[
             0.5729202626331521, 0.6624609543173985, 0.9604414285214224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 245}], {
             RGBColor[
             0.6421875775658619, 0.7192911914488913, 0.9657297534650694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 264}], {
             RGBColor[
             0.8391332000044945, 0.874694318322841, 0.9591708961154136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 202}], {
             RGBColor[
             0.4915699891014794, 0.5974626353918893, 0.9532983296869428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 203}], {
             RGBColor[
             0.7119568966761887, 0.7686419401139146, 0.8076735181724178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 216}], {
             RGBColor[
             0.6167041413199148, 0.6965727442860223, 0.9648445504871526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 237}], {
             RGBColor[
             0.5367158463105883, 0.6340852802911784, 0.9568720647737388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 269}], {
             RGBColor[
             0.551036411883566, 0.645272614957118, 0.9582994049167592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 277}], {
             RGBColor[
             0.641916761715317, 0.7165491514180522, 0.9672831745681678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 293}], {
             RGBColor[
             0.4839773146928501, 0.5912985602608798, 0.9527006065446126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 299}], {
             RGBColor[
             0.47992298242112996`, 0.5880070706771101, 0.9523814346566745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 203}], {
             RGBColor[
             0.7743339698025853, 0.8199375107262075, 0.8124030768804542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 216}], {
             RGBColor[
             0.6790812144463115, 0.7478683148983152, 0.9695741091951888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 237}], {
             RGBColor[
             0.5990929194369852, 0.6853808509034713, 0.961601623481775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 269}], {
             RGBColor[
             0.6134134850099627, 0.6965681855694109, 0.9630289636247955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 293}], {
             RGBColor[
             0.5463543878192468, 0.6425941308731727, 0.957430165252649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 299}], {
             RGBColor[
             0.5423000555475268, 0.639302641289403, 0.9571109933647108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 216}], {
             RGBColor[
             0.8994681220210208, 0.9190476196203405, 0.8239492976806639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 237}], {
             RGBColor[
             0.8194798270116943, 0.8565601556254965, 0.8159768119672501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 255}], {
             RGBColor[
             0.9412768661317394, 0.9522573253131863, 0.8279708748571806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 269}], {
             RGBColor[
             0.833800392584672, 0.8677474902914362, 0.8174041521102706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 293}], {
             RGBColor[
             0.7667412953939561, 0.813773435595198, 0.811805353738124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 299}], {
             RGBColor[
             0.7626869631222359, 0.8104819460114283, 0.8114861818501858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 226}], {
             RGBColor[
             0.8447796214154373, 0.8792565572921176, 0.9673879875357372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 243}], {
             RGBColor[
             0.9565759091219785, 0.9671349646403702, 0.9583898384264382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 254}], {
             RGBColor[
             0.7032836579548938, 0.7657377358394071, 0.9553009867274672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 283}], {
             RGBColor[
             0.9104445417533518, 0.9309234554709369, 0.9738349415958738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 225}], {
             RGBColor[
             0.9802441612277927, 0.9829800479841961, 0.8374197207710707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 251}], {
             RGBColor[
             0.9354039317008184, 0.9479921341918414, 0.8597167490273339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 269}], {
             RGBColor[
             0.833973236345626, 0.8683030385920152, 0.8497266780014948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 282}], {
             RGBColor[
             0.7564289043625363, 0.8058165979368834, 0.843302443537812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 219}], {
             RGBColor[
             0.6169562947293747, 0.6996406960800443, 0.9631736565835589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 254}], {
             RGBColor[
             0.5556884116831101, 0.6498461782977958, 0.9583654802137891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 283}], {
             RGBColor[
             0.7628492954815681, 0.8150318979293256, 0.9768994350821957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 212}], {
             RGBColor[
             0.5359110242924084, 0.63411573789392, 0.9566080254205153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 214}], {
             RGBColor[
             0.7866757372809401, 0.8329549364430773, 0.9474012108940646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 225}], {
             RGBColor[
             0.7836016385196154, 0.830662278620256, 0.9526048582436224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 242}], {
             RGBColor[
             0.6870694340242556, 0.7511888947356047, 0.9468991779238916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 244}], {
             RGBColor[
             0.4183622221983867, 0.5367860621967198, 0.9478786487486619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 252}], {
             RGBColor[
             0.7027663828361175, 0.7608849153729027, 0.8244667892900062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 268}], {
             RGBColor[
             0.523725456415802, 0.6230601285455388, 0.9559700225139449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 279}], {
             RGBColor[
             0.545847166711143, 0.6404245048009499, 0.958118346243279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 259}], {
             RGBColor[
             0.750125180021531, 0.8045091016655641, 0.9762463849754051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 211}], {
             RGBColor[
             0.4583714608823045, 0.5630076857636774, 0.9519819513118453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 226}], {
             RGBColor[
             0.6887848178036264, 0.7568032017174768, 0.9696152916447314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 227}], {
             RGBColor[
             0.6642261847128585, 0.7376178108944443, 0.9671675166117182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 241}], {
             RGBColor[
             0.5124605525650096, 0.6131178557859451, 0.9553090622446205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 290}], {
             RGBColor[
             0.5632478145954019, 0.6562950733791786, 0.9587695828318388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 291}], {
             RGBColor[
             0.6577333220212053, 0.7325455372121408, 0.9665203687378658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 231}], {
             RGBColor[
             0.35242372826020507`, 0.4764125355090326, 0.9437965043821828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 264}], {
             RGBColor[
             0.6186366656315476, 0.6886458995144751, 0.9425259719761739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 266}], {
             RGBColor[
             0.39145094697977256`, 0.5086925002338868, 0.9467042181788088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 214}], {
             RGBColor[
             0.7208052420905002, 0.7794783010154864, 0.9422156442210988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 225}], {
             RGBColor[
             0.7177311433291755, 0.7771856431926651, 0.9474192915706565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 265}], {
             RGBColor[
             0.5419231333903471, 0.6389966389020548, 0.9570813206717863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 276}], {
             RGBColor[
             0.4839200965343135, 0.591907160575294, 0.9525151091383544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 234}], {
             RGBColor[
             0.4919513467024782, 0.5973988930015421, 0.953431508075479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 249}], {
             RGBColor[
             0.5552168414812391, 0.6497890700049658, 0.9581278500691586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 263}], {
             RGBColor[
             0.5943604140455949, 0.6815675856105583, 0.9612093754890554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 286}], {
             RGBColor[
             0.7806500819694386, 0.8238174359978185, 0.710632541130148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 265}], {
             RGBColor[
             0.7926878463788788, 0.8378358374512123, 0.9478745061453355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 276}], {
             RGBColor[
             0.7346848095228452, 0.7907463591244515, 0.9433082946119038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 286}], {
             RGBColor[
             0.9822051536026857, 0.9827060308256761, 0.6975517633753535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 229}], {
             RGBColor[
             0.7138691550043434, 0.7747035298333856, 0.9646355925390597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 233}], {
             RGBColor[
             0.7047044889266958, 0.7672632410480494, 0.9639141164541494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 259}], {
             RGBColor[
             0.7580657504819681, 0.810584317076058, 0.9681149104325222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 296}], {
             RGBColor[
             0.7358920064484588, 0.7925826727538698, 0.9663693120771035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 237}], {
             RGBColor[
             0.7242270716554204, 0.7844909597976043, 0.9731478442819849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 269}], {
             RGBColor[
             0.7385476372283981, 0.7956782944635439, 0.9745751844250052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 293}], {
             RGBColor[
             0.6714885400376822, 0.7417042397673057, 0.9689763860528589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 299}], {
             RGBColor[
             0.6674342077659621, 0.738412750183536, 0.9686572141649206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 223}], {
             RGBColor[
             0.825904128673691, 0.8613734193947782, 0.8001616663366962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 246}], {
             RGBColor[
             0.6078807880247086, 0.6923137781544653, 0.9624311762347146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 247}], {
             RGBColor[
             0.7609769668256591, 0.8135605800165522, 0.9767151117924097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 251}], {
             RGBColor[
             0.7665656619397065, 0.8180168537994059, 0.9772481665214745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 270}], {
             RGBColor[
             0.7508982400210144, 0.8055240768422794, 0.975753793832397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 271}], {
             RGBColor[
             0.5982541522404206, 0.6844984415497803, 0.9616733322022466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 278}], {
             RGBColor[
             0.7695429212226464, 0.820390839536072, 0.9775321401697121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 295}], {
             RGBColor[
             0.5516797466744132, 0.6464877110848466, 0.9580619550869384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 220}], {
             RGBColor[
             0.6645639220074319, 0.73776036285453, 0.9672841064152753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 262}], {
             RGBColor[
             0.576116209389847, 0.6667561183789685, 0.9597731248678314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 290}], {
             RGBColor[
             0.5588351309052937, 0.6527265603614942, 0.958412695066851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 292}], {
             RGBColor[
             0.6319258758694135, 0.712064919823904, 0.9641666662506472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 250}], {
             RGBColor[
             0.5275490310594638, 0.6273270950839132, 0.9559497386822273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 222}], {
             RGBColor[
             0.722123001862797, 0.7828472444840842, 0.9729381302687063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 248}], {
             RGBColor[
             0.7339663591765833, 0.7920993652304633, 0.9741185654432778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 262}], {
             RGBColor[
             0.6062389564434546, 0.6904095282999374, 0.9626925514746905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 230}], {
             RGBColor[
             0.6627949687343049, 0.7123441980695546, 0.66515660722652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 232}], {
             RGBColor[
             0.6923166663877325, 0.7379144087732861, 0.6670377036959843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 245}], {
             RGBColor[
             0.7762963627688586, 0.8074877712496046, 0.6732634885758761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 288}], {
             RGBColor[
             0.7147456440426275, 0.757341261904761, 0.6684668583189879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 296}], {
             RGBColor[
             0.7544149550788772, 0.7897234587406947, 0.6715409040082834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 297}], {
             RGBColor[
             0.8458778910768028, 0.8629552820456735, 0.6794398857899897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 248}], {
             RGBColor[
             0.7614026919783408, 0.8135328369390487, 0.9768531626898497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 285}], {
             RGBColor[
             0.6294924245967657, 0.7084471620510089, 0.9650978582937986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 246}], {
             RGBColor[
             0.7763948913214205, 0.8214098462847232, 0.7961066904347519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 247}], {
             RGBColor[
             0.9294910701223711, 0.9426566481468102, 0.8103906259924469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 270}], {
             RGBColor[
             0.9194123433177264, 0.9346201449725375, 0.8094293080324343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 271}], {
             RGBColor[
             0.7667682555371325, 0.8135945096800383, 0.795348846402284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 278}], {
             RGBColor[
             0.9380570245193585, 0.9494869076663299, 0.8112076543697494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 295}], {
             RGBColor[
             0.7201938499711251, 0.7755837792151047, 0.7917374692869756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 253}], {
             RGBColor[
             0.47774083841216264`, 0.586529398490687, 0.952128445431628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 262}], {
             RGBColor[
             0.47890396291932114`, 0.5874736753637602, 0.9522200108534971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 265}], {
             RGBColor[
             0.789613747617554, 0.835543179628391, 0.9530781534948933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 276}], {
             RGBColor[
             0.7316107107615204, 0.7884537013016302, 0.9485119419614615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 241}], {
             RGBColor[
             0.5579788280345954, 0.6486770785344923, 0.9598458985509599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 243}], {
             RGBColor[
             0.8460993809797537, 0.8802408318142767, 0.9651539788417718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 290}], {
             RGBColor[
             0.6087660900649877, 0.6918542961277256, 0.9633064191381783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 291}], {
             RGBColor[
             0.7032515974907911, 0.7681047599606878, 0.9710572050442052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 241}], {
             RGBColor[
             0.5334201949438275, 0.6294916877114598, 0.9573981235179467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 290}], {
             RGBColor[
             0.5842074569742197, 0.6726689053046931, 0.9608586441051652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 291}], {
             RGBColor[
             0.6786929644000232, 0.7489193691376552, 0.9686094300111922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 299}], {
             RGBColor[
             0.6079194379794268, 0.6919193596972913, 0.9627253381097435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 264}], {
             RGBColor[
             0.7635720066332895, 0.8144549776477097, 0.9524671937164351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 233}], {
             RGBColor[
             0.4729325226094203, 0.5829869530785012, 0.9516501270701774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 259}], {
             RGBColor[
             0.5262937841646927, 0.6263080291065097, 0.9558509210485501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 284}], {
             RGBColor[
             0.7171888007152659, 0.7771793161691707, 0.9590162982527344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 245}], {
             RGBColor[
             0.45640431292070754`, 0.5665705795425756, 0.9511773300170046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 288}], {
             RGBColor[
             0.3948535941944764, 0.5164240701977321, 0.9463806997601162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 296}], {
             RGBColor[
             0.4345229052307262, 0.5488062670336658, 0.9494547454494118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 297}], {
             RGBColor[
             0.5259858412286517, 0.6220380903386445, 0.957353727231118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 232}], {
             RGBColor[
             0.4166586956414253, 0.5353105531148142, 0.9477701015428217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 245}], {
             RGBColor[
             0.5006383920225516, 0.6048839155911327, 0.9539958864227136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 264}], {
             RGBColor[
             0.6975840144611842, 0.7602870424650825, 0.9474370290730578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 266}], {
             RGBColor[
             0.4703982958094093, 0.5803336431844942, 0.9516152752756928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 240}], {
             RGBColor[
             0.4852030630027734, 0.5915538688394586, 0.9530015134054068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 245}], {
             RGBColor[
             0.4859260105741351, 0.592140790246307, 0.9530584264864687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 288}], {
             RGBColor[
             0.424375291847904, 0.5419942809014635, 0.9482617962295803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 297}], {
             RGBColor[
             0.5555075388820793, 0.6476083010423759, 0.9592348237005821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 259}], {
             RGBColor[
             0.517129118087045, 0.6188677403211735, 0.9551294449636396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[
             0.5934996627897269, 0.6778612506368848, 0.962778912372295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 249}], {
             RGBColor[
             0.4787083763711795, 0.586647653097579, 0.9523889729404005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 263}], {
             RGBColor[
             0.5178519489355353, 0.6184261687031716, 0.9554704983602975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 274}], {
             RGBColor[
             0.6010828357043132, 0.6843643753216347, 0.9632896328427942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 298}], {
             RGBColor[
             0.6329815934051497, 0.7109194003128163, 0.9656189637791379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 260}], {
             RGBColor[
             0.5167965928598173, 0.6183057742764966, 0.9551839497873272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 267}], {
             RGBColor[
             0.6570201480578886, 0.7290519788138157, 0.9685120791808672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 294}], {
             RGBColor[
             0.5985629748494392, 0.6829685945458066, 0.9627960601610841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 256}], {
             RGBColor[
             0.5575784748774378, 0.6516775546056162, 0.9583334543336264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 269}], {
             RGBColor[
             0.6585593422190716, 0.7331908304687, 0.9666026987115914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 277}], {
             RGBColor[
             0.7494396920508227, 0.804467366929634, 0.9755864683630001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 281}], {
             RGBColor[
             0.5334377677362433, 0.6312459733911004, 0.9566631885056726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 293}], {
             RGBColor[
             0.5915002450283557, 0.6792167757724619, 0.961003900339445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 248}], {
             RGBColor[
             0.7724012466395811, 0.822124991432521, 0.9779493958311452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 258}], {
             RGBColor[
             0.7274708147562019, 0.7870249965612954, 0.973471150279768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 263}], {
             RGBColor[
             0.6959087301328436, 0.762029943245901, 0.9705567797858714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 285}], {
             RGBColor[
             0.640490979258006, 0.7170393165444813, 0.9661940914350939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 290}], {
             RGBColor[
             0.4324418248263708, 0.5481689501961939, 0.9490001897380674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 291}], {
             RGBColor[
             0.5269273322521743, 0.6244194140291561, 0.9567509756440944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 250}], {
             RGBColor[
             0.7224488162971432, 0.7810742874803182, 0.9493630828614787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 268}], {
             RGBColor[
             0.8003025253115599, 0.8442794357278441, 0.9554920120226266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 254}], {
             RGBColor[
             0.7046034175192102, 0.7667220103615662, 0.9530669780335017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 256}], {
             RGBColor[
             0.7144069208975382, 0.7747354262855006, 0.9538236899155772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 283}], {
             RGBColor[
             0.9117643013176682, 0.9319077299930961, 0.9716009329019084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 279}], {
             RGBColor[
             0.5537170237810319, 0.6472409794443703, 0.958619806576731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 280}], {
             RGBColor[
             0.6651668875770977, 0.7349863521127722, 0.9695476650042332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 264}], {
             RGBColor[
             0.766851329393894, 0.8171172795965752, 0.9527253540167049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 288}], {
             RGBColor[
             0.5083549882290301, 0.6115676433777821, 0.9544875811094724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 297}], {
             RGBColor[
             0.6394872352632055, 0.7171816635186945, 0.9654606085804742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 270}], {
             RGBColor[
             0.7013890026687437, 0.7655605037322246, 0.9716988179304527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 278}], {
             RGBColor[
             0.7200336838703758, 0.780427266426017, 0.9734771642677678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 295}], {
             RGBColor[
             0.5021705093221427, 0.6065241379747919, 0.9540069791849941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 251}], {
             RGBColor[
             0.8701526033883864, 0.8993000825514379, 0.9874771261772253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 270}], {
             RGBColor[
             0.8544851814696943, 0.8868073055943115, 0.9859827534881478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 271}], {
             RGBColor[
             0.7018410936891005, 0.7657816703018123, 0.9719022918579974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 278}], {
             RGBColor[
             0.8731298626713264, 0.9016740682881039, 0.9877610998254629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 289}], {
             RGBColor[
             0.9160601961260696, 0.9350840340786926, 0.9633733304181422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 295}], {
             RGBColor[
             0.6552666881230932, 0.7277709398368787, 0.9682909147426891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 285}], {
             RGBColor[
             0.6413357819105518, 0.717699282797388, 0.96627829346837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 258}], {
             RGBColor[
             0.6126795283376545, 0.6958113990219896, 0.9630812108478736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 263}], {
             RGBColor[
             0.5811174437142962, 0.6708163457065952, 0.9601668403539769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 286}], {
             RGBColor[
             0.76740711163814, 0.8130661960938554, 0.7095900059950695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 270}], {
             RGBColor[
             0.8600738765837417, 0.8912635793771653, 0.9865158082172125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 271}], {
             RGBColor[
             0.707429788803148, 0.7702379440846662, 0.9724353465870622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 278}], {
             RGBColor[
             0.8787185577853738, 0.9061303420709577, 0.9882941545545276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 282}], {
             RGBColor[
             0.6967662711641518, 0.7615808200793339, 0.9715958754167683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 289}], {
             RGBColor[
             0.9216488912401171, 0.9395403078615463, 0.963906385147207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 295}], {
             RGBColor[
             0.6608553832371407, 0.7322272136197325, 0.968823969471754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 268}], {
             RGBColor[
             0.8159994741234218, 0.853975456365142, 0.8330596233887412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 279}], {
             RGBColor[
             0.8381211844187627, 0.871339832620553, 0.8352079471180753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 280}], {
             RGBColor[
             0.9495710482148285, 0.959085205288955, 0.8461358055455775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 283}], {
             RGBColor[
             0.9303366672463893, 0.9437482320080843, 0.8443012131180732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 283}], {
             RGBColor[
             0.6584720501505834, 0.7305105011921329, 0.9685120812029373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 258}], {
             RGBColor[
             0.7856090202057764, 0.8329914015605582, 0.9791202955550495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 286}], {
             RGBColor[
             0.9403366035062619, 0.950246198632424, 0.7256290907022455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 269}], {
             RGBColor[
             0.5718990404504155, 0.6628648892715557, 0.9597607944766469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 277}], {
             RGBColor[
             0.6627793902821665, 0.7341414257324899, 0.9687445641280554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 281}], {
             RGBColor[
             0.44677746596758705`, 0.5609200321939563, 0.9498212842707279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 293}], {
             RGBColor[
             0.5048399432596996, 0.6088908345753176, 0.9541619961045003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 267}], {
             RGBColor[
             0.8872257204721943, 0.9129137226766488, 0.9891055753260304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 272}], {
             RGBColor[
             0.90552980355977, 0.9275089016795822, 0.9908514351111712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 300}], {
             RGBColor[
             0.7830505548299342, 0.8311150952497351, 0.978832814079375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 263}], {
             RGBColor[
             0.6518231009020103, 0.7275899146275822, 0.9661627362677705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 286}], {
             RGBColor[
             0.8381127688258541, 0.8698397650148424, 0.7155859019088631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 267}], {
             RGBColor[
             0.7312531376455162, 0.7896096710042455, 0.974275289617951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 287}], {
             RGBColor[
             0.7761124540150313, 0.8247217921700207, 0.9557587657598787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 294}], {
             RGBColor[
             0.6727959644370669, 0.7435262867362364, 0.9685592705981678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 300}], {
             RGBColor[
             0.6270779720032561, 0.7078110435773318, 0.9640025283712954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 284}], {
             RGBColor[
             0.7269637440380309, 0.7851150555147697, 0.9597858175978996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 292}], {
             RGBColor[
             0.5736009103054363, 0.6647140852693115, 0.9595751113100623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 286}], {
             RGBColor[
             0.8065506842024956, 0.844844711699448, 0.7126715314149663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 288}], {
             RGBColor[
             0.7053006106676629, 0.7669707702517317, 0.9479287237598166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 276}], {
             RGBColor[
             0.555802700822692, 0.6502646970110197, 0.9581739710625912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 286}], {
             RGBColor[
             0.8033230449025326, 0.8422243687122444, 0.712417439826041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 272}], {
             RGBColor[
             0.8897807759311632, 0.9149510545444979, 0.9893492787966318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 287}], {
             RGBColor[
             0.9163360092131027, 0.9354679967073396, 0.9690868951534186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 300}], {
             RGBColor[
             0.7673015272013275, 0.8185572481146508, 0.9773306577648355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 279}], {
             RGBColor[
             0.6590802579984473, 0.7335150457931894, 0.9667111803420141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 280}], {
             RGBColor[
             0.7705301217945131, 0.8212604184615913, 0.9776390387695163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 277}], {
             RGBColor[
             0.7637602576238003, 0.8156547015955737, 0.9770138085060205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 282}], {
             RGBColor[
             0.5953355758089596, 0.6818917244795079, 0.9616058043909292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 293}], {
             RGBColor[
             0.6058208106013334, 0.6904041104384014, 0.9624312404824654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 271}], {
             RGBColor[
             0.6917623668844558, 0.7577451671275397, 0.9709409738979846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 278}], {
             RGBColor[
             0.8630511358666817, 0.8936375651138313, 0.9867997818654501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 289}], {
             RGBColor[
             0.9059814693214249, 0.9270475309044199, 0.9624120124581295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 295}], {
             RGBColor[
             0.6451879613184485, 0.719734436662606, 0.9673295967826765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 278}], {
             RGBColor[
             0.7104070480860879, 0.7726119298213321, 0.9727193202352997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 289}], {
             RGBColor[
             0.7533373815408311, 0.8060218956119207, 0.948331550827979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 295}], {
             RGBColor[
             0.49254387353785467`, 0.598708801370107, 0.9532491351525261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 274}], {
             RGBColor[
             0.435055466856178, 0.5512449116924263, 0.9489423275369997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 289}], {
             RGBColor[
             0.7042947757946286, 0.7658733342062501, 0.9445629021797326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 289}], {
             RGBColor[
             0.6983171750393495, 0.7606958368749772, 0.944182014745391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 281}], {
             RGBColor[
             0.6386386831409719, 0.7137098445179743, 0.9670742983001016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 282}], {
             RGBColor[
             0.6862159256407105, 0.753168260940442, 0.9705895740423378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 293}], {
             RGBColor[
             0.6967011604330844, 0.7616806468993356, 0.9714150101338741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 295}], {
             RGBColor[
             0.6638326425200806, 0.7346011993563984, 0.9691079431199916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 280}], {
             RGBColor[
             0.7926518320898539, 0.8386247947170022, 0.9797873624988505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 294}], {
             RGBColor[
             0.5885995526265406, 0.6743387789924935, 0.9621611997073494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 293}], {
             RGBColor[
             0.5282764786182437, 0.6279176697832697, 0.9560070060187826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 300}], {
             RGBColor[
             0.8121608435708425, 0.853669369280426, 0.9588141339067632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 296}], {
             RGBColor[
             0.4864735805390488, 0.5938033308688723, 0.9527649965418796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 297}], {
             RGBColor[
             0.5779365165369743, 0.6670351541738511, 0.9606639783235859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 291}], {
             RGBColor[
             0.5777145942825666, 0.6675966316223896, 0.9602114962313129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 297}], {
             RGBColor[
             0.6176058275732241, 0.6994173510097847, 0.9637380240128814]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.09631744162763219], {
             RGBColor[
             0.8753979443181465, 0.903482575027842, 0.9879774314776769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.09631744162763219], {
             RGBColor[
             0.9758872109779696, 0.9303240420558997, 0.3608267972778807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.09631744162763219], {
             RGBColor[
             0.6522994735112058, 0.7283005734573508, 0.9659787735005905]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.09631744162763219], {
             RGBColor[
             0.8641013868015587, 0.894475006701, 0.9868999557371888]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.09631744162763219], {
             RGBColor[
             0.6429779632921988, 0.7210185388281609, 0.9650496924764255]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.09631744162763219], {
             RGBColor[
             0.5314417611138404, 0.6304873887075466, 0.9562561886516479]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.09631744162763219], {
             RGBColor[
             0.8228095330488325, 0.8615500033560876, 0.9829615018645808]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.09631744162763219], {
             RGBColor[
             0.4261776004252764, 0.5435553500045205, 0.9483766377384116]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.09631744162763219], {
             RGBColor[
             0.5099619364607154, 0.6130490993990664, 0.9545652181717637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.09631744162763219], {
             RGBColor[
             0.727193379848213, 0.786808262302591, 0.9734434981609164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.09631744162763219], {
             RGBColor[
             0.5335610251940813, 0.632207902759645, 0.9564230248831646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.09631744162763219], {
             RGBColor[
             0.8313175060544302, 0.8683340300879762, 0.9837729999250119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.09631744162763219], {
             RGBColor[
             0.677463051362164, 0.7479585517247944, 0.9684868437737691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.09631744162763219], {
             RGBColor[
             0.4380867582825022, 0.5538704639687713, 0.9491354787462193]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.09631744162763219], {
             RGBColor[
             0.8900285252509202, 0.5935270423024579, 0.2299494446329042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.09631744162763219], {
             RGBColor[
             0.9926291210796987, 0.991219966390577, 0.7718180691399621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.09631744162763219], {
             RGBColor[
             0.776221593782628, 0.8251094756563829, 0.9783301723311901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.09631744162763219], {
             RGBColor[
             0.44313584420957325`, 0.5582437284243628, 0.9494572020367609]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.09631744162763219], {
             RGBColor[
             0.8192455362783049, 0.8587201065280795, 0.9826183968375573]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.09631744162763219], {
             RGBColor[
             0.4513111663521255, 0.5653247815606031, 0.9499781263345307]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.09631744162763219], {
             RGBColor[
             0.6775384912794754, 0.7480174859615627, 0.9684943629197006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.09631744162763219], {
             RGBColor[
             0.45947517875319677`, 0.5720616750895869, 0.9505907156659406]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.09631744162763219], {
             RGBColor[
             0.4666301856327171, 0.5778704320037683, 0.9511539840171502]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.09631744162763219], {
             RGBColor[
             0.6206709682403175, 0.7029276787827933, 0.9632806386939997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.09631744162763219], {
             RGBColor[
             0.588345011050631, 0.6766840104684299, 0.9607358209301448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.09631744162763219], {
             RGBColor[
             0.5827554151245427, 0.6721461246872044, 0.9602957874634785]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.09631744162763219], {
             RGBColor[
             0.716695747067653, 0.7786074317894535, 0.9723971922313059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.09631744162763219], {
             RGBColor[
             0.979546087777233, 0.9842660862712435, 0.9195073175451726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.09631744162763219], {
             RGBColor[
             0.45173975482815587`, 0.5656960033570574, 0.9500054356132375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.09631744162763219], {
             RGBColor[
             0.5520786919585615, 0.6472413788504311, 0.9578808034433128]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.09631744162763219], {
             RGBColor[
             0.9422224012297554, 0.9564301419560625, 0.9826865832935536]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.09631744162763219], {
             RGBColor[
             0.8862338998445904, 0.9121228718304514, 0.9890109745891609]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.09631744162763219], {
             RGBColor[
             0.9772346731278074, 0.9825422370102961, 0.9234199396331593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.09631744162763219], {
             RGBColor[
             0.8020660667436953, 0.8452993743588382, 0.9809061078656179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.09631744162763219], {
             RGBColor[
             0.9806606251290165, 0.9850973064033163, 0.9176206965264995]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.09631744162763219], {
             RGBColor[
             0.4666301856327171, 0.5778704320037683, 0.9511539840171502]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.09631744162763219], {
             RGBColor[
             0.9944171175117607, 0.9904671038106891, 0.6337158785911514]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.09631744162763219], {
             RGBColor[
             0.8688098351059501, 0.8982293955714972, 0.9873490517397431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.09631744162763219], {
             RGBColor[
             0.40133643345932796`, 0.522039179731971, 0.9467937805455229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.09631744162763219], {
             RGBColor[
             0.7290887396425676, 0.7882889317792088, 0.9736324099120732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.09631744162763219], {
             RGBColor[
             0.6716236615920339, 0.7433967760553628, 0.9679048279736826]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.09631744162763219], {
             RGBColor[
             0.2819126156606254, 0.4136384117244858, 0.9393658784583073]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.09631744162763219], {
             RGBColor[
             0.8285005403819139, 0.8660878581252078, 0.9835043152244323]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.09631744162763219], {
             RGBColor[
             0.6953618192514746, 0.7619412052355982, 0.9702708256834798]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.09631744162763219], {
             RGBColor[
             0.5164034833414942, 0.6182786373452627, 0.9550723203383822]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.09631744162763219], {
             RGBColor[
             0.8388557502282334, 0.8743448213719798, 0.9844920043837793]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.09631744162763219], {
             RGBColor[
             0.9503804047585549, 0.9625143676303363, 0.968877211267384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.09631744162763219], {
             RGBColor[
             0.5033051301440463, 0.6076448041454874, 0.9540411699938304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.09631744162763219], {
             RGBColor[
             0.6484142135845097, 0.7252653788735467, 0.9655915271009157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.09631744162763219], {
             RGBColor[
             0.9628736340361522, 0.8864261912979763, 0.31027150826671723`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.09631744162763219], {
             RGBColor[
             0.5574370824747542, 0.6515915616642183, 0.9583026355731787]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.09631744162763219], {
             RGBColor[
             0.767785889243257, 0.8185194391564972, 0.9774893801388466]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.09631744162763219], {
             RGBColor[
             0.5804296183899783, 0.6702579381221363, 0.9601126922248594]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.09631744162763219], {
             RGBColor[
             0.971569955079032, 0.9783174995646439, 0.9330088296946482]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.09631744162763219], {
             RGBColor[
             0.3395962956244392, 0.468562975488946, 0.942859753557344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.09631744162763219], {
             RGBColor[
             0.6875435529253411, 0.7558335161605978, 0.9694915739619436]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.09631744162763219], {
             RGBColor[
             0.966248010596395, 0.9743484020833775, 0.9420174935183288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.09631744162763219], {
             RGBColor[
             0.672601295275567, 0.74416051091923, 0.9680022693627509]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.09631744162763219], {
             RGBColor[
             0.5448077541498793, 0.6413385039853274, 0.9573084085846906]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.09631744162763219], {
             RGBColor[
             0.4897941493957318, 0.5966759813112592, 0.9529775360969699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.09631744162763219], {
             RGBColor[
             0.9654217575563825, 0.9737321839190013, 0.9434161243937637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.09631744162763219], {
             RGBColor[
             0.8592718541811049, 0.8906240684836209, 0.9864393106044752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.09631744162763219], {
             RGBColor[
             0.7685467680573216, 0.8191138434689377, 0.9775652174282158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.09631744162763219], {
             RGBColor[
             0.6507995975163491, 0.727128858930689, 0.9658292798785613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.09631744162763219], {
             RGBColor[
             0.9943594203731666, 0.9919354896150895, 0.7431425319761691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.09631744162763219], {
             RGBColor[
             0.41349155266570226`, 0.5325673330544773, 0.9475682939930031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.09631744162763219], {
             RGBColor[
             0.9292467756037445, 0.9464201714073914, 0.9931135810771164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.09631744162763219], {
             RGBColor[
             0.4666301856327171, 0.5778704320037683, 0.9511539840171502]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.09631744162763219], {
             RGBColor[
             0.6344411749538242, 0.7141069529335611, 0.9643646798084162]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.09631744162763219], {
             RGBColor[
             0.8045147084023891, 0.8472122718329758, 0.9811501655822992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.09631744162763219], {
             RGBColor[
             0.3882791754971954, 0.510729639162039, 0.9459617836142556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.09631744162763219], {
             RGBColor[
             0.8319151165312147, 0.8688105484604599, 0.9838300005457807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.09631744162763219], {
             RGBColor[
             0.6567703018060368, 0.7317932185008263, 0.9664243838827534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.09631744162763219], {
             RGBColor[
             0.5601684350181585, 0.6538089967049837, 0.9585176576506695]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.09631744162763219], {
             RGBColor[
             0.7123558334271439, 0.7752170582689224, 0.9719646301984188]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.09631744162763219], {
             RGBColor[
             0.8561711499236236, 0.8881516510750802, 0.9861435626643653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.09631744162763219], {
             RGBColor[
             0.8915532325880589, 0.9163643633706522, 0.9895183372948573]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.09631744162763219], {
             RGBColor[
             0.5143023003769336, 0.6165728023574184, 0.9549069075185252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.09631744162763219], {
             RGBColor[
             0.6223799631402269, 0.7043151178318826, 0.9634151770327751]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.09631744162763219], {
             RGBColor[
             0.8681508518492733, 0.8977039402102471, 0.9872861973284399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.09631744162763219], {
             RGBColor[
             0.7170867680935928, 0.7789129003867875, 0.9724361655528724]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.09631744162763219], {
             RGBColor[
             0.4944036010659589, 0.6004181418305808, 0.953340409017428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.09631744162763219], {
             RGBColor[
             0.7203298179414004, 0.7814463955759865, 0.972759402453678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.09631744162763219], {
             RGBColor[
             0.7081855569692308, 0.7719592066047257, 0.9715489760145433]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.09631744162763219], {
             RGBColor[
             0.381107047728234, 0.5045175025701878, 0.945504781974881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.09631744162763219], {
             RGBColor[
             0.4423389937829958, 0.5575535366357283, 0.9494064274322065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.09631744162763219], {
             RGBColor[
             0.44596946797184733`, 0.5606980709051732, 0.9496377580372178]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.09631744162763219], {
             RGBColor[
             0.8335907815575044, 0.8701466782677079, 0.9839898269718721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.09631744162763219], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.09631744162763219], {
             RGBColor[
             0.8496839745464091, 0.8829789535189739, 0.9855248100857168]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.09631744162763219], {
             RGBColor[
             0.5471441680923812, 0.6432353100780991, 0.9574923396488106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.09631744162763219], {
             RGBColor[
             0.21404723810900797`, 0.34230759700427454`, 0.9355010456045717]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.09631744162763219], {
             RGBColor[
             0.8831117938605466, 0.9096333892660841, 0.9887131853332658]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.09631744162763219], {
             RGBColor[
             0.6844589879585816, 0.7534238305650032, 0.9691841333529555]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.09631744162763219], {
             RGBColor[
             0.9302792108900502, 0.9472434072799822, 0.9932120556763901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.09631744162763219], {
             RGBColor[
             0.3928419838344997, 0.5146817144103968, 0.9462525217267757]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.09631744162763219], {
             RGBColor[
             0.5268370624987628, 0.626749086932518, 0.9558936899091022]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.09631744162763219], {
             RGBColor[
             0.9886245204847471, 0.9895639611310235, 0.8381846645724367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.09631744162763219], {
             RGBColor[
             0.7404556200240375, 0.7971688251247037, 0.9747653543189616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.09631744162763219], {
             RGBColor[
             0.6132947130786202, 0.6969393025460191, 0.9626999528675579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.09631744162763219], {
             RGBColor[
             0.8369535919278004, 0.872828091975926, 0.9843105748270071]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.09631744162763219], {
             RGBColor[
             0.5200682337146141, 0.6212538467932843, 0.9553608229121772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.09631744162763219], {
             RGBColor[
             0.7815131433978709, 0.8292432744330773, 0.9788575845444949]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.09631744162763219], {
             RGBColor[
             0.9843800180288238, 0.9878087502867616, 0.9085270546873273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.09631744162763219], {
             RGBColor[
             0.46376785653177266`, 0.575546664293165, 0.9509286509852669]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.09631744162763219], {
             RGBColor[
             0.9570270464649201, 0.9674714221320665, 0.9576261805803017]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.09631744162763219], {
             RGBColor[
             0.8183208809414763, 0.8579977587513082, 0.9825262358349776]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.09631744162763219], {
             RGBColor[
             0.6286002134440707, 0.7093649972476257, 0.9639048579222214]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.09631744162763219], {
             RGBColor[
             0.46508607797029783`, 0.5766168558421588, 0.9510324262057118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.09631744162763219], {
             RGBColor[
             0.9941337939258618, 0.9898611033088602, 0.6028778547365596]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.09631744162763219], {
             RGBColor[
             0.7281237695444599, 0.7875350898045227, 0.9735362307108522]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.09631744162763219], {
             RGBColor[
             0.47091817310878165`, 0.5813516134084719, 0.9514915500986817]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.09631744162763219], {
             RGBColor[
             0.9836244109761746, 0.9873076930353728, 0.9126037801664102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.09631744162763219], {
             RGBColor[
             0.700494498109712, 0.7659508929694574, 0.970782403144458]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.09631744162763219], {
             RGBColor[
             0.8130183922890809, 0.8538554143156506, 0.9819977333206806]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.09631744162763219], {
             RGBColor[
             0.7610001145277616, 0.8132183403749543, 0.9768130375318761]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.09631744162763219], {
             RGBColor[
             0.859025492199955, 0.8904276261271697, 0.9864158123787833]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.09631744162763219], {
             RGBColor[
             0.7077642479012991, 0.7716300767587899, 0.971506983864009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.09631744162763219], {
             RGBColor[
             0.9862115727441378, 0.9885661452303531, 0.8781734531429125]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.09631744162763219], {
             RGBColor[
             0.6033963760078507, 0.688903386596965, 0.9619207195145435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.09631744162763219], {
             RGBColor[
             0.6216600346721173, 0.7037306474690632, 0.9633585016265807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.09631744162763219], {
             RGBColor[
             0.7093476699343765, 0.7728670580854832, 0.9716648045743459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.09631744162763219], {
             RGBColor[
             0.5286028626590691, 0.6281826430510452, 0.9560327001660606]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.09631744162763219], {
             RGBColor[
             0.9940799146444925, 0.9918199068133131, 0.7477746652379373]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.09631744162763219], {
             RGBColor[
             0.965878064799058, 0.9740724971134542, 0.9426437152559032]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.09631744162763219], {
             RGBColor[
             0.9188354837417994, 0.9381184898836654, 0.9921205427650541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.09631744162763219], {
             RGBColor[
             0.7365296998809463, 0.7941018664708226, 0.974374055288908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.09631744162763219], {
             RGBColor[
             0.8566019628329119, 0.8884951695948418, 0.9861846539842445]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.09631744162763219], {
             RGBColor[
             0.9365295566506959, 0.9521844277901774, 0.9923230842342393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.09631744162763219], {
             RGBColor[
             0.7541320519498573, 0.8078529576898866, 0.9761284932398044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.09631744162763219], {
             RGBColor[
             0.4797607632957117, 0.58853042647637, 0.952187671189672]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.09631744162763219], {
             RGBColor[
             0.5896377893624838, 0.6777335461409912, 0.9608375931744567]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.09631744162763219], {
             RGBColor[
             0.4149498286834543, 0.5338304184459703, 0.9476612140513514]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.09631744162763219], {
             RGBColor[
             0.8260097596401966, 0.8641017771722046, 0.9832667423337411]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.09631744162763219], {
             RGBColor[
             0.6047048708539482, 0.689965681660048, 0.962023729022003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.09631744162763219], {
             RGBColor[
             0.569651038326357, 0.6615074012569901, 0.9592641629190114]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.09631744162763219], {
             RGBColor[
             0.8951793726763501, 0.9192557490481049, 0.9898642017735719]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.09631744162763219], {
             RGBColor[
             0.6139675621392116, 0.6974855517249119, 0.962752922010335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.09631744162763219], {
             RGBColor[
             0.8718284963665541, 0.9006363941213258, 0.9876369743455702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.09631744162763219], {
             RGBColor[
             0.45791849740299245`, 0.5707978910417955, 0.9504681680077408]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.09631744162763219], {
             RGBColor[
             0.7545623464266888, 0.8081891070055465, 0.9761713809719246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.09631744162763219], {
             RGBColor[
             0.6094944206157835, 0.6938540539234639, 0.9624007799239535]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.09631744162763219], {
             RGBColor[
             0.4436874897865332, 0.5587215360966126, 0.9494923524051238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.09631744162763219], {
             RGBColor[
             0.5383788081114573, 0.6361191959706178, 0.9568022984025407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.09631744162763219], {
             RGBColor[
             0.6165711130880598, 0.6995992316738207, 0.9629578830781497]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.09631744162763219], {
             RGBColor[
             0.3874744042221381, 0.5100325867325648, 0.9459105043002403]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.09631744162763219], {
             RGBColor[
             0.42623175327118024`, 0.5436022544778412, 0.9483800883098672]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.09631744162763219], {
             RGBColor[
             0.46019257740937003`, 0.5726440916371096, 0.9506471919160724]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.09631744162763219], {
             RGBColor[
             0.8645090307487043, 0.8948000509192537, 0.9869388371807756]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.09631744162763219], {
             RGBColor[
             0.773957060203821, 0.8233404048135262, 0.9781044647873242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.09631744162763219], {
             RGBColor[
             0.8196047957495463, 0.8590007627574865, 0.98265420446418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.09631744162763219], {
             RGBColor[
             0.7372153299112122, 0.7946374858614476, 0.9744423924827479]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.09631744162763219], {
             RGBColor[
             0.6912499382777804, 0.7587289725674953, 0.9698609918157344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.09631744162763219], {
             RGBColor[
             0.9548062088725014, 0.9658151250919286, 0.9613854793370556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.09631744162763219], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.09631744162763219], {
             RGBColor[
             0.4720776574877907, 0.5822929350615275, 0.9515828289563285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.09631744162763219], {
             RGBColor[
             0.5371710787377932, 0.6351387068574892, 0.9567072215221875]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.09631744162763219], {
             RGBColor[
             0.9933413814774745, 0.988166213206948, 0.5166286499323679]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.09631744162763219], {
             RGBColor[
             0.6068830951760222, 0.6917340622925952, 0.9621952068197351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.09631744162763219], {
             RGBColor[
             0.9809039602675217, 0.9852787853511886, 0.9172087936089789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.09631744162763219], {
             RGBColor[
             0.5296308802354113, 0.6290172340311839, 0.9561136294754228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.09631744162763219], {
             RGBColor[
             0.8126717563760202, 0.853584619705837, 0.9819631838923635]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.09631744162763219], {
             RGBColor[
             0.6621589608727815, 0.7360028799190931, 0.9669614750586444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.09631744162763219], {
             RGBColor[
             0.46686251184728444`, 0.5780590448909307, 0.9511722735878]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.09631744162763219], {
             RGBColor[
             0.6409931257197458, 0.7194261217273545, 0.964880473373296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.09631744162763219], {
             RGBColor[
             0.8891780996152436, 0.9144704968093964, 0.9892917949916039]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.09631744162763219], {
             RGBColor[
             0.38791675133940295`, 0.510415725572527, 0.9459386902674002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.09631744162763219], {
             RGBColor[
             0.46659491245242135`, 0.5778417956469655, 0.9511512071831875]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.09631744162763219], {
             RGBColor[
             0.8858103307696715, 0.5743732063474587, 0.22642967976034203`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.09631744162763219], {
             RGBColor[
             0.6120172587803108, 0.6959022075979913, 0.9625993869857258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.09631744162763219], {
             RGBColor[
             0.7460414033161329, 0.801532481486014, 0.975322092995405]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.09631744162763219], {
             RGBColor[
             0.8718284963665541, 0.9006363941213258, 0.9876369743455702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.09631744162763219], {
             RGBColor[
             0.9896440663311221, 0.9899855695396327, 0.8212881513979312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.09631744162763219], {
             RGBColor[
             0.6751116386996786, 0.7461216102814626, 0.9682524769347732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.09631744162763219], {
             RGBColor[
             0.7974105761310768, 0.8416624697092214, 0.9804420920693854]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.09631744162763219], {
             RGBColor[
             0.6634042059120256, 0.7369756748079634, 0.9670855894466798]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.09631744162763219], {
             RGBColor[
             0.5614894231758136, 0.6548814344012065, 0.9586216506773793]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.09631744162763219], {
             RGBColor[
             0.6621589608727815, 0.7360028799190931, 0.9669614750586444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.09631744162763219], {
             RGBColor[
             0.48609214120537236`, 0.593670524288757, 0.952686100451322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.09631744162763219], {
             RGBColor[
             0.4783633952512165, 0.5873959801471358, 0.9520776652584815]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.09631744162763219], {
             RGBColor[
             0.8373951382967544, 0.873180169065073, 0.984352689913851]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.09631744162763219], {
             RGBColor[
             0.755721152295969, 0.809094374957879, 0.9762868799113179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.09631744162763219], {
             RGBColor[
             0.6274047651539059, 0.7083944784713382, 0.9638107478537482]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.09631744162763219], {
             RGBColor[
             0.5029104997167569, 0.6073244253867157, 0.9540101032410153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.09631744162763219], {
             RGBColor[
             0.4970576186715026, 0.6025727928848919, 0.9535493430053232]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.09631744162763219], {
             RGBColor[
             0.6953828862448079, 0.7619576629309052, 0.9702729254444931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.09631744162763219], {
             RGBColor[
             0.8492945222838362, 0.8826684148561984, 0.9854876637812444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.09631744162763219], {
             RGBColor[
             0.4214781903277293, 0.5394849571772445, 0.9480771954825211]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.09631744162763219], {
             RGBColor[
             0.6583698054390853, 0.7330427628956416, 0.9665838074566844]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.09631744162763219], {
             RGBColor[
             0.5957911229037891, 0.6827290995143399, 0.9613220061312318]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.09631744162763219], {
             RGBColor[
             0.8949796746465616, 0.9190965152598103, 0.9898451543972182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.09631744162763219], {
             RGBColor[
             0.4071394287162701, 0.527065442556512, 0.947163542271908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.09631744162763219], {
             RGBColor[
             0.45216377247386785`, 0.5660632661300266, 0.9500324536426782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.09631744162763219], {
             RGBColor[
             0.6775897693737575, 0.7480575447985437, 0.9684994738409176]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.09631744162763219], {
             RGBColor[
             0.9437975872083858, 0.9576049130797947, 0.9800202043060325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.09631744162763219], {
             RGBColor[
             0.9933760232602475, 0.9882403084774779, 0.5203991942029068]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.09631744162763219], {
             RGBColor[
             0.6380258610512964, 0.7170171625957574, 0.9646468794291471]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.09631744162763219], {
             RGBColor[
             0.7023268791986083, 0.7673823630027151, 0.9709650377668242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.09631744162763219], {
             RGBColor[
             0.891555995583138, 0.9163665665079288, 0.9895186008317944]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.09631744162763219], {
             RGBColor[
             0.7144694481764624, 0.776868230175157, 0.9721752955637781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.09631744162763219], {
             RGBColor[
             0.42919291597508263`, 0.5461670647795964, 0.9485687709789065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.09631744162763219], {
             RGBColor[
             0.5539470622278762, 0.6487582060041822, 0.9580278883949791]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.09631744162763219], {
             RGBColor[
             0.9947208773772945, 0.9911168154482327, 0.6667782653659292]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.09631744162763219], {
             RGBColor[
             0.9552561495576621, 0.9661506901182111, 0.9606238471204037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.09631744162763219], {
             RGBColor[
             0.9950665648992029, 0.9922279120493909, 0.7314233171483777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.09631744162763219], {
             RGBColor[
             0.6600656570140948, 0.7343675750349885, 0.9667528340930474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.09631744162763219], {
             RGBColor[
             0.6017815194828483, 0.6875923733215107, 0.961793592093481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.09631744162763219], {
             RGBColor[
             0.41049236512849774`, 0.5299695875532995, 0.9473771884152099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.09631744162763219], {
             RGBColor[
             0.9297599804007444, 0.9468293869819461, 0.9931625310087976]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.09631744162763219], {
             RGBColor[
             0.6432665423340406, 0.7212439789689298, 0.9650784553383919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.09631744162763219], {
             RGBColor[
             0.2734763794305684, 0.4047713925584252, 0.9388854472852988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.09631744162763219], {
             RGBColor[
             0.4700405291019686, 0.5806391024663291, 0.9514224587475495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.09631744162763219], {
             RGBColor[
             0.5684598118125378, 0.6605403099089288, 0.959170385204237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.09631744162763219], {
             RGBColor[
             0.971569955079032, 0.9783174995646439, 0.9330088296946482]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.09631744162763219], {
             RGBColor[
             0.9456411213216189, 0.9589798178029338, 0.9768995819230318]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.09631744162763219], {
             RGBColor[
             0.8042153666647469, 0.8469784237924483, 0.9811203299953987]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.09631744162763219], {
             RGBColor[
             0.6573900253769791, 0.7322773512645201, 0.9664861521366589]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.09631744162763219], {
             RGBColor[
             0.6344411749538242, 0.7141069529335611, 0.9643646798084162]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.09631744162763219], {
             RGBColor[
             0.5738469324446547, 0.6649138171251001, 0.9595944790740705]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.09631744162763219], {
             RGBColor[
             0.6946866690610395, 0.7614137727754987, 0.9702035330221345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.09631744162763219], {
             RGBColor[
             0.982687018582456, 0.9532613897765836, 0.3872427657853917]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.09631744162763219], {
             RGBColor[
             0.7495593346645545, 0.8042807161926695, 0.9756727275152781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.09631744162763219], {
             RGBColor[
             0.994418231970403, 0.9904694875250362, 0.6338371805367335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.09631744162763219], {
             RGBColor[
             0.4400166820127725, 0.5555420669031443, 0.9492584517797475]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.09631744162763219], {
             RGBColor[
             0.9654217575563825, 0.9737321839190013, 0.9434161243937637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.09631744162763219], {
             RGBColor[
             0.7343030932732124, 0.792362424466024, 0.9741521279510708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.09631744162763219], {
             RGBColor[
             0.6851858270916764, 0.7539916428199589, 0.9692565778850445]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.09631744162763219], {
             RGBColor[
             0.5633470614340523, 0.6563895488248945, 0.958767890765821]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.09631744162763219], {
             RGBColor[
             0.482097188687068, 0.5904272418638374, 0.9523716031550877]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.09631744162763219], {
             RGBColor[
             0.34290291888615376`, 0.47142700636252566`, 0.9430704486676483]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.09631744162763219], {
             RGBColor[
             0.4313710770898418, 0.54805367845964, 0.9487075614790667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.09631744162763219], {
             RGBColor[
             0.4019463141930089, 0.5225674277699884, 0.9468326416065767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.09631744162763219], {
             RGBColor[
             0.46376785653177266`, 0.575546664293165, 0.9509286509852669]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.09631744162763219], {
             RGBColor[
             0.4154428815924186, 0.5342574760941555, 0.9476926309467211]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.09631744162763219], {
             RGBColor[
             0.7730878053077275, 0.8226613362821161, 0.9780178255829304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.09631744162763219], {
             RGBColor[
             0.4425636032721896, 0.5577480820860667, 0.9494207393502435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.09631744162763219], {
             RGBColor[
             0.6442387766460941, 0.7220034958027604, 0.9651753585685711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.09631744162763219], {
             RGBColor[
             0.9947208773772945, 0.9911168154482327, 0.6667782653659292]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.09631744162763219], {
             RGBColor[
             0.7715564439870353, 0.8214650251796143, 0.977865193797869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.09631744162763219], {
             RGBColor[
             0.5684598118125378, 0.6605403099089288, 0.959170385204237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.09631744162763219], {
             RGBColor[
             0.38165456279597854`, 0.5049917326029606, 0.9455396691508491]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.09631744162763219], {
             RGBColor[
             0.9636465029200134, 0.97240820191791, 0.9464211674325732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.09631744162763219], {
             RGBColor[
             0.9578956686862948, 0.9681192391625294, 0.9561558297324727]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.09631744162763219], {
             RGBColor[
             0.42623207926827567`, 0.5436025368401401, 0.9483801090821138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.09631744162763219], {
             RGBColor[
             0.5699057069552613, 0.6617141527226256, 0.9592842113663607]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.09631744162763219], {
             RGBColor[
             0.5583715506724379, 0.6523502050444104, 0.9583762003327703]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.09631744162763219], {
             RGBColor[
             0.864563908274339, 0.8948438087685842, 0.9869440714481604]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.09631744162763219], {
             RGBColor[
             0.7732460492921269, 0.8227849576854278, 0.9780335978644212]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.09631744162763219], {
             RGBColor[
             0.5419738711499404, 0.6390378301010027, 0.95708531493408]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.09631744162763219], {
             RGBColor[
             0.48125112967427297`, 0.5897403730427263, 0.9523049982903843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.09631744162763219], {
             RGBColor[
             0.8757412985024339, 0.9037563563342917, 0.9880101809062901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.09631744162763219], {
             RGBColor[
             0.9950404005437372, 0.9918002431925058, 0.7015563901648024]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.09631744162763219], {
             RGBColor[
             0.5154649948115527, 0.6175167300782297, 0.9549984390835085]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.09631744162763219], {
             RGBColor[
             0.4513111663521255, 0.5653247815606031, 0.9499781263345307]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.09631744162763219], {
             RGBColor[
             0.8878328548861842, 0.9133978351781398, 0.989163484348432]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.09631744162763219], {
             RGBColor[
             0.47091817310878165`, 0.5813516134084719, 0.9514915500986817]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.09631744162763219], {
             RGBColor[
             0.902974748100801, 0.9254715698117332, 0.9906077316405698]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.09631744162763219], {
             RGBColor[
             0.6833851855253686, 0.7525849679429765, 0.9690771067616671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.09631744162763219], {
             RGBColor[
             0.5704903796423174, 0.6621888163491821, 0.9593302389420124]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.09631744162763219], {
             RGBColor[
             0.5910295824474449, 0.6788634664669265, 0.960947160224411]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.09631744162763219], {
             RGBColor[
             0.5016470753325979, 0.6062987205550355, 0.9539106418454183]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.09631744162763219], {
             RGBColor[
             0.5177912438258697, 0.6194052838243761, 0.9551815699272465]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.09631744162763219], {
             RGBColor[
             0.6202610162786519, 0.7025948613121877, 0.9632483657738738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.09631744162763219], {
             RGBColor[
             0.9637969518325267, 0.9725204064705248, 0.9461664966670491]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.09631744162763219], {
             RGBColor[
             0.6138057376787256, 0.6973541753377805, 0.962740182596023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.09631744162763219], {
             RGBColor[
             0.5094255145289768, 0.6126136079093484, 0.9545229890723189]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.09631744162763219], {
             RGBColor[
             0.8714766928435875, 0.9003558755415645, 0.987603419011491]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.09631744162763219], {
             RGBColor[
             0.6369585477031063, 0.7161506695377783, 0.9645628566126799]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.09631744162763219], {
             RGBColor[
             0.6728799077920493, 0.7443781651346396, 0.9680300388546119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.09631744162763219], {
             RGBColor[
             0.8444064546650496, 0.8787708024200388, 0.985021435528135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.09631744162763219], {
             RGBColor[
             0.539118279103862, 0.6367195318350406, 0.9568605122678343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.09631744162763219], {
             RGBColor[
             0.9080848590187389, 0.9295462335474313, 0.9910951385817727]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.09631744162763219], {
             RGBColor[
             0.4410330676114571, 0.5564224090236993, 0.9493232149713412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.09631744162763219], {
             RGBColor[
             0.429077866100899, 0.5460674143611534, 0.9485614401026581]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.09631744162763219], {
             RGBColor[
             0.9796653261218558, 0.9843550140334283, 0.9193054781300671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.09631744162763219], {
             RGBColor[
             0.4977996639666584, 0.6031752186842589, 0.9536077595291593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.09631744162763219], {
             RGBColor[
             0.8546406074555514, 0.8869312380565079, 0.9859975781574292]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.09631744162763219], {
             RGBColor[
             0.8816958170683138, 0.9085043278076237, 0.9885781282027652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.09631744162763219], {
             RGBColor[
             0.6812019682937882, 0.7508794220486004, 0.9688595040713481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.09631744162763219], {
             RGBColor[
             0.9041016958859197, 0.9263701673854042, 0.9907152209263527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.09631744162763219], {
             RGBColor[
             0.42263675882639246`, 0.5404884509794406, 0.948151018442774]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.09631744162763219], {
             RGBColor[
             0.5177912438258697, 0.6194052838243761, 0.9551815699272465]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.09631744162763219], {
             RGBColor[
             0.8656329339490414, 0.8956962208236628, 0.987046036071344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.09631744162763219], {
             RGBColor[
             0.9522804127434639, 0.9639313904745038, 0.9656609933503809]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.09631744162763219], {
             RGBColor[
             0.5094255145289768, 0.6126136079093484, 0.9545229890723189]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.09631744162763219], {
             RGBColor[
             0.9928403521263395, 0.9870945620867082, 0.4620946970560589]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.09631744162763219], {
             RGBColor[
             0.9611953255826178, 0.9705801178731148, 0.9505703712953464]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.09631744162763219], {
             RGBColor[
             0.44680426950279906`, 0.5614211340329386, 0.949690950852584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.09631744162763219], {
             RGBColor[
             0.9675564839778001, 0.975324259388801, 0.9398025893881239]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.09631744162763219], {
             RGBColor[
             0.483229086856763, 0.5913461677894274, 0.9524607103252858]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.09631744162763219], {
             RGBColor[
             0.67220010170837, 0.7438470954553517, 0.9679622821373398]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.09631744162763219], {
             RGBColor[
             0.6294105767850028, 0.710022886714247, 0.9639686526928782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.09631744162763219], {
             RGBColor[
             0.5387617134106175, 0.6364300557421633, 0.9568324421103189]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.09631744162763219], {
             RGBColor[
             0.7545623464266888, 0.8081891070055465, 0.9761713809719246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.09631744162763219], {
             RGBColor[
             0.44596946797184733`, 0.5606980709051732, 0.9496377580372178]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.09631744162763219], {
             RGBColor[
             0.5261428915752986, 0.626185527704806, 0.9558390422311752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.09631744162763219], {
             RGBColor[
             0.7090687635711496, 0.7726491743147634, 0.9716370057945877]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.09631744162763219], {
             RGBColor[
             0.49287538150257193`, 0.5991774643435166, 0.9532201019753455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.09631744162763219], {
             RGBColor[
             0.5306530488671773, 0.6298470765746238, 0.9561940983344425]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.09631744162763219], {
             RGBColor[
             0.6631263615590673, 0.7367586206877371, 0.96705789651818]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1FO4EAYYBuBzsm2dTrZdW7WsZbtVy3bLtWxr2bat5WVjyzZXrfc8u3i/
//a7+f7gJu2rtAsMCAjIJEJuKEIThrCEIzwRiEgkIhOFqEQjOjGISSxiE4e4
xCM+CUhIIhKThKQkI4jkBJOClKQiNWlISzrSk4GMIX3JTBayko3s5CAnuchN
HvKSj/wUoCCF+IEfKUwRivITxShOCUpSitKUoSzlKE8FfqYilahMFapSjerU
oCa1qE0d6lKP+jSgIY1oTBN+oSnNaM6vtKAlrWhNG9rSjvZ0oCOd6EwXutKN
7vSgJ73ozW/0oS/96M8ABjKIwQzhd4YyjOGMYCSjGM0YxjKO8UxgIpOYzBSm
Mo3pzGAms5jNH8xhLvOYzwIWsojFLGEpy1jOClayitWsYS3rWM8GNrKJzWxh
K9vYzg52sovd7GEv+9jPAQ5yiMMc4U+OcozjnOAkpzjNX5zhLOc4zwUuconL
XOEq17jODW5yi9v8zT/c4S73uM8DHvKIxzzhKc94zgte8orXvOEt73jPBz7y
ic/8yxe+8o3/CBl/IKEITRjCEo7wRCAikYhMFKISjejEICaxiE0c4hKP+CQg
IYlITBKSkowgkhNMClKSitSkIS3pSE8GMgb+/6++Az6VhWw=
          "], {Null, CompressedData["
1:eJxN2guYllWBB/D3qyhJJoMEhjQEkUhkrd1Es1FL08DywkWybEVNDSyNClNB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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[72, 227] -> 
             RGBColor[
              0.8705118000329004, 0.43480247052567644`, 0.21080209492961144`],
              UndirectedEdge[132, 236] -> 
             RGBColor[
              0.21416362323535532`, 0.3424299251513089, 0.9355076735653408], 
             UndirectedEdge[187, 193] -> 
             RGBColor[
              0.25215196023065367`, 0.38235807593304705`, 0.9376710531585147],
              UndirectedEdge[196, 225] -> 
             RGBColor[
              0.21532817540767707`, 0.3436539433212913, 0.935573993088754], 
             UndirectedEdge[39, 166] -> 
             RGBColor[
              0.19390930592620187`, 0.3211413534614994, 0.9343542201581618], 
             UndirectedEdge[7, 216] -> 
             RGBColor[
              0.8904157072945873, 0.6421896715609007, 0.4699552151052654], 
             UndirectedEdge[92, 281] -> 
             RGBColor[
              0.8805236512409333, 0.4901849175991575, 0.4256811132326063], 
             UndirectedEdge[99, 229] -> 
             RGBColor[
              0.20669327315473038`, 0.33457811356902034`, 0.9350822481796419],
              UndirectedEdge[187, 296] -> 
             RGBColor[
              0.20597365560918635`, 0.3338217499022659, 0.9350412670250019], 
             UndirectedEdge[100, 244] -> 
             RGBColor[
              0.18508330510196136`, 0.31186466699444937`, 0.9338515924681194],
              UndirectedEdge[232, 245] -> 
             RGBColor[
              0.206575126823306, 0.3344539342837832, 0.9350755199208491], 
             UndirectedEdge[6, 52] -> 
             RGBColor[
              0.20466403550360635`, 0.3324452561365908, 0.9349666860973984], 
             UndirectedEdge[113, 160] -> 
             RGBColor[
              0.23169850636271255`, 0.3608601990939647, 0.936506259218909], 
             UndirectedEdge[176, 288] -> 
             RGBColor[
              0.20152898742648828`, 0.32915012183401104`, 0.9347881497472945],
              UndirectedEdge[187, 228] -> 
             RGBColor[
              0.32549861800497937`, 0.4485853630705261, 0.9422458467242234], 
             UndirectedEdge[61, 268] -> 
             RGBColor[
              0.24115438507843467`, 0.37079892716152685`, 0.9370447575230503],
              UndirectedEdge[51, 101] -> 
             RGBColor[
              0.7293123816710212, 0.7884636426315792, 0.9736547004594159], 
             UndirectedEdge[207, 214] -> 
             RGBColor[
              0.19305906954872248`, 0.3202477011206687, 0.9343058004542764], 
             UndirectedEdge[17, 162] -> 
             RGBColor[
              0.8475057087773203, 0.8795582824939998, 0.8820715972741542], 
             UndirectedEdge[20, 279] -> 
             RGBColor[
              0.22783544818024304`, 0.35679988001215385`, 0.9362862637702997],
              UndirectedEdge[51, 197] -> 
             RGBColor[
              0.8988192263028636, 0.9205652040419037, 0.9289214218265444], 
             UndirectedEdge[86, 94] -> 
             RGBColor[
              0.6955329406462065, 0.7613368008112785, 0.9707925147289977], 
             UndirectedEdge[55, 114] -> 
             RGBColor[
              0.22063449464495144`, 0.3492312212797382, 0.9358761801193209], 
             UndirectedEdge[13, 270] -> 
             RGBColor[
              0.27306394266259, 0.4020687514269927, 0.9389450440967648], 
             UndirectedEdge[151, 220] -> 
             RGBColor[
              0.46545874896093703`, 0.5736549196510825, 0.9519637517959829], 
             UndirectedEdge[117, 225] -> 
             RGBColor[
              0.20655322702626136`, 0.33443091620856197`, 0.9350742727598051],
              UndirectedEdge[13, 277] -> 
             RGBColor[
              0.6631499633187324, 0.7252798242769541, 0.7115734484509257], 
             UndirectedEdge[81, 237] -> 
             RGBColor[
              0.8465380738337873, 0.3261495278745926, 0.19092293386380793`], 
             UndirectedEdge[172, 174] -> 
             RGBColor[
              0.21189442021644855`, 0.34004484890265657`, 0.9353784458103991],
              UndirectedEdge[128, 197] -> 
             RGBColor[
              0.8920740737202894, 0.5604973646047849, 0.4191176658739154], 
             UndirectedEdge[44, 71] -> 
             RGBColor[
              0.26976807981775686`, 0.40018277558695564`, 0.9386995645005083],
              UndirectedEdge[70, 122] -> 
             RGBColor[
              0.19740509453050553`, 0.32481564893042175`, 0.9345533001476212],
              UndirectedEdge[42, 293] -> 
             RGBColor[
              0.8583227451079464, 0.4059379610803489, 0.20178529360286196`], 
             UndirectedEdge[154, 181] -> 
             RGBColor[
              0.7417957890267707, 0.7840980478369171, 0.6774116520475943], 
             UndirectedEdge[42, 216] -> 
             RGBColor[
              0.847224395566658, 0.3555429478987492, 0.19252455870016974`], 
             UndirectedEdge[125, 130] -> 
             RGBColor[
              0.8607307087477495, 0.4103624865662075, 0.20352137280561344`], 
             UndirectedEdge[173, 263] -> 
             RGBColor[
              0.20558810816091344`, 0.33341651508901093`, 0.935019310668189], 
             UndirectedEdge[112, 132] -> 
             RGBColor[
              0.1930638232066118, 0.32025269751650964`, 0.9343060711680607], 
             UndirectedEdge[208, 279] -> 
             RGBColor[
              0.21299163292133522`, 0.34119808902279597`, 0.9354409304507616],
              UndirectedEdge[271, 295] -> 
             RGBColor[
              0.20977901412683497`, 0.3378214229779799, 0.9352579765630585], 
             UndirectedEdge[193, 264] -> 
             RGBColor[
              0.28788684943506876`, 0.4199177102097248, 0.939706102233675], 
             UndirectedEdge[16, 39] -> 
             RGBColor[
              0.22425729902189784`, 0.35303901837897317`, 0.9360824934691292],
              UndirectedEdge[168, 282] -> 
             RGBColor[
              0.42052178364044757`, 0.5386565657751188, 0.9480162540941248], 
             UndirectedEdge[92, 243] -> 
             RGBColor[
              0.8835089623946862, 0.49205410836049707`, 0.4046294016989433], 
             UndirectedEdge[71, 280] -> 
             RGBColor[
              0.2426648792276659, 0.37238655228322937`, 0.9371307779302732], 
             UndirectedEdge[69, 118] -> 
             RGBColor[
              0.19814492935345804`, 0.3255932622375819, 0.9345954326463008], 
             UndirectedEdge[175, 253] -> 
             RGBColor[
              0.18722926764301806`, 0.3141202096869836, 0.9339738018601655], 
             UndirectedEdge[137, 179] -> 
             RGBColor[
              0.3921454633437752, 0.5078279411583735, 0.9468889147894293], 
             UndirectedEdge[134, 221] -> 
             RGBColor[
              0.21549733286296777`, 0.343831738532004, 0.9355836263555868], 
             UndirectedEdge[91, 163] -> 
             RGBColor[
              0.5556545906660699, 0.6501444545135875, 0.9581623112885165], 
             UndirectedEdge[160, 232] -> 
             RGBColor[
              0.19183608079529113`, 0.31896226239884673`, 0.9342361530540182],
              UndirectedEdge[135, 263] -> 
             RGBColor[
              0.21148289076359805`, 0.33961230535523634`, 0.9353550098168626],
              UndirectedEdge[160, 297] -> 
             RGBColor[
              0.1938787777952211, 0.3211092664602433, 0.9343524816262648], 
             UndirectedEdge[179, 274] -> 
             RGBColor[
              0.4929016619374462, 0.5991987999844676, 0.9532221708674471], 
             UndirectedEdge[209, 259] -> 
             RGBColor[
              0.18280847530695815`, 0.30947367664736153`, 0.9337220442766032],
              UndirectedEdge[14, 173] -> 
             RGBColor[
              0.1907403974209291, 0.31781062970205387`, 0.9341737555067666], 
             UndirectedEdge[260, 267] -> 
             RGBColor[
              0.22718681650953165`, 0.35611812700061296`, 0.9362493251562173],
              UndirectedEdge[203, 216] -> 
             RGBColor[
              0.8900175091899872, 0.6418926960664795, 0.4706292606296545], 
             UndirectedEdge[37, 279] -> 
             RGBColor[
              0.23161750381713786`, 0.36077506028270767`, 0.936501646243771], 
             UndirectedEdge[192, 220] -> 
             RGBColor[
              0.3318533670341157, 0.4618564399149144, 0.9423663809943715], 
             UndirectedEdge[60, 225] -> 
             RGBColor[
              0.25743202099321577`, 0.38790775456968785`, 0.9379717448077927],
              UndirectedEdge[177, 226] -> 
             RGBColor[
              0.6391144281004404, 0.7063980774045702, 0.908678535889838], 
             UndirectedEdge[91, 273] -> 
             RGBColor[
              0.3645444727684772, 0.4827165664417553, 0.9449621664859775], 
             UndirectedEdge[52, 273] -> 
             RGBColor[
              0.2188316043007933, 0.34733626921817795`, 0.9357735081813584], 
             UndirectedEdge[21, 114] -> 
             RGBColor[
              0.21635493982133241`, 0.34473313782066695`, 0.9356324658031498],
              UndirectedEdge[7, 202] -> 
             RGBColor[
              0.890487052481644, 0.642513633392233, 0.47001474727817605`], 
             UndirectedEdge[94, 293] -> 
             RGBColor[
              0.8483237902546403, 0.739482330174071, 0.6092293420609014], 
             UndirectedEdge[132, 133] -> 
             RGBColor[
              0.19109281456444907`, 0.3181810424644308, 0.9341938251417357], 
             UndirectedEdge[13, 93] -> 
             RGBColor[
              0.2872094013725457, 0.41693652540503934`, 0.939750607043966], 
             UndirectedEdge[141, 178] -> 
             RGBColor[
              0.27642955220691934`, 0.4078753643883386, 0.9390536261060842], 
             UndirectedEdge[245, 264] -> 
             RGBColor[
              0.26072622472382, 0.3913701715551329, 0.938159344836913], 
             UndirectedEdge[5, 83] -> 
             RGBColor[
              0.8880392864849254, 0.5438464775091899, 0.242104808287807], 
             UndirectedEdge[210, 226] -> 
             RGBColor[
              0.7289680937933078, 0.7852771577024377, 0.9144848957128108], 
             UndirectedEdge[91, 298] -> 
             RGBColor[
              0.3751482927558811, 0.4938618535695355, 0.9455660383473143], 
             UndirectedEdge[126, 192] -> 
             RGBColor[
              0.2770528278061131, 0.40650831596386994`, 0.939163161568517], 
             UndirectedEdge[127, 156] -> 
             RGBColor[
              0.3716633849526351, 0.49633787652625627`, 0.9449030401335229], 
             UndirectedEdge[36, 268] -> 
             RGBColor[
              0.19319132437376368`, 0.32038670932722724`, 0.934313332170909], 
             UndirectedEdge[25, 221] -> 
             RGBColor[
              0.1886556188584439, 0.3156193952502866, 0.9340550304517865], 
             UndirectedEdge[69, 249] -> 
             RGBColor[
              0.20751277813074143`, 0.3354394652584245, 0.9351289177756767], 
             UndirectedEdge[22, 161] -> 
             RGBColor[
              0.1950980417525622, 0.32239079018520866`, 0.934421916904896], 
             UndirectedEdge[96, 112] -> 
             RGBColor[
              0.1950909003644823, 0.32238328413354655`, 0.9344215102134096], 
             UndirectedEdge[219, 250] -> 
             RGBColor[
              0.1834940050025886, 0.3101942118225623, 0.933761084178619], 
             UndirectedEdge[41, 219] -> 
             RGBColor[
              0.18646440411145038`, 0.3133162896201571, 0.933930244013557], 
             UndirectedEdge[202, 237] -> 
             RGBColor[
              0.8527387116152162, 0.3892539418421428, 0.19746540404923543`], 
             UndirectedEdge[91, 235] -> 
             RGBColor[
              0.44932632055040805`, 0.5626052939537676, 0.9501280434357534], 
             UndirectedEdge[69, 263] -> 
             RGBColor[
              0.2087290677202517, 0.3367178627342138, 0.9351981836684602], 
             UndirectedEdge[12, 239] -> 
             RGBColor[
              0.3335981101513706, 0.4567875043441526, 0.9427184858018454], 
             UndirectedEdge[122, 266] -> 
             RGBColor[
              0.19159505471631844`, 0.31870892870791034`, 0.9342224269753869],
              UndirectedEdge[206, 254] -> 
             RGBColor[
              0.27060222090313846`, 0.400822588016517, 0.9387557425033809], 
             UndirectedEdge[137, 270] -> 
             RGBColor[
              0.23718665422901314`, 0.36662859047011903`, 0.9368188011209075],
              UndirectedEdge[25, 58] -> 
             RGBColor[
              0.19112827338567, 0.31821831193375316`, 0.9341958444691476], 
             UndirectedEdge[107, 156] -> 
             RGBColor[
              0.4014834091317521, 0.5221664826722128, 0.9468031457054042], 
             UndirectedEdge[136, 194] -> 
             RGBColor[
              0.539310518839214, 0.6345587760249104, 0.957788184762517], 
             UndirectedEdge[45, 281] -> 
             RGBColor[
              0.6391981620742301, 0.7080190375817033, 0.9308676637061029], 
             UndirectedEdge[137, 147] -> 
             RGBColor[
              0.23746595794531072`, 0.3669221563848262, 0.9368347070543579], 
             UndirectedEdge[164, 187] -> 
             RGBColor[
              0.2033506574299822, 0.3310648125082323, 0.9348918911590742], 
             UndirectedEdge[199, 229] -> 
             RGBColor[
              0.20805355497894237`, 0.33600785601311617`, 0.9351597142171741],
              UndirectedEdge[191, 271] -> 
             RGBColor[
              0.22500596477055484`, 0.35382591354896176`, 0.9361251288759636],
              UndirectedEdge[153, 222] -> 
             RGBColor[
              0.2212473690290584, 0.3498753911159149, 0.9359110824088295], 
             UndirectedEdge[158, 186] -> 
             RGBColor[
              0.19303082310645578`, 0.3202180123189185, 0.9343041918611762], 
             UndirectedEdge[16, 192] -> 
             RGBColor[
              0.28870383608450384`, 0.4187542643810497, 0.9398266692538492], 
             UndirectedEdge[75, 143] -> 
             RGBColor[
              0.31991196504772945`, 0.4513422193006194, 0.941611753099148], 
             UndirectedEdge[204, 226] -> 
             RGBColor[
              0.734932739386402, 0.7901195256991334, 0.9149544544631159], 
             UndirectedEdge[137, 191] -> 
             RGBColor[
              0.24445543716588297`, 0.3742685422042259, 0.9372327475559615], 
             UndirectedEdge[197, 198] -> 
             RGBColor[
              0.9754663865596167, 0.9808663065126991, 0.9104194926535587], 
             UndirectedEdge[80, 156] -> 
             RGBColor[
              0.6866499660786538, 0.7281441949934098, 0.6592663633827371], 
             UndirectedEdge[103, 159] -> 
             RGBColor[
              0.35628521918114736`, 0.4813996069512451, 0.9439824173184419], 
             UndirectedEdge[28, 288] -> 
             RGBColor[
              0.19616769103516415`, 0.32351505940090497`, 0.9344828318491358],
              UndirectedEdge[118, 263] -> 
             RGBColor[
              0.19930513416780576`, 0.32681271105869525`, 0.9346615045941087],
              UndirectedEdge[68, 83] -> 
             RGBColor[
              0.8566539261889098, 0.5407679915618476, 0.4575135965364173], 
             UndirectedEdge[64, 90] -> 
             RGBColor[
              0.22549030939770529`, 0.3543349904613199, 0.936152711585956], 
             UndirectedEdge[213, 263] -> 
             RGBColor[
              0.2061321686296245, 0.3339883571370523, 0.9350502941070169], 
             UndirectedEdge[52, 53] -> 
             RGBColor[
              0.2073052253779457, 0.3352213141556316, 0.9351170979534518], 
             UndirectedEdge[245, 297] -> 
             RGBColor[
              0.20861782382323596`, 0.3366009383451798, 0.9351918484930957], 
             UndirectedEdge[189, 267] -> 
             RGBColor[
              0.20602096440657885`, 0.33387147444787646`, 0.9350439611910263],
              UndirectedEdge[145, 203] -> 
             RGBColor[
              0.9010144773435402, 0.923871728137574, 0.9891457475385399], 
             UndirectedEdge[136, 279] -> 
             RGBColor[
              0.3146411108912604, 0.44028382744269734`, 0.9415136410409652], 
             UndirectedEdge[80, 256] -> 
             RGBColor[
              0.8715548723467077, 0.4059318707085048, 0.23392588524752353`], 
             UndirectedEdge[40, 130] -> 
             RGBColor[
              0.8005184128051482, 0.7225949328330918, 0.608776500228449], 
             UndirectedEdge[83, 101] -> 
             RGBColor[
              0.7801443981327315, 0.4806917133441988, 0.4499691651133977], 
             UndirectedEdge[83, 194] -> 
             RGBColor[
              0.7930369047021925, 0.4907634374629408, 0.4512541696809177], 
             UndirectedEdge[149, 197] -> 
             RGBColor[
              0.9409227595816787, 0.803504489870005, 0.5552674312684278], 
             UndirectedEdge[23, 44] -> 
             RGBColor[
              0.6527829845870825, 0.7190887957178285, 0.883793610021852], 
             UndirectedEdge[97, 284] -> 
             RGBColor[
              0.3449079379891919, 0.4668961630433738, 0.9434276902262162], 
             UndirectedEdge[135, 276] -> 
             RGBColor[
              0.22722517815635135`, 0.3561584475236893, 0.9362515097952526], 
             UndirectedEdge[142, 150] -> 
             RGBColor[
              0.8557601994902863, 0.3776078411395296, 0.19898565697406115`], 
             UndirectedEdge[46, 214] -> 
             RGBColor[
              0.20276955741382008`, 0.3304540395473769, 0.9348587983728143], 
             UndirectedEdge[5, 243] -> 
             RGBColor[
              0.9792150980469998, 0.9514729807028455, 0.600039087887734], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.17910006852395627`, 0.30557590599185624`, 0.9335108559964074],
              UndirectedEdge[198, 243] -> 
             RGBColor[
              0.9760042846861029, 0.9810887412113525, 0.9015051286619535], 
             UndirectedEdge[13, 32] -> 
             RGBColor[
              0.6604824509868196, 0.7261357390166185, 0.898179624729629], 
             UndirectedEdge[86, 140] -> 
             RGBColor[
              0.7429383557535131, 0.3165575788102572, 0.4298769805861715], 
             UndirectedEdge[171, 275] -> 
             RGBColor[
              0.17966143058790973`, 0.3061659331134819, 0.9335428247354888], 
             UndirectedEdge[36, 250] -> 
             RGBColor[
              0.18199349180428678`, 0.3086170773131154, 0.9336756321717861], 
             UndirectedEdge[168, 203] -> 
             RGBColor[
              0.6687682561638781, 0.7369332784725033, 0.9690249189979729], 
             UndirectedEdge[17, 169] -> 
             RGBColor[
              0.654201051554568, 0.729209809683748, 0.9665623183284373], 
             UndirectedEdge[191, 246] -> 
             RGBColor[
              0.2059132617802264, 0.3337582721588391, 0.9350378276857872], 
             UndirectedEdge[17, 178] -> 
             RGBColor[
              0.4813372368134904, 0.5789969861106385, 0.9545799540531321], 
             UndirectedEdge[9, 132] -> 
             RGBColor[
              0.19792820821317225`, 0.32536547457822756`, 0.9345830906979717],
              UndirectedEdge[11, 283] -> 
             RGBColor[
              0.41881779248479195`, 0.534778825033336, 0.9485064845740085], 
             UndirectedEdge[64, 69] -> 
             RGBColor[
              0.22143670136219934`, 0.3500743914024093, 0.9359218646051097], 
             UndirectedEdge[193, 288] -> 
             RGBColor[
              0.24421454187002306`, 0.3740153459746332, 0.9372190289252349], 
             UndirectedEdge[221, 288] -> 
             RGBColor[
              0.19753047223834988`, 0.324947428850772, 0.9345604402226031], 
             UndirectedEdge[65, 264] -> 
             RGBColor[
              0.33683666992223255`, 0.4650136831097602, 0.942726350900722], 
             UndirectedEdge[27, 151] -> 
             RGBColor[
              0.7838347809145911, 0.7971566134890326, 0.6494113635450639], 
             UndirectedEdge[201, 293] -> 
             RGBColor[
              0.8634956504151338, 0.4456991780529511, 0.2067388735669856], 
             UndirectedEdge[43, 99] -> 
             RGBColor[
              0.21063039427602828`, 0.33871627749540134`, 0.9353064614030511],
              UndirectedEdge[77, 293] -> 
             RGBColor[0.6567707297143, 0.585264649646495, 0.5928277208084357],
              UndirectedEdge[61, 280] -> 
             RGBColor[
              0.2696360759953822, 0.40073499015874336`, 0.9386667476858847], 
             UndirectedEdge[20, 55] -> 
             RGBColor[
              0.21057054856025512`, 0.3386533758536862, 0.9353030532780715], 
             UndirectedEdge[208, 242] -> 
             RGBColor[
              0.18509931747274389`, 0.3118814970113848, 0.9338525043489474], 
             UndirectedEdge[29, 261] -> 
             RGBColor[
              0.21999581851421782`, 0.3485599321719316, 0.9358398084585123], 
             UndirectedEdge[12, 76] -> 
             RGBColor[
              0.3782689418854923, 0.5020592779365523, 0.9453239403802199], 
             UndirectedEdge[168, 276] -> 
             RGBColor[
              0.3208926338924916, 0.4461337879304579, 0.9418960475542608], 
             UndirectedEdge[148, 271] -> 
             RGBColor[
              0.23446623518977533`, 0.3637692575753508, 0.9366638772811222], 
             UndirectedEdge[131, 170] -> 
             RGBColor[
              0.21349214626363155`, 0.34172416027992825`, 0.9354694339451624],
              UndirectedEdge[141, 261] -> 
             RGBColor[
              0.269292107733182, 0.4003734577063236, 0.9386471592022079], 
             UndirectedEdge[129, 184] -> 
             RGBColor[
              0.19028873719925032`, 0.31733590617215746`, 0.9341480341253134],
              UndirectedEdge[111, 185] -> 
             RGBColor[
              0.5718800780485805, 0.6633170361205862, 0.9594396410911864], 
             UndirectedEdge[234, 239] -> 
             RGBColor[
              0.2158656276199601, 0.3442188396728392, 0.9356046001971543], 
             UndirectedEdge[103, 203] -> 
             RGBColor[
              0.679227364936692, 0.7459924328014227, 0.96969136416035], 
             UndirectedEdge[28, 160] -> 
             RGBColor[
              0.18961722538074013`, 0.31663010467459485`, 0.9341097925206621],
              UndirectedEdge[133, 170] -> 
             RGBColor[
              0.1914328920115927, 0.3185384854235343, 0.9342131920492509], 
             UndirectedEdge[87, 299] -> 
             RGBColor[
              0.8768452825301113, 0.42571428195008987`, 0.27555164113063385`],
              UndirectedEdge[5, 290] -> 
             RGBColor[
              0.9587118125308915, 0.8695626925266455, 0.3088146906826389], 
             UndirectedEdge[183, 253] -> 
             RGBColor[
              0.19229512745236005`, 0.31944474954066526`, 0.9342622950820396],
              UndirectedEdge[176, 245] -> 
             RGBColor[
              0.20971756780007914`, 0.3377568389926374, 0.9352544772856515], 
             UndirectedEdge[29, 190] -> 
             RGBColor[
              0.199834842245044, 0.32736946783330456`, 0.9346916706854744], 
             UndirectedEdge[159, 168] -> 
             RGBColor[
              0.3458261104083336, 0.4723404526223259, 0.943315972156065], 
             UndirectedEdge[202, 299] -> 
             RGBColor[
              0.8506117900174305, 0.3729054904185747, 0.19542866152518146`], 
             UndirectedEdge[65, 115] -> 
             RGBColor[
              0.3645960621661024, 0.4902165167425332, 0.9444527165749532], 
             UndirectedEdge[51, 142] -> 
             RGBColor[
              0.8237226416206042, 0.438239252848624, 0.4448084869772376], 
             UndirectedEdge[134, 187] -> 
             RGBColor[
              0.23476961577043198`, 0.36408812980106076`, 0.9366811543563793],
              UndirectedEdge[85, 239] -> 
             RGBColor[
              0.2348622905163943, 0.36418553683498534`, 0.936686432046062], 
             UndirectedEdge[120, 284] -> 
             RGBColor[
              0.26002401193692654`, 0.39063210139324567`, 0.9381193548575302],
              UndirectedEdge[31, 61] -> 
             RGBColor[
              0.3484538930002764, 0.47332381494877457`, 0.9435307438846312], 
             UndirectedEdge[217, 247] -> 
             RGBColor[
              0.19889732977739935`, 0.3263840827880864, 0.9346382807373675], 
             UndirectedEdge[66, 169] -> 
             RGBColor[
              0.4955403552880472, 0.5995224478502696, 0.9539323726469158], 
             UndirectedEdge[168, 293] -> 
             RGBColor[
              0.650085093471142, 0.5794738875625195, 0.5924017179788976], 
             UndirectedEdge[93, 105] -> 
             RGBColor[
              0.26248514686677915`, 0.39321891024948796`, 0.9382595128508624],
              UndirectedEdge[169, 193] -> 
             RGBColor[
              0.44215135474031986`, 0.5505814803014513, 0.9506292633518225], 
             UndirectedEdge[87, 216] -> 
             RGBColor[
              0.9086918285764461, 0.6536007359987195, 0.30538616585458284`], 
             UndirectedEdge[81, 201] -> 
             RGBColor[
              0.8600643597048547, 0.4301184883358802, 0.203875720489697], 
             UndirectedEdge[63, 244] -> 
             RGBColor[
              0.18619322197801913`, 0.31303126000398057`, 0.9339148005922362],
              UndirectedEdge[32, 150] -> 
             RGBColor[
              0.9475427884309859, 0.8298940012964792, 0.5491295264859543], 
             UndirectedEdge[95, 282] -> 
             RGBColor[
              0.36409426757402563`, 0.48782276310977274`, 0.9444924758077534],
              UndirectedEdge[126, 239] -> 
             RGBColor[
              0.2305322261132995, 0.35963436460539283`, 0.9364398412840619], 
             UndirectedEdge[149, 150] -> 
             RGBColor[
              0.901456610665, 0.644502615181237, 0.23943789960535378`], 
             UndirectedEdge[16, 222] -> 
             RGBColor[
              0.23410797445122994`, 0.3633927028240968, 0.9366434748620613], 
             UndirectedEdge[192, 262] -> 
             RGBColor[
              0.31722856394081744`, 0.4487355619302395, 0.9414511103067129], 
             UndirectedEdge[214, 276] -> 
             RGBColor[
              0.22110211631188992`, 0.34972272130061666`, 0.9359028104814688],
              UndirectedEdge[48, 100] -> 
             RGBColor[
              0.18673636136840888`, 0.31360213394030656`, 0.9339457315770161],
              UndirectedEdge[105, 143] -> 
             RGBColor[
              0.29536739445361543`, 0.4277802373181654, 0.9401321082060067], 
             UndirectedEdge[268, 279] -> 
             RGBColor[
              0.22085812887375872`, 0.34946627503344374`, 0.9358889157578143],
              UndirectedEdge[24, 106] -> 
             RGBColor[
              0.892812310133672, 0.8140725087445938, 0.6221015838690171], 
             UndirectedEdge[33, 222] -> 
             RGBColor[
              0.210965999406103, 0.33906901976570414`, 0.9353255736187255], 
             UndirectedEdge[155, 291] -> 
             RGBColor[
              0.9265943306289632, 0.845047396157727, 0.6262279650717502], 
             UndirectedEdge[99, 233] -> 
             RGBColor[
              0.20053490529032286`, 0.32810527848045334`, 0.9347315382402527],
              UndirectedEdge[237, 269] -> 
             RGBColor[
              0.8744380750181129, 0.4362072994771681, 0.23118026314495393`], 
             UndirectedEdge[85, 135] -> 
             RGBColor[
              0.22261249954375167`, 0.3513102298411313, 0.9359888245721116], 
             UndirectedEdge[126, 248] -> 
             RGBColor[
              0.22272354417989754`, 0.3514269447943572, 0.9359951483998643], 
             UndirectedEdge[188, 261] -> 
             RGBColor[
              0.30030042916823396`, 0.42860875023970424`, 0.9405725470875715],
              UndirectedEdge[37, 177] -> 
             RGBColor[
              0.2592700003340752, 0.38983958739155206`, 0.9380764150122078], 
             UndirectedEdge[160, 180] -> 
             RGBColor[
              0.19532450559808373`, 0.32262881804548893`, 0.9344348136858753],
              UndirectedEdge[23, 194] -> 
             RGBColor[
              0.8376760987270953, 0.8722472965038359, 0.8977776532625734], 
             UndirectedEdge[51, 243] -> 
             RGBColor[
              0.8993571244293498, 0.920787638740557, 0.9200070578349391], 
             UndirectedEdge[108, 208] -> 
             RGBColor[
              0.2150010029643497, 0.34331006433942324`, 0.9355553611021148], 
             UndirectedEdge[179, 251] -> 
             RGBColor[
              0.4041820274938994, 0.5204791332423994, 0.9475743793112779], 
             UndirectedEdge[26, 224] -> 
             RGBColor[
              0.21888166411978893`, 0.3473888852619182, 0.9357763590139934], 
             UndirectedEdge[106, 291] -> 
             RGBColor[
              0.8943677152627585, 0.9186085554583606, 0.9897867851648885], 
             UndirectedEdge[48, 161] -> 
             RGBColor[
              0.19723226696141938`, 0.3246339961974114, 0.9345434578732372], 
             UndirectedEdge[227, 299] -> 
             RGBColor[
              0.8633640950075484, 0.3798620775565069, 0.20395744452515618`], 
             UndirectedEdge[162, 299] -> 
             RGBColor[
              0.8762453581797867, 0.42669348450426003`, 0.3747047266637896], 
             UndirectedEdge[200, 227] -> 
             RGBColor[
              0.6591374011618665, 0.6706282245294286, 0.6126589597072597], 
             UndirectedEdge[202, 293] -> 
             RGBColor[
              0.8776334125818863, 0.5372437306244892, 0.2196066587898482], 
             UndirectedEdge[3, 155] -> 
             RGBColor[
              0.9402661035019293, 0.855471333191099, 0.6109745630706932], 
             UndirectedEdge[39, 234] -> 
             RGBColor[
              0.19793969225016772`, 0.3253775450292399, 0.9345837446968894], 
             UndirectedEdge[144, 176] -> 
             RGBColor[
              0.19591627409858087`, 0.32325080425980146`, 0.9344685140265354],
              UndirectedEdge[140, 162] -> 
             RGBColor[
              0.8753287589904273, 0.41964810147851817`, 0.3738269902449083], 
             UndirectedEdge[123, 257] -> 
             RGBColor[
              0.19133948148967972`, 0.3184403050424346, 0.9342078724582165], 
             UndirectedEdge[121, 286] -> 
             RGBColor[
              0.22317009351070355`, 0.3518962964538972, 0.9360205787236432], 
             UndirectedEdge[176, 230] -> 
             RGBColor[
              0.19313907822011844`, 0.32033179530714856`, 0.9343103568297502],
              UndirectedEdge[39, 64] -> 
             RGBColor[
              0.2185143800083959, 0.3470028463736865, 0.9357554427271977], 
             UndirectedEdge[269, 277] -> 
             RGBColor[
              0.9830880426173179, 0.9543005010685027, 0.41547009014484526`], 
             UndirectedEdge[154, 203] -> 
             RGBColor[
              0.7172113529376909, 0.7776981044453534, 0.9724416173890855], 
             UndirectedEdge[107, 137] -> 
             RGBColor[
              0.33500472849332374`, 0.4602209338581902, 0.9427270090780024], 
             UndirectedEdge[192, 218] -> 
             RGBColor[
              0.6489034320102649, 0.7179182155893853, 0.9413556495465901], 
             UndirectedEdge[247, 270] -> 
             RGBColor[
              0.20529778048290723`, 0.33311136229158844`, 0.935002776936428], 
             UndirectedEdge[28, 240] -> 
             RGBColor[
              0.18200025991928498`, 0.3086241910311017, 0.9336760176059227], 
             UndirectedEdge[31, 194] -> 
             RGBColor[
              0.552827044743554, 0.6462661114029045, 0.958649445840947], 
             UndirectedEdge[58, 187] -> 
             RGBColor[
              0.20794054512620663`, 0.3358890754926524, 0.9351532784732439], 
             UndirectedEdge[8, 121] -> 
             RGBColor[
              0.21495883648631775`, 0.3432657446975026, 0.9355529597835706], 
             UndirectedEdge[62, 186] -> 
             RGBColor[
              0.19739650616034748`, 0.3248066220088515, 0.934552811052646], 
             UndirectedEdge[271, 289] -> 
             RGBColor[
              0.23303990394891333`, 0.36227009300658086`, 0.9365826498270231],
              UndirectedEdge[236, 294] -> 
             RGBColor[
              0.38374017735760657`, 0.49740352912178454`, 0.9465549709165739],
              UndirectedEdge[115, 211] -> 
             RGBColor[
              0.3112307319414529, 0.4404795631489132, 0.9411810111605179], 
             UndirectedEdge[43, 284] -> 
             RGBColor[
              0.23327215251581435`, 0.3625142009758035, 0.9365958760393271], 
             UndirectedEdge[87, 181] -> 
             RGBColor[
              0.9897210070316473, 0.9765905802662477, 0.448420390956374], 
             UndirectedEdge[77, 205] -> 
             RGBColor[
              0.3930712028278346, 0.5148802523815419, 0.9462671273583405], 
             UndirectedEdge[132, 267] -> 
             RGBColor[
              0.19655119281637518`, 0.32391814408837505`, 0.9345046717082358],
              UndirectedEdge[108, 280] -> 
             RGBColor[
              0.2513491898337207, 0.3815143133472875, 0.9376253365720018], 
             UndirectedEdge[40, 97] -> 
             RGBColor[
              0.5690459020341019, 0.6601769695084484, 0.9597409246828227], 
             UndirectedEdge[35, 262] -> 
             RGBColor[
              0.25511664496274467`, 0.3854741475583434, 0.9378398875681493], 
             UndirectedEdge[201, 216] -> 
             RGBColor[
              0.8523973008738454, 0.3953041648713514, 0.19747813866429334`], 
             UndirectedEdge[244, 279] -> 
             RGBColor[
              0.21308524932289044`, 0.3412964857964532, 0.9354462617663373], 
             UndirectedEdge[143, 163] -> 
             RGBColor[
              0.4640224729127619, 0.5716064552084593, 0.95205347173178], 
             UndirectedEdge[102, 165] -> 
             RGBColor[
              0.20499479718794766`, 0.3327929076383356, 0.9349855224860035], 
             UndirectedEdge[7, 282] -> 
             RGBColor[
              0.6894759164963487, 0.7547973275205713, 0.9692952652700408], 
             UndirectedEdge[10, 122] -> 
             RGBColor[
              0.1877216481680741, 0.3146377328375459, 0.9340018422026558], 
             UndirectedEdge[113, 193] -> 
             RGBColor[
              0.2735981771019762, 0.40489940963349313`, 0.9388923834825018], 
             UndirectedEdge[22, 100] -> 
             RGBColor[
              0.1846021361595517, 0.3113589279281038, 0.9338241906086748], 
             UndirectedEdge[116, 254] -> 
             RGBColor[
              0.30306682721859113`, 0.43494494762898417`, 0.9406045538059649],
              UndirectedEdge[174, 298] -> 
             RGBColor[
              0.24667128016472487`, 0.3765975336885693, 0.9373589365366997], 
             UndirectedEdge[159, 271] -> 
             RGBColor[
              0.2569380089981777, 0.38738851664073326`, 0.9379436115555007], 
             UndirectedEdge[11, 101] -> 
             RGBColor[
              0.589571415450858, 0.6776035417182125, 0.9608844110153827], 
             UndirectedEdge[148, 225] -> 
             RGBColor[
              0.23694694145511846`, 0.36637663714608804`, 0.9368051498330575],
              UndirectedEdge[239, 248] -> 
             RGBColor[
              0.22976740900447992`, 0.35883049333181793`, 0.9363962860811601],
              UndirectedEdge[22, 119] -> 
             RGBColor[
              0.18469650892406414`, 0.31145811968718523`, 0.933829564998002], 
             UndirectedEdge[38, 247] -> 
             RGBColor[
              0.19193794866685385`, 0.31906933199065524`, 0.9342419542786038],
              UndirectedEdge[157, 222] -> 
             RGBColor[
              0.20198183109515816`, 0.32962608924173, 0.9348139385243031], 
             UndirectedEdge[42, 203] -> 
             RGBColor[
              0.8707781869031039, 0.5109108883536715, 0.45286742761557874`], 
             UndirectedEdge[155, 241] -> 
             RGBColor[
              0.9562190222247212, 0.8670479840915544, 0.569594959834627], 
             UndirectedEdge[103, 154] -> 
             RGBColor[
              0.45931362601150366`, 0.5710619602704519, 0.9508179830889629], 
             UndirectedEdge[88, 107] -> 
             RGBColor[
              0.3156668760979841, 0.43989562490003076`, 0.9416257469918767], 
             UndirectedEdge[58, 176] -> 
             RGBColor[
              0.19266677740688082`, 0.31983537720683475`, 0.9342834599971428],
              UndirectedEdge[48, 119] -> 
             RGBColor[
              0.1868307341329213, 0.31370132569938797`, 0.933951105966343], 
             UndirectedEdge[206, 219] -> 
             RGBColor[
              0.20337837440800324`, 0.33109394480949034`, 0.9348934695999689],
              UndirectedEdge[1, 125] -> 
             RGBColor[
              0.8241937608739676, 0.18696942461673885`, 0.17080127877684323`],
              UndirectedEdge[191, 278] -> 
             RGBColor[
              0.21400334724237668`, 0.34226146492060344`, 0.9354985460846478],
              UndirectedEdge[90, 118] -> 
             RGBColor[
              0.20219853738896398`, 0.32985386129649247`, 0.9348262796271471],
              UndirectedEdge[101, 283] -> 
             RGBColor[
              0.4765743997943146, 0.5815921216615045, 0.9531053393092228], 
             UndirectedEdge[5, 226] -> 
             RGBColor[
              0.978634912205556, 0.9512330589473125, 0.6096542687532867], 
             UndirectedEdge[3, 241] -> 
             RGBColor[
              0.9701712881509421, 0.9769533662972854, 0.9210009349471945], 
             UndirectedEdge[194, 241] -> 
             RGBColor[
              0.8360648746712487, 0.8715810139501738, 0.9244798055821426], 
             UndirectedEdge[139, 235] -> 
             RGBColor[
              0.42460849977243, 0.5421962738843169, 0.9482766560323135], 
             UndirectedEdge[40, 94] -> 
             RGBColor[
              0.7430612286953848, 0.7992043464221197, 0.9750250570405241], 
             UndirectedEdge[161, 177] -> 
             RGBColor[
              0.24681318446187503`, 0.3767466841021262, 0.9373670177764938], 
             UndirectedEdge[34, 295] -> 
             RGBColor[
              0.19030787854135572`, 0.3173560249363414, 0.9341491241964293], 
             UndirectedEdge[1, 281] -> 
             RGBColor[
              0.8719494618139193, 0.4242799404293628, 0.41747045975413577`], 
             UndirectedEdge[191, 295] -> 
             RGBColor[
              0.21214976125282442`, 0.34031322852144436`, 0.9353929871046776],
              UndirectedEdge[144, 297] -> 
             RGBColor[
              0.19481653012173772`, 0.32209490361234383`, 0.9344058852339796],
              UndirectedEdge[141, 294] -> 
             RGBColor[
              0.41494859536709305`, 0.5302055551777425, 0.9483322441534972], 
             UndirectedEdge[80, 201] -> 
             RGBColor[
              0.8898455310710746, 0.5465218886817487, 0.2514410406983216], 
             UndirectedEdge[113, 115] -> 
             RGBColor[
              0.3096806718260522, 0.43885035168813935`, 0.9410927375300542], 
             UndirectedEdge[129, 253] -> 
             RGBColor[
              0.19046881652676248`, 0.3175251809630616, 0.9341582893766117], 
             UndirectedEdge[37, 108] -> 
             RGBColor[
              0.23362687386015235`, 0.362887035599335, 0.936616076895124], 
             UndirectedEdge[265, 276] -> 
             RGBColor[
              0.23204484364859856`, 0.36122422154048306`, 0.93652598261498], 
             UndirectedEdge[59, 194] -> 
             RGBColor[
              0.8355066141794747, 0.8713501588901851, 0.9337316266626792], 
             UndirectedEdge[103, 225] -> 
             RGBColor[
              0.3244631340928782, 0.4479525778867464, 0.9421701966492211], 
             UndirectedEdge[46, 265] -> 
             RGBColor[
              0.21371228475052867`, 0.3419555397872433, 0.9354819705063254], 
             UndirectedEdge[51, 149] -> 
             RGBColor[
              0.8534002738604769, 0.7354497327448786, 0.6081721446101185], 
             UndirectedEdge[52, 124] -> 
             RGBColor[
              0.1923287617954415, 0.3194801013677844, 0.9342642105081206], 
             UndirectedEdge[82, 258] -> 
             RGBColor[
              0.47680058453134755`, 0.5830547562597531, 0.9528035659599465], 
             UndirectedEdge[45, 132] -> 
             RGBColor[
              0.24841553022607393`, 0.3784308510948885, 0.9374582689973068], 
             UndirectedEdge[74, 287] -> 
             RGBColor[
              0.2244511741859948, 0.35324279346883447`, 0.936093534372912], 
             UndirectedEdge[128, 269] -> 
             RGBColor[
              0.8876818023454497, 0.5380043911533983, 0.24386247139026226`], 
             UndirectedEdge[14, 249] -> 
             RGBColor[
              0.19382527220510481`, 0.3210530286925808, 0.9343494345620621], 
             UndirectedEdge[101, 198] -> 
             RGBColor[
              0.8059595419277743, 0.8487647451023745, 0.9551527712864303], 
             UndirectedEdge[164, 297] -> 
             RGBColor[
              0.18697714573381324`, 0.31385521357495705`, 0.9339594438904173],
              UndirectedEdge[68, 235] -> 
             RGBColor[
              0.6426752269533634, 0.7164421222894727, 0.967683202312762], 
             UndirectedEdge[108, 177] -> 
             RGBColor[
              0.2663285931328081, 0.3972586159636525, 0.9384783914298436], 
             UndirectedEdge[62, 276] -> 
             RGBColor[
              0.22152543341226616`, 0.3501676544129665, 0.9359269177640938], 
             UndirectedEdge[13, 107] -> 
             RGBColor[
              0.3708820169269006, 0.49566109481506393`, 0.9448532520538597], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.21391225518849333`, 0.3421657213964022, 0.9354933585269378], 
             UndirectedEdge[62, 135] -> 
             RGBColor[
              0.20737676424851148`, 0.33529650604442257`, 0.9351211719862982],
              UndirectedEdge[18, 35] -> 
             RGBColor[
              0.20318410319091706`, 0.3308897534428262, 0.9348824061415544], 
             UndirectedEdge[42, 202] -> 
             RGBColor[
              0.8472600681601863, 0.3557049288144153, 0.19255432478662504`], 
             UndirectedEdge[121, 255] -> 
             RGBColor[
              0.295733658786952, 0.42287002848225363`, 0.9403468487457121], 
             UndirectedEdge[128, 281] -> 
             RGBColor[
              0.8894473613175273, 0.5587764636425476, 0.4342264680798416], 
             UndirectedEdge[82, 181] -> 
             RGBColor[
              0.7998668067519439, 0.8312427160957487, 0.681983215284067], 
             UndirectedEdge[136, 204] -> 
             RGBColor[
              0.4381119186941594, 0.553069802846105, 0.9493643283826801], 
             UndirectedEdge[118, 166] -> 
             RGBColor[
              0.18740769372755933`, 0.31430774681470364`, 0.9339839629617225],
              UndirectedEdge[39, 263] -> 
             RGBColor[
              0.2058067463664483, 0.333646317705491, 0.935031761790548], 
             UndirectedEdge[52, 84] -> 
             RGBColor[
              0.1931004885069918, 0.32029123507192336`, 0.9343081592026761], 
             UndirectedEdge[129, 165] -> 
             RGBColor[
              0.20344097121398075`, 0.33115973802143944`, 0.9348970343954657],
              UndirectedEdge[141, 236] -> 
             RGBColor[
              0.2626393533607303, 0.39338099105188706`, 0.9382682946825648], 
             UndirectedEdge[97, 178] -> 
             RGBColor[
              0.353934746876465, 0.4763839115166376, 0.9439417536383794], 
             UndirectedEdge[115, 227] -> 
             RGBColor[
              0.6522166119287909, 0.6646337847447196, 0.6122179731371418], 
             UndirectedEdge[256, 281] -> 
             RGBColor[
              0.8714392611368911, 0.42035831445436117`, 0.41698189100962424`],
              UndirectedEdge[221, 297] -> 
             RGBColor[
              0.18909437890281156`, 0.31608055987591055`, 0.9340800171872259],
              UndirectedEdge[224, 262] -> 
             RGBColor[
              0.2562537795699573, 0.3866693481290222, 0.9379046457017901], 
             UndirectedEdge[73, 119] -> 
             RGBColor[
              0.18176019735719462`, 0.3083718700574992, 0.9336623463981524], 
             UndirectedEdge[3, 227] -> 
             RGBColor[
              0.9534614284413586, 0.9077863994945625, 0.6215918312510428], 
             UndirectedEdge[45, 188] -> 
             RGBColor[
              0.32789958178650086`, 0.45761720952884744`, 0.9421442779998944],
              UndirectedEdge[260, 300] -> 
             RGBColor[
              0.24190674150061214`, 0.37158970146338766`, 0.9370876031082818],
              UndirectedEdge[23, 291] -> 
             RGBColor[
              0.9581107393338224, 0.9671957118175754, 0.9095521846286824], 
             UndirectedEdge[142, 149] -> 
             RGBColor[
              0.8517916638064809, 0.3601987767340248, 0.1957058266051599], 
             UndirectedEdge[81, 97] -> 
             RGBColor[
              0.6691615275279388, 0.5770839186847934, 0.5896504800872672], 
             UndirectedEdge[181, 201] -> 
             RGBColor[
              0.8923407162696778, 0.5549387342539829, 0.2611343640187083], 
             UndirectedEdge[56, 57] -> 
             RGBColor[
              0.18951617750640207`, 0.3165238969518603, 0.9341040379937053], 
             UndirectedEdge[197, 243] -> 
             RGBColor[
              0.9868796101505515, 0.9888423958656835, 0.8671023444932484], 
             UndirectedEdge[65, 200] -> 
             RGBColor[
              0.37151685139917806`, 0.49621095652724223`, 0.9448937031450712],
              UndirectedEdge[8, 173] -> 
             RGBColor[
              0.2028775855537629, 0.3305675839718365, 0.9348649504155706], 
             UndirectedEdge[53, 273] -> 
             RGBColor[
              0.2274037724911021, 0.35634616149304726`, 0.9362616804784101], 
             UndirectedEdge[26, 253] -> 
             RGBColor[
              0.21047277090696587`, 0.3385506053406179, 0.9352974849853658], 
             UndirectedEdge[114, 206] -> 
             RGBColor[
              0.2307773334017795, 0.35989198790628496`, 0.936453799781537], 
             UndirectedEdge[9, 45] -> 
             RGBColor[
              0.24944742731977937`, 0.3795154403664275, 0.9375170340102383], 
             UndirectedEdge[47, 190] -> 
             RGBColor[
              0.1942570496898653, 0.32150685420533776`, 0.9343740236510617], 
             UndirectedEdge[191, 282] -> 
             RGBColor[
              0.3340044293562811, 0.4561964353369906, 0.9427789040351794], 
             UndirectedEdge[59, 155] -> 
             RGBColor[
              0.9556607617329471, 0.8668171290315656, 0.5788467809151635], 
             UndirectedEdge[214, 265] -> 
             RGBColor[
              0.21177311264038245`, 0.33991734694886655`, 0.9353715375234006],
              UndirectedEdge[167, 282] -> 
             RGBColor[
              0.674157084988882, 0.6138860835498305, 0.5969373306942671], 
             UndirectedEdge[28, 221] -> 
             RGBColor[
              0.18483282648833058`, 0.31160139809026205`, 0.9338373280816231],
              UndirectedEdge[136, 197] -> 
             RGBColor[
              0.689478603616865, 0.751552751257122, 0.9111273992783655], 
             UndirectedEdge[121, 234] -> 
             RGBColor[
              0.20980230497718771`, 0.3378459031384259, 0.9352593029425303], 
             UndirectedEdge[141, 146] -> 
             RGBColor[
              0.24693839801171524`, 0.3768782914820059, 0.9373741485029203], 
             UndirectedEdge[32, 167] -> 
             RGBColor[
              0.947679092916505, 0.830434403160785, 0.5492392002744804], 
             UndirectedEdge[101, 136] -> 
             RGBColor[
              0.5199717589850226, 0.6194511898467974, 0.9558606779112371], 
             UndirectedEdge[91, 274] -> 
             RGBColor[
              0.4766026768727841, 0.5859665496480654, 0.9519390550580074], 
             UndirectedEdge[84, 295] -> 
             RGBColor[
              0.19219536521772562`, 0.31933989310677346`, 0.9342566137703623],
              UndirectedEdge[73, 122] -> 
             RGBColor[
              0.18385458485627515`, 0.31057320411086997`, 0.9337816186678564],
              UndirectedEdge[157, 248] -> 
             RGBColor[
              0.20224840910221648`, 0.3299062796291701, 0.9348291197474383], 
             UndirectedEdge[125, 167] -> 
             RGBColor[
              0.859356989051198, 0.4049161457343329, 0.20241604569242247`], 
             UndirectedEdge[20, 208] -> 
             RGBColor[
              0.20416035452872197`, 0.331915855496769, 0.9349380022110079], 
             UndirectedEdge[77, 103] -> 
             RGBColor[
              0.41755616548084906`, 0.5360878963815774, 0.9478272875273883], 
             UndirectedEdge[46, 276] -> 
             RGBColor[
              0.22304128842203616`, 0.35176091413899346`, 0.9360132434643936],
              UndirectedEdge[3, 291] -> 
             RGBColor[
              0.940546596555184, 0.9549527783634579, 0.9776339401843177], 
             UndirectedEdge[79, 297] -> 
             RGBColor[
              0.1875669958551452, 0.3144751834511347, 0.9339930349822221], 
             UndirectedEdge[18, 262] -> 
             RGBColor[
              0.25190729178629806`, 0.38210091388515394`, 0.9376571196525632],
              UndirectedEdge[127, 225] -> 
             RGBColor[
              0.28821593818422175`, 0.41655707862770686`, 0.9398605573780583],
              UndirectedEdge[109, 292] -> 
             RGBColor[
              0.8832633694480486, 0.907223500639492, 0.873440789605417], 
             UndirectedEdge[267, 287] -> 
             RGBColor[
              0.2196035170740144, 0.34814759848492993`, 0.9358174674718507], 
             UndirectedEdge[218, 262] -> 
             RGBColor[
              0.6355147016275733, 0.7058679616598169, 0.9405191403190352], 
             UndirectedEdge[207, 225] -> 
             RGBColor[
              0.20644219198451136`, 0.33431421133965444`, 0.9350679494784392],
              UndirectedEdge[203, 299] -> 
             RGBColor[
              0.8581709631436525, 0.41400624201784997`, 0.4407947359057055], 
             UndirectedEdge[142, 163] -> 
             RGBColor[
              0.7603405238297619, 0.3885080681094508, 0.43863923535829075`], 
             UndirectedEdge[2, 54] -> 
             RGBColor[
              0.22131402237840694`, 0.34994544801214666`, 0.9359148782184701],
              UndirectedEdge[90, 195] -> 
             RGBColor[
              0.19970007804544365`, 0.3272278221149808, 0.934683996063673], 
             UndirectedEdge[88, 93] -> 
             RGBColor[
              0.23199426054362918`, 0.36117105549000617`, 0.9365231019819831],
              UndirectedEdge[77, 82] -> 
             RGBColor[
              0.5136111712070213, 0.6149382362843397, 0.9551491039925967], 
             UndirectedEdge[167, 168] -> 
             RGBColor[
              0.6540467218133117, 0.5964674977433942, 0.5956559161356156], 
             UndirectedEdge[18, 26] -> 
             RGBColor[
              0.21453517633612967`, 0.3428204510180499, 0.9355288329647664], 
             UndirectedEdge[129, 224] -> 
             RGBColor[
              0.19887770973958555`, 0.32636346088436186`, 0.9346371634052393],
              UndirectedEdge[38, 289] -> 
             RGBColor[
              0.21478203632197956`, 0.34307991651500525`, 0.935542891275764], 
             UndirectedEdge[31, 241] -> 
             RGBColor[
              0.7028863769460394, 0.7632151146504713, 0.9137909719699326], 
             UndirectedEdge[5, 197] -> 
             RGBColor[
              0.9786771999205136, 0.9512505460041922, 0.6089534518793391], 
             UndirectedEdge[59, 241] -> 
             RGBColor[
              0.9855659463819599, 0.9882991621377519, 0.8888731527916648], 
             UndirectedEdge[155, 226] -> 
             RGBColor[
              0.9562854870849291, 0.8670754690193194, 0.5684934650954372], 
             UndirectedEdge[15, 186] -> 
             RGBColor[
              0.22574603195372214`, 0.35460377108144014`, 0.9361672746072136],
              UndirectedEdge[198, 256] -> 
             RGBColor[
              0.866815756563354, 0.4169101123137112, 0.4248082782495014], 
             UndirectedEdge[72, 291] -> 
             RGBColor[
              0.8619019121087841, 0.4662467231049401, 0.44816350088512813`], 
             UndirectedEdge[230, 297] -> 
             RGBColor[
              0.19203933424327527`, 0.319175894659691, 0.9342477280371944], 
             UndirectedEdge[138, 231] -> 
             RGBColor[
              0.23123426787294182`, 0.3603722550067954, 0.9364798215236958], 
             UndirectedEdge[54, 165] -> 
             RGBColor[
              0.2309155676527057, 0.3600372808685661, 0.936461672017628], 
             UndirectedEdge[103, 167] -> 
             RGBColor[
              0.6645058305861254, 0.6055266520723135, 0.5963223612979925], 
             UndirectedEdge[78, 131] -> 
             RGBColor[
              0.21176961520445978`, 0.33991367092196156`, 0.9353713383495988],
              UndirectedEdge[16, 239] -> 
             RGBColor[
              0.2421832343916902, 0.3718803130225725, 0.9371033489693941], 
             UndirectedEdge[12, 87] -> 
             RGBColor[
              0.7113840896935575, 0.7671448961592477, 0.7220908533867955], 
             UndirectedEdge[125, 281] -> 
             RGBColor[
              0.8829501729358756, 0.5088362266550703, 0.4280047531480473], 
             UndirectedEdge[148, 205] -> 
             RGBColor[
              0.3093284827197305, 0.43657270388582725`, 0.9411425228750159], 
             UndirectedEdge[103, 269] -> 
             RGBColor[
              0.6972472679550255, 0.7302486647196956, 0.6491594274470608], 
             UndirectedEdge[40, 169] -> 
             RGBColor[
              0.6469863029423364, 0.7235735932337524, 0.9658432196124291], 
             UndirectedEdge[38, 53] -> 
             RGBColor[
              0.2009984379794762, 0.32859248072642344`, 0.9347579357411648], 
             UndirectedEdge[118, 285] -> 
             RGBColor[
              0.19420033164892994`, 0.32144723994818314`, 0.9343707936425373],
              UndirectedEdge[74, 267] -> 
             RGBColor[
              0.2010537316252639, 0.328650597853966, 0.9347610846324927], 
             UndirectedEdge[3, 200] -> 
             RGBColor[
              0.659894342148658, 0.7282185404316961, 0.9534476666394777], 
             UndirectedEdge[124, 273] -> 
             RGBColor[
              0.2124273089085979, 0.3406049487052001, 0.9354087930330789], 
             UndirectedEdge[131, 182] -> 
             RGBColor[
              0.24187571808972635`, 0.3715570938915489, 0.9370858363709268], 
             UndirectedEdge[62, 207] -> 
             RGBColor[
              0.19348238664909873`, 0.3206926342330184, 0.9343299077369014], 
             UndirectedEdge[75, 262] -> 
             RGBColor[
              0.318384602518598, 0.4497368644421247, 0.9415247720626443], 
             UndirectedEdge[197, 283] -> 
             RGBColor[
              0.646081244426157, 0.713693683071829, 0.9083720606763512], 
             UndirectedEdge[246, 278] -> 
             RGBColor[
              0.1925398971260588, 0.3197020179870163, 0.9342762343528525], 
             UndirectedEdge[225, 265] -> 
             RGBColor[
              0.22515623507617133`, 0.35398385716785236`, 0.9361336865475633],
              UndirectedEdge[101, 204] -> 
             RGBColor[
              0.5654681824695174, 0.6580354513456885, 0.9589869162220399], 
             UndirectedEdge[87, 140] -> 
             RGBColor[
              0.8759286833407519, 0.418668898924348, 0.2746739047117526], 
             UndirectedEdge[57, 247] -> 
             RGBColor[
              0.18871603896391997`, 0.3156829006119979, 0.9340584712874099], 
             UndirectedEdge[40, 66] -> 
             RGBColor[
              0.5377876957046065, 0.6331026822689709, 0.9577491794160538], 
             UndirectedEdge[167, 293] -> 
             RGBColor[
              0.9037203948195764, 0.6547034053372311, 0.24132279457904], 
             UndirectedEdge[42, 140] -> 
             RGBColor[
              0.8308428229488108, 0.23807702936156347`, 0.1771684281287546], 
             UndirectedEdge[107, 150] -> 
             RGBColor[
              0.657942354371067, 0.5994193570949246, 0.595803153810185], 
             UndirectedEdge[91, 143] -> 
             RGBColor[
              0.39852667636969663`, 0.5184340170227889, 0.9468974027089019], 
             UndirectedEdge[91, 142] -> 
             RGBColor[
              0.7166766594677184, 0.35305977598567057`, 0.4352018560097054], 
             UndirectedEdge[44, 283] -> 
             RGBColor[
              0.3110200455084933, 0.44354120705361005`, 0.9410488029197814], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.19626308316666907`, 0.323615322579327, 0.9344882642899051], 
             UndirectedEdge[199, 233] -> 
             RGBColor[
              0.20189518711453486`, 0.32953502092454917`, 0.9348090042777849],
              UndirectedEdge[249, 286] -> 
             RGBColor[
              0.2141737173623244, 0.342440534718758, 0.9355082484109388], 
             UndirectedEdge[48, 266] -> 
             RGBColor[
              0.19547981769013628`, 0.32279206090159157`, 0.934443658479754], 
             UndirectedEdge[113, 169] -> 
             RGBColor[
              0.4361857848874334, 0.5443112881470928, 0.9502895329739705], 
             UndirectedEdge[18, 33] -> 
             RGBColor[
              0.20024058888485757`, 0.32779593327757145`, 0.9347147773563635],
              UndirectedEdge[269, 293] -> 
             RGBColor[
              0.9364618321884765, 0.7794254179846133, 0.2941598607281082], 
             UndirectedEdge[189, 257] -> 
             RGBColor[
              0.1999558217805158, 0.327496624995631, 0.9346985602910465], 
             UndirectedEdge[11, 197] -> 
             RGBColor[
              0.7590782600827003, 0.809705103128537, 0.9161511323825111], 
             UndirectedEdge[221, 296] -> 
             RGBColor[
              0.18670137270172213`, 0.31356535863320917`, 0.9339437390242094],
              UndirectedEdge[126, 157] -> 
             RGBColor[
              0.20301322621103607`, 0.33071015090274497`, 0.93487267495034], 
             UndirectedEdge[24, 87] -> 
             RGBColor[
              0.9584560317231505, 0.8616047223377981, 0.3765513268644449], 
             UndirectedEdge[53, 137] -> 
             RGBColor[
              0.2387057780017381, 0.36822528587326325`, 0.936905312972422], 
             UndirectedEdge[27, 140] -> 
             RGBColor[
              0.8681598345506768, 0.3927281505486404, 0.22192545531754573`], 
             UndirectedEdge[115, 200] -> 
             RGBColor[
              0.35864952563609026`, 0.485065925681853, 0.9440738085255767], 
             UndirectedEdge[1, 5] -> 
             RGBColor[
              0.8694664994809802, 0.4010878979497081, 0.22431948647786654`], 
             UndirectedEdge[40, 42] -> 
             RGBColor[
              0.7881477040684427, 0.44575263857904807`, 0.445649103589277], 
             UndirectedEdge[82, 167] -> 
             RGBColor[
              0.7605608363122977, 0.684376991975076, 0.6036441777632009], 
             UndirectedEdge[52, 57] -> 
             RGBColor[
              0.18920436008623348`, 0.3161961570728968, 0.9340862804529193], 
             UndirectedEdge[27, 203] -> 
             RGBColor[
              0.9534832977574548, 0.9312795143111227, 0.6643276822065549], 
             UndirectedEdge[251, 270] -> 
             RGBColor[
              0.24922321837913736`, 0.37927978255414485`, 0.9375042656427561],
              UndirectedEdge[200, 264] -> 
             RGBColor[
              0.3308901333922204, 0.45986309204908005`, 0.9423474428513454], 
             UndirectedEdge[84, 271] -> 
             RGBColor[
              0.20505156873545605`, 0.33285257813429087`, 0.9349887555416483],
              UndirectedEdge[80, 145] -> 
             RGBColor[
              0.9218561356347152, 0.9176464031707863, 0.6795757972164687], 
             UndirectedEdge[199, 259] -> 
             RGBColor[
              0.19177802866162308`, 0.31890124592564373`, 0.9342328470708863],
              UndirectedEdge[273, 274] -> 
             RGBColor[
              0.3509883555182567, 0.4717110997619036, 0.9438949792783465], 
             UndirectedEdge[281, 294] -> 
             RGBColor[
              0.7572554970898742, 0.8088426757639791, 0.9389810177450694], 
             UndirectedEdge[18, 183] -> 
             RGBColor[
              0.19635753288152386`, 0.32371459521809726`, 0.9344936430614402],
              UndirectedEdge[77, 269] -> 
             RGBColor[
              0.6934737954253698, 0.7269802724747518, 0.6489189851142219], 
             UndirectedEdge[134, 144] -> 
             RGBColor[
              0.22121948408189393`, 0.34984608226843733`, 0.9359094944023405],
              UndirectedEdge[200, 210] -> 
             RGBColor[
              0.4186246829308158, 0.5365148469090834, 0.9480331221442837], 
             UndirectedEdge[87, 151] -> 
             RGBColor[
              0.7954880540997038, 0.8360677360525939, 0.7285340376363743], 
             UndirectedEdge[109, 290] -> 
             RGBColor[
              0.9696110495252712, 0.9082697495604787, 0.5222701846474617], 
             UndirectedEdge[247, 278] -> 
             RGBColor[
              0.19919319876560948`, 0.3266950598538726, 0.9346551300385472], 
             UndirectedEdge[156, 205] -> 
             RGBColor[
              0.38342561820827703`, 0.5065257317852604, 0.945652519235638], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.18357179140558838`, 0.31027597026405784`, 0.9337655139991952],
              UndirectedEdge[64, 121] -> 
             RGBColor[
              0.2303769927354159, 0.3594712044828725, 0.9364310009728385], 
             UndirectedEdge[106, 264] -> 
             RGBColor[
              0.579035279379287, 0.6606770441091168, 0.9634331593756991], 
             UndirectedEdge[91, 107] -> 
             RGBColor[
              0.44931704433721525`, 0.562597259364136, 0.9501274523636514], 
             UndirectedEdge[7, 299] -> 
             RGBColor[
              0.8585691612482524, 0.41430321751227117`, 0.4401206903813164], 
             UndirectedEdge[160, 221] -> 
             RGBColor[
              0.19098000658392586`, 0.31806247412446187`, 0.9341874008941293],
              UndirectedEdge[8, 234] -> 
             RGBColor[
              0.19931169581116837`, 0.32681960776190155`, 0.934661878269991], 
             UndirectedEdge[49, 174] -> 
             RGBColor[
              0.22141328802375174`, 0.3500497824992095, 0.9359205312501221], 
             UndirectedEdge[79, 245] -> 
             RGBColor[
              0.20419166956427437`, 0.3319487695846225, 0.9349397855559562], 
             UndirectedEdge[13, 147] -> 
             RGBColor[
              0.27334324637888757`, 0.4023623173416999, 0.9389609500302152], 
             UndirectedEdge[1, 197] -> 
             RGBColor[
              0.8745761742166813, 0.4260008413916001, 0.4023616575482095], 
             UndirectedEdge[129, 175] -> 
             RGBColor[
              0.18584814501363772`, 0.3126685622352725, 0.9338951489696101], 
             UndirectedEdge[116, 283] -> 
             RGBColor[
              0.29658629715284524`, 0.4290613813379507, 0.9402015229115228], 
             UndirectedEdge[62, 265] -> 
             RGBColor[
              0.2121964297407587, 0.3403622800612163, 0.9353956448060256], 
             UndirectedEdge[31, 291] -> 
             RGBColor[
              0.6732616853502813, 0.7412145267166439, 0.970423977207056], 
             UndirectedEdge[92, 277] -> 
             RGBColor[
              0.8853735220807035, 0.49151915194709656`, 0.27879642661699433`],
              UndirectedEdge[124, 289] -> 
             RGBColor[
              0.2146845283282537, 0.3429774294312355, 0.9355373383397714], 
             UndirectedEdge[80, 277] -> 
             RGBColor[
              0.9859097978901593, 0.963818944183442, 0.4264320765360633], 
             UndirectedEdge[119, 244] -> 
             RGBColor[
              0.18517767786647377`, 0.3119638587535308, 0.9338569668574466], 
             UndirectedEdge[252, 268] -> 
             RGBColor[
              0.22149590633125682`, 0.35013661957870057`, 0.9359252362405117],
              UndirectedEdge[3, 194] -> 
             RGBColor[
              0.8201119559484569, 0.8600043630497185, 0.9658594088182089], 
             UndirectedEdge[1, 237] -> 
             RGBColor[
              0.820820491401125, 0.16104099727236243`, 0.16757103212008623`], 
             UndirectedEdge[149, 281] -> 
             RGBColor[
              0.9369826909775356, 0.800923138426649, 0.5779306345773171], 
             UndirectedEdge[29, 209] -> 
             RGBColor[
              0.1878554243304431, 0.3147783400660943, 0.9340094605571987], 
             UndirectedEdge[123, 287] -> 
             RGBColor[
              0.22080206667647367`, 0.3494073501095485, 0.9358857230986155], 
             UndirectedEdge[17, 81] -> 
             RGBColor[
              0.7965640174649642, 0.6796969932787943, 0.60028868050202], 
             UndirectedEdge[176, 187] -> 
             RGBColor[
              0.20946640578711895`, 0.33749285179242483`, 0.9352401739805742],
              UndirectedEdge[246, 270] -> 
             RGBColor[
              0.19864447884335656`, 0.3261183204247322, 0.9346238812507333], 
             UndirectedEdge[45, 131] -> 
             RGBColor[
              0.2646712879230951, 0.39551668310902466`, 0.9383840103499137], 
             UndirectedEdge[4, 158] -> 
             RGBColor[
              0.2067416614051505, 0.33462897268820413`, 0.9350850038189193], 
             UndirectedEdge[169, 264] -> 
             RGBColor[
              0.450474457220526, 0.5593295887233245, 0.9511032517251437], 
             UndirectedEdge[42, 181] -> 
             RGBColor[
              0.8871678109624904, 0.5151775172813806, 0.25618078405458466`], 
             UndirectedEdge[8, 263] -> 
             RGBColor[
              0.20717874992744892`, 0.3350883804381527, 0.9351098953636496], 
             UndirectedEdge[145, 205] -> 
             RGBColor[
              0.6186317877643385, 0.696027939962637, 0.9659619530693695], 
             UndirectedEdge[167, 269] -> 
             RGBColor[
              0.9404234605306463, 0.796419028165488, 0.2974140588848261], 
             UndirectedEdge[187, 288] -> 
             RGBColor[
              0.2168027551458141, 0.3452038201198287, 0.9356579682233956], 
             UndirectedEdge[47, 131] -> 
             RGBColor[
              0.20675371716772, 0.33464164405904423`, 0.9350856903767627], 
             UndirectedEdge[43, 97] -> 
             RGBColor[
              0.33722237523593046`, 0.45881814929687276`, 0.9429900087971892],
              UndirectedEdge[104, 114] -> 
             RGBColor[
              0.28710993911342014`, 0.4166656473064825, 0.939751033226302], 
             UndirectedEdge[26, 129] -> 
             RGBColor[
              0.20909164827758553`, 0.33709895788890676`, 0.9352188320948104],
              UndirectedEdge[28, 79] -> 
             RGBColor[
              0.1833054434406642, 0.3099960216654862, 0.9337503458766192], 
             UndirectedEdge[53, 247] -> 
             RGBColor[
              0.2068169042556322, 0.33470805769473266`, 0.9350892887879424], 
             UndirectedEdge[150, 281] -> 
             RGBColor[
              0.9429354945032435, 0.8270367350349062, 0.582850380130669], 
             UndirectedEdge[76, 248] -> 
             RGBColor[
              0.2744382407386017, 0.40410226692421763`, 0.9390017406595347], 
             UndirectedEdge[194, 210] -> 
             RGBColor[
              0.5788422967306146, 0.6683006695271059, 0.9604448643230148], 
             UndirectedEdge[60, 265] -> 
             RGBColor[
              0.2549916258941355, 0.3853427445905684, 0.9378327679171411], 
             UndirectedEdge[78, 178] -> 
             RGBColor[
              0.2265713684695162, 0.3554712520888972, 0.9362142763008121], 
             UndirectedEdge[120, 190] -> 
             RGBColor[
              0.24175240008128845`, 0.37142747884586735`, 0.937078813592779], 
             UndirectedEdge[96, 267] -> 
             RGBColor[
              0.19857826997424566`, 0.3260487307054119, 0.9346201107535846], 
             UndirectedEdge[159, 212] -> 
             RGBColor[
              0.2623047179263146, 0.3930292679932042, 0.9382492376896236], 
             UndirectedEdge[34, 147] -> 
             RGBColor[
              0.19854534996450335`, 0.32601412968792354`, 0.9346182360077306],
              UndirectedEdge[41, 250] -> 
             RGBColor[
              0.18562426514456906`, 0.3124332502980778, 0.9338823993422674], 
             UndirectedEdge[146, 236] -> 
             RGBColor[
              0.2157299800022288, 0.3440762654260479, 0.9355968752659971], 
             UndirectedEdge[82, 103] -> 
             RGBColor[
              0.5173846437366769, 0.6182066285292835, 0.9553895463254356], 
             UndirectedEdge[179, 289] -> 
             RGBColor[
              0.383100677252795, 0.49832129750419296`, 0.9463738276021099], 
             UndirectedEdge[124, 247] -> 
             RGBColor[
              0.191840440673128, 0.3189668449068855, 0.9342364013426112], 
             UndirectedEdge[162, 227] -> 
             RGBColor[
              0.9720263822129245, 0.9204431940139248, 0.5369240475267748], 
             UndirectedEdge[156, 191] -> 
             RGBColor[
              0.31093411780431135`, 0.4362140910182484, 0.9413088841833633], 
             UndirectedEdge[1, 51] -> 
             RGBColor[
              0.8162278504025469, 0.38063100330818245`, 0.4376314664426699], 
             UndirectedEdge[23, 198] -> 
             RGBColor[
              0.9769688580402975, 0.9814876170817164, 0.8855196519471269], 
             UndirectedEdge[77, 159] -> 
             RGBColor[
              0.3525117466514917, 0.4781312147063014, 0.9437419749856031], 
             UndirectedEdge[2, 238] -> 
             RGBColor[
              0.19301734075154908`, 0.3202038415090809, 0.9343034240610095], 
             UndirectedEdge[113, 245] -> 
             RGBColor[
              0.24643755239072743`, 0.3763518709789012, 0.9373456260857398], 
             UndirectedEdge[167, 201] -> 
             RGBColor[
              0.8661367359765803, 0.45702825150686766`, 0.20890833900479755`],
              UndirectedEdge[125, 150] -> 
             RGBColor[
              0.8592661193941853, 0.40455587782479563`, 0.20234292983340507`],
              UndirectedEdge[142, 198] -> 
             RGBColor[
              0.8748207484584395, 0.4784399878291542, 0.43247386752858047`], 
             UndirectedEdge[34, 52] -> 
             RGBColor[
              0.1912130018306219, 0.3183073669014913, 0.934200669628743], 
             UndirectedEdge[13, 251] -> 
             RGBColor[
              0.3094480150189227, 0.44031071835692515`, 0.9410170631920465], 
             UndirectedEdge[120, 188] -> 
             RGBColor[
              0.317477361422549, 0.44666279511939655`, 0.9415507479684607], 
             UndirectedEdge[67, 173] -> 
             RGBColor[
              0.1901069718936137, 0.3171448593113474, 0.934137682860055], 
             UndirectedEdge[20, 280] -> 
             RGBColor[
              0.24050854139809294`, 0.3701201045046333, 0.9370079776808949], 
             UndirectedEdge[32, 107] -> 
             RGBColor[
              0.6980757286113448, 0.7586971466019095, 0.9005750351374335], 
             UndirectedEdge[189, 287] -> 
             RGBColor[
              0.22941840696730975`, 0.35846367006274493`, 0.9363764109314454],
              UndirectedEdge[159, 205] -> 
             RGBColor[
              0.33180025652813283`, 0.4601919629512097, 0.9424222571493942], 
             UndirectedEdge[66, 86] -> 
             RGBColor[
              0.49025940765542825`, 0.5952351366581299, 0.9535166371045274], 
             UndirectedEdge[119, 266] -> 
             RGBColor[
              0.1895006672172379, 0.3165075946545396, 0.9341031547056828], 
             UndirectedEdge[28, 230] -> 
             RGBColor[
              0.1877777818287943, 0.3146967328740425, 0.9340050389315915], 
             UndirectedEdge[83, 142] -> 
             RGBColor[
              0.8410135879259631, 0.3162539858335876, 0.18690796415711172`], 
             UndirectedEdge[191, 217] -> 
             RGBColor[
              0.21370747825416658`, 0.3419504878548173, 0.9354816967834682], 
             UndirectedEdge[43, 233] -> 
             RGBColor[
              0.2154911007768475, 0.3438251882143545, 0.9355832714475019], 
             UndirectedEdge[113, 297] -> 
             RGBColor[
              0.22981287868159825`, 0.35887828484541334`, 0.9363988755120056],
              UndirectedEdge[158, 207] -> 
             RGBColor[
              0.189116703595207, 0.3161040245430854, 0.9340812885454315], 
             UndirectedEdge[40, 201] -> 
             RGBColor[
              0.7933206093756301, 0.4855138555516503, 0.4506026835534007], 
             UndirectedEdge[194, 226] -> 
             RGBColor[
              0.8361313395314567, 0.8716084988779389, 0.9233783108429527], 
             UndirectedEdge[134, 230] -> 
             RGBColor[
              0.21844228820343148`, 0.34692707331578443`, 0.9357513372055553],
              UndirectedEdge[134, 264] -> 
             RGBColor[
              0.27050450497484707`, 0.4016477640777385, 0.9387162034315397], 
             UndirectedEdge[59, 226] -> 
             RGBColor[
              0.9856324112421679, 0.988326647065517, 0.887771658052475], 
             UndirectedEdge[42, 201] -> 
             RGBColor[
              0.84019118707681, 0.30993265252864627`, 0.18612043217519372`], 
             UndirectedEdge[217, 295] -> 
             RGBColor[
              0.19848052761044668`, 0.32594599728383544`, 0.9346145444705631],
              UndirectedEdge[45, 94] -> 
             RGBColor[
              0.5484117816822776, 0.636917841037437, 0.9603911500045271], 
             UndirectedEdge[197, 254] -> 
             RGBColor[
              0.6525617744919028, 0.7195772493628625, 0.9087750915707931], 
             UndirectedEdge[30, 189] -> 
             RGBColor[
              0.23256614809149867`, 0.36177214556258186`, 0.9365556701318023],
              UndirectedEdge[92, 179] -> 
             RGBColor[
              0.7286220477197832, 0.3701780038392919, 0.4370908994932349], 
             UndirectedEdge[134, 288] -> 
             RGBColor[
              0.22683219740980134`, 0.35574539984264686`, 0.9362291301230996],
              UndirectedEdge[59, 83] -> 
             RGBColor[
              0.8927042858426667, 0.5685755362546596, 0.4275164011539326], 
             UndirectedEdge[10, 22] -> 
             RGBColor[
              0.18947218593303478`, 0.31647765901902436`, 0.9341015327386817],
              UndirectedEdge[148, 168] -> 
             RGBColor[
              0.32335433659993124`, 0.4487211935569434, 0.9420362378816867], 
             UndirectedEdge[130, 216] -> 
             RGBColor[
              0.8815768726528278, 0.553695183078948, 0.2228219191679405], 
             UndirectedEdge[158, 196] -> 
             RGBColor[
              0.1980026870183727, 0.32544375652472224`, 0.9345873321557463], 
             UndirectedEdge[203, 237] -> 
             RGBColor[
              0.8624248063392239, 0.4467031448649862, 0.4448682209538134], 
             UndirectedEdge[160, 193] -> 
             RGBColor[
              0.23766407621559904`, 0.36713039124832314`, 0.9368459895967611],
              UndirectedEdge[38, 88] -> 
             RGBColor[
              0.20448897001762012`, 0.33226125121102634`, 0.9349567163769577],
              UndirectedEdge[22, 73] -> 
             RGBColor[
              0.1856051226212358, 0.3124131302923484, 0.9338813092038822], 
             UndirectedEdge[181, 227] -> 
             RGBColor[
              0.9694992257478029, 0.9078122736758734, 0.34102909604815745`], 
             UndirectedEdge[85, 255] -> 
             RGBColor[
              0.2990831810082368, 0.42639058870879876`, 0.9405375990810403], 
             UndirectedEdge[106, 227] -> 
             RGBColor[
              0.907282547148933, 0.8714421765894653, 0.6337446762316135], 
             UndirectedEdge[131, 261] -> 
             RGBColor[
              0.23707213530482818`, 0.36650822381988146`, 0.9368122794375908],
              UndirectedEdge[81, 94] -> 
             RGBColor[
              0.8431768541892217, 0.7161112955984645, 0.6049346124449686], 
             UndirectedEdge[77, 154] -> 
             RGBColor[
              0.455540153481848, 0.5677935680255081, 0.950577540756124], 
             UndirectedEdge[167, 277] -> 
             RGBColor[
              0.9503466052484179, 0.8295784884211206, 0.3626330239957771], 
             UndirectedEdge[113, 176] -> 
             RGBColor[
              0.23091262265844142`, 0.3600341854928709, 0.9364615043045614], 
             UndirectedEdge[4, 276] -> 
             RGBColor[
              0.23095575836688206`, 0.36007952385740394`, 0.9364639608193436],
              UndirectedEdge[101, 243] -> 
             RGBColor[
              0.8173727655187092, 0.8567408344553589, 0.91183562312612], 
             UndirectedEdge[52, 271] -> 
             RGBColor[
              0.21068413741610115`, 0.3387727649431298, 0.9353095219953723], 
             UndirectedEdge[37, 71] -> 
             RGBColor[
              0.22494256325409756`, 0.3537592745352769, 0.9361215182533955], 
             UndirectedEdge[83, 291] -> 
             RGBColor[
              0.8733266651066773, 0.5540623810054337, 0.4591038572583237], 
             UndirectedEdge[80, 149] -> 
             RGBColor[
              0.9371561077922606, 0.7792834728078644, 0.30334662593416606`], 
             UndirectedEdge[104, 206] -> 
             RGBColor[
              0.2787552105581772, 0.4078842978745366, 0.9392752437947942], 
             UndirectedEdge[61, 108] -> 
             RGBColor[
              0.25897235282054676`, 0.38952674098289125`, 0.9380594644266425],
              UndirectedEdge[115, 264] -> 
             RGBColor[
              0.32396934415914475`, 0.453868652264371, 0.9419064562812274], 
             UndirectedEdge[38, 52] -> 
             RGBColor[
              0.19242626978916738`, 0.3195825884515542, 0.934269763444113], 
             UndirectedEdge[33, 285] -> 
             RGBColor[
              0.20009304762604624`, 0.3276408580599046, 0.934706375099942], 
             UndirectedEdge[100, 122] -> 
             RGBColor[
              0.18285159839459103`, 0.3095190017466254, 0.933724500072649], 
             UndirectedEdge[205, 269] -> 
             RGBColor[
              0.6727623053020111, 0.7090410207196602, 0.647599267278013], 
             UndirectedEdge[177, 252] -> 
             RGBColor[
              0.2649570005472917, 0.39581698519228203`, 0.9384002812611878], 
             UndirectedEdge[152, 244] -> 
             RGBColor[
              0.1860116480511821, 0.312840414294423, 0.9339044602257174], 
             UndirectedEdge[10, 71] -> 
             RGBColor[
              0.20685989156236995`, 0.3347532400796667, 0.9350917368514671], 
             UndirectedEdge[233, 259] -> 
             RGBColor[
              0.1952784533382303, 0.32258041420050104`, 0.9344321910778048], 
             UndirectedEdge[130, 299] -> 
             RGBColor[
              0.849730326606493, 0.32580872903031854`, 0.19298739444399152`], 
             UndirectedEdge[81, 86] -> 
             RGBColor[
              0.7418209808035544, 0.6361932312179576, 0.5953370394744854], 
             UndirectedEdge[205, 282] -> 
             RGBColor[
              0.40649592976024684`, 0.5265080761040026, 0.947122539087454], 
             UndirectedEdge[176, 297] -> 
             RGBColor[
              0.19309289409094996`, 0.3202832528591496, 0.9343077267119173], 
             UndirectedEdge[92, 128] -> 
             RGBColor[
              0.8360165444918075, 0.27784452028027223`, 0.18212278972121096`],
              UndirectedEdge[166, 285] -> 
             RGBColor[
              0.19288702957547718`, 0.3200668762008235, 0.9342960030323104], 
             UndirectedEdge[132, 146] -> 
             RGBColor[
              0.19846266788634026`, 0.3259272255814276, 0.9346135273856964], 
             UndirectedEdge[81, 130] -> 
             RGBColor[
              0.9006340382989853, 0.6395018820094367, 0.23868605563289352`], 
             UndirectedEdge[1, 128] -> 
             RGBColor[
              0.8274423550647934, 0.21193954311047752`, 0.1739121362427404], 
             UndirectedEdge[296, 297] -> 
             RGBColor[
              0.18960014391301738`, 0.31661215096899065`, 0.934108819756345], 
             UndirectedEdge[128, 237] -> 
             RGBColor[
              0.838318390904733, 0.29553752048554727`, 0.1843270404457921], 
             UndirectedEdge[112, 146] -> 
             RGBColor[
              0.19463017997348525`, 0.32189903779124873`, 0.934395272868717], 
             UndirectedEdge[116, 287] -> 
             RGBColor[
              0.2651763885560936, 0.39604757589953593`, 0.9384127750837334], 
             UndirectedEdge[10, 266] -> 
             RGBColor[
              0.19427634422620857`, 0.3215271339863788, 0.9343751224463628], 
             UndirectedEdge[16, 76] -> 
             RGBColor[
              0.286854066125812, 0.4171520866149722, 0.9397088035477686], 
             UndirectedEdge[23, 72] -> 
             RGBColor[
              0.8827258558765204, 0.48135797009659975`, 0.3926067291806665], 
             UndirectedEdge[237, 277] -> 
             RGBColor[
              0.8810535048299607, 0.45831360631425644`, 0.27465957321892126`],
              UndirectedEdge[56, 278] -> 
             RGBColor[
              0.1999933373080916, 0.327536056193735, 0.9347006967448426], 
             UndirectedEdge[88, 274] -> 
             RGBColor[
              0.342952508633553, 0.4632649151839602, 0.9434373496862328], 
             UndirectedEdge[103, 282] -> 
             RGBColor[
              0.4309808924132613, 0.5477157201040381, 0.9486826992565017], 
             UndirectedEdge[46, 60] -> 
             RGBColor[
              0.2459880706675731, 0.3758794371890788, 0.9373200287665547], 
             UndirectedEdge[82, 216] -> 
             RGBColor[
              0.7821223617233105, 0.5567021598850534, 0.46109471540637825`], 
             UndirectedEdge[48, 70] -> 
             RGBColor[
              0.2012898575043234, 0.328898781124103, 0.9347745316519882], 
             UndirectedEdge[143, 174] -> 
             RGBColor[
              0.27004966377854045`, 0.4011696971418227, 0.9386903008982872], 
             UndirectedEdge[95, 205] -> 
             RGBColor[
              0.32995805051825455`, 0.4582556876322203, 0.9423173462424312], 
             UndirectedEdge[78, 190] -> 
             RGBColor[
              0.19927294772660503`, 0.32677888106825503`, 0.9346596716238978],
              UndirectedEdge[68, 292] -> 
             RGBColor[
              0.8252860920096456, 0.8638987146846454, 0.9830984780135097], 
             UndirectedEdge[145, 269] -> 
             RGBColor[
              0.9190343803618738, 0.908127960055847, 0.6686138108252507], 
             UndirectedEdge[198, 254] -> 
             RGBColor[
              0.6416864490274542, 0.7118235947085315, 0.9431778757394982], 
             UndirectedEdge[124, 147] -> 
             RGBColor[
              0.19966110992932296`, 0.3271868641542167, 0.9346817768871081], 
             UndirectedEdge[44, 194] -> 
             RGBColor[
              0.5011124283287507, 0.6014735099165995, 0.9553542362124354], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.3434646997755016, 0.4661397793633797, 0.9433176524403382], 
             UndirectedEdge[5, 11] -> 
             RGBColor[
              0.7514137479791486, 0.7723356879656991, 0.6490878757769967], 
             UndirectedEdge[108, 254] -> 
             RGBColor[
              0.27973365180931276`, 0.4104203008650652, 0.9392757639847461], 
             UndirectedEdge[61, 71] -> 
             RGBColor[
              0.25028804221449197`, 0.3803989799188331, 0.9375649057849139], 
             UndirectedEdge[229, 284] -> 
             RGBColor[
              0.22933503139451644`, 0.3583760370494225, 0.936371662815918], 
             UndirectedEdge[37, 136] -> 
             RGBColor[
              0.309591888135542, 0.4349767741872242, 0.9412260952746828], 
             UndirectedEdge[148, 159] -> 
             RGBColor[
              0.26876902654338763`, 0.39982366621058674`, 0.9386173705022783],
              UndirectedEdge[164, 230] -> 
             RGBColor[
              0.1870233298629817, 0.313903756022956, 0.9339620740082502], 
             UndirectedEdge[176, 193] -> 
             RGBColor[
              0.23687819251132788`, 0.36630437764722934`, 0.9368012346824135],
              UndirectedEdge[216, 299] -> 
             RGBColor[
              0.8505404448303738, 0.37258152858724236`, 0.19536912935227085`],
              UndirectedEdge[149, 277] -> 
             RGBColor[
              0.9442574972371908, 0.8029244899485575, 0.3576036046538991], 
             UndirectedEdge[39, 248] -> 
             RGBColor[
              0.21184147363468755`, 0.3399891986882186, 0.9353754305808952], 
             UndirectedEdge[13, 137] -> 
             RGBColor[
              0.2974114508687985, 0.42765952627289927`, 0.9403315986701979], 
             UndirectedEdge[68, 75] -> 
             RGBColor[
              0.6048929892039929, 0.6837170469414527, 0.9652757515328931], 
             UndirectedEdge[66, 97] -> 
             RGBColor[
              0.4175999543798127, 0.5361258241249656, 0.9478300777173092], 
             UndirectedEdge[59, 106] -> 
             RGBColor[
              0.9234341463667425, 0.9403782883321993, 0.9424056010083017], 
             UndirectedEdge[51, 198] -> 
             RGBColor[
              0.8879439008384149, 0.9128115493875727, 0.9633242059952494], 
             UndirectedEdge[193, 228] -> 
             RGBColor[
              0.35291040472918833`, 0.4773968889253306, 0.9438069074260627], 
             UndirectedEdge[30, 287] -> 
             RGBColor[
              0.24614870075893425`, 0.37604826959963533`, 0.9373291764126268],
              UndirectedEdge[93, 147] -> 
             RGBColor[
              0.22726390844905786`, 0.3561991555169663, 0.936253715428126], 
             UndirectedEdge[69, 121] -> 
             RGBColor[
              0.21650915427912054`, 0.3448952269935637, 0.9356412480883811], 
             UndirectedEdge[148, 251] -> 
             RGBColor[
              0.26595227173522773`, 0.39686307831464074`, 0.9384569604829689],
              UndirectedEdge[125, 269] -> 
             RGBColor[
              0.881184613963798, 0.48806415416592097`, 0.23764075645846794`], 
             UndirectedEdge[37, 44] -> 
             RGBColor[
              0.27139379762507876`, 0.4018915080789134, 0.9387921467246012], 
             UndirectedEdge[91, 105] -> 
             RGBColor[
              0.38699951220692347`, 0.5063182366232937, 0.9462409477627431], 
             UndirectedEdge[81, 203] -> 
             RGBColor[
              0.9132949931047244, 0.7717981514907339, 0.6103970678254644], 
             UndirectedEdge[8, 69] -> 
             RGBColor[
              0.2060185451131012, 0.33386893161703934`, 0.9350438234158418], 
             UndirectedEdge[52, 270] -> 
             RGBColor[
              0.20578610160522076`, 0.3336246187524874, 0.9350305861019373], 
             UndirectedEdge[108, 268] -> 
             RGBColor[
              0.2228674989167732, 0.351578250350071, 0.9360033464091675], 
             UndirectedEdge[11, 254] -> 
             RGBColor[
              0.4252983225505378, 0.5406623913243694, 0.9489095154684506], 
             UndirectedEdge[82, 255] -> 
             RGBColor[
              0.489728760692208, 0.5942524926612631, 0.9536273379129792], 
             UndirectedEdge[43, 66] -> 
             RGBColor[
              0.3059641689064351, 0.4317438620573953, 0.9409982635304203], 
             UndirectedEdge[252, 283] -> 
             RGBColor[
              0.27188152915805053`, 0.4030951038026612, 0.9387946229216484], 
             UndirectedEdge[99, 215] -> 
             RGBColor[
              0.21020795705683448`, 0.338272269193962, 0.9352824042283578], 
             UndirectedEdge[114, 283] -> 
             RGBColor[
              0.2724764193926355, 0.4037203711574294, 0.9388285010404467], 
             UndirectedEdge[24, 194] -> 
             RGBColor[
              0.8048847779464043, 0.7450443793025796, 0.6134276095233945], 
             UndirectedEdge[134, 228] -> 
             RGBColor[
              0.3355280602689666, 0.4591269427933443, 0.9428170086239273], 
             UndirectedEdge[49, 143] -> 
             RGBColor[
              0.2582581828615999, 0.38877610307504745`, 0.9380187935040003], 
             UndirectedEdge[123, 189] -> 
             RGBColor[
              0.2072195140090381, 0.335131226072495, 0.935112216817791], 
             UndirectedEdge[232, 240] -> 
             RGBColor[
              0.184219115333836, 0.3109563487553536, 0.933802378139279], 
             UndirectedEdge[11, 243] -> 
             RGBColor[
              0.7596161582091865, 0.8099275378271904, 0.907236768390906], 
             UndirectedEdge[155, 210] -> 
             RGBColor[
              0.698996444284087, 0.6637676396684864, 0.6055600185754992], 
             UndirectedEdge[148, 156] -> 
             RGBColor[
              0.32039438822353183`, 0.44615743504463745`, 0.9418476325885221],
              UndirectedEdge[15, 212] -> 
             RGBColor[
              0.24587235329600743`, 0.3757578108946581, 0.9373134388334325], 
             UndirectedEdge[51, 204] -> 
             RGBColor[
              0.647452541380158, 0.7220822556308867, 0.967158350930859], 
             UndirectedEdge[95, 156] -> 
             RGBColor[
              0.3410239560220559, 0.4678404187910305, 0.9430224559559374], 
             UndirectedEdge[87, 109] -> 
             RGBColor[
              0.9929796059139886, 0.9895239708410322, 0.632193448669364], 
             UndirectedEdge[113, 288] -> 
             RGBColor[
              0.23824897201713657`, 0.3677451538202748, 0.9368792985473828], 
             UndirectedEdge[164, 176] -> 
             RGBColor[
              0.1880768897106564, 0.3150111142224146, 0.9340220726829731], 
             UndirectedEdge[17, 294] -> 
             RGBColor[
              0.6198562799736641, 0.7013271769000424, 0.963858572100545], 
             UndirectedEdge[77, 212] -> 
             RGBColor[
              0.32357566422601636`, 0.4477175574235364, 0.9420941078985701], 
             UndirectedEdge[180, 296] -> 
             RGBColor[
              0.19104587171588, 0.3181317025542363, 0.9341911518159554], 
             UndirectedEdge[217, 271] -> 
             RGBColor[
              0.21133673112817714`, 0.3394586823113528, 0.9353466862418491], 
             UndirectedEdge[4, 85] -> 
             RGBColor[
              0.2263430797542824, 0.3552313061748459, 0.9362012755962026], 
             UndirectedEdge[95, 127] -> 
             RGBColor[
              0.3181958172626126, 0.4480678323732162, 0.9415678671403162], 
             UndirectedEdge[54, 75] -> 
             RGBColor[
              0.2884831291269512, 0.41830852004459096`, 0.9398219273882558], 
             UndirectedEdge[134, 193] -> 
             RGBColor[
              0.26218140249464095`, 0.39289965565586527`, 0.9382422150582186],
              UndirectedEdge[40, 178] -> 
             RGBColor[
              0.4741224882012588, 0.573360769660643, 0.953860855337124], 
             UndirectedEdge[69, 239] -> 
             RGBColor[
              0.22257247692189291`, 0.35126816352797696`, 0.935986545343005], 
             UndirectedEdge[134, 200] -> 
             RGBColor[
              0.3051846864517926, 0.4328450374952205, 0.9408835556758889], 
             UndirectedEdge[89, 141] -> 
             RGBColor[
              0.33729605784908523`, 0.4651931821113565, 0.9427636193772146], 
             UndirectedEdge[38, 147] -> 
             RGBColor[
              0.1997586179230488, 0.3272893512379864, 0.9346873298231007], 
             UndirectedEdge[170, 182] -> 
             RGBColor[
              0.2259600378398488, 0.3548287048365162, 0.9361794619258352], 
             UndirectedEdge[94, 120] -> 
             RGBColor[
              0.5379895613183256, 0.6259634266279861, 0.9597976199730934], 
             UndirectedEdge[80, 269] -> 
             RGBColor[
              0.9759866531723878, 0.9306594839278095, 0.36121311142511225`], 
             UndirectedEdge[263, 286] -> 
             RGBColor[
              0.2153900069518347, 0.3437189321945473, 0.9355775143037223], 
             UndirectedEdge[130, 140] -> 
             RGBColor[
              0.8488137274171336, 0.3187633460045766, 0.19210965802511026`], 
             UndirectedEdge[25, 288] -> 
             RGBColor[
              0.19999048340527747`, 0.32753305656092946`, 0.9347005342192993],
              UndirectedEdge[148, 191] -> 
             RGBColor[
              0.23683698231576478`, 0.36626106311881523`, 0.9367988878227413],
              UndirectedEdge[177, 268] -> 
             RGBColor[
              0.24851062539069607`, 0.37853080214228807`, 0.9374636845262513],
              UndirectedEdge[69, 126] -> 
             RGBColor[
              0.21552861209731056`, 0.34386461499051624`, 0.9355854076617092],
              UndirectedEdge[20, 37] -> 
             RGBColor[
              0.22278622542452461`, 0.3514928267566807, 0.9359987180040172], 
             UndirectedEdge[3, 72] -> 
             RGBColor[
              0.8710164273574281, 0.4731960144605215, 0.4379945662177568], 
             UndirectedEdge[87, 154] -> 
             RGBColor[
              0.7452228320173793, 0.7952601643437132, 0.7245769752264782], 
             UndirectedEdge[11, 204] -> 
             RGBColor[
              0.5077115751599948, 0.6112221547175201, 0.9543880614868259], 
             UndirectedEdge[55, 268] -> 
             RGBColor[
              0.20359322925377082`, 0.3313197708749761, 0.9349057052655861], 
             UndirectedEdge[125, 142] -> 
             RGBColor[
              0.8334415120439743, 0.25805169249981336`, 0.1796569357410828], 
             UndirectedEdge[176, 221] -> 
             RGBColor[
              0.1901941228796547, 0.3172364605233681, 0.9341426459797817], 
             UndirectedEdge[29, 182] -> 
             RGBColor[
              0.224799401299116, 0.35360880224359903`, 0.9361133653918483], 
             UndirectedEdge[122, 161] -> 
             RGBColor[
              0.19334750398760153`, 0.32055086400373023`, 0.9343222263688701],
              UndirectedEdge[44, 226] -> 
             RGBColor[
              0.6512382253914439, 0.7184499980919314, 0.9093942676022314], 
             UndirectedEdge[89, 131] -> 
             RGBColor[
              0.3050760854207314, 0.4313279482249144, 0.9409287396125976], 
             UndirectedEdge[56, 110] -> 
             RGBColor[
              0.1926369557700678, 0.31980403277574326`, 0.9342817616990433], 
             UndirectedEdge[43, 178] -> 
             RGBColor[
              0.24229896140308743`, 0.37200194944906734`, 0.9371099394514903],
              UndirectedEdge[66, 162] -> 
             RGBColor[
              0.6888450125107997, 0.7498709206605213, 0.8694416515926326], 
             UndirectedEdge[5, 142] -> 
             RGBColor[
              0.8769612906990375, 0.45869614749014964`, 0.23149650701243416`],
              UndirectedEdge[147, 273] -> 
             RGBColor[
              0.22616395243467474`, 0.35504303200461024`, 0.9361910745603459],
              UndirectedEdge[81, 167] -> 
             RGBColor[
              0.8985734587541578, 0.6313323707616247, 0.23702806496310708`], 
             UndirectedEdge[95, 212] -> 
             RGBColor[
              0.2604625119164363, 0.3910929926742148, 0.9381443267826606], 
             UndirectedEdge[56, 217] -> 
             RGBColor[
              0.19969746831988144`, 0.32722507912794885`, 0.934683847443663], 
             UndirectedEdge[6, 93] -> 
             RGBColor[
              0.2258625386311459, 0.35472622698636247`, 0.9361739094901367], 
             UndirectedEdge[131, 146] -> 
             RGBColor[
              0.2147184255833614, 0.3430130575955638, 0.9355392687383033], 
             UndirectedEdge[7, 80] -> 
             RGBColor[
              0.9585640473109542, 0.9468487152511682, 0.6807339798518178], 
             UndirectedEdge[76, 239] -> 
             RGBColor[
              0.28224692267200363`, 0.41230968673525326`, 0.9394464335437323],
              UndirectedEdge[148, 278] -> 
             RGBColor[
              0.2234636176615972, 0.35220480894699246`, 0.9360372944898065], 
             UndirectedEdge[29, 170] -> 
             RGBColor[
              0.19641582947302122`, 0.3237758686319784, 0.934496962966084], 
             UndirectedEdge[147, 289] -> 
             RGBColor[
              0.22842117185433053`, 0.35741551273064565`, 0.9363196198670385],
              UndirectedEdge[25, 28] -> 
             RGBColor[
              0.18729283765525817`, 0.3141870258004196, 0.9339774220783192], 
             UndirectedEdge[5, 149] -> 
             RGBColor[
              0.933258247478127, 0.766135074707167, 0.2882041746629133], 
             UndirectedEdge[140, 202] -> 
             RGBColor[
              0.8337362452113755, 0.25175489945285184`, 0.1796038966578704], 
             UndirectedEdge[10, 63] -> 
             RGBColor[
              0.18664280478053893`, 0.31350380003462497`, 0.9339404036677414],
              UndirectedEdge[43, 259] -> 
             RGBColor[
              0.20537394232393572`, 0.33319141321544904`, 0.9350071142406031],
              UndirectedEdge[21, 50] -> 
             RGBColor[
              0.18770061499905671`, 0.31461562564332873`, 0.9340006443947961],
              UndirectedEdge[87, 155] -> 
             RGBColor[
              0.959730943798982, 0.866659323879206, 0.37757715104669176`], 
             UndirectedEdge[127, 282] -> 
             RGBColor[
              0.3947336965046049, 0.5163202208449985, 0.9463730599853389], 
             UndirectedEdge[79, 144] -> 
             RGBColor[
              0.1903903758627761, 0.31744273485178653`, 0.9341538222968402], 
             UndirectedEdge[54, 298] -> 
             RGBColor[
              0.25208733908179476`, 0.3822901550083788, 0.9376673730796856], 
             UndirectedEdge[234, 263] -> 
             RGBColor[
              0.20202221841831886`, 0.32966853887907605`, 0.9348162385226094],
              UndirectedEdge[34, 38] -> 
             RGBColor[
              0.18490621443215238`, 0.31167853347228314`, 0.9338415074164561],
              UndirectedEdge[39, 85] -> 
             RGBColor[
              0.21693635514660192`, 0.345344242191386, 0.9356655765457971], 
             UndirectedEdge[20, 108] -> 
             RGBColor[
              0.2298448182232575, 0.3589118553287811, 0.9364006944216527], 
             UndirectedEdge[94, 201] -> 
             RGBColor[
              0.8292056662666228, 0.5135475347314276, 0.45417937065937186`], 
             UndirectedEdge[260, 294] -> 
             RGBColor[
              0.39710848893487455`, 0.5114544721894022, 0.9473162764842546], 
             UndirectedEdge[138, 266] -> 
             RGBColor[
              0.21471877848996196`, 0.3430134285227765, 0.935539288835812], 
             UndirectedEdge[127, 168] -> 
             RGBColor[
              0.3746233333290345, 0.4989016350385623, 0.9450916454266876], 
             UndirectedEdge[128, 198] -> 
             RGBColor[
              0.8848238567439902, 0.5553282615018976, 0.4420528553197187], 
             UndirectedEdge[145, 216] -> 
             RGBColor[
              0.8659437661770946, 0.6227214635073127, 0.46918309334836605`], 
             UndirectedEdge[141, 182] -> 
             RGBColor[
              0.2740956905180802, 0.4054223277779909, 0.9389207161355438], 
             UndirectedEdge[41, 252] -> 
             RGBColor[
              0.21326847287064163`, 0.3414890653621836, 0.9354566960763266], 
             UndirectedEdge[55, 208] -> 
             RGBColor[
              0.19572673330134732`, 0.32305158486432833`, 0.9344577199585336],
              UndirectedEdge[121, 249] -> 
             RGBColor[
              0.21645306950395798`, 0.3448362783388877, 0.9356380541434055], 
             UndirectedEdge[89, 120] -> 
             RGBColor[
              0.3299173264663655, 0.4574376675895273, 0.9423434115408236], 
             UndirectedEdge[32, 142] -> 
             RGBColor[
              0.8825157823171381, 0.4837930341441863, 0.4021669111922269], 
             UndirectedEdge[7, 77] -> 
             RGBColor[
              0.6760511895639363, 0.7431695037981105, 0.9684398535409274], 
             UndirectedEdge[45, 146] -> 
             RGBColor[
              0.24998188699294738`, 0.3800771913696276, 0.937547470697963], 
             UndirectedEdge[110, 223] -> 
             RGBColor[
              0.18370379552866184`, 0.31041471496695283`, 0.9337730314387216],
              UndirectedEdge[225, 276] -> 
             RGBColor[
              0.23448523874767882`, 0.3637892315196025, 0.9366649595056316], 
             UndirectedEdge[65, 291] -> 
             RGBColor[
              0.6521691058057041, 0.7229451944590042, 0.9690799766899112], 
             UndirectedEdge[194, 290] -> 
             RGBColor[
              0.8162082398567924, 0.7899381324572718, 0.622538732772305], 
             UndirectedEdge[154, 258] -> 
             RGBColor[
              0.4187295668061743, 0.5359100880009214, 0.9482320027234739], 
             UndirectedEdge[31, 280] -> 
             RGBColor[
              0.3408307300134504, 0.46531138731317084`, 0.9430966160299905], 
             UndirectedEdge[156, 271] -> 
             RGBColor[
              0.3085633706783219, 0.433722285474784, 0.9411738736417443], 
             UndirectedEdge[83, 241] -> 
             RGBColor[
              0.8930764595038494, 0.5687294396279854, 0.42134852043357485`], 
             UndirectedEdge[208, 268] -> 
             RGBColor[
              0.19718303522223768`, 0.3245822505180589, 0.9345406541985226], 
             UndirectedEdge[1, 80] -> 
             RGBColor[
              0.8720650730237359, 0.40985349668350635`, 0.23441445399203503`],
              UndirectedEdge[116, 206] -> 
             RGBColor[
              0.2548872111619892, 0.3852329980868062, 0.9378268216526131], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.22364840280037163`, 0.35239902984389887`, 0.9360478177300946],
              UndirectedEdge[108, 204] -> 
             RGBColor[
              0.36214690441876973`, 0.48098006425821577`, 0.9447543100031214],
              UndirectedEdge[251, 271] -> 
             RGBColor[
              0.25412125419001774`, 0.38442792874478726`, 0.9377832015361911],
              UndirectedEdge[6, 38] -> 
             RGBColor[
              0.19835724810513683`, 0.32581642270738265`, 0.9346075238851115],
              UndirectedEdge[135, 158] -> 
             RGBColor[
              0.20301108119461975`, 0.33070789635448955`, 0.9348725527948284],
              UndirectedEdge[25, 180] -> 
             RGBColor[
              0.1930001178726018, 0.32018573917131365`, 0.9343024432435325], 
             UndirectedEdge[57, 217] -> 
             RGBColor[
              0.18985695379830947`, 0.3168820744411198, 0.9341234446993961], 
             UndirectedEdge[71, 136] -> 
             RGBColor[
              0.3079661703282201, 0.43326804169526645`, 0.9411335130505898], 
             UndirectedEdge[135, 173] -> 
             RGBColor[
              0.20718172638991203`, 0.3350915088889201, 0.9351100648687836], 
             UndirectedEdge[143, 235] -> 
             RGBColor[
              0.3576942027971, 0.4840672946486393, 0.9440192038790169], 
             UndirectedEdge[264, 288] -> 
             RGBColor[
              0.2525376443502292, 0.38276345439650644`, 0.937693017298556], 
             UndirectedEdge[223, 247] -> 
             RGBColor[
              0.18962339324408597`, 0.3166365874900364, 0.934110143771355], 
             UndirectedEdge[191, 225] -> 
             RGBColor[
              0.22748667103589795`, 0.35643329311969896`, 0.9362664014278987],
              UndirectedEdge[1, 243] -> 
             RGBColor[
              0.8749347729676722, 0.4261491311907023, 0.39641874822047274`], 
             UndirectedEdge[29, 284] -> 
             RGBColor[
              0.21810645410068208`, 0.3465740903806829, 0.9357322119502256], 
             UndirectedEdge[6, 273] -> 
             RGBColor[
              0.22476258261676274`, 0.3535701034740064, 0.9361112686223567], 
             UndirectedEdge[103, 276] -> 
             RGBColor[
              0.33135174266530537`, 0.4551929422593771, 0.9425624927166377], 
             UndirectedEdge[99, 199] -> 
             RGBColor[
              0.19703448061371565`, 0.32442611020559603`, 0.9345321942333341],
              UndirectedEdge[35, 129] -> 
             RGBColor[
              0.19774057513237292`, 0.32516826031368307`, 0.9345724052715985],
              UndirectedEdge[77, 145] -> 
             RGBColor[
              0.6393432778876973, 0.7139671917177287, 0.9672816709055783], 
             UndirectedEdge[72, 155] -> 
             RGBColor[
              0.8617149167399476, 0.39992575965670085`, 0.20372391614271176`],
              UndirectedEdge[20, 44] -> 
             RGBColor[
              0.26761174198818394`, 0.3979163278083595, 0.93857676425113], 
             UndirectedEdge[131, 178] -> 
             RGBColor[
              0.2442095797785655, 0.3740101305018966, 0.9372187463414672], 
             UndirectedEdge[106, 241] -> 
             RGBColor[
              0.9239924068585166, 0.940609143392188, 0.9331537799277652], 
             UndirectedEdge[85, 286] -> 
             RGBColor[
              0.2265196157319883, 0.3554168566804423, 0.9362113290589713], 
             UndirectedEdge[86, 261] -> 
             RGBColor[
              0.41945675567834323`, 0.5279913173677868, 0.949221846121721], 
             UndirectedEdge[256, 269] -> 
             RGBColor[
              0.8696737021648134, 0.3995862419652118, 0.22661789432004487`], 
             UndirectedEdge[37, 61] -> 
             RGBColor[
              0.25191376002181387`, 0.38210771241079083`, 0.937657488009007], 
             UndirectedEdge[73, 244] -> 
             RGBColor[
              0.18608629156364545`, 0.31291886935869395`, 0.9339087110633268],
              UndirectedEdge[180, 193] -> 
             RGBColor[
              0.23722417633734735`, 0.3666680285850174, 0.9368209379494682], 
             UndirectedEdge[8, 213] -> 
             RGBColor[
              0.20342164602247398`, 0.3311394260198779, 0.9348959338543985], 
             UndirectedEdge[48, 138] -> 
             RGBColor[
              0.21204884540564534`, 0.34020715956762493`, 0.9353872400964722],
              UndirectedEdge[170, 284] -> 
             RGBColor[
              0.2192670906414149, 0.34779399297360003`, 0.9357983084842125], 
             UndirectedEdge[55, 219] -> 
             RGBColor[
              0.19323553565117518`, 0.3204331781829436, 0.9343158499377529], 
             UndirectedEdge[111, 235] -> 
             RGBColor[
              0.5113487817124779, 0.61295792200517, 0.9550106787741928], 
             UndirectedEdge[56, 247] -> 
             RGBColor[
              0.19855655348549195`, 0.3260259052988269, 0.9346188740316768], 
             UndirectedEdge[7, 82] -> 
             RGBColor[
              0.7758796678197641, 0.8252882359458167, 0.9760021123389747], 
             UndirectedEdge[182, 190] -> 
             RGBColor[
              0.22937905061187158`, 0.35842230403784237`, 0.9363741696452258],
              UndirectedEdge[113, 228] -> 
             RGBColor[
              0.34694483487630184`, 0.4711266967709722, 0.9434671770482106], 
             UndirectedEdge[133, 146] -> 
             RGBColor[
              0.19265917133132254`, 0.3198273827391699, 0.9342830268423918], 
             UndirectedEdge[93, 274] -> 
             RGBColor[
              0.3520883115326398, 0.4728672232742597, 0.9439576201461266], 
             UndirectedEdge[153, 220] -> 
             RGBColor[
              0.27707930337293885`, 0.40630757672797435`, 0.9391730382607208],
              UndirectedEdge[90, 153] -> 
             RGBColor[
              0.21837262298903565`, 0.3468538507584247, 0.9357473698746558], 
             UndirectedEdge[178, 190] -> 
             RGBColor[
              0.23171291230071078`, 0.36087534064819005`, 0.9365070796157662],
              UndirectedEdge[39, 126] -> 
             RGBColor[
              0.21260629074350712`, 0.3407930699617935, 0.9354189857837971], 
             UndirectedEdge[15, 77] -> 
             RGBColor[
              0.3360793820211845, 0.46085975760775527`, 0.942806176129412], 
             UndirectedEdge[103, 293] -> 
             RGBColor[
              0.6605442022439556, 0.5885330418914387, 0.5930681631412746], 
             UndirectedEdge[92, 269] -> 
             RGBColor[
              0.8787580922688558, 0.4694128451100082, 0.23531711654302695`], 
             UndirectedEdge[8, 14] -> 
             RGBColor[
              0.19233103918746458`, 0.31948249505119564`, 0.9342643402022272],
              UndirectedEdge[157, 171] -> 
             RGBColor[
              0.1808430925709541, 0.30740793477935857`, 0.9336101186373109], 
             UndirectedEdge[198, 226] -> 
             RGBColor[
              0.975424098844659, 0.9808488194558194, 0.9111203095275062], 
             UndirectedEdge[86, 169] -> 
             RGBColor[
              0.5994580148931581, 0.6857060476229113, 0.9616106773009028], 
             UndirectedEdge[163, 235] -> 
             RGBColor[
              0.5148221170934733, 0.615777732139438, 0.9552841124586315], 
             UndirectedEdge[31, 136] -> 
             RGBColor[
              0.4061320211140046, 0.526192876725208, 0.9470993511503072], 
             UndirectedEdge[111, 292] -> 
             RGBColor[
              0.6939596467687601, 0.7604145144003427, 0.9704259544749405], 
             UndirectedEdge[48, 122] -> 
             RGBColor[
              0.1889251216320018, 0.3159026597527588, 0.9340703782360471], 
             UndirectedEdge[246, 295] -> 
             RGBColor[
              0.19068631113650653`, 0.3177537815878572, 0.9341706753728822], 
             UndirectedEdge[258, 263] -> 
             RGBColor[
              0.2750253960672227, 0.40349492782139373`, 0.9390800123727585], 
             UndirectedEdge[24, 299] -> 
             RGBColor[
              0.8537172703307078, 0.34161563232659264`, 0.19619538295009195`],
              UndirectedEdge[66, 193] -> 
             RGBColor[
              0.33295274750258996`, 0.46011056933666983`, 0.9425352231554471],
              UndirectedEdge[29, 199] -> 
             RGBColor[
              0.196824977685108, 0.32420590934437654`, 0.9345202633514818], 
             UndirectedEdge[27, 87] -> 
             RGBColor[
              0.9814947768371431, 0.9488415742094825, 0.4164630400439475], 
             UndirectedEdge[164, 180] -> 
             RGBColor[
              0.18842287353667586`, 0.3153747651602027, 0.9340417759500277], 
             UndirectedEdge[106, 200] -> 
             RGBColor[
              0.6137154608562325, 0.6918743175265988, 0.9656005116200483], 
             UndirectedEdge[69, 285] -> 
             RGBColor[
              0.2036242652013759, 0.3313523916237017, 0.9349074727168887], 
             UndirectedEdge[88, 137] -> 
             RGBColor[
              0.242196310039882, 0.3718940563578661, 0.9371040936082149], 
             UndirectedEdge[43, 261] -> 
             RGBColor[
              0.23516151692935008`, 0.3645000427670523, 0.9367034725476139], 
             UndirectedEdge[224, 253] -> 
             RGBColor[
              0.20025883236896588`, 0.32781510833607297`, 0.9347158162957947],
              UndirectedEdge[5, 23] -> 
             RGBColor[
              0.9801796714011944, 0.9518718565732095, 0.5840536111729073], 
             UndirectedEdge[42, 162] -> 
             RGBColor[
              0.8888525819392381, 0.5235981308400817, 0.3867774183736629], 
             UndirectedEdge[29, 131] -> 
             RGBColor[
              0.21233150972289871`, 0.34050425768701104`, 0.9354033374111754],
              UndirectedEdge[12, 192] -> 
             RGBColor[
              0.3801187118441842, 0.5036614557026298, 0.9454418060863005], 
             UndirectedEdge[69, 76] -> 
             RGBColor[
              0.2672433086560147, 0.39653993712037666`, 0.9385919999213795], 
             UndirectedEdge[176, 180] -> 
             RGBColor[
              0.1945386218938126, 0.32180280444439524`, 0.9343900587715277], 
             UndirectedEdge[101, 116] -> 
             RGBColor[
              0.46733992011891123`, 0.5718860980228273, 0.952579449352897], 
             UndirectedEdge[125, 293] -> 
             RGBColor[
              0.8567159034897515, 0.39358707228041634`, 0.20024658025461053`],
              UndirectedEdge[30, 300] -> 
             RGBColor[
              0.23747118318928384`, 0.36692764844754155`, 0.936835004624272], 
             UndirectedEdge[155, 290] -> 
             RGBColor[
              0.9363623874102649, 0.7854051025986525, 0.2676538870247894], 
             UndirectedEdge[217, 246] -> 
             RGBColor[
              0.1922440281378487, 0.31939104092123016`, 0.9342593850516728], 
             UndirectedEdge[42, 82] -> 
             RGBColor[
              0.7628830394364272, 0.4257203521722454, 0.4433328823923026], 
             UndirectedEdge[122, 138] -> 
             RGBColor[
              0.2081640824318275, 0.3361240273739437, 0.9351660085921052], 
             UndirectedEdge[58, 160] -> 
             RGBColor[
              0.19345266111115197`, 0.32066139080792844`, 0.9343282149114902],
              UndirectedEdge[158, 225] -> 
             RGBColor[
              0.21027114178594725`, 0.3383386803504027, 0.9352860025052073], 
             UndirectedEdge[197, 204] -> 
             RGBColor[
              0.7349750271013598, 0.7901370127560131, 0.9142536375891683], 
             UndirectedEdge[40, 182] -> 
             RGBColor[
              0.47178862651241965`, 0.5709077330502953, 0.9537279453665835], 
             UndirectedEdge[1, 149] -> 
             RGBColor[
              0.8442968725884236, 0.3025905271935833, 0.18852880607059228`], 
             UndirectedEdge[32, 156] -> 
             RGBColor[
              0.691083843191671, 0.7526411268737674, 0.9001295183811735], 
             UndirectedEdge[258, 286] -> 
             RGBColor[
              0.28052613048445796`, 0.4092765484606139, 0.9393932710602128], 
             UndirectedEdge[101, 197] -> 
             RGBColor[
              0.816834867392223, 0.8565183997567056, 0.9207499871177253], 
             UndirectedEdge[53, 271] -> 
             RGBColor[
              0.21925630560640996`, 0.3477826572179991, 0.935797694292424], 
             UndirectedEdge[22, 70] -> 
             RGBColor[
              0.19915563229546623`, 0.32665557511190024`, 0.9346529906836472],
              UndirectedEdge[76, 258] -> 
             RGBColor[
              0.3335396370029857, 0.4633170022075566, 0.942473828625678], 
             UndirectedEdge[232, 297] -> 
             RGBColor[
              0.18995045311417683`, 0.3169803481502954, 0.934128769347115], 
             UndirectedEdge[178, 261] -> 
             RGBColor[
              0.2518738885698846, 0.38206580498681714`, 0.9376552173888041], 
             UndirectedEdge[155, 227] -> 
             RGBColor[
              0.9395091625151377, 0.7978810172888317, 0.27018585613847523`], 
             UndirectedEdge[178, 182] -> 
             RGBColor[
              0.2566774713547828, 0.3871146750584845, 0.9379287743221401], 
             UndirectedEdge[5, 51] -> 
             RGBColor[
              0.8911547141993119, 0.8831957888790658, 0.6618581652210298], 
             UndirectedEdge[110, 295] -> 
             RGBColor[
              0.19142001506063305`, 0.31852495093162986`, 0.9342124587259435],
              UndirectedEdge[186, 286] -> 
             RGBColor[
              0.2070033670926693, 0.3349040419588854, 0.9350999075706646], 
             UndirectedEdge[34, 270] -> 
             RGBColor[
              0.19826604624820576`, 0.32572056377321634`, 0.9346023300742803],
              UndirectedEdge[4, 8] -> 
             RGBColor[
              0.21250294836697825`, 0.34068445057177643`, 0.935413100588335], 
             UndirectedEdge[69, 166] -> 
             RGBColor[
              0.19683162728000528`, 0.3242128984902222, 0.9345206420360739], 
             UndirectedEdge[25, 176] -> 
             RGBColor[
              0.19265413404658233`, 0.31982208823352565`, 0.9342827399764779],
              UndirectedEdge[32, 149] -> 
             RGBColor[
              0.9415899849052779, 0.803780404688222, 0.5442097809326024], 
             UndirectedEdge[16, 153] -> 
             RGBColor[
              0.233929772423327, 0.36320540119410966`, 0.9366333265201985], 
             UndirectedEdge[169, 299] -> 
             RGBColor[
              0.7473755866979517, 0.32646116929742564`, 0.43103187403331167`],
              UndirectedEdge[187, 229] -> 
             RGBColor[
              0.22122626051320093`, 0.3498532047273915, 0.9359098803100787], 
             UndirectedEdge[15, 82] -> 
             RGBColor[
              0.43590786027701234`, 0.5429784897554615, 0.9503684349274593], 
             UndirectedEdge[44, 280] -> 
             RGBColor[
              0.2891161135986471, 0.42051878582686586`, 0.939801406401479], 
             UndirectedEdge[186, 265] -> 
             RGBColor[
              0.2079159163966799, 0.33586318913636815`, 0.9351518759035322], 
             UndirectedEdge[117, 265] -> 
             RGBColor[
              0.2041128319271811, 0.33186590622944256`, 0.9349352958691536], 
             UndirectedEdge[106, 162] -> 
             RGBColor[
              0.9266044419072905, 0.9416892870110949, 0.8898655994395634], 
             UndirectedEdge[9, 146] -> 
             RGBColor[
              0.1994945649800457, 0.3270118148529666, 0.9346722923986279], 
             UndirectedEdge[130, 294] -> 
             RGBColor[
              0.723926300807685, 0.6611320656306849, 0.6022559472314186], 
             UndirectedEdge[13, 53] -> 
             RGBColor[
              0.27458306643531494`, 0.40366544683013694`, 0.9390315559482794],
              UndirectedEdge[34, 57] -> 
             RGBColor[
              0.18168430472921848`, 0.3082921020936258, 0.9336580244252622], 
             UndirectedEdge[25, 144] -> 
             RGBColor[
              0.19437777007737006`, 0.3216337389867199, 0.9343808984985402], 
             UndirectedEdge[206, 283] -> 
             RGBColor[
              0.26412169083739256`, 0.3949390217254835, 0.938352711608939], 
             UndirectedEdge[107, 273] -> 
             RGBColor[
              0.32370272298268776`, 0.4483418094779742, 0.9420833765839904], 
             UndirectedEdge[64, 85] -> 
             RGBColor[
              0.2337265149567007, 0.3629917647094177, 0.9366217513081667], 
             UndirectedEdge[175, 224] -> 
             RGBColor[
              0.19563816085584113`, 0.3229584896082839, 0.9344526758887932], 
             UndirectedEdge[68, 163] -> 
             RGBColor[
              0.7490034970690254, 0.8039812828492927, 0.9757174701655251], 
             UndirectedEdge[7, 237] -> 
             RGBColor[
              0.8628230044438239, 0.4470001203594073, 0.4441941754294244], 
             UndirectedEdge[76, 126] -> 
             RGBColor[
              0.2752030578474213, 0.40490613819779253`, 0.9390452958624365], 
             UndirectedEdge[30, 236] -> 
             RGBColor[
              0.2403636886171835, 0.3699678550477007, 0.9369997285293126], 
             UndirectedEdge[7, 269] -> 
             RGBColor[
              0.9557422920381128, 0.9373302721362289, 0.6697719934605999], 
             UndirectedEdge[237, 256] -> 
             RGBColor[
              0.8226924771507464, 0.17542990005333894`, 0.16936364778802923`],
              UndirectedEdge[106, 290] -> 
             RGBColor[
              0.9041357720440601, 0.8589662618992862, 0.6312127071179277], 
             UndirectedEdge[180, 288] -> 
             RGBColor[
              0.20187497125250775`, 0.32951377277179905`, 0.9348078530143491],
              UndirectedEdge[201, 237] -> 
             RGBColor[
              0.8386009494484636, 0.2977093892706047, 0.18459761882637282`], 
             UndirectedEdge[10, 73] -> 
             RGBColor[
              0.18653587436616526`, 0.31339140938933835`, 0.9339343141388322],
              UndirectedEdge[18, 175] -> 
             RGBColor[
              0.19129167307218187`, 0.3183900553644156, 0.9342051498395663], 
             UndirectedEdge[57, 295] -> 
             RGBColor[
              0.1882992367969673, 0.3152448151077469, 0.9340347350206055], 
             UndirectedEdge[71, 161] -> 
             RGBColor[
              0.2124857473818974, 0.34066637124585103`, 0.9354121210176813], 
             UndirectedEdge[218, 220] -> 
             RGBColor[
              0.6501395047208716, 0.7189888396444919, 0.9414344110066938], 
             UndirectedEdge[192, 248] -> 
             RGBColor[
              0.27628801069729353`, 0.4057044446902951, 0.9391196063656152], 
             UndirectedEdge[23, 24] -> 
             RGBColor[
              0.956555334204736, 0.8626596651038085, 0.541866983332811], 
             UndirectedEdge[39, 195] -> 
             RGBColor[
              0.1927241486561343, 0.3198956780273474, 0.9342867272049146], 
             UndirectedEdge[79, 232] -> 
             RGBColor[
              0.1855242988552152, 0.31232817938973806`, 0.9338767064099756], 
             UndirectedEdge[12, 154] -> 
             RGBColor[
              0.46345887168868094`, 0.5746523637299171, 0.9510821144780158], 
             UndirectedEdge[106, 155] -> 
             RGBColor[
              0.8940872222095038, 0.8191271102860018, 0.6231274080512639], 
             UndirectedEdge[95, 103] -> 
             RGBColor[
              0.35444301317126903`, 0.47946333163225574`, 0.9438775064114789],
              UndirectedEdge[3, 228] -> 
             RGBColor[
              0.690237715965832, 0.7545004457298199, 0.955381119587516], 
             UndirectedEdge[81, 293] -> 
             RGBColor[
              0.8946118304119881, 0.61433876058075, 0.23377386680638917`], 
             UndirectedEdge[95, 145] -> 
             RGBColor[
              0.5762301255781173, 0.6573426269684071, 0.963331889789669], 
             UndirectedEdge[39, 153] -> 
             RGBColor[
              0.2113966935997263, 0.3395217066707913, 0.9353501010158973], 
             UndirectedEdge[39, 90] -> 
             RGBColor[
              0.20870014958760652`, 0.3366874679432882, 0.9351965368235865], 
             UndirectedEdge[120, 141] -> 
             RGBColor[
              0.28646903998749706`, 0.4184275025860159, 0.939625360083097], 
             UndirectedEdge[102, 172] -> 
             RGBColor[
              0.19138970866876043`, 0.3184930969922355, 0.9342107328217606], 
             UndirectedEdge[155, 194] -> 
             RGBColor[
              0.8061596900222359, 0.7500989808439875, 0.6144534337056413], 
             UndirectedEdge[53, 251] -> 
             RGBColor[
              0.25074234215186236`, 0.3808764779572891, 0.9375907774942707], 
             UndirectedEdge[128, 243] -> 
             RGBColor[
              0.8924326724712802, 0.5606456544038871, 0.4131747565461786], 
             UndirectedEdge[72, 87] -> 
             RGBColor[
              0.8839929875554634, 0.4806546749192594, 0.28239629153508916`], 
             UndirectedEdge[76, 90] -> 
             RGBColor[
              0.2712969166915207, 0.40080053617928724`, 0.938822846902226], 
             UndirectedEdge[3, 106] -> 
             RGBColor[
              0.9080394881357245, 0.9290324924917327, 0.9745333831638314], 
             UndirectedEdge[104, 243] -> 
             RGBColor[
              0.6612526622734278, 0.7268613939195354, 0.9003802288706013], 
             UndirectedEdge[34, 217] -> 
             RGBColor[
              0.1918655955426979, 0.3189932842697143, 0.9342378338752199], 
             UndirectedEdge[31, 37] -> 
             RGBColor[
              0.32310841403988205`, 0.4466841095652183, 0.9420873563531128], 
             UndirectedEdge[64, 249] -> 
             RGBColor[
              0.22138061658703678`, 0.35001544274773333`, 0.9359186706601341],
              UndirectedEdge[89, 188] -> 
             RGBColor[
              0.3683043792841372, 0.49342847464473716`, 0.9446890072625783], 
             UndirectedEdge[179, 269] -> 
             RGBColor[
              0.7479608310759376, 0.7722887789067958, 0.6529117994592061], 
             UndirectedEdge[213, 249] -> 
             RGBColor[
              0.2049158790401142, 0.33270995966126304`, 0.9349810282142335], 
             UndirectedEdge[44, 252] -> 
             RGBColor[
              0.27708079783829526`, 0.4078689058796433, 0.9391160129735812], 
             UndirectedEdge[149, 198] -> 
             RGBColor[
              0.93004743411723, 0.7957508352156739, 0.5896702154371328], 
             UndirectedEdge[158, 214] -> 
             RGBColor[
              0.19688801935015837`, 0.3242721701314169, 0.9345238534810445], 
             UndirectedEdge[202, 216] -> 
             RGBColor[
              0.8665350630405979, 0.48684871744288943`, 0.21034592388715595`],
              UndirectedEdge[78, 209] -> 
             RGBColor[
              0.18729352981200414`, 0.31418775330104487`, 0.933977461495622], 
             UndirectedEdge[77, 265] -> 
             RGBColor[
              0.31824926646414226`, 0.4421191756626833, 0.9417907774257306], 
             UndirectedEdge[44, 204] -> 
             RGBColor[
              0.39991382818369614`, 0.5199845367377941, 0.9469303798325985], 
             UndirectedEdge[54, 102] -> 
             RGBColor[
              0.218116116310074, 0.34658424597537324`, 0.9357327621987566], 
             UndirectedEdge[2, 253] -> 
             RGBColor[
              0.19522054856906235`, 0.32251955261673115`, 0.9344288934868631],
              UndirectedEdge[40, 86] -> 
             RGBColor[
              0.6417053553097174, 0.7192862820416126, 0.9654274840700409], 
             UndirectedEdge[75, 165] -> 
             RGBColor[
              0.27536181000482485`, 0.4045171817075533, 0.9390746876755028], 
             UndirectedEdge[73, 100] -> 
             RGBColor[
              0.1816658245926822, 0.30827267829841776`, 0.9336569720088254], 
             UndirectedEdge[50, 206] -> 
             RGBColor[
              0.20212300857950383`, 0.32977447572894675`, 0.9348219783731833],
              UndirectedEdge[32, 277] -> 
             RGBColor[
              0.9903436750031767, 0.9883158760637997, 0.6672952315344995], 
             UndirectedEdge[156, 251] -> 
             RGBColor[
              0.3400494072237743, 0.46681610621407393`, 0.942966956843591], 
             UndirectedEdge[31, 44] -> 
             RGBColor[
              0.36793393060354135`, 0.4931076106168971, 0.9446654026002257], 
             UndirectedEdge[80, 92] -> 
             RGBColor[
              0.8806392624507501, 0.47575847385330106`, 0.24262510747050564`],
              UndirectedEdge[11, 149] -> 
             RGBColor[
              0.7136593076403137, 0.6245896318315118, 0.5954018551660852], 
             UndirectedEdge[103, 145] -> 
             RGBColor[
              0.643116750417353, 0.7172355839626725, 0.9675221132384173], 
             UndirectedEdge[150, 274] -> 
             RGBColor[
              0.6852279869066359, 0.622788647378854, 0.5976147565045411], 
             UndirectedEdge[13, 156] -> 
             RGBColor[
              0.3638901315072269, 0.4896050750869218, 0.9444077352975997], 
             UndirectedEdge[84, 278] -> 
             RGBColor[
              0.19404895120727791`, 0.32128812950593255`, 0.9343621727503324],
              UndirectedEdge[150, 293] -> 
             RGBColor[
              0.9035840903340573, 0.6541630034729253, 0.24121312079051388`], 
             UndirectedEdge[52, 137] -> 
             RGBColor[
              0.23013360981142927`, 0.35921539359839394`, 0.9364171406753703],
              UndirectedEdge[41, 152] -> 
             RGBColor[
              0.1855570941414352, 0.31236264931489655`, 0.9338785740530094], 
             UndirectedEdge[177, 279] -> 
             RGBColor[
              0.2643192230897936, 0.3951466406470252, 0.9383639607784904], 
             UndirectedEdge[108, 279] -> 
             RGBColor[
              0.23867609661587075`, 0.3681940888548081, 0.9369036226614065], 
             UndirectedEdge[161, 279] -> 
             RGBColor[
              0.2191606879449377, 0.34768215699328187`, 0.9357922490080568], 
             UndirectedEdge[89, 260] -> 
             RGBColor[
              0.3194559514168667, 0.4464420991230162, 0.9417476517079721], 
             UndirectedEdge[63, 161] -> 
             RGBColor[
              0.19226866060006637`, 0.3194169312008093, 0.9342607878339557], 
             UndirectedEdge[110, 148] -> 
             RGBColor[
              0.2161072361235734, 0.34447278552900074`, 0.9356183594440073], 
             UndirectedEdge[200, 228] -> 
             RGBColor[
              0.3959136886863399, 0.5173422707646859, 0.946448248043733], 
             UndirectedEdge[67, 118] -> 
             RGBColor[
              0.18382399790050605`, 0.31054105528103165`, 0.9337798767859746],
              UndirectedEdge[140, 203] -> 
             RGBColor[
              0.8572543639542931, 0.40696085899210804`, 0.43991699948682417`],
              UndirectedEdge[144, 231] -> 
             RGBColor[
              0.21441031983489064`, 0.34268921891888826`, 0.9355217225717294],
              UndirectedEdge[101, 149] -> 
             RGBColor[
              0.7714159149498363, 0.6714029284596804, 0.6000007099012994], 
             UndirectedEdge[131, 284] -> 
             RGBColor[
              0.23518277089129241`, 0.36452238202863274`, 0.9367046829293041],
              UndirectedEdge[157, 275] -> 
             RGBColor[
              0.18135642915031058`, 0.30794748407168115`, 0.9336393523960919],
              UndirectedEdge[113, 144] -> 
             RGBColor[
              0.23263625868922916`, 0.36184583624606526`, 0.9365596628266237],
              UndirectedEdge[48, 73] -> 
             RGBColor[
              0.187739347830093, 0.31465633630455114`, 0.9340028501722235], 
             UndirectedEdge[35, 183] -> 
             RGBColor[
              0.19956688605797046`, 0.32708782889128674`, 0.9346764109770263],
              UndirectedEdge[93, 107] -> 
             RGBColor[
              0.32480267899707094`, 0.44949793299033025`, 0.9421460174517705],
              UndirectedEdge[23, 226] -> 
             RGBColor[
              0.9878018957897885, 0.9892237846791677, 0.8518176846523693], 
             UndirectedEdge[200, 211] -> 
             RGBColor[
              0.31815152117452855`, 0.44647400293362227`, 0.9416219977306357],
              UndirectedEdge[87, 227] -> 
             RGBColor[
              0.9729262687384115, 0.9189743901826695, 0.3881944192270413], 
             UndirectedEdge[223, 278] -> 
             RGBColor[
              0.1910601770666856, 0.31814673838494456`, 0.9341919664845209], 
             UndirectedEdge[182, 229] -> 
             RGBColor[
              0.23602797859295035`, 0.36541074891233866`, 0.9367528162575407],
              UndirectedEdge[79, 221] -> 
             RGBColor[
              0.18466822464384994`, 0.3114283911153532, 0.9338279542500865], 
             UndirectedEdge[115, 228] -> 
             RGBColor[
              0.3889928994532643, 0.5113478309799768, 0.946007261473615], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.3382052536051789, 0.4616299042238716, 0.9429808558058818], 
             UndirectedEdge[9, 47] -> 
             RGBColor[
              0.1915298565644043, 0.31864040131644705`, 0.9342187140370874], 
             UndirectedEdge[18, 224] -> 
             RGBColor[
              0.2043212377981297, 0.33208495401350496`, 0.9349471642751953], 
             UndirectedEdge[194, 291] -> 
             RGBColor[
              0.8064401830754907, 0.8495804260163464, 0.9811128108192658], 
             UndirectedEdge[5, 198] -> 
             RGBColor[
              0.967801874456065, 0.9434968913498611, 0.6433562360480443], 
             UndirectedEdge[49, 172] -> 
             RGBColor[
              0.20010293929950806`, 0.3276512548358813, 0.9347069384161122], 
             UndirectedEdge[162, 228] -> 
             RGBColor[
              0.7088026697373979, 0.7671572402491821, 0.8707133358632482], 
             UndirectedEdge[100, 161] -> 
             RGBColor[
              0.1911587437240086, 0.318250338191278, 0.9341975797098391], 
             UndirectedEdge[174, 235] -> 
             RGBColor[
              0.3208493079592518, 0.4453409740728014, 0.9419209416251387], 
             UndirectedEdge[14, 67] -> 
             RGBColor[
              0.17956042552731538`, 0.30605977039070653`, 0.9335370726467116],
              UndirectedEdge[190, 199] -> 
             RGBColor[
              0.2014046269978636, 0.3290194111386199, 0.9347810676048591], 
             UndirectedEdge[160, 288] -> 
             RGBColor[
              0.20231487113075944`, 0.32997613543510473`, 0.934832904661642], 
             UndirectedEdge[33, 275] -> 
             RGBColor[
              0.19034059746125545`, 0.31739041459565537`, 0.9341509874905143],
              UndirectedEdge[109, 218] -> 
             RGBColor[
              0.9800003657513711, 0.9831729301139916, 0.8546124313811914], 
             UndirectedEdge[231, 264] -> 
             RGBColor[
              0.2636953407278438, 0.39449090072818943`, 0.9383284316009286], 
             UndirectedEdge[221, 230] -> 
             RGBColor[
              0.18914056303198, 0.3161291023239095, 0.9340826473050587], 
             UndirectedEdge[45, 236] -> 
             RGBColor[
              0.26568284234196243`, 0.3965798909395088, 0.9384416168776075], 
             UndirectedEdge[279, 280] -> 
             RGBColor[
              0.24933981979070619`, 0.37940233803066026`, 0.9375109059206487],
              UndirectedEdge[71, 252] -> 
             RGBColor[
              0.23062956346731406`, 0.3597366723360068, 0.9364453845023752], 
             UndirectedEdge[230, 296] -> 
             RGBColor[
              0.18964632804218584`, 0.3166606934169896, 0.9341114498741778], 
             UndirectedEdge[27, 154] -> 
             RGBColor[
              0.7335695588322665, 0.7563490417801518, 0.6454543011351679], 
             UndirectedEdge[5, 101] -> 
             RGBColor[
              0.8091703552886713, 0.8191489845938676, 0.6536867305122107], 
             UndirectedEdge[68, 143] -> 
             RGBColor[
              0.5918755827726521, 0.672270845358494, 0.9644525615859105], 
             UndirectedEdge[58, 221] -> 
             RGBColor[
              0.18866826221874242`, 0.3156326842235957, 0.9340557504724514], 
             UndirectedEdge[85, 249] -> 
             RGBColor[
              0.21980259172524277`, 0.34835683856543287`, 0.9358288044787336],
              UndirectedEdge[26, 54] -> 
             RGBColor[
              0.23656624471631046`, 0.3659765007360335, 0.9367834697169728], 
             UndirectedEdge[269, 282] -> 
             RGBColor[
              0.7068985223577822, 0.7386080961972126, 0.6497743968433352], 
             UndirectedEdge[24, 210] -> 
             RGBColor[
              0.6977215322082554, 0.6587130381270785, 0.6045341943932525], 
             UndirectedEdge[144, 288] -> 
             RGBColor[
              0.20325262345727604`, 0.33096177258720527`, 0.9348863082693568],
              UndirectedEdge[182, 199] -> 
             RGBColor[
              0.22636918605193562`, 0.35525874554891435`, 0.936202762311233], 
             UndirectedEdge[35, 224] -> 
             RGBColor[
              0.20753059097457632`, 0.33545818768669444`, 0.9351299321907813],
              UndirectedEdge[161, 280] -> 
             RGBColor[
              0.2318337811627876, 0.36100238148576125`, 0.9365139629186521], 
             UndirectedEdge[27, 42] -> 
             RGBColor[
              0.8816836574994876, 0.49667817991020385`, 0.23487588344630034`],
              UndirectedEdge[13, 273] -> 
             RGBColor[
              0.2861094453581625, 0.4157804018926833, 0.9396879661761859], 
             UndirectedEdge[167, 202] -> 
             RGBColor[
              0.8802744981433329, 0.5485728040784057, 0.22177612422766013`], 
             UndirectedEdge[117, 207] -> 
             RGBColor[
              0.18539878883552113`, 0.3121962604012447, 0.9338695588000294], 
             UndirectedEdge[33, 248] -> 
             RGBColor[
              0.21123257741316134`, 0.3393492101531443, 0.9353407548418606], 
             UndirectedEdge[23, 210] -> 
             RGBColor[
              0.7305128529889463, 0.7859159553283347, 0.8888842381324313], 
             UndirectedEdge[54, 111] -> 
             RGBColor[
              0.4291203016109882, 0.5357529458181629, 0.9499902123364491], 
             UndirectedEdge[30, 267] -> 
             RGBColor[
              0.22275125819820335`, 0.35145607398476686`, 0.9359967266722076],
              UndirectedEdge[170, 199] -> 
             RGBColor[
              0.19798561422584082`, 0.3254258119372937, 0.9345863598854686], 
             UndirectedEdge[169, 200] -> 
             RGBColor[
              0.4851546386974715, 0.5905268621408066, 0.9532706039694929], 
             UndirectedEdge[137, 278] -> 
             RGBColor[
              0.23108207251171536`, 0.3602122880324031, 0.9364711542230267], 
             UndirectedEdge[92, 150] -> 
             RGBColor[
              0.856839597699243, 0.38590456876888285`, 0.2000192899179641], 
             UndirectedEdge[68, 185] -> 
             RGBColor[
              0.7032065232894661, 0.766801236404889, 0.9721121646297556], 
             UndirectedEdge[26, 102] -> 
             RGBColor[
              0.21064547425155244`, 0.3387321275058029, 0.9353073201853483], 
             UndirectedEdge[270, 271] -> 
             RGBColor[
              0.217737181833685, 0.3461859618148549, 0.9357111824409096], 
             UndirectedEdge[169, 202] -> 
             RGBColor[
              0.7792934779313432, 0.5546715851773875, 0.4609259309301712], 
             UndirectedEdge[17, 97] -> 
             RGBColor[
              0.5762606506463335, 0.665813185958444, 0.9604600233988309], 
             UndirectedEdge[46, 158] -> 
             RGBColor[
              0.1988271914603046, 0.32631036296979365`, 0.9346342864639694], 
             UndirectedEdge[98, 285] -> 
             RGBColor[
              0.18936585526810354`, 0.31636589874842813`, 0.9340954773646161],
              UndirectedEdge[77, 168] -> 
             RGBColor[
              0.4070970567080353, 0.527028742052658, 0.9471608423650113], 
             UndirectedEdge[242, 268] -> 
             RGBColor[0.1929658134251674, 0.3201496830220325, 0.934300489656],
              UndirectedEdge[115, 134] -> 
             RGBColor[
              0.29826389721871693`, 0.4268505977105114, 0.940442569105771], 
             UndirectedEdge[99, 284] -> 
             RGBColor[
              0.2183159570292897, 0.34679429124190236`, 0.9357441428320781], 
             UndirectedEdge[204, 283] -> 
             RGBColor[
              0.3947145595034514, 0.515210734660812, 0.9466089897806659], 
             UndirectedEdge[77, 167] -> 
             RGBColor[
              0.6607323580564698, 0.6022582598273698, 0.5960819189651536], 
             UndirectedEdge[227, 290] -> 
             RGBColor[
              0.9495577123496941, 0.837720168902116, 0.27827115520513895`], 
             UndirectedEdge[60, 145] -> 
             RGBColor[
              0.5760856373176906, 0.6571907606456139, 0.9633236613969889], 
             UndirectedEdge[32, 125] -> 
             RGBColor[
              0.8860217022210372, 0.5107410708294523, 0.40552418405157087`], 
             UndirectedEdge[15, 60] -> 
             RGBColor[
              0.27282174145117777`, 0.4040833265356404, 0.9388481666208225], 
             UndirectedEdge[30, 260] -> 
             RGBColor[
              0.25373200019445147`, 0.38401879811531836`, 0.9377610340969933],
              UndirectedEdge[42, 80] -> 
             RGBColor[
              0.8846726257638872, 0.5067606717091464, 0.24648746073419803`], 
             UndirectedEdge[97, 130] -> 
             RGBColor[
              0.6803306714803544, 0.6256180746890865, 0.5988573985297044], 
             UndirectedEdge[65, 211] -> 
             RGBColor[
              0.3240980577045407, 0.45162459399430244`, 0.9420009057800123], 
             UndirectedEdge[1, 256] -> 
             RGBColor[
              0.8184383049744752, 0.1427304685163843, 0.1652898477076317], 
             UndirectedEdge[5, 128] -> 
             RGBColor[
              0.8869643989845882, 0.5355844211628931, 0.24107549480357243`], 
             UndirectedEdge[125, 256] -> 
             RGBColor[
              0.8294390160964316, 0.2272867547420918, 0.17582414110154324`], 
             UndirectedEdge[39, 239] -> 
             RGBColor[
              0.2196501555680895, 0.3481966184992542, 0.9358201234650929], 
             UndirectedEdge[156, 269] -> 
             RGBColor[
              0.6838282108058124, 0.7186257518784704, 0.6483043769915192], 
             UndirectedEdge[78, 170] -> 
             RGBColor[
              0.19585393495458225`, 0.32318528186692885`, 0.9344649639045073],
              UndirectedEdge[23, 155] -> 
             RGBColor[
              0.9578302462805677, 0.8677142666452164, 0.5428928075150579], 
             UndirectedEdge[127, 251] -> 
             RGBColor[
              0.31722126846433096`, 0.4470435197962596, 0.9415123680279698], 
             UndirectedEdge[241, 290] -> 
             RGBColor[
              0.9662675720592777, 0.9068871357048387, 0.5776802589012907], 
             UndirectedEdge[85, 234] -> 
             RGBColor[
              0.21315182719847248`, 0.341366463364971, 0.9354500532778585], 
             UndirectedEdge[270, 289] -> 
             RGBColor[
              0.22814186813803294`, 0.35712194681593845`, 0.9363037139335881],
              UndirectedEdge[69, 258] -> 
             RGBColor[
              0.273865191252875, 0.4022754790002804, 0.9390139404249507], 
             UndirectedEdge[52, 289] -> 
             RGBColor[
              0.22108882372044908`, 0.3497087499442134, 0.9359020534880509], 
             UndirectedEdge[47, 170] -> 
             RGBColor[
              0.1908380369178425, 0.3179132550040116, 0.9341793159316711], 
             UndirectedEdge[72, 241] -> 
             RGBColor[
              0.8816517065059561, 0.48091378172749166`, 0.4104081640603793], 
             UndirectedEdge[115, 210] -> 
             RGBColor[
              0.4117038936977402, 0.5305204071243743, 0.9475921355741658], 
             UndirectedEdge[166, 239] -> 
             RGBColor[
              0.21183524129599424`, 0.3399826481050988, 0.9353750756584267], 
             UndirectedEdge[180, 215] -> 
             RGBColor[
              0.2098131605219987, 0.33785731300430355`, 0.9352599211497481], 
             UndirectedEdge[51, 254] -> 
             RGBColor[
              0.5650392887707011, 0.6515224922377361, 0.9616798049124837], 
             UndirectedEdge[109, 227] -> 
             RGBColor[
              0.9727578246301442, 0.9207456642506578, 0.5248021537611475], 
             UndirectedEdge[203, 255] -> 
             RGBColor[
              0.651571481892223, 0.7220382969334023, 0.9679291557478935], 
             UndirectedEdge[257, 272] -> 
             RGBColor[
              0.18158199985616474`, 0.30818457318554265`, 0.9336521983140883],
              UndirectedEdge[32, 128] -> 
             RGBColor[
              0.8925188906026889, 0.5606813078169296, 0.41174589898336517`], 
             UndirectedEdge[39, 76] -> 
             RGBColor[
              0.26432098730221126`, 0.39346839209165385`, 0.9384255780434674],
              UndirectedEdge[144, 221] -> 
             RGBColor[
              0.19191775891044247`, 0.3190481112765624, 0.9342408045018441], 
             UndirectedEdge[165, 262] -> 
             RGBColor[
              0.26081704104435255`, 0.39146562526609985`, 0.9381645166920165],
              UndirectedEdge[101, 226] -> 
             RGBColor[
              0.8167925796772653, 0.8565009126998259, 0.9214508039916728], 
             UndirectedEdge[56, 191] -> 
             RGBColor[
              0.21336670196225918`, 0.34159231036555776`, 0.9354622900777774],
              UndirectedEdge[63, 71] -> 
             RGBColor[
              0.20309975866494467`, 0.3308011019982774, 0.9348776028455769], 
             UndirectedEdge[137, 289] -> 
             RGBColor[
              0.25248937634424146`, 0.382712721661845, 0.9376902685070212], 
             UndirectedEdge[148, 295] -> 
             RGBColor[
              0.2216100316720449, 0.3502565725478334, 0.9359317355098362], 
             UndirectedEdge[10, 119] -> 
             RGBColor[
              0.1856272606689936, 0.3124363987841752, 0.9338825699329518], 
             UndirectedEdge[115, 231] -> 
             RGBColor[
              0.29145473297171365`, 0.41969373436096236`, 0.9400547972751598],
              UndirectedEdge[33, 171] -> 
             RGBColor[
              0.189827260881899, 0.31685086530333273`, 0.9341217537317332], 
             UndirectedEdge[173, 234] -> 
             RGBColor[
              0.19772105404463286`, 0.3251477424127598, 0.9345712935745305], 
             UndirectedEdge[69, 173] -> 
             RGBColor[
              0.2044279033465657, 0.3321970662678976, 0.9349532387203812], 
             UndirectedEdge[4, 263] -> 
             RGBColor[
              0.21521347097412877`, 0.3435333816889509, 0.9355674608409534], 
             UndirectedEdge[134, 160] -> 
             RGBColor[
              0.22028173175537732`, 0.3488604451163368, 0.9358560907946256], 
             UndirectedEdge[7, 205] -> 
             RGBColor[
              0.6553396994405775, 0.7252302520430189, 0.9671201357047186], 
             UndirectedEdge[23, 106] -> 
             RGBColor[
              0.9256036309143629, 0.94127542594585, 0.906451627608196], 
             UndirectedEdge[45, 96] -> 
             RGBColor[
              0.2504426073839444, 0.3805614377119254, 0.9375737080426556], 
             UndirectedEdge[65, 210] -> 
             RGBColor[
              0.424571219460828, 0.5416654379697635, 0.9484120301936603], 
             UndirectedEdge[138, 211] -> 
             RGBColor[
              0.25101026684268113`, 0.38115808379474614`, 0.9376060354090536],
              UndirectedEdge[72, 210] -> 
             RGBColor[
              0.7101699878788666, 0.345393552112113, 0.4343848698876275], 
             UndirectedEdge[37, 41] -> 
             RGBColor[
              0.20758147265742513`, 0.3355116675614536, 0.9351328298273469], 
             UndirectedEdge[52, 88] -> 
             RGBColor[
              0.21079575741608964`, 0.3388900846402345, 0.9353158785892447], 
             UndirectedEdge[157, 285] -> 
             RGBColor[
              0.1911088793151014, 0.31819792753593046`, 0.9341947400055196], 
             UndirectedEdge[135, 265] -> 
             RGBColor[
              0.21789617448484386`, 0.3463530731719392, 0.9357202368371844], 
             UndirectedEdge[17, 42] -> 
             RGBColor[
              0.7929575364765972, 0.44951011621237846`, 0.44612850273328253`],
              UndirectedEdge[242, 250] -> 
             RGBColor[
              0.18176798085569046`, 0.30838005100792065`, 0.933662789656877], 
             UndirectedEdge[81, 202] -> 
             RGBColor[
              0.8742021218716074, 0.5216630409074182, 0.2167435057125596], 
             UndirectedEdge[229, 259] -> 
             RGBColor[
              0.2014368212026378, 0.32905324928906804`, 0.934782901017194], 
             UndirectedEdge[40, 81] -> 
             RGBColor[
              0.7893492688527326, 0.6740607768287987, 0.5995695817860118], 
             UndirectedEdge[100, 119] -> 
             RGBColor[
              0.1807572108955105, 0.3073176676932546, 0.933605227802945], 
             UndirectedEdge[81, 269] -> 
             RGBColor[
              0.931314896123058, 0.7560543834090069, 0.28986513111217527`], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.8156793803955554, 0.4095785742701399, 0.4412265840334828], 
             UndirectedEdge[180, 233] -> 
             RGBColor[
              0.20014010875548707`, 0.32769032229079487`, 0.9347090551616429],
              UndirectedEdge[33, 184] -> 
             RGBColor[
              0.1959981041281816, 0.3233368128092353, 0.9344731741256647], 
             UndirectedEdge[103, 168] -> 
             RGBColor[
              0.41087052923769096`, 0.5302971342976018, 0.9474012846978503], 
             UndirectedEdge[49, 238] -> 
             RGBColor[
              0.19853266531396374`, 0.3260007973159532, 0.9346175136356476], 
             UndirectedEdge[97, 120] -> 
             RGBColor[
              0.3639742346570427, 0.4869360497143149, 0.944513487615392], 
             UndirectedEdge[117, 212] -> 
             RGBColor[
              0.20943922968905518`, 0.3374642879902957, 0.935238626341993], 
             UndirectedEdge[270, 278] -> 
             RGBColor[
              0.20673456430550685`, 0.3346215131864966, 0.9350845996495938], 
             UndirectedEdge[26, 165] -> 
             RGBColor[
              0.2234449255941841, 0.3521851623989958, 0.9360362300042198], 
             UndirectedEdge[65, 70] -> 
             RGBColor[
              0.2936166091660087, 0.41958665894484415`, 0.940265032379005], 
             UndirectedEdge[56, 223] -> 
             RGBColor[
              0.19042353178656807`, 0.3174775838298989, 0.9341557104776503], 
             UndirectedEdge[207, 212] -> 
             RGBColor[
              0.20932819464730518`, 0.33734758312138824`, 0.935232303060627], 
             UndirectedEdge[171, 184] -> 
             RGBColor[
              0.1853189372548359, 0.31211233132706184`, 0.9338650113706392], 
             UndirectedEdge[32, 205] -> 
             RGBColor[
              0.6800179376878698, 0.7430563957149572, 0.8994244086676673], 
             UndirectedEdge[23, 31] -> 
             RGBColor[
              0.7044976010018857, 0.7638813972041334, 0.8870888196503636], 
             UndirectedEdge[235, 274] -> 
             RGBColor[
              0.43577020330018756`, 0.5515998272739158, 0.9490608562281224], 
             UndirectedEdge[178, 199] -> 
             RGBColor[
              0.2287030477407748, 0.357711782159262, 0.9363356722817735], 
             UndirectedEdge[117, 158] -> 
             RGBColor[
              0.189227738636957, 0.3162207294119929, 0.9340876118267976], 
             UndirectedEdge[112, 190] -> 
             RGBColor[
              0.19682291342577818`, 0.3242037396769393, 0.9345201457949667], 
             UndirectedEdge[64, 213] -> 
             RGBColor[
              0.21883980227157213`, 0.34734488580524786`, 0.9357739750436664],
              UndirectedEdge[127, 205] -> 
             RGBColor[
              0.3605974794488338, 0.48675314536744607`, 0.9441979304200168], 
             UndirectedEdge[121, 263] -> 
             RGBColor[
              0.2176693590934683, 0.34611467581467703`, 0.935707320036189], 
             UndirectedEdge[14, 213] -> 
             RGBColor[
              0.19128445788964016`, 0.31838247175009526`, 0.9342047389455943],
              UndirectedEdge[109, 111] -> 
             RGBColor[
              0.8035074391264327, 0.8444862586698714, 0.8657863480729937], 
             UndirectedEdge[55, 108] -> 
             RGBColor[
              0.22141119699588285`, 0.35004758469634045`, 0.9359204121691784],
              UndirectedEdge[40, 162] -> 
             RGBColor[
              0.8402909601650888, 0.8739220660440041, 0.881352498558146], 
             UndirectedEdge[15, 225] -> 
             RGBColor[
              0.2429863506332136, 0.37272443911292436`, 0.9371490852512447], 
             UndirectedEdge[31, 59] -> 
             RGBColor[
              0.7023281164542653, 0.7629842595904825, 0.9230427930504692], 
             UndirectedEdge[210, 227] -> 
             RGBColor[
              0.7121917692235163, 0.7160827059719499, 0.6161772867558488], 
             UndirectedEdge[52, 93] -> 
             RGBColor[
              0.21993156031517644`, 0.348492392730534, 0.9358361490491385], 
             UndirectedEdge[32, 293] -> 
             RGBColor[
              0.9437174645743351, 0.8134407929799102, 0.5459850021177625], 
             UndirectedEdge[99, 209] -> 
             RGBColor[
              0.18806492725905072`, 0.31499854092731383`, 0.934021391439051], 
             UndirectedEdge[201, 299] -> 
             RGBColor[
              0.8364740278506779, 0.2813609378470366, 0.18256087630231885`], 
             UndirectedEdge[127, 148] -> 
             RGBColor[
              0.29756624946408855`, 0.42638484862682313`, 0.9403930437729009],
              UndirectedEdge[24, 226] -> 
             RGBColor[
              0.9550105750090976, 0.8620208674779115, 0.5674676409131905], 
             UndirectedEdge[144, 264] -> 
             RGBColor[
              0.24692493102232177`, 0.3768641368222969, 0.9373733815777969], 
             UndirectedEdge[148, 217] -> 
             RGBColor[
              0.22316774867338707`, 0.35189383188120626`, 0.9360204451886269],
              UndirectedEdge[230, 288] -> 
             RGBColor[
              0.2004754275788136, 0.3280427636345524, 0.9347281510725716], 
             UndirectedEdge[1, 83] -> 
             RGBColor[
              0.827979798814962, 0.21607057128362597`, 0.1744267929848577], 
             UndirectedEdge[15, 214] -> 
             RGBColor[
              0.22960322819742474`, 0.35865792889393855`, 0.936386936227082], 
             UndirectedEdge[173, 249] -> 
             RGBColor[
              0.20437181857140313`, 0.33213811761322165`, 0.9349500447754056],
              UndirectedEdge[114, 204] -> 
             RGBColor[
              0.3613702020678383, 0.4801637008416135, 0.944710077953264], 
             UndirectedEdge[77, 95] -> 
             RGBColor[
              0.3506695406416134, 0.476194939387312, 0.94363706407864], 
             UndirectedEdge[52, 295] -> 
             RGBColor[
              0.19782793389837072`, 0.3252600799156124, 0.9345773802240863], 
             UndirectedEdge[7, 103] -> 
             RGBColor[
              0.6798246620935919, 0.7464378960430543, 0.9686802958737664], 
             UndirectedEdge[29, 99] -> 
             RGBColor[
              0.19546469586089602`, 0.32277616690028066`, 0.9344427973139495],
              UndirectedEdge[28, 144] -> 
             RGBColor[
              0.19055497770725674`, 0.3176157418266954, 0.9341631961283768], 
             UndirectedEdge[75, 185] -> 
             RGBColor[
              0.43124290556454353`, 0.5458726103470143, 0.9492713561429931], 
             UndirectedEdge[227, 291] -> 
             RGBColor[
              0.9397896555683924, 0.8973624624611904, 0.6368452332520997], 
             UndirectedEdge[76, 192] -> 
             RGBColor[
              0.32876752436481727`, 0.45918363809373036`, 0.9421697538281874],
              UndirectedEdge[59, 72] -> 
             RGBColor[
              0.8812795328447734, 0.4807598783541659, 0.416576044780737], 
             UndirectedEdge[104, 254] -> 
             RGBColor[
              0.32693482661477913`, 0.45759624741671456`, 0.942052975948146], 
             UndirectedEdge[32, 237] -> 
             RGBColor[
              0.879275163275352, 0.4588842161406994, 0.3990636907380568], 
             UndirectedEdge[25, 232] -> 
             RGBColor[
              0.1895116930698092, 0.31651918352467145`, 0.9341037826116756], 
             UndirectedEdge[9, 141] -> 
             RGBColor[
              0.24640393833854723`, 0.3763165404788058, 0.9373437118151957], 
             UndirectedEdge[22, 48] -> 
             RGBColor[
              0.19067565939696252`, 0.3177425859342372, 0.934170068772073], 
             UndirectedEdge[25, 160] -> 
             RGBColor[
              0.19344001775085345`, 0.32064810183461934`, 0.9343274948908254],
              UndirectedEdge[72, 106] -> 
             RGBColor[
              0.8402305064958111, 0.44896653252378993`, 0.44609646287147053`],
              UndirectedEdge[4, 186] -> 
             RGBColor[
              0.2068268311149634, 0.334718491453289, 0.9350898541078958], 
             UndirectedEdge[78, 182] -> 
             RGBColor[
              0.22423750678067705`, 0.3530182154785495, 0.9360813663302717], 
             UndirectedEdge[106, 211] -> 
             RGBColor[
              0.5662966671615951, 0.6472879549936589, 0.9627077142549896], 
             UndirectedEdge[180, 245] -> 
             RGBColor[
              0.2100635516260986, 0.3381204899304254, 0.9352741805527061], 
             UndirectedEdge[136, 280] -> 
             RGBColor[
              0.32731420410911033`, 0.4536040519351767, 0.9422353549515605], 
             UndirectedEdge[82, 140] -> 
             RGBColor[
              0.7493592164876164, 0.32177032281068196`, 0.43038245426354804`],
              UndirectedEdge[50, 219] -> 
             RGBColor[
              0.1830787781409705, 0.30975778206409804`, 0.9337374376231229], 
             UndirectedEdge[251, 278] -> 
             RGBColor[
              0.24311863666183964`, 0.372863480116429, 0.9371566187448754], 
             UndirectedEdge[80, 150] -> 
             RGBColor[
              0.9431089113179686, 0.8053970694161215, 0.30826637148751795`], 
             UndirectedEdge[26, 183] -> 
             RGBColor[
              0.21091795920318307`, 0.3390185264665105, 0.9353228378002383], 
             UndirectedEdge[243, 256] -> 
             RGBColor[
              0.874424572290644, 0.42222750521570074`, 0.3959301794759612], 
             UndirectedEdge[184, 248] -> 
             RGBColor[
              0.20672425378609824`, 0.33461067617687346`, 0.9350840124807664],
              UndirectedEdge[4, 255] -> 
             RGBColor[
              0.2932777706676125, 0.42028873435652747`, 0.9402069895504767], 
             UndirectedEdge[37, 280] -> 
             RGBColor[
              0.2442905970349878, 0.3740952847751871, 0.9372233601543662], 
             UndirectedEdge[188, 260] -> 
             RGBColor[
              0.3070159863730502, 0.43566722665288543`, 0.9409549881356092], 
             UndirectedEdge[70, 266] -> 
             RGBColor[
              0.20395979058864, 0.33170505007925455`, 0.934926580391328], 
             UndirectedEdge[103, 127] -> 
             RGBColor[
              0.3850824421018483, 0.5079607893674816, 0.9457580905890645], 
             UndirectedEdge[37, 268] -> 
             RGBColor[
              0.21580890611804032`, 0.3441592217779706, 0.9356013699915318], 
             UndirectedEdge[186, 196] -> 
             RGBColor[
              0.19808785672818557`, 0.32553327528980713`, 0.9345921824447229],
              UndirectedEdge[139, 274] -> 
             RGBColor[
              0.4518848560948061, 0.5655575295786147, 0.9500876676545675], 
             UndirectedEdge[15, 255] -> 
             RGBColor[
              0.31219697150637127`, 0.44017401398467865`, 0.9412844100497945],
              UndirectedEdge[118, 195] -> 
             RGBColor[
              0.18622253645749176`, 0.31306207138055164`, 0.9339164700084752],
              UndirectedEdge[125, 128] -> 
             RGBColor[
              0.8384430661867497, 0.296495829336185, 0.18444642963665195`], 
             UndirectedEdge[61, 177] -> 
             RGBColor[
              0.2846154792944696, 0.4164792927751083, 0.9395198025437264], 
             UndirectedEdge[117, 276] -> 
             RGBColor[
              0.21344183559868857`, 0.34167128058119267`, 0.9354665688272218],
              UndirectedEdge[7, 154] -> 
             RGBColor[
              0.7178086500945909, 0.778143567686985, 0.971430549102502], 
             UndirectedEdge[59, 198] -> 
             RGBColor[
              0.974799373492677, 0.9805904794680657, 0.9214736253472325], 
             UndirectedEdge[83, 197] -> 
             RGBColor[
              0.8931489612206265, 0.5687594209510818, 0.42014697935815], 
             UndirectedEdge[243, 283] -> 
             RGBColor[
              0.6466191425526432, 0.7139161177704824, 0.899457696684746], 
             UndirectedEdge[95, 225] -> 
             RGBColor[
              0.2575765092536425, 0.3880596208924811, 0.9379799732004728], 
             UndirectedEdge[21, 74] -> 
             RGBColor[
              0.19973960321144332`, 0.32726936557048675`, 0.9346862469634045],
              UndirectedEdge[62, 225] -> 
             RGBColor[
              0.21463682483983898`, 0.34292729004033573`, 0.9355346216966771],
              UndirectedEdge[236, 267] -> 
             RGBColor[
              0.21381850493226368`, 0.3420671839329953, 0.9354880195885366], 
             UndirectedEdge[123, 300] -> 
             RGBColor[
              0.21212454910682327`, 0.34028672895745476`, 0.9353915513102607],
              UndirectedEdge[111, 218] -> 
             RGBColor[
              0.7906966430720825, 0.8363639438748425, 0.9515975962507148], 
             UndirectedEdge[61, 161] -> 
             RGBColor[
              0.23945694414961366`, 0.369014809121365, 0.9369480907732928], 
             UndirectedEdge[58, 180] -> 
             RGBColor[
              0.1930127612329003, 0.32019902814462275`, 0.9343031632641974], 
             UndirectedEdge[188, 236] -> 
             RGBColor[
              0.29364767479578224`, 0.42161628358526776`, 0.9401936825679285],
              UndirectedEdge[41, 268] -> 
             RGBColor[
              0.19682209771404596`, 0.32420288231218963`, 0.9345200993413902],
              UndirectedEdge[65, 138] -> 
             RGBColor[
              0.30437559706733064`, 0.4308950373883661, 0.9408777408234891], 
             UndirectedEdge[241, 291] -> 
             RGBColor[
              0.956499515277976, 0.9665294292639133, 0.9362543369482514], 
             UndirectedEdge[270, 295] -> 
             RGBColor[
              0.20488097831595456`, 0.3326732767873375, 0.9349790406696236], 
             UndirectedEdge[127, 212] -> 
             RGBColor[
              0.2911019408470156, 0.4195904504094406, 0.9400249109602461], 
             UndirectedEdge[105, 274] -> 
             RGBColor[
              0.373443394956703, 0.4953127699434419, 0.9451737605551122], 
             UndirectedEdge[128, 142] -> 
             RGBColor[
              0.839938700425626, 0.30799192948729065`, 0.18587865067287715`], 
             UndirectedEdge[38, 57] -> 
             RGBColor[
              0.18289757268776397`, 0.30956732364368866`, 0.9337271182406324],
              UndirectedEdge[135, 255] -> 
             RGBColor[
              0.28954719045708177`, 0.4163676580228129, 0.9399945385263857], 
             UndirectedEdge[46, 196] -> 
             RGBColor[
              0.2038842250820344, 0.33162562594068223`, 0.9349222770475161], 
             UndirectedEdge[138, 210] -> 
             RGBColor[
              0.35148342859896836`, 0.4711989277702072, 0.9440171598227016], 
             UndirectedEdge[72, 109] -> 
             RGBColor[
              0.8838806914832852, 0.4818355242979183, 0.3734681145578266], 
             UndirectedEdge[277, 282] -> 
             RGBColor[
              0.7168216670755537, 0.7717675564528452, 0.7149933619542863], 
             UndirectedEdge[62, 117] -> 
             RGBColor[
              0.1935934216908487, 0.32080933910192594`, 0.9343362310182673], 
             UndirectedEdge[33, 126] -> 
             RGBColor[
              0.2119973945219809, 0.3401530814267192, 0.9353843100447624], 
             UndirectedEdge[217, 278] -> 
             RGBColor[
              0.20033411359999898`, 0.32789423368299453`, 0.9347201034505334],
              UndirectedEdge[228, 264] -> 
             RGBColor[
              0.3612335072093944, 0.48614499734720384`, 0.9442808957993838], 
             UndirectedEdge[121, 239] -> 
             RGBColor[
              0.2315127682951095, 0.3606649766084402, 0.9364956817107337], 
             UndirectedEdge[56, 84] -> 
             RGBColor[
              0.1934123059271604, 0.32061897495088687`, 0.9343259167434621], 
             UndirectedEdge[45, 120] -> 
             RGBColor[
              0.2895125289687292, 0.4216264024736376, 0.9397986822781397], 
             UndirectedEdge[67, 234] -> 
             RGBColor[
              0.18654108215101917`, 0.31339688310141245`, 0.9339346107144755],
              UndirectedEdge[153, 192] -> 
             RGBColor[
              0.2758432306623323, 0.4052369526728678, 0.9390942768006172], 
             UndirectedEdge[77, 127] -> 
             RGBColor[
              0.3813089695721926, 0.5046923971225378, 0.9455176482562255], 
             UndirectedEdge[36, 152] -> 
             RGBColor[
              0.18192632080115292`, 0.3085464763299341, 0.9336718068825283], 
             UndirectedEdge[22, 122] -> 
             RGBColor[
              0.18679089642314464`, 0.31365945374055604`, 0.9339488372677058],
              UndirectedEdge[68, 218] -> 
             RGBColor[
              0.9220230883129681, 0.9398481441591451, 0.964270119789284], 
             UndirectedEdge[56, 148] -> 
             RGBColor[
              0.2228269723814797, 0.3515356543919468, 0.936001038482936], 
             UndirectedEdge[7, 130] -> 
             RGBColor[
              0.92506143421404, 0.8207777707366587, 0.6185929179813181], 
             UndirectedEdge[58, 296] -> 
             RGBColor[
              0.18917402722894824`, 0.3161642753166758, 0.9340845530415703], 
             UndirectedEdge[104, 116] -> 
             RGBColor[
              0.3112198168736299, 0.4420066574870038, 0.9411240550973782], 
             UndirectedEdge[252, 279] -> 
             RGBColor[
              0.23730450403035436`, 0.36675245808343765`, 0.9368255124927507],
              UndirectedEdge[64, 173] -> 
             RGBColor[
              0.21829574180286104`, 0.34677304375720647`, 0.9357429916048386],
              UndirectedEdge[109, 155] -> 
             RGBColor[
              0.9595624996907148, 0.8684305979471943, 0.514184885580798], 
             UndirectedEdge[151, 258] -> 
             RGBColor[
              0.4689947888884989, 0.5767176597098022, 0.9521890651333698], 
             UndirectedEdge[167, 216] -> 
             RGBColor[
              0.8802031529562763, 0.5482488422470734, 0.22171659205474953`], 
             UndirectedEdge[12, 258] -> 
             RGBColor[
              0.3848908244823526, 0.507794819816456, 0.9457458808837911], 
             UndirectedEdge[151, 239] -> 
             RGBColor[
              0.41770207455751684`, 0.5257103442374987, 0.9491616700514242], 
             UndirectedEdge[136, 226] -> 
             RGBColor[
              0.6894363159019072, 0.7515352642002422, 0.911828216152313], 
             UndirectedEdge[59, 210] -> 
             RGBColor[
              0.7283433684413259, 0.785018817714684, 0.9248382115325371], 
             UndirectedEdge[191, 205] -> 
             RGBColor[
              0.29986821230051, 0.4266293598594382, 0.9406037744698572], 
             UndirectedEdge[212, 276] -> 
             RGBColor[
              0.23737124141047264`, 0.3668226033013362, 0.9368293130878194], 
             UndirectedEdge[218, 292] -> 
             RGBColor[
              0.8704525733936984, 0.8991011858444631, 0.9592520377831382], 
             UndirectedEdge[144, 245] -> 
             RGBColor[
              0.2114412038308669, 0.3395684897458317, 0.9353526358077138], 
             UndirectedEdge[1, 277] -> 
             RGBColor[
              0.8767993326536895, 0.4256141747773018, 0.2705857731385237], 
             UndirectedEdge[64, 239] -> 
             RGBColor[
              0.23644031537818827`, 0.3658441410172859, 0.9367762982274624], 
             UndirectedEdge[128, 256] -> 
             RGBColor[
              0.8359362044780833, 0.2772269917295691, 0.18204585603333756`], 
             UndirectedEdge[7, 81] -> 
             RGBColor[
              0.9138922902616244, 0.7722436147323656, 0.6093859995388808], 
             UndirectedEdge[32, 145] -> 
             RGBColor[
              0.9262900127477325, 0.9421433350511439, 0.920438952214905], 
             UndirectedEdge[84, 247] -> 
             RGBColor[
              0.1926121673846783, 0.3197779786110244, 0.9342803500371666], 
             UndirectedEdge[215, 259] -> 
             RGBColor[
              0.20495150510474192`, 0.33274740491400967`, 0.9349830570659099],
              UndirectedEdge[187, 233] -> 
             RGBColor[
              0.2150678926487934, 0.3433803696388245, 0.9355591703706895], 
             UndirectedEdge[37, 152] -> 
             RGBColor[
              0.20454390254542953`, 0.33231898878067745`, 0.9349598447031511],
              UndirectedEdge[257, 300] -> 
             RGBColor[
              0.20486085687830097`, 0.33265212788059073`, 0.9349778947835161],
              UndirectedEdge[10, 244] -> 
             RGBColor[
              0.1899533548754444, 0.3169833980853699, 0.9341289345981263], 
             UndirectedEdge[98, 157] -> 
             RGBColor[
              0.18079506708635712`, 0.3073574569500555, 0.9336073836570105], 
             UndirectedEdge[13, 271] -> 
             RGBColor[
              0.2779619784734704, 0.40721689761763513`, 0.9392239799901998], 
             UndirectedEdge[202, 203] -> 
             RGBColor[
              0.8900888543770439, 0.6422166578978118, 0.47068879280256504`], 
             UndirectedEdge[166, 195] -> 
             RGBColor[
              0.184909234384039, 0.31168170763319203`, 0.9338416793982484], 
             UndirectedEdge[260, 287] -> 
             RGBColor[
              0.25058425907026255`, 0.38071032261548143`, 0.9375817748966364],
              UndirectedEdge[212, 214] -> 
             RGBColor[
              0.21709951040225656`, 0.3455157287097197, 0.9356748679962401], 
             UndirectedEdge[25, 113] -> 
             RGBColor[
              0.22937411863723062`, 0.3584171202197894, 0.9363738887765662], 
             UndirectedEdge[244, 280] -> 
             RGBColor[
              0.22575834254074034`, 0.3546167102889326, 0.9361679756769326], 
             UndirectedEdge[58, 134] -> 
             RGBColor[
              0.21796998739019388`, 0.34643065521547056`, 0.9357244403729478],
              UndirectedEdge[64, 263] -> 
             RGBColor[
              0.22259690617654707`, 0.3512938402235227, 0.9359879365529176], 
             UndirectedEdge[182, 261] -> 
             RGBColor[
              0.24954002688104543`, 0.37961276837646946`, 0.9375223074182637],
              UndirectedEdge[150, 277] -> 
             RGBColor[
              0.9502103007628988, 0.8290380865568148, 0.362523350207251], 
             UndirectedEdge[86, 202] -> 
             RGBColor[
              0.7757728461762639, 0.551813377715961, 0.4606487739019124], 
             UndirectedEdge[257, 267] -> 
             RGBColor[
              0.19014093188722048`, 0.31718055341781604`, 0.9341396168314517],
              UndirectedEdge[134, 245] -> 
             RGBColor[
              0.2350207777833922, 0.3643521170012733, 0.9366954576614566], 
             UndirectedEdge[187, 297] -> 
             RGBColor[
              0.20836666181027574`, 0.33633695114496726`, 0.9351775451880184],
              UndirectedEdge[75, 292] -> 
             RGBColor[
              0.5533224742847231, 0.6429700886267707, 0.9602576695267473], 
             UndirectedEdge[54, 174] -> 
             RGBColor[
              0.23862082785776215`, 0.3681359978857943, 0.936900475187395], 
             UndirectedEdge[44, 108] -> 
             RGBColor[
              0.27845239042381165`, 0.4093105366510138, 0.9391941231422369], 
             UndirectedEdge[94, 141] -> 
             RGBColor[
              0.5453682927010454, 0.6337189411498153, 0.9602178278094844], 
             UndirectedEdge[185, 262] -> 
             RGBColor[
              0.41669813660407123`, 0.5328210539055609, 0.9483611851595068], 
             UndirectedEdge[40, 202] -> 
             RGBColor[
              0.8074583715423828, 0.5770584081231883, 0.4634704687762633], 
             UndirectedEdge[110, 191] -> 
             RGBColor[
              0.20664696570435293`, 0.3345294415026117, 0.9350796110388486], 
             UndirectedEdge[92, 125] -> 
             RGBColor[
              0.8327679503009816, 0.2528744017865336, 0.1790119322553138], 
             UndirectedEdge[72, 226] -> 
             RGBColor[
              0.8816960164127614, 0.48093210501266836`, 0.40967383423425274`],
              UndirectedEdge[130, 162] -> 
             RGBColor[
              0.9515757296113414, 0.8393631712246421, 0.5204689724050278], 
             UndirectedEdge[29, 43] -> 
             RGBColor[
              0.21042089134742065`, 0.3384960766341818, 0.9352945305211986], 
             UndirectedEdge[152, 268] -> 
             RGBColor[
              0.1937845276020504, 0.3210102035314135, 0.9343471142171944], 
             UndirectedEdge[4, 62] -> 
             RGBColor[
              0.21110734445904222`, 0.33921758237813715`, 0.9353336230103891],
              UndirectedEdge[18, 184] -> 
             RGBColor[
              0.19573226525779447`, 0.3230573993013006, 0.9344580349952694], 
             UndirectedEdge[95, 159] -> 
             RGBColor[
              0.2893985943419117, 0.4215066499569798, 0.9397921938696936], 
             UndirectedEdge[154, 255] -> 
             RGBColor[
              0.43165774296703474`, 0.5471078244024314, 0.9490557746765065], 
             UndirectedEdge[140, 269] -> 
             RGBColor[
              0.8692676326331821, 0.39646501360429004`, 0.22622904167796476`],
              UndirectedEdge[10, 161] -> 
             RGBColor[
              0.19602879349749167`, 0.3233690692821986, 0.9344749218398459], 
             UndirectedEdge[216, 293] -> 
             RGBColor[
              0.8775620673948297, 0.536919768793157, 0.2195471266169376], 
             UndirectedEdge[188, 294] -> 
             RGBColor[
              0.445956916802145, 0.5584408477111231, 0.9502576320388609], 
             UndirectedEdge[32, 282] -> 
             RGBColor[
              0.7141541547436409, 0.7726234711925095, 0.9015995382329896], 
             UndirectedEdge[251, 282] -> 
             RGBColor[
              0.363119718775744, 0.4867984505328162, 0.944436976695407], 
             UndirectedEdge[181, 299] -> 
             RGBColor[
              0.874560587203039, 0.4182728709455591, 0.2441080923447113], 
             UndirectedEdge[60, 159] -> 
             RGBColor[
              0.28925410608148494`, 0.42135478363418655`, 0.9397839654770135],
              UndirectedEdge[137, 217] -> 
             RGBColor[
              0.23078620352350526`, 0.3599013109666169, 0.9364543049218471], 
             UndirectedEdge[20, 152] -> 
             RGBColor[
              0.20076184690853469`, 0.3283438085101236, 0.9347444622296798], 
             UndirectedEdge[62, 196] -> 
             RGBColor[
              0.2023683700722644, 0.33003236621465526`, 0.9348359513472162], 
             UndirectedEdge[251, 289] -> 
             RGBColor[
              0.26452594049436573`, 0.3953639137458709, 0.9383757330288698], 
             UndirectedEdge[104, 283] -> 
             RGBColor[
              0.32045429654903324`, 0.4517126811256811, 0.9416499450537039], 
             UndirectedEdge[45, 294] -> 
             RGBColor[
              0.4179920843483252, 0.5334044550653643, 0.9485055663485399], 
             UndirectedEdge[15, 158] -> 
             RGBColor[
              0.22566086224390924`, 0.3545142523163553, 0.9361624243182372], 
             UndirectedEdge[150, 237] -> 
             RGBColor[
              0.8525195804485002, 0.35269902313604284`, 0.19588243651989107`],
              UndirectedEdge[169, 228] -> 
             RGBColor[
              0.5154980125146456, 0.6168087674389304, 0.9552040569175313], 
             UndirectedEdge[159, 251] -> 
             RGBColor[
              0.2884240455436301, 0.4204823373800232, 0.9397366947573472], 
             UndirectedEdge[203, 293] -> 
             RGBColor[
              0.9184419291701429, 0.7951691860663403, 0.6146917974413972], 
             UndirectedEdge[145, 282] -> 
             RGBColor[
              0.6527680048201097, 0.7255950154401895, 0.9681370826346918], 
             UndirectedEdge[195, 234] -> 
             RGBColor[
              0.18893962070800485`, 0.3159178992009325, 0.934071203936976], 
             UndirectedEdge[156, 270] -> 
             RGBColor[
              0.3036653348674415, 0.42857413928414156`, 0.9408949377483093], 
             UndirectedEdge[25, 134] -> 
             RGBColor[
              0.21795734402989536`, 0.34641736624216146`, 0.935723720352283], 
             UndirectedEdge[158, 276] -> 
             RGBColor[
              0.21715975035837445`, 0.34557904472303347`, 0.935678298572624], 
             UndirectedEdge[268, 280] -> 
             RGBColor[
              0.23353122209160865`, 0.3627864995259231, 0.9366106296684096], 
             UndirectedEdge[8, 186] -> 
             RGBColor[
              0.19879211006828354`, 0.3262734902024908, 0.934632288630592], 
             UndirectedEdge[32, 256] -> 
             RGBColor[
              0.8745107904220526, 0.4222631586287432, 0.39450132191314774`], 
             UndirectedEdge[60, 168] -> 
             RGBColor[
              0.3438394161380286, 0.4702523109805432, 0.9432028328564219], 
             UndirectedEdge[162, 216] -> 
             RGBColor[
              0.9080919042261215, 0.6545799385528897, 0.40453925138773855`], 
             UndirectedEdge[106, 115] -> 
             RGBColor[
              0.6067946716231568, 0.6858798777418896, 0.9651595250499304], 
             UndirectedEdge[77, 276] -> 
             RGBColor[
              0.3275782701356497, 0.45192455001443343`, 0.9423220503837988], 
             UndirectedEdge[80, 281] -> 
             RGBColor[
              0.9786349916305042, 0.9618175926615335, 0.6467591064594813], 
             UndirectedEdge[130, 293] -> 
             RGBColor[
              0.9057809743644036, 0.6628729165850431, 0.24298078524882644`], 
             UndirectedEdge[39, 118] -> 
             RGBColor[
              0.19522260799965463`, 0.322521717208859, 0.9344290107683887], 
             UndirectedEdge[58, 245] -> 
             RGBColor[
              0.20819170713916685`, 0.33615306269286493`, 0.9351675817783212],
              UndirectedEdge[54, 143] -> 
             RGBColor[
              0.2754657226956103, 0.40686231846163223`, 0.9389987374412732], 
             UndirectedEdge[239, 258] -> 
             RGBColor[
              0.28886880526886394`, 0.4180452286151569, 0.9398683740473033], 
             UndirectedEdge[184, 222] -> 
             RGBColor[
              0.2064576757790399, 0.33433048578943325`, 0.9350688312576314], 
             UndirectedEdge[143, 298] -> 
             RGBColor[
              0.28351617500257303`, 0.41532385426440727`, 0.9394571987905778],
              UndirectedEdge[203, 269] -> 
             RGBColor[
              0.9551449948812127, 0.9368848088945971, 0.6707830617471834], 
             UndirectedEdge[107, 139] -> 
             RGBColor[
              0.4245992235592372, 0.5421882392946853, 0.9482760649602114], 
             UndirectedEdge[108, 283] -> 
             RGBColor[
              0.2732531217435669, 0.4045367345740317, 0.9388727330903042], 
             UndirectedEdge[173, 186] -> 
             RGBColor[
              0.19720146830174806`, 0.32460162485334904`, 0.9345417039351314],
              UndirectedEdge[164, 296] -> 
             RGBColor[
              0.18458413953272382`, 0.31134001233225567`, 0.9338231657274008],
              UndirectedEdge[11, 116] -> 
             RGBColor[
              0.4095833128093886, 0.5250728013946587, 0.9479805946176828], 
             UndirectedEdge[43, 229] -> 
             RGBColor[
              0.221649468641255, 0.3502980233029215, 0.935933981386891], 
             UndirectedEdge[128, 149] -> 
             RGBColor[
              0.8617947720920316, 0.43708705040676815`, 0.20528481439629814`],
              UndirectedEdge[221, 232] -> 
             RGBColor[
              0.18705168190288157`, 0.31393355581451393`, 0.9339636886149794],
              UndirectedEdge[8, 85] -> 
             RGBColor[
              0.21830835870760254`, 0.3467863049240477, 0.9357437101188987], 
             UndirectedEdge[20, 41] -> 
             RGBColor[
              0.20379941702053028`, 0.3315364872908998, 0.9349174473538756], 
             UndirectedEdge[108, 252] -> 
             RGBColor[
              0.23931387407336885`, 0.3688644334000649, 0.9369399431441039], 
             UndirectedEdge[65, 241] -> 
             RGBColor[
              0.6817937974014621, 0.7449457823928316, 0.912446971452788], 
             UndirectedEdge[231, 245] -> 
             RGBColor[
              0.2282116135363889, 0.3571952536517242, 0.9363076858308454], 
             UndirectedEdge[80, 167] -> 
             RGBColor[
              0.9432452158034876, 0.8059374712804274, 0.30837604527604406`], 
             UndirectedEdge[17, 201] -> 
             RGBColor[
              0.7981304417837846, 0.4892713331849807, 0.45108208269740613`], 
             UndirectedEdge[57, 223] -> 
             RGBColor[
              0.1805830172649961, 0.30713457914306985`, 0.9335953077333836], 
             UndirectedEdge[162, 202] -> 
             RGBColor[
              0.9081632494131782, 0.6549039003842219, 0.40459878356064916`], 
             UndirectedEdge[3, 59] -> 
             RGBColor[
              0.9696130276591681, 0.9767225112372966, 0.930252756027731], 
             UndirectedEdge[180, 187] -> 
             RGBColor[
              0.20981238961313842`, 0.3378565027302129, 0.9352598772476289], 
             UndirectedEdge[193, 215] -> 
             RGBColor[
              0.252152731139514, 0.38235888620713765`, 0.9376710970606339], 
             UndirectedEdge[43, 78] -> 
             RGBColor[
              0.20985899682898168`, 0.3379054898691324, 0.9352625314596219], 
             UndirectedEdge[56, 251] -> 
             RGBColor[
              0.2424819913817221, 0.3721943255613833, 0.9371203627380049], 
             UndirectedEdge[261, 284] -> 
             RGBColor[
              0.2428470796826115, 0.3725780565135533, 0.937141153976641], 
             UndirectedEdge[36, 41] -> 
             RGBColor[
              0.18496389091314852`, 0.31173915511071026`, 0.9338447920067241],
              UndirectedEdge[95, 168] -> 
             RGBColor[
              0.3439839043984553, 0.4704041773033365, 0.943211061249102], 
             UndirectedEdge[194, 280] -> 
             RGBColor[
              0.4740092277386598, 0.5736772866128733, 0.9537854496422005], 
             UndirectedEdge[99, 182] -> 
             RGBColor[
              0.22500890422772363`, 0.3538290031048185, 0.9361252962737008], 
             UndirectedEdge[94, 97] -> 
             RGBColor[
              0.622873487370591, 0.7022274882781143, 0.9651059553417796], 
             UndirectedEdge[79, 240] -> 
             RGBColor[
              0.18183565807480434`, 0.3084511840561929, 0.9336666437743861], 
             UndirectedEdge[83, 198] -> 
             RGBColor[
              0.8858987442443274, 0.5635903178481945, 0.44308216880395335`], 
             UndirectedEdge[69, 213] -> 
             RGBColor[
              0.20497196381527677`, 0.33276890831593897`, 0.934984222159209], 
             UndirectedEdge[214, 286] -> 
             RGBColor[
              0.21086056333637188`, 0.3389581997713838, 0.9353195691905329], 
             UndirectedEdge[277, 293] -> 
             RGBColor[
              0.946384976906248, 0.8125848782402458, 0.35937882583905917`], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.23002654529780098`, 0.3591028620062883, 0.9364110435097069], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.4656160294018773, 0.5758295097005381, 0.9514105681730911], 
             UndirectedEdge[43, 199] -> 
             RGBColor[
              0.21199067610024028`, 0.34014601993949717`, 0.9353839274405833],
              UndirectedEdge[192, 222] -> 
             RGBColor[
              0.2760214326902352, 0.40542425430285495`, 0.93910442514248], 
             UndirectedEdge[130, 202] -> 
             RGBColor[
              0.8816482178398845, 0.5540191449102804, 0.2228814513408511], 
             UndirectedEdge[4, 265] -> 
             RGBColor[
              0.22162675469537457`, 0.35027414950565383`, 0.9359326878612754],
              UndirectedEdge[121, 173] -> 
             RGBColor[
              0.21336819471978227`, 0.34159387934836083`, 0.9354623750881099],
              UndirectedEdge[53, 107] -> 
             RGBColor[
              0.3121763440598402, 0.43622685441542786`, 0.9414269663560839], 
             UndirectedEdge[172, 238] -> 
             RGBColor[
              0.18901379750666059`, 0.31599586371940025`, 0.9340754281959247],
              UndirectedEdge[210, 211] -> 
             RGBColor[
              0.3712058892361785, 0.49192848437614356`, 0.9451403247792249], 
             UndirectedEdge[180, 221] -> 
             RGBColor[
              0.19054010670567417`, 0.3176001114611562, 0.9341623492468364], 
             UndirectedEdge[196, 212] -> 
             RGBColor[
              0.2182141780704709, 0.3466873151030251, 0.9357383466709418], 
             UndirectedEdge[160, 176] -> 
             RGBColor[
              0.19497852177206426`, 0.3222651671077009, 0.9344151104188206], 
             UndirectedEdge[115, 193] -> 
             RGBColor[
              0.3156462416789386, 0.4451205438424978, 0.9414324679079064], 
             UndirectedEdge[21, 300] -> 
             RGBColor[
              0.2096118710905434, 0.33764574504935696`, 0.9352484580144076], 
             UndirectedEdge[75, 235] -> 
             RGBColor[
              0.3707116092284409, 0.495513496231598, 0.9448423938259995], 
             UndirectedEdge[77, 255] -> 
             RGBColor[
              0.38990028243638014`, 0.512133760513557, 0.9460650791149319], 
             UndirectedEdge[62, 286] -> 
             RGBColor[
              0.21128388043674812`, 0.3394031328837336, 0.935343676473158], 
             UndirectedEdge[46, 225] -> 
             RGBColor[
              0.21615267984960895`, 0.3445205497663627, 0.935620947396977], 
             UndirectedEdge[37, 161] -> 
             RGBColor[
              0.21411146518921928`, 0.3423751037378088, 0.9355047032417743], 
             UndirectedEdge[3, 162] -> 
             RGBColor[
              0.972783323199716, 0.9780335099161923, 0.8777127544589929], 
             UndirectedEdge[107, 274] -> 
             RGBColor[
              0.43576092708699476`, 0.5515917926842843, 0.9490602651560203], 
             UndirectedEdge[6, 147] -> 
             RGBColor[
              0.2119963836374878, 0.34015201892302305`, 0.935384252476386], 
             UndirectedEdge[8, 135] -> 
             RGBColor[
              0.2087723681564475, 0.33676337423806185`, 0.9352006495642442], 
             UndirectedEdge[186, 249] -> 
             RGBColor[
              0.20028634308592377`, 0.3278440238438759, 0.934717382990427], 
             UndirectedEdge[277, 281] -> 
             RGBColor[
              0.9857363810754343, 0.9854586098022267, 0.7010160851792143], 
             UndirectedEdge[256, 277] -> 
             RGBColor[
              0.8762891319766611, 0.42169254880230017`, 0.2700972043940122], 
             UndirectedEdge[8, 249] -> 
             RGBColor[
              0.20596246033793864`, 0.3338099829623634, 0.9350406294708662], 
             UndirectedEdge[114, 254] -> 
             RGBColor[
              0.2789569494583814, 0.4096039374484629, 0.9392315319348887], 
             UndirectedEdge[223, 270] -> 
             RGBColor[
              0.19716475878398335`, 0.32456304082266046`, 0.9345396133824015],
              UndirectedEdge[120, 294] -> 
             RGBColor[
              0.40756986398437334`, 0.5224500406559134, 0.9479120363171062], 
             UndirectedEdge[23, 290] -> 
             RGBColor[
              0.9678787961151241, 0.9075534182585008, 0.5509781065817215], 
             UndirectedEdge[7, 293] -> 
             RGBColor[
              0.9190392263270429, 0.795614649307972, 0.6136807291548138], 
             UndirectedEdge[95, 191] -> 
             RGBColor[
              0.2574665501142888, 0.38794404686520834`, 0.9379737111901566], 
             UndirectedEdge[65, 194] -> 
             RGBColor[
              0.5317344651989768, 0.6279967791452647, 0.9573054453238024], 
             UndirectedEdge[94, 188] -> 
             RGBColor[
              0.5763766141360973, 0.661954233683196, 0.9621432156948482], 
             UndirectedEdge[24, 162] -> 
             RGBColor[
              0.9575561451976635, 0.8630735261690534, 0.5252809551641785], 
             UndirectedEdge[34, 84] -> 
             RGBColor[
              0.1855804331499768, 0.3123871800926523, 0.9338799031750189], 
             UndirectedEdge[130, 201] -> 
             RGBColor[
              0.8675104556731318, 0.4624745923387423, 0.2100136661179885], 
             UndirectedEdge[74, 260] -> 
             RGBColor[
              0.23203447362151203`, 0.3612133219845175, 0.9365253920572785], 
             UndirectedEdge[69, 85] -> 
             RGBColor[
              0.21985867650040533`, 0.3484157872201088, 0.9358319984237091], 
             UndirectedEdge[220, 262] -> 
             RGBColor[
              0.318464636651424, 0.44980618598534605`, 0.9415298717668166], 
             UndirectedEdge[26, 262] -> 
             RGBColor[
              0.26646771810795733`, 0.39740484513356716`, 0.9384863143913613],
              UndirectedEdge[217, 270] -> 
             RGBColor[
              0.20643869531729672`, 0.3343105361207104, 0.9350677503484142], 
             UndirectedEdge[221, 245] -> 
             RGBColor[
              0.20571905261194073`, 0.33355414600939837`, 0.93502676776096], 
             UndirectedEdge[3, 24] -> 
             RGBColor[
              0.9389911914260977, 0.8504167316496911, 0.6099487388884464], 
             UndirectedEdge[59, 197] -> 
             RGBColor[
              0.9856746989571257, 0.9883441341223966, 0.8870708411785275], 
             UndirectedEdge[54, 235] -> 
             RGBColor[
              0.32626536687632174`, 0.4510335953926109, 0.9422293781681247], 
             UndirectedEdge[159, 282] -> 
             RGBColor[
              0.36593647358390397`, 0.4897590384287621, 0.9445973867147164], 
             UndirectedEdge[6, 53] -> 
             RGBColor[
              0.21323620369391516`, 0.3414551484114601, 0.9354548583944501], 
             UndirectedEdge[31, 210] -> 
             RGBColor[
              0.4456637990054052, 0.5599347702274033, 0.949756030710805], 
             UndirectedEdge[137, 273] -> 
             RGBColor[
              0.25023215692458567`, 0.3803402409358096, 0.9375617232003286], 
             UndirectedEdge[99, 259] -> 
             RGBColor[
              0.19041774683741108`, 0.3174715034815479, 0.934155381033354], 
             UndirectedEdge[16, 151] -> 
             RGBColor[
              0.42230921801132515`, 0.5305527441172178, 0.9494240400554605], 
             UndirectedEdge[24, 227] -> 
             RGBColor[
              0.9382342504393061, 0.7928264157474236, 0.2691600319562284], 
             UndirectedEdge[87, 202] -> 
             RGBColor[
              0.9087631737635028, 0.6539246978300517, 0.30544569802749344`], 
             UndirectedEdge[17, 94] -> 
             RGBColor[
              0.7502759773076164, 0.8048405628721153, 0.9757441557565323], 
             UndirectedEdge[5, 92] -> 
             RGBColor[
              0.8780406889079944, 0.46699287511950294`, 0.23253013995633712`],
              UndirectedEdge[72, 290] -> 
             RGBColor[
              0.8684139499629852, 0.42648519406555707`, 0.2091141155204876], 
             UndirectedEdge[103, 212] -> 
             RGBColor[
              0.327349136755672, 0.45098594966848016`, 0.9423345502314089], 
             UndirectedEdge[112, 133] -> 
             RGBColor[
              0.18726032665159403`, 0.3141528546742519, 0.9339755706247563], 
             UndirectedEdge[71, 244] -> 
             RGBColor[
              0.20641030875985014`, 0.33428070004902233`, 0.9350661337759618],
              UndirectedEdge[142, 197] -> 
             RGBColor[
              0.8820709654347386, 0.4836090909320415, 0.4095386780827771], 
             UndirectedEdge[117, 196] -> 
             RGBColor[
              0.1942847722586868, 0.32153599238288155`, 0.9343756024103442], 
             UndirectedEdge[131, 188] -> 
             RGBColor[
              0.2926361203769149, 0.4205530757547836, 0.9401360760402346], 
             UndirectedEdge[13, 282] -> 
             RGBColor[
              0.38696044305919663`, 0.509587419405664, 0.9458777551494157], 
             UndirectedEdge[139, 143] -> 
             RGBColor[
              0.37380885559171856`, 0.49802499695333824`, 0.9450460153054621],
              UndirectedEdge[45, 89] -> 
             RGBColor[
              0.34033954683031736`, 0.4683920819989782, 0.9429369415722573], 
             UndirectedEdge[127, 269] -> 
             RGBColor[
              0.6610000720463691, 0.698853165460656, 0.646849788175898], 
             UndirectedEdge[25, 79] -> 
             RGBColor[
              0.18712823581077753`, 0.3140140188255107, 0.9339680482467827], 
             UndirectedEdge[29, 78] -> 
             RGBColor[
              0.1946932984138494, 0.3219653792740117, 0.9343988673705204], 
             UndirectedEdge[150, 179] -> 
             RGBColor[
              0.7150830892215184, 0.6470263643951079, 0.5999650595216117], 
             UndirectedEdge[11, 198] -> 
             RGBColor[
              0.7482029346182517, 0.8019514484742061, 0.9505539165512161], 
             UndirectedEdge[135, 286] -> 
             RGBColor[
              0.2169836251808333, 0.34539392599445645`, 0.9356682685043168], 
             UndirectedEdge[101, 104] -> 
             RGBColor[
              0.49120791951509923`, 0.5945373978105576, 0.9540278714950781], 
             UndirectedEdge[3, 290] -> 
             RGBColor[
              0.9503146533364857, 0.8953104848043834, 0.619059862137357], 
             UndirectedEdge[158, 212] -> 
             RGBColor[
              0.21315714444874106`, 0.34137205213213645`, 0.9354503560873951],
              UndirectedEdge[102, 175] -> 
             RGBColor[
              0.18740197098760464`, 0.3143017318521686, 0.9339836370601481], 
             UndirectedEdge[103, 255] -> 
             RGBColor[
              0.3936737549660358, 0.5154021527585007, 0.9463055214477708], 
             UndirectedEdge[3, 65] -> 
             RGBColor[
              0.6658408786786703, 0.7333691314923763, 0.9538265746888542], 
             UndirectedEdge[148, 270] -> 
             RGBColor[
              0.22956819937889494`, 0.35862111138470837`, 0.9363849413876872],
              UndirectedEdge[49, 298] -> 
             RGBColor[
              0.23487979924778435`, 0.36420393962179404`, 0.9366874291424127],
              UndirectedEdge[15, 103] -> 
             RGBColor[
              0.33985285455084013`, 0.464128149852699, 0.9430466184622509], 
             UndirectedEdge[4, 15] -> 
             RGBColor[
              0.23945687025241685`, 0.36901473145072583`, 0.9369480865649568],
              UndirectedEdge[83, 290] -> 
             RGBColor[
              0.8798387029608784, 0.5143008519660508, 0.22005447189368316`], 
             UndirectedEdge[182, 284] -> 
             RGBColor[
              0.24765066246750966`, 0.3776269265852207, 0.937414710909977], 
             UndirectedEdge[32, 92] -> 
             RGBColor[
              0.883595180526095, 0.49208976177353947`, 0.4032005441361298], 
             UndirectedEdge[87, 203] -> 
             RGBColor[
              0.9651365709425674, 0.970190636874684, 0.7434503562978652], 
             UndirectedEdge[115, 169] -> 
             RGBColor[
              0.47823384946439584`, 0.5845324223560975, 0.9528296173993749], 
             UndirectedEdge[111, 143] -> 
             RGBColor[
              0.46054913753176646`, 0.5687866450741914, 0.9517800380473413], 
             UndirectedEdge[163, 274] -> 
             RGBColor[
              0.5420984734158494, 0.6391389878337358, 0.9570951240808855], 
             UndirectedEdge[96, 260] -> 
             RGBColor[
              0.22955901197049378`, 0.3586114548359634, 0.9363844181783704], 
             UndirectedEdge[27, 227] -> 
             RGBColor[
              0.9612729955532987, 0.8800632676191081, 0.309071745135731], 
             UndirectedEdge[103, 205] -> 
             RGBColor[
              0.39684467535749024`, 0.5181486446264856, 0.9465075696911796], 
             UndirectedEdge[27, 216] -> 
             RGBColor[
              0.9009229797863709, 0.6276599876230118, 0.25263771646037597`], 
             UndirectedEdge[145, 293] -> 
             RGBColor[
              0.8823313146508039, 0.7664123372275902, 0.6125225465194646], 
             UndirectedEdge[96, 133] -> 
             RGBColor[
              0.19311989172231955`, 0.3203116290814677, 0.9343092641870845], 
             UndirectedEdge[127, 159] -> 
             RGBColor[
              0.3200380232724909, 0.45000410769220556`, 0.9416727780472791], 
             UndirectedEdge[186, 214] -> 
             RGBColor[
              0.19697318905997124`, 0.32436168889650174`, 0.9345287037700212],
              UndirectedEdge[111, 262] -> 
             RGBColor[
              0.459021775002635, 0.5671812902156966, 0.9516930570108376], 
             UndirectedEdge[33, 157] -> 
             RGBColor[
              0.19152225944429985`, 0.31863241626153205`, 0.9342182813923363],
              UndirectedEdge[112, 131] -> 
             RGBColor[
              0.20931958090363292`, 0.3373385295306458, 0.9352318125206677], 
             UndirectedEdge[37, 55] -> 
             RGBColor[
              0.21435260419714997`, 0.34262855612424004`, 0.9355184357515427],
              UndirectedEdge[20, 71] -> 
             RGBColor[
              0.22116050761720274`, 0.349784094264723, 0.9359061357799242], 
             UndirectedEdge[37, 252] -> 
             RGBColor[
              0.23225528127463596`, 0.3614454048279645, 0.9365379667264683], 
             UndirectedEdge[120, 178] -> 
             RGBColor[
              0.2690508208241996, 0.4001198498665095, 0.9386334182696933], 
             UndirectedEdge[113, 231] -> 
             RGBColor[
              0.24940666839475117`, 0.3794726001519578, 0.9375147128497554], 
             UndirectedEdge[7, 181] -> 
             RGBColor[
              0.962306825108859, 0.9594739836095195, 0.6952739648323978], 
             UndirectedEdge[42, 299] -> 
             RGBColor[
              0.8313011225434905, 0.2415997208744344, 0.17760729633819525`], 
             UndirectedEdge[64, 234] -> 
             RGBColor[
              0.2147298520602665, 0.3430250675472716, 0.9355399194592591], 
             UndirectedEdge[78, 261] -> 
             RGBColor[
              0.21943392399577888`, 0.3479693454068822, 0.9358078093969358], 
             UndirectedEdge[10, 100] -> 
             RGBColor[
              0.18553288790448116`, 0.3123372070250937, 0.9338771955436248], 
             UndirectedEdge[6, 88] -> 
             RGBColor[
              0.21672673573205908`, 0.345123918896063, 0.935653639030243], 
             UndirectedEdge[36, 208] -> 
             RGBColor[
              0.1853248284213402, 0.31211852331657947`, 0.9338653468638564], 
             UndirectedEdge[92, 142] -> 
             RGBColor[
              0.8310149903490321, 0.23940038344390055`, 0.17733329582564183`],
              UndirectedEdge[237, 293] -> 
             RGBColor[
              0.8499693645440664, 0.3417302175916635, 0.19378608694109653`], 
             UndirectedEdge[127, 145] -> 
             RGBColor[
              0.6068695545086966, 0.6858400847036329, 0.9652124739672545], 
             UndirectedEdge[90, 285] -> 
             RGBColor[
              0.20767787323688183`, 0.3356129906826123, 0.9351383196977351], 
             UndirectedEdge[134, 176] -> 
             RGBColor[
              0.21949584805110617`, 0.34803443151524305`, 0.9358113358802782],
              UndirectedEdge[28, 297] -> 
             RGBColor[
              0.18773159769962583`, 0.31464819042604353`, 0.9340024088137586],
              UndirectedEdge[20, 136] -> 
             RGBColor[
              0.3058098324986471, 0.43100159391667037`, 0.9410107128012115], 
             UndirectedEdge[113, 134] -> 
             RGBColor[
              0.25621583264175446`, 0.38662946350150684`, 0.9379024846803665],
              UndirectedEdge[12, 181] -> 
             RGBColor[
              0.707957046702949, 0.7559827796524516, 0.6749255302079116], 
             UndirectedEdge[84, 217] -> 
             RGBColor[
              0.19375308221906778`, 0.32097715244014635`, 0.9343453234491528],
              UndirectedEdge[126, 153] -> 
             RGBColor[
              0.2222787641449363, 0.35095945277692997`, 0.9359698188348664], 
             UndirectedEdge[217, 251] -> 
             RGBColor[
              0.24282276767362948`, 0.3725525030506428, 0.9371397694436958], 
             UndirectedEdge[211, 266] -> 
             RGBColor[
              0.23444123912717205`, 0.36374298512871284`, 0.9366624537923354],
              UndirectedEdge[156, 282] -> 
             RGBColor[
              0.41756183526404816`, 0.5360928072628128, 0.9478276488009602], 
             UndirectedEdge[92, 256] -> 
             RGBColor[
              0.8270124944014894, 0.208635445686179, 0.17350050118610227`], 
             UndirectedEdge[56, 246] -> 
             RGBColor[
              0.1919032518459413, 0.3190328634319706, 0.934239978345982], 
             UndirectedEdge[223, 246] -> 
             RGBColor[
              0.1829700916045353, 0.3096435456231802, 0.9337312480856603], 
             UndirectedEdge[66, 228] -> 
             RGBColor[
              0.40629940527691566`, 0.5263378564741489, 0.9471100167211559], 
             UndirectedEdge[170, 261] -> 
             RGBColor[
              0.22115645505495063`, 0.3497798347648488, 0.9359059049924991], 
             UndirectedEdge[104, 287] -> 
             RGBColor[
              0.2890443879522816, 0.41869887568726627`, 0.9398611972259145], 
             UndirectedEdge[255, 258] -> 
             RGBColor[
              0.3530896957607064, 0.48025028048897034`, 0.9437195410822816], 
             UndirectedEdge[27, 162] -> 
             RGBColor[
              0.9805948903116561, 0.9503103780407378, 0.565192668343681], 
             UndirectedEdge[162, 169] -> 
             RGBColor[
              0.7980436197485294, 0.8403418316253028, 0.877535691789008], 
             UndirectedEdge[90, 166] -> 
             RGBColor[
              0.20088523531551122`, 0.3284734975491328, 0.9347514890169203], 
             UndirectedEdge[74, 257] -> 
             RGBColor[
              0.19498858899920085`, 0.3222757484017205, 0.9344156837325129], 
             UndirectedEdge[82, 203] -> 
             RGBColor[
              0.7752823706628642, 0.824842772704185, 0.9770131806255582], 
             UndirectedEdge[1, 142] -> 
             RGBColor[
              0.822440800922018, 0.17349540627410584`, 0.16912264234717125`], 
             UndirectedEdge[82, 145] -> 
             RGBColor[
              0.7391717561435251, 0.7960859238654349, 0.9748439297036255], 
             UndirectedEdge[77, 203] -> 
             RGBColor[
              0.6754538924070363, 0.7427240405564789, 0.9694509218275109], 
             UndirectedEdge[12, 27] -> 
             RGBColor[
              0.6997308165084448, 0.7282337735956864, 0.6429681792954851], 
             UndirectedEdge[54, 185] -> 
             RGBColor[
              0.3867966632124244, 0.5013927095080272, 0.9466583404851183], 
             UndirectedEdge[35, 165] -> 
             RGBColor[
              0.2120938524489715, 0.3402544648237721, 0.9353898031810077], 
             UndirectedEdge[60, 95] -> 
             RGBColor[
              0.28741190007160666`, 0.4194185083151971, 0.9396790545700505], 
             UndirectedEdge[47, 112] -> 
             RGBColor[
              0.18666547155784385`, 0.31352762425472913`, 0.9339416945071765],
              UndirectedEdge[24, 59] -> 
             RGBColor[
              0.9543858496571156, 0.8617625274901577, 0.5778209567329167], 
             UndirectedEdge[239, 285] -> 
             RGBColor[
              0.21862787921736482`, 0.3471221412385783, 0.9357619063392415], 
             UndirectedEdge[173, 286] -> 
             RGBColor[
              0.2110888425781487, 0.3391981357282311, 0.9353325693556434], 
             UndirectedEdge[17, 40] -> 
             RGBColor[
              0.6964483919711273, 0.7627900441024493, 0.9703791250975754], 
             UndirectedEdge[226, 241] -> 
             RGBColor[
              0.9861906717339419, 0.9885575021255057, 0.8785198369719385], 
             UndirectedEdge[255, 286] -> 
             RGBColor[
              0.2934543066453184, 0.4204742848621239, 0.9402170430132455], 
             UndirectedEdge[95, 271] -> 
             RGBColor[
              0.25509580298829937`, 0.3854522413217438, 0.9378387006485376], 
             UndirectedEdge[189, 260] -> 
             RGBColor[
              0.23700170640282697`, 0.36643419857842796`, 0.936808268615812], 
             UndirectedEdge[193, 245] -> 
             RGBColor[
              0.2524031222436139, 0.38262206313325964`, 0.9376853564635919], 
             UndirectedEdge[84, 223] -> 
             RGBColor[
              0.1844791456857544, 0.31122965714209644`, 0.9338171864831403], 
             UndirectedEdge[44, 61] -> 
             RGBColor[
              0.29673927658547317`, 0.4285312134624696, 0.9402355342561197], 
             UndirectedEdge[262, 292] -> 
             RGBColor[
              0.5387777053242508, 0.6299185321853173, 0.9593474985432611], 
             UndirectedEdge[153, 248] -> 
             RGBColor[
              0.2215139470361167, 0.3501555815033551, 0.9359262636319645], 
             UndirectedEdge[78, 99] -> 
             RGBColor[
              0.19490280134245708`, 0.32218558013523124`, 0.9344107982523728],
              UndirectedEdge[199, 261] -> 
             RGBColor[
              0.22156560326703745`, 0.35020987547724697`, 0.9359292053778969],
              UndirectedEdge[58, 215] -> 
             RGBColor[
              0.20794131603506694`, 0.33588988576674306`, 0.935153322375363], 
             UndirectedEdge[23, 197] -> 
             RGBColor[
              0.9878441835047461, 0.9892412717360475, 0.8511168677784218], 
             UndirectedEdge[196, 214] -> 
             RGBColor[
              0.20194505297188817`, 0.32958743310230554`, 0.9348118440645912],
              UndirectedEdge[88, 289] -> 
             RGBColor[
              0.23315152394890182`, 0.3623874127036856, 0.9365890064208955], 
             UndirectedEdge[47, 96] -> 
             RGBColor[
              0.19252503662856937`, 0.3196863986619449, 0.9342753880695046], 
             UndirectedEdge[179, 205] -> 
             RGBColor[
              0.44755823847840226`, 0.5601887588135859, 0.9502599417033248], 
             UndirectedEdge[72, 194] -> 
             RGBColor[
              0.7816121517042992, 0.4029477795624471, 0.4403138133077221], 
             UndirectedEdge[140, 299] -> 
             RGBColor[
              0.8177772995946797, 0.13764969151287093`, 0.16465686820944062`],
              UndirectedEdge[134, 297] -> 
             RGBColor[
              0.21839610407426302`, 0.3468785308677854, 0.9357487070877224], 
             UndirectedEdge[67, 195] -> 
             RGBColor[
              0.18132553855698572`, 0.30791501609952, 0.9336375932225005], 
             UndirectedEdge[24, 155] -> 
             RGBColor[
              0.9250389254998768, 0.7405113494439601, 0.2585427637758789], 
             UndirectedEdge[156, 277] -> 
             RGBColor[
              0.6937513555235839, 0.7517852121341029, 0.7135233421024703], 
             UndirectedEdge[267, 272] -> 
             RGBColor[
              0.18764714248222777`, 0.31455942263778813`, 0.9339975992140681],
              UndirectedEdge[71, 177] -> 
             RGBColor[
              0.2576442825267533, 0.3881308548995943, 0.9379838327881149], 
             UndirectedEdge[188, 281] -> 
             RGBColor[
              0.66716299452805, 0.7330554302274623, 0.9326197293964239], 
             UndirectedEdge[1, 150] -> 
             RGBColor[
              0.848265408272229, 0.31999959159908814`, 0.19180863643949353`], 
             UndirectedEdge[84, 246] -> 
             RGBColor[
              0.1859588657451276, 0.3127849367441682, 0.9339014543514719], 
             UndirectedEdge[58, 230] -> 
             RGBColor[
              0.19161321755920613`, 0.31872801900737613`, 0.9342234613224198],
              UndirectedEdge[74, 189] -> 
             RGBColor[
              0.21086862151855923`, 0.33896666943178094`, 0.9353200280920875],
              UndirectedEdge[48, 71] -> 
             RGBColor[
              0.2080633650262977, 0.3360181669948795, 0.9351602728848583], 
             UndirectedEdge[80, 205] -> 
             RGBColor[
              0.6755840605748524, 0.7185594638345996, 0.6585612536692309], 
             UndirectedEdge[1, 32] -> 
             RGBColor[
              0.8750209910990808, 0.42618478460374476`, 0.39498989065765927`],
              UndirectedEdge[229, 233] -> 
             RGBColor[
              0.2115539796555496, 0.3396870242879735, 0.9353590582240927], 
             UndirectedEdge[54, 172] -> 
             RGBColor[
              0.21731047913351847`, 0.34573747022246615`, 0.935686882353385], 
             UndirectedEdge[61, 194] -> 
             RGBColor[
              0.4816323907254858, 0.581689714248477, 0.9542195774968412], 
             UndirectedEdge[177, 194] -> 
             RGBColor[
              0.4889886310377472, 0.5894215892292383, 0.9546385045000421], 
             UndirectedEdge[7, 42] -> 
             RGBColor[
              0.8711763850077039, 0.5112078638480927, 0.45219338209118976`], 
             UndirectedEdge[26, 75] -> 
             RGBColor[
              0.28101248706842963`, 0.4104564015750206, 0.9393964853748475], 
             UndirectedEdge[170, 190] -> 
             RGBColor[
              0.2009954787857768, 0.3285893704262217, 0.9347577672194614], 
             UndirectedEdge[20, 36] -> 
             RGBColor[
              0.200168643680248, 0.32772031430593734`, 0.9347106801833944], 
             UndirectedEdge[119, 161] -> 
             RGBColor[
              0.191253116488521, 0.3183495299503595, 0.9342029540991661], 
             UndirectedEdge[212, 225] -> 
             RGBColor[
              0.23048263283804543`, 0.3595822389287055, 0.9364370170204028], 
             UndirectedEdge[102, 253] -> 
             RGBColor[
              0.1920226425007294, 0.3191583505799577, 0.9342467774671497], 
             UndirectedEdge[91, 179] -> 
             RGBColor[
              0.5064577791876668, 0.6102042666643193, 0.9542893580750782], 
             UndirectedEdge[118, 239] -> 
             RGBColor[
              0.213148543369447, 0.34136301185245843`, 0.9354498662686535], 
             UndirectedEdge[105, 298] -> 
             RGBColor[
              0.27198901083979987`, 0.403208073864912, 0.938800743844419], 
             UndirectedEdge[90, 239] -> 
             RGBColor[
              0.2266260849573989, 0.3555287625868876, 0.9362173923238513], 
             UndirectedEdge[208, 252] -> 
             RGBColor[
              0.21362941037883332`, 0.3418684335680528, 0.935477250933459], 
             UndirectedEdge[117, 214] -> 
             RGBColor[
              0.19317010459047246`, 0.32036440598957616`, 0.9343121237356424],
              UndirectedEdge[179, 282] -> 
             RGBColor[
              0.48169445553417334`, 0.5897558342911382, 0.9524350712686471], 
             UndirectedEdge[44, 268] -> 
             RGBColor[
              0.2606344226816996, 0.39058272282964934`, 0.9381794162386446], 
             UndirectedEdge[53, 124] -> 
             RGBColor[
              0.20090092998575032`, 0.32848999364265374`, 0.9347523828051723],
              UndirectedEdge[42, 81] -> 
             RGBColor[
              0.8548914543976673, 0.39035727136327797`, 0.1989221405255734], 
             UndirectedEdge[173, 213] -> 
             RGBColor[
              0.20183100425593847`, 0.3294675606707361, 0.9348053491589379], 
             UndirectedEdge[119, 122] -> 
             RGBColor[
              0.18294597115910344`, 0.30961819350570674`, 0.933729874461976], 
             UndirectedEdge[68, 111] -> 
             RGBColor[
              0.7455301616880299, 0.8011614727150247, 0.9754440364810864], 
             UndirectedEdge[34, 53] -> 
             RGBColor[
              0.1997851700209307, 0.32731725917636056`, 0.9346888419257947], 
             UndirectedEdge[85, 263] -> 
             RGBColor[
              0.22101888131475306`, 0.34963523604122215`, 0.9358980703715171],
              UndirectedEdge[37, 208] -> 
             RGBColor[
              0.20794241016561682`, 0.3358910357673228, 0.9351533846844792], 
             UndirectedEdge[256, 293] -> 
             RGBColor[
              0.8452049916907669, 0.30510916007970723`, 0.18922371811618746`],
              UndirectedEdge[76, 153] -> 
             RGBColor[
              0.27399346070364045`, 0.40363477490679034`, 0.9389764110945367],
              UndirectedEdge[135, 213] -> 
             RGBColor[
              0.20772578685862308`, 0.3356633509369615, 0.9351410483076115], 
             UndirectedEdge[36, 55] -> 
             RGBColor[
              0.19173502245287335`, 0.3188560436734967, 0.9342303979309199], 
             UndirectedEdge[121, 135] -> 
             RGBColor[
              0.21926297732246688`, 0.3477896696145861, 0.9357980742367835], 
             UndirectedEdge[83, 226] -> 
             RGBColor[
              0.8931207694106547, 0.5687477629131621, 0.4206141906074483], 
             UndirectedEdge[60, 127] -> 
             RGBColor[
              0.3180513290021859, 0.44791596605042294`, 0.941559638747636], 
             UndirectedEdge[247, 271] -> 
             RGBColor[
              0.21019581629378764`, 0.33825950848223085`, 0.9352817128298629],
              UndirectedEdge[202, 269] -> 
             RGBColor[
              0.902102123055933, 0.6317208125099938, 0.2570008349937056], 
             UndirectedEdge[190, 284] -> 
             RGBColor[
              0.22268610341343767`, 0.3513875921749262, 0.9359930162036031], 
             UndirectedEdge[53, 217] -> 
             RGBColor[
              0.2079578190900217, 0.3359072315238546, 0.9351542621999286], 
             UndirectedEdge[42, 87] -> 
             RGBColor[
              0.8894525062895627, 0.5226189282859114, 0.2876243328405072], 
             UndirectedEdge[205, 225] -> 
             RGBColor[
              0.29997817143986366`, 0.426744933886711, 0.9406100364801734], 
             UndirectedEdge[110, 246] -> 
             RGBColor[
              0.18518351558803503`, 0.3119699945690246, 0.9338572993070533], 
             UndirectedEdge[191, 251] -> 
             RGBColor[
              0.25649200131600725`, 0.38691973428825177`, 0.9379182120778102],
              UndirectedEdge[23, 83] -> 
             RGBColor[
              0.8941506088744137, 0.5691736279970934, 0.4035470855538621], 
             UndirectedEdge[226, 291] -> 
             RGBColor[
              0.956565980138184, 0.9665569141916783, 0.9351528422090618], 
             UndirectedEdge[60, 276] -> 
             RGBColor[
              0.26432062956564295`, 0.39514811894231855`, 0.9383640408752093],
              UndirectedEdge[27, 155] -> 
             RGBColor[
              0.9480776706138694, 0.8277482013156446, 0.2984544769553814], 
             UndirectedEdge[167, 203] -> 
             RGBColor[
              0.9224035575123126, 0.8121627962472151, 0.6179459955981152], 
             UndirectedEdge[137, 271] -> 
             RGBColor[
              0.24208469003989352`, 0.37177673666076144`, 0.9370977370143425],
              UndirectedEdge[52, 247] -> 
             RGBColor[
              0.1982447360653234, 0.3256981654198634, 0.9346011164908907], 
             UndirectedEdge[81, 299] -> 
             RGBColor[
              0.8422842306382159, 0.2934526250274564, 0.1868494488157], 
             UndirectedEdge[31, 290] -> 
             RGBColor[
              0.683029742131583, 0.6815722331575694, 0.6118498991600951], 
             UndirectedEdge[79, 288] -> 
             RGBColor[
              0.19600308919068352`, 0.3233420524259961, 0.9344734580175993], 
             UndirectedEdge[237, 281] -> 
             RGBColor[
              0.8762036339901905, 0.45697937196631744`, 0.42154425983453325`],
              UndirectedEdge[43, 215] -> 
             RGBColor[
              0.22516415254335911`, 0.35399217892786317`, 0.9361341374356069],
              UndirectedEdge[56, 295] -> 
             RGBColor[
              0.19813975131853928`, 0.3255878197945759, 0.9345951377648724], 
             UndirectedEdge[89, 94] -> 
             RGBColor[
              0.5888165791799138, 0.6727291061533267, 0.962935879267211], 
             UndirectedEdge[92, 237] -> 
             RGBColor[
              0.829394680828139, 0.22694597444215714`, 0.1757816855985568], 
             UndirectedEdge[126, 285] -> 
             RGBColor[
              0.21158401439278246`, 0.3397185927011176, 0.9353607686579457], 
             UndirectedEdge[4, 214] -> 
             RGBColor[
              0.21068402735866598`, 0.33877264926578743`, 0.9353095157277642],
              UndirectedEdge[220, 222] -> 
             RGBColor[
              0.2772575054008418, 0.4064948783579615, 0.9391831866025837], 
             UndirectedEdge[199, 209] -> 
             RGBColor[
              0.1894252090832627, 0.31642828337140966`, 0.9340988574765833], 
             UndirectedEdge[290, 291] -> 
             RGBColor[
              0.9366428804635196, 0.8848865477710113, 0.6343132641384139], 
             UndirectedEdge[91, 150] -> 
             RGBColor[
              0.6987841041568563, 0.6337941140587057, 0.5986819437121721], 
             UndirectedEdge[60, 148] -> 
             RGBColor[
              0.2667823322730826, 0.39773552456880407`, 0.9385042312026353], 
             UndirectedEdge[81, 140] -> 
             RGBColor[
              0.8413676314488565, 0.2864072420017145, 0.18597171239681876`], 
             UndirectedEdge[142, 256] -> 
             RGBColor[
              0.8259330961925325, 0.20033871805682574`, 0.1724668682421993], 
             UndirectedEdge[30, 123] -> 
             RGBColor[
              0.2239498078006626, 0.3527158256093854, 0.9360649822989724], 
             UndirectedEdge[53, 289] -> 
             RGBColor[
              0.22966099191075792`, 0.3587186422190827, 0.9363902257851027], 
             UndirectedEdge[274, 289] -> 
             RGBColor[
              0.3532455749379125, 0.4740835804879391, 0.944023524585039], 
             UndirectedEdge[11, 114] -> 
             RGBColor[
              0.38547343504917886`, 0.49973179121413747`, 0.9466075727466067],
              UndirectedEdge[137, 247] -> 
             RGBColor[
              0.22964528868911577`, 0.358702137137495, 0.9363893315098609], 
             UndirectedEdge[84, 191] -> 
             RGBColor[
              0.2074223158614455, 0.3353443836777553, 0.9351237660832672], 
             UndirectedEdge[17, 120] -> 
             RGBColor[
              0.4913767245940681, 0.5895491243083159, 0.9551516880301447], 
             UndirectedEdge[126, 222] -> 
             RGBColor[
              0.22245696617283922`, 0.3511467544069171, 0.9359799671767292], 
             UndirectedEdge[184, 224] -> 
             RGBColor[
              0.20007875304145373`, 0.32762583354516883`, 0.9347055610444963],
              UndirectedEdge[278, 295] -> 
             RGBColor[
              0.1987763965986568, 0.3262569743496216, 0.9346313937717428], 
             UndirectedEdge[28, 245] -> 
             RGBColor[
              0.204356271408755, 0.33212177655953135`, 0.9349491593874928], 
             UndirectedEdge[14, 186] -> 
             RGBColor[
              0.18665492193544975`, 0.31351653593270823`, 0.9339410937217879],
              UndirectedEdge[227, 241] -> 
             RGBColor[
              0.9694143471641505, 0.9193630503950179, 0.5802122280149764], 
             UndirectedEdge[121, 154] -> 
             RGBColor[
              0.3613735298324199, 0.47852983599420473`, 0.9448593103869043], 
             UndirectedEdge[187, 230] -> 
             RGBColor[
              0.20841284593944426`, 0.3363854935929662, 0.9351801753058513], 
             UndirectedEdge[125, 277] -> 
             RGBColor[
              0.8878000437756458, 0.5101704610030093, 0.28112006653243526`], 
             UndirectedEdge[62, 158] -> 
             RGBColor[
              0.1973113364505346, 0.3247171032437667, 0.9345479607636695], 
             UndirectedEdge[20, 61] -> 
             RGBColor[
              0.248131704384919, 0.378132532140237, 0.9374421055355356], 
             UndirectedEdge[64, 258] -> 
             RGBColor[
              0.28773302970917036`, 0.41685145648958927`, 0.939803693309408], 
             UndirectedEdge[94, 294] -> 
             RGBColor[
              0.6664691166979216, 0.7377414792197128, 0.9685045040434936], 
             UndirectedEdge[125, 237] -> 
             RGBColor[
              0.8318212025230813, 0.24559728349806995`, 0.17810532551399777`],
              UndirectedEdge[267, 300] -> 
             RGBColor[
              0.210925999504364, 0.33902697733283615`, 0.935323295683496], 
             UndirectedEdge[165, 175] -> 
             RGBColor[
              0.2002014223302363, 0.3277547667453615, 0.9347125468790196], 
             UndirectedEdge[67, 263] -> 
             RGBColor[
              0.19440813626729972`, 0.3216656557776636, 0.934382627808134], 
             UndirectedEdge[163, 298] -> 
             RGBColor[
              0.44064408929894633`, 0.5470342917552059, 0.9507221073701924], 
             UndirectedEdge[92, 149] -> 
             RGBColor[
              0.8528710620154377, 0.368495504363378, 0.19673945954906286`], 
             UndirectedEdge[95, 276] -> 
             RGBColor[
              0.2644651178260697, 0.3952999852651118, 0.9383722692678894], 
             UndirectedEdge[70, 231] -> 
             RGBColor[
              0.2204752799716199, 0.3490638765632734, 0.9358671130792118], 
             UndirectedEdge[239, 263] -> 
             RGBColor[
              0.22373268173624067`, 0.3524876123490904, 0.9360526172908128], 
             UndirectedEdge[116, 204] -> 
             RGBColor[
              0.38548007982804805`, 0.5055047110221348, 0.9460830998243401], 
             UndirectedEdge[121, 258] -> 
             RGBColor[
              0.28280548262609156`, 0.41167229208074363`, 0.9395230767926794],
              UndirectedEdge[95, 148] -> 
             RGBColor[
              0.2669268205335093, 0.3978873908915973, 0.9385124595953154], 
             UndirectedEdge[60, 77] -> 
             RGBColor[
              0.3505250523811867, 0.47604307306451876`, 0.9436288356859599], 
             UndirectedEdge[42, 269] -> 
             RGBColor[
              0.8827914555819929, 0.5004150429658535, 0.23917946980671936`], 
             UndirectedEdge[61, 136] -> 
             RGBColor[
              0.33493736709593636`, 0.46161647957078045`, 0.9426694828062012],
              UndirectedEdge[95, 251] -> 
             RGBColor[
              0.2865818395337517, 0.41854606206103384`, 0.9396317838503843], 
             UndirectedEdge[158, 265] -> 
             RGBColor[
              0.20783074668686696`, 0.3357736703712833, 0.9351470256145558], 
             UndirectedEdge[152, 208] -> 
             RGBColor[
              0.1859180316496269, 0.31274201752076575`, 0.9338991289101417], 
             UndirectedEdge[153, 285] -> 
             RGBColor[
              0.21037441724900163`, 0.3384472294101154, 0.9352918838900459], 
             UndirectedEdge[61, 279] -> 
             RGBColor[
              0.25696298277753227`, 0.387414765666264, 0.9379450337752894], 
             UndirectedEdge[82, 168] -> 
             RGBColor[
              0.5069255349638632, 0.6091474742003642, 0.9547231011630586], 
             UndirectedEdge[4, 249] -> 
             RGBColor[
              0.21399718138461848`, 0.3422549842131616, 0.93549819494817], 
             UndirectedEdge[75, 163] -> 
             RGBColor[
              0.47703987934410275`, 0.583052656791418, 0.9528766616787626], 
             UndirectedEdge[59, 290] -> 
             RGBColor[
              0.9657093115675036, 0.9066562806448499, 0.5869320799818273], 
             UndirectedEdge[205, 251] -> 
             RGBColor[
              0.3289835017199729, 0.45723137505526373`, 0.9422618471300848], 
             UndirectedEdge[183, 224] -> 
             RGBColor[
              0.2007040206651831, 0.3282830294619655, 0.9347411691106672], 
             UndirectedEdge[170, 178] -> 
             RGBColor[
              0.228293899528688, 0.35728174144686387`, 0.9363123718963757], 
             UndirectedEdge[102, 238] -> 
             RGBColor[
              0.18981943468321613`, 0.3168426394723074, 0.9341213080412961], 
             UndirectedEdge[89, 236] -> 
             RGBColor[
              0.30608763983959875`, 0.4323911560553985, 0.9409863461402914], 
             UndirectedEdge[65, 231] -> 
             RGBColor[
              0.30432205873480145`, 0.4308387652063516, 0.9408746918946544], 
             UndirectedEdge[25, 245] -> 
             RGBColor[
              0.2081790637788683, 0.33613977371955583`, 0.9351668617576563], 
             UndirectedEdge[217, 223] -> 
             RGBColor[
              0.19076430807847547`, 0.31783576131915836`, 0.9341751171833412],
              UndirectedEdge[254, 283] -> 
             RGBColor[
              0.3123013068939945, 0.44465097126766145`, 0.9411304437622906], 
             UndirectedEdge[168, 205] -> 
             RGBColor[
              0.3863855665846765, 0.5090894902975664, 0.9458411245288025], 
             UndirectedEdge[142, 243] -> 
             RGBColor[
              0.8824295641857295, 0.48375738073114377`, 0.40359576875504033`],
              UndirectedEdge[57, 278] -> 
             RGBColor[
              0.19015282278651957`, 0.31719305150690597`, 0.9341402940005757],
              UndirectedEdge[185, 218] -> 
             RGBColor[
              0.7483730046735189, 0.8020037075647066, 0.948265724399384], 
             UndirectedEdge[16, 248] -> 
             RGBColor[
              0.23437455245828825`, 0.36367289321153695`, 0.9366586560851965],
              UndirectedEdge[184, 275] -> 
             RGBColor[
              0.18583227383419235`, 0.31265188061938454`, 0.9338942451294201],
              UndirectedEdge[127, 191] -> 
             RGBColor[
              0.28810597904486807`, 0.41644150460043405`, 0.9398542953677421],
              UndirectedEdge[33, 153] -> 
             RGBColor[
              0.21078779737820008`, 0.338881718135717, 0.9353154252768627], 
             UndirectedEdge[83, 243] -> 
             RGBColor[
              0.8935075599716172, 0.5689077107501841, 0.41420407003041315`], 
             UndirectedEdge[94, 281] -> 
             RGBColor[
              0.8876751944238266, 0.9123560617360518, 0.9508666014010566], 
             UndirectedEdge[140, 293] -> 
             RGBColor[
              0.8447989221591355, 0.30198793171878546`, 0.18883486547410736`],
              UndirectedEdge[126, 220] -> 
             RGBColor[
              0.27828890051671973`, 0.40757894001897654`, 0.9392419230286206],
              UndirectedEdge[76, 220] -> 
             RGBColor[
              0.3300035970754238, 0.4602542621488369, 0.942248515288291], 
             UndirectedEdge[90, 126] -> 
             RGBColor[
              0.2195822201328165, 0.34812521404942687`, 0.9358162546425555], 
             UndirectedEdge[35, 102] -> 
             RGBColor[
              0.19929440110633984`, 0.32680142993057915`, 0.9346608933621363],
              UndirectedEdge[105, 235] -> 
             RGBColor[
              0.34616703863432685`, 0.47195151424914406`, 0.9433627489328582],
              UndirectedEdge[21, 287] -> 
             RGBColor[
              0.21828938866019382`, 0.34676636620145074`, 0.9357426298027625],
              UndirectedEdge[160, 245] -> 
             RGBColor[
              0.2105034515043503, 0.33858285259373117`, 0.935299232199999], 
             UndirectedEdge[235, 298] -> 
             RGBColor[
              0.33431581918328446`, 0.4594951311953859, 0.9426878395174293], 
             UndirectedEdge[15, 196] -> 
             RGBColor[
              0.23071789586563907`, 0.35982951528724394`, 0.9364504149017838],
              UndirectedEdge[13, 274] -> 
             RGBColor[
              0.3981676494624695, 0.5190303850989934, 0.9466648547482157], 
             UndirectedEdge[2, 172] -> 
             RGBColor[
              0.19458761473709335`, 0.321854299029009, 0.9343928488414741], 
             UndirectedEdge[247, 295] -> 
             RGBColor[
              0.1973396127760572, 0.3247468234547135, 0.9345495710585769], 
             UndirectedEdge[159, 225] -> 
             RGBColor[
              0.2594187152635208, 0.38999589621147046`, 0.9380848841074358], 
             UndirectedEdge[204, 254] -> 
             RGBColor[
              0.40119508956919725`, 0.5210943009518455, 0.9470120206751078], 
             UndirectedEdge[61, 252] -> 
             RGBColor[
              0.2576007602350303, 0.3880851102115208, 0.9379813542579867], 
             UndirectedEdge[4, 173] -> 
             RGBColor[
              0.21091230660044274`, 0.33901258522263467`, 0.9353225158928745],
              UndirectedEdge[230, 245] -> 
             RGBColor[
              0.20866400795240445`, 0.3366494807931788, 0.9351944786109285], 
             UndirectedEdge[137, 295] -> 
             RGBColor[
              0.2292284865221631, 0.35826405163324404`, 0.9363655952430565], 
             UndirectedEdge[109, 192] -> 
             RGBColor[
              0.6617142280646152, 0.7260405303844142, 0.8555444013688691], 
             UndirectedEdge[178, 229] -> 
             RGBColor[
              0.23836184028178953`, 0.36786378552268634`, 0.9368857262280812],
              UndirectedEdge[91, 93] -> 
             RGBColor[
              0.3656444287828603, 0.48387268995411137`, 0.9450248073537576], 
             UndirectedEdge[143, 185] -> 
             RGBColor[
              0.41822549913320267`, 0.5344264087640556, 0.9484481661960105], 
             UndirectedEdge[139, 273] -> 
             RGBColor[
              0.3398266519904991, 0.46230754637230465`, 0.9431107790825377], 
             UndirectedEdge[130, 281] -> 
             RGBColor[
              0.9451323785335899, 0.8357466481470239, 0.5846180445889815], 
             UndirectedEdge[220, 248] -> 
             RGBColor[
              0.27752408340790014`, 0.40677506874540165`, 0.9391983678257189],
              UndirectedEdge[88, 273] -> 
             RGBColor[
              0.23089430452924603`, 0.3600149319776501, 0.936460461114203], 
             UndirectedEdge[24, 218] -> 
             RGBColor[
              0.945476791560533, 0.8552536816107574, 0.5989703095762722], 
             UndirectedEdge[66, 215] -> 
             RGBColor[
              0.3055417316872413, 0.4312998537559559, 0.940974206355727], 
             UndirectedEdge[151, 154] -> 
             RGBColor[
              0.5475628360948273, 0.6435752036232633, 0.9575252987275946], 
             UndirectedEdge[8, 64] -> 
             RGBColor[
              0.21988638356939655`, 0.34844490910634823`, 0.9358335763002992],
              UndirectedEdge[71, 108] -> 
             RGBColor[
              0.23200115605283045`, 0.3611783031073773, 0.936523494671031], 
             UndirectedEdge[43, 182] -> 
             RGBColor[
              0.23996509971424826`, 0.36954891283871966`, 0.9369770294809499],
              UndirectedEdge[58, 297] -> 
             RGBColor[
              0.19156703343003767`, 0.3186794765593771, 0.934220831204587], 
             UndirectedEdge[46, 207] -> 
             RGBColor[
              0.1949982416588687, 0.3222858939590454, 0.9344162334372013], 
             UndirectedEdge[100, 266] -> 
             RGBColor[
              0.1894062944527255, 0.3164084028954582, 0.9340977803163559], 
             UndirectedEdge[12, 151] -> 
             RGBColor[
              0.5137240937710055, 0.6154599354387978, 0.9550391768879118], 
             UndirectedEdge[196, 265] -> 
             RGBColor[
              0.21288778030859679`, 0.34108893334217194`, 0.9354350161981024],
              UndirectedEdge[93, 139] -> 
             RGBColor[
              0.3409266080048823, 0.4634636698846607, 0.9431734199503177], 
             UndirectedEdge[30, 104] -> 
             RGBColor[
              0.2921921290764705, 0.4220073511871032, 0.9400404564262714], 
             UndirectedEdge[85, 121] -> 
             RGBColor[
              0.22879896787362192`, 0.35781260030057205`, 0.936341134791438], 
             UndirectedEdge[79, 160] -> 
             RGBColor[
              0.1894526235362595, 0.316457097699686, 0.9341004186891254], 
             UndirectedEdge[60, 196] -> 
             RGBColor[
              0.24516356622564123`, 0.3750128307440074, 0.9372730744583317], 
             UndirectedEdge[25, 297] -> 
             RGBColor[
              0.19155439006973912`, 0.318666187586068, 0.9342201111839221], 
             UndirectedEdge[9, 133] -> 
             RGBColor[
              0.19212471165815448`, 0.3192656317359698, 0.9342525901546672], 
             UndirectedEdge[151, 192] -> 
             RGBColor[
              0.4642226762503304, 0.5725842955959759, 0.9518849903358793], 
             UndirectedEdge[45, 141] -> 
             RGBColor[
              0.2968912603514489, 0.4293819169954668, 0.9402188901145307], 
             UndirectedEdge[177, 280] -> 
             RGBColor[
              0.27699231630764354`, 0.4084668651395046, 0.9390856746890857], 
             UndirectedEdge[141, 188] -> 
             RGBColor[
              0.3248560928052687, 0.45441830964122576`, 0.9419709558048517], 
             UndirectedEdge[129, 183] -> 
             RGBColor[
              0.1909140048229797, 0.31799310208895415`, 0.9341836421914842], 
             UndirectedEdge[41, 55] -> 
             RGBColor[
              0.19536579579315563`, 0.32267221665845913`, 0.9344371651014012],
              UndirectedEdge[120, 261] -> 
             RGBColor[
              0.2619133763504623, 0.3926179431844944, 0.9382269513658168], 
             UndirectedEdge[71, 279] -> 
             RGBColor[
              0.22999178600981598`, 0.35906632779075, 0.9364090640196779], 
             UndirectedEdge[180, 230] -> 
             RGBColor[
              0.1934850620461379, 0.3206954462449366, 0.9343300600968047], 
             UndirectedEdge[106, 194] -> 
             RGBColor[
              0.7739330746560312, 0.8236601401446212, 0.9780122537987794], 
             UndirectedEdge[90, 234] -> 
             RGBColor[
              0.20491562163947707`, 0.33270968911687326`, 0.9349810135556479],
              UndirectedEdge[44, 136] -> 
             RGBColor[
              0.3544174046992013, 0.48140027523890294`, 0.9438041415217957], 
             UndirectedEdge[120, 131] -> 
             RGBColor[
              0.2542490675591432, 0.38456226869957383`, 0.93779048031848], 
             UndirectedEdge[44, 279] -> 
             RGBColor[
              0.27644302038079716`, 0.4071985613343865, 0.9390796924908837], 
             UndirectedEdge[105, 139] -> 
             RGBColor[
              0.3622816914289454, 0.48590921655384295`, 0.9443895603593033], 
             UndirectedEdge[157, 184] -> 
             RGBColor[
              0.18701393581723674`, 0.31389388228526116`, 0.9339615390312422],
              UndirectedEdge[83, 149] -> 
             RGBColor[
              0.8628696595923687, 0.44534910675306505`, 0.20631412788053274`],
              UndirectedEdge[145, 168] -> 
             RGBColor[
              0.6326576416445393, 0.7081764296337532, 0.9668556680760403], 
             UndirectedEdge[112, 170] -> 
             RGBColor[
              0.1934039006537554, 0.3206101404756131, 0.9343254380755761], 
             UndirectedEdge[159, 270] -> 
             RGBColor[
              0.2520399731872973, 0.38224037045009085`, 0.9376646756620657], 
             UndirectedEdge[86, 162] -> 
             RGBColor[
              0.7927626721159106, 0.8360545204331631, 0.8771199562466196], 
             UndirectedEdge[3, 264] -> 
             RGBColor[
              0.6252141606717125, 0.697021267014214, 0.9512803143951285], 
             UndirectedEdge[60, 282] -> 
             RGBColor[
              0.36394977931359895`, 0.4876708967869795, 0.9444842474150733], 
             UndirectedEdge[135, 186] -> 
             RGBColor[
              0.20309625090443267`, 0.3307974151195744, 0.934877403083805], 
             UndirectedEdge[89, 294] -> 
             RGBColor[
              0.4583968818459615, 0.569215720181254, 0.9510502956112238], 
             UndirectedEdge[201, 203] -> 
             RGBColor[
              0.8759510922102913, 0.5506721053262738, 0.4578210075797024], 
             UndirectedEdge[181, 203] -> 
             RGBColor[
              0.961709527951959, 0.9590285203678879, 0.6962850331189814], 
             UndirectedEdge[70, 211] -> 
             RGBColor[
              0.24025127894135917`, 0.3698497053512242, 0.9369933269645696], 
             UndirectedEdge[156, 159] -> 
             RGBColor[
              0.3428661620319342, 0.4697766941100199, 0.9431273668629003], 
             UndirectedEdge[56, 270] -> 
             RGBColor[
              0.20609791902538932`, 0.3339523586314509, 0.9350483436427234], 
             UndirectedEdge[113, 264] -> 
             RGBColor[
              0.28192127958218227`, 0.41364751805536637`, 0.939366371855823], 
             UndirectedEdge[144, 240] -> 
             RGBColor[
              0.18908519234139687`, 0.31607090421740214`, 0.9340794940261437],
              UndirectedEdge[231, 232] -> 
             RGBColor[
              0.20954424282732975`, 0.33757466345683984`, 0.9352446066848648],
              UndirectedEdge[90, 248] -> 
             RGBColor[
              0.21881740302399694`, 0.347321342775852, 0.9357726994396538], 
             UndirectedEdge[27, 109] -> 
             RGBColor[
              0.9813263327288758, 0.9506128482774708, 0.5530707745780536], 
             UndirectedEdge[42, 145] -> 
             RGBColor[
              0.8467044438902113, 0.49173965579450474`, 0.4514212603342903], 
             UndirectedEdge[160, 230] -> 
             RGBColor[
              0.19392496192438957`, 0.3211578089082423, 0.9343551117440977], 
             UndirectedEdge[247, 251] -> 
             RGBColor[
              0.24168185283923999`, 0.37135332922152087`, 0.9370747960317096],
              UndirectedEdge[109, 220] -> 
             RGBColor[
              0.6629503007752218, 0.7271111544395208, 0.8556231628289728], 
             UndirectedEdge[139, 163] -> 
             RGBColor[
              0.5309367698880918, 0.6297354344441368, 0.9563109238850767], 
             UndirectedEdge[31, 279] -> 
             RGBColor[
              0.32815763679560045`, 0.4519911628206914, 0.9423749021193952], 
             UndirectedEdge[9, 112] -> 
             RGBColor[
              0.19409572030031721`, 0.3213372867880486, 0.9343648361809924], 
             UndirectedEdge[196, 276] -> 
             RGBColor[
              0.22221678398010425`, 0.35089430769392205`, 0.9359662891561706],
              UndirectedEdge[137, 251] -> 
             RGBColor[
              0.27357072658534587`, 0.4048705574000514, 0.9388908202161892], 
             UndirectedEdge[162, 181] -> 
             RGBColor[
              0.9888211205061603, 0.9780593840975029, 0.5971500192561076], 
             UndirectedEdge[96, 236] -> 
             RGBColor[
              0.2161907003932258, 0.34456051176834573`, 0.9356231126106896], 
             UndirectedEdge[251, 295] -> 
             RGBColor[
              0.24126505067228732`, 0.3709152437172699, 0.9370510597649051], 
             UndirectedEdge[20, 268] -> 
             RGBColor[
              0.21202685048114545`, 0.34018404150741677`, 0.9353859875180606],
              UndirectedEdge[187, 215] -> 
             RGBColor[
              0.224740944415305, 0.35354736035233314`, 0.9361100363587946], 
             UndirectedEdge[55, 250] -> 
             RGBColor[
              0.1923953966842939, 0.31955013886086425`, 0.9342680052664631], 
             UndirectedEdge[193, 230] -> 
             RGBColor[
              0.2358246326636532, 0.3651970194477707, 0.9367412360076905], 
             UndirectedEdge[55, 242] -> 
             RGBColor[
              0.19150951150427703`, 0.318619017368302, 0.9342175554160109], 
             UndirectedEdge[51, 116] -> 
             RGBColor[
              0.5493242790295518, 0.6359329023080253, 0.960750884061716], 
             UndirectedEdge[130, 203] -> 
             RGBColor[
              0.92446413705714, 0.8203323074950271, 0.6196039862679017], 
             UndirectedEdge[34, 124] -> 
             RGBColor[
              0.1848087064384265, 0.3115760463885134, 0.9338359544804635], 
             UndirectedEdge[190, 261] -> 
             RGBColor[
              0.2245754678269734, 0.353373433966175, 0.9361006127118898], 
             UndirectedEdge[76, 85] -> 
             RGBColor[
              0.2795331222505161, 0.40945731042738504`, 0.9392918866244364], 
             UndirectedEdge[130, 237] -> 
             RGBColor[
              0.8539841698020644, 0.35850563187745466`, 0.19706087949209944`],
              UndirectedEdge[175, 183] -> 
             RGBColor[
              0.18767445593923526`, 0.3145881308128762, 0.9339991546750381], 
             UndirectedEdge[93, 289] -> 
             RGBColor[
              0.24228732684798865`, 0.37198972079398507`, 0.9371092768807893],
              UndirectedEdge[69, 234] -> 
             RGBColor[
              0.20086201360397116`, 0.32844909005796263`, 0.9347501665748015],
              UndirectedEdge[32, 269] -> 
             RGBColor[
              0.980420530285405, 0.9551564158081671, 0.6020762664235486], 
             UndirectedEdge[226, 243] -> 
             RGBColor[
              0.9868373224355939, 0.9888249088088037, 0.8678031613671959], 
             UndirectedEdge[72, 218] -> 
             RGBColor[
              0.875340160780385, 0.47642064776789905`, 0.430675613342974], 
             UndirectedEdge[81, 181] -> 
             RGBColor[
              0.9378794291938042, 0.7781980948822975, 0.31536710248397326`], 
             UndirectedEdge[8, 67] -> 
             RGBColor[
              0.1916976136601492, 0.31881672466048916`, 0.9342282675555156], 
             UndirectedEdge[145, 156] -> 
             RGBColor[
              0.6296976932681398, 0.7056126711214472, 0.9666670627828757], 
             UndirectedEdge[20, 177] -> 
             RGBColor[
              0.2554879446971804, 0.38586440712099823`, 0.9378610325387366], 
             UndirectedEdge[180, 297] -> 
             RGBColor[
              0.19343887791696943`, 0.3206469037969376, 0.9343274299789719], 
             UndirectedEdge[140, 216] -> 
             RGBColor[
              0.8337005726178471, 0.2515929185371857, 0.1795741305714151], 
             UndirectedEdge[287, 300] -> 
             RGBColor[
              0.2343234420650949, 0.3636191729477046, 0.9366557454239152], 
             UndirectedEdge[140, 167] -> 
             RGBColor[
              0.847440007720582, 0.31331700517270195`, 0.1910043309119193], 
             UndirectedEdge[248, 285] -> 
             RGBColor[
              0.21081919728396287`, 0.3389147214275427, 0.9353172134550438], 
             UndirectedEdge[185, 292] -> 
             RGBColor[
              0.6516360083701964, 0.726054278090207, 0.9670940826236099], 
             UndirectedEdge[23, 241] -> 
             RGBColor[
              0.9877354309295805, 0.9891962997514028, 0.8529191793915591], 
             UndirectedEdge[10, 48] -> 
             RGBColor[
              0.19160641114189197`, 0.3187208650312271, 0.934223073707023], 
             UndirectedEdge[46, 62] -> 
             RGBColor[
              0.20319287451419632`, 0.3308989726597267, 0.9348829056554392], 
             UndirectedEdge[15, 276] -> 
             RGBColor[
              0.24987495920564082`, 0.37996480348555506`, 0.9375413813186614],
              UndirectedEdge[85, 154] -> 
             RGBColor[
              0.36472305205370464`, 0.48205039622074985`, 0.9450500607222323],
              UndirectedEdge[32, 179] -> 
             RGBColor[
              0.7552164634617963, 0.8063041539020928, 0.9047369408488604], 
             UndirectedEdge[145, 277] -> 
             RGBColor[
              0.9289575250796454, 0.9412874203114796, 0.7338327759362018], 
             UndirectedEdge[58, 164] -> 
             RGBColor[
              0.1865510290497441, 0.3134073379226422, 0.9339351771756428], 
             UndirectedEdge[18, 253] -> 
             RGBColor[
              0.19591234458530662`, 0.3232466740922047, 0.9344682902465677], 
             UndirectedEdge[59, 136] -> 
             RGBColor[
              0.6888115905499252, 0.7512769242124885, 0.9221815319720392], 
             UndirectedEdge[232, 288] -> 
             RGBColor[
              0.19838654644971515`, 0.32584721712515685`, 0.9346091923824922],
              UndirectedEdge[136, 177] -> 
             RGBColor[
              0.34229360740819775`, 0.46934835455154167`, 0.9430884098094023],
              UndirectedEdge[31, 65] -> 
             RGBColor[
              0.3985559674737674, 0.5196308798455622, 0.9466166117115924], 
             UndirectedEdge[62, 214] -> 
             RGBColor[
              0.20125370240405008`, 0.3288607798213499, 0.9347724726725144], 
             UndirectedEdge[24, 109] -> 
             RGBColor[
              0.9582875876148832, 0.8633759964057863, 0.5131590613985512], 
             UndirectedEdge[71, 268] -> 
             RGBColor[
              0.21418318831071842`, 0.34245048928601285`, 0.9355087877674388],
              UndirectedEdge[64, 118] -> 
             RGBColor[
              0.2120127678097534, 0.3401692397268907, 0.9353851855307582], 
             UndirectedEdge[21, 206] -> 
             RGBColor[
              0.20800021126608947`, 0.33595178838872103`, 0.9351566763716421],
              UndirectedEdge[6, 124] -> 
             RGBColor[
              0.19825974011141095`, 0.3257139356236129, 0.9346019709491189], 
             UndirectedEdge[7, 140] -> 
             RGBColor[
              0.8576525620588931, 0.4072578344865292, 0.4392429539624352], 
             UndirectedEdge[78, 229] -> 
             RGBColor[
              0.20592187570768378`, 0.3337673259427514, 0.9350383182362128], 
             UndirectedEdge[67, 213] -> 
             RGBColor[
              0.19065103236232478`, 0.3177167013593888, 0.9341686662988828], 
             UndirectedEdge[189, 300] -> 
             RGBColor[
              0.22074088939765935`, 0.34934304891065115`, 0.9358822391430908],
              UndirectedEdge[77, 225] -> 
             RGBColor[
              0.32068966156322254`, 0.4446841856418027, 0.9419297543163823], 
             UndirectedEdge[153, 239] -> 
             RGBColor[
              0.22932262896951866`, 0.3583630013143907, 0.9363709565161622], 
             UndirectedEdge[7, 168] -> 
             RGBColor[
              0.6693655533207783, 0.7373787417141351, 0.9680138507113893], 
             UndirectedEdge[5, 256] -> 
             RGBColor[
              0.868956298803952, 0.39716627197470655`, 0.223830917733355], 
             UndirectedEdge[193, 200] -> 
             RGBColor[
              0.3225670309120143, 0.4511149836272068, 0.9418734544780243], 
             UndirectedEdge[17, 202] -> 
             RGBColor[
              0.8122682039505371, 0.5808158857565188, 0.4639498679202687], 
             UndirectedEdge[12, 220] -> 
             RGBColor[
              0.38135478455479077`, 0.5047320797577364, 0.9455205675464041], 
             UndirectedEdge[196, 207] -> 
             RGBColor[
              0.19417373721693681`, 0.32141928751397403`, 0.9343692791289782],
              UndirectedEdge[222, 285] -> 
             RGBColor[
              0.21055261927690455`, 0.33863453104010255`, 0.9353020322319088],
              UndirectedEdge[169, 227] -> 
             RGBColor[
              0.7787217249901721, 0.7700947212036731, 0.6214147685810579], 
             UndirectedEdge[139, 298] -> 
             RGBColor[
              0.350430471977903, 0.4734528335000848, 0.9437146509438744], 
             UndirectedEdge[210, 241] -> 
             RGBColor[
              0.7289016289330998, 0.7852496727746727, 0.9155863904520005], 
             UndirectedEdge[58, 288] -> 
             RGBColor[
              0.200003126765576, 0.32754634553423856`, 0.9347012542399642], 
             UndirectedEdge[85, 258] -> 
             RGBColor[
              0.2861550048473763, 0.41519285230728875`, 0.9397138271280076], 
             UndirectedEdge[87, 162] -> 
             RGBColor[
              0.9922481634967688, 0.9892215006042993, 0.6443153424349913], 
             UndirectedEdge[222, 248] -> 
             RGBColor[
              0.22169214906401963`, 0.3503428831333422, 0.9359364119738274], 
             UndirectedEdge[76, 87] -> 
             RGBColor[
              0.6600329022141906, 0.7226670785503484, 0.7188188011286823], 
             UndirectedEdge[80, 282] -> 
             RGBColor[
              0.7097202776306235, 0.7481265393121519, 0.6607363832345532], 
             UndirectedEdge[273, 289] -> 
             RGBColor[
              0.24118737083360547`, 0.370833597281629, 0.9370466360130092], 
             UndirectedEdge[215, 296] -> 
             RGBColor[
              0.20597442651804665`, 0.33382256017635653`, 0.935041310927121], 
             UndirectedEdge[142, 277] -> 
             RGBColor[
              0.8842941238717467, 0.48322242431774326`, 0.2777627936730913], 
             UndirectedEdge[134, 180] -> 
             RGBColor[
              0.21984183187712564`, 0.34839808245303105`, 0.9358310391473328],
              UndirectedEdge[86, 178] -> 
             RGBColor[
              0.4265942001520806, 0.5354932240498018, 0.9496283130255976], 
             UndirectedEdge[3, 210] -> 
             RGBColor[
              0.7129487102103079, 0.7736730218742174, 0.9569659936880668], 
             UndirectedEdge[79, 176] -> 
             RGBColor[
              0.18866673983198834`, 0.31563108409859225`, 0.9340556637747779],
              UndirectedEdge[131, 141] -> 
             RGBColor[
              0.26162779894186294`, 0.392317783221403, 0.938210688154871], 
             UndirectedEdge[150, 256] -> 
             RGBColor[
              0.8477552075952007, 0.3160779656240866, 0.191320067694982], 
             UndirectedEdge[74, 300] -> 
             RGBColor[
              0.2157736566163444, 0.3441221723167407, 0.9355993625845572], 
             UndirectedEdge[25, 230] -> 
             RGBColor[
              0.19160057419890764`, 0.31871473003406703`, 0.934222741301755], 
             UndirectedEdge[165, 253] -> 
             RGBColor[
              0.20482209384336109`, 0.3326113854731506, 0.9349756872860211], 
             UndirectedEdge[223, 295] -> 
             RGBColor[
              0.1892065910771333, 0.3161985019857855, 0.9340864075045505], 
             UndirectedEdge[164, 221] -> 
             RGBColor[
              0.184078374522518, 0.31080842123917557`, 0.9337943631582817], 
             UndirectedEdge[70, 138] -> 
             RGBColor[
              0.22052881830414905`, 0.3491201487452879, 0.9358701620080464], 
             UndirectedEdge[165, 224] -> 
             RGBColor[
              0.21323098705618415`, 0.3414496653944509, 0.9354545613146487], 
             UndirectedEdge[87, 258] -> 
             RGBColor[
              0.6666547848110509, 0.7284026204302521, 0.7192407416322534], 
             UndirectedEdge[90, 222] -> 
             RGBColor[
              0.2185508250169386, 0.3470411523884118, 0.9357575182165185], 
             UndirectedEdge[163, 185] -> 
             RGBColor[
              0.5753534134295759, 0.6661368462548543, 0.9597130747756251], 
             UndirectedEdge[64, 286] -> 
             RGBColor[
              0.22809764059378232`, 0.35707546086274283`, 0.9363011952403719],
              UndirectedEdge[131, 199] -> 
             RGBColor[
              0.21390129447571837`, 0.3421542009923264, 0.9354927343305601], 
             UndirectedEdge[2, 49] -> 
             RGBColor[
              0.20410648254439653`, 0.3318592326255619, 0.934934934281197], 
             UndirectedEdge[51, 283] -> 
             RGBColor[
              0.5585587587049552, 0.6456389259467026, 0.9612767740180419], 
             UndirectedEdge[66, 187] -> 
             RGBColor[
              0.305540960778381, 0.4312990434818653, 0.9409741624536079], 
             UndirectedEdge[120, 170] -> 
             RGBColor[
              0.23833338730926568`, 0.3678338796445412, 0.9368841058733883], 
             UndirectedEdge[17, 182] -> 
             RGBColor[
              0.47900337512465124`, 0.5765439495002909, 0.9544470440825916], 
             UndirectedEdge[156, 179] -> 
             RGBColor[
              0.4586241439822036, 0.5697734899723961, 0.9509650514168311], 
             UndirectedEdge[199, 284] -> 
             RGBColor[
              0.21967623885350168`, 0.3482240336859982, 0.9358216088696103], 
             UndirectedEdge[210, 291] -> 
             RGBColor[
              0.6992769373373419, 0.7632490848408453, 0.9722193956891239], 
             UndirectedEdge[212, 265] -> 
             RGBColor[
              0.22804223773896515`, 0.3570172289495861, 0.9362980401297512], 
             UndirectedEdge[85, 173] -> 
             RGBColor[
              0.21671771694106706`, 0.34511443957490595`, 0.9356531254234381],
              UndirectedEdge[47, 146] -> 
             RGBColor[
              0.19206431623757236`, 0.3192021523196471, 0.9342491507248121], 
             UndirectedEdge[198, 283] -> 
             RGBColor[
              0.6352059189617083, 0.705940028417498, 0.9427748448450561], 
             UndirectedEdge[168, 212] -> 
             RGBColor[
              0.31689002798285826`, 0.4419267953395609, 0.941668105069032], 
             UndirectedEdge[56, 271] -> 
             RGBColor[
              0.21099595483626973`, 0.3391005048220933, 0.9353272795361584], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.33246233459167696`, 0.45559373221858496`, 0.9426538050639501],
              UndirectedEdge[159, 191] -> 
             RGBColor[
              0.25930875612416715`, 0.38988032218419766`, 0.9380786220971196],
              UndirectedEdge[72, 83] -> 
             RGBColor[
              0.8351278328210138, 0.271013492942614, 0.1812717584216026], 
             UndirectedEdge[179, 277] -> 
             RGBColor[
              0.7578839757937091, 0.8054482391624284, 0.7181307645701571], 
             UndirectedEdge[86, 182] -> 
             RGBColor[
              0.4242603384632414, 0.5330401874394541, 0.9494954030550571], 
             UndirectedEdge[80, 293] -> 
             RGBColor[
              0.9392835874613179, 0.7889438610995526, 0.30512184711932616`], 
             UndirectedEdge[9, 96] -> 
             RGBColor[
              0.19995528537104273`, 0.3274960611952644, 0.9346985297433206], 
             UndirectedEdge[51, 226] -> 
             RGBColor[
              0.8987769385879059, 0.920547716985024, 0.9296222387004919], 
             UndirectedEdge[185, 235] -> 
             RGBColor[
              0.4690251433139141, 0.5785976856950342, 0.951678806922862], 
             UndirectedEdge[136, 210] -> 
             RGBColor[
              0.43214727310106515`, 0.5482274348494092, 0.9488947696323751], 
             UndirectedEdge[78, 284] -> 
             RGBColor[
              0.2175445595822431, 0.34598350361563335`, 0.935700212888649], 
             UndirectedEdge[81, 216] -> 
             RGBColor[
              0.8741307766845507, 0.521339079076086, 0.216683973539649], 
             UndirectedEdge[2, 165] -> 
             RGBColor[
              0.2081927032562806, 0.336154109675109, 0.935167638505717], 
             UndirectedEdge[181, 216] -> 
             RGBColor[
              0.9064071332493737, 0.6461593249941886, 0.2739426170686603], 
             UndirectedEdge[7, 203] -> 
             RGBColor[
              0.9377223890197792, 0.9530740402179558, 0.990303930173889], 
             UndirectedEdge[44, 177] -> 
             RGBColor[
              0.3040955168977345, 0.4362630884432308, 0.9406544612593207], 
             UndirectedEdge[140, 237] -> 
             RGBColor[
              0.8199042211924654, 0.15399814293643901`, 0.1666936107334946], 
             UndirectedEdge[38, 124] -> 
             RGBColor[
              0.186021974396972, 0.31285126793857626`, 0.9339050482958335], 
             UndirectedEdge[5, 59] -> 
             RGBColor[
              0.978010186853574, 0.9509747189595588, 0.6200075845730131], 
             UndirectedEdge[35, 253] -> 
             RGBColor[
              0.19912169776175326`, 0.3266199077653942, 0.9346510581621539], 
             UndirectedEdge[200, 231] -> 
             RGBColor[
              0.2983755222047893, 0.4256881741456715, 0.9404957838452779], 
             UndirectedEdge[213, 234] -> 
             RGBColor[
              0.19826511451334394`, 0.3257195844608012, 0.9346022770133582], 
             UndirectedEdge[53, 88] -> 
             RGBColor[
              0.21936792560639845`, 0.34789997691510377`, 0.9358040508862964],
              UndirectedEdge[150, 269] -> 
             RGBColor[
              0.9402871560451271, 0.7958786263011822, 0.2973043850963], 
             UndirectedEdge[4, 135] -> 
             RGBColor[
              0.21680708920312736`, 0.3452083754888601, 0.935658215041548], 
             UndirectedEdge[91, 139] -> 
             RGBColor[
              0.4654409733450266, 0.5765629962584664, 0.9511548548621985], 
             UndirectedEdge[28, 232] -> 
             RGBColor[
              0.18568890069969585`, 0.3125011863646469, 0.9338860802415121], 
             UndirectedEdge[127, 276] -> 
             RGBColor[
              0.29510454675664893`, 0.4237974430003376, 0.9402528534454749], 
             UndirectedEdge[60, 103] -> 
             RGBColor[
              0.35429852491084235`, 0.47931146530946245`, 0.9438692780187988],
              UndirectedEdge[145, 159] -> 
             RGBColor[
              0.5780723315879956, 0.6592789022873965, 0.963436800696632], 
             UndirectedEdge[20, 252] -> 
             RGBColor[
              0.2284732256377411, 0.3574702245574107, 0.936322584252997], 
             UndirectedEdge[80, 128] -> 
             RGBColor[
              0.889562972527344, 0.5443500198966912, 0.25117046231774093`], 
             UndirectedEdge[167, 237] -> 
             RGBColor[
              0.8526104501055128, 0.35305929104558004`, 0.1959555523789085], 
             UndirectedEdge[24, 291] -> 
             RGBColor[
              0.9253194185531315, 0.839992794616319, 0.6252021408895034], 
             UndirectedEdge[22, 244] -> 
             RGBColor[
              0.18902260313051494`, 0.31600511898838, 0.9340759296631764], 
             UndirectedEdge[51, 83] -> 
             RGBColor[
              0.8348006374064919, 0.5233895828676642, 0.45541678825261045`], 
             UndirectedEdge[29, 229] -> 
             RGBColor[
              0.20648377022612274`, 0.3343579127078008, 0.9350703172977894], 
             UndirectedEdge[151, 181] -> 
             RGBColor[
              0.7920610111090953, 0.8249056195457978, 0.6813687144574905], 
             UndirectedEdge[22, 63] -> 
             RGBColor[
              0.18571205303560948`, 0.312525520937635, 0.9338873987327916], 
             UndirectedEdge[163, 292] -> 
             RGBColor[
              0.6974329821497556, 0.7632343245346107, 0.9706993881593793], 
             UndirectedEdge[247, 289] -> 
             RGBColor[
              0.22060050259813557`, 0.34919549348331447`, 0.9358742443225416],
              UndirectedEdge[155, 299] -> 
             RGBColor[
              0.8545672117145955, 0.3449853666875312, 0.19687926573825648`], 
             UndirectedEdge[31, 71] -> 
             RGBColor[
              0.32148269623256015`, 0.4449753770732606, 0.9419947741290198], 
             UndirectedEdge[45, 260] -> 
             RGBColor[
              0.2790511539192304, 0.41063083400712647`, 0.9392029224452882], 
             UndirectedEdge[80, 125] -> 
             RGBColor[
              0.8830657841456923, 0.4944097829092139, 0.2449487473859466], 
             UndirectedEdge[97, 261] -> 
             RGBColor[
              0.34679730240272766`, 0.46888200483462256`, 0.9435352867345028],
              UndirectedEdge[107, 147] -> 
             RGBColor[
              0.3109365240034128, 0.43492372492699083`, 0.9413563604380197], 
             UndirectedEdge[15, 286] -> 
             RGBColor[
              0.23963340623012278`, 0.3692002819563222, 0.9369581400277256], 
             UndirectedEdge[94, 202] -> 
             RGBColor[
              0.8433434284333755, 0.6050920873029656, 0.46704715588223444`], 
             UndirectedEdge[86, 130] -> 
             RGBColor[
              0.75299012475597, 0.6847273872222507, 0.6045439579169226], 
             UndirectedEdge[73, 161] -> 
             RGBColor[
              0.19216173018569271`, 0.31930454055552265`, 0.9342546983050465],
              UndirectedEdge[7, 167] -> 
             RGBColor[
              0.9230008546692128, 0.8126082594888467, 0.6169349273115317], 
             UndirectedEdge[288, 297] -> 
             RGBColor[
              0.20042924344964513`, 0.3279942211865534, 0.9347255209547387], 
             UndirectedEdge[15, 46] -> 
             RGBColor[
              0.23154240030757095`, 0.3606961217323153, 0.9364973692100068], 
             UndirectedEdge[1, 92] -> 
             RGBColor[
              0.8229805000264965, 0.17764377008878246`, 0.16963945881912273`],
              UndirectedEdge[85, 213] -> 
             RGBColor[
              0.21726177740977812`, 0.34568628162294734`, 0.9356841088622658],
              UndirectedEdge[2, 174] -> 
             RGBColor[
              0.21589796346133705`, 0.34425282669233714`, 0.9356064416754841],
              UndirectedEdge[104, 204] -> 
             RGBColor[
              0.40934807922423605`, 0.5281560108098651, 0.9475315219665212], 
             UndirectedEdge[125, 243] -> 
             RGBColor[
              0.8859354840896285, 0.5107054174164098, 0.4069530416143843], 
             UndirectedEdge[149, 243] -> 
             RGBColor[
              0.9414606577081649, 0.8037269245686582, 0.5463530672768225], 
             UndirectedEdge[35, 175] -> 
             RGBColor[
              0.19450102624862847`, 0.3217632890376051, 0.9343879177551523], 
             UndirectedEdge[82, 201] -> 
             RGBColor[
              0.7680559447436146, 0.4654815691448476, 0.44828646235642633`], 
             UndirectedEdge[39, 69] -> 
             RGBColor[
              0.20464654155210055`, 0.3324268688843776, 0.9349656898427401], 
             UndirectedEdge[5, 204] -> 
             RGBColor[
              0.7273105149978081, 0.7527675975931751, 0.6471903809836539], 
             UndirectedEdge[107, 277] -> 
             RGBColor[
              0.7007432409432577, 0.7578412318622451, 0.7139688588587303], 
             UndirectedEdge[236, 260] -> 
             RGBColor[
              0.2447992469285118, 0.3746299080635468, 0.9372523270133223], 
             UndirectedEdge[11, 51] -> 
             RGBColor[
              0.6715557743614986, 0.7416503460034106, 0.9690558457242018], 
             UndirectedEdge[41, 242] -> 
             RGBColor[
              0.18473837996455222`, 0.31150212880551553`, 0.933831949491815], 
             UndirectedEdge[53, 93] -> 
             RGBColor[
              0.22850372850548528`, 0.3575022850054033, 0.93632432134619], 
             UndirectedEdge[82, 293] -> 
             RGBColor[
              0.7565992079701278, 0.6673833817942012, 0.600389979606483], 
             UndirectedEdge[76, 151] -> 
             RGBColor[
              0.46237290629163863`, 0.5709821178298984, 0.9517671246297987], 
             UndirectedEdge[130, 269] -> 
             RGBColor[
              0.9424840400754735, 0.8045885394133, 0.29907204955461253`], 
             UndirectedEdge[13, 289] -> 
             RGBColor[
              0.2883666647778183, 0.41815288261871875`, 0.9398165114828785], 
             UndirectedEdge[86, 120] -> 
             RGBColor[
              0.4366336879326583, 0.5460453622474791, 0.9502000470026102], 
             UndirectedEdge[86, 284] -> 
             RGBColor[
              0.41756739126480746`, 0.526005475576538, 0.9491142496134344], 
             UndirectedEdge[49, 102] -> 
             RGBColor[
              0.20090857647606358`, 0.32849803058878846`, 0.9347528182614836],
              UndirectedEdge[27, 299] -> 
             RGBColor[
              0.8690764337400362, 0.3997735335743823, 0.222803191736427], 
             UndirectedEdge[120, 182] -> 
             RGBColor[
              0.2667169591353605, 0.3976668132561618, 0.9385005082991529], 
             UndirectedEdge[97, 182] -> 
             RGBColor[
              0.35160088518762583`, 0.47393087490628993`, 0.9438088436678389],
              UndirectedEdge[42, 130] -> 
             RGBColor[
              0.8623375503659444, 0.42271337536614007`, 0.20506008615386487`],
              UndirectedEdge[15, 127] -> 
             RGBColor[
              0.3036056586421837, 0.43273265059365945`, 0.9407369791910881], 
             UndirectedEdge[28, 176] -> 
             RGBColor[
              0.18883134167646898`, 0.3158040910735011, 0.9340650376063144], 
             UndirectedEdge[26, 35] -> 
             RGBColor[
              0.21774452951257628`, 0.3461936846912394, 0.9357116008803525], 
             UndirectedEdge[44, 59] -> 
             RGBColor[
              0.650613500039462, 0.7181916581041776, 0.9197475834219577], 
             UndirectedEdge[155, 218] -> 
             RGBColor[
              0.9467517036363646, 0.8603082831521655, 0.5999961337585191], 
             UndirectedEdge[65, 155] -> 
             RGBColor[
              0.6518886127524492, 0.6234637492866453, 0.6024205995762867], 
             UndirectedEdge[55, 252] -> 
             RGBColor[
              0.22003960441036646`, 0.34860595392497, 0.9358423020005227], 
             UndirectedEdge[160, 296] -> 
             RGBColor[
              0.1914857715941317, 0.31859406521754197`, 0.9342162034632482], 
             UndirectedEdge[88, 147] -> 
             RGBColor[
              0.21812810554997109`, 0.34659684742666674`, 0.9357334449682322],
              UndirectedEdge[204, 243] -> 
             RGBColor[
              0.7355129252278461, 0.7903594474546665, 0.9053392735975632], 
             UndirectedEdge[65, 106] -> 
             RGBColor[
              0.6196619973862446, 0.6970249085872788, 0.9659794196694249], 
             UndirectedEdge[115, 245] -> 
             RGBColor[
              0.2884856169676899, 0.4165730051879058, 0.9398857105111442], 
             UndirectedEdge[60, 205] -> 
             RGBColor[
              0.3298135622578278, 0.45810382130942706`, 0.9423091178497511], 
             UndirectedEdge[75, 111] -> 
             RGBColor[
              0.4735665439631073, 0.5802328466571501, 0.952603227994324], 
             UndirectedEdge[17, 86] -> 
             RGBColor[
              0.648920103921949, 0.7249224984916083, 0.966146582786049], 
             UndirectedEdge[67, 166] -> 
             RGBColor[
              0.1825106958270533, 0.309160691533672, 0.9337050861757479], 
             UndirectedEdge[3, 169] -> 
             RGBColor[
              0.7794786659769637, 0.8276850371059405, 0.962203475513276], 
             UndirectedEdge[7, 255] -> 
             RGBColor[
              0.6521687790491231, 0.722483760175034, 0.9669180874613099], 
             UndirectedEdge[211, 231] -> 
             RGBColor[
              0.25095672851015194`, 0.3811018116127316, 0.937602986480219], 
             UndirectedEdge[218, 290] -> 
             RGBColor[
              0.956800253470921, 0.9001474347654498, 0.6080814328251828], 
             UndirectedEdge[201, 269] -> 
             RGBColor[
              0.8879643608891803, 0.5401762599384556, 0.244133049770843], 
             UndirectedEdge[34, 223] -> 
             RGBColor[
              0.1825916590093845, 0.3092457889716643, 0.9337096969092074], 
             UndirectedEdge[63, 208] -> 
             RGBColor[
              0.1860996055764639, 0.3129328632303233, 0.9339094692766605], 
             UndirectedEdge[131, 190] -> 
             RGBColor[
              0.21691115903565433`, 0.3453177594812544, 0.9356641416645529], 
             UndirectedEdge[27, 181] -> 
             RGBColor[
              0.9780677338465346, 0.9376794577026863, 0.3692977168650637], 
             UndirectedEdge[108, 136] -> 
             RGBColor[
              0.3166504809342749, 0.4423958027593246, 0.9416280716923184], 
             UndirectedEdge[101, 254] -> 
             RGBColor[
              0.4830549298600605, 0.587475687952538, 0.9535083702036646], 
             UndirectedEdge[62, 212] -> 
             RGBColor[
              0.2175228275026328, 0.34596066182206947`, 0.9356989752788649], 
             UndirectedEdge[69, 195] -> 
             RGBColor[
              0.1956464700099377, 0.32296722305607023`, 0.9344531490828267], 
             UndirectedEdge[136, 252] -> 
             RGBColor[
              0.3152788883487585, 0.44095417198795417`, 0.9415499615236627], 
             UndirectedEdge[26, 175] -> 
             RGBColor[
              0.20585209939384108`, 0.33369398661282884`, 0.9350343445783642],
              UndirectedEdge[24, 27] -> 
             RGBColor[
              0.9468027585380377, 0.8226935997742366, 0.2974286527731346], 
             UndirectedEdge[231, 266] -> 
             RGBColor[
              0.21466524015743277`, 0.342957156340762, 0.9355362399069774], 
             UndirectedEdge[153, 157] -> 
             RGBColor[
              0.2018036290672552, 0.32943878761174283`, 0.9348037901824403], 
             UndirectedEdge[161, 244] -> 
             RGBColor[
              0.19557921069497186`, 0.3228965292515542, 0.9344493187643406], 
             UndirectedEdge[128, 150] -> 
             RGBColor[
              0.865763307775837, 0.454496114812273, 0.2085646447651994], 
             UndirectedEdge[113, 200] -> 
             RGBColor[
              0.3166014610591278, 0.4448447914728484, 0.9415337241001722], 
             UndirectedEdge[211, 264] -> 
             RGBColor[
              0.28347133969758304`, 0.41527672951614025`, 0.9394546454862865],
              UndirectedEdge[144, 232] -> 
             RGBColor[
              0.19277383312180774`, 0.31994789955094727`, 0.9342895566617331],
              UndirectedEdge[208, 244] -> 
             RGBColor[
              0.18941015567136937`, 0.31641246128106837`, 0.9340980002070455],
              UndirectedEdge[47, 133] -> 
             RGBColor[
              0.18469446291568115`, 0.3114559692026503, 0.9338294484808514], 
             UndirectedEdge[181, 258] -> 
             RGBColor[
              0.6632277418204424, 0.717240503923456, 0.6720754184533696], 
             UndirectedEdge[53, 147] -> 
             RGBColor[
              0.21463757351182716`, 0.3429280769420639, 0.9355346643324394], 
             UndirectedEdge[123, 267] -> 
             RGBColor[
              0.19740462411574278`, 0.32481515449468, 0.9345532733581963], 
             UndirectedEdge[59, 227] -> 
             RGBColor[
              0.9688560866723765, 0.9191321953350291, 0.5894640490955131], 
             UndirectedEdge[213, 286] -> 
             RGBColor[
              0.21163290304685975`, 0.3397699777762725, 0.935363552794471], 
             UndirectedEdge[16, 126] -> 
             RGBColor[
              0.23513936956710785`, 0.3644767644851118, 0.9367022112880983], 
             UndirectedEdge[68, 109] -> 
             RGBColor[
              0.9348338843673183, 0.947970458954174, 0.8784588716115629], 
             UndirectedEdge[137, 156] -> 
             RGBColor[
              0.32801284307365003`, 0.4541649141300481, 0.9422814923217423], 
             UndirectedEdge[181, 202] -> 
             RGBColor[
              0.9064784784364304, 0.6464832868255209, 0.2740021492415709], 
             UndirectedEdge[135, 214] -> 
             RGBColor[
              0.20695344714813524`, 0.3348515729320728, 0.9350970647036734], 
             UndirectedEdge[166, 234] -> 
             RGBColor[
              0.19012477797807242`, 0.3171635746350845, 0.9341386968902232], 
             UndirectedEdge[63, 152] -> 
             RGBColor[
              0.18270109795627662`, 0.30936081624367795`, 0.9337159292953324],
              UndirectedEdge[130, 167] -> 
             RGBColor[
              0.9097426027065735, 0.6798665267659179, 0.24623498340554434`], 
             UndirectedEdge[30, 74] -> 
             RGBColor[
              0.22759891531018372`, 0.3565512689686714, 0.9362727935732689], 
             UndirectedEdge[31, 177] -> 
             RGBColor[
              0.3558101333125378, 0.4810556899295358, 0.9439496708878323], 
             UndirectedEdge[24, 72] -> 
             RGBColor[
              0.8608649753560598, 0.3965560252957622, 0.20304003335454723`], 
             UndirectedEdge[39, 285] -> 
             RGBColor[
              0.20070194384757245`, 0.3282808465949789, 0.9347410508389766], 
             UndirectedEdge[27, 72] -> 
             RGBColor[
              0.8762241387653882, 0.45471392654355186`, 0.22964784214088227`],
              UndirectedEdge[109, 151] -> 
             RGBColor[
              0.7953196099914366, 0.8378390101205823, 0.8651417721704804], 
             UndirectedEdge[29, 178] -> 
             RGBColor[
              0.22713326298795516`, 0.3560618388539467, 0.9362462753623888], 
             UndirectedEdge[149, 256] -> 
             RGBColor[
              0.8437866719113953, 0.2986689012185817, 0.18804023732608074`], 
             UndirectedEdge[93, 137] -> 
             RGBColor[
              0.25133211293896884`, 0.38149636444816565`, 0.9376243640681086],
              UndirectedEdge[7, 145] -> 
             RGBColor[
              0.9016117745004403, 0.9243171913792056, 0.9881346792519563], 
             UndirectedEdge[271, 278] -> 
             RGBColor[
              0.21163260011638724`, 0.339769659377139, 0.9353635355430288], 
             UndirectedEdge[15, 135] -> 
             RGBColor[
              0.2357262900418861, 0.3650936551170112, 0.9367356355408658], 
             UndirectedEdge[94, 130] -> 
             RGBColor[
              0.8543459981416374, 0.7646454516027577, 0.6141415308874059], 
             UndirectedEdge[265, 286] -> 
             RGBColor[
              0.22180329067308052`, 0.3504597000112502, 0.9359427413240442], 
             UndirectedEdge[140, 201] -> 
             RGBColor[
              0.8266673641279991, 0.20598262316708282`, 0.17317000404643912`],
              UndirectedEdge[29, 259] -> 
             RGBColor[
              0.19020824390880345`, 0.3172513026203284, 0.9341434501515016], 
             UndirectedEdge[21, 123] -> 
             RGBColor[
              0.1960904957019222, 0.3234339222112008, 0.934478435689108], 
             UndirectedEdge[21, 189] -> 
             RGBColor[
              0.20470683599275827`, 0.3324902421643972, 0.934969123521938], 
             UndirectedEdge[107, 289] -> 
             RGBColor[
              0.32595994240234355`, 0.45071429020400966`, 0.942211921890683], 
             UndirectedEdge[17, 66] -> 
             RGBColor[
              0.5450024443168381, 0.6387388987189666, 0.9584682781320619], 
             UndirectedEdge[71, 208] -> 
             RGBColor[
              0.20631669235829492`, 0.33418230327536513`, 0.9350608024603861],
              UndirectedEdge[6, 289] -> 
             RGBColor[
              0.22701980203641853`, 0.3559425842000419, 0.9362398139290493], 
             UndirectedEdge[96, 132] -> 
             RGBColor[
              0.1989233882773373, 0.32641147192372544`, 0.9346397647303889], 
             UndirectedEdge[55, 283] -> 
             RGBColor[
              0.25397885208056453`, 0.38427825509893676`, 0.9377750919467229],
              UndirectedEdge[48, 244] -> 
             RGBColor[
              0.19115682833937214`, 0.31824832500058275`, 0.9341974706315176],
              UndirectedEdge[110, 278] -> 
             RGBColor[
              0.19327360105018532`, 0.32047318733078894`, 0.9343180177059138],
              UndirectedEdge[245, 288] -> 
             RGBColor[
              0.2170539171587743, 0.34546780732004123`, 0.9356722715284729], 
             UndirectedEdge[106, 210] -> 
             RGBColor[
              0.6667698289178824, 0.73732879896912, 0.9691188386686375], 
             UndirectedEdge[176, 296] -> 
             RGBColor[
              0.19069988788986053`, 0.3177680516164482, 0.9341714485489008], 
             UndirectedEdge[82, 154] -> 
             RGBColor[
              0.5553686317376758, 0.6499123001732142, 0.9581397995541713], 
             UndirectedEdge[46, 117] -> 
             RGBColor[
              0.1951092767006187, 0.3224025988279529, 0.9344225567185672], 
             UndirectedEdge[249, 258] -> 
             RGBColor[
              0.2738091064777124, 0.40221653034560445`, 0.9390107464799751], 
             UndirectedEdge[146, 170] -> 
             RGBColor[
              0.19880274533348388`, 0.3262846685405311, 0.9346328942932117], 
             UndirectedEdge[18, 129] -> 
             RGBColor[
              0.1945312219559263, 0.32179502664049353`, 0.9343896373560123], 
             UndirectedEdge[13, 179] -> 
             RGBColor[
              0.42802275177735205`, 0.5432681021152472, 0.9490151577652866], 
             UndirectedEdge[144, 160] -> 
             RGBColor[
              0.19670215780285202`, 0.3240768178608952, 0.934513268940883], 
             UndirectedEdge[17, 130] -> 
             RGBColor[
              0.8077331614173798, 0.7282311492830874, 0.6094955989444572], 
             UndirectedEdge[111, 163] -> 
             RGBColor[
              0.6176770518281398, 0.70049708256499, 0.9630449466269559], 
             UndirectedEdge[107, 251] -> 
             RGBColor[
              0.34704129264344796`, 0.47287212594221606`, 0.943412473599851], 
             UndirectedEdge[1, 198] -> 
             RGBColor[
              0.8673259572403823, 0.4208317382887128, 0.4252968469940128], 
             UndirectedEdge[168, 269] -> 
             RGBColor[
              0.6867881591822118, 0.7211895103907764, 0.6484929822846838], 
             UndirectedEdge[145, 201] -> 
             RGBColor[
              0.8518773491973987, 0.5315008727671069, 0.456374840298414], 
             UndirectedEdge[197, 226] -> 
             RGBColor[
              0.9862994243091077, 0.9886024741101505, 0.8767175253588012], 
             UndirectedEdge[105, 174] -> 
             RGBColor[
              0.25852249961576723`, 0.3890539167423275, 0.9380338459521285], 
             UndirectedEdge[178, 284] -> 
             RGBColor[
              0.24998452415634886`, 0.38007996319556836`, 0.9375476208805174],
              UndirectedEdge[201, 202] -> 
             RGBColor[
              0.8524329734673737, 0.3954661457870175, 0.19750790475074864`], 
             UndirectedEdge[24, 65] -> 
             RGBColor[
              0.6506137006766177, 0.6184091477452374, 0.6013947753940398], 
             UndirectedEdge[134, 169] -> 
             RGBColor[
              0.42476901028009817`, 0.532311534169465, 0.9496393645496872], 
             UndirectedEdge[104, 300] -> 
             RGBColor[
              0.2803668703826312, 0.4095782545351725, 0.9393670254375599], 
             UndirectedEdge[168, 225] -> 
             RGBColor[
              0.31400402532006444`, 0.4388934235578272, 0.9415037514868442], 
             UndirectedEdge[27, 202] -> 
             RGBColor[
              0.9009943249734276, 0.6279839494543441, 0.2526972486332866], 
             UndirectedEdge[113, 187] -> 
             RGBColor[
              0.24618639037776724`, 0.3760878837786886, 0.9373313227806626], 
             UndirectedEdge[7, 201] -> 
             RGBColor[
              0.8763492903148913, 0.5509690808206948, 0.45714696205531347`], 
             UndirectedEdge[51, 104] -> 
             RGBColor[
              0.5731922784257398, 0.6585842020957557, 0.9621993062038972], 
             UndirectedEdge[2, 183] -> 
             RGBColor[
              0.19566573686527955`, 0.3229874737426237, 0.9344542463017356], 
             UndirectedEdge[135, 249] -> 
             RGBColor[
              0.21026660117408774`, 0.33833390787944695`, 0.9352857439240791],
              UndirectedEdge[84, 270] -> 
             RGBColor[
              0.20015353292457566`, 0.32770443194364846`, 0.9347098196482133],
              UndirectedEdge[114, 116] -> 
             RGBColor[
              0.26324193971723214`, 0.3940143475187522, 0.9383026110841209], 
             UndirectedEdge[15, 168] -> 
             RGBColor[
              0.3293937457780264, 0.4550689955237798, 0.942380173299874], 
             UndirectedEdge[42, 237] -> 
             RGBColor[
              0.8334280441412762, 0.2579481722980025, 0.1796440388622492], 
             UndirectedEdge[40, 140] -> 
             RGBColor[
              0.7746238811196319, 0.3418026092174846, 0.43269867546052243`], 
             UndirectedEdge[42, 167] -> 
             RGBColor[
              0.8609638306693929, 0.4172670345342654, 0.20395475904067392`], 
             UndirectedEdge[16, 285] -> 
             RGBColor[
              0.22323502267117318`, 0.3519645411182973, 0.9360242763432778], 
             UndirectedEdge[8, 286] -> 
             RGBColor[
              0.21267948434468417`, 0.34087000107737286`, 0.9354231540511039],
              UndirectedEdge[9, 236] -> 
             RGBColor[
              0.21519552032906075`, 0.34351451442284786`, 0.9355664385782725],
              UndirectedEdge[54, 238] -> 
             RGBColor[
              0.21574020514797415`, 0.344087012702538, 0.9355974575729206], 
             UndirectedEdge[165, 183] -> 
             RGBColor[
              0.2052672821395783, 0.33307930659904317`, 0.9350010401008936], 
             UndirectedEdge[249, 263] -> 
             RGBColor[
              0.20867298294508915`, 0.33665891407953785`, 0.9351949897234846],
              UndirectedEdge[33, 98] -> 
             RGBColor[
              0.18977923539730202`, 0.3168003874740297, 0.9341190187514328], 
             UndirectedEdge[282, 293] -> 
             RGBColor[
              0.6701954566467123, 0.5968924733689558, 0.5936831325375491], 
             UndirectedEdge[54, 163] -> 
             RGBColor[
              0.4325936369919836, 0.5385727559524309, 0.9502636460208878], 
             UndirectedEdge[145, 237] -> 
             RGBColor[
              0.8383510633263312, 0.42753191230581933`, 0.44342205367252496`],
              UndirectedEdge[140, 181] -> 
             RGBColor[
              0.8736439880136796, 0.4112274879198171, 0.24323035592583006`], 
             UndirectedEdge[15, 265] -> 
             RGBColor[
              0.24054595553413333`, 0.37015942913380495`, 0.9370101083605932],
              UndirectedEdge[144, 230] -> 
             RGBColor[
              0.19486271425090618`, 0.32214344606034284`, 0.9344085153518125],
              UndirectedEdge[22, 266] -> 
             RGBColor[
              0.1933455924812791, 0.32054885488938883`, 0.9343221175114128], 
             UndirectedEdge[18, 165] -> 
             RGBColor[
              0.2088844992725249, 0.33688123115058255`, 0.9352070352654217], 
             UndirectedEdge[17, 140] -> 
             RGBColor[
              0.7794337135277863, 0.345560086850815, 0.43317807460452784`], 
             UndirectedEdge[80, 237] -> 
             RGBColor[
              0.8763192452000071, 0.442552928220461, 0.2384882540724326], 
             UndirectedEdge[7, 127] -> 
             RGBColor[
              0.6435774661849356, 0.7150423967840147, 0.9663706566026036], 
             UndirectedEdge[60, 212] -> 
             RGBColor[
              0.2603180236560096, 0.39094112635142153`, 0.9381360983899805], 
             UndirectedEdge[53, 270] -> 
             RGBColor[
              0.21435826979552958`, 0.3426345110273567, 0.935518758398989], 
             UndirectedEdge[243, 254] -> 
             RGBColor[
              0.6530996726183891, 0.7197996840615158, 0.8998607275791879], 
             UndirectedEdge[201, 277] -> 
             RGBColor[
              0.8945797907010281, 0.562282566775544, 0.2876123598448103], 
             UndirectedEdge[288, 296] -> 
             RGBColor[
              0.1980362372485557, 0.3254790199438521, 0.9345892427917222], 
             UndirectedEdge[93, 273] -> 
             RGBColor[
              0.24003010742833283`, 0.36961724006794966`, 0.9369807315740968],
              UndirectedEdge[128, 277] -> 
             RGBColor[
              0.8942972321572974, 0.5601106979904866, 0.2873417814642296], 
             UndirectedEdge[3, 115] -> 
             RGBColor[
              0.6529735529155825, 0.7222241006469869, 0.9530066800693597], 
             UndirectedEdge[74, 123] -> 
             RGBColor[
              0.20225228122772315`, 0.32991034947858455`, 0.9348293402592576],
              UndirectedEdge[52, 147] -> 
             RGBColor[
              0.20606540532151835`, 0.3339181846671946, 0.9350464920353876], 
             UndirectedEdge[64, 76] -> 
             RGBColor[
              0.28111114711231006`, 0.41111591460968555`, 0.939381752805837], 
             UndirectedEdge[132, 260] -> 
             RGBColor[
              0.2275319348126233, 0.35648086821892655`, 0.9362689791330215], 
             UndirectedEdge[171, 285] -> 
             RGBColor[
              0.18941388075270052`, 0.31641637657773114`, 0.9340982123449165],
              UndirectedEdge[226, 290] -> 
             RGBColor[
              0.9663340369194856, 0.9069146206326038, 0.576578764162101], 
             UndirectedEdge[24, 290] -> 
             RGBColor[
              0.9350874753344331, 0.7803505010572445, 0.2666280628425426], 
             UndirectedEdge[103, 265] -> 
             RGBColor[
              0.3220227389937979, 0.445387567907627, 0.9420312197585695], 
             UndirectedEdge[41, 208] -> 
             RGBColor[
              0.1889556017616225, 0.3159346963015419, 0.9340721140343375], 
             UndirectedEdge[80, 179] -> 
             RGBColor[
              0.7507825863487789, 0.7818072220217351, 0.663873785850424], 
             UndirectedEdge[102, 183] -> 
             RGBColor[
              0.19246783079694663`, 0.31962627170585023`, 0.934272130282022], 
             UndirectedEdge[16, 220] -> 
             RGBColor[
              0.2899399087951104, 0.41982488843615623`, 0.9399054307139528], 
             UndirectedEdge[52, 217] -> 
             RGBColor[
              0.19938565089971289`, 0.32689733924898534`, 0.9346660899028769],
              UndirectedEdge[24, 241] -> 
             RGBColor[
              0.9549441101488896, 0.8619933825501465, 0.5685691356523801], 
             UndirectedEdge[105, 163] -> 
             RGBColor[
              0.4524953087499887, 0.5594906748089641, 0.9513970167856213], 
             UndirectedEdge[2, 102] -> 
             RGBColor[
              0.19539325191364892`, 0.3227010747819161, 0.9344387286868456], 
             UndirectedEdge[49, 54] -> 
             RGBColor[
              0.22682934694082163`, 0.355742403819019, 0.936228967793108], 
             UndirectedEdge[216, 237] -> 
             RGBColor[
              0.8526673664281595, 0.38892998001081047`, 0.19740587187632483`],
              UndirectedEdge[89, 281] -> 
             RGBColor[
              0.6796029595718664, 0.743830302697593, 0.9334123929687868], 
             UndirectedEdge[145, 167] -> 
             RGBColor[
              0.8862929429929738, 0.7834059474084649, 0.6157767446761826], 
             UndirectedEdge[16, 90] -> 
             RGBColor[
              0.2312332284112072, 0.3603711624666066, 0.9364797623278878], 
             UndirectedEdge[210, 290] -> 
             RGBColor[
              0.7090449941186435, 0.7036067912817707, 0.613645317642163], 
             UndirectedEdge[152, 242] -> 
             RGBColor[
              0.1817008098525566, 0.3083094500247394, 0.9336589643676192], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.18784627824446665`, 0.31476872694983776`, 0.9340089397011326],
              UndirectedEdge[77, 282] -> 
             RGBColor[
              0.42720741988360567`, 0.5444473278590943, 0.9484422569236628], 
             UndirectedEdge[81, 162] -> 
             RGBColor[
              0.9404065856589258, 0.790829015220349, 0.5112620539625906], 
             UndirectedEdge[34, 247] -> 
             RGBColor[
              0.1907246807083084, 0.31779411044059236`, 0.9341728604632337], 
             UndirectedEdge[7, 60] -> 
             RGBColor[
              0.6127935489939296, 0.6863930727259957, 0.9644818440323379], 
             UndirectedEdge[155, 162] -> 
             RGBColor[
              0.9588310572734952, 0.8681281277104613, 0.5263067793464253], 
             UndirectedEdge[234, 249] -> 
             RGBColor[
              0.2008059288288086, 0.3283901414032867, 0.934746972629826], 
             UndirectedEdge[118, 234] -> 
             RGBColor[
              0.19143808005152518`, 0.3185439383824441, 0.9342134875004501], 
             UndirectedEdge[223, 271] -> 
             RGBColor[
              0.20206279459486376`, 0.3297111870133029, 0.9348185492758365], 
             UndirectedEdge[154, 216] -> 
             RGBColor[
              0.7434083499065284, 0.5252723810458323, 0.4580470065820631], 
             UndirectedEdge[147, 247] -> 
             RGBColor[
              0.2055770841992048, 0.33340492820629564`, 0.9350186828698783], 
             UndirectedEdge[4, 286] -> 
             RGBColor[
              0.22071420539136402`, 0.34931500232817103`, 0.9358807195284078],
              UndirectedEdge[88, 124] -> 
             RGBColor[
              0.20439146202389424`, 0.3321587641272566, 0.9349511634409652], 
             UndirectedEdge[23, 136] -> 
             RGBColor[
              0.6909810750975458, 0.7521740618261392, 0.8862275585719336], 
             UndirectedEdge[11, 104] -> 
             RGBColor[
              0.4334513122055766, 0.547724101182389, 0.9494290167598639], 
             UndirectedEdge[4, 121] -> 
             RGBColor[
              0.2229935575329976, 0.35171074594830076`, 0.9360105252608744], 
             UndirectedEdge[4, 213] -> 
             RGBColor[
              0.21145636706915383`, 0.33958442727067606`, 0.9353534993317023],
              UndirectedEdge[198, 204] -> 
             RGBColor[
              0.7240997016369111, 0.7823833581016821, 0.9486564217578735], 
             UndirectedEdge[156, 168] -> 
             RGBColor[
              0.3974514720884778, 0.5186742214563766, 0.9465462342423088], 
             UndirectedEdge[31, 226] -> 
             RGBColor[
              0.7029528418062473, 0.7632425995782364, 0.912689477230743], 
             UndirectedEdge[36, 242] -> 
             RGBColor[
              0.18110760662426995`, 0.30768595582055314`, 0.9336251823213337],
              UndirectedEdge[216, 269] -> 
             RGBColor[
              0.9020307778688763, 0.6313968506786615, 0.25694130282079497`], 
             UndirectedEdge[97, 202] -> 
             RGBColor[
              0.7273332106591868, 0.5124071693605181, 0.4568577343104335], 
             UndirectedEdge[23, 59] -> 
             RGBColor[
              0.9871771704378065, 0.988965444691414, 0.8621710004720957], 
             UndirectedEdge[174, 238] -> 
             RGBColor[
              0.21032414623090429`, 0.3383943913827284, 0.9352890210299346], 
             UndirectedEdge[86, 97] -> 
             RGBColor[
              0.5215176139849236, 0.6223094238976072, 0.9555083823712963], 
             UndirectedEdge[46, 212] -> 
             RGBColor[
              0.21903868251240277`, 0.34755392154809645`, 0.9357853009791648],
              UndirectedEdge[59, 291] -> 
             RGBColor[
              0.955941254786202, 0.9662985742039245, 0.945506158028788], 
             UndirectedEdge[125, 149] -> 
             RGBColor[
              0.8552975837103799, 0.3871468134192908, 0.19906309946450382`], 
             UndirectedEdge[32, 80] -> 
             RGBColor[
              0.9832422855582464, 0.9646748589231064, 0.6130382528147665], 
             UndirectedEdge[69, 90] -> 
             RGBColor[
              0.21162247094140993`, 0.33975901297201105`, 0.9353629587014987],
              UndirectedEdge[215, 229] -> 
             RGBColor[
              0.2212270314220612, 0.34985401500148217`, 0.9359099242121978], 
             UndirectedEdge[187, 245] -> 
             RGBColor[
              0.22499133551940492`, 0.35381053727845513`, 0.9361242957617526],
              UndirectedEdge[98, 275] -> 
             RGBColor[
              0.17961340510331275`, 0.30611545528417883`, 0.9335400897551883],
              UndirectedEdge[252, 280] -> 
             RGBColor[
              0.2499775972482043, 0.3800726825759171, 0.937547226403346], 
             UndirectedEdge[96, 146] -> 
             RGBColor[
              0.20048974504421074`, 0.3280578121984645, 0.9347289664310452], 
             UndirectedEdge[191, 270] -> 
             RGBColor[
              0.22010792895967446`, 0.34867776735831935`, 0.9358461929825286],
              UndirectedEdge[40, 120] -> 
             RGBColor[
              0.4841619759818365, 0.5839129078583203, 0.9544325893141365], 
             UndirectedEdge[215, 233] -> 
             RGBColor[
              0.2150686635576537, 0.34338117991291517`, 0.9355592142728086], 
             UndirectedEdge[21, 257] -> 
             RGBColor[
              0.1888268034733999, 0.3157993211343368, 0.9340647791623633], 
             UndirectedEdge[200, 245] -> 
             RGBColor[
              0.2954064062007655, 0.4225674449726149, 0.9403266970812623], 
             UndirectedEdge[41, 108] -> 
             RGBColor[
              0.21464006545615802`, 0.34293069613355404`, 0.9355348062449824],
              UndirectedEdge[63, 73] -> 
             RGBColor[
              0.18277574146873998`, 0.309439271307949, 0.933720180132942]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {3}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.8649038628242013, 0.8951148792988238, 0.9869764966166072], 
             160 -> RGBColor[
              0.19576440547633542`, 0.32309118070879467`, 0.9344598653331682],
              245 -> 
             RGBColor[
              0.22524249753236514`, 0.35407452447866766`, 0.9361385990668298],
              155 -> RGBColor[
              0.9263138375757084, 0.7455659509853682, 0.2595685879581257], 
             213 -> RGBColor[
              0.20237506472464956`, 0.3300394027187775, 0.9348363325977657], 
             27 -> RGBColor[
              0.9698415036520304, 0.9099304516459211, 0.33734036595263717`], 
             19 -> RGBColor[
              0.18771789764902583`, 0.31463379080422954`, 0.9340016286161444],
              164 -> RGBColor[
              0.18196114135351968`, 0.30858307493822207`, 0.9336737898614731],
              190 -> RGBColor[
              0.2044144915577996, 0.3321829696275479, 0.9349524749388519], 
             103 -> RGBColor[
              0.4213296380105047, 0.5393562886265211, 0.9480677298602272], 
             138 -> RGBColor[
              0.231287806205471, 0.36042852718880986`, 0.9364828704525304], 
             291 -> RGBColor[
              0.926874823682218, 0.9445288413300859, 0.9928873421853748], 28 -> 
             RGBColor[
              0.18347004528514485`, 0.31016902864039503`, 0.9337597197081559],
              195 -> RGBColor[
              0.18372407711397143`, 0.31043603219904004`, 0.9337741864450011],
              114 -> RGBColor[
              0.23913206195702244`, 0.3686733373382309, 0.9369295892130448], 
             93 -> RGBColor[
              0.24113006344271598`, 0.3707733635803057, 0.9370433724418767], 
             34 -> RGBColor[
              0.1836929464736069, 0.31040331192222026`, 0.933772413601086], 
             161 -> RGBColor[
              0.2016546493170191, 0.3292822004483829, 0.9347953060060602], 22 -> 
             RGBColor[
              0.18854143418810532`, 0.3154993799220345, 0.9340485278037318], 
             124 -> RGBColor[
              0.1859244664032461, 0.3127487808548065, 0.9338994953598411], 84 -> 
             RGBColor[
              0.18746791982634672`, 0.31437104826308443`, 0.9339873927489519],
              46 -> RGBColor[
              0.2047087295239663, 0.33249223238575365`, 0.9349692313557391], 
             241 -> RGBColor[
              0.986124206873734, 0.9885300171977407, 0.8796213317111282], 185 -> 
             RGBColor[
              0.5295564396500168, 0.6289567998104505, 0.9561077692398556], 
             121 -> RGBColor[
              0.22544944565233713`, 0.35429204007402687`, 0.9361503844561099],
              126 -> RGBColor[
              0.22348836128871713`, 0.3522308160679321, 0.9360387036027661], 
             236 -> 
             RGBColor[
              0.23143093535124384`, 0.3605789649959291, 0.9364910214456416], 
             78 -> RGBColor[
              0.19413140389541048`, 0.3213747925089622, 0.9343668683089438], 
             254 -> RGBColor[
              0.31878183695974033`, 0.45053453755869494`, 0.9415334746567325],
              290 -> RGBColor[
              0.9464109372448213, 0.8252442542119368, 0.27573918609145315`], 
             251 -> RGBColor[
              0.28560729073547014`, 0.4175217494840773, 0.9395762847380378], 
             165 -> RGBColor[
              0.21779424853057935`, 0.34624594253152846`, 0.935714432304875], 
             100 -> RGBColor[
              0.1806628381309981, 0.3072184759341732, 0.933599853413618], 235 -> 
             RGBColor[
              0.40849384697781144`, 0.528238571579618, 0.9472498446058684], 
             70 -> RGBColor[
              0.20976983040282712`, 0.33781177030176596`, 0.9352574535635624],
              234 -> RGBColor[
              0.1941551643020383, 0.3213997662028249, 0.9343682214289508], 
             257 -> RGBColor[
              0.18407578926115742`, 0.31080570396557056`, 0.9337942159314718],
              135 -> RGBColor[
              0.21307650899259664`, 0.34128729915514544`, 0.9354457640174572],
              265 -> RGBColor[
              0.22271583997709107`, 0.35141884718873295`, 0.9359947096569118],
              111 -> RGBColor[
              0.6142037164471443, 0.6976772724307221, 0.9627715129425172], 
             182 -> RGBColor[
              0.2543436096659436, 0.38466163844813683`, 0.9377958643515997], 
             188 -> RGBColor[
              0.35586441424032067`, 0.4826536021746064, 0.9438963436902155], 
             154 -> RGBColor[
              0.4972976140125026, 0.6027676319143825, 0.9535682363176986], 
             269 -> RGBColor[
              0.9731648978995463, 0.9211410408128702, 0.3502511250338943], 
             208 -> RGBColor[
              0.18931653926981418`, 0.3163140645074111, 0.9340926688914699], 
             86 -> RGBColor[
              0.5941770672605392, 0.6814187364307716, 0.9611949417585145], 
             119 -> RGBColor[
              0.18085158366002294`, 0.307416859452336, 0.933610602192272], 
             140 -> RGBColor[0.817319, 0.134127, 0.164218], 85 -> 
             RGBColor[
              0.23214849009490668`, 0.36133316052711717`, 0.9365318851267661],
              242 -> RGBColor[
              0.18088209567567362`, 0.3074489295153584, 0.9336123398064248], 
             117 -> 
             RGBColor[
              0.1855098238772711, 0.3123129652701522, 0.9338758820813954], 47 -> 
             RGBColor[
              0.18409960782193097`, 0.31083073878312756`, 0.9337955723632715],
              81 -> RGBColor[
              0.8894648943465696, 0.5909677260051436, 0.2294791371904563], 
             275 -> RGBColor[
              0.1801747671672662, 0.30670548240580453`, 0.9335720584942697], 
             23 -> RGBColor[
              0.989346654985427, 0.9898625823050647, 0.82621702707199], 110 -> 
             RGBColor[
              0.18591721951216156`, 0.3127411639127972, 0.9338990826601146], 
             6 -> RGBColor[
              0.2105950138195758, 0.3386790903924193, 0.9353044465383967], 
             218 -> RGBColor[
              0.9671895696970209, 0.9750506153189628, 0.9404236795589124], 
             108 -> RGBColor[
              0.24068546665888524`, 0.3703060641714354, 0.9370180533127597], 
             297 -> RGBColor[
              0.19199315011410678`, 0.319127352211692, 0.9342450979193615], 
             157 -> RGBColor[
              0.18253809113335498`, 0.30918948573755783`, 0.933706646297914], 
             270 -> RGBColor[
              0.2128391460228046, 0.3410378156242125, 0.9354322465474746], 33 -> 
             RGBColor[
              0.20050642775524471`, 0.3280753467855062, 0.9347299164867587], 
             252 -> RGBColor[
              0.23794228148785246`, 0.3674228026286945, 0.9368618329754481], 
             260 -> RGBColor[
              0.25816755850577977`, 0.38868085113116446`, 0.938013632581003], 
             159 -> RGBColor[
              0.29124080035179, 0.42344292527596916`, 0.9398971047766567], 
             183 -> RGBColor[
              0.19274031574857725`, 0.3199126706665578, 0.9342876478969121], 
             99 -> RGBColor[
              0.19567419878950365`, 0.3229963677615002, 0.9344547281958019], 
             17 -> RGBColor[
              0.7036631405833589, 0.768426260552445, 0.9710982238135836], 277 -> 
             RGBColor[
              0.9930111873350895, 0.9874599613241353, 0.4806890552557963], 
             104 -> RGBColor[
              0.3350878162698179, 0.46465795727473413`, 0.9425724772395593], 
             79 -> RGBColor[
              0.18314084159618357`, 0.3098230146905773, 0.9337409720450827], 
             191 -> RGBColor[
              0.2273767118965443, 0.3563177190924262, 0.9362601394175826], 50 -> 
             RGBColor[
              0.1818234123124711, 0.30843831298355445`, 0.9336659463963373], 
             225 -> 
             RGBColor[
              0.2275966301752516, 0.35654886714697176`, 0.936272663438215], 
             61 -> RGBColor[
              0.2772592389822082, 0.4087474177943471, 0.9391008755405253], 
             196 -> RGBColor[
              0.2030597206401025, 0.3307590194956109, 0.934875322739293], 1 -> 
             RGBColor[
              0.8186934053129894, 0.1446912815038851, 0.16553413207988746`], 
             263 -> RGBColor[
              0.20988927253459944`, 0.3379373115553272, 0.935264255616268], 
             201 -> RGBColor[
              0.8453640923839973, 0.3496938695012485, 0.19107401213931735`], 
             293 -> RGBColor[
              0.8997587664774066, 0.6377097951563564, 0.23806859642232206`], 
             184 -> RGBColor[
              0.1914897805011185, 0.3185982788329645, 0.9342164317645705], 
             106 -> RGBColor[
              0.861860606843299, 0.8926882695866354, 0.9866862281444021], 206 -> 
             RGBColor[
              0.22242260484653656`, 0.35111063847433904`, 0.9359780103500293],
              247 -> RGBColor[
              0.19775641494300986`, 0.32518490895896446`, 0.9345733073253814],
              220 -> RGBColor[
              0.33308943974472227`, 0.4629270639700209, 0.9424451424544752], 
             107 -> RGBColor[
              0.40847529455142584`, 0.5282225024003548, 0.9472486624616643], 
             131 -> RGBColor[
              0.22940782651350908`, 0.3584525493349609, 0.9363758083902539], 
             127 -> RGBColor[
              0.34883524619319184`, 0.47656529010844195`, 0.9434484513179017],
              210 -> RGBColor[
              0.4716790509924657, 0.5819693283516046, 0.9515514491928728], 
             181 -> RGBColor[
              0.9862939640410388, 0.9654284637594515, 0.4012550677774902], 
             194 -> RGBColor[
              0.6860055424687634, 0.754632010702607, 0.9693382794531569], 118 -> 
             RGBColor[
              0.1887209958010121, 0.3156881105620633, 0.9340587535719493], 
             276 -> RGBColor[
              0.24137384732010603`, 0.3710295958922332, 0.9370572555730482], 
             280 -> RGBColor[
              0.2620129130085561, 0.39272256252313964`, 0.938232619831244], 
             189 -> RGBColor[
              0.21583585429987417`, 0.3441875460256914, 0.935602904650621], 
             168 -> RGBColor[
              0.4004114204648772, 0.5212379799686826, 0.9467348395354733], 41 -> 
             RGBColor[
              0.1885946642534308, 0.31555532809567266`, 0.9340515591772053], 
             14 -> 
             RGBColor[
              0.1801938510546308, 0.30672554078141306`, 0.9335731452934231], 
             77 -> RGBColor[
              0.4137826929511934, 0.5328195041366336, 0.9475868451945494], 51 -> 
             RGBColor[
              0.8112967405816618, 0.8525104469167772, 0.981826135168235], 179 -> 
             RGBColor[
              0.5227567642523288, 0.6234365170007214, 0.9555724738845179], 
             223 -> RGBColor[
              0.1814903715451621, 0.30808826602110845`, 0.9336469802173286], 
             292 -> RGBColor[
              0.773715577090376, 0.8231517563699634, 0.978080396007364], 143 -> 
             RGBColor[
              0.3068945586163886, 0.4398960177176607, 0.9407885631521654], 
             112 -> RGBColor[
              0.18923133529375677`, 0.3162245097263307, 0.9340878166510814], 
             197 -> RGBColor[
              0.9863417120240653, 0.9886199611670301, 0.8760167084848537], 54 -> 
             RGBColor[
              0.24403688677483204`, 0.37382861920560384`, 0.937208911730381], 
             71 -> RGBColor[
              0.22331684544677569`, 0.35205054204331915`, 0.9360289360293025],
              177 -> RGBColor[
              0.29197171960673096`, 0.42421116775586953`, 0.9399387295469274],
              158 -> RGBColor[
              0.19294565339664288`, 0.32012849355383366`, 0.9342993415721996],
              226 -> RGBColor[
              0.9862571365941499, 0.9885849870532707, 0.8774183422327487], 
             203 -> RGBColor[
              0.9371250918628792, 0.9526285769763242, 0.9913149984604726], 
             115 -> RGBColor[
              0.3517287364030146, 0.47907148589714393`, 0.9436328219554587], 
             173 -> RGBColor[
              0.20128694378722742`, 0.32889571862269473`, 0.9347743657201101],
              212 -> RGBColor[
              0.23336863550083925`, 0.36261561071043924`, 0.9366013706025906],
              129 -> RGBColor[
              0.18908769389738214`, 0.3160735335113504, 0.9340796364860563], 
             279 -> RGBColor[
              0.23666672657285628`, 0.3660821135381808, 0.9367891920100534], 
             26 -> RGBColor[
              0.2290956026577889, 0.35812438226646315`, 0.9363580277035645], 
             40 -> RGBColor[
              0.6892336433588957, 0.7571538276524538, 0.9696600263815672], 
             146 -> RGBColor[
              0.20002902465321373`, 0.3275735658561667, 0.9347027290863527], 
             192 -> RGBColor[
              0.3306172943235091, 0.4607858158598078, 0.9422876195342679], 
             300 -> 
             RGBColor[
              0.2256459244954445, 0.3544985517956109, 0.9361615736355604], 
             221 -> RGBColor[
              0.1861956076915163, 0.31303376754012907`, 0.9339149364550904], 
             62 -> RGBColor[
              0.20167701950442632`, 0.3293057129336997, 0.9347965799551393], 
             286 -> RGBColor[
              0.22089074136906994`, 0.34950055283376746`, 0.9358907729911765],
              152 -> RGBColor[
              0.1825195240294396, 0.3091699705341204, 0.9337055889288136], 64 -> 
             RGBColor[
              0.2353045398184947, 0.3646503688917182, 0.9367116174895672], 37 -> 
             RGBColor[
              0.22656828106141946`, 0.3554680070272346, 0.9362141004774884], 
             148 -> RGBColor[
              0.2462972527349853, 0.37620440714520426`, 0.9373376362279], 261 -> 
             RGBColor[
              0.24473644409614725`, 0.3745638983048021, 0.9372487504849276], 
             15 -> RGBColor[
              0.2583760710911756, 0.38890001107887695`, 0.9380255070642746], 
             136 -> RGBColor[
              0.39261549520966454`, 0.5144855413472138, 0.9462380900718772], 
             198 -> RGBColor[
              0.964591061095168, 0.9731126518583681, 0.9448222768222637], 63 -> 
             RGBColor[
              0.18288267188311363`, 0.3095516619532356, 0.9337262696618512], 
             171 -> RGBColor[
              0.17914809400855325`, 0.30562638382115925`, 0.9335135909767078],
              59 -> RGBColor[
              0.985007685890186, 0.9880683070777632, 0.8981249738722014], 229 -> 
             RGBColor[
              0.2177123475199571, 0.3461598593765405, 0.9357097681634818], 
             102 -> RGBColor[
              0.19219534584531597`, 0.31933987274514264`, 0.9342566126671321],
              299 -> RGBColor[
              0.8186938987840391, 0.1446950745386128, 0.16553460462832187`], 
             128 -> RGBColor[
              0.8449402545684014, 0.34643606632366236`, 0.19066814456844627`],
              12 -> RGBColor[
              0.42962012936485927`, 0.5465370955454517, 0.948595992638333], 
             222 -> RGBColor[
              0.2214255710569613, 0.35006269274590207`, 0.9359212307506922], 
             92 -> RGBColor[
              0.8315546894535105, 0.24354874725857717`, 0.17785011229759332`],
              271 -> RGBColor[
              0.2226352176445654, 0.3513341080054973, 0.9359901183343445], 
             132 -> RGBColor[
              0.19689631111946682`, 0.3242808853066886, 0.9345243256850401], 
             80 -> 
             RGBColor[
              0.9788084084452291, 0.9401779270427488, 0.37217509781633024`], 
             244 -> RGBColor[
              0.1895037720729246, 0.31651085805472556`, 0.934103331522621], 
             150 -> RGBColor[
              0.9074094141907081, 0.6706162117894943, 0.24435764515870567`], 
             125 -> RGBColor[
              0.8351944719959239, 0.27152571084244637`, 0.18133557217075477`],
              258 -> RGBColor[
              0.340161519599846, 0.46905254408746033`, 0.942895769129249], 
             133 -> RGBColor[
              0.18528931800943133`, 0.31208119962217307`, 0.9338633245984311],
              255 -> RGBColor[
              0.3660178719215669, 0.49144801689048034`, 0.9445433130353144], 
             176 -> RGBColor[
              0.19419263806779313`, 0.3214391535066072, 0.9343703555044731], 
             230 -> RGBColor[
              0.19208551837244375`, 0.31922443710768994`, 0.9342503581550272],
              274 -> RGBColor[
              0.46304655962256364`, 0.5749610829682137, 0.9508718678503764], 
             87 -> RGBColor[
              0.9931480500222558, 0.9877526967730439, 0.4955857141352578], 
             130 -> RGBColor[
              0.9118031822514008, 0.6880360380137298, 0.24789297407533079`], 
             35 -> RGBColor[
              0.20639345636736367`, 0.33426298711601565`, 0.9350651740571405],
              31 -> RGBColor[
              0.41964854701834464`, 0.537900212103202, 0.9479606122287372], 
             18 -> RGBColor[
              0.19997475001447043`, 0.3275165197696367, 0.9346996382259684], 
             24 -> RGBColor[
              0.9237640134240451, 0.7354567479025522, 0.2575169395936321], 
             151 -> RGBColor[
              0.5978280581771518, 0.684382775332144, 0.9614823611374906], 137 -> 
             RGBColor[
              0.26153416243522165`, 0.3922193653160256, 0.9382053556943405], 
             296 -> RGBColor[
              0.18720713771192796`, 0.31409694972628927`, 0.9339725415933283],
              266 -> RGBColor[
              0.1981497507744529, 0.3255983298567432, 0.9345957072190938], 
             283 -> RGBColor[
              0.3058207768282486, 0.438767404976628, 0.9407274128678487], 284 -> 
             RGBColor[
              0.24095771526907575`, 0.3705922147223045, 0.9370335574683543], 
             238 -> RGBColor[
              0.1874435235211163, 0.31434540619947215`, 0.9339860034154601], 
             72 -> RGBColor[
              0.8294154563220671, 0.22710566399236717`, 0.1758015802350048], 
             288 -> 
             RGBColor[
              0.20886533678518346`, 0.33686109016141486`, 0.9352059439901159],
              172 -> RGBColor[
              0.19058407149220488`, 0.3176463212393284, 0.9341648529763892], 
             243 -> RGBColor[
              0.9874175082770378, 0.9890648305643368, 0.8581879805016432], 88 -> 
             RGBColor[
              0.22285845764454237`, 0.35156874739970667`, 0.9360028315220893],
              273 -> RGBColor[
              0.2389301514139497, 0.3684611165555936, 0.9369180907063167], 
             202 -> RGBColor[
              0.8665707356341262, 0.4870106983585556, 0.21037568997361125`], 
             98 -> RGBColor[
              0.1790520430393593, 0.3055254281625532, 0.9335081210161069], 30 -> 
             RGBColor[
              0.24929644188312317`, 0.37935674509947226`, 0.9375084356129837],
              116 -> RGBColor[
              0.2873518174774419, 0.41935535769927346`, 0.9396756329551971], 
             240 -> RGBColor[
              0.18053047455342514`, 0.3070793534218085, 0.9335923155036896], 
             73 -> RGBColor[
              0.1826688110543663, 0.3093268806626624, 0.9337140906040328], 29 -> 
             RGBColor[
              0.19525519293228838`, 0.32255596603906117`, 0.934430866432097], 
             75 -> RGBColor[
              0.3329293714790703, 0.46278842088357813`, 0.9424349430461306], 
             200 -> RGBColor[
              0.3655703148691659, 0.4910603654665621, 0.9445147950956946], 
             156 -> RGBColor[
              0.3944915237120784, 0.5161104629440706, 0.9463576289491441], 25 -> 
             RGBColor[
              0.1911156300253715, 0.31820502296044406`, 0.9341951244484827], 
             38 -> RGBColor[
              0.18611948239069784`, 0.312953755022346, 0.9339106012318261], 3 -> 
             RGBColor[
              0.9542183694281502, 0.96537671539683, 0.9623805381832607], 57 -> 
             RGBColor[
              0.17967566298483006`, 0.30618089226503126`, 0.9335436352494385],
              227 -> RGBColor[
              0.952704487454567, 0.8501960835922951, 0.28080312431882476`], 
             39 -> RGBColor[
              0.20172422019829714`, 0.3293553238556548, 0.934799267964828], 
             109 -> RGBColor[
              0.9928111618057213, 0.9912952449090205, 0.7688011832034702], 
             256 -> RGBColor[
              0.817928104297447, 0.13880884254138265`, 0.16480127896312016`], 
             287 -> RGBColor[
              0.2430009596347453, 0.3727397940997984, 0.9371499172122699], 
             239 -> 
             RGBColor[
              0.23757609093788187`, 0.36703791314285356`, 0.9368409789653577],
              285 -> RGBColor[
              0.1996796674968478, 0.327206369334303, 0.9346828337131252], 216 -> 
             RGBColor[
              0.8664637178535413, 0.48652475561155717`, 0.21028639171424535`],
              21 -> RGBColor[
              0.19357781768564236`, 0.320792938303103, 0.9343353423932549], 
             175 -> RGBColor[
              0.18260859612989327`, 0.30926359095919453`, 0.9337106614531641],
              7 -> RGBColor[
              0.9383196861766793, 0.9535195034595876, 0.9892928618873055], 13 -> 
             RGBColor[
              0.33328873930237535`, 0.463099687229773, 0.9424578416460552], 
             294 -> RGBColor[
              0.5360494193639693, 0.63422809324764, 0.9566189203875064], 193 -> 
             RGBColor[
              0.27956374695486264`, 0.41116960178785156`, 0.939232113860354], 
             60 -> RGBColor[
              0.28726741181117993`, 0.4192666419924039, 0.9396708261773704], 
             65 -> RGBColor[
              0.3774633879291902, 0.5013615475879224, 0.9452726111944477], 69 -> 
             RGBColor[
              0.20756886290590398`, 0.3354984139131004, 0.9351321117206522], 
             217 -> RGBColor[
              0.20003824461178885`, 0.32758325661720833`, 0.9347032541493537],
              214 -> RGBColor[
              0.20083038530367384`, 0.32841584670900015`, 0.9347483653898895],
              170 -> RGBColor[
              0.19757646601375403`, 0.32499577122489554`, 0.9345630595000708],
              74 -> RGBColor[
              0.20590138873724428`, 0.3337457928378705, 0.935037151533554], 
             246 -> RGBColor[
              0.1844498116639085, 0.31119882522525194`, 0.9338155159539919], 
             264 -> RGBColor[
              0.2962099519152749, 0.42866581863159803`, 0.9401800906069961], 
             278 -> RGBColor[
              0.2006299825882091, 0.3282052107487807, 0.934736952751713], 45 -> 
             RGBColor[
              0.29993474933268105`, 0.43258081688308847`, 0.9403922123095734],
              237 -> RGBColor[
              0.8250746635773962, 0.19374042880931708`, 0.17164483220048377`],
              228 -> RGBColor[
              0.426257062503514, 0.5436241760628097, 0.9483817009917713], 180 -> 
             RGBColor[
              0.19488460571983207`, 0.32216645538218325`, 0.9344097620385824],
              53 -> RGBColor[
              0.21587739356825456`, 0.3442312064305009, 0.9356052702505034], 
             48 -> 
             RGBColor[
              0.1928098846058197, 0.31998579194643995`, 0.9342916097404141], 
             5 -> RGBColor[
              0.9710126878169619, 0.9138811308413543, 0.3418901952738247], 
             101 -> RGBColor[
              0.6473280227603806, 0.724416838346381, 0.9654832657505968], 267 -> 
             RGBColor[
              0.1962060745132835, 0.32355540287006146`, 0.9344850177314316], 
             120 -> RGBColor[
              0.27909030860477735`, 0.41067198806418675`, 0.939205152246706], 
             147 -> RGBColor[
              0.21339775345539977`, 0.34162494745362687`, 0.9354640584143752],
              89 -> RGBColor[
              0.3807443443279537, 0.5042033471148679, 0.9454816708349412], 43 -> 
             RGBColor[
              0.2255865897625529, 0.3544361872293025, 0.9361581946103001], 
             199 -> RGBColor[
              0.19839476243792764`, 0.32585585264969186`, 0.9346096602708663],
              268 -> RGBColor[
              0.20504953117466115`, 0.3328504365287066, 0.9349886395055752], 
             169 -> RGBColor[
              0.6047389625257771, 0.6899933588150511, 0.9620264128432912], 20 -> 
             RGBColor[
              0.21900416978762977`, 0.3475176464861269, 0.9357833355305459], 
             4 -> RGBColor[
              0.2205376694136581, 0.34912945182257465`, 0.935870666065639], 
             167 -> RGBColor[
              0.9076820231617462, 0.6716970155181059, 0.2445769927357579], 
             142 -> RGBColor[
              0.8299355921400753, 0.23110365581454728`, 0.17629966288173887`],
              16 -> RGBColor[
              0.24679037784549854`, 0.37672271290229153`, 0.9373657189734305],
              281 -> RGBColor[
              0.9784615748157791, 0.9834572582803182, 0.9213431151026323], 
             289 -> RGBColor[
              0.2434445902532613, 0.3732060780076645, 0.9371751813197018], 
             178 -> RGBColor[
              0.25901133304362195`, 0.3895677116688322, 0.9380616842926806], 
             58 -> RGBColor[
              0.19114091674596853`, 0.31823160090706226`, 0.9341965644898124],
              186 -> RGBColor[
              0.19311599281626868`, 0.32030753108400334`, 0.9343090421501528],
              122 -> RGBColor[
              0.18504035865818397`, 0.31181952755907755`, 0.93384914673168], 
             249 -> RGBColor[
              0.20745669335557887`, 0.3353805166037485, 0.9351257238307011], 
             113 -> RGBColor[
              0.2676326072490897, 0.3986292174791347, 0.9385526531046497], 52 -> 
             RGBColor[
              0.1987330571876369, 0.3262114218807623, 0.9346289256564001], 
             187 -> RGBColor[
              0.22474017350644473`, 0.35354655007824254`, 0.9361099924566755],
              259 -> RGBColor[
              0.18516129488531852`, 0.3119466392015956, 0.9338560338709061], 
             42 -> RGBColor[
              0.8376047344232163, 0.2900520440423452, 0.18364364219313192`], 
             134 -> RGBColor[
              0.24479905803441923`, 0.3746297095238789, 0.9372523162560832], 
             248 -> RGBColor[
              0.22195872707107797`, 0.35062307352078237`, 0.9359515931969625],
              174 -> RGBColor[
              0.23320476894069225`, 0.36244337656598474`, 0.9365920386444091],
              215 -> RGBColor[
              0.22474171532416531`, 0.3535481706264238, 0.9361100802609137], 
             83 -> RGBColor[
              0.846552585818907, 0.35882915084310774`, 0.19221211479479816`], 
             95 -> RGBColor[
              0.28755638833203334`, 0.4195703746379904, 0.9396872829627306], 
             166 -> RGBColor[
              0.18609439165410657`, 0.312927383067344, 0.9339091723514956], 
             233 -> RGBColor[
              0.20539561179114207`, 0.3332141891994065, 0.9350083482847035], 
             295 -> RGBColor[
              0.19692281060910452`, 0.3243087379504625, 0.9345258347917725], 
             141 -> RGBColor[
              0.2938477713702168, 0.42618301710784506`, 0.940045567919488], 
             205 -> RGBColor[
              0.3723597127044757, 0.4969410006264502, 0.9449474095221317], 
             224 -> RGBColor[
              0.20866772558178895`, 0.33665338825737323`, 0.9351946903244223],
              231 -> RGBColor[
              0.23118072954041266`, 0.36031598282478083`, 0.9364767725948611],
              68 -> RGBColor[
              0.8768566069289154, 0.9046456729993274, 0.9881165600196555], 10 -> 
             RGBColor[
              0.19040293767796423`, 0.3174559381160143, 0.9341545376736317], 
             250 -> RGBColor[
              0.18265386603570732`, 0.30931117250048296`, 0.9337132395073293],
              282 -> RGBColor[
              0.4406321468160179, 0.5560751515815551, 0.9492976686527762], 
             232 -> RGBColor[
              0.18790775611424687`, 0.3148333440888988, 0.9340124407748683], 
             253 -> RGBColor[
              0.19184993915614282`, 0.3189768284147727, 0.9342369422671671], 
             55 -> RGBColor[
              0.20213692733288047`, 0.32978910522124555`, 0.9348227710255971],
              91 -> 
             RGBColor[
              0.49015879412300467`, 0.5969720163279171, 0.9530062422656385], 
             105 -> RGBColor[
              0.28384023029084227`, 0.41566445691867016`, 0.9394756532598479],
              36 -> RGBColor[
              0.18133311757286624`, 0.3079229821257478, 0.9336380248362428], 
             123 -> RGBColor[
              0.19860317371820202`, 0.3260749061192986, 0.9346215289849611], 
             94 -> RGBColor[
              0.796888814031874, 0.8412548651917855, 0.9803900876994809], 96 -> 
             RGBColor[
              0.20095046543520778`, 0.32854205854076235`, 0.9347552037757377],
              2 -> RGBColor[
              0.19859115798198185`, 0.32606227681868954`, 0.934620844706559], 
             262 -> RGBColor[
              0.3038398335581257, 0.4366853080006712, 0.9406146010791581], 
             272 -> RGBColor[
              0.17908821045117204`, 0.30556344240551475`, 0.9335101806967048],
              97 -> RGBColor[
              0.44885816070930806`, 0.563200111364443, 0.9498218229840781], 
             209 -> RGBColor[
              0.1804556557285978, 0.30700071409312746`, 0.9335880546823002], 
             66 -> RGBColor[
              0.3863417480503173, 0.5090515368854881, 0.9458383324505404], 
             139 -> RGBColor[
              0.4407231525670485, 0.5561539761890157, 0.9493034674587586], 56 -> 
             RGBColor[
              0.19935669202797407`, 0.3268669016386893, 0.9346644407379722], 
             144 -> RGBColor[
              0.19763991012936863`, 0.32506245501299574`, 0.9345666725485978],
              298 -> RGBColor[
              0.2601377913887575, 0.39075169081115385`, 0.9381258344289902], 
             204 -> RGBColor[
              0.4836083421786542, 0.5916540643449961, 0.9524905666934831], 
             207 -> RGBColor[
              0.18528775379377113`, 0.3120795555323372, 0.9338632355186633], 
             149 -> RGBColor[
              0.895503807139292, 0.6183890185729798, 0.2345181540520019], 219 -> 
             RGBColor[
              0.18433414396946993`, 0.31107725114464163`, 0.9338089288499086],
              9 -> RGBColor[
              0.19896010530687766`, 0.32645006384976655`, 0.9346418557109033],
              11 -> RGBColor[
              0.5318148081413353, 0.630790245090044, 0.9562855562801685], 44 -> 
             RGBColor[
              0.31621931418873805`, 0.44831500913059213`, 0.9413701929717141],
              153 -> RGBColor[
              0.22106916700115545`, 0.3496880894859278, 0.9359009340669666], 
             32 -> 
             RGBColor[
              0.9876761626712638, 0.9891717908034641, 0.8539014078132029], 
             162 -> RGBColor[
              0.9913482769712819, 0.9906903044355545, 0.7930449707347249], 90 -> 
             RGBColor[
              0.21567607897691587`, 0.34401961203092163`, 0.935593805682345], 
             8 -> RGBColor[
              0.2044682273202984, 0.33223944932097826`, 0.9349555351110312], 
             163 -> RGBColor[
              0.6211503872091352, 0.7033168926992579, 0.9633183803113946], 49 -> 
             RGBColor[
              0.20962180710681122`, 0.3376561884324342, 0.9352490238558351], 
             76 -> RGBColor[
              0.3269177544061254, 0.4575814603276529, 0.9420518881221068], 82 -> 
             RGBColor[
              0.6134396494628491, 0.6970569684320459, 0.962711362790644], 67 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 211 -> 
             RGBColor[
              0.2707327274798912, 0.4018876404006824, 
               0.9387292003655769]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJwtl3k4FGrYxsc2dmbMmGEYZp8hUUJS8qQSUSklLeLUoUhCylJkaUGShISD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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 5}], {
             RGBColor[
             0.8694664994809802, 0.4010878979497081, 0.22431948647786654`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 32}], {
             RGBColor[
             0.8750209910990808, 0.42618478460374476`, 0.39498989065765927`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 51}], {
             RGBColor[
             0.8162278504025469, 0.38063100330818245`, 0.4376314664426699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 80}], {
             RGBColor[
             0.8720650730237359, 0.40985349668350635`, 0.23441445399203503`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 83}], {
             RGBColor[
             0.827979798814962, 0.21607057128362597`, 0.1744267929848577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 92}], {
             RGBColor[
             0.8229805000264965, 0.17764377008878246`, 0.16963945881912273`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 125}], {
             RGBColor[
             0.8241937608739676, 0.18696942461673885`, 0.17080127877684323`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 128}], {
             RGBColor[
             0.8274423550647934, 0.21193954311047752`, 0.1739121362427404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 142}], {
             RGBColor[
             0.822440800922018, 0.17349540627410584`, 0.16912264234717125`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 149}], {
             RGBColor[
             0.8442968725884236, 0.3025905271935833, 0.18852880607059228`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 150}], {
             RGBColor[
             0.848265408272229, 0.31999959159908814`, 0.19180863643949353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 197}], {
             RGBColor[
             0.8745761742166813, 0.4260008413916001, 0.4023616575482095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 198}], {
             RGBColor[
             0.8673259572403823, 0.4208317382887128, 0.4252968469940128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 237}], {
             RGBColor[
             0.820820491401125, 0.16104099727236243`, 0.16757103212008623`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 243}], {
             RGBColor[
             0.8749347729676722, 0.4261491311907023, 0.39641874822047274`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 256}], {
             RGBColor[
             0.8184383049744752, 0.1427304685163843, 0.1652898477076317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 277}], {
             RGBColor[
             0.8767993326536895, 0.4256141747773018, 0.2705857731385237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 281}], {
             RGBColor[
             0.8719494618139193, 0.4242799404293628, 0.41747045975413577`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 49}], {
             RGBColor[
             0.20410648254439653`, 0.3318592326255619, 0.934934934281197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 54}], {
             RGBColor[
             0.22131402237840694`, 0.34994544801214666`, 0.9359148782184701]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 102}], {
             RGBColor[
             0.19539325191364892`, 0.3227010747819161, 0.9344387286868456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 165}], {
             RGBColor[
             0.2081927032562806, 0.336154109675109, 0.935167638505717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 172}], {
             RGBColor[
             0.19458761473709335`, 0.321854299029009, 0.9343928488414741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 174}], {
             RGBColor[
             0.21589796346133705`, 0.34425282669233714`, 0.9356064416754841]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 183}], {
             RGBColor[
             0.19566573686527955`, 0.3229874737426237, 0.9344542463017356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 238}], {
             RGBColor[
             0.19301734075154908`, 0.3202038415090809, 0.9343034240610095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 253}], {
             RGBColor[
             0.19522054856906235`, 0.32251955261673115`, 0.9344288934868631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 24}], {
             RGBColor[
             0.9389911914260977, 0.8504167316496911, 0.6099487388884464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 59}], {
             RGBColor[
             0.9696130276591681, 0.9767225112372966, 0.930252756027731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 65}], {
             RGBColor[
             0.6658408786786703, 0.7333691314923763, 0.9538265746888542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 72}], {
             RGBColor[
             0.8710164273574281, 0.4731960144605215, 0.4379945662177568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 106}], {
             RGBColor[
             0.9080394881357245, 0.9290324924917327, 0.9745333831638314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 115}], {
             RGBColor[
             0.6529735529155825, 0.7222241006469869, 0.9530066800693597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 155}], {
             RGBColor[
             0.9402661035019293, 0.855471333191099, 0.6109745630706932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[
             0.972783323199716, 0.9780335099161923, 0.8777127544589929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 169}], {
             RGBColor[
             0.7794786659769637, 0.8276850371059405, 0.962203475513276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 194}], {
             RGBColor[
             0.8201119559484569, 0.8600043630497185, 0.9658594088182089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 200}], {
             RGBColor[
             0.659894342148658, 0.7282185404316961, 0.9534476666394777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 210}], {
             RGBColor[
             0.7129487102103079, 0.7736730218742174, 0.9569659936880668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 227}], {
             RGBColor[
             0.9534614284413586, 0.9077863994945625, 0.6215918312510428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 228}], {
             RGBColor[
             0.690237715965832, 0.7545004457298199, 0.955381119587516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 241}], {
             RGBColor[
             0.9701712881509421, 0.9769533662972854, 0.9210009349471945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 264}], {
             RGBColor[
             0.6252141606717125, 0.697021267014214, 0.9512803143951285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 290}], {
             RGBColor[
             0.9503146533364857, 0.8953104848043834, 0.619059862137357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 291}], {
             RGBColor[
             0.940546596555184, 0.9549527783634579, 0.9776339401843177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 8}], {
             RGBColor[
             0.21250294836697825`, 0.34068445057177643`, 0.935413100588335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 15}], {
             RGBColor[
             0.23945687025241685`, 0.36901473145072583`, 0.9369480865649568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 62}], {
             RGBColor[
             0.21110734445904222`, 0.33921758237813715`, 0.9353336230103891]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 85}], {
             RGBColor[
             0.2263430797542824, 0.3552313061748459, 0.9362012755962026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 121}], {
             RGBColor[
             0.2229935575329976, 0.35171074594830076`, 0.9360105252608744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 135}], {
             RGBColor[
             0.21680708920312736`, 0.3452083754888601, 0.935658215041548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 158}], {
             RGBColor[
             0.2067416614051505, 0.33462897268820413`, 0.9350850038189193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 173}], {
             RGBColor[
             0.21091230660044274`, 0.33901258522263467`, 0.9353225158928745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 186}], {
             RGBColor[
             0.2068268311149634, 0.334718491453289, 0.9350898541078958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 213}], {
             RGBColor[
             0.21145636706915383`, 0.33958442727067606`, 0.9353534993317023]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 214}], {
             RGBColor[
             0.21068402735866598`, 0.33877264926578743`, 0.9353095157277642]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 249}], {
             RGBColor[
             0.21399718138461848`, 0.3422549842131616, 0.93549819494817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 255}], {
             RGBColor[
             0.2932777706676125, 0.42028873435652747`, 0.9402069895504767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 263}], {
             RGBColor[
             0.21521347097412877`, 0.3435333816889509, 0.9355674608409534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 265}], {
             RGBColor[
             0.22162675469537457`, 0.35027414950565383`, 0.9359326878612754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 276}], {
             RGBColor[
             0.23095575836688206`, 0.36007952385740394`, 0.9364639608193436]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 286}], {
             RGBColor[
             0.22071420539136402`, 0.34931500232817103`, 0.9358807195284078]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.7514137479791486, 0.7723356879656991, 0.6490878757769967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 23}], {
             RGBColor[
             0.9801796714011944, 0.9518718565732095, 0.5840536111729073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 51}], {
             RGBColor[
             0.8911547141993119, 0.8831957888790658, 0.6618581652210298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.978010186853574, 0.9509747189595588, 0.6200075845730131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[
             0.8880392864849254, 0.5438464775091899, 0.242104808287807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 92}], {
             RGBColor[
             0.8780406889079944, 0.46699287511950294`, 0.23253013995633712`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 101}], {
             RGBColor[
             0.8091703552886713, 0.8191489845938676, 0.6536867305122107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 128}], {
             RGBColor[
             0.8869643989845882, 0.5355844211628931, 0.24107549480357243`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 142}], {
             RGBColor[
             0.8769612906990375, 0.45869614749014964`, 0.23149650701243416`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 149}], {
             RGBColor[
             0.933258247478127, 0.766135074707167, 0.2882041746629133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 197}], {
             RGBColor[
             0.9786771999205136, 0.9512505460041922, 0.6089534518793391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 198}], {
             RGBColor[
             0.967801874456065, 0.9434968913498611, 0.6433562360480443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 204}], {
             RGBColor[
             0.7273105149978081, 0.7527675975931751, 0.6471903809836539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 226}], {
             RGBColor[
             0.978634912205556, 0.9512330589473125, 0.6096542687532867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 243}], {
             RGBColor[
             0.9792150980469998, 0.9514729807028455, 0.600039087887734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 256}], {
             RGBColor[
             0.868956298803952, 0.39716627197470655`, 0.223830917733355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 290}], {
             RGBColor[
             0.9587118125308915, 0.8695626925266455, 0.3088146906826389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 38}], {
             RGBColor[
             0.19835724810513683`, 0.32581642270738265`, 0.9346075238851115]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 52}], {
             RGBColor[
             0.20466403550360635`, 0.3324452561365908, 0.9349666860973984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.21323620369391516`, 0.3414551484114601, 0.9354548583944501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 88}], {
             RGBColor[
             0.21672673573205908`, 0.345123918896063, 0.935653639030243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 93}], {
             RGBColor[
             0.2258625386311459, 0.35472622698636247`, 0.9361739094901367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 124}], {
             RGBColor[
             0.19825974011141095`, 0.3257139356236129, 0.9346019709491189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 147}], {
             RGBColor[
             0.2119963836374878, 0.34015201892302305`, 0.935384252476386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 273}], {
             RGBColor[
             0.22476258261676274`, 0.3535701034740064, 0.9361112686223567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 289}], {
             RGBColor[
             0.22701980203641853`, 0.3559425842000419, 0.9362398139290493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 42}], {
             RGBColor[
             0.8711763850077039, 0.5112078638480927, 0.45219338209118976`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 60}], {
             RGBColor[
             0.6127935489939296, 0.6863930727259957, 0.9644818440323379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 77}], {
             RGBColor[
             0.6760511895639363, 0.7431695037981105, 0.9684398535409274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 80}], {
             RGBColor[
             0.9585640473109542, 0.9468487152511682, 0.6807339798518178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 81}], {
             RGBColor[
             0.9138922902616244, 0.7722436147323656, 0.6093859995388808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 82}], {
             RGBColor[
             0.7758796678197641, 0.8252882359458167, 0.9760021123389747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 103}], {
             RGBColor[
             0.6798246620935919, 0.7464378960430543, 0.9686802958737664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 127}], {
             RGBColor[
             0.6435774661849356, 0.7150423967840147, 0.9663706566026036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 130}], {
             RGBColor[
             0.92506143421404, 0.8207777707366587, 0.6185929179813181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 140}], {
             RGBColor[
             0.8576525620588931, 0.4072578344865292, 0.4392429539624352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 145}], {
             RGBColor[
             0.9016117745004403, 0.9243171913792056, 0.9881346792519563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 154}], {
             RGBColor[
             0.7178086500945909, 0.778143567686985, 0.971430549102502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 167}], {
             RGBColor[
             0.9230008546692128, 0.8126082594888467, 0.6169349273115317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 168}], {
             RGBColor[
             0.6693655533207783, 0.7373787417141351, 0.9680138507113893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 181}], {
             RGBColor[
             0.962306825108859, 0.9594739836095195, 0.6952739648323978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 201}], {
             RGBColor[
             0.8763492903148913, 0.5509690808206948, 0.45714696205531347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 202}], {
             RGBColor[
             0.890487052481644, 0.642513633392233, 0.47001474727817605`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 203}], {
             RGBColor[
             0.9377223890197792, 0.9530740402179558, 0.990303930173889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 205}], {
             RGBColor[
             0.6553396994405775, 0.7252302520430189, 0.9671201357047186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 216}], {
             RGBColor[
             0.8904157072945873, 0.6421896715609007, 0.4699552151052654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 237}], {
             RGBColor[
             0.8628230044438239, 0.4470001203594073, 0.4441941754294244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 255}], {
             RGBColor[
             0.6521687790491231, 0.722483760175034, 0.9669180874613099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 269}], {
             RGBColor[
             0.9557422920381128, 0.9373302721362289, 0.6697719934605999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 282}], {
             RGBColor[
             0.6894759164963487, 0.7547973275205713, 0.9692952652700408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 293}], {
             RGBColor[
             0.9190392263270429, 0.795614649307972, 0.6136807291548138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 299}], {
             RGBColor[
             0.8585691612482524, 0.41430321751227117`, 0.4401206903813164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 14}], {
             RGBColor[
             0.19233103918746458`, 0.31948249505119564`, 0.9342643402022272]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 64}], {
             RGBColor[
             0.21988638356939655`, 0.34844490910634823`, 0.9358335763002992]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 67}], {
             RGBColor[
             0.1916976136601492, 0.31881672466048916`, 0.9342282675555156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 69}], {
             RGBColor[
             0.2060185451131012, 0.33386893161703934`, 0.9350438234158418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 85}], {
             RGBColor[
             0.21830835870760254`, 0.3467863049240477, 0.9357437101188987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 121}], {
             RGBColor[
             0.21495883648631775`, 0.3432657446975026, 0.9355529597835706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 135}], {
             RGBColor[
             0.2087723681564475, 0.33676337423806185`, 0.9352006495642442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 173}], {
             RGBColor[
             0.2028775855537629, 0.3305675839718365, 0.9348649504155706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 186}], {
             RGBColor[
             0.19879211006828354`, 0.3262734902024908, 0.934632288630592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 213}], {
             RGBColor[
             0.20342164602247398`, 0.3311394260198779, 0.9348959338543985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 234}], {
             RGBColor[
             0.19931169581116837`, 0.32681960776190155`, 0.934661878269991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 249}], {
             RGBColor[
             0.20596246033793864`, 0.3338099829623634, 0.9350406294708662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 263}], {
             RGBColor[
             0.20717874992744892`, 0.3350883804381527, 0.9351098953636496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 286}], {
             RGBColor[
             0.21267948434468417`, 0.34087000107737286`, 0.9354231540511039]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 45}], {
             RGBColor[
             0.24944742731977937`, 0.3795154403664275, 0.9375170340102383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 47}], {
             RGBColor[
             0.1915298565644043, 0.31864040131644705`, 0.9342187140370874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 96}], {
             RGBColor[
             0.19995528537104273`, 0.3274960611952644, 0.9346985297433206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 112}], {
             RGBColor[
             0.19409572030031721`, 0.3213372867880486, 0.9343648361809924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 132}], {
             RGBColor[
             0.19792820821317225`, 0.32536547457822756`, 0.9345830906979717]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 133}], {
             RGBColor[
             0.19212471165815448`, 0.3192656317359698, 0.9342525901546672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 141}], {
             RGBColor[
             0.24640393833854723`, 0.3763165404788058, 0.9373437118151957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 146}], {
             RGBColor[
             0.1994945649800457, 0.3270118148529666, 0.9346722923986279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 236}], {
             RGBColor[
             0.21519552032906075`, 0.34351451442284786`, 0.9355664385782725]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 22}], {
             RGBColor[
             0.18947218593303478`, 0.31647765901902436`, 0.9341015327386817]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 48}], {
             RGBColor[
             0.19160641114189197`, 0.3187208650312271, 0.934223073707023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 63}], {
             RGBColor[
             0.18664280478053893`, 0.31350380003462497`, 0.9339404036677414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 71}], {
             RGBColor[
             0.20685989156236995`, 0.3347532400796667, 0.9350917368514671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 73}], {
             RGBColor[
             0.18653587436616526`, 0.31339140938933835`, 0.9339343141388322]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 100}], {
             RGBColor[
             0.18553288790448116`, 0.3123372070250937, 0.9338771955436248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 119}], {
             RGBColor[
             0.1856272606689936, 0.3124363987841752, 0.9338825699329518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 122}], {
             RGBColor[
             0.1877216481680741, 0.3146377328375459, 0.9340018422026558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 161}], {
             RGBColor[
             0.19602879349749167`, 0.3233690692821986, 0.9344749218398459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 244}], {
             RGBColor[
             0.1899533548754444, 0.3169833980853699, 0.9341289345981263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 266}], {
             RGBColor[
             0.19427634422620857`, 0.3215271339863788, 0.9343751224463628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 51}], {
             RGBColor[
             0.6715557743614986, 0.7416503460034106, 0.9690558457242018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 101}], {
             RGBColor[
             0.589571415450858, 0.6776035417182125, 0.9608844110153827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 104}], {
             RGBColor[
             0.4334513122055766, 0.547724101182389, 0.9494290167598639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 114}], {
             RGBColor[
             0.38547343504917886`, 0.49973179121413747`, 0.9466075727466067]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 116}], {
             RGBColor[
             0.4095833128093886, 0.5250728013946587, 0.9479805946176828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 149}], {
             RGBColor[
             0.7136593076403137, 0.6245896318315118, 0.5954018551660852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 197}], {
             RGBColor[
             0.7590782600827003, 0.809705103128537, 0.9161511323825111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 198}], {
             RGBColor[
             0.7482029346182517, 0.8019514484742061, 0.9505539165512161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 204}], {
             RGBColor[
             0.5077115751599948, 0.6112221547175201, 0.9543880614868259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 243}], {
             RGBColor[
             0.7596161582091865, 0.8099275378271904, 0.907236768390906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 254}], {
             RGBColor[
             0.4252983225505378, 0.5406623913243694, 0.9489095154684506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 283}], {
             RGBColor[
             0.41881779248479195`, 0.534778825033336, 0.9485064845740085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.3382052536051789, 0.4616299042238716, 0.9429808558058818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 27}], {
             RGBColor[
             0.6997308165084448, 0.7282337735956864, 0.6429681792954851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.33246233459167696`, 0.45559373221858496`, 0.9426538050639501]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 76}], {
             RGBColor[
             0.3782689418854923, 0.5020592779365523, 0.9453239403802199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 87}], {
             RGBColor[
             0.7113840896935575, 0.7671448961592477, 0.7220908533867955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 151}], {
             RGBColor[
             0.5137240937710055, 0.6154599354387978, 0.9550391768879118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 154}], {
             RGBColor[
             0.46345887168868094`, 0.5746523637299171, 0.9510821144780158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 181}], {
             RGBColor[
             0.707957046702949, 0.7559827796524516, 0.6749255302079116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 192}], {
             RGBColor[
             0.3801187118441842, 0.5036614557026298, 0.9454418060863005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 220}], {
             RGBColor[
             0.38135478455479077`, 0.5047320797577364, 0.9455205675464041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 239}], {
             RGBColor[
             0.3335981101513706, 0.4567875043441526, 0.9427184858018454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 258}], {
             RGBColor[
             0.3848908244823526, 0.507794819816456, 0.9457458808837911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 32}], {
             RGBColor[
             0.6604824509868196, 0.7261357390166185, 0.898179624729629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 53}], {
             RGBColor[
             0.27458306643531494`, 0.40366544683013694`, 0.9390315559482794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 93}], {
             RGBColor[
             0.2872094013725457, 0.41693652540503934`, 0.939750607043966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 107}], {
             RGBColor[
             0.3708820169269006, 0.49566109481506393`, 0.9448532520538597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 137}], {
             RGBColor[
             0.2974114508687985, 0.42765952627289927`, 0.9403315986701979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 147}], {
             RGBColor[
             0.27334324637888757`, 0.4023623173416999, 0.9389609500302152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 156}], {
             RGBColor[
             0.3638901315072269, 0.4896050750869218, 0.9444077352975997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 179}], {
             RGBColor[
             0.42802275177735205`, 0.5432681021152472, 0.9490151577652866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 251}], {
             RGBColor[
             0.3094480150189227, 0.44031071835692515`, 0.9410170631920465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 270}], {
             RGBColor[
             0.27306394266259, 0.4020687514269927, 0.9389450440967648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 271}], {
             RGBColor[
             0.2779619784734704, 0.40721689761763513`, 0.9392239799901998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 273}], {
             RGBColor[
             0.2861094453581625, 0.4157804018926833, 0.9396879661761859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 274}], {
             RGBColor[
             0.3981676494624695, 0.5190303850989934, 0.9466648547482157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 277}], {
             RGBColor[
             0.6631499633187324, 0.7252798242769541, 0.7115734484509257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 282}], {
             RGBColor[
             0.38696044305919663`, 0.509587419405664, 0.9458777551494157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 289}], {
             RGBColor[
             0.2883666647778183, 0.41815288261871875`, 0.9398165114828785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 67}], {
             RGBColor[
             0.17956042552731538`, 0.30605977039070653`, 0.9335370726467116]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 173}], {
             RGBColor[
             0.1907403974209291, 0.31781062970205387`, 0.9341737555067666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 186}], {
             RGBColor[
             0.18665492193544975`, 0.31351653593270823`, 0.9339410937217879]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.19128445788964016`, 0.31838247175009526`, 0.9342047389455943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 249}], {
             RGBColor[
             0.19382527220510481`, 0.3210530286925808, 0.9343494345620621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 46}], {
             RGBColor[
             0.23154240030757095`, 0.3606961217323153, 0.9364973692100068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 60}], {
             RGBColor[
             0.27282174145117777`, 0.4040833265356404, 0.9388481666208225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.23002654529780098`, 0.3591028620062883, 0.9364110435097069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 77}], {
             RGBColor[
             0.3360793820211845, 0.46085975760775527`, 0.942806176129412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 82}], {
             RGBColor[
             0.43590786027701234`, 0.5429784897554615, 0.9503684349274593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 103}], {
             RGBColor[
             0.33985285455084013`, 0.464128149852699, 0.9430466184622509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 127}], {
             RGBColor[
             0.3036056586421837, 0.43273265059365945`, 0.9407369791910881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 135}], {
             RGBColor[
             0.2357262900418861, 0.3650936551170112, 0.9367356355408658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 158}], {
             RGBColor[
             0.22566086224390924`, 0.3545142523163553, 0.9361624243182372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 168}], {
             RGBColor[
             0.3293937457780264, 0.4550689955237798, 0.942380173299874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 186}], {
             RGBColor[
             0.22574603195372214`, 0.35460377108144014`, 0.9361672746072136]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 196}], {
             RGBColor[
             0.23071789586563907`, 0.35982951528724394`, 0.9364504149017838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 212}], {
             RGBColor[
             0.24587235329600743`, 0.3757578108946581, 0.9373134388334325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 214}], {
             RGBColor[
             0.22960322819742474`, 0.35865792889393855`, 0.936386936227082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 225}], {
             RGBColor[
             0.2429863506332136, 0.37272443911292436`, 0.9371490852512447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 255}], {
             RGBColor[
             0.31219697150637127`, 0.44017401398467865`, 0.9412844100497945]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 265}], {
             RGBColor[
             0.24054595553413333`, 0.37015942913380495`, 0.9370101083605932]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 276}], {
             RGBColor[
             0.24987495920564082`, 0.37996480348555506`, 0.9375413813186614]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 286}], {
             RGBColor[
             0.23963340623012278`, 0.3692002819563222, 0.9369581400277256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.22364840280037163`, 0.35239902984389887`, 0.9360478177300946]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 39}], {
             RGBColor[
             0.22425729902189784`, 0.35303901837897317`, 0.9360824934691292]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 76}], {
             RGBColor[
             0.286854066125812, 0.4171520866149722, 0.9397088035477686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 90}], {
             RGBColor[
             0.2312332284112072, 0.3603711624666066, 0.9364797623278878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 126}], {
             RGBColor[
             0.23513936956710785`, 0.3644767644851118, 0.9367022112880983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 151}], {
             RGBColor[
             0.42230921801132515`, 0.5305527441172178, 0.9494240400554605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 153}], {
             RGBColor[
             0.233929772423327, 0.36320540119410966`, 0.9366333265201985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 192}], {
             RGBColor[
             0.28870383608450384`, 0.4187542643810497, 0.9398266692538492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 220}], {
             RGBColor[
             0.2899399087951104, 0.41982488843615623`, 0.9399054307139528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 222}], {
             RGBColor[
             0.23410797445122994`, 0.3633927028240968, 0.9366434748620613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 239}], {
             RGBColor[
             0.2421832343916902, 0.3718803130225725, 0.9371033489693941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 248}], {
             RGBColor[
             0.23437455245828825`, 0.36367289321153695`, 0.9366586560851965]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 285}], {
             RGBColor[
             0.22323502267117318`, 0.3519645411182973, 0.9360242763432778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 40}], {
             RGBColor[
             0.6964483919711273, 0.7627900441024493, 0.9703791250975754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[
             0.7929575364765972, 0.44951011621237846`, 0.44612850273328253`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 66}], {
             RGBColor[
             0.5450024443168381, 0.6387388987189666, 0.9584682781320619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 81}], {
             RGBColor[
             0.7965640174649642, 0.6796969932787943, 0.60028868050202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 86}], {
             RGBColor[
             0.648920103921949, 0.7249224984916083, 0.966146582786049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 94}], {
             RGBColor[
             0.7502759773076164, 0.8048405628721153, 0.9757441557565323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 97}], {
             RGBColor[
             0.5762606506463335, 0.665813185958444, 0.9604600233988309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 120}], {
             RGBColor[
             0.4913767245940681, 0.5895491243083159, 0.9551516880301447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 130}], {
             RGBColor[
             0.8077331614173798, 0.7282311492830874, 0.6094955989444572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 140}], {
             RGBColor[
             0.7794337135277863, 0.345560086850815, 0.43317807460452784`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 162}], {
             RGBColor[
             0.8475057087773203, 0.8795582824939998, 0.8820715972741542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 169}], {
             RGBColor[
             0.654201051554568, 0.729209809683748, 0.9665623183284373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 178}], {
             RGBColor[
             0.4813372368134904, 0.5789969861106385, 0.9545799540531321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 182}], {
             RGBColor[
             0.47900337512465124`, 0.5765439495002909, 0.9544470440825916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 201}], {
             RGBColor[
             0.7981304417837846, 0.4892713331849807, 0.45108208269740613`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 202}], {
             RGBColor[
             0.8122682039505371, 0.5808158857565188, 0.4639498679202687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 294}], {
             RGBColor[
             0.6198562799736641, 0.7013271769000424, 0.963858572100545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 26}], {
             RGBColor[
             0.21453517633612967`, 0.3428204510180499, 0.9355288329647664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 33}], {
             RGBColor[
             0.20024058888485757`, 0.32779593327757145`, 0.9347147773563635]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 35}], {
             RGBColor[
             0.20318410319091706`, 0.3308897534428262, 0.9348824061415544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 129}], {
             RGBColor[
             0.1945312219559263, 0.32179502664049353`, 0.9343896373560123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 165}], {
             RGBColor[
             0.2088844992725249, 0.33688123115058255`, 0.9352070352654217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 175}], {
             RGBColor[
             0.19129167307218187`, 0.3183900553644156, 0.9342051498395663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 183}], {
             RGBColor[
             0.19635753288152386`, 0.32371459521809726`, 0.9344936430614402]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 184}], {
             RGBColor[
             0.19573226525779447`, 0.3230573993013006, 0.9344580349952694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.2043212377981297, 0.33208495401350496`, 0.9349471642751953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 253}], {
             RGBColor[
             0.19591234458530662`, 0.3232466740922047, 0.9344682902465677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 262}], {
             RGBColor[
             0.25190729178629806`, 0.38210091388515394`, 0.9376571196525632]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 36}], {
             RGBColor[
             0.200168643680248, 0.32772031430593734`, 0.9347106801833944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 37}], {
             RGBColor[
             0.22278622542452461`, 0.3514928267566807, 0.9359987180040172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 41}], {
             RGBColor[
             0.20379941702053028`, 0.3315364872908998, 0.9349174473538756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 44}], {
             RGBColor[
             0.26761174198818394`, 0.3979163278083595, 0.93857676425113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 55}], {
             RGBColor[
             0.21057054856025512`, 0.3386533758536862, 0.9353030532780715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 61}], {
             RGBColor[
             0.248131704384919, 0.378132532140237, 0.9374421055355356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 71}], {
             RGBColor[
             0.22116050761720274`, 0.349784094264723, 0.9359061357799242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 108}], {
             RGBColor[
             0.2298448182232575, 0.3589118553287811, 0.9364006944216527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 136}], {
             RGBColor[
             0.3058098324986471, 0.43100159391667037`, 0.9410107128012115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 152}], {
             RGBColor[
             0.20076184690853469`, 0.3283438085101236, 0.9347444622296798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 177}], {
             RGBColor[
             0.2554879446971804, 0.38586440712099823`, 0.9378610325387366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 208}], {
             RGBColor[
             0.20416035452872197`, 0.331915855496769, 0.9349380022110079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 252}], {
             RGBColor[
             0.2284732256377411, 0.3574702245574107, 0.936322584252997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 268}], {
             RGBColor[
             0.21202685048114545`, 0.34018404150741677`, 0.9353859875180606]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 279}], {
             RGBColor[
             0.22783544818024304`, 0.35679988001215385`, 0.9362862637702997]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 280}], {
             RGBColor[
             0.24050854139809294`, 0.3701201045046333, 0.9370079776808949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 50}], {
             RGBColor[
             0.18770061499905671`, 0.31461562564332873`, 0.9340006443947961]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 74}], {
             RGBColor[
             0.19973960321144332`, 0.32726936557048675`, 0.9346862469634045]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[
             0.21635493982133241`, 0.34473313782066695`, 0.9356324658031498]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 123}], {
             RGBColor[
             0.1960904957019222, 0.3234339222112008, 0.934478435689108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 189}], {
             RGBColor[
             0.20470683599275827`, 0.3324902421643972, 0.934969123521938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 206}], {
             RGBColor[
             0.20800021126608947`, 0.33595178838872103`, 0.9351566763716421]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 257}], {
             RGBColor[
             0.1888268034733999, 0.3157993211343368, 0.9340647791623633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 287}], {
             RGBColor[
             0.21828938866019382`, 0.34676636620145074`, 0.9357426298027625]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 300}], {
             RGBColor[
             0.2096118710905434, 0.33764574504935696`, 0.9352484580144076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.19067565939696252`, 0.3177425859342372, 0.934170068772073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 63}], {
             RGBColor[
             0.18571205303560948`, 0.312525520937635, 0.9338873987327916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 70}], {
             RGBColor[
             0.19915563229546623`, 0.32665557511190024`, 0.9346529906836472]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 73}], {
             RGBColor[
             0.1856051226212358, 0.3124131302923484, 0.9338813092038822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 100}], {
             RGBColor[
             0.1846021361595517, 0.3113589279281038, 0.9338241906086748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 119}], {
             RGBColor[
             0.18469650892406414`, 0.31145811968718523`, 0.933829564998002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 122}], {
             RGBColor[
             0.18679089642314464`, 0.31365945374055604`, 0.9339488372677058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 161}], {
             RGBColor[
             0.1950980417525622, 0.32239079018520866`, 0.934421916904896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 244}], {
             RGBColor[
             0.18902260313051494`, 0.31600511898838, 0.9340759296631764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 266}], {
             RGBColor[
             0.1933455924812791, 0.32054885488938883`, 0.9343221175114128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 24}], {
             RGBColor[
             0.956555334204736, 0.8626596651038085, 0.541866983332811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 31}], {
             RGBColor[
             0.7044976010018857, 0.7638813972041334, 0.8870888196503636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 44}], {
             RGBColor[
             0.6527829845870825, 0.7190887957178285, 0.883793610021852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 59}], {
             RGBColor[
             0.9871771704378065, 0.988965444691414, 0.8621710004720957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 72}], {
             RGBColor[
             0.8827258558765204, 0.48135797009659975`, 0.3926067291806665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 83}], {
             RGBColor[
             0.8941506088744137, 0.5691736279970934, 0.4035470855538621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 106}], {
             RGBColor[
             0.9256036309143629, 0.94127542594585, 0.906451627608196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 136}], {
             RGBColor[
             0.6909810750975458, 0.7521740618261392, 0.8862275585719336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 155}], {
             RGBColor[
             0.9578302462805677, 0.8677142666452164, 0.5428928075150579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 194}], {
             RGBColor[
             0.8376760987270953, 0.8722472965038359, 0.8977776532625734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 197}], {
             RGBColor[
             0.9878441835047461, 0.9892412717360475, 0.8511168677784218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 198}], {
             RGBColor[
             0.9769688580402975, 0.9814876170817164, 0.8855196519471269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 210}], {
             RGBColor[
             0.7305128529889463, 0.7859159553283347, 0.8888842381324313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 226}], {
             RGBColor[
             0.9878018957897885, 0.9892237846791677, 0.8518176846523693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 241}], {
             RGBColor[
             0.9877354309295805, 0.9891962997514028, 0.8529191793915591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 290}], {
             RGBColor[
             0.9678787961151241, 0.9075534182585008, 0.5509781065817215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 291}], {
             RGBColor[
             0.9581107393338224, 0.9671957118175754, 0.9095521846286824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.9468027585380377, 0.8226935997742366, 0.2974286527731346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 59}], {
             RGBColor[
             0.9543858496571156, 0.8617625274901577, 0.5778209567329167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 65}], {
             RGBColor[
             0.6506137006766177, 0.6184091477452374, 0.6013947753940398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 72}], {
             RGBColor[
             0.8608649753560598, 0.3965560252957622, 0.20304003335454723`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 87}], {
             RGBColor[
             0.9584560317231505, 0.8616047223377981, 0.3765513268644449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 106}], {
             RGBColor[
             0.892812310133672, 0.8140725087445938, 0.6221015838690171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 109}], {
             RGBColor[
             0.9582875876148832, 0.8633759964057863, 0.5131590613985512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 155}], {
             RGBColor[
             0.9250389254998768, 0.7405113494439601, 0.2585427637758789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 162}], {
             RGBColor[
             0.9575561451976635, 0.8630735261690534, 0.5252809551641785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 194}], {
             RGBColor[
             0.8048847779464043, 0.7450443793025796, 0.6134276095233945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 210}], {
             RGBColor[
             0.6977215322082554, 0.6587130381270785, 0.6045341943932525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 218}], {
             RGBColor[
             0.945476791560533, 0.8552536816107574, 0.5989703095762722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 226}], {
             RGBColor[
             0.9550105750090976, 0.8620208674779115, 0.5674676409131905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 227}], {
             RGBColor[
             0.9382342504393061, 0.7928264157474236, 0.2691600319562284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 241}], {
             RGBColor[
             0.9549441101488896, 0.8619933825501465, 0.5685691356523801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 290}], {
             RGBColor[
             0.9350874753344331, 0.7803505010572445, 0.2666280628425426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 291}], {
             RGBColor[
             0.9253194185531315, 0.839992794616319, 0.6252021408895034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 299}], {
             RGBColor[
             0.8537172703307078, 0.34161563232659264`, 0.19619538295009195`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 28}], {
             RGBColor[
             0.18729283765525817`, 0.3141870258004196, 0.9339774220783192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 58}], {
             RGBColor[
             0.19112827338567, 0.31821831193375316`, 0.9341958444691476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 79}], {
             RGBColor[
             0.18712823581077753`, 0.3140140188255107, 0.9339680482467827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 113}], {
             RGBColor[
             0.22937411863723062`, 0.3584171202197894, 0.9363738887765662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 134}], {
             RGBColor[
             0.21795734402989536`, 0.34641736624216146`, 0.935723720352283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 144}], {
             RGBColor[
             0.19437777007737006`, 0.3216337389867199, 0.9343808984985402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 160}], {
             RGBColor[
             0.19344001775085345`, 0.32064810183461934`, 0.9343274948908254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 176}], {
             RGBColor[
             0.19265413404658233`, 0.31982208823352565`, 0.9342827399764779]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.1930001178726018, 0.32018573917131365`, 0.9343024432435325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 221}], {
             RGBColor[
             0.1886556188584439, 0.3156193952502866, 0.9340550304517865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 230}], {
             RGBColor[
             0.19160057419890764`, 0.31871473003406703`, 0.934222741301755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 232}], {
             RGBColor[
             0.1895116930698092, 0.31651918352467145`, 0.9341037826116756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 245}], {
             RGBColor[
             0.2081790637788683, 0.33613977371955583`, 0.9351668617576563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 288}], {
             RGBColor[
             0.19999048340527747`, 0.32753305656092946`, 0.9347005342192993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 297}], {
             RGBColor[
             0.19155439006973912`, 0.318666187586068, 0.9342201111839221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 35}], {
             RGBColor[
             0.21774452951257628`, 0.3461936846912394, 0.9357116008803525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 54}], {
             RGBColor[
             0.23656624471631046`, 0.3659765007360335, 0.9367834697169728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 75}], {
             RGBColor[
             0.28101248706842963`, 0.4104564015750206, 0.9393964853748475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 102}], {
             RGBColor[
             0.21064547425155244`, 0.3387321275058029, 0.9353073201853483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 129}], {
             RGBColor[
             0.20909164827758553`, 0.33709895788890676`, 0.9352188320948104]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 165}], {
             RGBColor[
             0.2234449255941841, 0.3521851623989958, 0.9360362300042198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 175}], {
             RGBColor[
             0.20585209939384108`, 0.33369398661282884`, 0.9350343445783642]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 183}], {
             RGBColor[
             0.21091795920318307`, 0.3390185264665105, 0.9353228378002383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 224}], {
             RGBColor[
             0.21888166411978893`, 0.3473888852619182, 0.9357763590139934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 253}], {
             RGBColor[
             0.21047277090696587`, 0.3385506053406179, 0.9352974849853658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 262}], {
             RGBColor[
             0.26646771810795733`, 0.39740484513356716`, 0.9384863143913613]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 42}], {
             RGBColor[
             0.8816836574994876, 0.49667817991020385`, 0.23487588344630034`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 72}], {
             RGBColor[
             0.8762241387653882, 0.45471392654355186`, 0.22964784214088227`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 87}], {
             RGBColor[
             0.9814947768371431, 0.9488415742094825, 0.4164630400439475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 109}], {
             RGBColor[
             0.9813263327288758, 0.9506128482774708, 0.5530707745780536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 140}], {
             RGBColor[
             0.8681598345506768, 0.3927281505486404, 0.22192545531754573`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 151}], {
             RGBColor[
             0.7838347809145911, 0.7971566134890326, 0.6494113635450639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 154}], {
             RGBColor[
             0.7335695588322665, 0.7563490417801518, 0.6454543011351679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 155}], {
             RGBColor[
             0.9480776706138694, 0.8277482013156446, 0.2984544769553814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 162}], {
             RGBColor[
             0.9805948903116561, 0.9503103780407378, 0.565192668343681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 181}], {
             RGBColor[
             0.9780677338465346, 0.9376794577026863, 0.3692977168650637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 202}], {
             RGBColor[
             0.9009943249734276, 0.6279839494543441, 0.2526972486332866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 203}], {
             RGBColor[
             0.9534832977574548, 0.9312795143111227, 0.6643276822065549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 216}], {
             RGBColor[
             0.9009229797863709, 0.6276599876230118, 0.25263771646037597`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 227}], {
             RGBColor[
             0.9612729955532987, 0.8800632676191081, 0.309071745135731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 299}], {
             RGBColor[
             0.8690764337400362, 0.3997735335743823, 0.222803191736427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 79}], {
             RGBColor[
             0.1833054434406642, 0.3099960216654862, 0.9337503458766192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 144}], {
             RGBColor[
             0.19055497770725674`, 0.3176157418266954, 0.9341631961283768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 160}], {
             RGBColor[
             0.18961722538074013`, 0.31663010467459485`, 0.9341097925206621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 176}], {
             RGBColor[
             0.18883134167646898`, 0.3158040910735011, 0.9340650376063144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 221}], {
             RGBColor[
             0.18483282648833058`, 0.31160139809026205`, 0.9338373280816231]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 230}], {
             RGBColor[
             0.1877777818287943, 0.3146967328740425, 0.9340050389315915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 232}], {
             RGBColor[
             0.18568890069969585`, 0.3125011863646469, 0.9338860802415121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 240}], {
             RGBColor[
             0.18200025991928498`, 0.3086241910311017, 0.9336760176059227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 245}], {
             RGBColor[
             0.204356271408755, 0.33212177655953135`, 0.9349491593874928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 288}], {
             RGBColor[
             0.19616769103516415`, 0.32351505940090497`, 0.9344828318491358]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 297}], {
             RGBColor[
             0.18773159769962583`, 0.31464819042604353`, 0.9340024088137586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 43}], {
             RGBColor[
             0.21042089134742065`, 0.3384960766341818, 0.9352945305211986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 78}], {
             RGBColor[
             0.1946932984138494, 0.3219653792740117, 0.9343988673705204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 99}], {
             RGBColor[
             0.19546469586089602`, 0.32277616690028066`, 0.9344427973139495]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 131}], {
             RGBColor[
             0.21233150972289871`, 0.34050425768701104`, 0.9354033374111754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 170}], {
             RGBColor[
             0.19641582947302122`, 0.3237758686319784, 0.934496962966084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 178}], {
             RGBColor[
             0.22713326298795516`, 0.3560618388539467, 0.9362462753623888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 182}], {
             RGBColor[
             0.224799401299116, 0.35360880224359903`, 0.9361133653918483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 190}], {
             RGBColor[
             0.199834842245044, 0.32736946783330456`, 0.9346916706854744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 199}], {
             RGBColor[
             0.196824977685108, 0.32420590934437654`, 0.9345202633514818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 209}], {
             RGBColor[
             0.1878554243304431, 0.3147783400660943, 0.9340094605571987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 229}], {
             RGBColor[
             0.20648377022612274`, 0.3343579127078008, 0.9350703172977894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 259}], {
             RGBColor[
             0.19020824390880345`, 0.3172513026203284, 0.9341434501515016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 261}], {
             RGBColor[
             0.21999581851421782`, 0.3485599321719316, 0.9358398084585123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 284}], {
             RGBColor[
             0.21810645410068208`, 0.3465740903806829, 0.9357322119502256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 74}], {
             RGBColor[
             0.22759891531018372`, 0.3565512689686714, 0.9362727935732689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 104}], {
             RGBColor[
             0.2921921290764705, 0.4220073511871032, 0.9400404564262714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 123}], {
             RGBColor[
             0.2239498078006626, 0.3527158256093854, 0.9360649822989724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 189}], {
             RGBColor[
             0.23256614809149867`, 0.36177214556258186`, 0.9365556701318023]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 236}], {
             RGBColor[
             0.2403636886171835, 0.3699678550477007, 0.9369997285293126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 260}], {
             RGBColor[
             0.25373200019445147`, 0.38401879811531836`, 0.9377610340969933]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 267}], {
             RGBColor[
             0.22275125819820335`, 0.35145607398476686`, 0.9359967266722076]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 287}], {
             RGBColor[
             0.24614870075893425`, 0.37604826959963533`, 0.9373291764126268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 300}], {
             RGBColor[
             0.23747118318928384`, 0.36692764844754155`, 0.936835004624272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 37}], {
             RGBColor[
             0.32310841403988205`, 0.4466841095652183, 0.9420873563531128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 44}], {
             RGBColor[
             0.36793393060354135`, 0.4931076106168971, 0.9446654026002257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 59}], {
             RGBColor[
             0.7023281164542653, 0.7629842595904825, 0.9230427930504692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 61}], {
             RGBColor[
             0.3484538930002764, 0.47332381494877457`, 0.9435307438846312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 65}], {
             RGBColor[
             0.3985559674737674, 0.5196308798455622, 0.9466166117115924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 71}], {
             RGBColor[
             0.32148269623256015`, 0.4449753770732606, 0.9419947741290198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 136}], {
             RGBColor[
             0.4061320211140046, 0.526192876725208, 0.9470993511503072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 177}], {
             RGBColor[
             0.3558101333125378, 0.4810556899295358, 0.9439496708878323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 194}], {
             RGBColor[
             0.552827044743554, 0.6462661114029045, 0.958649445840947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 210}], {
             RGBColor[
             0.4456637990054052, 0.5599347702274033, 0.949756030710805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 226}], {
             RGBColor[
             0.7029528418062473, 0.7632425995782364, 0.912689477230743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 241}], {
             RGBColor[
             0.7028863769460394, 0.7632151146504713, 0.9137909719699326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 279}], {
             RGBColor[
             0.32815763679560045`, 0.4519911628206914, 0.9423749021193952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 280}], {
             RGBColor[
             0.3408307300134504, 0.46531138731317084`, 0.9430966160299905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 290}], {
             RGBColor[
             0.683029742131583, 0.6815722331575694, 0.6118498991600951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 291}], {
             RGBColor[
             0.6732616853502813, 0.7412145267166439, 0.970423977207056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 80}], {
             RGBColor[
             0.9832422855582464, 0.9646748589231064, 0.6130382528147665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 92}], {
             RGBColor[
             0.883595180526095, 0.49208976177353947`, 0.4032005441361298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 107}], {
             RGBColor[
             0.6980757286113448, 0.7586971466019095, 0.9005750351374335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 125}], {
             RGBColor[
             0.8860217022210372, 0.5107410708294523, 0.40552418405157087`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 128}], {
             RGBColor[
             0.8925188906026889, 0.5606813078169296, 0.41174589898336517`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 142}], {
             RGBColor[
             0.8825157823171381, 0.4837930341441863, 0.4021669111922269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 145}], {
             RGBColor[
             0.9262900127477325, 0.9421433350511439, 0.920438952214905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 149}], {
             RGBColor[
             0.9415899849052779, 0.803780404688222, 0.5442097809326024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 150}], {
             RGBColor[
             0.9475427884309859, 0.8298940012964792, 0.5491295264859543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 156}], {
             RGBColor[
             0.691083843191671, 0.7526411268737674, 0.9001295183811735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 167}], {
             RGBColor[
             0.947679092916505, 0.830434403160785, 0.5492392002744804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 179}], {
             RGBColor[
             0.7552164634617963, 0.8063041539020928, 0.9047369408488604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 205}], {
             RGBColor[
             0.6800179376878698, 0.7430563957149572, 0.8994244086676673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 237}], {
             RGBColor[
             0.879275163275352, 0.4588842161406994, 0.3990636907380568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 256}], {
             RGBColor[
             0.8745107904220526, 0.4222631586287432, 0.39450132191314774`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 269}], {
             RGBColor[
             0.980420530285405, 0.9551564158081671, 0.6020762664235486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 277}], {
             RGBColor[
             0.9903436750031767, 0.9883158760637997, 0.6672952315344995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 282}], {
             RGBColor[
             0.7141541547436409, 0.7726234711925095, 0.9015995382329896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 293}], {
             RGBColor[
             0.9437174645743351, 0.8134407929799102, 0.5459850021177625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 98}], {
             RGBColor[
             0.18977923539730202`, 0.3168003874740297, 0.9341190187514328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 126}], {
             RGBColor[
             0.2119973945219809, 0.3401530814267192, 0.9353843100447624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 153}], {
             RGBColor[
             0.21078779737820008`, 0.338881718135717, 0.9353154252768627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 157}], {
             RGBColor[
             0.19152225944429985`, 0.31863241626153205`, 0.9342182813923363]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 171}], {
             RGBColor[
             0.189827260881899, 0.31685086530333273`, 0.9341217537317332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 184}], {
             RGBColor[
             0.1959981041281816, 0.3233368128092353, 0.9344731741256647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 222}], {
             RGBColor[
             0.210965999406103, 0.33906901976570414`, 0.9353255736187255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 248}], {
             RGBColor[
             0.21123257741316134`, 0.3393492101531443, 0.9353407548418606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 275}], {
             RGBColor[
             0.19034059746125545`, 0.31739041459565537`, 0.9341509874905143]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 285}], {
             RGBColor[
             0.20009304762604624`, 0.3276408580599046, 0.934706375099942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 38}], {
             RGBColor[
             0.18490621443215238`, 0.31167853347228314`, 0.9338415074164561]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 52}], {
             RGBColor[
             0.1912130018306219, 0.3183073669014913, 0.934200669628743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 53}], {
             RGBColor[
             0.1997851700209307, 0.32731725917636056`, 0.9346888419257947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 57}], {
             RGBColor[
             0.18168430472921848`, 0.3082921020936258, 0.9336580244252622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 84}], {
             RGBColor[
             0.1855804331499768, 0.3123871800926523, 0.9338799031750189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 124}], {
             RGBColor[
             0.1848087064384265, 0.3115760463885134, 0.9338359544804635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 147}], {
             RGBColor[
             0.19854534996450335`, 0.32601412968792354`, 0.9346182360077306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 217}], {
             RGBColor[
             0.1918655955426979, 0.3189932842697143, 0.9342378338752199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 223}], {
             RGBColor[
             0.1825916590093845, 0.3092457889716643, 0.9337096969092074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 247}], {
             RGBColor[
             0.1907246807083084, 0.31779411044059236`, 0.9341728604632337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 270}], {
             RGBColor[
             0.19826604624820576`, 0.32572056377321634`, 0.9346023300742803]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 295}], {
             RGBColor[
             0.19030787854135572`, 0.3173560249363414, 0.9341491241964293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 102}], {
             RGBColor[
             0.19929440110633984`, 0.32680142993057915`, 0.9346608933621363]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 129}], {
             RGBColor[
             0.19774057513237292`, 0.32516826031368307`, 0.9345724052715985]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 165}], {
             RGBColor[
             0.2120938524489715, 0.3402544648237721, 0.9353898031810077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 175}], {
             RGBColor[
             0.19450102624862847`, 0.3217632890376051, 0.9343879177551523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 183}], {
             RGBColor[
             0.19956688605797046`, 0.32708782889128674`, 0.9346764109770263]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 224}], {
             RGBColor[
             0.20753059097457632`, 0.33545818768669444`, 0.9351299321907813]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 253}], {
             RGBColor[
             0.19912169776175326`, 0.3266199077653942, 0.9346510581621539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 262}], {
             RGBColor[
             0.25511664496274467`, 0.3854741475583434, 0.9378398875681493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 41}], {
             RGBColor[
             0.18496389091314852`, 0.31173915511071026`, 0.9338447920067241]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 55}], {
             RGBColor[
             0.19173502245287335`, 0.3188560436734967, 0.9342303979309199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 152}], {
             RGBColor[
             0.18192632080115292`, 0.3085464763299341, 0.9336718068825283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 208}], {
             RGBColor[
             0.1853248284213402, 0.31211852331657947`, 0.9338653468638564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 242}], {
             RGBColor[
             0.18110760662426995`, 0.30768595582055314`, 0.9336251823213337]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 250}], {
             RGBColor[
             0.18199349180428678`, 0.3086170773131154, 0.9336756321717861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 268}], {
             RGBColor[
             0.19319132437376368`, 0.32038670932722724`, 0.934313332170909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 41}], {
             RGBColor[
             0.20758147265742513`, 0.3355116675614536, 0.9351328298273469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 44}], {
             RGBColor[
             0.27139379762507876`, 0.4018915080789134, 0.9387921467246012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 55}], {
             RGBColor[
             0.21435260419714997`, 0.34262855612424004`, 0.9355184357515427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 61}], {
             RGBColor[
             0.25191376002181387`, 0.38210771241079083`, 0.937657488009007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 71}], {
             RGBColor[
             0.22494256325409756`, 0.3537592745352769, 0.9361215182533955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 108}], {
             RGBColor[
             0.23362687386015235`, 0.362887035599335, 0.936616076895124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 136}], {
             RGBColor[
             0.309591888135542, 0.4349767741872242, 0.9412260952746828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 152}], {
             RGBColor[
             0.20454390254542953`, 0.33231898878067745`, 0.9349598447031511]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 161}], {
             RGBColor[
             0.21411146518921928`, 0.3423751037378088, 0.9355047032417743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 177}], {
             RGBColor[
             0.2592700003340752, 0.38983958739155206`, 0.9380764150122078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 208}], {
             RGBColor[
             0.20794241016561682`, 0.3358910357673228, 0.9351533846844792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 252}], {
             RGBColor[
             0.23225528127463596`, 0.3614454048279645, 0.9365379667264683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 268}], {
             RGBColor[
             0.21580890611804032`, 0.3441592217779706, 0.9356013699915318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 279}], {
             RGBColor[
             0.23161750381713786`, 0.36077506028270767`, 0.936501646243771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 280}], {
             RGBColor[
             0.2442905970349878, 0.3740952847751871, 0.9372233601543662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 52}], {
             RGBColor[
             0.19242626978916738`, 0.3195825884515542, 0.934269763444113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 53}], {
             RGBColor[
             0.2009984379794762, 0.32859248072642344`, 0.9347579357411648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 57}], {
             RGBColor[
             0.18289757268776397`, 0.30956732364368866`, 0.9337271182406324]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 88}], {
             RGBColor[
             0.20448897001762012`, 0.33226125121102634`, 0.9349567163769577]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 124}], {
             RGBColor[
             0.186021974396972, 0.31285126793857626`, 0.9339050482958335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 147}], {
             RGBColor[
             0.1997586179230488, 0.3272893512379864, 0.9346873298231007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 247}], {
             RGBColor[
             0.19193794866685385`, 0.31906933199065524`, 0.9342419542786038]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 289}], {
             RGBColor[
             0.21478203632197956`, 0.34307991651500525`, 0.935542891275764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 64}], {
             RGBColor[
             0.2185143800083959, 0.3470028463736865, 0.9357554427271977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 69}], {
             RGBColor[
             0.20464654155210055`, 0.3324268688843776, 0.9349656898427401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 76}], {
             RGBColor[
             0.26432098730221126`, 0.39346839209165385`, 0.9384255780434674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 85}], {
             RGBColor[
             0.21693635514660192`, 0.345344242191386, 0.9356655765457971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 90}], {
             RGBColor[
             0.20870014958760652`, 0.3366874679432882, 0.9351965368235865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 118}], {
             RGBColor[
             0.19522260799965463`, 0.322521717208859, 0.9344290107683887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 126}], {
             RGBColor[
             0.21260629074350712`, 0.3407930699617935, 0.9354189857837971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 153}], {
             RGBColor[
             0.2113966935997263, 0.3395217066707913, 0.9353501010158973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 166}], {
             RGBColor[
             0.19390930592620187`, 0.3211413534614994, 0.9343542201581618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 195}], {
             RGBColor[
             0.1927241486561343, 0.3198956780273474, 0.9342867272049146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 234}], {
             RGBColor[
             0.19793969225016772`, 0.3253775450292399, 0.9345837446968894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 239}], {
             RGBColor[
             0.2196501555680895, 0.3481966184992542, 0.9358201234650929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 248}], {
             RGBColor[
             0.21184147363468755`, 0.3399891986882186, 0.9353754305808952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 263}], {
             RGBColor[
             0.2058067463664483, 0.333646317705491, 0.935031761790548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 285}], {
             RGBColor[
             0.20070194384757245`, 0.3282808465949789, 0.9347410508389766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 42}], {
             RGBColor[
             0.7881477040684427, 0.44575263857904807`, 0.445649103589277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 66}], {
             RGBColor[
             0.5377876957046065, 0.6331026822689709, 0.9577491794160538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 81}], {
             RGBColor[
             0.7893492688527326, 0.6740607768287987, 0.5995695817860118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 86}], {
             RGBColor[
             0.6417053553097174, 0.7192862820416126, 0.9654274840700409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 94}], {
             RGBColor[
             0.7430612286953848, 0.7992043464221197, 0.9750250570405241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 97}], {
             RGBColor[
             0.5690459020341019, 0.6601769695084484, 0.9597409246828227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 120}], {
             RGBColor[
             0.4841619759818365, 0.5839129078583203, 0.9544325893141365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 130}], {
             RGBColor[
             0.8005184128051482, 0.7225949328330918, 0.608776500228449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 140}], {
             RGBColor[
             0.7746238811196319, 0.3418026092174846, 0.43269867546052243`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 162}], {
             RGBColor[
             0.8402909601650888, 0.8739220660440041, 0.881352498558146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 169}], {
             RGBColor[
             0.6469863029423364, 0.7235735932337524, 0.9658432196124291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 178}], {
             RGBColor[
             0.4741224882012588, 0.573360769660643, 0.953860855337124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 182}], {
             RGBColor[
             0.47178862651241965`, 0.5709077330502953, 0.9537279453665835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 201}], {
             RGBColor[
             0.7933206093756301, 0.4855138555516503, 0.4506026835534007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 202}], {
             RGBColor[
             0.8074583715423828, 0.5770584081231883, 0.4634704687762633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 55}], {
             RGBColor[
             0.19536579579315563`, 0.32267221665845913`, 0.9344371651014012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 108}], {
             RGBColor[
             0.21464006545615802`, 0.34293069613355404`, 0.9355348062449824]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 152}], {
             RGBColor[
             0.1855570941414352, 0.31236264931489655`, 0.9338785740530094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 208}], {
             RGBColor[
             0.1889556017616225, 0.3159346963015419, 0.9340721140343375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 219}], {
             RGBColor[
             0.18646440411145038`, 0.3133162896201571, 0.933930244013557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 242}], {
             RGBColor[
             0.18473837996455222`, 0.31150212880551553`, 0.933831949491815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.18562426514456906`, 0.3124332502980778, 0.9338823993422674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 252}], {
             RGBColor[
             0.21326847287064163`, 0.3414890653621836, 0.9354566960763266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 268}], {
             RGBColor[
             0.19682209771404596`, 0.32420288231218963`, 0.9345200993413902]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 80}], {
             RGBColor[
             0.8846726257638872, 0.5067606717091464, 0.24648746073419803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 81}], {
             RGBColor[
             0.8548914543976673, 0.39035727136327797`, 0.1989221405255734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 82}], {
             RGBColor[
             0.7628830394364272, 0.4257203521722454, 0.4433328823923026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 87}], {
             RGBColor[
             0.8894525062895627, 0.5226189282859114, 0.2876243328405072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 130}], {
             RGBColor[
             0.8623375503659444, 0.42271337536614007`, 0.20506008615386487`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 140}], {
             RGBColor[
             0.8308428229488108, 0.23807702936156347`, 0.1771684281287546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 145}], {
             RGBColor[
             0.8467044438902113, 0.49173965579450474`, 0.4514212603342903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 162}], {
             RGBColor[
             0.8888525819392381, 0.5235981308400817, 0.3867774183736629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 167}], {
             RGBColor[
             0.8609638306693929, 0.4172670345342654, 0.20395475904067392`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 181}], {
             RGBColor[
             0.8871678109624904, 0.5151775172813806, 0.25618078405458466`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 201}], {
             RGBColor[
             0.84019118707681, 0.30993265252864627`, 0.18612043217519372`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 202}], {
             RGBColor[
             0.8472600681601863, 0.3557049288144153, 0.19255432478662504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 203}], {
             RGBColor[
             0.8707781869031039, 0.5109108883536715, 0.45286742761557874`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 216}], {
             RGBColor[
             0.847224395566658, 0.3555429478987492, 0.19252455870016974`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 237}], {
             RGBColor[
             0.8334280441412762, 0.2579481722980025, 0.1796440388622492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 269}], {
             RGBColor[
             0.8827914555819929, 0.5004150429658535, 0.23917946980671936`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 293}], {
             RGBColor[
             0.8583227451079464, 0.4059379610803489, 0.20178529360286196`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 299}], {
             RGBColor[
             0.8313011225434905, 0.2415997208744344, 0.17760729633819525`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 66}], {
             RGBColor[
             0.3059641689064351, 0.4317438620573953, 0.9409982635304203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 78}], {
             RGBColor[
             0.20985899682898168`, 0.3379054898691324, 0.9352625314596219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 97}], {
             RGBColor[
             0.33722237523593046`, 0.45881814929687276`, 0.9429900087971892]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 99}], {
             RGBColor[
             0.21063039427602828`, 0.33871627749540134`, 0.9353064614030511]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 178}], {
             RGBColor[
             0.24229896140308743`, 0.37200194944906734`, 0.9371099394514903]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 182}], {
             RGBColor[
             0.23996509971424826`, 0.36954891283871966`, 0.9369770294809499]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 199}], {
             RGBColor[
             0.21199067610024028`, 0.34014601993949717`, 0.9353839274405833]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 215}], {
             RGBColor[
             0.22516415254335911`, 0.35399217892786317`, 0.9361341374356069]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 229}], {
             RGBColor[
             0.221649468641255, 0.3502980233029215, 0.935933981386891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 233}], {
             RGBColor[
             0.2154911007768475, 0.3438251882143545, 0.9355832714475019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 259}], {
             RGBColor[
             0.20537394232393572`, 0.33319141321544904`, 0.9350071142406031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 261}], {
             RGBColor[
             0.23516151692935008`, 0.3645000427670523, 0.9367034725476139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 284}], {
             RGBColor[
             0.23327215251581435`, 0.3625142009758035, 0.9365958760393271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 59}], {
             RGBColor[
             0.650613500039462, 0.7181916581041776, 0.9197475834219577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 61}], {
             RGBColor[
             0.29673927658547317`, 0.4285312134624696, 0.9402355342561197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 71}], {
             RGBColor[
             0.26976807981775686`, 0.40018277558695564`, 0.9386995645005083]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 108}], {
             RGBColor[
             0.27845239042381165`, 0.4093105366510138, 0.9391941231422369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 136}], {
             RGBColor[
             0.3544174046992013, 0.48140027523890294`, 0.9438041415217957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 177}], {
             RGBColor[
             0.3040955168977345, 0.4362630884432308, 0.9406544612593207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 194}], {
             RGBColor[
             0.5011124283287507, 0.6014735099165995, 0.9553542362124354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 204}], {
             RGBColor[
             0.39991382818369614`, 0.5199845367377941, 0.9469303798325985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 226}], {
             RGBColor[
             0.6512382253914439, 0.7184499980919314, 0.9093942676022314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 252}], {
             RGBColor[
             0.27708079783829526`, 0.4078689058796433, 0.9391160129735812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 268}], {
             RGBColor[
             0.2606344226816996, 0.39058272282964934`, 0.9381794162386446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 279}], {
             RGBColor[
             0.27644302038079716`, 0.4071985613343865, 0.9390796924908837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 280}], {
             RGBColor[
             0.2891161135986471, 0.42051878582686586`, 0.939801406401479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 283}], {
             RGBColor[
             0.3110200455084933, 0.44354120705361005`, 0.9410488029197814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 89}], {
             RGBColor[
             0.34033954683031736`, 0.4683920819989782, 0.9429369415722573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 94}], {
             RGBColor[
             0.5484117816822776, 0.636917841037437, 0.9603911500045271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 96}], {
             RGBColor[
             0.2504426073839444, 0.3805614377119254, 0.9375737080426556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 120}], {
             RGBColor[
             0.2895125289687292, 0.4216264024736376, 0.9397986822781397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 131}], {
             RGBColor[
             0.2646712879230951, 0.39551668310902466`, 0.9383840103499137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 132}], {
             RGBColor[
             0.24841553022607393`, 0.3784308510948885, 0.9374582689973068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 141}], {
             RGBColor[
             0.2968912603514489, 0.4293819169954668, 0.9402188901145307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 146}], {
             RGBColor[
             0.24998188699294738`, 0.3800771913696276, 0.937547470697963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 188}], {
             RGBColor[
             0.32789958178650086`, 0.45761720952884744`, 0.9421442779998944]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 236}], {
             RGBColor[
             0.26568284234196243`, 0.3965798909395088, 0.9384416168776075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 260}], {
             RGBColor[
             0.2790511539192304, 0.41063083400712647`, 0.9392029224452882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 281}], {
             RGBColor[
             0.6391981620742301, 0.7080190375817033, 0.9308676637061029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 294}], {
             RGBColor[
             0.4179920843483252, 0.5334044550653643, 0.9485055663485399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 60}], {
             RGBColor[
             0.2459880706675731, 0.3758794371890788, 0.9373200287665547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 62}], {
             RGBColor[
             0.20319287451419632`, 0.3308989726597267, 0.9348829056554392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 117}], {
             RGBColor[
             0.1951092767006187, 0.3224025988279529, 0.9344225567185672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 158}], {
             RGBColor[
             0.1988271914603046, 0.32631036296979365`, 0.9346342864639694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 196}], {
             RGBColor[
             0.2038842250820344, 0.33162562594068223`, 0.9349222770475161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 207}], {
             RGBColor[
             0.1949982416588687, 0.3222858939590454, 0.9344162334372013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 212}], {
             RGBColor[
             0.21903868251240277`, 0.34755392154809645`, 0.9357853009791648]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 214}], {
             RGBColor[
             0.20276955741382008`, 0.3304540395473769, 0.9348587983728143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 225}], {
             RGBColor[
             0.21615267984960895`, 0.3445205497663627, 0.935620947396977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 265}], {
             RGBColor[
             0.21371228475052867`, 0.3419555397872433, 0.9354819705063254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 276}], {
             RGBColor[
             0.22304128842203616`, 0.35176091413899346`, 0.9360132434643936]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.19252503662856937`, 0.3196863986619449, 0.9342753880695046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 112}], {
             RGBColor[
             0.18666547155784385`, 0.31352762425472913`, 0.9339416945071765]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 131}], {
             RGBColor[
             0.20675371716772, 0.33464164405904423`, 0.9350856903767627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 133}], {
             RGBColor[
             0.18469446291568115`, 0.3114559692026503, 0.9338294484808514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 146}], {
             RGBColor[
             0.19206431623757236`, 0.3192021523196471, 0.9342491507248121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 170}], {
             RGBColor[
             0.1908380369178425, 0.3179132550040116, 0.9341793159316711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 190}], {
             RGBColor[
             0.1942570496898653, 0.32150685420533776`, 0.9343740236510617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.18784627824446665`, 0.31476872694983776`, 0.9340089397011326]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 70}], {
             RGBColor[
             0.2012898575043234, 0.328898781124103, 0.9347745316519882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 71}], {
             RGBColor[
             0.2080633650262977, 0.3360181669948795, 0.9351602728848583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 73}], {
             RGBColor[
             0.187739347830093, 0.31465633630455114`, 0.9340028501722235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 100}], {
             RGBColor[
             0.18673636136840888`, 0.31360213394030656`, 0.9339457315770161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 119}], {
             RGBColor[
             0.1868307341329213, 0.31370132569938797`, 0.933951105966343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 122}], {
             RGBColor[
             0.1889251216320018, 0.3159026597527588, 0.9340703782360471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 138}], {
             RGBColor[
             0.21204884540564534`, 0.34020715956762493`, 0.9353872400964722]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 161}], {
             RGBColor[
             0.19723226696141938`, 0.3246339961974114, 0.9345434578732372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 244}], {
             RGBColor[
             0.19115682833937214`, 0.31824832500058275`, 0.9341974706315176]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 266}], {
             RGBColor[
             0.19547981769013628`, 0.32279206090159157`, 0.934443658479754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 54}], {
             RGBColor[
             0.22682934694082163`, 0.355742403819019, 0.936228967793108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 102}], {
             RGBColor[
             0.20090857647606358`, 0.32849803058878846`, 0.9347528182614836]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 143}], {
             RGBColor[
             0.2582581828615999, 0.38877610307504745`, 0.9380187935040003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 172}], {
             RGBColor[
             0.20010293929950806`, 0.3276512548358813, 0.9347069384161122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 174}], {
             RGBColor[
             0.22141328802375174`, 0.3500497824992095, 0.9359205312501221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 238}], {
             RGBColor[
             0.19853266531396374`, 0.3260007973159532, 0.9346175136356476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 298}], {
             RGBColor[
             0.23487979924778435`, 0.36420393962179404`, 0.9366874291424127]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 206}], {
             RGBColor[
             0.20212300857950383`, 0.32977447572894675`, 0.9348219783731833]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 219}], {
             RGBColor[
             0.1830787781409705, 0.30975778206409804`, 0.9337374376231229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 83}], {
             RGBColor[
             0.8348006374064919, 0.5233895828676642, 0.45541678825261045`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 101}], {
             RGBColor[
             0.7293123816710212, 0.7884636426315792, 0.9736547004594159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 104}], {
             RGBColor[
             0.5731922784257398, 0.6585842020957557, 0.9621993062038972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 116}], {
             RGBColor[
             0.5493242790295518, 0.6359329023080253, 0.960750884061716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 142}], {
             RGBColor[
             0.8237226416206042, 0.438239252848624, 0.4448084869772376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 149}], {
             RGBColor[
             0.8534002738604769, 0.7354497327448786, 0.6081721446101185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 197}], {
             RGBColor[
             0.8988192263028636, 0.9205652040419037, 0.9289214218265444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 198}], {
             RGBColor[
             0.8879439008384149, 0.9128115493875727, 0.9633242059952494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 204}], {
             RGBColor[
             0.647452541380158, 0.7220822556308867, 0.967158350930859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 226}], {
             RGBColor[
             0.8987769385879059, 0.920547716985024, 0.9296222387004919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 243}], {
             RGBColor[
             0.8993571244293498, 0.920787638740557, 0.9200070578349391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 254}], {
             RGBColor[
             0.5650392887707011, 0.6515224922377361, 0.9616798049124837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 283}], {
             RGBColor[
             0.5585587587049552, 0.6456389259467026, 0.9612767740180419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 53}], {
             RGBColor[
             0.2073052253779457, 0.3352213141556316, 0.9351170979534518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 57}], {
             RGBColor[
             0.18920436008623348`, 0.3161961570728968, 0.9340862804529193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 84}], {
             RGBColor[
             0.1931004885069918, 0.32029123507192336`, 0.9343081592026761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 88}], {
             RGBColor[
             0.21079575741608964`, 0.3388900846402345, 0.9353158785892447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 93}], {
             RGBColor[
             0.21993156031517644`, 0.348492392730534, 0.9358361490491385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 124}], {
             RGBColor[
             0.1923287617954415, 0.3194801013677844, 0.9342642105081206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 137}], {
             RGBColor[
             0.23013360981142927`, 0.35921539359839394`, 0.9364171406753703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 147}], {
             RGBColor[
             0.20606540532151835`, 0.3339181846671946, 0.9350464920353876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 217}], {
             RGBColor[
             0.19938565089971289`, 0.32689733924898534`, 0.9346660899028769]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 247}], {
             RGBColor[
             0.1982447360653234, 0.3256981654198634, 0.9346011164908907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 270}], {
             RGBColor[
             0.20578610160522076`, 0.3336246187524874, 0.9350305861019373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 271}], {
             RGBColor[
             0.21068413741610115`, 0.3387727649431298, 0.9353095219953723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 273}], {
             RGBColor[
             0.2188316043007933, 0.34733626921817795`, 0.9357735081813584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 289}], {
             RGBColor[
             0.22108882372044908`, 0.3497087499442134, 0.9359020534880509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 295}], {
             RGBColor[
             0.19782793389837072`, 0.3252600799156124, 0.9345773802240863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 88}], {
             RGBColor[
             0.21936792560639845`, 0.34789997691510377`, 0.9358040508862964]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 93}], {
             RGBColor[
             0.22850372850548528`, 0.3575022850054033, 0.93632432134619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 107}], {
             RGBColor[
             0.3121763440598402, 0.43622685441542786`, 0.9414269663560839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 124}], {
             RGBColor[
             0.20090092998575032`, 0.32848999364265374`, 0.9347523828051723]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 137}], {
             RGBColor[
             0.2387057780017381, 0.36822528587326325`, 0.936905312972422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 147}], {
             RGBColor[
             0.21463757351182716`, 0.3429280769420639, 0.9355346643324394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 217}], {
             RGBColor[
             0.2079578190900217, 0.3359072315238546, 0.9351542621999286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 247}], {
             RGBColor[
             0.2068169042556322, 0.33470805769473266`, 0.9350892887879424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 251}], {
             RGBColor[
             0.25074234215186236`, 0.3808764779572891, 0.9375907774942707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 270}], {
             RGBColor[
             0.21435826979552958`, 0.3426345110273567, 0.935518758398989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 271}], {
             RGBColor[
             0.21925630560640996`, 0.3477826572179991, 0.935797694292424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 273}], {
             RGBColor[
             0.2274037724911021, 0.35634616149304726`, 0.9362616804784101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 289}], {
             RGBColor[
             0.22966099191075792`, 0.3587186422190827, 0.9363902257851027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 75}], {
             RGBColor[
             0.2884831291269512, 0.41830852004459096`, 0.9398219273882558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 102}], {
             RGBColor[
             0.218116116310074, 0.34658424597537324`, 0.9357327621987566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 111}], {
             RGBColor[
             0.4291203016109882, 0.5357529458181629, 0.9499902123364491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 143}], {
             RGBColor[
             0.2754657226956103, 0.40686231846163223`, 0.9389987374412732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 163}], {
             RGBColor[
             0.4325936369919836, 0.5385727559524309, 0.9502636460208878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 165}], {
             RGBColor[
             0.2309155676527057, 0.3600372808685661, 0.936461672017628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 172}], {
             RGBColor[
             0.21731047913351847`, 0.34573747022246615`, 0.935686882353385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 174}], {
             RGBColor[
             0.23862082785776215`, 0.3681359978857943, 0.936900475187395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 185}], {
             RGBColor[
             0.3867966632124244, 0.5013927095080272, 0.9466583404851183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 235}], {
             RGBColor[
             0.32626536687632174`, 0.4510335953926109, 0.9422293781681247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 238}], {
             RGBColor[
             0.21574020514797415`, 0.344087012702538, 0.9355974575729206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 298}], {
             RGBColor[
             0.25208733908179476`, 0.3822901550083788, 0.9376673730796856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 108}], {
             RGBColor[
             0.22141119699588285`, 0.35004758469634045`, 0.9359204121691784]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 114}], {
             RGBColor[
             0.22063449464495144`, 0.3492312212797382, 0.9358761801193209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 208}], {
             RGBColor[
             0.19572673330134732`, 0.32305158486432833`, 0.9344577199585336]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 219}], {
             RGBColor[
             0.19323553565117518`, 0.3204331781829436, 0.9343158499377529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 242}], {
             RGBColor[
             0.19150951150427703`, 0.318619017368302, 0.9342175554160109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 250}], {
             RGBColor[
             0.1923953966842939, 0.31955013886086425`, 0.9342680052664631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 252}], {
             RGBColor[
             0.22003960441036646`, 0.34860595392497, 0.9358423020005227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 268}], {
             RGBColor[
             0.20359322925377082`, 0.3313197708749761, 0.9349057052655861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 283}], {
             RGBColor[
             0.25397885208056453`, 0.38427825509893676`, 0.9377750919467229]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 57}], {
             RGBColor[
             0.18951617750640207`, 0.3165238969518603, 0.9341040379937053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 84}], {
             RGBColor[
             0.1934123059271604, 0.32061897495088687`, 0.9343259167434621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 110}], {
             RGBColor[
             0.1926369557700678, 0.31980403277574326`, 0.9342817616990433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 148}], {
             RGBColor[
             0.2228269723814797, 0.3515356543919468, 0.936001038482936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 191}], {
             RGBColor[
             0.21336670196225918`, 0.34159231036555776`, 0.9354622900777774]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 217}], {
             RGBColor[
             0.19969746831988144`, 0.32722507912794885`, 0.934683847443663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 223}], {
             RGBColor[
             0.19042353178656807`, 0.3174775838298989, 0.9341557104776503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 246}], {
             RGBColor[
             0.1919032518459413, 0.3190328634319706, 0.934239978345982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 247}], {
             RGBColor[
             0.19855655348549195`, 0.3260259052988269, 0.9346188740316768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 251}], {
             RGBColor[
             0.2424819913817221, 0.3721943255613833, 0.9371203627380049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 270}], {
             RGBColor[
             0.20609791902538932`, 0.3339523586314509, 0.9350483436427234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 271}], {
             RGBColor[
             0.21099595483626973`, 0.3391005048220933, 0.9353272795361584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 278}], {
             RGBColor[
             0.1999933373080916, 0.327536056193735, 0.9347006967448426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 295}], {
             RGBColor[
             0.19813975131853928`, 0.3255878197945759, 0.9345951377648724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.18357179140558838`, 0.31027597026405784`, 0.9337655139991952]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 217}], {
             RGBColor[
             0.18985695379830947`, 0.3168820744411198, 0.9341234446993961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 223}], {
             RGBColor[
             0.1805830172649961, 0.30713457914306985`, 0.9335953077333836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 247}], {
             RGBColor[
             0.18871603896391997`, 0.3156829006119979, 0.9340584712874099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 278}], {
             RGBColor[
             0.19015282278651957`, 0.31719305150690597`, 0.9341402940005757]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 295}], {
             RGBColor[
             0.1882992367969673, 0.3152448151077469, 0.9340347350206055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 134}], {
             RGBColor[
             0.21796998739019388`, 0.34643065521547056`, 0.9357244403729478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 160}], {
             RGBColor[
             0.19345266111115197`, 0.32066139080792844`, 0.9343282149114902]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 164}], {
             RGBColor[
             0.1865510290497441, 0.3134073379226422, 0.9339351771756428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 176}], {
             RGBColor[
             0.19266677740688082`, 0.31983537720683475`, 0.9342834599971428]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 180}], {
             RGBColor[
             0.1930127612329003, 0.32019902814462275`, 0.9343031632641974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 187}], {
             RGBColor[
             0.20794054512620663`, 0.3358890754926524, 0.9351532784732439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 215}], {
             RGBColor[
             0.20794131603506694`, 0.33588988576674306`, 0.935153322375363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 221}], {
             RGBColor[
             0.18866826221874242`, 0.3156326842235957, 0.9340557504724514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 230}], {
             RGBColor[
             0.19161321755920613`, 0.31872801900737613`, 0.9342234613224198]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[
             0.20819170713916685`, 0.33615306269286493`, 0.9351675817783212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 288}], {
             RGBColor[
             0.200003126765576, 0.32754634553423856`, 0.9347012542399642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 296}], {
             RGBColor[
             0.18917402722894824`, 0.3161642753166758, 0.9340845530415703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 297}], {
             RGBColor[
             0.19156703343003767`, 0.3186794765593771, 0.934220831204587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 72}], {
             RGBColor[
             0.8812795328447734, 0.4807598783541659, 0.416576044780737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 83}], {
             RGBColor[
             0.8927042858426667, 0.5685755362546596, 0.4275164011539326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 106}], {
             RGBColor[
             0.9234341463667425, 0.9403782883321993, 0.9424056010083017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 136}], {
             RGBColor[
             0.6888115905499252, 0.7512769242124885, 0.9221815319720392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 155}], {
             RGBColor[
             0.9556607617329471, 0.8668171290315656, 0.5788467809151635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[
             0.8355066141794747, 0.8713501588901851, 0.9337316266626792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 197}], {
             RGBColor[
             0.9856746989571257, 0.9883441341223966, 0.8870708411785275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 198}], {
             RGBColor[
             0.974799373492677, 0.9805904794680657, 0.9214736253472325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 210}], {
             RGBColor[
             0.7283433684413259, 0.785018817714684, 0.9248382115325371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 226}], {
             RGBColor[
             0.9856324112421679, 0.988326647065517, 0.887771658052475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 227}], {
             RGBColor[
             0.9688560866723765, 0.9191321953350291, 0.5894640490955131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 241}], {
             RGBColor[
             0.9855659463819599, 0.9882991621377519, 0.8888731527916648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 290}], {
             RGBColor[
             0.9657093115675036, 0.9066562806448499, 0.5869320799818273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 291}], {
             RGBColor[
             0.955941254786202, 0.9662985742039245, 0.945506158028788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 77}], {
             RGBColor[
             0.3505250523811867, 0.47604307306451876`, 0.9436288356859599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 95}], {
             RGBColor[
             0.28741190007160666`, 0.4194185083151971, 0.9396790545700505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 103}], {
             RGBColor[
             0.35429852491084235`, 0.47931146530946245`, 0.9438692780187988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 127}], {
             RGBColor[
             0.3180513290021859, 0.44791596605042294`, 0.941559638747636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 145}], {
             RGBColor[
             0.5760856373176906, 0.6571907606456139, 0.9633236613969889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 148}], {
             RGBColor[
             0.2667823322730826, 0.39773552456880407`, 0.9385042312026353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 159}], {
             RGBColor[
             0.28925410608148494`, 0.42135478363418655`, 0.9397839654770135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 168}], {
             RGBColor[
             0.3438394161380286, 0.4702523109805432, 0.9432028328564219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 196}], {
             RGBColor[
             0.24516356622564123`, 0.3750128307440074, 0.9372730744583317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 205}], {
             RGBColor[
             0.3298135622578278, 0.45810382130942706`, 0.9423091178497511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 212}], {
             RGBColor[
             0.2603180236560096, 0.39094112635142153`, 0.9381360983899805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 225}], {
             RGBColor[
             0.25743202099321577`, 0.38790775456968785`, 0.9379717448077927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 265}], {
             RGBColor[
             0.2549916258941355, 0.3853427445905684, 0.9378327679171411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 276}], {
             RGBColor[
             0.26432062956564295`, 0.39514811894231855`, 0.9383640408752093]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 282}], {
             RGBColor[
             0.36394977931359895`, 0.4876708967869795, 0.9444842474150733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 71}], {
             RGBColor[
             0.25028804221449197`, 0.3803989799188331, 0.9375649057849139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 108}], {
             RGBColor[
             0.25897235282054676`, 0.38952674098289125`, 0.9380594644266425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 136}], {
             RGBColor[
             0.33493736709593636`, 0.46161647957078045`, 0.9426694828062012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 161}], {
             RGBColor[
             0.23945694414961366`, 0.369014809121365, 0.9369480907732928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 177}], {
             RGBColor[
             0.2846154792944696, 0.4164792927751083, 0.9395198025437264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 194}], {
             RGBColor[
             0.4816323907254858, 0.581689714248477, 0.9542195774968412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 252}], {
             RGBColor[
             0.2576007602350303, 0.3880851102115208, 0.9379813542579867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 268}], {
             RGBColor[
             0.24115438507843467`, 0.37079892716152685`, 0.9370447575230503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 279}], {
             RGBColor[
             0.25696298277753227`, 0.387414765666264, 0.9379450337752894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 280}], {
             RGBColor[
             0.2696360759953822, 0.40073499015874336`, 0.9386667476858847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 117}], {
             RGBColor[
             0.1935934216908487, 0.32080933910192594`, 0.9343362310182673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 135}], {
             RGBColor[
             0.20737676424851148`, 0.33529650604442257`, 0.9351211719862982]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 158}], {
             RGBColor[
             0.1973113364505346, 0.3247171032437667, 0.9345479607636695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 186}], {
             RGBColor[
             0.19739650616034748`, 0.3248066220088515, 0.934552811052646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 196}], {
             RGBColor[
             0.2023683700722644, 0.33003236621465526`, 0.9348359513472162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 207}], {
             RGBColor[
             0.19348238664909873`, 0.3206926342330184, 0.9343299077369014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 212}], {
             RGBColor[
             0.2175228275026328, 0.34596066182206947`, 0.9356989752788649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 214}], {
             RGBColor[
             0.20125370240405008`, 0.3288607798213499, 0.9347724726725144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 225}], {
             RGBColor[
             0.21463682483983898`, 0.34292729004033573`, 0.9355346216966771]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 265}], {
             RGBColor[
             0.2121964297407587, 0.3403622800612163, 0.9353956448060256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 276}], {
             RGBColor[
             0.22152543341226616`, 0.3501676544129665, 0.9359269177640938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 286}], {
             RGBColor[
             0.21128388043674812`, 0.3394031328837336, 0.935343676473158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 71}], {
             RGBColor[
             0.20309975866494467`, 0.3308011019982774, 0.9348776028455769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 73}], {
             RGBColor[
             0.18277574146873998`, 0.309439271307949, 0.933720180132942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 152}], {
             RGBColor[
             0.18270109795627662`, 0.30936081624367795`, 0.9337159292953324]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 161}], {
             RGBColor[
             0.19226866060006637`, 0.3194169312008093, 0.9342607878339557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 208}], {
             RGBColor[
             0.1860996055764639, 0.3129328632303233, 0.9339094692766605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 244}], {
             RGBColor[
             0.18619322197801913`, 0.31303126000398057`, 0.9339148005922362]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 69}], {
             RGBColor[
             0.22143670136219934`, 0.3500743914024093, 0.9359218646051097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 76}], {
             RGBColor[
             0.28111114711231006`, 0.41111591460968555`, 0.939381752805837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 85}], {
             RGBColor[
             0.2337265149567007, 0.3629917647094177, 0.9366217513081667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 90}], {
             RGBColor[
             0.22549030939770529`, 0.3543349904613199, 0.936152711585956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 118}], {
             RGBColor[
             0.2120127678097534, 0.3401692397268907, 0.9353851855307582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 121}], {
             RGBColor[
             0.2303769927354159, 0.3594712044828725, 0.9364310009728385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 173}], {
             RGBColor[
             0.21829574180286104`, 0.34677304375720647`, 0.9357429916048386]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 213}], {
             RGBColor[
             0.21883980227157213`, 0.34734488580524786`, 0.9357739750436664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 234}], {
             RGBColor[
             0.2147298520602665, 0.3430250675472716, 0.9355399194592591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 239}], {
             RGBColor[
             0.23644031537818827`, 0.3658441410172859, 0.9367762982274624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 249}], {
             RGBColor[
             0.22138061658703678`, 0.35001544274773333`, 0.9359186706601341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 258}], {
             RGBColor[
             0.28773302970917036`, 0.41685145648958927`, 0.939803693309408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 263}], {
             RGBColor[
             0.22259690617654707`, 0.3512938402235227, 0.9359879365529176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 286}], {
             RGBColor[
             0.22809764059378232`, 0.35707546086274283`, 0.9363011952403719]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 70}], {
             RGBColor[
             0.2936166091660087, 0.41958665894484415`, 0.940265032379005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 106}], {
             RGBColor[
             0.6196619973862446, 0.6970249085872788, 0.9659794196694249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 115}], {
             RGBColor[
             0.3645960621661024, 0.4902165167425332, 0.9444527165749532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 138}], {
             RGBColor[
             0.30437559706733064`, 0.4308950373883661, 0.9408777408234891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 155}], {
             RGBColor[
             0.6518886127524492, 0.6234637492866453, 0.6024205995762867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 194}], {
             RGBColor[
             0.5317344651989768, 0.6279967791452647, 0.9573054453238024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 200}], {
             RGBColor[
             0.37151685139917806`, 0.49621095652724223`, 0.9448937031450712]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[
             0.424571219460828, 0.5416654379697635, 0.9484120301936603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 211}], {
             RGBColor[
             0.3240980577045407, 0.45162459399430244`, 0.9420009057800123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 231}], {
             RGBColor[
             0.30432205873480145`, 0.4308387652063516, 0.9408746918946544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 241}], {
             RGBColor[
             0.6817937974014621, 0.7449457823928316, 0.912446971452788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 264}], {
             RGBColor[
             0.33683666992223255`, 0.4650136831097602, 0.942726350900722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 291}], {
             RGBColor[
             0.6521691058057041, 0.7229451944590042, 0.9690799766899112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 86}], {
             RGBColor[
             0.49025940765542825`, 0.5952351366581299, 0.9535166371045274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 97}], {
             RGBColor[
             0.4175999543798127, 0.5361258241249656, 0.9478300777173092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 162}], {
             RGBColor[
             0.6888450125107997, 0.7498709206605213, 0.8694416515926326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 169}], {
             RGBColor[
             0.4955403552880472, 0.5995224478502696, 0.9539323726469158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 187}], {
             RGBColor[
             0.305540960778381, 0.4312990434818653, 0.9409741624536079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 193}], {
             RGBColor[
             0.33295274750258996`, 0.46011056933666983`, 0.9425352231554471]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 215}], {
             RGBColor[
             0.3055417316872413, 0.4312998537559559, 0.940974206355727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 228}], {
             RGBColor[
             0.40629940527691566`, 0.5263378564741489, 0.9471100167211559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 118}], {
             RGBColor[
             0.18382399790050605`, 0.31054105528103165`, 0.9337798767859746]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 166}], {
             RGBColor[
             0.1825106958270533, 0.309160691533672, 0.9337050861757479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 173}], {
             RGBColor[
             0.1901069718936137, 0.3171448593113474, 0.934137682860055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 195}], {
             RGBColor[
             0.18132553855698572`, 0.30791501609952, 0.9336375932225005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 213}], {
             RGBColor[
             0.19065103236232478`, 0.3177167013593888, 0.9341686662988828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 234}], {
             RGBColor[
             0.18654108215101917`, 0.31339688310141245`, 0.9339346107144755]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 263}], {
             RGBColor[
             0.19440813626729972`, 0.3216656557776636, 0.934382627808134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 75}], {
             RGBColor[
             0.6048929892039929, 0.6837170469414527, 0.9652757515328931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 83}], {
             RGBColor[
             0.8566539261889098, 0.5407679915618476, 0.4575135965364173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 109}], {
             RGBColor[
             0.9348338843673183, 0.947970458954174, 0.8784588716115629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 111}], {
             RGBColor[
             0.7455301616880299, 0.8011614727150247, 0.9754440364810864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 143}], {
             RGBColor[
             0.5918755827726521, 0.672270845358494, 0.9644525615859105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 163}], {
             RGBColor[
             0.7490034970690254, 0.8039812828492927, 0.9757174701655251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 185}], {
             RGBColor[
             0.7032065232894661, 0.766801236404889, 0.9721121646297556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 218}], {
             RGBColor[
             0.9220230883129681, 0.9398481441591451, 0.964270119789284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 235}], {
             RGBColor[
             0.6426752269533634, 0.7164421222894727, 0.967683202312762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 292}], {
             RGBColor[
             0.8252860920096456, 0.8638987146846454, 0.9830984780135097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 76}], {
             RGBColor[
             0.2672433086560147, 0.39653993712037666`, 0.9385919999213795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 85}], {
             RGBColor[
             0.21985867650040533`, 0.3484157872201088, 0.9358319984237091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 90}], {
             RGBColor[
             0.21162247094140993`, 0.33975901297201105`, 0.9353629587014987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 118}], {
             RGBColor[
             0.19814492935345804`, 0.3255932622375819, 0.9345954326463008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 121}], {
             RGBColor[
             0.21650915427912054`, 0.3448952269935637, 0.9356412480883811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 126}], {
             RGBColor[
             0.21552861209731056`, 0.34386461499051624`, 0.9355854076617092]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 166}], {
             RGBColor[
             0.19683162728000528`, 0.3242128984902222, 0.9345206420360739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 173}], {
             RGBColor[
             0.2044279033465657, 0.3321970662678976, 0.9349532387203812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 195}], {
             RGBColor[
             0.1956464700099377, 0.32296722305607023`, 0.9344531490828267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 213}], {
             RGBColor[
             0.20497196381527677`, 0.33276890831593897`, 0.934984222159209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 234}], {
             RGBColor[
             0.20086201360397116`, 0.32844909005796263`, 0.9347501665748015]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 239}], {
             RGBColor[
             0.22257247692189291`, 0.35126816352797696`, 0.935986545343005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 249}], {
             RGBColor[
             0.20751277813074143`, 0.3354394652584245, 0.9351289177756767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 258}], {
             RGBColor[
             0.273865191252875, 0.4022754790002804, 0.9390139404249507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 263}], {
             RGBColor[
             0.2087290677202517, 0.3367178627342138, 0.9351981836684602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 285}], {
             RGBColor[
             0.2036242652013759, 0.3313523916237017, 0.9349074727168887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 122}], {
             RGBColor[
             0.19740509453050553`, 0.32481564893042175`, 0.9345533001476212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 138}], {
             RGBColor[
             0.22052881830414905`, 0.3491201487452879, 0.9358701620080464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 211}], {
             RGBColor[
             0.24025127894135917`, 0.3698497053512242, 0.9369933269645696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 231}], {
             RGBColor[
             0.2204752799716199, 0.3490638765632734, 0.9358671130792118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 266}], {
             RGBColor[
             0.20395979058864, 0.33170505007925455`, 0.934926580391328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 108}], {
             RGBColor[
             0.23200115605283045`, 0.3611783031073773, 0.936523494671031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 136}], {
             RGBColor[
             0.3079661703282201, 0.43326804169526645`, 0.9411335130505898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 161}], {
             RGBColor[
             0.2124857473818974, 0.34066637124585103`, 0.9354121210176813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 177}], {
             RGBColor[
             0.2576442825267533, 0.3881308548995943, 0.9379838327881149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 208}], {
             RGBColor[
             0.20631669235829492`, 0.33418230327536513`, 0.9350608024603861]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 244}], {
             RGBColor[
             0.20641030875985014`, 0.33428070004902233`, 0.9350661337759618]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 252}], {
             RGBColor[
             0.23062956346731406`, 0.3597366723360068, 0.9364453845023752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 268}], {
             RGBColor[
             0.21418318831071842`, 0.34245048928601285`, 0.9355087877674388]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 279}], {
             RGBColor[
             0.22999178600981598`, 0.35906632779075, 0.9364090640196779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 280}], {
             RGBColor[
             0.2426648792276659, 0.37238655228322937`, 0.9371307779302732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 83}], {
             RGBColor[
             0.8351278328210138, 0.271013492942614, 0.1812717584216026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 87}], {
             RGBColor[
             0.8839929875554634, 0.4806546749192594, 0.28239629153508916`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 106}], {
             RGBColor[
             0.8402305064958111, 0.44896653252378993`, 0.44609646287147053`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 109}], {
             RGBColor[
             0.8838806914832852, 0.4818355242979183, 0.3734681145578266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 155}], {
             RGBColor[
             0.8617149167399476, 0.39992575965670085`, 0.20372391614271176`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 194}], {
             RGBColor[
             0.7816121517042992, 0.4029477795624471, 0.4403138133077221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 210}], {
             RGBColor[
             0.7101699878788666, 0.345393552112113, 0.4343848698876275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 218}], {
             RGBColor[
             0.875340160780385, 0.47642064776789905`, 0.430675613342974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 226}], {
             RGBColor[
             0.8816960164127614, 0.48093210501266836`, 0.40967383423425274`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 227}], {
             RGBColor[
             0.8705118000329004, 0.43480247052567644`, 0.21080209492961144`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 241}], {
             RGBColor[
             0.8816517065059561, 0.48091378172749166`, 0.4104081640603793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 290}], {
             RGBColor[
             0.8684139499629852, 0.42648519406555707`, 0.2091141155204876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 291}], {
             RGBColor[
             0.8619019121087841, 0.4662467231049401, 0.44816350088512813`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 100}], {
             RGBColor[
             0.1816658245926822, 0.30827267829841776`, 0.9336569720088254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 119}], {
             RGBColor[
             0.18176019735719462`, 0.3083718700574992, 0.9336623463981524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 122}], {
             RGBColor[
             0.18385458485627515`, 0.31057320411086997`, 0.9337816186678564]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 161}], {
             RGBColor[
             0.19216173018569271`, 0.31930454055552265`, 0.9342546983050465]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 244}], {
             RGBColor[
             0.18608629156364545`, 0.31291886935869395`, 0.9339087110633268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 123}], {
             RGBColor[
             0.20225228122772315`, 0.32991034947858455`, 0.9348293402592576]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 189}], {
             RGBColor[
             0.21086862151855923`, 0.33896666943178094`, 0.9353200280920875]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 257}], {
             RGBColor[
             0.19498858899920085`, 0.3222757484017205, 0.9344156837325129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 260}], {
             RGBColor[
             0.23203447362151203`, 0.3612133219845175, 0.9365253920572785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 267}], {
             RGBColor[
             0.2010537316252639, 0.328650597853966, 0.9347610846324927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 287}], {
             RGBColor[
             0.2244511741859948, 0.35324279346883447`, 0.936093534372912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 300}], {
             RGBColor[
             0.2157736566163444, 0.3441221723167407, 0.9355993625845572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 111}], {
             RGBColor[
             0.4735665439631073, 0.5802328466571501, 0.952603227994324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 143}], {
             RGBColor[
             0.31991196504772945`, 0.4513422193006194, 0.941611753099148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.47703987934410275`, 0.583052656791418, 0.9528766616787626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 165}], {
             RGBColor[
             0.27536181000482485`, 0.4045171817075533, 0.9390746876755028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 185}], {
             RGBColor[
             0.43124290556454353`, 0.5458726103470143, 0.9492713561429931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 235}], {
             RGBColor[
             0.3707116092284409, 0.495513496231598, 0.9448423938259995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 262}], {
             RGBColor[
             0.318384602518598, 0.4497368644421247, 0.9415247720626443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 292}], {
             RGBColor[
             0.5533224742847231, 0.6429700886267707, 0.9602576695267473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 85}], {
             RGBColor[
             0.2795331222505161, 0.40945731042738504`, 0.9392918866244364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 87}], {
             RGBColor[
             0.6600329022141906, 0.7226670785503484, 0.7188188011286823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 90}], {
             RGBColor[
             0.2712969166915207, 0.40080053617928724`, 0.938822846902226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 126}], {
             RGBColor[
             0.2752030578474213, 0.40490613819779253`, 0.9390452958624365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 151}], {
             RGBColor[
             0.46237290629163863`, 0.5709821178298984, 0.9517671246297987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 153}], {
             RGBColor[
             0.27399346070364045`, 0.40363477490679034`, 0.9389764110945367]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 192}], {
             RGBColor[
             0.32876752436481727`, 0.45918363809373036`, 0.9421697538281874]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 220}], {
             RGBColor[
             0.3300035970754238, 0.4602542621488369, 0.942248515288291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 239}], {
             RGBColor[
             0.28224692267200363`, 0.41230968673525326`, 0.9394464335437323]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 248}], {
             RGBColor[
             0.2744382407386017, 0.40410226692421763`, 0.9390017406595347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 258}], {
             RGBColor[
             0.3335396370029857, 0.4633170022075566, 0.942473828625678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 82}], {
             RGBColor[
             0.5136111712070213, 0.6149382362843397, 0.9551491039925967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 95}], {
             RGBColor[
             0.3506695406416134, 0.476194939387312, 0.94363706407864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 103}], {
             RGBColor[
             0.41755616548084906`, 0.5360878963815774, 0.9478272875273883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 127}], {
             RGBColor[
             0.3813089695721926, 0.5046923971225378, 0.9455176482562255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 145}], {
             RGBColor[
             0.6393432778876973, 0.7139671917177287, 0.9672816709055783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 154}], {
             RGBColor[
             0.455540153481848, 0.5677935680255081, 0.950577540756124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 159}], {
             RGBColor[
             0.3525117466514917, 0.4781312147063014, 0.9437419749856031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 167}], {
             RGBColor[
             0.6607323580564698, 0.6022582598273698, 0.5960819189651536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 168}], {
             RGBColor[
             0.4070970567080353, 0.527028742052658, 0.9471608423650113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 203}], {
             RGBColor[
             0.6754538924070363, 0.7427240405564789, 0.9694509218275109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 205}], {
             RGBColor[
             0.3930712028278346, 0.5148802523815419, 0.9462671273583405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 212}], {
             RGBColor[
             0.32357566422601636`, 0.4477175574235364, 0.9420941078985701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 225}], {
             RGBColor[
             0.32068966156322254`, 0.4446841856418027, 0.9419297543163823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 255}], {
             RGBColor[
             0.38990028243638014`, 0.512133760513557, 0.9460650791149319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 265}], {
             RGBColor[
             0.31824926646414226`, 0.4421191756626833, 0.9417907774257306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 269}], {
             RGBColor[
             0.6934737954253698, 0.7269802724747518, 0.6489189851142219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 276}], {
             RGBColor[
             0.3275782701356497, 0.45192455001443343`, 0.9423220503837988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 282}], {
             RGBColor[
             0.42720741988360567`, 0.5444473278590943, 0.9484422569236628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 293}], {
             RGBColor[
             0.6567707297143, 0.585264649646495, 0.5928277208084357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 99}], {
             RGBColor[
             0.19490280134245708`, 0.32218558013523124`, 0.9344107982523728]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 131}], {
             RGBColor[
             0.21176961520445978`, 0.33991367092196156`, 0.9353713383495988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 170}], {
             RGBColor[
             0.19585393495458225`, 0.32318528186692885`, 0.9344649639045073]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 178}], {
             RGBColor[
             0.2265713684695162, 0.3554712520888972, 0.9362142763008121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 182}], {
             RGBColor[
             0.22423750678067705`, 0.3530182154785495, 0.9360813663302717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 190}], {
             RGBColor[
             0.19927294772660503`, 0.32677888106825503`, 0.9346596716238978]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.19626308316666907`, 0.323615322579327, 0.9344882642899051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 209}], {
             RGBColor[
             0.18729352981200414`, 0.31418775330104487`, 0.933977461495622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 229}], {
             RGBColor[
             0.20592187570768378`, 0.3337673259427514, 0.9350383182362128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 261}], {
             RGBColor[
             0.21943392399577888`, 0.3479693454068822, 0.9358078093969358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 284}], {
             RGBColor[
             0.2175445595822431, 0.34598350361563335`, 0.935700212888649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 144}], {
             RGBColor[
             0.1903903758627761, 0.31744273485178653`, 0.9341538222968402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 160}], {
             RGBColor[
             0.1894526235362595, 0.316457097699686, 0.9341004186891254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 176}], {
             RGBColor[
             0.18866673983198834`, 0.31563108409859225`, 0.9340556637747779]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 221}], {
             RGBColor[
             0.18466822464384994`, 0.3114283911153532, 0.9338279542500865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 232}], {
             RGBColor[
             0.1855242988552152, 0.31232817938973806`, 0.9338767064099756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 240}], {
             RGBColor[
             0.18183565807480434`, 0.3084511840561929, 0.9336666437743861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 245}], {
             RGBColor[
             0.20419166956427437`, 0.3319487695846225, 0.9349397855559562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 288}], {
             RGBColor[
             0.19600308919068352`, 0.3233420524259961, 0.9344734580175993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 297}], {
             RGBColor[
             0.1875669958551452, 0.3144751834511347, 0.9339930349822221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 92}], {
             RGBColor[
             0.8806392624507501, 0.47575847385330106`, 0.24262510747050564`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 125}], {
             RGBColor[
             0.8830657841456923, 0.4944097829092139, 0.2449487473859466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 128}], {
             RGBColor[
             0.889562972527344, 0.5443500198966912, 0.25117046231774093`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 145}], {
             RGBColor[
             0.9218561356347152, 0.9176464031707863, 0.6795757972164687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 149}], {
             RGBColor[
             0.9371561077922606, 0.7792834728078644, 0.30334662593416606`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 150}], {
             RGBColor[
             0.9431089113179686, 0.8053970694161215, 0.30826637148751795`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 156}], {
             RGBColor[
             0.6866499660786538, 0.7281441949934098, 0.6592663633827371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 167}], {
             RGBColor[
             0.9432452158034876, 0.8059374712804274, 0.30837604527604406`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 179}], {
             RGBColor[
             0.7507825863487789, 0.7818072220217351, 0.663873785850424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 201}], {
             RGBColor[
             0.8898455310710746, 0.5465218886817487, 0.2514410406983216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 205}], {
             RGBColor[
             0.6755840605748524, 0.7185594638345996, 0.6585612536692309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 237}], {
             RGBColor[
             0.8763192452000071, 0.442552928220461, 0.2384882540724326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 256}], {
             RGBColor[
             0.8715548723467077, 0.4059318707085048, 0.23392588524752353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 269}], {
             RGBColor[
             0.9759866531723878, 0.9306594839278095, 0.36121311142511225`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 277}], {
             RGBColor[
             0.9859097978901593, 0.963818944183442, 0.4264320765360633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 281}], {
             RGBColor[
             0.9786349916305042, 0.9618175926615335, 0.6467591064594813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 282}], {
             RGBColor[
             0.7097202776306235, 0.7481265393121519, 0.6607363832345532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 293}], {
             RGBColor[
             0.9392835874613179, 0.7889438610995526, 0.30512184711932616`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 86}], {
             RGBColor[
             0.7418209808035544, 0.6361932312179576, 0.5953370394744854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 94}], {
             RGBColor[
             0.8431768541892217, 0.7161112955984645, 0.6049346124449686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 97}], {
             RGBColor[
             0.6691615275279388, 0.5770839186847934, 0.5896504800872672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.9006340382989853, 0.6395018820094367, 0.23868605563289352`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 140}], {
             RGBColor[
             0.8413676314488565, 0.2864072420017145, 0.18597171239681876`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 162}], {
             RGBColor[
             0.9404065856589258, 0.790829015220349, 0.5112620539625906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 167}], {
             RGBColor[
             0.8985734587541578, 0.6313323707616247, 0.23702806496310708`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 181}], {
             RGBColor[
             0.9378794291938042, 0.7781980948822975, 0.31536710248397326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 201}], {
             RGBColor[
             0.8600643597048547, 0.4301184883358802, 0.203875720489697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 202}], {
             RGBColor[
             0.8742021218716074, 0.5216630409074182, 0.2167435057125596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 203}], {
             RGBColor[
             0.9132949931047244, 0.7717981514907339, 0.6103970678254644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 216}], {
             RGBColor[
             0.8741307766845507, 0.521339079076086, 0.216683973539649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 237}], {
             RGBColor[
             0.8465380738337873, 0.3261495278745926, 0.19092293386380793`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 269}], {
             RGBColor[
             0.931314896123058, 0.7560543834090069, 0.28986513111217527`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 293}], {
             RGBColor[
             0.8946118304119881, 0.61433876058075, 0.23377386680638917`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 299}], {
             RGBColor[
             0.8422842306382159, 0.2934526250274564, 0.1868494488157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 103}], {
             RGBColor[
             0.5173846437366769, 0.6182066285292835, 0.9553895463254356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 140}], {
             RGBColor[
             0.7493592164876164, 0.32177032281068196`, 0.43038245426354804`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 145}], {
             RGBColor[
             0.7391717561435251, 0.7960859238654349, 0.9748439297036255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 154}], {
             RGBColor[
             0.5553686317376758, 0.6499123001732142, 0.9581397995541713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 167}], {
             RGBColor[
             0.7605608363122977, 0.684376991975076, 0.6036441777632009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 168}], {
             RGBColor[
             0.5069255349638632, 0.6091474742003642, 0.9547231011630586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 181}], {
             RGBColor[
             0.7998668067519439, 0.8312427160957487, 0.681983215284067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 201}], {
             RGBColor[
             0.7680559447436146, 0.4654815691448476, 0.44828646235642633`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 203}], {
             RGBColor[
             0.7752823706628642, 0.824842772704185, 0.9770131806255582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 216}], {
             RGBColor[
             0.7821223617233105, 0.5567021598850534, 0.46109471540637825`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 255}], {
             RGBColor[
             0.489728760692208, 0.5942524926612631, 0.9536273379129792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 258}], {
             RGBColor[
             0.47680058453134755`, 0.5830547562597531, 0.9528035659599465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 293}], {
             RGBColor[
             0.7565992079701278, 0.6673833817942012, 0.600389979606483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 101}], {
             RGBColor[
             0.7801443981327315, 0.4806917133441988, 0.4499691651133977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 142}], {
             RGBColor[
             0.8410135879259631, 0.3162539858335876, 0.18690796415711172`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 149}], {
             RGBColor[
             0.8628696595923687, 0.44534910675306505`, 0.20631412788053274`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 194}], {
             RGBColor[
             0.7930369047021925, 0.4907634374629408, 0.4512541696809177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[
             0.8931489612206265, 0.5687594209510818, 0.42014697935815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 198}], {
             RGBColor[
             0.8858987442443274, 0.5635903178481945, 0.44308216880395335`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 226}], {
             RGBColor[
             0.8931207694106547, 0.5687477629131621, 0.4206141906074483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 241}], {
             RGBColor[
             0.8930764595038494, 0.5687294396279854, 0.42134852043357485`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 243}], {
             RGBColor[
             0.8935075599716172, 0.5689077107501841, 0.41420407003041315`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 290}], {
             RGBColor[
             0.8798387029608784, 0.5143008519660508, 0.22005447189368316`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 291}], {
             RGBColor[
             0.8733266651066773, 0.5540623810054337, 0.4591038572583237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 191}], {
             RGBColor[
             0.2074223158614455, 0.3353443836777553, 0.9351237660832672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 217}], {
             RGBColor[
             0.19375308221906778`, 0.32097715244014635`, 0.9343453234491528]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 223}], {
             RGBColor[
             0.1844791456857544, 0.31122965714209644`, 0.9338171864831403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 246}], {
             RGBColor[
             0.1859588657451276, 0.3127849367441682, 0.9339014543514719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 247}], {
             RGBColor[
             0.1926121673846783, 0.3197779786110244, 0.9342803500371666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 270}], {
             RGBColor[
             0.20015353292457566`, 0.32770443194364846`, 0.9347098196482133]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 271}], {
             RGBColor[
             0.20505156873545605`, 0.33285257813429087`, 0.9349887555416483]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 278}], {
             RGBColor[
             0.19404895120727791`, 0.32128812950593255`, 0.9343621727503324]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 295}], {
             RGBColor[
             0.19219536521772562`, 0.31933989310677346`, 0.9342566137703623]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[
             0.22879896787362192`, 0.35781260030057205`, 0.936341134791438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 135}], {
             RGBColor[
             0.22261249954375167`, 0.3513102298411313, 0.9359888245721116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 154}], {
             RGBColor[
             0.36472305205370464`, 0.48205039622074985`, 0.9450500607222323]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 173}], {
             RGBColor[
             0.21671771694106706`, 0.34511443957490595`, 0.9356531254234381]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 213}], {
             RGBColor[
             0.21726177740977812`, 0.34568628162294734`, 0.9356841088622658]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 234}], {
             RGBColor[
             0.21315182719847248`, 0.341366463364971, 0.9354500532778585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 239}], {
             RGBColor[
             0.2348622905163943, 0.36418553683498534`, 0.936686432046062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 249}], {
             RGBColor[
             0.21980259172524277`, 0.34835683856543287`, 0.9358288044787336]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 255}], {
             RGBColor[
             0.2990831810082368, 0.42639058870879876`, 0.9405375990810403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 258}], {
             RGBColor[
             0.2861550048473763, 0.41519285230728875`, 0.9397138271280076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 263}], {
             RGBColor[
             0.22101888131475306`, 0.34963523604122215`, 0.9358980703715171]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 286}], {
             RGBColor[
             0.2265196157319883, 0.3554168566804423, 0.9362113290589713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[
             0.6955329406462065, 0.7613368008112785, 0.9707925147289977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 97}], {
             RGBColor[
             0.5215176139849236, 0.6223094238976072, 0.9555083823712963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 120}], {
             RGBColor[
             0.4366336879326583, 0.5460453622474791, 0.9502000470026102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 130}], {
             RGBColor[
             0.75299012475597, 0.6847273872222507, 0.6045439579169226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 140}], {
             RGBColor[
             0.7429383557535131, 0.3165575788102572, 0.4298769805861715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 162}], {
             RGBColor[
             0.7927626721159106, 0.8360545204331631, 0.8771199562466196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 169}], {
             RGBColor[
             0.5994580148931581, 0.6857060476229113, 0.9616106773009028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[
             0.4265942001520806, 0.5354932240498018, 0.9496283130255976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 182}], {
             RGBColor[
             0.4242603384632414, 0.5330401874394541, 0.9494954030550571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 202}], {
             RGBColor[
             0.7757728461762639, 0.551813377715961, 0.4606487739019124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 261}], {
             RGBColor[
             0.41945675567834323`, 0.5279913173677868, 0.949221846121721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 284}], {
             RGBColor[
             0.41756739126480746`, 0.526005475576538, 0.9491142496134344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 109}], {
             RGBColor[
             0.9929796059139886, 0.9895239708410322, 0.632193448669364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 140}], {
             RGBColor[
             0.8759286833407519, 0.418668898924348, 0.2746739047117526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 151}], {
             RGBColor[
             0.7954880540997038, 0.8360677360525939, 0.7285340376363743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[
             0.7452228320173793, 0.7952601643437132, 0.7245769752264782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 155}], {
             RGBColor[
             0.959730943798982, 0.866659323879206, 0.37757715104669176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 162}], {
             RGBColor[
             0.9922481634967688, 0.9892215006042993, 0.6443153424349913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 181}], {
             RGBColor[
             0.9897210070316473, 0.9765905802662477, 0.448420390956374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 202}], {
             RGBColor[
             0.9087631737635028, 0.6539246978300517, 0.30544569802749344`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 203}], {
             RGBColor[
             0.9651365709425674, 0.970190636874684, 0.7434503562978652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 216}], {
             RGBColor[
             0.9086918285764461, 0.6536007359987195, 0.30538616585458284`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 227}], {
             RGBColor[
             0.9729262687384115, 0.9189743901826695, 0.3881944192270413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 258}], {
             RGBColor[
             0.6666547848110509, 0.7284026204302521, 0.7192407416322534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 299}], {
             RGBColor[
             0.8768452825301113, 0.42571428195008987`, 0.27555164113063385`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 93}], {
             RGBColor[
             0.23199426054362918`, 0.36117105549000617`, 0.9365231019819831]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 107}], {
             RGBColor[
             0.3156668760979841, 0.43989562490003076`, 0.9416257469918767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 124}], {
             RGBColor[
             0.20439146202389424`, 0.3321587641272566, 0.9349511634409652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 137}], {
             RGBColor[
             0.242196310039882, 0.3718940563578661, 0.9371040936082149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 147}], {
             RGBColor[
             0.21812810554997109`, 0.34659684742666674`, 0.9357334449682322]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 273}], {
             RGBColor[
             0.23089430452924603`, 0.3600149319776501, 0.936460461114203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 274}], {
             RGBColor[
             0.342952508633553, 0.4632649151839602, 0.9434373496862328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 289}], {
             RGBColor[
             0.23315152394890182`, 0.3623874127036856, 0.9365890064208955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 94}], {
             RGBColor[
             0.5888165791799138, 0.6727291061533267, 0.962935879267211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 120}], {
             RGBColor[
             0.3299173264663655, 0.4574376675895273, 0.9423434115408236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 131}], {
             RGBColor[
             0.3050760854207314, 0.4313279482249144, 0.9409287396125976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 141}], {
             RGBColor[
             0.33729605784908523`, 0.4651931821113565, 0.9427636193772146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 188}], {
             RGBColor[
             0.3683043792841372, 0.49342847464473716`, 0.9446890072625783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 236}], {
             RGBColor[
             0.30608763983959875`, 0.4323911560553985, 0.9409863461402914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 260}], {
             RGBColor[
             0.3194559514168667, 0.4464420991230162, 0.9417476517079721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 281}], {
             RGBColor[
             0.6796029595718664, 0.743830302697593, 0.9334123929687868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 294}], {
             RGBColor[
             0.4583968818459615, 0.569215720181254, 0.9510502956112238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 118}], {
             RGBColor[
             0.20219853738896398`, 0.32985386129649247`, 0.9348262796271471]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 126}], {
             RGBColor[
             0.2195822201328165, 0.34812521404942687`, 0.9358162546425555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 153}], {
             RGBColor[
             0.21837262298903565`, 0.3468538507584247, 0.9357473698746558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.20088523531551122`, 0.3284734975491328, 0.9347514890169203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 195}], {
             RGBColor[
             0.19970007804544365`, 0.3272278221149808, 0.934683996063673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 222}], {
             RGBColor[
             0.2185508250169386, 0.3470411523884118, 0.9357575182165185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 234}], {
             RGBColor[
             0.20491562163947707`, 0.33270968911687326`, 0.9349810135556479]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 239}], {
             RGBColor[
             0.2266260849573989, 0.3555287625868876, 0.9362173923238513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 248}], {
             RGBColor[
             0.21881740302399694`, 0.347321342775852, 0.9357726994396538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 285}], {
             RGBColor[
             0.20767787323688183`, 0.3356129906826123, 0.9351383196977351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 93}], {
             RGBColor[
             0.3656444287828603, 0.48387268995411137`, 0.9450248073537576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 105}], {
             RGBColor[
             0.38699951220692347`, 0.5063182366232937, 0.9462409477627431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 107}], {
             RGBColor[
             0.44931704433721525`, 0.562597259364136, 0.9501274523636514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 139}], {
             RGBColor[
             0.4654409733450266, 0.5765629962584664, 0.9511548548621985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 142}], {
             RGBColor[
             0.7166766594677184, 0.35305977598567057`, 0.4352018560097054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 143}], {
             RGBColor[
             0.39852667636969663`, 0.5184340170227889, 0.9468974027089019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 150}], {
             RGBColor[
             0.6987841041568563, 0.6337941140587057, 0.5986819437121721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 163}], {
             RGBColor[
             0.5556545906660699, 0.6501444545135875, 0.9581623112885165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 179}], {
             RGBColor[
             0.5064577791876668, 0.6102042666643193, 0.9542893580750782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 235}], {
             RGBColor[
             0.44932632055040805`, 0.5626052939537676, 0.9501280434357534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 273}], {
             RGBColor[
             0.3645444727684772, 0.4827165664417553, 0.9449621664859775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 274}], {
             RGBColor[
             0.4766026768727841, 0.5859665496480654, 0.9519390550580074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 298}], {
             RGBColor[
             0.3751482927558811, 0.4938618535695355, 0.9455660383473143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 125}], {
             RGBColor[
             0.8327679503009816, 0.2528744017865336, 0.1790119322553138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 128}], {
             RGBColor[
             0.8360165444918075, 0.27784452028027223`, 0.18212278972121096`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 142}], {
             RGBColor[
             0.8310149903490321, 0.23940038344390055`, 0.17733329582564183`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 149}], {
             RGBColor[
             0.8528710620154377, 0.368495504363378, 0.19673945954906286`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 150}], {
             RGBColor[
             0.856839597699243, 0.38590456876888285`, 0.2000192899179641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 179}], {
             RGBColor[
             0.7286220477197832, 0.3701780038392919, 0.4370908994932349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 237}], {
             RGBColor[
             0.829394680828139, 0.22694597444215714`, 0.1757816855985568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 243}], {
             RGBColor[
             0.8835089623946862, 0.49205410836049707`, 0.4046294016989433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 256}], {
             RGBColor[
             0.8270124944014894, 0.208635445686179, 0.17350050118610227`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 269}], {
             RGBColor[
             0.8787580922688558, 0.4694128451100082, 0.23531711654302695`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 277}], {
             RGBColor[
             0.8853735220807035, 0.49151915194709656`, 0.27879642661699433`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 281}], {
             RGBColor[
             0.8805236512409333, 0.4901849175991575, 0.4256811132326063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 105}], {
             RGBColor[
             0.26248514686677915`, 0.39321891024948796`, 0.9382595128508624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 107}], {
             RGBColor[
             0.32480267899707094`, 0.44949793299033025`, 0.9421460174517705]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 137}], {
             RGBColor[
             0.25133211293896884`, 0.38149636444816565`, 0.9376243640681086]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 139}], {
             RGBColor[
             0.3409266080048823, 0.4634636698846607, 0.9431734199503177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 147}], {
             RGBColor[
             0.22726390844905786`, 0.3561991555169663, 0.936253715428126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 273}], {
             RGBColor[
             0.24003010742833283`, 0.36961724006794966`, 0.9369807315740968]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 274}], {
             RGBColor[
             0.3520883115326398, 0.4728672232742597, 0.9439576201461266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 289}], {
             RGBColor[
             0.24228732684798865`, 0.37198972079398507`, 0.9371092768807893]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 97}], {
             RGBColor[
             0.622873487370591, 0.7022274882781143, 0.9651059553417796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 120}], {
             RGBColor[
             0.5379895613183256, 0.6259634266279861, 0.9597976199730934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 130}], {
             RGBColor[
             0.8543459981416374, 0.7646454516027577, 0.6141415308874059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 141}], {
             RGBColor[
             0.5453682927010454, 0.6337189411498153, 0.9602178278094844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 188}], {
             RGBColor[
             0.5763766141360973, 0.661954233683196, 0.9621432156948482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 201}], {
             RGBColor[
             0.8292056662666228, 0.5135475347314276, 0.45417937065937186`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 202}], {
             RGBColor[
             0.8433434284333755, 0.6050920873029656, 0.46704715588223444`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.8156793803955554, 0.4095785742701399, 0.4412265840334828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 281}], {
             RGBColor[
             0.8876751944238266, 0.9123560617360518, 0.9508666014010566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 293}], {
             RGBColor[
             0.8483237902546403, 0.739482330174071, 0.6092293420609014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 294}], {
             RGBColor[
             0.6664691166979216, 0.7377414792197128, 0.9685045040434936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 103}], {
             RGBColor[
             0.35444301317126903`, 0.47946333163225574`, 0.9438775064114789]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 127}], {
             RGBColor[
             0.3181958172626126, 0.4480678323732162, 0.9415678671403162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 145}], {
             RGBColor[
             0.5762301255781173, 0.6573426269684071, 0.963331889789669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 148}], {
             RGBColor[
             0.2669268205335093, 0.3978873908915973, 0.9385124595953154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 156}], {
             RGBColor[
             0.3410239560220559, 0.4678404187910305, 0.9430224559559374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 159}], {
             RGBColor[
             0.2893985943419117, 0.4215066499569798, 0.9397921938696936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 168}], {
             RGBColor[
             0.3439839043984553, 0.4704041773033365, 0.943211061249102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 191}], {
             RGBColor[
             0.2574665501142888, 0.38794404686520834`, 0.9379737111901566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 205}], {
             RGBColor[
             0.32995805051825455`, 0.4582556876322203, 0.9423173462424312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 212}], {
             RGBColor[
             0.2604625119164363, 0.3910929926742148, 0.9381443267826606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 225}], {
             RGBColor[
             0.2575765092536425, 0.3880596208924811, 0.9379799732004728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 251}], {
             RGBColor[
             0.2865818395337517, 0.41854606206103384`, 0.9396317838503843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 271}], {
             RGBColor[
             0.25509580298829937`, 0.3854522413217438, 0.9378387006485376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 276}], {
             RGBColor[
             0.2644651178260697, 0.3952999852651118, 0.9383722692678894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 282}], {
             RGBColor[
             0.36409426757402563`, 0.48782276310977274`, 0.9444924758077534]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 112}], {
             RGBColor[
             0.1950909003644823, 0.32238328413354655`, 0.9344215102134096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 132}], {
             RGBColor[
             0.1989233882773373, 0.32641147192372544`, 0.9346397647303889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 133}], {
             RGBColor[
             0.19311989172231955`, 0.3203116290814677, 0.9343092641870845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 146}], {
             RGBColor[
             0.20048974504421074`, 0.3280578121984645, 0.9347289664310452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 236}], {
             RGBColor[
             0.2161907003932258, 0.34456051176834573`, 0.9356231126106896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 260}], {
             RGBColor[
             0.22955901197049378`, 0.3586114548359634, 0.9363844181783704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 267}], {
             RGBColor[
             0.19857826997424566`, 0.3260487307054119, 0.9346201107535846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 120}], {
             RGBColor[
             0.3639742346570427, 0.4869360497143149, 0.944513487615392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 130}], {
             RGBColor[
             0.6803306714803544, 0.6256180746890865, 0.5988573985297044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 178}], {
             RGBColor[
             0.353934746876465, 0.4763839115166376, 0.9439417536383794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 182}], {
             RGBColor[
             0.35160088518762583`, 0.47393087490628993`, 0.9438088436678389]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 202}], {
             RGBColor[
             0.7273332106591868, 0.5124071693605181, 0.4568577343104335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 261}], {
             RGBColor[
             0.34679730240272766`, 0.46888200483462256`, 0.9435352867345028]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 284}], {
             RGBColor[
             0.3449079379891919, 0.4668961630433738, 0.9434276902262162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 157}], {
             RGBColor[
             0.18079506708635712`, 0.3073574569500555, 0.9336073836570105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.17910006852395627`, 0.30557590599185624`, 0.9335108559964074]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 275}], {
             RGBColor[
             0.17961340510331275`, 0.30611545528417883`, 0.9335400897551883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 285}], {
             RGBColor[
             0.18936585526810354`, 0.31636589874842813`, 0.9340954773646161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 182}], {
             RGBColor[
             0.22500890422772363`, 0.3538290031048185, 0.9361252962737008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 199}], {
             RGBColor[
             0.19703448061371565`, 0.32442611020559603`, 0.9345321942333341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 209}], {
             RGBColor[
             0.18806492725905072`, 0.31499854092731383`, 0.934021391439051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 215}], {
             RGBColor[
             0.21020795705683448`, 0.338272269193962, 0.9352824042283578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 229}], {
             RGBColor[
             0.20669327315473038`, 0.33457811356902034`, 0.9350822481796419]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 233}], {
             RGBColor[
             0.20053490529032286`, 0.32810527848045334`, 0.9347315382402527]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 259}], {
             RGBColor[
             0.19041774683741108`, 0.3174715034815479, 0.934155381033354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 284}], {
             RGBColor[
             0.2183159570292897, 0.34679429124190236`, 0.9357441428320781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 119}], {
             RGBColor[
             0.1807572108955105, 0.3073176676932546, 0.933605227802945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 122}], {
             RGBColor[
             0.18285159839459103`, 0.3095190017466254, 0.933724500072649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 161}], {
             RGBColor[
             0.1911587437240086, 0.318250338191278, 0.9341975797098391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 244}], {
             RGBColor[
             0.18508330510196136`, 0.31186466699444937`, 0.9338515924681194]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 266}], {
             RGBColor[
             0.1894062944527255, 0.3164084028954582, 0.9340977803163559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 104}], {
             RGBColor[
             0.49120791951509923`, 0.5945373978105576, 0.9540278714950781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 116}], {
             RGBColor[
             0.46733992011891123`, 0.5718860980228273, 0.952579449352897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 136}], {
             RGBColor[
             0.5199717589850226, 0.6194511898467974, 0.9558606779112371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 149}], {
             RGBColor[
             0.7714159149498363, 0.6714029284596804, 0.6000007099012994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 197}], {
             RGBColor[
             0.816834867392223, 0.8565183997567056, 0.9207499871177253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 198}], {
             RGBColor[
             0.8059595419277743, 0.8487647451023745, 0.9551527712864303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[
             0.5654681824695174, 0.6580354513456885, 0.9589869162220399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 226}], {
             RGBColor[
             0.8167925796772653, 0.8565009126998259, 0.9214508039916728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 243}], {
             RGBColor[
             0.8173727655187092, 0.8567408344553589, 0.91183562312612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 254}], {
             RGBColor[
             0.4830549298600605, 0.587475687952538, 0.9535083702036646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 283}], {
             RGBColor[
             0.4765743997943146, 0.5815921216615045, 0.9531053393092228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 165}], {
             RGBColor[
             0.20499479718794766`, 0.3327929076383356, 0.9349855224860035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 172}], {
             RGBColor[
             0.19138970866876043`, 0.3184930969922355, 0.9342107328217606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 175}], {
             RGBColor[
             0.18740197098760464`, 0.3143017318521686, 0.9339836370601481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 183}], {
             RGBColor[
             0.19246783079694663`, 0.31962627170585023`, 0.934272130282022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 238}], {
             RGBColor[
             0.18981943468321613`, 0.3168426394723074, 0.9341213080412961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 253}], {
             RGBColor[
             0.1920226425007294, 0.3191583505799577, 0.9342467774671497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 127}], {
             RGBColor[
             0.3850824421018483, 0.5079607893674816, 0.9457580905890645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 145}], {
             RGBColor[
             0.643116750417353, 0.7172355839626725, 0.9675221132384173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 154}], {
             RGBColor[
             0.45931362601150366`, 0.5710619602704519, 0.9508179830889629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 159}], {
             RGBColor[
             0.35628521918114736`, 0.4813996069512451, 0.9439824173184419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 167}], {
             RGBColor[
             0.6645058305861254, 0.6055266520723135, 0.5963223612979925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 168}], {
             RGBColor[
             0.41087052923769096`, 0.5302971342976018, 0.9474012846978503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 203}], {
             RGBColor[
             0.679227364936692, 0.7459924328014227, 0.96969136416035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 205}], {
             RGBColor[
             0.39684467535749024`, 0.5181486446264856, 0.9465075696911796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 212}], {
             RGBColor[
             0.327349136755672, 0.45098594966848016`, 0.9423345502314089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 225}], {
             RGBColor[
             0.3244631340928782, 0.4479525778867464, 0.9421701966492211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 255}], {
             RGBColor[
             0.3936737549660358, 0.5154021527585007, 0.9463055214477708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 265}], {
             RGBColor[
             0.3220227389937979, 0.445387567907627, 0.9420312197585695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 269}], {
             RGBColor[
             0.6972472679550255, 0.7302486647196956, 0.6491594274470608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 276}], {
             RGBColor[
             0.33135174266530537`, 0.4551929422593771, 0.9425624927166377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 282}], {
             RGBColor[
             0.4309808924132613, 0.5477157201040381, 0.9486826992565017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 293}], {
             RGBColor[
             0.6605442022439556, 0.5885330418914387, 0.5930681631412746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 114}], {
             RGBColor[
             0.28710993911342014`, 0.4166656473064825, 0.939751033226302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 116}], {
             RGBColor[
             0.3112198168736299, 0.4420066574870038, 0.9411240550973782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 204}], {
             RGBColor[
             0.40934807922423605`, 0.5281560108098651, 0.9475315219665212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 206}], {
             RGBColor[
             0.2787552105581772, 0.4078842978745366, 0.9392752437947942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 243}], {
             RGBColor[
             0.6612526622734278, 0.7268613939195354, 0.9003802288706013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 254}], {
             RGBColor[
             0.32693482661477913`, 0.45759624741671456`, 0.942052975948146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 283}], {
             RGBColor[
             0.32045429654903324`, 0.4517126811256811, 0.9416499450537039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 287}], {
             RGBColor[
             0.2890443879522816, 0.41869887568726627`, 0.9398611972259145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 300}], {
             RGBColor[
             0.2803668703826312, 0.4095782545351725, 0.9393670254375599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 139}], {
             RGBColor[
             0.3622816914289454, 0.48590921655384295`, 0.9443895603593033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 143}], {
             RGBColor[
             0.29536739445361543`, 0.4277802373181654, 0.9401321082060067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 163}], {
             RGBColor[
             0.4524953087499887, 0.5594906748089641, 0.9513970167856213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 174}], {
             RGBColor[
             0.25852249961576723`, 0.3890539167423275, 0.9380338459521285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 235}], {
             RGBColor[
             0.34616703863432685`, 0.47195151424914406`, 0.9433627489328582]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 274}], {
             RGBColor[
             0.373443394956703, 0.4953127699434419, 0.9451737605551122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 298}], {
             RGBColor[
             0.27198901083979987`, 0.403208073864912, 0.938800743844419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 115}], {
             RGBColor[
             0.6067946716231568, 0.6858798777418896, 0.9651595250499304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 155}], {
             RGBColor[
             0.8940872222095038, 0.8191271102860018, 0.6231274080512639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 162}], {
             RGBColor[
             0.9266044419072905, 0.9416892870110949, 0.8898655994395634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 194}], {
             RGBColor[
             0.7739330746560312, 0.8236601401446212, 0.9780122537987794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 200}], {
             RGBColor[
             0.6137154608562325, 0.6918743175265988, 0.9656005116200483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 210}], {
             RGBColor[
             0.6667698289178824, 0.73732879896912, 0.9691188386686375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 211}], {
             RGBColor[
             0.5662966671615951, 0.6472879549936589, 0.9627077142549896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 227}], {
             RGBColor[
             0.907282547148933, 0.8714421765894653, 0.6337446762316135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 241}], {
             RGBColor[
             0.9239924068585166, 0.940609143392188, 0.9331537799277652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 264}], {
             RGBColor[
             0.579035279379287, 0.6606770441091168, 0.9634331593756991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 290}], {
             RGBColor[
             0.9041357720440601, 0.8589662618992862, 0.6312127071179277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 291}], {
             RGBColor[
             0.8943677152627585, 0.9186085554583606, 0.9897867851648885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 137}], {
             RGBColor[
             0.33500472849332374`, 0.4602209338581902, 0.9427270090780024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 139}], {
             RGBColor[
             0.4245992235592372, 0.5421882392946853, 0.9482760649602114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[
             0.3109365240034128, 0.43492372492699083`, 0.9413563604380197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 150}], {
             RGBColor[
             0.657942354371067, 0.5994193570949246, 0.595803153810185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.4014834091317521, 0.5221664826722128, 0.9468031457054042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.4656160294018773, 0.5758295097005381, 0.9514105681730911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 251}], {
             RGBColor[
             0.34704129264344796`, 0.47287212594221606`, 0.943412473599851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 273}], {
             RGBColor[
             0.32370272298268776`, 0.4483418094779742, 0.9420833765839904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 274}], {
             RGBColor[
             0.43576092708699476`, 0.5515917926842843, 0.9490602651560203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 277}], {
             RGBColor[
             0.7007432409432577, 0.7578412318622451, 0.7139688588587303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 289}], {
             RGBColor[
             0.32595994240234355`, 0.45071429020400966`, 0.942211921890683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 136}], {
             RGBColor[
             0.3166504809342749, 0.4423958027593246, 0.9416280716923184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 177}], {
             RGBColor[
             0.2663285931328081, 0.3972586159636525, 0.9384783914298436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 204}], {
             RGBColor[
             0.36214690441876973`, 0.48098006425821577`, 0.9447543100031214]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 208}], {
             RGBColor[
             0.2150010029643497, 0.34331006433942324`, 0.9355553611021148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 252}], {
             RGBColor[
             0.23931387407336885`, 0.3688644334000649, 0.9369399431441039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 254}], {
             RGBColor[
             0.27973365180931276`, 0.4104203008650652, 0.9392757639847461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 268}], {
             RGBColor[
             0.2228674989167732, 0.351578250350071, 0.9360033464091675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 279}], {
             RGBColor[
             0.23867609661587075`, 0.3681940888548081, 0.9369036226614065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 280}], {
             RGBColor[
             0.2513491898337207, 0.3815143133472875, 0.9376253365720018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 283}], {
             RGBColor[
             0.2732531217435669, 0.4045367345740317, 0.9388727330903042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 111}], {
             RGBColor[
             0.8035074391264327, 0.8444862586698714, 0.8657863480729937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 151}], {
             RGBColor[
             0.7953196099914366, 0.8378390101205823, 0.8651417721704804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 155}], {
             RGBColor[
             0.9595624996907148, 0.8684305979471943, 0.514184885580798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 192}], {
             RGBColor[
             0.6617142280646152, 0.7260405303844142, 0.8555444013688691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 218}], {
             RGBColor[
             0.9800003657513711, 0.9831729301139916, 0.8546124313811914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 220}], {
             RGBColor[
             0.6629503007752218, 0.7271111544395208, 0.8556231628289728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 227}], {
             RGBColor[
             0.9727578246301442, 0.9207456642506578, 0.5248021537611475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 290}], {
             RGBColor[
             0.9696110495252712, 0.9082697495604787, 0.5222701846474617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 292}], {
             RGBColor[
             0.8832633694480486, 0.907223500639492, 0.873440789605417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 148}], {
             RGBColor[
             0.2161072361235734, 0.34447278552900074`, 0.9356183594440073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 191}], {
             RGBColor[
             0.20664696570435293`, 0.3345294415026117, 0.9350796110388486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 223}], {
             RGBColor[
             0.18370379552866184`, 0.31041471496695283`, 0.9337730314387216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 246}], {
             RGBColor[
             0.18518351558803503`, 0.3119699945690246, 0.9338572993070533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 278}], {
             RGBColor[
             0.19327360105018532`, 0.32047318733078894`, 0.9343180177059138]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 295}], {
             RGBColor[
             0.19142001506063305`, 0.31852495093162986`, 0.9342124587259435]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 143}], {
             RGBColor[
             0.46054913753176646`, 0.5687866450741914, 0.9517800380473413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 163}], {
             RGBColor[
             0.6176770518281398, 0.70049708256499, 0.9630449466269559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.5718800780485805, 0.6633170361205862, 0.9594396410911864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 218}], {
             RGBColor[
             0.7906966430720825, 0.8363639438748425, 0.9515975962507148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 235}], {
             RGBColor[
             0.5113487817124779, 0.61295792200517, 0.9550106787741928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 262}], {
             RGBColor[
             0.459021775002635, 0.5671812902156966, 0.9516930570108376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 292}], {
             RGBColor[
             0.6939596467687601, 0.7604145144003427, 0.9704259544749405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 131}], {
             RGBColor[
             0.20931958090363292`, 0.3373385295306458, 0.9352318125206677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 132}], {
             RGBColor[
             0.1930638232066118, 0.32025269751650964`, 0.9343060711680607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 133}], {
             RGBColor[
             0.18726032665159403`, 0.3141528546742519, 0.9339755706247563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 146}], {
             RGBColor[
             0.19463017997348525`, 0.32189903779124873`, 0.934395272868717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 170}], {
             RGBColor[
             0.1934039006537554, 0.3206101404756131, 0.9343254380755761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 190}], {
             RGBColor[
             0.19682291342577818`, 0.3242037396769393, 0.9345201457949667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 115}], {
             RGBColor[
             0.3096806718260522, 0.43885035168813935`, 0.9410927375300542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 134}], {
             RGBColor[
             0.25621583264175446`, 0.38662946350150684`, 0.9379024846803665]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 144}], {
             RGBColor[
             0.23263625868922916`, 0.36184583624606526`, 0.9365596628266237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 160}], {
             RGBColor[
             0.23169850636271255`, 0.3608601990939647, 0.936506259218909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 169}], {
             RGBColor[
             0.4361857848874334, 0.5443112881470928, 0.9502895329739705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 176}], {
             RGBColor[
             0.23091262265844142`, 0.3600341854928709, 0.9364615043045614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 187}], {
             RGBColor[
             0.24618639037776724`, 0.3760878837786886, 0.9373313227806626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 193}], {
             RGBColor[
             0.2735981771019762, 0.40489940963349313`, 0.9388923834825018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 200}], {
             RGBColor[
             0.3166014610591278, 0.4448447914728484, 0.9415337241001722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 228}], {
             RGBColor[
             0.34694483487630184`, 0.4711266967709722, 0.9434671770482106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 231}], {
             RGBColor[
             0.24940666839475117`, 0.3794726001519578, 0.9375147128497554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 245}], {
             RGBColor[
             0.24643755239072743`, 0.3763518709789012, 0.9373456260857398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 264}], {
             RGBColor[
             0.28192127958218227`, 0.41364751805536637`, 0.939366371855823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 288}], {
             RGBColor[
             0.23824897201713657`, 0.3677451538202748, 0.9368792985473828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 297}], {
             RGBColor[
             0.22981287868159825`, 0.35887828484541334`, 0.9363988755120056]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 116}], {
             RGBColor[
             0.26324193971723214`, 0.3940143475187522, 0.9383026110841209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 204}], {
             RGBColor[
             0.3613702020678383, 0.4801637008416135, 0.944710077953264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 206}], {
             RGBColor[
             0.2307773334017795, 0.35989198790628496`, 0.936453799781537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 254}], {
             RGBColor[
             0.2789569494583814, 0.4096039374484629, 0.9392315319348887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 283}], {
             RGBColor[
             0.2724764193926355, 0.4037203711574294, 0.9388285010404467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 134}], {
             RGBColor[
             0.29826389721871693`, 0.4268505977105114, 0.940442569105771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 169}], {
             RGBColor[
             0.47823384946439584`, 0.5845324223560975, 0.9528296173993749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 193}], {
             RGBColor[
             0.3156462416789386, 0.4451205438424978, 0.9414324679079064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 200}], {
             RGBColor[
             0.35864952563609026`, 0.485065925681853, 0.9440738085255767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 210}], {
             RGBColor[
             0.4117038936977402, 0.5305204071243743, 0.9475921355741658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 211}], {
             RGBColor[
             0.3112307319414529, 0.4404795631489132, 0.9411810111605179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 227}], {
             RGBColor[
             0.6522166119287909, 0.6646337847447196, 0.6122179731371418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 228}], {
             RGBColor[
             0.3889928994532643, 0.5113478309799768, 0.946007261473615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 231}], {
             RGBColor[
             0.29145473297171365`, 0.41969373436096236`, 0.9400547972751598]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 245}], {
             RGBColor[
             0.2884856169676899, 0.4165730051879058, 0.9398857105111442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 264}], {
             RGBColor[
             0.32396934415914475`, 0.453868652264371, 0.9419064562812274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 204}], {
             RGBColor[
             0.38548007982804805`, 0.5055047110221348, 0.9460830998243401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 206}], {
             RGBColor[
             0.2548872111619892, 0.3852329980868062, 0.9378268216526131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 254}], {
             RGBColor[
             0.30306682721859113`, 0.43494494762898417`, 0.9406045538059649]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 283}], {
             RGBColor[
             0.29658629715284524`, 0.4290613813379507, 0.9402015229115228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 287}], {
             RGBColor[
             0.2651763885560936, 0.39604757589953593`, 0.9384127750837334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 158}], {
             RGBColor[
             0.189227738636957, 0.3162207294119929, 0.9340876118267976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 196}], {
             RGBColor[
             0.1942847722586868, 0.32153599238288155`, 0.9343756024103442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 207}], {
             RGBColor[
             0.18539878883552113`, 0.3121962604012447, 0.9338695588000294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 212}], {
             RGBColor[
             0.20943922968905518`, 0.3374642879902957, 0.935238626341993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 214}], {
             RGBColor[
             0.19317010459047246`, 0.32036440598957616`, 0.9343121237356424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 225}], {
             RGBColor[
             0.20655322702626136`, 0.33443091620856197`, 0.9350742727598051]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 265}], {
             RGBColor[
             0.2041128319271811, 0.33186590622944256`, 0.9349352958691536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 276}], {
             RGBColor[
             0.21344183559868857`, 0.34167128058119267`, 0.9354665688272218]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 166}], {
             RGBColor[
             0.18740769372755933`, 0.31430774681470364`, 0.9339839629617225]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.18622253645749176`, 0.31306207138055164`, 0.9339164700084752]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 234}], {
             RGBColor[
             0.19143808005152518`, 0.3185439383824441, 0.9342134875004501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 239}], {
             RGBColor[
             0.213148543369447, 0.34136301185245843`, 0.9354498662686535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 263}], {
             RGBColor[
             0.19930513416780576`, 0.32681271105869525`, 0.9346615045941087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 285}], {
             RGBColor[
             0.19420033164892994`, 0.32144723994818314`, 0.9343707936425373]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 122}], {
             RGBColor[
             0.18294597115910344`, 0.30961819350570674`, 0.933729874461976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 161}], {
             RGBColor[
             0.191253116488521, 0.3183495299503595, 0.9342029540991661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 244}], {
             RGBColor[
             0.18517767786647377`, 0.3119638587535308, 0.9338569668574466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 266}], {
             RGBColor[
             0.1895006672172379, 0.3165075946545396, 0.9341031547056828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 131}], {
             RGBColor[
             0.2542490675591432, 0.38456226869957383`, 0.93779048031848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 141}], {
             RGBColor[
             0.28646903998749706`, 0.4184275025860159, 0.939625360083097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 170}], {
             RGBColor[
             0.23833338730926568`, 0.3678338796445412, 0.9368841058733883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 178}], {
             RGBColor[
             0.2690508208241996, 0.4001198498665095, 0.9386334182696933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 182}], {
             RGBColor[
             0.2667169591353605, 0.3976668132561618, 0.9385005082991529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 188}], {
             RGBColor[
             0.317477361422549, 0.44666279511939655`, 0.9415507479684607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 190}], {
             RGBColor[
             0.24175240008128845`, 0.37142747884586735`, 0.937078813592779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 261}], {
             RGBColor[
             0.2619133763504623, 0.3926179431844944, 0.9382269513658168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 284}], {
             RGBColor[
             0.26002401193692654`, 0.39063210139324567`, 0.9381193548575302]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 294}], {
             RGBColor[
             0.40756986398437334`, 0.5224500406559134, 0.9479120363171062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 135}], {
             RGBColor[
             0.21926297732246688`, 0.3477896696145861, 0.9357980742367835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 154}], {
             RGBColor[
             0.3613735298324199, 0.47852983599420473`, 0.9448593103869043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 173}], {
             RGBColor[
             0.21336819471978227`, 0.34159387934836083`, 0.9354623750881099]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.21391225518849333`, 0.3421657213964022, 0.9354933585269378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 234}], {
             RGBColor[
             0.20980230497718771`, 0.3378459031384259, 0.9352593029425303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 239}], {
             RGBColor[
             0.2315127682951095, 0.3606649766084402, 0.9364956817107337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 249}], {
             RGBColor[
             0.21645306950395798`, 0.3448362783388877, 0.9356380541434055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 255}], {
             RGBColor[
             0.295733658786952, 0.42287002848225363`, 0.9403468487457121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 258}], {
             RGBColor[
             0.28280548262609156`, 0.41167229208074363`, 0.9395230767926794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 263}], {
             RGBColor[
             0.2176693590934683, 0.34611467581467703`, 0.935707320036189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 286}], {
             RGBColor[
             0.22317009351070355`, 0.3518962964538972, 0.9360205787236432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 138}], {
             RGBColor[
             0.2081640824318275, 0.3361240273739437, 0.9351660085921052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 161}], {
             RGBColor[
             0.19334750398760153`, 0.32055086400373023`, 0.9343222263688701]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 266}], {
             RGBColor[
             0.19159505471631844`, 0.31870892870791034`, 0.9342224269753869]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 189}], {
             RGBColor[
             0.2072195140090381, 0.335131226072495, 0.935112216817791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 257}], {
             RGBColor[
             0.19133948148967972`, 0.3184403050424346, 0.9342078724582165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 267}], {
             RGBColor[
             0.19740462411574278`, 0.32481515449468, 0.9345532733581963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 287}], {
             RGBColor[
             0.22080206667647367`, 0.3494073501095485, 0.9358857230986155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 300}], {
             RGBColor[
             0.21212454910682327`, 0.34028672895745476`, 0.9353915513102607]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 147}], {
             RGBColor[
             0.19966110992932296`, 0.3271868641542167, 0.9346817768871081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 247}], {
             RGBColor[
             0.191840440673128, 0.3189668449068855, 0.9342364013426112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 273}], {
             RGBColor[
             0.2124273089085979, 0.3406049487052001, 0.9354087930330789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 289}], {
             RGBColor[
             0.2146845283282537, 0.3429774294312355, 0.9355373383397714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 128}], {
             RGBColor[
             0.8384430661867497, 0.296495829336185, 0.18444642963665195`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 130}], {
             RGBColor[
             0.8607307087477495, 0.4103624865662075, 0.20352137280561344`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 142}], {
             RGBColor[
             0.8334415120439743, 0.25805169249981336`, 0.1796569357410828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.8552975837103799, 0.3871468134192908, 0.19906309946450382`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 150}], {
             RGBColor[
             0.8592661193941853, 0.40455587782479563`, 0.20234292983340507`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 167}], {
             RGBColor[
             0.859356989051198, 0.4049161457343329, 0.20241604569242247`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 237}], {
             RGBColor[
             0.8318212025230813, 0.24559728349806995`, 0.17810532551399777`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 243}], {
             RGBColor[
             0.8859354840896285, 0.5107054174164098, 0.4069530416143843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 256}], {
             RGBColor[
             0.8294390160964316, 0.2272867547420918, 0.17582414110154324`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 269}], {
             RGBColor[
             0.881184613963798, 0.48806415416592097`, 0.23764075645846794`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 277}], {
             RGBColor[
             0.8878000437756458, 0.5101704610030093, 0.28112006653243526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 281}], {
             RGBColor[
             0.8829501729358756, 0.5088362266550703, 0.4280047531480473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 293}], {
             RGBColor[
             0.8567159034897515, 0.39358707228041634`, 0.20024658025461053`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 153}], {
             RGBColor[
             0.2222787641449363, 0.35095945277692997`, 0.9359698188348664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 157}], {
             RGBColor[
             0.20301322621103607`, 0.33071015090274497`, 0.93487267495034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 192}], {
             RGBColor[
             0.2770528278061131, 0.40650831596386994`, 0.939163161568517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 220}], {
             RGBColor[
             0.27828890051671973`, 0.40757894001897654`, 0.9392419230286206]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 222}], {
             RGBColor[
             0.22245696617283922`, 0.3511467544069171, 0.9359799671767292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 239}], {
             RGBColor[
             0.2305322261132995, 0.35963436460539283`, 0.9364398412840619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 248}], {
             RGBColor[
             0.22272354417989754`, 0.3514269447943572, 0.9359951483998643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 285}], {
             RGBColor[
             0.21158401439278246`, 0.3397185927011176, 0.9353607686579457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 145}], {
             RGBColor[
             0.6068695545086966, 0.6858400847036329, 0.9652124739672545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 148}], {
             RGBColor[
             0.29756624946408855`, 0.42638484862682313`, 0.9403930437729009]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 156}], {
             RGBColor[
             0.3716633849526351, 0.49633787652625627`, 0.9449030401335229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 159}], {
             RGBColor[
             0.3200380232724909, 0.45000410769220556`, 0.9416727780472791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 168}], {
             RGBColor[
             0.3746233333290345, 0.4989016350385623, 0.9450916454266876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 191}], {
             RGBColor[
             0.28810597904486807`, 0.41644150460043405`, 0.9398542953677421]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 205}], {
             RGBColor[
             0.3605974794488338, 0.48675314536744607`, 0.9441979304200168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 212}], {
             RGBColor[
             0.2911019408470156, 0.4195904504094406, 0.9400249109602461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 225}], {
             RGBColor[
             0.28821593818422175`, 0.41655707862770686`, 0.9398605573780583]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 251}], {
             RGBColor[
             0.31722126846433096`, 0.4470435197962596, 0.9415123680279698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 269}], {
             RGBColor[
             0.6610000720463691, 0.698853165460656, 0.646849788175898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 276}], {
             RGBColor[
             0.29510454675664893`, 0.4237974430003376, 0.9402528534454749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 282}], {
             RGBColor[
             0.3947336965046049, 0.5163202208449985, 0.9463730599853389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 142}], {
             RGBColor[
             0.839938700425626, 0.30799192948729065`, 0.18587865067287715`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 149}], {
             RGBColor[
             0.8617947720920316, 0.43708705040676815`, 0.20528481439629814`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 150}], {
             RGBColor[
             0.865763307775837, 0.454496114812273, 0.2085646447651994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 197}], {
             RGBColor[
             0.8920740737202894, 0.5604973646047849, 0.4191176658739154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 198}], {
             RGBColor[
             0.8848238567439902, 0.5553282615018976, 0.4420528553197187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 237}], {
             RGBColor[
             0.838318390904733, 0.29553752048554727`, 0.1843270404457921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 243}], {
             RGBColor[
             0.8924326724712802, 0.5606456544038871, 0.4131747565461786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 256}], {
             RGBColor[
             0.8359362044780833, 0.2772269917295691, 0.18204585603333756`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 269}], {
             RGBColor[
             0.8876818023454497, 0.5380043911533983, 0.24386247139026226`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 277}], {
             RGBColor[
             0.8942972321572974, 0.5601106979904866, 0.2873417814642296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 281}], {
             RGBColor[
             0.8894473613175273, 0.5587764636425476, 0.4342264680798416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 165}], {
             RGBColor[
             0.20344097121398075`, 0.33115973802143944`, 0.9348970343954657]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 175}], {
             RGBColor[
             0.18584814501363772`, 0.3126685622352725, 0.9338951489696101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 183}], {
             RGBColor[
             0.1909140048229797, 0.31799310208895415`, 0.9341836421914842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 184}], {
             RGBColor[
             0.19028873719925032`, 0.31733590617215746`, 0.9341480341253134]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 224}], {
             RGBColor[
             0.19887770973958555`, 0.32636346088436186`, 0.9346371634052393]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 253}], {
             RGBColor[
             0.19046881652676248`, 0.3175251809630616, 0.9341582893766117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 140}], {
             RGBColor[
             0.8488137274171336, 0.3187633460045766, 0.19210965802511026`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 162}], {
             RGBColor[
             0.9515757296113414, 0.8393631712246421, 0.5204689724050278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 167}], {
             RGBColor[
             0.9097426027065735, 0.6798665267659179, 0.24623498340554434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 201}], {
             RGBColor[
             0.8675104556731318, 0.4624745923387423, 0.2100136661179885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 202}], {
             RGBColor[
             0.8816482178398845, 0.5540191449102804, 0.2228814513408511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 203}], {
             RGBColor[
             0.92446413705714, 0.8203323074950271, 0.6196039862679017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 216}], {
             RGBColor[
             0.8815768726528278, 0.553695183078948, 0.2228219191679405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 237}], {
             RGBColor[
             0.8539841698020644, 0.35850563187745466`, 0.19706087949209944`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 269}], {
             RGBColor[
             0.9424840400754735, 0.8045885394133, 0.29907204955461253`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 281}], {
             RGBColor[
             0.9451323785335899, 0.8357466481470239, 0.5846180445889815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 293}], {
             RGBColor[
             0.9057809743644036, 0.6628729165850431, 0.24298078524882644`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 294}], {
             RGBColor[
             0.723926300807685, 0.6611320656306849, 0.6022559472314186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 299}], {
             RGBColor[
             0.849730326606493, 0.32580872903031854`, 0.19298739444399152`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 141}], {
             RGBColor[
             0.26162779894186294`, 0.392317783221403, 0.938210688154871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 146}], {
             RGBColor[
             0.2147184255833614, 0.3430130575955638, 0.9355392687383033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 170}], {
             RGBColor[
             0.21349214626363155`, 0.34172416027992825`, 0.9354694339451624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 178}], {
             RGBColor[
             0.2442095797785655, 0.3740101305018966, 0.9372187463414672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 182}], {
             RGBColor[
             0.24187571808972635`, 0.3715570938915489, 0.9370858363709268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 188}], {
             RGBColor[
             0.2926361203769149, 0.4205530757547836, 0.9401360760402346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 190}], {
             RGBColor[
             0.21691115903565433`, 0.3453177594812544, 0.9356641416645529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 199}], {
             RGBColor[
             0.21390129447571837`, 0.3421542009923264, 0.9354927343305601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 261}], {
             RGBColor[
             0.23707213530482818`, 0.36650822381988146`, 0.9368122794375908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 284}], {
             RGBColor[
             0.23518277089129241`, 0.36452238202863274`, 0.9367046829293041]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 133}], {
             RGBColor[
             0.19109281456444907`, 0.3181810424644308, 0.9341938251417357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 146}], {
             RGBColor[
             0.19846266788634026`, 0.3259272255814276, 0.9346135273856964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 236}], {
             RGBColor[
             0.21416362323535532`, 0.3424299251513089, 0.9355076735653408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 260}], {
             RGBColor[
             0.2275319348126233, 0.35648086821892655`, 0.9362689791330215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 267}], {
             RGBColor[
             0.19655119281637518`, 0.32391814408837505`, 0.9345046717082358]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 146}], {
             RGBColor[
             0.19265917133132254`, 0.3198273827391699, 0.9342830268423918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 170}], {
             RGBColor[
             0.1914328920115927, 0.3185384854235343, 0.9342131920492509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 144}], {
             RGBColor[
             0.22121948408189393`, 0.34984608226843733`, 0.9359094944023405]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 160}], {
             RGBColor[
             0.22028173175537732`, 0.3488604451163368, 0.9358560907946256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 169}], {
             RGBColor[
             0.42476901028009817`, 0.532311534169465, 0.9496393645496872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 176}], {
             RGBColor[
             0.21949584805110617`, 0.34803443151524305`, 0.9358113358802782]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 180}], {
             RGBColor[
             0.21984183187712564`, 0.34839808245303105`, 0.9358310391473328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 187}], {
             RGBColor[
             0.23476961577043198`, 0.36408812980106076`, 0.9366811543563793]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 193}], {
             RGBColor[
             0.26218140249464095`, 0.39289965565586527`, 0.9382422150582186]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 200}], {
             RGBColor[
             0.3051846864517926, 0.4328450374952205, 0.9408835556758889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 221}], {
             RGBColor[
             0.21549733286296777`, 0.343831738532004, 0.9355836263555868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 228}], {
             RGBColor[
             0.3355280602689666, 0.4591269427933443, 0.9428170086239273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 230}], {
             RGBColor[
             0.21844228820343148`, 0.34692707331578443`, 0.9357513372055553]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 245}], {
             RGBColor[
             0.2350207777833922, 0.3643521170012733, 0.9366954576614566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 264}], {
             RGBColor[
             0.27050450497484707`, 0.4016477640777385, 0.9387162034315397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 288}], {
             RGBColor[
             0.22683219740980134`, 0.35574539984264686`, 0.9362291301230996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 297}], {
             RGBColor[
             0.21839610407426302`, 0.3468785308677854, 0.9357487070877224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 158}], {
             RGBColor[
             0.20301108119461975`, 0.33070789635448955`, 0.9348725527948284]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 173}], {
             RGBColor[
             0.20718172638991203`, 0.3350915088889201, 0.9351100648687836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 186}], {
             RGBColor[
             0.20309625090443267`, 0.3307974151195744, 0.934877403083805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 213}], {
             RGBColor[
             0.20772578685862308`, 0.3356633509369615, 0.9351410483076115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 214}], {
             RGBColor[
             0.20695344714813524`, 0.3348515729320728, 0.9350970647036734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 249}], {
             RGBColor[
             0.21026660117408774`, 0.33833390787944695`, 0.9352857439240791]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 255}], {
             RGBColor[
             0.28954719045708177`, 0.4163676580228129, 0.9399945385263857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 263}], {
             RGBColor[
             0.21148289076359805`, 0.33961230535523634`, 0.9353550098168626]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 265}], {
             RGBColor[
             0.21789617448484386`, 0.3463530731719392, 0.9357202368371844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 276}], {
             RGBColor[
             0.22722517815635135`, 0.3561584475236893, 0.9362515097952526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 286}], {
             RGBColor[
             0.2169836251808333, 0.34539392599445645`, 0.9356682685043168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 177}], {
             RGBColor[
             0.34229360740819775`, 0.46934835455154167`, 0.9430884098094023]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 194}], {
             RGBColor[
             0.539310518839214, 0.6345587760249104, 0.957788184762517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 197}], {
             RGBColor[
             0.689478603616865, 0.751552751257122, 0.9111273992783655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 204}], {
             RGBColor[
             0.4381119186941594, 0.553069802846105, 0.9493643283826801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 210}], {
             RGBColor[
             0.43214727310106515`, 0.5482274348494092, 0.9488947696323751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 226}], {
             RGBColor[
             0.6894363159019072, 0.7515352642002422, 0.911828216152313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 252}], {
             RGBColor[
             0.3152788883487585, 0.44095417198795417`, 0.9415499615236627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 279}], {
             RGBColor[
             0.3146411108912604, 0.44028382744269734`, 0.9415136410409652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 280}], {
             RGBColor[
             0.32731420410911033`, 0.4536040519351767, 0.9422353549515605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 147}], {
             RGBColor[
             0.23746595794531072`, 0.3669221563848262, 0.9368347070543579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 156}], {
             RGBColor[
             0.32801284307365003`, 0.4541649141300481, 0.9422814923217423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 179}], {
             RGBColor[
             0.3921454633437752, 0.5078279411583735, 0.9468889147894293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 191}], {
             RGBColor[
             0.24445543716588297`, 0.3742685422042259, 0.9372327475559615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 217}], {
             RGBColor[
             0.23078620352350526`, 0.3599013109666169, 0.9364543049218471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 247}], {
             RGBColor[
             0.22964528868911577`, 0.358702137137495, 0.9363893315098609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 251}], {
             RGBColor[
             0.27357072658534587`, 0.4048705574000514, 0.9388908202161892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 270}], {
             RGBColor[
             0.23718665422901314`, 0.36662859047011903`, 0.9368188011209075]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 271}], {
             RGBColor[
             0.24208469003989352`, 0.37177673666076144`, 0.9370977370143425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 273}], {
             RGBColor[
             0.25023215692458567`, 0.3803402409358096, 0.9375617232003286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 278}], {
             RGBColor[
             0.23108207251171536`, 0.3602122880324031, 0.9364711542230267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 289}], {
             RGBColor[
             0.25248937634424146`, 0.382712721661845, 0.9376902685070212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 295}], {
             RGBColor[
             0.2292284865221631, 0.35826405163324404`, 0.9363655952430565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 210}], {
             RGBColor[
             0.35148342859896836`, 0.4711989277702072, 0.9440171598227016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 211}], {
             RGBColor[
             0.25101026684268113`, 0.38115808379474614`, 0.9376060354090536]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 231}], {
             RGBColor[
             0.23123426787294182`, 0.3603722550067954, 0.9364798215236958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 266}], {
             RGBColor[
             0.21471877848996196`, 0.3430134285227765, 0.935539288835812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 143}], {
             RGBColor[
             0.37380885559171856`, 0.49802499695333824`, 0.9450460153054621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 163}], {
             RGBColor[
             0.5309367698880918, 0.6297354344441368, 0.9563109238850767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 235}], {
             RGBColor[
             0.42460849977243, 0.5421962738843169, 0.9482766560323135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 273}], {
             RGBColor[
             0.3398266519904991, 0.46230754637230465`, 0.9431107790825377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 274}], {
             RGBColor[
             0.4518848560948061, 0.5655575295786147, 0.9500876676545675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 298}], {
             RGBColor[
             0.350430471977903, 0.4734528335000848, 0.9437146509438744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 162}], {
             RGBColor[
             0.8753287589904273, 0.41964810147851817`, 0.3738269902449083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 167}], {
             RGBColor[
             0.847440007720582, 0.31331700517270195`, 0.1910043309119193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 181}], {
             RGBColor[
             0.8736439880136796, 0.4112274879198171, 0.24323035592583006`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 201}], {
             RGBColor[
             0.8266673641279991, 0.20598262316708282`, 0.17317000404643912`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 202}], {
             RGBColor[
             0.8337362452113755, 0.25175489945285184`, 0.1796038966578704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 203}], {
             RGBColor[
             0.8572543639542931, 0.40696085899210804`, 0.43991699948682417`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 216}], {
             RGBColor[
             0.8337005726178471, 0.2515929185371857, 0.1795741305714151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 237}], {
             RGBColor[
             0.8199042211924654, 0.15399814293643901`, 0.1666936107334946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 269}], {
             RGBColor[
             0.8692676326331821, 0.39646501360429004`, 0.22622904167796476`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 293}], {
             RGBColor[
             0.8447989221591355, 0.30198793171878546`, 0.18883486547410736`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 299}], {
             RGBColor[
             0.8177772995946797, 0.13764969151287093`, 0.16465686820944062`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 146}], {
             RGBColor[
             0.24693839801171524`, 0.3768782914820059, 0.9373741485029203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 178}], {
             RGBColor[
             0.27642955220691934`, 0.4078753643883386, 0.9390536261060842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 182}], {
             RGBColor[
             0.2740956905180802, 0.4054223277779909, 0.9389207161355438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 188}], {
             RGBColor[
             0.3248560928052687, 0.45441830964122576`, 0.9419709558048517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 236}], {
             RGBColor[
             0.2626393533607303, 0.39338099105188706`, 0.9382682946825648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 261}], {
             RGBColor[
             0.269292107733182, 0.4003734577063236, 0.9386471592022079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 294}], {
             RGBColor[
             0.41494859536709305`, 0.5302055551777425, 0.9483322441534972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 149}], {
             RGBColor[
             0.8517916638064809, 0.3601987767340248, 0.1957058266051599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[
             0.8557601994902863, 0.3776078411395296, 0.19898565697406115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 163}], {
             RGBColor[
             0.7603405238297619, 0.3885080681094508, 0.43863923535829075`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 197}], {
             RGBColor[
             0.8820709654347386, 0.4836090909320415, 0.4095386780827771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 198}], {
             RGBColor[
             0.8748207484584395, 0.4784399878291542, 0.43247386752858047`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 243}], {
             RGBColor[
             0.8824295641857295, 0.48375738073114377`, 0.40359576875504033`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 256}], {
             RGBColor[
             0.8259330961925325, 0.20033871805682574`, 0.1724668682421993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 277}], {
             RGBColor[
             0.8842941238717467, 0.48322242431774326`, 0.2777627936730913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 163}], {
             RGBColor[
             0.4640224729127619, 0.5716064552084593, 0.95205347173178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 174}], {
             RGBColor[
             0.27004966377854045`, 0.4011696971418227, 0.9386903008982872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 185}], {
             RGBColor[
             0.41822549913320267`, 0.5344264087640556, 0.9484481661960105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 235}], {
             RGBColor[
             0.3576942027971, 0.4840672946486393, 0.9440192038790169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 298}], {
             RGBColor[
             0.28351617500257303`, 0.41532385426440727`, 0.9394571987905778]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 160}], {
             RGBColor[
             0.19670215780285202`, 0.3240768178608952, 0.934513268940883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 176}], {
             RGBColor[
             0.19591627409858087`, 0.32325080425980146`, 0.9344685140265354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 221}], {
             RGBColor[
             0.19191775891044247`, 0.3190481112765624, 0.9342408045018441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 230}], {
             RGBColor[
             0.19486271425090618`, 0.32214344606034284`, 0.9344085153518125]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 231}], {
             RGBColor[
             0.21441031983489064`, 0.34268921891888826`, 0.9355217225717294]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 232}], {
             RGBColor[
             0.19277383312180774`, 0.31994789955094727`, 0.9342895566617331]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 240}], {
             RGBColor[
             0.18908519234139687`, 0.31607090421740214`, 0.9340794940261437]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 245}], {
             RGBColor[
             0.2114412038308669, 0.3395684897458317, 0.9353526358077138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 264}], {
             RGBColor[
             0.24692493102232177`, 0.3768641368222969, 0.9373733815777969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 288}], {
             RGBColor[
             0.20325262345727604`, 0.33096177258720527`, 0.9348863082693568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 297}], {
             RGBColor[
             0.19481653012173772`, 0.32209490361234383`, 0.9344058852339796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 156}], {
             RGBColor[
             0.6296976932681398, 0.7056126711214472, 0.9666670627828757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 159}], {
             RGBColor[
             0.5780723315879956, 0.6592789022873965, 0.963436800696632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 167}], {
             RGBColor[
             0.8862929429929738, 0.7834059474084649, 0.6157767446761826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 168}], {
             RGBColor[
             0.6326576416445393, 0.7081764296337532, 0.9668556680760403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 201}], {
             RGBColor[
             0.8518773491973987, 0.5315008727671069, 0.456374840298414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 203}], {
             RGBColor[
             0.9010144773435402, 0.923871728137574, 0.9891457475385399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 205}], {
             RGBColor[
             0.6186317877643385, 0.696027939962637, 0.9659619530693695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 216}], {
             RGBColor[
             0.8659437661770946, 0.6227214635073127, 0.46918309334836605`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 237}], {
             RGBColor[
             0.8383510633263312, 0.42753191230581933`, 0.44342205367252496`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 269}], {
             RGBColor[
             0.9190343803618738, 0.908127960055847, 0.6686138108252507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 277}], {
             RGBColor[
             0.9289575250796454, 0.9412874203114796, 0.7338327759362018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 282}], {
             RGBColor[
             0.6527680048201097, 0.7255950154401895, 0.9681370826346918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 293}], {
             RGBColor[
             0.8823313146508039, 0.7664123372275902, 0.6125225465194646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 170}], {
             RGBColor[
             0.19880274533348388`, 0.3262846685405311, 0.9346328942932117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 236}], {
             RGBColor[
             0.2157299800022288, 0.3440762654260479, 0.9355968752659971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 247}], {
             RGBColor[
             0.2055770841992048, 0.33340492820629564`, 0.9350186828698783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 273}], {
             RGBColor[
             0.22616395243467474`, 0.35504303200461024`, 0.9361910745603459]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 289}], {
             RGBColor[
             0.22842117185433053`, 0.35741551273064565`, 0.9363196198670385]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 156}], {
             RGBColor[
             0.32039438822353183`, 0.44615743504463745`, 0.9418476325885221]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 159}], {
             RGBColor[
             0.26876902654338763`, 0.39982366621058674`, 0.9386173705022783]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 168}], {
             RGBColor[
             0.32335433659993124`, 0.4487211935569434, 0.9420362378816867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 191}], {
             RGBColor[
             0.23683698231576478`, 0.36626106311881523`, 0.9367988878227413]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 205}], {
             RGBColor[
             0.3093284827197305, 0.43657270388582725`, 0.9411425228750159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 217}], {
             RGBColor[
             0.22316774867338707`, 0.35189383188120626`, 0.9360204451886269]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 225}], {
             RGBColor[
             0.23694694145511846`, 0.36637663714608804`, 0.9368051498330575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 251}], {
             RGBColor[
             0.26595227173522773`, 0.39686307831464074`, 0.9384569604829689]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 270}], {
             RGBColor[
             0.22956819937889494`, 0.35862111138470837`, 0.9363849413876872]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 271}], {
             RGBColor[
             0.23446623518977533`, 0.3637692575753508, 0.9366638772811222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 278}], {
             RGBColor[
             0.2234636176615972, 0.35220480894699246`, 0.9360372944898065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.3434646997755016, 0.4661397793633797, 0.9433176524403382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 295}], {
             RGBColor[
             0.2216100316720449, 0.3502565725478334, 0.9359317355098362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 150}], {
             RGBColor[
             0.901456610665, 0.644502615181237, 0.23943789960535378`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.9409227595816787, 0.803504489870005, 0.5552674312684278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 198}], {
             RGBColor[
             0.93004743411723, 0.7957508352156739, 0.5896702154371328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 243}], {
             RGBColor[
             0.9414606577081649, 0.8037269245686582, 0.5463530672768225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 256}], {
             RGBColor[
             0.8437866719113953, 0.2986689012185817, 0.18804023732608074`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 277}], {
             RGBColor[
             0.9442574972371908, 0.8029244899485575, 0.3576036046538991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 281}], {
             RGBColor[
             0.9369826909775356, 0.800923138426649, 0.5779306345773171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 179}], {
             RGBColor[
             0.7150830892215184, 0.6470263643951079, 0.5999650595216117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 237}], {
             RGBColor[
             0.8525195804485002, 0.35269902313604284`, 0.19588243651989107`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 256}], {
             RGBColor[
             0.8477552075952007, 0.3160779656240866, 0.191320067694982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 269}], {
             RGBColor[
             0.9402871560451271, 0.7958786263011822, 0.2973043850963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 274}], {
             RGBColor[
             0.6852279869066359, 0.622788647378854, 0.5976147565045411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 277}], {
             RGBColor[
             0.9502103007628988, 0.8290380865568148, 0.362523350207251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 281}], {
             RGBColor[
             0.9429354945032435, 0.8270367350349062, 0.582850380130669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 293}], {
             RGBColor[
             0.9035840903340573, 0.6541630034729253, 0.24121312079051388`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 154}], {
             RGBColor[
             0.5475628360948273, 0.6435752036232633, 0.9575252987275946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 181}], {
             RGBColor[
             0.7920610111090953, 0.8249056195457978, 0.6813687144574905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 192}], {
             RGBColor[
             0.4642226762503304, 0.5725842955959759, 0.9518849903358793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 220}], {
             RGBColor[
             0.46545874896093703`, 0.5736549196510825, 0.9519637517959829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 239}], {
             RGBColor[
             0.41770207455751684`, 0.5257103442374987, 0.9491616700514242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 258}], {
             RGBColor[
             0.4689947888884989, 0.5767176597098022, 0.9521890651333698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 208}], {
             RGBColor[
             0.1859180316496269, 0.31274201752076575`, 0.9338991289101417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 242}], {
             RGBColor[
             0.1817008098525566, 0.3083094500247394, 0.9336589643676192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 244}], {
             RGBColor[
             0.1860116480511821, 0.312840414294423, 0.9339044602257174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 268}], {
             RGBColor[
             0.1937845276020504, 0.3210102035314135, 0.9343471142171944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 157}], {
             RGBColor[
             0.2018036290672552, 0.32943878761174283`, 0.9348037901824403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 192}], {
             RGBColor[
             0.2758432306623323, 0.4052369526728678, 0.9390942768006172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 220}], {
             RGBColor[
             0.27707930337293885`, 0.40630757672797435`, 0.9391730382607208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 222}], {
             RGBColor[
             0.2212473690290584, 0.3498753911159149, 0.9359110824088295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 239}], {
             RGBColor[
             0.22932262896951866`, 0.3583630013143907, 0.9363709565161622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 248}], {
             RGBColor[
             0.2215139470361167, 0.3501555815033551, 0.9359262636319645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 285}], {
             RGBColor[
             0.21037441724900163`, 0.3384472294101154, 0.9352918838900459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 181}], {
             RGBColor[
             0.7417957890267707, 0.7840980478369171, 0.6774116520475943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[
             0.7172113529376909, 0.7776981044453534, 0.9724416173890855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 216}], {
             RGBColor[
             0.7434083499065284, 0.5252723810458323, 0.4580470065820631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 255}], {
             RGBColor[
             0.43165774296703474`, 0.5471078244024314, 0.9490557746765065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 258}], {
             RGBColor[
             0.4187295668061743, 0.5359100880009214, 0.9482320027234739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 162}], {
             RGBColor[
             0.9588310572734952, 0.8681281277104613, 0.5263067793464253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 194}], {
             RGBColor[
             0.8061596900222359, 0.7500989808439875, 0.6144534337056413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 210}], {
             RGBColor[
             0.698996444284087, 0.6637676396684864, 0.6055600185754992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 218}], {
             RGBColor[
             0.9467517036363646, 0.8603082831521655, 0.5999961337585191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 226}], {
             RGBColor[
             0.9562854870849291, 0.8670754690193194, 0.5684934650954372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 227}], {
             RGBColor[
             0.9395091625151377, 0.7978810172888317, 0.27018585613847523`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 241}], {
             RGBColor[
             0.9562190222247212, 0.8670479840915544, 0.569594959834627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 290}], {
             RGBColor[
             0.9363623874102649, 0.7854051025986525, 0.2676538870247894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 291}], {
             RGBColor[
             0.9265943306289632, 0.845047396157727, 0.6262279650717502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.8545672117145955, 0.3449853666875312, 0.19687926573825648`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 159}], {
             RGBColor[
             0.3428661620319342, 0.4697766941100199, 0.9431273668629003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 168}], {
             RGBColor[
             0.3974514720884778, 0.5186742214563766, 0.9465462342423088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.4586241439822036, 0.5697734899723961, 0.9509650514168311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 191}], {
             RGBColor[
             0.31093411780431135`, 0.4362140910182484, 0.9413088841833633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 205}], {
             RGBColor[
             0.38342561820827703`, 0.5065257317852604, 0.945652519235638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 251}], {
             RGBColor[
             0.3400494072237743, 0.46681610621407393`, 0.942966956843591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 269}], {
             RGBColor[
             0.6838282108058124, 0.7186257518784704, 0.6483043769915192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 270}], {
             RGBColor[
             0.3036653348674415, 0.42857413928414156`, 0.9408949377483093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 271}], {
             RGBColor[
             0.3085633706783219, 0.433722285474784, 0.9411738736417443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 277}], {
             RGBColor[
             0.6937513555235839, 0.7517852121341029, 0.7135233421024703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 282}], {
             RGBColor[
             0.41756183526404816`, 0.5360928072628128, 0.9478276488009602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 171}], {
             RGBColor[
             0.1808430925709541, 0.30740793477935857`, 0.9336101186373109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 184}], {
             RGBColor[
             0.18701393581723674`, 0.31389388228526116`, 0.9339615390312422]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 222}], {
             RGBColor[
             0.20198183109515816`, 0.32962608924173, 0.9348139385243031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 248}], {
             RGBColor[
             0.20224840910221648`, 0.3299062796291701, 0.9348291197474383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 275}], {
             RGBColor[
             0.18135642915031058`, 0.30794748407168115`, 0.9336393523960919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 285}], {
             RGBColor[
             0.1911088793151014, 0.31819792753593046`, 0.9341947400055196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 186}], {
             RGBColor[
             0.19303082310645578`, 0.3202180123189185, 0.9343041918611762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 196}], {
             RGBColor[
             0.1980026870183727, 0.32544375652472224`, 0.9345873321557463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 207}], {
             RGBColor[
             0.189116703595207, 0.3161040245430854, 0.9340812885454315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 212}], {
             RGBColor[
             0.21315714444874106`, 0.34137205213213645`, 0.9354503560873951]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 214}], {
             RGBColor[
             0.19688801935015837`, 0.3242721701314169, 0.9345238534810445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 225}], {
             RGBColor[
             0.21027114178594725`, 0.3383386803504027, 0.9352860025052073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 265}], {
             RGBColor[
             0.20783074668686696`, 0.3357736703712833, 0.9351470256145558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 276}], {
             RGBColor[
             0.21715975035837445`, 0.34557904472303347`, 0.935678298572624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 168}], {
             RGBColor[
             0.3458261104083336, 0.4723404526223259, 0.943315972156065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 191}], {
             RGBColor[
             0.25930875612416715`, 0.38988032218419766`, 0.9380786220971196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 205}], {
             RGBColor[
             0.33180025652813283`, 0.4601919629512097, 0.9424222571493942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 212}], {
             RGBColor[
             0.2623047179263146, 0.3930292679932042, 0.9382492376896236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 225}], {
             RGBColor[
             0.2594187152635208, 0.38999589621147046`, 0.9380848841074358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 251}], {
             RGBColor[
             0.2884240455436301, 0.4204823373800232, 0.9397366947573472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 270}], {
             RGBColor[
             0.2520399731872973, 0.38224037045009085`, 0.9376646756620657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 271}], {
             RGBColor[
             0.2569380089981777, 0.38738851664073326`, 0.9379436115555007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 282}], {
             RGBColor[
             0.36593647358390397`, 0.4897590384287621, 0.9445973867147164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 176}], {
             RGBColor[
             0.19497852177206426`, 0.3222651671077009, 0.9344151104188206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 180}], {
             RGBColor[
             0.19532450559808373`, 0.32262881804548893`, 0.9344348136858753]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 193}], {
             RGBColor[
             0.23766407621559904`, 0.36713039124832314`, 0.9368459895967611]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 221}], {
             RGBColor[
             0.19098000658392586`, 0.31806247412446187`, 0.9341874008941293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 230}], {
             RGBColor[
             0.19392496192438957`, 0.3211578089082423, 0.9343551117440977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 232}], {
             RGBColor[
             0.19183608079529113`, 0.31896226239884673`, 0.9342361530540182]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 245}], {
             RGBColor[
             0.2105034515043503, 0.33858285259373117`, 0.935299232199999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 288}], {
             RGBColor[
             0.20231487113075944`, 0.32997613543510473`, 0.934832904661642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 296}], {
             RGBColor[
             0.1914857715941317, 0.31859406521754197`, 0.9342162034632482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 297}], {
             RGBColor[
             0.1938787777952211, 0.3211092664602433, 0.9343524816262648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 177}], {
             RGBColor[
             0.24681318446187503`, 0.3767466841021262, 0.9373670177764938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 244}], {
             RGBColor[
             0.19557921069497186`, 0.3228965292515542, 0.9344493187643406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 279}], {
             RGBColor[
             0.2191606879449377, 0.34768215699328187`, 0.9357922490080568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 280}], {
             RGBColor[
             0.2318337811627876, 0.36100238148576125`, 0.9365139629186521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 169}], {
             RGBColor[
             0.7980436197485294, 0.8403418316253028, 0.877535691789008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 181}], {
             RGBColor[
             0.9888211205061603, 0.9780593840975029, 0.5971500192561076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 202}], {
             RGBColor[
             0.9081632494131782, 0.6549039003842219, 0.40459878356064916`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 216}], {
             RGBColor[
             0.9080919042261215, 0.6545799385528897, 0.40453925138773855`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 227}], {
             RGBColor[
             0.9720263822129245, 0.9204431940139248, 0.5369240475267748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 228}], {
             RGBColor[
             0.7088026697373979, 0.7671572402491821, 0.8707133358632482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 299}], {
             RGBColor[
             0.8762453581797867, 0.42669348450426003`, 0.3747047266637896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 185}], {
             RGBColor[
             0.5753534134295759, 0.6661368462548543, 0.9597130747756251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 235}], {
             RGBColor[
             0.5148221170934733, 0.615777732139438, 0.9552841124586315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 274}], {
             RGBColor[
             0.5420984734158494, 0.6391389878337358, 0.9570951240808855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 292}], {
             RGBColor[
             0.6974329821497556, 0.7632343245346107, 0.9706993881593793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 298}], {
             RGBColor[
             0.44064408929894633`, 0.5470342917552059, 0.9507221073701924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 176}], {
             RGBColor[
             0.1880768897106564, 0.3150111142224146, 0.9340220726829731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 180}], {
             RGBColor[
             0.18842287353667586`, 0.3153747651602027, 0.9340417759500277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 187}], {
             RGBColor[
             0.2033506574299822, 0.3310648125082323, 0.9348918911590742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 221}], {
             RGBColor[
             0.184078374522518, 0.31080842123917557`, 0.9337943631582817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 230}], {
             RGBColor[
             0.1870233298629817, 0.313903756022956, 0.9339620740082502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 296}], {
             RGBColor[
             0.18458413953272382`, 0.31134001233225567`, 0.9338231657274008]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 297}], {
             RGBColor[
             0.18697714573381324`, 0.31385521357495705`, 0.9339594438904173]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 175}], {
             RGBColor[
             0.2002014223302363, 0.3277547667453615, 0.9347125468790196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 183}], {
             RGBColor[
             0.2052672821395783, 0.33307930659904317`, 0.9350010401008936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 224}], {
             RGBColor[
             0.21323098705618415`, 0.3414496653944509, 0.9354545613146487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 253}], {
             RGBColor[
             0.20482209384336109`, 0.3326113854731506, 0.9349756872860211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 262}], {
             RGBColor[
             0.26081704104435255`, 0.39146562526609985`, 0.9381645166920165]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 195}], {
             RGBColor[
             0.184909234384039, 0.31168170763319203`, 0.9338416793982484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 234}], {
             RGBColor[
             0.19012477797807242`, 0.3171635746350845, 0.9341386968902232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.21183524129599424`, 0.3399826481050988, 0.9353750756584267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 285}], {
             RGBColor[
             0.19288702957547718`, 0.3200668762008235, 0.9342960030323104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 168}], {
             RGBColor[
             0.6540467218133117, 0.5964674977433942, 0.5956559161356156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[
             0.8661367359765803, 0.45702825150686766`, 0.20890833900479755`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 202}], {
             RGBColor[
             0.8802744981433329, 0.5485728040784057, 0.22177612422766013`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.9224035575123126, 0.8121627962472151, 0.6179459955981152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 216}], {
             RGBColor[
             0.8802031529562763, 0.5482488422470734, 0.22171659205474953`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 237}], {
             RGBColor[
             0.8526104501055128, 0.35305929104558004`, 0.1959555523789085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 269}], {
             RGBColor[
             0.9404234605306463, 0.796419028165488, 0.2974140588848261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 277}], {
             RGBColor[
             0.9503466052484179, 0.8295784884211206, 0.3626330239957771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 282}], {
             RGBColor[
             0.674157084988882, 0.6138860835498305, 0.5969373306942671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 293}], {
             RGBColor[
             0.9037203948195764, 0.6547034053372311, 0.24132279457904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 203}], {
             RGBColor[
             0.6687682561638781, 0.7369332784725033, 0.9690249189979729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 205}], {
             RGBColor[
             0.3863855665846765, 0.5090894902975664, 0.9458411245288025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 212}], {
             RGBColor[
             0.31689002798285826`, 0.4419267953395609, 0.941668105069032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 225}], {
             RGBColor[
             0.31400402532006444`, 0.4388934235578272, 0.9415037514868442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 269}], {
             RGBColor[
             0.6867881591822118, 0.7211895103907764, 0.6484929822846838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 276}], {
             RGBColor[
             0.3208926338924916, 0.4461337879304579, 0.9418960475542608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 282}], {
             RGBColor[
             0.42052178364044757`, 0.5386565657751188, 0.9480162540941248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 293}], {
             RGBColor[
             0.650085093471142, 0.5794738875625195, 0.5924017179788976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 193}], {
             RGBColor[
             0.44215135474031986`, 0.5505814803014513, 0.9506292633518225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 200}], {
             RGBColor[
             0.4851546386974715, 0.5905268621408066, 0.9532706039694929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 202}], {
             RGBColor[
             0.7792934779313432, 0.5546715851773875, 0.4609259309301712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 227}], {
             RGBColor[
             0.7787217249901721, 0.7700947212036731, 0.6214147685810579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 228}], {
             RGBColor[
             0.5154980125146456, 0.6168087674389304, 0.9552040569175313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 264}], {
             RGBColor[
             0.450474457220526, 0.5593295887233245, 0.9511032517251437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 299}], {
             RGBColor[
             0.7473755866979517, 0.32646116929742564`, 0.43103187403331167`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 178}], {
             RGBColor[
             0.228293899528688, 0.35728174144686387`, 0.9363123718963757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 182}], {
             RGBColor[
             0.2259600378398488, 0.3548287048365162, 0.9361794619258352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 190}], {
             RGBColor[
             0.2009954787857768, 0.3285893704262217, 0.9347577672194614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 199}], {
             RGBColor[
             0.19798561422584082`, 0.3254258119372937, 0.9345863598854686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 261}], {
             RGBColor[
             0.22115645505495063`, 0.3497798347648488, 0.9359059049924991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 284}], {
             RGBColor[
             0.2192670906414149, 0.34779399297360003`, 0.9357983084842125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 184}], {
             RGBColor[
             0.1853189372548359, 0.31211233132706184`, 0.9338650113706392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 275}], {
             RGBColor[
             0.17966143058790973`, 0.3061659331134819, 0.9335428247354888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 285}], {
             RGBColor[
             0.18941388075270052`, 0.31641637657773114`, 0.9340982123449165]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 174}], {
             RGBColor[
             0.21189442021644855`, 0.34004484890265657`, 0.9353784458103991]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 238}], {
             RGBColor[
             0.18901379750666059`, 0.31599586371940025`, 0.9340754281959247]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 186}], {
             RGBColor[
             0.19720146830174806`, 0.32460162485334904`, 0.9345417039351314]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 213}], {
             RGBColor[
             0.20183100425593847`, 0.3294675606707361, 0.9348053491589379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 234}], {
             RGBColor[
             0.19772105404463286`, 0.3251477424127598, 0.9345712935745305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 249}], {
             RGBColor[
             0.20437181857140313`, 0.33213811761322165`, 0.9349500447754056]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 263}], {
             RGBColor[
             0.20558810816091344`, 0.33341651508901093`, 0.935019310668189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 286}], {
             RGBColor[
             0.2110888425781487, 0.3391981357282311, 0.9353325693556434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 235}], {
             RGBColor[
             0.3208493079592518, 0.4453409740728014, 0.9419209416251387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 238}], {
             RGBColor[
             0.21032414623090429`, 0.3383943913827284, 0.9352890210299346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 298}], {
             RGBColor[
             0.24667128016472487`, 0.3765975336885693, 0.9373589365366997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 183}], {
             RGBColor[
             0.18767445593923526`, 0.3145881308128762, 0.9339991546750381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 224}], {
             RGBColor[
             0.19563816085584113`, 0.3229584896082839, 0.9344526758887932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 253}], {
             RGBColor[
             0.18722926764301806`, 0.3141202096869836, 0.9339738018601655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 180}], {
             RGBColor[
             0.1945386218938126, 0.32180280444439524`, 0.9343900587715277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 187}], {
             RGBColor[
             0.20946640578711895`, 0.33749285179242483`, 0.9352401739805742]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 193}], {
             RGBColor[
             0.23687819251132788`, 0.36630437764722934`, 0.9368012346824135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 221}], {
             RGBColor[
             0.1901941228796547, 0.3172364605233681, 0.9341426459797817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 230}], {
             RGBColor[
             0.19313907822011844`, 0.32033179530714856`, 0.9343103568297502]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 245}], {
             RGBColor[
             0.20971756780007914`, 0.3377568389926374, 0.9352544772856515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 288}], {
             RGBColor[
             0.20152898742648828`, 0.32915012183401104`, 0.9347881497472945]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 296}], {
             RGBColor[
             0.19069988788986053`, 0.3177680516164482, 0.9341714485489008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 297}], {
             RGBColor[
             0.19309289409094996`, 0.3202832528591496, 0.9343077267119173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 194}], {
             RGBColor[
             0.4889886310377472, 0.5894215892292383, 0.9546385045000421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 226}], {
             RGBColor[
             0.6391144281004404, 0.7063980774045702, 0.908678535889838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 252}], {
             RGBColor[
             0.2649570005472917, 0.39581698519228203`, 0.9384002812611878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 268}], {
             RGBColor[
             0.24851062539069607`, 0.37853080214228807`, 0.9374636845262513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 279}], {
             RGBColor[
             0.2643192230897936, 0.3951466406470252, 0.9383639607784904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 280}], {
             RGBColor[
             0.27699231630764354`, 0.4084668651395046, 0.9390856746890857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 182}], {
             RGBColor[
             0.2566774713547828, 0.3871146750584845, 0.9379287743221401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 190}], {
             RGBColor[
             0.23171291230071078`, 0.36087534064819005`, 0.9365070796157662]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 199}], {
             RGBColor[
             0.2287030477407748, 0.357711782159262, 0.9363356722817735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 229}], {
             RGBColor[
             0.23836184028178953`, 0.36786378552268634`, 0.9368857262280812]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 261}], {
             RGBColor[
             0.2518738885698846, 0.38206580498681714`, 0.9376552173888041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 284}], {
             RGBColor[
             0.24998452415634886`, 0.38007996319556836`, 0.9375476208805174]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 205}], {
             RGBColor[
             0.44755823847840226`, 0.5601887588135859, 0.9502599417033248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 251}], {
             RGBColor[
             0.4041820274938994, 0.5204791332423994, 0.9475743793112779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 269}], {
             RGBColor[
             0.7479608310759376, 0.7722887789067958, 0.6529117994592061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 274}], {
             RGBColor[
             0.4929016619374462, 0.5991987999844676, 0.9532221708674471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 277}], {
             RGBColor[
             0.7578839757937091, 0.8054482391624284, 0.7181307645701571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 282}], {
             RGBColor[
             0.48169445553417334`, 0.5897558342911382, 0.9524350712686471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 289}], {
             RGBColor[
             0.383100677252795, 0.49832129750419296`, 0.9463738276021099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 187}], {
             RGBColor[
             0.20981238961313842`, 0.3378565027302129, 0.9352598772476289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 193}], {
             RGBColor[
             0.23722417633734735`, 0.3666680285850174, 0.9368209379494682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 215}], {
             RGBColor[
             0.2098131605219987, 0.33785731300430355`, 0.9352599211497481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 221}], {
             RGBColor[
             0.19054010670567417`, 0.3176001114611562, 0.9341623492468364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 230}], {
             RGBColor[
             0.1934850620461379, 0.3206954462449366, 0.9343300600968047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 233}], {
             RGBColor[
             0.20014010875548707`, 0.32769032229079487`, 0.9347090551616429]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 245}], {
             RGBColor[
             0.2100635516260986, 0.3381204899304254, 0.9352741805527061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 288}], {
             RGBColor[
             0.20187497125250775`, 0.32951377277179905`, 0.9348078530143491]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 296}], {
             RGBColor[
             0.19104587171588, 0.3181317025542363, 0.9341911518159554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 297}], {
             RGBColor[
             0.19343887791696943`, 0.3206469037969376, 0.9343274299789719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 201}], {
             RGBColor[
             0.8923407162696778, 0.5549387342539829, 0.2611343640187083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 202}], {
             RGBColor[
             0.9064784784364304, 0.6464832868255209, 0.2740021492415709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 203}], {
             RGBColor[
             0.961709527951959, 0.9590285203678879, 0.6962850331189814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 216}], {
             RGBColor[
             0.9064071332493737, 0.6461593249941886, 0.2739426170686603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 227}], {
             RGBColor[
             0.9694992257478029, 0.9078122736758734, 0.34102909604815745`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 258}], {
             RGBColor[
             0.6632277418204424, 0.717240503923456, 0.6720754184533696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 299}], {
             RGBColor[
             0.874560587203039, 0.4182728709455591, 0.2441080923447113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 190}], {
             RGBColor[
             0.22937905061187158`, 0.35842230403784237`, 0.9363741696452258]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 199}], {
             RGBColor[
             0.22636918605193562`, 0.35525874554891435`, 0.936202762311233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 229}], {
             RGBColor[
             0.23602797859295035`, 0.36541074891233866`, 0.9367528162575407]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 261}], {
             RGBColor[
             0.24954002688104543`, 0.37961276837646946`, 0.9375223074182637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 284}], {
             RGBColor[
             0.24765066246750966`, 0.3776269265852207, 0.937414710909977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 224}], {
             RGBColor[
             0.2007040206651831, 0.3282830294619655, 0.9347411691106672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 253}], {
             RGBColor[
             0.19229512745236005`, 0.31944474954066526`, 0.9342622950820396]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 222}], {
             RGBColor[
             0.2064576757790399, 0.33433048578943325`, 0.9350688312576314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 224}], {
             RGBColor[
             0.20007875304145373`, 0.32762583354516883`, 0.9347055610444963]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 248}], {
             RGBColor[
             0.20672425378609824`, 0.33461067617687346`, 0.9350840124807664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 275}], {
             RGBColor[
             0.18583227383419235`, 0.31265188061938454`, 0.9338942451294201]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 218}], {
             RGBColor[
             0.7483730046735189, 0.8020037075647066, 0.948265724399384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 235}], {
             RGBColor[
             0.4690251433139141, 0.5785976856950342, 0.951678806922862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 262}], {
             RGBColor[
             0.41669813660407123`, 0.5328210539055609, 0.9483611851595068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 292}], {
             RGBColor[
             0.6516360083701964, 0.726054278090207, 0.9670940826236099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 196}], {
             RGBColor[
             0.19808785672818557`, 0.32553327528980713`, 0.9345921824447229]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 214}], {
             RGBColor[
             0.19697318905997124`, 0.32436168889650174`, 0.9345287037700212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 249}], {
             RGBColor[
             0.20028634308592377`, 0.3278440238438759, 0.934717382990427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 265}], {
             RGBColor[
             0.2079159163966799, 0.33586318913636815`, 0.9351518759035322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 286}], {
             RGBColor[
             0.2070033670926693, 0.3349040419588854, 0.9350999075706646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 193}], {
             RGBColor[
             0.25215196023065367`, 0.38235807593304705`, 0.9376710531585147]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 215}], {
             RGBColor[
             0.224740944415305, 0.35354736035233314`, 0.9361100363587946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 228}], {
             RGBColor[
             0.32549861800497937`, 0.4485853630705261, 0.9422458467242234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 229}], {
             RGBColor[
             0.22122626051320093`, 0.3498532047273915, 0.9359098803100787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 230}], {
             RGBColor[
             0.20841284593944426`, 0.3363854935929662, 0.9351801753058513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 233}], {
             RGBColor[
             0.2150678926487934, 0.3433803696388245, 0.9355591703706895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 245}], {
             RGBColor[
             0.22499133551940492`, 0.35381053727845513`, 0.9361242957617526]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 288}], {
             RGBColor[
             0.2168027551458141, 0.3452038201198287, 0.9356579682233956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 296}], {
             RGBColor[
             0.20597365560918635`, 0.3338217499022659, 0.9350412670250019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 297}], {
             RGBColor[
             0.20836666181027574`, 0.33633695114496726`, 0.9351775451880184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 236}], {
             RGBColor[
             0.29364767479578224`, 0.42161628358526776`, 0.9401936825679285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 260}], {
             RGBColor[
             0.3070159863730502, 0.43566722665288543`, 0.9409549881356092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 261}], {
             RGBColor[
             0.30030042916823396`, 0.42860875023970424`, 0.9405725470875715]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 281}], {
             RGBColor[
             0.66716299452805, 0.7330554302274623, 0.9326197293964239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 294}], {
             RGBColor[
             0.445956916802145, 0.5584408477111231, 0.9502576320388609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 257}], {
             RGBColor[
             0.1999558217805158, 0.327496624995631, 0.9346985602910465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 260}], {
             RGBColor[
             0.23700170640282697`, 0.36643419857842796`, 0.936808268615812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 267}], {
             RGBColor[
             0.20602096440657885`, 0.33387147444787646`, 0.9350439611910263]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 287}], {
             RGBColor[
             0.22941840696730975`, 0.35846367006274493`, 0.9363764109314454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 300}], {
             RGBColor[
             0.22074088939765935`, 0.34934304891065115`, 0.9358822391430908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 199}], {
             RGBColor[
             0.2014046269978636, 0.3290194111386199, 0.9347810676048591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 261}], {
             RGBColor[
             0.2245754678269734, 0.353373433966175, 0.9361006127118898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 284}], {
             RGBColor[
             0.22268610341343767`, 0.3513875921749262, 0.9359930162036031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 205}], {
             RGBColor[
             0.29986821230051, 0.4266293598594382, 0.9406037744698572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 217}], {
             RGBColor[
             0.21370747825416658`, 0.3419504878548173, 0.9354816967834682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 225}], {
             RGBColor[
             0.22748667103589795`, 0.35643329311969896`, 0.9362664014278987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 246}], {
             RGBColor[
             0.2059132617802264, 0.3337582721588391, 0.9350378276857872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 251}], {
             RGBColor[
             0.25649200131600725`, 0.38691973428825177`, 0.9379182120778102]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 270}], {
             RGBColor[
             0.22010792895967446`, 0.34867776735831935`, 0.9358461929825286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 271}], {
             RGBColor[
             0.22500596477055484`, 0.35382591354896176`, 0.9361251288759636]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 278}], {
             RGBColor[
             0.21400334724237668`, 0.34226146492060344`, 0.9354985460846478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 282}], {
             RGBColor[
             0.3340044293562811, 0.4561964353369906, 0.9427789040351794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 295}], {
             RGBColor[
             0.21214976125282442`, 0.34031322852144436`, 0.9353929871046776]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 218}], {
             RGBColor[
             0.6489034320102649, 0.7179182155893853, 0.9413556495465901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 220}], {
             RGBColor[
             0.3318533670341157, 0.4618564399149144, 0.9423663809943715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 222}], {
             RGBColor[
             0.2760214326902352, 0.40542425430285495`, 0.93910442514248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 248}], {
             RGBColor[
             0.27628801069729353`, 0.4057044446902951, 0.9391196063656152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 262}], {
             RGBColor[
             0.31722856394081744`, 0.4487355619302395, 0.9414511103067129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 200}], {
             RGBColor[
             0.3225670309120143, 0.4511149836272068, 0.9418734544780243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 215}], {
             RGBColor[
             0.252152731139514, 0.38235888620713765`, 0.9376710970606339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 228}], {
             RGBColor[
             0.35291040472918833`, 0.4773968889253306, 0.9438069074260627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 230}], {
             RGBColor[
             0.2358246326636532, 0.3651970194477707, 0.9367412360076905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 245}], {
             RGBColor[
             0.2524031222436139, 0.38262206313325964`, 0.9376853564635919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 264}], {
             RGBColor[
             0.28788684943506876`, 0.4199177102097248, 0.939706102233675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 288}], {
             RGBColor[
             0.24421454187002306`, 0.3740153459746332, 0.9372190289252349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 210}], {
             RGBColor[
             0.5788422967306146, 0.6683006695271059, 0.9604448643230148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 226}], {
             RGBColor[
             0.8361313395314567, 0.8716084988779389, 0.9233783108429527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 241}], {
             RGBColor[
             0.8360648746712487, 0.8715810139501738, 0.9244798055821426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 280}], {
             RGBColor[
             0.4740092277386598, 0.5736772866128733, 0.9537854496422005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 290}], {
             RGBColor[
             0.8162082398567924, 0.7899381324572718, 0.622538732772305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 291}], {
             RGBColor[
             0.8064401830754907, 0.8495804260163464, 0.9811128108192658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 234}], {
             RGBColor[
             0.18893962070800485`, 0.3159178992009325, 0.934071203936976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 207}], {
             RGBColor[
             0.19417373721693681`, 0.32141928751397403`, 0.9343692791289782]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 212}], {
             RGBColor[
             0.2182141780704709, 0.3466873151030251, 0.9357383466709418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 214}], {
             RGBColor[
             0.20194505297188817`, 0.32958743310230554`, 0.9348118440645912]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 225}], {
             RGBColor[
             0.21532817540767707`, 0.3436539433212913, 0.935573993088754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 265}], {
             RGBColor[
             0.21288778030859679`, 0.34108893334217194`, 0.9354350161981024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 276}], {
             RGBColor[
             0.22221678398010425`, 0.35089430769392205`, 0.9359662891561706]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 198}], {
             RGBColor[
             0.9754663865596167, 0.9808663065126991, 0.9104194926535587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 204}], {
             RGBColor[
             0.7349750271013598, 0.7901370127560131, 0.9142536375891683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 226}], {
             RGBColor[
             0.9862994243091077, 0.9886024741101505, 0.8767175253588012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 243}], {
             RGBColor[
             0.9868796101505515, 0.9888423958656835, 0.8671023444932484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 254}], {
             RGBColor[
             0.6525617744919028, 0.7195772493628625, 0.9087750915707931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 283}], {
             RGBColor[
             0.646081244426157, 0.713693683071829, 0.9083720606763512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 204}], {
             RGBColor[
             0.7240997016369111, 0.7823833581016821, 0.9486564217578735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 226}], {
             RGBColor[
             0.975424098844659, 0.9808488194558194, 0.9111203095275062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 243}], {
             RGBColor[
             0.9760042846861029, 0.9810887412113525, 0.9015051286619535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 254}], {
             RGBColor[
             0.6416864490274542, 0.7118235947085315, 0.9431778757394982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 256}], {
             RGBColor[
             0.866815756563354, 0.4169101123137112, 0.4248082782495014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 283}], {
             RGBColor[
             0.6352059189617083, 0.705940028417498, 0.9427748448450561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 209}], {
             RGBColor[
             0.1894252090832627, 0.31642828337140966`, 0.9340988574765833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 229}], {
             RGBColor[
             0.20805355497894237`, 0.33600785601311617`, 0.9351597142171741]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 233}], {
             RGBColor[
             0.20189518711453486`, 0.32953502092454917`, 0.9348090042777849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 259}], {
             RGBColor[
             0.19177802866162308`, 0.31890124592564373`, 0.9342328470708863]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 261}], {
             RGBColor[
             0.22156560326703745`, 0.35020987547724697`, 0.9359292053778969]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 284}], {
             RGBColor[
             0.21967623885350168`, 0.3482240336859982, 0.9358216088696103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 210}], {
             RGBColor[
             0.4186246829308158, 0.5365148469090834, 0.9480331221442837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 211}], {
             RGBColor[
             0.31815152117452855`, 0.44647400293362227`, 0.9416219977306357]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 227}], {
             RGBColor[
             0.6591374011618665, 0.6706282245294286, 0.6126589597072597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 228}], {
             RGBColor[
             0.3959136886863399, 0.5173422707646859, 0.946448248043733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 231}], {
             RGBColor[
             0.2983755222047893, 0.4256881741456715, 0.9404957838452779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 245}], {
             RGBColor[
             0.2954064062007655, 0.4225674449726149, 0.9403266970812623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 264}], {
             RGBColor[
             0.3308901333922204, 0.45986309204908005`, 0.9423474428513454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 202}], {
             RGBColor[
             0.8524329734673737, 0.3954661457870175, 0.19750790475074864`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 203}], {
             RGBColor[
             0.8759510922102913, 0.5506721053262738, 0.4578210075797024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 216}], {
             RGBColor[
             0.8523973008738454, 0.3953041648713514, 0.19747813866429334`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 237}], {
             RGBColor[
             0.8386009494484636, 0.2977093892706047, 0.18459761882637282`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 269}], {
             RGBColor[
             0.8879643608891803, 0.5401762599384556, 0.244133049770843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 277}], {
             RGBColor[
             0.8945797907010281, 0.562282566775544, 0.2876123598448103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 293}], {
             RGBColor[
             0.8634956504151338, 0.4456991780529511, 0.2067388735669856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 299}], {
             RGBColor[
             0.8364740278506779, 0.2813609378470366, 0.18256087630231885`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 203}], {
             RGBColor[
             0.8900888543770439, 0.6422166578978118, 0.47068879280256504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 216}], {
             RGBColor[
             0.8665350630405979, 0.48684871744288943`, 0.21034592388715595`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 237}], {
             RGBColor[
             0.8527387116152162, 0.3892539418421428, 0.19746540404923543`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 269}], {
             RGBColor[
             0.902102123055933, 0.6317208125099938, 0.2570008349937056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 293}], {
             RGBColor[
             0.8776334125818863, 0.5372437306244892, 0.2196066587898482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 299}], {
             RGBColor[
             0.8506117900174305, 0.3729054904185747, 0.19542866152518146`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 216}], {
             RGBColor[
             0.8900175091899872, 0.6418926960664795, 0.4706292606296545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 237}], {
             RGBColor[
             0.8624248063392239, 0.4467031448649862, 0.4448682209538134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 255}], {
             RGBColor[
             0.651571481892223, 0.7220382969334023, 0.9679291557478935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 269}], {
             RGBColor[
             0.9551449948812127, 0.9368848088945971, 0.6707830617471834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 293}], {
             RGBColor[
             0.9184419291701429, 0.7951691860663403, 0.6146917974413972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 299}], {
             RGBColor[
             0.8581709631436525, 0.41400624201784997`, 0.4407947359057055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 226}], {
             RGBColor[
             0.734932739386402, 0.7901195256991334, 0.9149544544631159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 243}], {
             RGBColor[
             0.7355129252278461, 0.7903594474546665, 0.9053392735975632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 254}], {
             RGBColor[
             0.40119508956919725`, 0.5210943009518455, 0.9470120206751078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 283}], {
             RGBColor[
             0.3947145595034514, 0.515210734660812, 0.9466089897806659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 225}], {
             RGBColor[
             0.29997817143986366`, 0.426744933886711, 0.9406100364801734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 251}], {
             RGBColor[
             0.3289835017199729, 0.45723137505526373`, 0.9422618471300848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 269}], {
             RGBColor[
             0.6727623053020111, 0.7090410207196602, 0.647599267278013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 282}], {
             RGBColor[
             0.40649592976024684`, 0.5265080761040026, 0.947122539087454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 219}], {
             RGBColor[
             0.20337837440800324`, 0.33109394480949034`, 0.9348934695999689]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 254}], {
             RGBColor[
             0.27060222090313846`, 0.400822588016517, 0.9387557425033809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 283}], {
             RGBColor[
             0.26412169083739256`, 0.3949390217254835, 0.938352711608939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 212}], {
             RGBColor[
             0.20932819464730518`, 0.33734758312138824`, 0.935232303060627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 214}], {
             RGBColor[
             0.19305906954872248`, 0.3202477011206687, 0.9343058004542764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 225}], {
             RGBColor[
             0.20644219198451136`, 0.33431421133965444`, 0.9350679494784392]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 242}], {
             RGBColor[
             0.18509931747274389`, 0.3118814970113848, 0.9338525043489474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 244}], {
             RGBColor[
             0.18941015567136937`, 0.31641246128106837`, 0.9340980002070455]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 252}], {
             RGBColor[
             0.21362941037883332`, 0.3418684335680528, 0.935477250933459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 268}], {
             RGBColor[
             0.19718303522223768`, 0.3245822505180589, 0.9345406541985226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 279}], {
             RGBColor[
             0.21299163292133522`, 0.34119808902279597`, 0.9354409304507616]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 259}], {
             RGBColor[
             0.18280847530695815`, 0.30947367664736153`, 0.9337220442766032]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 211}], {
             RGBColor[
             0.3712058892361785, 0.49192848437614356`, 0.9451403247792249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 226}], {
             RGBColor[
             0.7289680937933078, 0.7852771577024377, 0.9144848957128108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 227}], {
             RGBColor[
             0.7121917692235163, 0.7160827059719499, 0.6161772867558488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 241}], {
             RGBColor[
             0.7289016289330998, 0.7852496727746727, 0.9155863904520005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 290}], {
             RGBColor[
             0.7090449941186435, 0.7036067912817707, 0.613645317642163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 291}], {
             RGBColor[
             0.6992769373373419, 0.7632490848408453, 0.9722193956891239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 231}], {
             RGBColor[
             0.25095672851015194`, 0.3811018116127316, 0.937602986480219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 264}], {
             RGBColor[
             0.28347133969758304`, 0.41527672951614025`, 0.9394546454862865]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 266}], {
             RGBColor[
             0.23444123912717205`, 0.36374298512871284`, 0.9366624537923354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 214}], {
             RGBColor[
             0.21709951040225656`, 0.3455157287097197, 0.9356748679962401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 225}], {
             RGBColor[
             0.23048263283804543`, 0.3595822389287055, 0.9364370170204028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 265}], {
             RGBColor[
             0.22804223773896515`, 0.3570172289495861, 0.9362980401297512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 276}], {
             RGBColor[
             0.23737124141047264`, 0.3668226033013362, 0.9368293130878194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 234}], {
             RGBColor[
             0.19826511451334394`, 0.3257195844608012, 0.9346022770133582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 249}], {
             RGBColor[
             0.2049158790401142, 0.33270995966126304`, 0.9349810282142335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 263}], {
             RGBColor[
             0.2061321686296245, 0.3339883571370523, 0.9350502941070169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 286}], {
             RGBColor[
             0.21163290304685975`, 0.3397699777762725, 0.935363552794471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 265}], {
             RGBColor[
             0.21177311264038245`, 0.33991734694886655`, 0.9353715375234006]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 276}], {
             RGBColor[
             0.22110211631188992`, 0.34972272130061666`, 0.9359028104814688]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 286}], {
             RGBColor[
             0.21086056333637188`, 0.3389581997713838, 0.9353195691905329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 229}], {
             RGBColor[
             0.2212270314220612, 0.34985401500148217`, 0.9359099242121978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 233}], {
             RGBColor[
             0.2150686635576537, 0.34338117991291517`, 0.9355592142728086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 259}], {
             RGBColor[
             0.20495150510474192`, 0.33274740491400967`, 0.9349830570659099]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 296}], {
             RGBColor[
             0.20597442651804665`, 0.33382256017635653`, 0.935041310927121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 237}], {
             RGBColor[
             0.8526673664281595, 0.38892998001081047`, 0.19740587187632483`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 269}], {
             RGBColor[
             0.9020307778688763, 0.6313968506786615, 0.25694130282079497`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 293}], {
             RGBColor[
             0.8775620673948297, 0.536919768793157, 0.2195471266169376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 299}], {
             RGBColor[
             0.8505404448303738, 0.37258152858724236`, 0.19536912935227085`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 223}], {
             RGBColor[
             0.19076430807847547`, 0.31783576131915836`, 0.9341751171833412]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 246}], {
             RGBColor[
             0.1922440281378487, 0.31939104092123016`, 0.9342593850516728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 247}], {
             RGBColor[
             0.19889732977739935`, 0.3263840827880864, 0.9346382807373675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 251}], {
             RGBColor[
             0.24282276767362948`, 0.3725525030506428, 0.9371397694436958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 270}], {
             RGBColor[
             0.20643869531729672`, 0.3343105361207104, 0.9350677503484142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 271}], {
             RGBColor[
             0.21133673112817714`, 0.3394586823113528, 0.9353466862418491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 278}], {
             RGBColor[
             0.20033411359999898`, 0.32789423368299453`, 0.9347201034505334]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 295}], {
             RGBColor[
             0.19848052761044668`, 0.32594599728383544`, 0.9346145444705631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 220}], {
             RGBColor[
             0.6501395047208716, 0.7189888396444919, 0.9414344110066938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 262}], {
             RGBColor[
             0.6355147016275733, 0.7058679616598169, 0.9405191403190352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 290}], {
             RGBColor[
             0.956800253470921, 0.9001474347654498, 0.6080814328251828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 292}], {
             RGBColor[
             0.8704525733936984, 0.8991011858444631, 0.9592520377831382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 250}], {
             RGBColor[
             0.1834940050025886, 0.3101942118225623, 0.933761084178619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 222}], {
             RGBColor[
             0.2772575054008418, 0.4064948783579615, 0.9391831866025837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 248}], {
             RGBColor[
             0.27752408340790014`, 0.40677506874540165`, 0.9391983678257189]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 262}], {
             RGBColor[
             0.318464636651424, 0.44980618598534605`, 0.9415298717668166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 230}], {
             RGBColor[
             0.18914056303198, 0.3161291023239095, 0.9340826473050587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 232}], {
             RGBColor[
             0.18705168190288157`, 0.31393355581451393`, 0.9339636886149794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 245}], {
             RGBColor[
             0.20571905261194073`, 0.33355414600939837`, 0.93502676776096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 288}], {
             RGBColor[
             0.19753047223834988`, 0.324947428850772, 0.9345604402226031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 296}], {
             RGBColor[
             0.18670137270172213`, 0.31356535863320917`, 0.9339437390242094]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 297}], {
             RGBColor[
             0.18909437890281156`, 0.31608055987591055`, 0.9340800171872259]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 248}], {
             RGBColor[
             0.22169214906401963`, 0.3503428831333422, 0.9359364119738274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 285}], {
             RGBColor[
             0.21055261927690455`, 0.33863453104010255`, 0.9353020322319088]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 246}], {
             RGBColor[
             0.1829700916045353, 0.3096435456231802, 0.9337312480856603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 247}], {
             RGBColor[
             0.18962339324408597`, 0.3166365874900364, 0.934110143771355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 270}], {
             RGBColor[
             0.19716475878398335`, 0.32456304082266046`, 0.9345396133824015]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 271}], {
             RGBColor[
             0.20206279459486376`, 0.3297111870133029, 0.9348185492758365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 278}], {
             RGBColor[
             0.1910601770666856, 0.31814673838494456`, 0.9341919664845209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 295}], {
             RGBColor[
             0.1892065910771333, 0.3161985019857855, 0.9340864075045505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 253}], {
             RGBColor[
             0.20025883236896588`, 0.32781510833607297`, 0.9347158162957947]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 262}], {
             RGBColor[
             0.2562537795699573, 0.3866693481290222, 0.9379046457017901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 265}], {
             RGBColor[
             0.22515623507617133`, 0.35398385716785236`, 0.9361336865475633]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 276}], {
             RGBColor[
             0.23448523874767882`, 0.3637892315196025, 0.9366649595056316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 241}], {
             RGBColor[
             0.9861906717339419, 0.9885575021255057, 0.8785198369719385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 243}], {
             RGBColor[
             0.9868373224355939, 0.9888249088088037, 0.8678031613671959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 290}], {
             RGBColor[
             0.9663340369194856, 0.9069146206326038, 0.576578764162101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 291}], {
             RGBColor[
             0.956565980138184, 0.9665569141916783, 0.9351528422090618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 241}], {
             RGBColor[
             0.9694143471641505, 0.9193630503950179, 0.5802122280149764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 290}], {
             RGBColor[
             0.9495577123496941, 0.837720168902116, 0.27827115520513895`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 291}], {
             RGBColor[
             0.9397896555683924, 0.8973624624611904, 0.6368452332520997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 299}], {
             RGBColor[
             0.8633640950075484, 0.3798620775565069, 0.20395744452515618`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 264}], {
             RGBColor[
             0.3612335072093944, 0.48614499734720384`, 0.9442808957993838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 233}], {
             RGBColor[
             0.2115539796555496, 0.3396870242879735, 0.9353590582240927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 259}], {
             RGBColor[
             0.2014368212026378, 0.32905324928906804`, 0.934782901017194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 284}], {
             RGBColor[
             0.22933503139451644`, 0.3583760370494225, 0.936371662815918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 245}], {
             RGBColor[
             0.20866400795240445`, 0.3366494807931788, 0.9351944786109285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 288}], {
             RGBColor[
             0.2004754275788136, 0.3280427636345524, 0.9347281510725716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 296}], {
             RGBColor[
             0.18964632804218584`, 0.3166606934169896, 0.9341114498741778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 297}], {
             RGBColor[
             0.19203933424327527`, 0.319175894659691, 0.9342477280371944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 232}], {
             RGBColor[
             0.20954424282732975`, 0.33757466345683984`, 0.9352446066848648]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 245}], {
             RGBColor[
             0.2282116135363889, 0.3571952536517242, 0.9363076858308454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 264}], {
             RGBColor[
             0.2636953407278438, 0.39449090072818943`, 0.9383284316009286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 266}], {
             RGBColor[
             0.21466524015743277`, 0.342957156340762, 0.9355362399069774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 240}], {
             RGBColor[
             0.184219115333836, 0.3109563487553536, 0.933802378139279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 245}], {
             RGBColor[
             0.206575126823306, 0.3344539342837832, 0.9350755199208491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 288}], {
             RGBColor[
             0.19838654644971515`, 0.32584721712515685`, 0.9346091923824922]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 297}], {
             RGBColor[
             0.18995045311417683`, 0.3169803481502954, 0.934128769347115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 259}], {
             RGBColor[
             0.1952784533382303, 0.32258041420050104`, 0.9344321910778048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[
             0.2158656276199601, 0.3442188396728392, 0.9356046001971543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 249}], {
             RGBColor[
             0.2008059288288086, 0.3283901414032867, 0.934746972629826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 263}], {
             RGBColor[
             0.20202221841831886`, 0.32966853887907605`, 0.9348162385226094]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 274}], {
             RGBColor[
             0.43577020330018756`, 0.5515998272739158, 0.9490608562281224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 298}], {
             RGBColor[
             0.33431581918328446`, 0.4594951311953859, 0.9426878395174293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 260}], {
             RGBColor[
             0.2447992469285118, 0.3746299080635468, 0.9372523270133223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 267}], {
             RGBColor[
             0.21381850493226368`, 0.3420671839329953, 0.9354880195885366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 294}], {
             RGBColor[
             0.38374017735760657`, 0.49740352912178454`, 0.9465549709165739]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 256}], {
             RGBColor[
             0.8226924771507464, 0.17542990005333894`, 0.16936364778802923`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 269}], {
             RGBColor[
             0.8744380750181129, 0.4362072994771681, 0.23118026314495393`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 277}], {
             RGBColor[
             0.8810535048299607, 0.45831360631425644`, 0.27465957321892126`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 281}], {
             RGBColor[
             0.8762036339901905, 0.45697937196631744`, 0.42154425983453325`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 293}], {
             RGBColor[
             0.8499693645440664, 0.3417302175916635, 0.19378608694109653`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 248}], {
             RGBColor[
             0.22976740900447992`, 0.35883049333181793`, 0.9363962860811601]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 258}], {
             RGBColor[
             0.28886880526886394`, 0.4180452286151569, 0.9398683740473033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 263}], {
             RGBColor[
             0.22373268173624067`, 0.3524876123490904, 0.9360526172908128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 285}], {
             RGBColor[
             0.21862787921736482`, 0.3471221412385783, 0.9357619063392415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 290}], {
             RGBColor[
             0.9662675720592777, 0.9068871357048387, 0.5776802589012907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 291}], {
             RGBColor[
             0.956499515277976, 0.9665294292639133, 0.9362543369482514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 250}], {
             RGBColor[
             0.18176798085569046`, 0.30838005100792065`, 0.933662789656877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 268}], {
             RGBColor[
             0.1929658134251674, 0.3201496830220325, 0.934300489656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 254}], {
             RGBColor[
             0.6530996726183891, 0.7197996840615158, 0.8998607275791879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 256}], {
             RGBColor[
             0.874424572290644, 0.42222750521570074`, 0.3959301794759612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 283}], {
             RGBColor[
             0.6466191425526432, 0.7139161177704824, 0.899457696684746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 279}], {
             RGBColor[
             0.21308524932289044`, 0.3412964857964532, 0.9354462617663373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 280}], {
             RGBColor[
             0.22575834254074034`, 0.3546167102889326, 0.9361679756769326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 264}], {
             RGBColor[
             0.26072622472382, 0.3913701715551329, 0.938159344836913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 288}], {
             RGBColor[
             0.2170539171587743, 0.34546780732004123`, 0.9356722715284729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 297}], {
             RGBColor[
             0.20861782382323596`, 0.3366009383451798, 0.9351918484930957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 270}], {
             RGBColor[
             0.19864447884335656`, 0.3261183204247322, 0.9346238812507333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 278}], {
             RGBColor[
             0.1925398971260588, 0.3197020179870163, 0.9342762343528525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 295}], {
             RGBColor[
             0.19068631113650653`, 0.3177537815878572, 0.9341706753728822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 251}], {
             RGBColor[
             0.24168185283923999`, 0.37135332922152087`, 0.9370747960317096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 270}], {
             RGBColor[
             0.20529778048290723`, 0.33311136229158844`, 0.935002776936428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 271}], {
             RGBColor[
             0.21019581629378764`, 0.33825950848223085`, 0.9352817128298629]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 278}], {
             RGBColor[
             0.19919319876560948`, 0.3266950598538726, 0.9346551300385472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 289}], {
             RGBColor[
             0.22060050259813557`, 0.34919549348331447`, 0.9358742443225416]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 295}], {
             RGBColor[
             0.1973396127760572, 0.3247468234547135, 0.9345495710585769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 285}], {
             RGBColor[
             0.21081919728396287`, 0.3389147214275427, 0.9353172134550438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 258}], {
             RGBColor[
             0.2738091064777124, 0.40221653034560445`, 0.9390107464799751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 263}], {
             RGBColor[
             0.20867298294508915`, 0.33665891407953785`, 0.9351949897234846]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 286}], {
             RGBColor[
             0.2141737173623244, 0.342440534718758, 0.9355082484109388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 270}], {
             RGBColor[
             0.24922321837913736`, 0.37927978255414485`, 0.9375042656427561]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 271}], {
             RGBColor[
             0.25412125419001774`, 0.38442792874478726`, 0.9377832015361911]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 278}], {
             RGBColor[
             0.24311863666183964`, 0.372863480116429, 0.9371566187448754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 282}], {
             RGBColor[
             0.363119718775744, 0.4867984505328162, 0.944436976695407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 289}], {
             RGBColor[
             0.26452594049436573`, 0.3953639137458709, 0.9383757330288698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 295}], {
             RGBColor[
             0.24126505067228732`, 0.3709152437172699, 0.9370510597649051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 268}], {
             RGBColor[
             0.22149590633125682`, 0.35013661957870057`, 0.9359252362405117]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 279}], {
             RGBColor[
             0.23730450403035436`, 0.36675245808343765`, 0.9368255124927507]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 280}], {
             RGBColor[
             0.2499775972482043, 0.3800726825759171, 0.937547226403346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 283}], {
             RGBColor[
             0.27188152915805053`, 0.4030951038026612, 0.9387946229216484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 283}], {
             RGBColor[
             0.3123013068939945, 0.44465097126766145`, 0.9411304437622906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 258}], {
             RGBColor[
             0.3530896957607064, 0.48025028048897034`, 0.9437195410822816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 286}], {
             RGBColor[
             0.2934543066453184, 0.4204742848621239, 0.9402170430132455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 269}], {
             RGBColor[
             0.8696737021648134, 0.3995862419652118, 0.22661789432004487`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 277}], {
             RGBColor[
             0.8762891319766611, 0.42169254880230017`, 0.2700972043940122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 281}], {
             RGBColor[
             0.8714392611368911, 0.42035831445436117`, 0.41698189100962424`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 293}], {
             RGBColor[
             0.8452049916907669, 0.30510916007970723`, 0.18922371811618746`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 267}], {
             RGBColor[
             0.19014093188722048`, 0.31718055341781604`, 0.9341396168314517]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 272}], {
             RGBColor[
             0.18158199985616474`, 0.30818457318554265`, 0.9336521983140883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 300}], {
             RGBColor[
             0.20486085687830097`, 0.33265212788059073`, 0.9349778947835161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 263}], {
             RGBColor[
             0.2750253960672227, 0.40349492782139373`, 0.9390800123727585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 286}], {
             RGBColor[
             0.28052613048445796`, 0.4092765484606139, 0.9393932710602128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 267}], {
             RGBColor[
             0.22718681650953165`, 0.35611812700061296`, 0.9362493251562173]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 287}], {
             RGBColor[
             0.25058425907026255`, 0.38071032261548143`, 0.9375817748966364]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 294}], {
             RGBColor[
             0.39710848893487455`, 0.5114544721894022, 0.9473162764842546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 300}], {
             RGBColor[
             0.24190674150061214`, 0.37158970146338766`, 0.9370876031082818]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 284}], {
             RGBColor[
             0.2428470796826115, 0.3725780565135533, 0.937141153976641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 292}], {
             RGBColor[
             0.5387777053242508, 0.6299185321853173, 0.9593474985432611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 286}], {
             RGBColor[
             0.2153900069518347, 0.3437189321945473, 0.9355775143037223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 288}], {
             RGBColor[
             0.2525376443502292, 0.38276345439650644`, 0.937693017298556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 276}], {
             RGBColor[
             0.23204484364859856`, 0.36122422154048306`, 0.93652598261498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 286}], {
             RGBColor[
             0.22180329067308052`, 0.3504597000112502, 0.9359427413240442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 272}], {
             RGBColor[
             0.18764714248222777`, 0.31455942263778813`, 0.9339975992140681]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 287}], {
             RGBColor[
             0.2196035170740144, 0.34814759848492993`, 0.9358174674718507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 300}], {
             RGBColor[
             0.210925999504364, 0.33902697733283615`, 0.935323295683496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 279}], {
             RGBColor[
             0.22085812887375872`, 0.34946627503344374`, 0.9358889157578143]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 280}], {
             RGBColor[
             0.23353122209160865`, 0.3627864995259231, 0.9366106296684096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 277}], {
             RGBColor[
             0.9830880426173179, 0.9543005010685027, 0.41547009014484526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 282}], {
             RGBColor[
             0.7068985223577822, 0.7386080961972126, 0.6497743968433352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 293}], {
             RGBColor[
             0.9364618321884765, 0.7794254179846133, 0.2941598607281082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 271}], {
             RGBColor[
             0.217737181833685, 0.3461859618148549, 0.9357111824409096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 278}], {
             RGBColor[
             0.20673456430550685`, 0.3346215131864966, 0.9350845996495938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 289}], {
             RGBColor[
             0.22814186813803294`, 0.35712194681593845`, 0.9363037139335881]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 295}], {
             RGBColor[
             0.20488097831595456`, 0.3326732767873375, 0.9349790406696236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 278}], {
             RGBColor[
             0.21163260011638724`, 0.339769659377139, 0.9353635355430288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 289}], {
             RGBColor[
             0.23303990394891333`, 0.36227009300658086`, 0.9365826498270231]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 295}], {
             RGBColor[
             0.20977901412683497`, 0.3378214229779799, 0.9352579765630585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 274}], {
             RGBColor[
             0.3509883555182567, 0.4717110997619036, 0.9438949792783465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 289}], {
             RGBColor[
             0.24118737083360547`, 0.370833597281629, 0.9370466360130092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 289}], {
             RGBColor[
             0.3532455749379125, 0.4740835804879391, 0.944023524585039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 281}], {
             RGBColor[
             0.9857363810754343, 0.9854586098022267, 0.7010160851792143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 282}], {
             RGBColor[
             0.7168216670755537, 0.7717675564528452, 0.7149933619542863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 293}], {
             RGBColor[
             0.946384976906248, 0.8125848782402458, 0.35937882583905917`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 295}], {
             RGBColor[
             0.1987763965986568, 0.3262569743496216, 0.9346313937717428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 280}], {
             RGBColor[
             0.24933981979070619`, 0.37940233803066026`, 0.9375109059206487]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 294}], {
             RGBColor[
             0.7572554970898742, 0.8088426757639791, 0.9389810177450694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 293}], {
             RGBColor[
             0.6701954566467123, 0.5968924733689558, 0.5936831325375491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 300}], {
             RGBColor[
             0.2343234420650949, 0.3636191729477046, 0.9366557454239152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 296}], {
             RGBColor[
             0.1980362372485557, 0.3254790199438521, 0.9345892427917222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 297}], {
             RGBColor[
             0.20042924344964513`, 0.3279942211865534, 0.9347255209547387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 291}], {
             RGBColor[
             0.9366428804635196, 0.8848865477710113, 0.6343132641384139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 297}], {
             RGBColor[
             0.18960014391301738`, 0.31661215096899065`, 0.934108819756345]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.09631744162763219], {
             RGBColor[
             0.8186934053129894, 0.1446912815038851, 0.16553413207988746`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.09631744162763219], {
             RGBColor[
             0.19859115798198185`, 0.32606227681868954`, 0.934620844706559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.09631744162763219], {
             RGBColor[
             0.9542183694281502, 0.96537671539683, 0.9623805381832607]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.09631744162763219], {
             RGBColor[
             0.2205376694136581, 0.34912945182257465`, 0.935870666065639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.09631744162763219], {
             RGBColor[
             0.9710126878169619, 0.9138811308413543, 0.3418901952738247]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.09631744162763219], {
             RGBColor[
             0.2105950138195758, 0.3386790903924193, 0.9353044465383967]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.09631744162763219], {
             RGBColor[
             0.9383196861766793, 0.9535195034595876, 0.9892928618873055]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.09631744162763219], {
             RGBColor[
             0.2044682273202984, 0.33223944932097826`, 0.9349555351110312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.09631744162763219], {
             RGBColor[
             0.19896010530687766`, 0.32645006384976655`, 0.9346418557109033]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.09631744162763219], {
             RGBColor[
             0.19040293767796423`, 0.3174559381160143, 0.9341545376736317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.09631744162763219], {
             RGBColor[
             0.5318148081413353, 0.630790245090044, 0.9562855562801685]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.09631744162763219], {
             RGBColor[
             0.42962012936485927`, 0.5465370955454517, 0.948595992638333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.09631744162763219], {
             RGBColor[
             0.33328873930237535`, 0.463099687229773, 0.9424578416460552]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.09631744162763219], {
             RGBColor[
             0.1801938510546308, 0.30672554078141306`, 0.9335731452934231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.09631744162763219], {
             RGBColor[
             0.2583760710911756, 0.38890001107887695`, 0.9380255070642746]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.09631744162763219], {
             RGBColor[
             0.24679037784549854`, 0.37672271290229153`, 0.9373657189734305]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.09631744162763219], {
             RGBColor[
             0.7036631405833589, 0.768426260552445, 0.9710982238135836]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.09631744162763219], {
             RGBColor[
             0.19997475001447043`, 0.3275165197696367, 0.9346996382259684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.09631744162763219], {
             RGBColor[
             0.18771789764902583`, 0.31463379080422954`, 0.9340016286161444]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.09631744162763219], {
             RGBColor[
             0.21900416978762977`, 0.3475176464861269, 0.9357833355305459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.09631744162763219], {
             RGBColor[
             0.19357781768564236`, 0.320792938303103, 0.9343353423932549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.09631744162763219], {
             RGBColor[
             0.18854143418810532`, 0.3154993799220345, 0.9340485278037318]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.09631744162763219], {
             RGBColor[
             0.989346654985427, 0.9898625823050647, 0.82621702707199]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.09631744162763219], {
             RGBColor[
             0.9237640134240451, 0.7354567479025522, 0.2575169395936321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.09631744162763219], {
             RGBColor[
             0.1911156300253715, 0.31820502296044406`, 0.9341951244484827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.09631744162763219], {
             RGBColor[
             0.2290956026577889, 0.35812438226646315`, 0.9363580277035645]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.09631744162763219], {
             RGBColor[
             0.9698415036520304, 0.9099304516459211, 0.33734036595263717`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.09631744162763219], {
             RGBColor[
             0.18347004528514485`, 0.31016902864039503`, 0.9337597197081559]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.09631744162763219], {
             RGBColor[
             0.19525519293228838`, 0.32255596603906117`, 0.934430866432097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.09631744162763219], {
             RGBColor[
             0.24929644188312317`, 0.37935674509947226`, 0.9375084356129837]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.09631744162763219], {
             RGBColor[
             0.41964854701834464`, 0.537900212103202, 0.9479606122287372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.09631744162763219], {
             RGBColor[
             0.9876761626712638, 0.9891717908034641, 0.8539014078132029]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.09631744162763219], {
             RGBColor[
             0.20050642775524471`, 0.3280753467855062, 0.9347299164867587]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.09631744162763219], {
             RGBColor[
             0.1836929464736069, 0.31040331192222026`, 0.933772413601086]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.09631744162763219], {
             RGBColor[
             0.20639345636736367`, 0.33426298711601565`, 0.9350651740571405]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.09631744162763219], {
             RGBColor[
             0.18133311757286624`, 0.3079229821257478, 0.9336380248362428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.09631744162763219], {
             RGBColor[
             0.22656828106141946`, 0.3554680070272346, 0.9362141004774884]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.09631744162763219], {
             RGBColor[
             0.18611948239069784`, 0.312953755022346, 0.9339106012318261]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.09631744162763219], {
             RGBColor[
             0.20172422019829714`, 0.3293553238556548, 0.934799267964828]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.09631744162763219], {
             RGBColor[
             0.6892336433588957, 0.7571538276524538, 0.9696600263815672]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.09631744162763219], {
             RGBColor[
             0.1885946642534308, 0.31555532809567266`, 0.9340515591772053]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.09631744162763219], {
             RGBColor[
             0.8376047344232163, 0.2900520440423452, 0.18364364219313192`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.09631744162763219], {
             RGBColor[
             0.2255865897625529, 0.3544361872293025, 0.9361581946103001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.09631744162763219], {
             RGBColor[
             0.31621931418873805`, 0.44831500913059213`, 0.9413701929717141]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.09631744162763219], {
             RGBColor[
             0.29993474933268105`, 0.43258081688308847`, 0.9403922123095734]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.09631744162763219], {
             RGBColor[
             0.2047087295239663, 0.33249223238575365`, 0.9349692313557391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.09631744162763219], {
             RGBColor[
             0.18409960782193097`, 0.31083073878312756`, 0.9337955723632715]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.09631744162763219], {
             RGBColor[
             0.1928098846058197, 0.31998579194643995`, 0.9342916097404141]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.09631744162763219], {
             RGBColor[
             0.20962180710681122`, 0.3376561884324342, 0.9352490238558351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.09631744162763219], {
             RGBColor[
             0.1818234123124711, 0.30843831298355445`, 0.9336659463963373]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.09631744162763219], {
             RGBColor[
             0.8112967405816618, 0.8525104469167772, 0.981826135168235]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.09631744162763219], {
             RGBColor[
             0.1987330571876369, 0.3262114218807623, 0.9346289256564001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.09631744162763219], {
             RGBColor[
             0.21587739356825456`, 0.3442312064305009, 0.9356052702505034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.09631744162763219], {
             RGBColor[
             0.24403688677483204`, 0.37382861920560384`, 0.937208911730381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.09631744162763219], {
             RGBColor[
             0.20213692733288047`, 0.32978910522124555`, 0.9348227710255971]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.09631744162763219], {
             RGBColor[
             0.19935669202797407`, 0.3268669016386893, 0.9346644407379722]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.09631744162763219], {
             RGBColor[
             0.17967566298483006`, 0.30618089226503126`, 0.9335436352494385]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.09631744162763219], {
             RGBColor[
             0.19114091674596853`, 0.31823160090706226`, 0.9341965644898124]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.09631744162763219], {
             RGBColor[
             0.985007685890186, 0.9880683070777632, 0.8981249738722014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.09631744162763219], {
             RGBColor[
             0.28726741181117993`, 0.4192666419924039, 0.9396708261773704]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.09631744162763219], {
             RGBColor[
             0.2772592389822082, 0.4087474177943471, 0.9391008755405253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.09631744162763219], {
             RGBColor[
             0.20167701950442632`, 0.3293057129336997, 0.9347965799551393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.09631744162763219], {
             RGBColor[
             0.18288267188311363`, 0.3095516619532356, 0.9337262696618512]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.09631744162763219], {
             RGBColor[
             0.2353045398184947, 0.3646503688917182, 0.9367116174895672]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.09631744162763219], {
             RGBColor[
             0.3774633879291902, 0.5013615475879224, 0.9452726111944477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.09631744162763219], {
             RGBColor[
             0.3863417480503173, 0.5090515368854881, 0.9458383324505404]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.09631744162763219], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.09631744162763219], {
             RGBColor[
             0.8768566069289154, 0.9046456729993274, 0.9881165600196555]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.09631744162763219], {
             RGBColor[
             0.20756886290590398`, 0.3354984139131004, 0.9351321117206522]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.09631744162763219], {
             RGBColor[
             0.20976983040282712`, 0.33781177030176596`, 0.9352574535635624]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.09631744162763219], {
             RGBColor[
             0.22331684544677569`, 0.35205054204331915`, 0.9360289360293025]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.09631744162763219], {
             RGBColor[
             0.8294154563220671, 0.22710566399236717`, 0.1758015802350048]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.09631744162763219], {
             RGBColor[
             0.1826688110543663, 0.3093268806626624, 0.9337140906040328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.09631744162763219], {
             RGBColor[
             0.20590138873724428`, 0.3337457928378705, 0.935037151533554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.09631744162763219], {
             RGBColor[
             0.3329293714790703, 0.46278842088357813`, 0.9424349430461306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.09631744162763219], {
             RGBColor[
             0.3269177544061254, 0.4575814603276529, 0.9420518881221068]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.09631744162763219], {
             RGBColor[
             0.4137826929511934, 0.5328195041366336, 0.9475868451945494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.09631744162763219], {
             RGBColor[
             0.19413140389541048`, 0.3213747925089622, 0.9343668683089438]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.09631744162763219], {
             RGBColor[
             0.18314084159618357`, 0.3098230146905773, 0.9337409720450827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.09631744162763219], {
             RGBColor[
             0.9788084084452291, 0.9401779270427488, 0.37217509781633024`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.09631744162763219], {
             RGBColor[
             0.8894648943465696, 0.5909677260051436, 0.2294791371904563]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.09631744162763219], {
             RGBColor[
             0.6134396494628491, 0.6970569684320459, 0.962711362790644]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.09631744162763219], {
             RGBColor[
             0.846552585818907, 0.35882915084310774`, 0.19221211479479816`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.09631744162763219], {
             RGBColor[
             0.18746791982634672`, 0.31437104826308443`, 0.9339873927489519]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.09631744162763219], {
             RGBColor[
             0.23214849009490668`, 0.36133316052711717`, 0.9365318851267661]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.09631744162763219], {
             RGBColor[
             0.5941770672605392, 0.6814187364307716, 0.9611949417585145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.09631744162763219], {
             RGBColor[
             0.9931480500222558, 0.9877526967730439, 0.4955857141352578]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.09631744162763219], {
             RGBColor[
             0.22285845764454237`, 0.35156874739970667`, 0.9360028315220893]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.09631744162763219], {
             RGBColor[
             0.3807443443279537, 0.5042033471148679, 0.9454816708349412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.09631744162763219], {
             RGBColor[
             0.21567607897691587`, 0.34401961203092163`, 0.935593805682345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.09631744162763219], {
             RGBColor[
             0.49015879412300467`, 0.5969720163279171, 0.9530062422656385]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.09631744162763219], {
             RGBColor[
             0.8315546894535105, 0.24354874725857717`, 0.17785011229759332`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.09631744162763219], {
             RGBColor[
             0.24113006344271598`, 0.3707733635803057, 0.9370433724418767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.09631744162763219], {
             RGBColor[
             0.796888814031874, 0.8412548651917855, 0.9803900876994809]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.09631744162763219], {
             RGBColor[
             0.28755638833203334`, 0.4195703746379904, 0.9396872829627306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.09631744162763219], {
             RGBColor[
             0.20095046543520778`, 0.32854205854076235`, 0.9347552037757377]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.09631744162763219], {
             RGBColor[
             0.44885816070930806`, 0.563200111364443, 0.9498218229840781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.09631744162763219], {
             RGBColor[
             0.1790520430393593, 0.3055254281625532, 0.9335081210161069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.09631744162763219], {
             RGBColor[
             0.19567419878950365`, 0.3229963677615002, 0.9344547281958019]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.09631744162763219], {
             RGBColor[
             0.1806628381309981, 0.3072184759341732, 0.933599853413618]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.09631744162763219], {
             RGBColor[
             0.6473280227603806, 0.724416838346381, 0.9654832657505968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.09631744162763219], {
             RGBColor[
             0.19219534584531597`, 0.31933987274514264`, 0.9342566126671321]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.09631744162763219], {
             RGBColor[
             0.4213296380105047, 0.5393562886265211, 0.9480677298602272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.09631744162763219], {
             RGBColor[
             0.3350878162698179, 0.46465795727473413`, 0.9425724772395593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.09631744162763219], {
             RGBColor[
             0.28384023029084227`, 0.41566445691867016`, 0.9394756532598479]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.09631744162763219], {
             RGBColor[
             0.861860606843299, 0.8926882695866354, 0.9866862281444021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.09631744162763219], {
             RGBColor[
             0.40847529455142584`, 0.5282225024003548, 0.9472486624616643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.09631744162763219], {
             RGBColor[
             0.24068546665888524`, 0.3703060641714354, 0.9370180533127597]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.09631744162763219], {
             RGBColor[
             0.9928111618057213, 0.9912952449090205, 0.7688011832034702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.09631744162763219], {
             RGBColor[
             0.18591721951216156`, 0.3127411639127972, 0.9338990826601146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.09631744162763219], {
             RGBColor[
             0.6142037164471443, 0.6976772724307221, 0.9627715129425172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.09631744162763219], {
             RGBColor[
             0.18923133529375677`, 0.3162245097263307, 0.9340878166510814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.09631744162763219], {
             RGBColor[
             0.2676326072490897, 0.3986292174791347, 0.9385526531046497]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.09631744162763219], {
             RGBColor[
             0.23913206195702244`, 0.3686733373382309, 0.9369295892130448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.09631744162763219], {
             RGBColor[
             0.3517287364030146, 0.47907148589714393`, 0.9436328219554587]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.09631744162763219], {
             RGBColor[
             0.2873518174774419, 0.41935535769927346`, 0.9396756329551971]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.09631744162763219], {
             RGBColor[
             0.1855098238772711, 0.3123129652701522, 0.9338758820813954]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.09631744162763219], {
             RGBColor[
             0.1887209958010121, 0.3156881105620633, 0.9340587535719493]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.09631744162763219], {
             RGBColor[
             0.18085158366002294`, 0.307416859452336, 0.933610602192272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.09631744162763219], {
             RGBColor[
             0.27909030860477735`, 0.41067198806418675`, 0.939205152246706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.09631744162763219], {
             RGBColor[
             0.22544944565233713`, 0.35429204007402687`, 0.9361503844561099]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.09631744162763219], {
             RGBColor[
             0.18504035865818397`, 0.31181952755907755`, 0.93384914673168]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.09631744162763219], {
             RGBColor[
             0.19860317371820202`, 0.3260749061192986, 0.9346215289849611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.09631744162763219], {
             RGBColor[
             0.1859244664032461, 0.3127487808548065, 0.9338994953598411]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.09631744162763219], {
             RGBColor[
             0.8351944719959239, 0.27152571084244637`, 0.18133557217075477`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.09631744162763219], {
             RGBColor[
             0.22348836128871713`, 0.3522308160679321, 0.9360387036027661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.09631744162763219], {
             RGBColor[
             0.34883524619319184`, 0.47656529010844195`, 0.9434484513179017]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.09631744162763219], {
             RGBColor[
             0.8449402545684014, 0.34643606632366236`, 0.19066814456844627`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.09631744162763219], {
             RGBColor[
             0.18908769389738214`, 0.3160735335113504, 0.9340796364860563]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.09631744162763219], {
             RGBColor[
             0.9118031822514008, 0.6880360380137298, 0.24789297407533079`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.09631744162763219], {
             RGBColor[
             0.22940782651350908`, 0.3584525493349609, 0.9363758083902539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.09631744162763219], {
             RGBColor[
             0.19689631111946682`, 0.3242808853066886, 0.9345243256850401]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.09631744162763219], {
             RGBColor[
             0.18528931800943133`, 0.31208119962217307`, 0.9338633245984311]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.09631744162763219], {
             RGBColor[
             0.24479905803441923`, 0.3746297095238789, 0.9372523162560832]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.09631744162763219], {
             RGBColor[
             0.21307650899259664`, 0.34128729915514544`, 0.9354457640174572]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.09631744162763219], {
             RGBColor[
             0.39261549520966454`, 0.5144855413472138, 0.9462380900718772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.09631744162763219], {
             RGBColor[
             0.26153416243522165`, 0.3922193653160256, 0.9382053556943405]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.09631744162763219], {
             RGBColor[
             0.231287806205471, 0.36042852718880986`, 0.9364828704525304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.09631744162763219], {
             RGBColor[
             0.4407231525670485, 0.5561539761890157, 0.9493034674587586]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.09631744162763219], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.09631744162763219], {
             RGBColor[
             0.2938477713702168, 0.42618301710784506`, 0.940045567919488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.09631744162763219], {
             RGBColor[
             0.8299355921400753, 0.23110365581454728`, 0.17629966288173887`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.09631744162763219], {
             RGBColor[
             0.3068945586163886, 0.4398960177176607, 0.9407885631521654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.09631744162763219], {
             RGBColor[
             0.19763991012936863`, 0.32506245501299574`, 0.9345666725485978]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.09631744162763219], {
             RGBColor[
             0.8649038628242013, 0.8951148792988238, 0.9869764966166072]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.09631744162763219], {
             RGBColor[
             0.20002902465321373`, 0.3275735658561667, 0.9347027290863527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.09631744162763219], {
             RGBColor[
             0.21339775345539977`, 0.34162494745362687`, 0.9354640584143752]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.09631744162763219], {
             RGBColor[
             0.2462972527349853, 0.37620440714520426`, 0.9373376362279]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.09631744162763219], {
             RGBColor[
             0.895503807139292, 0.6183890185729798, 0.2345181540520019]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.09631744162763219], {
             RGBColor[
             0.9074094141907081, 0.6706162117894943, 0.24435764515870567`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.09631744162763219], {
             RGBColor[
             0.5978280581771518, 0.684382775332144, 0.9614823611374906]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.09631744162763219], {
             RGBColor[
             0.1825195240294396, 0.3091699705341204, 0.9337055889288136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.09631744162763219], {
             RGBColor[
             0.22106916700115545`, 0.3496880894859278, 0.9359009340669666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.09631744162763219], {
             RGBColor[
             0.4972976140125026, 0.6027676319143825, 0.9535682363176986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.09631744162763219], {
             RGBColor[
             0.9263138375757084, 0.7455659509853682, 0.2595685879581257]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.09631744162763219], {
             RGBColor[
             0.3944915237120784, 0.5161104629440706, 0.9463576289491441]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.09631744162763219], {
             RGBColor[
             0.18253809113335498`, 0.30918948573755783`, 0.933706646297914]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.09631744162763219], {
             RGBColor[
             0.19294565339664288`, 0.32012849355383366`, 0.9342993415721996]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.09631744162763219], {
             RGBColor[
             0.29124080035179, 0.42344292527596916`, 0.9398971047766567]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.09631744162763219], {
             RGBColor[
             0.19576440547633542`, 0.32309118070879467`, 0.9344598653331682]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.09631744162763219], {
             RGBColor[
             0.2016546493170191, 0.3292822004483829, 0.9347953060060602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.09631744162763219], {
             RGBColor[
             0.9913482769712819, 0.9906903044355545, 0.7930449707347249]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.09631744162763219], {
             RGBColor[
             0.6211503872091352, 0.7033168926992579, 0.9633183803113946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.09631744162763219], {
             RGBColor[
             0.18196114135351968`, 0.30858307493822207`, 0.9336737898614731]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.09631744162763219], {
             RGBColor[
             0.21779424853057935`, 0.34624594253152846`, 0.935714432304875]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.09631744162763219], {
             RGBColor[
             0.18609439165410657`, 0.312927383067344, 0.9339091723514956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.09631744162763219], {
             RGBColor[
             0.9076820231617462, 0.6716970155181059, 0.2445769927357579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.09631744162763219], {
             RGBColor[
             0.4004114204648772, 0.5212379799686826, 0.9467348395354733]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.09631744162763219], {
             RGBColor[
             0.6047389625257771, 0.6899933588150511, 0.9620264128432912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.09631744162763219], {
             RGBColor[
             0.19757646601375403`, 0.32499577122489554`, 0.9345630595000708]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.09631744162763219], {
             RGBColor[
             0.17914809400855325`, 0.30562638382115925`, 0.9335135909767078]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.09631744162763219], {
             RGBColor[
             0.19058407149220488`, 0.3176463212393284, 0.9341648529763892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.09631744162763219], {
             RGBColor[
             0.20128694378722742`, 0.32889571862269473`, 0.9347743657201101]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.09631744162763219], {
             RGBColor[
             0.23320476894069225`, 0.36244337656598474`, 0.9365920386444091]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.09631744162763219], {
             RGBColor[
             0.18260859612989327`, 0.30926359095919453`, 0.9337106614531641]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.09631744162763219], {
             RGBColor[
             0.19419263806779313`, 0.3214391535066072, 0.9343703555044731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.09631744162763219], {
             RGBColor[
             0.29197171960673096`, 0.42421116775586953`, 0.9399387295469274]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.09631744162763219], {
             RGBColor[
             0.25901133304362195`, 0.3895677116688322, 0.9380616842926806]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.09631744162763219], {
             RGBColor[
             0.5227567642523288, 0.6234365170007214, 0.9555724738845179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.09631744162763219], {
             RGBColor[
             0.19488460571983207`, 0.32216645538218325`, 0.9344097620385824]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.09631744162763219], {
             RGBColor[
             0.9862939640410388, 0.9654284637594515, 0.4012550677774902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.09631744162763219], {
             RGBColor[
             0.2543436096659436, 0.38466163844813683`, 0.9377958643515997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.09631744162763219], {
             RGBColor[
             0.19274031574857725`, 0.3199126706665578, 0.9342876478969121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.09631744162763219], {
             RGBColor[
             0.1914897805011185, 0.3185982788329645, 0.9342164317645705]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.09631744162763219], {
             RGBColor[
             0.5295564396500168, 0.6289567998104505, 0.9561077692398556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.09631744162763219], {
             RGBColor[
             0.19311599281626868`, 0.32030753108400334`, 0.9343090421501528]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.09631744162763219], {
             RGBColor[
             0.22474017350644473`, 0.35354655007824254`, 0.9361099924566755]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.09631744162763219], {
             RGBColor[
             0.35586441424032067`, 0.4826536021746064, 0.9438963436902155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.09631744162763219], {
             RGBColor[
             0.21583585429987417`, 0.3441875460256914, 0.935602904650621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.09631744162763219], {
             RGBColor[
             0.2044144915577996, 0.3321829696275479, 0.9349524749388519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.09631744162763219], {
             RGBColor[
             0.2273767118965443, 0.3563177190924262, 0.9362601394175826]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.09631744162763219], {
             RGBColor[
             0.3306172943235091, 0.4607858158598078, 0.9422876195342679]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.09631744162763219], {
             RGBColor[
             0.27956374695486264`, 0.41116960178785156`, 0.939232113860354]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.09631744162763219], {
             RGBColor[
             0.6860055424687634, 0.754632010702607, 0.9693382794531569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.09631744162763219], {
             RGBColor[
             0.18372407711397143`, 0.31043603219904004`, 0.9337741864450011]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.09631744162763219], {
             RGBColor[
             0.2030597206401025, 0.3307590194956109, 0.934875322739293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.09631744162763219], {
             RGBColor[
             0.9863417120240653, 0.9886199611670301, 0.8760167084848537]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.09631744162763219], {
             RGBColor[
             0.964591061095168, 0.9731126518583681, 0.9448222768222637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.09631744162763219], {
             RGBColor[
             0.19839476243792764`, 0.32585585264969186`, 0.9346096602708663]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.09631744162763219], {
             RGBColor[
             0.3655703148691659, 0.4910603654665621, 0.9445147950956946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.09631744162763219], {
             RGBColor[
             0.8453640923839973, 0.3496938695012485, 0.19107401213931735`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.09631744162763219], {
             RGBColor[
             0.8665707356341262, 0.4870106983585556, 0.21037568997361125`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.09631744162763219], {
             RGBColor[
             0.9371250918628792, 0.9526285769763242, 0.9913149984604726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.09631744162763219], {
             RGBColor[
             0.4836083421786542, 0.5916540643449961, 0.9524905666934831]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.09631744162763219], {
             RGBColor[
             0.3723597127044757, 0.4969410006264502, 0.9449474095221317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.09631744162763219], {
             RGBColor[
             0.22242260484653656`, 0.35111063847433904`, 0.9359780103500293]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.09631744162763219], {
             RGBColor[
             0.18528775379377113`, 0.3120795555323372, 0.9338632355186633]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.09631744162763219], {
             RGBColor[
             0.18931653926981418`, 0.3163140645074111, 0.9340926688914699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.09631744162763219], {
             RGBColor[
             0.1804556557285978, 0.30700071409312746`, 0.9335880546823002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.09631744162763219], {
             RGBColor[
             0.4716790509924657, 0.5819693283516046, 0.9515514491928728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.09631744162763219], {
             RGBColor[
             0.2707327274798912, 0.4018876404006824, 0.9387292003655769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.09631744162763219], {
             RGBColor[
             0.23336863550083925`, 0.36261561071043924`, 0.9366013706025906]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.09631744162763219], {
             RGBColor[
             0.20237506472464956`, 0.3300394027187775, 0.9348363325977657]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.09631744162763219], {
             RGBColor[
             0.20083038530367384`, 0.32841584670900015`, 0.9347483653898895]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.09631744162763219], {
             RGBColor[
             0.22474171532416531`, 0.3535481706264238, 0.9361100802609137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.09631744162763219], {
             RGBColor[
             0.8664637178535413, 0.48652475561155717`, 0.21028639171424535`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.09631744162763219], {
             RGBColor[
             0.20003824461178885`, 0.32758325661720833`, 0.9347032541493537]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.09631744162763219], {
             RGBColor[
             0.9671895696970209, 0.9750506153189628, 0.9404236795589124]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.09631744162763219], {
             RGBColor[
             0.18433414396946993`, 0.31107725114464163`, 0.9338089288499086]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.09631744162763219], {
             RGBColor[
             0.33308943974472227`, 0.4629270639700209, 0.9424451424544752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.09631744162763219], {
             RGBColor[
             0.1861956076915163, 0.31303376754012907`, 0.9339149364550904]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.09631744162763219], {
             RGBColor[
             0.2214255710569613, 0.35006269274590207`, 0.9359212307506922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.09631744162763219], {
             RGBColor[
             0.1814903715451621, 0.30808826602110845`, 0.9336469802173286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.09631744162763219], {
             RGBColor[
             0.20866772558178895`, 0.33665338825737323`, 0.9351946903244223]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.09631744162763219], {
             RGBColor[
             0.2275966301752516, 0.35654886714697176`, 0.936272663438215]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.09631744162763219], {
             RGBColor[
             0.9862571365941499, 0.9885849870532707, 0.8774183422327487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.09631744162763219], {
             RGBColor[
             0.952704487454567, 0.8501960835922951, 0.28080312431882476`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.09631744162763219], {
             RGBColor[
             0.426257062503514, 0.5436241760628097, 0.9483817009917713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.09631744162763219], {
             RGBColor[
             0.2177123475199571, 0.3461598593765405, 0.9357097681634818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.09631744162763219], {
             RGBColor[
             0.19208551837244375`, 0.31922443710768994`, 0.9342503581550272]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.09631744162763219], {
             RGBColor[
             0.23118072954041266`, 0.36031598282478083`, 0.9364767725948611]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.09631744162763219], {
             RGBColor[
             0.18790775611424687`, 0.3148333440888988, 0.9340124407748683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.09631744162763219], {
             RGBColor[
             0.20539561179114207`, 0.3332141891994065, 0.9350083482847035]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.09631744162763219], {
             RGBColor[
             0.1941551643020383, 0.3213997662028249, 0.9343682214289508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.09631744162763219], {
             RGBColor[
             0.40849384697781144`, 0.528238571579618, 0.9472498446058684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.09631744162763219], {
             RGBColor[
             0.23143093535124384`, 0.3605789649959291, 0.9364910214456416]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.09631744162763219], {
             RGBColor[
             0.8250746635773962, 0.19374042880931708`, 0.17164483220048377`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.09631744162763219], {
             RGBColor[
             0.1874435235211163, 0.31434540619947215`, 0.9339860034154601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.09631744162763219], {
             RGBColor[
             0.23757609093788187`, 0.36703791314285356`, 0.9368409789653577]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.09631744162763219], {
             RGBColor[
             0.18053047455342514`, 0.3070793534218085, 0.9335923155036896]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.09631744162763219], {
             RGBColor[
             0.986124206873734, 0.9885300171977407, 0.8796213317111282]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.09631744162763219], {
             RGBColor[
             0.18088209567567362`, 0.3074489295153584, 0.9336123398064248]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.09631744162763219], {
             RGBColor[
             0.9874175082770378, 0.9890648305643368, 0.8581879805016432]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.09631744162763219], {
             RGBColor[
             0.1895037720729246, 0.31651085805472556`, 0.934103331522621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.09631744162763219], {
             RGBColor[
             0.22524249753236514`, 0.35407452447866766`, 0.9361385990668298]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.09631744162763219], {
             RGBColor[
             0.1844498116639085, 0.31119882522525194`, 0.9338155159539919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.09631744162763219], {
             RGBColor[
             0.19775641494300986`, 0.32518490895896446`, 0.9345733073253814]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.09631744162763219], {
             RGBColor[
             0.22195872707107797`, 0.35062307352078237`, 0.9359515931969625]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.09631744162763219], {
             RGBColor[
             0.20745669335557887`, 0.3353805166037485, 0.9351257238307011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.09631744162763219], {
             RGBColor[
             0.18265386603570732`, 0.30931117250048296`, 0.9337132395073293]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.09631744162763219], {
             RGBColor[
             0.28560729073547014`, 0.4175217494840773, 0.9395762847380378]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.09631744162763219], {
             RGBColor[
             0.23794228148785246`, 0.3674228026286945, 0.9368618329754481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.09631744162763219], {
             RGBColor[
             0.19184993915614282`, 0.3189768284147727, 0.9342369422671671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.09631744162763219], {
             RGBColor[
             0.31878183695974033`, 0.45053453755869494`, 0.9415334746567325]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.09631744162763219], {
             RGBColor[
             0.3660178719215669, 0.49144801689048034`, 0.9445433130353144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.09631744162763219], {
             RGBColor[
             0.817928104297447, 0.13880884254138265`, 0.16480127896312016`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.09631744162763219], {
             RGBColor[
             0.18407578926115742`, 0.31080570396557056`, 0.9337942159314718]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.09631744162763219], {
             RGBColor[
             0.340161519599846, 0.46905254408746033`, 0.942895769129249]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.09631744162763219], {
             RGBColor[
             0.18516129488531852`, 0.3119466392015956, 0.9338560338709061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.09631744162763219], {
             RGBColor[
             0.25816755850577977`, 0.38868085113116446`, 0.938013632581003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.09631744162763219], {
             RGBColor[
             0.24473644409614725`, 0.3745638983048021, 0.9372487504849276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.09631744162763219], {
             RGBColor[
             0.3038398335581257, 0.4366853080006712, 0.9406146010791581]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.09631744162763219], {
             RGBColor[
             0.20988927253459944`, 0.3379373115553272, 0.935264255616268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.09631744162763219], {
             RGBColor[
             0.2962099519152749, 0.42866581863159803`, 0.9401800906069961]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.09631744162763219], {
             RGBColor[
             0.22271583997709107`, 0.35141884718873295`, 0.9359947096569118]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.09631744162763219], {
             RGBColor[
             0.1981497507744529, 0.3255983298567432, 0.9345957072190938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.09631744162763219], {
             RGBColor[
             0.1962060745132835, 0.32355540287006146`, 0.9344850177314316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.09631744162763219], {
             RGBColor[
             0.20504953117466115`, 0.3328504365287066, 0.9349886395055752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.09631744162763219], {
             RGBColor[
             0.9731648978995463, 0.9211410408128702, 0.3502511250338943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.09631744162763219], {
             RGBColor[
             0.2128391460228046, 0.3410378156242125, 0.9354322465474746]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.09631744162763219], {
             RGBColor[
             0.2226352176445654, 0.3513341080054973, 0.9359901183343445]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.09631744162763219], {
             RGBColor[
             0.17908821045117204`, 0.30556344240551475`, 0.9335101806967048]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.09631744162763219], {
             RGBColor[
             0.2389301514139497, 0.3684611165555936, 0.9369180907063167]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.09631744162763219], {
             RGBColor[
             0.46304655962256364`, 0.5749610829682137, 0.9508718678503764]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.09631744162763219], {
             RGBColor[
             0.1801747671672662, 0.30670548240580453`, 0.9335720584942697]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.09631744162763219], {
             RGBColor[
             0.24137384732010603`, 0.3710295958922332, 0.9370572555730482]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.09631744162763219], {
             RGBColor[
             0.9930111873350895, 0.9874599613241353, 0.4806890552557963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.09631744162763219], {
             RGBColor[
             0.2006299825882091, 0.3282052107487807, 0.934736952751713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.09631744162763219], {
             RGBColor[
             0.23666672657285628`, 0.3660821135381808, 0.9367891920100534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.09631744162763219], {
             RGBColor[
             0.2620129130085561, 0.39272256252313964`, 0.938232619831244]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.09631744162763219], {
             RGBColor[
             0.9784615748157791, 0.9834572582803182, 0.9213431151026323]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.09631744162763219], {
             RGBColor[
             0.4406321468160179, 0.5560751515815551, 0.9492976686527762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.09631744162763219], {
             RGBColor[
             0.3058207768282486, 0.438767404976628, 0.9407274128678487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.09631744162763219], {
             RGBColor[
             0.24095771526907575`, 0.3705922147223045, 0.9370335574683543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.09631744162763219], {
             RGBColor[
             0.1996796674968478, 0.327206369334303, 0.9346828337131252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.09631744162763219], {
             RGBColor[
             0.22089074136906994`, 0.34950055283376746`, 0.9358907729911765]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.09631744162763219], {
             RGBColor[
             0.2430009596347453, 0.3727397940997984, 0.9371499172122699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.09631744162763219], {
             RGBColor[
             0.20886533678518346`, 0.33686109016141486`, 0.9352059439901159]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.09631744162763219], {
             RGBColor[
             0.2434445902532613, 0.3732060780076645, 0.9371751813197018]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.09631744162763219], {
             RGBColor[
             0.9464109372448213, 0.8252442542119368, 0.27573918609145315`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.09631744162763219], {
             RGBColor[
             0.926874823682218, 0.9445288413300859, 0.9928873421853748]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.09631744162763219], {
             RGBColor[
             0.773715577090376, 0.8231517563699634, 0.978080396007364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.09631744162763219], {
             RGBColor[
             0.8997587664774066, 0.6377097951563564, 0.23806859642232206`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.09631744162763219], {
             RGBColor[
             0.5360494193639693, 0.63422809324764, 0.9566189203875064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.09631744162763219], {
             RGBColor[
             0.19692281060910452`, 0.3243087379504625, 0.9345258347917725]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.09631744162763219], {
             RGBColor[
             0.18720713771192796`, 0.31409694972628927`, 0.9339725415933283]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.09631744162763219], {
             RGBColor[
             0.19199315011410678`, 0.319127352211692, 0.9342450979193615]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.09631744162763219], {
             RGBColor[
             0.2601377913887575, 0.39075169081115385`, 0.9381258344289902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.09631744162763219], {
             RGBColor[
             0.8186938987840391, 0.1446950745386128, 0.16553460462832187`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.09631744162763219], {
             RGBColor[
             0.2256459244954445, 0.3544985517956109, 0.9361615736355604]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{
  3.834950276960332*^9, {3.835008779561106*^9, 3.8350087876555696`*^9}, 
   3.8350238845485015`*^9, 3.8350517632409744`*^9},
 CellLabel->
  "Out[401]=",ExpressionUUID->"9ec79fd2-13a5-4ac0-adcf-a41646af28d1"]
}, Open  ]],

Cell["Estimated with absolute Mean Deviation v Calculated: (r=3)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 
  3.8349503756793146`*^9}},ExpressionUUID->"0ba91b9d-9ad3-47e7-9aa9-\
b71dcecea7e8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraphb", "[", 
     RowBox[{"graphin3", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsi3", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}], 
     "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"AMDi3300", ",", "kri3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502409842243`*^9}, {3.835008795612831*^9, 3.835008803050581*^9}, 
   3.835051770419874*^9},
 CellLabel->
  "In[402]:=",ExpressionUUID->"16afaf15-096c-4200-a678-d5b2ec38cdfc"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1FO4EAYYBuBzsm2dTrZdW7WsZbtVy3bLtWxr2bat5WVjyzZXrfc8u3i/
//a7+f7gJu2rtAsMCAjIJEJuKEIThrCEIzwRiEgkIhOFqEQjOjGISSxiE4e4
xCM+CUhIIhKThKQkI4jkBJOClKQiNWlISzrSk4GMIX3JTBayko3s5CAnuchN
HvKSj/wUoCCF+IEfKUwRivITxShOCUpSitKUoSzlKE8FfqYilahMFapSjerU
oCa1qE0d6lKP+jSgIY1oTBN+oSnNaM6vtKAlrWhNG9rSjvZ0oCOd6EwXutKN
7vSgJ73ozW/0oS/96M8ABjKIwQzhd4YyjOGMYCSjGM0YxjKO8UxgIpOYzBSm
Mo3pzGAms5jNH8xhLvOYzwIWsojFLGEpy1jOClayitWsYS3rWM8GNrKJzWxh
K9vYzg52sovd7GEv+9jPAQ5yiMMc4U+OcozjnOAkpzjNX5zhLOc4zwUuconL
XOEq17jODW5yi9v8zT/c4S73uM8DHvKIxzzhKc94zgte8orXvOEt73jPBz7y
ic/8yxe+8o3/CBl/IKEITRjCEo7wRCAikYhMFKISjejEICaxiE0c4hKP+CQg
IYlITBKSkowgkhNMClKSitSkIS3pSE8GMgb+/6++Az6VhWw=
          "], {Null, CompressedData["
1:eJxN2guYllWBB/D3qyhJJoMEhjQEkUhkrd1Es1FL08DywkWybEVNDSyNClNB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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[72, 227] -> 
             RGBColor[
              0.9915769309777831, 0.9891548142010902, 0.6707685515097135], 
             UndirectedEdge[132, 236] -> 
             RGBColor[
              0.9902898551741035, 0.9890512265097999, 0.7232571477612644], 
             UndirectedEdge[187, 193] -> 
             RGBColor[
              0.9617395632580235, 0.970986009440325, 0.9496491188708036], 
             UndirectedEdge[196, 225] -> 
             RGBColor[
              0.991966001176685, 0.9840607716627072, 0.4658747213822664], 
             UndirectedEdge[39, 166] -> 
             RGBColor[
              0.9828401078505877, 0.9713323166140058, 0.6531814070001691], 
             UndirectedEdge[7, 216] -> 
             RGBColor[
              0.897326785146247, 0.9202420382579519, 0.9648981757509825], 
             UndirectedEdge[92, 281] -> 
             RGBColor[
              0.6519579705041822, 0.24030471119698749`, 0.4233752820390615], 
             UndirectedEdge[99, 229] -> 
             RGBColor[
              0.9207857724027312, 0.7539069270129832, 0.5820826576132218], 
             UndirectedEdge[187, 296] -> 
             RGBColor[
              0.9768098926368707, 0.9495483870627384, 0.6266927977637277], 
             UndirectedEdge[100, 244] -> 
             RGBColor[
              0.9878438809692847, 0.9892411466298593, 0.851121881573956], 
             UndirectedEdge[232, 245] -> 
             RGBColor[
              0.7657934532496244, 0.7161789115405732, 0.6104000546641467], 
             UndirectedEdge[6, 52] -> 
             RGBColor[
              0.8613856216609682, 0.8915661698345823, 0.9362717185699174], 
             UndirectedEdge[113, 160] -> 
             RGBColor[
              0.9553869668902197, 0.851560316236629, 0.3312445381112956], 
             UndirectedEdge[176, 288] -> 
             RGBColor[
              0.9795124956528012, 0.9415222963397702, 0.4625521167439696], 
             UndirectedEdge[187, 228] -> 
             RGBColor[
              0.9700438916679082, 0.9771793639713271, 0.9355920569885982], 
             UndirectedEdge[61, 268] -> 
             RGBColor[
              0.9720729671757549, 0.9754797005941889, 0.7409058702963918], 
             UndirectedEdge[51, 101] -> 
             RGBColor[
              0.9940880249906091, 0.9918232606498587, 0.7476402558138828], 
             UndirectedEdge[207, 214] -> 
             RGBColor[
              0.7285731266845015, 0.781677091218624, 0.7178493378775659], 
             UndirectedEdge[17, 162] -> 
             RGBColor[
              0.9202895489899685, 0.9019877039393547, 0.6582280461738637], 
             UndirectedEdge[20, 279] -> 
             RGBColor[
              0.9601055178460935, 0.939453639991086, 0.6599858882430225], 
             UndirectedEdge[51, 197] -> 
             RGBColor[
              0.7445513922329386, 0.7961846151107127, 0.8428153980505788], 
             UndirectedEdge[86, 94] -> 
             RGBColor[
              0.852892293544161, 0.885537180000282, 0.9858308224158225], 
             UndirectedEdge[55, 114] -> 
             RGBColor[
              0.9746047046059325, 0.9272320141646233, 0.5221977228028694], 
             UndirectedEdge[13, 270] -> 
             RGBColor[
              0.9671236720056144, 0.9731237757542013, 0.8552302230607838], 
             UndirectedEdge[151, 220] -> 
             RGBColor[
              0.9353116914145739, 0.7759425989864939, 0.5417987393955712], 
             UndirectedEdge[117, 225] -> 
             RGBColor[
              0.9690570799805942, 0.9732304568621001, 0.7460109806484418], 
             UndirectedEdge[13, 277] -> 
             RGBColor[
              0.9844375317761263, 0.9860364240222057, 0.8259223746471522], 
             UndirectedEdge[81, 237] -> 
             RGBColor[
              0.9763013086663019, 0.9818461353231493, 0.924999882206049], 
             UndirectedEdge[172, 174] -> 
             RGBColor[
              0.9829797192006191, 0.9848872094617332, 0.8234721971047106], 
             UndirectedEdge[128, 197] -> 
             RGBColor[
              0.6246641932388056, 0.7044403909331878, 0.9647772414595996], 
             UndirectedEdge[44, 71] -> 
             RGBColor[
              0.9904184371272717, 0.9881423022485036, 0.651191974459099], 
             UndirectedEdge[70, 122] -> 
             RGBColor[
              0.7667807012261547, 0.779904761981215, 0.6430068071657311], 
             UndirectedEdge[42, 293] -> 
             RGBColor[
              0.957114946862753, 0.9675369781048466, 0.9574773881348659], 
             UndirectedEdge[154, 181] -> 
             RGBColor[
              0.9546242284081281, 0.9005279327559652, 0.6133191955402912], 
             UndirectedEdge[42, 216] -> 
             RGBColor[
              0.8949013301477029, 0.9184331378913557, 0.9690038384035402], 
             UndirectedEdge[125, 130] -> 
             RGBColor[
              0.8533562378474223, 0.4080586855443903, 0.19860723040970565`], 
             UndirectedEdge[173, 263] -> 
             RGBColor[
              0.9588426844453883, 0.8716741041027707, 0.5434424972829579], 
             UndirectedEdge[112, 132] -> 
             RGBColor[
              0.5864081907479468, 0.6473661649175226, 0.7548880350365885], 
             UndirectedEdge[208, 279] -> 
             RGBColor[
              0.9590252992767762, 0.96896171580731, 0.9542436597976316], 
             UndirectedEdge[271, 295] -> 
             RGBColor[
              0.9459928264248363, 0.8247078037863085, 0.5525746158182965], 
             UndirectedEdge[193, 264] -> 
             RGBColor[
              0.9676483651925432, 0.9733066574346911, 0.837803736592581], 
             UndirectedEdge[16, 39] -> 
             RGBColor[
              0.9726283822401387, 0.9368857683027654, 0.613510781326145], 
             UndirectedEdge[168, 282] -> 
             RGBColor[
              0.9882010502266545, 0.9892549153547436, 0.8392050062231122], 
             UndirectedEdge[92, 243] -> 
             RGBColor[
              0.8588985206700176, 0.40818706837863583`, 0.437133871031852], 
             UndirectedEdge[71, 280] -> 
             RGBColor[
              0.9428471101376299, 0.8086909981427942, 0.5418943063759007], 
             UndirectedEdge[69, 118] -> 
             RGBColor[
              0.9242878267198797, 0.7748085060452452, 0.5883341945095573], 
             UndirectedEdge[175, 253] -> 
             RGBColor[
              0.971109415098432, 0.9289665832002869, 0.6016758769940941], 
             UndirectedEdge[137, 179] -> 
             RGBColor[
              0.9834391793801134, 0.9853598110335784, 0.8318736273482821], 
             UndirectedEdge[134, 221] -> 
             RGBColor[
              0.9913066750635702, 0.9902563259059589, 0.7634392740011497], 
             UndirectedEdge[91, 163] -> 
             RGBColor[
              0.8944712501890548, 0.9148694419319316, 0.8014585212676453], 
             UndirectedEdge[160, 232] -> 
             RGBColor[
              0.7968698703028123, 0.8301156451196203, 0.6836878971550625], 
             UndirectedEdge[135, 263] -> 
             RGBColor[
              0.9338366292974196, 0.8538860705855296, 0.6243483350103203], 
             UndirectedEdge[160, 297] -> 
             RGBColor[
              0.990265301703761, 0.980165658461275, 0.5836468234122243], 
             UndirectedEdge[179, 274] -> 
             RGBColor[
              0.9150978372260254, 0.9342074199778847, 0.9594935921340257], 
             UndirectedEdge[209, 259] -> 
             RGBColor[
              0.8551339913290822, 0.884438094734745, 0.8215036209319477], 
             UndirectedEdge[14, 173] -> 
             RGBColor[
              0.9717494218571476, 0.977589904125456, 0.8941279302661697], 
             UndirectedEdge[260, 267] -> 
             RGBColor[
              0.9540375339316893, 0.9097462286016849, 0.6218038194701615], 
             UndirectedEdge[203, 216] -> 
             RGBColor[
              0.8646246532706263, 0.749840462660692, 0.6103493705918325], 
             UndirectedEdge[37, 279] -> 
             RGBColor[
              0.9316463569280052, 0.9480187258675303, 0.9824279144748496], 
             UndirectedEdge[192, 220] -> 
             RGBColor[
              0.8778910617527218, 0.9040303650554566, 0.9184197065875557], 
             UndirectedEdge[60, 225] -> 
             RGBColor[
              0.9912925885493471, 0.988969902803617, 0.6705867704965771], 
             UndirectedEdge[177, 226] -> 
             RGBColor[
              0.9326389004338647, 0.7706427175157065, 0.26465788200210527`], 
             UndirectedEdge[91, 273] -> 
             RGBColor[
              0.9939836037007117, 0.9895398616038253, 0.5865305755956044], 
             UndirectedEdge[52, 273] -> 
             RGBColor[
              0.989331607218485, 0.988449158964309, 0.724177771612809], 
             UndirectedEdge[21, 114] -> 
             RGBColor[
              0.9472037186319128, 0.8283873682330181, 0.27637707660447786`], 
             UndirectedEdge[7, 202] -> 
             RGBColor[
              0.9185016054312822, 0.7447254818716658, 0.5809694253939873], 
             UndirectedEdge[94, 293] -> 
             RGBColor[
              0.9116191685439254, 0.9318607870150867, 0.9739718036096932], 
             UndirectedEdge[132, 133] -> 
             RGBColor[
              0.7159163716380433, 0.7715422954804172, 0.7627007058605348], 
             UndirectedEdge[13, 93] -> 
             RGBColor[
              0.9297258105861003, 0.943389270894043, 0.8546287233225918], 
             UndirectedEdge[141, 178] -> 
             RGBColor[
              0.8869998043561396, 0.890785667933256, 0.6772674668848555], 
             UndirectedEdge[245, 264] -> 
             RGBColor[
              0.9600465199405543, 0.8662817845786117, 0.47420846779741566`], 
             UndirectedEdge[5, 83] -> 
             RGBColor[
              0.9911140900333633, 0.9889455295559112, 0.6771387535203252], 
             UndirectedEdge[210, 226] -> 
             RGBColor[
              0.9590801132928926, 0.8638995670081516, 0.3876712347044329], 
             UndirectedEdge[91, 298] -> 
             RGBColor[
              0.9940068668827341, 0.9895896191979028, 0.5890626293950227], 
             UndirectedEdge[126, 192] -> 
             RGBColor[
              0.8682368333265057, 0.8973551265443165, 0.9582665141048878], 
             UndirectedEdge[127, 156] -> 
             RGBColor[
              0.9212621684794392, 0.8487547264959167, 0.6275016251450299], 
             UndirectedEdge[36, 268] -> 
             RGBColor[
              0.6017590919743068, 0.6728854525376948, 0.9529075845271142], 
             UndirectedEdge[25, 221] -> 
             RGBColor[
              0.9788918559515087, 0.9390424671460338, 0.4929862997902278], 
             UndirectedEdge[69, 249] -> 
             RGBColor[
              0.9231664310259384, 0.9408976376406242, 0.9691575840624549], 
             UndirectedEdge[22, 161] -> 
             RGBColor[
              0.9654746076134808, 0.9733800915699489, 0.9257941422793201], 
             UndirectedEdge[96, 112] -> 
             RGBColor[
              0.56526405956909, 0.6344093872079621, 0.9501559301179898], 
             UndirectedEdge[219, 250] -> 
             RGBColor[
              0.9653772691678781, 0.9736990045516978, 0.9434914316310714], 
             UndirectedEdge[41, 219] -> 
             RGBColor[
              0.9494471035582916, 0.8452956312338711, 0.5822263069041118], 
             UndirectedEdge[202, 237] -> 
             RGBColor[
              0.9253995122034723, 0.7498699294480795, 0.5692930684908879], 
             UndirectedEdge[91, 235] -> 
             RGBColor[
              0.9944489812519504, 0.9905352571290368, 0.6371840500706012], 
             UndirectedEdge[69, 263] -> 
             RGBColor[
              0.9450765852225693, 0.8622688113107675, 0.6053220214790509], 
             UndirectedEdge[12, 239] -> 
             RGBColor[
              0.6089940538941991, 0.686528803751135, 0.9658779050080464], 
             UndirectedEdge[122, 266] -> 
             RGBColor[
              0.98046650819379, 0.9450005770812556, 0.4441350900147036], 
             UndirectedEdge[206, 254] -> 
             RGBColor[
              0.9797633309533489, 0.953610934451759, 0.6041639065017872], 
             UndirectedEdge[137, 270] -> 
             RGBColor[
              0.9670505096792994, 0.9731371680046951, 0.8596153703021314], 
             UndirectedEdge[25, 58] -> 
             RGBColor[
              0.9542566065863433, 0.8542732529215582, 0.2928662650641275], 
             UndirectedEdge[107, 156] -> 
             RGBColor[
              0.9561784875632175, 0.8754274157415266, 0.590314637557181], 
             UndirectedEdge[136, 194] -> 
             RGBColor[
              0.9711907296104676, 0.9772742533266334, 0.8995975756743266], 
             UndirectedEdge[45, 281] -> 
             RGBColor[
              0.6575351517323512, 0.7209404231761241, 0.7559898218553092], 
             UndirectedEdge[137, 147] -> 
             RGBColor[
              0.8686011015306124, 0.8953511859718724, 0.8530237043571708], 
             UndirectedEdge[164, 187] -> 
             RGBColor[
              0.9604288229330676, 0.9700084614521132, 0.9518678603451263], 
             UndirectedEdge[199, 229] -> 
             RGBColor[
              0.8972085201771336, 0.7358492434111578, 0.6055655923716563], 
             UndirectedEdge[191, 271] -> 
             RGBColor[
              0.9492643355073382, 0.8246778887242902, 0.3978445972767556], 
             UndirectedEdge[153, 222] -> 
             RGBColor[
              0.9352601029498517, 0.9325351402066753, 0.6870341731884253], 
             UndirectedEdge[158, 186] -> 
             RGBColor[
              0.950616271862657, 0.9626902769303787, 0.9684779497841325], 
             UndirectedEdge[16, 192] -> 
             RGBColor[
              0.8658355787109151, 0.8533431702780863, 0.6446248045548117], 
             UndirectedEdge[75, 143] -> 
             RGBColor[
              0.964654966923251, 0.9721046883314004, 0.8974410840219358], 
             UndirectedEdge[204, 226] -> 
             RGBColor[
              0.9062396847627896, 0.6612075819936725, 0.24316965232391674`], 
             UndirectedEdge[137, 191] -> 
             RGBColor[
              0.9943821093426519, 0.9905621039454703, 0.6422538703842506], 
             UndirectedEdge[197, 198] -> 
             RGBColor[
              0.7393132314588085, 0.7798317364015199, 0.6738715599984567], 
             UndirectedEdge[80, 156] -> 
             RGBColor[
              0.8866863412797084, 0.8211849004226783, 0.6242037518805142], 
             UndirectedEdge[103, 159] -> 
             RGBColor[
              0.9393627171297423, 0.7918777417132143, 0.2983093720570119], 
             UndirectedEdge[28, 288] -> 
             RGBColor[
              0.9799851182139948, 0.9425331882086927, 0.5139941658415539], 
             UndirectedEdge[118, 263] -> 
             RGBColor[
              0.9075194623921827, 0.6660127109914874, 0.24418548862142453`], 
             UndirectedEdge[68, 83] -> 
             RGBColor[
              0.6207715598856883, 0.6862899914668978, 0.8860215536921031], 
             UndirectedEdge[64, 90] -> 
             RGBColor[
              0.7292347497224869, 0.6813343042183566, 0.6063329305874137], 
             UndirectedEdge[213, 263] -> 
             RGBColor[
              0.9421612431929397, 0.8600945539985043, 0.6102569350922359], 
             UndirectedEdge[52, 53] -> 
             RGBColor[
              0.8788766745150451, 0.46227903126596703`, 0.4142475267362778], 
             UndirectedEdge[245, 297] -> 
             RGBColor[
              0.9591888846505732, 0.8662289248822279, 0.5103589809213085], 
             UndirectedEdge[189, 267] -> 
             RGBColor[
              0.9080643104799275, 0.8735711867841454, 0.634156397929439], 
             UndirectedEdge[145, 203] -> 
             RGBColor[
              0.9460331808637505, 0.81169380091346, 0.4962006932418333], 
             UndirectedEdge[136, 279] -> 
             RGBColor[
              0.9683379631587279, 0.9751466647779023, 0.9044265651564684], 
             UndirectedEdge[80, 256] -> 
             RGBColor[
              0.5104800354928686, 0.5911361653489694, 0.9591480300370289], 
             UndirectedEdge[40, 130] -> 
             RGBColor[
              0.8803750483832323, 0.5306986025803135, 0.44144546272374374`], 
             UndirectedEdge[83, 101] -> 
             RGBColor[
              0.9910098537034074, 0.9905503577172071, 0.7986535200947471], 
             UndirectedEdge[83, 194] -> 
             RGBColor[
              0.9712343925600455, 0.9772923090783705, 0.8988739676037277], 
             UndirectedEdge[149, 197] -> 
             RGBColor[
              0.7378151050267856, 0.7929584238243688, 0.9347237802996358], 
             UndirectedEdge[23, 44] -> 
             RGBColor[
              0.6227304277100723, 0.6849365441371287, 0.696295195615383], 
             UndirectedEdge[97, 284] -> 
             RGBColor[
              0.9791468012167547, 0.9810303995664001, 0.7507553688097971], 
             UndirectedEdge[135, 276] -> 
             RGBColor[
              0.788560292019618, 0.8355484169245221, 0.9760744768472716], 
             UndirectedEdge[142, 150] -> 
             RGBColor[
              0.9932558343119082, 0.9902182532008468, 0.6697794911967396], 
             UndirectedEdge[46, 214] -> 
             RGBColor[
              0.983638513863899, 0.983919973962518, 0.7066262559412032], 
             UndirectedEdge[5, 243] -> 
             RGBColor[
              0.9677146644098586, 0.972269204747991, 0.7514507594601416], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.8183719651801412, 0.6610864352673604, 0.5954955609660908], 
             UndirectedEdge[198, 243] -> 
             RGBColor[
              0.9632969981466287, 0.9579035541672867, 0.6886965048227534], 
             UndirectedEdge[13, 32] -> 
             RGBColor[
              0.9877966090037311, 0.9885416183185692, 0.82023633308847], 
             UndirectedEdge[86, 140] -> 
             RGBColor[
              0.6839367230519353, 0.75143994542788, 0.9702696766603145], 
             UndirectedEdge[171, 275] -> 
             RGBColor[
              0.823174711615619, 0.862275559528866, 0.982881063764463], 
             UndirectedEdge[36, 250] -> 
             RGBColor[
              0.6001419714566054, 0.6716794067033851, 0.9556449477510028], 
             UndirectedEdge[168, 203] -> 
             RGBColor[
              0.9457322011696043, 0.8115693380751052, 0.5011887056843163], 
             UndirectedEdge[17, 169] -> 
             RGBColor[
              0.9306688764820507, 0.9455000448000737, 0.9149997727306132], 
             UndirectedEdge[191, 246] -> 
             RGBColor[
              0.9802445350914792, 0.9442964451628697, 0.4394772876109646], 
             UndirectedEdge[17, 178] -> 
             RGBColor[
              0.833792466644487, 0.8705124548756648, 0.9839546742195893], 
             UndirectedEdge[9, 132] -> 
             RGBColor[
              0.9658844442710098, 0.9712647742098968, 0.7831565202057024], 
             UndirectedEdge[11, 283] -> 
             RGBColor[
              0.9576241848229947, 0.9679167669417943, 0.956615381098708], 
             UndirectedEdge[64, 69] -> 
             RGBColor[
              0.7492148787635721, 0.8028636761035532, 0.9530658977537456], 
             UndirectedEdge[193, 288] -> 
             RGBColor[
              0.9526082668936378, 0.9240720795574973, 0.6518942003209647], 
             UndirectedEdge[221, 288] -> 
             RGBColor[
              0.979825429708918, 0.9421916306433177, 0.4966130575471518], 
             UndirectedEdge[65, 264] -> 
             RGBColor[
              0.9565656157250317, 0.8524811593066317, 0.4714076505582828], 
             UndirectedEdge[27, 151] -> 
             RGBColor[
              0.9368415009660139, 0.7765752145503266, 0.5164458361080009], 
             UndirectedEdge[201, 293] -> 
             RGBColor[
              0.974870518757793, 0.9784007149054919, 0.8023926759950197], 
             UndirectedEdge[43, 99] -> 
             RGBColor[
              0.9761669826197559, 0.9811375348690405, 0.8979809566733336], 
             UndirectedEdge[77, 293] -> 
             RGBColor[
              0.9669853188255678, 0.9530423784494819, 0.6662944760282067], 
             UndirectedEdge[61, 280] -> 
             RGBColor[
              0.9454729759218785, 0.8080794880879134, 0.37499581330146237`], 
             UndirectedEdge[20, 55] -> 
             RGBColor[
              0.9827930722702094, 0.9548638103470811, 0.5539532521622204], 
             UndirectedEdge[208, 242] -> 
             RGBColor[
              0.9666236524085858, 0.9322277905122941, 0.6232938382263207], 
             UndirectedEdge[29, 261] -> 
             RGBColor[
              0.9470212758295165, 0.8159271179968055, 0.33954087136279054`], 
             UndirectedEdge[12, 76] -> 
             RGBColor[
              0.6563390163316849, 0.7194220367475705, 0.7146874702936397], 
             UndirectedEdge[168, 276] -> 
             RGBColor[
              0.8153858958017304, 0.8540888805622486, 0.8650140094112306], 
             UndirectedEdge[148, 271] -> 
             RGBColor[
              0.9467835441929152, 0.8170354713794934, 0.32648408251463856`], 
             UndirectedEdge[131, 170] -> 
             RGBColor[
              0.9668447652845022, 0.973017792102413, 0.8614892734276434], 
             UndirectedEdge[141, 261] -> 
             RGBColor[
              0.9860037591284254, 0.9643686741086323, 0.40700345590559406`], 
             UndirectedEdge[129, 184] -> 
             RGBColor[
              0.9864778989787675, 0.9886762779726446, 0.8737597382048978], 
             UndirectedEdge[111, 185] -> 
             RGBColor[
              0.9722134417362323, 0.9165346225266217, 0.36475850045826286`], 
             UndirectedEdge[234, 239] -> 
             RGBColor[
              0.8745844209042419, 0.9028338935400994, 0.9878998368882177], 
             UndirectedEdge[103, 203] -> 
             RGBColor[
              0.9014365851438979, 0.6452713401826924, 0.23946565894498067`], 
             UndirectedEdge[28, 160] -> 
             RGBColor[
              0.9912159845330576, 0.9804175374357054, 0.5576239607199688], 
             UndirectedEdge[133, 170] -> 
             RGBColor[
              0.7164116915283211, 0.7729485162966094, 0.8418205846923617], 
             UndirectedEdge[87, 299] -> 
             RGBColor[
              0.9700450013885761, 0.9758075941322338, 0.8741224595699337], 
             UndirectedEdge[5, 290] -> 
             RGBColor[
              0.9790222695572981, 0.9807023981524471, 0.732309933441279], 
             UndirectedEdge[183, 253] -> 
             RGBColor[
              0.9764513159369568, 0.930791934915534, 0.4850373574503616], 
             UndirectedEdge[176, 245] -> 
             RGBColor[
              0.9596669449186761, 0.8654699119877358, 0.4328940691314688], 
             UndirectedEdge[29, 190] -> 
             RGBColor[
              0.9373611270460773, 0.7834220281766874, 0.2951372380921481], 
             UndirectedEdge[159, 168] -> 
             RGBColor[
              0.9836583331554485, 0.9581757396056274, 0.5600324187963475], 
             UndirectedEdge[202, 299] -> 
             RGBColor[
              0.9103934593288487, 0.7386784397843416, 0.5946944018022184], 
             UndirectedEdge[65, 115] -> 
             RGBColor[
              0.9511280583624753, 0.8505119647424436, 0.5824553386964404], 
             UndirectedEdge[51, 142] -> 
             RGBColor[
              0.9938519962849808, 0.9917256567144204, 0.7515518622888546], 
             UndirectedEdge[134, 187] -> 
             RGBColor[
              0.985464514094812, 0.9880782161989214, 0.8825381141421371], 
             UndirectedEdge[85, 239] -> 
             RGBColor[
              0.9423654943360655, 0.9552170664200073, 0.9330703558878783], 
             UndirectedEdge[120, 284] -> 
             RGBColor[
              0.9437666650087354, 0.95725306530402, 0.9686733287771797], 
             UndirectedEdge[31, 61] -> 
             RGBColor[
              0.969050840751848, 0.973225803655517, 0.7460215420352576], 
             UndirectedEdge[217, 247] -> 
             RGBColor[
              0.9781411090914857, 0.936757550925051, 0.4690216917087892], 
             UndirectedEdge[66, 169] -> 
             RGBColor[
              0.9411944932337677, 0.9538928858876372, 0.916003715452721], 
             UndirectedEdge[168, 293] -> 
             RGBColor[
              0.9741223140802636, 0.9787550169885801, 0.8630366341964824], 
             UndirectedEdge[93, 105] -> 
             RGBColor[
              0.6234777602298113, 0.7002487873243086, 0.9662599113997643], 
             UndirectedEdge[169, 193] -> 
             RGBColor[
              0.9643717449533127, 0.9722534852967151, 0.9140430904579102], 
             UndirectedEdge[87, 216] -> 
             RGBColor[
              0.9116275118109982, 0.9295348993222821, 0.8792230567833931], 
             UndirectedEdge[81, 201] -> 
             RGBColor[
              0.9847335187906078, 0.9857565241807849, 0.78569718962186], 
             UndirectedEdge[63, 244] -> 
             RGBColor[
              0.9686537512429478, 0.913124015857474, 0.5638261842952013], 
             UndirectedEdge[32, 150] -> 
             RGBColor[
              0.987091121938934, 0.9870326528226518, 0.7434484198467792], 
             UndirectedEdge[95, 282] -> 
             RGBColor[
              0.9669875546134147, 0.9144698332371004, 0.5960543753746487], 
             UndirectedEdge[126, 239] -> 
             RGBColor[
              0.9332146532814497, 0.9487499915234893, 0.9645747319330351], 
             UndirectedEdge[149, 150] -> 
             RGBColor[
              0.9876803066522397, 0.9874720658171339, 0.7424510838111367], 
             UndirectedEdge[16, 222] -> 
             RGBColor[
              0.9258452258813465, 0.9007765491363463, 0.650459153627632], 
             UndirectedEdge[192, 262] -> 
             RGBColor[
              0.8759083552126348, 0.9030765350060275, 0.9452806286050262], 
             UndirectedEdge[214, 276] -> 
             RGBColor[
              0.8154019944173898, 0.8521686776400981, 0.7246848244101216], 
             UndirectedEdge[48, 100] -> 
             RGBColor[
              0.991094034466652, 0.9898587872344848, 0.7444581678922808], 
             UndirectedEdge[105, 143] -> 
             RGBColor[
              0.6607496372227208, 0.729889333205386, 0.9670746699101967], 
             UndirectedEdge[268, 279] -> 
             RGBColor[
              0.9493691581969244, 0.9617601816004364, 0.9705889879208807], 
             UndirectedEdge[24, 106] -> 
             RGBColor[
              0.8937560429826079, 0.9181208245855703, 0.9897284433167615], 
             UndirectedEdge[33, 222] -> 
             RGBColor[
              0.9405523061229857, 0.9502935062711313, 0.715542069631876], 
             UndirectedEdge[155, 291] -> 
             RGBColor[
              0.9745267992108269, 0.9318804860381021, 0.5557141832714172], 
             UndirectedEdge[99, 233] -> 
             RGBColor[
              0.6736075478093978, 0.7394787418680332, 0.9453095811671213], 
             UndirectedEdge[237, 269] -> 
             RGBColor[
              0.938178013272938, 0.8078941183097729, 0.5799557630129739], 
             UndirectedEdge[85, 135] -> 
             RGBColor[
              0.9628547656130289, 0.9714601181518243, 0.9317469831138581], 
             UndirectedEdge[126, 248] -> 
             RGBColor[
              0.9808913753382003, 0.983683139925615, 0.8461941505414893], 
             UndirectedEdge[188, 261] -> 
             RGBColor[
              0.9938889001633189, 0.9893373003133384, 0.576222679992877], 
             UndirectedEdge[37, 177] -> 
             RGBColor[
              0.9279240264909838, 0.8685136359396317, 0.6313720954152142], 
             UndirectedEdge[160, 180] -> 
             RGBColor[
              0.8244003229001124, 0.8521730911137446, 0.6860555316359707], 
             UndirectedEdge[23, 194] -> 
             RGBColor[
              0.6031495391886721, 0.6739224457935202, 0.9505539200799076], 
             UndirectedEdge[51, 243] -> 
             RGBColor[
              0.9685351589207589, 0.9742564328764795, 0.8576403428748754], 
             UndirectedEdge[108, 208] -> 
             RGBColor[
              0.9809741235404816, 0.9840664022574763, 0.8604536942472008], 
             UndirectedEdge[179, 251] -> 
             RGBColor[
              0.9383283039614765, 0.952730763578512, 0.9617093347893355], 
             UndirectedEdge[26, 224] -> 
             RGBColor[
              0.9883572645581844, 0.9886560913543327, 0.795192932519244], 
             UndirectedEdge[106, 291] -> 
             RGBColor[
              0.9122704793199273, 0.8845984795963183, 0.6412880424824101], 
             UndirectedEdge[48, 161] -> 
             RGBColor[
              0.9694203352511434, 0.9742853699570264, 0.8076029650047826], 
             UndirectedEdge[227, 299] -> 
             RGBColor[
              0.970514315339379, 0.9743716229694168, 0.7478576822598719], 
             UndirectedEdge[162, 299] -> 
             RGBColor[
              0.9576282010661754, 0.9314527058955149, 0.6511169306222233], 
             UndirectedEdge[200, 227] -> 
             RGBColor[
              0.9841277835679977, 0.9575724562073921, 0.4395204967133279], 
             UndirectedEdge[202, 293] -> 
             RGBColor[
              0.9141895864663209, 0.7415095851878807, 0.5882685487470035], 
             UndirectedEdge[3, 155] -> 
             RGBColor[
              0.9922414777702244, 0.990395961974901, 0.7299980515635109], 
             UndirectedEdge[39, 234] -> 
             RGBColor[
              0.9163994044785218, 0.9349816265856059, 0.9504775958314038], 
             UndirectedEdge[144, 176] -> 
             RGBColor[
              0.9855628250744422, 0.9861384461213194, 0.7655223086830016], 
             UndirectedEdge[140, 162] -> 
             RGBColor[
              0.7488595433590117, 0.7659174219540809, 0.6424308865858692], 
             UndirectedEdge[123, 257] -> 
             RGBColor[
              0.9281390191048005, 0.9446282431724699, 0.9615050363377757], 
             UndirectedEdge[121, 286] -> 
             RGBColor[
              0.9554920622161343, 0.8483139214765438, 0.4652746897694742], 
             UndirectedEdge[176, 230] -> 
             RGBColor[
              0.993358948331064, 0.9882037869304945, 0.518540693535526], 
             UndirectedEdge[39, 64] -> 
             RGBColor[
              0.7593006351357386, 0.8103856166920048, 0.9359933430022214], 
             UndirectedEdge[269, 277] -> 
             RGBColor[
              0.9361757248562876, 0.8064008148870814, 0.5833451150219063], 
             UndirectedEdge[154, 203] -> 
             RGBColor[
              0.9230519316957426, 0.7309689863735108, 0.2568578741579889], 
             UndirectedEdge[107, 137] -> 
             RGBColor[
              0.9880512224575202, 0.9887994652091809, 0.8240666414317164], 
             UndirectedEdge[192, 218] -> 
             RGBColor[
              0.8651379023932092, 0.8950439489282978, 0.963512195844326], 
             UndirectedEdge[247, 270] -> 
             RGBColor[
              0.9667068761690172, 0.972232291604243, 0.8098645684129129], 
             UndirectedEdge[28, 240] -> 
             RGBColor[
              0.9755662647716112, 0.9793414385519659, 0.8346859535691804], 
             UndirectedEdge[31, 194] -> 
             RGBColor[
              0.9491997982247571, 0.9616338732104956, 0.9708756701776047], 
             UndirectedEdge[58, 187] -> 
             RGBColor[
              0.9643214767081383, 0.9043363463016698, 0.5942479413708903], 
             UndirectedEdge[8, 121] -> 
             RGBColor[
              0.9889089310998995, 0.9728103559089357, 0.5337763841375649], 
             UndirectedEdge[62, 186] -> 
             RGBColor[
              0.9126189805652574, 0.7524078354348716, 0.5989646255095362], 
             UndirectedEdge[271, 289] -> 
             RGBColor[
              0.9497183279977356, 0.825648932755568, 0.44725887813961696`], 
             UndirectedEdge[236, 294] -> 
             RGBColor[
              0.9901300213148103, 0.988709358046454, 0.7058602185574485], 
             UndirectedEdge[115, 211] -> 
             RGBColor[
              0.8931437207062047, 0.5742428991671833, 0.43282279781530625`], 
             UndirectedEdge[43, 284] -> 
             RGBColor[
              0.9762192264218543, 0.9811764982111041, 0.8978925215437469], 
             UndirectedEdge[87, 181] -> 
             RGBColor[
              0.9770233123277743, 0.9810120070047524, 0.862309999384855], 
             UndirectedEdge[77, 205] -> 
             RGBColor[
              0.9600365806060105, 0.8725292000351581, 0.3217848886485954], 
             UndirectedEdge[132, 267] -> 
             RGBColor[
              0.9737723097879777, 0.9216519114192814, 0.42892159533113017`], 
             UndirectedEdge[108, 280] -> 
             RGBColor[
              0.9447179912067534, 0.8094646555443272, 0.5108889653755203], 
             UndirectedEdge[40, 97] -> 
             RGBColor[
              0.9770828405483598, 0.9794911010793367, 0.7542491158542337], 
             UndirectedEdge[35, 262] -> 
             RGBColor[
              0.9511604121093529, 0.8517204872910832, 0.5833194850050978], 
             UndirectedEdge[201, 216] -> 
             RGBColor[
              0.9126569020427429, 0.9292968746920011, 0.813919126263694], 
             UndirectedEdge[244, 279] -> 
             RGBColor[
              0.9679232663994151, 0.9749751770107058, 0.9112991636590946], 
             UndirectedEdge[143, 163] -> 
             RGBColor[
              0.8666950389815509, 0.8966690358257858, 0.9843526845514228], 
             UndirectedEdge[102, 165] -> 
             RGBColor[
              0.9448689680604547, 0.8478061150945618, 0.5945726974501687], 
             UndirectedEdge[7, 282] -> 
             RGBColor[
              0.973619138007688, 0.9798457768376063, 0.9295400975089378], 
             UndirectedEdge[10, 122] -> 
             RGBColor[
              0.980001680154583, 0.944006356906716, 0.3935414265331689], 
             UndirectedEdge[113, 193] -> 
             RGBColor[
              0.9319123950890207, 0.8446484555136611, 0.6215519644155449], 
             UndirectedEdge[22, 100] -> 
             RGBColor[
              0.9871483068289895, 0.9889535088474073, 0.8626493451668183], 
             UndirectedEdge[116, 254] -> 
             RGBColor[
              0.889046388490782, 0.5497306579626473, 0.24432938292604212`], 
             UndirectedEdge[174, 298] -> 
             RGBColor[
              0.9822571782202412, 0.9833417673648039, 0.7448280703966199], 
             UndirectedEdge[159, 271] -> 
             RGBColor[
              0.9395749773691815, 0.7927192828310592, 0.2984801616280529], 
             UndirectedEdge[11, 101] -> 
             RGBColor[
              0.9838570708028526, 0.9859907524506268, 0.84546419770767], 
             UndirectedEdge[148, 225] -> 
             RGBColor[
              0.9910160058056922, 0.980856214206828, 0.4621841687575319], 
             UndirectedEdge[239, 248] -> 
             RGBColor[
              0.9460632172027907, 0.9567461698525412, 0.8717895185862171], 
             UndirectedEdge[22, 119] -> 
             RGBColor[
              0.9516083646911632, 0.8480148201154756, 0.5621982050423568], 
             UndirectedEdge[38, 247] -> 
             RGBColor[
              0.9789590340181302, 0.9395166037605287, 0.4721991755966414], 
             UndirectedEdge[157, 222] -> 
             RGBColor[
              0.940830091616639, 0.9508876613536341, 0.7457773063226929], 
             UndirectedEdge[42, 203] -> 
             RGBColor[
              0.9287248339520937, 0.8003512991913718, 0.5956294596226998], 
             UndirectedEdge[155, 241] -> 
             RGBColor[
              0.7887356969635426, 0.8330596778540538, 0.8882754922912979], 
             UndirectedEdge[103, 154] -> 
             RGBColor[
              0.9260403597646236, 0.7444817025954951, 0.2593485412919776], 
             UndirectedEdge[88, 107] -> 
             RGBColor[
              0.8338411096610856, 0.8702552162998392, 0.943210412534362], 
             UndirectedEdge[58, 176] -> 
             RGBColor[
              0.9698507036207796, 0.90584512170516, 0.44108816042672083`], 
             UndirectedEdge[48, 119] -> 
             RGBColor[
              0.9555540923288257, 0.8489200985025532, 0.4440070277678193], 
             UndirectedEdge[206, 219] -> 
             RGBColor[
              0.9851898835554604, 0.9879717495537749, 0.8874074117008827], 
             UndirectedEdge[1, 125] -> 
             RGBColor[
              0.8968105641385697, 0.6086533837387778, 0.2500764603437277], 
             UndirectedEdge[191, 278] -> 
             RGBColor[
              0.9891524941051968, 0.9743450826043806, 0.47408302625235027`], 
             UndirectedEdge[90, 118] -> 
             RGBColor[
              0.9043076976787947, 0.6532791341600486, 0.2416012273432252], 
             UndirectedEdge[101, 283] -> 
             RGBColor[
              0.9669304081698952, 0.9733668751738336, 0.8741166223646089], 
             UndirectedEdge[5, 226] -> 
             RGBColor[
              0.9590936947959434, 0.8639286164698767, 0.3891494974961963], 
             UndirectedEdge[3, 241] -> 
             RGBColor[
              0.7910068738125683, 0.8333351639024789, 0.8023919438825019], 
             UndirectedEdge[194, 241] -> 
             RGBColor[
              0.7705567324344578, 0.8204618215933122, 0.9620378593009105], 
             UndirectedEdge[139, 235] -> 
             RGBColor[
              0.9948619975569494, 0.9914186572430757, 0.6821383260285675], 
             UndirectedEdge[40, 94] -> 
             RGBColor[
              0.9142331553876903, 0.933810294123156, 0.9695470057201567], 
             UndirectedEdge[161, 177] -> 
             RGBColor[
              0.9424314238768896, 0.8798570487213272, 0.6249760089235435], 
             UndirectedEdge[34, 295] -> 
             RGBColor[
              0.9821446714325257, 0.9857149805489482, 0.8932045693363277], 
             UndirectedEdge[1, 281] -> 
             RGBColor[
              0.6459666423344524, 0.6827388170213485, 0.6411775517383702], 
             UndirectedEdge[191, 295] -> 
             RGBColor[
              0.9904076282405173, 0.9889185538702323, 0.7081213078740006], 
             UndirectedEdge[144, 297] -> 
             RGBColor[
              0.9850847648063392, 0.9868974590158115, 0.8429872204728415], 
             UndirectedEdge[141, 294] -> 
             RGBColor[
              0.986471606834795, 0.9653693530458977, 0.4579257915225565], 
             UndirectedEdge[80, 201] -> 
             RGBColor[
              0.9182728628024937, 0.9337748893606326, 0.8144547816143863], 
             UndirectedEdge[113, 115] -> 
             RGBColor[
              0.9537586415075059, 0.860941350322622, 0.5845719676426544], 
             UndirectedEdge[129, 253] -> 
             RGBColor[
              0.9729933409820419, 0.9297535630738366, 0.5708093864430854], 
             UndirectedEdge[37, 108] -> 
             RGBColor[
              0.9535951811917107, 0.9631234123176966, 0.8886379489244187], 
             UndirectedEdge[265, 276] -> 
             RGBColor[
              0.8044374502651772, 0.8473895755475995, 0.9491985893636146], 
             UndirectedEdge[59, 194] -> 
             RGBColor[
              0.9688394749340151, 0.9614198655248885, 0.6780042138127871], 
             UndirectedEdge[103, 225] -> 
             RGBColor[
              0.9488697350649951, 0.8234463403498561, 0.37782720189290375`], 
             UndirectedEdge[46, 265] -> 
             RGBColor[
              0.9726739697116864, 0.9791408718700194, 0.9311400208946963], 
             UndirectedEdge[51, 149] -> 
             RGBColor[
              0.9882764686253122, 0.9889794693307072, 0.8242234549032517], 
             UndirectedEdge[52, 124] -> 
             RGBColor[
              0.9787263301754382, 0.9835184143809991, 0.9147912498401867], 
             UndirectedEdge[82, 258] -> 
             RGBColor[
              0.9104726533955907, 0.9303610690567266, 0.953562174803058], 
             UndirectedEdge[45, 132] -> 
             RGBColor[
              0.9938618867240245, 0.9892795212981653, 0.5732824338333055], 
             UndirectedEdge[74, 287] -> 
             RGBColor[
              0.9743476630688587, 0.9263566116532133, 0.5226939946764775], 
             UndirectedEdge[128, 269] -> 
             RGBColor[
              0.8269730750092184, 0.720827389286746, 0.6067151985875454], 
             UndirectedEdge[14, 249] -> 
             RGBColor[
              0.9193048041100007, 0.9380176426095516, 0.9756943111575338], 
             UndirectedEdge[101, 198] -> 
             RGBColor[
              0.9888498642164789, 0.975470381940666, 0.5786964177617606], 
             UndirectedEdge[164, 297] -> 
             RGBColor[
              0.9654799895776061, 0.9722762497500954, 0.8761729911907965], 
             UndirectedEdge[68, 235] -> 
             RGBColor[
              0.6236341387300512, 0.686869490629664, 0.794658563082169], 
             UndirectedEdge[108, 177] -> 
             RGBColor[
              0.966133332786234, 0.8962691828297984, 0.5282185283457496], 
             UndirectedEdge[62, 276] -> 
             RGBColor[
              0.7586335916584035, 0.6312850089348421, 0.5928997472649467], 
             UndirectedEdge[13, 107] -> 
             RGBColor[
              0.9881243847838352, 0.9887860729586873, 0.8196814941903687], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.9754244464696435, 0.9790381035440868, 0.8192499066011061], 
             UndirectedEdge[62, 135] -> 
             RGBColor[
              0.9094383373387522, 0.7500357169243694, 0.6043486248473975], 
             UndirectedEdge[18, 35] -> 
             RGBColor[
              0.9518419768651456, 0.852136261774888, 0.5780218496003823], 
             UndirectedEdge[42, 202] -> 
             RGBColor[
              0.9160761504327382, 0.7429165815050697, 0.5850750880465452], 
             UndirectedEdge[121, 255] -> 
             RGBColor[
              0.9777013390983563, 0.9807362063385112, 0.8153957212894011], 
             UndirectedEdge[128, 281] -> 
             RGBColor[
              0.538237134677873, 0.6306886729264819, 0.9589643027947103], 
             UndirectedEdge[82, 181] -> 
             RGBColor[
              0.9023019791173383, 0.924267393558257, 0.9673929951029907], 
             UndirectedEdge[136, 204] -> 
             RGBColor[
              0.9382164170506314, 0.7862064393279697, 0.5318825164186445], 
             UndirectedEdge[118, 166] -> 
             RGBColor[
              0.9351972286480346, 0.7675542757062741, 0.30911742889406696`], 
             UndirectedEdge[39, 263] -> 
             RGBColor[
              0.9551623415947359, 0.8697907518992191, 0.5882494667275266], 
             UndirectedEdge[52, 84] -> 
             RGBColor[
              0.9897190055304623, 0.9892777647816509, 0.7663436871262883], 
             UndirectedEdge[129, 165] -> 
             RGBColor[
              0.9536651805610105, 0.8537482670091991, 0.5520055086697535], 
             UndirectedEdge[141, 236] -> 
             RGBColor[
              0.9830319143722981, 0.9654241181839982, 0.6223047984144596], 
             UndirectedEdge[97, 178] -> 
             RGBColor[
              0.8941677166664252, 0.9142202144189737, 0.7684207705211797], 
             UndirectedEdge[115, 227] -> 
             RGBColor[
              0.9887247781529194, 0.9879529563188589, 0.7170321187659188], 
             UndirectedEdge[256, 281] -> 
             RGBColor[
              0.25008145575627344`, 0.37902706679548126`, 0.9375954230585922],
              UndirectedEdge[221, 297] -> 
             RGBColor[
              0.9940078927178422, 0.9913733488241276, 0.718673106942661], 
             UndirectedEdge[224, 262] -> 
             RGBColor[
              0.9826524654894173, 0.9865828176827638, 0.9142490303515083], 
             UndirectedEdge[73, 119] -> 
             RGBColor[
              0.9387054680445139, 0.8387833687580613, 0.6015719642040005], 
             UndirectedEdge[3, 227] -> 
             RGBColor[
              0.9939525783383085, 0.98947350149079, 0.5831536563643525], 
             UndirectedEdge[45, 188] -> 
             RGBColor[
              0.9944890869571126, 0.9906210391770699, 0.6415493085737838], 
             UndirectedEdge[260, 300] -> 
             RGBColor[
              0.9744084427263433, 0.9779755788791156, 0.7967858946027532], 
             UndirectedEdge[23, 291] -> 
             RGBColor[
              0.6058850020073849, 0.628280312165888, 0.6166241363694053], 
             UndirectedEdge[142, 149] -> 
             RGBColor[
              0.9871157090788276, 0.9884994654280763, 0.8434602445379116], 
             UndirectedEdge[81, 97] -> 
             RGBColor[
              0.9843318537374096, 0.9848974032465603, 0.7419784273706105], 
             UndirectedEdge[181, 201] -> 
             RGBColor[
              0.978052702559519, 0.9807739823744714, 0.7970060688651559], 
             UndirectedEdge[56, 57] -> 
             RGBColor[
              0.9911844287903602, 0.9860571660204293, 0.606509272392741], 
             UndirectedEdge[197, 243] -> 
             RGBColor[
              0.7180737953222325, 0.7782353873701409, 0.9681406682712594], 
             UndirectedEdge[65, 200] -> 
             RGBColor[
              0.9465310637775537, 0.8201314646309767, 0.30494371664384934`], 
             UndirectedEdge[8, 173] -> 
             RGBColor[
              0.9861801913737116, 0.9720678942091142, 0.6070525943207343], 
             UndirectedEdge[53, 273] -> 
             RGBColor[
              0.8817561469315954, 0.46253163330766606`, 0.2983347930251128], 
             UndirectedEdge[26, 253] -> 
             RGBColor[
              0.9764350020032202, 0.9307570410608634, 0.48326168644107353`], 
             UndirectedEdge[114, 206] -> 
             RGBColor[
              0.971574963289072, 0.9259791382693012, 0.5724083771424362], 
             UndirectedEdge[9, 45] -> 
             RGBColor[
              0.9658569494991409, 0.971205965673017, 0.7801638839658309], 
             UndirectedEdge[47, 190] -> 
             RGBColor[
              0.9832475687710813, 0.9547335601057798, 0.42502337491169134`], 
             UndirectedEdge[191, 282] -> 
             RGBColor[
              0.9885324962560684, 0.9880092086640995, 0.7331994411105218], 
             UndirectedEdge[59, 155] -> 
             RGBColor[
              0.9870184394630999, 0.97401772178563, 0.6042418468031744], 
             UndirectedEdge[214, 265] -> 
             RGBColor[
              0.9820838983432979, 0.9827605442527029, 0.7092578145089152], 
             UndirectedEdge[167, 282] -> 
             RGBColor[
              0.7086495013011938, 0.7686926352628045, 0.9309385664203975], 
             UndirectedEdge[28, 221] -> 
             RGBColor[
              0.9949585755471387, 0.991625227798558, 0.6926502442504054], 
             UndirectedEdge[136, 197] -> 
             RGBColor[
              0.741429557996159, 0.794893656426324, 0.8945522704020419], 
             UndirectedEdge[121, 234] -> 
             RGBColor[
              0.9228084870553621, 0.937607440488979, 0.8323944162036656], 
             UndirectedEdge[141, 146] -> 
             RGBColor[
              0.9849463642173342, 0.9662157923940375, 0.5905774100448291], 
             UndirectedEdge[32, 167] -> 
             RGBColor[
              0.7071374797029087, 0.7675649720305118, 0.9334980245879023], 
             UndirectedEdge[101, 136] -> 
             RGBColor[
              0.9909661907538294, 0.9905323019654699, 0.7993771281653459], 
             UndirectedEdge[91, 274] -> 
             RGBColor[
              0.926359394306111, 0.9400912240760662, 0.804554430576338], 
             UndirectedEdge[84, 295] -> 
             RGBColor[
              0.9907808658126402, 0.989716871296896, 0.7487459142442807], 
             UndirectedEdge[73, 122] -> 
             RGBColor[
              0.9639621541334946, 0.9356002065348757, 0.6391717157455288], 
             UndirectedEdge[157, 248] -> 
             RGBColor[
              0.9934749864579021, 0.9897822958766725, 0.6278705936864741], 
             UndirectedEdge[125, 167] -> 
             RGBColor[
              0.7178824888908737, 0.4877993809234075, 0.45281122120794604`], 
             UndirectedEdge[20, 208] -> 
             RGBColor[
              0.9712239781633198, 0.9477457694908654, 0.6411652350848384], 
             UndirectedEdge[77, 103] -> 
             RGBColor[
              0.9415836339837894, 0.7993694157579914, 0.3069372146500292], 
             UndirectedEdge[46, 276] -> 
             RGBColor[
              0.8059920657857784, 0.8485490052574146, 0.9465670307959024], 
             UndirectedEdge[3, 291] -> 
             RGBColor[
              0.9767979760598526, 0.9321559720865273, 0.46983063486262133`], 
             UndirectedEdge[79, 297] -> 
             RGBColor[
              0.993768781853789, 0.990861914863735, 0.6926473650116896], 
             UndirectedEdge[18, 262] -> 
             RGBColor[
              0.9840674199449102, 0.9875455530037898, 0.9077099574838684], 
             UndirectedEdge[127, 225] -> 
             RGBColor[
              0.9522495911512051, 0.9600633035697255, 0.7525444421549635], 
             UndirectedEdge[109, 292] -> 
             RGBColor[
              0.8156798702233903, 0.8562794762028272, 0.9521295584032452], 
             UndirectedEdge[267, 287] -> 
             RGBColor[
              0.9545747688699522, 0.8576111261699615, 0.28230799664679085`], 
             UndirectedEdge[218, 262] -> 
             RGBColor[
              0.9726154023696919, 0.9790971924422551, 0.9312391601278838], 
             UndirectedEdge[207, 225] -> 
             RGBColor[
              0.7287061338953518, 0.7819615801935411, 0.7323263519532739], 
             UndirectedEdge[203, 299] -> 
             RGBColor[
              0.9230421428482042, 0.7961131574706437, 0.6052487733783731], 
             UndirectedEdge[142, 163] -> 
             RGBColor[
              0.8936586727792464, 0.9153664377474298, 0.875476607156829], 
             UndirectedEdge[2, 54] -> 
             RGBColor[
              0.9756370899989177, 0.9598138747543361, 0.6523265022605707], 
             UndirectedEdge[90, 195] -> 
             RGBColor[
              0.9534217880494119, 0.8444653950055256, 0.3260366647057712], 
             UndirectedEdge[88, 93] -> 
             RGBColor[
              0.7754425354633506, 0.8248584142351949, 0.978157641666585], 
             UndirectedEdge[77, 82] -> 
             RGBColor[
              0.9108767312448443, 0.9088065227511017, 0.6784032294257369], 
             UndirectedEdge[167, 168] -> 
             RGBColor[
              0.7134646963387308, 0.7708177720975633, 0.8571359797549258], 
             UndirectedEdge[18, 26] -> 
             RGBColor[
              0.9897722190136773, 0.9896188266753587, 0.788653859651604], 
             UndirectedEdge[129, 224] -> 
             RGBColor[
              0.9849156035370061, 0.987652613367306, 0.8827406325212558], 
             UndirectedEdge[38, 289] -> 
             RGBColor[
              0.9790536879991771, 0.9397190590550024, 0.4825016772969304], 
             UndirectedEdge[31, 241] -> 
             RGBColor[
              0.7661441587961856, 0.8171709313988149, 0.9695071954869829], 
             UndirectedEdge[5, 197] -> 
             RGBColor[
              0.7437308977220384, 0.7941973869822242, 0.736625814635845], 
             UndirectedEdge[59, 241] -> 
             RGBColor[
              0.7857838355054436, 0.8169569237132077, 0.6766357391221653], 
             UndirectedEdge[155, 226] -> 
             RGBColor[
              0.9573929618517105, 0.8648732522530775, 0.5371223445699862], 
             UndirectedEdge[15, 186] -> 
             RGBColor[
              0.9225567677075583, 0.9408271636263659, 0.9835104524641332], 
             UndirectedEdge[198, 256] -> 
             RGBColor[
              0.5817317171416023, 0.632446951599333, 0.6639641982749753], 
             UndirectedEdge[72, 291] -> 
             RGBColor[
              0.9744223286993272, 0.9318372847968274, 0.5574455300079824], 
             UndirectedEdge[230, 297] -> 
             RGBColor[
              0.992880888062961, 0.9889627998249866, 0.5960056053253658], 
             UndirectedEdge[138, 231] -> 
             RGBColor[
              0.951275127724666, 0.9609382062594254, 0.8738585829317589], 
             UndirectedEdge[54, 165] -> 
             RGBColor[
              0.9492016608485272, 0.8295005429075367, 0.3134408498138357], 
             UndirectedEdge[103, 167] -> 
             RGBColor[
              0.6691690803130245, 0.6045197742051504, 0.5954129330155902], 
             UndirectedEdge[78, 131] -> 
             RGBColor[
              0.8652419454063437, 0.46445993197313135`, 0.44607782338100677`],
              UndirectedEdge[16, 239] -> 
             RGBColor[
              0.9308133986658591, 0.9047380352572589, 0.650933022382959], 
             UndirectedEdge[12, 87] -> 
             RGBColor[
              0.6560277433990596, 0.7211960416678714, 0.8581540371162215], 
             UndirectedEdge[125, 281] -> 
             RGBColor[
              0.6803234102572995, 0.455267594785187, 0.4504179899296038], 
             UndirectedEdge[148, 205] -> 
             RGBColor[
              0.9650242305756971, 0.8893537145388153, 0.3411609669421637], 
             UndirectedEdge[103, 269] -> 
             RGBColor[
              0.9015664026940082, 0.6458608113580836, 0.23957398189091197`], 
             UndirectedEdge[40, 169] -> 
             RGBColor[
              0.9744176425394948, 0.9797456992678422, 0.8970380062342213], 
             UndirectedEdge[38, 53] -> 
             RGBColor[
              0.8717126262153387, 0.4291247430451252, 0.21915973718831835`], 
             UndirectedEdge[118, 285] -> 
             RGBColor[
              0.9392247786983203, 0.7846979765412413, 0.5070506100830148], 
             UndirectedEdge[74, 267] -> 
             RGBColor[
              0.9734281322789684, 0.9227109784867693, 0.52195411861877], 
             UndirectedEdge[3, 200] -> 
             RGBColor[
              0.9846878598489395, 0.9587704027399282, 0.5004813435036906], 
             UndirectedEdge[124, 273] -> 
             RGBColor[
              0.9830455388002636, 0.9838973174435477, 0.7409221492734391], 
             UndirectedEdge[131, 182] -> 
             RGBColor[
              0.9653228188959551, 0.9723884281585107, 0.886711863756867], 
             UndirectedEdge[62, 207] -> 
             RGBColor[
              0.6718047239255149, 0.5607934225133681, 0.5860642607323912], 
             UndirectedEdge[75, 262] -> 
             RGBColor[
              0.9869659099462572, 0.988744153107142, 0.8596744771098765], 
             UndirectedEdge[197, 283] -> 
             RGBColor[
              0.7173937754122247, 0.7777282296346876, 0.969291764601305], 
             UndirectedEdge[246, 278] -> 
             RGBColor[
              0.9757178918736568, 0.9297528889590363, 0.36016902453085514`], 
             UndirectedEdge[225, 265] -> 
             RGBColor[
              0.9822169055541483, 0.9830450332276199, 0.7237348285846232], 
             UndirectedEdge[101, 204] -> 
             RGBColor[
              0.9404135204465549, 0.7871149980451658, 0.49547082722686936`], 
             UndirectedEdge[87, 140] -> 
             RGBColor[
              0.7612763436814123, 0.8102723101907998, 0.8654364155335796], 
             UndirectedEdge[57, 247] -> 
             RGBColor[
              0.9928643325876931, 0.9905544572808207, 0.7124743072950098], 
             UndirectedEdge[40, 66] -> 
             RGBColor[
              0.9272332072781386, 0.9441761826235914, 0.9707869622747509], 
             UndirectedEdge[167, 293] -> 
             RGBColor[
              0.6945707651548028, 0.7581927368966408, 0.9547701943937676], 
             UndirectedEdge[42, 140] -> 
             RGBColor[
              0.7445501620181171, 0.7991705487598736, 0.9552171971537269], 
             UndirectedEdge[107, 150] -> 
             RGBColor[
              0.9874188977190381, 0.9872771074627699, 0.7428935809486781], 
             UndirectedEdge[91, 143] -> 
             RGBColor[
              0.9665401803506091, 0.9720512550746473, 0.8056466434289247], 
             UndirectedEdge[91, 142] -> 
             RGBColor[
              0.9935038141483046, 0.9907486569962912, 0.6967705660343309], 
             UndirectedEdge[44, 283] -> 
             RGBColor[
              0.9667358355479335, 0.9711229248786055, 0.720078345409065], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.8580805375972463, 0.45880309409071424`, 0.4472487499226616], 
             UndirectedEdge[199, 233] -> 
             RGBColor[
              0.6500302955838001, 0.7214210582662077, 0.9687925159255559], 
             UndirectedEdge[249, 286] -> 
             RGBColor[
              0.9003187047427994, 0.8079991982608179, 0.6201172808440079], 
             UndirectedEdge[48, 266] -> 
             RGBColor[
              0.9940957306099983, 0.98977968972502, 0.5987348977043789], 
             UndirectedEdge[113, 169] -> 
             RGBColor[
              0.9559195786308319, 0.8618573727488341, 0.5497636333698261], 
             UndirectedEdge[18, 33] -> 
             RGBColor[
              0.9887017236848297, 0.9873291454106335, 0.672137049437898], 
             UndirectedEdge[269, 293] -> 
             RGBColor[
              0.9269680875357866, 0.799533774049574, 0.5989312432690894], 
             UndirectedEdge[189, 257] -> 
             RGBColor[
              0.8739083297323811, 0.9022947967916635, 0.987835350708692], 
             UndirectedEdge[11, 197] -> 
             RGBColor[
              0.7343204380451821, 0.7903521069114808, 0.940639339944366], 
             UndirectedEdge[221, 296] -> 
             RGBColor[
              0.9826520536056288, 0.951726496769776, 0.5075939576227403], 
             UndirectedEdge[126, 157] -> 
             RGBColor[
              0.9806264225365611, 0.9817861175476206, 0.720655807033292], 
             UndirectedEdge[24, 87] -> 
             RGBColor[
              0.9572541494907885, 0.9659163417060603, 0.8835749662166718], 
             UndirectedEdge[53, 137] -> 
             RGBColor[
              0.8822342354379201, 0.46366746899295574`, 0.35860405315510613`],
              UndirectedEdge[27, 140] -> 
             RGBColor[
              0.7602548502896177, 0.80984989642211, 0.8823652045757742], 
             UndirectedEdge[115, 200] -> 
             RGBColor[
              0.9794600596635503, 0.957249857567997, 0.634359805905257], 
             UndirectedEdge[1, 5] -> 
             RGBColor[
              0.9820345699830113, 0.9505243524059044, 0.4303005815921416], 
             UndirectedEdge[40, 42] -> 
             RGBColor[
              0.959728933706518, 0.9694864852129159, 0.9530525902453293], 
             UndirectedEdge[82, 167] -> 
             RGBColor[
              0.6384621775740793, 0.7139568811982608, 0.9668789477912978], 
             UndirectedEdge[52, 57] -> 
             RGBColor[
              0.9881716247136629, 0.9893766770907897, 0.8456903195559858], 
             UndirectedEdge[27, 203] -> 
             RGBColor[
              0.9444295222235943, 0.8110306468536083, 0.5227774670447471], 
             UndirectedEdge[251, 270] -> 
             RGBColor[
              0.9219396342606625, 0.9405081205496287, 0.9894510777431849], 
             UndirectedEdge[200, 264] -> 
             RGBColor[
              0.9848976170261067, 0.9592190521321851, 0.5233121177670994], 
             UndirectedEdge[84, 271] -> 
             RGBColor[
              0.9496375730794612, 0.8254762061509539, 0.4384692036470357], 
             UndirectedEdge[80, 145] -> 
             RGBColor[
              0.9178256378191105, 0.9342536542820754, 0.8701107273733661], 
             UndirectedEdge[199, 259] -> 
             RGBColor[
              0.9560412263667792, 0.9640543670450986, 0.8313523256259836], 
             UndirectedEdge[273, 274] -> 
             RGBColor[
              0.9260266064487097, 0.9393794244990984, 0.7683325260267952], 
             UndirectedEdge[281, 294] -> 
             RGBColor[
              0.657402812644927, 0.720657363249658, 0.7415855288913649], 
             UndirectedEdge[18, 183] -> 
             RGBColor[
              0.9897885329474139, 0.9896537205300293, 0.790429530660892], 
             UndirectedEdge[77, 269] -> 
             RGBColor[
              0.9387250234650186, 0.7864461707113983, 0.3045548704619718], 
             UndirectedEdge[134, 144] -> 
             RGBColor[
              0.9823835471520673, 0.9857804360976428, 0.8877533875313303], 
             UndirectedEdge[200, 210] -> 
             RGBColor[
              0.9841038344410957, 0.9575212314465771, 0.4369137820469331], 
             UndirectedEdge[87, 151] -> 
             RGBColor[
              0.9378629943578085, 0.7769976283190164, 0.4995170470658064], 
             UndirectedEdge[109, 290] -> 
             RGBColor[
              0.8134935318362622, 0.8546489086135076, 0.9558304590042761], 
             UndirectedEdge[247, 278] -> 
             RGBColor[
              0.9895118326145473, 0.9751136713411848, 0.5131948054149227], 
             UndirectedEdge[156, 205] -> 
             RGBColor[
              0.9363352590154502, 0.785297547553214, 0.2676320588815363], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.9928782316504656, 0.9905841859706802, 0.7139871345027176], 
             UndirectedEdge[64, 121] -> 
             RGBColor[
              0.765709717712579, 0.813011430595378, 0.8179101633744832], 
             UndirectedEdge[106, 264] -> 
             RGBColor[
              0.9301949150564922, 0.9435626049253741, 0.8384026850379127], 
             UndirectedEdge[91, 107] -> 
             RGBColor[
              0.9876668775554345, 0.9878075112582143, 0.7698846557862693], 
             UndirectedEdge[7, 299] -> 
             RGBColor[
              0.9557442747238248, 0.9665147330679036, 0.959797578537523], 
             UndirectedEdge[160, 221] -> 
             RGBColor[
              0.9910562960279807, 0.9800759798703303, 0.5402428524255667], 
             UndirectedEdge[8, 234] -> 
             RGBColor[
              0.9168827907069814, 0.91905768104974, 0.6870115417325717], 
             UndirectedEdge[49, 174] -> 
             RGBColor[
              0.9171512120012394, 0.9358699004251824, 0.9605622827231546], 
             UndirectedEdge[79, 245] -> 
             RGBColor[
              0.9597407681107399, 0.8656278123308905, 0.4409292680036796], 
             UndirectedEdge[13, 147] -> 
             RGBColor[
              0.8686742638569274, 0.8953377937213787, 0.8486385571158231], 
             UndirectedEdge[1, 197] -> 
             RGBColor[
              0.7323937008953851, 0.7564905350280543, 0.6469904904032595], 
             UndirectedEdge[129, 175] -> 
             RGBColor[
              0.9860282054006853, 0.9884823900155195, 0.8808572877790876], 
             UndirectedEdge[116, 283] -> 
             RGBColor[
              0.8785108303099153, 0.5620823899594338, 0.45711616366784796`], 
             UndirectedEdge[62, 265] -> 
             RGBColor[
              0.9253154955843115, 0.7618768755474469, 0.5774727373637405], 
             UndirectedEdge[31, 291] -> 
             RGBColor[
              0.9519352610434699, 0.9159917395828634, 0.6369458864671025], 
             UndirectedEdge[92, 277] -> 
             RGBColor[
              0.8694272191791126, 0.41603935448755736`, 0.41931153078031935`],
              UndirectedEdge[124, 289] -> 
             RGBColor[
              0.9835136920305153, 0.9848986498655037, 0.7918777392794996], 
             UndirectedEdge[80, 277] -> 
             RGBColor[
              0.9078383642615375, 0.9283711970803055, 0.9571468262075079], 
             UndirectedEdge[119, 244] -> 
             RGBColor[
              0.9523039388314583, 0.8483024578979277, 0.5506707414494945], 
             UndirectedEdge[252, 268] -> 
             RGBColor[
              0.9122638774774917, 0.7411084483730854, 0.5922175398363578], 
             UndirectedEdge[3, 194] -> 
             RGBColor[
              0.9740625132411398, 0.9777981057141596, 0.8037604185731236], 
             UndirectedEdge[1, 237] -> 
             RGBColor[
              0.9741728037634982, 0.9478340853798948, 0.6316925728413245], 
             UndirectedEdge[149, 281] -> 
             RGBColor[
              0.651388046465853, 0.7192067058176629, 0.9289108416347465], 
             UndirectedEdge[29, 209] -> 
             RGBColor[
              0.8084596745421672, 0.711441377714613, 0.6058621458246547], 
             UndirectedEdge[123, 287] -> 
             RGBColor[
              0.9632145306422373, 0.9195502663313957, 0.6085659596162303], 
             UndirectedEdge[17, 81] -> 
             RGBColor[
              0.9239566037154714, 0.9411896437032514, 0.95751233106902], 
             UndirectedEdge[176, 187] -> 
             RGBColor[
              0.9886437920171869, 0.988436226222598, 0.7603070352938086], 
             UndirectedEdge[246, 270] -> 
             RGBColor[
              0.9529129354281266, 0.9268715092220945, 0.6568387875288454], 
             UndirectedEdge[45, 131] -> 
             RGBColor[
              0.9663219506223555, 0.971552762749341, 0.779376758355945], 
             UndirectedEdge[4, 158] -> 
             RGBColor[
              0.9634050831649379, 0.9722281514598632, 0.9468298281055597], 
             UndirectedEdge[169, 264] -> 
             RGBColor[
              0.9916555487343542, 0.990515574669864, 0.7660154055468621], 
             UndirectedEdge[42, 181] -> 
             RGBColor[
              0.9602971306644791, 0.9699102455738262, 0.9520907810050021], 
             UndirectedEdge[8, 263] -> 
             RGBColor[
              0.9556457278231956, 0.8538668063633532, 0.3247834126286947], 
             UndirectedEdge[145, 205] -> 
             RGBColor[
              0.9674745555548525, 0.8983663014126111, 0.5135390343743882], 
             UndirectedEdge[167, 269] -> 
             RGBColor[
              0.6663104697942537, 0.5915965291585573, 0.5930305888275328], 
             UndirectedEdge[187, 288] -> 
             RGBColor[
              0.9739832687401597, 0.9400135209362801, 0.6157118976881392], 
             UndirectedEdge[47, 131] -> 
             RGBColor[
              0.9659954630185141, 0.9708544387776847, 0.7438405975257516], 
             UndirectedEdge[43, 97] -> 
             RGBColor[
              0.9907817497179534, 0.9890993047995811, 0.7038141313861659], 
             UndirectedEdge[104, 114] -> 
             RGBColor[
              0.9754868308885862, 0.9273933748753811, 0.4927920353044374], 
             UndirectedEdge[26, 129] -> 
             RGBColor[
              0.9913537923054734, 0.990272847876096, 0.762443097226067], 
             UndirectedEdge[28, 79] -> 
             RGBColor[
              0.9947194646830857, 0.9911137938381653, 0.666624502319434], 
             UndirectedEdge[53, 247] -> 
             RGBColor[
              0.8820051464310653, 0.463064218059321, 0.3254368518956271], 
             UndirectedEdge[150, 281] -> 
             RGBColor[
              0.6575281716989336, 0.7209254935904335, 0.7552300882935746], 
             UndirectedEdge[76, 248] -> 
             RGBColor[
              0.9934081796402765, 0.9896394028489768, 0.6205990838718105], 
             UndirectedEdge[194, 210] -> 
             RGBColor[
              0.973478487833296, 0.9765489344208085, 0.7401928571163662], 
             UndirectedEdge[60, 265] -> 
             RGBColor[
              0.9801950371862842, 0.9839063117362015, 0.8806235213743623], 
             UndirectedEdge[78, 178] -> 
             RGBColor[
              0.8171808119154906, 0.4263274019550226, 0.44331143780490256`], 
             UndirectedEdge[120, 190] -> 
             RGBColor[
              0.9481313864472526, 0.9315207965118516, 0.6716710862386585], 
             UndirectedEdge[96, 267] -> 
             RGBColor[
              0.9526281786091209, 0.9086951337097209, 0.6241894904125315], 
             UndirectedEdge[159, 212] -> 
             RGBColor[
              0.7559290641195278, 0.7802120081380319, 0.6557000381827256], 
             UndirectedEdge[34, 147] -> 
             RGBColor[
              0.8596351727029881, 0.890474147513332, 0.949244384767707], 
             UndirectedEdge[41, 250] -> 
             RGBColor[
              0.9316670707893095, 0.8320353119068958, 0.6123232646067631], 
             UndirectedEdge[146, 236] -> 
             RGBColor[
              0.9886047786973496, 0.9895557973945939, 0.8385118370797212], 
             UndirectedEdge[82, 103] -> 
             RGBColor[
              0.8737181104738339, 0.7682211633977871, 0.6134223408546771], 
             UndirectedEdge[179, 289] -> 
             RGBColor[0.983190199850878, 0.9846573899276, 0.7924253271593525],
              UndirectedEdge[124, 247] -> 
             RGBColor[
              0.9834190380494685, 0.9846961945710301, 0.7815752375792107], 
             UndirectedEdge[162, 227] -> 
             RGBColor[
              0.9805063877841631, 0.9453566378843521, 0.425452057936341], 
             UndirectedEdge[156, 191] -> 
             RGBColor[
              0.9625093744483493, 0.877190054477816, 0.4085018665097153], 
             UndirectedEdge[1, 51] -> 
             RGBColor[
              0.9828550644939116, 0.9525115805343929, 0.5364901650068754], 
             UndirectedEdge[23, 198] -> 
             RGBColor[
              0.6186115703987598, 0.6712100156903567, 0.6660644513591167], 
             UndirectedEdge[77, 159] -> 
             RGBColor[
              0.9765213379007527, 0.9324631010665292, 0.3632902606280718], 
             UndirectedEdge[2, 238] -> 
             RGBColor[
              0.9353686226067619, 0.805306225891818, 0.584383258407945], 
             UndirectedEdge[113, 245] -> 
             RGBColor[
              0.924310549837032, 0.7376235826575818, 0.25795669562037976`], 
             UndirectedEdge[167, 201] -> 
             RGBColor[
              0.7142129010162601, 0.7704634700144751, 0.796492021553463], 
             UndirectedEdge[125, 150] -> 
             RGBColor[
              0.9045182503815572, 0.6341111681181676, 0.326111484713864], 
             UndirectedEdge[142, 198] -> 
             RGBColor[
              0.9886138355108505, 0.9753727780052276, 0.5826080242367325], 
             UndirectedEdge[34, 52] -> 
             RGBColor[
              0.9810828111503478, 0.9852758740337032, 0.9108023422183353], 
             UndirectedEdge[13, 251] -> 
             RGBColor[
              0.9500473682699628, 0.9595931293771665, 0.8565670116357473], 
             UndirectedEdge[120, 188] -> 
             RGBColor[
              0.9590464170294425, 0.9667099516114855, 0.8526608590705574], 
             UndirectedEdge[67, 173] -> 
             RGBColor[
              0.9885634831458319, 0.9801072969799952, 0.616311232808535], 
             UndirectedEdge[20, 280] -> 
             RGBColor[
              0.9349678458295916, 0.7731440227777162, 0.29160050621315803`], 
             UndirectedEdge[32, 107] -> 
             RGBColor[
              0.9806895877726517, 0.9851189066955174, 0.9175716703254926], 
             UndirectedEdge[189, 287] -> 
             RGBColor[
              0.9089838412698179, 0.8772168199505894, 0.6348962739871464], 
             UndirectedEdge[159, 205] -> 
             RGBColor[
              0.9578156637519633, 0.8650375259903811, 0.31315704605557804`], 
             UndirectedEdge[66, 86] -> 
             RGBColor[
              0.8658923454346092, 0.8959030685007174, 0.9870707789704168], 
             UndirectedEdge[119, 266] -> 
             RGBColor[
              0.9552098221048093, 0.8481837393044411, 0.40653533847317525`], 
             UndirectedEdge[28, 230] -> 
             RGBColor[
              0.9938315708922576, 0.9892146787994169, 0.5699827426331102], 
             UndirectedEdge[83, 142] -> 
             RGBColor[
              0.9907738249977791, 0.9904527537817687, 0.8025651265697189], 
             UndirectedEdge[191, 217] -> 
             RGBColor[
              0.9777817705821352, 0.9359889621882468, 0.4299099125462168], 
             UndirectedEdge[43, 233] -> 
             RGBColor[
              0.6852947401126949, 0.7475866104432777, 0.8982799086139035], 
             UndirectedEdge[113, 297] -> 
             RGBColor[
              0.9583385635800812, 0.8628576851904262, 0.5096747926283898], 
             UndirectedEdge[158, 207] -> 
             RGBColor[
              0.7098020152229145, 0.7710758640088751, 0.9555775850069874], 
             UndirectedEdge[40, 201] -> 
             RGBColor[
              0.977484505601558, 0.9803502220135611, 0.7979678781054831], 
             UndirectedEdge[194, 226] -> 
             RGBColor[
              0.9392139973226257, 0.8522753959923361, 0.6108847115795989], 
             UndirectedEdge[134, 230] -> 
             RGBColor[
              0.9901796704086891, 0.9878457769068179, 0.6407717723838546], 
             UndirectedEdge[134, 264] -> 
             RGBColor[
              0.9913733160293317, 0.9903988641932875, 0.7706927318639145], 
             UndirectedEdge[59, 226] -> 
             RGBColor[
              0.9544411003936115, 0.8487704981122317, 0.32548259140085367`], 
             UndirectedEdge[42, 201] -> 
             RGBColor[
              0.9767570827242102, 0.9798077112226808, 0.7991992152945613], 
             UndirectedEdge[217, 295] -> 
             RGBColor[
              0.9745102614996333, 0.9360188772502651, 0.5846399310877577], 
             UndirectedEdge[45, 94] -> 
             RGBColor[
              0.9309221730718353, 0.9434061525019006, 0.7787812779887481], 
             UndirectedEdge[197, 254] -> 
             RGBColor[
              0.7331971126835246, 0.7592006316395077, 0.6501115934885962], 
             UndirectedEdge[30, 189] -> 
             RGBColor[
              0.9172199258093424, 0.9358950496838545, 0.9595411553828128], 
             UndirectedEdge[92, 179] -> 
             RGBColor[
              0.868810425799314, 0.41557935099481, 0.4203556010868409], 
             UndirectedEdge[134, 288] -> 
             RGBColor[
              0.9763332177304263, 0.9411642863160936, 0.5847831955922982], 
             UndirectedEdge[59, 83] -> 
             RGBColor[
              0.9864614956310314, 0.9737874111982661, 0.6134718474249825], 
             UndirectedEdge[10, 22] -> 
             RGBColor[
              0.989685174933129, 0.9878801911634025, 0.666332411497382], 
             UndirectedEdge[148, 168] -> 
             RGBColor[
              0.9908668999791823, 0.9824919281540615, 0.5880363396829331], 
             UndirectedEdge[130, 216] -> 
             RGBColor[
              0.8371566460106888, 0.49666303769927345`, 0.4520796281625509], 
             UndirectedEdge[158, 196] -> 
             RGBColor[
              0.9730618825042477, 0.9731750554780412, 0.6891259544359799], 
             UndirectedEdge[203, 237] -> 
             RGBColor[
              0.9380481957228277, 0.8073046471343817, 0.5798474400670426], 
             UndirectedEdge[160, 193] -> 
             RGBColor[
              0.9638391332127005, 0.9619564287845099, 0.6955239951993796], 
             UndirectedEdge[38, 88] -> 
             RGBColor[
              0.8250925547319778, 0.8218772312516389, 0.6410937485885055], 
             UndirectedEdge[22, 73] -> 
             RGBColor[
              0.9736456489120404, 0.9794740407915623, 0.9119627007097418], 
             UndirectedEdge[181, 227] -> 
             RGBColor[
              0.9774926262785772, 0.9795760358419354, 0.7360452220747933], 
             UndirectedEdge[85, 255] -> 
             RGBColor[
              0.9734562721372617, 0.9793667043592234, 0.9138013978840687], 
             UndirectedEdge[106, 227] -> 
             RGBColor[
              0.9294250815983832, 0.9419160090005811, 0.7546110639841411], 
             UndirectedEdge[131, 261] -> 
             RGBColor[
              0.9657217638285618, 0.9702690238856095, 0.7140501297750382], 
             UndirectedEdge[81, 94] -> 
             RGBColor[
              0.9214821685767403, 0.9392165962903796, 0.9572763172365335], 
             UndirectedEdge[77, 154] -> 
             RGBColor[
              0.9631989805356341, 0.8850670619488099, 0.3243294298630374], 
             UndirectedEdge[167, 277] -> 
             RGBColor[
              0.703778402475304, 0.7650597777341481, 0.9391840661465846], 
             UndirectedEdge[113, 176] -> 
             RGBColor[
              0.9588166238481841, 0.8620986722959341, 0.43220988083855005`], 
             UndirectedEdge[4, 276] -> 
             RGBColor[
              0.804529746548404, 0.8474584099645088, 0.9490423558308376], 
             UndirectedEdge[101, 243] -> 
             RGBColor[
              0.9676104280799029, 0.9738740329092869, 0.8729655260345635], 
             UndirectedEdge[52, 271] -> 
             RGBColor[
              0.9449309661426585, 0.8242686972710633, 0.570172388700304], 
             UndirectedEdge[37, 71] -> 
             RGBColor[
              0.9517243001225872, 0.9623497549161636, 0.9196432899247993], 
             UndirectedEdge[83, 291] -> 
             RGBColor[
              0.9739698553787584, 0.9316501754507382, 0.5649441838932254], 
             UndirectedEdge[80, 149] -> 
             RGBColor[
              0.9117866262024481, 0.9313158043711511, 0.9504634486131831], 
             UndirectedEdge[104, 206] -> 
             RGBColor[
              0.9911343327735749, 0.9903984118349567, 0.7818040076353463], 
             UndirectedEdge[61, 108] -> 
             RGBColor[
              0.9925594722020861, 0.9894937917514494, 0.6495912297808961], 
             UndirectedEdge[115, 264] -> 
             RGBColor[
              0.9894946116110284, 0.9895995522436519, 0.8008237398196905], 
             UndirectedEdge[38, 52] -> 
             RGBColor[
              0.9742663261441, 0.9383388235704977, 0.6054151878576175], 
             UndirectedEdge[33, 285] -> 
             RGBColor[
              0.9921866580880518, 0.988770255345095, 0.614382667655371], 
             UndirectedEdge[100, 122] -> 
             RGBColor[
              0.9774648120504437, 0.9450796745907206, 0.5898583602026053], 
             UndirectedEdge[205, 269] -> 
             RGBColor[
              0.9200193493162292, 0.7190205956352503, 0.2544216558894781], 
             UndirectedEdge[177, 252] -> 
             RGBColor[
              0.9070792278030959, 0.6605127631522811, 0.24363704581165757`], 
             UndirectedEdge[152, 244] -> 
             RGBColor[
              0.9881839974422568, 0.9893817935320279, 0.8454852714235905], 
             UndirectedEdge[10, 71] -> 
             RGBColor[
              0.990442264828141, 0.9881932672913128, 0.6537854726511904], 
             UndirectedEdge[233, 259] -> 
             RGBColor[
              0.6887462360853158, 0.7485611262211613, 0.808168342808119], 
             UndirectedEdge[130, 299] -> 
             RGBColor[
              0.8761016390624075, 0.5275115009059079, 0.4486792300202447], 
             UndirectedEdge[81, 86] -> 
             RGBColor[
              0.906364507929386, 0.9271621840481459, 0.9558343812682939], 
             UndirectedEdge[205, 282] -> 
             RGBColor[
              0.9623583808231693, 0.8961167017394975, 0.5923296334823428], 
             UndirectedEdge[176, 297] -> 
             RGBColor[
              0.9936949586617253, 0.9907040145205802, 0.6846121661394788], 
             UndirectedEdge[92, 128] -> 
             RGBColor[
              0.7966254526143998, 0.35899040408733374`, 0.43489158649074544`],
              UndirectedEdge[166, 285] -> 
             RGBColor[
              0.9876913034568617, 0.9736998465215503, 0.5889703773251509], 
             UndirectedEdge[132, 146] -> 
             RGBColor[
              0.9922043050191396, 0.9898429007198392, 0.6915297593916339], 
             UndirectedEdge[81, 130] -> 
             RGBColor[
              0.8852077238425988, 0.5343028040251293, 0.4332650037346616], 
             UndirectedEdge[1, 128] -> 
             RGBColor[
              0.8629678654997786, 0.8607673563568679, 0.6584520084158962], 
             UndirectedEdge[296, 297] -> 
             RGBColor[
              0.981861059281409, 0.9518161753607206, 0.5509979286093979], 
             UndirectedEdge[128, 237] -> 
             RGBColor[
              0.8664432961069188, 0.8957839412850283, 0.9494793238976648], 
             UndirectedEdge[112, 146] -> 
             RGBColor[
              0.5847231142711928, 0.6478707358023166, 0.8701427243550454], 
             UndirectedEdge[116, 287] -> 
             RGBColor[
              0.8834430894665171, 0.5307370131832354, 0.22304285265079846`], 
             UndirectedEdge[10, 266] -> 
             RGBColor[
              0.9932866323467751, 0.9880491103523681, 0.5106695449282004], 
             UndirectedEdge[16, 76] -> 
             RGBColor[
              0.9781583611033449, 0.9376312682536945, 0.39974258766855236`], 
             UndirectedEdge[23, 72] -> 
             RGBColor[
              0.6212240332062572, 0.6864771008129869, 0.87852289980686], 
             UndirectedEdge[237, 277] -> 
             RGBColor[
              0.9756459459539881, 0.9813573668853637, 0.9261092403320257], 
             UndirectedEdge[56, 278] -> 
             RGBColor[
              0.9878319288172142, 0.9706163800807933, 0.4072297705126538], 
             UndirectedEdge[88, 274] -> 
             RGBColor[
              0.7725336264117622, 0.822538929117691, 0.9778801873244307], 
             UndirectedEdge[103, 282] -> 
             RGBColor[
              0.9439054342009482, 0.8229569174623308, 0.5774819594837766], 
             UndirectedEdge[46, 60] -> 
             RGBColor[
              0.9817496527068852, 0.9850657414460164, 0.8779919628066502], 
             UndirectedEdge[82, 216] -> 
             RGBColor[
              0.836906178600562, 0.8727902858757868, 0.9843060525015288], 
             UndirectedEdge[48, 70] -> 
             RGBColor[
              0.7804099236423632, 0.8246838746249793, 0.7976066148554064], 
             UndirectedEdge[143, 174] -> 
             RGBColor[
              0.9547904916881161, 0.9658034032415486, 0.9614120844305218], 
             UndirectedEdge[95, 205] -> 
             RGBColor[
              0.9459600802474665, 0.823456756456613, 0.27537641596840756`], 
             UndirectedEdge[78, 190] -> 
             RGBColor[
              0.8767433492413884, 0.4537126795251947, 0.2335330083049666], 
             UndirectedEdge[68, 292] -> 
             RGBColor[
              0.6108660777967512, 0.6796774276527533, 0.9374918330120261], 
             UndirectedEdge[145, 269] -> 
             RGBColor[
              0.9461629984138606, 0.8122832720888513, 0.4963090161877646], 
             UndirectedEdge[198, 254] -> 
             RGBColor[
              0.978420315507921, 0.9388687984366536, 0.37066743004008995`], 
             UndirectedEdge[124, 147] -> 
             RGBColor[
              0.8572786917280785, 0.8887166878606279, 0.9532332923895583], 
             UndirectedEdge[44, 194] -> 
             RGBColor[
              0.9731932603844295, 0.9759388617486014, 0.7091476095270076], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.9860517049416453, 0.9803667913193026, 0.6618389263484048], 
             UndirectedEdge[5, 11] -> 
             RGBColor[
              0.9839613071328084, 0.9843859242893309, 0.7239494311332481], 
             UndirectedEdge[108, 254] -> 
             RGBColor[
              0.9820543421097991, 0.9545583264412523, 0.5661959226925917], 
             UndirectedEdge[61, 71] -> 
             RGBColor[
              0.9906885911329626, 0.9887201343499163, 0.6805965707812764], 
             UndirectedEdge[229, 284] -> 
             RGBColor[
              0.9208380162048295, 0.7539458903550469, 0.5819942224836351], 
             UndirectedEdge[37, 136] -> 
             RGBColor[
              0.9520774811271833, 0.9624958043379019, 0.9137901666755022], 
             UndirectedEdge[148, 159] -> 
             RGBColor[
              0.9815089878704393, 0.9492876155701864, 0.38266633892164004`], 
             UndirectedEdge[164, 230] -> 
             RGBColor[
              0.9651439792469447, 0.9697760221600098, 0.7101015185868437], 
             UndirectedEdge[176, 193] -> 
             RGBColor[
              0.9672687901706649, 0.9724947848438151, 0.796489337926634], 
             UndirectedEdge[216, 299] -> 
             RGBColor[
              0.8892186390438135, 0.9141949961706277, 0.9786231521592136], 
             UndirectedEdge[149, 277] -> 
             RGBColor[
              0.9775919194782485, 0.9828086707535177, 0.9228152147466333], 
             UndirectedEdge[39, 248] -> 
             RGBColor[
              0.9878782007770703, 0.9888939028980477, 0.8343672775294031], 
             UndirectedEdge[13, 137] -> 
             RGBColor[
              0.9951582436885997, 0.9922221768322328, 0.7267313041946939], 
             UndirectedEdge[68, 75] -> 
             RGBColor[
              0.6216163356088559, 0.6866393279381733, 0.8720214337497261], 
             UndirectedEdge[66, 97] -> 
             RGBColor[
              0.9438596912426327, 0.9536382876991318, 0.7732148250727334], 
             UndirectedEdge[59, 106] -> 
             RGBColor[
              0.9247621195722003, 0.9267357153438461, 0.6898157060141672], 
             UndirectedEdge[51, 198] -> 
             RGBColor[
              0.9897745950573349, 0.9758527819078586, 0.5633712346020727], 
             UndirectedEdge[193, 228] -> 
             RGBColor[
              0.9486688898213861, 0.9612379225925443, 0.9717743596214237], 
             UndirectedEdge[30, 287] -> 
             RGBColor[
              0.9637303841993672, 0.9199349890696706, 0.6076927541001647], 
             UndirectedEdge[93, 147] -> 
             RGBColor[
              0.803168668428113, 0.8465182800336826, 0.9809211234850688], 
             UndirectedEdge[69, 121] -> 
             RGBColor[
              0.9783397884992733, 0.9812123608563501, 0.8143149929879212], 
             UndirectedEdge[148, 251] -> 
             RGBColor[
              0.946790442609592, 0.9502906391456072, 0.700729063063187], 
             UndirectedEdge[125, 269] -> 
             RGBColor[
              0.8728140371448629, 0.5153600723586964, 0.21558525379149387`], 
             UndirectedEdge[37, 44] -> 
             RGBColor[
              0.9540800119011451, 0.96116041275987, 0.7233402005281833], 
             UndirectedEdge[91, 105] -> 
             RGBColor[
              0.6885258484302249, 0.7480897393115318, 0.7841805066264191], 
             UndirectedEdge[81, 203] -> 
             RGBColor[
              0.9367012700184911, 0.8063001121494757, 0.5821274339499984], 
             UndirectedEdge[8, 69] -> 
             RGBColor[
              0.9724140921508926, 0.962662601417111, 0.6689321185168273], 
             UndirectedEdge[52, 270] -> 
             RGBColor[
              0.9620141682949869, 0.971054511414212, 0.9430805806738889], 
             UndirectedEdge[108, 268] -> 
             RGBColor[
              0.9713179824606297, 0.9768648680506027, 0.8767990223704498], 
             UndirectedEdge[11, 254] -> 
             RGBColor[
              0.9734275220942947, 0.9493891689466145, 0.6374352099859992], 
             UndirectedEdge[82, 255] -> 
             RGBColor[
              0.9017896292416605, 0.9238852838598726, 0.968260269800264], 
             UndirectedEdge[43, 66] -> 
             RGBColor[
              0.9409321164477323, 0.9537843863438358, 0.9203519778066832], 
             UndirectedEdge[252, 283] -> 
             RGBColor[
              0.907196899855361, 0.7373295047589149, 0.6007946112712086], 
             UndirectedEdge[99, 215] -> 
             RGBColor[
              0.9718716234985223, 0.978542483377963, 0.9324981837481758], 
             UndirectedEdge[114, 283] -> 
             RGBColor[
              0.9483124917970603, 0.9091334954873633, 0.6343321052835872], 
             UndirectedEdge[24, 194] -> 
             RGBColor[
              0.9378333983444227, 0.9528049747666126, 0.9779169511153812], 
             UndirectedEdge[134, 228] -> 
             RGBColor[
              0.9723938406581746, 0.9783301293511407, 0.9046633548927572], 
             UndirectedEdge[49, 143] -> 
             RGBColor[
              0.9011246894562284, 0.9239173461521353, 0.9876910050053349], 
             UndirectedEdge[123, 189] -> 
             RGBColor[
              0.9167040722522125, 0.9355103269455797, 0.9604143608988783], 
             UndirectedEdge[232, 240] -> 
             RGBColor[
              0.781220150541366, 0.8290395462358809, 0.9607498900042741], 
             UndirectedEdge[11, 243] -> 
             RGBColor[
              0.9583042047330024, 0.9684239246772476, 0.9554642847686625], 
             UndirectedEdge[155, 210] -> 
             RGBColor[
              0.9916574523623809, 0.9891467906815499, 0.6664304901067535], 
             UndirectedEdge[148, 156] -> 
             RGBColor[
              0.9600285831339262, 0.8695476371330191, 0.3371413517475983], 
             UndirectedEdge[15, 212] -> 
             RGBColor[
              0.7184724592272449, 0.7790317772859949, 0.9735016037523316], 
             UndirectedEdge[51, 204] -> 
             RGBColor[
              0.9413382512874111, 0.7874973980123584, 0.48014564406718135`], 
             UndirectedEdge[95, 156] -> 
             RGBColor[
              0.9409644328056956, 0.8036506790508169, 0.27135680077384217`], 
             UndirectedEdge[87, 109] -> 
             RGBColor[
              0.8273840827616769, 0.8636358612830417, 0.8708496605724172], 
             UndirectedEdge[113, 288] -> 
             RGBColor[
              0.944156100571157, 0.8136759670096163, 0.2876147432328806], 
             UndirectedEdge[164, 176] -> 
             RGBColor[
              0.965958049845709, 0.9715172368556033, 0.7987080794009567], 
             UndirectedEdge[17, 294] -> 
             RGBColor[
              0.9332642691231423, 0.9450961399883064, 0.7646129988572903], 
             UndirectedEdge[77, 212] -> 
             RGBColor[
              0.758149980973575, 0.787703682182809, 0.6643278807757429], 
             UndirectedEdge[180, 296] -> 
             RGBColor[
              0.8159960804777605, 0.8238236080131903, 0.6534066368331441], 
             UndirectedEdge[217, 271] -> 
             RGBColor[
              0.9333669687664543, 0.771778212104323, 0.27436322049051265`], 
             UndirectedEdge[4, 85] -> 
             RGBColor[
              0.9788242201418149, 0.983370111191811, 0.9047148620974241], 
             UndirectedEdge[95, 127] -> 
             RGBColor[
              0.9308869897114554, 0.8869139353993156, 0.6352459822319012], 
             UndirectedEdge[54, 75] -> 
             RGBColor[
              0.9847655282813628, 0.9655662246900218, 0.5896014204237062], 
             UndirectedEdge[134, 193] -> 
             RGBColor[
              0.96408951224829, 0.9721367748201386, 0.9187204167749626], 
             UndirectedEdge[40, 178] -> 
             RGBColor[
              0.8775412327019312, 0.9047581093434331, 0.9659929077231972], 
             UndirectedEdge[69, 239] -> 
             RGBColor[
              0.9301157223481532, 0.9464388139074704, 0.9698204136724733], 
             UndirectedEdge[134, 200] -> 
             RGBColor[
              0.9813387640818536, 0.9580491695176325, 0.6042287979494811], 
             UndirectedEdge[89, 141] -> 
             RGBColor[
              0.9692782900364457, 0.9080305998717083, 0.3351523874100575], 
             UndirectedEdge[38, 147] -> 
             RGBColor[
              0.8528186876967403, 0.8435370970501266, 0.6438572304069892], 
             UndirectedEdge[170, 182] -> 
             RGBColor[
              0.9933580748879017, 0.9915214075235272, 0.7597374180660542], 
             UndirectedEdge[94, 120] -> 
             RGBColor[
              0.8954795031441651, 0.9194950649363163, 0.9898928284855217], 
             UndirectedEdge[80, 269] -> 
             RGBColor[
              0.8703704315804873, 0.7549079485047148, 0.6109933488884561], 
             UndirectedEdge[263, 286] -> 
             RGBColor[
              0.9222288589394304, 0.7293703719309612, 0.25628171826060403`], 
             UndirectedEdge[130, 140] -> 
             RGBColor[
              0.7369225339242983, 0.417154644944952, 0.4428885339960087], 
             UndirectedEdge[25, 288] -> 
             RGBColor[
              0.9639183986183648, 0.8899504275561685, 0.31433022138137623`], 
             UndirectedEdge[148, 191] -> 
             RGBColor[
              0.9911983460085962, 0.9812462214634172, 0.4820307745703427], 
             UndirectedEdge[177, 268] -> 
             RGBColor[
              0.9456468277599028, 0.8822550916725378, 0.6195331688612453], 
             UndirectedEdge[69, 126] -> 
             RGBColor[
              0.9649438804835628, 0.9733757839805443, 0.9442250456277455], 
             UndirectedEdge[20, 37] -> 
             RGBColor[
              0.9438450358145489, 0.9268027795510856, 0.6693494897620564], 
             UndirectedEdge[3, 72] -> 
             RGBColor[
              0.9921370072587249, 0.9903527607336262, 0.7317293983000761], 
             UndirectedEdge[87, 154] -> 
             RGBColor[
              0.9700547902361145, 0.910663423035101, 0.5257315603495495], 
             UndirectedEdge[11, 204] -> 
             RGBColor[
              0.9311072970996546, 0.7816648898131265, 0.5779695859609685], 
             UndirectedEdge[55, 268] -> 
             RGBColor[
              0.9720567126210402, 0.9771703519564315, 0.8645563518400785], 
             UndirectedEdge[125, 142] -> 
             RGBColor[
              0.9041418519992825, 0.6347961011921293, 0.39345092519838054`], 
             UndirectedEdge[176, 221] -> 
             RGBColor[
              0.9944859529859451, 0.9906143359296355, 0.6412081951528212], 
             UndirectedEdge[29, 182] -> 
             RGBColor[
              0.9466223308969097, 0.8180465222697066, 0.5122026053446194], 
             UndirectedEdge[122, 161] -> 
             RGBColor[
              0.955791112834935, 0.9295062573132622, 0.6530031573151072], 
             UndirectedEdge[44, 226] -> 
             RGBColor[
              0.958794885844026, 0.8632894943359446, 0.3566259871150743], 
             UndirectedEdge[89, 131] -> 
             RGBColor[
              0.9489962947365822, 0.9139309496486856, 0.6421990612795017], 
             UndirectedEdge[56, 110] -> 
             RGBColor[
              0.9753047154106973, 0.975400124274088, 0.6865019954102904], 
             UndirectedEdge[43, 178] -> 
             RGBColor[
              0.8912401418715248, 0.9143663130636777, 0.9155579232551295], 
             UndirectedEdge[66, 162] -> 
             RGBColor[
              0.9308151657416857, 0.9103805450269183, 0.6592319888959715], 
             UndirectedEdge[5, 142] -> 
             RGBColor[
              0.9930315017740805, 0.9897384285859319, 0.6453622788741208], 
             UndirectedEdge[147, 273] -> 
             RGBColor[
              0.8678839687711253, 0.8936474324439379, 0.7626198141621808], 
             UndirectedEdge[81, 167] -> 
             RGBColor[
              0.7044337651876177, 0.7655485461719338, 0.938074708020608], 
             UndirectedEdge[95, 212] -> 
             RGBColor[
              0.744073480615031, 0.7386312386042638, 0.6179194080955551], 
             UndirectedEdge[56, 217] -> 
             RGBColor[
              0.9764612052941526, 0.9322602596646595, 0.36305665680652033`], 
             UndirectedEdge[6, 93] -> 
             RGBColor[
              0.8009895299427814, 0.8448159204868755, 0.9807039273260578], 
             UndirectedEdge[131, 146] -> 
             RGBColor[
              0.9646643689174706, 0.9721161421710147, 0.8976240839142734], 
             UndirectedEdge[7, 80] -> 
             RGBColor[
              0.9029427459059978, 0.9247200529265833, 0.9654338311016748], 
             UndirectedEdge[76, 239] -> 
             RGBColor[
              0.9457314575835258, 0.954706254446851, 0.7389796652633563], 
             UndirectedEdge[148, 278] -> 
             RGBColor[
              0.9866717027907738, 0.9667026652595838, 0.40272251149023325`], 
             UndirectedEdge[29, 170] -> 
             RGBColor[
              0.9481442772854569, 0.818675886213609, 0.48698001501539556`], 
             UndirectedEdge[147, 289] -> 
             RGBColor[
              0.868352122001377, 0.894648764865894, 0.8135754041682413], 
             UndirectedEdge[25, 28] -> 
             RGBColor[
              0.9790515444565855, 0.9393840247114088, 0.5103674080846299], 
             UndirectedEdge[5, 149] -> 
             RGBColor[
              0.9874559741144119, 0.9869922412022187, 0.7180338714885178], 
             UndirectedEdge[140, 202] -> 
             RGBColor[
              0.701624801621685, 0.5731431558429076, 0.5860083577658645], 
             UndirectedEdge[10, 63] -> 
             RGBColor[
              0.9710948064770919, 0.9120110770894478, 0.36909711783734744`], 
             UndirectedEdge[43, 259] -> 
             RGBColor[
              0.991305670895674, 0.9902199192221686, 0.7608397183143312], 
             UndirectedEdge[21, 50] -> 
             RGBColor[
              0.9533945464095692, 0.8848431034952312, 0.6039431632329149], 
             UndirectedEdge[87, 155] -> 
             RGBColor[
              0.9912120875384798, 0.9906339866051821, 0.7953019820832101], 
             UndirectedEdge[127, 282] -> 
             RGBColor[
              0.9472852902871582, 0.9595738806822002, 0.9521991997458364], 
             UndirectedEdge[79, 144] -> 
             RGBColor[
              0.985636648266506, 0.9862963464644741, 0.7735575075552125], 
             UndirectedEdge[54, 298] -> 
             RGBColor[
              0.9863412170333419, 0.9648507494503784, 0.4641171290805708], 
             UndirectedEdge[234, 263] -> 
             RGBColor[
              0.8895452837786582, 0.8186638909433965, 0.6234014446947954], 
             UndirectedEdge[34, 38] -> 
             RGBColor[
              0.9703367387007882, 0.9355444417024404, 0.6181706578963961], 
             UndirectedEdge[39, 85] -> 
             RGBColor[
              0.9841804779103451, 0.9873647994655137, 0.8956481148310644], 
             UndirectedEdge[20, 108] -> 
             RGBColor[
              0.9820543421097991, 0.9545583264412523, 0.5661959226925917], 
             UndirectedEdge[94, 201] -> 
             RGBColor[
              0.9312613044053826, 0.944131520132921, 0.8156936307693886], 
             UndirectedEdge[260, 294] -> 
             RGBColor[
              0.9739947717803119, 0.9770907785541028, 0.7517603650083926], 
             UndirectedEdge[138, 266] -> 
             RGBColor[
              0.9936513903309945, 0.9903223249922983, 0.658899025145925], 
             UndirectedEdge[127, 168] -> 
             RGBColor[
              0.9521004853246953, 0.9616990175169591, 0.8783966130803648], 
             UndirectedEdge[128, 198] -> 
             RGBColor[
              0.8698873960632019, 0.8841085577303336, 0.6853330780110934], 
             UndirectedEdge[145, 216] -> 
             RGBColor[
              0.9122096770593597, 0.929775639613444, 0.8695750720226738], 
             UndirectedEdge[141, 182] -> 
             RGBColor[
              0.9856048141958186, 0.9664880783815334, 0.5796651898874228], 
             UndirectedEdge[41, 252] -> 
             RGBColor[
              0.894716591350204, 0.6114990292209489, 0.2336897783332868], 
             UndirectedEdge[55, 208] -> 
             RGBColor[
              0.981712853700892, 0.9843718861633052, 0.8482110237168294], 
             UndirectedEdge[121, 249] -> 
             RGBColor[
              0.9396612699749454, 0.9510453921324489, 0.8340018496831924], 
             UndirectedEdge[89, 120] -> 
             RGBColor[
              0.941066066138712, 0.9076878120950458, 0.6442236510137643], 
             UndirectedEdge[32, 142] -> 
             RGBColor[
              0.9865265243655219, 0.9880600524335943, 0.8444575805735541], 
             UndirectedEdge[7, 77] -> 
             RGBColor[
              0.9712973377905292, 0.9562582751332669, 0.6589953526751905], 
             UndirectedEdge[45, 146] -> 
             RGBColor[
              0.9921768102472707, 0.9897840921829593, 0.6885371231517623], 
             UndirectedEdge[110, 223] -> 
             RGBColor[
              0.949530914421244, 0.8835878319299002, 0.61174498809123], 
             UndirectedEdge[225, 276] -> 
             RGBColor[
              0.8155350016282402, 0.8524531666150151, 0.7391618384858294], 
             UndirectedEdge[65, 291] -> 
             RGBColor[
              0.9386411799884669, 0.7935170339775759, 0.2742930080027801], 
             UndirectedEdge[194, 290] -> 
             RGBColor[
              0.9591425720839803, 0.9690491776749064, 0.9540451475246816], 
             UndirectedEdge[154, 258] -> 
             RGBColor[
              0.9627949026863806, 0.9066216082544346, 0.5994883752403586], 
             UndirectedEdge[31, 280] -> 
             RGBColor[
              0.9212093597565153, 0.7931966674483948, 0.6073192776298819], 
             UndirectedEdge[156, 271] -> 
             RGBColor[
              0.9180945726326684, 0.7129793043938921, 0.2529551744540111], 
             UndirectedEdge[83, 241] -> 
             RGBColor[
              0.7881787531314741, 0.8328293672666898, 0.897505492913106], 
             UndirectedEdge[208, 268] -> 
             RGBColor[
              0.9604876185141504, 0.9700523111002158, 0.9517683347626964], 
             UndirectedEdge[1, 80] -> 
             RGBColor[
              0.9063652220710476, 0.8948479155748367, 0.6627301587168068], 
             UndirectedEdge[116, 206] -> 
             RGBColor[
              0.8940191446379231, 0.5733128184807258, 0.415833678240414], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.9779473824273172, 0.9371800061988875, 0.3767788607923991], 
             UndirectedEdge[108, 204] -> 
             RGBColor[
              0.939734117115159, 0.7868340473077644, 0.506730298667561], 
             UndirectedEdge[251, 271] -> 
             RGBColor[
              0.9048564321083341, 0.7937223064064801, 0.6165428857695999], 
             UndirectedEdge[6, 38] -> 
             RGBColor[
              0.8506395492114085, 0.8418347375033195, 0.6436400342479782], 
             UndirectedEdge[135, 158] -> 
             RGBColor[
              0.9474356286361517, 0.9603181584198763, 0.9738619491219938], 
             UndirectedEdge[25, 180] -> 
             RGBColor[
              0.8122358828236405, 0.8111395783894482, 0.6387989790006317], 
             UndirectedEdge[57, 217] -> 
             RGBColor[
              0.9766076273374587, 0.9368861919240493, 0.5498811513461945], 
             UndirectedEdge[71, 136] -> 
             RGBColor[
              0.9884159063533099, 0.9894776938265355, 0.841641940606418], 
             UndirectedEdge[135, 173] -> 
             RGBColor[
              0.9643710928479355, 0.9720871584312907, 0.90661751670236], 
             UndirectedEdge[143, 235] -> 
             RGBColor[
              0.9666727700444464, 0.972334851022891, 0.8200782133543787], 
             UndirectedEdge[264, 288] -> 
             RGBColor[
              0.9798920706746794, 0.9423341689306461, 0.5038665154099166], 
             UndirectedEdge[223, 247] -> 
             RGBColor[
              0.9669441095549338, 0.8941162326772432, 0.4508928054362753], 
             UndirectedEdge[191, 225] -> 
             RGBColor[
              0.9934967971201152, 0.9884986315516248, 0.5335446835196489], 
             UndirectedEdge[1, 243] -> 
             RGBColor[
              0.9563774675832054, 0.934562352793821, 0.661815435227556], 
             UndirectedEdge[29, 284] -> 
             RGBColor[
              0.9329964056075601, 0.8091542969688558, 0.5921394806306695], 
             UndirectedEdge[6, 273] -> 
             RGBColor[
              0.8657048302857936, 0.8919450728971308, 0.7624026180031699], 
             UndirectedEdge[103, 276] -> 
             RGBColor[
              0.7710902797760241, 0.6877908826698357, 0.6032909626718952], 
             UndirectedEdge[99, 199] -> 
             RGBColor[
              0.9409025380908611, 0.9549719826919705, 0.968493563984986], 
             UndirectedEdge[35, 129] -> 
             RGBColor[
              0.9534235501569417, 0.8527902829756253, 0.5518110871748453], 
             UndirectedEdge[77, 145] -> 
             RGBColor[
              0.9861802297036419, 0.9657918764887591, 0.5636722489468818], 
             UndirectedEdge[72, 155] -> 
             RGBColor[
              0.9898658304096992, 0.9900772746852011, 0.817612946708872], 
             UndirectedEdge[20, 44] -> 
             RGBColor[
              0.9825391728192334, 0.9525953268834257, 0.4008981742963562], 
             UndirectedEdge[131, 178] -> 
             RGBColor[
              0.8667178090562759, 0.8966860177102333, 0.9843141407542997], 
             UndirectedEdge[106, 241] -> 
             RGBColor[
              0.726479377072643, 0.78577767141227, 0.9738493515022906], 
             UndirectedEdge[85, 286] -> 
             RGBColor[
              0.9512469952550396, 0.846944419497256, 0.5636803663641419], 
             UndirectedEdge[86, 261] -> 
             RGBColor[
              0.9152043256306874, 0.9300680013959355, 0.7120127134396017], 
             UndirectedEdge[256, 269] -> 
             RGBColor[
              0.5388173960876188, 0.4691657831557453, 0.5853463188514273], 
             UndirectedEdge[37, 61] -> 
             RGBColor[
              0.9543501659068359, 0.9617382448612828, 0.7527447968503608], 
             UndirectedEdge[73, 244] -> 
             RGBColor[
              0.9743412230523356, 0.9797616785740144, 0.9004352371168794], 
             UndirectedEdge[180, 193] -> 
             RGBColor[
              0.8009257510989134, 0.8452612303907769, 0.9763629579402201], 
             UndirectedEdge[8, 213] -> 
             RGBColor[
              0.9694987501212629, 0.9604883441048477, 0.6738670321300122], 
             UndirectedEdge[48, 138] -> 
             RGBColor[
              0.9939956605550109, 0.9910586841904104, 0.6963707144405691], 
             UndirectedEdge[170, 284] -> 
             RGBColor[
              0.9797321495985523, 0.9826291822226765, 0.8396742933521043], 
             UndirectedEdge[55, 219] -> 
             RGBColor[
              0.988219624872321, 0.989224625449097, 0.8371967573613158], 
             UndirectedEdge[111, 235] -> 
             RGBColor[
              0.9936531987697432, 0.9888331588655466, 0.5505680378825578], 
             UndirectedEdge[56, 247] -> 
             RGBColor[
              0.9927179105443871, 0.9859285250214309, 0.5256498127553357], 
             UndirectedEdge[7, 82] -> 
             RGBColor[
              0.9034318142805735, 0.9251100227730626, 0.9654804788798383], 
             UndirectedEdge[182, 190] -> 
             RGBColor[
              0.9825749246485223, 0.9562675494866056, 0.5678946411428067], 
             UndirectedEdge[113, 228] -> 
             RGBColor[
              0.9402167234989053, 0.8508418100446633, 0.6074949025333396], 
             UndirectedEdge[133, 146] -> 
             RGBColor[
              0.7142312951612895, 0.7720468663652111, 0.8779553951789917], 
             UndirectedEdge[93, 274] -> 
             RGBColor[
              0.8613113061056974, 0.8922502720888431, 0.9866338353496831], 
             UndirectedEdge[153, 220] -> 
             RGBColor[
              0.98471066229599, 0.9701088349118019, 0.6220658663816924], 
             UndirectedEdge[90, 153] -> 
             RGBColor[
              0.9519773738953924, 0.8395930468994462, 0.3204253884721307], 
             UndirectedEdge[178, 190] -> 
             RGBColor[
              0.8839699148088431, 0.8805651390383282, 0.6654969181402395], 
             UndirectedEdge[39, 126] -> 
             RGBColor[
              0.9750296368557294, 0.9808977245689958, 0.9271524908762212], 
             UndirectedEdge[15, 77] -> 
             RGBColor[
              0.9390647330084698, 0.931282870214492, 0.6810918261976777], 
             UndirectedEdge[103, 293] -> 
             RGBColor[
              0.9298266980545573, 0.8124570190961671, 0.6013135874571469], 
             UndirectedEdge[92, 269] -> 
             RGBColor[
              0.8444485973917458, 0.3003971887704968, 0.1885425459009515], 
             UndirectedEdge[8, 14] -> 
             RGBColor[
              0.9685524652349549, 0.9597826063860384, 0.6754688456119065], 
             UndirectedEdge[157, 171] -> 
             RGBColor[
              0.8797262570248143, 0.9025994949656493, 0.739833898873471], 
             UndirectedEdge[198, 226] -> 
             RGBColor[
              0.9546760285327134, 0.8495629658891726, 0.32639524285880805`], 
             UndirectedEdge[86, 169] -> 
             RGBColor[
              0.9130767806959653, 0.9314725851449682, 0.9133218229298872], 
             UndirectedEdge[163, 235] -> 
             RGBColor[
              0.8946038398828922, 0.9151530378801753, 0.8158900911930993], 
             UndirectedEdge[31, 136] -> 
             RGBColor[
              0.9667781559721953, 0.9739833631321362, 0.9070669118603991], 
             UndirectedEdge[111, 292] -> 
             RGBColor[
              0.9808851378364432, 0.9816410958886359, 0.6934013078124148], 
             UndirectedEdge[48, 122] -> 
             RGBColor[
              0.9808107784178064, 0.9457369362793677, 0.4816067793093476], 
             UndirectedEdge[246, 295] -> 
             RGBColor[
              0.9769730260089773, 0.9443263602248879, 0.5942073061525055], 
             UndirectedEdge[258, 263] -> 
             RGBColor[
              0.9531211599755827, 0.8682684419897826, 0.5917046547833249], 
             UndirectedEdge[24, 299] -> 
             RGBColor[
              0.9348452767236037, 0.950576438554406, 0.9829750615924923], 
             UndirectedEdge[66, 193] -> 
             RGBColor[
              0.9171873096919565, 0.9366839686524644, 0.9877920464984399], 
             UndirectedEdge[29, 199] -> 
             RGBColor[
              0.9093669095798642, 0.7910576500249666, 0.6157108505186906], 
             UndirectedEdge[27, 87] -> 
             RGBColor[
              0.9914323807639662, 0.9907250835151984, 0.7916511532363077], 
             UndirectedEdge[164, 180] -> 
             RGBColor[
              0.7996150107739575, 0.8442836824025651, 0.9785816994145428], 
             UndirectedEdge[106, 200] -> 
             RGBColor[
              0.9201603631090142, 0.9112129102497192, 0.6719387511234793], 
             UndirectedEdge[69, 285] -> 
             RGBColor[
              0.9767819015287069, 0.9809540768605214, 0.8681871429406411], 
             UndirectedEdge[88, 137] -> 
             RGBColor[
              0.8408749685658501, 0.8736913201733847, 0.850260222538687], 
             UndirectedEdge[43, 261] -> 
             RGBColor[
              0.9902440966438106, 0.9879493192390538, 0.6452939122758681], 
             UndirectedEdge[224, 253] -> 
             RGBColor[
              0.9699968132347528, 0.9281368065520734, 0.6035592217362623], 
             UndirectedEdge[5, 23] -> 
             RGBColor[
              0.6230292366619897, 0.6855756662710608, 0.728818705996505], 
             UndirectedEdge[42, 162] -> 
             RGBColor[
              0.9633108921700649, 0.9356908476162429, 0.6414976168665498], 
             UndirectedEdge[29, 131] -> 
             RGBColor[
              0.9201090212935101, 0.7995429068485924, 0.6139544607062084], 
             UndirectedEdge[12, 192] -> 
             RGBColor[
              0.5440162339392551, 0.6351339387719623, 0.9595696871798991], 
             UndirectedEdge[69, 76] -> 
             RGBColor[
              0.977460684785639, 0.979332046903906, 0.7186299789580667], 
             UndirectedEdge[176, 180] -> 
             RGBColor[
              0.8278299798580768, 0.8627114471730499, 0.7870208743632251], 
             UndirectedEdge[101, 116] -> 
             RGBColor[
              0.8959994209631539, 0.574131713631989, 0.3830153747404893], 
             UndirectedEdge[125, 293] -> 
             RGBColor[
              0.8916542340518957, 0.6264242108507521, 0.45674499083565046`], 
             UndirectedEdge[30, 300] -> 
             RGBColor[
              0.9831817622041308, 0.9845187061806573, 0.7819349531750488], 
             UndirectedEdge[155, 290] -> 
             RGBColor[
              0.9773215366130651, 0.9816470339356479, 0.8802827805150689], 
             UndirectedEdge[217, 246] -> 
             RGBColor[
              0.9643471683505951, 0.8913967685429025, 0.31599591082472167`], 
             UndirectedEdge[42, 82] -> 
             RGBColor[
              0.9010063592820294, 0.9233011224064666, 0.9695861415323961], 
             UndirectedEdge[122, 138] -> 
             RGBColor[
              0.9803664381388025, 0.9462795715466461, 0.5417709067508937], 
             UndirectedEdge[58, 160] -> 
             RGBColor[
              0.9664210466628154, 0.8953067656458548, 0.3401228176994664], 
             UndirectedEdge[158, 225] -> 
             RGBColor[
              0.974410338244774, 0.9772229081103694, 0.7369493107605516], 
             UndirectedEdge[197, 204] -> 
             RGBColor[
              0.6908768876888844, 0.5914763525060198, 0.5906459694635654], 
             UndirectedEdge[40, 182] -> 
             RGBColor[
              0.9761462425416101, 0.9804605197917106, 0.8683906307257645], 
             UndirectedEdge[1, 149] -> 
             RGBColor[
              0.9761187772877586, 0.9492853892480488, 0.6283985472559324], 
             UndirectedEdge[32, 156] -> 
             RGBColor[
              0.9558507117831134, 0.8751829611014086, 0.5908694764552823], 
             UndirectedEdge[258, 286] -> 
             RGBColor[
              0.9470417980201407, 0.8441657976637342, 0.5868130574530106], 
             UndirectedEdge[101, 197] -> 
             RGBColor[
              0.7436266613920826, 0.7958022151435201, 0.8581405812102669], 
             UndirectedEdge[53, 271] -> 
             RGBColor[
              0.8521557195477111, 0.3530779921788356, 0.1956645377501094], 
             UndirectedEdge[22, 70] -> 
             RGBColor[
              0.7764641960047006, 0.8237785962379016, 0.915797792129944], 
             UndirectedEdge[76, 258] -> 
             RGBColor[
              0.9855052595386522, 0.9853316775829211, 0.7050126122623406], 
             UndirectedEdge[232, 297] -> 
             RGBColor[
              0.7998214669926736, 0.8414130140734177, 0.8621181516721568], 
             UndirectedEdge[178, 261] -> 
             RGBColor[
              0.8936300635922823, 0.9130702288584465, 0.7099005514108819], 
             UndirectedEdge[155, 227] -> 
             RGBColor[
              0.9916814014892827, 0.989198015442365, 0.6690372047731483], 
             UndirectedEdge[178, 182] -> 
             RGBColor[
              0.8932311186596755, 0.9151896331313476, 0.8825622853927106], 
             UndirectedEdge[5, 51] -> 
             RGBColor[
              0.9941922613205649, 0.9902184324885628, 0.626125489239461], 
             UndirectedEdge[110, 295] -> 
             RGBColor[
              0.973353771616178, 0.9791587418596934, 0.9080852696915278], 
             UndirectedEdge[186, 286] -> 
             RGBColor[
              0.9309379105684827, 0.8321555447699833, 0.6140727383421449], 
             UndirectedEdge[34, 270] -> 
             RGBColor[
              0.9580845808516751, 0.9682601295461548, 0.9558360507126678], 
             UndirectedEdge[4, 8] -> 
             RGBColor[
              0.977143590754529, 0.9661898537318598, 0.6609263110316627], 
             UndirectedEdge[69, 166] -> 
             RGBColor[
              0.9727543514784212, 0.9638103760255542, 0.6702539617516934], 
             UndirectedEdge[25, 176] -> 
             RGBColor[
              0.9785789218953919, 0.9383731328424865, 0.4589253589870456], 
             UndirectedEdge[32, 149] -> 
             RGBColor[
              0.9809509967058534, 0.9853138650498814, 0.9171291731879512], 
             UndirectedEdge[16, 153] -> 
             RGBColor[
              0.9726551792541833, 0.9194216401344315, 0.3482709643489484], 
             UndirectedEdge[169, 299] -> 
             RGBColor[
              0.9680075285582576, 0.9749650467562337, 0.9078886571789728], 
             UndirectedEdge[187, 229] -> 
             RGBColor[
              0.9301031597967746, 0.7608558192756392, 0.5663107511189351], 
             UndirectedEdge[15, 82] -> 
             RGBColor[
              0.8711992094985141, 0.9001346178542877, 0.9875769524023255], 
             UndirectedEdge[44, 280] -> 
             RGBColor[
              0.9452028219161878, 0.8075016559865006, 0.34559121697928485`], 
             UndirectedEdge[186, 265] -> 
             RGBColor[
              0.9584228391720312, 0.9685124020476292, 0.9552634676082041], 
             UndirectedEdge[117, 265] -> 
             RGBColor[
              0.9579595286175312, 0.9681668657946845, 0.956047731526227], 
             UndirectedEdge[106, 162] -> 
             RGBColor[
              0.9165389673251796, 0.8989970919266792, 0.6578703123464924], 
             UndirectedEdge[9, 146] -> 
             RGBColor[
              0.964199367794256, 0.9717693450946907, 0.8984112095241592], 
             UndirectedEdge[130, 294] -> 
             RGBColor[
              0.8914128341143794, 0.5369071348818326, 0.3046654489268418], 
             UndirectedEdge[13, 53] -> 
             RGBColor[
              0.8822830103221302, 0.4636585408259599, 0.35568062166087433`], 
             UndirectedEdge[34, 57] -> 
             RGBColor[
              0.9842420372703511, 0.9865822952227326, 0.8584457895947646], 
             UndirectedEdge[25, 144] -> 
             RGBColor[
              0.9699687280400058, 0.9345665773377176, 0.6173004133204083], 
             UndirectedEdge[206, 283] -> 
             RGBColor[
              0.963959993682049, 0.9721385324469389, 0.9233440776144961], 
             UndirectedEdge[107, 273] -> 
             RGBColor[
              0.9873340896980332, 0.9870957116812464, 0.7336627512367264], 
             UndirectedEdge[64, 85] -> 
             RGBColor[
              0.7614646507514844, 0.8116419286160901, 0.9163158399691507], 
             UndirectedEdge[175, 224] -> 
             RGBColor[
              0.9830316776533962, 0.9868656334937564, 0.9136071230722644], 
             UndirectedEdge[68, 163] -> 
             RGBColor[
              0.5236564076671557, 0.6112036754325588, 0.9589330342792132], 
             UndirectedEdge[7, 237] -> 
             RGBColor[
              0.9707503275984484, 0.9777062227316415, 0.9343962452261925], 
             UndirectedEdge[76, 126] -> 
             RGBColor[
              0.9805596157189355, 0.9816432245199248, 0.7133842972186285], 
             UndirectedEdge[30, 236] -> 
             RGBColor[
              0.9793283987956025, 0.9836886709937451, 0.9012884304725913], 
             UndirectedEdge[7, 269] -> 
             RGBColor[
              0.9312801065007479, 0.8027496707333592, 0.5916321199160732], 
             UndirectedEdge[237, 256] -> 
             RGBColor[
              0.5782876171853193, 0.6441223351540276, 0.9281104441615466], 
             UndirectedEdge[106, 290] -> 
             RGBColor[
              0.9150652167221656, 0.9343650274938641, 0.9658566397260617], 
             UndirectedEdge[180, 288] -> 
             RGBColor[
              0.8131694565810497, 0.814288741886732, 0.6424257367575557], 
             UndirectedEdge[201, 237] -> 
             RGBColor[
              0.9860804444949444, 0.9867610591656907, 0.7834171957389041], 
             UndirectedEdge[10, 73] -> 
             RGBColor[
              0.9767822782864797, 0.9786487398059882, 0.7057061706590256], 
             UndirectedEdge[18, 175] -> 
             RGBColor[
              0.9844466321088892, 0.9878283688147822, 0.9070680502046246], 
             UndirectedEdge[57, 295] -> 
             RGBColor[
              0.9892334849958409, 0.9898157836060348, 0.8280925466739784], 
             UndirectedEdge[71, 161] -> 
             RGBColor[
              0.9662316975084929, 0.9736931676978591, 0.9132472034331285], 
             UndirectedEdge[218, 220] -> 
             RGBColor[
              0.9745981089097789, 0.9800510224916843, 0.9043782381104133], 
             UndirectedEdge[192, 248] -> 
             RGBColor[
              0.8810853972478467, 0.9053513048733685, 0.86548130075807], 
             UndirectedEdge[23, 24] -> 
             RGBColor[
              0.5873705656700655, 0.6618026571551399, 0.9650645372037566], 
             UndirectedEdge[39, 195] -> 
             RGBColor[
              0.9834876734626636, 0.9735167074791737, 0.6556970771205789], 
             UndirectedEdge[79, 232] -> 
             RGBColor[
              0.8003733504528403, 0.8408119015220803, 0.7926884387545278], 
             UndirectedEdge[12, 154] -> 
             RGBColor[
              0.6336286594794133, 0.6407119674190842, 0.6091632332716577], 
             UndirectedEdge[106, 155] -> 
             RGBColor[
              0.9277139810302992, 0.9428384694846921, 0.9014554591832997], 
             UndirectedEdge[95, 103] -> 
             RGBColor[
              0.9275071336252454, 0.7502969721794462, 0.26052874196984144`], 
             UndirectedEdge[3, 228] -> 
             RGBColor[
              0.9757429364252604, 0.9790513625734363, 0.8009159004469666], 
             UndirectedEdge[81, 293] -> 
             RGBColor[
              0.9650913829291505, 0.9734857910629505, 0.9439753624621645], 
             UndirectedEdge[95, 145] -> 
             RGBColor[
              0.9721037293450979, 0.916719432910214, 0.5172637762666941], 
             UndirectedEdge[39, 153] -> 
             RGBColor[
              0.9820432593086441, 0.9686443593730945, 0.6500858008869383], 
             UndirectedEdge[39, 90] -> 
             RGBColor[
              0.9519505768813479, 0.8570571750677802, 0.5856652054493273], 
             UndirectedEdge[120, 141] -> 
             RGBColor[
              0.9511612759945489, 0.9417413254067794, 0.6834416349832745], 
             UndirectedEdge[102, 172] -> 
             RGBColor[
              0.9827310652256473, 0.9847017637343328, 0.8238931034249946], 
             UndirectedEdge[155, 194] -> 
             RGBColor[
              0.971791336392114, 0.9775226196657344, 0.8896439669819196], 
             UndirectedEdge[53, 251] -> 
             RGBColor[
              0.8521603184921622, 0.4419147706895782, 0.4451611914491417], 
             UndirectedEdge[128, 243] -> 
             RGBColor[
              0.8486479599266259, 0.8825122086989545, 0.9796021862838962], 
             UndirectedEdge[72, 87] -> 
             RGBColor[
              0.9911076170269801, 0.9905907853639073, 0.7970333288197752], 
             UndirectedEdge[76, 90] -> 
             RGBColor[
              0.9574805557445538, 0.8578026750187093, 0.3718970117917347], 
             UndirectedEdge[3, 106] -> 
             RGBColor[
              0.929985157879325, 0.9431139555331172, 0.8155719107745039], 
             UndirectedEdge[104, 243] -> 
             RGBColor[
              0.9685518811915709, 0.9740599267884722, 0.8425766394464518], 
             UndirectedEdge[34, 217] -> 
             RGBColor[
              0.9695188137741436, 0.9327853888669628, 0.6149931740085439], 
             UndirectedEdge[31, 37] -> 
             RGBColor[
              0.9300865497414726, 0.9468554242217642, 0.9850682611787804], 
             UndirectedEdge[64, 249] -> 
             RGBColor[
              0.7105363602392442, 0.772696707379652, 0.9727527544490169], 
             UndirectedEdge[89, 188] -> 
             RGBColor[
              0.9771634310713393, 0.9329992260764145, 0.5043716114973404], 
             UndirectedEdge[179, 269] -> 
             RGBColor[
              0.9352505347865898, 0.8057108096479604, 0.5849112204816886], 
             UndirectedEdge[213, 249] -> 
             RGBColor[
              0.9202510889963087, 0.9387233803283609, 0.9740924976756398], 
             UndirectedEdge[44, 252] -> 
             RGBColor[
              0.9332352132132573, 0.7531595399725194, 0.3356051509246266], 
             UndirectedEdge[149, 198] -> 
             RGBColor[
              0.983038307851182, 0.9726265906215146, 0.6552796168511296], 
             UndirectedEdge[158, 214] -> 
             RGBColor[
              0.9742773310339237, 0.9769384191354523, 0.7224722966848437], 
             UndirectedEdge[202, 216] -> 
             RGBColor[
              0.8519759697512708, 0.6924057449743899, 0.5997949990156779], 
             UndirectedEdge[78, 209] -> 
             RGBColor[
              0.790809047572115, 0.40572557921714514`, 0.44068294679330433`], 
             UndirectedEdge[77, 265] -> 
             RGBColor[
              0.9749308044729426, 0.9589681086357553, 0.6528448413417487], 
             UndirectedEdge[44, 204] -> 
             RGBColor[
              0.9402189478245933, 0.7848710477499378, 0.34143255027132546`], 
             UndirectedEdge[54, 102] -> 
             RGBColor[
              0.9746523990712561, 0.9590794938727696, 0.6539933271525762], 
             UndirectedEdge[2, 253] -> 
             RGBColor[
              0.9651818194091477, 0.9245457920407659, 0.611709750331495], 
             UndirectedEdge[40, 86] -> 
             RGBColor[
              0.8991154947403364, 0.9217558818809224, 0.9681050697519171], 
             UndirectedEdge[75, 165] -> 
             RGBColor[
              0.9549820972705614, 0.8542928459118141, 0.5301807907212988], 
             UndirectedEdge[73, 100] -> 
             RGBColor[
              0.9742454101823402, 0.9797220574899929, 0.902023104328462], 
             UndirectedEdge[50, 206] -> 
             RGBColor[
              0.9777657910667286, 0.9824348735315143, 0.8999744637708733], 
             UndirectedEdge[32, 277] -> 
             RGBColor[
              0.9770027347649427, 0.9823692577590357, 0.9238125507822759], 
             UndirectedEdge[156, 251] -> 
             RGBColor[
              0.9181014710493451, 0.8462344721600059, 0.6272001550025597], 
             UndirectedEdge[31, 44] -> 
             RGBColor[
              0.9687806867461572, 0.9726479715541042, 0.7166169457130802], 
             UndirectedEdge[80, 92] -> 
             RGBColor[
              0.8255570236619124, 0.381710776899313, 0.43774368669135255`], 
             UndirectedEdge[11, 149] -> 
             RGBColor[
              0.9780455144375556, 0.9831469611314754, 0.9220473967970388], 
             UndirectedEdge[103, 145] -> 
             RGBColor[
              0.9490216089326314, 0.8252065171354444, 0.498691360375822], 
             UndirectedEdge[150, 274] -> 
             RGBColor[
              0.9261114144697147, 0.9395608202806218, 0.7775633557387469], 
             UndirectedEdge[13, 156] -> 
             RGBColor[
              0.9632855087942971, 0.8788501273645785, 0.4929793003201586], 
             UndirectedEdge[84, 278] -> 
             RGBColor[
              0.9895257316773197, 0.9751434000310443, 0.5147076326226303], 
             UndirectedEdge[150, 293] -> 
             RGBColor[
              0.974524407390828, 0.977660417688781, 0.7647205896526446], 
             UndirectedEdge[52, 137] -> 
             RGBColor[
              0.9900487399779722, 0.9901529124922435, 0.814581661807799], 
             UndirectedEdge[41, 152] -> 
             RGBColor[
              0.9520826031124783, 0.846557378969622, 0.5462473341823055], 
             UndirectedEdge[177, 279] -> 
             RGBColor[
              0.9441845085225286, 0.8811644963796321, 0.6220084938961803], 
             UndirectedEdge[108, 279] -> 
             RGBColor[
              0.9698556632232554, 0.975774272757697, 0.8792743474053849], 
             UndirectedEdge[161, 279] -> 
             RGBColor[
              0.9461537543139109, 0.9593621386492258, 0.976031827983179], 
             UndirectedEdge[89, 260] -> 
             RGBColor[
              0.9568014549819628, 0.9197520253799134, 0.6289869608958936], 
             UndirectedEdge[63, 161] -> 
             RGBColor[
              0.9468842391574438, 0.8975109774959942, 0.6285588486192857], 
             UndirectedEdge[110, 148] -> 
             RGBColor[
              0.9741444893842569, 0.9714864094528785, 0.6819947363878699], 
             UndirectedEdge[200, 228] -> 
             RGBColor[
              0.9659181416549496, 0.9471503172900383, 0.6572827407959421], 
             UndirectedEdge[67, 118] -> 
             RGBColor[
              0.9372402610926263, 0.7744459038687119, 0.3170542241470015], 
             UndirectedEdge[140, 203] -> 
             RGBColor[
              0.7142734851410404, 0.6305778735292098, 0.596562729342019], 
             UndirectedEdge[144, 231] -> 
             RGBColor[
              0.9429757831961905, 0.9563034918388562, 0.9575398434988833], 
             UndirectedEdge[101, 149] -> 
             RGBColor[
              0.9873517377844561, 0.9885970693635147, 0.8395486380629398], 
             UndirectedEdge[131, 284] -> 
             RGBColor[
              0.9516968936066055, 0.9634962028576597, 0.966648739042917], 
             UndirectedEdge[157, 275] -> 
             RGBColor[
              0.9366584882470675, 0.9475613380618948, 0.745379415069269], 
             UndirectedEdge[113, 144] -> 
             RGBColor[
              0.950206429992798, 0.8582921167911653, 0.5905849351719126], 
             UndirectedEdge[48, 73] -> 
             RGBColor[
              0.977591376549703, 0.9803793191786401, 0.7937715234352043], 
             UndirectedEdge[35, 183] -> 
             RGBColor[
              0.9568815251118565, 0.8538286548173228, 0.46603905818212144`], 
             UndirectedEdge[93, 107] -> 
             RGBColor[
              0.9226187893550208, 0.9399665592709912, 0.9519640605596144], 
             UndirectedEdge[23, 226] -> 
             RGBColor[
              0.5887511646482685, 0.5612730783808634, 0.5980322976679743], 
             UndirectedEdge[200, 211] -> 
             RGBColor[
              0.8900790576495903, 0.5539892324262055, 0.24781504978024557`], 
             UndirectedEdge[87, 227] -> 
             RGBColor[
              0.9929231881065638, 0.9897115261210712, 0.6484575868840514], 
             UndirectedEdge[223, 278] -> 
             RGBColor[
              0.9620581278277609, 0.8788040877366056, 0.3324727631935934], 
             UndirectedEdge[182, 229] -> 
             RGBColor[
              0.9344639414941791, 0.7628381156558977, 0.502057347197585], 
             UndirectedEdge[79, 221] -> 
             RGBColor[
              0.9945597761780088, 0.9907722362727903, 0.649243394025032], 
             UndirectedEdge[115, 228] -> 
             RGBColor[
              0.9705151362398714, 0.9775308174015052, 0.9347943628485331], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.6414209574140182, 0.6694538175579785, 0.6266408274132423], 
             UndirectedEdge[9, 47] -> 
             RGBColor[
              0.9655304618952996, 0.9705076417013607, 0.7446277231356375], 
             UndirectedEdge[18, 224] -> 
             RGBColor[
              0.98333403024521, 0.9869985921665687, 0.9089513949467928], 
             UndirectedEdge[194, 291] -> 
             RGBColor[
              0.9563478346817421, 0.9192826297773606, 0.6294765502810299], 
             UndirectedEdge[5, 198] -> 
             RGBColor[
              0.9889541005464346, 0.9738655537793701, 0.4571816511873388], 
             UndirectedEdge[49, 172] -> 
             RGBColor[
              0.9293139169687313, 0.9430011523723201, 0.8497511176795238], 
             UndirectedEdge[162, 228] -> 
             RGBColor[
              0.9622967458711151, 0.9349344989669983, 0.6432143020189551], 
             UndirectedEdge[100, 161] -> 
             RGBColor[
              0.9660743688837806, 0.9736281082683793, 0.9158545458980403], 
             UndirectedEdge[174, 235] -> 
             RGBColor[
              0.9826992925894574, 0.9842874052959381, 0.7929494910721983], 
             UndirectedEdge[14, 67] -> 
             RGBColor[
              0.970935757007075, 0.9678220091569194, 0.684727484099707], 
             UndirectedEdge[190, 199] -> 
             RGBColor[
              0.9453195033314767, 0.9292786772418657, 0.6714028863168781], 
             UndirectedEdge[160, 288] -> 
             RGBColor[
              0.9760828386948368, 0.930983940280465, 0.3615867740167152], 
             UndirectedEdge[33, 275] -> 
             RGBColor[
              0.9363807027534142, 0.946967182979392, 0.715144178378452], 
             UndirectedEdge[109, 218] -> 
             RGBColor[
              0.8120796204589296, 0.8535944158233604, 0.9582238421589524], 
             UndirectedEdge[231, 264] -> 
             RGBColor[
              0.9519655520734548, 0.9609219199345009, 0.8404791878314677], 
             UndirectedEdge[221, 230] -> 
             RGBColor[
              0.9936718823871808, 0.9888731212340419, 0.5526016343387082], 
             UndirectedEdge[45, 236] -> 
             RGBColor[
              0.9902623604022345, 0.98899241797292, 0.7202645115213928], 
             UndirectedEdge[279, 280] -> 
             RGBColor[
              0.9227691669430479, 0.794359969094161, 0.6046789309259512], 
             UndirectedEdge[71, 252] -> 
             RGBColor[
              0.9308795014346993, 0.754348882128813, 0.5319082403212425], 
             UndirectedEdge[230, 296] -> 
             RGBColor[
              0.9815250489507477, 0.949315947770635, 0.3849264560054452], 
             UndirectedEdge[27, 154] -> 
             RGBColor[
              0.9690332968443199, 0.910241009266411, 0.542660349391744], 
             UndirectedEdge[5, 101] -> 
             RGBColor[
              0.9932675304797088, 0.9898360325213702, 0.6414506723991489], 
             UndirectedEdge[68, 143] -> 
             RGBColor[
              0.59572533782871, 0.6683854885752745, 0.9631211564404927], 
             UndirectedEdge[58, 221] -> 
             RGBColor[
              0.9701636376768965, 0.9065144560087074, 0.47514910122990306`], 
             UndirectedEdge[85, 249] -> 
             RGBColor[
              0.9354162030138506, 0.949675890153161, 0.9324075262778599], 
             UndirectedEdge[26, 54] -> 
             RGBColor[
              0.9868902725929901, 0.9660251237744336, 0.5238784383701491], 
             UndirectedEdge[269, 282] -> 
             RGBColor[
              0.9410468236821774, 0.8100336724157378, 0.5750996152957193], 
             UndirectedEdge[24, 210] -> 
             RGBColor[
              0.9576995143146896, 0.9644291457824281, 0.7547034742402152], 
             UndirectedEdge[144, 288] -> 
             RGBColor[
              0.9709023017974151, 0.9377157408350014, 0.6209271710773323], 
             UndirectedEdge[182, 199] -> 
             RGBColor[
              0.954580707182309, 0.9639031713348849, 0.8884682535693492], 
             UndirectedEdge[35, 224] -> 
             RGBColor[
              0.9504270224096527, 0.8511735264538622, 0.5845609224680222], 
             UndirectedEdge[161, 280] -> 
             RGBColor[
              0.921016082297409, 0.793052521435856, 0.6076464459533144], 
             UndirectedEdge[27, 42] -> 
             RGBColor[
              0.9747061991006709, 0.979623322084272, 0.8814319348564549], 
             UndirectedEdge[13, 273] -> 
             RGBColor[
              0.9944411109291125, 0.9905184233042983, 0.6363274139997039], 
             UndirectedEdge[167, 202] -> 
             RGBColor[
              0.653531968724788, 0.533572340296864, 0.5823678943054469], 
             UndirectedEdge[117, 207] -> 
             RGBColor[
              0.7044487569587348, 0.7670834127606057, 0.9646392548948777], 
             UndirectedEdge[33, 248] -> 
             RGBColor[
              0.9931972009642488, 0.9891881407941697, 0.5976353569956572], 
             UndirectedEdge[23, 210] -> 
             RGBColor[
              0.6230156551589389, 0.6855466168093357, 0.7273404432047416], 
             UndirectedEdge[54, 111] -> 
             RGBColor[
              0.9858549592265136, 0.9638106931697785, 0.41119096764265184`], 
             UndirectedEdge[30, 267] -> 
             RGBColor[
              0.9628108534094768, 0.9162893559032266, 0.6069528780424571], 
             UndirectedEdge[170, 199] -> 
             RGBColor[
              0.9561026535708562, 0.9645325352787874, 0.8632456632401255], 
             UndirectedEdge[169, 200] -> 
             RGBColor[
              0.9816209967868762, 0.958165879994209, 0.5995514716324286], 
             UndirectedEdge[137, 278] -> 
             RGBColor[
              0.9898554661248296, 0.9760185477416369, 0.5629456073041412], 
             UndirectedEdge[92, 150] -> 
             RGBColor[
              0.8761528106284401, 0.4191482845299681, 0.2990687768233216], 
             UndirectedEdge[68, 185] -> 
             RGBColor[
              0.6021943816965403, 0.614570954290739, 0.6088490256578741], 
             UndirectedEdge[26, 102] -> 
             RGBColor[
              0.9825575798049178, 0.9843306959614587, 0.8050102860064822], 
             UndirectedEdge[270, 271] -> 
             RGBColor[
              0.9219327358439857, 0.8072529527835149, 0.6152060971946364], 
             UndirectedEdge[169, 202] -> 
             RGBColor[
              0.930764859265715, 0.7531757955599958, 0.529060504035437], 
             UndirectedEdge[17, 97] -> 
             RGBColor[
              0.9333340744909158, 0.9452454466115683, 0.7722108823506256], 
             UndirectedEdge[46, 158] -> 
             RGBColor[
              0.9648674024023121, 0.9733187467527689, 0.9443545030706246], 
             UndirectedEdge[98, 285] -> 
             RGBColor[
              0.931110151737032, 0.747851350729309, 0.5002795664388078], 
             UndirectedEdge[77, 168] -> 
             RGBColor[
              0.9858792500094957, 0.9656674136504043, 0.5686602613893648], 
             UndirectedEdge[242, 268] -> 
             RGBColor[
              0.9569675113287339, 0.9250262563054205, 0.6396391663495697], 
             UndirectedEdge[115, 134] -> 
             RGBColor[
              0.9859357586667752, 0.9884296696290994, 0.8817404200020721], 
             UndirectedEdge[99, 284] -> 
             RGBColor[
              0.9645320341185571, 0.9730686296358596, 0.9449221940969648], 
             UndirectedEdge[204, 283] -> 
             RGBColor[
              0.9141806344666972, 0.7690410125363333, 0.6066220106179074], 
             UndirectedEdge[77, 167] -> 
             RGBColor[
              0.706327701084035, 0.7451051335584651, 0.66039382158665], 
             UndirectedEdge[227, 290] -> 
             RGBColor[
              0.9790326371811491, 0.980724573451537, 0.7334383853159103], 
             UndirectedEdge[60, 145] -> 
             RGBColor[
              0.9914444624169835, 0.9907300795892053, 0.7914509289794953], 
             UndirectedEdge[32, 125] -> 
             RGBColor[
              0.900032043750633, 0.632672367606666, 0.44256354429840694`], 
             UndirectedEdge[15, 60] -> 
             RGBColor[
              0.9443289657218114, 0.9562210733149382, 0.9088705062302913], 
             UndirectedEdge[30, 260] -> 
             RGBColor[
              0.9631931492611041, 0.972070091501394, 0.9471885769235353], 
             UndirectedEdge[42, 80] -> 
             RGBColor[
              0.9005172909074537, 0.9229111525599872, 0.9695394937542325], 
             UndirectedEdge[97, 130] -> 
             RGBColor[
              0.8914593710262283, 0.5370066726306739, 0.3097307045890653], 
             UndirectedEdge[65, 211] -> 
             RGBColor[
              0.8711910567822069, 0.48283063720916986`, 0.21321207164103445`],
              UndirectedEdge[1, 256] -> 
             RGBColor[
              0.574812186578179, 0.6091057502258672, 0.637083128679778], 
             UndirectedEdge[5, 128] -> 
             RGBColor[
              0.8743050623264319, 0.8984742083110377, 0.7480873326484817], 
             UndirectedEdge[125, 256] -> 
             RGBColor[
              0.6328871064197839, 0.40617888358819954`, 0.447688374557209], 
             UndirectedEdge[39, 239] -> 
             RGBColor[
              0.9402014787203198, 0.9539607544959219, 0.952747858920949], 
             UndirectedEdge[156, 269] -> 
             RGBColor[
              0.9150237018744585, 0.6992145182294542, 0.2504020406949127], 
             UndirectedEdge[78, 170] -> 
             RGBColor[
              0.8839321160676414, 0.47721525154980915`, 0.3614281929204649], 
             UndirectedEdge[23, 155] -> 
             RGBColor[
              0.6213285037177567, 0.6865203020542616, 0.876791553070295], 
             UndirectedEdge[127, 251] -> 
             RGBColor[
              0.908024027955105, 0.9294977285085047, 0.9910893364606187], 
             UndirectedEdge[241, 290] -> 
             RGBColor[
              0.776086932655409, 0.8245862358632257, 0.9526766728340599], 
             UndirectedEdge[85, 234] -> 
             RGBColor[
              0.9185634200942674, 0.9362379385096912, 0.9308000927983332], 
             UndirectedEdge[270, 289] -> 
             RGBColor[
              0.966801530150064, 0.9724347468987167, 0.8201670701132019], 
             UndirectedEdge[69, 258] -> 
             RGBColor[
              0.9698895243032796, 0.9770642370435405, 0.9358533606714576], 
             UndirectedEdge[52, 289] -> 
             RGBColor[
              0.9897997604487367, 0.9894504913862652, 0.7751333616188696], 
             UndirectedEdge[47, 170] -> 
             RGBColor[
              0.9940307190104609, 0.9899874181427014, 0.6168661518349388], 
             UndirectedEdge[72, 241] -> 
             RGBColor[
              0.788631226452043, 0.833016476612779, 0.8900068390278629], 
             UndirectedEdge[115, 210] -> 
             RGBColor[
              0.9887008290260175, 0.9879017315580438, 0.714425404099524], 
             UndirectedEdge[166, 239] -> 
             RGBColor[
              0.941025124276308, 0.9391845835684992, 0.690603648056983], 
             UndirectedEdge[180, 215] -> 
             RGBColor[
              0.8203751987334555, 0.8597665965910708, 0.9434401163233057], 
             UndirectedEdge[51, 254] -> 
             RGBColor[
              0.9836584762820513, 0.9552216771458464, 0.539611268092212], 
             UndirectedEdge[109, 227] -> 
             RGBColor[
              0.8278533967124798, 0.8621998901202246, 0.7445848832623555], 
             UndirectedEdge[203, 255] -> 
             RGBColor[
              0.9295081039117248, 0.8009354606447778, 0.5943035878905677], 
             UndirectedEdge[257, 272] -> 
             RGBColor[
              0.9131466415981502, 0.9334469525757751, 0.9868832208182345], 
             UndirectedEdge[32, 128] -> 
             RGBColor[
              0.8678000849178733, 0.8967958321587004, 0.947182634347915], 
             UndirectedEdge[39, 76] -> 
             RGBColor[
              0.9875464411578055, 0.9868539874923574, 0.7015574242065423], 
             UndirectedEdge[144, 221] -> 
             RGBColor[
              0.985875759130559, 0.9868077804248667, 0.7995832494861839], 
             UndirectedEdge[165, 262] -> 
             RGBColor[
              0.9514020425134216, 0.8526784713246569, 0.5835139065000061], 
             UndirectedEdge[101, 226] -> 
             RGBColor[
              0.9589894584659876, 0.8655334446311727, 0.5106642640706183], 
             UndirectedEdge[56, 191] -> 
             RGBColor[
              0.9923585720350366, 0.9851599362846267, 0.48653803359276326`], 
             UndirectedEdge[63, 71] -> 
             RGBColor[
              0.9687152669976647, 0.9131494542029324, 0.562806709041872], 
             UndirectedEdge[137, 289] -> 
             RGBColor[
              0.9948361018330493, 0.9915331479767482, 0.691668151247112], 
             UndirectedEdge[148, 295] -> 
             RGBColor[
              0.9879268369260943, 0.9812761365254354, 0.6367607931118836], 
             UndirectedEdge[10, 119] -> 
             RGBColor[
              0.9547449940656023, 0.8471895191299015, 0.35594167499164064`], 
             UndirectedEdge[115, 231] -> 
             RGBColor[
              0.9465279947108984, 0.9589527253703128, 0.9515268759696252], 
             UndirectedEdge[33, 171] -> 
             RGBColor[
              0.879448471531161, 0.9020053398831465, 0.7095986621826542], 
             UndirectedEdge[173, 234] -> 
             RGBColor[
              0.9200797473291742, 0.9368649787891575, 0.905670626386835], 
             UndirectedEdge[69, 173] -> 
             RGBColor[
              0.9756110487730854, 0.9804698991565286, 0.8875912031710906], 
             UndirectedEdge[4, 263] -> 
             RGBColor[
              0.9498060838262057, 0.8657960636255163, 0.5973162139938863], 
             UndirectedEdge[134, 160] -> 
             RGBColor[
              0.987564084049489, 0.9790486355431063, 0.6284129904707132], 
             UndirectedEdge[7, 205] -> 
             RGBColor[
              0.9525916636417397, 0.888832700057119, 0.6088621381026968], 
             UndirectedEdge[23, 106] -> 
             RGBColor[
              0.5590721838268573, 0.6392382956124778, 0.9623654122812877], 
             UndirectedEdge[45, 96] -> 
             RGBColor[
              0.9727177555451677, 0.9763227435886049, 0.7685503289147069], 
             UndirectedEdge[65, 210] -> 
             RGBColor[
              0.9557718331400208, 0.8507833386210237, 0.3850093148381164], 
             UndirectedEdge[138, 211] -> 
             RGBColor[
              0.8963084760487164, 0.5755665530932583, 0.381043935790062], 
             UndirectedEdge[72, 210] -> 
             RGBColor[
              0.9915529818508813, 0.9891035894402751, 0.6681618368433186], 
             UndirectedEdge[37, 41] -> 
             RGBColor[
              0.9155613900380918, 0.8194999020082995, 0.6214248279368435], 
             UndirectedEdge[52, 88] -> 
             RGBColor[
              0.8358386271815375, 0.8716086635829017, 0.9337254329104446], 
             UndirectedEdge[157, 285] -> 
             RGBColor[
              0.9924644435817052, 0.9893644104275978, 0.6446179043461878], 
             UndirectedEdge[135, 265] -> 
             RGBColor[
              0.955242195945526, 0.9661402835371269, 0.9606474669460653], 
             UndirectedEdge[17, 42] -> 
             RGBColor[
              0.915980167649074, 0.9352408307451474, 0.9710143567417213], 
             UndirectedEdge[242, 250] -> 
             RGBColor[
              0.9553503908110327, 0.9238202104711106, 0.6423765295734584], 
             UndirectedEdge[81, 202] -> 
             RGBColor[
              0.9240525864991357, 0.7488653944631736, 0.5715730623738438], 
             UndirectedEdge[229, 259] -> 
             RGBColor[
              0.9359244606786492, 0.7629893113661114, 0.4449414192542194], 
             UndirectedEdge[40, 81] -> 
             RGBColor[
              0.9677053697729155, 0.9754352981710198, 0.9395505645726281], 
             UndirectedEdge[100, 119] -> 
             RGBColor[
              0.952208125961463, 0.848262836813906, 0.552258608661077], 
             UndirectedEdge[81, 269] -> 
             RGBColor[
              0.9368310875686015, 0.806889583324867, 0.5822357568959298], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.9228290942810768, 0.9402211312752855, 0.9549963233535776], 
             UndirectedEdge[180, 233] -> 
             RGBColor[
              0.522111123044331, 0.620702855081141, 0.9562515137422511], 
             UndirectedEdge[33, 184] -> 
             RGBColor[
              0.9888490646710981, 0.9873900746949462, 0.6696952279891799], 
             UndirectedEdge[103, 168] -> 
             RGBColor[
              0.9487206292384852, 0.8250820542970896, 0.5036793728183049], 
             UndirectedEdge[49, 238] -> 
             RGBColor[
              0.8809667834221844, 0.7628712336482386, 0.6119080975544798], 
             UndirectedEdge[97, 120] -> 
             RGBColor[
              0.9583291883048346, 0.965175871892497, 0.7745949386195987], 
             UndirectedEdge[117, 212] -> 
             RGBColor[
              0.7411787051181635, 0.7969024393417382, 0.9675307709602212], 
             UndirectedEdge[270, 278] -> 
             RGBColor[
              0.9618208944418443, 0.9569201466636054, 0.6914445261702311], 
             UndirectedEdge[26, 165] -> 
             RGBColor[
              0.9571068415821888, 0.8547517449962259, 0.46445780866774167`], 
             UndirectedEdge[65, 70] -> 
             RGBColor[
              0.7422894544635951, 0.686122636066125, 0.6060229460734112], 
             UndirectedEdge[56, 223] -> 
             RGBColor[
              0.9652642057576007, 0.8896189414168517, 0.34492777053400636`], 
             UndirectedEdge[207, 212] -> 
             RGBColor[
              0.5008277590329212, 0.6056335626731792, 0.9538461422650533], 
             UndirectedEdge[171, 184] -> 
             RGBColor[
              0.8756430735333028, 0.9026984512444203, 0.937432113375191], 
             UndirectedEdge[32, 205] -> 
             RGBColor[
              0.9608463592248844, 0.8949890385072048, 0.5948890916498477], 
             UndirectedEdge[23, 31] -> 
             RGBColor[
              0.5987369655503998, 0.670631555599023, 0.9580232562659801], 
             UndirectedEdge[235, 274] -> 
             RGBColor[
              0.9264919839999484, 0.9403748200243098, 0.8189860005017919], 
             UndirectedEdge[178, 199] -> 
             RGBColor[
              0.85597569734263, 0.8882007608866076, 0.986070530566782], 
             UndirectedEdge[117, 158] -> 
             RGBColor[
              0.950152961308157, 0.9623447406774339, 0.9692622137021554], 
             UndirectedEdge[112, 190] -> 
             RGBColor[
              0.576120360398845, 0.6135185276967932, 0.6421651369451677], 
             UndirectedEdge[64, 213] -> 
             RGBColor[
              0.7462995367339424, 0.8006894187912901, 0.9580008113669305], 
             UndirectedEdge[127, 205] -> 
             RGBColor[
              0.92625781592121, 0.8685608039017128, 0.6315212403395953], 
             UndirectedEdge[121, 263] -> 
             RGBColor[
              0.9615714241715763, 0.8724165658025922, 0.47016628709978847`], 
             UndirectedEdge[14, 213] -> 
             RGBColor[
              0.9550679806046989, 0.9660103540211895, 0.9609423680754476], 
             UndirectedEdge[109, 111] -> 
             RGBColor[
              0.8275195589806459, 0.861485844968004, 0.7082487063598909], 
             UndirectedEdge[55, 108] -> 
             RGBColor[
              0.9925432176473713, 0.991184443113692, 0.7732417113245827], 
             UndirectedEdge[40, 162] -> 
             RGBColor[
              0.9640383150474127, 0.9362333584071232, 0.6402662796774717], 
             UndirectedEdge[15, 225] -> 
             RGBColor[
              0.9463508340896755, 0.9553597948063568, 0.7519818134405523], 
             UndirectedEdge[31, 59] -> 
             RGBColor[
              0.9644269012957429, 0.9581289753303912, 0.6854735499988596], 
             UndirectedEdge[210, 227] -> 
             RGBColor[
              0.9933685529304648, 0.9882243301974389, 0.519586094907595], 
             UndirectedEdge[52, 93] -> 
             RGBColor[
              0.9246163068754727, 0.9413200065540537, 0.942479080935697], 
             UndirectedEdge[32, 293] -> 
             RGBColor[
              0.9677950974444416, 0.9755022169215285, 0.9393986790294591], 
             UndirectedEdge[99, 209] -> 
             RGBColor[
              0.8399953030531642, 0.8753557103816169, 0.9586448592909502], 
             UndirectedEdge[201, 299] -> 
             RGBColor[
              0.9710743916203208, 0.9755695695019528, 0.8088185290502347], 
             UndirectedEdge[127, 148] -> 
             RGBColor[
              0.9499511400396861, 0.952810893481518, 0.7010305332056573], 
             UndirectedEdge[24, 226] -> 
             RGBColor[
              0.9234350238040192, 0.8401556073539558, 0.6253953287034479], 
             UndirectedEdge[144, 264] -> 
             RGBColor[
              0.9859424000963204, 0.9869503187121953, 0.8068367073489486], 
             UndirectedEdge[148, 217] -> 
             RGBColor[
              0.9753009792677121, 0.92834654484345, 0.3585493977840998], 
             UndirectedEdge[230, 288] -> 
             RGBColor[
              0.9786984250540369, 0.9397810816441766, 0.3739455559298567], 
             UndirectedEdge[1, 83] -> 
             RGBColor[
              0.9797768932067099, 0.9512386776017413, 0.5875034292877397], 
             UndirectedEdge[15, 214] -> 
             RGBColor[
              0.946217826878825, 0.9550753058314396, 0.7375047993648443], 
             UndirectedEdge[173, 249] -> 
             RGBColor[
              0.9369325302487574, 0.9503029304326274, 0.9072780598663619], 
             UndirectedEdge[114, 204] -> 
             RGBColor[
              0.9217956040737201, 0.7228816183586956, 0.25568631014584764`], 
             UndirectedEdge[77, 95] -> 
             RGBColor[
              0.9646657543962559, 0.890882331532761, 0.32550963054090126`], 
             UndirectedEdge[52, 295] -> 
             RGBColor[
              0.9860742588758376, 0.9885093624170055, 0.8804490992975491], 
             UndirectedEdge[7, 103] -> 
             RGBColor[
              0.9341387170195186, 0.8156729157799523, 0.5940144641041306], 
             UndirectedEdge[29, 99] -> 
             RGBColor[
              0.9329441618054619, 0.8091153336267922, 0.5922279157602561], 
             UndirectedEdge[28, 144] -> 
             RGBColor[
              0.9860354476356359, 0.9871493379902417, 0.8169643577805858], 
             UndirectedEdge[75, 185] -> 
             RGBColor[
              0.9711240107910815, 0.9182901540468649, 0.5431689532393174], 
             UndirectedEdge[227, 291] -> 
             RGBColor[
              0.9762378997789108, 0.9309580255539912, 0.40886978807225866`], 
             UndirectedEdge[76, 192] -> 
             RGBColor[
              0.8807536376285818, 0.9033113894676783, 0.7326714474352092], 
             UndirectedEdge[59, 72] -> 
             RGBColor[
              0.9869139689516002, 0.9739745205443552, 0.6059731935397394], 
             UndirectedEdge[104, 254] -> 
             RGBColor[
              0.9836751985528631, 0.955025171057839, 0.5245475646637884], 
             UndirectedEdge[32, 237] -> 
             RGBColor[
              0.979005023181593, 0.9838625611817273, 0.9204231987733434], 
             UndirectedEdge[25, 232] -> 
             RGBColor[
              0.7847054302263402, 0.7890821323953239, 0.6364313445197236], 
             UndirectedEdge[9, 141] -> 
             RGBColor[
              0.9586265034692044, 0.947637665884095, 0.6822041708588977], 
             UndirectedEdge[22, 48] -> 
             RGBColor[
              0.9904942731963522, 0.9896107705360544, 0.7543977642735606], 
             UndirectedEdge[25, 160] -> 
             RGBColor[
              0.9751492649374276, 0.9278347767831812, 0.3579600162597912], 
             UndirectedEdge[72, 106] -> 
             RGBColor[
              0.9276095105187996, 0.9427952682434173, 0.9031868059198649], 
             UndirectedEdge[4, 186] -> 
             RGBColor[
              0.958515135455258, 0.9685812364645384, 0.9551072340754272], 
             UndirectedEdge[78, 182] -> 
             RGBColor[
              0.8829174851419433, 0.4767956755872075, 0.37824325313994733`], 
             UndirectedEdge[106, 211] -> 
             RGBColor[
              0.8536105896698473, 0.5435516009549981, 0.45787542796078773`], 
             UndirectedEdge[180, 245] -> 
             RGBColor[
              0.7933239058469247, 0.7382363575346975, 0.6127676891450549], 
             UndirectedEdge[136, 280] -> 
             RGBColor[
              0.9432002911422259, 0.8088370475645326, 0.5360411831266038], 
             UndirectedEdge[82, 140] -> 
             RGBColor[
              0.6865550104709763, 0.7535276967443045, 0.9705194112517155], 
             UndirectedEdge[50, 219] -> 
             RGBColor[
              0.9757332094481284, 0.9814224478564124, 0.9259615259984109], 
             UndirectedEdge[251, 278] -> 
             RGBColor[
              0.9447445907061927, 0.9433895002865705, 0.6927813147451947], 
             UndirectedEdge[80, 150] -> 
             RGBColor[
              0.9179267514355287, 0.9330345921439216, 0.7767826952720113], 
             UndirectedEdge[26, 183] -> 
             RGBColor[
              0.9948117672603882, 0.9913112197177933, 0.6766710682333432], 
             UndirectedEdge[243, 256] -> 
             RGBColor[
              0.5604922810050263, 0.6308506025679538, 0.958233306547778], 
             UndirectedEdge[184, 248] -> 
             RGBColor[
              0.9893918029663906, 0.9898812521554434, 0.825468808188194], 
             UndirectedEdge[4, 255] -> 
             RGBColor[
              0.9659359987529856, 0.9741157041614352, 0.9425456481834988], 
             UndirectedEdge[37, 280] -> 
             RGBColor[
              0.9065086849115032, 0.7817091086541605, 0.6140425324449851], 
             UndirectedEdge[188, 260] -> 
             RGBColor[
              0.9747818058726931, 0.9787741648963533, 0.8374241689526867], 
             UndirectedEdge[70, 266] -> 
             RGBColor[
              0.7800656534183468, 0.8239475154268672, 0.7601349255607625], 
             UndirectedEdge[103, 127] -> 
             RGBColor[
              0.907804869298989, 0.795401019624546, 0.6166735663410292], 
             UndirectedEdge[37, 268] -> 
             RGBColor[
              0.9331086761653795, 0.949109321160436, 0.9799525894399146], 
             UndirectedEdge[186, 196] -> 
             RGBColor[
              0.9681719347945679, 0.9695281404827165, 0.6974033604058473], 
             UndirectedEdge[139, 274] -> 
             RGBColor[
              0.9267724106111099, 0.9409746241901051, 0.8495087065343043], 
             UndirectedEdge[15, 255] -> 
             RGBColor[
              0.9299776310052861, 0.9463616313232628, 0.9709488665722049], 
             UndirectedEdge[118, 195] -> 
             RGBColor[
              0.9358447942601105, 0.7697386665714421, 0.3116330990144768], 
             UndirectedEdge[125, 128] -> 
             RGBColor[
              0.8249908923675168, 0.5739532876755333, 0.46193429438128775`], 
             UndirectedEdge[61, 177] -> 
             RGBColor[
              0.9668883175013592, 0.8948840153733846, 0.3923253762716915], 
             UndirectedEdge[117, 276] -> 
             RGBColor[
              0.7912776246916231, 0.8375749991820797, 0.9714747414274333], 
             UndirectedEdge[7, 154] -> 
             RGBColor[
              0.9557540635713633, 0.9013705619707707, 0.6114066793171389], 
             UndirectedEdge[59, 198] -> 
             RGBColor[
              0.9843015061441028, 0.9587074354217249, 0.39351474509199613`], 
             UndirectedEdge[83, 197] -> 
             RGBColor[
              0.741473220945737, 0.7949117121780611, 0.8938286623314431], 
             UndirectedEdge[243, 283] -> 
             RGBColor[
              0.941377542100045, 0.9558000474004543, 0.9841167094256016], 
             UndirectedEdge[95, 225] -> 
             RGBColor[
              0.9719518554774615, 0.9149592561246257, 0.39639961778377575`], 
             UndirectedEdge[21, 74] -> 
             RGBColor[
              0.9658405011688085, 0.8926285495631658, 0.5158489325229424], 
             UndirectedEdge[62, 225] -> 
             RGBColor[
              0.9364130469473744, 0.7669404666148625, 0.3674359864859553], 
             UndirectedEdge[236, 267] -> 
             RGBColor[
              0.9701727834661877, 0.921364808094036, 0.5759036730192175], 
             UndirectedEdge[123, 300] -> 
             RGBColor[
              0.9826659086470009, 0.9841339834423825, 0.7828081586911144], 
             UndirectedEdge[111, 218] -> 
             RGBColor[
              0.9772848880719825, 0.9789560355091691, 0.699495591568122], 
             UndirectedEdge[61, 161] -> 
             RGBColor[
              0.9688575632927416, 0.9730816576429782, 0.7463487103586901], 
             UndirectedEdge[58, 180] -> 
             RGBColor[
              0.8035076645490282, 0.7786115672521217, 0.6209617804403069], 
             UndirectedEdge[188, 236] -> 
             RGBColor[
              0.9909170554071915, 0.9903927443887044, 0.7915240225017426], 
             UndirectedEdge[41, 268] -> 
             RGBColor[
              0.9332841913070109, 0.8332413577412057, 0.6095859013828746], 
             UndirectedEdge[65, 138] -> 
             RGBColor[
              0.9558751913762429, 0.8524974456315562, 0.5047870456585739], 
             UndirectedEdge[241, 291] -> 
             RGBColor[
              0.7732921952531706, 0.7748196879656799, 0.6281080755904082], 
             UndirectedEdge[270, 295] -> 
             RGBColor[
              0.9630760285771647, 0.9714936179294571, 0.9254828077918814], 
             UndirectedEdge[127, 212] -> 
             RGBColor[
              0.7243712162887745, 0.7837352860493636, 0.9740642324667429], 
             UndirectedEdge[105, 274] -> 
             RGBColor[
              0.6205688511782228, 0.6979293022068047, 0.9659824570576101], 
             UndirectedEdge[128, 142] -> 
             RGBColor[
              0.8739647972908478, 0.8999814325368953, 0.8735137056978755], 
             UndirectedEdge[38, 57] -> 
             RGBColor[
              0.9774255522641033, 0.9396452447595269, 0.5530586352340466], 
             UndirectedEdge[135, 255] -> 
             RGBColor[
              0.9499665442241996, 0.9622057111214486, 0.9695777691999329], 
             UndirectedEdge[46, 196] -> 
             RGBColor[
              0.9824230653342232, 0.9801566103051067, 0.6732799136923394], 
             UndirectedEdge[138, 210] -> 
             RGBColor[
              0.993447962039785, 0.9898872124471564, 0.6367571110616577], 
             UndirectedEdge[72, 109] -> 
             RGBColor[
              0.8260378256328962, 0.8630791493630607, 0.8931606251980793], 
             UndirectedEdge[277, 282] -> 
             RGBColor[
              0.9785147563632277, 0.9834969209913285, 0.9212530926147711], 
             UndirectedEdge[62, 117] -> 
             RGBColor[
              0.9121556700107574, 0.752062299181927, 0.5997488894275591], 
             UndirectedEdge[33, 126] -> 
             RGBColor[
              0.9803486370429078, 0.9811919624651178, 0.6904205703424753], 
             UndirectedEdge[217, 278] -> 
             RGBColor[
              0.9732551273643129, 0.9214454059844134, 0.35060164946610733`], 
             UndirectedEdge[228, 264] -> 
             RGBColor[
              0.9759526936024276, 0.9795000119656933, 0.8237466747103755], 
             UndirectedEdge[121, 239] -> 
             RGBColor[
              0.9466105612971601, 0.9565865683992951, 0.8346646792932109], 
             UndirectedEdge[56, 84] -> 
             RGBColor[
              0.9927318096071596, 0.9859582537112904, 0.5271626399630434], 
             UndirectedEdge[45, 120] -> 
             RGBColor[
              0.9583917220244854, 0.9653096251957012, 0.7814013480902077], 
             UndirectedEdge[67, 234] -> 
             RGBColor[
              0.9192660824791016, 0.927097083820621, 0.6962701802203723], 
             UndirectedEdge[153, 192] -> 
             RGBColor[
              0.8752504557794203, 0.8851017613484152, 0.6811998241156052], 
             UndirectedEdge[77, 127] -> 
             RGBColor[
              0.9449634900699995, 0.9359863789778609, 0.6816544549120891], 
             UndirectedEdge[36, 152] -> 
             RGBColor[
              0.6205575037797741, 0.6862014737661113, 0.8895690173265453], 
             UndirectedEdge[22, 122] -> 
             RGBColor[
              0.9768650507801439, 0.9448316578922902, 0.5997979565838851], 
             UndirectedEdge[68, 218] -> 
             RGBColor[
              0.6072658280322906, 0.6769923672732865, 0.9435861167677333], 
             UndirectedEdge[56, 148] -> 
             RGBColor[
              0.9898777807206136, 0.97751751893983, 0.41517751883064624`], 
             UndirectedEdge[7, 130] -> 
             RGBColor[
              0.8815070697973632, 0.5315428622974574, 0.4395292457480906], 
             UndirectedEdge[58, 296] -> 
             RGBColor[
              0.9580168042404633, 0.8669572825453005, 0.30747392289664], 
             UndirectedEdge[104, 116] -> 
             RGBColor[
              0.8966270563709325, 0.5742556428847791, 0.3627561170150814], 
             UndirectedEdge[252, 279] -> 
             RGBColor[
              0.9108015582401174, 0.7400178530801798, 0.5946928648712929], 
             UndirectedEdge[64, 173] -> 
             RGBColor[
              0.7629809779863911, 0.8122689688955564, 0.8911863735576526], 
             UndirectedEdge[109, 155] -> 
             RGBColor[
              0.8261422961443958, 0.8631223506043355, 0.8914292784615141], 
             UndirectedEdge[151, 258] -> 
             RGBColor[
              0.9306031068080746, 0.7729558135383501, 0.5732738619566156], 
             UndirectedEdge[167, 216] -> 
             RGBColor[
              0.6323571484397528, 0.70908889668315, 0.9662966446624419], 
             UndirectedEdge[12, 258] -> 
             RGBColor[
              0.6487678558493255, 0.7171542268872051, 0.9319108520070306], 
             UndirectedEdge[151, 239] -> 
             RGBColor[
              0.8908293048529482, 0.74233039040228, 0.6072409149576312], 
             UndirectedEdge[136, 226] -> 
             RGBColor[
              0.9567923550700641, 0.8646248859139766, 0.5470759532623932], 
             UndirectedEdge[59, 210] -> 
             RGBColor[
              0.9887055909042819, 0.973044036540704, 0.45479073693762095`], 
             UndirectedEdge[191, 205] -> 
             RGBColor[
              0.9675050218901202, 0.896996131883612, 0.4125214817042807], 
             UndirectedEdge[212, 276] -> 
             RGBColor[
              0.5876566267658097, 0.6761251490946533, 0.9606816287976088], 
             UndirectedEdge[218, 292] -> 
             RGBColor[
              0.9654451993147269, 0.9737496667439922, 0.9433764436114764], 
             UndirectedEdge[144, 245] -> 
             RGBColor[
              0.9510567510632901, 0.861663356482967, 0.5912691234648314], 
             UndirectedEdge[1, 277] -> 
             RGBColor[
              0.972170515346848, 0.9463407819572034, 0.635081924850257], 
             UndirectedEdge[64, 239] -> 
             RGBColor[
              0.7174856515614589, 0.7782378836464983, 0.9734155840590353], 
             UndirectedEdge[128, 256] -> 
             RGBColor[
              0.4670826789215996, 0.5570556061310007, 0.9548698797361181], 
             UndirectedEdge[7, 81] -> 
             RGBColor[
              0.9694034018941118, 0.9767016877467356, 0.9366762391091483], 
             UndirectedEdge[32, 145] -> 
             RGBColor[
              0.9869900083225158, 0.9882517149608057, 0.8367764519481342], 
             UndirectedEdge[84, 247] -> 
             RGBColor[
              0.9944117134044925, 0.9904555449716819, 0.6331276748653123], 
             UndirectedEdge[215, 259] -> 
             RGBColor[
              0.9870103117744404, 0.9876248677310911, 0.7953569453891733], 
             UndirectedEdge[187, 233] -> 
             RGBColor[
              0.6829249352034411, 0.746427634130689, 0.9295376746728347], 
             UndirectedEdge[37, 152] -> 
             RGBColor[
              0.9519070879708471, 0.9624253423888525, 0.9166140222393455], 
             UndirectedEdge[257, 300] -> 
             RGBColor[
              0.9398701661271696, 0.9509184532884662, 0.8102291485009281], 
             UndirectedEdge[10, 244] -> 
             RGBColor[
              0.9903807490734241, 0.9881678289458546, 0.6548049479045196], 
             UndirectedEdge[98, 157] -> 
             RGBColor[
              0.9318557418115898, 0.7463722138003893, 0.3579939122708967], 
             UndirectedEdge[13, 271] -> 
             RGBColor[
              0.950040469853286, 0.8263379616110527, 0.48232203108719884`], 
             UndirectedEdge[202, 203] -> 
             RGBColor[
              0.8857994735556616, 0.5743239062744059, 0.2264206202348374], 
             UndirectedEdge[166, 195] -> 
             RGBColor[
              0.9843113190186519, 0.9587405365517511, 0.393552866256613], 
             UndirectedEdge[260, 287] -> 
             RGBColor[
              0.9549570647215796, 0.9133918617681288, 0.622543695527869], 
             UndirectedEdge[212, 214] -> 
             RGBColor[
              0.7653030748439302, 0.8114961177997566, 0.7207408539429095], 
             UndirectedEdge[25, 113] -> 
             RGBColor[
              0.9432225268137477, 0.8105268035123324, 0.2839879854759566], 
             UndirectedEdge[244, 280] -> 
             RGBColor[
              0.9427855943829129, 0.808665559797336, 0.54291378162923], 
             UndirectedEdge[58, 134] -> 
             RGBColor[
              0.9666714256984048, 0.9054871116814833, 0.5633192392750495], 
             UndirectedEdge[64, 263] -> 
             RGBColor[
              0.7324465144358752, 0.6940678810497954, 0.6089171918656129], 
             UndirectedEdge[182, 261] -> 
             RGBColor[
              0.9922350734319614, 0.9887726393067238, 0.6122982744134492], 
             UndirectedEdge[150, 277] -> 
             RGBColor[
              0.9837320447113291, 0.9845274585262882, 0.7491344614054615], 
             UndirectedEdge[86, 202] -> 
             RGBColor[
              0.8554627114665565, 0.695185978173076, 0.6001275675531328], 
             UndirectedEdge[257, 267] -> 
             RGBColor[
              0.9194992573325156, 0.8826891030110355, 0.6352470733683364], 
             UndirectedEdge[134, 245] -> 
             RGBColor[
              0.9564876669963013, 0.8651119019640592, 0.5551251479797974], 
             UndirectedEdge[187, 297] -> 
             RGBColor[
              0.988165731749084, 0.9891952391170901, 0.8377719470836483], 
             UndirectedEdge[75, 292] -> 
             RGBColor[
              0.9797957068912923, 0.9833966274088791, 0.8718117605934692], 
             UndirectedEdge[54, 174] -> 
             RGBColor[
              0.9749010530462279, 0.95926493960017, 0.6535724208322924], 
             UndirectedEdge[44, 108] -> 
             RGBColor[
              0.9922893181963953, 0.9889159596500365, 0.6201866334587185], 
             UndirectedEdge[94, 141] -> 
             RGBColor[
              0.9236917270418988, 0.9198378527129788, 0.6808215648818149], 
             UndirectedEdge[185, 262] -> 
             RGBColor[
              0.9675439560339416, 0.9166757794597078, 0.5965020690180246], 
             UndirectedEdge[40, 202] -> 
             RGBColor[
              0.9168035733100859, 0.74345909229595, 0.583843750857467], 
             UndirectedEdge[110, 191] -> 
             RGBColor[
              0.9766252806986799, 0.9791288267976752, 0.7533552511499869], 
             UndirectedEdge[92, 125] -> 
             RGBColor[
              0.8315017198765585, 0.24160844179409974`, 0.17773935394527118`],
              UndirectedEdge[72, 226] -> 
             RGBColor[
              0.9572884913402109, 0.8648300510118028, 0.5388536913065514], 
             UndirectedEdge[130, 162] -> 
             RGBColor[
              0.8827630206922635, 0.5081681775158648, 0.23374214713789068`], 
             UndirectedEdge[29, 43] -> 
             RGBColor[
              0.944631354108759, 0.8172232022020367, 0.5451982432070381], 
             UndirectedEdge[152, 268] -> 
             RGBColor[
              0.9696298892397661, 0.9761667981217585, 0.9047750956853766], 
             UndirectedEdge[4, 62] -> 
             RGBColor[
              0.9254077918675383, 0.7619457099643561, 0.5773165038309634], 
             UndirectedEdge[18, 184] -> 
             RGBColor[
              0.9848963256869714, 0.9880222567719072, 0.8999705006304348], 
             UndirectedEdge[95, 159] -> 
             RGBColor[
              0.9624448375422088, 0.883390657487984, 0.3168817879478839], 
             UndirectedEdge[154, 255] -> 
             RGBColor[
              0.9541118785324504, 0.9001458230575806, 0.6141864702375646], 
             UndirectedEdge[140, 269] -> 
             RGBColor[
              0.7144033026911507, 0.6311673447046011, 0.5966710522879504], 
             UndirectedEdge[10, 161] -> 
             RGBColor[
              0.9686112369879201, 0.9725547905843747, 0.7195376122286039], 
             UndirectedEdge[216, 293] -> 
             RGBColor[
              0.8930147661812856, 0.9170261415741667, 0.9721972991039987], 
             UndirectedEdge[188, 294] -> 
             RGBColor[
              0.9943567478696884, 0.9903379792506039, 0.6271450156098395], 
             UndirectedEdge[32, 282] -> 
             RGBColor[
              0.9818738335908326, 0.9860021152876921, 0.9155670510560888], 
             UndirectedEdge[251, 282] -> 
             RGBColor[
              0.9441245928570642, 0.9570536263462894, 0.9518977296033662], 
             UndirectedEdge[181, 299] -> 
             RGBColor[
              0.9546144395605896, 0.9656721038530981, 0.9617100947606755], 
             UndirectedEdge[60, 159] -> 
             RGBColor[
              0.9817855706140943, 0.9574013041669753, 0.5910689406606853], 
             UndirectedEdge[137, 217] -> 
             RGBColor[
              0.978484742601768, 0.9376624273255031, 0.5187724935980077], 
             UndirectedEdge[20, 152] -> 
             RGBColor[
              0.9803662488889354, 0.9538602565124081, 0.5941719960075185], 
             UndirectedEdge[62, 196] -> 
             RGBColor[
              0.9350645912068483, 0.7628926139825342, 0.3196126301613836], 
             UndirectedEdge[251, 289] -> 
             RGBColor[
              0.9497252264144124, 0.9589041005216818, 0.8215038586881654], 
             UndirectedEdge[104, 283] -> 
             RGBColor[
              0.9678718612815631, 0.9735527690530188, 0.8437277357764972], 
             UndirectedEdge[45, 294] -> 
             RGBColor[
              0.9937020528647313, 0.9889376528348195, 0.5558855046294897], 
             UndirectedEdge[15, 158] -> 
             RGBColor[
              0.9274467154172382, 0.9444740786216906, 0.9752330464942658], 
             UndirectedEdge[150, 237] -> 
             RGBColor[
              0.9857343331279794, 0.9860207619489798, 0.745745109396529], 
             UndirectedEdge[169, 228] -> 
             RGBColor[
              0.9726760733631972, 0.9784468398277173, 0.8999860285757048], 
             UndirectedEdge[159, 251] -> 
             RGBColor[
              0.9395818757858583, 0.925974450597173, 0.6727251421766014], 
             UndirectedEdge[203, 293] -> 
             RGBColor[
              0.9268382699856763, 0.7989443028741828, 0.5988229203231581], 
             UndirectedEdge[145, 282] -> 
             RGBColor[
              0.9885020299208007, 0.9893793781930984, 0.8342169937806292], 
             UndirectedEdge[195, 234] -> 
             RGBColor[
              0.9178706156465858, 0.9223898465233512, 0.6908490550878477], 
             UndirectedEdge[156, 270] -> 
             RGBColor[
              0.9351777747849968, 0.8597651185370407, 0.6258633664275961], 
             UndirectedEdge[25, 134] -> 
             RGBColor[
              0.975399643973017, 0.9380151228188098, 0.5811564378353742], 
             UndirectedEdge[158, 276] -> 
             RGBColor[
              0.796630882955803, 0.841567450430349, 0.9624130715395429], 
             UndirectedEdge[268, 280] -> 
             RGBColor[
              0.9242314861804222, 0.7954505643870666, 0.6022036058910161], 
             UndirectedEdge[8, 186] -> 
             RGBColor[
              0.964354779452248, 0.9566519792023753, 0.6825744327102354], 
             UndirectedEdge[32, 256] -> 
             RGBColor[
              0.5796444059962738, 0.6451342260276997, 0.9258137546117968], 
             UndirectedEdge[60, 168] -> 
             RGBColor[
              0.9911434827228373, 0.9906056167508506, 0.7964389414219784], 
             UndirectedEdge[162, 216] -> 
             RGBColor[
              0.8992107114885975, 0.885180011085563, 0.6562175278356825], 
             UndirectedEdge[106, 115] -> 
             RGBColor[
              0.9247573576939359, 0.941593410361186, 0.9494503731760702], 
             UndirectedEdge[77, 276] -> 
             RGBColor[
              0.8082489005470346, 0.8283762420231504, 0.668271851242955], 
             UndirectedEdge[80, 281] -> 
             RGBColor[
              0.581634491249142, 0.6647692321444507, 0.9632424530956211], 
             UndirectedEdge[130, 293] -> 
             RGBColor[
              0.878632390487389, 0.5293989311749341, 0.44439532798343473`], 
             UndirectedEdge[39, 118] -> 
             RGBColor[
              0.9343735830920463, 0.7823304466336968, 0.5712616397580329], 
             UndirectedEdge[58, 245] -> 
             RGBColor[
              0.9353446296096275, 0.7813700320668076, 0.2668349752085506], 
             UndirectedEdge[54, 143] -> 
             RGBColor[
              0.9588745305012167, 0.947312385327123, 0.6807011431144727], 
             UndirectedEdge[239, 258] -> 
             RGBColor[
              0.9381602971011664, 0.9524384445864855, 0.9562030469767473], 
             UndirectedEdge[184, 222] -> 
             RGBColor[
              0.9367469081251274, 0.9509866176324051, 0.9433755208244128], 
             UndirectedEdge[143, 298] -> 
             RGBColor[
              0.9662306556752301, 0.971389213091757, 0.7719567926788002], 
             UndirectedEdge[203, 269] -> 
             RGBColor[
              0.8985779746251272, 0.6323480951360994, 0.2370833147569233], 
             UndirectedEdge[107, 139] -> 
             RGBColor[
              0.9880798938604334, 0.9886909113722532, 0.8148389317442356], 
             UndirectedEdge[108, 283] -> 
             RGBColor[
              0.9662510048384991, 0.973085924436432, 0.8853760938053006], 
             UndirectedEdge[173, 186] -> 
             RGBColor[
              0.9675517360744408, 0.9744592769417928, 0.9012335173644987], 
             UndirectedEdge[164, 296] -> 
             RGBColor[
              0.9541241504653928, 0.9326293976957438, 0.6650938418708758], 
             UndirectedEdge[11, 116] -> 
             RGBColor[
              0.8897952720652202, 0.5704983081439627, 0.43801454722988864`], 
             UndirectedEdge[43, 229] -> 
             RGBColor[
              0.9324729647060284, 0.7620147955882277, 0.5350529850600039], 
             UndirectedEdge[128, 149] -> 
             RGBColor[
              0.8683892696311791, 0.8972352451531823, 0.9461852983122725], 
             UndirectedEdge[221, 232] -> 
             RGBColor[
              0.8006124613168935, 0.841323335482473, 0.8187141806854992], 
             UndirectedEdge[8, 85] -> 
             RGBColor[
              0.9846638641388048, 0.9714408539296479, 0.6321820607322325], 
             UndirectedEdge[20, 41] -> 
             RGBColor[
              0.9440205509561801, 0.8109348161318553, 0.29898280170501645`], 
             UndirectedEdge[108, 252] -> 
             RGBColor[
              0.9327503825038228, 0.755122539530346, 0.5009028993208622], 
             UndirectedEdge[65, 241] -> 
             RGBColor[
              0.7528500777411825, 0.6946962257935274, 0.6068543170226608], 
             UndirectedEdge[231, 245] -> 
             RGBColor[
              0.9170799030404244, 0.8356349577052726, 0.6249116039473505], 
             UndirectedEdge[80, 167] -> 
             RGBColor[
              0.6379731091995036, 0.7135669113517815, 0.9668323000131344], 
             UndirectedEdge[17, 201] -> 
             RGBColor[
              0.9337357395441139, 0.9461045675457928, 0.8159296446018751], 
             UndirectedEdge[57, 223] -> 
             RGBColor[
              0.9654106278009069, 0.8942448736762415, 0.5317522650736806], 
             UndirectedEdge[162, 202] -> 
             RGBColor[
              0.9203855317736328, 0.7096634546992769, 0.2722887774786875], 
             UndirectedEdge[3, 59] -> 
             RGBColor[
              0.9892896163121256, 0.9742932078340552, 0.5183582983943784], 
             UndirectedEdge[180, 187] -> 
             RGBColor[
              0.8223007529454354, 0.8612026717695598, 0.9401806553073946], 
             UndirectedEdge[193, 215] -> 
             RGBColor[
              0.9598140090460436, 0.9695499342618361, 0.9529085798867145], 
             UndirectedEdge[43, 78] -> 
             RGBColor[
              0.8815901672831762, 0.47624679554209426`, 0.4002403450482267], 
             UndirectedEdge[56, 251] -> 
             RGBColor[
              0.9479506686360324, 0.9542043539668167, 0.7052363220856076], 
             UndirectedEdge[261, 284] -> 
             RGBColor[
              0.9786091481426118, 0.9798804140058729, 0.6922351496994992], 
             UndirectedEdge[36, 41] -> 
             RGBColor[
              0.5842118058470189, 0.5432760333855582, 0.5943798230240432], 
             UndirectedEdge[95, 168] -> 
             RGBColor[
              0.9718027496509517, 0.9165949700718592, 0.522251788709177], 
             UndirectedEdge[194, 280] -> 
             RGBColor[
              0.9256219333947875, 0.796487557642892, 0.5998499414438094], 
             UndirectedEdge[99, 182] -> 
             RGBColor[
              0.9781579594079066, 0.9819608549367105, 0.8649853188109147], 
             UndirectedEdge[94, 97] -> 
             RGBColor[
              0.9308596393521844, 0.9432723991986964, 0.7719748685181391], 
             UndirectedEdge[79, 240] -> 
             RGBColor[
              0.9751674654024813, 0.9784884470261983, 0.7912791033438071], 
             UndirectedEdge[83, 198] -> 
             RGBColor[
              0.9866964237701332, 0.9745798789752069, 0.6143844988829369], 
             UndirectedEdge[69, 213] -> 
             RGBColor[
              0.9589296075206366, 0.9688903490522621, 0.9544056409803685], 
             UndirectedEdge[214, 286] -> 
             RGBColor[
              0.9545989697397494, 0.8464036869750571, 0.36806708524285603`], 
             UndirectedEdge[277, 293] -> 
             RGBColor[
              0.9644360202168367, 0.972997022625165, 0.9450847205881412], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.8894494241198387, 0.7341916371261836, 0.6057197222196694], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.9764053204753489, 0.9819237071600329, 0.9248238173439569], 
             UndirectedEdge[43, 199] -> 
             RGBColor[
              0.9525897303941583, 0.963079851267215, 0.9214638914317681], 
             UndirectedEdge[192, 222] -> 
             RGBColor[
              0.8284405024065835, 0.86645667035033, 0.9833880133942887], 
             UndirectedEdge[130, 202] -> 
             RGBColor[
              0.851273192867379, 0.37965200010841604`, 0.1961271279245542], 
             UndirectedEdge[4, 265] -> 
             RGBColor[
              0.9712116504743121, 0.9780502765771137, 0.9336153459296312], 
             UndirectedEdge[121, 173] -> 
             RGBColor[
              0.9921058877220923, 0.9906176536483533, 0.7524354687918282], 
             UndirectedEdge[53, 107] -> 
             RGBColor[
              0.8775449961680772, 0.4613767330772587, 0.42057084648555604`], 
             UndirectedEdge[172, 238] -> 
             RGBColor[
              0.946795290621564, 0.8118885426847895, 0.47481801193603596`], 
             UndirectedEdge[210, 211] -> 
             RGBColor[
              0.8962395705579017, 0.5744238150862366, 0.3011921152430903], 
             UndirectedEdge[180, 221] -> 
             RGBColor[
              0.8281429139141936, 0.8633807814765972, 0.8210818151664072], 
             UndirectedEdge[196, 212] -> 
             RGBColor[
              0.7640876263142544, 0.8077327541423454, 0.6873945116940456], 
             UndirectedEdge[160, 176] -> 
             RGBColor[
              0.990743361971864, 0.9794066455667829, 0.5061819116223846], 
             UndirectedEdge[115, 193] -> 
             RGBColor[
              0.9622108078299867, 0.9713374628705029, 0.9488514247307385], 
             UndirectedEdge[21, 300] -> 
             RGBColor[
              0.9664385157645561, 0.8921124143573447, 0.45044500962584744`], 
             UndirectedEdge[75, 235] -> 
             RGBColor[
              0.9925637678245923, 0.9905886903857899, 0.7289784906636122], 
             UndirectedEdge[77, 255] -> 
             RGBColor[
              0.9696551527516162, 0.9550335362200768, 0.6617751435956163], 
             UndirectedEdge[62, 286] -> 
             RGBColor[
              0.897830566980763, 0.6255200182698011, 0.23628200809768116`], 
             UndirectedEdge[46, 225] -> 
             RGBColor[
              0.9837715210747493, 0.984204462937435, 0.7211032700169111], 
             UndirectedEdge[37, 161] -> 
             RGBColor[
              0.9298932722823663, 0.9467112782092254, 0.9853954295022128], 
             UndirectedEdge[3, 162] -> 
             RGBColor[
              0.9810664640651049, 0.9465545844168881, 0.4864129047267036], 
             UndirectedEdge[107, 274] -> 
             RGBColor[
              0.9197098803034324, 0.9376470741534872, 0.95168660621746], 
             UndirectedEdge[6, 147] -> 
             RGBColor[
              0.7399379832136085, 0.796764443314211, 0.9747137611192891], 
             UndirectedEdge[8, 135] -> 
             RGBColor[
              0.9611741362257428, 0.954279860691873, 0.6879584320480967], 
             UndirectedEdge[186, 249] -> 
             RGBColor[
              0.9151071183272939, 0.9348870154258884, 0.982799898255863], 
             UndirectedEdge[277, 281] -> 
             RGBColor[
              0.6474397845249423, 0.7162620985268173, 0.9355942192290713], 
             UndirectedEdge[256, 277] -> 
             RGBColor[
              0.5762853287686689, 0.6426290317313361, 0.9314997961704791], 
             UndirectedEdge[8, 249] -> 
             RGBColor[
              0.9337355736265647, 0.9324956326932098, 0.6886189752120986], 
             UndirectedEdge[114, 254] -> 
             RGBColor[
              0.9641158290683602, 0.8906058974921836, 0.3151519341708784], 
             UndirectedEdge[223, 270] -> 
             RGBColor[
              0.9392531713822307, 0.8759227079996638, 0.6291425261915837], 
             UndirectedEdge[120, 294] -> 
             RGBColor[
              0.9582593829370613, 0.9650265652692351, 0.7669970551262634], 
             UndirectedEdge[23, 290] -> 
             RGBColor[
              0.608679739409623, 0.6780468600634337, 0.941192733613057], 
             UndirectedEdge[7, 293] -> 
             RGBColor[
              0.959540401861297, 0.9693458784714427, 0.9533717254823081], 
             UndirectedEdge[95, 191] -> 
             RGBColor[
              0.9721341956803655, 0.9153492633812149, 0.4162462235965866], 
             UndirectedEdge[65, 194] -> 
             RGBColor[
              0.935905717169754, 0.8391591676052081, 0.6082227917132825], 
             UndirectedEdge[94, 188] -> 
             RGBColor[
              0.9315768680767924, 0.944806478917685, 0.8500407889690978], 
             UndirectedEdge[24, 162] -> 
             RGBColor[
              0.9448373491683879, 0.9215614534693413, 0.6605694372689612], 
             UndirectedEdge[34, 84] -> 
             RGBColor[
              0.9857894180871505, 0.9864833829135937, 0.779099157165067], 
             UndirectedEdge[130, 201] -> 
             RGBColor[
              0.8917271477283605, 0.5375794199201569, 0.3388765460898983], 
             UndirectedEdge[74, 260] -> 
             RGBColor[
              0.9738104281305957, 0.9784917140849366, 0.8621898174998481], 
             UndirectedEdge[69, 85] -> 
             RGBColor[
              0.9740947215381786, 0.9798428588770622, 0.9127206695825887], 
             UndirectedEdge[220, 262] -> 
             RGBColor[
              0.9853685617292045, 0.988083608569414, 0.8861466708711134], 
             UndirectedEdge[26, 262] -> 
             RGBColor[
              0.9890906542578846, 0.9892030521915538, 0.7939514950563196], 
             UndirectedEdge[217, 270] -> 
             RGBColor[
              0.9504501709187827, 0.9185640262474716, 0.6472714124640976], 
             UndirectedEdge[221, 245] -> 
             RGBColor[
              0.959979878974793, 0.8661392462912831, 0.4669550099346509], 
             UndirectedEdge[3, 24] -> 
             RGBColor[
              0.9582835397225332, 0.9656783170757792, 0.8182710356969727], 
             UndirectedEdge[59, 197] -> 
             RGBColor[
              0.7390783033197066, 0.7790392686245791, 0.6729589085405023], 
             UndirectedEdge[54, 235] -> 
             RGBColor[
              0.986783331402558, 0.9657963873815125, 0.5122385497561491], 
             UndirectedEdge[159, 282] -> 
             RGBColor[
              0.9788431381179115, 0.9560506027708685, 0.6338350054618191], 
             UndirectedEdge[6, 53] -> 
             RGBColor[
              0.7964588232265842, 0.3979429738878482, 0.43973075766318503`], 
             UndirectedEdge[31, 210] -> 
             RGBColor[
              0.9690659141950239, 0.9732580442263112, 0.7476621933024388], 
             UndirectedEdge[137, 273] -> 
             RGBColor[
              0.9943679486027975, 0.9905318155547921, 0.6407125612410516], 
             UndirectedEdge[99, 259] -> 
             RGBColor[
              0.9796184785923769, 0.9821120506469241, 0.807869390867549], 
             UndirectedEdge[16, 151] -> 
             RGBColor[
              0.9232562083727671, 0.7252554042091235, 0.2680038373628273], 
             UndirectedEdge[24, 227] -> 
             RGBColor[
              0.9577234634415914, 0.9644803705432432, 0.7573101889066101], 
             UndirectedEdge[87, 202] -> 
             RGBColor[
              0.9328023320960335, 0.7540183429359959, 0.495294306426398], 
             UndirectedEdge[17, 94] -> 
             RGBColor[
              0.8704843893302463, 0.8995646396553876, 0.9875087722165486], 
             UndirectedEdge[5, 92] -> 
             RGBColor[
              0.8760032556032216, 0.4188284014533581, 0.282790635274909], 
             UndirectedEdge[72, 290] -> 
             RGBColor[
              0.9772170661015656, 0.9816038326943731, 0.882014127251634], 
             UndirectedEdge[103, 212] -> 
             RGBColor[
              0.7209913602025645, 0.6471183228294942, 0.599346992204683], 
             UndirectedEdge[112, 133] -> 
             RGBColor[
              0.3084351808900966, 0.4295701305628945, 0.9413136708239463], 
             UndirectedEdge[71, 244] -> 
             RGBColor[
              0.988001209593997, 0.989306206059339, 0.8485145391090442], 
             UndirectedEdge[142, 197] -> 
             RGBColor[
              0.7433906326864541, 0.7957046112080817, 0.8620521876852387], 
             UndirectedEdge[117, 196] -> 
             RGBColor[
              0.9677086242400679, 0.9691826042297718, 0.6981876243238702], 
             UndirectedEdge[131, 188] -> 
             RGBColor[
              0.9669766456273126, 0.9729530891651252, 0.8506362693362948], 
             UndirectedEdge[13, 282] -> 
             RGBColor[
              0.989308630602016, 0.989669281550862, 0.8176768749209651], 
             UndirectedEdge[139, 143] -> 
             RGBColor[
              0.9669531966556081, 0.9729346551886862, 0.8506009193868911], 
             UndirectedEdge[45, 89] -> 
             RGBColor[
              0.9765087360663822, 0.9315988996606301, 0.4331121005169907], 
             UndirectedEdge[127, 269] -> 
             RGBColor[
              0.9049462587802182, 0.782477774577953, 0.6142912221529717], 
             UndirectedEdge[25, 79] -> 
             RGBColor[
              0.9786527450874556, 0.9385310331856411, 0.46696055785925644`], 
             UndirectedEdge[29, 78] -> 
             RGBColor[
              0.8527749534069802, 0.36156532804726205`, 0.19640498443950832`],
              UndirectedEdge[150, 179] -> 
             RGBColor[
              0.9828068546416312, 0.9838374532871672, 0.7507005668652438], 
             UndirectedEdge[11, 198] -> 
             RGBColor[
              0.9795436408695783, 0.9700202737086268, 0.6611951764958598], 
             UndirectedEdge[135, 286] -> 
             RGBColor[
              0.9277572673419776, 0.8297834262594812, 0.619456737680006], 
             UndirectedEdge[101, 104] -> 
             RGBColor[
              0.9941047472614211, 0.9916267545618513, 0.732576552385459], 
             UndirectedEdge[3, 290] -> 
             RGBColor[
              0.9795927134620908, 0.9819225199840731, 0.794399232106273], 
             UndirectedEdge[158, 212] -> 
             RGBColor[
              0.7465319633823434, 0.8008948905900075, 0.958469101072331], 
             UndirectedEdge[102, 175] -> 
             RGBColor[
              0.9772319929001295, 0.9825402381008823, 0.9234244765595028], 
             UndirectedEdge[103, 255] -> 
             RGBColor[
              0.9324965319806057, 0.8144481768667622, 0.5967942550245564], 
             UndirectedEdge[3, 65] -> 
             RGBColor[
              0.9563558585478644, 0.8520325099143748, 0.44857687629487386`], 
             UndirectedEdge[148, 270] -> 
             RGBColor[
              0.9638667463452436, 0.963821285522642, 0.6993922744882235], 
             UndirectedEdge[49, 298] -> 
             RGBColor[
              0.9285913759883534, 0.9414557102753908, 0.771106990971433], 
             UndirectedEdge[15, 103] -> 
             RGBColor[
              0.9019061122374593, 0.7906975108611773, 0.6161109376266178], 
             UndirectedEdge[4, 15] -> 
             RGBColor[
              0.9353455790098393, 0.9503650381558504, 0.9618623307855603], 
             UndirectedEdge[83, 290] -> 
             RGBColor[
              0.9767645927809967, 0.981416723348284, 0.889512781136877], 
             UndirectedEdge[182, 284] -> 
             RGBColor[
              0.9782102032100051, 0.981999818278774, 0.864896883681328], 
             UndirectedEdge[32, 92] -> 
             RGBColor[
              0.8716666039975158, 0.4177094840184665, 0.41552083640786464`], 
             UndirectedEdge[87, 203] -> 
             RGBColor[
              0.9454510156153889, 0.811453060622298, 0.5058486780025526], 
             UndirectedEdge[115, 169] -> 
             RGBColor[
              0.9862179913717979, 0.988546380105676, 0.8770630936850197], 
             UndirectedEdge[111, 143] -> 
             RGBColor[
              0.9657443978684019, 0.9703491568111571, 0.7190306312408814], 
             UndirectedEdge[163, 274] -> 
             RGBColor[
              0.8265142529370527, 0.8647090048272047, 0.9832604716988361], 
             UndirectedEdge[96, 260] -> 
             RGBColor[
              0.9530104744607483, 0.9644758693078883, 0.9644251892936097], 
             UndirectedEdge[27, 227] -> 
             RGBColor[
              0.9919016947147692, 0.9892891123523813, 0.6653863759262459], 
             UndirectedEdge[103, 205] -> 
             RGBColor[
              0.922877959835, 0.7319438406818434, 0.25680400007753557`], 
             UndirectedEdge[27, 216] -> 
             RGBColor[
              0.9106060184192035, 0.9291124855535922, 0.8961518458255876], 
             UndirectedEdge[145, 293] -> 
             RGBColor[
              0.9744232937744098, 0.9788794798269349, 0.8580486217539994], 
             UndirectedEdge[96, 133] -> 
             RGBColor[
              0.6947722404591865, 0.7585855177708567, 0.9579686009419361], 
             UndirectedEdge[127, 159] -> 
             RGBColor[
              0.9427425732159522, 0.9284947049330838, 0.6730266123190717], 
             UndirectedEdge[186, 214] -> 
             RGBColor[
              0.9693873833242438, 0.9732915041401276, 0.7307497026547112], 
             UndirectedEdge[111, 262] -> 
             RGBColor[
              0.9880553408914081, 0.9869886215868988, 0.6812640243288222], 
             UndirectedEdge[33, 157] -> 
             RGBColor[
              0.9929322481626096, 0.9872911184161753, 0.47209701348746], 
             UndirectedEdge[112, 131] -> 
             RGBColor[
              0.5588682546462778, 0.6296394063686981, 0.9609823595592281], 
             UndirectedEdge[37, 55] -> 
             RGBColor[
              0.9543339113521211, 0.9634288962235253, 0.8763952783940474], 
             UndirectedEdge[20, 71] -> 
             RGBColor[
              0.9801834610406756, 0.9537846690397194, 0.5972012636929722], 
             UndirectedEdge[37, 252] -> 
             RGBColor[
              0.8945410762085726, 0.7273669926401793, 0.6040564663903268], 
             UndirectedEdge[120, 178] -> 
             RGBColor[
              0.858787580458406, 0.8904428801565936, 0.9863387304885624], 
             UndirectedEdge[113, 231] -> 
             RGBColor[
              0.9162295819699324, 0.832263718013471, 0.6242274156544318], 
             UndirectedEdge[7, 181] -> 
             RGBColor[
              0.962722585663023, 0.9717191459404222, 0.9479851183524444], 
             UndirectedEdge[42, 299] -> 
             RGBColor[
              0.9533188197252809, 0.9647058327013076, 0.9639032411900809], 
             UndirectedEdge[64, 234] -> 
             RGBColor[
              0.6936835773196608, 0.7592587557361823, 0.97114532096949], 
             UndirectedEdge[78, 261] -> 
             RGBColor[
              0.8831834484303479, 0.4753827394052734, 0.2631354304853949], 
             UndirectedEdge[10, 100] -> 
             RGBColor[
              0.9902849362034287, 0.9881282078618331, 0.6563928151161021], 
             UndirectedEdge[6, 88] -> 
             RGBColor[
              0.7122118502488461, 0.7751045775157235, 0.9719502793008055], 
             UndirectedEdge[36, 208] -> 
             RGBColor[
              0.6114152330541586, 0.6800869867445685, 0.9365622564038651], 
             UndirectedEdge[92, 142] -> 
             RGBColor[
              0.8757764122461654, 0.4198332176039298, 0.3664082173078382], 
             UndirectedEdge[237, 293] -> 
             RGBColor[
              0.9664383086334871, 0.9744903260478563, 0.9416953685792087], 
             UndirectedEdge[127, 145] -> 
             RGBColor[
              0.9524014650188415, 0.9618234803553138, 0.8734086006378818], 
             UndirectedEdge[90, 285] -> 
             RGBColor[
              0.9568017724876219, 0.8594247049753247, 0.5214541757743092], 
             UndirectedEdge[134, 176] -> 
             RGBColor[
              0.9909937410074534, 0.9895869916024116, 0.7293783331979676], 
             UndirectedEdge[28, 297] -> 
             RGBColor[
              0.9941675812229189, 0.9917149063895025, 0.736054215237063], 
             UndirectedEdge[20, 136] -> 
             RGBColor[
              0.9805366420452716, 0.9539307184614576, 0.5913481404436751], 
             UndirectedEdge[113, 134] -> 
             RGBColor[
              0.9556373459258092, 0.8617406622722575, 0.5544409596868787], 
             UndirectedEdge[12, 181] -> 
             RGBColor[
              0.640597181571073, 0.7110605513887357, 0.9457416723069632], 
             UndirectedEdge[84, 217] -> 
             RGBColor[
              0.978155008154258, 0.9367872796149105, 0.4705345189164969], 
             UndirectedEdge[126, 153] -> 
             RGBColor[
              0.975056433869774, 0.9634335964006617, 0.6619126738990245], 
             UndirectedEdge[217, 251] -> 
             RGBColor[
              0.9333738671831311, 0.9050333798704367, 0.6486082010390611], 
             UndirectedEdge[211, 266] -> 
             RGBColor[
              0.896375189418708, 0.5747138901163312, 0.3159533912992685], 
             UndirectedEdge[156, 282] -> 
             RGBColor[
              0.9573627333813984, 0.8763106243337013, 0.5883100182877774], 
             UndirectedEdge[92, 256] -> 
             RGBColor[0.6045216666666666, 0.191216, 0.4206456666666667], 
             UndirectedEdge[56, 246] -> 
             RGBColor[
              0.9789239698034966, 0.9405677426392824, 0.37262403187126814`], 
             UndirectedEdge[223, 246] -> 
             RGBColor[
              0.9531501688140434, 0.8487554502950947, 0.2978670245522077], 
             UndirectedEdge[66, 228] -> 
             RGBColor[
              0.9254916381018412, 0.9428773231834665, 0.9737349846162344], 
             UndirectedEdge[170, 261] -> 
             RGBColor[
              0.9937570198205086, 0.9894020032506261, 0.5870756840842255], 
             UndirectedEdge[104, 287] -> 
             RGBColor[
              0.9752702500164658, 0.9265347038887211, 0.4926177692509229], 
             UndirectedEdge[255, 258] -> 
             RGBColor[
              0.9692510749023626, 0.9765880825257016, 0.9369340889729375], 
             UndirectedEdge[27, 162] -> 
             RGBColor[
              0.9790155804415656, 0.9463701952784793, 0.5686456242885972], 
             UndirectedEdge[162, 169] -> 
             RGBColor[
              0.9779996010030416, 0.9459500616711691, 0.5854830328554417], 
             UndirectedEdge[90, 166] -> 
             RGBColor[
              0.9527742224373361, 0.8422810041403574, 0.3235209945853614], 
             UndirectedEdge[74, 257] -> 
             RGBColor[
              0.939272151531422, 0.9514345884942874, 0.8756330713980229], 
             UndirectedEdge[82, 203] -> 
             RGBColor[
              0.8707296824049529, 0.7547084471758028, 0.6109316737206884], 
             UndirectedEdge[1, 142] -> 
             RGBColor[
              0.9816943049474272, 0.952031576631762, 0.5557269546415353], 
             UndirectedEdge[82, 145] -> 
             RGBColor[
              0.9183147061936863, 0.9346436241285547, 0.8701573751515297], 
             UndirectedEdge[77, 203] -> 
             RGBColor[
              0.9385952059149085, 0.785856699536007, 0.30444654751604056`], 
             UndirectedEdge[12, 27] -> 
             RGBColor[
              0.6550062500072649, 0.7207736278991816, 0.875082826158416], 
             UndirectedEdge[54, 185] -> 
             RGBColor[
              0.9653435743690472, 0.8934978510425875, 0.3264290123318543], 
             UndirectedEdge[35, 165] -> 
             RGBColor[
              0.919176599433657, 0.7172691800957552, 0.25382579861651994`], 
             UndirectedEdge[60, 95] -> 
             RGBColor[
              0.9699299871095974, 0.9158205346332071, 0.5532883105735148], 
             UndirectedEdge[47, 112] -> 
             RGBColor[
              0.5860542083722364, 0.6466090324089866, 0.7163592379665236], 
             UndirectedEdge[24, 59] -> 
             RGBColor[
              0.9530605014154085, 0.9493000768865082, 0.692514830936636], 
             UndirectedEdge[239, 285] -> 
             RGBColor[
              0.9450526743265938, 0.9563282844034664, 0.8885368292459308], 
             UndirectedEdge[173, 286] -> 
             RGBColor[
              0.9527633224899463, 0.8475714597767223, 0.5385508999526437], 
             UndirectedEdge[17, 40] -> 
             RGBColor[
              0.9167075905264217, 0.9357833415360277, 0.9697830195526431], 
             UndirectedEdge[226, 241] -> 
             RGBColor[
              0.7561583578940543, 0.7078124541806554, 0.6095162368889772], 
             UndirectedEdge[255, 286] -> 
             RGBColor[
              0.9383587738662105, 0.8376900124668802, 0.6015111524502166], 
             UndirectedEdge[95, 271] -> 
             RGBColor[
              0.9277193938646846, 0.7511385132972911, 0.26069953154088243`], 
             UndirectedEdge[189, 260] -> 
             RGBColor[
              0.9084466063315548, 0.9293519223823128, 0.9743920968105171], 
             UndirectedEdge[193, 245] -> 
             RGBColor[
              0.9327627161595128, 0.8480196952054628, 0.6222361527084638], 
             UndirectedEdge[84, 223] -> 
             RGBColor[
              0.9669580086177063, 0.8941459613671027, 0.4524056326439829], 
             UndirectedEdge[44, 61] -> 
             RGBColor[
              0.9930443029115205, 0.9875307921936227, 0.48429348138466055`], 
             UndirectedEdge[262, 292] -> 
             RGBColor[
              0.9762156521341525, 0.9817822528217219, 0.9251448763721766], 
             UndirectedEdge[153, 248] -> 
             RGBColor[
              0.987904997791115, 0.9714297747297137, 0.5691274605522065], 
             UndirectedEdge[78, 99] -> 
             RGBColor[
              0.8737987057476447, 0.4708415498252646, 0.43159346008370525`], 
             UndirectedEdge[199, 261] -> 
             RGBColor[
              0.9549796521149159, 0.9617837670619838, 0.7158065195875205], 
             UndirectedEdge[58, 215] -> 
             RGBColor[
              0.9623959224961585, 0.9029002711231809, 0.5975074023868014], 
             UndirectedEdge[23, 197] -> 
             RGBColor[
              0.37338836757436344`, 0.4915418488932108, 0.9455086148076229], 
             UndirectedEdge[196, 214] -> 
             RGBColor[
              0.9918329939658346, 0.9837762826877902, 0.4513977073065585], 
             UndirectedEdge[88, 289] -> 
             RGBColor[
              0.8406259890366146, 0.8729888990674064, 0.8108119223497576], 
             UndirectedEdge[47, 96] -> 
             RGBColor[
              0.9723912679413265, 0.9756244196169488, 0.7330141680845134], 
             UndirectedEdge[179, 205] -> 
             RGBColor[
              0.9565620919275816, 0.8917938389717202, 0.6021412386683122], 
             UndirectedEdge[72, 194] -> 
             RGBColor[
              0.9716868658806144, 0.9774794184244596, 0.8913753137184847], 
             UndirectedEdge[140, 299] -> 
             RGBColor[
              0.7388674709142276, 0.7949324070391455, 0.9648365109094001], 
             UndirectedEdge[134, 297] -> 
             RGBColor[
              0.9905156807393505, 0.9903460044969037, 0.8068432449878074], 
             UndirectedEdge[67, 195] -> 
             RGBColor[
              0.9863543514632435, 0.9656321647141889, 0.40148966150954757`], 
             UndirectedEdge[24, 155] -> 
             RGBColor[
              0.9560123628735075, 0.9654028310273541, 0.9041545841057685], 
             UndirectedEdge[156, 277] -> 
             RGBColor[
              0.9524916345555086, 0.8726777668050449, 0.5965555180139646], 
             UndirectedEdge[267, 272] -> 
             RGBColor[
              0.9473026223456966, 0.9047233425682571, 0.6332042680389816], 
             UndirectedEdge[71, 177] -> 
             RGBColor[
              0.9642624517171106, 0.8954955254282654, 0.55922386934613], 
             UndirectedEdge[188, 281] -> 
             RGBColor[
              0.6581898467373083, 0.7223407495919084, 0.8272493328356589], 
             UndirectedEdge[1, 150] -> 
             RGBColor[
              0.9822589025208392, 0.9510041770208194, 0.4547177939147604], 
             UndirectedEdge[84, 246] -> 
             RGBColor[
              0.9806177726636021, 0.9450947625895334, 0.4801018939812447], 
             UndirectedEdge[58, 230] -> 
             RGBColor[
              0.9690366330220154, 0.9041039070095663, 0.3524815996126079], 
             UndirectedEdge[74, 189] -> 
             RGBColor[
              0.9278372046788339, 0.9423166722673972, 0.8745423959591256], 
             UndirectedEdge[48, 71] -> 
             RGBColor[
              0.9912513630913643, 0.9899238466639646, 0.741850825427369], 
             UndirectedEdge[80, 205] -> 
             RGBColor[
              0.8916819887214791, 0.8409909778284745, 0.6282233670750796], 
             UndirectedEdge[1, 32] -> 
             RGBColor[
              0.9755295925744528, 0.9488459762535669, 0.6293958832915749], 
             UndirectedEdge[229, 233] -> 
             RGBColor[
              0.6299135298956702, 0.5203560025872205, 0.5823816095537916], 
             UndirectedEdge[54, 172] -> 
             RGBColor[
              0.9870637580137198, 0.9663961915473077, 0.5427612557886615], 
             UndirectedEdge[61, 194] -> 
             RGBColor[
              0.9734634143901202, 0.9765166938500143, 0.7385522058491851], 
             UndirectedEdge[177, 194] -> 
             RGBColor[
              0.9470372749742682, 0.8832920849283632, 0.6171795044140387], 
             UndirectedEdge[7, 42] -> 
             RGBColor[
              0.9614269658277144, 0.9707528747886317, 0.9501782647818497], 
             UndirectedEdge[26, 75] -> 
             RGBColor[
              0.9926707090150244, 0.990817426778711, 0.7406183792776122], 
             UndirectedEdge[170, 190] -> 
             RGBColor[
              0.9840968710370694, 0.9568969134305081, 0.542672050813583], 
             UndirectedEdge[20, 36] -> 
             RGBColor[
              0.612495451623476, 0.6505789109283444, 0.6423044848492562], 
             UndirectedEdge[119, 161] -> 
             RGBColor[
              0.9305344267459543, 0.8326894195364476, 0.6154034057735789], 
             UndirectedEdge[212, 225] -> 
             RGBColor[
              0.7654360820547806, 0.8117806067746737, 0.7352178680186174], 
             UndirectedEdge[102, 253] -> 
             RGBColor[
              0.9641971284814862, 0.9238114111591993, 0.6133765752235005], 
             UndirectedEdge[91, 179] -> 
             RGBColor[
              0.9830548344780276, 0.9843678570826117, 0.7776916417028349], 
             UndirectedEdge[118, 239] -> 
             RGBColor[
              0.8925585995177666, 0.7501827135881902, 0.6086838808148468], 
             UndirectedEdge[105, 298] -> 
             RGBColor[
              0.688216323754846, 0.7474276973286413, 0.7504906558762947], 
             UndirectedEdge[90, 239] -> 
             RGBColor[
              0.9101355933070681, 0.8249094420222738, 0.6230874465061413], 
             UndirectedEdge[208, 252] -> 
             RGBColor[
              0.9219200185573435, 0.7483099825799591, 0.5758722117131088], 
             UndirectedEdge[117, 214] -> 
             RGBColor[
              0.9689240727697438, 0.972945967887183, 0.7315339665727341], 
             UndirectedEdge[179, 282] -> 
             RGBColor[
              0.9775895662935298, 0.9828069157522075, 0.9228191980745533], 
             UndirectedEdge[44, 268] -> 
             RGBColor[
              0.9718028131700642, 0.9749018684927762, 0.7115012739742144], 
             UndirectedEdge[53, 124] -> 
             RGBColor[
              0.8746859622362309, 0.4592444702521261, 0.4254104451766978], 
             UndirectedEdge[42, 81] -> 
             RGBColor[
              0.9669779468955678, 0.9748927873801395, 0.9407819017617062], 
             UndirectedEdge[173, 213] -> 
             RGBColor[
              0.9726957067434556, 0.9782956418442653, 0.8925261167842755], 
             UndirectedEdge[119, 122] -> 
             RGBColor[
              0.9419248699126173, 0.8041409858587889, 0.2894072200781439], 
             UndirectedEdge[68, 111] -> 
             RGBColor[
              0.6227057665540068, 0.6848837964179301, 0.6936109809686717], 
             UndirectedEdge[34, 53] -> 
             RGBColor[
              0.8762569495528373, 0.46041611002059557`, 0.422751173428797], 
             UndirectedEdge[85, 263] -> 
             RGBColor[
              0.9573263572104816, 0.8710470638233043, 0.5685719636944561], 
             UndirectedEdge[37, 208] -> 
             RGBColor[
              0.9427648172452314, 0.9563108553673096, 0.9636072613166654], 
             UndirectedEdge[256, 293] -> 
             RGBColor[
              0.5670776914481679, 0.6357619908938288, 0.9470859244176622], 
             UndirectedEdge[76, 153] -> 
             RGBColor[
              0.98757323817185, 0.9693898593240236, 0.43631760722934576`], 
             UndirectedEdge[135, 213] -> 
             RGBColor[
              0.9476896515954869, 0.9605076083270241, 0.9734319545116379], 
             UndirectedEdge[36, 55] -> 
             RGBColor[
              0.6229843271610482, 0.6872050276007842, 0.8493502734812473], 
             UndirectedEdge[121, 135] -> 
             RGBColor[
              0.9670998325741235, 0.9728296201311122, 0.8333413065191905], 
             UndirectedEdge[83, 226] -> 
             RGBColor[
              0.956836018019642, 0.8646429416657138, 0.5463523451917944], 
             UndirectedEdge[60, 127] -> 
             RGBColor[
              0.950227722783341, 0.960924582078307, 0.9094331349447026], 
             UndirectedEdge[247, 271] -> 
             RGBColor[
              0.9496236740166888, 0.8254464774610943, 0.43695637643932794`], 
             UndirectedEdge[202, 269] -> 
             RGBColor[
              0.8859292911057717, 0.5749133774497972, 0.22652894318076866`], 
             UndirectedEdge[190, 284] -> 
             RGBColor[
              0.9689489993591727, 0.9473753241857548, 0.6478315164288568], 
             UndirectedEdge[53, 217] -> 
             RGBColor[
              0.871167342930909, 0.4272853744881401, 0.21704141459641688`], 
             UndirectedEdge[42, 87] -> 
             RGBColor[
              0.9757276924924656, 0.980045735852962, 0.8645031458142604], 
             UndirectedEdge[205, 225] -> 
             RGBColor[
              0.9673226816872161, 0.8966061246270228, 0.3926748758914699], 
             UndirectedEdge[110, 246] -> 
             RGBColor[
              0.9631906784671399, 0.9345366331523308, 0.6394412494284918], 
             UndirectedEdge[191, 251] -> 
             RGBColor[
              0.949271233924015, 0.957933056490404, 0.7720895778253041], 
             UndirectedEdge[23, 83] -> 
             RGBColor[
              0.6207715598856883, 0.6862899914668978, 0.8860215536921031], 
             UndirectedEdge[226, 291] -> 
             RGBColor[
              0.9419494601413385, 0.8066332623647039, 0.2769549278690966], 
             UndirectedEdge[60, 276] -> 
             RGBColor[
              0.8135131332603761, 0.8533144451235966, 0.8960505312755684], 
             UndirectedEdge[27, 155] -> 
             RGBColor[
              0.9901905941466851, 0.9902115728364922, 0.8122307711254046], 
             UndirectedEdge[167, 203] -> 
             RGBColor[
              0.6661806522441435, 0.5910070579831661, 0.5929222658816016], 
             UndirectedEdge[137, 271] -> 
             RGBColor[
              0.949967307526971, 0.8263513538615465, 0.4867071783285465], 
             UndirectedEdge[52, 247] -> 
             RGBColor[
              0.9897051064676898, 0.9892480360917915, 0.7648308599185806], 
             UndirectedEdge[81, 299] -> 
             RGBColor[
              0.9612952557916783, 0.9706546456594114, 0.9504012155173795], 
             UndirectedEdge[31, 290] -> 
             RGBColor[
              0.954729998445708, 0.9657582874804091, 0.9615144837107541], 
             UndirectedEdge[79, 288] -> 
             RGBColor[
              0.9795863188448649, 0.941680196682925, 0.47058731561618045`], 
             UndirectedEdge[237, 281] -> 
             RGBColor[
              0.6494420729415927, 0.7177554019495088, 0.9322048672201388], 
             UndirectedEdge[43, 215] -> 
             RGBColor[
              0.9835588158018195, 0.9866503519532075, 0.8854685111949578], 
             UndirectedEdge[56, 295] -> 
             RGBColor[
              0.9890870629525347, 0.985189851346645, 0.6412680521343042], 
             UndirectedEdge[89, 94] -> 
             RGBColor[
              0.9135965171860619, 0.8857843394012452, 0.6416035809123047], 
             UndirectedEdge[92, 237] -> 
             RGBColor[
              0.8707620781235462, 0.417034890102685, 0.4170519627743644], 
             UndirectedEdge[126, 285] -> 
             RGBColor[
              0.9798808324620034, 0.9832652544765403, 0.862941461201203], 
             UndirectedEdge[4, 214] -> 
             RGBColor[
              0.9821761946265247, 0.9828293786696121, 0.7091015809761383], 
             UndirectedEdge[220, 222] -> 
             RGBColor[
              0.9379007089231532, 0.9514637439137167, 0.924254055660376], 
             UndirectedEdge[199, 209] -> 
             RGBColor[
              0.8164180508275665, 0.8572980267797914, 0.9821277940493847], 
             UndirectedEdge[290, 291] -> 
             RGBColor[
              0.9618780349026932, 0.9234070440472741, 0.6201153638141792], 
             UndirectedEdge[91, 150] -> 
             RGBColor[
              0.9940684117217167, 0.9897212573853487, 0.595761405307556], 
             UndirectedEdge[60, 148] -> 
             RGBColor[
              0.988994137437828, 0.9817174927154095, 0.6190728615472709], 
             UndirectedEdge[81, 140] -> 
             RGBColor[
              0.7525265980845146, 0.8051193617179775, 0.9417151714810255], 
             UndirectedEdge[142, 256] -> 
             RGBColor[
              0.5858091183692481, 0.6483198264058947, 0.8521448259617572], 
             UndirectedEdge[30, 123] -> 
             RGBColor[
              0.9714506151817618, 0.9782284960646609, 0.9332108410118964], 
             UndirectedEdge[53, 289] -> 
             RGBColor[
              0.8820682490850965, 0.4631991882556368, 0.3323051863624864], 
             UndirectedEdge[274, 289] -> 
             RGBColor[
              0.9264947596789614, 0.9403807569210545, 0.8192881160328557], 
             UndirectedEdge[11, 114] -> 
             RGBColor[
              0.9652391544300177, 0.9217573727641566, 0.6056796806266482], 
             UndirectedEdge[137, 247] -> 
             RGBColor[
              0.9947414478520025, 0.9913306926822745, 0.681365649546823], 
             UndirectedEdge[84, 191] -> 
             RGBColor[
              0.9940523748951422, 0.9896869562348777, 0.5940158957027398], 
             UndirectedEdge[17, 120] -> 
             RGBColor[
              0.8979539382828965, 0.9214681123491881, 0.9901288423180082], 
             UndirectedEdge[126, 222] -> 
             RGBColor[
              0.9282464804969371, 0.9447885054025766, 0.9641008631777082], 
             UndirectedEdge[184, 224] -> 
             RGBColor[
              0.9834813712314785, 0.9870595214508814, 0.9065095734980747], 
             UndirectedEdge[278, 295] -> 
             RGBColor[
              0.9858809850226948, 0.9743749976663989, 0.6288130447938911], 
             UndirectedEdge[28, 245] -> 
             RGBColor[
              0.9601395674798698, 0.8664808038566582, 0.484336118229053], 
             UndirectedEdge[14, 186] -> 
             RGBColor[
              0.9499240099356839, 0.9621739891187171, 0.9696497686556709], 
             UndirectedEdge[227, 241] -> 
             RGBColor[
              0.7904467975316265, 0.8321372173699428, 0.7414310970921392], 
             UndirectedEdge[121, 154] -> 
             RGBColor[
              0.9712451668823743, 0.9107697320672442, 0.4779500075568222], 
             UndirectedEdge[187, 230] -> 
             RGBColor[
              0.9878297214184226, 0.9866950115270043, 0.6717004744796956], 
             UndirectedEdge[125, 277] -> 
             RGBColor[
              0.8977926589322297, 0.631002238075757, 0.4463542386708617], 
             UndirectedEdge[62, 158] -> 
             RGBColor[
              0.9175089282749371, 0.7560547504301963, 0.5906872195396689], 
             UndirectedEdge[20, 61] -> 
             RGBColor[
              0.9828093268249243, 0.9531731589848385, 0.4303027706185337], 
             UndirectedEdge[64, 258] -> 
             RGBColor[
              0.7572594535165853, 0.8088633067825683, 0.9394485310580196], 
             UndirectedEdge[94, 294] -> 
             RGBColor[
              0.9307898339844112, 0.9431230925754346, 0.7643769850248038], 
             UndirectedEdge[125, 237] -> 
             RGBColor[
              0.8991275178766632, 0.6319977736908846, 0.4440946706649067], 
             UndirectedEdge[267, 300] -> 
             RGBColor[
              0.974026146874716, 0.9221948432809481, 0.456550195721675], 
             UndirectedEdge[165, 175] -> 
             RGBColor[
              0.9517812546774005, 0.8529612871356494, 0.5828719992207623], 
             UndirectedEdge[67, 263] -> 
             RGBColor[
              0.9580290195953158, 0.8619062091342342, 0.3340420511164953], 
             UndirectedEdge[163, 298] -> 
             RGBColor[
              0.8941617255136758, 0.9142073999490412, 0.7677686705175208], 
             UndirectedEdge[92, 149] -> 
             RGBColor[
              0.8720593938063864, 0.41800242601478776`, 0.4148559457174362], 
             UndirectedEdge[95, 276] -> 
             RGBColor[
              0.7941724001884906, 0.7793037984446053, 0.6218633785627672], 
             UndirectedEdge[70, 231] -> 
             RGBColor[
              0.7376893908120181, 0.7945633966939942, 0.9750944833465962], 
             UndirectedEdge[239, 263] -> 
             RGBColor[
              0.9133473580204563, 0.8376430188537125, 0.6256717077843406], 
             UndirectedEdge[116, 204] -> 
             RGBColor[
              0.8608329051610218, 0.4379144718736554, 0.20468563357602163`], 
             UndirectedEdge[121, 258] -> 
             RGBColor[
              0.9863843632522865, 0.9872119915353652, 0.8006976262921951], 
             UndirectedEdge[95, 148] -> 
             RGBColor[
              0.9696534043659425, 0.9077068460364182, 0.34488570883446956`], 
             UndirectedEdge[60, 77] -> 
             RGBColor[
              0.9840064874681415, 0.9648929782117524, 0.5996967832537026], 
             UndirectedEdge[42, 269] -> 
             RGBColor[
              0.9288546515022038, 0.800940770366763, 0.595737782568631], 
             UndirectedEdge[61, 136] -> 
             RGBColor[
              0.9910417721375586, 0.9888661837716547, 0.6747434475319796], 
             UndirectedEdge[95, 251] -> 
             RGBColor[
              0.9277262922813614, 0.8843936810634049, 0.6349445120894309], 
             UndirectedEdge[158, 265] -> 
             RGBColor[
              0.9633127868817111, 0.9721593170429539, 0.9469860616383368], 
             UndirectedEdge[152, 208] -> 
             RGBColor[
              0.979286030319618, 0.9833683323286322, 0.8884297675621274], 
             UndirectedEdge[153, 285] -> 
             RGBColor[
              0.9868944549149181, 0.971011889280639, 0.5858747712119203], 
             UndirectedEdge[61, 279] -> 
             RGBColor[
              0.9706106479383806, 0.9743891053012832, 0.743381195331327], 
             UndirectedEdge[82, 168] -> 
             RGBColor[0.91801372649954, 0.9345191612902, 0.8751453875940126], 
             UndirectedEdge[4, 249] -> 
             RGBColor[
              0.9278959296295748, 0.9444248899553729, 0.9611517765772901], 
             UndirectedEdge[75, 163] -> 
             RGBColor[
              0.8925860367616967, 0.9149228751886846, 0.8932529618606564], 
             UndirectedEdge[59, 290] -> 
             RGBColor[
              0.9743696751549662, 0.965544279794802, 0.6686430273459363], 
             UndirectedEdge[205, 251] -> 
             RGBColor[
              0.923097118491116, 0.866040549565802, 0.631219770197125], 
             UndirectedEdge[183, 224] -> 
             RGBColor[
              0.988373578491921, 0.9886909852090034, 0.7969686035285319], 
             UndirectedEdge[170, 178] -> 
             RGBColor[
              0.8947530650482227, 0.9158189970752499, 0.857339695063487], 
             UndirectedEdge[102, 238] -> 
             RGBColor[
              0.9343839316791004, 0.8045718450102514, 0.5860500832999507], 
             UndirectedEdge[89, 236] -> 
             RGBColor[
              0.9729367045164612, 0.9313706048722646, 0.5830868144449495], 
             UndirectedEdge[65, 231] -> 
             RGBColor[
              0.9135989988249018, 0.8218343324332926, 0.6221107867082176], 
             UndirectedEdge[25, 245] -> 
             RGBColor[
              0.9440728478842397, 0.8138980432041341, 0.2846721737688753], 
             UndirectedEdge[217, 223] -> 
             RGBColor[
              0.9506874043046993, 0.8404479673204718, 0.2882996494874599], 
             UndirectedEdge[254, 283] -> 
             RGBColor[
              0.9565008594613373, 0.9367652916698213, 0.6660876346429382], 
             UndirectedEdge[168, 205] -> 
             RGBColor[
              0.9671735758607063, 0.8982418385742563, 0.5185270468168711], 
             UndirectedEdge[142, 243] -> 
             RGBColor[
              0.9673743993742745, 0.9737764289738484, 0.8768771325095353], 
             UndirectedEdge[57, 278] -> 
             RGBColor[
              0.9879783508605203, 0.9752423123401831, 0.594054265052328], 
             UndirectedEdge[185, 218] -> 
             RGBColor[
              0.9567735032145162, 0.9086431933819781, 0.6147336362573245], 
             UndirectedEdge[16, 248] -> 
             RGBColor[
              0.9784901207226097, 0.9396711836593847, 0.5325524409914131], 
             UndirectedEdge[184, 275] -> 
             RGBColor[
              0.9325753047555561, 0.9476602943406658, 0.9429776295709889], 
             UndirectedEdge[127, 191] -> 
             RGBColor[
              0.9524319313541092, 0.9604533108263147, 0.7723910479677744], 
             UndirectedEdge[33, 153] -> 
             RGBColor[
              0.9873622594958225, 0.9689385972692165, 0.4133538803531925], 
             UndirectedEdge[83, 243] -> 
             RGBColor[
              0.9654569876335573, 0.9729835299438279, 0.9086536071557396], 
             UndirectedEdge[94, 281] -> 
             RGBColor[
              0.5946229328520309, 0.6751258629167392, 0.9644813022506233], 
             UndirectedEdge[140, 293] -> 
             RGBColor[
              0.7426635980516998, 0.7977635524426846, 0.9584106578541852], 
             UndirectedEdge[126, 220] -> 
             RGBColor[
              0.9776970398430754, 0.9823622001077031, 0.8991325563709751], 
             UndirectedEdge[76, 220] -> 
             RGBColor[
              0.9902138441451516, 0.9883184630310649, 0.6735374897012963], 
             UndirectedEdge[90, 126] -> 
             RGBColor[
              0.9449637514424778, 0.8518464120953475, 0.5974920784614135], 
             UndirectedEdge[35, 102] -> 
             RGBColor[
              0.9446273376563861, 0.8468481310609881, 0.5943782759552605], 
             UndirectedEdge[105, 235] -> 
             RGBColor[
              0.6886584381240621, 0.7483733352597755, 0.7986120765518732], 
             UndirectedEdge[21, 287] -> 
             RGBColor[
              0.9469871377597924, 0.827528697246358, 0.2762028105509633], 
             UndirectedEdge[160, 245] -> 
             RGBColor[
              0.9562372879607118, 0.8549315559284305, 0.33192872640421434`], 
             UndirectedEdge[235, 298] -> 
             RGBColor[
              0.9941394565765714, 0.9898732151461465, 0.6034941993204768], 
             UndirectedEdge[15, 196] -> 
             RGBColor[
              0.9450023783491492, 0.9513119421740285, 0.7041584571159805], 
             UndirectedEdge[13, 274] -> 
             RGBColor[
              0.9268169015345118, 0.9410697857765391, 0.8543512689804376], 
             UndirectedEdge[2, 172] -> 
             RGBColor[
              0.983715756153309, 0.9854361446158995, 0.822226278532989], 
             UndirectedEdge[247, 295] -> 
             RGBColor[
              0.9907669667498678, 0.9896871426070365, 0.7472330870365731], 
             UndirectedEdge[159, 225] -> 
             RGBColor[
              0.9838074389819584, 0.9565400256583938, 0.4341802478709462], 
             UndirectedEdge[204, 254] -> 
             RGBColor[
              0.9299839717379971, 0.7505134145411534, 0.28744183950519864`], 
             UndirectedEdge[61, 252] -> 
             RGBColor[
              0.933505367218948, 0.7537373720739322, 0.36500974724680413`], 
             UndirectedEdge[4, 173] -> 
             RGBColor[
              0.9803405473767217, 0.9839971514712773, 0.879585395685926], 
             UndirectedEdge[230, 245] -> 
             RGBColor[
              0.9588528743199118, 0.8637286972921421, 0.3442875083173558], 
             UndirectedEdge[137, 295] -> 
             RGBColor[
              0.99111060026015, 0.9905920190074886, 0.7969838889257915], 
             UndirectedEdge[109, 192] -> 
             RGBColor[
              0.7153725733018725, 0.7775737583871326, 0.9722653106360949], 
             UndirectedEdge[178, 229] -> 
             RGBColor[
              0.8358589316545, 0.6871357052076204, 0.5996596241950177], 
             UndirectedEdge[91, 93] -> 
             RGBColor[
              0.9292683033576994, 0.9424107091935701, 0.8048318849184923], 
             UndirectedEdge[143, 185] -> 
             RGBColor[
              0.9452330130109354, 0.900036314683966, 0.6342686759300837], 
             UndirectedEdge[139, 273] -> 
             RGBColor[
              0.9943966200057107, 0.9904232617178643, 0.6314848515535707], 
             UndirectedEdge[130, 281] -> 
             RGBColor[
              0.6673015666927927, 0.358242315109369, 0.4380683270773881], 
             UndirectedEdge[220, 248] -> 
             RGBColor[
              0.9905456037644165, 0.9903583784367551, 0.8063473430241571], 
             UndirectedEdge[88, 273] -> 
             RGBColor[
              0.8401578358063628, 0.8719875666454502, 0.7598563323436971], 
             UndirectedEdge[24, 218] -> 
             RGBColor[
              0.9419496871880413, 0.9558748962463789, 0.970949147803207], 
             UndirectedEdge[66, 215] -> 
             RGBColor[
              0.9366367573264988, 0.9511893348527583, 0.9548692048815255], 
             UndirectedEdge[151, 154] -> 
             RGBColor[
              0.9154639104381623, 0.6965135540702292, 0.2505262432212427], 
             UndirectedEdge[8, 64] -> 
             RGBColor[
              0.7597840213641983, 0.794461671156139, 0.6725272889033893], 
             UndirectedEdge[71, 108] -> 
             RGBColor[
              0.9899336064178375, 0.9901053018063302, 0.8164897228553345], 
             UndirectedEdge[43, 182] -> 
             RGBColor[
              0.9898451517112038, 0.990068723511955, 0.8179556462576968], 
             UndirectedEdge[58, 297] -> 
             RGBColor[
              0.9693726433526767, 0.9066041345996521, 0.5185530722165607], 
             UndirectedEdge[46, 207] -> 
             RGBColor[
              0.7191631980528899, 0.7780574188359406, 0.9397315442633469], 
             UndirectedEdge[100, 266] -> 
             RGBColor[
              0.9907497642426356, 0.9891224280363727, 0.7069864785976367], 
             UndirectedEdge[12, 151] -> 
             RGBColor[
              0.6014368636011073, 0.5070461727029997, 0.5829487199879146], 
             UndirectedEdge[196, 265] -> 
             RGBColor[
              0.980868449813622, 0.9789971805952917, 0.6759114722600514], 
             UndirectedEdge[93, 139] -> 
             RGBColor[
              0.9296813196626985, 0.943294109307609, 0.8497861608764586], 
             UndirectedEdge[30, 104] -> 
             RGBColor[
              0.9835063345559903, 0.9852129336219861, 0.8172626506465892], 
             UndirectedEdge[85, 121] -> 
             RGBColor[
              0.9905895604871855, 0.9899906133688869, 0.7775649352033263], 
             UndirectedEdge[79, 160] -> 
             RGBColor[
              0.9908171851639277, 0.9795645459099377, 0.5142171104945954], 
             UndirectedEdge[60, 196] -> 
             RGBColor[
              0.9899441328088209, 0.9849220501712888, 0.6227634141720054], 
             UndirectedEdge[25, 297] -> 
             RGBColor[
              0.9781008616272889, 0.9391321457369786, 0.5363902707768854], 
             UndirectedEdge[9, 133] -> 
             RGBColor[
              0.6879114344131597, 0.7534687398552686, 0.9695821559930602], 
             UndirectedEdge[151, 192] -> 
             RGBColor[
              0.8258514848980042, 0.6909355254231073, 0.600932697129484], 
             UndirectedEdge[45, 141] -> 
             RGBColor[
              0.9866039459222191, 0.9656524129723637, 0.4723300844865008], 
             UndirectedEdge[177, 280] -> 
             RGBColor[
              0.9190468365060265, 0.7148548791662623, 0.2536231118663158], 
             UndirectedEdge[141, 188] -> 
             RGBColor[
              0.9872586409271762, 0.9670527393881481, 0.5435895954668506], 
             UndirectedEdge[129, 183] -> 
             RGBColor[
              0.99137010623921, 0.9903077417307666, 0.7642187682353551], 
             UndirectedEdge[41, 55] -> 
             RGBColor[
              0.9545094264937524, 0.847560932804295, 0.5060285903370074], 
             UndirectedEdge[120, 261] -> 
             RGBColor[
              0.9577915352306917, 0.9640258863319697, 0.7160747195093009], 
             UndirectedEdge[71, 279] -> 
             RGBColor[
              0.9679847821541319, 0.975000615356164, 0.9102796884057653], 
             UndirectedEdge[180, 230] -> 
             RGBColor[
              0.8270159092593126, 0.8609702324774562, 0.6984143135491121], 
             UndirectedEdge[106, 194] -> 
             RGBColor[
              0.9095350165012145, 0.9302406132239506, 0.9752178261929123], 
             UndirectedEdge[90, 234] -> 
             RGBColor[
              0.88633351906527, 0.8059303141119576, 0.6208171834165961], 
             UndirectedEdge[44, 136] -> 
             RGBColor[
              0.9907716181318678, 0.9882883516702419, 0.645338851209802], 
             UndirectedEdge[120, 131] -> 
             RGBColor[
              0.9308792806946854, 0.9476416751837566, 0.9904883088527188], 
             UndirectedEdge[44, 279] -> 
             RGBColor[
              0.9703404939326898, 0.9738112731998704, 0.7139765990091493], 
             UndirectedEdge[105, 139] -> 
             RGBColor[
              0.6889388647352239, 0.7489731394255706, 0.8291347825843856], 
             UndirectedEdge[157, 184] -> 
             RGBColor[
              0.9891268501647514, 0.987984229777449, 0.6999304646799969], 
             UndirectedEdge[83, 149] -> 
             RGBColor[
              0.9851982973381105, 0.9877065663980558, 0.8752367191841159], 
             UndirectedEdge[145, 168] -> 
             RGBColor[
              0.9933172249583377, 0.9915045150278573, 0.7604144071151575], 
             UndirectedEdge[112, 170] -> 
             RGBColor[
              0.5869035106382245, 0.6487723857337149, 0.8340079138684153], 
             UndirectedEdge[159, 270] -> 
             RGBColor[
              0.9566581795215099, 0.9395050969742078, 0.6713883536016378], 
             UndirectedEdge[86, 162] -> 
             RGBColor[
              0.9026974532038832, 0.8879602442842494, 0.6565500963731375], 
             UndirectedEdge[3, 264] -> 
             RGBColor[
              0.9947224117964175, 0.9911200974155832, 0.6669452774181239], 
             UndirectedEdge[60, 282] -> 
             RGBColor[
              0.9863282876853002, 0.9884804799160917, 0.87024152808745], 
             UndirectedEdge[135, 186] -> 
             RGBColor[
              0.9425456809264718, 0.9566712434245517, 0.9821393550918611], 
             UndirectedEdge[89, 294] -> 
             RGBColor[
              0.9763763969789581, 0.9313158397341641, 0.4187078075530464], 
             UndirectedEdge[201, 203] -> 
             RGBColor[
              0.9464804058471337, 0.8112150359920172, 0.44054474748285355`], 
             UndirectedEdge[181, 203] -> 
             RGBColor[
              0.9300204537874024, 0.8013175703431623, 0.5934363131932944], 
             UndirectedEdge[70, 211] -> 
             RGBColor[
              0.7539179847736178, 0.46465001338297085`, 0.4485345360666202], 
             UndirectedEdge[156, 159] -> 
             RGBColor[
              0.9528200163101925, 0.845231448584585, 0.30913743086101264`], 
             UndirectedEdge[56, 270] -> 
             RGBColor[
              0.965026972371684, 0.9677350003438515, 0.703899533510644], 
             UndirectedEdge[113, 264] -> 
             RGBColor[
              0.9591961988700624, 0.8629105448868101, 0.47352427950449694`], 
             UndirectedEdge[144, 240] -> 
             RGBColor[
              0.9664834483550315, 0.9745239911782747, 0.9416189588049588], 
             UndirectedEdge[231, 232] -> 
             RGBColor[
              0.7577124853825249, 0.8108190468964624, 0.9766707746981986], 
             UndirectedEdge[90, 248] -> 
             RGBColor[
              0.9578123153638187, 0.8598425904243995, 0.5047068651145954], 
             UndirectedEdge[27, 109] -> 
             RGBColor[
              0.8263625893698823, 0.8632134475143518, 0.8877784496146117], 
             UndirectedEdge[42, 145] -> 
             RGBColor[
              0.9763098577408271, 0.9802864761441239, 0.8548551610535411], 
             UndirectedEdge[160, 230] -> 
             RGBColor[
              0.9899292913730997, 0.9776654308711893, 0.4175753508082716], 
             UndirectedEdge[247, 251] -> 
             RGBColor[
              0.9496305724333656, 0.9587016452272081, 0.8112013569878764], 
             UndirectedEdge[109, 220] -> 
             RGBColor[
              0.8248327798184423, 0.8625808319505193, 0.9131313529021821], 
             UndirectedEdge[139, 163] -> 
             RGBColor[
              0.8948842664940537, 0.9157528420459706, 0.8464127972256117], 
             UndirectedEdge[31, 279] -> 
             RGBColor[
              0.9463470317730174, 0.9595062846617646, 0.9757046596597465], 
             UndirectedEdge[9, 112] -> 
             RGBColor[
              0.5584032535230631, 0.6292926092923742, 0.9617694851691139], 
             UndirectedEdge[196, 276] -> 
             RGBColor[
              0.814186545887714, 0.8484053139826868, 0.6913384821612578], 
             UndirectedEdge[137, 251] -> 
             RGBColor[
              0.9499742059436478, 0.9596065216276602, 0.860952158877095], 
             UndirectedEdge[162, 181] -> 
             RGBColor[
              0.9646065120053737, 0.9366571187680335, 0.6393044704371444], 
             UndirectedEdge[96, 236] -> 
             RGBColor[
              0.9691457239952467, 0.9760944488002394, 0.9185250428426657], 
             UndirectedEdge[251, 295] -> 
             RGBColor[
              0.9459997248415131, 0.9579629715524223, 0.926819596366845], 
             UndirectedEdge[20, 268] -> 
             RGBColor[
              0.9615678370834679, 0.9405442352839918, 0.6575105632080875], 
             UndirectedEdge[187, 215] -> 
             RGBColor[
              0.9811890108925657, 0.985491375640619, 0.9167262772538891], 
             UndirectedEdge[55, 250] -> 
             RGBColor[
              0.9704395921033389, 0.9759643061221217, 0.867293715063967], 
             UndirectedEdge[193, 230] -> 
             RGBColor[
              0.9664547195719007, 0.9707535701482215, 0.707882777112521], 
             UndirectedEdge[55, 242] -> 
             RGBColor[
              0.9781927465154755, 0.9393458313685098, 0.5360818553037028], 
             UndirectedEdge[51, 116] -> 
             RGBColor[
              0.8966159081903913, 0.5743866469434507, 0.372798585967364], 
             UndirectedEdge[130, 203] -> 
             RGBColor[
              0.8597056485469494, 0.41794181189928414`, 0.2031633756419906], 
             UndirectedEdge[34, 124] -> 
             RGBColor[
              0.9747967427321265, 0.9807240325129418, 0.9275467198789653], 
             UndirectedEdge[190, 261] -> 
             RGBColor[
              0.982973869581129, 0.9541481452137045, 0.39523290716097803`], 
             UndirectedEdge[76, 85] -> 
             RGBColor[
              0.9897104567735513, 0.9881102994164428, 0.6818799211734718], 
             UndirectedEdge[130, 237] -> 
             RGBColor[
              0.8861056743121566, 0.5349724940150665, 0.431745007812691], 
             UndirectedEdge[175, 183] -> 
             RGBColor[
              0.9894861803556001, 0.989520761857217, 0.7950852587863637], 
             UndirectedEdge[93, 289] -> 
             RGBColor[
              0.9294036687305498, 0.9427002420385584, 0.81956557037501], 
             UndirectedEdge[69, 234] -> 
             RGBColor[
              0.9063136481063552, 0.9274596859971543, 0.967550150582928], 
             UndirectedEdge[32, 269] -> 
             RGBColor[
              0.9395348020838925, 0.808906009183445, 0.5776590734632241], 
             UndirectedEdge[226, 243] -> 
             RGBColor[
              0.9334365923961374, 0.8479666168577935, 0.6206643511316108], 
             UndirectedEdge[72, 218] -> 
             RGBColor[
              0.975803154724233, 0.9805493399042259, 0.8844075104063104], 
             UndirectedEdge[81, 181] -> 
             RGBColor[
              0.9682735667308766, 0.97585905853193, 0.9385887553323008], 
             UndirectedEdge[8, 67] -> 
             RGBColor[
              0.9853665265236391, 0.9622999992405776, 0.3976521481542717], 
             UndirectedEdge[145, 156] -> 
             RGBColor[
              0.9624789081130817, 0.8785602240068149, 0.5095194191798227], 
             UndirectedEdge[20, 177] -> 
             RGBColor[
              0.9563831874090722, 0.8599485500631874, 0.30893006918338717`], 
             UndirectedEdge[180, 297] -> 
             RGBColor[
              0.8273519195899739, 0.863470460067542, 0.8644857861530648], 
             UndirectedEdge[140, 216] -> 
             RGBColor[
              0.6804499813366497, 0.7486597122291938, 0.9699371081228596], 
             UndirectedEdge[287, 300] -> 
             RGBColor[
              0.9749456776646063, 0.9258404764473922, 0.4572900717793825], 
             UndirectedEdge[140, 167] -> 
             RGBColor[
              0.48200598031016695`, 0.5898263075516679, 0.9525100034126286], 
             UndirectedEdge[248, 285] -> 
             RGBColor[
              0.9927293963833443, 0.9912614328055922, 0.7701562478543851], 
             UndirectedEdge[185, 292] -> 
             RGBColor[
              0.9603737529789766, 0.9113282537614449, 0.6086393525016172], 
             UndirectedEdge[23, 241] -> 
             RGBColor[
              0.4200938997601006, 0.5294595039818395, 0.9491854453892858], 
             UndirectedEdge[10, 48] -> 
             RGBColor[
              0.9936309025707915, 0.9887854695504803, 0.5481412342228443], 
             UndirectedEdge[46, 62] -> 
             RGBColor[
              0.9268701111049126, 0.763036305257262, 0.5748411787960284], 
             UndirectedEdge[15, 276] -> 
             RGBColor[
              0.7685713788007045, 0.8197043371263364, 0.9774455742195436], 
             UndirectedEdge[85, 154] -> 
             RGBColor[
              0.9670000999212796, 0.9094002300879563, 0.5763556841514899], 
             UndirectedEdge[32, 179] -> 
             RGBColor[
              0.9760775446952448, 0.9816792525199147, 0.9253786562420582], 
             UndirectedEdge[145, 277] -> 
             RGBColor[
              0.983630931094911, 0.9857465206644421, 0.8424624935068163], 
             UndirectedEdge[58, 164] -> 
             RGBColor[
              0.9416357345366604, 0.8874173569346753, 0.6326489854780386], 
             UndirectedEdge[18, 253] -> 
             RGBColor[
              0.9714117676902458, 0.9290995418730993, 0.5970201488686224], 
             UndirectedEdge[59, 136] -> 
             RGBColor[
              0.9864178326814534, 0.973769355446529, 0.6141954554955814], 
             UndirectedEdge[232, 288] -> 
             RGBColor[
              0.7856390039837495, 0.7922312958926077, 0.6400581022766476], 
             UndirectedEdge[136, 177] -> 
             RGBColor[
              0.9646156327217066, 0.8956415748500037, 0.553370746096833], 
             UndirectedEdge[31, 65] -> 
             RGBColor[
              0.9314931435314817, 0.8358682774107109, 0.615692127899355], 
             UndirectedEdge[62, 214] -> 
             RGBColor[
              0.9362800397365241, 0.7666559776399453, 0.35295897241024743`], 
             UndirectedEdge[24, 109] -> 
             RGBColor[
              0.7921843580967045, 0.8384047057052137, 0.9797022625949758], 
             UndirectedEdge[71, 268] -> 
             RGBColor[
              0.9694471013915062, 0.9760912106490698, 0.9078043633708303], 
             UndirectedEdge[64, 118] -> 
             RGBColor[
              0.7116577559331855, 0.6066075757842732, 0.5919293648961192], 
             UndirectedEdge[21, 206] -> 
             RGBColor[
              0.9628512205169014, 0.8913924051925937, 0.5653890489353868], 
             UndirectedEdge[6, 124] -> 
             RGBColor[
              0.8550995532427468, 0.8870143283138208, 0.9530160962305474], 
             UndirectedEdge[7, 140] -> 
             RGBColor[
              0.746975617016661, 0.8009794491264697, 0.951111534501169], 
             UndirectedEdge[78, 229] -> 
             RGBColor[
              0.8446693604718264, 0.32475972363805605`, 0.1896414790081521], 
             UndirectedEdge[67, 213] -> 
             RGBColor[
              0.9718820418933831, 0.9685277468757287, 0.6831256706178128], 
             UndirectedEdge[189, 300] -> 
             RGBColor[
              0.9284352192745815, 0.9418005370615761, 0.8091384730620306], 
             UndirectedEdge[77, 225] -> 
             RGBColor[
              0.9860283558360056, 0.9640316997031708, 0.4428080904639636], 
             UndirectedEdge[153, 239] -> 
             RGBColor[
              0.9402282757343643, 0.936496626327588, 0.6875080419437524], 
             UndirectedEdge[7, 168] -> 
             RGBColor[
              0.978434333045225, 0.9819709136723651, 0.8557375108434662], 
             UndirectedEdge[5, 256] -> 
             RGBColor[
              0.5861493834048324, 0.6468126021800371, 0.7267184529123636], 
             UndirectedEdge[193, 200] -> 
             RGBColor[
              0.9576138132450651, 0.9409569627590362, 0.6713398026781475], 
             UndirectedEdge[17, 202] -> 
             RGBColor[
              0.8730548072526418, 0.7092134378281816, 0.601805517353859], 
             UndirectedEdge[12, 220] -> 
             RGBColor[
              0.6534764404558249, 0.7201410123353489, 0.9004357294459864], 
             UndirectedEdge[196, 207] -> 
             RGBColor[
              0.7273576781548255, 0.7779137275612129, 0.6845029956287021], 
             UndirectedEdge[222, 285] -> 
             RGBColor[
              0.9400845015420812, 0.9523667982825539, 0.8880629604906038], 
             UndirectedEdge[169, 227] -> 
             RGBColor[
              0.9908857152762452, 0.9888689787450711, 0.6822237844930905], 
             UndirectedEdge[139, 298] -> 
             RGBColor[
              0.9944198831877331, 0.9904730193119416, 0.6340169053529892], 
             UndirectedEdge[210, 241] -> 
             RGBColor[
              0.7904228484047247, 0.8320859926091277, 0.7388243824257444], 
             UndirectedEdge[58, 288] -> 
             RGBColor[
              0.9551901803437526, 0.8574224164188421, 0.2964930228210515], 
             UndirectedEdge[85, 258] -> 
             RGBColor[
              0.9821392962911919, 0.9858424895560773, 0.8991033028868627], 
             UndirectedEdge[87, 162] -> 
             RGBColor[
              0.9800370738333601, 0.9467926090471692, 0.5517168352464027], 
             UndirectedEdge[222, 248] -> 
             RGBColor[
              0.9410950444182782, 0.9527846837316285, 0.87131564983089], 
             UndirectedEdge[76, 87] -> 
             RGBColor[
              0.9927651470883863, 0.9893734923635873, 0.6312557973715315], 
             UndirectedEdge[80, 282] -> 
             RGBColor[
              0.9127094630874273, 0.9320040546089619, 0.9489013264813209], 
             UndirectedEdge[273, 289] -> 
             RGBColor[
              0.9941189690735621, 0.9898293944488137, 0.601264261052122], 
             UndirectedEdge[215, 296] -> 
             RGBColor[
              0.9748843384248909, 0.9481123118842496, 0.6299522587796387], 
             UndirectedEdge[142, 277] -> 
             RGBColor[
              0.983167447137917, 0.9855548581372308, 0.8501436221322363], 
             UndirectedEdge[134, 180] -> 
             RGBColor[
              0.8246507019357019, 0.8623534371493733, 0.9092519532115537], 
             UndirectedEdge[86, 178] -> 
             RGBColor[
              0.8162003708584017, 0.8564849952205593, 0.9822767244188632], 
             UndirectedEdge[3, 210] -> 
             RGBColor[
              0.9939286292114066, 0.9894222767299751, 0.5805469416979576], 
             UndirectedEdge[79, 176] -> 
             RGBColor[
              0.994246842121892, 0.9901029019692429, 0.6151824532218498], 
             UndirectedEdge[131, 141] -> 
             RGBColor[
              0.9590915045924191, 0.947984462960419, 0.6814170452490118], 
             UndirectedEdge[150, 256] -> 
             RGBColor[
              0.5863737159426602, 0.6472924267949521, 0.7511356652349824], 
             UndirectedEdge[74, 300] -> 
             RGBColor[
              0.9937990410736224, 0.9909403287642, 0.6969361937513616], 
             UndirectedEdge[25, 230] -> 
             RGBColor[
              0.9777648512966276, 0.9366319181468927, 0.3703187981729327], 
             UndirectedEdge[165, 253] -> 
             RGBColor[
              0.9387463902587572, 0.7942324601939665, 0.2728240978847601], 
             UndirectedEdge[223, 295] -> 
             RGBColor[
              0.9633132619630814, 0.8933775590024573, 0.5665110448152437], 
             UndirectedEdge[164, 221] -> 
             RGBColor[
              0.9662709839018258, 0.9721865711591509, 0.8327690202041389], 
             UndirectedEdge[70, 138] -> 
             RGBColor[
              0.7799655833633593, 0.8252265098922577, 0.8577707422969525], 
             UndirectedEdge[165, 224] -> 
             RGBColor[
              0.9506686528137214, 0.8521315104874359, 0.5847553439629305], 
             UndirectedEdge[87, 258] -> 
             RGBColor[
              0.9851939866060269, 0.9871056825032218, 0.8484791790849224], 
             UndirectedEdge[90, 222] -> 
             RGBColor[
              0.9051674205225555, 0.820947955901361, 0.6226135777508143], 
             UndirectedEdge[163, 185] -> 
             RGBColor[
              0.8731640828493812, 0.8428545015412504, 0.6300805537688043], 
             UndirectedEdge[64, 286] -> 
             RGBColor[
              0.7263671524804332, 0.669965236723747, 0.6040255945352987], 
             UndirectedEdge[131, 199] -> 
             RGBColor[
              0.9280673975789095, 0.9453995559137707, 0.9902201089309384], 
             UndirectedEdge[2, 49] -> 
             RGBColor[
              0.9178872489539293, 0.9364188355793486, 0.9593163641514328], 
             UndirectedEdge[51, 283] -> 
             RGBColor[
              0.9678551390107513, 0.9737492751410262, 0.858791439204921], 
             UndirectedEdge[66, 187] -> 
             RGBColor[
              0.9385623115384786, 0.9526254100312472, 0.9516097438656144], 
             UndirectedEdge[120, 170] -> 
             RGBColor[
              0.9589145366866321, 0.9667746545487732, 0.8635138631619059], 
             UndirectedEdge[17, 182] -> 
             RGBColor[
              0.932397476484166, 0.9462148653239422, 0.8863523972221565], 
             UndirectedEdge[156, 179] -> 
             RGBColor[
              0.9515664444858107, 0.871987761565924, 0.5981216234737468], 
             UndirectedEdge[199, 284] -> 
             RGBColor[
              0.9409547818929596, 0.9550109460340341, 0.9684051288553993], 
             UndirectedEdge[210, 291] -> 
             RGBColor[
              0.9762139506520089, 0.9309068007931762, 0.4062630734058639], 
             UndirectedEdge[212, 265] -> 
             RGBColor[
              0.7543385306917176, 0.8067170157072581, 0.9452546188964026], 
             UndirectedEdge[85, 173] -> 
             RGBColor[
              0.9878608207609976, 0.9892481516690654, 0.8508411453864957], 
             UndirectedEdge[47, 146] -> 
             RGBColor[
              0.9918503226434294, 0.9890857682113031, 0.6530009623215689], 
             UndirectedEdge[198, 283] -> 
             RGBColor[
              0.962616978236621, 0.9573963964318335, 0.6898476011527988], 
             UndirectedEdge[168, 212] -> 
             RGBColor[
              0.7652869762282708, 0.8134163207219072, 0.8610700389440187], 
             UndirectedEdge[56, 271] -> 
             RGBColor[
              0.9479437702193556, 0.8209491862007029, 0.3309913415370591], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.428093210309618, 0.542953665947218, 0.9491233890893187], 
             UndirectedEdge[159, 191] -> 
             RGBColor[
              0.9839897791848624, 0.956930032914983, 0.45402685368375706`], 
             UndirectedEdge[72, 83] -> 
             RGBColor[
              0.9893088865776307, 0.9898469640978372, 0.8268429473306802], 
             UndirectedEdge[179, 277] -> 
             RGBColor[
              0.9727184674676399, 0.9791740582235512, 0.9310646978007404], 
             UndirectedEdge[86, 182] -> 
             RGBColor[
              0.9148053806980807, 0.9321874056688366, 0.8846744474214304], 
             UndirectedEdge[80, 293] -> 
             RGBColor[
              0.8986307269410365, 0.9215041562427982, 0.972732954454691], 
             UndirectedEdge[9, 96] -> 
             RGBColor[
              0.944740313092153, 0.9583079965003363, 0.9784244152871038], 
             UndirectedEdge[51, 226] -> 
             RGBColor[
              0.9599141893068437, 0.8659158445983652, 0.4953390809109302], 
             UndirectedEdge[185, 235] -> 
             RGBColor[
              0.9731418139122767, 0.9185203167383555, 0.4658060825717602], 
             UndirectedEdge[136, 210] -> 
             RGBColor[
              0.9910568455807345, 0.9888984243424489, 0.6763840987991605], 
             UndirectedEdge[78, 284] -> 
             RGBColor[
              0.8738335349490437, 0.47086752538664023`, 0.43153450333064747`],
              UndirectedEdge[81, 216] -> 
             RGBColor[
              0.9028777662141004, 0.9243819508494597, 0.9555018127308389], 
             UndirectedEdge[2, 165] -> 
             RGBColor[
              0.9458536589881164, 0.8485404959761285, 0.5929058725581631], 
             UndirectedEdge[181, 216] -> 
             RGBColor[
              0.8961969499830117, 0.9193994090431463, 0.9668106919741348], 
             UndirectedEdge[7, 203] -> 
             RGBColor[
              0.9311502889506377, 0.8021601995579679, 0.5915237969701419], 
             UndirectedEdge[44, 177] -> 
             RGBColor[
              0.9666181634956684, 0.8943061832719718, 0.362920779949514], 
             UndirectedEdge[140, 237] -> 
             RGBColor[
              0.7538735237888512, 0.8061238967028834, 0.9394351775980696], 
             UndirectedEdge[38, 124] -> 
             RGBColor[
              0.9679802577258785, 0.9337869820497363, 0.6221595655182475], 
             UndirectedEdge[5, 59] -> 
             RGBColor[
              0.9887191724073328, 0.9730730860024291, 0.4562689997293844], 
             UndirectedEdge[35, 253] -> 
             RGBColor[
              0.9385047598546885, 0.7932744761603927, 0.2726296763898518], 
             UndirectedEdge[200, 231] -> 
             RGBColor[
              0.9419310001259767, 0.928572225258846, 0.6740152539170343], 
             UndirectedEdge[213, 234] -> 
             RGBColor[
              0.9033983060767254, 0.925285428684891, 0.972485064196113], 
             UndirectedEdge[53, 88] -> 
             RGBColor[
              0.7794274935736304, 0.38463796972006115`, 0.4380332338902031], 
             UndirectedEdge[150, 269] -> 
             RGBColor[
              0.9462641120302788, 0.8110642099506975, 0.4029809840864097], 
             UndirectedEdge[4, 135] -> 
             RGBColor[
              0.9553344922287528, 0.9662091179540362, 0.9604912334132882], 
             UndirectedEdge[91, 139] -> 
             RGBColor[
              0.994729407863112, 0.991135061294832, 0.6677067561031136], 
             UndirectedEdge[28, 232] -> 
             RGBColor[
              0.8007721498219702, 0.841664893047848, 0.8360952889799012], 
             UndirectedEdge[127, 276] -> 
             RGBColor[
              0.7744701358622341, 0.8244078458897051, 0.978008202933955], 
             UndirectedEdge[60, 103] -> 
             RGBColor[
              0.946847866697131, 0.8243076188584375, 0.5347158946826428], 
             UndirectedEdge[145, 159] -> 
             RGBColor[
              0.9839593128495947, 0.9583002024439822, 0.5550444063538645], 
             UndirectedEdge[20, 252] -> 
             RGBColor[
              0.923000237126661, 0.718801906763735, 0.2816144401584998], 
             UndirectedEdge[80, 128] -> 
             RGBColor[
              0.7986357144144682, 0.8427977714799701, 0.980516909773147], 
             UndirectedEdge[167, 237] -> 
             RGBColor[
              0.7057806908919542, 0.7665530811568396, 0.9357947141376521], 
             UndirectedEdge[24, 291] -> 
             RGBColor[
              0.9405688611631355, 0.9071628411389804, 0.6439871674048789], 
             UndirectedEdge[22, 244] -> 
             RGBColor[
              0.987244119698985, 0.9889931299314287, 0.8610614779552358], 
             UndirectedEdge[51, 83] -> 
             RGBColor[
              0.9919345845442635, 0.9909327576843997, 0.783328336935059], 
             UndirectedEdge[29, 229] -> 
             RGBColor[
              0.8892501438917342, 0.5899925943459794, 0.22929994414692634`], 
             UndirectedEdge[151, 181] -> 
             RGBColor[
              0.9224324325298221, 0.7668621380398807, 0.5871046822565481], 
             UndirectedEdge[22, 63] -> 
             RGBColor[
              0.9679581771026526, 0.912836378075022, 0.5753536478880636], 
             UndirectedEdge[163, 292] -> 
             RGBColor[
              0.8818357789495921, 0.9079609749032647, 0.9587233611229562], 
             UndirectedEdge[247, 289] -> 
             RGBColor[
              0.9944924683227669, 0.9906282715762962, 0.6419173493578936], 
             UndirectedEdge[155, 299] -> 
             RGBColor[
              0.968803214771295, 0.9752940834535277, 0.8947020774590306], 
             UndirectedEdge[31, 71] -> 
             RGBColor[
              0.9664249749675993, 0.9738373137103978, 0.9129200351096961], 
             UndirectedEdge[45, 260] -> 
             RGBColor[
              0.9741271108677361, 0.9773738384805688, 0.7661646579723369], 
             UndirectedEdge[80, 125] -> 
             RGBColor[
              0.8539224634150295, 0.5966736604875125, 0.46478639458189497`], 
             UndirectedEdge[97, 261] -> 
             RGBColor[
              0.993171671438711, 0.9878032205943499, 0.4981567595419183], 
             UndirectedEdge[107, 147] -> 
             RGBColor[
              0.861567242625848, 0.8919150820983268, 0.9459738943528457], 
             UndirectedEdge[15, 286] -> 
             RGBColor[
              0.9077683541230641, 0.8139393464612954, 0.620827835052278], 
             UndirectedEdge[94, 202] -> 
             RGBColor[
              0.8705803721139105, 0.7072403904153097, 0.6015695035213724], 
             UndirectedEdge[86, 130] -> 
             RGBColor[
              0.839481140487546, 0.4985165264983977, 0.45230134052085424`], 
             UndirectedEdge[73, 161] -> 
             RGBColor[
              0.9525717109668316, 0.9641486402125344, 0.9651679014409638], 
             UndirectedEdge[7, 167] -> 
             RGBColor[
              0.6988827841197641, 0.761408633580426, 0.9474710710407515], 
             UndirectedEdge[288, 297] -> 
             RGBColor[
              0.9790344353846983, 0.9422813092342623, 0.5400170285338094], 
             UndirectedEdge[15, 46] -> 
             RGBColor[
              0.9368078982472137, 0.9514556334487563, 0.9593870057506253], 
             UndirectedEdge[1, 92] -> 
             RGBColor[
              0.8684451243854527, 0.39369050015057816`, 0.22303375245318535`],
              UndirectedEdge[85, 213] -> 
             RGBColor[
              0.9711793795085489, 0.977668601564799, 0.9176555831957737], 
             UndirectedEdge[2, 174] -> 
             RGBColor[
              0.971553051185817, 0.9783048926687616, 0.9330374435766198], 
             UndirectedEdge[104, 204] -> 
             RGBColor[
              0.941354973558223, 0.7873008919243512, 0.46508194063875763`], 
             UndirectedEdge[125, 243] -> 
             RGBColor[
              0.8872639604231347, 0.6231499519668353, 0.4641765789223944], 
             UndirectedEdge[149, 243] -> 
             RGBColor[
              0.961798871714606, 0.9710302415901355, 0.9495487251239323], 
             UndirectedEdge[35, 175] -> 
             RGBColor[
              0.9515396242733318, 0.8520033031020757, 0.5826775777258539], 
             UndirectedEdge[82, 201] -> 
             RGBColor[
              0.9187619311770694, 0.9341648592071119, 0.8145014293925499], 
             UndirectedEdge[39, 69] -> 
             RGBColor[
              0.9719307059224329, 0.9785865469529769, 0.9323981726156594], 
             UndirectedEdge[5, 204] -> 
             RGBColor[
              0.9405177567765108, 0.7855101698838699, 0.37395606065244746`], 
             UndirectedEdge[107, 277] -> 
             RGBColor[
              0.9773305105450468, 0.9826137123991538, 0.9232577118841747], 
             UndirectedEdge[236, 260] -> 
             RGBColor[
              0.970555079317815, 0.9771455436922034, 0.9161393719002957], 
             UndirectedEdge[11, 51] -> 
             RGBColor[
              0.9847818016437087, 0.9863731524178194, 0.8301390145479819], 
             UndirectedEdge[41, 242] -> 
             RGBColor[
              0.9394202252014462, 0.7954168371532839, 0.28111140484649877`], 
             UndirectedEdge[53, 93] -> 
             RGBColor[
              0.8386126133695873, 0.43111219836749587`, 0.4438689992403714], 
             UndirectedEdge[82, 293] -> 
             RGBColor[
              0.8991197953156123, 0.9218941260892776, 0.9727796022328545], 
             UndirectedEdge[76, 151] -> 
             RGBColor[
              0.938174267290434, 0.7752236233987155, 0.35605048024322467`], 
             UndirectedEdge[130, 269] -> 
             RGBColor[
              0.8597921935803562, 0.4183347926828783, 0.20323559093927815`], 
             UndirectedEdge[13, 289] -> 
             RGBColor[
              0.9949092641593642, 0.9915197557262545, 0.6872830040057644], 
             UndirectedEdge[86, 120] -> 
             RGBColor[
              0.8803618424968112, 0.9074406526940826, 0.9884508925172821], 
             UndirectedEdge[86, 284] -> 
             RGBColor[
              0.9011794554087311, 0.9232951803679859, 0.9646113227074805], 
             UndirectedEdge[49, 102] -> 
             RGBColor[
              0.9169025580262677, 0.9356844546977819, 0.9609831890434384], 
             UndirectedEdge[27, 299] -> 
             RGBColor[
              0.9690235079967815, 0.975385180363544, 0.8910512486121283], 
             UndirectedEdge[120, 182] -> 
             RGBColor[
              0.9573925902980849, 0.9661452906048709, 0.8887364534911296], 
             UndirectedEdge[97, 182] -> 
             RGBColor[
              0.9927727265061042, 0.989922624867251, 0.670818493523747], 
             UndirectedEdge[42, 130] -> 
             RGBColor[
              0.8798900997983338, 0.5303369287197267, 0.4422663541831291], 
             UndirectedEdge[15, 127] -> 
             RGBColor[
              0.9052859683236694, 0.9273144740810467, 0.9908281778886776], 
             UndirectedEdge[28, 176] -> 
             RGBColor[
              0.9946456414910219, 0.9909558934950105, 0.6585893034472232], 
             UndirectedEdge[26, 35] -> 
             RGBColor[
              0.95686521117812, 0.8537937609626521, 0.4642633871728334], 
             UndirectedEdge[44, 59] -> 
             RGBColor[
              0.9884203634554154, 0.972433963868497, 0.4237454893482624], 
             UndirectedEdge[155, 218] -> 
             RGBColor[
              0.9759076252357326, 0.9805925411455007, 0.8826761636697453], 
             UndirectedEdge[65, 155] -> 
             RGBColor[
              0.9540846816988386, 0.8517570238659496, 0.5344604247036697], 
             UndirectedEdge[55, 252] -> 
             RGBColor[
              0.9334891126642333, 0.7554280234361748, 0.4886602287904908], 
             UndirectedEdge[160, 296] -> 
             RGBColor[
              0.9789094625915477, 0.9405188064069234, 0.3725676740923037], 
             UndirectedEdge[88, 147] -> 
             RGBColor[
              0.7143909887341777, 0.7768069370625306, 0.9721674754598164], 
             UndirectedEdge[204, 243] -> 
             RGBColor[
              0.9148606543767048, 0.7695481702717866, 0.605470914287862], 
             UndirectedEdge[65, 106] -> 
             RGBColor[
              0.8918283618079392, 0.8044750174241658, 0.6200342839146626], 
             UndirectedEdge[115, 245] -> 
             RGBColor[
              0.9546089625779981, 0.8643125900144236, 0.5852561559355732], 
             UndirectedEdge[60, 205] -> 
             RGBColor[
              0.965300813319352, 0.8974674031356042, 0.5495635686812089], 
             UndirectedEdge[75, 111] -> 
             RGBColor[
              0.9916353956485479, 0.9886029961740559, 0.6279309085501149], 
             UndirectedEdge[17, 86] -> 
             RGBColor[
              0.8553667286828922, 0.8875102274131539, 0.986066836248309], 
             UndirectedEdge[67, 166] -> 
             RGBColor[
              0.9857067858511677, 0.9634477738490208, 0.3989739913891377], 
             UndirectedEdge[3, 169] -> 
             RGBColor[
              0.991445791557187, 0.9900669252776071, 0.7431846312834531], 
             UndirectedEdge[7, 255] -> 
             RGBColor[
              0.9622102357873454, 0.9713370362420377, 0.9488523930497177], 
             UndirectedEdge[211, 231] -> 
             RGBColor[
              0.8681243476811557, 0.5551244776277493, 0.45925976315649103`], 
             UndirectedEdge[218, 290] -> 
             RGBColor[
              0.9632588609275989, 0.9721190991546727, 0.9470773442125073], 
             UndirectedEdge[201, 269] -> 
             RGBColor[
              0.9466102233972438, 0.8118045071674084, 0.4406530704287848], 
             UndirectedEdge[34, 223] -> 
             RGBColor[
              0.9583218142375918, 0.890144070619155, 0.5968642877360301], 
             UndirectedEdge[63, 208] -> 
             RGBColor[
              0.959755784120309, 0.9071105546540784, 0.6067706804337383], 
             UndirectedEdge[131, 190] -> 
             RGBColor[
              0.9560616150451227, 0.9377639340654913, 0.6696464965043958], 
             UndirectedEdge[27, 181] -> 
             RGBColor[
              0.9760018189359797, 0.9805895932360627, 0.8792387884270495], 
             UndirectedEdge[108, 136] -> 
             RGBColor[
              0.9902867874224335, 0.9902513512280685, 0.8106365996060375], 
             UndirectedEdge[101, 254] -> 
             RGBColor[
              0.9827337454411951, 0.9548392771786538, 0.5549364512519002], 
             UndirectedEdge[62, 212] -> 
             RGBColor[
              0.7085346720849439, 0.5906124490945006, 0.5889557767977347], 
             UndirectedEdge[69, 195] -> 
             RGBColor[
              0.9734019170904971, 0.9659947668907223, 0.6727696318721033], 
             UndirectedEdge[136, 252] -> 
             RGBColor[
              0.9312326824392954, 0.7544949315505514, 0.5260551170719456], 
             UndirectedEdge[26, 175] -> 
             RGBColor[
              0.9894698664218635, 0.9894858680025463, 0.7933095877770757], 
             UndirectedEdge[24, 27] -> 
             RGBColor[
              0.9562326560989939, 0.9654939279373704, 0.9005037552588663], 
             UndirectedEdge[231, 266] -> 
             RGBColor[
              0.9513751977796534, 0.9596592117940348, 0.7762227661955687], 
             UndirectedEdge[153, 157] -> 
             RGBColor[
              0.9876400449894758, 0.9695327523517193, 0.44358911704400933`], 
             UndirectedEdge[161, 244] -> 
             RGBColor[
              0.966170181753776, 0.9736677293524009, 0.9142666786864577], 
             UndirectedEdge[128, 150] -> 
             RGBColor[
              0.8745293948642597, 0.8989540329259529, 0.7725045449711005], 
             UndirectedEdge[113, 200] -> 
             RGBColor[
              0.9491616469225843, 0.8305608502111551, 0.30706034559006357`], 
             UndirectedEdge[211, 264] -> 
             RGBColor[
              0.896768758947909, 0.5755556955433087, 0.35879100572320116`], 
             UndirectedEdge[144, 232] -> 
             RGBColor[
              0.7916893334053905, 0.8368474456741568, 0.9430282942156796], 
             UndirectedEdge[208, 244] -> 
             RGBColor[
              0.9790417267166411, 0.9832673065104851, 0.8924785105009103], 
             UndirectedEdge[47, 133] -> 
             RGBColor[
              0.7155623892623331, 0.7707851629718812, 0.7241719087904699], 
             UndirectedEdge[181, 258] -> 
             RGBColor[
              0.9697634247780403, 0.9769701922240861, 0.9360668142756641], 
             UndirectedEdge[53, 147] -> 
             RGBColor[
              0.7979115822168054, 0.3990778802523862, 0.43987555510252563`], 
             UndirectedEdge[123, 267] -> 
             RGBColor[
              0.9622949998523469, 0.9159046331649519, 0.6078260835585227], 
             UndirectedEdge[59, 227] -> 
             RGBColor[
              0.9887295400311839, 0.973095261301519, 0.4573974516040158], 
             UndirectedEdge[213, 286] -> 
             RGBColor[
              0.9360818812374977, 0.8359919096724558, 0.6053653377619217], 
             UndirectedEdge[16, 126] -> 
             RGBColor[
              0.9656415568012686, 0.9316750053303328, 0.6253376543382312], 
             UndirectedEdge[68, 109] -> 
             RGBColor[
              0.45750049894095385`, 0.5595221767321213, 0.9523392315595021], 
             UndirectedEdge[137, 156] -> 
             RGBColor[
              0.963212346467982, 0.8788635196150723, 0.4973644475615062], 
             UndirectedEdge[181, 202] -> 
             RGBColor[
              0.917371770268047, 0.7438828526568602, 0.5828819416171398], 
             UndirectedEdge[135, 214] -> 
             RGBColor[
              0.9662067400977385, 0.9709193856296254, 0.7361337019925722], 
             UndirectedEdge[166, 234] -> 
             RGBColor[
              0.91722305003451, 0.9202054556581831, 0.6883333849674378], 
             UndirectedEdge[63, 152] -> 
             RGBColor[
              0.9688980548459246, 0.9132250416756211, 0.5597774413564183], 
             UndirectedEdge[130, 167] -> 
             RGBColor[
              0.704860645326367, 0.3907741012475895, 0.4404615583557303], 
             UndirectedEdge[30, 74] -> 
             RGBColor[
              0.9825837476083832, 0.9850348413864785, 0.8473388760721438], 
             UndirectedEdge[31, 177] -> 
             RGBColor[
              0.942624701335996, 0.880001194733866, 0.6246488406001112], 
             UndirectedEdge[24, 72] -> 
             RGBColor[
              0.9559078923620079, 0.9653596297860794, 0.9058859308423337], 
             UndirectedEdge[39, 285] -> 
             RGBColor[
              0.9868676579008735, 0.988476017448973, 0.8511145881891169], 
             UndirectedEdge[27, 72] -> 
             RGBColor[
              0.9900861236351856, 0.9901683715952174, 0.8139621178619697], 
             UndirectedEdge[109, 151] -> 
             RGBColor[
              0.7727932029637246, 0.64948599231817, 0.5956443434441104], 
             UndirectedEdge[29, 178] -> 
             RGBColor[
              0.8480173210572307, 0.7423441118214293, 0.6098048823420521], 
             UndirectedEdge[149, 256] -> 
             RGBColor[
              0.5802335907095796, 0.6455736390221817, 0.9248164185761543], 
             UndirectedEdge[93, 137] -> 
             RGBColor[
              0.9296526482597853, 0.9434026631445368, 0.8590138705639394], 
             UndirectedEdge[7, 145] -> 
             RGBColor[
              0.9787353127393712, 0.9820953765107199, 0.8507494984009832], 
             UndirectedEdge[271, 278] -> 
             RGBColor[
              0.9447376922895159, 0.8101343325204567, 0.31853633419664606`], 
             UndirectedEdge[15, 135] -> 
             RGBColor[
              0.9193761244810532, 0.9384550451158638, 0.9888944518019943], 
             UndirectedEdge[94, 130] -> 
             RGBColor[
              0.8495595809191154, 0.5065528013265534, 0.45326263116634735`], 
             UndirectedEdge[265, 286] -> 
             RGBColor[
              0.9436344255875369, 0.8416245848825586, 0.592580850196349], 
             UndirectedEdge[140, 201] -> 
             RGBColor[
              0.762305733913157, 0.8100342855605189, 0.8001324850138807], 
             UndirectedEdge[29, 259] -> 
             RGBColor[
              0.9480828500813799, 0.8181977179799202, 0.45508667740125364`], 
             UndirectedEdge[21, 123] -> 
             RGBColor[
              0.954707368742187, 0.8858222042413483, 0.6017208974626951], 
             UndirectedEdge[21, 189] -> 
             RGBColor[
              0.9004766793697676, 0.8434887578605419, 0.6280512118336115], 
             UndirectedEdge[107, 289] -> 
             RGBColor[
              0.9878022429282849, 0.9880970441032026, 0.784618341242787], 
             UndirectedEdge[17, 66] -> 
             RGBColor[
              0.8834844412206946, 0.909930528155823, 0.988748728771143], 
             UndirectedEdge[71, 208] -> 
             RGBColor[
              0.9791032424713582, 0.9832927448559434, 0.8914590352475811], 
             UndirectedEdge[6, 289] -> 
             RGBColor[
              0.8661729835160453, 0.8929464053190869, 0.8133582080092303], 
             UndirectedEdge[96, 132] -> 
             RGBColor[
              0.9727452503170366, 0.9763815521254848, 0.7715429651545782], 
             UndirectedEdge[55, 283] -> 
             RGBColor[
              0.9669897349989095, 0.973391408342261, 0.8731334232749293], 
             UndirectedEdge[48, 244] -> 
             RGBColor[
              0.9911898473366474, 0.9898984083185065, 0.7428703006806983], 
             UndirectedEdge[110, 278] -> 
             RGBColor[
              0.9720986374808576, 0.9645852705938418, 0.6740469880698774], 
             UndirectedEdge[245, 288] -> 
             RGBColor[
              0.945006421641649, 0.8170472067014178, 0.28829893152579933`], 
             UndirectedEdge[106, 210] -> 
             RGBColor[
              0.9294011324714813, 0.941864784239766, 0.7520043493177464], 
             UndirectedEdge[176, 296] -> 
             RGBColor[
              0.9823391195495119, 0.9510571624662285, 0.4735330168195581], 
             UndirectedEdge[82, 154] -> 
             RGBColor[
              0.8953334570256786, 0.8539188095886056, 0.6308145560676852], 
             UndirectedEdge[46, 117] -> 
             RGBColor[
              0.9595141441381323, 0.9693262955044996, 0.9534161729585149], 
             UndirectedEdge[249, 258] -> 
             RGBColor[
              0.9312110057789517, 0.9468972683196393, 0.9555402173667288], 
             UndirectedEdge[146, 170] -> 
             RGBColor[
              0.9926996249094173, 0.9912491215360314, 0.7706496382234607], 
             UndirectedEdge[18, 129] -> 
             RGBColor[
              0.986330557992499, 0.9886153486883319, 0.8762015596536159], 
             UndirectedEdge[13, 179] -> 
             RGBColor[
              0.9835123417064284, 0.9853464187830847, 0.8274884801069344], 
             UndirectedEdge[144, 160] -> 
             RGBColor[
              0.9821331681164779, 0.9756000900620141, 0.6645569659557472], 
             UndirectedEdge[17, 130] -> 
             RGBColor[
              0.8512092043449362, 0.507868166268468, 0.45341997372133835`], 
             UndirectedEdge[111, 163] -> 
             RGBColor[
              0.8936754677068477, 0.9131673436684414, 0.714842509079602], 
             UndirectedEdge[107, 251] -> 
             RGBColor[
              0.9429403470388833, 0.9561704177541146, 0.9539023488727698], 
             UndirectedEdge[1, 198] -> 
             RGBColor[
              0.9776169037197814, 0.9361587018252002, 0.3675463269547533], 
             UndirectedEdge[168, 269] -> 
             RGBColor[
              0.9458620187197144, 0.8121588092504965, 0.5012970286302476], 
             UndirectedEdge[145, 201] -> 
             RGBColor[
              0.9940654296358671, 0.9911502129447691, 0.6997704489136949], 
             UndirectedEdge[197, 226] -> 
             RGBColor[
              0.7094528257083171, 0.6698947990920268, 0.6058394063073143], 
             UndirectedEdge[105, 174] -> 
             RGBColor[
              0.676776159767732, 0.7418418874784329, 0.9399459476280163], 
             UndirectedEdge[178, 284] -> 
             RGBColor[
              0.8796051933703259, 0.9062974078304966, 0.9624991606787607], 
             UndirectedEdge[201, 202] -> 
             RGBColor[
              0.9338317223277781, 0.753780318305715, 0.4299903759066989], 
             UndirectedEdge[24, 65] -> 
             RGBColor[
              0.9201267436511474, 0.8270393789668279, 0.6227334088371315], 
             UndirectedEdge[134, 169] -> 
             RGBColor[
              0.9880966957901012, 0.9893456920553114, 0.8469320857292437], 
             UndirectedEdge[104, 300] -> 
             RGBColor[
              0.9947216280212294, 0.9911184209997077, 0.666859968325807], 
             UndirectedEdge[168, 225] -> 
             RGBColor[
              0.9931653510907014, 0.989744338242269, 0.6395502486322393], 
             UndirectedEdge[27, 202] -> 
             RGBColor[
              0.9317808387042388, 0.7535959291673061, 0.5122230954685925], 
             UndirectedEdge[113, 187] -> 
             RGBColor[
              0.9532873969355427, 0.8605898968924439, 0.5853696617827195], 
             UndirectedEdge[7, 201] -> 
             RGBColor[
              0.9791825377227543, 0.981616611589277, 0.7950935526420035], 
             UndirectedEdge[51, 104] -> 
             RGBColor[
              0.995029478102277, 0.9920091545290439, 0.7172513692257712], 
             UndirectedEdge[2, 183] -> 
             RGBColor[
              0.9835585846663158, 0.985099970697696, 0.8051191321237646], 
             UndirectedEdge[135, 249] -> 
             RGBColor[
              0.9119264751007886, 0.9325148969153862, 0.9881838975937242], 
             UndirectedEdge[84, 270] -> 
             RGBColor[
              0.9667207752317896, 0.9722620202941025, 0.8113773956206206], 
             UndirectedEdge[114, 116] -> 
             RGBColor[
              0.8835874767145974, 0.5313094605076755, 0.22315903001980814`], 
             UndirectedEdge[15, 168] -> 
             RGBColor[
              0.9462017282631656, 0.9569955087535902, 0.8778339843659535], 
             UndirectedEdge[42, 237] -> 
             RGBColor[
              0.9683248725999044, 0.9758973223650453, 0.9385019078787503], 
             UndirectedEdge[40, 140] -> 
             RGBColor[
              0.7452775848954648, 0.7997130595507539, 0.9539858599646487], 
             UndirectedEdge[42, 167] -> 
             RGBColor[
              0.6964573291212202, 0.7595997332138298, 0.9515767336933092], 
             UndirectedEdge[16, 285] -> 
             RGBColor[
              0.9774795778464127, 0.9392532982103099, 0.5492997516511269], 
             UndirectedEdge[8, 286] -> 
             RGBColor[
              0.9495663658677536, 0.8297641620373047, 0.3198918152983804], 
             UndirectedEdge[9, 236] -> 
             RGBColor[
              0.9622849179492199, 0.9709776708846514, 0.9301385978937897], 
             UndirectedEdge[54, 238] -> 
             RGBColor[
              0.9387166244671727, 0.7862662728232263, 0.3049182356636176], 
             UndirectedEdge[165, 183] -> 
             RGBColor[
              0.9571231555159253, 0.8547866388508965, 0.4662334796770297], 
             UndirectedEdge[249, 263] -> 
             RGBColor[
              0.9063980666982414, 0.8321018425868663, 0.6250088781743222], 
             UndirectedEdge[33, 98] -> 
             RGBColor[
              0.9315779563179365, 0.7457780587178865, 0.3277586755800799], 
             UndirectedEdge[282, 293] -> 
             RGBColor[
              0.9693071190427266, 0.9766298801538212, 0.936839220861954], 
             UndirectedEdge[54, 163] -> 
             RGBColor[
              0.8868056003396625, 0.8901305721844073, 0.6765130209531933], 
             UndirectedEdge[145, 237] -> 
             RGBColor[
              0.9856332195115612, 0.9872398240871336, 0.8390731414978838], 
             UndirectedEdge[140, 181] -> 
             RGBColor[
              0.7458457818534259, 0.8001368199116641, 0.9530240507243215], 
             UndirectedEdge[15, 265] -> 
             RGBColor[
              0.9352532827266125, 0.9502962037389412, 0.9620185643183373], 
             UndirectedEdge[144, 230] -> 
             RGBColor[
              0.9847487544756779, 0.9843972314257257, 0.6769157478688886], 
             UndirectedEdge[22, 266] -> 
             RGBColor[
              0.9901500029723358, 0.9888744113379422, 0.7169260749789166], 
             UndirectedEdge[18, 165] -> 
             RGBColor[
              0.9520836072692144, 0.8530942458084618, 0.5782162710952905], 
             UndirectedEdge[17, 140] -> 
             RGBColor[
              0.7015288188380207, 0.7654674050829855, 0.9719476264610407], 
             UndirectedEdge[80, 237] -> 
             RGBColor[
              0.9098406526781879, 0.9298645005029971, 0.9537574741985755], 
             UndirectedEdge[7, 127] -> 
             RGBColor[
              0.9375185731057287, 0.9522898789998216, 0.9687317043661905], 
             UndirectedEdge[60, 212] -> 
             RGBColor[
              0.7634142136869165, 0.8126418852832551, 0.8921065608083565], 
             UndirectedEdge[53, 270] -> 
             RGBColor[
              0.8635445209825966, 0.45093520160760137`, 0.44426999906583264`],
              UndirectedEdge[243, 254] -> 
             RGBColor[
              0.957180879371345, 0.9372724494052744, 0.6649365383128927], 
             UndirectedEdge[201, 277] -> 
             RGBColor[
              0.9840781560782941, 0.9852677557429992, 0.7868065477478365], 
             UndirectedEdge[288, 296] -> 
             RGBColor[
              0.9676785962724849, 0.9026344571799108, 0.32893787921388873`], 
             UndirectedEdge[93, 273] -> 
             RGBColor[
              0.9289355155002981, 0.9416989096166023, 0.7686099803689495], 
             UndirectedEdge[128, 277] -> 
             RGBColor[
              0.8644410076902684, 0.8942906378623368, 0.9528686759065972], 
             UndirectedEdge[3, 115] -> 
             RGBColor[
              0.989284854433861, 0.989150902851395, 0.7779929655562815], 
             UndirectedEdge[74, 123] -> 
             RGBColor[
              0.9820678940512533, 0.9846501186482035, 0.8482120815882093], 
             UndirectedEdge[52, 147] -> 
             RGBColor[
              0.8635647601462999, 0.8932685293813893, 0.9364889147289284], 
             UndirectedEdge[64, 76] -> 
             RGBColor[
              0.7648306139989447, 0.8111311166429338, 0.7222251493446287], 
             UndirectedEdge[132, 260] -> 
             RGBColor[
              0.9741546056396051, 0.9774326470174487, 0.7691572942122082], 
             UndirectedEdge[171, 285] -> 
             RGBColor[
              0.8789806669502567, 0.904078631894569, 0.8821195530413819], 
             UndirectedEdge[226, 290] -> 
             RGBColor[
              0.9447441975435769, 0.8563998102622496, 0.6015235251127482], 
             UndirectedEdge[24, 290] -> 
             RGBColor[
              0.9433635985653739, 0.9569293890365261, 0.9685557646485305], 
             UndirectedEdge[103, 265] -> 
             RGBColor[
              0.9377721837019322, 0.8183827492824405, 0.5878639527706888], 
             UndirectedEdge[41, 208] -> 
             RGBColor[
              0.9429403323868627, 0.8404428919480793, 0.5932405732596253], 
             UndirectedEdge[80, 179] -> 
             RGBColor[
              0.9069131741918397, 0.9276811918411845, 0.9587129316672902], 
             UndirectedEdge[102, 183] -> 
             RGBColor[
              0.9825738937386543, 0.9843655898161294, 0.8067859570157703], 
             UndirectedEdge[16, 220] -> 
             RGBColor[
              0.9752957852274848, 0.9383502438414728, 0.585490846820899], 
             UndirectedEdge[52, 217] -> 
             RGBColor[
              0.9734484012174554, 0.93557977073502, 0.6022377039697653], 
             UndirectedEdge[24, 241] -> 
             RGBColor[
              0.7547777589158513, 0.808342032954932, 0.9765484764247595], 
             UndirectedEdge[105, 163] -> 
             RGBColor[
              0.5886807070611666, 0.6727075200626702, 0.9628865477489172], 
             UndirectedEdge[2, 102] -> 
             RGBColor[
              0.9713043972108453, 0.9781194469413612, 0.9334583498969036], 
             UndirectedEdge[49, 54] -> 
             RGBColor[
              0.92123525081434, 0.9173788825107568, 0.6798513414071055], 
             UndirectedEdge[216, 237] -> 
             RGBColor[
              0.904224691918437, 0.9253864858343656, 0.953221818847883], 
             UndirectedEdge[89, 281] -> 
             RGBColor[
              0.6402094958465778, 0.6633186100754687, 0.6188121247788658], 
             UndirectedEdge[145, 167] -> 
             RGBColor[
              0.713765676032877, 0.7709422349359181, 0.8521479673124428], 
             UndirectedEdge[16, 90] -> 
             RGBColor[
              0.9425624968268871, 0.8078344558291173, 0.2838503689113373], 
             UndirectedEdge[210, 290] -> 
             RGBColor[
              0.9790086880542472, 0.980673348690722, 0.7308316706495155], 
             UndirectedEdge[152, 242] -> 
             RGBColor[
              0.9757659231342015, 0.9383422775338368, 0.5763005991490008], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.9719039047403152, 0.9137416564620997, 0.4571624706135261], 
             UndirectedEdge[77, 282] -> 
             RGBColor[
              0.9810640549719587, 0.9635422768156454, 0.6424628480548364], 
             UndirectedEdge[81, 162] -> 
             RGBColor[
              0.9712873282364625, 0.9416396605743468, 0.6279955911938485], 
             UndirectedEdge[34, 247] -> 
             RGBColor[
              0.9857755190243781, 0.9864536542237342, 0.7775863299573593], 
             UndirectedEdge[7, 60] -> 
             RGBColor[
              0.9765615705038706, 0.9811964782337131, 0.886774032707804], 
             UndirectedEdge[155, 162] -> 
             RGBColor[
              0.9787952872160792, 0.946279098368463, 0.5722964531354996], 
             UndirectedEdge[234, 249] -> 
             RGBColor[
              0.8676351295820273, 0.8972927172732531, 0.9872370072781993], 
             UndirectedEdge[118, 234] -> 
             RGBColor[
              0.8687565252759686, 0.7312035856778742, 0.6064136177253017], 
             UndirectedEdge[223, 271] -> 
             RGBColor[
              0.9221699692299024, 0.7291368938565151, 0.2562343342179987], 
             UndirectedEdge[154, 216] -> 
             RGBColor[
              0.8892284278913519, 0.8490508250734947, 0.6302322529388293], 
             UndirectedEdge[147, 247] -> 
             RGBColor[
              0.8682574680203301, 0.8944463095714204, 0.8032729024679524], 
             UndirectedEdge[4, 286] -> 
             RGBColor[
              0.9437267218707637, 0.8416934192994678, 0.592424616663572], 
             UndirectedEdge[88, 124] -> 
             RGBColor[
              0.8295525587633161, 0.8670568220621403, 0.9504698105710747], 
             UndirectedEdge[23, 136] -> 
             RGBColor[
              0.6207278969361103, 0.6862719357151607, 0.886745161762702], 
             UndirectedEdge[11, 104] -> 
             RGBColor[
              0.9847985239145205, 0.9861766463298121, 0.8150753111195582], 
             UndirectedEdge[4, 121] -> 
             RGBColor[
              0.9830692871029096, 0.9847396131710988, 0.8063091855027564], 
             UndirectedEdge[4, 213] -> 
             RGBColor[
              0.963659106124273, 0.9724176013670109, 0.946399833495204], 
             UndirectedEdge[198, 204] -> 
             RGBColor[
              0.9361000905132808, 0.7711445193031656, 0.3112018060150592], 
             UndirectedEdge[156, 168] -> 
             RGBColor[
              0.9621779284189355, 0.8784357611684601, 0.5145074316223057], 
             UndirectedEdge[31, 226] -> 
             RGBColor[
              0.9348014236843535, 0.8489845057978389, 0.6183540477656715], 
             UndirectedEdge[36, 242] -> 
             RGBColor[
              0.6078951258687421, 0.6350609319497731, 0.6244330879907385], 
             UndirectedEdge[216, 269] -> 
             RGBColor[
              0.8647544708207364, 0.7504299338360833, 0.6104576935377637], 
             UndirectedEdge[97, 202] -> 
             RGBColor[
              0.93343005727458, 0.7529211973714904, 0.38627161365544943`], 
             UndirectedEdge[23, 59] -> 
             RGBColor[
              0.6183766422596579, 0.6704175479134158, 0.6651517999011624], 
             UndirectedEdge[174, 238] -> 
             RGBColor[
              0.934632585654072, 0.8047572907376518, 0.5856291769796667], 
             UndirectedEdge[86, 97] -> 
             RGBColor[
              0.9157419787048304, 0.9312179869564627, 0.7705329325498995], 
             UndirectedEdge[46, 212] -> 
             RGBColor[
              0.7558931462123188, 0.8078764454170732, 0.9426230603286905], 
             UndirectedEdge[59, 291] -> 
             RGBColor[
              0.971574937752728, 0.9157777318972562, 0.34407443010228467`], 
             UndirectedEdge[125, 149] -> 
             RGBColor[
              0.9004248335595034, 0.6329653096029872, 0.44189865360797853`], 
             UndirectedEdge[32, 80] -> 
             RGBColor[
              0.9111974414891424, 0.9308763913766691, 0.9514607846488257], 
             UndirectedEdge[69, 90] -> 
             RGBColor[
              0.9418648205091813, 0.8495352344793288, 0.6027377602008517], 
             UndirectedEdge[215, 229] -> 
             RGBColor[
              0.9281776055847948, 0.7594197440971503, 0.569570212134846], 
             UndirectedEdge[187, 245] -> 
             RGBColor[
              0.9541377180060349, 0.8639611365842457, 0.5860538500756383], 
             UndirectedEdge[98, 275] -> 
             RGBColor[
              0.8753041964023944, 0.706048278363606, 0.6010410771618888], 
             UndirectedEdge[252, 280] -> 
             RGBColor[
              0.8856638862236152, 0.57370823586681, 0.22630748284142838`], 
             UndirectedEdge[96, 146] -> 
             RGBColor[
              0.9710601738402829, 0.9768861230102788, 0.8867976544730352], 
             UndirectedEdge[191, 270] -> 
             RGBColor[
              0.9663475376596666, 0.9714637028674388, 0.7707527892503405], 
             UndirectedEdge[40, 120] -> 
             RGBColor[
              0.9417027043403405, 0.9557137668169565, 0.9721670758216163], 
             UndirectedEdge[215, 233] -> 
             RGBColor[
              0.6809993809914613, 0.7449915589522003, 0.9327971356887457], 
             UndirectedEdge[21, 257] -> 
             RGBColor[
              0.9119116262223557, 0.8526066740874321, 0.6291418872725087], 
             UndirectedEdge[200, 245] -> 
             RGBColor[
              0.9500119679930763, 0.8339320899029568, 0.3077445338829823], 
             UndirectedEdge[41, 108] -> 
             RGBColor[
              0.953770696333342, 0.847255448898466, 0.5182712608673787], 
             UndirectedEdge[63, 73] -> 
             RGBColor[
              0.9550552804560034, 0.9036049267176076, 0.6147274070497073]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.993618204652484, 0.9916289778662121, 0.7554263946726746], 160 -> 
             RGBColor[
              0.9873137050138996, 0.9688682895074777, 0.40521656889513014`], 
             245 -> RGBColor[
              0.9251608709075241, 0.7409948223493834, 0.2586408839132985], 
             155 -> RGBColor[
              0.9899703009211988, 0.9901204759264759, 0.8158815999723069], 
             213 -> RGBColor[
              0.956014265491007, 0.9667160917399988, 0.9593405545935535], 27 -> 
             RGBColor[
              0.9904108873721715, 0.9903026697465085, 0.8085799422785023], 19 -> 
             RGBColor[
              0.9943443294243139, 0.9903114174516452, 0.6257933444685859], 
             164 -> RGBColor[
              0.9377430807615897, 0.9530894720851186, 0.9902689044522743], 
             190 -> RGBColor[
              0.9733137207976899, 0.9216430553935864, 0.3508292738903356], 
             103 -> RGBColor[
              0.9044250132127789, 0.6587840564046766, 0.24195632607896939`], 
             138 -> RGBColor[
              0.9935513202760071, 0.9916013194576888, 0.7565348418821152], 
             291 -> RGBColor[
              0.959083297500455, 0.8736404961497284, 0.2955467665705276], 28 -> 
             RGBColor[
              0.9951182640522156, 0.9919667853639329, 0.7100313525448074], 
             195 -> 
             RGBColor[
              0.9849588846307277, 0.9609249274169192, 0.39606853637702283`], 
             114 -> RGBColor[
              0.9559274614040834, 0.8629741013097256, 0.2833964048115274], 93 -> 
             RGBColor[
              0.8642202151572859, 0.894569757206347, 0.9869112896918374], 34 -> 
             RGBColor[
              0.9771532237070361, 0.982481492165646, 0.9235578122571141], 161 -> 
             RGBColor[
              0.944400669668272, 0.9580546909909209, 0.9789993430105421], 22 -> 
             RGBColor[
              0.9865485455586898, 0.9887054921489767, 0.8725889415480982], 
             124 -> RGBColor[
              0.9724402617572168, 0.9789665728602377, 0.9315356275008166], 84 -> 
             RGBColor[
              0.994425612467265, 0.9904852736615414, 0.6346405020730199], 46 -> 
             RGBColor[
              0.9742285852322875, 0.9803003015798345, 0.9285084623269841], 
             241 -> RGBColor[
              0.5875010930058864, 0.6759988797816315, 0.9606693846102887], 
             185 -> RGBColor[
              0.9517020568787659, 0.8462217803994306, 0.2799965451474653], 
             121 -> RGBColor[
              0.9948346274482802, 0.9913601153481748, 0.6791592586086587], 
             126 -> RGBColor[
              0.9680428114168593, 0.9756869615965631, 0.9389793638883073], 
             236 -> RGBColor[
              0.9866903288523134, 0.9887641231845545, 0.8702392254493517], 78 -> 
             RGBColor[
              0.8284581634632378, 0.21974749159099885`, 0.17488487551228213`],
              254 -> RGBColor[
              0.9723041967326372, 0.9182376936746414, 0.3469074635302294], 
             290 -> RGBColor[
              0.9646727723049314, 0.9731735919448199, 0.9446839610578309], 
             251 -> RGBColor[
              0.9048633305250109, 0.9269774741725939, 0.9907878663181484], 
             165 -> RGBColor[
              0.9194182298377258, 0.718227164129329, 0.2540202201114282], 100 -> 
             RGBColor[
              0.9877480680992893, 0.9892015255458377, 0.8527097487855385], 
             235 -> RGBColor[
              0.9945815709457877, 0.9908188530772805, 0.6516156199960551], 70 -> 
             RGBColor[
              0.5663798464507115, 0.6588517003268265, 0.9590066427117899], 
             234 -> RGBColor[
              0.8507823466624439, 0.8838547656297833, 0.9856295737986726], 
             257 -> RGBColor[
              0.8853432765849691, 0.9114127130185536, 0.9889260261475894], 
             135 -> RGBColor[
              0.9393650376999667, 0.9542991249140494, 0.9875233544297223], 
             265 -> RGBColor[
              0.9711193541910853, 0.9779814421602044, 0.9337715794624083], 
             111 -> RGBColor[
              0.9927248265936988, 0.9868474646538127, 0.44952045576906047`], 
             182 -> RGBColor[
              0.9918361284993545, 0.9908920435796249, 0.7849600083952779], 
             188 -> RGBColor[
              0.9951437819620697, 0.9920213655928543, 0.7128088195541336], 
             154 -> RGBColor[
              0.9476557063164683, 0.8301793487863136, 0.27674075650498575`], 
             269 -> RGBColor[
              0.8987077921752374, 0.6329375663114906, 0.23719163770285456`], 
             208 -> RGBColor[
              0.9701437595940023, 0.9772538453070895, 0.9354230066394473], 86 -> 
             RGBColor[
              0.8377746328968069, 0.8734827677580485, 0.9843888864475829], 
             119 -> RGBColor[
              0.9166681838236366, 0.7073241480819744, 0.25180746853661556`], 
             140 -> RGBColor[
              0.5300988132070639, 0.6293971230977116, 0.9561504668730462], 85 -> 
             RGBColor[
              0.9863444935260909, 0.9886211113895991, 0.8759706117979938], 
             242 -> RGBColor[
              0.9631035452231693, 0.8872017357174987, 0.311164669813194], 117 -> 
             RGBColor[
              0.9447997030439771, 0.9583522894291646, 0.9783238835900457], 47 -> 
             RGBColor[
              0.9931814167444729, 0.9878240648179731, 0.4992174759330471], 81 -> 
             RGBColor[
              0.9749543829619653, 0.9808416003382434, 0.9272798760890049], 
             275 -> RGBColor[
              0.8801069428378722, 0.9072374026251115, 0.988426579960261], 23 -> 
             RGBColor[
              0.2526867065143148, 0.38292012818204746`, 0.937701506168283], 
             110 -> RGBColor[
              0.9595714240743407, 0.9693690147871364, 0.9533192129675141], 6 -> 
             RGBColor[
              0.7377588447282768, 0.795062083767404, 0.9744965649602781], 218 -> 
             RGBColor[
              0.9618449495502663, 0.9710646063645254, 0.9494707273671836], 
             108 -> RGBColor[
              0.9918044874869609, 0.9908789592078632, 0.7854843818549541], 
             297 -> RGBColor[
              0.9932168983936224, 0.9914630274150723, 0.7620770779293186], 
             157 -> RGBColor[
              0.9932100336562629, 0.9878852734986782, 0.5023322501782769], 
             270 -> RGBColor[
              0.9390159379963141, 0.9540387669266636, 0.9881142891682213], 
             33 -> 
             RGBColor[
              0.9926544626689563, 0.9866969633336725, 0.4418617767966432], 
             252 -> RGBColor[
              0.8736962775206848, 0.5193661198528288, 0.21632141678677017`], 
             260 -> RGBColor[
              0.9544198297833166, 0.9655269641998522, 0.9620395183512397], 
             159 -> RGBColor[
              0.9743004210467056, 0.9249714270217522, 0.35466241803505444`], 
             183 -> RGBColor[
              0.9948280811941248, 0.991346113572464, 0.6784467392426312], 99 -> 
             RGBColor[
              0.9644797903164588, 0.9730296662937961, 0.9450106292265514], 17 -> 
             RGBColor[
              0.8729588244689775, 0.9015376870682593, 0.9877447860490352], 
             277 -> RGBColor[
              0.9736436575373378, 0.9798640634626722, 0.9294985923409581], 
             104 -> RGBColor[
              0.995046200373089, 0.9918126484410367, 0.7021876657973474], 79 -> 
             RGBColor[
              0.9943206653139558, 0.9902608023123977, 0.6232176520940607], 
             191 -> RGBColor[
              0.9936791373230193, 0.988888638808214, 0.5533912893324597], 50 -> 
             RGBColor[
              0.9683091169593964, 0.9758855718341519, 0.9385285780684014], 
             225 -> RGBColor[
              0.9933144569172112, 0.9881086242950355, 0.5136980777068381], 61 -> 
             RGBColor[
              0.9933144569172112, 0.9881086242950355, 0.5136980777068381], 
             196 -> RGBColor[
              0.9906175454361588, 0.980012919030379, 0.41805136505769463`], 1 -> 
             RGBColor[
              0.9706973731563581, 0.9128175004517345, 0.34066525735955605`], 
             263 -> RGBColor[
              0.9283082208948724, 0.7534730162570097, 0.2611733155909183], 
             201 -> RGBColor[
              0.9945126546192502, 0.9906714480233262, 0.6441145031547151], 
             293 -> RGBColor[
              0.9552283828963357, 0.9661299817876576, 0.9606708488353243], 
             184 -> RGBColor[
              0.9850436666732398, 0.9880831860562199, 0.8975286791817167], 
             106 -> RGBColor[
              0.8654576611393997, 0.8955564630429083, 0.9870293183942925], 
             206 -> RGBColor[
              0.9872224651740606, 0.9889841752288767, 0.8614203494733451], 
             247 -> RGBColor[
              0.9943978143417201, 0.9904258162818225, 0.6316148476576046], 
             220 -> RGBColor[
              0.9873512682692915, 0.9890374386188432, 0.859285748853643], 107 -> 
             RGBColor[
              0.9810173635527558, 0.9853633613356354, 0.9170168314273913], 
             131 -> RGBColor[
              0.9388095092925555, 0.9538848127373963, 0.9884637191184561], 
             127 -> RGBColor[
              0.911184725385199, 0.9320179828444155, 0.991390806603089], 210 -> 
             RGBColor[
              0.9933446038035629, 0.988173105436624, 0.5169793802412002], 181 -> 
             RGBColor[
              0.9615927504997879, 0.9708765167256167, 0.9498976345755967], 
             194 -> RGBColor[
              0.9536123718630293, 0.9649247634049929, 0.9634063339915322], 
             118 -> RGBColor[
              0.8867307038894932, 0.5785524057259651, 0.22719766165193075`], 
             276 -> RGBColor[
              0.6377555463392692, 0.7167977089349947, 0.9646255992648208], 
             280 -> RGBColor[
              0.8976314949265458, 0.6280503518807912, 0.2362935488960866], 
             189 -> RGBColor[
              0.8624733828797931, 0.8931768805647733, 0.9867446752697946], 
             168 -> RGBColor[
              0.9930162452641915, 0.9913800521895025, 0.7654024195576405], 41 -> 
             RGBColor[
              0.9157369051797231, 0.703631938589069, 0.25105813987980347`], 
             14 -> RGBColor[
              0.9541216957183908, 0.9653046163023802, 0.9625441815573417], 77 -> 
             RGBColor[
              0.9787422547547999, 0.9399547751113061, 0.3719181032210891], 51 -> 
             RGBColor[
              0.9950127558314652, 0.9922056606170513, 0.7323150726541948], 
             179 -> RGBColor[
              0.9717932773979421, 0.9784840529844302, 0.9326308032605226], 
             223 -> RGBColor[
              0.9394904047681475, 0.797806649072664, 0.270170763214946], 292 -> 
             RGBColor[
              0.9690454490791875, 0.976434727123459, 0.9372821598557691], 143 -> 
             RGBColor[
              0.9387639691431051, 0.9538508489685015, 0.9885408067127023], 
             112 -> RGBColor[0.178927, 0.305394, 0.933501], 197 -> 
             RGBColor[
              0.4940900286344121, 0.6001635696043741, 0.9533157234469629], 54 -> 
             RGBColor[
              0.9789850918593285, 0.9407739216857445, 0.3728614795162432], 71 -> 
             RGBColor[
              0.9880627253487139, 0.9893316444047973, 0.8474950638557149], 
             177 -> RGBColor[
              0.9404621780855071, 0.8016594064517335, 0.270952674836545], 158 -> 
             RGBColor[
              0.9555062195723367, 0.9663371919257033, 0.9602005438142651], 
             226 -> 
             RGBColor[
              0.9248156227822222, 0.7396260285796793, 0.2583630891676656], 
             203 -> RGBColor[
              0.898448157075017, 0.631758623960708, 0.236974991810992], 115 -> 
             RGBColor[
              0.984057054248472, 0.9876303576794638, 0.9118714279578479], 173 -> 
             RGBColor[
              0.9893771479959044, 0.9898751919485318, 0.8257116789749976], 
             212 -> RGBColor[
              0.5375577071923501, 0.6354525892543118, 0.9567376583303968], 
             129 -> RGBColor[
              0.9879121312842951, 0.9892693698890692, 0.8499907972280789], 
             279 -> RGBColor[
              0.94790683895955, 0.9606695863075307, 0.9730643129558157], 26 -> 
             RGBColor[
              0.9947954533266518, 0.9912763258631228, 0.6748953972240551], 40 -> 
             RGBColor[
              0.9604563565838657, 0.9700289960037962, 0.9518212530562512], 
             146 -> RGBColor[
              0.9905192285423858, 0.9903474716046331, 0.8067844487100907], 
             192 -> RGBColor[
              0.7684308552361521, 0.81902329149207, 0.9775536643214685], 300 -> 
             RGBColor[
              0.99439705566937, 0.9904241935583789, 0.6315322708542667], 221 -> 
             RGBColor[
              0.9947988870420619, 0.991283670233183, 0.6752691359560034], 62 -> 
             RGBColor[
              0.8795116369775376, 0.5457723089346893, 0.22117389526507253`], 
             286 -> RGBColor[
              0.9161494969839884, 0.7052677276049129, 0.2513901209302898], 
             152 -> RGBColor[
              0.9884283010452336, 0.989482819350175, 0.8414365284848075], 64 -> 
             RGBColor[
              0.5365848079768778, 0.6346627458425812, 0.9566610681403076], 37 -> 
             RGBColor[
              0.9153858748964605, 0.9353678654275299, 0.9917915159938835], 
             148 -> RGBColor[
              0.9887175546941731, 0.9736038041186205, 0.4106702598082257], 
             261 -> RGBColor[
              0.9926340183645681, 0.9866532350338226, 0.4396365404316204], 15 -> 
             RGBColor[
              0.8993872112621397, 0.922610965317678, 0.9902655491742663], 136 -> 
             RGBColor[
              0.9887690873579059, 0.9896237432482738, 0.835788817357121], 198 -> 
             RGBColor[
              0.9845364342832047, 0.9594999031986658, 0.3944273965499505], 63 -> 
             RGBColor[
              0.9493678086466156, 0.8369672640010674, 0.27811835422802916`], 
             171 -> RGBColor[
              0.7662424803933658, 0.8173137164326205, 0.9773355475686651], 
             59 -> 
             RGBColor[
              0.984066578005001, 0.957914967644784, 0.3926020936340418], 229 -> 
             RGBColor[
              0.8770917544890036, 0.5347841877321705, 0.21915468599989205`], 
             102 -> RGBColor[
              0.9703197062831838, 0.9773850660597947, 0.9351251747889092], 
             299 -> RGBColor[
              0.9476361286213913, 0.9604676909805795, 0.9735225549457542], 
             128 -> RGBColor[
              0.7552383578431991, 0.8087172122620013, 0.9762387594722364], 12 -> 
             RGBColor[
              0.3196016126423582, 0.4512445860518547, 0.9415857100383297], 
             222 -> RGBColor[
              0.888450149577015, 0.9138900492085902, 0.9892223624671089], 92 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 271 -> 
             RGBColor[
              0.9048495336916573, 0.6604671386403663, 0.24229790522105138`], 
             132 -> RGBColor[
              0.9938893814958935, 0.9893383298350452, 0.5762750700731769], 80 -> 
             RGBColor[
              0.8420330709857372, 0.8768783306979389, 0.9847950600740577], 
             244 -> RGBColor[
              0.98793969383928, 0.9892807677138808, 0.8495340143623734], 150 -> 
             RGBColor[
              0.9938204318853203, 0.9891908535899043, 0.5687703304699648], 
             125 -> RGBColor[
              0.8598671596296756, 0.4565713253822993, 0.20478206183581352`], 
             258 -> RGBColor[
              0.9779340990562928, 0.9830638677225556, 0.9222359939757315], 
             133 -> RGBColor[
              0.4379433617801932, 0.5537462611257891, 0.9491263416478927], 
             255 -> RGBColor[
              0.9605680507484324, 0.9701122973288476, 0.9516321839701435], 
             176 -> RGBColor[
              0.9941730189298282, 0.9899450016260881, 0.607147254349639], 230 -> 
             RGBColor[
              0.9925448777322997, 0.9864625722349009, 0.42993413272141306`], 
             274 -> RGBColor[
              0.8584023970541089, 0.8899307869713392, 0.9863563810075289], 87 -> 
             RGBColor[
              0.9924538741557608, 0.9911474972838882, 0.7747223641941132], 
             130 -> RGBColor[
              0.8403343942829156, 0.31103340586857225`, 0.18625756755748993`],
              35 -> RGBColor[
              0.9189349690295883, 0.7163111960621815, 0.25363137712161166`], 
             31 -> RGBColor[
              0.9447872245864848, 0.9583429830159984, 0.9783450063636773], 18 -> 
             RGBColor[
              0.9847489847007029, 0.9879613274875946, 0.9024123220791529], 24 -> 
             RGBColor[
              0.9220544248258162, 0.9406851861282324, 0.9924275682392303], 
             151 -> RGBColor[
              0.8832721145598563, 0.5628477593541447, 0.22431172993749957`], 
             137 -> RGBColor[
              0.9950850813622847, 0.9922355690827266, 0.7311164514360415], 
             296 -> RGBColor[
              0.9705052201691957, 0.912169323306369, 0.3399187792894772], 266 -> 
             RGBColor[
              0.9937514603859819, 0.9890433305269077, 0.561263208409735], 283 -> 
             RGBColor[
              0.9406975221900373, 0.955292889665001, 0.985267805755647], 284 -> 
             RGBColor[
              0.9645842779206555, 0.9731075929779232, 0.9448337589673781], 
             238 -> RGBColor[
              0.898448157075017, 0.631758623960708, 0.236974991810992], 72 -> 
             RGBColor[
              0.9897613598981996, 0.9900340734439264, 0.8193442934454371], 
             288 -> RGBColor[
              0.964851972375774, 0.8930995910534524, 0.31795697913830023`], 
             172 -> RGBColor[
              0.995142424168111, 0.992018461408871, 0.7126610320610799], 243 -> 
             RGBColor[
              0.9420575620100528, 0.9563072051359076, 0.9829656130955561], 88 -> 
             RGBColor[
              0.6866648557694154, 0.7551470712640429, 0.9694039936413327], 
             273 -> RGBColor[
              0.9936508158433104, 0.9888280620268576, 0.5503086710460616], 
             202 -> RGBColor[
              0.873150790036306, 0.5168891885881037, 0.21586624865868276`], 
             98 -> RGBColor[
              0.8705014499669166, 0.5048591541021005, 0.21365557436351662`], 
             30 -> RGBColor[
              0.9719664687388917, 0.9786132188029357, 0.9323376354958309], 
             116 -> RGBColor[
              0.8474174843698543, 0.36547714010665033`, 0.19304034262394848`],
              240 -> RGBColor[
              0.956014265491007, 0.9667160917399988, 0.9593405545935535], 73 -> 
             RGBColor[
              0.9607427522653912, 0.970242589434148, 0.9513364598713855], 29 -> 
             RGBColor[
              0.9014085332944649, 0.6452010009597884, 0.23944520229396066`], 
             75 -> RGBColor[
              0.990545964703397, 0.9903585276942992, 0.8063413613311693], 200 -> 
             RGBColor[
              0.9748630650786286, 0.9268693574565301, 0.35684818385266603`], 
             156 -> RGBColor[
              0.9313396115736794, 0.7654914701474178, 0.26361244368697084`], 
             25 -> RGBColor[
              0.9629848248609555, 0.8868012640588847, 0.3107034636244522], 38 -> 
             RGBColor[
              0.9635202536945403, 0.8886073912392349, 0.31278350353567824`], 
             3 -> RGBColor[
              0.9945126546192502, 0.9906714480233262, 0.6441145031547151], 57 -> 
             RGBColor[
              0.9913308508336662, 0.990683098279819, 0.7933337669324151], 227 -> 
             RGBColor[
              0.9933925020573667, 0.988275554958254, 0.5221928095739897], 39 -> 
             RGBColor[
              0.9820164622945995, 0.9861084875414284, 0.915325617864135], 109 -> 
             RGBColor[
              0.6623142913675929, 0.7361242252821952, 0.9669769569507213], 
             256 -> RGBColor[0.178927, 0.305394, 0.933501], 287 -> 
             RGBColor[
              0.9554942996598426, 0.8612567593364054, 0.2830478727044984], 
             239 -> RGBColor[
              0.8983864951460401, 0.9218130214504154, 0.990170099977763], 285 -> 
             RGBColor[
              0.9917188535071475, 0.9908435473565175, 0.7869035585140988], 
             216 -> RGBColor[
              0.8308011494662355, 0.8679223013606759, 0.9837237493726729], 21 -> 
             RGBColor[
              0.9384799758597422, 0.7938006351563105, 0.26935774839742826`], 
             175 -> RGBColor[
              0.9841442795170753, 0.9876954101419699, 0.9117237783300962], 7 -> 
             RGBColor[
              0.9638524208262583, 0.9725617751552278, 0.9460726021292919], 13 -> 
             RGBColor[
              0.9952314060149147, 0.9922087845817391, 0.7223461569533463], 
             294 -> RGBColor[
              0.9935697137773072, 0.9886545929083534, 0.5414812116655454], 
             193 -> RGBColor[
              0.9403645614115015, 0.9550445680615421, 0.985831421503629], 60 -> 
             RGBColor[
              0.989270720181483, 0.9898311813121985, 0.8274754632863162], 65 -> 
             RGBColor[
              0.9181990624764786, 0.7133935718054234, 0.2530392494350327], 69 -> 
             RGBColor[
              0.9618449495502663, 0.9710646063645254, 0.9494707273671836], 
             217 -> RGBColor[
              0.9618844038412512, 0.8830892855682796, 0.30642853575997386`], 
             214 -> RGBColor[
              0.9930484424955105, 0.9875396463452013, 0.4847440495554223], 
             170 -> RGBColor[
              0.9948800212764489, 0.9921507714674297, 0.7345148277368305], 74 -> 
             RGBColor[
              0.9932010264778748, 0.9914564639700211, 0.7623401166484566], 
             246 -> 
             RGBColor[
              0.9668099328599391, 0.8997042515175253, 0.3255632858894695], 
             264 -> RGBColor[
              0.9949321689735847, 0.99156874680784, 0.6897760516815329], 278 -> 
             RGBColor[
              0.9846258508873744, 0.9598015264005472, 0.3947747631722408], 45 -> 
             RGBColor[
              0.9938343919521555, 0.9892207127612855, 0.570289797593434], 237 -> 
             RGBColor[
              0.9776482343706385, 0.9828506703080552, 0.9227198883230932], 
             228 -> RGBColor[
              0.9569732182312707, 0.9674312771235465, 0.9577172977392182], 
             180 -> RGBColor[
              0.6614869407863253, 0.7354778927200116, 0.9668944943768112], 53 -> 
             RGBColor[
              0.8258088124757379, 0.19938341894807032`, 0.1723478540146384], 
             48 -> RGBColor[
              0.9944400008340147, 0.990516048923132, 0.636206586999023], 5 -> 
             RGBColor[
              0.9933717668096647, 0.9882312043600743, 0.519935905824727], 101 -> 
             RGBColor[
              0.993163294149753, 0.9914408606826661, 0.7629654389735708], 267 -> 
             RGBColor[
              0.9536552380800619, 0.8539654930035175, 0.28156812058908337`], 
             120 -> RGBColor[
              0.9229490520968153, 0.9413985376301168, 0.9925128985869813], 
             147 -> RGBColor[
              0.7421171216989402, 0.7984668028610181, 0.9749309572783], 89 -> 
             RGBColor[
              0.9591830801806088, 0.8739770865599747, 0.29593440344054733`], 
             43 -> RGBColor[
              0.987854174923053, 0.989245403444285, 0.8509512841201157], 199 -> 
             RGBColor[
              0.9173252858652635, 0.936914299090145, 0.9919764987434205], 268 -> 
             RGBColor[
              0.9508314774342986, 0.9628507768933422, 0.9681136628859456], 
             169 -> RGBColor[
              0.9883789284951238, 0.989462402531888, 0.8422547594121913], 20 -> 
             RGBColor[
              0.9723041967326372, 0.9182376936746414, 0.3469074635302294], 4 -> 
             RGBColor[
              0.971303946757539, 0.9781191109940229, 0.9334591123968543], 167 -> 
             RGBColor[
              0.43391314741327, 0.5502554920056241, 0.948869539952211], 142 -> 
             RGBColor[
              0.9926912367384962, 0.9912456528117893, 0.7707886519235145], 16 -> 
             RGBColor[
              0.963240302185678, 0.8876630490641024, 0.311695944788155], 281 -> 
             RGBColor[
              0.3212359115125469, 0.4526601335909625, 0.9416898461171844], 
             289 -> 
             RGBColor[
              0.9945871223038139, 0.9908307268707698, 0.6522198510581825], 
             178 -> RGBColor[
              0.7946261088199965, 0.8394872226830702, 0.9801645623901434], 58 -> 
             RGBColor[
              0.945528388311731, 0.8217452417842318, 0.2750290665038027], 186 -> 
             RGBColor[0.9457263241529771, 0.9590433619350539, 0.976755355754],
              122 -> RGBColor[
              0.9671815560015979, 0.9009578236356035, 0.3270069716196722], 
             249 -> RGBColor[
              0.8844879125016105, 0.9107306689167229, 0.988844440757726], 113 -> 
             RGBColor[
              0.9234602287665399, 0.7342523429657801, 0.25727250732746104`], 
             52 -> RGBColor[
              0.9850123985936596, 0.9880702559017605, 0.8980468721795566], 
             187 -> RGBColor[
              0.9831145651045455, 0.9869274508191078, 0.9134668162379781], 
             259 -> RGBColor[
              0.994757166868295, 0.9911944350000522, 0.6707281525085467], 42 -> 
             RGBColor[
              0.9590015108291703, 0.9689439744220356, 0.9542839274344075], 
             134 -> RGBColor[
              0.9878144630850785, 0.989228981578735, 0.8516094120462963], 248 -> 
             RGBColor[
              0.9937399392595413, 0.9916793182546669, 0.7534089371946713], 
             174 -> RGBColor[
              0.9708170142331272, 0.9777559575145955, 0.9342833621483414], 
             215 -> RGBColor[
              0.9792634566805859, 0.9840553004621301, 0.9199857382698001], 83 -> 
             RGBColor[
              0.9888564132570619, 0.9896598547517481, 0.8343416012159233], 95 -> 
             RGBColor[
              0.9505892540377119, 0.8418098879542159, 0.27910115786071343`], 
             166 -> RGBColor[
              0.983663753406576, 0.956556145686583, 0.39103719613620314`], 
             233 -> RGBColor[
              0.38273530530233674`, 0.5059278174422703, 0.9456085331076912], 
             295 -> RGBColor[
              0.9871361191580154, 0.9889484689322505, 0.8628513264155415], 
             141 -> RGBColor[
              0.9793734998922826, 0.9420841131834419, 0.37437037137956763`], 
             205 -> RGBColor[
              0.9413309064572211, 0.8051036249590101, 0.2716516740761017], 
             224 -> RGBColor[
              0.981919075789717, 0.9860358568455428, 0.9154904678144327], 231 -> 
             RGBColor[
              0.9089989351733249, 0.9302750930611619, 0.9911823239814025], 68 -> 
             RGBColor[
              0.2526867065143148, 0.38292012818204746`, 0.937701506168283], 
             10 -> RGBColor[
              0.9928218043075682, 0.9870548901778284, 0.4600758814466657], 
             250 -> RGBColor[
              0.947597236398896, 0.9604386852247226, 0.9735883893337227], 282 -> 
             RGBColor[
              0.9833858551891175, 0.9871297785199848, 0.9130075928885839], 
             232 -> RGBColor[
              0.6064260355917249, 0.691363000731763, 0.9621592254149949], 253 -> 
             RGBColor[
              0.9580745506797886, 0.870237756258604, 0.29162797565809195`], 
             55 -> RGBColor[
              0.9932819478077817, 0.9914899270195209, 0.7609990407942114], 91 -> 
             RGBColor[
              0.994316391558113, 0.9902516611807931, 0.6227524801451472], 105 -> 
             RGBColor[
              0.38273530530233674`, 0.5059278174422703, 0.9456085331076912], 
             36 -> RGBColor[
              0.2526867065143148, 0.38292012818204746`, 0.937701506168283], 
             123 -> RGBColor[
              0.9709347616246319, 0.9778437733263861, 0.9340840465279621], 94 -> 
             RGBColor[
              0.868009954191515, 0.8975915922425157, 0.9872727583840621], 96 -> 
             RGBColor[
              0.9516011191381799, 0.9634247744159243, 0.9668108602359796], 2 -> 
             RGBColor[
              0.9722890881385069, 0.9788538278229278, 0.931791525004898], 262 -> 
             RGBColor[
              0.9833858551891175, 0.9871297785199848, 0.9130075928885839], 
             272 -> RGBColor[
              0.9409500066113313, 0.9554811921329968, 0.9848404154888798], 97 -> 
             RGBColor[
              0.9937093245128539, 0.9889532061548771, 0.5566769786522161], 
             209 -> RGBColor[
              0.7155108157898694, 0.7776817544694377, 0.9722790893553489], 66 -> 
             RGBColor[
              0.8940100579724116, 0.9183233692433865, 0.9897526714932507], 
             139 -> RGBColor[
              0.995142424168111, 0.992018461408871, 0.7126610320610799], 56 -> 
             RGBColor[
              0.991038006747054, 0.9814312337610395, 0.4196847778530668], 144 -> 
             RGBColor[
              0.9769526312190562, 0.9823318906165506, 0.9238973630163643], 
             298 -> RGBColor[
              0.9936973422073552, 0.9889275772150123, 0.5553727786448983], 
             204 -> RGBColor[
              0.8876637467433569, 0.5827891354076655, 0.2279762154801679], 
             207 -> RGBColor[
              0.46409781087349233`, 0.5758145360920468, 0.9509546261997096], 
             149 -> 
             RGBColor[
              0.9815401814191591, 0.9857532780443633, 0.9161318371523086], 
             219 -> RGBColor[
              0.9831573019368602, 0.986959323878673, 0.9133944739284202], 9 -> 
             RGBColor[
              0.9378795070461262, 0.9531912185847483, 0.9900379703382278], 11 -> 
             RGBColor[
              0.9745508474559521, 0.9805406442185876, 0.9279629564417691], 44 -> 
             RGBColor[
              0.9927741489058297, 0.98695296009221, 0.45488888506248304`], 
             153 -> RGBColor[
              0.9820700563226886, 0.9511802312047605, 0.3848459839097418], 32 -> 
             RGBColor[
              0.9803618119925476, 0.9848744520553994, 0.9181265092235937], 
             162 -> RGBColor[
              0.9676202735109596, 0.9024377208104502, 0.3287113062986922], 90 -> 
             RGBColor[
              0.9218846914680962, 0.728005862594132, 0.2560047930345196], 8 -> 
             RGBColor[
              0.9829832347515188, 0.9542605964696966, 0.38839350966647107`], 
             163 -> RGBColor[
              0.7946261088199965, 0.8394872226830702, 0.9801645623901434], 49 -> 
             RGBColor[
              0.8634854097693516, 0.8939838433357692, 0.9868412032979677], 76 -> 
             RGBColor[
              0.9930764200210116, 0.9875994874432865, 0.48778923054894974`], 
             82 -> RGBColor[
              0.8430112077348887, 0.8776582703908975, 0.9848883556303847], 67 -> 
             RGBColor[
              0.9877498182957593, 0.9703394020114586, 0.4069107866420723], 
             211 -> RGBColor[
              0.847687053935071, 0.367549169911043, 
               0.19329848274403533`]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJwtl3k4FGrYxsc2dmbMmGEYZp8hUUJS8qQSUSklLeLUoUhCylJkaUGShISD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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 5}], {
             RGBColor[
             0.9820345699830113, 0.9505243524059044, 0.4303005815921416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 32}], {
             RGBColor[
             0.9755295925744528, 0.9488459762535669, 0.6293958832915749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 51}], {
             RGBColor[
             0.9828550644939116, 0.9525115805343929, 0.5364901650068754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 80}], {
             RGBColor[
             0.9063652220710476, 0.8948479155748367, 0.6627301587168068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 83}], {
             RGBColor[
             0.9797768932067099, 0.9512386776017413, 0.5875034292877397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 92}], {
             RGBColor[
             0.8684451243854527, 0.39369050015057816`, 0.22303375245318535`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 125}], {
             RGBColor[
             0.8968105641385697, 0.6086533837387778, 0.2500764603437277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 128}], {
             RGBColor[
             0.8629678654997786, 0.8607673563568679, 0.6584520084158962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 142}], {
             RGBColor[
             0.9816943049474272, 0.952031576631762, 0.5557269546415353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 149}], {
             RGBColor[
             0.9761187772877586, 0.9492853892480488, 0.6283985472559324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 150}], {
             RGBColor[
             0.9822589025208392, 0.9510041770208194, 0.4547177939147604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 197}], {
             RGBColor[
             0.7323937008953851, 0.7564905350280543, 0.6469904904032595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 198}], {
             RGBColor[
             0.9776169037197814, 0.9361587018252002, 0.3675463269547533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 237}], {
             RGBColor[
             0.9741728037634982, 0.9478340853798948, 0.6316925728413245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 243}], {
             RGBColor[
             0.9563774675832054, 0.934562352793821, 0.661815435227556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 256}], {
             RGBColor[
             0.574812186578179, 0.6091057502258672, 0.637083128679778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 277}], {
             RGBColor[
             0.972170515346848, 0.9463407819572034, 0.635081924850257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 281}], {
             RGBColor[
             0.6459666423344524, 0.6827388170213485, 0.6411775517383702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 49}], {
             RGBColor[
             0.9178872489539293, 0.9364188355793486, 0.9593163641514328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 54}], {
             RGBColor[
             0.9756370899989177, 0.9598138747543361, 0.6523265022605707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 102}], {
             RGBColor[
             0.9713043972108453, 0.9781194469413612, 0.9334583498969036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 165}], {
             RGBColor[
             0.9458536589881164, 0.8485404959761285, 0.5929058725581631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 172}], {
             RGBColor[
             0.983715756153309, 0.9854361446158995, 0.822226278532989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 174}], {
             RGBColor[
             0.971553051185817, 0.9783048926687616, 0.9330374435766198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 183}], {
             RGBColor[
             0.9835585846663158, 0.985099970697696, 0.8051191321237646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 238}], {
             RGBColor[
             0.9353686226067619, 0.805306225891818, 0.584383258407945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 253}], {
             RGBColor[
             0.9651818194091477, 0.9245457920407659, 0.611709750331495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 24}], {
             RGBColor[
             0.9582835397225332, 0.9656783170757792, 0.8182710356969727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 59}], {
             RGBColor[
             0.9892896163121256, 0.9742932078340552, 0.5183582983943784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 65}], {
             RGBColor[
             0.9563558585478644, 0.8520325099143748, 0.44857687629487386`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 72}], {
             RGBColor[
             0.9921370072587249, 0.9903527607336262, 0.7317293983000761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 106}], {
             RGBColor[
             0.929985157879325, 0.9431139555331172, 0.8155719107745039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 115}], {
             RGBColor[
             0.989284854433861, 0.989150902851395, 0.7779929655562815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 155}], {
             RGBColor[
             0.9922414777702244, 0.990395961974901, 0.7299980515635109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[
             0.9810664640651049, 0.9465545844168881, 0.4864129047267036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 169}], {
             RGBColor[
             0.991445791557187, 0.9900669252776071, 0.7431846312834531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 194}], {
             RGBColor[
             0.9740625132411398, 0.9777981057141596, 0.8037604185731236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 200}], {
             RGBColor[
             0.9846878598489395, 0.9587704027399282, 0.5004813435036906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 210}], {
             RGBColor[
             0.9939286292114066, 0.9894222767299751, 0.5805469416979576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 227}], {
             RGBColor[
             0.9939525783383085, 0.98947350149079, 0.5831536563643525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 228}], {
             RGBColor[
             0.9757429364252604, 0.9790513625734363, 0.8009159004469666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 241}], {
             RGBColor[
             0.7910068738125683, 0.8333351639024789, 0.8023919438825019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 264}], {
             RGBColor[
             0.9947224117964175, 0.9911200974155832, 0.6669452774181239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 290}], {
             RGBColor[
             0.9795927134620908, 0.9819225199840731, 0.794399232106273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 291}], {
             RGBColor[
             0.9767979760598526, 0.9321559720865273, 0.46983063486262133`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 8}], {
             RGBColor[
             0.977143590754529, 0.9661898537318598, 0.6609263110316627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 15}], {
             RGBColor[
             0.9353455790098393, 0.9503650381558504, 0.9618623307855603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 62}], {
             RGBColor[
             0.9254077918675383, 0.7619457099643561, 0.5773165038309634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 85}], {
             RGBColor[
             0.9788242201418149, 0.983370111191811, 0.9047148620974241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 121}], {
             RGBColor[
             0.9830692871029096, 0.9847396131710988, 0.8063091855027564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 135}], {
             RGBColor[
             0.9553344922287528, 0.9662091179540362, 0.9604912334132882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 158}], {
             RGBColor[
             0.9634050831649379, 0.9722281514598632, 0.9468298281055597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 173}], {
             RGBColor[
             0.9803405473767217, 0.9839971514712773, 0.879585395685926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 186}], {
             RGBColor[
             0.958515135455258, 0.9685812364645384, 0.9551072340754272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 213}], {
             RGBColor[
             0.963659106124273, 0.9724176013670109, 0.946399833495204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 214}], {
             RGBColor[
             0.9821761946265247, 0.9828293786696121, 0.7091015809761383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 249}], {
             RGBColor[
             0.9278959296295748, 0.9444248899553729, 0.9611517765772901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 255}], {
             RGBColor[
             0.9659359987529856, 0.9741157041614352, 0.9425456481834988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 263}], {
             RGBColor[
             0.9498060838262057, 0.8657960636255163, 0.5973162139938863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 265}], {
             RGBColor[
             0.9712116504743121, 0.9780502765771137, 0.9336153459296312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 276}], {
             RGBColor[
             0.804529746548404, 0.8474584099645088, 0.9490423558308376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 286}], {
             RGBColor[
             0.9437267218707637, 0.8416934192994678, 0.592424616663572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.9839613071328084, 0.9843859242893309, 0.7239494311332481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 23}], {
             RGBColor[
             0.6230292366619897, 0.6855756662710608, 0.728818705996505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 51}], {
             RGBColor[
             0.9941922613205649, 0.9902184324885628, 0.626125489239461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.9887191724073328, 0.9730730860024291, 0.4562689997293844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[
             0.9911140900333633, 0.9889455295559112, 0.6771387535203252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 92}], {
             RGBColor[
             0.8760032556032216, 0.4188284014533581, 0.282790635274909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 101}], {
             RGBColor[
             0.9932675304797088, 0.9898360325213702, 0.6414506723991489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 128}], {
             RGBColor[
             0.8743050623264319, 0.8984742083110377, 0.7480873326484817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 142}], {
             RGBColor[
             0.9930315017740805, 0.9897384285859319, 0.6453622788741208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 149}], {
             RGBColor[
             0.9874559741144119, 0.9869922412022187, 0.7180338714885178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 197}], {
             RGBColor[
             0.7437308977220384, 0.7941973869822242, 0.736625814635845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 198}], {
             RGBColor[
             0.9889541005464346, 0.9738655537793701, 0.4571816511873388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 204}], {
             RGBColor[
             0.9405177567765108, 0.7855101698838699, 0.37395606065244746`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 226}], {
             RGBColor[
             0.9590936947959434, 0.8639286164698767, 0.3891494974961963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 243}], {
             RGBColor[
             0.9677146644098586, 0.972269204747991, 0.7514507594601416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 256}], {
             RGBColor[
             0.5861493834048324, 0.6468126021800371, 0.7267184529123636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 290}], {
             RGBColor[
             0.9790222695572981, 0.9807023981524471, 0.732309933441279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 38}], {
             RGBColor[
             0.8506395492114085, 0.8418347375033195, 0.6436400342479782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 52}], {
             RGBColor[
             0.8613856216609682, 0.8915661698345823, 0.9362717185699174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.7964588232265842, 0.3979429738878482, 0.43973075766318503`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 88}], {
             RGBColor[
             0.7122118502488461, 0.7751045775157235, 0.9719502793008055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 93}], {
             RGBColor[
             0.8009895299427814, 0.8448159204868755, 0.9807039273260578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 124}], {
             RGBColor[
             0.8550995532427468, 0.8870143283138208, 0.9530160962305474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 147}], {
             RGBColor[
             0.7399379832136085, 0.796764443314211, 0.9747137611192891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 273}], {
             RGBColor[
             0.8657048302857936, 0.8919450728971308, 0.7624026180031699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 289}], {
             RGBColor[
             0.8661729835160453, 0.8929464053190869, 0.8133582080092303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 42}], {
             RGBColor[
             0.9614269658277144, 0.9707528747886317, 0.9501782647818497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 60}], {
             RGBColor[
             0.9765615705038706, 0.9811964782337131, 0.886774032707804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 77}], {
             RGBColor[
             0.9712973377905292, 0.9562582751332669, 0.6589953526751905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 80}], {
             RGBColor[
             0.9029427459059978, 0.9247200529265833, 0.9654338311016748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 81}], {
             RGBColor[
             0.9694034018941118, 0.9767016877467356, 0.9366762391091483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 82}], {
             RGBColor[
             0.9034318142805735, 0.9251100227730626, 0.9654804788798383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 103}], {
             RGBColor[
             0.9341387170195186, 0.8156729157799523, 0.5940144641041306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 127}], {
             RGBColor[
             0.9375185731057287, 0.9522898789998216, 0.9687317043661905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 130}], {
             RGBColor[
             0.8815070697973632, 0.5315428622974574, 0.4395292457480906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 140}], {
             RGBColor[
             0.746975617016661, 0.8009794491264697, 0.951111534501169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 145}], {
             RGBColor[
             0.9787353127393712, 0.9820953765107199, 0.8507494984009832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 154}], {
             RGBColor[
             0.9557540635713633, 0.9013705619707707, 0.6114066793171389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 167}], {
             RGBColor[
             0.6988827841197641, 0.761408633580426, 0.9474710710407515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 168}], {
             RGBColor[
             0.978434333045225, 0.9819709136723651, 0.8557375108434662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 181}], {
             RGBColor[
             0.962722585663023, 0.9717191459404222, 0.9479851183524444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 201}], {
             RGBColor[
             0.9791825377227543, 0.981616611589277, 0.7950935526420035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 202}], {
             RGBColor[
             0.9185016054312822, 0.7447254818716658, 0.5809694253939873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 203}], {
             RGBColor[
             0.9311502889506377, 0.8021601995579679, 0.5915237969701419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 205}], {
             RGBColor[
             0.9525916636417397, 0.888832700057119, 0.6088621381026968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 216}], {
             RGBColor[
             0.897326785146247, 0.9202420382579519, 0.9648981757509825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 237}], {
             RGBColor[
             0.9707503275984484, 0.9777062227316415, 0.9343962452261925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 255}], {
             RGBColor[
             0.9622102357873454, 0.9713370362420377, 0.9488523930497177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 269}], {
             RGBColor[
             0.9312801065007479, 0.8027496707333592, 0.5916321199160732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 282}], {
             RGBColor[
             0.973619138007688, 0.9798457768376063, 0.9295400975089378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 293}], {
             RGBColor[
             0.959540401861297, 0.9693458784714427, 0.9533717254823081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 299}], {
             RGBColor[
             0.9557442747238248, 0.9665147330679036, 0.959797578537523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 14}], {
             RGBColor[
             0.9685524652349549, 0.9597826063860384, 0.6754688456119065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 64}], {
             RGBColor[
             0.7597840213641983, 0.794461671156139, 0.6725272889033893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 67}], {
             RGBColor[
             0.9853665265236391, 0.9622999992405776, 0.3976521481542717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 69}], {
             RGBColor[
             0.9724140921508926, 0.962662601417111, 0.6689321185168273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 85}], {
             RGBColor[
             0.9846638641388048, 0.9714408539296479, 0.6321820607322325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 121}], {
             RGBColor[
             0.9889089310998995, 0.9728103559089357, 0.5337763841375649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 135}], {
             RGBColor[
             0.9611741362257428, 0.954279860691873, 0.6879584320480967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 173}], {
             RGBColor[
             0.9861801913737116, 0.9720678942091142, 0.6070525943207343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 186}], {
             RGBColor[
             0.964354779452248, 0.9566519792023753, 0.6825744327102354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 213}], {
             RGBColor[
             0.9694987501212629, 0.9604883441048477, 0.6738670321300122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 234}], {
             RGBColor[
             0.9168827907069814, 0.91905768104974, 0.6870115417325717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 249}], {
             RGBColor[
             0.9337355736265647, 0.9324956326932098, 0.6886189752120986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 263}], {
             RGBColor[
             0.9556457278231956, 0.8538668063633532, 0.3247834126286947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 286}], {
             RGBColor[
             0.9495663658677536, 0.8297641620373047, 0.3198918152983804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 45}], {
             RGBColor[
             0.9658569494991409, 0.971205965673017, 0.7801638839658309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 47}], {
             RGBColor[
             0.9655304618952996, 0.9705076417013607, 0.7446277231356375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 96}], {
             RGBColor[
             0.944740313092153, 0.9583079965003363, 0.9784244152871038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 112}], {
             RGBColor[
             0.5584032535230631, 0.6292926092923742, 0.9617694851691139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 132}], {
             RGBColor[
             0.9658844442710098, 0.9712647742098968, 0.7831565202057024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 133}], {
             RGBColor[
             0.6879114344131597, 0.7534687398552686, 0.9695821559930602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 141}], {
             RGBColor[
             0.9586265034692044, 0.947637665884095, 0.6822041708588977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 146}], {
             RGBColor[
             0.964199367794256, 0.9717693450946907, 0.8984112095241592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 236}], {
             RGBColor[
             0.9622849179492199, 0.9709776708846514, 0.9301385978937897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 22}], {
             RGBColor[
             0.989685174933129, 0.9878801911634025, 0.666332411497382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 48}], {
             RGBColor[
             0.9936309025707915, 0.9887854695504803, 0.5481412342228443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 63}], {
             RGBColor[
             0.9710948064770919, 0.9120110770894478, 0.36909711783734744`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 71}], {
             RGBColor[
             0.990442264828141, 0.9881932672913128, 0.6537854726511904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 73}], {
             RGBColor[
             0.9767822782864797, 0.9786487398059882, 0.7057061706590256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 100}], {
             RGBColor[
             0.9902849362034287, 0.9881282078618331, 0.6563928151161021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 119}], {
             RGBColor[
             0.9547449940656023, 0.8471895191299015, 0.35594167499164064`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 122}], {
             RGBColor[
             0.980001680154583, 0.944006356906716, 0.3935414265331689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 161}], {
             RGBColor[
             0.9686112369879201, 0.9725547905843747, 0.7195376122286039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 244}], {
             RGBColor[
             0.9903807490734241, 0.9881678289458546, 0.6548049479045196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 266}], {
             RGBColor[
             0.9932866323467751, 0.9880491103523681, 0.5106695449282004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 51}], {
             RGBColor[
             0.9847818016437087, 0.9863731524178194, 0.8301390145479819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 101}], {
             RGBColor[
             0.9838570708028526, 0.9859907524506268, 0.84546419770767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 104}], {
             RGBColor[
             0.9847985239145205, 0.9861766463298121, 0.8150753111195582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 114}], {
             RGBColor[
             0.9652391544300177, 0.9217573727641566, 0.6056796806266482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 116}], {
             RGBColor[
             0.8897952720652202, 0.5704983081439627, 0.43801454722988864`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 149}], {
             RGBColor[
             0.9780455144375556, 0.9831469611314754, 0.9220473967970388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 197}], {
             RGBColor[
             0.7343204380451821, 0.7903521069114808, 0.940639339944366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 198}], {
             RGBColor[
             0.9795436408695783, 0.9700202737086268, 0.6611951764958598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 204}], {
             RGBColor[
             0.9311072970996546, 0.7816648898131265, 0.5779695859609685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 243}], {
             RGBColor[
             0.9583042047330024, 0.9684239246772476, 0.9554642847686625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 254}], {
             RGBColor[
             0.9734275220942947, 0.9493891689466145, 0.6374352099859992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 283}], {
             RGBColor[
             0.9576241848229947, 0.9679167669417943, 0.956615381098708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.6414209574140182, 0.6694538175579785, 0.6266408274132423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 27}], {
             RGBColor[
             0.6550062500072649, 0.7207736278991816, 0.875082826158416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.428093210309618, 0.542953665947218, 0.9491233890893187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 76}], {
             RGBColor[
             0.6563390163316849, 0.7194220367475705, 0.7146874702936397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 87}], {
             RGBColor[
             0.6560277433990596, 0.7211960416678714, 0.8581540371162215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 151}], {
             RGBColor[
             0.6014368636011073, 0.5070461727029997, 0.5829487199879146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 154}], {
             RGBColor[
             0.6336286594794133, 0.6407119674190842, 0.6091632332716577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 181}], {
             RGBColor[
             0.640597181571073, 0.7110605513887357, 0.9457416723069632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 192}], {
             RGBColor[
             0.5440162339392551, 0.6351339387719623, 0.9595696871798991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 220}], {
             RGBColor[
             0.6534764404558249, 0.7201410123353489, 0.9004357294459864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 239}], {
             RGBColor[
             0.6089940538941991, 0.686528803751135, 0.9658779050080464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 258}], {
             RGBColor[
             0.6487678558493255, 0.7171542268872051, 0.9319108520070306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 32}], {
             RGBColor[
             0.9877966090037311, 0.9885416183185692, 0.82023633308847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 53}], {
             RGBColor[
             0.8822830103221302, 0.4636585408259599, 0.35568062166087433`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 93}], {
             RGBColor[
             0.9297258105861003, 0.943389270894043, 0.8546287233225918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 107}], {
             RGBColor[
             0.9881243847838352, 0.9887860729586873, 0.8196814941903687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 137}], {
             RGBColor[
             0.9951582436885997, 0.9922221768322328, 0.7267313041946939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 147}], {
             RGBColor[
             0.8686742638569274, 0.8953377937213787, 0.8486385571158231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 156}], {
             RGBColor[
             0.9632855087942971, 0.8788501273645785, 0.4929793003201586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 179}], {
             RGBColor[
             0.9835123417064284, 0.9853464187830847, 0.8274884801069344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 251}], {
             RGBColor[
             0.9500473682699628, 0.9595931293771665, 0.8565670116357473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 270}], {
             RGBColor[
             0.9671236720056144, 0.9731237757542013, 0.8552302230607838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 271}], {
             RGBColor[
             0.950040469853286, 0.8263379616110527, 0.48232203108719884`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 273}], {
             RGBColor[
             0.9944411109291125, 0.9905184233042983, 0.6363274139997039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 274}], {
             RGBColor[
             0.9268169015345118, 0.9410697857765391, 0.8543512689804376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 277}], {
             RGBColor[
             0.9844375317761263, 0.9860364240222057, 0.8259223746471522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 282}], {
             RGBColor[
             0.989308630602016, 0.989669281550862, 0.8176768749209651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 289}], {
             RGBColor[
             0.9949092641593642, 0.9915197557262545, 0.6872830040057644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 67}], {
             RGBColor[
             0.970935757007075, 0.9678220091569194, 0.684727484099707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 173}], {
             RGBColor[
             0.9717494218571476, 0.977589904125456, 0.8941279302661697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 186}], {
             RGBColor[
             0.9499240099356839, 0.9621739891187171, 0.9696497686556709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.9550679806046989, 0.9660103540211895, 0.9609423680754476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 249}], {
             RGBColor[
             0.9193048041100007, 0.9380176426095516, 0.9756943111575338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 46}], {
             RGBColor[
             0.9368078982472137, 0.9514556334487563, 0.9593870057506253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 60}], {
             RGBColor[
             0.9443289657218114, 0.9562210733149382, 0.9088705062302913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.8894494241198387, 0.7341916371261836, 0.6057197222196694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 77}], {
             RGBColor[
             0.9390647330084698, 0.931282870214492, 0.6810918261976777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 82}], {
             RGBColor[
             0.8711992094985141, 0.9001346178542877, 0.9875769524023255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 103}], {
             RGBColor[
             0.9019061122374593, 0.7906975108611773, 0.6161109376266178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 127}], {
             RGBColor[
             0.9052859683236694, 0.9273144740810467, 0.9908281778886776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 135}], {
             RGBColor[
             0.9193761244810532, 0.9384550451158638, 0.9888944518019943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 158}], {
             RGBColor[
             0.9274467154172382, 0.9444740786216906, 0.9752330464942658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 168}], {
             RGBColor[
             0.9462017282631656, 0.9569955087535902, 0.8778339843659535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 186}], {
             RGBColor[
             0.9225567677075583, 0.9408271636263659, 0.9835104524641332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 196}], {
             RGBColor[
             0.9450023783491492, 0.9513119421740285, 0.7041584571159805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 212}], {
             RGBColor[
             0.7184724592272449, 0.7790317772859949, 0.9735016037523316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 214}], {
             RGBColor[
             0.946217826878825, 0.9550753058314396, 0.7375047993648443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 225}], {
             RGBColor[
             0.9463508340896755, 0.9553597948063568, 0.7519818134405523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 255}], {
             RGBColor[
             0.9299776310052861, 0.9463616313232628, 0.9709488665722049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 265}], {
             RGBColor[
             0.9352532827266125, 0.9502962037389412, 0.9620185643183373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 276}], {
             RGBColor[
             0.7685713788007045, 0.8197043371263364, 0.9774455742195436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 286}], {
             RGBColor[
             0.9077683541230641, 0.8139393464612954, 0.620827835052278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.9779473824273172, 0.9371800061988875, 0.3767788607923991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 39}], {
             RGBColor[
             0.9726283822401387, 0.9368857683027654, 0.613510781326145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 76}], {
             RGBColor[
             0.9781583611033449, 0.9376312682536945, 0.39974258766855236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 90}], {
             RGBColor[
             0.9425624968268871, 0.8078344558291173, 0.2838503689113373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 126}], {
             RGBColor[
             0.9656415568012686, 0.9316750053303328, 0.6253376543382312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 151}], {
             RGBColor[
             0.9232562083727671, 0.7252554042091235, 0.2680038373628273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 153}], {
             RGBColor[
             0.9726551792541833, 0.9194216401344315, 0.3482709643489484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 192}], {
             RGBColor[
             0.8658355787109151, 0.8533431702780863, 0.6446248045548117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 220}], {
             RGBColor[
             0.9752957852274848, 0.9383502438414728, 0.585490846820899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 222}], {
             RGBColor[
             0.9258452258813465, 0.9007765491363463, 0.650459153627632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 239}], {
             RGBColor[
             0.9308133986658591, 0.9047380352572589, 0.650933022382959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 248}], {
             RGBColor[
             0.9784901207226097, 0.9396711836593847, 0.5325524409914131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 285}], {
             RGBColor[
             0.9774795778464127, 0.9392532982103099, 0.5492997516511269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 40}], {
             RGBColor[
             0.9167075905264217, 0.9357833415360277, 0.9697830195526431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[
             0.915980167649074, 0.9352408307451474, 0.9710143567417213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 66}], {
             RGBColor[
             0.8834844412206946, 0.909930528155823, 0.988748728771143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 81}], {
             RGBColor[
             0.9239566037154714, 0.9411896437032514, 0.95751233106902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 86}], {
             RGBColor[
             0.8553667286828922, 0.8875102274131539, 0.986066836248309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 94}], {
             RGBColor[
             0.8704843893302463, 0.8995646396553876, 0.9875087722165486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 97}], {
             RGBColor[
             0.9333340744909158, 0.9452454466115683, 0.7722108823506256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 120}], {
             RGBColor[
             0.8979539382828965, 0.9214681123491881, 0.9901288423180082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 130}], {
             RGBColor[
             0.8512092043449362, 0.507868166268468, 0.45341997372133835`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 140}], {
             RGBColor[
             0.7015288188380207, 0.7654674050829855, 0.9719476264610407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 162}], {
             RGBColor[
             0.9202895489899685, 0.9019877039393547, 0.6582280461738637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 169}], {
             RGBColor[
             0.9306688764820507, 0.9455000448000737, 0.9149997727306132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 178}], {
             RGBColor[
             0.833792466644487, 0.8705124548756648, 0.9839546742195893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 182}], {
             RGBColor[
             0.932397476484166, 0.9462148653239422, 0.8863523972221565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 201}], {
             RGBColor[
             0.9337357395441139, 0.9461045675457928, 0.8159296446018751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 202}], {
             RGBColor[
             0.8730548072526418, 0.7092134378281816, 0.601805517353859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 294}], {
             RGBColor[
             0.9332642691231423, 0.9450961399883064, 0.7646129988572903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 26}], {
             RGBColor[
             0.9897722190136773, 0.9896188266753587, 0.788653859651604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 33}], {
             RGBColor[
             0.9887017236848297, 0.9873291454106335, 0.672137049437898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 35}], {
             RGBColor[
             0.9518419768651456, 0.852136261774888, 0.5780218496003823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 129}], {
             RGBColor[
             0.986330557992499, 0.9886153486883319, 0.8762015596536159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 165}], {
             RGBColor[
             0.9520836072692144, 0.8530942458084618, 0.5782162710952905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 175}], {
             RGBColor[
             0.9844466321088892, 0.9878283688147822, 0.9070680502046246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 183}], {
             RGBColor[
             0.9897885329474139, 0.9896537205300293, 0.790429530660892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 184}], {
             RGBColor[
             0.9848963256869714, 0.9880222567719072, 0.8999705006304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.98333403024521, 0.9869985921665687, 0.9089513949467928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 253}], {
             RGBColor[
             0.9714117676902458, 0.9290995418730993, 0.5970201488686224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 262}], {
             RGBColor[
             0.9840674199449102, 0.9875455530037898, 0.9077099574838684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 36}], {
             RGBColor[
             0.612495451623476, 0.6505789109283444, 0.6423044848492562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 37}], {
             RGBColor[
             0.9438450358145489, 0.9268027795510856, 0.6693494897620564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 41}], {
             RGBColor[
             0.9440205509561801, 0.8109348161318553, 0.29898280170501645`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 44}], {
             RGBColor[
             0.9825391728192334, 0.9525953268834257, 0.4008981742963562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 55}], {
             RGBColor[
             0.9827930722702094, 0.9548638103470811, 0.5539532521622204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 61}], {
             RGBColor[
             0.9828093268249243, 0.9531731589848385, 0.4303027706185337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 71}], {
             RGBColor[
             0.9801834610406756, 0.9537846690397194, 0.5972012636929722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 108}], {
             RGBColor[
             0.9820543421097991, 0.9545583264412523, 0.5661959226925917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 136}], {
             RGBColor[
             0.9805366420452716, 0.9539307184614576, 0.5913481404436751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 152}], {
             RGBColor[
             0.9803662488889354, 0.9538602565124081, 0.5941719960075185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 177}], {
             RGBColor[
             0.9563831874090722, 0.8599485500631874, 0.30893006918338717`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 208}], {
             RGBColor[
             0.9712239781633198, 0.9477457694908654, 0.6411652350848384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 252}], {
             RGBColor[
             0.923000237126661, 0.718801906763735, 0.2816144401584998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 268}], {
             RGBColor[
             0.9615678370834679, 0.9405442352839918, 0.6575105632080875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 279}], {
             RGBColor[
             0.9601055178460935, 0.939453639991086, 0.6599858882430225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 280}], {
             RGBColor[
             0.9349678458295916, 0.7731440227777162, 0.29160050621315803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 50}], {
             RGBColor[
             0.9533945464095692, 0.8848431034952312, 0.6039431632329149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 74}], {
             RGBColor[
             0.9658405011688085, 0.8926285495631658, 0.5158489325229424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[
             0.9472037186319128, 0.8283873682330181, 0.27637707660447786`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 123}], {
             RGBColor[
             0.954707368742187, 0.8858222042413483, 0.6017208974626951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 189}], {
             RGBColor[
             0.9004766793697676, 0.8434887578605419, 0.6280512118336115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 206}], {
             RGBColor[
             0.9628512205169014, 0.8913924051925937, 0.5653890489353868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 257}], {
             RGBColor[
             0.9119116262223557, 0.8526066740874321, 0.6291418872725087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 287}], {
             RGBColor[
             0.9469871377597924, 0.827528697246358, 0.2762028105509633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 300}], {
             RGBColor[
             0.9664385157645561, 0.8921124143573447, 0.45044500962584744`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.9904942731963522, 0.9896107705360544, 0.7543977642735606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 63}], {
             RGBColor[
             0.9679581771026526, 0.912836378075022, 0.5753536478880636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 70}], {
             RGBColor[
             0.7764641960047006, 0.8237785962379016, 0.915797792129944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 73}], {
             RGBColor[
             0.9736456489120404, 0.9794740407915623, 0.9119627007097418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 100}], {
             RGBColor[
             0.9871483068289895, 0.9889535088474073, 0.8626493451668183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 119}], {
             RGBColor[
             0.9516083646911632, 0.8480148201154756, 0.5621982050423568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 122}], {
             RGBColor[
             0.9768650507801439, 0.9448316578922902, 0.5997979565838851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 161}], {
             RGBColor[
             0.9654746076134808, 0.9733800915699489, 0.9257941422793201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 244}], {
             RGBColor[
             0.987244119698985, 0.9889931299314287, 0.8610614779552358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 266}], {
             RGBColor[
             0.9901500029723358, 0.9888744113379422, 0.7169260749789166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 24}], {
             RGBColor[
             0.5873705656700655, 0.6618026571551399, 0.9650645372037566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 31}], {
             RGBColor[
             0.5987369655503998, 0.670631555599023, 0.9580232562659801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 44}], {
             RGBColor[
             0.6227304277100723, 0.6849365441371287, 0.696295195615383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 59}], {
             RGBColor[
             0.6183766422596579, 0.6704175479134158, 0.6651517999011624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 72}], {
             RGBColor[
             0.6212240332062572, 0.6864771008129869, 0.87852289980686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 83}], {
             RGBColor[
             0.6207715598856883, 0.6862899914668978, 0.8860215536921031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 106}], {
             RGBColor[
             0.5590721838268573, 0.6392382956124778, 0.9623654122812877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 136}], {
             RGBColor[
             0.6207278969361103, 0.6862719357151607, 0.886745161762702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 155}], {
             RGBColor[
             0.6213285037177567, 0.6865203020542616, 0.876791553070295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 194}], {
             RGBColor[
             0.6031495391886721, 0.6739224457935202, 0.9505539200799076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 197}], {
             RGBColor[
             0.37338836757436344`, 0.4915418488932108, 0.9455086148076229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 198}], {
             RGBColor[
             0.6186115703987598, 0.6712100156903567, 0.6660644513591167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 210}], {
             RGBColor[
             0.6230156551589389, 0.6855466168093357, 0.7273404432047416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 226}], {
             RGBColor[
             0.5887511646482685, 0.5612730783808634, 0.5980322976679743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 241}], {
             RGBColor[
             0.4200938997601006, 0.5294595039818395, 0.9491854453892858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 290}], {
             RGBColor[
             0.608679739409623, 0.6780468600634337, 0.941192733613057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 291}], {
             RGBColor[
             0.6058850020073849, 0.628280312165888, 0.6166241363694053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.9562326560989939, 0.9654939279373704, 0.9005037552588663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 59}], {
             RGBColor[
             0.9530605014154085, 0.9493000768865082, 0.692514830936636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 65}], {
             RGBColor[
             0.9201267436511474, 0.8270393789668279, 0.6227334088371315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 72}], {
             RGBColor[
             0.9559078923620079, 0.9653596297860794, 0.9058859308423337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 87}], {
             RGBColor[
             0.9572541494907885, 0.9659163417060603, 0.8835749662166718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 106}], {
             RGBColor[
             0.8937560429826079, 0.9181208245855703, 0.9897284433167615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 109}], {
             RGBColor[
             0.7921843580967045, 0.8384047057052137, 0.9797022625949758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 155}], {
             RGBColor[
             0.9560123628735075, 0.9654028310273541, 0.9041545841057685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 162}], {
             RGBColor[
             0.9448373491683879, 0.9215614534693413, 0.6605694372689612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 194}], {
             RGBColor[
             0.9378333983444227, 0.9528049747666126, 0.9779169511153812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 210}], {
             RGBColor[
             0.9576995143146896, 0.9644291457824281, 0.7547034742402152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 218}], {
             RGBColor[
             0.9419496871880413, 0.9558748962463789, 0.970949147803207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 226}], {
             RGBColor[
             0.9234350238040192, 0.8401556073539558, 0.6253953287034479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 227}], {
             RGBColor[
             0.9577234634415914, 0.9644803705432432, 0.7573101889066101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 241}], {
             RGBColor[
             0.7547777589158513, 0.808342032954932, 0.9765484764247595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 290}], {
             RGBColor[
             0.9433635985653739, 0.9569293890365261, 0.9685557646485305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 291}], {
             RGBColor[
             0.9405688611631355, 0.9071628411389804, 0.6439871674048789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 299}], {
             RGBColor[
             0.9348452767236037, 0.950576438554406, 0.9829750615924923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 28}], {
             RGBColor[
             0.9790515444565855, 0.9393840247114088, 0.5103674080846299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 58}], {
             RGBColor[
             0.9542566065863433, 0.8542732529215582, 0.2928662650641275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 79}], {
             RGBColor[
             0.9786527450874556, 0.9385310331856411, 0.46696055785925644`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 113}], {
             RGBColor[
             0.9432225268137477, 0.8105268035123324, 0.2839879854759566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 134}], {
             RGBColor[
             0.975399643973017, 0.9380151228188098, 0.5811564378353742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 144}], {
             RGBColor[
             0.9699687280400058, 0.9345665773377176, 0.6173004133204083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 160}], {
             RGBColor[
             0.9751492649374276, 0.9278347767831812, 0.3579600162597912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 176}], {
             RGBColor[
             0.9785789218953919, 0.9383731328424865, 0.4589253589870456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.8122358828236405, 0.8111395783894482, 0.6387989790006317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 221}], {
             RGBColor[
             0.9788918559515087, 0.9390424671460338, 0.4929862997902278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 230}], {
             RGBColor[
             0.9777648512966276, 0.9366319181468927, 0.3703187981729327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 232}], {
             RGBColor[
             0.7847054302263402, 0.7890821323953239, 0.6364313445197236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 245}], {
             RGBColor[
             0.9440728478842397, 0.8138980432041341, 0.2846721737688753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 288}], {
             RGBColor[
             0.9639183986183648, 0.8899504275561685, 0.31433022138137623`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 297}], {
             RGBColor[
             0.9781008616272889, 0.9391321457369786, 0.5363902707768854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 35}], {
             RGBColor[
             0.95686521117812, 0.8537937609626521, 0.4642633871728334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 54}], {
             RGBColor[
             0.9868902725929901, 0.9660251237744336, 0.5238784383701491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 75}], {
             RGBColor[
             0.9926707090150244, 0.990817426778711, 0.7406183792776122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 102}], {
             RGBColor[
             0.9825575798049178, 0.9843306959614587, 0.8050102860064822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 129}], {
             RGBColor[
             0.9913537923054734, 0.990272847876096, 0.762443097226067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 165}], {
             RGBColor[
             0.9571068415821888, 0.8547517449962259, 0.46445780866774167`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 175}], {
             RGBColor[
             0.9894698664218635, 0.9894858680025463, 0.7933095877770757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 183}], {
             RGBColor[
             0.9948117672603882, 0.9913112197177933, 0.6766710682333432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 224}], {
             RGBColor[
             0.9883572645581844, 0.9886560913543327, 0.795192932519244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 253}], {
             RGBColor[
             0.9764350020032202, 0.9307570410608634, 0.48326168644107353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 262}], {
             RGBColor[
             0.9890906542578846, 0.9892030521915538, 0.7939514950563196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 42}], {
             RGBColor[
             0.9747061991006709, 0.979623322084272, 0.8814319348564549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 72}], {
             RGBColor[
             0.9900861236351856, 0.9901683715952174, 0.8139621178619697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 87}], {
             RGBColor[
             0.9914323807639662, 0.9907250835151984, 0.7916511532363077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 109}], {
             RGBColor[
             0.8263625893698823, 0.8632134475143518, 0.8877784496146117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 140}], {
             RGBColor[
             0.7602548502896177, 0.80984989642211, 0.8823652045757742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 151}], {
             RGBColor[
             0.9368415009660139, 0.7765752145503266, 0.5164458361080009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 154}], {
             RGBColor[
             0.9690332968443199, 0.910241009266411, 0.542660349391744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 155}], {
             RGBColor[
             0.9901905941466851, 0.9902115728364922, 0.8122307711254046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 162}], {
             RGBColor[
             0.9790155804415656, 0.9463701952784793, 0.5686456242885972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 181}], {
             RGBColor[
             0.9760018189359797, 0.9805895932360627, 0.8792387884270495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 202}], {
             RGBColor[
             0.9317808387042388, 0.7535959291673061, 0.5122230954685925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 203}], {
             RGBColor[
             0.9444295222235943, 0.8110306468536083, 0.5227774670447471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 216}], {
             RGBColor[
             0.9106060184192035, 0.9291124855535922, 0.8961518458255876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 227}], {
             RGBColor[
             0.9919016947147692, 0.9892891123523813, 0.6653863759262459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 299}], {
             RGBColor[
             0.9690235079967815, 0.975385180363544, 0.8910512486121283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 79}], {
             RGBColor[
             0.9947194646830857, 0.9911137938381653, 0.666624502319434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 144}], {
             RGBColor[
             0.9860354476356359, 0.9871493379902417, 0.8169643577805858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 160}], {
             RGBColor[
             0.9912159845330576, 0.9804175374357054, 0.5576239607199688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 176}], {
             RGBColor[
             0.9946456414910219, 0.9909558934950105, 0.6585893034472232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 221}], {
             RGBColor[
             0.9949585755471387, 0.991625227798558, 0.6926502442504054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 230}], {
             RGBColor[
             0.9938315708922576, 0.9892146787994169, 0.5699827426331102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 232}], {
             RGBColor[
             0.8007721498219702, 0.841664893047848, 0.8360952889799012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 240}], {
             RGBColor[
             0.9755662647716112, 0.9793414385519659, 0.8346859535691804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 245}], {
             RGBColor[
             0.9601395674798698, 0.8664808038566582, 0.484336118229053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 288}], {
             RGBColor[
             0.9799851182139948, 0.9425331882086927, 0.5139941658415539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 297}], {
             RGBColor[
             0.9941675812229189, 0.9917149063895025, 0.736054215237063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 43}], {
             RGBColor[
             0.944631354108759, 0.8172232022020367, 0.5451982432070381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 78}], {
             RGBColor[
             0.8527749534069802, 0.36156532804726205`, 0.19640498443950832`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 99}], {
             RGBColor[
             0.9329441618054619, 0.8091153336267922, 0.5922279157602561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 131}], {
             RGBColor[
             0.9201090212935101, 0.7995429068485924, 0.6139544607062084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 170}], {
             RGBColor[
             0.9481442772854569, 0.818675886213609, 0.48698001501539556`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 178}], {
             RGBColor[
             0.8480173210572307, 0.7423441118214293, 0.6098048823420521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 182}], {
             RGBColor[
             0.9466223308969097, 0.8180465222697066, 0.5122026053446194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 190}], {
             RGBColor[
             0.9373611270460773, 0.7834220281766874, 0.2951372380921481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 199}], {
             RGBColor[
             0.9093669095798642, 0.7910576500249666, 0.6157108505186906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 209}], {
             RGBColor[
             0.8084596745421672, 0.711441377714613, 0.6058621458246547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 229}], {
             RGBColor[
             0.8892501438917342, 0.5899925943459794, 0.22929994414692634`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 259}], {
             RGBColor[
             0.9480828500813799, 0.8181977179799202, 0.45508667740125364`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 261}], {
             RGBColor[
             0.9470212758295165, 0.8159271179968055, 0.33954087136279054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 284}], {
             RGBColor[
             0.9329964056075601, 0.8091542969688558, 0.5921394806306695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 74}], {
             RGBColor[
             0.9825837476083832, 0.9850348413864785, 0.8473388760721438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 104}], {
             RGBColor[
             0.9835063345559903, 0.9852129336219861, 0.8172626506465892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 123}], {
             RGBColor[
             0.9714506151817618, 0.9782284960646609, 0.9332108410118964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 189}], {
             RGBColor[
             0.9172199258093424, 0.9358950496838545, 0.9595411553828128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 236}], {
             RGBColor[
             0.9793283987956025, 0.9836886709937451, 0.9012884304725913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 260}], {
             RGBColor[
             0.9631931492611041, 0.972070091501394, 0.9471885769235353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 267}], {
             RGBColor[
             0.9628108534094768, 0.9162893559032266, 0.6069528780424571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 287}], {
             RGBColor[
             0.9637303841993672, 0.9199349890696706, 0.6076927541001647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 300}], {
             RGBColor[
             0.9831817622041308, 0.9845187061806573, 0.7819349531750488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 37}], {
             RGBColor[
             0.9300865497414726, 0.9468554242217642, 0.9850682611787804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 44}], {
             RGBColor[
             0.9687806867461572, 0.9726479715541042, 0.7166169457130802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 59}], {
             RGBColor[
             0.9644269012957429, 0.9581289753303912, 0.6854735499988596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 61}], {
             RGBColor[
             0.969050840751848, 0.973225803655517, 0.7460215420352576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 65}], {
             RGBColor[
             0.9314931435314817, 0.8358682774107109, 0.615692127899355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 71}], {
             RGBColor[
             0.9664249749675993, 0.9738373137103978, 0.9129200351096961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 136}], {
             RGBColor[
             0.9667781559721953, 0.9739833631321362, 0.9070669118603991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 177}], {
             RGBColor[
             0.942624701335996, 0.880001194733866, 0.6246488406001112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 194}], {
             RGBColor[
             0.9491997982247571, 0.9616338732104956, 0.9708756701776047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 210}], {
             RGBColor[
             0.9690659141950239, 0.9732580442263112, 0.7476621933024388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 226}], {
             RGBColor[
             0.9348014236843535, 0.8489845057978389, 0.6183540477656715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 241}], {
             RGBColor[
             0.7661441587961856, 0.8171709313988149, 0.9695071954869829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 279}], {
             RGBColor[
             0.9463470317730174, 0.9595062846617646, 0.9757046596597465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 280}], {
             RGBColor[
             0.9212093597565153, 0.7931966674483948, 0.6073192776298819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 290}], {
             RGBColor[
             0.954729998445708, 0.9657582874804091, 0.9615144837107541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 291}], {
             RGBColor[
             0.9519352610434699, 0.9159917395828634, 0.6369458864671025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 80}], {
             RGBColor[
             0.9111974414891424, 0.9308763913766691, 0.9514607846488257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 92}], {
             RGBColor[
             0.8716666039975158, 0.4177094840184665, 0.41552083640786464`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 107}], {
             RGBColor[
             0.9806895877726517, 0.9851189066955174, 0.9175716703254926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 125}], {
             RGBColor[
             0.900032043750633, 0.632672367606666, 0.44256354429840694`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 128}], {
             RGBColor[
             0.8678000849178733, 0.8967958321587004, 0.947182634347915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 142}], {
             RGBColor[
             0.9865265243655219, 0.9880600524335943, 0.8444575805735541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 145}], {
             RGBColor[
             0.9869900083225158, 0.9882517149608057, 0.8367764519481342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 149}], {
             RGBColor[
             0.9809509967058534, 0.9853138650498814, 0.9171291731879512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 150}], {
             RGBColor[
             0.987091121938934, 0.9870326528226518, 0.7434484198467792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 156}], {
             RGBColor[
             0.9558507117831134, 0.8751829611014086, 0.5908694764552823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 167}], {
             RGBColor[
             0.7071374797029087, 0.7675649720305118, 0.9334980245879023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 179}], {
             RGBColor[
             0.9760775446952448, 0.9816792525199147, 0.9253786562420582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 205}], {
             RGBColor[
             0.9608463592248844, 0.8949890385072048, 0.5948890916498477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 237}], {
             RGBColor[
             0.979005023181593, 0.9838625611817273, 0.9204231987733434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 256}], {
             RGBColor[
             0.5796444059962738, 0.6451342260276997, 0.9258137546117968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 269}], {
             RGBColor[
             0.9395348020838925, 0.808906009183445, 0.5776590734632241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 277}], {
             RGBColor[
             0.9770027347649427, 0.9823692577590357, 0.9238125507822759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 282}], {
             RGBColor[
             0.9818738335908326, 0.9860021152876921, 0.9155670510560888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 293}], {
             RGBColor[
             0.9677950974444416, 0.9755022169215285, 0.9393986790294591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 98}], {
             RGBColor[
             0.9315779563179365, 0.7457780587178865, 0.3277586755800799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 126}], {
             RGBColor[
             0.9803486370429078, 0.9811919624651178, 0.6904205703424753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 153}], {
             RGBColor[
             0.9873622594958225, 0.9689385972692165, 0.4133538803531925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 157}], {
             RGBColor[
             0.9929322481626096, 0.9872911184161753, 0.47209701348746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 171}], {
             RGBColor[
             0.879448471531161, 0.9020053398831465, 0.7095986621826542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 184}], {
             RGBColor[
             0.9888490646710981, 0.9873900746949462, 0.6696952279891799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 222}], {
             RGBColor[
             0.9405523061229857, 0.9502935062711313, 0.715542069631876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 248}], {
             RGBColor[
             0.9931972009642488, 0.9891881407941697, 0.5976353569956572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 275}], {
             RGBColor[
             0.9363807027534142, 0.946967182979392, 0.715144178378452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 285}], {
             RGBColor[
             0.9921866580880518, 0.988770255345095, 0.614382667655371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 38}], {
             RGBColor[
             0.9703367387007882, 0.9355444417024404, 0.6181706578963961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 52}], {
             RGBColor[
             0.9810828111503478, 0.9852758740337032, 0.9108023422183353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 53}], {
             RGBColor[
             0.8762569495528373, 0.46041611002059557`, 0.422751173428797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 57}], {
             RGBColor[
             0.9842420372703511, 0.9865822952227326, 0.8584457895947646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 84}], {
             RGBColor[
             0.9857894180871505, 0.9864833829135937, 0.779099157165067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 124}], {
             RGBColor[
             0.9747967427321265, 0.9807240325129418, 0.9275467198789653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 147}], {
             RGBColor[
             0.8596351727029881, 0.890474147513332, 0.949244384767707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 217}], {
             RGBColor[
             0.9695188137741436, 0.9327853888669628, 0.6149931740085439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 223}], {
             RGBColor[
             0.9583218142375918, 0.890144070619155, 0.5968642877360301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 247}], {
             RGBColor[
             0.9857755190243781, 0.9864536542237342, 0.7775863299573593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 270}], {
             RGBColor[
             0.9580845808516751, 0.9682601295461548, 0.9558360507126678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 295}], {
             RGBColor[
             0.9821446714325257, 0.9857149805489482, 0.8932045693363277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 102}], {
             RGBColor[
             0.9446273376563861, 0.8468481310609881, 0.5943782759552605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 129}], {
             RGBColor[
             0.9534235501569417, 0.8527902829756253, 0.5518110871748453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 165}], {
             RGBColor[
             0.919176599433657, 0.7172691800957552, 0.25382579861651994`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 175}], {
             RGBColor[
             0.9515396242733318, 0.8520033031020757, 0.5826775777258539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 183}], {
             RGBColor[
             0.9568815251118565, 0.8538286548173228, 0.46603905818212144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 224}], {
             RGBColor[
             0.9504270224096527, 0.8511735264538622, 0.5845609224680222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 253}], {
             RGBColor[
             0.9385047598546885, 0.7932744761603927, 0.2726296763898518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 262}], {
             RGBColor[
             0.9511604121093529, 0.8517204872910832, 0.5833194850050978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 41}], {
             RGBColor[
             0.5842118058470189, 0.5432760333855582, 0.5943798230240432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 55}], {
             RGBColor[
             0.6229843271610482, 0.6872050276007842, 0.8493502734812473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 152}], {
             RGBColor[
             0.6205575037797741, 0.6862014737661113, 0.8895690173265453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 208}], {
             RGBColor[
             0.6114152330541586, 0.6800869867445685, 0.9365622564038651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 242}], {
             RGBColor[
             0.6078951258687421, 0.6350609319497731, 0.6244330879907385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 250}], {
             RGBColor[
             0.6001419714566054, 0.6716794067033851, 0.9556449477510028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 268}], {
             RGBColor[
             0.6017590919743068, 0.6728854525376948, 0.9529075845271142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 41}], {
             RGBColor[
             0.9155613900380918, 0.8194999020082995, 0.6214248279368435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 44}], {
             RGBColor[
             0.9540800119011451, 0.96116041275987, 0.7233402005281833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 55}], {
             RGBColor[
             0.9543339113521211, 0.9634288962235253, 0.8763952783940474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 61}], {
             RGBColor[
             0.9543501659068359, 0.9617382448612828, 0.7527447968503608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 71}], {
             RGBColor[
             0.9517243001225872, 0.9623497549161636, 0.9196432899247993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 108}], {
             RGBColor[
             0.9535951811917107, 0.9631234123176966, 0.8886379489244187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 136}], {
             RGBColor[
             0.9520774811271833, 0.9624958043379019, 0.9137901666755022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 152}], {
             RGBColor[
             0.9519070879708471, 0.9624253423888525, 0.9166140222393455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 161}], {
             RGBColor[
             0.9298932722823663, 0.9467112782092254, 0.9853954295022128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 177}], {
             RGBColor[
             0.9279240264909838, 0.8685136359396317, 0.6313720954152142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 208}], {
             RGBColor[
             0.9427648172452314, 0.9563108553673096, 0.9636072613166654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 252}], {
             RGBColor[
             0.8945410762085726, 0.7273669926401793, 0.6040564663903268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 268}], {
             RGBColor[
             0.9331086761653795, 0.949109321160436, 0.9799525894399146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 279}], {
             RGBColor[
             0.9316463569280052, 0.9480187258675303, 0.9824279144748496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 280}], {
             RGBColor[
             0.9065086849115032, 0.7817091086541605, 0.6140425324449851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 52}], {
             RGBColor[
             0.9742663261441, 0.9383388235704977, 0.6054151878576175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 53}], {
             RGBColor[
             0.8717126262153387, 0.4291247430451252, 0.21915973718831835`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 57}], {
             RGBColor[
             0.9774255522641033, 0.9396452447595269, 0.5530586352340466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 88}], {
             RGBColor[
             0.8250925547319778, 0.8218772312516389, 0.6410937485885055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 124}], {
             RGBColor[
             0.9679802577258785, 0.9337869820497363, 0.6221595655182475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 147}], {
             RGBColor[
             0.8528186876967403, 0.8435370970501266, 0.6438572304069892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 247}], {
             RGBColor[
             0.9789590340181302, 0.9395166037605287, 0.4721991755966414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 289}], {
             RGBColor[
             0.9790536879991771, 0.9397190590550024, 0.4825016772969304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 64}], {
             RGBColor[
             0.7593006351357386, 0.8103856166920048, 0.9359933430022214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 69}], {
             RGBColor[
             0.9719307059224329, 0.9785865469529769, 0.9323981726156594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 76}], {
             RGBColor[
             0.9875464411578055, 0.9868539874923574, 0.7015574242065423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 85}], {
             RGBColor[
             0.9841804779103451, 0.9873647994655137, 0.8956481148310644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 90}], {
             RGBColor[
             0.9519505768813479, 0.8570571750677802, 0.5856652054493273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 118}], {
             RGBColor[
             0.9343735830920463, 0.7823304466336968, 0.5712616397580329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 126}], {
             RGBColor[
             0.9750296368557294, 0.9808977245689958, 0.9271524908762212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 153}], {
             RGBColor[
             0.9820432593086441, 0.9686443593730945, 0.6500858008869383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 166}], {
             RGBColor[
             0.9828401078505877, 0.9713323166140058, 0.6531814070001691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 195}], {
             RGBColor[
             0.9834876734626636, 0.9735167074791737, 0.6556970771205789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 234}], {
             RGBColor[
             0.9163994044785218, 0.9349816265856059, 0.9504775958314038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 239}], {
             RGBColor[
             0.9402014787203198, 0.9539607544959219, 0.952747858920949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 248}], {
             RGBColor[
             0.9878782007770703, 0.9888939028980477, 0.8343672775294031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 263}], {
             RGBColor[
             0.9551623415947359, 0.8697907518992191, 0.5882494667275266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 285}], {
             RGBColor[
             0.9868676579008735, 0.988476017448973, 0.8511145881891169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 42}], {
             RGBColor[
             0.959728933706518, 0.9694864852129159, 0.9530525902453293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 66}], {
             RGBColor[
             0.9272332072781386, 0.9441761826235914, 0.9707869622747509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 81}], {
             RGBColor[
             0.9677053697729155, 0.9754352981710198, 0.9395505645726281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 86}], {
             RGBColor[
             0.8991154947403364, 0.9217558818809224, 0.9681050697519171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 94}], {
             RGBColor[
             0.9142331553876903, 0.933810294123156, 0.9695470057201567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 97}], {
             RGBColor[
             0.9770828405483598, 0.9794911010793367, 0.7542491158542337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 120}], {
             RGBColor[
             0.9417027043403405, 0.9557137668169565, 0.9721670758216163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 130}], {
             RGBColor[
             0.8803750483832323, 0.5306986025803135, 0.44144546272374374`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 140}], {
             RGBColor[
             0.7452775848954648, 0.7997130595507539, 0.9539858599646487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 162}], {
             RGBColor[
             0.9640383150474127, 0.9362333584071232, 0.6402662796774717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 169}], {
             RGBColor[
             0.9744176425394948, 0.9797456992678422, 0.8970380062342213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 178}], {
             RGBColor[
             0.8775412327019312, 0.9047581093434331, 0.9659929077231972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 182}], {
             RGBColor[
             0.9761462425416101, 0.9804605197917106, 0.8683906307257645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 201}], {
             RGBColor[
             0.977484505601558, 0.9803502220135611, 0.7979678781054831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 202}], {
             RGBColor[
             0.9168035733100859, 0.74345909229595, 0.583843750857467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 55}], {
             RGBColor[
             0.9545094264937524, 0.847560932804295, 0.5060285903370074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 108}], {
             RGBColor[
             0.953770696333342, 0.847255448898466, 0.5182712608673787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 152}], {
             RGBColor[
             0.9520826031124783, 0.846557378969622, 0.5462473341823055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 208}], {
             RGBColor[
             0.9429403323868627, 0.8404428919480793, 0.5932405732596253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 219}], {
             RGBColor[
             0.9494471035582916, 0.8452956312338711, 0.5822263069041118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 242}], {
             RGBColor[
             0.9394202252014462, 0.7954168371532839, 0.28111140484649877`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.9316670707893095, 0.8320353119068958, 0.6123232646067631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 252}], {
             RGBColor[
             0.894716591350204, 0.6114990292209489, 0.2336897783332868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 268}], {
             RGBColor[
             0.9332841913070109, 0.8332413577412057, 0.6095859013828746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 80}], {
             RGBColor[
             0.9005172909074537, 0.9229111525599872, 0.9695394937542325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 81}], {
             RGBColor[
             0.9669779468955678, 0.9748927873801395, 0.9407819017617062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 82}], {
             RGBColor[
             0.9010063592820294, 0.9233011224064666, 0.9695861415323961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 87}], {
             RGBColor[
             0.9757276924924656, 0.980045735852962, 0.8645031458142604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 130}], {
             RGBColor[
             0.8798900997983338, 0.5303369287197267, 0.4422663541831291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 140}], {
             RGBColor[
             0.7445501620181171, 0.7991705487598736, 0.9552171971537269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 145}], {
             RGBColor[
             0.9763098577408271, 0.9802864761441239, 0.8548551610535411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 162}], {
             RGBColor[
             0.9633108921700649, 0.9356908476162429, 0.6414976168665498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 167}], {
             RGBColor[
             0.6964573291212202, 0.7595997332138298, 0.9515767336933092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 181}], {
             RGBColor[
             0.9602971306644791, 0.9699102455738262, 0.9520907810050021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 201}], {
             RGBColor[
             0.9767570827242102, 0.9798077112226808, 0.7991992152945613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 202}], {
             RGBColor[
             0.9160761504327382, 0.7429165815050697, 0.5850750880465452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 203}], {
             RGBColor[
             0.9287248339520937, 0.8003512991913718, 0.5956294596226998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 216}], {
             RGBColor[
             0.8949013301477029, 0.9184331378913557, 0.9690038384035402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 237}], {
             RGBColor[
             0.9683248725999044, 0.9758973223650453, 0.9385019078787503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 269}], {
             RGBColor[
             0.9288546515022038, 0.800940770366763, 0.595737782568631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 293}], {
             RGBColor[
             0.957114946862753, 0.9675369781048466, 0.9574773881348659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 299}], {
             RGBColor[
             0.9533188197252809, 0.9647058327013076, 0.9639032411900809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 66}], {
             RGBColor[
             0.9409321164477323, 0.9537843863438358, 0.9203519778066832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 78}], {
             RGBColor[
             0.8815901672831762, 0.47624679554209426`, 0.4002403450482267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 97}], {
             RGBColor[
             0.9907817497179534, 0.9890993047995811, 0.7038141313861659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 99}], {
             RGBColor[
             0.9761669826197559, 0.9811375348690405, 0.8979809566733336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 178}], {
             RGBColor[
             0.8912401418715248, 0.9143663130636777, 0.9155579232551295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 182}], {
             RGBColor[
             0.9898451517112038, 0.990068723511955, 0.8179556462576968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 199}], {
             RGBColor[
             0.9525897303941583, 0.963079851267215, 0.9214638914317681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 215}], {
             RGBColor[
             0.9835588158018195, 0.9866503519532075, 0.8854685111949578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 229}], {
             RGBColor[
             0.9324729647060284, 0.7620147955882277, 0.5350529850600039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 233}], {
             RGBColor[
             0.6852947401126949, 0.7475866104432777, 0.8982799086139035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 259}], {
             RGBColor[
             0.991305670895674, 0.9902199192221686, 0.7608397183143312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 261}], {
             RGBColor[
             0.9902440966438106, 0.9879493192390538, 0.6452939122758681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 284}], {
             RGBColor[
             0.9762192264218543, 0.9811764982111041, 0.8978925215437469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 59}], {
             RGBColor[
             0.9884203634554154, 0.972433963868497, 0.4237454893482624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 61}], {
             RGBColor[
             0.9930443029115205, 0.9875307921936227, 0.48429348138466055`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 71}], {
             RGBColor[
             0.9904184371272717, 0.9881423022485036, 0.651191974459099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 108}], {
             RGBColor[
             0.9922893181963953, 0.9889159596500365, 0.6201866334587185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 136}], {
             RGBColor[
             0.9907716181318678, 0.9882883516702419, 0.645338851209802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 177}], {
             RGBColor[
             0.9666181634956684, 0.8943061832719718, 0.362920779949514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 194}], {
             RGBColor[
             0.9731932603844295, 0.9759388617486014, 0.7091476095270076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 204}], {
             RGBColor[
             0.9402189478245933, 0.7848710477499378, 0.34143255027132546`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 226}], {
             RGBColor[
             0.958794885844026, 0.8632894943359446, 0.3566259871150743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 252}], {
             RGBColor[
             0.9332352132132573, 0.7531595399725194, 0.3356051509246266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 268}], {
             RGBColor[
             0.9718028131700642, 0.9749018684927762, 0.7115012739742144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 279}], {
             RGBColor[
             0.9703404939326898, 0.9738112731998704, 0.7139765990091493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 280}], {
             RGBColor[
             0.9452028219161878, 0.8075016559865006, 0.34559121697928485`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 283}], {
             RGBColor[
             0.9667358355479335, 0.9711229248786055, 0.720078345409065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 89}], {
             RGBColor[
             0.9765087360663822, 0.9315988996606301, 0.4331121005169907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 94}], {
             RGBColor[
             0.9309221730718353, 0.9434061525019006, 0.7787812779887481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 96}], {
             RGBColor[
             0.9727177555451677, 0.9763227435886049, 0.7685503289147069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 120}], {
             RGBColor[
             0.9583917220244854, 0.9653096251957012, 0.7814013480902077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 131}], {
             RGBColor[
             0.9663219506223555, 0.971552762749341, 0.779376758355945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 132}], {
             RGBColor[
             0.9938618867240245, 0.9892795212981653, 0.5732824338333055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 141}], {
             RGBColor[
             0.9866039459222191, 0.9656524129723637, 0.4723300844865008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 146}], {
             RGBColor[
             0.9921768102472707, 0.9897840921829593, 0.6885371231517623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 188}], {
             RGBColor[
             0.9944890869571126, 0.9906210391770699, 0.6415493085737838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 236}], {
             RGBColor[
             0.9902623604022345, 0.98899241797292, 0.7202645115213928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 260}], {
             RGBColor[
             0.9741271108677361, 0.9773738384805688, 0.7661646579723369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 281}], {
             RGBColor[
             0.6575351517323512, 0.7209404231761241, 0.7559898218553092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 294}], {
             RGBColor[
             0.9937020528647313, 0.9889376528348195, 0.5558855046294897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 60}], {
             RGBColor[
             0.9817496527068852, 0.9850657414460164, 0.8779919628066502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 62}], {
             RGBColor[
             0.9268701111049126, 0.763036305257262, 0.5748411787960284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 117}], {
             RGBColor[
             0.9595141441381323, 0.9693262955044996, 0.9534161729585149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 158}], {
             RGBColor[
             0.9648674024023121, 0.9733187467527689, 0.9443545030706246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 196}], {
             RGBColor[
             0.9824230653342232, 0.9801566103051067, 0.6732799136923394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 207}], {
             RGBColor[
             0.7191631980528899, 0.7780574188359406, 0.9397315442633469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 212}], {
             RGBColor[
             0.7558931462123188, 0.8078764454170732, 0.9426230603286905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 214}], {
             RGBColor[
             0.983638513863899, 0.983919973962518, 0.7066262559412032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 225}], {
             RGBColor[
             0.9837715210747493, 0.984204462937435, 0.7211032700169111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 265}], {
             RGBColor[
             0.9726739697116864, 0.9791408718700194, 0.9311400208946963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 276}], {
             RGBColor[
             0.8059920657857784, 0.8485490052574146, 0.9465670307959024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.9723912679413265, 0.9756244196169488, 0.7330141680845134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 112}], {
             RGBColor[
             0.5860542083722364, 0.6466090324089866, 0.7163592379665236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 131}], {
             RGBColor[
             0.9659954630185141, 0.9708544387776847, 0.7438405975257516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 133}], {
             RGBColor[
             0.7155623892623331, 0.7707851629718812, 0.7241719087904699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 146}], {
             RGBColor[
             0.9918503226434294, 0.9890857682113031, 0.6530009623215689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 170}], {
             RGBColor[
             0.9940307190104609, 0.9899874181427014, 0.6168661518349388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 190}], {
             RGBColor[
             0.9832475687710813, 0.9547335601057798, 0.42502337491169134`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.9719039047403152, 0.9137416564620997, 0.4571624706135261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 70}], {
             RGBColor[
             0.7804099236423632, 0.8246838746249793, 0.7976066148554064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 71}], {
             RGBColor[
             0.9912513630913643, 0.9899238466639646, 0.741850825427369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 73}], {
             RGBColor[
             0.977591376549703, 0.9803793191786401, 0.7937715234352043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 100}], {
             RGBColor[
             0.991094034466652, 0.9898587872344848, 0.7444581678922808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 119}], {
             RGBColor[
             0.9555540923288257, 0.8489200985025532, 0.4440070277678193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 122}], {
             RGBColor[
             0.9808107784178064, 0.9457369362793677, 0.4816067793093476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 138}], {
             RGBColor[
             0.9939956605550109, 0.9910586841904104, 0.6963707144405691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 161}], {
             RGBColor[
             0.9694203352511434, 0.9742853699570264, 0.8076029650047826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 244}], {
             RGBColor[
             0.9911898473366474, 0.9898984083185065, 0.7428703006806983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 266}], {
             RGBColor[
             0.9940957306099983, 0.98977968972502, 0.5987348977043789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 54}], {
             RGBColor[
             0.92123525081434, 0.9173788825107568, 0.6798513414071055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 102}], {
             RGBColor[
             0.9169025580262677, 0.9356844546977819, 0.9609831890434384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 143}], {
             RGBColor[
             0.9011246894562284, 0.9239173461521353, 0.9876910050053349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 172}], {
             RGBColor[
             0.9293139169687313, 0.9430011523723201, 0.8497511176795238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 174}], {
             RGBColor[
             0.9171512120012394, 0.9358699004251824, 0.9605622827231546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 238}], {
             RGBColor[
             0.8809667834221844, 0.7628712336482386, 0.6119080975544798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 298}], {
             RGBColor[
             0.9285913759883534, 0.9414557102753908, 0.771106990971433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 206}], {
             RGBColor[
             0.9777657910667286, 0.9824348735315143, 0.8999744637708733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 219}], {
             RGBColor[
             0.9757332094481284, 0.9814224478564124, 0.9259615259984109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 83}], {
             RGBColor[
             0.9919345845442635, 0.9909327576843997, 0.783328336935059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 101}], {
             RGBColor[
             0.9940880249906091, 0.9918232606498587, 0.7476402558138828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 104}], {
             RGBColor[
             0.995029478102277, 0.9920091545290439, 0.7172513692257712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 116}], {
             RGBColor[
             0.8966159081903913, 0.5743866469434507, 0.372798585967364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 142}], {
             RGBColor[
             0.9938519962849808, 0.9917256567144204, 0.7515518622888546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 149}], {
             RGBColor[
             0.9882764686253122, 0.9889794693307072, 0.8242234549032517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 197}], {
             RGBColor[
             0.7445513922329386, 0.7961846151107127, 0.8428153980505788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 198}], {
             RGBColor[
             0.9897745950573349, 0.9758527819078586, 0.5633712346020727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 204}], {
             RGBColor[
             0.9413382512874111, 0.7874973980123584, 0.48014564406718135`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 226}], {
             RGBColor[
             0.9599141893068437, 0.8659158445983652, 0.4953390809109302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 243}], {
             RGBColor[
             0.9685351589207589, 0.9742564328764795, 0.8576403428748754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 254}], {
             RGBColor[
             0.9836584762820513, 0.9552216771458464, 0.539611268092212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 283}], {
             RGBColor[
             0.9678551390107513, 0.9737492751410262, 0.858791439204921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 53}], {
             RGBColor[
             0.8788766745150451, 0.46227903126596703`, 0.4142475267362778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 57}], {
             RGBColor[
             0.9881716247136629, 0.9893766770907897, 0.8456903195559858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 84}], {
             RGBColor[
             0.9897190055304623, 0.9892777647816509, 0.7663436871262883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 88}], {
             RGBColor[
             0.8358386271815375, 0.8716086635829017, 0.9337254329104446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 93}], {
             RGBColor[
             0.9246163068754727, 0.9413200065540537, 0.942479080935697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 124}], {
             RGBColor[
             0.9787263301754382, 0.9835184143809991, 0.9147912498401867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 137}], {
             RGBColor[
             0.9900487399779722, 0.9901529124922435, 0.814581661807799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 147}], {
             RGBColor[
             0.8635647601462999, 0.8932685293813893, 0.9364889147289284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 217}], {
             RGBColor[
             0.9734484012174554, 0.93557977073502, 0.6022377039697653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 247}], {
             RGBColor[
             0.9897051064676898, 0.9892480360917915, 0.7648308599185806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 270}], {
             RGBColor[
             0.9620141682949869, 0.971054511414212, 0.9430805806738889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 271}], {
             RGBColor[
             0.9449309661426585, 0.8242686972710633, 0.570172388700304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 273}], {
             RGBColor[
             0.989331607218485, 0.988449158964309, 0.724177771612809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 289}], {
             RGBColor[
             0.9897997604487367, 0.9894504913862652, 0.7751333616188696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 295}], {
             RGBColor[
             0.9860742588758376, 0.9885093624170055, 0.8804490992975491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 88}], {
             RGBColor[
             0.7794274935736304, 0.38463796972006115`, 0.4380332338902031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 93}], {
             RGBColor[
             0.8386126133695873, 0.43111219836749587`, 0.4438689992403714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 107}], {
             RGBColor[
             0.8775449961680772, 0.4613767330772587, 0.42057084648555604`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 124}], {
             RGBColor[
             0.8746859622362309, 0.4592444702521261, 0.4254104451766978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 137}], {
             RGBColor[
             0.8822342354379201, 0.46366746899295574`, 0.35860405315510613`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 147}], {
             RGBColor[
             0.7979115822168054, 0.3990778802523862, 0.43987555510252563`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 217}], {
             RGBColor[
             0.871167342930909, 0.4272853744881401, 0.21704141459641688`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 247}], {
             RGBColor[
             0.8820051464310653, 0.463064218059321, 0.3254368518956271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 251}], {
             RGBColor[
             0.8521603184921622, 0.4419147706895782, 0.4451611914491417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 270}], {
             RGBColor[
             0.8635445209825966, 0.45093520160760137`, 0.44426999906583264`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 271}], {
             RGBColor[
             0.8521557195477111, 0.3530779921788356, 0.1956645377501094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 273}], {
             RGBColor[
             0.8817561469315954, 0.46253163330766606`, 0.2983347930251128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 289}], {
             RGBColor[
             0.8820682490850965, 0.4631991882556368, 0.3323051863624864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 75}], {
             RGBColor[
             0.9847655282813628, 0.9655662246900218, 0.5896014204237062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 102}], {
             RGBColor[
             0.9746523990712561, 0.9590794938727696, 0.6539933271525762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 111}], {
             RGBColor[
             0.9858549592265136, 0.9638106931697785, 0.41119096764265184`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 143}], {
             RGBColor[
             0.9588745305012167, 0.947312385327123, 0.6807011431144727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 163}], {
             RGBColor[
             0.8868056003396625, 0.8901305721844073, 0.6765130209531933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 165}], {
             RGBColor[
             0.9492016608485272, 0.8295005429075367, 0.3134408498138357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 172}], {
             RGBColor[
             0.9870637580137198, 0.9663961915473077, 0.5427612557886615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 174}], {
             RGBColor[
             0.9749010530462279, 0.95926493960017, 0.6535724208322924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 185}], {
             RGBColor[
             0.9653435743690472, 0.8934978510425875, 0.3264290123318543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 235}], {
             RGBColor[
             0.986783331402558, 0.9657963873815125, 0.5122385497561491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 238}], {
             RGBColor[
             0.9387166244671727, 0.7862662728232263, 0.3049182356636176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 298}], {
             RGBColor[
             0.9863412170333419, 0.9648507494503784, 0.4641171290805708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 108}], {
             RGBColor[
             0.9925432176473713, 0.991184443113692, 0.7732417113245827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 114}], {
             RGBColor[
             0.9746047046059325, 0.9272320141646233, 0.5221977228028694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 208}], {
             RGBColor[
             0.981712853700892, 0.9843718861633052, 0.8482110237168294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 219}], {
             RGBColor[
             0.988219624872321, 0.989224625449097, 0.8371967573613158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 242}], {
             RGBColor[
             0.9781927465154755, 0.9393458313685098, 0.5360818553037028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 250}], {
             RGBColor[
             0.9704395921033389, 0.9759643061221217, 0.867293715063967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 252}], {
             RGBColor[
             0.9334891126642333, 0.7554280234361748, 0.4886602287904908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 268}], {
             RGBColor[
             0.9720567126210402, 0.9771703519564315, 0.8645563518400785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 283}], {
             RGBColor[
             0.9669897349989095, 0.973391408342261, 0.8731334232749293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 57}], {
             RGBColor[
             0.9911844287903602, 0.9860571660204293, 0.606509272392741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 84}], {
             RGBColor[
             0.9927318096071596, 0.9859582537112904, 0.5271626399630434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 110}], {
             RGBColor[
             0.9753047154106973, 0.975400124274088, 0.6865019954102904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 148}], {
             RGBColor[
             0.9898777807206136, 0.97751751893983, 0.41517751883064624`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 191}], {
             RGBColor[
             0.9923585720350366, 0.9851599362846267, 0.48653803359276326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 217}], {
             RGBColor[
             0.9764612052941526, 0.9322602596646595, 0.36305665680652033`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 223}], {
             RGBColor[
             0.9652642057576007, 0.8896189414168517, 0.34492777053400636`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 246}], {
             RGBColor[
             0.9789239698034966, 0.9405677426392824, 0.37262403187126814`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 247}], {
             RGBColor[
             0.9927179105443871, 0.9859285250214309, 0.5256498127553357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 251}], {
             RGBColor[
             0.9479506686360324, 0.9542043539668167, 0.7052363220856076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 270}], {
             RGBColor[
             0.965026972371684, 0.9677350003438515, 0.703899533510644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 271}], {
             RGBColor[
             0.9479437702193556, 0.8209491862007029, 0.3309913415370591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 278}], {
             RGBColor[
             0.9878319288172142, 0.9706163800807933, 0.4072297705126538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 295}], {
             RGBColor[
             0.9890870629525347, 0.985189851346645, 0.6412680521343042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.9928782316504656, 0.9905841859706802, 0.7139871345027176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 217}], {
             RGBColor[
             0.9766076273374587, 0.9368861919240493, 0.5498811513461945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 223}], {
             RGBColor[
             0.9654106278009069, 0.8942448736762415, 0.5317522650736806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 247}], {
             RGBColor[
             0.9928643325876931, 0.9905544572808207, 0.7124743072950098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 278}], {
             RGBColor[
             0.9879783508605203, 0.9752423123401831, 0.594054265052328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 295}], {
             RGBColor[
             0.9892334849958409, 0.9898157836060348, 0.8280925466739784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 134}], {
             RGBColor[
             0.9666714256984048, 0.9054871116814833, 0.5633192392750495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 160}], {
             RGBColor[
             0.9664210466628154, 0.8953067656458548, 0.3401228176994664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 164}], {
             RGBColor[
             0.9416357345366604, 0.8874173569346753, 0.6326489854780386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 176}], {
             RGBColor[
             0.9698507036207796, 0.90584512170516, 0.44108816042672083`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 180}], {
             RGBColor[
             0.8035076645490282, 0.7786115672521217, 0.6209617804403069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 187}], {
             RGBColor[
             0.9643214767081383, 0.9043363463016698, 0.5942479413708903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 215}], {
             RGBColor[
             0.9623959224961585, 0.9029002711231809, 0.5975074023868014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 221}], {
             RGBColor[
             0.9701636376768965, 0.9065144560087074, 0.47514910122990306`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 230}], {
             RGBColor[
             0.9690366330220154, 0.9041039070095663, 0.3524815996126079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[
             0.9353446296096275, 0.7813700320668076, 0.2668349752085506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 288}], {
             RGBColor[
             0.9551901803437526, 0.8574224164188421, 0.2964930228210515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 296}], {
             RGBColor[
             0.9580168042404633, 0.8669572825453005, 0.30747392289664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 297}], {
             RGBColor[
             0.9693726433526767, 0.9066041345996521, 0.5185530722165607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 72}], {
             RGBColor[
             0.9869139689516002, 0.9739745205443552, 0.6059731935397394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 83}], {
             RGBColor[
             0.9864614956310314, 0.9737874111982661, 0.6134718474249825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 106}], {
             RGBColor[
             0.9247621195722003, 0.9267357153438461, 0.6898157060141672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 136}], {
             RGBColor[
             0.9864178326814534, 0.973769355446529, 0.6141954554955814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 155}], {
             RGBColor[
             0.9870184394630999, 0.97401772178563, 0.6042418468031744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[
             0.9688394749340151, 0.9614198655248885, 0.6780042138127871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 197}], {
             RGBColor[
             0.7390783033197066, 0.7790392686245791, 0.6729589085405023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 198}], {
             RGBColor[
             0.9843015061441028, 0.9587074354217249, 0.39351474509199613`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 210}], {
             RGBColor[
             0.9887055909042819, 0.973044036540704, 0.45479073693762095`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 226}], {
             RGBColor[
             0.9544411003936115, 0.8487704981122317, 0.32548259140085367`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 227}], {
             RGBColor[
             0.9887295400311839, 0.973095261301519, 0.4573974516040158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 241}], {
             RGBColor[
             0.7857838355054436, 0.8169569237132077, 0.6766357391221653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 290}], {
             RGBColor[
             0.9743696751549662, 0.965544279794802, 0.6686430273459363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 291}], {
             RGBColor[
             0.971574937752728, 0.9157777318972562, 0.34407443010228467`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 77}], {
             RGBColor[
             0.9840064874681415, 0.9648929782117524, 0.5996967832537026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 95}], {
             RGBColor[
             0.9699299871095974, 0.9158205346332071, 0.5532883105735148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 103}], {
             RGBColor[
             0.946847866697131, 0.8243076188584375, 0.5347158946826428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 127}], {
             RGBColor[
             0.950227722783341, 0.960924582078307, 0.9094331349447026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 145}], {
             RGBColor[
             0.9914444624169835, 0.9907300795892053, 0.7914509289794953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 148}], {
             RGBColor[
             0.988994137437828, 0.9817174927154095, 0.6190728615472709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 159}], {
             RGBColor[
             0.9817855706140943, 0.9574013041669753, 0.5910689406606853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 168}], {
             RGBColor[
             0.9911434827228373, 0.9906056167508506, 0.7964389414219784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 196}], {
             RGBColor[
             0.9899441328088209, 0.9849220501712888, 0.6227634141720054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 205}], {
             RGBColor[
             0.965300813319352, 0.8974674031356042, 0.5495635686812089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 212}], {
             RGBColor[
             0.7634142136869165, 0.8126418852832551, 0.8921065608083565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 225}], {
             RGBColor[
             0.9912925885493471, 0.988969902803617, 0.6705867704965771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 265}], {
             RGBColor[
             0.9801950371862842, 0.9839063117362015, 0.8806235213743623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 276}], {
             RGBColor[
             0.8135131332603761, 0.8533144451235966, 0.8960505312755684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 282}], {
             RGBColor[
             0.9863282876853002, 0.9884804799160917, 0.87024152808745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 71}], {
             RGBColor[
             0.9906885911329626, 0.9887201343499163, 0.6805965707812764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 108}], {
             RGBColor[
             0.9925594722020861, 0.9894937917514494, 0.6495912297808961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 136}], {
             RGBColor[
             0.9910417721375586, 0.9888661837716547, 0.6747434475319796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 161}], {
             RGBColor[
             0.9688575632927416, 0.9730816576429782, 0.7463487103586901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 177}], {
             RGBColor[
             0.9668883175013592, 0.8948840153733846, 0.3923253762716915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 194}], {
             RGBColor[
             0.9734634143901202, 0.9765166938500143, 0.7385522058491851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 252}], {
             RGBColor[
             0.933505367218948, 0.7537373720739322, 0.36500974724680413`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 268}], {
             RGBColor[
             0.9720729671757549, 0.9754797005941889, 0.7409058702963918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 279}], {
             RGBColor[
             0.9706106479383806, 0.9743891053012832, 0.743381195331327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 280}], {
             RGBColor[
             0.9454729759218785, 0.8080794880879134, 0.37499581330146237`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 117}], {
             RGBColor[
             0.9121556700107574, 0.752062299181927, 0.5997488894275591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 135}], {
             RGBColor[
             0.9094383373387522, 0.7500357169243694, 0.6043486248473975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 158}], {
             RGBColor[
             0.9175089282749371, 0.7560547504301963, 0.5906872195396689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 186}], {
             RGBColor[
             0.9126189805652574, 0.7524078354348716, 0.5989646255095362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 196}], {
             RGBColor[
             0.9350645912068483, 0.7628926139825342, 0.3196126301613836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 207}], {
             RGBColor[
             0.6718047239255149, 0.5607934225133681, 0.5860642607323912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 212}], {
             RGBColor[
             0.7085346720849439, 0.5906124490945006, 0.5889557767977347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 214}], {
             RGBColor[
             0.9362800397365241, 0.7666559776399453, 0.35295897241024743`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 225}], {
             RGBColor[
             0.9364130469473744, 0.7669404666148625, 0.3674359864859553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 265}], {
             RGBColor[
             0.9253154955843115, 0.7618768755474469, 0.5774727373637405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 276}], {
             RGBColor[
             0.7586335916584035, 0.6312850089348421, 0.5928997472649467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 286}], {
             RGBColor[
             0.897830566980763, 0.6255200182698011, 0.23628200809768116`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 71}], {
             RGBColor[
             0.9687152669976647, 0.9131494542029324, 0.562806709041872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 73}], {
             RGBColor[
             0.9550552804560034, 0.9036049267176076, 0.6147274070497073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 152}], {
             RGBColor[
             0.9688980548459246, 0.9132250416756211, 0.5597774413564183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 161}], {
             RGBColor[
             0.9468842391574438, 0.8975109774959942, 0.6285588486192857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 208}], {
             RGBColor[
             0.959755784120309, 0.9071105546540784, 0.6067706804337383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 244}], {
             RGBColor[
             0.9686537512429478, 0.913124015857474, 0.5638261842952013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 69}], {
             RGBColor[
             0.7492148787635721, 0.8028636761035532, 0.9530658977537456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 76}], {
             RGBColor[
             0.7648306139989447, 0.8111311166429338, 0.7222251493446287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 85}], {
             RGBColor[
             0.7614646507514844, 0.8116419286160901, 0.9163158399691507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 90}], {
             RGBColor[
             0.7292347497224869, 0.6813343042183566, 0.6063329305874137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 118}], {
             RGBColor[
             0.7116577559331855, 0.6066075757842732, 0.5919293648961192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 121}], {
             RGBColor[
             0.765709717712579, 0.813011430595378, 0.8179101633744832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 173}], {
             RGBColor[
             0.7629809779863911, 0.8122689688955564, 0.8911863735576526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 213}], {
             RGBColor[
             0.7462995367339424, 0.8006894187912901, 0.9580008113669305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 234}], {
             RGBColor[
             0.6936835773196608, 0.7592587557361823, 0.97114532096949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 239}], {
             RGBColor[
             0.7174856515614589, 0.7782378836464983, 0.9734155840590353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 249}], {
             RGBColor[
             0.7105363602392442, 0.772696707379652, 0.9727527544490169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 258}], {
             RGBColor[
             0.7572594535165853, 0.8088633067825683, 0.9394485310580196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 263}], {
             RGBColor[
             0.7324465144358752, 0.6940678810497954, 0.6089171918656129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 286}], {
             RGBColor[
             0.7263671524804332, 0.669965236723747, 0.6040255945352987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 70}], {
             RGBColor[
             0.7422894544635951, 0.686122636066125, 0.6060229460734112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 106}], {
             RGBColor[
             0.8918283618079392, 0.8044750174241658, 0.6200342839146626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 115}], {
             RGBColor[
             0.9511280583624753, 0.8505119647424436, 0.5824553386964404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 138}], {
             RGBColor[
             0.9558751913762429, 0.8524974456315562, 0.5047870456585739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 155}], {
             RGBColor[
             0.9540846816988386, 0.8517570238659496, 0.5344604247036697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 194}], {
             RGBColor[
             0.935905717169754, 0.8391591676052081, 0.6082227917132825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 200}], {
             RGBColor[
             0.9465310637775537, 0.8201314646309767, 0.30494371664384934`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[
             0.9557718331400208, 0.8507833386210237, 0.3850093148381164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 211}], {
             RGBColor[
             0.8711910567822069, 0.48283063720916986`, 0.21321207164103445`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 231}], {
             RGBColor[
             0.9135989988249018, 0.8218343324332926, 0.6221107867082176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 241}], {
             RGBColor[
             0.7528500777411825, 0.6946962257935274, 0.6068543170226608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 264}], {
             RGBColor[
             0.9565656157250317, 0.8524811593066317, 0.4714076505582828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 291}], {
             RGBColor[
             0.9386411799884669, 0.7935170339775759, 0.2742930080027801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 86}], {
             RGBColor[
             0.8658923454346092, 0.8959030685007174, 0.9870707789704168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 97}], {
             RGBColor[
             0.9438596912426327, 0.9536382876991318, 0.7732148250727334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 162}], {
             RGBColor[
             0.9308151657416857, 0.9103805450269183, 0.6592319888959715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 169}], {
             RGBColor[
             0.9411944932337677, 0.9538928858876372, 0.916003715452721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 187}], {
             RGBColor[
             0.9385623115384786, 0.9526254100312472, 0.9516097438656144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 193}], {
             RGBColor[
             0.9171873096919565, 0.9366839686524644, 0.9877920464984399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 215}], {
             RGBColor[
             0.9366367573264988, 0.9511893348527583, 0.9548692048815255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 228}], {
             RGBColor[
             0.9254916381018412, 0.9428773231834665, 0.9737349846162344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 118}], {
             RGBColor[
             0.9372402610926263, 0.7744459038687119, 0.3170542241470015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 166}], {
             RGBColor[
             0.9857067858511677, 0.9634477738490208, 0.3989739913891377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 173}], {
             RGBColor[
             0.9885634831458319, 0.9801072969799952, 0.616311232808535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 195}], {
             RGBColor[
             0.9863543514632435, 0.9656321647141889, 0.40148966150954757`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 213}], {
             RGBColor[
             0.9718820418933831, 0.9685277468757287, 0.6831256706178128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 234}], {
             RGBColor[
             0.9192660824791016, 0.927097083820621, 0.6962701802203723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 263}], {
             RGBColor[
             0.9580290195953158, 0.8619062091342342, 0.3340420511164953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 75}], {
             RGBColor[
             0.6216163356088559, 0.6866393279381733, 0.8720214337497261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 83}], {
             RGBColor[
             0.6207715598856883, 0.6862899914668978, 0.8860215536921031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 109}], {
             RGBColor[
             0.45750049894095385`, 0.5595221767321213, 0.9523392315595021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 111}], {
             RGBColor[
             0.6227057665540068, 0.6848837964179301, 0.6936109809686717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 143}], {
             RGBColor[
             0.59572533782871, 0.6683854885752745, 0.9631211564404927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 163}], {
             RGBColor[
             0.5236564076671557, 0.6112036754325588, 0.9589330342792132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 185}], {
             RGBColor[
             0.6021943816965403, 0.614570954290739, 0.6088490256578741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 218}], {
             RGBColor[
             0.6072658280322906, 0.6769923672732865, 0.9435861167677333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 235}], {
             RGBColor[
             0.6236341387300512, 0.686869490629664, 0.794658563082169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 292}], {
             RGBColor[
             0.6108660777967512, 0.6796774276527533, 0.9374918330120261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 76}], {
             RGBColor[
             0.977460684785639, 0.979332046903906, 0.7186299789580667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 85}], {
             RGBColor[
             0.9740947215381786, 0.9798428588770622, 0.9127206695825887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 90}], {
             RGBColor[
             0.9418648205091813, 0.8495352344793288, 0.6027377602008517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 118}], {
             RGBColor[
             0.9242878267198797, 0.7748085060452452, 0.5883341945095573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 121}], {
             RGBColor[
             0.9783397884992733, 0.9812123608563501, 0.8143149929879212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 126}], {
             RGBColor[
             0.9649438804835628, 0.9733757839805443, 0.9442250456277455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 166}], {
             RGBColor[
             0.9727543514784212, 0.9638103760255542, 0.6702539617516934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 173}], {
             RGBColor[
             0.9756110487730854, 0.9804698991565286, 0.8875912031710906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 195}], {
             RGBColor[
             0.9734019170904971, 0.9659947668907223, 0.6727696318721033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 213}], {
             RGBColor[
             0.9589296075206366, 0.9688903490522621, 0.9544056409803685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 234}], {
             RGBColor[
             0.9063136481063552, 0.9274596859971543, 0.967550150582928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 239}], {
             RGBColor[
             0.9301157223481532, 0.9464388139074704, 0.9698204136724733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 249}], {
             RGBColor[
             0.9231664310259384, 0.9408976376406242, 0.9691575840624549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 258}], {
             RGBColor[
             0.9698895243032796, 0.9770642370435405, 0.9358533606714576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 263}], {
             RGBColor[
             0.9450765852225693, 0.8622688113107675, 0.6053220214790509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 285}], {
             RGBColor[
             0.9767819015287069, 0.9809540768605214, 0.8681871429406411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 122}], {
             RGBColor[
             0.7667807012261547, 0.779904761981215, 0.6430068071657311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 138}], {
             RGBColor[
             0.7799655833633593, 0.8252265098922577, 0.8577707422969525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 211}], {
             RGBColor[
             0.7539179847736178, 0.46465001338297085`, 0.4485345360666202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 231}], {
             RGBColor[
             0.7376893908120181, 0.7945633966939942, 0.9750944833465962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 266}], {
             RGBColor[
             0.7800656534183468, 0.8239475154268672, 0.7601349255607625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 108}], {
             RGBColor[
             0.9899336064178375, 0.9901053018063302, 0.8164897228553345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 136}], {
             RGBColor[
             0.9884159063533099, 0.9894776938265355, 0.841641940606418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 161}], {
             RGBColor[
             0.9662316975084929, 0.9736931676978591, 0.9132472034331285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 177}], {
             RGBColor[
             0.9642624517171106, 0.8954955254282654, 0.55922386934613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 208}], {
             RGBColor[
             0.9791032424713582, 0.9832927448559434, 0.8914590352475811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 244}], {
             RGBColor[
             0.988001209593997, 0.989306206059339, 0.8485145391090442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 252}], {
             RGBColor[
             0.9308795014346993, 0.754348882128813, 0.5319082403212425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 268}], {
             RGBColor[
             0.9694471013915062, 0.9760912106490698, 0.9078043633708303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 279}], {
             RGBColor[
             0.9679847821541319, 0.975000615356164, 0.9102796884057653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 280}], {
             RGBColor[
             0.9428471101376299, 0.8086909981427942, 0.5418943063759007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 83}], {
             RGBColor[
             0.9893088865776307, 0.9898469640978372, 0.8268429473306802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 87}], {
             RGBColor[
             0.9911076170269801, 0.9905907853639073, 0.7970333288197752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 106}], {
             RGBColor[
             0.9276095105187996, 0.9427952682434173, 0.9031868059198649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 109}], {
             RGBColor[
             0.8260378256328962, 0.8630791493630607, 0.8931606251980793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 155}], {
             RGBColor[
             0.9898658304096992, 0.9900772746852011, 0.817612946708872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 194}], {
             RGBColor[
             0.9716868658806144, 0.9774794184244596, 0.8913753137184847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 210}], {
             RGBColor[
             0.9915529818508813, 0.9891035894402751, 0.6681618368433186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 218}], {
             RGBColor[
             0.975803154724233, 0.9805493399042259, 0.8844075104063104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 226}], {
             RGBColor[
             0.9572884913402109, 0.8648300510118028, 0.5388536913065514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 227}], {
             RGBColor[
             0.9915769309777831, 0.9891548142010902, 0.6707685515097135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 241}], {
             RGBColor[
             0.788631226452043, 0.833016476612779, 0.8900068390278629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 290}], {
             RGBColor[
             0.9772170661015656, 0.9816038326943731, 0.882014127251634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 291}], {
             RGBColor[
             0.9744223286993272, 0.9318372847968274, 0.5574455300079824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 100}], {
             RGBColor[
             0.9742454101823402, 0.9797220574899929, 0.902023104328462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 119}], {
             RGBColor[
             0.9387054680445139, 0.8387833687580613, 0.6015719642040005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 122}], {
             RGBColor[
             0.9639621541334946, 0.9356002065348757, 0.6391717157455288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 161}], {
             RGBColor[
             0.9525717109668316, 0.9641486402125344, 0.9651679014409638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 244}], {
             RGBColor[
             0.9743412230523356, 0.9797616785740144, 0.9004352371168794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 123}], {
             RGBColor[
             0.9820678940512533, 0.9846501186482035, 0.8482120815882093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 189}], {
             RGBColor[
             0.9278372046788339, 0.9423166722673972, 0.8745423959591256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 257}], {
             RGBColor[
             0.939272151531422, 0.9514345884942874, 0.8756330713980229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 260}], {
             RGBColor[
             0.9738104281305957, 0.9784917140849366, 0.8621898174998481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 267}], {
             RGBColor[
             0.9734281322789684, 0.9227109784867693, 0.52195411861877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 287}], {
             RGBColor[
             0.9743476630688587, 0.9263566116532133, 0.5226939946764775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 300}], {
             RGBColor[
             0.9937990410736224, 0.9909403287642, 0.6969361937513616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 111}], {
             RGBColor[
             0.9916353956485479, 0.9886029961740559, 0.6279309085501149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 143}], {
             RGBColor[
             0.964654966923251, 0.9721046883314004, 0.8974410840219358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.8925860367616967, 0.9149228751886846, 0.8932529618606564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 165}], {
             RGBColor[
             0.9549820972705614, 0.8542928459118141, 0.5301807907212988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 185}], {
             RGBColor[
             0.9711240107910815, 0.9182901540468649, 0.5431689532393174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 235}], {
             RGBColor[
             0.9925637678245923, 0.9905886903857899, 0.7289784906636122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 262}], {
             RGBColor[
             0.9869659099462572, 0.988744153107142, 0.8596744771098765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 292}], {
             RGBColor[
             0.9797957068912923, 0.9833966274088791, 0.8718117605934692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 85}], {
             RGBColor[
             0.9897104567735513, 0.9881102994164428, 0.6818799211734718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 87}], {
             RGBColor[
             0.9927651470883863, 0.9893734923635873, 0.6312557973715315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 90}], {
             RGBColor[
             0.9574805557445538, 0.8578026750187093, 0.3718970117917347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 126}], {
             RGBColor[
             0.9805596157189355, 0.9816432245199248, 0.7133842972186285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 151}], {
             RGBColor[
             0.938174267290434, 0.7752236233987155, 0.35605048024322467`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 153}], {
             RGBColor[
             0.98757323817185, 0.9693898593240236, 0.43631760722934576`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 192}], {
             RGBColor[
             0.8807536376285818, 0.9033113894676783, 0.7326714474352092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 220}], {
             RGBColor[
             0.9902138441451516, 0.9883184630310649, 0.6735374897012963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 239}], {
             RGBColor[
             0.9457314575835258, 0.954706254446851, 0.7389796652633563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 248}], {
             RGBColor[
             0.9934081796402765, 0.9896394028489768, 0.6205990838718105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 258}], {
             RGBColor[
             0.9855052595386522, 0.9853316775829211, 0.7050126122623406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 82}], {
             RGBColor[
             0.9108767312448443, 0.9088065227511017, 0.6784032294257369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 95}], {
             RGBColor[
             0.9646657543962559, 0.890882331532761, 0.32550963054090126`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 103}], {
             RGBColor[
             0.9415836339837894, 0.7993694157579914, 0.3069372146500292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 127}], {
             RGBColor[
             0.9449634900699995, 0.9359863789778609, 0.6816544549120891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 145}], {
             RGBColor[
             0.9861802297036419, 0.9657918764887591, 0.5636722489468818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 154}], {
             RGBColor[
             0.9631989805356341, 0.8850670619488099, 0.3243294298630374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 159}], {
             RGBColor[
             0.9765213379007527, 0.9324631010665292, 0.3632902606280718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 167}], {
             RGBColor[
             0.706327701084035, 0.7451051335584651, 0.66039382158665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 168}], {
             RGBColor[
             0.9858792500094957, 0.9656674136504043, 0.5686602613893648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 203}], {
             RGBColor[
             0.9385952059149085, 0.785856699536007, 0.30444654751604056`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 205}], {
             RGBColor[
             0.9600365806060105, 0.8725292000351581, 0.3217848886485954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 212}], {
             RGBColor[
             0.758149980973575, 0.787703682182809, 0.6643278807757429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 225}], {
             RGBColor[
             0.9860283558360056, 0.9640316997031708, 0.4428080904639636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 255}], {
             RGBColor[
             0.9696551527516162, 0.9550335362200768, 0.6617751435956163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 265}], {
             RGBColor[
             0.9749308044729426, 0.9589681086357553, 0.6528448413417487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 269}], {
             RGBColor[
             0.9387250234650186, 0.7864461707113983, 0.3045548704619718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 276}], {
             RGBColor[
             0.8082489005470346, 0.8283762420231504, 0.668271851242955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 282}], {
             RGBColor[
             0.9810640549719587, 0.9635422768156454, 0.6424628480548364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 293}], {
             RGBColor[
             0.9669853188255678, 0.9530423784494819, 0.6662944760282067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 99}], {
             RGBColor[
             0.8737987057476447, 0.4708415498252646, 0.43159346008370525`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 131}], {
             RGBColor[
             0.8652419454063437, 0.46445993197313135`, 0.44607782338100677`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 170}], {
             RGBColor[
             0.8839321160676414, 0.47721525154980915`, 0.3614281929204649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 178}], {
             RGBColor[
             0.8171808119154906, 0.4263274019550226, 0.44331143780490256`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 182}], {
             RGBColor[
             0.8829174851419433, 0.4767956755872075, 0.37824325313994733`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 190}], {
             RGBColor[
             0.8767433492413884, 0.4537126795251947, 0.2335330083049666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.8580805375972463, 0.45880309409071424`, 0.4472487499226616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 209}], {
             RGBColor[
             0.790809047572115, 0.40572557921714514`, 0.44068294679330433`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 229}], {
             RGBColor[
             0.8446693604718264, 0.32475972363805605`, 0.1896414790081521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 261}], {
             RGBColor[
             0.8831834484303479, 0.4753827394052734, 0.2631354304853949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 284}], {
             RGBColor[
             0.8738335349490437, 0.47086752538664023`, 0.43153450333064747`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 144}], {
             RGBColor[
             0.985636648266506, 0.9862963464644741, 0.7735575075552125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 160}], {
             RGBColor[
             0.9908171851639277, 0.9795645459099377, 0.5142171104945954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 176}], {
             RGBColor[
             0.994246842121892, 0.9901029019692429, 0.6151824532218498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 221}], {
             RGBColor[
             0.9945597761780088, 0.9907722362727903, 0.649243394025032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 232}], {
             RGBColor[
             0.8003733504528403, 0.8408119015220803, 0.7926884387545278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 240}], {
             RGBColor[
             0.9751674654024813, 0.9784884470261983, 0.7912791033438071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 245}], {
             RGBColor[
             0.9597407681107399, 0.8656278123308905, 0.4409292680036796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 288}], {
             RGBColor[
             0.9795863188448649, 0.941680196682925, 0.47058731561618045`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 297}], {
             RGBColor[
             0.993768781853789, 0.990861914863735, 0.6926473650116896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 92}], {
             RGBColor[
             0.8255570236619124, 0.381710776899313, 0.43774368669135255`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 125}], {
             RGBColor[
             0.8539224634150295, 0.5966736604875125, 0.46478639458189497`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 128}], {
             RGBColor[
             0.7986357144144682, 0.8427977714799701, 0.980516909773147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 145}], {
             RGBColor[
             0.9178256378191105, 0.9342536542820754, 0.8701107273733661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 149}], {
             RGBColor[
             0.9117866262024481, 0.9313158043711511, 0.9504634486131831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 150}], {
             RGBColor[
             0.9179267514355287, 0.9330345921439216, 0.7767826952720113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 156}], {
             RGBColor[
             0.8866863412797084, 0.8211849004226783, 0.6242037518805142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 167}], {
             RGBColor[
             0.6379731091995036, 0.7135669113517815, 0.9668323000131344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 179}], {
             RGBColor[
             0.9069131741918397, 0.9276811918411845, 0.9587129316672902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 201}], {
             RGBColor[
             0.9182728628024937, 0.9337748893606326, 0.8144547816143863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 205}], {
             RGBColor[
             0.8916819887214791, 0.8409909778284745, 0.6282233670750796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 237}], {
             RGBColor[
             0.9098406526781879, 0.9298645005029971, 0.9537574741985755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 256}], {
             RGBColor[
             0.5104800354928686, 0.5911361653489694, 0.9591480300370289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 269}], {
             RGBColor[
             0.8703704315804873, 0.7549079485047148, 0.6109933488884561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 277}], {
             RGBColor[
             0.9078383642615375, 0.9283711970803055, 0.9571468262075079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 281}], {
             RGBColor[
             0.581634491249142, 0.6647692321444507, 0.9632424530956211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 282}], {
             RGBColor[
             0.9127094630874273, 0.9320040546089619, 0.9489013264813209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 293}], {
             RGBColor[
             0.8986307269410365, 0.9215041562427982, 0.972732954454691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 86}], {
             RGBColor[
             0.906364507929386, 0.9271621840481459, 0.9558343812682939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 94}], {
             RGBColor[
             0.9214821685767403, 0.9392165962903796, 0.9572763172365335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 97}], {
             RGBColor[
             0.9843318537374096, 0.9848974032465603, 0.7419784273706105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.8852077238425988, 0.5343028040251293, 0.4332650037346616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 140}], {
             RGBColor[
             0.7525265980845146, 0.8051193617179775, 0.9417151714810255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 162}], {
             RGBColor[
             0.9712873282364625, 0.9416396605743468, 0.6279955911938485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 167}], {
             RGBColor[
             0.7044337651876177, 0.7655485461719338, 0.938074708020608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 181}], {
             RGBColor[
             0.9682735667308766, 0.97585905853193, 0.9385887553323008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 201}], {
             RGBColor[
             0.9847335187906078, 0.9857565241807849, 0.78569718962186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 202}], {
             RGBColor[
             0.9240525864991357, 0.7488653944631736, 0.5715730623738438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 203}], {
             RGBColor[
             0.9367012700184911, 0.8063001121494757, 0.5821274339499984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 216}], {
             RGBColor[
             0.9028777662141004, 0.9243819508494597, 0.9555018127308389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 237}], {
             RGBColor[
             0.9763013086663019, 0.9818461353231493, 0.924999882206049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 269}], {
             RGBColor[
             0.9368310875686015, 0.806889583324867, 0.5822357568959298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 293}], {
             RGBColor[
             0.9650913829291505, 0.9734857910629505, 0.9439753624621645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 299}], {
             RGBColor[
             0.9612952557916783, 0.9706546456594114, 0.9504012155173795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 103}], {
             RGBColor[
             0.8737181104738339, 0.7682211633977871, 0.6134223408546771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 140}], {
             RGBColor[
             0.6865550104709763, 0.7535276967443045, 0.9705194112517155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 145}], {
             RGBColor[
             0.9183147061936863, 0.9346436241285547, 0.8701573751515297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 154}], {
             RGBColor[
             0.8953334570256786, 0.8539188095886056, 0.6308145560676852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 167}], {
             RGBColor[
             0.6384621775740793, 0.7139568811982608, 0.9668789477912978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 168}], {
             RGBColor[0.91801372649954, 0.9345191612902, 0.8751453875940126]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 181}], {
             RGBColor[
             0.9023019791173383, 0.924267393558257, 0.9673929951029907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 201}], {
             RGBColor[
             0.9187619311770694, 0.9341648592071119, 0.8145014293925499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 203}], {
             RGBColor[
             0.8707296824049529, 0.7547084471758028, 0.6109316737206884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 216}], {
             RGBColor[
             0.836906178600562, 0.8727902858757868, 0.9843060525015288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 255}], {
             RGBColor[
             0.9017896292416605, 0.9238852838598726, 0.968260269800264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 258}], {
             RGBColor[
             0.9104726533955907, 0.9303610690567266, 0.953562174803058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 293}], {
             RGBColor[
             0.8991197953156123, 0.9218941260892776, 0.9727796022328545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 101}], {
             RGBColor[
             0.9910098537034074, 0.9905503577172071, 0.7986535200947471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 142}], {
             RGBColor[
             0.9907738249977791, 0.9904527537817687, 0.8025651265697189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 149}], {
             RGBColor[
             0.9851982973381105, 0.9877065663980558, 0.8752367191841159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 194}], {
             RGBColor[
             0.9712343925600455, 0.9772923090783705, 0.8988739676037277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[
             0.741473220945737, 0.7949117121780611, 0.8938286623314431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 198}], {
             RGBColor[
             0.9866964237701332, 0.9745798789752069, 0.6143844988829369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 226}], {
             RGBColor[
             0.956836018019642, 0.8646429416657138, 0.5463523451917944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 241}], {
             RGBColor[
             0.7881787531314741, 0.8328293672666898, 0.897505492913106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 243}], {
             RGBColor[
             0.9654569876335573, 0.9729835299438279, 0.9086536071557396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 290}], {
             RGBColor[
             0.9767645927809967, 0.981416723348284, 0.889512781136877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 291}], {
             RGBColor[
             0.9739698553787584, 0.9316501754507382, 0.5649441838932254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 191}], {
             RGBColor[
             0.9940523748951422, 0.9896869562348777, 0.5940158957027398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 217}], {
             RGBColor[
             0.978155008154258, 0.9367872796149105, 0.4705345189164969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 223}], {
             RGBColor[
             0.9669580086177063, 0.8941459613671027, 0.4524056326439829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 246}], {
             RGBColor[
             0.9806177726636021, 0.9450947625895334, 0.4801018939812447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 247}], {
             RGBColor[
             0.9944117134044925, 0.9904555449716819, 0.6331276748653123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 270}], {
             RGBColor[
             0.9667207752317896, 0.9722620202941025, 0.8113773956206206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 271}], {
             RGBColor[
             0.9496375730794612, 0.8254762061509539, 0.4384692036470357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 278}], {
             RGBColor[
             0.9895257316773197, 0.9751434000310443, 0.5147076326226303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 295}], {
             RGBColor[
             0.9907808658126402, 0.989716871296896, 0.7487459142442807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[
             0.9905895604871855, 0.9899906133688869, 0.7775649352033263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 135}], {
             RGBColor[
             0.9628547656130289, 0.9714601181518243, 0.9317469831138581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 154}], {
             RGBColor[
             0.9670000999212796, 0.9094002300879563, 0.5763556841514899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 173}], {
             RGBColor[
             0.9878608207609976, 0.9892481516690654, 0.8508411453864957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 213}], {
             RGBColor[
             0.9711793795085489, 0.977668601564799, 0.9176555831957737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 234}], {
             RGBColor[
             0.9185634200942674, 0.9362379385096912, 0.9308000927983332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 239}], {
             RGBColor[
             0.9423654943360655, 0.9552170664200073, 0.9330703558878783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 249}], {
             RGBColor[
             0.9354162030138506, 0.949675890153161, 0.9324075262778599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 255}], {
             RGBColor[
             0.9734562721372617, 0.9793667043592234, 0.9138013978840687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 258}], {
             RGBColor[
             0.9821392962911919, 0.9858424895560773, 0.8991033028868627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 263}], {
             RGBColor[
             0.9573263572104816, 0.8710470638233043, 0.5685719636944561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 286}], {
             RGBColor[
             0.9512469952550396, 0.846944419497256, 0.5636803663641419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[
             0.852892293544161, 0.885537180000282, 0.9858308224158225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 97}], {
             RGBColor[
             0.9157419787048304, 0.9312179869564627, 0.7705329325498995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 120}], {
             RGBColor[
             0.8803618424968112, 0.9074406526940826, 0.9884508925172821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 130}], {
             RGBColor[
             0.839481140487546, 0.4985165264983977, 0.45230134052085424`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 140}], {
             RGBColor[
             0.6839367230519353, 0.75143994542788, 0.9702696766603145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 162}], {
             RGBColor[
             0.9026974532038832, 0.8879602442842494, 0.6565500963731375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 169}], {
             RGBColor[
             0.9130767806959653, 0.9314725851449682, 0.9133218229298872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[
             0.8162003708584017, 0.8564849952205593, 0.9822767244188632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 182}], {
             RGBColor[
             0.9148053806980807, 0.9321874056688366, 0.8846744474214304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 202}], {
             RGBColor[
             0.8554627114665565, 0.695185978173076, 0.6001275675531328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 261}], {
             RGBColor[
             0.9152043256306874, 0.9300680013959355, 0.7120127134396017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 284}], {
             RGBColor[
             0.9011794554087311, 0.9232951803679859, 0.9646113227074805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 109}], {
             RGBColor[
             0.8273840827616769, 0.8636358612830417, 0.8708496605724172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 140}], {
             RGBColor[
             0.7612763436814123, 0.8102723101907998, 0.8654364155335796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 151}], {
             RGBColor[
             0.9378629943578085, 0.7769976283190164, 0.4995170470658064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[
             0.9700547902361145, 0.910663423035101, 0.5257315603495495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 155}], {
             RGBColor[
             0.9912120875384798, 0.9906339866051821, 0.7953019820832101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 162}], {
             RGBColor[
             0.9800370738333601, 0.9467926090471692, 0.5517168352464027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 181}], {
             RGBColor[
             0.9770233123277743, 0.9810120070047524, 0.862309999384855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 202}], {
             RGBColor[
             0.9328023320960335, 0.7540183429359959, 0.495294306426398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 203}], {
             RGBColor[
             0.9454510156153889, 0.811453060622298, 0.5058486780025526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 216}], {
             RGBColor[
             0.9116275118109982, 0.9295348993222821, 0.8792230567833931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 227}], {
             RGBColor[
             0.9929231881065638, 0.9897115261210712, 0.6484575868840514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 258}], {
             RGBColor[
             0.9851939866060269, 0.9871056825032218, 0.8484791790849224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 299}], {
             RGBColor[
             0.9700450013885761, 0.9758075941322338, 0.8741224595699337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 93}], {
             RGBColor[
             0.7754425354633506, 0.8248584142351949, 0.978157641666585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 107}], {
             RGBColor[
             0.8338411096610856, 0.8702552162998392, 0.943210412534362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 124}], {
             RGBColor[
             0.8295525587633161, 0.8670568220621403, 0.9504698105710747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 137}], {
             RGBColor[
             0.8408749685658501, 0.8736913201733847, 0.850260222538687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 147}], {
             RGBColor[
             0.7143909887341777, 0.7768069370625306, 0.9721674754598164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 273}], {
             RGBColor[
             0.8401578358063628, 0.8719875666454502, 0.7598563323436971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 274}], {
             RGBColor[
             0.7725336264117622, 0.822538929117691, 0.9778801873244307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 289}], {
             RGBColor[
             0.8406259890366146, 0.8729888990674064, 0.8108119223497576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 94}], {
             RGBColor[
             0.9135965171860619, 0.8857843394012452, 0.6416035809123047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 120}], {
             RGBColor[
             0.941066066138712, 0.9076878120950458, 0.6442236510137643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 131}], {
             RGBColor[
             0.9489962947365822, 0.9139309496486856, 0.6421990612795017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 141}], {
             RGBColor[
             0.9692782900364457, 0.9080305998717083, 0.3351523874100575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 188}], {
             RGBColor[
             0.9771634310713393, 0.9329992260764145, 0.5043716114973404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 236}], {
             RGBColor[
             0.9729367045164612, 0.9313706048722646, 0.5830868144449495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 260}], {
             RGBColor[
             0.9568014549819628, 0.9197520253799134, 0.6289869608958936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 281}], {
             RGBColor[
             0.6402094958465778, 0.6633186100754687, 0.6188121247788658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 294}], {
             RGBColor[
             0.9763763969789581, 0.9313158397341641, 0.4187078075530464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 118}], {
             RGBColor[
             0.9043076976787947, 0.6532791341600486, 0.2416012273432252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 126}], {
             RGBColor[
             0.9449637514424778, 0.8518464120953475, 0.5974920784614135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 153}], {
             RGBColor[
             0.9519773738953924, 0.8395930468994462, 0.3204253884721307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.9527742224373361, 0.8422810041403574, 0.3235209945853614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 195}], {
             RGBColor[
             0.9534217880494119, 0.8444653950055256, 0.3260366647057712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 222}], {
             RGBColor[
             0.9051674205225555, 0.820947955901361, 0.6226135777508143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 234}], {
             RGBColor[
             0.88633351906527, 0.8059303141119576, 0.6208171834165961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 239}], {
             RGBColor[
             0.9101355933070681, 0.8249094420222738, 0.6230874465061413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 248}], {
             RGBColor[
             0.9578123153638187, 0.8598425904243995, 0.5047068651145954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 285}], {
             RGBColor[
             0.9568017724876219, 0.8594247049753247, 0.5214541757743092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 93}], {
             RGBColor[
             0.9292683033576994, 0.9424107091935701, 0.8048318849184923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 105}], {
             RGBColor[
             0.6885258484302249, 0.7480897393115318, 0.7841805066264191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 107}], {
             RGBColor[
             0.9876668775554345, 0.9878075112582143, 0.7698846557862693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 139}], {
             RGBColor[
             0.994729407863112, 0.991135061294832, 0.6677067561031136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 142}], {
             RGBColor[
             0.9935038141483046, 0.9907486569962912, 0.6967705660343309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 143}], {
             RGBColor[
             0.9665401803506091, 0.9720512550746473, 0.8056466434289247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 150}], {
             RGBColor[
             0.9940684117217167, 0.9897212573853487, 0.595761405307556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 163}], {
             RGBColor[
             0.8944712501890548, 0.9148694419319316, 0.8014585212676453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 179}], {
             RGBColor[
             0.9830548344780276, 0.9843678570826117, 0.7776916417028349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 235}], {
             RGBColor[
             0.9944489812519504, 0.9905352571290368, 0.6371840500706012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 273}], {
             RGBColor[
             0.9939836037007117, 0.9895398616038253, 0.5865305755956044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 274}], {
             RGBColor[
             0.926359394306111, 0.9400912240760662, 0.804554430576338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 298}], {
             RGBColor[
             0.9940068668827341, 0.9895896191979028, 0.5890626293950227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 125}], {
             RGBColor[
             0.8315017198765585, 0.24160844179409974`, 0.17773935394527118`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 128}], {
             RGBColor[
             0.7966254526143998, 0.35899040408733374`, 0.43489158649074544`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 142}], {
             RGBColor[
             0.8757764122461654, 0.4198332176039298, 0.3664082173078382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 149}], {
             RGBColor[
             0.8720593938063864, 0.41800242601478776`, 0.4148559457174362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 150}], {
             RGBColor[
             0.8761528106284401, 0.4191482845299681, 0.2990687768233216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 179}], {
             RGBColor[
             0.868810425799314, 0.41557935099481, 0.4203556010868409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 237}], {
             RGBColor[
             0.8707620781235462, 0.417034890102685, 0.4170519627743644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 243}], {
             RGBColor[
             0.8588985206700176, 0.40818706837863583`, 0.437133871031852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 256}], {
             RGBColor[0.6045216666666666, 0.191216, 0.4206456666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 269}], {
             RGBColor[
             0.8444485973917458, 0.3003971887704968, 0.1885425459009515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 277}], {
             RGBColor[
             0.8694272191791126, 0.41603935448755736`, 0.41931153078031935`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 281}], {
             RGBColor[
             0.6519579705041822, 0.24030471119698749`, 0.4233752820390615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 105}], {
             RGBColor[
             0.6234777602298113, 0.7002487873243086, 0.9662599113997643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 107}], {
             RGBColor[
             0.9226187893550208, 0.9399665592709912, 0.9519640605596144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 137}], {
             RGBColor[
             0.9296526482597853, 0.9434026631445368, 0.8590138705639394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 139}], {
             RGBColor[
             0.9296813196626985, 0.943294109307609, 0.8497861608764586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 147}], {
             RGBColor[
             0.803168668428113, 0.8465182800336826, 0.9809211234850688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 273}], {
             RGBColor[
             0.9289355155002981, 0.9416989096166023, 0.7686099803689495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 274}], {
             RGBColor[
             0.8613113061056974, 0.8922502720888431, 0.9866338353496831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 289}], {
             RGBColor[
             0.9294036687305498, 0.9427002420385584, 0.81956557037501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 97}], {
             RGBColor[
             0.9308596393521844, 0.9432723991986964, 0.7719748685181391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 120}], {
             RGBColor[
             0.8954795031441651, 0.9194950649363163, 0.9898928284855217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 130}], {
             RGBColor[
             0.8495595809191154, 0.5065528013265534, 0.45326263116634735`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 141}], {
             RGBColor[
             0.9236917270418988, 0.9198378527129788, 0.6808215648818149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 188}], {
             RGBColor[
             0.9315768680767924, 0.944806478917685, 0.8500407889690978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 201}], {
             RGBColor[
             0.9312613044053826, 0.944131520132921, 0.8156936307693886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 202}], {
             RGBColor[
             0.8705803721139105, 0.7072403904153097, 0.6015695035213724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.9228290942810768, 0.9402211312752855, 0.9549963233535776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 281}], {
             RGBColor[
             0.5946229328520309, 0.6751258629167392, 0.9644813022506233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 293}], {
             RGBColor[
             0.9116191685439254, 0.9318607870150867, 0.9739718036096932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 294}], {
             RGBColor[
             0.9307898339844112, 0.9431230925754346, 0.7643769850248038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 103}], {
             RGBColor[
             0.9275071336252454, 0.7502969721794462, 0.26052874196984144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 127}], {
             RGBColor[
             0.9308869897114554, 0.8869139353993156, 0.6352459822319012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 145}], {
             RGBColor[
             0.9721037293450979, 0.916719432910214, 0.5172637762666941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 148}], {
             RGBColor[
             0.9696534043659425, 0.9077068460364182, 0.34488570883446956`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 156}], {
             RGBColor[
             0.9409644328056956, 0.8036506790508169, 0.27135680077384217`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 159}], {
             RGBColor[
             0.9624448375422088, 0.883390657487984, 0.3168817879478839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 168}], {
             RGBColor[
             0.9718027496509517, 0.9165949700718592, 0.522251788709177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 191}], {
             RGBColor[
             0.9721341956803655, 0.9153492633812149, 0.4162462235965866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 205}], {
             RGBColor[
             0.9459600802474665, 0.823456756456613, 0.27537641596840756`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 212}], {
             RGBColor[
             0.744073480615031, 0.7386312386042638, 0.6179194080955551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 225}], {
             RGBColor[
             0.9719518554774615, 0.9149592561246257, 0.39639961778377575`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 251}], {
             RGBColor[
             0.9277262922813614, 0.8843936810634049, 0.6349445120894309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 271}], {
             RGBColor[
             0.9277193938646846, 0.7511385132972911, 0.26069953154088243`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 276}], {
             RGBColor[
             0.7941724001884906, 0.7793037984446053, 0.6218633785627672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 282}], {
             RGBColor[
             0.9669875546134147, 0.9144698332371004, 0.5960543753746487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 112}], {
             RGBColor[
             0.56526405956909, 0.6344093872079621, 0.9501559301179898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 132}], {
             RGBColor[
             0.9727452503170366, 0.9763815521254848, 0.7715429651545782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 133}], {
             RGBColor[
             0.6947722404591865, 0.7585855177708567, 0.9579686009419361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 146}], {
             RGBColor[
             0.9710601738402829, 0.9768861230102788, 0.8867976544730352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 236}], {
             RGBColor[
             0.9691457239952467, 0.9760944488002394, 0.9185250428426657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 260}], {
             RGBColor[
             0.9530104744607483, 0.9644758693078883, 0.9644251892936097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 267}], {
             RGBColor[
             0.9526281786091209, 0.9086951337097209, 0.6241894904125315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 120}], {
             RGBColor[
             0.9583291883048346, 0.965175871892497, 0.7745949386195987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 130}], {
             RGBColor[
             0.8914593710262283, 0.5370066726306739, 0.3097307045890653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 178}], {
             RGBColor[
             0.8941677166664252, 0.9142202144189737, 0.7684207705211797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 182}], {
             RGBColor[
             0.9927727265061042, 0.989922624867251, 0.670818493523747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 202}], {
             RGBColor[
             0.93343005727458, 0.7529211973714904, 0.38627161365544943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 261}], {
             RGBColor[
             0.993171671438711, 0.9878032205943499, 0.4981567595419183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 284}], {
             RGBColor[
             0.9791468012167547, 0.9810303995664001, 0.7507553688097971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 157}], {
             RGBColor[
             0.9318557418115898, 0.7463722138003893, 0.3579939122708967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.8183719651801412, 0.6610864352673604, 0.5954955609660908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 275}], {
             RGBColor[
             0.8753041964023944, 0.706048278363606, 0.6010410771618888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 285}], {
             RGBColor[
             0.931110151737032, 0.747851350729309, 0.5002795664388078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 182}], {
             RGBColor[
             0.9781579594079066, 0.9819608549367105, 0.8649853188109147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 199}], {
             RGBColor[
             0.9409025380908611, 0.9549719826919705, 0.968493563984986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 209}], {
             RGBColor[
             0.8399953030531642, 0.8753557103816169, 0.9586448592909502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 215}], {
             RGBColor[
             0.9718716234985223, 0.978542483377963, 0.9324981837481758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 229}], {
             RGBColor[
             0.9207857724027312, 0.7539069270129832, 0.5820826576132218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 233}], {
             RGBColor[
             0.6736075478093978, 0.7394787418680332, 0.9453095811671213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 259}], {
             RGBColor[
             0.9796184785923769, 0.9821120506469241, 0.807869390867549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 284}], {
             RGBColor[
             0.9645320341185571, 0.9730686296358596, 0.9449221940969648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 119}], {
             RGBColor[
             0.952208125961463, 0.848262836813906, 0.552258608661077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 122}], {
             RGBColor[
             0.9774648120504437, 0.9450796745907206, 0.5898583602026053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 161}], {
             RGBColor[
             0.9660743688837806, 0.9736281082683793, 0.9158545458980403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 244}], {
             RGBColor[
             0.9878438809692847, 0.9892411466298593, 0.851121881573956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 266}], {
             RGBColor[
             0.9907497642426356, 0.9891224280363727, 0.7069864785976367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 104}], {
             RGBColor[
             0.9941047472614211, 0.9916267545618513, 0.732576552385459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 116}], {
             RGBColor[
             0.8959994209631539, 0.574131713631989, 0.3830153747404893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 136}], {
             RGBColor[
             0.9909661907538294, 0.9905323019654699, 0.7993771281653459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 149}], {
             RGBColor[
             0.9873517377844561, 0.9885970693635147, 0.8395486380629398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 197}], {
             RGBColor[
             0.7436266613920826, 0.7958022151435201, 0.8581405812102669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 198}], {
             RGBColor[
             0.9888498642164789, 0.975470381940666, 0.5786964177617606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[
             0.9404135204465549, 0.7871149980451658, 0.49547082722686936`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 226}], {
             RGBColor[
             0.9589894584659876, 0.8655334446311727, 0.5106642640706183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 243}], {
             RGBColor[
             0.9676104280799029, 0.9738740329092869, 0.8729655260345635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 254}], {
             RGBColor[
             0.9827337454411951, 0.9548392771786538, 0.5549364512519002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 283}], {
             RGBColor[
             0.9669304081698952, 0.9733668751738336, 0.8741166223646089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 165}], {
             RGBColor[
             0.9448689680604547, 0.8478061150945618, 0.5945726974501687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 172}], {
             RGBColor[
             0.9827310652256473, 0.9847017637343328, 0.8238931034249946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 175}], {
             RGBColor[
             0.9772319929001295, 0.9825402381008823, 0.9234244765595028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 183}], {
             RGBColor[
             0.9825738937386543, 0.9843655898161294, 0.8067859570157703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 238}], {
             RGBColor[
             0.9343839316791004, 0.8045718450102514, 0.5860500832999507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 253}], {
             RGBColor[
             0.9641971284814862, 0.9238114111591993, 0.6133765752235005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 127}], {
             RGBColor[
             0.907804869298989, 0.795401019624546, 0.6166735663410292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 145}], {
             RGBColor[
             0.9490216089326314, 0.8252065171354444, 0.498691360375822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 154}], {
             RGBColor[
             0.9260403597646236, 0.7444817025954951, 0.2593485412919776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 159}], {
             RGBColor[
             0.9393627171297423, 0.7918777417132143, 0.2983093720570119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 167}], {
             RGBColor[
             0.6691690803130245, 0.6045197742051504, 0.5954129330155902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 168}], {
             RGBColor[
             0.9487206292384852, 0.8250820542970896, 0.5036793728183049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 203}], {
             RGBColor[
             0.9014365851438979, 0.6452713401826924, 0.23946565894498067`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 205}], {
             RGBColor[
             0.922877959835, 0.7319438406818434, 0.25680400007753557`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 212}], {
             RGBColor[
             0.7209913602025645, 0.6471183228294942, 0.599346992204683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 225}], {
             RGBColor[
             0.9488697350649951, 0.8234463403498561, 0.37782720189290375`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 255}], {
             RGBColor[
             0.9324965319806057, 0.8144481768667622, 0.5967942550245564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 265}], {
             RGBColor[
             0.9377721837019322, 0.8183827492824405, 0.5878639527706888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 269}], {
             RGBColor[
             0.9015664026940082, 0.6458608113580836, 0.23957398189091197`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 276}], {
             RGBColor[
             0.7710902797760241, 0.6877908826698357, 0.6032909626718952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 282}], {
             RGBColor[
             0.9439054342009482, 0.8229569174623308, 0.5774819594837766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 293}], {
             RGBColor[
             0.9298266980545573, 0.8124570190961671, 0.6013135874571469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 114}], {
             RGBColor[
             0.9754868308885862, 0.9273933748753811, 0.4927920353044374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 116}], {
             RGBColor[
             0.8966270563709325, 0.5742556428847791, 0.3627561170150814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 204}], {
             RGBColor[
             0.941354973558223, 0.7873008919243512, 0.46508194063875763`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 206}], {
             RGBColor[
             0.9911343327735749, 0.9903984118349567, 0.7818040076353463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 243}], {
             RGBColor[
             0.9685518811915709, 0.9740599267884722, 0.8425766394464518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 254}], {
             RGBColor[
             0.9836751985528631, 0.955025171057839, 0.5245475646637884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 283}], {
             RGBColor[
             0.9678718612815631, 0.9735527690530188, 0.8437277357764972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 287}], {
             RGBColor[
             0.9752702500164658, 0.9265347038887211, 0.4926177692509229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 300}], {
             RGBColor[
             0.9947216280212294, 0.9911184209997077, 0.666859968325807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 139}], {
             RGBColor[
             0.6889388647352239, 0.7489731394255706, 0.8291347825843856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 143}], {
             RGBColor[
             0.6607496372227208, 0.729889333205386, 0.9670746699101967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 163}], {
             RGBColor[
             0.5886807070611666, 0.6727075200626702, 0.9628865477489172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 174}], {
             RGBColor[
             0.676776159767732, 0.7418418874784329, 0.9399459476280163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 235}], {
             RGBColor[
             0.6886584381240621, 0.7483733352597755, 0.7986120765518732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 274}], {
             RGBColor[
             0.6205688511782228, 0.6979293022068047, 0.9659824570576101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 298}], {
             RGBColor[
             0.688216323754846, 0.7474276973286413, 0.7504906558762947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 115}], {
             RGBColor[
             0.9247573576939359, 0.941593410361186, 0.9494503731760702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 155}], {
             RGBColor[
             0.9277139810302992, 0.9428384694846921, 0.9014554591832997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 162}], {
             RGBColor[
             0.9165389673251796, 0.8989970919266792, 0.6578703123464924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 194}], {
             RGBColor[
             0.9095350165012145, 0.9302406132239506, 0.9752178261929123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 200}], {
             RGBColor[
             0.9201603631090142, 0.9112129102497192, 0.6719387511234793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 210}], {
             RGBColor[
             0.9294011324714813, 0.941864784239766, 0.7520043493177464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 211}], {
             RGBColor[
             0.8536105896698473, 0.5435516009549981, 0.45787542796078773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 227}], {
             RGBColor[
             0.9294250815983832, 0.9419160090005811, 0.7546110639841411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 241}], {
             RGBColor[
             0.726479377072643, 0.78577767141227, 0.9738493515022906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 264}], {
             RGBColor[
             0.9301949150564922, 0.9435626049253741, 0.8384026850379127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 290}], {
             RGBColor[
             0.9150652167221656, 0.9343650274938641, 0.9658566397260617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 291}], {
             RGBColor[
             0.9122704793199273, 0.8845984795963183, 0.6412880424824101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 137}], {
             RGBColor[
             0.9880512224575202, 0.9887994652091809, 0.8240666414317164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 139}], {
             RGBColor[
             0.9880798938604334, 0.9886909113722532, 0.8148389317442356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[
             0.861567242625848, 0.8919150820983268, 0.9459738943528457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 150}], {
             RGBColor[
             0.9874188977190381, 0.9872771074627699, 0.7428935809486781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.9561784875632175, 0.8754274157415266, 0.590314637557181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.9764053204753489, 0.9819237071600329, 0.9248238173439569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 251}], {
             RGBColor[
             0.9429403470388833, 0.9561704177541146, 0.9539023488727698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 273}], {
             RGBColor[
             0.9873340896980332, 0.9870957116812464, 0.7336627512367264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 274}], {
             RGBColor[
             0.9197098803034324, 0.9376470741534872, 0.95168660621746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 277}], {
             RGBColor[
             0.9773305105450468, 0.9826137123991538, 0.9232577118841747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 289}], {
             RGBColor[
             0.9878022429282849, 0.9880970441032026, 0.784618341242787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 136}], {
             RGBColor[
             0.9902867874224335, 0.9902513512280685, 0.8106365996060375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 177}], {
             RGBColor[
             0.966133332786234, 0.8962691828297984, 0.5282185283457496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 204}], {
             RGBColor[
             0.939734117115159, 0.7868340473077644, 0.506730298667561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 208}], {
             RGBColor[
             0.9809741235404816, 0.9840664022574763, 0.8604536942472008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 252}], {
             RGBColor[
             0.9327503825038228, 0.755122539530346, 0.5009028993208622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 254}], {
             RGBColor[
             0.9820543421097991, 0.9545583264412523, 0.5661959226925917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 268}], {
             RGBColor[
             0.9713179824606297, 0.9768648680506027, 0.8767990223704498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 279}], {
             RGBColor[
             0.9698556632232554, 0.975774272757697, 0.8792743474053849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 280}], {
             RGBColor[
             0.9447179912067534, 0.8094646555443272, 0.5108889653755203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 283}], {
             RGBColor[
             0.9662510048384991, 0.973085924436432, 0.8853760938053006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 111}], {
             RGBColor[
             0.8275195589806459, 0.861485844968004, 0.7082487063598909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 151}], {
             RGBColor[
             0.7727932029637246, 0.64948599231817, 0.5956443434441104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 155}], {
             RGBColor[
             0.8261422961443958, 0.8631223506043355, 0.8914292784615141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 192}], {
             RGBColor[
             0.7153725733018725, 0.7775737583871326, 0.9722653106360949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 218}], {
             RGBColor[
             0.8120796204589296, 0.8535944158233604, 0.9582238421589524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 220}], {
             RGBColor[
             0.8248327798184423, 0.8625808319505193, 0.9131313529021821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 227}], {
             RGBColor[
             0.8278533967124798, 0.8621998901202246, 0.7445848832623555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 290}], {
             RGBColor[
             0.8134935318362622, 0.8546489086135076, 0.9558304590042761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 292}], {
             RGBColor[
             0.8156798702233903, 0.8562794762028272, 0.9521295584032452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 148}], {
             RGBColor[
             0.9741444893842569, 0.9714864094528785, 0.6819947363878699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 191}], {
             RGBColor[
             0.9766252806986799, 0.9791288267976752, 0.7533552511499869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 223}], {
             RGBColor[
             0.949530914421244, 0.8835878319299002, 0.61174498809123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 246}], {
             RGBColor[
             0.9631906784671399, 0.9345366331523308, 0.6394412494284918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 278}], {
             RGBColor[
             0.9720986374808576, 0.9645852705938418, 0.6740469880698774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 295}], {
             RGBColor[
             0.973353771616178, 0.9791587418596934, 0.9080852696915278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 143}], {
             RGBColor[
             0.9657443978684019, 0.9703491568111571, 0.7190306312408814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 163}], {
             RGBColor[
             0.8936754677068477, 0.9131673436684414, 0.714842509079602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.9722134417362323, 0.9165346225266217, 0.36475850045826286`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 218}], {
             RGBColor[
             0.9772848880719825, 0.9789560355091691, 0.699495591568122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 235}], {
             RGBColor[
             0.9936531987697432, 0.9888331588655466, 0.5505680378825578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 262}], {
             RGBColor[
             0.9880553408914081, 0.9869886215868988, 0.6812640243288222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 292}], {
             RGBColor[
             0.9808851378364432, 0.9816410958886359, 0.6934013078124148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 131}], {
             RGBColor[
             0.5588682546462778, 0.6296394063686981, 0.9609823595592281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 132}], {
             RGBColor[
             0.5864081907479468, 0.6473661649175226, 0.7548880350365885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 133}], {
             RGBColor[
             0.3084351808900966, 0.4295701305628945, 0.9413136708239463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 146}], {
             RGBColor[
             0.5847231142711928, 0.6478707358023166, 0.8701427243550454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 170}], {
             RGBColor[
             0.5869035106382245, 0.6487723857337149, 0.8340079138684153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 190}], {
             RGBColor[
             0.576120360398845, 0.6135185276967932, 0.6421651369451677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 115}], {
             RGBColor[
             0.9537586415075059, 0.860941350322622, 0.5845719676426544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 134}], {
             RGBColor[
             0.9556373459258092, 0.8617406622722575, 0.5544409596868787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 144}], {
             RGBColor[
             0.950206429992798, 0.8582921167911653, 0.5905849351719126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 160}], {
             RGBColor[
             0.9553869668902197, 0.851560316236629, 0.3312445381112956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 169}], {
             RGBColor[
             0.9559195786308319, 0.8618573727488341, 0.5497636333698261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 176}], {
             RGBColor[
             0.9588166238481841, 0.8620986722959341, 0.43220988083855005`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 187}], {
             RGBColor[
             0.9532873969355427, 0.8605898968924439, 0.5853696617827195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 193}], {
             RGBColor[
             0.9319123950890207, 0.8446484555136611, 0.6215519644155449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 200}], {
             RGBColor[
             0.9491616469225843, 0.8305608502111551, 0.30706034559006357`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 228}], {
             RGBColor[
             0.9402167234989053, 0.8508418100446633, 0.6074949025333396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 231}], {
             RGBColor[
             0.9162295819699324, 0.832263718013471, 0.6242274156544318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 245}], {
             RGBColor[
             0.924310549837032, 0.7376235826575818, 0.25795669562037976`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 264}], {
             RGBColor[
             0.9591961988700624, 0.8629105448868101, 0.47352427950449694`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 288}], {
             RGBColor[
             0.944156100571157, 0.8136759670096163, 0.2876147432328806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 297}], {
             RGBColor[
             0.9583385635800812, 0.8628576851904262, 0.5096747926283898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 116}], {
             RGBColor[
             0.8835874767145974, 0.5313094605076755, 0.22315903001980814`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 204}], {
             RGBColor[
             0.9217956040737201, 0.7228816183586956, 0.25568631014584764`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 206}], {
             RGBColor[
             0.971574963289072, 0.9259791382693012, 0.5724083771424362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 254}], {
             RGBColor[
             0.9641158290683602, 0.8906058974921836, 0.3151519341708784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 283}], {
             RGBColor[
             0.9483124917970603, 0.9091334954873633, 0.6343321052835872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 134}], {
             RGBColor[
             0.9859357586667752, 0.9884296696290994, 0.8817404200020721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 169}], {
             RGBColor[
             0.9862179913717979, 0.988546380105676, 0.8770630936850197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 193}], {
             RGBColor[
             0.9622108078299867, 0.9713374628705029, 0.9488514247307385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 200}], {
             RGBColor[
             0.9794600596635503, 0.957249857567997, 0.634359805905257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 210}], {
             RGBColor[
             0.9887008290260175, 0.9879017315580438, 0.714425404099524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 211}], {
             RGBColor[
             0.8931437207062047, 0.5742428991671833, 0.43282279781530625`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 227}], {
             RGBColor[
             0.9887247781529194, 0.9879529563188589, 0.7170321187659188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 228}], {
             RGBColor[
             0.9705151362398714, 0.9775308174015052, 0.9347943628485331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 231}], {
             RGBColor[
             0.9465279947108984, 0.9589527253703128, 0.9515268759696252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 245}], {
             RGBColor[
             0.9546089625779981, 0.8643125900144236, 0.5852561559355732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 264}], {
             RGBColor[
             0.9894946116110284, 0.9895995522436519, 0.8008237398196905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 204}], {
             RGBColor[
             0.8608329051610218, 0.4379144718736554, 0.20468563357602163`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 206}], {
             RGBColor[
             0.8940191446379231, 0.5733128184807258, 0.415833678240414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 254}], {
             RGBColor[
             0.889046388490782, 0.5497306579626473, 0.24432938292604212`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 283}], {
             RGBColor[
             0.8785108303099153, 0.5620823899594338, 0.45711616366784796`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 287}], {
             RGBColor[
             0.8834430894665171, 0.5307370131832354, 0.22304285265079846`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 158}], {
             RGBColor[
             0.950152961308157, 0.9623447406774339, 0.9692622137021554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 196}], {
             RGBColor[
             0.9677086242400679, 0.9691826042297718, 0.6981876243238702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 207}], {
             RGBColor[
             0.7044487569587348, 0.7670834127606057, 0.9646392548948777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 212}], {
             RGBColor[
             0.7411787051181635, 0.7969024393417382, 0.9675307709602212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 214}], {
             RGBColor[
             0.9689240727697438, 0.972945967887183, 0.7315339665727341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 225}], {
             RGBColor[
             0.9690570799805942, 0.9732304568621001, 0.7460109806484418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 265}], {
             RGBColor[
             0.9579595286175312, 0.9681668657946845, 0.956047731526227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 276}], {
             RGBColor[
             0.7912776246916231, 0.8375749991820797, 0.9714747414274333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 166}], {
             RGBColor[
             0.9351972286480346, 0.7675542757062741, 0.30911742889406696`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.9358447942601105, 0.7697386665714421, 0.3116330990144768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 234}], {
             RGBColor[
             0.8687565252759686, 0.7312035856778742, 0.6064136177253017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 239}], {
             RGBColor[
             0.8925585995177666, 0.7501827135881902, 0.6086838808148468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 263}], {
             RGBColor[
             0.9075194623921827, 0.6660127109914874, 0.24418548862142453`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 285}], {
             RGBColor[
             0.9392247786983203, 0.7846979765412413, 0.5070506100830148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 122}], {
             RGBColor[
             0.9419248699126173, 0.8041409858587889, 0.2894072200781439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 161}], {
             RGBColor[
             0.9305344267459543, 0.8326894195364476, 0.6154034057735789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 244}], {
             RGBColor[
             0.9523039388314583, 0.8483024578979277, 0.5506707414494945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 266}], {
             RGBColor[
             0.9552098221048093, 0.8481837393044411, 0.40653533847317525`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 131}], {
             RGBColor[
             0.9308792806946854, 0.9476416751837566, 0.9904883088527188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 141}], {
             RGBColor[
             0.9511612759945489, 0.9417413254067794, 0.6834416349832745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 170}], {
             RGBColor[
             0.9589145366866321, 0.9667746545487732, 0.8635138631619059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 178}], {
             RGBColor[
             0.858787580458406, 0.8904428801565936, 0.9863387304885624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 182}], {
             RGBColor[
             0.9573925902980849, 0.9661452906048709, 0.8887364534911296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 188}], {
             RGBColor[
             0.9590464170294425, 0.9667099516114855, 0.8526608590705574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 190}], {
             RGBColor[
             0.9481313864472526, 0.9315207965118516, 0.6716710862386585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 261}], {
             RGBColor[
             0.9577915352306917, 0.9640258863319697, 0.7160747195093009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 284}], {
             RGBColor[
             0.9437666650087354, 0.95725306530402, 0.9686733287771797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 294}], {
             RGBColor[
             0.9582593829370613, 0.9650265652692351, 0.7669970551262634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 135}], {
             RGBColor[
             0.9670998325741235, 0.9728296201311122, 0.8333413065191905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 154}], {
             RGBColor[
             0.9712451668823743, 0.9107697320672442, 0.4779500075568222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 173}], {
             RGBColor[
             0.9921058877220923, 0.9906176536483533, 0.7524354687918282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.9754244464696435, 0.9790381035440868, 0.8192499066011061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 234}], {
             RGBColor[
             0.9228084870553621, 0.937607440488979, 0.8323944162036656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 239}], {
             RGBColor[
             0.9466105612971601, 0.9565865683992951, 0.8346646792932109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 249}], {
             RGBColor[
             0.9396612699749454, 0.9510453921324489, 0.8340018496831924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 255}], {
             RGBColor[
             0.9777013390983563, 0.9807362063385112, 0.8153957212894011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 258}], {
             RGBColor[
             0.9863843632522865, 0.9872119915353652, 0.8006976262921951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 263}], {
             RGBColor[
             0.9615714241715763, 0.8724165658025922, 0.47016628709978847`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 286}], {
             RGBColor[
             0.9554920622161343, 0.8483139214765438, 0.4652746897694742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 138}], {
             RGBColor[
             0.9803664381388025, 0.9462795715466461, 0.5417709067508937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 161}], {
             RGBColor[
             0.955791112834935, 0.9295062573132622, 0.6530031573151072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 266}], {
             RGBColor[
             0.98046650819379, 0.9450005770812556, 0.4441350900147036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 189}], {
             RGBColor[
             0.9167040722522125, 0.9355103269455797, 0.9604143608988783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 257}], {
             RGBColor[
             0.9281390191048005, 0.9446282431724699, 0.9615050363377757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 267}], {
             RGBColor[
             0.9622949998523469, 0.9159046331649519, 0.6078260835585227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 287}], {
             RGBColor[
             0.9632145306422373, 0.9195502663313957, 0.6085659596162303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 300}], {
             RGBColor[
             0.9826659086470009, 0.9841339834423825, 0.7828081586911144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 147}], {
             RGBColor[
             0.8572786917280785, 0.8887166878606279, 0.9532332923895583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 247}], {
             RGBColor[
             0.9834190380494685, 0.9846961945710301, 0.7815752375792107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 273}], {
             RGBColor[
             0.9830455388002636, 0.9838973174435477, 0.7409221492734391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 289}], {
             RGBColor[
             0.9835136920305153, 0.9848986498655037, 0.7918777392794996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 128}], {
             RGBColor[
             0.8249908923675168, 0.5739532876755333, 0.46193429438128775`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 130}], {
             RGBColor[
             0.8533562378474223, 0.4080586855443903, 0.19860723040970565`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 142}], {
             RGBColor[
             0.9041418519992825, 0.6347961011921293, 0.39345092519838054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.9004248335595034, 0.6329653096029872, 0.44189865360797853`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 150}], {
             RGBColor[
             0.9045182503815572, 0.6341111681181676, 0.326111484713864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 167}], {
             RGBColor[
             0.7178824888908737, 0.4877993809234075, 0.45281122120794604`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 237}], {
             RGBColor[
             0.8991275178766632, 0.6319977736908846, 0.4440946706649067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 243}], {
             RGBColor[
             0.8872639604231347, 0.6231499519668353, 0.4641765789223944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 256}], {
             RGBColor[
             0.6328871064197839, 0.40617888358819954`, 0.447688374557209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 269}], {
             RGBColor[
             0.8728140371448629, 0.5153600723586964, 0.21558525379149387`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 277}], {
             RGBColor[
             0.8977926589322297, 0.631002238075757, 0.4463542386708617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 281}], {
             RGBColor[
             0.6803234102572995, 0.455267594785187, 0.4504179899296038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 293}], {
             RGBColor[
             0.8916542340518957, 0.6264242108507521, 0.45674499083565046`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 153}], {
             RGBColor[
             0.975056433869774, 0.9634335964006617, 0.6619126738990245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 157}], {
             RGBColor[
             0.9806264225365611, 0.9817861175476206, 0.720655807033292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 192}], {
             RGBColor[
             0.8682368333265057, 0.8973551265443165, 0.9582665141048878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 220}], {
             RGBColor[
             0.9776970398430754, 0.9823622001077031, 0.8991325563709751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 222}], {
             RGBColor[
             0.9282464804969371, 0.9447885054025766, 0.9641008631777082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 239}], {
             RGBColor[
             0.9332146532814497, 0.9487499915234893, 0.9645747319330351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 248}], {
             RGBColor[
             0.9808913753382003, 0.983683139925615, 0.8461941505414893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 285}], {
             RGBColor[
             0.9798808324620034, 0.9832652544765403, 0.862941461201203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 145}], {
             RGBColor[
             0.9524014650188415, 0.9618234803553138, 0.8734086006378818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 148}], {
             RGBColor[
             0.9499511400396861, 0.952810893481518, 0.7010305332056573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 156}], {
             RGBColor[
             0.9212621684794392, 0.8487547264959167, 0.6275016251450299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 159}], {
             RGBColor[
             0.9427425732159522, 0.9284947049330838, 0.6730266123190717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 168}], {
             RGBColor[
             0.9521004853246953, 0.9616990175169591, 0.8783966130803648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 191}], {
             RGBColor[
             0.9524319313541092, 0.9604533108263147, 0.7723910479677744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 205}], {
             RGBColor[
             0.92625781592121, 0.8685608039017128, 0.6315212403395953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 212}], {
             RGBColor[
             0.7243712162887745, 0.7837352860493636, 0.9740642324667429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 225}], {
             RGBColor[
             0.9522495911512051, 0.9600633035697255, 0.7525444421549635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 251}], {
             RGBColor[
             0.908024027955105, 0.9294977285085047, 0.9910893364606187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 269}], {
             RGBColor[
             0.9049462587802182, 0.782477774577953, 0.6142912221529717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 276}], {
             RGBColor[
             0.7744701358622341, 0.8244078458897051, 0.978008202933955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 282}], {
             RGBColor[
             0.9472852902871582, 0.9595738806822002, 0.9521991997458364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 142}], {
             RGBColor[
             0.8739647972908478, 0.8999814325368953, 0.8735137056978755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 149}], {
             RGBColor[
             0.8683892696311791, 0.8972352451531823, 0.9461852983122725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 150}], {
             RGBColor[
             0.8745293948642597, 0.8989540329259529, 0.7725045449711005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 197}], {
             RGBColor[
             0.6246641932388056, 0.7044403909331878, 0.9647772414595996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 198}], {
             RGBColor[
             0.8698873960632019, 0.8841085577303336, 0.6853330780110934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 237}], {
             RGBColor[
             0.8664432961069188, 0.8957839412850283, 0.9494793238976648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 243}], {
             RGBColor[
             0.8486479599266259, 0.8825122086989545, 0.9796021862838962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 256}], {
             RGBColor[
             0.4670826789215996, 0.5570556061310007, 0.9548698797361181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 269}], {
             RGBColor[
             0.8269730750092184, 0.720827389286746, 0.6067151985875454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 277}], {
             RGBColor[
             0.8644410076902684, 0.8942906378623368, 0.9528686759065972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 281}], {
             RGBColor[
             0.538237134677873, 0.6306886729264819, 0.9589643027947103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 165}], {
             RGBColor[
             0.9536651805610105, 0.8537482670091991, 0.5520055086697535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 175}], {
             RGBColor[
             0.9860282054006853, 0.9884823900155195, 0.8808572877790876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 183}], {
             RGBColor[
             0.99137010623921, 0.9903077417307666, 0.7642187682353551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 184}], {
             RGBColor[
             0.9864778989787675, 0.9886762779726446, 0.8737597382048978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 224}], {
             RGBColor[
             0.9849156035370061, 0.987652613367306, 0.8827406325212558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 253}], {
             RGBColor[
             0.9729933409820419, 0.9297535630738366, 0.5708093864430854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 140}], {
             RGBColor[
             0.7369225339242983, 0.417154644944952, 0.4428885339960087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 162}], {
             RGBColor[
             0.8827630206922635, 0.5081681775158648, 0.23374214713789068`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 167}], {
             RGBColor[
             0.704860645326367, 0.3907741012475895, 0.4404615583557303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 201}], {
             RGBColor[
             0.8917271477283605, 0.5375794199201569, 0.3388765460898983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 202}], {
             RGBColor[
             0.851273192867379, 0.37965200010841604`, 0.1961271279245542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 203}], {
             RGBColor[
             0.8597056485469494, 0.41794181189928414`, 0.2031633756419906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 216}], {
             RGBColor[
             0.8371566460106888, 0.49666303769927345`, 0.4520796281625509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 237}], {
             RGBColor[
             0.8861056743121566, 0.5349724940150665, 0.431745007812691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 269}], {
             RGBColor[
             0.8597921935803562, 0.4183347926828783, 0.20323559093927815`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 281}], {
             RGBColor[
             0.6673015666927927, 0.358242315109369, 0.4380683270773881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 293}], {
             RGBColor[
             0.878632390487389, 0.5293989311749341, 0.44439532798343473`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 294}], {
             RGBColor[
             0.8914128341143794, 0.5369071348818326, 0.3046654489268418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 299}], {
             RGBColor[
             0.8761016390624075, 0.5275115009059079, 0.4486792300202447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 141}], {
             RGBColor[
             0.9590915045924191, 0.947984462960419, 0.6814170452490118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 146}], {
             RGBColor[
             0.9646643689174706, 0.9721161421710147, 0.8976240839142734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 170}], {
             RGBColor[
             0.9668447652845022, 0.973017792102413, 0.8614892734276434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 178}], {
             RGBColor[
             0.8667178090562759, 0.8966860177102333, 0.9843141407542997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 182}], {
             RGBColor[
             0.9653228188959551, 0.9723884281585107, 0.886711863756867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 188}], {
             RGBColor[
             0.9669766456273126, 0.9729530891651252, 0.8506362693362948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 190}], {
             RGBColor[
             0.9560616150451227, 0.9377639340654913, 0.6696464965043958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 199}], {
             RGBColor[
             0.9280673975789095, 0.9453995559137707, 0.9902201089309384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 261}], {
             RGBColor[
             0.9657217638285618, 0.9702690238856095, 0.7140501297750382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 284}], {
             RGBColor[
             0.9516968936066055, 0.9634962028576597, 0.966648739042917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 133}], {
             RGBColor[
             0.7159163716380433, 0.7715422954804172, 0.7627007058605348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 146}], {
             RGBColor[
             0.9922043050191396, 0.9898429007198392, 0.6915297593916339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 236}], {
             RGBColor[
             0.9902898551741035, 0.9890512265097999, 0.7232571477612644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 260}], {
             RGBColor[
             0.9741546056396051, 0.9774326470174487, 0.7691572942122082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 267}], {
             RGBColor[
             0.9737723097879777, 0.9216519114192814, 0.42892159533113017`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 146}], {
             RGBColor[
             0.7142312951612895, 0.7720468663652111, 0.8779553951789917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 170}], {
             RGBColor[
             0.7164116915283211, 0.7729485162966094, 0.8418205846923617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 144}], {
             RGBColor[
             0.9823835471520673, 0.9857804360976428, 0.8877533875313303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 160}], {
             RGBColor[
             0.987564084049489, 0.9790486355431063, 0.6284129904707132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 169}], {
             RGBColor[
             0.9880966957901012, 0.9893456920553114, 0.8469320857292437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 176}], {
             RGBColor[
             0.9909937410074534, 0.9895869916024116, 0.7293783331979676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 180}], {
             RGBColor[
             0.8246507019357019, 0.8623534371493733, 0.9092519532115537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 187}], {
             RGBColor[
             0.985464514094812, 0.9880782161989214, 0.8825381141421371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 193}], {
             RGBColor[
             0.96408951224829, 0.9721367748201386, 0.9187204167749626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 200}], {
             RGBColor[
             0.9813387640818536, 0.9580491695176325, 0.6042287979494811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 221}], {
             RGBColor[
             0.9913066750635702, 0.9902563259059589, 0.7634392740011497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 228}], {
             RGBColor[
             0.9723938406581746, 0.9783301293511407, 0.9046633548927572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 230}], {
             RGBColor[
             0.9901796704086891, 0.9878457769068179, 0.6407717723838546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 245}], {
             RGBColor[
             0.9564876669963013, 0.8651119019640592, 0.5551251479797974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 264}], {
             RGBColor[
             0.9913733160293317, 0.9903988641932875, 0.7706927318639145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 288}], {
             RGBColor[
             0.9763332177304263, 0.9411642863160936, 0.5847831955922982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 297}], {
             RGBColor[
             0.9905156807393505, 0.9903460044969037, 0.8068432449878074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 158}], {
             RGBColor[
             0.9474356286361517, 0.9603181584198763, 0.9738619491219938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 173}], {
             RGBColor[
             0.9643710928479355, 0.9720871584312907, 0.90661751670236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 186}], {
             RGBColor[
             0.9425456809264718, 0.9566712434245517, 0.9821393550918611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 213}], {
             RGBColor[
             0.9476896515954869, 0.9605076083270241, 0.9734319545116379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 214}], {
             RGBColor[
             0.9662067400977385, 0.9709193856296254, 0.7361337019925722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 249}], {
             RGBColor[
             0.9119264751007886, 0.9325148969153862, 0.9881838975937242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 255}], {
             RGBColor[
             0.9499665442241996, 0.9622057111214486, 0.9695777691999329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 263}], {
             RGBColor[
             0.9338366292974196, 0.8538860705855296, 0.6243483350103203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 265}], {
             RGBColor[
             0.955242195945526, 0.9661402835371269, 0.9606474669460653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 276}], {
             RGBColor[
             0.788560292019618, 0.8355484169245221, 0.9760744768472716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 286}], {
             RGBColor[
             0.9277572673419776, 0.8297834262594812, 0.619456737680006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 177}], {
             RGBColor[
             0.9646156327217066, 0.8956415748500037, 0.553370746096833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 194}], {
             RGBColor[
             0.9711907296104676, 0.9772742533266334, 0.8995975756743266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 197}], {
             RGBColor[
             0.741429557996159, 0.794893656426324, 0.8945522704020419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 204}], {
             RGBColor[
             0.9382164170506314, 0.7862064393279697, 0.5318825164186445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 210}], {
             RGBColor[
             0.9910568455807345, 0.9888984243424489, 0.6763840987991605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 226}], {
             RGBColor[
             0.9567923550700641, 0.8646248859139766, 0.5470759532623932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 252}], {
             RGBColor[
             0.9312326824392954, 0.7544949315505514, 0.5260551170719456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 279}], {
             RGBColor[
             0.9683379631587279, 0.9751466647779023, 0.9044265651564684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 280}], {
             RGBColor[
             0.9432002911422259, 0.8088370475645326, 0.5360411831266038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 147}], {
             RGBColor[
             0.8686011015306124, 0.8953511859718724, 0.8530237043571708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 156}], {
             RGBColor[
             0.963212346467982, 0.8788635196150723, 0.4973644475615062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 179}], {
             RGBColor[
             0.9834391793801134, 0.9853598110335784, 0.8318736273482821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 191}], {
             RGBColor[
             0.9943821093426519, 0.9905621039454703, 0.6422538703842506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 217}], {
             RGBColor[
             0.978484742601768, 0.9376624273255031, 0.5187724935980077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 247}], {
             RGBColor[
             0.9947414478520025, 0.9913306926822745, 0.681365649546823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 251}], {
             RGBColor[
             0.9499742059436478, 0.9596065216276602, 0.860952158877095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 270}], {
             RGBColor[
             0.9670505096792994, 0.9731371680046951, 0.8596153703021314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 271}], {
             RGBColor[
             0.949967307526971, 0.8263513538615465, 0.4867071783285465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 273}], {
             RGBColor[
             0.9943679486027975, 0.9905318155547921, 0.6407125612410516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 278}], {
             RGBColor[
             0.9898554661248296, 0.9760185477416369, 0.5629456073041412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 289}], {
             RGBColor[
             0.9948361018330493, 0.9915331479767482, 0.691668151247112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 295}], {
             RGBColor[
             0.99111060026015, 0.9905920190074886, 0.7969838889257915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 210}], {
             RGBColor[
             0.993447962039785, 0.9898872124471564, 0.6367571110616577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 211}], {
             RGBColor[
             0.8963084760487164, 0.5755665530932583, 0.381043935790062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 231}], {
             RGBColor[
             0.951275127724666, 0.9609382062594254, 0.8738585829317589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 266}], {
             RGBColor[
             0.9936513903309945, 0.9903223249922983, 0.658899025145925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 143}], {
             RGBColor[
             0.9669531966556081, 0.9729346551886862, 0.8506009193868911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 163}], {
             RGBColor[
             0.8948842664940537, 0.9157528420459706, 0.8464127972256117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 235}], {
             RGBColor[
             0.9948619975569494, 0.9914186572430757, 0.6821383260285675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 273}], {
             RGBColor[
             0.9943966200057107, 0.9904232617178643, 0.6314848515535707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 274}], {
             RGBColor[
             0.9267724106111099, 0.9409746241901051, 0.8495087065343043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 298}], {
             RGBColor[
             0.9944198831877331, 0.9904730193119416, 0.6340169053529892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 162}], {
             RGBColor[
             0.7488595433590117, 0.7659174219540809, 0.6424308865858692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 167}], {
             RGBColor[
             0.48200598031016695`, 0.5898263075516679, 0.9525100034126286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 181}], {
             RGBColor[
             0.7458457818534259, 0.8001368199116641, 0.9530240507243215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 201}], {
             RGBColor[
             0.762305733913157, 0.8100342855605189, 0.8001324850138807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 202}], {
             RGBColor[
             0.701624801621685, 0.5731431558429076, 0.5860083577658645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 203}], {
             RGBColor[
             0.7142734851410404, 0.6305778735292098, 0.596562729342019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 216}], {
             RGBColor[
             0.6804499813366497, 0.7486597122291938, 0.9699371081228596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 237}], {
             RGBColor[
             0.7538735237888512, 0.8061238967028834, 0.9394351775980696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 269}], {
             RGBColor[
             0.7144033026911507, 0.6311673447046011, 0.5966710522879504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 293}], {
             RGBColor[
             0.7426635980516998, 0.7977635524426846, 0.9584106578541852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 299}], {
             RGBColor[
             0.7388674709142276, 0.7949324070391455, 0.9648365109094001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 146}], {
             RGBColor[
             0.9849463642173342, 0.9662157923940375, 0.5905774100448291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 178}], {
             RGBColor[
             0.8869998043561396, 0.890785667933256, 0.6772674668848555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 182}], {
             RGBColor[
             0.9856048141958186, 0.9664880783815334, 0.5796651898874228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 188}], {
             RGBColor[
             0.9872586409271762, 0.9670527393881481, 0.5435895954668506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 236}], {
             RGBColor[
             0.9830319143722981, 0.9654241181839982, 0.6223047984144596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 261}], {
             RGBColor[
             0.9860037591284254, 0.9643686741086323, 0.40700345590559406`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 294}], {
             RGBColor[
             0.986471606834795, 0.9653693530458977, 0.4579257915225565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 149}], {
             RGBColor[
             0.9871157090788276, 0.9884994654280763, 0.8434602445379116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[
             0.9932558343119082, 0.9902182532008468, 0.6697794911967396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 163}], {
             RGBColor[
             0.8936586727792464, 0.9153664377474298, 0.875476607156829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 197}], {
             RGBColor[
             0.7433906326864541, 0.7957046112080817, 0.8620521876852387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 198}], {
             RGBColor[
             0.9886138355108505, 0.9753727780052276, 0.5826080242367325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 243}], {
             RGBColor[
             0.9673743993742745, 0.9737764289738484, 0.8768771325095353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 256}], {
             RGBColor[
             0.5858091183692481, 0.6483198264058947, 0.8521448259617572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 277}], {
             RGBColor[
             0.983167447137917, 0.9855548581372308, 0.8501436221322363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 163}], {
             RGBColor[
             0.8666950389815509, 0.8966690358257858, 0.9843526845514228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 174}], {
             RGBColor[
             0.9547904916881161, 0.9658034032415486, 0.9614120844305218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 185}], {
             RGBColor[
             0.9452330130109354, 0.900036314683966, 0.6342686759300837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 235}], {
             RGBColor[
             0.9666727700444464, 0.972334851022891, 0.8200782133543787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 298}], {
             RGBColor[
             0.9662306556752301, 0.971389213091757, 0.7719567926788002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 160}], {
             RGBColor[
             0.9821331681164779, 0.9756000900620141, 0.6645569659557472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 176}], {
             RGBColor[
             0.9855628250744422, 0.9861384461213194, 0.7655223086830016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 221}], {
             RGBColor[
             0.985875759130559, 0.9868077804248667, 0.7995832494861839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 230}], {
             RGBColor[
             0.9847487544756779, 0.9843972314257257, 0.6769157478688886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 231}], {
             RGBColor[
             0.9429757831961905, 0.9563034918388562, 0.9575398434988833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 232}], {
             RGBColor[
             0.7916893334053905, 0.8368474456741568, 0.9430282942156796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 240}], {
             RGBColor[
             0.9664834483550315, 0.9745239911782747, 0.9416189588049588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 245}], {
             RGBColor[
             0.9510567510632901, 0.861663356482967, 0.5912691234648314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 264}], {
             RGBColor[
             0.9859424000963204, 0.9869503187121953, 0.8068367073489486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 288}], {
             RGBColor[
             0.9709023017974151, 0.9377157408350014, 0.6209271710773323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 297}], {
             RGBColor[
             0.9850847648063392, 0.9868974590158115, 0.8429872204728415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 156}], {
             RGBColor[
             0.9624789081130817, 0.8785602240068149, 0.5095194191798227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 159}], {
             RGBColor[
             0.9839593128495947, 0.9583002024439822, 0.5550444063538645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 167}], {
             RGBColor[
             0.713765676032877, 0.7709422349359181, 0.8521479673124428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 168}], {
             RGBColor[
             0.9933172249583377, 0.9915045150278573, 0.7604144071151575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 201}], {
             RGBColor[
             0.9940654296358671, 0.9911502129447691, 0.6997704489136949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 203}], {
             RGBColor[
             0.9460331808637505, 0.81169380091346, 0.4962006932418333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 205}], {
             RGBColor[
             0.9674745555548525, 0.8983663014126111, 0.5135390343743882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 216}], {
             RGBColor[
             0.9122096770593597, 0.929775639613444, 0.8695750720226738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 237}], {
             RGBColor[
             0.9856332195115612, 0.9872398240871336, 0.8390731414978838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 269}], {
             RGBColor[
             0.9461629984138606, 0.8122832720888513, 0.4963090161877646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 277}], {
             RGBColor[
             0.983630931094911, 0.9857465206644421, 0.8424624935068163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 282}], {
             RGBColor[
             0.9885020299208007, 0.9893793781930984, 0.8342169937806292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 293}], {
             RGBColor[
             0.9744232937744098, 0.9788794798269349, 0.8580486217539994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 170}], {
             RGBColor[
             0.9926996249094173, 0.9912491215360314, 0.7706496382234607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 236}], {
             RGBColor[
             0.9886047786973496, 0.9895557973945939, 0.8385118370797212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 247}], {
             RGBColor[
             0.8682574680203301, 0.8944463095714204, 0.8032729024679524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 273}], {
             RGBColor[
             0.8678839687711253, 0.8936474324439379, 0.7626198141621808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 289}], {
             RGBColor[
             0.868352122001377, 0.894648764865894, 0.8135754041682413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 156}], {
             RGBColor[
             0.9600285831339262, 0.8695476371330191, 0.3371413517475983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 159}], {
             RGBColor[
             0.9815089878704393, 0.9492876155701864, 0.38266633892164004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 168}], {
             RGBColor[
             0.9908668999791823, 0.9824919281540615, 0.5880363396829331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 191}], {
             RGBColor[
             0.9911983460085962, 0.9812462214634172, 0.4820307745703427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 205}], {
             RGBColor[
             0.9650242305756971, 0.8893537145388153, 0.3411609669421637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 217}], {
             RGBColor[
             0.9753009792677121, 0.92834654484345, 0.3585493977840998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 225}], {
             RGBColor[
             0.9910160058056922, 0.980856214206828, 0.4621841687575319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 251}], {
             RGBColor[
             0.946790442609592, 0.9502906391456072, 0.700729063063187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 270}], {
             RGBColor[
             0.9638667463452436, 0.963821285522642, 0.6993922744882235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 271}], {
             RGBColor[
             0.9467835441929152, 0.8170354713794934, 0.32648408251463856`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 278}], {
             RGBColor[
             0.9866717027907738, 0.9667026652595838, 0.40272251149023325`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.9860517049416453, 0.9803667913193026, 0.6618389263484048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 295}], {
             RGBColor[
             0.9879268369260943, 0.9812761365254354, 0.6367607931118836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 150}], {
             RGBColor[
             0.9876803066522397, 0.9874720658171339, 0.7424510838111367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.7378151050267856, 0.7929584238243688, 0.9347237802996358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 198}], {
             RGBColor[
             0.983038307851182, 0.9726265906215146, 0.6552796168511296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 243}], {
             RGBColor[
             0.961798871714606, 0.9710302415901355, 0.9495487251239323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 256}], {
             RGBColor[
             0.5802335907095796, 0.6455736390221817, 0.9248164185761543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 277}], {
             RGBColor[
             0.9775919194782485, 0.9828086707535177, 0.9228152147466333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 281}], {
             RGBColor[
             0.651388046465853, 0.7192067058176629, 0.9289108416347465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 179}], {
             RGBColor[
             0.9828068546416312, 0.9838374532871672, 0.7507005668652438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 237}], {
             RGBColor[
             0.9857343331279794, 0.9860207619489798, 0.745745109396529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 256}], {
             RGBColor[
             0.5863737159426602, 0.6472924267949521, 0.7511356652349824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 269}], {
             RGBColor[
             0.9462641120302788, 0.8110642099506975, 0.4029809840864097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 274}], {
             RGBColor[
             0.9261114144697147, 0.9395608202806218, 0.7775633557387469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 277}], {
             RGBColor[
             0.9837320447113291, 0.9845274585262882, 0.7491344614054615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 281}], {
             RGBColor[
             0.6575281716989336, 0.7209254935904335, 0.7552300882935746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 293}], {
             RGBColor[
             0.974524407390828, 0.977660417688781, 0.7647205896526446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 154}], {
             RGBColor[
             0.9154639104381623, 0.6965135540702292, 0.2505262432212427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 181}], {
             RGBColor[
             0.9224324325298221, 0.7668621380398807, 0.5871046822565481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 192}], {
             RGBColor[
             0.8258514848980042, 0.6909355254231073, 0.600932697129484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 220}], {
             RGBColor[
             0.9353116914145739, 0.7759425989864939, 0.5417987393955712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 239}], {
             RGBColor[
             0.8908293048529482, 0.74233039040228, 0.6072409149576312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 258}], {
             RGBColor[
             0.9306031068080746, 0.7729558135383501, 0.5732738619566156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 208}], {
             RGBColor[
             0.979286030319618, 0.9833683323286322, 0.8884297675621274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 242}], {
             RGBColor[
             0.9757659231342015, 0.9383422775338368, 0.5763005991490008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 244}], {
             RGBColor[
             0.9881839974422568, 0.9893817935320279, 0.8454852714235905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 268}], {
             RGBColor[
             0.9696298892397661, 0.9761667981217585, 0.9047750956853766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 157}], {
             RGBColor[
             0.9876400449894758, 0.9695327523517193, 0.44358911704400933`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 192}], {
             RGBColor[
             0.8752504557794203, 0.8851017613484152, 0.6811998241156052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 220}], {
             RGBColor[
             0.98471066229599, 0.9701088349118019, 0.6220658663816924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 222}], {
             RGBColor[
             0.9352601029498517, 0.9325351402066753, 0.6870341731884253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 239}], {
             RGBColor[
             0.9402282757343643, 0.936496626327588, 0.6875080419437524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 248}], {
             RGBColor[
             0.987904997791115, 0.9714297747297137, 0.5691274605522065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 285}], {
             RGBColor[
             0.9868944549149181, 0.971011889280639, 0.5858747712119203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 181}], {
             RGBColor[
             0.9546242284081281, 0.9005279327559652, 0.6133191955402912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[
             0.9230519316957426, 0.7309689863735108, 0.2568578741579889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 216}], {
             RGBColor[
             0.8892284278913519, 0.8490508250734947, 0.6302322529388293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 255}], {
             RGBColor[
             0.9541118785324504, 0.9001458230575806, 0.6141864702375646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 258}], {
             RGBColor[
             0.9627949026863806, 0.9066216082544346, 0.5994883752403586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 162}], {
             RGBColor[
             0.9787952872160792, 0.946279098368463, 0.5722964531354996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 194}], {
             RGBColor[
             0.971791336392114, 0.9775226196657344, 0.8896439669819196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 210}], {
             RGBColor[
             0.9916574523623809, 0.9891467906815499, 0.6664304901067535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 218}], {
             RGBColor[
             0.9759076252357326, 0.9805925411455007, 0.8826761636697453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 226}], {
             RGBColor[
             0.9573929618517105, 0.8648732522530775, 0.5371223445699862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 227}], {
             RGBColor[
             0.9916814014892827, 0.989198015442365, 0.6690372047731483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 241}], {
             RGBColor[
             0.7887356969635426, 0.8330596778540538, 0.8882754922912979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 290}], {
             RGBColor[
             0.9773215366130651, 0.9816470339356479, 0.8802827805150689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 291}], {
             RGBColor[
             0.9745267992108269, 0.9318804860381021, 0.5557141832714172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.968803214771295, 0.9752940834535277, 0.8947020774590306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 159}], {
             RGBColor[
             0.9528200163101925, 0.845231448584585, 0.30913743086101264`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 168}], {
             RGBColor[
             0.9621779284189355, 0.8784357611684601, 0.5145074316223057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.9515664444858107, 0.871987761565924, 0.5981216234737468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 191}], {
             RGBColor[
             0.9625093744483493, 0.877190054477816, 0.4085018665097153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 205}], {
             RGBColor[
             0.9363352590154502, 0.785297547553214, 0.2676320588815363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 251}], {
             RGBColor[
             0.9181014710493451, 0.8462344721600059, 0.6272001550025597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 269}], {
             RGBColor[
             0.9150237018744585, 0.6992145182294542, 0.2504020406949127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 270}], {
             RGBColor[
             0.9351777747849968, 0.8597651185370407, 0.6258633664275961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 271}], {
             RGBColor[
             0.9180945726326684, 0.7129793043938921, 0.2529551744540111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 277}], {
             RGBColor[
             0.9524916345555086, 0.8726777668050449, 0.5965555180139646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 282}], {
             RGBColor[
             0.9573627333813984, 0.8763106243337013, 0.5883100182877774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 171}], {
             RGBColor[
             0.8797262570248143, 0.9025994949656493, 0.739833898873471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 184}], {
             RGBColor[
             0.9891268501647514, 0.987984229777449, 0.6999304646799969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 222}], {
             RGBColor[
             0.940830091616639, 0.9508876613536341, 0.7457773063226929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 248}], {
             RGBColor[
             0.9934749864579021, 0.9897822958766725, 0.6278705936864741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 275}], {
             RGBColor[
             0.9366584882470675, 0.9475613380618948, 0.745379415069269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 285}], {
             RGBColor[
             0.9924644435817052, 0.9893644104275978, 0.6446179043461878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 186}], {
             RGBColor[
             0.950616271862657, 0.9626902769303787, 0.9684779497841325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 196}], {
             RGBColor[
             0.9730618825042477, 0.9731750554780412, 0.6891259544359799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 207}], {
             RGBColor[
             0.7098020152229145, 0.7710758640088751, 0.9555775850069874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 212}], {
             RGBColor[
             0.7465319633823434, 0.8008948905900075, 0.958469101072331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 214}], {
             RGBColor[
             0.9742773310339237, 0.9769384191354523, 0.7224722966848437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 225}], {
             RGBColor[
             0.974410338244774, 0.9772229081103694, 0.7369493107605516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 265}], {
             RGBColor[
             0.9633127868817111, 0.9721593170429539, 0.9469860616383368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 276}], {
             RGBColor[
             0.796630882955803, 0.841567450430349, 0.9624130715395429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 168}], {
             RGBColor[
             0.9836583331554485, 0.9581757396056274, 0.5600324187963475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 191}], {
             RGBColor[
             0.9839897791848624, 0.956930032914983, 0.45402685368375706`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 205}], {
             RGBColor[
             0.9578156637519633, 0.8650375259903811, 0.31315704605557804`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 212}], {
             RGBColor[
             0.7559290641195278, 0.7802120081380319, 0.6557000381827256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 225}], {
             RGBColor[
             0.9838074389819584, 0.9565400256583938, 0.4341802478709462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 251}], {
             RGBColor[
             0.9395818757858583, 0.925974450597173, 0.6727251421766014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 270}], {
             RGBColor[
             0.9566581795215099, 0.9395050969742078, 0.6713883536016378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 271}], {
             RGBColor[
             0.9395749773691815, 0.7927192828310592, 0.2984801616280529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 282}], {
             RGBColor[
             0.9788431381179115, 0.9560506027708685, 0.6338350054618191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 176}], {
             RGBColor[
             0.990743361971864, 0.9794066455667829, 0.5061819116223846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 180}], {
             RGBColor[
             0.8244003229001124, 0.8521730911137446, 0.6860555316359707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 193}], {
             RGBColor[
             0.9638391332127005, 0.9619564287845099, 0.6955239951993796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 221}], {
             RGBColor[
             0.9910562960279807, 0.9800759798703303, 0.5402428524255667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 230}], {
             RGBColor[
             0.9899292913730997, 0.9776654308711893, 0.4175753508082716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 232}], {
             RGBColor[
             0.7968698703028123, 0.8301156451196203, 0.6836878971550625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 245}], {
             RGBColor[
             0.9562372879607118, 0.8549315559284305, 0.33192872640421434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 288}], {
             RGBColor[
             0.9760828386948368, 0.930983940280465, 0.3615867740167152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 296}], {
             RGBColor[
             0.9789094625915477, 0.9405188064069234, 0.3725676740923037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 297}], {
             RGBColor[
             0.990265301703761, 0.980165658461275, 0.5836468234122243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 177}], {
             RGBColor[
             0.9424314238768896, 0.8798570487213272, 0.6249760089235435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 244}], {
             RGBColor[
             0.966170181753776, 0.9736677293524009, 0.9142666786864577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 279}], {
             RGBColor[
             0.9461537543139109, 0.9593621386492258, 0.976031827983179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 280}], {
             RGBColor[
             0.921016082297409, 0.793052521435856, 0.6076464459533144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 169}], {
             RGBColor[
             0.9779996010030416, 0.9459500616711691, 0.5854830328554417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 181}], {
             RGBColor[
             0.9646065120053737, 0.9366571187680335, 0.6393044704371444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 202}], {
             RGBColor[
             0.9203855317736328, 0.7096634546992769, 0.2722887774786875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 216}], {
             RGBColor[
             0.8992107114885975, 0.885180011085563, 0.6562175278356825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 227}], {
             RGBColor[
             0.9805063877841631, 0.9453566378843521, 0.425452057936341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 228}], {
             RGBColor[
             0.9622967458711151, 0.9349344989669983, 0.6432143020189551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 299}], {
             RGBColor[
             0.9576282010661754, 0.9314527058955149, 0.6511169306222233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 185}], {
             RGBColor[
             0.8731640828493812, 0.8428545015412504, 0.6300805537688043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 235}], {
             RGBColor[
             0.8946038398828922, 0.9151530378801753, 0.8158900911930993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 274}], {
             RGBColor[
             0.8265142529370527, 0.8647090048272047, 0.9832604716988361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 292}], {
             RGBColor[
             0.8818357789495921, 0.9079609749032647, 0.9587233611229562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 298}], {
             RGBColor[
             0.8941617255136758, 0.9142073999490412, 0.7677686705175208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 176}], {
             RGBColor[
             0.965958049845709, 0.9715172368556033, 0.7987080794009567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 180}], {
             RGBColor[
             0.7996150107739575, 0.8442836824025651, 0.9785816994145428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 187}], {
             RGBColor[
             0.9604288229330676, 0.9700084614521132, 0.9518678603451263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 221}], {
             RGBColor[
             0.9662709839018258, 0.9721865711591509, 0.8327690202041389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 230}], {
             RGBColor[
             0.9651439792469447, 0.9697760221600098, 0.7101015185868437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 296}], {
             RGBColor[
             0.9541241504653928, 0.9326293976957438, 0.6650938418708758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 297}], {
             RGBColor[
             0.9654799895776061, 0.9722762497500954, 0.8761729911907965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 175}], {
             RGBColor[
             0.9517812546774005, 0.8529612871356494, 0.5828719992207623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 183}], {
             RGBColor[
             0.9571231555159253, 0.8547866388508965, 0.4662334796770297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 224}], {
             RGBColor[
             0.9506686528137214, 0.8521315104874359, 0.5847553439629305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 253}], {
             RGBColor[
             0.9387463902587572, 0.7942324601939665, 0.2728240978847601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 262}], {
             RGBColor[
             0.9514020425134216, 0.8526784713246569, 0.5835139065000061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 195}], {
             RGBColor[
             0.9843113190186519, 0.9587405365517511, 0.393552866256613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 234}], {
             RGBColor[
             0.91722305003451, 0.9202054556581831, 0.6883333849674378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.941025124276308, 0.9391845835684992, 0.690603648056983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 285}], {
             RGBColor[
             0.9876913034568617, 0.9736998465215503, 0.5889703773251509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 168}], {
             RGBColor[
             0.7134646963387308, 0.7708177720975633, 0.8571359797549258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[
             0.7142129010162601, 0.7704634700144751, 0.796492021553463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 202}], {
             RGBColor[
             0.653531968724788, 0.533572340296864, 0.5823678943054469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.6661806522441435, 0.5910070579831661, 0.5929222658816016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 216}], {
             RGBColor[
             0.6323571484397528, 0.70908889668315, 0.9662966446624419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 237}], {
             RGBColor[
             0.7057806908919542, 0.7665530811568396, 0.9357947141376521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 269}], {
             RGBColor[
             0.6663104697942537, 0.5915965291585573, 0.5930305888275328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 277}], {
             RGBColor[
             0.703778402475304, 0.7650597777341481, 0.9391840661465846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 282}], {
             RGBColor[
             0.7086495013011938, 0.7686926352628045, 0.9309385664203975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 293}], {
             RGBColor[
             0.6945707651548028, 0.7581927368966408, 0.9547701943937676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 203}], {
             RGBColor[
             0.9457322011696043, 0.8115693380751052, 0.5011887056843163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 205}], {
             RGBColor[
             0.9671735758607063, 0.8982418385742563, 0.5185270468168711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 212}], {
             RGBColor[
             0.7652869762282708, 0.8134163207219072, 0.8610700389440187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 225}], {
             RGBColor[
             0.9931653510907014, 0.989744338242269, 0.6395502486322393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 269}], {
             RGBColor[
             0.9458620187197144, 0.8121588092504965, 0.5012970286302476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 276}], {
             RGBColor[
             0.8153858958017304, 0.8540888805622486, 0.8650140094112306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 282}], {
             RGBColor[
             0.9882010502266545, 0.9892549153547436, 0.8392050062231122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 293}], {
             RGBColor[
             0.9741223140802636, 0.9787550169885801, 0.8630366341964824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 193}], {
             RGBColor[
             0.9643717449533127, 0.9722534852967151, 0.9140430904579102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 200}], {
             RGBColor[
             0.9816209967868762, 0.958165879994209, 0.5995514716324286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 202}], {
             RGBColor[
             0.930764859265715, 0.7531757955599958, 0.529060504035437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 227}], {
             RGBColor[
             0.9908857152762452, 0.9888689787450711, 0.6822237844930905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 228}], {
             RGBColor[
             0.9726760733631972, 0.9784468398277173, 0.8999860285757048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 264}], {
             RGBColor[
             0.9916555487343542, 0.990515574669864, 0.7660154055468621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 299}], {
             RGBColor[
             0.9680075285582576, 0.9749650467562337, 0.9078886571789728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 178}], {
             RGBColor[
             0.8947530650482227, 0.9158189970752499, 0.857339695063487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 182}], {
             RGBColor[
             0.9933580748879017, 0.9915214075235272, 0.7597374180660542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 190}], {
             RGBColor[
             0.9840968710370694, 0.9568969134305081, 0.542672050813583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 199}], {
             RGBColor[
             0.9561026535708562, 0.9645325352787874, 0.8632456632401255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 261}], {
             RGBColor[
             0.9937570198205086, 0.9894020032506261, 0.5870756840842255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 284}], {
             RGBColor[
             0.9797321495985523, 0.9826291822226765, 0.8396742933521043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 184}], {
             RGBColor[
             0.8756430735333028, 0.9026984512444203, 0.937432113375191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 275}], {
             RGBColor[
             0.823174711615619, 0.862275559528866, 0.982881063764463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 285}], {
             RGBColor[
             0.8789806669502567, 0.904078631894569, 0.8821195530413819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 174}], {
             RGBColor[
             0.9829797192006191, 0.9848872094617332, 0.8234721971047106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 238}], {
             RGBColor[
             0.946795290621564, 0.8118885426847895, 0.47481801193603596`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 186}], {
             RGBColor[
             0.9675517360744408, 0.9744592769417928, 0.9012335173644987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 213}], {
             RGBColor[
             0.9726957067434556, 0.9782956418442653, 0.8925261167842755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 234}], {
             RGBColor[
             0.9200797473291742, 0.9368649787891575, 0.905670626386835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 249}], {
             RGBColor[
             0.9369325302487574, 0.9503029304326274, 0.9072780598663619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 263}], {
             RGBColor[
             0.9588426844453883, 0.8716741041027707, 0.5434424972829579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 286}], {
             RGBColor[
             0.9527633224899463, 0.8475714597767223, 0.5385508999526437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 235}], {
             RGBColor[
             0.9826992925894574, 0.9842874052959381, 0.7929494910721983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 238}], {
             RGBColor[
             0.934632585654072, 0.8047572907376518, 0.5856291769796667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 298}], {
             RGBColor[
             0.9822571782202412, 0.9833417673648039, 0.7448280703966199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 183}], {
             RGBColor[
             0.9894861803556001, 0.989520761857217, 0.7950852587863637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 224}], {
             RGBColor[
             0.9830316776533962, 0.9868656334937564, 0.9136071230722644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 253}], {
             RGBColor[
             0.971109415098432, 0.9289665832002869, 0.6016758769940941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 180}], {
             RGBColor[
             0.8278299798580768, 0.8627114471730499, 0.7870208743632251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 187}], {
             RGBColor[
             0.9886437920171869, 0.988436226222598, 0.7603070352938086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 193}], {
             RGBColor[
             0.9672687901706649, 0.9724947848438151, 0.796489337926634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 221}], {
             RGBColor[
             0.9944859529859451, 0.9906143359296355, 0.6412081951528212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 230}], {
             RGBColor[
             0.993358948331064, 0.9882037869304945, 0.518540693535526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 245}], {
             RGBColor[
             0.9596669449186761, 0.8654699119877358, 0.4328940691314688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 288}], {
             RGBColor[
             0.9795124956528012, 0.9415222963397702, 0.4625521167439696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 296}], {
             RGBColor[
             0.9823391195495119, 0.9510571624662285, 0.4735330168195581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 297}], {
             RGBColor[
             0.9936949586617253, 0.9907040145205802, 0.6846121661394788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 194}], {
             RGBColor[
             0.9470372749742682, 0.8832920849283632, 0.6171795044140387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 226}], {
             RGBColor[
             0.9326389004338647, 0.7706427175157065, 0.26465788200210527`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 252}], {
             RGBColor[
             0.9070792278030959, 0.6605127631522811, 0.24363704581165757`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 268}], {
             RGBColor[
             0.9456468277599028, 0.8822550916725378, 0.6195331688612453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 279}], {
             RGBColor[
             0.9441845085225286, 0.8811644963796321, 0.6220084938961803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 280}], {
             RGBColor[
             0.9190468365060265, 0.7148548791662623, 0.2536231118663158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 182}], {
             RGBColor[
             0.8932311186596755, 0.9151896331313476, 0.8825622853927106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 190}], {
             RGBColor[
             0.8839699148088431, 0.8805651390383282, 0.6654969181402395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 199}], {
             RGBColor[
             0.85597569734263, 0.8882007608866076, 0.986070530566782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 229}], {
             RGBColor[
             0.8358589316545, 0.6871357052076204, 0.5996596241950177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 261}], {
             RGBColor[
             0.8936300635922823, 0.9130702288584465, 0.7099005514108819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 284}], {
             RGBColor[
             0.8796051933703259, 0.9062974078304966, 0.9624991606787607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 205}], {
             RGBColor[
             0.9565620919275816, 0.8917938389717202, 0.6021412386683122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 251}], {
             RGBColor[
             0.9383283039614765, 0.952730763578512, 0.9617093347893355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 269}], {
             RGBColor[
             0.9352505347865898, 0.8057108096479604, 0.5849112204816886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 274}], {
             RGBColor[
             0.9150978372260254, 0.9342074199778847, 0.9594935921340257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 277}], {
             RGBColor[
             0.9727184674676399, 0.9791740582235512, 0.9310646978007404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 282}], {
             RGBColor[
             0.9775895662935298, 0.9828069157522075, 0.9228191980745533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 289}], {
             RGBColor[
             0.983190199850878, 0.9846573899276, 0.7924253271593525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 187}], {
             RGBColor[
             0.8223007529454354, 0.8612026717695598, 0.9401806553073946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 193}], {
             RGBColor[
             0.8009257510989134, 0.8452612303907769, 0.9763629579402201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 215}], {
             RGBColor[
             0.8203751987334555, 0.8597665965910708, 0.9434401163233057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 221}], {
             RGBColor[
             0.8281429139141936, 0.8633807814765972, 0.8210818151664072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 230}], {
             RGBColor[
             0.8270159092593126, 0.8609702324774562, 0.6984143135491121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 233}], {
             RGBColor[
             0.522111123044331, 0.620702855081141, 0.9562515137422511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 245}], {
             RGBColor[
             0.7933239058469247, 0.7382363575346975, 0.6127676891450549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 288}], {
             RGBColor[
             0.8131694565810497, 0.814288741886732, 0.6424257367575557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 296}], {
             RGBColor[
             0.8159960804777605, 0.8238236080131903, 0.6534066368331441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 297}], {
             RGBColor[
             0.8273519195899739, 0.863470460067542, 0.8644857861530648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 201}], {
             RGBColor[
             0.978052702559519, 0.9807739823744714, 0.7970060688651559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 202}], {
             RGBColor[
             0.917371770268047, 0.7438828526568602, 0.5828819416171398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 203}], {
             RGBColor[
             0.9300204537874024, 0.8013175703431623, 0.5934363131932944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 216}], {
             RGBColor[
             0.8961969499830117, 0.9193994090431463, 0.9668106919741348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 227}], {
             RGBColor[
             0.9774926262785772, 0.9795760358419354, 0.7360452220747933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 258}], {
             RGBColor[
             0.9697634247780403, 0.9769701922240861, 0.9360668142756641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 299}], {
             RGBColor[
             0.9546144395605896, 0.9656721038530981, 0.9617100947606755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 190}], {
             RGBColor[
             0.9825749246485223, 0.9562675494866056, 0.5678946411428067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 199}], {
             RGBColor[
             0.954580707182309, 0.9639031713348849, 0.8884682535693492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 229}], {
             RGBColor[
             0.9344639414941791, 0.7628381156558977, 0.502057347197585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 261}], {
             RGBColor[
             0.9922350734319614, 0.9887726393067238, 0.6122982744134492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 284}], {
             RGBColor[
             0.9782102032100051, 0.981999818278774, 0.864896883681328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 224}], {
             RGBColor[
             0.988373578491921, 0.9886909852090034, 0.7969686035285319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 253}], {
             RGBColor[
             0.9764513159369568, 0.930791934915534, 0.4850373574503616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 222}], {
             RGBColor[
             0.9367469081251274, 0.9509866176324051, 0.9433755208244128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 224}], {
             RGBColor[
             0.9834813712314785, 0.9870595214508814, 0.9065095734980747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 248}], {
             RGBColor[
             0.9893918029663906, 0.9898812521554434, 0.825468808188194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 275}], {
             RGBColor[
             0.9325753047555561, 0.9476602943406658, 0.9429776295709889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 218}], {
             RGBColor[
             0.9567735032145162, 0.9086431933819781, 0.6147336362573245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 235}], {
             RGBColor[
             0.9731418139122767, 0.9185203167383555, 0.4658060825717602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 262}], {
             RGBColor[
             0.9675439560339416, 0.9166757794597078, 0.5965020690180246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 292}], {
             RGBColor[
             0.9603737529789766, 0.9113282537614449, 0.6086393525016172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 196}], {
             RGBColor[
             0.9681719347945679, 0.9695281404827165, 0.6974033604058473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 214}], {
             RGBColor[
             0.9693873833242438, 0.9732915041401276, 0.7307497026547112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 249}], {
             RGBColor[
             0.9151071183272939, 0.9348870154258884, 0.982799898255863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 265}], {
             RGBColor[
             0.9584228391720312, 0.9685124020476292, 0.9552634676082041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 286}], {
             RGBColor[
             0.9309379105684827, 0.8321555447699833, 0.6140727383421449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 193}], {
             RGBColor[
             0.9617395632580235, 0.970986009440325, 0.9496491188708036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 215}], {
             RGBColor[
             0.9811890108925657, 0.985491375640619, 0.9167262772538891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 228}], {
             RGBColor[
             0.9700438916679082, 0.9771793639713271, 0.9355920569885982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 229}], {
             RGBColor[
             0.9301031597967746, 0.7608558192756392, 0.5663107511189351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 230}], {
             RGBColor[
             0.9878297214184226, 0.9866950115270043, 0.6717004744796956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 233}], {
             RGBColor[
             0.6829249352034411, 0.746427634130689, 0.9295376746728347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 245}], {
             RGBColor[
             0.9541377180060349, 0.8639611365842457, 0.5860538500756383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 288}], {
             RGBColor[
             0.9739832687401597, 0.9400135209362801, 0.6157118976881392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 296}], {
             RGBColor[
             0.9768098926368707, 0.9495483870627384, 0.6266927977637277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 297}], {
             RGBColor[
             0.988165731749084, 0.9891952391170901, 0.8377719470836483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 236}], {
             RGBColor[
             0.9909170554071915, 0.9903927443887044, 0.7915240225017426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 260}], {
             RGBColor[
             0.9747818058726931, 0.9787741648963533, 0.8374241689526867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 261}], {
             RGBColor[
             0.9938889001633189, 0.9893373003133384, 0.576222679992877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 281}], {
             RGBColor[
             0.6581898467373083, 0.7223407495919084, 0.8272493328356589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 294}], {
             RGBColor[
             0.9943567478696884, 0.9903379792506039, 0.6271450156098395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 257}], {
             RGBColor[
             0.8739083297323811, 0.9022947967916635, 0.987835350708692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 260}], {
             RGBColor[
             0.9084466063315548, 0.9293519223823128, 0.9743920968105171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 267}], {
             RGBColor[
             0.9080643104799275, 0.8735711867841454, 0.634156397929439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 287}], {
             RGBColor[
             0.9089838412698179, 0.8772168199505894, 0.6348962739871464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 300}], {
             RGBColor[
             0.9284352192745815, 0.9418005370615761, 0.8091384730620306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 199}], {
             RGBColor[
             0.9453195033314767, 0.9292786772418657, 0.6714028863168781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 261}], {
             RGBColor[
             0.982973869581129, 0.9541481452137045, 0.39523290716097803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 284}], {
             RGBColor[
             0.9689489993591727, 0.9473753241857548, 0.6478315164288568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 205}], {
             RGBColor[
             0.9675050218901202, 0.896996131883612, 0.4125214817042807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 217}], {
             RGBColor[
             0.9777817705821352, 0.9359889621882468, 0.4299099125462168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 225}], {
             RGBColor[
             0.9934967971201152, 0.9884986315516248, 0.5335446835196489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 246}], {
             RGBColor[
             0.9802445350914792, 0.9442964451628697, 0.4394772876109646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 251}], {
             RGBColor[
             0.949271233924015, 0.957933056490404, 0.7720895778253041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 270}], {
             RGBColor[
             0.9663475376596666, 0.9714637028674388, 0.7707527892503405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 271}], {
             RGBColor[
             0.9492643355073382, 0.8246778887242902, 0.3978445972767556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 278}], {
             RGBColor[
             0.9891524941051968, 0.9743450826043806, 0.47408302625235027`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 282}], {
             RGBColor[
             0.9885324962560684, 0.9880092086640995, 0.7331994411105218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 295}], {
             RGBColor[
             0.9904076282405173, 0.9889185538702323, 0.7081213078740006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 218}], {
             RGBColor[
             0.8651379023932092, 0.8950439489282978, 0.963512195844326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 220}], {
             RGBColor[
             0.8778910617527218, 0.9040303650554566, 0.9184197065875557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 222}], {
             RGBColor[
             0.8284405024065835, 0.86645667035033, 0.9833880133942887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 248}], {
             RGBColor[
             0.8810853972478467, 0.9053513048733685, 0.86548130075807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 262}], {
             RGBColor[
             0.8759083552126348, 0.9030765350060275, 0.9452806286050262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 200}], {
             RGBColor[
             0.9576138132450651, 0.9409569627590362, 0.6713398026781475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 215}], {
             RGBColor[
             0.9598140090460436, 0.9695499342618361, 0.9529085798867145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 228}], {
             RGBColor[
             0.9486688898213861, 0.9612379225925443, 0.9717743596214237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 230}], {
             RGBColor[
             0.9664547195719007, 0.9707535701482215, 0.707882777112521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 245}], {
             RGBColor[
             0.9327627161595128, 0.8480196952054628, 0.6222361527084638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 264}], {
             RGBColor[
             0.9676483651925432, 0.9733066574346911, 0.837803736592581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 288}], {
             RGBColor[
             0.9526082668936378, 0.9240720795574973, 0.6518942003209647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 210}], {
             RGBColor[
             0.973478487833296, 0.9765489344208085, 0.7401928571163662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 226}], {
             RGBColor[
             0.9392139973226257, 0.8522753959923361, 0.6108847115795989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 241}], {
             RGBColor[
             0.7705567324344578, 0.8204618215933122, 0.9620378593009105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 280}], {
             RGBColor[
             0.9256219333947875, 0.796487557642892, 0.5998499414438094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 290}], {
             RGBColor[
             0.9591425720839803, 0.9690491776749064, 0.9540451475246816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 291}], {
             RGBColor[
             0.9563478346817421, 0.9192826297773606, 0.6294765502810299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 234}], {
             RGBColor[
             0.9178706156465858, 0.9223898465233512, 0.6908490550878477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 207}], {
             RGBColor[
             0.7273576781548255, 0.7779137275612129, 0.6845029956287021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 212}], {
             RGBColor[
             0.7640876263142544, 0.8077327541423454, 0.6873945116940456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 214}], {
             RGBColor[
             0.9918329939658346, 0.9837762826877902, 0.4513977073065585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 225}], {
             RGBColor[
             0.991966001176685, 0.9840607716627072, 0.4658747213822664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 265}], {
             RGBColor[
             0.980868449813622, 0.9789971805952917, 0.6759114722600514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 276}], {
             RGBColor[
             0.814186545887714, 0.8484053139826868, 0.6913384821612578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 198}], {
             RGBColor[
             0.7393132314588085, 0.7798317364015199, 0.6738715599984567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 204}], {
             RGBColor[
             0.6908768876888844, 0.5914763525060198, 0.5906459694635654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 226}], {
             RGBColor[
             0.7094528257083171, 0.6698947990920268, 0.6058394063073143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 243}], {
             RGBColor[
             0.7180737953222325, 0.7782353873701409, 0.9681406682712594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 254}], {
             RGBColor[
             0.7331971126835246, 0.7592006316395077, 0.6501115934885962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 283}], {
             RGBColor[
             0.7173937754122247, 0.7777282296346876, 0.969291764601305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 204}], {
             RGBColor[
             0.9361000905132808, 0.7711445193031656, 0.3112018060150592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 226}], {
             RGBColor[
             0.9546760285327134, 0.8495629658891726, 0.32639524285880805`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 243}], {
             RGBColor[
             0.9632969981466287, 0.9579035541672867, 0.6886965048227534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 254}], {
             RGBColor[
             0.978420315507921, 0.9388687984366536, 0.37066743004008995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 256}], {
             RGBColor[
             0.5817317171416023, 0.632446951599333, 0.6639641982749753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 283}], {
             RGBColor[
             0.962616978236621, 0.9573963964318335, 0.6898476011527988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 209}], {
             RGBColor[
             0.8164180508275665, 0.8572980267797914, 0.9821277940493847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 229}], {
             RGBColor[
             0.8972085201771336, 0.7358492434111578, 0.6055655923716563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 233}], {
             RGBColor[
             0.6500302955838001, 0.7214210582662077, 0.9687925159255559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 259}], {
             RGBColor[
             0.9560412263667792, 0.9640543670450986, 0.8313523256259836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 261}], {
             RGBColor[
             0.9549796521149159, 0.9617837670619838, 0.7158065195875205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 284}], {
             RGBColor[
             0.9409547818929596, 0.9550109460340341, 0.9684051288553993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 210}], {
             RGBColor[
             0.9841038344410957, 0.9575212314465771, 0.4369137820469331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 211}], {
             RGBColor[
             0.8900790576495903, 0.5539892324262055, 0.24781504978024557`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 227}], {
             RGBColor[
             0.9841277835679977, 0.9575724562073921, 0.4395204967133279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 228}], {
             RGBColor[
             0.9659181416549496, 0.9471503172900383, 0.6572827407959421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 231}], {
             RGBColor[
             0.9419310001259767, 0.928572225258846, 0.6740152539170343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 245}], {
             RGBColor[
             0.9500119679930763, 0.8339320899029568, 0.3077445338829823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 264}], {
             RGBColor[
             0.9848976170261067, 0.9592190521321851, 0.5233121177670994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 202}], {
             RGBColor[
             0.9338317223277781, 0.753780318305715, 0.4299903759066989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 203}], {
             RGBColor[
             0.9464804058471337, 0.8112150359920172, 0.44054474748285355`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 216}], {
             RGBColor[
             0.9126569020427429, 0.9292968746920011, 0.813919126263694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 237}], {
             RGBColor[
             0.9860804444949444, 0.9867610591656907, 0.7834171957389041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 269}], {
             RGBColor[
             0.9466102233972438, 0.8118045071674084, 0.4406530704287848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 277}], {
             RGBColor[
             0.9840781560782941, 0.9852677557429992, 0.7868065477478365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 293}], {
             RGBColor[
             0.974870518757793, 0.9784007149054919, 0.8023926759950197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 299}], {
             RGBColor[
             0.9710743916203208, 0.9755695695019528, 0.8088185290502347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 203}], {
             RGBColor[
             0.8857994735556616, 0.5743239062744059, 0.2264206202348374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 216}], {
             RGBColor[
             0.8519759697512708, 0.6924057449743899, 0.5997949990156779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 237}], {
             RGBColor[
             0.9253995122034723, 0.7498699294480795, 0.5692930684908879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 269}], {
             RGBColor[
             0.8859292911057717, 0.5749133774497972, 0.22652894318076866`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 293}], {
             RGBColor[
             0.9141895864663209, 0.7415095851878807, 0.5882685487470035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 299}], {
             RGBColor[
             0.9103934593288487, 0.7386784397843416, 0.5946944018022184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 216}], {
             RGBColor[
             0.8646246532706263, 0.749840462660692, 0.6103493705918325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 237}], {
             RGBColor[
             0.9380481957228277, 0.8073046471343817, 0.5798474400670426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 255}], {
             RGBColor[
             0.9295081039117248, 0.8009354606447778, 0.5943035878905677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 269}], {
             RGBColor[
             0.8985779746251272, 0.6323480951360994, 0.2370833147569233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 293}], {
             RGBColor[
             0.9268382699856763, 0.7989443028741828, 0.5988229203231581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 299}], {
             RGBColor[
             0.9230421428482042, 0.7961131574706437, 0.6052487733783731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 226}], {
             RGBColor[
             0.9062396847627896, 0.6612075819936725, 0.24316965232391674`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 243}], {
             RGBColor[
             0.9148606543767048, 0.7695481702717866, 0.605470914287862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 254}], {
             RGBColor[
             0.9299839717379971, 0.7505134145411534, 0.28744183950519864`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 283}], {
             RGBColor[
             0.9141806344666972, 0.7690410125363333, 0.6066220106179074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 225}], {
             RGBColor[
             0.9673226816872161, 0.8966061246270228, 0.3926748758914699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 251}], {
             RGBColor[
             0.923097118491116, 0.866040549565802, 0.631219770197125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 269}], {
             RGBColor[
             0.9200193493162292, 0.7190205956352503, 0.2544216558894781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 282}], {
             RGBColor[
             0.9623583808231693, 0.8961167017394975, 0.5923296334823428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 219}], {
             RGBColor[
             0.9851898835554604, 0.9879717495537749, 0.8874074117008827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 254}], {
             RGBColor[
             0.9797633309533489, 0.953610934451759, 0.6041639065017872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 283}], {
             RGBColor[
             0.963959993682049, 0.9721385324469389, 0.9233440776144961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 212}], {
             RGBColor[
             0.5008277590329212, 0.6056335626731792, 0.9538461422650533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 214}], {
             RGBColor[
             0.7285731266845015, 0.781677091218624, 0.7178493378775659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 225}], {
             RGBColor[
             0.7287061338953518, 0.7819615801935411, 0.7323263519532739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 242}], {
             RGBColor[
             0.9666236524085858, 0.9322277905122941, 0.6232938382263207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 244}], {
             RGBColor[
             0.9790417267166411, 0.9832673065104851, 0.8924785105009103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 252}], {
             RGBColor[
             0.9219200185573435, 0.7483099825799591, 0.5758722117131088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 268}], {
             RGBColor[
             0.9604876185141504, 0.9700523111002158, 0.9517683347626964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 279}], {
             RGBColor[
             0.9590252992767762, 0.96896171580731, 0.9542436597976316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 259}], {
             RGBColor[
             0.8551339913290822, 0.884438094734745, 0.8215036209319477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 211}], {
             RGBColor[
             0.8962395705579017, 0.5744238150862366, 0.3011921152430903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 226}], {
             RGBColor[
             0.9590801132928926, 0.8638995670081516, 0.3876712347044329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 227}], {
             RGBColor[
             0.9933685529304648, 0.9882243301974389, 0.519586094907595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 241}], {
             RGBColor[
             0.7904228484047247, 0.8320859926091277, 0.7388243824257444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 290}], {
             RGBColor[
             0.9790086880542472, 0.980673348690722, 0.7308316706495155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 291}], {
             RGBColor[
             0.9762139506520089, 0.9309068007931762, 0.4062630734058639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 231}], {
             RGBColor[
             0.8681243476811557, 0.5551244776277493, 0.45925976315649103`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 264}], {
             RGBColor[
             0.896768758947909, 0.5755556955433087, 0.35879100572320116`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 266}], {
             RGBColor[
             0.896375189418708, 0.5747138901163312, 0.3159533912992685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 214}], {
             RGBColor[
             0.7653030748439302, 0.8114961177997566, 0.7207408539429095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 225}], {
             RGBColor[
             0.7654360820547806, 0.8117806067746737, 0.7352178680186174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 265}], {
             RGBColor[
             0.7543385306917176, 0.8067170157072581, 0.9452546188964026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 276}], {
             RGBColor[
             0.5876566267658097, 0.6761251490946533, 0.9606816287976088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 234}], {
             RGBColor[
             0.9033983060767254, 0.925285428684891, 0.972485064196113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 249}], {
             RGBColor[
             0.9202510889963087, 0.9387233803283609, 0.9740924976756398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 263}], {
             RGBColor[
             0.9421612431929397, 0.8600945539985043, 0.6102569350922359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 286}], {
             RGBColor[
             0.9360818812374977, 0.8359919096724558, 0.6053653377619217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 265}], {
             RGBColor[
             0.9820838983432979, 0.9827605442527029, 0.7092578145089152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 276}], {
             RGBColor[
             0.8154019944173898, 0.8521686776400981, 0.7246848244101216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 286}], {
             RGBColor[
             0.9545989697397494, 0.8464036869750571, 0.36806708524285603`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 229}], {
             RGBColor[
             0.9281776055847948, 0.7594197440971503, 0.569570212134846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 233}], {
             RGBColor[
             0.6809993809914613, 0.7449915589522003, 0.9327971356887457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 259}], {
             RGBColor[
             0.9870103117744404, 0.9876248677310911, 0.7953569453891733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 296}], {
             RGBColor[
             0.9748843384248909, 0.9481123118842496, 0.6299522587796387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 237}], {
             RGBColor[
             0.904224691918437, 0.9253864858343656, 0.953221818847883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 269}], {
             RGBColor[
             0.8647544708207364, 0.7504299338360833, 0.6104576935377637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 293}], {
             RGBColor[
             0.8930147661812856, 0.9170261415741667, 0.9721972991039987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 299}], {
             RGBColor[
             0.8892186390438135, 0.9141949961706277, 0.9786231521592136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 223}], {
             RGBColor[
             0.9506874043046993, 0.8404479673204718, 0.2882996494874599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 246}], {
             RGBColor[
             0.9643471683505951, 0.8913967685429025, 0.31599591082472167`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 247}], {
             RGBColor[
             0.9781411090914857, 0.936757550925051, 0.4690216917087892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 251}], {
             RGBColor[
             0.9333738671831311, 0.9050333798704367, 0.6486082010390611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 270}], {
             RGBColor[
             0.9504501709187827, 0.9185640262474716, 0.6472714124640976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 271}], {
             RGBColor[
             0.9333669687664543, 0.771778212104323, 0.27436322049051265`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 278}], {
             RGBColor[
             0.9732551273643129, 0.9214454059844134, 0.35060164946610733`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 295}], {
             RGBColor[
             0.9745102614996333, 0.9360188772502651, 0.5846399310877577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 220}], {
             RGBColor[
             0.9745981089097789, 0.9800510224916843, 0.9043782381104133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 262}], {
             RGBColor[
             0.9726154023696919, 0.9790971924422551, 0.9312391601278838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 290}], {
             RGBColor[
             0.9632588609275989, 0.9721190991546727, 0.9470773442125073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 292}], {
             RGBColor[
             0.9654451993147269, 0.9737496667439922, 0.9433764436114764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 250}], {
             RGBColor[
             0.9653772691678781, 0.9736990045516978, 0.9434914316310714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 222}], {
             RGBColor[
             0.9379007089231532, 0.9514637439137167, 0.924254055660376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 248}], {
             RGBColor[
             0.9905456037644165, 0.9903583784367551, 0.8063473430241571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 262}], {
             RGBColor[
             0.9853685617292045, 0.988083608569414, 0.8861466708711134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 230}], {
             RGBColor[
             0.9936718823871808, 0.9888731212340419, 0.5526016343387082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 232}], {
             RGBColor[
             0.8006124613168935, 0.841323335482473, 0.8187141806854992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 245}], {
             RGBColor[
             0.959979878974793, 0.8661392462912831, 0.4669550099346509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 288}], {
             RGBColor[
             0.979825429708918, 0.9421916306433177, 0.4966130575471518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 296}], {
             RGBColor[
             0.9826520536056288, 0.951726496769776, 0.5075939576227403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 297}], {
             RGBColor[
             0.9940078927178422, 0.9913733488241276, 0.718673106942661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 248}], {
             RGBColor[
             0.9410950444182782, 0.9527846837316285, 0.87131564983089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 285}], {
             RGBColor[
             0.9400845015420812, 0.9523667982825539, 0.8880629604906038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 246}], {
             RGBColor[
             0.9531501688140434, 0.8487554502950947, 0.2978670245522077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 247}], {
             RGBColor[
             0.9669441095549338, 0.8941162326772432, 0.4508928054362753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 270}], {
             RGBColor[
             0.9392531713822307, 0.8759227079996638, 0.6291425261915837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 271}], {
             RGBColor[
             0.9221699692299024, 0.7291368938565151, 0.2562343342179987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 278}], {
             RGBColor[
             0.9620581278277609, 0.8788040877366056, 0.3324727631935934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 295}], {
             RGBColor[
             0.9633132619630814, 0.8933775590024573, 0.5665110448152437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 253}], {
             RGBColor[
             0.9699968132347528, 0.9281368065520734, 0.6035592217362623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 262}], {
             RGBColor[
             0.9826524654894173, 0.9865828176827638, 0.9142490303515083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 265}], {
             RGBColor[
             0.9822169055541483, 0.9830450332276199, 0.7237348285846232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 276}], {
             RGBColor[
             0.8155350016282402, 0.8524531666150151, 0.7391618384858294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 241}], {
             RGBColor[
             0.7561583578940543, 0.7078124541806554, 0.6095162368889772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 243}], {
             RGBColor[
             0.9334365923961374, 0.8479666168577935, 0.6206643511316108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 290}], {
             RGBColor[
             0.9447441975435769, 0.8563998102622496, 0.6015235251127482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 291}], {
             RGBColor[
             0.9419494601413385, 0.8066332623647039, 0.2769549278690966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 241}], {
             RGBColor[
             0.7904467975316265, 0.8321372173699428, 0.7414310970921392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 290}], {
             RGBColor[
             0.9790326371811491, 0.980724573451537, 0.7334383853159103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 291}], {
             RGBColor[
             0.9762378997789108, 0.9309580255539912, 0.40886978807225866`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 299}], {
             RGBColor[
             0.970514315339379, 0.9743716229694168, 0.7478576822598719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 264}], {
             RGBColor[
             0.9759526936024276, 0.9795000119656933, 0.8237466747103755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 233}], {
             RGBColor[
             0.6299135298956702, 0.5203560025872205, 0.5823816095537916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 259}], {
             RGBColor[
             0.9359244606786492, 0.7629893113661114, 0.4449414192542194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 284}], {
             RGBColor[
             0.9208380162048295, 0.7539458903550469, 0.5819942224836351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 245}], {
             RGBColor[
             0.9588528743199118, 0.8637286972921421, 0.3442875083173558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 288}], {
             RGBColor[
             0.9786984250540369, 0.9397810816441766, 0.3739455559298567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 296}], {
             RGBColor[
             0.9815250489507477, 0.949315947770635, 0.3849264560054452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 297}], {
             RGBColor[
             0.992880888062961, 0.9889627998249866, 0.5960056053253658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 232}], {
             RGBColor[
             0.7577124853825249, 0.8108190468964624, 0.9766707746981986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 245}], {
             RGBColor[
             0.9170799030404244, 0.8356349577052726, 0.6249116039473505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 264}], {
             RGBColor[
             0.9519655520734548, 0.9609219199345009, 0.8404791878314677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 266}], {
             RGBColor[
             0.9513751977796534, 0.9596592117940348, 0.7762227661955687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 240}], {
             RGBColor[
             0.781220150541366, 0.8290395462358809, 0.9607498900042741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 245}], {
             RGBColor[
             0.7657934532496244, 0.7161789115405732, 0.6104000546641467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 288}], {
             RGBColor[
             0.7856390039837495, 0.7922312958926077, 0.6400581022766476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 297}], {
             RGBColor[
             0.7998214669926736, 0.8414130140734177, 0.8621181516721568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 259}], {
             RGBColor[
             0.6887462360853158, 0.7485611262211613, 0.808168342808119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[
             0.8745844209042419, 0.9028338935400994, 0.9878998368882177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 249}], {
             RGBColor[
             0.8676351295820273, 0.8972927172732531, 0.9872370072781993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 263}], {
             RGBColor[
             0.8895452837786582, 0.8186638909433965, 0.6234014446947954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 274}], {
             RGBColor[
             0.9264919839999484, 0.9403748200243098, 0.8189860005017919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 298}], {
             RGBColor[
             0.9941394565765714, 0.9898732151461465, 0.6034941993204768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 260}], {
             RGBColor[
             0.970555079317815, 0.9771455436922034, 0.9161393719002957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 267}], {
             RGBColor[
             0.9701727834661877, 0.921364808094036, 0.5759036730192175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 294}], {
             RGBColor[
             0.9901300213148103, 0.988709358046454, 0.7058602185574485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 256}], {
             RGBColor[
             0.5782876171853193, 0.6441223351540276, 0.9281104441615466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 269}], {
             RGBColor[
             0.938178013272938, 0.8078941183097729, 0.5799557630129739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 277}], {
             RGBColor[
             0.9756459459539881, 0.9813573668853637, 0.9261092403320257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 281}], {
             RGBColor[
             0.6494420729415927, 0.7177554019495088, 0.9322048672201388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 293}], {
             RGBColor[
             0.9664383086334871, 0.9744903260478563, 0.9416953685792087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 248}], {
             RGBColor[
             0.9460632172027907, 0.9567461698525412, 0.8717895185862171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 258}], {
             RGBColor[
             0.9381602971011664, 0.9524384445864855, 0.9562030469767473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 263}], {
             RGBColor[
             0.9133473580204563, 0.8376430188537125, 0.6256717077843406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 285}], {
             RGBColor[
             0.9450526743265938, 0.9563282844034664, 0.8885368292459308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 290}], {
             RGBColor[
             0.776086932655409, 0.8245862358632257, 0.9526766728340599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 291}], {
             RGBColor[
             0.7732921952531706, 0.7748196879656799, 0.6281080755904082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 250}], {
             RGBColor[
             0.9553503908110327, 0.9238202104711106, 0.6423765295734584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 268}], {
             RGBColor[
             0.9569675113287339, 0.9250262563054205, 0.6396391663495697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 254}], {
             RGBColor[
             0.957180879371345, 0.9372724494052744, 0.6649365383128927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 256}], {
             RGBColor[
             0.5604922810050263, 0.6308506025679538, 0.958233306547778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 283}], {
             RGBColor[
             0.941377542100045, 0.9558000474004543, 0.9841167094256016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 279}], {
             RGBColor[
             0.9679232663994151, 0.9749751770107058, 0.9112991636590946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 280}], {
             RGBColor[
             0.9427855943829129, 0.808665559797336, 0.54291378162923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 264}], {
             RGBColor[
             0.9600465199405543, 0.8662817845786117, 0.47420846779741566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 288}], {
             RGBColor[
             0.945006421641649, 0.8170472067014178, 0.28829893152579933`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 297}], {
             RGBColor[
             0.9591888846505732, 0.8662289248822279, 0.5103589809213085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 270}], {
             RGBColor[
             0.9529129354281266, 0.9268715092220945, 0.6568387875288454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 278}], {
             RGBColor[
             0.9757178918736568, 0.9297528889590363, 0.36016902453085514`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 295}], {
             RGBColor[
             0.9769730260089773, 0.9443263602248879, 0.5942073061525055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 251}], {
             RGBColor[
             0.9496305724333656, 0.9587016452272081, 0.8112013569878764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 270}], {
             RGBColor[
             0.9667068761690172, 0.972232291604243, 0.8098645684129129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 271}], {
             RGBColor[
             0.9496236740166888, 0.8254464774610943, 0.43695637643932794`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 278}], {
             RGBColor[
             0.9895118326145473, 0.9751136713411848, 0.5131948054149227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 289}], {
             RGBColor[
             0.9944924683227669, 0.9906282715762962, 0.6419173493578936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 295}], {
             RGBColor[
             0.9907669667498678, 0.9896871426070365, 0.7472330870365731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 285}], {
             RGBColor[
             0.9927293963833443, 0.9912614328055922, 0.7701562478543851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 258}], {
             RGBColor[
             0.9312110057789517, 0.9468972683196393, 0.9555402173667288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 263}], {
             RGBColor[
             0.9063980666982414, 0.8321018425868663, 0.6250088781743222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 286}], {
             RGBColor[
             0.9003187047427994, 0.8079991982608179, 0.6201172808440079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 270}], {
             RGBColor[
             0.9219396342606625, 0.9405081205496287, 0.9894510777431849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 271}], {
             RGBColor[
             0.9048564321083341, 0.7937223064064801, 0.6165428857695999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 278}], {
             RGBColor[
             0.9447445907061927, 0.9433895002865705, 0.6927813147451947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 282}], {
             RGBColor[
             0.9441245928570642, 0.9570536263462894, 0.9518977296033662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 289}], {
             RGBColor[
             0.9497252264144124, 0.9589041005216818, 0.8215038586881654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 295}], {
             RGBColor[
             0.9459997248415131, 0.9579629715524223, 0.926819596366845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 268}], {
             RGBColor[
             0.9122638774774917, 0.7411084483730854, 0.5922175398363578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 279}], {
             RGBColor[
             0.9108015582401174, 0.7400178530801798, 0.5946928648712929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 280}], {
             RGBColor[
             0.8856638862236152, 0.57370823586681, 0.22630748284142838`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 283}], {
             RGBColor[
             0.907196899855361, 0.7373295047589149, 0.6007946112712086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 283}], {
             RGBColor[
             0.9565008594613373, 0.9367652916698213, 0.6660876346429382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 258}], {
             RGBColor[
             0.9692510749023626, 0.9765880825257016, 0.9369340889729375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 286}], {
             RGBColor[
             0.9383587738662105, 0.8376900124668802, 0.6015111524502166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 269}], {
             RGBColor[
             0.5388173960876188, 0.4691657831557453, 0.5853463188514273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 277}], {
             RGBColor[
             0.5762853287686689, 0.6426290317313361, 0.9314997961704791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 281}], {
             RGBColor[
             0.25008145575627344`, 0.37902706679548126`, 0.9375954230585922]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 293}], {
             RGBColor[
             0.5670776914481679, 0.6357619908938288, 0.9470859244176622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 267}], {
             RGBColor[
             0.9194992573325156, 0.8826891030110355, 0.6352470733683364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 272}], {
             RGBColor[
             0.9131466415981502, 0.9334469525757751, 0.9868832208182345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 300}], {
             RGBColor[
             0.9398701661271696, 0.9509184532884662, 0.8102291485009281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 263}], {
             RGBColor[
             0.9531211599755827, 0.8682684419897826, 0.5917046547833249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 286}], {
             RGBColor[
             0.9470417980201407, 0.8441657976637342, 0.5868130574530106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 267}], {
             RGBColor[
             0.9540375339316893, 0.9097462286016849, 0.6218038194701615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 287}], {
             RGBColor[
             0.9549570647215796, 0.9133918617681288, 0.622543695527869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 294}], {
             RGBColor[
             0.9739947717803119, 0.9770907785541028, 0.7517603650083926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 300}], {
             RGBColor[
             0.9744084427263433, 0.9779755788791156, 0.7967858946027532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 284}], {
             RGBColor[
             0.9786091481426118, 0.9798804140058729, 0.6922351496994992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 292}], {
             RGBColor[
             0.9762156521341525, 0.9817822528217219, 0.9251448763721766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 286}], {
             RGBColor[
             0.9222288589394304, 0.7293703719309612, 0.25628171826060403`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 288}], {
             RGBColor[
             0.9798920706746794, 0.9423341689306461, 0.5038665154099166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 276}], {
             RGBColor[
             0.8044374502651772, 0.8473895755475995, 0.9491985893636146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 286}], {
             RGBColor[
             0.9436344255875369, 0.8416245848825586, 0.592580850196349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 272}], {
             RGBColor[
             0.9473026223456966, 0.9047233425682571, 0.6332042680389816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 287}], {
             RGBColor[
             0.9545747688699522, 0.8576111261699615, 0.28230799664679085`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 300}], {
             RGBColor[
             0.974026146874716, 0.9221948432809481, 0.456550195721675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 279}], {
             RGBColor[
             0.9493691581969244, 0.9617601816004364, 0.9705889879208807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 280}], {
             RGBColor[
             0.9242314861804222, 0.7954505643870666, 0.6022036058910161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 277}], {
             RGBColor[
             0.9361757248562876, 0.8064008148870814, 0.5833451150219063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 282}], {
             RGBColor[
             0.9410468236821774, 0.8100336724157378, 0.5750996152957193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 293}], {
             RGBColor[
             0.9269680875357866, 0.799533774049574, 0.5989312432690894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 271}], {
             RGBColor[
             0.9219327358439857, 0.8072529527835149, 0.6152060971946364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 278}], {
             RGBColor[
             0.9618208944418443, 0.9569201466636054, 0.6914445261702311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 289}], {
             RGBColor[
             0.966801530150064, 0.9724347468987167, 0.8201670701132019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 295}], {
             RGBColor[
             0.9630760285771647, 0.9714936179294571, 0.9254828077918814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 278}], {
             RGBColor[
             0.9447376922895159, 0.8101343325204567, 0.31853633419664606`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 289}], {
             RGBColor[
             0.9497183279977356, 0.825648932755568, 0.44725887813961696`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 295}], {
             RGBColor[
             0.9459928264248363, 0.8247078037863085, 0.5525746158182965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 274}], {
             RGBColor[
             0.9260266064487097, 0.9393794244990984, 0.7683325260267952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 289}], {
             RGBColor[
             0.9941189690735621, 0.9898293944488137, 0.601264261052122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 289}], {
             RGBColor[
             0.9264947596789614, 0.9403807569210545, 0.8192881160328557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 281}], {
             RGBColor[
             0.6474397845249423, 0.7162620985268173, 0.9355942192290713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 282}], {
             RGBColor[
             0.9785147563632277, 0.9834969209913285, 0.9212530926147711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 293}], {
             RGBColor[
             0.9644360202168367, 0.972997022625165, 0.9450847205881412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 295}], {
             RGBColor[
             0.9858809850226948, 0.9743749976663989, 0.6288130447938911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 280}], {
             RGBColor[
             0.9227691669430479, 0.794359969094161, 0.6046789309259512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 294}], {
             RGBColor[
             0.657402812644927, 0.720657363249658, 0.7415855288913649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 293}], {
             RGBColor[
             0.9693071190427266, 0.9766298801538212, 0.936839220861954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 300}], {
             RGBColor[
             0.9749456776646063, 0.9258404764473922, 0.4572900717793825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 296}], {
             RGBColor[
             0.9676785962724849, 0.9026344571799108, 0.32893787921388873`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 297}], {
             RGBColor[
             0.9790344353846983, 0.9422813092342623, 0.5400170285338094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 291}], {
             RGBColor[
             0.9618780349026932, 0.9234070440472741, 0.6201153638141792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 297}], {
             RGBColor[
             0.981861059281409, 0.9518161753607206, 0.5509979286093979]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.032105813875877395`], {
             RGBColor[
             0.9706973731563581, 0.9128175004517345, 0.34066525735955605`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.032105813875877395`], {
             RGBColor[
             0.9722890881385069, 0.9788538278229278, 0.931791525004898]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.032105813875877395`], {
             RGBColor[
             0.9945126546192502, 0.9906714480233262, 0.6441145031547151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.032105813875877395`], {
             RGBColor[
             0.971303946757539, 0.9781191109940229, 0.9334591123968543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.032105813875877395`], {
             RGBColor[
             0.9933717668096647, 0.9882312043600743, 0.519935905824727]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.032105813875877395`], {
             RGBColor[
             0.7377588447282768, 0.795062083767404, 0.9744965649602781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.032105813875877395`], {
             RGBColor[
             0.9638524208262583, 0.9725617751552278, 0.9460726021292919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.032105813875877395`], {
             RGBColor[
             0.9829832347515188, 0.9542605964696966, 0.38839350966647107`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.032105813875877395`], {
             RGBColor[
             0.9378795070461262, 0.9531912185847483, 0.9900379703382278]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.032105813875877395`], {
             RGBColor[
             0.9928218043075682, 0.9870548901778284, 0.4600758814466657]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.032105813875877395`], {
             RGBColor[
             0.9745508474559521, 0.9805406442185876, 0.9279629564417691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.032105813875877395`], {
             RGBColor[
             0.3196016126423582, 0.4512445860518547, 0.9415857100383297]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.032105813875877395`], {
             RGBColor[
             0.9952314060149147, 0.9922087845817391, 0.7223461569533463]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.032105813875877395`], {
             RGBColor[
             0.9541216957183908, 0.9653046163023802, 0.9625441815573417]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.032105813875877395`], {
             RGBColor[
             0.8993872112621397, 0.922610965317678, 0.9902655491742663]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.032105813875877395`], {
             RGBColor[
             0.963240302185678, 0.8876630490641024, 0.311695944788155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.032105813875877395`], {
             RGBColor[
             0.8729588244689775, 0.9015376870682593, 0.9877447860490352]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.032105813875877395`], {
             RGBColor[
             0.9847489847007029, 0.9879613274875946, 0.9024123220791529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.032105813875877395`], {
             RGBColor[
             0.9943443294243139, 0.9903114174516452, 0.6257933444685859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.032105813875877395`], {
             RGBColor[
             0.9723041967326372, 0.9182376936746414, 0.3469074635302294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.032105813875877395`], {
             RGBColor[
             0.9384799758597422, 0.7938006351563105, 0.26935774839742826`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.032105813875877395`], {
             RGBColor[
             0.9865485455586898, 0.9887054921489767, 0.8725889415480982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.032105813875877395`], {
             RGBColor[
             0.2526867065143148, 0.38292012818204746`, 0.937701506168283]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.032105813875877395`], {
             RGBColor[
             0.9220544248258162, 0.9406851861282324, 0.9924275682392303]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.032105813875877395`], {
             RGBColor[
             0.9629848248609555, 0.8868012640588847, 0.3107034636244522]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.032105813875877395`], {
             RGBColor[
             0.9947954533266518, 0.9912763258631228, 0.6748953972240551]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.032105813875877395`], {
             RGBColor[
             0.9904108873721715, 0.9903026697465085, 0.8085799422785023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.032105813875877395`], {
             RGBColor[
             0.9951182640522156, 0.9919667853639329, 0.7100313525448074]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.032105813875877395`], {
             RGBColor[
             0.9014085332944649, 0.6452010009597884, 0.23944520229396066`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.032105813875877395`], {
             RGBColor[
             0.9719664687388917, 0.9786132188029357, 0.9323376354958309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.032105813875877395`], {
             RGBColor[
             0.9447872245864848, 0.9583429830159984, 0.9783450063636773]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.032105813875877395`], {
             RGBColor[
             0.9803618119925476, 0.9848744520553994, 0.9181265092235937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.032105813875877395`], {
             RGBColor[
             0.9926544626689563, 0.9866969633336725, 0.4418617767966432]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.032105813875877395`], {
             RGBColor[
             0.9771532237070361, 0.982481492165646, 0.9235578122571141]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.032105813875877395`], {
             RGBColor[
             0.9189349690295883, 0.7163111960621815, 0.25363137712161166`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.032105813875877395`], {
             RGBColor[
             0.2526867065143148, 0.38292012818204746`, 0.937701506168283]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.032105813875877395`], {
             RGBColor[
             0.9153858748964605, 0.9353678654275299, 0.9917915159938835]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.032105813875877395`], {
             RGBColor[
             0.9635202536945403, 0.8886073912392349, 0.31278350353567824`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.032105813875877395`], {
             RGBColor[
             0.9820164622945995, 0.9861084875414284, 0.915325617864135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.032105813875877395`], {
             RGBColor[
             0.9604563565838657, 0.9700289960037962, 0.9518212530562512]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.032105813875877395`], {
             RGBColor[
             0.9157369051797231, 0.703631938589069, 0.25105813987980347`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.032105813875877395`], {
             RGBColor[
             0.9590015108291703, 0.9689439744220356, 0.9542839274344075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.032105813875877395`], {
             RGBColor[
             0.987854174923053, 0.989245403444285, 0.8509512841201157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.032105813875877395`], {
             RGBColor[
             0.9927741489058297, 0.98695296009221, 0.45488888506248304`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.032105813875877395`], {
             RGBColor[
             0.9938343919521555, 0.9892207127612855, 0.570289797593434]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.032105813875877395`], {
             RGBColor[
             0.9742285852322875, 0.9803003015798345, 0.9285084623269841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.032105813875877395`], {
             RGBColor[
             0.9931814167444729, 0.9878240648179731, 0.4992174759330471]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.032105813875877395`], {
             RGBColor[
             0.9944400008340147, 0.990516048923132, 0.636206586999023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.032105813875877395`], {
             RGBColor[
             0.8634854097693516, 0.8939838433357692, 0.9868412032979677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.032105813875877395`], {
             RGBColor[
             0.9683091169593964, 0.9758855718341519, 0.9385285780684014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.032105813875877395`], {
             RGBColor[
             0.9950127558314652, 0.9922056606170513, 0.7323150726541948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.032105813875877395`], {
             RGBColor[
             0.9850123985936596, 0.9880702559017605, 0.8980468721795566]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.032105813875877395`], {
             RGBColor[
             0.8258088124757379, 0.19938341894807032`, 0.1723478540146384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.032105813875877395`], {
             RGBColor[
             0.9789850918593285, 0.9407739216857445, 0.3728614795162432]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.032105813875877395`], {
             RGBColor[
             0.9932819478077817, 0.9914899270195209, 0.7609990407942114]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.032105813875877395`], {
             RGBColor[
             0.991038006747054, 0.9814312337610395, 0.4196847778530668]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.032105813875877395`], {
             RGBColor[
             0.9913308508336662, 0.990683098279819, 0.7933337669324151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.032105813875877395`], {
             RGBColor[
             0.945528388311731, 0.8217452417842318, 0.2750290665038027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.032105813875877395`], {
             RGBColor[
             0.984066578005001, 0.957914967644784, 0.3926020936340418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.032105813875877395`], {
             RGBColor[
             0.989270720181483, 0.9898311813121985, 0.8274754632863162]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.032105813875877395`], {
             RGBColor[
             0.9933144569172112, 0.9881086242950355, 0.5136980777068381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.032105813875877395`], {
             RGBColor[
             0.8795116369775376, 0.5457723089346893, 0.22117389526507253`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.032105813875877395`], {
             RGBColor[
             0.9493678086466156, 0.8369672640010674, 0.27811835422802916`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.032105813875877395`], {
             RGBColor[
             0.5365848079768778, 0.6346627458425812, 0.9566610681403076]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.032105813875877395`], {
             RGBColor[
             0.9181990624764786, 0.7133935718054234, 0.2530392494350327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.032105813875877395`], {
             RGBColor[
             0.8940100579724116, 0.9183233692433865, 0.9897526714932507]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.032105813875877395`], {
             RGBColor[
             0.9877498182957593, 0.9703394020114586, 0.4069107866420723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.032105813875877395`], {
             RGBColor[
             0.2526867065143148, 0.38292012818204746`, 0.937701506168283]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.032105813875877395`], {
             RGBColor[
             0.9618449495502663, 0.9710646063645254, 0.9494707273671836]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.032105813875877395`], {
             RGBColor[
             0.5663798464507115, 0.6588517003268265, 0.9590066427117899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.032105813875877395`], {
             RGBColor[
             0.9880627253487139, 0.9893316444047973, 0.8474950638557149]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.032105813875877395`], {
             RGBColor[
             0.9897613598981996, 0.9900340734439264, 0.8193442934454371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.032105813875877395`], {
             RGBColor[
             0.9607427522653912, 0.970242589434148, 0.9513364598713855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.032105813875877395`], {
             RGBColor[
             0.9932010264778748, 0.9914564639700211, 0.7623401166484566]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.032105813875877395`], {
             RGBColor[
             0.990545964703397, 0.9903585276942992, 0.8063413613311693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.032105813875877395`], {
             RGBColor[
             0.9930764200210116, 0.9875994874432865, 0.48778923054894974`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.032105813875877395`], {
             RGBColor[
             0.9787422547547999, 0.9399547751113061, 0.3719181032210891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.032105813875877395`], {
             RGBColor[
             0.8284581634632378, 0.21974749159099885`, 0.17488487551228213`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.032105813875877395`], {
             RGBColor[
             0.9943206653139558, 0.9902608023123977, 0.6232176520940607]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.032105813875877395`], {
             RGBColor[
             0.8420330709857372, 0.8768783306979389, 0.9847950600740577]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.032105813875877395`], {
             RGBColor[
             0.9749543829619653, 0.9808416003382434, 0.9272798760890049]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.032105813875877395`], {
             RGBColor[
             0.8430112077348887, 0.8776582703908975, 0.9848883556303847]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.032105813875877395`], {
             RGBColor[
             0.9888564132570619, 0.9896598547517481, 0.8343416012159233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.032105813875877395`], {
             RGBColor[
             0.994425612467265, 0.9904852736615414, 0.6346405020730199]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.032105813875877395`], {
             RGBColor[
             0.9863444935260909, 0.9886211113895991, 0.8759706117979938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.032105813875877395`], {
             RGBColor[
             0.8377746328968069, 0.8734827677580485, 0.9843888864475829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.032105813875877395`], {
             RGBColor[
             0.9924538741557608, 0.9911474972838882, 0.7747223641941132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.032105813875877395`], {
             RGBColor[
             0.6866648557694154, 0.7551470712640429, 0.9694039936413327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.032105813875877395`], {
             RGBColor[
             0.9591830801806088, 0.8739770865599747, 0.29593440344054733`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.032105813875877395`], {
             RGBColor[
             0.9218846914680962, 0.728005862594132, 0.2560047930345196]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.032105813875877395`], {
             RGBColor[
             0.994316391558113, 0.9902516611807931, 0.6227524801451472]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.032105813875877395`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.032105813875877395`], {
             RGBColor[
             0.8642202151572859, 0.894569757206347, 0.9869112896918374]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.032105813875877395`], {
             RGBColor[
             0.868009954191515, 0.8975915922425157, 0.9872727583840621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.032105813875877395`], {
             RGBColor[
             0.9505892540377119, 0.8418098879542159, 0.27910115786071343`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.032105813875877395`], {
             RGBColor[
             0.9516011191381799, 0.9634247744159243, 0.9668108602359796]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.032105813875877395`], {
             RGBColor[
             0.9937093245128539, 0.9889532061548771, 0.5566769786522161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.032105813875877395`], {
             RGBColor[
             0.8705014499669166, 0.5048591541021005, 0.21365557436351662`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.032105813875877395`], {
             RGBColor[
             0.9644797903164588, 0.9730296662937961, 0.9450106292265514]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.032105813875877395`], {
             RGBColor[
             0.9877480680992893, 0.9892015255458377, 0.8527097487855385]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.032105813875877395`], {
             RGBColor[
             0.993163294149753, 0.9914408606826661, 0.7629654389735708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.032105813875877395`], {
             RGBColor[
             0.9703197062831838, 0.9773850660597947, 0.9351251747889092]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.032105813875877395`], {
             RGBColor[
             0.9044250132127789, 0.6587840564046766, 0.24195632607896939`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.032105813875877395`], {
             RGBColor[
             0.995046200373089, 0.9918126484410367, 0.7021876657973474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.032105813875877395`], {
             RGBColor[
             0.38273530530233674`, 0.5059278174422703, 0.9456085331076912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.032105813875877395`], {
             RGBColor[
             0.8654576611393997, 0.8955564630429083, 0.9870293183942925]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.032105813875877395`], {
             RGBColor[
             0.9810173635527558, 0.9853633613356354, 0.9170168314273913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.032105813875877395`], {
             RGBColor[
             0.9918044874869609, 0.9908789592078632, 0.7854843818549541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.032105813875877395`], {
             RGBColor[
             0.6623142913675929, 0.7361242252821952, 0.9669769569507213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.032105813875877395`], {
             RGBColor[
             0.9595714240743407, 0.9693690147871364, 0.9533192129675141]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.032105813875877395`], {
             RGBColor[
             0.9927248265936988, 0.9868474646538127, 0.44952045576906047`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.032105813875877395`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.032105813875877395`], {
             RGBColor[
             0.9234602287665399, 0.7342523429657801, 0.25727250732746104`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.032105813875877395`], {
             RGBColor[
             0.9559274614040834, 0.8629741013097256, 0.2833964048115274]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.032105813875877395`], {
             RGBColor[
             0.984057054248472, 0.9876303576794638, 0.9118714279578479]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.032105813875877395`], {
             RGBColor[
             0.8474174843698543, 0.36547714010665033`, 0.19304034262394848`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.032105813875877395`], {
             RGBColor[
             0.9447997030439771, 0.9583522894291646, 0.9783238835900457]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.032105813875877395`], {
             RGBColor[
             0.8867307038894932, 0.5785524057259651, 0.22719766165193075`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.032105813875877395`], {
             RGBColor[
             0.9166681838236366, 0.7073241480819744, 0.25180746853661556`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.032105813875877395`], {
             RGBColor[
             0.9229490520968153, 0.9413985376301168, 0.9925128985869813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.032105813875877395`], {
             RGBColor[
             0.9948346274482802, 0.9913601153481748, 0.6791592586086587]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.032105813875877395`], {
             RGBColor[
             0.9671815560015979, 0.9009578236356035, 0.3270069716196722]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.032105813875877395`], {
             RGBColor[
             0.9709347616246319, 0.9778437733263861, 0.9340840465279621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.032105813875877395`], {
             RGBColor[
             0.9724402617572168, 0.9789665728602377, 0.9315356275008166]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.032105813875877395`], {
             RGBColor[
             0.8598671596296756, 0.4565713253822993, 0.20478206183581352`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.032105813875877395`], {
             RGBColor[
             0.9680428114168593, 0.9756869615965631, 0.9389793638883073]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.032105813875877395`], {
             RGBColor[
             0.911184725385199, 0.9320179828444155, 0.991390806603089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.032105813875877395`], {
             RGBColor[
             0.7552383578431991, 0.8087172122620013, 0.9762387594722364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.032105813875877395`], {
             RGBColor[
             0.9879121312842951, 0.9892693698890692, 0.8499907972280789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.032105813875877395`], {
             RGBColor[
             0.8403343942829156, 0.31103340586857225`, 0.18625756755748993`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.032105813875877395`], {
             RGBColor[
             0.9388095092925555, 0.9538848127373963, 0.9884637191184561]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.032105813875877395`], {
             RGBColor[
             0.9938893814958935, 0.9893383298350452, 0.5762750700731769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.032105813875877395`], {
             RGBColor[
             0.4379433617801932, 0.5537462611257891, 0.9491263416478927]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.032105813875877395`], {
             RGBColor[
             0.9878144630850785, 0.989228981578735, 0.8516094120462963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.032105813875877395`], {
             RGBColor[
             0.9393650376999667, 0.9542991249140494, 0.9875233544297223]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.032105813875877395`], {
             RGBColor[
             0.9887690873579059, 0.9896237432482738, 0.835788817357121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.032105813875877395`], {
             RGBColor[
             0.9950850813622847, 0.9922355690827266, 0.7311164514360415]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.032105813875877395`], {
             RGBColor[
             0.9935513202760071, 0.9916013194576888, 0.7565348418821152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.032105813875877395`], {
             RGBColor[
             0.995142424168111, 0.992018461408871, 0.7126610320610799]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.032105813875877395`], {
             RGBColor[
             0.5300988132070639, 0.6293971230977116, 0.9561504668730462]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.032105813875877395`], {
             RGBColor[
             0.9793734998922826, 0.9420841131834419, 0.37437037137956763`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.032105813875877395`], {
             RGBColor[
             0.9926912367384962, 0.9912456528117893, 0.7707886519235145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.032105813875877395`], {
             RGBColor[
             0.9387639691431051, 0.9538508489685015, 0.9885408067127023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.032105813875877395`], {
             RGBColor[
             0.9769526312190562, 0.9823318906165506, 0.9238973630163643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.032105813875877395`], {
             RGBColor[
             0.993618204652484, 0.9916289778662121, 0.7554263946726746]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.032105813875877395`], {
             RGBColor[
             0.9905192285423858, 0.9903474716046331, 0.8067844487100907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.032105813875877395`], {
             RGBColor[
             0.7421171216989402, 0.7984668028610181, 0.9749309572783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.032105813875877395`], {
             RGBColor[
             0.9887175546941731, 0.9736038041186205, 0.4106702598082257]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.032105813875877395`], {
             RGBColor[
             0.9815401814191591, 0.9857532780443633, 0.9161318371523086]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.032105813875877395`], {
             RGBColor[
             0.9938204318853203, 0.9891908535899043, 0.5687703304699648]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.032105813875877395`], {
             RGBColor[
             0.8832721145598563, 0.5628477593541447, 0.22431172993749957`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.032105813875877395`], {
             RGBColor[
             0.9884283010452336, 0.989482819350175, 0.8414365284848075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.032105813875877395`], {
             RGBColor[
             0.9820700563226886, 0.9511802312047605, 0.3848459839097418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.032105813875877395`], {
             RGBColor[
             0.9476557063164683, 0.8301793487863136, 0.27674075650498575`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.032105813875877395`], {
             RGBColor[
             0.9899703009211988, 0.9901204759264759, 0.8158815999723069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.032105813875877395`], {
             RGBColor[
             0.9313396115736794, 0.7654914701474178, 0.26361244368697084`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.032105813875877395`], {
             RGBColor[
             0.9932100336562629, 0.9878852734986782, 0.5023322501782769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.032105813875877395`], {
             RGBColor[
             0.9555062195723367, 0.9663371919257033, 0.9602005438142651]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.032105813875877395`], {
             RGBColor[
             0.9743004210467056, 0.9249714270217522, 0.35466241803505444`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.032105813875877395`], {
             RGBColor[
             0.9873137050138996, 0.9688682895074777, 0.40521656889513014`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.032105813875877395`], {
             RGBColor[
             0.944400669668272, 0.9580546909909209, 0.9789993430105421]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.032105813875877395`], {
             RGBColor[
             0.9676202735109596, 0.9024377208104502, 0.3287113062986922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.032105813875877395`], {
             RGBColor[
             0.7946261088199965, 0.8394872226830702, 0.9801645623901434]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.032105813875877395`], {
             RGBColor[
             0.9377430807615897, 0.9530894720851186, 0.9902689044522743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.032105813875877395`], {
             RGBColor[
             0.9194182298377258, 0.718227164129329, 0.2540202201114282]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.032105813875877395`], {
             RGBColor[
             0.983663753406576, 0.956556145686583, 0.39103719613620314`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.032105813875877395`], {
             RGBColor[
             0.43391314741327, 0.5502554920056241, 0.948869539952211]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.032105813875877395`], {
             RGBColor[
             0.9930162452641915, 0.9913800521895025, 0.7654024195576405]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.032105813875877395`], {
             RGBColor[
             0.9883789284951238, 0.989462402531888, 0.8422547594121913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.032105813875877395`], {
             RGBColor[
             0.9948800212764489, 0.9921507714674297, 0.7345148277368305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.032105813875877395`], {
             RGBColor[
             0.7662424803933658, 0.8173137164326205, 0.9773355475686651]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.032105813875877395`], {
             RGBColor[
             0.995142424168111, 0.992018461408871, 0.7126610320610799]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.032105813875877395`], {
             RGBColor[
             0.9893771479959044, 0.9898751919485318, 0.8257116789749976]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.032105813875877395`], {
             RGBColor[
             0.9708170142331272, 0.9777559575145955, 0.9342833621483414]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.032105813875877395`], {
             RGBColor[
             0.9841442795170753, 0.9876954101419699, 0.9117237783300962]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.032105813875877395`], {
             RGBColor[
             0.9941730189298282, 0.9899450016260881, 0.607147254349639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.032105813875877395`], {
             RGBColor[
             0.9404621780855071, 0.8016594064517335, 0.270952674836545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.032105813875877395`], {
             RGBColor[
             0.7946261088199965, 0.8394872226830702, 0.9801645623901434]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.032105813875877395`], {
             RGBColor[
             0.9717932773979421, 0.9784840529844302, 0.9326308032605226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.032105813875877395`], {
             RGBColor[
             0.6614869407863253, 0.7354778927200116, 0.9668944943768112]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.032105813875877395`], {
             RGBColor[
             0.9615927504997879, 0.9708765167256167, 0.9498976345755967]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.032105813875877395`], {
             RGBColor[
             0.9918361284993545, 0.9908920435796249, 0.7849600083952779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.032105813875877395`], {
             RGBColor[
             0.9948280811941248, 0.991346113572464, 0.6784467392426312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.032105813875877395`], {
             RGBColor[
             0.9850436666732398, 0.9880831860562199, 0.8975286791817167]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.032105813875877395`], {
             RGBColor[
             0.9517020568787659, 0.8462217803994306, 0.2799965451474653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.032105813875877395`], {
             RGBColor[
             0.9457263241529771, 0.9590433619350539, 0.976755355754]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.032105813875877395`], {
             RGBColor[
             0.9831145651045455, 0.9869274508191078, 0.9134668162379781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.032105813875877395`], {
             RGBColor[
             0.9951437819620697, 0.9920213655928543, 0.7128088195541336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.032105813875877395`], {
             RGBColor[
             0.8624733828797931, 0.8931768805647733, 0.9867446752697946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.032105813875877395`], {
             RGBColor[
             0.9733137207976899, 0.9216430553935864, 0.3508292738903356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.032105813875877395`], {
             RGBColor[
             0.9936791373230193, 0.988888638808214, 0.5533912893324597]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.032105813875877395`], {
             RGBColor[
             0.7684308552361521, 0.81902329149207, 0.9775536643214685]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.032105813875877395`], {
             RGBColor[
             0.9403645614115015, 0.9550445680615421, 0.985831421503629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.032105813875877395`], {
             RGBColor[
             0.9536123718630293, 0.9649247634049929, 0.9634063339915322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.032105813875877395`], {
             RGBColor[
             0.9849588846307277, 0.9609249274169192, 0.39606853637702283`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.032105813875877395`], {
             RGBColor[
             0.9906175454361588, 0.980012919030379, 0.41805136505769463`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.032105813875877395`], {
             RGBColor[
             0.4940900286344121, 0.6001635696043741, 0.9533157234469629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.032105813875877395`], {
             RGBColor[
             0.9845364342832047, 0.9594999031986658, 0.3944273965499505]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.032105813875877395`], {
             RGBColor[
             0.9173252858652635, 0.936914299090145, 0.9919764987434205]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.032105813875877395`], {
             RGBColor[
             0.9748630650786286, 0.9268693574565301, 0.35684818385266603`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.032105813875877395`], {
             RGBColor[
             0.9945126546192502, 0.9906714480233262, 0.6441145031547151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.032105813875877395`], {
             RGBColor[
             0.873150790036306, 0.5168891885881037, 0.21586624865868276`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.032105813875877395`], {
             RGBColor[
             0.898448157075017, 0.631758623960708, 0.236974991810992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.032105813875877395`], {
             RGBColor[
             0.8876637467433569, 0.5827891354076655, 0.2279762154801679]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.032105813875877395`], {
             RGBColor[
             0.9413309064572211, 0.8051036249590101, 0.2716516740761017]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.032105813875877395`], {
             RGBColor[
             0.9872224651740606, 0.9889841752288767, 0.8614203494733451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.032105813875877395`], {
             RGBColor[
             0.46409781087349233`, 0.5758145360920468, 0.9509546261997096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.032105813875877395`], {
             RGBColor[
             0.9701437595940023, 0.9772538453070895, 0.9354230066394473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.032105813875877395`], {
             RGBColor[
             0.7155108157898694, 0.7776817544694377, 0.9722790893553489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.032105813875877395`], {
             RGBColor[
             0.9933446038035629, 0.988173105436624, 0.5169793802412002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.032105813875877395`], {
             RGBColor[
             0.847687053935071, 0.367549169911043, 0.19329848274403533`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.032105813875877395`], {
             RGBColor[
             0.5375577071923501, 0.6354525892543118, 0.9567376583303968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.032105813875877395`], {
             RGBColor[
             0.956014265491007, 0.9667160917399988, 0.9593405545935535]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.032105813875877395`], {
             RGBColor[
             0.9930484424955105, 0.9875396463452013, 0.4847440495554223]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.032105813875877395`], {
             RGBColor[
             0.9792634566805859, 0.9840553004621301, 0.9199857382698001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.032105813875877395`], {
             RGBColor[
             0.8308011494662355, 0.8679223013606759, 0.9837237493726729]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.032105813875877395`], {
             RGBColor[
             0.9618844038412512, 0.8830892855682796, 0.30642853575997386`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.032105813875877395`], {
             RGBColor[
             0.9618449495502663, 0.9710646063645254, 0.9494707273671836]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.032105813875877395`], {
             RGBColor[
             0.9831573019368602, 0.986959323878673, 0.9133944739284202]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.032105813875877395`], {
             RGBColor[
             0.9873512682692915, 0.9890374386188432, 0.859285748853643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.032105813875877395`], {
             RGBColor[
             0.9947988870420619, 0.991283670233183, 0.6752691359560034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.032105813875877395`], {
             RGBColor[
             0.888450149577015, 0.9138900492085902, 0.9892223624671089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.032105813875877395`], {
             RGBColor[
             0.9394904047681475, 0.797806649072664, 0.270170763214946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.032105813875877395`], {
             RGBColor[
             0.981919075789717, 0.9860358568455428, 0.9154904678144327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.032105813875877395`], {
             RGBColor[
             0.9933144569172112, 0.9881086242950355, 0.5136980777068381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.032105813875877395`], {
             RGBColor[
             0.9248156227822222, 0.7396260285796793, 0.2583630891676656]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.032105813875877395`], {
             RGBColor[
             0.9933925020573667, 0.988275554958254, 0.5221928095739897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.032105813875877395`], {
             RGBColor[
             0.9569732182312707, 0.9674312771235465, 0.9577172977392182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.032105813875877395`], {
             RGBColor[
             0.8770917544890036, 0.5347841877321705, 0.21915468599989205`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.032105813875877395`], {
             RGBColor[
             0.9925448777322997, 0.9864625722349009, 0.42993413272141306`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.032105813875877395`], {
             RGBColor[
             0.9089989351733249, 0.9302750930611619, 0.9911823239814025]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.032105813875877395`], {
             RGBColor[
             0.6064260355917249, 0.691363000731763, 0.9621592254149949]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.032105813875877395`], {
             RGBColor[
             0.38273530530233674`, 0.5059278174422703, 0.9456085331076912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.032105813875877395`], {
             RGBColor[
             0.8507823466624439, 0.8838547656297833, 0.9856295737986726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.032105813875877395`], {
             RGBColor[
             0.9945815709457877, 0.9908188530772805, 0.6516156199960551]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.032105813875877395`], {
             RGBColor[
             0.9866903288523134, 0.9887641231845545, 0.8702392254493517]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.032105813875877395`], {
             RGBColor[
             0.9776482343706385, 0.9828506703080552, 0.9227198883230932]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.032105813875877395`], {
             RGBColor[
             0.898448157075017, 0.631758623960708, 0.236974991810992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.032105813875877395`], {
             RGBColor[
             0.8983864951460401, 0.9218130214504154, 0.990170099977763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.032105813875877395`], {
             RGBColor[
             0.956014265491007, 0.9667160917399988, 0.9593405545935535]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.032105813875877395`], {
             RGBColor[
             0.5875010930058864, 0.6759988797816315, 0.9606693846102887]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.032105813875877395`], {
             RGBColor[
             0.9631035452231693, 0.8872017357174987, 0.311164669813194]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.032105813875877395`], {
             RGBColor[
             0.9420575620100528, 0.9563072051359076, 0.9829656130955561]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.032105813875877395`], {
             RGBColor[
             0.98793969383928, 0.9892807677138808, 0.8495340143623734]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.032105813875877395`], {
             RGBColor[
             0.9251608709075241, 0.7409948223493834, 0.2586408839132985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.032105813875877395`], {
             RGBColor[
             0.9668099328599391, 0.8997042515175253, 0.3255632858894695]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.032105813875877395`], {
             RGBColor[
             0.9943978143417201, 0.9904258162818225, 0.6316148476576046]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.032105813875877395`], {
             RGBColor[
             0.9937399392595413, 0.9916793182546669, 0.7534089371946713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.032105813875877395`], {
             RGBColor[
             0.8844879125016105, 0.9107306689167229, 0.988844440757726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.032105813875877395`], {
             RGBColor[
             0.947597236398896, 0.9604386852247226, 0.9735883893337227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.032105813875877395`], {
             RGBColor[
             0.9048633305250109, 0.9269774741725939, 0.9907878663181484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.032105813875877395`], {
             RGBColor[
             0.8736962775206848, 0.5193661198528288, 0.21632141678677017`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.032105813875877395`], {
             RGBColor[
             0.9580745506797886, 0.870237756258604, 0.29162797565809195`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.032105813875877395`], {
             RGBColor[
             0.9723041967326372, 0.9182376936746414, 0.3469074635302294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.032105813875877395`], {
             RGBColor[
             0.9605680507484324, 0.9701122973288476, 0.9516321839701435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.032105813875877395`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.032105813875877395`], {
             RGBColor[
             0.8853432765849691, 0.9114127130185536, 0.9889260261475894]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.032105813875877395`], {
             RGBColor[
             0.9779340990562928, 0.9830638677225556, 0.9222359939757315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.032105813875877395`], {
             RGBColor[
             0.994757166868295, 0.9911944350000522, 0.6707281525085467]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.032105813875877395`], {
             RGBColor[
             0.9544198297833166, 0.9655269641998522, 0.9620395183512397]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.032105813875877395`], {
             RGBColor[
             0.9926340183645681, 0.9866532350338226, 0.4396365404316204]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.032105813875877395`], {
             RGBColor[
             0.9833858551891175, 0.9871297785199848, 0.9130075928885839]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.032105813875877395`], {
             RGBColor[
             0.9283082208948724, 0.7534730162570097, 0.2611733155909183]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.032105813875877395`], {
             RGBColor[
             0.9949321689735847, 0.99156874680784, 0.6897760516815329]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.032105813875877395`], {
             RGBColor[
             0.9711193541910853, 0.9779814421602044, 0.9337715794624083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.032105813875877395`], {
             RGBColor[
             0.9937514603859819, 0.9890433305269077, 0.561263208409735]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.032105813875877395`], {
             RGBColor[
             0.9536552380800619, 0.8539654930035175, 0.28156812058908337`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.032105813875877395`], {
             RGBColor[
             0.9508314774342986, 0.9628507768933422, 0.9681136628859456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.032105813875877395`], {
             RGBColor[
             0.8987077921752374, 0.6329375663114906, 0.23719163770285456`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.032105813875877395`], {
             RGBColor[
             0.9390159379963141, 0.9540387669266636, 0.9881142891682213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.032105813875877395`], {
             RGBColor[
             0.9048495336916573, 0.6604671386403663, 0.24229790522105138`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.032105813875877395`], {
             RGBColor[
             0.9409500066113313, 0.9554811921329968, 0.9848404154888798]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.032105813875877395`], {
             RGBColor[
             0.9936508158433104, 0.9888280620268576, 0.5503086710460616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.032105813875877395`], {
             RGBColor[
             0.8584023970541089, 0.8899307869713392, 0.9863563810075289]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.032105813875877395`], {
             RGBColor[
             0.8801069428378722, 0.9072374026251115, 0.988426579960261]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.032105813875877395`], {
             RGBColor[
             0.6377555463392692, 0.7167977089349947, 0.9646255992648208]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.032105813875877395`], {
             RGBColor[
             0.9736436575373378, 0.9798640634626722, 0.9294985923409581]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.032105813875877395`], {
             RGBColor[
             0.9846258508873744, 0.9598015264005472, 0.3947747631722408]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.032105813875877395`], {
             RGBColor[
             0.94790683895955, 0.9606695863075307, 0.9730643129558157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.032105813875877395`], {
             RGBColor[
             0.8976314949265458, 0.6280503518807912, 0.2362935488960866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.032105813875877395`], {
             RGBColor[
             0.3212359115125469, 0.4526601335909625, 0.9416898461171844]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.032105813875877395`], {
             RGBColor[
             0.9833858551891175, 0.9871297785199848, 0.9130075928885839]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.032105813875877395`], {
             RGBColor[
             0.9406975221900373, 0.955292889665001, 0.985267805755647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.032105813875877395`], {
             RGBColor[
             0.9645842779206555, 0.9731075929779232, 0.9448337589673781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.032105813875877395`], {
             RGBColor[
             0.9917188535071475, 0.9908435473565175, 0.7869035585140988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.032105813875877395`], {
             RGBColor[
             0.9161494969839884, 0.7052677276049129, 0.2513901209302898]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.032105813875877395`], {
             RGBColor[
             0.9554942996598426, 0.8612567593364054, 0.2830478727044984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.032105813875877395`], {
             RGBColor[
             0.964851972375774, 0.8930995910534524, 0.31795697913830023`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.032105813875877395`], {
             RGBColor[
             0.9945871223038139, 0.9908307268707698, 0.6522198510581825]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.032105813875877395`], {
             RGBColor[
             0.9646727723049314, 0.9731735919448199, 0.9446839610578309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.032105813875877395`], {
             RGBColor[
             0.959083297500455, 0.8736404961497284, 0.2955467665705276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.032105813875877395`], {
             RGBColor[
             0.9690454490791875, 0.976434727123459, 0.9372821598557691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.032105813875877395`], {
             RGBColor[
             0.9552283828963357, 0.9661299817876576, 0.9606708488353243]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.032105813875877395`], {
             RGBColor[
             0.9935697137773072, 0.9886545929083534, 0.5414812116655454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.032105813875877395`], {
             RGBColor[
             0.9871361191580154, 0.9889484689322505, 0.8628513264155415]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.032105813875877395`], {
             RGBColor[
             0.9705052201691957, 0.912169323306369, 0.3399187792894772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.032105813875877395`], {
             RGBColor[
             0.9932168983936224, 0.9914630274150723, 0.7620770779293186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.032105813875877395`], {
             RGBColor[
             0.9936973422073552, 0.9889275772150123, 0.5553727786448983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.032105813875877395`], {
             RGBColor[
             0.9476361286213913, 0.9604676909805795, 0.9735225549457542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.032105813875877395`], {
             RGBColor[
             0.99439705566937, 0.9904241935583789, 0.6315322708542667]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1FO4EAYYBuBzsm2dTrZdW7WsZbtVy3bLtWxr2bat5WVjyzZXrfc8u3i/
//a7+f7gJu2rtAsMCAjIJEJuKEIThrCEIzwRiEgkIhOFqEQjOjGISSxiE4e4
xCM+CUhIIhKThKQkI4jkBJOClKQiNWlISzrSk4GMIX3JTBayko3s5CAnuchN
HvKSj/wUoCCF+IEfKUwRivITxShOCUpSitKUoSzlKE8FfqYilahMFapSjerU
oCa1qE0d6lKP+jSgIY1oTBN+oSnNaM6vtKAlrWhNG9rSjvZ0oCOd6EwXutKN
7vSgJ73ozW/0oS/96M8ABjKIwQzhd4YyjOGMYCSjGM0YxjKO8UxgIpOYzBSm
Mo3pzGAms5jNH8xhLvOYzwIWsojFLGEpy1jOClayitWsYS3rWM8GNrKJzWxh
K9vYzg52sovd7GEv+9jPAQ5yiMMc4U+OcozjnOAkpzjNX5zhLOc4zwUuconL
XOEq17jODW5yi9v8zT/c4S73uM8DHvKIxzzhKc94zgte8orXvOEt73jPBz7y
ic/8yxe+8o3/CBl/IKEITRjCEo7wRCAikYhMFKISjejEICaxiE0c4hKP+CQg
IYlITBKSkowgkhNMClKSitSkIS3pSE8GMgb+/6++Az6VhWw=
          "], {Null, CompressedData["
1:eJxN2guYllWBB/D3qyhJJoMEhjQEkUhkrd1Es1FL08DywkWybEVNDSyNClNB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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[72, 227] -> 
             RGBColor[
              0.8705118000329004, 0.43480247052567644`, 0.21080209492961144`],
              UndirectedEdge[132, 236] -> 
             RGBColor[
              0.21416362323535532`, 0.3424299251513089, 0.9355076735653408], 
             UndirectedEdge[187, 193] -> 
             RGBColor[
              0.25215196023065367`, 0.38235807593304705`, 0.9376710531585147],
              UndirectedEdge[196, 225] -> 
             RGBColor[
              0.21532817540767707`, 0.3436539433212913, 0.935573993088754], 
             UndirectedEdge[39, 166] -> 
             RGBColor[
              0.19390930592620187`, 0.3211413534614994, 0.9343542201581618], 
             UndirectedEdge[7, 216] -> 
             RGBColor[
              0.8904157072945873, 0.6421896715609007, 0.4699552151052654], 
             UndirectedEdge[92, 281] -> 
             RGBColor[
              0.8805236512409333, 0.4901849175991575, 0.4256811132326063], 
             UndirectedEdge[99, 229] -> 
             RGBColor[
              0.20669327315473038`, 0.33457811356902034`, 0.9350822481796419],
              UndirectedEdge[187, 296] -> 
             RGBColor[
              0.20597365560918635`, 0.3338217499022659, 0.9350412670250019], 
             UndirectedEdge[100, 244] -> 
             RGBColor[
              0.18508330510196136`, 0.31186466699444937`, 0.9338515924681194],
              UndirectedEdge[232, 245] -> 
             RGBColor[
              0.206575126823306, 0.3344539342837832, 0.9350755199208491], 
             UndirectedEdge[6, 52] -> 
             RGBColor[
              0.20466403550360635`, 0.3324452561365908, 0.9349666860973984], 
             UndirectedEdge[113, 160] -> 
             RGBColor[
              0.23169850636271255`, 0.3608601990939647, 0.936506259218909], 
             UndirectedEdge[176, 288] -> 
             RGBColor[
              0.20152898742648828`, 0.32915012183401104`, 0.9347881497472945],
              UndirectedEdge[187, 228] -> 
             RGBColor[
              0.32549861800497937`, 0.4485853630705261, 0.9422458467242234], 
             UndirectedEdge[61, 268] -> 
             RGBColor[
              0.24115438507843467`, 0.37079892716152685`, 0.9370447575230503],
              UndirectedEdge[51, 101] -> 
             RGBColor[
              0.7293123816710212, 0.7884636426315792, 0.9736547004594159], 
             UndirectedEdge[207, 214] -> 
             RGBColor[
              0.19305906954872248`, 0.3202477011206687, 0.9343058004542764], 
             UndirectedEdge[17, 162] -> 
             RGBColor[
              0.8475057087773203, 0.8795582824939998, 0.8820715972741542], 
             UndirectedEdge[20, 279] -> 
             RGBColor[
              0.22783544818024304`, 0.35679988001215385`, 0.9362862637702997],
              UndirectedEdge[51, 197] -> 
             RGBColor[
              0.8988192263028636, 0.9205652040419037, 0.9289214218265444], 
             UndirectedEdge[86, 94] -> 
             RGBColor[
              0.6955329406462065, 0.7613368008112785, 0.9707925147289977], 
             UndirectedEdge[55, 114] -> 
             RGBColor[
              0.22063449464495144`, 0.3492312212797382, 0.9358761801193209], 
             UndirectedEdge[13, 270] -> 
             RGBColor[
              0.27306394266259, 0.4020687514269927, 0.9389450440967648], 
             UndirectedEdge[151, 220] -> 
             RGBColor[
              0.46545874896093703`, 0.5736549196510825, 0.9519637517959829], 
             UndirectedEdge[117, 225] -> 
             RGBColor[
              0.20655322702626136`, 0.33443091620856197`, 0.9350742727598051],
              UndirectedEdge[13, 277] -> 
             RGBColor[
              0.6631499633187324, 0.7252798242769541, 0.7115734484509257], 
             UndirectedEdge[81, 237] -> 
             RGBColor[
              0.8465380738337873, 0.3261495278745926, 0.19092293386380793`], 
             UndirectedEdge[172, 174] -> 
             RGBColor[
              0.21189442021644855`, 0.34004484890265657`, 0.9353784458103991],
              UndirectedEdge[128, 197] -> 
             RGBColor[
              0.8920740737202894, 0.5604973646047849, 0.4191176658739154], 
             UndirectedEdge[44, 71] -> 
             RGBColor[
              0.26976807981775686`, 0.40018277558695564`, 0.9386995645005083],
              UndirectedEdge[70, 122] -> 
             RGBColor[
              0.19740509453050553`, 0.32481564893042175`, 0.9345533001476212],
              UndirectedEdge[42, 293] -> 
             RGBColor[
              0.8583227451079464, 0.4059379610803489, 0.20178529360286196`], 
             UndirectedEdge[154, 181] -> 
             RGBColor[
              0.7417957890267707, 0.7840980478369171, 0.6774116520475943], 
             UndirectedEdge[42, 216] -> 
             RGBColor[
              0.847224395566658, 0.3555429478987492, 0.19252455870016974`], 
             UndirectedEdge[125, 130] -> 
             RGBColor[
              0.8607307087477495, 0.4103624865662075, 0.20352137280561344`], 
             UndirectedEdge[173, 263] -> 
             RGBColor[
              0.20558810816091344`, 0.33341651508901093`, 0.935019310668189], 
             UndirectedEdge[112, 132] -> 
             RGBColor[
              0.1930638232066118, 0.32025269751650964`, 0.9343060711680607], 
             UndirectedEdge[208, 279] -> 
             RGBColor[
              0.21299163292133522`, 0.34119808902279597`, 0.9354409304507616],
              UndirectedEdge[271, 295] -> 
             RGBColor[
              0.20977901412683497`, 0.3378214229779799, 0.9352579765630585], 
             UndirectedEdge[193, 264] -> 
             RGBColor[
              0.28788684943506876`, 0.4199177102097248, 0.939706102233675], 
             UndirectedEdge[16, 39] -> 
             RGBColor[
              0.22425729902189784`, 0.35303901837897317`, 0.9360824934691292],
              UndirectedEdge[168, 282] -> 
             RGBColor[
              0.42052178364044757`, 0.5386565657751188, 0.9480162540941248], 
             UndirectedEdge[92, 243] -> 
             RGBColor[
              0.8835089623946862, 0.49205410836049707`, 0.4046294016989433], 
             UndirectedEdge[71, 280] -> 
             RGBColor[
              0.2426648792276659, 0.37238655228322937`, 0.9371307779302732], 
             UndirectedEdge[69, 118] -> 
             RGBColor[
              0.19814492935345804`, 0.3255932622375819, 0.9345954326463008], 
             UndirectedEdge[175, 253] -> 
             RGBColor[
              0.18722926764301806`, 0.3141202096869836, 0.9339738018601655], 
             UndirectedEdge[137, 179] -> 
             RGBColor[
              0.3921454633437752, 0.5078279411583735, 0.9468889147894293], 
             UndirectedEdge[134, 221] -> 
             RGBColor[
              0.21549733286296777`, 0.343831738532004, 0.9355836263555868], 
             UndirectedEdge[91, 163] -> 
             RGBColor[
              0.5556545906660699, 0.6501444545135875, 0.9581623112885165], 
             UndirectedEdge[160, 232] -> 
             RGBColor[
              0.19183608079529113`, 0.31896226239884673`, 0.9342361530540182],
              UndirectedEdge[135, 263] -> 
             RGBColor[
              0.21148289076359805`, 0.33961230535523634`, 0.9353550098168626],
              UndirectedEdge[160, 297] -> 
             RGBColor[
              0.1938787777952211, 0.3211092664602433, 0.9343524816262648], 
             UndirectedEdge[179, 274] -> 
             RGBColor[
              0.4929016619374462, 0.5991987999844676, 0.9532221708674471], 
             UndirectedEdge[209, 259] -> 
             RGBColor[
              0.18280847530695815`, 0.30947367664736153`, 0.9337220442766032],
              UndirectedEdge[14, 173] -> 
             RGBColor[
              0.1907403974209291, 0.31781062970205387`, 0.9341737555067666], 
             UndirectedEdge[260, 267] -> 
             RGBColor[
              0.22718681650953165`, 0.35611812700061296`, 0.9362493251562173],
              UndirectedEdge[203, 216] -> 
             RGBColor[
              0.8900175091899872, 0.6418926960664795, 0.4706292606296545], 
             UndirectedEdge[37, 279] -> 
             RGBColor[
              0.23161750381713786`, 0.36077506028270767`, 0.936501646243771], 
             UndirectedEdge[192, 220] -> 
             RGBColor[
              0.3318533670341157, 0.4618564399149144, 0.9423663809943715], 
             UndirectedEdge[60, 225] -> 
             RGBColor[
              0.25743202099321577`, 0.38790775456968785`, 0.9379717448077927],
              UndirectedEdge[177, 226] -> 
             RGBColor[
              0.6391144281004404, 0.7063980774045702, 0.908678535889838], 
             UndirectedEdge[91, 273] -> 
             RGBColor[
              0.3645444727684772, 0.4827165664417553, 0.9449621664859775], 
             UndirectedEdge[52, 273] -> 
             RGBColor[
              0.2188316043007933, 0.34733626921817795`, 0.9357735081813584], 
             UndirectedEdge[21, 114] -> 
             RGBColor[
              0.21635493982133241`, 0.34473313782066695`, 0.9356324658031498],
              UndirectedEdge[7, 202] -> 
             RGBColor[
              0.890487052481644, 0.642513633392233, 0.47001474727817605`], 
             UndirectedEdge[94, 293] -> 
             RGBColor[
              0.8483237902546403, 0.739482330174071, 0.6092293420609014], 
             UndirectedEdge[132, 133] -> 
             RGBColor[
              0.19109281456444907`, 0.3181810424644308, 0.9341938251417357], 
             UndirectedEdge[13, 93] -> 
             RGBColor[
              0.2872094013725457, 0.41693652540503934`, 0.939750607043966], 
             UndirectedEdge[141, 178] -> 
             RGBColor[
              0.27642955220691934`, 0.4078753643883386, 0.9390536261060842], 
             UndirectedEdge[245, 264] -> 
             RGBColor[
              0.26072622472382, 0.3913701715551329, 0.938159344836913], 
             UndirectedEdge[5, 83] -> 
             RGBColor[
              0.8880392864849254, 0.5438464775091899, 0.242104808287807], 
             UndirectedEdge[210, 226] -> 
             RGBColor[
              0.7289680937933078, 0.7852771577024377, 0.9144848957128108], 
             UndirectedEdge[91, 298] -> 
             RGBColor[
              0.3751482927558811, 0.4938618535695355, 0.9455660383473143], 
             UndirectedEdge[126, 192] -> 
             RGBColor[
              0.2770528278061131, 0.40650831596386994`, 0.939163161568517], 
             UndirectedEdge[127, 156] -> 
             RGBColor[
              0.3716633849526351, 0.49633787652625627`, 0.9449030401335229], 
             UndirectedEdge[36, 268] -> 
             RGBColor[
              0.19319132437376368`, 0.32038670932722724`, 0.934313332170909], 
             UndirectedEdge[25, 221] -> 
             RGBColor[
              0.1886556188584439, 0.3156193952502866, 0.9340550304517865], 
             UndirectedEdge[69, 249] -> 
             RGBColor[
              0.20751277813074143`, 0.3354394652584245, 0.9351289177756767], 
             UndirectedEdge[22, 161] -> 
             RGBColor[
              0.1950980417525622, 0.32239079018520866`, 0.934421916904896], 
             UndirectedEdge[96, 112] -> 
             RGBColor[
              0.1950909003644823, 0.32238328413354655`, 0.9344215102134096], 
             UndirectedEdge[219, 250] -> 
             RGBColor[
              0.1834940050025886, 0.3101942118225623, 0.933761084178619], 
             UndirectedEdge[41, 219] -> 
             RGBColor[
              0.18646440411145038`, 0.3133162896201571, 0.933930244013557], 
             UndirectedEdge[202, 237] -> 
             RGBColor[
              0.8527387116152162, 0.3892539418421428, 0.19746540404923543`], 
             UndirectedEdge[91, 235] -> 
             RGBColor[
              0.44932632055040805`, 0.5626052939537676, 0.9501280434357534], 
             UndirectedEdge[69, 263] -> 
             RGBColor[
              0.2087290677202517, 0.3367178627342138, 0.9351981836684602], 
             UndirectedEdge[12, 239] -> 
             RGBColor[
              0.3335981101513706, 0.4567875043441526, 0.9427184858018454], 
             UndirectedEdge[122, 266] -> 
             RGBColor[
              0.19159505471631844`, 0.31870892870791034`, 0.9342224269753869],
              UndirectedEdge[206, 254] -> 
             RGBColor[
              0.27060222090313846`, 0.400822588016517, 0.9387557425033809], 
             UndirectedEdge[137, 270] -> 
             RGBColor[
              0.23718665422901314`, 0.36662859047011903`, 0.9368188011209075],
              UndirectedEdge[25, 58] -> 
             RGBColor[
              0.19112827338567, 0.31821831193375316`, 0.9341958444691476], 
             UndirectedEdge[107, 156] -> 
             RGBColor[
              0.4014834091317521, 0.5221664826722128, 0.9468031457054042], 
             UndirectedEdge[136, 194] -> 
             RGBColor[
              0.539310518839214, 0.6345587760249104, 0.957788184762517], 
             UndirectedEdge[45, 281] -> 
             RGBColor[
              0.6391981620742301, 0.7080190375817033, 0.9308676637061029], 
             UndirectedEdge[137, 147] -> 
             RGBColor[
              0.23746595794531072`, 0.3669221563848262, 0.9368347070543579], 
             UndirectedEdge[164, 187] -> 
             RGBColor[
              0.2033506574299822, 0.3310648125082323, 0.9348918911590742], 
             UndirectedEdge[199, 229] -> 
             RGBColor[
              0.20805355497894237`, 0.33600785601311617`, 0.9351597142171741],
              UndirectedEdge[191, 271] -> 
             RGBColor[
              0.22500596477055484`, 0.35382591354896176`, 0.9361251288759636],
              UndirectedEdge[153, 222] -> 
             RGBColor[
              0.2212473690290584, 0.3498753911159149, 0.9359110824088295], 
             UndirectedEdge[158, 186] -> 
             RGBColor[
              0.19303082310645578`, 0.3202180123189185, 0.9343041918611762], 
             UndirectedEdge[16, 192] -> 
             RGBColor[
              0.28870383608450384`, 0.4187542643810497, 0.9398266692538492], 
             UndirectedEdge[75, 143] -> 
             RGBColor[
              0.31991196504772945`, 0.4513422193006194, 0.941611753099148], 
             UndirectedEdge[204, 226] -> 
             RGBColor[
              0.734932739386402, 0.7901195256991334, 0.9149544544631159], 
             UndirectedEdge[137, 191] -> 
             RGBColor[
              0.24445543716588297`, 0.3742685422042259, 0.9372327475559615], 
             UndirectedEdge[197, 198] -> 
             RGBColor[
              0.9754663865596167, 0.9808663065126991, 0.9104194926535587], 
             UndirectedEdge[80, 156] -> 
             RGBColor[
              0.6866499660786538, 0.7281441949934098, 0.6592663633827371], 
             UndirectedEdge[103, 159] -> 
             RGBColor[
              0.35628521918114736`, 0.4813996069512451, 0.9439824173184419], 
             UndirectedEdge[28, 288] -> 
             RGBColor[
              0.19616769103516415`, 0.32351505940090497`, 0.9344828318491358],
              UndirectedEdge[118, 263] -> 
             RGBColor[
              0.19930513416780576`, 0.32681271105869525`, 0.9346615045941087],
              UndirectedEdge[68, 83] -> 
             RGBColor[
              0.8566539261889098, 0.5407679915618476, 0.4575135965364173], 
             UndirectedEdge[64, 90] -> 
             RGBColor[
              0.22549030939770529`, 0.3543349904613199, 0.936152711585956], 
             UndirectedEdge[213, 263] -> 
             RGBColor[
              0.2061321686296245, 0.3339883571370523, 0.9350502941070169], 
             UndirectedEdge[52, 53] -> 
             RGBColor[
              0.2073052253779457, 0.3352213141556316, 0.9351170979534518], 
             UndirectedEdge[245, 297] -> 
             RGBColor[
              0.20861782382323596`, 0.3366009383451798, 0.9351918484930957], 
             UndirectedEdge[189, 267] -> 
             RGBColor[
              0.20602096440657885`, 0.33387147444787646`, 0.9350439611910263],
              UndirectedEdge[145, 203] -> 
             RGBColor[
              0.9010144773435402, 0.923871728137574, 0.9891457475385399], 
             UndirectedEdge[136, 279] -> 
             RGBColor[
              0.3146411108912604, 0.44028382744269734`, 0.9415136410409652], 
             UndirectedEdge[80, 256] -> 
             RGBColor[
              0.8715548723467077, 0.4059318707085048, 0.23392588524752353`], 
             UndirectedEdge[40, 130] -> 
             RGBColor[
              0.8005184128051482, 0.7225949328330918, 0.608776500228449], 
             UndirectedEdge[83, 101] -> 
             RGBColor[
              0.7801443981327315, 0.4806917133441988, 0.4499691651133977], 
             UndirectedEdge[83, 194] -> 
             RGBColor[
              0.7930369047021925, 0.4907634374629408, 0.4512541696809177], 
             UndirectedEdge[149, 197] -> 
             RGBColor[
              0.9409227595816787, 0.803504489870005, 0.5552674312684278], 
             UndirectedEdge[23, 44] -> 
             RGBColor[
              0.6527829845870825, 0.7190887957178285, 0.883793610021852], 
             UndirectedEdge[97, 284] -> 
             RGBColor[
              0.3449079379891919, 0.4668961630433738, 0.9434276902262162], 
             UndirectedEdge[135, 276] -> 
             RGBColor[
              0.22722517815635135`, 0.3561584475236893, 0.9362515097952526], 
             UndirectedEdge[142, 150] -> 
             RGBColor[
              0.8557601994902863, 0.3776078411395296, 0.19898565697406115`], 
             UndirectedEdge[46, 214] -> 
             RGBColor[
              0.20276955741382008`, 0.3304540395473769, 0.9348587983728143], 
             UndirectedEdge[5, 243] -> 
             RGBColor[
              0.9792150980469998, 0.9514729807028455, 0.600039087887734], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.17910006852395627`, 0.30557590599185624`, 0.9335108559964074],
              UndirectedEdge[198, 243] -> 
             RGBColor[
              0.9760042846861029, 0.9810887412113525, 0.9015051286619535], 
             UndirectedEdge[13, 32] -> 
             RGBColor[
              0.6604824509868196, 0.7261357390166185, 0.898179624729629], 
             UndirectedEdge[86, 140] -> 
             RGBColor[
              0.7429383557535131, 0.3165575788102572, 0.4298769805861715], 
             UndirectedEdge[171, 275] -> 
             RGBColor[
              0.17966143058790973`, 0.3061659331134819, 0.9335428247354888], 
             UndirectedEdge[36, 250] -> 
             RGBColor[
              0.18199349180428678`, 0.3086170773131154, 0.9336756321717861], 
             UndirectedEdge[168, 203] -> 
             RGBColor[
              0.6687682561638781, 0.7369332784725033, 0.9690249189979729], 
             UndirectedEdge[17, 169] -> 
             RGBColor[
              0.654201051554568, 0.729209809683748, 0.9665623183284373], 
             UndirectedEdge[191, 246] -> 
             RGBColor[
              0.2059132617802264, 0.3337582721588391, 0.9350378276857872], 
             UndirectedEdge[17, 178] -> 
             RGBColor[
              0.4813372368134904, 0.5789969861106385, 0.9545799540531321], 
             UndirectedEdge[9, 132] -> 
             RGBColor[
              0.19792820821317225`, 0.32536547457822756`, 0.9345830906979717],
              UndirectedEdge[11, 283] -> 
             RGBColor[
              0.41881779248479195`, 0.534778825033336, 0.9485064845740085], 
             UndirectedEdge[64, 69] -> 
             RGBColor[
              0.22143670136219934`, 0.3500743914024093, 0.9359218646051097], 
             UndirectedEdge[193, 288] -> 
             RGBColor[
              0.24421454187002306`, 0.3740153459746332, 0.9372190289252349], 
             UndirectedEdge[221, 288] -> 
             RGBColor[
              0.19753047223834988`, 0.324947428850772, 0.9345604402226031], 
             UndirectedEdge[65, 264] -> 
             RGBColor[
              0.33683666992223255`, 0.4650136831097602, 0.942726350900722], 
             UndirectedEdge[27, 151] -> 
             RGBColor[
              0.7838347809145911, 0.7971566134890326, 0.6494113635450639], 
             UndirectedEdge[201, 293] -> 
             RGBColor[
              0.8634956504151338, 0.4456991780529511, 0.2067388735669856], 
             UndirectedEdge[43, 99] -> 
             RGBColor[
              0.21063039427602828`, 0.33871627749540134`, 0.9353064614030511],
              UndirectedEdge[77, 293] -> 
             RGBColor[0.6567707297143, 0.585264649646495, 0.5928277208084357],
              UndirectedEdge[61, 280] -> 
             RGBColor[
              0.2696360759953822, 0.40073499015874336`, 0.9386667476858847], 
             UndirectedEdge[20, 55] -> 
             RGBColor[
              0.21057054856025512`, 0.3386533758536862, 0.9353030532780715], 
             UndirectedEdge[208, 242] -> 
             RGBColor[
              0.18509931747274389`, 0.3118814970113848, 0.9338525043489474], 
             UndirectedEdge[29, 261] -> 
             RGBColor[
              0.21999581851421782`, 0.3485599321719316, 0.9358398084585123], 
             UndirectedEdge[12, 76] -> 
             RGBColor[
              0.3782689418854923, 0.5020592779365523, 0.9453239403802199], 
             UndirectedEdge[168, 276] -> 
             RGBColor[
              0.3208926338924916, 0.4461337879304579, 0.9418960475542608], 
             UndirectedEdge[148, 271] -> 
             RGBColor[
              0.23446623518977533`, 0.3637692575753508, 0.9366638772811222], 
             UndirectedEdge[131, 170] -> 
             RGBColor[
              0.21349214626363155`, 0.34172416027992825`, 0.9354694339451624],
              UndirectedEdge[141, 261] -> 
             RGBColor[
              0.269292107733182, 0.4003734577063236, 0.9386471592022079], 
             UndirectedEdge[129, 184] -> 
             RGBColor[
              0.19028873719925032`, 0.31733590617215746`, 0.9341480341253134],
              UndirectedEdge[111, 185] -> 
             RGBColor[
              0.5718800780485805, 0.6633170361205862, 0.9594396410911864], 
             UndirectedEdge[234, 239] -> 
             RGBColor[
              0.2158656276199601, 0.3442188396728392, 0.9356046001971543], 
             UndirectedEdge[103, 203] -> 
             RGBColor[
              0.679227364936692, 0.7459924328014227, 0.96969136416035], 
             UndirectedEdge[28, 160] -> 
             RGBColor[
              0.18961722538074013`, 0.31663010467459485`, 0.9341097925206621],
              UndirectedEdge[133, 170] -> 
             RGBColor[
              0.1914328920115927, 0.3185384854235343, 0.9342131920492509], 
             UndirectedEdge[87, 299] -> 
             RGBColor[
              0.8768452825301113, 0.42571428195008987`, 0.27555164113063385`],
              UndirectedEdge[5, 290] -> 
             RGBColor[
              0.9587118125308915, 0.8695626925266455, 0.3088146906826389], 
             UndirectedEdge[183, 253] -> 
             RGBColor[
              0.19229512745236005`, 0.31944474954066526`, 0.9342622950820396],
              UndirectedEdge[176, 245] -> 
             RGBColor[
              0.20971756780007914`, 0.3377568389926374, 0.9352544772856515], 
             UndirectedEdge[29, 190] -> 
             RGBColor[
              0.199834842245044, 0.32736946783330456`, 0.9346916706854744], 
             UndirectedEdge[159, 168] -> 
             RGBColor[
              0.3458261104083336, 0.4723404526223259, 0.943315972156065], 
             UndirectedEdge[202, 299] -> 
             RGBColor[
              0.8506117900174305, 0.3729054904185747, 0.19542866152518146`], 
             UndirectedEdge[65, 115] -> 
             RGBColor[
              0.3645960621661024, 0.4902165167425332, 0.9444527165749532], 
             UndirectedEdge[51, 142] -> 
             RGBColor[
              0.8237226416206042, 0.438239252848624, 0.4448084869772376], 
             UndirectedEdge[134, 187] -> 
             RGBColor[
              0.23476961577043198`, 0.36408812980106076`, 0.9366811543563793],
              UndirectedEdge[85, 239] -> 
             RGBColor[
              0.2348622905163943, 0.36418553683498534`, 0.936686432046062], 
             UndirectedEdge[120, 284] -> 
             RGBColor[
              0.26002401193692654`, 0.39063210139324567`, 0.9381193548575302],
              UndirectedEdge[31, 61] -> 
             RGBColor[
              0.3484538930002764, 0.47332381494877457`, 0.9435307438846312], 
             UndirectedEdge[217, 247] -> 
             RGBColor[
              0.19889732977739935`, 0.3263840827880864, 0.9346382807373675], 
             UndirectedEdge[66, 169] -> 
             RGBColor[
              0.4955403552880472, 0.5995224478502696, 0.9539323726469158], 
             UndirectedEdge[168, 293] -> 
             RGBColor[
              0.650085093471142, 0.5794738875625195, 0.5924017179788976], 
             UndirectedEdge[93, 105] -> 
             RGBColor[
              0.26248514686677915`, 0.39321891024948796`, 0.9382595128508624],
              UndirectedEdge[169, 193] -> 
             RGBColor[
              0.44215135474031986`, 0.5505814803014513, 0.9506292633518225], 
             UndirectedEdge[87, 216] -> 
             RGBColor[
              0.9086918285764461, 0.6536007359987195, 0.30538616585458284`], 
             UndirectedEdge[81, 201] -> 
             RGBColor[
              0.8600643597048547, 0.4301184883358802, 0.203875720489697], 
             UndirectedEdge[63, 244] -> 
             RGBColor[
              0.18619322197801913`, 0.31303126000398057`, 0.9339148005922362],
              UndirectedEdge[32, 150] -> 
             RGBColor[
              0.9475427884309859, 0.8298940012964792, 0.5491295264859543], 
             UndirectedEdge[95, 282] -> 
             RGBColor[
              0.36409426757402563`, 0.48782276310977274`, 0.9444924758077534],
              UndirectedEdge[126, 239] -> 
             RGBColor[
              0.2305322261132995, 0.35963436460539283`, 0.9364398412840619], 
             UndirectedEdge[149, 150] -> 
             RGBColor[
              0.901456610665, 0.644502615181237, 0.23943789960535378`], 
             UndirectedEdge[16, 222] -> 
             RGBColor[
              0.23410797445122994`, 0.3633927028240968, 0.9366434748620613], 
             UndirectedEdge[192, 262] -> 
             RGBColor[
              0.31722856394081744`, 0.4487355619302395, 0.9414511103067129], 
             UndirectedEdge[214, 276] -> 
             RGBColor[
              0.22110211631188992`, 0.34972272130061666`, 0.9359028104814688],
              UndirectedEdge[48, 100] -> 
             RGBColor[
              0.18673636136840888`, 0.31360213394030656`, 0.9339457315770161],
              UndirectedEdge[105, 143] -> 
             RGBColor[
              0.29536739445361543`, 0.4277802373181654, 0.9401321082060067], 
             UndirectedEdge[268, 279] -> 
             RGBColor[
              0.22085812887375872`, 0.34946627503344374`, 0.9358889157578143],
              UndirectedEdge[24, 106] -> 
             RGBColor[
              0.892812310133672, 0.8140725087445938, 0.6221015838690171], 
             UndirectedEdge[33, 222] -> 
             RGBColor[
              0.210965999406103, 0.33906901976570414`, 0.9353255736187255], 
             UndirectedEdge[155, 291] -> 
             RGBColor[
              0.9265943306289632, 0.845047396157727, 0.6262279650717502], 
             UndirectedEdge[99, 233] -> 
             RGBColor[
              0.20053490529032286`, 0.32810527848045334`, 0.9347315382402527],
              UndirectedEdge[237, 269] -> 
             RGBColor[
              0.8744380750181129, 0.4362072994771681, 0.23118026314495393`], 
             UndirectedEdge[85, 135] -> 
             RGBColor[
              0.22261249954375167`, 0.3513102298411313, 0.9359888245721116], 
             UndirectedEdge[126, 248] -> 
             RGBColor[
              0.22272354417989754`, 0.3514269447943572, 0.9359951483998643], 
             UndirectedEdge[188, 261] -> 
             RGBColor[
              0.30030042916823396`, 0.42860875023970424`, 0.9405725470875715],
              UndirectedEdge[37, 177] -> 
             RGBColor[
              0.2592700003340752, 0.38983958739155206`, 0.9380764150122078], 
             UndirectedEdge[160, 180] -> 
             RGBColor[
              0.19532450559808373`, 0.32262881804548893`, 0.9344348136858753],
              UndirectedEdge[23, 194] -> 
             RGBColor[
              0.8376760987270953, 0.8722472965038359, 0.8977776532625734], 
             UndirectedEdge[51, 243] -> 
             RGBColor[
              0.8993571244293498, 0.920787638740557, 0.9200070578349391], 
             UndirectedEdge[108, 208] -> 
             RGBColor[
              0.2150010029643497, 0.34331006433942324`, 0.9355553611021148], 
             UndirectedEdge[179, 251] -> 
             RGBColor[
              0.4041820274938994, 0.5204791332423994, 0.9475743793112779], 
             UndirectedEdge[26, 224] -> 
             RGBColor[
              0.21888166411978893`, 0.3473888852619182, 0.9357763590139934], 
             UndirectedEdge[106, 291] -> 
             RGBColor[
              0.8943677152627585, 0.9186085554583606, 0.9897867851648885], 
             UndirectedEdge[48, 161] -> 
             RGBColor[
              0.19723226696141938`, 0.3246339961974114, 0.9345434578732372], 
             UndirectedEdge[227, 299] -> 
             RGBColor[
              0.8633640950075484, 0.3798620775565069, 0.20395744452515618`], 
             UndirectedEdge[162, 299] -> 
             RGBColor[
              0.8762453581797867, 0.42669348450426003`, 0.3747047266637896], 
             UndirectedEdge[200, 227] -> 
             RGBColor[
              0.6591374011618665, 0.6706282245294286, 0.6126589597072597], 
             UndirectedEdge[202, 293] -> 
             RGBColor[
              0.8776334125818863, 0.5372437306244892, 0.2196066587898482], 
             UndirectedEdge[3, 155] -> 
             RGBColor[
              0.9402661035019293, 0.855471333191099, 0.6109745630706932], 
             UndirectedEdge[39, 234] -> 
             RGBColor[
              0.19793969225016772`, 0.3253775450292399, 0.9345837446968894], 
             UndirectedEdge[144, 176] -> 
             RGBColor[
              0.19591627409858087`, 0.32325080425980146`, 0.9344685140265354],
              UndirectedEdge[140, 162] -> 
             RGBColor[
              0.8753287589904273, 0.41964810147851817`, 0.3738269902449083], 
             UndirectedEdge[123, 257] -> 
             RGBColor[
              0.19133948148967972`, 0.3184403050424346, 0.9342078724582165], 
             UndirectedEdge[121, 286] -> 
             RGBColor[
              0.22317009351070355`, 0.3518962964538972, 0.9360205787236432], 
             UndirectedEdge[176, 230] -> 
             RGBColor[
              0.19313907822011844`, 0.32033179530714856`, 0.9343103568297502],
              UndirectedEdge[39, 64] -> 
             RGBColor[
              0.2185143800083959, 0.3470028463736865, 0.9357554427271977], 
             UndirectedEdge[269, 277] -> 
             RGBColor[
              0.9830880426173179, 0.9543005010685027, 0.41547009014484526`], 
             UndirectedEdge[154, 203] -> 
             RGBColor[
              0.7172113529376909, 0.7776981044453534, 0.9724416173890855], 
             UndirectedEdge[107, 137] -> 
             RGBColor[
              0.33500472849332374`, 0.4602209338581902, 0.9427270090780024], 
             UndirectedEdge[192, 218] -> 
             RGBColor[
              0.6489034320102649, 0.7179182155893853, 0.9413556495465901], 
             UndirectedEdge[247, 270] -> 
             RGBColor[
              0.20529778048290723`, 0.33311136229158844`, 0.935002776936428], 
             UndirectedEdge[28, 240] -> 
             RGBColor[
              0.18200025991928498`, 0.3086241910311017, 0.9336760176059227], 
             UndirectedEdge[31, 194] -> 
             RGBColor[
              0.552827044743554, 0.6462661114029045, 0.958649445840947], 
             UndirectedEdge[58, 187] -> 
             RGBColor[
              0.20794054512620663`, 0.3358890754926524, 0.9351532784732439], 
             UndirectedEdge[8, 121] -> 
             RGBColor[
              0.21495883648631775`, 0.3432657446975026, 0.9355529597835706], 
             UndirectedEdge[62, 186] -> 
             RGBColor[
              0.19739650616034748`, 0.3248066220088515, 0.934552811052646], 
             UndirectedEdge[271, 289] -> 
             RGBColor[
              0.23303990394891333`, 0.36227009300658086`, 0.9365826498270231],
              UndirectedEdge[236, 294] -> 
             RGBColor[
              0.38374017735760657`, 0.49740352912178454`, 0.9465549709165739],
              UndirectedEdge[115, 211] -> 
             RGBColor[
              0.3112307319414529, 0.4404795631489132, 0.9411810111605179], 
             UndirectedEdge[43, 284] -> 
             RGBColor[
              0.23327215251581435`, 0.3625142009758035, 0.9365958760393271], 
             UndirectedEdge[87, 181] -> 
             RGBColor[
              0.9897210070316473, 0.9765905802662477, 0.448420390956374], 
             UndirectedEdge[77, 205] -> 
             RGBColor[
              0.3930712028278346, 0.5148802523815419, 0.9462671273583405], 
             UndirectedEdge[132, 267] -> 
             RGBColor[
              0.19655119281637518`, 0.32391814408837505`, 0.9345046717082358],
              UndirectedEdge[108, 280] -> 
             RGBColor[
              0.2513491898337207, 0.3815143133472875, 0.9376253365720018], 
             UndirectedEdge[40, 97] -> 
             RGBColor[
              0.5690459020341019, 0.6601769695084484, 0.9597409246828227], 
             UndirectedEdge[35, 262] -> 
             RGBColor[
              0.25511664496274467`, 0.3854741475583434, 0.9378398875681493], 
             UndirectedEdge[201, 216] -> 
             RGBColor[
              0.8523973008738454, 0.3953041648713514, 0.19747813866429334`], 
             UndirectedEdge[244, 279] -> 
             RGBColor[
              0.21308524932289044`, 0.3412964857964532, 0.9354462617663373], 
             UndirectedEdge[143, 163] -> 
             RGBColor[
              0.4640224729127619, 0.5716064552084593, 0.95205347173178], 
             UndirectedEdge[102, 165] -> 
             RGBColor[
              0.20499479718794766`, 0.3327929076383356, 0.9349855224860035], 
             UndirectedEdge[7, 282] -> 
             RGBColor[
              0.6894759164963487, 0.7547973275205713, 0.9692952652700408], 
             UndirectedEdge[10, 122] -> 
             RGBColor[
              0.1877216481680741, 0.3146377328375459, 0.9340018422026558], 
             UndirectedEdge[113, 193] -> 
             RGBColor[
              0.2735981771019762, 0.40489940963349313`, 0.9388923834825018], 
             UndirectedEdge[22, 100] -> 
             RGBColor[
              0.1846021361595517, 0.3113589279281038, 0.9338241906086748], 
             UndirectedEdge[116, 254] -> 
             RGBColor[
              0.30306682721859113`, 0.43494494762898417`, 0.9406045538059649],
              UndirectedEdge[174, 298] -> 
             RGBColor[
              0.24667128016472487`, 0.3765975336885693, 0.9373589365366997], 
             UndirectedEdge[159, 271] -> 
             RGBColor[
              0.2569380089981777, 0.38738851664073326`, 0.9379436115555007], 
             UndirectedEdge[11, 101] -> 
             RGBColor[
              0.589571415450858, 0.6776035417182125, 0.9608844110153827], 
             UndirectedEdge[148, 225] -> 
             RGBColor[
              0.23694694145511846`, 0.36637663714608804`, 0.9368051498330575],
              UndirectedEdge[239, 248] -> 
             RGBColor[
              0.22976740900447992`, 0.35883049333181793`, 0.9363962860811601],
              UndirectedEdge[22, 119] -> 
             RGBColor[
              0.18469650892406414`, 0.31145811968718523`, 0.933829564998002], 
             UndirectedEdge[38, 247] -> 
             RGBColor[
              0.19193794866685385`, 0.31906933199065524`, 0.9342419542786038],
              UndirectedEdge[157, 222] -> 
             RGBColor[
              0.20198183109515816`, 0.32962608924173, 0.9348139385243031], 
             UndirectedEdge[42, 203] -> 
             RGBColor[
              0.8707781869031039, 0.5109108883536715, 0.45286742761557874`], 
             UndirectedEdge[155, 241] -> 
             RGBColor[
              0.9562190222247212, 0.8670479840915544, 0.569594959834627], 
             UndirectedEdge[103, 154] -> 
             RGBColor[
              0.45931362601150366`, 0.5710619602704519, 0.9508179830889629], 
             UndirectedEdge[88, 107] -> 
             RGBColor[
              0.3156668760979841, 0.43989562490003076`, 0.9416257469918767], 
             UndirectedEdge[58, 176] -> 
             RGBColor[
              0.19266677740688082`, 0.31983537720683475`, 0.9342834599971428],
              UndirectedEdge[48, 119] -> 
             RGBColor[
              0.1868307341329213, 0.31370132569938797`, 0.933951105966343], 
             UndirectedEdge[206, 219] -> 
             RGBColor[
              0.20337837440800324`, 0.33109394480949034`, 0.9348934695999689],
              UndirectedEdge[1, 125] -> 
             RGBColor[
              0.8241937608739676, 0.18696942461673885`, 0.17080127877684323`],
              UndirectedEdge[191, 278] -> 
             RGBColor[
              0.21400334724237668`, 0.34226146492060344`, 0.9354985460846478],
              UndirectedEdge[90, 118] -> 
             RGBColor[
              0.20219853738896398`, 0.32985386129649247`, 0.9348262796271471],
              UndirectedEdge[101, 283] -> 
             RGBColor[
              0.4765743997943146, 0.5815921216615045, 0.9531053393092228], 
             UndirectedEdge[5, 226] -> 
             RGBColor[
              0.978634912205556, 0.9512330589473125, 0.6096542687532867], 
             UndirectedEdge[3, 241] -> 
             RGBColor[
              0.9701712881509421, 0.9769533662972854, 0.9210009349471945], 
             UndirectedEdge[194, 241] -> 
             RGBColor[
              0.8360648746712487, 0.8715810139501738, 0.9244798055821426], 
             UndirectedEdge[139, 235] -> 
             RGBColor[
              0.42460849977243, 0.5421962738843169, 0.9482766560323135], 
             UndirectedEdge[40, 94] -> 
             RGBColor[
              0.7430612286953848, 0.7992043464221197, 0.9750250570405241], 
             UndirectedEdge[161, 177] -> 
             RGBColor[
              0.24681318446187503`, 0.3767466841021262, 0.9373670177764938], 
             UndirectedEdge[34, 295] -> 
             RGBColor[
              0.19030787854135572`, 0.3173560249363414, 0.9341491241964293], 
             UndirectedEdge[1, 281] -> 
             RGBColor[
              0.8719494618139193, 0.4242799404293628, 0.41747045975413577`], 
             UndirectedEdge[191, 295] -> 
             RGBColor[
              0.21214976125282442`, 0.34031322852144436`, 0.9353929871046776],
              UndirectedEdge[144, 297] -> 
             RGBColor[
              0.19481653012173772`, 0.32209490361234383`, 0.9344058852339796],
              UndirectedEdge[141, 294] -> 
             RGBColor[
              0.41494859536709305`, 0.5302055551777425, 0.9483322441534972], 
             UndirectedEdge[80, 201] -> 
             RGBColor[
              0.8898455310710746, 0.5465218886817487, 0.2514410406983216], 
             UndirectedEdge[113, 115] -> 
             RGBColor[
              0.3096806718260522, 0.43885035168813935`, 0.9410927375300542], 
             UndirectedEdge[129, 253] -> 
             RGBColor[
              0.19046881652676248`, 0.3175251809630616, 0.9341582893766117], 
             UndirectedEdge[37, 108] -> 
             RGBColor[
              0.23362687386015235`, 0.362887035599335, 0.936616076895124], 
             UndirectedEdge[265, 276] -> 
             RGBColor[
              0.23204484364859856`, 0.36122422154048306`, 0.93652598261498], 
             UndirectedEdge[59, 194] -> 
             RGBColor[
              0.8355066141794747, 0.8713501588901851, 0.9337316266626792], 
             UndirectedEdge[103, 225] -> 
             RGBColor[
              0.3244631340928782, 0.4479525778867464, 0.9421701966492211], 
             UndirectedEdge[46, 265] -> 
             RGBColor[
              0.21371228475052867`, 0.3419555397872433, 0.9354819705063254], 
             UndirectedEdge[51, 149] -> 
             RGBColor[
              0.8534002738604769, 0.7354497327448786, 0.6081721446101185], 
             UndirectedEdge[52, 124] -> 
             RGBColor[
              0.1923287617954415, 0.3194801013677844, 0.9342642105081206], 
             UndirectedEdge[82, 258] -> 
             RGBColor[
              0.47680058453134755`, 0.5830547562597531, 0.9528035659599465], 
             UndirectedEdge[45, 132] -> 
             RGBColor[
              0.24841553022607393`, 0.3784308510948885, 0.9374582689973068], 
             UndirectedEdge[74, 287] -> 
             RGBColor[
              0.2244511741859948, 0.35324279346883447`, 0.936093534372912], 
             UndirectedEdge[128, 269] -> 
             RGBColor[
              0.8876818023454497, 0.5380043911533983, 0.24386247139026226`], 
             UndirectedEdge[14, 249] -> 
             RGBColor[
              0.19382527220510481`, 0.3210530286925808, 0.9343494345620621], 
             UndirectedEdge[101, 198] -> 
             RGBColor[
              0.8059595419277743, 0.8487647451023745, 0.9551527712864303], 
             UndirectedEdge[164, 297] -> 
             RGBColor[
              0.18697714573381324`, 0.31385521357495705`, 0.9339594438904173],
              UndirectedEdge[68, 235] -> 
             RGBColor[
              0.6426752269533634, 0.7164421222894727, 0.967683202312762], 
             UndirectedEdge[108, 177] -> 
             RGBColor[
              0.2663285931328081, 0.3972586159636525, 0.9384783914298436], 
             UndirectedEdge[62, 276] -> 
             RGBColor[
              0.22152543341226616`, 0.3501676544129665, 0.9359269177640938], 
             UndirectedEdge[13, 107] -> 
             RGBColor[
              0.3708820169269006, 0.49566109481506393`, 0.9448532520538597], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.21391225518849333`, 0.3421657213964022, 0.9354933585269378], 
             UndirectedEdge[62, 135] -> 
             RGBColor[
              0.20737676424851148`, 0.33529650604442257`, 0.9351211719862982],
              UndirectedEdge[18, 35] -> 
             RGBColor[
              0.20318410319091706`, 0.3308897534428262, 0.9348824061415544], 
             UndirectedEdge[42, 202] -> 
             RGBColor[
              0.8472600681601863, 0.3557049288144153, 0.19255432478662504`], 
             UndirectedEdge[121, 255] -> 
             RGBColor[
              0.295733658786952, 0.42287002848225363`, 0.9403468487457121], 
             UndirectedEdge[128, 281] -> 
             RGBColor[
              0.8894473613175273, 0.5587764636425476, 0.4342264680798416], 
             UndirectedEdge[82, 181] -> 
             RGBColor[
              0.7998668067519439, 0.8312427160957487, 0.681983215284067], 
             UndirectedEdge[136, 204] -> 
             RGBColor[
              0.4381119186941594, 0.553069802846105, 0.9493643283826801], 
             UndirectedEdge[118, 166] -> 
             RGBColor[
              0.18740769372755933`, 0.31430774681470364`, 0.9339839629617225],
              UndirectedEdge[39, 263] -> 
             RGBColor[
              0.2058067463664483, 0.333646317705491, 0.935031761790548], 
             UndirectedEdge[52, 84] -> 
             RGBColor[
              0.1931004885069918, 0.32029123507192336`, 0.9343081592026761], 
             UndirectedEdge[129, 165] -> 
             RGBColor[
              0.20344097121398075`, 0.33115973802143944`, 0.9348970343954657],
              UndirectedEdge[141, 236] -> 
             RGBColor[
              0.2626393533607303, 0.39338099105188706`, 0.9382682946825648], 
             UndirectedEdge[97, 178] -> 
             RGBColor[
              0.353934746876465, 0.4763839115166376, 0.9439417536383794], 
             UndirectedEdge[115, 227] -> 
             RGBColor[
              0.6522166119287909, 0.6646337847447196, 0.6122179731371418], 
             UndirectedEdge[256, 281] -> 
             RGBColor[
              0.8714392611368911, 0.42035831445436117`, 0.41698189100962424`],
              UndirectedEdge[221, 297] -> 
             RGBColor[
              0.18909437890281156`, 0.31608055987591055`, 0.9340800171872259],
              UndirectedEdge[224, 262] -> 
             RGBColor[
              0.2562537795699573, 0.3866693481290222, 0.9379046457017901], 
             UndirectedEdge[73, 119] -> 
             RGBColor[
              0.18176019735719462`, 0.3083718700574992, 0.9336623463981524], 
             UndirectedEdge[3, 227] -> 
             RGBColor[
              0.9534614284413586, 0.9077863994945625, 0.6215918312510428], 
             UndirectedEdge[45, 188] -> 
             RGBColor[
              0.32789958178650086`, 0.45761720952884744`, 0.9421442779998944],
              UndirectedEdge[260, 300] -> 
             RGBColor[
              0.24190674150061214`, 0.37158970146338766`, 0.9370876031082818],
              UndirectedEdge[23, 291] -> 
             RGBColor[
              0.9581107393338224, 0.9671957118175754, 0.9095521846286824], 
             UndirectedEdge[142, 149] -> 
             RGBColor[
              0.8517916638064809, 0.3601987767340248, 0.1957058266051599], 
             UndirectedEdge[81, 97] -> 
             RGBColor[
              0.6691615275279388, 0.5770839186847934, 0.5896504800872672], 
             UndirectedEdge[181, 201] -> 
             RGBColor[
              0.8923407162696778, 0.5549387342539829, 0.2611343640187083], 
             UndirectedEdge[56, 57] -> 
             RGBColor[
              0.18951617750640207`, 0.3165238969518603, 0.9341040379937053], 
             UndirectedEdge[197, 243] -> 
             RGBColor[
              0.9868796101505515, 0.9888423958656835, 0.8671023444932484], 
             UndirectedEdge[65, 200] -> 
             RGBColor[
              0.37151685139917806`, 0.49621095652724223`, 0.9448937031450712],
              UndirectedEdge[8, 173] -> 
             RGBColor[
              0.2028775855537629, 0.3305675839718365, 0.9348649504155706], 
             UndirectedEdge[53, 273] -> 
             RGBColor[
              0.2274037724911021, 0.35634616149304726`, 0.9362616804784101], 
             UndirectedEdge[26, 253] -> 
             RGBColor[
              0.21047277090696587`, 0.3385506053406179, 0.9352974849853658], 
             UndirectedEdge[114, 206] -> 
             RGBColor[
              0.2307773334017795, 0.35989198790628496`, 0.936453799781537], 
             UndirectedEdge[9, 45] -> 
             RGBColor[
              0.24944742731977937`, 0.3795154403664275, 0.9375170340102383], 
             UndirectedEdge[47, 190] -> 
             RGBColor[
              0.1942570496898653, 0.32150685420533776`, 0.9343740236510617], 
             UndirectedEdge[191, 282] -> 
             RGBColor[
              0.3340044293562811, 0.4561964353369906, 0.9427789040351794], 
             UndirectedEdge[59, 155] -> 
             RGBColor[
              0.9556607617329471, 0.8668171290315656, 0.5788467809151635], 
             UndirectedEdge[214, 265] -> 
             RGBColor[
              0.21177311264038245`, 0.33991734694886655`, 0.9353715375234006],
              UndirectedEdge[167, 282] -> 
             RGBColor[
              0.674157084988882, 0.6138860835498305, 0.5969373306942671], 
             UndirectedEdge[28, 221] -> 
             RGBColor[
              0.18483282648833058`, 0.31160139809026205`, 0.9338373280816231],
              UndirectedEdge[136, 197] -> 
             RGBColor[
              0.689478603616865, 0.751552751257122, 0.9111273992783655], 
             UndirectedEdge[121, 234] -> 
             RGBColor[
              0.20980230497718771`, 0.3378459031384259, 0.9352593029425303], 
             UndirectedEdge[141, 146] -> 
             RGBColor[
              0.24693839801171524`, 0.3768782914820059, 0.9373741485029203], 
             UndirectedEdge[32, 167] -> 
             RGBColor[
              0.947679092916505, 0.830434403160785, 0.5492392002744804], 
             UndirectedEdge[101, 136] -> 
             RGBColor[
              0.5199717589850226, 0.6194511898467974, 0.9558606779112371], 
             UndirectedEdge[91, 274] -> 
             RGBColor[
              0.4766026768727841, 0.5859665496480654, 0.9519390550580074], 
             UndirectedEdge[84, 295] -> 
             RGBColor[
              0.19219536521772562`, 0.31933989310677346`, 0.9342566137703623],
              UndirectedEdge[73, 122] -> 
             RGBColor[
              0.18385458485627515`, 0.31057320411086997`, 0.9337816186678564],
              UndirectedEdge[157, 248] -> 
             RGBColor[
              0.20224840910221648`, 0.3299062796291701, 0.9348291197474383], 
             UndirectedEdge[125, 167] -> 
             RGBColor[
              0.859356989051198, 0.4049161457343329, 0.20241604569242247`], 
             UndirectedEdge[20, 208] -> 
             RGBColor[
              0.20416035452872197`, 0.331915855496769, 0.9349380022110079], 
             UndirectedEdge[77, 103] -> 
             RGBColor[
              0.41755616548084906`, 0.5360878963815774, 0.9478272875273883], 
             UndirectedEdge[46, 276] -> 
             RGBColor[
              0.22304128842203616`, 0.35176091413899346`, 0.9360132434643936],
              UndirectedEdge[3, 291] -> 
             RGBColor[
              0.940546596555184, 0.9549527783634579, 0.9776339401843177], 
             UndirectedEdge[79, 297] -> 
             RGBColor[
              0.1875669958551452, 0.3144751834511347, 0.9339930349822221], 
             UndirectedEdge[18, 262] -> 
             RGBColor[
              0.25190729178629806`, 0.38210091388515394`, 0.9376571196525632],
              UndirectedEdge[127, 225] -> 
             RGBColor[
              0.28821593818422175`, 0.41655707862770686`, 0.9398605573780583],
              UndirectedEdge[109, 292] -> 
             RGBColor[
              0.8832633694480486, 0.907223500639492, 0.873440789605417], 
             UndirectedEdge[267, 287] -> 
             RGBColor[
              0.2196035170740144, 0.34814759848492993`, 0.9358174674718507], 
             UndirectedEdge[218, 262] -> 
             RGBColor[
              0.6355147016275733, 0.7058679616598169, 0.9405191403190352], 
             UndirectedEdge[207, 225] -> 
             RGBColor[
              0.20644219198451136`, 0.33431421133965444`, 0.9350679494784392],
              UndirectedEdge[203, 299] -> 
             RGBColor[
              0.8581709631436525, 0.41400624201784997`, 0.4407947359057055], 
             UndirectedEdge[142, 163] -> 
             RGBColor[
              0.7603405238297619, 0.3885080681094508, 0.43863923535829075`], 
             UndirectedEdge[2, 54] -> 
             RGBColor[
              0.22131402237840694`, 0.34994544801214666`, 0.9359148782184701],
              UndirectedEdge[90, 195] -> 
             RGBColor[
              0.19970007804544365`, 0.3272278221149808, 0.934683996063673], 
             UndirectedEdge[88, 93] -> 
             RGBColor[
              0.23199426054362918`, 0.36117105549000617`, 0.9365231019819831],
              UndirectedEdge[77, 82] -> 
             RGBColor[
              0.5136111712070213, 0.6149382362843397, 0.9551491039925967], 
             UndirectedEdge[167, 168] -> 
             RGBColor[
              0.6540467218133117, 0.5964674977433942, 0.5956559161356156], 
             UndirectedEdge[18, 26] -> 
             RGBColor[
              0.21453517633612967`, 0.3428204510180499, 0.9355288329647664], 
             UndirectedEdge[129, 224] -> 
             RGBColor[
              0.19887770973958555`, 0.32636346088436186`, 0.9346371634052393],
              UndirectedEdge[38, 289] -> 
             RGBColor[
              0.21478203632197956`, 0.34307991651500525`, 0.935542891275764], 
             UndirectedEdge[31, 241] -> 
             RGBColor[
              0.7028863769460394, 0.7632151146504713, 0.9137909719699326], 
             UndirectedEdge[5, 197] -> 
             RGBColor[
              0.9786771999205136, 0.9512505460041922, 0.6089534518793391], 
             UndirectedEdge[59, 241] -> 
             RGBColor[
              0.9855659463819599, 0.9882991621377519, 0.8888731527916648], 
             UndirectedEdge[155, 226] -> 
             RGBColor[
              0.9562854870849291, 0.8670754690193194, 0.5684934650954372], 
             UndirectedEdge[15, 186] -> 
             RGBColor[
              0.22574603195372214`, 0.35460377108144014`, 0.9361672746072136],
              UndirectedEdge[198, 256] -> 
             RGBColor[
              0.866815756563354, 0.4169101123137112, 0.4248082782495014], 
             UndirectedEdge[72, 291] -> 
             RGBColor[
              0.8619019121087841, 0.4662467231049401, 0.44816350088512813`], 
             UndirectedEdge[230, 297] -> 
             RGBColor[
              0.19203933424327527`, 0.319175894659691, 0.9342477280371944], 
             UndirectedEdge[138, 231] -> 
             RGBColor[
              0.23123426787294182`, 0.3603722550067954, 0.9364798215236958], 
             UndirectedEdge[54, 165] -> 
             RGBColor[
              0.2309155676527057, 0.3600372808685661, 0.936461672017628], 
             UndirectedEdge[103, 167] -> 
             RGBColor[
              0.6645058305861254, 0.6055266520723135, 0.5963223612979925], 
             UndirectedEdge[78, 131] -> 
             RGBColor[
              0.21176961520445978`, 0.33991367092196156`, 0.9353713383495988],
              UndirectedEdge[16, 239] -> 
             RGBColor[
              0.2421832343916902, 0.3718803130225725, 0.9371033489693941], 
             UndirectedEdge[12, 87] -> 
             RGBColor[
              0.7113840896935575, 0.7671448961592477, 0.7220908533867955], 
             UndirectedEdge[125, 281] -> 
             RGBColor[
              0.8829501729358756, 0.5088362266550703, 0.4280047531480473], 
             UndirectedEdge[148, 205] -> 
             RGBColor[
              0.3093284827197305, 0.43657270388582725`, 0.9411425228750159], 
             UndirectedEdge[103, 269] -> 
             RGBColor[
              0.6972472679550255, 0.7302486647196956, 0.6491594274470608], 
             UndirectedEdge[40, 169] -> 
             RGBColor[
              0.6469863029423364, 0.7235735932337524, 0.9658432196124291], 
             UndirectedEdge[38, 53] -> 
             RGBColor[
              0.2009984379794762, 0.32859248072642344`, 0.9347579357411648], 
             UndirectedEdge[118, 285] -> 
             RGBColor[
              0.19420033164892994`, 0.32144723994818314`, 0.9343707936425373],
              UndirectedEdge[74, 267] -> 
             RGBColor[
              0.2010537316252639, 0.328650597853966, 0.9347610846324927], 
             UndirectedEdge[3, 200] -> 
             RGBColor[
              0.659894342148658, 0.7282185404316961, 0.9534476666394777], 
             UndirectedEdge[124, 273] -> 
             RGBColor[
              0.2124273089085979, 0.3406049487052001, 0.9354087930330789], 
             UndirectedEdge[131, 182] -> 
             RGBColor[
              0.24187571808972635`, 0.3715570938915489, 0.9370858363709268], 
             UndirectedEdge[62, 207] -> 
             RGBColor[
              0.19348238664909873`, 0.3206926342330184, 0.9343299077369014], 
             UndirectedEdge[75, 262] -> 
             RGBColor[
              0.318384602518598, 0.4497368644421247, 0.9415247720626443], 
             UndirectedEdge[197, 283] -> 
             RGBColor[
              0.646081244426157, 0.713693683071829, 0.9083720606763512], 
             UndirectedEdge[246, 278] -> 
             RGBColor[
              0.1925398971260588, 0.3197020179870163, 0.9342762343528525], 
             UndirectedEdge[225, 265] -> 
             RGBColor[
              0.22515623507617133`, 0.35398385716785236`, 0.9361336865475633],
              UndirectedEdge[101, 204] -> 
             RGBColor[
              0.5654681824695174, 0.6580354513456885, 0.9589869162220399], 
             UndirectedEdge[87, 140] -> 
             RGBColor[
              0.8759286833407519, 0.418668898924348, 0.2746739047117526], 
             UndirectedEdge[57, 247] -> 
             RGBColor[
              0.18871603896391997`, 0.3156829006119979, 0.9340584712874099], 
             UndirectedEdge[40, 66] -> 
             RGBColor[
              0.5377876957046065, 0.6331026822689709, 0.9577491794160538], 
             UndirectedEdge[167, 293] -> 
             RGBColor[
              0.9037203948195764, 0.6547034053372311, 0.24132279457904], 
             UndirectedEdge[42, 140] -> 
             RGBColor[
              0.8308428229488108, 0.23807702936156347`, 0.1771684281287546], 
             UndirectedEdge[107, 150] -> 
             RGBColor[
              0.657942354371067, 0.5994193570949246, 0.595803153810185], 
             UndirectedEdge[91, 143] -> 
             RGBColor[
              0.39852667636969663`, 0.5184340170227889, 0.9468974027089019], 
             UndirectedEdge[91, 142] -> 
             RGBColor[
              0.7166766594677184, 0.35305977598567057`, 0.4352018560097054], 
             UndirectedEdge[44, 283] -> 
             RGBColor[
              0.3110200455084933, 0.44354120705361005`, 0.9410488029197814], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.19626308316666907`, 0.323615322579327, 0.9344882642899051], 
             UndirectedEdge[199, 233] -> 
             RGBColor[
              0.20189518711453486`, 0.32953502092454917`, 0.9348090042777849],
              UndirectedEdge[249, 286] -> 
             RGBColor[
              0.2141737173623244, 0.342440534718758, 0.9355082484109388], 
             UndirectedEdge[48, 266] -> 
             RGBColor[
              0.19547981769013628`, 0.32279206090159157`, 0.934443658479754], 
             UndirectedEdge[113, 169] -> 
             RGBColor[
              0.4361857848874334, 0.5443112881470928, 0.9502895329739705], 
             UndirectedEdge[18, 33] -> 
             RGBColor[
              0.20024058888485757`, 0.32779593327757145`, 0.9347147773563635],
              UndirectedEdge[269, 293] -> 
             RGBColor[
              0.9364618321884765, 0.7794254179846133, 0.2941598607281082], 
             UndirectedEdge[189, 257] -> 
             RGBColor[
              0.1999558217805158, 0.327496624995631, 0.9346985602910465], 
             UndirectedEdge[11, 197] -> 
             RGBColor[
              0.7590782600827003, 0.809705103128537, 0.9161511323825111], 
             UndirectedEdge[221, 296] -> 
             RGBColor[
              0.18670137270172213`, 0.31356535863320917`, 0.9339437390242094],
              UndirectedEdge[126, 157] -> 
             RGBColor[
              0.20301322621103607`, 0.33071015090274497`, 0.93487267495034], 
             UndirectedEdge[24, 87] -> 
             RGBColor[
              0.9584560317231505, 0.8616047223377981, 0.3765513268644449], 
             UndirectedEdge[53, 137] -> 
             RGBColor[
              0.2387057780017381, 0.36822528587326325`, 0.936905312972422], 
             UndirectedEdge[27, 140] -> 
             RGBColor[
              0.8681598345506768, 0.3927281505486404, 0.22192545531754573`], 
             UndirectedEdge[115, 200] -> 
             RGBColor[
              0.35864952563609026`, 0.485065925681853, 0.9440738085255767], 
             UndirectedEdge[1, 5] -> 
             RGBColor[
              0.8694664994809802, 0.4010878979497081, 0.22431948647786654`], 
             UndirectedEdge[40, 42] -> 
             RGBColor[
              0.7881477040684427, 0.44575263857904807`, 0.445649103589277], 
             UndirectedEdge[82, 167] -> 
             RGBColor[
              0.7605608363122977, 0.684376991975076, 0.6036441777632009], 
             UndirectedEdge[52, 57] -> 
             RGBColor[
              0.18920436008623348`, 0.3161961570728968, 0.9340862804529193], 
             UndirectedEdge[27, 203] -> 
             RGBColor[
              0.9534832977574548, 0.9312795143111227, 0.6643276822065549], 
             UndirectedEdge[251, 270] -> 
             RGBColor[
              0.24922321837913736`, 0.37927978255414485`, 0.9375042656427561],
              UndirectedEdge[200, 264] -> 
             RGBColor[
              0.3308901333922204, 0.45986309204908005`, 0.9423474428513454], 
             UndirectedEdge[84, 271] -> 
             RGBColor[
              0.20505156873545605`, 0.33285257813429087`, 0.9349887555416483],
              UndirectedEdge[80, 145] -> 
             RGBColor[
              0.9218561356347152, 0.9176464031707863, 0.6795757972164687], 
             UndirectedEdge[199, 259] -> 
             RGBColor[
              0.19177802866162308`, 0.31890124592564373`, 0.9342328470708863],
              UndirectedEdge[273, 274] -> 
             RGBColor[
              0.3509883555182567, 0.4717110997619036, 0.9438949792783465], 
             UndirectedEdge[281, 294] -> 
             RGBColor[
              0.7572554970898742, 0.8088426757639791, 0.9389810177450694], 
             UndirectedEdge[18, 183] -> 
             RGBColor[
              0.19635753288152386`, 0.32371459521809726`, 0.9344936430614402],
              UndirectedEdge[77, 269] -> 
             RGBColor[
              0.6934737954253698, 0.7269802724747518, 0.6489189851142219], 
             UndirectedEdge[134, 144] -> 
             RGBColor[
              0.22121948408189393`, 0.34984608226843733`, 0.9359094944023405],
              UndirectedEdge[200, 210] -> 
             RGBColor[
              0.4186246829308158, 0.5365148469090834, 0.9480331221442837], 
             UndirectedEdge[87, 151] -> 
             RGBColor[
              0.7954880540997038, 0.8360677360525939, 0.7285340376363743], 
             UndirectedEdge[109, 290] -> 
             RGBColor[
              0.9696110495252712, 0.9082697495604787, 0.5222701846474617], 
             UndirectedEdge[247, 278] -> 
             RGBColor[
              0.19919319876560948`, 0.3266950598538726, 0.9346551300385472], 
             UndirectedEdge[156, 205] -> 
             RGBColor[
              0.38342561820827703`, 0.5065257317852604, 0.945652519235638], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.18357179140558838`, 0.31027597026405784`, 0.9337655139991952],
              UndirectedEdge[64, 121] -> 
             RGBColor[
              0.2303769927354159, 0.3594712044828725, 0.9364310009728385], 
             UndirectedEdge[106, 264] -> 
             RGBColor[
              0.579035279379287, 0.6606770441091168, 0.9634331593756991], 
             UndirectedEdge[91, 107] -> 
             RGBColor[
              0.44931704433721525`, 0.562597259364136, 0.9501274523636514], 
             UndirectedEdge[7, 299] -> 
             RGBColor[
              0.8585691612482524, 0.41430321751227117`, 0.4401206903813164], 
             UndirectedEdge[160, 221] -> 
             RGBColor[
              0.19098000658392586`, 0.31806247412446187`, 0.9341874008941293],
              UndirectedEdge[8, 234] -> 
             RGBColor[
              0.19931169581116837`, 0.32681960776190155`, 0.934661878269991], 
             UndirectedEdge[49, 174] -> 
             RGBColor[
              0.22141328802375174`, 0.3500497824992095, 0.9359205312501221], 
             UndirectedEdge[79, 245] -> 
             RGBColor[
              0.20419166956427437`, 0.3319487695846225, 0.9349397855559562], 
             UndirectedEdge[13, 147] -> 
             RGBColor[
              0.27334324637888757`, 0.4023623173416999, 0.9389609500302152], 
             UndirectedEdge[1, 197] -> 
             RGBColor[
              0.8745761742166813, 0.4260008413916001, 0.4023616575482095], 
             UndirectedEdge[129, 175] -> 
             RGBColor[
              0.18584814501363772`, 0.3126685622352725, 0.9338951489696101], 
             UndirectedEdge[116, 283] -> 
             RGBColor[
              0.29658629715284524`, 0.4290613813379507, 0.9402015229115228], 
             UndirectedEdge[62, 265] -> 
             RGBColor[
              0.2121964297407587, 0.3403622800612163, 0.9353956448060256], 
             UndirectedEdge[31, 291] -> 
             RGBColor[
              0.6732616853502813, 0.7412145267166439, 0.970423977207056], 
             UndirectedEdge[92, 277] -> 
             RGBColor[
              0.8853735220807035, 0.49151915194709656`, 0.27879642661699433`],
              UndirectedEdge[124, 289] -> 
             RGBColor[
              0.2146845283282537, 0.3429774294312355, 0.9355373383397714], 
             UndirectedEdge[80, 277] -> 
             RGBColor[
              0.9859097978901593, 0.963818944183442, 0.4264320765360633], 
             UndirectedEdge[119, 244] -> 
             RGBColor[
              0.18517767786647377`, 0.3119638587535308, 0.9338569668574466], 
             UndirectedEdge[252, 268] -> 
             RGBColor[
              0.22149590633125682`, 0.35013661957870057`, 0.9359252362405117],
              UndirectedEdge[3, 194] -> 
             RGBColor[
              0.8201119559484569, 0.8600043630497185, 0.9658594088182089], 
             UndirectedEdge[1, 237] -> 
             RGBColor[
              0.820820491401125, 0.16104099727236243`, 0.16757103212008623`], 
             UndirectedEdge[149, 281] -> 
             RGBColor[
              0.9369826909775356, 0.800923138426649, 0.5779306345773171], 
             UndirectedEdge[29, 209] -> 
             RGBColor[
              0.1878554243304431, 0.3147783400660943, 0.9340094605571987], 
             UndirectedEdge[123, 287] -> 
             RGBColor[
              0.22080206667647367`, 0.3494073501095485, 0.9358857230986155], 
             UndirectedEdge[17, 81] -> 
             RGBColor[
              0.7965640174649642, 0.6796969932787943, 0.60028868050202], 
             UndirectedEdge[176, 187] -> 
             RGBColor[
              0.20946640578711895`, 0.33749285179242483`, 0.9352401739805742],
              UndirectedEdge[246, 270] -> 
             RGBColor[
              0.19864447884335656`, 0.3261183204247322, 0.9346238812507333], 
             UndirectedEdge[45, 131] -> 
             RGBColor[
              0.2646712879230951, 0.39551668310902466`, 0.9383840103499137], 
             UndirectedEdge[4, 158] -> 
             RGBColor[
              0.2067416614051505, 0.33462897268820413`, 0.9350850038189193], 
             UndirectedEdge[169, 264] -> 
             RGBColor[
              0.450474457220526, 0.5593295887233245, 0.9511032517251437], 
             UndirectedEdge[42, 181] -> 
             RGBColor[
              0.8871678109624904, 0.5151775172813806, 0.25618078405458466`], 
             UndirectedEdge[8, 263] -> 
             RGBColor[
              0.20717874992744892`, 0.3350883804381527, 0.9351098953636496], 
             UndirectedEdge[145, 205] -> 
             RGBColor[
              0.6186317877643385, 0.696027939962637, 0.9659619530693695], 
             UndirectedEdge[167, 269] -> 
             RGBColor[
              0.9404234605306463, 0.796419028165488, 0.2974140588848261], 
             UndirectedEdge[187, 288] -> 
             RGBColor[
              0.2168027551458141, 0.3452038201198287, 0.9356579682233956], 
             UndirectedEdge[47, 131] -> 
             RGBColor[
              0.20675371716772, 0.33464164405904423`, 0.9350856903767627], 
             UndirectedEdge[43, 97] -> 
             RGBColor[
              0.33722237523593046`, 0.45881814929687276`, 0.9429900087971892],
              UndirectedEdge[104, 114] -> 
             RGBColor[
              0.28710993911342014`, 0.4166656473064825, 0.939751033226302], 
             UndirectedEdge[26, 129] -> 
             RGBColor[
              0.20909164827758553`, 0.33709895788890676`, 0.9352188320948104],
              UndirectedEdge[28, 79] -> 
             RGBColor[
              0.1833054434406642, 0.3099960216654862, 0.9337503458766192], 
             UndirectedEdge[53, 247] -> 
             RGBColor[
              0.2068169042556322, 0.33470805769473266`, 0.9350892887879424], 
             UndirectedEdge[150, 281] -> 
             RGBColor[
              0.9429354945032435, 0.8270367350349062, 0.582850380130669], 
             UndirectedEdge[76, 248] -> 
             RGBColor[
              0.2744382407386017, 0.40410226692421763`, 0.9390017406595347], 
             UndirectedEdge[194, 210] -> 
             RGBColor[
              0.5788422967306146, 0.6683006695271059, 0.9604448643230148], 
             UndirectedEdge[60, 265] -> 
             RGBColor[
              0.2549916258941355, 0.3853427445905684, 0.9378327679171411], 
             UndirectedEdge[78, 178] -> 
             RGBColor[
              0.2265713684695162, 0.3554712520888972, 0.9362142763008121], 
             UndirectedEdge[120, 190] -> 
             RGBColor[
              0.24175240008128845`, 0.37142747884586735`, 0.937078813592779], 
             UndirectedEdge[96, 267] -> 
             RGBColor[
              0.19857826997424566`, 0.3260487307054119, 0.9346201107535846], 
             UndirectedEdge[159, 212] -> 
             RGBColor[
              0.2623047179263146, 0.3930292679932042, 0.9382492376896236], 
             UndirectedEdge[34, 147] -> 
             RGBColor[
              0.19854534996450335`, 0.32601412968792354`, 0.9346182360077306],
              UndirectedEdge[41, 250] -> 
             RGBColor[
              0.18562426514456906`, 0.3124332502980778, 0.9338823993422674], 
             UndirectedEdge[146, 236] -> 
             RGBColor[
              0.2157299800022288, 0.3440762654260479, 0.9355968752659971], 
             UndirectedEdge[82, 103] -> 
             RGBColor[
              0.5173846437366769, 0.6182066285292835, 0.9553895463254356], 
             UndirectedEdge[179, 289] -> 
             RGBColor[
              0.383100677252795, 0.49832129750419296`, 0.9463738276021099], 
             UndirectedEdge[124, 247] -> 
             RGBColor[
              0.191840440673128, 0.3189668449068855, 0.9342364013426112], 
             UndirectedEdge[162, 227] -> 
             RGBColor[
              0.9720263822129245, 0.9204431940139248, 0.5369240475267748], 
             UndirectedEdge[156, 191] -> 
             RGBColor[
              0.31093411780431135`, 0.4362140910182484, 0.9413088841833633], 
             UndirectedEdge[1, 51] -> 
             RGBColor[
              0.8162278504025469, 0.38063100330818245`, 0.4376314664426699], 
             UndirectedEdge[23, 198] -> 
             RGBColor[
              0.9769688580402975, 0.9814876170817164, 0.8855196519471269], 
             UndirectedEdge[77, 159] -> 
             RGBColor[
              0.3525117466514917, 0.4781312147063014, 0.9437419749856031], 
             UndirectedEdge[2, 238] -> 
             RGBColor[
              0.19301734075154908`, 0.3202038415090809, 0.9343034240610095], 
             UndirectedEdge[113, 245] -> 
             RGBColor[
              0.24643755239072743`, 0.3763518709789012, 0.9373456260857398], 
             UndirectedEdge[167, 201] -> 
             RGBColor[
              0.8661367359765803, 0.45702825150686766`, 0.20890833900479755`],
              UndirectedEdge[125, 150] -> 
             RGBColor[
              0.8592661193941853, 0.40455587782479563`, 0.20234292983340507`],
              UndirectedEdge[142, 198] -> 
             RGBColor[
              0.8748207484584395, 0.4784399878291542, 0.43247386752858047`], 
             UndirectedEdge[34, 52] -> 
             RGBColor[
              0.1912130018306219, 0.3183073669014913, 0.934200669628743], 
             UndirectedEdge[13, 251] -> 
             RGBColor[
              0.3094480150189227, 0.44031071835692515`, 0.9410170631920465], 
             UndirectedEdge[120, 188] -> 
             RGBColor[
              0.317477361422549, 0.44666279511939655`, 0.9415507479684607], 
             UndirectedEdge[67, 173] -> 
             RGBColor[
              0.1901069718936137, 0.3171448593113474, 0.934137682860055], 
             UndirectedEdge[20, 280] -> 
             RGBColor[
              0.24050854139809294`, 0.3701201045046333, 0.9370079776808949], 
             UndirectedEdge[32, 107] -> 
             RGBColor[
              0.6980757286113448, 0.7586971466019095, 0.9005750351374335], 
             UndirectedEdge[189, 287] -> 
             RGBColor[
              0.22941840696730975`, 0.35846367006274493`, 0.9363764109314454],
              UndirectedEdge[159, 205] -> 
             RGBColor[
              0.33180025652813283`, 0.4601919629512097, 0.9424222571493942], 
             UndirectedEdge[66, 86] -> 
             RGBColor[
              0.49025940765542825`, 0.5952351366581299, 0.9535166371045274], 
             UndirectedEdge[119, 266] -> 
             RGBColor[
              0.1895006672172379, 0.3165075946545396, 0.9341031547056828], 
             UndirectedEdge[28, 230] -> 
             RGBColor[
              0.1877777818287943, 0.3146967328740425, 0.9340050389315915], 
             UndirectedEdge[83, 142] -> 
             RGBColor[
              0.8410135879259631, 0.3162539858335876, 0.18690796415711172`], 
             UndirectedEdge[191, 217] -> 
             RGBColor[
              0.21370747825416658`, 0.3419504878548173, 0.9354816967834682], 
             UndirectedEdge[43, 233] -> 
             RGBColor[
              0.2154911007768475, 0.3438251882143545, 0.9355832714475019], 
             UndirectedEdge[113, 297] -> 
             RGBColor[
              0.22981287868159825`, 0.35887828484541334`, 0.9363988755120056],
              UndirectedEdge[158, 207] -> 
             RGBColor[
              0.189116703595207, 0.3161040245430854, 0.9340812885454315], 
             UndirectedEdge[40, 201] -> 
             RGBColor[
              0.7933206093756301, 0.4855138555516503, 0.4506026835534007], 
             UndirectedEdge[194, 226] -> 
             RGBColor[
              0.8361313395314567, 0.8716084988779389, 0.9233783108429527], 
             UndirectedEdge[134, 230] -> 
             RGBColor[
              0.21844228820343148`, 0.34692707331578443`, 0.9357513372055553],
              UndirectedEdge[134, 264] -> 
             RGBColor[
              0.27050450497484707`, 0.4016477640777385, 0.9387162034315397], 
             UndirectedEdge[59, 226] -> 
             RGBColor[
              0.9856324112421679, 0.988326647065517, 0.887771658052475], 
             UndirectedEdge[42, 201] -> 
             RGBColor[
              0.84019118707681, 0.30993265252864627`, 0.18612043217519372`], 
             UndirectedEdge[217, 295] -> 
             RGBColor[
              0.19848052761044668`, 0.32594599728383544`, 0.9346145444705631],
              UndirectedEdge[45, 94] -> 
             RGBColor[
              0.5484117816822776, 0.636917841037437, 0.9603911500045271], 
             UndirectedEdge[197, 254] -> 
             RGBColor[
              0.6525617744919028, 0.7195772493628625, 0.9087750915707931], 
             UndirectedEdge[30, 189] -> 
             RGBColor[
              0.23256614809149867`, 0.36177214556258186`, 0.9365556701318023],
              UndirectedEdge[92, 179] -> 
             RGBColor[
              0.7286220477197832, 0.3701780038392919, 0.4370908994932349], 
             UndirectedEdge[134, 288] -> 
             RGBColor[
              0.22683219740980134`, 0.35574539984264686`, 0.9362291301230996],
              UndirectedEdge[59, 83] -> 
             RGBColor[
              0.8927042858426667, 0.5685755362546596, 0.4275164011539326], 
             UndirectedEdge[10, 22] -> 
             RGBColor[
              0.18947218593303478`, 0.31647765901902436`, 0.9341015327386817],
              UndirectedEdge[148, 168] -> 
             RGBColor[
              0.32335433659993124`, 0.4487211935569434, 0.9420362378816867], 
             UndirectedEdge[130, 216] -> 
             RGBColor[
              0.8815768726528278, 0.553695183078948, 0.2228219191679405], 
             UndirectedEdge[158, 196] -> 
             RGBColor[
              0.1980026870183727, 0.32544375652472224`, 0.9345873321557463], 
             UndirectedEdge[203, 237] -> 
             RGBColor[
              0.8624248063392239, 0.4467031448649862, 0.4448682209538134], 
             UndirectedEdge[160, 193] -> 
             RGBColor[
              0.23766407621559904`, 0.36713039124832314`, 0.9368459895967611],
              UndirectedEdge[38, 88] -> 
             RGBColor[
              0.20448897001762012`, 0.33226125121102634`, 0.9349567163769577],
              UndirectedEdge[22, 73] -> 
             RGBColor[
              0.1856051226212358, 0.3124131302923484, 0.9338813092038822], 
             UndirectedEdge[181, 227] -> 
             RGBColor[
              0.9694992257478029, 0.9078122736758734, 0.34102909604815745`], 
             UndirectedEdge[85, 255] -> 
             RGBColor[
              0.2990831810082368, 0.42639058870879876`, 0.9405375990810403], 
             UndirectedEdge[106, 227] -> 
             RGBColor[
              0.907282547148933, 0.8714421765894653, 0.6337446762316135], 
             UndirectedEdge[131, 261] -> 
             RGBColor[
              0.23707213530482818`, 0.36650822381988146`, 0.9368122794375908],
              UndirectedEdge[81, 94] -> 
             RGBColor[
              0.8431768541892217, 0.7161112955984645, 0.6049346124449686], 
             UndirectedEdge[77, 154] -> 
             RGBColor[
              0.455540153481848, 0.5677935680255081, 0.950577540756124], 
             UndirectedEdge[167, 277] -> 
             RGBColor[
              0.9503466052484179, 0.8295784884211206, 0.3626330239957771], 
             UndirectedEdge[113, 176] -> 
             RGBColor[
              0.23091262265844142`, 0.3600341854928709, 0.9364615043045614], 
             UndirectedEdge[4, 276] -> 
             RGBColor[
              0.23095575836688206`, 0.36007952385740394`, 0.9364639608193436],
              UndirectedEdge[101, 243] -> 
             RGBColor[
              0.8173727655187092, 0.8567408344553589, 0.91183562312612], 
             UndirectedEdge[52, 271] -> 
             RGBColor[
              0.21068413741610115`, 0.3387727649431298, 0.9353095219953723], 
             UndirectedEdge[37, 71] -> 
             RGBColor[
              0.22494256325409756`, 0.3537592745352769, 0.9361215182533955], 
             UndirectedEdge[83, 291] -> 
             RGBColor[
              0.8733266651066773, 0.5540623810054337, 0.4591038572583237], 
             UndirectedEdge[80, 149] -> 
             RGBColor[
              0.9371561077922606, 0.7792834728078644, 0.30334662593416606`], 
             UndirectedEdge[104, 206] -> 
             RGBColor[
              0.2787552105581772, 0.4078842978745366, 0.9392752437947942], 
             UndirectedEdge[61, 108] -> 
             RGBColor[
              0.25897235282054676`, 0.38952674098289125`, 0.9380594644266425],
              UndirectedEdge[115, 264] -> 
             RGBColor[
              0.32396934415914475`, 0.453868652264371, 0.9419064562812274], 
             UndirectedEdge[38, 52] -> 
             RGBColor[
              0.19242626978916738`, 0.3195825884515542, 0.934269763444113], 
             UndirectedEdge[33, 285] -> 
             RGBColor[
              0.20009304762604624`, 0.3276408580599046, 0.934706375099942], 
             UndirectedEdge[100, 122] -> 
             RGBColor[
              0.18285159839459103`, 0.3095190017466254, 0.933724500072649], 
             UndirectedEdge[205, 269] -> 
             RGBColor[
              0.6727623053020111, 0.7090410207196602, 0.647599267278013], 
             UndirectedEdge[177, 252] -> 
             RGBColor[
              0.2649570005472917, 0.39581698519228203`, 0.9384002812611878], 
             UndirectedEdge[152, 244] -> 
             RGBColor[
              0.1860116480511821, 0.312840414294423, 0.9339044602257174], 
             UndirectedEdge[10, 71] -> 
             RGBColor[
              0.20685989156236995`, 0.3347532400796667, 0.9350917368514671], 
             UndirectedEdge[233, 259] -> 
             RGBColor[
              0.1952784533382303, 0.32258041420050104`, 0.9344321910778048], 
             UndirectedEdge[130, 299] -> 
             RGBColor[
              0.849730326606493, 0.32580872903031854`, 0.19298739444399152`], 
             UndirectedEdge[81, 86] -> 
             RGBColor[
              0.7418209808035544, 0.6361932312179576, 0.5953370394744854], 
             UndirectedEdge[205, 282] -> 
             RGBColor[
              0.40649592976024684`, 0.5265080761040026, 0.947122539087454], 
             UndirectedEdge[176, 297] -> 
             RGBColor[
              0.19309289409094996`, 0.3202832528591496, 0.9343077267119173], 
             UndirectedEdge[92, 128] -> 
             RGBColor[
              0.8360165444918075, 0.27784452028027223`, 0.18212278972121096`],
              UndirectedEdge[166, 285] -> 
             RGBColor[
              0.19288702957547718`, 0.3200668762008235, 0.9342960030323104], 
             UndirectedEdge[132, 146] -> 
             RGBColor[
              0.19846266788634026`, 0.3259272255814276, 0.9346135273856964], 
             UndirectedEdge[81, 130] -> 
             RGBColor[
              0.9006340382989853, 0.6395018820094367, 0.23868605563289352`], 
             UndirectedEdge[1, 128] -> 
             RGBColor[
              0.8274423550647934, 0.21193954311047752`, 0.1739121362427404], 
             UndirectedEdge[296, 297] -> 
             RGBColor[
              0.18960014391301738`, 0.31661215096899065`, 0.934108819756345], 
             UndirectedEdge[128, 237] -> 
             RGBColor[
              0.838318390904733, 0.29553752048554727`, 0.1843270404457921], 
             UndirectedEdge[112, 146] -> 
             RGBColor[
              0.19463017997348525`, 0.32189903779124873`, 0.934395272868717], 
             UndirectedEdge[116, 287] -> 
             RGBColor[
              0.2651763885560936, 0.39604757589953593`, 0.9384127750837334], 
             UndirectedEdge[10, 266] -> 
             RGBColor[
              0.19427634422620857`, 0.3215271339863788, 0.9343751224463628], 
             UndirectedEdge[16, 76] -> 
             RGBColor[
              0.286854066125812, 0.4171520866149722, 0.9397088035477686], 
             UndirectedEdge[23, 72] -> 
             RGBColor[
              0.8827258558765204, 0.48135797009659975`, 0.3926067291806665], 
             UndirectedEdge[237, 277] -> 
             RGBColor[
              0.8810535048299607, 0.45831360631425644`, 0.27465957321892126`],
              UndirectedEdge[56, 278] -> 
             RGBColor[
              0.1999933373080916, 0.327536056193735, 0.9347006967448426], 
             UndirectedEdge[88, 274] -> 
             RGBColor[
              0.342952508633553, 0.4632649151839602, 0.9434373496862328], 
             UndirectedEdge[103, 282] -> 
             RGBColor[
              0.4309808924132613, 0.5477157201040381, 0.9486826992565017], 
             UndirectedEdge[46, 60] -> 
             RGBColor[
              0.2459880706675731, 0.3758794371890788, 0.9373200287665547], 
             UndirectedEdge[82, 216] -> 
             RGBColor[
              0.7821223617233105, 0.5567021598850534, 0.46109471540637825`], 
             UndirectedEdge[48, 70] -> 
             RGBColor[
              0.2012898575043234, 0.328898781124103, 0.9347745316519882], 
             UndirectedEdge[143, 174] -> 
             RGBColor[
              0.27004966377854045`, 0.4011696971418227, 0.9386903008982872], 
             UndirectedEdge[95, 205] -> 
             RGBColor[
              0.32995805051825455`, 0.4582556876322203, 0.9423173462424312], 
             UndirectedEdge[78, 190] -> 
             RGBColor[
              0.19927294772660503`, 0.32677888106825503`, 0.9346596716238978],
              UndirectedEdge[68, 292] -> 
             RGBColor[
              0.8252860920096456, 0.8638987146846454, 0.9830984780135097], 
             UndirectedEdge[145, 269] -> 
             RGBColor[
              0.9190343803618738, 0.908127960055847, 0.6686138108252507], 
             UndirectedEdge[198, 254] -> 
             RGBColor[
              0.6416864490274542, 0.7118235947085315, 0.9431778757394982], 
             UndirectedEdge[124, 147] -> 
             RGBColor[
              0.19966110992932296`, 0.3271868641542167, 0.9346817768871081], 
             UndirectedEdge[44, 194] -> 
             RGBColor[
              0.5011124283287507, 0.6014735099165995, 0.9553542362124354], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.3434646997755016, 0.4661397793633797, 0.9433176524403382], 
             UndirectedEdge[5, 11] -> 
             RGBColor[
              0.7514137479791486, 0.7723356879656991, 0.6490878757769967], 
             UndirectedEdge[108, 254] -> 
             RGBColor[
              0.27973365180931276`, 0.4104203008650652, 0.9392757639847461], 
             UndirectedEdge[61, 71] -> 
             RGBColor[
              0.25028804221449197`, 0.3803989799188331, 0.9375649057849139], 
             UndirectedEdge[229, 284] -> 
             RGBColor[
              0.22933503139451644`, 0.3583760370494225, 0.936371662815918], 
             UndirectedEdge[37, 136] -> 
             RGBColor[
              0.309591888135542, 0.4349767741872242, 0.9412260952746828], 
             UndirectedEdge[148, 159] -> 
             RGBColor[
              0.26876902654338763`, 0.39982366621058674`, 0.9386173705022783],
              UndirectedEdge[164, 230] -> 
             RGBColor[
              0.1870233298629817, 0.313903756022956, 0.9339620740082502], 
             UndirectedEdge[176, 193] -> 
             RGBColor[
              0.23687819251132788`, 0.36630437764722934`, 0.9368012346824135],
              UndirectedEdge[216, 299] -> 
             RGBColor[
              0.8505404448303738, 0.37258152858724236`, 0.19536912935227085`],
              UndirectedEdge[149, 277] -> 
             RGBColor[
              0.9442574972371908, 0.8029244899485575, 0.3576036046538991], 
             UndirectedEdge[39, 248] -> 
             RGBColor[
              0.21184147363468755`, 0.3399891986882186, 0.9353754305808952], 
             UndirectedEdge[13, 137] -> 
             RGBColor[
              0.2974114508687985, 0.42765952627289927`, 0.9403315986701979], 
             UndirectedEdge[68, 75] -> 
             RGBColor[
              0.6048929892039929, 0.6837170469414527, 0.9652757515328931], 
             UndirectedEdge[66, 97] -> 
             RGBColor[
              0.4175999543798127, 0.5361258241249656, 0.9478300777173092], 
             UndirectedEdge[59, 106] -> 
             RGBColor[
              0.9234341463667425, 0.9403782883321993, 0.9424056010083017], 
             UndirectedEdge[51, 198] -> 
             RGBColor[
              0.8879439008384149, 0.9128115493875727, 0.9633242059952494], 
             UndirectedEdge[193, 228] -> 
             RGBColor[
              0.35291040472918833`, 0.4773968889253306, 0.9438069074260627], 
             UndirectedEdge[30, 287] -> 
             RGBColor[
              0.24614870075893425`, 0.37604826959963533`, 0.9373291764126268],
              UndirectedEdge[93, 147] -> 
             RGBColor[
              0.22726390844905786`, 0.3561991555169663, 0.936253715428126], 
             UndirectedEdge[69, 121] -> 
             RGBColor[
              0.21650915427912054`, 0.3448952269935637, 0.9356412480883811], 
             UndirectedEdge[148, 251] -> 
             RGBColor[
              0.26595227173522773`, 0.39686307831464074`, 0.9384569604829689],
              UndirectedEdge[125, 269] -> 
             RGBColor[
              0.881184613963798, 0.48806415416592097`, 0.23764075645846794`], 
             UndirectedEdge[37, 44] -> 
             RGBColor[
              0.27139379762507876`, 0.4018915080789134, 0.9387921467246012], 
             UndirectedEdge[91, 105] -> 
             RGBColor[
              0.38699951220692347`, 0.5063182366232937, 0.9462409477627431], 
             UndirectedEdge[81, 203] -> 
             RGBColor[
              0.9132949931047244, 0.7717981514907339, 0.6103970678254644], 
             UndirectedEdge[8, 69] -> 
             RGBColor[
              0.2060185451131012, 0.33386893161703934`, 0.9350438234158418], 
             UndirectedEdge[52, 270] -> 
             RGBColor[
              0.20578610160522076`, 0.3336246187524874, 0.9350305861019373], 
             UndirectedEdge[108, 268] -> 
             RGBColor[
              0.2228674989167732, 0.351578250350071, 0.9360033464091675], 
             UndirectedEdge[11, 254] -> 
             RGBColor[
              0.4252983225505378, 0.5406623913243694, 0.9489095154684506], 
             UndirectedEdge[82, 255] -> 
             RGBColor[
              0.489728760692208, 0.5942524926612631, 0.9536273379129792], 
             UndirectedEdge[43, 66] -> 
             RGBColor[
              0.3059641689064351, 0.4317438620573953, 0.9409982635304203], 
             UndirectedEdge[252, 283] -> 
             RGBColor[
              0.27188152915805053`, 0.4030951038026612, 0.9387946229216484], 
             UndirectedEdge[99, 215] -> 
             RGBColor[
              0.21020795705683448`, 0.338272269193962, 0.9352824042283578], 
             UndirectedEdge[114, 283] -> 
             RGBColor[
              0.2724764193926355, 0.4037203711574294, 0.9388285010404467], 
             UndirectedEdge[24, 194] -> 
             RGBColor[
              0.8048847779464043, 0.7450443793025796, 0.6134276095233945], 
             UndirectedEdge[134, 228] -> 
             RGBColor[
              0.3355280602689666, 0.4591269427933443, 0.9428170086239273], 
             UndirectedEdge[49, 143] -> 
             RGBColor[
              0.2582581828615999, 0.38877610307504745`, 0.9380187935040003], 
             UndirectedEdge[123, 189] -> 
             RGBColor[
              0.2072195140090381, 0.335131226072495, 0.935112216817791], 
             UndirectedEdge[232, 240] -> 
             RGBColor[
              0.184219115333836, 0.3109563487553536, 0.933802378139279], 
             UndirectedEdge[11, 243] -> 
             RGBColor[
              0.7596161582091865, 0.8099275378271904, 0.907236768390906], 
             UndirectedEdge[155, 210] -> 
             RGBColor[
              0.698996444284087, 0.6637676396684864, 0.6055600185754992], 
             UndirectedEdge[148, 156] -> 
             RGBColor[
              0.32039438822353183`, 0.44615743504463745`, 0.9418476325885221],
              UndirectedEdge[15, 212] -> 
             RGBColor[
              0.24587235329600743`, 0.3757578108946581, 0.9373134388334325], 
             UndirectedEdge[51, 204] -> 
             RGBColor[
              0.647452541380158, 0.7220822556308867, 0.967158350930859], 
             UndirectedEdge[95, 156] -> 
             RGBColor[
              0.3410239560220559, 0.4678404187910305, 0.9430224559559374], 
             UndirectedEdge[87, 109] -> 
             RGBColor[
              0.9929796059139886, 0.9895239708410322, 0.632193448669364], 
             UndirectedEdge[113, 288] -> 
             RGBColor[
              0.23824897201713657`, 0.3677451538202748, 0.9368792985473828], 
             UndirectedEdge[164, 176] -> 
             RGBColor[
              0.1880768897106564, 0.3150111142224146, 0.9340220726829731], 
             UndirectedEdge[17, 294] -> 
             RGBColor[
              0.6198562799736641, 0.7013271769000424, 0.963858572100545], 
             UndirectedEdge[77, 212] -> 
             RGBColor[
              0.32357566422601636`, 0.4477175574235364, 0.9420941078985701], 
             UndirectedEdge[180, 296] -> 
             RGBColor[
              0.19104587171588, 0.3181317025542363, 0.9341911518159554], 
             UndirectedEdge[217, 271] -> 
             RGBColor[
              0.21133673112817714`, 0.3394586823113528, 0.9353466862418491], 
             UndirectedEdge[4, 85] -> 
             RGBColor[
              0.2263430797542824, 0.3552313061748459, 0.9362012755962026], 
             UndirectedEdge[95, 127] -> 
             RGBColor[
              0.3181958172626126, 0.4480678323732162, 0.9415678671403162], 
             UndirectedEdge[54, 75] -> 
             RGBColor[
              0.2884831291269512, 0.41830852004459096`, 0.9398219273882558], 
             UndirectedEdge[134, 193] -> 
             RGBColor[
              0.26218140249464095`, 0.39289965565586527`, 0.9382422150582186],
              UndirectedEdge[40, 178] -> 
             RGBColor[
              0.4741224882012588, 0.573360769660643, 0.953860855337124], 
             UndirectedEdge[69, 239] -> 
             RGBColor[
              0.22257247692189291`, 0.35126816352797696`, 0.935986545343005], 
             UndirectedEdge[134, 200] -> 
             RGBColor[
              0.3051846864517926, 0.4328450374952205, 0.9408835556758889], 
             UndirectedEdge[89, 141] -> 
             RGBColor[
              0.33729605784908523`, 0.4651931821113565, 0.9427636193772146], 
             UndirectedEdge[38, 147] -> 
             RGBColor[
              0.1997586179230488, 0.3272893512379864, 0.9346873298231007], 
             UndirectedEdge[170, 182] -> 
             RGBColor[
              0.2259600378398488, 0.3548287048365162, 0.9361794619258352], 
             UndirectedEdge[94, 120] -> 
             RGBColor[
              0.5379895613183256, 0.6259634266279861, 0.9597976199730934], 
             UndirectedEdge[80, 269] -> 
             RGBColor[
              0.9759866531723878, 0.9306594839278095, 0.36121311142511225`], 
             UndirectedEdge[263, 286] -> 
             RGBColor[
              0.2153900069518347, 0.3437189321945473, 0.9355775143037223], 
             UndirectedEdge[130, 140] -> 
             RGBColor[
              0.8488137274171336, 0.3187633460045766, 0.19210965802511026`], 
             UndirectedEdge[25, 288] -> 
             RGBColor[
              0.19999048340527747`, 0.32753305656092946`, 0.9347005342192993],
              UndirectedEdge[148, 191] -> 
             RGBColor[
              0.23683698231576478`, 0.36626106311881523`, 0.9367988878227413],
              UndirectedEdge[177, 268] -> 
             RGBColor[
              0.24851062539069607`, 0.37853080214228807`, 0.9374636845262513],
              UndirectedEdge[69, 126] -> 
             RGBColor[
              0.21552861209731056`, 0.34386461499051624`, 0.9355854076617092],
              UndirectedEdge[20, 37] -> 
             RGBColor[
              0.22278622542452461`, 0.3514928267566807, 0.9359987180040172], 
             UndirectedEdge[3, 72] -> 
             RGBColor[
              0.8710164273574281, 0.4731960144605215, 0.4379945662177568], 
             UndirectedEdge[87, 154] -> 
             RGBColor[
              0.7452228320173793, 0.7952601643437132, 0.7245769752264782], 
             UndirectedEdge[11, 204] -> 
             RGBColor[
              0.5077115751599948, 0.6112221547175201, 0.9543880614868259], 
             UndirectedEdge[55, 268] -> 
             RGBColor[
              0.20359322925377082`, 0.3313197708749761, 0.9349057052655861], 
             UndirectedEdge[125, 142] -> 
             RGBColor[
              0.8334415120439743, 0.25805169249981336`, 0.1796569357410828], 
             UndirectedEdge[176, 221] -> 
             RGBColor[
              0.1901941228796547, 0.3172364605233681, 0.9341426459797817], 
             UndirectedEdge[29, 182] -> 
             RGBColor[
              0.224799401299116, 0.35360880224359903`, 0.9361133653918483], 
             UndirectedEdge[122, 161] -> 
             RGBColor[
              0.19334750398760153`, 0.32055086400373023`, 0.9343222263688701],
              UndirectedEdge[44, 226] -> 
             RGBColor[
              0.6512382253914439, 0.7184499980919314, 0.9093942676022314], 
             UndirectedEdge[89, 131] -> 
             RGBColor[
              0.3050760854207314, 0.4313279482249144, 0.9409287396125976], 
             UndirectedEdge[56, 110] -> 
             RGBColor[
              0.1926369557700678, 0.31980403277574326`, 0.9342817616990433], 
             UndirectedEdge[43, 178] -> 
             RGBColor[
              0.24229896140308743`, 0.37200194944906734`, 0.9371099394514903],
              UndirectedEdge[66, 162] -> 
             RGBColor[
              0.6888450125107997, 0.7498709206605213, 0.8694416515926326], 
             UndirectedEdge[5, 142] -> 
             RGBColor[
              0.8769612906990375, 0.45869614749014964`, 0.23149650701243416`],
              UndirectedEdge[147, 273] -> 
             RGBColor[
              0.22616395243467474`, 0.35504303200461024`, 0.9361910745603459],
              UndirectedEdge[81, 167] -> 
             RGBColor[
              0.8985734587541578, 0.6313323707616247, 0.23702806496310708`], 
             UndirectedEdge[95, 212] -> 
             RGBColor[
              0.2604625119164363, 0.3910929926742148, 0.9381443267826606], 
             UndirectedEdge[56, 217] -> 
             RGBColor[
              0.19969746831988144`, 0.32722507912794885`, 0.934683847443663], 
             UndirectedEdge[6, 93] -> 
             RGBColor[
              0.2258625386311459, 0.35472622698636247`, 0.9361739094901367], 
             UndirectedEdge[131, 146] -> 
             RGBColor[
              0.2147184255833614, 0.3430130575955638, 0.9355392687383033], 
             UndirectedEdge[7, 80] -> 
             RGBColor[
              0.9585640473109542, 0.9468487152511682, 0.6807339798518178], 
             UndirectedEdge[76, 239] -> 
             RGBColor[
              0.28224692267200363`, 0.41230968673525326`, 0.9394464335437323],
              UndirectedEdge[148, 278] -> 
             RGBColor[
              0.2234636176615972, 0.35220480894699246`, 0.9360372944898065], 
             UndirectedEdge[29, 170] -> 
             RGBColor[
              0.19641582947302122`, 0.3237758686319784, 0.934496962966084], 
             UndirectedEdge[147, 289] -> 
             RGBColor[
              0.22842117185433053`, 0.35741551273064565`, 0.9363196198670385],
              UndirectedEdge[25, 28] -> 
             RGBColor[
              0.18729283765525817`, 0.3141870258004196, 0.9339774220783192], 
             UndirectedEdge[5, 149] -> 
             RGBColor[
              0.933258247478127, 0.766135074707167, 0.2882041746629133], 
             UndirectedEdge[140, 202] -> 
             RGBColor[
              0.8337362452113755, 0.25175489945285184`, 0.1796038966578704], 
             UndirectedEdge[10, 63] -> 
             RGBColor[
              0.18664280478053893`, 0.31350380003462497`, 0.9339404036677414],
              UndirectedEdge[43, 259] -> 
             RGBColor[
              0.20537394232393572`, 0.33319141321544904`, 0.9350071142406031],
              UndirectedEdge[21, 50] -> 
             RGBColor[
              0.18770061499905671`, 0.31461562564332873`, 0.9340006443947961],
              UndirectedEdge[87, 155] -> 
             RGBColor[
              0.959730943798982, 0.866659323879206, 0.37757715104669176`], 
             UndirectedEdge[127, 282] -> 
             RGBColor[
              0.3947336965046049, 0.5163202208449985, 0.9463730599853389], 
             UndirectedEdge[79, 144] -> 
             RGBColor[
              0.1903903758627761, 0.31744273485178653`, 0.9341538222968402], 
             UndirectedEdge[54, 298] -> 
             RGBColor[
              0.25208733908179476`, 0.3822901550083788, 0.9376673730796856], 
             UndirectedEdge[234, 263] -> 
             RGBColor[
              0.20202221841831886`, 0.32966853887907605`, 0.9348162385226094],
              UndirectedEdge[34, 38] -> 
             RGBColor[
              0.18490621443215238`, 0.31167853347228314`, 0.9338415074164561],
              UndirectedEdge[39, 85] -> 
             RGBColor[
              0.21693635514660192`, 0.345344242191386, 0.9356655765457971], 
             UndirectedEdge[20, 108] -> 
             RGBColor[
              0.2298448182232575, 0.3589118553287811, 0.9364006944216527], 
             UndirectedEdge[94, 201] -> 
             RGBColor[
              0.8292056662666228, 0.5135475347314276, 0.45417937065937186`], 
             UndirectedEdge[260, 294] -> 
             RGBColor[
              0.39710848893487455`, 0.5114544721894022, 0.9473162764842546], 
             UndirectedEdge[138, 266] -> 
             RGBColor[
              0.21471877848996196`, 0.3430134285227765, 0.935539288835812], 
             UndirectedEdge[127, 168] -> 
             RGBColor[
              0.3746233333290345, 0.4989016350385623, 0.9450916454266876], 
             UndirectedEdge[128, 198] -> 
             RGBColor[
              0.8848238567439902, 0.5553282615018976, 0.4420528553197187], 
             UndirectedEdge[145, 216] -> 
             RGBColor[
              0.8659437661770946, 0.6227214635073127, 0.46918309334836605`], 
             UndirectedEdge[141, 182] -> 
             RGBColor[
              0.2740956905180802, 0.4054223277779909, 0.9389207161355438], 
             UndirectedEdge[41, 252] -> 
             RGBColor[
              0.21326847287064163`, 0.3414890653621836, 0.9354566960763266], 
             UndirectedEdge[55, 208] -> 
             RGBColor[
              0.19572673330134732`, 0.32305158486432833`, 0.9344577199585336],
              UndirectedEdge[121, 249] -> 
             RGBColor[
              0.21645306950395798`, 0.3448362783388877, 0.9356380541434055], 
             UndirectedEdge[89, 120] -> 
             RGBColor[
              0.3299173264663655, 0.4574376675895273, 0.9423434115408236], 
             UndirectedEdge[32, 142] -> 
             RGBColor[
              0.8825157823171381, 0.4837930341441863, 0.4021669111922269], 
             UndirectedEdge[7, 77] -> 
             RGBColor[
              0.6760511895639363, 0.7431695037981105, 0.9684398535409274], 
             UndirectedEdge[45, 146] -> 
             RGBColor[
              0.24998188699294738`, 0.3800771913696276, 0.937547470697963], 
             UndirectedEdge[110, 223] -> 
             RGBColor[
              0.18370379552866184`, 0.31041471496695283`, 0.9337730314387216],
              UndirectedEdge[225, 276] -> 
             RGBColor[
              0.23448523874767882`, 0.3637892315196025, 0.9366649595056316], 
             UndirectedEdge[65, 291] -> 
             RGBColor[
              0.6521691058057041, 0.7229451944590042, 0.9690799766899112], 
             UndirectedEdge[194, 290] -> 
             RGBColor[
              0.8162082398567924, 0.7899381324572718, 0.622538732772305], 
             UndirectedEdge[154, 258] -> 
             RGBColor[
              0.4187295668061743, 0.5359100880009214, 0.9482320027234739], 
             UndirectedEdge[31, 280] -> 
             RGBColor[
              0.3408307300134504, 0.46531138731317084`, 0.9430966160299905], 
             UndirectedEdge[156, 271] -> 
             RGBColor[
              0.3085633706783219, 0.433722285474784, 0.9411738736417443], 
             UndirectedEdge[83, 241] -> 
             RGBColor[
              0.8930764595038494, 0.5687294396279854, 0.42134852043357485`], 
             UndirectedEdge[208, 268] -> 
             RGBColor[
              0.19718303522223768`, 0.3245822505180589, 0.9345406541985226], 
             UndirectedEdge[1, 80] -> 
             RGBColor[
              0.8720650730237359, 0.40985349668350635`, 0.23441445399203503`],
              UndirectedEdge[116, 206] -> 
             RGBColor[
              0.2548872111619892, 0.3852329980868062, 0.9378268216526131], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.22364840280037163`, 0.35239902984389887`, 0.9360478177300946],
              UndirectedEdge[108, 204] -> 
             RGBColor[
              0.36214690441876973`, 0.48098006425821577`, 0.9447543100031214],
              UndirectedEdge[251, 271] -> 
             RGBColor[
              0.25412125419001774`, 0.38442792874478726`, 0.9377832015361911],
              UndirectedEdge[6, 38] -> 
             RGBColor[
              0.19835724810513683`, 0.32581642270738265`, 0.9346075238851115],
              UndirectedEdge[135, 158] -> 
             RGBColor[
              0.20301108119461975`, 0.33070789635448955`, 0.9348725527948284],
              UndirectedEdge[25, 180] -> 
             RGBColor[
              0.1930001178726018, 0.32018573917131365`, 0.9343024432435325], 
             UndirectedEdge[57, 217] -> 
             RGBColor[
              0.18985695379830947`, 0.3168820744411198, 0.9341234446993961], 
             UndirectedEdge[71, 136] -> 
             RGBColor[
              0.3079661703282201, 0.43326804169526645`, 0.9411335130505898], 
             UndirectedEdge[135, 173] -> 
             RGBColor[
              0.20718172638991203`, 0.3350915088889201, 0.9351100648687836], 
             UndirectedEdge[143, 235] -> 
             RGBColor[
              0.3576942027971, 0.4840672946486393, 0.9440192038790169], 
             UndirectedEdge[264, 288] -> 
             RGBColor[
              0.2525376443502292, 0.38276345439650644`, 0.937693017298556], 
             UndirectedEdge[223, 247] -> 
             RGBColor[
              0.18962339324408597`, 0.3166365874900364, 0.934110143771355], 
             UndirectedEdge[191, 225] -> 
             RGBColor[
              0.22748667103589795`, 0.35643329311969896`, 0.9362664014278987],
              UndirectedEdge[1, 243] -> 
             RGBColor[
              0.8749347729676722, 0.4261491311907023, 0.39641874822047274`], 
             UndirectedEdge[29, 284] -> 
             RGBColor[
              0.21810645410068208`, 0.3465740903806829, 0.9357322119502256], 
             UndirectedEdge[6, 273] -> 
             RGBColor[
              0.22476258261676274`, 0.3535701034740064, 0.9361112686223567], 
             UndirectedEdge[103, 276] -> 
             RGBColor[
              0.33135174266530537`, 0.4551929422593771, 0.9425624927166377], 
             UndirectedEdge[99, 199] -> 
             RGBColor[
              0.19703448061371565`, 0.32442611020559603`, 0.9345321942333341],
              UndirectedEdge[35, 129] -> 
             RGBColor[
              0.19774057513237292`, 0.32516826031368307`, 0.9345724052715985],
              UndirectedEdge[77, 145] -> 
             RGBColor[
              0.6393432778876973, 0.7139671917177287, 0.9672816709055783], 
             UndirectedEdge[72, 155] -> 
             RGBColor[
              0.8617149167399476, 0.39992575965670085`, 0.20372391614271176`],
              UndirectedEdge[20, 44] -> 
             RGBColor[
              0.26761174198818394`, 0.3979163278083595, 0.93857676425113], 
             UndirectedEdge[131, 178] -> 
             RGBColor[
              0.2442095797785655, 0.3740101305018966, 0.9372187463414672], 
             UndirectedEdge[106, 241] -> 
             RGBColor[
              0.9239924068585166, 0.940609143392188, 0.9331537799277652], 
             UndirectedEdge[85, 286] -> 
             RGBColor[
              0.2265196157319883, 0.3554168566804423, 0.9362113290589713], 
             UndirectedEdge[86, 261] -> 
             RGBColor[
              0.41945675567834323`, 0.5279913173677868, 0.949221846121721], 
             UndirectedEdge[256, 269] -> 
             RGBColor[
              0.8696737021648134, 0.3995862419652118, 0.22661789432004487`], 
             UndirectedEdge[37, 61] -> 
             RGBColor[
              0.25191376002181387`, 0.38210771241079083`, 0.937657488009007], 
             UndirectedEdge[73, 244] -> 
             RGBColor[
              0.18608629156364545`, 0.31291886935869395`, 0.9339087110633268],
              UndirectedEdge[180, 193] -> 
             RGBColor[
              0.23722417633734735`, 0.3666680285850174, 0.9368209379494682], 
             UndirectedEdge[8, 213] -> 
             RGBColor[
              0.20342164602247398`, 0.3311394260198779, 0.9348959338543985], 
             UndirectedEdge[48, 138] -> 
             RGBColor[
              0.21204884540564534`, 0.34020715956762493`, 0.9353872400964722],
              UndirectedEdge[170, 284] -> 
             RGBColor[
              0.2192670906414149, 0.34779399297360003`, 0.9357983084842125], 
             UndirectedEdge[55, 219] -> 
             RGBColor[
              0.19323553565117518`, 0.3204331781829436, 0.9343158499377529], 
             UndirectedEdge[111, 235] -> 
             RGBColor[
              0.5113487817124779, 0.61295792200517, 0.9550106787741928], 
             UndirectedEdge[56, 247] -> 
             RGBColor[
              0.19855655348549195`, 0.3260259052988269, 0.9346188740316768], 
             UndirectedEdge[7, 82] -> 
             RGBColor[
              0.7758796678197641, 0.8252882359458167, 0.9760021123389747], 
             UndirectedEdge[182, 190] -> 
             RGBColor[
              0.22937905061187158`, 0.35842230403784237`, 0.9363741696452258],
              UndirectedEdge[113, 228] -> 
             RGBColor[
              0.34694483487630184`, 0.4711266967709722, 0.9434671770482106], 
             UndirectedEdge[133, 146] -> 
             RGBColor[
              0.19265917133132254`, 0.3198273827391699, 0.9342830268423918], 
             UndirectedEdge[93, 274] -> 
             RGBColor[
              0.3520883115326398, 0.4728672232742597, 0.9439576201461266], 
             UndirectedEdge[153, 220] -> 
             RGBColor[
              0.27707930337293885`, 0.40630757672797435`, 0.9391730382607208],
              UndirectedEdge[90, 153] -> 
             RGBColor[
              0.21837262298903565`, 0.3468538507584247, 0.9357473698746558], 
             UndirectedEdge[178, 190] -> 
             RGBColor[
              0.23171291230071078`, 0.36087534064819005`, 0.9365070796157662],
              UndirectedEdge[39, 126] -> 
             RGBColor[
              0.21260629074350712`, 0.3407930699617935, 0.9354189857837971], 
             UndirectedEdge[15, 77] -> 
             RGBColor[
              0.3360793820211845, 0.46085975760775527`, 0.942806176129412], 
             UndirectedEdge[103, 293] -> 
             RGBColor[
              0.6605442022439556, 0.5885330418914387, 0.5930681631412746], 
             UndirectedEdge[92, 269] -> 
             RGBColor[
              0.8787580922688558, 0.4694128451100082, 0.23531711654302695`], 
             UndirectedEdge[8, 14] -> 
             RGBColor[
              0.19233103918746458`, 0.31948249505119564`, 0.9342643402022272],
              UndirectedEdge[157, 171] -> 
             RGBColor[
              0.1808430925709541, 0.30740793477935857`, 0.9336101186373109], 
             UndirectedEdge[198, 226] -> 
             RGBColor[
              0.975424098844659, 0.9808488194558194, 0.9111203095275062], 
             UndirectedEdge[86, 169] -> 
             RGBColor[
              0.5994580148931581, 0.6857060476229113, 0.9616106773009028], 
             UndirectedEdge[163, 235] -> 
             RGBColor[
              0.5148221170934733, 0.615777732139438, 0.9552841124586315], 
             UndirectedEdge[31, 136] -> 
             RGBColor[
              0.4061320211140046, 0.526192876725208, 0.9470993511503072], 
             UndirectedEdge[111, 292] -> 
             RGBColor[
              0.6939596467687601, 0.7604145144003427, 0.9704259544749405], 
             UndirectedEdge[48, 122] -> 
             RGBColor[
              0.1889251216320018, 0.3159026597527588, 0.9340703782360471], 
             UndirectedEdge[246, 295] -> 
             RGBColor[
              0.19068631113650653`, 0.3177537815878572, 0.9341706753728822], 
             UndirectedEdge[258, 263] -> 
             RGBColor[
              0.2750253960672227, 0.40349492782139373`, 0.9390800123727585], 
             UndirectedEdge[24, 299] -> 
             RGBColor[
              0.8537172703307078, 0.34161563232659264`, 0.19619538295009195`],
              UndirectedEdge[66, 193] -> 
             RGBColor[
              0.33295274750258996`, 0.46011056933666983`, 0.9425352231554471],
              UndirectedEdge[29, 199] -> 
             RGBColor[
              0.196824977685108, 0.32420590934437654`, 0.9345202633514818], 
             UndirectedEdge[27, 87] -> 
             RGBColor[
              0.9814947768371431, 0.9488415742094825, 0.4164630400439475], 
             UndirectedEdge[164, 180] -> 
             RGBColor[
              0.18842287353667586`, 0.3153747651602027, 0.9340417759500277], 
             UndirectedEdge[106, 200] -> 
             RGBColor[
              0.6137154608562325, 0.6918743175265988, 0.9656005116200483], 
             UndirectedEdge[69, 285] -> 
             RGBColor[
              0.2036242652013759, 0.3313523916237017, 0.9349074727168887], 
             UndirectedEdge[88, 137] -> 
             RGBColor[
              0.242196310039882, 0.3718940563578661, 0.9371040936082149], 
             UndirectedEdge[43, 261] -> 
             RGBColor[
              0.23516151692935008`, 0.3645000427670523, 0.9367034725476139], 
             UndirectedEdge[224, 253] -> 
             RGBColor[
              0.20025883236896588`, 0.32781510833607297`, 0.9347158162957947],
              UndirectedEdge[5, 23] -> 
             RGBColor[
              0.9801796714011944, 0.9518718565732095, 0.5840536111729073], 
             UndirectedEdge[42, 162] -> 
             RGBColor[
              0.8888525819392381, 0.5235981308400817, 0.3867774183736629], 
             UndirectedEdge[29, 131] -> 
             RGBColor[
              0.21233150972289871`, 0.34050425768701104`, 0.9354033374111754],
              UndirectedEdge[12, 192] -> 
             RGBColor[
              0.3801187118441842, 0.5036614557026298, 0.9454418060863005], 
             UndirectedEdge[69, 76] -> 
             RGBColor[
              0.2672433086560147, 0.39653993712037666`, 0.9385919999213795], 
             UndirectedEdge[176, 180] -> 
             RGBColor[
              0.1945386218938126, 0.32180280444439524`, 0.9343900587715277], 
             UndirectedEdge[101, 116] -> 
             RGBColor[
              0.46733992011891123`, 0.5718860980228273, 0.952579449352897], 
             UndirectedEdge[125, 293] -> 
             RGBColor[
              0.8567159034897515, 0.39358707228041634`, 0.20024658025461053`],
              UndirectedEdge[30, 300] -> 
             RGBColor[
              0.23747118318928384`, 0.36692764844754155`, 0.936835004624272], 
             UndirectedEdge[155, 290] -> 
             RGBColor[
              0.9363623874102649, 0.7854051025986525, 0.2676538870247894], 
             UndirectedEdge[217, 246] -> 
             RGBColor[
              0.1922440281378487, 0.31939104092123016`, 0.9342593850516728], 
             UndirectedEdge[42, 82] -> 
             RGBColor[
              0.7628830394364272, 0.4257203521722454, 0.4433328823923026], 
             UndirectedEdge[122, 138] -> 
             RGBColor[
              0.2081640824318275, 0.3361240273739437, 0.9351660085921052], 
             UndirectedEdge[58, 160] -> 
             RGBColor[
              0.19345266111115197`, 0.32066139080792844`, 0.9343282149114902],
              UndirectedEdge[158, 225] -> 
             RGBColor[
              0.21027114178594725`, 0.3383386803504027, 0.9352860025052073], 
             UndirectedEdge[197, 204] -> 
             RGBColor[
              0.7349750271013598, 0.7901370127560131, 0.9142536375891683], 
             UndirectedEdge[40, 182] -> 
             RGBColor[
              0.47178862651241965`, 0.5709077330502953, 0.9537279453665835], 
             UndirectedEdge[1, 149] -> 
             RGBColor[
              0.8442968725884236, 0.3025905271935833, 0.18852880607059228`], 
             UndirectedEdge[32, 156] -> 
             RGBColor[
              0.691083843191671, 0.7526411268737674, 0.9001295183811735], 
             UndirectedEdge[258, 286] -> 
             RGBColor[
              0.28052613048445796`, 0.4092765484606139, 0.9393932710602128], 
             UndirectedEdge[101, 197] -> 
             RGBColor[
              0.816834867392223, 0.8565183997567056, 0.9207499871177253], 
             UndirectedEdge[53, 271] -> 
             RGBColor[
              0.21925630560640996`, 0.3477826572179991, 0.935797694292424], 
             UndirectedEdge[22, 70] -> 
             RGBColor[
              0.19915563229546623`, 0.32665557511190024`, 0.9346529906836472],
              UndirectedEdge[76, 258] -> 
             RGBColor[
              0.3335396370029857, 0.4633170022075566, 0.942473828625678], 
             UndirectedEdge[232, 297] -> 
             RGBColor[
              0.18995045311417683`, 0.3169803481502954, 0.934128769347115], 
             UndirectedEdge[178, 261] -> 
             RGBColor[
              0.2518738885698846, 0.38206580498681714`, 0.9376552173888041], 
             UndirectedEdge[155, 227] -> 
             RGBColor[
              0.9395091625151377, 0.7978810172888317, 0.27018585613847523`], 
             UndirectedEdge[178, 182] -> 
             RGBColor[
              0.2566774713547828, 0.3871146750584845, 0.9379287743221401], 
             UndirectedEdge[5, 51] -> 
             RGBColor[
              0.8911547141993119, 0.8831957888790658, 0.6618581652210298], 
             UndirectedEdge[110, 295] -> 
             RGBColor[
              0.19142001506063305`, 0.31852495093162986`, 0.9342124587259435],
              UndirectedEdge[186, 286] -> 
             RGBColor[
              0.2070033670926693, 0.3349040419588854, 0.9350999075706646], 
             UndirectedEdge[34, 270] -> 
             RGBColor[
              0.19826604624820576`, 0.32572056377321634`, 0.9346023300742803],
              UndirectedEdge[4, 8] -> 
             RGBColor[
              0.21250294836697825`, 0.34068445057177643`, 0.935413100588335], 
             UndirectedEdge[69, 166] -> 
             RGBColor[
              0.19683162728000528`, 0.3242128984902222, 0.9345206420360739], 
             UndirectedEdge[25, 176] -> 
             RGBColor[
              0.19265413404658233`, 0.31982208823352565`, 0.9342827399764779],
              UndirectedEdge[32, 149] -> 
             RGBColor[
              0.9415899849052779, 0.803780404688222, 0.5442097809326024], 
             UndirectedEdge[16, 153] -> 
             RGBColor[
              0.233929772423327, 0.36320540119410966`, 0.9366333265201985], 
             UndirectedEdge[169, 299] -> 
             RGBColor[
              0.7473755866979517, 0.32646116929742564`, 0.43103187403331167`],
              UndirectedEdge[187, 229] -> 
             RGBColor[
              0.22122626051320093`, 0.3498532047273915, 0.9359098803100787], 
             UndirectedEdge[15, 82] -> 
             RGBColor[
              0.43590786027701234`, 0.5429784897554615, 0.9503684349274593], 
             UndirectedEdge[44, 280] -> 
             RGBColor[
              0.2891161135986471, 0.42051878582686586`, 0.939801406401479], 
             UndirectedEdge[186, 265] -> 
             RGBColor[
              0.2079159163966799, 0.33586318913636815`, 0.9351518759035322], 
             UndirectedEdge[117, 265] -> 
             RGBColor[
              0.2041128319271811, 0.33186590622944256`, 0.9349352958691536], 
             UndirectedEdge[106, 162] -> 
             RGBColor[
              0.9266044419072905, 0.9416892870110949, 0.8898655994395634], 
             UndirectedEdge[9, 146] -> 
             RGBColor[
              0.1994945649800457, 0.3270118148529666, 0.9346722923986279], 
             UndirectedEdge[130, 294] -> 
             RGBColor[
              0.723926300807685, 0.6611320656306849, 0.6022559472314186], 
             UndirectedEdge[13, 53] -> 
             RGBColor[
              0.27458306643531494`, 0.40366544683013694`, 0.9390315559482794],
              UndirectedEdge[34, 57] -> 
             RGBColor[
              0.18168430472921848`, 0.3082921020936258, 0.9336580244252622], 
             UndirectedEdge[25, 144] -> 
             RGBColor[
              0.19437777007737006`, 0.3216337389867199, 0.9343808984985402], 
             UndirectedEdge[206, 283] -> 
             RGBColor[
              0.26412169083739256`, 0.3949390217254835, 0.938352711608939], 
             UndirectedEdge[107, 273] -> 
             RGBColor[
              0.32370272298268776`, 0.4483418094779742, 0.9420833765839904], 
             UndirectedEdge[64, 85] -> 
             RGBColor[
              0.2337265149567007, 0.3629917647094177, 0.9366217513081667], 
             UndirectedEdge[175, 224] -> 
             RGBColor[
              0.19563816085584113`, 0.3229584896082839, 0.9344526758887932], 
             UndirectedEdge[68, 163] -> 
             RGBColor[
              0.7490034970690254, 0.8039812828492927, 0.9757174701655251], 
             UndirectedEdge[7, 237] -> 
             RGBColor[
              0.8628230044438239, 0.4470001203594073, 0.4441941754294244], 
             UndirectedEdge[76, 126] -> 
             RGBColor[
              0.2752030578474213, 0.40490613819779253`, 0.9390452958624365], 
             UndirectedEdge[30, 236] -> 
             RGBColor[
              0.2403636886171835, 0.3699678550477007, 0.9369997285293126], 
             UndirectedEdge[7, 269] -> 
             RGBColor[
              0.9557422920381128, 0.9373302721362289, 0.6697719934605999], 
             UndirectedEdge[237, 256] -> 
             RGBColor[
              0.8226924771507464, 0.17542990005333894`, 0.16936364778802923`],
              UndirectedEdge[106, 290] -> 
             RGBColor[
              0.9041357720440601, 0.8589662618992862, 0.6312127071179277], 
             UndirectedEdge[180, 288] -> 
             RGBColor[
              0.20187497125250775`, 0.32951377277179905`, 0.9348078530143491],
              UndirectedEdge[201, 237] -> 
             RGBColor[
              0.8386009494484636, 0.2977093892706047, 0.18459761882637282`], 
             UndirectedEdge[10, 73] -> 
             RGBColor[
              0.18653587436616526`, 0.31339140938933835`, 0.9339343141388322],
              UndirectedEdge[18, 175] -> 
             RGBColor[
              0.19129167307218187`, 0.3183900553644156, 0.9342051498395663], 
             UndirectedEdge[57, 295] -> 
             RGBColor[
              0.1882992367969673, 0.3152448151077469, 0.9340347350206055], 
             UndirectedEdge[71, 161] -> 
             RGBColor[
              0.2124857473818974, 0.34066637124585103`, 0.9354121210176813], 
             UndirectedEdge[218, 220] -> 
             RGBColor[
              0.6501395047208716, 0.7189888396444919, 0.9414344110066938], 
             UndirectedEdge[192, 248] -> 
             RGBColor[
              0.27628801069729353`, 0.4057044446902951, 0.9391196063656152], 
             UndirectedEdge[23, 24] -> 
             RGBColor[
              0.956555334204736, 0.8626596651038085, 0.541866983332811], 
             UndirectedEdge[39, 195] -> 
             RGBColor[
              0.1927241486561343, 0.3198956780273474, 0.9342867272049146], 
             UndirectedEdge[79, 232] -> 
             RGBColor[
              0.1855242988552152, 0.31232817938973806`, 0.9338767064099756], 
             UndirectedEdge[12, 154] -> 
             RGBColor[
              0.46345887168868094`, 0.5746523637299171, 0.9510821144780158], 
             UndirectedEdge[106, 155] -> 
             RGBColor[
              0.8940872222095038, 0.8191271102860018, 0.6231274080512639], 
             UndirectedEdge[95, 103] -> 
             RGBColor[
              0.35444301317126903`, 0.47946333163225574`, 0.9438775064114789],
              UndirectedEdge[3, 228] -> 
             RGBColor[
              0.690237715965832, 0.7545004457298199, 0.955381119587516], 
             UndirectedEdge[81, 293] -> 
             RGBColor[
              0.8946118304119881, 0.61433876058075, 0.23377386680638917`], 
             UndirectedEdge[95, 145] -> 
             RGBColor[
              0.5762301255781173, 0.6573426269684071, 0.963331889789669], 
             UndirectedEdge[39, 153] -> 
             RGBColor[
              0.2113966935997263, 0.3395217066707913, 0.9353501010158973], 
             UndirectedEdge[39, 90] -> 
             RGBColor[
              0.20870014958760652`, 0.3366874679432882, 0.9351965368235865], 
             UndirectedEdge[120, 141] -> 
             RGBColor[
              0.28646903998749706`, 0.4184275025860159, 0.939625360083097], 
             UndirectedEdge[102, 172] -> 
             RGBColor[
              0.19138970866876043`, 0.3184930969922355, 0.9342107328217606], 
             UndirectedEdge[155, 194] -> 
             RGBColor[
              0.8061596900222359, 0.7500989808439875, 0.6144534337056413], 
             UndirectedEdge[53, 251] -> 
             RGBColor[
              0.25074234215186236`, 0.3808764779572891, 0.9375907774942707], 
             UndirectedEdge[128, 243] -> 
             RGBColor[
              0.8924326724712802, 0.5606456544038871, 0.4131747565461786], 
             UndirectedEdge[72, 87] -> 
             RGBColor[
              0.8839929875554634, 0.4806546749192594, 0.28239629153508916`], 
             UndirectedEdge[76, 90] -> 
             RGBColor[
              0.2712969166915207, 0.40080053617928724`, 0.938822846902226], 
             UndirectedEdge[3, 106] -> 
             RGBColor[
              0.9080394881357245, 0.9290324924917327, 0.9745333831638314], 
             UndirectedEdge[104, 243] -> 
             RGBColor[
              0.6612526622734278, 0.7268613939195354, 0.9003802288706013], 
             UndirectedEdge[34, 217] -> 
             RGBColor[
              0.1918655955426979, 0.3189932842697143, 0.9342378338752199], 
             UndirectedEdge[31, 37] -> 
             RGBColor[
              0.32310841403988205`, 0.4466841095652183, 0.9420873563531128], 
             UndirectedEdge[64, 249] -> 
             RGBColor[
              0.22138061658703678`, 0.35001544274773333`, 0.9359186706601341],
              UndirectedEdge[89, 188] -> 
             RGBColor[
              0.3683043792841372, 0.49342847464473716`, 0.9446890072625783], 
             UndirectedEdge[179, 269] -> 
             RGBColor[
              0.7479608310759376, 0.7722887789067958, 0.6529117994592061], 
             UndirectedEdge[213, 249] -> 
             RGBColor[
              0.2049158790401142, 0.33270995966126304`, 0.9349810282142335], 
             UndirectedEdge[44, 252] -> 
             RGBColor[
              0.27708079783829526`, 0.4078689058796433, 0.9391160129735812], 
             UndirectedEdge[149, 198] -> 
             RGBColor[
              0.93004743411723, 0.7957508352156739, 0.5896702154371328], 
             UndirectedEdge[158, 214] -> 
             RGBColor[
              0.19688801935015837`, 0.3242721701314169, 0.9345238534810445], 
             UndirectedEdge[202, 216] -> 
             RGBColor[
              0.8665350630405979, 0.48684871744288943`, 0.21034592388715595`],
              UndirectedEdge[78, 209] -> 
             RGBColor[
              0.18729352981200414`, 0.31418775330104487`, 0.933977461495622], 
             UndirectedEdge[77, 265] -> 
             RGBColor[
              0.31824926646414226`, 0.4421191756626833, 0.9417907774257306], 
             UndirectedEdge[44, 204] -> 
             RGBColor[
              0.39991382818369614`, 0.5199845367377941, 0.9469303798325985], 
             UndirectedEdge[54, 102] -> 
             RGBColor[
              0.218116116310074, 0.34658424597537324`, 0.9357327621987566], 
             UndirectedEdge[2, 253] -> 
             RGBColor[
              0.19522054856906235`, 0.32251955261673115`, 0.9344288934868631],
              UndirectedEdge[40, 86] -> 
             RGBColor[
              0.6417053553097174, 0.7192862820416126, 0.9654274840700409], 
             UndirectedEdge[75, 165] -> 
             RGBColor[
              0.27536181000482485`, 0.4045171817075533, 0.9390746876755028], 
             UndirectedEdge[73, 100] -> 
             RGBColor[
              0.1816658245926822, 0.30827267829841776`, 0.9336569720088254], 
             UndirectedEdge[50, 206] -> 
             RGBColor[
              0.20212300857950383`, 0.32977447572894675`, 0.9348219783731833],
              UndirectedEdge[32, 277] -> 
             RGBColor[
              0.9903436750031767, 0.9883158760637997, 0.6672952315344995], 
             UndirectedEdge[156, 251] -> 
             RGBColor[
              0.3400494072237743, 0.46681610621407393`, 0.942966956843591], 
             UndirectedEdge[31, 44] -> 
             RGBColor[
              0.36793393060354135`, 0.4931076106168971, 0.9446654026002257], 
             UndirectedEdge[80, 92] -> 
             RGBColor[
              0.8806392624507501, 0.47575847385330106`, 0.24262510747050564`],
              UndirectedEdge[11, 149] -> 
             RGBColor[
              0.7136593076403137, 0.6245896318315118, 0.5954018551660852], 
             UndirectedEdge[103, 145] -> 
             RGBColor[
              0.643116750417353, 0.7172355839626725, 0.9675221132384173], 
             UndirectedEdge[150, 274] -> 
             RGBColor[
              0.6852279869066359, 0.622788647378854, 0.5976147565045411], 
             UndirectedEdge[13, 156] -> 
             RGBColor[
              0.3638901315072269, 0.4896050750869218, 0.9444077352975997], 
             UndirectedEdge[84, 278] -> 
             RGBColor[
              0.19404895120727791`, 0.32128812950593255`, 0.9343621727503324],
              UndirectedEdge[150, 293] -> 
             RGBColor[
              0.9035840903340573, 0.6541630034729253, 0.24121312079051388`], 
             UndirectedEdge[52, 137] -> 
             RGBColor[
              0.23013360981142927`, 0.35921539359839394`, 0.9364171406753703],
              UndirectedEdge[41, 152] -> 
             RGBColor[
              0.1855570941414352, 0.31236264931489655`, 0.9338785740530094], 
             UndirectedEdge[177, 279] -> 
             RGBColor[
              0.2643192230897936, 0.3951466406470252, 0.9383639607784904], 
             UndirectedEdge[108, 279] -> 
             RGBColor[
              0.23867609661587075`, 0.3681940888548081, 0.9369036226614065], 
             UndirectedEdge[161, 279] -> 
             RGBColor[
              0.2191606879449377, 0.34768215699328187`, 0.9357922490080568], 
             UndirectedEdge[89, 260] -> 
             RGBColor[
              0.3194559514168667, 0.4464420991230162, 0.9417476517079721], 
             UndirectedEdge[63, 161] -> 
             RGBColor[
              0.19226866060006637`, 0.3194169312008093, 0.9342607878339557], 
             UndirectedEdge[110, 148] -> 
             RGBColor[
              0.2161072361235734, 0.34447278552900074`, 0.9356183594440073], 
             UndirectedEdge[200, 228] -> 
             RGBColor[
              0.3959136886863399, 0.5173422707646859, 0.946448248043733], 
             UndirectedEdge[67, 118] -> 
             RGBColor[
              0.18382399790050605`, 0.31054105528103165`, 0.9337798767859746],
              UndirectedEdge[140, 203] -> 
             RGBColor[
              0.8572543639542931, 0.40696085899210804`, 0.43991699948682417`],
              UndirectedEdge[144, 231] -> 
             RGBColor[
              0.21441031983489064`, 0.34268921891888826`, 0.9355217225717294],
              UndirectedEdge[101, 149] -> 
             RGBColor[
              0.7714159149498363, 0.6714029284596804, 0.6000007099012994], 
             UndirectedEdge[131, 284] -> 
             RGBColor[
              0.23518277089129241`, 0.36452238202863274`, 0.9367046829293041],
              UndirectedEdge[157, 275] -> 
             RGBColor[
              0.18135642915031058`, 0.30794748407168115`, 0.9336393523960919],
              UndirectedEdge[113, 144] -> 
             RGBColor[
              0.23263625868922916`, 0.36184583624606526`, 0.9365596628266237],
              UndirectedEdge[48, 73] -> 
             RGBColor[
              0.187739347830093, 0.31465633630455114`, 0.9340028501722235], 
             UndirectedEdge[35, 183] -> 
             RGBColor[
              0.19956688605797046`, 0.32708782889128674`, 0.9346764109770263],
              UndirectedEdge[93, 107] -> 
             RGBColor[
              0.32480267899707094`, 0.44949793299033025`, 0.9421460174517705],
              UndirectedEdge[23, 226] -> 
             RGBColor[
              0.9878018957897885, 0.9892237846791677, 0.8518176846523693], 
             UndirectedEdge[200, 211] -> 
             RGBColor[
              0.31815152117452855`, 0.44647400293362227`, 0.9416219977306357],
              UndirectedEdge[87, 227] -> 
             RGBColor[
              0.9729262687384115, 0.9189743901826695, 0.3881944192270413], 
             UndirectedEdge[223, 278] -> 
             RGBColor[
              0.1910601770666856, 0.31814673838494456`, 0.9341919664845209], 
             UndirectedEdge[182, 229] -> 
             RGBColor[
              0.23602797859295035`, 0.36541074891233866`, 0.9367528162575407],
              UndirectedEdge[79, 221] -> 
             RGBColor[
              0.18466822464384994`, 0.3114283911153532, 0.9338279542500865], 
             UndirectedEdge[115, 228] -> 
             RGBColor[
              0.3889928994532643, 0.5113478309799768, 0.946007261473615], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.3382052536051789, 0.4616299042238716, 0.9429808558058818], 
             UndirectedEdge[9, 47] -> 
             RGBColor[
              0.1915298565644043, 0.31864040131644705`, 0.9342187140370874], 
             UndirectedEdge[18, 224] -> 
             RGBColor[
              0.2043212377981297, 0.33208495401350496`, 0.9349471642751953], 
             UndirectedEdge[194, 291] -> 
             RGBColor[
              0.8064401830754907, 0.8495804260163464, 0.9811128108192658], 
             UndirectedEdge[5, 198] -> 
             RGBColor[
              0.967801874456065, 0.9434968913498611, 0.6433562360480443], 
             UndirectedEdge[49, 172] -> 
             RGBColor[
              0.20010293929950806`, 0.3276512548358813, 0.9347069384161122], 
             UndirectedEdge[162, 228] -> 
             RGBColor[
              0.7088026697373979, 0.7671572402491821, 0.8707133358632482], 
             UndirectedEdge[100, 161] -> 
             RGBColor[
              0.1911587437240086, 0.318250338191278, 0.9341975797098391], 
             UndirectedEdge[174, 235] -> 
             RGBColor[
              0.3208493079592518, 0.4453409740728014, 0.9419209416251387], 
             UndirectedEdge[14, 67] -> 
             RGBColor[
              0.17956042552731538`, 0.30605977039070653`, 0.9335370726467116],
              UndirectedEdge[190, 199] -> 
             RGBColor[
              0.2014046269978636, 0.3290194111386199, 0.9347810676048591], 
             UndirectedEdge[160, 288] -> 
             RGBColor[
              0.20231487113075944`, 0.32997613543510473`, 0.934832904661642], 
             UndirectedEdge[33, 275] -> 
             RGBColor[
              0.19034059746125545`, 0.31739041459565537`, 0.9341509874905143],
              UndirectedEdge[109, 218] -> 
             RGBColor[
              0.9800003657513711, 0.9831729301139916, 0.8546124313811914], 
             UndirectedEdge[231, 264] -> 
             RGBColor[
              0.2636953407278438, 0.39449090072818943`, 0.9383284316009286], 
             UndirectedEdge[221, 230] -> 
             RGBColor[
              0.18914056303198, 0.3161291023239095, 0.9340826473050587], 
             UndirectedEdge[45, 236] -> 
             RGBColor[
              0.26568284234196243`, 0.3965798909395088, 0.9384416168776075], 
             UndirectedEdge[279, 280] -> 
             RGBColor[
              0.24933981979070619`, 0.37940233803066026`, 0.9375109059206487],
              UndirectedEdge[71, 252] -> 
             RGBColor[
              0.23062956346731406`, 0.3597366723360068, 0.9364453845023752], 
             UndirectedEdge[230, 296] -> 
             RGBColor[
              0.18964632804218584`, 0.3166606934169896, 0.9341114498741778], 
             UndirectedEdge[27, 154] -> 
             RGBColor[
              0.7335695588322665, 0.7563490417801518, 0.6454543011351679], 
             UndirectedEdge[5, 101] -> 
             RGBColor[
              0.8091703552886713, 0.8191489845938676, 0.6536867305122107], 
             UndirectedEdge[68, 143] -> 
             RGBColor[
              0.5918755827726521, 0.672270845358494, 0.9644525615859105], 
             UndirectedEdge[58, 221] -> 
             RGBColor[
              0.18866826221874242`, 0.3156326842235957, 0.9340557504724514], 
             UndirectedEdge[85, 249] -> 
             RGBColor[
              0.21980259172524277`, 0.34835683856543287`, 0.9358288044787336],
              UndirectedEdge[26, 54] -> 
             RGBColor[
              0.23656624471631046`, 0.3659765007360335, 0.9367834697169728], 
             UndirectedEdge[269, 282] -> 
             RGBColor[
              0.7068985223577822, 0.7386080961972126, 0.6497743968433352], 
             UndirectedEdge[24, 210] -> 
             RGBColor[
              0.6977215322082554, 0.6587130381270785, 0.6045341943932525], 
             UndirectedEdge[144, 288] -> 
             RGBColor[
              0.20325262345727604`, 0.33096177258720527`, 0.9348863082693568],
              UndirectedEdge[182, 199] -> 
             RGBColor[
              0.22636918605193562`, 0.35525874554891435`, 0.936202762311233], 
             UndirectedEdge[35, 224] -> 
             RGBColor[
              0.20753059097457632`, 0.33545818768669444`, 0.9351299321907813],
              UndirectedEdge[161, 280] -> 
             RGBColor[
              0.2318337811627876, 0.36100238148576125`, 0.9365139629186521], 
             UndirectedEdge[27, 42] -> 
             RGBColor[
              0.8816836574994876, 0.49667817991020385`, 0.23487588344630034`],
              UndirectedEdge[13, 273] -> 
             RGBColor[
              0.2861094453581625, 0.4157804018926833, 0.9396879661761859], 
             UndirectedEdge[167, 202] -> 
             RGBColor[
              0.8802744981433329, 0.5485728040784057, 0.22177612422766013`], 
             UndirectedEdge[117, 207] -> 
             RGBColor[
              0.18539878883552113`, 0.3121962604012447, 0.9338695588000294], 
             UndirectedEdge[33, 248] -> 
             RGBColor[
              0.21123257741316134`, 0.3393492101531443, 0.9353407548418606], 
             UndirectedEdge[23, 210] -> 
             RGBColor[
              0.7305128529889463, 0.7859159553283347, 0.8888842381324313], 
             UndirectedEdge[54, 111] -> 
             RGBColor[
              0.4291203016109882, 0.5357529458181629, 0.9499902123364491], 
             UndirectedEdge[30, 267] -> 
             RGBColor[
              0.22275125819820335`, 0.35145607398476686`, 0.9359967266722076],
              UndirectedEdge[170, 199] -> 
             RGBColor[
              0.19798561422584082`, 0.3254258119372937, 0.9345863598854686], 
             UndirectedEdge[169, 200] -> 
             RGBColor[
              0.4851546386974715, 0.5905268621408066, 0.9532706039694929], 
             UndirectedEdge[137, 278] -> 
             RGBColor[
              0.23108207251171536`, 0.3602122880324031, 0.9364711542230267], 
             UndirectedEdge[92, 150] -> 
             RGBColor[
              0.856839597699243, 0.38590456876888285`, 0.2000192899179641], 
             UndirectedEdge[68, 185] -> 
             RGBColor[
              0.7032065232894661, 0.766801236404889, 0.9721121646297556], 
             UndirectedEdge[26, 102] -> 
             RGBColor[
              0.21064547425155244`, 0.3387321275058029, 0.9353073201853483], 
             UndirectedEdge[270, 271] -> 
             RGBColor[
              0.217737181833685, 0.3461859618148549, 0.9357111824409096], 
             UndirectedEdge[169, 202] -> 
             RGBColor[
              0.7792934779313432, 0.5546715851773875, 0.4609259309301712], 
             UndirectedEdge[17, 97] -> 
             RGBColor[
              0.5762606506463335, 0.665813185958444, 0.9604600233988309], 
             UndirectedEdge[46, 158] -> 
             RGBColor[
              0.1988271914603046, 0.32631036296979365`, 0.9346342864639694], 
             UndirectedEdge[98, 285] -> 
             RGBColor[
              0.18936585526810354`, 0.31636589874842813`, 0.9340954773646161],
              UndirectedEdge[77, 168] -> 
             RGBColor[
              0.4070970567080353, 0.527028742052658, 0.9471608423650113], 
             UndirectedEdge[242, 268] -> 
             RGBColor[0.1929658134251674, 0.3201496830220325, 0.934300489656],
              UndirectedEdge[115, 134] -> 
             RGBColor[
              0.29826389721871693`, 0.4268505977105114, 0.940442569105771], 
             UndirectedEdge[99, 284] -> 
             RGBColor[
              0.2183159570292897, 0.34679429124190236`, 0.9357441428320781], 
             UndirectedEdge[204, 283] -> 
             RGBColor[
              0.3947145595034514, 0.515210734660812, 0.9466089897806659], 
             UndirectedEdge[77, 167] -> 
             RGBColor[
              0.6607323580564698, 0.6022582598273698, 0.5960819189651536], 
             UndirectedEdge[227, 290] -> 
             RGBColor[
              0.9495577123496941, 0.837720168902116, 0.27827115520513895`], 
             UndirectedEdge[60, 145] -> 
             RGBColor[
              0.5760856373176906, 0.6571907606456139, 0.9633236613969889], 
             UndirectedEdge[32, 125] -> 
             RGBColor[
              0.8860217022210372, 0.5107410708294523, 0.40552418405157087`], 
             UndirectedEdge[15, 60] -> 
             RGBColor[
              0.27282174145117777`, 0.4040833265356404, 0.9388481666208225], 
             UndirectedEdge[30, 260] -> 
             RGBColor[
              0.25373200019445147`, 0.38401879811531836`, 0.9377610340969933],
              UndirectedEdge[42, 80] -> 
             RGBColor[
              0.8846726257638872, 0.5067606717091464, 0.24648746073419803`], 
             UndirectedEdge[97, 130] -> 
             RGBColor[
              0.6803306714803544, 0.6256180746890865, 0.5988573985297044], 
             UndirectedEdge[65, 211] -> 
             RGBColor[
              0.3240980577045407, 0.45162459399430244`, 0.9420009057800123], 
             UndirectedEdge[1, 256] -> 
             RGBColor[
              0.8184383049744752, 0.1427304685163843, 0.1652898477076317], 
             UndirectedEdge[5, 128] -> 
             RGBColor[
              0.8869643989845882, 0.5355844211628931, 0.24107549480357243`], 
             UndirectedEdge[125, 256] -> 
             RGBColor[
              0.8294390160964316, 0.2272867547420918, 0.17582414110154324`], 
             UndirectedEdge[39, 239] -> 
             RGBColor[
              0.2196501555680895, 0.3481966184992542, 0.9358201234650929], 
             UndirectedEdge[156, 269] -> 
             RGBColor[
              0.6838282108058124, 0.7186257518784704, 0.6483043769915192], 
             UndirectedEdge[78, 170] -> 
             RGBColor[
              0.19585393495458225`, 0.32318528186692885`, 0.9344649639045073],
              UndirectedEdge[23, 155] -> 
             RGBColor[
              0.9578302462805677, 0.8677142666452164, 0.5428928075150579], 
             UndirectedEdge[127, 251] -> 
             RGBColor[
              0.31722126846433096`, 0.4470435197962596, 0.9415123680279698], 
             UndirectedEdge[241, 290] -> 
             RGBColor[
              0.9662675720592777, 0.9068871357048387, 0.5776802589012907], 
             UndirectedEdge[85, 234] -> 
             RGBColor[
              0.21315182719847248`, 0.341366463364971, 0.9354500532778585], 
             UndirectedEdge[270, 289] -> 
             RGBColor[
              0.22814186813803294`, 0.35712194681593845`, 0.9363037139335881],
              UndirectedEdge[69, 258] -> 
             RGBColor[
              0.273865191252875, 0.4022754790002804, 0.9390139404249507], 
             UndirectedEdge[52, 289] -> 
             RGBColor[
              0.22108882372044908`, 0.3497087499442134, 0.9359020534880509], 
             UndirectedEdge[47, 170] -> 
             RGBColor[
              0.1908380369178425, 0.3179132550040116, 0.9341793159316711], 
             UndirectedEdge[72, 241] -> 
             RGBColor[
              0.8816517065059561, 0.48091378172749166`, 0.4104081640603793], 
             UndirectedEdge[115, 210] -> 
             RGBColor[
              0.4117038936977402, 0.5305204071243743, 0.9475921355741658], 
             UndirectedEdge[166, 239] -> 
             RGBColor[
              0.21183524129599424`, 0.3399826481050988, 0.9353750756584267], 
             UndirectedEdge[180, 215] -> 
             RGBColor[
              0.2098131605219987, 0.33785731300430355`, 0.9352599211497481], 
             UndirectedEdge[51, 254] -> 
             RGBColor[
              0.5650392887707011, 0.6515224922377361, 0.9616798049124837], 
             UndirectedEdge[109, 227] -> 
             RGBColor[
              0.9727578246301442, 0.9207456642506578, 0.5248021537611475], 
             UndirectedEdge[203, 255] -> 
             RGBColor[
              0.651571481892223, 0.7220382969334023, 0.9679291557478935], 
             UndirectedEdge[257, 272] -> 
             RGBColor[
              0.18158199985616474`, 0.30818457318554265`, 0.9336521983140883],
              UndirectedEdge[32, 128] -> 
             RGBColor[
              0.8925188906026889, 0.5606813078169296, 0.41174589898336517`], 
             UndirectedEdge[39, 76] -> 
             RGBColor[
              0.26432098730221126`, 0.39346839209165385`, 0.9384255780434674],
              UndirectedEdge[144, 221] -> 
             RGBColor[
              0.19191775891044247`, 0.3190481112765624, 0.9342408045018441], 
             UndirectedEdge[165, 262] -> 
             RGBColor[
              0.26081704104435255`, 0.39146562526609985`, 0.9381645166920165],
              UndirectedEdge[101, 226] -> 
             RGBColor[
              0.8167925796772653, 0.8565009126998259, 0.9214508039916728], 
             UndirectedEdge[56, 191] -> 
             RGBColor[
              0.21336670196225918`, 0.34159231036555776`, 0.9354622900777774],
              UndirectedEdge[63, 71] -> 
             RGBColor[
              0.20309975866494467`, 0.3308011019982774, 0.9348776028455769], 
             UndirectedEdge[137, 289] -> 
             RGBColor[
              0.25248937634424146`, 0.382712721661845, 0.9376902685070212], 
             UndirectedEdge[148, 295] -> 
             RGBColor[
              0.2216100316720449, 0.3502565725478334, 0.9359317355098362], 
             UndirectedEdge[10, 119] -> 
             RGBColor[
              0.1856272606689936, 0.3124363987841752, 0.9338825699329518], 
             UndirectedEdge[115, 231] -> 
             RGBColor[
              0.29145473297171365`, 0.41969373436096236`, 0.9400547972751598],
              UndirectedEdge[33, 171] -> 
             RGBColor[
              0.189827260881899, 0.31685086530333273`, 0.9341217537317332], 
             UndirectedEdge[173, 234] -> 
             RGBColor[
              0.19772105404463286`, 0.3251477424127598, 0.9345712935745305], 
             UndirectedEdge[69, 173] -> 
             RGBColor[
              0.2044279033465657, 0.3321970662678976, 0.9349532387203812], 
             UndirectedEdge[4, 263] -> 
             RGBColor[
              0.21521347097412877`, 0.3435333816889509, 0.9355674608409534], 
             UndirectedEdge[134, 160] -> 
             RGBColor[
              0.22028173175537732`, 0.3488604451163368, 0.9358560907946256], 
             UndirectedEdge[7, 205] -> 
             RGBColor[
              0.6553396994405775, 0.7252302520430189, 0.9671201357047186], 
             UndirectedEdge[23, 106] -> 
             RGBColor[
              0.9256036309143629, 0.94127542594585, 0.906451627608196], 
             UndirectedEdge[45, 96] -> 
             RGBColor[
              0.2504426073839444, 0.3805614377119254, 0.9375737080426556], 
             UndirectedEdge[65, 210] -> 
             RGBColor[
              0.424571219460828, 0.5416654379697635, 0.9484120301936603], 
             UndirectedEdge[138, 211] -> 
             RGBColor[
              0.25101026684268113`, 0.38115808379474614`, 0.9376060354090536],
              UndirectedEdge[72, 210] -> 
             RGBColor[
              0.7101699878788666, 0.345393552112113, 0.4343848698876275], 
             UndirectedEdge[37, 41] -> 
             RGBColor[
              0.20758147265742513`, 0.3355116675614536, 0.9351328298273469], 
             UndirectedEdge[52, 88] -> 
             RGBColor[
              0.21079575741608964`, 0.3388900846402345, 0.9353158785892447], 
             UndirectedEdge[157, 285] -> 
             RGBColor[
              0.1911088793151014, 0.31819792753593046`, 0.9341947400055196], 
             UndirectedEdge[135, 265] -> 
             RGBColor[
              0.21789617448484386`, 0.3463530731719392, 0.9357202368371844], 
             UndirectedEdge[17, 42] -> 
             RGBColor[
              0.7929575364765972, 0.44951011621237846`, 0.44612850273328253`],
              UndirectedEdge[242, 250] -> 
             RGBColor[
              0.18176798085569046`, 0.30838005100792065`, 0.933662789656877], 
             UndirectedEdge[81, 202] -> 
             RGBColor[
              0.8742021218716074, 0.5216630409074182, 0.2167435057125596], 
             UndirectedEdge[229, 259] -> 
             RGBColor[
              0.2014368212026378, 0.32905324928906804`, 0.934782901017194], 
             UndirectedEdge[40, 81] -> 
             RGBColor[
              0.7893492688527326, 0.6740607768287987, 0.5995695817860118], 
             UndirectedEdge[100, 119] -> 
             RGBColor[
              0.1807572108955105, 0.3073176676932546, 0.933605227802945], 
             UndirectedEdge[81, 269] -> 
             RGBColor[
              0.931314896123058, 0.7560543834090069, 0.28986513111217527`], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.8156793803955554, 0.4095785742701399, 0.4412265840334828], 
             UndirectedEdge[180, 233] -> 
             RGBColor[
              0.20014010875548707`, 0.32769032229079487`, 0.9347090551616429],
              UndirectedEdge[33, 184] -> 
             RGBColor[
              0.1959981041281816, 0.3233368128092353, 0.9344731741256647], 
             UndirectedEdge[103, 168] -> 
             RGBColor[
              0.41087052923769096`, 0.5302971342976018, 0.9474012846978503], 
             UndirectedEdge[49, 238] -> 
             RGBColor[
              0.19853266531396374`, 0.3260007973159532, 0.9346175136356476], 
             UndirectedEdge[97, 120] -> 
             RGBColor[
              0.3639742346570427, 0.4869360497143149, 0.944513487615392], 
             UndirectedEdge[117, 212] -> 
             RGBColor[
              0.20943922968905518`, 0.3374642879902957, 0.935238626341993], 
             UndirectedEdge[270, 278] -> 
             RGBColor[
              0.20673456430550685`, 0.3346215131864966, 0.9350845996495938], 
             UndirectedEdge[26, 165] -> 
             RGBColor[
              0.2234449255941841, 0.3521851623989958, 0.9360362300042198], 
             UndirectedEdge[65, 70] -> 
             RGBColor[
              0.2936166091660087, 0.41958665894484415`, 0.940265032379005], 
             UndirectedEdge[56, 223] -> 
             RGBColor[
              0.19042353178656807`, 0.3174775838298989, 0.9341557104776503], 
             UndirectedEdge[207, 212] -> 
             RGBColor[
              0.20932819464730518`, 0.33734758312138824`, 0.935232303060627], 
             UndirectedEdge[171, 184] -> 
             RGBColor[
              0.1853189372548359, 0.31211233132706184`, 0.9338650113706392], 
             UndirectedEdge[32, 205] -> 
             RGBColor[
              0.6800179376878698, 0.7430563957149572, 0.8994244086676673], 
             UndirectedEdge[23, 31] -> 
             RGBColor[
              0.7044976010018857, 0.7638813972041334, 0.8870888196503636], 
             UndirectedEdge[235, 274] -> 
             RGBColor[
              0.43577020330018756`, 0.5515998272739158, 0.9490608562281224], 
             UndirectedEdge[178, 199] -> 
             RGBColor[
              0.2287030477407748, 0.357711782159262, 0.9363356722817735], 
             UndirectedEdge[117, 158] -> 
             RGBColor[
              0.189227738636957, 0.3162207294119929, 0.9340876118267976], 
             UndirectedEdge[112, 190] -> 
             RGBColor[
              0.19682291342577818`, 0.3242037396769393, 0.9345201457949667], 
             UndirectedEdge[64, 213] -> 
             RGBColor[
              0.21883980227157213`, 0.34734488580524786`, 0.9357739750436664],
              UndirectedEdge[127, 205] -> 
             RGBColor[
              0.3605974794488338, 0.48675314536744607`, 0.9441979304200168], 
             UndirectedEdge[121, 263] -> 
             RGBColor[
              0.2176693590934683, 0.34611467581467703`, 0.935707320036189], 
             UndirectedEdge[14, 213] -> 
             RGBColor[
              0.19128445788964016`, 0.31838247175009526`, 0.9342047389455943],
              UndirectedEdge[109, 111] -> 
             RGBColor[
              0.8035074391264327, 0.8444862586698714, 0.8657863480729937], 
             UndirectedEdge[55, 108] -> 
             RGBColor[
              0.22141119699588285`, 0.35004758469634045`, 0.9359204121691784],
              UndirectedEdge[40, 162] -> 
             RGBColor[
              0.8402909601650888, 0.8739220660440041, 0.881352498558146], 
             UndirectedEdge[15, 225] -> 
             RGBColor[
              0.2429863506332136, 0.37272443911292436`, 0.9371490852512447], 
             UndirectedEdge[31, 59] -> 
             RGBColor[
              0.7023281164542653, 0.7629842595904825, 0.9230427930504692], 
             UndirectedEdge[210, 227] -> 
             RGBColor[
              0.7121917692235163, 0.7160827059719499, 0.6161772867558488], 
             UndirectedEdge[52, 93] -> 
             RGBColor[
              0.21993156031517644`, 0.348492392730534, 0.9358361490491385], 
             UndirectedEdge[32, 293] -> 
             RGBColor[
              0.9437174645743351, 0.8134407929799102, 0.5459850021177625], 
             UndirectedEdge[99, 209] -> 
             RGBColor[
              0.18806492725905072`, 0.31499854092731383`, 0.934021391439051], 
             UndirectedEdge[201, 299] -> 
             RGBColor[
              0.8364740278506779, 0.2813609378470366, 0.18256087630231885`], 
             UndirectedEdge[127, 148] -> 
             RGBColor[
              0.29756624946408855`, 0.42638484862682313`, 0.9403930437729009],
              UndirectedEdge[24, 226] -> 
             RGBColor[
              0.9550105750090976, 0.8620208674779115, 0.5674676409131905], 
             UndirectedEdge[144, 264] -> 
             RGBColor[
              0.24692493102232177`, 0.3768641368222969, 0.9373733815777969], 
             UndirectedEdge[148, 217] -> 
             RGBColor[
              0.22316774867338707`, 0.35189383188120626`, 0.9360204451886269],
              UndirectedEdge[230, 288] -> 
             RGBColor[
              0.2004754275788136, 0.3280427636345524, 0.9347281510725716], 
             UndirectedEdge[1, 83] -> 
             RGBColor[
              0.827979798814962, 0.21607057128362597`, 0.1744267929848577], 
             UndirectedEdge[15, 214] -> 
             RGBColor[
              0.22960322819742474`, 0.35865792889393855`, 0.936386936227082], 
             UndirectedEdge[173, 249] -> 
             RGBColor[
              0.20437181857140313`, 0.33213811761322165`, 0.9349500447754056],
              UndirectedEdge[114, 204] -> 
             RGBColor[
              0.3613702020678383, 0.4801637008416135, 0.944710077953264], 
             UndirectedEdge[77, 95] -> 
             RGBColor[
              0.3506695406416134, 0.476194939387312, 0.94363706407864], 
             UndirectedEdge[52, 295] -> 
             RGBColor[
              0.19782793389837072`, 0.3252600799156124, 0.9345773802240863], 
             UndirectedEdge[7, 103] -> 
             RGBColor[
              0.6798246620935919, 0.7464378960430543, 0.9686802958737664], 
             UndirectedEdge[29, 99] -> 
             RGBColor[
              0.19546469586089602`, 0.32277616690028066`, 0.9344427973139495],
              UndirectedEdge[28, 144] -> 
             RGBColor[
              0.19055497770725674`, 0.3176157418266954, 0.9341631961283768], 
             UndirectedEdge[75, 185] -> 
             RGBColor[
              0.43124290556454353`, 0.5458726103470143, 0.9492713561429931], 
             UndirectedEdge[227, 291] -> 
             RGBColor[
              0.9397896555683924, 0.8973624624611904, 0.6368452332520997], 
             UndirectedEdge[76, 192] -> 
             RGBColor[
              0.32876752436481727`, 0.45918363809373036`, 0.9421697538281874],
              UndirectedEdge[59, 72] -> 
             RGBColor[
              0.8812795328447734, 0.4807598783541659, 0.416576044780737], 
             UndirectedEdge[104, 254] -> 
             RGBColor[
              0.32693482661477913`, 0.45759624741671456`, 0.942052975948146], 
             UndirectedEdge[32, 237] -> 
             RGBColor[
              0.879275163275352, 0.4588842161406994, 0.3990636907380568], 
             UndirectedEdge[25, 232] -> 
             RGBColor[
              0.1895116930698092, 0.31651918352467145`, 0.9341037826116756], 
             UndirectedEdge[9, 141] -> 
             RGBColor[
              0.24640393833854723`, 0.3763165404788058, 0.9373437118151957], 
             UndirectedEdge[22, 48] -> 
             RGBColor[
              0.19067565939696252`, 0.3177425859342372, 0.934170068772073], 
             UndirectedEdge[25, 160] -> 
             RGBColor[
              0.19344001775085345`, 0.32064810183461934`, 0.9343274948908254],
              UndirectedEdge[72, 106] -> 
             RGBColor[
              0.8402305064958111, 0.44896653252378993`, 0.44609646287147053`],
              UndirectedEdge[4, 186] -> 
             RGBColor[
              0.2068268311149634, 0.334718491453289, 0.9350898541078958], 
             UndirectedEdge[78, 182] -> 
             RGBColor[
              0.22423750678067705`, 0.3530182154785495, 0.9360813663302717], 
             UndirectedEdge[106, 211] -> 
             RGBColor[
              0.5662966671615951, 0.6472879549936589, 0.9627077142549896], 
             UndirectedEdge[180, 245] -> 
             RGBColor[
              0.2100635516260986, 0.3381204899304254, 0.9352741805527061], 
             UndirectedEdge[136, 280] -> 
             RGBColor[
              0.32731420410911033`, 0.4536040519351767, 0.9422353549515605], 
             UndirectedEdge[82, 140] -> 
             RGBColor[
              0.7493592164876164, 0.32177032281068196`, 0.43038245426354804`],
              UndirectedEdge[50, 219] -> 
             RGBColor[
              0.1830787781409705, 0.30975778206409804`, 0.9337374376231229], 
             UndirectedEdge[251, 278] -> 
             RGBColor[
              0.24311863666183964`, 0.372863480116429, 0.9371566187448754], 
             UndirectedEdge[80, 150] -> 
             RGBColor[
              0.9431089113179686, 0.8053970694161215, 0.30826637148751795`], 
             UndirectedEdge[26, 183] -> 
             RGBColor[
              0.21091795920318307`, 0.3390185264665105, 0.9353228378002383], 
             UndirectedEdge[243, 256] -> 
             RGBColor[
              0.874424572290644, 0.42222750521570074`, 0.3959301794759612], 
             UndirectedEdge[184, 248] -> 
             RGBColor[
              0.20672425378609824`, 0.33461067617687346`, 0.9350840124807664],
              UndirectedEdge[4, 255] -> 
             RGBColor[
              0.2932777706676125, 0.42028873435652747`, 0.9402069895504767], 
             UndirectedEdge[37, 280] -> 
             RGBColor[
              0.2442905970349878, 0.3740952847751871, 0.9372233601543662], 
             UndirectedEdge[188, 260] -> 
             RGBColor[
              0.3070159863730502, 0.43566722665288543`, 0.9409549881356092], 
             UndirectedEdge[70, 266] -> 
             RGBColor[
              0.20395979058864, 0.33170505007925455`, 0.934926580391328], 
             UndirectedEdge[103, 127] -> 
             RGBColor[
              0.3850824421018483, 0.5079607893674816, 0.9457580905890645], 
             UndirectedEdge[37, 268] -> 
             RGBColor[
              0.21580890611804032`, 0.3441592217779706, 0.9356013699915318], 
             UndirectedEdge[186, 196] -> 
             RGBColor[
              0.19808785672818557`, 0.32553327528980713`, 0.9345921824447229],
              UndirectedEdge[139, 274] -> 
             RGBColor[
              0.4518848560948061, 0.5655575295786147, 0.9500876676545675], 
             UndirectedEdge[15, 255] -> 
             RGBColor[
              0.31219697150637127`, 0.44017401398467865`, 0.9412844100497945],
              UndirectedEdge[118, 195] -> 
             RGBColor[
              0.18622253645749176`, 0.31306207138055164`, 0.9339164700084752],
              UndirectedEdge[125, 128] -> 
             RGBColor[
              0.8384430661867497, 0.296495829336185, 0.18444642963665195`], 
             UndirectedEdge[61, 177] -> 
             RGBColor[
              0.2846154792944696, 0.4164792927751083, 0.9395198025437264], 
             UndirectedEdge[117, 276] -> 
             RGBColor[
              0.21344183559868857`, 0.34167128058119267`, 0.9354665688272218],
              UndirectedEdge[7, 154] -> 
             RGBColor[
              0.7178086500945909, 0.778143567686985, 0.971430549102502], 
             UndirectedEdge[59, 198] -> 
             RGBColor[
              0.974799373492677, 0.9805904794680657, 0.9214736253472325], 
             UndirectedEdge[83, 197] -> 
             RGBColor[
              0.8931489612206265, 0.5687594209510818, 0.42014697935815], 
             UndirectedEdge[243, 283] -> 
             RGBColor[
              0.6466191425526432, 0.7139161177704824, 0.899457696684746], 
             UndirectedEdge[95, 225] -> 
             RGBColor[
              0.2575765092536425, 0.3880596208924811, 0.9379799732004728], 
             UndirectedEdge[21, 74] -> 
             RGBColor[
              0.19973960321144332`, 0.32726936557048675`, 0.9346862469634045],
              UndirectedEdge[62, 225] -> 
             RGBColor[
              0.21463682483983898`, 0.34292729004033573`, 0.9355346216966771],
              UndirectedEdge[236, 267] -> 
             RGBColor[
              0.21381850493226368`, 0.3420671839329953, 0.9354880195885366], 
             UndirectedEdge[123, 300] -> 
             RGBColor[
              0.21212454910682327`, 0.34028672895745476`, 0.9353915513102607],
              UndirectedEdge[111, 218] -> 
             RGBColor[
              0.7906966430720825, 0.8363639438748425, 0.9515975962507148], 
             UndirectedEdge[61, 161] -> 
             RGBColor[
              0.23945694414961366`, 0.369014809121365, 0.9369480907732928], 
             UndirectedEdge[58, 180] -> 
             RGBColor[
              0.1930127612329003, 0.32019902814462275`, 0.9343031632641974], 
             UndirectedEdge[188, 236] -> 
             RGBColor[
              0.29364767479578224`, 0.42161628358526776`, 0.9401936825679285],
              UndirectedEdge[41, 268] -> 
             RGBColor[
              0.19682209771404596`, 0.32420288231218963`, 0.9345200993413902],
              UndirectedEdge[65, 138] -> 
             RGBColor[
              0.30437559706733064`, 0.4308950373883661, 0.9408777408234891], 
             UndirectedEdge[241, 291] -> 
             RGBColor[
              0.956499515277976, 0.9665294292639133, 0.9362543369482514], 
             UndirectedEdge[270, 295] -> 
             RGBColor[
              0.20488097831595456`, 0.3326732767873375, 0.9349790406696236], 
             UndirectedEdge[127, 212] -> 
             RGBColor[
              0.2911019408470156, 0.4195904504094406, 0.9400249109602461], 
             UndirectedEdge[105, 274] -> 
             RGBColor[
              0.373443394956703, 0.4953127699434419, 0.9451737605551122], 
             UndirectedEdge[128, 142] -> 
             RGBColor[
              0.839938700425626, 0.30799192948729065`, 0.18587865067287715`], 
             UndirectedEdge[38, 57] -> 
             RGBColor[
              0.18289757268776397`, 0.30956732364368866`, 0.9337271182406324],
              UndirectedEdge[135, 255] -> 
             RGBColor[
              0.28954719045708177`, 0.4163676580228129, 0.9399945385263857], 
             UndirectedEdge[46, 196] -> 
             RGBColor[
              0.2038842250820344, 0.33162562594068223`, 0.9349222770475161], 
             UndirectedEdge[138, 210] -> 
             RGBColor[
              0.35148342859896836`, 0.4711989277702072, 0.9440171598227016], 
             UndirectedEdge[72, 109] -> 
             RGBColor[
              0.8838806914832852, 0.4818355242979183, 0.3734681145578266], 
             UndirectedEdge[277, 282] -> 
             RGBColor[
              0.7168216670755537, 0.7717675564528452, 0.7149933619542863], 
             UndirectedEdge[62, 117] -> 
             RGBColor[
              0.1935934216908487, 0.32080933910192594`, 0.9343362310182673], 
             UndirectedEdge[33, 126] -> 
             RGBColor[
              0.2119973945219809, 0.3401530814267192, 0.9353843100447624], 
             UndirectedEdge[217, 278] -> 
             RGBColor[
              0.20033411359999898`, 0.32789423368299453`, 0.9347201034505334],
              UndirectedEdge[228, 264] -> 
             RGBColor[
              0.3612335072093944, 0.48614499734720384`, 0.9442808957993838], 
             UndirectedEdge[121, 239] -> 
             RGBColor[
              0.2315127682951095, 0.3606649766084402, 0.9364956817107337], 
             UndirectedEdge[56, 84] -> 
             RGBColor[
              0.1934123059271604, 0.32061897495088687`, 0.9343259167434621], 
             UndirectedEdge[45, 120] -> 
             RGBColor[
              0.2895125289687292, 0.4216264024736376, 0.9397986822781397], 
             UndirectedEdge[67, 234] -> 
             RGBColor[
              0.18654108215101917`, 0.31339688310141245`, 0.9339346107144755],
              UndirectedEdge[153, 192] -> 
             RGBColor[
              0.2758432306623323, 0.4052369526728678, 0.9390942768006172], 
             UndirectedEdge[77, 127] -> 
             RGBColor[
              0.3813089695721926, 0.5046923971225378, 0.9455176482562255], 
             UndirectedEdge[36, 152] -> 
             RGBColor[
              0.18192632080115292`, 0.3085464763299341, 0.9336718068825283], 
             UndirectedEdge[22, 122] -> 
             RGBColor[
              0.18679089642314464`, 0.31365945374055604`, 0.9339488372677058],
              UndirectedEdge[68, 218] -> 
             RGBColor[
              0.9220230883129681, 0.9398481441591451, 0.964270119789284], 
             UndirectedEdge[56, 148] -> 
             RGBColor[
              0.2228269723814797, 0.3515356543919468, 0.936001038482936], 
             UndirectedEdge[7, 130] -> 
             RGBColor[
              0.92506143421404, 0.8207777707366587, 0.6185929179813181], 
             UndirectedEdge[58, 296] -> 
             RGBColor[
              0.18917402722894824`, 0.3161642753166758, 0.9340845530415703], 
             UndirectedEdge[104, 116] -> 
             RGBColor[
              0.3112198168736299, 0.4420066574870038, 0.9411240550973782], 
             UndirectedEdge[252, 279] -> 
             RGBColor[
              0.23730450403035436`, 0.36675245808343765`, 0.9368255124927507],
              UndirectedEdge[64, 173] -> 
             RGBColor[
              0.21829574180286104`, 0.34677304375720647`, 0.9357429916048386],
              UndirectedEdge[109, 155] -> 
             RGBColor[
              0.9595624996907148, 0.8684305979471943, 0.514184885580798], 
             UndirectedEdge[151, 258] -> 
             RGBColor[
              0.4689947888884989, 0.5767176597098022, 0.9521890651333698], 
             UndirectedEdge[167, 216] -> 
             RGBColor[
              0.8802031529562763, 0.5482488422470734, 0.22171659205474953`], 
             UndirectedEdge[12, 258] -> 
             RGBColor[
              0.3848908244823526, 0.507794819816456, 0.9457458808837911], 
             UndirectedEdge[151, 239] -> 
             RGBColor[
              0.41770207455751684`, 0.5257103442374987, 0.9491616700514242], 
             UndirectedEdge[136, 226] -> 
             RGBColor[
              0.6894363159019072, 0.7515352642002422, 0.911828216152313], 
             UndirectedEdge[59, 210] -> 
             RGBColor[
              0.7283433684413259, 0.785018817714684, 0.9248382115325371], 
             UndirectedEdge[191, 205] -> 
             RGBColor[
              0.29986821230051, 0.4266293598594382, 0.9406037744698572], 
             UndirectedEdge[212, 276] -> 
             RGBColor[
              0.23737124141047264`, 0.3668226033013362, 0.9368293130878194], 
             UndirectedEdge[218, 292] -> 
             RGBColor[
              0.8704525733936984, 0.8991011858444631, 0.9592520377831382], 
             UndirectedEdge[144, 245] -> 
             RGBColor[
              0.2114412038308669, 0.3395684897458317, 0.9353526358077138], 
             UndirectedEdge[1, 277] -> 
             RGBColor[
              0.8767993326536895, 0.4256141747773018, 0.2705857731385237], 
             UndirectedEdge[64, 239] -> 
             RGBColor[
              0.23644031537818827`, 0.3658441410172859, 0.9367762982274624], 
             UndirectedEdge[128, 256] -> 
             RGBColor[
              0.8359362044780833, 0.2772269917295691, 0.18204585603333756`], 
             UndirectedEdge[7, 81] -> 
             RGBColor[
              0.9138922902616244, 0.7722436147323656, 0.6093859995388808], 
             UndirectedEdge[32, 145] -> 
             RGBColor[
              0.9262900127477325, 0.9421433350511439, 0.920438952214905], 
             UndirectedEdge[84, 247] -> 
             RGBColor[
              0.1926121673846783, 0.3197779786110244, 0.9342803500371666], 
             UndirectedEdge[215, 259] -> 
             RGBColor[
              0.20495150510474192`, 0.33274740491400967`, 0.9349830570659099],
              UndirectedEdge[187, 233] -> 
             RGBColor[
              0.2150678926487934, 0.3433803696388245, 0.9355591703706895], 
             UndirectedEdge[37, 152] -> 
             RGBColor[
              0.20454390254542953`, 0.33231898878067745`, 0.9349598447031511],
              UndirectedEdge[257, 300] -> 
             RGBColor[
              0.20486085687830097`, 0.33265212788059073`, 0.9349778947835161],
              UndirectedEdge[10, 244] -> 
             RGBColor[
              0.1899533548754444, 0.3169833980853699, 0.9341289345981263], 
             UndirectedEdge[98, 157] -> 
             RGBColor[
              0.18079506708635712`, 0.3073574569500555, 0.9336073836570105], 
             UndirectedEdge[13, 271] -> 
             RGBColor[
              0.2779619784734704, 0.40721689761763513`, 0.9392239799901998], 
             UndirectedEdge[202, 203] -> 
             RGBColor[
              0.8900888543770439, 0.6422166578978118, 0.47068879280256504`], 
             UndirectedEdge[166, 195] -> 
             RGBColor[
              0.184909234384039, 0.31168170763319203`, 0.9338416793982484], 
             UndirectedEdge[260, 287] -> 
             RGBColor[
              0.25058425907026255`, 0.38071032261548143`, 0.9375817748966364],
              UndirectedEdge[212, 214] -> 
             RGBColor[
              0.21709951040225656`, 0.3455157287097197, 0.9356748679962401], 
             UndirectedEdge[25, 113] -> 
             RGBColor[
              0.22937411863723062`, 0.3584171202197894, 0.9363738887765662], 
             UndirectedEdge[244, 280] -> 
             RGBColor[
              0.22575834254074034`, 0.3546167102889326, 0.9361679756769326], 
             UndirectedEdge[58, 134] -> 
             RGBColor[
              0.21796998739019388`, 0.34643065521547056`, 0.9357244403729478],
              UndirectedEdge[64, 263] -> 
             RGBColor[
              0.22259690617654707`, 0.3512938402235227, 0.9359879365529176], 
             UndirectedEdge[182, 261] -> 
             RGBColor[
              0.24954002688104543`, 0.37961276837646946`, 0.9375223074182637],
              UndirectedEdge[150, 277] -> 
             RGBColor[
              0.9502103007628988, 0.8290380865568148, 0.362523350207251], 
             UndirectedEdge[86, 202] -> 
             RGBColor[
              0.7757728461762639, 0.551813377715961, 0.4606487739019124], 
             UndirectedEdge[257, 267] -> 
             RGBColor[
              0.19014093188722048`, 0.31718055341781604`, 0.9341396168314517],
              UndirectedEdge[134, 245] -> 
             RGBColor[
              0.2350207777833922, 0.3643521170012733, 0.9366954576614566], 
             UndirectedEdge[187, 297] -> 
             RGBColor[
              0.20836666181027574`, 0.33633695114496726`, 0.9351775451880184],
              UndirectedEdge[75, 292] -> 
             RGBColor[
              0.5533224742847231, 0.6429700886267707, 0.9602576695267473], 
             UndirectedEdge[54, 174] -> 
             RGBColor[
              0.23862082785776215`, 0.3681359978857943, 0.936900475187395], 
             UndirectedEdge[44, 108] -> 
             RGBColor[
              0.27845239042381165`, 0.4093105366510138, 0.9391941231422369], 
             UndirectedEdge[94, 141] -> 
             RGBColor[
              0.5453682927010454, 0.6337189411498153, 0.9602178278094844], 
             UndirectedEdge[185, 262] -> 
             RGBColor[
              0.41669813660407123`, 0.5328210539055609, 0.9483611851595068], 
             UndirectedEdge[40, 202] -> 
             RGBColor[
              0.8074583715423828, 0.5770584081231883, 0.4634704687762633], 
             UndirectedEdge[110, 191] -> 
             RGBColor[
              0.20664696570435293`, 0.3345294415026117, 0.9350796110388486], 
             UndirectedEdge[92, 125] -> 
             RGBColor[
              0.8327679503009816, 0.2528744017865336, 0.1790119322553138], 
             UndirectedEdge[72, 226] -> 
             RGBColor[
              0.8816960164127614, 0.48093210501266836`, 0.40967383423425274`],
              UndirectedEdge[130, 162] -> 
             RGBColor[
              0.9515757296113414, 0.8393631712246421, 0.5204689724050278], 
             UndirectedEdge[29, 43] -> 
             RGBColor[
              0.21042089134742065`, 0.3384960766341818, 0.9352945305211986], 
             UndirectedEdge[152, 268] -> 
             RGBColor[
              0.1937845276020504, 0.3210102035314135, 0.9343471142171944], 
             UndirectedEdge[4, 62] -> 
             RGBColor[
              0.21110734445904222`, 0.33921758237813715`, 0.9353336230103891],
              UndirectedEdge[18, 184] -> 
             RGBColor[
              0.19573226525779447`, 0.3230573993013006, 0.9344580349952694], 
             UndirectedEdge[95, 159] -> 
             RGBColor[
              0.2893985943419117, 0.4215066499569798, 0.9397921938696936], 
             UndirectedEdge[154, 255] -> 
             RGBColor[
              0.43165774296703474`, 0.5471078244024314, 0.9490557746765065], 
             UndirectedEdge[140, 269] -> 
             RGBColor[
              0.8692676326331821, 0.39646501360429004`, 0.22622904167796476`],
              UndirectedEdge[10, 161] -> 
             RGBColor[
              0.19602879349749167`, 0.3233690692821986, 0.9344749218398459], 
             UndirectedEdge[216, 293] -> 
             RGBColor[
              0.8775620673948297, 0.536919768793157, 0.2195471266169376], 
             UndirectedEdge[188, 294] -> 
             RGBColor[
              0.445956916802145, 0.5584408477111231, 0.9502576320388609], 
             UndirectedEdge[32, 282] -> 
             RGBColor[
              0.7141541547436409, 0.7726234711925095, 0.9015995382329896], 
             UndirectedEdge[251, 282] -> 
             RGBColor[
              0.363119718775744, 0.4867984505328162, 0.944436976695407], 
             UndirectedEdge[181, 299] -> 
             RGBColor[
              0.874560587203039, 0.4182728709455591, 0.2441080923447113], 
             UndirectedEdge[60, 159] -> 
             RGBColor[
              0.28925410608148494`, 0.42135478363418655`, 0.9397839654770135],
              UndirectedEdge[137, 217] -> 
             RGBColor[
              0.23078620352350526`, 0.3599013109666169, 0.9364543049218471], 
             UndirectedEdge[20, 152] -> 
             RGBColor[
              0.20076184690853469`, 0.3283438085101236, 0.9347444622296798], 
             UndirectedEdge[62, 196] -> 
             RGBColor[
              0.2023683700722644, 0.33003236621465526`, 0.9348359513472162], 
             UndirectedEdge[251, 289] -> 
             RGBColor[
              0.26452594049436573`, 0.3953639137458709, 0.9383757330288698], 
             UndirectedEdge[104, 283] -> 
             RGBColor[
              0.32045429654903324`, 0.4517126811256811, 0.9416499450537039], 
             UndirectedEdge[45, 294] -> 
             RGBColor[
              0.4179920843483252, 0.5334044550653643, 0.9485055663485399], 
             UndirectedEdge[15, 158] -> 
             RGBColor[
              0.22566086224390924`, 0.3545142523163553, 0.9361624243182372], 
             UndirectedEdge[150, 237] -> 
             RGBColor[
              0.8525195804485002, 0.35269902313604284`, 0.19588243651989107`],
              UndirectedEdge[169, 228] -> 
             RGBColor[
              0.5154980125146456, 0.6168087674389304, 0.9552040569175313], 
             UndirectedEdge[159, 251] -> 
             RGBColor[
              0.2884240455436301, 0.4204823373800232, 0.9397366947573472], 
             UndirectedEdge[203, 293] -> 
             RGBColor[
              0.9184419291701429, 0.7951691860663403, 0.6146917974413972], 
             UndirectedEdge[145, 282] -> 
             RGBColor[
              0.6527680048201097, 0.7255950154401895, 0.9681370826346918], 
             UndirectedEdge[195, 234] -> 
             RGBColor[
              0.18893962070800485`, 0.3159178992009325, 0.934071203936976], 
             UndirectedEdge[156, 270] -> 
             RGBColor[
              0.3036653348674415, 0.42857413928414156`, 0.9408949377483093], 
             UndirectedEdge[25, 134] -> 
             RGBColor[
              0.21795734402989536`, 0.34641736624216146`, 0.935723720352283], 
             UndirectedEdge[158, 276] -> 
             RGBColor[
              0.21715975035837445`, 0.34557904472303347`, 0.935678298572624], 
             UndirectedEdge[268, 280] -> 
             RGBColor[
              0.23353122209160865`, 0.3627864995259231, 0.9366106296684096], 
             UndirectedEdge[8, 186] -> 
             RGBColor[
              0.19879211006828354`, 0.3262734902024908, 0.934632288630592], 
             UndirectedEdge[32, 256] -> 
             RGBColor[
              0.8745107904220526, 0.4222631586287432, 0.39450132191314774`], 
             UndirectedEdge[60, 168] -> 
             RGBColor[
              0.3438394161380286, 0.4702523109805432, 0.9432028328564219], 
             UndirectedEdge[162, 216] -> 
             RGBColor[
              0.9080919042261215, 0.6545799385528897, 0.40453925138773855`], 
             UndirectedEdge[106, 115] -> 
             RGBColor[
              0.6067946716231568, 0.6858798777418896, 0.9651595250499304], 
             UndirectedEdge[77, 276] -> 
             RGBColor[
              0.3275782701356497, 0.45192455001443343`, 0.9423220503837988], 
             UndirectedEdge[80, 281] -> 
             RGBColor[
              0.9786349916305042, 0.9618175926615335, 0.6467591064594813], 
             UndirectedEdge[130, 293] -> 
             RGBColor[
              0.9057809743644036, 0.6628729165850431, 0.24298078524882644`], 
             UndirectedEdge[39, 118] -> 
             RGBColor[
              0.19522260799965463`, 0.322521717208859, 0.9344290107683887], 
             UndirectedEdge[58, 245] -> 
             RGBColor[
              0.20819170713916685`, 0.33615306269286493`, 0.9351675817783212],
              UndirectedEdge[54, 143] -> 
             RGBColor[
              0.2754657226956103, 0.40686231846163223`, 0.9389987374412732], 
             UndirectedEdge[239, 258] -> 
             RGBColor[
              0.28886880526886394`, 0.4180452286151569, 0.9398683740473033], 
             UndirectedEdge[184, 222] -> 
             RGBColor[
              0.2064576757790399, 0.33433048578943325`, 0.9350688312576314], 
             UndirectedEdge[143, 298] -> 
             RGBColor[
              0.28351617500257303`, 0.41532385426440727`, 0.9394571987905778],
              UndirectedEdge[203, 269] -> 
             RGBColor[
              0.9551449948812127, 0.9368848088945971, 0.6707830617471834], 
             UndirectedEdge[107, 139] -> 
             RGBColor[
              0.4245992235592372, 0.5421882392946853, 0.9482760649602114], 
             UndirectedEdge[108, 283] -> 
             RGBColor[
              0.2732531217435669, 0.4045367345740317, 0.9388727330903042], 
             UndirectedEdge[173, 186] -> 
             RGBColor[
              0.19720146830174806`, 0.32460162485334904`, 0.9345417039351314],
              UndirectedEdge[164, 296] -> 
             RGBColor[
              0.18458413953272382`, 0.31134001233225567`, 0.9338231657274008],
              UndirectedEdge[11, 116] -> 
             RGBColor[
              0.4095833128093886, 0.5250728013946587, 0.9479805946176828], 
             UndirectedEdge[43, 229] -> 
             RGBColor[
              0.221649468641255, 0.3502980233029215, 0.935933981386891], 
             UndirectedEdge[128, 149] -> 
             RGBColor[
              0.8617947720920316, 0.43708705040676815`, 0.20528481439629814`],
              UndirectedEdge[221, 232] -> 
             RGBColor[
              0.18705168190288157`, 0.31393355581451393`, 0.9339636886149794],
              UndirectedEdge[8, 85] -> 
             RGBColor[
              0.21830835870760254`, 0.3467863049240477, 0.9357437101188987], 
             UndirectedEdge[20, 41] -> 
             RGBColor[
              0.20379941702053028`, 0.3315364872908998, 0.9349174473538756], 
             UndirectedEdge[108, 252] -> 
             RGBColor[
              0.23931387407336885`, 0.3688644334000649, 0.9369399431441039], 
             UndirectedEdge[65, 241] -> 
             RGBColor[
              0.6817937974014621, 0.7449457823928316, 0.912446971452788], 
             UndirectedEdge[231, 245] -> 
             RGBColor[
              0.2282116135363889, 0.3571952536517242, 0.9363076858308454], 
             UndirectedEdge[80, 167] -> 
             RGBColor[
              0.9432452158034876, 0.8059374712804274, 0.30837604527604406`], 
             UndirectedEdge[17, 201] -> 
             RGBColor[
              0.7981304417837846, 0.4892713331849807, 0.45108208269740613`], 
             UndirectedEdge[57, 223] -> 
             RGBColor[
              0.1805830172649961, 0.30713457914306985`, 0.9335953077333836], 
             UndirectedEdge[162, 202] -> 
             RGBColor[
              0.9081632494131782, 0.6549039003842219, 0.40459878356064916`], 
             UndirectedEdge[3, 59] -> 
             RGBColor[
              0.9696130276591681, 0.9767225112372966, 0.930252756027731], 
             UndirectedEdge[180, 187] -> 
             RGBColor[
              0.20981238961313842`, 0.3378565027302129, 0.9352598772476289], 
             UndirectedEdge[193, 215] -> 
             RGBColor[
              0.252152731139514, 0.38235888620713765`, 0.9376710970606339], 
             UndirectedEdge[43, 78] -> 
             RGBColor[
              0.20985899682898168`, 0.3379054898691324, 0.9352625314596219], 
             UndirectedEdge[56, 251] -> 
             RGBColor[
              0.2424819913817221, 0.3721943255613833, 0.9371203627380049], 
             UndirectedEdge[261, 284] -> 
             RGBColor[
              0.2428470796826115, 0.3725780565135533, 0.937141153976641], 
             UndirectedEdge[36, 41] -> 
             RGBColor[
              0.18496389091314852`, 0.31173915511071026`, 0.9338447920067241],
              UndirectedEdge[95, 168] -> 
             RGBColor[
              0.3439839043984553, 0.4704041773033365, 0.943211061249102], 
             UndirectedEdge[194, 280] -> 
             RGBColor[
              0.4740092277386598, 0.5736772866128733, 0.9537854496422005], 
             UndirectedEdge[99, 182] -> 
             RGBColor[
              0.22500890422772363`, 0.3538290031048185, 0.9361252962737008], 
             UndirectedEdge[94, 97] -> 
             RGBColor[
              0.622873487370591, 0.7022274882781143, 0.9651059553417796], 
             UndirectedEdge[79, 240] -> 
             RGBColor[
              0.18183565807480434`, 0.3084511840561929, 0.9336666437743861], 
             UndirectedEdge[83, 198] -> 
             RGBColor[
              0.8858987442443274, 0.5635903178481945, 0.44308216880395335`], 
             UndirectedEdge[69, 213] -> 
             RGBColor[
              0.20497196381527677`, 0.33276890831593897`, 0.934984222159209], 
             UndirectedEdge[214, 286] -> 
             RGBColor[
              0.21086056333637188`, 0.3389581997713838, 0.9353195691905329], 
             UndirectedEdge[277, 293] -> 
             RGBColor[
              0.946384976906248, 0.8125848782402458, 0.35937882583905917`], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.23002654529780098`, 0.3591028620062883, 0.9364110435097069], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.4656160294018773, 0.5758295097005381, 0.9514105681730911], 
             UndirectedEdge[43, 199] -> 
             RGBColor[
              0.21199067610024028`, 0.34014601993949717`, 0.9353839274405833],
              UndirectedEdge[192, 222] -> 
             RGBColor[
              0.2760214326902352, 0.40542425430285495`, 0.93910442514248], 
             UndirectedEdge[130, 202] -> 
             RGBColor[
              0.8816482178398845, 0.5540191449102804, 0.2228814513408511], 
             UndirectedEdge[4, 265] -> 
             RGBColor[
              0.22162675469537457`, 0.35027414950565383`, 0.9359326878612754],
              UndirectedEdge[121, 173] -> 
             RGBColor[
              0.21336819471978227`, 0.34159387934836083`, 0.9354623750881099],
              UndirectedEdge[53, 107] -> 
             RGBColor[
              0.3121763440598402, 0.43622685441542786`, 0.9414269663560839], 
             UndirectedEdge[172, 238] -> 
             RGBColor[
              0.18901379750666059`, 0.31599586371940025`, 0.9340754281959247],
              UndirectedEdge[210, 211] -> 
             RGBColor[
              0.3712058892361785, 0.49192848437614356`, 0.9451403247792249], 
             UndirectedEdge[180, 221] -> 
             RGBColor[
              0.19054010670567417`, 0.3176001114611562, 0.9341623492468364], 
             UndirectedEdge[196, 212] -> 
             RGBColor[
              0.2182141780704709, 0.3466873151030251, 0.9357383466709418], 
             UndirectedEdge[160, 176] -> 
             RGBColor[
              0.19497852177206426`, 0.3222651671077009, 0.9344151104188206], 
             UndirectedEdge[115, 193] -> 
             RGBColor[
              0.3156462416789386, 0.4451205438424978, 0.9414324679079064], 
             UndirectedEdge[21, 300] -> 
             RGBColor[
              0.2096118710905434, 0.33764574504935696`, 0.9352484580144076], 
             UndirectedEdge[75, 235] -> 
             RGBColor[
              0.3707116092284409, 0.495513496231598, 0.9448423938259995], 
             UndirectedEdge[77, 255] -> 
             RGBColor[
              0.38990028243638014`, 0.512133760513557, 0.9460650791149319], 
             UndirectedEdge[62, 286] -> 
             RGBColor[
              0.21128388043674812`, 0.3394031328837336, 0.935343676473158], 
             UndirectedEdge[46, 225] -> 
             RGBColor[
              0.21615267984960895`, 0.3445205497663627, 0.935620947396977], 
             UndirectedEdge[37, 161] -> 
             RGBColor[
              0.21411146518921928`, 0.3423751037378088, 0.9355047032417743], 
             UndirectedEdge[3, 162] -> 
             RGBColor[
              0.972783323199716, 0.9780335099161923, 0.8777127544589929], 
             UndirectedEdge[107, 274] -> 
             RGBColor[
              0.43576092708699476`, 0.5515917926842843, 0.9490602651560203], 
             UndirectedEdge[6, 147] -> 
             RGBColor[
              0.2119963836374878, 0.34015201892302305`, 0.935384252476386], 
             UndirectedEdge[8, 135] -> 
             RGBColor[
              0.2087723681564475, 0.33676337423806185`, 0.9352006495642442], 
             UndirectedEdge[186, 249] -> 
             RGBColor[
              0.20028634308592377`, 0.3278440238438759, 0.934717382990427], 
             UndirectedEdge[277, 281] -> 
             RGBColor[
              0.9857363810754343, 0.9854586098022267, 0.7010160851792143], 
             UndirectedEdge[256, 277] -> 
             RGBColor[
              0.8762891319766611, 0.42169254880230017`, 0.2700972043940122], 
             UndirectedEdge[8, 249] -> 
             RGBColor[
              0.20596246033793864`, 0.3338099829623634, 0.9350406294708662], 
             UndirectedEdge[114, 254] -> 
             RGBColor[
              0.2789569494583814, 0.4096039374484629, 0.9392315319348887], 
             UndirectedEdge[223, 270] -> 
             RGBColor[
              0.19716475878398335`, 0.32456304082266046`, 0.9345396133824015],
              UndirectedEdge[120, 294] -> 
             RGBColor[
              0.40756986398437334`, 0.5224500406559134, 0.9479120363171062], 
             UndirectedEdge[23, 290] -> 
             RGBColor[
              0.9678787961151241, 0.9075534182585008, 0.5509781065817215], 
             UndirectedEdge[7, 293] -> 
             RGBColor[
              0.9190392263270429, 0.795614649307972, 0.6136807291548138], 
             UndirectedEdge[95, 191] -> 
             RGBColor[
              0.2574665501142888, 0.38794404686520834`, 0.9379737111901566], 
             UndirectedEdge[65, 194] -> 
             RGBColor[
              0.5317344651989768, 0.6279967791452647, 0.9573054453238024], 
             UndirectedEdge[94, 188] -> 
             RGBColor[
              0.5763766141360973, 0.661954233683196, 0.9621432156948482], 
             UndirectedEdge[24, 162] -> 
             RGBColor[
              0.9575561451976635, 0.8630735261690534, 0.5252809551641785], 
             UndirectedEdge[34, 84] -> 
             RGBColor[
              0.1855804331499768, 0.3123871800926523, 0.9338799031750189], 
             UndirectedEdge[130, 201] -> 
             RGBColor[
              0.8675104556731318, 0.4624745923387423, 0.2100136661179885], 
             UndirectedEdge[74, 260] -> 
             RGBColor[
              0.23203447362151203`, 0.3612133219845175, 0.9365253920572785], 
             UndirectedEdge[69, 85] -> 
             RGBColor[
              0.21985867650040533`, 0.3484157872201088, 0.9358319984237091], 
             UndirectedEdge[220, 262] -> 
             RGBColor[
              0.318464636651424, 0.44980618598534605`, 0.9415298717668166], 
             UndirectedEdge[26, 262] -> 
             RGBColor[
              0.26646771810795733`, 0.39740484513356716`, 0.9384863143913613],
              UndirectedEdge[217, 270] -> 
             RGBColor[
              0.20643869531729672`, 0.3343105361207104, 0.9350677503484142], 
             UndirectedEdge[221, 245] -> 
             RGBColor[
              0.20571905261194073`, 0.33355414600939837`, 0.93502676776096], 
             UndirectedEdge[3, 24] -> 
             RGBColor[
              0.9389911914260977, 0.8504167316496911, 0.6099487388884464], 
             UndirectedEdge[59, 197] -> 
             RGBColor[
              0.9856746989571257, 0.9883441341223966, 0.8870708411785275], 
             UndirectedEdge[54, 235] -> 
             RGBColor[
              0.32626536687632174`, 0.4510335953926109, 0.9422293781681247], 
             UndirectedEdge[159, 282] -> 
             RGBColor[
              0.36593647358390397`, 0.4897590384287621, 0.9445973867147164], 
             UndirectedEdge[6, 53] -> 
             RGBColor[
              0.21323620369391516`, 0.3414551484114601, 0.9354548583944501], 
             UndirectedEdge[31, 210] -> 
             RGBColor[
              0.4456637990054052, 0.5599347702274033, 0.949756030710805], 
             UndirectedEdge[137, 273] -> 
             RGBColor[
              0.25023215692458567`, 0.3803402409358096, 0.9375617232003286], 
             UndirectedEdge[99, 259] -> 
             RGBColor[
              0.19041774683741108`, 0.3174715034815479, 0.934155381033354], 
             UndirectedEdge[16, 151] -> 
             RGBColor[
              0.42230921801132515`, 0.5305527441172178, 0.9494240400554605], 
             UndirectedEdge[24, 227] -> 
             RGBColor[
              0.9382342504393061, 0.7928264157474236, 0.2691600319562284], 
             UndirectedEdge[87, 202] -> 
             RGBColor[
              0.9087631737635028, 0.6539246978300517, 0.30544569802749344`], 
             UndirectedEdge[17, 94] -> 
             RGBColor[
              0.7502759773076164, 0.8048405628721153, 0.9757441557565323], 
             UndirectedEdge[5, 92] -> 
             RGBColor[
              0.8780406889079944, 0.46699287511950294`, 0.23253013995633712`],
              UndirectedEdge[72, 290] -> 
             RGBColor[
              0.8684139499629852, 0.42648519406555707`, 0.2091141155204876], 
             UndirectedEdge[103, 212] -> 
             RGBColor[
              0.327349136755672, 0.45098594966848016`, 0.9423345502314089], 
             UndirectedEdge[112, 133] -> 
             RGBColor[
              0.18726032665159403`, 0.3141528546742519, 0.9339755706247563], 
             UndirectedEdge[71, 244] -> 
             RGBColor[
              0.20641030875985014`, 0.33428070004902233`, 0.9350661337759618],
              UndirectedEdge[142, 197] -> 
             RGBColor[
              0.8820709654347386, 0.4836090909320415, 0.4095386780827771], 
             UndirectedEdge[117, 196] -> 
             RGBColor[
              0.1942847722586868, 0.32153599238288155`, 0.9343756024103442], 
             UndirectedEdge[131, 188] -> 
             RGBColor[
              0.2926361203769149, 0.4205530757547836, 0.9401360760402346], 
             UndirectedEdge[13, 282] -> 
             RGBColor[
              0.38696044305919663`, 0.509587419405664, 0.9458777551494157], 
             UndirectedEdge[139, 143] -> 
             RGBColor[
              0.37380885559171856`, 0.49802499695333824`, 0.9450460153054621],
              UndirectedEdge[45, 89] -> 
             RGBColor[
              0.34033954683031736`, 0.4683920819989782, 0.9429369415722573], 
             UndirectedEdge[127, 269] -> 
             RGBColor[
              0.6610000720463691, 0.698853165460656, 0.646849788175898], 
             UndirectedEdge[25, 79] -> 
             RGBColor[
              0.18712823581077753`, 0.3140140188255107, 0.9339680482467827], 
             UndirectedEdge[29, 78] -> 
             RGBColor[
              0.1946932984138494, 0.3219653792740117, 0.9343988673705204], 
             UndirectedEdge[150, 179] -> 
             RGBColor[
              0.7150830892215184, 0.6470263643951079, 0.5999650595216117], 
             UndirectedEdge[11, 198] -> 
             RGBColor[
              0.7482029346182517, 0.8019514484742061, 0.9505539165512161], 
             UndirectedEdge[135, 286] -> 
             RGBColor[
              0.2169836251808333, 0.34539392599445645`, 0.9356682685043168], 
             UndirectedEdge[101, 104] -> 
             RGBColor[
              0.49120791951509923`, 0.5945373978105576, 0.9540278714950781], 
             UndirectedEdge[3, 290] -> 
             RGBColor[
              0.9503146533364857, 0.8953104848043834, 0.619059862137357], 
             UndirectedEdge[158, 212] -> 
             RGBColor[
              0.21315714444874106`, 0.34137205213213645`, 0.9354503560873951],
              UndirectedEdge[102, 175] -> 
             RGBColor[
              0.18740197098760464`, 0.3143017318521686, 0.9339836370601481], 
             UndirectedEdge[103, 255] -> 
             RGBColor[
              0.3936737549660358, 0.5154021527585007, 0.9463055214477708], 
             UndirectedEdge[3, 65] -> 
             RGBColor[
              0.6658408786786703, 0.7333691314923763, 0.9538265746888542], 
             UndirectedEdge[148, 270] -> 
             RGBColor[
              0.22956819937889494`, 0.35862111138470837`, 0.9363849413876872],
              UndirectedEdge[49, 298] -> 
             RGBColor[
              0.23487979924778435`, 0.36420393962179404`, 0.9366874291424127],
              UndirectedEdge[15, 103] -> 
             RGBColor[
              0.33985285455084013`, 0.464128149852699, 0.9430466184622509], 
             UndirectedEdge[4, 15] -> 
             RGBColor[
              0.23945687025241685`, 0.36901473145072583`, 0.9369480865649568],
              UndirectedEdge[83, 290] -> 
             RGBColor[
              0.8798387029608784, 0.5143008519660508, 0.22005447189368316`], 
             UndirectedEdge[182, 284] -> 
             RGBColor[
              0.24765066246750966`, 0.3776269265852207, 0.937414710909977], 
             UndirectedEdge[32, 92] -> 
             RGBColor[
              0.883595180526095, 0.49208976177353947`, 0.4032005441361298], 
             UndirectedEdge[87, 203] -> 
             RGBColor[
              0.9651365709425674, 0.970190636874684, 0.7434503562978652], 
             UndirectedEdge[115, 169] -> 
             RGBColor[
              0.47823384946439584`, 0.5845324223560975, 0.9528296173993749], 
             UndirectedEdge[111, 143] -> 
             RGBColor[
              0.46054913753176646`, 0.5687866450741914, 0.9517800380473413], 
             UndirectedEdge[163, 274] -> 
             RGBColor[
              0.5420984734158494, 0.6391389878337358, 0.9570951240808855], 
             UndirectedEdge[96, 260] -> 
             RGBColor[
              0.22955901197049378`, 0.3586114548359634, 0.9363844181783704], 
             UndirectedEdge[27, 227] -> 
             RGBColor[
              0.9612729955532987, 0.8800632676191081, 0.309071745135731], 
             UndirectedEdge[103, 205] -> 
             RGBColor[
              0.39684467535749024`, 0.5181486446264856, 0.9465075696911796], 
             UndirectedEdge[27, 216] -> 
             RGBColor[
              0.9009229797863709, 0.6276599876230118, 0.25263771646037597`], 
             UndirectedEdge[145, 293] -> 
             RGBColor[
              0.8823313146508039, 0.7664123372275902, 0.6125225465194646], 
             UndirectedEdge[96, 133] -> 
             RGBColor[
              0.19311989172231955`, 0.3203116290814677, 0.9343092641870845], 
             UndirectedEdge[127, 159] -> 
             RGBColor[
              0.3200380232724909, 0.45000410769220556`, 0.9416727780472791], 
             UndirectedEdge[186, 214] -> 
             RGBColor[
              0.19697318905997124`, 0.32436168889650174`, 0.9345287037700212],
              UndirectedEdge[111, 262] -> 
             RGBColor[
              0.459021775002635, 0.5671812902156966, 0.9516930570108376], 
             UndirectedEdge[33, 157] -> 
             RGBColor[
              0.19152225944429985`, 0.31863241626153205`, 0.9342182813923363],
              UndirectedEdge[112, 131] -> 
             RGBColor[
              0.20931958090363292`, 0.3373385295306458, 0.9352318125206677], 
             UndirectedEdge[37, 55] -> 
             RGBColor[
              0.21435260419714997`, 0.34262855612424004`, 0.9355184357515427],
              UndirectedEdge[20, 71] -> 
             RGBColor[
              0.22116050761720274`, 0.349784094264723, 0.9359061357799242], 
             UndirectedEdge[37, 252] -> 
             RGBColor[
              0.23225528127463596`, 0.3614454048279645, 0.9365379667264683], 
             UndirectedEdge[120, 178] -> 
             RGBColor[
              0.2690508208241996, 0.4001198498665095, 0.9386334182696933], 
             UndirectedEdge[113, 231] -> 
             RGBColor[
              0.24940666839475117`, 0.3794726001519578, 0.9375147128497554], 
             UndirectedEdge[7, 181] -> 
             RGBColor[
              0.962306825108859, 0.9594739836095195, 0.6952739648323978], 
             UndirectedEdge[42, 299] -> 
             RGBColor[
              0.8313011225434905, 0.2415997208744344, 0.17760729633819525`], 
             UndirectedEdge[64, 234] -> 
             RGBColor[
              0.2147298520602665, 0.3430250675472716, 0.9355399194592591], 
             UndirectedEdge[78, 261] -> 
             RGBColor[
              0.21943392399577888`, 0.3479693454068822, 0.9358078093969358], 
             UndirectedEdge[10, 100] -> 
             RGBColor[
              0.18553288790448116`, 0.3123372070250937, 0.9338771955436248], 
             UndirectedEdge[6, 88] -> 
             RGBColor[
              0.21672673573205908`, 0.345123918896063, 0.935653639030243], 
             UndirectedEdge[36, 208] -> 
             RGBColor[
              0.1853248284213402, 0.31211852331657947`, 0.9338653468638564], 
             UndirectedEdge[92, 142] -> 
             RGBColor[
              0.8310149903490321, 0.23940038344390055`, 0.17733329582564183`],
              UndirectedEdge[237, 293] -> 
             RGBColor[
              0.8499693645440664, 0.3417302175916635, 0.19378608694109653`], 
             UndirectedEdge[127, 145] -> 
             RGBColor[
              0.6068695545086966, 0.6858400847036329, 0.9652124739672545], 
             UndirectedEdge[90, 285] -> 
             RGBColor[
              0.20767787323688183`, 0.3356129906826123, 0.9351383196977351], 
             UndirectedEdge[134, 176] -> 
             RGBColor[
              0.21949584805110617`, 0.34803443151524305`, 0.9358113358802782],
              UndirectedEdge[28, 297] -> 
             RGBColor[
              0.18773159769962583`, 0.31464819042604353`, 0.9340024088137586],
              UndirectedEdge[20, 136] -> 
             RGBColor[
              0.3058098324986471, 0.43100159391667037`, 0.9410107128012115], 
             UndirectedEdge[113, 134] -> 
             RGBColor[
              0.25621583264175446`, 0.38662946350150684`, 0.9379024846803665],
              UndirectedEdge[12, 181] -> 
             RGBColor[
              0.707957046702949, 0.7559827796524516, 0.6749255302079116], 
             UndirectedEdge[84, 217] -> 
             RGBColor[
              0.19375308221906778`, 0.32097715244014635`, 0.9343453234491528],
              UndirectedEdge[126, 153] -> 
             RGBColor[
              0.2222787641449363, 0.35095945277692997`, 0.9359698188348664], 
             UndirectedEdge[217, 251] -> 
             RGBColor[
              0.24282276767362948`, 0.3725525030506428, 0.9371397694436958], 
             UndirectedEdge[211, 266] -> 
             RGBColor[
              0.23444123912717205`, 0.36374298512871284`, 0.9366624537923354],
              UndirectedEdge[156, 282] -> 
             RGBColor[
              0.41756183526404816`, 0.5360928072628128, 0.9478276488009602], 
             UndirectedEdge[92, 256] -> 
             RGBColor[
              0.8270124944014894, 0.208635445686179, 0.17350050118610227`], 
             UndirectedEdge[56, 246] -> 
             RGBColor[
              0.1919032518459413, 0.3190328634319706, 0.934239978345982], 
             UndirectedEdge[223, 246] -> 
             RGBColor[
              0.1829700916045353, 0.3096435456231802, 0.9337312480856603], 
             UndirectedEdge[66, 228] -> 
             RGBColor[
              0.40629940527691566`, 0.5263378564741489, 0.9471100167211559], 
             UndirectedEdge[170, 261] -> 
             RGBColor[
              0.22115645505495063`, 0.3497798347648488, 0.9359059049924991], 
             UndirectedEdge[104, 287] -> 
             RGBColor[
              0.2890443879522816, 0.41869887568726627`, 0.9398611972259145], 
             UndirectedEdge[255, 258] -> 
             RGBColor[
              0.3530896957607064, 0.48025028048897034`, 0.9437195410822816], 
             UndirectedEdge[27, 162] -> 
             RGBColor[
              0.9805948903116561, 0.9503103780407378, 0.565192668343681], 
             UndirectedEdge[162, 169] -> 
             RGBColor[
              0.7980436197485294, 0.8403418316253028, 0.877535691789008], 
             UndirectedEdge[90, 166] -> 
             RGBColor[
              0.20088523531551122`, 0.3284734975491328, 0.9347514890169203], 
             UndirectedEdge[74, 257] -> 
             RGBColor[
              0.19498858899920085`, 0.3222757484017205, 0.9344156837325129], 
             UndirectedEdge[82, 203] -> 
             RGBColor[
              0.7752823706628642, 0.824842772704185, 0.9770131806255582], 
             UndirectedEdge[1, 142] -> 
             RGBColor[
              0.822440800922018, 0.17349540627410584`, 0.16912264234717125`], 
             UndirectedEdge[82, 145] -> 
             RGBColor[
              0.7391717561435251, 0.7960859238654349, 0.9748439297036255], 
             UndirectedEdge[77, 203] -> 
             RGBColor[
              0.6754538924070363, 0.7427240405564789, 0.9694509218275109], 
             UndirectedEdge[12, 27] -> 
             RGBColor[
              0.6997308165084448, 0.7282337735956864, 0.6429681792954851], 
             UndirectedEdge[54, 185] -> 
             RGBColor[
              0.3867966632124244, 0.5013927095080272, 0.9466583404851183], 
             UndirectedEdge[35, 165] -> 
             RGBColor[
              0.2120938524489715, 0.3402544648237721, 0.9353898031810077], 
             UndirectedEdge[60, 95] -> 
             RGBColor[
              0.28741190007160666`, 0.4194185083151971, 0.9396790545700505], 
             UndirectedEdge[47, 112] -> 
             RGBColor[
              0.18666547155784385`, 0.31352762425472913`, 0.9339416945071765],
              UndirectedEdge[24, 59] -> 
             RGBColor[
              0.9543858496571156, 0.8617625274901577, 0.5778209567329167], 
             UndirectedEdge[239, 285] -> 
             RGBColor[
              0.21862787921736482`, 0.3471221412385783, 0.9357619063392415], 
             UndirectedEdge[173, 286] -> 
             RGBColor[
              0.2110888425781487, 0.3391981357282311, 0.9353325693556434], 
             UndirectedEdge[17, 40] -> 
             RGBColor[
              0.6964483919711273, 0.7627900441024493, 0.9703791250975754], 
             UndirectedEdge[226, 241] -> 
             RGBColor[
              0.9861906717339419, 0.9885575021255057, 0.8785198369719385], 
             UndirectedEdge[255, 286] -> 
             RGBColor[
              0.2934543066453184, 0.4204742848621239, 0.9402170430132455], 
             UndirectedEdge[95, 271] -> 
             RGBColor[
              0.25509580298829937`, 0.3854522413217438, 0.9378387006485376], 
             UndirectedEdge[189, 260] -> 
             RGBColor[
              0.23700170640282697`, 0.36643419857842796`, 0.936808268615812], 
             UndirectedEdge[193, 245] -> 
             RGBColor[
              0.2524031222436139, 0.38262206313325964`, 0.9376853564635919], 
             UndirectedEdge[84, 223] -> 
             RGBColor[
              0.1844791456857544, 0.31122965714209644`, 0.9338171864831403], 
             UndirectedEdge[44, 61] -> 
             RGBColor[
              0.29673927658547317`, 0.4285312134624696, 0.9402355342561197], 
             UndirectedEdge[262, 292] -> 
             RGBColor[
              0.5387777053242508, 0.6299185321853173, 0.9593474985432611], 
             UndirectedEdge[153, 248] -> 
             RGBColor[
              0.2215139470361167, 0.3501555815033551, 0.9359262636319645], 
             UndirectedEdge[78, 99] -> 
             RGBColor[
              0.19490280134245708`, 0.32218558013523124`, 0.9344107982523728],
              UndirectedEdge[199, 261] -> 
             RGBColor[
              0.22156560326703745`, 0.35020987547724697`, 0.9359292053778969],
              UndirectedEdge[58, 215] -> 
             RGBColor[
              0.20794131603506694`, 0.33588988576674306`, 0.935153322375363], 
             UndirectedEdge[23, 197] -> 
             RGBColor[
              0.9878441835047461, 0.9892412717360475, 0.8511168677784218], 
             UndirectedEdge[196, 214] -> 
             RGBColor[
              0.20194505297188817`, 0.32958743310230554`, 0.9348118440645912],
              UndirectedEdge[88, 289] -> 
             RGBColor[
              0.23315152394890182`, 0.3623874127036856, 0.9365890064208955], 
             UndirectedEdge[47, 96] -> 
             RGBColor[
              0.19252503662856937`, 0.3196863986619449, 0.9342753880695046], 
             UndirectedEdge[179, 205] -> 
             RGBColor[
              0.44755823847840226`, 0.5601887588135859, 0.9502599417033248], 
             UndirectedEdge[72, 194] -> 
             RGBColor[
              0.7816121517042992, 0.4029477795624471, 0.4403138133077221], 
             UndirectedEdge[140, 299] -> 
             RGBColor[
              0.8177772995946797, 0.13764969151287093`, 0.16465686820944062`],
              UndirectedEdge[134, 297] -> 
             RGBColor[
              0.21839610407426302`, 0.3468785308677854, 0.9357487070877224], 
             UndirectedEdge[67, 195] -> 
             RGBColor[
              0.18132553855698572`, 0.30791501609952, 0.9336375932225005], 
             UndirectedEdge[24, 155] -> 
             RGBColor[
              0.9250389254998768, 0.7405113494439601, 0.2585427637758789], 
             UndirectedEdge[156, 277] -> 
             RGBColor[
              0.6937513555235839, 0.7517852121341029, 0.7135233421024703], 
             UndirectedEdge[267, 272] -> 
             RGBColor[
              0.18764714248222777`, 0.31455942263778813`, 0.9339975992140681],
              UndirectedEdge[71, 177] -> 
             RGBColor[
              0.2576442825267533, 0.3881308548995943, 0.9379838327881149], 
             UndirectedEdge[188, 281] -> 
             RGBColor[
              0.66716299452805, 0.7330554302274623, 0.9326197293964239], 
             UndirectedEdge[1, 150] -> 
             RGBColor[
              0.848265408272229, 0.31999959159908814`, 0.19180863643949353`], 
             UndirectedEdge[84, 246] -> 
             RGBColor[
              0.1859588657451276, 0.3127849367441682, 0.9339014543514719], 
             UndirectedEdge[58, 230] -> 
             RGBColor[
              0.19161321755920613`, 0.31872801900737613`, 0.9342234613224198],
              UndirectedEdge[74, 189] -> 
             RGBColor[
              0.21086862151855923`, 0.33896666943178094`, 0.9353200280920875],
              UndirectedEdge[48, 71] -> 
             RGBColor[
              0.2080633650262977, 0.3360181669948795, 0.9351602728848583], 
             UndirectedEdge[80, 205] -> 
             RGBColor[
              0.6755840605748524, 0.7185594638345996, 0.6585612536692309], 
             UndirectedEdge[1, 32] -> 
             RGBColor[
              0.8750209910990808, 0.42618478460374476`, 0.39498989065765927`],
              UndirectedEdge[229, 233] -> 
             RGBColor[
              0.2115539796555496, 0.3396870242879735, 0.9353590582240927], 
             UndirectedEdge[54, 172] -> 
             RGBColor[
              0.21731047913351847`, 0.34573747022246615`, 0.935686882353385], 
             UndirectedEdge[61, 194] -> 
             RGBColor[
              0.4816323907254858, 0.581689714248477, 0.9542195774968412], 
             UndirectedEdge[177, 194] -> 
             RGBColor[
              0.4889886310377472, 0.5894215892292383, 0.9546385045000421], 
             UndirectedEdge[7, 42] -> 
             RGBColor[
              0.8711763850077039, 0.5112078638480927, 0.45219338209118976`], 
             UndirectedEdge[26, 75] -> 
             RGBColor[
              0.28101248706842963`, 0.4104564015750206, 0.9393964853748475], 
             UndirectedEdge[170, 190] -> 
             RGBColor[
              0.2009954787857768, 0.3285893704262217, 0.9347577672194614], 
             UndirectedEdge[20, 36] -> 
             RGBColor[
              0.200168643680248, 0.32772031430593734`, 0.9347106801833944], 
             UndirectedEdge[119, 161] -> 
             RGBColor[
              0.191253116488521, 0.3183495299503595, 0.9342029540991661], 
             UndirectedEdge[212, 225] -> 
             RGBColor[
              0.23048263283804543`, 0.3595822389287055, 0.9364370170204028], 
             UndirectedEdge[102, 253] -> 
             RGBColor[
              0.1920226425007294, 0.3191583505799577, 0.9342467774671497], 
             UndirectedEdge[91, 179] -> 
             RGBColor[
              0.5064577791876668, 0.6102042666643193, 0.9542893580750782], 
             UndirectedEdge[118, 239] -> 
             RGBColor[
              0.213148543369447, 0.34136301185245843`, 0.9354498662686535], 
             UndirectedEdge[105, 298] -> 
             RGBColor[
              0.27198901083979987`, 0.403208073864912, 0.938800743844419], 
             UndirectedEdge[90, 239] -> 
             RGBColor[
              0.2266260849573989, 0.3555287625868876, 0.9362173923238513], 
             UndirectedEdge[208, 252] -> 
             RGBColor[
              0.21362941037883332`, 0.3418684335680528, 0.935477250933459], 
             UndirectedEdge[117, 214] -> 
             RGBColor[
              0.19317010459047246`, 0.32036440598957616`, 0.9343121237356424],
              UndirectedEdge[179, 282] -> 
             RGBColor[
              0.48169445553417334`, 0.5897558342911382, 0.9524350712686471], 
             UndirectedEdge[44, 268] -> 
             RGBColor[
              0.2606344226816996, 0.39058272282964934`, 0.9381794162386446], 
             UndirectedEdge[53, 124] -> 
             RGBColor[
              0.20090092998575032`, 0.32848999364265374`, 0.9347523828051723],
              UndirectedEdge[42, 81] -> 
             RGBColor[
              0.8548914543976673, 0.39035727136327797`, 0.1989221405255734], 
             UndirectedEdge[173, 213] -> 
             RGBColor[
              0.20183100425593847`, 0.3294675606707361, 0.9348053491589379], 
             UndirectedEdge[119, 122] -> 
             RGBColor[
              0.18294597115910344`, 0.30961819350570674`, 0.933729874461976], 
             UndirectedEdge[68, 111] -> 
             RGBColor[
              0.7455301616880299, 0.8011614727150247, 0.9754440364810864], 
             UndirectedEdge[34, 53] -> 
             RGBColor[
              0.1997851700209307, 0.32731725917636056`, 0.9346888419257947], 
             UndirectedEdge[85, 263] -> 
             RGBColor[
              0.22101888131475306`, 0.34963523604122215`, 0.9358980703715171],
              UndirectedEdge[37, 208] -> 
             RGBColor[
              0.20794241016561682`, 0.3358910357673228, 0.9351533846844792], 
             UndirectedEdge[256, 293] -> 
             RGBColor[
              0.8452049916907669, 0.30510916007970723`, 0.18922371811618746`],
              UndirectedEdge[76, 153] -> 
             RGBColor[
              0.27399346070364045`, 0.40363477490679034`, 0.9389764110945367],
              UndirectedEdge[135, 213] -> 
             RGBColor[
              0.20772578685862308`, 0.3356633509369615, 0.9351410483076115], 
             UndirectedEdge[36, 55] -> 
             RGBColor[
              0.19173502245287335`, 0.3188560436734967, 0.9342303979309199], 
             UndirectedEdge[121, 135] -> 
             RGBColor[
              0.21926297732246688`, 0.3477896696145861, 0.9357980742367835], 
             UndirectedEdge[83, 226] -> 
             RGBColor[
              0.8931207694106547, 0.5687477629131621, 0.4206141906074483], 
             UndirectedEdge[60, 127] -> 
             RGBColor[
              0.3180513290021859, 0.44791596605042294`, 0.941559638747636], 
             UndirectedEdge[247, 271] -> 
             RGBColor[
              0.21019581629378764`, 0.33825950848223085`, 0.9352817128298629],
              UndirectedEdge[202, 269] -> 
             RGBColor[
              0.902102123055933, 0.6317208125099938, 0.2570008349937056], 
             UndirectedEdge[190, 284] -> 
             RGBColor[
              0.22268610341343767`, 0.3513875921749262, 0.9359930162036031], 
             UndirectedEdge[53, 217] -> 
             RGBColor[
              0.2079578190900217, 0.3359072315238546, 0.9351542621999286], 
             UndirectedEdge[42, 87] -> 
             RGBColor[
              0.8894525062895627, 0.5226189282859114, 0.2876243328405072], 
             UndirectedEdge[205, 225] -> 
             RGBColor[
              0.29997817143986366`, 0.426744933886711, 0.9406100364801734], 
             UndirectedEdge[110, 246] -> 
             RGBColor[
              0.18518351558803503`, 0.3119699945690246, 0.9338572993070533], 
             UndirectedEdge[191, 251] -> 
             RGBColor[
              0.25649200131600725`, 0.38691973428825177`, 0.9379182120778102],
              UndirectedEdge[23, 83] -> 
             RGBColor[
              0.8941506088744137, 0.5691736279970934, 0.4035470855538621], 
             UndirectedEdge[226, 291] -> 
             RGBColor[
              0.956565980138184, 0.9665569141916783, 0.9351528422090618], 
             UndirectedEdge[60, 276] -> 
             RGBColor[
              0.26432062956564295`, 0.39514811894231855`, 0.9383640408752093],
              UndirectedEdge[27, 155] -> 
             RGBColor[
              0.9480776706138694, 0.8277482013156446, 0.2984544769553814], 
             UndirectedEdge[167, 203] -> 
             RGBColor[
              0.9224035575123126, 0.8121627962472151, 0.6179459955981152], 
             UndirectedEdge[137, 271] -> 
             RGBColor[
              0.24208469003989352`, 0.37177673666076144`, 0.9370977370143425],
              UndirectedEdge[52, 247] -> 
             RGBColor[
              0.1982447360653234, 0.3256981654198634, 0.9346011164908907], 
             UndirectedEdge[81, 299] -> 
             RGBColor[
              0.8422842306382159, 0.2934526250274564, 0.1868494488157], 
             UndirectedEdge[31, 290] -> 
             RGBColor[
              0.683029742131583, 0.6815722331575694, 0.6118498991600951], 
             UndirectedEdge[79, 288] -> 
             RGBColor[
              0.19600308919068352`, 0.3233420524259961, 0.9344734580175993], 
             UndirectedEdge[237, 281] -> 
             RGBColor[
              0.8762036339901905, 0.45697937196631744`, 0.42154425983453325`],
              UndirectedEdge[43, 215] -> 
             RGBColor[
              0.22516415254335911`, 0.35399217892786317`, 0.9361341374356069],
              UndirectedEdge[56, 295] -> 
             RGBColor[
              0.19813975131853928`, 0.3255878197945759, 0.9345951377648724], 
             UndirectedEdge[89, 94] -> 
             RGBColor[
              0.5888165791799138, 0.6727291061533267, 0.962935879267211], 
             UndirectedEdge[92, 237] -> 
             RGBColor[
              0.829394680828139, 0.22694597444215714`, 0.1757816855985568], 
             UndirectedEdge[126, 285] -> 
             RGBColor[
              0.21158401439278246`, 0.3397185927011176, 0.9353607686579457], 
             UndirectedEdge[4, 214] -> 
             RGBColor[
              0.21068402735866598`, 0.33877264926578743`, 0.9353095157277642],
              UndirectedEdge[220, 222] -> 
             RGBColor[
              0.2772575054008418, 0.4064948783579615, 0.9391831866025837], 
             UndirectedEdge[199, 209] -> 
             RGBColor[
              0.1894252090832627, 0.31642828337140966`, 0.9340988574765833], 
             UndirectedEdge[290, 291] -> 
             RGBColor[
              0.9366428804635196, 0.8848865477710113, 0.6343132641384139], 
             UndirectedEdge[91, 150] -> 
             RGBColor[
              0.6987841041568563, 0.6337941140587057, 0.5986819437121721], 
             UndirectedEdge[60, 148] -> 
             RGBColor[
              0.2667823322730826, 0.39773552456880407`, 0.9385042312026353], 
             UndirectedEdge[81, 140] -> 
             RGBColor[
              0.8413676314488565, 0.2864072420017145, 0.18597171239681876`], 
             UndirectedEdge[142, 256] -> 
             RGBColor[
              0.8259330961925325, 0.20033871805682574`, 0.1724668682421993], 
             UndirectedEdge[30, 123] -> 
             RGBColor[
              0.2239498078006626, 0.3527158256093854, 0.9360649822989724], 
             UndirectedEdge[53, 289] -> 
             RGBColor[
              0.22966099191075792`, 0.3587186422190827, 0.9363902257851027], 
             UndirectedEdge[274, 289] -> 
             RGBColor[
              0.3532455749379125, 0.4740835804879391, 0.944023524585039], 
             UndirectedEdge[11, 114] -> 
             RGBColor[
              0.38547343504917886`, 0.49973179121413747`, 0.9466075727466067],
              UndirectedEdge[137, 247] -> 
             RGBColor[
              0.22964528868911577`, 0.358702137137495, 0.9363893315098609], 
             UndirectedEdge[84, 191] -> 
             RGBColor[
              0.2074223158614455, 0.3353443836777553, 0.9351237660832672], 
             UndirectedEdge[17, 120] -> 
             RGBColor[
              0.4913767245940681, 0.5895491243083159, 0.9551516880301447], 
             UndirectedEdge[126, 222] -> 
             RGBColor[
              0.22245696617283922`, 0.3511467544069171, 0.9359799671767292], 
             UndirectedEdge[184, 224] -> 
             RGBColor[
              0.20007875304145373`, 0.32762583354516883`, 0.9347055610444963],
              UndirectedEdge[278, 295] -> 
             RGBColor[
              0.1987763965986568, 0.3262569743496216, 0.9346313937717428], 
             UndirectedEdge[28, 245] -> 
             RGBColor[
              0.204356271408755, 0.33212177655953135`, 0.9349491593874928], 
             UndirectedEdge[14, 186] -> 
             RGBColor[
              0.18665492193544975`, 0.31351653593270823`, 0.9339410937217879],
              UndirectedEdge[227, 241] -> 
             RGBColor[
              0.9694143471641505, 0.9193630503950179, 0.5802122280149764], 
             UndirectedEdge[121, 154] -> 
             RGBColor[
              0.3613735298324199, 0.47852983599420473`, 0.9448593103869043], 
             UndirectedEdge[187, 230] -> 
             RGBColor[
              0.20841284593944426`, 0.3363854935929662, 0.9351801753058513], 
             UndirectedEdge[125, 277] -> 
             RGBColor[
              0.8878000437756458, 0.5101704610030093, 0.28112006653243526`], 
             UndirectedEdge[62, 158] -> 
             RGBColor[
              0.1973113364505346, 0.3247171032437667, 0.9345479607636695], 
             UndirectedEdge[20, 61] -> 
             RGBColor[
              0.248131704384919, 0.378132532140237, 0.9374421055355356], 
             UndirectedEdge[64, 258] -> 
             RGBColor[
              0.28773302970917036`, 0.41685145648958927`, 0.939803693309408], 
             UndirectedEdge[94, 294] -> 
             RGBColor[
              0.6664691166979216, 0.7377414792197128, 0.9685045040434936], 
             UndirectedEdge[125, 237] -> 
             RGBColor[
              0.8318212025230813, 0.24559728349806995`, 0.17810532551399777`],
              UndirectedEdge[267, 300] -> 
             RGBColor[
              0.210925999504364, 0.33902697733283615`, 0.935323295683496], 
             UndirectedEdge[165, 175] -> 
             RGBColor[
              0.2002014223302363, 0.3277547667453615, 0.9347125468790196], 
             UndirectedEdge[67, 263] -> 
             RGBColor[
              0.19440813626729972`, 0.3216656557776636, 0.934382627808134], 
             UndirectedEdge[163, 298] -> 
             RGBColor[
              0.44064408929894633`, 0.5470342917552059, 0.9507221073701924], 
             UndirectedEdge[92, 149] -> 
             RGBColor[
              0.8528710620154377, 0.368495504363378, 0.19673945954906286`], 
             UndirectedEdge[95, 276] -> 
             RGBColor[
              0.2644651178260697, 0.3952999852651118, 0.9383722692678894], 
             UndirectedEdge[70, 231] -> 
             RGBColor[
              0.2204752799716199, 0.3490638765632734, 0.9358671130792118], 
             UndirectedEdge[239, 263] -> 
             RGBColor[
              0.22373268173624067`, 0.3524876123490904, 0.9360526172908128], 
             UndirectedEdge[116, 204] -> 
             RGBColor[
              0.38548007982804805`, 0.5055047110221348, 0.9460830998243401], 
             UndirectedEdge[121, 258] -> 
             RGBColor[
              0.28280548262609156`, 0.41167229208074363`, 0.9395230767926794],
              UndirectedEdge[95, 148] -> 
             RGBColor[
              0.2669268205335093, 0.3978873908915973, 0.9385124595953154], 
             UndirectedEdge[60, 77] -> 
             RGBColor[
              0.3505250523811867, 0.47604307306451876`, 0.9436288356859599], 
             UndirectedEdge[42, 269] -> 
             RGBColor[
              0.8827914555819929, 0.5004150429658535, 0.23917946980671936`], 
             UndirectedEdge[61, 136] -> 
             RGBColor[
              0.33493736709593636`, 0.46161647957078045`, 0.9426694828062012],
              UndirectedEdge[95, 251] -> 
             RGBColor[
              0.2865818395337517, 0.41854606206103384`, 0.9396317838503843], 
             UndirectedEdge[158, 265] -> 
             RGBColor[
              0.20783074668686696`, 0.3357736703712833, 0.9351470256145558], 
             UndirectedEdge[152, 208] -> 
             RGBColor[
              0.1859180316496269, 0.31274201752076575`, 0.9338991289101417], 
             UndirectedEdge[153, 285] -> 
             RGBColor[
              0.21037441724900163`, 0.3384472294101154, 0.9352918838900459], 
             UndirectedEdge[61, 279] -> 
             RGBColor[
              0.25696298277753227`, 0.387414765666264, 0.9379450337752894], 
             UndirectedEdge[82, 168] -> 
             RGBColor[
              0.5069255349638632, 0.6091474742003642, 0.9547231011630586], 
             UndirectedEdge[4, 249] -> 
             RGBColor[
              0.21399718138461848`, 0.3422549842131616, 0.93549819494817], 
             UndirectedEdge[75, 163] -> 
             RGBColor[
              0.47703987934410275`, 0.583052656791418, 0.9528766616787626], 
             UndirectedEdge[59, 290] -> 
             RGBColor[
              0.9657093115675036, 0.9066562806448499, 0.5869320799818273], 
             UndirectedEdge[205, 251] -> 
             RGBColor[
              0.3289835017199729, 0.45723137505526373`, 0.9422618471300848], 
             UndirectedEdge[183, 224] -> 
             RGBColor[
              0.2007040206651831, 0.3282830294619655, 0.9347411691106672], 
             UndirectedEdge[170, 178] -> 
             RGBColor[
              0.228293899528688, 0.35728174144686387`, 0.9363123718963757], 
             UndirectedEdge[102, 238] -> 
             RGBColor[
              0.18981943468321613`, 0.3168426394723074, 0.9341213080412961], 
             UndirectedEdge[89, 236] -> 
             RGBColor[
              0.30608763983959875`, 0.4323911560553985, 0.9409863461402914], 
             UndirectedEdge[65, 231] -> 
             RGBColor[
              0.30432205873480145`, 0.4308387652063516, 0.9408746918946544], 
             UndirectedEdge[25, 245] -> 
             RGBColor[
              0.2081790637788683, 0.33613977371955583`, 0.9351668617576563], 
             UndirectedEdge[217, 223] -> 
             RGBColor[
              0.19076430807847547`, 0.31783576131915836`, 0.9341751171833412],
              UndirectedEdge[254, 283] -> 
             RGBColor[
              0.3123013068939945, 0.44465097126766145`, 0.9411304437622906], 
             UndirectedEdge[168, 205] -> 
             RGBColor[
              0.3863855665846765, 0.5090894902975664, 0.9458411245288025], 
             UndirectedEdge[142, 243] -> 
             RGBColor[
              0.8824295641857295, 0.48375738073114377`, 0.40359576875504033`],
              UndirectedEdge[57, 278] -> 
             RGBColor[
              0.19015282278651957`, 0.31719305150690597`, 0.9341402940005757],
              UndirectedEdge[185, 218] -> 
             RGBColor[
              0.7483730046735189, 0.8020037075647066, 0.948265724399384], 
             UndirectedEdge[16, 248] -> 
             RGBColor[
              0.23437455245828825`, 0.36367289321153695`, 0.9366586560851965],
              UndirectedEdge[184, 275] -> 
             RGBColor[
              0.18583227383419235`, 0.31265188061938454`, 0.9338942451294201],
              UndirectedEdge[127, 191] -> 
             RGBColor[
              0.28810597904486807`, 0.41644150460043405`, 0.9398542953677421],
              UndirectedEdge[33, 153] -> 
             RGBColor[
              0.21078779737820008`, 0.338881718135717, 0.9353154252768627], 
             UndirectedEdge[83, 243] -> 
             RGBColor[
              0.8935075599716172, 0.5689077107501841, 0.41420407003041315`], 
             UndirectedEdge[94, 281] -> 
             RGBColor[
              0.8876751944238266, 0.9123560617360518, 0.9508666014010566], 
             UndirectedEdge[140, 293] -> 
             RGBColor[
              0.8447989221591355, 0.30198793171878546`, 0.18883486547410736`],
              UndirectedEdge[126, 220] -> 
             RGBColor[
              0.27828890051671973`, 0.40757894001897654`, 0.9392419230286206],
              UndirectedEdge[76, 220] -> 
             RGBColor[
              0.3300035970754238, 0.4602542621488369, 0.942248515288291], 
             UndirectedEdge[90, 126] -> 
             RGBColor[
              0.2195822201328165, 0.34812521404942687`, 0.9358162546425555], 
             UndirectedEdge[35, 102] -> 
             RGBColor[
              0.19929440110633984`, 0.32680142993057915`, 0.9346608933621363],
              UndirectedEdge[105, 235] -> 
             RGBColor[
              0.34616703863432685`, 0.47195151424914406`, 0.9433627489328582],
              UndirectedEdge[21, 287] -> 
             RGBColor[
              0.21828938866019382`, 0.34676636620145074`, 0.9357426298027625],
              UndirectedEdge[160, 245] -> 
             RGBColor[
              0.2105034515043503, 0.33858285259373117`, 0.935299232199999], 
             UndirectedEdge[235, 298] -> 
             RGBColor[
              0.33431581918328446`, 0.4594951311953859, 0.9426878395174293], 
             UndirectedEdge[15, 196] -> 
             RGBColor[
              0.23071789586563907`, 0.35982951528724394`, 0.9364504149017838],
              UndirectedEdge[13, 274] -> 
             RGBColor[
              0.3981676494624695, 0.5190303850989934, 0.9466648547482157], 
             UndirectedEdge[2, 172] -> 
             RGBColor[
              0.19458761473709335`, 0.321854299029009, 0.9343928488414741], 
             UndirectedEdge[247, 295] -> 
             RGBColor[
              0.1973396127760572, 0.3247468234547135, 0.9345495710585769], 
             UndirectedEdge[159, 225] -> 
             RGBColor[
              0.2594187152635208, 0.38999589621147046`, 0.9380848841074358], 
             UndirectedEdge[204, 254] -> 
             RGBColor[
              0.40119508956919725`, 0.5210943009518455, 0.9470120206751078], 
             UndirectedEdge[61, 252] -> 
             RGBColor[
              0.2576007602350303, 0.3880851102115208, 0.9379813542579867], 
             UndirectedEdge[4, 173] -> 
             RGBColor[
              0.21091230660044274`, 0.33901258522263467`, 0.9353225158928745],
              UndirectedEdge[230, 245] -> 
             RGBColor[
              0.20866400795240445`, 0.3366494807931788, 0.9351944786109285], 
             UndirectedEdge[137, 295] -> 
             RGBColor[
              0.2292284865221631, 0.35826405163324404`, 0.9363655952430565], 
             UndirectedEdge[109, 192] -> 
             RGBColor[
              0.6617142280646152, 0.7260405303844142, 0.8555444013688691], 
             UndirectedEdge[178, 229] -> 
             RGBColor[
              0.23836184028178953`, 0.36786378552268634`, 0.9368857262280812],
              UndirectedEdge[91, 93] -> 
             RGBColor[
              0.3656444287828603, 0.48387268995411137`, 0.9450248073537576], 
             UndirectedEdge[143, 185] -> 
             RGBColor[
              0.41822549913320267`, 0.5344264087640556, 0.9484481661960105], 
             UndirectedEdge[139, 273] -> 
             RGBColor[
              0.3398266519904991, 0.46230754637230465`, 0.9431107790825377], 
             UndirectedEdge[130, 281] -> 
             RGBColor[
              0.9451323785335899, 0.8357466481470239, 0.5846180445889815], 
             UndirectedEdge[220, 248] -> 
             RGBColor[
              0.27752408340790014`, 0.40677506874540165`, 0.9391983678257189],
              UndirectedEdge[88, 273] -> 
             RGBColor[
              0.23089430452924603`, 0.3600149319776501, 0.936460461114203], 
             UndirectedEdge[24, 218] -> 
             RGBColor[
              0.945476791560533, 0.8552536816107574, 0.5989703095762722], 
             UndirectedEdge[66, 215] -> 
             RGBColor[
              0.3055417316872413, 0.4312998537559559, 0.940974206355727], 
             UndirectedEdge[151, 154] -> 
             RGBColor[
              0.5475628360948273, 0.6435752036232633, 0.9575252987275946], 
             UndirectedEdge[8, 64] -> 
             RGBColor[
              0.21988638356939655`, 0.34844490910634823`, 0.9358335763002992],
              UndirectedEdge[71, 108] -> 
             RGBColor[
              0.23200115605283045`, 0.3611783031073773, 0.936523494671031], 
             UndirectedEdge[43, 182] -> 
             RGBColor[
              0.23996509971424826`, 0.36954891283871966`, 0.9369770294809499],
              UndirectedEdge[58, 297] -> 
             RGBColor[
              0.19156703343003767`, 0.3186794765593771, 0.934220831204587], 
             UndirectedEdge[46, 207] -> 
             RGBColor[
              0.1949982416588687, 0.3222858939590454, 0.9344162334372013], 
             UndirectedEdge[100, 266] -> 
             RGBColor[
              0.1894062944527255, 0.3164084028954582, 0.9340977803163559], 
             UndirectedEdge[12, 151] -> 
             RGBColor[
              0.5137240937710055, 0.6154599354387978, 0.9550391768879118], 
             UndirectedEdge[196, 265] -> 
             RGBColor[
              0.21288778030859679`, 0.34108893334217194`, 0.9354350161981024],
              UndirectedEdge[93, 139] -> 
             RGBColor[
              0.3409266080048823, 0.4634636698846607, 0.9431734199503177], 
             UndirectedEdge[30, 104] -> 
             RGBColor[
              0.2921921290764705, 0.4220073511871032, 0.9400404564262714], 
             UndirectedEdge[85, 121] -> 
             RGBColor[
              0.22879896787362192`, 0.35781260030057205`, 0.936341134791438], 
             UndirectedEdge[79, 160] -> 
             RGBColor[
              0.1894526235362595, 0.316457097699686, 0.9341004186891254], 
             UndirectedEdge[60, 196] -> 
             RGBColor[
              0.24516356622564123`, 0.3750128307440074, 0.9372730744583317], 
             UndirectedEdge[25, 297] -> 
             RGBColor[
              0.19155439006973912`, 0.318666187586068, 0.9342201111839221], 
             UndirectedEdge[9, 133] -> 
             RGBColor[
              0.19212471165815448`, 0.3192656317359698, 0.9342525901546672], 
             UndirectedEdge[151, 192] -> 
             RGBColor[
              0.4642226762503304, 0.5725842955959759, 0.9518849903358793], 
             UndirectedEdge[45, 141] -> 
             RGBColor[
              0.2968912603514489, 0.4293819169954668, 0.9402188901145307], 
             UndirectedEdge[177, 280] -> 
             RGBColor[
              0.27699231630764354`, 0.4084668651395046, 0.9390856746890857], 
             UndirectedEdge[141, 188] -> 
             RGBColor[
              0.3248560928052687, 0.45441830964122576`, 0.9419709558048517], 
             UndirectedEdge[129, 183] -> 
             RGBColor[
              0.1909140048229797, 0.31799310208895415`, 0.9341836421914842], 
             UndirectedEdge[41, 55] -> 
             RGBColor[
              0.19536579579315563`, 0.32267221665845913`, 0.9344371651014012],
              UndirectedEdge[120, 261] -> 
             RGBColor[
              0.2619133763504623, 0.3926179431844944, 0.9382269513658168], 
             UndirectedEdge[71, 279] -> 
             RGBColor[
              0.22999178600981598`, 0.35906632779075, 0.9364090640196779], 
             UndirectedEdge[180, 230] -> 
             RGBColor[
              0.1934850620461379, 0.3206954462449366, 0.9343300600968047], 
             UndirectedEdge[106, 194] -> 
             RGBColor[
              0.7739330746560312, 0.8236601401446212, 0.9780122537987794], 
             UndirectedEdge[90, 234] -> 
             RGBColor[
              0.20491562163947707`, 0.33270968911687326`, 0.9349810135556479],
              UndirectedEdge[44, 136] -> 
             RGBColor[
              0.3544174046992013, 0.48140027523890294`, 0.9438041415217957], 
             UndirectedEdge[120, 131] -> 
             RGBColor[
              0.2542490675591432, 0.38456226869957383`, 0.93779048031848], 
             UndirectedEdge[44, 279] -> 
             RGBColor[
              0.27644302038079716`, 0.4071985613343865, 0.9390796924908837], 
             UndirectedEdge[105, 139] -> 
             RGBColor[
              0.3622816914289454, 0.48590921655384295`, 0.9443895603593033], 
             UndirectedEdge[157, 184] -> 
             RGBColor[
              0.18701393581723674`, 0.31389388228526116`, 0.9339615390312422],
              UndirectedEdge[83, 149] -> 
             RGBColor[
              0.8628696595923687, 0.44534910675306505`, 0.20631412788053274`],
              UndirectedEdge[145, 168] -> 
             RGBColor[
              0.6326576416445393, 0.7081764296337532, 0.9668556680760403], 
             UndirectedEdge[112, 170] -> 
             RGBColor[
              0.1934039006537554, 0.3206101404756131, 0.9343254380755761], 
             UndirectedEdge[159, 270] -> 
             RGBColor[
              0.2520399731872973, 0.38224037045009085`, 0.9376646756620657], 
             UndirectedEdge[86, 162] -> 
             RGBColor[
              0.7927626721159106, 0.8360545204331631, 0.8771199562466196], 
             UndirectedEdge[3, 264] -> 
             RGBColor[
              0.6252141606717125, 0.697021267014214, 0.9512803143951285], 
             UndirectedEdge[60, 282] -> 
             RGBColor[
              0.36394977931359895`, 0.4876708967869795, 0.9444842474150733], 
             UndirectedEdge[135, 186] -> 
             RGBColor[
              0.20309625090443267`, 0.3307974151195744, 0.934877403083805], 
             UndirectedEdge[89, 294] -> 
             RGBColor[
              0.4583968818459615, 0.569215720181254, 0.9510502956112238], 
             UndirectedEdge[201, 203] -> 
             RGBColor[
              0.8759510922102913, 0.5506721053262738, 0.4578210075797024], 
             UndirectedEdge[181, 203] -> 
             RGBColor[
              0.961709527951959, 0.9590285203678879, 0.6962850331189814], 
             UndirectedEdge[70, 211] -> 
             RGBColor[
              0.24025127894135917`, 0.3698497053512242, 0.9369933269645696], 
             UndirectedEdge[156, 159] -> 
             RGBColor[
              0.3428661620319342, 0.4697766941100199, 0.9431273668629003], 
             UndirectedEdge[56, 270] -> 
             RGBColor[
              0.20609791902538932`, 0.3339523586314509, 0.9350483436427234], 
             UndirectedEdge[113, 264] -> 
             RGBColor[
              0.28192127958218227`, 0.41364751805536637`, 0.939366371855823], 
             UndirectedEdge[144, 240] -> 
             RGBColor[
              0.18908519234139687`, 0.31607090421740214`, 0.9340794940261437],
              UndirectedEdge[231, 232] -> 
             RGBColor[
              0.20954424282732975`, 0.33757466345683984`, 0.9352446066848648],
              UndirectedEdge[90, 248] -> 
             RGBColor[
              0.21881740302399694`, 0.347321342775852, 0.9357726994396538], 
             UndirectedEdge[27, 109] -> 
             RGBColor[
              0.9813263327288758, 0.9506128482774708, 0.5530707745780536], 
             UndirectedEdge[42, 145] -> 
             RGBColor[
              0.8467044438902113, 0.49173965579450474`, 0.4514212603342903], 
             UndirectedEdge[160, 230] -> 
             RGBColor[
              0.19392496192438957`, 0.3211578089082423, 0.9343551117440977], 
             UndirectedEdge[247, 251] -> 
             RGBColor[
              0.24168185283923999`, 0.37135332922152087`, 0.9370747960317096],
              UndirectedEdge[109, 220] -> 
             RGBColor[
              0.6629503007752218, 0.7271111544395208, 0.8556231628289728], 
             UndirectedEdge[139, 163] -> 
             RGBColor[
              0.5309367698880918, 0.6297354344441368, 0.9563109238850767], 
             UndirectedEdge[31, 279] -> 
             RGBColor[
              0.32815763679560045`, 0.4519911628206914, 0.9423749021193952], 
             UndirectedEdge[9, 112] -> 
             RGBColor[
              0.19409572030031721`, 0.3213372867880486, 0.9343648361809924], 
             UndirectedEdge[196, 276] -> 
             RGBColor[
              0.22221678398010425`, 0.35089430769392205`, 0.9359662891561706],
              UndirectedEdge[137, 251] -> 
             RGBColor[
              0.27357072658534587`, 0.4048705574000514, 0.9388908202161892], 
             UndirectedEdge[162, 181] -> 
             RGBColor[
              0.9888211205061603, 0.9780593840975029, 0.5971500192561076], 
             UndirectedEdge[96, 236] -> 
             RGBColor[
              0.2161907003932258, 0.34456051176834573`, 0.9356231126106896], 
             UndirectedEdge[251, 295] -> 
             RGBColor[
              0.24126505067228732`, 0.3709152437172699, 0.9370510597649051], 
             UndirectedEdge[20, 268] -> 
             RGBColor[
              0.21202685048114545`, 0.34018404150741677`, 0.9353859875180606],
              UndirectedEdge[187, 215] -> 
             RGBColor[
              0.224740944415305, 0.35354736035233314`, 0.9361100363587946], 
             UndirectedEdge[55, 250] -> 
             RGBColor[
              0.1923953966842939, 0.31955013886086425`, 0.9342680052664631], 
             UndirectedEdge[193, 230] -> 
             RGBColor[
              0.2358246326636532, 0.3651970194477707, 0.9367412360076905], 
             UndirectedEdge[55, 242] -> 
             RGBColor[
              0.19150951150427703`, 0.318619017368302, 0.9342175554160109], 
             UndirectedEdge[51, 116] -> 
             RGBColor[
              0.5493242790295518, 0.6359329023080253, 0.960750884061716], 
             UndirectedEdge[130, 203] -> 
             RGBColor[
              0.92446413705714, 0.8203323074950271, 0.6196039862679017], 
             UndirectedEdge[34, 124] -> 
             RGBColor[
              0.1848087064384265, 0.3115760463885134, 0.9338359544804635], 
             UndirectedEdge[190, 261] -> 
             RGBColor[
              0.2245754678269734, 0.353373433966175, 0.9361006127118898], 
             UndirectedEdge[76, 85] -> 
             RGBColor[
              0.2795331222505161, 0.40945731042738504`, 0.9392918866244364], 
             UndirectedEdge[130, 237] -> 
             RGBColor[
              0.8539841698020644, 0.35850563187745466`, 0.19706087949209944`],
              UndirectedEdge[175, 183] -> 
             RGBColor[
              0.18767445593923526`, 0.3145881308128762, 0.9339991546750381], 
             UndirectedEdge[93, 289] -> 
             RGBColor[
              0.24228732684798865`, 0.37198972079398507`, 0.9371092768807893],
              UndirectedEdge[69, 234] -> 
             RGBColor[
              0.20086201360397116`, 0.32844909005796263`, 0.9347501665748015],
              UndirectedEdge[32, 269] -> 
             RGBColor[
              0.980420530285405, 0.9551564158081671, 0.6020762664235486], 
             UndirectedEdge[226, 243] -> 
             RGBColor[
              0.9868373224355939, 0.9888249088088037, 0.8678031613671959], 
             UndirectedEdge[72, 218] -> 
             RGBColor[
              0.875340160780385, 0.47642064776789905`, 0.430675613342974], 
             UndirectedEdge[81, 181] -> 
             RGBColor[
              0.9378794291938042, 0.7781980948822975, 0.31536710248397326`], 
             UndirectedEdge[8, 67] -> 
             RGBColor[
              0.1916976136601492, 0.31881672466048916`, 0.9342282675555156], 
             UndirectedEdge[145, 156] -> 
             RGBColor[
              0.6296976932681398, 0.7056126711214472, 0.9666670627828757], 
             UndirectedEdge[20, 177] -> 
             RGBColor[
              0.2554879446971804, 0.38586440712099823`, 0.9378610325387366], 
             UndirectedEdge[180, 297] -> 
             RGBColor[
              0.19343887791696943`, 0.3206469037969376, 0.9343274299789719], 
             UndirectedEdge[140, 216] -> 
             RGBColor[
              0.8337005726178471, 0.2515929185371857, 0.1795741305714151], 
             UndirectedEdge[287, 300] -> 
             RGBColor[
              0.2343234420650949, 0.3636191729477046, 0.9366557454239152], 
             UndirectedEdge[140, 167] -> 
             RGBColor[
              0.847440007720582, 0.31331700517270195`, 0.1910043309119193], 
             UndirectedEdge[248, 285] -> 
             RGBColor[
              0.21081919728396287`, 0.3389147214275427, 0.9353172134550438], 
             UndirectedEdge[185, 292] -> 
             RGBColor[
              0.6516360083701964, 0.726054278090207, 0.9670940826236099], 
             UndirectedEdge[23, 241] -> 
             RGBColor[
              0.9877354309295805, 0.9891962997514028, 0.8529191793915591], 
             UndirectedEdge[10, 48] -> 
             RGBColor[
              0.19160641114189197`, 0.3187208650312271, 0.934223073707023], 
             UndirectedEdge[46, 62] -> 
             RGBColor[
              0.20319287451419632`, 0.3308989726597267, 0.9348829056554392], 
             UndirectedEdge[15, 276] -> 
             RGBColor[
              0.24987495920564082`, 0.37996480348555506`, 0.9375413813186614],
              UndirectedEdge[85, 154] -> 
             RGBColor[
              0.36472305205370464`, 0.48205039622074985`, 0.9450500607222323],
              UndirectedEdge[32, 179] -> 
             RGBColor[
              0.7552164634617963, 0.8063041539020928, 0.9047369408488604], 
             UndirectedEdge[145, 277] -> 
             RGBColor[
              0.9289575250796454, 0.9412874203114796, 0.7338327759362018], 
             UndirectedEdge[58, 164] -> 
             RGBColor[
              0.1865510290497441, 0.3134073379226422, 0.9339351771756428], 
             UndirectedEdge[18, 253] -> 
             RGBColor[
              0.19591234458530662`, 0.3232466740922047, 0.9344682902465677], 
             UndirectedEdge[59, 136] -> 
             RGBColor[
              0.6888115905499252, 0.7512769242124885, 0.9221815319720392], 
             UndirectedEdge[232, 288] -> 
             RGBColor[
              0.19838654644971515`, 0.32584721712515685`, 0.9346091923824922],
              UndirectedEdge[136, 177] -> 
             RGBColor[
              0.34229360740819775`, 0.46934835455154167`, 0.9430884098094023],
              UndirectedEdge[31, 65] -> 
             RGBColor[
              0.3985559674737674, 0.5196308798455622, 0.9466166117115924], 
             UndirectedEdge[62, 214] -> 
             RGBColor[
              0.20125370240405008`, 0.3288607798213499, 0.9347724726725144], 
             UndirectedEdge[24, 109] -> 
             RGBColor[
              0.9582875876148832, 0.8633759964057863, 0.5131590613985512], 
             UndirectedEdge[71, 268] -> 
             RGBColor[
              0.21418318831071842`, 0.34245048928601285`, 0.9355087877674388],
              UndirectedEdge[64, 118] -> 
             RGBColor[
              0.2120127678097534, 0.3401692397268907, 0.9353851855307582], 
             UndirectedEdge[21, 206] -> 
             RGBColor[
              0.20800021126608947`, 0.33595178838872103`, 0.9351566763716421],
              UndirectedEdge[6, 124] -> 
             RGBColor[
              0.19825974011141095`, 0.3257139356236129, 0.9346019709491189], 
             UndirectedEdge[7, 140] -> 
             RGBColor[
              0.8576525620588931, 0.4072578344865292, 0.4392429539624352], 
             UndirectedEdge[78, 229] -> 
             RGBColor[
              0.20592187570768378`, 0.3337673259427514, 0.9350383182362128], 
             UndirectedEdge[67, 213] -> 
             RGBColor[
              0.19065103236232478`, 0.3177167013593888, 0.9341686662988828], 
             UndirectedEdge[189, 300] -> 
             RGBColor[
              0.22074088939765935`, 0.34934304891065115`, 0.9358822391430908],
              UndirectedEdge[77, 225] -> 
             RGBColor[
              0.32068966156322254`, 0.4446841856418027, 0.9419297543163823], 
             UndirectedEdge[153, 239] -> 
             RGBColor[
              0.22932262896951866`, 0.3583630013143907, 0.9363709565161622], 
             UndirectedEdge[7, 168] -> 
             RGBColor[
              0.6693655533207783, 0.7373787417141351, 0.9680138507113893], 
             UndirectedEdge[5, 256] -> 
             RGBColor[
              0.868956298803952, 0.39716627197470655`, 0.223830917733355], 
             UndirectedEdge[193, 200] -> 
             RGBColor[
              0.3225670309120143, 0.4511149836272068, 0.9418734544780243], 
             UndirectedEdge[17, 202] -> 
             RGBColor[
              0.8122682039505371, 0.5808158857565188, 0.4639498679202687], 
             UndirectedEdge[12, 220] -> 
             RGBColor[
              0.38135478455479077`, 0.5047320797577364, 0.9455205675464041], 
             UndirectedEdge[196, 207] -> 
             RGBColor[
              0.19417373721693681`, 0.32141928751397403`, 0.9343692791289782],
              UndirectedEdge[222, 285] -> 
             RGBColor[
              0.21055261927690455`, 0.33863453104010255`, 0.9353020322319088],
              UndirectedEdge[169, 227] -> 
             RGBColor[
              0.7787217249901721, 0.7700947212036731, 0.6214147685810579], 
             UndirectedEdge[139, 298] -> 
             RGBColor[
              0.350430471977903, 0.4734528335000848, 0.9437146509438744], 
             UndirectedEdge[210, 241] -> 
             RGBColor[
              0.7289016289330998, 0.7852496727746727, 0.9155863904520005], 
             UndirectedEdge[58, 288] -> 
             RGBColor[
              0.200003126765576, 0.32754634553423856`, 0.9347012542399642], 
             UndirectedEdge[85, 258] -> 
             RGBColor[
              0.2861550048473763, 0.41519285230728875`, 0.9397138271280076], 
             UndirectedEdge[87, 162] -> 
             RGBColor[
              0.9922481634967688, 0.9892215006042993, 0.6443153424349913], 
             UndirectedEdge[222, 248] -> 
             RGBColor[
              0.22169214906401963`, 0.3503428831333422, 0.9359364119738274], 
             UndirectedEdge[76, 87] -> 
             RGBColor[
              0.6600329022141906, 0.7226670785503484, 0.7188188011286823], 
             UndirectedEdge[80, 282] -> 
             RGBColor[
              0.7097202776306235, 0.7481265393121519, 0.6607363832345532], 
             UndirectedEdge[273, 289] -> 
             RGBColor[
              0.24118737083360547`, 0.370833597281629, 0.9370466360130092], 
             UndirectedEdge[215, 296] -> 
             RGBColor[
              0.20597442651804665`, 0.33382256017635653`, 0.935041310927121], 
             UndirectedEdge[142, 277] -> 
             RGBColor[
              0.8842941238717467, 0.48322242431774326`, 0.2777627936730913], 
             UndirectedEdge[134, 180] -> 
             RGBColor[
              0.21984183187712564`, 0.34839808245303105`, 0.9358310391473328],
              UndirectedEdge[86, 178] -> 
             RGBColor[
              0.4265942001520806, 0.5354932240498018, 0.9496283130255976], 
             UndirectedEdge[3, 210] -> 
             RGBColor[
              0.7129487102103079, 0.7736730218742174, 0.9569659936880668], 
             UndirectedEdge[79, 176] -> 
             RGBColor[
              0.18866673983198834`, 0.31563108409859225`, 0.9340556637747779],
              UndirectedEdge[131, 141] -> 
             RGBColor[
              0.26162779894186294`, 0.392317783221403, 0.938210688154871], 
             UndirectedEdge[150, 256] -> 
             RGBColor[
              0.8477552075952007, 0.3160779656240866, 0.191320067694982], 
             UndirectedEdge[74, 300] -> 
             RGBColor[
              0.2157736566163444, 0.3441221723167407, 0.9355993625845572], 
             UndirectedEdge[25, 230] -> 
             RGBColor[
              0.19160057419890764`, 0.31871473003406703`, 0.934222741301755], 
             UndirectedEdge[165, 253] -> 
             RGBColor[
              0.20482209384336109`, 0.3326113854731506, 0.9349756872860211], 
             UndirectedEdge[223, 295] -> 
             RGBColor[
              0.1892065910771333, 0.3161985019857855, 0.9340864075045505], 
             UndirectedEdge[164, 221] -> 
             RGBColor[
              0.184078374522518, 0.31080842123917557`, 0.9337943631582817], 
             UndirectedEdge[70, 138] -> 
             RGBColor[
              0.22052881830414905`, 0.3491201487452879, 0.9358701620080464], 
             UndirectedEdge[165, 224] -> 
             RGBColor[
              0.21323098705618415`, 0.3414496653944509, 0.9354545613146487], 
             UndirectedEdge[87, 258] -> 
             RGBColor[
              0.6666547848110509, 0.7284026204302521, 0.7192407416322534], 
             UndirectedEdge[90, 222] -> 
             RGBColor[
              0.2185508250169386, 0.3470411523884118, 0.9357575182165185], 
             UndirectedEdge[163, 185] -> 
             RGBColor[
              0.5753534134295759, 0.6661368462548543, 0.9597130747756251], 
             UndirectedEdge[64, 286] -> 
             RGBColor[
              0.22809764059378232`, 0.35707546086274283`, 0.9363011952403719],
              UndirectedEdge[131, 199] -> 
             RGBColor[
              0.21390129447571837`, 0.3421542009923264, 0.9354927343305601], 
             UndirectedEdge[2, 49] -> 
             RGBColor[
              0.20410648254439653`, 0.3318592326255619, 0.934934934281197], 
             UndirectedEdge[51, 283] -> 
             RGBColor[
              0.5585587587049552, 0.6456389259467026, 0.9612767740180419], 
             UndirectedEdge[66, 187] -> 
             RGBColor[
              0.305540960778381, 0.4312990434818653, 0.9409741624536079], 
             UndirectedEdge[120, 170] -> 
             RGBColor[
              0.23833338730926568`, 0.3678338796445412, 0.9368841058733883], 
             UndirectedEdge[17, 182] -> 
             RGBColor[
              0.47900337512465124`, 0.5765439495002909, 0.9544470440825916], 
             UndirectedEdge[156, 179] -> 
             RGBColor[
              0.4586241439822036, 0.5697734899723961, 0.9509650514168311], 
             UndirectedEdge[199, 284] -> 
             RGBColor[
              0.21967623885350168`, 0.3482240336859982, 0.9358216088696103], 
             UndirectedEdge[210, 291] -> 
             RGBColor[
              0.6992769373373419, 0.7632490848408453, 0.9722193956891239], 
             UndirectedEdge[212, 265] -> 
             RGBColor[
              0.22804223773896515`, 0.3570172289495861, 0.9362980401297512], 
             UndirectedEdge[85, 173] -> 
             RGBColor[
              0.21671771694106706`, 0.34511443957490595`, 0.9356531254234381],
              UndirectedEdge[47, 146] -> 
             RGBColor[
              0.19206431623757236`, 0.3192021523196471, 0.9342491507248121], 
             UndirectedEdge[198, 283] -> 
             RGBColor[
              0.6352059189617083, 0.705940028417498, 0.9427748448450561], 
             UndirectedEdge[168, 212] -> 
             RGBColor[
              0.31689002798285826`, 0.4419267953395609, 0.941668105069032], 
             UndirectedEdge[56, 271] -> 
             RGBColor[
              0.21099595483626973`, 0.3391005048220933, 0.9353272795361584], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.33246233459167696`, 0.45559373221858496`, 0.9426538050639501],
              UndirectedEdge[159, 191] -> 
             RGBColor[
              0.25930875612416715`, 0.38988032218419766`, 0.9380786220971196],
              UndirectedEdge[72, 83] -> 
             RGBColor[
              0.8351278328210138, 0.271013492942614, 0.1812717584216026], 
             UndirectedEdge[179, 277] -> 
             RGBColor[
              0.7578839757937091, 0.8054482391624284, 0.7181307645701571], 
             UndirectedEdge[86, 182] -> 
             RGBColor[
              0.4242603384632414, 0.5330401874394541, 0.9494954030550571], 
             UndirectedEdge[80, 293] -> 
             RGBColor[
              0.9392835874613179, 0.7889438610995526, 0.30512184711932616`], 
             UndirectedEdge[9, 96] -> 
             RGBColor[
              0.19995528537104273`, 0.3274960611952644, 0.9346985297433206], 
             UndirectedEdge[51, 226] -> 
             RGBColor[
              0.8987769385879059, 0.920547716985024, 0.9296222387004919], 
             UndirectedEdge[185, 235] -> 
             RGBColor[
              0.4690251433139141, 0.5785976856950342, 0.951678806922862], 
             UndirectedEdge[136, 210] -> 
             RGBColor[
              0.43214727310106515`, 0.5482274348494092, 0.9488947696323751], 
             UndirectedEdge[78, 284] -> 
             RGBColor[
              0.2175445595822431, 0.34598350361563335`, 0.935700212888649], 
             UndirectedEdge[81, 216] -> 
             RGBColor[
              0.8741307766845507, 0.521339079076086, 0.216683973539649], 
             UndirectedEdge[2, 165] -> 
             RGBColor[
              0.2081927032562806, 0.336154109675109, 0.935167638505717], 
             UndirectedEdge[181, 216] -> 
             RGBColor[
              0.9064071332493737, 0.6461593249941886, 0.2739426170686603], 
             UndirectedEdge[7, 203] -> 
             RGBColor[
              0.9377223890197792, 0.9530740402179558, 0.990303930173889], 
             UndirectedEdge[44, 177] -> 
             RGBColor[
              0.3040955168977345, 0.4362630884432308, 0.9406544612593207], 
             UndirectedEdge[140, 237] -> 
             RGBColor[
              0.8199042211924654, 0.15399814293643901`, 0.1666936107334946], 
             UndirectedEdge[38, 124] -> 
             RGBColor[
              0.186021974396972, 0.31285126793857626`, 0.9339050482958335], 
             UndirectedEdge[5, 59] -> 
             RGBColor[
              0.978010186853574, 0.9509747189595588, 0.6200075845730131], 
             UndirectedEdge[35, 253] -> 
             RGBColor[
              0.19912169776175326`, 0.3266199077653942, 0.9346510581621539], 
             UndirectedEdge[200, 231] -> 
             RGBColor[
              0.2983755222047893, 0.4256881741456715, 0.9404957838452779], 
             UndirectedEdge[213, 234] -> 
             RGBColor[
              0.19826511451334394`, 0.3257195844608012, 0.9346022770133582], 
             UndirectedEdge[53, 88] -> 
             RGBColor[
              0.21936792560639845`, 0.34789997691510377`, 0.9358040508862964],
              UndirectedEdge[150, 269] -> 
             RGBColor[
              0.9402871560451271, 0.7958786263011822, 0.2973043850963], 
             UndirectedEdge[4, 135] -> 
             RGBColor[
              0.21680708920312736`, 0.3452083754888601, 0.935658215041548], 
             UndirectedEdge[91, 139] -> 
             RGBColor[
              0.4654409733450266, 0.5765629962584664, 0.9511548548621985], 
             UndirectedEdge[28, 232] -> 
             RGBColor[
              0.18568890069969585`, 0.3125011863646469, 0.9338860802415121], 
             UndirectedEdge[127, 276] -> 
             RGBColor[
              0.29510454675664893`, 0.4237974430003376, 0.9402528534454749], 
             UndirectedEdge[60, 103] -> 
             RGBColor[
              0.35429852491084235`, 0.47931146530946245`, 0.9438692780187988],
              UndirectedEdge[145, 159] -> 
             RGBColor[
              0.5780723315879956, 0.6592789022873965, 0.963436800696632], 
             UndirectedEdge[20, 252] -> 
             RGBColor[
              0.2284732256377411, 0.3574702245574107, 0.936322584252997], 
             UndirectedEdge[80, 128] -> 
             RGBColor[
              0.889562972527344, 0.5443500198966912, 0.25117046231774093`], 
             UndirectedEdge[167, 237] -> 
             RGBColor[
              0.8526104501055128, 0.35305929104558004`, 0.1959555523789085], 
             UndirectedEdge[24, 291] -> 
             RGBColor[
              0.9253194185531315, 0.839992794616319, 0.6252021408895034], 
             UndirectedEdge[22, 244] -> 
             RGBColor[
              0.18902260313051494`, 0.31600511898838, 0.9340759296631764], 
             UndirectedEdge[51, 83] -> 
             RGBColor[
              0.8348006374064919, 0.5233895828676642, 0.45541678825261045`], 
             UndirectedEdge[29, 229] -> 
             RGBColor[
              0.20648377022612274`, 0.3343579127078008, 0.9350703172977894], 
             UndirectedEdge[151, 181] -> 
             RGBColor[
              0.7920610111090953, 0.8249056195457978, 0.6813687144574905], 
             UndirectedEdge[22, 63] -> 
             RGBColor[
              0.18571205303560948`, 0.312525520937635, 0.9338873987327916], 
             UndirectedEdge[163, 292] -> 
             RGBColor[
              0.6974329821497556, 0.7632343245346107, 0.9706993881593793], 
             UndirectedEdge[247, 289] -> 
             RGBColor[
              0.22060050259813557`, 0.34919549348331447`, 0.9358742443225416],
              UndirectedEdge[155, 299] -> 
             RGBColor[
              0.8545672117145955, 0.3449853666875312, 0.19687926573825648`], 
             UndirectedEdge[31, 71] -> 
             RGBColor[
              0.32148269623256015`, 0.4449753770732606, 0.9419947741290198], 
             UndirectedEdge[45, 260] -> 
             RGBColor[
              0.2790511539192304, 0.41063083400712647`, 0.9392029224452882], 
             UndirectedEdge[80, 125] -> 
             RGBColor[
              0.8830657841456923, 0.4944097829092139, 0.2449487473859466], 
             UndirectedEdge[97, 261] -> 
             RGBColor[
              0.34679730240272766`, 0.46888200483462256`, 0.9435352867345028],
              UndirectedEdge[107, 147] -> 
             RGBColor[
              0.3109365240034128, 0.43492372492699083`, 0.9413563604380197], 
             UndirectedEdge[15, 286] -> 
             RGBColor[
              0.23963340623012278`, 0.3692002819563222, 0.9369581400277256], 
             UndirectedEdge[94, 202] -> 
             RGBColor[
              0.8433434284333755, 0.6050920873029656, 0.46704715588223444`], 
             UndirectedEdge[86, 130] -> 
             RGBColor[
              0.75299012475597, 0.6847273872222507, 0.6045439579169226], 
             UndirectedEdge[73, 161] -> 
             RGBColor[
              0.19216173018569271`, 0.31930454055552265`, 0.9342546983050465],
              UndirectedEdge[7, 167] -> 
             RGBColor[
              0.9230008546692128, 0.8126082594888467, 0.6169349273115317], 
             UndirectedEdge[288, 297] -> 
             RGBColor[
              0.20042924344964513`, 0.3279942211865534, 0.9347255209547387], 
             UndirectedEdge[15, 46] -> 
             RGBColor[
              0.23154240030757095`, 0.3606961217323153, 0.9364973692100068], 
             UndirectedEdge[1, 92] -> 
             RGBColor[
              0.8229805000264965, 0.17764377008878246`, 0.16963945881912273`],
              UndirectedEdge[85, 213] -> 
             RGBColor[
              0.21726177740977812`, 0.34568628162294734`, 0.9356841088622658],
              UndirectedEdge[2, 174] -> 
             RGBColor[
              0.21589796346133705`, 0.34425282669233714`, 0.9356064416754841],
              UndirectedEdge[104, 204] -> 
             RGBColor[
              0.40934807922423605`, 0.5281560108098651, 0.9475315219665212], 
             UndirectedEdge[125, 243] -> 
             RGBColor[
              0.8859354840896285, 0.5107054174164098, 0.4069530416143843], 
             UndirectedEdge[149, 243] -> 
             RGBColor[
              0.9414606577081649, 0.8037269245686582, 0.5463530672768225], 
             UndirectedEdge[35, 175] -> 
             RGBColor[
              0.19450102624862847`, 0.3217632890376051, 0.9343879177551523], 
             UndirectedEdge[82, 201] -> 
             RGBColor[
              0.7680559447436146, 0.4654815691448476, 0.44828646235642633`], 
             UndirectedEdge[39, 69] -> 
             RGBColor[
              0.20464654155210055`, 0.3324268688843776, 0.9349656898427401], 
             UndirectedEdge[5, 204] -> 
             RGBColor[
              0.7273105149978081, 0.7527675975931751, 0.6471903809836539], 
             UndirectedEdge[107, 277] -> 
             RGBColor[
              0.7007432409432577, 0.7578412318622451, 0.7139688588587303], 
             UndirectedEdge[236, 260] -> 
             RGBColor[
              0.2447992469285118, 0.3746299080635468, 0.9372523270133223], 
             UndirectedEdge[11, 51] -> 
             RGBColor[
              0.6715557743614986, 0.7416503460034106, 0.9690558457242018], 
             UndirectedEdge[41, 242] -> 
             RGBColor[
              0.18473837996455222`, 0.31150212880551553`, 0.933831949491815], 
             UndirectedEdge[53, 93] -> 
             RGBColor[
              0.22850372850548528`, 0.3575022850054033, 0.93632432134619], 
             UndirectedEdge[82, 293] -> 
             RGBColor[
              0.7565992079701278, 0.6673833817942012, 0.600389979606483], 
             UndirectedEdge[76, 151] -> 
             RGBColor[
              0.46237290629163863`, 0.5709821178298984, 0.9517671246297987], 
             UndirectedEdge[130, 269] -> 
             RGBColor[
              0.9424840400754735, 0.8045885394133, 0.29907204955461253`], 
             UndirectedEdge[13, 289] -> 
             RGBColor[
              0.2883666647778183, 0.41815288261871875`, 0.9398165114828785], 
             UndirectedEdge[86, 120] -> 
             RGBColor[
              0.4366336879326583, 0.5460453622474791, 0.9502000470026102], 
             UndirectedEdge[86, 284] -> 
             RGBColor[
              0.41756739126480746`, 0.526005475576538, 0.9491142496134344], 
             UndirectedEdge[49, 102] -> 
             RGBColor[
              0.20090857647606358`, 0.32849803058878846`, 0.9347528182614836],
              UndirectedEdge[27, 299] -> 
             RGBColor[
              0.8690764337400362, 0.3997735335743823, 0.222803191736427], 
             UndirectedEdge[120, 182] -> 
             RGBColor[
              0.2667169591353605, 0.3976668132561618, 0.9385005082991529], 
             UndirectedEdge[97, 182] -> 
             RGBColor[
              0.35160088518762583`, 0.47393087490628993`, 0.9438088436678389],
              UndirectedEdge[42, 130] -> 
             RGBColor[
              0.8623375503659444, 0.42271337536614007`, 0.20506008615386487`],
              UndirectedEdge[15, 127] -> 
             RGBColor[
              0.3036056586421837, 0.43273265059365945`, 0.9407369791910881], 
             UndirectedEdge[28, 176] -> 
             RGBColor[
              0.18883134167646898`, 0.3158040910735011, 0.9340650376063144], 
             UndirectedEdge[26, 35] -> 
             RGBColor[
              0.21774452951257628`, 0.3461936846912394, 0.9357116008803525], 
             UndirectedEdge[44, 59] -> 
             RGBColor[
              0.650613500039462, 0.7181916581041776, 0.9197475834219577], 
             UndirectedEdge[155, 218] -> 
             RGBColor[
              0.9467517036363646, 0.8603082831521655, 0.5999961337585191], 
             UndirectedEdge[65, 155] -> 
             RGBColor[
              0.6518886127524492, 0.6234637492866453, 0.6024205995762867], 
             UndirectedEdge[55, 252] -> 
             RGBColor[
              0.22003960441036646`, 0.34860595392497, 0.9358423020005227], 
             UndirectedEdge[160, 296] -> 
             RGBColor[
              0.1914857715941317, 0.31859406521754197`, 0.9342162034632482], 
             UndirectedEdge[88, 147] -> 
             RGBColor[
              0.21812810554997109`, 0.34659684742666674`, 0.9357334449682322],
              UndirectedEdge[204, 243] -> 
             RGBColor[
              0.7355129252278461, 0.7903594474546665, 0.9053392735975632], 
             UndirectedEdge[65, 106] -> 
             RGBColor[
              0.6196619973862446, 0.6970249085872788, 0.9659794196694249], 
             UndirectedEdge[115, 245] -> 
             RGBColor[
              0.2884856169676899, 0.4165730051879058, 0.9398857105111442], 
             UndirectedEdge[60, 205] -> 
             RGBColor[
              0.3298135622578278, 0.45810382130942706`, 0.9423091178497511], 
             UndirectedEdge[75, 111] -> 
             RGBColor[
              0.4735665439631073, 0.5802328466571501, 0.952603227994324], 
             UndirectedEdge[17, 86] -> 
             RGBColor[
              0.648920103921949, 0.7249224984916083, 0.966146582786049], 
             UndirectedEdge[67, 166] -> 
             RGBColor[
              0.1825106958270533, 0.309160691533672, 0.9337050861757479], 
             UndirectedEdge[3, 169] -> 
             RGBColor[
              0.7794786659769637, 0.8276850371059405, 0.962203475513276], 
             UndirectedEdge[7, 255] -> 
             RGBColor[
              0.6521687790491231, 0.722483760175034, 0.9669180874613099], 
             UndirectedEdge[211, 231] -> 
             RGBColor[
              0.25095672851015194`, 0.3811018116127316, 0.937602986480219], 
             UndirectedEdge[218, 290] -> 
             RGBColor[
              0.956800253470921, 0.9001474347654498, 0.6080814328251828], 
             UndirectedEdge[201, 269] -> 
             RGBColor[
              0.8879643608891803, 0.5401762599384556, 0.244133049770843], 
             UndirectedEdge[34, 223] -> 
             RGBColor[
              0.1825916590093845, 0.3092457889716643, 0.9337096969092074], 
             UndirectedEdge[63, 208] -> 
             RGBColor[
              0.1860996055764639, 0.3129328632303233, 0.9339094692766605], 
             UndirectedEdge[131, 190] -> 
             RGBColor[
              0.21691115903565433`, 0.3453177594812544, 0.9356641416645529], 
             UndirectedEdge[27, 181] -> 
             RGBColor[
              0.9780677338465346, 0.9376794577026863, 0.3692977168650637], 
             UndirectedEdge[108, 136] -> 
             RGBColor[
              0.3166504809342749, 0.4423958027593246, 0.9416280716923184], 
             UndirectedEdge[101, 254] -> 
             RGBColor[
              0.4830549298600605, 0.587475687952538, 0.9535083702036646], 
             UndirectedEdge[62, 212] -> 
             RGBColor[
              0.2175228275026328, 0.34596066182206947`, 0.9356989752788649], 
             UndirectedEdge[69, 195] -> 
             RGBColor[
              0.1956464700099377, 0.32296722305607023`, 0.9344531490828267], 
             UndirectedEdge[136, 252] -> 
             RGBColor[
              0.3152788883487585, 0.44095417198795417`, 0.9415499615236627], 
             UndirectedEdge[26, 175] -> 
             RGBColor[
              0.20585209939384108`, 0.33369398661282884`, 0.9350343445783642],
              UndirectedEdge[24, 27] -> 
             RGBColor[
              0.9468027585380377, 0.8226935997742366, 0.2974286527731346], 
             UndirectedEdge[231, 266] -> 
             RGBColor[
              0.21466524015743277`, 0.342957156340762, 0.9355362399069774], 
             UndirectedEdge[153, 157] -> 
             RGBColor[
              0.2018036290672552, 0.32943878761174283`, 0.9348037901824403], 
             UndirectedEdge[161, 244] -> 
             RGBColor[
              0.19557921069497186`, 0.3228965292515542, 0.9344493187643406], 
             UndirectedEdge[128, 150] -> 
             RGBColor[
              0.865763307775837, 0.454496114812273, 0.2085646447651994], 
             UndirectedEdge[113, 200] -> 
             RGBColor[
              0.3166014610591278, 0.4448447914728484, 0.9415337241001722], 
             UndirectedEdge[211, 264] -> 
             RGBColor[
              0.28347133969758304`, 0.41527672951614025`, 0.9394546454862865],
              UndirectedEdge[144, 232] -> 
             RGBColor[
              0.19277383312180774`, 0.31994789955094727`, 0.9342895566617331],
              UndirectedEdge[208, 244] -> 
             RGBColor[
              0.18941015567136937`, 0.31641246128106837`, 0.9340980002070455],
              UndirectedEdge[47, 133] -> 
             RGBColor[
              0.18469446291568115`, 0.3114559692026503, 0.9338294484808514], 
             UndirectedEdge[181, 258] -> 
             RGBColor[
              0.6632277418204424, 0.717240503923456, 0.6720754184533696], 
             UndirectedEdge[53, 147] -> 
             RGBColor[
              0.21463757351182716`, 0.3429280769420639, 0.9355346643324394], 
             UndirectedEdge[123, 267] -> 
             RGBColor[
              0.19740462411574278`, 0.32481515449468, 0.9345532733581963], 
             UndirectedEdge[59, 227] -> 
             RGBColor[
              0.9688560866723765, 0.9191321953350291, 0.5894640490955131], 
             UndirectedEdge[213, 286] -> 
             RGBColor[
              0.21163290304685975`, 0.3397699777762725, 0.935363552794471], 
             UndirectedEdge[16, 126] -> 
             RGBColor[
              0.23513936956710785`, 0.3644767644851118, 0.9367022112880983], 
             UndirectedEdge[68, 109] -> 
             RGBColor[
              0.9348338843673183, 0.947970458954174, 0.8784588716115629], 
             UndirectedEdge[137, 156] -> 
             RGBColor[
              0.32801284307365003`, 0.4541649141300481, 0.9422814923217423], 
             UndirectedEdge[181, 202] -> 
             RGBColor[
              0.9064784784364304, 0.6464832868255209, 0.2740021492415709], 
             UndirectedEdge[135, 214] -> 
             RGBColor[
              0.20695344714813524`, 0.3348515729320728, 0.9350970647036734], 
             UndirectedEdge[166, 234] -> 
             RGBColor[
              0.19012477797807242`, 0.3171635746350845, 0.9341386968902232], 
             UndirectedEdge[63, 152] -> 
             RGBColor[
              0.18270109795627662`, 0.30936081624367795`, 0.9337159292953324],
              UndirectedEdge[130, 167] -> 
             RGBColor[
              0.9097426027065735, 0.6798665267659179, 0.24623498340554434`], 
             UndirectedEdge[30, 74] -> 
             RGBColor[
              0.22759891531018372`, 0.3565512689686714, 0.9362727935732689], 
             UndirectedEdge[31, 177] -> 
             RGBColor[
              0.3558101333125378, 0.4810556899295358, 0.9439496708878323], 
             UndirectedEdge[24, 72] -> 
             RGBColor[
              0.8608649753560598, 0.3965560252957622, 0.20304003335454723`], 
             UndirectedEdge[39, 285] -> 
             RGBColor[
              0.20070194384757245`, 0.3282808465949789, 0.9347410508389766], 
             UndirectedEdge[27, 72] -> 
             RGBColor[
              0.8762241387653882, 0.45471392654355186`, 0.22964784214088227`],
              UndirectedEdge[109, 151] -> 
             RGBColor[
              0.7953196099914366, 0.8378390101205823, 0.8651417721704804], 
             UndirectedEdge[29, 178] -> 
             RGBColor[
              0.22713326298795516`, 0.3560618388539467, 0.9362462753623888], 
             UndirectedEdge[149, 256] -> 
             RGBColor[
              0.8437866719113953, 0.2986689012185817, 0.18804023732608074`], 
             UndirectedEdge[93, 137] -> 
             RGBColor[
              0.25133211293896884`, 0.38149636444816565`, 0.9376243640681086],
              UndirectedEdge[7, 145] -> 
             RGBColor[
              0.9016117745004403, 0.9243171913792056, 0.9881346792519563], 
             UndirectedEdge[271, 278] -> 
             RGBColor[
              0.21163260011638724`, 0.339769659377139, 0.9353635355430288], 
             UndirectedEdge[15, 135] -> 
             RGBColor[
              0.2357262900418861, 0.3650936551170112, 0.9367356355408658], 
             UndirectedEdge[94, 130] -> 
             RGBColor[
              0.8543459981416374, 0.7646454516027577, 0.6141415308874059], 
             UndirectedEdge[265, 286] -> 
             RGBColor[
              0.22180329067308052`, 0.3504597000112502, 0.9359427413240442], 
             UndirectedEdge[140, 201] -> 
             RGBColor[
              0.8266673641279991, 0.20598262316708282`, 0.17317000404643912`],
              UndirectedEdge[29, 259] -> 
             RGBColor[
              0.19020824390880345`, 0.3172513026203284, 0.9341434501515016], 
             UndirectedEdge[21, 123] -> 
             RGBColor[
              0.1960904957019222, 0.3234339222112008, 0.934478435689108], 
             UndirectedEdge[21, 189] -> 
             RGBColor[
              0.20470683599275827`, 0.3324902421643972, 0.934969123521938], 
             UndirectedEdge[107, 289] -> 
             RGBColor[
              0.32595994240234355`, 0.45071429020400966`, 0.942211921890683], 
             UndirectedEdge[17, 66] -> 
             RGBColor[
              0.5450024443168381, 0.6387388987189666, 0.9584682781320619], 
             UndirectedEdge[71, 208] -> 
             RGBColor[
              0.20631669235829492`, 0.33418230327536513`, 0.9350608024603861],
              UndirectedEdge[6, 289] -> 
             RGBColor[
              0.22701980203641853`, 0.3559425842000419, 0.9362398139290493], 
             UndirectedEdge[96, 132] -> 
             RGBColor[
              0.1989233882773373, 0.32641147192372544`, 0.9346397647303889], 
             UndirectedEdge[55, 283] -> 
             RGBColor[
              0.25397885208056453`, 0.38427825509893676`, 0.9377750919467229],
              UndirectedEdge[48, 244] -> 
             RGBColor[
              0.19115682833937214`, 0.31824832500058275`, 0.9341974706315176],
              UndirectedEdge[110, 278] -> 
             RGBColor[
              0.19327360105018532`, 0.32047318733078894`, 0.9343180177059138],
              UndirectedEdge[245, 288] -> 
             RGBColor[
              0.2170539171587743, 0.34546780732004123`, 0.9356722715284729], 
             UndirectedEdge[106, 210] -> 
             RGBColor[
              0.6667698289178824, 0.73732879896912, 0.9691188386686375], 
             UndirectedEdge[176, 296] -> 
             RGBColor[
              0.19069988788986053`, 0.3177680516164482, 0.9341714485489008], 
             UndirectedEdge[82, 154] -> 
             RGBColor[
              0.5553686317376758, 0.6499123001732142, 0.9581397995541713], 
             UndirectedEdge[46, 117] -> 
             RGBColor[
              0.1951092767006187, 0.3224025988279529, 0.9344225567185672], 
             UndirectedEdge[249, 258] -> 
             RGBColor[
              0.2738091064777124, 0.40221653034560445`, 0.9390107464799751], 
             UndirectedEdge[146, 170] -> 
             RGBColor[
              0.19880274533348388`, 0.3262846685405311, 0.9346328942932117], 
             UndirectedEdge[18, 129] -> 
             RGBColor[
              0.1945312219559263, 0.32179502664049353`, 0.9343896373560123], 
             UndirectedEdge[13, 179] -> 
             RGBColor[
              0.42802275177735205`, 0.5432681021152472, 0.9490151577652866], 
             UndirectedEdge[144, 160] -> 
             RGBColor[
              0.19670215780285202`, 0.3240768178608952, 0.934513268940883], 
             UndirectedEdge[17, 130] -> 
             RGBColor[
              0.8077331614173798, 0.7282311492830874, 0.6094955989444572], 
             UndirectedEdge[111, 163] -> 
             RGBColor[
              0.6176770518281398, 0.70049708256499, 0.9630449466269559], 
             UndirectedEdge[107, 251] -> 
             RGBColor[
              0.34704129264344796`, 0.47287212594221606`, 0.943412473599851], 
             UndirectedEdge[1, 198] -> 
             RGBColor[
              0.8673259572403823, 0.4208317382887128, 0.4252968469940128], 
             UndirectedEdge[168, 269] -> 
             RGBColor[
              0.6867881591822118, 0.7211895103907764, 0.6484929822846838], 
             UndirectedEdge[145, 201] -> 
             RGBColor[
              0.8518773491973987, 0.5315008727671069, 0.456374840298414], 
             UndirectedEdge[197, 226] -> 
             RGBColor[
              0.9862994243091077, 0.9886024741101505, 0.8767175253588012], 
             UndirectedEdge[105, 174] -> 
             RGBColor[
              0.25852249961576723`, 0.3890539167423275, 0.9380338459521285], 
             UndirectedEdge[178, 284] -> 
             RGBColor[
              0.24998452415634886`, 0.38007996319556836`, 0.9375476208805174],
              UndirectedEdge[201, 202] -> 
             RGBColor[
              0.8524329734673737, 0.3954661457870175, 0.19750790475074864`], 
             UndirectedEdge[24, 65] -> 
             RGBColor[
              0.6506137006766177, 0.6184091477452374, 0.6013947753940398], 
             UndirectedEdge[134, 169] -> 
             RGBColor[
              0.42476901028009817`, 0.532311534169465, 0.9496393645496872], 
             UndirectedEdge[104, 300] -> 
             RGBColor[
              0.2803668703826312, 0.4095782545351725, 0.9393670254375599], 
             UndirectedEdge[168, 225] -> 
             RGBColor[
              0.31400402532006444`, 0.4388934235578272, 0.9415037514868442], 
             UndirectedEdge[27, 202] -> 
             RGBColor[
              0.9009943249734276, 0.6279839494543441, 0.2526972486332866], 
             UndirectedEdge[113, 187] -> 
             RGBColor[
              0.24618639037776724`, 0.3760878837786886, 0.9373313227806626], 
             UndirectedEdge[7, 201] -> 
             RGBColor[
              0.8763492903148913, 0.5509690808206948, 0.45714696205531347`], 
             UndirectedEdge[51, 104] -> 
             RGBColor[
              0.5731922784257398, 0.6585842020957557, 0.9621993062038972], 
             UndirectedEdge[2, 183] -> 
             RGBColor[
              0.19566573686527955`, 0.3229874737426237, 0.9344542463017356], 
             UndirectedEdge[135, 249] -> 
             RGBColor[
              0.21026660117408774`, 0.33833390787944695`, 0.9352857439240791],
              UndirectedEdge[84, 270] -> 
             RGBColor[
              0.20015353292457566`, 0.32770443194364846`, 0.9347098196482133],
              UndirectedEdge[114, 116] -> 
             RGBColor[
              0.26324193971723214`, 0.3940143475187522, 0.9383026110841209], 
             UndirectedEdge[15, 168] -> 
             RGBColor[
              0.3293937457780264, 0.4550689955237798, 0.942380173299874], 
             UndirectedEdge[42, 237] -> 
             RGBColor[
              0.8334280441412762, 0.2579481722980025, 0.1796440388622492], 
             UndirectedEdge[40, 140] -> 
             RGBColor[
              0.7746238811196319, 0.3418026092174846, 0.43269867546052243`], 
             UndirectedEdge[42, 167] -> 
             RGBColor[
              0.8609638306693929, 0.4172670345342654, 0.20395475904067392`], 
             UndirectedEdge[16, 285] -> 
             RGBColor[
              0.22323502267117318`, 0.3519645411182973, 0.9360242763432778], 
             UndirectedEdge[8, 286] -> 
             RGBColor[
              0.21267948434468417`, 0.34087000107737286`, 0.9354231540511039],
              UndirectedEdge[9, 236] -> 
             RGBColor[
              0.21519552032906075`, 0.34351451442284786`, 0.9355664385782725],
              UndirectedEdge[54, 238] -> 
             RGBColor[
              0.21574020514797415`, 0.344087012702538, 0.9355974575729206], 
             UndirectedEdge[165, 183] -> 
             RGBColor[
              0.2052672821395783, 0.33307930659904317`, 0.9350010401008936], 
             UndirectedEdge[249, 263] -> 
             RGBColor[
              0.20867298294508915`, 0.33665891407953785`, 0.9351949897234846],
              UndirectedEdge[33, 98] -> 
             RGBColor[
              0.18977923539730202`, 0.3168003874740297, 0.9341190187514328], 
             UndirectedEdge[282, 293] -> 
             RGBColor[
              0.6701954566467123, 0.5968924733689558, 0.5936831325375491], 
             UndirectedEdge[54, 163] -> 
             RGBColor[
              0.4325936369919836, 0.5385727559524309, 0.9502636460208878], 
             UndirectedEdge[145, 237] -> 
             RGBColor[
              0.8383510633263312, 0.42753191230581933`, 0.44342205367252496`],
              UndirectedEdge[140, 181] -> 
             RGBColor[
              0.8736439880136796, 0.4112274879198171, 0.24323035592583006`], 
             UndirectedEdge[15, 265] -> 
             RGBColor[
              0.24054595553413333`, 0.37015942913380495`, 0.9370101083605932],
              UndirectedEdge[144, 230] -> 
             RGBColor[
              0.19486271425090618`, 0.32214344606034284`, 0.9344085153518125],
              UndirectedEdge[22, 266] -> 
             RGBColor[
              0.1933455924812791, 0.32054885488938883`, 0.9343221175114128], 
             UndirectedEdge[18, 165] -> 
             RGBColor[
              0.2088844992725249, 0.33688123115058255`, 0.9352070352654217], 
             UndirectedEdge[17, 140] -> 
             RGBColor[
              0.7794337135277863, 0.345560086850815, 0.43317807460452784`], 
             UndirectedEdge[80, 237] -> 
             RGBColor[
              0.8763192452000071, 0.442552928220461, 0.2384882540724326], 
             UndirectedEdge[7, 127] -> 
             RGBColor[
              0.6435774661849356, 0.7150423967840147, 0.9663706566026036], 
             UndirectedEdge[60, 212] -> 
             RGBColor[
              0.2603180236560096, 0.39094112635142153`, 0.9381360983899805], 
             UndirectedEdge[53, 270] -> 
             RGBColor[
              0.21435826979552958`, 0.3426345110273567, 0.935518758398989], 
             UndirectedEdge[243, 254] -> 
             RGBColor[
              0.6530996726183891, 0.7197996840615158, 0.8998607275791879], 
             UndirectedEdge[201, 277] -> 
             RGBColor[
              0.8945797907010281, 0.562282566775544, 0.2876123598448103], 
             UndirectedEdge[288, 296] -> 
             RGBColor[
              0.1980362372485557, 0.3254790199438521, 0.9345892427917222], 
             UndirectedEdge[93, 273] -> 
             RGBColor[
              0.24003010742833283`, 0.36961724006794966`, 0.9369807315740968],
              UndirectedEdge[128, 277] -> 
             RGBColor[
              0.8942972321572974, 0.5601106979904866, 0.2873417814642296], 
             UndirectedEdge[3, 115] -> 
             RGBColor[
              0.6529735529155825, 0.7222241006469869, 0.9530066800693597], 
             UndirectedEdge[74, 123] -> 
             RGBColor[
              0.20225228122772315`, 0.32991034947858455`, 0.9348293402592576],
              UndirectedEdge[52, 147] -> 
             RGBColor[
              0.20606540532151835`, 0.3339181846671946, 0.9350464920353876], 
             UndirectedEdge[64, 76] -> 
             RGBColor[
              0.28111114711231006`, 0.41111591460968555`, 0.939381752805837], 
             UndirectedEdge[132, 260] -> 
             RGBColor[
              0.2275319348126233, 0.35648086821892655`, 0.9362689791330215], 
             UndirectedEdge[171, 285] -> 
             RGBColor[
              0.18941388075270052`, 0.31641637657773114`, 0.9340982123449165],
              UndirectedEdge[226, 290] -> 
             RGBColor[
              0.9663340369194856, 0.9069146206326038, 0.576578764162101], 
             UndirectedEdge[24, 290] -> 
             RGBColor[
              0.9350874753344331, 0.7803505010572445, 0.2666280628425426], 
             UndirectedEdge[103, 265] -> 
             RGBColor[
              0.3220227389937979, 0.445387567907627, 0.9420312197585695], 
             UndirectedEdge[41, 208] -> 
             RGBColor[
              0.1889556017616225, 0.3159346963015419, 0.9340721140343375], 
             UndirectedEdge[80, 179] -> 
             RGBColor[
              0.7507825863487789, 0.7818072220217351, 0.663873785850424], 
             UndirectedEdge[102, 183] -> 
             RGBColor[
              0.19246783079694663`, 0.31962627170585023`, 0.934272130282022], 
             UndirectedEdge[16, 220] -> 
             RGBColor[
              0.2899399087951104, 0.41982488843615623`, 0.9399054307139528], 
             UndirectedEdge[52, 217] -> 
             RGBColor[
              0.19938565089971289`, 0.32689733924898534`, 0.9346660899028769],
              UndirectedEdge[24, 241] -> 
             RGBColor[
              0.9549441101488896, 0.8619933825501465, 0.5685691356523801], 
             UndirectedEdge[105, 163] -> 
             RGBColor[
              0.4524953087499887, 0.5594906748089641, 0.9513970167856213], 
             UndirectedEdge[2, 102] -> 
             RGBColor[
              0.19539325191364892`, 0.3227010747819161, 0.9344387286868456], 
             UndirectedEdge[49, 54] -> 
             RGBColor[
              0.22682934694082163`, 0.355742403819019, 0.936228967793108], 
             UndirectedEdge[216, 237] -> 
             RGBColor[
              0.8526673664281595, 0.38892998001081047`, 0.19740587187632483`],
              UndirectedEdge[89, 281] -> 
             RGBColor[
              0.6796029595718664, 0.743830302697593, 0.9334123929687868], 
             UndirectedEdge[145, 167] -> 
             RGBColor[
              0.8862929429929738, 0.7834059474084649, 0.6157767446761826], 
             UndirectedEdge[16, 90] -> 
             RGBColor[
              0.2312332284112072, 0.3603711624666066, 0.9364797623278878], 
             UndirectedEdge[210, 290] -> 
             RGBColor[
              0.7090449941186435, 0.7036067912817707, 0.613645317642163], 
             UndirectedEdge[152, 242] -> 
             RGBColor[
              0.1817008098525566, 0.3083094500247394, 0.9336589643676192], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.18784627824446665`, 0.31476872694983776`, 0.9340089397011326],
              UndirectedEdge[77, 282] -> 
             RGBColor[
              0.42720741988360567`, 0.5444473278590943, 0.9484422569236628], 
             UndirectedEdge[81, 162] -> 
             RGBColor[
              0.9404065856589258, 0.790829015220349, 0.5112620539625906], 
             UndirectedEdge[34, 247] -> 
             RGBColor[
              0.1907246807083084, 0.31779411044059236`, 0.9341728604632337], 
             UndirectedEdge[7, 60] -> 
             RGBColor[
              0.6127935489939296, 0.6863930727259957, 0.9644818440323379], 
             UndirectedEdge[155, 162] -> 
             RGBColor[
              0.9588310572734952, 0.8681281277104613, 0.5263067793464253], 
             UndirectedEdge[234, 249] -> 
             RGBColor[
              0.2008059288288086, 0.3283901414032867, 0.934746972629826], 
             UndirectedEdge[118, 234] -> 
             RGBColor[
              0.19143808005152518`, 0.3185439383824441, 0.9342134875004501], 
             UndirectedEdge[223, 271] -> 
             RGBColor[
              0.20206279459486376`, 0.3297111870133029, 0.9348185492758365], 
             UndirectedEdge[154, 216] -> 
             RGBColor[
              0.7434083499065284, 0.5252723810458323, 0.4580470065820631], 
             UndirectedEdge[147, 247] -> 
             RGBColor[
              0.2055770841992048, 0.33340492820629564`, 0.9350186828698783], 
             UndirectedEdge[4, 286] -> 
             RGBColor[
              0.22071420539136402`, 0.34931500232817103`, 0.9358807195284078],
              UndirectedEdge[88, 124] -> 
             RGBColor[
              0.20439146202389424`, 0.3321587641272566, 0.9349511634409652], 
             UndirectedEdge[23, 136] -> 
             RGBColor[
              0.6909810750975458, 0.7521740618261392, 0.8862275585719336], 
             UndirectedEdge[11, 104] -> 
             RGBColor[
              0.4334513122055766, 0.547724101182389, 0.9494290167598639], 
             UndirectedEdge[4, 121] -> 
             RGBColor[
              0.2229935575329976, 0.35171074594830076`, 0.9360105252608744], 
             UndirectedEdge[4, 213] -> 
             RGBColor[
              0.21145636706915383`, 0.33958442727067606`, 0.9353534993317023],
              UndirectedEdge[198, 204] -> 
             RGBColor[
              0.7240997016369111, 0.7823833581016821, 0.9486564217578735], 
             UndirectedEdge[156, 168] -> 
             RGBColor[
              0.3974514720884778, 0.5186742214563766, 0.9465462342423088], 
             UndirectedEdge[31, 226] -> 
             RGBColor[
              0.7029528418062473, 0.7632425995782364, 0.912689477230743], 
             UndirectedEdge[36, 242] -> 
             RGBColor[
              0.18110760662426995`, 0.30768595582055314`, 0.9336251823213337],
              UndirectedEdge[216, 269] -> 
             RGBColor[
              0.9020307778688763, 0.6313968506786615, 0.25694130282079497`], 
             UndirectedEdge[97, 202] -> 
             RGBColor[
              0.7273332106591868, 0.5124071693605181, 0.4568577343104335], 
             UndirectedEdge[23, 59] -> 
             RGBColor[
              0.9871771704378065, 0.988965444691414, 0.8621710004720957], 
             UndirectedEdge[174, 238] -> 
             RGBColor[
              0.21032414623090429`, 0.3383943913827284, 0.9352890210299346], 
             UndirectedEdge[86, 97] -> 
             RGBColor[
              0.5215176139849236, 0.6223094238976072, 0.9555083823712963], 
             UndirectedEdge[46, 212] -> 
             RGBColor[
              0.21903868251240277`, 0.34755392154809645`, 0.9357853009791648],
              UndirectedEdge[59, 291] -> 
             RGBColor[
              0.955941254786202, 0.9662985742039245, 0.945506158028788], 
             UndirectedEdge[125, 149] -> 
             RGBColor[
              0.8552975837103799, 0.3871468134192908, 0.19906309946450382`], 
             UndirectedEdge[32, 80] -> 
             RGBColor[
              0.9832422855582464, 0.9646748589231064, 0.6130382528147665], 
             UndirectedEdge[69, 90] -> 
             RGBColor[
              0.21162247094140993`, 0.33975901297201105`, 0.9353629587014987],
              UndirectedEdge[215, 229] -> 
             RGBColor[
              0.2212270314220612, 0.34985401500148217`, 0.9359099242121978], 
             UndirectedEdge[187, 245] -> 
             RGBColor[
              0.22499133551940492`, 0.35381053727845513`, 0.9361242957617526],
              UndirectedEdge[98, 275] -> 
             RGBColor[
              0.17961340510331275`, 0.30611545528417883`, 0.9335400897551883],
              UndirectedEdge[252, 280] -> 
             RGBColor[
              0.2499775972482043, 0.3800726825759171, 0.937547226403346], 
             UndirectedEdge[96, 146] -> 
             RGBColor[
              0.20048974504421074`, 0.3280578121984645, 0.9347289664310452], 
             UndirectedEdge[191, 270] -> 
             RGBColor[
              0.22010792895967446`, 0.34867776735831935`, 0.9358461929825286],
              UndirectedEdge[40, 120] -> 
             RGBColor[
              0.4841619759818365, 0.5839129078583203, 0.9544325893141365], 
             UndirectedEdge[215, 233] -> 
             RGBColor[
              0.2150686635576537, 0.34338117991291517`, 0.9355592142728086], 
             UndirectedEdge[21, 257] -> 
             RGBColor[
              0.1888268034733999, 0.3157993211343368, 0.9340647791623633], 
             UndirectedEdge[200, 245] -> 
             RGBColor[
              0.2954064062007655, 0.4225674449726149, 0.9403266970812623], 
             UndirectedEdge[41, 108] -> 
             RGBColor[
              0.21464006545615802`, 0.34293069613355404`, 0.9355348062449824],
              UndirectedEdge[63, 73] -> 
             RGBColor[
              0.18277574146873998`, 0.309439271307949, 0.933720180132942]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.8649038628242013, 0.8951148792988238, 0.9869764966166072], 
             160 -> RGBColor[
              0.19576440547633542`, 0.32309118070879467`, 0.9344598653331682],
              245 -> RGBColor[
              0.22524249753236514`, 0.35407452447866766`, 0.9361385990668298],
              155 -> RGBColor[
              0.9263138375757084, 0.7455659509853682, 0.2595685879581257], 
             213 -> RGBColor[
              0.20237506472464956`, 0.3300394027187775, 0.9348363325977657], 
             27 -> RGBColor[
              0.9698415036520304, 0.9099304516459211, 0.33734036595263717`], 
             19 -> RGBColor[
              0.18771789764902583`, 0.31463379080422954`, 0.9340016286161444],
              164 -> RGBColor[
              0.18196114135351968`, 0.30858307493822207`, 0.9336737898614731],
              190 -> RGBColor[
              0.2044144915577996, 0.3321829696275479, 0.9349524749388519], 
             103 -> RGBColor[
              0.4213296380105047, 0.5393562886265211, 0.9480677298602272], 
             138 -> RGBColor[
              0.231287806205471, 0.36042852718880986`, 0.9364828704525304], 
             291 -> RGBColor[
              0.926874823682218, 0.9445288413300859, 0.9928873421853748], 28 -> 
             RGBColor[
              0.18347004528514485`, 0.31016902864039503`, 0.9337597197081559],
              195 -> RGBColor[
              0.18372407711397143`, 0.31043603219904004`, 0.9337741864450011],
              114 -> RGBColor[
              0.23913206195702244`, 0.3686733373382309, 0.9369295892130448], 
             93 -> RGBColor[
              0.24113006344271598`, 0.3707733635803057, 0.9370433724418767], 
             34 -> RGBColor[
              0.1836929464736069, 0.31040331192222026`, 0.933772413601086], 
             161 -> RGBColor[
              0.2016546493170191, 0.3292822004483829, 0.9347953060060602], 22 -> 
             RGBColor[
              0.18854143418810532`, 0.3154993799220345, 0.9340485278037318], 
             124 -> RGBColor[
              0.1859244664032461, 0.3127487808548065, 0.9338994953598411], 84 -> 
             RGBColor[
              0.18746791982634672`, 0.31437104826308443`, 0.9339873927489519],
              46 -> RGBColor[
              0.2047087295239663, 0.33249223238575365`, 0.9349692313557391], 
             241 -> RGBColor[
              0.986124206873734, 0.9885300171977407, 0.8796213317111282], 185 -> 
             RGBColor[
              0.5295564396500168, 0.6289567998104505, 0.9561077692398556], 
             121 -> RGBColor[
              0.22544944565233713`, 0.35429204007402687`, 0.9361503844561099],
              126 -> RGBColor[
              0.22348836128871713`, 0.3522308160679321, 0.9360387036027661], 
             236 -> RGBColor[
              0.23143093535124384`, 0.3605789649959291, 0.9364910214456416], 
             78 -> RGBColor[
              0.19413140389541048`, 0.3213747925089622, 0.9343668683089438], 
             254 -> RGBColor[
              0.31878183695974033`, 0.45053453755869494`, 0.9415334746567325],
              290 -> RGBColor[
              0.9464109372448213, 0.8252442542119368, 0.27573918609145315`], 
             251 -> RGBColor[
              0.28560729073547014`, 0.4175217494840773, 0.9395762847380378], 
             165 -> RGBColor[
              0.21779424853057935`, 0.34624594253152846`, 0.935714432304875], 
             100 -> RGBColor[
              0.1806628381309981, 0.3072184759341732, 0.933599853413618], 235 -> 
             RGBColor[
              0.40849384697781144`, 0.528238571579618, 0.9472498446058684], 
             70 -> RGBColor[
              0.20976983040282712`, 0.33781177030176596`, 0.9352574535635624],
              234 -> RGBColor[
              0.1941551643020383, 0.3213997662028249, 0.9343682214289508], 
             257 -> 
             RGBColor[
              0.18407578926115742`, 0.31080570396557056`, 0.9337942159314718],
              135 -> RGBColor[
              0.21307650899259664`, 0.34128729915514544`, 0.9354457640174572],
              265 -> RGBColor[
              0.22271583997709107`, 0.35141884718873295`, 0.9359947096569118],
              111 -> RGBColor[
              0.6142037164471443, 0.6976772724307221, 0.9627715129425172], 
             182 -> RGBColor[
              0.2543436096659436, 0.38466163844813683`, 0.9377958643515997], 
             188 -> RGBColor[
              0.35586441424032067`, 0.4826536021746064, 0.9438963436902155], 
             154 -> RGBColor[
              0.4972976140125026, 0.6027676319143825, 0.9535682363176986], 
             269 -> RGBColor[
              0.9731648978995463, 0.9211410408128702, 0.3502511250338943], 
             208 -> RGBColor[
              0.18931653926981418`, 0.3163140645074111, 0.9340926688914699], 
             86 -> RGBColor[
              0.5941770672605392, 0.6814187364307716, 0.9611949417585145], 
             119 -> RGBColor[
              0.18085158366002294`, 0.307416859452336, 0.933610602192272], 
             140 -> RGBColor[0.817319, 0.134127, 0.164218], 85 -> 
             RGBColor[
              0.23214849009490668`, 0.36133316052711717`, 0.9365318851267661],
              242 -> RGBColor[
              0.18088209567567362`, 0.3074489295153584, 0.9336123398064248], 
             117 -> RGBColor[
              0.1855098238772711, 0.3123129652701522, 0.9338758820813954], 47 -> 
             RGBColor[
              0.18409960782193097`, 0.31083073878312756`, 0.9337955723632715],
              81 -> RGBColor[
              0.8894648943465696, 0.5909677260051436, 0.2294791371904563], 
             275 -> RGBColor[
              0.1801747671672662, 0.30670548240580453`, 0.9335720584942697], 
             23 -> RGBColor[
              0.989346654985427, 0.9898625823050647, 0.82621702707199], 110 -> 
             RGBColor[
              0.18591721951216156`, 0.3127411639127972, 0.9338990826601146], 
             6 -> RGBColor[
              0.2105950138195758, 0.3386790903924193, 0.9353044465383967], 
             218 -> RGBColor[
              0.9671895696970209, 0.9750506153189628, 0.9404236795589124], 
             108 -> RGBColor[
              0.24068546665888524`, 0.3703060641714354, 0.9370180533127597], 
             297 -> RGBColor[
              0.19199315011410678`, 0.319127352211692, 0.9342450979193615], 
             157 -> RGBColor[
              0.18253809113335498`, 0.30918948573755783`, 0.933706646297914], 
             270 -> RGBColor[
              0.2128391460228046, 0.3410378156242125, 0.9354322465474746], 33 -> 
             RGBColor[
              0.20050642775524471`, 0.3280753467855062, 0.9347299164867587], 
             252 -> RGBColor[
              0.23794228148785246`, 0.3674228026286945, 0.9368618329754481], 
             260 -> RGBColor[
              0.25816755850577977`, 0.38868085113116446`, 0.938013632581003], 
             159 -> RGBColor[
              0.29124080035179, 0.42344292527596916`, 0.9398971047766567], 
             183 -> RGBColor[
              0.19274031574857725`, 0.3199126706665578, 0.9342876478969121], 
             99 -> RGBColor[
              0.19567419878950365`, 0.3229963677615002, 0.9344547281958019], 
             17 -> RGBColor[
              0.7036631405833589, 0.768426260552445, 0.9710982238135836], 277 -> 
             RGBColor[
              0.9930111873350895, 0.9874599613241353, 0.4806890552557963], 
             104 -> RGBColor[
              0.3350878162698179, 0.46465795727473413`, 0.9425724772395593], 
             79 -> RGBColor[
              0.18314084159618357`, 0.3098230146905773, 0.9337409720450827], 
             191 -> RGBColor[
              0.2273767118965443, 0.3563177190924262, 0.9362601394175826], 50 -> 
             RGBColor[
              0.1818234123124711, 0.30843831298355445`, 0.9336659463963373], 
             225 -> RGBColor[
              0.2275966301752516, 0.35654886714697176`, 0.936272663438215], 
             61 -> RGBColor[
              0.2772592389822082, 0.4087474177943471, 0.9391008755405253], 
             196 -> RGBColor[
              0.2030597206401025, 0.3307590194956109, 0.934875322739293], 1 -> 
             RGBColor[
              0.8186934053129894, 0.1446912815038851, 0.16553413207988746`], 
             263 -> RGBColor[
              0.20988927253459944`, 0.3379373115553272, 0.935264255616268], 
             201 -> RGBColor[
              0.8453640923839973, 0.3496938695012485, 0.19107401213931735`], 
             293 -> RGBColor[
              0.8997587664774066, 0.6377097951563564, 0.23806859642232206`], 
             184 -> RGBColor[
              0.1914897805011185, 0.3185982788329645, 0.9342164317645705], 
             106 -> RGBColor[
              0.861860606843299, 0.8926882695866354, 0.9866862281444021], 206 -> 
             RGBColor[
              0.22242260484653656`, 0.35111063847433904`, 0.9359780103500293],
              247 -> 
             RGBColor[
              0.19775641494300986`, 0.32518490895896446`, 0.9345733073253814],
              220 -> RGBColor[
              0.33308943974472227`, 0.4629270639700209, 0.9424451424544752], 
             107 -> RGBColor[
              0.40847529455142584`, 0.5282225024003548, 0.9472486624616643], 
             131 -> RGBColor[
              0.22940782651350908`, 0.3584525493349609, 0.9363758083902539], 
             127 -> RGBColor[
              0.34883524619319184`, 0.47656529010844195`, 0.9434484513179017],
              210 -> RGBColor[
              0.4716790509924657, 0.5819693283516046, 0.9515514491928728], 
             181 -> RGBColor[
              0.9862939640410388, 0.9654284637594515, 0.4012550677774902], 
             194 -> RGBColor[
              0.6860055424687634, 0.754632010702607, 0.9693382794531569], 118 -> 
             RGBColor[
              0.1887209958010121, 0.3156881105620633, 0.9340587535719493], 
             276 -> RGBColor[
              0.24137384732010603`, 0.3710295958922332, 0.9370572555730482], 
             280 -> RGBColor[
              0.2620129130085561, 0.39272256252313964`, 0.938232619831244], 
             189 -> RGBColor[
              0.21583585429987417`, 0.3441875460256914, 0.935602904650621], 
             168 -> RGBColor[
              0.4004114204648772, 0.5212379799686826, 0.9467348395354733], 41 -> 
             RGBColor[
              0.1885946642534308, 0.31555532809567266`, 0.9340515591772053], 
             14 -> RGBColor[
              0.1801938510546308, 0.30672554078141306`, 0.9335731452934231], 
             77 -> RGBColor[
              0.4137826929511934, 0.5328195041366336, 0.9475868451945494], 51 -> 
             RGBColor[
              0.8112967405816618, 0.8525104469167772, 0.981826135168235], 179 -> 
             RGBColor[
              0.5227567642523288, 0.6234365170007214, 0.9555724738845179], 
             223 -> RGBColor[
              0.1814903715451621, 0.30808826602110845`, 0.9336469802173286], 
             292 -> RGBColor[
              0.773715577090376, 0.8231517563699634, 0.978080396007364], 143 -> 
             RGBColor[
              0.3068945586163886, 0.4398960177176607, 0.9407885631521654], 
             112 -> RGBColor[
              0.18923133529375677`, 0.3162245097263307, 0.9340878166510814], 
             197 -> RGBColor[
              0.9863417120240653, 0.9886199611670301, 0.8760167084848537], 54 -> 
             RGBColor[
              0.24403688677483204`, 0.37382861920560384`, 0.937208911730381], 
             71 -> 
             RGBColor[
              0.22331684544677569`, 0.35205054204331915`, 0.9360289360293025],
              177 -> RGBColor[
              0.29197171960673096`, 0.42421116775586953`, 0.9399387295469274],
              158 -> RGBColor[
              0.19294565339664288`, 0.32012849355383366`, 0.9342993415721996],
              226 -> RGBColor[
              0.9862571365941499, 0.9885849870532707, 0.8774183422327487], 
             203 -> RGBColor[
              0.9371250918628792, 0.9526285769763242, 0.9913149984604726], 
             115 -> RGBColor[
              0.3517287364030146, 0.47907148589714393`, 0.9436328219554587], 
             173 -> RGBColor[
              0.20128694378722742`, 0.32889571862269473`, 0.9347743657201101],
              212 -> RGBColor[
              0.23336863550083925`, 0.36261561071043924`, 0.9366013706025906],
              129 -> RGBColor[
              0.18908769389738214`, 0.3160735335113504, 0.9340796364860563], 
             279 -> RGBColor[
              0.23666672657285628`, 0.3660821135381808, 0.9367891920100534], 
             26 -> RGBColor[
              0.2290956026577889, 0.35812438226646315`, 0.9363580277035645], 
             40 -> RGBColor[
              0.6892336433588957, 0.7571538276524538, 0.9696600263815672], 
             146 -> RGBColor[
              0.20002902465321373`, 0.3275735658561667, 0.9347027290863527], 
             192 -> RGBColor[
              0.3306172943235091, 0.4607858158598078, 0.9422876195342679], 
             300 -> RGBColor[
              0.2256459244954445, 0.3544985517956109, 0.9361615736355604], 
             221 -> RGBColor[
              0.1861956076915163, 0.31303376754012907`, 0.9339149364550904], 
             62 -> RGBColor[
              0.20167701950442632`, 0.3293057129336997, 0.9347965799551393], 
             286 -> RGBColor[
              0.22089074136906994`, 0.34950055283376746`, 0.9358907729911765],
              152 -> RGBColor[
              0.1825195240294396, 0.3091699705341204, 0.9337055889288136], 64 -> 
             RGBColor[
              0.2353045398184947, 0.3646503688917182, 0.9367116174895672], 37 -> 
             RGBColor[
              0.22656828106141946`, 0.3554680070272346, 0.9362141004774884], 
             148 -> RGBColor[
              0.2462972527349853, 0.37620440714520426`, 0.9373376362279], 261 -> 
             RGBColor[
              0.24473644409614725`, 0.3745638983048021, 0.9372487504849276], 
             15 -> RGBColor[
              0.2583760710911756, 0.38890001107887695`, 0.9380255070642746], 
             136 -> 
             RGBColor[
              0.39261549520966454`, 0.5144855413472138, 0.9462380900718772], 
             198 -> RGBColor[
              0.964591061095168, 0.9731126518583681, 0.9448222768222637], 63 -> 
             RGBColor[
              0.18288267188311363`, 0.3095516619532356, 0.9337262696618512], 
             171 -> RGBColor[
              0.17914809400855325`, 0.30562638382115925`, 0.9335135909767078],
              59 -> RGBColor[
              0.985007685890186, 0.9880683070777632, 0.8981249738722014], 229 -> 
             RGBColor[
              0.2177123475199571, 0.3461598593765405, 0.9357097681634818], 
             102 -> RGBColor[
              0.19219534584531597`, 0.31933987274514264`, 0.9342566126671321],
              299 -> RGBColor[
              0.8186938987840391, 0.1446950745386128, 0.16553460462832187`], 
             128 -> RGBColor[
              0.8449402545684014, 0.34643606632366236`, 0.19066814456844627`],
              12 -> RGBColor[
              0.42962012936485927`, 0.5465370955454517, 0.948595992638333], 
             222 -> RGBColor[
              0.2214255710569613, 0.35006269274590207`, 0.9359212307506922], 
             92 -> RGBColor[
              0.8315546894535105, 0.24354874725857717`, 0.17785011229759332`],
              271 -> RGBColor[
              0.2226352176445654, 0.3513341080054973, 0.9359901183343445], 
             132 -> RGBColor[
              0.19689631111946682`, 0.3242808853066886, 0.9345243256850401], 
             80 -> RGBColor[
              0.9788084084452291, 0.9401779270427488, 0.37217509781633024`], 
             244 -> RGBColor[
              0.1895037720729246, 0.31651085805472556`, 0.934103331522621], 
             150 -> RGBColor[
              0.9074094141907081, 0.6706162117894943, 0.24435764515870567`], 
             125 -> RGBColor[
              0.8351944719959239, 0.27152571084244637`, 0.18133557217075477`],
              258 -> RGBColor[
              0.340161519599846, 0.46905254408746033`, 0.942895769129249], 
             133 -> RGBColor[
              0.18528931800943133`, 0.31208119962217307`, 0.9338633245984311],
              255 -> RGBColor[
              0.3660178719215669, 0.49144801689048034`, 0.9445433130353144], 
             176 -> RGBColor[
              0.19419263806779313`, 0.3214391535066072, 0.9343703555044731], 
             230 -> RGBColor[
              0.19208551837244375`, 0.31922443710768994`, 0.9342503581550272],
              274 -> RGBColor[
              0.46304655962256364`, 0.5749610829682137, 0.9508718678503764], 
             87 -> 
             RGBColor[
              0.9931480500222558, 0.9877526967730439, 0.4955857141352578], 
             130 -> RGBColor[
              0.9118031822514008, 0.6880360380137298, 0.24789297407533079`], 
             35 -> RGBColor[
              0.20639345636736367`, 0.33426298711601565`, 0.9350651740571405],
              31 -> RGBColor[
              0.41964854701834464`, 0.537900212103202, 0.9479606122287372], 
             18 -> RGBColor[
              0.19997475001447043`, 0.3275165197696367, 0.9346996382259684], 
             24 -> RGBColor[
              0.9237640134240451, 0.7354567479025522, 0.2575169395936321], 
             151 -> RGBColor[
              0.5978280581771518, 0.684382775332144, 0.9614823611374906], 137 -> 
             RGBColor[
              0.26153416243522165`, 0.3922193653160256, 0.9382053556943405], 
             296 -> RGBColor[
              0.18720713771192796`, 0.31409694972628927`, 0.9339725415933283],
              266 -> RGBColor[
              0.1981497507744529, 0.3255983298567432, 0.9345957072190938], 
             283 -> RGBColor[
              0.3058207768282486, 0.438767404976628, 0.9407274128678487], 284 -> 
             RGBColor[
              0.24095771526907575`, 0.3705922147223045, 0.9370335574683543], 
             238 -> RGBColor[
              0.1874435235211163, 0.31434540619947215`, 0.9339860034154601], 
             72 -> RGBColor[
              0.8294154563220671, 0.22710566399236717`, 0.1758015802350048], 
             288 -> RGBColor[
              0.20886533678518346`, 0.33686109016141486`, 0.9352059439901159],
              172 -> RGBColor[
              0.19058407149220488`, 0.3176463212393284, 0.9341648529763892], 
             243 -> RGBColor[
              0.9874175082770378, 0.9890648305643368, 0.8581879805016432], 88 -> 
             RGBColor[
              0.22285845764454237`, 0.35156874739970667`, 0.9360028315220893],
              273 -> RGBColor[
              0.2389301514139497, 0.3684611165555936, 0.9369180907063167], 
             202 -> RGBColor[
              0.8665707356341262, 0.4870106983585556, 0.21037568997361125`], 
             98 -> RGBColor[
              0.1790520430393593, 0.3055254281625532, 0.9335081210161069], 30 -> 
             RGBColor[
              0.24929644188312317`, 0.37935674509947226`, 0.9375084356129837],
              116 -> RGBColor[
              0.2873518174774419, 0.41935535769927346`, 0.9396756329551971], 
             240 -> RGBColor[
              0.18053047455342514`, 0.3070793534218085, 0.9335923155036896], 
             73 -> 
             RGBColor[
              0.1826688110543663, 0.3093268806626624, 0.9337140906040328], 29 -> 
             RGBColor[
              0.19525519293228838`, 0.32255596603906117`, 0.934430866432097], 
             75 -> RGBColor[
              0.3329293714790703, 0.46278842088357813`, 0.9424349430461306], 
             200 -> RGBColor[
              0.3655703148691659, 0.4910603654665621, 0.9445147950956946], 
             156 -> RGBColor[
              0.3944915237120784, 0.5161104629440706, 0.9463576289491441], 25 -> 
             RGBColor[
              0.1911156300253715, 0.31820502296044406`, 0.9341951244484827], 
             38 -> RGBColor[
              0.18611948239069784`, 0.312953755022346, 0.9339106012318261], 3 -> 
             RGBColor[
              0.9542183694281502, 0.96537671539683, 0.9623805381832607], 57 -> 
             RGBColor[
              0.17967566298483006`, 0.30618089226503126`, 0.9335436352494385],
              227 -> RGBColor[
              0.952704487454567, 0.8501960835922951, 0.28080312431882476`], 
             39 -> RGBColor[
              0.20172422019829714`, 0.3293553238556548, 0.934799267964828], 
             109 -> RGBColor[
              0.9928111618057213, 0.9912952449090205, 0.7688011832034702], 
             256 -> RGBColor[
              0.817928104297447, 0.13880884254138265`, 0.16480127896312016`], 
             287 -> RGBColor[
              0.2430009596347453, 0.3727397940997984, 0.9371499172122699], 
             239 -> RGBColor[
              0.23757609093788187`, 0.36703791314285356`, 0.9368409789653577],
              285 -> RGBColor[
              0.1996796674968478, 0.327206369334303, 0.9346828337131252], 216 -> 
             RGBColor[
              0.8664637178535413, 0.48652475561155717`, 0.21028639171424535`],
              21 -> RGBColor[
              0.19357781768564236`, 0.320792938303103, 0.9343353423932549], 
             175 -> RGBColor[
              0.18260859612989327`, 0.30926359095919453`, 0.9337106614531641],
              7 -> RGBColor[
              0.9383196861766793, 0.9535195034595876, 0.9892928618873055], 13 -> 
             RGBColor[
              0.33328873930237535`, 0.463099687229773, 0.9424578416460552], 
             294 -> RGBColor[
              0.5360494193639693, 0.63422809324764, 0.9566189203875064], 193 -> 
             RGBColor[
              0.27956374695486264`, 0.41116960178785156`, 0.939232113860354], 
             60 -> RGBColor[
              0.28726741181117993`, 0.4192666419924039, 0.9396708261773704], 
             65 -> 
             RGBColor[
              0.3774633879291902, 0.5013615475879224, 0.9452726111944477], 69 -> 
             RGBColor[
              0.20756886290590398`, 0.3354984139131004, 0.9351321117206522], 
             217 -> RGBColor[
              0.20003824461178885`, 0.32758325661720833`, 0.9347032541493537],
              214 -> RGBColor[
              0.20083038530367384`, 0.32841584670900015`, 0.9347483653898895],
              170 -> RGBColor[
              0.19757646601375403`, 0.32499577122489554`, 0.9345630595000708],
              74 -> RGBColor[
              0.20590138873724428`, 0.3337457928378705, 0.935037151533554], 
             246 -> RGBColor[
              0.1844498116639085, 0.31119882522525194`, 0.9338155159539919], 
             264 -> RGBColor[
              0.2962099519152749, 0.42866581863159803`, 0.9401800906069961], 
             278 -> RGBColor[
              0.2006299825882091, 0.3282052107487807, 0.934736952751713], 45 -> 
             RGBColor[
              0.29993474933268105`, 0.43258081688308847`, 0.9403922123095734],
              237 -> RGBColor[
              0.8250746635773962, 0.19374042880931708`, 0.17164483220048377`],
              228 -> RGBColor[
              0.426257062503514, 0.5436241760628097, 0.9483817009917713], 180 -> 
             RGBColor[
              0.19488460571983207`, 0.32216645538218325`, 0.9344097620385824],
              53 -> RGBColor[
              0.21587739356825456`, 0.3442312064305009, 0.9356052702505034], 
             48 -> RGBColor[
              0.1928098846058197, 0.31998579194643995`, 0.9342916097404141], 
             5 -> RGBColor[
              0.9710126878169619, 0.9138811308413543, 0.3418901952738247], 
             101 -> RGBColor[
              0.6473280227603806, 0.724416838346381, 0.9654832657505968], 267 -> 
             RGBColor[
              0.1962060745132835, 0.32355540287006146`, 0.9344850177314316], 
             120 -> RGBColor[
              0.27909030860477735`, 0.41067198806418675`, 0.939205152246706], 
             147 -> RGBColor[
              0.21339775345539977`, 0.34162494745362687`, 0.9354640584143752],
              89 -> RGBColor[
              0.3807443443279537, 0.5042033471148679, 0.9454816708349412], 43 -> 
             RGBColor[
              0.2255865897625529, 0.3544361872293025, 0.9361581946103001], 
             199 -> RGBColor[
              0.19839476243792764`, 0.32585585264969186`, 0.9346096602708663],
              268 -> RGBColor[
              0.20504953117466115`, 0.3328504365287066, 0.9349886395055752], 
             169 -> 
             RGBColor[
              0.6047389625257771, 0.6899933588150511, 0.9620264128432912], 20 -> 
             RGBColor[
              0.21900416978762977`, 0.3475176464861269, 0.9357833355305459], 
             4 -> RGBColor[
              0.2205376694136581, 0.34912945182257465`, 0.935870666065639], 
             167 -> RGBColor[
              0.9076820231617462, 0.6716970155181059, 0.2445769927357579], 
             142 -> RGBColor[
              0.8299355921400753, 0.23110365581454728`, 0.17629966288173887`],
              16 -> RGBColor[
              0.24679037784549854`, 0.37672271290229153`, 0.9373657189734305],
              281 -> RGBColor[
              0.9784615748157791, 0.9834572582803182, 0.9213431151026323], 
             289 -> RGBColor[
              0.2434445902532613, 0.3732060780076645, 0.9371751813197018], 
             178 -> RGBColor[
              0.25901133304362195`, 0.3895677116688322, 0.9380616842926806], 
             58 -> RGBColor[
              0.19114091674596853`, 0.31823160090706226`, 0.9341965644898124],
              186 -> RGBColor[
              0.19311599281626868`, 0.32030753108400334`, 0.9343090421501528],
              122 -> RGBColor[
              0.18504035865818397`, 0.31181952755907755`, 0.93384914673168], 
             249 -> RGBColor[
              0.20745669335557887`, 0.3353805166037485, 0.9351257238307011], 
             113 -> RGBColor[
              0.2676326072490897, 0.3986292174791347, 0.9385526531046497], 52 -> 
             RGBColor[
              0.1987330571876369, 0.3262114218807623, 0.9346289256564001], 
             187 -> RGBColor[
              0.22474017350644473`, 0.35354655007824254`, 0.9361099924566755],
              259 -> RGBColor[
              0.18516129488531852`, 0.3119466392015956, 0.9338560338709061], 
             42 -> RGBColor[
              0.8376047344232163, 0.2900520440423452, 0.18364364219313192`], 
             134 -> RGBColor[
              0.24479905803441923`, 0.3746297095238789, 0.9372523162560832], 
             248 -> RGBColor[
              0.22195872707107797`, 0.35062307352078237`, 0.9359515931969625],
              174 -> RGBColor[
              0.23320476894069225`, 0.36244337656598474`, 0.9365920386444091],
              215 -> RGBColor[
              0.22474171532416531`, 0.3535481706264238, 0.9361100802609137], 
             83 -> RGBColor[
              0.846552585818907, 0.35882915084310774`, 0.19221211479479816`], 
             95 -> RGBColor[
              0.28755638833203334`, 0.4195703746379904, 0.9396872829627306], 
             166 -> 
             RGBColor[
              0.18609439165410657`, 0.312927383067344, 0.9339091723514956], 
             233 -> RGBColor[
              0.20539561179114207`, 0.3332141891994065, 0.9350083482847035], 
             295 -> RGBColor[
              0.19692281060910452`, 0.3243087379504625, 0.9345258347917725], 
             141 -> RGBColor[
              0.2938477713702168, 0.42618301710784506`, 0.940045567919488], 
             205 -> RGBColor[
              0.3723597127044757, 0.4969410006264502, 0.9449474095221317], 
             224 -> RGBColor[
              0.20866772558178895`, 0.33665338825737323`, 0.9351946903244223],
              231 -> RGBColor[
              0.23118072954041266`, 0.36031598282478083`, 0.9364767725948611],
              68 -> RGBColor[
              0.8768566069289154, 0.9046456729993274, 0.9881165600196555], 10 -> 
             RGBColor[
              0.19040293767796423`, 0.3174559381160143, 0.9341545376736317], 
             250 -> RGBColor[
              0.18265386603570732`, 0.30931117250048296`, 0.9337132395073293],
              282 -> RGBColor[
              0.4406321468160179, 0.5560751515815551, 0.9492976686527762], 
             232 -> RGBColor[
              0.18790775611424687`, 0.3148333440888988, 0.9340124407748683], 
             253 -> RGBColor[
              0.19184993915614282`, 0.3189768284147727, 0.9342369422671671], 
             55 -> RGBColor[
              0.20213692733288047`, 0.32978910522124555`, 0.9348227710255971],
              91 -> RGBColor[
              0.49015879412300467`, 0.5969720163279171, 0.9530062422656385], 
             105 -> RGBColor[
              0.28384023029084227`, 0.41566445691867016`, 0.9394756532598479],
              36 -> RGBColor[
              0.18133311757286624`, 0.3079229821257478, 0.9336380248362428], 
             123 -> RGBColor[
              0.19860317371820202`, 0.3260749061192986, 0.9346215289849611], 
             94 -> RGBColor[
              0.796888814031874, 0.8412548651917855, 0.9803900876994809], 96 -> 
             RGBColor[
              0.20095046543520778`, 0.32854205854076235`, 0.9347552037757377],
              2 -> RGBColor[
              0.19859115798198185`, 0.32606227681868954`, 0.934620844706559], 
             262 -> RGBColor[
              0.3038398335581257, 0.4366853080006712, 0.9406146010791581], 
             272 -> RGBColor[
              0.17908821045117204`, 0.30556344240551475`, 0.9335101806967048],
              97 -> RGBColor[
              0.44885816070930806`, 0.563200111364443, 0.9498218229840781], 
             209 -> 
             RGBColor[
              0.1804556557285978, 0.30700071409312746`, 0.9335880546823002], 
             66 -> RGBColor[
              0.3863417480503173, 0.5090515368854881, 0.9458383324505404], 
             139 -> RGBColor[
              0.4407231525670485, 0.5561539761890157, 0.9493034674587586], 56 -> 
             RGBColor[
              0.19935669202797407`, 0.3268669016386893, 0.9346644407379722], 
             144 -> RGBColor[
              0.19763991012936863`, 0.32506245501299574`, 0.9345666725485978],
              298 -> RGBColor[
              0.2601377913887575, 0.39075169081115385`, 0.9381258344289902], 
             204 -> RGBColor[
              0.4836083421786542, 0.5916540643449961, 0.9524905666934831], 
             207 -> RGBColor[
              0.18528775379377113`, 0.3120795555323372, 0.9338632355186633], 
             149 -> RGBColor[
              0.895503807139292, 0.6183890185729798, 0.2345181540520019], 219 -> 
             RGBColor[
              0.18433414396946993`, 0.31107725114464163`, 0.9338089288499086],
              9 -> RGBColor[
              0.19896010530687766`, 0.32645006384976655`, 0.9346418557109033],
              11 -> RGBColor[
              0.5318148081413353, 0.630790245090044, 0.9562855562801685], 44 -> 
             RGBColor[
              0.31621931418873805`, 0.44831500913059213`, 0.9413701929717141],
              153 -> RGBColor[
              0.22106916700115545`, 0.3496880894859278, 0.9359009340669666], 
             32 -> RGBColor[
              0.9876761626712638, 0.9891717908034641, 0.8539014078132029], 
             162 -> RGBColor[
              0.9913482769712819, 0.9906903044355545, 0.7930449707347249], 90 -> 
             RGBColor[
              0.21567607897691587`, 0.34401961203092163`, 0.935593805682345], 
             8 -> RGBColor[
              0.2044682273202984, 0.33223944932097826`, 0.9349555351110312], 
             163 -> RGBColor[
              0.6211503872091352, 0.7033168926992579, 0.9633183803113946], 49 -> 
             RGBColor[
              0.20962180710681122`, 0.3376561884324342, 0.9352490238558351], 
             76 -> RGBColor[
              0.3269177544061254, 0.4575814603276529, 0.9420518881221068], 82 -> 
             RGBColor[
              0.6134396494628491, 0.6970569684320459, 0.962711362790644], 67 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 211 -> 
             RGBColor[
              0.2707327274798912, 0.4018876404006824, 
               0.9387292003655769]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJwtl3k4FGrYxsc2dmbMmGEYZp8hUUJS8qQSUSklLeLUoUhCylJkaUGShISD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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 5}], {
             RGBColor[
             0.8694664994809802, 0.4010878979497081, 0.22431948647786654`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 32}], {
             RGBColor[
             0.8750209910990808, 0.42618478460374476`, 0.39498989065765927`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 51}], {
             RGBColor[
             0.8162278504025469, 0.38063100330818245`, 0.4376314664426699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 80}], {
             RGBColor[
             0.8720650730237359, 0.40985349668350635`, 0.23441445399203503`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 83}], {
             RGBColor[
             0.827979798814962, 0.21607057128362597`, 0.1744267929848577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 92}], {
             RGBColor[
             0.8229805000264965, 0.17764377008878246`, 0.16963945881912273`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 125}], {
             RGBColor[
             0.8241937608739676, 0.18696942461673885`, 0.17080127877684323`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 128}], {
             RGBColor[
             0.8274423550647934, 0.21193954311047752`, 0.1739121362427404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 142}], {
             RGBColor[
             0.822440800922018, 0.17349540627410584`, 0.16912264234717125`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 149}], {
             RGBColor[
             0.8442968725884236, 0.3025905271935833, 0.18852880607059228`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 150}], {
             RGBColor[
             0.848265408272229, 0.31999959159908814`, 0.19180863643949353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 197}], {
             RGBColor[
             0.8745761742166813, 0.4260008413916001, 0.4023616575482095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 198}], {
             RGBColor[
             0.8673259572403823, 0.4208317382887128, 0.4252968469940128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 237}], {
             RGBColor[
             0.820820491401125, 0.16104099727236243`, 0.16757103212008623`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 243}], {
             RGBColor[
             0.8749347729676722, 0.4261491311907023, 0.39641874822047274`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 256}], {
             RGBColor[
             0.8184383049744752, 0.1427304685163843, 0.1652898477076317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 277}], {
             RGBColor[
             0.8767993326536895, 0.4256141747773018, 0.2705857731385237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 281}], {
             RGBColor[
             0.8719494618139193, 0.4242799404293628, 0.41747045975413577`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 49}], {
             RGBColor[
             0.20410648254439653`, 0.3318592326255619, 0.934934934281197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 54}], {
             RGBColor[
             0.22131402237840694`, 0.34994544801214666`, 0.9359148782184701]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 102}], {
             RGBColor[
             0.19539325191364892`, 0.3227010747819161, 0.9344387286868456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 165}], {
             RGBColor[
             0.2081927032562806, 0.336154109675109, 0.935167638505717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 172}], {
             RGBColor[
             0.19458761473709335`, 0.321854299029009, 0.9343928488414741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 174}], {
             RGBColor[
             0.21589796346133705`, 0.34425282669233714`, 0.9356064416754841]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 183}], {
             RGBColor[
             0.19566573686527955`, 0.3229874737426237, 0.9344542463017356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 238}], {
             RGBColor[
             0.19301734075154908`, 0.3202038415090809, 0.9343034240610095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 253}], {
             RGBColor[
             0.19522054856906235`, 0.32251955261673115`, 0.9344288934868631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 24}], {
             RGBColor[
             0.9389911914260977, 0.8504167316496911, 0.6099487388884464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 59}], {
             RGBColor[
             0.9696130276591681, 0.9767225112372966, 0.930252756027731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 65}], {
             RGBColor[
             0.6658408786786703, 0.7333691314923763, 0.9538265746888542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 72}], {
             RGBColor[
             0.8710164273574281, 0.4731960144605215, 0.4379945662177568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 106}], {
             RGBColor[
             0.9080394881357245, 0.9290324924917327, 0.9745333831638314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 115}], {
             RGBColor[
             0.6529735529155825, 0.7222241006469869, 0.9530066800693597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 155}], {
             RGBColor[
             0.9402661035019293, 0.855471333191099, 0.6109745630706932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[
             0.972783323199716, 0.9780335099161923, 0.8777127544589929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 169}], {
             RGBColor[
             0.7794786659769637, 0.8276850371059405, 0.962203475513276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 194}], {
             RGBColor[
             0.8201119559484569, 0.8600043630497185, 0.9658594088182089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 200}], {
             RGBColor[
             0.659894342148658, 0.7282185404316961, 0.9534476666394777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 210}], {
             RGBColor[
             0.7129487102103079, 0.7736730218742174, 0.9569659936880668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 227}], {
             RGBColor[
             0.9534614284413586, 0.9077863994945625, 0.6215918312510428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 228}], {
             RGBColor[
             0.690237715965832, 0.7545004457298199, 0.955381119587516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 241}], {
             RGBColor[
             0.9701712881509421, 0.9769533662972854, 0.9210009349471945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 264}], {
             RGBColor[
             0.6252141606717125, 0.697021267014214, 0.9512803143951285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 290}], {
             RGBColor[
             0.9503146533364857, 0.8953104848043834, 0.619059862137357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 291}], {
             RGBColor[
             0.940546596555184, 0.9549527783634579, 0.9776339401843177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 8}], {
             RGBColor[
             0.21250294836697825`, 0.34068445057177643`, 0.935413100588335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 15}], {
             RGBColor[
             0.23945687025241685`, 0.36901473145072583`, 0.9369480865649568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 62}], {
             RGBColor[
             0.21110734445904222`, 0.33921758237813715`, 0.9353336230103891]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 85}], {
             RGBColor[
             0.2263430797542824, 0.3552313061748459, 0.9362012755962026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 121}], {
             RGBColor[
             0.2229935575329976, 0.35171074594830076`, 0.9360105252608744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 135}], {
             RGBColor[
             0.21680708920312736`, 0.3452083754888601, 0.935658215041548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 158}], {
             RGBColor[
             0.2067416614051505, 0.33462897268820413`, 0.9350850038189193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 173}], {
             RGBColor[
             0.21091230660044274`, 0.33901258522263467`, 0.9353225158928745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 186}], {
             RGBColor[
             0.2068268311149634, 0.334718491453289, 0.9350898541078958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 213}], {
             RGBColor[
             0.21145636706915383`, 0.33958442727067606`, 0.9353534993317023]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 214}], {
             RGBColor[
             0.21068402735866598`, 0.33877264926578743`, 0.9353095157277642]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 249}], {
             RGBColor[
             0.21399718138461848`, 0.3422549842131616, 0.93549819494817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 255}], {
             RGBColor[
             0.2932777706676125, 0.42028873435652747`, 0.9402069895504767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 263}], {
             RGBColor[
             0.21521347097412877`, 0.3435333816889509, 0.9355674608409534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 265}], {
             RGBColor[
             0.22162675469537457`, 0.35027414950565383`, 0.9359326878612754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 276}], {
             RGBColor[
             0.23095575836688206`, 0.36007952385740394`, 0.9364639608193436]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 286}], {
             RGBColor[
             0.22071420539136402`, 0.34931500232817103`, 0.9358807195284078]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.7514137479791486, 0.7723356879656991, 0.6490878757769967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 23}], {
             RGBColor[
             0.9801796714011944, 0.9518718565732095, 0.5840536111729073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 51}], {
             RGBColor[
             0.8911547141993119, 0.8831957888790658, 0.6618581652210298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.978010186853574, 0.9509747189595588, 0.6200075845730131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[
             0.8880392864849254, 0.5438464775091899, 0.242104808287807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 92}], {
             RGBColor[
             0.8780406889079944, 0.46699287511950294`, 0.23253013995633712`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 101}], {
             RGBColor[
             0.8091703552886713, 0.8191489845938676, 0.6536867305122107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 128}], {
             RGBColor[
             0.8869643989845882, 0.5355844211628931, 0.24107549480357243`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 142}], {
             RGBColor[
             0.8769612906990375, 0.45869614749014964`, 0.23149650701243416`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 149}], {
             RGBColor[
             0.933258247478127, 0.766135074707167, 0.2882041746629133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 197}], {
             RGBColor[
             0.9786771999205136, 0.9512505460041922, 0.6089534518793391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 198}], {
             RGBColor[
             0.967801874456065, 0.9434968913498611, 0.6433562360480443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 204}], {
             RGBColor[
             0.7273105149978081, 0.7527675975931751, 0.6471903809836539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 226}], {
             RGBColor[
             0.978634912205556, 0.9512330589473125, 0.6096542687532867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 243}], {
             RGBColor[
             0.9792150980469998, 0.9514729807028455, 0.600039087887734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 256}], {
             RGBColor[
             0.868956298803952, 0.39716627197470655`, 0.223830917733355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 290}], {
             RGBColor[
             0.9587118125308915, 0.8695626925266455, 0.3088146906826389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 38}], {
             RGBColor[
             0.19835724810513683`, 0.32581642270738265`, 0.9346075238851115]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 52}], {
             RGBColor[
             0.20466403550360635`, 0.3324452561365908, 0.9349666860973984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.21323620369391516`, 0.3414551484114601, 0.9354548583944501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 88}], {
             RGBColor[
             0.21672673573205908`, 0.345123918896063, 0.935653639030243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 93}], {
             RGBColor[
             0.2258625386311459, 0.35472622698636247`, 0.9361739094901367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 124}], {
             RGBColor[
             0.19825974011141095`, 0.3257139356236129, 0.9346019709491189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 147}], {
             RGBColor[
             0.2119963836374878, 0.34015201892302305`, 0.935384252476386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 273}], {
             RGBColor[
             0.22476258261676274`, 0.3535701034740064, 0.9361112686223567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 289}], {
             RGBColor[
             0.22701980203641853`, 0.3559425842000419, 0.9362398139290493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 42}], {
             RGBColor[
             0.8711763850077039, 0.5112078638480927, 0.45219338209118976`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 60}], {
             RGBColor[
             0.6127935489939296, 0.6863930727259957, 0.9644818440323379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 77}], {
             RGBColor[
             0.6760511895639363, 0.7431695037981105, 0.9684398535409274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 80}], {
             RGBColor[
             0.9585640473109542, 0.9468487152511682, 0.6807339798518178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 81}], {
             RGBColor[
             0.9138922902616244, 0.7722436147323656, 0.6093859995388808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 82}], {
             RGBColor[
             0.7758796678197641, 0.8252882359458167, 0.9760021123389747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 103}], {
             RGBColor[
             0.6798246620935919, 0.7464378960430543, 0.9686802958737664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 127}], {
             RGBColor[
             0.6435774661849356, 0.7150423967840147, 0.9663706566026036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 130}], {
             RGBColor[
             0.92506143421404, 0.8207777707366587, 0.6185929179813181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 140}], {
             RGBColor[
             0.8576525620588931, 0.4072578344865292, 0.4392429539624352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 145}], {
             RGBColor[
             0.9016117745004403, 0.9243171913792056, 0.9881346792519563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 154}], {
             RGBColor[
             0.7178086500945909, 0.778143567686985, 0.971430549102502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 167}], {
             RGBColor[
             0.9230008546692128, 0.8126082594888467, 0.6169349273115317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 168}], {
             RGBColor[
             0.6693655533207783, 0.7373787417141351, 0.9680138507113893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 181}], {
             RGBColor[
             0.962306825108859, 0.9594739836095195, 0.6952739648323978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 201}], {
             RGBColor[
             0.8763492903148913, 0.5509690808206948, 0.45714696205531347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 202}], {
             RGBColor[
             0.890487052481644, 0.642513633392233, 0.47001474727817605`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 203}], {
             RGBColor[
             0.9377223890197792, 0.9530740402179558, 0.990303930173889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 205}], {
             RGBColor[
             0.6553396994405775, 0.7252302520430189, 0.9671201357047186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 216}], {
             RGBColor[
             0.8904157072945873, 0.6421896715609007, 0.4699552151052654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 237}], {
             RGBColor[
             0.8628230044438239, 0.4470001203594073, 0.4441941754294244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 255}], {
             RGBColor[
             0.6521687790491231, 0.722483760175034, 0.9669180874613099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 269}], {
             RGBColor[
             0.9557422920381128, 0.9373302721362289, 0.6697719934605999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 282}], {
             RGBColor[
             0.6894759164963487, 0.7547973275205713, 0.9692952652700408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 293}], {
             RGBColor[
             0.9190392263270429, 0.795614649307972, 0.6136807291548138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 299}], {
             RGBColor[
             0.8585691612482524, 0.41430321751227117`, 0.4401206903813164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 14}], {
             RGBColor[
             0.19233103918746458`, 0.31948249505119564`, 0.9342643402022272]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 64}], {
             RGBColor[
             0.21988638356939655`, 0.34844490910634823`, 0.9358335763002992]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 67}], {
             RGBColor[
             0.1916976136601492, 0.31881672466048916`, 0.9342282675555156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 69}], {
             RGBColor[
             0.2060185451131012, 0.33386893161703934`, 0.9350438234158418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 85}], {
             RGBColor[
             0.21830835870760254`, 0.3467863049240477, 0.9357437101188987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 121}], {
             RGBColor[
             0.21495883648631775`, 0.3432657446975026, 0.9355529597835706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 135}], {
             RGBColor[
             0.2087723681564475, 0.33676337423806185`, 0.9352006495642442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 173}], {
             RGBColor[
             0.2028775855537629, 0.3305675839718365, 0.9348649504155706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 186}], {
             RGBColor[
             0.19879211006828354`, 0.3262734902024908, 0.934632288630592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 213}], {
             RGBColor[
             0.20342164602247398`, 0.3311394260198779, 0.9348959338543985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 234}], {
             RGBColor[
             0.19931169581116837`, 0.32681960776190155`, 0.934661878269991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 249}], {
             RGBColor[
             0.20596246033793864`, 0.3338099829623634, 0.9350406294708662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 263}], {
             RGBColor[
             0.20717874992744892`, 0.3350883804381527, 0.9351098953636496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 286}], {
             RGBColor[
             0.21267948434468417`, 0.34087000107737286`, 0.9354231540511039]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 45}], {
             RGBColor[
             0.24944742731977937`, 0.3795154403664275, 0.9375170340102383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 47}], {
             RGBColor[
             0.1915298565644043, 0.31864040131644705`, 0.9342187140370874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 96}], {
             RGBColor[
             0.19995528537104273`, 0.3274960611952644, 0.9346985297433206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 112}], {
             RGBColor[
             0.19409572030031721`, 0.3213372867880486, 0.9343648361809924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 132}], {
             RGBColor[
             0.19792820821317225`, 0.32536547457822756`, 0.9345830906979717]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 133}], {
             RGBColor[
             0.19212471165815448`, 0.3192656317359698, 0.9342525901546672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 141}], {
             RGBColor[
             0.24640393833854723`, 0.3763165404788058, 0.9373437118151957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 146}], {
             RGBColor[
             0.1994945649800457, 0.3270118148529666, 0.9346722923986279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 236}], {
             RGBColor[
             0.21519552032906075`, 0.34351451442284786`, 0.9355664385782725]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 22}], {
             RGBColor[
             0.18947218593303478`, 0.31647765901902436`, 0.9341015327386817]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 48}], {
             RGBColor[
             0.19160641114189197`, 0.3187208650312271, 0.934223073707023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 63}], {
             RGBColor[
             0.18664280478053893`, 0.31350380003462497`, 0.9339404036677414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 71}], {
             RGBColor[
             0.20685989156236995`, 0.3347532400796667, 0.9350917368514671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 73}], {
             RGBColor[
             0.18653587436616526`, 0.31339140938933835`, 0.9339343141388322]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 100}], {
             RGBColor[
             0.18553288790448116`, 0.3123372070250937, 0.9338771955436248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 119}], {
             RGBColor[
             0.1856272606689936, 0.3124363987841752, 0.9338825699329518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 122}], {
             RGBColor[
             0.1877216481680741, 0.3146377328375459, 0.9340018422026558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 161}], {
             RGBColor[
             0.19602879349749167`, 0.3233690692821986, 0.9344749218398459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 244}], {
             RGBColor[
             0.1899533548754444, 0.3169833980853699, 0.9341289345981263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 266}], {
             RGBColor[
             0.19427634422620857`, 0.3215271339863788, 0.9343751224463628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 51}], {
             RGBColor[
             0.6715557743614986, 0.7416503460034106, 0.9690558457242018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 101}], {
             RGBColor[
             0.589571415450858, 0.6776035417182125, 0.9608844110153827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 104}], {
             RGBColor[
             0.4334513122055766, 0.547724101182389, 0.9494290167598639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 114}], {
             RGBColor[
             0.38547343504917886`, 0.49973179121413747`, 0.9466075727466067]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 116}], {
             RGBColor[
             0.4095833128093886, 0.5250728013946587, 0.9479805946176828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 149}], {
             RGBColor[
             0.7136593076403137, 0.6245896318315118, 0.5954018551660852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 197}], {
             RGBColor[
             0.7590782600827003, 0.809705103128537, 0.9161511323825111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 198}], {
             RGBColor[
             0.7482029346182517, 0.8019514484742061, 0.9505539165512161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 204}], {
             RGBColor[
             0.5077115751599948, 0.6112221547175201, 0.9543880614868259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 243}], {
             RGBColor[
             0.7596161582091865, 0.8099275378271904, 0.907236768390906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 254}], {
             RGBColor[
             0.4252983225505378, 0.5406623913243694, 0.9489095154684506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 283}], {
             RGBColor[
             0.41881779248479195`, 0.534778825033336, 0.9485064845740085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.3382052536051789, 0.4616299042238716, 0.9429808558058818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 27}], {
             RGBColor[
             0.6997308165084448, 0.7282337735956864, 0.6429681792954851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.33246233459167696`, 0.45559373221858496`, 0.9426538050639501]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 76}], {
             RGBColor[
             0.3782689418854923, 0.5020592779365523, 0.9453239403802199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 87}], {
             RGBColor[
             0.7113840896935575, 0.7671448961592477, 0.7220908533867955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 151}], {
             RGBColor[
             0.5137240937710055, 0.6154599354387978, 0.9550391768879118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 154}], {
             RGBColor[
             0.46345887168868094`, 0.5746523637299171, 0.9510821144780158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 181}], {
             RGBColor[
             0.707957046702949, 0.7559827796524516, 0.6749255302079116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 192}], {
             RGBColor[
             0.3801187118441842, 0.5036614557026298, 0.9454418060863005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 220}], {
             RGBColor[
             0.38135478455479077`, 0.5047320797577364, 0.9455205675464041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 239}], {
             RGBColor[
             0.3335981101513706, 0.4567875043441526, 0.9427184858018454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 258}], {
             RGBColor[
             0.3848908244823526, 0.507794819816456, 0.9457458808837911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 32}], {
             RGBColor[
             0.6604824509868196, 0.7261357390166185, 0.898179624729629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 53}], {
             RGBColor[
             0.27458306643531494`, 0.40366544683013694`, 0.9390315559482794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 93}], {
             RGBColor[
             0.2872094013725457, 0.41693652540503934`, 0.939750607043966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 107}], {
             RGBColor[
             0.3708820169269006, 0.49566109481506393`, 0.9448532520538597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 137}], {
             RGBColor[
             0.2974114508687985, 0.42765952627289927`, 0.9403315986701979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 147}], {
             RGBColor[
             0.27334324637888757`, 0.4023623173416999, 0.9389609500302152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 156}], {
             RGBColor[
             0.3638901315072269, 0.4896050750869218, 0.9444077352975997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 179}], {
             RGBColor[
             0.42802275177735205`, 0.5432681021152472, 0.9490151577652866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 251}], {
             RGBColor[
             0.3094480150189227, 0.44031071835692515`, 0.9410170631920465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 270}], {
             RGBColor[
             0.27306394266259, 0.4020687514269927, 0.9389450440967648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 271}], {
             RGBColor[
             0.2779619784734704, 0.40721689761763513`, 0.9392239799901998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 273}], {
             RGBColor[
             0.2861094453581625, 0.4157804018926833, 0.9396879661761859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 274}], {
             RGBColor[
             0.3981676494624695, 0.5190303850989934, 0.9466648547482157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 277}], {
             RGBColor[
             0.6631499633187324, 0.7252798242769541, 0.7115734484509257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 282}], {
             RGBColor[
             0.38696044305919663`, 0.509587419405664, 0.9458777551494157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 289}], {
             RGBColor[
             0.2883666647778183, 0.41815288261871875`, 0.9398165114828785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 67}], {
             RGBColor[
             0.17956042552731538`, 0.30605977039070653`, 0.9335370726467116]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 173}], {
             RGBColor[
             0.1907403974209291, 0.31781062970205387`, 0.9341737555067666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 186}], {
             RGBColor[
             0.18665492193544975`, 0.31351653593270823`, 0.9339410937217879]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.19128445788964016`, 0.31838247175009526`, 0.9342047389455943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 249}], {
             RGBColor[
             0.19382527220510481`, 0.3210530286925808, 0.9343494345620621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 46}], {
             RGBColor[
             0.23154240030757095`, 0.3606961217323153, 0.9364973692100068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 60}], {
             RGBColor[
             0.27282174145117777`, 0.4040833265356404, 0.9388481666208225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.23002654529780098`, 0.3591028620062883, 0.9364110435097069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 77}], {
             RGBColor[
             0.3360793820211845, 0.46085975760775527`, 0.942806176129412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 82}], {
             RGBColor[
             0.43590786027701234`, 0.5429784897554615, 0.9503684349274593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 103}], {
             RGBColor[
             0.33985285455084013`, 0.464128149852699, 0.9430466184622509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 127}], {
             RGBColor[
             0.3036056586421837, 0.43273265059365945`, 0.9407369791910881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 135}], {
             RGBColor[
             0.2357262900418861, 0.3650936551170112, 0.9367356355408658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 158}], {
             RGBColor[
             0.22566086224390924`, 0.3545142523163553, 0.9361624243182372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 168}], {
             RGBColor[
             0.3293937457780264, 0.4550689955237798, 0.942380173299874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 186}], {
             RGBColor[
             0.22574603195372214`, 0.35460377108144014`, 0.9361672746072136]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 196}], {
             RGBColor[
             0.23071789586563907`, 0.35982951528724394`, 0.9364504149017838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 212}], {
             RGBColor[
             0.24587235329600743`, 0.3757578108946581, 0.9373134388334325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 214}], {
             RGBColor[
             0.22960322819742474`, 0.35865792889393855`, 0.936386936227082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 225}], {
             RGBColor[
             0.2429863506332136, 0.37272443911292436`, 0.9371490852512447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 255}], {
             RGBColor[
             0.31219697150637127`, 0.44017401398467865`, 0.9412844100497945]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 265}], {
             RGBColor[
             0.24054595553413333`, 0.37015942913380495`, 0.9370101083605932]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 276}], {
             RGBColor[
             0.24987495920564082`, 0.37996480348555506`, 0.9375413813186614]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 286}], {
             RGBColor[
             0.23963340623012278`, 0.3692002819563222, 0.9369581400277256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.22364840280037163`, 0.35239902984389887`, 0.9360478177300946]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 39}], {
             RGBColor[
             0.22425729902189784`, 0.35303901837897317`, 0.9360824934691292]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 76}], {
             RGBColor[
             0.286854066125812, 0.4171520866149722, 0.9397088035477686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 90}], {
             RGBColor[
             0.2312332284112072, 0.3603711624666066, 0.9364797623278878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 126}], {
             RGBColor[
             0.23513936956710785`, 0.3644767644851118, 0.9367022112880983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 151}], {
             RGBColor[
             0.42230921801132515`, 0.5305527441172178, 0.9494240400554605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 153}], {
             RGBColor[
             0.233929772423327, 0.36320540119410966`, 0.9366333265201985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 192}], {
             RGBColor[
             0.28870383608450384`, 0.4187542643810497, 0.9398266692538492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 220}], {
             RGBColor[
             0.2899399087951104, 0.41982488843615623`, 0.9399054307139528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 222}], {
             RGBColor[
             0.23410797445122994`, 0.3633927028240968, 0.9366434748620613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 239}], {
             RGBColor[
             0.2421832343916902, 0.3718803130225725, 0.9371033489693941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 248}], {
             RGBColor[
             0.23437455245828825`, 0.36367289321153695`, 0.9366586560851965]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 285}], {
             RGBColor[
             0.22323502267117318`, 0.3519645411182973, 0.9360242763432778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 40}], {
             RGBColor[
             0.6964483919711273, 0.7627900441024493, 0.9703791250975754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[
             0.7929575364765972, 0.44951011621237846`, 0.44612850273328253`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 66}], {
             RGBColor[
             0.5450024443168381, 0.6387388987189666, 0.9584682781320619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 81}], {
             RGBColor[
             0.7965640174649642, 0.6796969932787943, 0.60028868050202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 86}], {
             RGBColor[
             0.648920103921949, 0.7249224984916083, 0.966146582786049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 94}], {
             RGBColor[
             0.7502759773076164, 0.8048405628721153, 0.9757441557565323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 97}], {
             RGBColor[
             0.5762606506463335, 0.665813185958444, 0.9604600233988309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 120}], {
             RGBColor[
             0.4913767245940681, 0.5895491243083159, 0.9551516880301447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 130}], {
             RGBColor[
             0.8077331614173798, 0.7282311492830874, 0.6094955989444572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 140}], {
             RGBColor[
             0.7794337135277863, 0.345560086850815, 0.43317807460452784`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 162}], {
             RGBColor[
             0.8475057087773203, 0.8795582824939998, 0.8820715972741542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 169}], {
             RGBColor[
             0.654201051554568, 0.729209809683748, 0.9665623183284373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 178}], {
             RGBColor[
             0.4813372368134904, 0.5789969861106385, 0.9545799540531321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 182}], {
             RGBColor[
             0.47900337512465124`, 0.5765439495002909, 0.9544470440825916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 201}], {
             RGBColor[
             0.7981304417837846, 0.4892713331849807, 0.45108208269740613`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 202}], {
             RGBColor[
             0.8122682039505371, 0.5808158857565188, 0.4639498679202687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 294}], {
             RGBColor[
             0.6198562799736641, 0.7013271769000424, 0.963858572100545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 26}], {
             RGBColor[
             0.21453517633612967`, 0.3428204510180499, 0.9355288329647664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 33}], {
             RGBColor[
             0.20024058888485757`, 0.32779593327757145`, 0.9347147773563635]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 35}], {
             RGBColor[
             0.20318410319091706`, 0.3308897534428262, 0.9348824061415544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 129}], {
             RGBColor[
             0.1945312219559263, 0.32179502664049353`, 0.9343896373560123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 165}], {
             RGBColor[
             0.2088844992725249, 0.33688123115058255`, 0.9352070352654217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 175}], {
             RGBColor[
             0.19129167307218187`, 0.3183900553644156, 0.9342051498395663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 183}], {
             RGBColor[
             0.19635753288152386`, 0.32371459521809726`, 0.9344936430614402]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 184}], {
             RGBColor[
             0.19573226525779447`, 0.3230573993013006, 0.9344580349952694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.2043212377981297, 0.33208495401350496`, 0.9349471642751953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 253}], {
             RGBColor[
             0.19591234458530662`, 0.3232466740922047, 0.9344682902465677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 262}], {
             RGBColor[
             0.25190729178629806`, 0.38210091388515394`, 0.9376571196525632]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 36}], {
             RGBColor[
             0.200168643680248, 0.32772031430593734`, 0.9347106801833944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 37}], {
             RGBColor[
             0.22278622542452461`, 0.3514928267566807, 0.9359987180040172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 41}], {
             RGBColor[
             0.20379941702053028`, 0.3315364872908998, 0.9349174473538756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 44}], {
             RGBColor[
             0.26761174198818394`, 0.3979163278083595, 0.93857676425113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 55}], {
             RGBColor[
             0.21057054856025512`, 0.3386533758536862, 0.9353030532780715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 61}], {
             RGBColor[
             0.248131704384919, 0.378132532140237, 0.9374421055355356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 71}], {
             RGBColor[
             0.22116050761720274`, 0.349784094264723, 0.9359061357799242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 108}], {
             RGBColor[
             0.2298448182232575, 0.3589118553287811, 0.9364006944216527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 136}], {
             RGBColor[
             0.3058098324986471, 0.43100159391667037`, 0.9410107128012115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 152}], {
             RGBColor[
             0.20076184690853469`, 0.3283438085101236, 0.9347444622296798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 177}], {
             RGBColor[
             0.2554879446971804, 0.38586440712099823`, 0.9378610325387366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 208}], {
             RGBColor[
             0.20416035452872197`, 0.331915855496769, 0.9349380022110079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 252}], {
             RGBColor[
             0.2284732256377411, 0.3574702245574107, 0.936322584252997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 268}], {
             RGBColor[
             0.21202685048114545`, 0.34018404150741677`, 0.9353859875180606]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 279}], {
             RGBColor[
             0.22783544818024304`, 0.35679988001215385`, 0.9362862637702997]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 280}], {
             RGBColor[
             0.24050854139809294`, 0.3701201045046333, 0.9370079776808949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 50}], {
             RGBColor[
             0.18770061499905671`, 0.31461562564332873`, 0.9340006443947961]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 74}], {
             RGBColor[
             0.19973960321144332`, 0.32726936557048675`, 0.9346862469634045]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[
             0.21635493982133241`, 0.34473313782066695`, 0.9356324658031498]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 123}], {
             RGBColor[
             0.1960904957019222, 0.3234339222112008, 0.934478435689108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 189}], {
             RGBColor[
             0.20470683599275827`, 0.3324902421643972, 0.934969123521938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 206}], {
             RGBColor[
             0.20800021126608947`, 0.33595178838872103`, 0.9351566763716421]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 257}], {
             RGBColor[
             0.1888268034733999, 0.3157993211343368, 0.9340647791623633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 287}], {
             RGBColor[
             0.21828938866019382`, 0.34676636620145074`, 0.9357426298027625]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 300}], {
             RGBColor[
             0.2096118710905434, 0.33764574504935696`, 0.9352484580144076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.19067565939696252`, 0.3177425859342372, 0.934170068772073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 63}], {
             RGBColor[
             0.18571205303560948`, 0.312525520937635, 0.9338873987327916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 70}], {
             RGBColor[
             0.19915563229546623`, 0.32665557511190024`, 0.9346529906836472]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 73}], {
             RGBColor[
             0.1856051226212358, 0.3124131302923484, 0.9338813092038822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 100}], {
             RGBColor[
             0.1846021361595517, 0.3113589279281038, 0.9338241906086748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 119}], {
             RGBColor[
             0.18469650892406414`, 0.31145811968718523`, 0.933829564998002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 122}], {
             RGBColor[
             0.18679089642314464`, 0.31365945374055604`, 0.9339488372677058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 161}], {
             RGBColor[
             0.1950980417525622, 0.32239079018520866`, 0.934421916904896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 244}], {
             RGBColor[
             0.18902260313051494`, 0.31600511898838, 0.9340759296631764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 266}], {
             RGBColor[
             0.1933455924812791, 0.32054885488938883`, 0.9343221175114128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 24}], {
             RGBColor[
             0.956555334204736, 0.8626596651038085, 0.541866983332811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 31}], {
             RGBColor[
             0.7044976010018857, 0.7638813972041334, 0.8870888196503636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 44}], {
             RGBColor[
             0.6527829845870825, 0.7190887957178285, 0.883793610021852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 59}], {
             RGBColor[
             0.9871771704378065, 0.988965444691414, 0.8621710004720957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 72}], {
             RGBColor[
             0.8827258558765204, 0.48135797009659975`, 0.3926067291806665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 83}], {
             RGBColor[
             0.8941506088744137, 0.5691736279970934, 0.4035470855538621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 106}], {
             RGBColor[
             0.9256036309143629, 0.94127542594585, 0.906451627608196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 136}], {
             RGBColor[
             0.6909810750975458, 0.7521740618261392, 0.8862275585719336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 155}], {
             RGBColor[
             0.9578302462805677, 0.8677142666452164, 0.5428928075150579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 194}], {
             RGBColor[
             0.8376760987270953, 0.8722472965038359, 0.8977776532625734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 197}], {
             RGBColor[
             0.9878441835047461, 0.9892412717360475, 0.8511168677784218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 198}], {
             RGBColor[
             0.9769688580402975, 0.9814876170817164, 0.8855196519471269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 210}], {
             RGBColor[
             0.7305128529889463, 0.7859159553283347, 0.8888842381324313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 226}], {
             RGBColor[
             0.9878018957897885, 0.9892237846791677, 0.8518176846523693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 241}], {
             RGBColor[
             0.9877354309295805, 0.9891962997514028, 0.8529191793915591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 290}], {
             RGBColor[
             0.9678787961151241, 0.9075534182585008, 0.5509781065817215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 291}], {
             RGBColor[
             0.9581107393338224, 0.9671957118175754, 0.9095521846286824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.9468027585380377, 0.8226935997742366, 0.2974286527731346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 59}], {
             RGBColor[
             0.9543858496571156, 0.8617625274901577, 0.5778209567329167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 65}], {
             RGBColor[
             0.6506137006766177, 0.6184091477452374, 0.6013947753940398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 72}], {
             RGBColor[
             0.8608649753560598, 0.3965560252957622, 0.20304003335454723`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 87}], {
             RGBColor[
             0.9584560317231505, 0.8616047223377981, 0.3765513268644449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 106}], {
             RGBColor[
             0.892812310133672, 0.8140725087445938, 0.6221015838690171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 109}], {
             RGBColor[
             0.9582875876148832, 0.8633759964057863, 0.5131590613985512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 155}], {
             RGBColor[
             0.9250389254998768, 0.7405113494439601, 0.2585427637758789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 162}], {
             RGBColor[
             0.9575561451976635, 0.8630735261690534, 0.5252809551641785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 194}], {
             RGBColor[
             0.8048847779464043, 0.7450443793025796, 0.6134276095233945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 210}], {
             RGBColor[
             0.6977215322082554, 0.6587130381270785, 0.6045341943932525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 218}], {
             RGBColor[
             0.945476791560533, 0.8552536816107574, 0.5989703095762722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 226}], {
             RGBColor[
             0.9550105750090976, 0.8620208674779115, 0.5674676409131905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 227}], {
             RGBColor[
             0.9382342504393061, 0.7928264157474236, 0.2691600319562284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 241}], {
             RGBColor[
             0.9549441101488896, 0.8619933825501465, 0.5685691356523801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 290}], {
             RGBColor[
             0.9350874753344331, 0.7803505010572445, 0.2666280628425426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 291}], {
             RGBColor[
             0.9253194185531315, 0.839992794616319, 0.6252021408895034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 299}], {
             RGBColor[
             0.8537172703307078, 0.34161563232659264`, 0.19619538295009195`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 28}], {
             RGBColor[
             0.18729283765525817`, 0.3141870258004196, 0.9339774220783192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 58}], {
             RGBColor[
             0.19112827338567, 0.31821831193375316`, 0.9341958444691476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 79}], {
             RGBColor[
             0.18712823581077753`, 0.3140140188255107, 0.9339680482467827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 113}], {
             RGBColor[
             0.22937411863723062`, 0.3584171202197894, 0.9363738887765662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 134}], {
             RGBColor[
             0.21795734402989536`, 0.34641736624216146`, 0.935723720352283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 144}], {
             RGBColor[
             0.19437777007737006`, 0.3216337389867199, 0.9343808984985402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 160}], {
             RGBColor[
             0.19344001775085345`, 0.32064810183461934`, 0.9343274948908254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 176}], {
             RGBColor[
             0.19265413404658233`, 0.31982208823352565`, 0.9342827399764779]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.1930001178726018, 0.32018573917131365`, 0.9343024432435325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 221}], {
             RGBColor[
             0.1886556188584439, 0.3156193952502866, 0.9340550304517865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 230}], {
             RGBColor[
             0.19160057419890764`, 0.31871473003406703`, 0.934222741301755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 232}], {
             RGBColor[
             0.1895116930698092, 0.31651918352467145`, 0.9341037826116756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 245}], {
             RGBColor[
             0.2081790637788683, 0.33613977371955583`, 0.9351668617576563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 288}], {
             RGBColor[
             0.19999048340527747`, 0.32753305656092946`, 0.9347005342192993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 297}], {
             RGBColor[
             0.19155439006973912`, 0.318666187586068, 0.9342201111839221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 35}], {
             RGBColor[
             0.21774452951257628`, 0.3461936846912394, 0.9357116008803525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 54}], {
             RGBColor[
             0.23656624471631046`, 0.3659765007360335, 0.9367834697169728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 75}], {
             RGBColor[
             0.28101248706842963`, 0.4104564015750206, 0.9393964853748475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 102}], {
             RGBColor[
             0.21064547425155244`, 0.3387321275058029, 0.9353073201853483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 129}], {
             RGBColor[
             0.20909164827758553`, 0.33709895788890676`, 0.9352188320948104]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 165}], {
             RGBColor[
             0.2234449255941841, 0.3521851623989958, 0.9360362300042198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 175}], {
             RGBColor[
             0.20585209939384108`, 0.33369398661282884`, 0.9350343445783642]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 183}], {
             RGBColor[
             0.21091795920318307`, 0.3390185264665105, 0.9353228378002383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 224}], {
             RGBColor[
             0.21888166411978893`, 0.3473888852619182, 0.9357763590139934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 253}], {
             RGBColor[
             0.21047277090696587`, 0.3385506053406179, 0.9352974849853658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 262}], {
             RGBColor[
             0.26646771810795733`, 0.39740484513356716`, 0.9384863143913613]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 42}], {
             RGBColor[
             0.8816836574994876, 0.49667817991020385`, 0.23487588344630034`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 72}], {
             RGBColor[
             0.8762241387653882, 0.45471392654355186`, 0.22964784214088227`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 87}], {
             RGBColor[
             0.9814947768371431, 0.9488415742094825, 0.4164630400439475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 109}], {
             RGBColor[
             0.9813263327288758, 0.9506128482774708, 0.5530707745780536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 140}], {
             RGBColor[
             0.8681598345506768, 0.3927281505486404, 0.22192545531754573`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 151}], {
             RGBColor[
             0.7838347809145911, 0.7971566134890326, 0.6494113635450639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 154}], {
             RGBColor[
             0.7335695588322665, 0.7563490417801518, 0.6454543011351679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 155}], {
             RGBColor[
             0.9480776706138694, 0.8277482013156446, 0.2984544769553814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 162}], {
             RGBColor[
             0.9805948903116561, 0.9503103780407378, 0.565192668343681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 181}], {
             RGBColor[
             0.9780677338465346, 0.9376794577026863, 0.3692977168650637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 202}], {
             RGBColor[
             0.9009943249734276, 0.6279839494543441, 0.2526972486332866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 203}], {
             RGBColor[
             0.9534832977574548, 0.9312795143111227, 0.6643276822065549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 216}], {
             RGBColor[
             0.9009229797863709, 0.6276599876230118, 0.25263771646037597`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 227}], {
             RGBColor[
             0.9612729955532987, 0.8800632676191081, 0.309071745135731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 299}], {
             RGBColor[
             0.8690764337400362, 0.3997735335743823, 0.222803191736427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 79}], {
             RGBColor[
             0.1833054434406642, 0.3099960216654862, 0.9337503458766192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 144}], {
             RGBColor[
             0.19055497770725674`, 0.3176157418266954, 0.9341631961283768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 160}], {
             RGBColor[
             0.18961722538074013`, 0.31663010467459485`, 0.9341097925206621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 176}], {
             RGBColor[
             0.18883134167646898`, 0.3158040910735011, 0.9340650376063144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 221}], {
             RGBColor[
             0.18483282648833058`, 0.31160139809026205`, 0.9338373280816231]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 230}], {
             RGBColor[
             0.1877777818287943, 0.3146967328740425, 0.9340050389315915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 232}], {
             RGBColor[
             0.18568890069969585`, 0.3125011863646469, 0.9338860802415121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 240}], {
             RGBColor[
             0.18200025991928498`, 0.3086241910311017, 0.9336760176059227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 245}], {
             RGBColor[
             0.204356271408755, 0.33212177655953135`, 0.9349491593874928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 288}], {
             RGBColor[
             0.19616769103516415`, 0.32351505940090497`, 0.9344828318491358]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 297}], {
             RGBColor[
             0.18773159769962583`, 0.31464819042604353`, 0.9340024088137586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 43}], {
             RGBColor[
             0.21042089134742065`, 0.3384960766341818, 0.9352945305211986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 78}], {
             RGBColor[
             0.1946932984138494, 0.3219653792740117, 0.9343988673705204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 99}], {
             RGBColor[
             0.19546469586089602`, 0.32277616690028066`, 0.9344427973139495]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 131}], {
             RGBColor[
             0.21233150972289871`, 0.34050425768701104`, 0.9354033374111754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 170}], {
             RGBColor[
             0.19641582947302122`, 0.3237758686319784, 0.934496962966084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 178}], {
             RGBColor[
             0.22713326298795516`, 0.3560618388539467, 0.9362462753623888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 182}], {
             RGBColor[
             0.224799401299116, 0.35360880224359903`, 0.9361133653918483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 190}], {
             RGBColor[
             0.199834842245044, 0.32736946783330456`, 0.9346916706854744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 199}], {
             RGBColor[
             0.196824977685108, 0.32420590934437654`, 0.9345202633514818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 209}], {
             RGBColor[
             0.1878554243304431, 0.3147783400660943, 0.9340094605571987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 229}], {
             RGBColor[
             0.20648377022612274`, 0.3343579127078008, 0.9350703172977894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 259}], {
             RGBColor[
             0.19020824390880345`, 0.3172513026203284, 0.9341434501515016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 261}], {
             RGBColor[
             0.21999581851421782`, 0.3485599321719316, 0.9358398084585123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 284}], {
             RGBColor[
             0.21810645410068208`, 0.3465740903806829, 0.9357322119502256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 74}], {
             RGBColor[
             0.22759891531018372`, 0.3565512689686714, 0.9362727935732689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 104}], {
             RGBColor[
             0.2921921290764705, 0.4220073511871032, 0.9400404564262714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 123}], {
             RGBColor[
             0.2239498078006626, 0.3527158256093854, 0.9360649822989724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 189}], {
             RGBColor[
             0.23256614809149867`, 0.36177214556258186`, 0.9365556701318023]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 236}], {
             RGBColor[
             0.2403636886171835, 0.3699678550477007, 0.9369997285293126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 260}], {
             RGBColor[
             0.25373200019445147`, 0.38401879811531836`, 0.9377610340969933]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 267}], {
             RGBColor[
             0.22275125819820335`, 0.35145607398476686`, 0.9359967266722076]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 287}], {
             RGBColor[
             0.24614870075893425`, 0.37604826959963533`, 0.9373291764126268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 300}], {
             RGBColor[
             0.23747118318928384`, 0.36692764844754155`, 0.936835004624272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 37}], {
             RGBColor[
             0.32310841403988205`, 0.4466841095652183, 0.9420873563531128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 44}], {
             RGBColor[
             0.36793393060354135`, 0.4931076106168971, 0.9446654026002257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 59}], {
             RGBColor[
             0.7023281164542653, 0.7629842595904825, 0.9230427930504692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 61}], {
             RGBColor[
             0.3484538930002764, 0.47332381494877457`, 0.9435307438846312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 65}], {
             RGBColor[
             0.3985559674737674, 0.5196308798455622, 0.9466166117115924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 71}], {
             RGBColor[
             0.32148269623256015`, 0.4449753770732606, 0.9419947741290198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 136}], {
             RGBColor[
             0.4061320211140046, 0.526192876725208, 0.9470993511503072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 177}], {
             RGBColor[
             0.3558101333125378, 0.4810556899295358, 0.9439496708878323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 194}], {
             RGBColor[
             0.552827044743554, 0.6462661114029045, 0.958649445840947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 210}], {
             RGBColor[
             0.4456637990054052, 0.5599347702274033, 0.949756030710805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 226}], {
             RGBColor[
             0.7029528418062473, 0.7632425995782364, 0.912689477230743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 241}], {
             RGBColor[
             0.7028863769460394, 0.7632151146504713, 0.9137909719699326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 279}], {
             RGBColor[
             0.32815763679560045`, 0.4519911628206914, 0.9423749021193952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 280}], {
             RGBColor[
             0.3408307300134504, 0.46531138731317084`, 0.9430966160299905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 290}], {
             RGBColor[
             0.683029742131583, 0.6815722331575694, 0.6118498991600951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 291}], {
             RGBColor[
             0.6732616853502813, 0.7412145267166439, 0.970423977207056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 80}], {
             RGBColor[
             0.9832422855582464, 0.9646748589231064, 0.6130382528147665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 92}], {
             RGBColor[
             0.883595180526095, 0.49208976177353947`, 0.4032005441361298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 107}], {
             RGBColor[
             0.6980757286113448, 0.7586971466019095, 0.9005750351374335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 125}], {
             RGBColor[
             0.8860217022210372, 0.5107410708294523, 0.40552418405157087`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 128}], {
             RGBColor[
             0.8925188906026889, 0.5606813078169296, 0.41174589898336517`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 142}], {
             RGBColor[
             0.8825157823171381, 0.4837930341441863, 0.4021669111922269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 145}], {
             RGBColor[
             0.9262900127477325, 0.9421433350511439, 0.920438952214905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 149}], {
             RGBColor[
             0.9415899849052779, 0.803780404688222, 0.5442097809326024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 150}], {
             RGBColor[
             0.9475427884309859, 0.8298940012964792, 0.5491295264859543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 156}], {
             RGBColor[
             0.691083843191671, 0.7526411268737674, 0.9001295183811735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 167}], {
             RGBColor[
             0.947679092916505, 0.830434403160785, 0.5492392002744804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 179}], {
             RGBColor[
             0.7552164634617963, 0.8063041539020928, 0.9047369408488604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 205}], {
             RGBColor[
             0.6800179376878698, 0.7430563957149572, 0.8994244086676673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 237}], {
             RGBColor[
             0.879275163275352, 0.4588842161406994, 0.3990636907380568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 256}], {
             RGBColor[
             0.8745107904220526, 0.4222631586287432, 0.39450132191314774`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 269}], {
             RGBColor[
             0.980420530285405, 0.9551564158081671, 0.6020762664235486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 277}], {
             RGBColor[
             0.9903436750031767, 0.9883158760637997, 0.6672952315344995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 282}], {
             RGBColor[
             0.7141541547436409, 0.7726234711925095, 0.9015995382329896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 293}], {
             RGBColor[
             0.9437174645743351, 0.8134407929799102, 0.5459850021177625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 98}], {
             RGBColor[
             0.18977923539730202`, 0.3168003874740297, 0.9341190187514328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 126}], {
             RGBColor[
             0.2119973945219809, 0.3401530814267192, 0.9353843100447624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 153}], {
             RGBColor[
             0.21078779737820008`, 0.338881718135717, 0.9353154252768627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 157}], {
             RGBColor[
             0.19152225944429985`, 0.31863241626153205`, 0.9342182813923363]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 171}], {
             RGBColor[
             0.189827260881899, 0.31685086530333273`, 0.9341217537317332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 184}], {
             RGBColor[
             0.1959981041281816, 0.3233368128092353, 0.9344731741256647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 222}], {
             RGBColor[
             0.210965999406103, 0.33906901976570414`, 0.9353255736187255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 248}], {
             RGBColor[
             0.21123257741316134`, 0.3393492101531443, 0.9353407548418606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 275}], {
             RGBColor[
             0.19034059746125545`, 0.31739041459565537`, 0.9341509874905143]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 285}], {
             RGBColor[
             0.20009304762604624`, 0.3276408580599046, 0.934706375099942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 38}], {
             RGBColor[
             0.18490621443215238`, 0.31167853347228314`, 0.9338415074164561]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 52}], {
             RGBColor[
             0.1912130018306219, 0.3183073669014913, 0.934200669628743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 53}], {
             RGBColor[
             0.1997851700209307, 0.32731725917636056`, 0.9346888419257947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 57}], {
             RGBColor[
             0.18168430472921848`, 0.3082921020936258, 0.9336580244252622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 84}], {
             RGBColor[
             0.1855804331499768, 0.3123871800926523, 0.9338799031750189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 124}], {
             RGBColor[
             0.1848087064384265, 0.3115760463885134, 0.9338359544804635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 147}], {
             RGBColor[
             0.19854534996450335`, 0.32601412968792354`, 0.9346182360077306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 217}], {
             RGBColor[
             0.1918655955426979, 0.3189932842697143, 0.9342378338752199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 223}], {
             RGBColor[
             0.1825916590093845, 0.3092457889716643, 0.9337096969092074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 247}], {
             RGBColor[
             0.1907246807083084, 0.31779411044059236`, 0.9341728604632337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 270}], {
             RGBColor[
             0.19826604624820576`, 0.32572056377321634`, 0.9346023300742803]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 295}], {
             RGBColor[
             0.19030787854135572`, 0.3173560249363414, 0.9341491241964293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 102}], {
             RGBColor[
             0.19929440110633984`, 0.32680142993057915`, 0.9346608933621363]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 129}], {
             RGBColor[
             0.19774057513237292`, 0.32516826031368307`, 0.9345724052715985]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 165}], {
             RGBColor[
             0.2120938524489715, 0.3402544648237721, 0.9353898031810077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 175}], {
             RGBColor[
             0.19450102624862847`, 0.3217632890376051, 0.9343879177551523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 183}], {
             RGBColor[
             0.19956688605797046`, 0.32708782889128674`, 0.9346764109770263]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 224}], {
             RGBColor[
             0.20753059097457632`, 0.33545818768669444`, 0.9351299321907813]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 253}], {
             RGBColor[
             0.19912169776175326`, 0.3266199077653942, 0.9346510581621539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 262}], {
             RGBColor[
             0.25511664496274467`, 0.3854741475583434, 0.9378398875681493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 41}], {
             RGBColor[
             0.18496389091314852`, 0.31173915511071026`, 0.9338447920067241]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 55}], {
             RGBColor[
             0.19173502245287335`, 0.3188560436734967, 0.9342303979309199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 152}], {
             RGBColor[
             0.18192632080115292`, 0.3085464763299341, 0.9336718068825283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 208}], {
             RGBColor[
             0.1853248284213402, 0.31211852331657947`, 0.9338653468638564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 242}], {
             RGBColor[
             0.18110760662426995`, 0.30768595582055314`, 0.9336251823213337]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 250}], {
             RGBColor[
             0.18199349180428678`, 0.3086170773131154, 0.9336756321717861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 268}], {
             RGBColor[
             0.19319132437376368`, 0.32038670932722724`, 0.934313332170909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 41}], {
             RGBColor[
             0.20758147265742513`, 0.3355116675614536, 0.9351328298273469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 44}], {
             RGBColor[
             0.27139379762507876`, 0.4018915080789134, 0.9387921467246012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 55}], {
             RGBColor[
             0.21435260419714997`, 0.34262855612424004`, 0.9355184357515427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 61}], {
             RGBColor[
             0.25191376002181387`, 0.38210771241079083`, 0.937657488009007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 71}], {
             RGBColor[
             0.22494256325409756`, 0.3537592745352769, 0.9361215182533955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 108}], {
             RGBColor[
             0.23362687386015235`, 0.362887035599335, 0.936616076895124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 136}], {
             RGBColor[
             0.309591888135542, 0.4349767741872242, 0.9412260952746828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 152}], {
             RGBColor[
             0.20454390254542953`, 0.33231898878067745`, 0.9349598447031511]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 161}], {
             RGBColor[
             0.21411146518921928`, 0.3423751037378088, 0.9355047032417743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 177}], {
             RGBColor[
             0.2592700003340752, 0.38983958739155206`, 0.9380764150122078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 208}], {
             RGBColor[
             0.20794241016561682`, 0.3358910357673228, 0.9351533846844792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 252}], {
             RGBColor[
             0.23225528127463596`, 0.3614454048279645, 0.9365379667264683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 268}], {
             RGBColor[
             0.21580890611804032`, 0.3441592217779706, 0.9356013699915318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 279}], {
             RGBColor[
             0.23161750381713786`, 0.36077506028270767`, 0.936501646243771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 280}], {
             RGBColor[
             0.2442905970349878, 0.3740952847751871, 0.9372233601543662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 52}], {
             RGBColor[
             0.19242626978916738`, 0.3195825884515542, 0.934269763444113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 53}], {
             RGBColor[
             0.2009984379794762, 0.32859248072642344`, 0.9347579357411648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 57}], {
             RGBColor[
             0.18289757268776397`, 0.30956732364368866`, 0.9337271182406324]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 88}], {
             RGBColor[
             0.20448897001762012`, 0.33226125121102634`, 0.9349567163769577]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 124}], {
             RGBColor[
             0.186021974396972, 0.31285126793857626`, 0.9339050482958335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 147}], {
             RGBColor[
             0.1997586179230488, 0.3272893512379864, 0.9346873298231007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 247}], {
             RGBColor[
             0.19193794866685385`, 0.31906933199065524`, 0.9342419542786038]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 289}], {
             RGBColor[
             0.21478203632197956`, 0.34307991651500525`, 0.935542891275764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 64}], {
             RGBColor[
             0.2185143800083959, 0.3470028463736865, 0.9357554427271977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 69}], {
             RGBColor[
             0.20464654155210055`, 0.3324268688843776, 0.9349656898427401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 76}], {
             RGBColor[
             0.26432098730221126`, 0.39346839209165385`, 0.9384255780434674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 85}], {
             RGBColor[
             0.21693635514660192`, 0.345344242191386, 0.9356655765457971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 90}], {
             RGBColor[
             0.20870014958760652`, 0.3366874679432882, 0.9351965368235865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 118}], {
             RGBColor[
             0.19522260799965463`, 0.322521717208859, 0.9344290107683887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 126}], {
             RGBColor[
             0.21260629074350712`, 0.3407930699617935, 0.9354189857837971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 153}], {
             RGBColor[
             0.2113966935997263, 0.3395217066707913, 0.9353501010158973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 166}], {
             RGBColor[
             0.19390930592620187`, 0.3211413534614994, 0.9343542201581618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 195}], {
             RGBColor[
             0.1927241486561343, 0.3198956780273474, 0.9342867272049146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 234}], {
             RGBColor[
             0.19793969225016772`, 0.3253775450292399, 0.9345837446968894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 239}], {
             RGBColor[
             0.2196501555680895, 0.3481966184992542, 0.9358201234650929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 248}], {
             RGBColor[
             0.21184147363468755`, 0.3399891986882186, 0.9353754305808952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 263}], {
             RGBColor[
             0.2058067463664483, 0.333646317705491, 0.935031761790548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 285}], {
             RGBColor[
             0.20070194384757245`, 0.3282808465949789, 0.9347410508389766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 42}], {
             RGBColor[
             0.7881477040684427, 0.44575263857904807`, 0.445649103589277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 66}], {
             RGBColor[
             0.5377876957046065, 0.6331026822689709, 0.9577491794160538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 81}], {
             RGBColor[
             0.7893492688527326, 0.6740607768287987, 0.5995695817860118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 86}], {
             RGBColor[
             0.6417053553097174, 0.7192862820416126, 0.9654274840700409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 94}], {
             RGBColor[
             0.7430612286953848, 0.7992043464221197, 0.9750250570405241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 97}], {
             RGBColor[
             0.5690459020341019, 0.6601769695084484, 0.9597409246828227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 120}], {
             RGBColor[
             0.4841619759818365, 0.5839129078583203, 0.9544325893141365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 130}], {
             RGBColor[
             0.8005184128051482, 0.7225949328330918, 0.608776500228449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 140}], {
             RGBColor[
             0.7746238811196319, 0.3418026092174846, 0.43269867546052243`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 162}], {
             RGBColor[
             0.8402909601650888, 0.8739220660440041, 0.881352498558146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 169}], {
             RGBColor[
             0.6469863029423364, 0.7235735932337524, 0.9658432196124291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 178}], {
             RGBColor[
             0.4741224882012588, 0.573360769660643, 0.953860855337124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 182}], {
             RGBColor[
             0.47178862651241965`, 0.5709077330502953, 0.9537279453665835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 201}], {
             RGBColor[
             0.7933206093756301, 0.4855138555516503, 0.4506026835534007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 202}], {
             RGBColor[
             0.8074583715423828, 0.5770584081231883, 0.4634704687762633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 55}], {
             RGBColor[
             0.19536579579315563`, 0.32267221665845913`, 0.9344371651014012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 108}], {
             RGBColor[
             0.21464006545615802`, 0.34293069613355404`, 0.9355348062449824]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 152}], {
             RGBColor[
             0.1855570941414352, 0.31236264931489655`, 0.9338785740530094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 208}], {
             RGBColor[
             0.1889556017616225, 0.3159346963015419, 0.9340721140343375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 219}], {
             RGBColor[
             0.18646440411145038`, 0.3133162896201571, 0.933930244013557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 242}], {
             RGBColor[
             0.18473837996455222`, 0.31150212880551553`, 0.933831949491815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.18562426514456906`, 0.3124332502980778, 0.9338823993422674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 252}], {
             RGBColor[
             0.21326847287064163`, 0.3414890653621836, 0.9354566960763266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 268}], {
             RGBColor[
             0.19682209771404596`, 0.32420288231218963`, 0.9345200993413902]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 80}], {
             RGBColor[
             0.8846726257638872, 0.5067606717091464, 0.24648746073419803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 81}], {
             RGBColor[
             0.8548914543976673, 0.39035727136327797`, 0.1989221405255734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 82}], {
             RGBColor[
             0.7628830394364272, 0.4257203521722454, 0.4433328823923026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 87}], {
             RGBColor[
             0.8894525062895627, 0.5226189282859114, 0.2876243328405072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 130}], {
             RGBColor[
             0.8623375503659444, 0.42271337536614007`, 0.20506008615386487`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 140}], {
             RGBColor[
             0.8308428229488108, 0.23807702936156347`, 0.1771684281287546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 145}], {
             RGBColor[
             0.8467044438902113, 0.49173965579450474`, 0.4514212603342903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 162}], {
             RGBColor[
             0.8888525819392381, 0.5235981308400817, 0.3867774183736629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 167}], {
             RGBColor[
             0.8609638306693929, 0.4172670345342654, 0.20395475904067392`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 181}], {
             RGBColor[
             0.8871678109624904, 0.5151775172813806, 0.25618078405458466`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 201}], {
             RGBColor[
             0.84019118707681, 0.30993265252864627`, 0.18612043217519372`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 202}], {
             RGBColor[
             0.8472600681601863, 0.3557049288144153, 0.19255432478662504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 203}], {
             RGBColor[
             0.8707781869031039, 0.5109108883536715, 0.45286742761557874`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 216}], {
             RGBColor[
             0.847224395566658, 0.3555429478987492, 0.19252455870016974`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 237}], {
             RGBColor[
             0.8334280441412762, 0.2579481722980025, 0.1796440388622492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 269}], {
             RGBColor[
             0.8827914555819929, 0.5004150429658535, 0.23917946980671936`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 293}], {
             RGBColor[
             0.8583227451079464, 0.4059379610803489, 0.20178529360286196`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 299}], {
             RGBColor[
             0.8313011225434905, 0.2415997208744344, 0.17760729633819525`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 66}], {
             RGBColor[
             0.3059641689064351, 0.4317438620573953, 0.9409982635304203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 78}], {
             RGBColor[
             0.20985899682898168`, 0.3379054898691324, 0.9352625314596219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 97}], {
             RGBColor[
             0.33722237523593046`, 0.45881814929687276`, 0.9429900087971892]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 99}], {
             RGBColor[
             0.21063039427602828`, 0.33871627749540134`, 0.9353064614030511]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 178}], {
             RGBColor[
             0.24229896140308743`, 0.37200194944906734`, 0.9371099394514903]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 182}], {
             RGBColor[
             0.23996509971424826`, 0.36954891283871966`, 0.9369770294809499]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 199}], {
             RGBColor[
             0.21199067610024028`, 0.34014601993949717`, 0.9353839274405833]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 215}], {
             RGBColor[
             0.22516415254335911`, 0.35399217892786317`, 0.9361341374356069]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 229}], {
             RGBColor[
             0.221649468641255, 0.3502980233029215, 0.935933981386891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 233}], {
             RGBColor[
             0.2154911007768475, 0.3438251882143545, 0.9355832714475019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 259}], {
             RGBColor[
             0.20537394232393572`, 0.33319141321544904`, 0.9350071142406031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 261}], {
             RGBColor[
             0.23516151692935008`, 0.3645000427670523, 0.9367034725476139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 284}], {
             RGBColor[
             0.23327215251581435`, 0.3625142009758035, 0.9365958760393271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 59}], {
             RGBColor[
             0.650613500039462, 0.7181916581041776, 0.9197475834219577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 61}], {
             RGBColor[
             0.29673927658547317`, 0.4285312134624696, 0.9402355342561197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 71}], {
             RGBColor[
             0.26976807981775686`, 0.40018277558695564`, 0.9386995645005083]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 108}], {
             RGBColor[
             0.27845239042381165`, 0.4093105366510138, 0.9391941231422369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 136}], {
             RGBColor[
             0.3544174046992013, 0.48140027523890294`, 0.9438041415217957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 177}], {
             RGBColor[
             0.3040955168977345, 0.4362630884432308, 0.9406544612593207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 194}], {
             RGBColor[
             0.5011124283287507, 0.6014735099165995, 0.9553542362124354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 204}], {
             RGBColor[
             0.39991382818369614`, 0.5199845367377941, 0.9469303798325985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 226}], {
             RGBColor[
             0.6512382253914439, 0.7184499980919314, 0.9093942676022314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 252}], {
             RGBColor[
             0.27708079783829526`, 0.4078689058796433, 0.9391160129735812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 268}], {
             RGBColor[
             0.2606344226816996, 0.39058272282964934`, 0.9381794162386446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 279}], {
             RGBColor[
             0.27644302038079716`, 0.4071985613343865, 0.9390796924908837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 280}], {
             RGBColor[
             0.2891161135986471, 0.42051878582686586`, 0.939801406401479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 283}], {
             RGBColor[
             0.3110200455084933, 0.44354120705361005`, 0.9410488029197814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 89}], {
             RGBColor[
             0.34033954683031736`, 0.4683920819989782, 0.9429369415722573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 94}], {
             RGBColor[
             0.5484117816822776, 0.636917841037437, 0.9603911500045271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 96}], {
             RGBColor[
             0.2504426073839444, 0.3805614377119254, 0.9375737080426556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 120}], {
             RGBColor[
             0.2895125289687292, 0.4216264024736376, 0.9397986822781397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 131}], {
             RGBColor[
             0.2646712879230951, 0.39551668310902466`, 0.9383840103499137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 132}], {
             RGBColor[
             0.24841553022607393`, 0.3784308510948885, 0.9374582689973068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 141}], {
             RGBColor[
             0.2968912603514489, 0.4293819169954668, 0.9402188901145307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 146}], {
             RGBColor[
             0.24998188699294738`, 0.3800771913696276, 0.937547470697963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 188}], {
             RGBColor[
             0.32789958178650086`, 0.45761720952884744`, 0.9421442779998944]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 236}], {
             RGBColor[
             0.26568284234196243`, 0.3965798909395088, 0.9384416168776075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 260}], {
             RGBColor[
             0.2790511539192304, 0.41063083400712647`, 0.9392029224452882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 281}], {
             RGBColor[
             0.6391981620742301, 0.7080190375817033, 0.9308676637061029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 294}], {
             RGBColor[
             0.4179920843483252, 0.5334044550653643, 0.9485055663485399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 60}], {
             RGBColor[
             0.2459880706675731, 0.3758794371890788, 0.9373200287665547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 62}], {
             RGBColor[
             0.20319287451419632`, 0.3308989726597267, 0.9348829056554392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 117}], {
             RGBColor[
             0.1951092767006187, 0.3224025988279529, 0.9344225567185672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 158}], {
             RGBColor[
             0.1988271914603046, 0.32631036296979365`, 0.9346342864639694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 196}], {
             RGBColor[
             0.2038842250820344, 0.33162562594068223`, 0.9349222770475161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 207}], {
             RGBColor[
             0.1949982416588687, 0.3222858939590454, 0.9344162334372013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 212}], {
             RGBColor[
             0.21903868251240277`, 0.34755392154809645`, 0.9357853009791648]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 214}], {
             RGBColor[
             0.20276955741382008`, 0.3304540395473769, 0.9348587983728143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 225}], {
             RGBColor[
             0.21615267984960895`, 0.3445205497663627, 0.935620947396977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 265}], {
             RGBColor[
             0.21371228475052867`, 0.3419555397872433, 0.9354819705063254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 276}], {
             RGBColor[
             0.22304128842203616`, 0.35176091413899346`, 0.9360132434643936]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.19252503662856937`, 0.3196863986619449, 0.9342753880695046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 112}], {
             RGBColor[
             0.18666547155784385`, 0.31352762425472913`, 0.9339416945071765]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 131}], {
             RGBColor[
             0.20675371716772, 0.33464164405904423`, 0.9350856903767627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 133}], {
             RGBColor[
             0.18469446291568115`, 0.3114559692026503, 0.9338294484808514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 146}], {
             RGBColor[
             0.19206431623757236`, 0.3192021523196471, 0.9342491507248121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 170}], {
             RGBColor[
             0.1908380369178425, 0.3179132550040116, 0.9341793159316711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 190}], {
             RGBColor[
             0.1942570496898653, 0.32150685420533776`, 0.9343740236510617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.18784627824446665`, 0.31476872694983776`, 0.9340089397011326]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 70}], {
             RGBColor[
             0.2012898575043234, 0.328898781124103, 0.9347745316519882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 71}], {
             RGBColor[
             0.2080633650262977, 0.3360181669948795, 0.9351602728848583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 73}], {
             RGBColor[
             0.187739347830093, 0.31465633630455114`, 0.9340028501722235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 100}], {
             RGBColor[
             0.18673636136840888`, 0.31360213394030656`, 0.9339457315770161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 119}], {
             RGBColor[
             0.1868307341329213, 0.31370132569938797`, 0.933951105966343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 122}], {
             RGBColor[
             0.1889251216320018, 0.3159026597527588, 0.9340703782360471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 138}], {
             RGBColor[
             0.21204884540564534`, 0.34020715956762493`, 0.9353872400964722]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 161}], {
             RGBColor[
             0.19723226696141938`, 0.3246339961974114, 0.9345434578732372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 244}], {
             RGBColor[
             0.19115682833937214`, 0.31824832500058275`, 0.9341974706315176]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 266}], {
             RGBColor[
             0.19547981769013628`, 0.32279206090159157`, 0.934443658479754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 54}], {
             RGBColor[
             0.22682934694082163`, 0.355742403819019, 0.936228967793108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 102}], {
             RGBColor[
             0.20090857647606358`, 0.32849803058878846`, 0.9347528182614836]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 143}], {
             RGBColor[
             0.2582581828615999, 0.38877610307504745`, 0.9380187935040003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 172}], {
             RGBColor[
             0.20010293929950806`, 0.3276512548358813, 0.9347069384161122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 174}], {
             RGBColor[
             0.22141328802375174`, 0.3500497824992095, 0.9359205312501221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 238}], {
             RGBColor[
             0.19853266531396374`, 0.3260007973159532, 0.9346175136356476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 298}], {
             RGBColor[
             0.23487979924778435`, 0.36420393962179404`, 0.9366874291424127]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 206}], {
             RGBColor[
             0.20212300857950383`, 0.32977447572894675`, 0.9348219783731833]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 219}], {
             RGBColor[
             0.1830787781409705, 0.30975778206409804`, 0.9337374376231229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 83}], {
             RGBColor[
             0.8348006374064919, 0.5233895828676642, 0.45541678825261045`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 101}], {
             RGBColor[
             0.7293123816710212, 0.7884636426315792, 0.9736547004594159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 104}], {
             RGBColor[
             0.5731922784257398, 0.6585842020957557, 0.9621993062038972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 116}], {
             RGBColor[
             0.5493242790295518, 0.6359329023080253, 0.960750884061716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 142}], {
             RGBColor[
             0.8237226416206042, 0.438239252848624, 0.4448084869772376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 149}], {
             RGBColor[
             0.8534002738604769, 0.7354497327448786, 0.6081721446101185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 197}], {
             RGBColor[
             0.8988192263028636, 0.9205652040419037, 0.9289214218265444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 198}], {
             RGBColor[
             0.8879439008384149, 0.9128115493875727, 0.9633242059952494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 204}], {
             RGBColor[
             0.647452541380158, 0.7220822556308867, 0.967158350930859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 226}], {
             RGBColor[
             0.8987769385879059, 0.920547716985024, 0.9296222387004919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 243}], {
             RGBColor[
             0.8993571244293498, 0.920787638740557, 0.9200070578349391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 254}], {
             RGBColor[
             0.5650392887707011, 0.6515224922377361, 0.9616798049124837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 283}], {
             RGBColor[
             0.5585587587049552, 0.6456389259467026, 0.9612767740180419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 53}], {
             RGBColor[
             0.2073052253779457, 0.3352213141556316, 0.9351170979534518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 57}], {
             RGBColor[
             0.18920436008623348`, 0.3161961570728968, 0.9340862804529193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 84}], {
             RGBColor[
             0.1931004885069918, 0.32029123507192336`, 0.9343081592026761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 88}], {
             RGBColor[
             0.21079575741608964`, 0.3388900846402345, 0.9353158785892447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 93}], {
             RGBColor[
             0.21993156031517644`, 0.348492392730534, 0.9358361490491385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 124}], {
             RGBColor[
             0.1923287617954415, 0.3194801013677844, 0.9342642105081206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 137}], {
             RGBColor[
             0.23013360981142927`, 0.35921539359839394`, 0.9364171406753703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 147}], {
             RGBColor[
             0.20606540532151835`, 0.3339181846671946, 0.9350464920353876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 217}], {
             RGBColor[
             0.19938565089971289`, 0.32689733924898534`, 0.9346660899028769]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 247}], {
             RGBColor[
             0.1982447360653234, 0.3256981654198634, 0.9346011164908907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 270}], {
             RGBColor[
             0.20578610160522076`, 0.3336246187524874, 0.9350305861019373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 271}], {
             RGBColor[
             0.21068413741610115`, 0.3387727649431298, 0.9353095219953723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 273}], {
             RGBColor[
             0.2188316043007933, 0.34733626921817795`, 0.9357735081813584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 289}], {
             RGBColor[
             0.22108882372044908`, 0.3497087499442134, 0.9359020534880509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 295}], {
             RGBColor[
             0.19782793389837072`, 0.3252600799156124, 0.9345773802240863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 88}], {
             RGBColor[
             0.21936792560639845`, 0.34789997691510377`, 0.9358040508862964]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 93}], {
             RGBColor[
             0.22850372850548528`, 0.3575022850054033, 0.93632432134619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 107}], {
             RGBColor[
             0.3121763440598402, 0.43622685441542786`, 0.9414269663560839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 124}], {
             RGBColor[
             0.20090092998575032`, 0.32848999364265374`, 0.9347523828051723]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 137}], {
             RGBColor[
             0.2387057780017381, 0.36822528587326325`, 0.936905312972422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 147}], {
             RGBColor[
             0.21463757351182716`, 0.3429280769420639, 0.9355346643324394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 217}], {
             RGBColor[
             0.2079578190900217, 0.3359072315238546, 0.9351542621999286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 247}], {
             RGBColor[
             0.2068169042556322, 0.33470805769473266`, 0.9350892887879424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 251}], {
             RGBColor[
             0.25074234215186236`, 0.3808764779572891, 0.9375907774942707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 270}], {
             RGBColor[
             0.21435826979552958`, 0.3426345110273567, 0.935518758398989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 271}], {
             RGBColor[
             0.21925630560640996`, 0.3477826572179991, 0.935797694292424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 273}], {
             RGBColor[
             0.2274037724911021, 0.35634616149304726`, 0.9362616804784101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 289}], {
             RGBColor[
             0.22966099191075792`, 0.3587186422190827, 0.9363902257851027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 75}], {
             RGBColor[
             0.2884831291269512, 0.41830852004459096`, 0.9398219273882558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 102}], {
             RGBColor[
             0.218116116310074, 0.34658424597537324`, 0.9357327621987566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 111}], {
             RGBColor[
             0.4291203016109882, 0.5357529458181629, 0.9499902123364491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 143}], {
             RGBColor[
             0.2754657226956103, 0.40686231846163223`, 0.9389987374412732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 163}], {
             RGBColor[
             0.4325936369919836, 0.5385727559524309, 0.9502636460208878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 165}], {
             RGBColor[
             0.2309155676527057, 0.3600372808685661, 0.936461672017628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 172}], {
             RGBColor[
             0.21731047913351847`, 0.34573747022246615`, 0.935686882353385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 174}], {
             RGBColor[
             0.23862082785776215`, 0.3681359978857943, 0.936900475187395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 185}], {
             RGBColor[
             0.3867966632124244, 0.5013927095080272, 0.9466583404851183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 235}], {
             RGBColor[
             0.32626536687632174`, 0.4510335953926109, 0.9422293781681247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 238}], {
             RGBColor[
             0.21574020514797415`, 0.344087012702538, 0.9355974575729206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 298}], {
             RGBColor[
             0.25208733908179476`, 0.3822901550083788, 0.9376673730796856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 108}], {
             RGBColor[
             0.22141119699588285`, 0.35004758469634045`, 0.9359204121691784]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 114}], {
             RGBColor[
             0.22063449464495144`, 0.3492312212797382, 0.9358761801193209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 208}], {
             RGBColor[
             0.19572673330134732`, 0.32305158486432833`, 0.9344577199585336]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 219}], {
             RGBColor[
             0.19323553565117518`, 0.3204331781829436, 0.9343158499377529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 242}], {
             RGBColor[
             0.19150951150427703`, 0.318619017368302, 0.9342175554160109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 250}], {
             RGBColor[
             0.1923953966842939, 0.31955013886086425`, 0.9342680052664631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 252}], {
             RGBColor[
             0.22003960441036646`, 0.34860595392497, 0.9358423020005227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 268}], {
             RGBColor[
             0.20359322925377082`, 0.3313197708749761, 0.9349057052655861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 283}], {
             RGBColor[
             0.25397885208056453`, 0.38427825509893676`, 0.9377750919467229]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 57}], {
             RGBColor[
             0.18951617750640207`, 0.3165238969518603, 0.9341040379937053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 84}], {
             RGBColor[
             0.1934123059271604, 0.32061897495088687`, 0.9343259167434621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 110}], {
             RGBColor[
             0.1926369557700678, 0.31980403277574326`, 0.9342817616990433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 148}], {
             RGBColor[
             0.2228269723814797, 0.3515356543919468, 0.936001038482936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 191}], {
             RGBColor[
             0.21336670196225918`, 0.34159231036555776`, 0.9354622900777774]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 217}], {
             RGBColor[
             0.19969746831988144`, 0.32722507912794885`, 0.934683847443663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 223}], {
             RGBColor[
             0.19042353178656807`, 0.3174775838298989, 0.9341557104776503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 246}], {
             RGBColor[
             0.1919032518459413, 0.3190328634319706, 0.934239978345982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 247}], {
             RGBColor[
             0.19855655348549195`, 0.3260259052988269, 0.9346188740316768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 251}], {
             RGBColor[
             0.2424819913817221, 0.3721943255613833, 0.9371203627380049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 270}], {
             RGBColor[
             0.20609791902538932`, 0.3339523586314509, 0.9350483436427234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 271}], {
             RGBColor[
             0.21099595483626973`, 0.3391005048220933, 0.9353272795361584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 278}], {
             RGBColor[
             0.1999933373080916, 0.327536056193735, 0.9347006967448426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 295}], {
             RGBColor[
             0.19813975131853928`, 0.3255878197945759, 0.9345951377648724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.18357179140558838`, 0.31027597026405784`, 0.9337655139991952]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 217}], {
             RGBColor[
             0.18985695379830947`, 0.3168820744411198, 0.9341234446993961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 223}], {
             RGBColor[
             0.1805830172649961, 0.30713457914306985`, 0.9335953077333836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 247}], {
             RGBColor[
             0.18871603896391997`, 0.3156829006119979, 0.9340584712874099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 278}], {
             RGBColor[
             0.19015282278651957`, 0.31719305150690597`, 0.9341402940005757]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 295}], {
             RGBColor[
             0.1882992367969673, 0.3152448151077469, 0.9340347350206055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 134}], {
             RGBColor[
             0.21796998739019388`, 0.34643065521547056`, 0.9357244403729478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 160}], {
             RGBColor[
             0.19345266111115197`, 0.32066139080792844`, 0.9343282149114902]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 164}], {
             RGBColor[
             0.1865510290497441, 0.3134073379226422, 0.9339351771756428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 176}], {
             RGBColor[
             0.19266677740688082`, 0.31983537720683475`, 0.9342834599971428]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 180}], {
             RGBColor[
             0.1930127612329003, 0.32019902814462275`, 0.9343031632641974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 187}], {
             RGBColor[
             0.20794054512620663`, 0.3358890754926524, 0.9351532784732439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 215}], {
             RGBColor[
             0.20794131603506694`, 0.33588988576674306`, 0.935153322375363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 221}], {
             RGBColor[
             0.18866826221874242`, 0.3156326842235957, 0.9340557504724514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 230}], {
             RGBColor[
             0.19161321755920613`, 0.31872801900737613`, 0.9342234613224198]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[
             0.20819170713916685`, 0.33615306269286493`, 0.9351675817783212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 288}], {
             RGBColor[
             0.200003126765576, 0.32754634553423856`, 0.9347012542399642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 296}], {
             RGBColor[
             0.18917402722894824`, 0.3161642753166758, 0.9340845530415703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 297}], {
             RGBColor[
             0.19156703343003767`, 0.3186794765593771, 0.934220831204587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 72}], {
             RGBColor[
             0.8812795328447734, 0.4807598783541659, 0.416576044780737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 83}], {
             RGBColor[
             0.8927042858426667, 0.5685755362546596, 0.4275164011539326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 106}], {
             RGBColor[
             0.9234341463667425, 0.9403782883321993, 0.9424056010083017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 136}], {
             RGBColor[
             0.6888115905499252, 0.7512769242124885, 0.9221815319720392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 155}], {
             RGBColor[
             0.9556607617329471, 0.8668171290315656, 0.5788467809151635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[
             0.8355066141794747, 0.8713501588901851, 0.9337316266626792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 197}], {
             RGBColor[
             0.9856746989571257, 0.9883441341223966, 0.8870708411785275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 198}], {
             RGBColor[
             0.974799373492677, 0.9805904794680657, 0.9214736253472325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 210}], {
             RGBColor[
             0.7283433684413259, 0.785018817714684, 0.9248382115325371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 226}], {
             RGBColor[
             0.9856324112421679, 0.988326647065517, 0.887771658052475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 227}], {
             RGBColor[
             0.9688560866723765, 0.9191321953350291, 0.5894640490955131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 241}], {
             RGBColor[
             0.9855659463819599, 0.9882991621377519, 0.8888731527916648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 290}], {
             RGBColor[
             0.9657093115675036, 0.9066562806448499, 0.5869320799818273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 291}], {
             RGBColor[
             0.955941254786202, 0.9662985742039245, 0.945506158028788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 77}], {
             RGBColor[
             0.3505250523811867, 0.47604307306451876`, 0.9436288356859599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 95}], {
             RGBColor[
             0.28741190007160666`, 0.4194185083151971, 0.9396790545700505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 103}], {
             RGBColor[
             0.35429852491084235`, 0.47931146530946245`, 0.9438692780187988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 127}], {
             RGBColor[
             0.3180513290021859, 0.44791596605042294`, 0.941559638747636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 145}], {
             RGBColor[
             0.5760856373176906, 0.6571907606456139, 0.9633236613969889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 148}], {
             RGBColor[
             0.2667823322730826, 0.39773552456880407`, 0.9385042312026353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 159}], {
             RGBColor[
             0.28925410608148494`, 0.42135478363418655`, 0.9397839654770135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 168}], {
             RGBColor[
             0.3438394161380286, 0.4702523109805432, 0.9432028328564219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 196}], {
             RGBColor[
             0.24516356622564123`, 0.3750128307440074, 0.9372730744583317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 205}], {
             RGBColor[
             0.3298135622578278, 0.45810382130942706`, 0.9423091178497511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 212}], {
             RGBColor[
             0.2603180236560096, 0.39094112635142153`, 0.9381360983899805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 225}], {
             RGBColor[
             0.25743202099321577`, 0.38790775456968785`, 0.9379717448077927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 265}], {
             RGBColor[
             0.2549916258941355, 0.3853427445905684, 0.9378327679171411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 276}], {
             RGBColor[
             0.26432062956564295`, 0.39514811894231855`, 0.9383640408752093]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 282}], {
             RGBColor[
             0.36394977931359895`, 0.4876708967869795, 0.9444842474150733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 71}], {
             RGBColor[
             0.25028804221449197`, 0.3803989799188331, 0.9375649057849139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 108}], {
             RGBColor[
             0.25897235282054676`, 0.38952674098289125`, 0.9380594644266425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 136}], {
             RGBColor[
             0.33493736709593636`, 0.46161647957078045`, 0.9426694828062012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 161}], {
             RGBColor[
             0.23945694414961366`, 0.369014809121365, 0.9369480907732928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 177}], {
             RGBColor[
             0.2846154792944696, 0.4164792927751083, 0.9395198025437264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 194}], {
             RGBColor[
             0.4816323907254858, 0.581689714248477, 0.9542195774968412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 252}], {
             RGBColor[
             0.2576007602350303, 0.3880851102115208, 0.9379813542579867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 268}], {
             RGBColor[
             0.24115438507843467`, 0.37079892716152685`, 0.9370447575230503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 279}], {
             RGBColor[
             0.25696298277753227`, 0.387414765666264, 0.9379450337752894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 280}], {
             RGBColor[
             0.2696360759953822, 0.40073499015874336`, 0.9386667476858847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 117}], {
             RGBColor[
             0.1935934216908487, 0.32080933910192594`, 0.9343362310182673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 135}], {
             RGBColor[
             0.20737676424851148`, 0.33529650604442257`, 0.9351211719862982]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 158}], {
             RGBColor[
             0.1973113364505346, 0.3247171032437667, 0.9345479607636695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 186}], {
             RGBColor[
             0.19739650616034748`, 0.3248066220088515, 0.934552811052646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 196}], {
             RGBColor[
             0.2023683700722644, 0.33003236621465526`, 0.9348359513472162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 207}], {
             RGBColor[
             0.19348238664909873`, 0.3206926342330184, 0.9343299077369014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 212}], {
             RGBColor[
             0.2175228275026328, 0.34596066182206947`, 0.9356989752788649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 214}], {
             RGBColor[
             0.20125370240405008`, 0.3288607798213499, 0.9347724726725144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 225}], {
             RGBColor[
             0.21463682483983898`, 0.34292729004033573`, 0.9355346216966771]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 265}], {
             RGBColor[
             0.2121964297407587, 0.3403622800612163, 0.9353956448060256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 276}], {
             RGBColor[
             0.22152543341226616`, 0.3501676544129665, 0.9359269177640938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 286}], {
             RGBColor[
             0.21128388043674812`, 0.3394031328837336, 0.935343676473158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 71}], {
             RGBColor[
             0.20309975866494467`, 0.3308011019982774, 0.9348776028455769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 73}], {
             RGBColor[
             0.18277574146873998`, 0.309439271307949, 0.933720180132942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 152}], {
             RGBColor[
             0.18270109795627662`, 0.30936081624367795`, 0.9337159292953324]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 161}], {
             RGBColor[
             0.19226866060006637`, 0.3194169312008093, 0.9342607878339557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 208}], {
             RGBColor[
             0.1860996055764639, 0.3129328632303233, 0.9339094692766605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 244}], {
             RGBColor[
             0.18619322197801913`, 0.31303126000398057`, 0.9339148005922362]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 69}], {
             RGBColor[
             0.22143670136219934`, 0.3500743914024093, 0.9359218646051097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 76}], {
             RGBColor[
             0.28111114711231006`, 0.41111591460968555`, 0.939381752805837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 85}], {
             RGBColor[
             0.2337265149567007, 0.3629917647094177, 0.9366217513081667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 90}], {
             RGBColor[
             0.22549030939770529`, 0.3543349904613199, 0.936152711585956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 118}], {
             RGBColor[
             0.2120127678097534, 0.3401692397268907, 0.9353851855307582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 121}], {
             RGBColor[
             0.2303769927354159, 0.3594712044828725, 0.9364310009728385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 173}], {
             RGBColor[
             0.21829574180286104`, 0.34677304375720647`, 0.9357429916048386]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 213}], {
             RGBColor[
             0.21883980227157213`, 0.34734488580524786`, 0.9357739750436664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 234}], {
             RGBColor[
             0.2147298520602665, 0.3430250675472716, 0.9355399194592591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 239}], {
             RGBColor[
             0.23644031537818827`, 0.3658441410172859, 0.9367762982274624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 249}], {
             RGBColor[
             0.22138061658703678`, 0.35001544274773333`, 0.9359186706601341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 258}], {
             RGBColor[
             0.28773302970917036`, 0.41685145648958927`, 0.939803693309408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 263}], {
             RGBColor[
             0.22259690617654707`, 0.3512938402235227, 0.9359879365529176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 286}], {
             RGBColor[
             0.22809764059378232`, 0.35707546086274283`, 0.9363011952403719]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 70}], {
             RGBColor[
             0.2936166091660087, 0.41958665894484415`, 0.940265032379005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 106}], {
             RGBColor[
             0.6196619973862446, 0.6970249085872788, 0.9659794196694249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 115}], {
             RGBColor[
             0.3645960621661024, 0.4902165167425332, 0.9444527165749532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 138}], {
             RGBColor[
             0.30437559706733064`, 0.4308950373883661, 0.9408777408234891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 155}], {
             RGBColor[
             0.6518886127524492, 0.6234637492866453, 0.6024205995762867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 194}], {
             RGBColor[
             0.5317344651989768, 0.6279967791452647, 0.9573054453238024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 200}], {
             RGBColor[
             0.37151685139917806`, 0.49621095652724223`, 0.9448937031450712]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[
             0.424571219460828, 0.5416654379697635, 0.9484120301936603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 211}], {
             RGBColor[
             0.3240980577045407, 0.45162459399430244`, 0.9420009057800123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 231}], {
             RGBColor[
             0.30432205873480145`, 0.4308387652063516, 0.9408746918946544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 241}], {
             RGBColor[
             0.6817937974014621, 0.7449457823928316, 0.912446971452788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 264}], {
             RGBColor[
             0.33683666992223255`, 0.4650136831097602, 0.942726350900722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 291}], {
             RGBColor[
             0.6521691058057041, 0.7229451944590042, 0.9690799766899112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 86}], {
             RGBColor[
             0.49025940765542825`, 0.5952351366581299, 0.9535166371045274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 97}], {
             RGBColor[
             0.4175999543798127, 0.5361258241249656, 0.9478300777173092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 162}], {
             RGBColor[
             0.6888450125107997, 0.7498709206605213, 0.8694416515926326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 169}], {
             RGBColor[
             0.4955403552880472, 0.5995224478502696, 0.9539323726469158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 187}], {
             RGBColor[
             0.305540960778381, 0.4312990434818653, 0.9409741624536079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 193}], {
             RGBColor[
             0.33295274750258996`, 0.46011056933666983`, 0.9425352231554471]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 215}], {
             RGBColor[
             0.3055417316872413, 0.4312998537559559, 0.940974206355727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 228}], {
             RGBColor[
             0.40629940527691566`, 0.5263378564741489, 0.9471100167211559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 118}], {
             RGBColor[
             0.18382399790050605`, 0.31054105528103165`, 0.9337798767859746]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 166}], {
             RGBColor[
             0.1825106958270533, 0.309160691533672, 0.9337050861757479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 173}], {
             RGBColor[
             0.1901069718936137, 0.3171448593113474, 0.934137682860055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 195}], {
             RGBColor[
             0.18132553855698572`, 0.30791501609952, 0.9336375932225005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 213}], {
             RGBColor[
             0.19065103236232478`, 0.3177167013593888, 0.9341686662988828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 234}], {
             RGBColor[
             0.18654108215101917`, 0.31339688310141245`, 0.9339346107144755]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 263}], {
             RGBColor[
             0.19440813626729972`, 0.3216656557776636, 0.934382627808134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 75}], {
             RGBColor[
             0.6048929892039929, 0.6837170469414527, 0.9652757515328931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 83}], {
             RGBColor[
             0.8566539261889098, 0.5407679915618476, 0.4575135965364173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 109}], {
             RGBColor[
             0.9348338843673183, 0.947970458954174, 0.8784588716115629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 111}], {
             RGBColor[
             0.7455301616880299, 0.8011614727150247, 0.9754440364810864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 143}], {
             RGBColor[
             0.5918755827726521, 0.672270845358494, 0.9644525615859105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 163}], {
             RGBColor[
             0.7490034970690254, 0.8039812828492927, 0.9757174701655251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 185}], {
             RGBColor[
             0.7032065232894661, 0.766801236404889, 0.9721121646297556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 218}], {
             RGBColor[
             0.9220230883129681, 0.9398481441591451, 0.964270119789284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 235}], {
             RGBColor[
             0.6426752269533634, 0.7164421222894727, 0.967683202312762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 292}], {
             RGBColor[
             0.8252860920096456, 0.8638987146846454, 0.9830984780135097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 76}], {
             RGBColor[
             0.2672433086560147, 0.39653993712037666`, 0.9385919999213795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 85}], {
             RGBColor[
             0.21985867650040533`, 0.3484157872201088, 0.9358319984237091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 90}], {
             RGBColor[
             0.21162247094140993`, 0.33975901297201105`, 0.9353629587014987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 118}], {
             RGBColor[
             0.19814492935345804`, 0.3255932622375819, 0.9345954326463008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 121}], {
             RGBColor[
             0.21650915427912054`, 0.3448952269935637, 0.9356412480883811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 126}], {
             RGBColor[
             0.21552861209731056`, 0.34386461499051624`, 0.9355854076617092]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 166}], {
             RGBColor[
             0.19683162728000528`, 0.3242128984902222, 0.9345206420360739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 173}], {
             RGBColor[
             0.2044279033465657, 0.3321970662678976, 0.9349532387203812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 195}], {
             RGBColor[
             0.1956464700099377, 0.32296722305607023`, 0.9344531490828267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 213}], {
             RGBColor[
             0.20497196381527677`, 0.33276890831593897`, 0.934984222159209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 234}], {
             RGBColor[
             0.20086201360397116`, 0.32844909005796263`, 0.9347501665748015]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 239}], {
             RGBColor[
             0.22257247692189291`, 0.35126816352797696`, 0.935986545343005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 249}], {
             RGBColor[
             0.20751277813074143`, 0.3354394652584245, 0.9351289177756767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 258}], {
             RGBColor[
             0.273865191252875, 0.4022754790002804, 0.9390139404249507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 263}], {
             RGBColor[
             0.2087290677202517, 0.3367178627342138, 0.9351981836684602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 285}], {
             RGBColor[
             0.2036242652013759, 0.3313523916237017, 0.9349074727168887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 122}], {
             RGBColor[
             0.19740509453050553`, 0.32481564893042175`, 0.9345533001476212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 138}], {
             RGBColor[
             0.22052881830414905`, 0.3491201487452879, 0.9358701620080464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 211}], {
             RGBColor[
             0.24025127894135917`, 0.3698497053512242, 0.9369933269645696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 231}], {
             RGBColor[
             0.2204752799716199, 0.3490638765632734, 0.9358671130792118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 266}], {
             RGBColor[
             0.20395979058864, 0.33170505007925455`, 0.934926580391328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 108}], {
             RGBColor[
             0.23200115605283045`, 0.3611783031073773, 0.936523494671031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 136}], {
             RGBColor[
             0.3079661703282201, 0.43326804169526645`, 0.9411335130505898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 161}], {
             RGBColor[
             0.2124857473818974, 0.34066637124585103`, 0.9354121210176813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 177}], {
             RGBColor[
             0.2576442825267533, 0.3881308548995943, 0.9379838327881149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 208}], {
             RGBColor[
             0.20631669235829492`, 0.33418230327536513`, 0.9350608024603861]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 244}], {
             RGBColor[
             0.20641030875985014`, 0.33428070004902233`, 0.9350661337759618]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 252}], {
             RGBColor[
             0.23062956346731406`, 0.3597366723360068, 0.9364453845023752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 268}], {
             RGBColor[
             0.21418318831071842`, 0.34245048928601285`, 0.9355087877674388]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 279}], {
             RGBColor[
             0.22999178600981598`, 0.35906632779075, 0.9364090640196779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 280}], {
             RGBColor[
             0.2426648792276659, 0.37238655228322937`, 0.9371307779302732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 83}], {
             RGBColor[
             0.8351278328210138, 0.271013492942614, 0.1812717584216026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 87}], {
             RGBColor[
             0.8839929875554634, 0.4806546749192594, 0.28239629153508916`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 106}], {
             RGBColor[
             0.8402305064958111, 0.44896653252378993`, 0.44609646287147053`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 109}], {
             RGBColor[
             0.8838806914832852, 0.4818355242979183, 0.3734681145578266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 155}], {
             RGBColor[
             0.8617149167399476, 0.39992575965670085`, 0.20372391614271176`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 194}], {
             RGBColor[
             0.7816121517042992, 0.4029477795624471, 0.4403138133077221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 210}], {
             RGBColor[
             0.7101699878788666, 0.345393552112113, 0.4343848698876275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 218}], {
             RGBColor[
             0.875340160780385, 0.47642064776789905`, 0.430675613342974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 226}], {
             RGBColor[
             0.8816960164127614, 0.48093210501266836`, 0.40967383423425274`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 227}], {
             RGBColor[
             0.8705118000329004, 0.43480247052567644`, 0.21080209492961144`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 241}], {
             RGBColor[
             0.8816517065059561, 0.48091378172749166`, 0.4104081640603793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 290}], {
             RGBColor[
             0.8684139499629852, 0.42648519406555707`, 0.2091141155204876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 291}], {
             RGBColor[
             0.8619019121087841, 0.4662467231049401, 0.44816350088512813`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 100}], {
             RGBColor[
             0.1816658245926822, 0.30827267829841776`, 0.9336569720088254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 119}], {
             RGBColor[
             0.18176019735719462`, 0.3083718700574992, 0.9336623463981524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 122}], {
             RGBColor[
             0.18385458485627515`, 0.31057320411086997`, 0.9337816186678564]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 161}], {
             RGBColor[
             0.19216173018569271`, 0.31930454055552265`, 0.9342546983050465]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 244}], {
             RGBColor[
             0.18608629156364545`, 0.31291886935869395`, 0.9339087110633268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 123}], {
             RGBColor[
             0.20225228122772315`, 0.32991034947858455`, 0.9348293402592576]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 189}], {
             RGBColor[
             0.21086862151855923`, 0.33896666943178094`, 0.9353200280920875]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 257}], {
             RGBColor[
             0.19498858899920085`, 0.3222757484017205, 0.9344156837325129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 260}], {
             RGBColor[
             0.23203447362151203`, 0.3612133219845175, 0.9365253920572785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 267}], {
             RGBColor[
             0.2010537316252639, 0.328650597853966, 0.9347610846324927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 287}], {
             RGBColor[
             0.2244511741859948, 0.35324279346883447`, 0.936093534372912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 300}], {
             RGBColor[
             0.2157736566163444, 0.3441221723167407, 0.9355993625845572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 111}], {
             RGBColor[
             0.4735665439631073, 0.5802328466571501, 0.952603227994324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 143}], {
             RGBColor[
             0.31991196504772945`, 0.4513422193006194, 0.941611753099148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.47703987934410275`, 0.583052656791418, 0.9528766616787626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 165}], {
             RGBColor[
             0.27536181000482485`, 0.4045171817075533, 0.9390746876755028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 185}], {
             RGBColor[
             0.43124290556454353`, 0.5458726103470143, 0.9492713561429931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 235}], {
             RGBColor[
             0.3707116092284409, 0.495513496231598, 0.9448423938259995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 262}], {
             RGBColor[
             0.318384602518598, 0.4497368644421247, 0.9415247720626443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 292}], {
             RGBColor[
             0.5533224742847231, 0.6429700886267707, 0.9602576695267473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 85}], {
             RGBColor[
             0.2795331222505161, 0.40945731042738504`, 0.9392918866244364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 87}], {
             RGBColor[
             0.6600329022141906, 0.7226670785503484, 0.7188188011286823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 90}], {
             RGBColor[
             0.2712969166915207, 0.40080053617928724`, 0.938822846902226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 126}], {
             RGBColor[
             0.2752030578474213, 0.40490613819779253`, 0.9390452958624365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 151}], {
             RGBColor[
             0.46237290629163863`, 0.5709821178298984, 0.9517671246297987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 153}], {
             RGBColor[
             0.27399346070364045`, 0.40363477490679034`, 0.9389764110945367]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 192}], {
             RGBColor[
             0.32876752436481727`, 0.45918363809373036`, 0.9421697538281874]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 220}], {
             RGBColor[
             0.3300035970754238, 0.4602542621488369, 0.942248515288291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 239}], {
             RGBColor[
             0.28224692267200363`, 0.41230968673525326`, 0.9394464335437323]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 248}], {
             RGBColor[
             0.2744382407386017, 0.40410226692421763`, 0.9390017406595347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 258}], {
             RGBColor[
             0.3335396370029857, 0.4633170022075566, 0.942473828625678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 82}], {
             RGBColor[
             0.5136111712070213, 0.6149382362843397, 0.9551491039925967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 95}], {
             RGBColor[
             0.3506695406416134, 0.476194939387312, 0.94363706407864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 103}], {
             RGBColor[
             0.41755616548084906`, 0.5360878963815774, 0.9478272875273883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 127}], {
             RGBColor[
             0.3813089695721926, 0.5046923971225378, 0.9455176482562255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 145}], {
             RGBColor[
             0.6393432778876973, 0.7139671917177287, 0.9672816709055783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 154}], {
             RGBColor[
             0.455540153481848, 0.5677935680255081, 0.950577540756124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 159}], {
             RGBColor[
             0.3525117466514917, 0.4781312147063014, 0.9437419749856031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 167}], {
             RGBColor[
             0.6607323580564698, 0.6022582598273698, 0.5960819189651536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 168}], {
             RGBColor[
             0.4070970567080353, 0.527028742052658, 0.9471608423650113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 203}], {
             RGBColor[
             0.6754538924070363, 0.7427240405564789, 0.9694509218275109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 205}], {
             RGBColor[
             0.3930712028278346, 0.5148802523815419, 0.9462671273583405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 212}], {
             RGBColor[
             0.32357566422601636`, 0.4477175574235364, 0.9420941078985701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 225}], {
             RGBColor[
             0.32068966156322254`, 0.4446841856418027, 0.9419297543163823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 255}], {
             RGBColor[
             0.38990028243638014`, 0.512133760513557, 0.9460650791149319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 265}], {
             RGBColor[
             0.31824926646414226`, 0.4421191756626833, 0.9417907774257306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 269}], {
             RGBColor[
             0.6934737954253698, 0.7269802724747518, 0.6489189851142219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 276}], {
             RGBColor[
             0.3275782701356497, 0.45192455001443343`, 0.9423220503837988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 282}], {
             RGBColor[
             0.42720741988360567`, 0.5444473278590943, 0.9484422569236628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 293}], {
             RGBColor[
             0.6567707297143, 0.585264649646495, 0.5928277208084357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 99}], {
             RGBColor[
             0.19490280134245708`, 0.32218558013523124`, 0.9344107982523728]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 131}], {
             RGBColor[
             0.21176961520445978`, 0.33991367092196156`, 0.9353713383495988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 170}], {
             RGBColor[
             0.19585393495458225`, 0.32318528186692885`, 0.9344649639045073]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 178}], {
             RGBColor[
             0.2265713684695162, 0.3554712520888972, 0.9362142763008121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 182}], {
             RGBColor[
             0.22423750678067705`, 0.3530182154785495, 0.9360813663302717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 190}], {
             RGBColor[
             0.19927294772660503`, 0.32677888106825503`, 0.9346596716238978]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.19626308316666907`, 0.323615322579327, 0.9344882642899051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 209}], {
             RGBColor[
             0.18729352981200414`, 0.31418775330104487`, 0.933977461495622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 229}], {
             RGBColor[
             0.20592187570768378`, 0.3337673259427514, 0.9350383182362128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 261}], {
             RGBColor[
             0.21943392399577888`, 0.3479693454068822, 0.9358078093969358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 284}], {
             RGBColor[
             0.2175445595822431, 0.34598350361563335`, 0.935700212888649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 144}], {
             RGBColor[
             0.1903903758627761, 0.31744273485178653`, 0.9341538222968402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 160}], {
             RGBColor[
             0.1894526235362595, 0.316457097699686, 0.9341004186891254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 176}], {
             RGBColor[
             0.18866673983198834`, 0.31563108409859225`, 0.9340556637747779]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 221}], {
             RGBColor[
             0.18466822464384994`, 0.3114283911153532, 0.9338279542500865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 232}], {
             RGBColor[
             0.1855242988552152, 0.31232817938973806`, 0.9338767064099756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 240}], {
             RGBColor[
             0.18183565807480434`, 0.3084511840561929, 0.9336666437743861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 245}], {
             RGBColor[
             0.20419166956427437`, 0.3319487695846225, 0.9349397855559562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 288}], {
             RGBColor[
             0.19600308919068352`, 0.3233420524259961, 0.9344734580175993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 297}], {
             RGBColor[
             0.1875669958551452, 0.3144751834511347, 0.9339930349822221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 92}], {
             RGBColor[
             0.8806392624507501, 0.47575847385330106`, 0.24262510747050564`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 125}], {
             RGBColor[
             0.8830657841456923, 0.4944097829092139, 0.2449487473859466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 128}], {
             RGBColor[
             0.889562972527344, 0.5443500198966912, 0.25117046231774093`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 145}], {
             RGBColor[
             0.9218561356347152, 0.9176464031707863, 0.6795757972164687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 149}], {
             RGBColor[
             0.9371561077922606, 0.7792834728078644, 0.30334662593416606`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 150}], {
             RGBColor[
             0.9431089113179686, 0.8053970694161215, 0.30826637148751795`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 156}], {
             RGBColor[
             0.6866499660786538, 0.7281441949934098, 0.6592663633827371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 167}], {
             RGBColor[
             0.9432452158034876, 0.8059374712804274, 0.30837604527604406`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 179}], {
             RGBColor[
             0.7507825863487789, 0.7818072220217351, 0.663873785850424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 201}], {
             RGBColor[
             0.8898455310710746, 0.5465218886817487, 0.2514410406983216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 205}], {
             RGBColor[
             0.6755840605748524, 0.7185594638345996, 0.6585612536692309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 237}], {
             RGBColor[
             0.8763192452000071, 0.442552928220461, 0.2384882540724326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 256}], {
             RGBColor[
             0.8715548723467077, 0.4059318707085048, 0.23392588524752353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 269}], {
             RGBColor[
             0.9759866531723878, 0.9306594839278095, 0.36121311142511225`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 277}], {
             RGBColor[
             0.9859097978901593, 0.963818944183442, 0.4264320765360633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 281}], {
             RGBColor[
             0.9786349916305042, 0.9618175926615335, 0.6467591064594813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 282}], {
             RGBColor[
             0.7097202776306235, 0.7481265393121519, 0.6607363832345532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 293}], {
             RGBColor[
             0.9392835874613179, 0.7889438610995526, 0.30512184711932616`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 86}], {
             RGBColor[
             0.7418209808035544, 0.6361932312179576, 0.5953370394744854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 94}], {
             RGBColor[
             0.8431768541892217, 0.7161112955984645, 0.6049346124449686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 97}], {
             RGBColor[
             0.6691615275279388, 0.5770839186847934, 0.5896504800872672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.9006340382989853, 0.6395018820094367, 0.23868605563289352`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 140}], {
             RGBColor[
             0.8413676314488565, 0.2864072420017145, 0.18597171239681876`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 162}], {
             RGBColor[
             0.9404065856589258, 0.790829015220349, 0.5112620539625906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 167}], {
             RGBColor[
             0.8985734587541578, 0.6313323707616247, 0.23702806496310708`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 181}], {
             RGBColor[
             0.9378794291938042, 0.7781980948822975, 0.31536710248397326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 201}], {
             RGBColor[
             0.8600643597048547, 0.4301184883358802, 0.203875720489697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 202}], {
             RGBColor[
             0.8742021218716074, 0.5216630409074182, 0.2167435057125596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 203}], {
             RGBColor[
             0.9132949931047244, 0.7717981514907339, 0.6103970678254644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 216}], {
             RGBColor[
             0.8741307766845507, 0.521339079076086, 0.216683973539649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 237}], {
             RGBColor[
             0.8465380738337873, 0.3261495278745926, 0.19092293386380793`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 269}], {
             RGBColor[
             0.931314896123058, 0.7560543834090069, 0.28986513111217527`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 293}], {
             RGBColor[
             0.8946118304119881, 0.61433876058075, 0.23377386680638917`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 299}], {
             RGBColor[
             0.8422842306382159, 0.2934526250274564, 0.1868494488157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 103}], {
             RGBColor[
             0.5173846437366769, 0.6182066285292835, 0.9553895463254356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 140}], {
             RGBColor[
             0.7493592164876164, 0.32177032281068196`, 0.43038245426354804`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 145}], {
             RGBColor[
             0.7391717561435251, 0.7960859238654349, 0.9748439297036255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 154}], {
             RGBColor[
             0.5553686317376758, 0.6499123001732142, 0.9581397995541713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 167}], {
             RGBColor[
             0.7605608363122977, 0.684376991975076, 0.6036441777632009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 168}], {
             RGBColor[
             0.5069255349638632, 0.6091474742003642, 0.9547231011630586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 181}], {
             RGBColor[
             0.7998668067519439, 0.8312427160957487, 0.681983215284067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 201}], {
             RGBColor[
             0.7680559447436146, 0.4654815691448476, 0.44828646235642633`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 203}], {
             RGBColor[
             0.7752823706628642, 0.824842772704185, 0.9770131806255582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 216}], {
             RGBColor[
             0.7821223617233105, 0.5567021598850534, 0.46109471540637825`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 255}], {
             RGBColor[
             0.489728760692208, 0.5942524926612631, 0.9536273379129792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 258}], {
             RGBColor[
             0.47680058453134755`, 0.5830547562597531, 0.9528035659599465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 293}], {
             RGBColor[
             0.7565992079701278, 0.6673833817942012, 0.600389979606483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 101}], {
             RGBColor[
             0.7801443981327315, 0.4806917133441988, 0.4499691651133977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 142}], {
             RGBColor[
             0.8410135879259631, 0.3162539858335876, 0.18690796415711172`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 149}], {
             RGBColor[
             0.8628696595923687, 0.44534910675306505`, 0.20631412788053274`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 194}], {
             RGBColor[
             0.7930369047021925, 0.4907634374629408, 0.4512541696809177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[
             0.8931489612206265, 0.5687594209510818, 0.42014697935815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 198}], {
             RGBColor[
             0.8858987442443274, 0.5635903178481945, 0.44308216880395335`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 226}], {
             RGBColor[
             0.8931207694106547, 0.5687477629131621, 0.4206141906074483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 241}], {
             RGBColor[
             0.8930764595038494, 0.5687294396279854, 0.42134852043357485`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 243}], {
             RGBColor[
             0.8935075599716172, 0.5689077107501841, 0.41420407003041315`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 290}], {
             RGBColor[
             0.8798387029608784, 0.5143008519660508, 0.22005447189368316`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 291}], {
             RGBColor[
             0.8733266651066773, 0.5540623810054337, 0.4591038572583237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 191}], {
             RGBColor[
             0.2074223158614455, 0.3353443836777553, 0.9351237660832672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 217}], {
             RGBColor[
             0.19375308221906778`, 0.32097715244014635`, 0.9343453234491528]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 223}], {
             RGBColor[
             0.1844791456857544, 0.31122965714209644`, 0.9338171864831403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 246}], {
             RGBColor[
             0.1859588657451276, 0.3127849367441682, 0.9339014543514719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 247}], {
             RGBColor[
             0.1926121673846783, 0.3197779786110244, 0.9342803500371666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 270}], {
             RGBColor[
             0.20015353292457566`, 0.32770443194364846`, 0.9347098196482133]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 271}], {
             RGBColor[
             0.20505156873545605`, 0.33285257813429087`, 0.9349887555416483]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 278}], {
             RGBColor[
             0.19404895120727791`, 0.32128812950593255`, 0.9343621727503324]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 295}], {
             RGBColor[
             0.19219536521772562`, 0.31933989310677346`, 0.9342566137703623]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[
             0.22879896787362192`, 0.35781260030057205`, 0.936341134791438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 135}], {
             RGBColor[
             0.22261249954375167`, 0.3513102298411313, 0.9359888245721116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 154}], {
             RGBColor[
             0.36472305205370464`, 0.48205039622074985`, 0.9450500607222323]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 173}], {
             RGBColor[
             0.21671771694106706`, 0.34511443957490595`, 0.9356531254234381]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 213}], {
             RGBColor[
             0.21726177740977812`, 0.34568628162294734`, 0.9356841088622658]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 234}], {
             RGBColor[
             0.21315182719847248`, 0.341366463364971, 0.9354500532778585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 239}], {
             RGBColor[
             0.2348622905163943, 0.36418553683498534`, 0.936686432046062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 249}], {
             RGBColor[
             0.21980259172524277`, 0.34835683856543287`, 0.9358288044787336]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 255}], {
             RGBColor[
             0.2990831810082368, 0.42639058870879876`, 0.9405375990810403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 258}], {
             RGBColor[
             0.2861550048473763, 0.41519285230728875`, 0.9397138271280076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 263}], {
             RGBColor[
             0.22101888131475306`, 0.34963523604122215`, 0.9358980703715171]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 286}], {
             RGBColor[
             0.2265196157319883, 0.3554168566804423, 0.9362113290589713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[
             0.6955329406462065, 0.7613368008112785, 0.9707925147289977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 97}], {
             RGBColor[
             0.5215176139849236, 0.6223094238976072, 0.9555083823712963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 120}], {
             RGBColor[
             0.4366336879326583, 0.5460453622474791, 0.9502000470026102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 130}], {
             RGBColor[
             0.75299012475597, 0.6847273872222507, 0.6045439579169226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 140}], {
             RGBColor[
             0.7429383557535131, 0.3165575788102572, 0.4298769805861715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 162}], {
             RGBColor[
             0.7927626721159106, 0.8360545204331631, 0.8771199562466196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 169}], {
             RGBColor[
             0.5994580148931581, 0.6857060476229113, 0.9616106773009028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[
             0.4265942001520806, 0.5354932240498018, 0.9496283130255976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 182}], {
             RGBColor[
             0.4242603384632414, 0.5330401874394541, 0.9494954030550571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 202}], {
             RGBColor[
             0.7757728461762639, 0.551813377715961, 0.4606487739019124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 261}], {
             RGBColor[
             0.41945675567834323`, 0.5279913173677868, 0.949221846121721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 284}], {
             RGBColor[
             0.41756739126480746`, 0.526005475576538, 0.9491142496134344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 109}], {
             RGBColor[
             0.9929796059139886, 0.9895239708410322, 0.632193448669364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 140}], {
             RGBColor[
             0.8759286833407519, 0.418668898924348, 0.2746739047117526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 151}], {
             RGBColor[
             0.7954880540997038, 0.8360677360525939, 0.7285340376363743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[
             0.7452228320173793, 0.7952601643437132, 0.7245769752264782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 155}], {
             RGBColor[
             0.959730943798982, 0.866659323879206, 0.37757715104669176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 162}], {
             RGBColor[
             0.9922481634967688, 0.9892215006042993, 0.6443153424349913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 181}], {
             RGBColor[
             0.9897210070316473, 0.9765905802662477, 0.448420390956374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 202}], {
             RGBColor[
             0.9087631737635028, 0.6539246978300517, 0.30544569802749344`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 203}], {
             RGBColor[
             0.9651365709425674, 0.970190636874684, 0.7434503562978652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 216}], {
             RGBColor[
             0.9086918285764461, 0.6536007359987195, 0.30538616585458284`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 227}], {
             RGBColor[
             0.9729262687384115, 0.9189743901826695, 0.3881944192270413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 258}], {
             RGBColor[
             0.6666547848110509, 0.7284026204302521, 0.7192407416322534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 299}], {
             RGBColor[
             0.8768452825301113, 0.42571428195008987`, 0.27555164113063385`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 93}], {
             RGBColor[
             0.23199426054362918`, 0.36117105549000617`, 0.9365231019819831]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 107}], {
             RGBColor[
             0.3156668760979841, 0.43989562490003076`, 0.9416257469918767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 124}], {
             RGBColor[
             0.20439146202389424`, 0.3321587641272566, 0.9349511634409652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 137}], {
             RGBColor[
             0.242196310039882, 0.3718940563578661, 0.9371040936082149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 147}], {
             RGBColor[
             0.21812810554997109`, 0.34659684742666674`, 0.9357334449682322]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 273}], {
             RGBColor[
             0.23089430452924603`, 0.3600149319776501, 0.936460461114203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 274}], {
             RGBColor[
             0.342952508633553, 0.4632649151839602, 0.9434373496862328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 289}], {
             RGBColor[
             0.23315152394890182`, 0.3623874127036856, 0.9365890064208955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 94}], {
             RGBColor[
             0.5888165791799138, 0.6727291061533267, 0.962935879267211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 120}], {
             RGBColor[
             0.3299173264663655, 0.4574376675895273, 0.9423434115408236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 131}], {
             RGBColor[
             0.3050760854207314, 0.4313279482249144, 0.9409287396125976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 141}], {
             RGBColor[
             0.33729605784908523`, 0.4651931821113565, 0.9427636193772146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 188}], {
             RGBColor[
             0.3683043792841372, 0.49342847464473716`, 0.9446890072625783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 236}], {
             RGBColor[
             0.30608763983959875`, 0.4323911560553985, 0.9409863461402914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 260}], {
             RGBColor[
             0.3194559514168667, 0.4464420991230162, 0.9417476517079721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 281}], {
             RGBColor[
             0.6796029595718664, 0.743830302697593, 0.9334123929687868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 294}], {
             RGBColor[
             0.4583968818459615, 0.569215720181254, 0.9510502956112238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 118}], {
             RGBColor[
             0.20219853738896398`, 0.32985386129649247`, 0.9348262796271471]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 126}], {
             RGBColor[
             0.2195822201328165, 0.34812521404942687`, 0.9358162546425555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 153}], {
             RGBColor[
             0.21837262298903565`, 0.3468538507584247, 0.9357473698746558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.20088523531551122`, 0.3284734975491328, 0.9347514890169203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 195}], {
             RGBColor[
             0.19970007804544365`, 0.3272278221149808, 0.934683996063673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 222}], {
             RGBColor[
             0.2185508250169386, 0.3470411523884118, 0.9357575182165185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 234}], {
             RGBColor[
             0.20491562163947707`, 0.33270968911687326`, 0.9349810135556479]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 239}], {
             RGBColor[
             0.2266260849573989, 0.3555287625868876, 0.9362173923238513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 248}], {
             RGBColor[
             0.21881740302399694`, 0.347321342775852, 0.9357726994396538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 285}], {
             RGBColor[
             0.20767787323688183`, 0.3356129906826123, 0.9351383196977351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 93}], {
             RGBColor[
             0.3656444287828603, 0.48387268995411137`, 0.9450248073537576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 105}], {
             RGBColor[
             0.38699951220692347`, 0.5063182366232937, 0.9462409477627431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 107}], {
             RGBColor[
             0.44931704433721525`, 0.562597259364136, 0.9501274523636514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 139}], {
             RGBColor[
             0.4654409733450266, 0.5765629962584664, 0.9511548548621985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 142}], {
             RGBColor[
             0.7166766594677184, 0.35305977598567057`, 0.4352018560097054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 143}], {
             RGBColor[
             0.39852667636969663`, 0.5184340170227889, 0.9468974027089019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 150}], {
             RGBColor[
             0.6987841041568563, 0.6337941140587057, 0.5986819437121721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 163}], {
             RGBColor[
             0.5556545906660699, 0.6501444545135875, 0.9581623112885165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 179}], {
             RGBColor[
             0.5064577791876668, 0.6102042666643193, 0.9542893580750782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 235}], {
             RGBColor[
             0.44932632055040805`, 0.5626052939537676, 0.9501280434357534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 273}], {
             RGBColor[
             0.3645444727684772, 0.4827165664417553, 0.9449621664859775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 274}], {
             RGBColor[
             0.4766026768727841, 0.5859665496480654, 0.9519390550580074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 298}], {
             RGBColor[
             0.3751482927558811, 0.4938618535695355, 0.9455660383473143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 125}], {
             RGBColor[
             0.8327679503009816, 0.2528744017865336, 0.1790119322553138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 128}], {
             RGBColor[
             0.8360165444918075, 0.27784452028027223`, 0.18212278972121096`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 142}], {
             RGBColor[
             0.8310149903490321, 0.23940038344390055`, 0.17733329582564183`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 149}], {
             RGBColor[
             0.8528710620154377, 0.368495504363378, 0.19673945954906286`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 150}], {
             RGBColor[
             0.856839597699243, 0.38590456876888285`, 0.2000192899179641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 179}], {
             RGBColor[
             0.7286220477197832, 0.3701780038392919, 0.4370908994932349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 237}], {
             RGBColor[
             0.829394680828139, 0.22694597444215714`, 0.1757816855985568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 243}], {
             RGBColor[
             0.8835089623946862, 0.49205410836049707`, 0.4046294016989433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 256}], {
             RGBColor[
             0.8270124944014894, 0.208635445686179, 0.17350050118610227`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 269}], {
             RGBColor[
             0.8787580922688558, 0.4694128451100082, 0.23531711654302695`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 277}], {
             RGBColor[
             0.8853735220807035, 0.49151915194709656`, 0.27879642661699433`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 281}], {
             RGBColor[
             0.8805236512409333, 0.4901849175991575, 0.4256811132326063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 105}], {
             RGBColor[
             0.26248514686677915`, 0.39321891024948796`, 0.9382595128508624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 107}], {
             RGBColor[
             0.32480267899707094`, 0.44949793299033025`, 0.9421460174517705]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 137}], {
             RGBColor[
             0.25133211293896884`, 0.38149636444816565`, 0.9376243640681086]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 139}], {
             RGBColor[
             0.3409266080048823, 0.4634636698846607, 0.9431734199503177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 147}], {
             RGBColor[
             0.22726390844905786`, 0.3561991555169663, 0.936253715428126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 273}], {
             RGBColor[
             0.24003010742833283`, 0.36961724006794966`, 0.9369807315740968]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 274}], {
             RGBColor[
             0.3520883115326398, 0.4728672232742597, 0.9439576201461266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 289}], {
             RGBColor[
             0.24228732684798865`, 0.37198972079398507`, 0.9371092768807893]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 97}], {
             RGBColor[
             0.622873487370591, 0.7022274882781143, 0.9651059553417796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 120}], {
             RGBColor[
             0.5379895613183256, 0.6259634266279861, 0.9597976199730934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 130}], {
             RGBColor[
             0.8543459981416374, 0.7646454516027577, 0.6141415308874059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 141}], {
             RGBColor[
             0.5453682927010454, 0.6337189411498153, 0.9602178278094844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 188}], {
             RGBColor[
             0.5763766141360973, 0.661954233683196, 0.9621432156948482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 201}], {
             RGBColor[
             0.8292056662666228, 0.5135475347314276, 0.45417937065937186`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 202}], {
             RGBColor[
             0.8433434284333755, 0.6050920873029656, 0.46704715588223444`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.8156793803955554, 0.4095785742701399, 0.4412265840334828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 281}], {
             RGBColor[
             0.8876751944238266, 0.9123560617360518, 0.9508666014010566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 293}], {
             RGBColor[
             0.8483237902546403, 0.739482330174071, 0.6092293420609014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 294}], {
             RGBColor[
             0.6664691166979216, 0.7377414792197128, 0.9685045040434936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 103}], {
             RGBColor[
             0.35444301317126903`, 0.47946333163225574`, 0.9438775064114789]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 127}], {
             RGBColor[
             0.3181958172626126, 0.4480678323732162, 0.9415678671403162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 145}], {
             RGBColor[
             0.5762301255781173, 0.6573426269684071, 0.963331889789669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 148}], {
             RGBColor[
             0.2669268205335093, 0.3978873908915973, 0.9385124595953154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 156}], {
             RGBColor[
             0.3410239560220559, 0.4678404187910305, 0.9430224559559374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 159}], {
             RGBColor[
             0.2893985943419117, 0.4215066499569798, 0.9397921938696936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 168}], {
             RGBColor[
             0.3439839043984553, 0.4704041773033365, 0.943211061249102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 191}], {
             RGBColor[
             0.2574665501142888, 0.38794404686520834`, 0.9379737111901566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 205}], {
             RGBColor[
             0.32995805051825455`, 0.4582556876322203, 0.9423173462424312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 212}], {
             RGBColor[
             0.2604625119164363, 0.3910929926742148, 0.9381443267826606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 225}], {
             RGBColor[
             0.2575765092536425, 0.3880596208924811, 0.9379799732004728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 251}], {
             RGBColor[
             0.2865818395337517, 0.41854606206103384`, 0.9396317838503843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 271}], {
             RGBColor[
             0.25509580298829937`, 0.3854522413217438, 0.9378387006485376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 276}], {
             RGBColor[
             0.2644651178260697, 0.3952999852651118, 0.9383722692678894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 282}], {
             RGBColor[
             0.36409426757402563`, 0.48782276310977274`, 0.9444924758077534]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 112}], {
             RGBColor[
             0.1950909003644823, 0.32238328413354655`, 0.9344215102134096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 132}], {
             RGBColor[
             0.1989233882773373, 0.32641147192372544`, 0.9346397647303889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 133}], {
             RGBColor[
             0.19311989172231955`, 0.3203116290814677, 0.9343092641870845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 146}], {
             RGBColor[
             0.20048974504421074`, 0.3280578121984645, 0.9347289664310452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 236}], {
             RGBColor[
             0.2161907003932258, 0.34456051176834573`, 0.9356231126106896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 260}], {
             RGBColor[
             0.22955901197049378`, 0.3586114548359634, 0.9363844181783704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 267}], {
             RGBColor[
             0.19857826997424566`, 0.3260487307054119, 0.9346201107535846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 120}], {
             RGBColor[
             0.3639742346570427, 0.4869360497143149, 0.944513487615392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 130}], {
             RGBColor[
             0.6803306714803544, 0.6256180746890865, 0.5988573985297044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 178}], {
             RGBColor[
             0.353934746876465, 0.4763839115166376, 0.9439417536383794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 182}], {
             RGBColor[
             0.35160088518762583`, 0.47393087490628993`, 0.9438088436678389]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 202}], {
             RGBColor[
             0.7273332106591868, 0.5124071693605181, 0.4568577343104335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 261}], {
             RGBColor[
             0.34679730240272766`, 0.46888200483462256`, 0.9435352867345028]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 284}], {
             RGBColor[
             0.3449079379891919, 0.4668961630433738, 0.9434276902262162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 157}], {
             RGBColor[
             0.18079506708635712`, 0.3073574569500555, 0.9336073836570105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.17910006852395627`, 0.30557590599185624`, 0.9335108559964074]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 275}], {
             RGBColor[
             0.17961340510331275`, 0.30611545528417883`, 0.9335400897551883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 285}], {
             RGBColor[
             0.18936585526810354`, 0.31636589874842813`, 0.9340954773646161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 182}], {
             RGBColor[
             0.22500890422772363`, 0.3538290031048185, 0.9361252962737008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 199}], {
             RGBColor[
             0.19703448061371565`, 0.32442611020559603`, 0.9345321942333341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 209}], {
             RGBColor[
             0.18806492725905072`, 0.31499854092731383`, 0.934021391439051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 215}], {
             RGBColor[
             0.21020795705683448`, 0.338272269193962, 0.9352824042283578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 229}], {
             RGBColor[
             0.20669327315473038`, 0.33457811356902034`, 0.9350822481796419]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 233}], {
             RGBColor[
             0.20053490529032286`, 0.32810527848045334`, 0.9347315382402527]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 259}], {
             RGBColor[
             0.19041774683741108`, 0.3174715034815479, 0.934155381033354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 284}], {
             RGBColor[
             0.2183159570292897, 0.34679429124190236`, 0.9357441428320781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 119}], {
             RGBColor[
             0.1807572108955105, 0.3073176676932546, 0.933605227802945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 122}], {
             RGBColor[
             0.18285159839459103`, 0.3095190017466254, 0.933724500072649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 161}], {
             RGBColor[
             0.1911587437240086, 0.318250338191278, 0.9341975797098391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 244}], {
             RGBColor[
             0.18508330510196136`, 0.31186466699444937`, 0.9338515924681194]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 266}], {
             RGBColor[
             0.1894062944527255, 0.3164084028954582, 0.9340977803163559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 104}], {
             RGBColor[
             0.49120791951509923`, 0.5945373978105576, 0.9540278714950781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 116}], {
             RGBColor[
             0.46733992011891123`, 0.5718860980228273, 0.952579449352897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 136}], {
             RGBColor[
             0.5199717589850226, 0.6194511898467974, 0.9558606779112371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 149}], {
             RGBColor[
             0.7714159149498363, 0.6714029284596804, 0.6000007099012994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 197}], {
             RGBColor[
             0.816834867392223, 0.8565183997567056, 0.9207499871177253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 198}], {
             RGBColor[
             0.8059595419277743, 0.8487647451023745, 0.9551527712864303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[
             0.5654681824695174, 0.6580354513456885, 0.9589869162220399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 226}], {
             RGBColor[
             0.8167925796772653, 0.8565009126998259, 0.9214508039916728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 243}], {
             RGBColor[
             0.8173727655187092, 0.8567408344553589, 0.91183562312612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 254}], {
             RGBColor[
             0.4830549298600605, 0.587475687952538, 0.9535083702036646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 283}], {
             RGBColor[
             0.4765743997943146, 0.5815921216615045, 0.9531053393092228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 165}], {
             RGBColor[
             0.20499479718794766`, 0.3327929076383356, 0.9349855224860035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 172}], {
             RGBColor[
             0.19138970866876043`, 0.3184930969922355, 0.9342107328217606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 175}], {
             RGBColor[
             0.18740197098760464`, 0.3143017318521686, 0.9339836370601481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 183}], {
             RGBColor[
             0.19246783079694663`, 0.31962627170585023`, 0.934272130282022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 238}], {
             RGBColor[
             0.18981943468321613`, 0.3168426394723074, 0.9341213080412961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 253}], {
             RGBColor[
             0.1920226425007294, 0.3191583505799577, 0.9342467774671497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 127}], {
             RGBColor[
             0.3850824421018483, 0.5079607893674816, 0.9457580905890645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 145}], {
             RGBColor[
             0.643116750417353, 0.7172355839626725, 0.9675221132384173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 154}], {
             RGBColor[
             0.45931362601150366`, 0.5710619602704519, 0.9508179830889629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 159}], {
             RGBColor[
             0.35628521918114736`, 0.4813996069512451, 0.9439824173184419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 167}], {
             RGBColor[
             0.6645058305861254, 0.6055266520723135, 0.5963223612979925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 168}], {
             RGBColor[
             0.41087052923769096`, 0.5302971342976018, 0.9474012846978503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 203}], {
             RGBColor[
             0.679227364936692, 0.7459924328014227, 0.96969136416035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 205}], {
             RGBColor[
             0.39684467535749024`, 0.5181486446264856, 0.9465075696911796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 212}], {
             RGBColor[
             0.327349136755672, 0.45098594966848016`, 0.9423345502314089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 225}], {
             RGBColor[
             0.3244631340928782, 0.4479525778867464, 0.9421701966492211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 255}], {
             RGBColor[
             0.3936737549660358, 0.5154021527585007, 0.9463055214477708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 265}], {
             RGBColor[
             0.3220227389937979, 0.445387567907627, 0.9420312197585695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 269}], {
             RGBColor[
             0.6972472679550255, 0.7302486647196956, 0.6491594274470608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 276}], {
             RGBColor[
             0.33135174266530537`, 0.4551929422593771, 0.9425624927166377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 282}], {
             RGBColor[
             0.4309808924132613, 0.5477157201040381, 0.9486826992565017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 293}], {
             RGBColor[
             0.6605442022439556, 0.5885330418914387, 0.5930681631412746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 114}], {
             RGBColor[
             0.28710993911342014`, 0.4166656473064825, 0.939751033226302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 116}], {
             RGBColor[
             0.3112198168736299, 0.4420066574870038, 0.9411240550973782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 204}], {
             RGBColor[
             0.40934807922423605`, 0.5281560108098651, 0.9475315219665212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 206}], {
             RGBColor[
             0.2787552105581772, 0.4078842978745366, 0.9392752437947942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 243}], {
             RGBColor[
             0.6612526622734278, 0.7268613939195354, 0.9003802288706013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 254}], {
             RGBColor[
             0.32693482661477913`, 0.45759624741671456`, 0.942052975948146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 283}], {
             RGBColor[
             0.32045429654903324`, 0.4517126811256811, 0.9416499450537039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 287}], {
             RGBColor[
             0.2890443879522816, 0.41869887568726627`, 0.9398611972259145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 300}], {
             RGBColor[
             0.2803668703826312, 0.4095782545351725, 0.9393670254375599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 139}], {
             RGBColor[
             0.3622816914289454, 0.48590921655384295`, 0.9443895603593033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 143}], {
             RGBColor[
             0.29536739445361543`, 0.4277802373181654, 0.9401321082060067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 163}], {
             RGBColor[
             0.4524953087499887, 0.5594906748089641, 0.9513970167856213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 174}], {
             RGBColor[
             0.25852249961576723`, 0.3890539167423275, 0.9380338459521285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 235}], {
             RGBColor[
             0.34616703863432685`, 0.47195151424914406`, 0.9433627489328582]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 274}], {
             RGBColor[
             0.373443394956703, 0.4953127699434419, 0.9451737605551122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 298}], {
             RGBColor[
             0.27198901083979987`, 0.403208073864912, 0.938800743844419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 115}], {
             RGBColor[
             0.6067946716231568, 0.6858798777418896, 0.9651595250499304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 155}], {
             RGBColor[
             0.8940872222095038, 0.8191271102860018, 0.6231274080512639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 162}], {
             RGBColor[
             0.9266044419072905, 0.9416892870110949, 0.8898655994395634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 194}], {
             RGBColor[
             0.7739330746560312, 0.8236601401446212, 0.9780122537987794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 200}], {
             RGBColor[
             0.6137154608562325, 0.6918743175265988, 0.9656005116200483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 210}], {
             RGBColor[
             0.6667698289178824, 0.73732879896912, 0.9691188386686375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 211}], {
             RGBColor[
             0.5662966671615951, 0.6472879549936589, 0.9627077142549896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 227}], {
             RGBColor[
             0.907282547148933, 0.8714421765894653, 0.6337446762316135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 241}], {
             RGBColor[
             0.9239924068585166, 0.940609143392188, 0.9331537799277652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 264}], {
             RGBColor[
             0.579035279379287, 0.6606770441091168, 0.9634331593756991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 290}], {
             RGBColor[
             0.9041357720440601, 0.8589662618992862, 0.6312127071179277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 291}], {
             RGBColor[
             0.8943677152627585, 0.9186085554583606, 0.9897867851648885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 137}], {
             RGBColor[
             0.33500472849332374`, 0.4602209338581902, 0.9427270090780024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 139}], {
             RGBColor[
             0.4245992235592372, 0.5421882392946853, 0.9482760649602114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[
             0.3109365240034128, 0.43492372492699083`, 0.9413563604380197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 150}], {
             RGBColor[
             0.657942354371067, 0.5994193570949246, 0.595803153810185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.4014834091317521, 0.5221664826722128, 0.9468031457054042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.4656160294018773, 0.5758295097005381, 0.9514105681730911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 251}], {
             RGBColor[
             0.34704129264344796`, 0.47287212594221606`, 0.943412473599851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 273}], {
             RGBColor[
             0.32370272298268776`, 0.4483418094779742, 0.9420833765839904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 274}], {
             RGBColor[
             0.43576092708699476`, 0.5515917926842843, 0.9490602651560203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 277}], {
             RGBColor[
             0.7007432409432577, 0.7578412318622451, 0.7139688588587303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 289}], {
             RGBColor[
             0.32595994240234355`, 0.45071429020400966`, 0.942211921890683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 136}], {
             RGBColor[
             0.3166504809342749, 0.4423958027593246, 0.9416280716923184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 177}], {
             RGBColor[
             0.2663285931328081, 0.3972586159636525, 0.9384783914298436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 204}], {
             RGBColor[
             0.36214690441876973`, 0.48098006425821577`, 0.9447543100031214]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 208}], {
             RGBColor[
             0.2150010029643497, 0.34331006433942324`, 0.9355553611021148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 252}], {
             RGBColor[
             0.23931387407336885`, 0.3688644334000649, 0.9369399431441039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 254}], {
             RGBColor[
             0.27973365180931276`, 0.4104203008650652, 0.9392757639847461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 268}], {
             RGBColor[
             0.2228674989167732, 0.351578250350071, 0.9360033464091675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 279}], {
             RGBColor[
             0.23867609661587075`, 0.3681940888548081, 0.9369036226614065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 280}], {
             RGBColor[
             0.2513491898337207, 0.3815143133472875, 0.9376253365720018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 283}], {
             RGBColor[
             0.2732531217435669, 0.4045367345740317, 0.9388727330903042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 111}], {
             RGBColor[
             0.8035074391264327, 0.8444862586698714, 0.8657863480729937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 151}], {
             RGBColor[
             0.7953196099914366, 0.8378390101205823, 0.8651417721704804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 155}], {
             RGBColor[
             0.9595624996907148, 0.8684305979471943, 0.514184885580798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 192}], {
             RGBColor[
             0.6617142280646152, 0.7260405303844142, 0.8555444013688691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 218}], {
             RGBColor[
             0.9800003657513711, 0.9831729301139916, 0.8546124313811914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 220}], {
             RGBColor[
             0.6629503007752218, 0.7271111544395208, 0.8556231628289728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 227}], {
             RGBColor[
             0.9727578246301442, 0.9207456642506578, 0.5248021537611475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 290}], {
             RGBColor[
             0.9696110495252712, 0.9082697495604787, 0.5222701846474617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 292}], {
             RGBColor[
             0.8832633694480486, 0.907223500639492, 0.873440789605417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 148}], {
             RGBColor[
             0.2161072361235734, 0.34447278552900074`, 0.9356183594440073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 191}], {
             RGBColor[
             0.20664696570435293`, 0.3345294415026117, 0.9350796110388486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 223}], {
             RGBColor[
             0.18370379552866184`, 0.31041471496695283`, 0.9337730314387216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 246}], {
             RGBColor[
             0.18518351558803503`, 0.3119699945690246, 0.9338572993070533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 278}], {
             RGBColor[
             0.19327360105018532`, 0.32047318733078894`, 0.9343180177059138]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 295}], {
             RGBColor[
             0.19142001506063305`, 0.31852495093162986`, 0.9342124587259435]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 143}], {
             RGBColor[
             0.46054913753176646`, 0.5687866450741914, 0.9517800380473413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 163}], {
             RGBColor[
             0.6176770518281398, 0.70049708256499, 0.9630449466269559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.5718800780485805, 0.6633170361205862, 0.9594396410911864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 218}], {
             RGBColor[
             0.7906966430720825, 0.8363639438748425, 0.9515975962507148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 235}], {
             RGBColor[
             0.5113487817124779, 0.61295792200517, 0.9550106787741928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 262}], {
             RGBColor[
             0.459021775002635, 0.5671812902156966, 0.9516930570108376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 292}], {
             RGBColor[
             0.6939596467687601, 0.7604145144003427, 0.9704259544749405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 131}], {
             RGBColor[
             0.20931958090363292`, 0.3373385295306458, 0.9352318125206677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 132}], {
             RGBColor[
             0.1930638232066118, 0.32025269751650964`, 0.9343060711680607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 133}], {
             RGBColor[
             0.18726032665159403`, 0.3141528546742519, 0.9339755706247563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 146}], {
             RGBColor[
             0.19463017997348525`, 0.32189903779124873`, 0.934395272868717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 170}], {
             RGBColor[
             0.1934039006537554, 0.3206101404756131, 0.9343254380755761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 190}], {
             RGBColor[
             0.19682291342577818`, 0.3242037396769393, 0.9345201457949667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 115}], {
             RGBColor[
             0.3096806718260522, 0.43885035168813935`, 0.9410927375300542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 134}], {
             RGBColor[
             0.25621583264175446`, 0.38662946350150684`, 0.9379024846803665]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 144}], {
             RGBColor[
             0.23263625868922916`, 0.36184583624606526`, 0.9365596628266237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 160}], {
             RGBColor[
             0.23169850636271255`, 0.3608601990939647, 0.936506259218909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 169}], {
             RGBColor[
             0.4361857848874334, 0.5443112881470928, 0.9502895329739705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 176}], {
             RGBColor[
             0.23091262265844142`, 0.3600341854928709, 0.9364615043045614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 187}], {
             RGBColor[
             0.24618639037776724`, 0.3760878837786886, 0.9373313227806626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 193}], {
             RGBColor[
             0.2735981771019762, 0.40489940963349313`, 0.9388923834825018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 200}], {
             RGBColor[
             0.3166014610591278, 0.4448447914728484, 0.9415337241001722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 228}], {
             RGBColor[
             0.34694483487630184`, 0.4711266967709722, 0.9434671770482106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 231}], {
             RGBColor[
             0.24940666839475117`, 0.3794726001519578, 0.9375147128497554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 245}], {
             RGBColor[
             0.24643755239072743`, 0.3763518709789012, 0.9373456260857398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 264}], {
             RGBColor[
             0.28192127958218227`, 0.41364751805536637`, 0.939366371855823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 288}], {
             RGBColor[
             0.23824897201713657`, 0.3677451538202748, 0.9368792985473828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 297}], {
             RGBColor[
             0.22981287868159825`, 0.35887828484541334`, 0.9363988755120056]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 116}], {
             RGBColor[
             0.26324193971723214`, 0.3940143475187522, 0.9383026110841209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 204}], {
             RGBColor[
             0.3613702020678383, 0.4801637008416135, 0.944710077953264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 206}], {
             RGBColor[
             0.2307773334017795, 0.35989198790628496`, 0.936453799781537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 254}], {
             RGBColor[
             0.2789569494583814, 0.4096039374484629, 0.9392315319348887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 283}], {
             RGBColor[
             0.2724764193926355, 0.4037203711574294, 0.9388285010404467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 134}], {
             RGBColor[
             0.29826389721871693`, 0.4268505977105114, 0.940442569105771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 169}], {
             RGBColor[
             0.47823384946439584`, 0.5845324223560975, 0.9528296173993749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 193}], {
             RGBColor[
             0.3156462416789386, 0.4451205438424978, 0.9414324679079064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 200}], {
             RGBColor[
             0.35864952563609026`, 0.485065925681853, 0.9440738085255767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 210}], {
             RGBColor[
             0.4117038936977402, 0.5305204071243743, 0.9475921355741658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 211}], {
             RGBColor[
             0.3112307319414529, 0.4404795631489132, 0.9411810111605179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 227}], {
             RGBColor[
             0.6522166119287909, 0.6646337847447196, 0.6122179731371418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 228}], {
             RGBColor[
             0.3889928994532643, 0.5113478309799768, 0.946007261473615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 231}], {
             RGBColor[
             0.29145473297171365`, 0.41969373436096236`, 0.9400547972751598]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 245}], {
             RGBColor[
             0.2884856169676899, 0.4165730051879058, 0.9398857105111442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 264}], {
             RGBColor[
             0.32396934415914475`, 0.453868652264371, 0.9419064562812274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 204}], {
             RGBColor[
             0.38548007982804805`, 0.5055047110221348, 0.9460830998243401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 206}], {
             RGBColor[
             0.2548872111619892, 0.3852329980868062, 0.9378268216526131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 254}], {
             RGBColor[
             0.30306682721859113`, 0.43494494762898417`, 0.9406045538059649]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 283}], {
             RGBColor[
             0.29658629715284524`, 0.4290613813379507, 0.9402015229115228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 287}], {
             RGBColor[
             0.2651763885560936, 0.39604757589953593`, 0.9384127750837334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 158}], {
             RGBColor[
             0.189227738636957, 0.3162207294119929, 0.9340876118267976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 196}], {
             RGBColor[
             0.1942847722586868, 0.32153599238288155`, 0.9343756024103442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 207}], {
             RGBColor[
             0.18539878883552113`, 0.3121962604012447, 0.9338695588000294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 212}], {
             RGBColor[
             0.20943922968905518`, 0.3374642879902957, 0.935238626341993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 214}], {
             RGBColor[
             0.19317010459047246`, 0.32036440598957616`, 0.9343121237356424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 225}], {
             RGBColor[
             0.20655322702626136`, 0.33443091620856197`, 0.9350742727598051]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 265}], {
             RGBColor[
             0.2041128319271811, 0.33186590622944256`, 0.9349352958691536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 276}], {
             RGBColor[
             0.21344183559868857`, 0.34167128058119267`, 0.9354665688272218]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 166}], {
             RGBColor[
             0.18740769372755933`, 0.31430774681470364`, 0.9339839629617225]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.18622253645749176`, 0.31306207138055164`, 0.9339164700084752]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 234}], {
             RGBColor[
             0.19143808005152518`, 0.3185439383824441, 0.9342134875004501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 239}], {
             RGBColor[
             0.213148543369447, 0.34136301185245843`, 0.9354498662686535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 263}], {
             RGBColor[
             0.19930513416780576`, 0.32681271105869525`, 0.9346615045941087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 285}], {
             RGBColor[
             0.19420033164892994`, 0.32144723994818314`, 0.9343707936425373]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 122}], {
             RGBColor[
             0.18294597115910344`, 0.30961819350570674`, 0.933729874461976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 161}], {
             RGBColor[
             0.191253116488521, 0.3183495299503595, 0.9342029540991661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 244}], {
             RGBColor[
             0.18517767786647377`, 0.3119638587535308, 0.9338569668574466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 266}], {
             RGBColor[
             0.1895006672172379, 0.3165075946545396, 0.9341031547056828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 131}], {
             RGBColor[
             0.2542490675591432, 0.38456226869957383`, 0.93779048031848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 141}], {
             RGBColor[
             0.28646903998749706`, 0.4184275025860159, 0.939625360083097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 170}], {
             RGBColor[
             0.23833338730926568`, 0.3678338796445412, 0.9368841058733883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 178}], {
             RGBColor[
             0.2690508208241996, 0.4001198498665095, 0.9386334182696933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 182}], {
             RGBColor[
             0.2667169591353605, 0.3976668132561618, 0.9385005082991529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 188}], {
             RGBColor[
             0.317477361422549, 0.44666279511939655`, 0.9415507479684607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 190}], {
             RGBColor[
             0.24175240008128845`, 0.37142747884586735`, 0.937078813592779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 261}], {
             RGBColor[
             0.2619133763504623, 0.3926179431844944, 0.9382269513658168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 284}], {
             RGBColor[
             0.26002401193692654`, 0.39063210139324567`, 0.9381193548575302]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 294}], {
             RGBColor[
             0.40756986398437334`, 0.5224500406559134, 0.9479120363171062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 135}], {
             RGBColor[
             0.21926297732246688`, 0.3477896696145861, 0.9357980742367835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 154}], {
             RGBColor[
             0.3613735298324199, 0.47852983599420473`, 0.9448593103869043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 173}], {
             RGBColor[
             0.21336819471978227`, 0.34159387934836083`, 0.9354623750881099]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.21391225518849333`, 0.3421657213964022, 0.9354933585269378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 234}], {
             RGBColor[
             0.20980230497718771`, 0.3378459031384259, 0.9352593029425303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 239}], {
             RGBColor[
             0.2315127682951095, 0.3606649766084402, 0.9364956817107337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 249}], {
             RGBColor[
             0.21645306950395798`, 0.3448362783388877, 0.9356380541434055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 255}], {
             RGBColor[
             0.295733658786952, 0.42287002848225363`, 0.9403468487457121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 258}], {
             RGBColor[
             0.28280548262609156`, 0.41167229208074363`, 0.9395230767926794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 263}], {
             RGBColor[
             0.2176693590934683, 0.34611467581467703`, 0.935707320036189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 286}], {
             RGBColor[
             0.22317009351070355`, 0.3518962964538972, 0.9360205787236432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 138}], {
             RGBColor[
             0.2081640824318275, 0.3361240273739437, 0.9351660085921052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 161}], {
             RGBColor[
             0.19334750398760153`, 0.32055086400373023`, 0.9343222263688701]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 266}], {
             RGBColor[
             0.19159505471631844`, 0.31870892870791034`, 0.9342224269753869]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 189}], {
             RGBColor[
             0.2072195140090381, 0.335131226072495, 0.935112216817791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 257}], {
             RGBColor[
             0.19133948148967972`, 0.3184403050424346, 0.9342078724582165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 267}], {
             RGBColor[
             0.19740462411574278`, 0.32481515449468, 0.9345532733581963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 287}], {
             RGBColor[
             0.22080206667647367`, 0.3494073501095485, 0.9358857230986155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 300}], {
             RGBColor[
             0.21212454910682327`, 0.34028672895745476`, 0.9353915513102607]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 147}], {
             RGBColor[
             0.19966110992932296`, 0.3271868641542167, 0.9346817768871081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 247}], {
             RGBColor[
             0.191840440673128, 0.3189668449068855, 0.9342364013426112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 273}], {
             RGBColor[
             0.2124273089085979, 0.3406049487052001, 0.9354087930330789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 289}], {
             RGBColor[
             0.2146845283282537, 0.3429774294312355, 0.9355373383397714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 128}], {
             RGBColor[
             0.8384430661867497, 0.296495829336185, 0.18444642963665195`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 130}], {
             RGBColor[
             0.8607307087477495, 0.4103624865662075, 0.20352137280561344`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 142}], {
             RGBColor[
             0.8334415120439743, 0.25805169249981336`, 0.1796569357410828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.8552975837103799, 0.3871468134192908, 0.19906309946450382`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 150}], {
             RGBColor[
             0.8592661193941853, 0.40455587782479563`, 0.20234292983340507`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 167}], {
             RGBColor[
             0.859356989051198, 0.4049161457343329, 0.20241604569242247`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 237}], {
             RGBColor[
             0.8318212025230813, 0.24559728349806995`, 0.17810532551399777`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 243}], {
             RGBColor[
             0.8859354840896285, 0.5107054174164098, 0.4069530416143843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 256}], {
             RGBColor[
             0.8294390160964316, 0.2272867547420918, 0.17582414110154324`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 269}], {
             RGBColor[
             0.881184613963798, 0.48806415416592097`, 0.23764075645846794`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 277}], {
             RGBColor[
             0.8878000437756458, 0.5101704610030093, 0.28112006653243526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 281}], {
             RGBColor[
             0.8829501729358756, 0.5088362266550703, 0.4280047531480473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 293}], {
             RGBColor[
             0.8567159034897515, 0.39358707228041634`, 0.20024658025461053`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 153}], {
             RGBColor[
             0.2222787641449363, 0.35095945277692997`, 0.9359698188348664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 157}], {
             RGBColor[
             0.20301322621103607`, 0.33071015090274497`, 0.93487267495034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 192}], {
             RGBColor[
             0.2770528278061131, 0.40650831596386994`, 0.939163161568517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 220}], {
             RGBColor[
             0.27828890051671973`, 0.40757894001897654`, 0.9392419230286206]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 222}], {
             RGBColor[
             0.22245696617283922`, 0.3511467544069171, 0.9359799671767292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 239}], {
             RGBColor[
             0.2305322261132995, 0.35963436460539283`, 0.9364398412840619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 248}], {
             RGBColor[
             0.22272354417989754`, 0.3514269447943572, 0.9359951483998643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 285}], {
             RGBColor[
             0.21158401439278246`, 0.3397185927011176, 0.9353607686579457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 145}], {
             RGBColor[
             0.6068695545086966, 0.6858400847036329, 0.9652124739672545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 148}], {
             RGBColor[
             0.29756624946408855`, 0.42638484862682313`, 0.9403930437729009]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 156}], {
             RGBColor[
             0.3716633849526351, 0.49633787652625627`, 0.9449030401335229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 159}], {
             RGBColor[
             0.3200380232724909, 0.45000410769220556`, 0.9416727780472791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 168}], {
             RGBColor[
             0.3746233333290345, 0.4989016350385623, 0.9450916454266876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 191}], {
             RGBColor[
             0.28810597904486807`, 0.41644150460043405`, 0.9398542953677421]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 205}], {
             RGBColor[
             0.3605974794488338, 0.48675314536744607`, 0.9441979304200168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 212}], {
             RGBColor[
             0.2911019408470156, 0.4195904504094406, 0.9400249109602461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 225}], {
             RGBColor[
             0.28821593818422175`, 0.41655707862770686`, 0.9398605573780583]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 251}], {
             RGBColor[
             0.31722126846433096`, 0.4470435197962596, 0.9415123680279698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 269}], {
             RGBColor[
             0.6610000720463691, 0.698853165460656, 0.646849788175898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 276}], {
             RGBColor[
             0.29510454675664893`, 0.4237974430003376, 0.9402528534454749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 282}], {
             RGBColor[
             0.3947336965046049, 0.5163202208449985, 0.9463730599853389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 142}], {
             RGBColor[
             0.839938700425626, 0.30799192948729065`, 0.18587865067287715`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 149}], {
             RGBColor[
             0.8617947720920316, 0.43708705040676815`, 0.20528481439629814`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 150}], {
             RGBColor[
             0.865763307775837, 0.454496114812273, 0.2085646447651994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 197}], {
             RGBColor[
             0.8920740737202894, 0.5604973646047849, 0.4191176658739154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 198}], {
             RGBColor[
             0.8848238567439902, 0.5553282615018976, 0.4420528553197187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 237}], {
             RGBColor[
             0.838318390904733, 0.29553752048554727`, 0.1843270404457921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 243}], {
             RGBColor[
             0.8924326724712802, 0.5606456544038871, 0.4131747565461786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 256}], {
             RGBColor[
             0.8359362044780833, 0.2772269917295691, 0.18204585603333756`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 269}], {
             RGBColor[
             0.8876818023454497, 0.5380043911533983, 0.24386247139026226`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 277}], {
             RGBColor[
             0.8942972321572974, 0.5601106979904866, 0.2873417814642296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 281}], {
             RGBColor[
             0.8894473613175273, 0.5587764636425476, 0.4342264680798416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 165}], {
             RGBColor[
             0.20344097121398075`, 0.33115973802143944`, 0.9348970343954657]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 175}], {
             RGBColor[
             0.18584814501363772`, 0.3126685622352725, 0.9338951489696101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 183}], {
             RGBColor[
             0.1909140048229797, 0.31799310208895415`, 0.9341836421914842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 184}], {
             RGBColor[
             0.19028873719925032`, 0.31733590617215746`, 0.9341480341253134]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 224}], {
             RGBColor[
             0.19887770973958555`, 0.32636346088436186`, 0.9346371634052393]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 253}], {
             RGBColor[
             0.19046881652676248`, 0.3175251809630616, 0.9341582893766117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 140}], {
             RGBColor[
             0.8488137274171336, 0.3187633460045766, 0.19210965802511026`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 162}], {
             RGBColor[
             0.9515757296113414, 0.8393631712246421, 0.5204689724050278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 167}], {
             RGBColor[
             0.9097426027065735, 0.6798665267659179, 0.24623498340554434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 201}], {
             RGBColor[
             0.8675104556731318, 0.4624745923387423, 0.2100136661179885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 202}], {
             RGBColor[
             0.8816482178398845, 0.5540191449102804, 0.2228814513408511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 203}], {
             RGBColor[
             0.92446413705714, 0.8203323074950271, 0.6196039862679017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 216}], {
             RGBColor[
             0.8815768726528278, 0.553695183078948, 0.2228219191679405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 237}], {
             RGBColor[
             0.8539841698020644, 0.35850563187745466`, 0.19706087949209944`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 269}], {
             RGBColor[
             0.9424840400754735, 0.8045885394133, 0.29907204955461253`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 281}], {
             RGBColor[
             0.9451323785335899, 0.8357466481470239, 0.5846180445889815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 293}], {
             RGBColor[
             0.9057809743644036, 0.6628729165850431, 0.24298078524882644`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 294}], {
             RGBColor[
             0.723926300807685, 0.6611320656306849, 0.6022559472314186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 299}], {
             RGBColor[
             0.849730326606493, 0.32580872903031854`, 0.19298739444399152`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 141}], {
             RGBColor[
             0.26162779894186294`, 0.392317783221403, 0.938210688154871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 146}], {
             RGBColor[
             0.2147184255833614, 0.3430130575955638, 0.9355392687383033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 170}], {
             RGBColor[
             0.21349214626363155`, 0.34172416027992825`, 0.9354694339451624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 178}], {
             RGBColor[
             0.2442095797785655, 0.3740101305018966, 0.9372187463414672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 182}], {
             RGBColor[
             0.24187571808972635`, 0.3715570938915489, 0.9370858363709268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 188}], {
             RGBColor[
             0.2926361203769149, 0.4205530757547836, 0.9401360760402346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 190}], {
             RGBColor[
             0.21691115903565433`, 0.3453177594812544, 0.9356641416645529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 199}], {
             RGBColor[
             0.21390129447571837`, 0.3421542009923264, 0.9354927343305601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 261}], {
             RGBColor[
             0.23707213530482818`, 0.36650822381988146`, 0.9368122794375908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 284}], {
             RGBColor[
             0.23518277089129241`, 0.36452238202863274`, 0.9367046829293041]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 133}], {
             RGBColor[
             0.19109281456444907`, 0.3181810424644308, 0.9341938251417357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 146}], {
             RGBColor[
             0.19846266788634026`, 0.3259272255814276, 0.9346135273856964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 236}], {
             RGBColor[
             0.21416362323535532`, 0.3424299251513089, 0.9355076735653408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 260}], {
             RGBColor[
             0.2275319348126233, 0.35648086821892655`, 0.9362689791330215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 267}], {
             RGBColor[
             0.19655119281637518`, 0.32391814408837505`, 0.9345046717082358]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 146}], {
             RGBColor[
             0.19265917133132254`, 0.3198273827391699, 0.9342830268423918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 170}], {
             RGBColor[
             0.1914328920115927, 0.3185384854235343, 0.9342131920492509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 144}], {
             RGBColor[
             0.22121948408189393`, 0.34984608226843733`, 0.9359094944023405]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 160}], {
             RGBColor[
             0.22028173175537732`, 0.3488604451163368, 0.9358560907946256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 169}], {
             RGBColor[
             0.42476901028009817`, 0.532311534169465, 0.9496393645496872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 176}], {
             RGBColor[
             0.21949584805110617`, 0.34803443151524305`, 0.9358113358802782]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 180}], {
             RGBColor[
             0.21984183187712564`, 0.34839808245303105`, 0.9358310391473328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 187}], {
             RGBColor[
             0.23476961577043198`, 0.36408812980106076`, 0.9366811543563793]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 193}], {
             RGBColor[
             0.26218140249464095`, 0.39289965565586527`, 0.9382422150582186]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 200}], {
             RGBColor[
             0.3051846864517926, 0.4328450374952205, 0.9408835556758889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 221}], {
             RGBColor[
             0.21549733286296777`, 0.343831738532004, 0.9355836263555868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 228}], {
             RGBColor[
             0.3355280602689666, 0.4591269427933443, 0.9428170086239273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 230}], {
             RGBColor[
             0.21844228820343148`, 0.34692707331578443`, 0.9357513372055553]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 245}], {
             RGBColor[
             0.2350207777833922, 0.3643521170012733, 0.9366954576614566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 264}], {
             RGBColor[
             0.27050450497484707`, 0.4016477640777385, 0.9387162034315397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 288}], {
             RGBColor[
             0.22683219740980134`, 0.35574539984264686`, 0.9362291301230996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 297}], {
             RGBColor[
             0.21839610407426302`, 0.3468785308677854, 0.9357487070877224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 158}], {
             RGBColor[
             0.20301108119461975`, 0.33070789635448955`, 0.9348725527948284]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 173}], {
             RGBColor[
             0.20718172638991203`, 0.3350915088889201, 0.9351100648687836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 186}], {
             RGBColor[
             0.20309625090443267`, 0.3307974151195744, 0.934877403083805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 213}], {
             RGBColor[
             0.20772578685862308`, 0.3356633509369615, 0.9351410483076115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 214}], {
             RGBColor[
             0.20695344714813524`, 0.3348515729320728, 0.9350970647036734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 249}], {
             RGBColor[
             0.21026660117408774`, 0.33833390787944695`, 0.9352857439240791]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 255}], {
             RGBColor[
             0.28954719045708177`, 0.4163676580228129, 0.9399945385263857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 263}], {
             RGBColor[
             0.21148289076359805`, 0.33961230535523634`, 0.9353550098168626]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 265}], {
             RGBColor[
             0.21789617448484386`, 0.3463530731719392, 0.9357202368371844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 276}], {
             RGBColor[
             0.22722517815635135`, 0.3561584475236893, 0.9362515097952526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 286}], {
             RGBColor[
             0.2169836251808333, 0.34539392599445645`, 0.9356682685043168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 177}], {
             RGBColor[
             0.34229360740819775`, 0.46934835455154167`, 0.9430884098094023]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 194}], {
             RGBColor[
             0.539310518839214, 0.6345587760249104, 0.957788184762517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 197}], {
             RGBColor[
             0.689478603616865, 0.751552751257122, 0.9111273992783655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 204}], {
             RGBColor[
             0.4381119186941594, 0.553069802846105, 0.9493643283826801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 210}], {
             RGBColor[
             0.43214727310106515`, 0.5482274348494092, 0.9488947696323751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 226}], {
             RGBColor[
             0.6894363159019072, 0.7515352642002422, 0.911828216152313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 252}], {
             RGBColor[
             0.3152788883487585, 0.44095417198795417`, 0.9415499615236627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 279}], {
             RGBColor[
             0.3146411108912604, 0.44028382744269734`, 0.9415136410409652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 280}], {
             RGBColor[
             0.32731420410911033`, 0.4536040519351767, 0.9422353549515605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 147}], {
             RGBColor[
             0.23746595794531072`, 0.3669221563848262, 0.9368347070543579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 156}], {
             RGBColor[
             0.32801284307365003`, 0.4541649141300481, 0.9422814923217423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 179}], {
             RGBColor[
             0.3921454633437752, 0.5078279411583735, 0.9468889147894293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 191}], {
             RGBColor[
             0.24445543716588297`, 0.3742685422042259, 0.9372327475559615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 217}], {
             RGBColor[
             0.23078620352350526`, 0.3599013109666169, 0.9364543049218471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 247}], {
             RGBColor[
             0.22964528868911577`, 0.358702137137495, 0.9363893315098609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 251}], {
             RGBColor[
             0.27357072658534587`, 0.4048705574000514, 0.9388908202161892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 270}], {
             RGBColor[
             0.23718665422901314`, 0.36662859047011903`, 0.9368188011209075]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 271}], {
             RGBColor[
             0.24208469003989352`, 0.37177673666076144`, 0.9370977370143425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 273}], {
             RGBColor[
             0.25023215692458567`, 0.3803402409358096, 0.9375617232003286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 278}], {
             RGBColor[
             0.23108207251171536`, 0.3602122880324031, 0.9364711542230267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 289}], {
             RGBColor[
             0.25248937634424146`, 0.382712721661845, 0.9376902685070212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 295}], {
             RGBColor[
             0.2292284865221631, 0.35826405163324404`, 0.9363655952430565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 210}], {
             RGBColor[
             0.35148342859896836`, 0.4711989277702072, 0.9440171598227016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 211}], {
             RGBColor[
             0.25101026684268113`, 0.38115808379474614`, 0.9376060354090536]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 231}], {
             RGBColor[
             0.23123426787294182`, 0.3603722550067954, 0.9364798215236958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 266}], {
             RGBColor[
             0.21471877848996196`, 0.3430134285227765, 0.935539288835812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 143}], {
             RGBColor[
             0.37380885559171856`, 0.49802499695333824`, 0.9450460153054621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 163}], {
             RGBColor[
             0.5309367698880918, 0.6297354344441368, 0.9563109238850767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 235}], {
             RGBColor[
             0.42460849977243, 0.5421962738843169, 0.9482766560323135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 273}], {
             RGBColor[
             0.3398266519904991, 0.46230754637230465`, 0.9431107790825377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 274}], {
             RGBColor[
             0.4518848560948061, 0.5655575295786147, 0.9500876676545675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 298}], {
             RGBColor[
             0.350430471977903, 0.4734528335000848, 0.9437146509438744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 162}], {
             RGBColor[
             0.8753287589904273, 0.41964810147851817`, 0.3738269902449083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 167}], {
             RGBColor[
             0.847440007720582, 0.31331700517270195`, 0.1910043309119193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 181}], {
             RGBColor[
             0.8736439880136796, 0.4112274879198171, 0.24323035592583006`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 201}], {
             RGBColor[
             0.8266673641279991, 0.20598262316708282`, 0.17317000404643912`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 202}], {
             RGBColor[
             0.8337362452113755, 0.25175489945285184`, 0.1796038966578704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 203}], {
             RGBColor[
             0.8572543639542931, 0.40696085899210804`, 0.43991699948682417`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 216}], {
             RGBColor[
             0.8337005726178471, 0.2515929185371857, 0.1795741305714151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 237}], {
             RGBColor[
             0.8199042211924654, 0.15399814293643901`, 0.1666936107334946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 269}], {
             RGBColor[
             0.8692676326331821, 0.39646501360429004`, 0.22622904167796476`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 293}], {
             RGBColor[
             0.8447989221591355, 0.30198793171878546`, 0.18883486547410736`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 299}], {
             RGBColor[
             0.8177772995946797, 0.13764969151287093`, 0.16465686820944062`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 146}], {
             RGBColor[
             0.24693839801171524`, 0.3768782914820059, 0.9373741485029203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 178}], {
             RGBColor[
             0.27642955220691934`, 0.4078753643883386, 0.9390536261060842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 182}], {
             RGBColor[
             0.2740956905180802, 0.4054223277779909, 0.9389207161355438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 188}], {
             RGBColor[
             0.3248560928052687, 0.45441830964122576`, 0.9419709558048517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 236}], {
             RGBColor[
             0.2626393533607303, 0.39338099105188706`, 0.9382682946825648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 261}], {
             RGBColor[
             0.269292107733182, 0.4003734577063236, 0.9386471592022079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 294}], {
             RGBColor[
             0.41494859536709305`, 0.5302055551777425, 0.9483322441534972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 149}], {
             RGBColor[
             0.8517916638064809, 0.3601987767340248, 0.1957058266051599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[
             0.8557601994902863, 0.3776078411395296, 0.19898565697406115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 163}], {
             RGBColor[
             0.7603405238297619, 0.3885080681094508, 0.43863923535829075`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 197}], {
             RGBColor[
             0.8820709654347386, 0.4836090909320415, 0.4095386780827771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 198}], {
             RGBColor[
             0.8748207484584395, 0.4784399878291542, 0.43247386752858047`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 243}], {
             RGBColor[
             0.8824295641857295, 0.48375738073114377`, 0.40359576875504033`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 256}], {
             RGBColor[
             0.8259330961925325, 0.20033871805682574`, 0.1724668682421993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 277}], {
             RGBColor[
             0.8842941238717467, 0.48322242431774326`, 0.2777627936730913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 163}], {
             RGBColor[
             0.4640224729127619, 0.5716064552084593, 0.95205347173178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 174}], {
             RGBColor[
             0.27004966377854045`, 0.4011696971418227, 0.9386903008982872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 185}], {
             RGBColor[
             0.41822549913320267`, 0.5344264087640556, 0.9484481661960105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 235}], {
             RGBColor[
             0.3576942027971, 0.4840672946486393, 0.9440192038790169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 298}], {
             RGBColor[
             0.28351617500257303`, 0.41532385426440727`, 0.9394571987905778]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 160}], {
             RGBColor[
             0.19670215780285202`, 0.3240768178608952, 0.934513268940883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 176}], {
             RGBColor[
             0.19591627409858087`, 0.32325080425980146`, 0.9344685140265354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 221}], {
             RGBColor[
             0.19191775891044247`, 0.3190481112765624, 0.9342408045018441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 230}], {
             RGBColor[
             0.19486271425090618`, 0.32214344606034284`, 0.9344085153518125]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 231}], {
             RGBColor[
             0.21441031983489064`, 0.34268921891888826`, 0.9355217225717294]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 232}], {
             RGBColor[
             0.19277383312180774`, 0.31994789955094727`, 0.9342895566617331]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 240}], {
             RGBColor[
             0.18908519234139687`, 0.31607090421740214`, 0.9340794940261437]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 245}], {
             RGBColor[
             0.2114412038308669, 0.3395684897458317, 0.9353526358077138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 264}], {
             RGBColor[
             0.24692493102232177`, 0.3768641368222969, 0.9373733815777969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 288}], {
             RGBColor[
             0.20325262345727604`, 0.33096177258720527`, 0.9348863082693568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 297}], {
             RGBColor[
             0.19481653012173772`, 0.32209490361234383`, 0.9344058852339796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 156}], {
             RGBColor[
             0.6296976932681398, 0.7056126711214472, 0.9666670627828757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 159}], {
             RGBColor[
             0.5780723315879956, 0.6592789022873965, 0.963436800696632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 167}], {
             RGBColor[
             0.8862929429929738, 0.7834059474084649, 0.6157767446761826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 168}], {
             RGBColor[
             0.6326576416445393, 0.7081764296337532, 0.9668556680760403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 201}], {
             RGBColor[
             0.8518773491973987, 0.5315008727671069, 0.456374840298414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 203}], {
             RGBColor[
             0.9010144773435402, 0.923871728137574, 0.9891457475385399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 205}], {
             RGBColor[
             0.6186317877643385, 0.696027939962637, 0.9659619530693695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 216}], {
             RGBColor[
             0.8659437661770946, 0.6227214635073127, 0.46918309334836605`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 237}], {
             RGBColor[
             0.8383510633263312, 0.42753191230581933`, 0.44342205367252496`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 269}], {
             RGBColor[
             0.9190343803618738, 0.908127960055847, 0.6686138108252507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 277}], {
             RGBColor[
             0.9289575250796454, 0.9412874203114796, 0.7338327759362018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 282}], {
             RGBColor[
             0.6527680048201097, 0.7255950154401895, 0.9681370826346918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 293}], {
             RGBColor[
             0.8823313146508039, 0.7664123372275902, 0.6125225465194646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 170}], {
             RGBColor[
             0.19880274533348388`, 0.3262846685405311, 0.9346328942932117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 236}], {
             RGBColor[
             0.2157299800022288, 0.3440762654260479, 0.9355968752659971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 247}], {
             RGBColor[
             0.2055770841992048, 0.33340492820629564`, 0.9350186828698783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 273}], {
             RGBColor[
             0.22616395243467474`, 0.35504303200461024`, 0.9361910745603459]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 289}], {
             RGBColor[
             0.22842117185433053`, 0.35741551273064565`, 0.9363196198670385]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 156}], {
             RGBColor[
             0.32039438822353183`, 0.44615743504463745`, 0.9418476325885221]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 159}], {
             RGBColor[
             0.26876902654338763`, 0.39982366621058674`, 0.9386173705022783]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 168}], {
             RGBColor[
             0.32335433659993124`, 0.4487211935569434, 0.9420362378816867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 191}], {
             RGBColor[
             0.23683698231576478`, 0.36626106311881523`, 0.9367988878227413]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 205}], {
             RGBColor[
             0.3093284827197305, 0.43657270388582725`, 0.9411425228750159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 217}], {
             RGBColor[
             0.22316774867338707`, 0.35189383188120626`, 0.9360204451886269]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 225}], {
             RGBColor[
             0.23694694145511846`, 0.36637663714608804`, 0.9368051498330575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 251}], {
             RGBColor[
             0.26595227173522773`, 0.39686307831464074`, 0.9384569604829689]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 270}], {
             RGBColor[
             0.22956819937889494`, 0.35862111138470837`, 0.9363849413876872]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 271}], {
             RGBColor[
             0.23446623518977533`, 0.3637692575753508, 0.9366638772811222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 278}], {
             RGBColor[
             0.2234636176615972, 0.35220480894699246`, 0.9360372944898065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.3434646997755016, 0.4661397793633797, 0.9433176524403382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 295}], {
             RGBColor[
             0.2216100316720449, 0.3502565725478334, 0.9359317355098362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 150}], {
             RGBColor[
             0.901456610665, 0.644502615181237, 0.23943789960535378`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.9409227595816787, 0.803504489870005, 0.5552674312684278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 198}], {
             RGBColor[
             0.93004743411723, 0.7957508352156739, 0.5896702154371328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 243}], {
             RGBColor[
             0.9414606577081649, 0.8037269245686582, 0.5463530672768225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 256}], {
             RGBColor[
             0.8437866719113953, 0.2986689012185817, 0.18804023732608074`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 277}], {
             RGBColor[
             0.9442574972371908, 0.8029244899485575, 0.3576036046538991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 281}], {
             RGBColor[
             0.9369826909775356, 0.800923138426649, 0.5779306345773171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 179}], {
             RGBColor[
             0.7150830892215184, 0.6470263643951079, 0.5999650595216117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 237}], {
             RGBColor[
             0.8525195804485002, 0.35269902313604284`, 0.19588243651989107`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 256}], {
             RGBColor[
             0.8477552075952007, 0.3160779656240866, 0.191320067694982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 269}], {
             RGBColor[
             0.9402871560451271, 0.7958786263011822, 0.2973043850963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 274}], {
             RGBColor[
             0.6852279869066359, 0.622788647378854, 0.5976147565045411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 277}], {
             RGBColor[
             0.9502103007628988, 0.8290380865568148, 0.362523350207251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 281}], {
             RGBColor[
             0.9429354945032435, 0.8270367350349062, 0.582850380130669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 293}], {
             RGBColor[
             0.9035840903340573, 0.6541630034729253, 0.24121312079051388`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 154}], {
             RGBColor[
             0.5475628360948273, 0.6435752036232633, 0.9575252987275946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 181}], {
             RGBColor[
             0.7920610111090953, 0.8249056195457978, 0.6813687144574905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 192}], {
             RGBColor[
             0.4642226762503304, 0.5725842955959759, 0.9518849903358793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 220}], {
             RGBColor[
             0.46545874896093703`, 0.5736549196510825, 0.9519637517959829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 239}], {
             RGBColor[
             0.41770207455751684`, 0.5257103442374987, 0.9491616700514242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 258}], {
             RGBColor[
             0.4689947888884989, 0.5767176597098022, 0.9521890651333698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 208}], {
             RGBColor[
             0.1859180316496269, 0.31274201752076575`, 0.9338991289101417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 242}], {
             RGBColor[
             0.1817008098525566, 0.3083094500247394, 0.9336589643676192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 244}], {
             RGBColor[
             0.1860116480511821, 0.312840414294423, 0.9339044602257174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 268}], {
             RGBColor[
             0.1937845276020504, 0.3210102035314135, 0.9343471142171944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 157}], {
             RGBColor[
             0.2018036290672552, 0.32943878761174283`, 0.9348037901824403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 192}], {
             RGBColor[
             0.2758432306623323, 0.4052369526728678, 0.9390942768006172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 220}], {
             RGBColor[
             0.27707930337293885`, 0.40630757672797435`, 0.9391730382607208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 222}], {
             RGBColor[
             0.2212473690290584, 0.3498753911159149, 0.9359110824088295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 239}], {
             RGBColor[
             0.22932262896951866`, 0.3583630013143907, 0.9363709565161622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 248}], {
             RGBColor[
             0.2215139470361167, 0.3501555815033551, 0.9359262636319645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 285}], {
             RGBColor[
             0.21037441724900163`, 0.3384472294101154, 0.9352918838900459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 181}], {
             RGBColor[
             0.7417957890267707, 0.7840980478369171, 0.6774116520475943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[
             0.7172113529376909, 0.7776981044453534, 0.9724416173890855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 216}], {
             RGBColor[
             0.7434083499065284, 0.5252723810458323, 0.4580470065820631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 255}], {
             RGBColor[
             0.43165774296703474`, 0.5471078244024314, 0.9490557746765065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 258}], {
             RGBColor[
             0.4187295668061743, 0.5359100880009214, 0.9482320027234739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 162}], {
             RGBColor[
             0.9588310572734952, 0.8681281277104613, 0.5263067793464253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 194}], {
             RGBColor[
             0.8061596900222359, 0.7500989808439875, 0.6144534337056413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 210}], {
             RGBColor[
             0.698996444284087, 0.6637676396684864, 0.6055600185754992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 218}], {
             RGBColor[
             0.9467517036363646, 0.8603082831521655, 0.5999961337585191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 226}], {
             RGBColor[
             0.9562854870849291, 0.8670754690193194, 0.5684934650954372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 227}], {
             RGBColor[
             0.9395091625151377, 0.7978810172888317, 0.27018585613847523`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 241}], {
             RGBColor[
             0.9562190222247212, 0.8670479840915544, 0.569594959834627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 290}], {
             RGBColor[
             0.9363623874102649, 0.7854051025986525, 0.2676538870247894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 291}], {
             RGBColor[
             0.9265943306289632, 0.845047396157727, 0.6262279650717502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.8545672117145955, 0.3449853666875312, 0.19687926573825648`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 159}], {
             RGBColor[
             0.3428661620319342, 0.4697766941100199, 0.9431273668629003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 168}], {
             RGBColor[
             0.3974514720884778, 0.5186742214563766, 0.9465462342423088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.4586241439822036, 0.5697734899723961, 0.9509650514168311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 191}], {
             RGBColor[
             0.31093411780431135`, 0.4362140910182484, 0.9413088841833633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 205}], {
             RGBColor[
             0.38342561820827703`, 0.5065257317852604, 0.945652519235638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 251}], {
             RGBColor[
             0.3400494072237743, 0.46681610621407393`, 0.942966956843591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 269}], {
             RGBColor[
             0.6838282108058124, 0.7186257518784704, 0.6483043769915192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 270}], {
             RGBColor[
             0.3036653348674415, 0.42857413928414156`, 0.9408949377483093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 271}], {
             RGBColor[
             0.3085633706783219, 0.433722285474784, 0.9411738736417443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 277}], {
             RGBColor[
             0.6937513555235839, 0.7517852121341029, 0.7135233421024703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 282}], {
             RGBColor[
             0.41756183526404816`, 0.5360928072628128, 0.9478276488009602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 171}], {
             RGBColor[
             0.1808430925709541, 0.30740793477935857`, 0.9336101186373109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 184}], {
             RGBColor[
             0.18701393581723674`, 0.31389388228526116`, 0.9339615390312422]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 222}], {
             RGBColor[
             0.20198183109515816`, 0.32962608924173, 0.9348139385243031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 248}], {
             RGBColor[
             0.20224840910221648`, 0.3299062796291701, 0.9348291197474383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 275}], {
             RGBColor[
             0.18135642915031058`, 0.30794748407168115`, 0.9336393523960919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 285}], {
             RGBColor[
             0.1911088793151014, 0.31819792753593046`, 0.9341947400055196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 186}], {
             RGBColor[
             0.19303082310645578`, 0.3202180123189185, 0.9343041918611762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 196}], {
             RGBColor[
             0.1980026870183727, 0.32544375652472224`, 0.9345873321557463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 207}], {
             RGBColor[
             0.189116703595207, 0.3161040245430854, 0.9340812885454315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 212}], {
             RGBColor[
             0.21315714444874106`, 0.34137205213213645`, 0.9354503560873951]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 214}], {
             RGBColor[
             0.19688801935015837`, 0.3242721701314169, 0.9345238534810445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 225}], {
             RGBColor[
             0.21027114178594725`, 0.3383386803504027, 0.9352860025052073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 265}], {
             RGBColor[
             0.20783074668686696`, 0.3357736703712833, 0.9351470256145558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 276}], {
             RGBColor[
             0.21715975035837445`, 0.34557904472303347`, 0.935678298572624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 168}], {
             RGBColor[
             0.3458261104083336, 0.4723404526223259, 0.943315972156065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 191}], {
             RGBColor[
             0.25930875612416715`, 0.38988032218419766`, 0.9380786220971196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 205}], {
             RGBColor[
             0.33180025652813283`, 0.4601919629512097, 0.9424222571493942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 212}], {
             RGBColor[
             0.2623047179263146, 0.3930292679932042, 0.9382492376896236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 225}], {
             RGBColor[
             0.2594187152635208, 0.38999589621147046`, 0.9380848841074358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 251}], {
             RGBColor[
             0.2884240455436301, 0.4204823373800232, 0.9397366947573472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 270}], {
             RGBColor[
             0.2520399731872973, 0.38224037045009085`, 0.9376646756620657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 271}], {
             RGBColor[
             0.2569380089981777, 0.38738851664073326`, 0.9379436115555007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 282}], {
             RGBColor[
             0.36593647358390397`, 0.4897590384287621, 0.9445973867147164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 176}], {
             RGBColor[
             0.19497852177206426`, 0.3222651671077009, 0.9344151104188206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 180}], {
             RGBColor[
             0.19532450559808373`, 0.32262881804548893`, 0.9344348136858753]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 193}], {
             RGBColor[
             0.23766407621559904`, 0.36713039124832314`, 0.9368459895967611]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 221}], {
             RGBColor[
             0.19098000658392586`, 0.31806247412446187`, 0.9341874008941293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 230}], {
             RGBColor[
             0.19392496192438957`, 0.3211578089082423, 0.9343551117440977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 232}], {
             RGBColor[
             0.19183608079529113`, 0.31896226239884673`, 0.9342361530540182]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 245}], {
             RGBColor[
             0.2105034515043503, 0.33858285259373117`, 0.935299232199999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 288}], {
             RGBColor[
             0.20231487113075944`, 0.32997613543510473`, 0.934832904661642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 296}], {
             RGBColor[
             0.1914857715941317, 0.31859406521754197`, 0.9342162034632482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 297}], {
             RGBColor[
             0.1938787777952211, 0.3211092664602433, 0.9343524816262648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 177}], {
             RGBColor[
             0.24681318446187503`, 0.3767466841021262, 0.9373670177764938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 244}], {
             RGBColor[
             0.19557921069497186`, 0.3228965292515542, 0.9344493187643406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 279}], {
             RGBColor[
             0.2191606879449377, 0.34768215699328187`, 0.9357922490080568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 280}], {
             RGBColor[
             0.2318337811627876, 0.36100238148576125`, 0.9365139629186521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 169}], {
             RGBColor[
             0.7980436197485294, 0.8403418316253028, 0.877535691789008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 181}], {
             RGBColor[
             0.9888211205061603, 0.9780593840975029, 0.5971500192561076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 202}], {
             RGBColor[
             0.9081632494131782, 0.6549039003842219, 0.40459878356064916`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 216}], {
             RGBColor[
             0.9080919042261215, 0.6545799385528897, 0.40453925138773855`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 227}], {
             RGBColor[
             0.9720263822129245, 0.9204431940139248, 0.5369240475267748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 228}], {
             RGBColor[
             0.7088026697373979, 0.7671572402491821, 0.8707133358632482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 299}], {
             RGBColor[
             0.8762453581797867, 0.42669348450426003`, 0.3747047266637896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 185}], {
             RGBColor[
             0.5753534134295759, 0.6661368462548543, 0.9597130747756251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 235}], {
             RGBColor[
             0.5148221170934733, 0.615777732139438, 0.9552841124586315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 274}], {
             RGBColor[
             0.5420984734158494, 0.6391389878337358, 0.9570951240808855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 292}], {
             RGBColor[
             0.6974329821497556, 0.7632343245346107, 0.9706993881593793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 298}], {
             RGBColor[
             0.44064408929894633`, 0.5470342917552059, 0.9507221073701924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 176}], {
             RGBColor[
             0.1880768897106564, 0.3150111142224146, 0.9340220726829731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 180}], {
             RGBColor[
             0.18842287353667586`, 0.3153747651602027, 0.9340417759500277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 187}], {
             RGBColor[
             0.2033506574299822, 0.3310648125082323, 0.9348918911590742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 221}], {
             RGBColor[
             0.184078374522518, 0.31080842123917557`, 0.9337943631582817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 230}], {
             RGBColor[
             0.1870233298629817, 0.313903756022956, 0.9339620740082502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 296}], {
             RGBColor[
             0.18458413953272382`, 0.31134001233225567`, 0.9338231657274008]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 297}], {
             RGBColor[
             0.18697714573381324`, 0.31385521357495705`, 0.9339594438904173]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 175}], {
             RGBColor[
             0.2002014223302363, 0.3277547667453615, 0.9347125468790196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 183}], {
             RGBColor[
             0.2052672821395783, 0.33307930659904317`, 0.9350010401008936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 224}], {
             RGBColor[
             0.21323098705618415`, 0.3414496653944509, 0.9354545613146487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 253}], {
             RGBColor[
             0.20482209384336109`, 0.3326113854731506, 0.9349756872860211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 262}], {
             RGBColor[
             0.26081704104435255`, 0.39146562526609985`, 0.9381645166920165]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 195}], {
             RGBColor[
             0.184909234384039, 0.31168170763319203`, 0.9338416793982484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 234}], {
             RGBColor[
             0.19012477797807242`, 0.3171635746350845, 0.9341386968902232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.21183524129599424`, 0.3399826481050988, 0.9353750756584267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 285}], {
             RGBColor[
             0.19288702957547718`, 0.3200668762008235, 0.9342960030323104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 168}], {
             RGBColor[
             0.6540467218133117, 0.5964674977433942, 0.5956559161356156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[
             0.8661367359765803, 0.45702825150686766`, 0.20890833900479755`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 202}], {
             RGBColor[
             0.8802744981433329, 0.5485728040784057, 0.22177612422766013`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.9224035575123126, 0.8121627962472151, 0.6179459955981152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 216}], {
             RGBColor[
             0.8802031529562763, 0.5482488422470734, 0.22171659205474953`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 237}], {
             RGBColor[
             0.8526104501055128, 0.35305929104558004`, 0.1959555523789085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 269}], {
             RGBColor[
             0.9404234605306463, 0.796419028165488, 0.2974140588848261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 277}], {
             RGBColor[
             0.9503466052484179, 0.8295784884211206, 0.3626330239957771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 282}], {
             RGBColor[
             0.674157084988882, 0.6138860835498305, 0.5969373306942671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 293}], {
             RGBColor[
             0.9037203948195764, 0.6547034053372311, 0.24132279457904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 203}], {
             RGBColor[
             0.6687682561638781, 0.7369332784725033, 0.9690249189979729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 205}], {
             RGBColor[
             0.3863855665846765, 0.5090894902975664, 0.9458411245288025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 212}], {
             RGBColor[
             0.31689002798285826`, 0.4419267953395609, 0.941668105069032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 225}], {
             RGBColor[
             0.31400402532006444`, 0.4388934235578272, 0.9415037514868442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 269}], {
             RGBColor[
             0.6867881591822118, 0.7211895103907764, 0.6484929822846838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 276}], {
             RGBColor[
             0.3208926338924916, 0.4461337879304579, 0.9418960475542608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 282}], {
             RGBColor[
             0.42052178364044757`, 0.5386565657751188, 0.9480162540941248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 293}], {
             RGBColor[
             0.650085093471142, 0.5794738875625195, 0.5924017179788976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 193}], {
             RGBColor[
             0.44215135474031986`, 0.5505814803014513, 0.9506292633518225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 200}], {
             RGBColor[
             0.4851546386974715, 0.5905268621408066, 0.9532706039694929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 202}], {
             RGBColor[
             0.7792934779313432, 0.5546715851773875, 0.4609259309301712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 227}], {
             RGBColor[
             0.7787217249901721, 0.7700947212036731, 0.6214147685810579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 228}], {
             RGBColor[
             0.5154980125146456, 0.6168087674389304, 0.9552040569175313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 264}], {
             RGBColor[
             0.450474457220526, 0.5593295887233245, 0.9511032517251437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 299}], {
             RGBColor[
             0.7473755866979517, 0.32646116929742564`, 0.43103187403331167`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 178}], {
             RGBColor[
             0.228293899528688, 0.35728174144686387`, 0.9363123718963757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 182}], {
             RGBColor[
             0.2259600378398488, 0.3548287048365162, 0.9361794619258352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 190}], {
             RGBColor[
             0.2009954787857768, 0.3285893704262217, 0.9347577672194614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 199}], {
             RGBColor[
             0.19798561422584082`, 0.3254258119372937, 0.9345863598854686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 261}], {
             RGBColor[
             0.22115645505495063`, 0.3497798347648488, 0.9359059049924991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 284}], {
             RGBColor[
             0.2192670906414149, 0.34779399297360003`, 0.9357983084842125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 184}], {
             RGBColor[
             0.1853189372548359, 0.31211233132706184`, 0.9338650113706392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 275}], {
             RGBColor[
             0.17966143058790973`, 0.3061659331134819, 0.9335428247354888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 285}], {
             RGBColor[
             0.18941388075270052`, 0.31641637657773114`, 0.9340982123449165]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 174}], {
             RGBColor[
             0.21189442021644855`, 0.34004484890265657`, 0.9353784458103991]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 238}], {
             RGBColor[
             0.18901379750666059`, 0.31599586371940025`, 0.9340754281959247]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 186}], {
             RGBColor[
             0.19720146830174806`, 0.32460162485334904`, 0.9345417039351314]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 213}], {
             RGBColor[
             0.20183100425593847`, 0.3294675606707361, 0.9348053491589379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 234}], {
             RGBColor[
             0.19772105404463286`, 0.3251477424127598, 0.9345712935745305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 249}], {
             RGBColor[
             0.20437181857140313`, 0.33213811761322165`, 0.9349500447754056]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 263}], {
             RGBColor[
             0.20558810816091344`, 0.33341651508901093`, 0.935019310668189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 286}], {
             RGBColor[
             0.2110888425781487, 0.3391981357282311, 0.9353325693556434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 235}], {
             RGBColor[
             0.3208493079592518, 0.4453409740728014, 0.9419209416251387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 238}], {
             RGBColor[
             0.21032414623090429`, 0.3383943913827284, 0.9352890210299346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 298}], {
             RGBColor[
             0.24667128016472487`, 0.3765975336885693, 0.9373589365366997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 183}], {
             RGBColor[
             0.18767445593923526`, 0.3145881308128762, 0.9339991546750381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 224}], {
             RGBColor[
             0.19563816085584113`, 0.3229584896082839, 0.9344526758887932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 253}], {
             RGBColor[
             0.18722926764301806`, 0.3141202096869836, 0.9339738018601655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 180}], {
             RGBColor[
             0.1945386218938126, 0.32180280444439524`, 0.9343900587715277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 187}], {
             RGBColor[
             0.20946640578711895`, 0.33749285179242483`, 0.9352401739805742]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 193}], {
             RGBColor[
             0.23687819251132788`, 0.36630437764722934`, 0.9368012346824135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 221}], {
             RGBColor[
             0.1901941228796547, 0.3172364605233681, 0.9341426459797817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 230}], {
             RGBColor[
             0.19313907822011844`, 0.32033179530714856`, 0.9343103568297502]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 245}], {
             RGBColor[
             0.20971756780007914`, 0.3377568389926374, 0.9352544772856515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 288}], {
             RGBColor[
             0.20152898742648828`, 0.32915012183401104`, 0.9347881497472945]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 296}], {
             RGBColor[
             0.19069988788986053`, 0.3177680516164482, 0.9341714485489008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 297}], {
             RGBColor[
             0.19309289409094996`, 0.3202832528591496, 0.9343077267119173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 194}], {
             RGBColor[
             0.4889886310377472, 0.5894215892292383, 0.9546385045000421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 226}], {
             RGBColor[
             0.6391144281004404, 0.7063980774045702, 0.908678535889838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 252}], {
             RGBColor[
             0.2649570005472917, 0.39581698519228203`, 0.9384002812611878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 268}], {
             RGBColor[
             0.24851062539069607`, 0.37853080214228807`, 0.9374636845262513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 279}], {
             RGBColor[
             0.2643192230897936, 0.3951466406470252, 0.9383639607784904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 280}], {
             RGBColor[
             0.27699231630764354`, 0.4084668651395046, 0.9390856746890857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 182}], {
             RGBColor[
             0.2566774713547828, 0.3871146750584845, 0.9379287743221401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 190}], {
             RGBColor[
             0.23171291230071078`, 0.36087534064819005`, 0.9365070796157662]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 199}], {
             RGBColor[
             0.2287030477407748, 0.357711782159262, 0.9363356722817735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 229}], {
             RGBColor[
             0.23836184028178953`, 0.36786378552268634`, 0.9368857262280812]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 261}], {
             RGBColor[
             0.2518738885698846, 0.38206580498681714`, 0.9376552173888041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 284}], {
             RGBColor[
             0.24998452415634886`, 0.38007996319556836`, 0.9375476208805174]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 205}], {
             RGBColor[
             0.44755823847840226`, 0.5601887588135859, 0.9502599417033248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 251}], {
             RGBColor[
             0.4041820274938994, 0.5204791332423994, 0.9475743793112779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 269}], {
             RGBColor[
             0.7479608310759376, 0.7722887789067958, 0.6529117994592061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 274}], {
             RGBColor[
             0.4929016619374462, 0.5991987999844676, 0.9532221708674471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 277}], {
             RGBColor[
             0.7578839757937091, 0.8054482391624284, 0.7181307645701571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 282}], {
             RGBColor[
             0.48169445553417334`, 0.5897558342911382, 0.9524350712686471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 289}], {
             RGBColor[
             0.383100677252795, 0.49832129750419296`, 0.9463738276021099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 187}], {
             RGBColor[
             0.20981238961313842`, 0.3378565027302129, 0.9352598772476289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 193}], {
             RGBColor[
             0.23722417633734735`, 0.3666680285850174, 0.9368209379494682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 215}], {
             RGBColor[
             0.2098131605219987, 0.33785731300430355`, 0.9352599211497481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 221}], {
             RGBColor[
             0.19054010670567417`, 0.3176001114611562, 0.9341623492468364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 230}], {
             RGBColor[
             0.1934850620461379, 0.3206954462449366, 0.9343300600968047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 233}], {
             RGBColor[
             0.20014010875548707`, 0.32769032229079487`, 0.9347090551616429]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 245}], {
             RGBColor[
             0.2100635516260986, 0.3381204899304254, 0.9352741805527061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 288}], {
             RGBColor[
             0.20187497125250775`, 0.32951377277179905`, 0.9348078530143491]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 296}], {
             RGBColor[
             0.19104587171588, 0.3181317025542363, 0.9341911518159554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 297}], {
             RGBColor[
             0.19343887791696943`, 0.3206469037969376, 0.9343274299789719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 201}], {
             RGBColor[
             0.8923407162696778, 0.5549387342539829, 0.2611343640187083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 202}], {
             RGBColor[
             0.9064784784364304, 0.6464832868255209, 0.2740021492415709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 203}], {
             RGBColor[
             0.961709527951959, 0.9590285203678879, 0.6962850331189814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 216}], {
             RGBColor[
             0.9064071332493737, 0.6461593249941886, 0.2739426170686603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 227}], {
             RGBColor[
             0.9694992257478029, 0.9078122736758734, 0.34102909604815745`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 258}], {
             RGBColor[
             0.6632277418204424, 0.717240503923456, 0.6720754184533696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 299}], {
             RGBColor[
             0.874560587203039, 0.4182728709455591, 0.2441080923447113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 190}], {
             RGBColor[
             0.22937905061187158`, 0.35842230403784237`, 0.9363741696452258]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 199}], {
             RGBColor[
             0.22636918605193562`, 0.35525874554891435`, 0.936202762311233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 229}], {
             RGBColor[
             0.23602797859295035`, 0.36541074891233866`, 0.9367528162575407]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 261}], {
             RGBColor[
             0.24954002688104543`, 0.37961276837646946`, 0.9375223074182637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 284}], {
             RGBColor[
             0.24765066246750966`, 0.3776269265852207, 0.937414710909977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 224}], {
             RGBColor[
             0.2007040206651831, 0.3282830294619655, 0.9347411691106672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 253}], {
             RGBColor[
             0.19229512745236005`, 0.31944474954066526`, 0.9342622950820396]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 222}], {
             RGBColor[
             0.2064576757790399, 0.33433048578943325`, 0.9350688312576314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 224}], {
             RGBColor[
             0.20007875304145373`, 0.32762583354516883`, 0.9347055610444963]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 248}], {
             RGBColor[
             0.20672425378609824`, 0.33461067617687346`, 0.9350840124807664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 275}], {
             RGBColor[
             0.18583227383419235`, 0.31265188061938454`, 0.9338942451294201]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 218}], {
             RGBColor[
             0.7483730046735189, 0.8020037075647066, 0.948265724399384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 235}], {
             RGBColor[
             0.4690251433139141, 0.5785976856950342, 0.951678806922862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 262}], {
             RGBColor[
             0.41669813660407123`, 0.5328210539055609, 0.9483611851595068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 292}], {
             RGBColor[
             0.6516360083701964, 0.726054278090207, 0.9670940826236099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 196}], {
             RGBColor[
             0.19808785672818557`, 0.32553327528980713`, 0.9345921824447229]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 214}], {
             RGBColor[
             0.19697318905997124`, 0.32436168889650174`, 0.9345287037700212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 249}], {
             RGBColor[
             0.20028634308592377`, 0.3278440238438759, 0.934717382990427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 265}], {
             RGBColor[
             0.2079159163966799, 0.33586318913636815`, 0.9351518759035322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 286}], {
             RGBColor[
             0.2070033670926693, 0.3349040419588854, 0.9350999075706646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 193}], {
             RGBColor[
             0.25215196023065367`, 0.38235807593304705`, 0.9376710531585147]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 215}], {
             RGBColor[
             0.224740944415305, 0.35354736035233314`, 0.9361100363587946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 228}], {
             RGBColor[
             0.32549861800497937`, 0.4485853630705261, 0.9422458467242234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 229}], {
             RGBColor[
             0.22122626051320093`, 0.3498532047273915, 0.9359098803100787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 230}], {
             RGBColor[
             0.20841284593944426`, 0.3363854935929662, 0.9351801753058513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 233}], {
             RGBColor[
             0.2150678926487934, 0.3433803696388245, 0.9355591703706895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 245}], {
             RGBColor[
             0.22499133551940492`, 0.35381053727845513`, 0.9361242957617526]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 288}], {
             RGBColor[
             0.2168027551458141, 0.3452038201198287, 0.9356579682233956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 296}], {
             RGBColor[
             0.20597365560918635`, 0.3338217499022659, 0.9350412670250019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 297}], {
             RGBColor[
             0.20836666181027574`, 0.33633695114496726`, 0.9351775451880184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 236}], {
             RGBColor[
             0.29364767479578224`, 0.42161628358526776`, 0.9401936825679285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 260}], {
             RGBColor[
             0.3070159863730502, 0.43566722665288543`, 0.9409549881356092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 261}], {
             RGBColor[
             0.30030042916823396`, 0.42860875023970424`, 0.9405725470875715]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 281}], {
             RGBColor[
             0.66716299452805, 0.7330554302274623, 0.9326197293964239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 294}], {
             RGBColor[
             0.445956916802145, 0.5584408477111231, 0.9502576320388609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 257}], {
             RGBColor[
             0.1999558217805158, 0.327496624995631, 0.9346985602910465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 260}], {
             RGBColor[
             0.23700170640282697`, 0.36643419857842796`, 0.936808268615812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 267}], {
             RGBColor[
             0.20602096440657885`, 0.33387147444787646`, 0.9350439611910263]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 287}], {
             RGBColor[
             0.22941840696730975`, 0.35846367006274493`, 0.9363764109314454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 300}], {
             RGBColor[
             0.22074088939765935`, 0.34934304891065115`, 0.9358822391430908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 199}], {
             RGBColor[
             0.2014046269978636, 0.3290194111386199, 0.9347810676048591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 261}], {
             RGBColor[
             0.2245754678269734, 0.353373433966175, 0.9361006127118898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 284}], {
             RGBColor[
             0.22268610341343767`, 0.3513875921749262, 0.9359930162036031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 205}], {
             RGBColor[
             0.29986821230051, 0.4266293598594382, 0.9406037744698572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 217}], {
             RGBColor[
             0.21370747825416658`, 0.3419504878548173, 0.9354816967834682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 225}], {
             RGBColor[
             0.22748667103589795`, 0.35643329311969896`, 0.9362664014278987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 246}], {
             RGBColor[
             0.2059132617802264, 0.3337582721588391, 0.9350378276857872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 251}], {
             RGBColor[
             0.25649200131600725`, 0.38691973428825177`, 0.9379182120778102]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 270}], {
             RGBColor[
             0.22010792895967446`, 0.34867776735831935`, 0.9358461929825286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 271}], {
             RGBColor[
             0.22500596477055484`, 0.35382591354896176`, 0.9361251288759636]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 278}], {
             RGBColor[
             0.21400334724237668`, 0.34226146492060344`, 0.9354985460846478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 282}], {
             RGBColor[
             0.3340044293562811, 0.4561964353369906, 0.9427789040351794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 295}], {
             RGBColor[
             0.21214976125282442`, 0.34031322852144436`, 0.9353929871046776]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 218}], {
             RGBColor[
             0.6489034320102649, 0.7179182155893853, 0.9413556495465901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 220}], {
             RGBColor[
             0.3318533670341157, 0.4618564399149144, 0.9423663809943715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 222}], {
             RGBColor[
             0.2760214326902352, 0.40542425430285495`, 0.93910442514248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 248}], {
             RGBColor[
             0.27628801069729353`, 0.4057044446902951, 0.9391196063656152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 262}], {
             RGBColor[
             0.31722856394081744`, 0.4487355619302395, 0.9414511103067129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 200}], {
             RGBColor[
             0.3225670309120143, 0.4511149836272068, 0.9418734544780243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 215}], {
             RGBColor[
             0.252152731139514, 0.38235888620713765`, 0.9376710970606339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 228}], {
             RGBColor[
             0.35291040472918833`, 0.4773968889253306, 0.9438069074260627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 230}], {
             RGBColor[
             0.2358246326636532, 0.3651970194477707, 0.9367412360076905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 245}], {
             RGBColor[
             0.2524031222436139, 0.38262206313325964`, 0.9376853564635919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 264}], {
             RGBColor[
             0.28788684943506876`, 0.4199177102097248, 0.939706102233675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 288}], {
             RGBColor[
             0.24421454187002306`, 0.3740153459746332, 0.9372190289252349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 210}], {
             RGBColor[
             0.5788422967306146, 0.6683006695271059, 0.9604448643230148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 226}], {
             RGBColor[
             0.8361313395314567, 0.8716084988779389, 0.9233783108429527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 241}], {
             RGBColor[
             0.8360648746712487, 0.8715810139501738, 0.9244798055821426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 280}], {
             RGBColor[
             0.4740092277386598, 0.5736772866128733, 0.9537854496422005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 290}], {
             RGBColor[
             0.8162082398567924, 0.7899381324572718, 0.622538732772305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 291}], {
             RGBColor[
             0.8064401830754907, 0.8495804260163464, 0.9811128108192658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 234}], {
             RGBColor[
             0.18893962070800485`, 0.3159178992009325, 0.934071203936976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 207}], {
             RGBColor[
             0.19417373721693681`, 0.32141928751397403`, 0.9343692791289782]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 212}], {
             RGBColor[
             0.2182141780704709, 0.3466873151030251, 0.9357383466709418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 214}], {
             RGBColor[
             0.20194505297188817`, 0.32958743310230554`, 0.9348118440645912]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 225}], {
             RGBColor[
             0.21532817540767707`, 0.3436539433212913, 0.935573993088754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 265}], {
             RGBColor[
             0.21288778030859679`, 0.34108893334217194`, 0.9354350161981024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 276}], {
             RGBColor[
             0.22221678398010425`, 0.35089430769392205`, 0.9359662891561706]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 198}], {
             RGBColor[
             0.9754663865596167, 0.9808663065126991, 0.9104194926535587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 204}], {
             RGBColor[
             0.7349750271013598, 0.7901370127560131, 0.9142536375891683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 226}], {
             RGBColor[
             0.9862994243091077, 0.9886024741101505, 0.8767175253588012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 243}], {
             RGBColor[
             0.9868796101505515, 0.9888423958656835, 0.8671023444932484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 254}], {
             RGBColor[
             0.6525617744919028, 0.7195772493628625, 0.9087750915707931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 283}], {
             RGBColor[
             0.646081244426157, 0.713693683071829, 0.9083720606763512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 204}], {
             RGBColor[
             0.7240997016369111, 0.7823833581016821, 0.9486564217578735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 226}], {
             RGBColor[
             0.975424098844659, 0.9808488194558194, 0.9111203095275062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 243}], {
             RGBColor[
             0.9760042846861029, 0.9810887412113525, 0.9015051286619535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 254}], {
             RGBColor[
             0.6416864490274542, 0.7118235947085315, 0.9431778757394982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 256}], {
             RGBColor[
             0.866815756563354, 0.4169101123137112, 0.4248082782495014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 283}], {
             RGBColor[
             0.6352059189617083, 0.705940028417498, 0.9427748448450561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 209}], {
             RGBColor[
             0.1894252090832627, 0.31642828337140966`, 0.9340988574765833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 229}], {
             RGBColor[
             0.20805355497894237`, 0.33600785601311617`, 0.9351597142171741]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 233}], {
             RGBColor[
             0.20189518711453486`, 0.32953502092454917`, 0.9348090042777849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 259}], {
             RGBColor[
             0.19177802866162308`, 0.31890124592564373`, 0.9342328470708863]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 261}], {
             RGBColor[
             0.22156560326703745`, 0.35020987547724697`, 0.9359292053778969]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 284}], {
             RGBColor[
             0.21967623885350168`, 0.3482240336859982, 0.9358216088696103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 210}], {
             RGBColor[
             0.4186246829308158, 0.5365148469090834, 0.9480331221442837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 211}], {
             RGBColor[
             0.31815152117452855`, 0.44647400293362227`, 0.9416219977306357]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 227}], {
             RGBColor[
             0.6591374011618665, 0.6706282245294286, 0.6126589597072597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 228}], {
             RGBColor[
             0.3959136886863399, 0.5173422707646859, 0.946448248043733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 231}], {
             RGBColor[
             0.2983755222047893, 0.4256881741456715, 0.9404957838452779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 245}], {
             RGBColor[
             0.2954064062007655, 0.4225674449726149, 0.9403266970812623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 264}], {
             RGBColor[
             0.3308901333922204, 0.45986309204908005`, 0.9423474428513454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 202}], {
             RGBColor[
             0.8524329734673737, 0.3954661457870175, 0.19750790475074864`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 203}], {
             RGBColor[
             0.8759510922102913, 0.5506721053262738, 0.4578210075797024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 216}], {
             RGBColor[
             0.8523973008738454, 0.3953041648713514, 0.19747813866429334`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 237}], {
             RGBColor[
             0.8386009494484636, 0.2977093892706047, 0.18459761882637282`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 269}], {
             RGBColor[
             0.8879643608891803, 0.5401762599384556, 0.244133049770843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 277}], {
             RGBColor[
             0.8945797907010281, 0.562282566775544, 0.2876123598448103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 293}], {
             RGBColor[
             0.8634956504151338, 0.4456991780529511, 0.2067388735669856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 299}], {
             RGBColor[
             0.8364740278506779, 0.2813609378470366, 0.18256087630231885`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 203}], {
             RGBColor[
             0.8900888543770439, 0.6422166578978118, 0.47068879280256504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 216}], {
             RGBColor[
             0.8665350630405979, 0.48684871744288943`, 0.21034592388715595`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 237}], {
             RGBColor[
             0.8527387116152162, 0.3892539418421428, 0.19746540404923543`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 269}], {
             RGBColor[
             0.902102123055933, 0.6317208125099938, 0.2570008349937056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 293}], {
             RGBColor[
             0.8776334125818863, 0.5372437306244892, 0.2196066587898482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 299}], {
             RGBColor[
             0.8506117900174305, 0.3729054904185747, 0.19542866152518146`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 216}], {
             RGBColor[
             0.8900175091899872, 0.6418926960664795, 0.4706292606296545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 237}], {
             RGBColor[
             0.8624248063392239, 0.4467031448649862, 0.4448682209538134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 255}], {
             RGBColor[
             0.651571481892223, 0.7220382969334023, 0.9679291557478935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 269}], {
             RGBColor[
             0.9551449948812127, 0.9368848088945971, 0.6707830617471834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 293}], {
             RGBColor[
             0.9184419291701429, 0.7951691860663403, 0.6146917974413972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 299}], {
             RGBColor[
             0.8581709631436525, 0.41400624201784997`, 0.4407947359057055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 226}], {
             RGBColor[
             0.734932739386402, 0.7901195256991334, 0.9149544544631159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 243}], {
             RGBColor[
             0.7355129252278461, 0.7903594474546665, 0.9053392735975632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 254}], {
             RGBColor[
             0.40119508956919725`, 0.5210943009518455, 0.9470120206751078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 283}], {
             RGBColor[
             0.3947145595034514, 0.515210734660812, 0.9466089897806659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 225}], {
             RGBColor[
             0.29997817143986366`, 0.426744933886711, 0.9406100364801734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 251}], {
             RGBColor[
             0.3289835017199729, 0.45723137505526373`, 0.9422618471300848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 269}], {
             RGBColor[
             0.6727623053020111, 0.7090410207196602, 0.647599267278013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 282}], {
             RGBColor[
             0.40649592976024684`, 0.5265080761040026, 0.947122539087454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 219}], {
             RGBColor[
             0.20337837440800324`, 0.33109394480949034`, 0.9348934695999689]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 254}], {
             RGBColor[
             0.27060222090313846`, 0.400822588016517, 0.9387557425033809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 283}], {
             RGBColor[
             0.26412169083739256`, 0.3949390217254835, 0.938352711608939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 212}], {
             RGBColor[
             0.20932819464730518`, 0.33734758312138824`, 0.935232303060627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 214}], {
             RGBColor[
             0.19305906954872248`, 0.3202477011206687, 0.9343058004542764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 225}], {
             RGBColor[
             0.20644219198451136`, 0.33431421133965444`, 0.9350679494784392]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 242}], {
             RGBColor[
             0.18509931747274389`, 0.3118814970113848, 0.9338525043489474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 244}], {
             RGBColor[
             0.18941015567136937`, 0.31641246128106837`, 0.9340980002070455]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 252}], {
             RGBColor[
             0.21362941037883332`, 0.3418684335680528, 0.935477250933459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 268}], {
             RGBColor[
             0.19718303522223768`, 0.3245822505180589, 0.9345406541985226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 279}], {
             RGBColor[
             0.21299163292133522`, 0.34119808902279597`, 0.9354409304507616]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 259}], {
             RGBColor[
             0.18280847530695815`, 0.30947367664736153`, 0.9337220442766032]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 211}], {
             RGBColor[
             0.3712058892361785, 0.49192848437614356`, 0.9451403247792249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 226}], {
             RGBColor[
             0.7289680937933078, 0.7852771577024377, 0.9144848957128108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 227}], {
             RGBColor[
             0.7121917692235163, 0.7160827059719499, 0.6161772867558488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 241}], {
             RGBColor[
             0.7289016289330998, 0.7852496727746727, 0.9155863904520005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 290}], {
             RGBColor[
             0.7090449941186435, 0.7036067912817707, 0.613645317642163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 291}], {
             RGBColor[
             0.6992769373373419, 0.7632490848408453, 0.9722193956891239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 231}], {
             RGBColor[
             0.25095672851015194`, 0.3811018116127316, 0.937602986480219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 264}], {
             RGBColor[
             0.28347133969758304`, 0.41527672951614025`, 0.9394546454862865]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 266}], {
             RGBColor[
             0.23444123912717205`, 0.36374298512871284`, 0.9366624537923354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 214}], {
             RGBColor[
             0.21709951040225656`, 0.3455157287097197, 0.9356748679962401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 225}], {
             RGBColor[
             0.23048263283804543`, 0.3595822389287055, 0.9364370170204028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 265}], {
             RGBColor[
             0.22804223773896515`, 0.3570172289495861, 0.9362980401297512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 276}], {
             RGBColor[
             0.23737124141047264`, 0.3668226033013362, 0.9368293130878194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 234}], {
             RGBColor[
             0.19826511451334394`, 0.3257195844608012, 0.9346022770133582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 249}], {
             RGBColor[
             0.2049158790401142, 0.33270995966126304`, 0.9349810282142335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 263}], {
             RGBColor[
             0.2061321686296245, 0.3339883571370523, 0.9350502941070169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 286}], {
             RGBColor[
             0.21163290304685975`, 0.3397699777762725, 0.935363552794471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 265}], {
             RGBColor[
             0.21177311264038245`, 0.33991734694886655`, 0.9353715375234006]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 276}], {
             RGBColor[
             0.22110211631188992`, 0.34972272130061666`, 0.9359028104814688]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 286}], {
             RGBColor[
             0.21086056333637188`, 0.3389581997713838, 0.9353195691905329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 229}], {
             RGBColor[
             0.2212270314220612, 0.34985401500148217`, 0.9359099242121978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 233}], {
             RGBColor[
             0.2150686635576537, 0.34338117991291517`, 0.9355592142728086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 259}], {
             RGBColor[
             0.20495150510474192`, 0.33274740491400967`, 0.9349830570659099]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 296}], {
             RGBColor[
             0.20597442651804665`, 0.33382256017635653`, 0.935041310927121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 237}], {
             RGBColor[
             0.8526673664281595, 0.38892998001081047`, 0.19740587187632483`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 269}], {
             RGBColor[
             0.9020307778688763, 0.6313968506786615, 0.25694130282079497`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 293}], {
             RGBColor[
             0.8775620673948297, 0.536919768793157, 0.2195471266169376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 299}], {
             RGBColor[
             0.8505404448303738, 0.37258152858724236`, 0.19536912935227085`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 223}], {
             RGBColor[
             0.19076430807847547`, 0.31783576131915836`, 0.9341751171833412]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 246}], {
             RGBColor[
             0.1922440281378487, 0.31939104092123016`, 0.9342593850516728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 247}], {
             RGBColor[
             0.19889732977739935`, 0.3263840827880864, 0.9346382807373675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 251}], {
             RGBColor[
             0.24282276767362948`, 0.3725525030506428, 0.9371397694436958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 270}], {
             RGBColor[
             0.20643869531729672`, 0.3343105361207104, 0.9350677503484142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 271}], {
             RGBColor[
             0.21133673112817714`, 0.3394586823113528, 0.9353466862418491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 278}], {
             RGBColor[
             0.20033411359999898`, 0.32789423368299453`, 0.9347201034505334]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 295}], {
             RGBColor[
             0.19848052761044668`, 0.32594599728383544`, 0.9346145444705631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 220}], {
             RGBColor[
             0.6501395047208716, 0.7189888396444919, 0.9414344110066938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 262}], {
             RGBColor[
             0.6355147016275733, 0.7058679616598169, 0.9405191403190352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 290}], {
             RGBColor[
             0.956800253470921, 0.9001474347654498, 0.6080814328251828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 292}], {
             RGBColor[
             0.8704525733936984, 0.8991011858444631, 0.9592520377831382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 250}], {
             RGBColor[
             0.1834940050025886, 0.3101942118225623, 0.933761084178619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 222}], {
             RGBColor[
             0.2772575054008418, 0.4064948783579615, 0.9391831866025837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 248}], {
             RGBColor[
             0.27752408340790014`, 0.40677506874540165`, 0.9391983678257189]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 262}], {
             RGBColor[
             0.318464636651424, 0.44980618598534605`, 0.9415298717668166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 230}], {
             RGBColor[
             0.18914056303198, 0.3161291023239095, 0.9340826473050587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 232}], {
             RGBColor[
             0.18705168190288157`, 0.31393355581451393`, 0.9339636886149794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 245}], {
             RGBColor[
             0.20571905261194073`, 0.33355414600939837`, 0.93502676776096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 288}], {
             RGBColor[
             0.19753047223834988`, 0.324947428850772, 0.9345604402226031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 296}], {
             RGBColor[
             0.18670137270172213`, 0.31356535863320917`, 0.9339437390242094]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 297}], {
             RGBColor[
             0.18909437890281156`, 0.31608055987591055`, 0.9340800171872259]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 248}], {
             RGBColor[
             0.22169214906401963`, 0.3503428831333422, 0.9359364119738274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 285}], {
             RGBColor[
             0.21055261927690455`, 0.33863453104010255`, 0.9353020322319088]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 246}], {
             RGBColor[
             0.1829700916045353, 0.3096435456231802, 0.9337312480856603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 247}], {
             RGBColor[
             0.18962339324408597`, 0.3166365874900364, 0.934110143771355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 270}], {
             RGBColor[
             0.19716475878398335`, 0.32456304082266046`, 0.9345396133824015]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 271}], {
             RGBColor[
             0.20206279459486376`, 0.3297111870133029, 0.9348185492758365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 278}], {
             RGBColor[
             0.1910601770666856, 0.31814673838494456`, 0.9341919664845209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 295}], {
             RGBColor[
             0.1892065910771333, 0.3161985019857855, 0.9340864075045505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 253}], {
             RGBColor[
             0.20025883236896588`, 0.32781510833607297`, 0.9347158162957947]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 262}], {
             RGBColor[
             0.2562537795699573, 0.3866693481290222, 0.9379046457017901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 265}], {
             RGBColor[
             0.22515623507617133`, 0.35398385716785236`, 0.9361336865475633]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 276}], {
             RGBColor[
             0.23448523874767882`, 0.3637892315196025, 0.9366649595056316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 241}], {
             RGBColor[
             0.9861906717339419, 0.9885575021255057, 0.8785198369719385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 243}], {
             RGBColor[
             0.9868373224355939, 0.9888249088088037, 0.8678031613671959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 290}], {
             RGBColor[
             0.9663340369194856, 0.9069146206326038, 0.576578764162101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 291}], {
             RGBColor[
             0.956565980138184, 0.9665569141916783, 0.9351528422090618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 241}], {
             RGBColor[
             0.9694143471641505, 0.9193630503950179, 0.5802122280149764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 290}], {
             RGBColor[
             0.9495577123496941, 0.837720168902116, 0.27827115520513895`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 291}], {
             RGBColor[
             0.9397896555683924, 0.8973624624611904, 0.6368452332520997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 299}], {
             RGBColor[
             0.8633640950075484, 0.3798620775565069, 0.20395744452515618`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 264}], {
             RGBColor[
             0.3612335072093944, 0.48614499734720384`, 0.9442808957993838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 233}], {
             RGBColor[
             0.2115539796555496, 0.3396870242879735, 0.9353590582240927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 259}], {
             RGBColor[
             0.2014368212026378, 0.32905324928906804`, 0.934782901017194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 284}], {
             RGBColor[
             0.22933503139451644`, 0.3583760370494225, 0.936371662815918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 245}], {
             RGBColor[
             0.20866400795240445`, 0.3366494807931788, 0.9351944786109285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 288}], {
             RGBColor[
             0.2004754275788136, 0.3280427636345524, 0.9347281510725716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 296}], {
             RGBColor[
             0.18964632804218584`, 0.3166606934169896, 0.9341114498741778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 297}], {
             RGBColor[
             0.19203933424327527`, 0.319175894659691, 0.9342477280371944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 232}], {
             RGBColor[
             0.20954424282732975`, 0.33757466345683984`, 0.9352446066848648]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 245}], {
             RGBColor[
             0.2282116135363889, 0.3571952536517242, 0.9363076858308454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 264}], {
             RGBColor[
             0.2636953407278438, 0.39449090072818943`, 0.9383284316009286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 266}], {
             RGBColor[
             0.21466524015743277`, 0.342957156340762, 0.9355362399069774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 240}], {
             RGBColor[
             0.184219115333836, 0.3109563487553536, 0.933802378139279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 245}], {
             RGBColor[
             0.206575126823306, 0.3344539342837832, 0.9350755199208491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 288}], {
             RGBColor[
             0.19838654644971515`, 0.32584721712515685`, 0.9346091923824922]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 297}], {
             RGBColor[
             0.18995045311417683`, 0.3169803481502954, 0.934128769347115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 259}], {
             RGBColor[
             0.1952784533382303, 0.32258041420050104`, 0.9344321910778048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[
             0.2158656276199601, 0.3442188396728392, 0.9356046001971543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 249}], {
             RGBColor[
             0.2008059288288086, 0.3283901414032867, 0.934746972629826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 263}], {
             RGBColor[
             0.20202221841831886`, 0.32966853887907605`, 0.9348162385226094]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 274}], {
             RGBColor[
             0.43577020330018756`, 0.5515998272739158, 0.9490608562281224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 298}], {
             RGBColor[
             0.33431581918328446`, 0.4594951311953859, 0.9426878395174293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 260}], {
             RGBColor[
             0.2447992469285118, 0.3746299080635468, 0.9372523270133223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 267}], {
             RGBColor[
             0.21381850493226368`, 0.3420671839329953, 0.9354880195885366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 294}], {
             RGBColor[
             0.38374017735760657`, 0.49740352912178454`, 0.9465549709165739]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 256}], {
             RGBColor[
             0.8226924771507464, 0.17542990005333894`, 0.16936364778802923`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 269}], {
             RGBColor[
             0.8744380750181129, 0.4362072994771681, 0.23118026314495393`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 277}], {
             RGBColor[
             0.8810535048299607, 0.45831360631425644`, 0.27465957321892126`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 281}], {
             RGBColor[
             0.8762036339901905, 0.45697937196631744`, 0.42154425983453325`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 293}], {
             RGBColor[
             0.8499693645440664, 0.3417302175916635, 0.19378608694109653`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 248}], {
             RGBColor[
             0.22976740900447992`, 0.35883049333181793`, 0.9363962860811601]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 258}], {
             RGBColor[
             0.28886880526886394`, 0.4180452286151569, 0.9398683740473033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 263}], {
             RGBColor[
             0.22373268173624067`, 0.3524876123490904, 0.9360526172908128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 285}], {
             RGBColor[
             0.21862787921736482`, 0.3471221412385783, 0.9357619063392415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 290}], {
             RGBColor[
             0.9662675720592777, 0.9068871357048387, 0.5776802589012907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 291}], {
             RGBColor[
             0.956499515277976, 0.9665294292639133, 0.9362543369482514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 250}], {
             RGBColor[
             0.18176798085569046`, 0.30838005100792065`, 0.933662789656877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 268}], {
             RGBColor[
             0.1929658134251674, 0.3201496830220325, 0.934300489656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 254}], {
             RGBColor[
             0.6530996726183891, 0.7197996840615158, 0.8998607275791879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 256}], {
             RGBColor[
             0.874424572290644, 0.42222750521570074`, 0.3959301794759612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 283}], {
             RGBColor[
             0.6466191425526432, 0.7139161177704824, 0.899457696684746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 279}], {
             RGBColor[
             0.21308524932289044`, 0.3412964857964532, 0.9354462617663373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 280}], {
             RGBColor[
             0.22575834254074034`, 0.3546167102889326, 0.9361679756769326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 264}], {
             RGBColor[
             0.26072622472382, 0.3913701715551329, 0.938159344836913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 288}], {
             RGBColor[
             0.2170539171587743, 0.34546780732004123`, 0.9356722715284729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 297}], {
             RGBColor[
             0.20861782382323596`, 0.3366009383451798, 0.9351918484930957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 270}], {
             RGBColor[
             0.19864447884335656`, 0.3261183204247322, 0.9346238812507333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 278}], {
             RGBColor[
             0.1925398971260588, 0.3197020179870163, 0.9342762343528525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 295}], {
             RGBColor[
             0.19068631113650653`, 0.3177537815878572, 0.9341706753728822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 251}], {
             RGBColor[
             0.24168185283923999`, 0.37135332922152087`, 0.9370747960317096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 270}], {
             RGBColor[
             0.20529778048290723`, 0.33311136229158844`, 0.935002776936428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 271}], {
             RGBColor[
             0.21019581629378764`, 0.33825950848223085`, 0.9352817128298629]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 278}], {
             RGBColor[
             0.19919319876560948`, 0.3266950598538726, 0.9346551300385472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 289}], {
             RGBColor[
             0.22060050259813557`, 0.34919549348331447`, 0.9358742443225416]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 295}], {
             RGBColor[
             0.1973396127760572, 0.3247468234547135, 0.9345495710585769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 285}], {
             RGBColor[
             0.21081919728396287`, 0.3389147214275427, 0.9353172134550438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 258}], {
             RGBColor[
             0.2738091064777124, 0.40221653034560445`, 0.9390107464799751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 263}], {
             RGBColor[
             0.20867298294508915`, 0.33665891407953785`, 0.9351949897234846]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 286}], {
             RGBColor[
             0.2141737173623244, 0.342440534718758, 0.9355082484109388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 270}], {
             RGBColor[
             0.24922321837913736`, 0.37927978255414485`, 0.9375042656427561]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 271}], {
             RGBColor[
             0.25412125419001774`, 0.38442792874478726`, 0.9377832015361911]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 278}], {
             RGBColor[
             0.24311863666183964`, 0.372863480116429, 0.9371566187448754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 282}], {
             RGBColor[
             0.363119718775744, 0.4867984505328162, 0.944436976695407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 289}], {
             RGBColor[
             0.26452594049436573`, 0.3953639137458709, 0.9383757330288698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 295}], {
             RGBColor[
             0.24126505067228732`, 0.3709152437172699, 0.9370510597649051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 268}], {
             RGBColor[
             0.22149590633125682`, 0.35013661957870057`, 0.9359252362405117]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 279}], {
             RGBColor[
             0.23730450403035436`, 0.36675245808343765`, 0.9368255124927507]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 280}], {
             RGBColor[
             0.2499775972482043, 0.3800726825759171, 0.937547226403346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 283}], {
             RGBColor[
             0.27188152915805053`, 0.4030951038026612, 0.9387946229216484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 283}], {
             RGBColor[
             0.3123013068939945, 0.44465097126766145`, 0.9411304437622906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 258}], {
             RGBColor[
             0.3530896957607064, 0.48025028048897034`, 0.9437195410822816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 286}], {
             RGBColor[
             0.2934543066453184, 0.4204742848621239, 0.9402170430132455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 269}], {
             RGBColor[
             0.8696737021648134, 0.3995862419652118, 0.22661789432004487`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 277}], {
             RGBColor[
             0.8762891319766611, 0.42169254880230017`, 0.2700972043940122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 281}], {
             RGBColor[
             0.8714392611368911, 0.42035831445436117`, 0.41698189100962424`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 293}], {
             RGBColor[
             0.8452049916907669, 0.30510916007970723`, 0.18922371811618746`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 267}], {
             RGBColor[
             0.19014093188722048`, 0.31718055341781604`, 0.9341396168314517]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 272}], {
             RGBColor[
             0.18158199985616474`, 0.30818457318554265`, 0.9336521983140883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 300}], {
             RGBColor[
             0.20486085687830097`, 0.33265212788059073`, 0.9349778947835161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 263}], {
             RGBColor[
             0.2750253960672227, 0.40349492782139373`, 0.9390800123727585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 286}], {
             RGBColor[
             0.28052613048445796`, 0.4092765484606139, 0.9393932710602128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 267}], {
             RGBColor[
             0.22718681650953165`, 0.35611812700061296`, 0.9362493251562173]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 287}], {
             RGBColor[
             0.25058425907026255`, 0.38071032261548143`, 0.9375817748966364]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 294}], {
             RGBColor[
             0.39710848893487455`, 0.5114544721894022, 0.9473162764842546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 300}], {
             RGBColor[
             0.24190674150061214`, 0.37158970146338766`, 0.9370876031082818]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 284}], {
             RGBColor[
             0.2428470796826115, 0.3725780565135533, 0.937141153976641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 292}], {
             RGBColor[
             0.5387777053242508, 0.6299185321853173, 0.9593474985432611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 286}], {
             RGBColor[
             0.2153900069518347, 0.3437189321945473, 0.9355775143037223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 288}], {
             RGBColor[
             0.2525376443502292, 0.38276345439650644`, 0.937693017298556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 276}], {
             RGBColor[
             0.23204484364859856`, 0.36122422154048306`, 0.93652598261498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 286}], {
             RGBColor[
             0.22180329067308052`, 0.3504597000112502, 0.9359427413240442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 272}], {
             RGBColor[
             0.18764714248222777`, 0.31455942263778813`, 0.9339975992140681]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 287}], {
             RGBColor[
             0.2196035170740144, 0.34814759848492993`, 0.9358174674718507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 300}], {
             RGBColor[
             0.210925999504364, 0.33902697733283615`, 0.935323295683496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 279}], {
             RGBColor[
             0.22085812887375872`, 0.34946627503344374`, 0.9358889157578143]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 280}], {
             RGBColor[
             0.23353122209160865`, 0.3627864995259231, 0.9366106296684096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 277}], {
             RGBColor[
             0.9830880426173179, 0.9543005010685027, 0.41547009014484526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 282}], {
             RGBColor[
             0.7068985223577822, 0.7386080961972126, 0.6497743968433352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 293}], {
             RGBColor[
             0.9364618321884765, 0.7794254179846133, 0.2941598607281082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 271}], {
             RGBColor[
             0.217737181833685, 0.3461859618148549, 0.9357111824409096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 278}], {
             RGBColor[
             0.20673456430550685`, 0.3346215131864966, 0.9350845996495938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 289}], {
             RGBColor[
             0.22814186813803294`, 0.35712194681593845`, 0.9363037139335881]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 295}], {
             RGBColor[
             0.20488097831595456`, 0.3326732767873375, 0.9349790406696236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 278}], {
             RGBColor[
             0.21163260011638724`, 0.339769659377139, 0.9353635355430288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 289}], {
             RGBColor[
             0.23303990394891333`, 0.36227009300658086`, 0.9365826498270231]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 295}], {
             RGBColor[
             0.20977901412683497`, 0.3378214229779799, 0.9352579765630585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 274}], {
             RGBColor[
             0.3509883555182567, 0.4717110997619036, 0.9438949792783465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 289}], {
             RGBColor[
             0.24118737083360547`, 0.370833597281629, 0.9370466360130092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 289}], {
             RGBColor[
             0.3532455749379125, 0.4740835804879391, 0.944023524585039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 281}], {
             RGBColor[
             0.9857363810754343, 0.9854586098022267, 0.7010160851792143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 282}], {
             RGBColor[
             0.7168216670755537, 0.7717675564528452, 0.7149933619542863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 293}], {
             RGBColor[
             0.946384976906248, 0.8125848782402458, 0.35937882583905917`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 295}], {
             RGBColor[
             0.1987763965986568, 0.3262569743496216, 0.9346313937717428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 280}], {
             RGBColor[
             0.24933981979070619`, 0.37940233803066026`, 0.9375109059206487]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 294}], {
             RGBColor[
             0.7572554970898742, 0.8088426757639791, 0.9389810177450694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 293}], {
             RGBColor[
             0.6701954566467123, 0.5968924733689558, 0.5936831325375491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 300}], {
             RGBColor[
             0.2343234420650949, 0.3636191729477046, 0.9366557454239152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 296}], {
             RGBColor[
             0.1980362372485557, 0.3254790199438521, 0.9345892427917222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 297}], {
             RGBColor[
             0.20042924344964513`, 0.3279942211865534, 0.9347255209547387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 291}], {
             RGBColor[
             0.9366428804635196, 0.8848865477710113, 0.6343132641384139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 297}], {
             RGBColor[
             0.18960014391301738`, 0.31661215096899065`, 0.934108819756345]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.032105813875877395`], {
             RGBColor[
             0.8186934053129894, 0.1446912815038851, 0.16553413207988746`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.032105813875877395`], {
             RGBColor[
             0.19859115798198185`, 0.32606227681868954`, 0.934620844706559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.032105813875877395`], {
             RGBColor[
             0.9542183694281502, 0.96537671539683, 0.9623805381832607]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.032105813875877395`], {
             RGBColor[
             0.2205376694136581, 0.34912945182257465`, 0.935870666065639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.032105813875877395`], {
             RGBColor[
             0.9710126878169619, 0.9138811308413543, 0.3418901952738247]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.032105813875877395`], {
             RGBColor[
             0.2105950138195758, 0.3386790903924193, 0.9353044465383967]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.032105813875877395`], {
             RGBColor[
             0.9383196861766793, 0.9535195034595876, 0.9892928618873055]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.032105813875877395`], {
             RGBColor[
             0.2044682273202984, 0.33223944932097826`, 0.9349555351110312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.032105813875877395`], {
             RGBColor[
             0.19896010530687766`, 0.32645006384976655`, 0.9346418557109033]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.032105813875877395`], {
             RGBColor[
             0.19040293767796423`, 0.3174559381160143, 0.9341545376736317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.032105813875877395`], {
             RGBColor[
             0.5318148081413353, 0.630790245090044, 0.9562855562801685]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.032105813875877395`], {
             RGBColor[
             0.42962012936485927`, 0.5465370955454517, 0.948595992638333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.032105813875877395`], {
             RGBColor[
             0.33328873930237535`, 0.463099687229773, 0.9424578416460552]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.032105813875877395`], {
             RGBColor[
             0.1801938510546308, 0.30672554078141306`, 0.9335731452934231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.032105813875877395`], {
             RGBColor[
             0.2583760710911756, 0.38890001107887695`, 0.9380255070642746]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.032105813875877395`], {
             RGBColor[
             0.24679037784549854`, 0.37672271290229153`, 0.9373657189734305]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.032105813875877395`], {
             RGBColor[
             0.7036631405833589, 0.768426260552445, 0.9710982238135836]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.032105813875877395`], {
             RGBColor[
             0.19997475001447043`, 0.3275165197696367, 0.9346996382259684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.032105813875877395`], {
             RGBColor[
             0.18771789764902583`, 0.31463379080422954`, 0.9340016286161444]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.032105813875877395`], {
             RGBColor[
             0.21900416978762977`, 0.3475176464861269, 0.9357833355305459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.032105813875877395`], {
             RGBColor[
             0.19357781768564236`, 0.320792938303103, 0.9343353423932549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.032105813875877395`], {
             RGBColor[
             0.18854143418810532`, 0.3154993799220345, 0.9340485278037318]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.032105813875877395`], {
             RGBColor[
             0.989346654985427, 0.9898625823050647, 0.82621702707199]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.032105813875877395`], {
             RGBColor[
             0.9237640134240451, 0.7354567479025522, 0.2575169395936321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.032105813875877395`], {
             RGBColor[
             0.1911156300253715, 0.31820502296044406`, 0.9341951244484827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.032105813875877395`], {
             RGBColor[
             0.2290956026577889, 0.35812438226646315`, 0.9363580277035645]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.032105813875877395`], {
             RGBColor[
             0.9698415036520304, 0.9099304516459211, 0.33734036595263717`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.032105813875877395`], {
             RGBColor[
             0.18347004528514485`, 0.31016902864039503`, 0.9337597197081559]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.032105813875877395`], {
             RGBColor[
             0.19525519293228838`, 0.32255596603906117`, 0.934430866432097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.032105813875877395`], {
             RGBColor[
             0.24929644188312317`, 0.37935674509947226`, 0.9375084356129837]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.032105813875877395`], {
             RGBColor[
             0.41964854701834464`, 0.537900212103202, 0.9479606122287372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.032105813875877395`], {
             RGBColor[
             0.9876761626712638, 0.9891717908034641, 0.8539014078132029]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.032105813875877395`], {
             RGBColor[
             0.20050642775524471`, 0.3280753467855062, 0.9347299164867587]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.032105813875877395`], {
             RGBColor[
             0.1836929464736069, 0.31040331192222026`, 0.933772413601086]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.032105813875877395`], {
             RGBColor[
             0.20639345636736367`, 0.33426298711601565`, 0.9350651740571405]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.032105813875877395`], {
             RGBColor[
             0.18133311757286624`, 0.3079229821257478, 0.9336380248362428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.032105813875877395`], {
             RGBColor[
             0.22656828106141946`, 0.3554680070272346, 0.9362141004774884]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.032105813875877395`], {
             RGBColor[
             0.18611948239069784`, 0.312953755022346, 0.9339106012318261]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.032105813875877395`], {
             RGBColor[
             0.20172422019829714`, 0.3293553238556548, 0.934799267964828]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.032105813875877395`], {
             RGBColor[
             0.6892336433588957, 0.7571538276524538, 0.9696600263815672]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.032105813875877395`], {
             RGBColor[
             0.1885946642534308, 0.31555532809567266`, 0.9340515591772053]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.032105813875877395`], {
             RGBColor[
             0.8376047344232163, 0.2900520440423452, 0.18364364219313192`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.032105813875877395`], {
             RGBColor[
             0.2255865897625529, 0.3544361872293025, 0.9361581946103001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.032105813875877395`], {
             RGBColor[
             0.31621931418873805`, 0.44831500913059213`, 0.9413701929717141]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.032105813875877395`], {
             RGBColor[
             0.29993474933268105`, 0.43258081688308847`, 0.9403922123095734]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.032105813875877395`], {
             RGBColor[
             0.2047087295239663, 0.33249223238575365`, 0.9349692313557391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.032105813875877395`], {
             RGBColor[
             0.18409960782193097`, 0.31083073878312756`, 0.9337955723632715]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.032105813875877395`], {
             RGBColor[
             0.1928098846058197, 0.31998579194643995`, 0.9342916097404141]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.032105813875877395`], {
             RGBColor[
             0.20962180710681122`, 0.3376561884324342, 0.9352490238558351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.032105813875877395`], {
             RGBColor[
             0.1818234123124711, 0.30843831298355445`, 0.9336659463963373]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.032105813875877395`], {
             RGBColor[
             0.8112967405816618, 0.8525104469167772, 0.981826135168235]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.032105813875877395`], {
             RGBColor[
             0.1987330571876369, 0.3262114218807623, 0.9346289256564001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.032105813875877395`], {
             RGBColor[
             0.21587739356825456`, 0.3442312064305009, 0.9356052702505034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.032105813875877395`], {
             RGBColor[
             0.24403688677483204`, 0.37382861920560384`, 0.937208911730381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.032105813875877395`], {
             RGBColor[
             0.20213692733288047`, 0.32978910522124555`, 0.9348227710255971]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.032105813875877395`], {
             RGBColor[
             0.19935669202797407`, 0.3268669016386893, 0.9346644407379722]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.032105813875877395`], {
             RGBColor[
             0.17967566298483006`, 0.30618089226503126`, 0.9335436352494385]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.032105813875877395`], {
             RGBColor[
             0.19114091674596853`, 0.31823160090706226`, 0.9341965644898124]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.032105813875877395`], {
             RGBColor[
             0.985007685890186, 0.9880683070777632, 0.8981249738722014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.032105813875877395`], {
             RGBColor[
             0.28726741181117993`, 0.4192666419924039, 0.9396708261773704]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.032105813875877395`], {
             RGBColor[
             0.2772592389822082, 0.4087474177943471, 0.9391008755405253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.032105813875877395`], {
             RGBColor[
             0.20167701950442632`, 0.3293057129336997, 0.9347965799551393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.032105813875877395`], {
             RGBColor[
             0.18288267188311363`, 0.3095516619532356, 0.9337262696618512]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.032105813875877395`], {
             RGBColor[
             0.2353045398184947, 0.3646503688917182, 0.9367116174895672]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.032105813875877395`], {
             RGBColor[
             0.3774633879291902, 0.5013615475879224, 0.9452726111944477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.032105813875877395`], {
             RGBColor[
             0.3863417480503173, 0.5090515368854881, 0.9458383324505404]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.032105813875877395`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.032105813875877395`], {
             RGBColor[
             0.8768566069289154, 0.9046456729993274, 0.9881165600196555]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.032105813875877395`], {
             RGBColor[
             0.20756886290590398`, 0.3354984139131004, 0.9351321117206522]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.032105813875877395`], {
             RGBColor[
             0.20976983040282712`, 0.33781177030176596`, 0.9352574535635624]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.032105813875877395`], {
             RGBColor[
             0.22331684544677569`, 0.35205054204331915`, 0.9360289360293025]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.032105813875877395`], {
             RGBColor[
             0.8294154563220671, 0.22710566399236717`, 0.1758015802350048]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.032105813875877395`], {
             RGBColor[
             0.1826688110543663, 0.3093268806626624, 0.9337140906040328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.032105813875877395`], {
             RGBColor[
             0.20590138873724428`, 0.3337457928378705, 0.935037151533554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.032105813875877395`], {
             RGBColor[
             0.3329293714790703, 0.46278842088357813`, 0.9424349430461306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.032105813875877395`], {
             RGBColor[
             0.3269177544061254, 0.4575814603276529, 0.9420518881221068]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.032105813875877395`], {
             RGBColor[
             0.4137826929511934, 0.5328195041366336, 0.9475868451945494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.032105813875877395`], {
             RGBColor[
             0.19413140389541048`, 0.3213747925089622, 0.9343668683089438]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.032105813875877395`], {
             RGBColor[
             0.18314084159618357`, 0.3098230146905773, 0.9337409720450827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.032105813875877395`], {
             RGBColor[
             0.9788084084452291, 0.9401779270427488, 0.37217509781633024`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.032105813875877395`], {
             RGBColor[
             0.8894648943465696, 0.5909677260051436, 0.2294791371904563]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.032105813875877395`], {
             RGBColor[
             0.6134396494628491, 0.6970569684320459, 0.962711362790644]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.032105813875877395`], {
             RGBColor[
             0.846552585818907, 0.35882915084310774`, 0.19221211479479816`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.032105813875877395`], {
             RGBColor[
             0.18746791982634672`, 0.31437104826308443`, 0.9339873927489519]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.032105813875877395`], {
             RGBColor[
             0.23214849009490668`, 0.36133316052711717`, 0.9365318851267661]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.032105813875877395`], {
             RGBColor[
             0.5941770672605392, 0.6814187364307716, 0.9611949417585145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.032105813875877395`], {
             RGBColor[
             0.9931480500222558, 0.9877526967730439, 0.4955857141352578]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.032105813875877395`], {
             RGBColor[
             0.22285845764454237`, 0.35156874739970667`, 0.9360028315220893]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.032105813875877395`], {
             RGBColor[
             0.3807443443279537, 0.5042033471148679, 0.9454816708349412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.032105813875877395`], {
             RGBColor[
             0.21567607897691587`, 0.34401961203092163`, 0.935593805682345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.032105813875877395`], {
             RGBColor[
             0.49015879412300467`, 0.5969720163279171, 0.9530062422656385]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.032105813875877395`], {
             RGBColor[
             0.8315546894535105, 0.24354874725857717`, 0.17785011229759332`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.032105813875877395`], {
             RGBColor[
             0.24113006344271598`, 0.3707733635803057, 0.9370433724418767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.032105813875877395`], {
             RGBColor[
             0.796888814031874, 0.8412548651917855, 0.9803900876994809]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.032105813875877395`], {
             RGBColor[
             0.28755638833203334`, 0.4195703746379904, 0.9396872829627306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.032105813875877395`], {
             RGBColor[
             0.20095046543520778`, 0.32854205854076235`, 0.9347552037757377]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.032105813875877395`], {
             RGBColor[
             0.44885816070930806`, 0.563200111364443, 0.9498218229840781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.032105813875877395`], {
             RGBColor[
             0.1790520430393593, 0.3055254281625532, 0.9335081210161069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.032105813875877395`], {
             RGBColor[
             0.19567419878950365`, 0.3229963677615002, 0.9344547281958019]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.032105813875877395`], {
             RGBColor[
             0.1806628381309981, 0.3072184759341732, 0.933599853413618]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.032105813875877395`], {
             RGBColor[
             0.6473280227603806, 0.724416838346381, 0.9654832657505968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.032105813875877395`], {
             RGBColor[
             0.19219534584531597`, 0.31933987274514264`, 0.9342566126671321]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.032105813875877395`], {
             RGBColor[
             0.4213296380105047, 0.5393562886265211, 0.9480677298602272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.032105813875877395`], {
             RGBColor[
             0.3350878162698179, 0.46465795727473413`, 0.9425724772395593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.032105813875877395`], {
             RGBColor[
             0.28384023029084227`, 0.41566445691867016`, 0.9394756532598479]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.032105813875877395`], {
             RGBColor[
             0.861860606843299, 0.8926882695866354, 0.9866862281444021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.032105813875877395`], {
             RGBColor[
             0.40847529455142584`, 0.5282225024003548, 0.9472486624616643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.032105813875877395`], {
             RGBColor[
             0.24068546665888524`, 0.3703060641714354, 0.9370180533127597]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.032105813875877395`], {
             RGBColor[
             0.9928111618057213, 0.9912952449090205, 0.7688011832034702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.032105813875877395`], {
             RGBColor[
             0.18591721951216156`, 0.3127411639127972, 0.9338990826601146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.032105813875877395`], {
             RGBColor[
             0.6142037164471443, 0.6976772724307221, 0.9627715129425172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.032105813875877395`], {
             RGBColor[
             0.18923133529375677`, 0.3162245097263307, 0.9340878166510814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.032105813875877395`], {
             RGBColor[
             0.2676326072490897, 0.3986292174791347, 0.9385526531046497]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.032105813875877395`], {
             RGBColor[
             0.23913206195702244`, 0.3686733373382309, 0.9369295892130448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.032105813875877395`], {
             RGBColor[
             0.3517287364030146, 0.47907148589714393`, 0.9436328219554587]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.032105813875877395`], {
             RGBColor[
             0.2873518174774419, 0.41935535769927346`, 0.9396756329551971]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.032105813875877395`], {
             RGBColor[
             0.1855098238772711, 0.3123129652701522, 0.9338758820813954]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.032105813875877395`], {
             RGBColor[
             0.1887209958010121, 0.3156881105620633, 0.9340587535719493]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.032105813875877395`], {
             RGBColor[
             0.18085158366002294`, 0.307416859452336, 0.933610602192272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.032105813875877395`], {
             RGBColor[
             0.27909030860477735`, 0.41067198806418675`, 0.939205152246706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.032105813875877395`], {
             RGBColor[
             0.22544944565233713`, 0.35429204007402687`, 0.9361503844561099]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.032105813875877395`], {
             RGBColor[
             0.18504035865818397`, 0.31181952755907755`, 0.93384914673168]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.032105813875877395`], {
             RGBColor[
             0.19860317371820202`, 0.3260749061192986, 0.9346215289849611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.032105813875877395`], {
             RGBColor[
             0.1859244664032461, 0.3127487808548065, 0.9338994953598411]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.032105813875877395`], {
             RGBColor[
             0.8351944719959239, 0.27152571084244637`, 0.18133557217075477`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.032105813875877395`], {
             RGBColor[
             0.22348836128871713`, 0.3522308160679321, 0.9360387036027661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.032105813875877395`], {
             RGBColor[
             0.34883524619319184`, 0.47656529010844195`, 0.9434484513179017]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.032105813875877395`], {
             RGBColor[
             0.8449402545684014, 0.34643606632366236`, 0.19066814456844627`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.032105813875877395`], {
             RGBColor[
             0.18908769389738214`, 0.3160735335113504, 0.9340796364860563]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.032105813875877395`], {
             RGBColor[
             0.9118031822514008, 0.6880360380137298, 0.24789297407533079`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.032105813875877395`], {
             RGBColor[
             0.22940782651350908`, 0.3584525493349609, 0.9363758083902539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.032105813875877395`], {
             RGBColor[
             0.19689631111946682`, 0.3242808853066886, 0.9345243256850401]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.032105813875877395`], {
             RGBColor[
             0.18528931800943133`, 0.31208119962217307`, 0.9338633245984311]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.032105813875877395`], {
             RGBColor[
             0.24479905803441923`, 0.3746297095238789, 0.9372523162560832]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.032105813875877395`], {
             RGBColor[
             0.21307650899259664`, 0.34128729915514544`, 0.9354457640174572]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.032105813875877395`], {
             RGBColor[
             0.39261549520966454`, 0.5144855413472138, 0.9462380900718772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.032105813875877395`], {
             RGBColor[
             0.26153416243522165`, 0.3922193653160256, 0.9382053556943405]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.032105813875877395`], {
             RGBColor[
             0.231287806205471, 0.36042852718880986`, 0.9364828704525304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.032105813875877395`], {
             RGBColor[
             0.4407231525670485, 0.5561539761890157, 0.9493034674587586]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.032105813875877395`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.032105813875877395`], {
             RGBColor[
             0.2938477713702168, 0.42618301710784506`, 0.940045567919488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.032105813875877395`], {
             RGBColor[
             0.8299355921400753, 0.23110365581454728`, 0.17629966288173887`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.032105813875877395`], {
             RGBColor[
             0.3068945586163886, 0.4398960177176607, 0.9407885631521654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.032105813875877395`], {
             RGBColor[
             0.19763991012936863`, 0.32506245501299574`, 0.9345666725485978]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.032105813875877395`], {
             RGBColor[
             0.8649038628242013, 0.8951148792988238, 0.9869764966166072]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.032105813875877395`], {
             RGBColor[
             0.20002902465321373`, 0.3275735658561667, 0.9347027290863527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.032105813875877395`], {
             RGBColor[
             0.21339775345539977`, 0.34162494745362687`, 0.9354640584143752]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.032105813875877395`], {
             RGBColor[
             0.2462972527349853, 0.37620440714520426`, 0.9373376362279]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.032105813875877395`], {
             RGBColor[
             0.895503807139292, 0.6183890185729798, 0.2345181540520019]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.032105813875877395`], {
             RGBColor[
             0.9074094141907081, 0.6706162117894943, 0.24435764515870567`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.032105813875877395`], {
             RGBColor[
             0.5978280581771518, 0.684382775332144, 0.9614823611374906]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.032105813875877395`], {
             RGBColor[
             0.1825195240294396, 0.3091699705341204, 0.9337055889288136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.032105813875877395`], {
             RGBColor[
             0.22106916700115545`, 0.3496880894859278, 0.9359009340669666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.032105813875877395`], {
             RGBColor[
             0.4972976140125026, 0.6027676319143825, 0.9535682363176986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.032105813875877395`], {
             RGBColor[
             0.9263138375757084, 0.7455659509853682, 0.2595685879581257]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.032105813875877395`], {
             RGBColor[
             0.3944915237120784, 0.5161104629440706, 0.9463576289491441]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.032105813875877395`], {
             RGBColor[
             0.18253809113335498`, 0.30918948573755783`, 0.933706646297914]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.032105813875877395`], {
             RGBColor[
             0.19294565339664288`, 0.32012849355383366`, 0.9342993415721996]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.032105813875877395`], {
             RGBColor[
             0.29124080035179, 0.42344292527596916`, 0.9398971047766567]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.032105813875877395`], {
             RGBColor[
             0.19576440547633542`, 0.32309118070879467`, 0.9344598653331682]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.032105813875877395`], {
             RGBColor[
             0.2016546493170191, 0.3292822004483829, 0.9347953060060602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.032105813875877395`], {
             RGBColor[
             0.9913482769712819, 0.9906903044355545, 0.7930449707347249]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.032105813875877395`], {
             RGBColor[
             0.6211503872091352, 0.7033168926992579, 0.9633183803113946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.032105813875877395`], {
             RGBColor[
             0.18196114135351968`, 0.30858307493822207`, 0.9336737898614731]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.032105813875877395`], {
             RGBColor[
             0.21779424853057935`, 0.34624594253152846`, 0.935714432304875]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.032105813875877395`], {
             RGBColor[
             0.18609439165410657`, 0.312927383067344, 0.9339091723514956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.032105813875877395`], {
             RGBColor[
             0.9076820231617462, 0.6716970155181059, 0.2445769927357579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.032105813875877395`], {
             RGBColor[
             0.4004114204648772, 0.5212379799686826, 0.9467348395354733]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.032105813875877395`], {
             RGBColor[
             0.6047389625257771, 0.6899933588150511, 0.9620264128432912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.032105813875877395`], {
             RGBColor[
             0.19757646601375403`, 0.32499577122489554`, 0.9345630595000708]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.032105813875877395`], {
             RGBColor[
             0.17914809400855325`, 0.30562638382115925`, 0.9335135909767078]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.032105813875877395`], {
             RGBColor[
             0.19058407149220488`, 0.3176463212393284, 0.9341648529763892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.032105813875877395`], {
             RGBColor[
             0.20128694378722742`, 0.32889571862269473`, 0.9347743657201101]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.032105813875877395`], {
             RGBColor[
             0.23320476894069225`, 0.36244337656598474`, 0.9365920386444091]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.032105813875877395`], {
             RGBColor[
             0.18260859612989327`, 0.30926359095919453`, 0.9337106614531641]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.032105813875877395`], {
             RGBColor[
             0.19419263806779313`, 0.3214391535066072, 0.9343703555044731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.032105813875877395`], {
             RGBColor[
             0.29197171960673096`, 0.42421116775586953`, 0.9399387295469274]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.032105813875877395`], {
             RGBColor[
             0.25901133304362195`, 0.3895677116688322, 0.9380616842926806]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.032105813875877395`], {
             RGBColor[
             0.5227567642523288, 0.6234365170007214, 0.9555724738845179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.032105813875877395`], {
             RGBColor[
             0.19488460571983207`, 0.32216645538218325`, 0.9344097620385824]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.032105813875877395`], {
             RGBColor[
             0.9862939640410388, 0.9654284637594515, 0.4012550677774902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.032105813875877395`], {
             RGBColor[
             0.2543436096659436, 0.38466163844813683`, 0.9377958643515997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.032105813875877395`], {
             RGBColor[
             0.19274031574857725`, 0.3199126706665578, 0.9342876478969121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.032105813875877395`], {
             RGBColor[
             0.1914897805011185, 0.3185982788329645, 0.9342164317645705]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.032105813875877395`], {
             RGBColor[
             0.5295564396500168, 0.6289567998104505, 0.9561077692398556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.032105813875877395`], {
             RGBColor[
             0.19311599281626868`, 0.32030753108400334`, 0.9343090421501528]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.032105813875877395`], {
             RGBColor[
             0.22474017350644473`, 0.35354655007824254`, 0.9361099924566755]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.032105813875877395`], {
             RGBColor[
             0.35586441424032067`, 0.4826536021746064, 0.9438963436902155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.032105813875877395`], {
             RGBColor[
             0.21583585429987417`, 0.3441875460256914, 0.935602904650621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.032105813875877395`], {
             RGBColor[
             0.2044144915577996, 0.3321829696275479, 0.9349524749388519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.032105813875877395`], {
             RGBColor[
             0.2273767118965443, 0.3563177190924262, 0.9362601394175826]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.032105813875877395`], {
             RGBColor[
             0.3306172943235091, 0.4607858158598078, 0.9422876195342679]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.032105813875877395`], {
             RGBColor[
             0.27956374695486264`, 0.41116960178785156`, 0.939232113860354]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.032105813875877395`], {
             RGBColor[
             0.6860055424687634, 0.754632010702607, 0.9693382794531569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.032105813875877395`], {
             RGBColor[
             0.18372407711397143`, 0.31043603219904004`, 0.9337741864450011]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.032105813875877395`], {
             RGBColor[
             0.2030597206401025, 0.3307590194956109, 0.934875322739293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.032105813875877395`], {
             RGBColor[
             0.9863417120240653, 0.9886199611670301, 0.8760167084848537]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.032105813875877395`], {
             RGBColor[
             0.964591061095168, 0.9731126518583681, 0.9448222768222637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.032105813875877395`], {
             RGBColor[
             0.19839476243792764`, 0.32585585264969186`, 0.9346096602708663]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.032105813875877395`], {
             RGBColor[
             0.3655703148691659, 0.4910603654665621, 0.9445147950956946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.032105813875877395`], {
             RGBColor[
             0.8453640923839973, 0.3496938695012485, 0.19107401213931735`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.032105813875877395`], {
             RGBColor[
             0.8665707356341262, 0.4870106983585556, 0.21037568997361125`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.032105813875877395`], {
             RGBColor[
             0.9371250918628792, 0.9526285769763242, 0.9913149984604726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.032105813875877395`], {
             RGBColor[
             0.4836083421786542, 0.5916540643449961, 0.9524905666934831]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.032105813875877395`], {
             RGBColor[
             0.3723597127044757, 0.4969410006264502, 0.9449474095221317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.032105813875877395`], {
             RGBColor[
             0.22242260484653656`, 0.35111063847433904`, 0.9359780103500293]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.032105813875877395`], {
             RGBColor[
             0.18528775379377113`, 0.3120795555323372, 0.9338632355186633]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.032105813875877395`], {
             RGBColor[
             0.18931653926981418`, 0.3163140645074111, 0.9340926688914699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.032105813875877395`], {
             RGBColor[
             0.1804556557285978, 0.30700071409312746`, 0.9335880546823002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.032105813875877395`], {
             RGBColor[
             0.4716790509924657, 0.5819693283516046, 0.9515514491928728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.032105813875877395`], {
             RGBColor[
             0.2707327274798912, 0.4018876404006824, 0.9387292003655769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.032105813875877395`], {
             RGBColor[
             0.23336863550083925`, 0.36261561071043924`, 0.9366013706025906]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.032105813875877395`], {
             RGBColor[
             0.20237506472464956`, 0.3300394027187775, 0.9348363325977657]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.032105813875877395`], {
             RGBColor[
             0.20083038530367384`, 0.32841584670900015`, 0.9347483653898895]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.032105813875877395`], {
             RGBColor[
             0.22474171532416531`, 0.3535481706264238, 0.9361100802609137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.032105813875877395`], {
             RGBColor[
             0.8664637178535413, 0.48652475561155717`, 0.21028639171424535`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.032105813875877395`], {
             RGBColor[
             0.20003824461178885`, 0.32758325661720833`, 0.9347032541493537]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.032105813875877395`], {
             RGBColor[
             0.9671895696970209, 0.9750506153189628, 0.9404236795589124]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.032105813875877395`], {
             RGBColor[
             0.18433414396946993`, 0.31107725114464163`, 0.9338089288499086]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.032105813875877395`], {
             RGBColor[
             0.33308943974472227`, 0.4629270639700209, 0.9424451424544752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.032105813875877395`], {
             RGBColor[
             0.1861956076915163, 0.31303376754012907`, 0.9339149364550904]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.032105813875877395`], {
             RGBColor[
             0.2214255710569613, 0.35006269274590207`, 0.9359212307506922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.032105813875877395`], {
             RGBColor[
             0.1814903715451621, 0.30808826602110845`, 0.9336469802173286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.032105813875877395`], {
             RGBColor[
             0.20866772558178895`, 0.33665338825737323`, 0.9351946903244223]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.032105813875877395`], {
             RGBColor[
             0.2275966301752516, 0.35654886714697176`, 0.936272663438215]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.032105813875877395`], {
             RGBColor[
             0.9862571365941499, 0.9885849870532707, 0.8774183422327487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.032105813875877395`], {
             RGBColor[
             0.952704487454567, 0.8501960835922951, 0.28080312431882476`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.032105813875877395`], {
             RGBColor[
             0.426257062503514, 0.5436241760628097, 0.9483817009917713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.032105813875877395`], {
             RGBColor[
             0.2177123475199571, 0.3461598593765405, 0.9357097681634818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.032105813875877395`], {
             RGBColor[
             0.19208551837244375`, 0.31922443710768994`, 0.9342503581550272]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.032105813875877395`], {
             RGBColor[
             0.23118072954041266`, 0.36031598282478083`, 0.9364767725948611]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.032105813875877395`], {
             RGBColor[
             0.18790775611424687`, 0.3148333440888988, 0.9340124407748683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.032105813875877395`], {
             RGBColor[
             0.20539561179114207`, 0.3332141891994065, 0.9350083482847035]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.032105813875877395`], {
             RGBColor[
             0.1941551643020383, 0.3213997662028249, 0.9343682214289508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.032105813875877395`], {
             RGBColor[
             0.40849384697781144`, 0.528238571579618, 0.9472498446058684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.032105813875877395`], {
             RGBColor[
             0.23143093535124384`, 0.3605789649959291, 0.9364910214456416]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.032105813875877395`], {
             RGBColor[
             0.8250746635773962, 0.19374042880931708`, 0.17164483220048377`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.032105813875877395`], {
             RGBColor[
             0.1874435235211163, 0.31434540619947215`, 0.9339860034154601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.032105813875877395`], {
             RGBColor[
             0.23757609093788187`, 0.36703791314285356`, 0.9368409789653577]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.032105813875877395`], {
             RGBColor[
             0.18053047455342514`, 0.3070793534218085, 0.9335923155036896]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.032105813875877395`], {
             RGBColor[
             0.986124206873734, 0.9885300171977407, 0.8796213317111282]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.032105813875877395`], {
             RGBColor[
             0.18088209567567362`, 0.3074489295153584, 0.9336123398064248]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.032105813875877395`], {
             RGBColor[
             0.9874175082770378, 0.9890648305643368, 0.8581879805016432]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.032105813875877395`], {
             RGBColor[
             0.1895037720729246, 0.31651085805472556`, 0.934103331522621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.032105813875877395`], {
             RGBColor[
             0.22524249753236514`, 0.35407452447866766`, 0.9361385990668298]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.032105813875877395`], {
             RGBColor[
             0.1844498116639085, 0.31119882522525194`, 0.9338155159539919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.032105813875877395`], {
             RGBColor[
             0.19775641494300986`, 0.32518490895896446`, 0.9345733073253814]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.032105813875877395`], {
             RGBColor[
             0.22195872707107797`, 0.35062307352078237`, 0.9359515931969625]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.032105813875877395`], {
             RGBColor[
             0.20745669335557887`, 0.3353805166037485, 0.9351257238307011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.032105813875877395`], {
             RGBColor[
             0.18265386603570732`, 0.30931117250048296`, 0.9337132395073293]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.032105813875877395`], {
             RGBColor[
             0.28560729073547014`, 0.4175217494840773, 0.9395762847380378]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.032105813875877395`], {
             RGBColor[
             0.23794228148785246`, 0.3674228026286945, 0.9368618329754481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.032105813875877395`], {
             RGBColor[
             0.19184993915614282`, 0.3189768284147727, 0.9342369422671671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.032105813875877395`], {
             RGBColor[
             0.31878183695974033`, 0.45053453755869494`, 0.9415334746567325]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.032105813875877395`], {
             RGBColor[
             0.3660178719215669, 0.49144801689048034`, 0.9445433130353144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.032105813875877395`], {
             RGBColor[
             0.817928104297447, 0.13880884254138265`, 0.16480127896312016`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.032105813875877395`], {
             RGBColor[
             0.18407578926115742`, 0.31080570396557056`, 0.9337942159314718]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.032105813875877395`], {
             RGBColor[
             0.340161519599846, 0.46905254408746033`, 0.942895769129249]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.032105813875877395`], {
             RGBColor[
             0.18516129488531852`, 0.3119466392015956, 0.9338560338709061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.032105813875877395`], {
             RGBColor[
             0.25816755850577977`, 0.38868085113116446`, 0.938013632581003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.032105813875877395`], {
             RGBColor[
             0.24473644409614725`, 0.3745638983048021, 0.9372487504849276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.032105813875877395`], {
             RGBColor[
             0.3038398335581257, 0.4366853080006712, 0.9406146010791581]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.032105813875877395`], {
             RGBColor[
             0.20988927253459944`, 0.3379373115553272, 0.935264255616268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.032105813875877395`], {
             RGBColor[
             0.2962099519152749, 0.42866581863159803`, 0.9401800906069961]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.032105813875877395`], {
             RGBColor[
             0.22271583997709107`, 0.35141884718873295`, 0.9359947096569118]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.032105813875877395`], {
             RGBColor[
             0.1981497507744529, 0.3255983298567432, 0.9345957072190938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.032105813875877395`], {
             RGBColor[
             0.1962060745132835, 0.32355540287006146`, 0.9344850177314316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.032105813875877395`], {
             RGBColor[
             0.20504953117466115`, 0.3328504365287066, 0.9349886395055752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.032105813875877395`], {
             RGBColor[
             0.9731648978995463, 0.9211410408128702, 0.3502511250338943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.032105813875877395`], {
             RGBColor[
             0.2128391460228046, 0.3410378156242125, 0.9354322465474746]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.032105813875877395`], {
             RGBColor[
             0.2226352176445654, 0.3513341080054973, 0.9359901183343445]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.032105813875877395`], {
             RGBColor[
             0.17908821045117204`, 0.30556344240551475`, 0.9335101806967048]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.032105813875877395`], {
             RGBColor[
             0.2389301514139497, 0.3684611165555936, 0.9369180907063167]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.032105813875877395`], {
             RGBColor[
             0.46304655962256364`, 0.5749610829682137, 0.9508718678503764]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.032105813875877395`], {
             RGBColor[
             0.1801747671672662, 0.30670548240580453`, 0.9335720584942697]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.032105813875877395`], {
             RGBColor[
             0.24137384732010603`, 0.3710295958922332, 0.9370572555730482]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.032105813875877395`], {
             RGBColor[
             0.9930111873350895, 0.9874599613241353, 0.4806890552557963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.032105813875877395`], {
             RGBColor[
             0.2006299825882091, 0.3282052107487807, 0.934736952751713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.032105813875877395`], {
             RGBColor[
             0.23666672657285628`, 0.3660821135381808, 0.9367891920100534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.032105813875877395`], {
             RGBColor[
             0.2620129130085561, 0.39272256252313964`, 0.938232619831244]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.032105813875877395`], {
             RGBColor[
             0.9784615748157791, 0.9834572582803182, 0.9213431151026323]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.032105813875877395`], {
             RGBColor[
             0.4406321468160179, 0.5560751515815551, 0.9492976686527762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.032105813875877395`], {
             RGBColor[
             0.3058207768282486, 0.438767404976628, 0.9407274128678487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.032105813875877395`], {
             RGBColor[
             0.24095771526907575`, 0.3705922147223045, 0.9370335574683543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.032105813875877395`], {
             RGBColor[
             0.1996796674968478, 0.327206369334303, 0.9346828337131252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.032105813875877395`], {
             RGBColor[
             0.22089074136906994`, 0.34950055283376746`, 0.9358907729911765]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.032105813875877395`], {
             RGBColor[
             0.2430009596347453, 0.3727397940997984, 0.9371499172122699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.032105813875877395`], {
             RGBColor[
             0.20886533678518346`, 0.33686109016141486`, 0.9352059439901159]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.032105813875877395`], {
             RGBColor[
             0.2434445902532613, 0.3732060780076645, 0.9371751813197018]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.032105813875877395`], {
             RGBColor[
             0.9464109372448213, 0.8252442542119368, 0.27573918609145315`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.032105813875877395`], {
             RGBColor[
             0.926874823682218, 0.9445288413300859, 0.9928873421853748]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.032105813875877395`], {
             RGBColor[
             0.773715577090376, 0.8231517563699634, 0.978080396007364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.032105813875877395`], {
             RGBColor[
             0.8997587664774066, 0.6377097951563564, 0.23806859642232206`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.032105813875877395`], {
             RGBColor[
             0.5360494193639693, 0.63422809324764, 0.9566189203875064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.032105813875877395`], {
             RGBColor[
             0.19692281060910452`, 0.3243087379504625, 0.9345258347917725]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.032105813875877395`], {
             RGBColor[
             0.18720713771192796`, 0.31409694972628927`, 0.9339725415933283]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.032105813875877395`], {
             RGBColor[
             0.19199315011410678`, 0.319127352211692, 0.9342450979193615]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.032105813875877395`], {
             RGBColor[
             0.2601377913887575, 0.39075169081115385`, 0.9381258344289902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.032105813875877395`], {
             RGBColor[
             0.8186938987840391, 0.1446950745386128, 0.16553460462832187`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.032105813875877395`], {
             RGBColor[
             0.2256459244954445, 0.3544985517956109, 0.9361615736355604]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{3.8349502435193233`*^9, 3.8350088067170744`*^9, 
  3.8350238880784955`*^9, 3.835051773848199*^9},
 CellLabel->
  "Out[402]=",ExpressionUUID->"055b12a9-2093-4f81-a97c-fd831fceb1b8"]
}, Open  ]],

Cell["Estimated with absolute Mean Deviation v Calculated: (r=6)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 
  3.8349503922098827`*^9}},ExpressionUUID->"78321c96-d7fe-44b0-a813-\
6f26c9628ff4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphin3", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsi3", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}], 
     "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"AMDi6300", ",", "kri3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502409842243`*^9}, {3.8349504019691753`*^9, 3.834950402221115*^9}, {
   3.8350088129883285`*^9, 3.8350088201560917`*^9}},
 CellLabel->
  "In[152]:=",ExpressionUUID->"c2bb2bca-6101-4600-b8d2-7e236ff07ccf"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1FO4EAYYBuBzsm2dTrZdW7WsZbtVy3bLtWxr2bat5WVjyzZXrfc8u3i/
//a7+f7gJu2rtAsMCAjIJEJuKEIThrCEIzwRiEgkIhOFqEQjOjGISSxiE4e4
xCM+CUhIIhKThKQkI4jkBJOClKQiNWlISzrSk4GMIX3JTBayko3s5CAnuchN
HvKSj/wUoCCF+IEfKUwRivITxShOCUpSitKUoSzlKE8FfqYilahMFapSjerU
oCa1qE0d6lKP+jSgIY1oTBN+oSnNaM6vtKAlrWhNG9rSjvZ0oCOd6EwXutKN
7vSgJ73ozW/0oS/96M8ABjKIwQzhd4YyjOGMYCSjGM0YxjKO8UxgIpOYzBSm
Mo3pzGAms5jNH8xhLvOYzwIWsojFLGEpy1jOClayitWsYS3rWM8GNrKJzWxh
K9vYzg52sovd7GEv+9jPAQ5yiMMc4U+OcozjnOAkpzjNX5zhLOc4zwUuconL
XOEq17jODW5yi9v8zT/c4S73uM8DHvKIxzzhKc94zgte8orXvOEt73jPBz7y
ic/8yxe+8o3/CBl/IKEITRjCEo7wRCAikYhMFKISjejEICaxiE0c4hKP+CQg
IYlITBKSkowgkhNMClKSitSkIS3pSE8GMgb+/6++Az6VhWw=
          "], {Null, CompressedData["
1:eJxN2guYllWBB/D3qyhJJoMEhjQEkUhkrd1Es1FL08DywkWybEVNDSyNClNB
EwWFrQAlLl4YuUwas+aqQJgbq4DKUtKWYgKWGnghRCZKVGBhab//nt887vP4
f34PMN+5n/Oe9xt7f23MsG+9q6qqsw6oqnhCPfPr+UQ9V9czqZ5p9dxezxv1
nFHP8/UMqKdTrfx9fIPj6m6r58B6ZtdzaD1n1zOsnmXKPqj+c8P9+xX1zGXK
Ham+Zj/b7OfTjjX19FdWf+U9rr58Zru8p/7zY+tOruc0bY7j+Di36e8oZY6S
1Pvhejbp/6OS+j/u7z7u7w5Q1gHKP+D/lbtZeZuVuVm7+9ZKfXEkRzHj0qdW
xiSmvCnKnuLzLcasRZaZr8+rt1V/WtXfahxbtaNVNjP1Hl53l2S876/7ej1d
67lWuWfKMI7ifLZyM1Nuxn6l+V0pz5v7OZKfy5+rWvlzTPL3HY11R3Pc0Ryn
PRPUM0FbJkgz57OVaVf61b9W+tbf+H5OHuc249CtVsYiZj0fUivrPqa8Fepa
oa4Vspn57ArlvEvdmadL5GrrZYQ1FM/gCHM+wryP0K7Uv0+y3/Zpz3FV2YPH
+bfj/Ptx/v1k6yOO5VxmnWW9PyCbtKtnrdTb076OUzi4Kmt1sLkdrLzByst4
jZbUf4v+x9eZ8c94X6X/V8njbD9HrlTOldI+DyfKPqa/2R8NtbIuGuyrBvPV
YH3FZrYy661B+mr/fvXuV+9+Sf3vrdu5Vtq9w7ztME87tH+HOdyhL/Eyfb/M
eFxmPC4zHjkve9XKmRknM2fOobVy5sQ1PNU8nGoeTlX+qcrNOA2y7gYZp0Gy
j53Uu6Uq9W2RXvbvHbKSzzP9yXqYJ5vN16XadKmM5pWczf08xLwNkdmcw2Zm
joaYr5h5Sr9Ol0uYfZX9dmxV1vWxcgvv5+vsr/6jnLuxhcv4aWMTN3ALe9lf
z1Rlj8WxzHh8UobzUo7mlZzN/TzEvCxQTzybk7lAOxZoR+a7sVbmOQ7iPmau
Y8qfrk3TZTbnMOOd8RlTlfUUr+AY4zmmemeddVdvd/V2V2939XaXRufi29LN
en66KvM53jiON5/jze14cxvzvDpedrGb82l9Vdbjeulpv870uZmyi53N/9qq
nBtxGEexlcuYZB3GvjzK+C+uyjjEQUz2MWOx2LgsNi+pf6p6p0oLl3EtU+9U
9U6t3lmfd0vWQ8prq8o+iSM5lXO4lm3mu035bcrvrKzOyuisjM7al3W/rirn
fhzLuUyeYR/n/U+rcm7Gq5g8zm3M+XJ0VZ71R5vTo81pzHmT8+m2qqzL22QZ
V/J5przsx9VVWf9xOC/ldM5msp/Zj4363KjPjepu1OdG49Koz4363Wiecn+5
uSp3mphzv4vnUhf3kpg1GftWZU3F43giB/F2LuY+dvL57mz0XNup/zv1f6f+
x9GcztlczZ3GY6f1stO4dDIXnYx1J/PQyTx0Mg+dzEMHc9FBWzpoSwdt6aAN
HbShgzZ0UHcH9WfdL6/KeRjvZrKBW9jLOCysyjmz0FguNJbxdF7CqzmeC43z
QuO60LjmXDmnKufQObKCb3MXcy+M3XyuX618rp+/7+d8jG9zF/PZ2I3vtsbi
yRzMsZzLFq5j1mXNWNbMQxzC4ZzO2ZzD1WzjTlbuDburck/YbQ3stgZ2WwO7
1d1dGjmAgzmcc7ma69jHPeiIWtmLcQwz309VZe88ZZ7j7Uze4D5m3zxlftOf
Hu4bcSRncw7bmA/Er1Zlb3/V+MVbOIevs7Of78L295Jnq3JextM4guM4hck2
9nTO3CQ3czvzfpz3un/KmlJ2PIMjeBXv4E/5OLdxB3dbO0v1a6m+xmYmeb4s
1d+vVGVM4yRO43a+x8/18Bw/pir75hg5nudwJncxe+YY4xz7Kec65Vzn566T
mdzFzu6Zn5FBPJ23cyGzdnJvO9L5FM/mZC7g3VzOLcxZdaT9/VhV1nls5ACe
yJM5mMM5l4uZrGsvq1bsYzwGGo+BxmOgXMeZ3MWM60Dj87W6H6qVfr9QlX7H
szmZC3g3ky1Mn1/Q/7Osh/go1/BpHmpe3jTub5qbN81NvIRX83Yu5FNMst/f
NC659/6kKudK/Cov4xhO5y1MXmfWdzyC2de5tzxRlTtNnMdkPXOvyXz0tl57
G+d4HWdyKXcxc9Lb/aG3O0R8T1XOlDiC4ziF8/gs17OncX5/rdzL4yW8muP5
DLNuX6nKM+gV8x9buJwPV+X7hribH3I+/bYqZ1QczSuZ7Gf7/ePcquyP2J+D
eQaTKziVt3EuW7iMa5n7W+69Q5U/VEZyKlu4jGvZxpx/sS9Tbs7YF/U/ruTz
fNH4pN5FVXlPiUM4lMM4ilOZtHIt25j2LNKelD+jKutzhnpmqGeG8mcoP05g
0sz5XMRWrmUbU++M6p33jIn6N1F/JhrbiTKVLVzEtWxjyo092JcZ59y7763K
+REn8WYmj3IND9W+U6SFy7mBWc95Dl5flWdqPIPJHVzJ5/kidzDznPo+Jv15
CodyJCdyKlu04zztOE87zpOreD3v4E/5OF/kNu5g2pfvVb5YlXMynspkDG/h
T/g6j7Bf76zK+orDOILnchTH8TYmy5j5z9Wrq3tanM4ZnM05bOYiLmUbU2Bs
YFf3utj+vfQ/yFc4kpN4E6dxO3OfiT2U8+2qrMtvyyTexJt5Lx81/jfKA3yY
m+r5VFXuRfEcruDb3MU8M2I39uOsqpwDcQKTZs5nK1dwM1PuLOXOUm7uB3+t
yr0g5n5+eVXuM/E4nshBTBbzKe7jfubeHruzkYfYv0uqsj/iWZzEabyXS4xz
XMNDtf/BqtxvHtSPOJkLeDeT5XyBW5j7Tsx9J+N8QVX2wwUyihM4g7PYzPls
5Qpu5kHeY26oyvtWHMJkOmdzDlezjTuZwmIDuzLrOeW/VJX7amzkAH6Sgzmc
l3IuF/MxruY6vqQ9sY/3ph9V5X72I7mFP+HrzN0odmF/981XzfOr5iyu4QYm
h7pPnVSV+9xJMoXz+ATXczNznzqiKms93s6n+AaznrPP+8iNfICbqtLui2UN
n+YGvsr2dr+vVu6CsR8/x9M4gldxHKfwWW7jDibpX+p7zTi+pm2vadNr2hR7
VuVuF6/ldra/pw6olT/H0byW+ZkB5q9DreznOI33cgkf5RomhzqHf1yVczl+
nN/mJN7EmzmNyb1M+/Me9aeqnKPxeJ7D5G3uYvZp7MZ+7v17lRMv4ATOYjPn
cylXcBf3qmevemJvtn+fdECtvE/GsZzMZ/gKk5xj+X3LPVVZr/dYn/FYfpE3
MnmAm6qyLg+ulf10sPMwnsQzeQFHcQKncB5b+QTXczPfX3mnqcq7YxzE03kJ
r+Z4LuSbfL/1c6H1c6H1c6F8mzfxZv6Y25m1nPe+86vy3hcH8qtMLuOPOJM5
12IX9jafL1flHI6DeS6v4FjOZQuXcR2TnLfxKPvzC1XZn1+Qa5n+xAHOnYPk
aJ7Ak3gmh3EUJ3AK57GVT3A9NzPzHHt6/l9Tlef/NeYpfoUjmUziNN7LJXyU
OTti+/vBRcqPp3AoR/Iin40TuYQp7yLl5Tn6m6p8Rx4H8JO8lKN5Oa/kaiYv
cSf3s/33i7dW5R4TJzNZwAf5Arfwr8wZEHvxSOVuVe5WP7dVmVuVtVX+ynx+
q89n/FZVZV2u0q5VPr9Km+JyJhv4Crcw7Vul/Ky931VlzcV5fILJemYdZV4f
Mq/xLF7Ei3kNJ3Ea7+USJo9yDV9l5v8h839wVe4AsS8H8DieyEG8nLdzMZ/i
PnZSfnc22sePVGUfxy/wWibZzzH7OWfnD6vynIif53gm6/gM3+/e89/6EN9g
nh/3VeV5cZ/c7+9/UZXnSuzDG3kPH2Cyyc+/t1Z+Pn6RY3gPV/J5bmJyhHOr
o3Oko/XT0fOpo+dTR8+njp5LHT2POnoedfQc6ug51NFzKCYHM+dUF23voq9d
9LWLvnbR1y76Gh/mJr7XefTrqqzb2J9DOJTDOJITOZUzuIjLmKxlG/M+ELuy
L4/yvO0mn+Bn+Hmezkt4NcdzId9k1lP6tVF/NupPPJcTOZUzeCdbuIjL+Guu
5Ub93KifG/Vvo/7V/6v+syrndjyQ3flJDuelvIHTOZurmfyGL3En9zOVx0M8
77+h3tjIkzmYyVjOZQsf4zo+w5eZ8zT2cc6/VZX34Xg2x3Iyb+UCPsjlXMUX
uIVb+ZZ6Yy+2/36kybg36XeTfscBbNL3JnPQpC9N+t+k303GvsnYNhmHJuPf
ZBya9P+oqjyr4lm8iBdzCR/iGm7gq3yNHZR7qHO55h4Vr+UjTD7IAfb9R2vl
fhO/wpG8hhM5jduZMz72YNb196tybnxfbuBETudszuEitnEnU2hsYFf2YF/n
7e+rct7GE3gSz+QFHMUJnMf5bOUT/B2T9dzMnMUx53K+p/yg9OMZPI/X8zbe
wZV8ni9yB/M9au7336zK/T6ez+RHnMk5bOZS7mXu/7ELuzLvAdkPf6jK97Rx
MK/gGM7lSv5B+2OeKzHPxY9UZY3Gs3gxJ/FeLuFDfJRr+DRfZQflZ/1nPx8m
fTmATTyRJ3MQF/MxruNLzP0nNjL7Ob/HvMuc3mUu75KH+SJ3M7+vajCXDeaw
wZw0mL8G89Zg3hrMWzzI5zuzC7sy85fz9edVOU/jAt7NB5ks5ypu4Avcwtf4
FnOuxiPdc75Xlf32PZnHJ/g7/p7ruZnZR/Fg50gv/e0lQ/hNfp83cDpncDbn
sJmLuJRtTKX/Vye7sq9x/UCtfE8Tj+FAforncBabOZ8r+Ce+zV3cy+QgdmNv
tn/v8reqrPfYyMPYxJM5mMP5Dc7lY1zHl/gyk/bf+3+0KuPwUTmGA3k8r+NM
7mL6kfOsd1Xun73la7yed/AuPswXuZsfMv7fkllcwT/xbWY8Y/s4Hl4r94HD
nR+HO/8Ot89jEwdzOL/BKziXj3Ed/8CX+DL/xqSP5/GTVbmHx/4cynM5khdx
IqeyhYu4jL9mspYb2cas/9iXua/m+9/PVuX5FvsxOY1ncATP41Ucx2e5jTuY
74JjT/vtw/ZfPIFncggv4ChO4AzOYjPncxFbuZQruJcZi9iVScYl75l/qcr7
Z7yP9zPj9C79iafxDA7jCJ7LcbyNd3IZdzB5H3tax7+qyn6P3+BYTuYqJuv4
DF/mK3yLuUd/R1nfUVa8lQv4IJdzFX/FV/gW28vtxSOtsw/I55j1kv+v449V
+R4g/pZJvg/IufTlqpwv8RgOZHI+v8nrOJN5nsYubP//YH5ZlXb9UnviQTyJ
UziPyRNczzzfYuYr36P8S1XOm3gY+3IAm3giB/FSXs5kMR/jav6G6/gS97W3
oVZs/17nsFr5Xid+gaN5Ja/lI8x7wGGS94oeVXnXi5/m2fwOJ/NWLuCD/Dlf
4BZu5Vvspb6sn7xHf7cq/fiu9RJHM7mSv+FvuZ95L06bP1YrbYp380H+nMu5
gS9wC9O2j8mRzo2vV+U7m9iHxzK5h/fxAf6COV+yLv+tKusyfoCf5ed4Gkdw
HKcw+SWf5TbmfIlZr2nfv1flfSB+kWN4C3/C5A98nXkfiHkfyPvmf1TlfTOO
5DWcxGlMtjNrLXZgD37UvjqyKt8bxr480lqIl/N2PsU/8g3+N/exk/Ngj3Hf
Y9z3GPc9xnuP8d5jvPcY7z3GdY8x32PM9xjzPZIzfY/x32P831eVu0A8gWdy
CIdyGEdxAidyKmfwTi5iK5fx13ySa7mRbWzQzg+zL48ybn/3c/EgnslhHMFR
HMcpvJNr+Xfj9XfjlP31P1W5V8YPsw+/zht5Dx/gL7iJuY99qSr3sXgKhzIZ
yYt4DSdyKlu4hA/xSWY9x7zH5v5wSFXuoYdIfw7mubyCU3kb7+RctnAZn+Ra
buTLPMo97AdVeZ7Ggfwyz+c3mcxkM5dyBXdxL/NOEw9iZ3Zjb+a+3rvuz6ry
rhDvYvIwP2Qd/KMcy6/zFt7H+/kX5v/vyPvJR9QX+/E0nsev8Spezzt4F3/K
n/FF7uBu5nuMd9fKdyXxYq7h09zAV/ka6/9V/1yV95nYi0OYfJ83cDpncw6X
so07mUpiA7uyh3vDge4N8UJey5v4CLcz30ce6B5xoHyQhzH3irx3Pmc9Pmc9
xk/xeJ7DH3AWVzD5E9/mLu5l1uVz1uVz1uNz1Tvvjf9alfMhfoyn8Ev8Dsdy
MluYrOKv+CRf5ivMfTke5Vz9L/MbT+CZHMILOIoTOIOz2Mz5bOVSrmCymXuZ
dRBz7p9c989V+R3Nn/X/z/off8hb+Ss+w2Qr32L6HfP7m/8FjHdEAw==
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[72, 227] -> 
             RGBColor[
              0.9014234283390617, 0.9233263703109247, 0.9589712344562489], 
             UndirectedEdge[132, 236] -> 
             RGBColor[
              0.8017988801815835, 0.8452575794036739, 0.9808351782628155], 
             UndirectedEdge[187, 193] -> 
             RGBColor[
              0.7649234379755101, 0.8162832704706979, 0.9772040777476054], 
             UndirectedEdge[196, 225] -> 
             RGBColor[
              0.9913552909111139, 0.9906932048799251, 0.792928731600214], 
             UndirectedEdge[39, 166] -> 
             RGBColor[
              0.9337194767695196, 0.9487439843041545, 0.9504585523102389], 
             UndirectedEdge[7, 216] -> 
             RGBColor[
              0.8556372865577655, 0.8866947126772484, 0.918431050682091], 
             UndirectedEdge[92, 281] -> 
             RGBColor[
              0.6283144085866429, 0.6914604827872606, 0.7620972712265432], 
             UndirectedEdge[99, 229] -> 
             RGBColor[
              0.9820573039101479, 0.9860158708955116, 0.9097448774625472], 
             UndirectedEdge[187, 296] -> 
             RGBColor[
              0.7668967350304362, 0.8178248251276192, 0.9774007575565311], 
             UndirectedEdge[100, 244] -> 
             RGBColor[
              0.6914835972013595, 0.758911508694469, 0.9698842807535699], 
             UndirectedEdge[232, 245] -> 
             RGBColor[
              0.8124161894154333, 0.8519685525826122, 0.8769290055547871], 
             UndirectedEdge[6, 52] -> 
             RGBColor[
              0.7995348731207037, 0.844241483579695, 0.9804098159308159], 
             UndirectedEdge[113, 160] -> 
             RGBColor[
              0.9758013802050047, 0.9792802614570282, 0.8155206538849965], 
             UndirectedEdge[176, 288] -> 
             RGBColor[
              0.5762753138919149, 0.6426215626526508, 0.9315167487445255], 
             UndirectedEdge[187, 228] -> 
             RGBColor[
              0.8517223397925717, 0.8838639555609447, 0.9283625130665529], 
             UndirectedEdge[61, 268] -> 
             RGBColor[
              0.9713296217423791, 0.9774865592997113, 0.904231191337188], 
             UndirectedEdge[51, 101] -> 
             RGBColor[
              0.8943831942908742, 0.9177680701723665, 0.9602201848906625], 
             UndirectedEdge[207, 214] -> 
             RGBColor[
              0.712932851163354, 0.7743165523838782, 0.9733163291852017], 
             UndirectedEdge[17, 162] -> 
             RGBColor[
              0.8198336340388261, 0.8595475294493873, 0.9537129550462875], 
             UndirectedEdge[20, 279] -> 
             RGBColor[
              0.8218148140352257, 0.8609382126704149, 0.9459616053905088], 
             UndirectedEdge[51, 197] -> 
             RGBColor[
              0.7128580108414304, 0.7731188217359313, 0.9440694054050702], 
             UndirectedEdge[86, 94] -> 
             RGBColor[
              0.7257634137785298, 0.780410239284594, 0.8007517708065532], 
             UndirectedEdge[55, 114] -> 
             RGBColor[
              0.9462962395063182, 0.8787975557877206, 0.6153755829718868], 
             UndirectedEdge[13, 270] -> 
             RGBColor[
              0.9176243752811755, 0.937038608476376, 0.9880464588539006], 
             UndirectedEdge[151, 220] -> 
             RGBColor[
              0.9675003137003653, 0.9321458422972198, 0.6202479984587974], 
             UndirectedEdge[117, 225] -> 
             RGBColor[
              0.9808953768174733, 0.98462068377223, 0.8880388631435482], 
             UndirectedEdge[13, 277] -> 
             RGBColor[
              0.8120588239897344, 0.8539626840262924, 0.9776858335846645], 
             UndirectedEdge[81, 237] -> 
             RGBColor[
              0.9729172919326643, 0.9556523731111466, 0.6524022843232902], 
             UndirectedEdge[172, 174] -> 
             RGBColor[
              0.8571159347930857, 0.8877289366552311, 0.9130959799124432], 
             UndirectedEdge[128, 197] -> 
             RGBColor[
              0.7253037916150795, 0.7794301770556904, 0.7509725078428957], 
             UndirectedEdge[44, 71] -> 
             RGBColor[
              0.8789418543208826, 0.9063083926671494, 0.9883154527774237], 
             UndirectedEdge[70, 122] -> 
             RGBColor[
              0.8995112910788727, 0.9176340322503003, 0.7080313301206002], 
             UndirectedEdge[42, 293] -> 
             RGBColor[
              0.9127288328596703, 0.7836368910414045, 0.6140372207929843], 
             UndirectedEdge[154, 181] -> 
             RGBColor[
              0.9893351606166123, 0.9898578290881681, 0.8264075185097224], 
             UndirectedEdge[42, 216] -> 
             RGBColor[
              0.8101011597233523, 0.7025786314773679, 0.6040430365854571], 
             UndirectedEdge[125, 130] -> 
             RGBColor[0.9797150586045, 0.981865347393773, 0.7824158480332477],
              UndirectedEdge[173, 263] -> 
             RGBColor[
              0.9433223856381503, 0.9569067139772223, 0.9689050237602388], 
             UndirectedEdge[112, 132] -> 
             RGBColor[
              0.546455843669073, 0.6291260632559607, 0.9611699783685105], 
             UndirectedEdge[208, 279] -> 
             RGBColor[
              0.5452339987014456, 0.6404957505007132, 0.9578243364561432], 
             UndirectedEdge[271, 295] -> 
             RGBColor[
              0.8245007835614508, 0.8571052491697122, 0.6931533757037327], 
             UndirectedEdge[193, 264] -> 
             RGBColor[
              0.8960317564122003, 0.9188602977301551, 0.9504859584350298], 
             UndirectedEdge[16, 39] -> 
             RGBColor[
              0.9532110209503954, 0.9642860125501127, 0.9523176731945178], 
             UndirectedEdge[168, 282] -> 
             RGBColor[
              0.9079111612914561, 0.9282850344663169, 0.9521539534551796], 
             UndirectedEdge[92, 243] -> 
             RGBColor[
              0.9208633630453181, 0.9354818878988798, 0.7856329087679303], 
             UndirectedEdge[71, 280] -> 
             RGBColor[
              0.9274739115742472, 0.9427392693030934, 0.9054372754284494], 
             UndirectedEdge[69, 118] -> 
             RGBColor[
              0.8073805689431428, 0.8467053277691763, 0.8100132012066877], 
             UndirectedEdge[175, 253] -> 
             RGBColor[
              0.9643174409424723, 0.895151937069067, 0.5565199610849301], 
             UndirectedEdge[137, 179] -> 
             RGBColor[
              0.9046730993286185, 0.9227349333402103, 0.7941237960427305], 
             UndirectedEdge[134, 221] -> 
             RGBColor[
              0.9788408431527521, 0.9823812231466946, 0.8598471150553628], 
             UndirectedEdge[91, 163] -> 
             RGBColor[
              0.7981778219335831, 0.8396928065873284, 0.8458598686615564], 
             UndirectedEdge[160, 232] -> 
             RGBColor[
              0.8140270142033381, 0.8522004769300007, 0.8186722154367694], 
             UndirectedEdge[135, 263] -> 
             RGBColor[
              0.977319129938985, 0.9815804081125125, 0.8773835929040554], 
             UndirectedEdge[160, 297] -> 
             RGBColor[
              0.9795274341892968, 0.9820591464176598, 0.8092134164001101], 
             UndirectedEdge[179, 274] -> 
             RGBColor[
              0.7590590809682121, 0.8117019902058327, 0.9766195734466501], 
             UndirectedEdge[209, 259] -> 
             RGBColor[
              0.9704174391414783, 0.9745944813546055, 0.7714372652382471], 
             UndirectedEdge[14, 173] -> 
             RGBColor[
              0.957534603377976, 0.9638667275333261, 0.7197557505792036], 
             UndirectedEdge[260, 267] -> 
             RGBColor[
              0.9128042334532125, 0.9320234595740533, 0.94665355848449], 
             UndirectedEdge[203, 216] -> 
             RGBColor[
              0.8155539787735868, 0.7265636931561898, 0.60855291685539], 
             UndirectedEdge[37, 279] -> 
             RGBColor[
              0.8268499973353192, 0.8642800287598638, 0.9189247684609596], 
             UndirectedEdge[192, 220] -> 
             RGBColor[
              0.8400295329313675, 0.8322802071721012, 0.6407339243969095], 
             UndirectedEdge[60, 225] -> 
             RGBColor[
              0.673167427407009, 0.7370235857533396, 0.8953402262483863], 
             UndirectedEdge[177, 226] -> 
             RGBColor[
              0.9910472316057233, 0.9905658144403829, 0.798034071522464], 
             UndirectedEdge[91, 273] -> 
             RGBColor[
              0.9905285227997274, 0.9903513150188954, 0.8066304188131745], 
             UndirectedEdge[52, 273] -> 
             RGBColor[
              0.959824511079038, 0.9692231654942777, 0.9384158819208757], 
             UndirectedEdge[21, 114] -> 
             RGBColor[
              0.9707838276158292, 0.9772666682837844, 0.9135365460735014], 
             UndirectedEdge[7, 202] -> 
             RGBColor[
              0.8884453991991643, 0.9123246596236004, 0.9217010567409415], 
             UndirectedEdge[94, 293] -> 
             RGBColor[
              0.962011514498277, 0.9686940235698738, 0.8221221089392243], 
             UndirectedEdge[132, 133] -> 
             RGBColor[
              0.6415773044102994, 0.7167366812770488, 0.9670398604038635], 
             UndirectedEdge[13, 93] -> 
             RGBColor[
              0.9564362643872055, 0.9670308178258239, 0.9586262205372289], 
             UndirectedEdge[141, 178] -> 
             RGBColor[
              0.7860066934777357, 0.8324368102881923, 0.9480199807169207], 
             UndirectedEdge[245, 264] -> 
             RGBColor[
              0.9856863586332777, 0.9876218883256151, 0.8543180477436947], 
             UndirectedEdge[5, 83] -> 
             RGBColor[
              0.7018620163906879, 0.7588222443740837, 0.7150645261276267], 
             UndirectedEdge[210, 226] -> 
             RGBColor[
              0.9804649807178374, 0.9839461677013418, 0.8729357337944036], 
             UndirectedEdge[91, 298] -> 
             RGBColor[
              0.7692338236056808, 0.816194764832472, 0.8435812910878245], 
             UndirectedEdge[126, 192] -> 
             RGBColor[
              0.8545182268822396, 0.885004784657651, 0.8813317540576895], 
             UndirectedEdge[127, 156] -> 
             RGBColor[
              0.667739287342592, 0.7335766295233141, 0.9329781612243905], 
             UndirectedEdge[36, 268] -> 
             RGBColor[
              0.6122805818569008, 0.6833774681803984, 0.9502583994053202], 
             UndirectedEdge[25, 221] -> 
             RGBColor[
              0.955278685642529, 0.9661674974934055, 0.9605856994070763], 
             UndirectedEdge[69, 249] -> 
             RGBColor[
              0.7802723639357948, 0.8287853067625899, 0.9744940877404971], 
             UndirectedEdge[22, 161] -> 
             RGBColor[
              0.9594548126166563, 0.9655760690661989, 0.7343858960920921], 
             UndirectedEdge[96, 112] -> 
             RGBColor[
              0.5927046960030367, 0.6660036427154098, 0.9655812351909618], 
             UndirectedEdge[219, 250] -> 
             RGBColor[
              0.934790884824237, 0.9483753194089091, 0.8975240545500538], 
             UndirectedEdge[41, 219] -> 
             RGBColor[
              0.9366004584703704, 0.9481403117948988, 0.7960582745267955], 
             UndirectedEdge[202, 237] -> 
             RGBColor[
              0.879140078385607, 0.9058652047762166, 0.9589675409238394], 
             UndirectedEdge[91, 235] -> 
             RGBColor[
              0.9894177824701706, 0.9744399266059471, 0.5605388075987927], 
             UndirectedEdge[69, 263] -> 
             RGBColor[
              0.7922048878777616, 0.837684563580794, 0.9542954372074246], 
             UndirectedEdge[12, 239] -> 
             RGBColor[
              0.7213216178052286, 0.781704916345156, 0.9733114731542098], 
             UndirectedEdge[122, 266] -> 
             RGBColor[
              0.8541485903985993, 0.8821963457095763, 0.7035100000553303], 
             UndirectedEdge[206, 254] -> 
             RGBColor[
              0.96025143666255, 0.9698761670620044, 0.9521681290313637], 
             UndirectedEdge[137, 270] -> 
             RGBColor[
              0.9446424558948078, 0.9545666119213826, 0.7979464056530456], 
             UndirectedEdge[25, 58] -> 
             RGBColor[
              0.9026364382662523, 0.9249555923267112, 0.9820389166414176], 
             UndirectedEdge[107, 156] -> 
             RGBColor[
              0.6754415805401244, 0.7377746162152814, 0.8506905367584483], 
             UndirectedEdge[136, 194] -> 
             RGBColor[
              0.9123071368354019, 0.931295493330417, 0.9322071498181914], 
             UndirectedEdge[45, 281] -> 
             RGBColor[
              0.4927652320611423, 0.5884156846744879, 0.9556412475261793], 
             UndirectedEdge[137, 147] -> 
             RGBColor[
              0.8743257839246315, 0.8990273798984761, 0.7910990592550476], 
             UndirectedEdge[164, 187] -> 
             RGBColor[
              0.6444890865834898, 0.7211117188974562, 0.965943714382659], 
             UndirectedEdge[199, 229] -> 
             RGBColor[
              0.934575202919786, 0.9495476132095664, 0.9547455842090814], 
             UndirectedEdge[191, 271] -> 
             RGBColor[
              0.9894385801001842, 0.9760359921179115, 0.41347130735635534`], 
             UndirectedEdge[153, 222] -> 
             RGBColor[
              0.6704333350036258, 0.742027443613463, 0.9680866350522336], 
             UndirectedEdge[158, 186] -> 
             RGBColor[
              0.900741139099455, 0.7131324350591015, 0.598815325254556], 
             UndirectedEdge[16, 192] -> 
             RGBColor[
              0.8200260524593016, 0.8601587455779787, 0.9824762284472932], 
             UndirectedEdge[75, 143] -> 
             RGBColor[
              0.8336640207232288, 0.8706277154025082, 0.969051516928511], 
             UndirectedEdge[204, 226] -> 
             RGBColor[
              0.9888647392572953, 0.989663297766813, 0.8342036178450567], 
             UndirectedEdge[137, 191] -> 
             RGBColor[
              0.9909905823062102, 0.9802468897979317, 0.506605589588181], 
             UndirectedEdge[197, 198] -> 
             RGBColor[
              0.7257541728038782, 0.7803934968780077, 0.7999937208131278], 
             UndirectedEdge[80, 156] -> 
             RGBColor[
              0.5910780224533829, 0.6735423005473209, 0.9635709399763319], 
             UndirectedEdge[103, 159] -> 
             RGBColor[
              0.8979818557862327, 0.9212419866606232, 0.9815197945062801], 
             UndirectedEdge[28, 288] -> 
             RGBColor[
              0.3784137387854847, 0.4867993338343847, 0.9467072944975194], 
             UndirectedEdge[118, 263] -> 
             RGBColor[
              0.9794534127383233, 0.9818997354766843, 0.801070425803954], 
             UndirectedEdge[68, 83] -> 
             RGBColor[
              0.34035530703202255`, 0.465639595608097, 0.9430392276273302], 
             UndirectedEdge[64, 90] -> 
             RGBColor[
              0.9496655783808778, 0.9614648078301254, 0.9521818069742577], 
             UndirectedEdge[213, 263] -> 
             RGBColor[
              0.8274536035213176, 0.8655616167581534, 0.9575759058381513], 
             UndirectedEdge[52, 53] -> 
             RGBColor[
              0.9367942293730178, 0.9523314610417495, 0.9901290761881016], 
             UndirectedEdge[245, 297] -> 
             RGBColor[
              0.9779166094013918, 0.9818272220702714, 0.8674702065181279], 
             UndirectedEdge[189, 267] -> 
             RGBColor[
              0.9046061057761188, 0.9254864950965864, 0.9458716137480937], 
             UndirectedEdge[145, 203] -> 
             RGBColor[
              0.926131050966835, 0.8137118468918305, 0.6106813202261454], 
             UndirectedEdge[136, 279] -> 
             RGBColor[
              0.752764900043624, 0.8069346687352881, 0.9759524917885467], 
             UndirectedEdge[80, 256] -> 
             RGBColor[
              0.5385235398002698, 0.6228010594676295, 0.9604133881442527], 
             UndirectedEdge[40, 130] -> 
             RGBColor[
              0.9516858960001939, 0.9634880008608051, 0.9666673551219367], 
             UndirectedEdge[83, 101] -> 
             RGBColor[
              0.6153448546591883, 0.6947252855137227, 0.9650415764461766], 
             UndirectedEdge[83, 194] -> 
             RGBColor[
              0.6983990346866213, 0.7593329642845953, 0.9136726448895285], 
             UndirectedEdge[149, 197] -> 
             RGBColor[
              0.6624706223945132, 0.7337941137604297, 0.9688314879913965], 
             UndirectedEdge[23, 44] -> 
             RGBColor[
              0.5812211304084436, 0.6590974798129898, 0.9641449840721273], 
             UndirectedEdge[97, 284] -> 
             RGBColor[
              0.9887436639617455, 0.9876137508552498, 0.6908691210785699], 
             UndirectedEdge[135, 276] -> 
             RGBColor[
              0.9275004005099569, 0.9425932723585395, 0.8981829395848145], 
             UndirectedEdge[142, 150] -> 
             RGBColor[
              0.9162653299983663, 0.9352517974724748, 0.9635383469113565], 
             UndirectedEdge[46, 214] -> 
             RGBColor[
              0.9262425068579183, 0.9440246490581723, 0.9928270312421972], 
             UndirectedEdge[5, 243] -> 
             RGBColor[
              0.9203893509510219, 0.9344680239591543, 0.7340396175673412], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.9471406122648013, 0.8994602033547108, 0.6294888400866653], 
             UndirectedEdge[198, 243] -> 
             RGBColor[
              0.9211558476449795, 0.936107482882826, 0.8174680524353464], 
             UndirectedEdge[13, 32] -> 
             RGBColor[
              0.9632226599405231, 0.9601894940520288, 0.693792649178037], 
             UndirectedEdge[86, 140] -> 
             RGBColor[
              0.4791887632963029, 0.5880660511085436, 0.9521426412544135], 
             UndirectedEdge[171, 275] -> 
             RGBColor[
              0.9685157503834969, 0.9727542592806262, 0.7411767407535059], 
             UndirectedEdge[36, 250] -> 
             RGBColor[
              0.6302698145176182, 0.6957419949305158, 0.8727049627349397], 
             UndirectedEdge[168, 203] -> 
             RGBColor[
              0.9430765664824445, 0.8263497846176371, 0.5819969825564957], 
             UndirectedEdge[17, 169] -> 
             RGBColor[
              0.8126564418877433, 0.798266240344967, 0.6246433532317995], 
             UndirectedEdge[191, 246] -> 
             RGBColor[
              0.9845850432582908, 0.9780916861026947, 0.6618139865301307], 
             UndirectedEdge[17, 178] -> 
             RGBColor[
              0.6365640677079505, 0.7153774743500343, 0.9648414782672743], 
             UndirectedEdge[9, 132] -> 
             RGBColor[
              0.6733790272799578, 0.7428480175917842, 0.9694623785179685], 
             UndirectedEdge[11, 283] -> 
             RGBColor[
              0.9712601953205876, 0.9780864812439811, 0.9335331721674105], 
             UndirectedEdge[64, 69] -> 
             RGBColor[
              0.7679019779928653, 0.8190430497228411, 0.9775285055345442], 
             UndirectedEdge[193, 288] -> 
             RGBColor[
              0.4955874212890399, 0.5793237275125108, 0.9577109660633423], 
             UndirectedEdge[221, 288] -> 
             RGBColor[
              0.5721186512030436, 0.6395215304252011, 0.9385528944455275], 
             UndirectedEdge[65, 264] -> 
             RGBColor[
              0.9453646801492814, 0.8344883191425287, 0.5831141262580987], 
             UndirectedEdge[27, 151] -> 
             RGBColor[
              0.9642240662753834, 0.9728389477226718, 0.9454435033245803], 
             UndirectedEdge[201, 293] -> 
             RGBColor[
              0.877049170988957, 0.9047992183537923, 0.9881349269516062], 
             UndirectedEdge[43, 99] -> 
             RGBColor[
              0.9424360167404051, 0.9555442335008785, 0.9448419907441388], 
             UndirectedEdge[77, 293] -> 
             RGBColor[
              0.907909060250428, 0.9294060563815105, 0.9910783707383137], 
             UndirectedEdge[61, 280] -> 
             RGBColor[
              0.9888022275472866, 0.9896374475682468, 0.8352395986550207], 
             UndirectedEdge[20, 55] -> 
             RGBColor[
              0.9573114985480657, 0.8870127179452245, 0.5967296226538845], 
             UndirectedEdge[208, 242] -> 
             RGBColor[
              0.6618884323862336, 0.732276474994074, 0.9692790309300559], 
             UndirectedEdge[29, 261] -> 
             RGBColor[
              0.8117937232413525, 0.8523077552151987, 0.9121854524131056], 
             UndirectedEdge[12, 76] -> 
             RGBColor[
              0.9186793009124157, 0.9360642774110774, 0.9192578446141256], 
             UndirectedEdge[168, 276] -> 
             RGBColor[
              0.9219380952208487, 0.9394697308306361, 0.9534918549353568], 
             UndirectedEdge[148, 271] -> 
             RGBColor[
              0.8436592580275073, 0.8720719950323945, 0.6950629133923861], 
             UndirectedEdge[131, 170] -> 
             RGBColor[
              0.7471788426043355, 0.8025915263907235, 0.9753902251653399], 
             UndirectedEdge[141, 261] -> 
             RGBColor[
              0.9790641896001717, 0.9833875967220456, 0.8970771043442936], 
             UndirectedEdge[129, 184] -> 
             RGBColor[
              0.7524657325052013, 0.7986239225706996, 0.6869645253378378], 
             UndirectedEdge[111, 185] -> 
             RGBColor[
              0.795341729788942, 0.8311855879782607, 0.6870009586042906], 
             UndirectedEdge[234, 239] -> 
             RGBColor[
              0.4994596348672724, 0.6032354526312214, 0.9540941524147529], 
             UndirectedEdge[103, 203] -> 
             RGBColor[
              0.9261241772632438, 0.8137067204949471, 0.6106929556133762], 
             UndirectedEdge[28, 160] -> 
             RGBColor[
              0.7863395870835068, 0.829722576289744, 0.8164925597515089], 
             UndirectedEdge[133, 170] -> 
             RGBColor[
              0.6417960123712735, 0.7169110730684602, 0.9670607209644241], 
             UndirectedEdge[87, 299] -> 
             RGBColor[
              0.778853205912118, 0.8278101401170279, 0.9784213490275104], 
             UndirectedEdge[5, 290] -> 
             RGBColor[
              0.8185754761202175, 0.854705839550054, 0.7239513139615186], 
             UndirectedEdge[183, 253] -> 
             RGBColor[
              0.9866940600751496, 0.9887656661410853, 0.8701773894308612], 
             UndirectedEdge[176, 245] -> 
             RGBColor[
              0.982590337402032, 0.9853128807606217, 0.8595588041165325], 
             UndirectedEdge[29, 190] -> 
             RGBColor[
              0.6681016720941748, 0.7405521100875953, 0.9676175520331299], 
             UndirectedEdge[159, 168] -> 
             RGBColor[
              0.9149342450054333, 0.9338850507833133, 0.9528238214493996], 
             UndirectedEdge[202, 299] -> 
             RGBColor[
              0.8447852996800693, 0.8793167928710233, 0.9849928439638528], 
             UndirectedEdge[65, 115] -> 
             RGBColor[
              0.9516264040490015, 0.8378047702665373, 0.5119007188444626], 
             UndirectedEdge[51, 142] -> 
             RGBColor[
              0.9169537761582611, 0.9357652394912972, 0.9623729871381701], 
             UndirectedEdge[134, 187] -> 
             RGBColor[
              0.8549852086361788, 0.8852132356796807, 0.8742883322940986], 
             UndirectedEdge[85, 239] -> 
             RGBColor[
              0.7931239829640528, 0.8342045451484379, 0.7329432975573318], 
             UndirectedEdge[120, 284] -> 
             RGBColor[
              0.7104121129799243, 0.7700958870030624, 0.9275890639352811], 
             UndirectedEdge[31, 61] -> 
             RGBColor[
              0.9833619221714082, 0.9644294759749199, 0.6090175324849771], 
             UndirectedEdge[217, 247] -> 
             RGBColor[
              0.9248469981119712, 0.942434184393842, 0.9761309398927089], 
             UndirectedEdge[66, 169] -> 
             RGBColor[
              0.8922551978829081, 0.8605394352143712, 0.6325531190346216], 
             UndirectedEdge[168, 293] -> 
             RGBColor[
              0.954341003054272, 0.9653069299835058, 0.956582473210926], 
             UndirectedEdge[93, 105] -> 
             RGBColor[
              0.816449472649976, 0.8568151804225974, 0.9488899043234207], 
             UndirectedEdge[169, 193] -> 
             RGBColor[
              0.8828170424506285, 0.8530762347450067, 0.6316363062078183], 
             UndirectedEdge[87, 216] -> 
             RGBColor[
              0.6910667610825438, 0.7585858731503783, 0.9698427344248014], 
             UndirectedEdge[81, 201] -> 
             RGBColor[
              0.9010068240410949, 0.8991580740710375, 0.6748454922023803], 
             UndirectedEdge[63, 244] -> 
             RGBColor[
              0.8445214668063405, 0.8782477525623222, 0.9280607721644589], 
             UndirectedEdge[32, 150] -> 
             RGBColor[
              0.9768562439817211, 0.9703573987070093, 0.6707145476044949], 
             UndirectedEdge[95, 282] -> 
             RGBColor[
              0.8885234891607205, 0.9138257403356138, 0.9849722252577813], 
             UndirectedEdge[126, 239] -> 
             RGBColor[
              0.7922681442220084, 0.8356186661776936, 0.8756440474009628], 
             UndirectedEdge[149, 150] -> 
             RGBColor[
              0.9176948561470715, 0.9363916628199986, 0.9636746963915732], 
             UndirectedEdge[16, 222] -> 
             RGBColor[
              0.7681045229790933, 0.8191578118655821, 0.9776016233316349], 
             UndirectedEdge[192, 262] -> 
             RGBColor[
              0.7770509926997926, 0.8258915994526674, 0.9783772288831425], 
             UndirectedEdge[214, 276] -> 
             RGBColor[
              0.8970716885331409, 0.9207646303467645, 0.990044692549283], 
             UndirectedEdge[48, 100] -> 
             RGBColor[
              0.7076562917713707, 0.7715457406095929, 0.9714962238058851], 
             UndirectedEdge[105, 143] -> 
             RGBColor[
              0.6876586719137919, 0.7559234479893123, 0.9695030479468643], 
             UndirectedEdge[268, 279] -> 
             RGBColor[
              0.8107820727197215, 0.8527100122617679, 0.9646371586378738], 
             UndirectedEdge[24, 106] -> 
             RGBColor[
              0.8523317394127324, 0.8850902093517174, 0.9857773562623543], 
             UndirectedEdge[33, 222] -> 
             RGBColor[
              0.8023942159262782, 0.843920119651494, 0.8798127910005196], 
             UndirectedEdge[155, 291] -> 
             RGBColor[
              0.8715930856530858, 0.7857943732031611, 0.6175342001934669], 
             UndirectedEdge[99, 233] -> 
             RGBColor[
              0.8225429308459125, 0.861236595312084, 0.9330636628264637], 
             UndirectedEdge[237, 269] -> 
             RGBColor[
              0.9750480147303294, 0.9809114307577815, 0.9271213819282407], 
             UndirectedEdge[85, 135] -> 
             RGBColor[
              0.9917965395050558, 0.9891076401699479, 0.6570988134355533], 
             UndirectedEdge[126, 248] -> 
             RGBColor[
              0.9909714794351743, 0.990534488971119, 0.7992894810287939], 
             UndirectedEdge[188, 261] -> 
             RGBColor[
              0.8491504978429991, 0.8815844124599361, 0.9158450635287599], 
             UndirectedEdge[37, 177] -> 
             RGBColor[
              0.9892661279716106, 0.9898292823154018, 0.8275515680881578], 
             UndirectedEdge[160, 180] -> 
             RGBColor[
              0.7603701552531706, 0.8086394216203052, 0.8144481509486616], 
             UndirectedEdge[23, 194] -> 
             RGBColor[
              0.628060330228132, 0.6948283163956571, 0.90932183537377], 
             UndirectedEdge[51, 243] -> 
             RGBColor[
              0.9082596856825316, 0.9288328077407496, 0.9615437370272889], 
             UndirectedEdge[108, 208] -> 
             RGBColor[
              0.5930004986347516, 0.6778113032874571, 0.9625852547661741], 
             UndirectedEdge[179, 251] -> 
             RGBColor[
              0.8075082472065234, 0.8495508470985029, 0.9814485335540847], 
             UndirectedEdge[26, 224] -> 
             RGBColor[
              0.669020714900278, 0.738596920517959, 0.9696677453647924], 
             UndirectedEdge[106, 291] -> 
             RGBColor[
              0.839623420838087, 0.8749569410784134, 0.9845652254918547], 
             UndirectedEdge[48, 161] -> 
             RGBColor[
              0.830767169608577, 0.8685773112012802, 0.983539498793486], 
             UndirectedEdge[227, 299] -> 
             RGBColor[0.93534116875358, 0.9503714558449243, 0.96220633881571],
              UndirectedEdge[162, 299] -> 
             RGBColor[
              0.9337521292467938, 0.9491863527825768, 0.9648961682128196], 
             UndirectedEdge[200, 227] -> 
             RGBColor[
              0.9820505442515856, 0.9846402765775992, 0.8483801573489773], 
             UndirectedEdge[202, 293] -> 
             RGBColor[
              0.8596265279868132, 0.8911507854684104, 0.9864084135686709], 
             UndirectedEdge[3, 155] -> 
             RGBColor[
              0.9398935901858076, 0.8395462815726471, 0.5994652087669449], 
             UndirectedEdge[39, 234] -> 
             RGBColor[
              0.6948946860185975, 0.7567488380833127, 0.9296233038187041], 
             UndirectedEdge[144, 176] -> 
             RGBColor[
              0.7331123167566778, 0.7894019195178857, 0.9413654997992353], 
             UndirectedEdge[140, 162] -> 
             RGBColor[
              0.7345841330878553, 0.790791082687692, 0.9466921254873748], 
             UndirectedEdge[123, 257] -> 
             RGBColor[
              0.9847797078782092, 0.985254784854668, 0.7430748527454669], 
             UndirectedEdge[121, 286] -> 
             RGBColor[
              0.8925594895745721, 0.913364968428744, 0.8003876051517876], 
             UndirectedEdge[176, 230] -> 
             RGBColor[
              0.8916221540176122, 0.9155251105767719, 0.9555957893136195], 
             UndirectedEdge[39, 64] -> 
             RGBColor[
              0.949778714664411, 0.9615491846851407, 0.9519902967569046], 
             UndirectedEdge[269, 277] -> 
             RGBColor[
              0.8328069289045547, 0.8694365866998616, 0.9425647039363042], 
             UndirectedEdge[154, 203] -> 
             RGBColor[
              0.9472085883218728, 0.8288818671824898, 0.5503915654220617], 
             UndirectedEdge[107, 137] -> 
             RGBColor[
              0.9938313174982824, 0.9907515794052868, 0.6817110084837656], 
             UndirectedEdge[192, 218] -> 
             RGBColor[
              0.6688238122630328, 0.7408690238634518, 0.9678585590852944], 
             UndirectedEdge[247, 270] -> 
             RGBColor[
              0.9246733534344497, 0.9422957248414454, 0.9761143775083525], 
             UndirectedEdge[28, 240] -> 
             RGBColor[
              0.6342649764703312, 0.713224464948387, 0.9648563694333254], 
             UndirectedEdge[31, 194] -> 
             RGBColor[
              0.9823566099405285, 0.9640137535321053, 0.6256781578153077], 
             UndirectedEdge[58, 187] -> 
             RGBColor[
              0.788812420513237, 0.835269168216694, 0.9794992233641322], 
             UndirectedEdge[8, 121] -> 
             RGBColor[
              0.7719476199156781, 0.8217706147881172, 0.9779041825586892], 
             UndirectedEdge[62, 186] -> 
             RGBColor[
              0.9653381109641412, 0.9700117523139951, 0.7169891626297015], 
             UndirectedEdge[271, 289] -> 
             RGBColor[
              0.9483285492212974, 0.9545324294346749, 0.7053117376492144], 
             UndirectedEdge[236, 294] -> 
             RGBColor[
              0.8668861591866606, 0.8962509441070108, 0.9556502270357821], 
             UndirectedEdge[115, 211] -> 
             RGBColor[
              0.9654030238249957, 0.972364680025036, 0.8828338935439004], 
             UndirectedEdge[43, 284] -> 
             RGBColor[
              0.9422311409427235, 0.9554595120934692, 0.948237312913291], 
             UndirectedEdge[87, 181] -> 
             RGBColor[
              0.8245565699417738, 0.8616629492542247, 0.8812673810655589], 
             UndirectedEdge[77, 205] -> 
             RGBColor[
              0.9144265218442527, 0.934428013937713, 0.9856364865174753], 
             UndirectedEdge[132, 267] -> 
             RGBColor[
              0.9125068242165145, 0.9317863135216691, 0.9466251913259933], 
             UndirectedEdge[108, 280] -> 
             RGBColor[
              0.876021178457935, 0.9021764533170473, 0.9004064842657376], 
             UndirectedEdge[40, 97] -> 
             RGBColor[
              0.965602759593099, 0.970410303895739, 0.7325037213760313], 
             UndirectedEdge[35, 262] -> 
             RGBColor[
              0.9039744836011027, 0.8937983232484965, 0.6637624717843285], 
             UndirectedEdge[201, 216] -> 
             RGBColor[
              0.7744214978526389, 0.8237409587897556, 0.978140742744079], 
             UndirectedEdge[244, 279] -> 
             RGBColor[
              0.6851333859679767, 0.7539506754155574, 0.9692513510439242], 
             UndirectedEdge[143, 163] -> 
             RGBColor[
              0.6581828954569683, 0.7322662668967433, 0.9669962409778647], 
             UndirectedEdge[102, 165] -> 
             RGBColor[
              0.7994252127383095, 0.8436928998627214, 0.9805217297329332], 
             UndirectedEdge[7, 282] -> 
             RGBColor[
              0.9118351179312678, 0.9307310767240964, 0.9239967151338717], 
             UndirectedEdge[10, 122] -> 
             RGBColor[
              0.9728036924759004, 0.9755192589266843, 0.6995663927348654], 
             UndirectedEdge[113, 193] -> 
             RGBColor[
              0.8845359531960224, 0.9102867465141797, 0.9699453546943493], 
             UndirectedEdge[22, 100] -> 
             RGBColor[
              0.8363439347794499, 0.8685444984745115, 0.7223426211044913], 
             UndirectedEdge[116, 254] -> 
             RGBColor[
              0.9849184328292788, 0.984998785643104, 0.7143184098620046], 
             UndirectedEdge[174, 298] -> 
             RGBColor[
              0.6349019314067167, 0.7131922305602423, 0.9652821017368649], 
             UndirectedEdge[159, 271] -> 
             RGBColor[
              0.9208456797754827, 0.9326183353412001, 0.7026903970272254], 
             UndirectedEdge[11, 101] -> 
             RGBColor[
              0.8916932872949422, 0.915761941939119, 0.9647734957946708], 
             UndirectedEdge[148, 225] -> 
             RGBColor[
              0.8421872056162971, 0.875997894512942, 0.9084971614499618], 
             UndirectedEdge[239, 248] -> 
             RGBColor[
              0.791718750336188, 0.8353914776871281, 0.8847489258748082], 
             UndirectedEdge[22, 119] -> 
             RGBColor[
              0.9660796319535259, 0.970768460770955, 0.7318953610454728], 
             UndirectedEdge[38, 247] -> 
             RGBColor[
              0.9468072202164254, 0.9598494924493688, 0.9749256806614254], 
             UndirectedEdge[157, 222] -> 
             RGBColor[
              0.8003791868399057, 0.8430868533403936, 0.913207037689827], 
             UndirectedEdge[42, 203] -> 
             RGBColor[
              0.9014643962878428, 0.644679745675536, 0.23945173013855398`], 
             UndirectedEdge[155, 241] -> 
             RGBColor[
              0.7855951748078185, 0.7185587212066192, 0.6089769109314292], 
             UndirectedEdge[103, 154] -> 
             RGBColor[
              0.9664155502470393, 0.9739237803230789, 0.917122910626951], 
             UndirectedEdge[88, 107] -> 
             RGBColor[
              0.9212809230637558, 0.9370315212566842, 0.8714267162502174], 
             UndirectedEdge[58, 176] -> 
             RGBColor[
              0.9168247177186817, 0.9355371879111576, 0.9580218604243943], 
             UndirectedEdge[48, 119] -> 
             RGBColor[
              0.8373919889454465, 0.8737697029060365, 0.9810489637468666], 
             UndirectedEdge[206, 219] -> 
             RGBColor[
              0.9114757863702974, 0.9320387706705111, 0.9840927928000944], 
             UndirectedEdge[1, 125] -> 
             RGBColor[
              0.9879316825118512, 0.9879932920503885, 0.7685072469968337], 
             UndirectedEdge[191, 278] -> 
             RGBColor[
              0.9909875462536497, 0.9802403959884969, 0.5062751340033138], 
             UndirectedEdge[90, 118] -> 
             RGBColor[
              0.9891441693311552, 0.9891270858764607, 0.7846665026464013], 
             UndirectedEdge[101, 283] -> 
             RGBColor[
              0.8995626058535102, 0.9216308668352724, 0.9514527921220044], 
             UndirectedEdge[5, 226] -> 
             RGBColor[
              0.9916363194652764, 0.988866665569462, 0.6470538111630089], 
             UndirectedEdge[3, 241] -> 
             RGBColor[
              0.8088971215670733, 0.8510843118661526, 0.956696237361886], 
             UndirectedEdge[194, 241] -> 
             RGBColor[
              0.8203513820359074, 0.8593092182861402, 0.9230815960811694], 
             UndirectedEdge[139, 235] -> 
             RGBColor[
              0.9857114595586458, 0.9729072668338774, 0.6219621698989846], 
             UndirectedEdge[40, 94] -> 
             RGBColor[
              0.9664090974983757, 0.9721349791418581, 0.8202686262246774], 
             UndirectedEdge[161, 177] -> 
             RGBColor[
              0.9588968040060556, 0.9673416933080348, 0.8887489409011237], 
             UndirectedEdge[34, 295] -> 
             RGBColor[
              0.8229207517600996, 0.8609864963974927, 0.908377121697652], 
             UndirectedEdge[1, 281] -> 
             RGBColor[
              0.6221072785134947, 0.6895819371243579, 0.9271804134112671], 
             UndirectedEdge[191, 295] -> 
             RGBColor[
              0.8228805764947246, 0.851639910290934, 0.6868591771999322], 
             UndirectedEdge[144, 297] -> 
             RGBColor[
              0.7284385887560375, 0.7859162608275354, 0.9492769022008305], 
             UndirectedEdge[141, 294] -> 
             RGBColor[
              0.9708118929918796, 0.9777521381012584, 0.9342920310739399], 
             UndirectedEdge[80, 201] -> 
             RGBColor[
              0.8247124903701504, 0.863067369869706, 0.9831430076326781], 
             UndirectedEdge[113, 115] -> 
             RGBColor[
              0.9745815909298631, 0.9792100403433217, 0.8672969735890586], 
             UndirectedEdge[129, 253] -> 
             RGBColor[
              0.9896256918920124, 0.9851674617199062, 0.6306472712031445], 
             UndirectedEdge[37, 108] -> 
             RGBColor[
              0.8746164972686251, 0.9015955815466077, 0.9236856867709906], 
             UndirectedEdge[265, 276] -> 
             RGBColor[
              0.9224857953771889, 0.9398782047104579, 0.9525647414337517], 
             UndirectedEdge[59, 194] -> 
             RGBColor[
              0.9884823659093485, 0.9895051765608902, 0.8405405337710399], 
             UndirectedEdge[103, 225] -> 
             RGBColor[
              0.9667229107664501, 0.9740508817966604, 0.9120291513967864], 
             UndirectedEdge[46, 265] -> 
             RGBColor[
              0.9516566137019663, 0.9631382234218657, 0.9553470801266659], 
             UndirectedEdge[51, 149] -> 
             RGBColor[
              0.9183833023069663, 0.9369051048388211, 0.9625093366183868], 
             UndirectedEdge[52, 124] -> 
             RGBColor[
              0.8982949328562118, 0.7100475549458444, 0.6004042630062294], 
             UndirectedEdge[82, 258] -> 
             RGBColor[
              0.7265546049328172, 0.7833339764707806, 0.914972026599338], 
             UndirectedEdge[45, 132] -> 
             RGBColor[
              0.7817585137050905, 0.8296018927998112, 0.9788377418203112], 
             UndirectedEdge[74, 287] -> 
             RGBColor[
              0.8808009321063273, 0.9077907708299408, 0.9884927732762177], 
             UndirectedEdge[128, 269] -> 
             RGBColor[
              0.9876425462412601, 0.9873337241338482, 0.733772688168254], 
             UndirectedEdge[14, 249] -> 
             RGBColor[
              0.9665574254708011, 0.9709397280262018, 0.7164020391567283], 
             UndirectedEdge[101, 198] -> 
             RGBColor[0.907279356253322, 0.925042745314443, 0.81614450029872],
              UndirectedEdge[164, 297] -> 
             RGBColor[
              0.7678276557882941, 0.8178940799015696, 0.9523777538445165], 
             UndirectedEdge[68, 235] -> 
             RGBColor[
              0.6268490088051499, 0.6788753351157613, 0.6648971131729731], 
             UndirectedEdge[108, 177] -> 
             RGBColor[
              0.8772022148687724, 0.9026648422241799, 0.8808336545139079], 
             UndirectedEdge[62, 276] -> 
             RGBColor[
              0.9286578591750313, 0.9408232716715904, 0.7155484937298546], 
             UndirectedEdge[13, 107] -> 
             RGBColor[
              0.96681323688465, 0.9732235759602803, 0.8718110616846207], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.7407241272686778, 0.7973785850249473, 0.9747921166117646], 
             UndirectedEdge[62, 135] -> 
             RGBColor[
              0.9915179868701023, 0.988511844249774, 0.62678007814846], 
             UndirectedEdge[18, 35] -> 
             RGBColor[
              0.8125890900080092, 0.822273168160326, 0.6546896399769635], 
             UndirectedEdge[42, 202] -> 
             RGBColor[
              0.8429092723647509, 0.7282085784237198, 0.6073130426443076], 
             UndirectedEdge[121, 255] -> 
             RGBColor[
              0.8055888156448614, 0.49700277165186946`, 0.573457024588512], 
             UndirectedEdge[128, 281] -> 
             RGBColor[
              0.6281565119975054, 0.6911227579488894, 0.7449112019237271], 
             UndirectedEdge[82, 181] -> 
             RGBColor[
              0.7290518818388481, 0.7843666646485135, 0.8735856855209432], 
             UndirectedEdge[136, 204] -> 
             RGBColor[
              0.9129985383314876, 0.9315814056172562, 0.9207488377383376], 
             UndirectedEdge[118, 166] -> 
             RGBColor[
              0.9390912649585359, 0.9504530212377451, 0.8227717496844078], 
             UndirectedEdge[39, 263] -> 
             RGBColor[
              0.9740816245493071, 0.9801906985430937, 0.9287572284297851], 
             UndirectedEdge[52, 84] -> 
             RGBColor[
              0.727749080434744, 0.7863143318501261, 0.9745180555246417], 
             UndirectedEdge[129, 165] -> 
             RGBColor[
              0.9336727543954757, 0.9426061968456497, 0.7035606368767902], 
             UndirectedEdge[141, 236] -> 
             RGBColor[
              0.8668861591866606, 0.8962509441070108, 0.9556502270357821], 
             UndirectedEdge[97, 178] -> 
             RGBColor[
              0.79708287933393, 0.8372405405182702, 0.718664873411855], 
             UndirectedEdge[115, 227] -> 
             RGBColor[
              0.981628911842338, 0.9844659207409168, 0.8553676975199058], 
             UndirectedEdge[256, 281] -> 
             RGBColor[
              0.2574625620251247, 0.38793985513063733`, 0.9379734840743785], 
             UndirectedEdge[221, 297] -> 
             RGBColor[
              0.9647932370943182, 0.9732634343875015, 0.9444800455916481], 
             UndirectedEdge[224, 262] -> 
             RGBColor[
              0.6392262743042585, 0.7148396423352383, 0.9668259250229329], 
             UndirectedEdge[73, 119] -> 
             RGBColor[
              0.8205951487093728, 0.8606478836529017, 0.9793748116875312], 
             UndirectedEdge[3, 227] -> 
             RGBColor[
              0.9670571212919887, 0.9749518355153541, 0.9406478801605551], 
             UndirectedEdge[45, 188] -> 
             RGBColor[
              0.7169321009529949, 0.7787920732410385, 0.9724207497777442], 
             UndirectedEdge[260, 300] -> 
             RGBColor[
              0.9131160747038085, 0.9321524139451295, 0.9414855419428251], 
             UndirectedEdge[23, 291] -> 
             RGBColor[
              0.548305565226576, 0.6328515016061838, 0.9610054680810088], 
             UndirectedEdge[142, 149] -> 
             RGBColor[
              0.8665663877113439, 0.8964405315157955, 0.9871350697244964], 
             UndirectedEdge[81, 97] -> 
             RGBColor[
              0.9851628296451382, 0.9613282040409998, 0.4210677693413521], 
             UndirectedEdge[181, 201] -> 
             RGBColor[
              0.9079113067118689, 0.9268180348936019, 0.8895653893848365], 
             UndirectedEdge[56, 57] -> 
             RGBColor[
              0.9807330441561982, 0.9450408061003974, 0.5182017331264547], 
             UndirectedEdge[197, 243] -> 
             RGBColor[
              0.6523470057700784, 0.7257218166623582, 0.9678658884002986], 
             UndirectedEdge[65, 200] -> 
             RGBColor[
              0.9520480364582489, 0.8379791261032199, 0.5049131786735341], 
             UndirectedEdge[8, 173] -> 
             RGBColor[
              0.837721750133526, 0.8739813892102435, 0.9842403337406239], 
             UndirectedEdge[53, 273] -> 
             RGBColor[
              0.9628726139898599, 0.9715467948857319, 0.9350022249303639], 
             UndirectedEdge[26, 253] -> 
             RGBColor[
              0.9422771527503249, 0.9547561517604557, 0.9161062232798698], 
             UndirectedEdge[114, 206] -> 
             RGBColor[
              0.9492361776208025, 0.9616610049045005, 0.970814089349366], 
             UndirectedEdge[9, 45] -> 
             RGBColor[
              0.6145002060033227, 0.6966845016970107, 0.9636381868102729], 
             UndirectedEdge[47, 190] -> 
             RGBColor[
              0.7946880514075108, 0.8400970297526857, 0.9800217534254441], 
             UndirectedEdge[191, 282] -> 
             RGBColor[
              0.9122023889947792, 0.9215529801454254, 0.6957263305292047], 
             UndirectedEdge[59, 155] -> 
             RGBColor[
              0.9537261586812595, 0.8487546794813693, 0.5264358486212998], 
             UndirectedEdge[214, 265] -> 
             RGBColor[
              0.9549172110954439, 0.9657381352768664, 0.9556580788168254], 
             UndirectedEdge[167, 282] -> 
             RGBColor[
              0.7605897483948515, 0.8130319502915571, 0.9767365258899001], 
             UndirectedEdge[28, 221] -> 
             RGBColor[
              0.7716053899885282, 0.8209268642595857, 0.9517591889430469], 
             UndirectedEdge[136, 197] -> 
             RGBColor[
              0.6477277733585252, 0.7220385661231091, 0.9674253018892474], 
             UndirectedEdge[121, 234] -> 
             RGBColor[
              0.5983613168895926, 0.681254079095315, 0.9634349479672231], 
             UndirectedEdge[141, 146] -> 
             RGBColor[
              0.8351273662426298, 0.8714407336833678, 0.9524848073579152], 
             UndirectedEdge[32, 167] -> 
             RGBColor[
              0.8354558906814753, 0.8595202310843686, 0.685274310602251], 
             UndirectedEdge[101, 136] -> 
             RGBColor[
              0.829252956807969, 0.8666878145595444, 0.9835760813748395], 
             UndirectedEdge[91, 274] -> 
             RGBColor[
              0.8490444523808622, 0.8800606853937529, 0.8504987160474287], 
             UndirectedEdge[84, 295] -> 
             RGBColor[
              0.5898474071816417, 0.677664999696346, 0.9610173117089897], 
             UndirectedEdge[73, 122] -> 
             RGBColor[
              0.8472938776657188, 0.8768413920249039, 0.7028267863510492], 
             UndirectedEdge[157, 248] -> 
             RGBColor[
              0.9887539688730487, 0.9896174913662581, 0.8360393697765898], 
             UndirectedEdge[125, 167] -> 
             RGBColor[
              0.8394463357620723, 0.8718721479136982, 0.7950600558424109], 
             UndirectedEdge[20, 208] -> 
             RGBColor[
              0.7000292284374964, 0.7616339272892302, 0.9363400052699731], 
             UndirectedEdge[77, 103] -> 
             RGBColor[
              0.9158515856037668, 0.935490824156231, 0.9832242252887726], 
             UndirectedEdge[46, 276] -> 
             RGBColor[
              0.8938110911396633, 0.9181647184917638, 0.9897336938591234], 
             UndirectedEdge[3, 291] -> 
             RGBColor[
              0.8948950324123405, 0.9183199638626945, 0.9652535266239237], 
             UndirectedEdge[79, 297] -> 
             RGBColor[
              0.927895460464061, 0.94460574282141, 0.9674349845009999], 
             UndirectedEdge[18, 262] -> 
             RGBColor[
              0.7452010113630072, 0.8010101519635471, 0.9752027203984898], 
             UndirectedEdge[127, 225] -> 
             RGBColor[
              0.9831049696835138, 0.9862685945138467, 0.8842985987754579], 
             UndirectedEdge[109, 292] -> 
             RGBColor[
              0.7967703117768414, 0.8420789196871512, 0.9791859250274855], 
             UndirectedEdge[267, 287] -> 
             RGBColor[
              0.9336520889732602, 0.9486469736657768, 0.9486420455550924], 
             UndirectedEdge[218, 262] -> 
             RGBColor[
              0.7283592245193409, 0.7875127314625019, 0.9737568824080065], 
             UndirectedEdge[207, 225] -> 
             RGBColor[
              0.742238640209901, 0.7956808369061841, 0.900064315206677], 
             UndirectedEdge[203, 299] -> 
             RGBColor[
              0.903340423603161, 0.7957879601228395, 0.6171315314580992], 
             UndirectedEdge[142, 163] -> 
             RGBColor[
              0.7331691777631153, 0.7912110743216989, 0.9743733253020908], 
             UndirectedEdge[2, 54] -> 
             RGBColor[
              0.9622518592524675, 0.9691698526269781, 0.8451819639708085], 
             UndirectedEdge[90, 195] -> 
             RGBColor[
              0.9842526681610249, 0.9876675778586863, 0.9066739136029376], 
             UndirectedEdge[88, 93] -> 
             RGBColor[
              0.9109039505663112, 0.9308387631222278, 0.9582418751028257], 
             UndirectedEdge[77, 82] -> 
             RGBColor[
              0.6766527178846315, 0.7451748064041191, 0.9701010021086791], 
             UndirectedEdge[167, 168] -> 
             RGBColor[
              0.831914504730207, 0.8687816777061564, 0.944614927139225], 
             UndirectedEdge[18, 26] -> 
             RGBColor[
              0.7749954519590266, 0.8247674301462677, 0.9780445407403493], 
             UndirectedEdge[129, 224] -> 
             RGBColor[
              0.7163692540419655, 0.7690082304774095, 0.6842087932880669], 
             UndirectedEdge[38, 289] -> 
             RGBColor[
              0.9224940825251444, 0.9409405802872708, 0.9891696583633511], 
             UndirectedEdge[31, 241] -> 
             RGBColor[
              0.8166039340937051, 0.83480128674609, 0.6688045012605087], 
             UndirectedEdge[5, 197] -> 
             RGBColor[
              0.7249876761099208, 0.7787540379543361, 0.7165652859451225], 
             UndirectedEdge[59, 241] -> 
             RGBColor[
              0.822729690062525, 0.8602927097748749, 0.8836668772162409], 
             UndirectedEdge[155, 226] -> 
             RGBColor[
              0.9534171305331207, 0.8486268884004528, 0.5315572447751704], 
             UndirectedEdge[15, 186] -> 
             RGBColor[
              0.9613784986583839, 0.9567614781052255, 0.6925569595554029], 
             UndirectedEdge[198, 256] -> 
             RGBColor[
              0.6234186835175997, 0.686632940457906, 0.7936369540285948], 
             UndirectedEdge[72, 291] -> 
             RGBColor[
              0.8292613394594135, 0.8666944986582652, 0.9835768809196175], 
             UndirectedEdge[230, 297] -> 
             RGBColor[
              0.886948426016972, 0.9120394518864217, 0.9635071917152148], 
             UndirectedEdge[138, 231] -> 
             RGBColor[
              0.8903034262062848, 0.9152197188864476, 0.9842650059946092], 
             UndirectedEdge[54, 165] -> 
             RGBColor[
              0.9029881243054164, 0.9254822356342062, 0.9906090074749071], 
             UndirectedEdge[103, 167] -> 
             RGBColor[
              0.8149621155110063, 0.8561386135834663, 0.9733109001961056], 
             UndirectedEdge[78, 131] -> 
             RGBColor[
              0.8242777427354895, 0.8606828252017492, 0.8464506742050584], 
             UndirectedEdge[16, 239] -> 
             RGBColor[
              0.7577759697990705, 0.8107726270980213, 0.9767885217905666], 
             UndirectedEdge[12, 87] -> 
             RGBColor[
              0.7537853002217132, 0.8078216725696721, 0.9760303498043761], 
             UndirectedEdge[125, 281] -> 
             RGBColor[
              0.6284751756921857, 0.6918043473699689, 0.7795957785253096], 
             UndirectedEdge[148, 205] -> 
             RGBColor[
              0.8193703702787432, 0.8596328361332998, 0.9763045721001435], 
             UndirectedEdge[103, 269] -> 
             RGBColor[
              0.9634769896848744, 0.9722817792246958, 0.9467081091235311], 
             UndirectedEdge[40, 169] -> 
             RGBColor[
              0.9458137484025535, 0.9031800118475277, 0.635388653288603], 
             UndirectedEdge[38, 53] -> 
             RGBColor[
              0.9396160930292221, 0.9544863615675427, 0.9870983832430098], 
             UndirectedEdge[118, 285] -> 
             RGBColor[
              0.8551687077870594, 0.8843782736538035, 0.8145434823544542], 
             UndirectedEdge[74, 267] -> 
             RGBColor[
              0.9315251565843704, 0.9469510155129177, 0.948439176845105], 
             UndirectedEdge[3, 200] -> 
             RGBColor[
              0.9781889599046591, 0.9817603132944256, 0.8549168123858238], 
             UndirectedEdge[124, 273] -> 
             RGBColor[
              0.924373317473054, 0.7292628887898269, 0.5452774117484915], 
             UndirectedEdge[131, 182] -> 
             RGBColor[
              0.7843116760304614, 0.832200239820804, 0.9789319879663956], 
             UndirectedEdge[62, 207] -> 
             RGBColor[
              0.7445190218052444, 0.7943751937087041, 0.6988201303657735], 
             UndirectedEdge[75, 262] -> 
             RGBColor[
              0.8943750747261067, 0.9181898432691868, 0.9750670172335245], 
             UndirectedEdge[197, 283] -> 
             RGBColor[
              0.7180374224040664, 0.7769816183988372, 0.9353020126364121], 
             UndirectedEdge[246, 278] -> 
             RGBColor[
              0.9877542164784826, 0.9877614288520582, 0.7609120116808896], 
             UndirectedEdge[225, 265] -> 
             RGBColor[
              0.9842230001419909, 0.9871024197991722, 0.8824060648383008], 
             UndirectedEdge[101, 204] -> 
             RGBColor[
              0.9037412793513835, 0.9241999185881222, 0.9198658721127626], 
             UndirectedEdge[87, 140] -> 
             RGBColor[
              0.5796852097531795, 0.6694148700221433, 0.9602173063020655], 
             UndirectedEdge[57, 247] -> 
             RGBColor[
              0.9602738004628274, 0.9317215564839264, 0.6430208565693847], 
             UndirectedEdge[40, 66] -> 
             RGBColor[
              0.8846827039622843, 0.9108204325969071, 0.9865900920342726], 
             UndirectedEdge[167, 293] -> 
             RGBColor[
              0.8070195901576673, 0.8500538458087459, 0.9811650456456467], 
             UndirectedEdge[42, 140] -> 
             RGBColor[
              0.698719608393988, 0.6134076283491328, 0.5944176084627212], 
             UndirectedEdge[107, 150] -> 
             RGBColor[
              0.9804468209258479, 0.9833914806152606, 0.8487329601110787], 
             UndirectedEdge[91, 143] -> 
             RGBColor[
              0.8551592234269598, 0.8848375910089454, 0.8511081792795194], 
             UndirectedEdge[91, 142] -> 
             RGBColor[
              0.9301455057331067, 0.9437823984339011, 0.8584852636037454], 
             UndirectedEdge[44, 283] -> 
             RGBColor[
              0.9357775860612547, 0.9505077090234777, 0.9549070092637135], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.942620581999922, 0.953698810245736, 0.8580958737883301], 
             UndirectedEdge[199, 233] -> 
             RGBColor[
              0.7750608298555506, 0.8247683376261387, 0.978064369572998], 
             UndirectedEdge[249, 286] -> 
             RGBColor[
              0.9673564418852452, 0.9726487433437461, 0.8033700449112469], 
             UndirectedEdge[48, 266] -> 
             RGBColor[
              0.7256504492736076, 0.7856029132110026, 0.9732897132607456], 
             UndirectedEdge[113, 169] -> 
             RGBColor[
              0.9551051530685712, 0.9101095262341649, 0.6196607287754831], 
             UndirectedEdge[18, 33] -> 
             RGBColor[
              0.8224657640697013, 0.8600396058747701, 0.881512887631525], 
             UndirectedEdge[269, 293] -> 
             RGBColor[
              0.9555344643315355, 0.9661970114499754, 0.9545622545730721], 
             UndirectedEdge[189, 257] -> 
             RGBColor[
              0.9092893887919546, 0.9260953743437291, 0.771742004222436], 
             UndirectedEdge[11, 197] -> 
             RGBColor[
              0.7101681038454984, 0.7711126935026837, 0.9486227163090785], 
             UndirectedEdge[221, 296] -> 
             RGBColor[
              0.8907523695470095, 0.9149928125946333, 0.9629595403177953], 
             UndirectedEdge[126, 157] -> 
             RGBColor[
              0.9893033627588692, 0.9898446798568237, 0.8269344913027444], 
             UndirectedEdge[24, 87] -> 
             RGBColor[
              0.7549769724924504, 0.8087718796912758, 0.9761440125693773], 
             UndirectedEdge[53, 137] -> 
             RGBColor[
              0.9670025619314011, 0.972289108394967, 0.7963747447606986], 
             UndirectedEdge[27, 140] -> 
             RGBColor[
              0.7287093150598272, 0.7864096530215203, 0.9566366600108878], 
             UndirectedEdge[115, 200] -> 
             RGBColor[
              0.9927607504550084, 0.9912743985199881, 0.7696366297451745], 
             UndirectedEdge[1, 5] -> 
             RGBColor[
              0.9872969033120123, 0.9866355635279549, 0.6994154484974782], 
             UndirectedEdge[40, 42] -> 
             RGBColor[
              0.917126415859769, 0.7870778466133888, 0.6121837380784374], 
             UndirectedEdge[82, 167] -> 
             RGBColor[
              0.575763247791871, 0.6658225958313546, 0.960187677016012], 
             UndirectedEdge[52, 57] -> 
             RGBColor[
              0.9500345703648021, 0.9240347962106459, 0.6586072161414809], 
             UndirectedEdge[27, 203] -> 
             RGBColor[
              0.931454102953682, 0.8176817703479234, 0.6016707816867206], 
             UndirectedEdge[251, 270] -> 
             RGBColor[
              0.8474776037727126, 0.8813825256796752, 0.9852711431643997], 
             UndirectedEdge[200, 264] -> 
             RGBColor[
              0.9864990265552884, 0.9879579473959796, 0.8408500371588106], 
             UndirectedEdge[84, 271] -> 
             RGBColor[
              0.7564054107871012, 0.8020610815233233, 0.6876294418654129], 
             UndirectedEdge[80, 145] -> 
             RGBColor[
              0.885058806919856, 0.9109371437736129, 0.9802748915616477], 
             UndirectedEdge[199, 259] -> 
             RGBColor[
              0.9184936587789412, 0.937554023920436, 0.9819674437010781], 
             UndirectedEdge[273, 274] -> 
             RGBColor[
              0.844418825277015, 0.8781478697131178, 0.9271573278973921], 
             UndirectedEdge[281, 294] -> 
             RGBColor[
              0.6167313323428545, 0.6855725652725982, 0.9362804880068414], 
             UndirectedEdge[18, 183] -> 
             RGBColor[
              0.8194123592838514, 0.8587769445268976, 0.9321157068913406], 
             UndirectedEdge[77, 269] -> 
             RGBColor[
              0.933997436100231, 0.9490239697453906, 0.9525080335940382], 
             UndirectedEdge[134, 144] -> 
             RGBColor[
              0.7424861948144714, 0.7950340495867285, 0.8646439716645452], 
             UndirectedEdge[200, 210] -> 
             RGBColor[
              0.9819348633301211, 0.9845540019357812, 0.8485759749746002], 
             UndirectedEdge[87, 151] -> 
             RGBColor[
              0.8151999609687357, 0.8558441647232946, 0.9490241496157579], 
             UndirectedEdge[109, 290] -> 
             RGBColor[
              0.6504545246211346, 0.7268592853622963, 0.9657948862372558], 
             UndirectedEdge[247, 278] -> 
             RGBColor[
              0.974190653066044, 0.9776457454673583, 0.7838715865942469], 
             UndirectedEdge[156, 205] -> 
             RGBColor[
              0.6499321646660143, 0.7202961065876098, 0.9631209750744216], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.7440375243373503, 0.760341296410477, 0.6395825384875091], 
             UndirectedEdge[64, 121] -> 
             RGBColor[
              0.8532453455354061, 0.886054425697143, 0.9858019409054235], 
             UndirectedEdge[106, 264] -> 
             RGBColor[
              0.9162339920214382, 0.9349064835494534, 0.9524294588383193], 
             UndirectedEdge[91, 107] -> 
             RGBColor[
              0.9943269966605883, 0.9919220815766869, 0.7436798768034676], 
             UndirectedEdge[7, 299] -> 
             RGBColor[0.9434237313873398, 0.955918979643898, 0.9270096652848],
              UndirectedEdge[160, 221] -> 
             RGBColor[
              0.9800444995010658, 0.9824447728805603, 0.8083381596995168], 
             UndirectedEdge[8, 234] -> 
             RGBColor[
              0.5794901576376081, 0.6665117860615423, 0.961554047173995], 
             UndirectedEdge[49, 174] -> 
             RGBColor[
              0.7954954836396635, 0.8405261960192196, 0.9801557307394525], 
             UndirectedEdge[79, 245] -> 
             RGBColor[
              0.9415358980829036, 0.9535551569670804, 0.8895498887268862], 
             UndirectedEdge[13, 147] -> 
             RGBColor[
              0.8473077033109992, 0.8814993764534695, 0.9811991124559027], 
             UndirectedEdge[1, 197] -> 
             RGBColor[
              0.7192545581310688, 0.7778893562311587, 0.9332417193304356], 
             UndirectedEdge[129, 175] -> 
             RGBColor[
              0.9655641134819745, 0.890856958685221, 0.3449139786179085], 
             UndirectedEdge[116, 283] -> 
             RGBColor[
              0.9861781678832184, 0.9859382939837052, 0.7121860070072074], 
             UndirectedEdge[62, 265] -> 
             RGBColor[
              0.9865033817373343, 0.9857967766016924, 0.6811618799973971], 
             UndirectedEdge[31, 291] -> 
             RGBColor[
              0.9026018449389723, 0.9020369387426319, 0.6773617905225464], 
             UndirectedEdge[92, 277] -> 
             RGBColor[
              0.8389845315536137, 0.8712931108582254, 0.7775315439785776], 
             UndirectedEdge[124, 289] -> 
             RGBColor[
              0.8842210252629561, 0.6988254030570268, 0.5990618811360591], 
             UndirectedEdge[80, 277] -> 
             RGBColor[
              0.7543818724359451, 0.8080868248518951, 0.9761431217616515], 
             UndirectedEdge[119, 244] -> 
             RGBColor[
              0.8212192943754354, 0.8611354709909125, 0.9794370206945514], 
             UndirectedEdge[252, 268] -> 
             RGBColor[
              0.9585522904145318, 0.9686089465723291, 0.955044340420942], 
             UndirectedEdge[3, 194] -> 
             RGBColor[
              0.9746497974138966, 0.9802967786521679, 0.913569893916685], 
             UndirectedEdge[1, 237] -> 
             RGBColor[
              0.9750184873062403, 0.9808894092532425, 0.9271713641552379], 
             UndirectedEdge[149, 281] -> 
             RGBColor[
              0.5653233427769391, 0.6454866946536288, 0.9627701820722279], 
             UndirectedEdge[29, 209] -> 
             RGBColor[
              0.8150435669165887, 0.8523871002739585, 0.7664077825669985], 
             UndirectedEdge[123, 287] -> 
             RGBColor[
              0.92937220038433, 0.9454856609245484, 0.9572580587022372], 
             UndirectedEdge[17, 81] -> 
             RGBColor[
              0.8246440180191588, 0.8394651378727639, 0.6672443741967713], 
             UndirectedEdge[176, 187] -> 
             RGBColor[
              0.8456113305783851, 0.8795811056108378, 0.9510098604287887], 
             UndirectedEdge[246, 270] -> 
             RGBColor[
              0.9382369168468883, 0.9524114082261455, 0.9531548025949952], 
             UndirectedEdge[45, 131] -> 
             RGBColor[
              0.6880813133667263, 0.7562536187045387, 0.9695451728970839], 
             UndirectedEdge[4, 158] -> 
             RGBColor[
              0.8463715499416651, 0.6698389569631827, 0.5956874315650266], 
             UndirectedEdge[169, 264] -> 
             RGBColor[
              0.9666009562847491, 0.9186830774501402, 0.6002013325161637], 
             UndirectedEdge[42, 181] -> 
             RGBColor[
              0.9435909685825823, 0.8056557075812142, 0.5154676832262145], 
             UndirectedEdge[8, 263] -> 
             RGBColor[
              0.8586770961683179, 0.8899536465213231, 0.960687971785076], 
             UndirectedEdge[145, 205] -> 
             RGBColor[
              0.9439129491324874, 0.9576909498139017, 0.9798249266597374], 
             UndirectedEdge[167, 269] -> 
             RGBColor[
              0.8331079660074704, 0.8696717591726261, 0.9425947085013712], 
             UndirectedEdge[187, 288] -> 
             RGBColor[
              0.4482630166864703, 0.542353542958187, 0.9529941116842633], 
             UndirectedEdge[47, 131] -> 
             RGBColor[
              0.7713633266029553, 0.8218755774608928, 0.9776969628388721], 
             UndirectedEdge[43, 97] -> 
             RGBColor[
              0.9464517416852463, 0.9552053597996337, 0.7329500082985296], 
             UndirectedEdge[104, 114] -> 
             RGBColor[
              0.9743061905126518, 0.977645635509391, 0.7768302535784322], 
             UndirectedEdge[26, 129] -> 
             RGBColor[
              0.943523825289827, 0.9504611733766095, 0.7045002408128483], 
             UndirectedEdge[28, 79] -> 
             RGBColor[
              0.7347076133582711, 0.7922691726934941, 0.9747141278523986], 
             UndirectedEdge[53, 247] -> 
             RGBColor[
              0.947033459471043, 0.9600182213150299, 0.9745427166160054], 
             UndirectedEdge[150, 281] -> 
             RGBColor[
              0.6150222850639615, 0.684297960610308, 0.9391734592590881], 
             UndirectedEdge[76, 248] -> 
             RGBColor[
              0.989076433443375, 0.9897508387530495, 0.830695297334724], 
             UndirectedEdge[194, 210] -> 
             RGBColor[
              0.9783957008393586, 0.9830904672935236, 0.9072290565054614], 
             UndirectedEdge[60, 265] -> 
             RGBColor[
              0.6692757452045099, 0.7347728755947271, 0.9311122891113798], 
             UndirectedEdge[78, 178] -> 
             RGBColor[
              0.7982370225647868, 0.8397091361872926, 0.8442862415442333], 
             UndirectedEdge[120, 190] -> 
             RGBColor[
              0.5681167733273671, 0.6589178179723325, 0.9598740395159635], 
             UndirectedEdge[96, 267] -> 
             RGBColor[
              0.9587556765504782, 0.9686638929811183, 0.9510364481484446], 
             UndirectedEdge[159, 212] -> 
             RGBColor[
              0.8380665878401614, 0.8737155647049735, 0.9844167333707113], 
             UndirectedEdge[34, 147] -> 
             RGBColor[
              0.8711937499172541, 0.8986977294462362, 0.9131885230171412], 
             UndirectedEdge[41, 250] -> 
             RGBColor[
              0.9923326001078363, 0.9901140345278625, 0.705255727335049], 
             UndirectedEdge[146, 236] -> 
             RGBColor[
              0.7312016324374107, 0.7899395396891202, 0.9738430033197574], 
             UndirectedEdge[82, 103] -> 
             RGBColor[
              0.706132271469275, 0.7684326158834243, 0.964301077638172], 
             UndirectedEdge[179, 289] -> 
             RGBColor[
              0.8603908591769793, 0.8915551340981751, 0.9865357455999633], 
             UndirectedEdge[124, 247] -> 
             RGBColor[
              0.9085341629542371, 0.7177343152191248, 0.5848179034341332], 
             UndirectedEdge[162, 227] -> 
             RGBColor[
              0.9693296661321291, 0.9766466957361801, 0.9368010545208184], 
             UndirectedEdge[156, 191] -> 
             RGBColor[
              0.6726008453480521, 0.7272699266079263, 0.6755851178628637], 
             UndirectedEdge[1, 51] -> 
             RGBColor[
              0.9751672380435219, 0.9810003473095501, 0.9269195679574259], 
             UndirectedEdge[23, 198] -> 
             RGBColor[
              0.6322898086261564, 0.6959570554088171, 0.7941421514798737], 
             UndirectedEdge[77, 159] -> 
             RGBColor[
              0.8685023022015892, 0.8979841771813182, 0.9873197189767873], 
             UndirectedEdge[2, 238] -> 
             RGBColor[
              0.9509589147958082, 0.8301899758475706, 0.47059375420887356`], 
             UndirectedEdge[113, 245] -> 
             RGBColor[
              0.9741905554170998, 0.9790483371096399, 0.8737774440030142], 
             UndirectedEdge[167, 201] -> 
             RGBColor[
              0.7546226726648919, 0.8082739660764431, 0.9761673808799052], 
             UndirectedEdge[125, 150] -> 
             RGBColor[
              0.980846689062318, 0.9827093155363387, 0.7805002928446547], 
             UndirectedEdge[142, 198] -> 
             RGBColor[
              0.929849938120709, 0.9430399146333736, 0.8182973025462277], 
             UndirectedEdge[34, 52] -> 
             RGBColor[
              0.9608224250132018, 0.9696358285512727, 0.9218778655133039], 
             UndirectedEdge[13, 251] -> 
             RGBColor[
              0.8699798588432351, 0.8992110366700163, 0.9834588610360164], 
             UndirectedEdge[120, 188] -> 
             RGBColor[
              0.5736428361090802, 0.6632348202170395, 0.9604248258100518], 
             UndirectedEdge[67, 173] -> 
             RGBColor[
              0.9133042376071296, 0.9337080243575564, 0.9915929675709276], 
             UndirectedEdge[20, 280] -> 
             RGBColor[
              0.9830499082606798, 0.9859990773188204, 0.8741612347695364], 
             UndirectedEdge[32, 107] -> 
             RGBColor[
              0.9899092664734752, 0.978545950545592, 0.5793695341371403], 
             UndirectedEdge[189, 287] -> 
             RGBColor[
              0.8538818812980755, 0.8863262504136096, 0.9859252101792063], 
             UndirectedEdge[159, 205] -> 
             RGBColor[
              0.8965567920267186, 0.9201791764421053, 0.9839320557349828], 
             UndirectedEdge[66, 86] -> 
             RGBColor[
              0.6440370202424384, 0.719095692739643, 0.9670732366161485], 
             UndirectedEdge[119, 266] -> 
             RGBColor[
              0.8274498614422533, 0.8660028373375743, 0.9800580253918122], 
             UndirectedEdge[28, 230] -> 
             RGBColor[
              0.693760578911182, 0.7597028817585059, 0.9707863350666136], 
             UndirectedEdge[83, 142] -> 
             RGBColor[
              0.6379154365265752, 0.7127224548326534, 0.9671943786936842], 
             UndirectedEdge[191, 217] -> 
             RGBColor[
              0.9416438912995769, 0.9450288349149806, 0.6985344873017758], 
             UndirectedEdge[43, 233] -> 
             RGBColor[
              0.7800461327717316, 0.8287434828490587, 0.9785398722155758], 
             UndirectedEdge[113, 297] -> 
             RGBColor[
              0.9605501177982572, 0.9700989229639694, 0.9516625397771278], 
             UndirectedEdge[158, 207] -> 
             RGBColor[
              0.6799220499405582, 0.5374958764538105, 0.580646292990628], 
             UndirectedEdge[40, 201] -> 
             RGBColor[
              0.8814467539890556, 0.9082401739257766, 0.9862814442370593], 
             UndirectedEdge[194, 226] -> 
             RGBColor[
              0.9881733377612096, 0.9893773854799737, 0.8456619299249105], 
             UndirectedEdge[134, 230] -> 
             RGBColor[
              0.9009960320754059, 0.9211572406456148, 0.8788742611789295], 
             UndirectedEdge[134, 264] -> 
             RGBColor[
              0.986093527072869, 0.9877902629391377, 0.847570212981523], 
             UndirectedEdge[59, 226] -> 
             RGBColor[
              0.9905516457878274, 0.9903608769687084, 0.8062472110599821], 
             UndirectedEdge[42, 201] -> 
             RGBColor[
              0.8603319153668948, 0.7418570113091016, 0.6090395560272429], 
             UndirectedEdge[217, 295] -> 
             RGBColor[
              0.7767060947608437, 0.8260980919667813, 0.9782165556491531], 
             UndirectedEdge[45, 94] -> 
             RGBColor[
              0.8587283164716385, 0.8871236629793451, 0.8120625881368584], 
             UndirectedEdge[197, 254] -> 
             RGBColor[
              0.7167776873501268, 0.776042110058236, 0.9374344154912093], 
             UndirectedEdge[30, 189] -> 
             RGBColor[
              0.822818152539635, 0.8615568763040835, 0.9829623239993082], 
             UndirectedEdge[92, 179] -> 
             RGBColor[
              0.9045807262788654, 0.9225373567271367, 0.7840695596374987], 
             UndirectedEdge[134, 288] -> 
             RGBColor[
              0.5856491919497085, 0.6482536927214936, 0.8547952206098354], 
             UndirectedEdge[59, 83] -> 
             RGBColor[
              0.7007773427132389, 0.7603164557733301, 0.8742579260246], 
             UndirectedEdge[10, 22] -> 
             RGBColor[
              0.9729931943589879, 0.9759245842930293, 0.7201925032388871], 
             UndirectedEdge[148, 168] -> 
             RGBColor[
              0.837747823257458, 0.8733387104745077, 0.9451963378145605], 
             UndirectedEdge[130, 216] -> 
             RGBColor[
              0.8446606398637772, 0.878988785724784, 0.9585266536289563], 
             UndirectedEdge[158, 196] -> 
             RGBColor[
              0.929038700641771, 0.7325082444275515, 0.473510709384165], 
             UndirectedEdge[203, 237] -> 
             RGBColor[
              0.9376952023086988, 0.8223363720280328, 0.5911062284180857], 
             UndirectedEdge[160, 193] -> 
             RGBColor[
              0.903513269587062, 0.9222469699678701, 0.8274962313173316], 
             UndirectedEdge[38, 88] -> 
             RGBColor[
              0.8942259282422569, 0.9184003213807033, 0.9864734165725701], 
             UndirectedEdge[22, 73] -> 
             RGBColor[
              0.8474833795488064, 0.8772467173912487, 0.7234528968550707], 
             UndirectedEdge[181, 227] -> 
             RGBColor[
              0.9810445327832358, 0.9842242649821211, 0.8650523708537584], 
             UndirectedEdge[85, 255] -> 
             RGBColor[
              0.9067957014635719, 0.5727130354425111, 0.3359560343463967], 
             UndirectedEdge[106, 227] -> 
             RGBColor[
              0.9117855097177353, 0.931588812731073, 0.959959579028486], 
             UndirectedEdge[131, 261] -> 
             RGBColor[
              0.8202997102567305, 0.8590459579234362, 0.9129694866480995], 
             UndirectedEdge[81, 94] -> 
             RGBColor[
              0.985969167550415, 0.9630528792871189, 0.5088326741899983], 
             UndirectedEdge[77, 154] -> 
             RGBColor[
              0.9369359966623958, 0.9506659708437738, 0.9229228350974581], 
             UndirectedEdge[167, 277] -> 
             RGBColor[
              0.6842920547306865, 0.7532934210586322, 0.9691674950088787], 
             UndirectedEdge[113, 176] -> 
             RGBColor[
              0.9652238457988974, 0.9735845816543197, 0.9437511373755325], 
             UndirectedEdge[4, 276] -> 
             RGBColor[
              0.8469509354462058, 0.8807997023268419, 0.9852641303765266], 
             UndirectedEdge[101, 243] -> 
             RGBColor[
              0.8338721892195222, 0.8703710650987935, 0.9840166678858909], 
             UndirectedEdge[52, 271] -> 
             RGBColor[
              0.9624024568145532, 0.9657545813234925, 0.7066541195193846], 
             UndirectedEdge[37, 71] -> 
             RGBColor[
              0.9260692303849374, 0.9421583975326537, 0.9287164779337025], 
             UndirectedEdge[83, 291] -> 
             RGBColor[
              0.6186442696850651, 0.6973561494951219, 0.9653562775967672], 
             UndirectedEdge[80, 149] -> 
             RGBColor[
              0.8463843205520842, 0.880347898990621, 0.9852100861421021], 
             UndirectedEdge[104, 206] -> 
             RGBColor[
              0.9689628424456727, 0.9736605752699674, 0.7858751480874548], 
             UndirectedEdge[61, 108] -> 
             RGBColor[
              0.8753336332551385, 0.9018921357065852, 0.911800887586024], 
             UndirectedEdge[115, 264] -> 
             RGBColor[
              0.986077394146041, 0.9877835915592971, 0.8478375773297391], 
             UndirectedEdge[38, 52] -> 
             RGBColor[
              0.9365679901184001, 0.9521627321760884, 0.9905120402335215], 
             UndirectedEdge[33, 285] -> 
             RGBColor[
              0.8534121160699515, 0.8842151312583522, 0.8845973307888082], 
             UndirectedEdge[100, 122] -> 
             RGBColor[
              0.8361544328963624, 0.8681391731081667, 0.7017165106004697], 
             UndirectedEdge[205, 269] -> 
             RGBColor[
              0.9620519259253603, 0.9712189690061779, 0.9491203703522337], 
             UndirectedEdge[177, 252] -> 
             RGBColor[
              0.9772059326302767, 0.9812482237479973, 0.8664799179869452], 
             UndirectedEdge[152, 244] -> 
             RGBColor[
              0.8258018214734743, 0.8645531121974304, 0.9716799976320555], 
             UndirectedEdge[10, 71] -> 
             RGBColor[
              0.9092382881617138, 0.9300193237521172, 0.9757204578934631], 
             UndirectedEdge[233, 259] -> 
             RGBColor[
              0.8035858758006296, 0.8472215309545615, 0.970664618425981], 
             UndirectedEdge[130, 299] -> 
             RGBColor[
              0.9324470846933515, 0.9482130526914336, 0.9671052682316653], 
             UndirectedEdge[81, 86] -> 
             RGBColor[
              0.7171556408141231, 0.7526541695180605, 0.6584728188354507], 
             UndirectedEdge[205, 282] -> 
             RGBColor[
              0.8895337083127414, 0.914579160125109, 0.9832621877407628], 
             UndirectedEdge[176, 297] -> 
             RGBColor[
              0.9689498997831895, 0.9763634666149512, 0.9374438998906461], 
             UndirectedEdge[92, 128] -> 
             RGBColor[
              0.9938201488903191, 0.9891902482922119, 0.5687395282105274], 
             UndirectedEdge[166, 285] -> 
             RGBColor[
              0.7996308789418907, 0.8439107952264819, 0.9805270422356449], 
             UndirectedEdge[132, 146] -> 
             RGBColor[
              0.7700400872375528, 0.8204473689800309, 0.9776697585849486], 
             UndirectedEdge[81, 130] -> 
             RGBColor[
              0.9712459660522331, 0.9544059010060659, 0.6552314030872575], 
             UndirectedEdge[1, 128] -> 
             RGBColor[
              0.987613018817171, 0.9873117026293092, 0.7338226703952513], 
             UndirectedEdge[296, 297] -> 
             RGBColor[
              0.8902353042352406, 0.9146071861317326, 0.9638347970183885], 
             UndirectedEdge[128, 237] -> 
             RGBColor[
              0.981067720790251, 0.9824302300777742, 0.7449021526676979], 
             UndirectedEdge[112, 146] -> 
             RGBColor[
              0.4758585959249001, 0.5738080235414069, 0.9541778034254523], 
             UndirectedEdge[116, 287] -> 
             RGBColor[
              0.9380773431912491, 0.9487039554050378, 0.7464275937529378], 
             UndirectedEdge[10, 266] -> 
             RGBColor[
              0.8343634238477153, 0.8711589608596484, 0.9683551675852264], 
             UndirectedEdge[16, 76] -> 
             RGBColor[
              0.9551336529062575, 0.9651319881639426, 0.9227348932504824], 
             UndirectedEdge[23, 72] -> 
             RGBColor[
              0.5509723768063708, 0.6349779447712403, 0.9612598309501805], 
             UndirectedEdge[237, 277] -> 
             RGBColor[
              0.8262321034535456, 0.8645330926437875, 0.9536941684357481], 
             UndirectedEdge[56, 278] -> 
             RGBColor[
              0.9946498967594148, 0.9909649950838293, 0.6590524631513169], 
             UndirectedEdge[88, 274] -> 
             RGBColor[
              0.7759983787840297, 0.82517012507375, 0.9782455554941785], 
             UndirectedEdge[103, 282] -> 
             RGBColor[
              0.8909587720722555, 0.9156419703436268, 0.98084992651206], 
             UndirectedEdge[46, 60] -> 
             RGBColor[
              0.6406010409669843, 0.7130593893760331, 0.9682812415367514], 
             UndirectedEdge[82, 216] -> 
             RGBColor[
              0.595562072979618, 0.681289588544667, 0.9621610388801858], 
             UndirectedEdge[48, 70] -> 
             RGBColor[
              0.771013149953881, 0.8210405997517265, 0.9778110433260155], 
             UndirectedEdge[143, 174] -> 
             RGBColor[
              0.7208273312279956, 0.7818350567367157, 0.9728089899285598], 
             UndirectedEdge[95, 205] -> 
             RGBColor[
              0.9414707925173612, 0.9558695934090051, 0.9839588607926892], 
             UndirectedEdge[78, 190] -> 
             RGBColor[
              0.8476024675400451, 0.8789042774935423, 0.8487754647916305], 
             UndirectedEdge[68, 292] -> 
             RGBColor[
              0.6033845539172589, 0.6767428251089223, 0.9653170542514516], 
             UndirectedEdge[145, 269] -> 
             RGBColor[
              0.9634838633884655, 0.9722869056215793, 0.9466964737363004], 
             UndirectedEdge[198, 254] -> 
             RGBColor[
              0.9855865292250279, 0.9864277762787037, 0.787036579526257], 
             UndirectedEdge[124, 147] -> 
             RGBColor[
              0.8086662577602641, 0.6391094558408078, 0.5917149205100667], 
             UndirectedEdge[44, 194] -> 
             RGBColor[
              0.9392648580630424, 0.9527908484894883, 0.9347784013343257], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.7664230669221025, 0.8175889830599083, 0.9773179365652356], 
             UndirectedEdge[5, 11] -> 
             RGBColor[
              0.9782104490264418, 0.97985890079948, 0.7147964454761209], 
             UndirectedEdge[108, 254] -> 
             RGBColor[
              0.8695813139685316, 0.8982537654571588, 0.9507225237005397], 
             UndirectedEdge[61, 71] -> 
             RGBColor[
              0.9267863663714506, 0.9424549516926313, 0.9168316787487358], 
             UndirectedEdge[229, 284] -> 
             RGBColor[
              0.9818524281124663, 0.9859311494881025, 0.9131401996316995], 
             UndirectedEdge[37, 136] -> 
             RGBColor[
              0.9125953130797683, 0.931414661613254, 0.9274313236728275], 
             UndirectedEdge[148, 159] -> 
             RGBColor[
              0.7734461506360797, 0.8231889993769048, 0.9779878045594557], 
             UndirectedEdge[164, 230] -> 
             RGBColor[
              0.6904999100227169, 0.7570557238633903, 0.9705296432674899], 
             UndirectedEdge[176, 193] -> 
             RGBColor[
              0.8929357351809547, 0.9165512901651616, 0.9557267148078676], 
             UndirectedEdge[216, 299] -> 
             RGBColor[
              0.8119771870386705, 0.8536868459246714, 0.9817228379050023], 
             UndirectedEdge[149, 277] -> 
             RGBColor[
              0.7759934657439099, 0.8253193227245936, 0.9782044548242623], 
             UndirectedEdge[39, 248] -> 
             RGBColor[
              0.987153801487513, 0.9889048631392194, 0.8602780772787593], 
             UndirectedEdge[13, 137] -> 
             RGBColor[
              0.9671447109653303, 0.9723951229117237, 0.7961341235246624], 
             UndirectedEdge[68, 75] -> 
             RGBColor[
              0.6110901735348231, 0.6824896636029074, 0.952273450186383], 
             UndirectedEdge[66, 97] -> 
             RGBColor[
              0.9120442090734535, 0.9277697272625823, 0.72966818712205], 
             UndirectedEdge[59, 106] -> 
             RGBColor[
              0.9217564938662608, 0.9379172473566215, 0.8934668739196875], 
             UndirectedEdge[51, 198] -> 
             RGBColor[
              0.9816668527163314, 0.9835044879563991, 0.793671569440118], 
             UndirectedEdge[193, 228] -> 
             RGBColor[
              0.8990467443951413, 0.9208341401152684, 0.9330793674456318], 
             UndirectedEdge[30, 287] -> 
             RGBColor[
              0.8518641357367764, 0.8847173548732739, 0.9857327558063069], 
             UndirectedEdge[93, 147] -> 
             RGBColor[
              0.8636173373465067, 0.8936630748125763, 0.9535911562676143], 
             UndirectedEdge[69, 121] -> 
             RGBColor[
              0.7054754116251217, 0.769501531847588, 0.9715116479810378], 
             UndirectedEdge[148, 251] -> 
             RGBColor[
              0.7480464081114383, 0.8030988064707074, 0.975521933135566], 
             UndirectedEdge[125, 269] -> 
             RGBColor[
              0.9879612099359403, 0.9880153135549274, 0.7684572647698364], 
             UndirectedEdge[37, 44] -> 
             RGBColor[
              0.9395530343074088, 0.9529100167723253, 0.9300025751889617], 
             UndirectedEdge[91, 105] -> 
             RGBColor[
              0.8276535983904068, 0.8633499876798973, 0.8483666756305559], 
             UndirectedEdge[81, 203] -> 
             RGBColor[
              0.9421393049620428, 0.8019808084374718, 0.30525766631369133`], 
             UndirectedEdge[8, 69] -> 
             RGBColor[
              0.6866042523731373, 0.7547592388138153, 0.9696307471878097], 
             UndirectedEdge[52, 270] -> 
             RGBColor[
              0.9144341233364244, 0.934608964568165, 0.9917007370804487], 
             UndirectedEdge[108, 268] -> 
             RGBColor[
              0.8585485726530275, 0.8900255650485118, 0.9693980769479047], 
             UndirectedEdge[11, 254] -> 
             RGBColor[
              0.9700004602666481, 0.9771469729033798, 0.9356655750222078], 
             UndirectedEdge[82, 255] -> 
             RGBColor[
              0.6436461279361, 0.36780461680658083`, 0.5591534101415926], 
             UndirectedEdge[43, 66] -> 
             RGBColor[
              0.8655316860544315, 0.8956154885008019, 0.9870363789567711], 
             UndirectedEdge[252, 283] -> 
             RGBColor[
              0.9708447667839755, 0.9777766553215775, 0.9342363843187798], 
             UndirectedEdge[99, 215] -> 
             RGBColor[
              0.9232718440137402, 0.7262632337364725, 0.5528014202735045], 
             UndirectedEdge[114, 283] -> 
             RGBColor[
              0.9668545197834686, 0.9748007356420293, 0.9409908316675437], 
             UndirectedEdge[24, 194] -> 
             RGBColor[
              0.9190576114558201, 0.9366781385559861, 0.9328510161137067], 
             UndirectedEdge[134, 228] -> 
             RGBColor[
              0.9891085150558101, 0.9897641053242512, 0.8301636219921249], 
             UndirectedEdge[49, 143] -> 
             RGBColor[
              0.7898324493620128, 0.8361021906008643, 0.9795912924067205], 
             UndirectedEdge[123, 189] -> 
             RGBColor[
              0.9003262171871885, 0.9223251823553582, 0.9544876268952387], 
             UndirectedEdge[232, 240] -> 
             RGBColor[
              0.6619524035901625, 0.7357023655886437, 0.9670360251185859], 
             UndirectedEdge[11, 243] -> 
             RGBColor[
              0.9055697786865997, 0.9268266795075021, 0.9660970479312971], 
             UndirectedEdge[155, 210] -> 
             RGBColor[
              0.9436394936112696, 0.8423399702140026, 0.5931243713557213], 
             UndirectedEdge[148, 156] -> 
             RGBColor[
              0.5268215232753755, 0.6233059295224093, 0.9571767238988944], 
             UndirectedEdge[15, 212] -> 
             RGBColor[
              0.905128412109965, 0.9119685424347611, 0.6892497023460153], 
             UndirectedEdge[51, 204] -> 
             RGBColor[
              0.9781287758143928, 0.9826616612300785, 0.8973929412541606], 
             UndirectedEdge[95, 156] -> 
             RGBColor[
              0.6489219455139934, 0.7195426867981147, 0.9648310125914401], 
             UndirectedEdge[87, 109] -> 
             RGBColor[
              0.6573654491243449, 0.7322581521091758, 0.9664837026054744], 
             UndirectedEdge[113, 288] -> 
             RGBColor[
              0.5678755319069826, 0.636357019001669, 0.9457353886310071], 
             UndirectedEdge[164, 176] -> 
             RGBColor[
              0.7725013837889343, 0.8213797385919199, 0.9444663514429212], 
             UndirectedEdge[17, 294] -> 
             RGBColor[
              0.8213692672220945, 0.8606928021631003, 0.9511135286242934], 
             UndirectedEdge[77, 212] -> 
             RGBColor[
              0.8559363176576956, 0.8879644022005813, 0.9861211641532038], 
             UndirectedEdge[180, 296] -> 
             RGBColor[
              0.6710780252991144, 0.7411874613343782, 0.96906953156694], 
             UndirectedEdge[217, 271] -> 
             RGBColor[
              0.9432640983663032, 0.9504941737937588, 0.7048286858055763], 
             UndirectedEdge[4, 85] -> 
             RGBColor[
              0.9112470744413047, 0.9273140701382504, 0.7441800042272653], 
             UndirectedEdge[95, 127] -> 
             RGBColor[
              0.959277915193939, 0.9691501163447095, 0.9538160469426581], 
             UndirectedEdge[54, 75] -> 
             RGBColor[
              0.9408334243737543, 0.9552344701999145, 0.9794982560967755], 
             UndirectedEdge[134, 193] -> 
             RGBColor[
              0.9023096132387484, 0.9221834202340045, 0.8790051866731776], 
             UndirectedEdge[40, 178] -> 
             RGBColor[
              0.7697213742227608, 0.820291245852595, 0.9755867783240777], 
             UndirectedEdge[69, 239] -> 
             RGBColor[
              0.6065737296028015, 0.6914829053834944, 0.9621708524285677], 
             UndirectedEdge[134, 200] -> 
             RGBColor[
              0.9927768833818365, 0.9912810698998289, 0.7693692653969584], 
             UndirectedEdge[89, 141] -> 
             RGBColor[
              0.9786333011143125, 0.9832094132598138, 0.9042180416586361], 
             UndirectedEdge[38, 147] -> 
             RGBColor[
              0.8469393150224525, 0.8812246330710518, 0.9818226977373588], 
             UndirectedEdge[170, 182] -> 
             RGBColor[
              0.8782075843297996, 0.9057229057074878, 0.9882454174501836], 
             UndirectedEdge[94, 120] -> 
             RGBColor[
              0.7154390516277238, 0.7715664099553459, 0.800066664169166], 
             UndirectedEdge[80, 269] -> 
             RGBColor[
              0.903197783712729, 0.924465162965889, 0.949570335254144], 
             UndirectedEdge[263, 286] -> 
             RGBColor[
              0.9792889658272119, 0.9815480001619501, 0.7831713943781744], 
             UndirectedEdge[130, 140] -> 
             RGBColor[
              0.7332790885344129, 0.7898177825965491, 0.9489012255062204], 
             UndirectedEdge[25, 288] -> 
             RGBColor[
              0.5620870344394855, 0.6320399670682044, 0.9555338049615488], 
             UndirectedEdge[148, 191] -> 
             RGBColor[
              0.842039050960781, 0.8666066561536163, 0.6887687148885856], 
             UndirectedEdge[177, 268] -> 
             RGBColor[
              0.973198203356013, 0.9782592658173059, 0.873263958265072], 
             UndirectedEdge[69, 126] -> 
             RGBColor[
              0.8058264587017878, 0.8466259166674853, 0.8767114075825535], 
             UndirectedEdge[20, 37] -> 
             RGBColor[
              0.98164522707137, 0.9854182055483809, 0.8974404372747895], 
             UndirectedEdge[3, 72] -> 
             RGBColor[
              0.8975618439921353, 0.9204464070277512, 0.9655078894930954], 
             UndirectedEdge[87, 154] -> 
             RGBColor[
              0.8227213706308298, 0.8609040471766782, 0.911681382991473], 
             UndirectedEdge[11, 204] -> 
             RGBColor[
              0.9754388688184609, 0.980655532996831, 0.9019462521581687], 
             UndirectedEdge[55, 268] -> 
             RGBColor[
              0.9462787572325616, 0.8787845175365774, 0.6154051759012495], 
             UndirectedEdge[125, 142] -> 
             RGBColor[
              0.9297182206265905, 0.9427581842321355, 0.803960666177578], 
             UndirectedEdge[176, 221] -> 
             RGBColor[
              0.9694669650949584, 0.9767490930778518, 0.9365686431900528], 
             UndirectedEdge[29, 182] -> 
             RGBColor[
              0.7758056890150833, 0.8254620371125667, 0.9781479537314015], 
             UndirectedEdge[122, 161] -> 
             RGBColor[
              0.9592653107335688, 0.965170743699854, 0.7137597855880706], 
             UndirectedEdge[44, 226] -> 
             RGBColor[
              0.9413341379415212, 0.9536465488973065, 0.9004850786232679], 
             UndirectedEdge[89, 131] -> 
             RGBColor[
              0.8198688217708714, 0.8588677744612044, 0.9201104239624421], 
             UndirectedEdge[56, 110] -> 
             RGBColor[
              0.9377795608183506, 0.7709494388664959, 0.46733016239961717`], 
             UndirectedEdge[43, 178] -> 
             RGBColor[
              0.750570356314908, 0.8050863017564898, 0.9760330652465762], 
             UndirectedEdge[66, 162] -> 
             RGBColor[
              0.8994323900339909, 0.9218207243187915, 0.9616227208491097], 
             UndirectedEdge[5, 142] -> 
             RGBColor[
              0.9290834414267515, 0.941400455709702, 0.7348688676782223], 
             UndirectedEdge[147, 273] -> 
             RGBColor[
              0.8701958359830902, 0.8982850663892411, 0.929726539424713], 
             UndirectedEdge[81, 167] -> 
             RGBColor[
              0.8309772432098053, 0.8444127015259911, 0.6678756108964206], 
             UndirectedEdge[95, 212] -> 
             RGBColor[
              0.8829805883308042, 0.9094059816718734, 0.9844435384284178], 
             UndirectedEdge[56, 217] -> 
             RGBColor[
              0.9453062418053421, 0.955753434010313, 0.8513118164497789], 
             UndirectedEdge[6, 93] -> 
             RGBColor[
              0.8190347591009621, 0.8588348258470127, 0.9491475815159796], 
             UndirectedEdge[131, 146] -> 
             RGBColor[
              0.6763628868991887, 0.7470990948847585, 0.9683771896617213], 
             UndirectedEdge[7, 80] -> 
             RGBColor[
              0.9059282790752772, 0.9260211237571989, 0.92343331557069], 
             UndirectedEdge[76, 239] -> 
             RGBColor[
              0.7903730982302093, 0.8348350159596242, 0.9070498637068929], 
             UndirectedEdge[148, 278] -> 
             RGBColor[
              0.8452082241809729, 0.8762763989029798, 0.7878667400393446], 
             UndirectedEdge[29, 170] -> 
             RGBColor[
              0.7386728555889575, 0.7958533236824861, 0.974606190930346], 
             UndirectedEdge[147, 289] -> 
             RGBColor[
              0.8300435437729925, 0.867847580656441, 0.9835110088122804], 
             UndirectedEdge[25, 28] -> 
             RGBColor[
              0.7615737732249701, 0.813445300902589, 0.9687400994590682], 
             UndirectedEdge[5, 149] -> 
             RGBColor[
              0.9305129675754567, 0.9425403210572258, 0.7350052171584389], 
             UndirectedEdge[140, 202] -> 
             RGBColor[
              0.6456173035211308, 0.7209215227761387, 0.9667888012384078], 
             UndirectedEdge[10, 63] -> 
             RGBColor[
              0.9694071359504596, 0.9764380321260919, 0.9247381695412549], 
             UndirectedEdge[43, 259] -> 
             RGBColor[
              0.9234789616951222, 0.941529169143356, 0.9824429463436559], 
             UndirectedEdge[21, 50] -> 
             RGBColor[
              0.9778344685447361, 0.9474512112790772, 0.599067589032432], 
             UndirectedEdge[87, 155] -> 
             RGBColor[
              0.7872672116912722, 0.7198649291279242, 0.6091435639418988], 
             UndirectedEdge[127, 282] -> 
             RGBColor[
              0.9073408309893192, 0.9278596830608132, 0.9531193738907315], 
             UndirectedEdge[79, 144] -> 
             RGBColor[
              0.6920578774375492, 0.7576441957243445, 0.971356584409589], 
             UndirectedEdge[54, 298] -> 
             RGBColor[
              0.7364083007795915, 0.7933749799392932, 0.9751644025723973], 
             UndirectedEdge[234, 263] -> 
             RGBColor[
              0.6850907931422323, 0.7494371108285209, 0.9462187371936098], 
             UndirectedEdge[34, 38] -> 
             RGBColor[
              0.9636442886694061, 0.971790729077066, 0.9188471725682119], 
             UndirectedEdge[39, 85] -> 
             RGBColor[
              0.9885590341153779, 0.9877179306005293, 0.708472448961283], 
             UndirectedEdge[20, 108] -> 
             RGBColor[
              0.8695813139685316, 0.8982537654571588, 0.9507225237005397], 
             UndirectedEdge[94, 201] -> 
             RGBColor[
              0.9096145970055015, 0.926914143837571, 0.8171244441734828], 
             UndirectedEdge[260, 294] -> 
             RGBColor[
              0.9060220232235006, 0.9269959194503057, 0.95950534945947], 
             UndirectedEdge[138, 266] -> 
             RGBColor[
              0.7774368460642794, 0.8262138758508484, 0.9784101555669313], 
             UndirectedEdge[127, 168] -> 
             RGBColor[
              0.9786655873246746, 0.9836094104754125, 0.9209977751400564], 
             UndirectedEdge[128, 198] -> 
             RGBColor[
              0.9941126334899804, 0.9898158432761581, 0.6005746718779433], 
             UndirectedEdge[145, 216] -> 
             RGBColor[
              0.8347678144023445, 0.8716107326936624, 0.9752726266730486], 
             UndirectedEdge[141, 182] -> 
             RGBColor[
              0.9430761553739025, 0.9565418786194134, 0.9630396056625896], 
             UndirectedEdge[41, 252] -> 
             RGBColor[
              0.9783510967213824, 0.9807384657084364, 0.776025123727303], 
             UndirectedEdge[55, 208] -> 
             RGBColor[
              0.6807306832142856, 0.6665702557755228, 0.6085923537195188], 
             UndirectedEdge[121, 249] -> 
             RGBColor[
              0.8656157314783355, 0.8957966827368917, 0.9827675231113766], 
             UndirectedEdge[89, 120] -> 
             RGBColor[
              0.7113779359886856, 0.7704952796377044, 0.9115828772102816], 
             UndirectedEdge[32, 142] -> 
             RGBColor[
              0.9257277755459936, 0.9304062674028062, 0.6941749209374182], 
             UndirectedEdge[7, 77] -> 
             RGBColor[
              0.9367279314627791, 0.9505799305367005, 0.9263710139105843], 
             UndirectedEdge[45, 146] -> 
             RGBColor[
              0.7111612659609177, 0.7742838530852575, 0.9718455668772531], 
             UndirectedEdge[110, 223] -> 
             RGBColor[
              0.8701047187053874, 0.5030576901024366, 0.21332453207412355`], 
             UndirectedEdge[225, 276] -> 
             RGBColor[
              0.926377477579688, 0.9421289148690704, 0.9167926785707582], 
             UndirectedEdge[65, 291] -> 
             RGBColor[
              0.8687541089659302, 0.7745387766714888, 0.615249892911634], 
             UndirectedEdge[194, 290] -> 
             RGBColor[
              0.8151124944161507, 0.8552165594605656, 0.9225594327234203], 
             UndirectedEdge[154, 258] -> 
             RGBColor[
              0.9868378837105816, 0.9888251409104353, 0.8677938595881172], 
             UndirectedEdge[31, 280] -> 
             RGBColor[
              0.9840494673742047, 0.964713793585382, 0.5976231291646907], 
             UndirectedEdge[156, 271] -> 
             RGBColor[
              0.6742210524147785, 0.7327352654867045, 0.6818793163666642], 
             UndirectedEdge[83, 241] -> 
             RGBColor[
              0.5326463588397978, 0.63012049749858, 0.9567989883347294], 
             UndirectedEdge[208, 268] -> 
             RGBColor[
              0.6889964871219922, 0.7534057268805832, 0.9550155585173381], 
             UndirectedEdge[1, 80] -> 
             RGBColor[
              0.9031682562886398, 0.9244431414613501, 0.9496203174811413], 
             UndirectedEdge[116, 206] -> 
             RGBColor[
              0.9685598257205523, 0.9727985632461764, 0.7420092646890296], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.9568262174223037, 0.9658319070882517, 0.8946847190030407], 
             UndirectedEdge[108, 204] -> 
             RGBColor[
              0.8750197225203444, 0.90176232555061, 0.9170032008365008], 
             UndirectedEdge[251, 271] -> 
             RGBColor[
              0.8954459372508414, 0.9125281424350026, 0.7002245256033357], 
             UndirectedEdge[6, 38] -> 
             RGBColor[
              0.8023567367769079, 0.8463963841054882, 0.977379122985724], 
             UndirectedEdge[135, 158] -> 
             RGBColor[
              0.9269210150054161, 0.7316325269948802, 0.5086062407733145], 
             UndirectedEdge[25, 180] -> 
             RGBColor[
              0.735604341394634, 0.7923621462331504, 0.966695690656221], 
             UndirectedEdge[57, 217] -> 
             RGBColor[
              0.9308962119165523, 0.9087743886809123, 0.6567817824276725], 
             UndirectedEdge[71, 136] -> 
             RGBColor[
              0.8519841330932421, 0.884813037508078, 0.9857442012612896], 
             UndirectedEdge[135, 173] -> 
             RGBColor[
              0.9563637839041932, 0.9656081508014327, 0.9009359548596034], 
             UndirectedEdge[143, 235] -> 
             RGBColor[
              0.8494228559935557, 0.867013386915362, 0.6816751799151011], 
             UndirectedEdge[264, 288] -> 
             RGBColor[
              0.5793713351231605, 0.6449305702176442, 0.9262759923716877], 
             UndirectedEdge[223, 247] -> 
             RGBColor[
              0.9070089882386542, 0.7108088530492678, 0.5835452602659975], 
             UndirectedEdge[191, 225] -> 
             RGBColor[
              0.987966527688974, 0.9799618915984589, 0.626905555413931], 
             UndirectedEdge[1, 243] -> 
             RGBColor[
              0.9146562329721699, 0.9336033422359771, 0.9507160509526543], 
             UndirectedEdge[29, 284] -> 
             RGBColor[
              0.810397011746732, 0.8517301791183252, 0.9353325764524476], 
             UndirectedEdge[6, 273] -> 
             RGBColor[
              0.8256132577375457, 0.8634568174236774, 0.9252829646730782], 
             UndirectedEdge[103, 276] -> 
             RGBColor[
              0.9049857060016481, 0.926826666707946, 0.9821878279922374], 
             UndirectedEdge[99, 199] -> 
             RGBColor[
              0.9374507138242241, 0.9515690882779584, 0.944366488101561], 
             UndirectedEdge[35, 129] -> 
             RGBColor[
              0.9811174633388096, 0.9479669113906677, 0.38114534004946266`], 
             UndirectedEdge[77, 145] -> 
             RGBColor[
              0.915858459307358, 0.9354959505531145, 0.9832125899015418], 
             UndirectedEdge[72, 155] -> 
             RGBColor[
              0.8742598972328807, 0.7879208163682176, 0.6177885630626386], 
             UndirectedEdge[20, 44] -> 
             RGBColor[
              0.9345178510073152, 0.9495682006828765, 0.9570394121185108], 
             UndirectedEdge[131, 178] -> 
             RGBColor[
              0.6272422141342945, 0.7080951714895829, 0.9639123630207267], 
             UndirectedEdge[106, 241] -> 
             RGBColor[
              0.7536255099928197, 0.8077212890818715, 0.976007936229817], 
             UndirectedEdge[85, 286] -> 
             RGBColor[
              0.9937663753932827, 0.9890752322193856, 0.5628866149096723], 
             UndirectedEdge[86, 261] -> 
             RGBColor[
              0.7221331866253509, 0.7795172924291841, 0.9051270465333264], 
             UndirectedEdge[256, 269] -> 
             RGBColor[
              0.6169485962688794, 0.684150821315596, 0.9268349703189054], 
             UndirectedEdge[37, 61] -> 
             RGBColor[
              0.9873975463579767, 0.9890565757978071, 0.8585188011602738], 
             UndirectedEdge[73, 244] -> 
             RGBColor[
              0.702623041970716, 0.7676137276112062, 0.9709945565041495], 
             UndirectedEdge[180, 193] -> 
             RGBColor[
              0.6691047282441884, 0.7396459066774568, 0.9688728517580143], 
             UndirectedEdge[8, 213] -> 
             RGBColor[
              0.7218529680166933, 0.7826362919911747, 0.9729112158185365], 
             UndirectedEdge[48, 138] -> 
             RGBColor[
              0.7873789735674727, 0.8339807414193106, 0.9794010939219857], 
             UndirectedEdge[170, 284] -> 
             RGBColor[
              0.9127989070614484, 0.9319910477132463, 0.9454300401712297], 
             UndirectedEdge[55, 219] -> 
             RGBColor[
              0.908535848255813, 0.8491753215537312, 0.6286542864226152], 
             UndirectedEdge[111, 235] -> 
             RGBColor[
              0.7926235135091126, 0.822016406198862, 0.6764412016492254], 
             UndirectedEdge[56, 247] -> 
             RGBColor[
              0.9746838303516172, 0.9787006018133271, 0.8375508905914911], 
             UndirectedEdge[7, 82] -> 
             RGBColor[
              0.7270086173282873, 0.7835217222638938, 0.9074478662599835], 
             UndirectedEdge[182, 190] -> 
             RGBColor[
              0.807636400835017, 0.8504216921125971, 0.9812567785529676], 
             UndirectedEdge[113, 228] -> 
             RGBColor[
              0.971334855013084, 0.9778674316044266, 0.9211037900132967], 
             UndirectedEdge[133, 146] -> 
             RGBColor[
              0.5709800566661266, 0.6614186415624952, 0.9600476854608053], 
             UndirectedEdge[93, 274] -> 
             RGBColor[
              0.8378403266404314, 0.873525878136453, 0.9510219447402934], 
             UndirectedEdge[153, 220] -> 
             RGBColor[
              0.8448688169717171, 0.8360606926443432, 0.641216259004371], 
             UndirectedEdge[90, 153] -> 
             RGBColor[
              0.8554266966913948, 0.8870712674429782, 0.9429941951324694], 
             UndirectedEdge[178, 190] -> 
             RGBColor[
              0.65056693893885, 0.726316623781376, 0.9662371536072988], 
             UndirectedEdge[39, 126] -> 
             RGBColor[
              0.9877031953733335, 0.989132051629785, 0.851173198804914], 
             UndirectedEdge[15, 77] -> 
             RGBColor[
              0.9355641264713928, 0.9362371549111057, 0.6921526879520914], 
             UndirectedEdge[103, 293] -> 
             RGBColor[
              0.9373886138350713, 0.9526638658608156, 0.9852784462678066], 
             UndirectedEdge[92, 269] -> 
             RGBColor[
              0.9878004428303975, 0.9876714489722191, 0.7509587574710701], 
             UndirectedEdge[8, 14] -> 
             RGBColor[
              0.8728893139081436, 0.896913660077427, 0.7115386986040408], 
             UndirectedEdge[157, 171] -> 
             RGBColor[
              0.9654534721616281, 0.9732750626306053, 0.9218323983306242], 
             UndirectedEdge[198, 226] -> 
             RGBColor[
              0.9924028161592339, 0.9905061244931337, 0.7304822460310141], 
             UndirectedEdge[86, 169] -> 
             RGBColor[
              0.7051680646827077, 0.7114552719902636, 0.6158717978704789], 
             UndirectedEdge[163, 235] -> 
             RGBColor[
              0.7924414545001791, 0.8218686024937449, 0.676426869297138], 
             UndirectedEdge[31, 136] -> 
             RGBColor[
              0.9085596888931997, 0.9067875617903667, 0.6779300549975308], 
             UndirectedEdge[111, 292] -> 
             RGBColor[
              0.7691590586212215, 0.819883896192023, 0.976861142727704], 
             UndirectedEdge[48, 122] -> 
             RGBColor[
              0.8640907179017925, 0.8899632112780385, 0.7045009384103846], 
             UndirectedEdge[246, 295] -> 
             RGBColor[
              0.8196472467195575, 0.8591609431544954, 0.941496054877508], 
             UndirectedEdge[258, 263] -> 
             RGBColor[
              0.9752267688942184, 0.9807151630492754, 0.9120594302726444], 
             UndirectedEdge[24, 299] -> 
             RGBColor[
              0.8758873984485771, 0.9038728524655689, 0.9880241160495782], 
             UndirectedEdge[66, 193] -> 
             RGBColor[
              0.8216859980103592, 0.8607166554943861, 0.9828377449534879], 
             UndirectedEdge[29, 199] -> 
             RGBColor[
              0.7631197865540517, 0.815346642839789, 0.9769379610298295], 
             UndirectedEdge[27, 87] -> 
             RGBColor[
              0.806966885262639, 0.8497039503421119, 0.9629605992561319], 
             UndirectedEdge[164, 180] -> 
             RGBColor[
              0.548670376852168, 0.6444743551042151, 0.9576124883930679], 
             UndirectedEdge[106, 200] -> 
             RGBColor[
              0.9229173483304057, 0.9383972905101444, 0.8742285112537548], 
             UndirectedEdge[69, 285] -> 
             RGBColor[
              0.6679201829264977, 0.7401631017579133, 0.9677684937579248], 
             UndirectedEdge[88, 137] -> 
             RGBColor[
              0.921612397144436, 0.9362030682081276, 0.7957497780902589], 
             UndirectedEdge[43, 261] -> 
             RGBColor[
              0.943627852437344, 0.956037088190343, 0.925090188873949], 
             UndirectedEdge[224, 253] -> 
             RGBColor[
              0.7151225815024633, 0.7733032088612557, 0.8958147757550885], 
             UndirectedEdge[5, 23] -> 
             RGBColor[
              0.6315233119321988, 0.6943175964851456, 0.7107137166118683], 
             UndirectedEdge[42, 162] -> 
             RGBColor[
              0.9318761019314756, 0.7980781383352732, 0.5872163668932745], 
             UndirectedEdge[29, 131] -> 
             RGBColor[
              0.6447769472896192, 0.7223306577958022, 0.9652927614465578], 
             UndirectedEdge[12, 192] -> 
             RGBColor[
              0.7835717004654598, 0.8310910348251134, 0.9789991798109364], 
             UndirectedEdge[69, 76] -> 
             RGBColor[
              0.8039314127099888, 0.8458422664494158, 0.9081172238884836], 
             UndirectedEdge[176, 180] -> 
             RGBColor[
              0.7497926208470633, 0.8029437418175968, 0.9426786344391975], 
             UndirectedEdge[101, 116] -> 
             RGBColor[
              0.9066112598575731, 0.9236137546788432, 0.7434263306344675], 
             UndirectedEdge[125, 293] -> 
             RGBColor[
              0.9618728340861373, 0.9683974001910474, 0.8070276019141118], 
             UndirectedEdge[30, 300] -> 
             RGBColor[
              0.9029002014654157, 0.9240065539273269, 0.9405111428335294], 
             UndirectedEdge[155, 290] -> 
             RGBColor[
              0.7803562871880618, 0.7144660623810447, 0.6084547475736801], 
             UndirectedEdge[217, 246] -> 
             RGBColor[
              0.9384105615244098, 0.952549867778542, 0.9531713649793516], 
             UndirectedEdge[42, 82] -> 
             RGBColor[
              0.6814724904938739, 0.5994056410640132, 0.5930598521633497], 
             UndirectedEdge[122, 138] -> 
             RGBColor[
              0.9158771146924645, 0.9305741739178843, 0.7096213807165703], 
             UndirectedEdge[58, 160] -> 
             RGBColor[
              0.9274022521247889, 0.9412328677138662, 0.8297913769338583], 
             UndirectedEdge[158, 225] -> 
             RGBColor[
              0.9257980920751472, 0.7311681695054111, 0.5272159797592582], 
             UndirectedEdge[197, 204] -> 
             RGBColor[
              0.7222160959019397, 0.779550670151687, 0.9037150926271704], 
             UndirectedEdge[40, 182] -> 
             RGBColor[
              0.9267908361189277, 0.9443963141838161, 0.9906064032697466], 
             UndirectedEdge[1, 149] -> 
             RGBColor[
              0.9247798495966046, 0.9416756393340485, 0.9516816505437522], 
             UndirectedEdge[32, 156] -> 
             RGBColor[
              0.6718510035959975, 0.7247405343070299, 0.6726721242518645], 
             UndirectedEdge[258, 286] -> 
             RGBColor[
              0.9902380030484883, 0.9893841919229236, 0.7498781628461278], 
             UndirectedEdge[101, 197] -> 
             RGBColor[
              0.6384705143784211, 0.7146570790939751, 0.9665423362636723], 
             UndirectedEdge[53, 271] -> 
             RGBColor[
              0.9654505597253751, 0.9680782107149467, 0.7032404625288728], 
             UndirectedEdge[22, 70] -> 
             RGBColor[
              0.8997007929619603, 0.9180393576166452, 0.7286574406246218], 
             UndirectedEdge[76, 258] -> 
             RGBColor[
              0.9869532937264456, 0.9888728659178971, 0.8658812169537032], 
             UndirectedEdge[232, 297] -> 
             RGBColor[
              0.7987757517965907, 0.8430191384369419, 0.9548141013289007], 
             UndirectedEdge[178, 261] -> 
             RGBColor[
              0.7942589900860277, 0.8380722689089795, 0.9108050539872744], 
             UndirectedEdge[155, 227] -> 
             RGBColor[
              0.943755174532734, 0.8424262448558206, 0.5929285537300983], 
             UndirectedEdge[178, 182] -> 
             RGBColor[
              0.7582709558597586, 0.8112265508063474, 0.9767675553055704], 
             UndirectedEdge[5, 51] -> 
             RGBColor[
              0.9809003560223739, 0.9818650290327275, 0.7102431345721127], 
             UndirectedEdge[110, 295] -> 
             RGBColor[
              0.7691794137738521, 0.6412940968229643, 0.5942349015989914], 
             UndirectedEdge[186, 286] -> 
             RGBColor[
              0.9661504881872938, 0.9717493450503818, 0.8054114099587804], 
             UndirectedEdge[34, 270] -> 
             RGBColor[
              0.9415104218874304, 0.9542369614691426, 0.9200358694151392], 
             UndirectedEdge[4, 8] -> 
             RGBColor[
              0.7911690293706097, 0.8368615133138362, 0.9798000936761525], 
             UndirectedEdge[69, 166] -> 
             RGBColor[
              0.7518427400979741, 0.8062378493418548, 0.9759967610878785], 
             UndirectedEdge[25, 176] -> 
             RGBColor[
              0.9594353483314004, 0.9692675297208552, 0.9535495537060743], 
             UndirectedEdge[32, 149] -> 
             RGBColor[
              0.9271573016946988, 0.93154613275033, 0.6943112704176346], 
             UndirectedEdge[16, 153] -> 
             RGBColor[
              0.8248653364996512, 0.8639392310502206, 0.9829585630547548], 
             UndirectedEdge[169, 299] -> 
             RGBColor[
              0.926574937095711, 0.8879050636781565, 0.6358265663983316], 
             UndirectedEdge[187, 229] -> 
             RGBColor[
              0.8483904131893252, 0.8816537408717469, 0.9463055984692971], 
             UndirectedEdge[15, 82] -> 
             RGBColor[
              0.7258448123369009, 0.769178946638299, 0.6732295403014906], 
             UndirectedEdge[44, 280] -> 
             RGBColor[
              0.9409577154967186, 0.9534908885427649, 0.9067233726837086], 
             UndirectedEdge[186, 265] -> 
             RGBColor[
              0.9591660471662988, 0.9690666853528627, 0.9540054103335984], 
             UndirectedEdge[117, 265] -> 
             RGBColor[
              0.9770036946149742, 0.9823699736136177, 0.9238109260065417], 
             UndirectedEdge[106, 162] -> 
             RGBColor[
              0.9101964702109493, 0.9304037096687253, 0.9626494084255959], 
             UndirectedEdge[9, 146] -> 
             RGBColor[
              0.6027817795357849, 0.6875299778772305, 0.9624702035749103], 
             UndirectedEdge[130, 294] -> 
             RGBColor[
              0.9679712152551688, 0.9756335652964023, 0.9391005575147796], 
             UndirectedEdge[13, 53] -> 
             RGBColor[
              0.9399844813177689, 0.9547611049499605, 0.9864747979615536], 
             UndirectedEdge[34, 57] -> 
             RGBColor[
              0.9771108689158081, 0.9436627931116236, 0.5869423484761713], 
             UndirectedEdge[25, 144] -> 
             RGBColor[
              0.7189240373042484, 0.7788203239334394, 0.9653825560162587], 
             UndirectedEdge[206, 283] -> 
             RGBColor[
              0.9615111717164895, 0.9708156754026058, 0.9500357261765664], 
             UndirectedEdge[107, 273] -> 
             RGBColor[
              0.9897013695567412, 0.9900092658960518, 0.8203384886534311], 
             UndirectedEdge[64, 85] -> 
             RGBColor[
              0.9544522313541166, 0.9617646894877845, 0.7483009506633083], 
             UndirectedEdge[175, 224] -> 
             RGBColor[
              0.6910610030924254, 0.6789927058265705, 0.6100814831698524], 
             UndirectedEdge[68, 163] -> 
             RGBColor[
              0.4356090482685625, 0.5441282150971425, 0.9502181742357367], 
             UndirectedEdge[7, 237] -> 
             RGBColor[
              0.9777785100928775, 0.9824673915490914, 0.9009843622447866], 
             UndirectedEdge[76, 126] -> 
             RGBColor[
              0.9896258273291956, 0.989978027243615, 0.8215904188608787], 
             UndirectedEdge[30, 236] -> 
             RGBColor[
              0.7918804161798887, 0.8373488654382555, 0.9798891463120165], 
             UndirectedEdge[7, 269] -> 
             RGBColor[
              0.9843533355438867, 0.9873708856051653, 0.8898548977453427], 
             UndirectedEdge[237, 256] -> 
             RGBColor[
              0.6103737708178703, 0.6792473272595221, 0.9379644348183493], 
             UndirectedEdge[106, 290] -> 
             RGBColor[
              0.7483866223730631, 0.8036286302562969, 0.9754857728720678], 
             UndirectedEdge[180, 288] -> 
             RGBColor[
              0.3524443069551485, 0.465716179164946, 0.9446628856946722], 
             UndirectedEdge[201, 237] -> 
             RGBColor[
              0.896562721387751, 0.9195136376615984, 0.9606940543067747], 
             UndirectedEdge[10, 73] -> 
             RGBColor[
              0.8275087111148349, 0.865804007174976, 0.9676719538809455], 
             UndirectedEdge[18, 175] -> 
             RGBColor[
              0.7970357401511741, 0.7651632154548793, 0.6184582785454095], 
             UndirectedEdge[57, 295] -> 
             RGBColor[
              0.8121328971116999, 0.8153854640568658, 0.6451064723258289], 
             UndirectedEdge[71, 161] -> 
             RGBColor[
              0.8956999064193822, 0.9196708085252867, 0.9899138507466683], 
             UndirectedEdge[218, 220] -> 
             RGBColor[
              0.7913377647509158, 0.7939013391819355, 0.6361135779217735], 
             UndirectedEdge[192, 248] -> 
             RGBColor[
              0.8539688329964191, 0.8847775961670854, 0.8904366325315348], 
             UndirectedEdge[23, 24] -> 
             RGBColor[
              0.5610138838012213, 0.6429847698794878, 0.9622175988515085], 
             UndirectedEdge[39, 195] -> 
             RGBColor[
              0.984365804444558, 0.9877519547137017, 0.9064824033855845], 
             UndirectedEdge[79, 232] -> 
             RGBColor[
              0.7623950404781024, 0.8147470733337507, 0.9768937835376591], 
             UndirectedEdge[12, 154] -> 
             RGBColor[
              0.9185638908965517, 0.9360165524036155, 0.9211704872485396], 
             UndirectedEdge[106, 155] -> 
             RGBColor[
              0.8846219786115542, 0.7961832587883659, 0.6187769076348758], 
             UndirectedEdge[95, 103] -> 
             RGBColor[
              0.9428958562768753, 0.9569324036275231, 0.9815465995639866], 
             UndirectedEdge[3, 228] -> 
             RGBColor[
              0.9745205915786328, 0.9802433487188479, 0.9157111689809905], 
             UndirectedEdge[81, 293] -> 
             RGBColor[
              0.9534037415338703, 0.9409379538033404, 0.6798431569681216], 
             UndirectedEdge[95, 145] -> 
             RGBColor[
              0.9429027299804664, 0.9569375300244066, 0.9815349641767559], 
             UndirectedEdge[39, 153] -> 
             RGBColor[
              0.855539832974928, 0.8871556442979935, 0.9428026849151163], 
             UndirectedEdge[39, 90] -> 
             RGBColor[
              0.983772381142139, 0.9874180489428701, 0.9123533052722325], 
             UndirectedEdge[120, 141] -> 
             RGBColor[
              0.7035565278662528, 0.7650380044791489, 0.9416568666255855], 
             UndirectedEdge[102, 172] -> 
             RGBColor[
              0.8550593925988536, 0.8861223502627973, 0.9128910030060017], 
             UndirectedEdge[155, 194] -> 
             RGBColor[
              0.9513478506546419, 0.8477711879926345, 0.5658505674862282], 
             UndirectedEdge[53, 251] -> 
             RGBColor[
              0.869837709809306, 0.8991050221532596, 0.9836994822720526], 
             UndirectedEdge[128, 243] -> 
             RGBColor[
              0.9207054664561807, 0.9351441630605086, 0.7684468394651143], 
             UndirectedEdge[72, 87] -> 
             RGBColor[
              0.7449354654975999, 0.8007650545830283, 0.9751862446680494], 
             UndirectedEdge[76, 90] -> 
             RGBColor[
              0.9856950130980011, 0.9882640245567003, 0.8827705253281972], 
             UndirectedEdge[3, 106] -> 
             RGBColor[
              0.9079239253708089, 0.9287088494478993, 0.9664962340653326], 
             UndirectedEdge[104, 243] -> 
             RGBColor[
              0.9208907679743508, 0.9355405042710172, 0.7886157661695192], 
             UndirectedEdge[34, 217] -> 
             RGBColor[
              0.941684066564952, 0.9543754210215392, 0.9200524317994956], 
             UndirectedEdge[31, 37] -> 
             RGBColor[
              0.9826447861848948, 0.9641329218149424, 0.6209023316699438], 
             UndirectedEdge[64, 249] -> 
             RGBColor[
              0.9280422978460792, 0.9453382006121449, 0.9887843806648828], 
             UndirectedEdge[89, 188] -> 
             RGBColor[
              0.8487196093571399, 0.8814062289977043, 0.9229860008431026], 
             UndirectedEdge[179, 269] -> 
             RGBColor[
              0.8984031236298065, 0.9206808325687729, 0.9491027195952253], 
             UndirectedEdge[213, 249] -> 
             RGBColor[
              0.8155210795793508, 0.8566623599399492, 0.9777745563712238], 
             UndirectedEdge[44, 252] -> 
             RGBColor[
              0.9274928389660746, 0.9443289582049208, 0.9689309250877491], 
             UndirectedEdge[149, 198] -> 
             RGBColor[
              0.9312794642694141, 0.9441797799808975, 0.8184336520264441], 
             UndirectedEdge[158, 214] -> 
             RGBColor[
              0.8964923030286001, 0.7098038849831052, 0.6004679937377828], 
             UndirectedEdge[202, 216] -> 
             RGBColor[
              0.756998854850495, 0.8100925259043736, 0.9764142293611437], 
             UndirectedEdge[78, 209] -> 
             RGBColor[
              0.9945443623624591, 0.9907392676799055, 0.647565695325499], 
             UndirectedEdge[77, 265] -> 
             RGBColor[
              0.9333516749793076, 0.9485423621587429, 0.953601138730287], 
             UndirectedEdge[44, 204] -> 
             RGBColor[
              0.939956259559128, 0.9530767607763275, 0.9233200892544717], 
             UndirectedEdge[54, 102] -> 
             RGBColor[
              0.8259401926842889, 0.8648352251416882, 0.9830507521903826], 
             UndirectedEdge[2, 253] -> 
             RGBColor[
              0.9916898168030246, 0.9905887922222677, 0.769739575839713], 
             UndirectedEdge[40, 86] -> 
             RGBColor[
              0.6975955707620839, 0.7617362693727996, 0.9699087708701297], 
             UndirectedEdge[75, 165] -> 
             RGBColor[
              0.9143184444277748, 0.9340921449209477, 0.9769692336393259], 
             UndirectedEdge[73, 100] -> 
             RGBColor[
              0.690859451535297, 0.7584239213564582, 0.9698220717465498], 
             UndirectedEdge[50, 206] -> 
             RGBColor[
              0.9562868185497093, 0.9318455478997932, 0.6563451323082965], 
             UndirectedEdge[32, 277] -> 
             RGBColor[
              0.8351548535785596, 0.8592850586116041, 0.685244306037184], 
             UndirectedEdge[156, 251] -> 
             RGBColor[
              0.5786082024987094, 0.6637620769250174, 0.962338336109844], 
             UndirectedEdge[31, 44] -> 
             RGBColor[
              0.9355174101208401, 0.928282916949438, 0.6805013065136649], 
             UndirectedEdge[80, 92] -> 
             RGBColor[
              0.9093753863617879, 0.9263216871242528, 0.7845371752964174], 
             UndirectedEdge[11, 149] -> 
             RGBColor[
              0.9156933953110343, 0.9348989766055735, 0.9670626475223949], 
             UndirectedEdge[103, 145] -> 
             RGBColor[
              0.9453380128920015, 0.9587537600324196, 0.9774126654310347], 
             UndirectedEdge[150, 274] -> 
             RGBColor[
              0.8351642766461218, 0.8715300844323266, 0.9555517993550399], 
             UndirectedEdge[13, 156] -> 
             RGBColor[
              0.6487549740071723, 0.7194181597217182, 0.9651136517993449], 
             UndirectedEdge[84, 278] -> 
             RGBColor[
              0.7579543769405668, 0.8062654853939089, 0.7804332685123714], 
             UndirectedEdge[150, 293] -> 
             RGBColor[
              0.9484199434579131, 0.9608910134313866, 0.9666052826478905], 
             UndirectedEdge[52, 137] -> 
             RGBColor[
              0.9639544590205793, 0.9699654790035127, 0.7997884017512104], 
             UndirectedEdge[41, 152] -> 
             RGBColor[
              0.9712493145320698, 0.975441968179748, 0.788046588532366], 
             UndirectedEdge[177, 279] -> 
             RGBColor[
              0.8294357149354663, 0.8653492894374359, 0.876072736203877], 
             UndirectedEdge[108, 279] -> 
             RGBColor[
              0.7147860842324808, 0.7771155886686418, 0.9722068548867098], 
             UndirectedEdge[161, 279] -> 
             RGBColor[
              0.796480673369764, 0.8417924397524967, 0.9801221412739255], 
             UndirectedEdge[89, 260] -> 
             RGBColor[
              0.9138434313459334, 0.9324531946088612, 0.9294313600441662], 
             UndirectedEdge[63, 161] -> 
             RGBColor[
              0.955868754208128, 0.9660895168992616, 0.9389315623944601], 
             UndirectedEdge[110, 148] -> 
             RGBColor[
              0.7883378882399086, 0.6562608426856466, 0.5961444392876448], 
             UndirectedEdge[200, 228] -> 
             RGBColor[
              0.9895140145382295, 0.989931789781093, 0.8234434461694127], 
             UndirectedEdge[67, 118] -> 
             RGBColor[
              0.9494352647073028, 0.9587010458570184, 0.8237583696146428], 
             UndirectedEdge[140, 203] -> 
             RGBColor[
              0.7041724274442225, 0.6373926900279548, 0.5989274887326541], 
             UndirectedEdge[144, 231] -> 
             RGBColor[
              0.7170212438919754, 0.7774012237221044, 0.9686034889352333], 
             UndirectedEdge[101, 149] -> 
             RGBColor[
              0.843995805843957, 0.8784433621968649, 0.9849822674769888], 
             UndirectedEdge[131, 284] -> 
             RGBColor[
              0.81890299876211, 0.8584683818265625, 0.9361166106874416], 
             UndirectedEdge[157, 275] -> 
             RGBColor[
              0.9901481304186124, 0.9884068789019835, 0.6830287224734218], 
             UndirectedEdge[113, 144] -> 
             RGBColor[
              0.7247125347717455, 0.7831373758669039, 0.955584139685717], 
             UndirectedEdge[48, 73] -> 
             RGBColor[
              0.7187957365407271, 0.7802479595263301, 0.9726064995564646], 
             UndirectedEdge[35, 183] -> 
             RGBColor[
              0.9781858315219467, 0.951565115811847, 0.6206754582771794], 
             UndirectedEdge[93, 107] -> 
             RGBColor[
              0.9831228709201576, 0.985387274319387, 0.8442031054963324], 
             UndirectedEdge[23, 226] -> 
             RGBColor[
              0.630129610106611, 0.6956840168034754, 0.8750285126627122], 
             UndirectedEdge[200, 211] -> 
             RGBColor[
              0.9658246562342432, 0.9725390358617185, 0.8758463533729719], 
             UndirectedEdge[87, 227] -> 
             RGBColor[
              0.8144307427974533, 0.8552704830706312, 0.9503262353355091], 
             UndirectedEdge[223, 278] -> 
             RGBColor[
              0.9269750546464517, 0.72307324631977, 0.4050468328258233], 
             UndirectedEdge[182, 229] -> 
             RGBColor[
              0.9472611053808178, 0.959663007482344, 0.9559555769106534], 
             UndirectedEdge[79, 221] -> 
             RGBColor[
              0.92841252577583, 0.9449913692843106, 0.9665597278004066], 
             UndirectedEdge[115, 228] -> 
             RGBColor[
              0.9890923821289821, 0.9897574339444104, 0.8304309863403412], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.8860821724812769, 0.9120018885494745, 0.9889965026977994], 
             UndirectedEdge[9, 47] -> 
             RGBColor[
              0.6977822192395515, 0.7623064604533647, 0.9717899767520611], 
             UndirectedEdge[18, 224] -> 
             RGBColor[
              0.547840880711165, 0.6433144872470677, 0.9577530932155679], 
             UndirectedEdge[194, 291] -> 
             RGBColor[
              0.9063492928811747, 0.926544870282682, 0.9316388853432072], 
             UndirectedEdge[5, 198] -> 
             RGBColor[
              0.9937965179848216, 0.9891397041748038, 0.5661674499801701], 
             UndirectedEdge[49, 172] -> 
             RGBColor[
              0.9261210529271029, 0.9419960705193797, 0.919878282390604], 
             UndirectedEdge[162, 228] -> 
             RGBColor[
              0.976793136418773, 0.9819382089396739, 0.9118643433412537], 
             UndirectedEdge[100, 161] -> 
             RGBColor[
              0.8028308846031469, 0.8467532730314083, 0.9807550709835712], 
             UndirectedEdge[174, 235] -> 
             RGBColor[
              0.8550858902712064, 0.8714373923337173, 0.6822396182478331], 
             UndirectedEdge[14, 67] -> 
             RGBColor[
              0.9484718013817472, 0.95664029522474, 0.7188913324343444], 
             UndirectedEdge[190, 199] -> 
             RGBColor[
              0.7949504983739852, 0.8403062978398194, 0.9800467858513956], 
             UndirectedEdge[160, 288] -> 
             RGBColor[
              0.5868528482980221, 0.6483172424553593, 0.8032862652539894], 
             UndirectedEdge[33, 275] -> 
             RGBColor[
              0.9921631595049849, 0.9892401452130841, 0.6496344757841144], 
             UndirectedEdge[109, 218] -> 
             RGBColor[
              0.6384600811876397, 0.7171486463744514, 0.9648321861368989], 
             UndirectedEdge[231, 264] -> 
             RGBColor[
              0.960628576150373, 0.9701574370745136, 0.9515297302522111], 
             UndirectedEdge[221, 230] -> 
             RGBColor[
              0.887465491328741, 0.9124250783493222, 0.9626319350146215], 
             UndirectedEdge[45, 236] -> 
             RGBColor[
              0.7429200589049484, 0.7990940635089004, 0.97501098655512], 
             UndirectedEdge[279, 280] -> 
             RGBColor[
              0.828254678524629, 0.8648609005303034, 0.8956455659557065], 
             UndirectedEdge[71, 252] -> 
             RGBColor[
              0.9140090350436032, 0.9335773389652492, 0.9676448278324898], 
             UndirectedEdge[230, 296] -> 
             RGBColor[
              0.8129075584696633, 0.8537688300935533, 0.981986686441362], 
             UndirectedEdge[27, 154] -> 
             RGBColor[
              0.9717454759374775, 0.9778988301760554, 0.9081007367002953], 
             UndirectedEdge[5, 101] -> 
             RGBColor[
              0.9065128595593646, 0.9234032863907713, 0.7327160654307148], 
             UndirectedEdge[68, 143] -> 
             RGBColor[
              0.4925904497619391, 0.5892729995187596, 0.9554664848536998], 
             UndirectedEdge[58, 221] -> 
             RGBColor[
              0.9126680550298103, 0.9324371556837079, 0.9650580061253963], 
             UndirectedEdge[85, 249] -> 
             RGBColor[
              0.9668226172970461, 0.9715069465275333, 0.7452665328692611], 
             UndirectedEdge[26, 54] -> 
             RGBColor[
              0.9128391951997678, 0.933337212165166, 0.9915486114109652], 
             UndirectedEdge[269, 282] -> 
             RGBColor[
              0.9091046225687196, 0.9291751159327866, 0.9501337348173258], 
             UndirectedEdge[24, 210] -> 
             RGBColor[
              0.9113492544124479, 0.9312469207773543, 0.9601248199831998], 
             UndirectedEdge[144, 288] -> 
             RGBColor[
              0.3357640028647629, 0.452174356865235, 0.9433497510547099], 
             UndirectedEdge[182, 199] -> 
             RGBColor[
              0.9026545152948938, 0.9252162248647908, 0.9905771875496672], 
             UndirectedEdge[35, 224] -> 
             RGBColor[
              0.7066143529492606, 0.7361026585320172, 0.6463128446014066], 
             UndirectedEdge[161, 280] -> 
             RGBColor[
              0.9577157675952183, 0.9668533044009022, 0.9083217706529532], 
             UndirectedEdge[27, 42] -> 
             RGBColor[
              0.9260012839034475, 0.7936967086691014, 0.5971609014167876], 
             UndirectedEdge[13, 273] -> 
             RGBColor[
              0.9630147630237891, 0.9716528094024887, 0.9347616036943276], 
             UndirectedEdge[167, 202] -> 
             RGBColor[
              0.737200029662748, 0.7946255331910612, 0.97444086749697], 
             UndirectedEdge[117, 207] -> 
             RGBColor[
              0.7350193346828843, 0.7909483907206294, 0.9414691763749179], 
             UndirectedEdge[33, 248] -> 
             RGBColor[
              0.9907689979594212, 0.9904507576773586, 0.8026451230872822], 
             UndirectedEdge[23, 210] -> 
             RGBColor[
              0.6203519731847598, 0.6893970986170253, 0.9365956392432631], 
             UndirectedEdge[54, 111] -> 
             RGBColor[
              0.7655343581164273, 0.8170208253992667, 0.9774573124982165], 
             UndirectedEdge[30, 267] -> 
             RGBColor[
              0.9025883602148197, 0.9238775995562507, 0.9456791593751943], 
             UndirectedEdge[170, 199] -> 
             RGBColor[
              0.8655216818687681, 0.8956075114347102, 0.9870354247486116], 
             UndirectedEdge[169, 200] -> 
             RGBColor[
              0.9732843125937166, 0.9221738844108313, 0.5220003849315991], 
             UndirectedEdge[137, 278] -> 
             RGBColor[
              0.9941597555264021, 0.9899166325472954, 0.6057036147389401], 
             UndirectedEdge[92, 150] -> 
             RGBColor[
              0.9806859219567752, 0.9823654509536304, 0.7630017855458884], 
             UndirectedEdge[68, 185] -> 
             RGBColor[
              0.6295672250849795, 0.6880445168951599, 0.6754568701280382], 
             UndirectedEdge[26, 102] -> 
             RGBColor[
              0.8092762836326608, 0.8515478763936812, 0.9814613336689912], 
             UndirectedEdge[270, 271] -> 
             RGBColor[
              0.9430904536887816, 0.9503557142413623, 0.7048121234212199], 
             UndirectedEdge[169, 202] -> 
             RGBColor[
              0.8715966049075354, 0.8443107436578587, 0.6305179578544731], 
             UndirectedEdge[17, 97] -> 
             RGBColor[
              0.8324454530782888, 0.8654965323931783, 0.7217584213192277], 
             UndirectedEdge[46, 158] -> 
             RGBColor[
              0.8932317056351224, 0.7072039731281046, 0.6001569950476233], 
             UndirectedEdge[98, 285] -> 
             RGBColor[
              0.8330842270867521, 0.809567005671357, 0.6256480192341567], 
             UndirectedEdge[77, 168] -> 
             RGBColor[
              0.9328039748229675, 0.948133888278921, 0.9545282522318921], 
             UndirectedEdge[242, 268] -> 
             RGBColor[
              0.9274365064045096, 0.9444907367551287, 0.9760918531117865], 
             UndirectedEdge[115, 134] -> 
             RGBColor[
              0.992355250972589, 0.9911067140631464, 0.7763568055678869], 
             UndirectedEdge[99, 284] -> 
             RGBColor[
              0.9847279390169044, 0.9879526245564945, 0.9027611035241789], 
             UndirectedEdge[204, 283] -> 
             RGBColor[
              0.9833081873770289, 0.9865244578929844, 0.8886255484855023], 
             UndirectedEdge[77, 167] -> 
             RGBColor[
              0.7854825619263628, 0.8328808041041613, 0.9791108246666127], 
             UndirectedEdge[227, 290] -> 
             RGBColor[
              0.8075198182942429, 0.8498716163237519, 0.9496374189672905], 
             UndirectedEdge[60, 145] -> 
             RGBColor[
              0.6517825295325603, 0.7217264639890988, 0.9607237402826347], 
             UndirectedEdge[32, 125] -> 
             RGBColor[
              0.9903091346099453, 0.9778637854666701, 0.5111368668707164], 
             UndirectedEdge[15, 60] -> 
             RGBColor[
              0.6714881966965951, 0.7224676683470901, 0.6696638383331841], 
             UndirectedEdge[30, 260] -> 
             RGBColor[
              0.8310162802167287, 0.8680938407815505, 0.9837442687357044], 
             UndirectedEdge[42, 80] -> 
             RGBColor[
              0.8603921522408637, 0.7419050425573182, 0.6090453014740561], 
             UndirectedEdge[97, 130] -> 
             RGBColor[
              0.9790474011113631, 0.9804372955264803, 0.7097454502097139], 
             UndirectedEdge[65, 211] -> 
             RGBColor[
              0.9246903098282361, 0.8190694076082676, 0.61811044247226], 
             UndirectedEdge[1, 256] -> 
             RGBColor[
              0.6169190688447902, 0.6841287998110571, 0.9268849525459028], 
             UndirectedEdge[5, 128] -> 
             RGBColor[
              0.9933461367960229, 0.9881763843524866, 0.517146237009938], 
             UndirectedEdge[125, 256] -> 
             RGBColor[
              0.6232869660234812, 0.6863512100566681, 0.7793003176599451], 
             UndirectedEdge[39, 239] -> 
             RGBColor[
              0.7884504662743472, 0.8339890403457941, 0.9366326436509282], 
             UndirectedEdge[156, 269] -> 
             RGBColor[
              0.6695030789219925, 0.7348920623952874, 0.9299925221509846], 
             UndirectedEdge[78, 170] -> 
             RGBColor[
              0.9181736510348278, 0.934205491088433, 0.8557641036888465], 
             UndirectedEdge[23, 155] -> 
             RGBColor[
              0.5933041230000431, 0.5540778193161362, 0.59521715022403], 
             UndirectedEdge[127, 251] -> 
             RGBColor[
              0.888964172178655, 0.9133695064716122, 0.951323370461062], 
             UndirectedEdge[241, 290] -> 
             RGBColor[
              0.6493598185693275, 0.7260040926745503, 0.9656857761686213], 
             UndirectedEdge[85, 234] -> 
             RGBColor[
              0.6995682027083032, 0.7569643428859565, 0.7259339577251076], 
             UndirectedEdge[270, 289] -> 
             RGBColor[
              0.9003602157431687, 0.9233868126793474, 0.9903583552102784], 
             UndirectedEdge[69, 258] -> 
             RGBColor[
              0.8031539250990378, 0.8455207553417674, 0.921002205675378], 
             UndirectedEdge[52, 289] -> 
             RGBColor[
              0.9196722188689401, 0.9387856797614775, 0.9922003513084431], 
             UndirectedEdge[47, 170] -> 
             RGBColor[
              0.8652592349022936, 0.8953982433475766, 0.9870103923226601], 
             UndirectedEdge[72, 241] -> 
             RGBColor[
              0.7432634286141462, 0.7994588466617233, 0.9750195916575798], 
             UndirectedEdge[115, 210] -> 
             RGBColor[
              0.9815132309208736, 0.9843796460990987, 0.8555635151455288], 
             UndirectedEdge[166, 239] -> 
             RGBColor[
              0.7382844256181946, 0.7952305988520632, 0.9749294009062879], 
             UndirectedEdge[180, 215] -> 
             RGBColor[
              0.6937862435615957, 0.5452637399194666, 0.5810309152906633], 
             UndirectedEdge[51, 254] -> 
             RGBColor[
              0.97269036726258, 0.9791531011366273, 0.9311122641181996], 
             UndirectedEdge[109, 227] -> 
             RGBColor[
              0.8138534119658067, 0.8548194678370722, 0.9502686923936741], 
             UndirectedEdge[203, 255] -> 
             RGBColor[
              0.8636380337300689, 0.41307872141810353`, 0.2055452881167969], 
             UndirectedEdge[257, 272] -> 
             RGBColor[
              0.9055309397414877, 0.5615759884215195, 0.36227361503633215`], 
             UndirectedEdge[32, 128] -> 
             RGBColor[
              0.989990470915265, 0.9771821960455908, 0.4764522902691338], 
             UndirectedEdge[39, 76] -> 
             RGBColor[
              0.9858081493815343, 0.9883484014117155, 0.8825790151108441], 
             UndirectedEdge[144, 221] -> 
             RGBColor[
              0.7289556540678065, 0.786301887290436, 0.9484016455002373], 
             UndirectedEdge[165, 262] -> 
             RGBColor[
              0.8565297746577688, 0.8884376087034784, 0.9861777686116562], 
             UndirectedEdge[101, 226] -> 
             RGBColor[
              0.9051191577337767, 0.9247697067091012, 0.8970308614815586], 
             UndirectedEdge[56, 191] -> 
             RGBColor[
              0.9914807235392229, 0.9812952523344657, 0.559954438000558], 
             UndirectedEdge[63, 71] -> 
             RGBColor[
              0.9256268981871569, 0.9419754818014526, 0.9360470671699563], 
             UndirectedEdge[137, 289] -> 
             RGBColor[
              0.9498805514273235, 0.9587433271146952, 0.79844601988104], 
             UndirectedEdge[148, 295] -> 
             RGBColor[
              0.6771012544220478, 0.747675913205417, 0.968450783235963], 
             UndirectedEdge[10, 119] -> 
             RGBColor[
              0.9461049635195544, 0.9593257505546823, 0.9761144180713475], 
             UndirectedEdge[115, 231] -> 
             RGBColor[
              0.966890300050093, 0.9734738881985223, 0.8803163228385751], 
             UndirectedEdge[33, 171] -> 
             RGBColor[
              0.9674685012480007, 0.9741083289417058, 0.8884381516413168], 
             UndirectedEdge[173, 234] -> 
             RGBColor[
              0.6641354471074405, 0.7334648535174413, 0.9697710991491577], 
             UndirectedEdge[69, 173] -> 
             RGBColor[
              0.7712495418429697, 0.8217123062697143, 0.9778477991629726], 
             UndirectedEdge[4, 263] -> 
             RGBColor[
              0.8967696648752339, 0.919786838080815, 0.9644647836957674], 
             UndirectedEdge[134, 160] -> 
             RGBColor[
              0.9935750402477306, 0.9911769351768529, 0.7245804858638247], 
             UndirectedEdge[7, 205] -> 
             RGBColor[
              0.9647824212879084, 0.9727749297974877, 0.9229833506687797], 
             UndirectedEdge[23, 106] -> 
             RGBColor[
              0.5613344581850443, 0.6432403871913885, 0.9622481755224177], 
             UndirectedEdge[45, 96] -> 
             RGBColor[
              0.8280073660390542, 0.8664794722592604, 0.9832489986427626], 
             UndirectedEdge[65, 210] -> 
             RGBColor[
              0.940800516924114, 0.8310843736823303, 0.5908400640738882], 
             UndirectedEdge[138, 211] -> 
             RGBColor[
              0.8888161499811874, 0.9141105107129612, 0.9867825766999345], 
             UndirectedEdge[72, 210] -> 
             RGBColor[
              0.9013077474175973, 0.9232400956691067, 0.9591670520818718], 
             UndirectedEdge[37, 41] -> 
             RGBColor[
              0.9904112920627166, 0.989319524275841, 0.7370967738285156], 
             UndirectedEdge[52, 88] -> 
             RGBColor[
              0.8914040645860526, 0.91624542085491, 0.989504109517662], 
             UndirectedEdge[157, 285] -> 
             RGBColor[
              0.851397086983579, 0.8833818649472516, 0.9179915774781158], 
             UndirectedEdge[135, 265] -> 
             RGBColor[
              0.9853459230722599, 0.9875667772886414, 0.8637963258523571], 
             UndirectedEdge[17, 42] -> 
             RGBColor[
              0.7839691093449588, 0.682164075110828, 0.601438438021634], 
             UndirectedEdge[242, 250] -> 
             RGBColor[
              0.9454257390652269, 0.9568552635052462, 0.8985384164414059], 
             UndirectedEdge[81, 202] -> 
             RGBColor[
              0.883584181038951, 0.8855096411856556, 0.6731189788194449], 
             UndirectedEdge[229, 259] -> 
             RGBColor[
              0.963100248864865, 0.9720008065379893, 0.9473458330620643], 
             UndirectedEdge[40, 81] -> 
             RGBColor[
              0.957801324533969, 0.9443789093753246, 0.6779896742535748], 
             UndirectedEdge[100, 119] -> 
             RGBColor[
              0.8094557039400164, 0.8519456647361645, 0.9782645359369517], 
             UndirectedEdge[81, 269] -> 
             RGBColor[
              0.9794921173836734, 0.9605558671672205, 0.6412728198238462], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.981525064897071, 0.9834084428776799, 0.7946812362943927], 
             UndirectedEdge[180, 233] -> 
             RGBColor[
              0.5930573303937681, 0.6802371014950781, 0.9612931578436226], 
             UndirectedEdge[33, 184] -> 
             RGBColor[
              0.7525875054741884, 0.8034847883397515, 0.875891824305739], 
             UndirectedEdge[103, 168] -> 
             RGBColor[
              0.962283528407611, 0.9713916977582262, 0.9487283277613849], 
             UndirectedEdge[49, 238] -> 
             RGBColor[
              0.8857089085558789, 0.7817290686188632, 0.6154498218130501], 
             UndirectedEdge[97, 120] -> 
             RGBColor[
              0.7146327137224471, 0.7698417347092268, 0.7123017593205198], 
             UndirectedEdge[117, 212] -> 
             RGBColor[
              0.8995883372933622, 0.921792013655456, 0.9563309514294585], 
             UndirectedEdge[270, 278] -> 
             RGBColor[
              0.9446394198422472, 0.9545601181119476, 0.7976159500681783], 
             UndirectedEdge[26, 165] -> 
             RGBColor[
              0.8863242152537882, 0.9121948868861992, 0.9890195889535156], 
             UndirectedEdge[65, 70] -> 
             RGBColor[
              0.8586737065916015, 0.7666104592868787, 0.6142593514045266], 
             UndirectedEdge[56, 223] -> 
             RGBColor[
              0.927468231932025, 0.7241281026657388, 0.4587261368230675], 
             UndirectedEdge[207, 212] -> 
             RGBColor[
              0.6609316006857899, 0.7328521667894099, 0.9683564034925873], 
             UndirectedEdge[171, 184] -> 
             RGBColor[
              0.7289400963527004, 0.7869989024072935, 0.9674340892751305], 
             UndirectedEdge[32, 205] -> 
             RGBColor[
              0.9643998505993652, 0.9610674409179205, 0.6917999724531136], 
             UndirectedEdge[23, 31] -> 
             RGBColor[
              0.6243128822859298, 0.670320384855607, 0.6550447405531095], 
             UndirectedEdge[235, 274] -> 
             RGBColor[
              0.8433080849474581, 0.8622364813001694, 0.6810657166830103], 
             UndirectedEdge[178, 199] -> 
             RGBColor[
              0.7455850533987269, 0.8011111565335697, 0.9755575626039984], 
             UndirectedEdge[117, 158] -> 
             RGBColor[
              0.9185787865481303, 0.7264357233198565, 0.5686208409274991], 
             UndirectedEdge[112, 190] -> 
             RGBColor[
              0.4761033681352643, 0.5739992414524812, 0.9542022000318551], 
             UndirectedEdge[64, 213] -> 
             RGBColor[
              0.8031506936364213, 0.8469201029002005, 0.9808089741652708], 
             UndirectedEdge[127, 205] -> 
             RGBColor[
              0.9602881343459597, 0.9699035361342045, 0.9521060094256396], 
             UndirectedEdge[121, 263] -> 
             RGBColor[
              0.8775482554203022, 0.9046959395550959, 0.9625688725783041], 
             UndirectedEdge[14, 213] -> 
             RGBColor[
              0.8416658212611433, 0.8725216303142572, 0.7084266326571163], 
             UndirectedEdge[109, 111] -> 
             RGBColor[
              0.6291768651370786, 0.7096121133804886, 0.9641013773638578], 
             UndirectedEdge[55, 108] -> 
             RGBColor[
              0.8502827687453209, 0.8031900939434514, 0.6229748721500855], 
             UndirectedEdge[40, 162] -> 
             RGBColor[
              0.9529909405536364, 0.964461300951948, 0.964458255103091], 
             UndirectedEdge[15, 225] -> 
             RGBColor[
              0.9864354516340761, 0.9747972125515352, 0.6209576140601051], 
             UndirectedEdge[31, 59] -> 
             RGBColor[
              0.9847349179671462, 0.96499724502084, 0.5862634389503792], 
             UndirectedEdge[210, 227] -> 
             RGBColor[
              0.9708030247174507, 0.9777455241567097, 0.9343070427493316], 
             UndirectedEdge[52, 93] -> 
             RGBColor[
              0.9532460124424544, 0.9646011739176129, 0.962280498763777], 
             UndirectedEdge[32, 293] -> 
             RGBColor[
              0.9578823890055405, 0.9560454833617179, 0.697241856673952], 
             UndirectedEdge[99, 209] -> 
             RGBColor[
              0.9893744941867613, 0.988609545712128, 0.7338363096387299], 
             UndirectedEdge[201, 299] -> 
             RGBColor[
              0.8622079426822131, 0.8929652257564052, 0.9867193573467881], 
             UndirectedEdge[127, 148] -> 
             RGBColor[
              0.8371774929553208, 0.8729133590690041, 0.9461617582501125], 
             UndirectedEdge[24, 226] -> 
             RGBColor[
              0.9211268913342989, 0.9375338389638044, 0.8985576934026489], 
             UndirectedEdge[144, 264] -> 
             RGBColor[
              0.7362083379879234, 0.7917109270828793, 0.9361247434263975], 
             UndirectedEdge[148, 217] -> 
             RGBColor[
              0.7958645692269002, 0.8410648378294636, 0.9801260933378066], 
             UndirectedEdge[230, 288] -> 
             RGBColor[
              0.4942738401256974, 0.5782975479241211, 0.9575800405690942], 
             UndirectedEdge[1, 83] -> 
             RGBColor[
              0.696128898411836, 0.7579575626509063, 0.93174095951294], 
             UndirectedEdge[15, 214] -> 
             RGBColor[
              0.957129662587529, 0.9534329280292293, 0.6942096280386298], 
             UndirectedEdge[173, 249] -> 
             RGBColor[
              0.9313898616961835, 0.9480074571590181, 0.9891036742933113], 
             UndirectedEdge[114, 204] -> 
             RGBColor[
              0.9710331932813419, 0.9773697873948791, 0.9094039116583019], 
             UndirectedEdge[77, 95] -> 
             RGBColor[
              0.913416302692232, 0.933674594148218, 0.9873465240344937], 
             UndirectedEdge[52, 295] -> 
             RGBColor[
              0.7958444532090936, 0.841358499496515, 0.9800419893629615], 
             UndirectedEdge[7, 103] -> 
             RGBColor[
              0.9662074850474225, 0.9738377400160056, 0.9205710894400772], 
             UndirectedEdge[29, 99] -> 
             RGBColor[
              0.8106018875444135, 0.8518149005257343, 0.9319372542832953], 
             UndirectedEdge[28, 144] -> 
             RGBColor[
              0.5352507416502476, 0.6335796906996196, 0.9565560455522293], 
             UndirectedEdge[75, 185] -> 
             RGBColor[
              0.9706407960462691, 0.9693992327789085, 0.6890419022028494], 
             UndirectedEdge[227, 291] -> 
             RGBColor[
              0.8987566167592669, 0.9211999271458682, 0.9587168715870773], 
             UndirectedEdge[76, 192] -> 
             RGBColor[
              0.8526231808904405, 0.8842211344395815, 0.9127375703636196], 
             UndirectedEdge[59, 72] -> 
             RGBColor[
              0.9113944124875872, 0.9296548049364733, 0.8924785293474503], 
             UndirectedEdge[104, 254] -> 
             RGBColor[
              0.9853214495543992, 0.9858607976668949, 0.7581842932604299], 
             UndirectedEdge[32, 237] -> 
             RGBColor[
              0.9773959394043343, 0.970759902669524, 0.6698009840291206], 
             UndirectedEdge[25, 232] -> 
             RGBColor[
              0.7892612003448016, 0.8359232015428457, 0.9709197551443287], 
             UndirectedEdge[9, 141] -> 
             RGBColor[
              0.7384663062850347, 0.793841382295121, 0.944277427290935], 
             UndirectedEdge[22, 48] -> 
             RGBColor[
              0.86428021978488, 0.8903685366443834, 0.7251270489144062], 
             UndirectedEdge[25, 160] -> 
             RGBColor[
              0.9700128827375076, 0.9749632095235636, 0.8253190702155382], 
             UndirectedEdge[72, 106] -> 
             RGBColor[
              0.8422902324178819, 0.87708338424347, 0.9848195883610263], 
             UndirectedEdge[4, 186] -> 
             RGBColor[
              0.8836311872353158, 0.9099881829692467, 0.9867047992763733], 
             UndirectedEdge[78, 182] -> 
             RGBColor[
              0.9553064844609536, 0.9638142045185136, 0.859305866489902], 
             UndirectedEdge[106, 211] -> 
             RGBColor[
              0.8955596217003929, 0.9194875720151923, 0.9874257750524806], 
             UndirectedEdge[180, 245] -> 
             RGBColor[
              0.7587593304652658, 0.8084074972729169, 0.8727049410666793], 
             UndirectedEdge[136, 280] -> 
             RGBColor[
              0.9139999942690782, 0.9319955333836936, 0.9041521211675745], 
             UndirectedEdge[82, 140] -> 
             RGBColor[
              0.4841805216502537, 0.5921185854164321, 0.9525356107574499], 
             UndirectedEdge[50, 219] -> 
             RGBColor[
              0.9238697753661832, 0.9062083739052273, 0.6605789412500023], 
             UndirectedEdge[251, 278] -> 
             RGBColor[
              0.896994903404307, 0.916732546305588, 0.7930283522502941], 
             UndirectedEdge[80, 150] -> 
             RGBColor[
              0.8960832628391067, 0.9191591649473002, 0.9616133633289623], 
             UndirectedEdge[26, 183] -> 
             RGBColor[
              0.9405921934729642, 0.9540593777977887, 0.9440303590405651], 
             UndirectedEdge[243, 256] -> 
             RGBColor[
              0.5500115164838, 0.6319612602422565, 0.9615091216157657], 
             UndirectedEdge[184, 248] -> 
             RGBColor[
              0.7522405930641209, 0.8033413311429463, 0.881641060721096], 
             UndirectedEdge[4, 255] -> 
             RGBColor[
              0.8248102250997931, 0.5120936701775886, 0.5753529357059755], 
             UndirectedEdge[37, 280] -> 
             RGBColor[
              0.9880850915607733, 0.9893408934082693, 0.8471243978399874], 
             UndirectedEdge[188, 260] -> 
             RGBColor[
              0.776108331466328, 0.8251927351881962, 0.9782733086439364], 
             UndirectedEdge[70, 266] -> 
             RGBColor[
              0.7610710224506878, 0.8132737341832643, 0.9768201049709612], 
             UndirectedEdge[103, 127] -> 
             RGBColor[
              0.9617131981054738, 0.9709663463527225, 0.949693748196937], 
             UndirectedEdge[37, 268] -> 
             RGBColor[
              0.9706124857558658, 0.9771900051397338, 0.9161159905221545], 
             UndirectedEdge[186, 196] -> 
             RGBColor[
              0.9662983379354216, 0.9726574704336153, 0.8645280770955119], 
             UndirectedEdge[139, 274] -> 
             RGBColor[
              0.8453381294693375, 0.8785280256216832, 0.9119220783476205], 
             UndirectedEdge[15, 255] -> 
             RGBColor[
              0.9025575365228612, 0.5588669653135674, 0.28120509598500487`], 
             UndirectedEdge[118, 195] -> 
             RGBColor[
              0.9897375926335742, 0.9894609916472923, 0.7787956007597534], 
             UndirectedEdge[125, 128] -> 
             RGBColor[
              0.9939809159958619, 0.9895341128749202, 0.5862380355092938], 
             UndirectedEdge[61, 177] -> 
             RGBColor[
              0.989983263958124, 0.9901258364753793, 0.8156667689031912], 
             UndirectedEdge[117, 276] -> 
             RGBColor[
              0.9191581720526711, 0.9373964686835157, 0.9581975397389991], 
             UndirectedEdge[7, 154] -> 
             RGBColor[
              0.9872918961060515, 0.9890128867035485, 0.8602696992487626], 
             UndirectedEdge[59, 198] -> 
             RGBColor[
              0.9927118443073726, 0.9906339155740502, 0.7253608498771434], 
             UndirectedEdge[83, 197] -> 
             RGBColor[
              0.4338196712097445, 0.5500760370772875, 0.9488907969605843], 
             UndirectedEdge[243, 283] -> 
             RGBColor[
              0.9134390972451676, 0.9326956044036555, 0.9527763442586308], 
             UndirectedEdge[95, 225] -> 
             RGBColor[
              0.9642876278549153, 0.9722346517886473, 0.9161514501425074], 
             UndirectedEdge[21, 74] -> 
             RGBColor[
              0.9328310646306572, 0.9474910420503633, 0.9267969009364451], 
             UndirectedEdge[62, 225] -> 
             RGBColor[
              0.9903950639398333, 0.9880474867603048, 0.6453898171344037], 
             UndirectedEdge[236, 267] -> 
             RGBColor[
              0.8736683694163724, 0.9012784842307584, 0.942798436060802], 
             UndirectedEdge[123, 300] -> 
             RGBColor[
              0.9804082661129694, 0.9847748599786015, 0.9120364457294599], 
             UndirectedEdge[111, 218] -> 
             RGBColor[
              0.6108488280320199, 0.6949536228793233, 0.9625074038371174], 
             UndirectedEdge[61, 161] -> 
             RGBColor[
              0.9570282223924217, 0.9665689867904401, 0.9197161739732397], 
             UndirectedEdge[58, 180] -> 
             RGBColor[
              0.6929937107819153, 0.7586318044234528, 0.9711679973745411], 
             UndirectedEdge[188, 236] -> 
             RGBColor[
              0.7369724674294879, 0.7944477598449013, 0.9744181862202486], 
             UndirectedEdge[41, 268] -> 
             RGBColor[
              0.9743433674471189, 0.9777495077777449, 0.7828091640054298], 
             UndirectedEdge[65, 138] -> 
             RGBColor[
              0.8750395302051932, 0.7795506009544626, 0.6158494020004968], 
             UndirectedEdge[241, 291] -> 
             RGBColor[
              0.7405966170343512, 0.7973324034966667, 0.9747652287884081], 
             UndirectedEdge[270, 295] -> 
             RGBColor[
              0.7765324500833222, 0.8259596324143849, 0.9781999932647967], 
             UndirectedEdge[127, 212] -> 
             RGBColor[
              0.9017979301594027, 0.9234399243970728, 0.9525906870613682], 
             UndirectedEdge[105, 274] -> 
             RGBColor[
              0.6815439008676945, 0.7511465423741197, 0.9688935847147736], 
             UndirectedEdge[128, 142] -> 
             RGBColor[
              0.9293995569319102, 0.9420765948110563, 0.7692760895759956], 
             UndirectedEdge[38, 57] -> 
             RGBColor[
              0.9528564340210064, 0.9261896967364391, 0.6555765231963889], 
             UndirectedEdge[135, 255] -> 
             RGBColor[
              0.9053596901635441, 0.573887240209286, 0.4882717449142634], 
             UndirectedEdge[46, 196] -> 
             RGBColor[
              0.9587889044710891, 0.9667290085026186, 0.8658697468885792], 
             UndirectedEdge[138, 210] -> 
             RGBColor[
              0.9049263570770654, 0.926125476787024, 0.9595121983015629], 
             UndirectedEdge[72, 109] -> 
             RGBColor[
              0.7443581346659534, 0.8003140393494692, 0.9751287017262142], 
             UndirectedEdge[277, 282] -> 
             RGBColor[
              0.7602887112919358, 0.8127967778187926, 0.9767065213248332], 
             UndirectedEdge[62, 117] -> 
             RGBColor[
              0.9831757584128166, 0.9833150405747502, 0.6867946783026446], 
             UndirectedEdge[33, 126] -> 
             RGBColor[
              0.9913183918452417, 0.9906779461679242, 0.793540244613437], 
             UndirectedEdge[217, 278] -> 
             RGBColor[
              0.9448130645197688, 0.9546985776643442, 0.7976325124525347], 
             UndirectedEdge[228, 264] -> 
             RGBColor[
              0.9828306582292621, 0.9864409828204019, 0.9016443937539772], 
             UndirectedEdge[121, 239] -> 
             RGBColor[
              0.6919170971453423, 0.7584942813577963, 0.9704442877994472], 
             UndirectedEdge[56, 84] -> 
             RGBColor[
              0.7584475542261401, 0.8073203417398775, 0.8341125725096155], 
             UndirectedEdge[45, 120] -> 
             RGBColor[
              0.5795904275845407, 0.6678811238810386, 0.9610176261449234], 
             UndirectedEdge[67, 234] -> 
             RGBColor[
              0.6550726451112118, 0.7262384212088553, 0.9689066810042986], 
             UndirectedEdge[153, 192] -> 
             RGBColor[
              0.722354864483834, 0.7830283773258595, 0.9729612401678919], 
             UndirectedEdge[77, 127] -> 
             RGBColor[
              0.9322336445208305, 0.9477085368734174, 0.9554936726674441], 
             UndirectedEdge[36, 152] -> 
             RGBColor[
              0.6091865289418517, 0.6810699285824013, 0.9554958239322565], 
             UndirectedEdge[22, 122] -> 
             RGBColor[
              0.9927783609098718, 0.9869619691429572, 0.4553473357089908], 
             UndirectedEdge[68, 218] -> 
             RGBColor[
              0.4450743233280572, 0.5518125517962225, 0.9509633153608651], 
             UndirectedEdge[56, 148] -> 
             RGBColor[
              0.8457014014665462, 0.8773312552489487, 0.8415460440365887], 
             UndirectedEdge[7, 130] -> 
             RGBColor[
              0.9761071842124465, 0.9812209194440108, 0.903813481008754], 
             UndirectedEdge[58, 296] -> 
             RGBColor[
              0.8381101221707328, 0.873780907427939, 0.9844127575521366], 
             UndirectedEdge[104, 116] -> 
             RGBColor[
              0.9936298386124016, 0.9887831938510669, 0.5480254289180958], 
             UndirectedEdge[252, 279] -> 
             RGBColor[
              0.8147898019939851, 0.8556989701924592, 0.9578531183597471], 
             UndirectedEdge[64, 173] -> 
             RGBColor[
              0.919019475753254, 0.9382652001192693, 0.9921380920873584], 
             UndirectedEdge[109, 155] -> 
             RGBColor[
              0.7866898808596257, 0.7194139138943652, 0.6090860210000637], 
             UndirectedEdge[151, 258] -> 
             RGBColor[
              0.9793164740484874, 0.9837652584570517, 0.905136626212402], 
             UndirectedEdge[167, 216] -> 
             RGBColor[
              0.7043919170213493, 0.7689955862447092, 0.9711708614381194], 
             UndirectedEdge[12, 258] -> 
             RGBColor[
              0.9179018133014649, 0.935742766303429, 0.9321428264010201], 
             UndirectedEdge[151, 239] -> 
             RGBColor[
              0.7827362785522511, 0.8297274084987787, 0.9463052729655916], 
             UndirectedEdge[136, 226] -> 
             RGBColor[
              0.9143764167138808, 0.9321511937382352, 0.8979138271071336], 
             UndirectedEdge[59, 210] -> 
             RGBColor[
              0.9807740088659762, 0.9840739587822583, 0.867814337640533], 
             UndirectedEdge[191, 205] -> 
             RGBColor[
              0.9651496923514199, 0.9635968332188167, 0.6947129660641127], 
             UndirectedEdge[212, 276] -> 
             RGBColor[
              0.8450704380555769, 0.8793002447522962, 0.9850847668566685], 
             UndirectedEdge[218, 292] -> 
             RGBColor[
              0.7784422746717827, 0.8274204291859859, 0.977591951500745], 
             UndirectedEdge[144, 245] -> 
             RGBColor[
              0.7420790263748801, 0.7948656749732059, 0.871391806426717], 
             UndirectedEdge[1, 277] -> 
             RGBColor[
              0.8327774014804655, 0.8694145651953227, 0.9426146861633016], 
             UndirectedEdge[64, 239] -> 
             RGBColor[
              0.7543436635130859, 0.8080357992330494, 0.9764611453529535], 
             UndirectedEdge[128, 256] -> 
             RGBColor[
              0.622968302328801, 0.6856696206355888, 0.7446157410583627], 
             UndirectedEdge[7, 81] -> 
             RGBColor[
              0.9822226127462215, 0.9621118279585303, 0.6151358001403922], 
             UndirectedEdge[32, 145] -> 
             RGBColor[
              0.9658317880624705, 0.9621353775333219, 0.6893760758371803], 
             UndirectedEdge[84, 247] -> 
             RGBColor[
              0.7379883105327693, 0.7940010921234066, 0.9589316959525456], 
             UndirectedEdge[215, 259] -> 
             RGBColor[
              0.9043147889684572, 0.7122481693789501, 0.5904023758730217], 
             UndirectedEdge[187, 233] -> 
             RGBColor[
              0.6888760401250897, 0.7568744652883193, 0.9696243838332137], 
             UndirectedEdge[37, 152] -> 
             RGBColor[
              0.9675184328408167, 0.9748824655417367, 0.9213534150490909], 
             UndirectedEdge[257, 300] -> 
             RGBColor[
              0.9893714377177355, 0.9885450519669725, 0.7292908230566573], 
             UndirectedEdge[10, 244] -> 
             RGBColor[
              0.8281328567808974, 0.8662915945129868, 0.9677341628879657], 
             UndirectedEdge[98, 157] -> 
             RGBColor[
              0.9687729922999168, 0.9151128229760681, 0.5713408218065812], 
             UndirectedEdge[13, 271] -> 
             RGBColor[
              0.9655927087593041, 0.9681842252317034, 0.7029998412928367], 
             UndirectedEdge[202, 203] -> 
             RGBColor[
              0.8483620914149855, 0.7521936401025417, 0.6118229229142407], 
             UndirectedEdge[166, 195] -> 
             RGBColor[
              0.9341997637884054, 0.9489935132199707, 0.9447791606409441], 
             UndirectedEdge[260, 287] -> 
             RGBColor[
              0.8620800089751692, 0.8928632148910765, 0.9867071549156026], 
             UndirectedEdge[212, 214] -> 
             RGBColor[
              0.8775018537738319, 0.9051601753187047, 0.9881781042397423], 
             UndirectedEdge[25, 113] -> 
             RGBColor[
              0.951035566346468, 0.9630029860698733, 0.967768193592556], 
             UndirectedEdge[244, 280] -> 
             RGBColor[
              0.8463684801934308, 0.8790115400639629, 0.897450980422952], 
             UndirectedEdge[58, 134] -> 
             RGBColor[
              0.9261985957764753, 0.9411693179800004, 0.8813003322897042], 
             UndirectedEdge[64, 263] -> 
             RGBColor[
              0.9399748217880459, 0.9542374574303489, 0.9685857301318104], 
             UndirectedEdge[182, 261] -> 
             RGBColor[
              0.9513284519821946, 0.9621773372402006, 0.9258246789329432], 
             UndirectedEdge[150, 277] -> 
             RGBColor[
              0.8256924080309322, 0.8641305886812728, 0.9546077320111226], 
             UndirectedEdge[86, 202] -> 
             RGBColor[0.6233784272670658, 0.7028670011831306, 0.965038075436],
              UndirectedEdge[257, 267] -> 
             RGBColor[
              0.9890595964671394, 0.9884160975958963, 0.734458839598322], 
             UndirectedEdge[134, 245] -> 
             RGBColor[
              0.9919642154598257, 0.9909450108294644, 0.7828372759818425], 
             UndirectedEdge[187, 297] -> 
             RGBColor[
              0.8409376025777449, 0.8760954469204876, 0.958921262830384], 
             UndirectedEdge[75, 292] -> 
             RGBColor[
              0.9444581248785484, 0.9580975409926709, 0.978902086326263], 
             UndirectedEdge[54, 174] -> 
             RGBColor[
              0.8279967348785211, 0.8664418115341219, 0.9832557290968242], 
             UndirectedEdge[44, 108] -> 
             RGBColor[
              0.8274891212045703, 0.8657455766811033, 0.9832846616147118], 
             UndirectedEdge[94, 141] -> 
             RGBColor[
              0.9826944167533507, 0.9842805435774553, 0.7927018286175205], 
             UndirectedEdge[185, 262] -> 
             RGBColor[
              0.9128521262762631, 0.9237446965614393, 0.6982504371751797], 
             UndirectedEdge[40, 202] -> 
             RGBColor[
              0.8640241109869118, 0.8945917410403947, 0.9845549308541242], 
             UndirectedEdge[110, 191] -> 
             RGBColor[
              0.9341172103125854, 0.7602248397711635, 0.314552833251614], 
             UndirectedEdge[92, 125] -> 
             RGBColor[
              0.9941388125849994, 0.9898718377132912, 0.6034241048121098], 
             UndirectedEdge[72, 226] -> 
             RGBColor[
              0.9110853843394484, 0.9295270138555568, 0.897599925501321], 
             UndirectedEdge[130, 162] -> 
             RGBColor[
              0.9664355820719005, 0.9744882925826894, 0.9416999839367737], 
             UndirectedEdge[29, 43] -> 
             RGBColor[
              0.7681050894702328, 0.819321788062709, 0.9774134636724073], 
             UndirectedEdge[152, 268] -> 
             RGBColor[
              0.9514505082252191, 0.9633124490436409, 0.967065805226005], 
             UndirectedEdge[4, 62] -> 
             RGBColor[
              0.9109685218063512, 0.9267182742180764, 0.713861268940172], 
             UndirectedEdge[18, 184] -> 
             RGBColor[
              0.5839373591744009, 0.6729301793403579, 0.9605088252653389], 
             UndirectedEdge[95, 159] -> 
             RGBColor[
              0.8955465728746976, 0.9194257566526103, 0.9856420932520013], 
             UndirectedEdge[154, 255] -> 
             RGBColor[
              0.9039294067138643, 0.5732957812462355, 0.5119752431303717], 
             UndirectedEdge[140, 269] -> 
             RGBColor[
              0.7415252398658532, 0.7959677487577036, 0.9349426422428091], 
             UndirectedEdge[10, 161] -> 
             RGBColor[
              0.9394801441826849, 0.9541333588499261, 0.9786049531179669], 
             UndirectedEdge[216, 293] -> 
             RGBColor[
              0.8268184153454143, 0.8655208385220585, 0.9831384075098204], 
             UndirectedEdge[188, 294] -> 
             RGBColor[
              0.840898201234707, 0.875948953839149, 0.9530599902584063], 
             UndirectedEdge[32, 282] -> 
             RGBColor[
              0.9114525472427246, 0.9190235878445291, 0.6928133369182057], 
             UndirectedEdge[251, 282] -> 
             RGBColor[
              0.8182097461454365, 0.8580451304625165, 0.982479548776185], 
             UndirectedEdge[181, 299] -> 
             RGBColor[
              0.9454669958979005, 0.9567639220285178, 0.8931474845457597], 
             UndirectedEdge[60, 159] -> 
             RGBColor[
              0.6044263724267915, 0.6842146906173023, 0.9648308693578801], 
             UndirectedEdge[137, 217] -> 
             RGBColor[
              0.9448161005723293, 0.954705071473779, 0.7979629680374021], 
             UndirectedEdge[20, 152] -> 
             RGBColor[
              0.9624832495407232, 0.9715406494522879, 0.94839025197864], 
             UndirectedEdge[62, 196] -> 
             RGBColor[
              0.9936356725064572, 0.9893875616824451, 0.5916845467593106], 
             UndirectedEdge[251, 289] -> 
             RGBColor[
              0.8527156993052284, 0.8855592408729878, 0.9857707573923942], 
             UndirectedEdge[104, 283] -> 
             RGBColor[
              0.9865811846083388, 0.9868003060074962, 0.7560518904056326], 
             UndirectedEdge[45, 294] -> 
             RGBColor[
              0.8468457927101676, 0.880595257503148, 0.9536527905932778], 
             UndirectedEdge[15, 158] -> 
             RGBColor[
              0.9241188613647332, 0.7166122520991616, 0.301539591844056], 
             UndirectedEdge[150, 237] -> 
             RGBColor[
              0.967933493856707, 0.9756054327391928, 0.939164410003059], 
             UndirectedEdge[169, 228] -> 
             RGBColor[
              0.9696159442676902, 0.9206569198352536, 0.5827947415267656], 
             UndirectedEdge[159, 251] -> 
             RGBColor[
              0.8252328298594136, 0.863645146779513, 0.9831494167704051], 
             UndirectedEdge[203, 293] -> 
             RGBColor[
              0.9181816519099049, 0.8076219527202266, 0.6185471010629173], 
             UndirectedEdge[145, 282] -> 
             RGBColor[
              0.8909656457758466, 0.9156470967405104, 0.9808382911248293], 
             UndirectedEdge[195, 234] -> 
             RGBColor[
              0.6953749730374833, 0.7569983669991289, 0.9239439121494093], 
             UndirectedEdge[156, 270] -> 
             RGBColor[
              0.6262527189366498, 0.7015896487313771, 0.9669259339277282], 
             UndirectedEdge[25, 134] -> 
             RGBColor[
              0.9688092263891941, 0.974899659789698, 0.8768280255713842], 
             UndirectedEdge[158, 276] -> 
             RGBColor[
              0.864060887310345, 0.6839439544166968, 0.5973746563547091], 
             UndirectedEdge[268, 280] -> 
             RGBColor[
              0.9720171669451757, 0.9777708769101734, 0.8928367880169015], 
             UndirectedEdge[8, 186] -> 
             RGBColor[
              0.8455386185283996, 0.8801549914097548, 0.982927987365682], 
             UndirectedEdge[32, 256] -> 
             RGBColor[
              0.6192965209428843, 0.6739992932273386, 0.6695145724197853], 
             UndirectedEdge[60, 168] -> 
             RGBColor[
              0.6687280450481699, 0.7343644017149054, 0.932039402612985], 
             UndirectedEdge[162, 216] -> 
             RGBColor[
              0.8459656844172196, 0.8799620858159272, 0.9563175536101107], 
             UndirectedEdge[106, 115] -> 
             RGBColor[
              0.9224957159211582, 0.9382229346734619, 0.8812160514246833], 
             UndirectedEdge[77, 276] -> 
             RGBColor[
              0.8755061524170047, 0.9035688572286409, 0.9879877524627445], 
             UndirectedEdge[80, 281] -> 
             RGBColor[
              0.5437117494689743, 0.6282541967809303, 0.9607088490096172], 
             UndirectedEdge[130, 293] -> 
             RGBColor[
              0.9472883130000953, 0.9600470452888208, 0.9685208378364835], 
             UndirectedEdge[39, 118] -> 
             RGBColor[
              0.9892573056146884, 0.9892114627314761, 0.7844749924290482], 
             UndirectedEdge[58, 245] -> 
             RGBColor[
              0.9257914273368839, 0.9410009433664777, 0.8880481670518761], 
             UndirectedEdge[54, 143] -> 
             RGBColor[
              0.8223337006008704, 0.8620178061157666, 0.9826912907640922], 
             UndirectedEdge[239, 258] -> 
             RGBColor[
              0.7895956106192584, 0.8345135048519758, 0.9199348454937875], 
             UndirectedEdge[184, 222] -> 
             RGBColor[
              0.563865811030978, 0.6568106931170818, 0.9588087286343333], 
             UndirectedEdge[143, 298] -> 
             RGBColor[
              0.629238897129066, 0.708768225141887, 0.9647176634041329], 
             UndirectedEdge[203, 269] -> 
             RGBColor[
              0.9442700277597079, 0.8272398660841067, 0.5799767639186418], 
             UndirectedEdge[107, 139] -> 
             RGBColor[
              0.9906206737490637, 0.9903894218046173, 0.8051032391036594], 
             UndirectedEdge[108, 283] -> 
             RGBColor[
              0.8708410490224712, 0.8991932737977602, 0.9485901208457425], 
             UndirectedEdge[173, 186] -> 
             RGBColor[
              0.930183907998232, 0.947108058865654, 0.9911450393408447], 
             UndirectedEdge[164, 296] -> 
             RGBColor[
              0.6937867882409854, 0.7596234581087014, 0.9708572485706637], 
             UndirectedEdge[11, 116] -> 
             RGBColor[
              0.9783088493246505, 0.9800693690875518, 0.7255067106798737], 
             UndirectedEdge[43, 229] -> 
             RGBColor[
              0.9395605058359672, 0.9535227584324864, 0.9552210868516592], 
             UndirectedEdge[128, 149] -> 
             RGBColor[
              0.9308290830806154, 0.9432164601585802, 0.769412439056212], 
             UndirectedEdge[221, 232] -> 
             RGBColor[
              0.7992928171083596, 0.8434047648998424, 0.9539388446283074], 
             UndirectedEdge[8, 85] -> 
             RGBColor[
              0.8731545057343886, 0.8974808785787587, 0.7404031923165738], 
             UndirectedEdge[20, 41] -> 
             RGBColor[
              0.985376108762623, 0.9859777081863921, 0.7641336107580647], 
             UndirectedEdge[108, 252] -> 
             RGBColor[
              0.862556301927291, 0.8930145229792031, 0.962614036669778], 
             UndirectedEdge[65, 241] -> 
             RGBColor[
              0.782756198120663, 0.7073031246749469, 0.6066926036495963], 
             UndirectedEdge[231, 245] -> 
             RGBColor[
              0.9664992645373298, 0.9733121849648403, 0.8867967932525307], 
             UndirectedEdge[80, 167] -> 
             RGBColor[
              0.7546829095388609, 0.8083219973246596, 0.9761731263267185], 
             UndirectedEdge[17, 201] -> 
             RGBColor[
              0.7482894474742454, 0.8033264024232158, 0.9755361441802559], 
             UndirectedEdge[57, 223] -> 
             RGBColor[
              0.9130582020432352, 0.6771490573363381, 0.2641961028009611], 
             UndirectedEdge[162, 202] -> 
             RGBColor[
              0.8787737970586184, 0.9055920327622791, 0.9595875596689611], 
             UndirectedEdge[3, 59] -> 
             RGBColor[
              0.9770281054405143, 0.9812802701409027, 0.8741551750517565], 
             UndirectedEdge[180, 187] -> 
             RGBColor[
              0.6217803236416188, 0.702675722123133, 0.9641559973789354], 
             UndirectedEdge[193, 215] -> 
             RGBColor[
              0.8369293578954871, 0.6588712882670315, 0.5940789956593333], 
             UndirectedEdge[43, 78] -> 
             RGBColor[
              0.9476058849161031, 0.957673955468656, 0.8585713764309079], 
             UndirectedEdge[56, 251] -> 
             RGBColor[
              0.8974880806898802, 0.9177874026515568, 0.8467076562475383], 
             UndirectedEdge[261, 284] -> 
             RGBColor[
              0.9859197747138433, 0.988445479245959, 0.8830093016539893], 
             UndirectedEdge[36, 41] -> 
             RGBColor[
              0.6320793881637514, 0.6955069873165055, 0.7712391827116812], 
             UndirectedEdge[95, 168] -> 
             RGBColor[
              0.959848245496076, 0.9695754677502131, 0.9528506265071062], 
             UndirectedEdge[194, 280] -> 
             RGBColor[
              0.987796915316407, 0.9892217251254322, 0.8519002239853513], 
             UndirectedEdge[99, 182] -> 
             RGBColor[
              0.9501366162852557, 0.961684482550736, 0.945576480803133], 
             UndirectedEdge[94, 97] -> 
             RGBColor[
              0.993770602609545, 0.9890842738075333, 0.5633467213124548], 
             UndirectedEdge[79, 240] -> 
             RGBColor[
              0.7910721122576329, 0.8372889699731119, 0.979656908290685], 
             UndirectedEdge[83, 198] -> 
             RGBColor[
              0.7026285130846455, 0.7604617032977553, 0.7984929609956319], 
             UndirectedEdge[69, 213] -> 
             RGBColor[
              0.655380759726137, 0.7303672090506454, 0.966518681240885], 
             UndirectedEdge[214, 286] -> 
             RGBColor[
              0.9619016521164389, 0.9684207949743856, 0.8070640784420073], 
             UndirectedEdge[277, 293] -> 
             RGBColor[
              0.8067185530547516, 0.8498186733359814, 0.9811350410805797], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.9887158332294195, 0.9734915693540553, 0.4197134292192015], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.9043416252479382, 0.9235633863887669, 0.869800734202689], 
             UndirectedEdge[43, 199] -> 
             RGBColor[
              0.8949539157500432, 0.9190759758149332, 0.989842697490673], 
             UndirectedEdge[192, 222] -> 
             RGBColor[
              0.6655940509632762, 0.738246958141221, 0.9676043004447721], 
             UndirectedEdge[130, 202] -> 
             RGBColor[
              0.8774687525051759, 0.904618732671136, 0.9617966596878068], 
             UndirectedEdge[4, 265] -> 
             RGBColor[
              0.9047964580085088, 0.9257732072569439, 0.950877516644069], 
             UndirectedEdge[121, 173] -> 
             RGBColor[
              0.8565929093855105, 0.8887236822440161, 0.986121234533852], 
             UndirectedEdge[53, 107] -> 
             RGBColor[
              0.966671087850721, 0.9731175614435236, 0.872051682920657], 
             UndirectedEdge[172, 238] -> 
             RGBColor[
              0.9473293597093013, 0.8289318092548745, 0.5483900709860408], 
             UndirectedEdge[210, 211] -> 
             RGBColor[
              0.9545771367001084, 0.965644283440829, 0.9617732387733262], 
             UndirectedEdge[180, 221] -> 
             RGBColor[
              0.7456359581581922, 0.7998437095901471, 0.9497147801401995], 
             UndirectedEdge[196, 212] -> 
             RGBColor[
              0.9100482513870027, 0.9278645347631509, 0.8612208198861244], 
             UndirectedEdge[160, 176] -> 
             RGBColor[
              0.9842011621899369, 0.98554480510801, 0.8013020139985149], 
             UndirectedEdge[115, 193] -> 
             RGBColor[
              0.9022934803119204, 0.9221767488541637, 0.8792725510213937], 
             UndirectedEdge[21, 300] -> 
             RGBColor[
              0.9859940627481862, 0.9884761992572753, 0.8817781566736549], 
             UndirectedEdge[75, 235] -> 
             RGBColor[
              0.9679225797664396, 0.9602300509995099, 0.6784821452477844], 
             UndirectedEdge[77, 255] -> 
             RGBColor[
              0.8533654420705918, 0.5348628250793875, 0.5780765577921934], 
             UndirectedEdge[62, 286] -> 
             RGBColor[
              0.9934878227583293, 0.9884794362992115, 0.532567879622579], 
             UndirectedEdge[46, 225] -> 
             RGBColor[
              0.9555482959044654, 0.9653889335804782, 0.9195750172636724], 
             UndirectedEdge[37, 161] -> 
             RGBColor[
              0.9563110864059083, 0.9662724326304627, 0.9316009731582062], 
             UndirectedEdge[3, 162] -> 
             RGBColor[
              0.9654680817852027, 0.9737667324530065, 0.9433377095576649], 
             UndirectedEdge[107, 274] -> 
             RGBColor[
              0.848217299137876, 0.8797186362709093, 0.8642067858876852], 
             UndirectedEdge[6, 147] -> 
             RGBColor[
              0.7099061980247559, 0.7733033844746584, 0.9717204734346532], 
             UndirectedEdge[8, 135] -> 
             RGBColor[
              0.8717184944343608, 0.8986550833455338, 0.8927189028844404], 
             UndirectedEdge[186, 249] -> 
             RGBColor[
              0.9392067300910572, 0.9541810593585296, 0.9877913279183693], 
             UndirectedEdge[277, 281] -> 
             RGBColor[
              0.47332089466079996`, 0.5732256205149029, 0.9537032176917772], 
             UndirectedEdge[256, 277] -> 
             RGBColor[
              0.4681326849920955, 0.5677724832016021, 0.953407756826413], 
             UndirectedEdge[8, 249] -> 
             RGBColor[
              0.8467445722263511, 0.8810543897031191, 0.9808866223181485], 
             UndirectedEdge[114, 254] -> 
             RGBColor[
              0.965594784729529, 0.973861227301428, 0.9431232345223409], 
             UndirectedEdge[223, 270] -> 
             RGBColor[
              0.8774577550148575, 0.6877232256938572, 0.5972896237399289], 
             UndirectedEdge[120, 294] -> 
             RGBColor[
              0.7035565278662528, 0.7650380044791489, 0.9416568666255855], 
             UndirectedEdge[23, 290] -> 
             RGBColor[
              0.45706876676155206`, 0.5615231907840673, 0.951926015461222], 
             UndirectedEdge[7, 293] -> 
             RGBColor[
              0.9582649596940837, 0.9677529722412852, 0.9284252348896181], 
             UndirectedEdge[95, 191] -> 
             RGBColor[
              0.9641394731993991, 0.9628434134293217, 0.6964230035811313], 
             UndirectedEdge[65, 194] -> 
             RGBColor[
              0.9485088739674863, 0.8365155914609622, 0.5635662602043952], 
             UndirectedEdge[94, 188] -> 
             RGBColor[
              0.852780724996178, 0.8824773593153459, 0.8114697878019868], 
             UndirectedEdge[24, 162] -> 
             RGBColor[
              0.9098758958271262, 0.9301480923568246, 0.9626188317546867], 
             UndirectedEdge[34, 84] -> 
             RGBColor[
              0.75482537898575, 0.8059423287511038, 0.9028531878593321], 
             UndirectedEdge[130, 201] -> 
             RGBColor[
              0.8948913955073197, 0.918267165556518, 0.9635231730707421], 
             UndirectedEdge[74, 260] -> 
             RGBColor[
              0.8599530765862795, 0.8911672567382174, 0.9865042862056153], 
             UndirectedEdge[69, 85] -> 
             RGBColor[
              0.8066822974438324, 0.8452117956382295, 0.7340106577389225], 
             UndirectedEdge[220, 262] -> 
             RGBColor[
              0.8995649451876756, 0.8789239147711512, 0.6466322477196216], 
             UndirectedEdge[26, 262] -> 
             RGBColor[
              0.8663808455521201, 0.8962925852344383, 0.9871173725477143], 
             UndirectedEdge[217, 270] -> 
             RGBColor[
              0.8952957648881745, 0.9193485570384314, 0.9898753033666403], 
             UndirectedEdge[221, 245] -> 
             RGBColor[
              0.9784336747131608, 0.982212848533172, 0.8665949498175345], 
             UndirectedEdge[3, 24] -> 
             RGBColor[
              0.9076033509869859, 0.9284532321359986, 0.9664656573944234], 
             UndirectedEdge[59, 197] -> 
             RGBColor[
              0.7239030024324717, 0.7802482493535825, 0.8757586858420958], 
             UndirectedEdge[54, 235] -> 
             RGBColor[
              0.9565922596440812, 0.9516201417127683, 0.6921219190833655], 
             UndirectedEdge[159, 282] -> 
             RGBColor[
              0.8436094886700778, 0.8781353233687139, 0.9849454202000747], 
             UndirectedEdge[6, 53] -> 
             RGBColor[
              0.8025829760315255, 0.8465651129711492, 0.9769961589403042], 
             UndirectedEdge[31, 210] -> 
             RGBColor[
              0.9746482528971563, 0.9585825357534734, 0.6529519616848007], 
             UndirectedEdge[137, 273] -> 
             RGBColor[
              0.9900328436374213, 0.9891808128474953, 0.7446615504934726], 
             UndirectedEdge[99, 259] -> 
             RGBColor[
              0.965975759769303, 0.9740222816063813, 0.9369667369545438], 
             UndirectedEdge[16, 151] -> 
             RGBColor[
              0.9474968332282994, 0.9600243807030971, 0.9619903025091812], 
             UndirectedEdge[24, 227] -> 
             RGBColor[
              0.9114649353339123, 0.9313331954191724, 0.9599290023575768], 
             UndirectedEdge[87, 202] -> 
             RGBColor[
              0.7238748737239425, 0.7842158200967302, 0.9731127404836519], 
             UndirectedEdge[17, 94] -> 
             RGBColor[
              0.8332517909835655, 0.8672212076392973, 0.809523326167874], 
             UndirectedEdge[5, 92] -> 
             RGBColor[
              0.9935040333851604, 0.9885141091908576, 0.5343323063127542], 
             UndirectedEdge[72, 290] -> 
             RGBColor[
              0.7380245409943895, 0.7953661878361488, 0.9744974282998307], 
             UndirectedEdge[103, 212] -> 
             RGBColor[
              0.885415871242339, 0.9112222116798863, 0.9803212396826967], 
             UndirectedEdge[112, 133] -> 
             RGBColor[
              0.34739581309764667`, 0.47009733583842483`, 0.9435479052443672],
              UndirectedEdge[71, 244] -> 
             RGBColor[
              0.7843526190175949, 0.8318290441883474, 0.9790430605166671], 
             UndirectedEdge[142, 197] -> 
             RGBColor[
              0.661041096245808, 0.7326542484129057, 0.9686951385111799], 
             UndirectedEdge[117, 196] -> 
             RGBColor[
              0.984135985384097, 0.9859607586943704, 0.834333592768455], 
             UndirectedEdge[131, 188] -> 
             RGBColor[
              0.6821337218912658, 0.7516073150405396, 0.9689523725622122], 
             UndirectedEdge[13, 282] -> 
             RGBColor[
              0.8883565176538993, 0.9137012132592173, 0.985254864465686], 
             UndirectedEdge[139, 143] -> 
             RGBColor[
              0.851452900515435, 0.8833049312368758, 0.9125315415797113], 
             UndirectedEdge[45, 89] -> 
             RGBColor[
              0.8546672008326004, 0.8860525326617035, 0.923578801177974], 
             UndirectedEdge[127, 269] -> 
             RGBColor[
              0.9798590486019381, 0.9844994919418821, 0.9189775565022026], 
             UndirectedEdge[25, 79] -> 
             RGBColor[
              0.9183809090122719, 0.9375098059273139, 0.983540638316428], 
             UndirectedEdge[29, 78] -> 
             RGBColor[
              0.8157717557201114, 0.8539446224935119, 0.8456666399700644], 
             UndirectedEdge[150, 179] -> 
             RGBColor[
              0.891288602756184, 0.9153748345501841, 0.9611457476700436], 
             UndirectedEdge[11, 198] -> 
             RGBColor[
              0.9789769457203994, 0.9814983597231516, 0.7982248803441261], 
             UndirectedEdge[135, 286] -> 
             RGBColor[
              0.9923303640932548, 0.9902494369861606, 0.715202325477539], 
             UndirectedEdge[101, 104] -> 
             RGBColor[
              0.9070142765826934, 0.9244757667026342, 0.7872922140328928], 
             UndirectedEdge[3, 290] -> 
             RGBColor[
              0.8036582339473166, 0.8469916530405781, 0.9561740740041369], 
             UndirectedEdge[158, 212] -> 
             RGBColor[
              0.8444910525510361, 0.6683394993886371, 0.5955080680451685], 
             UndirectedEdge[102, 175] -> 
             RGBColor[
              0.8313165718248081, 0.7919436617022927, 0.6218750714740514], 
             UndirectedEdge[103, 255] -> 
             RGBColor[
              0.8828449956552353, 0.5581206345586927, 0.5722766333216862], 
             UndirectedEdge[3, 65] -> 
             RGBColor[
              0.9370546134986522, 0.8282906850409748, 0.5971809014851119], 
             UndirectedEdge[148, 270] -> 
             RGBColor[
              0.7956909245493786, 0.8409263782770671, 0.9801095309534502], 
             UndirectedEdge[49, 298] -> 
             RGBColor[
              0.7039070495407338, 0.7674593644243908, 0.9720644042150256], 
             UndirectedEdge[15, 103] -> 
             RGBColor[
              0.9650436800560362, 0.9594949643904109, 0.6863527634815842], 
             UndirectedEdge[4, 15] -> 
             RGBColor[
              0.907008909500594, 0.9134680000093067, 0.6894290658658735], 
             UndirectedEdge[83, 290] -> 
             RGBColor[
              0.5274074712200413, 0.6260278386730055, 0.9562768249769804], 
             UndirectedEdge[182, 284] -> 
             RGBColor[
              0.9499317404875741, 0.9615997611433269, 0.9489718029722852], 
             UndirectedEdge[32, 92] -> 
             RGBColor[
              0.9901483675044025, 0.9775199208839618, 0.49363835957195], 
             UndirectedEdge[87, 203] -> 
             RGBColor[
              0.7824299976470344, 0.7006869873485464, 0.6052514279778982], 
             UndirectedEdge[115, 169] -> 
             RGBColor[
              0.9728626801844691, 0.9219995285741487, 0.5289879251025276], 
             UndirectedEdge[111, 143] -> 
             RGBColor[
              0.6583649544659018, 0.7324140706018605, 0.9670105733299521], 
             UndirectedEdge[163, 274] -> 
             RGBColor[
              0.6520681244108708, 0.7274893612815507, 0.966386777745774], 
             UndirectedEdge[96, 260] -> 
             RGBColor[
              0.8871835965523873, 0.9128801342064181, 0.9891015575089548], 
             UndirectedEdge[27, 227] -> 
             RGBColor[
              0.963454848104101, 0.9722652660700084, 0.9467455890443315], 
             UndirectedEdge[103, 205] -> 
             RGBColor[
              0.9439060754288962, 0.9576858234170182, 0.9798365620469681], 
             UndirectedEdge[27, 216] -> 
             RGBColor[
              0.8400908663891915, 0.8755806561497553, 0.9662620881336237], 
             UndirectedEdge[145, 293] -> 
             RGBColor[
              0.9373954875386625, 0.9526689922576992, 0.9852668108805758], 
             UndirectedEdge[96, 133] -> 
             RGBColor[
              0.6878261567442631, 0.7536142607364981, 0.9714511172263148], 
             UndirectedEdge[127, 159] -> 
             RGBColor[
              0.9143639147032963, 0.9334596993778097, 0.9537892418849516], 
             UndirectedEdge[186, 214] -> 
             RGBColor[
              0.9337519403222507, 0.9499531109891691, 0.9914853614491297], 
             UndirectedEdge[111, 262] -> 
             RGBColor[
              0.7190760084687797, 0.7799761984685389, 0.9730260736349656], 
             UndirectedEdge[33, 157] -> 
             RGBColor[
              0.9891008812831161, 0.9897609485630632, 0.8302901333612327], 
             UndirectedEdge[112, 131] -> 
             RGBColor[
              0.4527786433307087, 0.5557777891606881, 0.9518774094452831], 
             UndirectedEdge[37, 55] -> 
             RGBColor[
              0.9623466818481592, 0.8903545340346735, 0.5696927857243353], 
             UndirectedEdge[20, 71] -> 
             RGBColor[
              0.9210340470848438, 0.9388165814432049, 0.9557533148632515], 
             UndirectedEdge[37, 252] -> 
             RGBColor[
              0.9746202150301294, 0.9801789630704252, 0.9093319502440278], 
             UndirectedEdge[120, 178] -> 
             RGBColor[
              0.5187513283521088, 0.6197226766660828, 0.9553848162685663], 
             UndirectedEdge[113, 231] -> 
             RGBColor[
              0.9491327729341952, 0.9615838858585384, 0.9709891265115306], 
             UndirectedEdge[7, 181] -> 
             RGBColor[
              0.9891270954169955, 0.9897717887810948, 0.8298556973228484], 
             UndirectedEdge[42, 299] -> 
             RGBColor[
              0.8978876045529265, 0.7718028984440175, 0.6126216511881661], 
             UndirectedEdge[64, 234] -> 
             RGBColor[
              0.6607878832573362, 0.7307955969705681, 0.9694518055207293], 
             UndirectedEdge[78, 261] -> 
             RGBColor[
              0.9912945186872228, 0.9906599226211458, 0.7933433651716061], 
             UndirectedEdge[10, 100] -> 
             RGBColor[
              0.8163692663454785, 0.8571017882582388, 0.966561678130366], 
             UndirectedEdge[6, 88] -> 
             RGBColor[
              0.7571928112445604, 0.8104790727843099, 0.9763711922698646], 
             UndirectedEdge[36, 208] -> 
             RGBColor[
              0.34673250783862486`, 0.4711632064193436, 0.9434455772235896], 
             UndirectedEdge[92, 142] -> 
             RGBColor[
              0.9295574535210477, 0.9424143196494272, 0.7864621588788117], 
             UndirectedEdge[237, 293] -> 
             RGBColor[
              0.9489596388805264, 0.9612935173939013, 0.965691719072516], 
             UndirectedEdge[127, 145] -> 
             RGBColor[
              0.961720071809065, 0.970971472749606, 0.9496821128097062], 
             UndirectedEdge[90, 285] -> 
             RGBColor[
              0.8496837833145101, 0.8825848598651976, 0.9424217951976384], 
             UndirectedEdge[134, 176] -> 
             RGBColor[
              0.9829975058416234, 0.9854812553741443, 0.8528109693543608], 
             UndirectedEdge[28, 297] -> 
             RGBColor[
              0.7710883246767593, 0.8205412377966852, 0.9526344456436402], 
             UndirectedEdge[20, 136] -> 
             RGBColor[
              0.9075601297796747, 0.9280728455238052, 0.9544681606023766], 
             UndirectedEdge[113, 134] -> 
             RGBColor[
              0.9745977238566911, 0.9792167117231625, 0.8670296092408425], 
             UndirectedEdge[12, 181] -> 
             RGBColor[
              0.9203990902074957, 0.936775454481162, 0.8907564853226253], 
             UndirectedEdge[84, 217] -> 
             RGBColor[
              0.7086107219864941, 0.7710539243203924, 0.9726926218108334], 
             UndirectedEdge[126, 153] -> 
             RGBColor[
              0.8593575109225892, 0.8887852701298931, 0.881814088665151], 
             UndirectedEdge[217, 251] -> 
             RGBColor[
              0.8476512484502342, 0.8815209852320717, 0.9852877055487561], 
             UndirectedEdge[211, 266] -> 
             RGBColor[
              0.8270876256873223, 0.8657326825046534, 0.9806711960386946], 
             UndirectedEdge[156, 282] -> 
             RGBColor[
              0.5969848613093736, 0.6782522535142184, 0.9641343395395137], 
             UndirectedEdge[92, 256] -> 
             RGBColor[
              0.6231261989179384, 0.6860073454739598, 0.7618018103611788], 
             UndirectedEdge[56, 246] -> 
             RGBColor[
              0.9882473937640559, 0.9888162851980271, 0.8145913156781337], 
             UndirectedEdge[223, 246] -> 
             RGBColor[
              0.9205725516510928, 0.7209245364339678, 0.5605856853526402], 
             UndirectedEdge[66, 228] -> 
             RGBColor[
              0.9084848998274209, 0.9282973405846329, 0.9339961802724353], 
             UndirectedEdge[170, 261] -> 
             RGBColor[
              0.9141956185560689, 0.9325686238101201, 0.9222829161318876], 
             UndirectedEdge[104, 287] -> 
             RGBColor[
              0.9384803599163695, 0.9495659674288288, 0.790293477151363], 
             UndirectedEdge[255, 258] -> 
             RGBColor[
              0.9032673291187775, 0.5730219951460489, 0.5229475822828523], 
             UndirectedEdge[27, 162] -> 
             RGBColor[
              0.9618658085973149, 0.9710801630076606, 0.9494354184414412], 
             UndirectedEdge[162, 169] -> 
             RGBColor[
              0.9605634344742602, 0.9141803035694122, 0.61042128210344], 
             UndirectedEdge[90, 166] -> 
             RGBColor[
              0.9336063404859865, 0.9486596074491391, 0.950650062527592], 
             UndirectedEdge[74, 257] -> 
             RGBColor[
              0.9362084396002064, 0.9475598947600603, 0.7743095673194473], 
             UndirectedEdge[82, 203] -> 
             RGBColor[
              0.6869253095441086, 0.6233907027428351, 0.5975697324332827], 
             UndirectedEdge[1, 142] -> 
             RGBColor[
              0.9233503234478995, 0.9405357739865245, 0.9515453010635355], 
             UndirectedEdge[82, 145] -> 
             RGBColor[
              0.7061391451728661, 0.7684377422803078, 0.9642894422509412], 
             UndirectedEdge[77, 203] -> 
             RGBColor[
              0.8966446236786003, 0.7904489110156419, 0.6164928800838834], 
             UndirectedEdge[12, 27] -> 
             RGBColor[
              0.9028094055283609, 0.9248164555690491, 0.9724497035131984], 
             UndirectedEdge[54, 185] -> 
             RGBColor[
              0.9593104759239107, 0.960789323492167, 0.7026816760384307], 
             UndirectedEdge[35, 165] -> 
             RGBColor[
              0.9239178533027708, 0.9097006249002575, 0.6656646881901299], 
             UndirectedEdge[60, 95] -> 
             RGBColor[
              0.6493403729174342, 0.7199051075842022, 0.9648576744155866], 
             UndirectedEdge[47, 112] -> 
             RGBColor[
              0.5708590356286667, 0.6485845061175413, 0.9634975766026032], 
             UndirectedEdge[24, 59] -> 
             RGBColor[
              0.9214359194824377, 0.9376616300447209, 0.8934362972487783], 
             UndirectedEdge[239, 285] -> 
             RGBColor[
              0.6543618684467183, 0.7291558512681215, 0.9667011335763342], 
             UndirectedEdge[173, 286] -> 
             RGBColor[
              0.9583336197924202, 0.9655757428508704, 0.8067237563337224], 
             UndirectedEdge[17, 40] -> 
             RGBColor[
              0.8050839479671197, 0.848547237727503, 0.9786803262314505], 
             UndirectedEdge[226, 241] -> 
             RGBColor[
              0.8224206619143863, 0.8601649186939584, 0.8887882733701116], 
             UndirectedEdge[255, 286] -> 
             RGBColor[
              0.9073295260517711, 0.5738548322587238, 0.3940595463883825], 
             UndirectedEdge[95, 271] -> 
             RGBColor[
              0.9657596802661255, 0.9683087523080999, 0.7027172020849318], 
             UndirectedEdge[189, 260] -> 
             RGBColor[
              0.8330340257780278, 0.8697027363218861, 0.9839367231086038], 
             UndirectedEdge[193, 245] -> 
             RGBColor[
              0.901902444799157, 0.9220150456204818, 0.8857530214353493], 
             UndirectedEdge[84, 223] -> 
             RGBColor[
              0.690772712113177, 0.5394285929758182, 0.5801069421841218], 
             UndirectedEdge[44, 61] -> 
             RGBColor[
              0.940270170293922, 0.9532065709323028, 0.9181177760039951], 
             UndirectedEdge[262, 292] -> 
             RGBColor[
              0.8866694551085426, 0.9124430047752016, 0.9881106212985931], 
             UndirectedEdge[153, 248] -> 
             RGBColor[
              0.8588081170367687, 0.8885580816393275, 0.8909189671389963], 
             UndirectedEdge[78, 99] -> 
             RGBColor[
              0.9901026829902839, 0.9901670679316812, 0.8130951670417959], 
             UndirectedEdge[199, 261] -> 
             RGBColor[
              0.938642549521163, 0.9520619429674229, 0.9246146862313712], 
             UndirectedEdge[58, 215] -> 
             RGBColor[
              0.8608183404332139, 0.6778571860130275, 0.5963741412758601], 
             UndirectedEdge[23, 197] -> 
             RGBColor[
              0.3634809667512553, 0.48557138918834936`, 0.9445399874448259], 
             UndirectedEdge[196, 214] -> 
             RGBColor[
              0.9620495018645667, 0.9693289203576192, 0.8661807455787388], 
             UndirectedEdge[88, 289] -> 
             RGBColor[
              0.8773301569927969, 0.9050232689660924, 0.9881617276474917], 
             UndirectedEdge[47, 96] -> 
             RGBColor[
              0.9112893792752832, 0.9321014310156144, 0.9914007885845508], 
             UndirectedEdge[179, 205] -> 
             RGBColor[
              0.8788322093738281, 0.9060848767610953, 0.9822311725186623], 
             UndirectedEdge[72, 194] -> 
             RGBColor[
              0.9090161044609696, 0.9286713134477386, 0.9318932482123787], 
             UndirectedEdge[140, 299] -> 
             RGBColor[
              0.7005956357093063, 0.7645158427964364, 0.9720974097822663], 
             UndirectedEdge[134, 297] -> 
             RGBColor[
              0.9783237778409831, 0.9819955966837941, 0.860722371755956], 
             UndirectedEdge[67, 195] -> 
             RGBColor[
              0.9445437635371723, 0.9572415378392441, 0.9457657805711791], 
             UndirectedEdge[24, 155] -> 
             RGBColor[
              0.8843014042277312, 0.7959276414764652, 0.6187463309639666], 
             UndirectedEdge[156, 277] -> 
             RGBColor[
              0.5206871676452087, 0.6185137242812935, 0.9565653086584921], 
             UndirectedEdge[267, 272] -> 
             RGBColor[
              0.9008476567256517, 0.5609671091743769, 0.5364032245619899], 
             UndirectedEdge[71, 177] -> 
             RGBColor[
              0.9286549479850845, 0.9432276582102259, 0.8858644456766198], 
             UndirectedEdge[188, 281] -> 
             RGBColor[
              0.4868176405856818, 0.5837693810104887, 0.9550484471913078], 
             UndirectedEdge[1, 150] -> 
             RGBColor[
              0.9744787918836271, 0.9804869052907277, 0.9280849277306124], 
             UndirectedEdge[84, 246] -> 
             RGBColor[
              0.7515518739452078, 0.8041167755081066, 0.9359721210391881], 
             UndirectedEdge[58, 230] -> 
             RGBColor[
              0.8348232439524641, 0.871213173182628, 0.984085152248963], 
             UndirectedEdge[74, 189] -> 
             RGBColor[
              0.8517549489091858, 0.8846302922607505, 0.9857223414692191], 
             UndirectedEdge[48, 71] -> 
             RGBColor[
              0.800525313587606, 0.8444632761034714, 0.9806550035689823], 
             UndirectedEdge[80, 205] -> 
             RGBColor[
              0.8836268694567507, 0.9098692071582114, 0.982698788177581], 
             UndirectedEdge[1, 32] -> 
             RGBColor[
              0.9839412374312544, 0.9756413752210591, 0.6587215017566739], 
             UndirectedEdge[229, 233] -> 
             RGBColor[
              0.8196674199414744, 0.859215120243692, 0.9434427589339842], 
             UndirectedEdge[54, 172] -> 
             RGBColor[
              0.9586223041659605, 0.967911686034282, 0.9229782807479756], 
             UndirectedEdge[61, 194] -> 
             RGBColor[
              0.9871093701136104, 0.9889374075149701, 0.8632946273056378], 
             UndirectedEdge[177, 194] -> 
             RGBColor[
              0.9889779517272443, 0.9897101140325647, 0.8323273942335218], 
             UndirectedEdge[7, 42] -> 
             RGBColor[
              0.9415477040720215, 0.8048107651965946, 0.5493298639652548], 
             UndirectedEdge[26, 75] -> 
             RGBColor[
              0.9241695153221261, 0.9419471214519075, 0.9779088375753839], 
             UndirectedEdge[170, 190] -> 
             RGBColor[
              0.7705035674088911, 0.8208129786825165, 0.977715015751912], 
             UndirectedEdge[20, 36] -> 
             RGBColor[
              0.623313323172405, 0.6916056685890454, 0.9315828461579552], 
             UndirectedEdge[119, 161] -> 
             RGBColor[
              0.9325665817772228, 0.9489772353278518, 0.9903078109245527], 
             UndirectedEdge[212, 225] -> 
             RGBColor[
              0.906807642820379, 0.9265244598410106, 0.9149260902612175], 
             UndirectedEdge[102, 253] -> 
             RGBColor[
              0.8553781502348461, 0.8862541647369779, 0.9076083640592874], 
             UndirectedEdge[91, 179] -> 
             RGBColor[
              0.9051687784909245, 0.9239054355116104, 0.8560926643624325], 
             UndirectedEdge[118, 239] -> 
             RGBColor[
              0.7938222544633633, 0.8356980772793847, 0.8089458410250971], 
             UndirectedEdge[105, 298] -> 
             RGBColor[
              0.601733272092513, 0.6872806218128389, 0.9619761597551695], 
             UndirectedEdge[90, 239] -> 
             RGBColor[
              0.7883373299908141, 0.8339046634907787, 0.9368241538682813], 
             UndirectedEdge[208, 252] -> 
             RGBColor[
              0.6930042163962558, 0.7563946848112745, 0.9482315182392114], 
             UndirectedEdge[117, 214] -> 
             RGBColor[
              0.9515895877709262, 0.9632563992499241, 0.961290877122073], 
             UndirectedEdge[179, 282] -> 
             RGBColor[
              0.8258849060171876, 0.8640410236877039, 0.9832445369837544], 
             UndirectedEdge[44, 268] -> 
             RGBColor[
              0.9234851096918111, 0.9413400002742294, 0.9757149653658759], 
             UndirectedEdge[53, 124] -> 
             RGBColor[
              0.9013430357670338, 0.7123711843372986, 0.5969906060157175], 
             UndirectedEdge[42, 81] -> 
             RGBColor[
              0.9366864859118083, 0.7779957467586498, 0.3007477860437583], 
             UndirectedEdge[173, 213] -> 
             RGBColor[
              0.8064982574865257, 0.8495893594470736, 0.9811282677936992], 
             UndirectedEdge[119, 122] -> 
             RGBColor[
              0.9658901300704383, 0.9703631354046102, 0.7112692505414512], 
             UndirectedEdge[68, 111] -> 
             RGBColor[
              0.43579110727749604`, 0.5442760188022596, 0.9502325065878241], 
             UndirectedEdge[34, 53] -> 
             RGBColor[
              0.9638705279240237, 0.9719594579427271, 0.9184642085227921], 
             UndirectedEdge[85, 263] -> 
             RGBColor[
              0.9787551412390129, 0.9804062033457375, 0.7250678823361887], 
             UndirectedEdge[37, 208] -> 
             RGBColor[
              0.7050644117375899, 0.764975743378679, 0.9093031683404239], 
             UndirectedEdge[256, 293] -> 
             RGBColor[
              0.5908602204190763, 0.6645329079517159, 0.9654053074631809], 
             UndirectedEdge[76, 153] -> 
             RGBColor[
              0.85746246493079, 0.8880016199118235, 0.9132199049710811], 
             UndirectedEdge[135, 213] -> 
             RGBColor[
              0.8404950017873605, 0.8742630535823639, 0.8896068369375159], 
             UndirectedEdge[36, 55] -> 
             RGBColor[
              0.6040147779491942, 0.596541997075338, 0.603835194607501], 
             UndirectedEdge[121, 135] -> 
             RGBColor[
              0.8905896536863451, 0.9133973763793064, 0.8945998036776686], 
             UndirectedEdge[83, 226] -> 
             RGBColor[
              0.7004683145651001, 0.7601886646924135, 0.8793793221784707], 
             UndirectedEdge[60, 127] -> 
             RGBColor[
              0.6681577147460327, 0.7339390503094017, 0.9330048230485369], 
             UndirectedEdge[247, 271] -> 
             RGBColor[
              0.9726416869125785, 0.9734413415967729, 0.6910677599472885], 
             UndirectedEdge[202, 269] -> 
             RGBColor[
              0.8857149038366161, 0.9107686988322905, 0.9478380764243954], 
             UndirectedEdge[190, 284] -> 
             RGBColor[
              0.8422277235666655, 0.8766898341183555, 0.9384414012740137], 
             UndirectedEdge[53, 217] -> 
             RGBColor[
              0.917655870924768, 0.9370710535120158, 0.9883036424742933], 
             UndirectedEdge[42, 87] -> 
             RGBColor[
              0.7769771785967998, 0.6767019256697244, 0.6007415477079653], 
             UndirectedEdge[205, 225] -> 
             RGBColor[
              0.965297847006936, 0.9729880715781425, 0.914441412625489], 
             UndirectedEdge[110, 246] -> 
             RGBColor[
              0.9308838805374183, 0.7677458726347249, 0.5691897109291898], 
             UndirectedEdge[191, 251] -> 
             RGBColor[
              0.893825730184115, 0.9070628035562244, 0.6939303270995352], 
             UndirectedEdge[23, 83] -> 
             RGBColor[
              0.34035530703202255`, 0.465639595608097, 0.9430392276273302], 
             UndirectedEdge[226, 291] -> 
             RGBColor[
              0.9084185727596535, 0.9274005706905002, 0.8973455626321494], 
             UndirectedEdge[60, 276] -> 
             RGBColor[
              0.6114302226422069, 0.6897993706646252, 0.9654989028438372], 
             UndirectedEdge[27, 155] -> 
             RGBColor[
              0.9362913169979199, 0.8368597121273013, 0.6055629176507211], 
             UndirectedEdge[167, 203] -> 
             RGBColor[
              0.7957551535858398, 0.7110967004428773, 0.6065795549912163], 
             UndirectedEdge[137, 271] -> 
             RGBColor[
              0.9926107893729366, 0.9857122286767099, 0.5128997880919816], 
             UndirectedEdge[52, 247] -> 
             RGBColor[
              0.9439853565602212, 0.9576945919235755, 0.9779563736065173], 
             UndirectedEdge[81, 299] -> 
             RGBColor[
              0.9385625132271265, 0.9291039612059533, 0.6784275873633034], 
             UndirectedEdge[31, 290] -> 
             RGBColor[
              0.8113650464739486, 0.8307086279205155, 0.6682823379027596], 
             UndirectedEdge[79, 288] -> 
             RGBColor[
              0.5352208745727863, 0.6108638388591094, 0.9615078333548792], 
             UndirectedEdge[237, 281] -> 
             RGBColor[
              0.6155619804865747, 0.6847004645728227, 0.9382598956837137], 
             UndirectedEdge[43, 215] -> 
             RGBColor[
              0.8807750459395594, 0.6937701212734473, 0.5982776296626166], 
             UndirectedEdge[56, 295] -> 
             RGBColor[
              0.8265429270004897, 0.8623645093862664, 0.8396365063479354], 
             UndirectedEdge[89, 94] -> 
             RGBColor[
              0.9905158248757835, 0.9897378187360109, 0.7626278392022167], 
             UndirectedEdge[92, 237] -> 
             RGBColor[
              0.9812256173793885, 0.9827679549161452, 0.7620882219705141], 
             UndirectedEdge[126, 285] -> 
             RGBColor[
              0.8536145975457046, 0.8842988625521124, 0.8812416887303199], 
             UndirectedEdge[4, 214] -> 
             RGBColor[
              0.8793823511644608, 0.9066596328932504, 0.9883574677596003], 
             UndirectedEdge[220, 222] -> 
             RGBColor[
              0.7881080034511592, 0.7912792734597047, 0.6358593192812512], 
             UndirectedEdge[199, 209] -> 
             RGBColor[
              0.9418923931963994, 0.9521412880261826, 0.7788370163852641], 
             UndirectedEdge[290, 291] -> 
             RGBColor[
              0.7353577294145947, 0.7932397446710922, 0.9742430654306591], 
             UndirectedEdge[91, 150] -> 
             RGBColor[
              0.9812739741688342, 0.9837335297381042, 0.8350248902708222], 
             UndirectedEdge[60, 148] -> 
             RGBColor[
              0.5272399506788161, 0.6236683503084968, 0.9572033857230409], 
             UndirectedEdge[81, 140] -> 
             RGBColor[
              0.7393945170681879, 0.7707086911110687, 0.6602235446378586], 
             UndirectedEdge[142, 256] -> 
             RGBColor[
              0.5587056069595295, 0.6388936919928041, 0.9623383717266469], 
             UndirectedEdge[30, 123] -> 
             RGBColor[
              0.8983084716258894, 0.9207162868150225, 0.9542951725223392], 
             UndirectedEdge[53, 289] -> 
             RGBColor[
              0.9227203217797622, 0.9411093091529319, 0.9887866943179313], 
             UndirectedEdge[274, 289] -> 
             RGBColor[
              0.8042665330669172, 0.8477103839803176, 0.9809417972849596], 
             UndirectedEdge[11, 114] -> 
             RGBColor[
              0.9589852012249005, 0.9689318107458759, 0.9543115353402101], 
             UndirectedEdge[137, 247] -> 
             RGBColor[
              0.9741936891186045, 0.9776522392767932, 0.7842020421791143], 
             UndirectedEdge[84, 191] -> 
             RGBColor[
              0.7547852037203749, 0.7965957426445451, 0.6813352433616123], 
             UndirectedEdge[17, 120] -> 
             RGBColor[
              0.5541139020964676, 0.6479786685409908, 0.958478364175939], 
             UndirectedEdge[126, 222] -> 
             RGBColor[
              0.8025966974020313, 0.8440038509452545, 0.8764571489420312], 
             UndirectedEdge[184, 224] -> 
             RGBColor[
              0.47796262211565227`, 0.5867596697120491, 0.952132029889782], 
             UndirectedEdge[278, 295] -> 
             RGBColor[
              0.8260497497149164, 0.8613096530402977, 0.7859572023506911], 
             UndirectedEdge[28, 245] -> 
             RGBColor[
              0.7847287622956018, 0.8294906519423555, 0.8747493498695267], 
             UndirectedEdge[14, 186] -> 
             RGBColor[
              0.9653514717728496, 0.9700403297328375, 0.7184434042042618], 
             UndirectedEdge[227, 241] -> 
             RGBColor[
              0.8127587059139996, 0.8539642751493264, 0.9501595823250395], 
             UndirectedEdge[121, 154] -> 
             RGBColor[
              0.8891593702366654, 0.9128059174162557, 0.918303301893777], 
             UndirectedEdge[187, 230] -> 
             RGBColor[
              0.7636098568121676, 0.8152570908823082, 0.9770731522533573], 
             UndirectedEdge[125, 277] -> 
             RGBColor[
              0.8391452986591565, 0.8716369754409337, 0.7950300512773439], 
             UndirectedEdge[62, 158] -> 
             RGBColor[
              0.9280784736704906, 0.7298625263079312, 0.3259717949183546], 
             UndirectedEdge[20, 61] -> 
             RGBColor[
              0.9823623630578833, 0.9857147597083583, 0.885555638089823], 
             UndirectedEdge[64, 258] -> 
             RGBColor[
              0.9509238590093222, 0.9620736491913224, 0.9352924985997637], 
             UndirectedEdge[94, 294] -> 
             RGBColor[
              0.9826944167533507, 0.9842805435774553, 0.7927018286175205], 
             UndirectedEdge[125, 237] -> 
             RGBColor[
              0.9813863844849313, 0.9831118194988535, 0.7795867292692804], 
             UndirectedEdge[267, 300] -> 
             RGBColor[
              0.9846881547018995, 0.9879361727198297, 0.903420432582315], 
             UndirectedEdge[165, 175] -> 
             RGBColor[
              0.9083645034459356, 0.8525906721948107, 0.6294333267585758], 
             UndirectedEdge[67, 263] -> 
             RGBColor[
              0.9342595836419214, 0.9496802816686362, 0.9680406056153796], 
             UndirectedEdge[163, 298] -> 
             RGBColor[
              0.5722574956356894, 0.6636234407202699, 0.9594693527861697], 
             UndirectedEdge[92, 149] -> 
             RGBColor[
              0.9309869796697527, 0.9435541849969512, 0.7865985083590282], 
             UndirectedEdge[95, 276] -> 
             RGBColor[
              0.9025504230901131, 0.925010436699933, 0.9863101267379584], 
             UndirectedEdge[70, 231] -> 
             RGBColor[
              0.8739376025926932, 0.9022795772188636, 0.982674955398639], 
             UndirectedEdge[239, 263] -> 
             RGBColor[
              0.7786465733979822, 0.8266773130910023, 0.953228077025834], 
             UndirectedEdge[116, 204] -> 
             RGBColor[
              0.9903568413810917, 0.9885073457365551, 0.6805990869979657], 
             UndirectedEdge[121, 258] -> 
             RGBColor[
              0.8884972926415786, 0.9125321313160693, 0.9292756410462575], 
             UndirectedEdge[95, 148] -> 
             RGBColor[
              0.8183601511267223, 0.8588794163438047, 0.978014609617162], 
             UndirectedEdge[60, 77] -> 
             RGBColor[
              0.6222961022443256, 0.6984635281129101, 0.9665353001403726], 
             UndirectedEdge[42, 269] -> 
             RGBColor[
              0.9388172087094733, 0.8032548044052847, 0.5754668836487088], 
             UndirectedEdge[61, 136] -> 
             RGBColor[
              0.9133124490662816, 0.9317112157732315, 0.9155465244878609], 
             UndirectedEdge[95, 251] -> 
             RGBColor[
              0.8701468303500564, 0.8993355637464128, 0.9831762218281116], 
             UndirectedEdge[158, 265] -> 
             RGBColor[
              0.9219064098726482, 0.7289174593467987, 0.5629880426222515], 
             UndirectedEdge[152, 208] -> 
             RGBColor[
              0.6859024342069432, 0.7510981872825861, 0.9602529830442743], 
             UndirectedEdge[153, 285] -> 
             RGBColor[
              0.721451235147299, 0.782322455220321, 0.9728711748405223], 
             UndirectedEdge[61, 279] -> 
             RGBColor[
              0.8275671333218324, 0.8645765829198413, 0.9070399692759931], 
             UndirectedEdge[82, 168] -> 
             RGBColor[
              0.7230846606884757, 0.7810756800061143, 0.9356051045812914], 
             UndirectedEdge[4, 249] -> 
             RGBColor[
              0.8848371409332672, 0.9108875812626108, 0.9846634342288398], 
             UndirectedEdge[75, 163] -> 
             RGBColor[
              0.7766826192298522, 0.8254829309808911, 0.9638032063105479], 
             UndirectedEdge[59, 290] -> 
             RGBColor[
              0.8174908024427685, 0.8562000509493004, 0.8831447138584918], 
             UndirectedEdge[205, 251] -> 
             RGBColor[
              0.8711570495020772, 0.9000889835359078, 0.9814661843110931], 
             UndirectedEdge[183, 224] -> 
             RGBColor[
              0.7134376222251027, 0.7726064348985887, 0.9237389115157837], 
             UndirectedEdge[170, 178] -> 
             RGBColor[
              0.7211381224336328, 0.7816178373762668, 0.9732257925045148], 
             UndirectedEdge[102, 238] -> 
             RGBColor[
              0.8146472482276297, 0.7258553483622807, 0.6084625424284478], 
             UndirectedEdge[89, 236] -> 
             RGBColor[
              0.8747075673090934, 0.9017082192655662, 0.9255762376204784], 
             UndirectedEdge[65, 231] -> 
             RGBColor[
              0.9261775860533334, 0.8201786157817539, 0.6155928717669346], 
             UndirectedEdge[25, 245] -> 
             RGBColor[
              0.9684020579496027, 0.9747312851761754, 0.883575860333556], 
             UndirectedEdge[217, 223] -> 
             RGBColor[
              0.877631399692379, 0.6878616852462537, 0.5973061861242853], 
             UndirectedEdge[254, 283] -> 
             RGBColor[
              0.977869778825216, 0.9830158977995332, 0.9223448713495415], 
             UndirectedEdge[168, 205] -> 
             RGBColor[
              0.9608584646480969, 0.9703288875397083, 0.9511405889900877], 
             UndirectedEdge[142, 243] -> 
             RGBColor[
              0.8564427710869092, 0.8883682344177241, 0.9861694701333985], 
             UndirectedEdge[57, 278] -> 
             RGBColor[
              0.9802398668706249, 0.9439859497544286, 0.4645224291292105], 
             UndirectedEdge[185, 218] -> 
             RGBColor[
              0.8046249458395033, 0.8387221209722235, 0.6877317673773315], 
             UndirectedEdge[16, 248] -> 
             RGBColor[
              0.9564793050122362, 0.9656884498914466, 0.9004339554183978], 
             UndirectedEdge[184, 275] -> 
             RGBColor[
              0.7536347546096847, 0.8021307186786718, 0.7286304134179281], 
             UndirectedEdge[127, 191] -> 
             RGBColor[
              0.9829568150279977, 0.9768773561545211, 0.6645701522140817], 
             UndirectedEdge[33, 153] -> 
             RGBColor[
              0.8591550294468362, 0.8887015388361326, 0.8851697307236392], 
             UndirectedEdge[83, 243] -> 
             RGBColor[
              0.6292213460508457, 0.7057900230821058, 0.966365128582803], 
             UndirectedEdge[94, 281] -> 
             RGBColor[
              0.6286138561043254, 0.6921009707487953, 0.7946902855504219], 
             UndirectedEdge[140, 293] -> 
             RGBColor[
              0.7154368640160501, 0.7763498353938234, 0.9735129793870845], 
             UndirectedEdge[126, 220] -> 
             RGBColor[
              0.9770321793701227, 0.9380370999761347, 0.5495867728941686], 
             UndirectedEdge[76, 220] -> 
             RGBColor[
              0.9751371333783234, 0.9372534497580652, 0.5809925892000987], 
             UndirectedEdge[90, 126] -> 
             RGBColor[
              0.9875900590898004, 0.9890476747747696, 0.8513647090222671], 
             UndirectedEdge[35, 102] -> 
             RGBColor[
              0.8468699216816433, 0.8490536144077394, 0.6581064329056054], 
             UndirectedEdge[105, 235] -> 
             RGBColor[
              0.8219172309570028, 0.8455257835863139, 0.6789336762661377], 
             UndirectedEdge[21, 287] -> 
             RGBColor[
              0.934957997019547, 0.9491870002032223, 0.9269997696464323], 
             UndirectedEdge[160, 245] -> 
             RGBColor[
              0.9931678718081394, 0.9910085605633302, 0.7313283206259966], 
             UndirectedEdge[235, 298] -> 
             RGBColor[
              0.7634974561722768, 0.7983705607388885, 0.6741482917234063], 
             UndirectedEdge[15, 196] -> 
             RGBColor[
              0.9896760602006999, 0.9761372874736756, 0.5672523436850119], 
             UndirectedEdge[13, 274] -> 
             RGBColor[
              0.821530692604924, 0.8613621797773461, 0.9786299009285819], 
             UndirectedEdge[2, 172] -> 
             RGBColor[
              0.9913710591670322, 0.9904569777480872, 0.7750222147864274], 
             UndirectedEdge[247, 295] -> 
             RGBColor[
              0.8060836833071189, 0.8490452597697955, 0.9644556297908653], 
             UndirectedEdge[159, 225] -> 
             RGBColor[
              0.9193736273642725, 0.9365442348217475, 0.9161246450848011], 
             UndirectedEdge[204, 254] -> 
             RGBColor[
              0.9820484523230892, 0.9855849495523831, 0.8907579513402997], 
             UndirectedEdge[61, 252] -> 
             RGBColor[
              0.9753373510166428, 0.9804755172304026, 0.8974471510590613], 
             UndirectedEdge[4, 173] -> 
             RGBColor[
              0.8758143188404421, 0.9038145807697352, 0.9880171456513154], 
             UndirectedEdge[230, 245] -> 
             RGBColor[
              0.9005888636358146, 0.9209888660320921, 0.8856220959411012], 
             UndirectedEdge[137, 295] -> 
             RGBColor[
              0.826052785767477, 0.8613161468497326, 0.7862876579355584], 
             UndirectedEdge[109, 192] -> 
             RGBColor[
              0.6871518493680915, 0.7555275143646171, 0.9694525326120349], 
             UndirectedEdge[178, 229] -> 
             RGBColor[
              0.7901916434846508, 0.835557939151123, 0.9409359519649846], 
             UndirectedEdge[91, 93] -> 
             RGBColor[
              0.9839500241631438, 0.9857293234422306, 0.8304950356560759], 
             UndirectedEdge[143, 185] -> 
             RGBColor[
              0.8521410722733852, 0.8761825686947606, 0.6922349368701662], 
             UndirectedEdge[139, 273] -> 
             RGBColor[
              0.9868221998882026, 0.9888186552468257, 0.8680537811133663], 
             UndirectedEdge[130, 281] -> 
             RGBColor[
              0.6138906546061436, 0.6834539924677423, 0.9410890144476811], 
             UndirectedEdge[220, 248] -> 
             RGBColor[
              0.9764827854843021, 0.9378099114855691, 0.5586916513680139], 
             UndirectedEdge[88, 273] -> 
             RGBColor[
              0.9174824492028948, 0.9354607546988926, 0.9343772582599243], 
             UndirectedEdge[24, 218] -> 
             RGBColor[
              0.7360716045557452, 0.7936623739565515, 0.9744924961008017], 
             UndirectedEdge[66, 215] -> 
             RGBColor[
              0.8463675133277666, 0.6663344887363959, 0.5949958084861369], 
             UndirectedEdge[151, 154] -> 
             RGBColor[
              0.9799785516435742, 0.9840390445572381, 0.8941642870599213], 
             UndirectedEdge[8, 64] -> 
             RGBColor[
              0.8343741862834216, 0.8713121326633703, 0.9839210401121954], 
             UndirectedEdge[71, 108] -> 
             RGBColor[
              0.8140053172820989, 0.8549939574414318, 0.9819985643594527], 
             UndirectedEdge[43, 182] -> 
             RGBColor[
              0.907639818211075, 0.9291913700877108, 0.991052690192245], 
             UndirectedEdge[58, 297] -> 
             RGBColor[
              0.9121509897180413, 0.9320515292208074, 0.9659332628259896], 
             UndirectedEdge[46, 207] -> 
             RGBColor[
              0.7096722537698764, 0.7717166405288776, 0.9730053304950421], 
             UndirectedEdge[100, 266] -> 
             RGBColor[
              0.6977141642681775, 0.7637788750411307, 0.9705052854508307], 
             UndirectedEdge[12, 151] -> 
             RGBColor[
              0.9110424812344575, 0.9309566699502319, 0.9585132538728244], 
             UndirectedEdge[196, 265] -> 
             RGBColor[
              0.9874636087086148, 0.9884424947213126, 0.8287007944632075], 
             UndirectedEdge[93, 139] -> 
             RGBColor[
              0.9802437012516191, 0.9841966636701609, 0.8919183979562676], 
             UndirectedEdge[30, 104] -> 
             RGBColor[
              0.9074166311579289, 0.924796593319303, 0.787330590971465], 
             UndirectedEdge[85, 121] -> 
             RGBColor[
              0.892025664986373, 0.9122231716125313, 0.7422840931098019], 
             UndirectedEdge[79, 160] -> 
             RGBColor[
              0.9431467228708085, 0.9537870813144688, 0.8312930986088686], 
             UndirectedEdge[60, 196] -> 
             RGBColor[
              0.6764080359736329, 0.7383636606754799, 0.8416349558732932], 
             UndirectedEdge[25, 297] -> 
             RGBColor[
              0.9547616203307601, 0.9657818710305048, 0.9614609561076695], 
             UndirectedEdge[9, 133] -> 
             RGBColor[
              0.4743189967085315, 0.5838192901742484, 0.9518403053938251], 
             UndirectedEdge[151, 192] -> 
             RGBColor[
              0.8449863612124824, 0.879113526978736, 0.9519929796223183], 
             UndirectedEdge[45, 141] -> 
             RGBColor[
              0.8468457927101676, 0.880595257503148, 0.9536527905932778], 
             UndirectedEdge[177, 280] -> 
             RGBColor[
              0.9906708091609205, 0.9904101540858414, 0.8042723655829047], 
             UndirectedEdge[141, 188] -> 
             RGBColor[
              0.840898201234707, 0.875948953839149, 0.9530599902584063], 
             UndirectedEdge[129, 183] -> 
             RGBColor[
              0.9879407326146518, 0.9844706877572392, 0.6585714069638398], 
             UndirectedEdge[41, 55] -> 
             RGBColor[
              0.9660775635394123, 0.8909140366726847, 0.4363859592076105], 
             UndirectedEdge[120, 261] -> 
             RGBColor[
              0.7118088244745449, 0.7706734630999361, 0.9044419398959391], 
             UndirectedEdge[71, 279] -> 
             RGBColor[
              0.7662388173487931, 0.8176784046546879, 0.9772376460494216], 
             UndirectedEdge[180, 230] -> 
             RGBColor[
              0.667791147080846, 0.7386197270890671, 0.9687419262637662], 
             UndirectedEdge[106, 194] -> 
             RGBColor[
              0.9193781858396431, 0.9369337558678867, 0.9328815927846159], 
             UndirectedEdge[90, 234] -> 
             RGBColor[
              0.6947815497350643, 0.7566644612282974, 0.9298148140360571], 
             UndirectedEdge[44, 136] -> 
             RGBColor[
              0.8654679370157135, 0.8955646567477497, 0.9870302985165487], 
             UndirectedEdge[120, 131] -> 
             RGBColor[
              0.5447920485228116, 0.6406963656805396, 0.9575492489293915], 
             UndirectedEdge[44, 279] -> 
             RGBColor[
              0.7797226212712645, 0.8284300238943594, 0.978523743304681], 
             UndirectedEdge[105, 139] -> 
             RGBColor[
              0.8239472754788821, 0.8618173279078277, 0.9097900379307478], 
             UndirectedEdge[157, 184] -> 
             RGBColor[
              0.7505724763878159, 0.802651522028651, 0.9092860709950465], 
             UndirectedEdge[83, 149] -> 
             RGBColor[
              0.6393449626752804, 0.7138623201801773, 0.9673307281739008], 
             UndirectedEdge[145, 168] -> 
             RGBColor[
              0.9622904021112021, 0.9713968241551096, 0.9487166923741542], 
             UndirectedEdge[112, 170] -> 
             RGBColor[
              0.5466745516300471, 0.629300455047372, 0.9611908389290711], 
             UndirectedEdge[159, 270] -> 
             RGBColor[
              0.872877346297354, 0.9014727185858726, 0.9877370145882893], 
             UndirectedEdge[86, 162] -> 
             RGBColor[
              0.7123452568337905, 0.7727365610946839, 0.9449413996849669], 
             UndirectedEdge[3, 264] -> 
             RGBColor[
              0.9715056035956917, 0.9782695063337346, 0.9331177599703884], 
             UndirectedEdge[60, 282] -> 
             RGBColor[
              0.5974032887128143, 0.678614674300306, 0.9641610013636601], 
             UndirectedEdge[135, 186] -> 
             RGBColor[
              0.9641806522990668, 0.9717817530009442, 0.8996236084846614], 
             UndirectedEdge[89, 294] -> 
             RGBColor[
              0.9786333011143125, 0.9832094132598138, 0.9042180416586361], 
             UndirectedEdge[201, 203] -> 
             RGBColor[
              0.8657847344171294, 0.7658420729879237, 0.6135494362971758], 
             UndirectedEdge[181, 203] -> 
             RGBColor[
              0.9490437876328168, 0.8296407692600363, 0.5199775634961475], 
             UndirectedEdge[70, 211] -> 
             RGBColor[
              0.8724503263675958, 0.9011703690453773, 0.9851925261039645], 
             UndirectedEdge[156, 159] -> 
             RGBColor[
              0.6040079450233508, 0.6838522698312148, 0.9648042075337336], 
             UndirectedEdge[56, 270] -> 
             RGBColor[
              0.9451325971278205, 0.9556149744579165, 0.8512952540654225], 
             UndirectedEdge[113, 264] -> 
             RGBColor[
              0.968319867030143, 0.9758935892193132, 0.9385103810026947], 
             UndirectedEdge[144, 240] -> 
             RGBColor[
              0.5916152405496093, 0.6785994879792374, 0.9614988259905157], 
             UndirectedEdge[231, 232] -> 
             RGBColor[
              0.7873584069325286, 0.8345041013315108, 0.9741406880633035], 
             UndirectedEdge[90, 248] -> 
             RGBColor[
              0.9870406652039798, 0.988820486284204, 0.8604695874961124], 
             UndirectedEdge[27, 109] -> 
             RGBColor[
              0.8063895544309926, 0.8492529351085528, 0.9629030563142968], 
             UndirectedEdge[42, 145] -> 
             RGBColor[
              0.9206782319166004, 0.7897267852130085, 0.6061714399562125], 
             UndirectedEdge[160, 230] -> 
             RGBColor[
              0.9021996884237196, 0.9212207903794805, 0.8273653058230835], 
             UndirectedEdge[247, 251] -> 
             RGBColor[
              0.8770288369965094, 0.9044681530350858, 0.9715267796904683], 
             UndirectedEdge[109, 220] -> 
             RGBColor[
              0.8096658018559745, 0.8085598296831008, 0.637707551448514], 
             UndirectedEdge[139, 163] -> 
             RGBColor[
              0.7944714990220585, 0.8381601468152587, 0.9072832309617481], 
             UndirectedEdge[31, 279] -> 
             RGBColor[
              0.8228143731487505, 0.8396529289369765, 0.669423499785663], 
             UndirectedEdge[9, 112] -> 
             RGBColor[
              0.379197535967305, 0.4962086721531601, 0.9459704233584721], 
             UndirectedEdge[196, 276] -> 
             RGBColor[
              0.9296180861463117, 0.9434689897912106, 0.863087408195665], 
             UndirectedEdge[137, 251] -> 
             RGBColor[
              0.8969979394568675, 0.9167390401150228, 0.7933588078351614], 
             UndirectedEdge[162, 181] -> 
             RGBColor[
              0.9794554932764497, 0.9830391619197735, 0.8677422002508681], 
             UndirectedEdge[96, 236] -> 
             RGBColor[
              0.8480477325155472, 0.8821351588631231, 0.985246435085267], 
             UndirectedEdge[251, 295] -> 
             RGBColor[
              0.7288879336453818, 0.7881320606080251, 0.9736123954469125], 
             UndirectedEdge[20, 268] -> 
             RGBColor[
              0.9655773024557723, 0.9738481890502848, 0.9431528274517037], 
             UndirectedEdge[187, 215] -> 
             RGBColor[
              0.7896049532929175, 0.6219011037127077, 0.5893621412802544], 
             UndirectedEdge[55, 250] -> 
             RGBColor[
              0.9642679898932789, 0.891149044286695, 0.5378517392308688], 
             UndirectedEdge[193, 230] -> 
             RGBColor[
              0.8109342614147372, 0.852227275436632, 0.9817900066324363], 
             UndirectedEdge[55, 242] -> 
             RGBColor[
              0.919170702496803, 0.8576552656500683, 0.6296686483139673], 
             UndirectedEdge[51, 116] -> 
             RGBColor[
              0.9809987563205824, 0.9820754973207994, 0.7209533997758655], 
             UndirectedEdge[130, 203] -> 
             RGBColor[
              0.9360238764282677, 0.8210898999229521, 0.5939353471820532], 
             UndirectedEdge[34, 124] -> 
             RGBColor[
              0.9253712314072178, 0.729675551846822, 0.5287393953409198], 
             UndirectedEdge[190, 261] -> 
             RGBColor[
              0.843624435061286, 0.8772674102152291, 0.9152942772346716], 
             UndirectedEdge[76, 85] -> 
             RGBColor[
              0.9904816660712401, 0.9885639062143592, 0.6788896690172477], 
             UndirectedEdge[130, 237] -> 
             RGBColor[
              0.9668018633988892, 0.9747614645966269, 0.9410799651916519], 
             UndirectedEdge[175, 183] -> 
             RGBColor[
              0.9626324816651116, 0.8944551631064002, 0.5844440968456253], 
             UndirectedEdge[93, 289] -> 
             RGBColor[
              0.9391721048491988, 0.9533790220287954, 0.9609381168936066], 
             UndirectedEdge[69, 234] -> 
             RGBColor[
              0.5130179493470519, 0.6142427031210131, 0.9551615125963435], 
             UndirectedEdge[32, 269] -> 
             RGBColor[
              0.9839707648553435, 0.9756633967255981, 0.6586715195296766], 
             UndirectedEdge[226, 243] -> 
             RGBColor[
              0.9189956491254341, 0.9358344442774842, 0.898354413618185], 
             UndirectedEdge[72, 218] -> 
             RGBColor[
              0.7260300975608946, 0.7856555488483039, 0.9735347281994737], 
             UndirectedEdge[81, 181] -> 
             RGBColor[
              0.9842658772567823, 0.9629567703431501, 0.5812736194013519], 
             UndirectedEdge[8, 67] -> 
             RGBColor[
              0.8286589481372972, 0.8667549569016575, 0.9833759155957648], 
             UndirectedEdge[145, 156] -> 
             RGBColor[
              0.6513641021291195, 0.7213640432030113, 0.9606970784584883], 
             UndirectedEdge[20, 177] -> 
             RGBColor[
              0.9842309446715172, 0.986487466225953, 0.8545884050177069], 
             UndirectedEdge[180, 297] -> 
             RGBColor[
              0.7451188928464232, 0.7994580831272464, 0.9505900368407929], 
             UndirectedEdge[140, 216] -> 
             RGBColor[
              0.612809190879732, 0.6952915758297867, 0.9635187951795573], 
             UndirectedEdge[287, 300] -> 
             RGBColor[
              0.9339639302238563, 0.9487759280368528, 0.9434740290134276], 
             UndirectedEdge[140, 167] -> 
             RGBColor[
              0.593010365691985, 0.6798245831164742, 0.9615454333153834], 
             UndirectedEdge[248, 285] -> 
             RGBColor[
              0.853065203659884, 0.8840716740615469, 0.8903465672041653], 
             UndirectedEdge[185, 292] -> 
             RGBColor[
              0.9629351764287049, 0.9636523942849233, 0.7020855062679181], 
             UndirectedEdge[23, 241] -> 
             RGBColor[
              0.4623076543813087, 0.5656158496096418, 0.9524481788189711], 
             UndirectedEdge[10, 48] -> 
             RGBColor[
              0.8443055513509086, 0.8789258264281106, 0.9693461059402808], 
             UndirectedEdge[46, 62] -> 
             RGBColor[
              0.9578286774998087, 0.9640832903829983, 0.7183308324227689], 
             UndirectedEdge[15, 276] -> 
             RGBColor[
              0.9246982468692739, 0.9275729974628208, 0.691116290655556], 
             UndirectedEdge[85, 154] -> 
             RGBColor[
              0.990366256055376, 0.9885161812068973, 0.6808023116516615], 
             UndirectedEdge[32, 179] -> 
             RGBColor[
              0.9007510483038114, 0.9105293044805154, 0.6917823216961052], 
             UndirectedEdge[145, 277] -> 
             RGBColor[
              0.8146679521116817, 0.8559085675075855, 0.9732692602438078], 
             UndirectedEdge[58, 164] -> 
             RGBColor[
              0.7157024737237863, 0.7770678011977759, 0.9729557143782647], 
             UndirectedEdge[18, 253] -> 
             RGBColor[
              0.821097318561212, 0.8594737184895644, 0.9041915711306454], 
             UndirectedEdge[59, 136] -> 
             RGBColor[
              0.9146854448620196, 0.9322789848191517, 0.892792430953263], 
             UndirectedEdge[232, 288] -> 
             RGBColor[
              0.4061011659053161, 0.5092772344746413, 0.9488869501827799], 
             UndirectedEdge[136, 177] -> 
             RGBColor[
              0.9151810306799155, 0.9324839222908261, 0.8845792914157449], 
             UndirectedEdge[31, 65] -> 
             RGBColor[
              0.9447614260252841, 0.8120076599209121, 0.3092891653837346], 
             UndirectedEdge[62, 214] -> 
             RGBColor[
              0.9610892748932863, 0.966683202237999, 0.7186418311129283], 
             UndirectedEdge[24, 109] -> 
             RGBColor[
              0.7543996416608039, 0.8083208644577168, 0.9760864696275422], 
             UndirectedEdge[71, 268] -> 
             RGBColor[
              0.9100013057693397, 0.9305883810345579, 0.9744288681106166], 
             UndirectedEdge[64, 118] -> 
             RGBColor[
              0.9551505028534271, 0.9632582216187313, 0.8243034941310734], 
             UndirectedEdge[21, 206] -> 
             RGBColor[
              0.9654404795488503, 0.9732816080443609, 0.9225814405825241], 
             UndirectedEdge[6, 124] -> 
             RGBColor[
              0.7640836795147196, 0.6042812068752441, 0.5872713457584319], 
             UndirectedEdge[7, 140] -> 
             RGBColor[
              0.7442557352284013, 0.7975237095490135, 0.908805622559355], 
             UndirectedEdge[78, 229] -> 
             RGBColor[
              0.9872271720858459, 0.9881455928632892, 0.8234742631493163], 
             UndirectedEdge[67, 213] -> 
             RGBColor[
              0.7974354554902969, 0.8423629271384876, 0.9802638496488401], 
             UndirectedEdge[189, 300] -> 
             RGBColor[
              0.9049179470267148, 0.9256154494676625, 0.9407035972064288], 
             UndirectedEdge[77, 225] -> 
             RGBColor[
              0.9372433571818067, 0.9507930723173552, 0.9178290758672936], 
             UndirectedEdge[153, 239] -> 
             RGBColor[
              0.6601047818236029, 0.7336422588459022, 0.9672735335111653], 
             UndirectedEdge[7, 168] -> 
             RGBColor[
              0.9831598742666232, 0.9864808041386957, 0.8918751163831966], 
             UndirectedEdge[5, 256] -> 
             RGBColor[
              0.6226521868236422, 0.6849934815342344, 0.7102085191605896], 
             UndirectedEdge[193, 200] -> 
             RGBColor[
              0.9027151127211679, 0.9223511046908461, 0.8722850108504652], 
             UndirectedEdge[17, 202] -> 
             RGBColor[
              0.7308668044721016, 0.789677969537834, 0.9738096307973206], 
             UndirectedEdge[12, 220] -> 
             RGBColor[
              0.9060856529533428, 0.8841233501435971, 0.6472541986474155], 
             UndirectedEdge[196, 207] -> 
             RGBColor[
              0.7454792487765248, 0.7970209118283244, 0.8463590448315839], 
             UndirectedEdge[222, 285] -> 
             RGBColor[
              0.6646904216267411, 0.7375410360356824, 0.9675142351174025], 
             UndirectedEdge[169, 227] -> 
             RGBColor[
              0.9621524739810462, 0.9153654066317598, 0.6077314527063304], 
             UndirectedEdge[139, 298] -> 
             RGBColor[
              0.7655275006941562, 0.8146621050604024, 0.9050046533880163], 
             UndirectedEdge[210, 241] -> 
             RGBColor[
              0.8126430249925352, 0.8538780005075083, 0.9503553999506624], 
             UndirectedEdge[58, 288] -> 
             RGBColor[
              0.5194764038267667, 0.5983096252585068, 0.9600061116798688], 
             UndirectedEdge[85, 258] -> 
             RGBColor[
              0.9897041784602891, 0.9882423951067109, 0.6917746508041421], 
             UndirectedEdge[87, 162] -> 
             RGBColor[
              0.8128417032906672, 0.8540853800082837, 0.9530160647326189], 
             UndirectedEdge[222, 248] -> 
             RGBColor[
              0.8020473035162108, 0.843776662454689, 0.8855620274158765], 
             UndirectedEdge[76, 87] -> 
             RGBColor[
              0.8228367806466939, 0.8609517721841402, 0.9097687403570591], 
             UndirectedEdge[80, 282] -> 
             RGBColor[
              0.8306795661001101, 0.86782535408482, 0.9837121526426731], 
             UndirectedEdge[273, 289] -> 
             RGBColor[
              0.9457506034857823, 0.9580010136054602, 0.9370735000507053], 
             UndirectedEdge[215, 296] -> 
             RGBColor[
              0.838902654950413, 0.6604128429239529, 0.594275675468259], 
             UndirectedEdge[142, 277] -> 
             RGBColor[
              0.7745639395952049, 0.8241794573770697, 0.9780681053440458], 
             UndirectedEdge[134, 180] -> 
             RGBColor[
              0.759166498904857, 0.8085758718864395, 0.8659571063045075], 
             UndirectedEdge[86, 178] -> 
             RGBColor[
              0.5290756905029148, 0.6285665059953309, 0.9560699229059536], 
             UndirectedEdge[3, 210] -> 
             RGBColor[
              0.9669414403705243, 0.9748655608735362, 0.940843697786178], 
             UndirectedEdge[79, 176] -> 
             RGBColor[
              0.9325691884647012, 0.9480914015117603, 0.9595235820994046], 
             UndirectedEdge[131, 141] -> 
             RGBColor[
              0.8120474136484385, 0.853410499302649, 0.950184413377746], 
             UndirectedEdge[150, 256] -> 
             RGBColor[
              0.609834075395257, 0.6788448232970072, 0.9388779983937238], 
             UndirectedEdge[74, 300] -> 
             RGBColor[
              0.9318369978349665, 0.9470799698839938, 0.9432711603034403], 
             UndirectedEdge[25, 230] -> 
             RGBColor[
              0.8774338745651828, 0.9049435149923255, 0.979612845530643], 
             UndirectedEdge[165, 253] -> 
             RGBColor[
              0.9324260818559735, 0.9469011752294958, 0.9151666193438117], 
             UndirectedEdge[223, 295] -> 
             RGBColor[
              0.7588680848875267, 0.5944727606222071, 0.5856308760224418], 
             UndirectedEdge[164, 221] -> 
             RGBColor[
              0.7683447211000631, 0.8182797063644702, 0.9515024971439232], 
             UndirectedEdge[70, 138] -> 
             RGBColor[
              0.8227995467445528, 0.8616515623915724, 0.9829314856322011], 
             UndirectedEdge[165, 224] -> 
             RGBColor[
              0.6591696440059267, 0.7307419439869992, 0.9687281414287343], 
             UndirectedEdge[87, 258] -> 
             RGBColor[
              0.8220592930357431, 0.8606302610764918, 0.9226537221439537], 
             UndirectedEdge[90, 222] -> 
             RGBColor[
              0.7986658831708369, 0.8422898482583396, 0.9376372554093497], 
             UndirectedEdge[163, 185] -> 
             RGBColor[
              0.7951596707800086, 0.8310377842731436, 0.6869866262522031], 
             UndirectedEdge[64, 286] -> 
             RGBColor[
              0.9549860559423158, 0.9629064863039971, 0.806404462705294], 
             UndirectedEdge[131, 199] -> 
             RGBColor[
              0.7716257735694297, 0.8220848455480263, 0.9777219952648235], 
             UndirectedEdge[2, 49] -> 
             RGBColor[
              0.9297506080136098, 0.9432542371120757, 0.8420819656134366], 
             UndirectedEdge[51, 283] -> 
             RGBColor[
              0.9739501023165196, 0.9800926094772286, 0.9289798612634024], 
             UndirectedEdge[66, 187] -> 
             RGBColor[
              0.7743615934077897, 0.8237464709400624, 0.978120890574409], 
             UndirectedEdge[120, 170] -> 
             RGBColor[
              0.63868795682215, 0.7142190315672234, 0.9668626784131795], 
             UndirectedEdge[17, 182] -> 
             RGBColor[
              0.7936335296041175, 0.8394825426812553, 0.9798611032129432], 
             UndirectedEdge[156, 179] -> 
             RGBColor[
              0.5862833623704604, 0.6697579701502048, 0.9631033243174132], 
             UndirectedEdge[199, 284] -> 
             RGBColor[
              0.9372458380265425, 0.9514843668705493, 0.9477618102707133], 
             UndirectedEdge[210, 291] -> 
             RGBColor[
              0.8986409358378025, 0.9211136525040502, 0.9589126892127002], 
             UndirectedEdge[212, 265] -> 
             RGBColor[
              0.9029159606178798, 0.9242737496823983, 0.950698153124211], 
             UndirectedEdge[85, 173] -> 
             RGBColor[
              0.957799795204221, 0.9644339460346577, 0.7486202442917367], 
             UndirectedEdge[47, 146] -> 
             RGBColor[
              0.7944432791971466, 0.8399058118416116, 0.9799973568190413], 
             UndirectedEdge[198, 283] -> 
             RGBColor[
              0.9868462642789674, 0.987367284619305, 0.7849041766714597], 
             UndirectedEdge[168, 212] -> 
             RGBColor[
              0.9023682604615397, 0.9238652758025764, 0.9516252666258163], 
             UndirectedEdge[56, 271] -> 
             RGBColor[
              0.9931009306059493, 0.9867605912132439, 0.5662486365043585], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.8826498661952924, 0.9092650606845027, 0.9886691262601861], 
             UndirectedEdge[159, 191] -> 
             RGBColor[
              0.9192254727087563, 0.9271529964624219, 0.6963961985234248], 
             UndirectedEdge[72, 83] -> 
             RGBColor[
              0.62131108126486, 0.6994825926601784, 0.9656106404659388], 
             UndirectedEdge[179, 277] -> 
             RGBColor[
              0.7495872123530225, 0.804302494454779, 0.9756755061027328], 
             UndirectedEdge[86, 182] -> 
             RGBColor[
              0.6861451523990817, 0.752671574326552, 0.9710895478516224], 
             UndirectedEdge[80, 293] -> 
             RGBColor[
              0.877109407862926, 0.9048472496020088, 0.9881406723984194], 
             UndirectedEdge[9, 96] -> 
             RGBColor[
              0.7196278796139215, 0.7797255970512333, 0.9738736353404198], 
             UndirectedEdge[51, 226] -> 
             RGBColor[
              0.9795066541967861, 0.9832314493510573, 0.8745579306229566], 
             UndirectedEdge[185, 235] -> 
             RGBColor[
              0.986399631316596, 0.9657849042917623, 0.4016655651894395], 
             UndirectedEdge[136, 210] -> 
             RGBColor[
              0.9045987797920296, 0.925864275551785, 0.9594809536876845], 
             UndirectedEdge[78, 284] -> 
             RGBColor[
              0.9898978071926023, 0.9900823465242721, 0.8164904892109481], 
             UndirectedEdge[81, 216] -> 
             RGBColor[
              0.8507760683975523, 0.8598796942393037, 0.6698489727605945], 
             UndirectedEdge[2, 165] -> 
             RGBColor[
              0.935736879306488, 0.9480275273480112, 0.8426529415133588], 
             UndirectedEdge[181, 216] -> 
             RGBColor[
              0.8576805510683263, 0.8875396550618682, 0.8845688699430507], 
             UndirectedEdge[7, 203] -> 
             RGBColor[
              0.947000523122256, 0.8287958268754165, 0.5538397442351879], 
             UndirectedEdge[44, 177] -> 
             RGBColor[
              0.9421387519075559, 0.9539792774498974, 0.8871505429318791], 
             UndirectedEdge[140, 237] -> 
             RGBColor[
              0.734950414414844, 0.7910642547016296, 0.946072106742253], 
             UndirectedEdge[38, 124] -> 
             RGBColor[
              0.901116796512416, 0.7122024554716376, 0.5973735700611374], 
             UndirectedEdge[5, 59] -> 
             RGBColor[
              0.9919453476134151, 0.9889944566503786, 0.6419324150091381], 
             UndirectedEdge[35, 253] -> 
             RGBColor[
              0.9798707907993074, 0.9522618897745139, 0.5927513225164841], 
             UndirectedEdge[200, 231] -> 
             RGBColor[
              0.9673119324593406, 0.9736482440352048, 0.8733287826676466], 
             UndirectedEdge[213, 234] -> 
             RGBColor[
              0.5482666649906078, 0.6421197562983725, 0.9584419812270702], 
             UndirectedEdge[53, 88] -> 
             RGBColor[
              0.8944521674968746, 0.9185690502463644, 0.9860904525271503], 
             UndirectedEdge[150, 269] -> 
             RGBColor[
              0.9745083193077162, 0.9805089267952667, 0.928034945503615], 
             UndirectedEdge[4, 135] -> 
             RGBColor[
              0.9098110631412768, 0.9284882749050254, 0.896495714795132], 
             UndirectedEdge[91, 139] -> 
             RGBColor[
              0.9914478269920499, 0.9907314709274608, 0.7913951692634029], 
             UndirectedEdge[28, 232] -> 
             RGBColor[
              0.6055879046908007, 0.690682568309026, 0.9620932446802994], 
             UndirectedEdge[127, 276] -> 
             RGBColor[
              0.9213677649187118, 0.9390443794251324, 0.9544572753709089], 
             UndirectedEdge[60, 103] -> 
             RGBColor[
              0.6517756558289691, 0.7217213375922152, 0.9607353756698654], 
             UndirectedEdge[145, 159] -> 
             RGBColor[
              0.8979887294898238, 0.9212471130575068, 0.9815081591190493], 
             UndirectedEdge[20, 252] -> 
             RGBColor[
              0.9695850317300359, 0.9768371469809762, 0.936368787173577], 
             UndirectedEdge[80, 128] -> 
             RGBColor[
              0.9092174897726506, 0.9259839622858816, 0.7673511059936013], 
             UndirectedEdge[167, 237] -> 
             RGBColor[
              0.8265331405564613, 0.864768265116552, 0.953724173000815], 
             UndirectedEdge[24, 291] -> 
             RGBColor[
              0.839302846454264, 0.8747013237665127, 0.9845346488209454], 
             UndirectedEdge[22, 244] -> 
             RGBColor[
              0.8481075252148689, 0.8777343047292595, 0.723515105862091], 
             UndirectedEdge[51, 83] -> 
             RGBColor[
              0.6897323511221977, 0.753187028155679, 0.9425686455875746], 
             UndirectedEdge[29, 229] -> 
             RGBColor[
              0.8077263766399756, 0.8497934254573423, 0.9423163503908157], 
             UndirectedEdge[151, 181] -> 
             RGBColor[
              0.9818137509545182, 0.9847979466347845, 0.8637502851340072], 
             UndirectedEdge[22, 63] -> 
             RGBColor[
              0.989381804384431, 0.9878807423423648, 0.6805191125153802], 
             UndirectedEdge[163, 292] -> 
             RGBColor[
              0.7689769996122879, 0.8197360924869059, 0.9768468103756165], 
             UndirectedEdge[247, 289] -> 
             RGBColor[
              0.9299114489669654, 0.9464724400347581, 0.976613991736347], 
             UndirectedEdge[155, 299] -> 
             RGBColor[
              0.9081776376473989, 0.8149659019022173, 0.6210236674220997], 
             UndirectedEdge[31, 71] -> 
             RGBColor[
              0.9220336061983687, 0.9175312977097665, 0.6792152092584058], 
             UndirectedEdge[45, 260] -> 
             RGBColor[
              0.7820559229417885, 0.8298390388521955, 0.9788661089788079], 
             UndirectedEdge[80, 125] -> 
             RGBColor[
              0.9095361534673307, 0.9266655517069611, 0.8020356825951838], 
             UndirectedEdge[97, 261] -> 
             RGBColor[
              0.990140375456366, 0.9881913269521234, 0.6677219970392279], 
             UndirectedEdge[107, 147] -> 
             RGBColor[
              0.8739943098439513, 0.8998558329470328, 0.866775997415006], 
             UndirectedEdge[15, 286] -> 
             RGBColor[
              0.989528210452572, 0.975229162090442, 0.5081356765482805], 
             UndirectedEdge[94, 202] -> 
             RGBColor[
              0.8921919540033576, 0.913265710952189, 0.8153979307905477], 
             UndirectedEdge[86, 130] -> 
             RGBColor[
              0.7110402122803481, 0.771763261003541, 0.9471504997038125], 
             UndirectedEdge[73, 161] -> 
             RGBColor[
              0.8139703293725034, 0.8554554919481455, 0.9818653467341507], 
             UndirectedEdge[7, 167] -> 
             RGBColor[
              0.8358384613700185, 0.871227719963936, 0.9164576888179172], 
             UndirectedEdge[288, 297] -> 
             RGBColor[
              0.5716015858912746, 0.6391359039623006, 0.9394281511461207], 
             UndirectedEdge[15, 46] -> 
             RGBColor[
              0.9538690651940513, 0.9508330161742287, 0.6938986293484702], 
             UndirectedEdge[1, 92] -> 
             RGBColor[
              0.9877709154063083, 0.9876494274676803, 0.7510087396980674], 
             UndirectedEdge[85, 213] -> 
             RGBColor[
              0.8419310130873883, 0.8730888488155888, 0.7372911263696491], 
             UndirectedEdge[2, 174] -> 
             RGBColor[
              0.8607454898795927, 0.8889871032479271, 0.835299663135276], 
             UndirectedEdge[104, 204] -> 
             RGBColor[
              0.990759858106212, 0.9893693577603461, 0.7244649703963908], 
             UndirectedEdge[125, 243] -> 
             RGBColor[
              0.9210241301508609, 0.9358257524815881, 0.8031314160666967], 
             UndirectedEdge[149, 243] -> 
             RGBColor[
              0.8578722972356143, 0.889508099765248, 0.9863058196136152], 
             UndirectedEdge[35, 175] -> 
             RGBColor[
              0.9558092123892694, 0.8579513867398287, 0.30701802993124816`], 
             UndirectedEdge[82, 201] -> 
             RGBColor[
              0.6457928286231606, 0.720567968376401, 0.9671575583219716], 
             UndirectedEdge[39, 69] -> 
             RGBColor[
              0.8020087807541266, 0.8449962908355858, 0.937700003832519], 
             UndirectedEdge[5, 204] -> 
             RGBColor[
              0.9902584410828832, 0.9882968774484833, 0.6698888217942127], 
             UndirectedEdge[107, 277] -> 
             RGBColor[
              0.8387454305226865, 0.8723191405198556, 0.8632627185437679], 
             UndirectedEdge[236, 260] -> 
             RGBColor[
              0.8020962894182815, 0.8454947254560581, 0.9808635454213122], 
             UndirectedEdge[11, 51] -> 
             RGBColor[
              0.9660807837579516, 0.9742236845810752, 0.9423005649360687], 
             UndirectedEdge[41, 242] -> 
             RGBColor[
              0.9472353127113602, 0.9566202558912359, 0.7970726364181475], 
             UndirectedEdge[53, 93] -> 
             RGBColor[
              0.9562941153532764, 0.9669248033090672, 0.9588668417732652], 
             UndirectedEdge[82, 293] -> 
             RGBColor[
              0.6981897461159361, 0.7623478481087038, 0.972155223087713], 
             UndirectedEdge[76, 151] -> 
             RGBColor[
              0.9800939616594383, 0.9840867695647, 0.8922516444255075], 
             UndirectedEdge[130, 269] -> 
             RGBColor[
              0.9733766888498983, 0.9796649586527009, 0.929950500692208], 
             UndirectedEdge[13, 289] -> 
             RGBColor[
              0.9228624708136912, 0.9412153236696885, 0.9885460730818951], 
             UndirectedEdge[86, 120] -> 
             RGBColor[
              0.4466255248914319, 0.5611677001862875, 0.9497068088146183], 
             UndirectedEdge[86, 284] -> 
             RGBColor[
              0.7207364751307304, 0.7789397163323104, 0.9282741705726685], 
             UndirectedEdge[49, 102] -> 
             RGBColor[
              0.7934389414454313, 0.8389196096267859, 0.979950753833011], 
             UndirectedEdge[27, 299] -> 
             RGBColor[
              0.9278773112187657, 0.944804923116405, 0.9748407027363328], 
             UndirectedEdge[120, 182] -> 
             RGBColor[
              0.6758207902482757, 0.743827744997304, 0.9704044412142352], 
             UndirectedEdge[97, 182] -> 
             RGBColor[
              0.9541523412300968, 0.9613456088494914, 0.7336844983575239], 
             UndirectedEdge[42, 130] -> 
             RGBColor[
              0.930571057378033, 0.7971048382441301, 0.5894254669121202], 
             UndirectedEdge[15, 127] -> 
             RGBColor[
              0.9814257389730998, 0.9717126771075972, 0.6586222108602557], 
             UndirectedEdge[28, 176] -> 
             RGBColor[
              0.7757620526773995, 0.8240268964870354, 0.9447230432420449], 
             UndirectedEdge[26, 35] -> 
             RGBColor[
              0.9337689241971221, 0.9175556014312172, 0.666604292126188], 
             UndirectedEdge[44, 59] -> 
             RGBColor[
              0.94164316608966, 0.953774339978223, 0.8953636824693971], 
             UndirectedEdge[155, 218] -> 
             RGBColor[
              0.768361843754567, 0.7047554233931999, 0.6074920474733232], 
             UndirectedEdge[65, 155] -> 
             RGBColor[
              0.9137526667393974, 0.6957650943814413, 0.2494615750546551], 
             UndirectedEdge[55, 252] -> 
             RGBColor[
              0.9502864865068252, 0.8817734754672688, 0.6086211356231228], 
             UndirectedEdge[160, 296] -> 
             RGBColor[
              0.905486566641988, 0.9237885246247914, 0.8276929111262572], 
             UndirectedEdge[88, 147] -> 
             RGBColor[
              0.801775389490105, 0.8453073217498734, 0.9808147670214993], 
             UndirectedEdge[204, 243] -> 
             RGBColor[
              0.9176177707430409, 0.9352646561565053, 0.921189424249389], 
             UndirectedEdge[65, 106] -> 
             RGBColor[
              0.8817830019243986, 0.7849276622566936, 0.6164926003530429], 
             UndirectedEdge[115, 245] -> 
             RGBColor[
              0.9919480825329977, 0.9909383394496237, 0.7831046403300587], 
             UndirectedEdge[60, 205] -> 
             RGBColor[
              0.650350592069455, 0.7206585273736974, 0.9631476368985681], 
             UndirectedEdge[75, 111] -> 
             RGBColor[
              0.7768646782387856, 0.8256307346860082, 0.9638175386626353], 
             UndirectedEdge[17, 86] -> 
             RGBColor[
              0.5644382642472737, 0.6568224978702388, 0.9591634708133263], 
             UndirectedEdge[67, 166] -> 
             RGBColor[
              0.893897435862134, 0.918233567429697, 0.9897419294958335], 
             UndirectedEdge[3, 169] -> 
             RGBColor[
              0.9582908896341198, 0.9124854433485862, 0.6142681077431769], 
             UndirectedEdge[7, 255] -> 
             RGBColor[
              0.9037213415142475, 0.5732097409391622, 0.5154234219434978], 
             UndirectedEdge[211, 231] -> 
             RGBColor[
              0.9399542058293278, 0.9547385255402525, 0.9865260464663724], 
             UndirectedEdge[218, 290] -> 
             RGBColor[
              0.6321264875160759, 0.712200794861131, 0.9642009127105153], 
             UndirectedEdge[201, 269] -> 
             RGBColor[
              0.9031375468387599, 0.9244171317176725, 0.9495645898073308], 
             UndirectedEdge[34, 223] -> 
             RGBColor[
              0.9238460566916349, 0.722750089676965, 0.527466752172784], 
             UndirectedEdge[63, 208] -> 
             RGBColor[
              0.7046220795398095, 0.7647928276474779, 0.9166337575766778], 
             UndirectedEdge[131, 190] -> 
             RGBColor[
              0.6766076591095529, 0.7472903127958326, 0.9684015862681239], 
             UndirectedEdge[27, 181] -> 
             RGBColor[
              0.9735806752484215, 0.9786577322536016, 0.8776867347743812], 
             UndirectedEdge[108, 136] -> 
             RGBColor[
              0.8005313999769299, 0.844250221522032, 0.9807134100985777], 
             UndirectedEdge[101, 254] -> 
             RGBColor[
              0.8983028707995706, 0.9206913584946712, 0.9535851949768016], 
             UndirectedEdge[62, 212] -> 
             RGBColor[
              0.9090880244157222, 0.9252188166435307, 0.7136819054203141], 
             UndirectedEdge[69, 195] -> 
             RGBColor[
              0.8024890677730124, 0.845245819751402, 0.9320206121632241], 
             UndirectedEdge[136, 252] -> 
             RGBColor[
              0.9005351177384342, 0.9228336030458495, 0.9663596735716149], 
             UndirectedEdge[26, 175] -> 
             RGBColor[
              0.9182155743402869, 0.8604456487257705, 0.6303729306946338], 
             UndirectedEdge[24, 27] -> 
             RGBColor[
              0.9040010777990981, 0.9257666626906529, 0.9725633662781996], 
             UndirectedEdge[231, 266] -> 
             RGBColor[
              0.8285749019124198, 0.8668418906781397, 0.9781536253333691], 
             UndirectedEdge[153, 157] -> 
             RGBColor[
              0.8571400003604637, 0.8878682725250321, 0.9185639774129468], 
             UndirectedEdge[161, 244] -> 
             RGBColor[
              0.8145944750385659, 0.8559430792861563, 0.9819275557411709], 
             UndirectedEdge[128, 150] -> 
             RGBColor[
              0.9805280253676377, 0.9820277261152595, 0.7458157162430723], 
             UndirectedEdge[113, 200] -> 
             RGBColor[
              0.9750032233391106, 0.9793843961800043, 0.86030943341813], 
             UndirectedEdge[211, 264] -> 
             RGBColor[
              0.9591412999252756, 0.9690482289010274, 0.9540473009575365], 
             UndirectedEdge[144, 232] -> 
             RGBColor[
              0.562938168770079, 0.6560575913398763, 0.9587357012374897], 
             UndirectedEdge[208, 244] -> 
             RGBColor[
              0.5633478003702475, 0.6546463900343726, 0.9596297509233885], 
             UndirectedEdge[47, 133] -> 
             RGBColor[
              0.6659804963698932, 0.7361951241386295, 0.9693674586379561], 
             UndirectedEdge[181, 258] -> 
             RGBColor[
              0.9886730830215256, 0.9895840429879816, 0.8373798576622029], 
             UndirectedEdge[53, 147] -> 
             RGBColor[
              0.8471655542770701, 0.8813933619367129, 0.9814397336919389], 
             UndirectedEdge[123, 267] -> 
             RGBColor[
              0.9800964248623731, 0.9846459056075254, 0.9172044622711246], 
             UndirectedEdge[59, 227] -> 
             RGBColor[
              0.9808896897874406, 0.9841602334240764, 0.86761852001491], 
             UndirectedEdge[213, 286] -> 
             RGBColor[
              0.8424648376755874, 0.8742306456318015, 0.7953946384116348], 
             UndirectedEdge[16, 126] -> 
             RGBColor[
              0.9570286988980568, 0.9659156383820122, 0.8913290769445523], 
             UndirectedEdge[68, 109] -> 
             RGBColor[
              0.4634023604331159, 0.5664710422973878, 0.9525572888876055], 
             UndirectedEdge[137, 156] -> 
             RGBColor[
              0.6757730546208045, 0.7369461631667248, 0.7750135985984898], 
             UndirectedEdge[181, 202] -> 
             RGBColor[
              0.890488663709725, 0.9131696020082201, 0.8878388760019011], 
             UndirectedEdge[135, 214] -> 
             RGBColor[
              0.9599318162282119, 0.968453202924948, 0.9012762769678884], 
             UndirectedEdge[166, 234] -> 
             RGBColor[
              0.6447286453624449, 0.7179903965895817, 0.9679200610740637], 
             UndirectedEdge[63, 152] -> 
             RGBColor[
              0.9670761006430364, 0.9746995498105356, 0.9286840042853447], 
             UndirectedEdge[130, 167] -> 
             RGBColor[
              0.8248618146760301, 0.8635217930114716, 0.9565532917647825], 
             UndirectedEdge[30, 74] -> 
             RGBColor[
              0.8497372033478867, 0.8830213967204148, 0.9855298870963196], 
             UndirectedEdge[31, 177] -> 
             RGBColor[
              0.9852305037850421, 0.9652021824925145, 0.5780502994128611], 
             UndirectedEdge[24, 72] -> 
             RGBColor[
              0.8419696580340589, 0.8768277669315693, 0.9847890116901171], 
             UndirectedEdge[39, 285] -> 
             RGBColor[
              0.8497969195980433, 0.8826692367202129, 0.9422302849802853], 
             UndirectedEdge[27, 72] -> 
             RGBColor[
              0.8939595708042476, 0.9177598375824053, 0.9716055983768717], 
             UndirectedEdge[109, 151] -> 
             RGBColor[
              0.8146226301370894, 0.8553931494897355, 0.9489666066739229], 
             UndirectedEdge[29, 178] -> 
             RGBColor[
              0.6187362271189164, 0.7013569687813456, 0.9631283287857327], 
             UndirectedEdge[149, 256] -> 
             RGBColor[
              0.5601351331082346, 0.6400335573403281, 0.9624747212068636], 
             UndirectedEdge[93, 137] -> 
             RGBColor[
              0.9834543450008377, 0.9845588212708305, 0.7685261673363739], 
             UndirectedEdge[7, 145] -> 
             RGBColor[
              0.9662143587510137, 0.9738428664128892, 0.9205594540528463], 
             UndirectedEdge[271, 278] -> 
             RGBColor[
              0.992607753320376, 0.9857057348672751, 0.5125693325071143], 
             UndirectedEdge[15, 135] -> 
             RGBColor[
              0.987558374564345, 0.9752615700410043, 0.6023478750741614], 
             UndirectedEdge[94, 130] -> 
             RGBColor[
              0.9798537390166397, 0.9821619707725994, 0.7975103550583602], 
             UndirectedEdge[265, 286] -> 
             RGBColor[
              0.9873157589604868, 0.9875343693380791, 0.7695841273264761], 
             UndirectedEdge[140, 201] -> 
             RGBColor[
              0.6630399465232746, 0.7345699556615206, 0.9685153146213431], 
             UndirectedEdge[29, 259] -> 
             RGBColor[
              0.7916448324991305, 0.8377998361682119, 0.9695382098828125], 
             UndirectedEdge[21, 123] -> 
             RGBColor[
              0.98140233290866, 0.985185932144971, 0.8955621863624647], 
             UndirectedEdge[21, 189] -> 
             RGBColor[
              0.9059120138224055, 0.926026521634032, 0.9242293378394337], 
             UndirectedEdge[107, 289] -> 
             RGBColor[
              0.9495490773466433, 0.9595717801632517, 0.8741229580409984], 
             UndirectedEdge[17, 66] -> 
             RGBColor[
              0.751525397447474, 0.8059066610943464, 0.9758447919774691], 
             UndirectedEdge[71, 208] -> 
             RGBColor[
              0.6444532317510637, 0.7183741192735031, 0.967616045928886], 
             UndirectedEdge[6, 289] -> 
             RGBColor[
              0.7854609655274479, 0.8330193316908774, 0.9790674340606456], 
             UndirectedEdge[96, 132] -> 
             RGBColor[
              0.8868861873156894, 0.9126429881540339, 0.9890731903504582], 
             UndirectedEdge[55, 283] -> 
             RGBColor[
              0.9585712336020054, 0.8879522262858258, 0.5945972197990872], 
             UndirectedEdge[48, 244] -> 
             RGBColor[
              0.7194198822067897, 0.7807355468643409, 0.9726687085634849], 
             UndirectedEdge[110, 278] -> 
             RGBColor[
              0.9372863835327773, 0.7698945825205272, 0.4136508584023729], 
             UndirectedEdge[245, 288] -> 
             RGBColor[
              0.5852420235101172, 0.6480853181079709, 0.8615430553720071], 
             UndirectedEdge[106, 210] -> 
             RGBColor[
              0.9116698287962709, 0.931502538089255, 0.960155396654109], 
             UndirectedEdge[176, 296] -> 
             RGBColor[
              0.8949090322358808, 0.918092844822083, 0.9559233946167933], 
             UndirectedEdge[82, 154] -> 
             RGBColor[
              0.7272166825279041, 0.7836077625709671, 0.9039996874468574], 
             UndirectedEdge[46, 117] -> 
             RGBColor[
              0.9483289903774486, 0.9606564873949235, 0.9609798784319133], 
             UndirectedEdge[249, 258] -> 
             RGBColor[
              0.9632942449522517, 0.9718159062310713, 0.9322580808057168], 
             UndirectedEdge[146, 170] -> 
             RGBColor[
              0.7702587951985269, 0.8206217607714423, 0.9776906191455093], 
             UndirectedEdge[18, 129] -> 
             RGBColor[
              0.8223439911007142, 0.8551787401057183, 0.6925855886636239], 
             UndirectedEdge[13, 179] -> 
             RGBColor[
              0.8776550187149861, 0.9052069298952037, 0.9842238492435856], 
             UndirectedEdge[144, 160] -> 
             RGBColor[
              0.743689851162785, 0.7950975993205942, 0.8131350163086992], 
             UndirectedEdge[17, 130] -> 
             RGBColor[
              0.8185285894853838, 0.8585742293582443, 0.9559220550651332], 
             UndirectedEdge[111, 163] -> 
             RGBColor[
              0.6013835529725251, 0.6872692861802434, 0.9617622627119891], 
             UndirectedEdge[107, 251] -> 
             RGBColor[
              0.8966664653761872, 0.9175674931635794, 0.8690357459951198], 
             UndirectedEdge[1, 198] -> 
             RGBColor[
              0.9880634000059697, 0.9882750224516266, 0.7828438833654834], 
             UndirectedEdge[168, 269] -> 
             RGBColor[
              0.980429378904075, 0.9849248433473858, 0.9180121360666507], 
             UndirectedEdge[145, 201] -> 
             RGBColor[
              0.884998570045887, 0.9108891125253964, 0.9802691461148344], 
             UndirectedEdge[197, 226] -> 
             RGBColor[
              0.7235939742843329, 0.780120458272666, 0.8808800819959663], 
             UndirectedEdge[105, 174] -> 
             RGBColor[
              0.6933217061914426, 0.7603474534076676, 0.9700674862795964], 
             UndirectedEdge[178, 284] -> 
             RGBColor[
              0.7928622785914072, 0.8374946928121059, 0.9339521780266165], 
             UndirectedEdge[201, 202] -> 
             RGBColor[
              0.8072296104940375, 0.8493709057361076, 0.9814107488029296], 
             UndirectedEdge[24, 65] -> 
             RGBColor[
              0.8814624275405756, 0.7846720449447929, 0.6164620236821337], 
             UndirectedEdge[134, 169] -> 
             RGBColor[
              0.9728788131112971, 0.9220061999539895, 0.5287205607543114], 
             UndirectedEdge[104, 300] -> 
             RGBColor[
              0.9895164256450089, 0.988855166482882, 0.7450718641785856], 
             UndirectedEdge[168, 225] -> 
             RGBColor[
              0.9836752999856508, 0.9866939459193504, 0.8833331783399059], 
             UndirectedEdge[27, 202] -> 
             RGBColor[
              0.8728989790305902, 0.9012106030961073, 0.9695320941924743], 
             UndirectedEdge[113, 187] -> 
             RGBColor[
              0.8372115485934528, 0.873316561959856, 0.9652285003152703], 
             UndirectedEdge[7, 201] -> 
             RGBColor[
              0.9058680422013081, 0.9259730925089824, 0.9234275701238768], 
             UndirectedEdge[51, 104] -> 
             RGBColor[
              0.9814017730457028, 0.9829375093445903, 0.7648192831742908], 
             UndirectedEdge[2, 183] -> 
             RGBColor[
              0.9900048575256639, 0.9898920182596007, 0.7976637116004084], 
             UndirectedEdge[135, 249] -> 
             RGBColor[
              0.9653866059970182, 0.9726811512943083, 0.8975822434371279], 
             UndirectedEdge[84, 270] -> 
             RGBColor[
              0.7084370773089725, 0.770915464767996, 0.972676059426477], 
             UndirectedEdge[114, 116] -> 
             RGBColor[
              0.9739031737875314, 0.9767836234856, 0.7329643701800068], 
             UndirectedEdge[15, 168] -> 
             RGBColor[
              0.9819960692752369, 0.9721380285131009, 0.6576567904247037], 
             UndirectedEdge[42, 237] -> 
             RGBColor[
              0.9322423832584643, 0.7983513103492107, 0.5865963481481528], 
             UndirectedEdge[40, 140] -> 
             RGBColor[
              0.7198344470161488, 0.7797907909658077, 0.9716594966725376], 
             UndirectedEdge[42, 167] -> 
             RGBColor[
              0.7903023345356053, 0.6871116387640552, 0.6020696747212833], 
             UndirectedEdge[16, 285] -> 
             RGBColor[
              0.8191224231227665, 0.8594528234724401, 0.9823861631199238], 
             UndirectedEdge[8, 286] -> 
             RGBColor[
              0.8736883303225877, 0.8986226753949713, 0.7985067043585595], 
             UndirectedEdge[9, 236] -> 
             RGBColor[
              0.6345405724798157, 0.7123401883008734, 0.9656356232527772], 
             UndirectedEdge[54, 238] -> 
             RGBColor[
              0.9182101597947366, 0.8076446841337654, 0.6185498201704218], 
             UndirectedEdge[165, 183] -> 
             RGBColor[
              0.9307411225786129, 0.9462044012668289, 0.943090755104507], 
             UndirectedEdge[249, 263] -> 
             RGBColor[
              0.9523452077309753, 0.9639797144700979, 0.9655513123377634], 
             UndirectedEdge[33, 98] -> 
             RGBColor[
              0.9707880213862894, 0.9159460892871687, 0.5379465751172737], 
             UndirectedEdge[282, 293] -> 
             RGBColor[
              0.8830162467189167, 0.9095572025689064, 0.9887040719616011], 
             UndirectedEdge[54, 163] -> 
             RGBColor[
              0.7653522991074938, 0.8168730216941495, 0.9774429801461291], 
             UndirectedEdge[145, 237] -> 
             RGBColor[
              0.9569090379374565, 0.9673834115655053, 0.9578259382357442], 
             UndirectedEdge[140, 181] -> 
             RGBColor[
              0.746298999738962, 0.798368651933633, 0.8749434418203148], 
             UndirectedEdge[15, 265] -> 
             RGBColor[
              0.9825437694315771, 0.9725465023929227, 0.6567296769230986], 
             UndirectedEdge[144, 230] -> 
             RGBColor[
              0.6511108429904603, 0.7250779047893561, 0.967428791623804], 
             UndirectedEdge[22, 266] -> 
             RGBColor[
              0.8543380922816868, 0.8826016710759212, 0.7241361105593518], 
             UndirectedEdge[18, 165] -> 
             RGBColor[
              0.7651443810646753, 0.8169124536153081, 0.9771049368042912], 
             UndirectedEdge[17, 140] -> 
             RGBColor[
              0.5866771405013386, 0.674877019463247, 0.9609141966157342], 
             UndirectedEdge[80, 237] -> 
             RGBColor[
              0.8966229582617199, 0.9195616689098149, 0.960699799753588], 
             UndirectedEdge[7, 127] -> 
             RGBColor[
              0.9825895439644862, 0.9860554527331921, 0.8928405368187486], 
             UndirectedEdge[60, 212] -> 
             RGBColor[
              0.5918603878828979, 0.6741949156365654, 0.9636323145342967], 
             UndirectedEdge[53, 270] -> 
             RGBColor[
              0.9174822262472464, 0.9369325939596194, 0.9882870800899368], 
             UndirectedEdge[243, 254] -> 
             RGBColor[
              0.9121793621912281, 0.9317560960630542, 0.954908747113428], 
             UndirectedEdge[201, 277] -> 
             RGBColor[
              0.7543216355619762, 0.8080387936036786, 0.9761373763148382], 
             UndirectedEdge[288, 296] -> 
             RGBColor[
              0.4975607183439659, 0.5808652821694322, 0.9579076458722678], 
             UndirectedEdge[93, 273] -> 
             RGBColor[
              0.9793243970592965, 0.9838165077615955, 0.9071536475060392], 
             UndirectedEdge[128, 277] -> 
             RGBColor[
              0.8388266349644762, 0.8709553860198542, 0.7603454746757614], 
             UndirectedEdge[3, 115] -> 
             RGBColor[
              0.9777673274954117, 0.981585957457743, 0.8619043525567524], 
             UndirectedEdge[74, 123] -> 
             RGBColor[
              0.9272452679954402, 0.9437897027716894, 0.95705518999225], 
             UndirectedEdge[52, 147] -> 
             RGBColor[
              0.8441174513662482, 0.8790697325452586, 0.9848533906824507], 
             UndirectedEdge[64, 76] -> 
             RGBColor[
              0.9517013466202731, 0.9623951602989709, 0.9224075168128694], 
             UndirectedEdge[132, 260] -> 
             RGBColor[
              0.8409347442184236, 0.8760025547469689, 0.9846903006865034], 
             UndirectedEdge[171, 285] -> 
             RGBColor[
              0.8297647069484635, 0.8677292453258942, 0.9761395957581998], 
             UndirectedEdge[226, 290] -> 
             RGBColor[
              0.8171817742946297, 0.8560722598683839, 0.8882661100123626], 
             UndirectedEdge[24, 290] -> 
             RGBColor[
              0.74806604798924, 0.8033730129443963, 0.9754551962011586], 
             UndirectedEdge[103, 265] -> 
             RGBColor[
              0.9628312285639511, 0.971800171638048, 0.9478012142597798], 
             UndirectedEdge[41, 208] -> 
             RGBColor[
              0.708795293428843, 0.7655352460166903, 0.775996341823699], 
             UndirectedEdge[80, 179] -> 
             RGBColor[
              0.8199780671611969, 0.8593310707208064, 0.9826811374205726], 
             UndirectedEdge[102, 183] -> 
             RGBColor[
              0.8536931909574854, 0.885557390774311, 0.9355324998199825], 
             UndirectedEdge[16, 220] -> 
             RGBColor[
              0.9425400049471846, 0.9131910608964624, 0.6507312472837724], 
             UndirectedEdge[52, 217] -> 
             RGBColor[
              0.9146077680139459, 0.9347474241205616, 0.9917172994648051], 
             UndirectedEdge[24, 241] -> 
             RGBColor[
              0.7533049356089967, 0.8074656717699709, 0.9759773595589077], 
             UndirectedEdge[105, 163] -> 
             RGBColor[
              0.6306772704204153, 0.7107786635676953, 0.9642547373289012], 
             UndirectedEdge[2, 102] -> 
             RGBColor[
              0.8586889476853605, 0.8873805168554934, 0.8350946862288344], 
             UndirectedEdge[49, 54] -> 
             RGBColor[
              0.8970018530125383, 0.9207089453982706, 0.9900380315749849], 
             UndirectedEdge[216, 237] -> 
             RGBColor[
              0.8463319657442083, 0.8802352578298647, 0.9556975348649889], 
             UndirectedEdge[89, 281] -> 
             RGBColor[
              0.6245527404652873, 0.6910298404311537, 0.9062064985915377], 
             UndirectedEdge[145, 167] -> 
             RGBColor[
              0.8149689892145975, 0.85614373998035, 0.9732992648088747], 
             UndirectedEdge[16, 90] -> 
             RGBColor[
              0.9530978846668623, 0.9642016356950973, 0.9525091834118709], 
             UndirectedEdge[210, 290] -> 
             RGBColor[
              0.8074041373727785, 0.8497853416819338, 0.9498332365929134], 
             UndirectedEdge[152, 242] -> 
             RGBColor[
              0.9243424534894604, 0.9421831971571317, 0.9813292776387228], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.8606941613763517, 0.890881984477446, 0.9296727152167741], 
             UndirectedEdge[77, 282] -> 
             RGBColor[
              0.8614792184876121, 0.8923841608643217, 0.9866498509825672], 
             UndirectedEdge[81, 162] -> 
             RGBColor[
              0.9725510106056756, 0.9553792010972091, 0.6530223030684119], 
             UndirectedEdge[34, 247] -> 
             RGBColor[
              0.971061655111227, 0.9773225888245533, 0.9062915059412078], 
             UndirectedEdge[7, 60] -> 
             RGBColor[
              0.6726520016879813, 0.7368104439726848, 0.903882164291677], 
             UndirectedEdge[155, 162] -> 
             RGBColor[
              0.942166135025948, 0.8412411417934731, 0.5956183831272082], 
             UndirectedEdge[234, 249] -> 
             RGBColor[
              0.6731582692002656, 0.7405378540103169, 0.9664173877266823], 
             UndirectedEdge[118, 234] -> 
             RGBColor[
              0.7002664742076137, 0.7584578750169033, 0.801936501192873], 
             UndirectedEdge[223, 271] -> 
             RGBColor[
              0.9254260884929861, 0.7188688424491846, 0.3122430061788649], 
             UndirectedEdge[154, 216] -> 
             RGBColor[
              0.8558453517573823, 0.8867807529843217, 0.9149828718689649], 
             UndirectedEdge[147, 247] -> 
             RGBColor[
              0.8543566814642733, 0.886756492818539, 0.9692670311103546], 
             UndirectedEdge[4, 286] -> 
             RGBColor[
              0.9117808990295038, 0.9284558669544631, 0.802283516269251], 
             UndirectedEdge[88, 124] -> 
             RGBColor[
              0.8559528709800686, 0.6762851441504593, 0.596365639345278], 
             UndirectedEdge[23, 136] -> 
             RGBColor[
              0.5542634091808032, 0.6376021246539185, 0.9615737325559932], 
             UndirectedEdge[11, 104] -> 
             RGBColor[
              0.9787118660497708, 0.9809313811113428, 0.7693725940782989], 
             UndirectedEdge[4, 121] -> 
             RGBColor[
              0.8100401886225941, 0.8516038063476088, 0.9816809944693806], 
             UndirectedEdge[4, 213] -> 
             RGBColor[
              0.7599455367236094, 0.8124694835506663, 0.9766880277292278], 
             UndirectedEdge[198, 204] -> 
             RGBColor[
              0.9910249377768406, 0.9899363363721548, 0.753317256662218], 
             UndirectedEdge[156, 168] -> 
             RGBColor[
              0.6683096176447291, 0.7340019809288177, 0.9320127407888386], 
             UndirectedEdge[31, 226] -> 
             RGBColor[
              0.9844258898190075, 0.9648694539399235, 0.5913848351042499], 
             UndirectedEdge[36, 242] -> 
             RGBColor[
              0.5851725271211421, 0.6622482162938892, 0.964521871818038], 
             UndirectedEdge[216, 269] -> 
             RGBColor[
              0.8529067911952174, 0.8851387518859386, 0.944568070365545], 
             UndirectedEdge[97, 202] -> 
             RGBColor[
              0.891385616098081, 0.9115410357060699, 0.7276330259419015], 
             UndirectedEdge[23, 59] -> 
             RGBColor[
              0.6304386382547498, 0.6958118078843919, 0.8699071165088417], 
             UndirectedEdge[174, 238] -> 
             RGBColor[
              0.8167037904218618, 0.7274619347547144, 0.6086675193348894], 
             UndirectedEdge[86, 97] -> 
             RGBColor[
              0.7249570758732531, 0.7786855640384749, 0.7129868659579071], 
             UndirectedEdge[46, 212] -> 
             RGBColor[
              0.8742412563803543, 0.9025602634637041, 0.9878671055495827], 
             UndirectedEdge[59, 291] -> 
             RGBColor[
              0.9087276009077923, 0.9275283617714167, 0.8922241664782786], 
             UndirectedEdge[125, 149] -> 
             RGBColor[
              0.9311477467752955, 0.9438980495796595, 0.8040970156577946], 
             UndirectedEdge[32, 80] -> 
             RGBColor[
              0.905545708386734, 0.9143136348776315, 0.6922499373550239], 
             UndirectedEdge[69, 90] -> 
             RGBColor[
              0.8018956444705935, 0.8449119139805705, 0.937891514049872], 
             UndirectedEdge[215, 229] -> 
             RGBColor[
              0.9203963331093021, 0.7242417586680805, 0.563180516381025], 
             UndirectedEdge[187, 245] -> 
             RGBColor[
              0.8545780401965875, 0.885044861066158, 0.8810361670562704], 
             UndirectedEdge[98, 275] -> 
             RGBColor[
              0.9718352705217855, 0.914592019626089, 0.3906851642294628], 
             UndirectedEdge[252, 280] -> 
             RGBColor[
              0.9760248962194393, 0.9807598348408647, 0.8860527477387747], 
             UndirectedEdge[96, 146] -> 
             RGBColor[
              0.8162889395715165, 0.8573249484394802, 0.9820810154074], 
             UndirectedEdge[191, 270] -> 
             RGBColor[
              0.9414702466220554, 0.9448903753625841, 0.6985179249174194], 
             UndirectedEdge[40, 120] -> 
             RGBColor[
              0.6872712086112779, 0.7528924400435516, 0.9692236642327425], 
             UndirectedEdge[215, 233] -> 
             RGBColor[
              0.7608819600450667, 0.5994624830846528, 0.5864993017449416], 
             UndirectedEdge[21, 257] -> 
             RGBColor[
              0.9903655045134261, 0.9889561241333419, 0.712816563689662], 
             UndirectedEdge[200, 245] -> 
             RGBColor[
              0.9923697149422452, 0.9911126952863063, 0.7761171001591302], 
             UndirectedEdge[41, 108] -> 
             RGBColor[
              0.8783473789598781, 0.902155084184619, 0.7903788602542657], 
             UndirectedEdge[63, 73] -> 
             RGBColor[
              0.843897321140278, 0.8777601652243114, 0.9279985631574387]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.9453448865955926, 0.9587588864293032, 0.977401030043804], 160 -> 
             RGBColor[
              0.9947786965960442, 0.9912404849107186, 0.6730715305079789], 
             245 -> RGBColor[
              0.9915570470202344, 0.9907766362159418, 0.7895851107440143], 
             155 -> RGBColor[
              0.916591643426553, 0.7070206909131136, 0.2517458823364881], 213 -> 
             RGBColor[
              0.690629475369693, 0.7582442622280048, 0.9697991498716118], 27 -> 
             RGBColor[
              0.9559909905692867, 0.9666987333414889, 0.9593799529649543], 19 -> 
             RGBColor[0.989103626300843, 0.989762083698437, 0.83024464131362],
              164 -> RGBColor[
              0.571379139794039, 0.6629103518785382, 0.9594002053967916], 190 -> 
             RGBColor[
              0.6999323839141084, 0.7655117650876256, 0.970726376854696], 103 -> 
             RGBColor[
              0.9453311391884103, 0.9587486336355361, 0.9774243008182655], 
             138 -> RGBColor[
              0.8391653703581445, 0.8745917040591563, 0.9845215362281713], 
             291 -> RGBColor[
              0.8265945278796185, 0.8645680554932086, 0.9833225180504459], 28 -> 
             RGBColor[
              0.5779004775709693, 0.6682046676687693, 0.959913588995039], 195 -> 
             RGBColor[
              0.9848460914634438, 0.9880014836295179, 0.9008030117162897], 
             114 -> RGBColor[
              0.9545795256877815, 0.965646065143924, 0.9617691948403432], 93 -> 
             RGBColor[
              0.972745898422713, 0.9791945161849307, 0.9310182643489405], 34 -> 
             RGBColor[
              0.9878987235642077, 0.9892638254522504, 0.8502129978479943], 
             161 -> RGBColor[
              0.9259417624403533, 0.9437848436230957, 0.9927983459711721], 22 -> 
             RGBColor[
              0.9929678627929593, 0.987367294509302, 0.47597344621301235`], 
             124 -> RGBColor[
              0.8628437392502277, 0.47008727824139357`, 0.20726579283384527`],
              84 -> RGBColor[
              0.5217520344072921, 0.6226208320499571, 0.9554933778706699], 46 -> 
             RGBColor[
              0.9229819094644407, 0.9414247372031717, 0.9925160325520376], 
             241 -> RGBColor[
              0.654598706189084, 0.7300967515001249, 0.9662079395263704], 185 -> 
             RGBColor[
              0.9891178475964255, 0.974954086071161, 0.41222532214450464`], 
             121 -> 
             RGBColor[
              0.7908187791676624, 0.8365129078218898, 0.9797850833519173], 
             126 -> RGBColor[
              0.9915208733209947, 0.9907616774616845, 0.7901846025549486], 
             236 -> RGBColor[
              0.7629604253814414, 0.8147497501127632, 0.9770084229976244], 78 -> 
             RGBColor[
              0.9952725511659818, 0.9922967898994588, 0.7268245527285649], 
             254 -> RGBColor[
              0.9766100437712765, 0.9820763894589319, 0.9244772742043387], 
             290 -> RGBColor[
              0.6441209309495708, 0.7219114338489758, 0.9651636128108723], 
             251 -> RGBColor[
              0.7998330873347723, 0.8435549538733155, 0.9806835453465155], 
             165 -> RGBColor[
              0.8764731443594369, 0.9043399103552394, 0.9880799850174575], 
             100 -> RGBColor[
              0.6797200067659406, 0.749721702439721, 0.9687117959959702], 235 -> 
             RGBColor[
              0.9836814150367665, 0.9566157225123636, 0.3911058082343744], 70 -> 
             RGBColor[
              0.8064337231309612, 0.8487114207239883, 0.9813414350362311], 
             234 -> RGBColor[
              0.40590385461152273`, 0.5259952503687401, 0.9470848125825287], 
             257 -> RGBColor[
              0.9937428794829753, 0.989024976843039, 0.5603292300726643], 135 -> 
             RGBColor[
              0.9903605282050278, 0.990281844936723, 0.80941452400342], 265 -> 
             RGBColor[
              0.9803313179394919, 0.9848517096405599, 0.9181781277012941], 
             111 -> RGBColor[
              0.6015656119814586, 0.6874170898853604, 0.9617765950640764], 
             182 -> RGBColor[
              0.9153404177559255, 0.9353316191375685, 0.9917871802512392], 
             188 -> RGBColor[
              0.7109845094775343, 0.7741457695770394, 0.9718279494428727], 
             154 -> RGBColor[
              0.9874999613056683, 0.9890989270106217, 0.8568215204356365], 
             269 -> RGBColor[
              0.9816228401813385, 0.9858149248138555, 0.9159919174287967], 
             208 -> RGBColor[
              0.42344841310371634`, 0.5411914651195284, 0.9482027363356074], 
             86 -> RGBColor[
              0.456949887042238, 0.5700115295155355, 0.9503919154520056], 119 -> 
             RGBColor[
              0.9391914011140923, 0.9541696270326081, 0.9878172758779331], 
             140 -> RGBColor[
              0.5014276395503677, 0.6061205727015517, 0.9538933670568214], 85 -> 
             RGBColor[
              0.9932325508050837, 0.9879334354031729, 0.5047831028676866], 
             242 -> RGBColor[
              0.9003284516687509, 0.9233614848686196, 0.9903553255245042], 
             117 -> RGBColor[
              0.9736760712904564, 0.9798882375866754, 0.9294437243117891], 47 -> 
             RGBColor[
              0.8894437189009132, 0.9146822944177458, 0.9893171299961921], 81 -> 
             RGBColor[
              0.9773613945860082, 0.9352968095205856, 0.36655372221889565`], 
             275 -> RGBColor[
              0.9932104086404812, 0.9878860755520045, 0.5023730648963034], 23 -> 
             RGBColor[
              0.2700166025735334, 0.4011349477191588, 0.9386884181115718], 
             110 -> RGBColor[
              0.880416047591713, 0.5498790263031939, 0.22192855765067318`], 6 -> 
             RGBColor[
              0.6653236197792114, 0.7384751355090947, 0.9672768986830185], 
             218 -> RGBColor[
              0.620132044082581, 0.7024901558732861, 0.9632382126101584], 108 -> 
             RGBColor[
              0.7625525841657868, 0.8144311414553858, 0.9769677731967408], 
             297 -> RGBColor[
              0.9642761717825492, 0.972877807924601, 0.9453553022922414], 157 -> 
             RGBColor[
              0.9870858521967436, 0.9889276822519627, 0.8636843800505403], 
             270 -> RGBColor[
              0.895122120210653, 0.9192100974860349, 0.9898587409822839], 33 -> 
             RGBColor[
              0.9911159103694888, 0.9905942148741638, 0.7968958866719252], 
             252 -> RGBColor[
              0.9625600196887953, 0.9715979045030205, 0.9482603001428153], 
             260 -> RGBColor[
              0.8412321534551215, 0.8762397007993531, 0.9847186678450001], 
             159 -> RGBColor[
              0.850632572384055, 0.8837353396857104, 0.9856152881942948], 183 -> 
             RGBColor[
              0.9850091007977889, 0.9880688921784184, 0.8981015251915565], 99 -> 
             RGBColor[
              0.9849328148145859, 0.9880373459639037, 0.8993657813550266], 17 -> 
             RGBColor[
              0.6719266414523094, 0.7436334662249422, 0.967935026174647], 277 -> 
             RGBColor[
              0.6839910176277708, 0.7530582485858677, 0.9691374904438117], 
             104 -> RGBColor[
              0.994032855337522, 0.9896452058748579, 0.591891312316521], 79 -> 
             RGBColor[
              0.8915147491455727, 0.9163336777182189, 0.9895146667097583], 
             191 -> RGBColor[
              0.9878183730334578, 0.9705706532391333, 0.4071771088525548], 50 -> 
             RGBColor[
              0.9686808075455953, 0.9060151511345095, 0.3328312807582043], 
             225 -> RGBColor[
              0.9881146823444901, 0.9893531299577847, 0.8466340019753072], 61 -> 
             RGBColor[
              0.9881146823444901, 0.9893531299577847, 0.8466340019753072], 
             196 -> RGBColor[
              0.9945958994777376, 0.9920332798020653, 0.739223461225121], 1 -> 
             RGBColor[
              0.9815637853331602, 0.9857708818047776, 0.9160918818827913], 
             263 -> RGBColor[
              0.9642777316729421, 0.9728789712883019, 0.9453526618046909], 
             201 -> RGBColor[
              0.8246522534961814, 0.8630193386214895, 0.9831372621858648], 
             293 -> RGBColor[
              0.9294460884817325, 0.9465790980860952, 0.9931325917173476], 
             184 -> RGBColor[
              0.5140591005788882, 0.6163753618053391, 0.9548877619395528], 
             106 -> RGBColor[
              0.8526523137965555, 0.8853458266636182, 0.9858079329332635], 
             206 -> RGBColor[
              0.9438928295538235, 0.957675944665077, 0.9798589838583887], 247 -> 
             RGBColor[
              0.9542245866582464, 0.9653813521968561, 0.9623700140344211], 
             220 -> RGBColor[
              0.9625434854192505, 0.8853125224905849, 0.3089889432333886], 
             107 -> RGBColor[
              0.9934998434176021, 0.9915800324538434, 0.7573879466437241], 
             131 -> RGBColor[
              0.6532829343049973, 0.7290688605040396, 0.9660767956815519], 
             127 -> RGBColor[
              0.9780952570225375, 0.9831840590699089, 0.9219631955756085], 
             210 -> RGBColor[
              0.9706873437959863, 0.9776592495148917, 0.9345028603749544], 
             181 -> RGBColor[
              0.9911703599275563, 0.9906167311657145, 0.7959935165838081], 
             194 -> RGBColor[
              0.9861040578827308, 0.9885216850721554, 0.8799552526359683], 
             118 -> RGBColor[
              0.9946290938037046, 0.9909204996650666, 0.6567881898032171], 
             276 -> RGBColor[
              0.8646402728148859, 0.8949046997803559, 0.9869513551662091], 
             280 -> RGBColor[
              0.9894897727500832, 0.9899217651787089, 0.8238451953347343], 
             189 -> RGBColor[
              0.824835898100934, 0.8631657718444192, 0.9831547783722077], 168 -> 
             RGBColor[
              0.9792359176268116, 0.9840347618809162, 0.9200323547045045], 41 -> 
             RGBColor[
              0.9941421737539696, 0.9898790269138522, 0.6037899473117907], 14 -> 
             RGBColor[
              0.9927021671525936, 0.9867989984005097, 0.4470541154426206], 77 -> 
             RGBColor[
              0.8863720320191234, 0.9122330146769259, 0.9890241497592798], 51 -> 
             RGBColor[
              0.9687706907538836, 0.9762298128143228, 0.9377472540320605], 
             179 -> RGBColor[
              0.8151834070782743, 0.8555467403236903, 0.9822135217616539], 
             223 -> RGBColor[
              0.859793389819062, 0.4562363539016795, 0.20472050649757392`], 
             292 -> RGBColor[
              0.9367525052609843, 0.9523507024986856, 0.9919456903913315], 
             143 -> RGBColor[
              0.7151642969503449, 0.7774110513183604, 0.9722445515958278], 
             112 -> RGBColor[
              0.2522743523564202, 0.3824867178173366, 0.9376780232090142], 
             197 -> RGBColor[
              0.45694533092897727`, 0.5700078306575399, 0.9503915567780801], 
             54 -> RGBColor[
              0.9295031042513959, 0.9466245609131729, 0.9931380299323567], 71 -> 
             RGBColor[
              0.8654580503984112, 0.8955567734274779, 0.9870293555221645], 
             177 -> RGBColor[
              0.9918518455717579, 0.990898542992974, 0.7846995358310752], 158 -> 
             RGBColor[
              0.8634815018058043, 0.4729832090530376, 0.20779795754320912`], 
             226 -> RGBColor[
              0.9902426176396886, 0.9902330858877919, 0.8113686072138527], 
             203 -> RGBColor[
              0.9069172153380773, 0.668664807354358, 0.24396161040848696`], 
             115 -> RGBColor[
              0.992339118045761, 0.9911000426833056, 0.7766241699161031], 173 -> 
             RGBColor[
              0.9223670396033584, 0.9409344566661425, 0.9924573857157868], 
             212 -> RGBColor[
              0.8255006032962678, 0.8636957897242366, 0.9832181785471279], 
             129 -> RGBColor[
              0.9908723644315146, 0.98087248333606, 0.41904128873612295`], 
             279 -> RGBColor[
              0.6670195842991749, 0.7398000358818979, 0.9674459365766789], 26 -> 
             RGBColor[
              0.8961752861481396, 0.920049863417159, 0.9899591928895737], 40 -> 
             RGBColor[
              0.9382412544819299, 0.9534610092300637, 0.9894256262882539], 
             146 -> RGBColor[
              0.69944283949338, 0.7651293292654773, 0.9706775836418905], 192 -> 
             RGBColor[
              0.7175155804434845, 0.7792478918536174, 0.9724789055604304], 
             300 -> 
             RGBColor[
              0.9849999959524957, 0.9880651270909059, 0.8982524160406501], 
             221 -> RGBColor[
              0.9653103024060872, 0.9736490608504021, 0.9436047888910548], 62 -> 
             RGBColor[
              0.9926754455351767, 0.9867418435628249, 0.4441456322935001], 
             286 -> RGBColor[
              0.9943001999814818, 0.9902170290355983, 0.620990126951658], 152 -> 
             RGBColor[
              0.94835645531017, 0.9610049094456439, 0.9723032297529413], 64 -> 
             RGBColor[
              0.9156719119031497, 0.9355959435723961, 0.9918187984589298], 37 -> 
             RGBColor[
              0.9866804103714635, 0.9887600216378297, 0.8704036003452404], 
             148 -> RGBColor[
              0.6962597288881043, 0.7626426590680992, 0.9703603209246164], 
             261 -> RGBColor[
              0.9873164862084638, 0.9890230553428327, 0.8598621776146472], 15 -> 
             RGBColor[
              0.9847562209236621, 0.9602412951452857, 0.3952812261449029], 
             136 -> RGBColor[
              0.838510215788073, 0.8740693015886783, 0.9844590470004145], 198 -> 
             RGBColor[
              0.9945630146787792, 0.9907791630984755, 0.6495958848481754], 63 -> 
             RGBColor[
              0.9857957459759027, 0.9883941901754274, 0.8850647788177481], 
             171 -> RGBColor[
              0.9438210921265127, 0.9576224430092479, 0.9799804166107083], 59 -> 
             RGBColor[
              0.9908606739359661, 0.990488668049625, 0.8011258149061115], 229 -> 
             RGBColor[
              0.97918179300571, 0.9839943958271196, 0.9201239735700676], 102 -> 
             RGBColor[
              0.7223772811171819, 0.7830458893702035, 0.9729634744484087], 
             299 -> RGBColor[
              0.8997636318682448, 0.922911112891321, 0.9903014525077113], 128 -> 
             RGBColor[
              0.9936622523011817, 0.9888525234538409, 0.5515534589077112], 12 -> 
             RGBColor[
              0.849627820487435, 0.8829341777966093, 0.9855194540614425], 222 -> 
             RGBColor[
              0.6136725214830678, 0.6972460244288244, 0.9627296953291138], 92 -> 
             RGBColor[
              0.9939780454794566, 0.9895279731305829, 0.5859255975133435], 
             271 -> RGBColor[
              0.9910587871669104, 0.9815013309966897, 0.4197655058601559], 
             132 -> RGBColor[
              0.8406373349817257, 0.8757654086945846, 0.9846619335280068], 80 -> 
             RGBColor[
              0.8247727272441194, 0.8631154011179225, 0.9831487530794913], 
             244 -> 
             RGBColor[
              0.7032471876367785, 0.768101314949217, 0.9710567655111697], 150 -> 
             RGBColor[
              0.9673937984340938, 0.9752029287766779, 0.9400779735784334], 
             125 -> RGBColor[
              0.9942995796905422, 0.9902157022959995, 0.6209226121108762], 
             258 -> RGBColor[
              0.9861758061154947, 0.9885513548102488, 0.8787661987405977], 
             133 -> RGBColor[
              0.4425172738388731, 0.5577079538595131, 0.9494177872797201], 
             255 -> RGBColor[
              0.8203588521220603, 0.15749263548184916`, 0.16712896582510686`],
              176 -> RGBColor[
              0.9736236277838297, 0.9798491253053015, 0.9295324974890509], 
             230 -> RGBColor[
              0.8096206802513948, 0.8512010958482423, 0.9816590811381882], 
             274 -> RGBColor[
              0.7029347548581498, 0.7678572400879752, 0.9710256251316464], 87 -> 
             RGBColor[
              0.6579427799559914, 0.7327091673427348, 0.9665412455473096], 
             130 -> RGBColor[
              0.965130537518458, 0.9735149924915464, 0.9439090839556193], 35 -> 
             RGBColor[
              0.9713625622461046, 0.9150613394452755, 0.3432493913628023], 31 -> 
             RGBColor[
              0.9786091619983263, 0.9395058219920551, 0.37140106299464704`], 
             18 -> RGBColor[
              0.6538156177699137, 0.7294849968753766, 0.9661298885911248], 24 -> 
             RGBColor[
              0.8520111650289094, 0.8848345920398168, 0.9857467795914451], 
             151 -> RGBColor[
              0.9724571419814801, 0.9789791621038545, 0.9315070536842063], 
             137 -> RGBColor[
              0.9941627915789626, 0.9899231263567303, 0.6060340703238073], 
             296 -> RGBColor[
              0.8161944366879319, 0.8563365643388644, 0.9823142917445357], 
             266 -> RGBColor[
              0.7157083217704143, 0.7778360476425404, 0.9722987749056913], 
             283 -> RGBColor[
              0.9791295138791556, 0.9839554061401345, 0.9202124684947441], 
             284 -> RGBColor[
              0.9845230632192228, 0.9878679031490853, 0.9061564256933312], 
             238 -> RGBColor[
              0.9069172153380773, 0.668664807354358, 0.24396161040848696`], 
             72 -> RGBColor[
              0.8319281510392084, 0.8688209418233217, 0.9838312437887892], 
             288 -> RGBColor[0.178927, 0.305394, 0.933501], 172 -> 
             RGBColor[
              0.9877415040805252, 0.9891988111553912, 0.8528185315635947], 
             243 -> 
             RGBColor[
              0.8477486806111797, 0.8814358026671765, 0.9853402200225173], 88 -> 
             RGBColor[
              0.8490620027099094, 0.8824830100595249, 0.9854654858567107], 
             273 -> RGBColor[
              0.9859028956958801, 0.9884384993382602, 0.8832890306631379], 
             202 -> RGBColor[
              0.7898069674918937, 0.8357224728507257, 0.9796842354199943], 98 -> 
             RGBColor[
              0.9504601324030899, 0.8412979637001735, 0.2789972635626222], 30 -> 
             RGBColor[
              0.8208004069783359, 0.8599479807637479, 0.9827698696264088], 
             116 -> RGBColor[
              0.9932268218872813, 0.987921181827276, 0.5041595455196706], 240 -> 
             RGBColor[
              0.690629475369693, 0.7582442622280048, 0.9697991498716118], 73 -> 
             RGBColor[
              0.7019988963046534, 0.7671261402731954, 0.9709323474971292], 29 -> 
             RGBColor[
              0.6362709602742411, 0.7155924550875649, 0.9645087272115639], 75 -> 
             RGBColor[
              0.9521637444961126, 0.963844379486656, 0.9658584822611943], 200 -> 
             RGBColor[
              0.993182382864256, 0.9914487543566707, 0.762649089574246], 156 -> 
             RGBColor[
              0.3573833176626465, 0.4839691999767193, 0.9439931268731725], 25 -> 
             RGBColor[
              0.945247068878971, 0.9586859341364088, 0.9775666099230976], 38 -> 
             RGBColor[
              0.9393898537746044, 0.9543176327018816, 0.9874813472884296], 3 -> 
             RGBColor[
              0.9631955369450624, 0.9720718722321805, 0.9471845351974016], 57 -> 
             RGBColor[
              0.9663230142674084, 0.8980617607709968, 0.3236716991043483], 
             227 -> RGBColor[
              0.9709187056389151, 0.9778317987985278, 0.9341112251237087], 39 -> 
             RGBColor[
              0.9838855174256722, 0.9875024257978855, 0.9121617950548794], 
             109 -> RGBColor[
              0.6567881182926985, 0.7318071368756167, 0.9664261596636393], 
             256 -> RGBColor[
              0.2522743523564202, 0.3824867178173366, 0.9376780232090142], 
             287 -> RGBColor[
              0.882927864495217, 0.9094867289827998, 0.988695641986205], 239 -> 
             RGBColor[
              0.5930154151230221, 0.6804756548937028, 0.9611034922469771], 
             285 -> RGBColor[
              0.7157083217704143, 0.7778360476425404, 0.9722987749056913], 
             216 -> RGBColor[
              0.7241907422090963, 0.7844625789580217, 0.9731442233022932], 21 -> 
             RGBColor[
              0.9869881295438769, 0.9888872714236447, 0.8653038973066597], 
             175 -> RGBColor[
              0.9402558625324343, 0.8008414340343819, 0.27078666849969407`], 
             7 -> RGBColor[
              0.9870838309064348, 0.9889268463964752, 0.8637178780618887], 13 -> 
             RGBColor[
              0.940126630351698, 0.9548671194667171, 0.9862341767255174], 294 -> 
             RGBColor[
              0.9708118929918796, 0.9777521381012584, 0.9342920310739399], 
             193 -> RGBColor[
              0.8122478425780797, 0.8532534550250217, 0.9819209321266844], 60 -> 
             RGBColor[
              0.358220172469528, 0.4846940415488944, 0.9440464505214654], 65 -> 
             RGBColor[
              0.9109136900522419, 0.684509497849769, 0.24717726777282212`], 
             69 -> RGBColor[
              0.620132044082581, 0.7024901558732861, 0.9632382126101584], 217 -> 
             RGBColor[
              0.8954694095656961, 0.9194870165908279, 0.9898918657509967], 
             214 -> RGBColor[
              0.9295031042513959, 0.9466245609131729, 0.9931380299323567], 
             170 -> RGBColor[
              0.8410747509036739, 0.8761141922774073, 0.984703654649128], 74 -> 
             RGBColor[
              0.8786739997174374, 0.9060948126770817, 0.9882899045662304], 
             246 -> RGBColor[
              0.9813517134831237, 0.985612718966256, 0.9164508642077064], 264 -> 
             RGBColor[
              0.979815670246321, 0.9844671404352885, 0.9190509847433752], 278 -> 
             RGBColor[
              0.9941567194738415, 0.9899101387378605, 0.6053731591540727], 45 -> 
             RGBColor[
              0.7228796924284554, 0.7834383769050377, 0.9730135501126157], 
             237 -> RGBColor[
              0.9684731892793204, 0.9760079367017075, 0.9382508464276845], 
             228 -> RGBColor[
              0.985845646212203, 0.9884148252055153, 0.8842378027645792], 180 -> 
             RGBColor[
              0.525961613910297, 0.626038358329892, 0.9558247713893443], 53 -> 
             RGBColor[
              0.9398423322838397, 0.9546550904332037, 0.9867154191975899], 48 -> 
             RGBColor[
              0.7355925767768008, 0.7933697787794648, 0.9742806516158], 5 -> 
             RGBColor[
              0.9930300212908642, 0.9875002452511322, 0.4827390151121649], 
             101 -> RGBColor[
              0.8199956978278649, 0.8593063275304104, 0.9826931157492645], 
             267 -> RGBColor[
              0.9843763134513034, 0.9878072183487536, 0.9085884491239797], 
             120 -> 
             RGBColor[
              0.4363011627406259, 0.5523238708570395, 0.949021702177231], 147 -> 
             RGBColor[
              0.7544887762703004, 0.808131633440222, 0.976164048186288], 89 -> 
             RGBColor[
              0.9864547092367454, 0.9886666884183692, 0.8741440522433324], 43 -> 
             RGBColor[
              0.8999392186662244, 0.9230511210378533, 0.9903182001332508], 
             199 -> RGBColor[
              0.8899686128338622, 0.9151008305920131, 0.9893671948480952], 
             268 -> RGBColor[
              0.9545445611402682, 0.9656199886416378, 0.9618283806990687], 
             169 -> RGBColor[
              0.9533862423231773, 0.8528990144649918, 0.281351680288952], 20 -> 
             RGBColor[
              0.9766100437712765, 0.9820763894589319, 0.9244772742043387], 4 -> 
             RGBColor[
              0.8292615980775258, 0.8666947048733279, 0.983576905586844], 167 -> 
             RGBColor[
              0.6845930918336023, 0.7535285935313967, 0.9691974995739456], 
             142 -> RGBColor[
              0.8651368615626388, 0.8953006661682716, 0.9869987202442798], 16 -> 
             RGBColor[
              0.9225365244751187, 0.9410695993023398, 0.9924735513341562], 
             281 -> RGBColor[
              0.26265077169382917`, 0.3933929924439381, 0.9382689449397429], 
             289 -> RGBColor[
              0.9055983112756845, 0.92756352787266, 0.9908579694382728], 178 -> 
             RGBColor[
              0.6012014939635917, 0.6871214824751263, 0.9617479303599016], 58 -> 
             RGBColor[
              0.8600258076535335, 0.8912252505170136, 0.9865112233597377], 
             186 -> RGBColor[
              0.9380007763931056, 0.9532816610651653, 0.9898326929659028], 
             122 -> RGBColor[
              0.9925888590267843, 0.9865566437766122, 0.43472122520496925`], 
             249 -> RGBColor[
              0.9404126837890086, 0.9550804576518938, 0.9857499628708358], 
             113 -> RGBColor[
              0.9568240638139651, 0.9673200380033379, 0.9579697772620142], 52 -> 
             RGBColor[
              0.9337461264621959, 0.9500078316502951, 0.9935427331786134], 
             187 -> RGBColor[
              0.7175990333729405, 0.7793130859163742, 0.9724872233685266], 
             259 -> RGBColor[
              0.94701870472402, 0.9600072172488588, 0.9745676925540611], 42 -> 
             RGBColor[
              0.8960115772376082, 0.6206946839967139, 0.23494184986862096`], 
             134 -> RGBColor[
              0.992371383899417, 0.9911133854429871, 0.7760894412196707], 248 -> 
             RGBColor[
              0.9904220855493537, 0.9903073004805534, 0.8083943595026393], 
             174 -> RGBColor[
              0.7264903655056463, 0.786259062155071, 0.9733734282612918], 215 -> 
             RGBColor[
              0.8616108732128943, 0.46448912150904126`, 0.20623705919198235`],
              83 -> RGBColor[
              0.4106940114905117, 0.5301442434970352, 0.9473900371430886], 95 -> 
             RGBColor[
              0.9404605733653404, 0.9551161736195101, 0.9856688983097077], 
             166 -> RGBColor[
              0.8835534361133671, 0.9099855428104235, 0.9887553095655985], 
             233 -> RGBColor[
              0.660153046877239, 0.7344358446602642, 0.9667615442979008], 295 -> 
             RGBColor[
              0.6579427799559914, 0.7327091673427348, 0.9665412455473096], 
             141 -> RGBColor[
              0.9708118929918796, 0.9777521381012584, 0.9342920310739399], 
             205 -> RGBColor[
              0.942481011669382, 0.9566230131985003, 0.9822488232756708], 224 -> 
             RGBColor[
              0.4418661436524164, 0.557143977618759, 0.949376297840011], 231 -> 
             RGBColor[
              0.9414414820544251, 0.9558477337137389, 0.984008475761047], 68 -> 
             RGBColor[
              0.2700166025735334, 0.4011349477191588, 0.9386884181115718], 10 -> 
             RGBColor[
              0.9530185259250165, 0.9644818740767565, 0.9644115602647617], 
             250 -> RGBColor[
              0.9905230264617029, 0.9903490421418728, 0.8067215073583075], 
             282 -> RGBColor[
              0.8365864049561007, 0.8725353070517176, 0.9842755522058547], 
             232 -> RGBColor[
              0.6332753318106321, 0.7131604689492826, 0.9642729003655599], 
             253 -> RGBColor[
              0.9883790193525103, 0.9894624401037523, 0.8422532536701659], 55 -> 
             RGBColor[
              0.938012953324855, 0.7919490464315171, 0.26898197110343025`], 
             91 -> RGBColor[
              0.9951541499035746, 0.9922641306995306, 0.7299718069632111], 
             105 -> RGBColor[
              0.660153046877239, 0.7344358446602642, 0.9667615442979008], 36 -> 
             RGBColor[
              0.2700166025735334, 0.4011349477191588, 0.9386884181115718], 
             123 -> RGBColor[
              0.975816536273443, 0.9814845928662971, 0.9258204754182696], 94 -> 
             RGBColor[
              0.9945769405148216, 0.9908089490536524, 0.651111626161101], 96 -> 
             RGBColor[
              0.933135039649653, 0.949520567613483, 0.9934844471729095], 2 -> 
             RGBColor[
              0.995000614253539, 0.9917151443407831, 0.6972258980092602], 262 -> 
             RGBColor[
              0.8365864049561007, 0.8725353070517176, 0.9842755522058547], 
             272 -> RGBColor[0.817319, 0.134127, 0.164218], 97 -> 
             RGBColor[
              0.9929642647042682, 0.9873595985614142, 0.47558181646380854`], 
             209 -> RGBColor[
              0.9938161735589365, 0.9891817454603522, 0.5683068379224331], 66 -> 
             RGBColor[
              0.8311241534426388, 0.8681798559637505, 0.9837545577802913], 
             139 -> RGBColor[
              0.9877415040805252, 0.9891988111553912, 0.8528185315635947], 56 -> 
             RGBColor[
              0.995143074044988, 0.9920198514297981, 0.7127317671485611], 144 -> 
             RGBColor[
              0.49260100572952575`, 0.5989547137304699, 0.9531985021094197], 
             298 -> RGBColor[
              0.5433134973077871, 0.6401253989654134, 0.957190775212438], 204 -> 
             RGBColor[
              0.9874868608749021, 0.9890935096458342, 0.8570386284762607], 
             207 -> RGBColor[
              0.4963625980753121, 0.6020085438545834, 0.9534946284380468], 
             149 -> RGBColor[
              0.867995913860049, 0.8975803968633195, 0.987271419204713], 219 -> 
             RGBColor[
              0.8790587431867711, 0.9064015966759452, 0.9883266017418001], 9 -> 
             RGBColor[
              0.5061207195781898, 0.6099306264889837, 0.9542628235079301], 11 -> 
             RGBColor[
              0.9633908767620196, 0.9722175563478277, 0.9468538758400769], 44 -> 
             RGBColor[
              0.892425658243354, 0.917060011906821, 0.9896015500326829], 153 -> 
             RGBColor[
              0.7271941485241836, 0.7868088627981015, 0.9734435747753534], 32 -> 
             RGBColor[
              0.9863186895293484, 0.9655118686373406, 0.4013511216305565], 
             162 -> RGBColor[
              0.967740626625343, 0.9754615926738325, 0.9394908839179281], 90 -> 
             RGBColor[
              0.9836592448586059, 0.9873336720878548, 0.9125448154895855], 8 -> 
             RGBColor[
              0.7530764606636936, 0.8070283217543445, 0.976023281765461], 163 -> 
             RGBColor[
              0.6012014939635917, 0.6871214824751263, 0.9617479303599016], 49 -> 
             RGBColor[
              0.8645006017736806, 0.8947933298833682, 0.9869380332176132], 76 -> 
             RGBColor[
              0.9877307813373964, 0.9891943770255456, 0.8529962351668088], 82 -> 
             RGBColor[
              0.4669334037501397, 0.5781165981313124, 0.9511778544580783], 67 -> 
             RGBColor[
              0.9042414356109009, 0.9264815920489704, 0.9907285494260685], 
             211 -> RGBColor[
              0.9384669296042303, 0.9536293173667663, 
               0.9890436171716979]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJwtl3k4FGrYxsc2dmbMmGEYZp8hUUJS8qQSUSklLeLUoUhCylJkaUGShISD
EspOCIknVNoplWQLSUhOpwWJz3d931/vX8/1Xtf73O99/2723sNb3MQJBIKe
GIHwv6cq42jri19aYJTSZkhRoiEx2zPzcZEc0PRFRmZLuGjE3eU9mcABx4mG
qEMxGjgubhPxLl4W9qiolb7MpaK/xaNMTjkLyA7XHjv7qWNuqfR/yzmK0AU5
zgfM5LC0cRs97l81iLkxKnYqTgUN/Sol9uVJgn2hl/2y2fn7bk/W8QV8IOQY
R/fRZxqskldcv7tXCIU1T6+VnOXh61PSupdfcmBrQ2SUnqE6/rRRimS4UMDS
p0mUncNAIlXamb6CCqeuYcFIhyKmn+/Yyf/6x8LcrddI2ZyGLVLn72esI8Fv
/ngyU0cF/crnPj28JA+bD3YnpKzTwmyvlvJDPmx4/dRWcmIpGe0efuiB20Tw
7Vx7r7WFi3ZhNyWO1/6wIBaeL5Co08U/PqpdUbf58Pu2M580x0ZdU8X6bwoi
iBlk6iwVp+LKKjFf3U4hPJ9yJjno8/DtgZjmwjY2HFhrJQolaOGEaU5hnjEL
rmgni+6HamJpmYcfN0IHvtLjyzMvq2FI7S7jMaICOKkqXjfv56J9pdGIY6YG
rM9m5N7JU0N2YpzSf866YMs5dtYnVQ1lNv9zWqmXD5KUQEd+BhFfnhkp/dIv
AP/kn72Fusp451C6RK0ZF/beOjH74DoLtY+e0NP/ow6ODSV/UgtUcFF88uTL
VHG4d8vAOFCfjXv6isrSFyvCzDIrl2ILcSx/v8ymX1wOqr0anPbk8/CwF3dD
a6AQur5FXfjzlIM/VvMtZP7iwxWg2eRLczCQeFJ4x1kBDH0ow7x9Uig+/qAu
JEcKPLpvVwSv00R3S2uHXR5sKEnPzDBOJuPz0eJf0qpCuJN5mTQ7/54Rx4qX
KSZowjZJz8H+Agqyb59wpSbwofTeqY+LTypgjO2W1cFyPJjWNS3Wz2PhYG6k
5ptmLtAOSBzRXkTEwr2VktOKCuB39kXqs2plnLs8nTsyxoewBb/VOZ5TDZIa
Rhk/rYTQJwgws67lYt+gGW1BnCK0cPxomRlsNCF4tN3oEIFP/moZzUIG7ncd
YaSNs2FNkQUt3kwdP+G3K3IByvDduCS7vp+IFcH2x2/cIoH4b8EqvSkZbB9p
ev/ajATRG93k3u9mo1+wzVZ6qgAkTS+ZGvWysHrV3wM/lpMBw9OPrF9NwKSw
yf3/jChAlpTlx4QVsw1B0tq6R8x04HNtY80PCg3jnI96n2xmw24V/0Vno5m4
eP3iiJ8DKkB77P42jkvClx7G+98m8YBUb55b3M3GrAb9DKKNHGwLk1FNqiJj
sMuphplhAWRZ1XT5FPMwt8Vmc0WnDNTvH1uhkKKOROa6hMkOLmS57RtcZq+F
tfWjrhPLeJDt21HXvoiC7YOD0WENfyxovepJI3/U8NgQW1c0QwPz60a7g4Xa
OJj9KeqzARECX7RUpIUxkNWTcrKzVQCeZcdd7FPY+PBMPSwP5EMHczQkJp+D
y+r0HncSWfC+0yf3xEom8u7kd5ZVC+FWbN63d1Z8HDi0894vUxHYl/TcEfNS
xMdKsp+H5VWAOeuv2ajHRkqnktITpjIUnZo7TKRo4ve/szdodVHB9bNQSb6S
jBxKVWnsDT4YPpa6vW8FEfWkuV9sXXRhKE6qOnSROvr9SNP6slQDdk7X2UWw
VXDhmkb/kSAt6Ax5O350qwo2//pr4twqOnjL00Re/1DQU1XDvWw1C1prYm/E
ZWlgM3+CMHVOGW6E5df/pUrA2o05BnodcmBhN2R6lq2GuxVEpCQlDqQb6lYu
fERC4vRIsvFKBhxRvBzk2aOGqTmr2/ItSdDx3dDbsl4BUw1OuHlKcmFra9N2
pqoMTq/eHBfEloLY+88v95kzscwIm6h+VCh6pWS8mE/HxGfHTOvITLCsiurc
eY2K7oZGJdruZEhTlJaecyPj2er7dkWSbNh68OfpwxQl7Hm9WjB6igIK1dSd
4kqKiEn54TWqAmCtLvjBjSeg19oVltu8OBDRdN7GV6CM9v/vd5obvypqb2Tj
7GuZw4GF8/uUrNC9elMWPyR69H8bFULYQ/W/6a94KLnAY2diKAcuT2t8f+zO
QJmvnGbDRlmY1DEoS3rARRPl7/tbvlLB8UpAtJcvGYczlr4Jr+BBQ1zSyK0e
GnqVFzMHs8hAPJw9cH5YHRPizHRkkzmQEZDoYOunibdYKUJjARWqe72iH8+R
cOK4Sk47iQ8GedJwoZ6FE98MLpA71cFa20GwJI2J3x9ySioiyWD/M8WFafW7
odMkoOCkFxX6fW+L/NaxcMGMi8yrXD64nvYWUVdPNayot5DJWSgEcnXw3fB2
NXRf2jgnG82Hb6ZHqXZuDEw54QF2kzy4f4//D2+Mgf7Pw8TG4nlwXJX/ziRO
DS21wxLlqmRB5OXIrrZVRpP7Oz4U/BKDpIabXvXeGgir8lqaDESg4Lskdixn
/v8V6duXmXJBpu6DiT9bDqdvOFVufSEHe8QP2EYG0BFH+NuvNQtBZdR41WQ+
F91Pz3Fb74qgT3HnJrRSxpsn40y7exUgtqF29FKiNP72abur6s0E4peLBhe/
UnBWjC907ZOG5Q+5d6ivtNCQYtmjbUOFqGxG0iRZGek7x36/PagFo8OrvPmu
qvicZSO6+EISvv9HNN9+m4cn1U8vCpzVgpX7HLdIIBlt/0SZBmTyIGxAe+rx
lATa32rKWQICMB1slTtkLIb9Tp/d7NYIwPr/dNPgNH76W1mQEKgalzQOKaqh
/TmtNMaIDKgzvspEhlPx01S7oLCaC1ctVvXqrWEhNeN4yFu2CphQCxU+usni
5Vf0c5Hz+txdU5mhx2Vj7gWHtuoVKnDtiIP0kSt0XNurd3/DdibMLWxOXh9N
wfjaO1/srs77V4LH4EuCFG5f88tthsiELcFDL+49ouNyeH+xa34+UbJjIVhq
4XW/R73n5HSguWHfugXN6njgxqKJLzJq4L5lrv+RJBk7LK+vfmDMB+uLtKfd
IbMNUnX+BW6LSIABmWxpMTmUjStkLdangCs/hZtdJo3TnYqh5cXa4JA0TpwJ
ouGJNaGOJl4M2Lu0afiLPBWXVDHvaG6lwveDmger+Bq47oGqvEK3ACY25BzL
3j+fP+9R6ZqnDFAX/jdr66yNZqojDjq2quATdWu52UEaWpZnkp6tZ8HaAdzn
ZaeJxc5aNozvqlDrf23Wo0sBM97PtJcUEEBQb725YIqFCiSvx5YtspDs22Ty
ik7GOx1P3x/qpcDWxkadV//KY2DQFxeGgQ4Ix1aYbxao4WPvkobzTgLgLlMy
bS/mon7IC/8DqSwY836r/dGNhgZ/Wcd1O1IhDRI185I1UVff2++tlS4Q1hd2
5NSp4p4idUKCuzx0CHN/alVzsXS9SoxhGAH8v+qaeC7RRDsLR/FzCxkw9Klr
aWspGa0fke7Oww1cFf3wzIogoYabgvh2Jy6kPxJc7cmi4cvne9N7OXzwX7hk
0u+2OAaGqJg1P5i0GAiTfmR5i43WTyPY2WoKkDiw4ZEjcrAwl0jvHpKAUesO
K+EvGnpeUd0dRlCGFc6XUgWJLMxPIHyp6yXCN9vskb838LE5znGqW1EHdG2K
n+xyoWPQSYXGEhceRNyalo05w8bTPZuXuUvwIJBqL2Z7VA7fkHb1/ZNOA623
5RrpQjJWGl6IrX8jgm8rXu7bfV4VpRsZq6u4DCDctPVJSaNhvEvWtgozHnQ9
2X/i3zo5HF7g4d35mQhKRceWMHt5qGv7UcrqhxiM7Q9rfHaKg+vT1K9GF1Og
8WN8o/0JFq7pDSt/uZcIEHlF1z2dgmFr/dt8nwjBcCD0XqSsKv6azdq0ZikX
KiJUuu6Xy+D4utIyLQsRdClbUXx2KyHGjcbdluBD/KV+WZsGCUy0Lz/1/I0K
tBq+aIkUEtH6sFCtci0ZGKU88yti2thSJj5h1ykAWt6MSRWDjuLRNo6xLhzg
JMt9mkzRRv9B57sre2YsTnTu2pWeooFy+7ZTYoLkIfSaVfnhMyRseB/jezRk
Pm9m3+iRvRjI/r2aeWA5G/7wqdc2x6tjif32lkezfDhxZMgx7LY0upXJxL8Z
5YFywUlJj2sMHBa1Hlb/pAkbdUKTQzVUMD5XSupXrRb42ajUxByj4Lac6e6G
JHX4smVWO+gpBTPTPl3tW8eF6qG/xvbd08AtoVba7BFVGGtxarxQoITeOb7T
RdECOLN4cEfeAga27CprrQcZyHp+rvmZtRLa7zgSePKwANqpVf9aN3FQYXaF
kLtPCHZo/HeSuwQmhHr+yXjCgf7vhkd6GVo4syo4tCCID5tXzuQbq2qj530t
/aWbSECQpe8CDgkJigqmXVqSYLZt5xKfRDqK3M5J7ZqQgePO5HCPR2T8M1tf
uD9cCEauD8wdxskY8vjEM6WtGlD6e/GK/l1UNB3b1lQcRYKKwdQZ52xxHC/1
GFnQpQazzcPsqkvaWAu35g46iCBhtPHZmxfaWOH14KhgDxnAdsjo7GZt9Hqw
3clsQAdC5qLir1bT0XXBxhB/L2lYr7HioPxxFl7I+vqp1V0ZWnaO578In2m4
XtKc3FctDQ6RC75kLpvvJ13BnKX/kiDRe8+H531K6PMfIXgXlQMDmiSXjqNM
NNvpNZzTwAKK+3++KTUM7KYP66VOz/Mhc82W3EI6Ptivk9zsJgCvB3s92qoU
UPtQTuVFGx3oDdbUeP2bhhOd/PGL0kKo0Et+O5TLxJZtW5hjHTqQmF8j5bGd
gQW6w5ue5Qqh9GeY790QZfxmXzSVf1ECzkku6V/apI6CleImhpdVYNHR8vMk
WSb6p59J0tfhA2nqbeX7K1Lo9vMzLSRPE65PBvBt96qgdYT2REi4HBwe9Z6Y
TeTgjfsPL4T9KwuGL0azwqo18M25wUFG8gLYOXh9/9wiBp7yMmZIpbMh/KWp
a3uw1ryfa9c5jwlht8vattnn8/Ppd4ctTOf13Chw4NupYbHVG4vPVwUQETj1
O0zIw7SoGOdj+iKYdO8O2COhjo+kN22PnN+n/aWemtLS6YYdoUNv0pqUwalu
uiK2VQL/VmcFjaI0XLG0H075oo2Frp050clEeGsk2mfMo+NQLK9OvVYErcG/
loIsB2lXQ1aqGFJAlLqZdKxSBhe3bwrY7jTfZxq7A8Ln+8XzNXV/pLgyEJ1Z
TbeW5aPfgZvbYmq44En46pBdPa//PfTzYkoqMNQc4fZXKRW33t/qpTXDhIcr
a25HvqOiWIRnm+MBHRg6fsHTSVwRk1QMHL5bk+FJy4XsDWZqKLU0S9bHRQji
l77vMDwviw+YhuPkvvm+3pi3bWWNLAbc7N0iacODIUxjbjaVwW6jbi/WJAmG
/e7nyPM56B0+oHPgJBEyLhOUywLUcElcFMFymA9aE4NHfx1noPmo6vp3A4pg
rPc6bvYdGXV4qeWqIULYm0NcuMmHg92zPRerngnB72XC0MGPMnjKV2HdBwkB
MFp127eYc1DvnpVj2oA6UHOvjN//TMaj4TW610vIUHci3+V6iSRWpRseuzJN
hrE0vbWpWVLomkaItT2tCyL9V7N5l6XwRsK2huI1ZFAsKDTZsJGEfYfb1tQ4
UEDyiW5CbQIVD8zGmMRO/7AQkMwrj+3m4K3BbFk3WRJw9ph/oM/n64dFBZr1
2Qx46nbDmHhaBRNGZIocd5Bhku36e6GnGBocMrN6Nc+r3wPd3x135WBtkHMP
pY4HDjPDP/naHHyaVZ3eDizoiGTR7o2ScMPj965r79JAxf9YQtw8r5mke77/
SODBZLp8m/kmTcSzL7/+W8kDvc/7HMXsZXFr3EHX15fFIV3rn8NvjbXR6LSv
fexDWVBZdmFPUqwqWv0R4y0fEEBhaubeuAoy3nB4psduFIHh3MJfW+fzf7Yn
lT7jT4aOOUWWZJE8lkfZZNAussBStvGOmkgLry1KE2nEs+HZgv64AroWXrxU
9OCKqyq4vz4zuieDhUHhBlRBBwNmUxRrGy+TsS0s7xHO87uClJFKLU8emyKc
eOerSeBkl1q6CcXwfCBlpTBLB0rbg5693qiKfXcz6ncc0QEyYTo7MYeONoH7
N5xZQIYukm1i30km+kR7WfSAFkTlauXRj9HQoVC+KvisEE7aNE61JZDwfwBO
YHOH
         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 5}], {
             RGBColor[
             0.9872969033120123, 0.9866355635279549, 0.6994154484974782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 32}], {
             RGBColor[
             0.9839412374312544, 0.9756413752210591, 0.6587215017566739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 51}], {
             RGBColor[
             0.9751672380435219, 0.9810003473095501, 0.9269195679574259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 80}], {
             RGBColor[
             0.9031682562886398, 0.9244431414613501, 0.9496203174811413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 83}], {
             RGBColor[
             0.696128898411836, 0.7579575626509063, 0.93174095951294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 92}], {
             RGBColor[
             0.9877709154063083, 0.9876494274676803, 0.7510087396980674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 125}], {
             RGBColor[
             0.9879316825118512, 0.9879932920503885, 0.7685072469968337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 128}], {
             RGBColor[
             0.987613018817171, 0.9873117026293092, 0.7338226703952513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 142}], {
             RGBColor[
             0.9233503234478995, 0.9405357739865245, 0.9515453010635355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 149}], {
             RGBColor[
             0.9247798495966046, 0.9416756393340485, 0.9516816505437522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 150}], {
             RGBColor[
             0.9744787918836271, 0.9804869052907277, 0.9280849277306124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 197}], {
             RGBColor[
             0.7192545581310688, 0.7778893562311587, 0.9332417193304356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 198}], {
             RGBColor[
             0.9880634000059697, 0.9882750224516266, 0.7828438833654834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 237}], {
             RGBColor[
             0.9750184873062403, 0.9808894092532425, 0.9271713641552379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 243}], {
             RGBColor[
             0.9146562329721699, 0.9336033422359771, 0.9507160509526543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 256}], {
             RGBColor[
             0.6169190688447902, 0.6841287998110571, 0.9268849525459028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 277}], {
             RGBColor[
             0.8327774014804655, 0.8694145651953227, 0.9426146861633016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 281}], {
             RGBColor[
             0.6221072785134947, 0.6895819371243579, 0.9271804134112671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 49}], {
             RGBColor[
             0.9297506080136098, 0.9432542371120757, 0.8420819656134366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 54}], {
             RGBColor[
             0.9622518592524675, 0.9691698526269781, 0.8451819639708085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 102}], {
             RGBColor[
             0.8586889476853605, 0.8873805168554934, 0.8350946862288344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 165}], {
             RGBColor[
             0.935736879306488, 0.9480275273480112, 0.8426529415133588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 172}], {
             RGBColor[
             0.9913710591670322, 0.9904569777480872, 0.7750222147864274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 174}], {
             RGBColor[
             0.8607454898795927, 0.8889871032479271, 0.835299663135276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 183}], {
             RGBColor[
             0.9900048575256639, 0.9898920182596007, 0.7976637116004084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 238}], {
             RGBColor[
             0.9509589147958082, 0.8301899758475706, 0.47059375420887356`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 253}], {
             RGBColor[
             0.9916898168030246, 0.9905887922222677, 0.769739575839713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 24}], {
             RGBColor[
             0.9076033509869859, 0.9284532321359986, 0.9664656573944234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 59}], {
             RGBColor[
             0.9770281054405143, 0.9812802701409027, 0.8741551750517565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 65}], {
             RGBColor[
             0.9370546134986522, 0.8282906850409748, 0.5971809014851119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 72}], {
             RGBColor[
             0.8975618439921353, 0.9204464070277512, 0.9655078894930954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 106}], {
             RGBColor[
             0.9079239253708089, 0.9287088494478993, 0.9664962340653326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 115}], {
             RGBColor[
             0.9777673274954117, 0.981585957457743, 0.8619043525567524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 155}], {
             RGBColor[
             0.9398935901858076, 0.8395462815726471, 0.5994652087669449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[
             0.9654680817852027, 0.9737667324530065, 0.9433377095576649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 169}], {
             RGBColor[
             0.9582908896341198, 0.9124854433485862, 0.6142681077431769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 194}], {
             RGBColor[
             0.9746497974138966, 0.9802967786521679, 0.913569893916685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 200}], {
             RGBColor[
             0.9781889599046591, 0.9817603132944256, 0.8549168123858238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 210}], {
             RGBColor[
             0.9669414403705243, 0.9748655608735362, 0.940843697786178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 227}], {
             RGBColor[
             0.9670571212919887, 0.9749518355153541, 0.9406478801605551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 228}], {
             RGBColor[
             0.9745205915786328, 0.9802433487188479, 0.9157111689809905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 241}], {
             RGBColor[
             0.8088971215670733, 0.8510843118661526, 0.956696237361886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 264}], {
             RGBColor[
             0.9715056035956917, 0.9782695063337346, 0.9331177599703884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 290}], {
             RGBColor[
             0.8036582339473166, 0.8469916530405781, 0.9561740740041369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 291}], {
             RGBColor[
             0.8948950324123405, 0.9183199638626945, 0.9652535266239237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 8}], {
             RGBColor[
             0.7911690293706097, 0.8368615133138362, 0.9798000936761525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 15}], {
             RGBColor[
             0.907008909500594, 0.9134680000093067, 0.6894290658658735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 62}], {
             RGBColor[
             0.9109685218063512, 0.9267182742180764, 0.713861268940172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 85}], {
             RGBColor[
             0.9112470744413047, 0.9273140701382504, 0.7441800042272653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 121}], {
             RGBColor[
             0.8100401886225941, 0.8516038063476088, 0.9816809944693806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 135}], {
             RGBColor[
             0.9098110631412768, 0.9284882749050254, 0.896495714795132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 158}], {
             RGBColor[
             0.8463715499416651, 0.6698389569631827, 0.5956874315650266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 173}], {
             RGBColor[
             0.8758143188404421, 0.9038145807697352, 0.9880171456513154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 186}], {
             RGBColor[
             0.8836311872353158, 0.9099881829692467, 0.9867047992763733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 213}], {
             RGBColor[
             0.7599455367236094, 0.8124694835506663, 0.9766880277292278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 214}], {
             RGBColor[
             0.8793823511644608, 0.9066596328932504, 0.9883574677596003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 249}], {
             RGBColor[
             0.8848371409332672, 0.9108875812626108, 0.9846634342288398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 255}], {
             RGBColor[
             0.8248102250997931, 0.5120936701775886, 0.5753529357059755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 263}], {
             RGBColor[
             0.8967696648752339, 0.919786838080815, 0.9644647836957674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 265}], {
             RGBColor[
             0.9047964580085088, 0.9257732072569439, 0.950877516644069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 276}], {
             RGBColor[
             0.8469509354462058, 0.8807997023268419, 0.9852641303765266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 286}], {
             RGBColor[
             0.9117808990295038, 0.9284558669544631, 0.802283516269251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.9782104490264418, 0.97985890079948, 0.7147964454761209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 23}], {
             RGBColor[
             0.6315233119321988, 0.6943175964851456, 0.7107137166118683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 51}], {
             RGBColor[
             0.9809003560223739, 0.9818650290327275, 0.7102431345721127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.9919453476134151, 0.9889944566503786, 0.6419324150091381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[
             0.7018620163906879, 0.7588222443740837, 0.7150645261276267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 92}], {
             RGBColor[
             0.9935040333851604, 0.9885141091908576, 0.5343323063127542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 101}], {
             RGBColor[
             0.9065128595593646, 0.9234032863907713, 0.7327160654307148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 128}], {
             RGBColor[
             0.9933461367960229, 0.9881763843524866, 0.517146237009938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 142}], {
             RGBColor[
             0.9290834414267515, 0.941400455709702, 0.7348688676782223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 149}], {
             RGBColor[
             0.9305129675754567, 0.9425403210572258, 0.7350052171584389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 197}], {
             RGBColor[
             0.7249876761099208, 0.7787540379543361, 0.7165652859451225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 198}], {
             RGBColor[
             0.9937965179848216, 0.9891397041748038, 0.5661674499801701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 204}], {
             RGBColor[
             0.9902584410828832, 0.9882968774484833, 0.6698888217942127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 226}], {
             RGBColor[
             0.9916363194652764, 0.988866665569462, 0.6470538111630089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 243}], {
             RGBColor[
             0.9203893509510219, 0.9344680239591543, 0.7340396175673412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 256}], {
             RGBColor[
             0.6226521868236422, 0.6849934815342344, 0.7102085191605896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 290}], {
             RGBColor[
             0.8185754761202175, 0.854705839550054, 0.7239513139615186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 38}], {
             RGBColor[
             0.8023567367769079, 0.8463963841054882, 0.977379122985724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 52}], {
             RGBColor[
             0.7995348731207037, 0.844241483579695, 0.9804098159308159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.8025829760315255, 0.8465651129711492, 0.9769961589403042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 88}], {
             RGBColor[
             0.7571928112445604, 0.8104790727843099, 0.9763711922698646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 93}], {
             RGBColor[
             0.8190347591009621, 0.8588348258470127, 0.9491475815159796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 124}], {
             RGBColor[
             0.7640836795147196, 0.6042812068752441, 0.5872713457584319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 147}], {
             RGBColor[
             0.7099061980247559, 0.7733033844746584, 0.9717204734346532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 273}], {
             RGBColor[
             0.8256132577375457, 0.8634568174236774, 0.9252829646730782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 289}], {
             RGBColor[
             0.7854609655274479, 0.8330193316908774, 0.9790674340606456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 42}], {
             RGBColor[
             0.9415477040720215, 0.8048107651965946, 0.5493298639652548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 60}], {
             RGBColor[
             0.6726520016879813, 0.7368104439726848, 0.903882164291677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 77}], {
             RGBColor[
             0.9367279314627791, 0.9505799305367005, 0.9263710139105843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 80}], {
             RGBColor[
             0.9059282790752772, 0.9260211237571989, 0.92343331557069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 81}], {
             RGBColor[
             0.9822226127462215, 0.9621118279585303, 0.6151358001403922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 82}], {
             RGBColor[
             0.7270086173282873, 0.7835217222638938, 0.9074478662599835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 103}], {
             RGBColor[
             0.9662074850474225, 0.9738377400160056, 0.9205710894400772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 127}], {
             RGBColor[
             0.9825895439644862, 0.9860554527331921, 0.8928405368187486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 130}], {
             RGBColor[
             0.9761071842124465, 0.9812209194440108, 0.903813481008754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 140}], {
             RGBColor[
             0.7442557352284013, 0.7975237095490135, 0.908805622559355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 145}], {
             RGBColor[
             0.9662143587510137, 0.9738428664128892, 0.9205594540528463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 154}], {
             RGBColor[
             0.9872918961060515, 0.9890128867035485, 0.8602696992487626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 167}], {
             RGBColor[
             0.8358384613700185, 0.871227719963936, 0.9164576888179172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 168}], {
             RGBColor[
             0.9831598742666232, 0.9864808041386957, 0.8918751163831966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 181}], {
             RGBColor[
             0.9891270954169955, 0.9897717887810948, 0.8298556973228484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 201}], {
             RGBColor[
             0.9058680422013081, 0.9259730925089824, 0.9234275701238768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 202}], {
             RGBColor[
             0.8884453991991643, 0.9123246596236004, 0.9217010567409415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 203}], {
             RGBColor[
             0.947000523122256, 0.8287958268754165, 0.5538397442351879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 205}], {
             RGBColor[
             0.9647824212879084, 0.9727749297974877, 0.9229833506687797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 216}], {
             RGBColor[
             0.8556372865577655, 0.8866947126772484, 0.918431050682091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 237}], {
             RGBColor[
             0.9777785100928775, 0.9824673915490914, 0.9009843622447866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 255}], {
             RGBColor[
             0.9037213415142475, 0.5732097409391622, 0.5154234219434978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 269}], {
             RGBColor[
             0.9843533355438867, 0.9873708856051653, 0.8898548977453427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 282}], {
             RGBColor[
             0.9118351179312678, 0.9307310767240964, 0.9239967151338717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 293}], {
             RGBColor[
             0.9582649596940837, 0.9677529722412852, 0.9284252348896181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 299}], {
             RGBColor[
             0.9434237313873398, 0.955918979643898, 0.9270096652848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 14}], {
             RGBColor[
             0.8728893139081436, 0.896913660077427, 0.7115386986040408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 64}], {
             RGBColor[
             0.8343741862834216, 0.8713121326633703, 0.9839210401121954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 67}], {
             RGBColor[
             0.8286589481372972, 0.8667549569016575, 0.9833759155957648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 69}], {
             RGBColor[
             0.6866042523731373, 0.7547592388138153, 0.9696307471878097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 85}], {
             RGBColor[
             0.8731545057343886, 0.8974808785787587, 0.7404031923165738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 121}], {
             RGBColor[
             0.7719476199156781, 0.8217706147881172, 0.9779041825586892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 135}], {
             RGBColor[
             0.8717184944343608, 0.8986550833455338, 0.8927189028844404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 173}], {
             RGBColor[
             0.837721750133526, 0.8739813892102435, 0.9842403337406239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 186}], {
             RGBColor[
             0.8455386185283996, 0.8801549914097548, 0.982927987365682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 213}], {
             RGBColor[
             0.7218529680166933, 0.7826362919911747, 0.9729112158185365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 234}], {
             RGBColor[
             0.5794901576376081, 0.6665117860615423, 0.961554047173995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 249}], {
             RGBColor[
             0.8467445722263511, 0.8810543897031191, 0.9808866223181485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 263}], {
             RGBColor[
             0.8586770961683179, 0.8899536465213231, 0.960687971785076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 286}], {
             RGBColor[
             0.8736883303225877, 0.8986226753949713, 0.7985067043585595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 45}], {
             RGBColor[
             0.6145002060033227, 0.6966845016970107, 0.9636381868102729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 47}], {
             RGBColor[
             0.6977822192395515, 0.7623064604533647, 0.9717899767520611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 96}], {
             RGBColor[
             0.7196278796139215, 0.7797255970512333, 0.9738736353404198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 112}], {
             RGBColor[
             0.379197535967305, 0.4962086721531601, 0.9459704233584721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 132}], {
             RGBColor[
             0.6733790272799578, 0.7428480175917842, 0.9694623785179685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 133}], {
             RGBColor[
             0.4743189967085315, 0.5838192901742484, 0.9518403053938251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 141}], {
             RGBColor[
             0.7384663062850347, 0.793841382295121, 0.944277427290935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 146}], {
             RGBColor[
             0.6027817795357849, 0.6875299778772305, 0.9624702035749103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 236}], {
             RGBColor[
             0.6345405724798157, 0.7123401883008734, 0.9656356232527772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 22}], {
             RGBColor[
             0.9729931943589879, 0.9759245842930293, 0.7201925032388871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 48}], {
             RGBColor[
             0.8443055513509086, 0.8789258264281106, 0.9693461059402808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 63}], {
             RGBColor[
             0.9694071359504596, 0.9764380321260919, 0.9247381695412549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 71}], {
             RGBColor[
             0.9092382881617138, 0.9300193237521172, 0.9757204578934631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 73}], {
             RGBColor[
             0.8275087111148349, 0.865804007174976, 0.9676719538809455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 100}], {
             RGBColor[
             0.8163692663454785, 0.8571017882582388, 0.966561678130366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 119}], {
             RGBColor[
             0.9461049635195544, 0.9593257505546823, 0.9761144180713475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 122}], {
             RGBColor[
             0.9728036924759004, 0.9755192589266843, 0.6995663927348654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 161}], {
             RGBColor[
             0.9394801441826849, 0.9541333588499261, 0.9786049531179669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 244}], {
             RGBColor[
             0.8281328567808974, 0.8662915945129868, 0.9677341628879657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 266}], {
             RGBColor[
             0.8343634238477153, 0.8711589608596484, 0.9683551675852264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 51}], {
             RGBColor[
             0.9660807837579516, 0.9742236845810752, 0.9423005649360687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 101}], {
             RGBColor[
             0.8916932872949422, 0.915761941939119, 0.9647734957946708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 104}], {
             RGBColor[
             0.9787118660497708, 0.9809313811113428, 0.7693725940782989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 114}], {
             RGBColor[
             0.9589852012249005, 0.9689318107458759, 0.9543115353402101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 116}], {
             RGBColor[
             0.9783088493246505, 0.9800693690875518, 0.7255067106798737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 149}], {
             RGBColor[
             0.9156933953110343, 0.9348989766055735, 0.9670626475223949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 197}], {
             RGBColor[
             0.7101681038454984, 0.7711126935026837, 0.9486227163090785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 198}], {
             RGBColor[
             0.9789769457203994, 0.9814983597231516, 0.7982248803441261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 204}], {
             RGBColor[
             0.9754388688184609, 0.980655532996831, 0.9019462521581687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 243}], {
             RGBColor[
             0.9055697786865997, 0.9268266795075021, 0.9660970479312971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 254}], {
             RGBColor[
             0.9700004602666481, 0.9771469729033798, 0.9356655750222078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 283}], {
             RGBColor[
             0.9712601953205876, 0.9780864812439811, 0.9335331721674105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.8860821724812769, 0.9120018885494745, 0.9889965026977994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 27}], {
             RGBColor[
             0.9028094055283609, 0.9248164555690491, 0.9724497035131984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.8826498661952924, 0.9092650606845027, 0.9886691262601861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 76}], {
             RGBColor[
             0.9186793009124157, 0.9360642774110774, 0.9192578446141256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 87}], {
             RGBColor[
             0.7537853002217132, 0.8078216725696721, 0.9760303498043761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 151}], {
             RGBColor[
             0.9110424812344575, 0.9309566699502319, 0.9585132538728244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 154}], {
             RGBColor[
             0.9185638908965517, 0.9360165524036155, 0.9211704872485396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 181}], {
             RGBColor[
             0.9203990902074957, 0.936775454481162, 0.8907564853226253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 192}], {
             RGBColor[
             0.7835717004654598, 0.8310910348251134, 0.9789991798109364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 220}], {
             RGBColor[
             0.9060856529533428, 0.8841233501435971, 0.6472541986474155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 239}], {
             RGBColor[
             0.7213216178052286, 0.781704916345156, 0.9733114731542098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 258}], {
             RGBColor[
             0.9179018133014649, 0.935742766303429, 0.9321428264010201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 32}], {
             RGBColor[
             0.9632226599405231, 0.9601894940520288, 0.693792649178037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 53}], {
             RGBColor[
             0.9399844813177689, 0.9547611049499605, 0.9864747979615536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 93}], {
             RGBColor[
             0.9564362643872055, 0.9670308178258239, 0.9586262205372289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 107}], {
             RGBColor[
             0.96681323688465, 0.9732235759602803, 0.8718110616846207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 137}], {
             RGBColor[
             0.9671447109653303, 0.9723951229117237, 0.7961341235246624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 147}], {
             RGBColor[
             0.8473077033109992, 0.8814993764534695, 0.9811991124559027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 156}], {
             RGBColor[
             0.6487549740071723, 0.7194181597217182, 0.9651136517993449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 179}], {
             RGBColor[
             0.8776550187149861, 0.9052069298952037, 0.9842238492435856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 251}], {
             RGBColor[
             0.8699798588432351, 0.8992110366700163, 0.9834588610360164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 270}], {
             RGBColor[
             0.9176243752811755, 0.937038608476376, 0.9880464588539006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 271}], {
             RGBColor[
             0.9655927087593041, 0.9681842252317034, 0.7029998412928367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 273}], {
             RGBColor[
             0.9630147630237891, 0.9716528094024887, 0.9347616036943276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 274}], {
             RGBColor[
             0.821530692604924, 0.8613621797773461, 0.9786299009285819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 277}], {
             RGBColor[
             0.8120588239897344, 0.8539626840262924, 0.9776858335846645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 282}], {
             RGBColor[
             0.8883565176538993, 0.9137012132592173, 0.985254864465686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 289}], {
             RGBColor[
             0.9228624708136912, 0.9412153236696885, 0.9885460730818951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 67}], {
             RGBColor[
             0.9484718013817472, 0.95664029522474, 0.7188913324343444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 173}], {
             RGBColor[
             0.957534603377976, 0.9638667275333261, 0.7197557505792036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 186}], {
             RGBColor[
             0.9653514717728496, 0.9700403297328375, 0.7184434042042618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.8416658212611433, 0.8725216303142572, 0.7084266326571163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 249}], {
             RGBColor[
             0.9665574254708011, 0.9709397280262018, 0.7164020391567283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 46}], {
             RGBColor[
             0.9538690651940513, 0.9508330161742287, 0.6938986293484702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 60}], {
             RGBColor[
             0.6714881966965951, 0.7224676683470901, 0.6696638383331841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.9887158332294195, 0.9734915693540553, 0.4197134292192015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 77}], {
             RGBColor[
             0.9355641264713928, 0.9362371549111057, 0.6921526879520914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 82}], {
             RGBColor[
             0.7258448123369009, 0.769178946638299, 0.6732295403014906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 103}], {
             RGBColor[
             0.9650436800560362, 0.9594949643904109, 0.6863527634815842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 127}], {
             RGBColor[
             0.9814257389730998, 0.9717126771075972, 0.6586222108602557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 135}], {
             RGBColor[
             0.987558374564345, 0.9752615700410043, 0.6023478750741614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 158}], {
             RGBColor[
             0.9241188613647332, 0.7166122520991616, 0.301539591844056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 168}], {
             RGBColor[
             0.9819960692752369, 0.9721380285131009, 0.6576567904247037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 186}], {
             RGBColor[
             0.9613784986583839, 0.9567614781052255, 0.6925569595554029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 196}], {
             RGBColor[
             0.9896760602006999, 0.9761372874736756, 0.5672523436850119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 212}], {
             RGBColor[
             0.905128412109965, 0.9119685424347611, 0.6892497023460153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 214}], {
             RGBColor[
             0.957129662587529, 0.9534329280292293, 0.6942096280386298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 225}], {
             RGBColor[
             0.9864354516340761, 0.9747972125515352, 0.6209576140601051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 255}], {
             RGBColor[
             0.9025575365228612, 0.5588669653135674, 0.28120509598500487`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 265}], {
             RGBColor[
             0.9825437694315771, 0.9725465023929227, 0.6567296769230986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 276}], {
             RGBColor[
             0.9246982468692739, 0.9275729974628208, 0.691116290655556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 286}], {
             RGBColor[
             0.989528210452572, 0.975229162090442, 0.5081356765482805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.9568262174223037, 0.9658319070882517, 0.8946847190030407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 39}], {
             RGBColor[
             0.9532110209503954, 0.9642860125501127, 0.9523176731945178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 76}], {
             RGBColor[
             0.9551336529062575, 0.9651319881639426, 0.9227348932504824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 90}], {
             RGBColor[
             0.9530978846668623, 0.9642016356950973, 0.9525091834118709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 126}], {
             RGBColor[
             0.9570286988980568, 0.9659156383820122, 0.8913290769445523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 151}], {
             RGBColor[
             0.9474968332282994, 0.9600243807030971, 0.9619903025091812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 153}], {
             RGBColor[
             0.8248653364996512, 0.8639392310502206, 0.9829585630547548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 192}], {
             RGBColor[
             0.8200260524593016, 0.8601587455779787, 0.9824762284472932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 220}], {
             RGBColor[
             0.9425400049471846, 0.9131910608964624, 0.6507312472837724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 222}], {
             RGBColor[
             0.7681045229790933, 0.8191578118655821, 0.9776016233316349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 239}], {
             RGBColor[
             0.7577759697990705, 0.8107726270980213, 0.9767885217905666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 248}], {
             RGBColor[
             0.9564793050122362, 0.9656884498914466, 0.9004339554183978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 285}], {
             RGBColor[
             0.8191224231227665, 0.8594528234724401, 0.9823861631199238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 40}], {
             RGBColor[
             0.8050839479671197, 0.848547237727503, 0.9786803262314505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[
             0.7839691093449588, 0.682164075110828, 0.601438438021634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 66}], {
             RGBColor[
             0.751525397447474, 0.8059066610943464, 0.9758447919774691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 81}], {
             RGBColor[
             0.8246440180191588, 0.8394651378727639, 0.6672443741967713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 86}], {
             RGBColor[
             0.5644382642472737, 0.6568224978702388, 0.9591634708133263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 94}], {
             RGBColor[
             0.8332517909835655, 0.8672212076392973, 0.809523326167874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 97}], {
             RGBColor[
             0.8324454530782888, 0.8654965323931783, 0.7217584213192277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 120}], {
             RGBColor[
             0.5541139020964676, 0.6479786685409908, 0.958478364175939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 130}], {
             RGBColor[
             0.8185285894853838, 0.8585742293582443, 0.9559220550651332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 140}], {
             RGBColor[
             0.5866771405013386, 0.674877019463247, 0.9609141966157342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 162}], {
             RGBColor[
             0.8198336340388261, 0.8595475294493873, 0.9537129550462875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 169}], {
             RGBColor[
             0.8126564418877433, 0.798266240344967, 0.6246433532317995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 178}], {
             RGBColor[
             0.6365640677079505, 0.7153774743500343, 0.9648414782672743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 182}], {
             RGBColor[
             0.7936335296041175, 0.8394825426812553, 0.9798611032129432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 201}], {
             RGBColor[
             0.7482894474742454, 0.8033264024232158, 0.9755361441802559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 202}], {
             RGBColor[
             0.7308668044721016, 0.789677969537834, 0.9738096307973206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 294}], {
             RGBColor[
             0.8213692672220945, 0.8606928021631003, 0.9511135286242934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 26}], {
             RGBColor[
             0.7749954519590266, 0.8247674301462677, 0.9780445407403493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 33}], {
             RGBColor[
             0.8224657640697013, 0.8600396058747701, 0.881512887631525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 35}], {
             RGBColor[
             0.8125890900080092, 0.822273168160326, 0.6546896399769635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 129}], {
             RGBColor[
             0.8223439911007142, 0.8551787401057183, 0.6925855886636239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 165}], {
             RGBColor[
             0.7651443810646753, 0.8169124536153081, 0.9771049368042912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 175}], {
             RGBColor[
             0.7970357401511741, 0.7651632154548793, 0.6184582785454095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 183}], {
             RGBColor[
             0.8194123592838514, 0.8587769445268976, 0.9321157068913406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 184}], {
             RGBColor[
             0.5839373591744009, 0.6729301793403579, 0.9605088252653389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.547840880711165, 0.6433144872470677, 0.9577530932155679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 253}], {
             RGBColor[
             0.821097318561212, 0.8594737184895644, 0.9041915711306454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 262}], {
             RGBColor[
             0.7452010113630072, 0.8010101519635471, 0.9752027203984898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 36}], {
             RGBColor[
             0.623313323172405, 0.6916056685890454, 0.9315828461579552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 37}], {
             RGBColor[
             0.98164522707137, 0.9854182055483809, 0.8974404372747895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 41}], {
             RGBColor[
             0.985376108762623, 0.9859777081863921, 0.7641336107580647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 44}], {
             RGBColor[
             0.9345178510073152, 0.9495682006828765, 0.9570394121185108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 55}], {
             RGBColor[
             0.9573114985480657, 0.8870127179452245, 0.5967296226538845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 61}], {
             RGBColor[
             0.9823623630578833, 0.9857147597083583, 0.885555638089823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 71}], {
             RGBColor[
             0.9210340470848438, 0.9388165814432049, 0.9557533148632515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 108}], {
             RGBColor[
             0.8695813139685316, 0.8982537654571588, 0.9507225237005397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 136}], {
             RGBColor[
             0.9075601297796747, 0.9280728455238052, 0.9544681606023766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 152}], {
             RGBColor[
             0.9624832495407232, 0.9715406494522879, 0.94839025197864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 177}], {
             RGBColor[
             0.9842309446715172, 0.986487466225953, 0.8545884050177069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 208}], {
             RGBColor[
             0.7000292284374964, 0.7616339272892302, 0.9363400052699731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 252}], {
             RGBColor[
             0.9695850317300359, 0.9768371469809762, 0.936368787173577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 268}], {
             RGBColor[
             0.9655773024557723, 0.9738481890502848, 0.9431528274517037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 279}], {
             RGBColor[
             0.8218148140352257, 0.8609382126704149, 0.9459616053905088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 280}], {
             RGBColor[
             0.9830499082606798, 0.9859990773188204, 0.8741612347695364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 50}], {
             RGBColor[
             0.9778344685447361, 0.9474512112790772, 0.599067589032432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 74}], {
             RGBColor[
             0.9328310646306572, 0.9474910420503633, 0.9267969009364451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[
             0.9707838276158292, 0.9772666682837844, 0.9135365460735014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 123}], {
             RGBColor[
             0.98140233290866, 0.985185932144971, 0.8955621863624647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 189}], {
             RGBColor[
             0.9059120138224055, 0.926026521634032, 0.9242293378394337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 206}], {
             RGBColor[
             0.9654404795488503, 0.9732816080443609, 0.9225814405825241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 257}], {
             RGBColor[
             0.9903655045134261, 0.9889561241333419, 0.712816563689662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 287}], {
             RGBColor[
             0.934957997019547, 0.9491870002032223, 0.9269997696464323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 300}], {
             RGBColor[
             0.9859940627481862, 0.9884761992572753, 0.8817781566736549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.86428021978488, 0.8903685366443834, 0.7251270489144062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 63}], {
             RGBColor[
             0.989381804384431, 0.9878807423423648, 0.6805191125153802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 70}], {
             RGBColor[
             0.8997007929619603, 0.9180393576166452, 0.7286574406246218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 73}], {
             RGBColor[
             0.8474833795488064, 0.8772467173912487, 0.7234528968550707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 100}], {
             RGBColor[
             0.8363439347794499, 0.8685444984745115, 0.7223426211044913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 119}], {
             RGBColor[
             0.9660796319535259, 0.970768460770955, 0.7318953610454728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 122}], {
             RGBColor[
             0.9927783609098718, 0.9869619691429572, 0.4553473357089908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 161}], {
             RGBColor[
             0.9594548126166563, 0.9655760690661989, 0.7343858960920921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 244}], {
             RGBColor[
             0.8481075252148689, 0.8777343047292595, 0.723515105862091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 266}], {
             RGBColor[
             0.8543380922816868, 0.8826016710759212, 0.7241361105593518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 24}], {
             RGBColor[
             0.5610138838012213, 0.6429847698794878, 0.9622175988515085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 31}], {
             RGBColor[
             0.6243128822859298, 0.670320384855607, 0.6550447405531095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 44}], {
             RGBColor[
             0.5812211304084436, 0.6590974798129898, 0.9641449840721273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 59}], {
             RGBColor[
             0.6304386382547498, 0.6958118078843919, 0.8699071165088417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 72}], {
             RGBColor[
             0.5509723768063708, 0.6349779447712403, 0.9612598309501805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 83}], {
             RGBColor[
             0.34035530703202255`, 0.465639595608097, 0.9430392276273302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 106}], {
             RGBColor[
             0.5613344581850443, 0.6432403871913885, 0.9622481755224177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 136}], {
             RGBColor[
             0.5542634091808032, 0.6376021246539185, 0.9615737325559932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 155}], {
             RGBColor[
             0.5933041230000431, 0.5540778193161362, 0.59521715022403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 194}], {
             RGBColor[
             0.628060330228132, 0.6948283163956571, 0.90932183537377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 197}], {
             RGBColor[
             0.3634809667512553, 0.48557138918834936`, 0.9445399874448259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 198}], {
             RGBColor[
             0.6322898086261564, 0.6959570554088171, 0.7941421514798737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 210}], {
             RGBColor[
             0.6203519731847598, 0.6893970986170253, 0.9365956392432631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 226}], {
             RGBColor[
             0.630129610106611, 0.6956840168034754, 0.8750285126627122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 241}], {
             RGBColor[
             0.4623076543813087, 0.5656158496096418, 0.9524481788189711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 290}], {
             RGBColor[
             0.45706876676155206`, 0.5615231907840673, 0.951926015461222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 291}], {
             RGBColor[
             0.548305565226576, 0.6328515016061838, 0.9610054680810088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.9040010777990981, 0.9257666626906529, 0.9725633662781996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 59}], {
             RGBColor[
             0.9214359194824377, 0.9376616300447209, 0.8934362972487783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 65}], {
             RGBColor[
             0.8814624275405756, 0.7846720449447929, 0.6164620236821337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 72}], {
             RGBColor[
             0.8419696580340589, 0.8768277669315693, 0.9847890116901171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 87}], {
             RGBColor[
             0.7549769724924504, 0.8087718796912758, 0.9761440125693773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 106}], {
             RGBColor[
             0.8523317394127324, 0.8850902093517174, 0.9857773562623543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 109}], {
             RGBColor[
             0.7543996416608039, 0.8083208644577168, 0.9760864696275422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 155}], {
             RGBColor[
             0.8843014042277312, 0.7959276414764652, 0.6187463309639666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 162}], {
             RGBColor[
             0.9098758958271262, 0.9301480923568246, 0.9626188317546867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 194}], {
             RGBColor[
             0.9190576114558201, 0.9366781385559861, 0.9328510161137067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 210}], {
             RGBColor[
             0.9113492544124479, 0.9312469207773543, 0.9601248199831998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 218}], {
             RGBColor[
             0.7360716045557452, 0.7936623739565515, 0.9744924961008017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 226}], {
             RGBColor[
             0.9211268913342989, 0.9375338389638044, 0.8985576934026489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 227}], {
             RGBColor[
             0.9114649353339123, 0.9313331954191724, 0.9599290023575768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 241}], {
             RGBColor[
             0.7533049356089967, 0.8074656717699709, 0.9759773595589077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 290}], {
             RGBColor[
             0.74806604798924, 0.8033730129443963, 0.9754551962011586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 291}], {
             RGBColor[
             0.839302846454264, 0.8747013237665127, 0.9845346488209454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 299}], {
             RGBColor[
             0.8758873984485771, 0.9038728524655689, 0.9880241160495782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 28}], {
             RGBColor[
             0.7615737732249701, 0.813445300902589, 0.9687400994590682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 58}], {
             RGBColor[
             0.9026364382662523, 0.9249555923267112, 0.9820389166414176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 79}], {
             RGBColor[
             0.9183809090122719, 0.9375098059273139, 0.983540638316428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 113}], {
             RGBColor[
             0.951035566346468, 0.9630029860698733, 0.967768193592556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 134}], {
             RGBColor[
             0.9688092263891941, 0.974899659789698, 0.8768280255713842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 144}], {
             RGBColor[
             0.7189240373042484, 0.7788203239334394, 0.9653825560162587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 160}], {
             RGBColor[
             0.9700128827375076, 0.9749632095235636, 0.8253190702155382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 176}], {
             RGBColor[
             0.9594353483314004, 0.9692675297208552, 0.9535495537060743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.735604341394634, 0.7923621462331504, 0.966695690656221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 221}], {
             RGBColor[
             0.955278685642529, 0.9661674974934055, 0.9605856994070763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 230}], {
             RGBColor[
             0.8774338745651828, 0.9049435149923255, 0.979612845530643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 232}], {
             RGBColor[
             0.7892612003448016, 0.8359232015428457, 0.9709197551443287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 245}], {
             RGBColor[
             0.9684020579496027, 0.9747312851761754, 0.883575860333556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 288}], {
             RGBColor[
             0.5620870344394855, 0.6320399670682044, 0.9555338049615488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 297}], {
             RGBColor[
             0.9547616203307601, 0.9657818710305048, 0.9614609561076695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 35}], {
             RGBColor[
             0.9337689241971221, 0.9175556014312172, 0.666604292126188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 54}], {
             RGBColor[
             0.9128391951997678, 0.933337212165166, 0.9915486114109652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 75}], {
             RGBColor[
             0.9241695153221261, 0.9419471214519075, 0.9779088375753839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 102}], {
             RGBColor[
             0.8092762836326608, 0.8515478763936812, 0.9814613336689912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 129}], {
             RGBColor[
             0.943523825289827, 0.9504611733766095, 0.7045002408128483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 165}], {
             RGBColor[
             0.8863242152537882, 0.9121948868861992, 0.9890195889535156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 175}], {
             RGBColor[
             0.9182155743402869, 0.8604456487257705, 0.6303729306946338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 183}], {
             RGBColor[
             0.9405921934729642, 0.9540593777977887, 0.9440303590405651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 224}], {
             RGBColor[
             0.669020714900278, 0.738596920517959, 0.9696677453647924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 253}], {
             RGBColor[
             0.9422771527503249, 0.9547561517604557, 0.9161062232798698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 262}], {
             RGBColor[
             0.8663808455521201, 0.8962925852344383, 0.9871173725477143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 42}], {
             RGBColor[
             0.9260012839034475, 0.7936967086691014, 0.5971609014167876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 72}], {
             RGBColor[
             0.8939595708042476, 0.9177598375824053, 0.9716055983768717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 87}], {
             RGBColor[
             0.806966885262639, 0.8497039503421119, 0.9629605992561319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 109}], {
             RGBColor[
             0.8063895544309926, 0.8492529351085528, 0.9629030563142968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 140}], {
             RGBColor[
             0.7287093150598272, 0.7864096530215203, 0.9566366600108878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 151}], {
             RGBColor[
             0.9642240662753834, 0.9728389477226718, 0.9454435033245803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 154}], {
             RGBColor[
             0.9717454759374775, 0.9778988301760554, 0.9081007367002953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 155}], {
             RGBColor[
             0.9362913169979199, 0.8368597121273013, 0.6055629176507211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 162}], {
             RGBColor[
             0.9618658085973149, 0.9710801630076606, 0.9494354184414412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 181}], {
             RGBColor[
             0.9735806752484215, 0.9786577322536016, 0.8776867347743812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 202}], {
             RGBColor[
             0.8728989790305902, 0.9012106030961073, 0.9695320941924743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 203}], {
             RGBColor[
             0.931454102953682, 0.8176817703479234, 0.6016707816867206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 216}], {
             RGBColor[
             0.8400908663891915, 0.8755806561497553, 0.9662620881336237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 227}], {
             RGBColor[
             0.963454848104101, 0.9722652660700084, 0.9467455890443315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 299}], {
             RGBColor[
             0.9278773112187657, 0.944804923116405, 0.9748407027363328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 79}], {
             RGBColor[
             0.7347076133582711, 0.7922691726934941, 0.9747141278523986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 144}], {
             RGBColor[
             0.5352507416502476, 0.6335796906996196, 0.9565560455522293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 160}], {
             RGBColor[
             0.7863395870835068, 0.829722576289744, 0.8164925597515089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 176}], {
             RGBColor[
             0.7757620526773995, 0.8240268964870354, 0.9447230432420449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 221}], {
             RGBColor[
             0.7716053899885282, 0.8209268642595857, 0.9517591889430469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 230}], {
             RGBColor[
             0.693760578911182, 0.7597028817585059, 0.9707863350666136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 232}], {
             RGBColor[
             0.6055879046908007, 0.690682568309026, 0.9620932446802994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 240}], {
             RGBColor[
             0.6342649764703312, 0.713224464948387, 0.9648563694333254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 245}], {
             RGBColor[
             0.7847287622956018, 0.8294906519423555, 0.8747493498695267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 288}], {
             RGBColor[
             0.3784137387854847, 0.4867993338343847, 0.9467072944975194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 297}], {
             RGBColor[
             0.7710883246767593, 0.8205412377966852, 0.9526344456436402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 43}], {
             RGBColor[
             0.7681050894702328, 0.819321788062709, 0.9774134636724073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 78}], {
             RGBColor[
             0.8157717557201114, 0.8539446224935119, 0.8456666399700644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 99}], {
             RGBColor[
             0.8106018875444135, 0.8518149005257343, 0.9319372542832953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 131}], {
             RGBColor[
             0.6447769472896192, 0.7223306577958022, 0.9652927614465578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 170}], {
             RGBColor[
             0.7386728555889575, 0.7958533236824861, 0.974606190930346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 178}], {
             RGBColor[
             0.6187362271189164, 0.7013569687813456, 0.9631283287857327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 182}], {
             RGBColor[
             0.7758056890150833, 0.8254620371125667, 0.9781479537314015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 190}], {
             RGBColor[
             0.6681016720941748, 0.7405521100875953, 0.9676175520331299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 199}], {
             RGBColor[
             0.7631197865540517, 0.815346642839789, 0.9769379610298295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 209}], {
             RGBColor[
             0.8150435669165887, 0.8523871002739585, 0.7664077825669985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 229}], {
             RGBColor[
             0.8077263766399756, 0.8497934254573423, 0.9423163503908157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 259}], {
             RGBColor[
             0.7916448324991305, 0.8377998361682119, 0.9695382098828125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 261}], {
             RGBColor[
             0.8117937232413525, 0.8523077552151987, 0.9121854524131056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 284}], {
             RGBColor[
             0.810397011746732, 0.8517301791183252, 0.9353325764524476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 74}], {
             RGBColor[
             0.8497372033478867, 0.8830213967204148, 0.9855298870963196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 104}], {
             RGBColor[
             0.9074166311579289, 0.924796593319303, 0.787330590971465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 123}], {
             RGBColor[
             0.8983084716258894, 0.9207162868150225, 0.9542951725223392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 189}], {
             RGBColor[
             0.822818152539635, 0.8615568763040835, 0.9829623239993082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 236}], {
             RGBColor[
             0.7918804161798887, 0.8373488654382555, 0.9798891463120165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 260}], {
             RGBColor[
             0.8310162802167287, 0.8680938407815505, 0.9837442687357044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 267}], {
             RGBColor[
             0.9025883602148197, 0.9238775995562507, 0.9456791593751943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 287}], {
             RGBColor[
             0.8518641357367764, 0.8847173548732739, 0.9857327558063069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 300}], {
             RGBColor[
             0.9029002014654157, 0.9240065539273269, 0.9405111428335294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 37}], {
             RGBColor[
             0.9826447861848948, 0.9641329218149424, 0.6209023316699438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 44}], {
             RGBColor[
             0.9355174101208401, 0.928282916949438, 0.6805013065136649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 59}], {
             RGBColor[
             0.9847349179671462, 0.96499724502084, 0.5862634389503792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 61}], {
             RGBColor[
             0.9833619221714082, 0.9644294759749199, 0.6090175324849771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 65}], {
             RGBColor[
             0.9447614260252841, 0.8120076599209121, 0.3092891653837346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 71}], {
             RGBColor[
             0.9220336061983687, 0.9175312977097665, 0.6792152092584058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 136}], {
             RGBColor[
             0.9085596888931997, 0.9067875617903667, 0.6779300549975308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 177}], {
             RGBColor[
             0.9852305037850421, 0.9652021824925145, 0.5780502994128611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 194}], {
             RGBColor[
             0.9823566099405285, 0.9640137535321053, 0.6256781578153077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 210}], {
             RGBColor[
             0.9746482528971563, 0.9585825357534734, 0.6529519616848007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 226}], {
             RGBColor[
             0.9844258898190075, 0.9648694539399235, 0.5913848351042499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 241}], {
             RGBColor[
             0.8166039340937051, 0.83480128674609, 0.6688045012605087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 279}], {
             RGBColor[
             0.8228143731487505, 0.8396529289369765, 0.669423499785663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 280}], {
             RGBColor[
             0.9840494673742047, 0.964713793585382, 0.5976231291646907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 290}], {
             RGBColor[
             0.8113650464739486, 0.8307086279205155, 0.6682823379027596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 291}], {
             RGBColor[
             0.9026018449389723, 0.9020369387426319, 0.6773617905225464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 80}], {
             RGBColor[
             0.905545708386734, 0.9143136348776315, 0.6922499373550239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 92}], {
             RGBColor[
             0.9901483675044025, 0.9775199208839618, 0.49363835957195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 107}], {
             RGBColor[
             0.9899092664734752, 0.978545950545592, 0.5793695341371403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 125}], {
             RGBColor[
             0.9903091346099453, 0.9778637854666701, 0.5111368668707164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 128}], {
             RGBColor[
             0.989990470915265, 0.9771821960455908, 0.4764522902691338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 142}], {
             RGBColor[
             0.9257277755459936, 0.9304062674028062, 0.6941749209374182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 145}], {
             RGBColor[
             0.9658317880624705, 0.9621353775333219, 0.6893760758371803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 149}], {
             RGBColor[
             0.9271573016946988, 0.93154613275033, 0.6943112704176346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 150}], {
             RGBColor[
             0.9768562439817211, 0.9703573987070093, 0.6707145476044949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 156}], {
             RGBColor[
             0.6718510035959975, 0.7247405343070299, 0.6726721242518645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 167}], {
             RGBColor[
             0.8354558906814753, 0.8595202310843686, 0.685274310602251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 179}], {
             RGBColor[
             0.9007510483038114, 0.9105293044805154, 0.6917823216961052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 205}], {
             RGBColor[
             0.9643998505993652, 0.9610674409179205, 0.6917999724531136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 237}], {
             RGBColor[
             0.9773959394043343, 0.970759902669524, 0.6698009840291206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 256}], {
             RGBColor[
             0.6192965209428843, 0.6739992932273386, 0.6695145724197853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 269}], {
             RGBColor[
             0.9839707648553435, 0.9756633967255981, 0.6586715195296766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 277}], {
             RGBColor[
             0.8351548535785596, 0.8592850586116041, 0.685244306037184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 282}], {
             RGBColor[
             0.9114525472427246, 0.9190235878445291, 0.6928133369182057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 293}], {
             RGBColor[
             0.9578823890055405, 0.9560454833617179, 0.697241856673952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 98}], {
             RGBColor[
             0.9707880213862894, 0.9159460892871687, 0.5379465751172737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 126}], {
             RGBColor[
             0.9913183918452417, 0.9906779461679242, 0.793540244613437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 153}], {
             RGBColor[
             0.8591550294468362, 0.8887015388361326, 0.8851697307236392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 157}], {
             RGBColor[
             0.9891008812831161, 0.9897609485630632, 0.8302901333612327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 171}], {
             RGBColor[
             0.9674685012480007, 0.9741083289417058, 0.8884381516413168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 184}], {
             RGBColor[
             0.7525875054741884, 0.8034847883397515, 0.875891824305739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 222}], {
             RGBColor[
             0.8023942159262782, 0.843920119651494, 0.8798127910005196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 248}], {
             RGBColor[
             0.9907689979594212, 0.9904507576773586, 0.8026451230872822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 275}], {
             RGBColor[
             0.9921631595049849, 0.9892401452130841, 0.6496344757841144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 285}], {
             RGBColor[
             0.8534121160699515, 0.8842151312583522, 0.8845973307888082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 38}], {
             RGBColor[
             0.9636442886694061, 0.971790729077066, 0.9188471725682119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 52}], {
             RGBColor[
             0.9608224250132018, 0.9696358285512727, 0.9218778655133039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 53}], {
             RGBColor[
             0.9638705279240237, 0.9719594579427271, 0.9184642085227921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 57}], {
             RGBColor[
             0.9771108689158081, 0.9436627931116236, 0.5869423484761713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 84}], {
             RGBColor[
             0.75482537898575, 0.8059423287511038, 0.9028531878593321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 124}], {
             RGBColor[
             0.9253712314072178, 0.729675551846822, 0.5287393953409198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 147}], {
             RGBColor[
             0.8711937499172541, 0.8986977294462362, 0.9131885230171412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 217}], {
             RGBColor[
             0.941684066564952, 0.9543754210215392, 0.9200524317994956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 223}], {
             RGBColor[
             0.9238460566916349, 0.722750089676965, 0.527466752172784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 247}], {
             RGBColor[
             0.971061655111227, 0.9773225888245533, 0.9062915059412078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 270}], {
             RGBColor[
             0.9415104218874304, 0.9542369614691426, 0.9200358694151392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 295}], {
             RGBColor[
             0.8229207517600996, 0.8609864963974927, 0.908377121697652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 102}], {
             RGBColor[
             0.8468699216816433, 0.8490536144077394, 0.6581064329056054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 129}], {
             RGBColor[
             0.9811174633388096, 0.9479669113906677, 0.38114534004946266`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 165}], {
             RGBColor[
             0.9239178533027708, 0.9097006249002575, 0.6656646881901299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 175}], {
             RGBColor[
             0.9558092123892694, 0.8579513867398287, 0.30701802993124816`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 183}], {
             RGBColor[
             0.9781858315219467, 0.951565115811847, 0.6206754582771794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 224}], {
             RGBColor[
             0.7066143529492606, 0.7361026585320172, 0.6463128446014066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 253}], {
             RGBColor[
             0.9798707907993074, 0.9522618897745139, 0.5927513225164841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 262}], {
             RGBColor[
             0.9039744836011027, 0.8937983232484965, 0.6637624717843285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 41}], {
             RGBColor[
             0.6320793881637514, 0.6955069873165055, 0.7712391827116812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 55}], {
             RGBColor[
             0.6040147779491942, 0.596541997075338, 0.603835194607501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 152}], {
             RGBColor[
             0.6091865289418517, 0.6810699285824013, 0.9554958239322565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 208}], {
             RGBColor[
             0.34673250783862486`, 0.4711632064193436, 0.9434455772235896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 242}], {
             RGBColor[
             0.5851725271211421, 0.6622482162938892, 0.964521871818038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 250}], {
             RGBColor[
             0.6302698145176182, 0.6957419949305158, 0.8727049627349397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 268}], {
             RGBColor[
             0.6122805818569008, 0.6833774681803984, 0.9502583994053202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 41}], {
             RGBColor[
             0.9904112920627166, 0.989319524275841, 0.7370967738285156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 44}], {
             RGBColor[
             0.9395530343074088, 0.9529100167723253, 0.9300025751889617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 55}], {
             RGBColor[
             0.9623466818481592, 0.8903545340346735, 0.5696927857243353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 61}], {
             RGBColor[
             0.9873975463579767, 0.9890565757978071, 0.8585188011602738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 71}], {
             RGBColor[
             0.9260692303849374, 0.9421583975326537, 0.9287164779337025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 108}], {
             RGBColor[
             0.8746164972686251, 0.9015955815466077, 0.9236856867709906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 136}], {
             RGBColor[
             0.9125953130797683, 0.931414661613254, 0.9274313236728275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 152}], {
             RGBColor[
             0.9675184328408167, 0.9748824655417367, 0.9213534150490909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 161}], {
             RGBColor[
             0.9563110864059083, 0.9662724326304627, 0.9316009731582062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 177}], {
             RGBColor[
             0.9892661279716106, 0.9898292823154018, 0.8275515680881578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 208}], {
             RGBColor[
             0.7050644117375899, 0.764975743378679, 0.9093031683404239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 252}], {
             RGBColor[
             0.9746202150301294, 0.9801789630704252, 0.9093319502440278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 268}], {
             RGBColor[
             0.9706124857558658, 0.9771900051397338, 0.9161159905221545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 279}], {
             RGBColor[
             0.8268499973353192, 0.8642800287598638, 0.9189247684609596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 280}], {
             RGBColor[
             0.9880850915607733, 0.9893408934082693, 0.8471243978399874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 52}], {
             RGBColor[
             0.9365679901184001, 0.9521627321760884, 0.9905120402335215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 53}], {
             RGBColor[
             0.9396160930292221, 0.9544863615675427, 0.9870983832430098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 57}], {
             RGBColor[
             0.9528564340210064, 0.9261896967364391, 0.6555765231963889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 88}], {
             RGBColor[
             0.8942259282422569, 0.9184003213807033, 0.9864734165725701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 124}], {
             RGBColor[
             0.901116796512416, 0.7122024554716376, 0.5973735700611374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 147}], {
             RGBColor[
             0.8469393150224525, 0.8812246330710518, 0.9818226977373588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 247}], {
             RGBColor[
             0.9468072202164254, 0.9598494924493688, 0.9749256806614254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 289}], {
             RGBColor[
             0.9224940825251444, 0.9409405802872708, 0.9891696583633511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 64}], {
             RGBColor[
             0.949778714664411, 0.9615491846851407, 0.9519902967569046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 69}], {
             RGBColor[
             0.8020087807541266, 0.8449962908355858, 0.937700003832519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 76}], {
             RGBColor[
             0.9858081493815343, 0.9883484014117155, 0.8825790151108441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 85}], {
             RGBColor[
             0.9885590341153779, 0.9877179306005293, 0.708472448961283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 90}], {
             RGBColor[
             0.983772381142139, 0.9874180489428701, 0.9123533052722325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 118}], {
             RGBColor[
             0.9892573056146884, 0.9892114627314761, 0.7844749924290482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 126}], {
             RGBColor[
             0.9877031953733335, 0.989132051629785, 0.851173198804914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 153}], {
             RGBColor[
             0.855539832974928, 0.8871556442979935, 0.9428026849151163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 166}], {
             RGBColor[
             0.9337194767695196, 0.9487439843041545, 0.9504585523102389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 195}], {
             RGBColor[
             0.984365804444558, 0.9877519547137017, 0.9064824033855845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 234}], {
             RGBColor[
             0.6948946860185975, 0.7567488380833127, 0.9296233038187041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 239}], {
             RGBColor[
             0.7884504662743472, 0.8339890403457941, 0.9366326436509282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 248}], {
             RGBColor[
             0.987153801487513, 0.9889048631392194, 0.8602780772787593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 263}], {
             RGBColor[
             0.9740816245493071, 0.9801906985430937, 0.9287572284297851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 285}], {
             RGBColor[
             0.8497969195980433, 0.8826692367202129, 0.9422302849802853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 42}], {
             RGBColor[
             0.917126415859769, 0.7870778466133888, 0.6121837380784374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 66}], {
             RGBColor[
             0.8846827039622843, 0.9108204325969071, 0.9865900920342726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 81}], {
             RGBColor[
             0.957801324533969, 0.9443789093753246, 0.6779896742535748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 86}], {
             RGBColor[
             0.6975955707620839, 0.7617362693727996, 0.9699087708701297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 94}], {
             RGBColor[
             0.9664090974983757, 0.9721349791418581, 0.8202686262246774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 97}], {
             RGBColor[
             0.965602759593099, 0.970410303895739, 0.7325037213760313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 120}], {
             RGBColor[
             0.6872712086112779, 0.7528924400435516, 0.9692236642327425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 130}], {
             RGBColor[
             0.9516858960001939, 0.9634880008608051, 0.9666673551219367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 140}], {
             RGBColor[
             0.7198344470161488, 0.7797907909658077, 0.9716594966725376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 162}], {
             RGBColor[
             0.9529909405536364, 0.964461300951948, 0.964458255103091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 169}], {
             RGBColor[
             0.9458137484025535, 0.9031800118475277, 0.635388653288603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 178}], {
             RGBColor[
             0.7697213742227608, 0.820291245852595, 0.9755867783240777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 182}], {
             RGBColor[
             0.9267908361189277, 0.9443963141838161, 0.9906064032697466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 201}], {
             RGBColor[
             0.8814467539890556, 0.9082401739257766, 0.9862814442370593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 202}], {
             RGBColor[
             0.8640241109869118, 0.8945917410403947, 0.9845549308541242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 55}], {
             RGBColor[
             0.9660775635394123, 0.8909140366726847, 0.4363859592076105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 108}], {
             RGBColor[
             0.8783473789598781, 0.902155084184619, 0.7903788602542657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 152}], {
             RGBColor[
             0.9712493145320698, 0.975441968179748, 0.788046588532366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 208}], {
             RGBColor[
             0.708795293428843, 0.7655352460166903, 0.775996341823699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 219}], {
             RGBColor[
             0.9366004584703704, 0.9481403117948988, 0.7960582745267955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 242}], {
             RGBColor[
             0.9472353127113602, 0.9566202558912359, 0.7970726364181475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.9923326001078363, 0.9901140345278625, 0.705255727335049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 252}], {
             RGBColor[
             0.9783510967213824, 0.9807384657084364, 0.776025123727303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 268}], {
             RGBColor[
             0.9743433674471189, 0.9777495077777449, 0.7828091640054298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 80}], {
             RGBColor[
             0.8603921522408637, 0.7419050425573182, 0.6090453014740561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 81}], {
             RGBColor[
             0.9366864859118083, 0.7779957467586498, 0.3007477860437583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 82}], {
             RGBColor[
             0.6814724904938739, 0.5994056410640132, 0.5930598521633497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 87}], {
             RGBColor[
             0.7769771785967998, 0.6767019256697244, 0.6007415477079653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 130}], {
             RGBColor[
             0.930571057378033, 0.7971048382441301, 0.5894254669121202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 140}], {
             RGBColor[
             0.698719608393988, 0.6134076283491328, 0.5944176084627212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 145}], {
             RGBColor[
             0.9206782319166004, 0.7897267852130085, 0.6061714399562125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 162}], {
             RGBColor[
             0.9318761019314756, 0.7980781383352732, 0.5872163668932745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 167}], {
             RGBColor[
             0.7903023345356053, 0.6871116387640552, 0.6020696747212833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 181}], {
             RGBColor[
             0.9435909685825823, 0.8056557075812142, 0.5154676832262145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 201}], {
             RGBColor[
             0.8603319153668948, 0.7418570113091016, 0.6090395560272429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 202}], {
             RGBColor[
             0.8429092723647509, 0.7282085784237198, 0.6073130426443076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 203}], {
             RGBColor[
             0.9014643962878428, 0.644679745675536, 0.23945173013855398`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 216}], {
             RGBColor[
             0.8101011597233523, 0.7025786314773679, 0.6040430365854571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 237}], {
             RGBColor[
             0.9322423832584643, 0.7983513103492107, 0.5865963481481528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 269}], {
             RGBColor[
             0.9388172087094733, 0.8032548044052847, 0.5754668836487088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 293}], {
             RGBColor[
             0.9127288328596703, 0.7836368910414045, 0.6140372207929843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 299}], {
             RGBColor[
             0.8978876045529265, 0.7718028984440175, 0.6126216511881661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 66}], {
             RGBColor[
             0.8655316860544315, 0.8956154885008019, 0.9870363789567711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 78}], {
             RGBColor[
             0.9476058849161031, 0.957673955468656, 0.8585713764309079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 97}], {
             RGBColor[
             0.9464517416852463, 0.9552053597996337, 0.7329500082985296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 99}], {
             RGBColor[
             0.9424360167404051, 0.9555442335008785, 0.9448419907441388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 178}], {
             RGBColor[
             0.750570356314908, 0.8050863017564898, 0.9760330652465762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 182}], {
             RGBColor[
             0.907639818211075, 0.9291913700877108, 0.991052690192245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 199}], {
             RGBColor[
             0.8949539157500432, 0.9190759758149332, 0.989842697490673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 215}], {
             RGBColor[
             0.8807750459395594, 0.6937701212734473, 0.5982776296626166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 229}], {
             RGBColor[
             0.9395605058359672, 0.9535227584324864, 0.9552210868516592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 233}], {
             RGBColor[
             0.7800461327717316, 0.8287434828490587, 0.9785398722155758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 259}], {
             RGBColor[
             0.9234789616951222, 0.941529169143356, 0.9824429463436559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 261}], {
             RGBColor[
             0.943627852437344, 0.956037088190343, 0.925090188873949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 284}], {
             RGBColor[
             0.9422311409427235, 0.9554595120934692, 0.948237312913291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 59}], {
             RGBColor[
             0.94164316608966, 0.953774339978223, 0.8953636824693971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 61}], {
             RGBColor[
             0.940270170293922, 0.9532065709323028, 0.9181177760039951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 71}], {
             RGBColor[
             0.8789418543208826, 0.9063083926671494, 0.9883154527774237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 108}], {
             RGBColor[
             0.8274891212045703, 0.8657455766811033, 0.9832846616147118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 136}], {
             RGBColor[
             0.8654679370157135, 0.8955646567477497, 0.9870302985165487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 177}], {
             RGBColor[
             0.9421387519075559, 0.9539792774498974, 0.8871505429318791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 194}], {
             RGBColor[
             0.9392648580630424, 0.9527908484894883, 0.9347784013343257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 204}], {
             RGBColor[
             0.939956259559128, 0.9530767607763275, 0.9233200892544717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 226}], {
             RGBColor[
             0.9413341379415212, 0.9536465488973065, 0.9004850786232679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 252}], {
             RGBColor[
             0.9274928389660746, 0.9443289582049208, 0.9689309250877491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 268}], {
             RGBColor[
             0.9234851096918111, 0.9413400002742294, 0.9757149653658759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 279}], {
             RGBColor[
             0.7797226212712645, 0.8284300238943594, 0.978523743304681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 280}], {
             RGBColor[
             0.9409577154967186, 0.9534908885427649, 0.9067233726837086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 283}], {
             RGBColor[
             0.9357775860612547, 0.9505077090234777, 0.9549070092637135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 89}], {
             RGBColor[
             0.8546672008326004, 0.8860525326617035, 0.923578801177974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 94}], {
             RGBColor[
             0.8587283164716385, 0.8871236629793451, 0.8120625881368584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 96}], {
             RGBColor[
             0.8280073660390542, 0.8664794722592604, 0.9832489986427626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 120}], {
             RGBColor[
             0.5795904275845407, 0.6678811238810386, 0.9610176261449234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 131}], {
             RGBColor[
             0.6880813133667263, 0.7562536187045387, 0.9695451728970839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 132}], {
             RGBColor[
             0.7817585137050905, 0.8296018927998112, 0.9788377418203112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 141}], {
             RGBColor[
             0.8468457927101676, 0.880595257503148, 0.9536527905932778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 146}], {
             RGBColor[
             0.7111612659609177, 0.7742838530852575, 0.9718455668772531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 188}], {
             RGBColor[
             0.7169321009529949, 0.7787920732410385, 0.9724207497777442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 236}], {
             RGBColor[
             0.7429200589049484, 0.7990940635089004, 0.97501098655512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 260}], {
             RGBColor[
             0.7820559229417885, 0.8298390388521955, 0.9788661089788079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 281}], {
             RGBColor[
             0.4927652320611423, 0.5884156846744879, 0.9556412475261793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 294}], {
             RGBColor[
             0.8468457927101676, 0.880595257503148, 0.9536527905932778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 60}], {
             RGBColor[
             0.6406010409669843, 0.7130593893760331, 0.9682812415367514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 62}], {
             RGBColor[
             0.9578286774998087, 0.9640832903829983, 0.7183308324227689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 117}], {
             RGBColor[
             0.9483289903774486, 0.9606564873949235, 0.9609798784319133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 158}], {
             RGBColor[
             0.8932317056351224, 0.7072039731281046, 0.6001569950476233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 196}], {
             RGBColor[
             0.9587889044710891, 0.9667290085026186, 0.8658697468885792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 207}], {
             RGBColor[
             0.7096722537698764, 0.7717166405288776, 0.9730053304950421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 212}], {
             RGBColor[
             0.8742412563803543, 0.9025602634637041, 0.9878671055495827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 214}], {
             RGBColor[
             0.9262425068579183, 0.9440246490581723, 0.9928270312421972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 225}], {
             RGBColor[
             0.9555482959044654, 0.9653889335804782, 0.9195750172636724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 265}], {
             RGBColor[
             0.9516566137019663, 0.9631382234218657, 0.9553470801266659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 276}], {
             RGBColor[
             0.8938110911396633, 0.9181647184917638, 0.9897336938591234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.9112893792752832, 0.9321014310156144, 0.9914007885845508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 112}], {
             RGBColor[
             0.5708590356286667, 0.6485845061175413, 0.9634975766026032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 131}], {
             RGBColor[
             0.7713633266029553, 0.8218755774608928, 0.9776969628388721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 133}], {
             RGBColor[
             0.6659804963698932, 0.7361951241386295, 0.9693674586379561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 146}], {
             RGBColor[
             0.7944432791971466, 0.8399058118416116, 0.9799973568190413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 170}], {
             RGBColor[
             0.8652592349022936, 0.8953982433475766, 0.9870103923226601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 190}], {
             RGBColor[
             0.7946880514075108, 0.8400970297526857, 0.9800217534254441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.8606941613763517, 0.890881984477446, 0.9296727152167741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 70}], {
             RGBColor[
             0.771013149953881, 0.8210405997517265, 0.9778110433260155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 71}], {
             RGBColor[
             0.800525313587606, 0.8444632761034714, 0.9806550035689823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 73}], {
             RGBColor[
             0.7187957365407271, 0.7802479595263301, 0.9726064995564646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 100}], {
             RGBColor[
             0.7076562917713707, 0.7715457406095929, 0.9714962238058851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 119}], {
             RGBColor[
             0.8373919889454465, 0.8737697029060365, 0.9810489637468666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 122}], {
             RGBColor[
             0.8640907179017925, 0.8899632112780385, 0.7045009384103846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 138}], {
             RGBColor[
             0.7873789735674727, 0.8339807414193106, 0.9794010939219857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 161}], {
             RGBColor[
             0.830767169608577, 0.8685773112012802, 0.983539498793486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 244}], {
             RGBColor[
             0.7194198822067897, 0.7807355468643409, 0.9726687085634849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 266}], {
             RGBColor[
             0.7256504492736076, 0.7856029132110026, 0.9732897132607456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 54}], {
             RGBColor[
             0.8970018530125383, 0.9207089453982706, 0.9900380315749849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 102}], {
             RGBColor[
             0.7934389414454313, 0.8389196096267859, 0.979950753833011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 143}], {
             RGBColor[
             0.7898324493620128, 0.8361021906008643, 0.9795912924067205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 172}], {
             RGBColor[
             0.9261210529271029, 0.9419960705193797, 0.919878282390604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 174}], {
             RGBColor[
             0.7954954836396635, 0.8405261960192196, 0.9801557307394525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 238}], {
             RGBColor[
             0.8857089085558789, 0.7817290686188632, 0.6154498218130501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 298}], {
             RGBColor[
             0.7039070495407338, 0.7674593644243908, 0.9720644042150256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 206}], {
             RGBColor[
             0.9562868185497093, 0.9318455478997932, 0.6563451323082965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 219}], {
             RGBColor[
             0.9238697753661832, 0.9062083739052273, 0.6605789412500023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 83}], {
             RGBColor[
             0.6897323511221977, 0.753187028155679, 0.9425686455875746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 101}], {
             RGBColor[
             0.8943831942908742, 0.9177680701723665, 0.9602201848906625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 104}], {
             RGBColor[
             0.9814017730457028, 0.9829375093445903, 0.7648192831742908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 116}], {
             RGBColor[
             0.9809987563205824, 0.9820754973207994, 0.7209533997758655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 142}], {
             RGBColor[
             0.9169537761582611, 0.9357652394912972, 0.9623729871381701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 149}], {
             RGBColor[
             0.9183833023069663, 0.9369051048388211, 0.9625093366183868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 197}], {
             RGBColor[
             0.7128580108414304, 0.7731188217359313, 0.9440694054050702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 198}], {
             RGBColor[
             0.9816668527163314, 0.9835044879563991, 0.793671569440118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 204}], {
             RGBColor[
             0.9781287758143928, 0.9826616612300785, 0.8973929412541606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 226}], {
             RGBColor[
             0.9795066541967861, 0.9832314493510573, 0.8745579306229566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 243}], {
             RGBColor[
             0.9082596856825316, 0.9288328077407496, 0.9615437370272889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 254}], {
             RGBColor[
             0.97269036726258, 0.9791531011366273, 0.9311122641181996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 283}], {
             RGBColor[
             0.9739501023165196, 0.9800926094772286, 0.9289798612634024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 53}], {
             RGBColor[
             0.9367942293730178, 0.9523314610417495, 0.9901290761881016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 57}], {
             RGBColor[
             0.9500345703648021, 0.9240347962106459, 0.6586072161414809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 84}], {
             RGBColor[
             0.727749080434744, 0.7863143318501261, 0.9745180555246417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 88}], {
             RGBColor[
             0.8914040645860526, 0.91624542085491, 0.989504109517662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 93}], {
             RGBColor[
             0.9532460124424544, 0.9646011739176129, 0.962280498763777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 124}], {
             RGBColor[
             0.8982949328562118, 0.7100475549458444, 0.6004042630062294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 137}], {
             RGBColor[
             0.9639544590205793, 0.9699654790035127, 0.7997884017512104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 147}], {
             RGBColor[
             0.8441174513662482, 0.8790697325452586, 0.9848533906824507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 217}], {
             RGBColor[
             0.9146077680139459, 0.9347474241205616, 0.9917172994648051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 247}], {
             RGBColor[
             0.9439853565602212, 0.9576945919235755, 0.9779563736065173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 270}], {
             RGBColor[
             0.9144341233364244, 0.934608964568165, 0.9917007370804487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 271}], {
             RGBColor[
             0.9624024568145532, 0.9657545813234925, 0.7066541195193846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 273}], {
             RGBColor[
             0.959824511079038, 0.9692231654942777, 0.9384158819208757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 289}], {
             RGBColor[
             0.9196722188689401, 0.9387856797614775, 0.9922003513084431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 295}], {
             RGBColor[
             0.7958444532090936, 0.841358499496515, 0.9800419893629615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 88}], {
             RGBColor[
             0.8944521674968746, 0.9185690502463644, 0.9860904525271503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 93}], {
             RGBColor[
             0.9562941153532764, 0.9669248033090672, 0.9588668417732652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 107}], {
             RGBColor[
             0.966671087850721, 0.9731175614435236, 0.872051682920657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 124}], {
             RGBColor[
             0.9013430357670338, 0.7123711843372986, 0.5969906060157175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 137}], {
             RGBColor[
             0.9670025619314011, 0.972289108394967, 0.7963747447606986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 147}], {
             RGBColor[
             0.8471655542770701, 0.8813933619367129, 0.9814397336919389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 217}], {
             RGBColor[
             0.917655870924768, 0.9370710535120158, 0.9883036424742933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 247}], {
             RGBColor[
             0.947033459471043, 0.9600182213150299, 0.9745427166160054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 251}], {
             RGBColor[
             0.869837709809306, 0.8991050221532596, 0.9836994822720526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 270}], {
             RGBColor[
             0.9174822262472464, 0.9369325939596194, 0.9882870800899368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 271}], {
             RGBColor[
             0.9654505597253751, 0.9680782107149467, 0.7032404625288728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 273}], {
             RGBColor[
             0.9628726139898599, 0.9715467948857319, 0.9350022249303639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 289}], {
             RGBColor[
             0.9227203217797622, 0.9411093091529319, 0.9887866943179313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 75}], {
             RGBColor[
             0.9408334243737543, 0.9552344701999145, 0.9794982560967755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 102}], {
             RGBColor[
             0.8259401926842889, 0.8648352251416882, 0.9830507521903826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 111}], {
             RGBColor[
             0.7655343581164273, 0.8170208253992667, 0.9774573124982165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 143}], {
             RGBColor[
             0.8223337006008704, 0.8620178061157666, 0.9826912907640922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 163}], {
             RGBColor[
             0.7653522991074938, 0.8168730216941495, 0.9774429801461291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 165}], {
             RGBColor[
             0.9029881243054164, 0.9254822356342062, 0.9906090074749071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 172}], {
             RGBColor[
             0.9586223041659605, 0.967911686034282, 0.9229782807479756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 174}], {
             RGBColor[
             0.8279967348785211, 0.8664418115341219, 0.9832557290968242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 185}], {
             RGBColor[
             0.9593104759239107, 0.960789323492167, 0.7026816760384307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 235}], {
             RGBColor[
             0.9565922596440812, 0.9516201417127683, 0.6921219190833655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 238}], {
             RGBColor[
             0.9182101597947366, 0.8076446841337654, 0.6185498201704218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 298}], {
             RGBColor[
             0.7364083007795915, 0.7933749799392932, 0.9751644025723973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 108}], {
             RGBColor[
             0.8502827687453209, 0.8031900939434514, 0.6229748721500855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 114}], {
             RGBColor[
             0.9462962395063182, 0.8787975557877206, 0.6153755829718868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 208}], {
             RGBColor[
             0.6807306832142856, 0.6665702557755228, 0.6085923537195188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 219}], {
             RGBColor[
             0.908535848255813, 0.8491753215537312, 0.6286542864226152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 242}], {
             RGBColor[
             0.919170702496803, 0.8576552656500683, 0.6296686483139673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 250}], {
             RGBColor[
             0.9642679898932789, 0.891149044286695, 0.5378517392308688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 252}], {
             RGBColor[
             0.9502864865068252, 0.8817734754672688, 0.6086211356231228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 268}], {
             RGBColor[
             0.9462787572325616, 0.8787845175365774, 0.6154051759012495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 283}], {
             RGBColor[
             0.9585712336020054, 0.8879522262858258, 0.5945972197990872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 57}], {
             RGBColor[
             0.9807330441561982, 0.9450408061003974, 0.5182017331264547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 84}], {
             RGBColor[
             0.7584475542261401, 0.8073203417398775, 0.8341125725096155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 110}], {
             RGBColor[
             0.9377795608183506, 0.7709494388664959, 0.46733016239961717`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 148}], {
             RGBColor[
             0.8457014014665462, 0.8773312552489487, 0.8415460440365887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 191}], {
             RGBColor[
             0.9914807235392229, 0.9812952523344657, 0.559954438000558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 217}], {
             RGBColor[
             0.9453062418053421, 0.955753434010313, 0.8513118164497789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 223}], {
             RGBColor[
             0.927468231932025, 0.7241281026657388, 0.4587261368230675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 246}], {
             RGBColor[
             0.9882473937640559, 0.9888162851980271, 0.8145913156781337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 247}], {
             RGBColor[
             0.9746838303516172, 0.9787006018133271, 0.8375508905914911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 251}], {
             RGBColor[
             0.8974880806898802, 0.9177874026515568, 0.8467076562475383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 270}], {
             RGBColor[
             0.9451325971278205, 0.9556149744579165, 0.8512952540654225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 271}], {
             RGBColor[
             0.9931009306059493, 0.9867605912132439, 0.5662486365043585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 278}], {
             RGBColor[
             0.9946498967594148, 0.9909649950838293, 0.6590524631513169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 295}], {
             RGBColor[
             0.8265429270004897, 0.8623645093862664, 0.8396365063479354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.7440375243373503, 0.760341296410477, 0.6395825384875091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 217}], {
             RGBColor[
             0.9308962119165523, 0.9087743886809123, 0.6567817824276725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 223}], {
             RGBColor[
             0.9130582020432352, 0.6771490573363381, 0.2641961028009611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 247}], {
             RGBColor[
             0.9602738004628274, 0.9317215564839264, 0.6430208565693847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 278}], {
             RGBColor[
             0.9802398668706249, 0.9439859497544286, 0.4645224291292105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 295}], {
             RGBColor[
             0.8121328971116999, 0.8153854640568658, 0.6451064723258289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 134}], {
             RGBColor[
             0.9261985957764753, 0.9411693179800004, 0.8813003322897042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 160}], {
             RGBColor[
             0.9274022521247889, 0.9412328677138662, 0.8297913769338583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 164}], {
             RGBColor[
             0.7157024737237863, 0.7770678011977759, 0.9729557143782647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 176}], {
             RGBColor[
             0.9168247177186817, 0.9355371879111576, 0.9580218604243943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 180}], {
             RGBColor[
             0.6929937107819153, 0.7586318044234528, 0.9711679973745411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 187}], {
             RGBColor[
             0.788812420513237, 0.835269168216694, 0.9794992233641322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 215}], {
             RGBColor[
             0.8608183404332139, 0.6778571860130275, 0.5963741412758601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 221}], {
             RGBColor[
             0.9126680550298103, 0.9324371556837079, 0.9650580061253963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 230}], {
             RGBColor[
             0.8348232439524641, 0.871213173182628, 0.984085152248963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[
             0.9257914273368839, 0.9410009433664777, 0.8880481670518761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 288}], {
             RGBColor[
             0.5194764038267667, 0.5983096252585068, 0.9600061116798688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 296}], {
             RGBColor[
             0.8381101221707328, 0.873780907427939, 0.9844127575521366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 297}], {
             RGBColor[
             0.9121509897180413, 0.9320515292208074, 0.9659332628259896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 72}], {
             RGBColor[
             0.9113944124875872, 0.9296548049364733, 0.8924785293474503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 83}], {
             RGBColor[
             0.7007773427132389, 0.7603164557733301, 0.8742579260246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 106}], {
             RGBColor[
             0.9217564938662608, 0.9379172473566215, 0.8934668739196875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 136}], {
             RGBColor[
             0.9146854448620196, 0.9322789848191517, 0.892792430953263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 155}], {
             RGBColor[
             0.9537261586812595, 0.8487546794813693, 0.5264358486212998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[
             0.9884823659093485, 0.9895051765608902, 0.8405405337710399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 197}], {
             RGBColor[
             0.7239030024324717, 0.7802482493535825, 0.8757586858420958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 198}], {
             RGBColor[
             0.9927118443073726, 0.9906339155740502, 0.7253608498771434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 210}], {
             RGBColor[
             0.9807740088659762, 0.9840739587822583, 0.867814337640533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 226}], {
             RGBColor[
             0.9905516457878274, 0.9903608769687084, 0.8062472110599821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 227}], {
             RGBColor[
             0.9808896897874406, 0.9841602334240764, 0.86761852001491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 241}], {
             RGBColor[
             0.822729690062525, 0.8602927097748749, 0.8836668772162409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 290}], {
             RGBColor[
             0.8174908024427685, 0.8562000509493004, 0.8831447138584918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 291}], {
             RGBColor[
             0.9087276009077923, 0.9275283617714167, 0.8922241664782786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 77}], {
             RGBColor[
             0.6222961022443256, 0.6984635281129101, 0.9665353001403726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 95}], {
             RGBColor[
             0.6493403729174342, 0.7199051075842022, 0.9648576744155866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 103}], {
             RGBColor[
             0.6517756558289691, 0.7217213375922152, 0.9607353756698654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 127}], {
             RGBColor[
             0.6681577147460327, 0.7339390503094017, 0.9330048230485369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 145}], {
             RGBColor[
             0.6517825295325603, 0.7217264639890988, 0.9607237402826347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 148}], {
             RGBColor[
             0.5272399506788161, 0.6236683503084968, 0.9572033857230409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 159}], {
             RGBColor[
             0.6044263724267915, 0.6842146906173023, 0.9648308693578801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 168}], {
             RGBColor[
             0.6687280450481699, 0.7343644017149054, 0.932039402612985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 196}], {
             RGBColor[
             0.6764080359736329, 0.7383636606754799, 0.8416349558732932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 205}], {
             RGBColor[
             0.650350592069455, 0.7206585273736974, 0.9631476368985681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 212}], {
             RGBColor[
             0.5918603878828979, 0.6741949156365654, 0.9636323145342967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 225}], {
             RGBColor[
             0.673167427407009, 0.7370235857533396, 0.8953402262483863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 265}], {
             RGBColor[
             0.6692757452045099, 0.7347728755947271, 0.9311122891113798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 276}], {
             RGBColor[
             0.6114302226422069, 0.6897993706646252, 0.9654989028438372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 282}], {
             RGBColor[
             0.5974032887128143, 0.678614674300306, 0.9641610013636601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 71}], {
             RGBColor[
             0.9267863663714506, 0.9424549516926313, 0.9168316787487358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 108}], {
             RGBColor[
             0.8753336332551385, 0.9018921357065852, 0.911800887586024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 136}], {
             RGBColor[
             0.9133124490662816, 0.9317112157732315, 0.9155465244878609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 161}], {
             RGBColor[
             0.9570282223924217, 0.9665689867904401, 0.9197161739732397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 177}], {
             RGBColor[
             0.989983263958124, 0.9901258364753793, 0.8156667689031912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 194}], {
             RGBColor[
             0.9871093701136104, 0.9889374075149701, 0.8632946273056378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 252}], {
             RGBColor[
             0.9753373510166428, 0.9804755172304026, 0.8974471510590613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 268}], {
             RGBColor[
             0.9713296217423791, 0.9774865592997113, 0.904231191337188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 279}], {
             RGBColor[
             0.8275671333218324, 0.8645765829198413, 0.9070399692759931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 280}], {
             RGBColor[
             0.9888022275472866, 0.9896374475682468, 0.8352395986550207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 117}], {
             RGBColor[
             0.9831757584128166, 0.9833150405747502, 0.6867946783026446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 135}], {
             RGBColor[
             0.9915179868701023, 0.988511844249774, 0.62678007814846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 158}], {
             RGBColor[
             0.9280784736704906, 0.7298625263079312, 0.3259717949183546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 186}], {
             RGBColor[
             0.9653381109641412, 0.9700117523139951, 0.7169891626297015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 196}], {
             RGBColor[
             0.9936356725064572, 0.9893875616824451, 0.5916845467593106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 207}], {
             RGBColor[
             0.7445190218052444, 0.7943751937087041, 0.6988201303657735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 212}], {
             RGBColor[
             0.9090880244157222, 0.9252188166435307, 0.7136819054203141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 214}], {
             RGBColor[
             0.9610892748932863, 0.966683202237999, 0.7186418311129283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 225}], {
             RGBColor[
             0.9903950639398333, 0.9880474867603048, 0.6453898171344037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 265}], {
             RGBColor[
             0.9865033817373343, 0.9857967766016924, 0.6811618799973971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 276}], {
             RGBColor[
             0.9286578591750313, 0.9408232716715904, 0.7155484937298546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 286}], {
             RGBColor[
             0.9934878227583293, 0.9884794362992115, 0.532567879622579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 71}], {
             RGBColor[
             0.9256268981871569, 0.9419754818014526, 0.9360470671699563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 73}], {
             RGBColor[
             0.843897321140278, 0.8777601652243114, 0.9279985631574387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 152}], {
             RGBColor[
             0.9670761006430364, 0.9746995498105356, 0.9286840042853447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 161}], {
             RGBColor[
             0.955868754208128, 0.9660895168992616, 0.9389315623944601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 208}], {
             RGBColor[
             0.7046220795398095, 0.7647928276474779, 0.9166337575766778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 244}], {
             RGBColor[
             0.8445214668063405, 0.8782477525623222, 0.9280607721644589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 69}], {
             RGBColor[
             0.7679019779928653, 0.8190430497228411, 0.9775285055345442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 76}], {
             RGBColor[
             0.9517013466202731, 0.9623951602989709, 0.9224075168128694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 85}], {
             RGBColor[
             0.9544522313541166, 0.9617646894877845, 0.7483009506633083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 90}], {
             RGBColor[
             0.9496655783808778, 0.9614648078301254, 0.9521818069742577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 118}], {
             RGBColor[
             0.9551505028534271, 0.9632582216187313, 0.8243034941310734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 121}], {
             RGBColor[
             0.8532453455354061, 0.886054425697143, 0.9858019409054235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 173}], {
             RGBColor[
             0.919019475753254, 0.9382652001192693, 0.9921380920873584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 213}], {
             RGBColor[
             0.8031506936364213, 0.8469201029002005, 0.9808089741652708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 234}], {
             RGBColor[
             0.6607878832573362, 0.7307955969705681, 0.9694518055207293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 239}], {
             RGBColor[
             0.7543436635130859, 0.8080357992330494, 0.9764611453529535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 249}], {
             RGBColor[
             0.9280422978460792, 0.9453382006121449, 0.9887843806648828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 258}], {
             RGBColor[
             0.9509238590093222, 0.9620736491913224, 0.9352924985997637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 263}], {
             RGBColor[
             0.9399748217880459, 0.9542374574303489, 0.9685857301318104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 286}], {
             RGBColor[
             0.9549860559423158, 0.9629064863039971, 0.806404462705294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 70}], {
             RGBColor[
             0.8586737065916015, 0.7666104592868787, 0.6142593514045266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 106}], {
             RGBColor[
             0.8817830019243986, 0.7849276622566936, 0.6164926003530429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 115}], {
             RGBColor[
             0.9516264040490015, 0.8378047702665373, 0.5119007188444626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 138}], {
             RGBColor[
             0.8750395302051932, 0.7795506009544626, 0.6158494020004968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 155}], {
             RGBColor[
             0.9137526667393974, 0.6957650943814413, 0.2494615750546551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 194}], {
             RGBColor[
             0.9485088739674863, 0.8365155914609622, 0.5635662602043952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 200}], {
             RGBColor[
             0.9520480364582489, 0.8379791261032199, 0.5049131786735341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[
             0.940800516924114, 0.8310843736823303, 0.5908400640738882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 211}], {
             RGBColor[
             0.9246903098282361, 0.8190694076082676, 0.61811044247226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 231}], {
             RGBColor[
             0.9261775860533334, 0.8201786157817539, 0.6155928717669346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 241}], {
             RGBColor[
             0.782756198120663, 0.7073031246749469, 0.6066926036495963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 264}], {
             RGBColor[
             0.9453646801492814, 0.8344883191425287, 0.5831141262580987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 291}], {
             RGBColor[
             0.8687541089659302, 0.7745387766714888, 0.615249892911634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 86}], {
             RGBColor[
             0.6440370202424384, 0.719095692739643, 0.9670732366161485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 97}], {
             RGBColor[
             0.9120442090734535, 0.9277697272625823, 0.72966818712205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 162}], {
             RGBColor[
             0.8994323900339909, 0.9218207243187915, 0.9616227208491097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 169}], {
             RGBColor[
             0.8922551978829081, 0.8605394352143712, 0.6325531190346216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 187}], {
             RGBColor[
             0.7743615934077897, 0.8237464709400624, 0.978120890574409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 193}], {
             RGBColor[
             0.8216859980103592, 0.8607166554943861, 0.9828377449534879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 215}], {
             RGBColor[
             0.8463675133277666, 0.6663344887363959, 0.5949958084861369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 228}], {
             RGBColor[
             0.9084848998274209, 0.9282973405846329, 0.9339961802724353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 118}], {
             RGBColor[
             0.9494352647073028, 0.9587010458570184, 0.8237583696146428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 166}], {
             RGBColor[
             0.893897435862134, 0.918233567429697, 0.9897419294958335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 173}], {
             RGBColor[
             0.9133042376071296, 0.9337080243575564, 0.9915929675709276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 195}], {
             RGBColor[
             0.9445437635371723, 0.9572415378392441, 0.9457657805711791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 213}], {
             RGBColor[
             0.7974354554902969, 0.8423629271384876, 0.9802638496488401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 234}], {
             RGBColor[
             0.6550726451112118, 0.7262384212088553, 0.9689066810042986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 263}], {
             RGBColor[
             0.9342595836419214, 0.9496802816686362, 0.9680406056153796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 75}], {
             RGBColor[
             0.6110901735348231, 0.6824896636029074, 0.952273450186383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 83}], {
             RGBColor[
             0.34035530703202255`, 0.465639595608097, 0.9430392276273302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 109}], {
             RGBColor[
             0.4634023604331159, 0.5664710422973878, 0.9525572888876055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 111}], {
             RGBColor[
             0.43579110727749604`, 0.5442760188022596, 0.9502325065878241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 143}], {
             RGBColor[
             0.4925904497619391, 0.5892729995187596, 0.9554664848536998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 163}], {
             RGBColor[
             0.4356090482685625, 0.5441282150971425, 0.9502181742357367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 185}], {
             RGBColor[
             0.6295672250849795, 0.6880445168951599, 0.6754568701280382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 218}], {
             RGBColor[
             0.4450743233280572, 0.5518125517962225, 0.9509633153608651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 235}], {
             RGBColor[
             0.6268490088051499, 0.6788753351157613, 0.6648971131729731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 292}], {
             RGBColor[
             0.6033845539172589, 0.6767428251089223, 0.9653170542514516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 76}], {
             RGBColor[
             0.8039314127099888, 0.8458422664494158, 0.9081172238884836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 85}], {
             RGBColor[
             0.8066822974438324, 0.8452117956382295, 0.7340106577389225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 90}], {
             RGBColor[
             0.8018956444705935, 0.8449119139805705, 0.937891514049872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 118}], {
             RGBColor[
             0.8073805689431428, 0.8467053277691763, 0.8100132012066877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 121}], {
             RGBColor[
             0.7054754116251217, 0.769501531847588, 0.9715116479810378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 126}], {
             RGBColor[
             0.8058264587017878, 0.8466259166674853, 0.8767114075825535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 166}], {
             RGBColor[
             0.7518427400979741, 0.8062378493418548, 0.9759967610878785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 173}], {
             RGBColor[
             0.7712495418429697, 0.8217123062697143, 0.9778477991629726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 195}], {
             RGBColor[
             0.8024890677730124, 0.845245819751402, 0.9320206121632241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 213}], {
             RGBColor[
             0.655380759726137, 0.7303672090506454, 0.966518681240885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 234}], {
             RGBColor[
             0.5130179493470519, 0.6142427031210131, 0.9551615125963435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 239}], {
             RGBColor[
             0.6065737296028015, 0.6914829053834944, 0.9621708524285677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 249}], {
             RGBColor[
             0.7802723639357948, 0.8287853067625899, 0.9744940877404971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 258}], {
             RGBColor[
             0.8031539250990378, 0.8455207553417674, 0.921002205675378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 263}], {
             RGBColor[
             0.7922048878777616, 0.837684563580794, 0.9542954372074246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 285}], {
             RGBColor[
             0.6679201829264977, 0.7401631017579133, 0.9677684937579248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 122}], {
             RGBColor[
             0.8995112910788727, 0.9176340322503003, 0.7080313301206002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 138}], {
             RGBColor[
             0.8227995467445528, 0.8616515623915724, 0.9829314856322011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 211}], {
             RGBColor[
             0.8724503263675958, 0.9011703690453773, 0.9851925261039645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 231}], {
             RGBColor[
             0.8739376025926932, 0.9022795772188636, 0.982674955398639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 266}], {
             RGBColor[
             0.7610710224506878, 0.8132737341832643, 0.9768201049709612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 108}], {
             RGBColor[
             0.8140053172820989, 0.8549939574414318, 0.9819985643594527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 136}], {
             RGBColor[
             0.8519841330932421, 0.884813037508078, 0.9857442012612896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 161}], {
             RGBColor[
             0.8956999064193822, 0.9196708085252867, 0.9899138507466683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 177}], {
             RGBColor[
             0.9286549479850845, 0.9432276582102259, 0.8858644456766198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 208}], {
             RGBColor[
             0.6444532317510637, 0.7183741192735031, 0.967616045928886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 244}], {
             RGBColor[
             0.7843526190175949, 0.8318290441883474, 0.9790430605166671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 252}], {
             RGBColor[
             0.9140090350436032, 0.9335773389652492, 0.9676448278324898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 268}], {
             RGBColor[
             0.9100013057693397, 0.9305883810345579, 0.9744288681106166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 279}], {
             RGBColor[
             0.7662388173487931, 0.8176784046546879, 0.9772376460494216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 280}], {
             RGBColor[
             0.9274739115742472, 0.9427392693030934, 0.9054372754284494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 83}], {
             RGBColor[
             0.62131108126486, 0.6994825926601784, 0.9656106404659388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 87}], {
             RGBColor[
             0.7449354654975999, 0.8007650545830283, 0.9751862446680494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 106}], {
             RGBColor[
             0.8422902324178819, 0.87708338424347, 0.9848195883610263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 109}], {
             RGBColor[
             0.7443581346659534, 0.8003140393494692, 0.9751287017262142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 155}], {
             RGBColor[
             0.8742598972328807, 0.7879208163682176, 0.6177885630626386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 194}], {
             RGBColor[
             0.9090161044609696, 0.9286713134477386, 0.9318932482123787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 210}], {
             RGBColor[
             0.9013077474175973, 0.9232400956691067, 0.9591670520818718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 218}], {
             RGBColor[
             0.7260300975608946, 0.7856555488483039, 0.9735347281994737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 226}], {
             RGBColor[
             0.9110853843394484, 0.9295270138555568, 0.897599925501321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 227}], {
             RGBColor[
             0.9014234283390617, 0.9233263703109247, 0.9589712344562489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 241}], {
             RGBColor[
             0.7432634286141462, 0.7994588466617233, 0.9750195916575798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 290}], {
             RGBColor[
             0.7380245409943895, 0.7953661878361488, 0.9744974282998307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 291}], {
             RGBColor[
             0.8292613394594135, 0.8666944986582652, 0.9835768809196175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 100}], {
             RGBColor[
             0.690859451535297, 0.7584239213564582, 0.9698220717465498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 119}], {
             RGBColor[
             0.8205951487093728, 0.8606478836529017, 0.9793748116875312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 122}], {
             RGBColor[
             0.8472938776657188, 0.8768413920249039, 0.7028267863510492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 161}], {
             RGBColor[
             0.8139703293725034, 0.8554554919481455, 0.9818653467341507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 244}], {
             RGBColor[
             0.702623041970716, 0.7676137276112062, 0.9709945565041495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 123}], {
             RGBColor[
             0.9272452679954402, 0.9437897027716894, 0.95705518999225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 189}], {
             RGBColor[
             0.8517549489091858, 0.8846302922607505, 0.9857223414692191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 257}], {
             RGBColor[
             0.9362084396002064, 0.9475598947600603, 0.7743095673194473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 260}], {
             RGBColor[
             0.8599530765862795, 0.8911672567382174, 0.9865042862056153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 267}], {
             RGBColor[
             0.9315251565843704, 0.9469510155129177, 0.948439176845105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 287}], {
             RGBColor[
             0.8808009321063273, 0.9077907708299408, 0.9884927732762177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 300}], {
             RGBColor[
             0.9318369978349665, 0.9470799698839938, 0.9432711603034403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 111}], {
             RGBColor[
             0.7768646782387856, 0.8256307346860082, 0.9638175386626353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 143}], {
             RGBColor[
             0.8336640207232288, 0.8706277154025082, 0.969051516928511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.7766826192298522, 0.8254829309808911, 0.9638032063105479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 165}], {
             RGBColor[
             0.9143184444277748, 0.9340921449209477, 0.9769692336393259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 185}], {
             RGBColor[
             0.9706407960462691, 0.9693992327789085, 0.6890419022028494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 235}], {
             RGBColor[
             0.9679225797664396, 0.9602300509995099, 0.6784821452477844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 262}], {
             RGBColor[
             0.8943750747261067, 0.9181898432691868, 0.9750670172335245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 292}], {
             RGBColor[
             0.9444581248785484, 0.9580975409926709, 0.978902086326263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 85}], {
             RGBColor[
             0.9904816660712401, 0.9885639062143592, 0.6788896690172477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 87}], {
             RGBColor[
             0.8228367806466939, 0.8609517721841402, 0.9097687403570591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 90}], {
             RGBColor[
             0.9856950130980011, 0.9882640245567003, 0.8827705253281972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 126}], {
             RGBColor[
             0.9896258273291956, 0.989978027243615, 0.8215904188608787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 151}], {
             RGBColor[
             0.9800939616594383, 0.9840867695647, 0.8922516444255075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 153}], {
             RGBColor[
             0.85746246493079, 0.8880016199118235, 0.9132199049710811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 192}], {
             RGBColor[
             0.8526231808904405, 0.8842211344395815, 0.9127375703636196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 220}], {
             RGBColor[
             0.9751371333783234, 0.9372534497580652, 0.5809925892000987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 239}], {
             RGBColor[
             0.7903730982302093, 0.8348350159596242, 0.9070498637068929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 248}], {
             RGBColor[
             0.989076433443375, 0.9897508387530495, 0.830695297334724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 258}], {
             RGBColor[
             0.9869532937264456, 0.9888728659178971, 0.8658812169537032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 82}], {
             RGBColor[
             0.6766527178846315, 0.7451748064041191, 0.9701010021086791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 95}], {
             RGBColor[
             0.913416302692232, 0.933674594148218, 0.9873465240344937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 103}], {
             RGBColor[
             0.9158515856037668, 0.935490824156231, 0.9832242252887726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 127}], {
             RGBColor[
             0.9322336445208305, 0.9477085368734174, 0.9554936726674441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 145}], {
             RGBColor[
             0.915858459307358, 0.9354959505531145, 0.9832125899015418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 154}], {
             RGBColor[
             0.9369359966623958, 0.9506659708437738, 0.9229228350974581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 159}], {
             RGBColor[
             0.8685023022015892, 0.8979841771813182, 0.9873197189767873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 167}], {
             RGBColor[
             0.7854825619263628, 0.8328808041041613, 0.9791108246666127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 168}], {
             RGBColor[
             0.9328039748229675, 0.948133888278921, 0.9545282522318921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 203}], {
             RGBColor[
             0.8966446236786003, 0.7904489110156419, 0.6164928800838834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 205}], {
             RGBColor[
             0.9144265218442527, 0.934428013937713, 0.9856364865174753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 212}], {
             RGBColor[
             0.8559363176576956, 0.8879644022005813, 0.9861211641532038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 225}], {
             RGBColor[
             0.9372433571818067, 0.9507930723173552, 0.9178290758672936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 255}], {
             RGBColor[
             0.8533654420705918, 0.5348628250793875, 0.5780765577921934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 265}], {
             RGBColor[
             0.9333516749793076, 0.9485423621587429, 0.953601138730287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 269}], {
             RGBColor[
             0.933997436100231, 0.9490239697453906, 0.9525080335940382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 276}], {
             RGBColor[
             0.8755061524170047, 0.9035688572286409, 0.9879877524627445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 282}], {
             RGBColor[
             0.8614792184876121, 0.8923841608643217, 0.9866498509825672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 293}], {
             RGBColor[
             0.907909060250428, 0.9294060563815105, 0.9910783707383137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 99}], {
             RGBColor[
             0.9901026829902839, 0.9901670679316812, 0.8130951670417959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 131}], {
             RGBColor[
             0.8242777427354895, 0.8606828252017492, 0.8464506742050584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 170}], {
             RGBColor[
             0.9181736510348278, 0.934205491088433, 0.8557641036888465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 178}], {
             RGBColor[
             0.7982370225647868, 0.8397091361872926, 0.8442862415442333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 182}], {
             RGBColor[
             0.9553064844609536, 0.9638142045185136, 0.859305866489902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 190}], {
             RGBColor[
             0.8476024675400451, 0.8789042774935423, 0.8487754647916305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.942620581999922, 0.953698810245736, 0.8580958737883301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 209}], {
             RGBColor[
             0.9945443623624591, 0.9907392676799055, 0.647565695325499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 229}], {
             RGBColor[
             0.9872271720858459, 0.9881455928632892, 0.8234742631493163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 261}], {
             RGBColor[
             0.9912945186872228, 0.9906599226211458, 0.7933433651716061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 284}], {
             RGBColor[
             0.9898978071926023, 0.9900823465242721, 0.8164904892109481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 144}], {
             RGBColor[
             0.6920578774375492, 0.7576441957243445, 0.971356584409589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 160}], {
             RGBColor[
             0.9431467228708085, 0.9537870813144688, 0.8312930986088686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 176}], {
             RGBColor[
             0.9325691884647012, 0.9480914015117603, 0.9595235820994046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 221}], {
             RGBColor[
             0.92841252577583, 0.9449913692843106, 0.9665597278004066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 232}], {
             RGBColor[
             0.7623950404781024, 0.8147470733337507, 0.9768937835376591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 240}], {
             RGBColor[
             0.7910721122576329, 0.8372889699731119, 0.979656908290685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 245}], {
             RGBColor[
             0.9415358980829036, 0.9535551569670804, 0.8895498887268862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 288}], {
             RGBColor[
             0.5352208745727863, 0.6108638388591094, 0.9615078333548792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 297}], {
             RGBColor[
             0.927895460464061, 0.94460574282141, 0.9674349845009999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 92}], {
             RGBColor[
             0.9093753863617879, 0.9263216871242528, 0.7845371752964174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 125}], {
             RGBColor[
             0.9095361534673307, 0.9266655517069611, 0.8020356825951838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 128}], {
             RGBColor[
             0.9092174897726506, 0.9259839622858816, 0.7673511059936013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 145}], {
             RGBColor[
             0.885058806919856, 0.9109371437736129, 0.9802748915616477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 149}], {
             RGBColor[
             0.8463843205520842, 0.880347898990621, 0.9852100861421021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 150}], {
             RGBColor[
             0.8960832628391067, 0.9191591649473002, 0.9616133633289623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 156}], {
             RGBColor[
             0.5910780224533829, 0.6735423005473209, 0.9635709399763319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 167}], {
             RGBColor[
             0.7546829095388609, 0.8083219973246596, 0.9761731263267185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 179}], {
             RGBColor[
             0.8199780671611969, 0.8593310707208064, 0.9826811374205726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 201}], {
             RGBColor[
             0.8247124903701504, 0.863067369869706, 0.9831430076326781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 205}], {
             RGBColor[
             0.8836268694567507, 0.9098692071582114, 0.982698788177581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 237}], {
             RGBColor[
             0.8966229582617199, 0.9195616689098149, 0.960699799753588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 256}], {
             RGBColor[
             0.5385235398002698, 0.6228010594676295, 0.9604133881442527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 269}], {
             RGBColor[
             0.903197783712729, 0.924465162965889, 0.949570335254144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 277}], {
             RGBColor[
             0.7543818724359451, 0.8080868248518951, 0.9761431217616515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 281}], {
             RGBColor[
             0.5437117494689743, 0.6282541967809303, 0.9607088490096172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 282}], {
             RGBColor[
             0.8306795661001101, 0.86782535408482, 0.9837121526426731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 293}], {
             RGBColor[
             0.877109407862926, 0.9048472496020088, 0.9881406723984194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 86}], {
             RGBColor[
             0.7171556408141231, 0.7526541695180605, 0.6584728188354507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 94}], {
             RGBColor[
             0.985969167550415, 0.9630528792871189, 0.5088326741899983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 97}], {
             RGBColor[
             0.9851628296451382, 0.9613282040409998, 0.4210677693413521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.9712459660522331, 0.9544059010060659, 0.6552314030872575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 140}], {
             RGBColor[
             0.7393945170681879, 0.7707086911110687, 0.6602235446378586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 162}], {
             RGBColor[
             0.9725510106056756, 0.9553792010972091, 0.6530223030684119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 167}], {
             RGBColor[
             0.8309772432098053, 0.8444127015259911, 0.6678756108964206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 181}], {
             RGBColor[
             0.9842658772567823, 0.9629567703431501, 0.5812736194013519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 201}], {
             RGBColor[
             0.9010068240410949, 0.8991580740710375, 0.6748454922023803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 202}], {
             RGBColor[
             0.883584181038951, 0.8855096411856556, 0.6731189788194449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 203}], {
             RGBColor[
             0.9421393049620428, 0.8019808084374718, 0.30525766631369133`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 216}], {
             RGBColor[
             0.8507760683975523, 0.8598796942393037, 0.6698489727605945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 237}], {
             RGBColor[
             0.9729172919326643, 0.9556523731111466, 0.6524022843232902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 269}], {
             RGBColor[
             0.9794921173836734, 0.9605558671672205, 0.6412728198238462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 293}], {
             RGBColor[
             0.9534037415338703, 0.9409379538033404, 0.6798431569681216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 299}], {
             RGBColor[
             0.9385625132271265, 0.9291039612059533, 0.6784275873633034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 103}], {
             RGBColor[
             0.706132271469275, 0.7684326158834243, 0.964301077638172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 140}], {
             RGBColor[
             0.4841805216502537, 0.5921185854164321, 0.9525356107574499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 145}], {
             RGBColor[
             0.7061391451728661, 0.7684377422803078, 0.9642894422509412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 154}], {
             RGBColor[
             0.7272166825279041, 0.7836077625709671, 0.9039996874468574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 167}], {
             RGBColor[
             0.575763247791871, 0.6658225958313546, 0.960187677016012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 168}], {
             RGBColor[
             0.7230846606884757, 0.7810756800061143, 0.9356051045812914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 181}], {
             RGBColor[
             0.7290518818388481, 0.7843666646485135, 0.8735856855209432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 201}], {
             RGBColor[
             0.6457928286231606, 0.720567968376401, 0.9671575583219716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 203}], {
             RGBColor[
             0.6869253095441086, 0.6233907027428351, 0.5975697324332827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 216}], {
             RGBColor[
             0.595562072979618, 0.681289588544667, 0.9621610388801858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 255}], {
             RGBColor[
             0.6436461279361, 0.36780461680658083`, 0.5591534101415926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 258}], {
             RGBColor[
             0.7265546049328172, 0.7833339764707806, 0.914972026599338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 293}], {
             RGBColor[
             0.6981897461159361, 0.7623478481087038, 0.972155223087713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 101}], {
             RGBColor[
             0.6153448546591883, 0.6947252855137227, 0.9650415764461766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 142}], {
             RGBColor[
             0.6379154365265752, 0.7127224548326534, 0.9671943786936842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 149}], {
             RGBColor[
             0.6393449626752804, 0.7138623201801773, 0.9673307281739008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 194}], {
             RGBColor[
             0.6983990346866213, 0.7593329642845953, 0.9136726448895285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[
             0.4338196712097445, 0.5500760370772875, 0.9488907969605843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 198}], {
             RGBColor[
             0.7026285130846455, 0.7604617032977553, 0.7984929609956319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 226}], {
             RGBColor[
             0.7004683145651001, 0.7601886646924135, 0.8793793221784707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 241}], {
             RGBColor[
             0.5326463588397978, 0.63012049749858, 0.9567989883347294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 243}], {
             RGBColor[
             0.6292213460508457, 0.7057900230821058, 0.966365128582803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 290}], {
             RGBColor[
             0.5274074712200413, 0.6260278386730055, 0.9562768249769804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 291}], {
             RGBColor[
             0.6186442696850651, 0.6973561494951219, 0.9653562775967672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 191}], {
             RGBColor[
             0.7547852037203749, 0.7965957426445451, 0.6813352433616123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 217}], {
             RGBColor[
             0.7086107219864941, 0.7710539243203924, 0.9726926218108334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 223}], {
             RGBColor[
             0.690772712113177, 0.5394285929758182, 0.5801069421841218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 246}], {
             RGBColor[
             0.7515518739452078, 0.8041167755081066, 0.9359721210391881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 247}], {
             RGBColor[
             0.7379883105327693, 0.7940010921234066, 0.9589316959525456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 270}], {
             RGBColor[
             0.7084370773089725, 0.770915464767996, 0.972676059426477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 271}], {
             RGBColor[
             0.7564054107871012, 0.8020610815233233, 0.6876294418654129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 278}], {
             RGBColor[
             0.7579543769405668, 0.8062654853939089, 0.7804332685123714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 295}], {
             RGBColor[
             0.5898474071816417, 0.677664999696346, 0.9610173117089897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[
             0.892025664986373, 0.9122231716125313, 0.7422840931098019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 135}], {
             RGBColor[
             0.9917965395050558, 0.9891076401699479, 0.6570988134355533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 154}], {
             RGBColor[
             0.990366256055376, 0.9885161812068973, 0.6808023116516615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 173}], {
             RGBColor[
             0.957799795204221, 0.9644339460346577, 0.7486202442917367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 213}], {
             RGBColor[
             0.8419310130873883, 0.8730888488155888, 0.7372911263696491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 234}], {
             RGBColor[
             0.6995682027083032, 0.7569643428859565, 0.7259339577251076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 239}], {
             RGBColor[
             0.7931239829640528, 0.8342045451484379, 0.7329432975573318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 249}], {
             RGBColor[
             0.9668226172970461, 0.9715069465275333, 0.7452665328692611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 255}], {
             RGBColor[
             0.9067957014635719, 0.5727130354425111, 0.3359560343463967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 258}], {
             RGBColor[
             0.9897041784602891, 0.9882423951067109, 0.6917746508041421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 263}], {
             RGBColor[
             0.9787551412390129, 0.9804062033457375, 0.7250678823361887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 286}], {
             RGBColor[
             0.9937663753932827, 0.9890752322193856, 0.5628866149096723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[
             0.7257634137785298, 0.780410239284594, 0.8007517708065532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 97}], {
             RGBColor[
             0.7249570758732531, 0.7786855640384749, 0.7129868659579071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 120}], {
             RGBColor[
             0.4466255248914319, 0.5611677001862875, 0.9497068088146183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 130}], {
             RGBColor[
             0.7110402122803481, 0.771763261003541, 0.9471504997038125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 140}], {
             RGBColor[
             0.4791887632963029, 0.5880660511085436, 0.9521426412544135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 162}], {
             RGBColor[
             0.7123452568337905, 0.7727365610946839, 0.9449413996849669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 169}], {
             RGBColor[
             0.7051680646827077, 0.7114552719902636, 0.6158717978704789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[
             0.5290756905029148, 0.6285665059953309, 0.9560699229059536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 182}], {
             RGBColor[
             0.6861451523990817, 0.752671574326552, 0.9710895478516224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 202}], {
             RGBColor[
             0.6233784272670658, 0.7028670011831306, 0.965038075436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 261}], {
             RGBColor[
             0.7221331866253509, 0.7795172924291841, 0.9051270465333264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 284}], {
             RGBColor[
             0.7207364751307304, 0.7789397163323104, 0.9282741705726685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 109}], {
             RGBColor[
             0.6573654491243449, 0.7322581521091758, 0.9664837026054744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 140}], {
             RGBColor[
             0.5796852097531795, 0.6694148700221433, 0.9602173063020655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 151}], {
             RGBColor[
             0.8151999609687357, 0.8558441647232946, 0.9490241496157579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[
             0.8227213706308298, 0.8609040471766782, 0.911681382991473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 155}], {
             RGBColor[
             0.7872672116912722, 0.7198649291279242, 0.6091435639418988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 162}], {
             RGBColor[
             0.8128417032906672, 0.8540853800082837, 0.9530160647326189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 181}], {
             RGBColor[
             0.8245565699417738, 0.8616629492542247, 0.8812673810655589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 202}], {
             RGBColor[
             0.7238748737239425, 0.7842158200967302, 0.9731127404836519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 203}], {
             RGBColor[
             0.7824299976470344, 0.7006869873485464, 0.6052514279778982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 216}], {
             RGBColor[
             0.6910667610825438, 0.7585858731503783, 0.9698427344248014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 227}], {
             RGBColor[
             0.8144307427974533, 0.8552704830706312, 0.9503262353355091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 258}], {
             RGBColor[
             0.8220592930357431, 0.8606302610764918, 0.9226537221439537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 299}], {
             RGBColor[
             0.778853205912118, 0.8278101401170279, 0.9784213490275104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 93}], {
             RGBColor[
             0.9109039505663112, 0.9308387631222278, 0.9582418751028257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 107}], {
             RGBColor[
             0.9212809230637558, 0.9370315212566842, 0.8714267162502174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 124}], {
             RGBColor[
             0.8559528709800686, 0.6762851441504593, 0.596365639345278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 137}], {
             RGBColor[
             0.921612397144436, 0.9362030682081276, 0.7957497780902589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 147}], {
             RGBColor[
             0.801775389490105, 0.8453073217498734, 0.9808147670214993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 273}], {
             RGBColor[
             0.9174824492028948, 0.9354607546988926, 0.9343772582599243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 274}], {
             RGBColor[
             0.7759983787840297, 0.82517012507375, 0.9782455554941785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 289}], {
             RGBColor[
             0.8773301569927969, 0.9050232689660924, 0.9881617276474917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 94}], {
             RGBColor[
             0.9905158248757835, 0.9897378187360109, 0.7626278392022167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 120}], {
             RGBColor[
             0.7113779359886856, 0.7704952796377044, 0.9115828772102816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 131}], {
             RGBColor[
             0.8198688217708714, 0.8588677744612044, 0.9201104239624421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 141}], {
             RGBColor[
             0.9786333011143125, 0.9832094132598138, 0.9042180416586361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 188}], {
             RGBColor[
             0.8487196093571399, 0.8814062289977043, 0.9229860008431026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 236}], {
             RGBColor[
             0.8747075673090934, 0.9017082192655662, 0.9255762376204784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 260}], {
             RGBColor[
             0.9138434313459334, 0.9324531946088612, 0.9294313600441662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 281}], {
             RGBColor[
             0.6245527404652873, 0.6910298404311537, 0.9062064985915377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 294}], {
             RGBColor[
             0.9786333011143125, 0.9832094132598138, 0.9042180416586361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 118}], {
             RGBColor[
             0.9891441693311552, 0.9891270858764607, 0.7846665026464013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 126}], {
             RGBColor[
             0.9875900590898004, 0.9890476747747696, 0.8513647090222671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 153}], {
             RGBColor[
             0.8554266966913948, 0.8870712674429782, 0.9429941951324694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.9336063404859865, 0.9486596074491391, 0.950650062527592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 195}], {
             RGBColor[
             0.9842526681610249, 0.9876675778586863, 0.9066739136029376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 222}], {
             RGBColor[
             0.7986658831708369, 0.8422898482583396, 0.9376372554093497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 234}], {
             RGBColor[
             0.6947815497350643, 0.7566644612282974, 0.9298148140360571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 239}], {
             RGBColor[
             0.7883373299908141, 0.8339046634907787, 0.9368241538682813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 248}], {
             RGBColor[
             0.9870406652039798, 0.988820486284204, 0.8604695874961124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 285}], {
             RGBColor[
             0.8496837833145101, 0.8825848598651976, 0.9424217951976384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 93}], {
             RGBColor[
             0.9839500241631438, 0.9857293234422306, 0.8304950356560759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 105}], {
             RGBColor[
             0.8276535983904068, 0.8633499876798973, 0.8483666756305559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 107}], {
             RGBColor[
             0.9943269966605883, 0.9919220815766869, 0.7436798768034676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 139}], {
             RGBColor[
             0.9914478269920499, 0.9907314709274608, 0.7913951692634029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 142}], {
             RGBColor[
             0.9301455057331067, 0.9437823984339011, 0.8584852636037454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 143}], {
             RGBColor[
             0.8551592234269598, 0.8848375910089454, 0.8511081792795194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 150}], {
             RGBColor[
             0.9812739741688342, 0.9837335297381042, 0.8350248902708222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 163}], {
             RGBColor[
             0.7981778219335831, 0.8396928065873284, 0.8458598686615564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 179}], {
             RGBColor[
             0.9051687784909245, 0.9239054355116104, 0.8560926643624325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 235}], {
             RGBColor[
             0.9894177824701706, 0.9744399266059471, 0.5605388075987927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 273}], {
             RGBColor[
             0.9905285227997274, 0.9903513150188954, 0.8066304188131745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 274}], {
             RGBColor[
             0.8490444523808622, 0.8800606853937529, 0.8504987160474287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 298}], {
             RGBColor[
             0.7692338236056808, 0.816194764832472, 0.8435812910878245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 125}], {
             RGBColor[
             0.9941388125849994, 0.9898718377132912, 0.6034241048121098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 128}], {
             RGBColor[
             0.9938201488903191, 0.9891902482922119, 0.5687395282105274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 142}], {
             RGBColor[
             0.9295574535210477, 0.9424143196494272, 0.7864621588788117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 149}], {
             RGBColor[
             0.9309869796697527, 0.9435541849969512, 0.7865985083590282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 150}], {
             RGBColor[
             0.9806859219567752, 0.9823654509536304, 0.7630017855458884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 179}], {
             RGBColor[
             0.9045807262788654, 0.9225373567271367, 0.7840695596374987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 237}], {
             RGBColor[
             0.9812256173793885, 0.9827679549161452, 0.7620882219705141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 243}], {
             RGBColor[
             0.9208633630453181, 0.9354818878988798, 0.7856329087679303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 256}], {
             RGBColor[
             0.6231261989179384, 0.6860073454739598, 0.7618018103611788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 269}], {
             RGBColor[
             0.9878004428303975, 0.9876714489722191, 0.7509587574710701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 277}], {
             RGBColor[
             0.8389845315536137, 0.8712931108582254, 0.7775315439785776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 281}], {
             RGBColor[
             0.6283144085866429, 0.6914604827872606, 0.7620972712265432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 105}], {
             RGBColor[
             0.816449472649976, 0.8568151804225974, 0.9488899043234207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 107}], {
             RGBColor[
             0.9831228709201576, 0.985387274319387, 0.8442031054963324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 137}], {
             RGBColor[
             0.9834543450008377, 0.9845588212708305, 0.7685261673363739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 139}], {
             RGBColor[
             0.9802437012516191, 0.9841966636701609, 0.8919183979562676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 147}], {
             RGBColor[
             0.8636173373465067, 0.8936630748125763, 0.9535911562676143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 273}], {
             RGBColor[
             0.9793243970592965, 0.9838165077615955, 0.9071536475060392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 274}], {
             RGBColor[
             0.8378403266404314, 0.873525878136453, 0.9510219447402934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 289}], {
             RGBColor[
             0.9391721048491988, 0.9533790220287954, 0.9609381168936066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 97}], {
             RGBColor[
             0.993770602609545, 0.9890842738075333, 0.5633467213124548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 120}], {
             RGBColor[
             0.7154390516277238, 0.7715664099553459, 0.800066664169166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 130}], {
             RGBColor[
             0.9798537390166397, 0.9821619707725994, 0.7975103550583602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 141}], {
             RGBColor[
             0.9826944167533507, 0.9842805435774553, 0.7927018286175205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 188}], {
             RGBColor[
             0.852780724996178, 0.8824773593153459, 0.8114697878019868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 201}], {
             RGBColor[
             0.9096145970055015, 0.926914143837571, 0.8171244441734828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 202}], {
             RGBColor[
             0.8921919540033576, 0.913265710952189, 0.8153979307905477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.981525064897071, 0.9834084428776799, 0.7946812362943927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 281}], {
             RGBColor[
             0.6286138561043254, 0.6921009707487953, 0.7946902855504219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 293}], {
             RGBColor[
             0.962011514498277, 0.9686940235698738, 0.8221221089392243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 294}], {
             RGBColor[
             0.9826944167533507, 0.9842805435774553, 0.7927018286175205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 103}], {
             RGBColor[
             0.9428958562768753, 0.9569324036275231, 0.9815465995639866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 127}], {
             RGBColor[
             0.959277915193939, 0.9691501163447095, 0.9538160469426581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 145}], {
             RGBColor[
             0.9429027299804664, 0.9569375300244066, 0.9815349641767559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 148}], {
             RGBColor[
             0.8183601511267223, 0.8588794163438047, 0.978014609617162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 156}], {
             RGBColor[
             0.6489219455139934, 0.7195426867981147, 0.9648310125914401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 159}], {
             RGBColor[
             0.8955465728746976, 0.9194257566526103, 0.9856420932520013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 168}], {
             RGBColor[
             0.959848245496076, 0.9695754677502131, 0.9528506265071062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 191}], {
             RGBColor[
             0.9641394731993991, 0.9628434134293217, 0.6964230035811313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 205}], {
             RGBColor[
             0.9414707925173612, 0.9558695934090051, 0.9839588607926892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 212}], {
             RGBColor[
             0.8829805883308042, 0.9094059816718734, 0.9844435384284178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 225}], {
             RGBColor[
             0.9642876278549153, 0.9722346517886473, 0.9161514501425074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 251}], {
             RGBColor[
             0.8701468303500564, 0.8993355637464128, 0.9831762218281116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 271}], {
             RGBColor[
             0.9657596802661255, 0.9683087523080999, 0.7027172020849318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 276}], {
             RGBColor[
             0.9025504230901131, 0.925010436699933, 0.9863101267379584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 282}], {
             RGBColor[
             0.8885234891607205, 0.9138257403356138, 0.9849722252577813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 112}], {
             RGBColor[
             0.5927046960030367, 0.6660036427154098, 0.9655812351909618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 132}], {
             RGBColor[
             0.8868861873156894, 0.9126429881540339, 0.9890731903504582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 133}], {
             RGBColor[
             0.6878261567442631, 0.7536142607364981, 0.9714511172263148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 146}], {
             RGBColor[
             0.8162889395715165, 0.8573249484394802, 0.9820810154074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 236}], {
             RGBColor[
             0.8480477325155472, 0.8821351588631231, 0.985246435085267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 260}], {
             RGBColor[
             0.8871835965523873, 0.9128801342064181, 0.9891015575089548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 267}], {
             RGBColor[
             0.9587556765504782, 0.9686638929811183, 0.9510364481484446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 120}], {
             RGBColor[
             0.7146327137224471, 0.7698417347092268, 0.7123017593205198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 130}], {
             RGBColor[
             0.9790474011113631, 0.9804372955264803, 0.7097454502097139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 178}], {
             RGBColor[
             0.79708287933393, 0.8372405405182702, 0.718664873411855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 182}], {
             RGBColor[
             0.9541523412300968, 0.9613456088494914, 0.7336844983575239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 202}], {
             RGBColor[
             0.891385616098081, 0.9115410357060699, 0.7276330259419015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 261}], {
             RGBColor[
             0.990140375456366, 0.9881913269521234, 0.6677219970392279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 284}], {
             RGBColor[
             0.9887436639617455, 0.9876137508552498, 0.6908691210785699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 157}], {
             RGBColor[
             0.9687729922999168, 0.9151128229760681, 0.5713408218065812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.9471406122648013, 0.8994602033547108, 0.6294888400866653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 275}], {
             RGBColor[
             0.9718352705217855, 0.914592019626089, 0.3906851642294628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 285}], {
             RGBColor[
             0.8330842270867521, 0.809567005671357, 0.6256480192341567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 182}], {
             RGBColor[
             0.9501366162852557, 0.961684482550736, 0.945576480803133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 199}], {
             RGBColor[
             0.9374507138242241, 0.9515690882779584, 0.944366488101561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 209}], {
             RGBColor[
             0.9893744941867613, 0.988609545712128, 0.7338363096387299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 215}], {
             RGBColor[
             0.9232718440137402, 0.7262632337364725, 0.5528014202735045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 229}], {
             RGBColor[
             0.9820573039101479, 0.9860158708955116, 0.9097448774625472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 233}], {
             RGBColor[
             0.8225429308459125, 0.861236595312084, 0.9330636628264637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 259}], {
             RGBColor[
             0.965975759769303, 0.9740222816063813, 0.9369667369545438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 284}], {
             RGBColor[
             0.9847279390169044, 0.9879526245564945, 0.9027611035241789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 119}], {
             RGBColor[
             0.8094557039400164, 0.8519456647361645, 0.9782645359369517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 122}], {
             RGBColor[
             0.8361544328963624, 0.8681391731081667, 0.7017165106004697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 161}], {
             RGBColor[
             0.8028308846031469, 0.8467532730314083, 0.9807550709835712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 244}], {
             RGBColor[
             0.6914835972013595, 0.758911508694469, 0.9698842807535699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 266}], {
             RGBColor[
             0.6977141642681775, 0.7637788750411307, 0.9705052854508307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 104}], {
             RGBColor[
             0.9070142765826934, 0.9244757667026342, 0.7872922140328928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 116}], {
             RGBColor[
             0.9066112598575731, 0.9236137546788432, 0.7434263306344675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 136}], {
             RGBColor[
             0.829252956807969, 0.8666878145595444, 0.9835760813748395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 149}], {
             RGBColor[
             0.843995805843957, 0.8784433621968649, 0.9849822674769888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 197}], {
             RGBColor[
             0.6384705143784211, 0.7146570790939751, 0.9665423362636723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 198}], {
             RGBColor[
             0.907279356253322, 0.925042745314443, 0.81614450029872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[
             0.9037412793513835, 0.9241999185881222, 0.9198658721127626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 226}], {
             RGBColor[
             0.9051191577337767, 0.9247697067091012, 0.8970308614815586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 243}], {
             RGBColor[
             0.8338721892195222, 0.8703710650987935, 0.9840166678858909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 254}], {
             RGBColor[
             0.8983028707995706, 0.9206913584946712, 0.9535851949768016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 283}], {
             RGBColor[
             0.8995626058535102, 0.9216308668352724, 0.9514527921220044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 165}], {
             RGBColor[
             0.7994252127383095, 0.8436928998627214, 0.9805217297329332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 172}], {
             RGBColor[
             0.8550593925988536, 0.8861223502627973, 0.9128910030060017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 175}], {
             RGBColor[
             0.8313165718248081, 0.7919436617022927, 0.6218750714740514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 183}], {
             RGBColor[
             0.8536931909574854, 0.885557390774311, 0.9355324998199825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 238}], {
             RGBColor[
             0.8146472482276297, 0.7258553483622807, 0.6084625424284478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 253}], {
             RGBColor[
             0.8553781502348461, 0.8862541647369779, 0.9076083640592874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 127}], {
             RGBColor[
             0.9617131981054738, 0.9709663463527225, 0.949693748196937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 145}], {
             RGBColor[
             0.9453380128920015, 0.9587537600324196, 0.9774126654310347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 154}], {
             RGBColor[
             0.9664155502470393, 0.9739237803230789, 0.917122910626951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 159}], {
             RGBColor[
             0.8979818557862327, 0.9212419866606232, 0.9815197945062801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 167}], {
             RGBColor[
             0.8149621155110063, 0.8561386135834663, 0.9733109001961056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 168}], {
             RGBColor[
             0.962283528407611, 0.9713916977582262, 0.9487283277613849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 203}], {
             RGBColor[
             0.9261241772632438, 0.8137067204949471, 0.6106929556133762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 205}], {
             RGBColor[
             0.9439060754288962, 0.9576858234170182, 0.9798365620469681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 212}], {
             RGBColor[
             0.885415871242339, 0.9112222116798863, 0.9803212396826967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 225}], {
             RGBColor[
             0.9667229107664501, 0.9740508817966604, 0.9120291513967864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 255}], {
             RGBColor[
             0.8828449956552353, 0.5581206345586927, 0.5722766333216862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 265}], {
             RGBColor[
             0.9628312285639511, 0.971800171638048, 0.9478012142597798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 269}], {
             RGBColor[
             0.9634769896848744, 0.9722817792246958, 0.9467081091235311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 276}], {
             RGBColor[
             0.9049857060016481, 0.926826666707946, 0.9821878279922374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 282}], {
             RGBColor[
             0.8909587720722555, 0.9156419703436268, 0.98084992651206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 293}], {
             RGBColor[
             0.9373886138350713, 0.9526638658608156, 0.9852784462678066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 114}], {
             RGBColor[
             0.9743061905126518, 0.977645635509391, 0.7768302535784322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 116}], {
             RGBColor[
             0.9936298386124016, 0.9887831938510669, 0.5480254289180958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 204}], {
             RGBColor[
             0.990759858106212, 0.9893693577603461, 0.7244649703963908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 206}], {
             RGBColor[
             0.9689628424456727, 0.9736605752699674, 0.7858751480874548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 243}], {
             RGBColor[
             0.9208907679743508, 0.9355405042710172, 0.7886157661695192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 254}], {
             RGBColor[
             0.9853214495543992, 0.9858607976668949, 0.7581842932604299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 283}], {
             RGBColor[
             0.9865811846083388, 0.9868003060074962, 0.7560518904056326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 287}], {
             RGBColor[
             0.9384803599163695, 0.9495659674288288, 0.790293477151363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 300}], {
             RGBColor[
             0.9895164256450089, 0.988855166482882, 0.7450718641785856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 139}], {
             RGBColor[
             0.8239472754788821, 0.8618173279078277, 0.9097900379307478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 143}], {
             RGBColor[
             0.6876586719137919, 0.7559234479893123, 0.9695030479468643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 163}], {
             RGBColor[
             0.6306772704204153, 0.7107786635676953, 0.9642547373289012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 174}], {
             RGBColor[
             0.6933217061914426, 0.7603474534076676, 0.9700674862795964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 235}], {
             RGBColor[
             0.8219172309570028, 0.8455257835863139, 0.6789336762661377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 274}], {
             RGBColor[
             0.6815439008676945, 0.7511465423741197, 0.9688935847147736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 298}], {
             RGBColor[
             0.601733272092513, 0.6872806218128389, 0.9619761597551695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 115}], {
             RGBColor[
             0.9224957159211582, 0.9382229346734619, 0.8812160514246833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 155}], {
             RGBColor[
             0.8846219786115542, 0.7961832587883659, 0.6187769076348758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 162}], {
             RGBColor[
             0.9101964702109493, 0.9304037096687253, 0.9626494084255959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 194}], {
             RGBColor[
             0.9193781858396431, 0.9369337558678867, 0.9328815927846159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 200}], {
             RGBColor[
             0.9229173483304057, 0.9383972905101444, 0.8742285112537548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 210}], {
             RGBColor[
             0.9116698287962709, 0.931502538089255, 0.960155396654109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 211}], {
             RGBColor[
             0.8955596217003929, 0.9194875720151923, 0.9874257750524806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 227}], {
             RGBColor[
             0.9117855097177353, 0.931588812731073, 0.959959579028486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 241}], {
             RGBColor[
             0.7536255099928197, 0.8077212890818715, 0.976007936229817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 264}], {
             RGBColor[
             0.9162339920214382, 0.9349064835494534, 0.9524294588383193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 290}], {
             RGBColor[
             0.7483866223730631, 0.8036286302562969, 0.9754857728720678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 291}], {
             RGBColor[
             0.839623420838087, 0.8749569410784134, 0.9845652254918547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 137}], {
             RGBColor[
             0.9938313174982824, 0.9907515794052868, 0.6817110084837656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 139}], {
             RGBColor[
             0.9906206737490637, 0.9903894218046173, 0.8051032391036594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[
             0.8739943098439513, 0.8998558329470328, 0.866775997415006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 150}], {
             RGBColor[
             0.9804468209258479, 0.9833914806152606, 0.8487329601110787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.6754415805401244, 0.7377746162152814, 0.8506905367584483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.9043416252479382, 0.9235633863887669, 0.869800734202689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 251}], {
             RGBColor[
             0.8966664653761872, 0.9175674931635794, 0.8690357459951198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 273}], {
             RGBColor[
             0.9897013695567412, 0.9900092658960518, 0.8203384886534311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 274}], {
             RGBColor[
             0.848217299137876, 0.8797186362709093, 0.8642067858876852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 277}], {
             RGBColor[
             0.8387454305226865, 0.8723191405198556, 0.8632627185437679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 289}], {
             RGBColor[
             0.9495490773466433, 0.9595717801632517, 0.8741229580409984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 136}], {
             RGBColor[
             0.8005313999769299, 0.844250221522032, 0.9807134100985777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 177}], {
             RGBColor[
             0.8772022148687724, 0.9026648422241799, 0.8808336545139079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 204}], {
             RGBColor[
             0.8750197225203444, 0.90176232555061, 0.9170032008365008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 208}], {
             RGBColor[
             0.5930004986347516, 0.6778113032874571, 0.9625852547661741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 252}], {
             RGBColor[
             0.862556301927291, 0.8930145229792031, 0.962614036669778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 254}], {
             RGBColor[
             0.8695813139685316, 0.8982537654571588, 0.9507225237005397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 268}], {
             RGBColor[
             0.8585485726530275, 0.8900255650485118, 0.9693980769479047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 279}], {
             RGBColor[
             0.7147860842324808, 0.7771155886686418, 0.9722068548867098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 280}], {
             RGBColor[
             0.876021178457935, 0.9021764533170473, 0.9004064842657376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 283}], {
             RGBColor[
             0.8708410490224712, 0.8991932737977602, 0.9485901208457425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 111}], {
             RGBColor[
             0.6291768651370786, 0.7096121133804886, 0.9641013773638578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 151}], {
             RGBColor[
             0.8146226301370894, 0.8553931494897355, 0.9489666066739229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 155}], {
             RGBColor[
             0.7866898808596257, 0.7194139138943652, 0.6090860210000637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 192}], {
             RGBColor[
             0.6871518493680915, 0.7555275143646171, 0.9694525326120349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 218}], {
             RGBColor[
             0.6384600811876397, 0.7171486463744514, 0.9648321861368989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 220}], {
             RGBColor[
             0.8096658018559745, 0.8085598296831008, 0.637707551448514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 227}], {
             RGBColor[
             0.8138534119658067, 0.8548194678370722, 0.9502686923936741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 290}], {
             RGBColor[
             0.6504545246211346, 0.7268592853622963, 0.9657948862372558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 292}], {
             RGBColor[
             0.7967703117768414, 0.8420789196871512, 0.9791859250274855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 148}], {
             RGBColor[
             0.7883378882399086, 0.6562608426856466, 0.5961444392876448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 191}], {
             RGBColor[
             0.9341172103125854, 0.7602248397711635, 0.314552833251614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 223}], {
             RGBColor[
             0.8701047187053874, 0.5030576901024366, 0.21332453207412355`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 246}], {
             RGBColor[
             0.9308838805374183, 0.7677458726347249, 0.5691897109291898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 278}], {
             RGBColor[
             0.9372863835327773, 0.7698945825205272, 0.4136508584023729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 295}], {
             RGBColor[
             0.7691794137738521, 0.6412940968229643, 0.5942349015989914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 143}], {
             RGBColor[
             0.6583649544659018, 0.7324140706018605, 0.9670105733299521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 163}], {
             RGBColor[
             0.6013835529725251, 0.6872692861802434, 0.9617622627119891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.795341729788942, 0.8311855879782607, 0.6870009586042906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 218}], {
             RGBColor[
             0.6108488280320199, 0.6949536228793233, 0.9625074038371174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 235}], {
             RGBColor[
             0.7926235135091126, 0.822016406198862, 0.6764412016492254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 262}], {
             RGBColor[
             0.7190760084687797, 0.7799761984685389, 0.9730260736349656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 292}], {
             RGBColor[
             0.7691590586212215, 0.819883896192023, 0.976861142727704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 131}], {
             RGBColor[
             0.4527786433307087, 0.5557777891606881, 0.9518774094452831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 132}], {
             RGBColor[
             0.546455843669073, 0.6291260632559607, 0.9611699783685105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 133}], {
             RGBColor[
             0.34739581309764667`, 0.47009733583842483`, 0.9435479052443672]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 146}], {
             RGBColor[
             0.4758585959249001, 0.5738080235414069, 0.9541778034254523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 170}], {
             RGBColor[
             0.5466745516300471, 0.629300455047372, 0.9611908389290711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 190}], {
             RGBColor[
             0.4761033681352643, 0.5739992414524812, 0.9542022000318551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 115}], {
             RGBColor[
             0.9745815909298631, 0.9792100403433217, 0.8672969735890586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 134}], {
             RGBColor[
             0.9745977238566911, 0.9792167117231625, 0.8670296092408425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 144}], {
             RGBColor[
             0.7247125347717455, 0.7831373758669039, 0.955584139685717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 160}], {
             RGBColor[
             0.9758013802050047, 0.9792802614570282, 0.8155206538849965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 169}], {
             RGBColor[
             0.9551051530685712, 0.9101095262341649, 0.6196607287754831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 176}], {
             RGBColor[
             0.9652238457988974, 0.9735845816543197, 0.9437511373755325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 187}], {
             RGBColor[
             0.8372115485934528, 0.873316561959856, 0.9652285003152703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 193}], {
             RGBColor[
             0.8845359531960224, 0.9102867465141797, 0.9699453546943493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 200}], {
             RGBColor[
             0.9750032233391106, 0.9793843961800043, 0.86030943341813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 228}], {
             RGBColor[
             0.971334855013084, 0.9778674316044266, 0.9211037900132967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 231}], {
             RGBColor[
             0.9491327729341952, 0.9615838858585384, 0.9709891265115306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 245}], {
             RGBColor[
             0.9741905554170998, 0.9790483371096399, 0.8737774440030142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 264}], {
             RGBColor[
             0.968319867030143, 0.9758935892193132, 0.9385103810026947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 288}], {
             RGBColor[
             0.5678755319069826, 0.636357019001669, 0.9457353886310071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 297}], {
             RGBColor[
             0.9605501177982572, 0.9700989229639694, 0.9516625397771278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 116}], {
             RGBColor[
             0.9739031737875314, 0.9767836234856, 0.7329643701800068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 204}], {
             RGBColor[
             0.9710331932813419, 0.9773697873948791, 0.9094039116583019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 206}], {
             RGBColor[
             0.9492361776208025, 0.9616610049045005, 0.970814089349366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 254}], {
             RGBColor[
             0.965594784729529, 0.973861227301428, 0.9431232345223409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 283}], {
             RGBColor[
             0.9668545197834686, 0.9748007356420293, 0.9409908316675437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 134}], {
             RGBColor[
             0.992355250972589, 0.9911067140631464, 0.7763568055678869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 169}], {
             RGBColor[
             0.9728626801844691, 0.9219995285741487, 0.5289879251025276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 193}], {
             RGBColor[
             0.9022934803119204, 0.9221767488541637, 0.8792725510213937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 200}], {
             RGBColor[
             0.9927607504550084, 0.9912743985199881, 0.7696366297451745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 210}], {
             RGBColor[
             0.9815132309208736, 0.9843796460990987, 0.8555635151455288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 211}], {
             RGBColor[
             0.9654030238249957, 0.972364680025036, 0.8828338935439004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 227}], {
             RGBColor[
             0.981628911842338, 0.9844659207409168, 0.8553676975199058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 228}], {
             RGBColor[
             0.9890923821289821, 0.9897574339444104, 0.8304309863403412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 231}], {
             RGBColor[
             0.966890300050093, 0.9734738881985223, 0.8803163228385751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 245}], {
             RGBColor[
             0.9919480825329977, 0.9909383394496237, 0.7831046403300587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 264}], {
             RGBColor[
             0.986077394146041, 0.9877835915592971, 0.8478375773297391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 204}], {
             RGBColor[
             0.9903568413810917, 0.9885073457365551, 0.6805990869979657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 206}], {
             RGBColor[
             0.9685598257205523, 0.9727985632461764, 0.7420092646890296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 254}], {
             RGBColor[
             0.9849184328292788, 0.984998785643104, 0.7143184098620046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 283}], {
             RGBColor[
             0.9861781678832184, 0.9859382939837052, 0.7121860070072074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 287}], {
             RGBColor[
             0.9380773431912491, 0.9487039554050378, 0.7464275937529378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 158}], {
             RGBColor[
             0.9185787865481303, 0.7264357233198565, 0.5686208409274991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 196}], {
             RGBColor[
             0.984135985384097, 0.9859607586943704, 0.834333592768455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 207}], {
             RGBColor[
             0.7350193346828843, 0.7909483907206294, 0.9414691763749179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 212}], {
             RGBColor[
             0.8995883372933622, 0.921792013655456, 0.9563309514294585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 214}], {
             RGBColor[
             0.9515895877709262, 0.9632563992499241, 0.961290877122073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 225}], {
             RGBColor[
             0.9808953768174733, 0.98462068377223, 0.8880388631435482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 265}], {
             RGBColor[
             0.9770036946149742, 0.9823699736136177, 0.9238109260065417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 276}], {
             RGBColor[
             0.9191581720526711, 0.9373964686835157, 0.9581975397389991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 166}], {
             RGBColor[
             0.9390912649585359, 0.9504530212377451, 0.8227717496844078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.9897375926335742, 0.9894609916472923, 0.7787956007597534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 234}], {
             RGBColor[
             0.7002664742076137, 0.7584578750169033, 0.801936501192873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 239}], {
             RGBColor[
             0.7938222544633633, 0.8356980772793847, 0.8089458410250971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 263}], {
             RGBColor[
             0.9794534127383233, 0.9818997354766843, 0.801070425803954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 285}], {
             RGBColor[
             0.8551687077870594, 0.8843782736538035, 0.8145434823544542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 122}], {
             RGBColor[
             0.9658901300704383, 0.9703631354046102, 0.7112692505414512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 161}], {
             RGBColor[
             0.9325665817772228, 0.9489772353278518, 0.9903078109245527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 244}], {
             RGBColor[
             0.8212192943754354, 0.8611354709909125, 0.9794370206945514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 266}], {
             RGBColor[
             0.8274498614422533, 0.8660028373375743, 0.9800580253918122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 131}], {
             RGBColor[
             0.5447920485228116, 0.6406963656805396, 0.9575492489293915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 141}], {
             RGBColor[
             0.7035565278662528, 0.7650380044791489, 0.9416568666255855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 170}], {
             RGBColor[
             0.63868795682215, 0.7142190315672234, 0.9668626784131795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 178}], {
             RGBColor[
             0.5187513283521088, 0.6197226766660828, 0.9553848162685663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 182}], {
             RGBColor[
             0.6758207902482757, 0.743827744997304, 0.9704044412142352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 188}], {
             RGBColor[
             0.5736428361090802, 0.6632348202170395, 0.9604248258100518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 190}], {
             RGBColor[
             0.5681167733273671, 0.6589178179723325, 0.9598740395159635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 261}], {
             RGBColor[
             0.7118088244745449, 0.7706734630999361, 0.9044419398959391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 284}], {
             RGBColor[
             0.7104121129799243, 0.7700958870030624, 0.9275890639352811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 294}], {
             RGBColor[
             0.7035565278662528, 0.7650380044791489, 0.9416568666255855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 135}], {
             RGBColor[
             0.8905896536863451, 0.9133973763793064, 0.8945998036776686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 154}], {
             RGBColor[
             0.8891593702366654, 0.9128059174162557, 0.918303301893777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 173}], {
             RGBColor[
             0.8565929093855105, 0.8887236822440161, 0.986121234533852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.7407241272686778, 0.7973785850249473, 0.9747921166117646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 234}], {
             RGBColor[
             0.5983613168895926, 0.681254079095315, 0.9634349479672231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 239}], {
             RGBColor[
             0.6919170971453423, 0.7584942813577963, 0.9704442877994472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 249}], {
             RGBColor[
             0.8656157314783355, 0.8957966827368917, 0.9827675231113766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 255}], {
             RGBColor[
             0.8055888156448614, 0.49700277165186946`, 0.573457024588512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 258}], {
             RGBColor[
             0.8884972926415786, 0.9125321313160693, 0.9292756410462575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 263}], {
             RGBColor[
             0.8775482554203022, 0.9046959395550959, 0.9625688725783041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 286}], {
             RGBColor[
             0.8925594895745721, 0.913364968428744, 0.8003876051517876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 138}], {
             RGBColor[
             0.9158771146924645, 0.9305741739178843, 0.7096213807165703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 161}], {
             RGBColor[
             0.9592653107335688, 0.965170743699854, 0.7137597855880706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 266}], {
             RGBColor[
             0.8541485903985993, 0.8821963457095763, 0.7035100000553303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 189}], {
             RGBColor[
             0.9003262171871885, 0.9223251823553582, 0.9544876268952387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 257}], {
             RGBColor[
             0.9847797078782092, 0.985254784854668, 0.7430748527454669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 267}], {
             RGBColor[
             0.9800964248623731, 0.9846459056075254, 0.9172044622711246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 287}], {
             RGBColor[
             0.92937220038433, 0.9454856609245484, 0.9572580587022372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 300}], {
             RGBColor[
             0.9804082661129694, 0.9847748599786015, 0.9120364457294599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 147}], {
             RGBColor[
             0.8086662577602641, 0.6391094558408078, 0.5917149205100667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 247}], {
             RGBColor[
             0.9085341629542371, 0.7177343152191248, 0.5848179034341332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 273}], {
             RGBColor[
             0.924373317473054, 0.7292628887898269, 0.5452774117484915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 289}], {
             RGBColor[
             0.8842210252629561, 0.6988254030570268, 0.5990618811360591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 128}], {
             RGBColor[
             0.9939809159958619, 0.9895341128749202, 0.5862380355092938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 130}], {
             RGBColor[
             0.9797150586045, 0.981865347393773, 0.7824158480332477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 142}], {
             RGBColor[
             0.9297182206265905, 0.9427581842321355, 0.803960666177578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.9311477467752955, 0.9438980495796595, 0.8040970156577946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 150}], {
             RGBColor[
             0.980846689062318, 0.9827093155363387, 0.7805002928446547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 167}], {
             RGBColor[
             0.8394463357620723, 0.8718721479136982, 0.7950600558424109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 237}], {
             RGBColor[
             0.9813863844849313, 0.9831118194988535, 0.7795867292692804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 243}], {
             RGBColor[
             0.9210241301508609, 0.9358257524815881, 0.8031314160666967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 256}], {
             RGBColor[
             0.6232869660234812, 0.6863512100566681, 0.7793003176599451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 269}], {
             RGBColor[
             0.9879612099359403, 0.9880153135549274, 0.7684572647698364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 277}], {
             RGBColor[
             0.8391452986591565, 0.8716369754409337, 0.7950300512773439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 281}], {
             RGBColor[
             0.6284751756921857, 0.6918043473699689, 0.7795957785253096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 293}], {
             RGBColor[
             0.9618728340861373, 0.9683974001910474, 0.8070276019141118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 153}], {
             RGBColor[
             0.8593575109225892, 0.8887852701298931, 0.881814088665151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 157}], {
             RGBColor[
             0.9893033627588692, 0.9898446798568237, 0.8269344913027444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 192}], {
             RGBColor[
             0.8545182268822396, 0.885004784657651, 0.8813317540576895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 220}], {
             RGBColor[
             0.9770321793701227, 0.9380370999761347, 0.5495867728941686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 222}], {
             RGBColor[
             0.8025966974020313, 0.8440038509452545, 0.8764571489420312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 239}], {
             RGBColor[
             0.7922681442220084, 0.8356186661776936, 0.8756440474009628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 248}], {
             RGBColor[
             0.9909714794351743, 0.990534488971119, 0.7992894810287939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 285}], {
             RGBColor[
             0.8536145975457046, 0.8842988625521124, 0.8812416887303199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 145}], {
             RGBColor[
             0.961720071809065, 0.970971472749606, 0.9496821128097062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 148}], {
             RGBColor[
             0.8371774929553208, 0.8729133590690041, 0.9461617582501125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 156}], {
             RGBColor[
             0.667739287342592, 0.7335766295233141, 0.9329781612243905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 159}], {
             RGBColor[
             0.9143639147032963, 0.9334596993778097, 0.9537892418849516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 168}], {
             RGBColor[
             0.9786655873246746, 0.9836094104754125, 0.9209977751400564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 191}], {
             RGBColor[
             0.9829568150279977, 0.9768773561545211, 0.6645701522140817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 205}], {
             RGBColor[
             0.9602881343459597, 0.9699035361342045, 0.9521060094256396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 212}], {
             RGBColor[
             0.9017979301594027, 0.9234399243970728, 0.9525906870613682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 225}], {
             RGBColor[
             0.9831049696835138, 0.9862685945138467, 0.8842985987754579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 251}], {
             RGBColor[
             0.888964172178655, 0.9133695064716122, 0.951323370461062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 269}], {
             RGBColor[
             0.9798590486019381, 0.9844994919418821, 0.9189775565022026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 276}], {
             RGBColor[
             0.9213677649187118, 0.9390443794251324, 0.9544572753709089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 282}], {
             RGBColor[
             0.9073408309893192, 0.9278596830608132, 0.9531193738907315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 142}], {
             RGBColor[
             0.9293995569319102, 0.9420765948110563, 0.7692760895759956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 149}], {
             RGBColor[
             0.9308290830806154, 0.9432164601585802, 0.769412439056212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 150}], {
             RGBColor[
             0.9805280253676377, 0.9820277261152595, 0.7458157162430723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 197}], {
             RGBColor[
             0.7253037916150795, 0.7794301770556904, 0.7509725078428957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 198}], {
             RGBColor[
             0.9941126334899804, 0.9898158432761581, 0.6005746718779433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 237}], {
             RGBColor[
             0.981067720790251, 0.9824302300777742, 0.7449021526676979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 243}], {
             RGBColor[
             0.9207054664561807, 0.9351441630605086, 0.7684468394651143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 256}], {
             RGBColor[
             0.622968302328801, 0.6856696206355888, 0.7446157410583627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 269}], {
             RGBColor[
             0.9876425462412601, 0.9873337241338482, 0.733772688168254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 277}], {
             RGBColor[
             0.8388266349644762, 0.8709553860198542, 0.7603454746757614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 281}], {
             RGBColor[
             0.6281565119975054, 0.6911227579488894, 0.7449112019237271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 165}], {
             RGBColor[
             0.9336727543954757, 0.9426061968456497, 0.7035606368767902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 175}], {
             RGBColor[
             0.9655641134819745, 0.890856958685221, 0.3449139786179085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 183}], {
             RGBColor[
             0.9879407326146518, 0.9844706877572392, 0.6585714069638398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 184}], {
             RGBColor[
             0.7524657325052013, 0.7986239225706996, 0.6869645253378378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 224}], {
             RGBColor[
             0.7163692540419655, 0.7690082304774095, 0.6842087932880669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 253}], {
             RGBColor[
             0.9896256918920124, 0.9851674617199062, 0.6306472712031445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 140}], {
             RGBColor[
             0.7332790885344129, 0.7898177825965491, 0.9489012255062204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 162}], {
             RGBColor[
             0.9664355820719005, 0.9744882925826894, 0.9416999839367737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 167}], {
             RGBColor[
             0.8248618146760301, 0.8635217930114716, 0.9565532917647825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 201}], {
             RGBColor[
             0.8948913955073197, 0.918267165556518, 0.9635231730707421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 202}], {
             RGBColor[
             0.8774687525051759, 0.904618732671136, 0.9617966596878068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 203}], {
             RGBColor[
             0.9360238764282677, 0.8210898999229521, 0.5939353471820532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 216}], {
             RGBColor[
             0.8446606398637772, 0.878988785724784, 0.9585266536289563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 237}], {
             RGBColor[
             0.9668018633988892, 0.9747614645966269, 0.9410799651916519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 269}], {
             RGBColor[
             0.9733766888498983, 0.9796649586527009, 0.929950500692208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 281}], {
             RGBColor[
             0.6138906546061436, 0.6834539924677423, 0.9410890144476811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 293}], {
             RGBColor[
             0.9472883130000953, 0.9600470452888208, 0.9685208378364835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 294}], {
             RGBColor[
             0.9679712152551688, 0.9756335652964023, 0.9391005575147796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 299}], {
             RGBColor[
             0.9324470846933515, 0.9482130526914336, 0.9671052682316653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 141}], {
             RGBColor[
             0.8120474136484385, 0.853410499302649, 0.950184413377746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 146}], {
             RGBColor[
             0.6763628868991887, 0.7470990948847585, 0.9683771896617213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 170}], {
             RGBColor[
             0.7471788426043355, 0.8025915263907235, 0.9753902251653399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 178}], {
             RGBColor[
             0.6272422141342945, 0.7080951714895829, 0.9639123630207267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 182}], {
             RGBColor[
             0.7843116760304614, 0.832200239820804, 0.9789319879663956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 188}], {
             RGBColor[
             0.6821337218912658, 0.7516073150405396, 0.9689523725622122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 190}], {
             RGBColor[
             0.6766076591095529, 0.7472903127958326, 0.9684015862681239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 199}], {
             RGBColor[
             0.7716257735694297, 0.8220848455480263, 0.9777219952648235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 261}], {
             RGBColor[
             0.8202997102567305, 0.8590459579234362, 0.9129694866480995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 284}], {
             RGBColor[
             0.81890299876211, 0.8584683818265625, 0.9361166106874416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 133}], {
             RGBColor[
             0.6415773044102994, 0.7167366812770488, 0.9670398604038635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 146}], {
             RGBColor[
             0.7700400872375528, 0.8204473689800309, 0.9776697585849486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 236}], {
             RGBColor[
             0.8017988801815835, 0.8452575794036739, 0.9808351782628155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 260}], {
             RGBColor[
             0.8409347442184236, 0.8760025547469689, 0.9846903006865034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 267}], {
             RGBColor[
             0.9125068242165145, 0.9317863135216691, 0.9466251913259933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 146}], {
             RGBColor[
             0.5709800566661266, 0.6614186415624952, 0.9600476854608053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 170}], {
             RGBColor[
             0.6417960123712735, 0.7169110730684602, 0.9670607209644241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 144}], {
             RGBColor[
             0.7424861948144714, 0.7950340495867285, 0.8646439716645452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 160}], {
             RGBColor[
             0.9935750402477306, 0.9911769351768529, 0.7245804858638247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 169}], {
             RGBColor[
             0.9728788131112971, 0.9220061999539895, 0.5287205607543114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 176}], {
             RGBColor[
             0.9829975058416234, 0.9854812553741443, 0.8528109693543608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 180}], {
             RGBColor[
             0.759166498904857, 0.8085758718864395, 0.8659571063045075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 187}], {
             RGBColor[
             0.8549852086361788, 0.8852132356796807, 0.8742883322940986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 193}], {
             RGBColor[
             0.9023096132387484, 0.9221834202340045, 0.8790051866731776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 200}], {
             RGBColor[
             0.9927768833818365, 0.9912810698998289, 0.7693692653969584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 221}], {
             RGBColor[
             0.9788408431527521, 0.9823812231466946, 0.8598471150553628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 228}], {
             RGBColor[
             0.9891085150558101, 0.9897641053242512, 0.8301636219921249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 230}], {
             RGBColor[
             0.9009960320754059, 0.9211572406456148, 0.8788742611789295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 245}], {
             RGBColor[
             0.9919642154598257, 0.9909450108294644, 0.7828372759818425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 264}], {
             RGBColor[
             0.986093527072869, 0.9877902629391377, 0.847570212981523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 288}], {
             RGBColor[
             0.5856491919497085, 0.6482536927214936, 0.8547952206098354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 297}], {
             RGBColor[
             0.9783237778409831, 0.9819955966837941, 0.860722371755956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 158}], {
             RGBColor[
             0.9269210150054161, 0.7316325269948802, 0.5086062407733145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 173}], {
             RGBColor[
             0.9563637839041932, 0.9656081508014327, 0.9009359548596034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 186}], {
             RGBColor[
             0.9641806522990668, 0.9717817530009442, 0.8996236084846614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 213}], {
             RGBColor[
             0.8404950017873605, 0.8742630535823639, 0.8896068369375159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 214}], {
             RGBColor[
             0.9599318162282119, 0.968453202924948, 0.9012762769678884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 249}], {
             RGBColor[
             0.9653866059970182, 0.9726811512943083, 0.8975822434371279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 255}], {
             RGBColor[
             0.9053596901635441, 0.573887240209286, 0.4882717449142634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 263}], {
             RGBColor[
             0.977319129938985, 0.9815804081125125, 0.8773835929040554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 265}], {
             RGBColor[
             0.9853459230722599, 0.9875667772886414, 0.8637963258523571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 276}], {
             RGBColor[
             0.9275004005099569, 0.9425932723585395, 0.8981829395848145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 286}], {
             RGBColor[
             0.9923303640932548, 0.9902494369861606, 0.715202325477539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 177}], {
             RGBColor[
             0.9151810306799155, 0.9324839222908261, 0.8845792914157449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 194}], {
             RGBColor[
             0.9123071368354019, 0.931295493330417, 0.9322071498181914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 197}], {
             RGBColor[
             0.6477277733585252, 0.7220385661231091, 0.9674253018892474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 204}], {
             RGBColor[
             0.9129985383314876, 0.9315814056172562, 0.9207488377383376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 210}], {
             RGBColor[
             0.9045987797920296, 0.925864275551785, 0.9594809536876845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 226}], {
             RGBColor[
             0.9143764167138808, 0.9321511937382352, 0.8979138271071336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 252}], {
             RGBColor[
             0.9005351177384342, 0.9228336030458495, 0.9663596735716149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 279}], {
             RGBColor[
             0.752764900043624, 0.8069346687352881, 0.9759524917885467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 280}], {
             RGBColor[
             0.9139999942690782, 0.9319955333836936, 0.9041521211675745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 147}], {
             RGBColor[
             0.8743257839246315, 0.8990273798984761, 0.7910990592550476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 156}], {
             RGBColor[
             0.6757730546208045, 0.7369461631667248, 0.7750135985984898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 179}], {
             RGBColor[
             0.9046730993286185, 0.9227349333402103, 0.7941237960427305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 191}], {
             RGBColor[
             0.9909905823062102, 0.9802468897979317, 0.506605589588181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 217}], {
             RGBColor[
             0.9448161005723293, 0.954705071473779, 0.7979629680374021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 247}], {
             RGBColor[
             0.9741936891186045, 0.9776522392767932, 0.7842020421791143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 251}], {
             RGBColor[
             0.8969979394568675, 0.9167390401150228, 0.7933588078351614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 270}], {
             RGBColor[
             0.9446424558948078, 0.9545666119213826, 0.7979464056530456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 271}], {
             RGBColor[
             0.9926107893729366, 0.9857122286767099, 0.5128997880919816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 273}], {
             RGBColor[
             0.9900328436374213, 0.9891808128474953, 0.7446615504934726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 278}], {
             RGBColor[
             0.9941597555264021, 0.9899166325472954, 0.6057036147389401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 289}], {
             RGBColor[
             0.9498805514273235, 0.9587433271146952, 0.79844601988104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 295}], {
             RGBColor[
             0.826052785767477, 0.8613161468497326, 0.7862876579355584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 210}], {
             RGBColor[
             0.9049263570770654, 0.926125476787024, 0.9595121983015629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 211}], {
             RGBColor[
             0.8888161499811874, 0.9141105107129612, 0.9867825766999345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 231}], {
             RGBColor[
             0.8903034262062848, 0.9152197188864476, 0.9842650059946092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 266}], {
             RGBColor[
             0.7774368460642794, 0.8262138758508484, 0.9784101555669313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 143}], {
             RGBColor[
             0.851452900515435, 0.8833049312368758, 0.9125315415797113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 163}], {
             RGBColor[
             0.7944714990220585, 0.8381601468152587, 0.9072832309617481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 235}], {
             RGBColor[
             0.9857114595586458, 0.9729072668338774, 0.6219621698989846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 273}], {
             RGBColor[
             0.9868221998882026, 0.9888186552468257, 0.8680537811133663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 274}], {
             RGBColor[
             0.8453381294693375, 0.8785280256216832, 0.9119220783476205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 298}], {
             RGBColor[
             0.7655275006941562, 0.8146621050604024, 0.9050046533880163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 162}], {
             RGBColor[
             0.7345841330878553, 0.790791082687692, 0.9466921254873748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 167}], {
             RGBColor[
             0.593010365691985, 0.6798245831164742, 0.9615454333153834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 181}], {
             RGBColor[
             0.746298999738962, 0.798368651933633, 0.8749434418203148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 201}], {
             RGBColor[
             0.6630399465232746, 0.7345699556615206, 0.9685153146213431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 202}], {
             RGBColor[
             0.6456173035211308, 0.7209215227761387, 0.9667888012384078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 203}], {
             RGBColor[
             0.7041724274442225, 0.6373926900279548, 0.5989274887326541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 216}], {
             RGBColor[
             0.612809190879732, 0.6952915758297867, 0.9635187951795573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 237}], {
             RGBColor[
             0.734950414414844, 0.7910642547016296, 0.946072106742253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 269}], {
             RGBColor[
             0.7415252398658532, 0.7959677487577036, 0.9349426422428091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 293}], {
             RGBColor[
             0.7154368640160501, 0.7763498353938234, 0.9735129793870845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 299}], {
             RGBColor[
             0.7005956357093063, 0.7645158427964364, 0.9720974097822663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 146}], {
             RGBColor[
             0.8351273662426298, 0.8714407336833678, 0.9524848073579152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 178}], {
             RGBColor[
             0.7860066934777357, 0.8324368102881923, 0.9480199807169207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 182}], {
             RGBColor[
             0.9430761553739025, 0.9565418786194134, 0.9630396056625896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 188}], {
             RGBColor[
             0.840898201234707, 0.875948953839149, 0.9530599902584063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 236}], {
             RGBColor[
             0.8668861591866606, 0.8962509441070108, 0.9556502270357821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 261}], {
             RGBColor[
             0.9790641896001717, 0.9833875967220456, 0.8970771043442936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 294}], {
             RGBColor[
             0.9708118929918796, 0.9777521381012584, 0.9342920310739399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 149}], {
             RGBColor[
             0.8665663877113439, 0.8964405315157955, 0.9871350697244964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[
             0.9162653299983663, 0.9352517974724748, 0.9635383469113565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 163}], {
             RGBColor[
             0.7331691777631153, 0.7912110743216989, 0.9743733253020908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 197}], {
             RGBColor[
             0.661041096245808, 0.7326542484129057, 0.9686951385111799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 198}], {
             RGBColor[
             0.929849938120709, 0.9430399146333736, 0.8182973025462277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 243}], {
             RGBColor[
             0.8564427710869092, 0.8883682344177241, 0.9861694701333985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 256}], {
             RGBColor[
             0.5587056069595295, 0.6388936919928041, 0.9623383717266469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 277}], {
             RGBColor[
             0.7745639395952049, 0.8241794573770697, 0.9780681053440458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 163}], {
             RGBColor[
             0.6581828954569683, 0.7322662668967433, 0.9669962409778647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 174}], {
             RGBColor[
             0.7208273312279956, 0.7818350567367157, 0.9728089899285598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 185}], {
             RGBColor[
             0.8521410722733852, 0.8761825686947606, 0.6922349368701662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 235}], {
             RGBColor[
             0.8494228559935557, 0.867013386915362, 0.6816751799151011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 298}], {
             RGBColor[
             0.629238897129066, 0.708768225141887, 0.9647176634041329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 160}], {
             RGBColor[
             0.743689851162785, 0.7950975993205942, 0.8131350163086992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 176}], {
             RGBColor[
             0.7331123167566778, 0.7894019195178857, 0.9413654997992353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 221}], {
             RGBColor[
             0.7289556540678065, 0.786301887290436, 0.9484016455002373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 230}], {
             RGBColor[
             0.6511108429904603, 0.7250779047893561, 0.967428791623804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 231}], {
             RGBColor[
             0.7170212438919754, 0.7774012237221044, 0.9686034889352333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 232}], {
             RGBColor[
             0.562938168770079, 0.6560575913398763, 0.9587357012374897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 240}], {
             RGBColor[
             0.5916152405496093, 0.6785994879792374, 0.9614988259905157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 245}], {
             RGBColor[
             0.7420790263748801, 0.7948656749732059, 0.871391806426717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 264}], {
             RGBColor[
             0.7362083379879234, 0.7917109270828793, 0.9361247434263975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 288}], {
             RGBColor[
             0.3357640028647629, 0.452174356865235, 0.9433497510547099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 297}], {
             RGBColor[
             0.7284385887560375, 0.7859162608275354, 0.9492769022008305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 156}], {
             RGBColor[
             0.6513641021291195, 0.7213640432030113, 0.9606970784584883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 159}], {
             RGBColor[
             0.8979887294898238, 0.9212471130575068, 0.9815081591190493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 167}], {
             RGBColor[
             0.8149689892145975, 0.85614373998035, 0.9732992648088747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 168}], {
             RGBColor[
             0.9622904021112021, 0.9713968241551096, 0.9487166923741542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 201}], {
             RGBColor[
             0.884998570045887, 0.9108891125253964, 0.9802691461148344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 203}], {
             RGBColor[
             0.926131050966835, 0.8137118468918305, 0.6106813202261454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 205}], {
             RGBColor[
             0.9439129491324874, 0.9576909498139017, 0.9798249266597374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 216}], {
             RGBColor[
             0.8347678144023445, 0.8716107326936624, 0.9752726266730486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 237}], {
             RGBColor[
             0.9569090379374565, 0.9673834115655053, 0.9578259382357442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 269}], {
             RGBColor[
             0.9634838633884655, 0.9722869056215793, 0.9466964737363004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 277}], {
             RGBColor[
             0.8146679521116817, 0.8559085675075855, 0.9732692602438078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 282}], {
             RGBColor[
             0.8909656457758466, 0.9156470967405104, 0.9808382911248293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 293}], {
             RGBColor[
             0.9373954875386625, 0.9526689922576992, 0.9852668108805758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 170}], {
             RGBColor[
             0.7702587951985269, 0.8206217607714423, 0.9776906191455093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 236}], {
             RGBColor[
             0.7312016324374107, 0.7899395396891202, 0.9738430033197574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 247}], {
             RGBColor[
             0.8543566814642733, 0.886756492818539, 0.9692670311103546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 273}], {
             RGBColor[
             0.8701958359830902, 0.8982850663892411, 0.929726539424713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 289}], {
             RGBColor[
             0.8300435437729925, 0.867847580656441, 0.9835110088122804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 156}], {
             RGBColor[
             0.5268215232753755, 0.6233059295224093, 0.9571767238988944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 159}], {
             RGBColor[
             0.7734461506360797, 0.8231889993769048, 0.9779878045594557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 168}], {
             RGBColor[
             0.837747823257458, 0.8733387104745077, 0.9451963378145605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 191}], {
             RGBColor[
             0.842039050960781, 0.8666066561536163, 0.6887687148885856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 205}], {
             RGBColor[
             0.8193703702787432, 0.8596328361332998, 0.9763045721001435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 217}], {
             RGBColor[
             0.7958645692269002, 0.8410648378294636, 0.9801260933378066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 225}], {
             RGBColor[
             0.8421872056162971, 0.875997894512942, 0.9084971614499618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 251}], {
             RGBColor[
             0.7480464081114383, 0.8030988064707074, 0.975521933135566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 270}], {
             RGBColor[
             0.7956909245493786, 0.8409263782770671, 0.9801095309534502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 271}], {
             RGBColor[
             0.8436592580275073, 0.8720719950323945, 0.6950629133923861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 278}], {
             RGBColor[
             0.8452082241809729, 0.8762763989029798, 0.7878667400393446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.7664230669221025, 0.8175889830599083, 0.9773179365652356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 295}], {
             RGBColor[
             0.6771012544220478, 0.747675913205417, 0.968450783235963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 150}], {
             RGBColor[
             0.9176948561470715, 0.9363916628199986, 0.9636746963915732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.6624706223945132, 0.7337941137604297, 0.9688314879913965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 198}], {
             RGBColor[
             0.9312794642694141, 0.9441797799808975, 0.8184336520264441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 243}], {
             RGBColor[
             0.8578722972356143, 0.889508099765248, 0.9863058196136152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 256}], {
             RGBColor[
             0.5601351331082346, 0.6400335573403281, 0.9624747212068636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 277}], {
             RGBColor[
             0.7759934657439099, 0.8253193227245936, 0.9782044548242623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 281}], {
             RGBColor[
             0.5653233427769391, 0.6454866946536288, 0.9627701820722279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 179}], {
             RGBColor[
             0.891288602756184, 0.9153748345501841, 0.9611457476700436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 237}], {
             RGBColor[
             0.967933493856707, 0.9756054327391928, 0.939164410003059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 256}], {
             RGBColor[
             0.609834075395257, 0.6788448232970072, 0.9388779983937238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 269}], {
             RGBColor[
             0.9745083193077162, 0.9805089267952667, 0.928034945503615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 274}], {
             RGBColor[
             0.8351642766461218, 0.8715300844323266, 0.9555517993550399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 277}], {
             RGBColor[
             0.8256924080309322, 0.8641305886812728, 0.9546077320111226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 281}], {
             RGBColor[
             0.6150222850639615, 0.684297960610308, 0.9391734592590881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 293}], {
             RGBColor[
             0.9484199434579131, 0.9608910134313866, 0.9666052826478905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 154}], {
             RGBColor[
             0.9799785516435742, 0.9840390445572381, 0.8941642870599213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 181}], {
             RGBColor[
             0.9818137509545182, 0.9847979466347845, 0.8637502851340072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 192}], {
             RGBColor[
             0.8449863612124824, 0.879113526978736, 0.9519929796223183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 220}], {
             RGBColor[
             0.9675003137003653, 0.9321458422972198, 0.6202479984587974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 239}], {
             RGBColor[
             0.7827362785522511, 0.8297274084987787, 0.9463052729655916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 258}], {
             RGBColor[
             0.9793164740484874, 0.9837652584570517, 0.905136626212402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 208}], {
             RGBColor[
             0.6859024342069432, 0.7510981872825861, 0.9602529830442743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 242}], {
             RGBColor[
             0.9243424534894604, 0.9421831971571317, 0.9813292776387228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 244}], {
             RGBColor[
             0.8258018214734743, 0.8645531121974304, 0.9716799976320555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 268}], {
             RGBColor[
             0.9514505082252191, 0.9633124490436409, 0.967065805226005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 157}], {
             RGBColor[
             0.8571400003604637, 0.8878682725250321, 0.9185639774129468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 192}], {
             RGBColor[
             0.722354864483834, 0.7830283773258595, 0.9729612401678919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 220}], {
             RGBColor[
             0.8448688169717171, 0.8360606926443432, 0.641216259004371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 222}], {
             RGBColor[
             0.6704333350036258, 0.742027443613463, 0.9680866350522336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 239}], {
             RGBColor[
             0.6601047818236029, 0.7336422588459022, 0.9672735335111653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 248}], {
             RGBColor[
             0.8588081170367687, 0.8885580816393275, 0.8909189671389963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 285}], {
             RGBColor[
             0.721451235147299, 0.782322455220321, 0.9728711748405223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 181}], {
             RGBColor[
             0.9893351606166123, 0.9898578290881681, 0.8264075185097224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[
             0.9472085883218728, 0.8288818671824898, 0.5503915654220617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 216}], {
             RGBColor[
             0.8558453517573823, 0.8867807529843217, 0.9149828718689649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 255}], {
             RGBColor[
             0.9039294067138643, 0.5732957812462355, 0.5119752431303717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 258}], {
             RGBColor[
             0.9868378837105816, 0.9888251409104353, 0.8677938595881172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 162}], {
             RGBColor[
             0.942166135025948, 0.8412411417934731, 0.5956183831272082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 194}], {
             RGBColor[
             0.9513478506546419, 0.8477711879926345, 0.5658505674862282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 210}], {
             RGBColor[
             0.9436394936112696, 0.8423399702140026, 0.5931243713557213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 218}], {
             RGBColor[
             0.768361843754567, 0.7047554233931999, 0.6074920474733232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 226}], {
             RGBColor[
             0.9534171305331207, 0.8486268884004528, 0.5315572447751704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 227}], {
             RGBColor[
             0.943755174532734, 0.8424262448558206, 0.5929285537300983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 241}], {
             RGBColor[
             0.7855951748078185, 0.7185587212066192, 0.6089769109314292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 290}], {
             RGBColor[
             0.7803562871880618, 0.7144660623810447, 0.6084547475736801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 291}], {
             RGBColor[
             0.8715930856530858, 0.7857943732031611, 0.6175342001934669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.9081776376473989, 0.8149659019022173, 0.6210236674220997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 159}], {
             RGBColor[
             0.6040079450233508, 0.6838522698312148, 0.9648042075337336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 168}], {
             RGBColor[
             0.6683096176447291, 0.7340019809288177, 0.9320127407888386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.5862833623704604, 0.6697579701502048, 0.9631033243174132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 191}], {
             RGBColor[
             0.6726008453480521, 0.7272699266079263, 0.6755851178628637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 205}], {
             RGBColor[
             0.6499321646660143, 0.7202961065876098, 0.9631209750744216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 251}], {
             RGBColor[
             0.5786082024987094, 0.6637620769250174, 0.962338336109844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 269}], {
             RGBColor[
             0.6695030789219925, 0.7348920623952874, 0.9299925221509846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 270}], {
             RGBColor[
             0.6262527189366498, 0.7015896487313771, 0.9669259339277282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 271}], {
             RGBColor[
             0.6742210524147785, 0.7327352654867045, 0.6818793163666642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 277}], {
             RGBColor[
             0.5206871676452087, 0.6185137242812935, 0.9565653086584921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 282}], {
             RGBColor[
             0.5969848613093736, 0.6782522535142184, 0.9641343395395137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 171}], {
             RGBColor[
             0.9654534721616281, 0.9732750626306053, 0.9218323983306242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 184}], {
             RGBColor[
             0.7505724763878159, 0.802651522028651, 0.9092860709950465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 222}], {
             RGBColor[
             0.8003791868399057, 0.8430868533403936, 0.913207037689827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 248}], {
             RGBColor[
             0.9887539688730487, 0.9896174913662581, 0.8360393697765898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 275}], {
             RGBColor[
             0.9901481304186124, 0.9884068789019835, 0.6830287224734218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 285}], {
             RGBColor[
             0.851397086983579, 0.8833818649472516, 0.9179915774781158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 186}], {
             RGBColor[
             0.900741139099455, 0.7131324350591015, 0.598815325254556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 196}], {
             RGBColor[
             0.929038700641771, 0.7325082444275515, 0.473510709384165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 207}], {
             RGBColor[
             0.6799220499405582, 0.5374958764538105, 0.580646292990628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 212}], {
             RGBColor[
             0.8444910525510361, 0.6683394993886371, 0.5955080680451685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 214}], {
             RGBColor[
             0.8964923030286001, 0.7098038849831052, 0.6004679937377828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 225}], {
             RGBColor[
             0.9257980920751472, 0.7311681695054111, 0.5272159797592582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 265}], {
             RGBColor[
             0.9219064098726482, 0.7289174593467987, 0.5629880426222515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 276}], {
             RGBColor[
             0.864060887310345, 0.6839439544166968, 0.5973746563547091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 168}], {
             RGBColor[
             0.9149342450054333, 0.9338850507833133, 0.9528238214493996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 191}], {
             RGBColor[
             0.9192254727087563, 0.9271529964624219, 0.6963961985234248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 205}], {
             RGBColor[
             0.8965567920267186, 0.9201791764421053, 0.9839320557349828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 212}], {
             RGBColor[
             0.8380665878401614, 0.8737155647049735, 0.9844167333707113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 225}], {
             RGBColor[
             0.9193736273642725, 0.9365442348217475, 0.9161246450848011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 251}], {
             RGBColor[
             0.8252328298594136, 0.863645146779513, 0.9831494167704051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 270}], {
             RGBColor[
             0.872877346297354, 0.9014727185858726, 0.9877370145882893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 271}], {
             RGBColor[
             0.9208456797754827, 0.9326183353412001, 0.7026903970272254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 282}], {
             RGBColor[
             0.8436094886700778, 0.8781353233687139, 0.9849454202000747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 176}], {
             RGBColor[
             0.9842011621899369, 0.98554480510801, 0.8013020139985149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 180}], {
             RGBColor[
             0.7603701552531706, 0.8086394216203052, 0.8144481509486616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 193}], {
             RGBColor[
             0.903513269587062, 0.9222469699678701, 0.8274962313173316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 221}], {
             RGBColor[
             0.9800444995010658, 0.9824447728805603, 0.8083381596995168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 230}], {
             RGBColor[
             0.9021996884237196, 0.9212207903794805, 0.8273653058230835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 232}], {
             RGBColor[
             0.8140270142033381, 0.8522004769300007, 0.8186722154367694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 245}], {
             RGBColor[
             0.9931678718081394, 0.9910085605633302, 0.7313283206259966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 288}], {
             RGBColor[
             0.5868528482980221, 0.6483172424553593, 0.8032862652539894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 296}], {
             RGBColor[
             0.905486566641988, 0.9237885246247914, 0.8276929111262572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 297}], {
             RGBColor[
             0.9795274341892968, 0.9820591464176598, 0.8092134164001101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 177}], {
             RGBColor[
             0.9588968040060556, 0.9673416933080348, 0.8887489409011237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 244}], {
             RGBColor[
             0.8145944750385659, 0.8559430792861563, 0.9819275557411709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 279}], {
             RGBColor[
             0.796480673369764, 0.8417924397524967, 0.9801221412739255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 280}], {
             RGBColor[
             0.9577157675952183, 0.9668533044009022, 0.9083217706529532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 169}], {
             RGBColor[
             0.9605634344742602, 0.9141803035694122, 0.61042128210344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 181}], {
             RGBColor[
             0.9794554932764497, 0.9830391619197735, 0.8677422002508681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 202}], {
             RGBColor[
             0.8787737970586184, 0.9055920327622791, 0.9595875596689611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 216}], {
             RGBColor[
             0.8459656844172196, 0.8799620858159272, 0.9563175536101107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 227}], {
             RGBColor[
             0.9693296661321291, 0.9766466957361801, 0.9368010545208184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 228}], {
             RGBColor[
             0.976793136418773, 0.9819382089396739, 0.9118643433412537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 299}], {
             RGBColor[
             0.9337521292467938, 0.9491863527825768, 0.9648961682128196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 185}], {
             RGBColor[
             0.7951596707800086, 0.8310377842731436, 0.6869866262522031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 235}], {
             RGBColor[
             0.7924414545001791, 0.8218686024937449, 0.676426869297138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 274}], {
             RGBColor[
             0.6520681244108708, 0.7274893612815507, 0.966386777745774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 292}], {
             RGBColor[
             0.7689769996122879, 0.8197360924869059, 0.9768468103756165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 298}], {
             RGBColor[
             0.5722574956356894, 0.6636234407202699, 0.9594693527861697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 176}], {
             RGBColor[
             0.7725013837889343, 0.8213797385919199, 0.9444663514429212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 180}], {
             RGBColor[
             0.548670376852168, 0.6444743551042151, 0.9576124883930679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 187}], {
             RGBColor[
             0.6444890865834898, 0.7211117188974562, 0.965943714382659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 221}], {
             RGBColor[
             0.7683447211000631, 0.8182797063644702, 0.9515024971439232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 230}], {
             RGBColor[
             0.6904999100227169, 0.7570557238633903, 0.9705296432674899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 296}], {
             RGBColor[
             0.6937867882409854, 0.7596234581087014, 0.9708572485706637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 297}], {
             RGBColor[
             0.7678276557882941, 0.8178940799015696, 0.9523777538445165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 175}], {
             RGBColor[
             0.9083645034459356, 0.8525906721948107, 0.6294333267585758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 183}], {
             RGBColor[
             0.9307411225786129, 0.9462044012668289, 0.943090755104507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 224}], {
             RGBColor[
             0.6591696440059267, 0.7307419439869992, 0.9687281414287343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 253}], {
             RGBColor[
             0.9324260818559735, 0.9469011752294958, 0.9151666193438117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 262}], {
             RGBColor[
             0.8565297746577688, 0.8884376087034784, 0.9861777686116562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 195}], {
             RGBColor[
             0.9341997637884054, 0.9489935132199707, 0.9447791606409441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 234}], {
             RGBColor[
             0.6447286453624449, 0.7179903965895817, 0.9679200610740637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.7382844256181946, 0.7952305988520632, 0.9749294009062879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 285}], {
             RGBColor[
             0.7996308789418907, 0.8439107952264819, 0.9805270422356449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 168}], {
             RGBColor[
             0.831914504730207, 0.8687816777061564, 0.944614927139225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[
             0.7546226726648919, 0.8082739660764431, 0.9761673808799052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 202}], {
             RGBColor[
             0.737200029662748, 0.7946255331910612, 0.97444086749697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.7957551535858398, 0.7110967004428773, 0.6065795549912163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 216}], {
             RGBColor[
             0.7043919170213493, 0.7689955862447092, 0.9711708614381194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 237}], {
             RGBColor[
             0.8265331405564613, 0.864768265116552, 0.953724173000815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 269}], {
             RGBColor[
             0.8331079660074704, 0.8696717591726261, 0.9425947085013712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 277}], {
             RGBColor[
             0.6842920547306865, 0.7532934210586322, 0.9691674950088787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 282}], {
             RGBColor[
             0.7605897483948515, 0.8130319502915571, 0.9767365258899001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 293}], {
             RGBColor[
             0.8070195901576673, 0.8500538458087459, 0.9811650456456467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 203}], {
             RGBColor[
             0.9430765664824445, 0.8263497846176371, 0.5819969825564957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 205}], {
             RGBColor[
             0.9608584646480969, 0.9703288875397083, 0.9511405889900877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 212}], {
             RGBColor[
             0.9023682604615397, 0.9238652758025764, 0.9516252666258163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 225}], {
             RGBColor[
             0.9836752999856508, 0.9866939459193504, 0.8833331783399059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 269}], {
             RGBColor[
             0.980429378904075, 0.9849248433473858, 0.9180121360666507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 276}], {
             RGBColor[
             0.9219380952208487, 0.9394697308306361, 0.9534918549353568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 282}], {
             RGBColor[
             0.9079111612914561, 0.9282850344663169, 0.9521539534551796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 293}], {
             RGBColor[
             0.954341003054272, 0.9653069299835058, 0.956582473210926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 193}], {
             RGBColor[
             0.8828170424506285, 0.8530762347450067, 0.6316363062078183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 200}], {
             RGBColor[
             0.9732843125937166, 0.9221738844108313, 0.5220003849315991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 202}], {
             RGBColor[
             0.8715966049075354, 0.8443107436578587, 0.6305179578544731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 227}], {
             RGBColor[
             0.9621524739810462, 0.9153654066317598, 0.6077314527063304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 228}], {
             RGBColor[
             0.9696159442676902, 0.9206569198352536, 0.5827947415267656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 264}], {
             RGBColor[
             0.9666009562847491, 0.9186830774501402, 0.6002013325161637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 299}], {
             RGBColor[
             0.926574937095711, 0.8879050636781565, 0.6358265663983316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 178}], {
             RGBColor[
             0.7211381224336328, 0.7816178373762668, 0.9732257925045148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 182}], {
             RGBColor[
             0.8782075843297996, 0.9057229057074878, 0.9882454174501836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 190}], {
             RGBColor[
             0.7705035674088911, 0.8208129786825165, 0.977715015751912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 199}], {
             RGBColor[
             0.8655216818687681, 0.8956075114347102, 0.9870354247486116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 261}], {
             RGBColor[
             0.9141956185560689, 0.9325686238101201, 0.9222829161318876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 284}], {
             RGBColor[
             0.9127989070614484, 0.9319910477132463, 0.9454300401712297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 184}], {
             RGBColor[
             0.7289400963527004, 0.7869989024072935, 0.9674340892751305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 275}], {
             RGBColor[
             0.9685157503834969, 0.9727542592806262, 0.7411767407535059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 285}], {
             RGBColor[
             0.8297647069484635, 0.8677292453258942, 0.9761395957581998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 174}], {
             RGBColor[
             0.8571159347930857, 0.8877289366552311, 0.9130959799124432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 238}], {
             RGBColor[
             0.9473293597093013, 0.8289318092548745, 0.5483900709860408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 186}], {
             RGBColor[
             0.930183907998232, 0.947108058865654, 0.9911450393408447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 213}], {
             RGBColor[
             0.8064982574865257, 0.8495893594470736, 0.9811282677936992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 234}], {
             RGBColor[
             0.6641354471074405, 0.7334648535174413, 0.9697710991491577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 249}], {
             RGBColor[
             0.9313898616961835, 0.9480074571590181, 0.9891036742933113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 263}], {
             RGBColor[
             0.9433223856381503, 0.9569067139772223, 0.9689050237602388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 286}], {
             RGBColor[
             0.9583336197924202, 0.9655757428508704, 0.8067237563337224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 235}], {
             RGBColor[
             0.8550858902712064, 0.8714373923337173, 0.6822396182478331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 238}], {
             RGBColor[
             0.8167037904218618, 0.7274619347547144, 0.6086675193348894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 298}], {
             RGBColor[
             0.6349019314067167, 0.7131922305602423, 0.9652821017368649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 183}], {
             RGBColor[
             0.9626324816651116, 0.8944551631064002, 0.5844440968456253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 224}], {
             RGBColor[
             0.6910610030924254, 0.6789927058265705, 0.6100814831698524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 253}], {
             RGBColor[
             0.9643174409424723, 0.895151937069067, 0.5565199610849301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 180}], {
             RGBColor[
             0.7497926208470633, 0.8029437418175968, 0.9426786344391975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 187}], {
             RGBColor[
             0.8456113305783851, 0.8795811056108378, 0.9510098604287887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 193}], {
             RGBColor[
             0.8929357351809547, 0.9165512901651616, 0.9557267148078676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 221}], {
             RGBColor[
             0.9694669650949584, 0.9767490930778518, 0.9365686431900528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 230}], {
             RGBColor[
             0.8916221540176122, 0.9155251105767719, 0.9555957893136195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 245}], {
             RGBColor[
             0.982590337402032, 0.9853128807606217, 0.8595588041165325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 288}], {
             RGBColor[
             0.5762753138919149, 0.6426215626526508, 0.9315167487445255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 296}], {
             RGBColor[
             0.8949090322358808, 0.918092844822083, 0.9559233946167933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 297}], {
             RGBColor[
             0.9689498997831895, 0.9763634666149512, 0.9374438998906461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 194}], {
             RGBColor[
             0.9889779517272443, 0.9897101140325647, 0.8323273942335218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 226}], {
             RGBColor[
             0.9910472316057233, 0.9905658144403829, 0.798034071522464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 252}], {
             RGBColor[
             0.9772059326302767, 0.9812482237479973, 0.8664799179869452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 268}], {
             RGBColor[
             0.973198203356013, 0.9782592658173059, 0.873263958265072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 279}], {
             RGBColor[
             0.8294357149354663, 0.8653492894374359, 0.876072736203877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 280}], {
             RGBColor[
             0.9906708091609205, 0.9904101540858414, 0.8042723655829047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 182}], {
             RGBColor[
             0.7582709558597586, 0.8112265508063474, 0.9767675553055704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 190}], {
             RGBColor[
             0.65056693893885, 0.726316623781376, 0.9662371536072988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 199}], {
             RGBColor[
             0.7455850533987269, 0.8011111565335697, 0.9755575626039984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 229}], {
             RGBColor[
             0.7901916434846508, 0.835557939151123, 0.9409359519649846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 261}], {
             RGBColor[
             0.7942589900860277, 0.8380722689089795, 0.9108050539872744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 284}], {
             RGBColor[
             0.7928622785914072, 0.8374946928121059, 0.9339521780266165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 205}], {
             RGBColor[
             0.8788322093738281, 0.9060848767610953, 0.9822311725186623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 251}], {
             RGBColor[
             0.8075082472065234, 0.8495508470985029, 0.9814485335540847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 269}], {
             RGBColor[
             0.8984031236298065, 0.9206808325687729, 0.9491027195952253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 274}], {
             RGBColor[
             0.7590590809682121, 0.8117019902058327, 0.9766195734466501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 277}], {
             RGBColor[
             0.7495872123530225, 0.804302494454779, 0.9756755061027328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 282}], {
             RGBColor[
             0.8258849060171876, 0.8640410236877039, 0.9832445369837544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 289}], {
             RGBColor[
             0.8603908591769793, 0.8915551340981751, 0.9865357455999633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 187}], {
             RGBColor[
             0.6217803236416188, 0.702675722123133, 0.9641559973789354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 193}], {
             RGBColor[
             0.6691047282441884, 0.7396459066774568, 0.9688728517580143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 215}], {
             RGBColor[
             0.6937862435615957, 0.5452637399194666, 0.5810309152906633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 221}], {
             RGBColor[
             0.7456359581581922, 0.7998437095901471, 0.9497147801401995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 230}], {
             RGBColor[
             0.667791147080846, 0.7386197270890671, 0.9687419262637662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 233}], {
             RGBColor[
             0.5930573303937681, 0.6802371014950781, 0.9612931578436226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 245}], {
             RGBColor[
             0.7587593304652658, 0.8084074972729169, 0.8727049410666793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 288}], {
             RGBColor[
             0.3524443069551485, 0.465716179164946, 0.9446628856946722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 296}], {
             RGBColor[
             0.6710780252991144, 0.7411874613343782, 0.96906953156694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 297}], {
             RGBColor[
             0.7451188928464232, 0.7994580831272464, 0.9505900368407929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 201}], {
             RGBColor[
             0.9079113067118689, 0.9268180348936019, 0.8895653893848365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 202}], {
             RGBColor[
             0.890488663709725, 0.9131696020082201, 0.8878388760019011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 203}], {
             RGBColor[
             0.9490437876328168, 0.8296407692600363, 0.5199775634961475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 216}], {
             RGBColor[
             0.8576805510683263, 0.8875396550618682, 0.8845688699430507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 227}], {
             RGBColor[
             0.9810445327832358, 0.9842242649821211, 0.8650523708537584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 258}], {
             RGBColor[
             0.9886730830215256, 0.9895840429879816, 0.8373798576622029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 299}], {
             RGBColor[
             0.9454669958979005, 0.9567639220285178, 0.8931474845457597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 190}], {
             RGBColor[
             0.807636400835017, 0.8504216921125971, 0.9812567785529676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 199}], {
             RGBColor[
             0.9026545152948938, 0.9252162248647908, 0.9905771875496672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 229}], {
             RGBColor[
             0.9472611053808178, 0.959663007482344, 0.9559555769106534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 261}], {
             RGBColor[
             0.9513284519821946, 0.9621773372402006, 0.9258246789329432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 284}], {
             RGBColor[
             0.9499317404875741, 0.9615997611433269, 0.9489718029722852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 224}], {
             RGBColor[
             0.7134376222251027, 0.7726064348985887, 0.9237389115157837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 253}], {
             RGBColor[
             0.9866940600751496, 0.9887656661410853, 0.8701773894308612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 222}], {
             RGBColor[
             0.563865811030978, 0.6568106931170818, 0.9588087286343333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 224}], {
             RGBColor[
             0.47796262211565227`, 0.5867596697120491, 0.952132029889782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 248}], {
             RGBColor[
             0.7522405930641209, 0.8033413311429463, 0.881641060721096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 275}], {
             RGBColor[
             0.7536347546096847, 0.8021307186786718, 0.7286304134179281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 218}], {
             RGBColor[
             0.8046249458395033, 0.8387221209722235, 0.6877317673773315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 235}], {
             RGBColor[
             0.986399631316596, 0.9657849042917623, 0.4016655651894395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 262}], {
             RGBColor[
             0.9128521262762631, 0.9237446965614393, 0.6982504371751797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 292}], {
             RGBColor[
             0.9629351764287049, 0.9636523942849233, 0.7020855062679181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 196}], {
             RGBColor[
             0.9662983379354216, 0.9726574704336153, 0.8645280770955119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 214}], {
             RGBColor[
             0.9337519403222507, 0.9499531109891691, 0.9914853614491297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 249}], {
             RGBColor[
             0.9392067300910572, 0.9541810593585296, 0.9877913279183693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 265}], {
             RGBColor[
             0.9591660471662988, 0.9690666853528627, 0.9540054103335984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 286}], {
             RGBColor[
             0.9661504881872938, 0.9717493450503818, 0.8054114099587804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 193}], {
             RGBColor[
             0.7649234379755101, 0.8162832704706979, 0.9772040777476054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 215}], {
             RGBColor[
             0.7896049532929175, 0.6219011037127077, 0.5893621412802544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 228}], {
             RGBColor[
             0.8517223397925717, 0.8838639555609447, 0.9283625130665529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 229}], {
             RGBColor[
             0.8483904131893252, 0.8816537408717469, 0.9463055984692971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 230}], {
             RGBColor[
             0.7636098568121676, 0.8152570908823082, 0.9770731522533573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 233}], {
             RGBColor[
             0.6888760401250897, 0.7568744652883193, 0.9696243838332137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 245}], {
             RGBColor[
             0.8545780401965875, 0.885044861066158, 0.8810361670562704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 288}], {
             RGBColor[
             0.4482630166864703, 0.542353542958187, 0.9529941116842633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 296}], {
             RGBColor[
             0.7668967350304362, 0.8178248251276192, 0.9774007575565311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 297}], {
             RGBColor[
             0.8409376025777449, 0.8760954469204876, 0.958921262830384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 236}], {
             RGBColor[
             0.7369724674294879, 0.7944477598449013, 0.9744181862202486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 260}], {
             RGBColor[
             0.776108331466328, 0.8251927351881962, 0.9782733086439364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 261}], {
             RGBColor[
             0.8491504978429991, 0.8815844124599361, 0.9158450635287599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 281}], {
             RGBColor[
             0.4868176405856818, 0.5837693810104887, 0.9550484471913078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 294}], {
             RGBColor[
             0.840898201234707, 0.875948953839149, 0.9530599902584063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 257}], {
             RGBColor[
             0.9092893887919546, 0.9260953743437291, 0.771742004222436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 260}], {
             RGBColor[
             0.8330340257780278, 0.8697027363218861, 0.9839367231086038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 267}], {
             RGBColor[
             0.9046061057761188, 0.9254864950965864, 0.9458716137480937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 287}], {
             RGBColor[
             0.8538818812980755, 0.8863262504136096, 0.9859252101792063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 300}], {
             RGBColor[
             0.9049179470267148, 0.9256154494676625, 0.9407035972064288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 199}], {
             RGBColor[
             0.7949504983739852, 0.8403062978398194, 0.9800467858513956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 261}], {
             RGBColor[
             0.843624435061286, 0.8772674102152291, 0.9152942772346716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 284}], {
             RGBColor[
             0.8422277235666655, 0.8766898341183555, 0.9384414012740137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 205}], {
             RGBColor[
             0.9651496923514199, 0.9635968332188167, 0.6947129660641127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 217}], {
             RGBColor[
             0.9416438912995769, 0.9450288349149806, 0.6985344873017758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 225}], {
             RGBColor[
             0.987966527688974, 0.9799618915984589, 0.626905555413931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 246}], {
             RGBColor[
             0.9845850432582908, 0.9780916861026947, 0.6618139865301307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 251}], {
             RGBColor[
             0.893825730184115, 0.9070628035562244, 0.6939303270995352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 270}], {
             RGBColor[
             0.9414702466220554, 0.9448903753625841, 0.6985179249174194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 271}], {
             RGBColor[
             0.9894385801001842, 0.9760359921179115, 0.41347130735635534`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 278}], {
             RGBColor[
             0.9909875462536497, 0.9802403959884969, 0.5062751340033138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 282}], {
             RGBColor[
             0.9122023889947792, 0.9215529801454254, 0.6957263305292047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 295}], {
             RGBColor[
             0.8228805764947246, 0.851639910290934, 0.6868591771999322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 218}], {
             RGBColor[
             0.6688238122630328, 0.7408690238634518, 0.9678585590852944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 220}], {
             RGBColor[
             0.8400295329313675, 0.8322802071721012, 0.6407339243969095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 222}], {
             RGBColor[
             0.6655940509632762, 0.738246958141221, 0.9676043004447721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 248}], {
             RGBColor[
             0.8539688329964191, 0.8847775961670854, 0.8904366325315348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 262}], {
             RGBColor[
             0.7770509926997926, 0.8258915994526674, 0.9783772288831425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 200}], {
             RGBColor[
             0.9027151127211679, 0.9223511046908461, 0.8722850108504652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 215}], {
             RGBColor[
             0.8369293578954871, 0.6588712882670315, 0.5940789956593333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 228}], {
             RGBColor[
             0.8990467443951413, 0.9208341401152684, 0.9330793674456318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 230}], {
             RGBColor[
             0.8109342614147372, 0.852227275436632, 0.9817900066324363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 245}], {
             RGBColor[
             0.901902444799157, 0.9220150456204818, 0.8857530214353493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 264}], {
             RGBColor[
             0.8960317564122003, 0.9188602977301551, 0.9504859584350298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 288}], {
             RGBColor[
             0.4955874212890399, 0.5793237275125108, 0.9577109660633423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 210}], {
             RGBColor[
             0.9783957008393586, 0.9830904672935236, 0.9072290565054614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 226}], {
             RGBColor[
             0.9881733377612096, 0.9893773854799737, 0.8456619299249105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 241}], {
             RGBColor[
             0.8203513820359074, 0.8593092182861402, 0.9230815960811694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 280}], {
             RGBColor[
             0.987796915316407, 0.9892217251254322, 0.8519002239853513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 290}], {
             RGBColor[
             0.8151124944161507, 0.8552165594605656, 0.9225594327234203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 291}], {
             RGBColor[
             0.9063492928811747, 0.926544870282682, 0.9316388853432072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 234}], {
             RGBColor[
             0.6953749730374833, 0.7569983669991289, 0.9239439121494093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 207}], {
             RGBColor[
             0.7454792487765248, 0.7970209118283244, 0.8463590448315839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 212}], {
             RGBColor[
             0.9100482513870027, 0.9278645347631509, 0.8612208198861244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 214}], {
             RGBColor[
             0.9620495018645667, 0.9693289203576192, 0.8661807455787388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 225}], {
             RGBColor[
             0.9913552909111139, 0.9906932048799251, 0.792928731600214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 265}], {
             RGBColor[
             0.9874636087086148, 0.9884424947213126, 0.8287007944632075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 276}], {
             RGBColor[
             0.9296180861463117, 0.9434689897912106, 0.863087408195665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 198}], {
             RGBColor[
             0.7257541728038782, 0.7803934968780077, 0.7999937208131278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 204}], {
             RGBColor[
             0.7222160959019397, 0.779550670151687, 0.9037150926271704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 226}], {
             RGBColor[
             0.7235939742843329, 0.780120458272666, 0.8808800819959663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 243}], {
             RGBColor[
             0.6523470057700784, 0.7257218166623582, 0.9678658884002986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 254}], {
             RGBColor[
             0.7167776873501268, 0.776042110058236, 0.9374344154912093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 283}], {
             RGBColor[
             0.7180374224040664, 0.7769816183988372, 0.9353020126364121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 204}], {
             RGBColor[
             0.9910249377768406, 0.9899363363721548, 0.753317256662218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 226}], {
             RGBColor[
             0.9924028161592339, 0.9905061244931337, 0.7304822460310141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 243}], {
             RGBColor[
             0.9211558476449795, 0.936107482882826, 0.8174680524353464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 254}], {
             RGBColor[
             0.9855865292250279, 0.9864277762787037, 0.787036579526257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 256}], {
             RGBColor[
             0.6234186835175997, 0.686632940457906, 0.7936369540285948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 283}], {
             RGBColor[
             0.9868462642789674, 0.987367284619305, 0.7849041766714597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 209}], {
             RGBColor[
             0.9418923931963994, 0.9521412880261826, 0.7788370163852641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 229}], {
             RGBColor[
             0.934575202919786, 0.9495476132095664, 0.9547455842090814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 233}], {
             RGBColor[
             0.7750608298555506, 0.8247683376261387, 0.978064369572998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 259}], {
             RGBColor[
             0.9184936587789412, 0.937554023920436, 0.9819674437010781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 261}], {
             RGBColor[
             0.938642549521163, 0.9520619429674229, 0.9246146862313712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 284}], {
             RGBColor[
             0.9372458380265425, 0.9514843668705493, 0.9477618102707133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 210}], {
             RGBColor[
             0.9819348633301211, 0.9845540019357812, 0.8485759749746002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 211}], {
             RGBColor[
             0.9658246562342432, 0.9725390358617185, 0.8758463533729719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 227}], {
             RGBColor[
             0.9820505442515856, 0.9846402765775992, 0.8483801573489773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 228}], {
             RGBColor[
             0.9895140145382295, 0.989931789781093, 0.8234434461694127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 231}], {
             RGBColor[
             0.9673119324593406, 0.9736482440352048, 0.8733287826676466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 245}], {
             RGBColor[
             0.9923697149422452, 0.9911126952863063, 0.7761171001591302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 264}], {
             RGBColor[
             0.9864990265552884, 0.9879579473959796, 0.8408500371588106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 202}], {
             RGBColor[
             0.8072296104940375, 0.8493709057361076, 0.9814107488029296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 203}], {
             RGBColor[
             0.8657847344171294, 0.7658420729879237, 0.6135494362971758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 216}], {
             RGBColor[
             0.7744214978526389, 0.8237409587897556, 0.978140742744079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 237}], {
             RGBColor[
             0.896562721387751, 0.9195136376615984, 0.9606940543067747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 269}], {
             RGBColor[
             0.9031375468387599, 0.9244171317176725, 0.9495645898073308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 277}], {
             RGBColor[
             0.7543216355619762, 0.8080387936036786, 0.9761373763148382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 293}], {
             RGBColor[
             0.877049170988957, 0.9047992183537923, 0.9881349269516062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 299}], {
             RGBColor[
             0.8622079426822131, 0.8929652257564052, 0.9867193573467881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 203}], {
             RGBColor[
             0.8483620914149855, 0.7521936401025417, 0.6118229229142407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 216}], {
             RGBColor[
             0.756998854850495, 0.8100925259043736, 0.9764142293611437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 237}], {
             RGBColor[
             0.879140078385607, 0.9058652047762166, 0.9589675409238394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 269}], {
             RGBColor[
             0.8857149038366161, 0.9107686988322905, 0.9478380764243954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 293}], {
             RGBColor[
             0.8596265279868132, 0.8911507854684104, 0.9864084135686709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 299}], {
             RGBColor[
             0.8447852996800693, 0.8793167928710233, 0.9849928439638528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 216}], {
             RGBColor[
             0.8155539787735868, 0.7265636931561898, 0.60855291685539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 237}], {
             RGBColor[
             0.9376952023086988, 0.8223363720280328, 0.5911062284180857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 255}], {
             RGBColor[
             0.8636380337300689, 0.41307872141810353`, 0.2055452881167969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 269}], {
             RGBColor[
             0.9442700277597079, 0.8272398660841067, 0.5799767639186418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 293}], {
             RGBColor[
             0.9181816519099049, 0.8076219527202266, 0.6185471010629173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 299}], {
             RGBColor[
             0.903340423603161, 0.7957879601228395, 0.6171315314580992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 226}], {
             RGBColor[
             0.9888647392572953, 0.989663297766813, 0.8342036178450567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 243}], {
             RGBColor[
             0.9176177707430409, 0.9352646561565053, 0.921189424249389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 254}], {
             RGBColor[
             0.9820484523230892, 0.9855849495523831, 0.8907579513402997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 283}], {
             RGBColor[
             0.9833081873770289, 0.9865244578929844, 0.8886255484855023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 225}], {
             RGBColor[
             0.965297847006936, 0.9729880715781425, 0.914441412625489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 251}], {
             RGBColor[
             0.8711570495020772, 0.9000889835359078, 0.9814661843110931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 269}], {
             RGBColor[
             0.9620519259253603, 0.9712189690061779, 0.9491203703522337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 282}], {
             RGBColor[
             0.8895337083127414, 0.914579160125109, 0.9832621877407628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 219}], {
             RGBColor[
             0.9114757863702974, 0.9320387706705111, 0.9840927928000944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 254}], {
             RGBColor[
             0.96025143666255, 0.9698761670620044, 0.9521681290313637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 283}], {
             RGBColor[
             0.9615111717164895, 0.9708156754026058, 0.9500357261765664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 212}], {
             RGBColor[
             0.6609316006857899, 0.7328521667894099, 0.9683564034925873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 214}], {
             RGBColor[
             0.712932851163354, 0.7743165523838782, 0.9733163291852017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 225}], {
             RGBColor[
             0.742238640209901, 0.7956808369061841, 0.900064315206677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 242}], {
             RGBColor[
             0.6618884323862336, 0.732276474994074, 0.9692790309300559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 244}], {
             RGBColor[
             0.5633478003702475, 0.6546463900343726, 0.9596297509233885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 252}], {
             RGBColor[
             0.6930042163962558, 0.7563946848112745, 0.9482315182392114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 268}], {
             RGBColor[
             0.6889964871219922, 0.7534057268805832, 0.9550155585173381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 279}], {
             RGBColor[
             0.5452339987014456, 0.6404957505007132, 0.9578243364561432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 259}], {
             RGBColor[
             0.9704174391414783, 0.9745944813546055, 0.7714372652382471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 211}], {
             RGBColor[
             0.9545771367001084, 0.965644283440829, 0.9617732387733262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 226}], {
             RGBColor[
             0.9804649807178374, 0.9839461677013418, 0.8729357337944036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 227}], {
             RGBColor[
             0.9708030247174507, 0.9777455241567097, 0.9343070427493316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 241}], {
             RGBColor[
             0.8126430249925352, 0.8538780005075083, 0.9503553999506624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 290}], {
             RGBColor[
             0.8074041373727785, 0.8497853416819338, 0.9498332365929134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 291}], {
             RGBColor[
             0.8986409358378025, 0.9211136525040502, 0.9589126892127002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 231}], {
             RGBColor[
             0.9399542058293278, 0.9547385255402525, 0.9865260464663724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 264}], {
             RGBColor[
             0.9591412999252756, 0.9690482289010274, 0.9540473009575365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 266}], {
             RGBColor[
             0.8270876256873223, 0.8657326825046534, 0.9806711960386946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 214}], {
             RGBColor[
             0.8775018537738319, 0.9051601753187047, 0.9881781042397423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 225}], {
             RGBColor[
             0.906807642820379, 0.9265244598410106, 0.9149260902612175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 265}], {
             RGBColor[
             0.9029159606178798, 0.9242737496823983, 0.950698153124211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 276}], {
             RGBColor[
             0.8450704380555769, 0.8793002447522962, 0.9850847668566685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 234}], {
             RGBColor[
             0.5482666649906078, 0.6421197562983725, 0.9584419812270702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 249}], {
             RGBColor[
             0.8155210795793508, 0.8566623599399492, 0.9777745563712238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 263}], {
             RGBColor[
             0.8274536035213176, 0.8655616167581534, 0.9575759058381513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 286}], {
             RGBColor[
             0.8424648376755874, 0.8742306456318015, 0.7953946384116348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 265}], {
             RGBColor[
             0.9549172110954439, 0.9657381352768664, 0.9556580788168254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 276}], {
             RGBColor[
             0.8970716885331409, 0.9207646303467645, 0.990044692549283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 286}], {
             RGBColor[
             0.9619016521164389, 0.9684207949743856, 0.8070640784420073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 229}], {
             RGBColor[
             0.9203963331093021, 0.7242417586680805, 0.563180516381025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 233}], {
             RGBColor[
             0.7608819600450667, 0.5994624830846528, 0.5864993017449416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 259}], {
             RGBColor[
             0.9043147889684572, 0.7122481693789501, 0.5904023758730217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 296}], {
             RGBColor[
             0.838902654950413, 0.6604128429239529, 0.594275675468259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 237}], {
             RGBColor[
             0.8463319657442083, 0.8802352578298647, 0.9556975348649889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 269}], {
             RGBColor[
             0.8529067911952174, 0.8851387518859386, 0.944568070365545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 293}], {
             RGBColor[
             0.8268184153454143, 0.8655208385220585, 0.9831384075098204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 299}], {
             RGBColor[
             0.8119771870386705, 0.8536868459246714, 0.9817228379050023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 223}], {
             RGBColor[
             0.877631399692379, 0.6878616852462537, 0.5973061861242853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 246}], {
             RGBColor[
             0.9384105615244098, 0.952549867778542, 0.9531713649793516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 247}], {
             RGBColor[
             0.9248469981119712, 0.942434184393842, 0.9761309398927089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 251}], {
             RGBColor[
             0.8476512484502342, 0.8815209852320717, 0.9852877055487561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 270}], {
             RGBColor[
             0.8952957648881745, 0.9193485570384314, 0.9898753033666403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 271}], {
             RGBColor[
             0.9432640983663032, 0.9504941737937588, 0.7048286858055763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 278}], {
             RGBColor[
             0.9448130645197688, 0.9546985776643442, 0.7976325124525347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 295}], {
             RGBColor[
             0.7767060947608437, 0.8260980919667813, 0.9782165556491531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 220}], {
             RGBColor[
             0.7913377647509158, 0.7939013391819355, 0.6361135779217735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 262}], {
             RGBColor[
             0.7283592245193409, 0.7875127314625019, 0.9737568824080065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 290}], {
             RGBColor[
             0.6321264875160759, 0.712200794861131, 0.9642009127105153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 292}], {
             RGBColor[
             0.7784422746717827, 0.8274204291859859, 0.977591951500745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 250}], {
             RGBColor[
             0.934790884824237, 0.9483753194089091, 0.8975240545500538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 222}], {
             RGBColor[
             0.7881080034511592, 0.7912792734597047, 0.6358593192812512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 248}], {
             RGBColor[
             0.9764827854843021, 0.9378099114855691, 0.5586916513680139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 262}], {
             RGBColor[
             0.8995649451876756, 0.8789239147711512, 0.6466322477196216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 230}], {
             RGBColor[
             0.887465491328741, 0.9124250783493222, 0.9626319350146215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 232}], {
             RGBColor[
             0.7992928171083596, 0.8434047648998424, 0.9539388446283074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 245}], {
             RGBColor[
             0.9784336747131608, 0.982212848533172, 0.8665949498175345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 288}], {
             RGBColor[
             0.5721186512030436, 0.6395215304252011, 0.9385528944455275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 296}], {
             RGBColor[
             0.8907523695470095, 0.9149928125946333, 0.9629595403177953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 297}], {
             RGBColor[
             0.9647932370943182, 0.9732634343875015, 0.9444800455916481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 248}], {
             RGBColor[
             0.8020473035162108, 0.843776662454689, 0.8855620274158765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 285}], {
             RGBColor[
             0.6646904216267411, 0.7375410360356824, 0.9675142351174025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 246}], {
             RGBColor[
             0.9205725516510928, 0.7209245364339678, 0.5605856853526402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 247}], {
             RGBColor[
             0.9070089882386542, 0.7108088530492678, 0.5835452602659975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 270}], {
             RGBColor[
             0.8774577550148575, 0.6877232256938572, 0.5972896237399289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 271}], {
             RGBColor[
             0.9254260884929861, 0.7188688424491846, 0.3122430061788649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 278}], {
             RGBColor[
             0.9269750546464517, 0.72307324631977, 0.4050468328258233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 295}], {
             RGBColor[
             0.7588680848875267, 0.5944727606222071, 0.5856308760224418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 253}], {
             RGBColor[
             0.7151225815024633, 0.7733032088612557, 0.8958147757550885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 262}], {
             RGBColor[
             0.6392262743042585, 0.7148396423352383, 0.9668259250229329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 265}], {
             RGBColor[
             0.9842230001419909, 0.9871024197991722, 0.8824060648383008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 276}], {
             RGBColor[
             0.926377477579688, 0.9421289148690704, 0.9167926785707582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 241}], {
             RGBColor[
             0.8224206619143863, 0.8601649186939584, 0.8887882733701116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 243}], {
             RGBColor[
             0.9189956491254341, 0.9358344442774842, 0.898354413618185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 290}], {
             RGBColor[
             0.8171817742946297, 0.8560722598683839, 0.8882661100123626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 291}], {
             RGBColor[
             0.9084185727596535, 0.9274005706905002, 0.8973455626321494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 241}], {
             RGBColor[
             0.8127587059139996, 0.8539642751493264, 0.9501595823250395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 290}], {
             RGBColor[
             0.8075198182942429, 0.8498716163237519, 0.9496374189672905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 291}], {
             RGBColor[
             0.8987566167592669, 0.9211999271458682, 0.9587168715870773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 299}], {
             RGBColor[
             0.93534116875358, 0.9503714558449243, 0.96220633881571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 264}], {
             RGBColor[
             0.9828306582292621, 0.9864409828204019, 0.9016443937539772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 233}], {
             RGBColor[
             0.8196674199414744, 0.859215120243692, 0.9434427589339842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 259}], {
             RGBColor[
             0.963100248864865, 0.9720008065379893, 0.9473458330620643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 284}], {
             RGBColor[
             0.9818524281124663, 0.9859311494881025, 0.9131401996316995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 245}], {
             RGBColor[
             0.9005888636358146, 0.9209888660320921, 0.8856220959411012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 288}], {
             RGBColor[
             0.4942738401256974, 0.5782975479241211, 0.9575800405690942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 296}], {
             RGBColor[
             0.8129075584696633, 0.8537688300935533, 0.981986686441362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 297}], {
             RGBColor[
             0.886948426016972, 0.9120394518864217, 0.9635071917152148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 232}], {
             RGBColor[
             0.7873584069325286, 0.8345041013315108, 0.9741406880633035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 245}], {
             RGBColor[
             0.9664992645373298, 0.9733121849648403, 0.8867967932525307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 264}], {
             RGBColor[
             0.960628576150373, 0.9701574370745136, 0.9515297302522111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 266}], {
             RGBColor[
             0.8285749019124198, 0.8668418906781397, 0.9781536253333691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 240}], {
             RGBColor[
             0.6619524035901625, 0.7357023655886437, 0.9670360251185859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 245}], {
             RGBColor[
             0.8124161894154333, 0.8519685525826122, 0.8769290055547871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 288}], {
             RGBColor[
             0.4061011659053161, 0.5092772344746413, 0.9488869501827799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 297}], {
             RGBColor[
             0.7987757517965907, 0.8430191384369419, 0.9548141013289007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 259}], {
             RGBColor[
             0.8035858758006296, 0.8472215309545615, 0.970664618425981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[
             0.4994596348672724, 0.6032354526312214, 0.9540941524147529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 249}], {
             RGBColor[
             0.6731582692002656, 0.7405378540103169, 0.9664173877266823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 263}], {
             RGBColor[
             0.6850907931422323, 0.7494371108285209, 0.9462187371936098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 274}], {
             RGBColor[
             0.8433080849474581, 0.8622364813001694, 0.6810657166830103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 298}], {
             RGBColor[
             0.7634974561722768, 0.7983705607388885, 0.6741482917234063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 260}], {
             RGBColor[
             0.8020962894182815, 0.8454947254560581, 0.9808635454213122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 267}], {
             RGBColor[
             0.8736683694163724, 0.9012784842307584, 0.942798436060802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 294}], {
             RGBColor[
             0.8668861591866606, 0.8962509441070108, 0.9556502270357821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 256}], {
             RGBColor[
             0.6103737708178703, 0.6792473272595221, 0.9379644348183493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 269}], {
             RGBColor[
             0.9750480147303294, 0.9809114307577815, 0.9271213819282407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 277}], {
             RGBColor[
             0.8262321034535456, 0.8645330926437875, 0.9536941684357481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 281}], {
             RGBColor[
             0.6155619804865747, 0.6847004645728227, 0.9382598956837137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 293}], {
             RGBColor[
             0.9489596388805264, 0.9612935173939013, 0.965691719072516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 248}], {
             RGBColor[
             0.791718750336188, 0.8353914776871281, 0.8847489258748082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 258}], {
             RGBColor[
             0.7895956106192584, 0.8345135048519758, 0.9199348454937875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 263}], {
             RGBColor[
             0.7786465733979822, 0.8266773130910023, 0.953228077025834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 285}], {
             RGBColor[
             0.6543618684467183, 0.7291558512681215, 0.9667011335763342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 290}], {
             RGBColor[
             0.6493598185693275, 0.7260040926745503, 0.9656857761686213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 291}], {
             RGBColor[
             0.7405966170343512, 0.7973324034966667, 0.9747652287884081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 250}], {
             RGBColor[
             0.9454257390652269, 0.9568552635052462, 0.8985384164414059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 268}], {
             RGBColor[
             0.9274365064045096, 0.9444907367551287, 0.9760918531117865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 254}], {
             RGBColor[
             0.9121793621912281, 0.9317560960630542, 0.954908747113428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 256}], {
             RGBColor[
             0.5500115164838, 0.6319612602422565, 0.9615091216157657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 283}], {
             RGBColor[
             0.9134390972451676, 0.9326956044036555, 0.9527763442586308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 279}], {
             RGBColor[
             0.6851333859679767, 0.7539506754155574, 0.9692513510439242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 280}], {
             RGBColor[
             0.8463684801934308, 0.8790115400639629, 0.897450980422952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 264}], {
             RGBColor[
             0.9856863586332777, 0.9876218883256151, 0.8543180477436947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 288}], {
             RGBColor[
             0.5852420235101172, 0.6480853181079709, 0.8615430553720071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 297}], {
             RGBColor[
             0.9779166094013918, 0.9818272220702714, 0.8674702065181279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 270}], {
             RGBColor[
             0.9382369168468883, 0.9524114082261455, 0.9531548025949952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 278}], {
             RGBColor[
             0.9877542164784826, 0.9877614288520582, 0.7609120116808896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 295}], {
             RGBColor[
             0.8196472467195575, 0.8591609431544954, 0.941496054877508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 251}], {
             RGBColor[
             0.8770288369965094, 0.9044681530350858, 0.9715267796904683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 270}], {
             RGBColor[
             0.9246733534344497, 0.9422957248414454, 0.9761143775083525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 271}], {
             RGBColor[
             0.9726416869125785, 0.9734413415967729, 0.6910677599472885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 278}], {
             RGBColor[
             0.974190653066044, 0.9776457454673583, 0.7838715865942469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 289}], {
             RGBColor[
             0.9299114489669654, 0.9464724400347581, 0.976613991736347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 295}], {
             RGBColor[
             0.8060836833071189, 0.8490452597697955, 0.9644556297908653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 285}], {
             RGBColor[
             0.853065203659884, 0.8840716740615469, 0.8903465672041653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 258}], {
             RGBColor[
             0.9632942449522517, 0.9718159062310713, 0.9322580808057168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 263}], {
             RGBColor[
             0.9523452077309753, 0.9639797144700979, 0.9655513123377634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 286}], {
             RGBColor[
             0.9673564418852452, 0.9726487433437461, 0.8033700449112469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 270}], {
             RGBColor[
             0.8474776037727126, 0.8813825256796752, 0.9852711431643997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 271}], {
             RGBColor[
             0.8954459372508414, 0.9125281424350026, 0.7002245256033357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 278}], {
             RGBColor[
             0.896994903404307, 0.916732546305588, 0.7930283522502941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 282}], {
             RGBColor[
             0.8182097461454365, 0.8580451304625165, 0.982479548776185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 289}], {
             RGBColor[
             0.8527156993052284, 0.8855592408729878, 0.9857707573923942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 295}], {
             RGBColor[
             0.7288879336453818, 0.7881320606080251, 0.9736123954469125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 268}], {
             RGBColor[
             0.9585522904145318, 0.9686089465723291, 0.955044340420942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 279}], {
             RGBColor[
             0.8147898019939851, 0.8556989701924592, 0.9578531183597471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 280}], {
             RGBColor[
             0.9760248962194393, 0.9807598348408647, 0.8860527477387747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 283}], {
             RGBColor[
             0.9708447667839755, 0.9777766553215775, 0.9342363843187798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 283}], {
             RGBColor[
             0.977869778825216, 0.9830158977995332, 0.9223448713495415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 258}], {
             RGBColor[
             0.9032673291187775, 0.5730219951460489, 0.5229475822828523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 286}], {
             RGBColor[
             0.9073295260517711, 0.5738548322587238, 0.3940595463883825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 269}], {
             RGBColor[
             0.6169485962688794, 0.684150821315596, 0.9268349703189054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 277}], {
             RGBColor[
             0.4681326849920955, 0.5677724832016021, 0.953407756826413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 281}], {
             RGBColor[
             0.2574625620251247, 0.38793985513063733`, 0.9379734840743785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 293}], {
             RGBColor[
             0.5908602204190763, 0.6645329079517159, 0.9654053074631809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 267}], {
             RGBColor[
             0.9890595964671394, 0.9884160975958963, 0.734458839598322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 272}], {
             RGBColor[
             0.9055309397414877, 0.5615759884215195, 0.36227361503633215`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 300}], {
             RGBColor[
             0.9893714377177355, 0.9885450519669725, 0.7292908230566573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 263}], {
             RGBColor[
             0.9752267688942184, 0.9807151630492754, 0.9120594302726444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 286}], {
             RGBColor[
             0.9902380030484883, 0.9893841919229236, 0.7498781628461278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 267}], {
             RGBColor[
             0.9128042334532125, 0.9320234595740533, 0.94665355848449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 287}], {
             RGBColor[
             0.8620800089751692, 0.8928632148910765, 0.9867071549156026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 294}], {
             RGBColor[
             0.9060220232235006, 0.9269959194503057, 0.95950534945947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 300}], {
             RGBColor[
             0.9131160747038085, 0.9321524139451295, 0.9414855419428251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 284}], {
             RGBColor[
             0.9859197747138433, 0.988445479245959, 0.8830093016539893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 292}], {
             RGBColor[
             0.8866694551085426, 0.9124430047752016, 0.9881106212985931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 286}], {
             RGBColor[
             0.9792889658272119, 0.9815480001619501, 0.7831713943781744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 288}], {
             RGBColor[
             0.5793713351231605, 0.6449305702176442, 0.9262759923716877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 276}], {
             RGBColor[
             0.9224857953771889, 0.9398782047104579, 0.9525647414337517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 286}], {
             RGBColor[
             0.9873157589604868, 0.9875343693380791, 0.7695841273264761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 272}], {
             RGBColor[
             0.9008476567256517, 0.5609671091743769, 0.5364032245619899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 287}], {
             RGBColor[
             0.9336520889732602, 0.9486469736657768, 0.9486420455550924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 300}], {
             RGBColor[
             0.9846881547018995, 0.9879361727198297, 0.903420432582315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 279}], {
             RGBColor[
             0.8107820727197215, 0.8527100122617679, 0.9646371586378738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 280}], {
             RGBColor[
             0.9720171669451757, 0.9777708769101734, 0.8928367880169015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 277}], {
             RGBColor[
             0.8328069289045547, 0.8694365866998616, 0.9425647039363042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 282}], {
             RGBColor[
             0.9091046225687196, 0.9291751159327866, 0.9501337348173258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 293}], {
             RGBColor[
             0.9555344643315355, 0.9661970114499754, 0.9545622545730721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 271}], {
             RGBColor[
             0.9430904536887816, 0.9503557142413623, 0.7048121234212199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 278}], {
             RGBColor[
             0.9446394198422472, 0.9545601181119476, 0.7976159500681783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 289}], {
             RGBColor[
             0.9003602157431687, 0.9233868126793474, 0.9903583552102784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 295}], {
             RGBColor[
             0.7765324500833222, 0.8259596324143849, 0.9781999932647967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 278}], {
             RGBColor[
             0.992607753320376, 0.9857057348672751, 0.5125693325071143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 289}], {
             RGBColor[
             0.9483285492212974, 0.9545324294346749, 0.7053117376492144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 295}], {
             RGBColor[
             0.8245007835614508, 0.8571052491697122, 0.6931533757037327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 274}], {
             RGBColor[
             0.844418825277015, 0.8781478697131178, 0.9271573278973921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 289}], {
             RGBColor[
             0.9457506034857823, 0.9580010136054602, 0.9370735000507053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 289}], {
             RGBColor[
             0.8042665330669172, 0.8477103839803176, 0.9809417972849596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 281}], {
             RGBColor[
             0.47332089466079996`, 0.5732256205149029, 0.9537032176917772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 282}], {
             RGBColor[
             0.7602887112919358, 0.8127967778187926, 0.9767065213248332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 293}], {
             RGBColor[
             0.8067185530547516, 0.8498186733359814, 0.9811350410805797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 295}], {
             RGBColor[
             0.8260497497149164, 0.8613096530402977, 0.7859572023506911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 280}], {
             RGBColor[
             0.828254678524629, 0.8648609005303034, 0.8956455659557065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 294}], {
             RGBColor[
             0.6167313323428545, 0.6855725652725982, 0.9362804880068414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 293}], {
             RGBColor[
             0.8830162467189167, 0.9095572025689064, 0.9887040719616011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 300}], {
             RGBColor[
             0.9339639302238563, 0.9487759280368528, 0.9434740290134276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 296}], {
             RGBColor[
             0.4975607183439659, 0.5808652821694322, 0.9579076458722678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 297}], {
             RGBColor[
             0.5716015858912746, 0.6391359039623006, 0.9394281511461207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 291}], {
             RGBColor[
             0.7353577294145947, 0.7932397446710922, 0.9742430654306591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 297}], {
             RGBColor[
             0.8902353042352406, 0.9146071861317326, 0.9638347970183885]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.032105813875877395`], {
             RGBColor[
             0.9815637853331602, 0.9857708818047776, 0.9160918818827913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.032105813875877395`], {
             RGBColor[
             0.995000614253539, 0.9917151443407831, 0.6972258980092602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.032105813875877395`], {
             RGBColor[
             0.9631955369450624, 0.9720718722321805, 0.9471845351974016]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.032105813875877395`], {
             RGBColor[
             0.8292615980775258, 0.8666947048733279, 0.983576905586844]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.032105813875877395`], {
             RGBColor[
             0.9930300212908642, 0.9875002452511322, 0.4827390151121649]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.032105813875877395`], {
             RGBColor[
             0.6653236197792114, 0.7384751355090947, 0.9672768986830185]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.032105813875877395`], {
             RGBColor[
             0.9870838309064348, 0.9889268463964752, 0.8637178780618887]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.032105813875877395`], {
             RGBColor[
             0.7530764606636936, 0.8070283217543445, 0.976023281765461]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.032105813875877395`], {
             RGBColor[
             0.5061207195781898, 0.6099306264889837, 0.9542628235079301]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.032105813875877395`], {
             RGBColor[
             0.9530185259250165, 0.9644818740767565, 0.9644115602647617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.032105813875877395`], {
             RGBColor[
             0.9633908767620196, 0.9722175563478277, 0.9468538758400769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.032105813875877395`], {
             RGBColor[
             0.849627820487435, 0.8829341777966093, 0.9855194540614425]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.032105813875877395`], {
             RGBColor[
             0.940126630351698, 0.9548671194667171, 0.9862341767255174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.032105813875877395`], {
             RGBColor[
             0.9927021671525936, 0.9867989984005097, 0.4470541154426206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.032105813875877395`], {
             RGBColor[
             0.9847562209236621, 0.9602412951452857, 0.3952812261449029]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.032105813875877395`], {
             RGBColor[
             0.9225365244751187, 0.9410695993023398, 0.9924735513341562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.032105813875877395`], {
             RGBColor[
             0.6719266414523094, 0.7436334662249422, 0.967935026174647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.032105813875877395`], {
             RGBColor[
             0.6538156177699137, 0.7294849968753766, 0.9661298885911248]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.032105813875877395`], {
             RGBColor[
             0.989103626300843, 0.989762083698437, 0.83024464131362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.032105813875877395`], {
             RGBColor[
             0.9766100437712765, 0.9820763894589319, 0.9244772742043387]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.032105813875877395`], {
             RGBColor[
             0.9869881295438769, 0.9888872714236447, 0.8653038973066597]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.032105813875877395`], {
             RGBColor[
             0.9929678627929593, 0.987367294509302, 0.47597344621301235`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.032105813875877395`], {
             RGBColor[
             0.2700166025735334, 0.4011349477191588, 0.9386884181115718]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.032105813875877395`], {
             RGBColor[
             0.8520111650289094, 0.8848345920398168, 0.9857467795914451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.032105813875877395`], {
             RGBColor[
             0.945247068878971, 0.9586859341364088, 0.9775666099230976]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.032105813875877395`], {
             RGBColor[
             0.8961752861481396, 0.920049863417159, 0.9899591928895737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.032105813875877395`], {
             RGBColor[
             0.9559909905692867, 0.9666987333414889, 0.9593799529649543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.032105813875877395`], {
             RGBColor[
             0.5779004775709693, 0.6682046676687693, 0.959913588995039]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.032105813875877395`], {
             RGBColor[
             0.6362709602742411, 0.7155924550875649, 0.9645087272115639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.032105813875877395`], {
             RGBColor[
             0.8208004069783359, 0.8599479807637479, 0.9827698696264088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.032105813875877395`], {
             RGBColor[
             0.9786091619983263, 0.9395058219920551, 0.37140106299464704`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.032105813875877395`], {
             RGBColor[
             0.9863186895293484, 0.9655118686373406, 0.4013511216305565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.032105813875877395`], {
             RGBColor[
             0.9911159103694888, 0.9905942148741638, 0.7968958866719252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.032105813875877395`], {
             RGBColor[
             0.9878987235642077, 0.9892638254522504, 0.8502129978479943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.032105813875877395`], {
             RGBColor[
             0.9713625622461046, 0.9150613394452755, 0.3432493913628023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.032105813875877395`], {
             RGBColor[
             0.2700166025735334, 0.4011349477191588, 0.9386884181115718]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.032105813875877395`], {
             RGBColor[
             0.9866804103714635, 0.9887600216378297, 0.8704036003452404]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.032105813875877395`], {
             RGBColor[
             0.9393898537746044, 0.9543176327018816, 0.9874813472884296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.032105813875877395`], {
             RGBColor[
             0.9838855174256722, 0.9875024257978855, 0.9121617950548794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.032105813875877395`], {
             RGBColor[
             0.9382412544819299, 0.9534610092300637, 0.9894256262882539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.032105813875877395`], {
             RGBColor[
             0.9941421737539696, 0.9898790269138522, 0.6037899473117907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.032105813875877395`], {
             RGBColor[
             0.8960115772376082, 0.6206946839967139, 0.23494184986862096`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.032105813875877395`], {
             RGBColor[
             0.8999392186662244, 0.9230511210378533, 0.9903182001332508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.032105813875877395`], {
             RGBColor[
             0.892425658243354, 0.917060011906821, 0.9896015500326829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.032105813875877395`], {
             RGBColor[
             0.7228796924284554, 0.7834383769050377, 0.9730135501126157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.032105813875877395`], {
             RGBColor[
             0.9229819094644407, 0.9414247372031717, 0.9925160325520376]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.032105813875877395`], {
             RGBColor[
             0.8894437189009132, 0.9146822944177458, 0.9893171299961921]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.032105813875877395`], {
             RGBColor[
             0.7355925767768008, 0.7933697787794648, 0.9742806516158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.032105813875877395`], {
             RGBColor[
             0.8645006017736806, 0.8947933298833682, 0.9869380332176132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.032105813875877395`], {
             RGBColor[
             0.9686808075455953, 0.9060151511345095, 0.3328312807582043]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.032105813875877395`], {
             RGBColor[
             0.9687706907538836, 0.9762298128143228, 0.9377472540320605]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.032105813875877395`], {
             RGBColor[
             0.9337461264621959, 0.9500078316502951, 0.9935427331786134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.032105813875877395`], {
             RGBColor[
             0.9398423322838397, 0.9546550904332037, 0.9867154191975899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.032105813875877395`], {
             RGBColor[
             0.9295031042513959, 0.9466245609131729, 0.9931380299323567]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.032105813875877395`], {
             RGBColor[
             0.938012953324855, 0.7919490464315171, 0.26898197110343025`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.032105813875877395`], {
             RGBColor[
             0.995143074044988, 0.9920198514297981, 0.7127317671485611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.032105813875877395`], {
             RGBColor[
             0.9663230142674084, 0.8980617607709968, 0.3236716991043483]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.032105813875877395`], {
             RGBColor[
             0.8600258076535335, 0.8912252505170136, 0.9865112233597377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.032105813875877395`], {
             RGBColor[
             0.9908606739359661, 0.990488668049625, 0.8011258149061115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.032105813875877395`], {
             RGBColor[
             0.358220172469528, 0.4846940415488944, 0.9440464505214654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.032105813875877395`], {
             RGBColor[
             0.9881146823444901, 0.9893531299577847, 0.8466340019753072]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.032105813875877395`], {
             RGBColor[
             0.9926754455351767, 0.9867418435628249, 0.4441456322935001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.032105813875877395`], {
             RGBColor[
             0.9857957459759027, 0.9883941901754274, 0.8850647788177481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.032105813875877395`], {
             RGBColor[
             0.9156719119031497, 0.9355959435723961, 0.9918187984589298]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.032105813875877395`], {
             RGBColor[
             0.9109136900522419, 0.684509497849769, 0.24717726777282212`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.032105813875877395`], {
             RGBColor[
             0.8311241534426388, 0.8681798559637505, 0.9837545577802913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.032105813875877395`], {
             RGBColor[
             0.9042414356109009, 0.9264815920489704, 0.9907285494260685]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.032105813875877395`], {
             RGBColor[
             0.2700166025735334, 0.4011349477191588, 0.9386884181115718]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.032105813875877395`], {
             RGBColor[
             0.620132044082581, 0.7024901558732861, 0.9632382126101584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.032105813875877395`], {
             RGBColor[
             0.8064337231309612, 0.8487114207239883, 0.9813414350362311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.032105813875877395`], {
             RGBColor[
             0.8654580503984112, 0.8955567734274779, 0.9870293555221645]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.032105813875877395`], {
             RGBColor[
             0.8319281510392084, 0.8688209418233217, 0.9838312437887892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.032105813875877395`], {
             RGBColor[
             0.7019988963046534, 0.7671261402731954, 0.9709323474971292]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.032105813875877395`], {
             RGBColor[
             0.8786739997174374, 0.9060948126770817, 0.9882899045662304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.032105813875877395`], {
             RGBColor[
             0.9521637444961126, 0.963844379486656, 0.9658584822611943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.032105813875877395`], {
             RGBColor[
             0.9877307813373964, 0.9891943770255456, 0.8529962351668088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.032105813875877395`], {
             RGBColor[
             0.8863720320191234, 0.9122330146769259, 0.9890241497592798]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.032105813875877395`], {
             RGBColor[
             0.9952725511659818, 0.9922967898994588, 0.7268245527285649]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.032105813875877395`], {
             RGBColor[
             0.8915147491455727, 0.9163336777182189, 0.9895146667097583]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.032105813875877395`], {
             RGBColor[
             0.8247727272441194, 0.8631154011179225, 0.9831487530794913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.032105813875877395`], {
             RGBColor[
             0.9773613945860082, 0.9352968095205856, 0.36655372221889565`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.032105813875877395`], {
             RGBColor[
             0.4669334037501397, 0.5781165981313124, 0.9511778544580783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.032105813875877395`], {
             RGBColor[
             0.4106940114905117, 0.5301442434970352, 0.9473900371430886]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.032105813875877395`], {
             RGBColor[
             0.5217520344072921, 0.6226208320499571, 0.9554933778706699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.032105813875877395`], {
             RGBColor[
             0.9932325508050837, 0.9879334354031729, 0.5047831028676866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.032105813875877395`], {
             RGBColor[
             0.456949887042238, 0.5700115295155355, 0.9503919154520056]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.032105813875877395`], {
             RGBColor[
             0.6579427799559914, 0.7327091673427348, 0.9665412455473096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.032105813875877395`], {
             RGBColor[
             0.8490620027099094, 0.8824830100595249, 0.9854654858567107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.032105813875877395`], {
             RGBColor[
             0.9864547092367454, 0.9886666884183692, 0.8741440522433324]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.032105813875877395`], {
             RGBColor[
             0.9836592448586059, 0.9873336720878548, 0.9125448154895855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.032105813875877395`], {
             RGBColor[
             0.9951541499035746, 0.9922641306995306, 0.7299718069632111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.032105813875877395`], {
             RGBColor[
             0.9939780454794566, 0.9895279731305829, 0.5859255975133435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.032105813875877395`], {
             RGBColor[
             0.972745898422713, 0.9791945161849307, 0.9310182643489405]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.032105813875877395`], {
             RGBColor[
             0.9945769405148216, 0.9908089490536524, 0.651111626161101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.032105813875877395`], {
             RGBColor[
             0.9404605733653404, 0.9551161736195101, 0.9856688983097077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.032105813875877395`], {
             RGBColor[
             0.933135039649653, 0.949520567613483, 0.9934844471729095]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.032105813875877395`], {
             RGBColor[
             0.9929642647042682, 0.9873595985614142, 0.47558181646380854`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.032105813875877395`], {
             RGBColor[
             0.9504601324030899, 0.8412979637001735, 0.2789972635626222]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.032105813875877395`], {
             RGBColor[
             0.9849328148145859, 0.9880373459639037, 0.8993657813550266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.032105813875877395`], {
             RGBColor[
             0.6797200067659406, 0.749721702439721, 0.9687117959959702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.032105813875877395`], {
             RGBColor[
             0.8199956978278649, 0.8593063275304104, 0.9826931157492645]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.032105813875877395`], {
             RGBColor[
             0.7223772811171819, 0.7830458893702035, 0.9729634744484087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.032105813875877395`], {
             RGBColor[
             0.9453311391884103, 0.9587486336355361, 0.9774243008182655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.032105813875877395`], {
             RGBColor[
             0.994032855337522, 0.9896452058748579, 0.591891312316521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.032105813875877395`], {
             RGBColor[
             0.660153046877239, 0.7344358446602642, 0.9667615442979008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.032105813875877395`], {
             RGBColor[
             0.8526523137965555, 0.8853458266636182, 0.9858079329332635]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.032105813875877395`], {
             RGBColor[
             0.9934998434176021, 0.9915800324538434, 0.7573879466437241]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.032105813875877395`], {
             RGBColor[
             0.7625525841657868, 0.8144311414553858, 0.9769677731967408]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.032105813875877395`], {
             RGBColor[
             0.6567881182926985, 0.7318071368756167, 0.9664261596636393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.032105813875877395`], {
             RGBColor[
             0.880416047591713, 0.5498790263031939, 0.22192855765067318`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.032105813875877395`], {
             RGBColor[
             0.6015656119814586, 0.6874170898853604, 0.9617765950640764]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.032105813875877395`], {
             RGBColor[
             0.2522743523564202, 0.3824867178173366, 0.9376780232090142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.032105813875877395`], {
             RGBColor[
             0.9568240638139651, 0.9673200380033379, 0.9579697772620142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.032105813875877395`], {
             RGBColor[
             0.9545795256877815, 0.965646065143924, 0.9617691948403432]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.032105813875877395`], {
             RGBColor[
             0.992339118045761, 0.9911000426833056, 0.7766241699161031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.032105813875877395`], {
             RGBColor[
             0.9932268218872813, 0.987921181827276, 0.5041595455196706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.032105813875877395`], {
             RGBColor[
             0.9736760712904564, 0.9798882375866754, 0.9294437243117891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.032105813875877395`], {
             RGBColor[
             0.9946290938037046, 0.9909204996650666, 0.6567881898032171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.032105813875877395`], {
             RGBColor[
             0.9391914011140923, 0.9541696270326081, 0.9878172758779331]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.032105813875877395`], {
             RGBColor[
             0.4363011627406259, 0.5523238708570395, 0.949021702177231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.032105813875877395`], {
             RGBColor[
             0.7908187791676624, 0.8365129078218898, 0.9797850833519173]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.032105813875877395`], {
             RGBColor[
             0.9925888590267843, 0.9865566437766122, 0.43472122520496925`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.032105813875877395`], {
             RGBColor[
             0.975816536273443, 0.9814845928662971, 0.9258204754182696]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.032105813875877395`], {
             RGBColor[
             0.8628437392502277, 0.47008727824139357`, 0.20726579283384527`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.032105813875877395`], {
             RGBColor[
             0.9942995796905422, 0.9902157022959995, 0.6209226121108762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.032105813875877395`], {
             RGBColor[
             0.9915208733209947, 0.9907616774616845, 0.7901846025549486]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.032105813875877395`], {
             RGBColor[
             0.9780952570225375, 0.9831840590699089, 0.9219631955756085]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.032105813875877395`], {
             RGBColor[
             0.9936622523011817, 0.9888525234538409, 0.5515534589077112]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.032105813875877395`], {
             RGBColor[
             0.9908723644315146, 0.98087248333606, 0.41904128873612295`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.032105813875877395`], {
             RGBColor[
             0.965130537518458, 0.9735149924915464, 0.9439090839556193]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.032105813875877395`], {
             RGBColor[
             0.6532829343049973, 0.7290688605040396, 0.9660767956815519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.032105813875877395`], {
             RGBColor[
             0.8406373349817257, 0.8757654086945846, 0.9846619335280068]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.032105813875877395`], {
             RGBColor[
             0.4425172738388731, 0.5577079538595131, 0.9494177872797201]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.032105813875877395`], {
             RGBColor[
             0.992371383899417, 0.9911133854429871, 0.7760894412196707]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.032105813875877395`], {
             RGBColor[
             0.9903605282050278, 0.990281844936723, 0.80941452400342]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.032105813875877395`], {
             RGBColor[
             0.838510215788073, 0.8740693015886783, 0.9844590470004145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.032105813875877395`], {
             RGBColor[
             0.9941627915789626, 0.9899231263567303, 0.6060340703238073]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.032105813875877395`], {
             RGBColor[
             0.8391653703581445, 0.8745917040591563, 0.9845215362281713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.032105813875877395`], {
             RGBColor[
             0.9877415040805252, 0.9891988111553912, 0.8528185315635947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.032105813875877395`], {
             RGBColor[
             0.5014276395503677, 0.6061205727015517, 0.9538933670568214]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.032105813875877395`], {
             RGBColor[
             0.9708118929918796, 0.9777521381012584, 0.9342920310739399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.032105813875877395`], {
             RGBColor[
             0.8651368615626388, 0.8953006661682716, 0.9869987202442798]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.032105813875877395`], {
             RGBColor[
             0.7151642969503449, 0.7774110513183604, 0.9722445515958278]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.032105813875877395`], {
             RGBColor[
             0.49260100572952575`, 0.5989547137304699, 0.9531985021094197]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.032105813875877395`], {
             RGBColor[
             0.9453448865955926, 0.9587588864293032, 0.977401030043804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.032105813875877395`], {
             RGBColor[
             0.69944283949338, 0.7651293292654773, 0.9706775836418905]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.032105813875877395`], {
             RGBColor[
             0.7544887762703004, 0.808131633440222, 0.976164048186288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.032105813875877395`], {
             RGBColor[
             0.6962597288881043, 0.7626426590680992, 0.9703603209246164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.032105813875877395`], {
             RGBColor[
             0.867995913860049, 0.8975803968633195, 0.987271419204713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.032105813875877395`], {
             RGBColor[
             0.9673937984340938, 0.9752029287766779, 0.9400779735784334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.032105813875877395`], {
             RGBColor[
             0.9724571419814801, 0.9789791621038545, 0.9315070536842063]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.032105813875877395`], {
             RGBColor[
             0.94835645531017, 0.9610049094456439, 0.9723032297529413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.032105813875877395`], {
             RGBColor[
             0.7271941485241836, 0.7868088627981015, 0.9734435747753534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.032105813875877395`], {
             RGBColor[
             0.9874999613056683, 0.9890989270106217, 0.8568215204356365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.032105813875877395`], {
             RGBColor[
             0.916591643426553, 0.7070206909131136, 0.2517458823364881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.032105813875877395`], {
             RGBColor[
             0.3573833176626465, 0.4839691999767193, 0.9439931268731725]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.032105813875877395`], {
             RGBColor[
             0.9870858521967436, 0.9889276822519627, 0.8636843800505403]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.032105813875877395`], {
             RGBColor[
             0.8634815018058043, 0.4729832090530376, 0.20779795754320912`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.032105813875877395`], {
             RGBColor[
             0.850632572384055, 0.8837353396857104, 0.9856152881942948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.032105813875877395`], {
             RGBColor[
             0.9947786965960442, 0.9912404849107186, 0.6730715305079789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.032105813875877395`], {
             RGBColor[
             0.9259417624403533, 0.9437848436230957, 0.9927983459711721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.032105813875877395`], {
             RGBColor[
             0.967740626625343, 0.9754615926738325, 0.9394908839179281]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.032105813875877395`], {
             RGBColor[
             0.6012014939635917, 0.6871214824751263, 0.9617479303599016]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.032105813875877395`], {
             RGBColor[
             0.571379139794039, 0.6629103518785382, 0.9594002053967916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.032105813875877395`], {
             RGBColor[
             0.8764731443594369, 0.9043399103552394, 0.9880799850174575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.032105813875877395`], {
             RGBColor[
             0.8835534361133671, 0.9099855428104235, 0.9887553095655985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.032105813875877395`], {
             RGBColor[
             0.6845930918336023, 0.7535285935313967, 0.9691974995739456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.032105813875877395`], {
             RGBColor[
             0.9792359176268116, 0.9840347618809162, 0.9200323547045045]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.032105813875877395`], {
             RGBColor[
             0.9533862423231773, 0.8528990144649918, 0.281351680288952]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.032105813875877395`], {
             RGBColor[
             0.8410747509036739, 0.8761141922774073, 0.984703654649128]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.032105813875877395`], {
             RGBColor[
             0.9438210921265127, 0.9576224430092479, 0.9799804166107083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.032105813875877395`], {
             RGBColor[
             0.9877415040805252, 0.9891988111553912, 0.8528185315635947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.032105813875877395`], {
             RGBColor[
             0.9223670396033584, 0.9409344566661425, 0.9924573857157868]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.032105813875877395`], {
             RGBColor[
             0.7264903655056463, 0.786259062155071, 0.9733734282612918]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.032105813875877395`], {
             RGBColor[
             0.9402558625324343, 0.8008414340343819, 0.27078666849969407`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.032105813875877395`], {
             RGBColor[
             0.9736236277838297, 0.9798491253053015, 0.9295324974890509]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.032105813875877395`], {
             RGBColor[
             0.9918518455717579, 0.990898542992974, 0.7846995358310752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.032105813875877395`], {
             RGBColor[
             0.6012014939635917, 0.6871214824751263, 0.9617479303599016]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.032105813875877395`], {
             RGBColor[
             0.8151834070782743, 0.8555467403236903, 0.9822135217616539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.032105813875877395`], {
             RGBColor[
             0.525961613910297, 0.626038358329892, 0.9558247713893443]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.032105813875877395`], {
             RGBColor[
             0.9911703599275563, 0.9906167311657145, 0.7959935165838081]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.032105813875877395`], {
             RGBColor[
             0.9153404177559255, 0.9353316191375685, 0.9917871802512392]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.032105813875877395`], {
             RGBColor[
             0.9850091007977889, 0.9880688921784184, 0.8981015251915565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.032105813875877395`], {
             RGBColor[
             0.5140591005788882, 0.6163753618053391, 0.9548877619395528]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.032105813875877395`], {
             RGBColor[
             0.9891178475964255, 0.974954086071161, 0.41222532214450464`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.032105813875877395`], {
             RGBColor[
             0.9380007763931056, 0.9532816610651653, 0.9898326929659028]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.032105813875877395`], {
             RGBColor[
             0.7175990333729405, 0.7793130859163742, 0.9724872233685266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.032105813875877395`], {
             RGBColor[
             0.7109845094775343, 0.7741457695770394, 0.9718279494428727]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.032105813875877395`], {
             RGBColor[
             0.824835898100934, 0.8631657718444192, 0.9831547783722077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.032105813875877395`], {
             RGBColor[
             0.6999323839141084, 0.7655117650876256, 0.970726376854696]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.032105813875877395`], {
             RGBColor[
             0.9878183730334578, 0.9705706532391333, 0.4071771088525548]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.032105813875877395`], {
             RGBColor[
             0.7175155804434845, 0.7792478918536174, 0.9724789055604304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.032105813875877395`], {
             RGBColor[
             0.8122478425780797, 0.8532534550250217, 0.9819209321266844]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.032105813875877395`], {
             RGBColor[
             0.9861040578827308, 0.9885216850721554, 0.8799552526359683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.032105813875877395`], {
             RGBColor[
             0.9848460914634438, 0.9880014836295179, 0.9008030117162897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.032105813875877395`], {
             RGBColor[
             0.9945958994777376, 0.9920332798020653, 0.739223461225121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.032105813875877395`], {
             RGBColor[
             0.45694533092897727`, 0.5700078306575399, 0.9503915567780801]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.032105813875877395`], {
             RGBColor[
             0.9945630146787792, 0.9907791630984755, 0.6495958848481754]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.032105813875877395`], {
             RGBColor[
             0.8899686128338622, 0.9151008305920131, 0.9893671948480952]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.032105813875877395`], {
             RGBColor[
             0.993182382864256, 0.9914487543566707, 0.762649089574246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.032105813875877395`], {
             RGBColor[
             0.8246522534961814, 0.8630193386214895, 0.9831372621858648]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.032105813875877395`], {
             RGBColor[
             0.7898069674918937, 0.8357224728507257, 0.9796842354199943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.032105813875877395`], {
             RGBColor[
             0.9069172153380773, 0.668664807354358, 0.24396161040848696`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.032105813875877395`], {
             RGBColor[
             0.9874868608749021, 0.9890935096458342, 0.8570386284762607]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.032105813875877395`], {
             RGBColor[
             0.942481011669382, 0.9566230131985003, 0.9822488232756708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.032105813875877395`], {
             RGBColor[
             0.9438928295538235, 0.957675944665077, 0.9798589838583887]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.032105813875877395`], {
             RGBColor[
             0.4963625980753121, 0.6020085438545834, 0.9534946284380468]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.032105813875877395`], {
             RGBColor[
             0.42344841310371634`, 0.5411914651195284, 0.9482027363356074]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.032105813875877395`], {
             RGBColor[
             0.9938161735589365, 0.9891817454603522, 0.5683068379224331]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.032105813875877395`], {
             RGBColor[
             0.9706873437959863, 0.9776592495148917, 0.9345028603749544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.032105813875877395`], {
             RGBColor[
             0.9384669296042303, 0.9536293173667663, 0.9890436171716979]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.032105813875877395`], {
             RGBColor[
             0.8255006032962678, 0.8636957897242366, 0.9832181785471279]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.032105813875877395`], {
             RGBColor[
             0.690629475369693, 0.7582442622280048, 0.9697991498716118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.032105813875877395`], {
             RGBColor[
             0.9295031042513959, 0.9466245609131729, 0.9931380299323567]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.032105813875877395`], {
             RGBColor[
             0.8616108732128943, 0.46448912150904126`, 0.20623705919198235`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.032105813875877395`], {
             RGBColor[
             0.7241907422090963, 0.7844625789580217, 0.9731442233022932]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.032105813875877395`], {
             RGBColor[
             0.8954694095656961, 0.9194870165908279, 0.9898918657509967]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.032105813875877395`], {
             RGBColor[
             0.620132044082581, 0.7024901558732861, 0.9632382126101584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.032105813875877395`], {
             RGBColor[
             0.8790587431867711, 0.9064015966759452, 0.9883266017418001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.032105813875877395`], {
             RGBColor[
             0.9625434854192505, 0.8853125224905849, 0.3089889432333886]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.032105813875877395`], {
             RGBColor[
             0.9653103024060872, 0.9736490608504021, 0.9436047888910548]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.032105813875877395`], {
             RGBColor[
             0.6136725214830678, 0.6972460244288244, 0.9627296953291138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.032105813875877395`], {
             RGBColor[
             0.859793389819062, 0.4562363539016795, 0.20472050649757392`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.032105813875877395`], {
             RGBColor[
             0.4418661436524164, 0.557143977618759, 0.949376297840011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.032105813875877395`], {
             RGBColor[
             0.9881146823444901, 0.9893531299577847, 0.8466340019753072]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.032105813875877395`], {
             RGBColor[
             0.9902426176396886, 0.9902330858877919, 0.8113686072138527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.032105813875877395`], {
             RGBColor[
             0.9709187056389151, 0.9778317987985278, 0.9341112251237087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.032105813875877395`], {
             RGBColor[
             0.985845646212203, 0.9884148252055153, 0.8842378027645792]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.032105813875877395`], {
             RGBColor[
             0.97918179300571, 0.9839943958271196, 0.9201239735700676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.032105813875877395`], {
             RGBColor[
             0.8096206802513948, 0.8512010958482423, 0.9816590811381882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.032105813875877395`], {
             RGBColor[
             0.9414414820544251, 0.9558477337137389, 0.984008475761047]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.032105813875877395`], {
             RGBColor[
             0.6332753318106321, 0.7131604689492826, 0.9642729003655599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.032105813875877395`], {
             RGBColor[
             0.660153046877239, 0.7344358446602642, 0.9667615442979008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.032105813875877395`], {
             RGBColor[
             0.40590385461152273`, 0.5259952503687401, 0.9470848125825287]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.032105813875877395`], {
             RGBColor[
             0.9836814150367665, 0.9566157225123636, 0.3911058082343744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.032105813875877395`], {
             RGBColor[
             0.7629604253814414, 0.8147497501127632, 0.9770084229976244]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.032105813875877395`], {
             RGBColor[
             0.9684731892793204, 0.9760079367017075, 0.9382508464276845]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.032105813875877395`], {
             RGBColor[
             0.9069172153380773, 0.668664807354358, 0.24396161040848696`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.032105813875877395`], {
             RGBColor[
             0.5930154151230221, 0.6804756548937028, 0.9611034922469771]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.032105813875877395`], {
             RGBColor[
             0.690629475369693, 0.7582442622280048, 0.9697991498716118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.032105813875877395`], {
             RGBColor[
             0.654598706189084, 0.7300967515001249, 0.9662079395263704]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.032105813875877395`], {
             RGBColor[
             0.9003284516687509, 0.9233614848686196, 0.9903553255245042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.032105813875877395`], {
             RGBColor[
             0.8477486806111797, 0.8814358026671765, 0.9853402200225173]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.032105813875877395`], {
             RGBColor[
             0.7032471876367785, 0.768101314949217, 0.9710567655111697]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.032105813875877395`], {
             RGBColor[
             0.9915570470202344, 0.9907766362159418, 0.7895851107440143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.032105813875877395`], {
             RGBColor[
             0.9813517134831237, 0.985612718966256, 0.9164508642077064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.032105813875877395`], {
             RGBColor[
             0.9542245866582464, 0.9653813521968561, 0.9623700140344211]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.032105813875877395`], {
             RGBColor[
             0.9904220855493537, 0.9903073004805534, 0.8083943595026393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.032105813875877395`], {
             RGBColor[
             0.9404126837890086, 0.9550804576518938, 0.9857499628708358]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.032105813875877395`], {
             RGBColor[
             0.9905230264617029, 0.9903490421418728, 0.8067215073583075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.032105813875877395`], {
             RGBColor[
             0.7998330873347723, 0.8435549538733155, 0.9806835453465155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.032105813875877395`], {
             RGBColor[
             0.9625600196887953, 0.9715979045030205, 0.9482603001428153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.032105813875877395`], {
             RGBColor[
             0.9883790193525103, 0.9894624401037523, 0.8422532536701659]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.032105813875877395`], {
             RGBColor[
             0.9766100437712765, 0.9820763894589319, 0.9244772742043387]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.032105813875877395`], {
             RGBColor[
             0.8203588521220603, 0.15749263548184916`, 0.16712896582510686`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.032105813875877395`], {
             RGBColor[
             0.2522743523564202, 0.3824867178173366, 0.9376780232090142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.032105813875877395`], {
             RGBColor[
             0.9937428794829753, 0.989024976843039, 0.5603292300726643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.032105813875877395`], {
             RGBColor[
             0.9861758061154947, 0.9885513548102488, 0.8787661987405977]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.032105813875877395`], {
             RGBColor[
             0.94701870472402, 0.9600072172488588, 0.9745676925540611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.032105813875877395`], {
             RGBColor[
             0.8412321534551215, 0.8762397007993531, 0.9847186678450001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.032105813875877395`], {
             RGBColor[
             0.9873164862084638, 0.9890230553428327, 0.8598621776146472]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.032105813875877395`], {
             RGBColor[
             0.8365864049561007, 0.8725353070517176, 0.9842755522058547]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.032105813875877395`], {
             RGBColor[
             0.9642777316729421, 0.9728789712883019, 0.9453526618046909]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.032105813875877395`], {
             RGBColor[
             0.979815670246321, 0.9844671404352885, 0.9190509847433752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.032105813875877395`], {
             RGBColor[
             0.9803313179394919, 0.9848517096405599, 0.9181781277012941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.032105813875877395`], {
             RGBColor[
             0.7157083217704143, 0.7778360476425404, 0.9722987749056913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.032105813875877395`], {
             RGBColor[
             0.9843763134513034, 0.9878072183487536, 0.9085884491239797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.032105813875877395`], {
             RGBColor[
             0.9545445611402682, 0.9656199886416378, 0.9618283806990687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.032105813875877395`], {
             RGBColor[
             0.9816228401813385, 0.9858149248138555, 0.9159919174287967]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.032105813875877395`], {
             RGBColor[
             0.895122120210653, 0.9192100974860349, 0.9898587409822839]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.032105813875877395`], {
             RGBColor[
             0.9910587871669104, 0.9815013309966897, 0.4197655058601559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.032105813875877395`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.032105813875877395`], {
             RGBColor[
             0.9859028956958801, 0.9884384993382602, 0.8832890306631379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.032105813875877395`], {
             RGBColor[
             0.7029347548581498, 0.7678572400879752, 0.9710256251316464]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.032105813875877395`], {
             RGBColor[
             0.9932104086404812, 0.9878860755520045, 0.5023730648963034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.032105813875877395`], {
             RGBColor[
             0.8646402728148859, 0.8949046997803559, 0.9869513551662091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.032105813875877395`], {
             RGBColor[
             0.6839910176277708, 0.7530582485858677, 0.9691374904438117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.032105813875877395`], {
             RGBColor[
             0.9941567194738415, 0.9899101387378605, 0.6053731591540727]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.032105813875877395`], {
             RGBColor[
             0.6670195842991749, 0.7398000358818979, 0.9674459365766789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.032105813875877395`], {
             RGBColor[
             0.9894897727500832, 0.9899217651787089, 0.8238451953347343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.032105813875877395`], {
             RGBColor[
             0.26265077169382917`, 0.3933929924439381, 0.9382689449397429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.032105813875877395`], {
             RGBColor[
             0.8365864049561007, 0.8725353070517176, 0.9842755522058547]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.032105813875877395`], {
             RGBColor[
             0.9791295138791556, 0.9839554061401345, 0.9202124684947441]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.032105813875877395`], {
             RGBColor[
             0.9845230632192228, 0.9878679031490853, 0.9061564256933312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.032105813875877395`], {
             RGBColor[
             0.7157083217704143, 0.7778360476425404, 0.9722987749056913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.032105813875877395`], {
             RGBColor[
             0.9943001999814818, 0.9902170290355983, 0.620990126951658]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.032105813875877395`], {
             RGBColor[
             0.882927864495217, 0.9094867289827998, 0.988695641986205]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.032105813875877395`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.032105813875877395`], {
             RGBColor[
             0.9055983112756845, 0.92756352787266, 0.9908579694382728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.032105813875877395`], {
             RGBColor[
             0.6441209309495708, 0.7219114338489758, 0.9651636128108723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.032105813875877395`], {
             RGBColor[
             0.8265945278796185, 0.8645680554932086, 0.9833225180504459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.032105813875877395`], {
             RGBColor[
             0.9367525052609843, 0.9523507024986856, 0.9919456903913315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.032105813875877395`], {
             RGBColor[
             0.9294460884817325, 0.9465790980860952, 0.9931325917173476]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.032105813875877395`], {
             RGBColor[
             0.9708118929918796, 0.9777521381012584, 0.9342920310739399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.032105813875877395`], {
             RGBColor[
             0.6579427799559914, 0.7327091673427348, 0.9665412455473096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.032105813875877395`], {
             RGBColor[
             0.8161944366879319, 0.8563365643388644, 0.9823142917445357]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.032105813875877395`], {
             RGBColor[
             0.9642761717825492, 0.972877807924601, 0.9453553022922414]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.032105813875877395`], {
             RGBColor[
             0.5433134973077871, 0.6401253989654134, 0.957190775212438]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.032105813875877395`], {
             RGBColor[
             0.8997636318682448, 0.922911112891321, 0.9903014525077113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.032105813875877395`], {
             RGBColor[
             0.9849999959524957, 0.9880651270909059, 0.8982524160406501]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1FO4EAYYBuBzsm2dTrZdW7WsZbtVy3bLtWxr2bat5WVjyzZXrfc8u3i/
//a7+f7gJu2rtAsMCAjIJEJuKEIThrCEIzwRiEgkIhOFqEQjOjGISSxiE4e4
xCM+CUhIIhKThKQkI4jkBJOClKQiNWlISzrSk4GMIX3JTBayko3s5CAnuchN
HvKSj/wUoCCF+IEfKUwRivITxShOCUpSitKUoSzlKE8FfqYilahMFapSjerU
oCa1qE0d6lKP+jSgIY1oTBN+oSnNaM6vtKAlrWhNG9rSjvZ0oCOd6EwXutKN
7vSgJ73ozW/0oS/96M8ABjKIwQzhd4YyjOGMYCSjGM0YxjKO8UxgIpOYzBSm
Mo3pzGAms5jNH8xhLvOYzwIWsojFLGEpy1jOClayitWsYS3rWM8GNrKJzWxh
K9vYzg52sovd7GEv+9jPAQ5yiMMc4U+OcozjnOAkpzjNX5zhLOc4zwUuconL
XOEq17jODW5yi9v8zT/c4S73uM8DHvKIxzzhKc94zgte8orXvOEt73jPBz7y
ic/8yxe+8o3/CBl/IKEITRjCEo7wRCAikYhMFKISjejEICaxiE0c4hKP+CQg
IYlITBKSkowgkhNMClKSitSkIS3pSE8GMgb+/6++Az6VhWw=
          "], {Null, CompressedData["
1:eJxN2guYllWBB/D3qyhJJoMEhjQEkUhkrd1Es1FL08DywkWybEVNDSyNClNB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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[72, 227] -> 
             RGBColor[
              0.8910599718883171, 0.5386508737923311, 0.22830235227691478`], 
             UndirectedEdge[132, 236] -> 
             RGBColor[
              0.21416362323535532`, 0.3424299251513089, 0.9355076735653408], 
             UndirectedEdge[187, 193] -> 
             RGBColor[
              0.25215196023065367`, 0.38235807593304705`, 0.9376710531585147],
              UndirectedEdge[196, 225] -> 
             RGBColor[
              0.21532817540767707`, 0.3436539433212913, 0.935573993088754], 
             UndirectedEdge[39, 166] -> 
             RGBColor[
              0.19390930592620187`, 0.3211413534614994, 0.9343542201581618], 
             UndirectedEdge[7, 216] -> 
             RGBColor[
              0.9023917020151102, 0.7200221295355724, 0.5997896268007754], 
             UndirectedEdge[92, 281] -> 
             RGBColor[
              0.9050081321346448, 0.6135030027694477, 0.5495966137001128], 
             UndirectedEdge[99, 229] -> 
             RGBColor[
              0.20669327315473038`, 0.33457811356902034`, 0.9350822481796419],
              UndirectedEdge[187, 296] -> 
             RGBColor[
              0.20597365560918635`, 0.3338217499022659, 0.9350412670250019], 
             UndirectedEdge[100, 244] -> 
             RGBColor[
              0.18508330510196136`, 0.31186466699444937`, 0.9338515924681194],
              UndirectedEdge[232, 245] -> 
             RGBColor[
              0.206575126823306, 0.3344539342837832, 0.9350755199208491], 
             UndirectedEdge[6, 52] -> 
             RGBColor[
              0.20466403550360635`, 0.3324452561365908, 0.9349666860973984], 
             UndirectedEdge[113, 160] -> 
             RGBColor[
              0.23169850636271255`, 0.3608601990939647, 0.936506259218909], 
             UndirectedEdge[176, 288] -> 
             RGBColor[
              0.20152898742648828`, 0.32915012183401104`, 0.9347881497472945],
              UndirectedEdge[187, 228] -> 
             RGBColor[
              0.32549861800497937`, 0.4485853630705261, 0.9422458467242234], 
             UndirectedEdge[61, 268] -> 
             RGBColor[
              0.24115438507843467`, 0.37079892716152685`, 0.9370447575230503],
              UndirectedEdge[51, 101] -> 
             RGBColor[
              0.7293123816710212, 0.7884636426315792, 0.9736547004594159], 
             UndirectedEdge[207, 214] -> 
             RGBColor[
              0.19305906954872248`, 0.3202477011206687, 0.9343058004542764], 
             UndirectedEdge[17, 162] -> 
             RGBColor[
              0.8475057087773203, 0.8795582824939998, 0.8820715972741542], 
             UndirectedEdge[20, 279] -> 
             RGBColor[
              0.22783544818024304`, 0.35679988001215385`, 0.9362862637702997],
              UndirectedEdge[51, 197] -> 
             RGBColor[
              0.8988192263028636, 0.9205652040419037, 0.9289214218265444], 
             UndirectedEdge[86, 94] -> 
             RGBColor[
              0.6955329406462065, 0.7613368008112785, 0.9707925147289977], 
             UndirectedEdge[55, 114] -> 
             RGBColor[
              0.22063449464495144`, 0.3492312212797382, 0.9358761801193209], 
             UndirectedEdge[13, 270] -> 
             RGBColor[
              0.27306394266259, 0.4020687514269927, 0.9389450440967648], 
             UndirectedEdge[151, 220] -> 
             RGBColor[
              0.46545874896093703`, 0.5736549196510825, 0.9519637517959829], 
             UndirectedEdge[117, 225] -> 
             RGBColor[
              0.20655322702626136`, 0.33443091620856197`, 0.9350742727598051],
              UndirectedEdge[13, 277] -> 
             RGBColor[
              0.6631499633187324, 0.7252798242769541, 0.7115734484509257], 
             UndirectedEdge[81, 237] -> 
             RGBColor[
              0.857269778961983, 0.39235407740723033`, 0.20056198469547004`], 
             UndirectedEdge[172, 174] -> 
             RGBColor[
              0.21189442021644855`, 0.34004484890265657`, 0.9353784458103991],
              UndirectedEdge[128, 197] -> 
             RGBColor[
              0.9156409832962333, 0.6675280137453463, 0.53334242652665], 
             UndirectedEdge[44, 71] -> 
             RGBColor[
              0.26976807981775686`, 0.40018277558695564`, 0.9386995645005083],
              UndirectedEdge[70, 122] -> 
             RGBColor[
              0.19740509453050553`, 0.32481564893042175`, 0.9345533001476212],
              UndirectedEdge[42, 293] -> 
             RGBColor[
              0.8686817504503115, 0.4638809195993508, 0.210856119307727], 
             UndirectedEdge[154, 181] -> 
             RGBColor[
              0.7417957890267707, 0.7840980478369171, 0.6774116520475943], 
             UndirectedEdge[42, 216] -> 
             RGBColor[
              0.8520342261383788, 0.3882883998269512, 0.19696501695368862`], 
             UndirectedEdge[125, 130] -> 
             RGBColor[
              0.8734988271236623, 0.4797808744280881, 0.21461427312304276`], 
             UndirectedEdge[173, 263] -> 
             RGBColor[
              0.20558810816091344`, 0.33341651508901093`, 0.935019310668189], 
             UndirectedEdge[112, 132] -> 
             RGBColor[
              0.1930638232066118, 0.32025269751650964`, 0.9343060711680607], 
             UndirectedEdge[208, 279] -> 
             RGBColor[
              0.21299163292133522`, 0.34119808902279597`, 0.9354409304507616],
              UndirectedEdge[271, 295] -> 
             RGBColor[
              0.20977901412683497`, 0.3378214229779799, 0.9352579765630585], 
             UndirectedEdge[193, 264] -> 
             RGBColor[
              0.28788684943506876`, 0.4199177102097248, 0.939706102233675], 
             UndirectedEdge[16, 39] -> 
             RGBColor[
              0.22425729902189784`, 0.35303901837897317`, 0.9360824934691292],
              UndirectedEdge[168, 282] -> 
             RGBColor[
              0.42052178364044757`, 0.5386565657751188, 0.9480162540941248], 
             UndirectedEdge[92, 243] -> 
             RGBColor[
              0.9094860988652742, 0.6163067889114571, 0.5180190463996183], 
             UndirectedEdge[71, 280] -> 
             RGBColor[
              0.2426648792276659, 0.37238655228322937`, 0.9371307779302732], 
             UndirectedEdge[69, 118] -> 
             RGBColor[
              0.19814492935345804`, 0.3255932622375819, 0.9345954326463008], 
             UndirectedEdge[175, 253] -> 
             RGBColor[
              0.18722926764301806`, 0.3141202096869836, 0.9339738018601655], 
             UndirectedEdge[137, 179] -> 
             RGBColor[
              0.3921454633437752, 0.5078279411583735, 0.9468889147894293], 
             UndirectedEdge[134, 221] -> 
             RGBColor[
              0.21549733286296777`, 0.343831738532004, 0.9355836263555868], 
             UndirectedEdge[91, 163] -> 
             RGBColor[
              0.5556545906660699, 0.6501444545135875, 0.9581623112885165], 
             UndirectedEdge[160, 232] -> 
             RGBColor[
              0.19183608079529113`, 0.31896226239884673`, 0.9342361530540182],
              UndirectedEdge[135, 263] -> 
             RGBColor[
              0.21148289076359805`, 0.33961230535523634`, 0.9353550098168626],
              UndirectedEdge[160, 297] -> 
             RGBColor[
              0.1938787777952211, 0.3211092664602433, 0.9343524816262648], 
             UndirectedEdge[179, 274] -> 
             RGBColor[
              0.4929016619374462, 0.5991987999844676, 0.9532221708674471], 
             UndirectedEdge[209, 259] -> 
             RGBColor[
              0.18280847530695815`, 0.30947367664736153`, 0.9337220442766032],
              UndirectedEdge[14, 173] -> 
             RGBColor[
              0.1907403974209291, 0.31781062970205387`, 0.9341737555067666], 
             UndirectedEdge[260, 267] -> 
             RGBColor[
              0.22718681650953165`, 0.35611812700061296`, 0.9362493251562173],
              UndirectedEdge[203, 216] -> 
             RGBColor[
              0.9017944048582103, 0.7195766662939407, 0.600800695087359], 
             UndirectedEdge[37, 279] -> 
             RGBColor[
              0.23161750381713786`, 0.36077506028270767`, 0.936501646243771], 
             UndirectedEdge[192, 220] -> 
             RGBColor[
              0.3318533670341157, 0.4618564399149144, 0.9423663809943715], 
             UndirectedEdge[60, 225] -> 
             RGBColor[
              0.25743202099321577`, 0.38790775456968785`, 0.9379717448077927],
              UndirectedEdge[177, 226] -> 
             RGBColor[
              0.6391144281004404, 0.7063980774045702, 0.908678535889838], 
             UndirectedEdge[91, 273] -> 
             RGBColor[
              0.3645444727684772, 0.4827165664417553, 0.9449621664859775], 
             UndirectedEdge[52, 273] -> 
             RGBColor[
              0.2188316043007933, 0.34733626921817795`, 0.9357735081813584], 
             UndirectedEdge[21, 114] -> 
             RGBColor[
              0.21635493982133241`, 0.34473313782066695`, 0.9356324658031498],
              UndirectedEdge[7, 202] -> 
             RGBColor[
              0.9024452109054028, 0.7202651009090716, 0.5998342759304583], 
             UndirectedEdge[94, 293] -> 
             RGBColor[
              0.8483237902546403, 0.739482330174071, 0.6092293420609014], 
             UndirectedEdge[132, 133] -> 
             RGBColor[
              0.19109281456444907`, 0.3181810424644308, 0.9341938251417357], 
             UndirectedEdge[13, 93] -> 
             RGBColor[
              0.2872094013725457, 0.41693652540503934`, 0.939750607043966], 
             UndirectedEdge[141, 178] -> 
             RGBColor[
              0.27642955220691934`, 0.4078753643883386, 0.9390536261060842], 
             UndirectedEdge[245, 264] -> 
             RGBColor[
              0.26072622472382, 0.3913701715551329, 0.938159344836913], 
             UndirectedEdge[5, 83] -> 
             RGBColor[
              0.9087826368179345, 0.636355140842231, 0.2670511550343114], 
             UndirectedEdge[210, 226] -> 
             RGBColor[
              0.7289680937933078, 0.7852771577024377, 0.9144848957128108], 
             UndirectedEdge[91, 298] -> 
             RGBColor[
              0.3751482927558811, 0.4938618535695355, 0.9455660383473143], 
             UndirectedEdge[126, 192] -> 
             RGBColor[
              0.2770528278061131, 0.40650831596386994`, 0.939163161568517], 
             UndirectedEdge[127, 156] -> 
             RGBColor[
              0.3716633849526351, 0.49633787652625627`, 0.9449030401335229], 
             UndirectedEdge[36, 268] -> 
             RGBColor[
              0.19319132437376368`, 0.32038670932722724`, 0.934313332170909], 
             UndirectedEdge[25, 221] -> 
             RGBColor[
              0.1886556188584439, 0.3156193952502866, 0.9340550304517865], 
             UndirectedEdge[69, 249] -> 
             RGBColor[
              0.20751277813074143`, 0.3354394652584245, 0.9351289177756767], 
             UndirectedEdge[22, 161] -> 
             RGBColor[
              0.1950980417525622, 0.32239079018520866`, 0.934421916904896], 
             UndirectedEdge[96, 112] -> 
             RGBColor[
              0.1950909003644823, 0.32238328413354655`, 0.9344215102134096], 
             UndirectedEdge[219, 250] -> 
             RGBColor[
              0.1834940050025886, 0.3101942118225623, 0.933761084178619], 
             UndirectedEdge[41, 219] -> 
             RGBColor[
              0.18646440411145038`, 0.3133162896201571, 0.933930244013557], 
             UndirectedEdge[202, 237] -> 
             RGBColor[
              0.8458226996057612, 0.34037556358393634`, 0.1910102610870475], 
             UndirectedEdge[91, 235] -> 
             RGBColor[
              0.44932632055040805`, 0.5626052939537676, 0.9501280434357534], 
             UndirectedEdge[69, 263] -> 
             RGBColor[
              0.2087290677202517, 0.3367178627342138, 0.9351981836684602], 
             UndirectedEdge[12, 239] -> 
             RGBColor[
              0.3335981101513706, 0.4567875043441526, 0.9427184858018454], 
             UndirectedEdge[122, 266] -> 
             RGBColor[
              0.19159505471631844`, 0.31870892870791034`, 0.9342224269753869],
              UndirectedEdge[206, 254] -> 
             RGBColor[
              0.27060222090313846`, 0.400822588016517, 0.9387557425033809], 
             UndirectedEdge[137, 270] -> 
             RGBColor[
              0.23718665422901314`, 0.36662859047011903`, 0.9368188011209075],
              UndirectedEdge[25, 58] -> 
             RGBColor[
              0.19112827338567, 0.31821831193375316`, 0.9341958444691476], 
             UndirectedEdge[107, 156] -> 
             RGBColor[
              0.4014834091317521, 0.5221664826722128, 0.9468031457054042], 
             UndirectedEdge[136, 194] -> 
             RGBColor[
              0.539310518839214, 0.6345587760249104, 0.957788184762517], 
             UndirectedEdge[45, 281] -> 
             RGBColor[
              0.6391981620742301, 0.7080190375817033, 0.9308676637061029], 
             UndirectedEdge[137, 147] -> 
             RGBColor[
              0.23746595794531072`, 0.3669221563848262, 0.9368347070543579], 
             UndirectedEdge[164, 187] -> 
             RGBColor[
              0.2033506574299822, 0.3310648125082323, 0.9348918911590742], 
             UndirectedEdge[199, 229] -> 
             RGBColor[
              0.20805355497894237`, 0.33600785601311617`, 0.9351597142171741],
              UndirectedEdge[191, 271] -> 
             RGBColor[
              0.22500596477055484`, 0.35382591354896176`, 0.9361251288759636],
              UndirectedEdge[153, 222] -> 
             RGBColor[
              0.2212473690290584, 0.3498753911159149, 0.9359110824088295], 
             UndirectedEdge[158, 186] -> 
             RGBColor[
              0.19303082310645578`, 0.3202180123189185, 0.9343041918611762], 
             UndirectedEdge[16, 192] -> 
             RGBColor[
              0.28870383608450384`, 0.4187542643810497, 0.9398266692538492], 
             UndirectedEdge[75, 143] -> 
             RGBColor[
              0.31991196504772945`, 0.4513422193006194, 0.941611753099148], 
             UndirectedEdge[204, 226] -> 
             RGBColor[
              0.734932739386402, 0.7901195256991334, 0.9149544544631159], 
             UndirectedEdge[137, 191] -> 
             RGBColor[
              0.24445543716588297`, 0.3742685422042259, 0.9372327475559615], 
             UndirectedEdge[197, 198] -> 
             RGBColor[
              0.9754663865596167, 0.9808663065126991, 0.9104194926535587], 
             UndirectedEdge[80, 156] -> 
             RGBColor[
              0.6866499660786538, 0.7281441949934098, 0.6592663633827371], 
             UndirectedEdge[103, 159] -> 
             RGBColor[
              0.35628521918114736`, 0.4813996069512451, 0.9439824173184419], 
             UndirectedEdge[28, 288] -> 
             RGBColor[
              0.19616769103516415`, 0.32351505940090497`, 0.9344828318491358],
              UndirectedEdge[118, 263] -> 
             RGBColor[
              0.19930513416780576`, 0.32681271105869525`, 0.9346615045941087],
              UndirectedEdge[68, 83] -> 
             RGBColor[
              0.8617045963739112, 0.6317374119212176, 0.5901643374072268], 
             UndirectedEdge[64, 90] -> 
             RGBColor[
              0.22549030939770529`, 0.3543349904613199, 0.936152711585956], 
             UndirectedEdge[213, 263] -> 
             RGBColor[
              0.2061321686296245, 0.3339883571370523, 0.9350502941070169], 
             UndirectedEdge[52, 53] -> 
             RGBColor[
              0.2073052253779457, 0.3352213141556316, 0.9351170979534518], 
             UndirectedEdge[245, 297] -> 
             RGBColor[
              0.20861782382323596`, 0.3366009383451798, 0.9351918484930957], 
             UndirectedEdge[189, 267] -> 
             RGBColor[
              0.20602096440657885`, 0.33387147444787646`, 0.9350439611910263],
              UndirectedEdge[145, 203] -> 
             RGBColor[
              0.9010144773435402, 0.923871728137574, 0.9891457475385399], 
             UndirectedEdge[136, 279] -> 
             RGBColor[
              0.3146411108912604, 0.44028382744269734`, 0.9415136410409652], 
             UndirectedEdge[80, 256] -> 
             RGBColor[
              0.898368256371338, 0.5394933847920658, 0.2684881883897252], 
             UndirectedEdge[40, 130] -> 
             RGBColor[
              0.8005184128051482, 0.7225949328330918, 0.608776500228449], 
             UndirectedEdge[83, 101] -> 
             RGBColor[
              0.7469403042896439, 0.5416229945947444, 0.5788476902726976], 
             UndirectedEdge[83, 194] -> 
             RGBColor[
              0.7662790641438353, 0.5567305807728573, 0.5807751971239775], 
             UndirectedEdge[149, 197] -> 
             RGBColor[
              0.9409227595816787, 0.803504489870005, 0.5552674312684278], 
             UndirectedEdge[23, 44] -> 
             RGBColor[
              0.6527829845870825, 0.7190887957178285, 0.883793610021852], 
             UndirectedEdge[97, 284] -> 
             RGBColor[
              0.3449079379891919, 0.4668961630433738, 0.9434276902262162], 
             UndirectedEdge[135, 276] -> 
             RGBColor[
              0.22722517815635135`, 0.3561584475236893, 0.9362515097952526], 
             UndirectedEdge[142, 150] -> 
             RGBColor[
              0.8686725031653917, 0.4508599338020208, 0.21032865402022227`], 
             UndirectedEdge[46, 214] -> 
             RGBColor[
              0.20276955741382008`, 0.3304540395473769, 0.9348587983728143], 
             UndirectedEdge[5, 243] -> 
             RGBColor[
              0.9792150980469998, 0.9514729807028455, 0.600039087887734], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.17910006852395627`, 0.30557590599185624`, 0.9335108559964074],
              UndirectedEdge[198, 243] -> 
             RGBColor[
              0.9760042846861029, 0.9810887412113525, 0.9015051286619535], 
             UndirectedEdge[13, 32] -> 
             RGBColor[
              0.6604824509868196, 0.7261357390166185, 0.898179624729629], 
             UndirectedEdge[86, 140] -> 
             RGBColor[
              0.7057480336302696, 0.4077728682153858, 0.5627064708792573], 
             UndirectedEdge[171, 275] -> 
             RGBColor[
              0.17966143058790973`, 0.3061659331134819, 0.9335428247354888], 
             UndirectedEdge[36, 250] -> 
             RGBColor[
              0.18199349180428678`, 0.3086170773131154, 0.9336756321717861], 
             UndirectedEdge[168, 203] -> 
             RGBColor[
              0.6687682561638781, 0.7369332784725033, 0.9690249189979729], 
             UndirectedEdge[17, 169] -> 
             RGBColor[
              0.654201051554568, 0.729209809683748, 0.9665623183284373], 
             UndirectedEdge[191, 246] -> 
             RGBColor[
              0.2059132617802264, 0.3337582721588391, 0.9350378276857872], 
             UndirectedEdge[17, 178] -> 
             RGBColor[
              0.4813372368134904, 0.5789969861106385, 0.9545799540531321], 
             UndirectedEdge[9, 132] -> 
             RGBColor[
              0.19792820821317225`, 0.32536547457822756`, 0.9345830906979717],
              UndirectedEdge[11, 283] -> 
             RGBColor[
              0.41881779248479195`, 0.534778825033336, 0.9485064845740085], 
             UndirectedEdge[64, 69] -> 
             RGBColor[
              0.22143670136219934`, 0.3500743914024093, 0.9359218646051097], 
             UndirectedEdge[193, 288] -> 
             RGBColor[
              0.24421454187002306`, 0.3740153459746332, 0.9372190289252349], 
             UndirectedEdge[221, 288] -> 
             RGBColor[
              0.19753047223834988`, 0.324947428850772, 0.9345604402226031], 
             UndirectedEdge[65, 264] -> 
             RGBColor[
              0.33683666992223255`, 0.4650136831097602, 0.942726350900722], 
             UndirectedEdge[27, 151] -> 
             RGBColor[
              0.7838347809145911, 0.7971566134890326, 0.6494113635450639], 
             UndirectedEdge[201, 293] -> 
             RGBColor[
              0.872561429430702, 0.49370183232880244`, 0.21457130428081972`], 
             UndirectedEdge[43, 99] -> 
             RGBColor[
              0.21063039427602828`, 0.33871627749540134`, 0.9353064614030511],
              UndirectedEdge[77, 293] -> 
             RGBColor[0.6567707297143, 0.585264649646495, 0.5928277208084357],
              UndirectedEdge[61, 280] -> 
             RGBColor[
              0.2696360759953822, 0.40073499015874336`, 0.9386667476858847], 
             UndirectedEdge[20, 55] -> 
             RGBColor[
              0.21057054856025512`, 0.3386533758536862, 0.9353030532780715], 
             UndirectedEdge[208, 242] -> 
             RGBColor[
              0.18509931747274389`, 0.3118814970113848, 0.9338525043489474], 
             UndirectedEdge[29, 261] -> 
             RGBColor[
              0.21999581851421782`, 0.3485599321719316, 0.9358398084585123], 
             UndirectedEdge[12, 76] -> 
             RGBColor[
              0.3782689418854923, 0.5020592779365523, 0.9453239403802199], 
             UndirectedEdge[168, 276] -> 
             RGBColor[
              0.3208926338924916, 0.4461337879304579, 0.9418960475542608], 
             UndirectedEdge[148, 271] -> 
             RGBColor[
              0.23446623518977533`, 0.3637692575753508, 0.9366638772811222], 
             UndirectedEdge[131, 170] -> 
             RGBColor[
              0.21349214626363155`, 0.34172416027992825`, 0.9354694339451624],
              UndirectedEdge[141, 261] -> 
             RGBColor[
              0.269292107733182, 0.4003734577063236, 0.9386471592022079], 
             UndirectedEdge[129, 184] -> 
             RGBColor[
              0.19028873719925032`, 0.31733590617215746`, 0.9341480341253134],
              UndirectedEdge[111, 185] -> 
             RGBColor[
              0.5718800780485805, 0.6633170361205862, 0.9594396410911864], 
             UndirectedEdge[234, 239] -> 
             RGBColor[
              0.2158656276199601, 0.3442188396728392, 0.9356046001971543], 
             UndirectedEdge[103, 203] -> 
             RGBColor[
              0.679227364936692, 0.7459924328014227, 0.96969136416035], 
             UndirectedEdge[28, 160] -> 
             RGBColor[
              0.18961722538074013`, 0.31663010467459485`, 0.9341097925206621],
              UndirectedEdge[133, 170] -> 
             RGBColor[
              0.1914328920115927, 0.3185384854235343, 0.9342131920492509], 
             UndirectedEdge[87, 299] -> 
             RGBColor[
              0.9059209744031474, 0.5662238856558284, 0.33056015938178984`], 
             UndirectedEdge[5, 290] -> 
             RGBColor[
              0.9587118125308915, 0.8695626925266455, 0.3088146906826389], 
             UndirectedEdge[183, 253] -> 
             RGBColor[
              0.19229512745236005`, 0.31944474954066526`, 0.9342622950820396],
              UndirectedEdge[176, 245] -> 
             RGBColor[
              0.20971756780007914`, 0.3377568389926374, 0.9352544772856515], 
             UndirectedEdge[29, 190] -> 
             RGBColor[
              0.199834842245044, 0.32736946783330456`, 0.9346916706854744], 
             UndirectedEdge[159, 168] -> 
             RGBColor[
              0.3458261104083336, 0.4723404526223259, 0.943315972156065], 
             UndirectedEdge[202, 299] -> 
             RGBColor[
              0.8426323172090826, 0.3158528864485842, 0.18795514730096657`], 
             UndirectedEdge[65, 115] -> 
             RGBColor[
              0.3645960621661024, 0.4902165167425332, 0.9444527165749532], 
             UndirectedEdge[51, 142] -> 
             RGBColor[
              0.8206161663608685, 0.5418070513656623, 0.579062899024987], 
             UndirectedEdge[134, 187] -> 
             RGBColor[
              0.23476961577043198`, 0.36408812980106076`, 0.9366811543563793],
              UndirectedEdge[85, 239] -> 
             RGBColor[
              0.2348622905163943, 0.36418553683498534`, 0.936686432046062], 
             UndirectedEdge[120, 284] -> 
             RGBColor[
              0.26002401193692654`, 0.39063210139324567`, 0.9381193548575302],
              UndirectedEdge[31, 61] -> 
             RGBColor[
              0.3484538930002764, 0.47332381494877457`, 0.9435307438846312], 
             UndirectedEdge[217, 247] -> 
             RGBColor[
              0.19889732977739935`, 0.3263840827880864, 0.9346382807373675], 
             UndirectedEdge[66, 169] -> 
             RGBColor[
              0.4955403552880472, 0.5995224478502696, 0.9539323726469158], 
             UndirectedEdge[168, 293] -> 
             RGBColor[
              0.650085093471142, 0.5794738875625195, 0.5924017179788976], 
             UndirectedEdge[93, 105] -> 
             RGBColor[
              0.26248514686677915`, 0.39321891024948796`, 0.9382595128508624],
              UndirectedEdge[169, 193] -> 
             RGBColor[
              0.44215135474031986`, 0.5505814803014513, 0.9506292633518225], 
             UndirectedEdge[87, 216] -> 
             RGBColor[
              0.9298058839378985, 0.7371387261923006, 0.3529360529247516], 
             UndirectedEdge[81, 201] -> 
             RGBColor[
              0.8674144933652834, 0.47033079775319603`, 0.2102765746648868], 
             UndirectedEdge[63, 244] -> 
             RGBColor[
              0.18619322197801913`, 0.31303126000398057`, 0.9339148005922362],
              UndirectedEdge[32, 150] -> 
             RGBColor[
              0.9475427884309859, 0.8298940012964792, 0.5491295264859543], 
             UndirectedEdge[95, 282] -> 
             RGBColor[
              0.36409426757402563`, 0.48782276310977274`, 0.9444924758077534],
              UndirectedEdge[126, 239] -> 
             RGBColor[
              0.2305322261132995, 0.35963436460539283`, 0.9364398412840619], 
             UndirectedEdge[149, 150] -> 
             RGBColor[
              0.901456610665, 0.644502615181237, 0.23943789960535378`], 
             UndirectedEdge[16, 222] -> 
             RGBColor[
              0.23410797445122994`, 0.3633927028240968, 0.9366434748620613], 
             UndirectedEdge[192, 262] -> 
             RGBColor[
              0.31722856394081744`, 0.4487355619302395, 0.9414511103067129], 
             UndirectedEdge[214, 276] -> 
             RGBColor[
              0.22110211631188992`, 0.34972272130061666`, 0.9359028104814688],
              UndirectedEdge[48, 100] -> 
             RGBColor[
              0.18673636136840888`, 0.31360213394030656`, 0.9339457315770161],
              UndirectedEdge[105, 143] -> 
             RGBColor[
              0.29536739445361543`, 0.4277802373181654, 0.9401321082060067], 
             UndirectedEdge[268, 279] -> 
             RGBColor[
              0.22085812887375872`, 0.34946627503344374`, 0.9358889157578143],
              UndirectedEdge[24, 106] -> 
             RGBColor[
              0.892812310133672, 0.8140725087445938, 0.6221015838690171], 
             UndirectedEdge[33, 222] -> 
             RGBColor[
              0.210965999406103, 0.33906901976570414`, 0.9353255736187255], 
             UndirectedEdge[155, 291] -> 
             RGBColor[
              0.9265943306289632, 0.845047396157727, 0.6262279650717502], 
             UndirectedEdge[99, 233] -> 
             RGBColor[
              0.20053490529032286`, 0.32810527848045334`, 0.9347315382402527],
              UndirectedEdge[237, 269] -> 
             RGBColor[
              0.8991197807384712, 0.5574407348110937, 0.260947978617189], 
             UndirectedEdge[85, 135] -> 
             RGBColor[
              0.22261249954375167`, 0.3513102298411313, 0.9359888245721116], 
             UndirectedEdge[126, 248] -> 
             RGBColor[
              0.22272354417989754`, 0.3514269447943572, 0.9359951483998643], 
             UndirectedEdge[188, 261] -> 
             RGBColor[
              0.30030042916823396`, 0.42860875023970424`, 0.9405725470875715],
              UndirectedEdge[37, 177] -> 
             RGBColor[
              0.2592700003340752, 0.38983958739155206`, 0.9380764150122078], 
             UndirectedEdge[160, 180] -> 
             RGBColor[
              0.19532450559808373`, 0.32262881804548893`, 0.9344348136858753],
              UndirectedEdge[23, 194] -> 
             RGBColor[
              0.8376760987270953, 0.8722472965038359, 0.8977776532625734], 
             UndirectedEdge[51, 243] -> 
             RGBColor[
              0.8993571244293498, 0.920787638740557, 0.9200070578349391], 
             UndirectedEdge[108, 208] -> 
             RGBColor[
              0.2150010029643497, 0.34331006433942324`, 0.9355553611021148], 
             UndirectedEdge[179, 251] -> 
             RGBColor[
              0.4041820274938994, 0.5204791332423994, 0.9475743793112779], 
             UndirectedEdge[26, 224] -> 
             RGBColor[
              0.21888166411978893`, 0.3473888852619182, 0.9357763590139934], 
             UndirectedEdge[106, 291] -> 
             RGBColor[
              0.8943677152627585, 0.9186085554583606, 0.9897867851648885], 
             UndirectedEdge[48, 161] -> 
             RGBColor[
              0.19723226696141938`, 0.3246339961974114, 0.9345434578732372], 
             UndirectedEdge[227, 299] -> 
             RGBColor[
              0.885699193119303, 0.49744557906545395`, 0.22316886447357331`], 
             UndirectedEdge[162, 299] -> 
             RGBColor[
              0.9050210878776606, 0.5676926894870836, 0.4792897876815234], 
             UndirectedEdge[200, 227] -> 
             RGBColor[
              0.6591374011618665, 0.6706282245294286, 0.6126589597072597], 
             UndirectedEdge[202, 293] -> 
             RGBColor[
              0.8831647510557664, 0.562360246757456, 0.22422214319796666`], 
             UndirectedEdge[3, 155] -> 
             RGBColor[
              0.9402661035019293, 0.855471333191099, 0.6109745630706932], 
             UndirectedEdge[39, 234] -> 
             RGBColor[
              0.19793969225016772`, 0.3253775450292399, 0.9345837446968894], 
             UndirectedEdge[144, 176] -> 
             RGBColor[
              0.19591627409858087`, 0.32325080425980146`, 0.9344685140265354],
              UndirectedEdge[140, 162] -> 
             RGBColor[
              0.904333638485641, 0.5624086522177772, 0.47863148536736244`], 
             UndirectedEdge[123, 257] -> 
             RGBColor[
              0.19133948148967972`, 0.3184403050424346, 0.9342078724582165], 
             UndirectedEdge[121, 286] -> 
             RGBColor[
              0.22317009351070355`, 0.3518962964538972, 0.9360205787236432], 
             UndirectedEdge[176, 230] -> 
             RGBColor[
              0.19313907822011844`, 0.32033179530714856`, 0.9343103568297502],
              UndirectedEdge[39, 64] -> 
             RGBColor[
              0.2185143800083959, 0.3470028463736865, 0.9357554427271977], 
             UndirectedEdge[269, 277] -> 
             RGBColor[
              0.9830880426173179, 0.9543005010685027, 0.41547009014484526`], 
             UndirectedEdge[154, 203] -> 
             RGBColor[
              0.7172113529376909, 0.7776981044453534, 0.9724416173890855], 
             UndirectedEdge[107, 137] -> 
             RGBColor[
              0.33500472849332374`, 0.4602209338581902, 0.9427270090780024], 
             UndirectedEdge[192, 218] -> 
             RGBColor[
              0.6489034320102649, 0.7179182155893853, 0.9413556495465901], 
             UndirectedEdge[247, 270] -> 
             RGBColor[
              0.20529778048290723`, 0.33311136229158844`, 0.935002776936428], 
             UndirectedEdge[28, 240] -> 
             RGBColor[
              0.18200025991928498`, 0.3086241910311017, 0.9336760176059227], 
             UndirectedEdge[31, 194] -> 
             RGBColor[
              0.552827044743554, 0.6462661114029045, 0.958649445840947], 
             UndirectedEdge[58, 187] -> 
             RGBColor[
              0.20794054512620663`, 0.3358890754926524, 0.9351532784732439], 
             UndirectedEdge[8, 121] -> 
             RGBColor[
              0.21495883648631775`, 0.3432657446975026, 0.9355529597835706], 
             UndirectedEdge[62, 186] -> 
             RGBColor[
              0.19739650616034748`, 0.3248066220088515, 0.934552811052646], 
             UndirectedEdge[271, 289] -> 
             RGBColor[
              0.23303990394891333`, 0.36227009300658086`, 0.9365826498270231],
              UndirectedEdge[236, 294] -> 
             RGBColor[
              0.38374017735760657`, 0.49740352912178454`, 0.9465549709165739],
              UndirectedEdge[115, 211] -> 
             RGBColor[
              0.3112307319414529, 0.4404795631489132, 0.9411810111605179], 
             UndirectedEdge[43, 284] -> 
             RGBColor[
              0.23327215251581435`, 0.3625142009758035, 0.9365958760393271], 
             UndirectedEdge[87, 181] -> 
             RGBColor[
              0.9897210070316473, 0.9765905802662477, 0.448420390956374], 
             UndirectedEdge[77, 205] -> 
             RGBColor[
              0.3930712028278346, 0.5148802523815419, 0.9462671273583405], 
             UndirectedEdge[132, 267] -> 
             RGBColor[
              0.19655119281637518`, 0.32391814408837505`, 0.9345046717082358],
              UndirectedEdge[108, 280] -> 
             RGBColor[
              0.2513491898337207, 0.3815143133472875, 0.9376253365720018], 
             UndirectedEdge[40, 97] -> 
             RGBColor[
              0.5690459020341019, 0.6601769695084484, 0.9597409246828227], 
             UndirectedEdge[35, 262] -> 
             RGBColor[
              0.25511664496274467`, 0.3854741475583434, 0.9378398875681493], 
             UndirectedEdge[201, 216] -> 
             RGBColor[
              0.8559139051187693, 0.4181093125564028, 0.20068020192678135`], 
             UndirectedEdge[244, 279] -> 
             RGBColor[
              0.21308524932289044`, 0.3412964857964532, 0.9354462617663373], 
             UndirectedEdge[143, 163] -> 
             RGBColor[
              0.4640224729127619, 0.5716064552084593, 0.95205347173178], 
             UndirectedEdge[102, 165] -> 
             RGBColor[
              0.20499479718794766`, 0.3327929076383356, 0.9349855224860035], 
             UndirectedEdge[7, 282] -> 
             RGBColor[
              0.6894759164963487, 0.7547973275205713, 0.9692952652700408], 
             UndirectedEdge[10, 122] -> 
             RGBColor[
              0.1877216481680741, 0.3146377328375459, 0.9340018422026558], 
             UndirectedEdge[113, 193] -> 
             RGBColor[
              0.2735981771019762, 0.40489940963349313`, 0.9388923834825018], 
             UndirectedEdge[22, 100] -> 
             RGBColor[
              0.1846021361595517, 0.3113589279281038, 0.9338241906086748], 
             UndirectedEdge[116, 254] -> 
             RGBColor[
              0.30306682721859113`, 0.43494494762898417`, 0.9406045538059649],
              UndirectedEdge[174, 298] -> 
             RGBColor[
              0.24667128016472487`, 0.3765975336885693, 0.9373589365366997], 
             UndirectedEdge[159, 271] -> 
             RGBColor[
              0.2569380089981777, 0.38738851664073326`, 0.9379436115555007], 
             UndirectedEdge[11, 101] -> 
             RGBColor[
              0.589571415450858, 0.6776035417182125, 0.9608844110153827], 
             UndirectedEdge[148, 225] -> 
             RGBColor[
              0.23694694145511846`, 0.36637663714608804`, 0.9368051498330575],
              UndirectedEdge[239, 248] -> 
             RGBColor[
              0.22976740900447992`, 0.35883049333181793`, 0.9363962860811601],
              UndirectedEdge[22, 119] -> 
             RGBColor[
              0.18469650892406414`, 0.31145811968718523`, 0.933829564998002], 
             UndirectedEdge[38, 247] -> 
             RGBColor[
              0.19193794866685385`, 0.31906933199065524`, 0.9342419542786038],
              UndirectedEdge[157, 222] -> 
             RGBColor[
              0.20198183109515816`, 0.32962608924173, 0.9348139385243031], 
             UndirectedEdge[42, 203] -> 
             RGBColor[
              0.8873649131430477, 0.6213403105093347, 0.5874793203268023], 
             UndirectedEdge[155, 241] -> 
             RGBColor[
              0.9562190222247212, 0.8670479840915544, 0.569594959834627], 
             UndirectedEdge[103, 154] -> 
             RGBColor[
              0.45931362601150366`, 0.5710619602704519, 0.9508179830889629], 
             UndirectedEdge[88, 107] -> 
             RGBColor[
              0.3156668760979841, 0.43989562490003076`, 0.9416257469918767], 
             UndirectedEdge[58, 176] -> 
             RGBColor[
              0.19266677740688082`, 0.31983537720683475`, 0.9342834599971428],
              UndirectedEdge[48, 119] -> 
             RGBColor[
              0.1868307341329213, 0.31370132569938797`, 0.933951105966343], 
             UndirectedEdge[206, 219] -> 
             RGBColor[
              0.20337837440800324`, 0.33109394480949034`, 0.9348934695999689],
              UndirectedEdge[1, 125] -> 
             RGBColor[
              0.8269439386544566, 0.20810849617316574`, 0.17343485212532112`],
              UndirectedEdge[191, 278] -> 
             RGBColor[
              0.21400334724237668`, 0.34226146492060344`, 0.9354985460846478],
              UndirectedEdge[90, 118] -> 
             RGBColor[
              0.20219853738896398`, 0.32985386129649247`, 0.9348262796271471],
              UndirectedEdge[101, 283] -> 
             RGBColor[
              0.4765743997943146, 0.5815921216615045, 0.9531053393092228], 
             UndirectedEdge[5, 226] -> 
             RGBColor[
              0.978634912205556, 0.9512330589473125, 0.6096542687532867], 
             UndirectedEdge[3, 241] -> 
             RGBColor[
              0.9701712881509421, 0.9769533662972854, 0.9210009349471945], 
             UndirectedEdge[194, 241] -> 
             RGBColor[
              0.8360648746712487, 0.8715810139501738, 0.9244798055821426], 
             UndirectedEdge[139, 235] -> 
             RGBColor[
              0.42460849977243, 0.5421962738843169, 0.9482766560323135], 
             UndirectedEdge[40, 94] -> 
             RGBColor[
              0.7430612286953848, 0.7992043464221197, 0.9750250570405241], 
             UndirectedEdge[161, 177] -> 
             RGBColor[
              0.24681318446187503`, 0.3767466841021262, 0.9373670177764938], 
             UndirectedEdge[34, 295] -> 
             RGBColor[
              0.19030787854135572`, 0.3173560249363414, 0.9341491241964293], 
             UndirectedEdge[1, 281] -> 
             RGBColor[
              0.8985774900643843, 0.5640742698921016, 0.5434386235912599], 
             UndirectedEdge[191, 295] -> 
             RGBColor[
              0.21214976125282442`, 0.34031322852144436`, 0.9353929871046776],
              UndirectedEdge[144, 297] -> 
             RGBColor[
              0.19481653012173772`, 0.32209490361234383`, 0.9344058852339796],
              UndirectedEdge[141, 294] -> 
             RGBColor[
              0.41494859536709305`, 0.5302055551777425, 0.9483322441534972], 
             UndirectedEdge[80, 201] -> 
             RGBColor[
              0.9120862504146132, 0.6449358982719986, 0.2816245549778238], 
             UndirectedEdge[113, 115] -> 
             RGBColor[
              0.3096806718260522, 0.43885035168813935`, 0.9410927375300542], 
             UndirectedEdge[129, 253] -> 
             RGBColor[
              0.19046881652676248`, 0.3175251809630616, 0.9341582893766117], 
             UndirectedEdge[37, 108] -> 
             RGBColor[
              0.23362687386015235`, 0.362887035599335, 0.936616076895124], 
             UndirectedEdge[265, 276] -> 
             RGBColor[
              0.23204484364859856`, 0.36122422154048306`, 0.93652598261498], 
             UndirectedEdge[59, 194] -> 
             RGBColor[
              0.8355066141794747, 0.8713501588901851, 0.9337316266626792], 
             UndirectedEdge[103, 225] -> 
             RGBColor[
              0.3244631340928782, 0.4479525778867464, 0.9421701966492211], 
             UndirectedEdge[46, 265] -> 
             RGBColor[
              0.21371228475052867`, 0.3419555397872433, 0.9354819705063254], 
             UndirectedEdge[51, 149] -> 
             RGBColor[
              0.8534002738604769, 0.7354497327448786, 0.6081721446101185], 
             UndirectedEdge[52, 124] -> 
             RGBColor[
              0.1923287617954415, 0.3194801013677844, 0.9342642105081206], 
             UndirectedEdge[82, 258] -> 
             RGBColor[
              0.47680058453134755`, 0.5830547562597531, 0.9528035659599465], 
             UndirectedEdge[45, 132] -> 
             RGBColor[
              0.24841553022607393`, 0.3784308510948885, 0.9374582689973068], 
             UndirectedEdge[74, 287] -> 
             RGBColor[
              0.2244511741859948, 0.35324279346883447`, 0.936093534372912], 
             UndirectedEdge[128, 269] -> 
             RGBColor[
              0.9090525762339738, 0.6337885535682664, 0.2704596348011703], 
             UndirectedEdge[14, 249] -> 
             RGBColor[
              0.19382527220510481`, 0.3210530286925808, 0.9343494345620621], 
             UndirectedEdge[101, 198] -> 
             RGBColor[
              0.8059595419277743, 0.8487647451023745, 0.9551527712864303], 
             UndirectedEdge[164, 297] -> 
             RGBColor[
              0.18697714573381324`, 0.31385521357495705`, 0.9339594438904173],
              UndirectedEdge[68, 235] -> 
             RGBColor[
              0.6426752269533634, 0.7164421222894727, 0.967683202312762], 
             UndirectedEdge[108, 177] -> 
             RGBColor[
              0.2663285931328081, 0.3972586159636525, 0.9384783914298436], 
             UndirectedEdge[62, 276] -> 
             RGBColor[
              0.22152543341226616`, 0.3501676544129665, 0.9359269177640938], 
             UndirectedEdge[13, 107] -> 
             RGBColor[
              0.3708820169269006, 0.49566109481506393`, 0.9448532520538597], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.21391225518849333`, 0.3421657213964022, 0.9354933585269378], 
             UndirectedEdge[62, 135] -> 
             RGBColor[
              0.20737676424851148`, 0.33529650604442257`, 0.9351211719862982],
              UndirectedEdge[18, 35] -> 
             RGBColor[
              0.20318410319091706`, 0.3308897534428262, 0.9348824061415544], 
             UndirectedEdge[42, 202] -> 
             RGBColor[
              0.8520877350286713, 0.3885313712004504, 0.1970096660833716], 
             UndirectedEdge[121, 255] -> 
             RGBColor[
              0.295733658786952, 0.42287002848225363`, 0.9403468487457121], 
             UndirectedEdge[128, 281] -> 
             RGBColor[
              0.9117009146920902, 0.6649466623019902, 0.5560056298355394], 
             UndirectedEdge[82, 181] -> 
             RGBColor[
              0.7998668067519439, 0.8312427160957487, 0.681983215284067], 
             UndirectedEdge[136, 204] -> 
             RGBColor[
              0.4381119186941594, 0.553069802846105, 0.9493643283826801], 
             UndirectedEdge[118, 166] -> 
             RGBColor[
              0.18740769372755933`, 0.31430774681470364`, 0.9339839629617225],
              UndirectedEdge[39, 263] -> 
             RGBColor[
              0.2058067463664483, 0.333646317705491, 0.935031761790548], 
             UndirectedEdge[52, 84] -> 
             RGBColor[
              0.1931004885069918, 0.32029123507192336`, 0.9343081592026761], 
             UndirectedEdge[129, 165] -> 
             RGBColor[
              0.20344097121398075`, 0.33115973802143944`, 0.9348970343954657],
              UndirectedEdge[141, 236] -> 
             RGBColor[
              0.2626393533607303, 0.39338099105188706`, 0.9382682946825648], 
             UndirectedEdge[97, 178] -> 
             RGBColor[
              0.353934746876465, 0.4763839115166376, 0.9439417536383794], 
             UndirectedEdge[115, 227] -> 
             RGBColor[
              0.6522166119287909, 0.6646337847447196, 0.6122179731371418], 
             UndirectedEdge[256, 281] -> 
             RGBColor[
              0.8981948395566131, 0.5611330504108505, 0.5430721970328762], 
             UndirectedEdge[221, 297] -> 
             RGBColor[
              0.18909437890281156`, 0.31608055987591055`, 0.9340800171872259],
              UndirectedEdge[224, 262] -> 
             RGBColor[
              0.2562537795699573, 0.3866693481290222, 0.9379046457017901], 
             UndirectedEdge[73, 119] -> 
             RGBColor[
              0.18176019735719462`, 0.3083718700574992, 0.9336623463981524], 
             UndirectedEdge[3, 227] -> 
             RGBColor[
              0.9534614284413586, 0.9077863994945625, 0.6215918312510428], 
             UndirectedEdge[45, 188] -> 
             RGBColor[
              0.32789958178650086`, 0.45761720952884744`, 0.9421442779998944],
              UndirectedEdge[260, 300] -> 
             RGBColor[
              0.24190674150061214`, 0.37158970146338766`, 0.9370876031082818],
              UndirectedEdge[23, 291] -> 
             RGBColor[
              0.9581107393338224, 0.9671957118175754, 0.9095521846286824], 
             UndirectedEdge[142, 149] -> 
             RGBColor[
              0.8627196996396836, 0.42474633719376353`, 0.20540890846687038`],
              UndirectedEdge[81, 97] -> 
             RGBColor[
              0.6691615275279388, 0.5770839186847934, 0.5896504800872672], 
             UndirectedEdge[181, 201] -> 
             RGBColor[
              0.9158290282125181, 0.65756116663035, 0.29616453995840375`], 
             UndirectedEdge[56, 57] -> 
             RGBColor[
              0.18951617750640207`, 0.3165238969518603, 0.9341040379937053], 
             UndirectedEdge[197, 243] -> 
             RGBColor[
              0.9868796101505515, 0.9888423958656835, 0.8671023444932484], 
             UndirectedEdge[65, 200] -> 
             RGBColor[
              0.37151685139917806`, 0.49621095652724223`, 0.9448937031450712],
              UndirectedEdge[8, 173] -> 
             RGBColor[
              0.2028775855537629, 0.3305675839718365, 0.9348649504155706], 
             UndirectedEdge[53, 273] -> 
             RGBColor[
              0.2274037724911021, 0.35634616149304726`, 0.9362616804784101], 
             UndirectedEdge[26, 253] -> 
             RGBColor[
              0.21047277090696587`, 0.3385506053406179, 0.9352974849853658], 
             UndirectedEdge[114, 206] -> 
             RGBColor[
              0.2307773334017795, 0.35989198790628496`, 0.936453799781537], 
             UndirectedEdge[9, 45] -> 
             RGBColor[
              0.24944742731977937`, 0.3795154403664275, 0.9375170340102383], 
             UndirectedEdge[47, 190] -> 
             RGBColor[
              0.1942570496898653, 0.32150685420533776`, 0.9343740236510617], 
             UndirectedEdge[191, 282] -> 
             RGBColor[
              0.3340044293562811, 0.4561964353369906, 0.9427789040351794], 
             UndirectedEdge[59, 155] -> 
             RGBColor[
              0.9556607617329471, 0.8668171290315656, 0.5788467809151635], 
             UndirectedEdge[214, 265] -> 
             RGBColor[
              0.21177311264038245`, 0.33991734694886655`, 0.9353715375234006],
              UndirectedEdge[167, 282] -> 
             RGBColor[
              0.674157084988882, 0.6138860835498305, 0.5969373306942671], 
             UndirectedEdge[28, 221] -> 
             RGBColor[
              0.18483282648833058`, 0.31160139809026205`, 0.9338373280816231],
              UndirectedEdge[136, 197] -> 
             RGBColor[
              0.689478603616865, 0.751552751257122, 0.9111273992783655], 
             UndirectedEdge[121, 234] -> 
             RGBColor[
              0.20980230497718771`, 0.3378459031384259, 0.9352593029425303], 
             UndirectedEdge[141, 146] -> 
             RGBColor[
              0.24693839801171524`, 0.3768782914820059, 0.9373741485029203], 
             UndirectedEdge[32, 167] -> 
             RGBColor[
              0.947679092916505, 0.830434403160785, 0.5492392002744804], 
             UndirectedEdge[101, 136] -> 
             RGBColor[
              0.5199717589850226, 0.6194511898467974, 0.9558606779112371], 
             UndirectedEdge[91, 274] -> 
             RGBColor[
              0.4766026768727841, 0.5859665496480654, 0.9519390550580074], 
             UndirectedEdge[84, 295] -> 
             RGBColor[
              0.19219536521772562`, 0.31933989310677346`, 0.9342566137703623],
              UndirectedEdge[73, 122] -> 
             RGBColor[
              0.18385458485627515`, 0.31057320411086997`, 0.9337816186678564],
              UndirectedEdge[157, 248] -> 
             RGBColor[
              0.20224840910221648`, 0.3299062796291701, 0.9348291197474383], 
             UndirectedEdge[125, 167] -> 
             RGBColor[
              0.871438247578835, 0.47161136318027613`, 0.21295628245325632`], 
             UndirectedEdge[20, 208] -> 
             RGBColor[
              0.20416035452872197`, 0.331915855496769, 0.9349380022110079], 
             UndirectedEdge[77, 103] -> 
             RGBColor[
              0.41755616548084906`, 0.5360878963815774, 0.9478272875273883], 
             UndirectedEdge[46, 276] -> 
             RGBColor[
              0.22304128842203616`, 0.35176091413899346`, 0.9360132434643936],
              UndirectedEdge[3, 291] -> 
             RGBColor[
              0.940546596555184, 0.9549527783634579, 0.9776339401843177], 
             UndirectedEdge[79, 297] -> 
             RGBColor[
              0.1875669958551452, 0.3144751834511347, 0.9339930349822221], 
             UndirectedEdge[18, 262] -> 
             RGBColor[
              0.25190729178629806`, 0.38210091388515394`, 0.9376571196525632],
              UndirectedEdge[127, 225] -> 
             RGBColor[
              0.28821593818422175`, 0.41655707862770686`, 0.9398605573780583],
              UndirectedEdge[109, 292] -> 
             RGBColor[
              0.8832633694480486, 0.907223500639492, 0.873440789605417], 
             UndirectedEdge[267, 287] -> 
             RGBColor[
              0.2196035170740144, 0.34814759848492993`, 0.9358174674718507], 
             UndirectedEdge[218, 262] -> 
             RGBColor[
              0.6355147016275733, 0.7058679616598169, 0.9405191403190352], 
             UndirectedEdge[207, 225] -> 
             RGBColor[
              0.20644219198451136`, 0.33431421133965444`, 0.9350679494784392],
              UndirectedEdge[203, 299] -> 
             RGBColor[
              0.8779094953234592, 0.5486618257574685, 0.5784248015443972], 
             UndirectedEdge[142, 163] -> 
             RGBColor[
              0.7255429896746053, 0.4672102742569026, 0.5698090215965668], 
             UndirectedEdge[2, 54] -> 
             RGBColor[
              0.22131402237840694`, 0.34994544801214666`, 0.9359148782184701],
              UndirectedEdge[90, 195] -> 
             RGBColor[
              0.19970007804544365`, 0.3272278221149808, 0.934683996063673], 
             UndirectedEdge[88, 93] -> 
             RGBColor[
              0.23199426054362918`, 0.36117105549000617`, 0.9365231019819831],
              UndirectedEdge[77, 82] -> 
             RGBColor[
              0.5136111712070213, 0.6149382362843397, 0.9551491039925967], 
             UndirectedEdge[167, 168] -> 
             RGBColor[
              0.6540467218133117, 0.5964674977433942, 0.5956559161356156], 
             UndirectedEdge[18, 26] -> 
             RGBColor[
              0.21453517633612967`, 0.3428204510180499, 0.9355288329647664], 
             UndirectedEdge[129, 224] -> 
             RGBColor[
              0.19887770973958555`, 0.32636346088436186`, 0.9346371634052393],
              UndirectedEdge[38, 289] -> 
             RGBColor[
              0.21478203632197956`, 0.34307991651500525`, 0.935542891275764], 
             UndirectedEdge[31, 241] -> 
             RGBColor[
              0.7028863769460394, 0.7632151146504713, 0.9137909719699326], 
             UndirectedEdge[5, 197] -> 
             RGBColor[
              0.9786771999205136, 0.9512505460041922, 0.6089534518793391], 
             UndirectedEdge[59, 241] -> 
             RGBColor[
              0.9855659463819599, 0.9882991621377519, 0.8888731527916648], 
             UndirectedEdge[155, 226] -> 
             RGBColor[
              0.9562854870849291, 0.8670754690193194, 0.5684934650954372], 
             UndirectedEdge[15, 186] -> 
             RGBColor[
              0.22574603195372214`, 0.35460377108144014`, 0.9361672746072136],
              UndirectedEdge[198, 256] -> 
             RGBColor[
              0.8912595826963075, 0.5559607471998754, 0.554811777892692], 
             UndirectedEdge[72, 291] -> 
             RGBColor[
              0.8781451400021425, 0.5858172526612265, 0.5843444612101898], 
             UndirectedEdge[230, 297] -> 
             RGBColor[
              0.19203933424327527`, 0.319175894659691, 0.9342477280371944], 
             UndirectedEdge[138, 231] -> 
             RGBColor[
              0.23123426787294182`, 0.3603722550067954, 0.9364798215236958], 
             UndirectedEdge[54, 165] -> 
             RGBColor[
              0.2309155676527057, 0.3600372808685661, 0.936461672017628], 
             UndirectedEdge[103, 167] -> 
             RGBColor[
              0.6645058305861254, 0.6055266520723135, 0.5963223612979925], 
             UndirectedEdge[78, 131] -> 
             RGBColor[
              0.21176961520445978`, 0.33991367092196156`, 0.9353713383495988],
              UndirectedEdge[16, 239] -> 
             RGBColor[
              0.2421832343916902, 0.3718803130225725, 0.9371033489693941], 
             UndirectedEdge[12, 87] -> 
             RGBColor[
              0.7113840896935575, 0.7671448961592477, 0.7220908533867955], 
             UndirectedEdge[125, 281] -> 
             RGBColor[
              0.9068280234058514, 0.6274914845613823, 0.5513393436366936], 
             UndirectedEdge[148, 205] -> 
             RGBColor[
              0.3093284827197305, 0.43657270388582725`, 0.9411425228750159], 
             UndirectedEdge[103, 269] -> 
             RGBColor[
              0.6972472679550255, 0.7302486647196956, 0.6491594274470608], 
             UndirectedEdge[40, 169] -> 
             RGBColor[
              0.6469863029423364, 0.7235735932337524, 0.9658432196124291], 
             UndirectedEdge[38, 53] -> 
             RGBColor[
              0.2009984379794762, 0.32859248072642344`, 0.9347579357411648], 
             UndirectedEdge[118, 285] -> 
             RGBColor[
              0.19420033164892994`, 0.32144723994818314`, 0.9343707936425373],
              UndirectedEdge[74, 267] -> 
             RGBColor[
              0.2010537316252639, 0.328650597853966, 0.9347610846324927], 
             UndirectedEdge[3, 200] -> 
             RGBColor[
              0.659894342148658, 0.7282185404316961, 0.9534476666394777], 
             UndirectedEdge[124, 273] -> 
             RGBColor[
              0.2124273089085979, 0.3406049487052001, 0.9354087930330789], 
             UndirectedEdge[131, 182] -> 
             RGBColor[
              0.24187571808972635`, 0.3715570938915489, 0.9370858363709268], 
             UndirectedEdge[62, 207] -> 
             RGBColor[
              0.19348238664909873`, 0.3206926342330184, 0.9343299077369014], 
             UndirectedEdge[75, 262] -> 
             RGBColor[
              0.318384602518598, 0.4497368644421247, 0.9415247720626443], 
             UndirectedEdge[197, 283] -> 
             RGBColor[
              0.646081244426157, 0.713693683071829, 0.9083720606763512], 
             UndirectedEdge[246, 278] -> 
             RGBColor[
              0.1925398971260588, 0.3197020179870163, 0.9342762343528525], 
             UndirectedEdge[225, 265] -> 
             RGBColor[
              0.22515623507617133`, 0.35398385716785236`, 0.9361336865475633],
              UndirectedEdge[101, 204] -> 
             RGBColor[
              0.5654681824695174, 0.6580354513456885, 0.9589869162220399], 
             UndirectedEdge[87, 140] -> 
             RGBColor[
              0.9052335250111279, 0.560939848386522, 0.3299018570676289], 
             UndirectedEdge[57, 247] -> 
             RGBColor[
              0.18871603896391997`, 0.3156829006119979, 0.9340584712874099], 
             UndirectedEdge[40, 66] -> 
             RGBColor[
              0.5377876957046065, 0.6331026822689709, 0.9577491794160538], 
             UndirectedEdge[167, 293] -> 
             RGBColor[
              0.9037203948195764, 0.6547034053372311, 0.24132279457904], 
             UndirectedEdge[42, 140] -> 
             RGBColor[
              0.8274618672116081, 0.2120895220211726, 0.17393082109656596`], 
             UndirectedEdge[107, 150] -> 
             RGBColor[
              0.657942354371067, 0.5994193570949246, 0.595803153810185], 
             UndirectedEdge[91, 143] -> 
             RGBColor[
              0.39852667636969663`, 0.5184340170227889, 0.9468974027089019], 
             UndirectedEdge[91, 142] -> 
             RGBColor[
              0.6600471931315399, 0.4140378360712322, 0.5646529525736886], 
             UndirectedEdge[44, 283] -> 
             RGBColor[
              0.3110200455084933, 0.44354120705361005`, 0.9410488029197814], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.19626308316666907`, 0.323615322579327, 0.9344882642899051], 
             UndirectedEdge[199, 233] -> 
             RGBColor[
              0.20189518711453486`, 0.32953502092454917`, 0.9348090042777849],
              UndirectedEdge[249, 286] -> 
             RGBColor[
              0.2141737173623244, 0.342440534718758, 0.9355082484109388], 
             UndirectedEdge[48, 266] -> 
             RGBColor[
              0.19547981769013628`, 0.32279206090159157`, 0.934443658479754], 
             UndirectedEdge[113, 169] -> 
             RGBColor[
              0.4361857848874334, 0.5443112881470928, 0.9502895329739705], 
             UndirectedEdge[18, 33] -> 
             RGBColor[
              0.20024058888485757`, 0.32779593327757145`, 0.9347147773563635],
              UndirectedEdge[269, 293] -> 
             RGBColor[
              0.9364618321884765, 0.7794254179846133, 0.2941598607281082], 
             UndirectedEdge[189, 257] -> 
             RGBColor[
              0.1999558217805158, 0.327496624995631, 0.9346985602910465], 
             UndirectedEdge[11, 197] -> 
             RGBColor[
              0.7590782600827003, 0.809705103128537, 0.9161511323825111], 
             UndirectedEdge[221, 296] -> 
             RGBColor[
              0.18670137270172213`, 0.31356535863320917`, 0.9339437390242094],
              UndirectedEdge[126, 157] -> 
             RGBColor[
              0.20301322621103607`, 0.33071015090274497`, 0.93487267495034], 
             UndirectedEdge[24, 87] -> 
             RGBColor[
              0.9584560317231505, 0.8616047223377981, 0.3765513268644449], 
             UndirectedEdge[53, 137] -> 
             RGBColor[
              0.2387057780017381, 0.36822528587326325`, 0.936905312972422], 
             UndirectedEdge[27, 140] -> 
             RGBColor[
              0.8935802518260152, 0.5220287258229606, 0.25077918297631857`], 
             UndirectedEdge[115, 200] -> 
             RGBColor[
              0.35864952563609026`, 0.485065925681853, 0.9440738085255767], 
             UndirectedEdge[1, 5] -> 
             RGBColor[
              0.8948530465649757, 0.5292862061726197, 0.25371216367685606`], 
             UndirectedEdge[40, 42] -> 
             RGBColor[
              0.763419188891056, 0.5236029358473995, 0.5766518342873496], 
             UndirectedEdge[82, 167] -> 
             RGBColor[
              0.7605608363122977, 0.684376991975076, 0.6036441777632009], 
             UndirectedEdge[52, 57] -> 
             RGBColor[
              0.18920436008623348`, 0.3161961570728968, 0.9340862804529193], 
             UndirectedEdge[27, 203] -> 
             RGBColor[
              0.9534832977574548, 0.9312795143111227, 0.6643276822065549], 
             UndirectedEdge[251, 270] -> 
             RGBColor[
              0.24922321837913736`, 0.37927978255414485`, 0.9375042656427561],
              UndirectedEdge[200, 264] -> 
             RGBColor[
              0.3308901333922204, 0.45986309204908005`, 0.9423474428513454], 
             UndirectedEdge[84, 271] -> 
             RGBColor[
              0.20505156873545605`, 0.33285257813429087`, 0.9349887555416483],
              UndirectedEdge[80, 145] -> 
             RGBColor[
              0.9218561356347152, 0.9176464031707863, 0.6795757972164687], 
             UndirectedEdge[199, 259] -> 
             RGBColor[
              0.19177802866162308`, 0.31890124592564373`, 0.9342328470708863],
              UndirectedEdge[273, 274] -> 
             RGBColor[
              0.3509883555182567, 0.4717110997619036, 0.9438949792783465], 
             UndirectedEdge[281, 294] -> 
             RGBColor[
              0.7572554970898742, 0.8088426757639791, 0.9389810177450694], 
             UndirectedEdge[18, 183] -> 
             RGBColor[
              0.19635753288152386`, 0.32371459521809726`, 0.9344936430614402],
              UndirectedEdge[77, 269] -> 
             RGBColor[
              0.6934737954253698, 0.7269802724747518, 0.6489189851142219], 
             UndirectedEdge[134, 144] -> 
             RGBColor[
              0.22121948408189393`, 0.34984608226843733`, 0.9359094944023405],
              UndirectedEdge[200, 210] -> 
             RGBColor[
              0.4186246829308158, 0.5365148469090834, 0.9480331221442837], 
             UndirectedEdge[87, 151] -> 
             RGBColor[
              0.7954880540997038, 0.8360677360525939, 0.7285340376363743], 
             UndirectedEdge[109, 290] -> 
             RGBColor[
              0.9696110495252712, 0.9082697495604787, 0.5222701846474617], 
             UndirectedEdge[247, 278] -> 
             RGBColor[
              0.19919319876560948`, 0.3266950598538726, 0.9346551300385472], 
             UndirectedEdge[156, 205] -> 
             RGBColor[
              0.38342561820827703`, 0.5065257317852604, 0.945652519235638], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.18357179140558838`, 0.31027597026405784`, 0.9337655139991952],
              UndirectedEdge[64, 121] -> 
             RGBColor[
              0.2303769927354159, 0.3594712044828725, 0.9364310009728385], 
             UndirectedEdge[106, 264] -> 
             RGBColor[
              0.579035279379287, 0.6606770441091168, 0.9634331593756991], 
             UndirectedEdge[91, 107] -> 
             RGBColor[
              0.44931704433721525`, 0.562597259364136, 0.9501274523636514], 
             UndirectedEdge[7, 299] -> 
             RGBColor[
              0.8785067924803591, 0.5491072889991002, 0.5774137332578136], 
             UndirectedEdge[160, 221] -> 
             RGBColor[
              0.19098000658392586`, 0.31806247412446187`, 0.9341874008941293],
              UndirectedEdge[8, 234] -> 
             RGBColor[
              0.19931169581116837`, 0.32681960776190155`, 0.934661878269991], 
             UndirectedEdge[49, 174] -> 
             RGBColor[
              0.22141328802375174`, 0.3500497824992095, 0.9359205312501221], 
             UndirectedEdge[79, 245] -> 
             RGBColor[
              0.20419166956427437`, 0.3319487695846225, 0.9349397855559562], 
             UndirectedEdge[13, 147] -> 
             RGBColor[
              0.27334324637888757`, 0.4023623173416999, 0.9389609500302152], 
             UndirectedEdge[1, 197] -> 
             RGBColor[
              0.9025175586685273, 0.5666556213354577, 0.5207754202823706], 
             UndirectedEdge[129, 175] -> 
             RGBColor[
              0.18584814501363772`, 0.3126685622352725, 0.9338951489696101], 
             UndirectedEdge[116, 283] -> 
             RGBColor[
              0.29658629715284524`, 0.4290613813379507, 0.9402015229115228], 
             UndirectedEdge[62, 265] -> 
             RGBColor[
              0.2121964297407587, 0.3403622800612163, 0.9353956448060256], 
             UndirectedEdge[31, 291] -> 
             RGBColor[
              0.6732616853502813, 0.7412145267166439, 0.970423977207056], 
             UndirectedEdge[92, 277] -> 
             RGBColor[
              0.9122829383943001, 0.6155043542913563, 0.3292695837766948], 
             UndirectedEdge[124, 289] -> 
             RGBColor[
              0.2146845283282537, 0.3429774294312355, 0.9355373383397714], 
             UndirectedEdge[80, 277] -> 
             RGBColor[
              0.9859097978901593, 0.963818944183442, 0.4264320765360633], 
             UndirectedEdge[119, 244] -> 
             RGBColor[
              0.18517767786647377`, 0.3119638587535308, 0.9338569668574466], 
             UndirectedEdge[252, 268] -> 
             RGBColor[
              0.22149590633125682`, 0.35013661957870057`, 0.9359252362405117],
              UndirectedEdge[3, 194] -> 
             RGBColor[
              0.8201119559484569, 0.8600043630497185, 0.9658594088182089], 
             UndirectedEdge[1, 237] -> 
             RGBColor[
              0.8218840344451928, 0.1692158551566011, 0.1685894821401856], 
             UndirectedEdge[149, 281] -> 
             RGBColor[
              0.9369826909775356, 0.800923138426649, 0.5779306345773171], 
             UndirectedEdge[29, 209] -> 
             RGBColor[
              0.1878554243304431, 0.3147783400660943, 0.9340094605571987], 
             UndirectedEdge[123, 287] -> 
             RGBColor[
              0.22080206667647367`, 0.3494073501095485, 0.9358857230986155], 
             UndirectedEdge[17, 81] -> 
             RGBColor[
              0.7965640174649642, 0.6796969932787943, 0.60028868050202], 
             UndirectedEdge[176, 187] -> 
             RGBColor[
              0.20946640578711895`, 0.33749285179242483`, 0.9352401739805742],
              UndirectedEdge[246, 270] -> 
             RGBColor[
              0.19864447884335656`, 0.3261183204247322, 0.9346238812507333], 
             UndirectedEdge[45, 131] -> 
             RGBColor[
              0.2646712879230951, 0.39551668310902466`, 0.9383840103499137], 
             UndirectedEdge[4, 158] -> 
             RGBColor[
              0.2067416614051505, 0.33462897268820413`, 0.9350850038189193], 
             UndirectedEdge[169, 264] -> 
             RGBColor[
              0.450474457220526, 0.5593295887233245, 0.9511032517251437], 
             UndirectedEdge[42, 181] -> 
             RGBColor[
              0.9119493492321276, 0.6277402539008983, 0.29244935498531105`], 
             UndirectedEdge[8, 263] -> 
             RGBColor[
              0.20717874992744892`, 0.3350883804381527, 0.9351098953636496], 
             UndirectedEdge[145, 205] -> 
             RGBColor[
              0.6186317877643385, 0.696027939962637, 0.9659619530693695], 
             UndirectedEdge[167, 269] -> 
             RGBColor[
              0.9404234605306463, 0.796419028165488, 0.2974140588848261], 
             UndirectedEdge[187, 288] -> 
             RGBColor[
              0.2168027551458141, 0.3452038201198287, 0.9356579682233956], 
             UndirectedEdge[47, 131] -> 
             RGBColor[
              0.20675371716772, 0.33464164405904423`, 0.9350856903767627], 
             UndirectedEdge[43, 97] -> 
             RGBColor[
              0.33722237523593046`, 0.45881814929687276`, 0.9429900087971892],
              UndirectedEdge[104, 114] -> 
             RGBColor[
              0.28710993911342014`, 0.4166656473064825, 0.939751033226302], 
             UndirectedEdge[26, 129] -> 
             RGBColor[
              0.20909164827758553`, 0.33709895788890676`, 0.9352188320948104],
              UndirectedEdge[28, 79] -> 
             RGBColor[
              0.1833054434406642, 0.3099960216654862, 0.9337503458766192], 
             UndirectedEdge[53, 247] -> 
             RGBColor[
              0.2068169042556322, 0.33470805769473266`, 0.9350892887879424], 
             UndirectedEdge[150, 281] -> 
             RGBColor[
              0.9429354945032435, 0.8270367350349062, 0.582850380130669], 
             UndirectedEdge[76, 248] -> 
             RGBColor[
              0.2744382407386017, 0.40410226692421763`, 0.9390017406595347], 
             UndirectedEdge[194, 210] -> 
             RGBColor[
              0.5788422967306146, 0.6683006695271059, 0.9604448643230148], 
             UndirectedEdge[60, 265] -> 
             RGBColor[
              0.2549916258941355, 0.3853427445905684, 0.9378327679171411], 
             UndirectedEdge[78, 178] -> 
             RGBColor[
              0.2265713684695162, 0.3554712520888972, 0.9362142763008121], 
             UndirectedEdge[120, 190] -> 
             RGBColor[
              0.24175240008128845`, 0.37142747884586735`, 0.937078813592779], 
             UndirectedEdge[96, 267] -> 
             RGBColor[
              0.19857826997424566`, 0.3260487307054119, 0.9346201107535846], 
             UndirectedEdge[159, 212] -> 
             RGBColor[
              0.2623047179263146, 0.3930292679932042, 0.9382492376896236], 
             UndirectedEdge[34, 147] -> 
             RGBColor[
              0.19854534996450335`, 0.32601412968792354`, 0.9346182360077306],
              UndirectedEdge[41, 250] -> 
             RGBColor[
              0.18562426514456906`, 0.3124332502980778, 0.9338823993422674], 
             UndirectedEdge[146, 236] -> 
             RGBColor[
              0.2157299800022288, 0.3440762654260479, 0.9355968752659971], 
             UndirectedEdge[82, 103] -> 
             RGBColor[
              0.5173846437366769, 0.6182066285292835, 0.9553895463254356], 
             UndirectedEdge[179, 289] -> 
             RGBColor[
              0.383100677252795, 0.49832129750419296`, 0.9463738276021099], 
             UndirectedEdge[124, 247] -> 
             RGBColor[
              0.191840440673128, 0.3189668449068855, 0.9342364013426112], 
             UndirectedEdge[162, 227] -> 
             RGBColor[
              0.9720263822129245, 0.9204431940139248, 0.5369240475267748], 
             UndirectedEdge[156, 191] -> 
             RGBColor[
              0.31093411780431135`, 0.4362140910182484, 0.9413088841833633], 
             UndirectedEdge[1, 51] -> 
             RGBColor[
              0.8149950729473256, 0.4986008642103312, 0.5736801336240612], 
             UndirectedEdge[23, 198] -> 
             RGBColor[
              0.9769688580402975, 0.9814876170817164, 0.8855196519471269], 
             UndirectedEdge[77, 159] -> 
             RGBColor[
              0.3525117466514917, 0.4781312147063014, 0.9437419749856031], 
             UndirectedEdge[2, 238] -> 
             RGBColor[
              0.19301734075154908`, 0.3202038415090809, 0.9343034240610095], 
             UndirectedEdge[113, 245] -> 
             RGBColor[
              0.24643755239072743`, 0.3763518709789012, 0.9373456260857398], 
             UndirectedEdge[167, 201] -> 
             RGBColor[
              0.8765230577728718, 0.5106954425096772, 0.21782550243753762`], 
             UndirectedEdge[125, 150] -> 
             RGBColor[
              0.871301943093316, 0.4710709613159703, 0.2128466086647302], 
             UndirectedEdge[142, 198] -> 
             RGBColor[
              0.8972633266176216, 0.6021081538364577, 0.5605609698520013], 
             UndirectedEdge[34, 52] -> 
             RGBColor[
              0.1912130018306219, 0.3183073669014913, 0.934200669628743], 
             UndirectedEdge[13, 251] -> 
             RGBColor[
              0.3094480150189227, 0.44031071835692515`, 0.9410170631920465], 
             UndirectedEdge[120, 188] -> 
             RGBColor[
              0.317477361422549, 0.44666279511939655`, 0.9415507479684607], 
             UndirectedEdge[67, 173] -> 
             RGBColor[
              0.1901069718936137, 0.3171448593113474, 0.934137682860055], 
             UndirectedEdge[20, 280] -> 
             RGBColor[
              0.24050854139809294`, 0.3701201045046333, 0.9370079776808949], 
             UndirectedEdge[32, 107] -> 
             RGBColor[
              0.6980757286113448, 0.7586971466019095, 0.9005750351374335], 
             UndirectedEdge[189, 287] -> 
             RGBColor[
              0.22941840696730975`, 0.35846367006274493`, 0.9363764109314454],
              UndirectedEdge[159, 205] -> 
             RGBColor[
              0.33180025652813283`, 0.4601919629512097, 0.9424222571493942], 
             UndirectedEdge[66, 86] -> 
             RGBColor[
              0.49025940765542825`, 0.5952351366581299, 0.9535166371045274], 
             UndirectedEdge[119, 266] -> 
             RGBColor[
              0.1895006672172379, 0.3165075946545396, 0.9341031547056828], 
             UndirectedEdge[28, 230] -> 
             RGBColor[
              0.1877777818287943, 0.3146967328740425, 0.9340050389315915], 
             UndirectedEdge[83, 142] -> 
             RGBColor[
              0.8382440889794911, 0.2949664033288275, 0.18425588883826852`], 
             UndirectedEdge[191, 217] -> 
             RGBColor[
              0.21370747825416658`, 0.3419504878548173, 0.9354816967834682], 
             UndirectedEdge[43, 233] -> 
             RGBColor[
              0.2154911007768475, 0.3438251882143545, 0.9355832714475019], 
             UndirectedEdge[113, 297] -> 
             RGBColor[
              0.22981287868159825`, 0.35887828484541334`, 0.9363988755120056],
              UndirectedEdge[158, 207] -> 
             RGBColor[
              0.189116703595207, 0.3161040245430854, 0.9340812885454315], 
             UndirectedEdge[40, 201] -> 
             RGBColor[
              0.7672988678714465, 0.5534238485768511, 0.5803670192604423], 
             UndirectedEdge[194, 226] -> 
             RGBColor[
              0.8361313395314567, 0.8716084988779389, 0.9233783108429527], 
             UndirectedEdge[134, 230] -> 
             RGBColor[
              0.21844228820343148`, 0.34692707331578443`, 0.9357513372055553],
              UndirectedEdge[134, 264] -> 
             RGBColor[
              0.27050450497484707`, 0.4016477640777385, 0.9387162034315397], 
             UndirectedEdge[59, 226] -> 
             RGBColor[
              0.9856324112421679, 0.988326647065517, 0.887771658052475], 
             UndirectedEdge[42, 201] -> 
             RGBColor[
              0.8414844134036068, 0.31987295677179683`, 0.18735882716622465`],
              UndirectedEdge[217, 295] -> 
             RGBColor[
              0.19848052761044668`, 0.32594599728383544`, 0.9346145444705631],
              UndirectedEdge[45, 94] -> 
             RGBColor[
              0.5484117816822776, 0.636917841037437, 0.9603911500045271], 
             UndirectedEdge[197, 254] -> 
             RGBColor[
              0.6525617744919028, 0.7195772493628625, 0.9087750915707931], 
             UndirectedEdge[30, 189] -> 
             RGBColor[
              0.23256614809149867`, 0.36177214556258186`, 0.9365556701318023],
              UndirectedEdge[92, 179] -> 
             RGBColor[
              0.6771557268529196, 0.4334926321296493, 0.5667112930910556], 
             UndirectedEdge[134, 288] -> 
             RGBColor[
              0.22683219740980134`, 0.35574539984264686`, 0.9362291301230996],
              UndirectedEdge[59, 83] -> 
             RGBColor[
              0.9157801358545465, 0.6734487289604354, 0.5451685443334997], 
             UndirectedEdge[10, 22] -> 
             RGBColor[
              0.18947218593303478`, 0.31647765901902436`, 0.9341015327386817],
              UndirectedEdge[148, 168] -> 
             RGBColor[
              0.32335433659993124`, 0.4487211935569434, 0.9420362378816867], 
             UndirectedEdge[130, 216] -> 
             RGBColor[
              0.889133450052471, 0.5872803968126434, 0.22908968289478807`], 
             UndirectedEdge[158, 196] -> 
             RGBColor[
              0.1980026870183727, 0.32544375652472224`, 0.9345873321557463], 
             UndirectedEdge[203, 237] -> 
             RGBColor[
              0.8810998777201378, 0.5731845028928206, 0.5814799153304782], 
             UndirectedEdge[160, 193] -> 
             RGBColor[
              0.23766407621559904`, 0.36713039124832314`, 0.9368459895967611],
              UndirectedEdge[38, 88] -> 
             RGBColor[
              0.20448897001762012`, 0.33226125121102634`, 0.9349567163769577],
              UndirectedEdge[22, 73] -> 
             RGBColor[
              0.1856051226212358, 0.3124131302923484, 0.9338813092038822], 
             UndirectedEdge[181, 227] -> 
             RGBColor[
              0.9694992257478029, 0.9078122736758734, 0.34102909604815745`], 
             UndirectedEdge[85, 255] -> 
             RGBColor[
              0.2990831810082368, 0.42639058870879876`, 0.9405375990810403], 
             UndirectedEdge[106, 227] -> 
             RGBColor[
              0.907282547148933, 0.8714421765894653, 0.6337446762316135], 
             UndirectedEdge[131, 261] -> 
             RGBColor[
              0.23707213530482818`, 0.36650822381988146`, 0.9368122794375908],
              UndirectedEdge[81, 94] -> 
             RGBColor[
              0.8431768541892217, 0.7161112955984645, 0.6049346124449686], 
             UndirectedEdge[77, 154] -> 
             RGBColor[
              0.455540153481848, 0.5677935680255081, 0.950577540756124], 
             UndirectedEdge[167, 277] -> 
             RGBColor[
              0.9503466052484179, 0.8295784884211206, 0.3626330239957771], 
             UndirectedEdge[113, 176] -> 
             RGBColor[
              0.23091262265844142`, 0.3600341854928709, 0.9364615043045614], 
             UndirectedEdge[4, 276] -> 
             RGBColor[
              0.23095575836688206`, 0.36007952385740394`, 0.9364639608193436],
              UndirectedEdge[101, 243] -> 
             RGBColor[
              0.8173727655187092, 0.8567408344553589, 0.91183562312612], 
             UndirectedEdge[52, 271] -> 
             RGBColor[
              0.21068413741610115`, 0.3387727649431298, 0.9353095219953723], 
             UndirectedEdge[37, 71] -> 
             RGBColor[
              0.22494256325409756`, 0.3537592745352769, 0.9361215182533955], 
             UndirectedEdge[83, 291] -> 
             RGBColor[
              0.8867137047505624, 0.6516789960865967, 0.5925497284900865], 
             UndirectedEdge[80, 149] -> 
             RGBColor[
              0.9371561077922606, 0.7792834728078644, 0.30334662593416606`], 
             UndirectedEdge[104, 206] -> 
             RGBColor[
              0.2787552105581772, 0.4078842978745366, 0.9392752437947942], 
             UndirectedEdge[61, 108] -> 
             RGBColor[
              0.25897235282054676`, 0.38952674098289125`, 0.9380594644266425],
              UndirectedEdge[115, 264] -> 
             RGBColor[
              0.32396934415914475`, 0.453868652264371, 0.9419064562812274], 
             UndirectedEdge[38, 52] -> 
             RGBColor[
              0.19242626978916738`, 0.3195825884515542, 0.934269763444113], 
             UndirectedEdge[33, 285] -> 
             RGBColor[
              0.20009304762604624`, 0.3276408580599046, 0.934706375099942], 
             UndirectedEdge[100, 122] -> 
             RGBColor[
              0.18285159839459103`, 0.3095190017466254, 0.933724500072649], 
             UndirectedEdge[205, 269] -> 
             RGBColor[
              0.6727623053020111, 0.7090410207196602, 0.647599267278013], 
             UndirectedEdge[177, 252] -> 
             RGBColor[
              0.2649570005472917, 0.39581698519228203`, 0.9384002812611878], 
             UndirectedEdge[152, 244] -> 
             RGBColor[
              0.1860116480511821, 0.312840414294423, 0.9339044602257174], 
             UndirectedEdge[10, 71] -> 
             RGBColor[
              0.20685989156236995`, 0.3347532400796667, 0.9350917368514671], 
             UndirectedEdge[233, 259] -> 
             RGBColor[
              0.1952784533382303, 0.32258041420050104`, 0.9344321910778048], 
             UndirectedEdge[130, 299] -> 
             RGBColor[
              0.8652485405177199, 0.41636555627617133`, 0.20671378935182633`],
              UndirectedEdge[81, 86] -> 
             RGBColor[
              0.7418209808035544, 0.6361932312179576, 0.5953370394744854], 
             UndirectedEdge[205, 282] -> 
             RGBColor[
              0.40649592976024684`, 0.5265080761040026, 0.947122539087454], 
             UndirectedEdge[176, 297] -> 
             RGBColor[
              0.19309289409094996`, 0.3202832528591496, 0.9343077267119173], 
             UndirectedEdge[92, 128] -> 
             RGBColor[
              0.838247472010956, 0.29499240679111977`, 0.18425912843301978`], 
             UndirectedEdge[166, 285] -> 
             RGBColor[
              0.19288702957547718`, 0.3200668762008235, 0.9342960030323104], 
             UndirectedEdge[132, 146] -> 
             RGBColor[
              0.19846266788634026`, 0.3259272255814276, 0.9346135273856964], 
             UndirectedEdge[81, 130] -> 
             RGBColor[
              0.9006340382989853, 0.6395018820094367, 0.23868605563289352`], 
             UndirectedEdge[1, 128] -> 
             RGBColor[
              0.8318168299406954, 0.24556367391377373`, 0.17810113832416685`],
              UndirectedEdge[296, 297] -> 
             RGBColor[
              0.18960014391301738`, 0.31661215096899065`, 0.934108819756345], 
             UndirectedEdge[128, 237] -> 
             RGBColor[
              0.8350074590728989, 0.27008824756648975`, 0.18115648838446502`],
              UndirectedEdge[112, 146] -> 
             RGBColor[
              0.19463017997348525`, 0.32189903779124873`, 0.934395272868717], 
             UndirectedEdge[116, 287] -> 
             RGBColor[
              0.2651763885560936, 0.39604757589953593`, 0.9384127750837334], 
             UndirectedEdge[10, 266] -> 
             RGBColor[
              0.19427634422620857`, 0.3215271339863788, 0.9343751224463628], 
             UndirectedEdge[16, 76] -> 
             RGBColor[
              0.286854066125812, 0.4171520866149722, 0.9397088035477686], 
             UndirectedEdge[23, 72] -> 
             RGBColor[
              0.909381055653747, 0.6084841231487159, 0.5010093036534974], 
             UndirectedEdge[237, 277] -> 
             RGBColor[
              0.9090429254562429, 0.5906001950667261, 0.32616694372814004`], 
             UndirectedEdge[56, 278] -> 
             RGBColor[
              0.1999933373080916, 0.327536056193735, 0.9347006967448426], 
             UndirectedEdge[88, 274] -> 
             RGBColor[
              0.342952508633553, 0.4632649151839602, 0.9434373496862328], 
             UndirectedEdge[103, 282] -> 
             RGBColor[
              0.4309808924132613, 0.5477157201040381, 0.9486826992565017], 
             UndirectedEdge[46, 60] -> 
             RGBColor[
              0.2459880706675731, 0.3758794371890788, 0.9373200287665547], 
             UndirectedEdge[82, 216] -> 
             RGBColor[
              0.7399516836581952, 0.5917908620218015, 0.5864988772524447], 
             UndirectedEdge[48, 70] -> 
             RGBColor[
              0.2012898575043234, 0.328898781124103, 0.9347745316519882], 
             UndirectedEdge[143, 174] -> 
             RGBColor[
              0.27004966377854045`, 0.4011696971418227, 0.9386903008982872], 
             UndirectedEdge[95, 205] -> 
             RGBColor[
              0.32995805051825455`, 0.4582556876322203, 0.9423173462424312], 
             UndirectedEdge[78, 190] -> 
             RGBColor[
              0.19927294772660503`, 0.32677888106825503`, 0.9346596716238978],
              UndirectedEdge[68, 292] -> 
             RGBColor[
              0.8252860920096456, 0.8638987146846454, 0.9830984780135097], 
             UndirectedEdge[145, 269] -> 
             RGBColor[
              0.9190343803618738, 0.908127960055847, 0.6686138108252507], 
             UndirectedEdge[198, 254] -> 
             RGBColor[
              0.6416864490274542, 0.7118235947085315, 0.9431778757394982], 
             UndirectedEdge[124, 147] -> 
             RGBColor[
              0.19966110992932296`, 0.3271868641542167, 0.9346817768871081], 
             UndirectedEdge[44, 194] -> 
             RGBColor[
              0.5011124283287507, 0.6014735099165995, 0.9553542362124354], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.3434646997755016, 0.4661397793633797, 0.9433176524403382], 
             UndirectedEdge[5, 11] -> 
             RGBColor[
              0.7514137479791486, 0.7723356879656991, 0.6490878757769967], 
             UndirectedEdge[108, 254] -> 
             RGBColor[
              0.27973365180931276`, 0.4104203008650652, 0.9392757639847461], 
             UndirectedEdge[61, 71] -> 
             RGBColor[
              0.25028804221449197`, 0.3803989799188331, 0.9375649057849139], 
             UndirectedEdge[229, 284] -> 
             RGBColor[
              0.22933503139451644`, 0.3583760370494225, 0.936371662815918], 
             UndirectedEdge[37, 136] -> 
             RGBColor[
              0.309591888135542, 0.4349767741872242, 0.9412260952746828], 
             UndirectedEdge[148, 159] -> 
             RGBColor[
              0.26876902654338763`, 0.39982366621058674`, 0.9386173705022783],
              UndirectedEdge[164, 230] -> 
             RGBColor[
              0.1870233298629817, 0.313903756022956, 0.9339620740082502], 
             UndirectedEdge[176, 193] -> 
             RGBColor[
              0.23687819251132788`, 0.36630437764722934`, 0.9368012346824135],
              UndirectedEdge[216, 299] -> 
             RGBColor[
              0.8425788083187902, 0.31560991507508496`, 0.1879104981712836], 
             UndirectedEdge[149, 277] -> 
             RGBColor[
              0.9442574972371908, 0.8029244899485575, 0.3576036046538991], 
             UndirectedEdge[39, 248] -> 
             RGBColor[
              0.21184147363468755`, 0.3399891986882186, 0.9353754305808952], 
             UndirectedEdge[13, 137] -> 
             RGBColor[
              0.2974114508687985, 0.42765952627289927`, 0.9403315986701979], 
             UndirectedEdge[68, 75] -> 
             RGBColor[
              0.6048929892039929, 0.6837170469414527, 0.9652757515328931], 
             UndirectedEdge[66, 97] -> 
             RGBColor[
              0.4175999543798127, 0.5361258241249656, 0.9478300777173092], 
             UndirectedEdge[59, 106] -> 
             RGBColor[
              0.9234341463667425, 0.9403782883321993, 0.9424056010083017], 
             UndirectedEdge[51, 198] -> 
             RGBColor[
              0.8879439008384149, 0.9128115493875727, 0.9633242059952494], 
             UndirectedEdge[193, 228] -> 
             RGBColor[
              0.35291040472918833`, 0.4773968889253306, 0.9438069074260627], 
             UndirectedEdge[30, 287] -> 
             RGBColor[
              0.24614870075893425`, 0.37604826959963533`, 0.9373291764126268],
              UndirectedEdge[93, 147] -> 
             RGBColor[
              0.22726390844905786`, 0.3561991555169663, 0.936253715428126], 
             UndirectedEdge[69, 121] -> 
             RGBColor[
              0.21650915427912054`, 0.3448952269935637, 0.9356412480883811], 
             UndirectedEdge[148, 251] -> 
             RGBColor[
              0.26595227173522773`, 0.39686307831464074`, 0.9384569604829689],
              UndirectedEdge[125, 269] -> 
             RGBColor[
              0.904179684947735, 0.5963333758276583, 0.2657933486023245], 
             UndirectedEdge[37, 44] -> 
             RGBColor[
              0.27139379762507876`, 0.4018915080789134, 0.9387921467246012], 
             UndirectedEdge[91, 105] -> 
             RGBColor[
              0.38699951220692347`, 0.5063182366232937, 0.9462409477627431], 
             UndirectedEdge[81, 203] -> 
             RGBColor[
              0.9132949931047244, 0.7717981514907339, 0.6103970678254644], 
             UndirectedEdge[8, 69] -> 
             RGBColor[
              0.2060185451131012, 0.33386893161703934`, 0.9350438234158418], 
             UndirectedEdge[52, 270] -> 
             RGBColor[
              0.20578610160522076`, 0.3336246187524874, 0.9350305861019373], 
             UndirectedEdge[108, 268] -> 
             RGBColor[
              0.2228674989167732, 0.351578250350071, 0.9360033464091675], 
             UndirectedEdge[11, 254] -> 
             RGBColor[
              0.4252983225505378, 0.5406623913243694, 0.9489095154684506], 
             UndirectedEdge[82, 255] -> 
             RGBColor[
              0.489728760692208, 0.5942524926612631, 0.9536273379129792], 
             UndirectedEdge[43, 66] -> 
             RGBColor[
              0.3059641689064351, 0.4317438620573953, 0.9409982635304203], 
             UndirectedEdge[252, 283] -> 
             RGBColor[
              0.27188152915805053`, 0.4030951038026612, 0.9387946229216484], 
             UndirectedEdge[99, 215] -> 
             RGBColor[
              0.21020795705683448`, 0.338272269193962, 0.9352824042283578], 
             UndirectedEdge[114, 283] -> 
             RGBColor[
              0.2724764193926355, 0.4037203711574294, 0.9388285010404467], 
             UndirectedEdge[24, 194] -> 
             RGBColor[
              0.8048847779464043, 0.7450443793025796, 0.6134276095233945], 
             UndirectedEdge[134, 228] -> 
             RGBColor[
              0.3355280602689666, 0.4591269427933443, 0.9428170086239273], 
             UndirectedEdge[49, 143] -> 
             RGBColor[
              0.2582581828615999, 0.38877610307504745`, 0.9380187935040003], 
             UndirectedEdge[123, 189] -> 
             RGBColor[
              0.2072195140090381, 0.335131226072495, 0.935112216817791], 
             UndirectedEdge[232, 240] -> 
             RGBColor[
              0.184219115333836, 0.3109563487553536, 0.933802378139279], 
             UndirectedEdge[11, 243] -> 
             RGBColor[
              0.7596161582091865, 0.8099275378271904, 0.907236768390906], 
             UndirectedEdge[155, 210] -> 
             RGBColor[
              0.698996444284087, 0.6637676396684864, 0.6055600185754992], 
             UndirectedEdge[148, 156] -> 
             RGBColor[
              0.32039438822353183`, 0.44615743504463745`, 0.9418476325885221],
              UndirectedEdge[15, 212] -> 
             RGBColor[
              0.24587235329600743`, 0.3757578108946581, 0.9373134388334325], 
             UndirectedEdge[51, 204] -> 
             RGBColor[
              0.647452541380158, 0.7220822556308867, 0.967158350930859], 
             UndirectedEdge[95, 156] -> 
             RGBColor[
              0.3410239560220559, 0.4678404187910305, 0.9430224559559374], 
             UndirectedEdge[87, 109] -> 
             RGBColor[
              0.9929796059139886, 0.9895239708410322, 0.632193448669364], 
             UndirectedEdge[113, 288] -> 
             RGBColor[
              0.23824897201713657`, 0.3677451538202748, 0.9368792985473828], 
             UndirectedEdge[164, 176] -> 
             RGBColor[
              0.1880768897106564, 0.3150111142224146, 0.9340220726829731], 
             UndirectedEdge[17, 294] -> 
             RGBColor[
              0.6198562799736641, 0.7013271769000424, 0.963858572100545], 
             UndirectedEdge[77, 212] -> 
             RGBColor[
              0.32357566422601636`, 0.4477175574235364, 0.9420941078985701], 
             UndirectedEdge[180, 296] -> 
             RGBColor[
              0.19104587171588, 0.3181317025542363, 0.9341911518159554], 
             UndirectedEdge[217, 271] -> 
             RGBColor[
              0.21133673112817714`, 0.3394586823113528, 0.9353466862418491], 
             UndirectedEdge[4, 85] -> 
             RGBColor[
              0.2263430797542824, 0.3552313061748459, 0.9362012755962026], 
             UndirectedEdge[95, 127] -> 
             RGBColor[
              0.3181958172626126, 0.4480678323732162, 0.9415678671403162], 
             UndirectedEdge[54, 75] -> 
             RGBColor[
              0.2884831291269512, 0.41830852004459096`, 0.9398219273882558], 
             UndirectedEdge[134, 193] -> 
             RGBColor[
              0.26218140249464095`, 0.39289965565586527`, 0.9382422150582186],
              UndirectedEdge[40, 178] -> 
             RGBColor[
              0.4741224882012588, 0.573360769660643, 0.953860855337124], 
             UndirectedEdge[69, 239] -> 
             RGBColor[
              0.22257247692189291`, 0.35126816352797696`, 0.935986545343005], 
             UndirectedEdge[134, 200] -> 
             RGBColor[
              0.3051846864517926, 0.4328450374952205, 0.9408835556758889], 
             UndirectedEdge[89, 141] -> 
             RGBColor[
              0.33729605784908523`, 0.4651931821113565, 0.9427636193772146], 
             UndirectedEdge[38, 147] -> 
             RGBColor[
              0.1997586179230488, 0.3272893512379864, 0.9346873298231007], 
             UndirectedEdge[170, 182] -> 
             RGBColor[
              0.2259600378398488, 0.3548287048365162, 0.9361794619258352], 
             UndirectedEdge[94, 120] -> 
             RGBColor[
              0.5379895613183256, 0.6259634266279861, 0.9597976199730934], 
             UndirectedEdge[80, 269] -> 
             RGBColor[
              0.9759866531723878, 0.9306594839278095, 0.36121311142511225`], 
             UndirectedEdge[263, 286] -> 
             RGBColor[
              0.2153900069518347, 0.3437189321945473, 0.9355775143037223], 
             UndirectedEdge[130, 140] -> 
             RGBColor[
              0.8645610911257005, 0.4110815190068649, 0.2060554870376654], 
             UndirectedEdge[25, 288] -> 
             RGBColor[
              0.19999048340527747`, 0.32753305656092946`, 0.9347005342192993],
              UndirectedEdge[148, 191] -> 
             RGBColor[
              0.23683698231576478`, 0.36626106311881523`, 0.9367988878227413],
              UndirectedEdge[177, 268] -> 
             RGBColor[
              0.24851062539069607`, 0.37853080214228807`, 0.9374636845262513],
              UndirectedEdge[69, 126] -> 
             RGBColor[
              0.21552861209731056`, 0.34386461499051624`, 0.9355854076617092],
              UndirectedEdge[20, 37] -> 
             RGBColor[
              0.22278622542452461`, 0.3514928267566807, 0.9359987180040172], 
             UndirectedEdge[3, 72] -> 
             RGBColor[
              0.8918169128751087, 0.5962411896945986, 0.5690910592091327], 
             UndirectedEdge[87, 154] -> 
             RGBColor[
              0.7452228320173793, 0.7952601643437132, 0.7245769752264782], 
             UndirectedEdge[11, 204] -> 
             RGBColor[
              0.5077115751599948, 0.6112221547175201, 0.9543880614868259], 
             UndirectedEdge[55, 268] -> 
             RGBColor[
              0.20359322925377082`, 0.3313197708749761, 0.9349057052655861], 
             UndirectedEdge[125, 142] -> 
             RGBColor[
              0.8325650320679996, 0.2513146833284968, 0.1788176175262468], 
             UndirectedEdge[176, 221] -> 
             RGBColor[
              0.1901941228796547, 0.3172364605233681, 0.9341426459797817], 
             UndirectedEdge[29, 182] -> 
             RGBColor[
              0.224799401299116, 0.35360880224359903`, 0.9361133653918483], 
             UndirectedEdge[122, 161] -> 
             RGBColor[
              0.19334750398760153`, 0.32055086400373023`, 0.9343222263688701],
              UndirectedEdge[44, 226] -> 
             RGBColor[
              0.6512382253914439, 0.7184499980919314, 0.9093942676022314], 
             UndirectedEdge[89, 131] -> 
             RGBColor[
              0.3050760854207314, 0.4313279482249144, 0.9409287396125976], 
             UndirectedEdge[56, 110] -> 
             RGBColor[
              0.1926369557700678, 0.31980403277574326`, 0.9342817616990433], 
             UndirectedEdge[43, 178] -> 
             RGBColor[
              0.24229896140308743`, 0.37200194944906734`, 0.9371099394514903],
              UndirectedEdge[66, 162] -> 
             RGBColor[
              0.6888450125107997, 0.7498709206605213, 0.8694416515926326], 
             UndirectedEdge[5, 142] -> 
             RGBColor[
              0.9004741399785186, 0.5724923933279508, 0.25909492907778175`], 
             UndirectedEdge[147, 273] -> 
             RGBColor[
              0.22616395243467474`, 0.35504303200461024`, 0.9361910745603459],
              UndirectedEdge[81, 167] -> 
             RGBColor[
              0.8985734587541578, 0.6313323707616247, 0.23702806496310708`], 
             UndirectedEdge[95, 212] -> 
             RGBColor[
              0.2604625119164363, 0.3910929926742148, 0.9381443267826606], 
             UndirectedEdge[56, 217] -> 
             RGBColor[
              0.19969746831988144`, 0.32722507912794885`, 0.934683847443663], 
             UndirectedEdge[6, 93] -> 
             RGBColor[
              0.2258625386311459, 0.35472622698636247`, 0.9361739094901367], 
             UndirectedEdge[131, 146] -> 
             RGBColor[
              0.2147184255833614, 0.3430130575955638, 0.9355392687383033], 
             UndirectedEdge[7, 80] -> 
             RGBColor[
              0.9585640473109542, 0.9468487152511682, 0.6807339798518178], 
             UndirectedEdge[76, 239] -> 
             RGBColor[
              0.28224692267200363`, 0.41230968673525326`, 0.9394464335437323],
              UndirectedEdge[148, 278] -> 
             RGBColor[
              0.2234636176615972, 0.35220480894699246`, 0.9360372944898065], 
             UndirectedEdge[29, 170] -> 
             RGBColor[
              0.19641582947302122`, 0.3237758686319784, 0.934496962966084], 
             UndirectedEdge[147, 289] -> 
             RGBColor[
              0.22842117185433053`, 0.35741551273064565`, 0.9363196198670385],
              UndirectedEdge[25, 28] -> 
             RGBColor[
              0.18729283765525817`, 0.3141870258004196, 0.9339774220783192], 
             UndirectedEdge[5, 149] -> 
             RGBColor[
              0.933258247478127, 0.766135074707167, 0.2882041746629133], 
             UndirectedEdge[140, 202] -> 
             RGBColor[
              0.8419448678170631, 0.3105688491792778, 0.18729684498680563`], 
             UndirectedEdge[10, 63] -> 
             RGBColor[
              0.18664280478053893`, 0.31350380003462497`, 0.9339404036677414],
              UndirectedEdge[43, 259] -> 
             RGBColor[
              0.20537394232393572`, 0.33319141321544904`, 0.9350071142406031],
              UndirectedEdge[21, 50] -> 
             RGBColor[
              0.18770061499905671`, 0.31461562564332873`, 0.9340006443947961],
              UndirectedEdge[87, 155] -> 
             RGBColor[
              0.959730943798982, 0.866659323879206, 0.37757715104669176`], 
             UndirectedEdge[127, 282] -> 
             RGBColor[
              0.3947336965046049, 0.5163202208449985, 0.9463730599853389], 
             UndirectedEdge[79, 144] -> 
             RGBColor[
              0.1903903758627761, 0.31744273485178653`, 0.9341538222968402], 
             UndirectedEdge[54, 298] -> 
             RGBColor[
              0.25208733908179476`, 0.3822901550083788, 0.9376673730796856], 
             UndirectedEdge[234, 263] -> 
             RGBColor[
              0.20202221841831886`, 0.32966853887907605`, 0.9348162385226094],
              UndirectedEdge[34, 38] -> 
             RGBColor[
              0.18490621443215238`, 0.31167853347228314`, 0.9338415074164561],
              UndirectedEdge[39, 85] -> 
             RGBColor[
              0.21693635514660192`, 0.345344242191386, 0.9356655765457971], 
             UndirectedEdge[20, 108] -> 
             RGBColor[
              0.2298448182232575, 0.3589118553287811, 0.9364006944216527], 
             UndirectedEdge[94, 201] -> 
             RGBColor[
              0.8211264532079356, 0.595474367346517, 0.5857320499193991], 
             UndirectedEdge[260, 294] -> 
             RGBColor[
              0.39710848893487455`, 0.5114544721894022, 0.9473162764842546], 
             UndirectedEdge[138, 266] -> 
             RGBColor[
              0.21471877848996196`, 0.3430134285227765, 0.935539288835812], 
             UndirectedEdge[127, 168] -> 
             RGBColor[
              0.3746233333290345, 0.4989016350385623, 0.9450916454266876], 
             UndirectedEdge[128, 198] -> 
             RGBColor[
              0.9047656578317846, 0.6597743590910152, 0.567745210695355], 
             UndirectedEdge[145, 216] -> 
             RGBColor[
              0.8656837903388712, 0.6908198174551905, 0.5986314441654264], 
             UndirectedEdge[141, 182] -> 
             RGBColor[
              0.2740956905180802, 0.4054223277779909, 0.9389207161355438], 
             UndirectedEdge[41, 252] -> 
             RGBColor[
              0.21326847287064163`, 0.3414890653621836, 0.9354566960763266], 
             UndirectedEdge[55, 208] -> 
             RGBColor[
              0.19572673330134732`, 0.32305158486432833`, 0.9344577199585336],
              UndirectedEdge[121, 249] -> 
             RGBColor[
              0.21645306950395798`, 0.3448362783388877, 0.9356380541434055], 
             UndirectedEdge[89, 120] -> 
             RGBColor[
              0.3299173264663655, 0.4574376675895273, 0.9423434115408236], 
             UndirectedEdge[32, 142] -> 
             RGBColor[
              0.9088058774056695, 0.6101377233090057, 0.5151005353474709], 
             UndirectedEdge[7, 77] -> 
             RGBColor[
              0.6760511895639363, 0.7431695037981105, 0.9684398535409274], 
             UndirectedEdge[45, 146] -> 
             RGBColor[
              0.24998188699294738`, 0.3800771913696276, 0.937547470697963], 
             UndirectedEdge[110, 223] -> 
             RGBColor[
              0.18370379552866184`, 0.31041471496695283`, 0.9337730314387216],
              UndirectedEdge[225, 276] -> 
             RGBColor[
              0.23448523874767882`, 0.3637892315196025, 0.9366649595056316], 
             UndirectedEdge[65, 291] -> 
             RGBColor[
              0.6521691058057041, 0.7229451944590042, 0.9690799766899112], 
             UndirectedEdge[194, 290] -> 
             RGBColor[
              0.8162082398567924, 0.7899381324572718, 0.622538732772305], 
             UndirectedEdge[154, 258] -> 
             RGBColor[
              0.4187295668061743, 0.5359100880009214, 0.9482320027234739], 
             UndirectedEdge[31, 280] -> 
             RGBColor[
              0.3408307300134504, 0.46531138731317084`, 0.9430966160299905], 
             UndirectedEdge[156, 271] -> 
             RGBColor[
              0.3085633706783219, 0.433722285474784, 0.9411738736417443], 
             UndirectedEdge[83, 241] -> 
             RGBColor[
              0.9163383963463205, 0.6736795840204242, 0.5359167232529631], 
             UndirectedEdge[208, 268] -> 
             RGBColor[
              0.19718303522223768`, 0.3245822505180589, 0.9345406541985226], 
             UndirectedEdge[1, 80] -> 
             RGBColor[
              0.8987509068791093, 0.542434604273317, 0.26885461494810886`], 
             UndirectedEdge[116, 206] -> 
             RGBColor[
              0.2548872111619892, 0.3852329980868062, 0.9378268216526131], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.22364840280037163`, 0.35239902984389887`, 0.9360478177300946],
              UndirectedEdge[108, 204] -> 
             RGBColor[
              0.36214690441876973`, 0.48098006425821577`, 0.9447543100031214],
              UndirectedEdge[251, 271] -> 
             RGBColor[
              0.25412125419001774`, 0.38442792874478726`, 0.9377832015361911],
              UndirectedEdge[6, 38] -> 
             RGBColor[
              0.19835724810513683`, 0.32581642270738265`, 0.9346075238851115],
              UndirectedEdge[135, 158] -> 
             RGBColor[
              0.20301108119461975`, 0.33070789635448955`, 0.9348725527948284],
              UndirectedEdge[25, 180] -> 
             RGBColor[
              0.1930001178726018, 0.32018573917131365`, 0.9343024432435325], 
             UndirectedEdge[57, 217] -> 
             RGBColor[
              0.18985695379830947`, 0.3168820744411198, 0.9341234446993961], 
             UndirectedEdge[71, 136] -> 
             RGBColor[
              0.3079661703282201, 0.43326804169526645`, 0.9411335130505898], 
             UndirectedEdge[135, 173] -> 
             RGBColor[
              0.20718172638991203`, 0.3350915088889201, 0.9351100648687836], 
             UndirectedEdge[143, 235] -> 
             RGBColor[
              0.3576942027971, 0.4840672946486393, 0.9440192038790169], 
             UndirectedEdge[264, 288] -> 
             RGBColor[
              0.2525376443502292, 0.38276345439650644`, 0.937693017298556], 
             UndirectedEdge[223, 247] -> 
             RGBColor[
              0.18962339324408597`, 0.3166365874900364, 0.934110143771355], 
             UndirectedEdge[191, 225] -> 
             RGBColor[
              0.22748667103589795`, 0.35643329311969896`, 0.9362664014278987],
              UndirectedEdge[1, 243] -> 
             RGBColor[
              0.9030554567950135, 0.5668780560341109, 0.5118610562907654], 
             UndirectedEdge[29, 284] -> 
             RGBColor[
              0.21810645410068208`, 0.3465740903806829, 0.9357322119502256], 
             UndirectedEdge[6, 273] -> 
             RGBColor[
              0.22476258261676274`, 0.3535701034740064, 0.9361112686223567], 
             UndirectedEdge[103, 276] -> 
             RGBColor[
              0.33135174266530537`, 0.4551929422593771, 0.9425624927166377], 
             UndirectedEdge[99, 199] -> 
             RGBColor[
              0.19703448061371565`, 0.32442611020559603`, 0.9345321942333341],
              UndirectedEdge[35, 129] -> 
             RGBColor[
              0.19774057513237292`, 0.32516826031368307`, 0.9345724052715985],
              UndirectedEdge[77, 145] -> 
             RGBColor[
              0.6393432778876973, 0.7139671917177287, 0.9672816709055783], 
             UndirectedEdge[72, 155] -> 
             RGBColor[
              0.8778646469488878, 0.4863358074888676, 0.21768508409656526`], 
             UndirectedEdge[20, 44] -> 
             RGBColor[
              0.26761174198818394`, 0.3979163278083595, 0.93857676425113], 
             UndirectedEdge[131, 178] -> 
             RGBColor[
              0.2442095797785655, 0.3740101305018966, 0.9372187463414672], 
             UndirectedEdge[106, 241] -> 
             RGBColor[
              0.9239924068585166, 0.940609143392188, 0.9331537799277652], 
             UndirectedEdge[85, 286] -> 
             RGBColor[
              0.2265196157319883, 0.3554168566804423, 0.9362113290589713], 
             UndirectedEdge[86, 261] -> 
             RGBColor[
              0.41945675567834323`, 0.5279913173677868, 0.949221846121721], 
             UndirectedEdge[256, 269] -> 
             RGBColor[
              0.8955465010984967, 0.5299749416771264, 0.25752620199850723`], 
             UndirectedEdge[37, 61] -> 
             RGBColor[
              0.25191376002181387`, 0.38210771241079083`, 0.937657488009007], 
             UndirectedEdge[73, 244] -> 
             RGBColor[
              0.18608629156364545`, 0.31291886935869395`, 0.9339087110633268],
              UndirectedEdge[180, 193] -> 
             RGBColor[
              0.23722417633734735`, 0.3666680285850174, 0.9368209379494682], 
             UndirectedEdge[8, 213] -> 
             RGBColor[
              0.20342164602247398`, 0.3311394260198779, 0.9348959338543985], 
             UndirectedEdge[48, 138] -> 
             RGBColor[
              0.21204884540564534`, 0.34020715956762493`, 0.9353872400964722],
              UndirectedEdge[170, 284] -> 
             RGBColor[
              0.2192670906414149, 0.34779399297360003`, 0.9357983084842125], 
             UndirectedEdge[55, 219] -> 
             RGBColor[
              0.19323553565117518`, 0.3204331781829436, 0.9343158499377529], 
             UndirectedEdge[111, 235] -> 
             RGBColor[
              0.5113487817124779, 0.61295792200517, 0.9550106787741928], 
             UndirectedEdge[56, 247] -> 
             RGBColor[
              0.19855655348549195`, 0.3260259052988269, 0.9346188740316768], 
             UndirectedEdge[7, 82] -> 
             RGBColor[
              0.7758796678197641, 0.8252882359458167, 0.9760021123389747], 
             UndirectedEdge[182, 190] -> 
             RGBColor[
              0.22937905061187158`, 0.35842230403784237`, 0.9363741696452258],
              UndirectedEdge[113, 228] -> 
             RGBColor[
              0.34694483487630184`, 0.4711266967709722, 0.9434671770482106], 
             UndirectedEdge[133, 146] -> 
             RGBColor[
              0.19265917133132254`, 0.3198273827391699, 0.9342830268423918], 
             UndirectedEdge[93, 274] -> 
             RGBColor[
              0.3520883115326398, 0.4728672232742597, 0.9439576201461266], 
             UndirectedEdge[153, 220] -> 
             RGBColor[
              0.27707930337293885`, 0.40630757672797435`, 0.9391730382607208],
              UndirectedEdge[90, 153] -> 
             RGBColor[
              0.21837262298903565`, 0.3468538507584247, 0.9357473698746558], 
             UndirectedEdge[178, 190] -> 
             RGBColor[
              0.23171291230071078`, 0.36087534064819005`, 0.9365070796157662],
              UndirectedEdge[39, 126] -> 
             RGBColor[
              0.21260629074350712`, 0.3407930699617935, 0.9354189857837971], 
             UndirectedEdge[15, 77] -> 
             RGBColor[
              0.3360793820211845, 0.46085975760775527`, 0.942806176129412], 
             UndirectedEdge[103, 293] -> 
             RGBColor[
              0.6605442022439556, 0.5885330418914387, 0.5930681631412746], 
             UndirectedEdge[92, 269] -> 
             RGBColor[
              0.9023597936765284, 0.5823448940357236, 0.2640506186657438], 
             UndirectedEdge[8, 14] -> 
             RGBColor[
              0.19233103918746458`, 0.31948249505119564`, 0.9342643402022272],
              UndirectedEdge[157, 171] -> 
             RGBColor[
              0.1808430925709541, 0.30740793477935857`, 0.9336101186373109], 
             UndirectedEdge[198, 226] -> 
             RGBColor[
              0.975424098844659, 0.9808488194558194, 0.9111203095275062], 
             UndirectedEdge[86, 169] -> 
             RGBColor[
              0.5994580148931581, 0.6857060476229113, 0.9616106773009028], 
             UndirectedEdge[163, 235] -> 
             RGBColor[
              0.5148221170934733, 0.615777732139438, 0.9552841124586315], 
             UndirectedEdge[31, 136] -> 
             RGBColor[
              0.4061320211140046, 0.526192876725208, 0.9470993511503072], 
             UndirectedEdge[111, 292] -> 
             RGBColor[
              0.6939596467687601, 0.7604145144003427, 0.9704259544749405], 
             UndirectedEdge[48, 122] -> 
             RGBColor[
              0.1889251216320018, 0.3159026597527588, 0.9340703782360471], 
             UndirectedEdge[246, 295] -> 
             RGBColor[
              0.19068631113650653`, 0.3177537815878572, 0.9341706753728822], 
             UndirectedEdge[258, 263] -> 
             RGBColor[
              0.2750253960672227, 0.40349492782139373`, 0.9390800123727585], 
             UndirectedEdge[24, 299] -> 
             RGBColor[
              0.871228956104042, 0.44007591122058254`, 0.21152577211097698`], 
             UndirectedEdge[66, 193] -> 
             RGBColor[
              0.33295274750258996`, 0.46011056933666983`, 0.9425352231554471],
              UndirectedEdge[29, 199] -> 
             RGBColor[
              0.196824977685108, 0.32420590934437654`, 0.9345202633514818], 
             UndirectedEdge[27, 87] -> 
             RGBColor[
              0.9814947768371431, 0.9488415742094825, 0.4164630400439475], 
             UndirectedEdge[164, 180] -> 
             RGBColor[
              0.18842287353667586`, 0.3153747651602027, 0.9340417759500277], 
             UndirectedEdge[106, 200] -> 
             RGBColor[
              0.6137154608562325, 0.6918743175265988, 0.9656005116200483], 
             UndirectedEdge[69, 285] -> 
             RGBColor[
              0.2036242652013759, 0.3313523916237017, 0.9349074727168887], 
             UndirectedEdge[88, 137] -> 
             RGBColor[
              0.242196310039882, 0.3718940563578661, 0.9371040936082149], 
             UndirectedEdge[43, 261] -> 
             RGBColor[
              0.23516151692935008`, 0.3645000427670523, 0.9367034725476139], 
             UndirectedEdge[224, 253] -> 
             RGBColor[
              0.20025883236896588`, 0.32781510833607297`, 0.9347158162957947],
              UndirectedEdge[5, 23] -> 
             RGBColor[
              0.9801796714011944, 0.9518718565732095, 0.5840536111729073], 
             UndirectedEdge[42, 162] -> 
             RGBColor[
              0.914476505697249, 0.6403711742389498, 0.48834430646392846`], 
             UndirectedEdge[29, 131] -> 
             RGBColor[
              0.21233150972289871`, 0.34050425768701104`, 0.9354033374111754],
              UndirectedEdge[12, 192] -> 
             RGBColor[
              0.3801187118441842, 0.5036614557026298, 0.9454418060863005], 
             UndirectedEdge[69, 76] -> 
             RGBColor[
              0.2672433086560147, 0.39653993712037666`, 0.9385919999213795], 
             UndirectedEdge[176, 180] -> 
             RGBColor[
              0.1945386218938126, 0.32180280444439524`, 0.9343900587715277], 
             UndirectedEdge[101, 116] -> 
             RGBColor[
              0.46733992011891123`, 0.5718860980228273, 0.952579449352897], 
             UndirectedEdge[125, 293] -> 
             RGBColor[
              0.8674766192366652, 0.4546177529994014, 0.20970208429653842`], 
             UndirectedEdge[30, 300] -> 
             RGBColor[
              0.23747118318928384`, 0.36692764844754155`, 0.936835004624272], 
             UndirectedEdge[155, 290] -> 
             RGBColor[
              0.9363623874102649, 0.7854051025986525, 0.2676538870247894], 
             UndirectedEdge[217, 246] -> 
             RGBColor[
              0.1922440281378487, 0.31939104092123016`, 0.9342593850516728], 
             UndirectedEdge[42, 82] -> 
             RGBColor[
              0.7255221919430327, 0.49355450623719554`, 0.5731775024918879], 
             UndirectedEdge[122, 138] -> 
             RGBColor[
              0.2081640824318275, 0.3361240273739437, 0.9351660085921052], 
             UndirectedEdge[58, 160] -> 
             RGBColor[
              0.19345266111115197`, 0.32066139080792844`, 0.9343282149114902],
              UndirectedEdge[158, 225] -> 
             RGBColor[
              0.21027114178594725`, 0.3383386803504027, 0.9352860025052073], 
             UndirectedEdge[197, 204] -> 
             RGBColor[
              0.7349750271013598, 0.7901370127560131, 0.9142536375891683], 
             UndirectedEdge[40, 182] -> 
             RGBColor[
              0.47178862651241965`, 0.5709077330502953, 0.9537279453665835], 
             UndirectedEdge[1, 149] -> 
             RGBColor[
              0.8570986062261408, 0.38154015003843245`, 0.20002614306594468`],
              UndirectedEdge[32, 156] -> 
             RGBColor[
              0.691083843191671, 0.7526411268737674, 0.9001295183811735], 
             UndirectedEdge[258, 286] -> 
             RGBColor[
              0.28052613048445796`, 0.4092765484606139, 0.9393932710602128], 
             UndirectedEdge[101, 197] -> 
             RGBColor[
              0.816834867392223, 0.8565183997567056, 0.9207499871177253], 
             UndirectedEdge[53, 271] -> 
             RGBColor[
              0.21925630560640996`, 0.3477826572179991, 0.935797694292424], 
             UndirectedEdge[22, 70] -> 
             RGBColor[
              0.19915563229546623`, 0.32665557511190024`, 0.9346529906836472],
              UndirectedEdge[76, 258] -> 
             RGBColor[
              0.3335396370029857, 0.4633170022075566, 0.942473828625678], 
             UndirectedEdge[232, 297] -> 
             RGBColor[
              0.18995045311417683`, 0.3169803481502954, 0.934128769347115], 
             UndirectedEdge[178, 261] -> 
             RGBColor[
              0.2518738885698846, 0.38206580498681714`, 0.9376552173888041], 
             UndirectedEdge[155, 227] -> 
             RGBColor[
              0.9395091625151377, 0.7978810172888317, 0.27018585613847523`], 
             UndirectedEdge[178, 182] -> 
             RGBColor[
              0.2566774713547828, 0.3871146750584845, 0.9379287743221401], 
             UndirectedEdge[5, 51] -> 
             RGBColor[
              0.8911547141993119, 0.8831957888790658, 0.6618581652210298], 
             UndirectedEdge[110, 295] -> 
             RGBColor[
              0.19142001506063305`, 0.31852495093162986`, 0.9342124587259435],
              UndirectedEdge[186, 286] -> 
             RGBColor[
              0.2070033670926693, 0.3349040419588854, 0.9350999075706646], 
             UndirectedEdge[34, 270] -> 
             RGBColor[
              0.19826604624820576`, 0.32572056377321634`, 0.9346023300742803],
              UndirectedEdge[4, 8] -> 
             RGBColor[
              0.21250294836697825`, 0.34068445057177643`, 0.935413100588335], 
             UndirectedEdge[69, 166] -> 
             RGBColor[
              0.19683162728000528`, 0.3242128984902222, 0.9345206420360739], 
             UndirectedEdge[25, 176] -> 
             RGBColor[
              0.19265413404658233`, 0.31982208823352565`, 0.9342827399764779],
              UndirectedEdge[32, 149] -> 
             RGBColor[
              0.9415899849052779, 0.803780404688222, 0.5442097809326024], 
             UndirectedEdge[16, 153] -> 
             RGBColor[
              0.233929772423327, 0.36320540119410966`, 0.9366333265201985], 
             UndirectedEdge[169, 299] -> 
             RGBColor[
              0.7117164306549081, 0.41734421667683197`, 0.5637805087358065], 
             UndirectedEdge[187, 229] -> 
             RGBColor[
              0.22122626051320093`, 0.3498532047273915, 0.9359098803100787], 
             UndirectedEdge[15, 82] -> 
             RGBColor[
              0.43590786027701234`, 0.5429784897554615, 0.9503684349274593], 
             UndirectedEdge[44, 280] -> 
             RGBColor[
              0.2891161135986471, 0.42051878582686586`, 0.939801406401479], 
             UndirectedEdge[186, 265] -> 
             RGBColor[
              0.2079159163966799, 0.33586318913636815`, 0.9351518759035322], 
             UndirectedEdge[117, 265] -> 
             RGBColor[
              0.2041128319271811, 0.33186590622944256`, 0.9349352958691536], 
             UndirectedEdge[106, 162] -> 
             RGBColor[
              0.9266044419072905, 0.9416892870110949, 0.8898655994395634], 
             UndirectedEdge[9, 146] -> 
             RGBColor[
              0.1994945649800457, 0.3270118148529666, 0.9346722923986279], 
             UndirectedEdge[130, 294] -> 
             RGBColor[
              0.723926300807685, 0.6611320656306849, 0.6022559472314186], 
             UndirectedEdge[13, 53] -> 
             RGBColor[
              0.27458306643531494`, 0.40366544683013694`, 0.9390315559482794],
              UndirectedEdge[34, 57] -> 
             RGBColor[
              0.18168430472921848`, 0.3082921020936258, 0.9336580244252622], 
             UndirectedEdge[25, 144] -> 
             RGBColor[
              0.19437777007737006`, 0.3216337389867199, 0.9343808984985402], 
             UndirectedEdge[206, 283] -> 
             RGBColor[
              0.26412169083739256`, 0.3949390217254835, 0.938352711608939], 
             UndirectedEdge[107, 273] -> 
             RGBColor[
              0.32370272298268776`, 0.4483418094779742, 0.9420833765839904], 
             UndirectedEdge[64, 85] -> 
             RGBColor[
              0.2337265149567007, 0.3629917647094177, 0.9366217513081667], 
             UndirectedEdge[175, 224] -> 
             RGBColor[
              0.19563816085584113`, 0.3229584896082839, 0.9344526758887932], 
             UndirectedEdge[68, 163] -> 
             RGBColor[
              0.7490034970690254, 0.8039812828492927, 0.9757174701655251], 
             UndirectedEdge[7, 237] -> 
             RGBColor[
              0.8816971748770377, 0.5736299661344524, 0.5804688470438946], 
             UndirectedEdge[76, 126] -> 
             RGBColor[
              0.2752030578474213, 0.40490613819779253`, 0.9390452958624365], 
             UndirectedEdge[30, 236] -> 
             RGBColor[
              0.2403636886171835, 0.3699678550477007, 0.9369997285293126], 
             UndirectedEdge[7, 269] -> 
             RGBColor[
              0.9557422920381128, 0.9373302721362289, 0.6697719934605999], 
             UndirectedEdge[237, 256] -> 
             RGBColor[
              0.8215013839374217, 0.16627463567534986`, 0.16822305558180195`],
              UndirectedEdge[106, 290] -> 
             RGBColor[
              0.9041357720440601, 0.8589662618992862, 0.6312127071179277], 
             UndirectedEdge[180, 288] -> 
             RGBColor[
              0.20187497125250775`, 0.32951377277179905`, 0.9348078530143491],
              UndirectedEdge[201, 237] -> 
             RGBColor[
              0.8352193779806968, 0.2717171491552828, 0.18135942216990056`], 
             UndirectedEdge[10, 73] -> 
             RGBColor[
              0.18653587436616526`, 0.31339140938933835`, 0.9339343141388322],
              UndirectedEdge[18, 175] -> 
             RGBColor[
              0.19129167307218187`, 0.3183900553644156, 0.9342051498395663], 
             UndirectedEdge[57, 295] -> 
             RGBColor[
              0.1882992367969673, 0.3152448151077469, 0.9340347350206055], 
             UndirectedEdge[71, 161] -> 
             RGBColor[
              0.2124857473818974, 0.34066637124585103`, 0.9354121210176813], 
             UndirectedEdge[218, 220] -> 
             RGBColor[
              0.6501395047208716, 0.7189888396444919, 0.9414344110066938], 
             UndirectedEdge[192, 248] -> 
             RGBColor[
              0.27628801069729353`, 0.4057044446902951, 0.9391196063656152], 
             UndirectedEdge[23, 24] -> 
             RGBColor[
              0.956555334204736, 0.8626596651038085, 0.541866983332811], 
             UndirectedEdge[39, 195] -> 
             RGBColor[
              0.1927241486561343, 0.3198956780273474, 0.9342867272049146], 
             UndirectedEdge[79, 232] -> 
             RGBColor[
              0.1855242988552152, 0.31232817938973806`, 0.9338767064099756], 
             UndirectedEdge[12, 154] -> 
             RGBColor[
              0.46345887168868094`, 0.5746523637299171, 0.9510821144780158], 
             UndirectedEdge[106, 155] -> 
             RGBColor[
              0.8940872222095038, 0.8191271102860018, 0.6231274080512639], 
             UndirectedEdge[95, 103] -> 
             RGBColor[
              0.35444301317126903`, 0.47946333163225574`, 0.9438775064114789],
              UndirectedEdge[3, 228] -> 
             RGBColor[
              0.690237715965832, 0.7545004457298199, 0.955381119587516], 
             UndirectedEdge[81, 293] -> 
             RGBColor[
              0.8946118304119881, 0.61433876058075, 0.23377386680638917`], 
             UndirectedEdge[95, 145] -> 
             RGBColor[
              0.5762301255781173, 0.6573426269684071, 0.963331889789669], 
             UndirectedEdge[39, 153] -> 
             RGBColor[
              0.2113966935997263, 0.3395217066707913, 0.9353501010158973], 
             UndirectedEdge[39, 90] -> 
             RGBColor[
              0.20870014958760652`, 0.3366874679432882, 0.9351965368235865], 
             UndirectedEdge[120, 141] -> 
             RGBColor[
              0.28646903998749706`, 0.4184275025860159, 0.939625360083097], 
             UndirectedEdge[102, 172] -> 
             RGBColor[
              0.19138970866876043`, 0.3184930969922355, 0.9342107328217606], 
             UndirectedEdge[155, 194] -> 
             RGBColor[
              0.8061596900222359, 0.7500989808439875, 0.6144534337056413], 
             UndirectedEdge[53, 251] -> 
             RGBColor[
              0.25074234215186236`, 0.3808764779572891, 0.9375907774942707], 
             UndirectedEdge[128, 243] -> 
             RGBColor[
              0.9161788814227196, 0.6677504484439996, 0.5244280625350448], 
             UndirectedEdge[72, 87] -> 
             RGBColor[
              0.9112817531721615, 0.6074291803827055, 0.3356936471851313], 
             UndirectedEdge[76, 90] -> 
             RGBColor[
              0.2712969166915207, 0.40080053617928724`, 0.938822846902226], 
             UndirectedEdge[3, 106] -> 
             RGBColor[
              0.9080394881357245, 0.9290324924917327, 0.9745333831638314], 
             UndirectedEdge[104, 243] -> 
             RGBColor[
              0.6612526622734278, 0.7268613939195354, 0.9003802288706013], 
             UndirectedEdge[34, 217] -> 
             RGBColor[
              0.1918655955426979, 0.3189932842697143, 0.9342378338752199], 
             UndirectedEdge[31, 37] -> 
             RGBColor[
              0.32310841403988205`, 0.4466841095652183, 0.9420873563531128], 
             UndirectedEdge[64, 249] -> 
             RGBColor[
              0.22138061658703678`, 0.35001544274773333`, 0.9359186706601341],
              UndirectedEdge[89, 188] -> 
             RGBColor[
              0.3683043792841372, 0.49342847464473716`, 0.9446890072625783], 
             UndirectedEdge[179, 269] -> 
             RGBColor[
              0.7479608310759376, 0.7722887789067958, 0.6529117994592061], 
             UndirectedEdge[213, 249] -> 
             RGBColor[
              0.2049158790401142, 0.33270995966126304`, 0.9349810282142335], 
             UndirectedEdge[44, 252] -> 
             RGBColor[
              0.27708079783829526`, 0.4078689058796433, 0.9391160129735812], 
             UndirectedEdge[149, 198] -> 
             RGBColor[
              0.93004743411723, 0.7957508352156739, 0.5896702154371328], 
             UndirectedEdge[158, 214] -> 
             RGBColor[
              0.19688801935015837`, 0.3242721701314169, 0.9345238534810445], 
             UndirectedEdge[202, 216] -> 
             RGBColor[
              0.8665172267438337, 0.4867677269850564, 0.21033104084392829`], 
             UndirectedEdge[78, 209] -> 
             RGBColor[
              0.18729352981200414`, 0.31418775330104487`, 0.933977461495622], 
             UndirectedEdge[77, 265] -> 
             RGBColor[
              0.31824926646414226`, 0.4421191756626833, 0.9417907774257306], 
             UndirectedEdge[44, 204] -> 
             RGBColor[
              0.39991382818369614`, 0.5199845367377941, 0.9469303798325985], 
             UndirectedEdge[54, 102] -> 
             RGBColor[
              0.218116116310074, 0.34658424597537324`, 0.9357327621987566], 
             UndirectedEdge[2, 253] -> 
             RGBColor[
              0.19522054856906235`, 0.32251955261673115`, 0.9344288934868631],
              UndirectedEdge[40, 86] -> 
             RGBColor[
              0.6417053553097174, 0.7192862820416126, 0.9654274840700409], 
             UndirectedEdge[75, 165] -> 
             RGBColor[
              0.27536181000482485`, 0.4045171817075533, 0.9390746876755028], 
             UndirectedEdge[73, 100] -> 
             RGBColor[
              0.1816658245926822, 0.30827267829841776`, 0.9336569720088254], 
             UndirectedEdge[50, 206] -> 
             RGBColor[
              0.20212300857950383`, 0.32977447572894675`, 0.9348219783731833],
              UndirectedEdge[32, 277] -> 
             RGBColor[
              0.9903436750031767, 0.9883158760637997, 0.6672952315344995], 
             UndirectedEdge[156, 251] -> 
             RGBColor[
              0.3400494072237743, 0.46681610621407393`, 0.942966956843591], 
             UndirectedEdge[31, 44] -> 
             RGBColor[
              0.36793393060354135`, 0.4931076106168971, 0.9446654026002257], 
             UndirectedEdge[80, 92] -> 
             RGBColor[
              0.9051815489493698, 0.591863337150663, 0.2750126050569618], 
             UndirectedEdge[11, 149] -> 
             RGBColor[
              0.7136593076403137, 0.6245896318315118, 0.5954018551660852], 
             UndirectedEdge[103, 145] -> 
             RGBColor[
              0.643116750417353, 0.7172355839626725, 0.9675221132384173], 
             UndirectedEdge[150, 274] -> 
             RGBColor[
              0.6852279869066359, 0.622788647378854, 0.5976147565045411], 
             UndirectedEdge[13, 156] -> 
             RGBColor[
              0.3638901315072269, 0.4896050750869218, 0.9444077352975997], 
             UndirectedEdge[84, 278] -> 
             RGBColor[
              0.19404895120727791`, 0.32128812950593255`, 0.9343621727503324],
              UndirectedEdge[150, 293] -> 
             RGBColor[
              0.9035840903340573, 0.6541630034729253, 0.24121312079051388`], 
             UndirectedEdge[52, 137] -> 
             RGBColor[
              0.23013360981142927`, 0.35921539359839394`, 0.9364171406753703],
              UndirectedEdge[41, 152] -> 
             RGBColor[
              0.1855570941414352, 0.31236264931489655`, 0.9338785740530094], 
             UndirectedEdge[177, 279] -> 
             RGBColor[
              0.2643192230897936, 0.3951466406470252, 0.9383639607784904], 
             UndirectedEdge[108, 279] -> 
             RGBColor[
              0.23867609661587075`, 0.3681940888548081, 0.9369036226614065], 
             UndirectedEdge[161, 279] -> 
             RGBColor[
              0.2191606879449377, 0.34768215699328187`, 0.9357922490080568], 
             UndirectedEdge[89, 260] -> 
             RGBColor[
              0.3194559514168667, 0.4464420991230162, 0.9417476517079721], 
             UndirectedEdge[63, 161] -> 
             RGBColor[
              0.19226866060006637`, 0.3194169312008093, 0.9342607878339557], 
             UndirectedEdge[110, 148] -> 
             RGBColor[
              0.2161072361235734, 0.34447278552900074`, 0.9356183594440073], 
             UndirectedEdge[200, 228] -> 
             RGBColor[
              0.3959136886863399, 0.5173422707646859, 0.946448248043733], 
             UndirectedEdge[67, 118] -> 
             RGBColor[
              0.18382399790050605`, 0.31054105528103165`, 0.9337798767859746],
              UndirectedEdge[140, 203] -> 
             RGBColor[
              0.8772220459314396, 0.5433777884881621, 0.5777664992302363], 
             UndirectedEdge[144, 231] -> 
             RGBColor[
              0.21441031983489064`, 0.34268921891888826`, 0.9355217225717294],
              UndirectedEdge[101, 149] -> 
             RGBColor[
              0.7714159149498363, 0.6714029284596804, 0.6000007099012994], 
             UndirectedEdge[131, 284] -> 
             RGBColor[
              0.23518277089129241`, 0.36452238202863274`, 0.9367046829293041],
              UndirectedEdge[157, 275] -> 
             RGBColor[
              0.18135642915031058`, 0.30794748407168115`, 0.9336393523960919],
              UndirectedEdge[113, 144] -> 
             RGBColor[
              0.23263625868922916`, 0.36184583624606526`, 0.9365596628266237],
              UndirectedEdge[48, 73] -> 
             RGBColor[
              0.187739347830093, 0.31465633630455114`, 0.9340028501722235], 
             UndirectedEdge[35, 183] -> 
             RGBColor[
              0.19956688605797046`, 0.32708782889128674`, 0.9346764109770263],
              UndirectedEdge[93, 107] -> 
             RGBColor[
              0.32480267899707094`, 0.44949793299033025`, 0.9421460174517705],
              UndirectedEdge[23, 226] -> 
             RGBColor[
              0.9878018957897885, 0.9892237846791677, 0.8518176846523693], 
             UndirectedEdge[200, 211] -> 
             RGBColor[
              0.31815152117452855`, 0.44647400293362227`, 0.9416219977306357],
              UndirectedEdge[87, 227] -> 
             RGBColor[
              0.9729262687384115, 0.9189743901826695, 0.3881944192270413], 
             UndirectedEdge[223, 278] -> 
             RGBColor[
              0.1910601770666856, 0.31814673838494456`, 0.9341919664845209], 
             UndirectedEdge[182, 229] -> 
             RGBColor[
              0.23602797859295035`, 0.36541074891233866`, 0.9367528162575407],
              UndirectedEdge[79, 221] -> 
             RGBColor[
              0.18466822464384994`, 0.3114283911153532, 0.9338279542500865], 
             UndirectedEdge[115, 228] -> 
             RGBColor[
              0.3889928994532643, 0.5113478309799768, 0.946007261473615], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.3382052536051789, 0.4616299042238716, 0.9429808558058818], 
             UndirectedEdge[9, 47] -> 
             RGBColor[
              0.1915298565644043, 0.31864040131644705`, 0.9342187140370874], 
             UndirectedEdge[18, 224] -> 
             RGBColor[
              0.2043212377981297, 0.33208495401350496`, 0.9349471642751953], 
             UndirectedEdge[194, 291] -> 
             RGBColor[
              0.8064401830754907, 0.8495804260163464, 0.9811128108192658], 
             UndirectedEdge[5, 198] -> 
             RGBColor[
              0.967801874456065, 0.9434968913498611, 0.6433562360480443], 
             UndirectedEdge[49, 172] -> 
             RGBColor[
              0.20010293929950806`, 0.3276512548358813, 0.9347069384161122], 
             UndirectedEdge[162, 228] -> 
             RGBColor[
              0.7088026697373979, 0.7671572402491821, 0.8707133358632482], 
             UndirectedEdge[100, 161] -> 
             RGBColor[
              0.1911587437240086, 0.318250338191278, 0.9341975797098391], 
             UndirectedEdge[174, 235] -> 
             RGBColor[
              0.3208493079592518, 0.4453409740728014, 0.9419209416251387], 
             UndirectedEdge[14, 67] -> 
             RGBColor[
              0.17956042552731538`, 0.30605977039070653`, 0.9335370726467116],
              UndirectedEdge[190, 199] -> 
             RGBColor[
              0.2014046269978636, 0.3290194111386199, 0.9347810676048591], 
             UndirectedEdge[160, 288] -> 
             RGBColor[
              0.20231487113075944`, 0.32997613543510473`, 0.934832904661642], 
             UndirectedEdge[33, 275] -> 
             RGBColor[
              0.19034059746125545`, 0.31739041459565537`, 0.9341509874905143],
              UndirectedEdge[109, 218] -> 
             RGBColor[
              0.9800003657513711, 0.9831729301139916, 0.8546124313811914], 
             UndirectedEdge[231, 264] -> 
             RGBColor[
              0.2636953407278438, 0.39449090072818943`, 0.9383284316009286], 
             UndirectedEdge[221, 230] -> 
             RGBColor[
              0.18914056303198, 0.3161291023239095, 0.9340826473050587], 
             UndirectedEdge[45, 236] -> 
             RGBColor[
              0.26568284234196243`, 0.3965798909395088, 0.9384416168776075], 
             UndirectedEdge[279, 280] -> 
             RGBColor[
              0.24933981979070619`, 0.37940233803066026`, 0.9375109059206487],
              UndirectedEdge[71, 252] -> 
             RGBColor[
              0.23062956346731406`, 0.3597366723360068, 0.9364453845023752], 
             UndirectedEdge[230, 296] -> 
             RGBColor[
              0.18964632804218584`, 0.3166606934169896, 0.9341114498741778], 
             UndirectedEdge[27, 154] -> 
             RGBColor[
              0.7335695588322665, 0.7563490417801518, 0.6454543011351679], 
             UndirectedEdge[5, 101] -> 
             RGBColor[
              0.8091703552886713, 0.8191489845938676, 0.6536867305122107], 
             UndirectedEdge[68, 143] -> 
             RGBColor[
              0.5918755827726521, 0.672270845358494, 0.9644525615859105], 
             UndirectedEdge[58, 221] -> 
             RGBColor[
              0.18866826221874242`, 0.3156326842235957, 0.9340557504724514], 
             UndirectedEdge[85, 249] -> 
             RGBColor[
              0.21980259172524277`, 0.34835683856543287`, 0.9358288044787336],
              UndirectedEdge[26, 54] -> 
             RGBColor[
              0.23656624471631046`, 0.3659765007360335, 0.9367834697169728], 
             UndirectedEdge[269, 282] -> 
             RGBColor[
              0.7068985223577822, 0.7386080961972126, 0.6497743968433352], 
             UndirectedEdge[24, 210] -> 
             RGBColor[
              0.6977215322082554, 0.6587130381270785, 0.6045341943932525], 
             UndirectedEdge[144, 288] -> 
             RGBColor[
              0.20325262345727604`, 0.33096177258720527`, 0.9348863082693568],
              UndirectedEdge[182, 199] -> 
             RGBColor[
              0.22636918605193562`, 0.35525874554891435`, 0.936202762311233], 
             UndirectedEdge[35, 224] -> 
             RGBColor[
              0.20753059097457632`, 0.33545818768669444`, 0.9351299321907813],
              UndirectedEdge[161, 280] -> 
             RGBColor[
              0.2318337811627876, 0.36100238148576125`, 0.9365139629186521], 
             UndirectedEdge[27, 42] -> 
             RGBColor[
              0.9037231190376234, 0.5999912478441332, 0.26049200407288453`], 
             UndirectedEdge[13, 273] -> 
             RGBColor[
              0.2861094453581625, 0.4157804018926833, 0.9396879661761859], 
             UndirectedEdge[167, 202] -> 
             RGBColor[
              0.8871263793979363, 0.5793538569383307, 0.22747634135468459`], 
             UndirectedEdge[117, 207] -> 
             RGBColor[
              0.18539878883552113`, 0.3121962604012447, 0.9338695588000294], 
             UndirectedEdge[33, 248] -> 
             RGBColor[
              0.21123257741316134`, 0.3393492101531443, 0.9353407548418606], 
             UndirectedEdge[23, 210] -> 
             RGBColor[
              0.7305128529889463, 0.7859159553283347, 0.8888842381324313], 
             UndirectedEdge[54, 111] -> 
             RGBColor[
              0.4291203016109882, 0.5357529458181629, 0.9499902123364491], 
             UndirectedEdge[30, 267] -> 
             RGBColor[
              0.22275125819820335`, 0.35145607398476686`, 0.9359967266722076],
              UndirectedEdge[170, 199] -> 
             RGBColor[
              0.19798561422584082`, 0.3254258119372937, 0.9345863598854686], 
             UndirectedEdge[169, 200] -> 
             RGBColor[
              0.4851546386974715, 0.5905268621408066, 0.9532706039694929], 
             UndirectedEdge[137, 278] -> 
             RGBColor[
              0.23108207251171536`, 0.3602122880324031, 0.9364711542230267], 
             UndirectedEdge[92, 150] -> 
             RGBColor[
              0.8694820518221094, 0.4570824795240357, 0.2111038787281495], 
             UndirectedEdge[68, 185] -> 
             RGBColor[
              0.7032065232894661, 0.766801236404889, 0.9721121646297556], 
             UndirectedEdge[26, 102] -> 
             RGBColor[
              0.21064547425155244`, 0.3387321275058029, 0.9353073201853483], 
             UndirectedEdge[270, 271] -> 
             RGBColor[
              0.217737181833685, 0.3461859618148549, 0.9357111824409096], 
             UndirectedEdge[169, 202] -> 
             RGBColor[
              0.7356548490799517, 0.5885020285868033, 0.5862010514084512], 
             UndirectedEdge[17, 97] -> 
             RGBColor[
              0.5762606506463335, 0.665813185958444, 0.9604600233988309], 
             UndirectedEdge[46, 158] -> 
             RGBColor[
              0.1988271914603046, 0.32631036296979365`, 0.9346342864639694], 
             UndirectedEdge[98, 285] -> 
             RGBColor[
              0.18936585526810354`, 0.31636589874842813`, 0.9340954773646161],
              UndirectedEdge[77, 168] -> 
             RGBColor[
              0.4070970567080353, 0.527028742052658, 0.9471608423650113], 
             UndirectedEdge[242, 268] -> 
             RGBColor[0.1929658134251674, 0.3201496830220325, 0.934300489656],
              UndirectedEdge[115, 134] -> 
             RGBColor[
              0.29826389721871693`, 0.4268505977105114, 0.940442569105771], 
             UndirectedEdge[99, 284] -> 
             RGBColor[
              0.2183159570292897, 0.34679429124190236`, 0.9357441428320781], 
             UndirectedEdge[204, 283] -> 
             RGBColor[
              0.3947145595034514, 0.515210734660812, 0.9466089897806659], 
             UndirectedEdge[77, 167] -> 
             RGBColor[
              0.6607323580564698, 0.6022582598273698, 0.5960819189651536], 
             UndirectedEdge[227, 290] -> 
             RGBColor[
              0.9495577123496941, 0.837720168902116, 0.27827115520513895`], 
             UndirectedEdge[60, 145] -> 
             RGBColor[
              0.5760856373176906, 0.6571907606456139, 0.9633236613969889], 
             UndirectedEdge[32, 125] -> 
             RGBColor[
              0.9114353173335938, 0.6303487508229553, 0.5176184899919789], 
             UndirectedEdge[15, 60] -> 
             RGBColor[
              0.27282174145117777`, 0.4040833265356404, 0.9388481666208225], 
             UndirectedEdge[30, 260] -> 
             RGBColor[
              0.25373200019445147`, 0.38401879811531836`, 0.9377610340969933],
              UndirectedEdge[42, 80] -> 
             RGBColor[
              0.9082065714342227, 0.6151149855425471, 0.2779093700047311], 
             UndirectedEdge[97, 130] -> 
             RGBColor[
              0.6803306714803544, 0.6256180746890865, 0.5988573985297044], 
             UndirectedEdge[65, 211] -> 
             RGBColor[
              0.3240980577045407, 0.45162459399430244`, 0.9420009057800123], 
             UndirectedEdge[1, 256] -> 
             RGBColor[
              0.8183107548052182, 0.14175006202263388`, 0.1651677055215038], 
             UndirectedEdge[5, 128] -> 
             RGBColor[
              0.9079764711926817, 0.6301585985825083, 0.2662791699211355], 
             UndirectedEdge[125, 256] -> 
             RGBColor[
              0.8265612881466855, 0.2051672766919145, 0.17306842556693747`], 
             UndirectedEdge[39, 239] -> 
             RGBColor[
              0.2196501555680895, 0.3481966184992542, 0.9358201234650929], 
             UndirectedEdge[156, 269] -> 
             RGBColor[
              0.6838282108058124, 0.7186257518784704, 0.6483043769915192], 
             UndirectedEdge[78, 170] -> 
             RGBColor[
              0.19585393495458225`, 0.32318528186692885`, 0.9344649639045073],
              UndirectedEdge[23, 155] -> 
             RGBColor[
              0.9578302462805677, 0.8677142666452164, 0.5428928075150579], 
             UndirectedEdge[127, 251] -> 
             RGBColor[
              0.31722126846433096`, 0.4470435197962596, 0.9415123680279698], 
             UndirectedEdge[241, 290] -> 
             RGBColor[
              0.9662675720592777, 0.9068871357048387, 0.5776802589012907], 
             UndirectedEdge[85, 234] -> 
             RGBColor[
              0.21315182719847248`, 0.341366463364971, 0.9354500532778585], 
             UndirectedEdge[270, 289] -> 
             RGBColor[
              0.22814186813803294`, 0.35712194681593845`, 0.9363037139335881],
              UndirectedEdge[69, 258] -> 
             RGBColor[
              0.273865191252875, 0.4022754790002804, 0.9390139404249507], 
             UndirectedEdge[52, 289] -> 
             RGBColor[
              0.22108882372044908`, 0.3497087499442134, 0.9359020534880509], 
             UndirectedEdge[47, 170] -> 
             RGBColor[
              0.1908380369178425, 0.3179132550040116, 0.9341793159316711], 
             UndirectedEdge[72, 241] -> 
             RGBColor[
              0.9077698315979006, 0.607817840595054, 0.5277114559730665], 
             UndirectedEdge[115, 210] -> 
             RGBColor[
              0.4117038936977402, 0.5305204071243743, 0.9475921355741658], 
             UndirectedEdge[166, 239] -> 
             RGBColor[
              0.21183524129599424`, 0.3399826481050988, 0.9353750756584267], 
             UndirectedEdge[180, 215] -> 
             RGBColor[
              0.2098131605219987, 0.33785731300430355`, 0.9352599211497481], 
             UndirectedEdge[51, 254] -> 
             RGBColor[
              0.5650392887707011, 0.6515224922377361, 0.9616798049124837], 
             UndirectedEdge[109, 227] -> 
             RGBColor[
              0.9727578246301442, 0.9207456642506578, 0.5248021537611475], 
             UndirectedEdge[203, 255] -> 
             RGBColor[
              0.651571481892223, 0.7220382969334023, 0.9679291557478935], 
             UndirectedEdge[257, 272] -> 
             RGBColor[
              0.18158199985616474`, 0.30818457318554265`, 0.9336521983140883],
              UndirectedEdge[32, 128] -> 
             RGBColor[
              0.9163082086198326, 0.6678039285635632, 0.5222847761908246], 
             UndirectedEdge[39, 76] -> 
             RGBColor[
              0.26432098730221126`, 0.39346839209165385`, 0.9384255780434674],
              UndirectedEdge[144, 221] -> 
             RGBColor[
              0.19191775891044247`, 0.3190481112765624, 0.9342408045018441], 
             UndirectedEdge[165, 262] -> 
             RGBColor[
              0.26081704104435255`, 0.39146562526609985`, 0.9381645166920165],
              UndirectedEdge[101, 226] -> 
             RGBColor[
              0.8167925796772653, 0.8565009126998259, 0.9214508039916728], 
             UndirectedEdge[56, 191] -> 
             RGBColor[
              0.21336670196225918`, 0.34159231036555776`, 0.9354622900777774],
              UndirectedEdge[63, 71] -> 
             RGBColor[
              0.20309975866494467`, 0.3308011019982774, 0.9348776028455769], 
             UndirectedEdge[137, 289] -> 
             RGBColor[
              0.25248937634424146`, 0.382712721661845, 0.9376902685070212], 
             UndirectedEdge[148, 295] -> 
             RGBColor[
              0.2216100316720449, 0.3502565725478334, 0.9359317355098362], 
             UndirectedEdge[10, 119] -> 
             RGBColor[
              0.1856272606689936, 0.3124363987841752, 0.9338825699329518], 
             UndirectedEdge[115, 231] -> 
             RGBColor[
              0.29145473297171365`, 0.41969373436096236`, 0.9400547972751598],
              UndirectedEdge[33, 171] -> 
             RGBColor[
              0.189827260881899, 0.31685086530333273`, 0.9341217537317332], 
             UndirectedEdge[173, 234] -> 
             RGBColor[
              0.19772105404463286`, 0.3251477424127598, 0.9345712935745305], 
             UndirectedEdge[69, 173] -> 
             RGBColor[
              0.2044279033465657, 0.3321970662678976, 0.9349532387203812], 
             UndirectedEdge[4, 263] -> 
             RGBColor[
              0.21521347097412877`, 0.3435333816889509, 0.9355674608409534], 
             UndirectedEdge[134, 160] -> 
             RGBColor[
              0.22028173175537732`, 0.3488604451163368, 0.9358560907946256], 
             UndirectedEdge[7, 205] -> 
             RGBColor[
              0.6553396994405775, 0.7252302520430189, 0.9671201357047186], 
             UndirectedEdge[23, 106] -> 
             RGBColor[
              0.9256036309143629, 0.94127542594585, 0.906451627608196], 
             UndirectedEdge[45, 96] -> 
             RGBColor[
              0.2504426073839444, 0.3805614377119254, 0.9375737080426556], 
             UndirectedEdge[65, 210] -> 
             RGBColor[
              0.424571219460828, 0.5416654379697635, 0.9484120301936603], 
             UndirectedEdge[138, 211] -> 
             RGBColor[
              0.25101026684268113`, 0.38115808379474614`, 0.9376060354090536],
              UndirectedEdge[72, 210] -> 
             RGBColor[
              0.6505472536572664, 0.40453749617198587`, 0.5636765147139389], 
             UndirectedEdge[37, 41] -> 
             RGBColor[
              0.20758147265742513`, 0.3355116675614536, 0.9351328298273469], 
             UndirectedEdge[52, 88] -> 
             RGBColor[
              0.21079575741608964`, 0.3388900846402345, 0.9353158785892447], 
             UndirectedEdge[157, 285] -> 
             RGBColor[
              0.1911088793151014, 0.31819792753593046`, 0.9341947400055196], 
             UndirectedEdge[135, 265] -> 
             RGBColor[
              0.21789617448484386`, 0.3463530731719392, 0.9357202368371844], 
             UndirectedEdge[17, 42] -> 
             RGBColor[
              0.7706339375032876, 0.5292391522973952, 0.5773709330033577], 
             UndirectedEdge[242, 250] -> 
             RGBColor[
              0.18176798085569046`, 0.30838005100792065`, 0.933662789656877], 
             UndirectedEdge[81, 202] -> 
             RGBColor[
              0.8780178149903479, 0.5389892121818496, 0.21992741358203377`], 
             UndirectedEdge[229, 259] -> 
             RGBColor[
              0.2014368212026378, 0.32905324928906804`, 0.934782901017194], 
             UndirectedEdge[40, 81] -> 
             RGBColor[
              0.7893492688527326, 0.6740607768287987, 0.5995695817860118], 
             UndirectedEdge[100, 119] -> 
             RGBColor[
              0.1807572108955105, 0.3073176676932546, 0.933605227802945], 
             UndirectedEdge[81, 269] -> 
             RGBColor[
              0.931314896123058, 0.7560543834090069, 0.28986513111217527`], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.8109817388046351, 0.5174976470005512, 0.5760174599499823], 
             UndirectedEdge[180, 233] -> 
             RGBColor[
              0.20014010875548707`, 0.32769032229079487`, 0.9347090551616429],
              UndirectedEdge[33, 184] -> 
             RGBColor[
              0.1959981041281816, 0.3233368128092353, 0.9344731741256647], 
             UndirectedEdge[103, 168] -> 
             RGBColor[
              0.41087052923769096`, 0.5302971342976018, 0.9474012846978503], 
             UndirectedEdge[49, 238] -> 
             RGBColor[
              0.19853266531396374`, 0.3260007973159532, 0.9346175136356476], 
             UndirectedEdge[97, 120] -> 
             RGBColor[
              0.3639742346570427, 0.4869360497143149, 0.944513487615392], 
             UndirectedEdge[117, 212] -> 
             RGBColor[
              0.20943922968905518`, 0.3374642879902957, 0.935238626341993], 
             UndirectedEdge[270, 278] -> 
             RGBColor[
              0.20673456430550685`, 0.3346215131864966, 0.9350845996495938], 
             UndirectedEdge[26, 165] -> 
             RGBColor[
              0.2234449255941841, 0.3521851623989958, 0.9360362300042198], 
             UndirectedEdge[65, 70] -> 
             RGBColor[
              0.2936166091660087, 0.41958665894484415`, 0.940265032379005], 
             UndirectedEdge[56, 223] -> 
             RGBColor[
              0.19042353178656807`, 0.3174775838298989, 0.9341557104776503], 
             UndirectedEdge[207, 212] -> 
             RGBColor[
              0.20932819464730518`, 0.33734758312138824`, 0.935232303060627], 
             UndirectedEdge[171, 184] -> 
             RGBColor[
              0.1853189372548359, 0.31211233132706184`, 0.9338650113706392], 
             UndirectedEdge[32, 205] -> 
             RGBColor[
              0.6800179376878698, 0.7430563957149572, 0.8994244086676673], 
             UndirectedEdge[23, 31] -> 
             RGBColor[
              0.7044976010018857, 0.7638813972041334, 0.8870888196503636], 
             UndirectedEdge[235, 274] -> 
             RGBColor[
              0.43577020330018756`, 0.5515998272739158, 0.9490608562281224], 
             UndirectedEdge[178, 199] -> 
             RGBColor[
              0.2287030477407748, 0.357711782159262, 0.9363356722817735], 
             UndirectedEdge[117, 158] -> 
             RGBColor[
              0.189227738636957, 0.3162207294119929, 0.9340876118267976], 
             UndirectedEdge[112, 190] -> 
             RGBColor[
              0.19682291342577818`, 0.3242037396769393, 0.9345201457949667], 
             UndirectedEdge[64, 213] -> 
             RGBColor[
              0.21883980227157213`, 0.34734488580524786`, 0.9357739750436664],
              UndirectedEdge[127, 205] -> 
             RGBColor[
              0.3605974794488338, 0.48675314536744607`, 0.9441979304200168], 
             UndirectedEdge[121, 263] -> 
             RGBColor[
              0.2176693590934683, 0.34611467581467703`, 0.935707320036189], 
             UndirectedEdge[14, 213] -> 
             RGBColor[
              0.19128445788964016`, 0.31838247175009526`, 0.9342047389455943],
              UndirectedEdge[109, 111] -> 
             RGBColor[
              0.8035074391264327, 0.8444862586698714, 0.8657863480729937], 
             UndirectedEdge[55, 108] -> 
             RGBColor[
              0.22141119699588285`, 0.35004758469634045`, 0.9359204121691784],
              UndirectedEdge[40, 162] -> 
             RGBColor[
              0.8402909601650888, 0.8739220660440041, 0.881352498558146], 
             UndirectedEdge[15, 225] -> 
             RGBColor[
              0.2429863506332136, 0.37272443911292436`, 0.9371490852512447], 
             UndirectedEdge[31, 59] -> 
             RGBColor[
              0.7023281164542653, 0.7629842595904825, 0.9230427930504692], 
             UndirectedEdge[210, 227] -> 
             RGBColor[
              0.7121917692235163, 0.7160827059719499, 0.6161772867558488], 
             UndirectedEdge[52, 93] -> 
             RGBColor[
              0.21993156031517644`, 0.348492392730534, 0.9358361490491385], 
             UndirectedEdge[32, 293] -> 
             RGBColor[
              0.9437174645743351, 0.8134407929799102, 0.5459850021177625], 
             UndirectedEdge[99, 209] -> 
             RGBColor[
              0.18806492725905072`, 0.31499854092731383`, 0.934021391439051], 
             UndirectedEdge[201, 299] -> 
             RGBColor[
              0.8320289955840182, 0.24719447201993064`, 0.1783043083838196], 
             UndirectedEdge[127, 148] -> 
             RGBColor[
              0.29756624946408855`, 0.42638484862682313`, 0.9403930437729009],
              UndirectedEdge[24, 226] -> 
             RGBColor[
              0.9550105750090976, 0.8620208674779115, 0.5674676409131905], 
             UndirectedEdge[144, 264] -> 
             RGBColor[
              0.24692493102232177`, 0.3768641368222969, 0.9373733815777969], 
             UndirectedEdge[148, 217] -> 
             RGBColor[
              0.22316774867338707`, 0.35189383188120626`, 0.9360204451886269],
              UndirectedEdge[230, 288] -> 
             RGBColor[
              0.2004754275788136, 0.3280427636345524, 0.9347281510725716], 
             UndirectedEdge[1, 83] -> 
             RGBColor[
              0.8326229955659482, 0.2517602161734964, 0.1788731234373428], 
             UndirectedEdge[15, 214] -> 
             RGBColor[
              0.22960322819742474`, 0.35865792889393855`, 0.936386936227082], 
             UndirectedEdge[173, 249] -> 
             RGBColor[
              0.20437181857140313`, 0.33213811761322165`, 0.9349500447754056],
              UndirectedEdge[114, 204] -> 
             RGBColor[
              0.3613702020678383, 0.4801637008416135, 0.944710077953264], 
             UndirectedEdge[77, 95] -> 
             RGBColor[
              0.3506695406416134, 0.476194939387312, 0.94363706407864], 
             UndirectedEdge[52, 295] -> 
             RGBColor[
              0.19782793389837072`, 0.3252600799156124, 0.9345773802240863], 
             UndirectedEdge[7, 103] -> 
             RGBColor[
              0.6798246620935919, 0.7464378960430543, 0.9686802958737664], 
             UndirectedEdge[29, 99] -> 
             RGBColor[
              0.19546469586089602`, 0.32277616690028066`, 0.9344427973139495],
              UndirectedEdge[28, 144] -> 
             RGBColor[
              0.19055497770725674`, 0.3176157418266954, 0.9341631961283768], 
             UndirectedEdge[75, 185] -> 
             RGBColor[
              0.43124290556454353`, 0.5458726103470143, 0.9492713561429931], 
             UndirectedEdge[227, 291] -> 
             RGBColor[
              0.9397896555683924, 0.8973624624611904, 0.6368452332520997], 
             UndirectedEdge[76, 192] -> 
             RGBColor[
              0.32876752436481727`, 0.45918363809373036`, 0.9421697538281874],
              UndirectedEdge[59, 72] -> 
             RGBColor[
              0.9072115711061266, 0.6075869855350652, 0.536963277053603], 
             UndirectedEdge[104, 254] -> 
             RGBColor[
              0.32693482661477913`, 0.45759624741671456`, 0.942052975948146], 
             UndirectedEdge[32, 237] -> 
             RGBColor[
              0.90637541312433, 0.5914561098063906, 0.5127731200068433], 
             UndirectedEdge[25, 232] -> 
             RGBColor[
              0.1895116930698092, 0.31651918352467145`, 0.9341037826116756], 
             UndirectedEdge[9, 141] -> 
             RGBColor[
              0.24640393833854723`, 0.3763165404788058, 0.9373437118151957], 
             UndirectedEdge[22, 48] -> 
             RGBColor[
              0.19067565939696252`, 0.3177425859342372, 0.934170068772073], 
             UndirectedEdge[25, 160] -> 
             RGBColor[
              0.19344001775085345`, 0.32064810183461934`, 0.9343274948908254],
              UndirectedEdge[72, 106] -> 
             RGBColor[
              0.845638031582683, 0.5598969667895013, 0.5812439041897035], 
             UndirectedEdge[4, 186] -> 
             RGBColor[
              0.2068268311149634, 0.334718491453289, 0.9350898541078958], 
             UndirectedEdge[78, 182] -> 
             RGBColor[
              0.22423750678067705`, 0.3530182154785495, 0.9360813663302717], 
             UndirectedEdge[106, 211] -> 
             RGBColor[
              0.5662966671615951, 0.6472879549936589, 0.9627077142549896], 
             UndirectedEdge[180, 245] -> 
             RGBColor[
              0.2100635516260986, 0.3381204899304254, 0.9352741805527061], 
             UndirectedEdge[136, 280] -> 
             RGBColor[
              0.32731420410911033`, 0.4536040519351767, 0.9422353549515605], 
             UndirectedEdge[82, 140] -> 
             RGBColor[
              0.7153793247314246, 0.41559198421602295`, 0.5634646813953219], 
             UndirectedEdge[50, 219] -> 
             RGBColor[
              0.1830787781409705, 0.30975778206409804`, 0.9337374376231229], 
             UndirectedEdge[251, 278] -> 
             RGBColor[
              0.24311863666183964`, 0.372863480116429, 0.9371566187448754], 
             UndirectedEdge[80, 150] -> 
             RGBColor[
              0.9431089113179686, 0.8053970694161215, 0.30826637148751795`], 
             UndirectedEdge[26, 183] -> 
             RGBColor[
              0.21091795920318307`, 0.3390185264665105, 0.9353228378002383], 
             UndirectedEdge[243, 256] -> 
             RGBColor[
              0.9026728062872424, 0.5639368365528598, 0.5114946297323817], 
             UndirectedEdge[184, 248] -> 
             RGBColor[
              0.20672425378609824`, 0.33461067617687346`, 0.9350840124807664],
              UndirectedEdge[4, 255] -> 
             RGBColor[
              0.2932777706676125, 0.42028873435652747`, 0.9402069895504767], 
             UndirectedEdge[37, 280] -> 
             RGBColor[
              0.2442905970349878, 0.3740952847751871, 0.9372233601543662], 
             UndirectedEdge[188, 260] -> 
             RGBColor[
              0.3070159863730502, 0.43566722665288543`, 0.9409549881356092], 
             UndirectedEdge[70, 266] -> 
             RGBColor[
              0.20395979058864, 0.33170505007925455`, 0.934926580391328], 
             UndirectedEdge[103, 127] -> 
             RGBColor[
              0.3850824421018483, 0.5079607893674816, 0.9457580905890645], 
             UndirectedEdge[37, 268] -> 
             RGBColor[
              0.21580890611804032`, 0.3441592217779706, 0.9356013699915318], 
             UndirectedEdge[186, 196] -> 
             RGBColor[
              0.19808785672818557`, 0.32553327528980713`, 0.9345921824447229],
              UndirectedEdge[139, 274] -> 
             RGBColor[
              0.4518848560948061, 0.5655575295786147, 0.9500876676545675], 
             UndirectedEdge[15, 255] -> 
             RGBColor[
              0.31219697150637127`, 0.44017401398467865`, 0.9412844100497945],
              UndirectedEdge[118, 195] -> 
             RGBColor[
              0.18622253645749176`, 0.31306207138055164`, 0.9339164700084752],
              UndirectedEdge[125, 128] -> 
             RGBColor[
              0.8400673632821627, 0.3089808885830544, 0.18600185836960054`], 
             UndirectedEdge[61, 177] -> 
             RGBColor[
              0.2846154792944696, 0.4164792927751083, 0.9395198025437264], 
             UndirectedEdge[117, 276] -> 
             RGBColor[
              0.21344183559868857`, 0.34167128058119267`, 0.9354665688272218],
              UndirectedEdge[7, 154] -> 
             RGBColor[
              0.7178086500945909, 0.778143567686985, 0.971430549102502], 
             UndirectedEdge[59, 198] -> 
             RGBColor[
              0.974799373492677, 0.9805904794680657, 0.9214736253472325], 
             UndirectedEdge[83, 197] -> 
             RGBColor[
              0.9164471489214862, 0.6737245560050689, 0.534114411639826], 
             UndirectedEdge[243, 283] -> 
             RGBColor[
              0.6466191425526432, 0.7139161177704824, 0.899457696684746], 
             UndirectedEdge[95, 225] -> 
             RGBColor[
              0.2575765092536425, 0.3880596208924811, 0.9379799732004728], 
             UndirectedEdge[21, 74] -> 
             RGBColor[
              0.19973960321144332`, 0.32726936557048675`, 0.9346862469634045],
              UndirectedEdge[62, 225] -> 
             RGBColor[
              0.21463682483983898`, 0.34292729004033573`, 0.9355346216966771],
              UndirectedEdge[236, 267] -> 
             RGBColor[
              0.21381850493226368`, 0.3420671839329953, 0.9354880195885366], 
             UndirectedEdge[123, 300] -> 
             RGBColor[
              0.21212454910682327`, 0.34028672895745476`, 0.9353915513102607],
              UndirectedEdge[111, 218] -> 
             RGBColor[
              0.7906966430720825, 0.8363639438748425, 0.9515975962507148], 
             UndirectedEdge[61, 161] -> 
             RGBColor[
              0.23945694414961366`, 0.369014809121365, 0.9369480907732928], 
             UndirectedEdge[58, 180] -> 
             RGBColor[
              0.1930127612329003, 0.32019902814462275`, 0.9343031632641974], 
             UndirectedEdge[188, 236] -> 
             RGBColor[
              0.29364767479578224`, 0.42161628358526776`, 0.9401936825679285],
              UndirectedEdge[41, 268] -> 
             RGBColor[
              0.19682209771404596`, 0.32420288231218963`, 0.9345200993413902],
              UndirectedEdge[65, 138] -> 
             RGBColor[
              0.30437559706733064`, 0.4308950373883661, 0.9408777408234891], 
             UndirectedEdge[241, 291] -> 
             RGBColor[
              0.956499515277976, 0.9665294292639133, 0.9362543369482514], 
             UndirectedEdge[270, 295] -> 
             RGBColor[
              0.20488097831595456`, 0.3326732767873375, 0.9349790406696236], 
             UndirectedEdge[127, 212] -> 
             RGBColor[
              0.2911019408470156, 0.4195904504094406, 0.9400249109602461], 
             UndirectedEdge[105, 274] -> 
             RGBColor[
              0.373443394956703, 0.4953127699434419, 0.9451737605551122], 
             UndirectedEdge[128, 142] -> 
             RGBColor[
              0.8374379233542384, 0.28876986106910485`, 0.18348390372509257`],
              UndirectedEdge[38, 57] -> 
             RGBColor[
              0.18289757268776397`, 0.30956732364368866`, 0.9337271182406324],
              UndirectedEdge[135, 255] -> 
             RGBColor[
              0.28954719045708177`, 0.4163676580228129, 0.9399945385263857], 
             UndirectedEdge[46, 196] -> 
             RGBColor[
              0.2038842250820344, 0.33162562594068223`, 0.9349222770475161], 
             UndirectedEdge[138, 210] -> 
             RGBColor[
              0.35148342859896836`, 0.4711989277702072, 0.9440171598227016], 
             UndirectedEdge[72, 109] -> 
             RGBColor[
              0.9111133090638942, 0.6092004544506938, 0.4723013817192375], 
             UndirectedEdge[277, 282] -> 
             RGBColor[
              0.7168216670755537, 0.7717675564528452, 0.7149933619542863], 
             UndirectedEdge[62, 117] -> 
             RGBColor[
              0.1935934216908487, 0.32080933910192594`, 0.9343362310182673], 
             UndirectedEdge[33, 126] -> 
             RGBColor[
              0.2119973945219809, 0.3401530814267192, 0.9353843100447624], 
             UndirectedEdge[217, 278] -> 
             RGBColor[
              0.20033411359999898`, 0.32789423368299453`, 0.9347201034505334],
              UndirectedEdge[228, 264] -> 
             RGBColor[
              0.3612335072093944, 0.48614499734720384`, 0.9442808957993838], 
             UndirectedEdge[121, 239] -> 
             RGBColor[
              0.2315127682951095, 0.3606649766084402, 0.9364956817107337], 
             UndirectedEdge[56, 84] -> 
             RGBColor[
              0.1934123059271604, 0.32061897495088687`, 0.9343259167434621], 
             UndirectedEdge[45, 120] -> 
             RGBColor[
              0.2895125289687292, 0.4216264024736376, 0.9397986822781397], 
             UndirectedEdge[67, 234] -> 
             RGBColor[
              0.18654108215101917`, 0.31339688310141245`, 0.9339346107144755],
              UndirectedEdge[153, 192] -> 
             RGBColor[
              0.2758432306623323, 0.4052369526728678, 0.9390942768006172], 
             UndirectedEdge[77, 127] -> 
             RGBColor[
              0.3813089695721926, 0.5046923971225378, 0.9455176482562255], 
             UndirectedEdge[36, 152] -> 
             RGBColor[
              0.18192632080115292`, 0.3085464763299341, 0.9336718068825283], 
             UndirectedEdge[22, 122] -> 
             RGBColor[
              0.18679089642314464`, 0.31365945374055604`, 0.9339488372677058],
              UndirectedEdge[68, 218] -> 
             RGBColor[
              0.9220230883129681, 0.9398481441591451, 0.964270119789284], 
             UndirectedEdge[56, 148] -> 
             RGBColor[
              0.2228269723814797, 0.3515356543919468, 0.936001038482936], 
             UndirectedEdge[7, 130] -> 
             RGBColor[
              0.92506143421404, 0.8207777707366587, 0.6185929179813181], 
             UndirectedEdge[58, 296] -> 
             RGBColor[
              0.18917402722894824`, 0.3161642753166758, 0.9340845530415703], 
             UndirectedEdge[104, 116] -> 
             RGBColor[
              0.3112198168736299, 0.4420066574870038, 0.9411240550973782], 
             UndirectedEdge[252, 279] -> 
             RGBColor[
              0.23730450403035436`, 0.36675245808343765`, 0.9368255124927507],
              UndirectedEdge[64, 173] -> 
             RGBColor[
              0.21829574180286104`, 0.34677304375720647`, 0.9357429916048386],
              UndirectedEdge[109, 155] -> 
             RGBColor[
              0.9595624996907148, 0.8684305979471943, 0.514184885580798], 
             UndirectedEdge[151, 258] -> 
             RGBColor[
              0.4689947888884989, 0.5767176597098022, 0.9521890651333698], 
             UndirectedEdge[167, 216] -> 
             RGBColor[
              0.8870728705076437, 0.5791108855648315, 0.22743169222500162`], 
             UndirectedEdge[12, 258] -> 
             RGBColor[
              0.3848908244823526, 0.507794819816456, 0.9457458808837911], 
             UndirectedEdge[151, 239] -> 
             RGBColor[
              0.41770207455751684`, 0.5257103442374987, 0.9491616700514242], 
             UndirectedEdge[136, 226] -> 
             RGBColor[
              0.6894363159019072, 0.7515352642002422, 0.911828216152313], 
             UndirectedEdge[59, 210] -> 
             RGBColor[
              0.7283433684413259, 0.785018817714684, 0.9248382115325371], 
             UndirectedEdge[191, 205] -> 
             RGBColor[
              0.29986821230051, 0.4266293598594382, 0.9406037744698572], 
             UndirectedEdge[212, 276] -> 
             RGBColor[
              0.23737124141047264`, 0.3668226033013362, 0.9368293130878194], 
             UndirectedEdge[218, 292] -> 
             RGBColor[
              0.8704525733936984, 0.8991011858444631, 0.9592520377831382], 
             UndirectedEdge[144, 245] -> 
             RGBColor[
              0.2114412038308669, 0.3395684897458317, 0.9353526358077138], 
             UndirectedEdge[1, 277] -> 
             RGBColor[
              0.9058522963240394, 0.5660756214140101, 0.3231115936678419], 
             UndirectedEdge[64, 239] -> 
             RGBColor[
              0.23644031537818827`, 0.3658441410172859, 0.9367762982274624], 
             UndirectedEdge[128, 256] -> 
             RGBColor[
              0.8314341794329242, 0.2426224544325225, 0.1777347117657832], 
             UndirectedEdge[7, 81] -> 
             RGBColor[
              0.9138922902616244, 0.7722436147323656, 0.6093859995388808], 
             UndirectedEdge[32, 145] -> 
             RGBColor[
              0.9262900127477325, 0.9421433350511439, 0.920438952214905], 
             UndirectedEdge[84, 247] -> 
             RGBColor[
              0.1926121673846783, 0.3197779786110244, 0.9342803500371666], 
             UndirectedEdge[215, 259] -> 
             RGBColor[
              0.20495150510474192`, 0.33274740491400967`, 0.9349830570659099],
              UndirectedEdge[187, 233] -> 
             RGBColor[
              0.2150678926487934, 0.3433803696388245, 0.9355591703706895], 
             UndirectedEdge[37, 152] -> 
             RGBColor[
              0.20454390254542953`, 0.33231898878067745`, 0.9349598447031511],
              UndirectedEdge[257, 300] -> 
             RGBColor[
              0.20486085687830097`, 0.33265212788059073`, 0.9349778947835161],
              UndirectedEdge[10, 244] -> 
             RGBColor[
              0.1899533548754444, 0.3169833980853699, 0.9341289345981263], 
             UndirectedEdge[98, 157] -> 
             RGBColor[
              0.18079506708635712`, 0.3073574569500555, 0.9336073836570105], 
             UndirectedEdge[13, 271] -> 
             RGBColor[
              0.2779619784734704, 0.40721689761763513`, 0.9392239799901998], 
             UndirectedEdge[202, 203] -> 
             RGBColor[
              0.9018479137485027, 0.71981963766744, 0.6008453442170419], 
             UndirectedEdge[166, 195] -> 
             RGBColor[
              0.184909234384039, 0.31168170763319203`, 0.9338416793982484], 
             UndirectedEdge[260, 287] -> 
             RGBColor[
              0.25058425907026255`, 0.38071032261548143`, 0.9375817748966364],
              UndirectedEdge[212, 214] -> 
             RGBColor[
              0.21709951040225656`, 0.3455157287097197, 0.9356748679962401], 
             UndirectedEdge[25, 113] -> 
             RGBColor[
              0.22937411863723062`, 0.3584171202197894, 0.9363738887765662], 
             UndirectedEdge[244, 280] -> 
             RGBColor[
              0.22575834254074034`, 0.3546167102889326, 0.9361679756769326], 
             UndirectedEdge[58, 134] -> 
             RGBColor[
              0.21796998739019388`, 0.34643065521547056`, 0.9357244403729478],
              UndirectedEdge[64, 263] -> 
             RGBColor[
              0.22259690617654707`, 0.3512938402235227, 0.9359879365529176], 
             UndirectedEdge[182, 261] -> 
             RGBColor[
              0.24954002688104543`, 0.37961276837646946`, 0.9375223074182637],
              UndirectedEdge[150, 277] -> 
             RGBColor[
              0.9502103007628988, 0.8290380865568148, 0.362523350207251], 
             UndirectedEdge[86, 202] -> 
             RGBColor[
              0.7303739014473327, 0.5842147173946636, 0.5857853158660629], 
             UndirectedEdge[257, 267] -> 
             RGBColor[
              0.19014093188722048`, 0.31718055341781604`, 0.9341396168314517],
              UndirectedEdge[134, 245] -> 
             RGBColor[
              0.2350207777833922, 0.3643521170012733, 0.9366954576614566], 
             UndirectedEdge[187, 297] -> 
             RGBColor[
              0.20836666181027574`, 0.33633695114496726`, 0.9351775451880184],
              UndirectedEdge[75, 292] -> 
             RGBColor[
              0.5533224742847231, 0.6429700886267707, 0.9602576695267473], 
             UndirectedEdge[54, 174] -> 
             RGBColor[
              0.23862082785776215`, 0.3681359978857943, 0.936900475187395], 
             UndirectedEdge[44, 108] -> 
             RGBColor[
              0.27845239042381165`, 0.4093105366510138, 0.9391941231422369], 
             UndirectedEdge[94, 141] -> 
             RGBColor[
              0.5453682927010454, 0.6337189411498153, 0.9602178278094844], 
             UndirectedEdge[185, 262] -> 
             RGBColor[
              0.41669813660407123`, 0.5328210539055609, 0.9483611851595068], 
             UndirectedEdge[40, 202] -> 
             RGBColor[
              0.777902189496511, 0.6220822630055047, 0.5900178581775892], 
             UndirectedEdge[110, 191] -> 
             RGBColor[
              0.20664696570435293`, 0.3345294415026117, 0.9350796110388486], 
             UndirectedEdge[92, 125] -> 
             RGBColor[
              0.8333745807247173, 0.2575372290505118, 0.17959284223417404`], 
             UndirectedEdge[72, 226] -> 
             RGBColor[
              0.9078362964581086, 0.6078453255228189, 0.5266099612338768], 
             UndirectedEdge[130, 162] -> 
             RGBColor[
              0.9515757296113414, 0.8393631712246421, 0.5204689724050278], 
             UndirectedEdge[29, 43] -> 
             RGBColor[
              0.21042089134742065`, 0.3384960766341818, 0.9352945305211986], 
             UndirectedEdge[152, 268] -> 
             RGBColor[
              0.1937845276020504, 0.3210102035314135, 0.9343471142171944], 
             UndirectedEdge[4, 62] -> 
             RGBColor[
              0.21110734445904222`, 0.33921758237813715`, 0.9353336230103891],
              UndirectedEdge[18, 184] -> 
             RGBColor[
              0.19573226525779447`, 0.3230573993013006, 0.9344580349952694], 
             UndirectedEdge[95, 159] -> 
             RGBColor[
              0.2893985943419117, 0.4215066499569798, 0.9397921938696936], 
             UndirectedEdge[154, 255] -> 
             RGBColor[
              0.43165774296703474`, 0.5471078244024314, 0.9490557746765065], 
             UndirectedEdge[140, 269] -> 
             RGBColor[
              0.8952419489497732, 0.5276340204064351, 0.25723456251694715`], 
             UndirectedEdge[10, 161] -> 
             RGBColor[
              0.19602879349749167`, 0.3233690692821986, 0.9344749218398459], 
             UndirectedEdge[216, 293] -> 
             RGBColor[
              0.8831112421654739, 0.5621172753839567, 0.2241774940682837], 
             UndirectedEdge[188, 294] -> 
             RGBColor[
              0.445956916802145, 0.5584408477111231, 0.9502576320388609], 
             UndirectedEdge[32, 282] -> 
             RGBColor[
              0.7141541547436409, 0.7726234711925095, 0.9015995382329896], 
             UndirectedEdge[251, 282] -> 
             RGBColor[
              0.363119718775744, 0.4867984505328162, 0.944436976695407], 
             UndirectedEdge[181, 299] -> 
             RGBColor[
              0.9024939314125389, 0.5550617691490322, 0.28339483620290606`], 
             UndirectedEdge[60, 159] -> 
             RGBColor[
              0.28925410608148494`, 0.42135478363418655`, 0.9397839654770135],
              UndirectedEdge[137, 217] -> 
             RGBColor[
              0.23078620352350526`, 0.3599013109666169, 0.9364543049218471], 
             UndirectedEdge[20, 152] -> 
             RGBColor[
              0.20076184690853469`, 0.3283438085101236, 0.9347444622296798], 
             UndirectedEdge[62, 196] -> 
             RGBColor[
              0.2023683700722644, 0.33003236621465526`, 0.9348359513472162], 
             UndirectedEdge[251, 289] -> 
             RGBColor[
              0.26452594049436573`, 0.3953639137458709, 0.9383757330288698], 
             UndirectedEdge[104, 283] -> 
             RGBColor[
              0.32045429654903324`, 0.4517126811256811, 0.9416499450537039], 
             UndirectedEdge[45, 294] -> 
             RGBColor[
              0.4179920843483252, 0.5334044550653643, 0.9485055663485399], 
             UndirectedEdge[15, 158] -> 
             RGBColor[
              0.22566086224390924`, 0.3545142523163553, 0.9361624243182372], 
             UndirectedEdge[150, 237] -> 
             RGBColor[
              0.8662420388840522, 0.43217832029940567`, 0.20800123867959472`],
              UndirectedEdge[169, 228] -> 
             RGBColor[
              0.5154980125146456, 0.6168087674389304, 0.9552040569175313], 
             UndirectedEdge[159, 251] -> 
             RGBColor[
              0.2884240455436301, 0.4204823373800232, 0.9397366947573472], 
             UndirectedEdge[203, 293] -> 
             RGBColor[
              0.9184419291701429, 0.7951691860663403, 0.6146917974413972], 
             UndirectedEdge[145, 282] -> 
             RGBColor[
              0.6527680048201097, 0.7255950154401895, 0.9681370826346918], 
             UndirectedEdge[195, 234] -> 
             RGBColor[
              0.18893962070800485`, 0.3159178992009325, 0.934071203936976], 
             UndirectedEdge[156, 270] -> 
             RGBColor[
              0.3036653348674415, 0.42857413928414156`, 0.9408949377483093], 
             UndirectedEdge[25, 134] -> 
             RGBColor[
              0.21795734402989536`, 0.34641736624216146`, 0.935723720352283], 
             UndirectedEdge[158, 276] -> 
             RGBColor[
              0.21715975035837445`, 0.34557904472303347`, 0.935678298572624], 
             UndirectedEdge[268, 280] -> 
             RGBColor[
              0.23353122209160865`, 0.3627864995259231, 0.9366106296684096], 
             UndirectedEdge[8, 186] -> 
             RGBColor[
              0.19879211006828354`, 0.3262734902024908, 0.934632288630592], 
             UndirectedEdge[32, 256] -> 
             RGBColor[
              0.9028021334843555, 0.5639903166724234, 0.5093513433881616], 
             UndirectedEdge[60, 168] -> 
             RGBColor[
              0.3438394161380286, 0.4702523109805432, 0.9432028328564219], 
             UndirectedEdge[162, 216] -> 
             RGBColor[
              0.9289059974124116, 0.7386075300235558, 0.5016656812244851], 
             UndirectedEdge[106, 115] -> 
             RGBColor[
              0.6067946716231568, 0.6858798777418896, 0.9651595250499304], 
             UndirectedEdge[77, 276] -> 
             RGBColor[
              0.3275782701356497, 0.45192455001443343`, 0.9423220503837988], 
             UndirectedEdge[80, 281] -> 
             RGBColor[
              0.9786349916305042, 0.9618175926615335, 0.6467591064594813], 
             UndirectedEdge[130, 293] -> 
             RGBColor[
              0.9057809743644036, 0.6628729165850431, 0.24298078524882644`], 
             UndirectedEdge[39, 118] -> 
             RGBColor[
              0.19522260799965463`, 0.322521717208859, 0.9344290107683887], 
             UndirectedEdge[58, 245] -> 
             RGBColor[
              0.20819170713916685`, 0.33615306269286493`, 0.9351675817783212],
              UndirectedEdge[54, 143] -> 
             RGBColor[
              0.2754657226956103, 0.40686231846163223`, 0.9389987374412732], 
             UndirectedEdge[239, 258] -> 
             RGBColor[
              0.28886880526886394`, 0.4180452286151569, 0.9398683740473033], 
             UndirectedEdge[184, 222] -> 
             RGBColor[
              0.2064576757790399, 0.33433048578943325`, 0.9350688312576314], 
             UndirectedEdge[143, 298] -> 
             RGBColor[
              0.28351617500257303`, 0.41532385426440727`, 0.9394571987905778],
              UndirectedEdge[203, 269] -> 
             RGBColor[
              0.9551449948812127, 0.9368848088945971, 0.6707830617471834], 
             UndirectedEdge[107, 139] -> 
             RGBColor[
              0.4245992235592372, 0.5421882392946853, 0.9482760649602114], 
             UndirectedEdge[108, 283] -> 
             RGBColor[
              0.2732531217435669, 0.4045367345740317, 0.9388727330903042], 
             UndirectedEdge[173, 186] -> 
             RGBColor[
              0.19720146830174806`, 0.32460162485334904`, 0.9345417039351314],
              UndirectedEdge[164, 296] -> 
             RGBColor[
              0.18458413953272382`, 0.31134001233225567`, 0.9338231657274008],
              UndirectedEdge[11, 116] -> 
             RGBColor[
              0.4095833128093886, 0.5250728013946587, 0.9479805946176828], 
             UndirectedEdge[43, 229] -> 
             RGBColor[
              0.221649468641255, 0.3502980233029215, 0.935933981386891], 
             UndirectedEdge[128, 149] -> 
             RGBColor[
              0.8702220308538466, 0.4824125424483211, 0.2125931493102241], 
             UndirectedEdge[221, 232] -> 
             RGBColor[
              0.18705168190288157`, 0.31393355581451393`, 0.9339636886149794],
              UndirectedEdge[8, 85] -> 
             RGBColor[
              0.21830835870760254`, 0.3467863049240477, 0.9357437101188987], 
             UndirectedEdge[20, 41] -> 
             RGBColor[
              0.20379941702053028`, 0.3315364872908998, 0.9349174473538756], 
             UndirectedEdge[108, 252] -> 
             RGBColor[
              0.23931387407336885`, 0.3688644334000649, 0.9369399431441039], 
             UndirectedEdge[65, 241] -> 
             RGBColor[
              0.6817937974014621, 0.7449457823928316, 0.912446971452788], 
             UndirectedEdge[231, 245] -> 
             RGBColor[
              0.2282116135363889, 0.3571952536517242, 0.9363076858308454], 
             UndirectedEdge[80, 167] -> 
             RGBColor[
              0.9432452158034876, 0.8059374712804274, 0.30837604527604406`], 
             UndirectedEdge[17, 201] -> 
             RGBColor[
              0.7745136164836781, 0.5590600650268467, 0.5810861179764505], 
             UndirectedEdge[57, 223] -> 
             RGBColor[
              0.1805830172649961, 0.30713457914306985`, 0.9335953077333836], 
             UndirectedEdge[162, 202] -> 
             RGBColor[
              0.9289595063027041, 0.738850501397055, 0.5017103303541681], 
             UndirectedEdge[3, 59] -> 
             RGBColor[
              0.9696130276591681, 0.9767225112372966, 0.930252756027731], 
             UndirectedEdge[180, 187] -> 
             RGBColor[
              0.20981238961313842`, 0.3378565027302129, 0.9352598772476289], 
             UndirectedEdge[193, 215] -> 
             RGBColor[
              0.252152731139514, 0.38235888620713765`, 0.9376710970606339], 
             UndirectedEdge[43, 78] -> 
             RGBColor[
              0.20985899682898168`, 0.3379054898691324, 0.9352625314596219], 
             UndirectedEdge[56, 251] -> 
             RGBColor[
              0.2424819913817221, 0.3721943255613833, 0.9371203627380049], 
             UndirectedEdge[261, 284] -> 
             RGBColor[
              0.2428470796826115, 0.3725780565135533, 0.937141153976641], 
             UndirectedEdge[36, 41] -> 
             RGBColor[
              0.18496389091314852`, 0.31173915511071026`, 0.9338447920067241],
              UndirectedEdge[95, 168] -> 
             RGBColor[
              0.3439839043984553, 0.4704041773033365, 0.943211061249102], 
             UndirectedEdge[194, 280] -> 
             RGBColor[
              0.4740092277386598, 0.5736772866128733, 0.9537854496422005], 
             UndirectedEdge[99, 182] -> 
             RGBColor[
              0.22500890422772363`, 0.3538290031048185, 0.9361252962737008], 
             UndirectedEdge[94, 97] -> 
             RGBColor[
              0.622873487370591, 0.7022274882781143, 0.9651059553417796], 
             UndirectedEdge[79, 240] -> 
             RGBColor[
              0.18183565807480434`, 0.3084511840561929, 0.9336666437743861], 
             UndirectedEdge[83, 198] -> 
             RGBColor[
              0.9055718234570376, 0.665970901350738, 0.5685171958085309], 
             UndirectedEdge[69, 213] -> 
             RGBColor[
              0.20497196381527677`, 0.33276890831593897`, 0.934984222159209], 
             UndirectedEdge[214, 286] -> 
             RGBColor[
              0.21086056333637188`, 0.3389581997713838, 0.9353195691905329], 
             UndirectedEdge[277, 293] -> 
             RGBColor[
              0.946384976906248, 0.8125848782402458, 0.35937882583905917`], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.23002654529780098`, 0.3591028620062883, 0.9364110435097069], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.4656160294018773, 0.5758295097005381, 0.9514105681730911], 
             UndirectedEdge[43, 199] -> 
             RGBColor[
              0.21199067610024028`, 0.34014601993949717`, 0.9353839274405833],
              UndirectedEdge[192, 222] -> 
             RGBColor[
              0.2760214326902352, 0.40542425430285495`, 0.93910442514248], 
             UndirectedEdge[130, 202] -> 
             RGBColor[
              0.8891869589427635, 0.5875233681861427, 0.22913433202447103`], 
             UndirectedEdge[4, 265] -> 
             RGBColor[
              0.22162675469537457`, 0.35027414950565383`, 0.9359326878612754],
              UndirectedEdge[121, 173] -> 
             RGBColor[
              0.21336819471978227`, 0.34159387934836083`, 0.9354623750881099],
              UndirectedEdge[53, 107] -> 
             RGBColor[
              0.3121763440598402, 0.43622685441542786`, 0.9414269663560839], 
             UndirectedEdge[172, 238] -> 
             RGBColor[
              0.18901379750666059`, 0.31599586371940025`, 0.9340754281959247],
              UndirectedEdge[210, 211] -> 
             RGBColor[
              0.3712058892361785, 0.49192848437614356`, 0.9451403247792249], 
             UndirectedEdge[180, 221] -> 
             RGBColor[
              0.19054010670567417`, 0.3176001114611562, 0.9341623492468364], 
             UndirectedEdge[196, 212] -> 
             RGBColor[
              0.2182141780704709, 0.3466873151030251, 0.9357383466709418], 
             UndirectedEdge[160, 176] -> 
             RGBColor[
              0.19497852177206426`, 0.3222651671077009, 0.9344151104188206], 
             UndirectedEdge[115, 193] -> 
             RGBColor[
              0.3156462416789386, 0.4451205438424978, 0.9414324679079064], 
             UndirectedEdge[21, 300] -> 
             RGBColor[
              0.2096118710905434, 0.33764574504935696`, 0.9352484580144076], 
             UndirectedEdge[75, 235] -> 
             RGBColor[
              0.3707116092284409, 0.495513496231598, 0.9448423938259995], 
             UndirectedEdge[77, 255] -> 
             RGBColor[
              0.38990028243638014`, 0.512133760513557, 0.9460650791149319], 
             UndirectedEdge[62, 286] -> 
             RGBColor[
              0.21128388043674812`, 0.3394031328837336, 0.935343676473158], 
             UndirectedEdge[46, 225] -> 
             RGBColor[
              0.21615267984960895`, 0.3445205497663627, 0.935620947396977], 
             UndirectedEdge[37, 161] -> 
             RGBColor[
              0.21411146518921928`, 0.3423751037378088, 0.9355047032417743], 
             UndirectedEdge[3, 162] -> 
             RGBColor[
              0.972783323199716, 0.9780335099161923, 0.8777127544589929], 
             UndirectedEdge[107, 274] -> 
             RGBColor[
              0.43576092708699476`, 0.5515917926842843, 0.9490602651560203], 
             UndirectedEdge[6, 147] -> 
             RGBColor[
              0.2119963836374878, 0.34015201892302305`, 0.935384252476386], 
             UndirectedEdge[8, 135] -> 
             RGBColor[
              0.2087723681564475, 0.33676337423806185`, 0.9352006495642442], 
             UndirectedEdge[186, 249] -> 
             RGBColor[
              0.20028634308592377`, 0.3278440238438759, 0.934717382990427], 
             UndirectedEdge[277, 281] -> 
             RGBColor[
              0.9857363810754343, 0.9854586098022267, 0.7010160851792143], 
             UndirectedEdge[256, 277] -> 
             RGBColor[
              0.9054696458162683, 0.5631344019327589, 0.3227451671094582], 
             UndirectedEdge[8, 249] -> 
             RGBColor[
              0.20596246033793864`, 0.3338099829623634, 0.9350406294708662], 
             UndirectedEdge[114, 254] -> 
             RGBColor[
              0.2789569494583814, 0.4096039374484629, 0.9392315319348887], 
             UndirectedEdge[223, 270] -> 
             RGBColor[
              0.19716475878398335`, 0.32456304082266046`, 0.9345396133824015],
              UndirectedEdge[120, 294] -> 
             RGBColor[
              0.40756986398437334`, 0.5224500406559134, 0.9479120363171062], 
             UndirectedEdge[23, 290] -> 
             RGBColor[
              0.9678787961151241, 0.9075534182585008, 0.5509781065817215], 
             UndirectedEdge[7, 293] -> 
             RGBColor[
              0.9190392263270429, 0.795614649307972, 0.6136807291548138], 
             UndirectedEdge[95, 191] -> 
             RGBColor[
              0.2574665501142888, 0.38794404686520834`, 0.9379737111901566], 
             UndirectedEdge[65, 194] -> 
             RGBColor[
              0.5317344651989768, 0.6279967791452647, 0.9573054453238024], 
             UndirectedEdge[94, 188] -> 
             RGBColor[
              0.5763766141360973, 0.661954233683196, 0.9621432156948482], 
             UndirectedEdge[24, 162] -> 
             RGBColor[
              0.9575561451976635, 0.8630735261690534, 0.5252809551641785], 
             UndirectedEdge[34, 84] -> 
             RGBColor[
              0.1855804331499768, 0.3123871800926523, 0.9338799031750189], 
             UndirectedEdge[130, 201] -> 
             RGBColor[
              0.8785836373176991, 0.5188649537574892, 0.21948349310732407`], 
             UndirectedEdge[74, 260] -> 
             RGBColor[
              0.23203447362151203`, 0.3612133219845175, 0.9365253920572785], 
             UndirectedEdge[69, 85] -> 
             RGBColor[
              0.21985867650040533`, 0.3484157872201088, 0.9358319984237091], 
             UndirectedEdge[220, 262] -> 
             RGBColor[
              0.318464636651424, 0.44980618598534605`, 0.9415298717668166], 
             UndirectedEdge[26, 262] -> 
             RGBColor[
              0.26646771810795733`, 0.39740484513356716`, 0.9384863143913613],
              UndirectedEdge[217, 270] -> 
             RGBColor[
              0.20643869531729672`, 0.3343105361207104, 0.9350677503484142], 
             UndirectedEdge[221, 245] -> 
             RGBColor[
              0.20571905261194073`, 0.33355414600939837`, 0.93502676776096], 
             UndirectedEdge[3, 24] -> 
             RGBColor[
              0.9389911914260977, 0.8504167316496911, 0.6099487388884464], 
             UndirectedEdge[59, 197] -> 
             RGBColor[
              0.9856746989571257, 0.9883441341223966, 0.8870708411785275], 
             UndirectedEdge[54, 235] -> 
             RGBColor[
              0.32626536687632174`, 0.4510335953926109, 0.9422293781681247], 
             UndirectedEdge[159, 282] -> 
             RGBColor[
              0.36593647358390397`, 0.4897590384287621, 0.9445973867147164], 
             UndirectedEdge[6, 53] -> 
             RGBColor[
              0.21323620369391516`, 0.3414551484114601, 0.9354548583944501], 
             UndirectedEdge[31, 210] -> 
             RGBColor[
              0.4456637990054052, 0.5599347702274033, 0.949756030710805], 
             UndirectedEdge[137, 273] -> 
             RGBColor[
              0.25023215692458567`, 0.3803402409358096, 0.9375617232003286], 
             UndirectedEdge[99, 259] -> 
             RGBColor[
              0.19041774683741108`, 0.3174715034815479, 0.934155381033354], 
             UndirectedEdge[16, 151] -> 
             RGBColor[
              0.42230921801132515`, 0.5305527441172178, 0.9494240400554605], 
             UndirectedEdge[24, 227] -> 
             RGBColor[
              0.9382342504393061, 0.7928264157474236, 0.2691600319562284], 
             UndirectedEdge[87, 202] -> 
             RGBColor[
              0.9298593928281911, 0.7373816975657997, 0.35298070205443455`], 
             UndirectedEdge[17, 94] -> 
             RGBColor[
              0.7502759773076164, 0.8048405628721153, 0.9757441557565323], 
             UndirectedEdge[5, 92] -> 
             RGBColor[
              0.9012836886352362, 0.5787149390499657, 0.259870153785709], 
             UndirectedEdge[72, 290] -> 
             RGBColor[
              0.8879131967834442, 0.526174959102152, 0.22577038316322898`], 
             UndirectedEdge[103, 212] -> 
             RGBColor[
              0.327349136755672, 0.45098594966848016`, 0.9423345502314089], 
             UndirectedEdge[112, 133] -> 
             RGBColor[
              0.18726032665159403`, 0.3141528546742519, 0.9339755706247563], 
             UndirectedEdge[71, 244] -> 
             RGBColor[
              0.20641030875985014`, 0.33428070004902233`, 0.9350661337759618],
              UndirectedEdge[142, 197] -> 
             RGBColor[
              0.9081386520820702, 0.6098618084907887, 0.5261581856832962], 
             UndirectedEdge[117, 196] -> 
             RGBColor[
              0.1942847722586868, 0.32153599238288155`, 0.9343756024103442], 
             UndirectedEdge[131, 188] -> 
             RGBColor[
              0.2926361203769149, 0.4205530757547836, 0.9401360760402346], 
             UndirectedEdge[13, 282] -> 
             RGBColor[
              0.38696044305919663`, 0.509587419405664, 0.9458777551494157], 
             UndirectedEdge[139, 143] -> 
             RGBColor[
              0.37380885559171856`, 0.49802499695333824`, 0.9450460153054621],
              UndirectedEdge[45, 89] -> 
             RGBColor[
              0.34033954683031736`, 0.4683920819989782, 0.9429369415722573], 
             UndirectedEdge[127, 269] -> 
             RGBColor[
              0.6610000720463691, 0.698853165460656, 0.646849788175898], 
             UndirectedEdge[25, 79] -> 
             RGBColor[
              0.18712823581077753`, 0.3140140188255107, 0.9339680482467827], 
             UndirectedEdge[29, 78] -> 
             RGBColor[
              0.1946932984138494, 0.3219653792740117, 0.9343988673705204], 
             UndirectedEdge[150, 179] -> 
             RGBColor[
              0.7150830892215184, 0.6470263643951079, 0.5999650595216117], 
             UndirectedEdge[11, 198] -> 
             RGBColor[
              0.7482029346182517, 0.8019514484742061, 0.9505539165512161], 
             UndirectedEdge[135, 286] -> 
             RGBColor[
              0.2169836251808333, 0.34539392599445645`, 0.9356682685043168], 
             UndirectedEdge[101, 104] -> 
             RGBColor[
              0.49120791951509923`, 0.5945373978105576, 0.9540278714950781], 
             UndirectedEdge[3, 290] -> 
             RGBColor[
              0.9503146533364857, 0.8953104848043834, 0.619059862137357], 
             UndirectedEdge[158, 212] -> 
             RGBColor[
              0.21315714444874106`, 0.34137205213213645`, 0.9354503560873951],
              UndirectedEdge[102, 175] -> 
             RGBColor[
              0.18740197098760464`, 0.3143017318521686, 0.9339836370601481], 
             UndirectedEdge[103, 255] -> 
             RGBColor[
              0.3936737549660358, 0.5154021527585007, 0.9463055214477708], 
             UndirectedEdge[3, 65] -> 
             RGBColor[
              0.6658408786786703, 0.7333691314923763, 0.9538265746888542], 
             UndirectedEdge[148, 270] -> 
             RGBColor[
              0.22956819937889494`, 0.35862111138470837`, 0.9363849413876872],
              UndirectedEdge[49, 298] -> 
             RGBColor[
              0.23487979924778435`, 0.36420393962179404`, 0.9366874291424127],
              UndirectedEdge[15, 103] -> 
             RGBColor[
              0.33985285455084013`, 0.464128149852699, 0.9430466184622509], 
             UndirectedEdge[4, 15] -> 
             RGBColor[
              0.23945687025241685`, 0.36901473145072583`, 0.9369480865649568],
              UndirectedEdge[83, 290] -> 
             RGBColor[
              0.8964817615318641, 0.5920367025275223, 0.23397565044312565`], 
             UndirectedEdge[182, 284] -> 
             RGBColor[
              0.24765066246750966`, 0.3776269265852207, 0.937414710909977], 
             UndirectedEdge[32, 92] -> 
             RGBColor[
              0.9096154260623872, 0.6163602690310206, 0.515875760055398], 
             UndirectedEdge[87, 203] -> 
             RGBColor[
              0.9651365709425674, 0.970190636874684, 0.7434503562978652], 
             UndirectedEdge[115, 169] -> 
             RGBColor[
              0.47823384946439584`, 0.5845324223560975, 0.9528296173993749], 
             UndirectedEdge[111, 143] -> 
             RGBColor[
              0.46054913753176646`, 0.5687866450741914, 0.9517800380473413], 
             UndirectedEdge[163, 274] -> 
             RGBColor[
              0.5420984734158494, 0.6391389878337358, 0.9570951240808855], 
             UndirectedEdge[96, 260] -> 
             RGBColor[
              0.22955901197049378`, 0.3586114548359634, 0.9363844181783704], 
             UndirectedEdge[27, 227] -> 
             RGBColor[
              0.9612729955532987, 0.8800632676191081, 0.309071745135731], 
             UndirectedEdge[103, 205] -> 
             RGBColor[
              0.39684467535749024`, 0.5181486446264856, 0.9465075696911796], 
             UndirectedEdge[27, 216] -> 
             RGBColor[
              0.9181526107527858, 0.6982276036287391, 0.27381337883344126`], 
             UndirectedEdge[145, 293] -> 
             RGBColor[
              0.8823313146508039, 0.7664123372275902, 0.6125225465194646], 
             UndirectedEdge[96, 133] -> 
             RGBColor[
              0.19311989172231955`, 0.3203116290814677, 0.9343092641870845], 
             UndirectedEdge[127, 159] -> 
             RGBColor[
              0.3200380232724909, 0.45000410769220556`, 0.9416727780472791], 
             UndirectedEdge[186, 214] -> 
             RGBColor[
              0.19697318905997124`, 0.32436168889650174`, 0.9345287037700212],
              UndirectedEdge[111, 262] -> 
             RGBColor[
              0.459021775002635, 0.5671812902156966, 0.9516930570108376], 
             UndirectedEdge[33, 157] -> 
             RGBColor[
              0.19152225944429985`, 0.31863241626153205`, 0.9342182813923363],
              UndirectedEdge[112, 131] -> 
             RGBColor[
              0.20931958090363292`, 0.3373385295306458, 0.9352318125206677], 
             UndirectedEdge[37, 55] -> 
             RGBColor[
              0.21435260419714997`, 0.34262855612424004`, 0.9355184357515427],
              UndirectedEdge[20, 71] -> 
             RGBColor[
              0.22116050761720274`, 0.349784094264723, 0.9359061357799242], 
             UndirectedEdge[37, 252] -> 
             RGBColor[
              0.23225528127463596`, 0.3614454048279645, 0.9365379667264683], 
             UndirectedEdge[120, 178] -> 
             RGBColor[
              0.2690508208241996, 0.4001198498665095, 0.9386334182696933], 
             UndirectedEdge[113, 231] -> 
             RGBColor[
              0.24940666839475117`, 0.3794726001519578, 0.9375147128497554], 
             UndirectedEdge[7, 181] -> 
             RGBColor[
              0.962306825108859, 0.9594739836095195, 0.6952739648323978], 
             UndirectedEdge[42, 299] -> 
             RGBColor[
              0.8281493166036277, 0.217373559290479, 0.1745891234107269], 
             UndirectedEdge[64, 234] -> 
             RGBColor[
              0.2147298520602665, 0.3430250675472716, 0.9355399194592591], 
             UndirectedEdge[78, 261] -> 
             RGBColor[
              0.21943392399577888`, 0.3479693454068822, 0.9358078093969358], 
             UndirectedEdge[10, 100] -> 
             RGBColor[
              0.18553288790448116`, 0.3123372070250937, 0.9338771955436248], 
             UndirectedEdge[6, 88] -> 
             RGBColor[
              0.21672673573205908`, 0.345123918896063, 0.935653639030243], 
             UndirectedEdge[36, 208] -> 
             RGBColor[
              0.1853248284213402, 0.31211852331657947`, 0.9338653468638564], 
             UndirectedEdge[92, 142] -> 
             RGBColor[
              0.830745140796793, 0.23732620153656223`, 0.1770748875896661], 
             UndirectedEdge[237, 293] -> 
             RGBColor[
              0.8624167150274014, 0.41572511198283674`, 0.2048567143114029], 
             UndirectedEdge[127, 145] -> 
             RGBColor[
              0.6068695545086966, 0.6858400847036329, 0.9652124739672545], 
             UndirectedEdge[90, 285] -> 
             RGBColor[
              0.20767787323688183`, 0.3356129906826123, 0.9351383196977351], 
             UndirectedEdge[134, 176] -> 
             RGBColor[
              0.21949584805110617`, 0.34803443151524305`, 0.9358113358802782],
              UndirectedEdge[28, 297] -> 
             RGBColor[
              0.18773159769962583`, 0.31464819042604353`, 0.9340024088137586],
              UndirectedEdge[20, 136] -> 
             RGBColor[
              0.3058098324986471, 0.43100159391667037`, 0.9410107128012115], 
             UndirectedEdge[113, 134] -> 
             RGBColor[
              0.25621583264175446`, 0.38662946350150684`, 0.9379024846803665],
              UndirectedEdge[12, 181] -> 
             RGBColor[
              0.707957046702949, 0.7559827796524516, 0.6749255302079116], 
             UndirectedEdge[84, 217] -> 
             RGBColor[
              0.19375308221906778`, 0.32097715244014635`, 0.9343453234491528],
              UndirectedEdge[126, 153] -> 
             RGBColor[
              0.2222787641449363, 0.35095945277692997`, 0.9359698188348664], 
             UndirectedEdge[217, 251] -> 
             RGBColor[
              0.24282276767362948`, 0.3725525030506428, 0.9371397694436958], 
             UndirectedEdge[211, 266] -> 
             RGBColor[
              0.23444123912717205`, 0.36374298512871284`, 0.9366624537923354],
              UndirectedEdge[156, 282] -> 
             RGBColor[
              0.41756183526404816`, 0.5360928072628128, 0.9478276488009602], 
             UndirectedEdge[92, 256] -> 
             RGBColor[
              0.8247413968754788, 0.1911787948999799, 0.17132569563035674`], 
             UndirectedEdge[56, 246] -> 
             RGBColor[
              0.1919032518459413, 0.3190328634319706, 0.934239978345982], 
             UndirectedEdge[223, 246] -> 
             RGBColor[
              0.1829700916045353, 0.3096435456231802, 0.9337312480856603], 
             UndirectedEdge[66, 228] -> 
             RGBColor[
              0.40629940527691566`, 0.5263378564741489, 0.9471100167211559], 
             UndirectedEdge[170, 261] -> 
             RGBColor[
              0.22115645505495063`, 0.3497798347648488, 0.9359059049924991], 
             UndirectedEdge[104, 287] -> 
             RGBColor[
              0.2890443879522816, 0.41869887568726627`, 0.9398611972259145], 
             UndirectedEdge[255, 258] -> 
             RGBColor[
              0.3530896957607064, 0.48025028048897034`, 0.9437195410822816], 
             UndirectedEdge[27, 162] -> 
             RGBColor[
              0.9805948903116561, 0.9503103780407378, 0.565192668343681], 
             UndirectedEdge[162, 169] -> 
             RGBColor[
              0.7980436197485294, 0.8403418316253028, 0.877535691789008], 
             UndirectedEdge[90, 166] -> 
             RGBColor[
              0.20088523531551122`, 0.3284734975491328, 0.9347514890169203], 
             UndirectedEdge[74, 257] -> 
             RGBColor[
              0.19498858899920085`, 0.3222757484017205, 0.9344156837325129], 
             UndirectedEdge[82, 203] -> 
             RGBColor[
              0.7752823706628642, 0.824842772704185, 0.9770131806255582], 
             UndirectedEdge[1, 142] -> 
             RGBColor[
              0.8243144987265323, 0.1878974686592162, 0.17091689748081318`], 
             UndirectedEdge[82, 145] -> 
             RGBColor[
              0.7391717561435251, 0.7960859238654349, 0.9748439297036255], 
             UndirectedEdge[77, 203] -> 
             RGBColor[
              0.6754538924070363, 0.7427240405564789, 0.9694509218275109], 
             UndirectedEdge[12, 27] -> 
             RGBColor[
              0.6997308165084448, 0.7282337735956864, 0.6429681792954851], 
             UndirectedEdge[54, 185] -> 
             RGBColor[
              0.3867966632124244, 0.5013927095080272, 0.9466583404851183], 
             UndirectedEdge[35, 165] -> 
             RGBColor[
              0.2120938524489715, 0.3402544648237721, 0.9353898031810077], 
             UndirectedEdge[60, 95] -> 
             RGBColor[
              0.28741190007160666`, 0.4194185083151971, 0.9396790545700505], 
             UndirectedEdge[47, 112] -> 
             RGBColor[
              0.18666547155784385`, 0.31352762425472913`, 0.9339416945071765],
              UndirectedEdge[24, 59] -> 
             RGBColor[
              0.9543858496571156, 0.8617625274901577, 0.5778209567329167], 
             UndirectedEdge[239, 285] -> 
             RGBColor[
              0.21862787921736482`, 0.3471221412385783, 0.9357619063392415], 
             UndirectedEdge[173, 286] -> 
             RGBColor[
              0.2110888425781487, 0.3391981357282311, 0.9353325693556434], 
             UndirectedEdge[17, 40] -> 
             RGBColor[
              0.6964483919711273, 0.7627900441024493, 0.9703791250975754], 
             UndirectedEdge[226, 241] -> 
             RGBColor[
              0.9861906717339419, 0.9885575021255057, 0.8785198369719385], 
             UndirectedEdge[255, 286] -> 
             RGBColor[
              0.2934543066453184, 0.4204742848621239, 0.9402170430132455], 
             UndirectedEdge[95, 271] -> 
             RGBColor[
              0.25509580298829937`, 0.3854522413217438, 0.9378387006485376], 
             UndirectedEdge[189, 260] -> 
             RGBColor[
              0.23700170640282697`, 0.36643419857842796`, 0.936808268615812], 
             UndirectedEdge[193, 245] -> 
             RGBColor[
              0.2524031222436139, 0.38262206313325964`, 0.9376853564635919], 
             UndirectedEdge[84, 223] -> 
             RGBColor[
              0.1844791456857544, 0.31122965714209644`, 0.9338171864831403], 
             UndirectedEdge[44, 61] -> 
             RGBColor[
              0.29673927658547317`, 0.4285312134624696, 0.9402355342561197], 
             UndirectedEdge[262, 292] -> 
             RGBColor[
              0.5387777053242508, 0.6299185321853173, 0.9593474985432611], 
             UndirectedEdge[153, 248] -> 
             RGBColor[
              0.2215139470361167, 0.3501555815033551, 0.9359262636319645], 
             UndirectedEdge[78, 99] -> 
             RGBColor[
              0.19490280134245708`, 0.32218558013523124`, 0.9344107982523728],
              UndirectedEdge[199, 261] -> 
             RGBColor[
              0.22156560326703745`, 0.35020987547724697`, 0.9359292053778969],
              UndirectedEdge[58, 215] -> 
             RGBColor[
              0.20794131603506694`, 0.33588988576674306`, 0.935153322375363], 
             UndirectedEdge[23, 197] -> 
             RGBColor[
              0.9878441835047461, 0.9892412717360475, 0.8511168677784218], 
             UndirectedEdge[196, 214] -> 
             RGBColor[
              0.20194505297188817`, 0.32958743310230554`, 0.9348118440645912],
              UndirectedEdge[88, 289] -> 
             RGBColor[
              0.23315152394890182`, 0.3623874127036856, 0.9365890064208955], 
             UndirectedEdge[47, 96] -> 
             RGBColor[
              0.19252503662856937`, 0.3196863986619449, 0.9342753880695046], 
             UndirectedEdge[179, 205] -> 
             RGBColor[
              0.44755823847840226`, 0.5601887588135859, 0.9502599417033248], 
             UndirectedEdge[72, 194] -> 
             RGBColor[
              0.7577104993954153, 0.4908688373474871, 0.5725699298440808], 
             UndirectedEdge[140, 299] -> 
             RGBColor[
              0.8180064493920196, 0.1394110372693064, 0.16487630231416095`], 
             UndirectedEdge[134, 297] -> 
             RGBColor[
              0.21839610407426302`, 0.3468785308677854, 0.9357487070877224], 
             UndirectedEdge[67, 195] -> 
             RGBColor[
              0.18132553855698572`, 0.30791501609952, 0.9336375932225005], 
             UndirectedEdge[24, 155] -> 
             RGBColor[
              0.9250389254998768, 0.7405113494439601, 0.2585427637758789], 
             UndirectedEdge[156, 277] -> 
             RGBColor[
              0.6937513555235839, 0.7517852121341029, 0.7135233421024703], 
             UndirectedEdge[267, 272] -> 
             RGBColor[
              0.18764714248222777`, 0.31455942263778813`, 0.9339975992140681],
              UndirectedEdge[71, 177] -> 
             RGBColor[
              0.2576442825267533, 0.3881308548995943, 0.9379838327881149], 
             UndirectedEdge[188, 281] -> 
             RGBColor[
              0.66716299452805, 0.7330554302274623, 0.9326197293964239], 
             UndirectedEdge[1, 150] -> 
             RGBColor[
              0.8630514097518487, 0.4076537466466897, 0.20494588861929658`], 
             UndirectedEdge[84, 246] -> 
             RGBColor[
              0.1859588657451276, 0.3127849367441682, 0.9339014543514719], 
             UndirectedEdge[58, 230] -> 
             RGBColor[
              0.19161321755920613`, 0.31872801900737613`, 0.9342234613224198],
              UndirectedEdge[74, 189] -> 
             RGBColor[
              0.21086862151855923`, 0.33896666943178094`, 0.9353200280920875],
              UndirectedEdge[48, 71] -> 
             RGBColor[
              0.2080633650262977, 0.3360181669948795, 0.9351602728848583], 
             UndirectedEdge[80, 205] -> 
             RGBColor[
              0.6755840605748524, 0.7185594638345996, 0.6585612536692309], 
             UndirectedEdge[1, 32] -> 
             RGBColor[
              0.9031847839921265, 0.5669315361536746, 0.5097177699465452], 
             UndirectedEdge[229, 233] -> 
             RGBColor[
              0.2115539796555496, 0.3396870242879735, 0.9353590582240927], 
             UndirectedEdge[54, 172] -> 
             RGBColor[
              0.21731047913351847`, 0.34573747022246615`, 0.935686882353385], 
             UndirectedEdge[61, 194] -> 
             RGBColor[
              0.4816323907254858, 0.581689714248477, 0.9542195774968412], 
             UndirectedEdge[177, 194] -> 
             RGBColor[
              0.4889886310377472, 0.5894215892292383, 0.9546385045000421], 
             UndirectedEdge[7, 42] -> 
             RGBColor[
              0.8879622102999478, 0.6217857737509664, 0.5864682520402187], 
             UndirectedEdge[26, 75] -> 
             RGBColor[
              0.28101248706842963`, 0.4104564015750206, 0.9393964853748475], 
             UndirectedEdge[170, 190] -> 
             RGBColor[
              0.2009954787857768, 0.3285893704262217, 0.9347577672194614], 
             UndirectedEdge[20, 36] -> 
             RGBColor[
              0.200168643680248, 0.32772031430593734`, 0.9347106801833944], 
             UndirectedEdge[119, 161] -> 
             RGBColor[
              0.191253116488521, 0.3183495299503595, 0.9342029540991661], 
             UndirectedEdge[212, 225] -> 
             RGBColor[
              0.23048263283804543`, 0.3595822389287055, 0.9364370170204028], 
             UndirectedEdge[102, 253] -> 
             RGBColor[
              0.1920226425007294, 0.3191583505799577, 0.9342467774671497], 
             UndirectedEdge[91, 179] -> 
             RGBColor[
              0.5064577791876668, 0.6102042666643193, 0.9542893580750782], 
             UndirectedEdge[118, 239] -> 
             RGBColor[
              0.213148543369447, 0.34136301185245843`, 0.9354498662686535], 
             UndirectedEdge[105, 298] -> 
             RGBColor[
              0.27198901083979987`, 0.403208073864912, 0.938800743844419], 
             UndirectedEdge[90, 239] -> 
             RGBColor[
              0.2266260849573989, 0.3555287625868876, 0.9362173923238513], 
             UndirectedEdge[208, 252] -> 
             RGBColor[
              0.21362941037883332`, 0.3418684335680528, 0.935477250933459], 
             UndirectedEdge[117, 214] -> 
             RGBColor[
              0.19317010459047246`, 0.32036440598957616`, 0.9343121237356424],
              UndirectedEdge[179, 282] -> 
             RGBColor[
              0.48169445553417334`, 0.5897558342911382, 0.9524350712686471], 
             UndirectedEdge[44, 268] -> 
             RGBColor[
              0.2606344226816996, 0.39058272282964934`, 0.9381794162386446], 
             UndirectedEdge[53, 124] -> 
             RGBColor[
              0.20090092998575032`, 0.32848999364265374`, 0.9347523828051723],
              UndirectedEdge[42, 81] -> 
             RGBColor[
              0.8635348143848929, 0.4405098850237444, 0.2065613896917941], 
             UndirectedEdge[173, 213] -> 
             RGBColor[
              0.20183100425593847`, 0.3294675606707361, 0.9348053491589379], 
             UndirectedEdge[119, 122] -> 
             RGBColor[
              0.18294597115910344`, 0.30961819350570674`, 0.933729874461976], 
             UndirectedEdge[68, 111] -> 
             RGBColor[
              0.7455301616880299, 0.8011614727150247, 0.9754440364810864], 
             UndirectedEdge[34, 53] -> 
             RGBColor[
              0.1997851700209307, 0.32731725917636056`, 0.9346888419257947], 
             UndirectedEdge[85, 263] -> 
             RGBColor[
              0.22101888131475306`, 0.34963523604122215`, 0.9358980703715171],
              UndirectedEdge[37, 208] -> 
             RGBColor[
              0.20794241016561682`, 0.3358910357673228, 0.9351533846844792], 
             UndirectedEdge[256, 293] -> 
             RGBColor[
              0.8588434353874268, 0.38825931884886955`, 0.2014349376927211], 
             UndirectedEdge[76, 153] -> 
             RGBColor[
              0.27399346070364045`, 0.40363477490679034`, 0.9389764110945367],
              UndirectedEdge[135, 213] -> 
             RGBColor[
              0.20772578685862308`, 0.3356633509369615, 0.9351410483076115], 
             UndirectedEdge[36, 55] -> 
             RGBColor[
              0.19173502245287335`, 0.3188560436734967, 0.9342303979309199], 
             UndirectedEdge[121, 135] -> 
             RGBColor[
              0.21926297732246688`, 0.3477896696145861, 0.9357980742367835], 
             UndirectedEdge[83, 226] -> 
             RGBColor[
              0.9164048612065285, 0.6737070689481892, 0.5348152285137735], 
             UndirectedEdge[60, 127] -> 
             RGBColor[
              0.3180513290021859, 0.44791596605042294`, 0.941559638747636], 
             UndirectedEdge[247, 271] -> 
             RGBColor[
              0.21019581629378764`, 0.33825950848223085`, 0.9352817128298629],
              UndirectedEdge[202, 269] -> 
             RGBColor[
              0.9198678167668363, 0.7040758695857129, 0.2803134075037528], 
             UndirectedEdge[190, 284] -> 
             RGBColor[
              0.22268610341343767`, 0.3513875921749262, 0.9359930162036031], 
             UndirectedEdge[53, 217] -> 
             RGBColor[
              0.2079578190900217, 0.3359072315238546, 0.9351542621999286], 
             UndirectedEdge[42, 87] -> 
             RGBColor[
              0.915376392222736, 0.6389023704076946, 0.3396146781641949], 
             UndirectedEdge[205, 225] -> 
             RGBColor[
              0.29997817143986366`, 0.426744933886711, 0.9406100364801734], 
             UndirectedEdge[110, 246] -> 
             RGBColor[
              0.18518351558803503`, 0.3119699945690246, 0.9338572993070533], 
             UndirectedEdge[191, 251] -> 
             RGBColor[
              0.25649200131600725`, 0.38691973428825177`, 0.9379182120778102],
              UndirectedEdge[23, 83] -> 
             RGBColor[
              0.917949620402167, 0.6743458665740862, 0.5092145709333941], 
             UndirectedEdge[226, 291] -> 
             RGBColor[
              0.956565980138184, 0.9665569141916783, 0.9351528422090618], 
             UndirectedEdge[60, 276] -> 
             RGBColor[
              0.26432062956564295`, 0.39514811894231855`, 0.9383640408752093],
              UndirectedEdge[27, 155] -> 
             RGBColor[
              0.9480776706138694, 0.8277482013156446, 0.2984544769553814], 
             UndirectedEdge[167, 203] -> 
             RGBColor[
              0.9224035575123126, 0.8121627962472151, 0.6179459955981152], 
             UndirectedEdge[137, 271] -> 
             RGBColor[
              0.24208469003989352`, 0.37177673666076144`, 0.9370977370143425],
              UndirectedEdge[52, 247] -> 
             RGBColor[
              0.1982447360653234, 0.3256981654198634, 0.9346011164908907], 
             UndirectedEdge[81, 299] -> 
             RGBColor[
              0.8540793965653044, 0.3678314002718782, 0.19750687090938907`], 
             UndirectedEdge[31, 290] -> 
             RGBColor[
              0.683029742131583, 0.6815722331575694, 0.6118498991600951], 
             UndirectedEdge[79, 288] -> 
             RGBColor[
              0.19600308919068352`, 0.3233420524259961, 0.9344734580175993], 
             UndirectedEdge[237, 281] -> 
             RGBColor[
              0.9017681191965876, 0.5885988435448176, 0.546493973651558], 
             UndirectedEdge[43, 215] -> 
             RGBColor[
              0.22516415254335911`, 0.35399217892786317`, 0.9361341374356069],
              UndirectedEdge[56, 295] -> 
             RGBColor[
              0.19813975131853928`, 0.3255878197945759, 0.9345951377648724], 
             UndirectedEdge[89, 94] -> 
             RGBColor[
              0.5888165791799138, 0.6727291061533267, 0.962935879267211], 
             UndirectedEdge[92, 237] -> 
             RGBColor[
              0.8283146765154534, 0.21864458803394712`, 0.17474747224903853`],
              UndirectedEdge[126, 285] -> 
             RGBColor[
              0.21158401439278246`, 0.3397185927011176, 0.9353607686579457], 
             UndirectedEdge[4, 214] -> 
             RGBColor[
              0.21068402735866598`, 0.33877264926578743`, 0.9353095157277642],
              UndirectedEdge[220, 222] -> 
             RGBColor[
              0.2772575054008418, 0.4064948783579615, 0.9391831866025837], 
             UndirectedEdge[199, 209] -> 
             RGBColor[
              0.1894252090832627, 0.31642828337140966`, 0.9340988574765833], 
             UndirectedEdge[290, 291] -> 
             RGBColor[
              0.9366428804635196, 0.8848865477710113, 0.6343132641384139], 
             UndirectedEdge[91, 150] -> 
             RGBColor[
              0.6987841041568563, 0.6337941140587057, 0.5986819437121721], 
             UndirectedEdge[60, 148] -> 
             RGBColor[
              0.2667823322730826, 0.39773552456880407`, 0.9385042312026353], 
             UndirectedEdge[81, 140] -> 
             RGBColor[
              0.8533919471732848, 0.3625473630025718, 0.19684856859522815`], 
             UndirectedEdge[142, 256] -> 
             RGBColor[
              0.8239318482187612, 0.18495624917796497`, 0.17055047092242953`],
              UndirectedEdge[30, 123] -> 
             RGBColor[
              0.2239498078006626, 0.3527158256093854, 0.9360649822989724], 
             UndirectedEdge[53, 289] -> 
             RGBColor[
              0.22966099191075792`, 0.3587186422190827, 0.9363902257851027], 
             UndirectedEdge[274, 289] -> 
             RGBColor[
              0.3532455749379125, 0.4740835804879391, 0.944023524585039], 
             UndirectedEdge[11, 114] -> 
             RGBColor[
              0.38547343504917886`, 0.49973179121413747`, 0.9466075727466067],
              UndirectedEdge[137, 247] -> 
             RGBColor[
              0.22964528868911577`, 0.358702137137495, 0.9363893315098609], 
             UndirectedEdge[84, 191] -> 
             RGBColor[
              0.2074223158614455, 0.3353443836777553, 0.9351237660832672], 
             UndirectedEdge[17, 120] -> 
             RGBColor[
              0.4913767245940681, 0.5895491243083159, 0.9551516880301447], 
             UndirectedEdge[126, 222] -> 
             RGBColor[
              0.22245696617283922`, 0.3511467544069171, 0.9359799671767292], 
             UndirectedEdge[184, 224] -> 
             RGBColor[
              0.20007875304145373`, 0.32762583354516883`, 0.9347055610444963],
              UndirectedEdge[278, 295] -> 
             RGBColor[
              0.1987763965986568, 0.3262569743496216, 0.9346313937717428], 
             UndirectedEdge[28, 245] -> 
             RGBColor[
              0.204356271408755, 0.33212177655953135`, 0.9349491593874928], 
             UndirectedEdge[14, 186] -> 
             RGBColor[
              0.18665492193544975`, 0.31351653593270823`, 0.9339410937217879],
              UndirectedEdge[227, 241] -> 
             RGBColor[
              0.9694143471641505, 0.9193630503950179, 0.5802122280149764], 
             UndirectedEdge[121, 154] -> 
             RGBColor[
              0.3613735298324199, 0.47852983599420473`, 0.9448593103869043], 
             UndirectedEdge[187, 230] -> 
             RGBColor[
              0.20841284593944426`, 0.3363854935929662, 0.9351801753058513], 
             UndirectedEdge[125, 277] -> 
             RGBColor[
              0.9141028296655067, 0.6294928360832908, 0.33101231371327555`], 
             UndirectedEdge[62, 158] -> 
             RGBColor[
              0.1973113364505346, 0.3247171032437667, 0.9345479607636695], 
             UndirectedEdge[20, 61] -> 
             RGBColor[
              0.248131704384919, 0.378132532140237, 0.9374421055355356], 
             UndirectedEdge[64, 258] -> 
             RGBColor[
              0.28773302970917036`, 0.41685145648958927`, 0.939803693309408], 
             UndirectedEdge[94, 294] -> 
             RGBColor[
              0.6664691166979216, 0.7377414792197128, 0.9685045040434936], 
             UndirectedEdge[125, 237] -> 
             RGBColor[
              0.8301345677866601, 0.23263306982588172`, 0.17649020218561928`],
              UndirectedEdge[267, 300] -> 
             RGBColor[
              0.210925999504364, 0.33902697733283615`, 0.935323295683496], 
             UndirectedEdge[165, 175] -> 
             RGBColor[
              0.2002014223302363, 0.3277547667453615, 0.9347125468790196], 
             UndirectedEdge[67, 263] -> 
             RGBColor[
              0.19440813626729972`, 0.3216656557776636, 0.934382627808134], 
             UndirectedEdge[163, 298] -> 
             RGBColor[
              0.44064408929894633`, 0.5470342917552059, 0.9507221073701924], 
             UndirectedEdge[92, 149] -> 
             RGBColor[
              0.8635292482964012, 0.4309688829157785, 0.2061841331747976], 
             UndirectedEdge[95, 276] -> 
             RGBColor[
              0.2644651178260697, 0.3952999852651118, 0.9383722692678894], 
             UndirectedEdge[70, 231] -> 
             RGBColor[
              0.2204752799716199, 0.3490638765632734, 0.9358671130792118], 
             UndirectedEdge[239, 263] -> 
             RGBColor[
              0.22373268173624067`, 0.3524876123490904, 0.9360526172908128], 
             UndirectedEdge[116, 204] -> 
             RGBColor[
              0.38548007982804805`, 0.5055047110221348, 0.9460830998243401], 
             UndirectedEdge[121, 258] -> 
             RGBColor[
              0.28280548262609156`, 0.41167229208074363`, 0.9395230767926794],
              UndirectedEdge[95, 148] -> 
             RGBColor[
              0.2669268205335093, 0.3978873908915973, 0.9385124595953154], 
             UndirectedEdge[60, 77] -> 
             RGBColor[
              0.3505250523811867, 0.47604307306451876`, 0.9436288356859599], 
             UndirectedEdge[42, 269] -> 
             RGBColor[
              0.9053848161613813, 0.6055965424276077, 0.2669473836135131], 
             UndirectedEdge[61, 136] -> 
             RGBColor[
              0.33493736709593636`, 0.46161647957078045`, 0.9426694828062012],
              UndirectedEdge[95, 251] -> 
             RGBColor[
              0.2865818395337517, 0.41854606206103384`, 0.9396317838503843], 
             UndirectedEdge[158, 265] -> 
             RGBColor[
              0.20783074668686696`, 0.3357736703712833, 0.9351470256145558], 
             UndirectedEdge[152, 208] -> 
             RGBColor[
              0.1859180316496269, 0.31274201752076575`, 0.9338991289101417], 
             UndirectedEdge[153, 285] -> 
             RGBColor[
              0.21037441724900163`, 0.3384472294101154, 0.9352918838900459], 
             UndirectedEdge[61, 279] -> 
             RGBColor[
              0.25696298277753227`, 0.387414765666264, 0.9379450337752894], 
             UndirectedEdge[82, 168] -> 
             RGBColor[
              0.5069255349638632, 0.6091474742003642, 0.9547231011630586], 
             UndirectedEdge[4, 249] -> 
             RGBColor[
              0.21399718138461848`, 0.3422549842131616, 0.93549819494817], 
             UndirectedEdge[75, 163] -> 
             RGBColor[
              0.47703987934410275`, 0.583052656791418, 0.9528766616787626], 
             UndirectedEdge[59, 290] -> 
             RGBColor[
              0.9657093115675036, 0.9066562806448499, 0.5869320799818273], 
             UndirectedEdge[205, 251] -> 
             RGBColor[
              0.3289835017199729, 0.45723137505526373`, 0.9422618471300848], 
             UndirectedEdge[183, 224] -> 
             RGBColor[
              0.2007040206651831, 0.3282830294619655, 0.9347411691106672], 
             UndirectedEdge[170, 178] -> 
             RGBColor[
              0.228293899528688, 0.35728174144686387`, 0.9363123718963757], 
             UndirectedEdge[102, 238] -> 
             RGBColor[
              0.18981943468321613`, 0.3168426394723074, 0.9341213080412961], 
             UndirectedEdge[89, 236] -> 
             RGBColor[
              0.30608763983959875`, 0.4323911560553985, 0.9409863461402914], 
             UndirectedEdge[65, 231] -> 
             RGBColor[
              0.30432205873480145`, 0.4308387652063516, 0.9408746918946544], 
             UndirectedEdge[25, 245] -> 
             RGBColor[
              0.2081790637788683, 0.33613977371955583`, 0.9351668617576563], 
             UndirectedEdge[217, 223] -> 
             RGBColor[
              0.19076430807847547`, 0.31783576131915836`, 0.9341751171833412],
              UndirectedEdge[254, 283] -> 
             RGBColor[
              0.3123013068939945, 0.44465097126766145`, 0.9411304437622906], 
             UndirectedEdge[168, 205] -> 
             RGBColor[
              0.3863855665846765, 0.5090894902975664, 0.9458411245288025], 
             UndirectedEdge[142, 243] -> 
             RGBColor[
              0.9086765502085565, 0.610084243189442, 0.517243821691691], 
             UndirectedEdge[57, 278] -> 
             RGBColor[
              0.19015282278651957`, 0.31719305150690597`, 0.9341402940005757],
              UndirectedEdge[185, 218] -> 
             RGBColor[
              0.7483730046735189, 0.8020037075647066, 0.948265724399384], 
             UndirectedEdge[16, 248] -> 
             RGBColor[
              0.23437455245828825`, 0.36367289321153695`, 0.9366586560851965],
              UndirectedEdge[184, 275] -> 
             RGBColor[
              0.18583227383419235`, 0.31265188061938454`, 0.9338942451294201],
              UndirectedEdge[127, 191] -> 
             RGBColor[
              0.28810597904486807`, 0.41644150460043405`, 0.9398542953677421],
              UndirectedEdge[33, 153] -> 
             RGBColor[
              0.21078779737820008`, 0.338881718135717, 0.9353154252768627], 
             UndirectedEdge[83, 243] -> 
             RGBColor[
              0.9169850470479723, 0.6739469907037223, 0.5252000476482207], 
             UndirectedEdge[94, 281] -> 
             RGBColor[
              0.8876751944238266, 0.9123560617360518, 0.9508666014010566], 
             UndirectedEdge[140, 293] -> 
             RGBColor[
              0.8585388832387033, 0.3859183975781782, 0.20114329821116103`], 
             UndirectedEdge[126, 220] -> 
             RGBColor[
              0.27828890051671973`, 0.40757894001897654`, 0.9392419230286206],
              UndirectedEdge[76, 220] -> 
             RGBColor[
              0.3300035970754238, 0.4602542621488369, 0.942248515288291], 
             UndirectedEdge[90, 126] -> 
             RGBColor[
              0.2195822201328165, 0.34812521404942687`, 0.9358162546425555], 
             UndirectedEdge[35, 102] -> 
             RGBColor[
              0.19929440110633984`, 0.32680142993057915`, 0.9346608933621363],
              UndirectedEdge[105, 235] -> 
             RGBColor[
              0.34616703863432685`, 0.47195151424914406`, 0.9433627489328582],
              UndirectedEdge[21, 287] -> 
             RGBColor[
              0.21828938866019382`, 0.34676636620145074`, 0.9357426298027625],
              UndirectedEdge[160, 245] -> 
             RGBColor[
              0.2105034515043503, 0.33858285259373117`, 0.935299232199999], 
             UndirectedEdge[235, 298] -> 
             RGBColor[
              0.33431581918328446`, 0.4594951311953859, 0.9426878395174293], 
             UndirectedEdge[15, 196] -> 
             RGBColor[
              0.23071789586563907`, 0.35982951528724394`, 0.9364504149017838],
              UndirectedEdge[13, 274] -> 
             RGBColor[
              0.3981676494624695, 0.5190303850989934, 0.9466648547482157], 
             UndirectedEdge[2, 172] -> 
             RGBColor[
              0.19458761473709335`, 0.321854299029009, 0.9343928488414741], 
             UndirectedEdge[247, 295] -> 
             RGBColor[
              0.1973396127760572, 0.3247468234547135, 0.9345495710585769], 
             UndirectedEdge[159, 225] -> 
             RGBColor[
              0.2594187152635208, 0.38999589621147046`, 0.9380848841074358], 
             UndirectedEdge[204, 254] -> 
             RGBColor[
              0.40119508956919725`, 0.5210943009518455, 0.9470120206751078], 
             UndirectedEdge[61, 252] -> 
             RGBColor[
              0.2576007602350303, 0.3880851102115208, 0.9379813542579867], 
             UndirectedEdge[4, 173] -> 
             RGBColor[
              0.21091230660044274`, 0.33901258522263467`, 0.9353225158928745],
              UndirectedEdge[230, 245] -> 
             RGBColor[
              0.20866400795240445`, 0.3366494807931788, 0.9351944786109285], 
             UndirectedEdge[137, 295] -> 
             RGBColor[
              0.2292284865221631, 0.35826405163324404`, 0.9363655952430565], 
             UndirectedEdge[109, 192] -> 
             RGBColor[
              0.6617142280646152, 0.7260405303844142, 0.8555444013688691], 
             UndirectedEdge[178, 229] -> 
             RGBColor[
              0.23836184028178953`, 0.36786378552268634`, 0.9368857262280812],
              UndirectedEdge[91, 93] -> 
             RGBColor[
              0.3656444287828603, 0.48387268995411137`, 0.9450248073537576], 
             UndirectedEdge[143, 185] -> 
             RGBColor[
              0.41822549913320267`, 0.5344264087640556, 0.9484481661960105], 
             UndirectedEdge[139, 273] -> 
             RGBColor[
              0.3398266519904991, 0.46230754637230465`, 0.9431107790825377], 
             UndirectedEdge[130, 281] -> 
             RGBColor[
              0.9451323785335899, 0.8357466481470239, 0.5846180445889815], 
             UndirectedEdge[220, 248] -> 
             RGBColor[
              0.27752408340790014`, 0.40677506874540165`, 0.9391983678257189],
              UndirectedEdge[88, 273] -> 
             RGBColor[
              0.23089430452924603`, 0.3600149319776501, 0.936460461114203], 
             UndirectedEdge[24, 218] -> 
             RGBColor[
              0.945476791560533, 0.8552536816107574, 0.5989703095762722], 
             UndirectedEdge[66, 215] -> 
             RGBColor[
              0.3055417316872413, 0.4312998537559559, 0.940974206355727], 
             UndirectedEdge[151, 154] -> 
             RGBColor[
              0.5475628360948273, 0.6435752036232633, 0.9575252987275946], 
             UndirectedEdge[8, 64] -> 
             RGBColor[
              0.21988638356939655`, 0.34844490910634823`, 0.9358335763002992],
              UndirectedEdge[71, 108] -> 
             RGBColor[
              0.23200115605283045`, 0.3611783031073773, 0.936523494671031], 
             UndirectedEdge[43, 182] -> 
             RGBColor[
              0.23996509971424826`, 0.36954891283871966`, 0.9369770294809499],
              UndirectedEdge[58, 297] -> 
             RGBColor[
              0.19156703343003767`, 0.3186794765593771, 0.934220831204587], 
             UndirectedEdge[46, 207] -> 
             RGBColor[
              0.1949982416588687, 0.3222858939590454, 0.9344162334372013], 
             UndirectedEdge[100, 266] -> 
             RGBColor[
              0.1894062944527255, 0.3164084028954582, 0.9340977803163559], 
             UndirectedEdge[12, 151] -> 
             RGBColor[
              0.5137240937710055, 0.6154599354387978, 0.9550391768879118], 
             UndirectedEdge[196, 265] -> 
             RGBColor[
              0.21288778030859679`, 0.34108893334217194`, 0.9354350161981024],
              UndirectedEdge[93, 139] -> 
             RGBColor[
              0.3409266080048823, 0.4634636698846607, 0.9431734199503177], 
             UndirectedEdge[30, 104] -> 
             RGBColor[
              0.2921921290764705, 0.4220073511871032, 0.9400404564262714], 
             UndirectedEdge[85, 121] -> 
             RGBColor[
              0.22879896787362192`, 0.35781260030057205`, 0.936341134791438], 
             UndirectedEdge[79, 160] -> 
             RGBColor[
              0.1894526235362595, 0.316457097699686, 0.9341004186891254], 
             UndirectedEdge[60, 196] -> 
             RGBColor[
              0.24516356622564123`, 0.3750128307440074, 0.9372730744583317], 
             UndirectedEdge[25, 297] -> 
             RGBColor[
              0.19155439006973912`, 0.318666187586068, 0.9342201111839221], 
             UndirectedEdge[9, 133] -> 
             RGBColor[
              0.19212471165815448`, 0.3192656317359698, 0.9342525901546672], 
             UndirectedEdge[151, 192] -> 
             RGBColor[
              0.4642226762503304, 0.5725842955959759, 0.9518849903358793], 
             UndirectedEdge[45, 141] -> 
             RGBColor[
              0.2968912603514489, 0.4293819169954668, 0.9402188901145307], 
             UndirectedEdge[177, 280] -> 
             RGBColor[
              0.27699231630764354`, 0.4084668651395046, 0.9390856746890857], 
             UndirectedEdge[141, 188] -> 
             RGBColor[
              0.3248560928052687, 0.45441830964122576`, 0.9419709558048517], 
             UndirectedEdge[129, 183] -> 
             RGBColor[
              0.1909140048229797, 0.31799310208895415`, 0.9341836421914842], 
             UndirectedEdge[41, 55] -> 
             RGBColor[
              0.19536579579315563`, 0.32267221665845913`, 0.9344371651014012],
              UndirectedEdge[120, 261] -> 
             RGBColor[
              0.2619133763504623, 0.3926179431844944, 0.9382269513658168], 
             UndirectedEdge[71, 279] -> 
             RGBColor[
              0.22999178600981598`, 0.35906632779075, 0.9364090640196779], 
             UndirectedEdge[180, 230] -> 
             RGBColor[
              0.1934850620461379, 0.3206954462449366, 0.9343300600968047], 
             UndirectedEdge[106, 194] -> 
             RGBColor[
              0.7739330746560312, 0.8236601401446212, 0.9780122537987794], 
             UndirectedEdge[90, 234] -> 
             RGBColor[
              0.20491562163947707`, 0.33270968911687326`, 0.9349810135556479],
              UndirectedEdge[44, 136] -> 
             RGBColor[
              0.3544174046992013, 0.48140027523890294`, 0.9438041415217957], 
             UndirectedEdge[120, 131] -> 
             RGBColor[
              0.2542490675591432, 0.38456226869957383`, 0.93779048031848], 
             UndirectedEdge[44, 279] -> 
             RGBColor[
              0.27644302038079716`, 0.4071985613343865, 0.9390796924908837], 
             UndirectedEdge[105, 139] -> 
             RGBColor[
              0.3622816914289454, 0.48590921655384295`, 0.9443895603593033], 
             UndirectedEdge[157, 184] -> 
             RGBColor[
              0.18701393581723674`, 0.31389388228526116`, 0.9339615390312422],
              UndirectedEdge[83, 149] -> 
             RGBColor[
              0.8710281964790996, 0.48860908470804376`, 0.21336513442340005`],
              UndirectedEdge[145, 168] -> 
             RGBColor[
              0.6326576416445393, 0.7081764296337532, 0.9668556680760403], 
             UndirectedEdge[112, 170] -> 
             RGBColor[
              0.1934039006537554, 0.3206101404756131, 0.9343254380755761], 
             UndirectedEdge[159, 270] -> 
             RGBColor[
              0.2520399731872973, 0.38224037045009085`, 0.9376646756620657], 
             UndirectedEdge[86, 162] -> 
             RGBColor[
              0.7927626721159106, 0.8360545204331631, 0.8771199562466196], 
             UndirectedEdge[3, 264] -> 
             RGBColor[
              0.6252141606717125, 0.697021267014214, 0.9512803143951285], 
             UndirectedEdge[60, 282] -> 
             RGBColor[
              0.36394977931359895`, 0.4876708967869795, 0.9444842474150733], 
             UndirectedEdge[135, 186] -> 
             RGBColor[
              0.20309625090443267`, 0.3307974151195744, 0.934877403083805], 
             UndirectedEdge[89, 294] -> 
             RGBColor[
              0.4583968818459615, 0.569215720181254, 0.9510502956112238], 
             UndirectedEdge[201, 203] -> 
             RGBColor[
              0.8912445921234382, 0.6511612232387863, 0.591194505299895], 
             UndirectedEdge[181, 203] -> 
             RGBColor[
              0.961709527951959, 0.9590285203678879, 0.6962850331189814], 
             UndirectedEdge[70, 211] -> 
             RGBColor[
              0.24025127894135917`, 0.3698497053512242, 0.9369933269645696], 
             UndirectedEdge[156, 159] -> 
             RGBColor[
              0.3428661620319342, 0.4697766941100199, 0.9431273668629003], 
             UndirectedEdge[56, 270] -> 
             RGBColor[
              0.20609791902538932`, 0.3339523586314509, 0.9350483436427234], 
             UndirectedEdge[113, 264] -> 
             RGBColor[
              0.28192127958218227`, 0.41364751805536637`, 0.939366371855823], 
             UndirectedEdge[144, 240] -> 
             RGBColor[
              0.18908519234139687`, 0.31607090421740214`, 0.9340794940261437],
              UndirectedEdge[231, 232] -> 
             RGBColor[
              0.20954424282732975`, 0.33757466345683984`, 0.9352446066848648],
              UndirectedEdge[90, 248] -> 
             RGBColor[
              0.21881740302399694`, 0.347321342775852, 0.9357726994396538], 
             UndirectedEdge[27, 109] -> 
             RGBColor[
              0.9813263327288758, 0.9506128482774708, 0.5530707745780536], 
             UndirectedEdge[42, 145] -> 
             RGBColor[
              0.8512542986237088, 0.5925834616705845, 0.5853100694048696], 
             UndirectedEdge[160, 230] -> 
             RGBColor[
              0.19392496192438957`, 0.3211578089082423, 0.9343551117440977], 
             UndirectedEdge[247, 251] -> 
             RGBColor[
              0.24168185283923999`, 0.37135332922152087`, 0.9370747960317096],
              UndirectedEdge[109, 220] -> 
             RGBColor[
              0.6629503007752218, 0.7271111544395208, 0.8556231628289728], 
             UndirectedEdge[139, 163] -> 
             RGBColor[
              0.5309367698880918, 0.6297354344441368, 0.9563109238850767], 
             UndirectedEdge[31, 279] -> 
             RGBColor[
              0.32815763679560045`, 0.4519911628206914, 0.9423749021193952], 
             UndirectedEdge[9, 112] -> 
             RGBColor[
              0.19409572030031721`, 0.3213372867880486, 0.9343648361809924], 
             UndirectedEdge[196, 276] -> 
             RGBColor[
              0.22221678398010425`, 0.35089430769392205`, 0.9359662891561706],
              UndirectedEdge[137, 251] -> 
             RGBColor[
              0.27357072658534587`, 0.4048705574000514, 0.9388908202161892], 
             UndirectedEdge[162, 181] -> 
             RGBColor[
              0.9888211205061603, 0.9780593840975029, 0.5971500192561076], 
             UndirectedEdge[96, 236] -> 
             RGBColor[
              0.2161907003932258, 0.34456051176834573`, 0.9356231126106896], 
             UndirectedEdge[251, 295] -> 
             RGBColor[
              0.24126505067228732`, 0.3709152437172699, 0.9370510597649051], 
             UndirectedEdge[20, 268] -> 
             RGBColor[
              0.21202685048114545`, 0.34018404150741677`, 0.9353859875180606],
              UndirectedEdge[187, 215] -> 
             RGBColor[
              0.224740944415305, 0.35354736035233314`, 0.9361100363587946], 
             UndirectedEdge[55, 250] -> 
             RGBColor[
              0.1923953966842939, 0.31955013886086425`, 0.9342680052664631], 
             UndirectedEdge[193, 230] -> 
             RGBColor[
              0.2358246326636532, 0.3651970194477707, 0.9367412360076905], 
             UndirectedEdge[55, 242] -> 
             RGBColor[
              0.19150951150427703`, 0.318619017368302, 0.9342175554160109], 
             UndirectedEdge[51, 116] -> 
             RGBColor[
              0.5493242790295518, 0.6359329023080253, 0.960750884061716], 
             UndirectedEdge[130, 203] -> 
             RGBColor[
              0.92446413705714, 0.8203323074950271, 0.6196039862679017], 
             UndirectedEdge[34, 124] -> 
             RGBColor[
              0.1848087064384265, 0.3115760463885134, 0.9338359544804635], 
             UndirectedEdge[190, 261] -> 
             RGBColor[
              0.2245754678269734, 0.353373433966175, 0.9361006127118898], 
             UndirectedEdge[76, 85] -> 
             RGBColor[
              0.2795331222505161, 0.40945731042738504`, 0.9392918866244364], 
             UndirectedEdge[130, 237] -> 
             RGBColor[
              0.8684389229143985, 0.44088823341152344`, 0.20976890313790728`],
              UndirectedEdge[175, 183] -> 
             RGBColor[
              0.18767445593923526`, 0.3145881308128762, 0.9339991546750381], 
             UndirectedEdge[93, 289] -> 
             RGBColor[
              0.24228732684798865`, 0.37198972079398507`, 0.9371092768807893],
              UndirectedEdge[69, 234] -> 
             RGBColor[
              0.20086201360397116`, 0.32844909005796263`, 0.9347501665748015],
              UndirectedEdge[32, 269] -> 
             RGBColor[
              0.980420530285405, 0.9551564158081671, 0.6020762664235486], 
             UndirectedEdge[226, 243] -> 
             RGBColor[
              0.9868373224355939, 0.9888249088088037, 0.8678031613671959], 
             UndirectedEdge[72, 218] -> 
             RGBColor[
              0.898302513009544, 0.6010781396556649, 0.5581126298969585], 
             UndirectedEdge[81, 181] -> 
             RGBColor[
              0.9378794291938042, 0.7781980948822975, 0.31536710248397326`], 
             UndirectedEdge[8, 67] -> 
             RGBColor[
              0.1916976136601492, 0.31881672466048916`, 0.9342282675555156], 
             UndirectedEdge[145, 156] -> 
             RGBColor[
              0.6296976932681398, 0.7056126711214472, 0.9666670627828757], 
             UndirectedEdge[20, 177] -> 
             RGBColor[
              0.2554879446971804, 0.38586440712099823`, 0.9378610325387366], 
             UndirectedEdge[180, 297] -> 
             RGBColor[
              0.19343887791696943`, 0.3206469037969376, 0.9343274299789719], 
             UndirectedEdge[140, 216] -> 
             RGBColor[
              0.8418913589267707, 0.3103258778057786, 0.18725219585712266`], 
             UndirectedEdge[287, 300] -> 
             RGBColor[
              0.2343234420650949, 0.3636191729477046, 0.9366557454239152], 
             UndirectedEdge[140, 167] -> 
             RGBColor[
              0.862500511580873, 0.40291200775905295`, 0.20439749636787896`], 
             UndirectedEdge[248, 285] -> 
             RGBColor[
              0.21081919728396287`, 0.3389147214275427, 0.9353172134550438], 
             UndirectedEdge[185, 292] -> 
             RGBColor[
              0.6516360083701964, 0.726054278090207, 0.9670940826236099], 
             UndirectedEdge[23, 241] -> 
             RGBColor[
              0.9877354309295805, 0.9891962997514028, 0.8529191793915591], 
             UndirectedEdge[10, 48] -> 
             RGBColor[
              0.19160641114189197`, 0.3187208650312271, 0.934223073707023], 
             UndirectedEdge[46, 62] -> 
             RGBColor[
              0.20319287451419632`, 0.3308989726597267, 0.9348829056554392], 
             UndirectedEdge[15, 276] -> 
             RGBColor[
              0.24987495920564082`, 0.37996480348555506`, 0.9375413813186614],
              UndirectedEdge[85, 154] -> 
             RGBColor[
              0.36472305205370464`, 0.48205039622074985`, 0.9450500607222323],
              UndirectedEdge[32, 179] -> 
             RGBColor[
              0.7552164634617963, 0.8063041539020928, 0.9047369408488604], 
             UndirectedEdge[145, 277] -> 
             RGBColor[
              0.9289575250796454, 0.9412874203114796, 0.7338327759362018], 
             UndirectedEdge[58, 164] -> 
             RGBColor[
              0.1865510290497441, 0.3134073379226422, 0.9339351771756428], 
             UndirectedEdge[18, 253] -> 
             RGBColor[
              0.19591234458530662`, 0.3232466740922047, 0.9344682902465677], 
             UndirectedEdge[59, 136] -> 
             RGBColor[
              0.6888115905499252, 0.7512769242124885, 0.9221815319720392], 
             UndirectedEdge[232, 288] -> 
             RGBColor[
              0.19838654644971515`, 0.32584721712515685`, 0.9346091923824922],
              UndirectedEdge[136, 177] -> 
             RGBColor[
              0.34229360740819775`, 0.46934835455154167`, 0.9430884098094023],
              UndirectedEdge[31, 65] -> 
             RGBColor[
              0.3985559674737674, 0.5196308798455622, 0.9466166117115924], 
             UndirectedEdge[62, 214] -> 
             RGBColor[
              0.20125370240405008`, 0.3288607798213499, 0.9347724726725144], 
             UndirectedEdge[24, 109] -> 
             RGBColor[
              0.9582875876148832, 0.8633759964057863, 0.5131590613985512], 
             UndirectedEdge[71, 268] -> 
             RGBColor[
              0.21418318831071842`, 0.34245048928601285`, 0.9355087877674388],
              UndirectedEdge[64, 118] -> 
             RGBColor[
              0.2120127678097534, 0.3401692397268907, 0.9353851855307582], 
             UndirectedEdge[21, 206] -> 
             RGBColor[
              0.20800021126608947`, 0.33595178838872103`, 0.9351566763716421],
              UndirectedEdge[6, 124] -> 
             RGBColor[
              0.19825974011141095`, 0.3257139356236129, 0.9346019709491189], 
             UndirectedEdge[7, 140] -> 
             RGBColor[
              0.8778193430883396, 0.5438232517297938, 0.5767554309436527], 
             UndirectedEdge[78, 229] -> 
             RGBColor[
              0.20592187570768378`, 0.3337673259427514, 0.9350383182362128], 
             UndirectedEdge[67, 213] -> 
             RGBColor[
              0.19065103236232478`, 0.3177167013593888, 0.9341686662988828], 
             UndirectedEdge[189, 300] -> 
             RGBColor[
              0.22074088939765935`, 0.34934304891065115`, 0.9358822391430908],
              UndirectedEdge[77, 225] -> 
             RGBColor[
              0.32068966156322254`, 0.4446841856418027, 0.9419297543163823], 
             UndirectedEdge[153, 239] -> 
             RGBColor[
              0.22932262896951866`, 0.3583630013143907, 0.9363709565161622], 
             UndirectedEdge[7, 168] -> 
             RGBColor[
              0.6693655533207783, 0.7373787417141351, 0.9680138507113893], 
             UndirectedEdge[5, 256] -> 
             RGBColor[
              0.8944703960572045, 0.5263449866913684, 0.2533457371184724], 
             UndirectedEdge[193, 200] -> 
             RGBColor[
              0.3225670309120143, 0.4511149836272068, 0.9418734544780243], 
             UndirectedEdge[17, 202] -> 
             RGBColor[
              0.7851169381087426, 0.6277184794555003, 0.5907369568935974], 
             UndirectedEdge[12, 220] -> 
             RGBColor[
              0.38135478455479077`, 0.5047320797577364, 0.9455205675464041], 
             UndirectedEdge[196, 207] -> 
             RGBColor[
              0.19417373721693681`, 0.32141928751397403`, 0.9343692791289782],
              UndirectedEdge[222, 285] -> 
             RGBColor[
              0.21055261927690455`, 0.33863453104010255`, 0.9353020322319088],
              UndirectedEdge[169, 227] -> 
             RGBColor[
              0.7787217249901721, 0.7700947212036731, 0.6214147685810579], 
             UndirectedEdge[139, 298] -> 
             RGBColor[
              0.350430471977903, 0.4734528335000848, 0.9437146509438744], 
             UndirectedEdge[210, 241] -> 
             RGBColor[
              0.7289016289330998, 0.7852496727746727, 0.9155863904520005], 
             UndirectedEdge[58, 288] -> 
             RGBColor[
              0.200003126765576, 0.32754634553423856`, 0.9347012542399642], 
             UndirectedEdge[85, 258] -> 
             RGBColor[
              0.2861550048473763, 0.41519285230728875`, 0.9397138271280076], 
             UndirectedEdge[87, 162] -> 
             RGBColor[
              0.9922481634967688, 0.9892215006042993, 0.6443153424349913], 
             UndirectedEdge[222, 248] -> 
             RGBColor[
              0.22169214906401963`, 0.3503428831333422, 0.9359364119738274], 
             UndirectedEdge[76, 87] -> 
             RGBColor[
              0.6600329022141906, 0.7226670785503484, 0.7188188011286823], 
             UndirectedEdge[80, 282] -> 
             RGBColor[
              0.7097202776306235, 0.7481265393121519, 0.6607363832345532], 
             UndirectedEdge[273, 289] -> 
             RGBColor[
              0.24118737083360547`, 0.370833597281629, 0.9370466360130092], 
             UndirectedEdge[215, 296] -> 
             RGBColor[
              0.20597442651804665`, 0.33382256017635653`, 0.935041310927121], 
             UndirectedEdge[142, 277] -> 
             RGBColor[
              0.9114733897375824, 0.6092818085693412, 0.32849435906876756`], 
             UndirectedEdge[134, 180] -> 
             RGBColor[
              0.21984183187712564`, 0.34839808245303105`, 0.9358310391473328],
              UndirectedEdge[86, 178] -> 
             RGBColor[
              0.4265942001520806, 0.5354932240498018, 0.9496283130255976], 
             UndirectedEdge[3, 210] -> 
             RGBColor[
              0.7129487102103079, 0.7736730218742174, 0.9569659936880668], 
             UndirectedEdge[79, 176] -> 
             RGBColor[
              0.18866673983198834`, 0.31563108409859225`, 0.9340556637747779],
              UndirectedEdge[131, 141] -> 
             RGBColor[
              0.26162779894186294`, 0.392317783221403, 0.938210688154871], 
             UndirectedEdge[150, 256] -> 
             RGBColor[
              0.8626687592440776, 0.4047125271654385, 0.20457946206091293`], 
             UndirectedEdge[74, 300] -> 
             RGBColor[
              0.2157736566163444, 0.3441221723167407, 0.9355993625845572], 
             UndirectedEdge[25, 230] -> 
             RGBColor[
              0.19160057419890764`, 0.31871473003406703`, 0.934222741301755], 
             UndirectedEdge[165, 253] -> 
             RGBColor[
              0.20482209384336109`, 0.3326113854731506, 0.9349756872860211], 
             UndirectedEdge[223, 295] -> 
             RGBColor[
              0.1892065910771333, 0.3161985019857855, 0.9340864075045505], 
             UndirectedEdge[164, 221] -> 
             RGBColor[
              0.184078374522518, 0.31080842123917557`, 0.9337943631582817], 
             UndirectedEdge[70, 138] -> 
             RGBColor[
              0.22052881830414905`, 0.3491201487452879, 0.9358701620080464], 
             UndirectedEdge[165, 224] -> 
             RGBColor[
              0.21323098705618415`, 0.3414496653944509, 0.9354545613146487], 
             UndirectedEdge[87, 258] -> 
             RGBColor[
              0.6666547848110509, 0.7284026204302521, 0.7192407416322534], 
             UndirectedEdge[90, 222] -> 
             RGBColor[
              0.2185508250169386, 0.3470411523884118, 0.9357575182165185], 
             UndirectedEdge[163, 185] -> 
             RGBColor[
              0.5753534134295759, 0.6661368462548543, 0.9597130747756251], 
             UndirectedEdge[64, 286] -> 
             RGBColor[
              0.22809764059378232`, 0.35707546086274283`, 0.9363011952403719],
              UndirectedEdge[131, 199] -> 
             RGBColor[
              0.21390129447571837`, 0.3421542009923264, 0.9354927343305601], 
             UndirectedEdge[2, 49] -> 
             RGBColor[
              0.20410648254439653`, 0.3318592326255619, 0.934934934281197], 
             UndirectedEdge[51, 283] -> 
             RGBColor[
              0.5585587587049552, 0.6456389259467026, 0.9612767740180419], 
             UndirectedEdge[66, 187] -> 
             RGBColor[
              0.305540960778381, 0.4312990434818653, 0.9409741624536079], 
             UndirectedEdge[120, 170] -> 
             RGBColor[
              0.23833338730926568`, 0.3678338796445412, 0.9368841058733883], 
             UndirectedEdge[17, 182] -> 
             RGBColor[
              0.47900337512465124`, 0.5765439495002909, 0.9544470440825916], 
             UndirectedEdge[156, 179] -> 
             RGBColor[
              0.4586241439822036, 0.5697734899723961, 0.9509650514168311], 
             UndirectedEdge[199, 284] -> 
             RGBColor[
              0.21967623885350168`, 0.3482240336859982, 0.9358216088696103], 
             UndirectedEdge[210, 291] -> 
             RGBColor[
              0.6992769373373419, 0.7632490848408453, 0.9722193956891239], 
             UndirectedEdge[212, 265] -> 
             RGBColor[
              0.22804223773896515`, 0.3570172289495861, 0.9362980401297512], 
             UndirectedEdge[85, 173] -> 
             RGBColor[
              0.21671771694106706`, 0.34511443957490595`, 0.9356531254234381],
              UndirectedEdge[47, 146] -> 
             RGBColor[
              0.19206431623757236`, 0.3192021523196471, 0.9342491507248121], 
             UndirectedEdge[198, 283] -> 
             RGBColor[
              0.6352059189617083, 0.705940028417498, 0.9427748448450561], 
             UndirectedEdge[168, 212] -> 
             RGBColor[
              0.31689002798285826`, 0.4419267953395609, 0.941668105069032], 
             UndirectedEdge[56, 271] -> 
             RGBColor[
              0.21099595483626973`, 0.3391005048220933, 0.9353272795361584], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.33246233459167696`, 0.45559373221858496`, 0.9426538050639501],
              UndirectedEdge[159, 191] -> 
             RGBColor[
              0.25930875612416715`, 0.38988032218419766`, 0.9380786220971196],
              UndirectedEdge[72, 83] -> 
             RGBColor[
              0.8379840210704871, 0.29296740741773747`, 0.18400684751490148`],
              UndirectedEdge[179, 277] -> 
             RGBColor[
              0.7578839757937091, 0.8054482391624284, 0.7181307645701571], 
             UndirectedEdge[86, 182] -> 
             RGBColor[
              0.4242603384632414, 0.5330401874394541, 0.9494954030550571], 
             UndirectedEdge[80, 293] -> 
             RGBColor[
              0.9392835874613179, 0.7889438610995526, 0.30512184711932616`], 
             UndirectedEdge[9, 96] -> 
             RGBColor[
              0.19995528537104273`, 0.3274960611952644, 0.9346985297433206], 
             UndirectedEdge[51, 226] -> 
             RGBColor[
              0.8987769385879059, 0.920547716985024, 0.9296222387004919], 
             UndirectedEdge[185, 235] -> 
             RGBColor[
              0.4690251433139141, 0.5785976856950342, 0.951678806922862], 
             UndirectedEdge[136, 210] -> 
             RGBColor[
              0.43214727310106515`, 0.5482274348494092, 0.9488947696323751], 
             UndirectedEdge[78, 284] -> 
             RGBColor[
              0.2175445595822431, 0.34598350361563335`, 0.935700212888649], 
             UndirectedEdge[81, 216] -> 
             RGBColor[
              0.8779643061000555, 0.5387462408083503, 0.21988276445235083`], 
             UndirectedEdge[2, 165] -> 
             RGBColor[
              0.2081927032562806, 0.336154109675109, 0.935167638505717], 
             UndirectedEdge[181, 216] -> 
             RGBColor[
              0.92637884094729, 0.7259766096855043, 0.3057707297458678], 
             UndirectedEdge[7, 203] -> 
             RGBColor[
              0.9377223890197792, 0.9530740402179558, 0.990303930173889], 
             UndirectedEdge[44, 177] -> 
             RGBColor[
              0.3040955168977345, 0.4362630884432308, 0.9406544612593207], 
             UndirectedEdge[140, 237] -> 
             RGBColor[
              0.8211968317886982, 0.16393371440465854`, 0.16793141610024187`],
              UndirectedEdge[38, 124] -> 
             RGBColor[
              0.186021974396972, 0.31285126793857626`, 0.9339050482958335], 
             UndirectedEdge[5, 59] -> 
             RGBColor[
              0.978010186853574, 0.9509747189595588, 0.6200075845730131], 
             UndirectedEdge[35, 253] -> 
             RGBColor[
              0.19912169776175326`, 0.3266199077653942, 0.9346510581621539], 
             UndirectedEdge[200, 231] -> 
             RGBColor[
              0.2983755222047893, 0.4256881741456715, 0.9404957838452779], 
             UndirectedEdge[213, 234] -> 
             RGBColor[
              0.19826511451334394`, 0.3257195844608012, 0.9346022770133582], 
             UndirectedEdge[53, 88] -> 
             RGBColor[
              0.21936792560639845`, 0.34789997691510377`, 0.9358040508862964],
              UndirectedEdge[150, 269] -> 
             RGBColor[
              0.9402871560451271, 0.7958786263011822, 0.2973043850963], 
             UndirectedEdge[4, 135] -> 
             RGBColor[
              0.21680708920312736`, 0.3452083754888601, 0.935658215041548], 
             UndirectedEdge[91, 139] -> 
             RGBColor[
              0.4654409733450266, 0.5765629962584664, 0.9511548548621985], 
             UndirectedEdge[28, 232] -> 
             RGBColor[
              0.18568890069969585`, 0.3125011863646469, 0.9338860802415121], 
             UndirectedEdge[127, 276] -> 
             RGBColor[
              0.29510454675664893`, 0.4237974430003376, 0.9402528534454749], 
             UndirectedEdge[60, 103] -> 
             RGBColor[
              0.35429852491084235`, 0.47931146530946245`, 0.9438692780187988],
              UndirectedEdge[145, 159] -> 
             RGBColor[
              0.5780723315879956, 0.6592789022873965, 0.963436800696632], 
             UndirectedEdge[20, 252] -> 
             RGBColor[
              0.2284732256377411, 0.3574702245574107, 0.936322584252997], 
             UndirectedEdge[80, 128] -> 
             RGBColor[
              0.9118743315068152, 0.6433069966832056, 0.2814216211923882], 
             UndirectedEdge[167, 237] -> 
             RGBColor[
              0.8663783433695712, 0.4327187221637115, 0.20811091246812083`], 
             UndirectedEdge[24, 291] -> 
             RGBColor[
              0.9253194185531315, 0.839992794616319, 0.6252021408895034], 
             UndirectedEdge[22, 244] -> 
             RGBColor[
              0.18902260313051494`, 0.31600511898838, 0.9340759296631764], 
             UndirectedEdge[51, 83] -> 
             RGBColor[
              0.8289246632002845, 0.6056697988799424, 0.5870191249815166], 
             UndirectedEdge[29, 229] -> 
             RGBColor[
              0.20648377022612274`, 0.3343579127078008, 0.9350703172977894], 
             UndirectedEdge[151, 181] -> 
             RGBColor[
              0.7920610111090953, 0.8249056195457978, 0.6813687144574905], 
             UndirectedEdge[22, 63] -> 
             RGBColor[
              0.18571205303560948`, 0.312525520937635, 0.9338873987327916], 
             UndirectedEdge[163, 292] -> 
             RGBColor[
              0.6974329821497556, 0.7632343245346107, 0.9706993881593793], 
             UndirectedEdge[247, 289] -> 
             RGBColor[
              0.22060050259813557`, 0.34919549348331447`, 0.9358742443225416],
              UndirectedEdge[155, 299] -> 
             RGBColor[
              0.8725038681798738, 0.44513051276199045`, 0.2125515962932238], 
             UndirectedEdge[31, 71] -> 
             RGBColor[
              0.32148269623256015`, 0.4449753770732606, 0.9419947741290198], 
             UndirectedEdge[45, 260] -> 
             RGBColor[
              0.2790511539192304, 0.41063083400712647`, 0.9392029224452882], 
             UndirectedEdge[80, 125] -> 
             RGBColor[
              0.9070014402205765, 0.6058518189425977, 0.2767553349935425], 
             UndirectedEdge[97, 261] -> 
             RGBColor[
              0.34679730240272766`, 0.46888200483462256`, 0.9435352867345028],
              UndirectedEdge[107, 147] -> 
             RGBColor[
              0.3109365240034128, 0.43492372492699083`, 0.9413563604380197], 
             UndirectedEdge[15, 286] -> 
             RGBColor[
              0.23963340623012278`, 0.3692002819563222, 0.9369581400277256], 
             UndirectedEdge[94, 202] -> 
             RGBColor[
              0.8317297748330001, 0.6641327817751705, 0.595382888836546], 
             UndirectedEdge[86, 130] -> 
             RGBColor[
              0.75299012475597, 0.6847273872222507, 0.6045439579169226], 
             UndirectedEdge[73, 161] -> 
             RGBColor[
              0.19216173018569271`, 0.31930454055552265`, 0.9342546983050465],
              UndirectedEdge[7, 167] -> 
             RGBColor[
              0.9230008546692128, 0.8126082594888467, 0.6169349273115317], 
             UndirectedEdge[288, 297] -> 
             RGBColor[
              0.20042924344964513`, 0.3279942211865534, 0.9347255209547387], 
             UndirectedEdge[15, 46] -> 
             RGBColor[
              0.23154240030757095`, 0.3606961217323153, 0.9364973692100068], 
             UndirectedEdge[1, 92] -> 
             RGBColor[
              0.82512404738325, 0.19412001438123114`, 0.1716921221887404], 
             UndirectedEdge[85, 213] -> 
             RGBColor[
              0.21726177740977812`, 0.34568628162294734`, 0.9356841088622658],
              UndirectedEdge[2, 174] -> 
             RGBColor[
              0.21589796346133705`, 0.34425282669233714`, 0.9356064416754841],
              UndirectedEdge[104, 204] -> 
             RGBColor[
              0.40934807922423605`, 0.5281560108098651, 0.9475315219665212], 
             UndirectedEdge[125, 243] -> 
             RGBColor[
              0.9113059901364808, 0.6302952707033915, 0.519761776336199], 
             UndirectedEdge[149, 243] -> 
             RGBColor[
              0.9414606577081649, 0.8037269245686582, 0.5463530672768225], 
             UndirectedEdge[35, 175] -> 
             RGBColor[
              0.19450102624862847`, 0.3217632890376051, 0.9343879177551523], 
             UndirectedEdge[82, 201] -> 
             RGBColor[
              0.7294018709234232, 0.5233754189666472, 0.5768926874649807], 
             UndirectedEdge[39, 69] -> 
             RGBColor[
              0.20464654155210055`, 0.3324268688843776, 0.9349656898427401], 
             UndirectedEdge[5, 204] -> 
             RGBColor[
              0.7273105149978081, 0.7527675975931751, 0.6471903809836539], 
             UndirectedEdge[107, 277] -> 
             RGBColor[
              0.7007432409432577, 0.7578412318622451, 0.7139688588587303], 
             UndirectedEdge[236, 260] -> 
             RGBColor[
              0.2447992469285118, 0.3746299080635468, 0.9372523270133223], 
             UndirectedEdge[11, 51] -> 
             RGBColor[
              0.6715557743614986, 0.7416503460034106, 0.9690558457242018], 
             UndirectedEdge[41, 242] -> 
             RGBColor[
              0.18473837996455222`, 0.31150212880551553`, 0.933831949491815], 
             UndirectedEdge[53, 93] -> 
             RGBColor[
              0.22850372850548528`, 0.3575022850054033, 0.93632432134619], 
             UndirectedEdge[82, 293] -> 
             RGBColor[
              0.7565992079701278, 0.6673833817942012, 0.600389979606483], 
             UndirectedEdge[76, 151] -> 
             RGBColor[
              0.46237290629163863`, 0.5709821178298984, 0.9517671246297987], 
             UndirectedEdge[130, 269] -> 
             RGBColor[
              0.9424840400754735, 0.8045885394133, 0.29907204955461253`], 
             UndirectedEdge[13, 289] -> 
             RGBColor[
              0.2883666647778183, 0.41815288261871875`, 0.9398165114828785], 
             UndirectedEdge[86, 120] -> 
             RGBColor[
              0.4366336879326583, 0.5460453622474791, 0.9502000470026102], 
             UndirectedEdge[86, 284] -> 
             RGBColor[
              0.41756739126480746`, 0.526005475576538, 0.9491142496134344], 
             UndirectedEdge[49, 102] -> 
             RGBColor[
              0.20090857647606358`, 0.32849803058878846`, 0.9347528182614836],
              UndirectedEdge[27, 299] -> 
             RGBColor[
              0.8942677012180347, 0.5273127630922669, 0.2514374852904795], 
             UndirectedEdge[120, 182] -> 
             RGBColor[
              0.2667169591353605, 0.3976668132561618, 0.9385005082991529], 
             UndirectedEdge[97, 182] -> 
             RGBColor[
              0.35160088518762583`, 0.47393087490628993`, 0.9438088436678389],
              UndirectedEdge[42, 130] -> 
             RGBColor[
              0.8747039583373085, 0.4890440410280375, 0.21576830813423137`], 
             UndirectedEdge[15, 127] -> 
             RGBColor[
              0.3036056586421837, 0.43273265059365945`, 0.9407369791910881], 
             UndirectedEdge[28, 176] -> 
             RGBColor[
              0.18883134167646898`, 0.3158040910735011, 0.9340650376063144], 
             UndirectedEdge[26, 35] -> 
             RGBColor[
              0.21774452951257628`, 0.3461936846912394, 0.9357116008803525], 
             UndirectedEdge[44, 59] -> 
             RGBColor[
              0.650613500039462, 0.7181916581041776, 0.9197475834219577], 
             UndirectedEdge[155, 218] -> 
             RGBColor[
              0.9467517036363646, 0.8603082831521655, 0.5999961337585191], 
             UndirectedEdge[65, 155] -> 
             RGBColor[
              0.6518886127524492, 0.6234637492866453, 0.6024205995762867], 
             UndirectedEdge[55, 252] -> 
             RGBColor[
              0.22003960441036646`, 0.34860595392497, 0.9358423020005227], 
             UndirectedEdge[160, 296] -> 
             RGBColor[
              0.1914857715941317, 0.31859406521754197`, 0.9342162034632482], 
             UndirectedEdge[88, 147] -> 
             RGBColor[
              0.21812810554997109`, 0.34659684742666674`, 0.9357334449682322],
              UndirectedEdge[204, 243] -> 
             RGBColor[
              0.7355129252278461, 0.7903594474546665, 0.9053392735975632], 
             UndirectedEdge[65, 106] -> 
             RGBColor[
              0.6196619973862446, 0.6970249085872788, 0.9659794196694249], 
             UndirectedEdge[115, 245] -> 
             RGBColor[
              0.2884856169676899, 0.4165730051879058, 0.9398857105111442], 
             UndirectedEdge[60, 205] -> 
             RGBColor[
              0.3298135622578278, 0.45810382130942706`, 0.9423091178497511], 
             UndirectedEdge[75, 111] -> 
             RGBColor[
              0.4735665439631073, 0.5802328466571501, 0.952603227994324], 
             UndirectedEdge[17, 86] -> 
             RGBColor[
              0.648920103921949, 0.7249224984916083, 0.966146582786049], 
             UndirectedEdge[67, 166] -> 
             RGBColor[
              0.1825106958270533, 0.309160691533672, 0.9337050861757479], 
             UndirectedEdge[3, 169] -> 
             RGBColor[
              0.7794786659769637, 0.8276850371059405, 0.962203475513276], 
             UndirectedEdge[7, 255] -> 
             RGBColor[
              0.6521687790491231, 0.722483760175034, 0.9669180874613099], 
             UndirectedEdge[211, 231] -> 
             RGBColor[
              0.25095672851015194`, 0.3811018116127316, 0.937602986480219], 
             UndirectedEdge[218, 290] -> 
             RGBColor[
              0.956800253470921, 0.9001474347654498, 0.6080814328251828], 
             UndirectedEdge[201, 269] -> 
             RGBColor[
              0.9092644951417719, 0.6354174551570593, 0.2706625685866058], 
             UndirectedEdge[34, 223] -> 
             RGBColor[
              0.1825916590093845, 0.3092457889716643, 0.9337096969092074], 
             UndirectedEdge[63, 208] -> 
             RGBColor[
              0.1860996055764639, 0.3129328632303233, 0.9339094692766605], 
             UndirectedEdge[131, 190] -> 
             RGBColor[
              0.21691115903565433`, 0.3453177594812544, 0.9356641416645529], 
             UndirectedEdge[27, 181] -> 
             RGBColor[
              0.9780677338465346, 0.9376794577026863, 0.3692977168650637], 
             UndirectedEdge[108, 136] -> 
             RGBColor[
              0.3166504809342749, 0.4423958027593246, 0.9416280716923184], 
             UndirectedEdge[101, 254] -> 
             RGBColor[
              0.4830549298600605, 0.587475687952538, 0.9535083702036646], 
             UndirectedEdge[62, 212] -> 
             RGBColor[
              0.2175228275026328, 0.34596066182206947`, 0.9356989752788649], 
             UndirectedEdge[69, 195] -> 
             RGBColor[
              0.1956464700099377, 0.32296722305607023`, 0.9344531490828267], 
             UndirectedEdge[136, 252] -> 
             RGBColor[
              0.3152788883487585, 0.44095417198795417`, 0.9415499615236627], 
             UndirectedEdge[26, 175] -> 
             RGBColor[
              0.20585209939384108`, 0.33369398661282884`, 0.9350343445783642],
              UndirectedEdge[24, 27] -> 
             RGBColor[
              0.9468027585380377, 0.8226935997742366, 0.2974286527731346], 
             UndirectedEdge[231, 266] -> 
             RGBColor[
              0.21466524015743277`, 0.342957156340762, 0.9355362399069774], 
             UndirectedEdge[153, 157] -> 
             RGBColor[
              0.2018036290672552, 0.32943878761174283`, 0.9348037901824403], 
             UndirectedEdge[161, 244] -> 
             RGBColor[
              0.19557921069497186`, 0.3228965292515542, 0.9344493187643406], 
             UndirectedEdge[128, 150] -> 
             RGBColor[
              0.8761748343795548, 0.5085261390565783, 0.21751289486357597`], 
             UndirectedEdge[113, 200] -> 
             RGBColor[
              0.3166014610591278, 0.4448447914728484, 0.9415337241001722], 
             UndirectedEdge[211, 264] -> 
             RGBColor[
              0.28347133969758304`, 0.41527672951614025`, 0.9394546454862865],
              UndirectedEdge[144, 232] -> 
             RGBColor[
              0.19277383312180774`, 0.31994789955094727`, 0.9342895566617331],
              UndirectedEdge[208, 244] -> 
             RGBColor[
              0.18941015567136937`, 0.31641246128106837`, 0.9340980002070455],
              UndirectedEdge[47, 133] -> 
             RGBColor[
              0.18469446291568115`, 0.3114559692026503, 0.9338294484808514], 
             UndirectedEdge[181, 258] -> 
             RGBColor[
              0.6632277418204424, 0.717240503923456, 0.6720754184533696], 
             UndirectedEdge[53, 147] -> 
             RGBColor[
              0.21463757351182716`, 0.3429280769420639, 0.9355346643324394], 
             UndirectedEdge[123, 267] -> 
             RGBColor[
              0.19740462411574278`, 0.32481515449468, 0.9345532733581963], 
             UndirectedEdge[59, 227] -> 
             RGBColor[
              0.9688560866723765, 0.9191321953350291, 0.5894640490955131], 
             UndirectedEdge[213, 286] -> 
             RGBColor[
              0.21163290304685975`, 0.3397699777762725, 0.935363552794471], 
             UndirectedEdge[16, 126] -> 
             RGBColor[
              0.23513936956710785`, 0.3644767644851118, 0.9367022112880983], 
             UndirectedEdge[68, 109] -> 
             RGBColor[
              0.9348338843673183, 0.947970458954174, 0.8784588716115629], 
             UndirectedEdge[137, 156] -> 
             RGBColor[
              0.32801284307365003`, 0.4541649141300481, 0.9422814923217423], 
             UndirectedEdge[181, 202] -> 
             RGBColor[
              0.9264323498375825, 0.7262195810590035, 0.3058153788755507], 
             UndirectedEdge[135, 214] -> 
             RGBColor[
              0.20695344714813524`, 0.3348515729320728, 0.9350970647036734], 
             UndirectedEdge[166, 234] -> 
             RGBColor[
              0.19012477797807242`, 0.3171635746350845, 0.9341386968902232], 
             UndirectedEdge[63, 152] -> 
             RGBColor[
              0.18270109795627662`, 0.30936081624367795`, 0.9337159292953324],
              UndirectedEdge[130, 167] -> 
             RGBColor[
              0.9097426027065735, 0.6798665267659179, 0.24623498340554434`], 
             UndirectedEdge[30, 74] -> 
             RGBColor[
              0.22759891531018372`, 0.3565512689686714, 0.9362727935732689], 
             UndirectedEdge[31, 177] -> 
             RGBColor[
              0.3558101333125378, 0.4810556899295358, 0.9439496708878323], 
             UndirectedEdge[24, 72] -> 
             RGBColor[
              0.8765897348730561, 0.4812812059474597, 0.21665925991431845`], 
             UndirectedEdge[39, 285] -> 
             RGBColor[
              0.20070194384757245`, 0.3282808465949789, 0.9347410508389766], 
             UndirectedEdge[27, 72] -> 
             RGBColor[
              0.8996284799870488, 0.5685180578191442, 0.256570973093821], 
             UndirectedEdge[109, 151] -> 
             RGBColor[
              0.7953196099914366, 0.8378390101205823, 0.8651417721704804], 
             UndirectedEdge[29, 178] -> 
             RGBColor[
              0.22713326298795516`, 0.3560618388539467, 0.9362462753623888], 
             UndirectedEdge[149, 256] -> 
             RGBColor[
              0.8567159557183694, 0.3785989305571812, 0.19965971650756104`], 
             UndirectedEdge[93, 137] -> 
             RGBColor[
              0.25133211293896884`, 0.38149636444816565`, 0.9376243640681086],
              UndirectedEdge[7, 145] -> 
             RGBColor[
              0.9016117745004403, 0.9243171913792056, 0.9881346792519563], 
             UndirectedEdge[271, 278] -> 
             RGBColor[
              0.21163260011638724`, 0.339769659377139, 0.9353635355430288], 
             UndirectedEdge[15, 135] -> 
             RGBColor[
              0.2357262900418861, 0.3650936551170112, 0.9367356355408658], 
             UndirectedEdge[94, 130] -> 
             RGBColor[
              0.8543459981416374, 0.7646454516027577, 0.6141415308874059], 
             UndirectedEdge[265, 286] -> 
             RGBColor[
              0.22180329067308052`, 0.3504597000112502, 0.9359427413240442], 
             UndirectedEdge[140, 201] -> 
             RGBColor[
              0.8313415461919986, 0.24191043475062424`, 0.1776460060696587], 
             UndirectedEdge[29, 259] -> 
             RGBColor[
              0.19020824390880345`, 0.3172513026203284, 0.9341434501515016], 
             UndirectedEdge[21, 123] -> 
             RGBColor[
              0.1960904957019222, 0.3234339222112008, 0.934478435689108], 
             UndirectedEdge[21, 189] -> 
             RGBColor[
              0.20470683599275827`, 0.3324902421643972, 0.934969123521938], 
             UndirectedEdge[107, 289] -> 
             RGBColor[
              0.32595994240234355`, 0.45071429020400966`, 0.942211921890683], 
             UndirectedEdge[17, 66] -> 
             RGBColor[
              0.5450024443168381, 0.6387388987189666, 0.9584682781320619], 
             UndirectedEdge[71, 208] -> 
             RGBColor[
              0.20631669235829492`, 0.33418230327536513`, 0.9350608024603861],
              UndirectedEdge[6, 289] -> 
             RGBColor[
              0.22701980203641853`, 0.3559425842000419, 0.9362398139290493], 
             UndirectedEdge[96, 132] -> 
             RGBColor[
              0.1989233882773373, 0.32641147192372544`, 0.9346397647303889], 
             UndirectedEdge[55, 283] -> 
             RGBColor[
              0.25397885208056453`, 0.38427825509893676`, 0.9377750919467229],
              UndirectedEdge[48, 244] -> 
             RGBColor[
              0.19115682833937214`, 0.31824832500058275`, 0.9341974706315176],
              UndirectedEdge[110, 278] -> 
             RGBColor[
              0.19327360105018532`, 0.32047318733078894`, 0.9343180177059138],
              UndirectedEdge[245, 288] -> 
             RGBColor[
              0.2170539171587743, 0.34546780732004123`, 0.9356722715284729], 
             UndirectedEdge[106, 210] -> 
             RGBColor[
              0.6667698289178824, 0.73732879896912, 0.9691188386686375], 
             UndirectedEdge[176, 296] -> 
             RGBColor[
              0.19069988788986053`, 0.3177680516164482, 0.9341714485489008], 
             UndirectedEdge[82, 154] -> 
             RGBColor[
              0.5553686317376758, 0.6499123001732142, 0.9581397995541713], 
             UndirectedEdge[46, 117] -> 
             RGBColor[
              0.1951092767006187, 0.3224025988279529, 0.9344225567185672], 
             UndirectedEdge[249, 258] -> 
             RGBColor[
              0.2738091064777124, 0.40221653034560445`, 0.9390107464799751], 
             UndirectedEdge[146, 170] -> 
             RGBColor[
              0.19880274533348388`, 0.3262846685405311, 0.9346328942932117], 
             UndirectedEdge[18, 129] -> 
             RGBColor[
              0.1945312219559263, 0.32179502664049353`, 0.9343896373560123], 
             UndirectedEdge[13, 179] -> 
             RGBColor[
              0.42802275177735205`, 0.5432681021152472, 0.9490151577652866], 
             UndirectedEdge[144, 160] -> 
             RGBColor[
              0.19670215780285202`, 0.3240768178608952, 0.934513268940883], 
             UndirectedEdge[17, 130] -> 
             RGBColor[
              0.8077331614173798, 0.7282311492830874, 0.6094955989444572], 
             UndirectedEdge[111, 163] -> 
             RGBColor[
              0.6176770518281398, 0.70049708256499, 0.9630449466269559], 
             UndirectedEdge[107, 251] -> 
             RGBColor[
              0.34704129264344796`, 0.47287212594221606`, 0.943412473599851], 
             UndirectedEdge[1, 198] -> 
             RGBColor[
              0.8916422332040788, 0.5589019666811266, 0.5551782044510756], 
             UndirectedEdge[168, 269] -> 
             RGBColor[
              0.6867881591822118, 0.7211895103907764, 0.6484929822846838], 
             UndirectedEdge[145, 201] -> 
             RGBColor[
              0.8551339776040994, 0.6224043744000362, 0.5890252543779623], 
             UndirectedEdge[197, 226] -> 
             RGBColor[
              0.9862994243091077, 0.9886024741101505, 0.8767175253588012], 
             UndirectedEdge[105, 174] -> 
             RGBColor[
              0.25852249961576723`, 0.3890539167423275, 0.9380338459521285], 
             UndirectedEdge[178, 284] -> 
             RGBColor[
              0.24998452415634886`, 0.38007996319556836`, 0.9375476208805174],
              UndirectedEdge[201, 202] -> 
             RGBColor[
              0.8559674140090618, 0.41835228392990204`, 0.20072485105646432`],
              UndirectedEdge[24, 65] -> 
             RGBColor[
              0.6506137006766177, 0.6184091477452374, 0.6013947753940398], 
             UndirectedEdge[134, 169] -> 
             RGBColor[
              0.42476901028009817`, 0.532311534169465, 0.9496393645496872], 
             UndirectedEdge[104, 300] -> 
             RGBColor[
              0.2803668703826312, 0.4095782545351725, 0.9393670254375599], 
             UndirectedEdge[168, 225] -> 
             RGBColor[
              0.31400402532006444`, 0.4388934235578272, 0.9415037514868442], 
             UndirectedEdge[27, 202] -> 
             RGBColor[
              0.9182061196430783, 0.6984705750022384, 0.2738580279631242], 
             UndirectedEdge[113, 187] -> 
             RGBColor[
              0.24618639037776724`, 0.3760878837786886, 0.9373313227806626], 
             UndirectedEdge[7, 201] -> 
             RGBColor[
              0.8918418892803384, 0.651606686480418, 0.5901834370133114], 
             UndirectedEdge[51, 104] -> 
             RGBColor[
              0.5731922784257398, 0.6585842020957557, 0.9621993062038972], 
             UndirectedEdge[2, 183] -> 
             RGBColor[
              0.19566573686527955`, 0.3229874737426237, 0.9344542463017356], 
             UndirectedEdge[135, 249] -> 
             RGBColor[
              0.21026660117408774`, 0.33833390787944695`, 0.9352857439240791],
              UndirectedEdge[84, 270] -> 
             RGBColor[
              0.20015353292457566`, 0.32770443194364846`, 0.9347098196482133],
              UndirectedEdge[114, 116] -> 
             RGBColor[
              0.26324193971723214`, 0.3940143475187522, 0.9383026110841209], 
             UndirectedEdge[15, 168] -> 
             RGBColor[
              0.3293937457780264, 0.4550689955237798, 0.942380173299874], 
             UndirectedEdge[42, 237] -> 
             RGBColor[
              0.8313396990003062, 0.24189623642583113`, 0.17764423719680783`],
              UndirectedEdge[40, 140] -> 
             RGBColor[
              0.7532763216794478, 0.4456404138262269, 0.5669390131907837], 
             UndirectedEdge[42, 167] -> 
             RGBColor[
              0.8726433787924812, 0.48087452978022555`, 0.21411031746444492`],
              UndirectedEdge[16, 285] -> 
             RGBColor[
              0.22323502267117318`, 0.3519645411182973, 0.9360242763432778], 
             UndirectedEdge[8, 286] -> 
             RGBColor[
              0.21267948434468417`, 0.34087000107737286`, 0.9354231540511039],
              UndirectedEdge[9, 236] -> 
             RGBColor[
              0.21519552032906075`, 0.34351451442284786`, 0.9355664385782725],
              UndirectedEdge[54, 238] -> 
             RGBColor[
              0.21574020514797415`, 0.344087012702538, 0.9355974575729206], 
             UndirectedEdge[165, 183] -> 
             RGBColor[
              0.2052672821395783, 0.33307930659904317`, 0.9350010401008936], 
             UndirectedEdge[249, 263] -> 
             RGBColor[
              0.20867298294508915`, 0.33665891407953785`, 0.9351949897234846],
              UndirectedEdge[33, 98] -> 
             RGBColor[
              0.18977923539730202`, 0.3168003874740297, 0.9341190187514328], 
             UndirectedEdge[282, 293] -> 
             RGBColor[
              0.6701954566467123, 0.5968924733689558, 0.5936831325375491], 
             UndirectedEdge[54, 163] -> 
             RGBColor[
              0.4325936369919836, 0.5385727559524309, 0.9502636460208878], 
             UndirectedEdge[145, 237] -> 
             RGBColor[
              0.8449892632007987, 0.5444276540540705, 0.5793106644085455], 
             UndirectedEdge[140, 181] -> 
             RGBColor[
              0.9018064820205194, 0.5497777318797257, 0.2827365338887451], 
             UndirectedEdge[15, 265] -> 
             RGBColor[
              0.24054595553413333`, 0.37015942913380495`, 0.9370101083605932],
              UndirectedEdge[144, 230] -> 
             RGBColor[
              0.19486271425090618`, 0.32214344606034284`, 0.9344085153518125],
              UndirectedEdge[22, 266] -> 
             RGBColor[
              0.1933455924812791, 0.32054885488938883`, 0.9343221175114128], 
             UndirectedEdge[18, 165] -> 
             RGBColor[
              0.2088844992725249, 0.33688123115058255`, 0.9352070352654217], 
             UndirectedEdge[17, 140] -> 
             RGBColor[
              0.7604910702916794, 0.4512766302762225, 0.5676581119067918], 
             UndirectedEdge[80, 237] -> 
             RGBColor[
              0.9019415360113127, 0.566959177926033, 0.27190996500840703`], 
             UndirectedEdge[7, 127] -> 
             RGBColor[
              0.6435774661849356, 0.7150423967840147, 0.9663706566026036], 
             UndirectedEdge[60, 212] -> 
             RGBColor[
              0.2603180236560096, 0.39094112635142153`, 0.9381360983899805], 
             UndirectedEdge[53, 270] -> 
             RGBColor[
              0.21435826979552958`, 0.3426345110273567, 0.935518758398989], 
             UndirectedEdge[243, 254] -> 
             RGBColor[
              0.6530996726183891, 0.7197996840615158, 0.8998607275791879], 
             UndirectedEdge[201, 277] -> 
             RGBColor[
              0.9191876398595434, 0.6685769154126919, 0.3358815336975568], 
             UndirectedEdge[288, 296] -> 
             RGBColor[
              0.1980362372485557, 0.3254790199438521, 0.9345892427917222], 
             UndirectedEdge[93, 273] -> 
             RGBColor[
              0.24003010742833283`, 0.36961724006794966`, 0.9369807315740968],
              UndirectedEdge[128, 277] -> 
             RGBColor[
              0.9189757209517455, 0.6669480138238988, 0.3356785999121213], 
             UndirectedEdge[3, 115] -> 
             RGBColor[
              0.6529735529155825, 0.7222241006469869, 0.9530066800693597], 
             UndirectedEdge[74, 123] -> 
             RGBColor[
              0.20225228122772315`, 0.32991034947858455`, 0.9348293402592576],
              UndirectedEdge[52, 147] -> 
             RGBColor[
              0.20606540532151835`, 0.3339181846671946, 0.9350464920353876], 
             UndirectedEdge[64, 76] -> 
             RGBColor[
              0.28111114711231006`, 0.41111591460968555`, 0.939381752805837], 
             UndirectedEdge[132, 260] -> 
             RGBColor[
              0.2275319348126233, 0.35648086821892655`, 0.9362689791330215], 
             UndirectedEdge[171, 285] -> 
             RGBColor[
              0.18941388075270052`, 0.31641637657773114`, 0.9340982123449165],
              UndirectedEdge[226, 290] -> 
             RGBColor[
              0.9663340369194856, 0.9069146206326038, 0.576578764162101], 
             UndirectedEdge[24, 290] -> 
             RGBColor[
              0.9350874753344331, 0.7803505010572445, 0.2666280628425426], 
             UndirectedEdge[103, 265] -> 
             RGBColor[
              0.3220227389937979, 0.445387567907627, 0.9420312197585695], 
             UndirectedEdge[41, 208] -> 
             RGBColor[
              0.1889556017616225, 0.3159346963015419, 0.9340721140343375], 
             UndirectedEdge[80, 179] -> 
             RGBColor[
              0.7507825863487789, 0.7818072220217351, 0.663873785850424], 
             UndirectedEdge[102, 183] -> 
             RGBColor[
              0.19246783079694663`, 0.31962627170585023`, 0.934272130282022], 
             UndirectedEdge[16, 220] -> 
             RGBColor[
              0.2899399087951104, 0.41982488843615623`, 0.9399054307139528], 
             UndirectedEdge[52, 217] -> 
             RGBColor[
              0.19938565089971289`, 0.32689733924898534`, 0.9346660899028769],
              UndirectedEdge[24, 241] -> 
             RGBColor[
              0.9549441101488896, 0.8619933825501465, 0.5685691356523801], 
             UndirectedEdge[105, 163] -> 
             RGBColor[
              0.4524953087499887, 0.5594906748089641, 0.9513970167856213], 
             UndirectedEdge[2, 102] -> 
             RGBColor[
              0.19539325191364892`, 0.3227010747819161, 0.9344387286868456], 
             UndirectedEdge[49, 54] -> 
             RGBColor[
              0.22682934694082163`, 0.355742403819019, 0.936228967793108], 
             UndirectedEdge[216, 237] -> 
             RGBColor[
              0.8457691907154687, 0.3401325922104371, 0.19096561195736456`], 
             UndirectedEdge[89, 281] -> 
             RGBColor[
              0.6796029595718664, 0.743830302697593, 0.9334123929687868], 
             UndirectedEdge[145, 167] -> 
             RGBColor[
              0.8862929429929738, 0.7834059474084649, 0.6157767446761826], 
             UndirectedEdge[16, 90] -> 
             RGBColor[
              0.2312332284112072, 0.3603711624666066, 0.9364797623278878], 
             UndirectedEdge[210, 290] -> 
             RGBColor[
              0.7090449941186435, 0.7036067912817707, 0.613645317642163], 
             UndirectedEdge[152, 242] -> 
             RGBColor[
              0.1817008098525566, 0.3083094500247394, 0.9336589643676192], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.18784627824446665`, 0.31476872694983776`, 0.9340089397011326],
              UndirectedEdge[77, 282] -> 
             RGBColor[
              0.42720741988360567`, 0.5444473278590943, 0.9484422569236628], 
             UndirectedEdge[81, 162] -> 
             RGBColor[
              0.9404065856589258, 0.790829015220349, 0.5112620539625906], 
             UndirectedEdge[34, 247] -> 
             RGBColor[
              0.1907246807083084, 0.31779411044059236`, 0.9341728604632337], 
             UndirectedEdge[7, 60] -> 
             RGBColor[
              0.6127935489939296, 0.6863930727259957, 0.9644818440323379], 
             UndirectedEdge[155, 162] -> 
             RGBColor[
              0.9588310572734952, 0.8681281277104613, 0.5263067793464253], 
             UndirectedEdge[234, 249] -> 
             RGBColor[
              0.2008059288288086, 0.3283901414032867, 0.934746972629826], 
             UndirectedEdge[118, 234] -> 
             RGBColor[
              0.19143808005152518`, 0.3185439383824441, 0.9342134875004501], 
             UndirectedEdge[223, 271] -> 
             RGBColor[
              0.20206279459486376`, 0.3297111870133029, 0.9348185492758365], 
             UndirectedEdge[154, 216] -> 
             RGBColor[
              0.6818806659330219, 0.5446461937629699, 0.581927314015972], 
             UndirectedEdge[147, 247] -> 
             RGBColor[
              0.2055770841992048, 0.33340492820629564`, 0.9350186828698783], 
             UndirectedEdge[4, 286] -> 
             RGBColor[
              0.22071420539136402`, 0.34931500232817103`, 0.9358807195284078],
              UndirectedEdge[88, 124] -> 
             RGBColor[
              0.20439146202389424`, 0.3321587641272566, 0.9349511634409652], 
             UndirectedEdge[23, 136] -> 
             RGBColor[
              0.6909810750975458, 0.7521740618261392, 0.8862275585719336], 
             UndirectedEdge[11, 104] -> 
             RGBColor[
              0.4334513122055766, 0.547724101182389, 0.9494290167598639], 
             UndirectedEdge[4, 121] -> 
             RGBColor[
              0.2229935575329976, 0.35171074594830076`, 0.9360105252608744], 
             UndirectedEdge[4, 213] -> 
             RGBColor[
              0.21145636706915383`, 0.33958442727067606`, 0.9353534993317023],
              UndirectedEdge[198, 204] -> 
             RGBColor[
              0.7240997016369111, 0.7823833581016821, 0.9486564217578735], 
             UndirectedEdge[156, 168] -> 
             RGBColor[
              0.3974514720884778, 0.5186742214563766, 0.9465462342423088], 
             UndirectedEdge[31, 226] -> 
             RGBColor[
              0.7029528418062473, 0.7632425995782364, 0.912689477230743], 
             UndirectedEdge[36, 242] -> 
             RGBColor[
              0.18110760662426995`, 0.30768595582055314`, 0.9336251823213337],
              UndirectedEdge[216, 269] -> 
             RGBColor[
              0.9198143078765437, 0.7038328982122137, 0.28026875837406984`], 
             UndirectedEdge[97, 202] -> 
             RGBColor[
              0.6577144481717172, 0.5251054048614994, 0.5800987564788447], 
             UndirectedEdge[23, 59] -> 
             RGBColor[
              0.9871771704378065, 0.988965444691414, 0.8621710004720957], 
             UndirectedEdge[174, 238] -> 
             RGBColor[
              0.21032414623090429`, 0.3383943913827284, 0.9352890210299346], 
             UndirectedEdge[86, 97] -> 
             RGBColor[
              0.5215176139849236, 0.6223094238976072, 0.9555083823712963], 
             UndirectedEdge[46, 212] -> 
             RGBColor[
              0.21903868251240277`, 0.34755392154809645`, 0.9357853009791648],
              UndirectedEdge[59, 291] -> 
             RGBColor[
              0.955941254786202, 0.9662985742039245, 0.945506158028788], 
             UndirectedEdge[125, 149] -> 
             RGBColor[
              0.865349139567608, 0.4449573647077131, 0.20792686311137834`], 
             UndirectedEdge[32, 80] -> 
             RGBColor[
              0.9832422855582464, 0.9646748589231064, 0.6130382528147665], 
             UndirectedEdge[69, 90] -> 
             RGBColor[
              0.21162247094140993`, 0.33975901297201105`, 0.9353629587014987],
              UndirectedEdge[215, 229] -> 
             RGBColor[
              0.2212270314220612, 0.34985401500148217`, 0.9359099242121978], 
             UndirectedEdge[187, 245] -> 
             RGBColor[
              0.22499133551940492`, 0.35381053727845513`, 0.9361242957617526],
              UndirectedEdge[98, 275] -> 
             RGBColor[
              0.17961340510331275`, 0.30611545528417883`, 0.9335400897551883],
              UndirectedEdge[252, 280] -> 
             RGBColor[
              0.2499775972482043, 0.3800726825759171, 0.937547226403346], 
             UndirectedEdge[96, 146] -> 
             RGBColor[
              0.20048974504421074`, 0.3280578121984645, 0.9347289664310452], 
             UndirectedEdge[191, 270] -> 
             RGBColor[
              0.22010792895967446`, 0.34867776735831935`, 0.9358461929825286],
              UndirectedEdge[40, 120] -> 
             RGBColor[
              0.4841619759818365, 0.5839129078583203, 0.9544325893141365], 
             UndirectedEdge[215, 233] -> 
             RGBColor[
              0.2150686635576537, 0.34338117991291517`, 0.9355592142728086], 
             UndirectedEdge[21, 257] -> 
             RGBColor[
              0.1888268034733999, 0.3157993211343368, 0.9340647791623633], 
             UndirectedEdge[200, 245] -> 
             RGBColor[
              0.2954064062007655, 0.4225674449726149, 0.9403266970812623], 
             UndirectedEdge[41, 108] -> 
             RGBColor[
              0.21464006545615802`, 0.34293069613355404`, 0.9355348062449824],
              UndirectedEdge[63, 73] -> 
             RGBColor[
              0.18277574146873998`, 0.309439271307949, 0.933720180132942]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.8649038628242013, 0.8951148792988238, 0.9869764966166072], 
             160 -> RGBColor[
              0.19576440547633542`, 0.32309118070879467`, 0.9344598653331682],
              245 -> RGBColor[
              0.22524249753236514`, 0.35407452447866766`, 0.9361385990668298],
              155 -> RGBColor[
              0.9263138375757084, 0.7455659509853682, 0.2595685879581257], 
             213 -> RGBColor[
              0.20237506472464956`, 0.3300394027187775, 0.9348363325977657], 
             27 -> RGBColor[
              0.9698415036520304, 0.9099304516459211, 0.33734036595263717`], 
             19 -> RGBColor[
              0.18771789764902583`, 0.31463379080422954`, 0.9340016286161444],
              164 -> RGBColor[
              0.18196114135351968`, 0.30858307493822207`, 0.9336737898614731],
              190 -> RGBColor[
              0.2044144915577996, 0.3321829696275479, 0.9349524749388519], 
             103 -> RGBColor[
              0.4213296380105047, 0.5393562886265211, 0.9480677298602272], 
             138 -> RGBColor[
              0.231287806205471, 0.36042852718880986`, 0.9364828704525304], 
             291 -> RGBColor[
              0.926874823682218, 0.9445288413300859, 0.9928873421853748], 28 -> 
             RGBColor[
              0.18347004528514485`, 0.31016902864039503`, 0.9337597197081559],
              195 -> RGBColor[
              0.18372407711397143`, 0.31043603219904004`, 0.9337741864450011],
              114 -> RGBColor[
              0.23913206195702244`, 0.3686733373382309, 0.9369295892130448], 
             93 -> RGBColor[
              0.24113006344271598`, 0.3707733635803057, 0.9370433724418767], 
             34 -> RGBColor[
              0.1836929464736069, 0.31040331192222026`, 0.933772413601086], 
             161 -> RGBColor[
              0.2016546493170191, 0.3292822004483829, 0.9347953060060602], 22 -> 
             RGBColor[
              0.18854143418810532`, 0.3154993799220345, 0.9340485278037318], 
             124 -> RGBColor[
              0.1859244664032461, 0.3127487808548065, 0.9338994953598411], 84 -> 
             RGBColor[
              0.18746791982634672`, 0.31437104826308443`, 0.9339873927489519],
              46 -> RGBColor[
              0.2047087295239663, 0.33249223238575365`, 0.9349692313557391], 
             241 -> RGBColor[
              0.986124206873734, 0.9885300171977407, 0.8796213317111282], 185 -> 
             RGBColor[
              0.5295564396500168, 0.6289567998104505, 0.9561077692398556], 
             121 -> RGBColor[
              0.22544944565233713`, 0.35429204007402687`, 0.9361503844561099],
              126 -> RGBColor[
              0.22348836128871713`, 0.3522308160679321, 0.9360387036027661], 
             236 -> RGBColor[
              0.23143093535124384`, 0.3605789649959291, 0.9364910214456416], 
             78 -> RGBColor[
              0.19413140389541048`, 0.3213747925089622, 0.9343668683089438], 
             254 -> RGBColor[
              0.31878183695974033`, 0.45053453755869494`, 0.9415334746567325],
              290 -> RGBColor[
              0.9464109372448213, 0.8252442542119368, 0.27573918609145315`], 
             251 -> RGBColor[
              0.28560729073547014`, 0.4175217494840773, 0.9395762847380378], 
             165 -> RGBColor[
              0.21779424853057935`, 0.34624594253152846`, 0.935714432304875], 
             100 -> 
             RGBColor[
              0.1806628381309981, 0.3072184759341732, 0.933599853413618], 235 -> 
             RGBColor[
              0.40849384697781144`, 0.528238571579618, 0.9472498446058684], 
             70 -> RGBColor[
              0.20976983040282712`, 0.33781177030176596`, 0.9352574535635624],
              234 -> RGBColor[
              0.1941551643020383, 0.3213997662028249, 0.9343682214289508], 
             257 -> RGBColor[
              0.18407578926115742`, 0.31080570396557056`, 0.9337942159314718],
              135 -> RGBColor[
              0.21307650899259664`, 0.34128729915514544`, 0.9354457640174572],
              265 -> RGBColor[
              0.22271583997709107`, 0.35141884718873295`, 0.9359947096569118],
              111 -> RGBColor[
              0.6142037164471443, 0.6976772724307221, 0.9627715129425172], 
             182 -> RGBColor[
              0.2543436096659436, 0.38466163844813683`, 0.9377958643515997], 
             188 -> RGBColor[
              0.35586441424032067`, 0.4826536021746064, 0.9438963436902155], 
             154 -> RGBColor[
              0.4972976140125026, 0.6027676319143825, 0.9535682363176986], 
             269 -> RGBColor[
              0.9731648978995463, 0.9211410408128702, 0.3502511250338943], 
             208 -> RGBColor[
              0.18931653926981418`, 0.3163140645074111, 0.9340926688914699], 
             86 -> RGBColor[
              0.5941770672605392, 0.6814187364307716, 0.9611949417585145], 
             119 -> RGBColor[
              0.18085158366002294`, 0.307416859452336, 0.933610602192272], 
             140 -> RGBColor[0.817319, 0.134127, 0.164218], 85 -> 
             RGBColor[
              0.23214849009490668`, 0.36133316052711717`, 0.9365318851267661],
              242 -> RGBColor[
              0.18088209567567362`, 0.3074489295153584, 0.9336123398064248], 
             117 -> RGBColor[
              0.1855098238772711, 0.3123129652701522, 0.9338758820813954], 47 -> 
             RGBColor[
              0.18409960782193097`, 0.31083073878312756`, 0.9337955723632715],
              81 -> RGBColor[
              0.8894648943465696, 0.5909677260051436, 0.2294791371904563], 
             275 -> RGBColor[
              0.1801747671672662, 0.30670548240580453`, 0.9335720584942697], 
             23 -> RGBColor[
              0.989346654985427, 0.9898625823050647, 0.82621702707199], 110 -> 
             RGBColor[
              0.18591721951216156`, 0.3127411639127972, 0.9338990826601146], 
             6 -> RGBColor[
              0.2105950138195758, 0.3386790903924193, 0.9353044465383967], 
             218 -> RGBColor[
              0.9671895696970209, 0.9750506153189628, 0.9404236795589124], 
             108 -> RGBColor[
              0.24068546665888524`, 0.3703060641714354, 0.9370180533127597], 
             297 -> RGBColor[
              0.19199315011410678`, 0.319127352211692, 0.9342450979193615], 
             157 -> RGBColor[
              0.18253809113335498`, 0.30918948573755783`, 0.933706646297914], 
             270 -> RGBColor[
              0.2128391460228046, 0.3410378156242125, 0.9354322465474746], 33 -> 
             RGBColor[
              0.20050642775524471`, 0.3280753467855062, 0.9347299164867587], 
             252 -> RGBColor[
              0.23794228148785246`, 0.3674228026286945, 0.9368618329754481], 
             260 -> RGBColor[
              0.25816755850577977`, 0.38868085113116446`, 0.938013632581003], 
             159 -> RGBColor[
              0.29124080035179, 0.42344292527596916`, 0.9398971047766567], 
             183 -> RGBColor[
              0.19274031574857725`, 0.3199126706665578, 0.9342876478969121], 
             99 -> RGBColor[
              0.19567419878950365`, 0.3229963677615002, 0.9344547281958019], 
             17 -> RGBColor[
              0.7036631405833589, 0.768426260552445, 0.9710982238135836], 277 -> 
             RGBColor[
              0.9930111873350895, 0.9874599613241353, 0.4806890552557963], 
             104 -> RGBColor[
              0.3350878162698179, 0.46465795727473413`, 0.9425724772395593], 
             79 -> RGBColor[
              0.18314084159618357`, 0.3098230146905773, 0.9337409720450827], 
             191 -> RGBColor[
              0.2273767118965443, 0.3563177190924262, 0.9362601394175826], 50 -> 
             RGBColor[
              0.1818234123124711, 0.30843831298355445`, 0.9336659463963373], 
             225 -> RGBColor[
              0.2275966301752516, 0.35654886714697176`, 0.936272663438215], 
             61 -> RGBColor[
              0.2772592389822082, 0.4087474177943471, 0.9391008755405253], 
             196 -> RGBColor[
              0.2030597206401025, 0.3307590194956109, 0.934875322739293], 1 -> 
             RGBColor[
              0.8186934053129894, 0.1446912815038851, 0.16553413207988746`], 
             263 -> RGBColor[
              0.20988927253459944`, 0.3379373115553272, 0.935264255616268], 
             201 -> RGBColor[
              0.8453640923839973, 0.3496938695012485, 0.19107401213931735`], 
             293 -> 
             RGBColor[
              0.8997587664774066, 0.6377097951563564, 0.23806859642232206`], 
             184 -> RGBColor[
              0.1914897805011185, 0.3185982788329645, 0.9342164317645705], 
             106 -> RGBColor[
              0.861860606843299, 0.8926882695866354, 0.9866862281444021], 206 -> 
             RGBColor[
              0.22242260484653656`, 0.35111063847433904`, 0.9359780103500293],
              247 -> RGBColor[
              0.19775641494300986`, 0.32518490895896446`, 0.9345733073253814],
              220 -> RGBColor[
              0.33308943974472227`, 0.4629270639700209, 0.9424451424544752], 
             107 -> RGBColor[
              0.40847529455142584`, 0.5282225024003548, 0.9472486624616643], 
             131 -> RGBColor[
              0.22940782651350908`, 0.3584525493349609, 0.9363758083902539], 
             127 -> RGBColor[
              0.34883524619319184`, 0.47656529010844195`, 0.9434484513179017],
              210 -> RGBColor[
              0.4716790509924657, 0.5819693283516046, 0.9515514491928728], 
             181 -> RGBColor[
              0.9862939640410388, 0.9654284637594515, 0.4012550677774902], 
             194 -> RGBColor[
              0.6860055424687634, 0.754632010702607, 0.9693382794531569], 118 -> 
             RGBColor[
              0.1887209958010121, 0.3156881105620633, 0.9340587535719493], 
             276 -> RGBColor[
              0.24137384732010603`, 0.3710295958922332, 0.9370572555730482], 
             280 -> RGBColor[
              0.2620129130085561, 0.39272256252313964`, 0.938232619831244], 
             189 -> RGBColor[
              0.21583585429987417`, 0.3441875460256914, 0.935602904650621], 
             168 -> RGBColor[
              0.4004114204648772, 0.5212379799686826, 0.9467348395354733], 41 -> 
             RGBColor[
              0.1885946642534308, 0.31555532809567266`, 0.9340515591772053], 
             14 -> RGBColor[
              0.1801938510546308, 0.30672554078141306`, 0.9335731452934231], 
             77 -> RGBColor[
              0.4137826929511934, 0.5328195041366336, 0.9475868451945494], 51 -> 
             RGBColor[
              0.8112967405816618, 0.8525104469167772, 0.981826135168235], 179 -> 
             RGBColor[
              0.5227567642523288, 0.6234365170007214, 0.9555724738845179], 
             223 -> RGBColor[
              0.1814903715451621, 0.30808826602110845`, 0.9336469802173286], 
             292 -> RGBColor[
              0.773715577090376, 0.8231517563699634, 0.978080396007364], 143 -> 
             RGBColor[
              0.3068945586163886, 0.4398960177176607, 0.9407885631521654], 
             112 -> RGBColor[
              0.18923133529375677`, 0.3162245097263307, 0.9340878166510814], 
             197 -> RGBColor[
              0.9863417120240653, 0.9886199611670301, 0.8760167084848537], 54 -> 
             RGBColor[
              0.24403688677483204`, 0.37382861920560384`, 0.937208911730381], 
             71 -> RGBColor[
              0.22331684544677569`, 0.35205054204331915`, 0.9360289360293025],
              177 -> RGBColor[
              0.29197171960673096`, 0.42421116775586953`, 0.9399387295469274],
              158 -> RGBColor[
              0.19294565339664288`, 0.32012849355383366`, 0.9342993415721996],
              226 -> RGBColor[
              0.9862571365941499, 0.9885849870532707, 0.8774183422327487], 
             203 -> RGBColor[
              0.9371250918628792, 0.9526285769763242, 0.9913149984604726], 
             115 -> RGBColor[
              0.3517287364030146, 0.47907148589714393`, 0.9436328219554587], 
             173 -> RGBColor[
              0.20128694378722742`, 0.32889571862269473`, 0.9347743657201101],
              212 -> RGBColor[
              0.23336863550083925`, 0.36261561071043924`, 0.9366013706025906],
              129 -> RGBColor[
              0.18908769389738214`, 0.3160735335113504, 0.9340796364860563], 
             279 -> RGBColor[
              0.23666672657285628`, 0.3660821135381808, 0.9367891920100534], 
             26 -> RGBColor[
              0.2290956026577889, 0.35812438226646315`, 0.9363580277035645], 
             40 -> RGBColor[
              0.6892336433588957, 0.7571538276524538, 0.9696600263815672], 
             146 -> RGBColor[
              0.20002902465321373`, 0.3275735658561667, 0.9347027290863527], 
             192 -> RGBColor[
              0.3306172943235091, 0.4607858158598078, 0.9422876195342679], 
             300 -> RGBColor[
              0.2256459244954445, 0.3544985517956109, 0.9361615736355604], 
             221 -> RGBColor[
              0.1861956076915163, 0.31303376754012907`, 0.9339149364550904], 
             62 -> RGBColor[
              0.20167701950442632`, 0.3293057129336997, 0.9347965799551393], 
             286 -> RGBColor[
              0.22089074136906994`, 0.34950055283376746`, 0.9358907729911765],
              152 -> RGBColor[
              0.1825195240294396, 0.3091699705341204, 0.9337055889288136], 64 -> 
             RGBColor[
              0.2353045398184947, 0.3646503688917182, 0.9367116174895672], 37 -> 
             RGBColor[
              0.22656828106141946`, 0.3554680070272346, 0.9362141004774884], 
             148 -> RGBColor[
              0.2462972527349853, 0.37620440714520426`, 0.9373376362279], 261 -> 
             RGBColor[
              0.24473644409614725`, 0.3745638983048021, 0.9372487504849276], 
             15 -> RGBColor[
              0.2583760710911756, 0.38890001107887695`, 0.9380255070642746], 
             136 -> RGBColor[
              0.39261549520966454`, 0.5144855413472138, 0.9462380900718772], 
             198 -> RGBColor[
              0.964591061095168, 0.9731126518583681, 0.9448222768222637], 63 -> 
             RGBColor[
              0.18288267188311363`, 0.3095516619532356, 0.9337262696618512], 
             171 -> RGBColor[
              0.17914809400855325`, 0.30562638382115925`, 0.9335135909767078],
              59 -> RGBColor[
              0.985007685890186, 0.9880683070777632, 0.8981249738722014], 229 -> 
             RGBColor[
              0.2177123475199571, 0.3461598593765405, 0.9357097681634818], 
             102 -> RGBColor[
              0.19219534584531597`, 0.31933987274514264`, 0.9342566126671321],
              299 -> RGBColor[
              0.8186938987840391, 0.1446950745386128, 0.16553460462832187`], 
             128 -> RGBColor[
              0.8449402545684014, 0.34643606632366236`, 0.19066814456844627`],
              12 -> RGBColor[
              0.42962012936485927`, 0.5465370955454517, 0.948595992638333], 
             222 -> RGBColor[
              0.2214255710569613, 0.35006269274590207`, 0.9359212307506922], 
             92 -> RGBColor[
              0.8315546894535105, 0.24354874725857717`, 0.17785011229759332`],
              271 -> RGBColor[
              0.2226352176445654, 0.3513341080054973, 0.9359901183343445], 
             132 -> RGBColor[
              0.19689631111946682`, 0.3242808853066886, 0.9345243256850401], 
             80 -> RGBColor[
              0.9788084084452291, 0.9401779270427488, 0.37217509781633024`], 
             244 -> RGBColor[
              0.1895037720729246, 0.31651085805472556`, 0.934103331522621], 
             150 -> RGBColor[
              0.9074094141907081, 0.6706162117894943, 0.24435764515870567`], 
             125 -> RGBColor[
              0.8351944719959239, 0.27152571084244637`, 0.18133557217075477`],
              258 -> RGBColor[
              0.340161519599846, 0.46905254408746033`, 0.942895769129249], 
             133 -> RGBColor[
              0.18528931800943133`, 0.31208119962217307`, 0.9338633245984311],
              255 -> 
             RGBColor[
              0.3660178719215669, 0.49144801689048034`, 0.9445433130353144], 
             176 -> RGBColor[
              0.19419263806779313`, 0.3214391535066072, 0.9343703555044731], 
             230 -> RGBColor[
              0.19208551837244375`, 0.31922443710768994`, 0.9342503581550272],
              274 -> RGBColor[
              0.46304655962256364`, 0.5749610829682137, 0.9508718678503764], 
             87 -> RGBColor[
              0.9931480500222558, 0.9877526967730439, 0.4955857141352578], 
             130 -> RGBColor[
              0.9118031822514008, 0.6880360380137298, 0.24789297407533079`], 
             35 -> RGBColor[
              0.20639345636736367`, 0.33426298711601565`, 0.9350651740571405],
              31 -> RGBColor[
              0.41964854701834464`, 0.537900212103202, 0.9479606122287372], 
             18 -> RGBColor[
              0.19997475001447043`, 0.3275165197696367, 0.9346996382259684], 
             24 -> RGBColor[
              0.9237640134240451, 0.7354567479025522, 0.2575169395936321], 
             151 -> RGBColor[
              0.5978280581771518, 0.684382775332144, 0.9614823611374906], 137 -> 
             RGBColor[
              0.26153416243522165`, 0.3922193653160256, 0.9382053556943405], 
             296 -> RGBColor[
              0.18720713771192796`, 0.31409694972628927`, 0.9339725415933283],
              266 -> RGBColor[
              0.1981497507744529, 0.3255983298567432, 0.9345957072190938], 
             283 -> RGBColor[
              0.3058207768282486, 0.438767404976628, 0.9407274128678487], 284 -> 
             RGBColor[
              0.24095771526907575`, 0.3705922147223045, 0.9370335574683543], 
             238 -> RGBColor[
              0.1874435235211163, 0.31434540619947215`, 0.9339860034154601], 
             72 -> RGBColor[
              0.8294154563220671, 0.22710566399236717`, 0.1758015802350048], 
             288 -> RGBColor[
              0.20886533678518346`, 0.33686109016141486`, 0.9352059439901159],
              172 -> RGBColor[
              0.19058407149220488`, 0.3176463212393284, 0.9341648529763892], 
             243 -> RGBColor[
              0.9874175082770378, 0.9890648305643368, 0.8581879805016432], 88 -> 
             RGBColor[
              0.22285845764454237`, 0.35156874739970667`, 0.9360028315220893],
              273 -> RGBColor[
              0.2389301514139497, 0.3684611165555936, 0.9369180907063167], 
             202 -> RGBColor[
              0.8665707356341262, 0.4870106983585556, 0.21037568997361125`], 
             98 -> 
             RGBColor[
              0.1790520430393593, 0.3055254281625532, 0.9335081210161069], 30 -> 
             RGBColor[
              0.24929644188312317`, 0.37935674509947226`, 0.9375084356129837],
              116 -> RGBColor[
              0.2873518174774419, 0.41935535769927346`, 0.9396756329551971], 
             240 -> RGBColor[
              0.18053047455342514`, 0.3070793534218085, 0.9335923155036896], 
             73 -> RGBColor[
              0.1826688110543663, 0.3093268806626624, 0.9337140906040328], 29 -> 
             RGBColor[
              0.19525519293228838`, 0.32255596603906117`, 0.934430866432097], 
             75 -> RGBColor[
              0.3329293714790703, 0.46278842088357813`, 0.9424349430461306], 
             200 -> RGBColor[
              0.3655703148691659, 0.4910603654665621, 0.9445147950956946], 
             156 -> RGBColor[
              0.3944915237120784, 0.5161104629440706, 0.9463576289491441], 25 -> 
             RGBColor[
              0.1911156300253715, 0.31820502296044406`, 0.9341951244484827], 
             38 -> RGBColor[
              0.18611948239069784`, 0.312953755022346, 0.9339106012318261], 3 -> 
             RGBColor[
              0.9542183694281502, 0.96537671539683, 0.9623805381832607], 57 -> 
             RGBColor[
              0.17967566298483006`, 0.30618089226503126`, 0.9335436352494385],
              227 -> RGBColor[
              0.952704487454567, 0.8501960835922951, 0.28080312431882476`], 
             39 -> RGBColor[
              0.20172422019829714`, 0.3293553238556548, 0.934799267964828], 
             109 -> RGBColor[
              0.9928111618057213, 0.9912952449090205, 0.7688011832034702], 
             256 -> RGBColor[
              0.817928104297447, 0.13880884254138265`, 0.16480127896312016`], 
             287 -> RGBColor[
              0.2430009596347453, 0.3727397940997984, 0.9371499172122699], 
             239 -> RGBColor[
              0.23757609093788187`, 0.36703791314285356`, 0.9368409789653577],
              285 -> RGBColor[
              0.1996796674968478, 0.327206369334303, 0.9346828337131252], 216 -> 
             RGBColor[
              0.8664637178535413, 0.48652475561155717`, 0.21028639171424535`],
              21 -> RGBColor[
              0.19357781768564236`, 0.320792938303103, 0.9343353423932549], 
             175 -> RGBColor[
              0.18260859612989327`, 0.30926359095919453`, 0.9337106614531641],
              7 -> RGBColor[
              0.9383196861766793, 0.9535195034595876, 0.9892928618873055], 13 -> 
             RGBColor[
              0.33328873930237535`, 0.463099687229773, 0.9424578416460552], 
             294 -> RGBColor[
              0.5360494193639693, 0.63422809324764, 0.9566189203875064], 193 -> 
             RGBColor[
              0.27956374695486264`, 0.41116960178785156`, 0.939232113860354], 
             60 -> RGBColor[
              0.28726741181117993`, 0.4192666419924039, 0.9396708261773704], 
             65 -> RGBColor[
              0.3774633879291902, 0.5013615475879224, 0.9452726111944477], 69 -> 
             RGBColor[
              0.20756886290590398`, 0.3354984139131004, 0.9351321117206522], 
             217 -> RGBColor[
              0.20003824461178885`, 0.32758325661720833`, 0.9347032541493537],
              214 -> RGBColor[
              0.20083038530367384`, 0.32841584670900015`, 0.9347483653898895],
              170 -> RGBColor[
              0.19757646601375403`, 0.32499577122489554`, 0.9345630595000708],
              74 -> RGBColor[
              0.20590138873724428`, 0.3337457928378705, 0.935037151533554], 
             246 -> RGBColor[
              0.1844498116639085, 0.31119882522525194`, 0.9338155159539919], 
             264 -> RGBColor[
              0.2962099519152749, 0.42866581863159803`, 0.9401800906069961], 
             278 -> RGBColor[
              0.2006299825882091, 0.3282052107487807, 0.934736952751713], 45 -> 
             RGBColor[
              0.29993474933268105`, 0.43258081688308847`, 0.9403922123095734],
              237 -> RGBColor[
              0.8250746635773962, 0.19374042880931708`, 0.17164483220048377`],
              228 -> RGBColor[
              0.426257062503514, 0.5436241760628097, 0.9483817009917713], 180 -> 
             RGBColor[
              0.19488460571983207`, 0.32216645538218325`, 0.9344097620385824],
              53 -> RGBColor[
              0.21587739356825456`, 0.3442312064305009, 0.9356052702505034], 
             48 -> RGBColor[
              0.1928098846058197, 0.31998579194643995`, 0.9342916097404141], 
             5 -> RGBColor[
              0.9710126878169619, 0.9138811308413543, 0.3418901952738247], 
             101 -> RGBColor[
              0.6473280227603806, 0.724416838346381, 0.9654832657505968], 267 -> 
             RGBColor[
              0.1962060745132835, 0.32355540287006146`, 0.9344850177314316], 
             120 -> RGBColor[
              0.27909030860477735`, 0.41067198806418675`, 0.939205152246706], 
             147 -> RGBColor[
              0.21339775345539977`, 0.34162494745362687`, 0.9354640584143752],
              89 -> 
             RGBColor[
              0.3807443443279537, 0.5042033471148679, 0.9454816708349412], 43 -> 
             RGBColor[
              0.2255865897625529, 0.3544361872293025, 0.9361581946103001], 
             199 -> RGBColor[
              0.19839476243792764`, 0.32585585264969186`, 0.9346096602708663],
              268 -> RGBColor[
              0.20504953117466115`, 0.3328504365287066, 0.9349886395055752], 
             169 -> RGBColor[
              0.6047389625257771, 0.6899933588150511, 0.9620264128432912], 20 -> 
             RGBColor[
              0.21900416978762977`, 0.3475176464861269, 0.9357833355305459], 
             4 -> RGBColor[
              0.2205376694136581, 0.34912945182257465`, 0.935870666065639], 
             167 -> RGBColor[
              0.9076820231617462, 0.6716970155181059, 0.2445769927357579], 
             142 -> RGBColor[
              0.8299355921400753, 0.23110365581454728`, 0.17629966288173887`],
              16 -> RGBColor[
              0.24679037784549854`, 0.37672271290229153`, 0.9373657189734305],
              281 -> RGBColor[
              0.9784615748157791, 0.9834572582803182, 0.9213431151026323], 
             289 -> RGBColor[
              0.2434445902532613, 0.3732060780076645, 0.9371751813197018], 
             178 -> RGBColor[
              0.25901133304362195`, 0.3895677116688322, 0.9380616842926806], 
             58 -> RGBColor[
              0.19114091674596853`, 0.31823160090706226`, 0.9341965644898124],
              186 -> RGBColor[
              0.19311599281626868`, 0.32030753108400334`, 0.9343090421501528],
              122 -> RGBColor[
              0.18504035865818397`, 0.31181952755907755`, 0.93384914673168], 
             249 -> RGBColor[
              0.20745669335557887`, 0.3353805166037485, 0.9351257238307011], 
             113 -> RGBColor[
              0.2676326072490897, 0.3986292174791347, 0.9385526531046497], 52 -> 
             RGBColor[
              0.1987330571876369, 0.3262114218807623, 0.9346289256564001], 
             187 -> RGBColor[
              0.22474017350644473`, 0.35354655007824254`, 0.9361099924566755],
              259 -> RGBColor[
              0.18516129488531852`, 0.3119466392015956, 0.9338560338709061], 
             42 -> RGBColor[
              0.8376047344232163, 0.2900520440423452, 0.18364364219313192`], 
             134 -> RGBColor[
              0.24479905803441923`, 0.3746297095238789, 0.9372523162560832], 
             248 -> RGBColor[
              0.22195872707107797`, 0.35062307352078237`, 0.9359515931969625],
              174 -> 
             RGBColor[
              0.23320476894069225`, 0.36244337656598474`, 0.9365920386444091],
              215 -> RGBColor[
              0.22474171532416531`, 0.3535481706264238, 0.9361100802609137], 
             83 -> RGBColor[
              0.846552585818907, 0.35882915084310774`, 0.19221211479479816`], 
             95 -> RGBColor[
              0.28755638833203334`, 0.4195703746379904, 0.9396872829627306], 
             166 -> RGBColor[
              0.18609439165410657`, 0.312927383067344, 0.9339091723514956], 
             233 -> RGBColor[
              0.20539561179114207`, 0.3332141891994065, 0.9350083482847035], 
             295 -> RGBColor[
              0.19692281060910452`, 0.3243087379504625, 0.9345258347917725], 
             141 -> RGBColor[
              0.2938477713702168, 0.42618301710784506`, 0.940045567919488], 
             205 -> RGBColor[
              0.3723597127044757, 0.4969410006264502, 0.9449474095221317], 
             224 -> RGBColor[
              0.20866772558178895`, 0.33665338825737323`, 0.9351946903244223],
              231 -> RGBColor[
              0.23118072954041266`, 0.36031598282478083`, 0.9364767725948611],
              68 -> RGBColor[
              0.8768566069289154, 0.9046456729993274, 0.9881165600196555], 10 -> 
             RGBColor[
              0.19040293767796423`, 0.3174559381160143, 0.9341545376736317], 
             250 -> RGBColor[
              0.18265386603570732`, 0.30931117250048296`, 0.9337132395073293],
              282 -> RGBColor[
              0.4406321468160179, 0.5560751515815551, 0.9492976686527762], 
             232 -> RGBColor[
              0.18790775611424687`, 0.3148333440888988, 0.9340124407748683], 
             253 -> RGBColor[
              0.19184993915614282`, 0.3189768284147727, 0.9342369422671671], 
             55 -> RGBColor[
              0.20213692733288047`, 0.32978910522124555`, 0.9348227710255971],
              91 -> RGBColor[
              0.49015879412300467`, 0.5969720163279171, 0.9530062422656385], 
             105 -> RGBColor[
              0.28384023029084227`, 0.41566445691867016`, 0.9394756532598479],
              36 -> RGBColor[
              0.18133311757286624`, 0.3079229821257478, 0.9336380248362428], 
             123 -> RGBColor[
              0.19860317371820202`, 0.3260749061192986, 0.9346215289849611], 
             94 -> RGBColor[
              0.796888814031874, 0.8412548651917855, 0.9803900876994809], 96 -> 
             RGBColor[
              0.20095046543520778`, 0.32854205854076235`, 0.9347552037757377],
              2 -> 
             RGBColor[
              0.19859115798198185`, 0.32606227681868954`, 0.934620844706559], 
             262 -> RGBColor[
              0.3038398335581257, 0.4366853080006712, 0.9406146010791581], 
             272 -> RGBColor[
              0.17908821045117204`, 0.30556344240551475`, 0.9335101806967048],
              97 -> RGBColor[
              0.44885816070930806`, 0.563200111364443, 0.9498218229840781], 
             209 -> RGBColor[
              0.1804556557285978, 0.30700071409312746`, 0.9335880546823002], 
             66 -> RGBColor[
              0.3863417480503173, 0.5090515368854881, 0.9458383324505404], 
             139 -> RGBColor[
              0.4407231525670485, 0.5561539761890157, 0.9493034674587586], 56 -> 
             RGBColor[
              0.19935669202797407`, 0.3268669016386893, 0.9346644407379722], 
             144 -> RGBColor[
              0.19763991012936863`, 0.32506245501299574`, 0.9345666725485978],
              298 -> RGBColor[
              0.2601377913887575, 0.39075169081115385`, 0.9381258344289902], 
             204 -> RGBColor[
              0.4836083421786542, 0.5916540643449961, 0.9524905666934831], 
             207 -> RGBColor[
              0.18528775379377113`, 0.3120795555323372, 0.9338632355186633], 
             149 -> RGBColor[
              0.895503807139292, 0.6183890185729798, 0.2345181540520019], 219 -> 
             RGBColor[
              0.18433414396946993`, 0.31107725114464163`, 0.9338089288499086],
              9 -> RGBColor[
              0.19896010530687766`, 0.32645006384976655`, 0.9346418557109033],
              11 -> RGBColor[
              0.5318148081413353, 0.630790245090044, 0.9562855562801685], 44 -> 
             RGBColor[
              0.31621931418873805`, 0.44831500913059213`, 0.9413701929717141],
              153 -> RGBColor[
              0.22106916700115545`, 0.3496880894859278, 0.9359009340669666], 
             32 -> RGBColor[
              0.9876761626712638, 0.9891717908034641, 0.8539014078132029], 
             162 -> RGBColor[
              0.9913482769712819, 0.9906903044355545, 0.7930449707347249], 90 -> 
             RGBColor[
              0.21567607897691587`, 0.34401961203092163`, 0.935593805682345], 
             8 -> RGBColor[
              0.2044682273202984, 0.33223944932097826`, 0.9349555351110312], 
             163 -> RGBColor[
              0.6211503872091352, 0.7033168926992579, 0.9633183803113946], 49 -> 
             RGBColor[
              0.20962180710681122`, 0.3376561884324342, 0.9352490238558351], 
             76 -> 
             RGBColor[
              0.3269177544061254, 0.4575814603276529, 0.9420518881221068], 82 -> 
             RGBColor[
              0.6134396494628491, 0.6970569684320459, 0.962711362790644], 67 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 211 -> 
             RGBColor[
              0.2707327274798912, 0.4018876404006824, 
               0.9387292003655769]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJwtl3k4FGrYxsc2dmbMmGEYZp8hUUJS8qQSUSklLeLUoUhCylJkaUGShISD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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 5}], {
             RGBColor[
             0.8948530465649757, 0.5292862061726197, 0.25371216367685606`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 32}], {
             RGBColor[
             0.9031847839921265, 0.5669315361536746, 0.5097177699465452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 51}], {
             RGBColor[
             0.8149950729473256, 0.4986008642103312, 0.5736801336240612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 80}], {
             RGBColor[
             0.8987509068791093, 0.542434604273317, 0.26885461494810886`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 83}], {
             RGBColor[
             0.8326229955659482, 0.2517602161734964, 0.1788731234373428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 92}], {
             RGBColor[
             0.82512404738325, 0.19412001438123114`, 0.1716921221887404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 125}], {
             RGBColor[
             0.8269439386544566, 0.20810849617316574`, 0.17343485212532112`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 128}], {
             RGBColor[
             0.8318168299406954, 0.24556367391377373`, 0.17810113832416685`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 142}], {
             RGBColor[
             0.8243144987265323, 0.1878974686592162, 0.17091689748081318`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 149}], {
             RGBColor[
             0.8570986062261408, 0.38154015003843245`, 0.20002614306594468`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 150}], {
             RGBColor[
             0.8630514097518487, 0.4076537466466897, 0.20494588861929658`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 197}], {
             RGBColor[
             0.9025175586685273, 0.5666556213354577, 0.5207754202823706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 198}], {
             RGBColor[
             0.8916422332040788, 0.5589019666811266, 0.5551782044510756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 237}], {
             RGBColor[
             0.8218840344451928, 0.1692158551566011, 0.1685894821401856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 243}], {
             RGBColor[
             0.9030554567950135, 0.5668780560341109, 0.5118610562907654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 256}], {
             RGBColor[
             0.8183107548052182, 0.14175006202263388`, 0.1651677055215038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 277}], {
             RGBColor[
             0.9058522963240394, 0.5660756214140101, 0.3231115936678419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 281}], {
             RGBColor[
             0.8985774900643843, 0.5640742698921016, 0.5434386235912599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 49}], {
             RGBColor[
             0.20410648254439653`, 0.3318592326255619, 0.934934934281197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 54}], {
             RGBColor[
             0.22131402237840694`, 0.34994544801214666`, 0.9359148782184701]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 102}], {
             RGBColor[
             0.19539325191364892`, 0.3227010747819161, 0.9344387286868456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 165}], {
             RGBColor[
             0.2081927032562806, 0.336154109675109, 0.935167638505717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 172}], {
             RGBColor[
             0.19458761473709335`, 0.321854299029009, 0.9343928488414741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 174}], {
             RGBColor[
             0.21589796346133705`, 0.34425282669233714`, 0.9356064416754841]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 183}], {
             RGBColor[
             0.19566573686527955`, 0.3229874737426237, 0.9344542463017356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 238}], {
             RGBColor[
             0.19301734075154908`, 0.3202038415090809, 0.9343034240610095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 253}], {
             RGBColor[
             0.19522054856906235`, 0.32251955261673115`, 0.9344288934868631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 24}], {
             RGBColor[
             0.9389911914260977, 0.8504167316496911, 0.6099487388884464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 59}], {
             RGBColor[
             0.9696130276591681, 0.9767225112372966, 0.930252756027731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 65}], {
             RGBColor[
             0.6658408786786703, 0.7333691314923763, 0.9538265746888542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 72}], {
             RGBColor[
             0.8918169128751087, 0.5962411896945986, 0.5690910592091327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 106}], {
             RGBColor[
             0.9080394881357245, 0.9290324924917327, 0.9745333831638314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 115}], {
             RGBColor[
             0.6529735529155825, 0.7222241006469869, 0.9530066800693597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 155}], {
             RGBColor[
             0.9402661035019293, 0.855471333191099, 0.6109745630706932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[
             0.972783323199716, 0.9780335099161923, 0.8777127544589929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 169}], {
             RGBColor[
             0.7794786659769637, 0.8276850371059405, 0.962203475513276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 194}], {
             RGBColor[
             0.8201119559484569, 0.8600043630497185, 0.9658594088182089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 200}], {
             RGBColor[
             0.659894342148658, 0.7282185404316961, 0.9534476666394777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 210}], {
             RGBColor[
             0.7129487102103079, 0.7736730218742174, 0.9569659936880668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 227}], {
             RGBColor[
             0.9534614284413586, 0.9077863994945625, 0.6215918312510428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 228}], {
             RGBColor[
             0.690237715965832, 0.7545004457298199, 0.955381119587516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 241}], {
             RGBColor[
             0.9701712881509421, 0.9769533662972854, 0.9210009349471945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 264}], {
             RGBColor[
             0.6252141606717125, 0.697021267014214, 0.9512803143951285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 290}], {
             RGBColor[
             0.9503146533364857, 0.8953104848043834, 0.619059862137357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 291}], {
             RGBColor[
             0.940546596555184, 0.9549527783634579, 0.9776339401843177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 8}], {
             RGBColor[
             0.21250294836697825`, 0.34068445057177643`, 0.935413100588335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 15}], {
             RGBColor[
             0.23945687025241685`, 0.36901473145072583`, 0.9369480865649568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 62}], {
             RGBColor[
             0.21110734445904222`, 0.33921758237813715`, 0.9353336230103891]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 85}], {
             RGBColor[
             0.2263430797542824, 0.3552313061748459, 0.9362012755962026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 121}], {
             RGBColor[
             0.2229935575329976, 0.35171074594830076`, 0.9360105252608744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 135}], {
             RGBColor[
             0.21680708920312736`, 0.3452083754888601, 0.935658215041548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 158}], {
             RGBColor[
             0.2067416614051505, 0.33462897268820413`, 0.9350850038189193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 173}], {
             RGBColor[
             0.21091230660044274`, 0.33901258522263467`, 0.9353225158928745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 186}], {
             RGBColor[
             0.2068268311149634, 0.334718491453289, 0.9350898541078958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 213}], {
             RGBColor[
             0.21145636706915383`, 0.33958442727067606`, 0.9353534993317023]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 214}], {
             RGBColor[
             0.21068402735866598`, 0.33877264926578743`, 0.9353095157277642]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 249}], {
             RGBColor[
             0.21399718138461848`, 0.3422549842131616, 0.93549819494817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 255}], {
             RGBColor[
             0.2932777706676125, 0.42028873435652747`, 0.9402069895504767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 263}], {
             RGBColor[
             0.21521347097412877`, 0.3435333816889509, 0.9355674608409534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 265}], {
             RGBColor[
             0.22162675469537457`, 0.35027414950565383`, 0.9359326878612754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 276}], {
             RGBColor[
             0.23095575836688206`, 0.36007952385740394`, 0.9364639608193436]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 286}], {
             RGBColor[
             0.22071420539136402`, 0.34931500232817103`, 0.9358807195284078]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.7514137479791486, 0.7723356879656991, 0.6490878757769967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 23}], {
             RGBColor[
             0.9801796714011944, 0.9518718565732095, 0.5840536111729073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 51}], {
             RGBColor[
             0.8911547141993119, 0.8831957888790658, 0.6618581652210298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.978010186853574, 0.9509747189595588, 0.6200075845730131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[
             0.9087826368179345, 0.636355140842231, 0.2670511550343114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 92}], {
             RGBColor[
             0.9012836886352362, 0.5787149390499657, 0.259870153785709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 101}], {
             RGBColor[
             0.8091703552886713, 0.8191489845938676, 0.6536867305122107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 128}], {
             RGBColor[
             0.9079764711926817, 0.6301585985825083, 0.2662791699211355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 142}], {
             RGBColor[
             0.9004741399785186, 0.5724923933279508, 0.25909492907778175`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 149}], {
             RGBColor[
             0.933258247478127, 0.766135074707167, 0.2882041746629133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 197}], {
             RGBColor[
             0.9786771999205136, 0.9512505460041922, 0.6089534518793391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 198}], {
             RGBColor[
             0.967801874456065, 0.9434968913498611, 0.6433562360480443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 204}], {
             RGBColor[
             0.7273105149978081, 0.7527675975931751, 0.6471903809836539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 226}], {
             RGBColor[
             0.978634912205556, 0.9512330589473125, 0.6096542687532867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 243}], {
             RGBColor[
             0.9792150980469998, 0.9514729807028455, 0.600039087887734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 256}], {
             RGBColor[
             0.8944703960572045, 0.5263449866913684, 0.2533457371184724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 290}], {
             RGBColor[
             0.9587118125308915, 0.8695626925266455, 0.3088146906826389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 38}], {
             RGBColor[
             0.19835724810513683`, 0.32581642270738265`, 0.9346075238851115]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 52}], {
             RGBColor[
             0.20466403550360635`, 0.3324452561365908, 0.9349666860973984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.21323620369391516`, 0.3414551484114601, 0.9354548583944501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 88}], {
             RGBColor[
             0.21672673573205908`, 0.345123918896063, 0.935653639030243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 93}], {
             RGBColor[
             0.2258625386311459, 0.35472622698636247`, 0.9361739094901367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 124}], {
             RGBColor[
             0.19825974011141095`, 0.3257139356236129, 0.9346019709491189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 147}], {
             RGBColor[
             0.2119963836374878, 0.34015201892302305`, 0.935384252476386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 273}], {
             RGBColor[
             0.22476258261676274`, 0.3535701034740064, 0.9361112686223567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 289}], {
             RGBColor[
             0.22701980203641853`, 0.3559425842000419, 0.9362398139290493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 42}], {
             RGBColor[
             0.8879622102999478, 0.6217857737509664, 0.5864682520402187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 60}], {
             RGBColor[
             0.6127935489939296, 0.6863930727259957, 0.9644818440323379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 77}], {
             RGBColor[
             0.6760511895639363, 0.7431695037981105, 0.9684398535409274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 80}], {
             RGBColor[
             0.9585640473109542, 0.9468487152511682, 0.6807339798518178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 81}], {
             RGBColor[
             0.9138922902616244, 0.7722436147323656, 0.6093859995388808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 82}], {
             RGBColor[
             0.7758796678197641, 0.8252882359458167, 0.9760021123389747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 103}], {
             RGBColor[
             0.6798246620935919, 0.7464378960430543, 0.9686802958737664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 127}], {
             RGBColor[
             0.6435774661849356, 0.7150423967840147, 0.9663706566026036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 130}], {
             RGBColor[
             0.92506143421404, 0.8207777707366587, 0.6185929179813181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 140}], {
             RGBColor[
             0.8778193430883396, 0.5438232517297938, 0.5767554309436527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 145}], {
             RGBColor[
             0.9016117745004403, 0.9243171913792056, 0.9881346792519563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 154}], {
             RGBColor[
             0.7178086500945909, 0.778143567686985, 0.971430549102502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 167}], {
             RGBColor[
             0.9230008546692128, 0.8126082594888467, 0.6169349273115317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 168}], {
             RGBColor[
             0.6693655533207783, 0.7373787417141351, 0.9680138507113893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 181}], {
             RGBColor[
             0.962306825108859, 0.9594739836095195, 0.6952739648323978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 201}], {
             RGBColor[
             0.8918418892803384, 0.651606686480418, 0.5901834370133114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 202}], {
             RGBColor[
             0.9024452109054028, 0.7202651009090716, 0.5998342759304583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 203}], {
             RGBColor[
             0.9377223890197792, 0.9530740402179558, 0.990303930173889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 205}], {
             RGBColor[
             0.6553396994405775, 0.7252302520430189, 0.9671201357047186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 216}], {
             RGBColor[
             0.9023917020151102, 0.7200221295355724, 0.5997896268007754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 237}], {
             RGBColor[
             0.8816971748770377, 0.5736299661344524, 0.5804688470438946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 255}], {
             RGBColor[
             0.6521687790491231, 0.722483760175034, 0.9669180874613099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 269}], {
             RGBColor[
             0.9557422920381128, 0.9373302721362289, 0.6697719934605999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 282}], {
             RGBColor[
             0.6894759164963487, 0.7547973275205713, 0.9692952652700408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 293}], {
             RGBColor[
             0.9190392263270429, 0.795614649307972, 0.6136807291548138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 299}], {
             RGBColor[
             0.8785067924803591, 0.5491072889991002, 0.5774137332578136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 14}], {
             RGBColor[
             0.19233103918746458`, 0.31948249505119564`, 0.9342643402022272]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 64}], {
             RGBColor[
             0.21988638356939655`, 0.34844490910634823`, 0.9358335763002992]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 67}], {
             RGBColor[
             0.1916976136601492, 0.31881672466048916`, 0.9342282675555156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 69}], {
             RGBColor[
             0.2060185451131012, 0.33386893161703934`, 0.9350438234158418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 85}], {
             RGBColor[
             0.21830835870760254`, 0.3467863049240477, 0.9357437101188987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 121}], {
             RGBColor[
             0.21495883648631775`, 0.3432657446975026, 0.9355529597835706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 135}], {
             RGBColor[
             0.2087723681564475, 0.33676337423806185`, 0.9352006495642442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 173}], {
             RGBColor[
             0.2028775855537629, 0.3305675839718365, 0.9348649504155706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 186}], {
             RGBColor[
             0.19879211006828354`, 0.3262734902024908, 0.934632288630592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 213}], {
             RGBColor[
             0.20342164602247398`, 0.3311394260198779, 0.9348959338543985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 234}], {
             RGBColor[
             0.19931169581116837`, 0.32681960776190155`, 0.934661878269991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 249}], {
             RGBColor[
             0.20596246033793864`, 0.3338099829623634, 0.9350406294708662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 263}], {
             RGBColor[
             0.20717874992744892`, 0.3350883804381527, 0.9351098953636496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 286}], {
             RGBColor[
             0.21267948434468417`, 0.34087000107737286`, 0.9354231540511039]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 45}], {
             RGBColor[
             0.24944742731977937`, 0.3795154403664275, 0.9375170340102383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 47}], {
             RGBColor[
             0.1915298565644043, 0.31864040131644705`, 0.9342187140370874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 96}], {
             RGBColor[
             0.19995528537104273`, 0.3274960611952644, 0.9346985297433206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 112}], {
             RGBColor[
             0.19409572030031721`, 0.3213372867880486, 0.9343648361809924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 132}], {
             RGBColor[
             0.19792820821317225`, 0.32536547457822756`, 0.9345830906979717]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 133}], {
             RGBColor[
             0.19212471165815448`, 0.3192656317359698, 0.9342525901546672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 141}], {
             RGBColor[
             0.24640393833854723`, 0.3763165404788058, 0.9373437118151957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 146}], {
             RGBColor[
             0.1994945649800457, 0.3270118148529666, 0.9346722923986279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 236}], {
             RGBColor[
             0.21519552032906075`, 0.34351451442284786`, 0.9355664385782725]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 22}], {
             RGBColor[
             0.18947218593303478`, 0.31647765901902436`, 0.9341015327386817]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 48}], {
             RGBColor[
             0.19160641114189197`, 0.3187208650312271, 0.934223073707023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 63}], {
             RGBColor[
             0.18664280478053893`, 0.31350380003462497`, 0.9339404036677414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 71}], {
             RGBColor[
             0.20685989156236995`, 0.3347532400796667, 0.9350917368514671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 73}], {
             RGBColor[
             0.18653587436616526`, 0.31339140938933835`, 0.9339343141388322]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 100}], {
             RGBColor[
             0.18553288790448116`, 0.3123372070250937, 0.9338771955436248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 119}], {
             RGBColor[
             0.1856272606689936, 0.3124363987841752, 0.9338825699329518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 122}], {
             RGBColor[
             0.1877216481680741, 0.3146377328375459, 0.9340018422026558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 161}], {
             RGBColor[
             0.19602879349749167`, 0.3233690692821986, 0.9344749218398459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 244}], {
             RGBColor[
             0.1899533548754444, 0.3169833980853699, 0.9341289345981263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 266}], {
             RGBColor[
             0.19427634422620857`, 0.3215271339863788, 0.9343751224463628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 51}], {
             RGBColor[
             0.6715557743614986, 0.7416503460034106, 0.9690558457242018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 101}], {
             RGBColor[
             0.589571415450858, 0.6776035417182125, 0.9608844110153827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 104}], {
             RGBColor[
             0.4334513122055766, 0.547724101182389, 0.9494290167598639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 114}], {
             RGBColor[
             0.38547343504917886`, 0.49973179121413747`, 0.9466075727466067]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 116}], {
             RGBColor[
             0.4095833128093886, 0.5250728013946587, 0.9479805946176828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 149}], {
             RGBColor[
             0.7136593076403137, 0.6245896318315118, 0.5954018551660852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 197}], {
             RGBColor[
             0.7590782600827003, 0.809705103128537, 0.9161511323825111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 198}], {
             RGBColor[
             0.7482029346182517, 0.8019514484742061, 0.9505539165512161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 204}], {
             RGBColor[
             0.5077115751599948, 0.6112221547175201, 0.9543880614868259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 243}], {
             RGBColor[
             0.7596161582091865, 0.8099275378271904, 0.907236768390906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 254}], {
             RGBColor[
             0.4252983225505378, 0.5406623913243694, 0.9489095154684506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 283}], {
             RGBColor[
             0.41881779248479195`, 0.534778825033336, 0.9485064845740085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.3382052536051789, 0.4616299042238716, 0.9429808558058818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 27}], {
             RGBColor[
             0.6997308165084448, 0.7282337735956864, 0.6429681792954851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.33246233459167696`, 0.45559373221858496`, 0.9426538050639501]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 76}], {
             RGBColor[
             0.3782689418854923, 0.5020592779365523, 0.9453239403802199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 87}], {
             RGBColor[
             0.7113840896935575, 0.7671448961592477, 0.7220908533867955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 151}], {
             RGBColor[
             0.5137240937710055, 0.6154599354387978, 0.9550391768879118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 154}], {
             RGBColor[
             0.46345887168868094`, 0.5746523637299171, 0.9510821144780158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 181}], {
             RGBColor[
             0.707957046702949, 0.7559827796524516, 0.6749255302079116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 192}], {
             RGBColor[
             0.3801187118441842, 0.5036614557026298, 0.9454418060863005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 220}], {
             RGBColor[
             0.38135478455479077`, 0.5047320797577364, 0.9455205675464041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 239}], {
             RGBColor[
             0.3335981101513706, 0.4567875043441526, 0.9427184858018454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 258}], {
             RGBColor[
             0.3848908244823526, 0.507794819816456, 0.9457458808837911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 32}], {
             RGBColor[
             0.6604824509868196, 0.7261357390166185, 0.898179624729629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 53}], {
             RGBColor[
             0.27458306643531494`, 0.40366544683013694`, 0.9390315559482794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 93}], {
             RGBColor[
             0.2872094013725457, 0.41693652540503934`, 0.939750607043966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 107}], {
             RGBColor[
             0.3708820169269006, 0.49566109481506393`, 0.9448532520538597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 137}], {
             RGBColor[
             0.2974114508687985, 0.42765952627289927`, 0.9403315986701979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 147}], {
             RGBColor[
             0.27334324637888757`, 0.4023623173416999, 0.9389609500302152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 156}], {
             RGBColor[
             0.3638901315072269, 0.4896050750869218, 0.9444077352975997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 179}], {
             RGBColor[
             0.42802275177735205`, 0.5432681021152472, 0.9490151577652866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 251}], {
             RGBColor[
             0.3094480150189227, 0.44031071835692515`, 0.9410170631920465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 270}], {
             RGBColor[
             0.27306394266259, 0.4020687514269927, 0.9389450440967648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 271}], {
             RGBColor[
             0.2779619784734704, 0.40721689761763513`, 0.9392239799901998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 273}], {
             RGBColor[
             0.2861094453581625, 0.4157804018926833, 0.9396879661761859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 274}], {
             RGBColor[
             0.3981676494624695, 0.5190303850989934, 0.9466648547482157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 277}], {
             RGBColor[
             0.6631499633187324, 0.7252798242769541, 0.7115734484509257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 282}], {
             RGBColor[
             0.38696044305919663`, 0.509587419405664, 0.9458777551494157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 289}], {
             RGBColor[
             0.2883666647778183, 0.41815288261871875`, 0.9398165114828785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 67}], {
             RGBColor[
             0.17956042552731538`, 0.30605977039070653`, 0.9335370726467116]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 173}], {
             RGBColor[
             0.1907403974209291, 0.31781062970205387`, 0.9341737555067666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 186}], {
             RGBColor[
             0.18665492193544975`, 0.31351653593270823`, 0.9339410937217879]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.19128445788964016`, 0.31838247175009526`, 0.9342047389455943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 249}], {
             RGBColor[
             0.19382527220510481`, 0.3210530286925808, 0.9343494345620621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 46}], {
             RGBColor[
             0.23154240030757095`, 0.3606961217323153, 0.9364973692100068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 60}], {
             RGBColor[
             0.27282174145117777`, 0.4040833265356404, 0.9388481666208225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.23002654529780098`, 0.3591028620062883, 0.9364110435097069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 77}], {
             RGBColor[
             0.3360793820211845, 0.46085975760775527`, 0.942806176129412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 82}], {
             RGBColor[
             0.43590786027701234`, 0.5429784897554615, 0.9503684349274593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 103}], {
             RGBColor[
             0.33985285455084013`, 0.464128149852699, 0.9430466184622509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 127}], {
             RGBColor[
             0.3036056586421837, 0.43273265059365945`, 0.9407369791910881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 135}], {
             RGBColor[
             0.2357262900418861, 0.3650936551170112, 0.9367356355408658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 158}], {
             RGBColor[
             0.22566086224390924`, 0.3545142523163553, 0.9361624243182372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 168}], {
             RGBColor[
             0.3293937457780264, 0.4550689955237798, 0.942380173299874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 186}], {
             RGBColor[
             0.22574603195372214`, 0.35460377108144014`, 0.9361672746072136]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 196}], {
             RGBColor[
             0.23071789586563907`, 0.35982951528724394`, 0.9364504149017838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 212}], {
             RGBColor[
             0.24587235329600743`, 0.3757578108946581, 0.9373134388334325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 214}], {
             RGBColor[
             0.22960322819742474`, 0.35865792889393855`, 0.936386936227082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 225}], {
             RGBColor[
             0.2429863506332136, 0.37272443911292436`, 0.9371490852512447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 255}], {
             RGBColor[
             0.31219697150637127`, 0.44017401398467865`, 0.9412844100497945]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 265}], {
             RGBColor[
             0.24054595553413333`, 0.37015942913380495`, 0.9370101083605932]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 276}], {
             RGBColor[
             0.24987495920564082`, 0.37996480348555506`, 0.9375413813186614]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 286}], {
             RGBColor[
             0.23963340623012278`, 0.3692002819563222, 0.9369581400277256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.22364840280037163`, 0.35239902984389887`, 0.9360478177300946]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 39}], {
             RGBColor[
             0.22425729902189784`, 0.35303901837897317`, 0.9360824934691292]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 76}], {
             RGBColor[
             0.286854066125812, 0.4171520866149722, 0.9397088035477686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 90}], {
             RGBColor[
             0.2312332284112072, 0.3603711624666066, 0.9364797623278878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 126}], {
             RGBColor[
             0.23513936956710785`, 0.3644767644851118, 0.9367022112880983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 151}], {
             RGBColor[
             0.42230921801132515`, 0.5305527441172178, 0.9494240400554605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 153}], {
             RGBColor[
             0.233929772423327, 0.36320540119410966`, 0.9366333265201985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 192}], {
             RGBColor[
             0.28870383608450384`, 0.4187542643810497, 0.9398266692538492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 220}], {
             RGBColor[
             0.2899399087951104, 0.41982488843615623`, 0.9399054307139528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 222}], {
             RGBColor[
             0.23410797445122994`, 0.3633927028240968, 0.9366434748620613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 239}], {
             RGBColor[
             0.2421832343916902, 0.3718803130225725, 0.9371033489693941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 248}], {
             RGBColor[
             0.23437455245828825`, 0.36367289321153695`, 0.9366586560851965]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 285}], {
             RGBColor[
             0.22323502267117318`, 0.3519645411182973, 0.9360242763432778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 40}], {
             RGBColor[
             0.6964483919711273, 0.7627900441024493, 0.9703791250975754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[
             0.7706339375032876, 0.5292391522973952, 0.5773709330033577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 66}], {
             RGBColor[
             0.5450024443168381, 0.6387388987189666, 0.9584682781320619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 81}], {
             RGBColor[
             0.7965640174649642, 0.6796969932787943, 0.60028868050202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 86}], {
             RGBColor[
             0.648920103921949, 0.7249224984916083, 0.966146582786049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 94}], {
             RGBColor[
             0.7502759773076164, 0.8048405628721153, 0.9757441557565323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 97}], {
             RGBColor[
             0.5762606506463335, 0.665813185958444, 0.9604600233988309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 120}], {
             RGBColor[
             0.4913767245940681, 0.5895491243083159, 0.9551516880301447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 130}], {
             RGBColor[
             0.8077331614173798, 0.7282311492830874, 0.6094955989444572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 140}], {
             RGBColor[
             0.7604910702916794, 0.4512766302762225, 0.5676581119067918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 162}], {
             RGBColor[
             0.8475057087773203, 0.8795582824939998, 0.8820715972741542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 169}], {
             RGBColor[
             0.654201051554568, 0.729209809683748, 0.9665623183284373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 178}], {
             RGBColor[
             0.4813372368134904, 0.5789969861106385, 0.9545799540531321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 182}], {
             RGBColor[
             0.47900337512465124`, 0.5765439495002909, 0.9544470440825916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 201}], {
             RGBColor[
             0.7745136164836781, 0.5590600650268467, 0.5810861179764505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 202}], {
             RGBColor[
             0.7851169381087426, 0.6277184794555003, 0.5907369568935974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 294}], {
             RGBColor[
             0.6198562799736641, 0.7013271769000424, 0.963858572100545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 26}], {
             RGBColor[
             0.21453517633612967`, 0.3428204510180499, 0.9355288329647664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 33}], {
             RGBColor[
             0.20024058888485757`, 0.32779593327757145`, 0.9347147773563635]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 35}], {
             RGBColor[
             0.20318410319091706`, 0.3308897534428262, 0.9348824061415544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 129}], {
             RGBColor[
             0.1945312219559263, 0.32179502664049353`, 0.9343896373560123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 165}], {
             RGBColor[
             0.2088844992725249, 0.33688123115058255`, 0.9352070352654217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 175}], {
             RGBColor[
             0.19129167307218187`, 0.3183900553644156, 0.9342051498395663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 183}], {
             RGBColor[
             0.19635753288152386`, 0.32371459521809726`, 0.9344936430614402]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 184}], {
             RGBColor[
             0.19573226525779447`, 0.3230573993013006, 0.9344580349952694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.2043212377981297, 0.33208495401350496`, 0.9349471642751953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 253}], {
             RGBColor[
             0.19591234458530662`, 0.3232466740922047, 0.9344682902465677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 262}], {
             RGBColor[
             0.25190729178629806`, 0.38210091388515394`, 0.9376571196525632]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 36}], {
             RGBColor[
             0.200168643680248, 0.32772031430593734`, 0.9347106801833944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 37}], {
             RGBColor[
             0.22278622542452461`, 0.3514928267566807, 0.9359987180040172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 41}], {
             RGBColor[
             0.20379941702053028`, 0.3315364872908998, 0.9349174473538756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 44}], {
             RGBColor[
             0.26761174198818394`, 0.3979163278083595, 0.93857676425113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 55}], {
             RGBColor[
             0.21057054856025512`, 0.3386533758536862, 0.9353030532780715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 61}], {
             RGBColor[
             0.248131704384919, 0.378132532140237, 0.9374421055355356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 71}], {
             RGBColor[
             0.22116050761720274`, 0.349784094264723, 0.9359061357799242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 108}], {
             RGBColor[
             0.2298448182232575, 0.3589118553287811, 0.9364006944216527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 136}], {
             RGBColor[
             0.3058098324986471, 0.43100159391667037`, 0.9410107128012115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 152}], {
             RGBColor[
             0.20076184690853469`, 0.3283438085101236, 0.9347444622296798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 177}], {
             RGBColor[
             0.2554879446971804, 0.38586440712099823`, 0.9378610325387366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 208}], {
             RGBColor[
             0.20416035452872197`, 0.331915855496769, 0.9349380022110079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 252}], {
             RGBColor[
             0.2284732256377411, 0.3574702245574107, 0.936322584252997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 268}], {
             RGBColor[
             0.21202685048114545`, 0.34018404150741677`, 0.9353859875180606]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 279}], {
             RGBColor[
             0.22783544818024304`, 0.35679988001215385`, 0.9362862637702997]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 280}], {
             RGBColor[
             0.24050854139809294`, 0.3701201045046333, 0.9370079776808949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 50}], {
             RGBColor[
             0.18770061499905671`, 0.31461562564332873`, 0.9340006443947961]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 74}], {
             RGBColor[
             0.19973960321144332`, 0.32726936557048675`, 0.9346862469634045]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[
             0.21635493982133241`, 0.34473313782066695`, 0.9356324658031498]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 123}], {
             RGBColor[
             0.1960904957019222, 0.3234339222112008, 0.934478435689108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 189}], {
             RGBColor[
             0.20470683599275827`, 0.3324902421643972, 0.934969123521938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 206}], {
             RGBColor[
             0.20800021126608947`, 0.33595178838872103`, 0.9351566763716421]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 257}], {
             RGBColor[
             0.1888268034733999, 0.3157993211343368, 0.9340647791623633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 287}], {
             RGBColor[
             0.21828938866019382`, 0.34676636620145074`, 0.9357426298027625]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 300}], {
             RGBColor[
             0.2096118710905434, 0.33764574504935696`, 0.9352484580144076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.19067565939696252`, 0.3177425859342372, 0.934170068772073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 63}], {
             RGBColor[
             0.18571205303560948`, 0.312525520937635, 0.9338873987327916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 70}], {
             RGBColor[
             0.19915563229546623`, 0.32665557511190024`, 0.9346529906836472]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 73}], {
             RGBColor[
             0.1856051226212358, 0.3124131302923484, 0.9338813092038822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 100}], {
             RGBColor[
             0.1846021361595517, 0.3113589279281038, 0.9338241906086748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 119}], {
             RGBColor[
             0.18469650892406414`, 0.31145811968718523`, 0.933829564998002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 122}], {
             RGBColor[
             0.18679089642314464`, 0.31365945374055604`, 0.9339488372677058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 161}], {
             RGBColor[
             0.1950980417525622, 0.32239079018520866`, 0.934421916904896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 244}], {
             RGBColor[
             0.18902260313051494`, 0.31600511898838, 0.9340759296631764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 266}], {
             RGBColor[
             0.1933455924812791, 0.32054885488938883`, 0.9343221175114128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 24}], {
             RGBColor[
             0.956555334204736, 0.8626596651038085, 0.541866983332811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 31}], {
             RGBColor[
             0.7044976010018857, 0.7638813972041334, 0.8870888196503636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 44}], {
             RGBColor[
             0.6527829845870825, 0.7190887957178285, 0.883793610021852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 59}], {
             RGBColor[
             0.9871771704378065, 0.988965444691414, 0.8621710004720957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 72}], {
             RGBColor[
             0.909381055653747, 0.6084841231487159, 0.5010093036534974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 83}], {
             RGBColor[
             0.917949620402167, 0.6743458665740862, 0.5092145709333941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 106}], {
             RGBColor[
             0.9256036309143629, 0.94127542594585, 0.906451627608196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 136}], {
             RGBColor[
             0.6909810750975458, 0.7521740618261392, 0.8862275585719336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 155}], {
             RGBColor[
             0.9578302462805677, 0.8677142666452164, 0.5428928075150579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 194}], {
             RGBColor[
             0.8376760987270953, 0.8722472965038359, 0.8977776532625734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 197}], {
             RGBColor[
             0.9878441835047461, 0.9892412717360475, 0.8511168677784218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 198}], {
             RGBColor[
             0.9769688580402975, 0.9814876170817164, 0.8855196519471269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 210}], {
             RGBColor[
             0.7305128529889463, 0.7859159553283347, 0.8888842381324313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 226}], {
             RGBColor[
             0.9878018957897885, 0.9892237846791677, 0.8518176846523693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 241}], {
             RGBColor[
             0.9877354309295805, 0.9891962997514028, 0.8529191793915591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 290}], {
             RGBColor[
             0.9678787961151241, 0.9075534182585008, 0.5509781065817215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 291}], {
             RGBColor[
             0.9581107393338224, 0.9671957118175754, 0.9095521846286824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.9468027585380377, 0.8226935997742366, 0.2974286527731346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 59}], {
             RGBColor[
             0.9543858496571156, 0.8617625274901577, 0.5778209567329167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 65}], {
             RGBColor[
             0.6506137006766177, 0.6184091477452374, 0.6013947753940398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 72}], {
             RGBColor[
             0.8765897348730561, 0.4812812059474597, 0.21665925991431845`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 87}], {
             RGBColor[
             0.9584560317231505, 0.8616047223377981, 0.3765513268644449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 106}], {
             RGBColor[
             0.892812310133672, 0.8140725087445938, 0.6221015838690171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 109}], {
             RGBColor[
             0.9582875876148832, 0.8633759964057863, 0.5131590613985512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 155}], {
             RGBColor[
             0.9250389254998768, 0.7405113494439601, 0.2585427637758789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 162}], {
             RGBColor[
             0.9575561451976635, 0.8630735261690534, 0.5252809551641785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 194}], {
             RGBColor[
             0.8048847779464043, 0.7450443793025796, 0.6134276095233945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 210}], {
             RGBColor[
             0.6977215322082554, 0.6587130381270785, 0.6045341943932525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 218}], {
             RGBColor[
             0.945476791560533, 0.8552536816107574, 0.5989703095762722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 226}], {
             RGBColor[
             0.9550105750090976, 0.8620208674779115, 0.5674676409131905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 227}], {
             RGBColor[
             0.9382342504393061, 0.7928264157474236, 0.2691600319562284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 241}], {
             RGBColor[
             0.9549441101488896, 0.8619933825501465, 0.5685691356523801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 290}], {
             RGBColor[
             0.9350874753344331, 0.7803505010572445, 0.2666280628425426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 291}], {
             RGBColor[
             0.9253194185531315, 0.839992794616319, 0.6252021408895034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 299}], {
             RGBColor[
             0.871228956104042, 0.44007591122058254`, 0.21152577211097698`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 28}], {
             RGBColor[
             0.18729283765525817`, 0.3141870258004196, 0.9339774220783192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 58}], {
             RGBColor[
             0.19112827338567, 0.31821831193375316`, 0.9341958444691476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 79}], {
             RGBColor[
             0.18712823581077753`, 0.3140140188255107, 0.9339680482467827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 113}], {
             RGBColor[
             0.22937411863723062`, 0.3584171202197894, 0.9363738887765662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 134}], {
             RGBColor[
             0.21795734402989536`, 0.34641736624216146`, 0.935723720352283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 144}], {
             RGBColor[
             0.19437777007737006`, 0.3216337389867199, 0.9343808984985402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 160}], {
             RGBColor[
             0.19344001775085345`, 0.32064810183461934`, 0.9343274948908254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 176}], {
             RGBColor[
             0.19265413404658233`, 0.31982208823352565`, 0.9342827399764779]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.1930001178726018, 0.32018573917131365`, 0.9343024432435325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 221}], {
             RGBColor[
             0.1886556188584439, 0.3156193952502866, 0.9340550304517865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 230}], {
             RGBColor[
             0.19160057419890764`, 0.31871473003406703`, 0.934222741301755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 232}], {
             RGBColor[
             0.1895116930698092, 0.31651918352467145`, 0.9341037826116756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 245}], {
             RGBColor[
             0.2081790637788683, 0.33613977371955583`, 0.9351668617576563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 288}], {
             RGBColor[
             0.19999048340527747`, 0.32753305656092946`, 0.9347005342192993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 297}], {
             RGBColor[
             0.19155439006973912`, 0.318666187586068, 0.9342201111839221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 35}], {
             RGBColor[
             0.21774452951257628`, 0.3461936846912394, 0.9357116008803525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 54}], {
             RGBColor[
             0.23656624471631046`, 0.3659765007360335, 0.9367834697169728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 75}], {
             RGBColor[
             0.28101248706842963`, 0.4104564015750206, 0.9393964853748475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 102}], {
             RGBColor[
             0.21064547425155244`, 0.3387321275058029, 0.9353073201853483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 129}], {
             RGBColor[
             0.20909164827758553`, 0.33709895788890676`, 0.9352188320948104]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 165}], {
             RGBColor[
             0.2234449255941841, 0.3521851623989958, 0.9360362300042198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 175}], {
             RGBColor[
             0.20585209939384108`, 0.33369398661282884`, 0.9350343445783642]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 183}], {
             RGBColor[
             0.21091795920318307`, 0.3390185264665105, 0.9353228378002383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 224}], {
             RGBColor[
             0.21888166411978893`, 0.3473888852619182, 0.9357763590139934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 253}], {
             RGBColor[
             0.21047277090696587`, 0.3385506053406179, 0.9352974849853658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 262}], {
             RGBColor[
             0.26646771810795733`, 0.39740484513356716`, 0.9384863143913613]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 42}], {
             RGBColor[
             0.9037231190376234, 0.5999912478441332, 0.26049200407288453`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 72}], {
             RGBColor[
             0.8996284799870488, 0.5685180578191442, 0.256570973093821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 87}], {
             RGBColor[
             0.9814947768371431, 0.9488415742094825, 0.4164630400439475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 109}], {
             RGBColor[
             0.9813263327288758, 0.9506128482774708, 0.5530707745780536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 140}], {
             RGBColor[
             0.8935802518260152, 0.5220287258229606, 0.25077918297631857`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 151}], {
             RGBColor[
             0.7838347809145911, 0.7971566134890326, 0.6494113635450639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 154}], {
             RGBColor[
             0.7335695588322665, 0.7563490417801518, 0.6454543011351679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 155}], {
             RGBColor[
             0.9480776706138694, 0.8277482013156446, 0.2984544769553814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 162}], {
             RGBColor[
             0.9805948903116561, 0.9503103780407378, 0.565192668343681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 181}], {
             RGBColor[
             0.9780677338465346, 0.9376794577026863, 0.3692977168650637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 202}], {
             RGBColor[
             0.9182061196430783, 0.6984705750022384, 0.2738580279631242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 203}], {
             RGBColor[
             0.9534832977574548, 0.9312795143111227, 0.6643276822065549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 216}], {
             RGBColor[
             0.9181526107527858, 0.6982276036287391, 0.27381337883344126`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 227}], {
             RGBColor[
             0.9612729955532987, 0.8800632676191081, 0.309071745135731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 299}], {
             RGBColor[
             0.8942677012180347, 0.5273127630922669, 0.2514374852904795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 79}], {
             RGBColor[
             0.1833054434406642, 0.3099960216654862, 0.9337503458766192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 144}], {
             RGBColor[
             0.19055497770725674`, 0.3176157418266954, 0.9341631961283768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 160}], {
             RGBColor[
             0.18961722538074013`, 0.31663010467459485`, 0.9341097925206621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 176}], {
             RGBColor[
             0.18883134167646898`, 0.3158040910735011, 0.9340650376063144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 221}], {
             RGBColor[
             0.18483282648833058`, 0.31160139809026205`, 0.9338373280816231]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 230}], {
             RGBColor[
             0.1877777818287943, 0.3146967328740425, 0.9340050389315915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 232}], {
             RGBColor[
             0.18568890069969585`, 0.3125011863646469, 0.9338860802415121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 240}], {
             RGBColor[
             0.18200025991928498`, 0.3086241910311017, 0.9336760176059227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 245}], {
             RGBColor[
             0.204356271408755, 0.33212177655953135`, 0.9349491593874928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 288}], {
             RGBColor[
             0.19616769103516415`, 0.32351505940090497`, 0.9344828318491358]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 297}], {
             RGBColor[
             0.18773159769962583`, 0.31464819042604353`, 0.9340024088137586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 43}], {
             RGBColor[
             0.21042089134742065`, 0.3384960766341818, 0.9352945305211986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 78}], {
             RGBColor[
             0.1946932984138494, 0.3219653792740117, 0.9343988673705204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 99}], {
             RGBColor[
             0.19546469586089602`, 0.32277616690028066`, 0.9344427973139495]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 131}], {
             RGBColor[
             0.21233150972289871`, 0.34050425768701104`, 0.9354033374111754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 170}], {
             RGBColor[
             0.19641582947302122`, 0.3237758686319784, 0.934496962966084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 178}], {
             RGBColor[
             0.22713326298795516`, 0.3560618388539467, 0.9362462753623888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 182}], {
             RGBColor[
             0.224799401299116, 0.35360880224359903`, 0.9361133653918483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 190}], {
             RGBColor[
             0.199834842245044, 0.32736946783330456`, 0.9346916706854744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 199}], {
             RGBColor[
             0.196824977685108, 0.32420590934437654`, 0.9345202633514818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 209}], {
             RGBColor[
             0.1878554243304431, 0.3147783400660943, 0.9340094605571987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 229}], {
             RGBColor[
             0.20648377022612274`, 0.3343579127078008, 0.9350703172977894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 259}], {
             RGBColor[
             0.19020824390880345`, 0.3172513026203284, 0.9341434501515016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 261}], {
             RGBColor[
             0.21999581851421782`, 0.3485599321719316, 0.9358398084585123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 284}], {
             RGBColor[
             0.21810645410068208`, 0.3465740903806829, 0.9357322119502256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 74}], {
             RGBColor[
             0.22759891531018372`, 0.3565512689686714, 0.9362727935732689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 104}], {
             RGBColor[
             0.2921921290764705, 0.4220073511871032, 0.9400404564262714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 123}], {
             RGBColor[
             0.2239498078006626, 0.3527158256093854, 0.9360649822989724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 189}], {
             RGBColor[
             0.23256614809149867`, 0.36177214556258186`, 0.9365556701318023]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 236}], {
             RGBColor[
             0.2403636886171835, 0.3699678550477007, 0.9369997285293126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 260}], {
             RGBColor[
             0.25373200019445147`, 0.38401879811531836`, 0.9377610340969933]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 267}], {
             RGBColor[
             0.22275125819820335`, 0.35145607398476686`, 0.9359967266722076]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 287}], {
             RGBColor[
             0.24614870075893425`, 0.37604826959963533`, 0.9373291764126268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 300}], {
             RGBColor[
             0.23747118318928384`, 0.36692764844754155`, 0.936835004624272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 37}], {
             RGBColor[
             0.32310841403988205`, 0.4466841095652183, 0.9420873563531128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 44}], {
             RGBColor[
             0.36793393060354135`, 0.4931076106168971, 0.9446654026002257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 59}], {
             RGBColor[
             0.7023281164542653, 0.7629842595904825, 0.9230427930504692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 61}], {
             RGBColor[
             0.3484538930002764, 0.47332381494877457`, 0.9435307438846312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 65}], {
             RGBColor[
             0.3985559674737674, 0.5196308798455622, 0.9466166117115924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 71}], {
             RGBColor[
             0.32148269623256015`, 0.4449753770732606, 0.9419947741290198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 136}], {
             RGBColor[
             0.4061320211140046, 0.526192876725208, 0.9470993511503072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 177}], {
             RGBColor[
             0.3558101333125378, 0.4810556899295358, 0.9439496708878323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 194}], {
             RGBColor[
             0.552827044743554, 0.6462661114029045, 0.958649445840947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 210}], {
             RGBColor[
             0.4456637990054052, 0.5599347702274033, 0.949756030710805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 226}], {
             RGBColor[
             0.7029528418062473, 0.7632425995782364, 0.912689477230743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 241}], {
             RGBColor[
             0.7028863769460394, 0.7632151146504713, 0.9137909719699326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 279}], {
             RGBColor[
             0.32815763679560045`, 0.4519911628206914, 0.9423749021193952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 280}], {
             RGBColor[
             0.3408307300134504, 0.46531138731317084`, 0.9430966160299905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 290}], {
             RGBColor[
             0.683029742131583, 0.6815722331575694, 0.6118498991600951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 291}], {
             RGBColor[
             0.6732616853502813, 0.7412145267166439, 0.970423977207056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 80}], {
             RGBColor[
             0.9832422855582464, 0.9646748589231064, 0.6130382528147665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 92}], {
             RGBColor[
             0.9096154260623872, 0.6163602690310206, 0.515875760055398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 107}], {
             RGBColor[
             0.6980757286113448, 0.7586971466019095, 0.9005750351374335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 125}], {
             RGBColor[
             0.9114353173335938, 0.6303487508229553, 0.5176184899919789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 128}], {
             RGBColor[
             0.9163082086198326, 0.6678039285635632, 0.5222847761908246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 142}], {
             RGBColor[
             0.9088058774056695, 0.6101377233090057, 0.5151005353474709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 145}], {
             RGBColor[
             0.9262900127477325, 0.9421433350511439, 0.920438952214905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 149}], {
             RGBColor[
             0.9415899849052779, 0.803780404688222, 0.5442097809326024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 150}], {
             RGBColor[
             0.9475427884309859, 0.8298940012964792, 0.5491295264859543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 156}], {
             RGBColor[
             0.691083843191671, 0.7526411268737674, 0.9001295183811735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 167}], {
             RGBColor[
             0.947679092916505, 0.830434403160785, 0.5492392002744804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 179}], {
             RGBColor[
             0.7552164634617963, 0.8063041539020928, 0.9047369408488604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 205}], {
             RGBColor[
             0.6800179376878698, 0.7430563957149572, 0.8994244086676673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 237}], {
             RGBColor[
             0.90637541312433, 0.5914561098063906, 0.5127731200068433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 256}], {
             RGBColor[
             0.9028021334843555, 0.5639903166724234, 0.5093513433881616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 269}], {
             RGBColor[
             0.980420530285405, 0.9551564158081671, 0.6020762664235486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 277}], {
             RGBColor[
             0.9903436750031767, 0.9883158760637997, 0.6672952315344995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 282}], {
             RGBColor[
             0.7141541547436409, 0.7726234711925095, 0.9015995382329896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 293}], {
             RGBColor[
             0.9437174645743351, 0.8134407929799102, 0.5459850021177625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 98}], {
             RGBColor[
             0.18977923539730202`, 0.3168003874740297, 0.9341190187514328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 126}], {
             RGBColor[
             0.2119973945219809, 0.3401530814267192, 0.9353843100447624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 153}], {
             RGBColor[
             0.21078779737820008`, 0.338881718135717, 0.9353154252768627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 157}], {
             RGBColor[
             0.19152225944429985`, 0.31863241626153205`, 0.9342182813923363]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 171}], {
             RGBColor[
             0.189827260881899, 0.31685086530333273`, 0.9341217537317332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 184}], {
             RGBColor[
             0.1959981041281816, 0.3233368128092353, 0.9344731741256647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 222}], {
             RGBColor[
             0.210965999406103, 0.33906901976570414`, 0.9353255736187255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 248}], {
             RGBColor[
             0.21123257741316134`, 0.3393492101531443, 0.9353407548418606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 275}], {
             RGBColor[
             0.19034059746125545`, 0.31739041459565537`, 0.9341509874905143]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 285}], {
             RGBColor[
             0.20009304762604624`, 0.3276408580599046, 0.934706375099942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 38}], {
             RGBColor[
             0.18490621443215238`, 0.31167853347228314`, 0.9338415074164561]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 52}], {
             RGBColor[
             0.1912130018306219, 0.3183073669014913, 0.934200669628743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 53}], {
             RGBColor[
             0.1997851700209307, 0.32731725917636056`, 0.9346888419257947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 57}], {
             RGBColor[
             0.18168430472921848`, 0.3082921020936258, 0.9336580244252622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 84}], {
             RGBColor[
             0.1855804331499768, 0.3123871800926523, 0.9338799031750189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 124}], {
             RGBColor[
             0.1848087064384265, 0.3115760463885134, 0.9338359544804635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 147}], {
             RGBColor[
             0.19854534996450335`, 0.32601412968792354`, 0.9346182360077306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 217}], {
             RGBColor[
             0.1918655955426979, 0.3189932842697143, 0.9342378338752199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 223}], {
             RGBColor[
             0.1825916590093845, 0.3092457889716643, 0.9337096969092074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 247}], {
             RGBColor[
             0.1907246807083084, 0.31779411044059236`, 0.9341728604632337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 270}], {
             RGBColor[
             0.19826604624820576`, 0.32572056377321634`, 0.9346023300742803]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 295}], {
             RGBColor[
             0.19030787854135572`, 0.3173560249363414, 0.9341491241964293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 102}], {
             RGBColor[
             0.19929440110633984`, 0.32680142993057915`, 0.9346608933621363]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 129}], {
             RGBColor[
             0.19774057513237292`, 0.32516826031368307`, 0.9345724052715985]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 165}], {
             RGBColor[
             0.2120938524489715, 0.3402544648237721, 0.9353898031810077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 175}], {
             RGBColor[
             0.19450102624862847`, 0.3217632890376051, 0.9343879177551523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 183}], {
             RGBColor[
             0.19956688605797046`, 0.32708782889128674`, 0.9346764109770263]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 224}], {
             RGBColor[
             0.20753059097457632`, 0.33545818768669444`, 0.9351299321907813]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 253}], {
             RGBColor[
             0.19912169776175326`, 0.3266199077653942, 0.9346510581621539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 262}], {
             RGBColor[
             0.25511664496274467`, 0.3854741475583434, 0.9378398875681493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 41}], {
             RGBColor[
             0.18496389091314852`, 0.31173915511071026`, 0.9338447920067241]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 55}], {
             RGBColor[
             0.19173502245287335`, 0.3188560436734967, 0.9342303979309199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 152}], {
             RGBColor[
             0.18192632080115292`, 0.3085464763299341, 0.9336718068825283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 208}], {
             RGBColor[
             0.1853248284213402, 0.31211852331657947`, 0.9338653468638564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 242}], {
             RGBColor[
             0.18110760662426995`, 0.30768595582055314`, 0.9336251823213337]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 250}], {
             RGBColor[
             0.18199349180428678`, 0.3086170773131154, 0.9336756321717861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 268}], {
             RGBColor[
             0.19319132437376368`, 0.32038670932722724`, 0.934313332170909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 41}], {
             RGBColor[
             0.20758147265742513`, 0.3355116675614536, 0.9351328298273469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 44}], {
             RGBColor[
             0.27139379762507876`, 0.4018915080789134, 0.9387921467246012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 55}], {
             RGBColor[
             0.21435260419714997`, 0.34262855612424004`, 0.9355184357515427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 61}], {
             RGBColor[
             0.25191376002181387`, 0.38210771241079083`, 0.937657488009007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 71}], {
             RGBColor[
             0.22494256325409756`, 0.3537592745352769, 0.9361215182533955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 108}], {
             RGBColor[
             0.23362687386015235`, 0.362887035599335, 0.936616076895124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 136}], {
             RGBColor[
             0.309591888135542, 0.4349767741872242, 0.9412260952746828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 152}], {
             RGBColor[
             0.20454390254542953`, 0.33231898878067745`, 0.9349598447031511]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 161}], {
             RGBColor[
             0.21411146518921928`, 0.3423751037378088, 0.9355047032417743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 177}], {
             RGBColor[
             0.2592700003340752, 0.38983958739155206`, 0.9380764150122078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 208}], {
             RGBColor[
             0.20794241016561682`, 0.3358910357673228, 0.9351533846844792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 252}], {
             RGBColor[
             0.23225528127463596`, 0.3614454048279645, 0.9365379667264683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 268}], {
             RGBColor[
             0.21580890611804032`, 0.3441592217779706, 0.9356013699915318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 279}], {
             RGBColor[
             0.23161750381713786`, 0.36077506028270767`, 0.936501646243771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 280}], {
             RGBColor[
             0.2442905970349878, 0.3740952847751871, 0.9372233601543662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 52}], {
             RGBColor[
             0.19242626978916738`, 0.3195825884515542, 0.934269763444113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 53}], {
             RGBColor[
             0.2009984379794762, 0.32859248072642344`, 0.9347579357411648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 57}], {
             RGBColor[
             0.18289757268776397`, 0.30956732364368866`, 0.9337271182406324]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 88}], {
             RGBColor[
             0.20448897001762012`, 0.33226125121102634`, 0.9349567163769577]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 124}], {
             RGBColor[
             0.186021974396972, 0.31285126793857626`, 0.9339050482958335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 147}], {
             RGBColor[
             0.1997586179230488, 0.3272893512379864, 0.9346873298231007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 247}], {
             RGBColor[
             0.19193794866685385`, 0.31906933199065524`, 0.9342419542786038]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 289}], {
             RGBColor[
             0.21478203632197956`, 0.34307991651500525`, 0.935542891275764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 64}], {
             RGBColor[
             0.2185143800083959, 0.3470028463736865, 0.9357554427271977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 69}], {
             RGBColor[
             0.20464654155210055`, 0.3324268688843776, 0.9349656898427401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 76}], {
             RGBColor[
             0.26432098730221126`, 0.39346839209165385`, 0.9384255780434674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 85}], {
             RGBColor[
             0.21693635514660192`, 0.345344242191386, 0.9356655765457971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 90}], {
             RGBColor[
             0.20870014958760652`, 0.3366874679432882, 0.9351965368235865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 118}], {
             RGBColor[
             0.19522260799965463`, 0.322521717208859, 0.9344290107683887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 126}], {
             RGBColor[
             0.21260629074350712`, 0.3407930699617935, 0.9354189857837971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 153}], {
             RGBColor[
             0.2113966935997263, 0.3395217066707913, 0.9353501010158973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 166}], {
             RGBColor[
             0.19390930592620187`, 0.3211413534614994, 0.9343542201581618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 195}], {
             RGBColor[
             0.1927241486561343, 0.3198956780273474, 0.9342867272049146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 234}], {
             RGBColor[
             0.19793969225016772`, 0.3253775450292399, 0.9345837446968894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 239}], {
             RGBColor[
             0.2196501555680895, 0.3481966184992542, 0.9358201234650929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 248}], {
             RGBColor[
             0.21184147363468755`, 0.3399891986882186, 0.9353754305808952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 263}], {
             RGBColor[
             0.2058067463664483, 0.333646317705491, 0.935031761790548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 285}], {
             RGBColor[
             0.20070194384757245`, 0.3282808465949789, 0.9347410508389766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 42}], {
             RGBColor[
             0.763419188891056, 0.5236029358473995, 0.5766518342873496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 66}], {
             RGBColor[
             0.5377876957046065, 0.6331026822689709, 0.9577491794160538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 81}], {
             RGBColor[
             0.7893492688527326, 0.6740607768287987, 0.5995695817860118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 86}], {
             RGBColor[
             0.6417053553097174, 0.7192862820416126, 0.9654274840700409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 94}], {
             RGBColor[
             0.7430612286953848, 0.7992043464221197, 0.9750250570405241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 97}], {
             RGBColor[
             0.5690459020341019, 0.6601769695084484, 0.9597409246828227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 120}], {
             RGBColor[
             0.4841619759818365, 0.5839129078583203, 0.9544325893141365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 130}], {
             RGBColor[
             0.8005184128051482, 0.7225949328330918, 0.608776500228449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 140}], {
             RGBColor[
             0.7532763216794478, 0.4456404138262269, 0.5669390131907837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 162}], {
             RGBColor[
             0.8402909601650888, 0.8739220660440041, 0.881352498558146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 169}], {
             RGBColor[
             0.6469863029423364, 0.7235735932337524, 0.9658432196124291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 178}], {
             RGBColor[
             0.4741224882012588, 0.573360769660643, 0.953860855337124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 182}], {
             RGBColor[
             0.47178862651241965`, 0.5709077330502953, 0.9537279453665835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 201}], {
             RGBColor[
             0.7672988678714465, 0.5534238485768511, 0.5803670192604423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 202}], {
             RGBColor[
             0.777902189496511, 0.6220822630055047, 0.5900178581775892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 55}], {
             RGBColor[
             0.19536579579315563`, 0.32267221665845913`, 0.9344371651014012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 108}], {
             RGBColor[
             0.21464006545615802`, 0.34293069613355404`, 0.9355348062449824]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 152}], {
             RGBColor[
             0.1855570941414352, 0.31236264931489655`, 0.9338785740530094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 208}], {
             RGBColor[
             0.1889556017616225, 0.3159346963015419, 0.9340721140343375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 219}], {
             RGBColor[
             0.18646440411145038`, 0.3133162896201571, 0.933930244013557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 242}], {
             RGBColor[
             0.18473837996455222`, 0.31150212880551553`, 0.933831949491815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.18562426514456906`, 0.3124332502980778, 0.9338823993422674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 252}], {
             RGBColor[
             0.21326847287064163`, 0.3414890653621836, 0.9354566960763266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 268}], {
             RGBColor[
             0.19682209771404596`, 0.32420288231218963`, 0.9345200993413902]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 80}], {
             RGBColor[
             0.9082065714342227, 0.6151149855425471, 0.2779093700047311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 81}], {
             RGBColor[
             0.8635348143848929, 0.4405098850237444, 0.2065613896917941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 82}], {
             RGBColor[
             0.7255221919430327, 0.49355450623719554`, 0.5731775024918879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 87}], {
             RGBColor[
             0.915376392222736, 0.6389023704076946, 0.3396146781641949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 130}], {
             RGBColor[
             0.8747039583373085, 0.4890440410280375, 0.21576830813423137`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 140}], {
             RGBColor[
             0.8274618672116081, 0.2120895220211726, 0.17393082109656596`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 145}], {
             RGBColor[
             0.8512542986237088, 0.5925834616705845, 0.5853100694048696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 162}], {
             RGBColor[
             0.914476505697249, 0.6403711742389498, 0.48834430646392846`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 167}], {
             RGBColor[
             0.8726433787924812, 0.48087452978022555`, 0.21411031746444492`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 181}], {
             RGBColor[
             0.9119493492321276, 0.6277402539008983, 0.29244935498531105`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 201}], {
             RGBColor[
             0.8414844134036068, 0.31987295677179683`, 0.18735882716622465`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 202}], {
             RGBColor[
             0.8520877350286713, 0.3885313712004504, 0.1970096660833716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 203}], {
             RGBColor[
             0.8873649131430477, 0.6213403105093347, 0.5874793203268023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 216}], {
             RGBColor[
             0.8520342261383788, 0.3882883998269512, 0.19696501695368862`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 237}], {
             RGBColor[
             0.8313396990003062, 0.24189623642583113`, 0.17764423719680783`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 269}], {
             RGBColor[
             0.9053848161613813, 0.6055965424276077, 0.2669473836135131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 293}], {
             RGBColor[
             0.8686817504503115, 0.4638809195993508, 0.210856119307727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 299}], {
             RGBColor[
             0.8281493166036277, 0.217373559290479, 0.1745891234107269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 66}], {
             RGBColor[
             0.3059641689064351, 0.4317438620573953, 0.9409982635304203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 78}], {
             RGBColor[
             0.20985899682898168`, 0.3379054898691324, 0.9352625314596219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 97}], {
             RGBColor[
             0.33722237523593046`, 0.45881814929687276`, 0.9429900087971892]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 99}], {
             RGBColor[
             0.21063039427602828`, 0.33871627749540134`, 0.9353064614030511]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 178}], {
             RGBColor[
             0.24229896140308743`, 0.37200194944906734`, 0.9371099394514903]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 182}], {
             RGBColor[
             0.23996509971424826`, 0.36954891283871966`, 0.9369770294809499]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 199}], {
             RGBColor[
             0.21199067610024028`, 0.34014601993949717`, 0.9353839274405833]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 215}], {
             RGBColor[
             0.22516415254335911`, 0.35399217892786317`, 0.9361341374356069]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 229}], {
             RGBColor[
             0.221649468641255, 0.3502980233029215, 0.935933981386891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 233}], {
             RGBColor[
             0.2154911007768475, 0.3438251882143545, 0.9355832714475019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 259}], {
             RGBColor[
             0.20537394232393572`, 0.33319141321544904`, 0.9350071142406031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 261}], {
             RGBColor[
             0.23516151692935008`, 0.3645000427670523, 0.9367034725476139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 284}], {
             RGBColor[
             0.23327215251581435`, 0.3625142009758035, 0.9365958760393271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 59}], {
             RGBColor[
             0.650613500039462, 0.7181916581041776, 0.9197475834219577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 61}], {
             RGBColor[
             0.29673927658547317`, 0.4285312134624696, 0.9402355342561197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 71}], {
             RGBColor[
             0.26976807981775686`, 0.40018277558695564`, 0.9386995645005083]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 108}], {
             RGBColor[
             0.27845239042381165`, 0.4093105366510138, 0.9391941231422369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 136}], {
             RGBColor[
             0.3544174046992013, 0.48140027523890294`, 0.9438041415217957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 177}], {
             RGBColor[
             0.3040955168977345, 0.4362630884432308, 0.9406544612593207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 194}], {
             RGBColor[
             0.5011124283287507, 0.6014735099165995, 0.9553542362124354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 204}], {
             RGBColor[
             0.39991382818369614`, 0.5199845367377941, 0.9469303798325985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 226}], {
             RGBColor[
             0.6512382253914439, 0.7184499980919314, 0.9093942676022314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 252}], {
             RGBColor[
             0.27708079783829526`, 0.4078689058796433, 0.9391160129735812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 268}], {
             RGBColor[
             0.2606344226816996, 0.39058272282964934`, 0.9381794162386446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 279}], {
             RGBColor[
             0.27644302038079716`, 0.4071985613343865, 0.9390796924908837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 280}], {
             RGBColor[
             0.2891161135986471, 0.42051878582686586`, 0.939801406401479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 283}], {
             RGBColor[
             0.3110200455084933, 0.44354120705361005`, 0.9410488029197814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 89}], {
             RGBColor[
             0.34033954683031736`, 0.4683920819989782, 0.9429369415722573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 94}], {
             RGBColor[
             0.5484117816822776, 0.636917841037437, 0.9603911500045271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 96}], {
             RGBColor[
             0.2504426073839444, 0.3805614377119254, 0.9375737080426556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 120}], {
             RGBColor[
             0.2895125289687292, 0.4216264024736376, 0.9397986822781397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 131}], {
             RGBColor[
             0.2646712879230951, 0.39551668310902466`, 0.9383840103499137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 132}], {
             RGBColor[
             0.24841553022607393`, 0.3784308510948885, 0.9374582689973068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 141}], {
             RGBColor[
             0.2968912603514489, 0.4293819169954668, 0.9402188901145307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 146}], {
             RGBColor[
             0.24998188699294738`, 0.3800771913696276, 0.937547470697963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 188}], {
             RGBColor[
             0.32789958178650086`, 0.45761720952884744`, 0.9421442779998944]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 236}], {
             RGBColor[
             0.26568284234196243`, 0.3965798909395088, 0.9384416168776075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 260}], {
             RGBColor[
             0.2790511539192304, 0.41063083400712647`, 0.9392029224452882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 281}], {
             RGBColor[
             0.6391981620742301, 0.7080190375817033, 0.9308676637061029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 294}], {
             RGBColor[
             0.4179920843483252, 0.5334044550653643, 0.9485055663485399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 60}], {
             RGBColor[
             0.2459880706675731, 0.3758794371890788, 0.9373200287665547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 62}], {
             RGBColor[
             0.20319287451419632`, 0.3308989726597267, 0.9348829056554392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 117}], {
             RGBColor[
             0.1951092767006187, 0.3224025988279529, 0.9344225567185672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 158}], {
             RGBColor[
             0.1988271914603046, 0.32631036296979365`, 0.9346342864639694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 196}], {
             RGBColor[
             0.2038842250820344, 0.33162562594068223`, 0.9349222770475161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 207}], {
             RGBColor[
             0.1949982416588687, 0.3222858939590454, 0.9344162334372013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 212}], {
             RGBColor[
             0.21903868251240277`, 0.34755392154809645`, 0.9357853009791648]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 214}], {
             RGBColor[
             0.20276955741382008`, 0.3304540395473769, 0.9348587983728143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 225}], {
             RGBColor[
             0.21615267984960895`, 0.3445205497663627, 0.935620947396977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 265}], {
             RGBColor[
             0.21371228475052867`, 0.3419555397872433, 0.9354819705063254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 276}], {
             RGBColor[
             0.22304128842203616`, 0.35176091413899346`, 0.9360132434643936]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.19252503662856937`, 0.3196863986619449, 0.9342753880695046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 112}], {
             RGBColor[
             0.18666547155784385`, 0.31352762425472913`, 0.9339416945071765]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 131}], {
             RGBColor[
             0.20675371716772, 0.33464164405904423`, 0.9350856903767627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 133}], {
             RGBColor[
             0.18469446291568115`, 0.3114559692026503, 0.9338294484808514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 146}], {
             RGBColor[
             0.19206431623757236`, 0.3192021523196471, 0.9342491507248121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 170}], {
             RGBColor[
             0.1908380369178425, 0.3179132550040116, 0.9341793159316711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 190}], {
             RGBColor[
             0.1942570496898653, 0.32150685420533776`, 0.9343740236510617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.18784627824446665`, 0.31476872694983776`, 0.9340089397011326]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 70}], {
             RGBColor[
             0.2012898575043234, 0.328898781124103, 0.9347745316519882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 71}], {
             RGBColor[
             0.2080633650262977, 0.3360181669948795, 0.9351602728848583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 73}], {
             RGBColor[
             0.187739347830093, 0.31465633630455114`, 0.9340028501722235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 100}], {
             RGBColor[
             0.18673636136840888`, 0.31360213394030656`, 0.9339457315770161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 119}], {
             RGBColor[
             0.1868307341329213, 0.31370132569938797`, 0.933951105966343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 122}], {
             RGBColor[
             0.1889251216320018, 0.3159026597527588, 0.9340703782360471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 138}], {
             RGBColor[
             0.21204884540564534`, 0.34020715956762493`, 0.9353872400964722]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 161}], {
             RGBColor[
             0.19723226696141938`, 0.3246339961974114, 0.9345434578732372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 244}], {
             RGBColor[
             0.19115682833937214`, 0.31824832500058275`, 0.9341974706315176]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 266}], {
             RGBColor[
             0.19547981769013628`, 0.32279206090159157`, 0.934443658479754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 54}], {
             RGBColor[
             0.22682934694082163`, 0.355742403819019, 0.936228967793108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 102}], {
             RGBColor[
             0.20090857647606358`, 0.32849803058878846`, 0.9347528182614836]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 143}], {
             RGBColor[
             0.2582581828615999, 0.38877610307504745`, 0.9380187935040003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 172}], {
             RGBColor[
             0.20010293929950806`, 0.3276512548358813, 0.9347069384161122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 174}], {
             RGBColor[
             0.22141328802375174`, 0.3500497824992095, 0.9359205312501221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 238}], {
             RGBColor[
             0.19853266531396374`, 0.3260007973159532, 0.9346175136356476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 298}], {
             RGBColor[
             0.23487979924778435`, 0.36420393962179404`, 0.9366874291424127]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 206}], {
             RGBColor[
             0.20212300857950383`, 0.32977447572894675`, 0.9348219783731833]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 219}], {
             RGBColor[
             0.1830787781409705, 0.30975778206409804`, 0.9337374376231229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 83}], {
             RGBColor[
             0.8289246632002845, 0.6056697988799424, 0.5870191249815166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 101}], {
             RGBColor[
             0.7293123816710212, 0.7884636426315792, 0.9736547004594159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 104}], {
             RGBColor[
             0.5731922784257398, 0.6585842020957557, 0.9621993062038972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 116}], {
             RGBColor[
             0.5493242790295518, 0.6359329023080253, 0.960750884061716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 142}], {
             RGBColor[
             0.8206161663608685, 0.5418070513656623, 0.579062899024987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 149}], {
             RGBColor[
             0.8534002738604769, 0.7354497327448786, 0.6081721446101185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 197}], {
             RGBColor[
             0.8988192263028636, 0.9205652040419037, 0.9289214218265444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 198}], {
             RGBColor[
             0.8879439008384149, 0.9128115493875727, 0.9633242059952494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 204}], {
             RGBColor[
             0.647452541380158, 0.7220822556308867, 0.967158350930859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 226}], {
             RGBColor[
             0.8987769385879059, 0.920547716985024, 0.9296222387004919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 243}], {
             RGBColor[
             0.8993571244293498, 0.920787638740557, 0.9200070578349391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 254}], {
             RGBColor[
             0.5650392887707011, 0.6515224922377361, 0.9616798049124837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 283}], {
             RGBColor[
             0.5585587587049552, 0.6456389259467026, 0.9612767740180419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 53}], {
             RGBColor[
             0.2073052253779457, 0.3352213141556316, 0.9351170979534518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 57}], {
             RGBColor[
             0.18920436008623348`, 0.3161961570728968, 0.9340862804529193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 84}], {
             RGBColor[
             0.1931004885069918, 0.32029123507192336`, 0.9343081592026761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 88}], {
             RGBColor[
             0.21079575741608964`, 0.3388900846402345, 0.9353158785892447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 93}], {
             RGBColor[
             0.21993156031517644`, 0.348492392730534, 0.9358361490491385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 124}], {
             RGBColor[
             0.1923287617954415, 0.3194801013677844, 0.9342642105081206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 137}], {
             RGBColor[
             0.23013360981142927`, 0.35921539359839394`, 0.9364171406753703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 147}], {
             RGBColor[
             0.20606540532151835`, 0.3339181846671946, 0.9350464920353876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 217}], {
             RGBColor[
             0.19938565089971289`, 0.32689733924898534`, 0.9346660899028769]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 247}], {
             RGBColor[
             0.1982447360653234, 0.3256981654198634, 0.9346011164908907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 270}], {
             RGBColor[
             0.20578610160522076`, 0.3336246187524874, 0.9350305861019373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 271}], {
             RGBColor[
             0.21068413741610115`, 0.3387727649431298, 0.9353095219953723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 273}], {
             RGBColor[
             0.2188316043007933, 0.34733626921817795`, 0.9357735081813584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 289}], {
             RGBColor[
             0.22108882372044908`, 0.3497087499442134, 0.9359020534880509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 295}], {
             RGBColor[
             0.19782793389837072`, 0.3252600799156124, 0.9345773802240863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 88}], {
             RGBColor[
             0.21936792560639845`, 0.34789997691510377`, 0.9358040508862964]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 93}], {
             RGBColor[
             0.22850372850548528`, 0.3575022850054033, 0.93632432134619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 107}], {
             RGBColor[
             0.3121763440598402, 0.43622685441542786`, 0.9414269663560839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 124}], {
             RGBColor[
             0.20090092998575032`, 0.32848999364265374`, 0.9347523828051723]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 137}], {
             RGBColor[
             0.2387057780017381, 0.36822528587326325`, 0.936905312972422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 147}], {
             RGBColor[
             0.21463757351182716`, 0.3429280769420639, 0.9355346643324394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 217}], {
             RGBColor[
             0.2079578190900217, 0.3359072315238546, 0.9351542621999286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 247}], {
             RGBColor[
             0.2068169042556322, 0.33470805769473266`, 0.9350892887879424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 251}], {
             RGBColor[
             0.25074234215186236`, 0.3808764779572891, 0.9375907774942707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 270}], {
             RGBColor[
             0.21435826979552958`, 0.3426345110273567, 0.935518758398989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 271}], {
             RGBColor[
             0.21925630560640996`, 0.3477826572179991, 0.935797694292424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 273}], {
             RGBColor[
             0.2274037724911021, 0.35634616149304726`, 0.9362616804784101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 289}], {
             RGBColor[
             0.22966099191075792`, 0.3587186422190827, 0.9363902257851027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 75}], {
             RGBColor[
             0.2884831291269512, 0.41830852004459096`, 0.9398219273882558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 102}], {
             RGBColor[
             0.218116116310074, 0.34658424597537324`, 0.9357327621987566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 111}], {
             RGBColor[
             0.4291203016109882, 0.5357529458181629, 0.9499902123364491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 143}], {
             RGBColor[
             0.2754657226956103, 0.40686231846163223`, 0.9389987374412732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 163}], {
             RGBColor[
             0.4325936369919836, 0.5385727559524309, 0.9502636460208878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 165}], {
             RGBColor[
             0.2309155676527057, 0.3600372808685661, 0.936461672017628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 172}], {
             RGBColor[
             0.21731047913351847`, 0.34573747022246615`, 0.935686882353385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 174}], {
             RGBColor[
             0.23862082785776215`, 0.3681359978857943, 0.936900475187395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 185}], {
             RGBColor[
             0.3867966632124244, 0.5013927095080272, 0.9466583404851183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 235}], {
             RGBColor[
             0.32626536687632174`, 0.4510335953926109, 0.9422293781681247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 238}], {
             RGBColor[
             0.21574020514797415`, 0.344087012702538, 0.9355974575729206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 298}], {
             RGBColor[
             0.25208733908179476`, 0.3822901550083788, 0.9376673730796856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 108}], {
             RGBColor[
             0.22141119699588285`, 0.35004758469634045`, 0.9359204121691784]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 114}], {
             RGBColor[
             0.22063449464495144`, 0.3492312212797382, 0.9358761801193209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 208}], {
             RGBColor[
             0.19572673330134732`, 0.32305158486432833`, 0.9344577199585336]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 219}], {
             RGBColor[
             0.19323553565117518`, 0.3204331781829436, 0.9343158499377529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 242}], {
             RGBColor[
             0.19150951150427703`, 0.318619017368302, 0.9342175554160109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 250}], {
             RGBColor[
             0.1923953966842939, 0.31955013886086425`, 0.9342680052664631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 252}], {
             RGBColor[
             0.22003960441036646`, 0.34860595392497, 0.9358423020005227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 268}], {
             RGBColor[
             0.20359322925377082`, 0.3313197708749761, 0.9349057052655861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 283}], {
             RGBColor[
             0.25397885208056453`, 0.38427825509893676`, 0.9377750919467229]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 57}], {
             RGBColor[
             0.18951617750640207`, 0.3165238969518603, 0.9341040379937053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 84}], {
             RGBColor[
             0.1934123059271604, 0.32061897495088687`, 0.9343259167434621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 110}], {
             RGBColor[
             0.1926369557700678, 0.31980403277574326`, 0.9342817616990433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 148}], {
             RGBColor[
             0.2228269723814797, 0.3515356543919468, 0.936001038482936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 191}], {
             RGBColor[
             0.21336670196225918`, 0.34159231036555776`, 0.9354622900777774]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 217}], {
             RGBColor[
             0.19969746831988144`, 0.32722507912794885`, 0.934683847443663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 223}], {
             RGBColor[
             0.19042353178656807`, 0.3174775838298989, 0.9341557104776503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 246}], {
             RGBColor[
             0.1919032518459413, 0.3190328634319706, 0.934239978345982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 247}], {
             RGBColor[
             0.19855655348549195`, 0.3260259052988269, 0.9346188740316768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 251}], {
             RGBColor[
             0.2424819913817221, 0.3721943255613833, 0.9371203627380049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 270}], {
             RGBColor[
             0.20609791902538932`, 0.3339523586314509, 0.9350483436427234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 271}], {
             RGBColor[
             0.21099595483626973`, 0.3391005048220933, 0.9353272795361584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 278}], {
             RGBColor[
             0.1999933373080916, 0.327536056193735, 0.9347006967448426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 295}], {
             RGBColor[
             0.19813975131853928`, 0.3255878197945759, 0.9345951377648724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.18357179140558838`, 0.31027597026405784`, 0.9337655139991952]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 217}], {
             RGBColor[
             0.18985695379830947`, 0.3168820744411198, 0.9341234446993961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 223}], {
             RGBColor[
             0.1805830172649961, 0.30713457914306985`, 0.9335953077333836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 247}], {
             RGBColor[
             0.18871603896391997`, 0.3156829006119979, 0.9340584712874099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 278}], {
             RGBColor[
             0.19015282278651957`, 0.31719305150690597`, 0.9341402940005757]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 295}], {
             RGBColor[
             0.1882992367969673, 0.3152448151077469, 0.9340347350206055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 134}], {
             RGBColor[
             0.21796998739019388`, 0.34643065521547056`, 0.9357244403729478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 160}], {
             RGBColor[
             0.19345266111115197`, 0.32066139080792844`, 0.9343282149114902]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 164}], {
             RGBColor[
             0.1865510290497441, 0.3134073379226422, 0.9339351771756428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 176}], {
             RGBColor[
             0.19266677740688082`, 0.31983537720683475`, 0.9342834599971428]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 180}], {
             RGBColor[
             0.1930127612329003, 0.32019902814462275`, 0.9343031632641974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 187}], {
             RGBColor[
             0.20794054512620663`, 0.3358890754926524, 0.9351532784732439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 215}], {
             RGBColor[
             0.20794131603506694`, 0.33588988576674306`, 0.935153322375363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 221}], {
             RGBColor[
             0.18866826221874242`, 0.3156326842235957, 0.9340557504724514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 230}], {
             RGBColor[
             0.19161321755920613`, 0.31872801900737613`, 0.9342234613224198]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[
             0.20819170713916685`, 0.33615306269286493`, 0.9351675817783212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 288}], {
             RGBColor[
             0.200003126765576, 0.32754634553423856`, 0.9347012542399642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 296}], {
             RGBColor[
             0.18917402722894824`, 0.3161642753166758, 0.9340845530415703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 297}], {
             RGBColor[
             0.19156703343003767`, 0.3186794765593771, 0.934220831204587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 72}], {
             RGBColor[
             0.9072115711061266, 0.6075869855350652, 0.536963277053603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 83}], {
             RGBColor[
             0.9157801358545465, 0.6734487289604354, 0.5451685443334997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 106}], {
             RGBColor[
             0.9234341463667425, 0.9403782883321993, 0.9424056010083017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 136}], {
             RGBColor[
             0.6888115905499252, 0.7512769242124885, 0.9221815319720392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 155}], {
             RGBColor[
             0.9556607617329471, 0.8668171290315656, 0.5788467809151635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[
             0.8355066141794747, 0.8713501588901851, 0.9337316266626792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 197}], {
             RGBColor[
             0.9856746989571257, 0.9883441341223966, 0.8870708411785275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 198}], {
             RGBColor[
             0.974799373492677, 0.9805904794680657, 0.9214736253472325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 210}], {
             RGBColor[
             0.7283433684413259, 0.785018817714684, 0.9248382115325371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 226}], {
             RGBColor[
             0.9856324112421679, 0.988326647065517, 0.887771658052475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 227}], {
             RGBColor[
             0.9688560866723765, 0.9191321953350291, 0.5894640490955131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 241}], {
             RGBColor[
             0.9855659463819599, 0.9882991621377519, 0.8888731527916648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 290}], {
             RGBColor[
             0.9657093115675036, 0.9066562806448499, 0.5869320799818273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 291}], {
             RGBColor[
             0.955941254786202, 0.9662985742039245, 0.945506158028788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 77}], {
             RGBColor[
             0.3505250523811867, 0.47604307306451876`, 0.9436288356859599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 95}], {
             RGBColor[
             0.28741190007160666`, 0.4194185083151971, 0.9396790545700505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 103}], {
             RGBColor[
             0.35429852491084235`, 0.47931146530946245`, 0.9438692780187988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 127}], {
             RGBColor[
             0.3180513290021859, 0.44791596605042294`, 0.941559638747636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 145}], {
             RGBColor[
             0.5760856373176906, 0.6571907606456139, 0.9633236613969889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 148}], {
             RGBColor[
             0.2667823322730826, 0.39773552456880407`, 0.9385042312026353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 159}], {
             RGBColor[
             0.28925410608148494`, 0.42135478363418655`, 0.9397839654770135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 168}], {
             RGBColor[
             0.3438394161380286, 0.4702523109805432, 0.9432028328564219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 196}], {
             RGBColor[
             0.24516356622564123`, 0.3750128307440074, 0.9372730744583317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 205}], {
             RGBColor[
             0.3298135622578278, 0.45810382130942706`, 0.9423091178497511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 212}], {
             RGBColor[
             0.2603180236560096, 0.39094112635142153`, 0.9381360983899805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 225}], {
             RGBColor[
             0.25743202099321577`, 0.38790775456968785`, 0.9379717448077927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 265}], {
             RGBColor[
             0.2549916258941355, 0.3853427445905684, 0.9378327679171411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 276}], {
             RGBColor[
             0.26432062956564295`, 0.39514811894231855`, 0.9383640408752093]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 282}], {
             RGBColor[
             0.36394977931359895`, 0.4876708967869795, 0.9444842474150733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 71}], {
             RGBColor[
             0.25028804221449197`, 0.3803989799188331, 0.9375649057849139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 108}], {
             RGBColor[
             0.25897235282054676`, 0.38952674098289125`, 0.9380594644266425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 136}], {
             RGBColor[
             0.33493736709593636`, 0.46161647957078045`, 0.9426694828062012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 161}], {
             RGBColor[
             0.23945694414961366`, 0.369014809121365, 0.9369480907732928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 177}], {
             RGBColor[
             0.2846154792944696, 0.4164792927751083, 0.9395198025437264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 194}], {
             RGBColor[
             0.4816323907254858, 0.581689714248477, 0.9542195774968412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 252}], {
             RGBColor[
             0.2576007602350303, 0.3880851102115208, 0.9379813542579867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 268}], {
             RGBColor[
             0.24115438507843467`, 0.37079892716152685`, 0.9370447575230503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 279}], {
             RGBColor[
             0.25696298277753227`, 0.387414765666264, 0.9379450337752894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 280}], {
             RGBColor[
             0.2696360759953822, 0.40073499015874336`, 0.9386667476858847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 117}], {
             RGBColor[
             0.1935934216908487, 0.32080933910192594`, 0.9343362310182673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 135}], {
             RGBColor[
             0.20737676424851148`, 0.33529650604442257`, 0.9351211719862982]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 158}], {
             RGBColor[
             0.1973113364505346, 0.3247171032437667, 0.9345479607636695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 186}], {
             RGBColor[
             0.19739650616034748`, 0.3248066220088515, 0.934552811052646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 196}], {
             RGBColor[
             0.2023683700722644, 0.33003236621465526`, 0.9348359513472162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 207}], {
             RGBColor[
             0.19348238664909873`, 0.3206926342330184, 0.9343299077369014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 212}], {
             RGBColor[
             0.2175228275026328, 0.34596066182206947`, 0.9356989752788649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 214}], {
             RGBColor[
             0.20125370240405008`, 0.3288607798213499, 0.9347724726725144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 225}], {
             RGBColor[
             0.21463682483983898`, 0.34292729004033573`, 0.9355346216966771]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 265}], {
             RGBColor[
             0.2121964297407587, 0.3403622800612163, 0.9353956448060256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 276}], {
             RGBColor[
             0.22152543341226616`, 0.3501676544129665, 0.9359269177640938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 286}], {
             RGBColor[
             0.21128388043674812`, 0.3394031328837336, 0.935343676473158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 71}], {
             RGBColor[
             0.20309975866494467`, 0.3308011019982774, 0.9348776028455769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 73}], {
             RGBColor[
             0.18277574146873998`, 0.309439271307949, 0.933720180132942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 152}], {
             RGBColor[
             0.18270109795627662`, 0.30936081624367795`, 0.9337159292953324]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 161}], {
             RGBColor[
             0.19226866060006637`, 0.3194169312008093, 0.9342607878339557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 208}], {
             RGBColor[
             0.1860996055764639, 0.3129328632303233, 0.9339094692766605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 244}], {
             RGBColor[
             0.18619322197801913`, 0.31303126000398057`, 0.9339148005922362]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 69}], {
             RGBColor[
             0.22143670136219934`, 0.3500743914024093, 0.9359218646051097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 76}], {
             RGBColor[
             0.28111114711231006`, 0.41111591460968555`, 0.939381752805837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 85}], {
             RGBColor[
             0.2337265149567007, 0.3629917647094177, 0.9366217513081667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 90}], {
             RGBColor[
             0.22549030939770529`, 0.3543349904613199, 0.936152711585956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 118}], {
             RGBColor[
             0.2120127678097534, 0.3401692397268907, 0.9353851855307582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 121}], {
             RGBColor[
             0.2303769927354159, 0.3594712044828725, 0.9364310009728385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 173}], {
             RGBColor[
             0.21829574180286104`, 0.34677304375720647`, 0.9357429916048386]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 213}], {
             RGBColor[
             0.21883980227157213`, 0.34734488580524786`, 0.9357739750436664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 234}], {
             RGBColor[
             0.2147298520602665, 0.3430250675472716, 0.9355399194592591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 239}], {
             RGBColor[
             0.23644031537818827`, 0.3658441410172859, 0.9367762982274624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 249}], {
             RGBColor[
             0.22138061658703678`, 0.35001544274773333`, 0.9359186706601341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 258}], {
             RGBColor[
             0.28773302970917036`, 0.41685145648958927`, 0.939803693309408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 263}], {
             RGBColor[
             0.22259690617654707`, 0.3512938402235227, 0.9359879365529176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 286}], {
             RGBColor[
             0.22809764059378232`, 0.35707546086274283`, 0.9363011952403719]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 70}], {
             RGBColor[
             0.2936166091660087, 0.41958665894484415`, 0.940265032379005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 106}], {
             RGBColor[
             0.6196619973862446, 0.6970249085872788, 0.9659794196694249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 115}], {
             RGBColor[
             0.3645960621661024, 0.4902165167425332, 0.9444527165749532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 138}], {
             RGBColor[
             0.30437559706733064`, 0.4308950373883661, 0.9408777408234891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 155}], {
             RGBColor[
             0.6518886127524492, 0.6234637492866453, 0.6024205995762867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 194}], {
             RGBColor[
             0.5317344651989768, 0.6279967791452647, 0.9573054453238024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 200}], {
             RGBColor[
             0.37151685139917806`, 0.49621095652724223`, 0.9448937031450712]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[
             0.424571219460828, 0.5416654379697635, 0.9484120301936603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 211}], {
             RGBColor[
             0.3240980577045407, 0.45162459399430244`, 0.9420009057800123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 231}], {
             RGBColor[
             0.30432205873480145`, 0.4308387652063516, 0.9408746918946544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 241}], {
             RGBColor[
             0.6817937974014621, 0.7449457823928316, 0.912446971452788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 264}], {
             RGBColor[
             0.33683666992223255`, 0.4650136831097602, 0.942726350900722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 291}], {
             RGBColor[
             0.6521691058057041, 0.7229451944590042, 0.9690799766899112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 86}], {
             RGBColor[
             0.49025940765542825`, 0.5952351366581299, 0.9535166371045274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 97}], {
             RGBColor[
             0.4175999543798127, 0.5361258241249656, 0.9478300777173092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 162}], {
             RGBColor[
             0.6888450125107997, 0.7498709206605213, 0.8694416515926326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 169}], {
             RGBColor[
             0.4955403552880472, 0.5995224478502696, 0.9539323726469158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 187}], {
             RGBColor[
             0.305540960778381, 0.4312990434818653, 0.9409741624536079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 193}], {
             RGBColor[
             0.33295274750258996`, 0.46011056933666983`, 0.9425352231554471]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 215}], {
             RGBColor[
             0.3055417316872413, 0.4312998537559559, 0.940974206355727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 228}], {
             RGBColor[
             0.40629940527691566`, 0.5263378564741489, 0.9471100167211559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 118}], {
             RGBColor[
             0.18382399790050605`, 0.31054105528103165`, 0.9337798767859746]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 166}], {
             RGBColor[
             0.1825106958270533, 0.309160691533672, 0.9337050861757479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 173}], {
             RGBColor[
             0.1901069718936137, 0.3171448593113474, 0.934137682860055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 195}], {
             RGBColor[
             0.18132553855698572`, 0.30791501609952, 0.9336375932225005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 213}], {
             RGBColor[
             0.19065103236232478`, 0.3177167013593888, 0.9341686662988828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 234}], {
             RGBColor[
             0.18654108215101917`, 0.31339688310141245`, 0.9339346107144755]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 263}], {
             RGBColor[
             0.19440813626729972`, 0.3216656557776636, 0.934382627808134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 75}], {
             RGBColor[
             0.6048929892039929, 0.6837170469414527, 0.9652757515328931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 83}], {
             RGBColor[
             0.8617045963739112, 0.6317374119212176, 0.5901643374072268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 109}], {
             RGBColor[
             0.9348338843673183, 0.947970458954174, 0.8784588716115629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 111}], {
             RGBColor[
             0.7455301616880299, 0.8011614727150247, 0.9754440364810864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 143}], {
             RGBColor[
             0.5918755827726521, 0.672270845358494, 0.9644525615859105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 163}], {
             RGBColor[
             0.7490034970690254, 0.8039812828492927, 0.9757174701655251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 185}], {
             RGBColor[
             0.7032065232894661, 0.766801236404889, 0.9721121646297556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 218}], {
             RGBColor[
             0.9220230883129681, 0.9398481441591451, 0.964270119789284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 235}], {
             RGBColor[
             0.6426752269533634, 0.7164421222894727, 0.967683202312762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 292}], {
             RGBColor[
             0.8252860920096456, 0.8638987146846454, 0.9830984780135097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 76}], {
             RGBColor[
             0.2672433086560147, 0.39653993712037666`, 0.9385919999213795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 85}], {
             RGBColor[
             0.21985867650040533`, 0.3484157872201088, 0.9358319984237091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 90}], {
             RGBColor[
             0.21162247094140993`, 0.33975901297201105`, 0.9353629587014987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 118}], {
             RGBColor[
             0.19814492935345804`, 0.3255932622375819, 0.9345954326463008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 121}], {
             RGBColor[
             0.21650915427912054`, 0.3448952269935637, 0.9356412480883811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 126}], {
             RGBColor[
             0.21552861209731056`, 0.34386461499051624`, 0.9355854076617092]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 166}], {
             RGBColor[
             0.19683162728000528`, 0.3242128984902222, 0.9345206420360739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 173}], {
             RGBColor[
             0.2044279033465657, 0.3321970662678976, 0.9349532387203812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 195}], {
             RGBColor[
             0.1956464700099377, 0.32296722305607023`, 0.9344531490828267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 213}], {
             RGBColor[
             0.20497196381527677`, 0.33276890831593897`, 0.934984222159209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 234}], {
             RGBColor[
             0.20086201360397116`, 0.32844909005796263`, 0.9347501665748015]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 239}], {
             RGBColor[
             0.22257247692189291`, 0.35126816352797696`, 0.935986545343005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 249}], {
             RGBColor[
             0.20751277813074143`, 0.3354394652584245, 0.9351289177756767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 258}], {
             RGBColor[
             0.273865191252875, 0.4022754790002804, 0.9390139404249507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 263}], {
             RGBColor[
             0.2087290677202517, 0.3367178627342138, 0.9351981836684602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 285}], {
             RGBColor[
             0.2036242652013759, 0.3313523916237017, 0.9349074727168887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 122}], {
             RGBColor[
             0.19740509453050553`, 0.32481564893042175`, 0.9345533001476212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 138}], {
             RGBColor[
             0.22052881830414905`, 0.3491201487452879, 0.9358701620080464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 211}], {
             RGBColor[
             0.24025127894135917`, 0.3698497053512242, 0.9369933269645696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 231}], {
             RGBColor[
             0.2204752799716199, 0.3490638765632734, 0.9358671130792118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 266}], {
             RGBColor[
             0.20395979058864, 0.33170505007925455`, 0.934926580391328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 108}], {
             RGBColor[
             0.23200115605283045`, 0.3611783031073773, 0.936523494671031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 136}], {
             RGBColor[
             0.3079661703282201, 0.43326804169526645`, 0.9411335130505898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 161}], {
             RGBColor[
             0.2124857473818974, 0.34066637124585103`, 0.9354121210176813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 177}], {
             RGBColor[
             0.2576442825267533, 0.3881308548995943, 0.9379838327881149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 208}], {
             RGBColor[
             0.20631669235829492`, 0.33418230327536513`, 0.9350608024603861]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 244}], {
             RGBColor[
             0.20641030875985014`, 0.33428070004902233`, 0.9350661337759618]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 252}], {
             RGBColor[
             0.23062956346731406`, 0.3597366723360068, 0.9364453845023752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 268}], {
             RGBColor[
             0.21418318831071842`, 0.34245048928601285`, 0.9355087877674388]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 279}], {
             RGBColor[
             0.22999178600981598`, 0.35906632779075, 0.9364090640196779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 280}], {
             RGBColor[
             0.2426648792276659, 0.37238655228322937`, 0.9371307779302732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 83}], {
             RGBColor[
             0.8379840210704871, 0.29296740741773747`, 0.18400684751490148`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 87}], {
             RGBColor[
             0.9112817531721615, 0.6074291803827055, 0.3356936471851313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 106}], {
             RGBColor[
             0.845638031582683, 0.5598969667895013, 0.5812439041897035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 109}], {
             RGBColor[
             0.9111133090638942, 0.6092004544506938, 0.4723013817192375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 155}], {
             RGBColor[
             0.8778646469488878, 0.4863358074888676, 0.21768508409656526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 194}], {
             RGBColor[
             0.7577104993954153, 0.4908688373474871, 0.5725699298440808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 210}], {
             RGBColor[
             0.6505472536572664, 0.40453749617198587`, 0.5636765147139389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 218}], {
             RGBColor[
             0.898302513009544, 0.6010781396556649, 0.5581126298969585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 226}], {
             RGBColor[
             0.9078362964581086, 0.6078453255228189, 0.5266099612338768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 227}], {
             RGBColor[
             0.8910599718883171, 0.5386508737923311, 0.22830235227691478`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 241}], {
             RGBColor[
             0.9077698315979006, 0.607817840595054, 0.5277114559730665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 290}], {
             RGBColor[
             0.8879131967834442, 0.526174959102152, 0.22577038316322898`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 291}], {
             RGBColor[
             0.8781451400021425, 0.5858172526612265, 0.5843444612101898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 100}], {
             RGBColor[
             0.1816658245926822, 0.30827267829841776`, 0.9336569720088254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 119}], {
             RGBColor[
             0.18176019735719462`, 0.3083718700574992, 0.9336623463981524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 122}], {
             RGBColor[
             0.18385458485627515`, 0.31057320411086997`, 0.9337816186678564]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 161}], {
             RGBColor[
             0.19216173018569271`, 0.31930454055552265`, 0.9342546983050465]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 244}], {
             RGBColor[
             0.18608629156364545`, 0.31291886935869395`, 0.9339087110633268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 123}], {
             RGBColor[
             0.20225228122772315`, 0.32991034947858455`, 0.9348293402592576]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 189}], {
             RGBColor[
             0.21086862151855923`, 0.33896666943178094`, 0.9353200280920875]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 257}], {
             RGBColor[
             0.19498858899920085`, 0.3222757484017205, 0.9344156837325129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 260}], {
             RGBColor[
             0.23203447362151203`, 0.3612133219845175, 0.9365253920572785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 267}], {
             RGBColor[
             0.2010537316252639, 0.328650597853966, 0.9347610846324927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 287}], {
             RGBColor[
             0.2244511741859948, 0.35324279346883447`, 0.936093534372912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 300}], {
             RGBColor[
             0.2157736566163444, 0.3441221723167407, 0.9355993625845572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 111}], {
             RGBColor[
             0.4735665439631073, 0.5802328466571501, 0.952603227994324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 143}], {
             RGBColor[
             0.31991196504772945`, 0.4513422193006194, 0.941611753099148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.47703987934410275`, 0.583052656791418, 0.9528766616787626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 165}], {
             RGBColor[
             0.27536181000482485`, 0.4045171817075533, 0.9390746876755028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 185}], {
             RGBColor[
             0.43124290556454353`, 0.5458726103470143, 0.9492713561429931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 235}], {
             RGBColor[
             0.3707116092284409, 0.495513496231598, 0.9448423938259995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 262}], {
             RGBColor[
             0.318384602518598, 0.4497368644421247, 0.9415247720626443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 292}], {
             RGBColor[
             0.5533224742847231, 0.6429700886267707, 0.9602576695267473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 85}], {
             RGBColor[
             0.2795331222505161, 0.40945731042738504`, 0.9392918866244364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 87}], {
             RGBColor[
             0.6600329022141906, 0.7226670785503484, 0.7188188011286823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 90}], {
             RGBColor[
             0.2712969166915207, 0.40080053617928724`, 0.938822846902226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 126}], {
             RGBColor[
             0.2752030578474213, 0.40490613819779253`, 0.9390452958624365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 151}], {
             RGBColor[
             0.46237290629163863`, 0.5709821178298984, 0.9517671246297987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 153}], {
             RGBColor[
             0.27399346070364045`, 0.40363477490679034`, 0.9389764110945367]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 192}], {
             RGBColor[
             0.32876752436481727`, 0.45918363809373036`, 0.9421697538281874]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 220}], {
             RGBColor[
             0.3300035970754238, 0.4602542621488369, 0.942248515288291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 239}], {
             RGBColor[
             0.28224692267200363`, 0.41230968673525326`, 0.9394464335437323]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 248}], {
             RGBColor[
             0.2744382407386017, 0.40410226692421763`, 0.9390017406595347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 258}], {
             RGBColor[
             0.3335396370029857, 0.4633170022075566, 0.942473828625678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 82}], {
             RGBColor[
             0.5136111712070213, 0.6149382362843397, 0.9551491039925967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 95}], {
             RGBColor[
             0.3506695406416134, 0.476194939387312, 0.94363706407864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 103}], {
             RGBColor[
             0.41755616548084906`, 0.5360878963815774, 0.9478272875273883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 127}], {
             RGBColor[
             0.3813089695721926, 0.5046923971225378, 0.9455176482562255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 145}], {
             RGBColor[
             0.6393432778876973, 0.7139671917177287, 0.9672816709055783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 154}], {
             RGBColor[
             0.455540153481848, 0.5677935680255081, 0.950577540756124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 159}], {
             RGBColor[
             0.3525117466514917, 0.4781312147063014, 0.9437419749856031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 167}], {
             RGBColor[
             0.6607323580564698, 0.6022582598273698, 0.5960819189651536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 168}], {
             RGBColor[
             0.4070970567080353, 0.527028742052658, 0.9471608423650113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 203}], {
             RGBColor[
             0.6754538924070363, 0.7427240405564789, 0.9694509218275109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 205}], {
             RGBColor[
             0.3930712028278346, 0.5148802523815419, 0.9462671273583405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 212}], {
             RGBColor[
             0.32357566422601636`, 0.4477175574235364, 0.9420941078985701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 225}], {
             RGBColor[
             0.32068966156322254`, 0.4446841856418027, 0.9419297543163823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 255}], {
             RGBColor[
             0.38990028243638014`, 0.512133760513557, 0.9460650791149319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 265}], {
             RGBColor[
             0.31824926646414226`, 0.4421191756626833, 0.9417907774257306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 269}], {
             RGBColor[
             0.6934737954253698, 0.7269802724747518, 0.6489189851142219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 276}], {
             RGBColor[
             0.3275782701356497, 0.45192455001443343`, 0.9423220503837988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 282}], {
             RGBColor[
             0.42720741988360567`, 0.5444473278590943, 0.9484422569236628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 293}], {
             RGBColor[
             0.6567707297143, 0.585264649646495, 0.5928277208084357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 99}], {
             RGBColor[
             0.19490280134245708`, 0.32218558013523124`, 0.9344107982523728]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 131}], {
             RGBColor[
             0.21176961520445978`, 0.33991367092196156`, 0.9353713383495988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 170}], {
             RGBColor[
             0.19585393495458225`, 0.32318528186692885`, 0.9344649639045073]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 178}], {
             RGBColor[
             0.2265713684695162, 0.3554712520888972, 0.9362142763008121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 182}], {
             RGBColor[
             0.22423750678067705`, 0.3530182154785495, 0.9360813663302717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 190}], {
             RGBColor[
             0.19927294772660503`, 0.32677888106825503`, 0.9346596716238978]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.19626308316666907`, 0.323615322579327, 0.9344882642899051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 209}], {
             RGBColor[
             0.18729352981200414`, 0.31418775330104487`, 0.933977461495622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 229}], {
             RGBColor[
             0.20592187570768378`, 0.3337673259427514, 0.9350383182362128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 261}], {
             RGBColor[
             0.21943392399577888`, 0.3479693454068822, 0.9358078093969358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 284}], {
             RGBColor[
             0.2175445595822431, 0.34598350361563335`, 0.935700212888649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 144}], {
             RGBColor[
             0.1903903758627761, 0.31744273485178653`, 0.9341538222968402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 160}], {
             RGBColor[
             0.1894526235362595, 0.316457097699686, 0.9341004186891254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 176}], {
             RGBColor[
             0.18866673983198834`, 0.31563108409859225`, 0.9340556637747779]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 221}], {
             RGBColor[
             0.18466822464384994`, 0.3114283911153532, 0.9338279542500865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 232}], {
             RGBColor[
             0.1855242988552152, 0.31232817938973806`, 0.9338767064099756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 240}], {
             RGBColor[
             0.18183565807480434`, 0.3084511840561929, 0.9336666437743861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 245}], {
             RGBColor[
             0.20419166956427437`, 0.3319487695846225, 0.9349397855559562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 288}], {
             RGBColor[
             0.19600308919068352`, 0.3233420524259961, 0.9344734580175993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 297}], {
             RGBColor[
             0.1875669958551452, 0.3144751834511347, 0.9339930349822221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 92}], {
             RGBColor[
             0.9051815489493698, 0.591863337150663, 0.2750126050569618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 125}], {
             RGBColor[
             0.9070014402205765, 0.6058518189425977, 0.2767553349935425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 128}], {
             RGBColor[
             0.9118743315068152, 0.6433069966832056, 0.2814216211923882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 145}], {
             RGBColor[
             0.9218561356347152, 0.9176464031707863, 0.6795757972164687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 149}], {
             RGBColor[
             0.9371561077922606, 0.7792834728078644, 0.30334662593416606`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 150}], {
             RGBColor[
             0.9431089113179686, 0.8053970694161215, 0.30826637148751795`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 156}], {
             RGBColor[
             0.6866499660786538, 0.7281441949934098, 0.6592663633827371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 167}], {
             RGBColor[
             0.9432452158034876, 0.8059374712804274, 0.30837604527604406`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 179}], {
             RGBColor[
             0.7507825863487789, 0.7818072220217351, 0.663873785850424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 201}], {
             RGBColor[
             0.9120862504146132, 0.6449358982719986, 0.2816245549778238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 205}], {
             RGBColor[
             0.6755840605748524, 0.7185594638345996, 0.6585612536692309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 237}], {
             RGBColor[
             0.9019415360113127, 0.566959177926033, 0.27190996500840703`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 256}], {
             RGBColor[
             0.898368256371338, 0.5394933847920658, 0.2684881883897252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 269}], {
             RGBColor[
             0.9759866531723878, 0.9306594839278095, 0.36121311142511225`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 277}], {
             RGBColor[
             0.9859097978901593, 0.963818944183442, 0.4264320765360633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 281}], {
             RGBColor[
             0.9786349916305042, 0.9618175926615335, 0.6467591064594813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 282}], {
             RGBColor[
             0.7097202776306235, 0.7481265393121519, 0.6607363832345532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 293}], {
             RGBColor[
             0.9392835874613179, 0.7889438610995526, 0.30512184711932616`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 86}], {
             RGBColor[
             0.7418209808035544, 0.6361932312179576, 0.5953370394744854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 94}], {
             RGBColor[
             0.8431768541892217, 0.7161112955984645, 0.6049346124449686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 97}], {
             RGBColor[
             0.6691615275279388, 0.5770839186847934, 0.5896504800872672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.9006340382989853, 0.6395018820094367, 0.23868605563289352`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 140}], {
             RGBColor[
             0.8533919471732848, 0.3625473630025718, 0.19684856859522815`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 162}], {
             RGBColor[
             0.9404065856589258, 0.790829015220349, 0.5112620539625906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 167}], {
             RGBColor[
             0.8985734587541578, 0.6313323707616247, 0.23702806496310708`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 181}], {
             RGBColor[
             0.9378794291938042, 0.7781980948822975, 0.31536710248397326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 201}], {
             RGBColor[
             0.8674144933652834, 0.47033079775319603`, 0.2102765746648868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 202}], {
             RGBColor[
             0.8780178149903479, 0.5389892121818496, 0.21992741358203377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 203}], {
             RGBColor[
             0.9132949931047244, 0.7717981514907339, 0.6103970678254644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 216}], {
             RGBColor[
             0.8779643061000555, 0.5387462408083503, 0.21988276445235083`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 237}], {
             RGBColor[
             0.857269778961983, 0.39235407740723033`, 0.20056198469547004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 269}], {
             RGBColor[
             0.931314896123058, 0.7560543834090069, 0.28986513111217527`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 293}], {
             RGBColor[
             0.8946118304119881, 0.61433876058075, 0.23377386680638917`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 299}], {
             RGBColor[
             0.8540793965653044, 0.3678314002718782, 0.19750687090938907`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 103}], {
             RGBColor[
             0.5173846437366769, 0.6182066285292835, 0.9553895463254356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 140}], {
             RGBColor[
             0.7153793247314246, 0.41559198421602295`, 0.5634646813953219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 145}], {
             RGBColor[
             0.7391717561435251, 0.7960859238654349, 0.9748439297036255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 154}], {
             RGBColor[
             0.5553686317376758, 0.6499123001732142, 0.9581397995541713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 167}], {
             RGBColor[
             0.7605608363122977, 0.684376991975076, 0.6036441777632009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 168}], {
             RGBColor[
             0.5069255349638632, 0.6091474742003642, 0.9547231011630586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 181}], {
             RGBColor[
             0.7998668067519439, 0.8312427160957487, 0.681983215284067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 201}], {
             RGBColor[
             0.7294018709234232, 0.5233754189666472, 0.5768926874649807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 203}], {
             RGBColor[
             0.7752823706628642, 0.824842772704185, 0.9770131806255582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 216}], {
             RGBColor[
             0.7399516836581952, 0.5917908620218015, 0.5864988772524447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 255}], {
             RGBColor[
             0.489728760692208, 0.5942524926612631, 0.9536273379129792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 258}], {
             RGBColor[
             0.47680058453134755`, 0.5830547562597531, 0.9528035659599465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 293}], {
             RGBColor[
             0.7565992079701278, 0.6673833817942012, 0.600389979606483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 101}], {
             RGBColor[
             0.7469403042896439, 0.5416229945947444, 0.5788476902726976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 142}], {
             RGBColor[
             0.8382440889794911, 0.2949664033288275, 0.18425588883826852`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 149}], {
             RGBColor[
             0.8710281964790996, 0.48860908470804376`, 0.21336513442340005`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 194}], {
             RGBColor[
             0.7662790641438353, 0.5567305807728573, 0.5807751971239775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[
             0.9164471489214862, 0.6737245560050689, 0.534114411639826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 198}], {
             RGBColor[
             0.9055718234570376, 0.665970901350738, 0.5685171958085309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 226}], {
             RGBColor[
             0.9164048612065285, 0.6737070689481892, 0.5348152285137735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 241}], {
             RGBColor[
             0.9163383963463205, 0.6736795840204242, 0.5359167232529631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 243}], {
             RGBColor[
             0.9169850470479723, 0.6739469907037223, 0.5252000476482207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 290}], {
             RGBColor[
             0.8964817615318641, 0.5920367025275223, 0.23397565044312565`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 291}], {
             RGBColor[
             0.8867137047505624, 0.6516789960865967, 0.5925497284900865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 191}], {
             RGBColor[
             0.2074223158614455, 0.3353443836777553, 0.9351237660832672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 217}], {
             RGBColor[
             0.19375308221906778`, 0.32097715244014635`, 0.9343453234491528]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 223}], {
             RGBColor[
             0.1844791456857544, 0.31122965714209644`, 0.9338171864831403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 246}], {
             RGBColor[
             0.1859588657451276, 0.3127849367441682, 0.9339014543514719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 247}], {
             RGBColor[
             0.1926121673846783, 0.3197779786110244, 0.9342803500371666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 270}], {
             RGBColor[
             0.20015353292457566`, 0.32770443194364846`, 0.9347098196482133]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 271}], {
             RGBColor[
             0.20505156873545605`, 0.33285257813429087`, 0.9349887555416483]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 278}], {
             RGBColor[
             0.19404895120727791`, 0.32128812950593255`, 0.9343621727503324]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 295}], {
             RGBColor[
             0.19219536521772562`, 0.31933989310677346`, 0.9342566137703623]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[
             0.22879896787362192`, 0.35781260030057205`, 0.936341134791438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 135}], {
             RGBColor[
             0.22261249954375167`, 0.3513102298411313, 0.9359888245721116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 154}], {
             RGBColor[
             0.36472305205370464`, 0.48205039622074985`, 0.9450500607222323]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 173}], {
             RGBColor[
             0.21671771694106706`, 0.34511443957490595`, 0.9356531254234381]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 213}], {
             RGBColor[
             0.21726177740977812`, 0.34568628162294734`, 0.9356841088622658]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 234}], {
             RGBColor[
             0.21315182719847248`, 0.341366463364971, 0.9354500532778585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 239}], {
             RGBColor[
             0.2348622905163943, 0.36418553683498534`, 0.936686432046062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 249}], {
             RGBColor[
             0.21980259172524277`, 0.34835683856543287`, 0.9358288044787336]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 255}], {
             RGBColor[
             0.2990831810082368, 0.42639058870879876`, 0.9405375990810403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 258}], {
             RGBColor[
             0.2861550048473763, 0.41519285230728875`, 0.9397138271280076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 263}], {
             RGBColor[
             0.22101888131475306`, 0.34963523604122215`, 0.9358980703715171]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 286}], {
             RGBColor[
             0.2265196157319883, 0.3554168566804423, 0.9362113290589713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[
             0.6955329406462065, 0.7613368008112785, 0.9707925147289977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 97}], {
             RGBColor[
             0.5215176139849236, 0.6223094238976072, 0.9555083823712963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 120}], {
             RGBColor[
             0.4366336879326583, 0.5460453622474791, 0.9502000470026102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 130}], {
             RGBColor[
             0.75299012475597, 0.6847273872222507, 0.6045439579169226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 140}], {
             RGBColor[
             0.7057480336302696, 0.4077728682153858, 0.5627064708792573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 162}], {
             RGBColor[
             0.7927626721159106, 0.8360545204331631, 0.8771199562466196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 169}], {
             RGBColor[
             0.5994580148931581, 0.6857060476229113, 0.9616106773009028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[
             0.4265942001520806, 0.5354932240498018, 0.9496283130255976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 182}], {
             RGBColor[
             0.4242603384632414, 0.5330401874394541, 0.9494954030550571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 202}], {
             RGBColor[
             0.7303739014473327, 0.5842147173946636, 0.5857853158660629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 261}], {
             RGBColor[
             0.41945675567834323`, 0.5279913173677868, 0.949221846121721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 284}], {
             RGBColor[
             0.41756739126480746`, 0.526005475576538, 0.9491142496134344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 109}], {
             RGBColor[
             0.9929796059139886, 0.9895239708410322, 0.632193448669364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 140}], {
             RGBColor[
             0.9052335250111279, 0.560939848386522, 0.3299018570676289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 151}], {
             RGBColor[
             0.7954880540997038, 0.8360677360525939, 0.7285340376363743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[
             0.7452228320173793, 0.7952601643437132, 0.7245769752264782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 155}], {
             RGBColor[
             0.959730943798982, 0.866659323879206, 0.37757715104669176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 162}], {
             RGBColor[
             0.9922481634967688, 0.9892215006042993, 0.6443153424349913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 181}], {
             RGBColor[
             0.9897210070316473, 0.9765905802662477, 0.448420390956374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 202}], {
             RGBColor[
             0.9298593928281911, 0.7373816975657997, 0.35298070205443455`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 203}], {
             RGBColor[
             0.9651365709425674, 0.970190636874684, 0.7434503562978652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 216}], {
             RGBColor[
             0.9298058839378985, 0.7371387261923006, 0.3529360529247516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 227}], {
             RGBColor[
             0.9729262687384115, 0.9189743901826695, 0.3881944192270413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 258}], {
             RGBColor[
             0.6666547848110509, 0.7284026204302521, 0.7192407416322534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 299}], {
             RGBColor[
             0.9059209744031474, 0.5662238856558284, 0.33056015938178984`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 93}], {
             RGBColor[
             0.23199426054362918`, 0.36117105549000617`, 0.9365231019819831]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 107}], {
             RGBColor[
             0.3156668760979841, 0.43989562490003076`, 0.9416257469918767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 124}], {
             RGBColor[
             0.20439146202389424`, 0.3321587641272566, 0.9349511634409652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 137}], {
             RGBColor[
             0.242196310039882, 0.3718940563578661, 0.9371040936082149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 147}], {
             RGBColor[
             0.21812810554997109`, 0.34659684742666674`, 0.9357334449682322]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 273}], {
             RGBColor[
             0.23089430452924603`, 0.3600149319776501, 0.936460461114203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 274}], {
             RGBColor[
             0.342952508633553, 0.4632649151839602, 0.9434373496862328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 289}], {
             RGBColor[
             0.23315152394890182`, 0.3623874127036856, 0.9365890064208955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 94}], {
             RGBColor[
             0.5888165791799138, 0.6727291061533267, 0.962935879267211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 120}], {
             RGBColor[
             0.3299173264663655, 0.4574376675895273, 0.9423434115408236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 131}], {
             RGBColor[
             0.3050760854207314, 0.4313279482249144, 0.9409287396125976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 141}], {
             RGBColor[
             0.33729605784908523`, 0.4651931821113565, 0.9427636193772146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 188}], {
             RGBColor[
             0.3683043792841372, 0.49342847464473716`, 0.9446890072625783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 236}], {
             RGBColor[
             0.30608763983959875`, 0.4323911560553985, 0.9409863461402914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 260}], {
             RGBColor[
             0.3194559514168667, 0.4464420991230162, 0.9417476517079721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 281}], {
             RGBColor[
             0.6796029595718664, 0.743830302697593, 0.9334123929687868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 294}], {
             RGBColor[
             0.4583968818459615, 0.569215720181254, 0.9510502956112238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 118}], {
             RGBColor[
             0.20219853738896398`, 0.32985386129649247`, 0.9348262796271471]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 126}], {
             RGBColor[
             0.2195822201328165, 0.34812521404942687`, 0.9358162546425555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 153}], {
             RGBColor[
             0.21837262298903565`, 0.3468538507584247, 0.9357473698746558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.20088523531551122`, 0.3284734975491328, 0.9347514890169203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 195}], {
             RGBColor[
             0.19970007804544365`, 0.3272278221149808, 0.934683996063673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 222}], {
             RGBColor[
             0.2185508250169386, 0.3470411523884118, 0.9357575182165185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 234}], {
             RGBColor[
             0.20491562163947707`, 0.33270968911687326`, 0.9349810135556479]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 239}], {
             RGBColor[
             0.2266260849573989, 0.3555287625868876, 0.9362173923238513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 248}], {
             RGBColor[
             0.21881740302399694`, 0.347321342775852, 0.9357726994396538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 285}], {
             RGBColor[
             0.20767787323688183`, 0.3356129906826123, 0.9351383196977351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 93}], {
             RGBColor[
             0.3656444287828603, 0.48387268995411137`, 0.9450248073537576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 105}], {
             RGBColor[
             0.38699951220692347`, 0.5063182366232937, 0.9462409477627431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 107}], {
             RGBColor[
             0.44931704433721525`, 0.562597259364136, 0.9501274523636514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 139}], {
             RGBColor[
             0.4654409733450266, 0.5765629962584664, 0.9511548548621985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 142}], {
             RGBColor[
             0.6600471931315399, 0.4140378360712322, 0.5646529525736886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 143}], {
             RGBColor[
             0.39852667636969663`, 0.5184340170227889, 0.9468974027089019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 150}], {
             RGBColor[
             0.6987841041568563, 0.6337941140587057, 0.5986819437121721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 163}], {
             RGBColor[
             0.5556545906660699, 0.6501444545135875, 0.9581623112885165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 179}], {
             RGBColor[
             0.5064577791876668, 0.6102042666643193, 0.9542893580750782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 235}], {
             RGBColor[
             0.44932632055040805`, 0.5626052939537676, 0.9501280434357534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 273}], {
             RGBColor[
             0.3645444727684772, 0.4827165664417553, 0.9449621664859775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 274}], {
             RGBColor[
             0.4766026768727841, 0.5859665496480654, 0.9519390550580074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 298}], {
             RGBColor[
             0.3751482927558811, 0.4938618535695355, 0.9455660383473143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 125}], {
             RGBColor[
             0.8333745807247173, 0.2575372290505118, 0.17959284223417404`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 128}], {
             RGBColor[
             0.838247472010956, 0.29499240679111977`, 0.18425912843301978`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 142}], {
             RGBColor[
             0.830745140796793, 0.23732620153656223`, 0.1770748875896661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 149}], {
             RGBColor[
             0.8635292482964012, 0.4309688829157785, 0.2061841331747976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 150}], {
             RGBColor[
             0.8694820518221094, 0.4570824795240357, 0.2111038787281495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 179}], {
             RGBColor[
             0.6771557268529196, 0.4334926321296493, 0.5667112930910556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 237}], {
             RGBColor[
             0.8283146765154534, 0.21864458803394712`, 0.17474747224903853`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 243}], {
             RGBColor[
             0.9094860988652742, 0.6163067889114571, 0.5180190463996183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 256}], {
             RGBColor[
             0.8247413968754788, 0.1911787948999799, 0.17132569563035674`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 269}], {
             RGBColor[
             0.9023597936765284, 0.5823448940357236, 0.2640506186657438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 277}], {
             RGBColor[
             0.9122829383943001, 0.6155043542913563, 0.3292695837766948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 281}], {
             RGBColor[
             0.9050081321346448, 0.6135030027694477, 0.5495966137001128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 105}], {
             RGBColor[
             0.26248514686677915`, 0.39321891024948796`, 0.9382595128508624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 107}], {
             RGBColor[
             0.32480267899707094`, 0.44949793299033025`, 0.9421460174517705]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 137}], {
             RGBColor[
             0.25133211293896884`, 0.38149636444816565`, 0.9376243640681086]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 139}], {
             RGBColor[
             0.3409266080048823, 0.4634636698846607, 0.9431734199503177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 147}], {
             RGBColor[
             0.22726390844905786`, 0.3561991555169663, 0.936253715428126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 273}], {
             RGBColor[
             0.24003010742833283`, 0.36961724006794966`, 0.9369807315740968]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 274}], {
             RGBColor[
             0.3520883115326398, 0.4728672232742597, 0.9439576201461266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 289}], {
             RGBColor[
             0.24228732684798865`, 0.37198972079398507`, 0.9371092768807893]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 97}], {
             RGBColor[
             0.622873487370591, 0.7022274882781143, 0.9651059553417796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 120}], {
             RGBColor[
             0.5379895613183256, 0.6259634266279861, 0.9597976199730934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 130}], {
             RGBColor[
             0.8543459981416374, 0.7646454516027577, 0.6141415308874059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 141}], {
             RGBColor[
             0.5453682927010454, 0.6337189411498153, 0.9602178278094844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 188}], {
             RGBColor[
             0.5763766141360973, 0.661954233683196, 0.9621432156948482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 201}], {
             RGBColor[
             0.8211264532079356, 0.595474367346517, 0.5857320499193991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 202}], {
             RGBColor[
             0.8317297748330001, 0.6641327817751705, 0.595382888836546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.8109817388046351, 0.5174976470005512, 0.5760174599499823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 281}], {
             RGBColor[
             0.8876751944238266, 0.9123560617360518, 0.9508666014010566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 293}], {
             RGBColor[
             0.8483237902546403, 0.739482330174071, 0.6092293420609014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 294}], {
             RGBColor[
             0.6664691166979216, 0.7377414792197128, 0.9685045040434936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 103}], {
             RGBColor[
             0.35444301317126903`, 0.47946333163225574`, 0.9438775064114789]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 127}], {
             RGBColor[
             0.3181958172626126, 0.4480678323732162, 0.9415678671403162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 145}], {
             RGBColor[
             0.5762301255781173, 0.6573426269684071, 0.963331889789669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 148}], {
             RGBColor[
             0.2669268205335093, 0.3978873908915973, 0.9385124595953154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 156}], {
             RGBColor[
             0.3410239560220559, 0.4678404187910305, 0.9430224559559374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 159}], {
             RGBColor[
             0.2893985943419117, 0.4215066499569798, 0.9397921938696936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 168}], {
             RGBColor[
             0.3439839043984553, 0.4704041773033365, 0.943211061249102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 191}], {
             RGBColor[
             0.2574665501142888, 0.38794404686520834`, 0.9379737111901566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 205}], {
             RGBColor[
             0.32995805051825455`, 0.4582556876322203, 0.9423173462424312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 212}], {
             RGBColor[
             0.2604625119164363, 0.3910929926742148, 0.9381443267826606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 225}], {
             RGBColor[
             0.2575765092536425, 0.3880596208924811, 0.9379799732004728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 251}], {
             RGBColor[
             0.2865818395337517, 0.41854606206103384`, 0.9396317838503843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 271}], {
             RGBColor[
             0.25509580298829937`, 0.3854522413217438, 0.9378387006485376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 276}], {
             RGBColor[
             0.2644651178260697, 0.3952999852651118, 0.9383722692678894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 282}], {
             RGBColor[
             0.36409426757402563`, 0.48782276310977274`, 0.9444924758077534]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 112}], {
             RGBColor[
             0.1950909003644823, 0.32238328413354655`, 0.9344215102134096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 132}], {
             RGBColor[
             0.1989233882773373, 0.32641147192372544`, 0.9346397647303889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 133}], {
             RGBColor[
             0.19311989172231955`, 0.3203116290814677, 0.9343092641870845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 146}], {
             RGBColor[
             0.20048974504421074`, 0.3280578121984645, 0.9347289664310452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 236}], {
             RGBColor[
             0.2161907003932258, 0.34456051176834573`, 0.9356231126106896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 260}], {
             RGBColor[
             0.22955901197049378`, 0.3586114548359634, 0.9363844181783704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 267}], {
             RGBColor[
             0.19857826997424566`, 0.3260487307054119, 0.9346201107535846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 120}], {
             RGBColor[
             0.3639742346570427, 0.4869360497143149, 0.944513487615392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 130}], {
             RGBColor[
             0.6803306714803544, 0.6256180746890865, 0.5988573985297044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 178}], {
             RGBColor[
             0.353934746876465, 0.4763839115166376, 0.9439417536383794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 182}], {
             RGBColor[
             0.35160088518762583`, 0.47393087490628993`, 0.9438088436678389]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 202}], {
             RGBColor[
             0.6577144481717172, 0.5251054048614994, 0.5800987564788447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 261}], {
             RGBColor[
             0.34679730240272766`, 0.46888200483462256`, 0.9435352867345028]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 284}], {
             RGBColor[
             0.3449079379891919, 0.4668961630433738, 0.9434276902262162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 157}], {
             RGBColor[
             0.18079506708635712`, 0.3073574569500555, 0.9336073836570105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.17910006852395627`, 0.30557590599185624`, 0.9335108559964074]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 275}], {
             RGBColor[
             0.17961340510331275`, 0.30611545528417883`, 0.9335400897551883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 285}], {
             RGBColor[
             0.18936585526810354`, 0.31636589874842813`, 0.9340954773646161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 182}], {
             RGBColor[
             0.22500890422772363`, 0.3538290031048185, 0.9361252962737008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 199}], {
             RGBColor[
             0.19703448061371565`, 0.32442611020559603`, 0.9345321942333341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 209}], {
             RGBColor[
             0.18806492725905072`, 0.31499854092731383`, 0.934021391439051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 215}], {
             RGBColor[
             0.21020795705683448`, 0.338272269193962, 0.9352824042283578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 229}], {
             RGBColor[
             0.20669327315473038`, 0.33457811356902034`, 0.9350822481796419]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 233}], {
             RGBColor[
             0.20053490529032286`, 0.32810527848045334`, 0.9347315382402527]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 259}], {
             RGBColor[
             0.19041774683741108`, 0.3174715034815479, 0.934155381033354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 284}], {
             RGBColor[
             0.2183159570292897, 0.34679429124190236`, 0.9357441428320781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 119}], {
             RGBColor[
             0.1807572108955105, 0.3073176676932546, 0.933605227802945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 122}], {
             RGBColor[
             0.18285159839459103`, 0.3095190017466254, 0.933724500072649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 161}], {
             RGBColor[
             0.1911587437240086, 0.318250338191278, 0.9341975797098391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 244}], {
             RGBColor[
             0.18508330510196136`, 0.31186466699444937`, 0.9338515924681194]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 266}], {
             RGBColor[
             0.1894062944527255, 0.3164084028954582, 0.9340977803163559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 104}], {
             RGBColor[
             0.49120791951509923`, 0.5945373978105576, 0.9540278714950781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 116}], {
             RGBColor[
             0.46733992011891123`, 0.5718860980228273, 0.952579449352897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 136}], {
             RGBColor[
             0.5199717589850226, 0.6194511898467974, 0.9558606779112371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 149}], {
             RGBColor[
             0.7714159149498363, 0.6714029284596804, 0.6000007099012994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 197}], {
             RGBColor[
             0.816834867392223, 0.8565183997567056, 0.9207499871177253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 198}], {
             RGBColor[
             0.8059595419277743, 0.8487647451023745, 0.9551527712864303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[
             0.5654681824695174, 0.6580354513456885, 0.9589869162220399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 226}], {
             RGBColor[
             0.8167925796772653, 0.8565009126998259, 0.9214508039916728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 243}], {
             RGBColor[
             0.8173727655187092, 0.8567408344553589, 0.91183562312612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 254}], {
             RGBColor[
             0.4830549298600605, 0.587475687952538, 0.9535083702036646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 283}], {
             RGBColor[
             0.4765743997943146, 0.5815921216615045, 0.9531053393092228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 165}], {
             RGBColor[
             0.20499479718794766`, 0.3327929076383356, 0.9349855224860035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 172}], {
             RGBColor[
             0.19138970866876043`, 0.3184930969922355, 0.9342107328217606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 175}], {
             RGBColor[
             0.18740197098760464`, 0.3143017318521686, 0.9339836370601481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 183}], {
             RGBColor[
             0.19246783079694663`, 0.31962627170585023`, 0.934272130282022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 238}], {
             RGBColor[
             0.18981943468321613`, 0.3168426394723074, 0.9341213080412961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 253}], {
             RGBColor[
             0.1920226425007294, 0.3191583505799577, 0.9342467774671497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 127}], {
             RGBColor[
             0.3850824421018483, 0.5079607893674816, 0.9457580905890645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 145}], {
             RGBColor[
             0.643116750417353, 0.7172355839626725, 0.9675221132384173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 154}], {
             RGBColor[
             0.45931362601150366`, 0.5710619602704519, 0.9508179830889629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 159}], {
             RGBColor[
             0.35628521918114736`, 0.4813996069512451, 0.9439824173184419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 167}], {
             RGBColor[
             0.6645058305861254, 0.6055266520723135, 0.5963223612979925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 168}], {
             RGBColor[
             0.41087052923769096`, 0.5302971342976018, 0.9474012846978503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 203}], {
             RGBColor[
             0.679227364936692, 0.7459924328014227, 0.96969136416035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 205}], {
             RGBColor[
             0.39684467535749024`, 0.5181486446264856, 0.9465075696911796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 212}], {
             RGBColor[
             0.327349136755672, 0.45098594966848016`, 0.9423345502314089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 225}], {
             RGBColor[
             0.3244631340928782, 0.4479525778867464, 0.9421701966492211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 255}], {
             RGBColor[
             0.3936737549660358, 0.5154021527585007, 0.9463055214477708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 265}], {
             RGBColor[
             0.3220227389937979, 0.445387567907627, 0.9420312197585695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 269}], {
             RGBColor[
             0.6972472679550255, 0.7302486647196956, 0.6491594274470608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 276}], {
             RGBColor[
             0.33135174266530537`, 0.4551929422593771, 0.9425624927166377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 282}], {
             RGBColor[
             0.4309808924132613, 0.5477157201040381, 0.9486826992565017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 293}], {
             RGBColor[
             0.6605442022439556, 0.5885330418914387, 0.5930681631412746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 114}], {
             RGBColor[
             0.28710993911342014`, 0.4166656473064825, 0.939751033226302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 116}], {
             RGBColor[
             0.3112198168736299, 0.4420066574870038, 0.9411240550973782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 204}], {
             RGBColor[
             0.40934807922423605`, 0.5281560108098651, 0.9475315219665212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 206}], {
             RGBColor[
             0.2787552105581772, 0.4078842978745366, 0.9392752437947942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 243}], {
             RGBColor[
             0.6612526622734278, 0.7268613939195354, 0.9003802288706013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 254}], {
             RGBColor[
             0.32693482661477913`, 0.45759624741671456`, 0.942052975948146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 283}], {
             RGBColor[
             0.32045429654903324`, 0.4517126811256811, 0.9416499450537039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 287}], {
             RGBColor[
             0.2890443879522816, 0.41869887568726627`, 0.9398611972259145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 300}], {
             RGBColor[
             0.2803668703826312, 0.4095782545351725, 0.9393670254375599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 139}], {
             RGBColor[
             0.3622816914289454, 0.48590921655384295`, 0.9443895603593033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 143}], {
             RGBColor[
             0.29536739445361543`, 0.4277802373181654, 0.9401321082060067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 163}], {
             RGBColor[
             0.4524953087499887, 0.5594906748089641, 0.9513970167856213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 174}], {
             RGBColor[
             0.25852249961576723`, 0.3890539167423275, 0.9380338459521285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 235}], {
             RGBColor[
             0.34616703863432685`, 0.47195151424914406`, 0.9433627489328582]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 274}], {
             RGBColor[
             0.373443394956703, 0.4953127699434419, 0.9451737605551122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 298}], {
             RGBColor[
             0.27198901083979987`, 0.403208073864912, 0.938800743844419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 115}], {
             RGBColor[
             0.6067946716231568, 0.6858798777418896, 0.9651595250499304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 155}], {
             RGBColor[
             0.8940872222095038, 0.8191271102860018, 0.6231274080512639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 162}], {
             RGBColor[
             0.9266044419072905, 0.9416892870110949, 0.8898655994395634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 194}], {
             RGBColor[
             0.7739330746560312, 0.8236601401446212, 0.9780122537987794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 200}], {
             RGBColor[
             0.6137154608562325, 0.6918743175265988, 0.9656005116200483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 210}], {
             RGBColor[
             0.6667698289178824, 0.73732879896912, 0.9691188386686375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 211}], {
             RGBColor[
             0.5662966671615951, 0.6472879549936589, 0.9627077142549896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 227}], {
             RGBColor[
             0.907282547148933, 0.8714421765894653, 0.6337446762316135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 241}], {
             RGBColor[
             0.9239924068585166, 0.940609143392188, 0.9331537799277652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 264}], {
             RGBColor[
             0.579035279379287, 0.6606770441091168, 0.9634331593756991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 290}], {
             RGBColor[
             0.9041357720440601, 0.8589662618992862, 0.6312127071179277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 291}], {
             RGBColor[
             0.8943677152627585, 0.9186085554583606, 0.9897867851648885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 137}], {
             RGBColor[
             0.33500472849332374`, 0.4602209338581902, 0.9427270090780024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 139}], {
             RGBColor[
             0.4245992235592372, 0.5421882392946853, 0.9482760649602114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[
             0.3109365240034128, 0.43492372492699083`, 0.9413563604380197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 150}], {
             RGBColor[
             0.657942354371067, 0.5994193570949246, 0.595803153810185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.4014834091317521, 0.5221664826722128, 0.9468031457054042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.4656160294018773, 0.5758295097005381, 0.9514105681730911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 251}], {
             RGBColor[
             0.34704129264344796`, 0.47287212594221606`, 0.943412473599851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 273}], {
             RGBColor[
             0.32370272298268776`, 0.4483418094779742, 0.9420833765839904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 274}], {
             RGBColor[
             0.43576092708699476`, 0.5515917926842843, 0.9490602651560203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 277}], {
             RGBColor[
             0.7007432409432577, 0.7578412318622451, 0.7139688588587303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 289}], {
             RGBColor[
             0.32595994240234355`, 0.45071429020400966`, 0.942211921890683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 136}], {
             RGBColor[
             0.3166504809342749, 0.4423958027593246, 0.9416280716923184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 177}], {
             RGBColor[
             0.2663285931328081, 0.3972586159636525, 0.9384783914298436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 204}], {
             RGBColor[
             0.36214690441876973`, 0.48098006425821577`, 0.9447543100031214]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 208}], {
             RGBColor[
             0.2150010029643497, 0.34331006433942324`, 0.9355553611021148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 252}], {
             RGBColor[
             0.23931387407336885`, 0.3688644334000649, 0.9369399431441039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 254}], {
             RGBColor[
             0.27973365180931276`, 0.4104203008650652, 0.9392757639847461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 268}], {
             RGBColor[
             0.2228674989167732, 0.351578250350071, 0.9360033464091675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 279}], {
             RGBColor[
             0.23867609661587075`, 0.3681940888548081, 0.9369036226614065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 280}], {
             RGBColor[
             0.2513491898337207, 0.3815143133472875, 0.9376253365720018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 283}], {
             RGBColor[
             0.2732531217435669, 0.4045367345740317, 0.9388727330903042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 111}], {
             RGBColor[
             0.8035074391264327, 0.8444862586698714, 0.8657863480729937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 151}], {
             RGBColor[
             0.7953196099914366, 0.8378390101205823, 0.8651417721704804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 155}], {
             RGBColor[
             0.9595624996907148, 0.8684305979471943, 0.514184885580798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 192}], {
             RGBColor[
             0.6617142280646152, 0.7260405303844142, 0.8555444013688691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 218}], {
             RGBColor[
             0.9800003657513711, 0.9831729301139916, 0.8546124313811914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 220}], {
             RGBColor[
             0.6629503007752218, 0.7271111544395208, 0.8556231628289728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 227}], {
             RGBColor[
             0.9727578246301442, 0.9207456642506578, 0.5248021537611475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 290}], {
             RGBColor[
             0.9696110495252712, 0.9082697495604787, 0.5222701846474617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 292}], {
             RGBColor[
             0.8832633694480486, 0.907223500639492, 0.873440789605417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 148}], {
             RGBColor[
             0.2161072361235734, 0.34447278552900074`, 0.9356183594440073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 191}], {
             RGBColor[
             0.20664696570435293`, 0.3345294415026117, 0.9350796110388486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 223}], {
             RGBColor[
             0.18370379552866184`, 0.31041471496695283`, 0.9337730314387216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 246}], {
             RGBColor[
             0.18518351558803503`, 0.3119699945690246, 0.9338572993070533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 278}], {
             RGBColor[
             0.19327360105018532`, 0.32047318733078894`, 0.9343180177059138]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 295}], {
             RGBColor[
             0.19142001506063305`, 0.31852495093162986`, 0.9342124587259435]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 143}], {
             RGBColor[
             0.46054913753176646`, 0.5687866450741914, 0.9517800380473413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 163}], {
             RGBColor[
             0.6176770518281398, 0.70049708256499, 0.9630449466269559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.5718800780485805, 0.6633170361205862, 0.9594396410911864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 218}], {
             RGBColor[
             0.7906966430720825, 0.8363639438748425, 0.9515975962507148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 235}], {
             RGBColor[
             0.5113487817124779, 0.61295792200517, 0.9550106787741928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 262}], {
             RGBColor[
             0.459021775002635, 0.5671812902156966, 0.9516930570108376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 292}], {
             RGBColor[
             0.6939596467687601, 0.7604145144003427, 0.9704259544749405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 131}], {
             RGBColor[
             0.20931958090363292`, 0.3373385295306458, 0.9352318125206677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 132}], {
             RGBColor[
             0.1930638232066118, 0.32025269751650964`, 0.9343060711680607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 133}], {
             RGBColor[
             0.18726032665159403`, 0.3141528546742519, 0.9339755706247563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 146}], {
             RGBColor[
             0.19463017997348525`, 0.32189903779124873`, 0.934395272868717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 170}], {
             RGBColor[
             0.1934039006537554, 0.3206101404756131, 0.9343254380755761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 190}], {
             RGBColor[
             0.19682291342577818`, 0.3242037396769393, 0.9345201457949667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 115}], {
             RGBColor[
             0.3096806718260522, 0.43885035168813935`, 0.9410927375300542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 134}], {
             RGBColor[
             0.25621583264175446`, 0.38662946350150684`, 0.9379024846803665]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 144}], {
             RGBColor[
             0.23263625868922916`, 0.36184583624606526`, 0.9365596628266237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 160}], {
             RGBColor[
             0.23169850636271255`, 0.3608601990939647, 0.936506259218909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 169}], {
             RGBColor[
             0.4361857848874334, 0.5443112881470928, 0.9502895329739705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 176}], {
             RGBColor[
             0.23091262265844142`, 0.3600341854928709, 0.9364615043045614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 187}], {
             RGBColor[
             0.24618639037776724`, 0.3760878837786886, 0.9373313227806626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 193}], {
             RGBColor[
             0.2735981771019762, 0.40489940963349313`, 0.9388923834825018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 200}], {
             RGBColor[
             0.3166014610591278, 0.4448447914728484, 0.9415337241001722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 228}], {
             RGBColor[
             0.34694483487630184`, 0.4711266967709722, 0.9434671770482106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 231}], {
             RGBColor[
             0.24940666839475117`, 0.3794726001519578, 0.9375147128497554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 245}], {
             RGBColor[
             0.24643755239072743`, 0.3763518709789012, 0.9373456260857398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 264}], {
             RGBColor[
             0.28192127958218227`, 0.41364751805536637`, 0.939366371855823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 288}], {
             RGBColor[
             0.23824897201713657`, 0.3677451538202748, 0.9368792985473828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 297}], {
             RGBColor[
             0.22981287868159825`, 0.35887828484541334`, 0.9363988755120056]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 116}], {
             RGBColor[
             0.26324193971723214`, 0.3940143475187522, 0.9383026110841209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 204}], {
             RGBColor[
             0.3613702020678383, 0.4801637008416135, 0.944710077953264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 206}], {
             RGBColor[
             0.2307773334017795, 0.35989198790628496`, 0.936453799781537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 254}], {
             RGBColor[
             0.2789569494583814, 0.4096039374484629, 0.9392315319348887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 283}], {
             RGBColor[
             0.2724764193926355, 0.4037203711574294, 0.9388285010404467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 134}], {
             RGBColor[
             0.29826389721871693`, 0.4268505977105114, 0.940442569105771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 169}], {
             RGBColor[
             0.47823384946439584`, 0.5845324223560975, 0.9528296173993749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 193}], {
             RGBColor[
             0.3156462416789386, 0.4451205438424978, 0.9414324679079064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 200}], {
             RGBColor[
             0.35864952563609026`, 0.485065925681853, 0.9440738085255767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 210}], {
             RGBColor[
             0.4117038936977402, 0.5305204071243743, 0.9475921355741658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 211}], {
             RGBColor[
             0.3112307319414529, 0.4404795631489132, 0.9411810111605179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 227}], {
             RGBColor[
             0.6522166119287909, 0.6646337847447196, 0.6122179731371418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 228}], {
             RGBColor[
             0.3889928994532643, 0.5113478309799768, 0.946007261473615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 231}], {
             RGBColor[
             0.29145473297171365`, 0.41969373436096236`, 0.9400547972751598]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 245}], {
             RGBColor[
             0.2884856169676899, 0.4165730051879058, 0.9398857105111442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 264}], {
             RGBColor[
             0.32396934415914475`, 0.453868652264371, 0.9419064562812274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 204}], {
             RGBColor[
             0.38548007982804805`, 0.5055047110221348, 0.9460830998243401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 206}], {
             RGBColor[
             0.2548872111619892, 0.3852329980868062, 0.9378268216526131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 254}], {
             RGBColor[
             0.30306682721859113`, 0.43494494762898417`, 0.9406045538059649]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 283}], {
             RGBColor[
             0.29658629715284524`, 0.4290613813379507, 0.9402015229115228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 287}], {
             RGBColor[
             0.2651763885560936, 0.39604757589953593`, 0.9384127750837334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 158}], {
             RGBColor[
             0.189227738636957, 0.3162207294119929, 0.9340876118267976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 196}], {
             RGBColor[
             0.1942847722586868, 0.32153599238288155`, 0.9343756024103442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 207}], {
             RGBColor[
             0.18539878883552113`, 0.3121962604012447, 0.9338695588000294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 212}], {
             RGBColor[
             0.20943922968905518`, 0.3374642879902957, 0.935238626341993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 214}], {
             RGBColor[
             0.19317010459047246`, 0.32036440598957616`, 0.9343121237356424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 225}], {
             RGBColor[
             0.20655322702626136`, 0.33443091620856197`, 0.9350742727598051]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 265}], {
             RGBColor[
             0.2041128319271811, 0.33186590622944256`, 0.9349352958691536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 276}], {
             RGBColor[
             0.21344183559868857`, 0.34167128058119267`, 0.9354665688272218]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 166}], {
             RGBColor[
             0.18740769372755933`, 0.31430774681470364`, 0.9339839629617225]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.18622253645749176`, 0.31306207138055164`, 0.9339164700084752]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 234}], {
             RGBColor[
             0.19143808005152518`, 0.3185439383824441, 0.9342134875004501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 239}], {
             RGBColor[
             0.213148543369447, 0.34136301185245843`, 0.9354498662686535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 263}], {
             RGBColor[
             0.19930513416780576`, 0.32681271105869525`, 0.9346615045941087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 285}], {
             RGBColor[
             0.19420033164892994`, 0.32144723994818314`, 0.9343707936425373]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 122}], {
             RGBColor[
             0.18294597115910344`, 0.30961819350570674`, 0.933729874461976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 161}], {
             RGBColor[
             0.191253116488521, 0.3183495299503595, 0.9342029540991661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 244}], {
             RGBColor[
             0.18517767786647377`, 0.3119638587535308, 0.9338569668574466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 266}], {
             RGBColor[
             0.1895006672172379, 0.3165075946545396, 0.9341031547056828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 131}], {
             RGBColor[
             0.2542490675591432, 0.38456226869957383`, 0.93779048031848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 141}], {
             RGBColor[
             0.28646903998749706`, 0.4184275025860159, 0.939625360083097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 170}], {
             RGBColor[
             0.23833338730926568`, 0.3678338796445412, 0.9368841058733883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 178}], {
             RGBColor[
             0.2690508208241996, 0.4001198498665095, 0.9386334182696933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 182}], {
             RGBColor[
             0.2667169591353605, 0.3976668132561618, 0.9385005082991529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 188}], {
             RGBColor[
             0.317477361422549, 0.44666279511939655`, 0.9415507479684607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 190}], {
             RGBColor[
             0.24175240008128845`, 0.37142747884586735`, 0.937078813592779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 261}], {
             RGBColor[
             0.2619133763504623, 0.3926179431844944, 0.9382269513658168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 284}], {
             RGBColor[
             0.26002401193692654`, 0.39063210139324567`, 0.9381193548575302]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 294}], {
             RGBColor[
             0.40756986398437334`, 0.5224500406559134, 0.9479120363171062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 135}], {
             RGBColor[
             0.21926297732246688`, 0.3477896696145861, 0.9357980742367835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 154}], {
             RGBColor[
             0.3613735298324199, 0.47852983599420473`, 0.9448593103869043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 173}], {
             RGBColor[
             0.21336819471978227`, 0.34159387934836083`, 0.9354623750881099]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.21391225518849333`, 0.3421657213964022, 0.9354933585269378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 234}], {
             RGBColor[
             0.20980230497718771`, 0.3378459031384259, 0.9352593029425303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 239}], {
             RGBColor[
             0.2315127682951095, 0.3606649766084402, 0.9364956817107337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 249}], {
             RGBColor[
             0.21645306950395798`, 0.3448362783388877, 0.9356380541434055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 255}], {
             RGBColor[
             0.295733658786952, 0.42287002848225363`, 0.9403468487457121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 258}], {
             RGBColor[
             0.28280548262609156`, 0.41167229208074363`, 0.9395230767926794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 263}], {
             RGBColor[
             0.2176693590934683, 0.34611467581467703`, 0.935707320036189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 286}], {
             RGBColor[
             0.22317009351070355`, 0.3518962964538972, 0.9360205787236432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 138}], {
             RGBColor[
             0.2081640824318275, 0.3361240273739437, 0.9351660085921052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 161}], {
             RGBColor[
             0.19334750398760153`, 0.32055086400373023`, 0.9343222263688701]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 266}], {
             RGBColor[
             0.19159505471631844`, 0.31870892870791034`, 0.9342224269753869]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 189}], {
             RGBColor[
             0.2072195140090381, 0.335131226072495, 0.935112216817791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 257}], {
             RGBColor[
             0.19133948148967972`, 0.3184403050424346, 0.9342078724582165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 267}], {
             RGBColor[
             0.19740462411574278`, 0.32481515449468, 0.9345532733581963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 287}], {
             RGBColor[
             0.22080206667647367`, 0.3494073501095485, 0.9358857230986155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 300}], {
             RGBColor[
             0.21212454910682327`, 0.34028672895745476`, 0.9353915513102607]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 147}], {
             RGBColor[
             0.19966110992932296`, 0.3271868641542167, 0.9346817768871081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 247}], {
             RGBColor[
             0.191840440673128, 0.3189668449068855, 0.9342364013426112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 273}], {
             RGBColor[
             0.2124273089085979, 0.3406049487052001, 0.9354087930330789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 289}], {
             RGBColor[
             0.2146845283282537, 0.3429774294312355, 0.9355373383397714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 128}], {
             RGBColor[
             0.8400673632821627, 0.3089808885830544, 0.18600185836960054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 130}], {
             RGBColor[
             0.8734988271236623, 0.4797808744280881, 0.21461427312304276`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 142}], {
             RGBColor[
             0.8325650320679996, 0.2513146833284968, 0.1788176175262468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.865349139567608, 0.4449573647077131, 0.20792686311137834`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 150}], {
             RGBColor[
             0.871301943093316, 0.4710709613159703, 0.2128466086647302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 167}], {
             RGBColor[
             0.871438247578835, 0.47161136318027613`, 0.21295628245325632`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 237}], {
             RGBColor[
             0.8301345677866601, 0.23263306982588172`, 0.17649020218561928`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 243}], {
             RGBColor[
             0.9113059901364808, 0.6302952707033915, 0.519761776336199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 256}], {
             RGBColor[
             0.8265612881466855, 0.2051672766919145, 0.17306842556693747`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 269}], {
             RGBColor[
             0.904179684947735, 0.5963333758276583, 0.2657933486023245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 277}], {
             RGBColor[
             0.9141028296655067, 0.6294928360832908, 0.33101231371327555`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 281}], {
             RGBColor[
             0.9068280234058514, 0.6274914845613823, 0.5513393436366936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 293}], {
             RGBColor[
             0.8674766192366652, 0.4546177529994014, 0.20970208429653842`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 153}], {
             RGBColor[
             0.2222787641449363, 0.35095945277692997`, 0.9359698188348664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 157}], {
             RGBColor[
             0.20301322621103607`, 0.33071015090274497`, 0.93487267495034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 192}], {
             RGBColor[
             0.2770528278061131, 0.40650831596386994`, 0.939163161568517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 220}], {
             RGBColor[
             0.27828890051671973`, 0.40757894001897654`, 0.9392419230286206]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 222}], {
             RGBColor[
             0.22245696617283922`, 0.3511467544069171, 0.9359799671767292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 239}], {
             RGBColor[
             0.2305322261132995, 0.35963436460539283`, 0.9364398412840619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 248}], {
             RGBColor[
             0.22272354417989754`, 0.3514269447943572, 0.9359951483998643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 285}], {
             RGBColor[
             0.21158401439278246`, 0.3397185927011176, 0.9353607686579457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 145}], {
             RGBColor[
             0.6068695545086966, 0.6858400847036329, 0.9652124739672545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 148}], {
             RGBColor[
             0.29756624946408855`, 0.42638484862682313`, 0.9403930437729009]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 156}], {
             RGBColor[
             0.3716633849526351, 0.49633787652625627`, 0.9449030401335229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 159}], {
             RGBColor[
             0.3200380232724909, 0.45000410769220556`, 0.9416727780472791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 168}], {
             RGBColor[
             0.3746233333290345, 0.4989016350385623, 0.9450916454266876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 191}], {
             RGBColor[
             0.28810597904486807`, 0.41644150460043405`, 0.9398542953677421]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 205}], {
             RGBColor[
             0.3605974794488338, 0.48675314536744607`, 0.9441979304200168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 212}], {
             RGBColor[
             0.2911019408470156, 0.4195904504094406, 0.9400249109602461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 225}], {
             RGBColor[
             0.28821593818422175`, 0.41655707862770686`, 0.9398605573780583]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 251}], {
             RGBColor[
             0.31722126846433096`, 0.4470435197962596, 0.9415123680279698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 269}], {
             RGBColor[
             0.6610000720463691, 0.698853165460656, 0.646849788175898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 276}], {
             RGBColor[
             0.29510454675664893`, 0.4237974430003376, 0.9402528534454749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 282}], {
             RGBColor[
             0.3947336965046049, 0.5163202208449985, 0.9463730599853389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 142}], {
             RGBColor[
             0.8374379233542384, 0.28876986106910485`, 0.18348390372509257`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 149}], {
             RGBColor[
             0.8702220308538466, 0.4824125424483211, 0.2125931493102241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 150}], {
             RGBColor[
             0.8761748343795548, 0.5085261390565783, 0.21751289486357597`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 197}], {
             RGBColor[
             0.9156409832962333, 0.6675280137453463, 0.53334242652665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 198}], {
             RGBColor[
             0.9047656578317846, 0.6597743590910152, 0.567745210695355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 237}], {
             RGBColor[
             0.8350074590728989, 0.27008824756648975`, 0.18115648838446502`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 243}], {
             RGBColor[
             0.9161788814227196, 0.6677504484439996, 0.5244280625350448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 256}], {
             RGBColor[
             0.8314341794329242, 0.2426224544325225, 0.1777347117657832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 269}], {
             RGBColor[
             0.9090525762339738, 0.6337885535682664, 0.2704596348011703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 277}], {
             RGBColor[
             0.9189757209517455, 0.6669480138238988, 0.3356785999121213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 281}], {
             RGBColor[
             0.9117009146920902, 0.6649466623019902, 0.5560056298355394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 165}], {
             RGBColor[
             0.20344097121398075`, 0.33115973802143944`, 0.9348970343954657]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 175}], {
             RGBColor[
             0.18584814501363772`, 0.3126685622352725, 0.9338951489696101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 183}], {
             RGBColor[
             0.1909140048229797, 0.31799310208895415`, 0.9341836421914842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 184}], {
             RGBColor[
             0.19028873719925032`, 0.31733590617215746`, 0.9341480341253134]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 224}], {
             RGBColor[
             0.19887770973958555`, 0.32636346088436186`, 0.9346371634052393]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 253}], {
             RGBColor[
             0.19046881652676248`, 0.3175251809630616, 0.9341582893766117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 140}], {
             RGBColor[
             0.8645610911257005, 0.4110815190068649, 0.2060554870376654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 162}], {
             RGBColor[
             0.9515757296113414, 0.8393631712246421, 0.5204689724050278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 167}], {
             RGBColor[
             0.9097426027065735, 0.6798665267659179, 0.24623498340554434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 201}], {
             RGBColor[
             0.8785836373176991, 0.5188649537574892, 0.21948349310732407`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 202}], {
             RGBColor[
             0.8891869589427635, 0.5875233681861427, 0.22913433202447103`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 203}], {
             RGBColor[
             0.92446413705714, 0.8203323074950271, 0.6196039862679017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 216}], {
             RGBColor[
             0.889133450052471, 0.5872803968126434, 0.22908968289478807`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 237}], {
             RGBColor[
             0.8684389229143985, 0.44088823341152344`, 0.20976890313790728`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 269}], {
             RGBColor[
             0.9424840400754735, 0.8045885394133, 0.29907204955461253`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 281}], {
             RGBColor[
             0.9451323785335899, 0.8357466481470239, 0.5846180445889815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 293}], {
             RGBColor[
             0.9057809743644036, 0.6628729165850431, 0.24298078524882644`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 294}], {
             RGBColor[
             0.723926300807685, 0.6611320656306849, 0.6022559472314186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 299}], {
             RGBColor[
             0.8652485405177199, 0.41636555627617133`, 0.20671378935182633`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 141}], {
             RGBColor[
             0.26162779894186294`, 0.392317783221403, 0.938210688154871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 146}], {
             RGBColor[
             0.2147184255833614, 0.3430130575955638, 0.9355392687383033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 170}], {
             RGBColor[
             0.21349214626363155`, 0.34172416027992825`, 0.9354694339451624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 178}], {
             RGBColor[
             0.2442095797785655, 0.3740101305018966, 0.9372187463414672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 182}], {
             RGBColor[
             0.24187571808972635`, 0.3715570938915489, 0.9370858363709268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 188}], {
             RGBColor[
             0.2926361203769149, 0.4205530757547836, 0.9401360760402346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 190}], {
             RGBColor[
             0.21691115903565433`, 0.3453177594812544, 0.9356641416645529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 199}], {
             RGBColor[
             0.21390129447571837`, 0.3421542009923264, 0.9354927343305601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 261}], {
             RGBColor[
             0.23707213530482818`, 0.36650822381988146`, 0.9368122794375908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 284}], {
             RGBColor[
             0.23518277089129241`, 0.36452238202863274`, 0.9367046829293041]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 133}], {
             RGBColor[
             0.19109281456444907`, 0.3181810424644308, 0.9341938251417357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 146}], {
             RGBColor[
             0.19846266788634026`, 0.3259272255814276, 0.9346135273856964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 236}], {
             RGBColor[
             0.21416362323535532`, 0.3424299251513089, 0.9355076735653408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 260}], {
             RGBColor[
             0.2275319348126233, 0.35648086821892655`, 0.9362689791330215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 267}], {
             RGBColor[
             0.19655119281637518`, 0.32391814408837505`, 0.9345046717082358]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 146}], {
             RGBColor[
             0.19265917133132254`, 0.3198273827391699, 0.9342830268423918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 170}], {
             RGBColor[
             0.1914328920115927, 0.3185384854235343, 0.9342131920492509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 144}], {
             RGBColor[
             0.22121948408189393`, 0.34984608226843733`, 0.9359094944023405]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 160}], {
             RGBColor[
             0.22028173175537732`, 0.3488604451163368, 0.9358560907946256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 169}], {
             RGBColor[
             0.42476901028009817`, 0.532311534169465, 0.9496393645496872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 176}], {
             RGBColor[
             0.21949584805110617`, 0.34803443151524305`, 0.9358113358802782]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 180}], {
             RGBColor[
             0.21984183187712564`, 0.34839808245303105`, 0.9358310391473328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 187}], {
             RGBColor[
             0.23476961577043198`, 0.36408812980106076`, 0.9366811543563793]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 193}], {
             RGBColor[
             0.26218140249464095`, 0.39289965565586527`, 0.9382422150582186]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 200}], {
             RGBColor[
             0.3051846864517926, 0.4328450374952205, 0.9408835556758889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 221}], {
             RGBColor[
             0.21549733286296777`, 0.343831738532004, 0.9355836263555868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 228}], {
             RGBColor[
             0.3355280602689666, 0.4591269427933443, 0.9428170086239273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 230}], {
             RGBColor[
             0.21844228820343148`, 0.34692707331578443`, 0.9357513372055553]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 245}], {
             RGBColor[
             0.2350207777833922, 0.3643521170012733, 0.9366954576614566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 264}], {
             RGBColor[
             0.27050450497484707`, 0.4016477640777385, 0.9387162034315397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 288}], {
             RGBColor[
             0.22683219740980134`, 0.35574539984264686`, 0.9362291301230996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 297}], {
             RGBColor[
             0.21839610407426302`, 0.3468785308677854, 0.9357487070877224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 158}], {
             RGBColor[
             0.20301108119461975`, 0.33070789635448955`, 0.9348725527948284]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 173}], {
             RGBColor[
             0.20718172638991203`, 0.3350915088889201, 0.9351100648687836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 186}], {
             RGBColor[
             0.20309625090443267`, 0.3307974151195744, 0.934877403083805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 213}], {
             RGBColor[
             0.20772578685862308`, 0.3356633509369615, 0.9351410483076115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 214}], {
             RGBColor[
             0.20695344714813524`, 0.3348515729320728, 0.9350970647036734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 249}], {
             RGBColor[
             0.21026660117408774`, 0.33833390787944695`, 0.9352857439240791]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 255}], {
             RGBColor[
             0.28954719045708177`, 0.4163676580228129, 0.9399945385263857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 263}], {
             RGBColor[
             0.21148289076359805`, 0.33961230535523634`, 0.9353550098168626]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 265}], {
             RGBColor[
             0.21789617448484386`, 0.3463530731719392, 0.9357202368371844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 276}], {
             RGBColor[
             0.22722517815635135`, 0.3561584475236893, 0.9362515097952526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 286}], {
             RGBColor[
             0.2169836251808333, 0.34539392599445645`, 0.9356682685043168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 177}], {
             RGBColor[
             0.34229360740819775`, 0.46934835455154167`, 0.9430884098094023]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 194}], {
             RGBColor[
             0.539310518839214, 0.6345587760249104, 0.957788184762517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 197}], {
             RGBColor[
             0.689478603616865, 0.751552751257122, 0.9111273992783655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 204}], {
             RGBColor[
             0.4381119186941594, 0.553069802846105, 0.9493643283826801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 210}], {
             RGBColor[
             0.43214727310106515`, 0.5482274348494092, 0.9488947696323751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 226}], {
             RGBColor[
             0.6894363159019072, 0.7515352642002422, 0.911828216152313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 252}], {
             RGBColor[
             0.3152788883487585, 0.44095417198795417`, 0.9415499615236627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 279}], {
             RGBColor[
             0.3146411108912604, 0.44028382744269734`, 0.9415136410409652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 280}], {
             RGBColor[
             0.32731420410911033`, 0.4536040519351767, 0.9422353549515605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 147}], {
             RGBColor[
             0.23746595794531072`, 0.3669221563848262, 0.9368347070543579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 156}], {
             RGBColor[
             0.32801284307365003`, 0.4541649141300481, 0.9422814923217423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 179}], {
             RGBColor[
             0.3921454633437752, 0.5078279411583735, 0.9468889147894293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 191}], {
             RGBColor[
             0.24445543716588297`, 0.3742685422042259, 0.9372327475559615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 217}], {
             RGBColor[
             0.23078620352350526`, 0.3599013109666169, 0.9364543049218471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 247}], {
             RGBColor[
             0.22964528868911577`, 0.358702137137495, 0.9363893315098609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 251}], {
             RGBColor[
             0.27357072658534587`, 0.4048705574000514, 0.9388908202161892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 270}], {
             RGBColor[
             0.23718665422901314`, 0.36662859047011903`, 0.9368188011209075]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 271}], {
             RGBColor[
             0.24208469003989352`, 0.37177673666076144`, 0.9370977370143425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 273}], {
             RGBColor[
             0.25023215692458567`, 0.3803402409358096, 0.9375617232003286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 278}], {
             RGBColor[
             0.23108207251171536`, 0.3602122880324031, 0.9364711542230267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 289}], {
             RGBColor[
             0.25248937634424146`, 0.382712721661845, 0.9376902685070212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 295}], {
             RGBColor[
             0.2292284865221631, 0.35826405163324404`, 0.9363655952430565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 210}], {
             RGBColor[
             0.35148342859896836`, 0.4711989277702072, 0.9440171598227016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 211}], {
             RGBColor[
             0.25101026684268113`, 0.38115808379474614`, 0.9376060354090536]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 231}], {
             RGBColor[
             0.23123426787294182`, 0.3603722550067954, 0.9364798215236958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 266}], {
             RGBColor[
             0.21471877848996196`, 0.3430134285227765, 0.935539288835812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 143}], {
             RGBColor[
             0.37380885559171856`, 0.49802499695333824`, 0.9450460153054621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 163}], {
             RGBColor[
             0.5309367698880918, 0.6297354344441368, 0.9563109238850767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 235}], {
             RGBColor[
             0.42460849977243, 0.5421962738843169, 0.9482766560323135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 273}], {
             RGBColor[
             0.3398266519904991, 0.46230754637230465`, 0.9431107790825377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 274}], {
             RGBColor[
             0.4518848560948061, 0.5655575295786147, 0.9500876676545675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 298}], {
             RGBColor[
             0.350430471977903, 0.4734528335000848, 0.9437146509438744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 162}], {
             RGBColor[
             0.904333638485641, 0.5624086522177772, 0.47863148536736244`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 167}], {
             RGBColor[
             0.862500511580873, 0.40291200775905295`, 0.20439749636787896`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 181}], {
             RGBColor[
             0.9018064820205194, 0.5497777318797257, 0.2827365338887451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 201}], {
             RGBColor[
             0.8313415461919986, 0.24191043475062424`, 0.1776460060696587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 202}], {
             RGBColor[
             0.8419448678170631, 0.3105688491792778, 0.18729684498680563`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 203}], {
             RGBColor[
             0.8772220459314396, 0.5433777884881621, 0.5777664992302363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 216}], {
             RGBColor[
             0.8418913589267707, 0.3103258778057786, 0.18725219585712266`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 237}], {
             RGBColor[
             0.8211968317886982, 0.16393371440465854`, 0.16793141610024187`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 269}], {
             RGBColor[
             0.8952419489497732, 0.5276340204064351, 0.25723456251694715`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 293}], {
             RGBColor[
             0.8585388832387033, 0.3859183975781782, 0.20114329821116103`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 299}], {
             RGBColor[
             0.8180064493920196, 0.1394110372693064, 0.16487630231416095`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 146}], {
             RGBColor[
             0.24693839801171524`, 0.3768782914820059, 0.9373741485029203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 178}], {
             RGBColor[
             0.27642955220691934`, 0.4078753643883386, 0.9390536261060842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 182}], {
             RGBColor[
             0.2740956905180802, 0.4054223277779909, 0.9389207161355438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 188}], {
             RGBColor[
             0.3248560928052687, 0.45441830964122576`, 0.9419709558048517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 236}], {
             RGBColor[
             0.2626393533607303, 0.39338099105188706`, 0.9382682946825648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 261}], {
             RGBColor[
             0.269292107733182, 0.4003734577063236, 0.9386471592022079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 294}], {
             RGBColor[
             0.41494859536709305`, 0.5302055551777425, 0.9483322441534972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 149}], {
             RGBColor[
             0.8627196996396836, 0.42474633719376353`, 0.20540890846687038`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[
             0.8686725031653917, 0.4508599338020208, 0.21032865402022227`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 163}], {
             RGBColor[
             0.7255429896746053, 0.4672102742569026, 0.5698090215965668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 197}], {
             RGBColor[
             0.9081386520820702, 0.6098618084907887, 0.5261581856832962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 198}], {
             RGBColor[
             0.8972633266176216, 0.6021081538364577, 0.5605609698520013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 243}], {
             RGBColor[
             0.9086765502085565, 0.610084243189442, 0.517243821691691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 256}], {
             RGBColor[
             0.8239318482187612, 0.18495624917796497`, 0.17055047092242953`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 277}], {
             RGBColor[
             0.9114733897375824, 0.6092818085693412, 0.32849435906876756`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 163}], {
             RGBColor[
             0.4640224729127619, 0.5716064552084593, 0.95205347173178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 174}], {
             RGBColor[
             0.27004966377854045`, 0.4011696971418227, 0.9386903008982872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 185}], {
             RGBColor[
             0.41822549913320267`, 0.5344264087640556, 0.9484481661960105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 235}], {
             RGBColor[
             0.3576942027971, 0.4840672946486393, 0.9440192038790169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 298}], {
             RGBColor[
             0.28351617500257303`, 0.41532385426440727`, 0.9394571987905778]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 160}], {
             RGBColor[
             0.19670215780285202`, 0.3240768178608952, 0.934513268940883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 176}], {
             RGBColor[
             0.19591627409858087`, 0.32325080425980146`, 0.9344685140265354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 221}], {
             RGBColor[
             0.19191775891044247`, 0.3190481112765624, 0.9342408045018441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 230}], {
             RGBColor[
             0.19486271425090618`, 0.32214344606034284`, 0.9344085153518125]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 231}], {
             RGBColor[
             0.21441031983489064`, 0.34268921891888826`, 0.9355217225717294]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 232}], {
             RGBColor[
             0.19277383312180774`, 0.31994789955094727`, 0.9342895566617331]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 240}], {
             RGBColor[
             0.18908519234139687`, 0.31607090421740214`, 0.9340794940261437]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 245}], {
             RGBColor[
             0.2114412038308669, 0.3395684897458317, 0.9353526358077138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 264}], {
             RGBColor[
             0.24692493102232177`, 0.3768641368222969, 0.9373733815777969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 288}], {
             RGBColor[
             0.20325262345727604`, 0.33096177258720527`, 0.9348863082693568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 297}], {
             RGBColor[
             0.19481653012173772`, 0.32209490361234383`, 0.9344058852339796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 156}], {
             RGBColor[
             0.6296976932681398, 0.7056126711214472, 0.9666670627828757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 159}], {
             RGBColor[
             0.5780723315879956, 0.6592789022873965, 0.963436800696632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 167}], {
             RGBColor[
             0.8862929429929738, 0.7834059474084649, 0.6157767446761826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 168}], {
             RGBColor[
             0.6326576416445393, 0.7081764296337532, 0.9668556680760403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 201}], {
             RGBColor[
             0.8551339776040994, 0.6224043744000362, 0.5890252543779623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 203}], {
             RGBColor[
             0.9010144773435402, 0.923871728137574, 0.9891457475385399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 205}], {
             RGBColor[
             0.6186317877643385, 0.696027939962637, 0.9659619530693695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 216}], {
             RGBColor[
             0.8656837903388712, 0.6908198174551905, 0.5986314441654264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 237}], {
             RGBColor[
             0.8449892632007987, 0.5444276540540705, 0.5793106644085455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 269}], {
             RGBColor[
             0.9190343803618738, 0.908127960055847, 0.6686138108252507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 277}], {
             RGBColor[
             0.9289575250796454, 0.9412874203114796, 0.7338327759362018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 282}], {
             RGBColor[
             0.6527680048201097, 0.7255950154401895, 0.9681370826346918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 293}], {
             RGBColor[
             0.8823313146508039, 0.7664123372275902, 0.6125225465194646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 170}], {
             RGBColor[
             0.19880274533348388`, 0.3262846685405311, 0.9346328942932117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 236}], {
             RGBColor[
             0.2157299800022288, 0.3440762654260479, 0.9355968752659971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 247}], {
             RGBColor[
             0.2055770841992048, 0.33340492820629564`, 0.9350186828698783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 273}], {
             RGBColor[
             0.22616395243467474`, 0.35504303200461024`, 0.9361910745603459]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 289}], {
             RGBColor[
             0.22842117185433053`, 0.35741551273064565`, 0.9363196198670385]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 156}], {
             RGBColor[
             0.32039438822353183`, 0.44615743504463745`, 0.9418476325885221]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 159}], {
             RGBColor[
             0.26876902654338763`, 0.39982366621058674`, 0.9386173705022783]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 168}], {
             RGBColor[
             0.32335433659993124`, 0.4487211935569434, 0.9420362378816867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 191}], {
             RGBColor[
             0.23683698231576478`, 0.36626106311881523`, 0.9367988878227413]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 205}], {
             RGBColor[
             0.3093284827197305, 0.43657270388582725`, 0.9411425228750159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 217}], {
             RGBColor[
             0.22316774867338707`, 0.35189383188120626`, 0.9360204451886269]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 225}], {
             RGBColor[
             0.23694694145511846`, 0.36637663714608804`, 0.9368051498330575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 251}], {
             RGBColor[
             0.26595227173522773`, 0.39686307831464074`, 0.9384569604829689]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 270}], {
             RGBColor[
             0.22956819937889494`, 0.35862111138470837`, 0.9363849413876872]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 271}], {
             RGBColor[
             0.23446623518977533`, 0.3637692575753508, 0.9366638772811222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 278}], {
             RGBColor[
             0.2234636176615972, 0.35220480894699246`, 0.9360372944898065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.3434646997755016, 0.4661397793633797, 0.9433176524403382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 295}], {
             RGBColor[
             0.2216100316720449, 0.3502565725478334, 0.9359317355098362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 150}], {
             RGBColor[
             0.901456610665, 0.644502615181237, 0.23943789960535378`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.9409227595816787, 0.803504489870005, 0.5552674312684278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 198}], {
             RGBColor[
             0.93004743411723, 0.7957508352156739, 0.5896702154371328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 243}], {
             RGBColor[
             0.9414606577081649, 0.8037269245686582, 0.5463530672768225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 256}], {
             RGBColor[
             0.8567159557183694, 0.3785989305571812, 0.19965971650756104`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 277}], {
             RGBColor[
             0.9442574972371908, 0.8029244899485575, 0.3576036046538991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 281}], {
             RGBColor[
             0.9369826909775356, 0.800923138426649, 0.5779306345773171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 179}], {
             RGBColor[
             0.7150830892215184, 0.6470263643951079, 0.5999650595216117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 237}], {
             RGBColor[
             0.8662420388840522, 0.43217832029940567`, 0.20800123867959472`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 256}], {
             RGBColor[
             0.8626687592440776, 0.4047125271654385, 0.20457946206091293`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 269}], {
             RGBColor[
             0.9402871560451271, 0.7958786263011822, 0.2973043850963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 274}], {
             RGBColor[
             0.6852279869066359, 0.622788647378854, 0.5976147565045411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 277}], {
             RGBColor[
             0.9502103007628988, 0.8290380865568148, 0.362523350207251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 281}], {
             RGBColor[
             0.9429354945032435, 0.8270367350349062, 0.582850380130669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 293}], {
             RGBColor[
             0.9035840903340573, 0.6541630034729253, 0.24121312079051388`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 154}], {
             RGBColor[
             0.5475628360948273, 0.6435752036232633, 0.9575252987275946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 181}], {
             RGBColor[
             0.7920610111090953, 0.8249056195457978, 0.6813687144574905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 192}], {
             RGBColor[
             0.4642226762503304, 0.5725842955959759, 0.9518849903358793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 220}], {
             RGBColor[
             0.46545874896093703`, 0.5736549196510825, 0.9519637517959829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 239}], {
             RGBColor[
             0.41770207455751684`, 0.5257103442374987, 0.9491616700514242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 258}], {
             RGBColor[
             0.4689947888884989, 0.5767176597098022, 0.9521890651333698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 208}], {
             RGBColor[
             0.1859180316496269, 0.31274201752076575`, 0.9338991289101417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 242}], {
             RGBColor[
             0.1817008098525566, 0.3083094500247394, 0.9336589643676192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 244}], {
             RGBColor[
             0.1860116480511821, 0.312840414294423, 0.9339044602257174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 268}], {
             RGBColor[
             0.1937845276020504, 0.3210102035314135, 0.9343471142171944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 157}], {
             RGBColor[
             0.2018036290672552, 0.32943878761174283`, 0.9348037901824403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 192}], {
             RGBColor[
             0.2758432306623323, 0.4052369526728678, 0.9390942768006172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 220}], {
             RGBColor[
             0.27707930337293885`, 0.40630757672797435`, 0.9391730382607208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 222}], {
             RGBColor[
             0.2212473690290584, 0.3498753911159149, 0.9359110824088295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 239}], {
             RGBColor[
             0.22932262896951866`, 0.3583630013143907, 0.9363709565161622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 248}], {
             RGBColor[
             0.2215139470361167, 0.3501555815033551, 0.9359262636319645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 285}], {
             RGBColor[
             0.21037441724900163`, 0.3384472294101154, 0.9352918838900459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 181}], {
             RGBColor[
             0.7417957890267707, 0.7840980478369171, 0.6774116520475943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[
             0.7172113529376909, 0.7776981044453534, 0.9724416173890855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 216}], {
             RGBColor[
             0.6818806659330219, 0.5446461937629699, 0.581927314015972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 255}], {
             RGBColor[
             0.43165774296703474`, 0.5471078244024314, 0.9490557746765065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 258}], {
             RGBColor[
             0.4187295668061743, 0.5359100880009214, 0.9482320027234739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 162}], {
             RGBColor[
             0.9588310572734952, 0.8681281277104613, 0.5263067793464253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 194}], {
             RGBColor[
             0.8061596900222359, 0.7500989808439875, 0.6144534337056413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 210}], {
             RGBColor[
             0.698996444284087, 0.6637676396684864, 0.6055600185754992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 218}], {
             RGBColor[
             0.9467517036363646, 0.8603082831521655, 0.5999961337585191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 226}], {
             RGBColor[
             0.9562854870849291, 0.8670754690193194, 0.5684934650954372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 227}], {
             RGBColor[
             0.9395091625151377, 0.7978810172888317, 0.27018585613847523`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 241}], {
             RGBColor[
             0.9562190222247212, 0.8670479840915544, 0.569594959834627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 290}], {
             RGBColor[
             0.9363623874102649, 0.7854051025986525, 0.2676538870247894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 291}], {
             RGBColor[
             0.9265943306289632, 0.845047396157727, 0.6262279650717502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.8725038681798738, 0.44513051276199045`, 0.2125515962932238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 159}], {
             RGBColor[
             0.3428661620319342, 0.4697766941100199, 0.9431273668629003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 168}], {
             RGBColor[
             0.3974514720884778, 0.5186742214563766, 0.9465462342423088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.4586241439822036, 0.5697734899723961, 0.9509650514168311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 191}], {
             RGBColor[
             0.31093411780431135`, 0.4362140910182484, 0.9413088841833633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 205}], {
             RGBColor[
             0.38342561820827703`, 0.5065257317852604, 0.945652519235638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 251}], {
             RGBColor[
             0.3400494072237743, 0.46681610621407393`, 0.942966956843591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 269}], {
             RGBColor[
             0.6838282108058124, 0.7186257518784704, 0.6483043769915192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 270}], {
             RGBColor[
             0.3036653348674415, 0.42857413928414156`, 0.9408949377483093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 271}], {
             RGBColor[
             0.3085633706783219, 0.433722285474784, 0.9411738736417443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 277}], {
             RGBColor[
             0.6937513555235839, 0.7517852121341029, 0.7135233421024703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 282}], {
             RGBColor[
             0.41756183526404816`, 0.5360928072628128, 0.9478276488009602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 171}], {
             RGBColor[
             0.1808430925709541, 0.30740793477935857`, 0.9336101186373109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 184}], {
             RGBColor[
             0.18701393581723674`, 0.31389388228526116`, 0.9339615390312422]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 222}], {
             RGBColor[
             0.20198183109515816`, 0.32962608924173, 0.9348139385243031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 248}], {
             RGBColor[
             0.20224840910221648`, 0.3299062796291701, 0.9348291197474383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 275}], {
             RGBColor[
             0.18135642915031058`, 0.30794748407168115`, 0.9336393523960919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 285}], {
             RGBColor[
             0.1911088793151014, 0.31819792753593046`, 0.9341947400055196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 186}], {
             RGBColor[
             0.19303082310645578`, 0.3202180123189185, 0.9343041918611762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 196}], {
             RGBColor[
             0.1980026870183727, 0.32544375652472224`, 0.9345873321557463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 207}], {
             RGBColor[
             0.189116703595207, 0.3161040245430854, 0.9340812885454315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 212}], {
             RGBColor[
             0.21315714444874106`, 0.34137205213213645`, 0.9354503560873951]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 214}], {
             RGBColor[
             0.19688801935015837`, 0.3242721701314169, 0.9345238534810445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 225}], {
             RGBColor[
             0.21027114178594725`, 0.3383386803504027, 0.9352860025052073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 265}], {
             RGBColor[
             0.20783074668686696`, 0.3357736703712833, 0.9351470256145558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 276}], {
             RGBColor[
             0.21715975035837445`, 0.34557904472303347`, 0.935678298572624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 168}], {
             RGBColor[
             0.3458261104083336, 0.4723404526223259, 0.943315972156065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 191}], {
             RGBColor[
             0.25930875612416715`, 0.38988032218419766`, 0.9380786220971196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 205}], {
             RGBColor[
             0.33180025652813283`, 0.4601919629512097, 0.9424222571493942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 212}], {
             RGBColor[
             0.2623047179263146, 0.3930292679932042, 0.9382492376896236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 225}], {
             RGBColor[
             0.2594187152635208, 0.38999589621147046`, 0.9380848841074358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 251}], {
             RGBColor[
             0.2884240455436301, 0.4204823373800232, 0.9397366947573472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 270}], {
             RGBColor[
             0.2520399731872973, 0.38224037045009085`, 0.9376646756620657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 271}], {
             RGBColor[
             0.2569380089981777, 0.38738851664073326`, 0.9379436115555007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 282}], {
             RGBColor[
             0.36593647358390397`, 0.4897590384287621, 0.9445973867147164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 176}], {
             RGBColor[
             0.19497852177206426`, 0.3222651671077009, 0.9344151104188206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 180}], {
             RGBColor[
             0.19532450559808373`, 0.32262881804548893`, 0.9344348136858753]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 193}], {
             RGBColor[
             0.23766407621559904`, 0.36713039124832314`, 0.9368459895967611]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 221}], {
             RGBColor[
             0.19098000658392586`, 0.31806247412446187`, 0.9341874008941293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 230}], {
             RGBColor[
             0.19392496192438957`, 0.3211578089082423, 0.9343551117440977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 232}], {
             RGBColor[
             0.19183608079529113`, 0.31896226239884673`, 0.9342361530540182]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 245}], {
             RGBColor[
             0.2105034515043503, 0.33858285259373117`, 0.935299232199999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 288}], {
             RGBColor[
             0.20231487113075944`, 0.32997613543510473`, 0.934832904661642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 296}], {
             RGBColor[
             0.1914857715941317, 0.31859406521754197`, 0.9342162034632482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 297}], {
             RGBColor[
             0.1938787777952211, 0.3211092664602433, 0.9343524816262648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 177}], {
             RGBColor[
             0.24681318446187503`, 0.3767466841021262, 0.9373670177764938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 244}], {
             RGBColor[
             0.19557921069497186`, 0.3228965292515542, 0.9344493187643406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 279}], {
             RGBColor[
             0.2191606879449377, 0.34768215699328187`, 0.9357922490080568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 280}], {
             RGBColor[
             0.2318337811627876, 0.36100238148576125`, 0.9365139629186521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 169}], {
             RGBColor[
             0.7980436197485294, 0.8403418316253028, 0.877535691789008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 181}], {
             RGBColor[
             0.9888211205061603, 0.9780593840975029, 0.5971500192561076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 202}], {
             RGBColor[
             0.9289595063027041, 0.738850501397055, 0.5017103303541681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 216}], {
             RGBColor[
             0.9289059974124116, 0.7386075300235558, 0.5016656812244851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 227}], {
             RGBColor[
             0.9720263822129245, 0.9204431940139248, 0.5369240475267748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 228}], {
             RGBColor[
             0.7088026697373979, 0.7671572402491821, 0.8707133358632482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 299}], {
             RGBColor[
             0.9050210878776606, 0.5676926894870836, 0.4792897876815234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 185}], {
             RGBColor[
             0.5753534134295759, 0.6661368462548543, 0.9597130747756251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 235}], {
             RGBColor[
             0.5148221170934733, 0.615777732139438, 0.9552841124586315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 274}], {
             RGBColor[
             0.5420984734158494, 0.6391389878337358, 0.9570951240808855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 292}], {
             RGBColor[
             0.6974329821497556, 0.7632343245346107, 0.9706993881593793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 298}], {
             RGBColor[
             0.44064408929894633`, 0.5470342917552059, 0.9507221073701924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 176}], {
             RGBColor[
             0.1880768897106564, 0.3150111142224146, 0.9340220726829731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 180}], {
             RGBColor[
             0.18842287353667586`, 0.3153747651602027, 0.9340417759500277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 187}], {
             RGBColor[
             0.2033506574299822, 0.3310648125082323, 0.9348918911590742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 221}], {
             RGBColor[
             0.184078374522518, 0.31080842123917557`, 0.9337943631582817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 230}], {
             RGBColor[
             0.1870233298629817, 0.313903756022956, 0.9339620740082502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 296}], {
             RGBColor[
             0.18458413953272382`, 0.31134001233225567`, 0.9338231657274008]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 297}], {
             RGBColor[
             0.18697714573381324`, 0.31385521357495705`, 0.9339594438904173]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 175}], {
             RGBColor[
             0.2002014223302363, 0.3277547667453615, 0.9347125468790196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 183}], {
             RGBColor[
             0.2052672821395783, 0.33307930659904317`, 0.9350010401008936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 224}], {
             RGBColor[
             0.21323098705618415`, 0.3414496653944509, 0.9354545613146487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 253}], {
             RGBColor[
             0.20482209384336109`, 0.3326113854731506, 0.9349756872860211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 262}], {
             RGBColor[
             0.26081704104435255`, 0.39146562526609985`, 0.9381645166920165]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 195}], {
             RGBColor[
             0.184909234384039, 0.31168170763319203`, 0.9338416793982484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 234}], {
             RGBColor[
             0.19012477797807242`, 0.3171635746350845, 0.9341386968902232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.21183524129599424`, 0.3399826481050988, 0.9353750756584267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 285}], {
             RGBColor[
             0.19288702957547718`, 0.3200668762008235, 0.9342960030323104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 168}], {
             RGBColor[
             0.6540467218133117, 0.5964674977433942, 0.5956559161356156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[
             0.8765230577728718, 0.5106954425096772, 0.21782550243753762`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 202}], {
             RGBColor[
             0.8871263793979363, 0.5793538569383307, 0.22747634135468459`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.9224035575123126, 0.8121627962472151, 0.6179459955981152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 216}], {
             RGBColor[
             0.8870728705076437, 0.5791108855648315, 0.22743169222500162`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 237}], {
             RGBColor[
             0.8663783433695712, 0.4327187221637115, 0.20811091246812083`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 269}], {
             RGBColor[
             0.9404234605306463, 0.796419028165488, 0.2974140588848261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 277}], {
             RGBColor[
             0.9503466052484179, 0.8295784884211206, 0.3626330239957771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 282}], {
             RGBColor[
             0.674157084988882, 0.6138860835498305, 0.5969373306942671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 293}], {
             RGBColor[
             0.9037203948195764, 0.6547034053372311, 0.24132279457904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 203}], {
             RGBColor[
             0.6687682561638781, 0.7369332784725033, 0.9690249189979729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 205}], {
             RGBColor[
             0.3863855665846765, 0.5090894902975664, 0.9458411245288025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 212}], {
             RGBColor[
             0.31689002798285826`, 0.4419267953395609, 0.941668105069032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 225}], {
             RGBColor[
             0.31400402532006444`, 0.4388934235578272, 0.9415037514868442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 269}], {
             RGBColor[
             0.6867881591822118, 0.7211895103907764, 0.6484929822846838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 276}], {
             RGBColor[
             0.3208926338924916, 0.4461337879304579, 0.9418960475542608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 282}], {
             RGBColor[
             0.42052178364044757`, 0.5386565657751188, 0.9480162540941248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 293}], {
             RGBColor[
             0.650085093471142, 0.5794738875625195, 0.5924017179788976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 193}], {
             RGBColor[
             0.44215135474031986`, 0.5505814803014513, 0.9506292633518225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 200}], {
             RGBColor[
             0.4851546386974715, 0.5905268621408066, 0.9532706039694929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 202}], {
             RGBColor[
             0.7356548490799517, 0.5885020285868033, 0.5862010514084512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 227}], {
             RGBColor[
             0.7787217249901721, 0.7700947212036731, 0.6214147685810579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 228}], {
             RGBColor[
             0.5154980125146456, 0.6168087674389304, 0.9552040569175313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 264}], {
             RGBColor[
             0.450474457220526, 0.5593295887233245, 0.9511032517251437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 299}], {
             RGBColor[
             0.7117164306549081, 0.41734421667683197`, 0.5637805087358065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 178}], {
             RGBColor[
             0.228293899528688, 0.35728174144686387`, 0.9363123718963757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 182}], {
             RGBColor[
             0.2259600378398488, 0.3548287048365162, 0.9361794619258352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 190}], {
             RGBColor[
             0.2009954787857768, 0.3285893704262217, 0.9347577672194614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 199}], {
             RGBColor[
             0.19798561422584082`, 0.3254258119372937, 0.9345863598854686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 261}], {
             RGBColor[
             0.22115645505495063`, 0.3497798347648488, 0.9359059049924991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 284}], {
             RGBColor[
             0.2192670906414149, 0.34779399297360003`, 0.9357983084842125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 184}], {
             RGBColor[
             0.1853189372548359, 0.31211233132706184`, 0.9338650113706392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 275}], {
             RGBColor[
             0.17966143058790973`, 0.3061659331134819, 0.9335428247354888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 285}], {
             RGBColor[
             0.18941388075270052`, 0.31641637657773114`, 0.9340982123449165]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 174}], {
             RGBColor[
             0.21189442021644855`, 0.34004484890265657`, 0.9353784458103991]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 238}], {
             RGBColor[
             0.18901379750666059`, 0.31599586371940025`, 0.9340754281959247]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 186}], {
             RGBColor[
             0.19720146830174806`, 0.32460162485334904`, 0.9345417039351314]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 213}], {
             RGBColor[
             0.20183100425593847`, 0.3294675606707361, 0.9348053491589379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 234}], {
             RGBColor[
             0.19772105404463286`, 0.3251477424127598, 0.9345712935745305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 249}], {
             RGBColor[
             0.20437181857140313`, 0.33213811761322165`, 0.9349500447754056]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 263}], {
             RGBColor[
             0.20558810816091344`, 0.33341651508901093`, 0.935019310668189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 286}], {
             RGBColor[
             0.2110888425781487, 0.3391981357282311, 0.9353325693556434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 235}], {
             RGBColor[
             0.3208493079592518, 0.4453409740728014, 0.9419209416251387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 238}], {
             RGBColor[
             0.21032414623090429`, 0.3383943913827284, 0.9352890210299346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 298}], {
             RGBColor[
             0.24667128016472487`, 0.3765975336885693, 0.9373589365366997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 183}], {
             RGBColor[
             0.18767445593923526`, 0.3145881308128762, 0.9339991546750381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 224}], {
             RGBColor[
             0.19563816085584113`, 0.3229584896082839, 0.9344526758887932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 253}], {
             RGBColor[
             0.18722926764301806`, 0.3141202096869836, 0.9339738018601655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 180}], {
             RGBColor[
             0.1945386218938126, 0.32180280444439524`, 0.9343900587715277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 187}], {
             RGBColor[
             0.20946640578711895`, 0.33749285179242483`, 0.9352401739805742]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 193}], {
             RGBColor[
             0.23687819251132788`, 0.36630437764722934`, 0.9368012346824135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 221}], {
             RGBColor[
             0.1901941228796547, 0.3172364605233681, 0.9341426459797817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 230}], {
             RGBColor[
             0.19313907822011844`, 0.32033179530714856`, 0.9343103568297502]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 245}], {
             RGBColor[
             0.20971756780007914`, 0.3377568389926374, 0.9352544772856515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 288}], {
             RGBColor[
             0.20152898742648828`, 0.32915012183401104`, 0.9347881497472945]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 296}], {
             RGBColor[
             0.19069988788986053`, 0.3177680516164482, 0.9341714485489008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 297}], {
             RGBColor[
             0.19309289409094996`, 0.3202832528591496, 0.9343077267119173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 194}], {
             RGBColor[
             0.4889886310377472, 0.5894215892292383, 0.9546385045000421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 226}], {
             RGBColor[
             0.6391144281004404, 0.7063980774045702, 0.908678535889838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 252}], {
             RGBColor[
             0.2649570005472917, 0.39581698519228203`, 0.9384002812611878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 268}], {
             RGBColor[
             0.24851062539069607`, 0.37853080214228807`, 0.9374636845262513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 279}], {
             RGBColor[
             0.2643192230897936, 0.3951466406470252, 0.9383639607784904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 280}], {
             RGBColor[
             0.27699231630764354`, 0.4084668651395046, 0.9390856746890857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 182}], {
             RGBColor[
             0.2566774713547828, 0.3871146750584845, 0.9379287743221401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 190}], {
             RGBColor[
             0.23171291230071078`, 0.36087534064819005`, 0.9365070796157662]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 199}], {
             RGBColor[
             0.2287030477407748, 0.357711782159262, 0.9363356722817735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 229}], {
             RGBColor[
             0.23836184028178953`, 0.36786378552268634`, 0.9368857262280812]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 261}], {
             RGBColor[
             0.2518738885698846, 0.38206580498681714`, 0.9376552173888041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 284}], {
             RGBColor[
             0.24998452415634886`, 0.38007996319556836`, 0.9375476208805174]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 205}], {
             RGBColor[
             0.44755823847840226`, 0.5601887588135859, 0.9502599417033248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 251}], {
             RGBColor[
             0.4041820274938994, 0.5204791332423994, 0.9475743793112779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 269}], {
             RGBColor[
             0.7479608310759376, 0.7722887789067958, 0.6529117994592061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 274}], {
             RGBColor[
             0.4929016619374462, 0.5991987999844676, 0.9532221708674471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 277}], {
             RGBColor[
             0.7578839757937091, 0.8054482391624284, 0.7181307645701571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 282}], {
             RGBColor[
             0.48169445553417334`, 0.5897558342911382, 0.9524350712686471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 289}], {
             RGBColor[
             0.383100677252795, 0.49832129750419296`, 0.9463738276021099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 187}], {
             RGBColor[
             0.20981238961313842`, 0.3378565027302129, 0.9352598772476289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 193}], {
             RGBColor[
             0.23722417633734735`, 0.3666680285850174, 0.9368209379494682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 215}], {
             RGBColor[
             0.2098131605219987, 0.33785731300430355`, 0.9352599211497481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 221}], {
             RGBColor[
             0.19054010670567417`, 0.3176001114611562, 0.9341623492468364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 230}], {
             RGBColor[
             0.1934850620461379, 0.3206954462449366, 0.9343300600968047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 233}], {
             RGBColor[
             0.20014010875548707`, 0.32769032229079487`, 0.9347090551616429]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 245}], {
             RGBColor[
             0.2100635516260986, 0.3381204899304254, 0.9352741805527061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 288}], {
             RGBColor[
             0.20187497125250775`, 0.32951377277179905`, 0.9348078530143491]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 296}], {
             RGBColor[
             0.19104587171588, 0.3181317025542363, 0.9341911518159554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 297}], {
             RGBColor[
             0.19343887791696943`, 0.3206469037969376, 0.9343274299789719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 201}], {
             RGBColor[
             0.9158290282125181, 0.65756116663035, 0.29616453995840375`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 202}], {
             RGBColor[
             0.9264323498375825, 0.7262195810590035, 0.3058153788755507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 203}], {
             RGBColor[
             0.961709527951959, 0.9590285203678879, 0.6962850331189814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 216}], {
             RGBColor[
             0.92637884094729, 0.7259766096855043, 0.3057707297458678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 227}], {
             RGBColor[
             0.9694992257478029, 0.9078122736758734, 0.34102909604815745`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 258}], {
             RGBColor[
             0.6632277418204424, 0.717240503923456, 0.6720754184533696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 299}], {
             RGBColor[
             0.9024939314125389, 0.5550617691490322, 0.28339483620290606`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 190}], {
             RGBColor[
             0.22937905061187158`, 0.35842230403784237`, 0.9363741696452258]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 199}], {
             RGBColor[
             0.22636918605193562`, 0.35525874554891435`, 0.936202762311233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 229}], {
             RGBColor[
             0.23602797859295035`, 0.36541074891233866`, 0.9367528162575407]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 261}], {
             RGBColor[
             0.24954002688104543`, 0.37961276837646946`, 0.9375223074182637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 284}], {
             RGBColor[
             0.24765066246750966`, 0.3776269265852207, 0.937414710909977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 224}], {
             RGBColor[
             0.2007040206651831, 0.3282830294619655, 0.9347411691106672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 253}], {
             RGBColor[
             0.19229512745236005`, 0.31944474954066526`, 0.9342622950820396]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 222}], {
             RGBColor[
             0.2064576757790399, 0.33433048578943325`, 0.9350688312576314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 224}], {
             RGBColor[
             0.20007875304145373`, 0.32762583354516883`, 0.9347055610444963]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 248}], {
             RGBColor[
             0.20672425378609824`, 0.33461067617687346`, 0.9350840124807664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 275}], {
             RGBColor[
             0.18583227383419235`, 0.31265188061938454`, 0.9338942451294201]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 218}], {
             RGBColor[
             0.7483730046735189, 0.8020037075647066, 0.948265724399384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 235}], {
             RGBColor[
             0.4690251433139141, 0.5785976856950342, 0.951678806922862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 262}], {
             RGBColor[
             0.41669813660407123`, 0.5328210539055609, 0.9483611851595068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 292}], {
             RGBColor[
             0.6516360083701964, 0.726054278090207, 0.9670940826236099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 196}], {
             RGBColor[
             0.19808785672818557`, 0.32553327528980713`, 0.9345921824447229]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 214}], {
             RGBColor[
             0.19697318905997124`, 0.32436168889650174`, 0.9345287037700212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 249}], {
             RGBColor[
             0.20028634308592377`, 0.3278440238438759, 0.934717382990427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 265}], {
             RGBColor[
             0.2079159163966799, 0.33586318913636815`, 0.9351518759035322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 286}], {
             RGBColor[
             0.2070033670926693, 0.3349040419588854, 0.9350999075706646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 193}], {
             RGBColor[
             0.25215196023065367`, 0.38235807593304705`, 0.9376710531585147]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 215}], {
             RGBColor[
             0.224740944415305, 0.35354736035233314`, 0.9361100363587946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 228}], {
             RGBColor[
             0.32549861800497937`, 0.4485853630705261, 0.9422458467242234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 229}], {
             RGBColor[
             0.22122626051320093`, 0.3498532047273915, 0.9359098803100787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 230}], {
             RGBColor[
             0.20841284593944426`, 0.3363854935929662, 0.9351801753058513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 233}], {
             RGBColor[
             0.2150678926487934, 0.3433803696388245, 0.9355591703706895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 245}], {
             RGBColor[
             0.22499133551940492`, 0.35381053727845513`, 0.9361242957617526]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 288}], {
             RGBColor[
             0.2168027551458141, 0.3452038201198287, 0.9356579682233956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 296}], {
             RGBColor[
             0.20597365560918635`, 0.3338217499022659, 0.9350412670250019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 297}], {
             RGBColor[
             0.20836666181027574`, 0.33633695114496726`, 0.9351775451880184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 236}], {
             RGBColor[
             0.29364767479578224`, 0.42161628358526776`, 0.9401936825679285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 260}], {
             RGBColor[
             0.3070159863730502, 0.43566722665288543`, 0.9409549881356092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 261}], {
             RGBColor[
             0.30030042916823396`, 0.42860875023970424`, 0.9405725470875715]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 281}], {
             RGBColor[
             0.66716299452805, 0.7330554302274623, 0.9326197293964239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 294}], {
             RGBColor[
             0.445956916802145, 0.5584408477111231, 0.9502576320388609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 257}], {
             RGBColor[
             0.1999558217805158, 0.327496624995631, 0.9346985602910465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 260}], {
             RGBColor[
             0.23700170640282697`, 0.36643419857842796`, 0.936808268615812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 267}], {
             RGBColor[
             0.20602096440657885`, 0.33387147444787646`, 0.9350439611910263]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 287}], {
             RGBColor[
             0.22941840696730975`, 0.35846367006274493`, 0.9363764109314454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 300}], {
             RGBColor[
             0.22074088939765935`, 0.34934304891065115`, 0.9358822391430908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 199}], {
             RGBColor[
             0.2014046269978636, 0.3290194111386199, 0.9347810676048591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 261}], {
             RGBColor[
             0.2245754678269734, 0.353373433966175, 0.9361006127118898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 284}], {
             RGBColor[
             0.22268610341343767`, 0.3513875921749262, 0.9359930162036031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 205}], {
             RGBColor[
             0.29986821230051, 0.4266293598594382, 0.9406037744698572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 217}], {
             RGBColor[
             0.21370747825416658`, 0.3419504878548173, 0.9354816967834682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 225}], {
             RGBColor[
             0.22748667103589795`, 0.35643329311969896`, 0.9362664014278987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 246}], {
             RGBColor[
             0.2059132617802264, 0.3337582721588391, 0.9350378276857872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 251}], {
             RGBColor[
             0.25649200131600725`, 0.38691973428825177`, 0.9379182120778102]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 270}], {
             RGBColor[
             0.22010792895967446`, 0.34867776735831935`, 0.9358461929825286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 271}], {
             RGBColor[
             0.22500596477055484`, 0.35382591354896176`, 0.9361251288759636]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 278}], {
             RGBColor[
             0.21400334724237668`, 0.34226146492060344`, 0.9354985460846478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 282}], {
             RGBColor[
             0.3340044293562811, 0.4561964353369906, 0.9427789040351794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 295}], {
             RGBColor[
             0.21214976125282442`, 0.34031322852144436`, 0.9353929871046776]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 218}], {
             RGBColor[
             0.6489034320102649, 0.7179182155893853, 0.9413556495465901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 220}], {
             RGBColor[
             0.3318533670341157, 0.4618564399149144, 0.9423663809943715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 222}], {
             RGBColor[
             0.2760214326902352, 0.40542425430285495`, 0.93910442514248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 248}], {
             RGBColor[
             0.27628801069729353`, 0.4057044446902951, 0.9391196063656152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 262}], {
             RGBColor[
             0.31722856394081744`, 0.4487355619302395, 0.9414511103067129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 200}], {
             RGBColor[
             0.3225670309120143, 0.4511149836272068, 0.9418734544780243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 215}], {
             RGBColor[
             0.252152731139514, 0.38235888620713765`, 0.9376710970606339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 228}], {
             RGBColor[
             0.35291040472918833`, 0.4773968889253306, 0.9438069074260627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 230}], {
             RGBColor[
             0.2358246326636532, 0.3651970194477707, 0.9367412360076905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 245}], {
             RGBColor[
             0.2524031222436139, 0.38262206313325964`, 0.9376853564635919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 264}], {
             RGBColor[
             0.28788684943506876`, 0.4199177102097248, 0.939706102233675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 288}], {
             RGBColor[
             0.24421454187002306`, 0.3740153459746332, 0.9372190289252349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 210}], {
             RGBColor[
             0.5788422967306146, 0.6683006695271059, 0.9604448643230148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 226}], {
             RGBColor[
             0.8361313395314567, 0.8716084988779389, 0.9233783108429527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 241}], {
             RGBColor[
             0.8360648746712487, 0.8715810139501738, 0.9244798055821426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 280}], {
             RGBColor[
             0.4740092277386598, 0.5736772866128733, 0.9537854496422005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 290}], {
             RGBColor[
             0.8162082398567924, 0.7899381324572718, 0.622538732772305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 291}], {
             RGBColor[
             0.8064401830754907, 0.8495804260163464, 0.9811128108192658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 234}], {
             RGBColor[
             0.18893962070800485`, 0.3159178992009325, 0.934071203936976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 207}], {
             RGBColor[
             0.19417373721693681`, 0.32141928751397403`, 0.9343692791289782]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 212}], {
             RGBColor[
             0.2182141780704709, 0.3466873151030251, 0.9357383466709418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 214}], {
             RGBColor[
             0.20194505297188817`, 0.32958743310230554`, 0.9348118440645912]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 225}], {
             RGBColor[
             0.21532817540767707`, 0.3436539433212913, 0.935573993088754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 265}], {
             RGBColor[
             0.21288778030859679`, 0.34108893334217194`, 0.9354350161981024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 276}], {
             RGBColor[
             0.22221678398010425`, 0.35089430769392205`, 0.9359662891561706]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 198}], {
             RGBColor[
             0.9754663865596167, 0.9808663065126991, 0.9104194926535587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 204}], {
             RGBColor[
             0.7349750271013598, 0.7901370127560131, 0.9142536375891683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 226}], {
             RGBColor[
             0.9862994243091077, 0.9886024741101505, 0.8767175253588012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 243}], {
             RGBColor[
             0.9868796101505515, 0.9888423958656835, 0.8671023444932484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 254}], {
             RGBColor[
             0.6525617744919028, 0.7195772493628625, 0.9087750915707931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 283}], {
             RGBColor[
             0.646081244426157, 0.713693683071829, 0.9083720606763512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 204}], {
             RGBColor[
             0.7240997016369111, 0.7823833581016821, 0.9486564217578735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 226}], {
             RGBColor[
             0.975424098844659, 0.9808488194558194, 0.9111203095275062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 243}], {
             RGBColor[
             0.9760042846861029, 0.9810887412113525, 0.9015051286619535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 254}], {
             RGBColor[
             0.6416864490274542, 0.7118235947085315, 0.9431778757394982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 256}], {
             RGBColor[
             0.8912595826963075, 0.5559607471998754, 0.554811777892692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 283}], {
             RGBColor[
             0.6352059189617083, 0.705940028417498, 0.9427748448450561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 209}], {
             RGBColor[
             0.1894252090832627, 0.31642828337140966`, 0.9340988574765833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 229}], {
             RGBColor[
             0.20805355497894237`, 0.33600785601311617`, 0.9351597142171741]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 233}], {
             RGBColor[
             0.20189518711453486`, 0.32953502092454917`, 0.9348090042777849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 259}], {
             RGBColor[
             0.19177802866162308`, 0.31890124592564373`, 0.9342328470708863]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 261}], {
             RGBColor[
             0.22156560326703745`, 0.35020987547724697`, 0.9359292053778969]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 284}], {
             RGBColor[
             0.21967623885350168`, 0.3482240336859982, 0.9358216088696103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 210}], {
             RGBColor[
             0.4186246829308158, 0.5365148469090834, 0.9480331221442837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 211}], {
             RGBColor[
             0.31815152117452855`, 0.44647400293362227`, 0.9416219977306357]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 227}], {
             RGBColor[
             0.6591374011618665, 0.6706282245294286, 0.6126589597072597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 228}], {
             RGBColor[
             0.3959136886863399, 0.5173422707646859, 0.946448248043733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 231}], {
             RGBColor[
             0.2983755222047893, 0.4256881741456715, 0.9404957838452779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 245}], {
             RGBColor[
             0.2954064062007655, 0.4225674449726149, 0.9403266970812623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 264}], {
             RGBColor[
             0.3308901333922204, 0.45986309204908005`, 0.9423474428513454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 202}], {
             RGBColor[
             0.8559674140090618, 0.41835228392990204`, 0.20072485105646432`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 203}], {
             RGBColor[
             0.8912445921234382, 0.6511612232387863, 0.591194505299895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 216}], {
             RGBColor[
             0.8559139051187693, 0.4181093125564028, 0.20068020192678135`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 237}], {
             RGBColor[
             0.8352193779806968, 0.2717171491552828, 0.18135942216990056`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 269}], {
             RGBColor[
             0.9092644951417719, 0.6354174551570593, 0.2706625685866058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 277}], {
             RGBColor[
             0.9191876398595434, 0.6685769154126919, 0.3358815336975568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 293}], {
             RGBColor[
             0.872561429430702, 0.49370183232880244`, 0.21457130428081972`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 299}], {
             RGBColor[
             0.8320289955840182, 0.24719447201993064`, 0.1783043083838196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 203}], {
             RGBColor[
             0.9018479137485027, 0.71981963766744, 0.6008453442170419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 216}], {
             RGBColor[
             0.8665172267438337, 0.4867677269850564, 0.21033104084392829`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 237}], {
             RGBColor[
             0.8458226996057612, 0.34037556358393634`, 0.1910102610870475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 269}], {
             RGBColor[
             0.9198678167668363, 0.7040758695857129, 0.2803134075037528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 293}], {
             RGBColor[
             0.8831647510557664, 0.562360246757456, 0.22422214319796666`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 299}], {
             RGBColor[
             0.8426323172090826, 0.3158528864485842, 0.18795514730096657`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 216}], {
             RGBColor[
             0.9017944048582103, 0.7195766662939407, 0.600800695087359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 237}], {
             RGBColor[
             0.8810998777201378, 0.5731845028928206, 0.5814799153304782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 255}], {
             RGBColor[
             0.651571481892223, 0.7220382969334023, 0.9679291557478935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 269}], {
             RGBColor[
             0.9551449948812127, 0.9368848088945971, 0.6707830617471834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 293}], {
             RGBColor[
             0.9184419291701429, 0.7951691860663403, 0.6146917974413972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 299}], {
             RGBColor[
             0.8779094953234592, 0.5486618257574685, 0.5784248015443972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 226}], {
             RGBColor[
             0.734932739386402, 0.7901195256991334, 0.9149544544631159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 243}], {
             RGBColor[
             0.7355129252278461, 0.7903594474546665, 0.9053392735975632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 254}], {
             RGBColor[
             0.40119508956919725`, 0.5210943009518455, 0.9470120206751078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 283}], {
             RGBColor[
             0.3947145595034514, 0.515210734660812, 0.9466089897806659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 225}], {
             RGBColor[
             0.29997817143986366`, 0.426744933886711, 0.9406100364801734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 251}], {
             RGBColor[
             0.3289835017199729, 0.45723137505526373`, 0.9422618471300848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 269}], {
             RGBColor[
             0.6727623053020111, 0.7090410207196602, 0.647599267278013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 282}], {
             RGBColor[
             0.40649592976024684`, 0.5265080761040026, 0.947122539087454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 219}], {
             RGBColor[
             0.20337837440800324`, 0.33109394480949034`, 0.9348934695999689]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 254}], {
             RGBColor[
             0.27060222090313846`, 0.400822588016517, 0.9387557425033809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 283}], {
             RGBColor[
             0.26412169083739256`, 0.3949390217254835, 0.938352711608939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 212}], {
             RGBColor[
             0.20932819464730518`, 0.33734758312138824`, 0.935232303060627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 214}], {
             RGBColor[
             0.19305906954872248`, 0.3202477011206687, 0.9343058004542764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 225}], {
             RGBColor[
             0.20644219198451136`, 0.33431421133965444`, 0.9350679494784392]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 242}], {
             RGBColor[
             0.18509931747274389`, 0.3118814970113848, 0.9338525043489474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 244}], {
             RGBColor[
             0.18941015567136937`, 0.31641246128106837`, 0.9340980002070455]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 252}], {
             RGBColor[
             0.21362941037883332`, 0.3418684335680528, 0.935477250933459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 268}], {
             RGBColor[
             0.19718303522223768`, 0.3245822505180589, 0.9345406541985226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 279}], {
             RGBColor[
             0.21299163292133522`, 0.34119808902279597`, 0.9354409304507616]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 259}], {
             RGBColor[
             0.18280847530695815`, 0.30947367664736153`, 0.9337220442766032]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 211}], {
             RGBColor[
             0.3712058892361785, 0.49192848437614356`, 0.9451403247792249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 226}], {
             RGBColor[
             0.7289680937933078, 0.7852771577024377, 0.9144848957128108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 227}], {
             RGBColor[
             0.7121917692235163, 0.7160827059719499, 0.6161772867558488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 241}], {
             RGBColor[
             0.7289016289330998, 0.7852496727746727, 0.9155863904520005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 290}], {
             RGBColor[
             0.7090449941186435, 0.7036067912817707, 0.613645317642163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 291}], {
             RGBColor[
             0.6992769373373419, 0.7632490848408453, 0.9722193956891239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 231}], {
             RGBColor[
             0.25095672851015194`, 0.3811018116127316, 0.937602986480219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 264}], {
             RGBColor[
             0.28347133969758304`, 0.41527672951614025`, 0.9394546454862865]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 266}], {
             RGBColor[
             0.23444123912717205`, 0.36374298512871284`, 0.9366624537923354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 214}], {
             RGBColor[
             0.21709951040225656`, 0.3455157287097197, 0.9356748679962401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 225}], {
             RGBColor[
             0.23048263283804543`, 0.3595822389287055, 0.9364370170204028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 265}], {
             RGBColor[
             0.22804223773896515`, 0.3570172289495861, 0.9362980401297512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 276}], {
             RGBColor[
             0.23737124141047264`, 0.3668226033013362, 0.9368293130878194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 234}], {
             RGBColor[
             0.19826511451334394`, 0.3257195844608012, 0.9346022770133582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 249}], {
             RGBColor[
             0.2049158790401142, 0.33270995966126304`, 0.9349810282142335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 263}], {
             RGBColor[
             0.2061321686296245, 0.3339883571370523, 0.9350502941070169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 286}], {
             RGBColor[
             0.21163290304685975`, 0.3397699777762725, 0.935363552794471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 265}], {
             RGBColor[
             0.21177311264038245`, 0.33991734694886655`, 0.9353715375234006]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 276}], {
             RGBColor[
             0.22110211631188992`, 0.34972272130061666`, 0.9359028104814688]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 286}], {
             RGBColor[
             0.21086056333637188`, 0.3389581997713838, 0.9353195691905329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 229}], {
             RGBColor[
             0.2212270314220612, 0.34985401500148217`, 0.9359099242121978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 233}], {
             RGBColor[
             0.2150686635576537, 0.34338117991291517`, 0.9355592142728086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 259}], {
             RGBColor[
             0.20495150510474192`, 0.33274740491400967`, 0.9349830570659099]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 296}], {
             RGBColor[
             0.20597442651804665`, 0.33382256017635653`, 0.935041310927121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 237}], {
             RGBColor[
             0.8457691907154687, 0.3401325922104371, 0.19096561195736456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 269}], {
             RGBColor[
             0.9198143078765437, 0.7038328982122137, 0.28026875837406984`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 293}], {
             RGBColor[
             0.8831112421654739, 0.5621172753839567, 0.2241774940682837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 299}], {
             RGBColor[
             0.8425788083187902, 0.31560991507508496`, 0.1879104981712836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 223}], {
             RGBColor[
             0.19076430807847547`, 0.31783576131915836`, 0.9341751171833412]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 246}], {
             RGBColor[
             0.1922440281378487, 0.31939104092123016`, 0.9342593850516728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 247}], {
             RGBColor[
             0.19889732977739935`, 0.3263840827880864, 0.9346382807373675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 251}], {
             RGBColor[
             0.24282276767362948`, 0.3725525030506428, 0.9371397694436958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 270}], {
             RGBColor[
             0.20643869531729672`, 0.3343105361207104, 0.9350677503484142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 271}], {
             RGBColor[
             0.21133673112817714`, 0.3394586823113528, 0.9353466862418491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 278}], {
             RGBColor[
             0.20033411359999898`, 0.32789423368299453`, 0.9347201034505334]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 295}], {
             RGBColor[
             0.19848052761044668`, 0.32594599728383544`, 0.9346145444705631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 220}], {
             RGBColor[
             0.6501395047208716, 0.7189888396444919, 0.9414344110066938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 262}], {
             RGBColor[
             0.6355147016275733, 0.7058679616598169, 0.9405191403190352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 290}], {
             RGBColor[
             0.956800253470921, 0.9001474347654498, 0.6080814328251828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 292}], {
             RGBColor[
             0.8704525733936984, 0.8991011858444631, 0.9592520377831382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 250}], {
             RGBColor[
             0.1834940050025886, 0.3101942118225623, 0.933761084178619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 222}], {
             RGBColor[
             0.2772575054008418, 0.4064948783579615, 0.9391831866025837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 248}], {
             RGBColor[
             0.27752408340790014`, 0.40677506874540165`, 0.9391983678257189]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 262}], {
             RGBColor[
             0.318464636651424, 0.44980618598534605`, 0.9415298717668166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 230}], {
             RGBColor[
             0.18914056303198, 0.3161291023239095, 0.9340826473050587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 232}], {
             RGBColor[
             0.18705168190288157`, 0.31393355581451393`, 0.9339636886149794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 245}], {
             RGBColor[
             0.20571905261194073`, 0.33355414600939837`, 0.93502676776096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 288}], {
             RGBColor[
             0.19753047223834988`, 0.324947428850772, 0.9345604402226031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 296}], {
             RGBColor[
             0.18670137270172213`, 0.31356535863320917`, 0.9339437390242094]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 297}], {
             RGBColor[
             0.18909437890281156`, 0.31608055987591055`, 0.9340800171872259]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 248}], {
             RGBColor[
             0.22169214906401963`, 0.3503428831333422, 0.9359364119738274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 285}], {
             RGBColor[
             0.21055261927690455`, 0.33863453104010255`, 0.9353020322319088]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 246}], {
             RGBColor[
             0.1829700916045353, 0.3096435456231802, 0.9337312480856603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 247}], {
             RGBColor[
             0.18962339324408597`, 0.3166365874900364, 0.934110143771355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 270}], {
             RGBColor[
             0.19716475878398335`, 0.32456304082266046`, 0.9345396133824015]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 271}], {
             RGBColor[
             0.20206279459486376`, 0.3297111870133029, 0.9348185492758365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 278}], {
             RGBColor[
             0.1910601770666856, 0.31814673838494456`, 0.9341919664845209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 295}], {
             RGBColor[
             0.1892065910771333, 0.3161985019857855, 0.9340864075045505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 253}], {
             RGBColor[
             0.20025883236896588`, 0.32781510833607297`, 0.9347158162957947]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 262}], {
             RGBColor[
             0.2562537795699573, 0.3866693481290222, 0.9379046457017901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 265}], {
             RGBColor[
             0.22515623507617133`, 0.35398385716785236`, 0.9361336865475633]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 276}], {
             RGBColor[
             0.23448523874767882`, 0.3637892315196025, 0.9366649595056316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 241}], {
             RGBColor[
             0.9861906717339419, 0.9885575021255057, 0.8785198369719385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 243}], {
             RGBColor[
             0.9868373224355939, 0.9888249088088037, 0.8678031613671959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 290}], {
             RGBColor[
             0.9663340369194856, 0.9069146206326038, 0.576578764162101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 291}], {
             RGBColor[
             0.956565980138184, 0.9665569141916783, 0.9351528422090618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 241}], {
             RGBColor[
             0.9694143471641505, 0.9193630503950179, 0.5802122280149764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 290}], {
             RGBColor[
             0.9495577123496941, 0.837720168902116, 0.27827115520513895`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 291}], {
             RGBColor[
             0.9397896555683924, 0.8973624624611904, 0.6368452332520997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 299}], {
             RGBColor[
             0.885699193119303, 0.49744557906545395`, 0.22316886447357331`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 264}], {
             RGBColor[
             0.3612335072093944, 0.48614499734720384`, 0.9442808957993838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 233}], {
             RGBColor[
             0.2115539796555496, 0.3396870242879735, 0.9353590582240927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 259}], {
             RGBColor[
             0.2014368212026378, 0.32905324928906804`, 0.934782901017194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 284}], {
             RGBColor[
             0.22933503139451644`, 0.3583760370494225, 0.936371662815918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 245}], {
             RGBColor[
             0.20866400795240445`, 0.3366494807931788, 0.9351944786109285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 288}], {
             RGBColor[
             0.2004754275788136, 0.3280427636345524, 0.9347281510725716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 296}], {
             RGBColor[
             0.18964632804218584`, 0.3166606934169896, 0.9341114498741778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 297}], {
             RGBColor[
             0.19203933424327527`, 0.319175894659691, 0.9342477280371944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 232}], {
             RGBColor[
             0.20954424282732975`, 0.33757466345683984`, 0.9352446066848648]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 245}], {
             RGBColor[
             0.2282116135363889, 0.3571952536517242, 0.9363076858308454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 264}], {
             RGBColor[
             0.2636953407278438, 0.39449090072818943`, 0.9383284316009286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 266}], {
             RGBColor[
             0.21466524015743277`, 0.342957156340762, 0.9355362399069774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 240}], {
             RGBColor[
             0.184219115333836, 0.3109563487553536, 0.933802378139279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 245}], {
             RGBColor[
             0.206575126823306, 0.3344539342837832, 0.9350755199208491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 288}], {
             RGBColor[
             0.19838654644971515`, 0.32584721712515685`, 0.9346091923824922]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 297}], {
             RGBColor[
             0.18995045311417683`, 0.3169803481502954, 0.934128769347115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 259}], {
             RGBColor[
             0.1952784533382303, 0.32258041420050104`, 0.9344321910778048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[
             0.2158656276199601, 0.3442188396728392, 0.9356046001971543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 249}], {
             RGBColor[
             0.2008059288288086, 0.3283901414032867, 0.934746972629826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 263}], {
             RGBColor[
             0.20202221841831886`, 0.32966853887907605`, 0.9348162385226094]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 274}], {
             RGBColor[
             0.43577020330018756`, 0.5515998272739158, 0.9490608562281224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 298}], {
             RGBColor[
             0.33431581918328446`, 0.4594951311953859, 0.9426878395174293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 260}], {
             RGBColor[
             0.2447992469285118, 0.3746299080635468, 0.9372523270133223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 267}], {
             RGBColor[
             0.21381850493226368`, 0.3420671839329953, 0.9354880195885366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 294}], {
             RGBColor[
             0.38374017735760657`, 0.49740352912178454`, 0.9465549709165739]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 256}], {
             RGBColor[
             0.8215013839374217, 0.16627463567534986`, 0.16822305558180195`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 269}], {
             RGBColor[
             0.8991197807384712, 0.5574407348110937, 0.260947978617189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 277}], {
             RGBColor[
             0.9090429254562429, 0.5906001950667261, 0.32616694372814004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 281}], {
             RGBColor[
             0.9017681191965876, 0.5885988435448176, 0.546493973651558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 293}], {
             RGBColor[
             0.8624167150274014, 0.41572511198283674`, 0.2048567143114029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 248}], {
             RGBColor[
             0.22976740900447992`, 0.35883049333181793`, 0.9363962860811601]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 258}], {
             RGBColor[
             0.28886880526886394`, 0.4180452286151569, 0.9398683740473033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 263}], {
             RGBColor[
             0.22373268173624067`, 0.3524876123490904, 0.9360526172908128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 285}], {
             RGBColor[
             0.21862787921736482`, 0.3471221412385783, 0.9357619063392415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 290}], {
             RGBColor[
             0.9662675720592777, 0.9068871357048387, 0.5776802589012907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 291}], {
             RGBColor[
             0.956499515277976, 0.9665294292639133, 0.9362543369482514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 250}], {
             RGBColor[
             0.18176798085569046`, 0.30838005100792065`, 0.933662789656877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 268}], {
             RGBColor[
             0.1929658134251674, 0.3201496830220325, 0.934300489656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 254}], {
             RGBColor[
             0.6530996726183891, 0.7197996840615158, 0.8998607275791879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 256}], {
             RGBColor[
             0.9026728062872424, 0.5639368365528598, 0.5114946297323817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 283}], {
             RGBColor[
             0.6466191425526432, 0.7139161177704824, 0.899457696684746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 279}], {
             RGBColor[
             0.21308524932289044`, 0.3412964857964532, 0.9354462617663373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 280}], {
             RGBColor[
             0.22575834254074034`, 0.3546167102889326, 0.9361679756769326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 264}], {
             RGBColor[
             0.26072622472382, 0.3913701715551329, 0.938159344836913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 288}], {
             RGBColor[
             0.2170539171587743, 0.34546780732004123`, 0.9356722715284729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 297}], {
             RGBColor[
             0.20861782382323596`, 0.3366009383451798, 0.9351918484930957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 270}], {
             RGBColor[
             0.19864447884335656`, 0.3261183204247322, 0.9346238812507333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 278}], {
             RGBColor[
             0.1925398971260588, 0.3197020179870163, 0.9342762343528525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 295}], {
             RGBColor[
             0.19068631113650653`, 0.3177537815878572, 0.9341706753728822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 251}], {
             RGBColor[
             0.24168185283923999`, 0.37135332922152087`, 0.9370747960317096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 270}], {
             RGBColor[
             0.20529778048290723`, 0.33311136229158844`, 0.935002776936428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 271}], {
             RGBColor[
             0.21019581629378764`, 0.33825950848223085`, 0.9352817128298629]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 278}], {
             RGBColor[
             0.19919319876560948`, 0.3266950598538726, 0.9346551300385472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 289}], {
             RGBColor[
             0.22060050259813557`, 0.34919549348331447`, 0.9358742443225416]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 295}], {
             RGBColor[
             0.1973396127760572, 0.3247468234547135, 0.9345495710585769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 285}], {
             RGBColor[
             0.21081919728396287`, 0.3389147214275427, 0.9353172134550438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 258}], {
             RGBColor[
             0.2738091064777124, 0.40221653034560445`, 0.9390107464799751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 263}], {
             RGBColor[
             0.20867298294508915`, 0.33665891407953785`, 0.9351949897234846]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 286}], {
             RGBColor[
             0.2141737173623244, 0.342440534718758, 0.9355082484109388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 270}], {
             RGBColor[
             0.24922321837913736`, 0.37927978255414485`, 0.9375042656427561]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 271}], {
             RGBColor[
             0.25412125419001774`, 0.38442792874478726`, 0.9377832015361911]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 278}], {
             RGBColor[
             0.24311863666183964`, 0.372863480116429, 0.9371566187448754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 282}], {
             RGBColor[
             0.363119718775744, 0.4867984505328162, 0.944436976695407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 289}], {
             RGBColor[
             0.26452594049436573`, 0.3953639137458709, 0.9383757330288698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 295}], {
             RGBColor[
             0.24126505067228732`, 0.3709152437172699, 0.9370510597649051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 268}], {
             RGBColor[
             0.22149590633125682`, 0.35013661957870057`, 0.9359252362405117]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 279}], {
             RGBColor[
             0.23730450403035436`, 0.36675245808343765`, 0.9368255124927507]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 280}], {
             RGBColor[
             0.2499775972482043, 0.3800726825759171, 0.937547226403346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 283}], {
             RGBColor[
             0.27188152915805053`, 0.4030951038026612, 0.9387946229216484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 283}], {
             RGBColor[
             0.3123013068939945, 0.44465097126766145`, 0.9411304437622906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 258}], {
             RGBColor[
             0.3530896957607064, 0.48025028048897034`, 0.9437195410822816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 286}], {
             RGBColor[
             0.2934543066453184, 0.4204742848621239, 0.9402170430132455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 269}], {
             RGBColor[
             0.8955465010984967, 0.5299749416771264, 0.25752620199850723`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 277}], {
             RGBColor[
             0.9054696458162683, 0.5631344019327589, 0.3227451671094582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 281}], {
             RGBColor[
             0.8981948395566131, 0.5611330504108505, 0.5430721970328762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 293}], {
             RGBColor[
             0.8588434353874268, 0.38825931884886955`, 0.2014349376927211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 267}], {
             RGBColor[
             0.19014093188722048`, 0.31718055341781604`, 0.9341396168314517]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 272}], {
             RGBColor[
             0.18158199985616474`, 0.30818457318554265`, 0.9336521983140883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 300}], {
             RGBColor[
             0.20486085687830097`, 0.33265212788059073`, 0.9349778947835161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 263}], {
             RGBColor[
             0.2750253960672227, 0.40349492782139373`, 0.9390800123727585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 286}], {
             RGBColor[
             0.28052613048445796`, 0.4092765484606139, 0.9393932710602128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 267}], {
             RGBColor[
             0.22718681650953165`, 0.35611812700061296`, 0.9362493251562173]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 287}], {
             RGBColor[
             0.25058425907026255`, 0.38071032261548143`, 0.9375817748966364]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 294}], {
             RGBColor[
             0.39710848893487455`, 0.5114544721894022, 0.9473162764842546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 300}], {
             RGBColor[
             0.24190674150061214`, 0.37158970146338766`, 0.9370876031082818]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 284}], {
             RGBColor[
             0.2428470796826115, 0.3725780565135533, 0.937141153976641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 292}], {
             RGBColor[
             0.5387777053242508, 0.6299185321853173, 0.9593474985432611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 286}], {
             RGBColor[
             0.2153900069518347, 0.3437189321945473, 0.9355775143037223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 288}], {
             RGBColor[
             0.2525376443502292, 0.38276345439650644`, 0.937693017298556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 276}], {
             RGBColor[
             0.23204484364859856`, 0.36122422154048306`, 0.93652598261498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 286}], {
             RGBColor[
             0.22180329067308052`, 0.3504597000112502, 0.9359427413240442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 272}], {
             RGBColor[
             0.18764714248222777`, 0.31455942263778813`, 0.9339975992140681]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 287}], {
             RGBColor[
             0.2196035170740144, 0.34814759848492993`, 0.9358174674718507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 300}], {
             RGBColor[
             0.210925999504364, 0.33902697733283615`, 0.935323295683496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 279}], {
             RGBColor[
             0.22085812887375872`, 0.34946627503344374`, 0.9358889157578143]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 280}], {
             RGBColor[
             0.23353122209160865`, 0.3627864995259231, 0.9366106296684096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 277}], {
             RGBColor[
             0.9830880426173179, 0.9543005010685027, 0.41547009014484526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 282}], {
             RGBColor[
             0.7068985223577822, 0.7386080961972126, 0.6497743968433352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 293}], {
             RGBColor[
             0.9364618321884765, 0.7794254179846133, 0.2941598607281082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 271}], {
             RGBColor[
             0.217737181833685, 0.3461859618148549, 0.9357111824409096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 278}], {
             RGBColor[
             0.20673456430550685`, 0.3346215131864966, 0.9350845996495938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 289}], {
             RGBColor[
             0.22814186813803294`, 0.35712194681593845`, 0.9363037139335881]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 295}], {
             RGBColor[
             0.20488097831595456`, 0.3326732767873375, 0.9349790406696236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 278}], {
             RGBColor[
             0.21163260011638724`, 0.339769659377139, 0.9353635355430288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 289}], {
             RGBColor[
             0.23303990394891333`, 0.36227009300658086`, 0.9365826498270231]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 295}], {
             RGBColor[
             0.20977901412683497`, 0.3378214229779799, 0.9352579765630585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 274}], {
             RGBColor[
             0.3509883555182567, 0.4717110997619036, 0.9438949792783465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 289}], {
             RGBColor[
             0.24118737083360547`, 0.370833597281629, 0.9370466360130092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 289}], {
             RGBColor[
             0.3532455749379125, 0.4740835804879391, 0.944023524585039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 281}], {
             RGBColor[
             0.9857363810754343, 0.9854586098022267, 0.7010160851792143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 282}], {
             RGBColor[
             0.7168216670755537, 0.7717675564528452, 0.7149933619542863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 293}], {
             RGBColor[
             0.946384976906248, 0.8125848782402458, 0.35937882583905917`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 295}], {
             RGBColor[
             0.1987763965986568, 0.3262569743496216, 0.9346313937717428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 280}], {
             RGBColor[
             0.24933981979070619`, 0.37940233803066026`, 0.9375109059206487]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 294}], {
             RGBColor[
             0.7572554970898742, 0.8088426757639791, 0.9389810177450694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 293}], {
             RGBColor[
             0.6701954566467123, 0.5968924733689558, 0.5936831325375491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 300}], {
             RGBColor[
             0.2343234420650949, 0.3636191729477046, 0.9366557454239152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 296}], {
             RGBColor[
             0.1980362372485557, 0.3254790199438521, 0.9345892427917222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 297}], {
             RGBColor[
             0.20042924344964513`, 0.3279942211865534, 0.9347255209547387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 291}], {
             RGBColor[
             0.9366428804635196, 0.8848865477710113, 0.6343132641384139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 297}], {
             RGBColor[
             0.18960014391301738`, 0.31661215096899065`, 0.934108819756345]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.032105813875877395`], {
             RGBColor[
             0.8186934053129894, 0.1446912815038851, 0.16553413207988746`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.032105813875877395`], {
             RGBColor[
             0.19859115798198185`, 0.32606227681868954`, 0.934620844706559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.032105813875877395`], {
             RGBColor[
             0.9542183694281502, 0.96537671539683, 0.9623805381832607]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.032105813875877395`], {
             RGBColor[
             0.2205376694136581, 0.34912945182257465`, 0.935870666065639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.032105813875877395`], {
             RGBColor[
             0.9710126878169619, 0.9138811308413543, 0.3418901952738247]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.032105813875877395`], {
             RGBColor[
             0.2105950138195758, 0.3386790903924193, 0.9353044465383967]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.032105813875877395`], {
             RGBColor[
             0.9383196861766793, 0.9535195034595876, 0.9892928618873055]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.032105813875877395`], {
             RGBColor[
             0.2044682273202984, 0.33223944932097826`, 0.9349555351110312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.032105813875877395`], {
             RGBColor[
             0.19896010530687766`, 0.32645006384976655`, 0.9346418557109033]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.032105813875877395`], {
             RGBColor[
             0.19040293767796423`, 0.3174559381160143, 0.9341545376736317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.032105813875877395`], {
             RGBColor[
             0.5318148081413353, 0.630790245090044, 0.9562855562801685]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.032105813875877395`], {
             RGBColor[
             0.42962012936485927`, 0.5465370955454517, 0.948595992638333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.032105813875877395`], {
             RGBColor[
             0.33328873930237535`, 0.463099687229773, 0.9424578416460552]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.032105813875877395`], {
             RGBColor[
             0.1801938510546308, 0.30672554078141306`, 0.9335731452934231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.032105813875877395`], {
             RGBColor[
             0.2583760710911756, 0.38890001107887695`, 0.9380255070642746]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.032105813875877395`], {
             RGBColor[
             0.24679037784549854`, 0.37672271290229153`, 0.9373657189734305]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.032105813875877395`], {
             RGBColor[
             0.7036631405833589, 0.768426260552445, 0.9710982238135836]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.032105813875877395`], {
             RGBColor[
             0.19997475001447043`, 0.3275165197696367, 0.9346996382259684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.032105813875877395`], {
             RGBColor[
             0.18771789764902583`, 0.31463379080422954`, 0.9340016286161444]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.032105813875877395`], {
             RGBColor[
             0.21900416978762977`, 0.3475176464861269, 0.9357833355305459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.032105813875877395`], {
             RGBColor[
             0.19357781768564236`, 0.320792938303103, 0.9343353423932549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.032105813875877395`], {
             RGBColor[
             0.18854143418810532`, 0.3154993799220345, 0.9340485278037318]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.032105813875877395`], {
             RGBColor[
             0.989346654985427, 0.9898625823050647, 0.82621702707199]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.032105813875877395`], {
             RGBColor[
             0.9237640134240451, 0.7354567479025522, 0.2575169395936321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.032105813875877395`], {
             RGBColor[
             0.1911156300253715, 0.31820502296044406`, 0.9341951244484827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.032105813875877395`], {
             RGBColor[
             0.2290956026577889, 0.35812438226646315`, 0.9363580277035645]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.032105813875877395`], {
             RGBColor[
             0.9698415036520304, 0.9099304516459211, 0.33734036595263717`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.032105813875877395`], {
             RGBColor[
             0.18347004528514485`, 0.31016902864039503`, 0.9337597197081559]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.032105813875877395`], {
             RGBColor[
             0.19525519293228838`, 0.32255596603906117`, 0.934430866432097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.032105813875877395`], {
             RGBColor[
             0.24929644188312317`, 0.37935674509947226`, 0.9375084356129837]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.032105813875877395`], {
             RGBColor[
             0.41964854701834464`, 0.537900212103202, 0.9479606122287372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.032105813875877395`], {
             RGBColor[
             0.9876761626712638, 0.9891717908034641, 0.8539014078132029]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.032105813875877395`], {
             RGBColor[
             0.20050642775524471`, 0.3280753467855062, 0.9347299164867587]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.032105813875877395`], {
             RGBColor[
             0.1836929464736069, 0.31040331192222026`, 0.933772413601086]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.032105813875877395`], {
             RGBColor[
             0.20639345636736367`, 0.33426298711601565`, 0.9350651740571405]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.032105813875877395`], {
             RGBColor[
             0.18133311757286624`, 0.3079229821257478, 0.9336380248362428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.032105813875877395`], {
             RGBColor[
             0.22656828106141946`, 0.3554680070272346, 0.9362141004774884]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.032105813875877395`], {
             RGBColor[
             0.18611948239069784`, 0.312953755022346, 0.9339106012318261]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.032105813875877395`], {
             RGBColor[
             0.20172422019829714`, 0.3293553238556548, 0.934799267964828]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.032105813875877395`], {
             RGBColor[
             0.6892336433588957, 0.7571538276524538, 0.9696600263815672]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.032105813875877395`], {
             RGBColor[
             0.1885946642534308, 0.31555532809567266`, 0.9340515591772053]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.032105813875877395`], {
             RGBColor[
             0.8376047344232163, 0.2900520440423452, 0.18364364219313192`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.032105813875877395`], {
             RGBColor[
             0.2255865897625529, 0.3544361872293025, 0.9361581946103001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.032105813875877395`], {
             RGBColor[
             0.31621931418873805`, 0.44831500913059213`, 0.9413701929717141]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.032105813875877395`], {
             RGBColor[
             0.29993474933268105`, 0.43258081688308847`, 0.9403922123095734]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.032105813875877395`], {
             RGBColor[
             0.2047087295239663, 0.33249223238575365`, 0.9349692313557391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.032105813875877395`], {
             RGBColor[
             0.18409960782193097`, 0.31083073878312756`, 0.9337955723632715]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.032105813875877395`], {
             RGBColor[
             0.1928098846058197, 0.31998579194643995`, 0.9342916097404141]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.032105813875877395`], {
             RGBColor[
             0.20962180710681122`, 0.3376561884324342, 0.9352490238558351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.032105813875877395`], {
             RGBColor[
             0.1818234123124711, 0.30843831298355445`, 0.9336659463963373]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.032105813875877395`], {
             RGBColor[
             0.8112967405816618, 0.8525104469167772, 0.981826135168235]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.032105813875877395`], {
             RGBColor[
             0.1987330571876369, 0.3262114218807623, 0.9346289256564001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.032105813875877395`], {
             RGBColor[
             0.21587739356825456`, 0.3442312064305009, 0.9356052702505034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.032105813875877395`], {
             RGBColor[
             0.24403688677483204`, 0.37382861920560384`, 0.937208911730381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.032105813875877395`], {
             RGBColor[
             0.20213692733288047`, 0.32978910522124555`, 0.9348227710255971]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.032105813875877395`], {
             RGBColor[
             0.19935669202797407`, 0.3268669016386893, 0.9346644407379722]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.032105813875877395`], {
             RGBColor[
             0.17967566298483006`, 0.30618089226503126`, 0.9335436352494385]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.032105813875877395`], {
             RGBColor[
             0.19114091674596853`, 0.31823160090706226`, 0.9341965644898124]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.032105813875877395`], {
             RGBColor[
             0.985007685890186, 0.9880683070777632, 0.8981249738722014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.032105813875877395`], {
             RGBColor[
             0.28726741181117993`, 0.4192666419924039, 0.9396708261773704]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.032105813875877395`], {
             RGBColor[
             0.2772592389822082, 0.4087474177943471, 0.9391008755405253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.032105813875877395`], {
             RGBColor[
             0.20167701950442632`, 0.3293057129336997, 0.9347965799551393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.032105813875877395`], {
             RGBColor[
             0.18288267188311363`, 0.3095516619532356, 0.9337262696618512]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.032105813875877395`], {
             RGBColor[
             0.2353045398184947, 0.3646503688917182, 0.9367116174895672]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.032105813875877395`], {
             RGBColor[
             0.3774633879291902, 0.5013615475879224, 0.9452726111944477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.032105813875877395`], {
             RGBColor[
             0.3863417480503173, 0.5090515368854881, 0.9458383324505404]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.032105813875877395`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.032105813875877395`], {
             RGBColor[
             0.8768566069289154, 0.9046456729993274, 0.9881165600196555]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.032105813875877395`], {
             RGBColor[
             0.20756886290590398`, 0.3354984139131004, 0.9351321117206522]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.032105813875877395`], {
             RGBColor[
             0.20976983040282712`, 0.33781177030176596`, 0.9352574535635624]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.032105813875877395`], {
             RGBColor[
             0.22331684544677569`, 0.35205054204331915`, 0.9360289360293025]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.032105813875877395`], {
             RGBColor[
             0.8294154563220671, 0.22710566399236717`, 0.1758015802350048]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.032105813875877395`], {
             RGBColor[
             0.1826688110543663, 0.3093268806626624, 0.9337140906040328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.032105813875877395`], {
             RGBColor[
             0.20590138873724428`, 0.3337457928378705, 0.935037151533554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.032105813875877395`], {
             RGBColor[
             0.3329293714790703, 0.46278842088357813`, 0.9424349430461306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.032105813875877395`], {
             RGBColor[
             0.3269177544061254, 0.4575814603276529, 0.9420518881221068]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.032105813875877395`], {
             RGBColor[
             0.4137826929511934, 0.5328195041366336, 0.9475868451945494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.032105813875877395`], {
             RGBColor[
             0.19413140389541048`, 0.3213747925089622, 0.9343668683089438]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.032105813875877395`], {
             RGBColor[
             0.18314084159618357`, 0.3098230146905773, 0.9337409720450827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.032105813875877395`], {
             RGBColor[
             0.9788084084452291, 0.9401779270427488, 0.37217509781633024`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.032105813875877395`], {
             RGBColor[
             0.8894648943465696, 0.5909677260051436, 0.2294791371904563]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.032105813875877395`], {
             RGBColor[
             0.6134396494628491, 0.6970569684320459, 0.962711362790644]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.032105813875877395`], {
             RGBColor[
             0.846552585818907, 0.35882915084310774`, 0.19221211479479816`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.032105813875877395`], {
             RGBColor[
             0.18746791982634672`, 0.31437104826308443`, 0.9339873927489519]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.032105813875877395`], {
             RGBColor[
             0.23214849009490668`, 0.36133316052711717`, 0.9365318851267661]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.032105813875877395`], {
             RGBColor[
             0.5941770672605392, 0.6814187364307716, 0.9611949417585145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.032105813875877395`], {
             RGBColor[
             0.9931480500222558, 0.9877526967730439, 0.4955857141352578]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.032105813875877395`], {
             RGBColor[
             0.22285845764454237`, 0.35156874739970667`, 0.9360028315220893]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.032105813875877395`], {
             RGBColor[
             0.3807443443279537, 0.5042033471148679, 0.9454816708349412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.032105813875877395`], {
             RGBColor[
             0.21567607897691587`, 0.34401961203092163`, 0.935593805682345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.032105813875877395`], {
             RGBColor[
             0.49015879412300467`, 0.5969720163279171, 0.9530062422656385]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.032105813875877395`], {
             RGBColor[
             0.8315546894535105, 0.24354874725857717`, 0.17785011229759332`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.032105813875877395`], {
             RGBColor[
             0.24113006344271598`, 0.3707733635803057, 0.9370433724418767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.032105813875877395`], {
             RGBColor[
             0.796888814031874, 0.8412548651917855, 0.9803900876994809]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.032105813875877395`], {
             RGBColor[
             0.28755638833203334`, 0.4195703746379904, 0.9396872829627306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.032105813875877395`], {
             RGBColor[
             0.20095046543520778`, 0.32854205854076235`, 0.9347552037757377]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.032105813875877395`], {
             RGBColor[
             0.44885816070930806`, 0.563200111364443, 0.9498218229840781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.032105813875877395`], {
             RGBColor[
             0.1790520430393593, 0.3055254281625532, 0.9335081210161069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.032105813875877395`], {
             RGBColor[
             0.19567419878950365`, 0.3229963677615002, 0.9344547281958019]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.032105813875877395`], {
             RGBColor[
             0.1806628381309981, 0.3072184759341732, 0.933599853413618]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.032105813875877395`], {
             RGBColor[
             0.6473280227603806, 0.724416838346381, 0.9654832657505968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.032105813875877395`], {
             RGBColor[
             0.19219534584531597`, 0.31933987274514264`, 0.9342566126671321]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.032105813875877395`], {
             RGBColor[
             0.4213296380105047, 0.5393562886265211, 0.9480677298602272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.032105813875877395`], {
             RGBColor[
             0.3350878162698179, 0.46465795727473413`, 0.9425724772395593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.032105813875877395`], {
             RGBColor[
             0.28384023029084227`, 0.41566445691867016`, 0.9394756532598479]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.032105813875877395`], {
             RGBColor[
             0.861860606843299, 0.8926882695866354, 0.9866862281444021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.032105813875877395`], {
             RGBColor[
             0.40847529455142584`, 0.5282225024003548, 0.9472486624616643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.032105813875877395`], {
             RGBColor[
             0.24068546665888524`, 0.3703060641714354, 0.9370180533127597]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.032105813875877395`], {
             RGBColor[
             0.9928111618057213, 0.9912952449090205, 0.7688011832034702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.032105813875877395`], {
             RGBColor[
             0.18591721951216156`, 0.3127411639127972, 0.9338990826601146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.032105813875877395`], {
             RGBColor[
             0.6142037164471443, 0.6976772724307221, 0.9627715129425172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.032105813875877395`], {
             RGBColor[
             0.18923133529375677`, 0.3162245097263307, 0.9340878166510814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.032105813875877395`], {
             RGBColor[
             0.2676326072490897, 0.3986292174791347, 0.9385526531046497]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.032105813875877395`], {
             RGBColor[
             0.23913206195702244`, 0.3686733373382309, 0.9369295892130448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.032105813875877395`], {
             RGBColor[
             0.3517287364030146, 0.47907148589714393`, 0.9436328219554587]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.032105813875877395`], {
             RGBColor[
             0.2873518174774419, 0.41935535769927346`, 0.9396756329551971]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.032105813875877395`], {
             RGBColor[
             0.1855098238772711, 0.3123129652701522, 0.9338758820813954]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.032105813875877395`], {
             RGBColor[
             0.1887209958010121, 0.3156881105620633, 0.9340587535719493]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.032105813875877395`], {
             RGBColor[
             0.18085158366002294`, 0.307416859452336, 0.933610602192272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.032105813875877395`], {
             RGBColor[
             0.27909030860477735`, 0.41067198806418675`, 0.939205152246706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.032105813875877395`], {
             RGBColor[
             0.22544944565233713`, 0.35429204007402687`, 0.9361503844561099]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.032105813875877395`], {
             RGBColor[
             0.18504035865818397`, 0.31181952755907755`, 0.93384914673168]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.032105813875877395`], {
             RGBColor[
             0.19860317371820202`, 0.3260749061192986, 0.9346215289849611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.032105813875877395`], {
             RGBColor[
             0.1859244664032461, 0.3127487808548065, 0.9338994953598411]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.032105813875877395`], {
             RGBColor[
             0.8351944719959239, 0.27152571084244637`, 0.18133557217075477`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.032105813875877395`], {
             RGBColor[
             0.22348836128871713`, 0.3522308160679321, 0.9360387036027661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.032105813875877395`], {
             RGBColor[
             0.34883524619319184`, 0.47656529010844195`, 0.9434484513179017]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.032105813875877395`], {
             RGBColor[
             0.8449402545684014, 0.34643606632366236`, 0.19066814456844627`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.032105813875877395`], {
             RGBColor[
             0.18908769389738214`, 0.3160735335113504, 0.9340796364860563]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.032105813875877395`], {
             RGBColor[
             0.9118031822514008, 0.6880360380137298, 0.24789297407533079`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.032105813875877395`], {
             RGBColor[
             0.22940782651350908`, 0.3584525493349609, 0.9363758083902539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.032105813875877395`], {
             RGBColor[
             0.19689631111946682`, 0.3242808853066886, 0.9345243256850401]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.032105813875877395`], {
             RGBColor[
             0.18528931800943133`, 0.31208119962217307`, 0.9338633245984311]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.032105813875877395`], {
             RGBColor[
             0.24479905803441923`, 0.3746297095238789, 0.9372523162560832]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.032105813875877395`], {
             RGBColor[
             0.21307650899259664`, 0.34128729915514544`, 0.9354457640174572]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.032105813875877395`], {
             RGBColor[
             0.39261549520966454`, 0.5144855413472138, 0.9462380900718772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.032105813875877395`], {
             RGBColor[
             0.26153416243522165`, 0.3922193653160256, 0.9382053556943405]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.032105813875877395`], {
             RGBColor[
             0.231287806205471, 0.36042852718880986`, 0.9364828704525304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.032105813875877395`], {
             RGBColor[
             0.4407231525670485, 0.5561539761890157, 0.9493034674587586]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.032105813875877395`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.032105813875877395`], {
             RGBColor[
             0.2938477713702168, 0.42618301710784506`, 0.940045567919488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.032105813875877395`], {
             RGBColor[
             0.8299355921400753, 0.23110365581454728`, 0.17629966288173887`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.032105813875877395`], {
             RGBColor[
             0.3068945586163886, 0.4398960177176607, 0.9407885631521654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.032105813875877395`], {
             RGBColor[
             0.19763991012936863`, 0.32506245501299574`, 0.9345666725485978]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.032105813875877395`], {
             RGBColor[
             0.8649038628242013, 0.8951148792988238, 0.9869764966166072]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.032105813875877395`], {
             RGBColor[
             0.20002902465321373`, 0.3275735658561667, 0.9347027290863527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.032105813875877395`], {
             RGBColor[
             0.21339775345539977`, 0.34162494745362687`, 0.9354640584143752]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.032105813875877395`], {
             RGBColor[
             0.2462972527349853, 0.37620440714520426`, 0.9373376362279]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.032105813875877395`], {
             RGBColor[
             0.895503807139292, 0.6183890185729798, 0.2345181540520019]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.032105813875877395`], {
             RGBColor[
             0.9074094141907081, 0.6706162117894943, 0.24435764515870567`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.032105813875877395`], {
             RGBColor[
             0.5978280581771518, 0.684382775332144, 0.9614823611374906]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.032105813875877395`], {
             RGBColor[
             0.1825195240294396, 0.3091699705341204, 0.9337055889288136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.032105813875877395`], {
             RGBColor[
             0.22106916700115545`, 0.3496880894859278, 0.9359009340669666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.032105813875877395`], {
             RGBColor[
             0.4972976140125026, 0.6027676319143825, 0.9535682363176986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.032105813875877395`], {
             RGBColor[
             0.9263138375757084, 0.7455659509853682, 0.2595685879581257]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.032105813875877395`], {
             RGBColor[
             0.3944915237120784, 0.5161104629440706, 0.9463576289491441]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.032105813875877395`], {
             RGBColor[
             0.18253809113335498`, 0.30918948573755783`, 0.933706646297914]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.032105813875877395`], {
             RGBColor[
             0.19294565339664288`, 0.32012849355383366`, 0.9342993415721996]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.032105813875877395`], {
             RGBColor[
             0.29124080035179, 0.42344292527596916`, 0.9398971047766567]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.032105813875877395`], {
             RGBColor[
             0.19576440547633542`, 0.32309118070879467`, 0.9344598653331682]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.032105813875877395`], {
             RGBColor[
             0.2016546493170191, 0.3292822004483829, 0.9347953060060602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.032105813875877395`], {
             RGBColor[
             0.9913482769712819, 0.9906903044355545, 0.7930449707347249]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.032105813875877395`], {
             RGBColor[
             0.6211503872091352, 0.7033168926992579, 0.9633183803113946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.032105813875877395`], {
             RGBColor[
             0.18196114135351968`, 0.30858307493822207`, 0.9336737898614731]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.032105813875877395`], {
             RGBColor[
             0.21779424853057935`, 0.34624594253152846`, 0.935714432304875]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.032105813875877395`], {
             RGBColor[
             0.18609439165410657`, 0.312927383067344, 0.9339091723514956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.032105813875877395`], {
             RGBColor[
             0.9076820231617462, 0.6716970155181059, 0.2445769927357579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.032105813875877395`], {
             RGBColor[
             0.4004114204648772, 0.5212379799686826, 0.9467348395354733]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.032105813875877395`], {
             RGBColor[
             0.6047389625257771, 0.6899933588150511, 0.9620264128432912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.032105813875877395`], {
             RGBColor[
             0.19757646601375403`, 0.32499577122489554`, 0.9345630595000708]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.032105813875877395`], {
             RGBColor[
             0.17914809400855325`, 0.30562638382115925`, 0.9335135909767078]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.032105813875877395`], {
             RGBColor[
             0.19058407149220488`, 0.3176463212393284, 0.9341648529763892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.032105813875877395`], {
             RGBColor[
             0.20128694378722742`, 0.32889571862269473`, 0.9347743657201101]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.032105813875877395`], {
             RGBColor[
             0.23320476894069225`, 0.36244337656598474`, 0.9365920386444091]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.032105813875877395`], {
             RGBColor[
             0.18260859612989327`, 0.30926359095919453`, 0.9337106614531641]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.032105813875877395`], {
             RGBColor[
             0.19419263806779313`, 0.3214391535066072, 0.9343703555044731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.032105813875877395`], {
             RGBColor[
             0.29197171960673096`, 0.42421116775586953`, 0.9399387295469274]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.032105813875877395`], {
             RGBColor[
             0.25901133304362195`, 0.3895677116688322, 0.9380616842926806]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.032105813875877395`], {
             RGBColor[
             0.5227567642523288, 0.6234365170007214, 0.9555724738845179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.032105813875877395`], {
             RGBColor[
             0.19488460571983207`, 0.32216645538218325`, 0.9344097620385824]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.032105813875877395`], {
             RGBColor[
             0.9862939640410388, 0.9654284637594515, 0.4012550677774902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.032105813875877395`], {
             RGBColor[
             0.2543436096659436, 0.38466163844813683`, 0.9377958643515997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.032105813875877395`], {
             RGBColor[
             0.19274031574857725`, 0.3199126706665578, 0.9342876478969121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.032105813875877395`], {
             RGBColor[
             0.1914897805011185, 0.3185982788329645, 0.9342164317645705]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.032105813875877395`], {
             RGBColor[
             0.5295564396500168, 0.6289567998104505, 0.9561077692398556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.032105813875877395`], {
             RGBColor[
             0.19311599281626868`, 0.32030753108400334`, 0.9343090421501528]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.032105813875877395`], {
             RGBColor[
             0.22474017350644473`, 0.35354655007824254`, 0.9361099924566755]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.032105813875877395`], {
             RGBColor[
             0.35586441424032067`, 0.4826536021746064, 0.9438963436902155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.032105813875877395`], {
             RGBColor[
             0.21583585429987417`, 0.3441875460256914, 0.935602904650621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.032105813875877395`], {
             RGBColor[
             0.2044144915577996, 0.3321829696275479, 0.9349524749388519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.032105813875877395`], {
             RGBColor[
             0.2273767118965443, 0.3563177190924262, 0.9362601394175826]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.032105813875877395`], {
             RGBColor[
             0.3306172943235091, 0.4607858158598078, 0.9422876195342679]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.032105813875877395`], {
             RGBColor[
             0.27956374695486264`, 0.41116960178785156`, 0.939232113860354]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.032105813875877395`], {
             RGBColor[
             0.6860055424687634, 0.754632010702607, 0.9693382794531569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.032105813875877395`], {
             RGBColor[
             0.18372407711397143`, 0.31043603219904004`, 0.9337741864450011]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.032105813875877395`], {
             RGBColor[
             0.2030597206401025, 0.3307590194956109, 0.934875322739293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.032105813875877395`], {
             RGBColor[
             0.9863417120240653, 0.9886199611670301, 0.8760167084848537]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.032105813875877395`], {
             RGBColor[
             0.964591061095168, 0.9731126518583681, 0.9448222768222637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.032105813875877395`], {
             RGBColor[
             0.19839476243792764`, 0.32585585264969186`, 0.9346096602708663]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.032105813875877395`], {
             RGBColor[
             0.3655703148691659, 0.4910603654665621, 0.9445147950956946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.032105813875877395`], {
             RGBColor[
             0.8453640923839973, 0.3496938695012485, 0.19107401213931735`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.032105813875877395`], {
             RGBColor[
             0.8665707356341262, 0.4870106983585556, 0.21037568997361125`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.032105813875877395`], {
             RGBColor[
             0.9371250918628792, 0.9526285769763242, 0.9913149984604726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.032105813875877395`], {
             RGBColor[
             0.4836083421786542, 0.5916540643449961, 0.9524905666934831]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.032105813875877395`], {
             RGBColor[
             0.3723597127044757, 0.4969410006264502, 0.9449474095221317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.032105813875877395`], {
             RGBColor[
             0.22242260484653656`, 0.35111063847433904`, 0.9359780103500293]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.032105813875877395`], {
             RGBColor[
             0.18528775379377113`, 0.3120795555323372, 0.9338632355186633]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.032105813875877395`], {
             RGBColor[
             0.18931653926981418`, 0.3163140645074111, 0.9340926688914699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.032105813875877395`], {
             RGBColor[
             0.1804556557285978, 0.30700071409312746`, 0.9335880546823002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.032105813875877395`], {
             RGBColor[
             0.4716790509924657, 0.5819693283516046, 0.9515514491928728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.032105813875877395`], {
             RGBColor[
             0.2707327274798912, 0.4018876404006824, 0.9387292003655769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.032105813875877395`], {
             RGBColor[
             0.23336863550083925`, 0.36261561071043924`, 0.9366013706025906]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.032105813875877395`], {
             RGBColor[
             0.20237506472464956`, 0.3300394027187775, 0.9348363325977657]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.032105813875877395`], {
             RGBColor[
             0.20083038530367384`, 0.32841584670900015`, 0.9347483653898895]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.032105813875877395`], {
             RGBColor[
             0.22474171532416531`, 0.3535481706264238, 0.9361100802609137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.032105813875877395`], {
             RGBColor[
             0.8664637178535413, 0.48652475561155717`, 0.21028639171424535`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.032105813875877395`], {
             RGBColor[
             0.20003824461178885`, 0.32758325661720833`, 0.9347032541493537]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.032105813875877395`], {
             RGBColor[
             0.9671895696970209, 0.9750506153189628, 0.9404236795589124]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.032105813875877395`], {
             RGBColor[
             0.18433414396946993`, 0.31107725114464163`, 0.9338089288499086]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.032105813875877395`], {
             RGBColor[
             0.33308943974472227`, 0.4629270639700209, 0.9424451424544752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.032105813875877395`], {
             RGBColor[
             0.1861956076915163, 0.31303376754012907`, 0.9339149364550904]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.032105813875877395`], {
             RGBColor[
             0.2214255710569613, 0.35006269274590207`, 0.9359212307506922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.032105813875877395`], {
             RGBColor[
             0.1814903715451621, 0.30808826602110845`, 0.9336469802173286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.032105813875877395`], {
             RGBColor[
             0.20866772558178895`, 0.33665338825737323`, 0.9351946903244223]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.032105813875877395`], {
             RGBColor[
             0.2275966301752516, 0.35654886714697176`, 0.936272663438215]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.032105813875877395`], {
             RGBColor[
             0.9862571365941499, 0.9885849870532707, 0.8774183422327487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.032105813875877395`], {
             RGBColor[
             0.952704487454567, 0.8501960835922951, 0.28080312431882476`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.032105813875877395`], {
             RGBColor[
             0.426257062503514, 0.5436241760628097, 0.9483817009917713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.032105813875877395`], {
             RGBColor[
             0.2177123475199571, 0.3461598593765405, 0.9357097681634818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.032105813875877395`], {
             RGBColor[
             0.19208551837244375`, 0.31922443710768994`, 0.9342503581550272]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.032105813875877395`], {
             RGBColor[
             0.23118072954041266`, 0.36031598282478083`, 0.9364767725948611]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.032105813875877395`], {
             RGBColor[
             0.18790775611424687`, 0.3148333440888988, 0.9340124407748683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.032105813875877395`], {
             RGBColor[
             0.20539561179114207`, 0.3332141891994065, 0.9350083482847035]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.032105813875877395`], {
             RGBColor[
             0.1941551643020383, 0.3213997662028249, 0.9343682214289508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.032105813875877395`], {
             RGBColor[
             0.40849384697781144`, 0.528238571579618, 0.9472498446058684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.032105813875877395`], {
             RGBColor[
             0.23143093535124384`, 0.3605789649959291, 0.9364910214456416]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.032105813875877395`], {
             RGBColor[
             0.8250746635773962, 0.19374042880931708`, 0.17164483220048377`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.032105813875877395`], {
             RGBColor[
             0.1874435235211163, 0.31434540619947215`, 0.9339860034154601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.032105813875877395`], {
             RGBColor[
             0.23757609093788187`, 0.36703791314285356`, 0.9368409789653577]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.032105813875877395`], {
             RGBColor[
             0.18053047455342514`, 0.3070793534218085, 0.9335923155036896]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.032105813875877395`], {
             RGBColor[
             0.986124206873734, 0.9885300171977407, 0.8796213317111282]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.032105813875877395`], {
             RGBColor[
             0.18088209567567362`, 0.3074489295153584, 0.9336123398064248]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.032105813875877395`], {
             RGBColor[
             0.9874175082770378, 0.9890648305643368, 0.8581879805016432]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.032105813875877395`], {
             RGBColor[
             0.1895037720729246, 0.31651085805472556`, 0.934103331522621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.032105813875877395`], {
             RGBColor[
             0.22524249753236514`, 0.35407452447866766`, 0.9361385990668298]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.032105813875877395`], {
             RGBColor[
             0.1844498116639085, 0.31119882522525194`, 0.9338155159539919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.032105813875877395`], {
             RGBColor[
             0.19775641494300986`, 0.32518490895896446`, 0.9345733073253814]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.032105813875877395`], {
             RGBColor[
             0.22195872707107797`, 0.35062307352078237`, 0.9359515931969625]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.032105813875877395`], {
             RGBColor[
             0.20745669335557887`, 0.3353805166037485, 0.9351257238307011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.032105813875877395`], {
             RGBColor[
             0.18265386603570732`, 0.30931117250048296`, 0.9337132395073293]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.032105813875877395`], {
             RGBColor[
             0.28560729073547014`, 0.4175217494840773, 0.9395762847380378]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.032105813875877395`], {
             RGBColor[
             0.23794228148785246`, 0.3674228026286945, 0.9368618329754481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.032105813875877395`], {
             RGBColor[
             0.19184993915614282`, 0.3189768284147727, 0.9342369422671671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.032105813875877395`], {
             RGBColor[
             0.31878183695974033`, 0.45053453755869494`, 0.9415334746567325]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.032105813875877395`], {
             RGBColor[
             0.3660178719215669, 0.49144801689048034`, 0.9445433130353144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.032105813875877395`], {
             RGBColor[
             0.817928104297447, 0.13880884254138265`, 0.16480127896312016`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.032105813875877395`], {
             RGBColor[
             0.18407578926115742`, 0.31080570396557056`, 0.9337942159314718]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.032105813875877395`], {
             RGBColor[
             0.340161519599846, 0.46905254408746033`, 0.942895769129249]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.032105813875877395`], {
             RGBColor[
             0.18516129488531852`, 0.3119466392015956, 0.9338560338709061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.032105813875877395`], {
             RGBColor[
             0.25816755850577977`, 0.38868085113116446`, 0.938013632581003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.032105813875877395`], {
             RGBColor[
             0.24473644409614725`, 0.3745638983048021, 0.9372487504849276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.032105813875877395`], {
             RGBColor[
             0.3038398335581257, 0.4366853080006712, 0.9406146010791581]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.032105813875877395`], {
             RGBColor[
             0.20988927253459944`, 0.3379373115553272, 0.935264255616268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.032105813875877395`], {
             RGBColor[
             0.2962099519152749, 0.42866581863159803`, 0.9401800906069961]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.032105813875877395`], {
             RGBColor[
             0.22271583997709107`, 0.35141884718873295`, 0.9359947096569118]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.032105813875877395`], {
             RGBColor[
             0.1981497507744529, 0.3255983298567432, 0.9345957072190938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.032105813875877395`], {
             RGBColor[
             0.1962060745132835, 0.32355540287006146`, 0.9344850177314316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.032105813875877395`], {
             RGBColor[
             0.20504953117466115`, 0.3328504365287066, 0.9349886395055752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.032105813875877395`], {
             RGBColor[
             0.9731648978995463, 0.9211410408128702, 0.3502511250338943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.032105813875877395`], {
             RGBColor[
             0.2128391460228046, 0.3410378156242125, 0.9354322465474746]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.032105813875877395`], {
             RGBColor[
             0.2226352176445654, 0.3513341080054973, 0.9359901183343445]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.032105813875877395`], {
             RGBColor[
             0.17908821045117204`, 0.30556344240551475`, 0.9335101806967048]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.032105813875877395`], {
             RGBColor[
             0.2389301514139497, 0.3684611165555936, 0.9369180907063167]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.032105813875877395`], {
             RGBColor[
             0.46304655962256364`, 0.5749610829682137, 0.9508718678503764]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.032105813875877395`], {
             RGBColor[
             0.1801747671672662, 0.30670548240580453`, 0.9335720584942697]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.032105813875877395`], {
             RGBColor[
             0.24137384732010603`, 0.3710295958922332, 0.9370572555730482]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.032105813875877395`], {
             RGBColor[
             0.9930111873350895, 0.9874599613241353, 0.4806890552557963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.032105813875877395`], {
             RGBColor[
             0.2006299825882091, 0.3282052107487807, 0.934736952751713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.032105813875877395`], {
             RGBColor[
             0.23666672657285628`, 0.3660821135381808, 0.9367891920100534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.032105813875877395`], {
             RGBColor[
             0.2620129130085561, 0.39272256252313964`, 0.938232619831244]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.032105813875877395`], {
             RGBColor[
             0.9784615748157791, 0.9834572582803182, 0.9213431151026323]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.032105813875877395`], {
             RGBColor[
             0.4406321468160179, 0.5560751515815551, 0.9492976686527762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.032105813875877395`], {
             RGBColor[
             0.3058207768282486, 0.438767404976628, 0.9407274128678487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.032105813875877395`], {
             RGBColor[
             0.24095771526907575`, 0.3705922147223045, 0.9370335574683543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.032105813875877395`], {
             RGBColor[
             0.1996796674968478, 0.327206369334303, 0.9346828337131252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.032105813875877395`], {
             RGBColor[
             0.22089074136906994`, 0.34950055283376746`, 0.9358907729911765]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.032105813875877395`], {
             RGBColor[
             0.2430009596347453, 0.3727397940997984, 0.9371499172122699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.032105813875877395`], {
             RGBColor[
             0.20886533678518346`, 0.33686109016141486`, 0.9352059439901159]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.032105813875877395`], {
             RGBColor[
             0.2434445902532613, 0.3732060780076645, 0.9371751813197018]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.032105813875877395`], {
             RGBColor[
             0.9464109372448213, 0.8252442542119368, 0.27573918609145315`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.032105813875877395`], {
             RGBColor[
             0.926874823682218, 0.9445288413300859, 0.9928873421853748]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.032105813875877395`], {
             RGBColor[
             0.773715577090376, 0.8231517563699634, 0.978080396007364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.032105813875877395`], {
             RGBColor[
             0.8997587664774066, 0.6377097951563564, 0.23806859642232206`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.032105813875877395`], {
             RGBColor[
             0.5360494193639693, 0.63422809324764, 0.9566189203875064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.032105813875877395`], {
             RGBColor[
             0.19692281060910452`, 0.3243087379504625, 0.9345258347917725]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.032105813875877395`], {
             RGBColor[
             0.18720713771192796`, 0.31409694972628927`, 0.9339725415933283]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.032105813875877395`], {
             RGBColor[
             0.19199315011410678`, 0.319127352211692, 0.9342450979193615]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.032105813875877395`], {
             RGBColor[
             0.2601377913887575, 0.39075169081115385`, 0.9381258344289902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.032105813875877395`], {
             RGBColor[
             0.8186938987840391, 0.1446950745386128, 0.16553460462832187`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.032105813875877395`], {
             RGBColor[
             0.2256459244954445, 0.3544985517956109, 0.9361615736355604]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{3.8349504055390835`*^9, 3.8350088235913897`*^9, 
  3.8350238911145*^9},
 CellLabel->
  "Out[152]=",ExpressionUUID->"6971b768-5f15-4385-b4e8-7f69f1b6752a"]
}, Open  ]],

Cell["Estimated with Max-Min Deviation v Calculated: (r = 3)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 3.8349503922098827`*^9}, {3.8349504781120467`*^9, 
  3.8349504928656063`*^9}},ExpressionUUID->"891a11fd-80f8-4231-b3fd-\
0b56fec57d98"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphin3", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsi3", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}], 
     "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"mMDi3300", ",", "kri3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502554527807`*^9}, {3.8350088308601418`*^9, 3.835008843081888*^9}},
 CellLabel->
  "In[153]:=",ExpressionUUID->"442ffc98-e47e-4daf-b859-2884ec7b713e"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1FO4EAYYBuBzsm2dTrZdW7WsZbtVy3bLtWxr2bat5WVjyzZXrfc8u3i/
//a7+f7gJu2rtAsMCAjIJEJuKEIThrCEIzwRiEgkIhOFqEQjOjGISSxiE4e4
xCM+CUhIIhKThKQkI4jkBJOClKQiNWlISzrSk4GMIX3JTBayko3s5CAnuchN
HvKSj/wUoCCF+IEfKUwRivITxShOCUpSitKUoSzlKE8FfqYilahMFapSjerU
oCa1qE0d6lKP+jSgIY1oTBN+oSnNaM6vtKAlrWhNG9rSjvZ0oCOd6EwXutKN
7vSgJ73ozW/0oS/96M8ABjKIwQzhd4YyjOGMYCSjGM0YxjKO8UxgIpOYzBSm
Mo3pzGAms5jNH8xhLvOYzwIWsojFLGEpy1jOClayitWsYS3rWM8GNrKJzWxh
K9vYzg52sovd7GEv+9jPAQ5yiMMc4U+OcozjnOAkpzjNX5zhLOc4zwUuconL
XOEq17jODW5yi9v8zT/c4S73uM8DHvKIxzzhKc94zgte8orXvOEt73jPBz7y
ic/8yxe+8o3/CBl/IKEITRjCEo7wRCAikYhMFKISjejEICaxiE0c4hKP+CQg
IYlITBKSkowgkhNMClKSitSkIS3pSE8GMgb+/6++Az6VhWw=
          "], {Null, CompressedData["
1:eJxN2guYllWBB/D3qyhJJoMEhjQEkUhkrd1Es1FL08DywkWybEVNDSyNClNB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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[72, 227] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[132, 236] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[187, 193] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[196, 225] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[39, 166] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[7, 216] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142857, 0.9722277142857143], 
             UndirectedEdge[92, 281] -> 
             RGBColor[
              0.8048095000000002, 0.6892778571428575, 0.6017240714285714], 
             UndirectedEdge[99, 229] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[187, 296] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[100, 244] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[232, 245] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[6, 52] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 
             UndirectedEdge[113, 160] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[176, 288] -> 
             RGBColor[
              0.8542270000000001, 0.3663391428571431, 0.1975453571428572], 
             UndirectedEdge[187, 228] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[61, 268] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[51, 101] -> 
             RGBColor[
              0.8934179285714287, 0.8304337142857144, 0.6257149285714285], 
             UndirectedEdge[207, 214] -> 
             RGBColor[
              0.6417487142857143, 0.7052103571428572, 0.7258179285714287], 
             UndirectedEdge[17, 162] -> 
             RGBColor[
              0.8934179285714287, 0.8304337142857144, 0.6257149285714285], 
             UndirectedEdge[20, 279] -> 
             RGBColor[
              0.8349272857142858, 0.2694719999999999, 0.1810797142857143], 
             UndirectedEdge[51, 197] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142857, 0.9722277142857143], 
             UndirectedEdge[86, 94] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[55, 114] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[13, 270] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142857, 0.7488217142857143], 
             UndirectedEdge[151, 220] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[117, 225] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[13, 277] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[81, 237] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[172, 174] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[128, 197] -> 
             RGBColor[
              0.7519839999999999, 0.8057464285714286, 0.9703062142857143], 
             UndirectedEdge[44, 71] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[70, 122] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[42, 293] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[154, 181] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857144], 
             UndirectedEdge[42, 216] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[125, 130] -> 
             RGBColor[
              0.9124627142857145, 0.6868797142857146, 0.2482285714285715], 
             UndirectedEdge[173, 263] -> 
             RGBColor[
              0.9124627142857145, 0.6868797142857146, 0.2482285714285715], 
             UndirectedEdge[112, 132] -> 
             RGBColor[0.5815595, 0.6465624999999999, 0.922572], 
             UndirectedEdge[208, 279] -> 
             RGBColor[
              0.8975810714285714, 0.6807742857142856, 0.5899719285714285], 
             UndirectedEdge[271, 295] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[193, 264] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[16, 39] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[168, 282] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[92, 243] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[71, 280] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[69, 118] -> 
             RGBColor[
              0.8558905000000001, 0.8840378571428572, 0.7421867142857144], 
             UndirectedEdge[175, 253] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[137, 179] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[134, 221] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[91, 163] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[160, 232] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[135, 263] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[160, 297] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[179, 274] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[209, 259] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[14, 173] -> 
             RGBColor[
              0.8720902142857143, 0.742105285714286, 0.6083590714285715], 
             UndirectedEdge[260, 267] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[203, 216] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[37, 279] -> 
             RGBColor[
              0.9231166428571429, 0.6982394285714284, 0.4760250714285714], 
             UndirectedEdge[192, 220] -> 
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[60, 225] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[177, 226] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[91, 273] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[52, 273] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857144], 
             UndirectedEdge[21, 114] -> 
             RGBColor[0.893163, 0.5900125714285714, 0.23176292857142858`], 
             UndirectedEdge[7, 202] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[94, 293] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[132, 133] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[13, 93] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[141, 178] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[245, 264] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.4924907142857144], 
             UndirectedEdge[5, 83] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142857, 0.7488217142857143], 
             UndirectedEdge[210, 226] -> 
             RGBColor[
              0.9124627142857145, 0.6868797142857146, 0.2482285714285715], 
             UndirectedEdge[91, 298] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[126, 192] -> 
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855], 
             UndirectedEdge[127, 156] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[36, 268] -> 
             RGBColor[0.586112, 0.6467326428571429, 0.7226495000000002], 
             UndirectedEdge[25, 221] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[69, 249] -> 
             RGBColor[
              0.6399127142857143, 0.7173828571428572, 0.9655927142857142], 
             UndirectedEdge[22, 161] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[96, 112] -> 
             RGBColor[
              0.5607767857142857, 0.6310627857142858, 0.9577517142857144], 
             UndirectedEdge[219, 250] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[41, 219] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[202, 237] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[91, 235] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[69, 263] -> 
             RGBColor[
              0.8261372142857144, 0.7776062857142859, 0.6190799285714286], 
             UndirectedEdge[12, 239] -> 
             RGBColor[
              0.37013421428571425`, 0.48007764285714283`, 0.9460554999999999],
              UndirectedEdge[122, 266] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[206, 254] -> 
             RGBColor[
              0.9055083571428572, 0.5628944285714286, 0.45916335714285716`], 
             UndirectedEdge[137, 270] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[25, 58] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[107, 156] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[136, 194] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142857, 0.7488217142857143], 
             UndirectedEdge[45, 281] -> 
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855], 
             UndirectedEdge[137, 147] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[164, 187] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[199, 229] -> 
             RGBColor[
              0.8261372142857144, 0.7776062857142859, 0.6190799285714286], 
             UndirectedEdge[191, 271] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.4924907142857144], 
             UndirectedEdge[153, 222] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[158, 186] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[16, 192] -> 
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[75, 143] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[204, 226] -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             UndirectedEdge[137, 191] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[197, 198] -> 
             RGBColor[
              0.7262382142857142, 0.6266562857142859, 0.5947413571428571], 
             UndirectedEdge[80, 156] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[103, 159] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[28, 288] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[118, 263] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[68, 83] -> 
             RGBColor[
              0.5159862142857143, 0.5955266428571429, 0.9596732142857143], 
             UndirectedEdge[64, 90] -> 
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855], 
             UndirectedEdge[213, 263] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[52, 53] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[245, 297] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[189, 267] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[145, 203] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[136, 279] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.35486971428571434`], 
             UndirectedEdge[80, 256] -> 
             RGBColor[0.5815595, 0.6465625, 0.922572], 
             UndirectedEdge[40, 130] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[83, 101] -> 
             RGBColor[
              0.8934179285714287, 0.8304337142857144, 0.6257149285714285], 
             UndirectedEdge[83, 194] -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714285], 
             UndirectedEdge[149, 197] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[23, 44] -> 
             RGBColor[0.586112, 0.6467326428571429, 0.7226495000000002], 
             UndirectedEdge[97, 284] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[135, 276] -> 
             RGBColor[
              0.7519839999999999, 0.8057464285714286, 0.9703062142857143], 
             UndirectedEdge[142, 150] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[46, 214] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002], 
             UndirectedEdge[5, 243] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857144], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.8934179285714287, 0.8304337142857144, 0.6257149285714285], 
             UndirectedEdge[198, 243] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[13, 32] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[86, 140] -> 
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861], 
             UndirectedEdge[171, 275] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[36, 250] -> 
             RGBColor[
              0.37013421428571425`, 0.48007764285714283`, 0.9460554999999999],
              UndirectedEdge[168, 203] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[17, 169] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[191, 246] -> 
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`], 
             UndirectedEdge[17, 178] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142857, 0.9722277142857143], 
             UndirectedEdge[9, 132] -> 
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[11, 283] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[64, 69] -> 
             RGBColor[
              0.7184840000000001, 0.7800044285714287, 0.9725754285714285], 
             UndirectedEdge[193, 288] -> 
             RGBColor[
              0.8351822142857144, 0.5098931428571429, 0.5750317142857142], 
             UndirectedEdge[221, 288] -> 
             RGBColor[
              0.8755547142857143, 0.45466757142857156`, 0.2149012142857143], 
             UndirectedEdge[65, 264] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[27, 151] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[201, 293] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[43, 99] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[77, 293] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[61, 280] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[20, 55] -> 
             RGBColor[0.894471, 0.5250334285714284, 0.2542395714285713], 
             UndirectedEdge[208, 242] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[29, 261] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.4924907142857144], 
             UndirectedEdge[12, 76] -> 
             RGBColor[
              0.5607767857142856, 0.6310627857142856, 0.9577517142857144], 
             UndirectedEdge[168, 276] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[148, 271] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[131, 170] -> 
             RGBColor[0.905308, 0.5610991428571428, 0.3380080000000001], 
             UndirectedEdge[141, 261] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[129, 184] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[111, 185] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[234, 239] -> 
             RGBColor[
              0.6399127142857143, 0.7173828571428572, 0.9655927142857142], 
             UndirectedEdge[103, 203] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[28, 160] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[133, 170] -> 
             RGBColor[
              0.8351822142857144, 0.5098931428571429, 0.5750317142857142], 
             UndirectedEdge[87, 299] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[5, 290] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[183, 253] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[176, 245] -> 
             RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             UndirectedEdge[29, 190] -> 
             RGBColor[
              0.8542270000000001, 0.3663391428571431, 0.1975453571428572], 
             UndirectedEdge[159, 168] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[202, 299] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[65, 115] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[51, 142] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[134, 187] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[85, 239] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[120, 284] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[31, 61] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[217, 247] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[66, 169] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[168, 293] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[93, 105] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[169, 193] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[87, 216] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[81, 201] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[63, 244] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[32, 150] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[95, 282] -> 
             RGBColor[
              0.8934179285714287, 0.8304337142857144, 0.6257149285714285], 
             UndirectedEdge[126, 239] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[149, 150] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[16, 222] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[192, 262] -> 
             RGBColor[
              0.7857647142857144, 0.8328318571428572, 0.9792104285714285], 
             UndirectedEdge[214, 276] -> 
             RGBColor[
              0.7773192142857142, 0.8214162857142857, 0.7352040000000001], 
             UndirectedEdge[48, 100] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[105, 143] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[268, 279] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.35486971428571434`], 
             UndirectedEdge[24, 106] -> 
             RGBColor[
              0.8558905000000001, 0.8840378571428572, 0.7421867142857144], 
             UndirectedEdge[33, 222] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[155, 291] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[99, 233] -> 
             RGBColor[
              0.7519839999999999, 0.8057464285714286, 0.9703062142857143], 
             UndirectedEdge[237, 269] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[85, 135] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[126, 248] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[188, 261] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[37, 177] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[160, 180] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[23, 194] -> 
             RGBColor[
              0.5159862142857143, 0.5955266428571429, 0.9596732142857143], 
             UndirectedEdge[51, 243] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[108, 208] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[179, 251] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 
             UndirectedEdge[26, 224] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[106, 291] -> 
             RGBColor[
              0.8048095000000002, 0.6892778571428575, 0.6017240714285714], 
             UndirectedEdge[48, 161] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[227, 299] -> 
             RGBColor[
              0.9124627142857145, 0.6868797142857146, 0.2482285714285715], 
             UndirectedEdge[162, 299] -> 
             RGBColor[
              0.9124627142857145, 0.6868797142857146, 0.2482285714285715], 
             UndirectedEdge[200, 227] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[202, 293] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[3, 155] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[39, 234] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[144, 176] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[140, 162] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[123, 257] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[121, 286] -> 
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`], 
             UndirectedEdge[176, 230] -> 
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`], 
             UndirectedEdge[39, 64] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[269, 277] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[154, 203] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[107, 137] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[192, 218] -> 
             RGBColor[
              0.7184840000000001, 0.7800044285714287, 0.9725754285714285], 
             UndirectedEdge[247, 270] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[28, 240] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[31, 194] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[58, 187] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[8, 121] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[62, 186] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[271, 289] -> 
             RGBColor[
              0.9231166428571429, 0.6982394285714284, 0.4760250714285714], 
             UndirectedEdge[236, 294] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[115, 211] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[43, 284] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[87, 181] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[77, 205] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[132, 267] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[108, 280] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[40, 97] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[35, 262] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142857, 0.7488217142857143], 
             UndirectedEdge[201, 216] -> 
             RGBColor[
              0.7773192142857142, 0.8214162857142857, 0.7352040000000001], 
             UndirectedEdge[244, 279] -> 
             RGBColor[
              0.9183637857142857, 0.6962739999999998, 0.5547922142857142], 
             UndirectedEdge[143, 163] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[102, 165] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[7, 282] -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714285], 
             UndirectedEdge[10, 122] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[113, 193] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142857, 0.7488217142857143], 
             UndirectedEdge[22, 100] -> 
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[116, 254] -> 
             RGBColor[
              0.8349272857142858, 0.2694719999999999, 0.1810797142857143], 
             UndirectedEdge[174, 298] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[159, 271] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[11, 101] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[148, 225] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[239, 248] -> 
             RGBColor[
              0.7773192142857142, 0.8214162857142857, 0.7352040000000001], 
             UndirectedEdge[22, 119] -> 
             RGBColor[
              0.8048095000000002, 0.6892778571428575, 0.6017240714285714], 
             UndirectedEdge[38, 247] -> 
             RGBColor[0.894471, 0.5250334285714284, 0.2542395714285713], 
             UndirectedEdge[157, 222] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[42, 203] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[155, 241] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[103, 154] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[88, 107] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[58, 176] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[48, 119] -> 
             RGBColor[
              0.9124627142857145, 0.6868797142857146, 0.2482285714285715], 
             UndirectedEdge[206, 219] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[1, 125] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[191, 278] -> 
             RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             UndirectedEdge[90, 118] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[101, 283] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[5, 226] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[3, 241] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[194, 241] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142857, 0.9722277142857143], 
             UndirectedEdge[139, 235] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[40, 94] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[161, 177] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[34, 295] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[1, 281] -> 
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855], 
             UndirectedEdge[191, 295] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.4924907142857144], 
             UndirectedEdge[144, 297] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 
             UndirectedEdge[141, 294] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[80, 201] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[113, 115] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[129, 253] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[37, 108] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[265, 276] -> 
             RGBColor[
              0.7519839999999999, 0.8057464285714286, 0.9703062142857143], 
             UndirectedEdge[59, 194] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[103, 225] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[46, 265] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857144], 
             UndirectedEdge[51, 149] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[52, 124] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[82, 258] -> 
             RGBColor[
              0.7519839999999999, 0.8057464285714286, 0.9703062142857143], 
             UndirectedEdge[45, 132] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[74, 287] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[128, 269] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[14, 249] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142857, 0.9722277142857143], 
             UndirectedEdge[101, 198] -> 
             RGBColor[
              0.9124627142857145, 0.6868797142857146, 0.2482285714285715], 
             UndirectedEdge[164, 297] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 
             UndirectedEdge[68, 235] -> 
             RGBColor[
              0.5863123571428572, 0.6485279285714285, 0.8438048571428571], 
             UndirectedEdge[108, 177] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[62, 276] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[13, 107] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.7262382142857142, 0.6266562857142859, 0.5947413571428573], 
             UndirectedEdge[62, 135] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[18, 35] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002], 
             UndirectedEdge[42, 202] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[121, 255] -> 
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428573], 
             UndirectedEdge[128, 281] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[82, 181] -> 
             RGBColor[
              0.7519839999999999, 0.8057464285714286, 0.9703062142857143], 
             UndirectedEdge[136, 204] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[118, 166] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[39, 263] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[52, 84] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[129, 165] -> 
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428572], 
             UndirectedEdge[141, 236] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[97, 178] -> 
             RGBColor[
              0.7519839999999999, 0.8057464285714286, 0.9703062142857143], 
             UndirectedEdge[115, 227] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[256, 281] -> 
             RGBColor[
              0.44870550000000003`, 0.5426992142857143, 0.9530382142857143], 
             UndirectedEdge[221, 297] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[224, 262] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[73, 119] -> 
             RGBColor[
              0.8048095000000002, 0.6892778571428575, 0.6017240714285714], 
             UndirectedEdge[3, 227] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[45, 188] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[260, 300] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[23, 291] -> 
             RGBColor[0.535031, 0.4519726428571431, 0.5821868571428572], 
             UndirectedEdge[142, 149] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[81, 97] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[181, 201] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857144], 
             UndirectedEdge[56, 57] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[197, 243] -> 
             RGBColor[
              0.7519839999999999, 0.8057464285714286, 0.9703062142857143], 
             UndirectedEdge[65, 200] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[8, 173] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[53, 273] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[26, 253] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[114, 206] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[9, 45] -> 
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855], 
             UndirectedEdge[47, 190] -> 
             RGBColor[
              0.9055083571428572, 0.5628944285714286, 0.45916335714285716`], 
             UndirectedEdge[191, 282] -> 
             RGBColor[
              0.8720902142857143, 0.742105285714286, 0.6083590714285714], 
             UndirectedEdge[59, 155] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[214, 265] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857144], 
             UndirectedEdge[167, 282] -> 
             RGBColor[
              0.6325285714285714, 0.7084724285714286, 0.9666597142857143], 
             UndirectedEdge[28, 221] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[136, 197] -> 
             RGBColor[
              0.7773192142857142, 0.8214162857142857, 0.7352040000000001], 
             UndirectedEdge[121, 234] -> 
             RGBColor[
              0.8048095000000002, 0.6892778571428575, 0.6017240714285714], 
             UndirectedEdge[141, 146] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[32, 167] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[101, 136] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[91, 274] -> 
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855], 
             UndirectedEdge[84, 295] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[73, 122] -> 
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855], 
             UndirectedEdge[157, 248] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[125, 167] -> 
             RGBColor[
              0.6515733571428572, 0.5649184285714288, 0.5891733571428572], 
             UndirectedEdge[20, 208] -> 
             RGBColor[
              0.8799727857142856, 0.5454292857142857, 0.5731102142857143], 
             UndirectedEdge[77, 103] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[46, 276] -> 
             RGBColor[
              0.7773192142857142, 0.8214162857142857, 0.7352040000000001], 
             UndirectedEdge[3, 291] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[79, 297] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[18, 262] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142857, 0.7488217142857143], 
             UndirectedEdge[127, 225] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[109, 292] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[267, 287] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[218, 262] -> 
             RGBColor[
              0.7857647142857144, 0.8328318571428572, 0.9792104285714285], 
             UndirectedEdge[207, 225] -> 
             RGBColor[
              0.6309117142857144, 0.6691446428571428, 0.6420494999999999], 
             UndirectedEdge[203, 299] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[142, 163] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[2, 54] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[90, 195] -> 
             RGBColor[0.894471, 0.5250334285714284, 0.2542395714285713], 
             UndirectedEdge[88, 93] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[77, 82] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[167, 168] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[18, 26] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[129, 224] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[38, 289] -> 
             RGBColor[
              0.8349272857142858, 0.2694719999999999, 0.1810797142857143], 
             UndirectedEdge[31, 241] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[5, 197] -> 
             RGBColor[
              0.7773192142857142, 0.8214162857142857, 0.7352040000000001], 
             UndirectedEdge[59, 241] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[155, 226] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[15, 186] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[198, 256] -> 
             RGBColor[0.535031, 0.4519726428571431, 0.5821868571428572], 
             UndirectedEdge[72, 291] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[230, 297] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857144], 
             UndirectedEdge[138, 231] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[54, 165] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[103, 167] -> 
             RGBColor[
              0.6729010714285715, 0.6532468571428572, 0.6065292142857144], 
             UndirectedEdge[78, 131] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[16, 239] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[12, 87] -> 
             RGBColor[0.575275, 0.6106669285714286, 0.6388810714285713], 
             UndirectedEdge[125, 281] -> 
             RGBColor[
              0.8048095000000002, 0.6892778571428575, 0.6017240714285714], 
             UndirectedEdge[148, 205] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[103, 269] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[40, 169] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[38, 53] -> 
             RGBColor[
              0.8755547142857143, 0.45466757142857156`, 0.2149012142857143], 
             UndirectedEdge[118, 285] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[74, 267] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[3, 200] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[124, 273] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[131, 182] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[62, 207] -> 
             RGBColor[
              0.6119954285714286, 0.5987787857142859, 0.6027111428571429], 
             UndirectedEdge[75, 262] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[197, 283] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[246, 278] -> 
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`], 
             UndirectedEdge[225, 265] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[101, 204] -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             UndirectedEdge[87, 140] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[57, 247] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[40, 66] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[167, 293] -> 
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[42, 140] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[107, 150] -> 
             RGBColor[
              0.9124627142857145, 0.6868797142857146, 0.2482285714285715], 
             UndirectedEdge[91, 143] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[91, 142] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[44, 283] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[78, 199] -> 
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855], 
             UndirectedEdge[199, 233] -> 
             RGBColor[
              0.6399127142857143, 0.7173828571428572, 0.9655927142857142], 
             UndirectedEdge[249, 286] -> 
             RGBColor[
              0.7773192142857142, 0.8214162857142857, 0.7352040000000001], 
             UndirectedEdge[48, 266] -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             UndirectedEdge[113, 169] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[18, 33] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[269, 293] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[189, 257] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[11, 197] -> 
             RGBColor[
              0.7519839999999999, 0.8057464285714286, 0.9703062142857143], 
             UndirectedEdge[221, 296] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[126, 157] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[24, 87] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[53, 137] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[27, 140] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[115, 200] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[1, 5] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[40, 42] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[82, 167] -> 
             RGBColor[0.48667657142857135`, 0.5930234285714285, 0.953042], 
             UndirectedEdge[52, 57] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[27, 203] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[251, 270] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[200, 264] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[84, 271] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[80, 145] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[199, 259] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[273, 274] -> 
             RGBColor[
              0.8558905000000001, 0.8840378571428572, 0.7421867142857144], 
             UndirectedEdge[281, 294] -> 
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855], 
             UndirectedEdge[18, 183] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[77, 269] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[134, 144] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[200, 210] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[87, 151] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[109, 290] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[247, 278] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[156, 205] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[64, 121] -> 
             RGBColor[
              0.8048095000000002, 0.6892778571428575, 0.6017240714285714], 
             UndirectedEdge[106, 264] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[91, 107] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[7, 299] -> 
             RGBColor[
              0.8720902142857143, 0.742105285714286, 0.6083590714285715], 
             UndirectedEdge[160, 221] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[8, 234] -> 
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855], 
             UndirectedEdge[49, 174] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142857, 0.9722277142857143], 
             UndirectedEdge[79, 245] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[13, 147] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[1, 197] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[129, 175] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[116, 283] -> 
             RGBColor[
              0.9183637857142857, 0.6962739999999998, 0.5547922142857142], 
             UndirectedEdge[62, 265] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[31, 291] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[92, 277] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.4924907142857144], 
             UndirectedEdge[124, 289] -> 
             RGBColor[
              0.9231166428571429, 0.6982394285714284, 0.4760250714285714], 
             UndirectedEdge[80, 277] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[119, 244] -> 
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428573], 
             UndirectedEdge[252, 268] -> 
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`], 
             UndirectedEdge[3, 194] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[1, 237] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[149, 281] -> 
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855], 
             UndirectedEdge[29, 209] -> 
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428573], 
             UndirectedEdge[123, 287] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[17, 81] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[176, 187] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.4924907142857144], 
             UndirectedEdge[246, 270] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142857, 0.7488217142857143], 
             UndirectedEdge[45, 131] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[4, 158] -> RGBColor[0.984192, 0.987731, 0.911643],
              UndirectedEdge[169, 264] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[42, 181] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[8, 263] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[145, 205] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[167, 269] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[187, 288] -> 
             RGBColor[
              0.9055083571428572, 0.5628944285714286, 0.45916335714285716`], 
             UndirectedEdge[47, 131] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[43, 97] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[104, 114] -> 
             RGBColor[
              0.9124627142857145, 0.6868797142857146, 0.2482285714285715], 
             UndirectedEdge[26, 129] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[28, 79] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[53, 247] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[150, 281] -> 
             RGBColor[
              0.8048095000000002, 0.6892778571428575, 0.6017240714285714], 
             UndirectedEdge[76, 248] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857144], 
             UndirectedEdge[194, 210] -> 
             RGBColor[
              0.8720902142857143, 0.742105285714286, 0.6083590714285715], 
             UndirectedEdge[60, 265] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857144], 
             UndirectedEdge[78, 178] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[120, 190] -> 
             RGBColor[
              0.8799727857142856, 0.5454292857142857, 0.5731102142857143], 
             UndirectedEdge[96, 267] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[159, 212] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[34, 147] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[41, 250] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[146, 236] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[82, 103] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[179, 289] -> 
             RGBColor[
              0.8975810714285714, 0.6807742857142856, 0.5899719285714285], 
             UndirectedEdge[124, 247] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[162, 227] -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             UndirectedEdge[156, 191] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[1, 51] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[23, 198] -> 
             RGBColor[0.535031, 0.4519726428571431, 0.5821868571428572], 
             UndirectedEdge[77, 159] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[2, 238] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[113, 245] -> 
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`], 
             UndirectedEdge[167, 201] -> 
             RGBColor[
              0.7026543571428572, 0.7596784285714285, 0.7296360000000002], 
             UndirectedEdge[125, 150] -> 
             RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             UndirectedEdge[142, 198] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[34, 52] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[13, 251] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857144], 
             UndirectedEdge[120, 188] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[67, 173] -> 
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428572], 
             UndirectedEdge[20, 280] -> 
             RGBColor[0.894471, 0.5250334285714284, 0.2542395714285713], 
             UndirectedEdge[32, 107] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[189, 287] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[159, 205] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[66, 86] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[119, 266] -> 
             RGBColor[
              0.9124627142857145, 0.6868797142857146, 0.2482285714285715], 
             UndirectedEdge[28, 230] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[83, 142] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[191, 217] -> 
             RGBColor[
              0.9124627142857145, 0.6868797142857146, 0.2482285714285715], 
             UndirectedEdge[43, 233] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[113, 297] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857144], 
             UndirectedEdge[158, 207] -> 
             RGBColor[
              0.6371962142857143, 0.7050402142857144, 0.9257404285714286], 
             UndirectedEdge[40, 201] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[194, 226] -> 
             RGBColor[
              0.8934179285714287, 0.8304337142857144, 0.6257149285714285], 
             UndirectedEdge[134, 230] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[134, 264] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[59, 226] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[42, 201] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[217, 295] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[45, 94] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[197, 254] -> 
             RGBColor[0.6893302142857143, 0.39444414285714285`, 0.561414], 
             UndirectedEdge[30, 189] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[92, 179] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[134, 288] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], UndirectedEdge[59, 83] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[10, 22] -> 
             RGBColor[
              0.8558905000000001, 0.8840378571428572, 0.7421867142857144], 
             UndirectedEdge[148, 168] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[130, 216] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[158, 196] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[203, 237] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[160, 193] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[38, 88] -> 
             RGBColor[0.6893302142857143, 0.39444414285714285`, 0.561414], 
             UndirectedEdge[22, 73] -> 
             RGBColor[
              0.7184840000000001, 0.7800044285714287, 0.9725754285714285], 
             UndirectedEdge[181, 227] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[85, 255] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[106, 227] -> 
             RGBColor[
              0.8261372142857144, 0.7776062857142859, 0.6190799285714286], 
             UndirectedEdge[131, 261] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[81, 94] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[77, 154] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[167, 277] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[113, 176] -> 
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`], 
             UndirectedEdge[4, 276] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[101, 243] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[52, 271] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[37, 71] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[83, 291] -> 
             RGBColor[
              0.8720902142857143, 0.742105285714286, 0.6083590714285715], 
             UndirectedEdge[80, 149] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[104, 206] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.4924907142857144], 
             UndirectedEdge[61, 108] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[115, 264] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[38, 52] -> 
             RGBColor[
              0.8799727857142856, 0.5454292857142857, 0.5731102142857143], 
             UndirectedEdge[33, 285] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[100, 122] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[205, 269] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[177, 252] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[152, 244] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[10, 71] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[233, 259] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[130, 299] -> 
             RGBColor[
              0.9124627142857145, 0.6868797142857146, 0.2482285714285715], 
             UndirectedEdge[81, 86] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[205, 282] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[176, 297] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[92, 128] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[166, 285] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[132, 146] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[81, 130] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[1, 128] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[296, 297] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[128, 237] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[112, 146] -> 
             RGBColor[
              0.5863123571428572, 0.6485279285714285, 0.8438048571428571], 
             UndirectedEdge[116, 287] -> 
             RGBColor[
              0.9120792857142856, 0.6603784285714284, 0.2711012857142856], 
             UndirectedEdge[10, 266] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[16, 76] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[23, 72] -> 
             RGBColor[
              0.5863123571428572, 0.6485279285714285, 0.8438048571428571], 
             UndirectedEdge[237, 277] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[56, 278] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[88, 274] -> 
             RGBColor[
              0.6399127142857143, 0.7173828571428572, 0.9655927142857142], 
             UndirectedEdge[103, 282] -> 
             RGBColor[
              0.8934179285714287, 0.8304337142857144, 0.6257149285714285], 
             UndirectedEdge[46, 60] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002], 
             UndirectedEdge[82, 216] -> 
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861], 
             UndirectedEdge[48, 70] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[143, 174] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[95, 205] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[78, 190] -> 
             RGBColor[0.894471, 0.5250334285714284, 0.2542395714285713], 
             UndirectedEdge[68, 292] -> 
             RGBColor[
              0.5863123571428572, 0.6485279285714285, 0.8438048571428571], 
             UndirectedEdge[145, 269] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[198, 254] -> 
             RGBColor[
              0.8542270000000001, 0.3663391428571431, 0.1975453571428572], 
             UndirectedEdge[124, 147] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[44, 194] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142857, 0.7488217142857143], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[5, 11] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857144], 
             UndirectedEdge[108, 254] -> 
             RGBColor[
              0.8755547142857143, 0.45466757142857156`, 0.2149012142857143], 
             UndirectedEdge[61, 71] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[229, 284] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[37, 136] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[148, 159] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[164, 230] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857144], 
             UndirectedEdge[176, 193] -> 
             RGBColor[
              0.8720902142857143, 0.742105285714286, 0.6083590714285714], 
             UndirectedEdge[216, 299] -> 
             RGBColor[
              0.7262382142857142, 0.6266562857142859, 0.5947413571428571], 
             UndirectedEdge[149, 277] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[39, 248] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[13, 137] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[68, 75] -> 
             RGBColor[
              0.5607767857142856, 0.6310627857142856, 0.9577517142857144], 
             UndirectedEdge[66, 97] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[59, 106] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[51, 198] -> 
             RGBColor[
              0.8720902142857143, 0.742105285714286, 0.6083590714285715], 
             UndirectedEdge[193, 228] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[30, 287] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[93, 147] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[69, 121] -> 
             RGBColor[
              0.8048095000000002, 0.6892778571428575, 0.6017240714285714], 
             UndirectedEdge[148, 251] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[125, 269] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.4924907142857144], 
             UndirectedEdge[37, 44] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[91, 105] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[81, 203] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[8, 69] -> 
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855], 
             UndirectedEdge[52, 270] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[108, 268] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[11, 254] -> 
             RGBColor[
              0.8799727857142856, 0.5454292857142857, 0.5731102142857143], 
             UndirectedEdge[82, 255] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[43, 66] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[252, 283] -> 
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428573], 
             UndirectedEdge[99, 215] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[114, 283] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[24, 194] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142857, 0.7488217142857143], 
             UndirectedEdge[134, 228] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[49, 143] -> 
             RGBColor[
              0.8934179285714287, 0.8304337142857144, 0.6257149285714285], 
             UndirectedEdge[123, 189] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[232, 240] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[11, 243] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 
             UndirectedEdge[155, 210] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[148, 156] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[15, 212] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[51, 204] -> 
             RGBColor[
              0.8934179285714287, 0.8304337142857144, 0.6257149285714285], 
             UndirectedEdge[95, 156] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[87, 109] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[113, 288] -> 
             RGBColor[0.905308, 0.5610991428571428, 0.3380080000000001], 
             UndirectedEdge[164, 176] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[17, 294] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[77, 212] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[180, 296] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[217, 271] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[4, 85] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[95, 127] -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             UndirectedEdge[54, 75] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[134, 193] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[40, 178] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[69, 239] -> 
             RGBColor[
              0.6399127142857143, 0.7173828571428572, 0.9655927142857142], 
             UndirectedEdge[134, 200] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[89, 141] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[38, 147] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[170, 182] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[94, 120] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[80, 269] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[263, 286] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[130, 140] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[25, 288] -> 
             RGBColor[0.894471, 0.5250334285714284, 0.2542395714285713], 
             UndirectedEdge[148, 191] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[177, 268] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[69, 126] -> 
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855], 
             UndirectedEdge[20, 37] -> 
             RGBColor[
              0.9055083571428572, 0.5628944285714286, 0.45916335714285716`], 
             UndirectedEdge[3, 72] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[87, 154] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[11, 204] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[55, 268] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[125, 142] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[176, 221] -> 
             RGBColor[
              0.9124627142857145, 0.6868797142857146, 0.2482285714285715], 
             UndirectedEdge[29, 182] -> 
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428573], 
             UndirectedEdge[122, 161] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[44, 226] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[89, 131] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[56, 110] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[43, 178] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[66, 162] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[5, 142] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[147, 273] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[81, 167] -> 
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[95, 212] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[56, 217] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[6, 93] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[131, 146] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[7, 80] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[76, 239] -> 
             RGBColor[
              0.7519839999999999, 0.8057464285714286, 0.9703062142857143], 
             UndirectedEdge[148, 278] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[29, 170] -> 
             RGBColor[
              0.8542270000000001, 0.3663391428571431, 0.1975453571428572], 
             UndirectedEdge[147, 289] -> 
             RGBColor[
              0.9183637857142857, 0.6962739999999998, 0.5547922142857142], 
             UndirectedEdge[25, 28] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[5, 149] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[140, 202] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[10, 63] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[43, 259] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[21, 50] -> 
             RGBColor[
              0.9183637857142857, 0.6962739999999998, 0.5547922142857142], 
             UndirectedEdge[87, 155] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[127, 282] -> 
             RGBColor[
              0.8934179285714287, 0.8304337142857144, 0.6257149285714285], 
             UndirectedEdge[79, 144] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[54, 298] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[234, 263] -> 
             RGBColor[
              0.8261372142857144, 0.7776062857142859, 0.6190799285714286], 
             UndirectedEdge[34, 38] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], UndirectedEdge[39, 85] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[20, 108] -> 
             RGBColor[
              0.8755547142857143, 0.45466757142857156`, 0.2149012142857143], 
             UndirectedEdge[94, 201] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[260, 294] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[138, 266] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[127, 168] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[128, 198] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[145, 216] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[141, 182] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[41, 252] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[55, 208] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[121, 249] -> 
             RGBColor[
              0.7262382142857142, 0.6266562857142859, 0.5947413571428573], 
             UndirectedEdge[89, 120] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[32, 142] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[7, 77] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[45, 146] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[110, 223] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[225, 276] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[65, 291] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[194, 290] -> 
             RGBColor[
              0.8934179285714287, 0.8304337142857144, 0.6257149285714285], 
             UndirectedEdge[154, 258] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857144], 
             UndirectedEdge[31, 280] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[156, 271] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[83, 241] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142857, 0.9722277142857143], 
             UndirectedEdge[208, 268] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857144], 
             UndirectedEdge[1, 80] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[116, 206] -> 
             RGBColor[
              0.9231166428571429, 0.6982394285714284, 0.4760250714285715], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[108, 204] -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             UndirectedEdge[251, 271] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[6, 38] -> 
             RGBColor[
              0.8799727857142856, 0.5454292857142857, 0.5731102142857143], 
             UndirectedEdge[135, 158] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[25, 180] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[57, 217] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[71, 136] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[135, 173] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[143, 235] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[264, 288] -> 
             RGBColor[
              0.9055083571428572, 0.5628944285714286, 0.45916335714285716`], 
             UndirectedEdge[223, 247] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[191, 225] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[1, 243] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[29, 284] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.4924907142857144], 
             UndirectedEdge[6, 273] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857144], 
             UndirectedEdge[103, 276] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[99, 199] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[35, 129] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[77, 145] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[72, 155] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[20, 44] -> 
             RGBColor[0.905308, 0.5610991428571428, 0.3380080000000001], 
             UndirectedEdge[131, 178] -> 
             RGBColor[
              0.7773192142857142, 0.8214162857142857, 0.7352040000000001], 
             UndirectedEdge[106, 241] -> 
             RGBColor[
              0.6399127142857143, 0.7173828571428572, 0.9655927142857142], 
             UndirectedEdge[85, 286] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[86, 261] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[256, 269] -> 
             RGBColor[
              0.5863123571428572, 0.6485279285714285, 0.8438048571428571], 
             UndirectedEdge[37, 61] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[73, 244] -> 
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[180, 193] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[8, 213] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[48, 138] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[170, 284] -> 
             RGBColor[
              0.9055083571428572, 0.5628944285714286, 0.45916335714285716`], 
             UndirectedEdge[55, 219] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[111, 235] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[56, 247] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[7, 82] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142857, 0.9722277142857143], 
             UndirectedEdge[182, 190] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[113, 228] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[133, 146] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[93, 274] -> 
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[153, 220] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[90, 153] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[178, 190] -> 
             RGBColor[0.6893302142857143, 0.39444414285714285`, 0.561414], 
             UndirectedEdge[39, 126] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[15, 77] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[103, 293] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[92, 269] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.4924907142857144], 
             UndirectedEdge[8, 14] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[157, 171] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[198, 226] -> 
             RGBColor[
              0.9124627142857145, 0.6868797142857146, 0.2482285714285715], 
             UndirectedEdge[86, 169] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[163, 235] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[31, 136] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[111, 292] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[48, 122] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[246, 295] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[258, 263] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[24, 299] -> 
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`], 
             UndirectedEdge[66, 193] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[29, 199] -> 
             RGBColor[
              0.8048095000000002, 0.6892778571428575, 0.6017240714285714], 
             UndirectedEdge[27, 87] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[164, 180] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 
             UndirectedEdge[106, 200] -> 
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855], 
             UndirectedEdge[69, 285] -> 
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[88, 137] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[43, 261] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[224, 253] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[5, 23] -> 
             RGBColor[0.586112, 0.6467326428571428, 0.7226495000000002], 
             UndirectedEdge[42, 162] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[29, 131] -> 
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`], 
             UndirectedEdge[12, 192] -> 
             RGBColor[
              0.44870550000000003`, 0.5426992142857143, 0.9530382142857143], 
             UndirectedEdge[69, 76] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[176, 180] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[101, 116] -> 
             RGBColor[0.893163, 0.5900125714285714, 0.23176292857142858`], 
             UndirectedEdge[125, 293] -> 
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428573], 
             UndirectedEdge[30, 300] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[155, 290] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[217, 246] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[42, 82] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[122, 138] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[58, 160] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[158, 225] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[197, 204] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[40, 182] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[1, 149] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[32, 156] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[258, 286] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857144], 
             UndirectedEdge[101, 197] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[53, 271] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[22, 70] -> 
             RGBColor[
              0.6399127142857143, 0.7173828571428572, 0.9655927142857142], 
             UndirectedEdge[76, 258] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 
             UndirectedEdge[232, 297] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[178, 261] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[155, 227] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[178, 182] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[5, 51] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142857, 0.7488217142857143], 
             UndirectedEdge[110, 295] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[186, 286] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[34, 270] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[4, 8] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[69, 166] -> 
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[25, 176] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[32, 149] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[16, 153] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[169, 299] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[187, 229] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[15, 82] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[44, 280] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[186, 265] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[117, 265] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[106, 162] -> 
             RGBColor[
              0.8261372142857144, 0.7776062857142859, 0.6190799285714286], 
             UndirectedEdge[9, 146] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[130, 294] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[13, 53] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[34, 57] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[25, 144] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[206, 283] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[107, 273] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[64, 85] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[175, 224] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[68, 163] -> 
             RGBColor[
              0.37013421428571425`, 0.48007764285714283`, 0.9460554999999999],
              UndirectedEdge[7, 237] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[76, 126] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[30, 236] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[7, 269] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[237, 256] -> 
             RGBColor[0.575275, 0.6106669285714285, 0.6388810714285713], 
             UndirectedEdge[106, 290] -> 
             RGBColor[
              0.8261372142857144, 0.7776062857142859, 0.6190799285714286], 
             UndirectedEdge[180, 288] -> 
             RGBColor[
              0.8799727857142856, 0.5454292857142857, 0.5731102142857143], 
             UndirectedEdge[201, 237] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[10, 73] -> 
             RGBColor[
              0.8558905000000001, 0.8840378571428572, 0.7421867142857144], 
             UndirectedEdge[18, 175] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[57, 295] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[71, 161] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[218, 220] -> 
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[192, 248] -> 
             RGBColor[
              0.8558905000000001, 0.8840378571428572, 0.7421867142857144], 
             UndirectedEdge[23, 24] -> 
             RGBColor[0.586112, 0.6467326428571429, 0.7226495000000002], 
             UndirectedEdge[39, 195] -> 
             RGBColor[
              0.9055083571428572, 0.5628944285714286, 0.45916335714285716`], 
             UndirectedEdge[79, 232] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[12, 154] -> 
             RGBColor[0.586112, 0.6467326428571429, 0.7226495000000002], 
             UndirectedEdge[106, 155] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[95, 103] -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             UndirectedEdge[3, 228] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[81, 293] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[95, 145] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[39, 153] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[39, 90] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[120, 141] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[102, 172] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[155, 194] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[53, 251] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[128, 243] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 
             UndirectedEdge[72, 87] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[76, 90] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[3, 106] -> 
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855], 
             UndirectedEdge[104, 243] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[34, 217] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[31, 37] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[64, 249] -> 
             RGBColor[
              0.6399127142857143, 0.7173828571428572, 0.9655927142857142], 
             UndirectedEdge[89, 188] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[179, 269] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[213, 249] -> 
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861], 
             UndirectedEdge[44, 252] -> 
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`], 
             UndirectedEdge[149, 198] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[158, 214] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[202, 216] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[78, 209] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[77, 265] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[44, 204] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[54, 102] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[2, 253] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[40, 86] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[75, 165] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[73, 100] -> 
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[50, 206] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[32, 277] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[156, 251] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[31, 44] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[80, 92] -> 
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428572], 
             UndirectedEdge[11, 149] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[103, 145] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[150, 274] -> 
             RGBColor[
              0.8048095000000002, 0.6892778571428575, 0.6017240714285714], 
             UndirectedEdge[13, 156] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[84, 278] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[150, 293] -> 
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428573], 
             UndirectedEdge[52, 137] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[41, 152] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[177, 279] -> 
             RGBColor[
              0.9231166428571429, 0.6982394285714284, 0.4760250714285714], 
             UndirectedEdge[108, 279] -> 
             RGBColor[0.893163, 0.5900125714285714, 0.23176292857142858`], 
             UndirectedEdge[161, 279] -> 
             RGBColor[
              0.8975810714285714, 0.6807742857142856, 0.5899719285714285], 
             UndirectedEdge[89, 260] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[63, 161] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[110, 148] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[200, 228] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[67, 118] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[140, 203] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[144, 231] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 
             UndirectedEdge[101, 149] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[131, 284] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[157, 275] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[113, 144] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857144], 
             UndirectedEdge[48, 73] -> 
             RGBColor[
              0.8261372142857144, 0.7776062857142859, 0.6190799285714286], 
             UndirectedEdge[35, 183] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[93, 107] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[23, 226] -> 
             RGBColor[
              0.5563587142857143, 0.5403010714285715, 0.5995427142857144], 
             UndirectedEdge[200, 211] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[87, 227] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[223, 278] -> 
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`], 
             UndirectedEdge[182, 229] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[79, 221] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[115, 228] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[12, 16] -> 
             RGBColor[0.5815595, 0.6465624999999999, 0.922572], 
             UndirectedEdge[9, 47] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[18, 224] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[194, 291] -> 
             RGBColor[
              0.8720902142857143, 0.742105285714286, 0.6083590714285715], 
             UndirectedEdge[5, 198] -> 
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`], 
             UndirectedEdge[49, 172] -> 
             RGBColor[
              0.8934179285714287, 0.8304337142857144, 0.6257149285714285], 
             UndirectedEdge[162, 228] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[100, 161] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[174, 235] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[14, 67] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[190, 199] -> 
             RGBColor[0.7679015, 0.45706571428571435`, 0.5683967142857143], 
             UndirectedEdge[160, 288] -> 
             RGBColor[0.894471, 0.5250334285714284, 0.2542395714285713], 
             UndirectedEdge[33, 275] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[109, 218] -> 
             RGBColor[
              0.6399127142857143, 0.7173828571428572, 0.9655927142857142], 
             UndirectedEdge[231, 264] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[221, 230] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[45, 236] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[279, 280] -> 
             RGBColor[
              0.9120792857142856, 0.6603784285714284, 0.2711012857142856], 
             UndirectedEdge[71, 252] -> 
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428572], 
             UndirectedEdge[230, 296] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[27, 154] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[5, 101] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[68, 143] -> 
             RGBColor[
              0.5563587142857143, 0.5403010714285715, 0.5995427142857144], 
             UndirectedEdge[58, 221] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[85, 249] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[26, 54] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[269, 282] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[24, 210] -> 
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`], 
             UndirectedEdge[144, 288] -> 
             RGBColor[
              0.8799727857142856, 0.5454292857142857, 0.5731102142857143], 
             UndirectedEdge[182, 199] -> 
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[35, 224] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[161, 280] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[27, 42] -> RGBColor[0.984192, 0.987731, 0.911643],
              UndirectedEdge[13, 273] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002], 
             UndirectedEdge[167, 202] -> 
             RGBColor[
              0.6918173571428571, 0.7236127142857142, 0.6458675714285713], 
             UndirectedEdge[117, 207] -> 
             RGBColor[
              0.5716229285714286, 0.6540043571428572, 0.9628416428571429], 
             UndirectedEdge[33, 248] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[23, 210] -> 
             RGBColor[0.535031, 0.4519726428571431, 0.5821868571428572], 
             UndirectedEdge[54, 111] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[30, 267] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[170, 199] -> 
             RGBColor[0.7679015, 0.45706571428571435`, 0.5683967142857143], 
             UndirectedEdge[169, 200] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[137, 278] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[92, 150] -> 
             RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             UndirectedEdge[68, 185] -> 
             RGBColor[
              0.5863123571428572, 0.6485279285714285, 0.8438048571428571], 
             UndirectedEdge[26, 102] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[270, 271] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[169, 202] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[17, 97] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[46, 158] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[98, 285] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[77, 168] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[242, 268] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[115, 134] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[99, 284] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[204, 283] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[77, 167] -> 
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[227, 290] -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             UndirectedEdge[60, 145] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[32, 125] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[15, 60] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[30, 260] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[42, 80] -> RGBColor[0.984192, 0.987731, 0.911643],
              UndirectedEdge[97, 130] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[65, 211] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[1, 256] -> 
             RGBColor[0.575275, 0.6106669285714285, 0.6388810714285713], 
             UndirectedEdge[5, 128] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857144], 
             UndirectedEdge[125, 256] -> 
             RGBColor[0.535031, 0.4519726428571431, 0.5821868571428572], 
             UndirectedEdge[39, 239] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[156, 269] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[78, 170] -> 
             RGBColor[0.894471, 0.5250334285714284, 0.2542395714285713], 
             UndirectedEdge[23, 155] -> 
             RGBColor[
              0.5863123571428572, 0.6485279285714285, 0.8438048571428571], 
             UndirectedEdge[127, 251] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[241, 290] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[85, 234] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[270, 289] -> 
             RGBColor[0.8527905, 0.6452381428571428, 0.5918934285714286], 
             UndirectedEdge[69, 258] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[52, 289] -> 
             RGBColor[
              0.8975810714285714, 0.6807742857142856, 0.5899719285714285], 
             UndirectedEdge[47, 170] -> 
             RGBColor[
              0.9055083571428572, 0.5628944285714286, 0.45916335714285716`], 
             UndirectedEdge[72, 241] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[115, 210] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[166, 239] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[180, 215] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[51, 254] -> 
             RGBColor[
              0.8351822142857144, 0.5098931428571429, 0.5750317142857142], 
             UndirectedEdge[109, 227] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[203, 255] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[257, 272] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[32, 128] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[39, 76] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[144, 221] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[165, 262] -> 
             RGBColor[
              0.8720902142857143, 0.742105285714286, 0.6083590714285714], 
             UndirectedEdge[101, 226] -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             UndirectedEdge[56, 191] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[63, 71] -> RGBColor[0.984192, 0.987731, 0.911643],
              UndirectedEdge[137, 289] -> 
             RGBColor[
              0.9231166428571429, 0.6982394285714284, 0.4760250714285714], 
             UndirectedEdge[148, 295] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[10, 119] -> 
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`], 
             UndirectedEdge[115, 231] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[33, 171] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[173, 234] -> 
             RGBColor[
              0.8048095000000002, 0.6892778571428575, 0.6017240714285714], 
             UndirectedEdge[69, 173] -> 
             RGBColor[
              0.8048095000000002, 0.6892778571428575, 0.6017240714285714], 
             UndirectedEdge[4, 263] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[134, 160] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[7, 205] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[23, 106] -> 
             RGBColor[
              0.44870550000000003`, 0.5426992142857143, 0.9530382142857143], 
             UndirectedEdge[45, 96] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[65, 210] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[138, 211] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[72, 210] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[37, 41] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[52, 88] -> 
             RGBColor[
              0.7519839999999999, 0.8057464285714286, 0.9703062142857143], 
             UndirectedEdge[157, 285] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[135, 265] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 
             UndirectedEdge[17, 42] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[242, 250] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[81, 202] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[229, 259] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[40, 81] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[100, 119] -> 
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428572], 
             UndirectedEdge[81, 269] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[180, 233] -> 
             RGBColor[
              0.7519839999999999, 0.8057464285714286, 0.9703062142857143], 
             UndirectedEdge[33, 184] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[103, 168] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[49, 238] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[97, 120] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 
             UndirectedEdge[117, 212] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142857, 0.9722277142857143], 
             UndirectedEdge[270, 278] -> 
             RGBColor[
              0.8720902142857143, 0.742105285714286, 0.6083590714285715], 
             UndirectedEdge[26, 165] -> 
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428572], 
             UndirectedEdge[65, 70] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[56, 223] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[207, 212] -> 
             RGBColor[
              0.4257709285714285, 0.5385553571428572, 0.9492239285714286], 
             UndirectedEdge[171, 184] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[32, 205] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[23, 31] -> 
             RGBColor[
              0.5863123571428572, 0.6485279285714285, 0.8438048571428571], 
             UndirectedEdge[235, 274] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[178, 199] -> 
             RGBColor[
              0.6399127142857143, 0.7173828571428572, 0.9655927142857142], 
             UndirectedEdge[117, 158] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[112, 190] -> 
             RGBColor[0.49812300000000004`, 0.2197605, 0.5488595000000001], 
             UndirectedEdge[64, 213] -> 
             RGBColor[
              0.6399127142857143, 0.7173828571428572, 0.9655927142857142], 
             UndirectedEdge[127, 205] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[121, 263] -> 
             RGBColor[
              0.9124627142857145, 0.6868797142857146, 0.2482285714285715], 
             UndirectedEdge[14, 213] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142857, 0.9722277142857143], 
             UndirectedEdge[109, 111] -> 
             RGBColor[
              0.7773192142857142, 0.8214162857142857, 0.7352040000000001], 
             UndirectedEdge[55, 108] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[40, 162] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[15, 225] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[31, 59] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[210, 227] -> 
             RGBColor[
              0.9124627142857145, 0.6868797142857146, 0.2482285714285715], 
             UndirectedEdge[52, 93] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[32, 293] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[99, 209] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[201, 299] -> 
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`], 
             UndirectedEdge[127, 148] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[24, 226] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[144, 264] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[148, 217] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[230, 288] -> 
             RGBColor[0.905308, 0.5610991428571428, 0.3380080000000001], 
             UndirectedEdge[1, 83] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[15, 214] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[173, 249] -> 
             RGBColor[
              0.7262382142857142, 0.6266562857142859, 0.5947413571428573], 
             UndirectedEdge[114, 204] -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             UndirectedEdge[77, 95] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[52, 295] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[7, 103] -> 
             RGBColor[
              0.8934179285714287, 0.8304337142857144, 0.6257149285714285], 
             UndirectedEdge[29, 99] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[28, 144] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[75, 185] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[227, 291] -> 
             RGBColor[
              0.9124627142857145, 0.6868797142857146, 0.2482285714285715], 
             UndirectedEdge[76, 192] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[59, 72] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[104, 254] -> 
             RGBColor[
              0.8542270000000001, 0.3663391428571431, 0.1975453571428572], 
             UndirectedEdge[32, 237] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[25, 232] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[9, 141] -> 
             RGBColor[
              0.8261372142857144, 0.7776062857142859, 0.6190799285714286], 
             UndirectedEdge[22, 48] -> 
             RGBColor[
              0.8261372142857144, 0.7776062857142859, 0.6190799285714286], 
             UndirectedEdge[25, 160] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[72, 106] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[4, 186] -> RGBColor[0.984192, 0.987731, 0.911643],
              UndirectedEdge[78, 182] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[106, 211] -> 
             RGBColor[
              0.8261372142857144, 0.7776062857142859, 0.6190799285714286], 
             UndirectedEdge[180, 245] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[136, 280] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[82, 140] -> 
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861], 
             UndirectedEdge[50, 219] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[251, 278] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[80, 150] -> 
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428572], 
             UndirectedEdge[26, 183] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[243, 256] -> 
             RGBColor[
              0.5607767857142857, 0.6310627857142858, 0.9577517142857144], 
             UndirectedEdge[184, 248] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[4, 255] -> RGBColor[0.984192, 0.987731, 0.911643],
              UndirectedEdge[37, 280] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[188, 260] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[70, 266] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[103, 127] -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             UndirectedEdge[37, 268] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[186, 196] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[139, 274] -> 
             RGBColor[
              0.8261372142857144, 0.7776062857142859, 0.6190799285714286], 
             UndirectedEdge[15, 255] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[118, 195] -> 
             RGBColor[0.905308, 0.5610991428571428, 0.3380080000000001], 
             UndirectedEdge[125, 128] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[61, 177] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[117, 276] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142857, 0.9722277142857143], 
             UndirectedEdge[7, 154] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142857, 0.7488217142857143], 
             UndirectedEdge[59, 198] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[83, 197] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142857, 0.9722277142857143], 
             UndirectedEdge[243, 283] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[95, 225] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[21, 74] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.35486971428571434`], 
             UndirectedEdge[62, 225] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[236, 267] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[123, 300] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[111, 218] -> 
             RGBColor[
              0.8558905000000001, 0.8840378571428572, 0.7421867142857144], 
             UndirectedEdge[61, 161] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[58, 180] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[188, 236] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[41, 268] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[65, 138] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[241, 291] -> 
             RGBColor[
              0.7262382142857142, 0.6266562857142859, 0.5947413571428571], 
             UndirectedEdge[270, 295] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[127, 212] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[105, 274] -> 
             RGBColor[
              0.6399127142857143, 0.7173828571428572, 0.9655927142857142], 
             UndirectedEdge[128, 142] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[38, 57] -> 
             RGBColor[
              0.9055083571428572, 0.5628944285714286, 0.45916335714285716`], 
             UndirectedEdge[135, 255] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[46, 196] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002], 
             UndirectedEdge[138, 210] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[72, 109] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[277, 282] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[62, 117] -> 
             RGBColor[
              0.8934179285714287, 0.8304337142857144, 0.6257149285714285], 
             UndirectedEdge[33, 126] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[217, 278] -> 
             RGBColor[
              0.9124627142857145, 0.6868797142857146, 0.2482285714285715], 
             UndirectedEdge[228, 264] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[121, 239] -> 
             RGBColor[
              0.7262382142857142, 0.6266562857142859, 0.5947413571428573], 
             UndirectedEdge[56, 84] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[45, 120] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[67, 234] -> 
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[153, 192] -> 
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855], 
             UndirectedEdge[77, 127] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[36, 152] -> 
             RGBColor[0.5815595, 0.6465624999999999, 0.922572], 
             UndirectedEdge[22, 122] -> 
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855], 
             UndirectedEdge[68, 218] -> 
             RGBColor[
              0.44870550000000003`, 0.5426992142857143, 0.9530382142857143], 
             UndirectedEdge[56, 148] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[7, 130] -> 
             RGBColor[
              0.8934179285714287, 0.8304337142857144, 0.6257149285714285], 
             UndirectedEdge[58, 296] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[104, 116] -> 
             RGBColor[
              0.8718352857142857, 0.501684142857143, 0.21440707142857146`], 
             UndirectedEdge[252, 279] -> 
             RGBColor[
              0.8718352857142857, 0.501684142857143, 0.21440707142857146`], 
             UndirectedEdge[64, 173] -> 
             RGBColor[
              0.8048095000000002, 0.6892778571428575, 0.6017240714285714], 
             UndirectedEdge[109, 155] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[151, 258] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[167, 216] -> 
             RGBColor[0.48667657142857135`, 0.5930234285714285, 0.953042], 
             UndirectedEdge[12, 258] -> 
             RGBColor[
              0.5607767857142856, 0.6310627857142856, 0.9577517142857144], 
             UndirectedEdge[151, 239] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[136, 226] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[59, 210] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[191, 205] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.4924907142857144], 
             UndirectedEdge[212, 276] -> 
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861], 
             UndirectedEdge[218, 292] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[144, 245] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[1, 277] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[64, 239] -> 
             RGBColor[
              0.6399127142857143, 0.7173828571428572, 0.9655927142857142], 
             UndirectedEdge[128, 256] -> 
             RGBColor[
              0.5607767857142857, 0.6310627857142858, 0.9577517142857144], 
             UndirectedEdge[7, 81] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[32, 145] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[84, 247] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[215, 259] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[187, 233] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[37, 152] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[257, 300] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[10, 244] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[98, 157] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[13, 271] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[202, 203] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[166, 195] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[260, 287] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[212, 214] -> 
             RGBColor[
              0.7773192142857142, 0.8214162857142857, 0.7352040000000001], 
             UndirectedEdge[25, 113] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[244, 280] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[58, 134] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[64, 263] -> 
             RGBColor[
              0.8261372142857144, 0.7776062857142859, 0.6190799285714286], 
             UndirectedEdge[182, 261] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[150, 277] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.4924907142857144], 
             UndirectedEdge[86, 202] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[257, 267] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[134, 245] -> 
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428572], 
             UndirectedEdge[187, 297] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[75, 292] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[54, 174] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[44, 108] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[94, 141] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[185, 262] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[40, 202] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[110, 191] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[92, 125] -> 
             RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             UndirectedEdge[72, 226] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[130, 162] -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             UndirectedEdge[29, 43] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[152, 268] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[4, 62] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[18, 184] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[95, 159] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[154, 255] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[140, 269] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[10, 161] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857144], 
             UndirectedEdge[216, 293] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[188, 294] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[32, 282] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[251, 282] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[181, 299] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[60, 159] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[137, 217] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[20, 152] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[62, 196] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[251, 289] -> 
             RGBColor[
              0.8975810714285714, 0.6807742857142856, 0.5899719285714285], 
             UndirectedEdge[104, 283] -> 
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428573], 
             UndirectedEdge[45, 294] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[15, 158] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[150, 237] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[169, 228] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[159, 251] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[203, 293] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[145, 282] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[195, 234] -> 
             RGBColor[0.7679015, 0.45706571428571435`, 0.5683967142857143], 
             UndirectedEdge[156, 270] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[25, 134] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[158, 276] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[268, 280] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[8, 186] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[32, 256] -> 
             RGBColor[
              0.5863123571428571, 0.6485279285714286, 0.8438048571428571], 
             UndirectedEdge[60, 168] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[162, 216] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[106, 115] -> 
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855], 
             UndirectedEdge[77, 276] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[80, 281] -> 
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[130, 293] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[39, 118] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[58, 245] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[54, 143] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[239, 258] -> 
             RGBColor[
              0.7519839999999999, 0.8057464285714286, 0.9703062142857143], 
             UndirectedEdge[184, 222] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[143, 298] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[203, 269] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[107, 139] -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             UndirectedEdge[108, 283] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[173, 186] -> 
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428573], 
             UndirectedEdge[164, 296] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[11, 116] -> 
             RGBColor[
              0.8975810714285714, 0.6807742857142856, 0.5899719285714285], 
             UndirectedEdge[43, 229] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[128, 149] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[221, 232] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[8, 85] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[20, 41] -> 
             RGBColor[0.894471, 0.5250334285714284, 0.2542395714285713], 
             UndirectedEdge[108, 252] -> 
             RGBColor[
              0.9124627142857145, 0.6868797142857146, 0.2482285714285715], 
             UndirectedEdge[65, 241] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[231, 245] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[80, 167] -> 
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[17, 201] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142857, 0.7488217142857143], 
             UndirectedEdge[57, 223] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[162, 202] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[3, 59] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[180, 187] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[193, 215] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[43, 78] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[56, 251] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[261, 284] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[36, 41] -> 
             RGBColor[0.575275, 0.6106669285714286, 0.6388810714285713], 
             UndirectedEdge[95, 168] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[194, 280] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[99, 182] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[94, 97] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[79, 240] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[83, 198] -> 
             RGBColor[
              0.8720902142857143, 0.742105285714286, 0.6083590714285715], 
             UndirectedEdge[69, 213] -> 
             RGBColor[
              0.6399127142857143, 0.7173828571428572, 0.9655927142857142], 
             UndirectedEdge[214, 286] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002], 
             UndirectedEdge[277, 293] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[107, 179] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[43, 199] -> 
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855], 
             UndirectedEdge[192, 222] -> 
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[130, 202] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[4, 265] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[121, 173] -> 
             RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             UndirectedEdge[53, 107] -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             UndirectedEdge[172, 238] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[210, 211] -> 
             RGBColor[
              0.9124627142857145, 0.6868797142857146, 0.2482285714285715], 
             UndirectedEdge[180, 221] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[196, 212] -> 
             RGBColor[
              0.7773192142857142, 0.8214162857142857, 0.7352040000000001], 
             UndirectedEdge[160, 176] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[115, 193] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[21, 300] -> 
             RGBColor[
              0.9120792857142856, 0.6603784285714284, 0.2711012857142856], 
             UndirectedEdge[75, 235] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[77, 255] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[62, 286] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[46, 225] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[37, 161] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[3, 162] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[107, 274] -> 
             RGBColor[
              0.8261372142857144, 0.7776062857142859, 0.6190799285714286], 
             UndirectedEdge[6, 147] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[8, 135] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[186, 249] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[277, 281] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[256, 277] -> 
             RGBColor[
              0.5863123571428572, 0.6485279285714285, 0.8438048571428571], 
             UndirectedEdge[8, 249] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[114, 254] -> 
             RGBColor[
              0.8755547142857143, 0.45466757142857156`, 0.2149012142857143], 
             UndirectedEdge[223, 270] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142857, 0.7488217142857143], 
             UndirectedEdge[120, 294] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[23, 290] -> 
             RGBColor[
              0.5563587142857143, 0.5403010714285715, 0.5995427142857144], 
             UndirectedEdge[7, 293] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[95, 191] -> 
             RGBColor[
              0.9124627142857145, 0.6868797142857146, 0.2482285714285715], 
             UndirectedEdge[65, 194] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[94, 188] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[24, 162] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[34, 84] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[130, 201] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[74, 260] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857144], 
             UndirectedEdge[69, 85] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[220, 262] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[26, 262] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[217, 270] -> 
             RGBColor[
              0.8934179285714287, 0.8304337142857144, 0.6257149285714285], 
             UndirectedEdge[221, 245] -> 
             RGBColor[
              0.9124627142857145, 0.6868797142857146, 0.2482285714285715], 
             UndirectedEdge[3, 24] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[59, 197] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[54, 235] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[159, 282] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[6, 53] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[31, 210] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[137, 273] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[99, 259] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[16, 151] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[24, 227] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[87, 202] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[17, 94] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[5, 92] -> 
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`], 
             UndirectedEdge[72, 290] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[103, 212] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[112, 133] -> 
             RGBColor[
              0.5159862142857143, 0.5955266428571429, 0.9596732142857143], 
             UndirectedEdge[71, 244] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[142, 197] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[117, 196] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142857, 0.7488217142857143], 
             UndirectedEdge[131, 188] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[13, 282] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142857, 0.7488217142857143], 
             UndirectedEdge[139, 143] -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             UndirectedEdge[45, 89] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[127, 269] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[25, 79] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[29, 78] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[150, 179] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[11, 198] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[135, 286] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857144], 
             UndirectedEdge[101, 104] -> 
             RGBColor[
              0.9124627142857145, 0.6868797142857146, 0.2482285714285715], 
             UndirectedEdge[3, 290] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[158, 212] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[102, 175] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[103, 255] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[3, 65] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[148, 270] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[49, 298] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[15, 103] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[4, 15] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[83, 290] -> 
             RGBColor[
              0.8934179285714287, 0.8304337142857144, 0.6257149285714285], 
             UndirectedEdge[182, 284] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[32, 92] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[87, 203] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[115, 169] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[111, 143] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[163, 274] -> 
             RGBColor[
              0.6399127142857143, 0.7173828571428572, 0.9655927142857142], 
             UndirectedEdge[96, 260] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 
             UndirectedEdge[27, 227] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[103, 205] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[27, 216] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[145, 293] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[96, 133] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[127, 159] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[186, 214] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[111, 262] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142857, 0.7488217142857143], 
             UndirectedEdge[33, 157] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[112, 131] -> 
             RGBColor[0.586112, 0.6467326428571429, 0.7226495000000002], 
             UndirectedEdge[37, 55] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[20, 71] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[37, 252] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[120, 178] -> 
             RGBColor[
              0.7519839999999999, 0.8057464285714286, 0.9703062142857143], 
             UndirectedEdge[113, 231] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857144], 
             UndirectedEdge[7, 181] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[42, 299] -> 
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428572], 
             UndirectedEdge[64, 234] -> 
             RGBColor[
              0.7184840000000001, 0.7800044285714287, 0.9725754285714285], 
             UndirectedEdge[78, 261] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[10, 100] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[6, 88] -> 
             RGBColor[
              0.7519839999999999, 0.8057464285714286, 0.9703062142857143], 
             UndirectedEdge[36, 208] -> 
             RGBColor[
              0.5607767857142856, 0.6310627857142856, 0.9577517142857144], 
             UndirectedEdge[92, 142] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[237, 293] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[127, 145] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[90, 285] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[134, 176] -> 
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428572], 
             UndirectedEdge[28, 297] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[20, 136] -> 
             RGBColor[0.905308, 0.5610991428571428, 0.3380080000000001], 
             UndirectedEdge[113, 134] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[12, 181] -> 
             RGBColor[
              0.5607767857142856, 0.6310627857142856, 0.9577517142857144], 
             UndirectedEdge[84, 217] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[126, 153] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[217, 251] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[211, 266] -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             UndirectedEdge[156, 282] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[92, 256] -> 
             RGBColor[0.535031, 0.4519726428571431, 0.5821868571428572], 
             UndirectedEdge[56, 246] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[223, 246] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002], 
             UndirectedEdge[66, 228] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[170, 261] -> 
             RGBColor[
              0.9055083571428572, 0.5628944285714286, 0.45916335714285716`], 
             UndirectedEdge[104, 287] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[255, 258] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[27, 162] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[162, 169] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[90, 166] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[74, 257] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[82, 203] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[1, 142] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[82, 145] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[77, 203] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[12, 27] -> 
             RGBColor[0.5815595, 0.6465624999999999, 0.922572], 
             UndirectedEdge[54, 185] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[35, 165] -> 
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`], 
             UndirectedEdge[60, 95] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[47, 112] -> 
             RGBColor[
              0.5863123571428571, 0.6485279285714286, 0.8438048571428571], 
             UndirectedEdge[24, 59] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[239, 285] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[173, 286] -> 
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`], 
             UndirectedEdge[17, 40] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[226, 241] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[255, 286] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[95, 271] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[189, 260] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 
             UndirectedEdge[193, 245] -> 
             RGBColor[
              0.8720902142857143, 0.742105285714286, 0.6083590714285715], 
             UndirectedEdge[84, 223] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[44, 61] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[262, 292] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[153, 248] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[78, 99] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[199, 261] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[58, 215] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[23, 197] -> 
             RGBColor[
              0.37013421428571425`, 0.48007764285714283`, 0.9460554999999999],
              UndirectedEdge[196, 214] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002], 
             UndirectedEdge[88, 289] -> 
             RGBColor[
              0.7069384999999999, 0.5297891428571427, 0.5782757142857142], 
             UndirectedEdge[47, 96] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[179, 205] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[72, 194] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[140, 299] -> 
             RGBColor[
              0.7262382142857142, 0.6266562857142859, 0.5947413571428571], 
             UndirectedEdge[134, 297] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[67, 195] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[24, 155] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[156, 277] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[267, 272] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[71, 177] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[188, 281] -> 
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855], 
             UndirectedEdge[1, 150] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[84, 246] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[58, 230] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[74, 189] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857144], 
             UndirectedEdge[48, 71] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[80, 205] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[1, 32] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[229, 233] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[54, 172] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[61, 194] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[177, 194] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[7, 42] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[26, 75] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[170, 190] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[20, 36] -> 
             RGBColor[0.498123, 0.2197605, 0.5488595000000001], 
             UndirectedEdge[119, 161] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[212, 225] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[102, 253] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[91, 179] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[118, 239] -> 
             RGBColor[
              0.7773192142857142, 0.8214162857142857, 0.7352040000000001], 
             UndirectedEdge[105, 298] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[90, 239] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[208, 252] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[117, 214] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142857, 0.7488217142857143], 
             UndirectedEdge[179, 282] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[44, 268] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002], 
             UndirectedEdge[53, 124] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[42, 81] -> RGBColor[0.984192, 0.987731, 0.911643],
              UndirectedEdge[173, 213] -> 
             RGBColor[
              0.7262382142857142, 0.6266562857142859, 0.5947413571428573], 
             UndirectedEdge[119, 122] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[68, 111] -> 
             RGBColor[0.586112, 0.6467326428571429, 0.7226495000000002], 
             UndirectedEdge[34, 53] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[85, 263] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[37, 208] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[256, 293] -> 
             RGBColor[0.5815595, 0.6465624999999999, 0.922572], 
             UndirectedEdge[76, 153] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[135, 213] -> 
             RGBColor[
              0.7519839999999999, 0.8057464285714286, 0.9703062142857143], 
             UndirectedEdge[36, 55] -> 
             RGBColor[0.575275, 0.6106669285714286, 0.6388810714285713], 
             UndirectedEdge[121, 135] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[83, 226] -> 
             RGBColor[
              0.8934179285714287, 0.8304337142857144, 0.6257149285714285], 
             UndirectedEdge[60, 127] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[247, 271] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[202, 269] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[190, 284] -> 
             RGBColor[
              0.9055083571428572, 0.5628944285714286, 0.45916335714285716`], 
             UndirectedEdge[53, 217] -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             UndirectedEdge[42, 87] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[205, 225] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[110, 246] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[191, 251] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[23, 83] -> 
             RGBColor[
              0.5159862142857143, 0.5955266428571429, 0.9596732142857143], 
             UndirectedEdge[226, 291] -> 
             RGBColor[
              0.9124627142857145, 0.6868797142857146, 0.2482285714285715], 
             UndirectedEdge[60, 276] -> 
             RGBColor[
              0.7773192142857142, 0.8214162857142857, 0.7352040000000001], 
             UndirectedEdge[27, 155] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[167, 203] -> 
             RGBColor[
              0.6918173571428571, 0.7236127142857142, 0.6458675714285713], 
             UndirectedEdge[137, 271] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[52, 247] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[81, 299] -> 
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428572], 
             UndirectedEdge[31, 290] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[79, 288] -> 
             RGBColor[
              0.9055083571428572, 0.5628944285714286, 0.45916335714285716`], 
             UndirectedEdge[237, 281] -> 
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855], 
             UndirectedEdge[43, 215] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[56, 295] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[89, 94] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[92, 237] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[126, 285] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[4, 214] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[220, 222] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[199, 209] -> 
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[290, 291] -> 
             RGBColor[
              0.9124627142857145, 0.6868797142857146, 0.2482285714285715], 
             UndirectedEdge[91, 150] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[60, 148] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[81, 140] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[142, 256] -> 
             RGBColor[0.575275, 0.6106669285714285, 0.6388810714285713], 
             UndirectedEdge[30, 123] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[53, 289] -> 
             RGBColor[0.893163, 0.5900125714285714, 0.23176292857142858`], 
             UndirectedEdge[274, 289] -> 
             RGBColor[
              0.7855097857142858, 0.5924107142857142, 0.5852584285714285], 
             UndirectedEdge[11, 114] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[137, 247] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[84, 191] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[17, 120] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[126, 222] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[184, 224] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[278, 295] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.4924907142857144], 
             UndirectedEdge[28, 245] -> 
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428572], 
             UndirectedEdge[14, 186] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[227, 241] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[121, 154] -> 
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`], 
             UndirectedEdge[187, 230] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[125, 277] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.4924907142857144], 
             UndirectedEdge[62, 158] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[20, 61] -> 
             RGBColor[0.894471, 0.5250334285714284, 0.2542395714285713], 
             UndirectedEdge[64, 258] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[94, 294] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[125, 237] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[267, 300] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[165, 175] -> 
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428573], 
             UndirectedEdge[67, 263] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[163, 298] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[92, 149] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[95, 276] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[70, 231] -> 
             RGBColor[
              0.7519839999999999, 0.8057464285714286, 0.9703062142857143], 
             UndirectedEdge[239, 263] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[116, 204] -> 
             RGBColor[0.893163, 0.5900125714285714, 0.23176292857142858`], 
             UndirectedEdge[121, 258] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[95, 148] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[60, 77] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[42, 269] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[61, 136] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[95, 251] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[158, 265] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[152, 208] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[153, 285] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[61, 279] -> 
             RGBColor[
              0.9120792857142856, 0.6603784285714284, 0.2711012857142856], 
             UndirectedEdge[82, 168] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[4, 249] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[75, 163] -> 
             RGBColor[
              0.7519839999999999, 0.8057464285714286, 0.9703062142857143], 
             UndirectedEdge[59, 290] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[205, 251] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[183, 224] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[170, 178] -> 
             RGBColor[0.6893302142857143, 0.39444414285714285`, 0.561414], 
             UndirectedEdge[102, 238] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[89, 236] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[65, 231] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[25, 245] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[217, 223] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[254, 283] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[168, 205] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[142, 243] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[57, 278] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[185, 218] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[16, 248] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[184, 275] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[127, 191] -> 
             RGBColor[
              0.9124627142857145, 0.6868797142857146, 0.2482285714285715], 
             UndirectedEdge[33, 153] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[83, 243] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[94, 281] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[140, 293] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[126, 220] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[76, 220] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[90, 126] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[35, 102] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857144], 
             UndirectedEdge[105, 235] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[21, 287] -> 
             RGBColor[
              0.9120792857142856, 0.6603784285714284, 0.2711012857142856], 
             UndirectedEdge[160, 245] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[235, 298] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[15, 196] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[13, 274] -> 
             RGBColor[
              0.8558905000000001, 0.8840378571428572, 0.7421867142857144], 
             UndirectedEdge[2, 172] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[247, 295] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[159, 225] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[204, 254] -> 
             RGBColor[
              0.8755547142857143, 0.45466757142857156`, 0.2149012142857143], 
             UndirectedEdge[61, 252] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[4, 173] -> 
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428572], 
             UndirectedEdge[230, 245] -> 
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`], 
             UndirectedEdge[137, 295] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[109, 192] -> 
             RGBColor[
              0.6399127142857143, 0.7173828571428572, 0.9655927142857142], 
             UndirectedEdge[178, 229] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[91, 93] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[143, 185] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[139, 273] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[130, 281] -> 
             RGBColor[
              0.8261372142857144, 0.7776062857142859, 0.6190799285714286], 
             UndirectedEdge[220, 248] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[88, 273] -> 
             RGBColor[
              0.7773192142857142, 0.8214162857142857, 0.7352040000000001], 
             UndirectedEdge[24, 218] -> 
             RGBColor[
              0.8558905000000001, 0.8840378571428572, 0.7421867142857144], 
             UndirectedEdge[66, 215] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[151, 154] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[8, 64] -> 
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855], 
             UndirectedEdge[71, 108] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[43, 182] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[58, 297] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[46, 207] -> 
             RGBColor[
              0.6417487142857143, 0.7052103571428572, 0.7258179285714287], 
             UndirectedEdge[100, 266] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[12, 151] -> 
             RGBColor[
              0.5563587142857143, 0.5403010714285715, 0.5995427142857144], 
             UndirectedEdge[196, 265] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857144], 
             UndirectedEdge[93, 139] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[30, 104] -> 
             RGBColor[
              0.8720902142857143, 0.742105285714286, 0.6083590714285715], 
             UndirectedEdge[85, 121] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[79, 160] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[60, 196] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002], 
             UndirectedEdge[25, 297] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[9, 133] -> 
             RGBColor[
              0.7857647142857144, 0.8328318571428572, 0.9792104285714285], 
             UndirectedEdge[151, 192] -> 
             RGBColor[
              0.8261372142857144, 0.7776062857142859, 0.6190799285714286], 
             UndirectedEdge[45, 141] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[177, 280] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[141, 188] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[129, 183] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[41, 55] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[120, 261] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[71, 279] -> 
             RGBColor[
              0.9183637857142857, 0.6962739999999998, 0.5547922142857142], 
             UndirectedEdge[180, 230] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857144], 
             UndirectedEdge[106, 194] -> 
             RGBColor[
              0.7857647142857144, 0.8328318571428572, 0.9792104285714285], 
             UndirectedEdge[90, 234] -> 
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855], 
             UndirectedEdge[44, 136] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002], 
             UndirectedEdge[120, 131] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857144], 
             UndirectedEdge[44, 279] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.35486971428571434`], 
             UndirectedEdge[105, 139] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[157, 184] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[83, 149] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[145, 168] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[112, 170] -> 
             RGBColor[0.49812300000000004`, 0.2197605, 0.5488595000000001], 
             UndirectedEdge[159, 270] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[86, 162] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[3, 264] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[60, 282] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142857, 0.7488217142857143], 
             UndirectedEdge[135, 186] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[89, 294] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[201, 203] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[181, 203] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[70, 211] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[156, 159] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[56, 270] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[113, 264] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[144, 240] -> 
             RGBColor[
              0.7519839999999999, 0.8057464285714286, 0.9703062142857143], 
             UndirectedEdge[231, 232] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[90, 248] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[27, 109] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[42, 145] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[160, 230] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[247, 251] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[109, 220] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[139, 163] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[31, 279] -> 
             RGBColor[
              0.9231166428571429, 0.6982394285714284, 0.4760250714285714], 
             UndirectedEdge[9, 112] -> 
             RGBColor[
              0.4487055000000001, 0.5426992142857143, 0.9530382142857143], 
             UndirectedEdge[196, 276] -> 
             RGBColor[
              0.7773192142857142, 0.8214162857142857, 0.7352040000000001], 
             UndirectedEdge[137, 251] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[162, 181] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[96, 236] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[251, 295] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[20, 268] -> 
             RGBColor[0.905308, 0.5610991428571428, 0.3380080000000001], 
             UndirectedEdge[187, 215] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[55, 250] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[193, 230] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142857, 0.7488217142857143], 
             UndirectedEdge[55, 242] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[51, 116] -> 
             RGBColor[0.8527905, 0.6452381428571428, 0.5918934285714286], 
             UndirectedEdge[130, 203] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[34, 124] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[190, 261] -> 
             RGBColor[
              0.9055083571428572, 0.5628944285714286, 0.45916335714285716`], 
             UndirectedEdge[76, 85] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[130, 237] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[175, 183] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[93, 289] -> 
             RGBColor[
              0.9183637857142857, 0.6962739999999998, 0.5547922142857142], 
             UndirectedEdge[69, 234] -> 
             RGBColor[
              0.7184840000000001, 0.7800044285714287, 0.9725754285714285], 
             UndirectedEdge[32, 269] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[226, 243] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[72, 218] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[81, 181] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[8, 67] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[145, 156] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[20, 177] -> 
             RGBColor[
              0.9055083571428572, 0.5628944285714286, 0.45916335714285716`], 
             UndirectedEdge[180, 297] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 
             UndirectedEdge[140, 216] -> 
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861], 
             UndirectedEdge[287, 300] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[140, 167] -> 
             RGBColor[0.48667657142857135`, 0.5930234285714285, 0.953042], 
             UndirectedEdge[248, 285] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[185, 292] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[23, 241] -> 
             RGBColor[
              0.37013421428571425`, 0.48007764285714283`, 0.9460554999999999],
              UndirectedEdge[10, 48] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[46, 62] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[15, 276] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[85, 154] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[32, 179] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[145, 277] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[58, 164] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[18, 253] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[59, 136] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[232, 288] -> 
             RGBColor[
              0.9055083571428572, 0.5628944285714286, 0.45916335714285716`], 
             UndirectedEdge[136, 177] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[31, 65] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[62, 214] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[24, 109] -> 
             RGBColor[
              0.7773192142857142, 0.8214162857142857, 0.7352040000000001], 
             UndirectedEdge[71, 268] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[64, 118] -> 
             RGBColor[
              0.8558905000000001, 0.8840378571428572, 0.7421867142857144], 
             UndirectedEdge[21, 206] -> 
             RGBColor[
              0.9231166428571429, 0.6982394285714284, 0.4760250714285715], 
             UndirectedEdge[6, 124] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[7, 140] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142857, 0.9722277142857143], 
             UndirectedEdge[78, 229] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[67, 213] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[189, 300] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[77, 225] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[153, 239] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[7, 168] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[5, 256] -> 
             RGBColor[0.586112, 0.6467326428571428, 0.7226495000000002], 
             UndirectedEdge[193, 200] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[17, 202] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[12, 220] -> 
             RGBColor[0.5815595, 0.6465624999999999, 0.922572], 
             UndirectedEdge[196, 207] -> 
             RGBColor[
              0.6417487142857143, 0.7052103571428572, 0.7258179285714287], 
             UndirectedEdge[222, 285] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[169, 227] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[139, 298] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[210, 241] -> 
             RGBColor[
              0.7262382142857142, 0.6266562857142859, 0.5947413571428573], 
             UndirectedEdge[58, 288] -> 
             RGBColor[0.894471, 0.5250334285714284, 0.2542395714285713], 
             UndirectedEdge[85, 258] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[87, 162] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[222, 248] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[76, 87] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[80, 282] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[273, 289] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.35486971428571434`], 
             UndirectedEdge[215, 296] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[142, 277] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[134, 180] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[86, 178] -> 
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861], 
             UndirectedEdge[3, 210] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[79, 176] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[131, 141] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[150, 256] -> 
             RGBColor[0.535031, 0.4519726428571431, 0.5821868571428572], 
             UndirectedEdge[74, 300] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[25, 230] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[165, 253] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[223, 295] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[164, 221] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[70, 138] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[165, 224] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.4924907142857144], 
             UndirectedEdge[87, 258] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[90, 222] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[163, 185] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[64, 286] -> 
             RGBColor[
              0.8558905000000001, 0.8840378571428572, 0.7421867142857144], 
             UndirectedEdge[131, 199] -> 
             RGBColor[
              0.8558905000000001, 0.8840378571428572, 0.7421867142857144], 
             UndirectedEdge[2, 49] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[51, 283] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[66, 187] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[120, 170] -> 
             RGBColor[
              0.8799727857142856, 0.5454292857142857, 0.5731102142857143], 
             UndirectedEdge[17, 182] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[156, 179] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[199, 284] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[210, 291] -> 
             RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             UndirectedEdge[212, 265] -> 
             RGBColor[
              0.7519839999999999, 0.8057464285714286, 0.9703062142857143], 
             UndirectedEdge[85, 173] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[47, 146] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[198, 283] -> 
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428573], 
             UndirectedEdge[168, 212] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[56, 271] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.44870550000000003`, 0.5426992142857143, 0.9530382142857143], 
             UndirectedEdge[159, 191] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[72, 83] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[179, 277] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[86, 182] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[80, 293] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[9, 96] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[51, 226] -> 
             RGBColor[
              0.8934179285714287, 0.8304337142857144, 0.6257149285714285], 
             UndirectedEdge[185, 235] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[136, 210] -> 
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`], 
             UndirectedEdge[78, 284] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[81, 216] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[2, 165] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[181, 216] -> 
             RGBColor[
              0.7519839999999999, 0.8057464285714286, 0.9703062142857143], 
             UndirectedEdge[7, 203] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[44, 177] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[140, 237] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[38, 124] -> 
             RGBColor[
              0.9055083571428572, 0.5628944285714286, 0.45916335714285716`], 
             UndirectedEdge[5, 59] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[35, 253] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[200, 231] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[213, 234] -> 
             RGBColor[
              0.6399127142857143, 0.7173828571428572, 0.9655927142857142], 
             UndirectedEdge[53, 88] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[150, 269] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.4924907142857144], 
             UndirectedEdge[4, 135] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[91, 139] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[28, 232] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[127, 276] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[60, 103] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[145, 159] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[20, 252] -> 
             RGBColor[
              0.8542270000000001, 0.3663391428571431, 0.1975453571428572], 
             UndirectedEdge[80, 128] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[167, 237] -> 
             RGBColor[
              0.6918173571428571, 0.7236127142857142, 0.6458675714285713], 
             UndirectedEdge[24, 291] -> 
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`], 
             UndirectedEdge[22, 244] -> 
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[51, 83] -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714285], 
             UndirectedEdge[29, 229] -> 
             RGBColor[
              0.9124627142857145, 0.6868797142857146, 0.2482285714285715], 
             UndirectedEdge[151, 181] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[22, 63] -> 
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[163, 292] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[247, 289] -> 
             RGBColor[
              0.9120792857142856, 0.6603784285714284, 0.2711012857142856], 
             UndirectedEdge[155, 299] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[31, 71] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[45, 260] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[80, 125] -> 
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428572], 
             UndirectedEdge[97, 261] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[107, 147] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[15, 286] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[94, 202] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[86, 130] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[73, 161] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[7, 167] -> 
             RGBColor[
              0.6325285714285714, 0.7084724285714286, 0.9666597142857143], 
             UndirectedEdge[288, 297] -> 
             RGBColor[
              0.8799727857142856, 0.5454292857142857, 0.5731102142857143], 
             UndirectedEdge[15, 46] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[1, 92] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[85, 213] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[2, 174] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[104, 204] -> 
             RGBColor[
              0.9124627142857145, 0.6868797142857146, 0.2482285714285715], 
             UndirectedEdge[125, 243] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[149, 243] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[35, 175] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[82, 201] -> 
             RGBColor[
              0.7773192142857142, 0.8214162857142857, 0.7352040000000001], 
             UndirectedEdge[39, 69] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[5, 204] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[107, 277] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[236, 260] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[11, 51] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[41, 242] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[53, 93] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[82, 293] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[76, 151] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[130, 269] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[13, 289] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.35486971428571434`], 
             UndirectedEdge[86, 120] -> 
             RGBColor[
              0.7519839999999999, 0.8057464285714286, 0.9703062142857143], 
             UndirectedEdge[86, 284] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[49, 102] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[27, 299] -> 
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428572], 
             UndirectedEdge[120, 182] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[97, 182] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[42, 130] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[15, 127] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[28, 176] -> 
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428572], 
             UndirectedEdge[26, 35] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[44, 59] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[155, 218] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[65, 155] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[55, 252] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[160, 296] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[88, 147] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[204, 243] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[65, 106] -> 
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855], 
             UndirectedEdge[115, 245] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[60, 205] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[75, 111] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857144], 
             UndirectedEdge[17, 86] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142857, 0.9722277142857143], 
             UndirectedEdge[67, 166] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[3, 169] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[7, 255] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[211, 231] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[218, 290] -> 
             RGBColor[
              0.8261372142857144, 0.7776062857142859, 0.6190799285714286], 
             UndirectedEdge[201, 269] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[34, 223] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[63, 208] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[131, 190] -> 
             RGBColor[0.905308, 0.5610991428571428, 0.3380080000000001], 
             UndirectedEdge[27, 181] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[108, 136] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[101, 254] -> 
             RGBColor[
              0.8755547142857143, 0.45466757142857156`, 0.2149012142857143], 
             UndirectedEdge[62, 212] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[69, 195] -> 
             RGBColor[0.7679015, 0.45706571428571435`, 0.5683967142857143], 
             UndirectedEdge[136, 252] -> 
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`], 
             UndirectedEdge[26, 175] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[24, 27] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[231, 266] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[153, 157] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[161, 244] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[128, 150] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[113, 200] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[211, 264] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[144, 232] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[208, 244] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[47, 133] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[181, 258] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 
             UndirectedEdge[53, 147] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[123, 267] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[59, 227] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[213, 286] -> 
             RGBColor[
              0.7773192142857142, 0.8214162857142857, 0.7352040000000001], 
             UndirectedEdge[16, 126] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[68, 109] -> 
             RGBColor[
              0.37013421428571425`, 0.48007764285714283`, 0.9460554999999999],
              UndirectedEdge[137, 156] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[181, 202] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[135, 214] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857144], 
             UndirectedEdge[166, 234] -> 
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[63, 152] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[130, 167] -> 
             RGBColor[
              0.6729010714285715, 0.6532468571428572, 0.6065292142857144], 
             UndirectedEdge[30, 74] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142857, 0.7488217142857143], 
             UndirectedEdge[31, 177] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[24, 72] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[39, 285] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[27, 72] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[109, 151] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[29, 178] -> 
             RGBColor[
              0.7262382142857142, 0.6266562857142859, 0.5947413571428573], 
             UndirectedEdge[149, 256] -> 
             RGBColor[0.575275, 0.6106669285714285, 0.6388810714285713], 
             UndirectedEdge[93, 137] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[7, 145] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[271, 278] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[15, 135] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[94, 130] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[265, 286] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857144], 
             UndirectedEdge[140, 201] -> 
             RGBColor[
              0.7773192142857142, 0.8214162857142857, 0.7352040000000001], 
             UndirectedEdge[29, 259] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.4924907142857144], 
             UndirectedEdge[21, 123] -> 
             RGBColor[
              0.9183637857142857, 0.6962739999999998, 0.5547922142857142], 
             UndirectedEdge[21, 189] -> 
             RGBColor[
              0.8975810714285714, 0.6807742857142856, 0.5899719285714287], 
             UndirectedEdge[107, 289] -> 
             RGBColor[0.893163, 0.5900125714285714, 0.23176292857142858`], 
             UndirectedEdge[17, 66] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[71, 208] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[6, 289] -> 
             RGBColor[
              0.8975810714285714, 0.6807742857142856, 0.5899719285714285], 
             UndirectedEdge[96, 132] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[55, 283] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[48, 244] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[110, 278] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[245, 288] -> 
             RGBColor[
              0.8542270000000001, 0.3663391428571431, 0.1975453571428572], 
             UndirectedEdge[106, 210] -> 
             RGBColor[
              0.8048095000000002, 0.6892778571428575, 0.6017240714285714], 
             UndirectedEdge[176, 296] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[82, 154] -> 
             RGBColor[
              0.7773192142857142, 0.8214162857142857, 0.7352040000000001], 
             UndirectedEdge[46, 117] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142857, 0.7488217142857143], 
             UndirectedEdge[249, 258] -> 
             RGBColor[
              0.7519839999999999, 0.8057464285714286, 0.9703062142857143], 
             UndirectedEdge[146, 170] -> 
             RGBColor[
              0.9055083571428572, 0.5628944285714286, 0.45916335714285716`], 
             UndirectedEdge[18, 129] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[13, 179] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857144], 
             UndirectedEdge[144, 160] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[17, 130] -> 
             RGBColor[
              0.8934179285714287, 0.8304337142857144, 0.6257149285714285], 
             UndirectedEdge[111, 163] -> 
             RGBColor[
              0.7773192142857142, 0.8214162857142857, 0.7352040000000001], 
             UndirectedEdge[107, 251] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[1, 198] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[168, 269] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[145, 201] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[197, 226] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[105, 174] -> 
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861], 
             UndirectedEdge[178, 284] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[201, 202] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[24, 65] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[134, 169] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[104, 300] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[168, 225] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[27, 202] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[113, 187] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[7, 201] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142857, 0.7488217142857143], 
             UndirectedEdge[51, 104] -> 
             RGBColor[
              0.8720902142857143, 0.742105285714286, 0.6083590714285715], 
             UndirectedEdge[2, 183] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[135, 249] -> 
             RGBColor[
              0.7519839999999999, 0.8057464285714286, 0.9703062142857143], 
             UndirectedEdge[84, 270] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[114, 116] -> 
             RGBColor[0.893163, 0.5900125714285714, 0.23176292857142858`], 
             UndirectedEdge[15, 168] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[42, 237] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[40, 140] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[42, 167] -> 
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[16, 285] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[8, 286] -> 
             RGBColor[
              0.9824599999999999, 0.9520055714285713, 0.4280295714285714], 
             UndirectedEdge[9, 236] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[54, 238] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[165, 183] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.4924907142857144], 
             UndirectedEdge[249, 263] -> 
             RGBColor[
              0.7475659285714286, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[33, 98] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[282, 293] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[54, 163] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[145, 237] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[140, 181] -> 
             RGBColor[
              0.7519839999999999, 0.8057464285714286, 0.9703062142857143], 
             UndirectedEdge[15, 265] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[144, 230] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857144], 
             UndirectedEdge[22, 266] -> 
             RGBColor[
              0.8261372142857144, 0.7776062857142859, 0.6190799285714286], 
             UndirectedEdge[18, 165] -> 
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`], 
             UndirectedEdge[17, 140] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142857, 0.9722277142857143], 
             UndirectedEdge[80, 237] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[7, 127] -> 
             RGBColor[
              0.8934179285714287, 0.8304337142857144, 0.6257149285714285], 
             UndirectedEdge[60, 212] -> 
             RGBColor[
              0.7773192142857142, 0.8214162857142857, 0.7352040000000001], 
             UndirectedEdge[53, 270] -> 
             RGBColor[
              0.8934179285714287, 0.8304337142857144, 0.6257149285714285], 
             UndirectedEdge[243, 254] -> 
             RGBColor[
              0.8799727857142856, 0.5454292857142857, 0.5731102142857143], 
             UndirectedEdge[201, 277] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[288, 296] -> 
             RGBColor[0.894471, 0.5250334285714284, 0.2542395714285713], 
             UndirectedEdge[93, 273] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[128, 277] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[3, 115] -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 
             UndirectedEdge[74, 123] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[52, 147] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[64, 76] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[132, 260] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[171, 285] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[226, 290] -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             UndirectedEdge[24, 290] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.3886912142857144], 
             UndirectedEdge[103, 265] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[41, 208] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[80, 179] -> 
             RGBColor[
              0.9634092857142856, 0.9722312857142857, 0.9468227142857143], 
             UndirectedEdge[102, 183] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[16, 220] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[52, 217] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[24, 241] -> 
             RGBColor[
              0.7773192142857142, 0.8214162857142857, 0.7352040000000001], 
             UndirectedEdge[105, 163] -> 
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861], 
             UndirectedEdge[2, 102] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[49, 54] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285714, 0.6650532857142856], 
             UndirectedEdge[216, 237] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[89, 281] -> 
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[145, 167] -> 
             RGBColor[
              0.6918173571428571, 0.7236127142857142, 0.6458675714285713], 
             UndirectedEdge[16, 90] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[210, 290] -> 
             RGBColor[
              0.9124627142857145, 0.6868797142857146, 0.2482285714285715], 
             UndirectedEdge[152, 242] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[77, 282] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[81, 162] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[34, 247] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[7, 60] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142857, 0.7488217142857143], 
             UndirectedEdge[155, 162] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[234, 249] -> 
             RGBColor[
              0.6399127142857143, 0.7173828571428572, 0.9655927142857142], 
             UndirectedEdge[118, 234] -> 
             RGBColor[
              0.8558905000000001, 0.8840378571428572, 0.7421867142857144], 
             UndirectedEdge[223, 271] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428573], 
             UndirectedEdge[154, 216] -> 
             RGBColor[
              0.7773192142857142, 0.8214162857142857, 0.7352040000000001], 
             UndirectedEdge[147, 247] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[4, 286] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117205000000001], 
             UndirectedEdge[88, 124] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[23, 136] -> 
             RGBColor[0.586112, 0.6467326428571429, 0.7226495000000002], 
             UndirectedEdge[11, 104] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[4, 121] -> 
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428572], 
             UndirectedEdge[4, 213] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[198, 204] -> 
             RGBColor[
              0.9124627142857145, 0.6868797142857146, 0.2482285714285715], 
             UndirectedEdge[156, 168] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[31, 226] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[36, 242] -> 
             RGBColor[0.575275, 0.6106669285714286, 0.6388810714285713], 
             UndirectedEdge[216, 269] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[97, 202] -> 
             RGBColor[
              0.9571247857142856, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[23, 59] -> 
             RGBColor[
              0.5863123571428572, 0.6485279285714285, 0.8438048571428571], 
             UndirectedEdge[174, 238] -> 
             RGBColor[
              0.7664822142857142, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[86, 97] -> 
             RGBColor[
              0.7519839999999999, 0.8057464285714286, 0.9703062142857143], 
             UndirectedEdge[46, 212] -> 
             RGBColor[
              0.7773192142857142, 0.8214162857142857, 0.7352040000000001], 
             UndirectedEdge[59, 291] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[125, 149] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[32, 80] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[69, 90] -> 
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855], 
             UndirectedEdge[215, 229] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[187, 245] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[98, 275] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[252, 280] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[96, 146] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[191, 270] -> 
             RGBColor[
              0.8720902142857143, 0.742105285714286, 0.6083590714285714], 
             UndirectedEdge[40, 120] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857143, 0.8680555714285715], 
             UndirectedEdge[215, 233] -> 
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[21, 257] -> 
             RGBColor[
              0.9183637857142857, 0.6962739999999998, 0.5547922142857142], 
             UndirectedEdge[200, 245] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285], 
             UndirectedEdge[41, 108] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856], 
             UndirectedEdge[63, 73] -> 
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 160 -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 245 -> 
             RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             155 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             213 -> RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861],
              27 -> RGBColor[0.984192, 0.987731, 0.911643], 19 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002], 164 -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 
             190 -> RGBColor[0.817319, 0.134127, 0.164218], 103 -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             138 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             291 -> RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             28 -> RGBColor[0.984192, 0.987731, 0.911643], 195 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 114 -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 93 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 34 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 161 -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 22 -> 
             RGBColor[
              0.7184840000000001, 0.7800044285714287, 0.9725754285714285], 
             124 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 84 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 46 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002], 241 -> 
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861], 185 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             121 -> RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             126 -> RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 236 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 78 -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 254 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 290 -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             251 -> RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 
             165 -> RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             100 -> RGBColor[0.984192, 0.987731, 0.911643], 235 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 70 -> 
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861], 234 -> 
             RGBColor[
              0.7184840000000001, 0.7800044285714287, 0.9725754285714285], 
             257 -> RGBColor[0.984192, 0.987731, 0.911643], 135 -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 
             265 -> RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 
             111 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117980000000002], 182 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 188 -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 154 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002], 269 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             208 -> RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 86 -> 
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861], 119 -> 
             RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             140 -> RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861],
              85 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             242 -> RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 117 -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714285], 47 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 81 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 275 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 23 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 110 -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 6 -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 
             218 -> RGBColor[
              0.7184840000000001, 0.7800044285714287, 0.9725754285714285], 
             108 -> RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             297 -> RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 
             157 -> RGBColor[0.984192, 0.987731, 0.911643], 270 -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714285], 33 -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 252 -> 
             RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             260 -> RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 
             159 -> RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 183 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 99 -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 17 -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714285], 
             277 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             104 -> RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             79 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             191 -> RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             50 -> RGBColor[0.984192, 0.987731, 0.911643], 225 -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 61 -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 196 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002], 1 -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 263 -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             201 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117980000000002], 293 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 184 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 106 -> 
             RGBColor[
              0.7184840000000001, 0.7800044285714287, 0.9725754285714285], 
             206 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             247 -> RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 220 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 107 -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             131 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117980000000002], 127 -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             210 -> RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             181 -> RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 
             194 -> RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714285], 
             118 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117980000000002], 276 -> 
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861], 280 -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 189 -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 
             168 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 41 -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 14 -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714285], 77 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 51 -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714285], 
             179 -> RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 
             223 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117980000000002], 292 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             143 -> RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             112 -> RGBColor[0.178927, 0.305394, 0.933501], 197 -> 
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861], 54 -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 71 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 177 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             158 -> RGBColor[0.984192, 0.987731, 0.911643], 226 -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             203 -> RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 115 -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 173 -> 
             RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             212 -> RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861],
              129 -> RGBColor[0.984192, 0.987731, 0.911643], 279 -> 
             RGBColor[
              0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`],
              26 -> RGBColor[0.984192, 0.987731, 0.911643], 40 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             146 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             192 -> RGBColor[
              0.7184840000000001, 0.7800044285714287, 0.9725754285714285], 
             300 -> RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 221 -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 62 -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             286 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117980000000002], 152 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 64 -> 
             RGBColor[
              0.7184840000000001, 0.7800044285714287, 0.9725754285714285], 37 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             148 -> RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 261 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 15 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             136 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117980000000002], 198 -> 
             RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             63 -> RGBColor[0.984192, 0.987731, 0.911643], 171 -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714285], 59 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             229 -> RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             102 -> RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 
             299 -> RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             128 -> RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 12 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 222 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 92 -> 
             RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             271 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             132 -> RGBColor[0.984192, 0.987731, 0.911643], 80 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 244 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 150 -> 
             RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             125 -> RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             258 -> RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 
             133 -> RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714285], 
             255 -> RGBColor[0.984192, 0.987731, 0.911643], 176 -> 
             RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             230 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117980000000002], 274 -> 
             RGBColor[
              0.7184840000000001, 0.7800044285714287, 0.9725754285714285], 87 -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 130 -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 35 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002], 31 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 18 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002], 24 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002], 151 -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             137 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             296 -> RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 266 -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             283 -> RGBColor[0.984192, 0.987731, 0.911643], 284 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             238 -> RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 72 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             288 -> RGBColor[0.817319, 0.134127, 0.164218], 172 -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             243 -> RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 88 -> 
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861], 273 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002], 202 -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 98 -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 30 -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714285], 
             116 -> RGBColor[
              0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`],
              240 -> RGBColor[
              0.5613414285714284, 0.6547612857142857, 0.95861], 73 -> 
             RGBColor[
              0.7184840000000001, 0.7800044285714287, 0.9725754285714285], 29 -> 
             RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             75 -> RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 
             200 -> RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 156 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 25 -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 38 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 3 -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 57 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             227 -> RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 39 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             109 -> RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861],
              256 -> RGBColor[0.178927, 0.305394, 0.933501], 287 -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 239 -> 
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861], 285 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 216 -> 
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861], 21 -> 
             RGBColor[
              0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`],
              175 -> RGBColor[0.984192, 0.987731, 0.911643], 7 -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714285], 13 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002], 294 -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 193 -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714285], 60 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002], 65 -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 69 -> 
             RGBColor[
              0.7184840000000001, 0.7800044285714287, 0.9725754285714285], 
             217 -> RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             214 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117980000000002], 170 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 74 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002], 246 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002], 264 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             278 -> RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             45 -> RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 237 -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 228 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             180 -> RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 53 -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 48 -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 5 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002], 101 -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             267 -> RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 120 -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 
             147 -> RGBColor[0.984192, 0.987731, 0.911643], 89 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 43 -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 199 -> 
             RGBColor[
              0.7184840000000001, 0.7800044285714287, 0.9725754285714285], 
             268 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117980000000002], 169 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 20 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 4 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 167 -> 
             RGBColor[0.41201171428571426`, 0.5312855714285714, 0.947474], 
             142 -> RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 16 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 281 -> 
             RGBColor[
              0.7184840000000001, 0.7800044285714287, 0.9725754285714285], 
             289 -> RGBColor[
              0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`],
              178 -> RGBColor[
              0.5613414285714284, 0.6547612857142857, 0.95861], 58 -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 186 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 122 -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 249 -> 
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861], 113 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002], 52 -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 
             187 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             259 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 42 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 134 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 248 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002], 174 -> 
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861], 215 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 83 -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714285], 95 -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             166 -> RGBColor[0.984192, 0.987731, 0.911643], 233 -> 
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861], 295 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             141 -> RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             205 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             224 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             231 -> RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 68 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 10 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002], 250 -> 
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861], 282 -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714285], 
             232 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             253 -> RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 55 -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 91 -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 105 -> 
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861], 36 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 123 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 94 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 96 -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 2 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             262 -> RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714285], 
             272 -> RGBColor[0.984192, 0.987731, 0.911643], 97 -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 
             209 -> RGBColor[0.984192, 0.987731, 0.911643], 66 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 139 -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 56 -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 144 -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 
             298 -> RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 204 -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             207 -> 
             RGBColor[
              0.29020042857142864`, 0.42234942857142865`, 0.9398378571428572],
              149 -> RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 219 -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 9 -> 
             RGBColor[
              0.7184840000000001, 0.7800044285714287, 0.9725754285714285], 11 -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 44 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002], 153 -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 32 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             162 -> RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 90 -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 8 -> 
             RGBColor[
              0.9716229999999999, 0.915939857142857, 0.3442611428571426], 163 -> 
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861], 49 -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714285], 76 -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285715, 0.9820024285714286], 82 -> 
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861], 67 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 211 -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 
               0.2655844285714286]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJwtl3k4FGrYxsc2dmbMmGEYZp8hUUJS8qQSUSklLeLUoUhCylJkaUGShISD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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 5}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 32}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 51}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 80}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 83}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 92}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 125}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 128}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 142}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 149}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 150}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 197}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 198}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 237}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 243}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 256}], {
             RGBColor[0.575275, 0.6106669285714285, 0.6388810714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 277}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 281}], {
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 49}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 54}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 102}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 165}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 172}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 174}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 183}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 238}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 253}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 24}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 59}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 65}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 72}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 106}], {
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 115}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 155}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 169}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 194}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 200}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 210}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 227}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 228}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 241}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 264}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 290}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 291}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 8}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 15}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 62}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 85}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 121}], {
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 135}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 158}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 173}], {
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 186}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 213}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 214}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 249}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 255}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 263}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 265}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 276}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 286}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 23}], {
             RGBColor[0.586112, 0.6467326428571428, 0.7226495000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 51}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142857, 0.7488217142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142857, 0.7488217142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 92}], {
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 101}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 128}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 142}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 149}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 197}], {
             RGBColor[
             0.7773192142857142, 0.8214162857142857, 0.7352040000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 198}], {
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 204}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 226}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 243}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 256}], {
             RGBColor[0.586112, 0.6467326428571428, 0.7226495000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 290}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 38}], {
             RGBColor[
             0.8799727857142856, 0.5454292857142857, 0.5731102142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 52}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 88}], {
             RGBColor[
             0.7519839999999999, 0.8057464285714286, 0.9703062142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 93}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 124}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 147}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 273}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 289}], {
             RGBColor[
             0.8975810714285714, 0.6807742857142856, 0.5899719285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 42}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 60}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142857, 0.7488217142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 77}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 80}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 81}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 82}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142857, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 103}], {
             RGBColor[
             0.8934179285714287, 0.8304337142857144, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 127}], {
             RGBColor[
             0.8934179285714287, 0.8304337142857144, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 130}], {
             RGBColor[
             0.8934179285714287, 0.8304337142857144, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 140}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142857, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 145}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 154}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142857, 0.7488217142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 167}], {
             RGBColor[
             0.6325285714285714, 0.7084724285714286, 0.9666597142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 168}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 181}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 201}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142857, 0.7488217142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 202}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 203}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 205}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 216}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142857, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 237}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 255}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 269}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 282}], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 293}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 299}], {
             RGBColor[
             0.8720902142857143, 0.742105285714286, 0.6083590714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 14}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 64}], {
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 67}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 69}], {
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 85}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 121}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 135}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 173}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 186}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 213}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 234}], {
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 249}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 263}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 286}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 45}], {
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 47}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 96}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 112}], {
             RGBColor[
             0.4487055000000001, 0.5426992142857143, 0.9530382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 132}], {
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 133}], {
             RGBColor[
             0.7857647142857144, 0.8328318571428572, 0.9792104285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 141}], {
             RGBColor[
             0.8261372142857144, 0.7776062857142859, 0.6190799285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 146}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 236}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 22}], {
             RGBColor[
             0.8558905000000001, 0.8840378571428572, 0.7421867142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 48}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 63}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 71}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 73}], {
             RGBColor[
             0.8558905000000001, 0.8840378571428572, 0.7421867142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 100}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 119}], {
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 122}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 161}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 244}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 266}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 51}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 101}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 104}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 114}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 116}], {
             RGBColor[
             0.8975810714285714, 0.6807742857142856, 0.5899719285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 149}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 197}], {
             RGBColor[
             0.7519839999999999, 0.8057464285714286, 0.9703062142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 198}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 204}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 243}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 254}], {
             RGBColor[
             0.8799727857142856, 0.5454292857142857, 0.5731102142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 283}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[0.5815595, 0.6465624999999999, 0.922572]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{12, 27}], {
             RGBColor[0.5815595, 0.6465624999999999, 0.922572]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.44870550000000003`, 0.5426992142857143, 0.9530382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 76}], {
             RGBColor[
             0.5607767857142856, 0.6310627857142856, 0.9577517142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 87}], {
             RGBColor[0.575275, 0.6106669285714286, 0.6388810714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 151}], {
             RGBColor[
             0.5563587142857143, 0.5403010714285715, 0.5995427142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 154}], {
             RGBColor[0.586112, 0.6467326428571429, 0.7226495000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 181}], {
             RGBColor[
             0.5607767857142856, 0.6310627857142856, 0.9577517142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 192}], {
             RGBColor[
             0.44870550000000003`, 0.5426992142857143, 0.9530382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 220}], {
             RGBColor[0.5815595, 0.6465624999999999, 0.922572]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{12, 239}], {
             RGBColor[
             0.37013421428571425`, 0.48007764285714283`, 0.9460554999999999]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 258}], {
             RGBColor[
             0.5607767857142856, 0.6310627857142856, 0.9577517142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 32}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 53}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 93}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 107}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 137}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 147}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 156}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 179}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 251}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 270}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142857, 0.7488217142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 271}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 273}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 274}], {
             RGBColor[
             0.8558905000000001, 0.8840378571428572, 0.7421867142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 277}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 282}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142857, 0.7488217142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 289}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.35486971428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 67}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 173}], {
             RGBColor[
             0.8720902142857143, 0.742105285714286, 0.6083590714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 186}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142857, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 249}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142857, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 46}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 60}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 77}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 82}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 103}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 127}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 135}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 158}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 168}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 186}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 196}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 212}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 214}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 225}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 255}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 265}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 276}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 286}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 39}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 76}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 90}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 126}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 151}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 153}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 192}], {
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 220}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 222}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 239}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 248}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 285}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 40}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 66}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 81}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 86}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142857, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 94}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 97}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 120}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 130}], {
             RGBColor[
             0.8934179285714287, 0.8304337142857144, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 140}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142857, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 162}], {
             RGBColor[
             0.8934179285714287, 0.8304337142857144, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 169}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 178}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142857, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 182}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 201}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142857, 0.7488217142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 202}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 294}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 26}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 33}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 35}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 129}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 165}], {
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 175}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 183}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 184}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 253}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 262}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142857, 0.7488217142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 36}], {
             RGBColor[0.498123, 0.2197605, 0.5488595000000001]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{20, 37}], {
             RGBColor[
             0.9055083571428572, 0.5628944285714286, 0.45916335714285716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 41}], {
             RGBColor[0.894471, 0.5250334285714284, 0.2542395714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 44}], {
             RGBColor[0.905308, 0.5610991428571428, 0.3380080000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 55}], {
             RGBColor[0.894471, 0.5250334285714284, 0.2542395714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 61}], {
             RGBColor[0.894471, 0.5250334285714284, 0.2542395714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 71}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{20, 108}], {
             RGBColor[
             0.8755547142857143, 0.45466757142857156`, 0.2149012142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 136}], {
             RGBColor[0.905308, 0.5610991428571428, 0.3380080000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 152}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{20, 177}], {
             RGBColor[
             0.9055083571428572, 0.5628944285714286, 0.45916335714285716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 208}], {
             RGBColor[
             0.8799727857142856, 0.5454292857142857, 0.5731102142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 252}], {
             RGBColor[
             0.8542270000000001, 0.3663391428571431, 0.1975453571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 268}], {
             RGBColor[0.905308, 0.5610991428571428, 0.3380080000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 279}], {
             RGBColor[
             0.8349272857142858, 0.2694719999999999, 0.1810797142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 280}], {
             RGBColor[0.894471, 0.5250334285714284, 0.2542395714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 50}], {
             RGBColor[
             0.9183637857142857, 0.6962739999999998, 0.5547922142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 74}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.35486971428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[0.893163, 0.5900125714285714, 0.23176292857142858`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 123}], {
             RGBColor[
             0.9183637857142857, 0.6962739999999998, 0.5547922142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 189}], {
             RGBColor[
             0.8975810714285714, 0.6807742857142856, 0.5899719285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 206}], {
             RGBColor[
             0.9231166428571429, 0.6982394285714284, 0.4760250714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 257}], {
             RGBColor[
             0.9183637857142857, 0.6962739999999998, 0.5547922142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 287}], {
             RGBColor[
             0.9120792857142856, 0.6603784285714284, 0.2711012857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 300}], {
             RGBColor[
             0.9120792857142856, 0.6603784285714284, 0.2711012857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.8261372142857144, 0.7776062857142859, 0.6190799285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 63}], {
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 70}], {
             RGBColor[
             0.6399127142857143, 0.7173828571428572, 0.9655927142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 73}], {
             RGBColor[
             0.7184840000000001, 0.7800044285714287, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 100}], {
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 119}], {
             RGBColor[
             0.8048095000000002, 0.6892778571428575, 0.6017240714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 122}], {
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 161}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 244}], {
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 266}], {
             RGBColor[
             0.8261372142857144, 0.7776062857142859, 0.6190799285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 24}], {
             RGBColor[0.586112, 0.6467326428571429, 0.7226495000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 31}], {
             RGBColor[
             0.5863123571428572, 0.6485279285714285, 0.8438048571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 44}], {
             RGBColor[0.586112, 0.6467326428571429, 0.7226495000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 59}], {
             RGBColor[
             0.5863123571428572, 0.6485279285714285, 0.8438048571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 72}], {
             RGBColor[
             0.5863123571428572, 0.6485279285714285, 0.8438048571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 83}], {
             RGBColor[
             0.5159862142857143, 0.5955266428571429, 0.9596732142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 106}], {
             RGBColor[
             0.44870550000000003`, 0.5426992142857143, 0.9530382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 136}], {
             RGBColor[0.586112, 0.6467326428571429, 0.7226495000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 155}], {
             RGBColor[
             0.5863123571428572, 0.6485279285714285, 0.8438048571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 194}], {
             RGBColor[
             0.5159862142857143, 0.5955266428571429, 0.9596732142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 197}], {
             RGBColor[
             0.37013421428571425`, 0.48007764285714283`, 0.9460554999999999]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 198}], {
             RGBColor[0.535031, 0.4519726428571431, 0.5821868571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 210}], {
             RGBColor[0.535031, 0.4519726428571431, 0.5821868571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 226}], {
             RGBColor[
             0.5563587142857143, 0.5403010714285715, 0.5995427142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 241}], {
             RGBColor[
             0.37013421428571425`, 0.48007764285714283`, 0.9460554999999999]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 290}], {
             RGBColor[
             0.5563587142857143, 0.5403010714285715, 0.5995427142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 291}], {
             RGBColor[0.535031, 0.4519726428571431, 0.5821868571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 59}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 65}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 72}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 87}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 106}], {
             RGBColor[
             0.8558905000000001, 0.8840378571428572, 0.7421867142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 109}], {
             RGBColor[
             0.7773192142857142, 0.8214162857142857, 0.7352040000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 155}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 162}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 194}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142857, 0.7488217142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 210}], {
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 218}], {
             RGBColor[
             0.8558905000000001, 0.8840378571428572, 0.7421867142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 226}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 227}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 241}], {
             RGBColor[
             0.7773192142857142, 0.8214162857142857, 0.7352040000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 290}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 291}], {
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 299}], {
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 28}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 58}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 79}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 113}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 134}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 144}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 160}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 176}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 221}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 230}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 232}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 245}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 288}], {
             RGBColor[0.894471, 0.5250334285714284, 0.2542395714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 297}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 35}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 54}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 75}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 102}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 129}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 165}], {
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 175}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 183}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 224}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 253}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 262}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 42}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 72}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 87}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 109}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 140}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 151}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 154}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 155}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 162}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 181}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 202}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 203}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 216}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 227}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 299}], {
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 79}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 144}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 160}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 176}], {
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 221}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 230}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 232}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 240}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 245}], {
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 288}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{28, 297}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 43}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 78}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 99}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 131}], {
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 170}], {
             RGBColor[
             0.8542270000000001, 0.3663391428571431, 0.1975453571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 178}], {
             RGBColor[
             0.7262382142857142, 0.6266562857142859, 0.5947413571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 182}], {
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 190}], {
             RGBColor[
             0.8542270000000001, 0.3663391428571431, 0.1975453571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 199}], {
             RGBColor[
             0.8048095000000002, 0.6892778571428575, 0.6017240714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 209}], {
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 229}], {
             RGBColor[
             0.9124627142857145, 0.6868797142857146, 0.2482285714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 259}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.4924907142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 261}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.4924907142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 284}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.4924907142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 74}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142857, 0.7488217142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 104}], {
             RGBColor[
             0.8720902142857143, 0.742105285714286, 0.6083590714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 123}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 189}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 236}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 260}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 267}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 287}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 300}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 37}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 44}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 59}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 61}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 65}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 71}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 136}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 177}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 194}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 210}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 226}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 241}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 279}], {
             RGBColor[
             0.9231166428571429, 0.6982394285714284, 0.4760250714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 280}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 290}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 291}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 80}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 92}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 107}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 125}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 128}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 142}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 145}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 149}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 150}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 156}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 167}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 179}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 205}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 237}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 256}], {
             RGBColor[
             0.5863123571428571, 0.6485279285714286, 0.8438048571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 269}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 277}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 282}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 293}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 98}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 126}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 153}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 157}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 171}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 184}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 222}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 248}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 275}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 285}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 38}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{34, 52}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 53}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 57}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 84}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 124}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 147}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 217}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 223}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 247}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 270}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 295}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 102}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 129}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 165}], {
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 175}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 183}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 224}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 253}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 262}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142857, 0.7488217142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 41}], {
             RGBColor[0.575275, 0.6106669285714286, 0.6388810714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 55}], {
             RGBColor[0.575275, 0.6106669285714286, 0.6388810714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 152}], {
             RGBColor[0.5815595, 0.6465624999999999, 0.922572]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{36, 208}], {
             RGBColor[
             0.5607767857142856, 0.6310627857142856, 0.9577517142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 242}], {
             RGBColor[0.575275, 0.6106669285714286, 0.6388810714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 250}], {
             RGBColor[
             0.37013421428571425`, 0.48007764285714283`, 0.9460554999999999]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 268}], {
             RGBColor[0.586112, 0.6467326428571429, 0.7226495000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 41}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 44}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 55}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 61}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 71}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 108}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 136}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 152}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 161}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 177}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 208}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 252}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 268}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 279}], {
             RGBColor[
             0.9231166428571429, 0.6982394285714284, 0.4760250714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 280}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 52}], {
             RGBColor[
             0.8799727857142856, 0.5454292857142857, 0.5731102142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 53}], {
             RGBColor[
             0.8755547142857143, 0.45466757142857156`, 0.2149012142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 57}], {
             RGBColor[
             0.9055083571428572, 0.5628944285714286, 0.45916335714285716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 88}], {
             RGBColor[0.6893302142857143, 0.39444414285714285`, 0.561414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 124}], {
             RGBColor[
             0.9055083571428572, 0.5628944285714286, 0.45916335714285716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 147}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{38, 247}], {
             RGBColor[0.894471, 0.5250334285714284, 0.2542395714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 289}], {
             RGBColor[
             0.8349272857142858, 0.2694719999999999, 0.1810797142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 64}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 69}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 76}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 85}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 90}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 118}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 126}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 153}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 166}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 195}], {
             RGBColor[
             0.9055083571428572, 0.5628944285714286, 0.45916335714285716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 234}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 239}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 248}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 263}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 285}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 42}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 66}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 81}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 86}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 94}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 97}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 120}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 130}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 140}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 162}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 169}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 178}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 182}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 201}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 202}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 55}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 108}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 152}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 208}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 219}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 242}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 252}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 268}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 80}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 81}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 82}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 87}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 130}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 140}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 145}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 162}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 167}], {
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 181}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 201}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 202}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 203}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 216}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 237}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 269}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 293}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 299}], {
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 66}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 78}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 97}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 99}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 178}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 182}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 199}], {
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 215}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 229}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 233}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 259}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 261}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 284}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 59}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 61}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 71}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 108}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 136}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 177}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 194}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142857, 0.7488217142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 204}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 226}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 252}], {
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 268}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 279}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.35486971428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 280}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 283}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 89}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 94}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 96}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 120}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 131}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 132}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 141}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 146}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 188}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 236}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 260}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 281}], {
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 294}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 60}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 62}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 117}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142857, 0.7488217142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 158}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 196}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 207}], {
             RGBColor[
             0.6417487142857143, 0.7052103571428572, 0.7258179285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 212}], {
             RGBColor[
             0.7773192142857142, 0.8214162857142857, 0.7352040000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 214}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 225}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 265}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 276}], {
             RGBColor[
             0.7773192142857142, 0.8214162857142857, 0.7352040000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 112}], {
             RGBColor[
             0.5863123571428571, 0.6485279285714286, 0.8438048571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 131}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 133}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 146}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 170}], {
             RGBColor[
             0.9055083571428572, 0.5628944285714286, 0.45916335714285716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 190}], {
             RGBColor[
             0.9055083571428572, 0.5628944285714286, 0.45916335714285716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 70}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 71}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 73}], {
             RGBColor[
             0.8261372142857144, 0.7776062857142859, 0.6190799285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 100}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 119}], {
             RGBColor[
             0.9124627142857145, 0.6868797142857146, 0.2482285714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 122}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 138}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 161}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 244}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 266}], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 54}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 102}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 143}], {
             RGBColor[
             0.8934179285714287, 0.8304337142857144, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 172}], {
             RGBColor[
             0.8934179285714287, 0.8304337142857144, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 174}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142857, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 238}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 298}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 206}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 219}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 83}], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 101}], {
             RGBColor[
             0.8934179285714287, 0.8304337142857144, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 104}], {
             RGBColor[
             0.8720902142857143, 0.742105285714286, 0.6083590714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 116}], {
             RGBColor[0.8527905, 0.6452381428571428, 0.5918934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 142}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 149}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 197}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142857, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 198}], {
             RGBColor[
             0.8720902142857143, 0.742105285714286, 0.6083590714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 204}], {
             RGBColor[
             0.8934179285714287, 0.8304337142857144, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 226}], {
             RGBColor[
             0.8934179285714287, 0.8304337142857144, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 243}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 254}], {
             RGBColor[
             0.8351822142857144, 0.5098931428571429, 0.5750317142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 283}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 53}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 57}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 84}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 88}], {
             RGBColor[
             0.7519839999999999, 0.8057464285714286, 0.9703062142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 93}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 124}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 137}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 147}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 217}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 247}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 270}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 271}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 273}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 289}], {
             RGBColor[
             0.8975810714285714, 0.6807742857142856, 0.5899719285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 295}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 88}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 93}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 107}], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 124}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 137}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 147}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 217}], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 247}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 251}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 270}], {
             RGBColor[
             0.8934179285714287, 0.8304337142857144, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 271}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 273}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 289}], {
             RGBColor[0.893163, 0.5900125714285714, 0.23176292857142858`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 75}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 102}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 111}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 143}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 163}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 165}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 172}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 174}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 185}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 235}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 238}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 298}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 108}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 114}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 208}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 219}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 242}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 250}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 252}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 268}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 283}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 57}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 84}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 110}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 148}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 191}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 217}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 223}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 246}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 247}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 251}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 270}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 271}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 278}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 295}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 217}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 223}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 247}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 278}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 295}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 134}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 160}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 164}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 176}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 180}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 187}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 215}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 221}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 230}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 288}], {
             RGBColor[0.894471, 0.5250334285714284, 0.2542395714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 296}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 297}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 72}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 83}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 106}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 136}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 155}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 197}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 198}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 210}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 226}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 227}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 241}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 290}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 291}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 77}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 95}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 103}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 127}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 145}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 148}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 159}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 168}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 196}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 205}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 212}], {
             RGBColor[
             0.7773192142857142, 0.8214162857142857, 0.7352040000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 225}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 265}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 276}], {
             RGBColor[
             0.7773192142857142, 0.8214162857142857, 0.7352040000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 282}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142857, 0.7488217142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 71}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 108}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 136}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 161}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 177}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 194}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 252}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 268}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 279}], {
             RGBColor[
             0.9120792857142856, 0.6603784285714284, 0.2711012857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 280}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 117}], {
             RGBColor[
             0.8934179285714287, 0.8304337142857144, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 135}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 158}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 186}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 196}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 207}], {
             RGBColor[
             0.6119954285714286, 0.5987787857142859, 0.6027111428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 212}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 214}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 225}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 265}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 276}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 286}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 71}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 73}], {
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 152}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 161}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 208}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 244}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 69}], {
             RGBColor[
             0.7184840000000001, 0.7800044285714287, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 76}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 85}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 90}], {
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 118}], {
             RGBColor[
             0.8558905000000001, 0.8840378571428572, 0.7421867142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 121}], {
             RGBColor[
             0.8048095000000002, 0.6892778571428575, 0.6017240714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 173}], {
             RGBColor[
             0.8048095000000002, 0.6892778571428575, 0.6017240714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 213}], {
             RGBColor[
             0.6399127142857143, 0.7173828571428572, 0.9655927142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 234}], {
             RGBColor[
             0.7184840000000001, 0.7800044285714287, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 239}], {
             RGBColor[
             0.6399127142857143, 0.7173828571428572, 0.9655927142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 249}], {
             RGBColor[
             0.6399127142857143, 0.7173828571428572, 0.9655927142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 258}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 263}], {
             RGBColor[
             0.8261372142857144, 0.7776062857142859, 0.6190799285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 286}], {
             RGBColor[
             0.8558905000000001, 0.8840378571428572, 0.7421867142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 70}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 106}], {
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 115}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 138}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 155}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 194}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 200}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 211}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 231}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 241}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 264}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 291}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 86}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 97}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 162}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 169}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 187}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 193}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 215}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 228}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 118}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 166}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 173}], {
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 195}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{67, 213}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 234}], {
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 263}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 75}], {
             RGBColor[
             0.5607767857142856, 0.6310627857142856, 0.9577517142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 83}], {
             RGBColor[
             0.5159862142857143, 0.5955266428571429, 0.9596732142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 109}], {
             RGBColor[
             0.37013421428571425`, 0.48007764285714283`, 0.9460554999999999]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 111}], {
             RGBColor[0.586112, 0.6467326428571429, 0.7226495000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 143}], {
             RGBColor[
             0.5563587142857143, 0.5403010714285715, 0.5995427142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 163}], {
             RGBColor[
             0.37013421428571425`, 0.48007764285714283`, 0.9460554999999999]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 185}], {
             RGBColor[
             0.5863123571428572, 0.6485279285714285, 0.8438048571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 218}], {
             RGBColor[
             0.44870550000000003`, 0.5426992142857143, 0.9530382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 235}], {
             RGBColor[
             0.5863123571428572, 0.6485279285714285, 0.8438048571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 292}], {
             RGBColor[
             0.5863123571428572, 0.6485279285714285, 0.8438048571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 76}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 85}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 90}], {
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 118}], {
             RGBColor[
             0.8558905000000001, 0.8840378571428572, 0.7421867142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 121}], {
             RGBColor[
             0.8048095000000002, 0.6892778571428575, 0.6017240714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 126}], {
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 166}], {
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 173}], {
             RGBColor[
             0.8048095000000002, 0.6892778571428575, 0.6017240714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 195}], {
             RGBColor[0.7679015, 0.45706571428571435`, 0.5683967142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 213}], {
             RGBColor[
             0.6399127142857143, 0.7173828571428572, 0.9655927142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 234}], {
             RGBColor[
             0.7184840000000001, 0.7800044285714287, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 239}], {
             RGBColor[
             0.6399127142857143, 0.7173828571428572, 0.9655927142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 249}], {
             RGBColor[
             0.6399127142857143, 0.7173828571428572, 0.9655927142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 258}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 263}], {
             RGBColor[
             0.8261372142857144, 0.7776062857142859, 0.6190799285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 285}], {
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 122}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 138}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 211}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 231}], {
             RGBColor[
             0.7519839999999999, 0.8057464285714286, 0.9703062142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 266}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 108}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 136}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 161}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 177}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 208}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 244}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 252}], {
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 268}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 279}], {
             RGBColor[
             0.9183637857142857, 0.6962739999999998, 0.5547922142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 280}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 83}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 87}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 106}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 109}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 155}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 194}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 210}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 218}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 226}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 227}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 241}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 290}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 291}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 100}], {
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 119}], {
             RGBColor[
             0.8048095000000002, 0.6892778571428575, 0.6017240714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 122}], {
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 161}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 244}], {
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 123}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 189}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 257}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 260}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 267}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 287}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 300}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 111}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 143}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.7519839999999999, 0.8057464285714286, 0.9703062142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 165}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 185}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 235}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 262}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 292}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 85}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 87}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 90}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 126}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 151}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 153}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 192}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 220}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 239}], {
             RGBColor[
             0.7519839999999999, 0.8057464285714286, 0.9703062142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 248}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 258}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 82}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 95}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 103}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 127}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 145}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 154}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 159}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 167}], {
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 168}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 203}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 205}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 212}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 225}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 255}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 265}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 269}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 276}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 282}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 293}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 99}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 131}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 170}], {
             RGBColor[0.894471, 0.5250334285714284, 0.2542395714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 178}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 182}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 190}], {
             RGBColor[0.894471, 0.5250334285714284, 0.2542395714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 209}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 229}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 261}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 284}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 144}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 160}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 176}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 221}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 232}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 240}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 245}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 288}], {
             RGBColor[
             0.9055083571428572, 0.5628944285714286, 0.45916335714285716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 297}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 92}], {
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 125}], {
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 128}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 145}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 149}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 150}], {
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 156}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 167}], {
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 179}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 201}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 205}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 237}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 256}], {
             RGBColor[0.5815595, 0.6465625, 0.922572]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{80, 269}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 277}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 281}], {
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 282}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 293}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 86}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 94}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 97}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 140}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 162}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 167}], {
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 181}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 201}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 202}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 203}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 216}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 237}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 269}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 293}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 299}], {
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 103}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 140}], {
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 145}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 154}], {
             RGBColor[
             0.7773192142857142, 0.8214162857142857, 0.7352040000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 167}], {
             RGBColor[0.48667657142857135`, 0.5930234285714285, 0.953042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 168}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 181}], {
             RGBColor[
             0.7519839999999999, 0.8057464285714286, 0.9703062142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 201}], {
             RGBColor[
             0.7773192142857142, 0.8214162857142857, 0.7352040000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 203}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 216}], {
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 255}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 258}], {
             RGBColor[
             0.7519839999999999, 0.8057464285714286, 0.9703062142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 293}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 101}], {
             RGBColor[
             0.8934179285714287, 0.8304337142857144, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 142}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 149}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 194}], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142857, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 198}], {
             RGBColor[
             0.8720902142857143, 0.742105285714286, 0.6083590714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 226}], {
             RGBColor[
             0.8934179285714287, 0.8304337142857144, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 241}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142857, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 243}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 290}], {
             RGBColor[
             0.8934179285714287, 0.8304337142857144, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 291}], {
             RGBColor[
             0.8720902142857143, 0.742105285714286, 0.6083590714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 191}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 217}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 223}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 246}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 247}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 270}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 271}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 278}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 295}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 135}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 154}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 173}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 213}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 234}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 239}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 249}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 255}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 258}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 263}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 286}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 97}], {
             RGBColor[
             0.7519839999999999, 0.8057464285714286, 0.9703062142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 120}], {
             RGBColor[
             0.7519839999999999, 0.8057464285714286, 0.9703062142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 130}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 140}], {
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 162}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 169}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 182}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 202}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 261}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 284}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 109}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 140}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 151}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 155}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 162}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 181}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 202}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 203}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 216}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 227}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 258}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 299}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 93}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 107}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 124}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 137}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 147}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 273}], {
             RGBColor[
             0.7773192142857142, 0.8214162857142857, 0.7352040000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 274}], {
             RGBColor[
             0.6399127142857143, 0.7173828571428572, 0.9655927142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 289}], {
             RGBColor[
             0.7069384999999999, 0.5297891428571427, 0.5782757142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 94}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 120}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 131}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 141}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 188}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 236}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 260}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 281}], {
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 294}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 118}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 126}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 153}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 195}], {
             RGBColor[0.894471, 0.5250334285714284, 0.2542395714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 222}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 234}], {
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 239}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 248}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 285}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 93}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 105}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 107}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 139}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 142}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 143}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 150}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 163}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 179}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 235}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 273}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 274}], {
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 298}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 125}], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 128}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 142}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 149}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 150}], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 179}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 237}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 243}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 256}], {
             RGBColor[0.535031, 0.4519726428571431, 0.5821868571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 269}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.4924907142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 277}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.4924907142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 281}], {
             RGBColor[
             0.8048095000000002, 0.6892778571428575, 0.6017240714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 105}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 107}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 137}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 139}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 147}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 273}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 274}], {
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 289}], {
             RGBColor[
             0.9183637857142857, 0.6962739999999998, 0.5547922142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 97}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 120}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 130}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 141}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 188}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 201}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 202}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 281}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 293}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 294}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 103}], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 127}], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 145}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 148}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 156}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 159}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 168}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 191}], {
             RGBColor[
             0.9124627142857145, 0.6868797142857146, 0.2482285714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 205}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 212}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 225}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 251}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 271}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 276}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 282}], {
             RGBColor[
             0.8934179285714287, 0.8304337142857144, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 112}], {
             RGBColor[
             0.5607767857142857, 0.6310627857142858, 0.9577517142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 132}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 133}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 146}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 236}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 260}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 267}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 120}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 130}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 178}], {
             RGBColor[
             0.7519839999999999, 0.8057464285714286, 0.9703062142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 182}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 202}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 261}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 284}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 157}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.8934179285714287, 0.8304337142857144, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 275}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 285}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 182}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 199}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 209}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 215}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 229}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 233}], {
             RGBColor[
             0.7519839999999999, 0.8057464285714286, 0.9703062142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 259}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 284}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 119}], {
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 122}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 161}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 244}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 266}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 104}], {
             RGBColor[
             0.9124627142857145, 0.6868797142857146, 0.2482285714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 116}], {
             RGBColor[0.893163, 0.5900125714285714, 0.23176292857142858`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 136}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 149}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 197}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 198}], {
             RGBColor[
             0.9124627142857145, 0.6868797142857146, 0.2482285714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 226}], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 243}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 254}], {
             RGBColor[
             0.8755547142857143, 0.45466757142857156`, 0.2149012142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 283}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 165}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 172}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 175}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 183}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 238}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 253}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 127}], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 145}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 154}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 159}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 167}], {
             RGBColor[
             0.6729010714285715, 0.6532468571428572, 0.6065292142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 168}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 203}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 205}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 212}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 225}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 255}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 265}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 269}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 276}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 282}], {
             RGBColor[
             0.8934179285714287, 0.8304337142857144, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 293}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 114}], {
             RGBColor[
             0.9124627142857145, 0.6868797142857146, 0.2482285714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 116}], {
             RGBColor[
             0.8718352857142857, 0.501684142857143, 0.21440707142857146`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 204}], {
             RGBColor[
             0.9124627142857145, 0.6868797142857146, 0.2482285714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 206}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.4924907142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 243}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 254}], {
             RGBColor[
             0.8542270000000001, 0.3663391428571431, 0.1975453571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 283}], {
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 287}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 300}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 139}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 143}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 163}], {
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 174}], {
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 235}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 274}], {
             RGBColor[
             0.6399127142857143, 0.7173828571428572, 0.9655927142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 298}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 115}], {
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 155}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 162}], {
             RGBColor[
             0.8261372142857144, 0.7776062857142859, 0.6190799285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 194}], {
             RGBColor[
             0.7857647142857144, 0.8328318571428572, 0.9792104285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 200}], {
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 210}], {
             RGBColor[
             0.8048095000000002, 0.6892778571428575, 0.6017240714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 211}], {
             RGBColor[
             0.8261372142857144, 0.7776062857142859, 0.6190799285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 227}], {
             RGBColor[
             0.8261372142857144, 0.7776062857142859, 0.6190799285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 241}], {
             RGBColor[
             0.6399127142857143, 0.7173828571428572, 0.9655927142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 264}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 290}], {
             RGBColor[
             0.8261372142857144, 0.7776062857142859, 0.6190799285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 291}], {
             RGBColor[
             0.8048095000000002, 0.6892778571428575, 0.6017240714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 137}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 139}], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 150}], {
             RGBColor[
             0.9124627142857145, 0.6868797142857146, 0.2482285714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 251}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 273}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 274}], {
             RGBColor[
             0.8261372142857144, 0.7776062857142859, 0.6190799285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 277}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 289}], {
             RGBColor[0.893163, 0.5900125714285714, 0.23176292857142858`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 136}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 177}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 204}], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 208}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 252}], {
             RGBColor[
             0.9124627142857145, 0.6868797142857146, 0.2482285714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 254}], {
             RGBColor[
             0.8755547142857143, 0.45466757142857156`, 0.2149012142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 268}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 279}], {
             RGBColor[0.893163, 0.5900125714285714, 0.23176292857142858`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 280}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 283}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 111}], {
             RGBColor[
             0.7773192142857142, 0.8214162857142857, 0.7352040000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 151}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 155}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 192}], {
             RGBColor[
             0.6399127142857143, 0.7173828571428572, 0.9655927142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 218}], {
             RGBColor[
             0.6399127142857143, 0.7173828571428572, 0.9655927142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 220}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 227}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 290}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 292}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 148}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 191}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 223}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 246}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 278}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 295}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 143}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 163}], {
             RGBColor[
             0.7773192142857142, 0.8214162857142857, 0.7352040000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 218}], {
             RGBColor[
             0.8558905000000001, 0.8840378571428572, 0.7421867142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 235}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 262}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142857, 0.7488217142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 292}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 131}], {
             RGBColor[0.586112, 0.6467326428571429, 0.7226495000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 132}], {
             RGBColor[0.5815595, 0.6465624999999999, 0.922572]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{112, 133}], {
             RGBColor[
             0.5159862142857143, 0.5955266428571429, 0.9596732142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 146}], {
             RGBColor[
             0.5863123571428572, 0.6485279285714285, 0.8438048571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 170}], {
             RGBColor[0.49812300000000004`, 0.2197605, 0.5488595000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 190}], {
             RGBColor[0.49812300000000004`, 0.2197605, 0.5488595000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 115}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 134}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 144}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 160}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 169}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 176}], {
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 187}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 193}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142857, 0.7488217142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 200}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 228}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 231}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 245}], {
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 264}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 288}], {
             RGBColor[0.905308, 0.5610991428571428, 0.3380080000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 297}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 116}], {
             RGBColor[0.893163, 0.5900125714285714, 0.23176292857142858`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 204}], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 206}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 254}], {
             RGBColor[
             0.8755547142857143, 0.45466757142857156`, 0.2149012142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 283}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 134}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 169}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 193}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 200}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 210}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 211}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 227}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 228}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 231}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 245}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 264}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 204}], {
             RGBColor[0.893163, 0.5900125714285714, 0.23176292857142858`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 206}], {
             RGBColor[
             0.9231166428571429, 0.6982394285714284, 0.4760250714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 254}], {
             RGBColor[
             0.8349272857142858, 0.2694719999999999, 0.1810797142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 283}], {
             RGBColor[
             0.9183637857142857, 0.6962739999999998, 0.5547922142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 287}], {
             RGBColor[
             0.9120792857142856, 0.6603784285714284, 0.2711012857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 158}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 196}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142857, 0.7488217142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 207}], {
             RGBColor[
             0.5716229285714286, 0.6540043571428572, 0.9628416428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 212}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142857, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 214}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142857, 0.7488217142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 225}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 265}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 276}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142857, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 166}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[0.905308, 0.5610991428571428, 0.3380080000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 234}], {
             RGBColor[
             0.8558905000000001, 0.8840378571428572, 0.7421867142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 239}], {
             RGBColor[
             0.7773192142857142, 0.8214162857142857, 0.7352040000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 263}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 285}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 122}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 161}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 244}], {
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 266}], {
             RGBColor[
             0.9124627142857145, 0.6868797142857146, 0.2482285714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 131}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 141}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 170}], {
             RGBColor[
             0.8799727857142856, 0.5454292857142857, 0.5731102142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 178}], {
             RGBColor[
             0.7519839999999999, 0.8057464285714286, 0.9703062142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 182}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 188}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 190}], {
             RGBColor[
             0.8799727857142856, 0.5454292857142857, 0.5731102142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 261}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 284}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 294}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 135}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 154}], {
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 173}], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.7262382142857142, 0.6266562857142859, 0.5947413571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 234}], {
             RGBColor[
             0.8048095000000002, 0.6892778571428575, 0.6017240714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 239}], {
             RGBColor[
             0.7262382142857142, 0.6266562857142859, 0.5947413571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 249}], {
             RGBColor[
             0.7262382142857142, 0.6266562857142859, 0.5947413571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 255}], {
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 258}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 263}], {
             RGBColor[
             0.9124627142857145, 0.6868797142857146, 0.2482285714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 286}], {
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 138}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 161}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 266}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 189}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 257}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 267}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 287}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 300}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 147}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 247}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 273}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 289}], {
             RGBColor[
             0.9231166428571429, 0.6982394285714284, 0.4760250714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 128}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 130}], {
             RGBColor[
             0.9124627142857145, 0.6868797142857146, 0.2482285714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 142}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 150}], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 167}], {
             RGBColor[
             0.6515733571428572, 0.5649184285714288, 0.5891733571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 237}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 243}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 256}], {
             RGBColor[0.535031, 0.4519726428571431, 0.5821868571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 269}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.4924907142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 277}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.4924907142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 281}], {
             RGBColor[
             0.8048095000000002, 0.6892778571428575, 0.6017240714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 293}], {
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 153}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 157}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 192}], {
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 220}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 222}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 239}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 248}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 285}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 145}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 148}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 156}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 159}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 168}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 191}], {
             RGBColor[
             0.9124627142857145, 0.6868797142857146, 0.2482285714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 205}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 212}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 225}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 251}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 269}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 276}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 282}], {
             RGBColor[
             0.8934179285714287, 0.8304337142857144, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 142}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 149}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 150}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 197}], {
             RGBColor[
             0.7519839999999999, 0.8057464285714286, 0.9703062142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 198}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 237}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 243}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 256}], {
             RGBColor[
             0.5607767857142857, 0.6310627857142858, 0.9577517142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 269}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 277}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 281}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 165}], {
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 175}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 183}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 184}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 224}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 253}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 140}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 162}], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 167}], {
             RGBColor[
             0.6729010714285715, 0.6532468571428572, 0.6065292142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 201}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 202}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 203}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 216}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 237}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 269}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 281}], {
             RGBColor[
             0.8261372142857144, 0.7776062857142859, 0.6190799285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 293}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 294}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 299}], {
             RGBColor[
             0.9124627142857145, 0.6868797142857146, 0.2482285714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 141}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 146}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 170}], {
             RGBColor[0.905308, 0.5610991428571428, 0.3380080000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 178}], {
             RGBColor[
             0.7773192142857142, 0.8214162857142857, 0.7352040000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 182}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 188}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 190}], {
             RGBColor[0.905308, 0.5610991428571428, 0.3380080000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 199}], {
             RGBColor[
             0.8558905000000001, 0.8840378571428572, 0.7421867142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 261}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 284}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 133}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 146}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 236}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 260}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 267}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 146}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 170}], {
             RGBColor[
             0.8351822142857144, 0.5098931428571429, 0.5750317142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 144}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 160}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 169}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 176}], {
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 180}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 187}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 193}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 200}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 221}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 228}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 230}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 245}], {
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 264}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 288}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{134, 297}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 158}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 173}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 186}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 213}], {
             RGBColor[
             0.7519839999999999, 0.8057464285714286, 0.9703062142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 214}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 249}], {
             RGBColor[
             0.7519839999999999, 0.8057464285714286, 0.9703062142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 255}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 263}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 265}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 276}], {
             RGBColor[
             0.7519839999999999, 0.8057464285714286, 0.9703062142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 286}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 177}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 194}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142857, 0.7488217142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 197}], {
             RGBColor[
             0.7773192142857142, 0.8214162857142857, 0.7352040000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 204}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 210}], {
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 226}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 252}], {
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 279}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.35486971428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 280}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 147}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 156}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 179}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 191}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 217}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 247}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 251}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 270}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 271}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 273}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 278}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 289}], {
             RGBColor[
             0.9231166428571429, 0.6982394285714284, 0.4760250714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 295}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 210}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 211}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 231}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 266}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 143}], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 163}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 235}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 273}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 274}], {
             RGBColor[
             0.8261372142857144, 0.7776062857142859, 0.6190799285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 298}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 162}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 167}], {
             RGBColor[0.48667657142857135`, 0.5930234285714285, 0.953042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 181}], {
             RGBColor[
             0.7519839999999999, 0.8057464285714286, 0.9703062142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 201}], {
             RGBColor[
             0.7773192142857142, 0.8214162857142857, 0.7352040000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 202}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 203}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 216}], {
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 237}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 269}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 293}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 299}], {
             RGBColor[
             0.7262382142857142, 0.6266562857142859, 0.5947413571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 146}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 178}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 182}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 188}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 236}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 261}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 294}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 149}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 163}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 197}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 198}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 243}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 256}], {
             RGBColor[0.575275, 0.6106669285714285, 0.6388810714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 277}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 163}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 174}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 185}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 235}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 298}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 160}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 176}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 221}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 230}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 231}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 232}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 240}], {
             RGBColor[
             0.7519839999999999, 0.8057464285714286, 0.9703062142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 245}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 264}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 288}], {
             RGBColor[
             0.8799727857142856, 0.5454292857142857, 0.5731102142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 297}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 156}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 159}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 167}], {
             RGBColor[
             0.6918173571428571, 0.7236127142857142, 0.6458675714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 168}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 201}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 203}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 205}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 216}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 237}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 269}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 277}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 282}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 293}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 170}], {
             RGBColor[
             0.9055083571428572, 0.5628944285714286, 0.45916335714285716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 236}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 247}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 273}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 289}], {
             RGBColor[
             0.9183637857142857, 0.6962739999999998, 0.5547922142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 156}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 159}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 168}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 191}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 205}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 217}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 225}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 251}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 270}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 271}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 278}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 295}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 150}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 198}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 243}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 256}], {
             RGBColor[0.575275, 0.6106669285714285, 0.6388810714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 277}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 281}], {
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 179}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 237}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 256}], {
             RGBColor[0.535031, 0.4519726428571431, 0.5821868571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 269}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.4924907142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 274}], {
             RGBColor[
             0.8048095000000002, 0.6892778571428575, 0.6017240714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 277}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.4924907142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 281}], {
             RGBColor[
             0.8048095000000002, 0.6892778571428575, 0.6017240714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 293}], {
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 154}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 181}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 192}], {
             RGBColor[
             0.8261372142857144, 0.7776062857142859, 0.6190799285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 220}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 239}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 258}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 208}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 242}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 244}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 268}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 157}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 192}], {
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 220}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 222}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 239}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 248}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 285}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 181}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 216}], {
             RGBColor[
             0.7773192142857142, 0.8214162857142857, 0.7352040000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 255}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 258}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 162}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 194}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 210}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 218}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 226}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 227}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 241}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 290}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 291}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 159}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 168}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 191}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 205}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 251}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 269}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 270}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 271}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 277}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 282}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 171}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 184}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 222}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 248}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 275}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 285}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 186}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 196}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 207}], {
             RGBColor[
             0.6371962142857143, 0.7050402142857144, 0.9257404285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 212}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 214}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 225}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 265}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 276}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 168}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 191}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 205}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 212}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 225}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 251}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 270}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 271}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 282}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 176}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 180}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 193}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 221}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 230}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 232}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 245}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 288}], {
             RGBColor[0.894471, 0.5250334285714284, 0.2542395714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 296}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 297}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 177}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 244}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 279}], {
             RGBColor[
             0.8975810714285714, 0.6807742857142856, 0.5899719285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 280}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 169}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 181}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 202}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 216}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 227}], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 228}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 299}], {
             RGBColor[
             0.9124627142857145, 0.6868797142857146, 0.2482285714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 185}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 235}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 274}], {
             RGBColor[
             0.6399127142857143, 0.7173828571428572, 0.9655927142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 292}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 298}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 176}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 180}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 187}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 221}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 230}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 296}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 297}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 175}], {
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 183}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.4924907142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 224}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.4924907142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 253}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 262}], {
             RGBColor[
             0.8720902142857143, 0.742105285714286, 0.6083590714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 195}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{166, 234}], {
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 285}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 168}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[
             0.7026543571428572, 0.7596784285714285, 0.7296360000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 202}], {
             RGBColor[
             0.6918173571428571, 0.7236127142857142, 0.6458675714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.6918173571428571, 0.7236127142857142, 0.6458675714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 216}], {
             RGBColor[0.48667657142857135`, 0.5930234285714285, 0.953042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 237}], {
             RGBColor[
             0.6918173571428571, 0.7236127142857142, 0.6458675714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 269}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 277}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 282}], {
             RGBColor[
             0.6325285714285714, 0.7084724285714286, 0.9666597142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 293}], {
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 203}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 205}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 212}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 225}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 269}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 276}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 282}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 293}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 193}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 200}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 202}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 227}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 228}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 264}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 299}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 178}], {
             RGBColor[0.6893302142857143, 0.39444414285714285`, 0.561414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 182}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{170, 190}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 199}], {
             RGBColor[0.7679015, 0.45706571428571435`, 0.5683967142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 261}], {
             RGBColor[
             0.9055083571428572, 0.5628944285714286, 0.45916335714285716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 284}], {
             RGBColor[
             0.9055083571428572, 0.5628944285714286, 0.45916335714285716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 184}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 275}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 285}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 174}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 238}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 186}], {
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 213}], {
             RGBColor[
             0.7262382142857142, 0.6266562857142859, 0.5947413571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 234}], {
             RGBColor[
             0.8048095000000002, 0.6892778571428575, 0.6017240714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 249}], {
             RGBColor[
             0.7262382142857142, 0.6266562857142859, 0.5947413571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 263}], {
             RGBColor[
             0.9124627142857145, 0.6868797142857146, 0.2482285714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 286}], {
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 235}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 238}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 298}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 183}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 224}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 253}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 180}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 187}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.4924907142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 193}], {
             RGBColor[
             0.8720902142857143, 0.742105285714286, 0.6083590714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 221}], {
             RGBColor[
             0.9124627142857145, 0.6868797142857146, 0.2482285714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 230}], {
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 245}], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 288}], {
             RGBColor[
             0.8542270000000001, 0.3663391428571431, 0.1975453571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 296}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 297}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 194}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 226}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 252}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 268}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 279}], {
             RGBColor[
             0.9231166428571429, 0.6982394285714284, 0.4760250714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 280}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 182}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 190}], {
             RGBColor[0.6893302142857143, 0.39444414285714285`, 0.561414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 199}], {
             RGBColor[
             0.6399127142857143, 0.7173828571428572, 0.9655927142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 229}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 261}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 284}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 205}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 251}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 269}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 274}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 277}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 282}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 289}], {
             RGBColor[
             0.8975810714285714, 0.6807742857142856, 0.5899719285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 187}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 193}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 215}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 221}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 230}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 233}], {
             RGBColor[
             0.7519839999999999, 0.8057464285714286, 0.9703062142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 245}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 288}], {
             RGBColor[
             0.8799727857142856, 0.5454292857142857, 0.5731102142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 296}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 297}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 201}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 202}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 203}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 216}], {
             RGBColor[
             0.7519839999999999, 0.8057464285714286, 0.9703062142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 227}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 258}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 299}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 190}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{182, 199}], {
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 229}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 261}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 284}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 224}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 253}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 222}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 224}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 248}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 275}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 218}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 235}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 262}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 292}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 196}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 214}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 249}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 265}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 286}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 193}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 215}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 228}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 229}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 230}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 233}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 245}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 288}], {
             RGBColor[
             0.9055083571428572, 0.5628944285714286, 0.45916335714285716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 296}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 297}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 236}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 260}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 261}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 281}], {
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 294}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 257}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 260}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 267}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 287}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 300}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 199}], {
             RGBColor[0.7679015, 0.45706571428571435`, 0.5683967142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 261}], {
             RGBColor[
             0.9055083571428572, 0.5628944285714286, 0.45916335714285716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 284}], {
             RGBColor[
             0.9055083571428572, 0.5628944285714286, 0.45916335714285716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 205}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.4924907142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 217}], {
             RGBColor[
             0.9124627142857145, 0.6868797142857146, 0.2482285714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 225}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 246}], {
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 251}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 270}], {
             RGBColor[
             0.8720902142857143, 0.742105285714286, 0.6083590714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 271}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.4924907142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 278}], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 282}], {
             RGBColor[
             0.8720902142857143, 0.742105285714286, 0.6083590714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 295}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.4924907142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 218}], {
             RGBColor[
             0.7184840000000001, 0.7800044285714287, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 220}], {
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 222}], {
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 248}], {
             RGBColor[
             0.8558905000000001, 0.8840378571428572, 0.7421867142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 262}], {
             RGBColor[
             0.7857647142857144, 0.8328318571428572, 0.9792104285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 200}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 215}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 228}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 230}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142857, 0.7488217142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 245}], {
             RGBColor[
             0.8720902142857143, 0.742105285714286, 0.6083590714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 264}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 288}], {
             RGBColor[
             0.8351822142857144, 0.5098931428571429, 0.5750317142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 210}], {
             RGBColor[
             0.8720902142857143, 0.742105285714286, 0.6083590714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 226}], {
             RGBColor[
             0.8934179285714287, 0.8304337142857144, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 241}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142857, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 280}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 290}], {
             RGBColor[
             0.8934179285714287, 0.8304337142857144, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 291}], {
             RGBColor[
             0.8720902142857143, 0.742105285714286, 0.6083590714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 234}], {
             RGBColor[0.7679015, 0.45706571428571435`, 0.5683967142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 207}], {
             RGBColor[
             0.6417487142857143, 0.7052103571428572, 0.7258179285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 212}], {
             RGBColor[
             0.7773192142857142, 0.8214162857142857, 0.7352040000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 214}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 225}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 265}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 276}], {
             RGBColor[
             0.7773192142857142, 0.8214162857142857, 0.7352040000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 198}], {
             RGBColor[
             0.7262382142857142, 0.6266562857142859, 0.5947413571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 204}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 226}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 243}], {
             RGBColor[
             0.7519839999999999, 0.8057464285714286, 0.9703062142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 254}], {
             RGBColor[0.6893302142857143, 0.39444414285714285`, 0.561414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 283}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 204}], {
             RGBColor[
             0.9124627142857145, 0.6868797142857146, 0.2482285714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 226}], {
             RGBColor[
             0.9124627142857145, 0.6868797142857146, 0.2482285714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 243}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 254}], {
             RGBColor[
             0.8542270000000001, 0.3663391428571431, 0.1975453571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 256}], {
             RGBColor[0.535031, 0.4519726428571431, 0.5821868571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 283}], {
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 209}], {
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 229}], {
             RGBColor[
             0.8261372142857144, 0.7776062857142859, 0.6190799285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 233}], {
             RGBColor[
             0.6399127142857143, 0.7173828571428572, 0.9655927142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 259}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 261}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 284}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 210}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 211}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 227}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 228}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 231}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 245}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 264}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 202}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 203}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 216}], {
             RGBColor[
             0.7773192142857142, 0.8214162857142857, 0.7352040000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 237}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 269}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 277}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 293}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 299}], {
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 203}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 216}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 237}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 269}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 293}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 299}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 216}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 237}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 255}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 269}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 293}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 299}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 226}], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 243}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 254}], {
             RGBColor[
             0.8755547142857143, 0.45466757142857156`, 0.2149012142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 283}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 225}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 251}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 269}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 282}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 219}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 254}], {
             RGBColor[
             0.9055083571428572, 0.5628944285714286, 0.45916335714285716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 283}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 212}], {
             RGBColor[
             0.4257709285714285, 0.5385553571428572, 0.9492239285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 214}], {
             RGBColor[
             0.6417487142857143, 0.7052103571428572, 0.7258179285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 225}], {
             RGBColor[
             0.6309117142857144, 0.6691446428571428, 0.6420494999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 242}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 244}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 252}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 268}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 279}], {
             RGBColor[
             0.8975810714285714, 0.6807742857142856, 0.5899719285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 259}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 211}], {
             RGBColor[
             0.9124627142857145, 0.6868797142857146, 0.2482285714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 226}], {
             RGBColor[
             0.9124627142857145, 0.6868797142857146, 0.2482285714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 227}], {
             RGBColor[
             0.9124627142857145, 0.6868797142857146, 0.2482285714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 241}], {
             RGBColor[
             0.7262382142857142, 0.6266562857142859, 0.5947413571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 290}], {
             RGBColor[
             0.9124627142857145, 0.6868797142857146, 0.2482285714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 291}], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 231}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 264}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 266}], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 214}], {
             RGBColor[
             0.7773192142857142, 0.8214162857142857, 0.7352040000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 225}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 265}], {
             RGBColor[
             0.7519839999999999, 0.8057464285714286, 0.9703062142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 276}], {
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 234}], {
             RGBColor[
             0.6399127142857143, 0.7173828571428572, 0.9655927142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 249}], {
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 263}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 286}], {
             RGBColor[
             0.7773192142857142, 0.8214162857142857, 0.7352040000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 265}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 276}], {
             RGBColor[
             0.7773192142857142, 0.8214162857142857, 0.7352040000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 286}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 229}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 233}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 259}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 296}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 237}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 269}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 293}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 299}], {
             RGBColor[
             0.7262382142857142, 0.6266562857142859, 0.5947413571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 223}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 246}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 247}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 251}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 270}], {
             RGBColor[
             0.8934179285714287, 0.8304337142857144, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 271}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 278}], {
             RGBColor[
             0.9124627142857145, 0.6868797142857146, 0.2482285714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 295}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 220}], {
             RGBColor[0.851338, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 262}], {
             RGBColor[
             0.7857647142857144, 0.8328318571428572, 0.9792104285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 290}], {
             RGBColor[
             0.8261372142857144, 0.7776062857142859, 0.6190799285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 292}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 250}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 222}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 248}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 262}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 230}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 232}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 245}], {
             RGBColor[
             0.9124627142857145, 0.6868797142857146, 0.2482285714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 288}], {
             RGBColor[
             0.8755547142857143, 0.45466757142857156`, 0.2149012142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 296}], {
             RGBColor[0.9527067142857143, 0.845574, 0.3049227857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 297}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 248}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 285}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 246}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 247}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 270}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142857, 0.7488217142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 271}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 278}], {
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 295}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 253}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 262}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 265}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 276}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 241}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 243}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 290}], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 291}], {
             RGBColor[
             0.9124627142857145, 0.6868797142857146, 0.2482285714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 241}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 290}], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 291}], {
             RGBColor[
             0.9124627142857145, 0.6868797142857146, 0.2482285714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 299}], {
             RGBColor[
             0.9124627142857145, 0.6868797142857146, 0.2482285714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 264}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 233}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 259}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 284}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 245}], {
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 288}], {
             RGBColor[0.905308, 0.5610991428571428, 0.3380080000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 296}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 297}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 232}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 245}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 264}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 266}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 240}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 245}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 288}], {
             RGBColor[
             0.9055083571428572, 0.5628944285714286, 0.45916335714285716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 297}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 259}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[
             0.6399127142857143, 0.7173828571428572, 0.9655927142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 249}], {
             RGBColor[
             0.6399127142857143, 0.7173828571428572, 0.9655927142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 263}], {
             RGBColor[
             0.8261372142857144, 0.7776062857142859, 0.6190799285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 274}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 298}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 260}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 267}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 294}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 256}], {
             RGBColor[0.575275, 0.6106669285714285, 0.6388810714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 269}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 277}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 281}], {
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 293}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 248}], {
             RGBColor[
             0.7773192142857142, 0.8214162857142857, 0.7352040000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 258}], {
             RGBColor[
             0.7519839999999999, 0.8057464285714286, 0.9703062142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 263}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 285}], {
             RGBColor[0.7727667142857142, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 290}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 291}], {
             RGBColor[
             0.7262382142857142, 0.6266562857142859, 0.5947413571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 250}], {
             RGBColor[
             0.7664822142857142, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 268}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 254}], {
             RGBColor[
             0.8799727857142856, 0.5454292857142857, 0.5731102142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 256}], {
             RGBColor[
             0.5607767857142857, 0.6310627857142858, 0.9577517142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 283}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 279}], {
             RGBColor[
             0.9183637857142857, 0.6962739999999998, 0.5547922142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 280}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 264}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.4924907142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 288}], {
             RGBColor[
             0.8542270000000001, 0.3663391428571431, 0.1975453571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 297}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 270}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142857, 0.7488217142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 278}], {
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 295}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 251}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 270}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285714, 0.6650532857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 271}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 278}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 289}], {
             RGBColor[
             0.9120792857142856, 0.6603784285714284, 0.2711012857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 295}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 285}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 258}], {
             RGBColor[
             0.7519839999999999, 0.8057464285714286, 0.9703062142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 263}], {
             RGBColor[
             0.7475659285714286, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 286}], {
             RGBColor[
             0.7773192142857142, 0.8214162857142857, 0.7352040000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 270}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 271}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 278}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 282}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 289}], {
             RGBColor[
             0.8975810714285714, 0.6807742857142856, 0.5899719285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 295}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857143, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 268}], {
             RGBColor[0.942216, 0.7933112857142859, 0.37133535714285726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 279}], {
             RGBColor[
             0.8718352857142857, 0.501684142857143, 0.21440707142857146`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 280}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 283}], {
             RGBColor[0.9376635, 0.7931411428571431, 0.5712578571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 283}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{255, 258}], {
             RGBColor[
             0.9634092857142856, 0.9722312857142857, 0.9468227142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 286}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 269}], {
             RGBColor[
             0.5863123571428572, 0.6485279285714285, 0.8438048571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 277}], {
             RGBColor[
             0.5863123571428572, 0.6485279285714285, 0.8438048571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 281}], {
             RGBColor[
             0.44870550000000003`, 0.5426992142857143, 0.9530382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 293}], {
             RGBColor[0.5815595, 0.6465624999999999, 0.922572]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{257, 267}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 272}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 300}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 263}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 286}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 267}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 287}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 294}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 300}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 284}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 292}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 286}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.3886912142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 288}], {
             RGBColor[
             0.9055083571428572, 0.5628944285714286, 0.45916335714285716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 276}], {
             RGBColor[
             0.7519839999999999, 0.8057464285714286, 0.9703062142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 286}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 272}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 287}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 300}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 279}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.35486971428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 280}], {
             RGBColor[
             0.9824599999999999, 0.9520055714285713, 0.4280295714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 277}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 282}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 293}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 271}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 278}], {
             RGBColor[
             0.8720902142857143, 0.742105285714286, 0.6083590714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 289}], {
             RGBColor[0.8527905, 0.6452381428571428, 0.5918934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 295}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 278}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 289}], {
             RGBColor[
             0.9231166428571429, 0.6982394285714284, 0.4760250714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 295}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 274}], {
             RGBColor[
             0.8558905000000001, 0.8840378571428572, 0.7421867142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 289}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.35486971428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 289}], {
             RGBColor[
             0.7855097857142858, 0.5924107142857142, 0.5852584285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 281}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 282}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 293}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 295}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.4924907142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 280}], {
             RGBColor[
             0.9120792857142856, 0.6603784285714284, 0.2711012857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 294}], {
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 293}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 300}], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 296}], {
             RGBColor[0.894471, 0.5250334285714284, 0.2542395714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 297}], {
             RGBColor[
             0.8799727857142856, 0.5454292857142857, 0.5731102142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 291}], {
             RGBColor[
             0.9124627142857145, 0.6868797142857146, 0.2482285714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 297}], {
             RGBColor[
             0.9571247857142856, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.032105813875877395`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.032105813875877395`], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.032105813875877395`], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.032105813875877395`], {
             RGBColor[
             0.7184840000000001, 0.7800044285714287, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.032105813875877395`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.032105813875877395`], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.032105813875877395`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.032105813875877395`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.032105813875877395`], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.032105813875877395`], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.032105813875877395`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.032105813875877395`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.032105813875877395`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.032105813875877395`], {
             RGBColor[
             0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.032105813875877395`], {
             RGBColor[
             0.7184840000000001, 0.7800044285714287, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.032105813875877395`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.032105813875877395`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.032105813875877395`], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.032105813875877395`], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.032105813875877395`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.032105813875877395`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.032105813875877395`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.032105813875877395`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.032105813875877395`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.032105813875877395`], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.032105813875877395`], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.032105813875877395`], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.032105813875877395`], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.032105813875877395`], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.032105813875877395`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.032105813875877395`], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.032105813875877395`], {
             RGBColor[
             0.7184840000000001, 0.7800044285714287, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.032105813875877395`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.032105813875877395`], {
             RGBColor[
             0.7184840000000001, 0.7800044285714287, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.032105813875877395`], {
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.032105813875877395`], {
             RGBColor[
             0.7184840000000001, 0.7800044285714287, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.032105813875877395`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.032105813875877395`], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.032105813875877395`], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.032105813875877395`], {
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.032105813875877395`], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.032105813875877395`], {
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.032105813875877395`], {
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.032105813875877395`], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.032105813875877395`], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.032105813875877395`], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.032105813875877395`], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.032105813875877395`], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.032105813875877395`], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.032105813875877395`], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.032105813875877395`], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.032105813875877395`], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.032105813875877395`], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.032105813875877395`], {
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.032105813875877395`], {
             RGBColor[
             0.7184840000000001, 0.7800044285714287, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.032105813875877395`], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.032105813875877395`], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.032105813875877395`], {
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.032105813875877395`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.032105813875877395`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.032105813875877395`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.032105813875877395`], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.032105813875877395`], {
             RGBColor[
             0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.032105813875877395`], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.032105813875877395`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.032105813875877395`], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.032105813875877395`], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.032105813875877395`], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.032105813875877395`], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.032105813875877395`], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.032105813875877395`], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.032105813875877395`], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.032105813875877395`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.032105813875877395`], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.032105813875877395`], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.032105813875877395`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.032105813875877395`], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.032105813875877395`], {
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.032105813875877395`], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.032105813875877395`], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.032105813875877395`], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.032105813875877395`], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.032105813875877395`], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.032105813875877395`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.032105813875877395`], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.032105813875877395`], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.032105813875877395`], {
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.032105813875877395`], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.032105813875877395`], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.032105813875877395`], {
             RGBColor[0.41201171428571426`, 0.5312855714285714, 0.947474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.032105813875877395`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.032105813875877395`], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.032105813875877395`], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.032105813875877395`], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.032105813875877395`], {
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.032105813875877395`], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.032105813875877395`], {
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.032105813875877395`], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.032105813875877395`], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.032105813875877395`], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.032105813875877395`], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.032105813875877395`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.032105813875877395`], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.032105813875877395`], {
             RGBColor[
             0.7184840000000001, 0.7800044285714287, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.032105813875877395`], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.032105813875877395`], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.032105813875877395`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.032105813875877395`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.032105813875877395`], {
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.032105813875877395`], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.032105813875877395`], {
             RGBColor[
             0.7184840000000001, 0.7800044285714287, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.032105813875877395`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.032105813875877395`], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.032105813875877395`], {
             RGBColor[
             0.29020042857142864`, 0.42234942857142865`, 0.9398378571428572]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.032105813875877395`], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.032105813875877395`], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.032105813875877395`], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.032105813875877395`], {
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.032105813875877395`], {
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.032105813875877395`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.032105813875877395`], {
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.032105813875877395`], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.032105813875877395`], {
             RGBColor[
             0.7184840000000001, 0.7800044285714287, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.032105813875877395`], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.032105813875877395`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.032105813875877395`], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.032105813875877395`], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.032105813875877395`], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.032105813875877395`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.032105813875877395`], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.032105813875877395`], {
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.032105813875877395`], {
             RGBColor[
             0.7184840000000001, 0.7800044285714287, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.032105813875877395`], {
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.032105813875877395`], {
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.032105813875877395`], {
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.032105813875877395`], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.032105813875877395`], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.032105813875877395`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.032105813875877395`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.032105813875877395`], {
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.032105813875877395`], {
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.032105813875877395`], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.032105813875877395`], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.032105813875877395`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.032105813875877395`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.032105813875877395`], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.032105813875877395`], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.032105813875877395`], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.032105813875877395`], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.032105813875877395`], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.032105813875877395`], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.032105813875877395`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.032105813875877395`], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.032105813875877395`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.032105813875877395`], {
             RGBColor[
             0.7184840000000001, 0.7800044285714287, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.032105813875877395`], {
             RGBColor[0.5613414285714284, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.032105813875877395`], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.032105813875877395`], {
             RGBColor[
             0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.032105813875877395`], {
             RGBColor[
             0.7184840000000001, 0.7800044285714287, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.032105813875877395`], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.032105813875877395`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117980000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.032105813875877395`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.032105813875877395`], {
             RGBColor[
             0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.032105813875877395`], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.032105813875877395`], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.032105813875877395`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.032105813875877395`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.032105813875877395`], {
             RGBColor[
             0.9426265714285713, 0.9567315714285715, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.032105813875877395`], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.032105813875877395`], {
             RGBColor[
             0.9716229999999999, 0.915939857142857, 0.3442611428571426]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1FO4EAYYBuBzsm2dTrZdW7WsZbtVy3bLtWxr2bat5WVjyzZXrfc8u3i/
//a7+f7gJu2rtAsMCAjIJEJuKEIThrCEIzwRiEgkIhOFqEQjOjGISSxiE4e4
xCM+CUhIIhKThKQkI4jkBJOClKQiNWlISzrSk4GMIX3JTBayko3s5CAnuchN
HvKSj/wUoCCF+IEfKUwRivITxShOCUpSitKUoSzlKE8FfqYilahMFapSjerU
oCa1qE0d6lKP+jSgIY1oTBN+oSnNaM6vtKAlrWhNG9rSjvZ0oCOd6EwXutKN
7vSgJ73ozW/0oS/96M8ABjKIwQzhd4YyjOGMYCSjGM0YxjKO8UxgIpOYzBSm
Mo3pzGAms5jNH8xhLvOYzwIWsojFLGEpy1jOClayitWsYS3rWM8GNrKJzWxh
K9vYzg52sovd7GEv+9jPAQ5yiMMc4U+OcozjnOAkpzjNX5zhLOc4zwUuconL
XOEq17jODW5yi9v8zT/c4S73uM8DHvKIxzzhKc94zgte8orXvOEt73jPBz7y
ic/8yxe+8o3/CBl/IKEITRjCEo7wRCAikYhMFKISjejEICaxiE0c4hKP+CQg
IYlITBKSkowgkhNMClKSitSkIS3pSE8GMgb+/6++Az6VhWw=
          "], {Null, CompressedData["
1:eJxN2guYllWBB/D3qyhJJoMEhjQEkUhkrd1Es1FL08DywkWybEVNDSyNClNB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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[72, 227] -> 
             RGBColor[
              0.8910599718883171, 0.5386508737923311, 0.22830235227691478`], 
             UndirectedEdge[132, 236] -> 
             RGBColor[
              0.21416362323535532`, 0.3424299251513089, 0.9355076735653408], 
             UndirectedEdge[187, 193] -> 
             RGBColor[
              0.25215196023065367`, 0.38235807593304705`, 0.9376710531585147],
              UndirectedEdge[196, 225] -> 
             RGBColor[
              0.21532817540767707`, 0.3436539433212913, 0.935573993088754], 
             UndirectedEdge[39, 166] -> 
             RGBColor[
              0.19390930592620187`, 0.3211413534614994, 0.9343542201581618], 
             UndirectedEdge[7, 216] -> 
             RGBColor[
              0.9023917020151102, 0.7200221295355724, 0.5997896268007754], 
             UndirectedEdge[92, 281] -> 
             RGBColor[
              0.9050081321346448, 0.6135030027694477, 0.5495966137001128], 
             UndirectedEdge[99, 229] -> 
             RGBColor[
              0.20669327315473038`, 0.33457811356902034`, 0.9350822481796419],
              UndirectedEdge[187, 296] -> 
             RGBColor[
              0.20597365560918635`, 0.3338217499022659, 0.9350412670250019], 
             UndirectedEdge[100, 244] -> 
             RGBColor[
              0.18508330510196136`, 0.31186466699444937`, 0.9338515924681194],
              UndirectedEdge[232, 245] -> 
             RGBColor[
              0.206575126823306, 0.3344539342837832, 0.9350755199208491], 
             UndirectedEdge[6, 52] -> 
             RGBColor[
              0.20466403550360635`, 0.3324452561365908, 0.9349666860973984], 
             UndirectedEdge[113, 160] -> 
             RGBColor[
              0.23169850636271255`, 0.3608601990939647, 0.936506259218909], 
             UndirectedEdge[176, 288] -> 
             RGBColor[
              0.20152898742648828`, 0.32915012183401104`, 0.9347881497472945],
              UndirectedEdge[187, 228] -> 
             RGBColor[
              0.32549861800497937`, 0.4485853630705261, 0.9422458467242234], 
             UndirectedEdge[61, 268] -> 
             RGBColor[
              0.24115438507843467`, 0.37079892716152685`, 0.9370447575230503],
              UndirectedEdge[51, 101] -> 
             RGBColor[
              0.7293123816710212, 0.7884636426315792, 0.9736547004594159], 
             UndirectedEdge[207, 214] -> 
             RGBColor[
              0.19305906954872248`, 0.3202477011206687, 0.9343058004542764], 
             UndirectedEdge[17, 162] -> 
             RGBColor[
              0.8475057087773203, 0.8795582824939998, 0.8820715972741542], 
             UndirectedEdge[20, 279] -> 
             RGBColor[
              0.22783544818024304`, 0.35679988001215385`, 0.9362862637702997],
              UndirectedEdge[51, 197] -> 
             RGBColor[
              0.8988192263028636, 0.9205652040419037, 0.9289214218265444], 
             UndirectedEdge[86, 94] -> 
             RGBColor[
              0.6955329406462065, 0.7613368008112785, 0.9707925147289977], 
             UndirectedEdge[55, 114] -> 
             RGBColor[
              0.22063449464495144`, 0.3492312212797382, 0.9358761801193209], 
             UndirectedEdge[13, 270] -> 
             RGBColor[
              0.27306394266259, 0.4020687514269927, 0.9389450440967648], 
             UndirectedEdge[151, 220] -> 
             RGBColor[
              0.46545874896093703`, 0.5736549196510825, 0.9519637517959829], 
             UndirectedEdge[117, 225] -> 
             RGBColor[
              0.20655322702626136`, 0.33443091620856197`, 0.9350742727598051],
              UndirectedEdge[13, 277] -> 
             RGBColor[
              0.6631499633187324, 0.7252798242769541, 0.7115734484509257], 
             UndirectedEdge[81, 237] -> 
             RGBColor[
              0.857269778961983, 0.39235407740723033`, 0.20056198469547004`], 
             UndirectedEdge[172, 174] -> 
             RGBColor[
              0.21189442021644855`, 0.34004484890265657`, 0.9353784458103991],
              UndirectedEdge[128, 197] -> 
             RGBColor[
              0.9156409832962333, 0.6675280137453463, 0.53334242652665], 
             UndirectedEdge[44, 71] -> 
             RGBColor[
              0.26976807981775686`, 0.40018277558695564`, 0.9386995645005083],
              UndirectedEdge[70, 122] -> 
             RGBColor[
              0.19740509453050553`, 0.32481564893042175`, 0.9345533001476212],
              UndirectedEdge[42, 293] -> 
             RGBColor[
              0.8686817504503115, 0.4638809195993508, 0.210856119307727], 
             UndirectedEdge[154, 181] -> 
             RGBColor[
              0.7417957890267707, 0.7840980478369171, 0.6774116520475943], 
             UndirectedEdge[42, 216] -> 
             RGBColor[
              0.8520342261383788, 0.3882883998269512, 0.19696501695368862`], 
             UndirectedEdge[125, 130] -> 
             RGBColor[
              0.8734988271236623, 0.4797808744280881, 0.21461427312304276`], 
             UndirectedEdge[173, 263] -> 
             RGBColor[
              0.20558810816091344`, 0.33341651508901093`, 0.935019310668189], 
             UndirectedEdge[112, 132] -> 
             RGBColor[
              0.1930638232066118, 0.32025269751650964`, 0.9343060711680607], 
             UndirectedEdge[208, 279] -> 
             RGBColor[
              0.21299163292133522`, 0.34119808902279597`, 0.9354409304507616],
              UndirectedEdge[271, 295] -> 
             RGBColor[
              0.20977901412683497`, 0.3378214229779799, 0.9352579765630585], 
             UndirectedEdge[193, 264] -> 
             RGBColor[
              0.28788684943506876`, 0.4199177102097248, 0.939706102233675], 
             UndirectedEdge[16, 39] -> 
             RGBColor[
              0.22425729902189784`, 0.35303901837897317`, 0.9360824934691292],
              UndirectedEdge[168, 282] -> 
             RGBColor[
              0.42052178364044757`, 0.5386565657751188, 0.9480162540941248], 
             UndirectedEdge[92, 243] -> 
             RGBColor[
              0.9094860988652742, 0.6163067889114571, 0.5180190463996183], 
             UndirectedEdge[71, 280] -> 
             RGBColor[
              0.2426648792276659, 0.37238655228322937`, 0.9371307779302732], 
             UndirectedEdge[69, 118] -> 
             RGBColor[
              0.19814492935345804`, 0.3255932622375819, 0.9345954326463008], 
             UndirectedEdge[175, 253] -> 
             RGBColor[
              0.18722926764301806`, 0.3141202096869836, 0.9339738018601655], 
             UndirectedEdge[137, 179] -> 
             RGBColor[
              0.3921454633437752, 0.5078279411583735, 0.9468889147894293], 
             UndirectedEdge[134, 221] -> 
             RGBColor[
              0.21549733286296777`, 0.343831738532004, 0.9355836263555868], 
             UndirectedEdge[91, 163] -> 
             RGBColor[
              0.5556545906660699, 0.6501444545135875, 0.9581623112885165], 
             UndirectedEdge[160, 232] -> 
             RGBColor[
              0.19183608079529113`, 0.31896226239884673`, 0.9342361530540182],
              UndirectedEdge[135, 263] -> 
             RGBColor[
              0.21148289076359805`, 0.33961230535523634`, 0.9353550098168626],
              UndirectedEdge[160, 297] -> 
             RGBColor[
              0.1938787777952211, 0.3211092664602433, 0.9343524816262648], 
             UndirectedEdge[179, 274] -> 
             RGBColor[
              0.4929016619374462, 0.5991987999844676, 0.9532221708674471], 
             UndirectedEdge[209, 259] -> 
             RGBColor[
              0.18280847530695815`, 0.30947367664736153`, 0.9337220442766032],
              UndirectedEdge[14, 173] -> 
             RGBColor[
              0.1907403974209291, 0.31781062970205387`, 0.9341737555067666], 
             UndirectedEdge[260, 267] -> 
             RGBColor[
              0.22718681650953165`, 0.35611812700061296`, 0.9362493251562173],
              UndirectedEdge[203, 216] -> 
             RGBColor[
              0.9017944048582103, 0.7195766662939407, 0.600800695087359], 
             UndirectedEdge[37, 279] -> 
             RGBColor[
              0.23161750381713786`, 0.36077506028270767`, 0.936501646243771], 
             UndirectedEdge[192, 220] -> 
             RGBColor[
              0.3318533670341157, 0.4618564399149144, 0.9423663809943715], 
             UndirectedEdge[60, 225] -> 
             RGBColor[
              0.25743202099321577`, 0.38790775456968785`, 0.9379717448077927],
              UndirectedEdge[177, 226] -> 
             RGBColor[
              0.6391144281004404, 0.7063980774045702, 0.908678535889838], 
             UndirectedEdge[91, 273] -> 
             RGBColor[
              0.3645444727684772, 0.4827165664417553, 0.9449621664859775], 
             UndirectedEdge[52, 273] -> 
             RGBColor[
              0.2188316043007933, 0.34733626921817795`, 0.9357735081813584], 
             UndirectedEdge[21, 114] -> 
             RGBColor[
              0.21635493982133241`, 0.34473313782066695`, 0.9356324658031498],
              UndirectedEdge[7, 202] -> 
             RGBColor[
              0.9024452109054028, 0.7202651009090716, 0.5998342759304583], 
             UndirectedEdge[94, 293] -> 
             RGBColor[
              0.8483237902546403, 0.739482330174071, 0.6092293420609014], 
             UndirectedEdge[132, 133] -> 
             RGBColor[
              0.19109281456444907`, 0.3181810424644308, 0.9341938251417357], 
             UndirectedEdge[13, 93] -> 
             RGBColor[
              0.2872094013725457, 0.41693652540503934`, 0.939750607043966], 
             UndirectedEdge[141, 178] -> 
             RGBColor[
              0.27642955220691934`, 0.4078753643883386, 0.9390536261060842], 
             UndirectedEdge[245, 264] -> 
             RGBColor[
              0.26072622472382, 0.3913701715551329, 0.938159344836913], 
             UndirectedEdge[5, 83] -> 
             RGBColor[
              0.9087826368179345, 0.636355140842231, 0.2670511550343114], 
             UndirectedEdge[210, 226] -> 
             RGBColor[
              0.7289680937933078, 0.7852771577024377, 0.9144848957128108], 
             UndirectedEdge[91, 298] -> 
             RGBColor[
              0.3751482927558811, 0.4938618535695355, 0.9455660383473143], 
             UndirectedEdge[126, 192] -> 
             RGBColor[
              0.2770528278061131, 0.40650831596386994`, 0.939163161568517], 
             UndirectedEdge[127, 156] -> 
             RGBColor[
              0.3716633849526351, 0.49633787652625627`, 0.9449030401335229], 
             UndirectedEdge[36, 268] -> 
             RGBColor[
              0.19319132437376368`, 0.32038670932722724`, 0.934313332170909], 
             UndirectedEdge[25, 221] -> 
             RGBColor[
              0.1886556188584439, 0.3156193952502866, 0.9340550304517865], 
             UndirectedEdge[69, 249] -> 
             RGBColor[
              0.20751277813074143`, 0.3354394652584245, 0.9351289177756767], 
             UndirectedEdge[22, 161] -> 
             RGBColor[
              0.1950980417525622, 0.32239079018520866`, 0.934421916904896], 
             UndirectedEdge[96, 112] -> 
             RGBColor[
              0.1950909003644823, 0.32238328413354655`, 0.9344215102134096], 
             UndirectedEdge[219, 250] -> 
             RGBColor[
              0.1834940050025886, 0.3101942118225623, 0.933761084178619], 
             UndirectedEdge[41, 219] -> 
             RGBColor[
              0.18646440411145038`, 0.3133162896201571, 0.933930244013557], 
             UndirectedEdge[202, 237] -> 
             RGBColor[
              0.8458226996057612, 0.34037556358393634`, 0.1910102610870475], 
             UndirectedEdge[91, 235] -> 
             RGBColor[
              0.44932632055040805`, 0.5626052939537676, 0.9501280434357534], 
             UndirectedEdge[69, 263] -> 
             RGBColor[
              0.2087290677202517, 0.3367178627342138, 0.9351981836684602], 
             UndirectedEdge[12, 239] -> 
             RGBColor[
              0.3335981101513706, 0.4567875043441526, 0.9427184858018454], 
             UndirectedEdge[122, 266] -> 
             RGBColor[
              0.19159505471631844`, 0.31870892870791034`, 0.9342224269753869],
              UndirectedEdge[206, 254] -> 
             RGBColor[
              0.27060222090313846`, 0.400822588016517, 0.9387557425033809], 
             UndirectedEdge[137, 270] -> 
             RGBColor[
              0.23718665422901314`, 0.36662859047011903`, 0.9368188011209075],
              UndirectedEdge[25, 58] -> 
             RGBColor[
              0.19112827338567, 0.31821831193375316`, 0.9341958444691476], 
             UndirectedEdge[107, 156] -> 
             RGBColor[
              0.4014834091317521, 0.5221664826722128, 0.9468031457054042], 
             UndirectedEdge[136, 194] -> 
             RGBColor[
              0.539310518839214, 0.6345587760249104, 0.957788184762517], 
             UndirectedEdge[45, 281] -> 
             RGBColor[
              0.6391981620742301, 0.7080190375817033, 0.9308676637061029], 
             UndirectedEdge[137, 147] -> 
             RGBColor[
              0.23746595794531072`, 0.3669221563848262, 0.9368347070543579], 
             UndirectedEdge[164, 187] -> 
             RGBColor[
              0.2033506574299822, 0.3310648125082323, 0.9348918911590742], 
             UndirectedEdge[199, 229] -> 
             RGBColor[
              0.20805355497894237`, 0.33600785601311617`, 0.9351597142171741],
              UndirectedEdge[191, 271] -> 
             RGBColor[
              0.22500596477055484`, 0.35382591354896176`, 0.9361251288759636],
              UndirectedEdge[153, 222] -> 
             RGBColor[
              0.2212473690290584, 0.3498753911159149, 0.9359110824088295], 
             UndirectedEdge[158, 186] -> 
             RGBColor[
              0.19303082310645578`, 0.3202180123189185, 0.9343041918611762], 
             UndirectedEdge[16, 192] -> 
             RGBColor[
              0.28870383608450384`, 0.4187542643810497, 0.9398266692538492], 
             UndirectedEdge[75, 143] -> 
             RGBColor[
              0.31991196504772945`, 0.4513422193006194, 0.941611753099148], 
             UndirectedEdge[204, 226] -> 
             RGBColor[
              0.734932739386402, 0.7901195256991334, 0.9149544544631159], 
             UndirectedEdge[137, 191] -> 
             RGBColor[
              0.24445543716588297`, 0.3742685422042259, 0.9372327475559615], 
             UndirectedEdge[197, 198] -> 
             RGBColor[
              0.9754663865596167, 0.9808663065126991, 0.9104194926535587], 
             UndirectedEdge[80, 156] -> 
             RGBColor[
              0.6866499660786538, 0.7281441949934098, 0.6592663633827371], 
             UndirectedEdge[103, 159] -> 
             RGBColor[
              0.35628521918114736`, 0.4813996069512451, 0.9439824173184419], 
             UndirectedEdge[28, 288] -> 
             RGBColor[
              0.19616769103516415`, 0.32351505940090497`, 0.9344828318491358],
              UndirectedEdge[118, 263] -> 
             RGBColor[
              0.19930513416780576`, 0.32681271105869525`, 0.9346615045941087],
              UndirectedEdge[68, 83] -> 
             RGBColor[
              0.8617045963739112, 0.6317374119212176, 0.5901643374072268], 
             UndirectedEdge[64, 90] -> 
             RGBColor[
              0.22549030939770529`, 0.3543349904613199, 0.936152711585956], 
             UndirectedEdge[213, 263] -> 
             RGBColor[
              0.2061321686296245, 0.3339883571370523, 0.9350502941070169], 
             UndirectedEdge[52, 53] -> 
             RGBColor[
              0.2073052253779457, 0.3352213141556316, 0.9351170979534518], 
             UndirectedEdge[245, 297] -> 
             RGBColor[
              0.20861782382323596`, 0.3366009383451798, 0.9351918484930957], 
             UndirectedEdge[189, 267] -> 
             RGBColor[
              0.20602096440657885`, 0.33387147444787646`, 0.9350439611910263],
              UndirectedEdge[145, 203] -> 
             RGBColor[
              0.9010144773435402, 0.923871728137574, 0.9891457475385399], 
             UndirectedEdge[136, 279] -> 
             RGBColor[
              0.3146411108912604, 0.44028382744269734`, 0.9415136410409652], 
             UndirectedEdge[80, 256] -> 
             RGBColor[
              0.898368256371338, 0.5394933847920658, 0.2684881883897252], 
             UndirectedEdge[40, 130] -> 
             RGBColor[
              0.8005184128051482, 0.7225949328330918, 0.608776500228449], 
             UndirectedEdge[83, 101] -> 
             RGBColor[
              0.7469403042896439, 0.5416229945947444, 0.5788476902726976], 
             UndirectedEdge[83, 194] -> 
             RGBColor[
              0.7662790641438353, 0.5567305807728573, 0.5807751971239775], 
             UndirectedEdge[149, 197] -> 
             RGBColor[
              0.9409227595816787, 0.803504489870005, 0.5552674312684278], 
             UndirectedEdge[23, 44] -> 
             RGBColor[
              0.6527829845870825, 0.7190887957178285, 0.883793610021852], 
             UndirectedEdge[97, 284] -> 
             RGBColor[
              0.3449079379891919, 0.4668961630433738, 0.9434276902262162], 
             UndirectedEdge[135, 276] -> 
             RGBColor[
              0.22722517815635135`, 0.3561584475236893, 0.9362515097952526], 
             UndirectedEdge[142, 150] -> 
             RGBColor[
              0.8686725031653917, 0.4508599338020208, 0.21032865402022227`], 
             UndirectedEdge[46, 214] -> 
             RGBColor[
              0.20276955741382008`, 0.3304540395473769, 0.9348587983728143], 
             UndirectedEdge[5, 243] -> 
             RGBColor[
              0.9792150980469998, 0.9514729807028455, 0.600039087887734], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.17910006852395627`, 0.30557590599185624`, 0.9335108559964074],
              UndirectedEdge[198, 243] -> 
             RGBColor[
              0.9760042846861029, 0.9810887412113525, 0.9015051286619535], 
             UndirectedEdge[13, 32] -> 
             RGBColor[
              0.6604824509868196, 0.7261357390166185, 0.898179624729629], 
             UndirectedEdge[86, 140] -> 
             RGBColor[
              0.7057480336302696, 0.4077728682153858, 0.5627064708792573], 
             UndirectedEdge[171, 275] -> 
             RGBColor[
              0.17966143058790973`, 0.3061659331134819, 0.9335428247354888], 
             UndirectedEdge[36, 250] -> 
             RGBColor[
              0.18199349180428678`, 0.3086170773131154, 0.9336756321717861], 
             UndirectedEdge[168, 203] -> 
             RGBColor[
              0.6687682561638781, 0.7369332784725033, 0.9690249189979729], 
             UndirectedEdge[17, 169] -> 
             RGBColor[
              0.654201051554568, 0.729209809683748, 0.9665623183284373], 
             UndirectedEdge[191, 246] -> 
             RGBColor[
              0.2059132617802264, 0.3337582721588391, 0.9350378276857872], 
             UndirectedEdge[17, 178] -> 
             RGBColor[
              0.4813372368134904, 0.5789969861106385, 0.9545799540531321], 
             UndirectedEdge[9, 132] -> 
             RGBColor[
              0.19792820821317225`, 0.32536547457822756`, 0.9345830906979717],
              UndirectedEdge[11, 283] -> 
             RGBColor[
              0.41881779248479195`, 0.534778825033336, 0.9485064845740085], 
             UndirectedEdge[64, 69] -> 
             RGBColor[
              0.22143670136219934`, 0.3500743914024093, 0.9359218646051097], 
             UndirectedEdge[193, 288] -> 
             RGBColor[
              0.24421454187002306`, 0.3740153459746332, 0.9372190289252349], 
             UndirectedEdge[221, 288] -> 
             RGBColor[
              0.19753047223834988`, 0.324947428850772, 0.9345604402226031], 
             UndirectedEdge[65, 264] -> 
             RGBColor[
              0.33683666992223255`, 0.4650136831097602, 0.942726350900722], 
             UndirectedEdge[27, 151] -> 
             RGBColor[
              0.7838347809145911, 0.7971566134890326, 0.6494113635450639], 
             UndirectedEdge[201, 293] -> 
             RGBColor[
              0.872561429430702, 0.49370183232880244`, 0.21457130428081972`], 
             UndirectedEdge[43, 99] -> 
             RGBColor[
              0.21063039427602828`, 0.33871627749540134`, 0.9353064614030511],
              UndirectedEdge[77, 293] -> 
             RGBColor[0.6567707297143, 0.585264649646495, 0.5928277208084357],
              UndirectedEdge[61, 280] -> 
             RGBColor[
              0.2696360759953822, 0.40073499015874336`, 0.9386667476858847], 
             UndirectedEdge[20, 55] -> 
             RGBColor[
              0.21057054856025512`, 0.3386533758536862, 0.9353030532780715], 
             UndirectedEdge[208, 242] -> 
             RGBColor[
              0.18509931747274389`, 0.3118814970113848, 0.9338525043489474], 
             UndirectedEdge[29, 261] -> 
             RGBColor[
              0.21999581851421782`, 0.3485599321719316, 0.9358398084585123], 
             UndirectedEdge[12, 76] -> 
             RGBColor[
              0.3782689418854923, 0.5020592779365523, 0.9453239403802199], 
             UndirectedEdge[168, 276] -> 
             RGBColor[
              0.3208926338924916, 0.4461337879304579, 0.9418960475542608], 
             UndirectedEdge[148, 271] -> 
             RGBColor[
              0.23446623518977533`, 0.3637692575753508, 0.9366638772811222], 
             UndirectedEdge[131, 170] -> 
             RGBColor[
              0.21349214626363155`, 0.34172416027992825`, 0.9354694339451624],
              UndirectedEdge[141, 261] -> 
             RGBColor[
              0.269292107733182, 0.4003734577063236, 0.9386471592022079], 
             UndirectedEdge[129, 184] -> 
             RGBColor[
              0.19028873719925032`, 0.31733590617215746`, 0.9341480341253134],
              UndirectedEdge[111, 185] -> 
             RGBColor[
              0.5718800780485805, 0.6633170361205862, 0.9594396410911864], 
             UndirectedEdge[234, 239] -> 
             RGBColor[
              0.2158656276199601, 0.3442188396728392, 0.9356046001971543], 
             UndirectedEdge[103, 203] -> 
             RGBColor[
              0.679227364936692, 0.7459924328014227, 0.96969136416035], 
             UndirectedEdge[28, 160] -> 
             RGBColor[
              0.18961722538074013`, 0.31663010467459485`, 0.9341097925206621],
              UndirectedEdge[133, 170] -> 
             RGBColor[
              0.1914328920115927, 0.3185384854235343, 0.9342131920492509], 
             UndirectedEdge[87, 299] -> 
             RGBColor[
              0.9059209744031474, 0.5662238856558284, 0.33056015938178984`], 
             UndirectedEdge[5, 290] -> 
             RGBColor[
              0.9587118125308915, 0.8695626925266455, 0.3088146906826389], 
             UndirectedEdge[183, 253] -> 
             RGBColor[
              0.19229512745236005`, 0.31944474954066526`, 0.9342622950820396],
              UndirectedEdge[176, 245] -> 
             RGBColor[
              0.20971756780007914`, 0.3377568389926374, 0.9352544772856515], 
             UndirectedEdge[29, 190] -> 
             RGBColor[
              0.199834842245044, 0.32736946783330456`, 0.9346916706854744], 
             UndirectedEdge[159, 168] -> 
             RGBColor[
              0.3458261104083336, 0.4723404526223259, 0.943315972156065], 
             UndirectedEdge[202, 299] -> 
             RGBColor[
              0.8426323172090826, 0.3158528864485842, 0.18795514730096657`], 
             UndirectedEdge[65, 115] -> 
             RGBColor[
              0.3645960621661024, 0.4902165167425332, 0.9444527165749532], 
             UndirectedEdge[51, 142] -> 
             RGBColor[
              0.8206161663608685, 0.5418070513656623, 0.579062899024987], 
             UndirectedEdge[134, 187] -> 
             RGBColor[
              0.23476961577043198`, 0.36408812980106076`, 0.9366811543563793],
              UndirectedEdge[85, 239] -> 
             RGBColor[
              0.2348622905163943, 0.36418553683498534`, 0.936686432046062], 
             UndirectedEdge[120, 284] -> 
             RGBColor[
              0.26002401193692654`, 0.39063210139324567`, 0.9381193548575302],
              UndirectedEdge[31, 61] -> 
             RGBColor[
              0.3484538930002764, 0.47332381494877457`, 0.9435307438846312], 
             UndirectedEdge[217, 247] -> 
             RGBColor[
              0.19889732977739935`, 0.3263840827880864, 0.9346382807373675], 
             UndirectedEdge[66, 169] -> 
             RGBColor[
              0.4955403552880472, 0.5995224478502696, 0.9539323726469158], 
             UndirectedEdge[168, 293] -> 
             RGBColor[
              0.650085093471142, 0.5794738875625195, 0.5924017179788976], 
             UndirectedEdge[93, 105] -> 
             RGBColor[
              0.26248514686677915`, 0.39321891024948796`, 0.9382595128508624],
              UndirectedEdge[169, 193] -> 
             RGBColor[
              0.44215135474031986`, 0.5505814803014513, 0.9506292633518225], 
             UndirectedEdge[87, 216] -> 
             RGBColor[
              0.9298058839378985, 0.7371387261923006, 0.3529360529247516], 
             UndirectedEdge[81, 201] -> 
             RGBColor[
              0.8674144933652834, 0.47033079775319603`, 0.2102765746648868], 
             UndirectedEdge[63, 244] -> 
             RGBColor[
              0.18619322197801913`, 0.31303126000398057`, 0.9339148005922362],
              UndirectedEdge[32, 150] -> 
             RGBColor[
              0.9475427884309859, 0.8298940012964792, 0.5491295264859543], 
             UndirectedEdge[95, 282] -> 
             RGBColor[
              0.36409426757402563`, 0.48782276310977274`, 0.9444924758077534],
              UndirectedEdge[126, 239] -> 
             RGBColor[
              0.2305322261132995, 0.35963436460539283`, 0.9364398412840619], 
             UndirectedEdge[149, 150] -> 
             RGBColor[
              0.901456610665, 0.644502615181237, 0.23943789960535378`], 
             UndirectedEdge[16, 222] -> 
             RGBColor[
              0.23410797445122994`, 0.3633927028240968, 0.9366434748620613], 
             UndirectedEdge[192, 262] -> 
             RGBColor[
              0.31722856394081744`, 0.4487355619302395, 0.9414511103067129], 
             UndirectedEdge[214, 276] -> 
             RGBColor[
              0.22110211631188992`, 0.34972272130061666`, 0.9359028104814688],
              UndirectedEdge[48, 100] -> 
             RGBColor[
              0.18673636136840888`, 0.31360213394030656`, 0.9339457315770161],
              UndirectedEdge[105, 143] -> 
             RGBColor[
              0.29536739445361543`, 0.4277802373181654, 0.9401321082060067], 
             UndirectedEdge[268, 279] -> 
             RGBColor[
              0.22085812887375872`, 0.34946627503344374`, 0.9358889157578143],
              UndirectedEdge[24, 106] -> 
             RGBColor[
              0.892812310133672, 0.8140725087445938, 0.6221015838690171], 
             UndirectedEdge[33, 222] -> 
             RGBColor[
              0.210965999406103, 0.33906901976570414`, 0.9353255736187255], 
             UndirectedEdge[155, 291] -> 
             RGBColor[
              0.9265943306289632, 0.845047396157727, 0.6262279650717502], 
             UndirectedEdge[99, 233] -> 
             RGBColor[
              0.20053490529032286`, 0.32810527848045334`, 0.9347315382402527],
              UndirectedEdge[237, 269] -> 
             RGBColor[
              0.8991197807384712, 0.5574407348110937, 0.260947978617189], 
             UndirectedEdge[85, 135] -> 
             RGBColor[
              0.22261249954375167`, 0.3513102298411313, 0.9359888245721116], 
             UndirectedEdge[126, 248] -> 
             RGBColor[
              0.22272354417989754`, 0.3514269447943572, 0.9359951483998643], 
             UndirectedEdge[188, 261] -> 
             RGBColor[
              0.30030042916823396`, 0.42860875023970424`, 0.9405725470875715],
              UndirectedEdge[37, 177] -> 
             RGBColor[
              0.2592700003340752, 0.38983958739155206`, 0.9380764150122078], 
             UndirectedEdge[160, 180] -> 
             RGBColor[
              0.19532450559808373`, 0.32262881804548893`, 0.9344348136858753],
              UndirectedEdge[23, 194] -> 
             RGBColor[
              0.8376760987270953, 0.8722472965038359, 0.8977776532625734], 
             UndirectedEdge[51, 243] -> 
             RGBColor[
              0.8993571244293498, 0.920787638740557, 0.9200070578349391], 
             UndirectedEdge[108, 208] -> 
             RGBColor[
              0.2150010029643497, 0.34331006433942324`, 0.9355553611021148], 
             UndirectedEdge[179, 251] -> 
             RGBColor[
              0.4041820274938994, 0.5204791332423994, 0.9475743793112779], 
             UndirectedEdge[26, 224] -> 
             RGBColor[
              0.21888166411978893`, 0.3473888852619182, 0.9357763590139934], 
             UndirectedEdge[106, 291] -> 
             RGBColor[
              0.8943677152627585, 0.9186085554583606, 0.9897867851648885], 
             UndirectedEdge[48, 161] -> 
             RGBColor[
              0.19723226696141938`, 0.3246339961974114, 0.9345434578732372], 
             UndirectedEdge[227, 299] -> 
             RGBColor[
              0.885699193119303, 0.49744557906545395`, 0.22316886447357331`], 
             UndirectedEdge[162, 299] -> 
             RGBColor[
              0.9050210878776606, 0.5676926894870836, 0.4792897876815234], 
             UndirectedEdge[200, 227] -> 
             RGBColor[
              0.6591374011618665, 0.6706282245294286, 0.6126589597072597], 
             UndirectedEdge[202, 293] -> 
             RGBColor[
              0.8831647510557664, 0.562360246757456, 0.22422214319796666`], 
             UndirectedEdge[3, 155] -> 
             RGBColor[
              0.9402661035019293, 0.855471333191099, 0.6109745630706932], 
             UndirectedEdge[39, 234] -> 
             RGBColor[
              0.19793969225016772`, 0.3253775450292399, 0.9345837446968894], 
             UndirectedEdge[144, 176] -> 
             RGBColor[
              0.19591627409858087`, 0.32325080425980146`, 0.9344685140265354],
              UndirectedEdge[140, 162] -> 
             RGBColor[
              0.904333638485641, 0.5624086522177772, 0.47863148536736244`], 
             UndirectedEdge[123, 257] -> 
             RGBColor[
              0.19133948148967972`, 0.3184403050424346, 0.9342078724582165], 
             UndirectedEdge[121, 286] -> 
             RGBColor[
              0.22317009351070355`, 0.3518962964538972, 0.9360205787236432], 
             UndirectedEdge[176, 230] -> 
             RGBColor[
              0.19313907822011844`, 0.32033179530714856`, 0.9343103568297502],
              UndirectedEdge[39, 64] -> 
             RGBColor[
              0.2185143800083959, 0.3470028463736865, 0.9357554427271977], 
             UndirectedEdge[269, 277] -> 
             RGBColor[
              0.9830880426173179, 0.9543005010685027, 0.41547009014484526`], 
             UndirectedEdge[154, 203] -> 
             RGBColor[
              0.7172113529376909, 0.7776981044453534, 0.9724416173890855], 
             UndirectedEdge[107, 137] -> 
             RGBColor[
              0.33500472849332374`, 0.4602209338581902, 0.9427270090780024], 
             UndirectedEdge[192, 218] -> 
             RGBColor[
              0.6489034320102649, 0.7179182155893853, 0.9413556495465901], 
             UndirectedEdge[247, 270] -> 
             RGBColor[
              0.20529778048290723`, 0.33311136229158844`, 0.935002776936428], 
             UndirectedEdge[28, 240] -> 
             RGBColor[
              0.18200025991928498`, 0.3086241910311017, 0.9336760176059227], 
             UndirectedEdge[31, 194] -> 
             RGBColor[
              0.552827044743554, 0.6462661114029045, 0.958649445840947], 
             UndirectedEdge[58, 187] -> 
             RGBColor[
              0.20794054512620663`, 0.3358890754926524, 0.9351532784732439], 
             UndirectedEdge[8, 121] -> 
             RGBColor[
              0.21495883648631775`, 0.3432657446975026, 0.9355529597835706], 
             UndirectedEdge[62, 186] -> 
             RGBColor[
              0.19739650616034748`, 0.3248066220088515, 0.934552811052646], 
             UndirectedEdge[271, 289] -> 
             RGBColor[
              0.23303990394891333`, 0.36227009300658086`, 0.9365826498270231],
              UndirectedEdge[236, 294] -> 
             RGBColor[
              0.38374017735760657`, 0.49740352912178454`, 0.9465549709165739],
              UndirectedEdge[115, 211] -> 
             RGBColor[
              0.3112307319414529, 0.4404795631489132, 0.9411810111605179], 
             UndirectedEdge[43, 284] -> 
             RGBColor[
              0.23327215251581435`, 0.3625142009758035, 0.9365958760393271], 
             UndirectedEdge[87, 181] -> 
             RGBColor[
              0.9897210070316473, 0.9765905802662477, 0.448420390956374], 
             UndirectedEdge[77, 205] -> 
             RGBColor[
              0.3930712028278346, 0.5148802523815419, 0.9462671273583405], 
             UndirectedEdge[132, 267] -> 
             RGBColor[
              0.19655119281637518`, 0.32391814408837505`, 0.9345046717082358],
              UndirectedEdge[108, 280] -> 
             RGBColor[
              0.2513491898337207, 0.3815143133472875, 0.9376253365720018], 
             UndirectedEdge[40, 97] -> 
             RGBColor[
              0.5690459020341019, 0.6601769695084484, 0.9597409246828227], 
             UndirectedEdge[35, 262] -> 
             RGBColor[
              0.25511664496274467`, 0.3854741475583434, 0.9378398875681493], 
             UndirectedEdge[201, 216] -> 
             RGBColor[
              0.8559139051187693, 0.4181093125564028, 0.20068020192678135`], 
             UndirectedEdge[244, 279] -> 
             RGBColor[
              0.21308524932289044`, 0.3412964857964532, 0.9354462617663373], 
             UndirectedEdge[143, 163] -> 
             RGBColor[
              0.4640224729127619, 0.5716064552084593, 0.95205347173178], 
             UndirectedEdge[102, 165] -> 
             RGBColor[
              0.20499479718794766`, 0.3327929076383356, 0.9349855224860035], 
             UndirectedEdge[7, 282] -> 
             RGBColor[
              0.6894759164963487, 0.7547973275205713, 0.9692952652700408], 
             UndirectedEdge[10, 122] -> 
             RGBColor[
              0.1877216481680741, 0.3146377328375459, 0.9340018422026558], 
             UndirectedEdge[113, 193] -> 
             RGBColor[
              0.2735981771019762, 0.40489940963349313`, 0.9388923834825018], 
             UndirectedEdge[22, 100] -> 
             RGBColor[
              0.1846021361595517, 0.3113589279281038, 0.9338241906086748], 
             UndirectedEdge[116, 254] -> 
             RGBColor[
              0.30306682721859113`, 0.43494494762898417`, 0.9406045538059649],
              UndirectedEdge[174, 298] -> 
             RGBColor[
              0.24667128016472487`, 0.3765975336885693, 0.9373589365366997], 
             UndirectedEdge[159, 271] -> 
             RGBColor[
              0.2569380089981777, 0.38738851664073326`, 0.9379436115555007], 
             UndirectedEdge[11, 101] -> 
             RGBColor[
              0.589571415450858, 0.6776035417182125, 0.9608844110153827], 
             UndirectedEdge[148, 225] -> 
             RGBColor[
              0.23694694145511846`, 0.36637663714608804`, 0.9368051498330575],
              UndirectedEdge[239, 248] -> 
             RGBColor[
              0.22976740900447992`, 0.35883049333181793`, 0.9363962860811601],
              UndirectedEdge[22, 119] -> 
             RGBColor[
              0.18469650892406414`, 0.31145811968718523`, 0.933829564998002], 
             UndirectedEdge[38, 247] -> 
             RGBColor[
              0.19193794866685385`, 0.31906933199065524`, 0.9342419542786038],
              UndirectedEdge[157, 222] -> 
             RGBColor[
              0.20198183109515816`, 0.32962608924173, 0.9348139385243031], 
             UndirectedEdge[42, 203] -> 
             RGBColor[
              0.8873649131430477, 0.6213403105093347, 0.5874793203268023], 
             UndirectedEdge[155, 241] -> 
             RGBColor[
              0.9562190222247212, 0.8670479840915544, 0.569594959834627], 
             UndirectedEdge[103, 154] -> 
             RGBColor[
              0.45931362601150366`, 0.5710619602704519, 0.9508179830889629], 
             UndirectedEdge[88, 107] -> 
             RGBColor[
              0.3156668760979841, 0.43989562490003076`, 0.9416257469918767], 
             UndirectedEdge[58, 176] -> 
             RGBColor[
              0.19266677740688082`, 0.31983537720683475`, 0.9342834599971428],
              UndirectedEdge[48, 119] -> 
             RGBColor[
              0.1868307341329213, 0.31370132569938797`, 0.933951105966343], 
             UndirectedEdge[206, 219] -> 
             RGBColor[
              0.20337837440800324`, 0.33109394480949034`, 0.9348934695999689],
              UndirectedEdge[1, 125] -> 
             RGBColor[
              0.8269439386544566, 0.20810849617316574`, 0.17343485212532112`],
              UndirectedEdge[191, 278] -> 
             RGBColor[
              0.21400334724237668`, 0.34226146492060344`, 0.9354985460846478],
              UndirectedEdge[90, 118] -> 
             RGBColor[
              0.20219853738896398`, 0.32985386129649247`, 0.9348262796271471],
              UndirectedEdge[101, 283] -> 
             RGBColor[
              0.4765743997943146, 0.5815921216615045, 0.9531053393092228], 
             UndirectedEdge[5, 226] -> 
             RGBColor[
              0.978634912205556, 0.9512330589473125, 0.6096542687532867], 
             UndirectedEdge[3, 241] -> 
             RGBColor[
              0.9701712881509421, 0.9769533662972854, 0.9210009349471945], 
             UndirectedEdge[194, 241] -> 
             RGBColor[
              0.8360648746712487, 0.8715810139501738, 0.9244798055821426], 
             UndirectedEdge[139, 235] -> 
             RGBColor[
              0.42460849977243, 0.5421962738843169, 0.9482766560323135], 
             UndirectedEdge[40, 94] -> 
             RGBColor[
              0.7430612286953848, 0.7992043464221197, 0.9750250570405241], 
             UndirectedEdge[161, 177] -> 
             RGBColor[
              0.24681318446187503`, 0.3767466841021262, 0.9373670177764938], 
             UndirectedEdge[34, 295] -> 
             RGBColor[
              0.19030787854135572`, 0.3173560249363414, 0.9341491241964293], 
             UndirectedEdge[1, 281] -> 
             RGBColor[
              0.8985774900643843, 0.5640742698921016, 0.5434386235912599], 
             UndirectedEdge[191, 295] -> 
             RGBColor[
              0.21214976125282442`, 0.34031322852144436`, 0.9353929871046776],
              UndirectedEdge[144, 297] -> 
             RGBColor[
              0.19481653012173772`, 0.32209490361234383`, 0.9344058852339796],
              UndirectedEdge[141, 294] -> 
             RGBColor[
              0.41494859536709305`, 0.5302055551777425, 0.9483322441534972], 
             UndirectedEdge[80, 201] -> 
             RGBColor[
              0.9120862504146132, 0.6449358982719986, 0.2816245549778238], 
             UndirectedEdge[113, 115] -> 
             RGBColor[
              0.3096806718260522, 0.43885035168813935`, 0.9410927375300542], 
             UndirectedEdge[129, 253] -> 
             RGBColor[
              0.19046881652676248`, 0.3175251809630616, 0.9341582893766117], 
             UndirectedEdge[37, 108] -> 
             RGBColor[
              0.23362687386015235`, 0.362887035599335, 0.936616076895124], 
             UndirectedEdge[265, 276] -> 
             RGBColor[
              0.23204484364859856`, 0.36122422154048306`, 0.93652598261498], 
             UndirectedEdge[59, 194] -> 
             RGBColor[
              0.8355066141794747, 0.8713501588901851, 0.9337316266626792], 
             UndirectedEdge[103, 225] -> 
             RGBColor[
              0.3244631340928782, 0.4479525778867464, 0.9421701966492211], 
             UndirectedEdge[46, 265] -> 
             RGBColor[
              0.21371228475052867`, 0.3419555397872433, 0.9354819705063254], 
             UndirectedEdge[51, 149] -> 
             RGBColor[
              0.8534002738604769, 0.7354497327448786, 0.6081721446101185], 
             UndirectedEdge[52, 124] -> 
             RGBColor[
              0.1923287617954415, 0.3194801013677844, 0.9342642105081206], 
             UndirectedEdge[82, 258] -> 
             RGBColor[
              0.47680058453134755`, 0.5830547562597531, 0.9528035659599465], 
             UndirectedEdge[45, 132] -> 
             RGBColor[
              0.24841553022607393`, 0.3784308510948885, 0.9374582689973068], 
             UndirectedEdge[74, 287] -> 
             RGBColor[
              0.2244511741859948, 0.35324279346883447`, 0.936093534372912], 
             UndirectedEdge[128, 269] -> 
             RGBColor[
              0.9090525762339738, 0.6337885535682664, 0.2704596348011703], 
             UndirectedEdge[14, 249] -> 
             RGBColor[
              0.19382527220510481`, 0.3210530286925808, 0.9343494345620621], 
             UndirectedEdge[101, 198] -> 
             RGBColor[
              0.8059595419277743, 0.8487647451023745, 0.9551527712864303], 
             UndirectedEdge[164, 297] -> 
             RGBColor[
              0.18697714573381324`, 0.31385521357495705`, 0.9339594438904173],
              UndirectedEdge[68, 235] -> 
             RGBColor[
              0.6426752269533634, 0.7164421222894727, 0.967683202312762], 
             UndirectedEdge[108, 177] -> 
             RGBColor[
              0.2663285931328081, 0.3972586159636525, 0.9384783914298436], 
             UndirectedEdge[62, 276] -> 
             RGBColor[
              0.22152543341226616`, 0.3501676544129665, 0.9359269177640938], 
             UndirectedEdge[13, 107] -> 
             RGBColor[
              0.3708820169269006, 0.49566109481506393`, 0.9448532520538597], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.21391225518849333`, 0.3421657213964022, 0.9354933585269378], 
             UndirectedEdge[62, 135] -> 
             RGBColor[
              0.20737676424851148`, 0.33529650604442257`, 0.9351211719862982],
              UndirectedEdge[18, 35] -> 
             RGBColor[
              0.20318410319091706`, 0.3308897534428262, 0.9348824061415544], 
             UndirectedEdge[42, 202] -> 
             RGBColor[
              0.8520877350286713, 0.3885313712004504, 0.1970096660833716], 
             UndirectedEdge[121, 255] -> 
             RGBColor[
              0.295733658786952, 0.42287002848225363`, 0.9403468487457121], 
             UndirectedEdge[128, 281] -> 
             RGBColor[
              0.9117009146920902, 0.6649466623019902, 0.5560056298355394], 
             UndirectedEdge[82, 181] -> 
             RGBColor[
              0.7998668067519439, 0.8312427160957487, 0.681983215284067], 
             UndirectedEdge[136, 204] -> 
             RGBColor[
              0.4381119186941594, 0.553069802846105, 0.9493643283826801], 
             UndirectedEdge[118, 166] -> 
             RGBColor[
              0.18740769372755933`, 0.31430774681470364`, 0.9339839629617225],
              UndirectedEdge[39, 263] -> 
             RGBColor[
              0.2058067463664483, 0.333646317705491, 0.935031761790548], 
             UndirectedEdge[52, 84] -> 
             RGBColor[
              0.1931004885069918, 0.32029123507192336`, 0.9343081592026761], 
             UndirectedEdge[129, 165] -> 
             RGBColor[
              0.20344097121398075`, 0.33115973802143944`, 0.9348970343954657],
              UndirectedEdge[141, 236] -> 
             RGBColor[
              0.2626393533607303, 0.39338099105188706`, 0.9382682946825648], 
             UndirectedEdge[97, 178] -> 
             RGBColor[
              0.353934746876465, 0.4763839115166376, 0.9439417536383794], 
             UndirectedEdge[115, 227] -> 
             RGBColor[
              0.6522166119287909, 0.6646337847447196, 0.6122179731371418], 
             UndirectedEdge[256, 281] -> 
             RGBColor[
              0.8981948395566131, 0.5611330504108505, 0.5430721970328762], 
             UndirectedEdge[221, 297] -> 
             RGBColor[
              0.18909437890281156`, 0.31608055987591055`, 0.9340800171872259],
              UndirectedEdge[224, 262] -> 
             RGBColor[
              0.2562537795699573, 0.3866693481290222, 0.9379046457017901], 
             UndirectedEdge[73, 119] -> 
             RGBColor[
              0.18176019735719462`, 0.3083718700574992, 0.9336623463981524], 
             UndirectedEdge[3, 227] -> 
             RGBColor[
              0.9534614284413586, 0.9077863994945625, 0.6215918312510428], 
             UndirectedEdge[45, 188] -> 
             RGBColor[
              0.32789958178650086`, 0.45761720952884744`, 0.9421442779998944],
              UndirectedEdge[260, 300] -> 
             RGBColor[
              0.24190674150061214`, 0.37158970146338766`, 0.9370876031082818],
              UndirectedEdge[23, 291] -> 
             RGBColor[
              0.9581107393338224, 0.9671957118175754, 0.9095521846286824], 
             UndirectedEdge[142, 149] -> 
             RGBColor[
              0.8627196996396836, 0.42474633719376353`, 0.20540890846687038`],
              UndirectedEdge[81, 97] -> 
             RGBColor[
              0.6691615275279388, 0.5770839186847934, 0.5896504800872672], 
             UndirectedEdge[181, 201] -> 
             RGBColor[
              0.9158290282125181, 0.65756116663035, 0.29616453995840375`], 
             UndirectedEdge[56, 57] -> 
             RGBColor[
              0.18951617750640207`, 0.3165238969518603, 0.9341040379937053], 
             UndirectedEdge[197, 243] -> 
             RGBColor[
              0.9868796101505515, 0.9888423958656835, 0.8671023444932484], 
             UndirectedEdge[65, 200] -> 
             RGBColor[
              0.37151685139917806`, 0.49621095652724223`, 0.9448937031450712],
              UndirectedEdge[8, 173] -> 
             RGBColor[
              0.2028775855537629, 0.3305675839718365, 0.9348649504155706], 
             UndirectedEdge[53, 273] -> 
             RGBColor[
              0.2274037724911021, 0.35634616149304726`, 0.9362616804784101], 
             UndirectedEdge[26, 253] -> 
             RGBColor[
              0.21047277090696587`, 0.3385506053406179, 0.9352974849853658], 
             UndirectedEdge[114, 206] -> 
             RGBColor[
              0.2307773334017795, 0.35989198790628496`, 0.936453799781537], 
             UndirectedEdge[9, 45] -> 
             RGBColor[
              0.24944742731977937`, 0.3795154403664275, 0.9375170340102383], 
             UndirectedEdge[47, 190] -> 
             RGBColor[
              0.1942570496898653, 0.32150685420533776`, 0.9343740236510617], 
             UndirectedEdge[191, 282] -> 
             RGBColor[
              0.3340044293562811, 0.4561964353369906, 0.9427789040351794], 
             UndirectedEdge[59, 155] -> 
             RGBColor[
              0.9556607617329471, 0.8668171290315656, 0.5788467809151635], 
             UndirectedEdge[214, 265] -> 
             RGBColor[
              0.21177311264038245`, 0.33991734694886655`, 0.9353715375234006],
              UndirectedEdge[167, 282] -> 
             RGBColor[
              0.674157084988882, 0.6138860835498305, 0.5969373306942671], 
             UndirectedEdge[28, 221] -> 
             RGBColor[
              0.18483282648833058`, 0.31160139809026205`, 0.9338373280816231],
              UndirectedEdge[136, 197] -> 
             RGBColor[
              0.689478603616865, 0.751552751257122, 0.9111273992783655], 
             UndirectedEdge[121, 234] -> 
             RGBColor[
              0.20980230497718771`, 0.3378459031384259, 0.9352593029425303], 
             UndirectedEdge[141, 146] -> 
             RGBColor[
              0.24693839801171524`, 0.3768782914820059, 0.9373741485029203], 
             UndirectedEdge[32, 167] -> 
             RGBColor[
              0.947679092916505, 0.830434403160785, 0.5492392002744804], 
             UndirectedEdge[101, 136] -> 
             RGBColor[
              0.5199717589850226, 0.6194511898467974, 0.9558606779112371], 
             UndirectedEdge[91, 274] -> 
             RGBColor[
              0.4766026768727841, 0.5859665496480654, 0.9519390550580074], 
             UndirectedEdge[84, 295] -> 
             RGBColor[
              0.19219536521772562`, 0.31933989310677346`, 0.9342566137703623],
              UndirectedEdge[73, 122] -> 
             RGBColor[
              0.18385458485627515`, 0.31057320411086997`, 0.9337816186678564],
              UndirectedEdge[157, 248] -> 
             RGBColor[
              0.20224840910221648`, 0.3299062796291701, 0.9348291197474383], 
             UndirectedEdge[125, 167] -> 
             RGBColor[
              0.871438247578835, 0.47161136318027613`, 0.21295628245325632`], 
             UndirectedEdge[20, 208] -> 
             RGBColor[
              0.20416035452872197`, 0.331915855496769, 0.9349380022110079], 
             UndirectedEdge[77, 103] -> 
             RGBColor[
              0.41755616548084906`, 0.5360878963815774, 0.9478272875273883], 
             UndirectedEdge[46, 276] -> 
             RGBColor[
              0.22304128842203616`, 0.35176091413899346`, 0.9360132434643936],
              UndirectedEdge[3, 291] -> 
             RGBColor[
              0.940546596555184, 0.9549527783634579, 0.9776339401843177], 
             UndirectedEdge[79, 297] -> 
             RGBColor[
              0.1875669958551452, 0.3144751834511347, 0.9339930349822221], 
             UndirectedEdge[18, 262] -> 
             RGBColor[
              0.25190729178629806`, 0.38210091388515394`, 0.9376571196525632],
              UndirectedEdge[127, 225] -> 
             RGBColor[
              0.28821593818422175`, 0.41655707862770686`, 0.9398605573780583],
              UndirectedEdge[109, 292] -> 
             RGBColor[
              0.8832633694480486, 0.907223500639492, 0.873440789605417], 
             UndirectedEdge[267, 287] -> 
             RGBColor[
              0.2196035170740144, 0.34814759848492993`, 0.9358174674718507], 
             UndirectedEdge[218, 262] -> 
             RGBColor[
              0.6355147016275733, 0.7058679616598169, 0.9405191403190352], 
             UndirectedEdge[207, 225] -> 
             RGBColor[
              0.20644219198451136`, 0.33431421133965444`, 0.9350679494784392],
              UndirectedEdge[203, 299] -> 
             RGBColor[
              0.8779094953234592, 0.5486618257574685, 0.5784248015443972], 
             UndirectedEdge[142, 163] -> 
             RGBColor[
              0.7255429896746053, 0.4672102742569026, 0.5698090215965668], 
             UndirectedEdge[2, 54] -> 
             RGBColor[
              0.22131402237840694`, 0.34994544801214666`, 0.9359148782184701],
              UndirectedEdge[90, 195] -> 
             RGBColor[
              0.19970007804544365`, 0.3272278221149808, 0.934683996063673], 
             UndirectedEdge[88, 93] -> 
             RGBColor[
              0.23199426054362918`, 0.36117105549000617`, 0.9365231019819831],
              UndirectedEdge[77, 82] -> 
             RGBColor[
              0.5136111712070213, 0.6149382362843397, 0.9551491039925967], 
             UndirectedEdge[167, 168] -> 
             RGBColor[
              0.6540467218133117, 0.5964674977433942, 0.5956559161356156], 
             UndirectedEdge[18, 26] -> 
             RGBColor[
              0.21453517633612967`, 0.3428204510180499, 0.9355288329647664], 
             UndirectedEdge[129, 224] -> 
             RGBColor[
              0.19887770973958555`, 0.32636346088436186`, 0.9346371634052393],
              UndirectedEdge[38, 289] -> 
             RGBColor[
              0.21478203632197956`, 0.34307991651500525`, 0.935542891275764], 
             UndirectedEdge[31, 241] -> 
             RGBColor[
              0.7028863769460394, 0.7632151146504713, 0.9137909719699326], 
             UndirectedEdge[5, 197] -> 
             RGBColor[
              0.9786771999205136, 0.9512505460041922, 0.6089534518793391], 
             UndirectedEdge[59, 241] -> 
             RGBColor[
              0.9855659463819599, 0.9882991621377519, 0.8888731527916648], 
             UndirectedEdge[155, 226] -> 
             RGBColor[
              0.9562854870849291, 0.8670754690193194, 0.5684934650954372], 
             UndirectedEdge[15, 186] -> 
             RGBColor[
              0.22574603195372214`, 0.35460377108144014`, 0.9361672746072136],
              UndirectedEdge[198, 256] -> 
             RGBColor[
              0.8912595826963075, 0.5559607471998754, 0.554811777892692], 
             UndirectedEdge[72, 291] -> 
             RGBColor[
              0.8781451400021425, 0.5858172526612265, 0.5843444612101898], 
             UndirectedEdge[230, 297] -> 
             RGBColor[
              0.19203933424327527`, 0.319175894659691, 0.9342477280371944], 
             UndirectedEdge[138, 231] -> 
             RGBColor[
              0.23123426787294182`, 0.3603722550067954, 0.9364798215236958], 
             UndirectedEdge[54, 165] -> 
             RGBColor[
              0.2309155676527057, 0.3600372808685661, 0.936461672017628], 
             UndirectedEdge[103, 167] -> 
             RGBColor[
              0.6645058305861254, 0.6055266520723135, 0.5963223612979925], 
             UndirectedEdge[78, 131] -> 
             RGBColor[
              0.21176961520445978`, 0.33991367092196156`, 0.9353713383495988],
              UndirectedEdge[16, 239] -> 
             RGBColor[
              0.2421832343916902, 0.3718803130225725, 0.9371033489693941], 
             UndirectedEdge[12, 87] -> 
             RGBColor[
              0.7113840896935575, 0.7671448961592477, 0.7220908533867955], 
             UndirectedEdge[125, 281] -> 
             RGBColor[
              0.9068280234058514, 0.6274914845613823, 0.5513393436366936], 
             UndirectedEdge[148, 205] -> 
             RGBColor[
              0.3093284827197305, 0.43657270388582725`, 0.9411425228750159], 
             UndirectedEdge[103, 269] -> 
             RGBColor[
              0.6972472679550255, 0.7302486647196956, 0.6491594274470608], 
             UndirectedEdge[40, 169] -> 
             RGBColor[
              0.6469863029423364, 0.7235735932337524, 0.9658432196124291], 
             UndirectedEdge[38, 53] -> 
             RGBColor[
              0.2009984379794762, 0.32859248072642344`, 0.9347579357411648], 
             UndirectedEdge[118, 285] -> 
             RGBColor[
              0.19420033164892994`, 0.32144723994818314`, 0.9343707936425373],
              UndirectedEdge[74, 267] -> 
             RGBColor[
              0.2010537316252639, 0.328650597853966, 0.9347610846324927], 
             UndirectedEdge[3, 200] -> 
             RGBColor[
              0.659894342148658, 0.7282185404316961, 0.9534476666394777], 
             UndirectedEdge[124, 273] -> 
             RGBColor[
              0.2124273089085979, 0.3406049487052001, 0.9354087930330789], 
             UndirectedEdge[131, 182] -> 
             RGBColor[
              0.24187571808972635`, 0.3715570938915489, 0.9370858363709268], 
             UndirectedEdge[62, 207] -> 
             RGBColor[
              0.19348238664909873`, 0.3206926342330184, 0.9343299077369014], 
             UndirectedEdge[75, 262] -> 
             RGBColor[
              0.318384602518598, 0.4497368644421247, 0.9415247720626443], 
             UndirectedEdge[197, 283] -> 
             RGBColor[
              0.646081244426157, 0.713693683071829, 0.9083720606763512], 
             UndirectedEdge[246, 278] -> 
             RGBColor[
              0.1925398971260588, 0.3197020179870163, 0.9342762343528525], 
             UndirectedEdge[225, 265] -> 
             RGBColor[
              0.22515623507617133`, 0.35398385716785236`, 0.9361336865475633],
              UndirectedEdge[101, 204] -> 
             RGBColor[
              0.5654681824695174, 0.6580354513456885, 0.9589869162220399], 
             UndirectedEdge[87, 140] -> 
             RGBColor[
              0.9052335250111279, 0.560939848386522, 0.3299018570676289], 
             UndirectedEdge[57, 247] -> 
             RGBColor[
              0.18871603896391997`, 0.3156829006119979, 0.9340584712874099], 
             UndirectedEdge[40, 66] -> 
             RGBColor[
              0.5377876957046065, 0.6331026822689709, 0.9577491794160538], 
             UndirectedEdge[167, 293] -> 
             RGBColor[
              0.9037203948195764, 0.6547034053372311, 0.24132279457904], 
             UndirectedEdge[42, 140] -> 
             RGBColor[
              0.8274618672116081, 0.2120895220211726, 0.17393082109656596`], 
             UndirectedEdge[107, 150] -> 
             RGBColor[
              0.657942354371067, 0.5994193570949246, 0.595803153810185], 
             UndirectedEdge[91, 143] -> 
             RGBColor[
              0.39852667636969663`, 0.5184340170227889, 0.9468974027089019], 
             UndirectedEdge[91, 142] -> 
             RGBColor[
              0.6600471931315399, 0.4140378360712322, 0.5646529525736886], 
             UndirectedEdge[44, 283] -> 
             RGBColor[
              0.3110200455084933, 0.44354120705361005`, 0.9410488029197814], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.19626308316666907`, 0.323615322579327, 0.9344882642899051], 
             UndirectedEdge[199, 233] -> 
             RGBColor[
              0.20189518711453486`, 0.32953502092454917`, 0.9348090042777849],
              UndirectedEdge[249, 286] -> 
             RGBColor[
              0.2141737173623244, 0.342440534718758, 0.9355082484109388], 
             UndirectedEdge[48, 266] -> 
             RGBColor[
              0.19547981769013628`, 0.32279206090159157`, 0.934443658479754], 
             UndirectedEdge[113, 169] -> 
             RGBColor[
              0.4361857848874334, 0.5443112881470928, 0.9502895329739705], 
             UndirectedEdge[18, 33] -> 
             RGBColor[
              0.20024058888485757`, 0.32779593327757145`, 0.9347147773563635],
              UndirectedEdge[269, 293] -> 
             RGBColor[
              0.9364618321884765, 0.7794254179846133, 0.2941598607281082], 
             UndirectedEdge[189, 257] -> 
             RGBColor[
              0.1999558217805158, 0.327496624995631, 0.9346985602910465], 
             UndirectedEdge[11, 197] -> 
             RGBColor[
              0.7590782600827003, 0.809705103128537, 0.9161511323825111], 
             UndirectedEdge[221, 296] -> 
             RGBColor[
              0.18670137270172213`, 0.31356535863320917`, 0.9339437390242094],
              UndirectedEdge[126, 157] -> 
             RGBColor[
              0.20301322621103607`, 0.33071015090274497`, 0.93487267495034], 
             UndirectedEdge[24, 87] -> 
             RGBColor[
              0.9584560317231505, 0.8616047223377981, 0.3765513268644449], 
             UndirectedEdge[53, 137] -> 
             RGBColor[
              0.2387057780017381, 0.36822528587326325`, 0.936905312972422], 
             UndirectedEdge[27, 140] -> 
             RGBColor[
              0.8935802518260152, 0.5220287258229606, 0.25077918297631857`], 
             UndirectedEdge[115, 200] -> 
             RGBColor[
              0.35864952563609026`, 0.485065925681853, 0.9440738085255767], 
             UndirectedEdge[1, 5] -> 
             RGBColor[
              0.8948530465649757, 0.5292862061726197, 0.25371216367685606`], 
             UndirectedEdge[40, 42] -> 
             RGBColor[
              0.763419188891056, 0.5236029358473995, 0.5766518342873496], 
             UndirectedEdge[82, 167] -> 
             RGBColor[
              0.7605608363122977, 0.684376991975076, 0.6036441777632009], 
             UndirectedEdge[52, 57] -> 
             RGBColor[
              0.18920436008623348`, 0.3161961570728968, 0.9340862804529193], 
             UndirectedEdge[27, 203] -> 
             RGBColor[
              0.9534832977574548, 0.9312795143111227, 0.6643276822065549], 
             UndirectedEdge[251, 270] -> 
             RGBColor[
              0.24922321837913736`, 0.37927978255414485`, 0.9375042656427561],
              UndirectedEdge[200, 264] -> 
             RGBColor[
              0.3308901333922204, 0.45986309204908005`, 0.9423474428513454], 
             UndirectedEdge[84, 271] -> 
             RGBColor[
              0.20505156873545605`, 0.33285257813429087`, 0.9349887555416483],
              UndirectedEdge[80, 145] -> 
             RGBColor[
              0.9218561356347152, 0.9176464031707863, 0.6795757972164687], 
             UndirectedEdge[199, 259] -> 
             RGBColor[
              0.19177802866162308`, 0.31890124592564373`, 0.9342328470708863],
              UndirectedEdge[273, 274] -> 
             RGBColor[
              0.3509883555182567, 0.4717110997619036, 0.9438949792783465], 
             UndirectedEdge[281, 294] -> 
             RGBColor[
              0.7572554970898742, 0.8088426757639791, 0.9389810177450694], 
             UndirectedEdge[18, 183] -> 
             RGBColor[
              0.19635753288152386`, 0.32371459521809726`, 0.9344936430614402],
              UndirectedEdge[77, 269] -> 
             RGBColor[
              0.6934737954253698, 0.7269802724747518, 0.6489189851142219], 
             UndirectedEdge[134, 144] -> 
             RGBColor[
              0.22121948408189393`, 0.34984608226843733`, 0.9359094944023405],
              UndirectedEdge[200, 210] -> 
             RGBColor[
              0.4186246829308158, 0.5365148469090834, 0.9480331221442837], 
             UndirectedEdge[87, 151] -> 
             RGBColor[
              0.7954880540997038, 0.8360677360525939, 0.7285340376363743], 
             UndirectedEdge[109, 290] -> 
             RGBColor[
              0.9696110495252712, 0.9082697495604787, 0.5222701846474617], 
             UndirectedEdge[247, 278] -> 
             RGBColor[
              0.19919319876560948`, 0.3266950598538726, 0.9346551300385472], 
             UndirectedEdge[156, 205] -> 
             RGBColor[
              0.38342561820827703`, 0.5065257317852604, 0.945652519235638], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.18357179140558838`, 0.31027597026405784`, 0.9337655139991952],
              UndirectedEdge[64, 121] -> 
             RGBColor[
              0.2303769927354159, 0.3594712044828725, 0.9364310009728385], 
             UndirectedEdge[106, 264] -> 
             RGBColor[
              0.579035279379287, 0.6606770441091168, 0.9634331593756991], 
             UndirectedEdge[91, 107] -> 
             RGBColor[
              0.44931704433721525`, 0.562597259364136, 0.9501274523636514], 
             UndirectedEdge[7, 299] -> 
             RGBColor[
              0.8785067924803591, 0.5491072889991002, 0.5774137332578136], 
             UndirectedEdge[160, 221] -> 
             RGBColor[
              0.19098000658392586`, 0.31806247412446187`, 0.9341874008941293],
              UndirectedEdge[8, 234] -> 
             RGBColor[
              0.19931169581116837`, 0.32681960776190155`, 0.934661878269991], 
             UndirectedEdge[49, 174] -> 
             RGBColor[
              0.22141328802375174`, 0.3500497824992095, 0.9359205312501221], 
             UndirectedEdge[79, 245] -> 
             RGBColor[
              0.20419166956427437`, 0.3319487695846225, 0.9349397855559562], 
             UndirectedEdge[13, 147] -> 
             RGBColor[
              0.27334324637888757`, 0.4023623173416999, 0.9389609500302152], 
             UndirectedEdge[1, 197] -> 
             RGBColor[
              0.9025175586685273, 0.5666556213354577, 0.5207754202823706], 
             UndirectedEdge[129, 175] -> 
             RGBColor[
              0.18584814501363772`, 0.3126685622352725, 0.9338951489696101], 
             UndirectedEdge[116, 283] -> 
             RGBColor[
              0.29658629715284524`, 0.4290613813379507, 0.9402015229115228], 
             UndirectedEdge[62, 265] -> 
             RGBColor[
              0.2121964297407587, 0.3403622800612163, 0.9353956448060256], 
             UndirectedEdge[31, 291] -> 
             RGBColor[
              0.6732616853502813, 0.7412145267166439, 0.970423977207056], 
             UndirectedEdge[92, 277] -> 
             RGBColor[
              0.9122829383943001, 0.6155043542913563, 0.3292695837766948], 
             UndirectedEdge[124, 289] -> 
             RGBColor[
              0.2146845283282537, 0.3429774294312355, 0.9355373383397714], 
             UndirectedEdge[80, 277] -> 
             RGBColor[
              0.9859097978901593, 0.963818944183442, 0.4264320765360633], 
             UndirectedEdge[119, 244] -> 
             RGBColor[
              0.18517767786647377`, 0.3119638587535308, 0.9338569668574466], 
             UndirectedEdge[252, 268] -> 
             RGBColor[
              0.22149590633125682`, 0.35013661957870057`, 0.9359252362405117],
              UndirectedEdge[3, 194] -> 
             RGBColor[
              0.8201119559484569, 0.8600043630497185, 0.9658594088182089], 
             UndirectedEdge[1, 237] -> 
             RGBColor[
              0.8218840344451928, 0.1692158551566011, 0.1685894821401856], 
             UndirectedEdge[149, 281] -> 
             RGBColor[
              0.9369826909775356, 0.800923138426649, 0.5779306345773171], 
             UndirectedEdge[29, 209] -> 
             RGBColor[
              0.1878554243304431, 0.3147783400660943, 0.9340094605571987], 
             UndirectedEdge[123, 287] -> 
             RGBColor[
              0.22080206667647367`, 0.3494073501095485, 0.9358857230986155], 
             UndirectedEdge[17, 81] -> 
             RGBColor[
              0.7965640174649642, 0.6796969932787943, 0.60028868050202], 
             UndirectedEdge[176, 187] -> 
             RGBColor[
              0.20946640578711895`, 0.33749285179242483`, 0.9352401739805742],
              UndirectedEdge[246, 270] -> 
             RGBColor[
              0.19864447884335656`, 0.3261183204247322, 0.9346238812507333], 
             UndirectedEdge[45, 131] -> 
             RGBColor[
              0.2646712879230951, 0.39551668310902466`, 0.9383840103499137], 
             UndirectedEdge[4, 158] -> 
             RGBColor[
              0.2067416614051505, 0.33462897268820413`, 0.9350850038189193], 
             UndirectedEdge[169, 264] -> 
             RGBColor[
              0.450474457220526, 0.5593295887233245, 0.9511032517251437], 
             UndirectedEdge[42, 181] -> 
             RGBColor[
              0.9119493492321276, 0.6277402539008983, 0.29244935498531105`], 
             UndirectedEdge[8, 263] -> 
             RGBColor[
              0.20717874992744892`, 0.3350883804381527, 0.9351098953636496], 
             UndirectedEdge[145, 205] -> 
             RGBColor[
              0.6186317877643385, 0.696027939962637, 0.9659619530693695], 
             UndirectedEdge[167, 269] -> 
             RGBColor[
              0.9404234605306463, 0.796419028165488, 0.2974140588848261], 
             UndirectedEdge[187, 288] -> 
             RGBColor[
              0.2168027551458141, 0.3452038201198287, 0.9356579682233956], 
             UndirectedEdge[47, 131] -> 
             RGBColor[
              0.20675371716772, 0.33464164405904423`, 0.9350856903767627], 
             UndirectedEdge[43, 97] -> 
             RGBColor[
              0.33722237523593046`, 0.45881814929687276`, 0.9429900087971892],
              UndirectedEdge[104, 114] -> 
             RGBColor[
              0.28710993911342014`, 0.4166656473064825, 0.939751033226302], 
             UndirectedEdge[26, 129] -> 
             RGBColor[
              0.20909164827758553`, 0.33709895788890676`, 0.9352188320948104],
              UndirectedEdge[28, 79] -> 
             RGBColor[
              0.1833054434406642, 0.3099960216654862, 0.9337503458766192], 
             UndirectedEdge[53, 247] -> 
             RGBColor[
              0.2068169042556322, 0.33470805769473266`, 0.9350892887879424], 
             UndirectedEdge[150, 281] -> 
             RGBColor[
              0.9429354945032435, 0.8270367350349062, 0.582850380130669], 
             UndirectedEdge[76, 248] -> 
             RGBColor[
              0.2744382407386017, 0.40410226692421763`, 0.9390017406595347], 
             UndirectedEdge[194, 210] -> 
             RGBColor[
              0.5788422967306146, 0.6683006695271059, 0.9604448643230148], 
             UndirectedEdge[60, 265] -> 
             RGBColor[
              0.2549916258941355, 0.3853427445905684, 0.9378327679171411], 
             UndirectedEdge[78, 178] -> 
             RGBColor[
              0.2265713684695162, 0.3554712520888972, 0.9362142763008121], 
             UndirectedEdge[120, 190] -> 
             RGBColor[
              0.24175240008128845`, 0.37142747884586735`, 0.937078813592779], 
             UndirectedEdge[96, 267] -> 
             RGBColor[
              0.19857826997424566`, 0.3260487307054119, 0.9346201107535846], 
             UndirectedEdge[159, 212] -> 
             RGBColor[
              0.2623047179263146, 0.3930292679932042, 0.9382492376896236], 
             UndirectedEdge[34, 147] -> 
             RGBColor[
              0.19854534996450335`, 0.32601412968792354`, 0.9346182360077306],
              UndirectedEdge[41, 250] -> 
             RGBColor[
              0.18562426514456906`, 0.3124332502980778, 0.9338823993422674], 
             UndirectedEdge[146, 236] -> 
             RGBColor[
              0.2157299800022288, 0.3440762654260479, 0.9355968752659971], 
             UndirectedEdge[82, 103] -> 
             RGBColor[
              0.5173846437366769, 0.6182066285292835, 0.9553895463254356], 
             UndirectedEdge[179, 289] -> 
             RGBColor[
              0.383100677252795, 0.49832129750419296`, 0.9463738276021099], 
             UndirectedEdge[124, 247] -> 
             RGBColor[
              0.191840440673128, 0.3189668449068855, 0.9342364013426112], 
             UndirectedEdge[162, 227] -> 
             RGBColor[
              0.9720263822129245, 0.9204431940139248, 0.5369240475267748], 
             UndirectedEdge[156, 191] -> 
             RGBColor[
              0.31093411780431135`, 0.4362140910182484, 0.9413088841833633], 
             UndirectedEdge[1, 51] -> 
             RGBColor[
              0.8149950729473256, 0.4986008642103312, 0.5736801336240612], 
             UndirectedEdge[23, 198] -> 
             RGBColor[
              0.9769688580402975, 0.9814876170817164, 0.8855196519471269], 
             UndirectedEdge[77, 159] -> 
             RGBColor[
              0.3525117466514917, 0.4781312147063014, 0.9437419749856031], 
             UndirectedEdge[2, 238] -> 
             RGBColor[
              0.19301734075154908`, 0.3202038415090809, 0.9343034240610095], 
             UndirectedEdge[113, 245] -> 
             RGBColor[
              0.24643755239072743`, 0.3763518709789012, 0.9373456260857398], 
             UndirectedEdge[167, 201] -> 
             RGBColor[
              0.8765230577728718, 0.5106954425096772, 0.21782550243753762`], 
             UndirectedEdge[125, 150] -> 
             RGBColor[
              0.871301943093316, 0.4710709613159703, 0.2128466086647302], 
             UndirectedEdge[142, 198] -> 
             RGBColor[
              0.8972633266176216, 0.6021081538364577, 0.5605609698520013], 
             UndirectedEdge[34, 52] -> 
             RGBColor[
              0.1912130018306219, 0.3183073669014913, 0.934200669628743], 
             UndirectedEdge[13, 251] -> 
             RGBColor[
              0.3094480150189227, 0.44031071835692515`, 0.9410170631920465], 
             UndirectedEdge[120, 188] -> 
             RGBColor[
              0.317477361422549, 0.44666279511939655`, 0.9415507479684607], 
             UndirectedEdge[67, 173] -> 
             RGBColor[
              0.1901069718936137, 0.3171448593113474, 0.934137682860055], 
             UndirectedEdge[20, 280] -> 
             RGBColor[
              0.24050854139809294`, 0.3701201045046333, 0.9370079776808949], 
             UndirectedEdge[32, 107] -> 
             RGBColor[
              0.6980757286113448, 0.7586971466019095, 0.9005750351374335], 
             UndirectedEdge[189, 287] -> 
             RGBColor[
              0.22941840696730975`, 0.35846367006274493`, 0.9363764109314454],
              UndirectedEdge[159, 205] -> 
             RGBColor[
              0.33180025652813283`, 0.4601919629512097, 0.9424222571493942], 
             UndirectedEdge[66, 86] -> 
             RGBColor[
              0.49025940765542825`, 0.5952351366581299, 0.9535166371045274], 
             UndirectedEdge[119, 266] -> 
             RGBColor[
              0.1895006672172379, 0.3165075946545396, 0.9341031547056828], 
             UndirectedEdge[28, 230] -> 
             RGBColor[
              0.1877777818287943, 0.3146967328740425, 0.9340050389315915], 
             UndirectedEdge[83, 142] -> 
             RGBColor[
              0.8382440889794911, 0.2949664033288275, 0.18425588883826852`], 
             UndirectedEdge[191, 217] -> 
             RGBColor[
              0.21370747825416658`, 0.3419504878548173, 0.9354816967834682], 
             UndirectedEdge[43, 233] -> 
             RGBColor[
              0.2154911007768475, 0.3438251882143545, 0.9355832714475019], 
             UndirectedEdge[113, 297] -> 
             RGBColor[
              0.22981287868159825`, 0.35887828484541334`, 0.9363988755120056],
              UndirectedEdge[158, 207] -> 
             RGBColor[
              0.189116703595207, 0.3161040245430854, 0.9340812885454315], 
             UndirectedEdge[40, 201] -> 
             RGBColor[
              0.7672988678714465, 0.5534238485768511, 0.5803670192604423], 
             UndirectedEdge[194, 226] -> 
             RGBColor[
              0.8361313395314567, 0.8716084988779389, 0.9233783108429527], 
             UndirectedEdge[134, 230] -> 
             RGBColor[
              0.21844228820343148`, 0.34692707331578443`, 0.9357513372055553],
              UndirectedEdge[134, 264] -> 
             RGBColor[
              0.27050450497484707`, 0.4016477640777385, 0.9387162034315397], 
             UndirectedEdge[59, 226] -> 
             RGBColor[
              0.9856324112421679, 0.988326647065517, 0.887771658052475], 
             UndirectedEdge[42, 201] -> 
             RGBColor[
              0.8414844134036068, 0.31987295677179683`, 0.18735882716622465`],
              UndirectedEdge[217, 295] -> 
             RGBColor[
              0.19848052761044668`, 0.32594599728383544`, 0.9346145444705631],
              UndirectedEdge[45, 94] -> 
             RGBColor[
              0.5484117816822776, 0.636917841037437, 0.9603911500045271], 
             UndirectedEdge[197, 254] -> 
             RGBColor[
              0.6525617744919028, 0.7195772493628625, 0.9087750915707931], 
             UndirectedEdge[30, 189] -> 
             RGBColor[
              0.23256614809149867`, 0.36177214556258186`, 0.9365556701318023],
              UndirectedEdge[92, 179] -> 
             RGBColor[
              0.6771557268529196, 0.4334926321296493, 0.5667112930910556], 
             UndirectedEdge[134, 288] -> 
             RGBColor[
              0.22683219740980134`, 0.35574539984264686`, 0.9362291301230996],
              UndirectedEdge[59, 83] -> 
             RGBColor[
              0.9157801358545465, 0.6734487289604354, 0.5451685443334997], 
             UndirectedEdge[10, 22] -> 
             RGBColor[
              0.18947218593303478`, 0.31647765901902436`, 0.9341015327386817],
              UndirectedEdge[148, 168] -> 
             RGBColor[
              0.32335433659993124`, 0.4487211935569434, 0.9420362378816867], 
             UndirectedEdge[130, 216] -> 
             RGBColor[
              0.889133450052471, 0.5872803968126434, 0.22908968289478807`], 
             UndirectedEdge[158, 196] -> 
             RGBColor[
              0.1980026870183727, 0.32544375652472224`, 0.9345873321557463], 
             UndirectedEdge[203, 237] -> 
             RGBColor[
              0.8810998777201378, 0.5731845028928206, 0.5814799153304782], 
             UndirectedEdge[160, 193] -> 
             RGBColor[
              0.23766407621559904`, 0.36713039124832314`, 0.9368459895967611],
              UndirectedEdge[38, 88] -> 
             RGBColor[
              0.20448897001762012`, 0.33226125121102634`, 0.9349567163769577],
              UndirectedEdge[22, 73] -> 
             RGBColor[
              0.1856051226212358, 0.3124131302923484, 0.9338813092038822], 
             UndirectedEdge[181, 227] -> 
             RGBColor[
              0.9694992257478029, 0.9078122736758734, 0.34102909604815745`], 
             UndirectedEdge[85, 255] -> 
             RGBColor[
              0.2990831810082368, 0.42639058870879876`, 0.9405375990810403], 
             UndirectedEdge[106, 227] -> 
             RGBColor[
              0.907282547148933, 0.8714421765894653, 0.6337446762316135], 
             UndirectedEdge[131, 261] -> 
             RGBColor[
              0.23707213530482818`, 0.36650822381988146`, 0.9368122794375908],
              UndirectedEdge[81, 94] -> 
             RGBColor[
              0.8431768541892217, 0.7161112955984645, 0.6049346124449686], 
             UndirectedEdge[77, 154] -> 
             RGBColor[
              0.455540153481848, 0.5677935680255081, 0.950577540756124], 
             UndirectedEdge[167, 277] -> 
             RGBColor[
              0.9503466052484179, 0.8295784884211206, 0.3626330239957771], 
             UndirectedEdge[113, 176] -> 
             RGBColor[
              0.23091262265844142`, 0.3600341854928709, 0.9364615043045614], 
             UndirectedEdge[4, 276] -> 
             RGBColor[
              0.23095575836688206`, 0.36007952385740394`, 0.9364639608193436],
              UndirectedEdge[101, 243] -> 
             RGBColor[
              0.8173727655187092, 0.8567408344553589, 0.91183562312612], 
             UndirectedEdge[52, 271] -> 
             RGBColor[
              0.21068413741610115`, 0.3387727649431298, 0.9353095219953723], 
             UndirectedEdge[37, 71] -> 
             RGBColor[
              0.22494256325409756`, 0.3537592745352769, 0.9361215182533955], 
             UndirectedEdge[83, 291] -> 
             RGBColor[
              0.8867137047505624, 0.6516789960865967, 0.5925497284900865], 
             UndirectedEdge[80, 149] -> 
             RGBColor[
              0.9371561077922606, 0.7792834728078644, 0.30334662593416606`], 
             UndirectedEdge[104, 206] -> 
             RGBColor[
              0.2787552105581772, 0.4078842978745366, 0.9392752437947942], 
             UndirectedEdge[61, 108] -> 
             RGBColor[
              0.25897235282054676`, 0.38952674098289125`, 0.9380594644266425],
              UndirectedEdge[115, 264] -> 
             RGBColor[
              0.32396934415914475`, 0.453868652264371, 0.9419064562812274], 
             UndirectedEdge[38, 52] -> 
             RGBColor[
              0.19242626978916738`, 0.3195825884515542, 0.934269763444113], 
             UndirectedEdge[33, 285] -> 
             RGBColor[
              0.20009304762604624`, 0.3276408580599046, 0.934706375099942], 
             UndirectedEdge[100, 122] -> 
             RGBColor[
              0.18285159839459103`, 0.3095190017466254, 0.933724500072649], 
             UndirectedEdge[205, 269] -> 
             RGBColor[
              0.6727623053020111, 0.7090410207196602, 0.647599267278013], 
             UndirectedEdge[177, 252] -> 
             RGBColor[
              0.2649570005472917, 0.39581698519228203`, 0.9384002812611878], 
             UndirectedEdge[152, 244] -> 
             RGBColor[
              0.1860116480511821, 0.312840414294423, 0.9339044602257174], 
             UndirectedEdge[10, 71] -> 
             RGBColor[
              0.20685989156236995`, 0.3347532400796667, 0.9350917368514671], 
             UndirectedEdge[233, 259] -> 
             RGBColor[
              0.1952784533382303, 0.32258041420050104`, 0.9344321910778048], 
             UndirectedEdge[130, 299] -> 
             RGBColor[
              0.8652485405177199, 0.41636555627617133`, 0.20671378935182633`],
              UndirectedEdge[81, 86] -> 
             RGBColor[
              0.7418209808035544, 0.6361932312179576, 0.5953370394744854], 
             UndirectedEdge[205, 282] -> 
             RGBColor[
              0.40649592976024684`, 0.5265080761040026, 0.947122539087454], 
             UndirectedEdge[176, 297] -> 
             RGBColor[
              0.19309289409094996`, 0.3202832528591496, 0.9343077267119173], 
             UndirectedEdge[92, 128] -> 
             RGBColor[
              0.838247472010956, 0.29499240679111977`, 0.18425912843301978`], 
             UndirectedEdge[166, 285] -> 
             RGBColor[
              0.19288702957547718`, 0.3200668762008235, 0.9342960030323104], 
             UndirectedEdge[132, 146] -> 
             RGBColor[
              0.19846266788634026`, 0.3259272255814276, 0.9346135273856964], 
             UndirectedEdge[81, 130] -> 
             RGBColor[
              0.9006340382989853, 0.6395018820094367, 0.23868605563289352`], 
             UndirectedEdge[1, 128] -> 
             RGBColor[
              0.8318168299406954, 0.24556367391377373`, 0.17810113832416685`],
              UndirectedEdge[296, 297] -> 
             RGBColor[
              0.18960014391301738`, 0.31661215096899065`, 0.934108819756345], 
             UndirectedEdge[128, 237] -> 
             RGBColor[
              0.8350074590728989, 0.27008824756648975`, 0.18115648838446502`],
              UndirectedEdge[112, 146] -> 
             RGBColor[
              0.19463017997348525`, 0.32189903779124873`, 0.934395272868717], 
             UndirectedEdge[116, 287] -> 
             RGBColor[
              0.2651763885560936, 0.39604757589953593`, 0.9384127750837334], 
             UndirectedEdge[10, 266] -> 
             RGBColor[
              0.19427634422620857`, 0.3215271339863788, 0.9343751224463628], 
             UndirectedEdge[16, 76] -> 
             RGBColor[
              0.286854066125812, 0.4171520866149722, 0.9397088035477686], 
             UndirectedEdge[23, 72] -> 
             RGBColor[
              0.909381055653747, 0.6084841231487159, 0.5010093036534974], 
             UndirectedEdge[237, 277] -> 
             RGBColor[
              0.9090429254562429, 0.5906001950667261, 0.32616694372814004`], 
             UndirectedEdge[56, 278] -> 
             RGBColor[
              0.1999933373080916, 0.327536056193735, 0.9347006967448426], 
             UndirectedEdge[88, 274] -> 
             RGBColor[
              0.342952508633553, 0.4632649151839602, 0.9434373496862328], 
             UndirectedEdge[103, 282] -> 
             RGBColor[
              0.4309808924132613, 0.5477157201040381, 0.9486826992565017], 
             UndirectedEdge[46, 60] -> 
             RGBColor[
              0.2459880706675731, 0.3758794371890788, 0.9373200287665547], 
             UndirectedEdge[82, 216] -> 
             RGBColor[
              0.7399516836581952, 0.5917908620218015, 0.5864988772524447], 
             UndirectedEdge[48, 70] -> 
             RGBColor[
              0.2012898575043234, 0.328898781124103, 0.9347745316519882], 
             UndirectedEdge[143, 174] -> 
             RGBColor[
              0.27004966377854045`, 0.4011696971418227, 0.9386903008982872], 
             UndirectedEdge[95, 205] -> 
             RGBColor[
              0.32995805051825455`, 0.4582556876322203, 0.9423173462424312], 
             UndirectedEdge[78, 190] -> 
             RGBColor[
              0.19927294772660503`, 0.32677888106825503`, 0.9346596716238978],
              UndirectedEdge[68, 292] -> 
             RGBColor[
              0.8252860920096456, 0.8638987146846454, 0.9830984780135097], 
             UndirectedEdge[145, 269] -> 
             RGBColor[
              0.9190343803618738, 0.908127960055847, 0.6686138108252507], 
             UndirectedEdge[198, 254] -> 
             RGBColor[
              0.6416864490274542, 0.7118235947085315, 0.9431778757394982], 
             UndirectedEdge[124, 147] -> 
             RGBColor[
              0.19966110992932296`, 0.3271868641542167, 0.9346817768871081], 
             UndirectedEdge[44, 194] -> 
             RGBColor[
              0.5011124283287507, 0.6014735099165995, 0.9553542362124354], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.3434646997755016, 0.4661397793633797, 0.9433176524403382], 
             UndirectedEdge[5, 11] -> 
             RGBColor[
              0.7514137479791486, 0.7723356879656991, 0.6490878757769967], 
             UndirectedEdge[108, 254] -> 
             RGBColor[
              0.27973365180931276`, 0.4104203008650652, 0.9392757639847461], 
             UndirectedEdge[61, 71] -> 
             RGBColor[
              0.25028804221449197`, 0.3803989799188331, 0.9375649057849139], 
             UndirectedEdge[229, 284] -> 
             RGBColor[
              0.22933503139451644`, 0.3583760370494225, 0.936371662815918], 
             UndirectedEdge[37, 136] -> 
             RGBColor[
              0.309591888135542, 0.4349767741872242, 0.9412260952746828], 
             UndirectedEdge[148, 159] -> 
             RGBColor[
              0.26876902654338763`, 0.39982366621058674`, 0.9386173705022783],
              UndirectedEdge[164, 230] -> 
             RGBColor[
              0.1870233298629817, 0.313903756022956, 0.9339620740082502], 
             UndirectedEdge[176, 193] -> 
             RGBColor[
              0.23687819251132788`, 0.36630437764722934`, 0.9368012346824135],
              UndirectedEdge[216, 299] -> 
             RGBColor[
              0.8425788083187902, 0.31560991507508496`, 0.1879104981712836], 
             UndirectedEdge[149, 277] -> 
             RGBColor[
              0.9442574972371908, 0.8029244899485575, 0.3576036046538991], 
             UndirectedEdge[39, 248] -> 
             RGBColor[
              0.21184147363468755`, 0.3399891986882186, 0.9353754305808952], 
             UndirectedEdge[13, 137] -> 
             RGBColor[
              0.2974114508687985, 0.42765952627289927`, 0.9403315986701979], 
             UndirectedEdge[68, 75] -> 
             RGBColor[
              0.6048929892039929, 0.6837170469414527, 0.9652757515328931], 
             UndirectedEdge[66, 97] -> 
             RGBColor[
              0.4175999543798127, 0.5361258241249656, 0.9478300777173092], 
             UndirectedEdge[59, 106] -> 
             RGBColor[
              0.9234341463667425, 0.9403782883321993, 0.9424056010083017], 
             UndirectedEdge[51, 198] -> 
             RGBColor[
              0.8879439008384149, 0.9128115493875727, 0.9633242059952494], 
             UndirectedEdge[193, 228] -> 
             RGBColor[
              0.35291040472918833`, 0.4773968889253306, 0.9438069074260627], 
             UndirectedEdge[30, 287] -> 
             RGBColor[
              0.24614870075893425`, 0.37604826959963533`, 0.9373291764126268],
              UndirectedEdge[93, 147] -> 
             RGBColor[
              0.22726390844905786`, 0.3561991555169663, 0.936253715428126], 
             UndirectedEdge[69, 121] -> 
             RGBColor[
              0.21650915427912054`, 0.3448952269935637, 0.9356412480883811], 
             UndirectedEdge[148, 251] -> 
             RGBColor[
              0.26595227173522773`, 0.39686307831464074`, 0.9384569604829689],
              UndirectedEdge[125, 269] -> 
             RGBColor[
              0.904179684947735, 0.5963333758276583, 0.2657933486023245], 
             UndirectedEdge[37, 44] -> 
             RGBColor[
              0.27139379762507876`, 0.4018915080789134, 0.9387921467246012], 
             UndirectedEdge[91, 105] -> 
             RGBColor[
              0.38699951220692347`, 0.5063182366232937, 0.9462409477627431], 
             UndirectedEdge[81, 203] -> 
             RGBColor[
              0.9132949931047244, 0.7717981514907339, 0.6103970678254644], 
             UndirectedEdge[8, 69] -> 
             RGBColor[
              0.2060185451131012, 0.33386893161703934`, 0.9350438234158418], 
             UndirectedEdge[52, 270] -> 
             RGBColor[
              0.20578610160522076`, 0.3336246187524874, 0.9350305861019373], 
             UndirectedEdge[108, 268] -> 
             RGBColor[
              0.2228674989167732, 0.351578250350071, 0.9360033464091675], 
             UndirectedEdge[11, 254] -> 
             RGBColor[
              0.4252983225505378, 0.5406623913243694, 0.9489095154684506], 
             UndirectedEdge[82, 255] -> 
             RGBColor[
              0.489728760692208, 0.5942524926612631, 0.9536273379129792], 
             UndirectedEdge[43, 66] -> 
             RGBColor[
              0.3059641689064351, 0.4317438620573953, 0.9409982635304203], 
             UndirectedEdge[252, 283] -> 
             RGBColor[
              0.27188152915805053`, 0.4030951038026612, 0.9387946229216484], 
             UndirectedEdge[99, 215] -> 
             RGBColor[
              0.21020795705683448`, 0.338272269193962, 0.9352824042283578], 
             UndirectedEdge[114, 283] -> 
             RGBColor[
              0.2724764193926355, 0.4037203711574294, 0.9388285010404467], 
             UndirectedEdge[24, 194] -> 
             RGBColor[
              0.8048847779464043, 0.7450443793025796, 0.6134276095233945], 
             UndirectedEdge[134, 228] -> 
             RGBColor[
              0.3355280602689666, 0.4591269427933443, 0.9428170086239273], 
             UndirectedEdge[49, 143] -> 
             RGBColor[
              0.2582581828615999, 0.38877610307504745`, 0.9380187935040003], 
             UndirectedEdge[123, 189] -> 
             RGBColor[
              0.2072195140090381, 0.335131226072495, 0.935112216817791], 
             UndirectedEdge[232, 240] -> 
             RGBColor[
              0.184219115333836, 0.3109563487553536, 0.933802378139279], 
             UndirectedEdge[11, 243] -> 
             RGBColor[
              0.7596161582091865, 0.8099275378271904, 0.907236768390906], 
             UndirectedEdge[155, 210] -> 
             RGBColor[
              0.698996444284087, 0.6637676396684864, 0.6055600185754992], 
             UndirectedEdge[148, 156] -> 
             RGBColor[
              0.32039438822353183`, 0.44615743504463745`, 0.9418476325885221],
              UndirectedEdge[15, 212] -> 
             RGBColor[
              0.24587235329600743`, 0.3757578108946581, 0.9373134388334325], 
             UndirectedEdge[51, 204] -> 
             RGBColor[
              0.647452541380158, 0.7220822556308867, 0.967158350930859], 
             UndirectedEdge[95, 156] -> 
             RGBColor[
              0.3410239560220559, 0.4678404187910305, 0.9430224559559374], 
             UndirectedEdge[87, 109] -> 
             RGBColor[
              0.9929796059139886, 0.9895239708410322, 0.632193448669364], 
             UndirectedEdge[113, 288] -> 
             RGBColor[
              0.23824897201713657`, 0.3677451538202748, 0.9368792985473828], 
             UndirectedEdge[164, 176] -> 
             RGBColor[
              0.1880768897106564, 0.3150111142224146, 0.9340220726829731], 
             UndirectedEdge[17, 294] -> 
             RGBColor[
              0.6198562799736641, 0.7013271769000424, 0.963858572100545], 
             UndirectedEdge[77, 212] -> 
             RGBColor[
              0.32357566422601636`, 0.4477175574235364, 0.9420941078985701], 
             UndirectedEdge[180, 296] -> 
             RGBColor[
              0.19104587171588, 0.3181317025542363, 0.9341911518159554], 
             UndirectedEdge[217, 271] -> 
             RGBColor[
              0.21133673112817714`, 0.3394586823113528, 0.9353466862418491], 
             UndirectedEdge[4, 85] -> 
             RGBColor[
              0.2263430797542824, 0.3552313061748459, 0.9362012755962026], 
             UndirectedEdge[95, 127] -> 
             RGBColor[
              0.3181958172626126, 0.4480678323732162, 0.9415678671403162], 
             UndirectedEdge[54, 75] -> 
             RGBColor[
              0.2884831291269512, 0.41830852004459096`, 0.9398219273882558], 
             UndirectedEdge[134, 193] -> 
             RGBColor[
              0.26218140249464095`, 0.39289965565586527`, 0.9382422150582186],
              UndirectedEdge[40, 178] -> 
             RGBColor[
              0.4741224882012588, 0.573360769660643, 0.953860855337124], 
             UndirectedEdge[69, 239] -> 
             RGBColor[
              0.22257247692189291`, 0.35126816352797696`, 0.935986545343005], 
             UndirectedEdge[134, 200] -> 
             RGBColor[
              0.3051846864517926, 0.4328450374952205, 0.9408835556758889], 
             UndirectedEdge[89, 141] -> 
             RGBColor[
              0.33729605784908523`, 0.4651931821113565, 0.9427636193772146], 
             UndirectedEdge[38, 147] -> 
             RGBColor[
              0.1997586179230488, 0.3272893512379864, 0.9346873298231007], 
             UndirectedEdge[170, 182] -> 
             RGBColor[
              0.2259600378398488, 0.3548287048365162, 0.9361794619258352], 
             UndirectedEdge[94, 120] -> 
             RGBColor[
              0.5379895613183256, 0.6259634266279861, 0.9597976199730934], 
             UndirectedEdge[80, 269] -> 
             RGBColor[
              0.9759866531723878, 0.9306594839278095, 0.36121311142511225`], 
             UndirectedEdge[263, 286] -> 
             RGBColor[
              0.2153900069518347, 0.3437189321945473, 0.9355775143037223], 
             UndirectedEdge[130, 140] -> 
             RGBColor[
              0.8645610911257005, 0.4110815190068649, 0.2060554870376654], 
             UndirectedEdge[25, 288] -> 
             RGBColor[
              0.19999048340527747`, 0.32753305656092946`, 0.9347005342192993],
              UndirectedEdge[148, 191] -> 
             RGBColor[
              0.23683698231576478`, 0.36626106311881523`, 0.9367988878227413],
              UndirectedEdge[177, 268] -> 
             RGBColor[
              0.24851062539069607`, 0.37853080214228807`, 0.9374636845262513],
              UndirectedEdge[69, 126] -> 
             RGBColor[
              0.21552861209731056`, 0.34386461499051624`, 0.9355854076617092],
              UndirectedEdge[20, 37] -> 
             RGBColor[
              0.22278622542452461`, 0.3514928267566807, 0.9359987180040172], 
             UndirectedEdge[3, 72] -> 
             RGBColor[
              0.8918169128751087, 0.5962411896945986, 0.5690910592091327], 
             UndirectedEdge[87, 154] -> 
             RGBColor[
              0.7452228320173793, 0.7952601643437132, 0.7245769752264782], 
             UndirectedEdge[11, 204] -> 
             RGBColor[
              0.5077115751599948, 0.6112221547175201, 0.9543880614868259], 
             UndirectedEdge[55, 268] -> 
             RGBColor[
              0.20359322925377082`, 0.3313197708749761, 0.9349057052655861], 
             UndirectedEdge[125, 142] -> 
             RGBColor[
              0.8325650320679996, 0.2513146833284968, 0.1788176175262468], 
             UndirectedEdge[176, 221] -> 
             RGBColor[
              0.1901941228796547, 0.3172364605233681, 0.9341426459797817], 
             UndirectedEdge[29, 182] -> 
             RGBColor[
              0.224799401299116, 0.35360880224359903`, 0.9361133653918483], 
             UndirectedEdge[122, 161] -> 
             RGBColor[
              0.19334750398760153`, 0.32055086400373023`, 0.9343222263688701],
              UndirectedEdge[44, 226] -> 
             RGBColor[
              0.6512382253914439, 0.7184499980919314, 0.9093942676022314], 
             UndirectedEdge[89, 131] -> 
             RGBColor[
              0.3050760854207314, 0.4313279482249144, 0.9409287396125976], 
             UndirectedEdge[56, 110] -> 
             RGBColor[
              0.1926369557700678, 0.31980403277574326`, 0.9342817616990433], 
             UndirectedEdge[43, 178] -> 
             RGBColor[
              0.24229896140308743`, 0.37200194944906734`, 0.9371099394514903],
              UndirectedEdge[66, 162] -> 
             RGBColor[
              0.6888450125107997, 0.7498709206605213, 0.8694416515926326], 
             UndirectedEdge[5, 142] -> 
             RGBColor[
              0.9004741399785186, 0.5724923933279508, 0.25909492907778175`], 
             UndirectedEdge[147, 273] -> 
             RGBColor[
              0.22616395243467474`, 0.35504303200461024`, 0.9361910745603459],
              UndirectedEdge[81, 167] -> 
             RGBColor[
              0.8985734587541578, 0.6313323707616247, 0.23702806496310708`], 
             UndirectedEdge[95, 212] -> 
             RGBColor[
              0.2604625119164363, 0.3910929926742148, 0.9381443267826606], 
             UndirectedEdge[56, 217] -> 
             RGBColor[
              0.19969746831988144`, 0.32722507912794885`, 0.934683847443663], 
             UndirectedEdge[6, 93] -> 
             RGBColor[
              0.2258625386311459, 0.35472622698636247`, 0.9361739094901367], 
             UndirectedEdge[131, 146] -> 
             RGBColor[
              0.2147184255833614, 0.3430130575955638, 0.9355392687383033], 
             UndirectedEdge[7, 80] -> 
             RGBColor[
              0.9585640473109542, 0.9468487152511682, 0.6807339798518178], 
             UndirectedEdge[76, 239] -> 
             RGBColor[
              0.28224692267200363`, 0.41230968673525326`, 0.9394464335437323],
              UndirectedEdge[148, 278] -> 
             RGBColor[
              0.2234636176615972, 0.35220480894699246`, 0.9360372944898065], 
             UndirectedEdge[29, 170] -> 
             RGBColor[
              0.19641582947302122`, 0.3237758686319784, 0.934496962966084], 
             UndirectedEdge[147, 289] -> 
             RGBColor[
              0.22842117185433053`, 0.35741551273064565`, 0.9363196198670385],
              UndirectedEdge[25, 28] -> 
             RGBColor[
              0.18729283765525817`, 0.3141870258004196, 0.9339774220783192], 
             UndirectedEdge[5, 149] -> 
             RGBColor[
              0.933258247478127, 0.766135074707167, 0.2882041746629133], 
             UndirectedEdge[140, 202] -> 
             RGBColor[
              0.8419448678170631, 0.3105688491792778, 0.18729684498680563`], 
             UndirectedEdge[10, 63] -> 
             RGBColor[
              0.18664280478053893`, 0.31350380003462497`, 0.9339404036677414],
              UndirectedEdge[43, 259] -> 
             RGBColor[
              0.20537394232393572`, 0.33319141321544904`, 0.9350071142406031],
              UndirectedEdge[21, 50] -> 
             RGBColor[
              0.18770061499905671`, 0.31461562564332873`, 0.9340006443947961],
              UndirectedEdge[87, 155] -> 
             RGBColor[
              0.959730943798982, 0.866659323879206, 0.37757715104669176`], 
             UndirectedEdge[127, 282] -> 
             RGBColor[
              0.3947336965046049, 0.5163202208449985, 0.9463730599853389], 
             UndirectedEdge[79, 144] -> 
             RGBColor[
              0.1903903758627761, 0.31744273485178653`, 0.9341538222968402], 
             UndirectedEdge[54, 298] -> 
             RGBColor[
              0.25208733908179476`, 0.3822901550083788, 0.9376673730796856], 
             UndirectedEdge[234, 263] -> 
             RGBColor[
              0.20202221841831886`, 0.32966853887907605`, 0.9348162385226094],
              UndirectedEdge[34, 38] -> 
             RGBColor[
              0.18490621443215238`, 0.31167853347228314`, 0.9338415074164561],
              UndirectedEdge[39, 85] -> 
             RGBColor[
              0.21693635514660192`, 0.345344242191386, 0.9356655765457971], 
             UndirectedEdge[20, 108] -> 
             RGBColor[
              0.2298448182232575, 0.3589118553287811, 0.9364006944216527], 
             UndirectedEdge[94, 201] -> 
             RGBColor[
              0.8211264532079356, 0.595474367346517, 0.5857320499193991], 
             UndirectedEdge[260, 294] -> 
             RGBColor[
              0.39710848893487455`, 0.5114544721894022, 0.9473162764842546], 
             UndirectedEdge[138, 266] -> 
             RGBColor[
              0.21471877848996196`, 0.3430134285227765, 0.935539288835812], 
             UndirectedEdge[127, 168] -> 
             RGBColor[
              0.3746233333290345, 0.4989016350385623, 0.9450916454266876], 
             UndirectedEdge[128, 198] -> 
             RGBColor[
              0.9047656578317846, 0.6597743590910152, 0.567745210695355], 
             UndirectedEdge[145, 216] -> 
             RGBColor[
              0.8656837903388712, 0.6908198174551905, 0.5986314441654264], 
             UndirectedEdge[141, 182] -> 
             RGBColor[
              0.2740956905180802, 0.4054223277779909, 0.9389207161355438], 
             UndirectedEdge[41, 252] -> 
             RGBColor[
              0.21326847287064163`, 0.3414890653621836, 0.9354566960763266], 
             UndirectedEdge[55, 208] -> 
             RGBColor[
              0.19572673330134732`, 0.32305158486432833`, 0.9344577199585336],
              UndirectedEdge[121, 249] -> 
             RGBColor[
              0.21645306950395798`, 0.3448362783388877, 0.9356380541434055], 
             UndirectedEdge[89, 120] -> 
             RGBColor[
              0.3299173264663655, 0.4574376675895273, 0.9423434115408236], 
             UndirectedEdge[32, 142] -> 
             RGBColor[
              0.9088058774056695, 0.6101377233090057, 0.5151005353474709], 
             UndirectedEdge[7, 77] -> 
             RGBColor[
              0.6760511895639363, 0.7431695037981105, 0.9684398535409274], 
             UndirectedEdge[45, 146] -> 
             RGBColor[
              0.24998188699294738`, 0.3800771913696276, 0.937547470697963], 
             UndirectedEdge[110, 223] -> 
             RGBColor[
              0.18370379552866184`, 0.31041471496695283`, 0.9337730314387216],
              UndirectedEdge[225, 276] -> 
             RGBColor[
              0.23448523874767882`, 0.3637892315196025, 0.9366649595056316], 
             UndirectedEdge[65, 291] -> 
             RGBColor[
              0.6521691058057041, 0.7229451944590042, 0.9690799766899112], 
             UndirectedEdge[194, 290] -> 
             RGBColor[
              0.8162082398567924, 0.7899381324572718, 0.622538732772305], 
             UndirectedEdge[154, 258] -> 
             RGBColor[
              0.4187295668061743, 0.5359100880009214, 0.9482320027234739], 
             UndirectedEdge[31, 280] -> 
             RGBColor[
              0.3408307300134504, 0.46531138731317084`, 0.9430966160299905], 
             UndirectedEdge[156, 271] -> 
             RGBColor[
              0.3085633706783219, 0.433722285474784, 0.9411738736417443], 
             UndirectedEdge[83, 241] -> 
             RGBColor[
              0.9163383963463205, 0.6736795840204242, 0.5359167232529631], 
             UndirectedEdge[208, 268] -> 
             RGBColor[
              0.19718303522223768`, 0.3245822505180589, 0.9345406541985226], 
             UndirectedEdge[1, 80] -> 
             RGBColor[
              0.8987509068791093, 0.542434604273317, 0.26885461494810886`], 
             UndirectedEdge[116, 206] -> 
             RGBColor[
              0.2548872111619892, 0.3852329980868062, 0.9378268216526131], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.22364840280037163`, 0.35239902984389887`, 0.9360478177300946],
              UndirectedEdge[108, 204] -> 
             RGBColor[
              0.36214690441876973`, 0.48098006425821577`, 0.9447543100031214],
              UndirectedEdge[251, 271] -> 
             RGBColor[
              0.25412125419001774`, 0.38442792874478726`, 0.9377832015361911],
              UndirectedEdge[6, 38] -> 
             RGBColor[
              0.19835724810513683`, 0.32581642270738265`, 0.9346075238851115],
              UndirectedEdge[135, 158] -> 
             RGBColor[
              0.20301108119461975`, 0.33070789635448955`, 0.9348725527948284],
              UndirectedEdge[25, 180] -> 
             RGBColor[
              0.1930001178726018, 0.32018573917131365`, 0.9343024432435325], 
             UndirectedEdge[57, 217] -> 
             RGBColor[
              0.18985695379830947`, 0.3168820744411198, 0.9341234446993961], 
             UndirectedEdge[71, 136] -> 
             RGBColor[
              0.3079661703282201, 0.43326804169526645`, 0.9411335130505898], 
             UndirectedEdge[135, 173] -> 
             RGBColor[
              0.20718172638991203`, 0.3350915088889201, 0.9351100648687836], 
             UndirectedEdge[143, 235] -> 
             RGBColor[
              0.3576942027971, 0.4840672946486393, 0.9440192038790169], 
             UndirectedEdge[264, 288] -> 
             RGBColor[
              0.2525376443502292, 0.38276345439650644`, 0.937693017298556], 
             UndirectedEdge[223, 247] -> 
             RGBColor[
              0.18962339324408597`, 0.3166365874900364, 0.934110143771355], 
             UndirectedEdge[191, 225] -> 
             RGBColor[
              0.22748667103589795`, 0.35643329311969896`, 0.9362664014278987],
              UndirectedEdge[1, 243] -> 
             RGBColor[
              0.9030554567950135, 0.5668780560341109, 0.5118610562907654], 
             UndirectedEdge[29, 284] -> 
             RGBColor[
              0.21810645410068208`, 0.3465740903806829, 0.9357322119502256], 
             UndirectedEdge[6, 273] -> 
             RGBColor[
              0.22476258261676274`, 0.3535701034740064, 0.9361112686223567], 
             UndirectedEdge[103, 276] -> 
             RGBColor[
              0.33135174266530537`, 0.4551929422593771, 0.9425624927166377], 
             UndirectedEdge[99, 199] -> 
             RGBColor[
              0.19703448061371565`, 0.32442611020559603`, 0.9345321942333341],
              UndirectedEdge[35, 129] -> 
             RGBColor[
              0.19774057513237292`, 0.32516826031368307`, 0.9345724052715985],
              UndirectedEdge[77, 145] -> 
             RGBColor[
              0.6393432778876973, 0.7139671917177287, 0.9672816709055783], 
             UndirectedEdge[72, 155] -> 
             RGBColor[
              0.8778646469488878, 0.4863358074888676, 0.21768508409656526`], 
             UndirectedEdge[20, 44] -> 
             RGBColor[
              0.26761174198818394`, 0.3979163278083595, 0.93857676425113], 
             UndirectedEdge[131, 178] -> 
             RGBColor[
              0.2442095797785655, 0.3740101305018966, 0.9372187463414672], 
             UndirectedEdge[106, 241] -> 
             RGBColor[
              0.9239924068585166, 0.940609143392188, 0.9331537799277652], 
             UndirectedEdge[85, 286] -> 
             RGBColor[
              0.2265196157319883, 0.3554168566804423, 0.9362113290589713], 
             UndirectedEdge[86, 261] -> 
             RGBColor[
              0.41945675567834323`, 0.5279913173677868, 0.949221846121721], 
             UndirectedEdge[256, 269] -> 
             RGBColor[
              0.8955465010984967, 0.5299749416771264, 0.25752620199850723`], 
             UndirectedEdge[37, 61] -> 
             RGBColor[
              0.25191376002181387`, 0.38210771241079083`, 0.937657488009007], 
             UndirectedEdge[73, 244] -> 
             RGBColor[
              0.18608629156364545`, 0.31291886935869395`, 0.9339087110633268],
              UndirectedEdge[180, 193] -> 
             RGBColor[
              0.23722417633734735`, 0.3666680285850174, 0.9368209379494682], 
             UndirectedEdge[8, 213] -> 
             RGBColor[
              0.20342164602247398`, 0.3311394260198779, 0.9348959338543985], 
             UndirectedEdge[48, 138] -> 
             RGBColor[
              0.21204884540564534`, 0.34020715956762493`, 0.9353872400964722],
              UndirectedEdge[170, 284] -> 
             RGBColor[
              0.2192670906414149, 0.34779399297360003`, 0.9357983084842125], 
             UndirectedEdge[55, 219] -> 
             RGBColor[
              0.19323553565117518`, 0.3204331781829436, 0.9343158499377529], 
             UndirectedEdge[111, 235] -> 
             RGBColor[
              0.5113487817124779, 0.61295792200517, 0.9550106787741928], 
             UndirectedEdge[56, 247] -> 
             RGBColor[
              0.19855655348549195`, 0.3260259052988269, 0.9346188740316768], 
             UndirectedEdge[7, 82] -> 
             RGBColor[
              0.7758796678197641, 0.8252882359458167, 0.9760021123389747], 
             UndirectedEdge[182, 190] -> 
             RGBColor[
              0.22937905061187158`, 0.35842230403784237`, 0.9363741696452258],
              UndirectedEdge[113, 228] -> 
             RGBColor[
              0.34694483487630184`, 0.4711266967709722, 0.9434671770482106], 
             UndirectedEdge[133, 146] -> 
             RGBColor[
              0.19265917133132254`, 0.3198273827391699, 0.9342830268423918], 
             UndirectedEdge[93, 274] -> 
             RGBColor[
              0.3520883115326398, 0.4728672232742597, 0.9439576201461266], 
             UndirectedEdge[153, 220] -> 
             RGBColor[
              0.27707930337293885`, 0.40630757672797435`, 0.9391730382607208],
              UndirectedEdge[90, 153] -> 
             RGBColor[
              0.21837262298903565`, 0.3468538507584247, 0.9357473698746558], 
             UndirectedEdge[178, 190] -> 
             RGBColor[
              0.23171291230071078`, 0.36087534064819005`, 0.9365070796157662],
              UndirectedEdge[39, 126] -> 
             RGBColor[
              0.21260629074350712`, 0.3407930699617935, 0.9354189857837971], 
             UndirectedEdge[15, 77] -> 
             RGBColor[
              0.3360793820211845, 0.46085975760775527`, 0.942806176129412], 
             UndirectedEdge[103, 293] -> 
             RGBColor[
              0.6605442022439556, 0.5885330418914387, 0.5930681631412746], 
             UndirectedEdge[92, 269] -> 
             RGBColor[
              0.9023597936765284, 0.5823448940357236, 0.2640506186657438], 
             UndirectedEdge[8, 14] -> 
             RGBColor[
              0.19233103918746458`, 0.31948249505119564`, 0.9342643402022272],
              UndirectedEdge[157, 171] -> 
             RGBColor[
              0.1808430925709541, 0.30740793477935857`, 0.9336101186373109], 
             UndirectedEdge[198, 226] -> 
             RGBColor[
              0.975424098844659, 0.9808488194558194, 0.9111203095275062], 
             UndirectedEdge[86, 169] -> 
             RGBColor[
              0.5994580148931581, 0.6857060476229113, 0.9616106773009028], 
             UndirectedEdge[163, 235] -> 
             RGBColor[
              0.5148221170934733, 0.615777732139438, 0.9552841124586315], 
             UndirectedEdge[31, 136] -> 
             RGBColor[
              0.4061320211140046, 0.526192876725208, 0.9470993511503072], 
             UndirectedEdge[111, 292] -> 
             RGBColor[
              0.6939596467687601, 0.7604145144003427, 0.9704259544749405], 
             UndirectedEdge[48, 122] -> 
             RGBColor[
              0.1889251216320018, 0.3159026597527588, 0.9340703782360471], 
             UndirectedEdge[246, 295] -> 
             RGBColor[
              0.19068631113650653`, 0.3177537815878572, 0.9341706753728822], 
             UndirectedEdge[258, 263] -> 
             RGBColor[
              0.2750253960672227, 0.40349492782139373`, 0.9390800123727585], 
             UndirectedEdge[24, 299] -> 
             RGBColor[
              0.871228956104042, 0.44007591122058254`, 0.21152577211097698`], 
             UndirectedEdge[66, 193] -> 
             RGBColor[
              0.33295274750258996`, 0.46011056933666983`, 0.9425352231554471],
              UndirectedEdge[29, 199] -> 
             RGBColor[
              0.196824977685108, 0.32420590934437654`, 0.9345202633514818], 
             UndirectedEdge[27, 87] -> 
             RGBColor[
              0.9814947768371431, 0.9488415742094825, 0.4164630400439475], 
             UndirectedEdge[164, 180] -> 
             RGBColor[
              0.18842287353667586`, 0.3153747651602027, 0.9340417759500277], 
             UndirectedEdge[106, 200] -> 
             RGBColor[
              0.6137154608562325, 0.6918743175265988, 0.9656005116200483], 
             UndirectedEdge[69, 285] -> 
             RGBColor[
              0.2036242652013759, 0.3313523916237017, 0.9349074727168887], 
             UndirectedEdge[88, 137] -> 
             RGBColor[
              0.242196310039882, 0.3718940563578661, 0.9371040936082149], 
             UndirectedEdge[43, 261] -> 
             RGBColor[
              0.23516151692935008`, 0.3645000427670523, 0.9367034725476139], 
             UndirectedEdge[224, 253] -> 
             RGBColor[
              0.20025883236896588`, 0.32781510833607297`, 0.9347158162957947],
              UndirectedEdge[5, 23] -> 
             RGBColor[
              0.9801796714011944, 0.9518718565732095, 0.5840536111729073], 
             UndirectedEdge[42, 162] -> 
             RGBColor[
              0.914476505697249, 0.6403711742389498, 0.48834430646392846`], 
             UndirectedEdge[29, 131] -> 
             RGBColor[
              0.21233150972289871`, 0.34050425768701104`, 0.9354033374111754],
              UndirectedEdge[12, 192] -> 
             RGBColor[
              0.3801187118441842, 0.5036614557026298, 0.9454418060863005], 
             UndirectedEdge[69, 76] -> 
             RGBColor[
              0.2672433086560147, 0.39653993712037666`, 0.9385919999213795], 
             UndirectedEdge[176, 180] -> 
             RGBColor[
              0.1945386218938126, 0.32180280444439524`, 0.9343900587715277], 
             UndirectedEdge[101, 116] -> 
             RGBColor[
              0.46733992011891123`, 0.5718860980228273, 0.952579449352897], 
             UndirectedEdge[125, 293] -> 
             RGBColor[
              0.8674766192366652, 0.4546177529994014, 0.20970208429653842`], 
             UndirectedEdge[30, 300] -> 
             RGBColor[
              0.23747118318928384`, 0.36692764844754155`, 0.936835004624272], 
             UndirectedEdge[155, 290] -> 
             RGBColor[
              0.9363623874102649, 0.7854051025986525, 0.2676538870247894], 
             UndirectedEdge[217, 246] -> 
             RGBColor[
              0.1922440281378487, 0.31939104092123016`, 0.9342593850516728], 
             UndirectedEdge[42, 82] -> 
             RGBColor[
              0.7255221919430327, 0.49355450623719554`, 0.5731775024918879], 
             UndirectedEdge[122, 138] -> 
             RGBColor[
              0.2081640824318275, 0.3361240273739437, 0.9351660085921052], 
             UndirectedEdge[58, 160] -> 
             RGBColor[
              0.19345266111115197`, 0.32066139080792844`, 0.9343282149114902],
              UndirectedEdge[158, 225] -> 
             RGBColor[
              0.21027114178594725`, 0.3383386803504027, 0.9352860025052073], 
             UndirectedEdge[197, 204] -> 
             RGBColor[
              0.7349750271013598, 0.7901370127560131, 0.9142536375891683], 
             UndirectedEdge[40, 182] -> 
             RGBColor[
              0.47178862651241965`, 0.5709077330502953, 0.9537279453665835], 
             UndirectedEdge[1, 149] -> 
             RGBColor[
              0.8570986062261408, 0.38154015003843245`, 0.20002614306594468`],
              UndirectedEdge[32, 156] -> 
             RGBColor[
              0.691083843191671, 0.7526411268737674, 0.9001295183811735], 
             UndirectedEdge[258, 286] -> 
             RGBColor[
              0.28052613048445796`, 0.4092765484606139, 0.9393932710602128], 
             UndirectedEdge[101, 197] -> 
             RGBColor[
              0.816834867392223, 0.8565183997567056, 0.9207499871177253], 
             UndirectedEdge[53, 271] -> 
             RGBColor[
              0.21925630560640996`, 0.3477826572179991, 0.935797694292424], 
             UndirectedEdge[22, 70] -> 
             RGBColor[
              0.19915563229546623`, 0.32665557511190024`, 0.9346529906836472],
              UndirectedEdge[76, 258] -> 
             RGBColor[
              0.3335396370029857, 0.4633170022075566, 0.942473828625678], 
             UndirectedEdge[232, 297] -> 
             RGBColor[
              0.18995045311417683`, 0.3169803481502954, 0.934128769347115], 
             UndirectedEdge[178, 261] -> 
             RGBColor[
              0.2518738885698846, 0.38206580498681714`, 0.9376552173888041], 
             UndirectedEdge[155, 227] -> 
             RGBColor[
              0.9395091625151377, 0.7978810172888317, 0.27018585613847523`], 
             UndirectedEdge[178, 182] -> 
             RGBColor[
              0.2566774713547828, 0.3871146750584845, 0.9379287743221401], 
             UndirectedEdge[5, 51] -> 
             RGBColor[
              0.8911547141993119, 0.8831957888790658, 0.6618581652210298], 
             UndirectedEdge[110, 295] -> 
             RGBColor[
              0.19142001506063305`, 0.31852495093162986`, 0.9342124587259435],
              UndirectedEdge[186, 286] -> 
             RGBColor[
              0.2070033670926693, 0.3349040419588854, 0.9350999075706646], 
             UndirectedEdge[34, 270] -> 
             RGBColor[
              0.19826604624820576`, 0.32572056377321634`, 0.9346023300742803],
              UndirectedEdge[4, 8] -> 
             RGBColor[
              0.21250294836697825`, 0.34068445057177643`, 0.935413100588335], 
             UndirectedEdge[69, 166] -> 
             RGBColor[
              0.19683162728000528`, 0.3242128984902222, 0.9345206420360739], 
             UndirectedEdge[25, 176] -> 
             RGBColor[
              0.19265413404658233`, 0.31982208823352565`, 0.9342827399764779],
              UndirectedEdge[32, 149] -> 
             RGBColor[
              0.9415899849052779, 0.803780404688222, 0.5442097809326024], 
             UndirectedEdge[16, 153] -> 
             RGBColor[
              0.233929772423327, 0.36320540119410966`, 0.9366333265201985], 
             UndirectedEdge[169, 299] -> 
             RGBColor[
              0.7117164306549081, 0.41734421667683197`, 0.5637805087358065], 
             UndirectedEdge[187, 229] -> 
             RGBColor[
              0.22122626051320093`, 0.3498532047273915, 0.9359098803100787], 
             UndirectedEdge[15, 82] -> 
             RGBColor[
              0.43590786027701234`, 0.5429784897554615, 0.9503684349274593], 
             UndirectedEdge[44, 280] -> 
             RGBColor[
              0.2891161135986471, 0.42051878582686586`, 0.939801406401479], 
             UndirectedEdge[186, 265] -> 
             RGBColor[
              0.2079159163966799, 0.33586318913636815`, 0.9351518759035322], 
             UndirectedEdge[117, 265] -> 
             RGBColor[
              0.2041128319271811, 0.33186590622944256`, 0.9349352958691536], 
             UndirectedEdge[106, 162] -> 
             RGBColor[
              0.9266044419072905, 0.9416892870110949, 0.8898655994395634], 
             UndirectedEdge[9, 146] -> 
             RGBColor[
              0.1994945649800457, 0.3270118148529666, 0.9346722923986279], 
             UndirectedEdge[130, 294] -> 
             RGBColor[
              0.723926300807685, 0.6611320656306849, 0.6022559472314186], 
             UndirectedEdge[13, 53] -> 
             RGBColor[
              0.27458306643531494`, 0.40366544683013694`, 0.9390315559482794],
              UndirectedEdge[34, 57] -> 
             RGBColor[
              0.18168430472921848`, 0.3082921020936258, 0.9336580244252622], 
             UndirectedEdge[25, 144] -> 
             RGBColor[
              0.19437777007737006`, 0.3216337389867199, 0.9343808984985402], 
             UndirectedEdge[206, 283] -> 
             RGBColor[
              0.26412169083739256`, 0.3949390217254835, 0.938352711608939], 
             UndirectedEdge[107, 273] -> 
             RGBColor[
              0.32370272298268776`, 0.4483418094779742, 0.9420833765839904], 
             UndirectedEdge[64, 85] -> 
             RGBColor[
              0.2337265149567007, 0.3629917647094177, 0.9366217513081667], 
             UndirectedEdge[175, 224] -> 
             RGBColor[
              0.19563816085584113`, 0.3229584896082839, 0.9344526758887932], 
             UndirectedEdge[68, 163] -> 
             RGBColor[
              0.7490034970690254, 0.8039812828492927, 0.9757174701655251], 
             UndirectedEdge[7, 237] -> 
             RGBColor[
              0.8816971748770377, 0.5736299661344524, 0.5804688470438946], 
             UndirectedEdge[76, 126] -> 
             RGBColor[
              0.2752030578474213, 0.40490613819779253`, 0.9390452958624365], 
             UndirectedEdge[30, 236] -> 
             RGBColor[
              0.2403636886171835, 0.3699678550477007, 0.9369997285293126], 
             UndirectedEdge[7, 269] -> 
             RGBColor[
              0.9557422920381128, 0.9373302721362289, 0.6697719934605999], 
             UndirectedEdge[237, 256] -> 
             RGBColor[
              0.8215013839374217, 0.16627463567534986`, 0.16822305558180195`],
              UndirectedEdge[106, 290] -> 
             RGBColor[
              0.9041357720440601, 0.8589662618992862, 0.6312127071179277], 
             UndirectedEdge[180, 288] -> 
             RGBColor[
              0.20187497125250775`, 0.32951377277179905`, 0.9348078530143491],
              UndirectedEdge[201, 237] -> 
             RGBColor[
              0.8352193779806968, 0.2717171491552828, 0.18135942216990056`], 
             UndirectedEdge[10, 73] -> 
             RGBColor[
              0.18653587436616526`, 0.31339140938933835`, 0.9339343141388322],
              UndirectedEdge[18, 175] -> 
             RGBColor[
              0.19129167307218187`, 0.3183900553644156, 0.9342051498395663], 
             UndirectedEdge[57, 295] -> 
             RGBColor[
              0.1882992367969673, 0.3152448151077469, 0.9340347350206055], 
             UndirectedEdge[71, 161] -> 
             RGBColor[
              0.2124857473818974, 0.34066637124585103`, 0.9354121210176813], 
             UndirectedEdge[218, 220] -> 
             RGBColor[
              0.6501395047208716, 0.7189888396444919, 0.9414344110066938], 
             UndirectedEdge[192, 248] -> 
             RGBColor[
              0.27628801069729353`, 0.4057044446902951, 0.9391196063656152], 
             UndirectedEdge[23, 24] -> 
             RGBColor[
              0.956555334204736, 0.8626596651038085, 0.541866983332811], 
             UndirectedEdge[39, 195] -> 
             RGBColor[
              0.1927241486561343, 0.3198956780273474, 0.9342867272049146], 
             UndirectedEdge[79, 232] -> 
             RGBColor[
              0.1855242988552152, 0.31232817938973806`, 0.9338767064099756], 
             UndirectedEdge[12, 154] -> 
             RGBColor[
              0.46345887168868094`, 0.5746523637299171, 0.9510821144780158], 
             UndirectedEdge[106, 155] -> 
             RGBColor[
              0.8940872222095038, 0.8191271102860018, 0.6231274080512639], 
             UndirectedEdge[95, 103] -> 
             RGBColor[
              0.35444301317126903`, 0.47946333163225574`, 0.9438775064114789],
              UndirectedEdge[3, 228] -> 
             RGBColor[
              0.690237715965832, 0.7545004457298199, 0.955381119587516], 
             UndirectedEdge[81, 293] -> 
             RGBColor[
              0.8946118304119881, 0.61433876058075, 0.23377386680638917`], 
             UndirectedEdge[95, 145] -> 
             RGBColor[
              0.5762301255781173, 0.6573426269684071, 0.963331889789669], 
             UndirectedEdge[39, 153] -> 
             RGBColor[
              0.2113966935997263, 0.3395217066707913, 0.9353501010158973], 
             UndirectedEdge[39, 90] -> 
             RGBColor[
              0.20870014958760652`, 0.3366874679432882, 0.9351965368235865], 
             UndirectedEdge[120, 141] -> 
             RGBColor[
              0.28646903998749706`, 0.4184275025860159, 0.939625360083097], 
             UndirectedEdge[102, 172] -> 
             RGBColor[
              0.19138970866876043`, 0.3184930969922355, 0.9342107328217606], 
             UndirectedEdge[155, 194] -> 
             RGBColor[
              0.8061596900222359, 0.7500989808439875, 0.6144534337056413], 
             UndirectedEdge[53, 251] -> 
             RGBColor[
              0.25074234215186236`, 0.3808764779572891, 0.9375907774942707], 
             UndirectedEdge[128, 243] -> 
             RGBColor[
              0.9161788814227196, 0.6677504484439996, 0.5244280625350448], 
             UndirectedEdge[72, 87] -> 
             RGBColor[
              0.9112817531721615, 0.6074291803827055, 0.3356936471851313], 
             UndirectedEdge[76, 90] -> 
             RGBColor[
              0.2712969166915207, 0.40080053617928724`, 0.938822846902226], 
             UndirectedEdge[3, 106] -> 
             RGBColor[
              0.9080394881357245, 0.9290324924917327, 0.9745333831638314], 
             UndirectedEdge[104, 243] -> 
             RGBColor[
              0.6612526622734278, 0.7268613939195354, 0.9003802288706013], 
             UndirectedEdge[34, 217] -> 
             RGBColor[
              0.1918655955426979, 0.3189932842697143, 0.9342378338752199], 
             UndirectedEdge[31, 37] -> 
             RGBColor[
              0.32310841403988205`, 0.4466841095652183, 0.9420873563531128], 
             UndirectedEdge[64, 249] -> 
             RGBColor[
              0.22138061658703678`, 0.35001544274773333`, 0.9359186706601341],
              UndirectedEdge[89, 188] -> 
             RGBColor[
              0.3683043792841372, 0.49342847464473716`, 0.9446890072625783], 
             UndirectedEdge[179, 269] -> 
             RGBColor[
              0.7479608310759376, 0.7722887789067958, 0.6529117994592061], 
             UndirectedEdge[213, 249] -> 
             RGBColor[
              0.2049158790401142, 0.33270995966126304`, 0.9349810282142335], 
             UndirectedEdge[44, 252] -> 
             RGBColor[
              0.27708079783829526`, 0.4078689058796433, 0.9391160129735812], 
             UndirectedEdge[149, 198] -> 
             RGBColor[
              0.93004743411723, 0.7957508352156739, 0.5896702154371328], 
             UndirectedEdge[158, 214] -> 
             RGBColor[
              0.19688801935015837`, 0.3242721701314169, 0.9345238534810445], 
             UndirectedEdge[202, 216] -> 
             RGBColor[
              0.8665172267438337, 0.4867677269850564, 0.21033104084392829`], 
             UndirectedEdge[78, 209] -> 
             RGBColor[
              0.18729352981200414`, 0.31418775330104487`, 0.933977461495622], 
             UndirectedEdge[77, 265] -> 
             RGBColor[
              0.31824926646414226`, 0.4421191756626833, 0.9417907774257306], 
             UndirectedEdge[44, 204] -> 
             RGBColor[
              0.39991382818369614`, 0.5199845367377941, 0.9469303798325985], 
             UndirectedEdge[54, 102] -> 
             RGBColor[
              0.218116116310074, 0.34658424597537324`, 0.9357327621987566], 
             UndirectedEdge[2, 253] -> 
             RGBColor[
              0.19522054856906235`, 0.32251955261673115`, 0.9344288934868631],
              UndirectedEdge[40, 86] -> 
             RGBColor[
              0.6417053553097174, 0.7192862820416126, 0.9654274840700409], 
             UndirectedEdge[75, 165] -> 
             RGBColor[
              0.27536181000482485`, 0.4045171817075533, 0.9390746876755028], 
             UndirectedEdge[73, 100] -> 
             RGBColor[
              0.1816658245926822, 0.30827267829841776`, 0.9336569720088254], 
             UndirectedEdge[50, 206] -> 
             RGBColor[
              0.20212300857950383`, 0.32977447572894675`, 0.9348219783731833],
              UndirectedEdge[32, 277] -> 
             RGBColor[
              0.9903436750031767, 0.9883158760637997, 0.6672952315344995], 
             UndirectedEdge[156, 251] -> 
             RGBColor[
              0.3400494072237743, 0.46681610621407393`, 0.942966956843591], 
             UndirectedEdge[31, 44] -> 
             RGBColor[
              0.36793393060354135`, 0.4931076106168971, 0.9446654026002257], 
             UndirectedEdge[80, 92] -> 
             RGBColor[
              0.9051815489493698, 0.591863337150663, 0.2750126050569618], 
             UndirectedEdge[11, 149] -> 
             RGBColor[
              0.7136593076403137, 0.6245896318315118, 0.5954018551660852], 
             UndirectedEdge[103, 145] -> 
             RGBColor[
              0.643116750417353, 0.7172355839626725, 0.9675221132384173], 
             UndirectedEdge[150, 274] -> 
             RGBColor[
              0.6852279869066359, 0.622788647378854, 0.5976147565045411], 
             UndirectedEdge[13, 156] -> 
             RGBColor[
              0.3638901315072269, 0.4896050750869218, 0.9444077352975997], 
             UndirectedEdge[84, 278] -> 
             RGBColor[
              0.19404895120727791`, 0.32128812950593255`, 0.9343621727503324],
              UndirectedEdge[150, 293] -> 
             RGBColor[
              0.9035840903340573, 0.6541630034729253, 0.24121312079051388`], 
             UndirectedEdge[52, 137] -> 
             RGBColor[
              0.23013360981142927`, 0.35921539359839394`, 0.9364171406753703],
              UndirectedEdge[41, 152] -> 
             RGBColor[
              0.1855570941414352, 0.31236264931489655`, 0.9338785740530094], 
             UndirectedEdge[177, 279] -> 
             RGBColor[
              0.2643192230897936, 0.3951466406470252, 0.9383639607784904], 
             UndirectedEdge[108, 279] -> 
             RGBColor[
              0.23867609661587075`, 0.3681940888548081, 0.9369036226614065], 
             UndirectedEdge[161, 279] -> 
             RGBColor[
              0.2191606879449377, 0.34768215699328187`, 0.9357922490080568], 
             UndirectedEdge[89, 260] -> 
             RGBColor[
              0.3194559514168667, 0.4464420991230162, 0.9417476517079721], 
             UndirectedEdge[63, 161] -> 
             RGBColor[
              0.19226866060006637`, 0.3194169312008093, 0.9342607878339557], 
             UndirectedEdge[110, 148] -> 
             RGBColor[
              0.2161072361235734, 0.34447278552900074`, 0.9356183594440073], 
             UndirectedEdge[200, 228] -> 
             RGBColor[
              0.3959136886863399, 0.5173422707646859, 0.946448248043733], 
             UndirectedEdge[67, 118] -> 
             RGBColor[
              0.18382399790050605`, 0.31054105528103165`, 0.9337798767859746],
              UndirectedEdge[140, 203] -> 
             RGBColor[
              0.8772220459314396, 0.5433777884881621, 0.5777664992302363], 
             UndirectedEdge[144, 231] -> 
             RGBColor[
              0.21441031983489064`, 0.34268921891888826`, 0.9355217225717294],
              UndirectedEdge[101, 149] -> 
             RGBColor[
              0.7714159149498363, 0.6714029284596804, 0.6000007099012994], 
             UndirectedEdge[131, 284] -> 
             RGBColor[
              0.23518277089129241`, 0.36452238202863274`, 0.9367046829293041],
              UndirectedEdge[157, 275] -> 
             RGBColor[
              0.18135642915031058`, 0.30794748407168115`, 0.9336393523960919],
              UndirectedEdge[113, 144] -> 
             RGBColor[
              0.23263625868922916`, 0.36184583624606526`, 0.9365596628266237],
              UndirectedEdge[48, 73] -> 
             RGBColor[
              0.187739347830093, 0.31465633630455114`, 0.9340028501722235], 
             UndirectedEdge[35, 183] -> 
             RGBColor[
              0.19956688605797046`, 0.32708782889128674`, 0.9346764109770263],
              UndirectedEdge[93, 107] -> 
             RGBColor[
              0.32480267899707094`, 0.44949793299033025`, 0.9421460174517705],
              UndirectedEdge[23, 226] -> 
             RGBColor[
              0.9878018957897885, 0.9892237846791677, 0.8518176846523693], 
             UndirectedEdge[200, 211] -> 
             RGBColor[
              0.31815152117452855`, 0.44647400293362227`, 0.9416219977306357],
              UndirectedEdge[87, 227] -> 
             RGBColor[
              0.9729262687384115, 0.9189743901826695, 0.3881944192270413], 
             UndirectedEdge[223, 278] -> 
             RGBColor[
              0.1910601770666856, 0.31814673838494456`, 0.9341919664845209], 
             UndirectedEdge[182, 229] -> 
             RGBColor[
              0.23602797859295035`, 0.36541074891233866`, 0.9367528162575407],
              UndirectedEdge[79, 221] -> 
             RGBColor[
              0.18466822464384994`, 0.3114283911153532, 0.9338279542500865], 
             UndirectedEdge[115, 228] -> 
             RGBColor[
              0.3889928994532643, 0.5113478309799768, 0.946007261473615], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.3382052536051789, 0.4616299042238716, 0.9429808558058818], 
             UndirectedEdge[9, 47] -> 
             RGBColor[
              0.1915298565644043, 0.31864040131644705`, 0.9342187140370874], 
             UndirectedEdge[18, 224] -> 
             RGBColor[
              0.2043212377981297, 0.33208495401350496`, 0.9349471642751953], 
             UndirectedEdge[194, 291] -> 
             RGBColor[
              0.8064401830754907, 0.8495804260163464, 0.9811128108192658], 
             UndirectedEdge[5, 198] -> 
             RGBColor[
              0.967801874456065, 0.9434968913498611, 0.6433562360480443], 
             UndirectedEdge[49, 172] -> 
             RGBColor[
              0.20010293929950806`, 0.3276512548358813, 0.9347069384161122], 
             UndirectedEdge[162, 228] -> 
             RGBColor[
              0.7088026697373979, 0.7671572402491821, 0.8707133358632482], 
             UndirectedEdge[100, 161] -> 
             RGBColor[
              0.1911587437240086, 0.318250338191278, 0.9341975797098391], 
             UndirectedEdge[174, 235] -> 
             RGBColor[
              0.3208493079592518, 0.4453409740728014, 0.9419209416251387], 
             UndirectedEdge[14, 67] -> 
             RGBColor[
              0.17956042552731538`, 0.30605977039070653`, 0.9335370726467116],
              UndirectedEdge[190, 199] -> 
             RGBColor[
              0.2014046269978636, 0.3290194111386199, 0.9347810676048591], 
             UndirectedEdge[160, 288] -> 
             RGBColor[
              0.20231487113075944`, 0.32997613543510473`, 0.934832904661642], 
             UndirectedEdge[33, 275] -> 
             RGBColor[
              0.19034059746125545`, 0.31739041459565537`, 0.9341509874905143],
              UndirectedEdge[109, 218] -> 
             RGBColor[
              0.9800003657513711, 0.9831729301139916, 0.8546124313811914], 
             UndirectedEdge[231, 264] -> 
             RGBColor[
              0.2636953407278438, 0.39449090072818943`, 0.9383284316009286], 
             UndirectedEdge[221, 230] -> 
             RGBColor[
              0.18914056303198, 0.3161291023239095, 0.9340826473050587], 
             UndirectedEdge[45, 236] -> 
             RGBColor[
              0.26568284234196243`, 0.3965798909395088, 0.9384416168776075], 
             UndirectedEdge[279, 280] -> 
             RGBColor[
              0.24933981979070619`, 0.37940233803066026`, 0.9375109059206487],
              UndirectedEdge[71, 252] -> 
             RGBColor[
              0.23062956346731406`, 0.3597366723360068, 0.9364453845023752], 
             UndirectedEdge[230, 296] -> 
             RGBColor[
              0.18964632804218584`, 0.3166606934169896, 0.9341114498741778], 
             UndirectedEdge[27, 154] -> 
             RGBColor[
              0.7335695588322665, 0.7563490417801518, 0.6454543011351679], 
             UndirectedEdge[5, 101] -> 
             RGBColor[
              0.8091703552886713, 0.8191489845938676, 0.6536867305122107], 
             UndirectedEdge[68, 143] -> 
             RGBColor[
              0.5918755827726521, 0.672270845358494, 0.9644525615859105], 
             UndirectedEdge[58, 221] -> 
             RGBColor[
              0.18866826221874242`, 0.3156326842235957, 0.9340557504724514], 
             UndirectedEdge[85, 249] -> 
             RGBColor[
              0.21980259172524277`, 0.34835683856543287`, 0.9358288044787336],
              UndirectedEdge[26, 54] -> 
             RGBColor[
              0.23656624471631046`, 0.3659765007360335, 0.9367834697169728], 
             UndirectedEdge[269, 282] -> 
             RGBColor[
              0.7068985223577822, 0.7386080961972126, 0.6497743968433352], 
             UndirectedEdge[24, 210] -> 
             RGBColor[
              0.6977215322082554, 0.6587130381270785, 0.6045341943932525], 
             UndirectedEdge[144, 288] -> 
             RGBColor[
              0.20325262345727604`, 0.33096177258720527`, 0.9348863082693568],
              UndirectedEdge[182, 199] -> 
             RGBColor[
              0.22636918605193562`, 0.35525874554891435`, 0.936202762311233], 
             UndirectedEdge[35, 224] -> 
             RGBColor[
              0.20753059097457632`, 0.33545818768669444`, 0.9351299321907813],
              UndirectedEdge[161, 280] -> 
             RGBColor[
              0.2318337811627876, 0.36100238148576125`, 0.9365139629186521], 
             UndirectedEdge[27, 42] -> 
             RGBColor[
              0.9037231190376234, 0.5999912478441332, 0.26049200407288453`], 
             UndirectedEdge[13, 273] -> 
             RGBColor[
              0.2861094453581625, 0.4157804018926833, 0.9396879661761859], 
             UndirectedEdge[167, 202] -> 
             RGBColor[
              0.8871263793979363, 0.5793538569383307, 0.22747634135468459`], 
             UndirectedEdge[117, 207] -> 
             RGBColor[
              0.18539878883552113`, 0.3121962604012447, 0.9338695588000294], 
             UndirectedEdge[33, 248] -> 
             RGBColor[
              0.21123257741316134`, 0.3393492101531443, 0.9353407548418606], 
             UndirectedEdge[23, 210] -> 
             RGBColor[
              0.7305128529889463, 0.7859159553283347, 0.8888842381324313], 
             UndirectedEdge[54, 111] -> 
             RGBColor[
              0.4291203016109882, 0.5357529458181629, 0.9499902123364491], 
             UndirectedEdge[30, 267] -> 
             RGBColor[
              0.22275125819820335`, 0.35145607398476686`, 0.9359967266722076],
              UndirectedEdge[170, 199] -> 
             RGBColor[
              0.19798561422584082`, 0.3254258119372937, 0.9345863598854686], 
             UndirectedEdge[169, 200] -> 
             RGBColor[
              0.4851546386974715, 0.5905268621408066, 0.9532706039694929], 
             UndirectedEdge[137, 278] -> 
             RGBColor[
              0.23108207251171536`, 0.3602122880324031, 0.9364711542230267], 
             UndirectedEdge[92, 150] -> 
             RGBColor[
              0.8694820518221094, 0.4570824795240357, 0.2111038787281495], 
             UndirectedEdge[68, 185] -> 
             RGBColor[
              0.7032065232894661, 0.766801236404889, 0.9721121646297556], 
             UndirectedEdge[26, 102] -> 
             RGBColor[
              0.21064547425155244`, 0.3387321275058029, 0.9353073201853483], 
             UndirectedEdge[270, 271] -> 
             RGBColor[
              0.217737181833685, 0.3461859618148549, 0.9357111824409096], 
             UndirectedEdge[169, 202] -> 
             RGBColor[
              0.7356548490799517, 0.5885020285868033, 0.5862010514084512], 
             UndirectedEdge[17, 97] -> 
             RGBColor[
              0.5762606506463335, 0.665813185958444, 0.9604600233988309], 
             UndirectedEdge[46, 158] -> 
             RGBColor[
              0.1988271914603046, 0.32631036296979365`, 0.9346342864639694], 
             UndirectedEdge[98, 285] -> 
             RGBColor[
              0.18936585526810354`, 0.31636589874842813`, 0.9340954773646161],
              UndirectedEdge[77, 168] -> 
             RGBColor[
              0.4070970567080353, 0.527028742052658, 0.9471608423650113], 
             UndirectedEdge[242, 268] -> 
             RGBColor[0.1929658134251674, 0.3201496830220325, 0.934300489656],
              UndirectedEdge[115, 134] -> 
             RGBColor[
              0.29826389721871693`, 0.4268505977105114, 0.940442569105771], 
             UndirectedEdge[99, 284] -> 
             RGBColor[
              0.2183159570292897, 0.34679429124190236`, 0.9357441428320781], 
             UndirectedEdge[204, 283] -> 
             RGBColor[
              0.3947145595034514, 0.515210734660812, 0.9466089897806659], 
             UndirectedEdge[77, 167] -> 
             RGBColor[
              0.6607323580564698, 0.6022582598273698, 0.5960819189651536], 
             UndirectedEdge[227, 290] -> 
             RGBColor[
              0.9495577123496941, 0.837720168902116, 0.27827115520513895`], 
             UndirectedEdge[60, 145] -> 
             RGBColor[
              0.5760856373176906, 0.6571907606456139, 0.9633236613969889], 
             UndirectedEdge[32, 125] -> 
             RGBColor[
              0.9114353173335938, 0.6303487508229553, 0.5176184899919789], 
             UndirectedEdge[15, 60] -> 
             RGBColor[
              0.27282174145117777`, 0.4040833265356404, 0.9388481666208225], 
             UndirectedEdge[30, 260] -> 
             RGBColor[
              0.25373200019445147`, 0.38401879811531836`, 0.9377610340969933],
              UndirectedEdge[42, 80] -> 
             RGBColor[
              0.9082065714342227, 0.6151149855425471, 0.2779093700047311], 
             UndirectedEdge[97, 130] -> 
             RGBColor[
              0.6803306714803544, 0.6256180746890865, 0.5988573985297044], 
             UndirectedEdge[65, 211] -> 
             RGBColor[
              0.3240980577045407, 0.45162459399430244`, 0.9420009057800123], 
             UndirectedEdge[1, 256] -> 
             RGBColor[
              0.8183107548052182, 0.14175006202263388`, 0.1651677055215038], 
             UndirectedEdge[5, 128] -> 
             RGBColor[
              0.9079764711926817, 0.6301585985825083, 0.2662791699211355], 
             UndirectedEdge[125, 256] -> 
             RGBColor[
              0.8265612881466855, 0.2051672766919145, 0.17306842556693747`], 
             UndirectedEdge[39, 239] -> 
             RGBColor[
              0.2196501555680895, 0.3481966184992542, 0.9358201234650929], 
             UndirectedEdge[156, 269] -> 
             RGBColor[
              0.6838282108058124, 0.7186257518784704, 0.6483043769915192], 
             UndirectedEdge[78, 170] -> 
             RGBColor[
              0.19585393495458225`, 0.32318528186692885`, 0.9344649639045073],
              UndirectedEdge[23, 155] -> 
             RGBColor[
              0.9578302462805677, 0.8677142666452164, 0.5428928075150579], 
             UndirectedEdge[127, 251] -> 
             RGBColor[
              0.31722126846433096`, 0.4470435197962596, 0.9415123680279698], 
             UndirectedEdge[241, 290] -> 
             RGBColor[
              0.9662675720592777, 0.9068871357048387, 0.5776802589012907], 
             UndirectedEdge[85, 234] -> 
             RGBColor[
              0.21315182719847248`, 0.341366463364971, 0.9354500532778585], 
             UndirectedEdge[270, 289] -> 
             RGBColor[
              0.22814186813803294`, 0.35712194681593845`, 0.9363037139335881],
              UndirectedEdge[69, 258] -> 
             RGBColor[
              0.273865191252875, 0.4022754790002804, 0.9390139404249507], 
             UndirectedEdge[52, 289] -> 
             RGBColor[
              0.22108882372044908`, 0.3497087499442134, 0.9359020534880509], 
             UndirectedEdge[47, 170] -> 
             RGBColor[
              0.1908380369178425, 0.3179132550040116, 0.9341793159316711], 
             UndirectedEdge[72, 241] -> 
             RGBColor[
              0.9077698315979006, 0.607817840595054, 0.5277114559730665], 
             UndirectedEdge[115, 210] -> 
             RGBColor[
              0.4117038936977402, 0.5305204071243743, 0.9475921355741658], 
             UndirectedEdge[166, 239] -> 
             RGBColor[
              0.21183524129599424`, 0.3399826481050988, 0.9353750756584267], 
             UndirectedEdge[180, 215] -> 
             RGBColor[
              0.2098131605219987, 0.33785731300430355`, 0.9352599211497481], 
             UndirectedEdge[51, 254] -> 
             RGBColor[
              0.5650392887707011, 0.6515224922377361, 0.9616798049124837], 
             UndirectedEdge[109, 227] -> 
             RGBColor[
              0.9727578246301442, 0.9207456642506578, 0.5248021537611475], 
             UndirectedEdge[203, 255] -> 
             RGBColor[
              0.651571481892223, 0.7220382969334023, 0.9679291557478935], 
             UndirectedEdge[257, 272] -> 
             RGBColor[
              0.18158199985616474`, 0.30818457318554265`, 0.9336521983140883],
              UndirectedEdge[32, 128] -> 
             RGBColor[
              0.9163082086198326, 0.6678039285635632, 0.5222847761908246], 
             UndirectedEdge[39, 76] -> 
             RGBColor[
              0.26432098730221126`, 0.39346839209165385`, 0.9384255780434674],
              UndirectedEdge[144, 221] -> 
             RGBColor[
              0.19191775891044247`, 0.3190481112765624, 0.9342408045018441], 
             UndirectedEdge[165, 262] -> 
             RGBColor[
              0.26081704104435255`, 0.39146562526609985`, 0.9381645166920165],
              UndirectedEdge[101, 226] -> 
             RGBColor[
              0.8167925796772653, 0.8565009126998259, 0.9214508039916728], 
             UndirectedEdge[56, 191] -> 
             RGBColor[
              0.21336670196225918`, 0.34159231036555776`, 0.9354622900777774],
              UndirectedEdge[63, 71] -> 
             RGBColor[
              0.20309975866494467`, 0.3308011019982774, 0.9348776028455769], 
             UndirectedEdge[137, 289] -> 
             RGBColor[
              0.25248937634424146`, 0.382712721661845, 0.9376902685070212], 
             UndirectedEdge[148, 295] -> 
             RGBColor[
              0.2216100316720449, 0.3502565725478334, 0.9359317355098362], 
             UndirectedEdge[10, 119] -> 
             RGBColor[
              0.1856272606689936, 0.3124363987841752, 0.9338825699329518], 
             UndirectedEdge[115, 231] -> 
             RGBColor[
              0.29145473297171365`, 0.41969373436096236`, 0.9400547972751598],
              UndirectedEdge[33, 171] -> 
             RGBColor[
              0.189827260881899, 0.31685086530333273`, 0.9341217537317332], 
             UndirectedEdge[173, 234] -> 
             RGBColor[
              0.19772105404463286`, 0.3251477424127598, 0.9345712935745305], 
             UndirectedEdge[69, 173] -> 
             RGBColor[
              0.2044279033465657, 0.3321970662678976, 0.9349532387203812], 
             UndirectedEdge[4, 263] -> 
             RGBColor[
              0.21521347097412877`, 0.3435333816889509, 0.9355674608409534], 
             UndirectedEdge[134, 160] -> 
             RGBColor[
              0.22028173175537732`, 0.3488604451163368, 0.9358560907946256], 
             UndirectedEdge[7, 205] -> 
             RGBColor[
              0.6553396994405775, 0.7252302520430189, 0.9671201357047186], 
             UndirectedEdge[23, 106] -> 
             RGBColor[
              0.9256036309143629, 0.94127542594585, 0.906451627608196], 
             UndirectedEdge[45, 96] -> 
             RGBColor[
              0.2504426073839444, 0.3805614377119254, 0.9375737080426556], 
             UndirectedEdge[65, 210] -> 
             RGBColor[
              0.424571219460828, 0.5416654379697635, 0.9484120301936603], 
             UndirectedEdge[138, 211] -> 
             RGBColor[
              0.25101026684268113`, 0.38115808379474614`, 0.9376060354090536],
              UndirectedEdge[72, 210] -> 
             RGBColor[
              0.6505472536572664, 0.40453749617198587`, 0.5636765147139389], 
             UndirectedEdge[37, 41] -> 
             RGBColor[
              0.20758147265742513`, 0.3355116675614536, 0.9351328298273469], 
             UndirectedEdge[52, 88] -> 
             RGBColor[
              0.21079575741608964`, 0.3388900846402345, 0.9353158785892447], 
             UndirectedEdge[157, 285] -> 
             RGBColor[
              0.1911088793151014, 0.31819792753593046`, 0.9341947400055196], 
             UndirectedEdge[135, 265] -> 
             RGBColor[
              0.21789617448484386`, 0.3463530731719392, 0.9357202368371844], 
             UndirectedEdge[17, 42] -> 
             RGBColor[
              0.7706339375032876, 0.5292391522973952, 0.5773709330033577], 
             UndirectedEdge[242, 250] -> 
             RGBColor[
              0.18176798085569046`, 0.30838005100792065`, 0.933662789656877], 
             UndirectedEdge[81, 202] -> 
             RGBColor[
              0.8780178149903479, 0.5389892121818496, 0.21992741358203377`], 
             UndirectedEdge[229, 259] -> 
             RGBColor[
              0.2014368212026378, 0.32905324928906804`, 0.934782901017194], 
             UndirectedEdge[40, 81] -> 
             RGBColor[
              0.7893492688527326, 0.6740607768287987, 0.5995695817860118], 
             UndirectedEdge[100, 119] -> 
             RGBColor[
              0.1807572108955105, 0.3073176676932546, 0.933605227802945], 
             UndirectedEdge[81, 269] -> 
             RGBColor[
              0.931314896123058, 0.7560543834090069, 0.28986513111217527`], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.8109817388046351, 0.5174976470005512, 0.5760174599499823], 
             UndirectedEdge[180, 233] -> 
             RGBColor[
              0.20014010875548707`, 0.32769032229079487`, 0.9347090551616429],
              UndirectedEdge[33, 184] -> 
             RGBColor[
              0.1959981041281816, 0.3233368128092353, 0.9344731741256647], 
             UndirectedEdge[103, 168] -> 
             RGBColor[
              0.41087052923769096`, 0.5302971342976018, 0.9474012846978503], 
             UndirectedEdge[49, 238] -> 
             RGBColor[
              0.19853266531396374`, 0.3260007973159532, 0.9346175136356476], 
             UndirectedEdge[97, 120] -> 
             RGBColor[
              0.3639742346570427, 0.4869360497143149, 0.944513487615392], 
             UndirectedEdge[117, 212] -> 
             RGBColor[
              0.20943922968905518`, 0.3374642879902957, 0.935238626341993], 
             UndirectedEdge[270, 278] -> 
             RGBColor[
              0.20673456430550685`, 0.3346215131864966, 0.9350845996495938], 
             UndirectedEdge[26, 165] -> 
             RGBColor[
              0.2234449255941841, 0.3521851623989958, 0.9360362300042198], 
             UndirectedEdge[65, 70] -> 
             RGBColor[
              0.2936166091660087, 0.41958665894484415`, 0.940265032379005], 
             UndirectedEdge[56, 223] -> 
             RGBColor[
              0.19042353178656807`, 0.3174775838298989, 0.9341557104776503], 
             UndirectedEdge[207, 212] -> 
             RGBColor[
              0.20932819464730518`, 0.33734758312138824`, 0.935232303060627], 
             UndirectedEdge[171, 184] -> 
             RGBColor[
              0.1853189372548359, 0.31211233132706184`, 0.9338650113706392], 
             UndirectedEdge[32, 205] -> 
             RGBColor[
              0.6800179376878698, 0.7430563957149572, 0.8994244086676673], 
             UndirectedEdge[23, 31] -> 
             RGBColor[
              0.7044976010018857, 0.7638813972041334, 0.8870888196503636], 
             UndirectedEdge[235, 274] -> 
             RGBColor[
              0.43577020330018756`, 0.5515998272739158, 0.9490608562281224], 
             UndirectedEdge[178, 199] -> 
             RGBColor[
              0.2287030477407748, 0.357711782159262, 0.9363356722817735], 
             UndirectedEdge[117, 158] -> 
             RGBColor[
              0.189227738636957, 0.3162207294119929, 0.9340876118267976], 
             UndirectedEdge[112, 190] -> 
             RGBColor[
              0.19682291342577818`, 0.3242037396769393, 0.9345201457949667], 
             UndirectedEdge[64, 213] -> 
             RGBColor[
              0.21883980227157213`, 0.34734488580524786`, 0.9357739750436664],
              UndirectedEdge[127, 205] -> 
             RGBColor[
              0.3605974794488338, 0.48675314536744607`, 0.9441979304200168], 
             UndirectedEdge[121, 263] -> 
             RGBColor[
              0.2176693590934683, 0.34611467581467703`, 0.935707320036189], 
             UndirectedEdge[14, 213] -> 
             RGBColor[
              0.19128445788964016`, 0.31838247175009526`, 0.9342047389455943],
              UndirectedEdge[109, 111] -> 
             RGBColor[
              0.8035074391264327, 0.8444862586698714, 0.8657863480729937], 
             UndirectedEdge[55, 108] -> 
             RGBColor[
              0.22141119699588285`, 0.35004758469634045`, 0.9359204121691784],
              UndirectedEdge[40, 162] -> 
             RGBColor[
              0.8402909601650888, 0.8739220660440041, 0.881352498558146], 
             UndirectedEdge[15, 225] -> 
             RGBColor[
              0.2429863506332136, 0.37272443911292436`, 0.9371490852512447], 
             UndirectedEdge[31, 59] -> 
             RGBColor[
              0.7023281164542653, 0.7629842595904825, 0.9230427930504692], 
             UndirectedEdge[210, 227] -> 
             RGBColor[
              0.7121917692235163, 0.7160827059719499, 0.6161772867558488], 
             UndirectedEdge[52, 93] -> 
             RGBColor[
              0.21993156031517644`, 0.348492392730534, 0.9358361490491385], 
             UndirectedEdge[32, 293] -> 
             RGBColor[
              0.9437174645743351, 0.8134407929799102, 0.5459850021177625], 
             UndirectedEdge[99, 209] -> 
             RGBColor[
              0.18806492725905072`, 0.31499854092731383`, 0.934021391439051], 
             UndirectedEdge[201, 299] -> 
             RGBColor[
              0.8320289955840182, 0.24719447201993064`, 0.1783043083838196], 
             UndirectedEdge[127, 148] -> 
             RGBColor[
              0.29756624946408855`, 0.42638484862682313`, 0.9403930437729009],
              UndirectedEdge[24, 226] -> 
             RGBColor[
              0.9550105750090976, 0.8620208674779115, 0.5674676409131905], 
             UndirectedEdge[144, 264] -> 
             RGBColor[
              0.24692493102232177`, 0.3768641368222969, 0.9373733815777969], 
             UndirectedEdge[148, 217] -> 
             RGBColor[
              0.22316774867338707`, 0.35189383188120626`, 0.9360204451886269],
              UndirectedEdge[230, 288] -> 
             RGBColor[
              0.2004754275788136, 0.3280427636345524, 0.9347281510725716], 
             UndirectedEdge[1, 83] -> 
             RGBColor[
              0.8326229955659482, 0.2517602161734964, 0.1788731234373428], 
             UndirectedEdge[15, 214] -> 
             RGBColor[
              0.22960322819742474`, 0.35865792889393855`, 0.936386936227082], 
             UndirectedEdge[173, 249] -> 
             RGBColor[
              0.20437181857140313`, 0.33213811761322165`, 0.9349500447754056],
              UndirectedEdge[114, 204] -> 
             RGBColor[
              0.3613702020678383, 0.4801637008416135, 0.944710077953264], 
             UndirectedEdge[77, 95] -> 
             RGBColor[
              0.3506695406416134, 0.476194939387312, 0.94363706407864], 
             UndirectedEdge[52, 295] -> 
             RGBColor[
              0.19782793389837072`, 0.3252600799156124, 0.9345773802240863], 
             UndirectedEdge[7, 103] -> 
             RGBColor[
              0.6798246620935919, 0.7464378960430543, 0.9686802958737664], 
             UndirectedEdge[29, 99] -> 
             RGBColor[
              0.19546469586089602`, 0.32277616690028066`, 0.9344427973139495],
              UndirectedEdge[28, 144] -> 
             RGBColor[
              0.19055497770725674`, 0.3176157418266954, 0.9341631961283768], 
             UndirectedEdge[75, 185] -> 
             RGBColor[
              0.43124290556454353`, 0.5458726103470143, 0.9492713561429931], 
             UndirectedEdge[227, 291] -> 
             RGBColor[
              0.9397896555683924, 0.8973624624611904, 0.6368452332520997], 
             UndirectedEdge[76, 192] -> 
             RGBColor[
              0.32876752436481727`, 0.45918363809373036`, 0.9421697538281874],
              UndirectedEdge[59, 72] -> 
             RGBColor[
              0.9072115711061266, 0.6075869855350652, 0.536963277053603], 
             UndirectedEdge[104, 254] -> 
             RGBColor[
              0.32693482661477913`, 0.45759624741671456`, 0.942052975948146], 
             UndirectedEdge[32, 237] -> 
             RGBColor[
              0.90637541312433, 0.5914561098063906, 0.5127731200068433], 
             UndirectedEdge[25, 232] -> 
             RGBColor[
              0.1895116930698092, 0.31651918352467145`, 0.9341037826116756], 
             UndirectedEdge[9, 141] -> 
             RGBColor[
              0.24640393833854723`, 0.3763165404788058, 0.9373437118151957], 
             UndirectedEdge[22, 48] -> 
             RGBColor[
              0.19067565939696252`, 0.3177425859342372, 0.934170068772073], 
             UndirectedEdge[25, 160] -> 
             RGBColor[
              0.19344001775085345`, 0.32064810183461934`, 0.9343274948908254],
              UndirectedEdge[72, 106] -> 
             RGBColor[
              0.845638031582683, 0.5598969667895013, 0.5812439041897035], 
             UndirectedEdge[4, 186] -> 
             RGBColor[
              0.2068268311149634, 0.334718491453289, 0.9350898541078958], 
             UndirectedEdge[78, 182] -> 
             RGBColor[
              0.22423750678067705`, 0.3530182154785495, 0.9360813663302717], 
             UndirectedEdge[106, 211] -> 
             RGBColor[
              0.5662966671615951, 0.6472879549936589, 0.9627077142549896], 
             UndirectedEdge[180, 245] -> 
             RGBColor[
              0.2100635516260986, 0.3381204899304254, 0.9352741805527061], 
             UndirectedEdge[136, 280] -> 
             RGBColor[
              0.32731420410911033`, 0.4536040519351767, 0.9422353549515605], 
             UndirectedEdge[82, 140] -> 
             RGBColor[
              0.7153793247314246, 0.41559198421602295`, 0.5634646813953219], 
             UndirectedEdge[50, 219] -> 
             RGBColor[
              0.1830787781409705, 0.30975778206409804`, 0.9337374376231229], 
             UndirectedEdge[251, 278] -> 
             RGBColor[
              0.24311863666183964`, 0.372863480116429, 0.9371566187448754], 
             UndirectedEdge[80, 150] -> 
             RGBColor[
              0.9431089113179686, 0.8053970694161215, 0.30826637148751795`], 
             UndirectedEdge[26, 183] -> 
             RGBColor[
              0.21091795920318307`, 0.3390185264665105, 0.9353228378002383], 
             UndirectedEdge[243, 256] -> 
             RGBColor[
              0.9026728062872424, 0.5639368365528598, 0.5114946297323817], 
             UndirectedEdge[184, 248] -> 
             RGBColor[
              0.20672425378609824`, 0.33461067617687346`, 0.9350840124807664],
              UndirectedEdge[4, 255] -> 
             RGBColor[
              0.2932777706676125, 0.42028873435652747`, 0.9402069895504767], 
             UndirectedEdge[37, 280] -> 
             RGBColor[
              0.2442905970349878, 0.3740952847751871, 0.9372233601543662], 
             UndirectedEdge[188, 260] -> 
             RGBColor[
              0.3070159863730502, 0.43566722665288543`, 0.9409549881356092], 
             UndirectedEdge[70, 266] -> 
             RGBColor[
              0.20395979058864, 0.33170505007925455`, 0.934926580391328], 
             UndirectedEdge[103, 127] -> 
             RGBColor[
              0.3850824421018483, 0.5079607893674816, 0.9457580905890645], 
             UndirectedEdge[37, 268] -> 
             RGBColor[
              0.21580890611804032`, 0.3441592217779706, 0.9356013699915318], 
             UndirectedEdge[186, 196] -> 
             RGBColor[
              0.19808785672818557`, 0.32553327528980713`, 0.9345921824447229],
              UndirectedEdge[139, 274] -> 
             RGBColor[
              0.4518848560948061, 0.5655575295786147, 0.9500876676545675], 
             UndirectedEdge[15, 255] -> 
             RGBColor[
              0.31219697150637127`, 0.44017401398467865`, 0.9412844100497945],
              UndirectedEdge[118, 195] -> 
             RGBColor[
              0.18622253645749176`, 0.31306207138055164`, 0.9339164700084752],
              UndirectedEdge[125, 128] -> 
             RGBColor[
              0.8400673632821627, 0.3089808885830544, 0.18600185836960054`], 
             UndirectedEdge[61, 177] -> 
             RGBColor[
              0.2846154792944696, 0.4164792927751083, 0.9395198025437264], 
             UndirectedEdge[117, 276] -> 
             RGBColor[
              0.21344183559868857`, 0.34167128058119267`, 0.9354665688272218],
              UndirectedEdge[7, 154] -> 
             RGBColor[
              0.7178086500945909, 0.778143567686985, 0.971430549102502], 
             UndirectedEdge[59, 198] -> 
             RGBColor[
              0.974799373492677, 0.9805904794680657, 0.9214736253472325], 
             UndirectedEdge[83, 197] -> 
             RGBColor[
              0.9164471489214862, 0.6737245560050689, 0.534114411639826], 
             UndirectedEdge[243, 283] -> 
             RGBColor[
              0.6466191425526432, 0.7139161177704824, 0.899457696684746], 
             UndirectedEdge[95, 225] -> 
             RGBColor[
              0.2575765092536425, 0.3880596208924811, 0.9379799732004728], 
             UndirectedEdge[21, 74] -> 
             RGBColor[
              0.19973960321144332`, 0.32726936557048675`, 0.9346862469634045],
              UndirectedEdge[62, 225] -> 
             RGBColor[
              0.21463682483983898`, 0.34292729004033573`, 0.9355346216966771],
              UndirectedEdge[236, 267] -> 
             RGBColor[
              0.21381850493226368`, 0.3420671839329953, 0.9354880195885366], 
             UndirectedEdge[123, 300] -> 
             RGBColor[
              0.21212454910682327`, 0.34028672895745476`, 0.9353915513102607],
              UndirectedEdge[111, 218] -> 
             RGBColor[
              0.7906966430720825, 0.8363639438748425, 0.9515975962507148], 
             UndirectedEdge[61, 161] -> 
             RGBColor[
              0.23945694414961366`, 0.369014809121365, 0.9369480907732928], 
             UndirectedEdge[58, 180] -> 
             RGBColor[
              0.1930127612329003, 0.32019902814462275`, 0.9343031632641974], 
             UndirectedEdge[188, 236] -> 
             RGBColor[
              0.29364767479578224`, 0.42161628358526776`, 0.9401936825679285],
              UndirectedEdge[41, 268] -> 
             RGBColor[
              0.19682209771404596`, 0.32420288231218963`, 0.9345200993413902],
              UndirectedEdge[65, 138] -> 
             RGBColor[
              0.30437559706733064`, 0.4308950373883661, 0.9408777408234891], 
             UndirectedEdge[241, 291] -> 
             RGBColor[
              0.956499515277976, 0.9665294292639133, 0.9362543369482514], 
             UndirectedEdge[270, 295] -> 
             RGBColor[
              0.20488097831595456`, 0.3326732767873375, 0.9349790406696236], 
             UndirectedEdge[127, 212] -> 
             RGBColor[
              0.2911019408470156, 0.4195904504094406, 0.9400249109602461], 
             UndirectedEdge[105, 274] -> 
             RGBColor[
              0.373443394956703, 0.4953127699434419, 0.9451737605551122], 
             UndirectedEdge[128, 142] -> 
             RGBColor[
              0.8374379233542384, 0.28876986106910485`, 0.18348390372509257`],
              UndirectedEdge[38, 57] -> 
             RGBColor[
              0.18289757268776397`, 0.30956732364368866`, 0.9337271182406324],
              UndirectedEdge[135, 255] -> 
             RGBColor[
              0.28954719045708177`, 0.4163676580228129, 0.9399945385263857], 
             UndirectedEdge[46, 196] -> 
             RGBColor[
              0.2038842250820344, 0.33162562594068223`, 0.9349222770475161], 
             UndirectedEdge[138, 210] -> 
             RGBColor[
              0.35148342859896836`, 0.4711989277702072, 0.9440171598227016], 
             UndirectedEdge[72, 109] -> 
             RGBColor[
              0.9111133090638942, 0.6092004544506938, 0.4723013817192375], 
             UndirectedEdge[277, 282] -> 
             RGBColor[
              0.7168216670755537, 0.7717675564528452, 0.7149933619542863], 
             UndirectedEdge[62, 117] -> 
             RGBColor[
              0.1935934216908487, 0.32080933910192594`, 0.9343362310182673], 
             UndirectedEdge[33, 126] -> 
             RGBColor[
              0.2119973945219809, 0.3401530814267192, 0.9353843100447624], 
             UndirectedEdge[217, 278] -> 
             RGBColor[
              0.20033411359999898`, 0.32789423368299453`, 0.9347201034505334],
              UndirectedEdge[228, 264] -> 
             RGBColor[
              0.3612335072093944, 0.48614499734720384`, 0.9442808957993838], 
             UndirectedEdge[121, 239] -> 
             RGBColor[
              0.2315127682951095, 0.3606649766084402, 0.9364956817107337], 
             UndirectedEdge[56, 84] -> 
             RGBColor[
              0.1934123059271604, 0.32061897495088687`, 0.9343259167434621], 
             UndirectedEdge[45, 120] -> 
             RGBColor[
              0.2895125289687292, 0.4216264024736376, 0.9397986822781397], 
             UndirectedEdge[67, 234] -> 
             RGBColor[
              0.18654108215101917`, 0.31339688310141245`, 0.9339346107144755],
              UndirectedEdge[153, 192] -> 
             RGBColor[
              0.2758432306623323, 0.4052369526728678, 0.9390942768006172], 
             UndirectedEdge[77, 127] -> 
             RGBColor[
              0.3813089695721926, 0.5046923971225378, 0.9455176482562255], 
             UndirectedEdge[36, 152] -> 
             RGBColor[
              0.18192632080115292`, 0.3085464763299341, 0.9336718068825283], 
             UndirectedEdge[22, 122] -> 
             RGBColor[
              0.18679089642314464`, 0.31365945374055604`, 0.9339488372677058],
              UndirectedEdge[68, 218] -> 
             RGBColor[
              0.9220230883129681, 0.9398481441591451, 0.964270119789284], 
             UndirectedEdge[56, 148] -> 
             RGBColor[
              0.2228269723814797, 0.3515356543919468, 0.936001038482936], 
             UndirectedEdge[7, 130] -> 
             RGBColor[
              0.92506143421404, 0.8207777707366587, 0.6185929179813181], 
             UndirectedEdge[58, 296] -> 
             RGBColor[
              0.18917402722894824`, 0.3161642753166758, 0.9340845530415703], 
             UndirectedEdge[104, 116] -> 
             RGBColor[
              0.3112198168736299, 0.4420066574870038, 0.9411240550973782], 
             UndirectedEdge[252, 279] -> 
             RGBColor[
              0.23730450403035436`, 0.36675245808343765`, 0.9368255124927507],
              UndirectedEdge[64, 173] -> 
             RGBColor[
              0.21829574180286104`, 0.34677304375720647`, 0.9357429916048386],
              UndirectedEdge[109, 155] -> 
             RGBColor[
              0.9595624996907148, 0.8684305979471943, 0.514184885580798], 
             UndirectedEdge[151, 258] -> 
             RGBColor[
              0.4689947888884989, 0.5767176597098022, 0.9521890651333698], 
             UndirectedEdge[167, 216] -> 
             RGBColor[
              0.8870728705076437, 0.5791108855648315, 0.22743169222500162`], 
             UndirectedEdge[12, 258] -> 
             RGBColor[
              0.3848908244823526, 0.507794819816456, 0.9457458808837911], 
             UndirectedEdge[151, 239] -> 
             RGBColor[
              0.41770207455751684`, 0.5257103442374987, 0.9491616700514242], 
             UndirectedEdge[136, 226] -> 
             RGBColor[
              0.6894363159019072, 0.7515352642002422, 0.911828216152313], 
             UndirectedEdge[59, 210] -> 
             RGBColor[
              0.7283433684413259, 0.785018817714684, 0.9248382115325371], 
             UndirectedEdge[191, 205] -> 
             RGBColor[
              0.29986821230051, 0.4266293598594382, 0.9406037744698572], 
             UndirectedEdge[212, 276] -> 
             RGBColor[
              0.23737124141047264`, 0.3668226033013362, 0.9368293130878194], 
             UndirectedEdge[218, 292] -> 
             RGBColor[
              0.8704525733936984, 0.8991011858444631, 0.9592520377831382], 
             UndirectedEdge[144, 245] -> 
             RGBColor[
              0.2114412038308669, 0.3395684897458317, 0.9353526358077138], 
             UndirectedEdge[1, 277] -> 
             RGBColor[
              0.9058522963240394, 0.5660756214140101, 0.3231115936678419], 
             UndirectedEdge[64, 239] -> 
             RGBColor[
              0.23644031537818827`, 0.3658441410172859, 0.9367762982274624], 
             UndirectedEdge[128, 256] -> 
             RGBColor[
              0.8314341794329242, 0.2426224544325225, 0.1777347117657832], 
             UndirectedEdge[7, 81] -> 
             RGBColor[
              0.9138922902616244, 0.7722436147323656, 0.6093859995388808], 
             UndirectedEdge[32, 145] -> 
             RGBColor[
              0.9262900127477325, 0.9421433350511439, 0.920438952214905], 
             UndirectedEdge[84, 247] -> 
             RGBColor[
              0.1926121673846783, 0.3197779786110244, 0.9342803500371666], 
             UndirectedEdge[215, 259] -> 
             RGBColor[
              0.20495150510474192`, 0.33274740491400967`, 0.9349830570659099],
              UndirectedEdge[187, 233] -> 
             RGBColor[
              0.2150678926487934, 0.3433803696388245, 0.9355591703706895], 
             UndirectedEdge[37, 152] -> 
             RGBColor[
              0.20454390254542953`, 0.33231898878067745`, 0.9349598447031511],
              UndirectedEdge[257, 300] -> 
             RGBColor[
              0.20486085687830097`, 0.33265212788059073`, 0.9349778947835161],
              UndirectedEdge[10, 244] -> 
             RGBColor[
              0.1899533548754444, 0.3169833980853699, 0.9341289345981263], 
             UndirectedEdge[98, 157] -> 
             RGBColor[
              0.18079506708635712`, 0.3073574569500555, 0.9336073836570105], 
             UndirectedEdge[13, 271] -> 
             RGBColor[
              0.2779619784734704, 0.40721689761763513`, 0.9392239799901998], 
             UndirectedEdge[202, 203] -> 
             RGBColor[
              0.9018479137485027, 0.71981963766744, 0.6008453442170419], 
             UndirectedEdge[166, 195] -> 
             RGBColor[
              0.184909234384039, 0.31168170763319203`, 0.9338416793982484], 
             UndirectedEdge[260, 287] -> 
             RGBColor[
              0.25058425907026255`, 0.38071032261548143`, 0.9375817748966364],
              UndirectedEdge[212, 214] -> 
             RGBColor[
              0.21709951040225656`, 0.3455157287097197, 0.9356748679962401], 
             UndirectedEdge[25, 113] -> 
             RGBColor[
              0.22937411863723062`, 0.3584171202197894, 0.9363738887765662], 
             UndirectedEdge[244, 280] -> 
             RGBColor[
              0.22575834254074034`, 0.3546167102889326, 0.9361679756769326], 
             UndirectedEdge[58, 134] -> 
             RGBColor[
              0.21796998739019388`, 0.34643065521547056`, 0.9357244403729478],
              UndirectedEdge[64, 263] -> 
             RGBColor[
              0.22259690617654707`, 0.3512938402235227, 0.9359879365529176], 
             UndirectedEdge[182, 261] -> 
             RGBColor[
              0.24954002688104543`, 0.37961276837646946`, 0.9375223074182637],
              UndirectedEdge[150, 277] -> 
             RGBColor[
              0.9502103007628988, 0.8290380865568148, 0.362523350207251], 
             UndirectedEdge[86, 202] -> 
             RGBColor[
              0.7303739014473327, 0.5842147173946636, 0.5857853158660629], 
             UndirectedEdge[257, 267] -> 
             RGBColor[
              0.19014093188722048`, 0.31718055341781604`, 0.9341396168314517],
              UndirectedEdge[134, 245] -> 
             RGBColor[
              0.2350207777833922, 0.3643521170012733, 0.9366954576614566], 
             UndirectedEdge[187, 297] -> 
             RGBColor[
              0.20836666181027574`, 0.33633695114496726`, 0.9351775451880184],
              UndirectedEdge[75, 292] -> 
             RGBColor[
              0.5533224742847231, 0.6429700886267707, 0.9602576695267473], 
             UndirectedEdge[54, 174] -> 
             RGBColor[
              0.23862082785776215`, 0.3681359978857943, 0.936900475187395], 
             UndirectedEdge[44, 108] -> 
             RGBColor[
              0.27845239042381165`, 0.4093105366510138, 0.9391941231422369], 
             UndirectedEdge[94, 141] -> 
             RGBColor[
              0.5453682927010454, 0.6337189411498153, 0.9602178278094844], 
             UndirectedEdge[185, 262] -> 
             RGBColor[
              0.41669813660407123`, 0.5328210539055609, 0.9483611851595068], 
             UndirectedEdge[40, 202] -> 
             RGBColor[
              0.777902189496511, 0.6220822630055047, 0.5900178581775892], 
             UndirectedEdge[110, 191] -> 
             RGBColor[
              0.20664696570435293`, 0.3345294415026117, 0.9350796110388486], 
             UndirectedEdge[92, 125] -> 
             RGBColor[
              0.8333745807247173, 0.2575372290505118, 0.17959284223417404`], 
             UndirectedEdge[72, 226] -> 
             RGBColor[
              0.9078362964581086, 0.6078453255228189, 0.5266099612338768], 
             UndirectedEdge[130, 162] -> 
             RGBColor[
              0.9515757296113414, 0.8393631712246421, 0.5204689724050278], 
             UndirectedEdge[29, 43] -> 
             RGBColor[
              0.21042089134742065`, 0.3384960766341818, 0.9352945305211986], 
             UndirectedEdge[152, 268] -> 
             RGBColor[
              0.1937845276020504, 0.3210102035314135, 0.9343471142171944], 
             UndirectedEdge[4, 62] -> 
             RGBColor[
              0.21110734445904222`, 0.33921758237813715`, 0.9353336230103891],
              UndirectedEdge[18, 184] -> 
             RGBColor[
              0.19573226525779447`, 0.3230573993013006, 0.9344580349952694], 
             UndirectedEdge[95, 159] -> 
             RGBColor[
              0.2893985943419117, 0.4215066499569798, 0.9397921938696936], 
             UndirectedEdge[154, 255] -> 
             RGBColor[
              0.43165774296703474`, 0.5471078244024314, 0.9490557746765065], 
             UndirectedEdge[140, 269] -> 
             RGBColor[
              0.8952419489497732, 0.5276340204064351, 0.25723456251694715`], 
             UndirectedEdge[10, 161] -> 
             RGBColor[
              0.19602879349749167`, 0.3233690692821986, 0.9344749218398459], 
             UndirectedEdge[216, 293] -> 
             RGBColor[
              0.8831112421654739, 0.5621172753839567, 0.2241774940682837], 
             UndirectedEdge[188, 294] -> 
             RGBColor[
              0.445956916802145, 0.5584408477111231, 0.9502576320388609], 
             UndirectedEdge[32, 282] -> 
             RGBColor[
              0.7141541547436409, 0.7726234711925095, 0.9015995382329896], 
             UndirectedEdge[251, 282] -> 
             RGBColor[
              0.363119718775744, 0.4867984505328162, 0.944436976695407], 
             UndirectedEdge[181, 299] -> 
             RGBColor[
              0.9024939314125389, 0.5550617691490322, 0.28339483620290606`], 
             UndirectedEdge[60, 159] -> 
             RGBColor[
              0.28925410608148494`, 0.42135478363418655`, 0.9397839654770135],
              UndirectedEdge[137, 217] -> 
             RGBColor[
              0.23078620352350526`, 0.3599013109666169, 0.9364543049218471], 
             UndirectedEdge[20, 152] -> 
             RGBColor[
              0.20076184690853469`, 0.3283438085101236, 0.9347444622296798], 
             UndirectedEdge[62, 196] -> 
             RGBColor[
              0.2023683700722644, 0.33003236621465526`, 0.9348359513472162], 
             UndirectedEdge[251, 289] -> 
             RGBColor[
              0.26452594049436573`, 0.3953639137458709, 0.9383757330288698], 
             UndirectedEdge[104, 283] -> 
             RGBColor[
              0.32045429654903324`, 0.4517126811256811, 0.9416499450537039], 
             UndirectedEdge[45, 294] -> 
             RGBColor[
              0.4179920843483252, 0.5334044550653643, 0.9485055663485399], 
             UndirectedEdge[15, 158] -> 
             RGBColor[
              0.22566086224390924`, 0.3545142523163553, 0.9361624243182372], 
             UndirectedEdge[150, 237] -> 
             RGBColor[
              0.8662420388840522, 0.43217832029940567`, 0.20800123867959472`],
              UndirectedEdge[169, 228] -> 
             RGBColor[
              0.5154980125146456, 0.6168087674389304, 0.9552040569175313], 
             UndirectedEdge[159, 251] -> 
             RGBColor[
              0.2884240455436301, 0.4204823373800232, 0.9397366947573472], 
             UndirectedEdge[203, 293] -> 
             RGBColor[
              0.9184419291701429, 0.7951691860663403, 0.6146917974413972], 
             UndirectedEdge[145, 282] -> 
             RGBColor[
              0.6527680048201097, 0.7255950154401895, 0.9681370826346918], 
             UndirectedEdge[195, 234] -> 
             RGBColor[
              0.18893962070800485`, 0.3159178992009325, 0.934071203936976], 
             UndirectedEdge[156, 270] -> 
             RGBColor[
              0.3036653348674415, 0.42857413928414156`, 0.9408949377483093], 
             UndirectedEdge[25, 134] -> 
             RGBColor[
              0.21795734402989536`, 0.34641736624216146`, 0.935723720352283], 
             UndirectedEdge[158, 276] -> 
             RGBColor[
              0.21715975035837445`, 0.34557904472303347`, 0.935678298572624], 
             UndirectedEdge[268, 280] -> 
             RGBColor[
              0.23353122209160865`, 0.3627864995259231, 0.9366106296684096], 
             UndirectedEdge[8, 186] -> 
             RGBColor[
              0.19879211006828354`, 0.3262734902024908, 0.934632288630592], 
             UndirectedEdge[32, 256] -> 
             RGBColor[
              0.9028021334843555, 0.5639903166724234, 0.5093513433881616], 
             UndirectedEdge[60, 168] -> 
             RGBColor[
              0.3438394161380286, 0.4702523109805432, 0.9432028328564219], 
             UndirectedEdge[162, 216] -> 
             RGBColor[
              0.9289059974124116, 0.7386075300235558, 0.5016656812244851], 
             UndirectedEdge[106, 115] -> 
             RGBColor[
              0.6067946716231568, 0.6858798777418896, 0.9651595250499304], 
             UndirectedEdge[77, 276] -> 
             RGBColor[
              0.3275782701356497, 0.45192455001443343`, 0.9423220503837988], 
             UndirectedEdge[80, 281] -> 
             RGBColor[
              0.9786349916305042, 0.9618175926615335, 0.6467591064594813], 
             UndirectedEdge[130, 293] -> 
             RGBColor[
              0.9057809743644036, 0.6628729165850431, 0.24298078524882644`], 
             UndirectedEdge[39, 118] -> 
             RGBColor[
              0.19522260799965463`, 0.322521717208859, 0.9344290107683887], 
             UndirectedEdge[58, 245] -> 
             RGBColor[
              0.20819170713916685`, 0.33615306269286493`, 0.9351675817783212],
              UndirectedEdge[54, 143] -> 
             RGBColor[
              0.2754657226956103, 0.40686231846163223`, 0.9389987374412732], 
             UndirectedEdge[239, 258] -> 
             RGBColor[
              0.28886880526886394`, 0.4180452286151569, 0.9398683740473033], 
             UndirectedEdge[184, 222] -> 
             RGBColor[
              0.2064576757790399, 0.33433048578943325`, 0.9350688312576314], 
             UndirectedEdge[143, 298] -> 
             RGBColor[
              0.28351617500257303`, 0.41532385426440727`, 0.9394571987905778],
              UndirectedEdge[203, 269] -> 
             RGBColor[
              0.9551449948812127, 0.9368848088945971, 0.6707830617471834], 
             UndirectedEdge[107, 139] -> 
             RGBColor[
              0.4245992235592372, 0.5421882392946853, 0.9482760649602114], 
             UndirectedEdge[108, 283] -> 
             RGBColor[
              0.2732531217435669, 0.4045367345740317, 0.9388727330903042], 
             UndirectedEdge[173, 186] -> 
             RGBColor[
              0.19720146830174806`, 0.32460162485334904`, 0.9345417039351314],
              UndirectedEdge[164, 296] -> 
             RGBColor[
              0.18458413953272382`, 0.31134001233225567`, 0.9338231657274008],
              UndirectedEdge[11, 116] -> 
             RGBColor[
              0.4095833128093886, 0.5250728013946587, 0.9479805946176828], 
             UndirectedEdge[43, 229] -> 
             RGBColor[
              0.221649468641255, 0.3502980233029215, 0.935933981386891], 
             UndirectedEdge[128, 149] -> 
             RGBColor[
              0.8702220308538466, 0.4824125424483211, 0.2125931493102241], 
             UndirectedEdge[221, 232] -> 
             RGBColor[
              0.18705168190288157`, 0.31393355581451393`, 0.9339636886149794],
              UndirectedEdge[8, 85] -> 
             RGBColor[
              0.21830835870760254`, 0.3467863049240477, 0.9357437101188987], 
             UndirectedEdge[20, 41] -> 
             RGBColor[
              0.20379941702053028`, 0.3315364872908998, 0.9349174473538756], 
             UndirectedEdge[108, 252] -> 
             RGBColor[
              0.23931387407336885`, 0.3688644334000649, 0.9369399431441039], 
             UndirectedEdge[65, 241] -> 
             RGBColor[
              0.6817937974014621, 0.7449457823928316, 0.912446971452788], 
             UndirectedEdge[231, 245] -> 
             RGBColor[
              0.2282116135363889, 0.3571952536517242, 0.9363076858308454], 
             UndirectedEdge[80, 167] -> 
             RGBColor[
              0.9432452158034876, 0.8059374712804274, 0.30837604527604406`], 
             UndirectedEdge[17, 201] -> 
             RGBColor[
              0.7745136164836781, 0.5590600650268467, 0.5810861179764505], 
             UndirectedEdge[57, 223] -> 
             RGBColor[
              0.1805830172649961, 0.30713457914306985`, 0.9335953077333836], 
             UndirectedEdge[162, 202] -> 
             RGBColor[
              0.9289595063027041, 0.738850501397055, 0.5017103303541681], 
             UndirectedEdge[3, 59] -> 
             RGBColor[
              0.9696130276591681, 0.9767225112372966, 0.930252756027731], 
             UndirectedEdge[180, 187] -> 
             RGBColor[
              0.20981238961313842`, 0.3378565027302129, 0.9352598772476289], 
             UndirectedEdge[193, 215] -> 
             RGBColor[
              0.252152731139514, 0.38235888620713765`, 0.9376710970606339], 
             UndirectedEdge[43, 78] -> 
             RGBColor[
              0.20985899682898168`, 0.3379054898691324, 0.9352625314596219], 
             UndirectedEdge[56, 251] -> 
             RGBColor[
              0.2424819913817221, 0.3721943255613833, 0.9371203627380049], 
             UndirectedEdge[261, 284] -> 
             RGBColor[
              0.2428470796826115, 0.3725780565135533, 0.937141153976641], 
             UndirectedEdge[36, 41] -> 
             RGBColor[
              0.18496389091314852`, 0.31173915511071026`, 0.9338447920067241],
              UndirectedEdge[95, 168] -> 
             RGBColor[
              0.3439839043984553, 0.4704041773033365, 0.943211061249102], 
             UndirectedEdge[194, 280] -> 
             RGBColor[
              0.4740092277386598, 0.5736772866128733, 0.9537854496422005], 
             UndirectedEdge[99, 182] -> 
             RGBColor[
              0.22500890422772363`, 0.3538290031048185, 0.9361252962737008], 
             UndirectedEdge[94, 97] -> 
             RGBColor[
              0.622873487370591, 0.7022274882781143, 0.9651059553417796], 
             UndirectedEdge[79, 240] -> 
             RGBColor[
              0.18183565807480434`, 0.3084511840561929, 0.9336666437743861], 
             UndirectedEdge[83, 198] -> 
             RGBColor[
              0.9055718234570376, 0.665970901350738, 0.5685171958085309], 
             UndirectedEdge[69, 213] -> 
             RGBColor[
              0.20497196381527677`, 0.33276890831593897`, 0.934984222159209], 
             UndirectedEdge[214, 286] -> 
             RGBColor[
              0.21086056333637188`, 0.3389581997713838, 0.9353195691905329], 
             UndirectedEdge[277, 293] -> 
             RGBColor[
              0.946384976906248, 0.8125848782402458, 0.35937882583905917`], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.23002654529780098`, 0.3591028620062883, 0.9364110435097069], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.4656160294018773, 0.5758295097005381, 0.9514105681730911], 
             UndirectedEdge[43, 199] -> 
             RGBColor[
              0.21199067610024028`, 0.34014601993949717`, 0.9353839274405833],
              UndirectedEdge[192, 222] -> 
             RGBColor[
              0.2760214326902352, 0.40542425430285495`, 0.93910442514248], 
             UndirectedEdge[130, 202] -> 
             RGBColor[
              0.8891869589427635, 0.5875233681861427, 0.22913433202447103`], 
             UndirectedEdge[4, 265] -> 
             RGBColor[
              0.22162675469537457`, 0.35027414950565383`, 0.9359326878612754],
              UndirectedEdge[121, 173] -> 
             RGBColor[
              0.21336819471978227`, 0.34159387934836083`, 0.9354623750881099],
              UndirectedEdge[53, 107] -> 
             RGBColor[
              0.3121763440598402, 0.43622685441542786`, 0.9414269663560839], 
             UndirectedEdge[172, 238] -> 
             RGBColor[
              0.18901379750666059`, 0.31599586371940025`, 0.9340754281959247],
              UndirectedEdge[210, 211] -> 
             RGBColor[
              0.3712058892361785, 0.49192848437614356`, 0.9451403247792249], 
             UndirectedEdge[180, 221] -> 
             RGBColor[
              0.19054010670567417`, 0.3176001114611562, 0.9341623492468364], 
             UndirectedEdge[196, 212] -> 
             RGBColor[
              0.2182141780704709, 0.3466873151030251, 0.9357383466709418], 
             UndirectedEdge[160, 176] -> 
             RGBColor[
              0.19497852177206426`, 0.3222651671077009, 0.9344151104188206], 
             UndirectedEdge[115, 193] -> 
             RGBColor[
              0.3156462416789386, 0.4451205438424978, 0.9414324679079064], 
             UndirectedEdge[21, 300] -> 
             RGBColor[
              0.2096118710905434, 0.33764574504935696`, 0.9352484580144076], 
             UndirectedEdge[75, 235] -> 
             RGBColor[
              0.3707116092284409, 0.495513496231598, 0.9448423938259995], 
             UndirectedEdge[77, 255] -> 
             RGBColor[
              0.38990028243638014`, 0.512133760513557, 0.9460650791149319], 
             UndirectedEdge[62, 286] -> 
             RGBColor[
              0.21128388043674812`, 0.3394031328837336, 0.935343676473158], 
             UndirectedEdge[46, 225] -> 
             RGBColor[
              0.21615267984960895`, 0.3445205497663627, 0.935620947396977], 
             UndirectedEdge[37, 161] -> 
             RGBColor[
              0.21411146518921928`, 0.3423751037378088, 0.9355047032417743], 
             UndirectedEdge[3, 162] -> 
             RGBColor[
              0.972783323199716, 0.9780335099161923, 0.8777127544589929], 
             UndirectedEdge[107, 274] -> 
             RGBColor[
              0.43576092708699476`, 0.5515917926842843, 0.9490602651560203], 
             UndirectedEdge[6, 147] -> 
             RGBColor[
              0.2119963836374878, 0.34015201892302305`, 0.935384252476386], 
             UndirectedEdge[8, 135] -> 
             RGBColor[
              0.2087723681564475, 0.33676337423806185`, 0.9352006495642442], 
             UndirectedEdge[186, 249] -> 
             RGBColor[
              0.20028634308592377`, 0.3278440238438759, 0.934717382990427], 
             UndirectedEdge[277, 281] -> 
             RGBColor[
              0.9857363810754343, 0.9854586098022267, 0.7010160851792143], 
             UndirectedEdge[256, 277] -> 
             RGBColor[
              0.9054696458162683, 0.5631344019327589, 0.3227451671094582], 
             UndirectedEdge[8, 249] -> 
             RGBColor[
              0.20596246033793864`, 0.3338099829623634, 0.9350406294708662], 
             UndirectedEdge[114, 254] -> 
             RGBColor[
              0.2789569494583814, 0.4096039374484629, 0.9392315319348887], 
             UndirectedEdge[223, 270] -> 
             RGBColor[
              0.19716475878398335`, 0.32456304082266046`, 0.9345396133824015],
              UndirectedEdge[120, 294] -> 
             RGBColor[
              0.40756986398437334`, 0.5224500406559134, 0.9479120363171062], 
             UndirectedEdge[23, 290] -> 
             RGBColor[
              0.9678787961151241, 0.9075534182585008, 0.5509781065817215], 
             UndirectedEdge[7, 293] -> 
             RGBColor[
              0.9190392263270429, 0.795614649307972, 0.6136807291548138], 
             UndirectedEdge[95, 191] -> 
             RGBColor[
              0.2574665501142888, 0.38794404686520834`, 0.9379737111901566], 
             UndirectedEdge[65, 194] -> 
             RGBColor[
              0.5317344651989768, 0.6279967791452647, 0.9573054453238024], 
             UndirectedEdge[94, 188] -> 
             RGBColor[
              0.5763766141360973, 0.661954233683196, 0.9621432156948482], 
             UndirectedEdge[24, 162] -> 
             RGBColor[
              0.9575561451976635, 0.8630735261690534, 0.5252809551641785], 
             UndirectedEdge[34, 84] -> 
             RGBColor[
              0.1855804331499768, 0.3123871800926523, 0.9338799031750189], 
             UndirectedEdge[130, 201] -> 
             RGBColor[
              0.8785836373176991, 0.5188649537574892, 0.21948349310732407`], 
             UndirectedEdge[74, 260] -> 
             RGBColor[
              0.23203447362151203`, 0.3612133219845175, 0.9365253920572785], 
             UndirectedEdge[69, 85] -> 
             RGBColor[
              0.21985867650040533`, 0.3484157872201088, 0.9358319984237091], 
             UndirectedEdge[220, 262] -> 
             RGBColor[
              0.318464636651424, 0.44980618598534605`, 0.9415298717668166], 
             UndirectedEdge[26, 262] -> 
             RGBColor[
              0.26646771810795733`, 0.39740484513356716`, 0.9384863143913613],
              UndirectedEdge[217, 270] -> 
             RGBColor[
              0.20643869531729672`, 0.3343105361207104, 0.9350677503484142], 
             UndirectedEdge[221, 245] -> 
             RGBColor[
              0.20571905261194073`, 0.33355414600939837`, 0.93502676776096], 
             UndirectedEdge[3, 24] -> 
             RGBColor[
              0.9389911914260977, 0.8504167316496911, 0.6099487388884464], 
             UndirectedEdge[59, 197] -> 
             RGBColor[
              0.9856746989571257, 0.9883441341223966, 0.8870708411785275], 
             UndirectedEdge[54, 235] -> 
             RGBColor[
              0.32626536687632174`, 0.4510335953926109, 0.9422293781681247], 
             UndirectedEdge[159, 282] -> 
             RGBColor[
              0.36593647358390397`, 0.4897590384287621, 0.9445973867147164], 
             UndirectedEdge[6, 53] -> 
             RGBColor[
              0.21323620369391516`, 0.3414551484114601, 0.9354548583944501], 
             UndirectedEdge[31, 210] -> 
             RGBColor[
              0.4456637990054052, 0.5599347702274033, 0.949756030710805], 
             UndirectedEdge[137, 273] -> 
             RGBColor[
              0.25023215692458567`, 0.3803402409358096, 0.9375617232003286], 
             UndirectedEdge[99, 259] -> 
             RGBColor[
              0.19041774683741108`, 0.3174715034815479, 0.934155381033354], 
             UndirectedEdge[16, 151] -> 
             RGBColor[
              0.42230921801132515`, 0.5305527441172178, 0.9494240400554605], 
             UndirectedEdge[24, 227] -> 
             RGBColor[
              0.9382342504393061, 0.7928264157474236, 0.2691600319562284], 
             UndirectedEdge[87, 202] -> 
             RGBColor[
              0.9298593928281911, 0.7373816975657997, 0.35298070205443455`], 
             UndirectedEdge[17, 94] -> 
             RGBColor[
              0.7502759773076164, 0.8048405628721153, 0.9757441557565323], 
             UndirectedEdge[5, 92] -> 
             RGBColor[
              0.9012836886352362, 0.5787149390499657, 0.259870153785709], 
             UndirectedEdge[72, 290] -> 
             RGBColor[
              0.8879131967834442, 0.526174959102152, 0.22577038316322898`], 
             UndirectedEdge[103, 212] -> 
             RGBColor[
              0.327349136755672, 0.45098594966848016`, 0.9423345502314089], 
             UndirectedEdge[112, 133] -> 
             RGBColor[
              0.18726032665159403`, 0.3141528546742519, 0.9339755706247563], 
             UndirectedEdge[71, 244] -> 
             RGBColor[
              0.20641030875985014`, 0.33428070004902233`, 0.9350661337759618],
              UndirectedEdge[142, 197] -> 
             RGBColor[
              0.9081386520820702, 0.6098618084907887, 0.5261581856832962], 
             UndirectedEdge[117, 196] -> 
             RGBColor[
              0.1942847722586868, 0.32153599238288155`, 0.9343756024103442], 
             UndirectedEdge[131, 188] -> 
             RGBColor[
              0.2926361203769149, 0.4205530757547836, 0.9401360760402346], 
             UndirectedEdge[13, 282] -> 
             RGBColor[
              0.38696044305919663`, 0.509587419405664, 0.9458777551494157], 
             UndirectedEdge[139, 143] -> 
             RGBColor[
              0.37380885559171856`, 0.49802499695333824`, 0.9450460153054621],
              UndirectedEdge[45, 89] -> 
             RGBColor[
              0.34033954683031736`, 0.4683920819989782, 0.9429369415722573], 
             UndirectedEdge[127, 269] -> 
             RGBColor[
              0.6610000720463691, 0.698853165460656, 0.646849788175898], 
             UndirectedEdge[25, 79] -> 
             RGBColor[
              0.18712823581077753`, 0.3140140188255107, 0.9339680482467827], 
             UndirectedEdge[29, 78] -> 
             RGBColor[
              0.1946932984138494, 0.3219653792740117, 0.9343988673705204], 
             UndirectedEdge[150, 179] -> 
             RGBColor[
              0.7150830892215184, 0.6470263643951079, 0.5999650595216117], 
             UndirectedEdge[11, 198] -> 
             RGBColor[
              0.7482029346182517, 0.8019514484742061, 0.9505539165512161], 
             UndirectedEdge[135, 286] -> 
             RGBColor[
              0.2169836251808333, 0.34539392599445645`, 0.9356682685043168], 
             UndirectedEdge[101, 104] -> 
             RGBColor[
              0.49120791951509923`, 0.5945373978105576, 0.9540278714950781], 
             UndirectedEdge[3, 290] -> 
             RGBColor[
              0.9503146533364857, 0.8953104848043834, 0.619059862137357], 
             UndirectedEdge[158, 212] -> 
             RGBColor[
              0.21315714444874106`, 0.34137205213213645`, 0.9354503560873951],
              UndirectedEdge[102, 175] -> 
             RGBColor[
              0.18740197098760464`, 0.3143017318521686, 0.9339836370601481], 
             UndirectedEdge[103, 255] -> 
             RGBColor[
              0.3936737549660358, 0.5154021527585007, 0.9463055214477708], 
             UndirectedEdge[3, 65] -> 
             RGBColor[
              0.6658408786786703, 0.7333691314923763, 0.9538265746888542], 
             UndirectedEdge[148, 270] -> 
             RGBColor[
              0.22956819937889494`, 0.35862111138470837`, 0.9363849413876872],
              UndirectedEdge[49, 298] -> 
             RGBColor[
              0.23487979924778435`, 0.36420393962179404`, 0.9366874291424127],
              UndirectedEdge[15, 103] -> 
             RGBColor[
              0.33985285455084013`, 0.464128149852699, 0.9430466184622509], 
             UndirectedEdge[4, 15] -> 
             RGBColor[
              0.23945687025241685`, 0.36901473145072583`, 0.9369480865649568],
              UndirectedEdge[83, 290] -> 
             RGBColor[
              0.8964817615318641, 0.5920367025275223, 0.23397565044312565`], 
             UndirectedEdge[182, 284] -> 
             RGBColor[
              0.24765066246750966`, 0.3776269265852207, 0.937414710909977], 
             UndirectedEdge[32, 92] -> 
             RGBColor[
              0.9096154260623872, 0.6163602690310206, 0.515875760055398], 
             UndirectedEdge[87, 203] -> 
             RGBColor[
              0.9651365709425674, 0.970190636874684, 0.7434503562978652], 
             UndirectedEdge[115, 169] -> 
             RGBColor[
              0.47823384946439584`, 0.5845324223560975, 0.9528296173993749], 
             UndirectedEdge[111, 143] -> 
             RGBColor[
              0.46054913753176646`, 0.5687866450741914, 0.9517800380473413], 
             UndirectedEdge[163, 274] -> 
             RGBColor[
              0.5420984734158494, 0.6391389878337358, 0.9570951240808855], 
             UndirectedEdge[96, 260] -> 
             RGBColor[
              0.22955901197049378`, 0.3586114548359634, 0.9363844181783704], 
             UndirectedEdge[27, 227] -> 
             RGBColor[
              0.9612729955532987, 0.8800632676191081, 0.309071745135731], 
             UndirectedEdge[103, 205] -> 
             RGBColor[
              0.39684467535749024`, 0.5181486446264856, 0.9465075696911796], 
             UndirectedEdge[27, 216] -> 
             RGBColor[
              0.9181526107527858, 0.6982276036287391, 0.27381337883344126`], 
             UndirectedEdge[145, 293] -> 
             RGBColor[
              0.8823313146508039, 0.7664123372275902, 0.6125225465194646], 
             UndirectedEdge[96, 133] -> 
             RGBColor[
              0.19311989172231955`, 0.3203116290814677, 0.9343092641870845], 
             UndirectedEdge[127, 159] -> 
             RGBColor[
              0.3200380232724909, 0.45000410769220556`, 0.9416727780472791], 
             UndirectedEdge[186, 214] -> 
             RGBColor[
              0.19697318905997124`, 0.32436168889650174`, 0.9345287037700212],
              UndirectedEdge[111, 262] -> 
             RGBColor[
              0.459021775002635, 0.5671812902156966, 0.9516930570108376], 
             UndirectedEdge[33, 157] -> 
             RGBColor[
              0.19152225944429985`, 0.31863241626153205`, 0.9342182813923363],
              UndirectedEdge[112, 131] -> 
             RGBColor[
              0.20931958090363292`, 0.3373385295306458, 0.9352318125206677], 
             UndirectedEdge[37, 55] -> 
             RGBColor[
              0.21435260419714997`, 0.34262855612424004`, 0.9355184357515427],
              UndirectedEdge[20, 71] -> 
             RGBColor[
              0.22116050761720274`, 0.349784094264723, 0.9359061357799242], 
             UndirectedEdge[37, 252] -> 
             RGBColor[
              0.23225528127463596`, 0.3614454048279645, 0.9365379667264683], 
             UndirectedEdge[120, 178] -> 
             RGBColor[
              0.2690508208241996, 0.4001198498665095, 0.9386334182696933], 
             UndirectedEdge[113, 231] -> 
             RGBColor[
              0.24940666839475117`, 0.3794726001519578, 0.9375147128497554], 
             UndirectedEdge[7, 181] -> 
             RGBColor[
              0.962306825108859, 0.9594739836095195, 0.6952739648323978], 
             UndirectedEdge[42, 299] -> 
             RGBColor[
              0.8281493166036277, 0.217373559290479, 0.1745891234107269], 
             UndirectedEdge[64, 234] -> 
             RGBColor[
              0.2147298520602665, 0.3430250675472716, 0.9355399194592591], 
             UndirectedEdge[78, 261] -> 
             RGBColor[
              0.21943392399577888`, 0.3479693454068822, 0.9358078093969358], 
             UndirectedEdge[10, 100] -> 
             RGBColor[
              0.18553288790448116`, 0.3123372070250937, 0.9338771955436248], 
             UndirectedEdge[6, 88] -> 
             RGBColor[
              0.21672673573205908`, 0.345123918896063, 0.935653639030243], 
             UndirectedEdge[36, 208] -> 
             RGBColor[
              0.1853248284213402, 0.31211852331657947`, 0.9338653468638564], 
             UndirectedEdge[92, 142] -> 
             RGBColor[
              0.830745140796793, 0.23732620153656223`, 0.1770748875896661], 
             UndirectedEdge[237, 293] -> 
             RGBColor[
              0.8624167150274014, 0.41572511198283674`, 0.2048567143114029], 
             UndirectedEdge[127, 145] -> 
             RGBColor[
              0.6068695545086966, 0.6858400847036329, 0.9652124739672545], 
             UndirectedEdge[90, 285] -> 
             RGBColor[
              0.20767787323688183`, 0.3356129906826123, 0.9351383196977351], 
             UndirectedEdge[134, 176] -> 
             RGBColor[
              0.21949584805110617`, 0.34803443151524305`, 0.9358113358802782],
              UndirectedEdge[28, 297] -> 
             RGBColor[
              0.18773159769962583`, 0.31464819042604353`, 0.9340024088137586],
              UndirectedEdge[20, 136] -> 
             RGBColor[
              0.3058098324986471, 0.43100159391667037`, 0.9410107128012115], 
             UndirectedEdge[113, 134] -> 
             RGBColor[
              0.25621583264175446`, 0.38662946350150684`, 0.9379024846803665],
              UndirectedEdge[12, 181] -> 
             RGBColor[
              0.707957046702949, 0.7559827796524516, 0.6749255302079116], 
             UndirectedEdge[84, 217] -> 
             RGBColor[
              0.19375308221906778`, 0.32097715244014635`, 0.9343453234491528],
              UndirectedEdge[126, 153] -> 
             RGBColor[
              0.2222787641449363, 0.35095945277692997`, 0.9359698188348664], 
             UndirectedEdge[217, 251] -> 
             RGBColor[
              0.24282276767362948`, 0.3725525030506428, 0.9371397694436958], 
             UndirectedEdge[211, 266] -> 
             RGBColor[
              0.23444123912717205`, 0.36374298512871284`, 0.9366624537923354],
              UndirectedEdge[156, 282] -> 
             RGBColor[
              0.41756183526404816`, 0.5360928072628128, 0.9478276488009602], 
             UndirectedEdge[92, 256] -> 
             RGBColor[
              0.8247413968754788, 0.1911787948999799, 0.17132569563035674`], 
             UndirectedEdge[56, 246] -> 
             RGBColor[
              0.1919032518459413, 0.3190328634319706, 0.934239978345982], 
             UndirectedEdge[223, 246] -> 
             RGBColor[
              0.1829700916045353, 0.3096435456231802, 0.9337312480856603], 
             UndirectedEdge[66, 228] -> 
             RGBColor[
              0.40629940527691566`, 0.5263378564741489, 0.9471100167211559], 
             UndirectedEdge[170, 261] -> 
             RGBColor[
              0.22115645505495063`, 0.3497798347648488, 0.9359059049924991], 
             UndirectedEdge[104, 287] -> 
             RGBColor[
              0.2890443879522816, 0.41869887568726627`, 0.9398611972259145], 
             UndirectedEdge[255, 258] -> 
             RGBColor[
              0.3530896957607064, 0.48025028048897034`, 0.9437195410822816], 
             UndirectedEdge[27, 162] -> 
             RGBColor[
              0.9805948903116561, 0.9503103780407378, 0.565192668343681], 
             UndirectedEdge[162, 169] -> 
             RGBColor[
              0.7980436197485294, 0.8403418316253028, 0.877535691789008], 
             UndirectedEdge[90, 166] -> 
             RGBColor[
              0.20088523531551122`, 0.3284734975491328, 0.9347514890169203], 
             UndirectedEdge[74, 257] -> 
             RGBColor[
              0.19498858899920085`, 0.3222757484017205, 0.9344156837325129], 
             UndirectedEdge[82, 203] -> 
             RGBColor[
              0.7752823706628642, 0.824842772704185, 0.9770131806255582], 
             UndirectedEdge[1, 142] -> 
             RGBColor[
              0.8243144987265323, 0.1878974686592162, 0.17091689748081318`], 
             UndirectedEdge[82, 145] -> 
             RGBColor[
              0.7391717561435251, 0.7960859238654349, 0.9748439297036255], 
             UndirectedEdge[77, 203] -> 
             RGBColor[
              0.6754538924070363, 0.7427240405564789, 0.9694509218275109], 
             UndirectedEdge[12, 27] -> 
             RGBColor[
              0.6997308165084448, 0.7282337735956864, 0.6429681792954851], 
             UndirectedEdge[54, 185] -> 
             RGBColor[
              0.3867966632124244, 0.5013927095080272, 0.9466583404851183], 
             UndirectedEdge[35, 165] -> 
             RGBColor[
              0.2120938524489715, 0.3402544648237721, 0.9353898031810077], 
             UndirectedEdge[60, 95] -> 
             RGBColor[
              0.28741190007160666`, 0.4194185083151971, 0.9396790545700505], 
             UndirectedEdge[47, 112] -> 
             RGBColor[
              0.18666547155784385`, 0.31352762425472913`, 0.9339416945071765],
              UndirectedEdge[24, 59] -> 
             RGBColor[
              0.9543858496571156, 0.8617625274901577, 0.5778209567329167], 
             UndirectedEdge[239, 285] -> 
             RGBColor[
              0.21862787921736482`, 0.3471221412385783, 0.9357619063392415], 
             UndirectedEdge[173, 286] -> 
             RGBColor[
              0.2110888425781487, 0.3391981357282311, 0.9353325693556434], 
             UndirectedEdge[17, 40] -> 
             RGBColor[
              0.6964483919711273, 0.7627900441024493, 0.9703791250975754], 
             UndirectedEdge[226, 241] -> 
             RGBColor[
              0.9861906717339419, 0.9885575021255057, 0.8785198369719385], 
             UndirectedEdge[255, 286] -> 
             RGBColor[
              0.2934543066453184, 0.4204742848621239, 0.9402170430132455], 
             UndirectedEdge[95, 271] -> 
             RGBColor[
              0.25509580298829937`, 0.3854522413217438, 0.9378387006485376], 
             UndirectedEdge[189, 260] -> 
             RGBColor[
              0.23700170640282697`, 0.36643419857842796`, 0.936808268615812], 
             UndirectedEdge[193, 245] -> 
             RGBColor[
              0.2524031222436139, 0.38262206313325964`, 0.9376853564635919], 
             UndirectedEdge[84, 223] -> 
             RGBColor[
              0.1844791456857544, 0.31122965714209644`, 0.9338171864831403], 
             UndirectedEdge[44, 61] -> 
             RGBColor[
              0.29673927658547317`, 0.4285312134624696, 0.9402355342561197], 
             UndirectedEdge[262, 292] -> 
             RGBColor[
              0.5387777053242508, 0.6299185321853173, 0.9593474985432611], 
             UndirectedEdge[153, 248] -> 
             RGBColor[
              0.2215139470361167, 0.3501555815033551, 0.9359262636319645], 
             UndirectedEdge[78, 99] -> 
             RGBColor[
              0.19490280134245708`, 0.32218558013523124`, 0.9344107982523728],
              UndirectedEdge[199, 261] -> 
             RGBColor[
              0.22156560326703745`, 0.35020987547724697`, 0.9359292053778969],
              UndirectedEdge[58, 215] -> 
             RGBColor[
              0.20794131603506694`, 0.33588988576674306`, 0.935153322375363], 
             UndirectedEdge[23, 197] -> 
             RGBColor[
              0.9878441835047461, 0.9892412717360475, 0.8511168677784218], 
             UndirectedEdge[196, 214] -> 
             RGBColor[
              0.20194505297188817`, 0.32958743310230554`, 0.9348118440645912],
              UndirectedEdge[88, 289] -> 
             RGBColor[
              0.23315152394890182`, 0.3623874127036856, 0.9365890064208955], 
             UndirectedEdge[47, 96] -> 
             RGBColor[
              0.19252503662856937`, 0.3196863986619449, 0.9342753880695046], 
             UndirectedEdge[179, 205] -> 
             RGBColor[
              0.44755823847840226`, 0.5601887588135859, 0.9502599417033248], 
             UndirectedEdge[72, 194] -> 
             RGBColor[
              0.7577104993954153, 0.4908688373474871, 0.5725699298440808], 
             UndirectedEdge[140, 299] -> 
             RGBColor[
              0.8180064493920196, 0.1394110372693064, 0.16487630231416095`], 
             UndirectedEdge[134, 297] -> 
             RGBColor[
              0.21839610407426302`, 0.3468785308677854, 0.9357487070877224], 
             UndirectedEdge[67, 195] -> 
             RGBColor[
              0.18132553855698572`, 0.30791501609952, 0.9336375932225005], 
             UndirectedEdge[24, 155] -> 
             RGBColor[
              0.9250389254998768, 0.7405113494439601, 0.2585427637758789], 
             UndirectedEdge[156, 277] -> 
             RGBColor[
              0.6937513555235839, 0.7517852121341029, 0.7135233421024703], 
             UndirectedEdge[267, 272] -> 
             RGBColor[
              0.18764714248222777`, 0.31455942263778813`, 0.9339975992140681],
              UndirectedEdge[71, 177] -> 
             RGBColor[
              0.2576442825267533, 0.3881308548995943, 0.9379838327881149], 
             UndirectedEdge[188, 281] -> 
             RGBColor[
              0.66716299452805, 0.7330554302274623, 0.9326197293964239], 
             UndirectedEdge[1, 150] -> 
             RGBColor[
              0.8630514097518487, 0.4076537466466897, 0.20494588861929658`], 
             UndirectedEdge[84, 246] -> 
             RGBColor[
              0.1859588657451276, 0.3127849367441682, 0.9339014543514719], 
             UndirectedEdge[58, 230] -> 
             RGBColor[
              0.19161321755920613`, 0.31872801900737613`, 0.9342234613224198],
              UndirectedEdge[74, 189] -> 
             RGBColor[
              0.21086862151855923`, 0.33896666943178094`, 0.9353200280920875],
              UndirectedEdge[48, 71] -> 
             RGBColor[
              0.2080633650262977, 0.3360181669948795, 0.9351602728848583], 
             UndirectedEdge[80, 205] -> 
             RGBColor[
              0.6755840605748524, 0.7185594638345996, 0.6585612536692309], 
             UndirectedEdge[1, 32] -> 
             RGBColor[
              0.9031847839921265, 0.5669315361536746, 0.5097177699465452], 
             UndirectedEdge[229, 233] -> 
             RGBColor[
              0.2115539796555496, 0.3396870242879735, 0.9353590582240927], 
             UndirectedEdge[54, 172] -> 
             RGBColor[
              0.21731047913351847`, 0.34573747022246615`, 0.935686882353385], 
             UndirectedEdge[61, 194] -> 
             RGBColor[
              0.4816323907254858, 0.581689714248477, 0.9542195774968412], 
             UndirectedEdge[177, 194] -> 
             RGBColor[
              0.4889886310377472, 0.5894215892292383, 0.9546385045000421], 
             UndirectedEdge[7, 42] -> 
             RGBColor[
              0.8879622102999478, 0.6217857737509664, 0.5864682520402187], 
             UndirectedEdge[26, 75] -> 
             RGBColor[
              0.28101248706842963`, 0.4104564015750206, 0.9393964853748475], 
             UndirectedEdge[170, 190] -> 
             RGBColor[
              0.2009954787857768, 0.3285893704262217, 0.9347577672194614], 
             UndirectedEdge[20, 36] -> 
             RGBColor[
              0.200168643680248, 0.32772031430593734`, 0.9347106801833944], 
             UndirectedEdge[119, 161] -> 
             RGBColor[
              0.191253116488521, 0.3183495299503595, 0.9342029540991661], 
             UndirectedEdge[212, 225] -> 
             RGBColor[
              0.23048263283804543`, 0.3595822389287055, 0.9364370170204028], 
             UndirectedEdge[102, 253] -> 
             RGBColor[
              0.1920226425007294, 0.3191583505799577, 0.9342467774671497], 
             UndirectedEdge[91, 179] -> 
             RGBColor[
              0.5064577791876668, 0.6102042666643193, 0.9542893580750782], 
             UndirectedEdge[118, 239] -> 
             RGBColor[
              0.213148543369447, 0.34136301185245843`, 0.9354498662686535], 
             UndirectedEdge[105, 298] -> 
             RGBColor[
              0.27198901083979987`, 0.403208073864912, 0.938800743844419], 
             UndirectedEdge[90, 239] -> 
             RGBColor[
              0.2266260849573989, 0.3555287625868876, 0.9362173923238513], 
             UndirectedEdge[208, 252] -> 
             RGBColor[
              0.21362941037883332`, 0.3418684335680528, 0.935477250933459], 
             UndirectedEdge[117, 214] -> 
             RGBColor[
              0.19317010459047246`, 0.32036440598957616`, 0.9343121237356424],
              UndirectedEdge[179, 282] -> 
             RGBColor[
              0.48169445553417334`, 0.5897558342911382, 0.9524350712686471], 
             UndirectedEdge[44, 268] -> 
             RGBColor[
              0.2606344226816996, 0.39058272282964934`, 0.9381794162386446], 
             UndirectedEdge[53, 124] -> 
             RGBColor[
              0.20090092998575032`, 0.32848999364265374`, 0.9347523828051723],
              UndirectedEdge[42, 81] -> 
             RGBColor[
              0.8635348143848929, 0.4405098850237444, 0.2065613896917941], 
             UndirectedEdge[173, 213] -> 
             RGBColor[
              0.20183100425593847`, 0.3294675606707361, 0.9348053491589379], 
             UndirectedEdge[119, 122] -> 
             RGBColor[
              0.18294597115910344`, 0.30961819350570674`, 0.933729874461976], 
             UndirectedEdge[68, 111] -> 
             RGBColor[
              0.7455301616880299, 0.8011614727150247, 0.9754440364810864], 
             UndirectedEdge[34, 53] -> 
             RGBColor[
              0.1997851700209307, 0.32731725917636056`, 0.9346888419257947], 
             UndirectedEdge[85, 263] -> 
             RGBColor[
              0.22101888131475306`, 0.34963523604122215`, 0.9358980703715171],
              UndirectedEdge[37, 208] -> 
             RGBColor[
              0.20794241016561682`, 0.3358910357673228, 0.9351533846844792], 
             UndirectedEdge[256, 293] -> 
             RGBColor[
              0.8588434353874268, 0.38825931884886955`, 0.2014349376927211], 
             UndirectedEdge[76, 153] -> 
             RGBColor[
              0.27399346070364045`, 0.40363477490679034`, 0.9389764110945367],
              UndirectedEdge[135, 213] -> 
             RGBColor[
              0.20772578685862308`, 0.3356633509369615, 0.9351410483076115], 
             UndirectedEdge[36, 55] -> 
             RGBColor[
              0.19173502245287335`, 0.3188560436734967, 0.9342303979309199], 
             UndirectedEdge[121, 135] -> 
             RGBColor[
              0.21926297732246688`, 0.3477896696145861, 0.9357980742367835], 
             UndirectedEdge[83, 226] -> 
             RGBColor[
              0.9164048612065285, 0.6737070689481892, 0.5348152285137735], 
             UndirectedEdge[60, 127] -> 
             RGBColor[
              0.3180513290021859, 0.44791596605042294`, 0.941559638747636], 
             UndirectedEdge[247, 271] -> 
             RGBColor[
              0.21019581629378764`, 0.33825950848223085`, 0.9352817128298629],
              UndirectedEdge[202, 269] -> 
             RGBColor[
              0.9198678167668363, 0.7040758695857129, 0.2803134075037528], 
             UndirectedEdge[190, 284] -> 
             RGBColor[
              0.22268610341343767`, 0.3513875921749262, 0.9359930162036031], 
             UndirectedEdge[53, 217] -> 
             RGBColor[
              0.2079578190900217, 0.3359072315238546, 0.9351542621999286], 
             UndirectedEdge[42, 87] -> 
             RGBColor[
              0.915376392222736, 0.6389023704076946, 0.3396146781641949], 
             UndirectedEdge[205, 225] -> 
             RGBColor[
              0.29997817143986366`, 0.426744933886711, 0.9406100364801734], 
             UndirectedEdge[110, 246] -> 
             RGBColor[
              0.18518351558803503`, 0.3119699945690246, 0.9338572993070533], 
             UndirectedEdge[191, 251] -> 
             RGBColor[
              0.25649200131600725`, 0.38691973428825177`, 0.9379182120778102],
              UndirectedEdge[23, 83] -> 
             RGBColor[
              0.917949620402167, 0.6743458665740862, 0.5092145709333941], 
             UndirectedEdge[226, 291] -> 
             RGBColor[
              0.956565980138184, 0.9665569141916783, 0.9351528422090618], 
             UndirectedEdge[60, 276] -> 
             RGBColor[
              0.26432062956564295`, 0.39514811894231855`, 0.9383640408752093],
              UndirectedEdge[27, 155] -> 
             RGBColor[
              0.9480776706138694, 0.8277482013156446, 0.2984544769553814], 
             UndirectedEdge[167, 203] -> 
             RGBColor[
              0.9224035575123126, 0.8121627962472151, 0.6179459955981152], 
             UndirectedEdge[137, 271] -> 
             RGBColor[
              0.24208469003989352`, 0.37177673666076144`, 0.9370977370143425],
              UndirectedEdge[52, 247] -> 
             RGBColor[
              0.1982447360653234, 0.3256981654198634, 0.9346011164908907], 
             UndirectedEdge[81, 299] -> 
             RGBColor[
              0.8540793965653044, 0.3678314002718782, 0.19750687090938907`], 
             UndirectedEdge[31, 290] -> 
             RGBColor[
              0.683029742131583, 0.6815722331575694, 0.6118498991600951], 
             UndirectedEdge[79, 288] -> 
             RGBColor[
              0.19600308919068352`, 0.3233420524259961, 0.9344734580175993], 
             UndirectedEdge[237, 281] -> 
             RGBColor[
              0.9017681191965876, 0.5885988435448176, 0.546493973651558], 
             UndirectedEdge[43, 215] -> 
             RGBColor[
              0.22516415254335911`, 0.35399217892786317`, 0.9361341374356069],
              UndirectedEdge[56, 295] -> 
             RGBColor[
              0.19813975131853928`, 0.3255878197945759, 0.9345951377648724], 
             UndirectedEdge[89, 94] -> 
             RGBColor[
              0.5888165791799138, 0.6727291061533267, 0.962935879267211], 
             UndirectedEdge[92, 237] -> 
             RGBColor[
              0.8283146765154534, 0.21864458803394712`, 0.17474747224903853`],
              UndirectedEdge[126, 285] -> 
             RGBColor[
              0.21158401439278246`, 0.3397185927011176, 0.9353607686579457], 
             UndirectedEdge[4, 214] -> 
             RGBColor[
              0.21068402735866598`, 0.33877264926578743`, 0.9353095157277642],
              UndirectedEdge[220, 222] -> 
             RGBColor[
              0.2772575054008418, 0.4064948783579615, 0.9391831866025837], 
             UndirectedEdge[199, 209] -> 
             RGBColor[
              0.1894252090832627, 0.31642828337140966`, 0.9340988574765833], 
             UndirectedEdge[290, 291] -> 
             RGBColor[
              0.9366428804635196, 0.8848865477710113, 0.6343132641384139], 
             UndirectedEdge[91, 150] -> 
             RGBColor[
              0.6987841041568563, 0.6337941140587057, 0.5986819437121721], 
             UndirectedEdge[60, 148] -> 
             RGBColor[
              0.2667823322730826, 0.39773552456880407`, 0.9385042312026353], 
             UndirectedEdge[81, 140] -> 
             RGBColor[
              0.8533919471732848, 0.3625473630025718, 0.19684856859522815`], 
             UndirectedEdge[142, 256] -> 
             RGBColor[
              0.8239318482187612, 0.18495624917796497`, 0.17055047092242953`],
              UndirectedEdge[30, 123] -> 
             RGBColor[
              0.2239498078006626, 0.3527158256093854, 0.9360649822989724], 
             UndirectedEdge[53, 289] -> 
             RGBColor[
              0.22966099191075792`, 0.3587186422190827, 0.9363902257851027], 
             UndirectedEdge[274, 289] -> 
             RGBColor[
              0.3532455749379125, 0.4740835804879391, 0.944023524585039], 
             UndirectedEdge[11, 114] -> 
             RGBColor[
              0.38547343504917886`, 0.49973179121413747`, 0.9466075727466067],
              UndirectedEdge[137, 247] -> 
             RGBColor[
              0.22964528868911577`, 0.358702137137495, 0.9363893315098609], 
             UndirectedEdge[84, 191] -> 
             RGBColor[
              0.2074223158614455, 0.3353443836777553, 0.9351237660832672], 
             UndirectedEdge[17, 120] -> 
             RGBColor[
              0.4913767245940681, 0.5895491243083159, 0.9551516880301447], 
             UndirectedEdge[126, 222] -> 
             RGBColor[
              0.22245696617283922`, 0.3511467544069171, 0.9359799671767292], 
             UndirectedEdge[184, 224] -> 
             RGBColor[
              0.20007875304145373`, 0.32762583354516883`, 0.9347055610444963],
              UndirectedEdge[278, 295] -> 
             RGBColor[
              0.1987763965986568, 0.3262569743496216, 0.9346313937717428], 
             UndirectedEdge[28, 245] -> 
             RGBColor[
              0.204356271408755, 0.33212177655953135`, 0.9349491593874928], 
             UndirectedEdge[14, 186] -> 
             RGBColor[
              0.18665492193544975`, 0.31351653593270823`, 0.9339410937217879],
              UndirectedEdge[227, 241] -> 
             RGBColor[
              0.9694143471641505, 0.9193630503950179, 0.5802122280149764], 
             UndirectedEdge[121, 154] -> 
             RGBColor[
              0.3613735298324199, 0.47852983599420473`, 0.9448593103869043], 
             UndirectedEdge[187, 230] -> 
             RGBColor[
              0.20841284593944426`, 0.3363854935929662, 0.9351801753058513], 
             UndirectedEdge[125, 277] -> 
             RGBColor[
              0.9141028296655067, 0.6294928360832908, 0.33101231371327555`], 
             UndirectedEdge[62, 158] -> 
             RGBColor[
              0.1973113364505346, 0.3247171032437667, 0.9345479607636695], 
             UndirectedEdge[20, 61] -> 
             RGBColor[
              0.248131704384919, 0.378132532140237, 0.9374421055355356], 
             UndirectedEdge[64, 258] -> 
             RGBColor[
              0.28773302970917036`, 0.41685145648958927`, 0.939803693309408], 
             UndirectedEdge[94, 294] -> 
             RGBColor[
              0.6664691166979216, 0.7377414792197128, 0.9685045040434936], 
             UndirectedEdge[125, 237] -> 
             RGBColor[
              0.8301345677866601, 0.23263306982588172`, 0.17649020218561928`],
              UndirectedEdge[267, 300] -> 
             RGBColor[
              0.210925999504364, 0.33902697733283615`, 0.935323295683496], 
             UndirectedEdge[165, 175] -> 
             RGBColor[
              0.2002014223302363, 0.3277547667453615, 0.9347125468790196], 
             UndirectedEdge[67, 263] -> 
             RGBColor[
              0.19440813626729972`, 0.3216656557776636, 0.934382627808134], 
             UndirectedEdge[163, 298] -> 
             RGBColor[
              0.44064408929894633`, 0.5470342917552059, 0.9507221073701924], 
             UndirectedEdge[92, 149] -> 
             RGBColor[
              0.8635292482964012, 0.4309688829157785, 0.2061841331747976], 
             UndirectedEdge[95, 276] -> 
             RGBColor[
              0.2644651178260697, 0.3952999852651118, 0.9383722692678894], 
             UndirectedEdge[70, 231] -> 
             RGBColor[
              0.2204752799716199, 0.3490638765632734, 0.9358671130792118], 
             UndirectedEdge[239, 263] -> 
             RGBColor[
              0.22373268173624067`, 0.3524876123490904, 0.9360526172908128], 
             UndirectedEdge[116, 204] -> 
             RGBColor[
              0.38548007982804805`, 0.5055047110221348, 0.9460830998243401], 
             UndirectedEdge[121, 258] -> 
             RGBColor[
              0.28280548262609156`, 0.41167229208074363`, 0.9395230767926794],
              UndirectedEdge[95, 148] -> 
             RGBColor[
              0.2669268205335093, 0.3978873908915973, 0.9385124595953154], 
             UndirectedEdge[60, 77] -> 
             RGBColor[
              0.3505250523811867, 0.47604307306451876`, 0.9436288356859599], 
             UndirectedEdge[42, 269] -> 
             RGBColor[
              0.9053848161613813, 0.6055965424276077, 0.2669473836135131], 
             UndirectedEdge[61, 136] -> 
             RGBColor[
              0.33493736709593636`, 0.46161647957078045`, 0.9426694828062012],
              UndirectedEdge[95, 251] -> 
             RGBColor[
              0.2865818395337517, 0.41854606206103384`, 0.9396317838503843], 
             UndirectedEdge[158, 265] -> 
             RGBColor[
              0.20783074668686696`, 0.3357736703712833, 0.9351470256145558], 
             UndirectedEdge[152, 208] -> 
             RGBColor[
              0.1859180316496269, 0.31274201752076575`, 0.9338991289101417], 
             UndirectedEdge[153, 285] -> 
             RGBColor[
              0.21037441724900163`, 0.3384472294101154, 0.9352918838900459], 
             UndirectedEdge[61, 279] -> 
             RGBColor[
              0.25696298277753227`, 0.387414765666264, 0.9379450337752894], 
             UndirectedEdge[82, 168] -> 
             RGBColor[
              0.5069255349638632, 0.6091474742003642, 0.9547231011630586], 
             UndirectedEdge[4, 249] -> 
             RGBColor[
              0.21399718138461848`, 0.3422549842131616, 0.93549819494817], 
             UndirectedEdge[75, 163] -> 
             RGBColor[
              0.47703987934410275`, 0.583052656791418, 0.9528766616787626], 
             UndirectedEdge[59, 290] -> 
             RGBColor[
              0.9657093115675036, 0.9066562806448499, 0.5869320799818273], 
             UndirectedEdge[205, 251] -> 
             RGBColor[
              0.3289835017199729, 0.45723137505526373`, 0.9422618471300848], 
             UndirectedEdge[183, 224] -> 
             RGBColor[
              0.2007040206651831, 0.3282830294619655, 0.9347411691106672], 
             UndirectedEdge[170, 178] -> 
             RGBColor[
              0.228293899528688, 0.35728174144686387`, 0.9363123718963757], 
             UndirectedEdge[102, 238] -> 
             RGBColor[
              0.18981943468321613`, 0.3168426394723074, 0.9341213080412961], 
             UndirectedEdge[89, 236] -> 
             RGBColor[
              0.30608763983959875`, 0.4323911560553985, 0.9409863461402914], 
             UndirectedEdge[65, 231] -> 
             RGBColor[
              0.30432205873480145`, 0.4308387652063516, 0.9408746918946544], 
             UndirectedEdge[25, 245] -> 
             RGBColor[
              0.2081790637788683, 0.33613977371955583`, 0.9351668617576563], 
             UndirectedEdge[217, 223] -> 
             RGBColor[
              0.19076430807847547`, 0.31783576131915836`, 0.9341751171833412],
              UndirectedEdge[254, 283] -> 
             RGBColor[
              0.3123013068939945, 0.44465097126766145`, 0.9411304437622906], 
             UndirectedEdge[168, 205] -> 
             RGBColor[
              0.3863855665846765, 0.5090894902975664, 0.9458411245288025], 
             UndirectedEdge[142, 243] -> 
             RGBColor[
              0.9086765502085565, 0.610084243189442, 0.517243821691691], 
             UndirectedEdge[57, 278] -> 
             RGBColor[
              0.19015282278651957`, 0.31719305150690597`, 0.9341402940005757],
              UndirectedEdge[185, 218] -> 
             RGBColor[
              0.7483730046735189, 0.8020037075647066, 0.948265724399384], 
             UndirectedEdge[16, 248] -> 
             RGBColor[
              0.23437455245828825`, 0.36367289321153695`, 0.9366586560851965],
              UndirectedEdge[184, 275] -> 
             RGBColor[
              0.18583227383419235`, 0.31265188061938454`, 0.9338942451294201],
              UndirectedEdge[127, 191] -> 
             RGBColor[
              0.28810597904486807`, 0.41644150460043405`, 0.9398542953677421],
              UndirectedEdge[33, 153] -> 
             RGBColor[
              0.21078779737820008`, 0.338881718135717, 0.9353154252768627], 
             UndirectedEdge[83, 243] -> 
             RGBColor[
              0.9169850470479723, 0.6739469907037223, 0.5252000476482207], 
             UndirectedEdge[94, 281] -> 
             RGBColor[
              0.8876751944238266, 0.9123560617360518, 0.9508666014010566], 
             UndirectedEdge[140, 293] -> 
             RGBColor[
              0.8585388832387033, 0.3859183975781782, 0.20114329821116103`], 
             UndirectedEdge[126, 220] -> 
             RGBColor[
              0.27828890051671973`, 0.40757894001897654`, 0.9392419230286206],
              UndirectedEdge[76, 220] -> 
             RGBColor[
              0.3300035970754238, 0.4602542621488369, 0.942248515288291], 
             UndirectedEdge[90, 126] -> 
             RGBColor[
              0.2195822201328165, 0.34812521404942687`, 0.9358162546425555], 
             UndirectedEdge[35, 102] -> 
             RGBColor[
              0.19929440110633984`, 0.32680142993057915`, 0.9346608933621363],
              UndirectedEdge[105, 235] -> 
             RGBColor[
              0.34616703863432685`, 0.47195151424914406`, 0.9433627489328582],
              UndirectedEdge[21, 287] -> 
             RGBColor[
              0.21828938866019382`, 0.34676636620145074`, 0.9357426298027625],
              UndirectedEdge[160, 245] -> 
             RGBColor[
              0.2105034515043503, 0.33858285259373117`, 0.935299232199999], 
             UndirectedEdge[235, 298] -> 
             RGBColor[
              0.33431581918328446`, 0.4594951311953859, 0.9426878395174293], 
             UndirectedEdge[15, 196] -> 
             RGBColor[
              0.23071789586563907`, 0.35982951528724394`, 0.9364504149017838],
              UndirectedEdge[13, 274] -> 
             RGBColor[
              0.3981676494624695, 0.5190303850989934, 0.9466648547482157], 
             UndirectedEdge[2, 172] -> 
             RGBColor[
              0.19458761473709335`, 0.321854299029009, 0.9343928488414741], 
             UndirectedEdge[247, 295] -> 
             RGBColor[
              0.1973396127760572, 0.3247468234547135, 0.9345495710585769], 
             UndirectedEdge[159, 225] -> 
             RGBColor[
              0.2594187152635208, 0.38999589621147046`, 0.9380848841074358], 
             UndirectedEdge[204, 254] -> 
             RGBColor[
              0.40119508956919725`, 0.5210943009518455, 0.9470120206751078], 
             UndirectedEdge[61, 252] -> 
             RGBColor[
              0.2576007602350303, 0.3880851102115208, 0.9379813542579867], 
             UndirectedEdge[4, 173] -> 
             RGBColor[
              0.21091230660044274`, 0.33901258522263467`, 0.9353225158928745],
              UndirectedEdge[230, 245] -> 
             RGBColor[
              0.20866400795240445`, 0.3366494807931788, 0.9351944786109285], 
             UndirectedEdge[137, 295] -> 
             RGBColor[
              0.2292284865221631, 0.35826405163324404`, 0.9363655952430565], 
             UndirectedEdge[109, 192] -> 
             RGBColor[
              0.6617142280646152, 0.7260405303844142, 0.8555444013688691], 
             UndirectedEdge[178, 229] -> 
             RGBColor[
              0.23836184028178953`, 0.36786378552268634`, 0.9368857262280812],
              UndirectedEdge[91, 93] -> 
             RGBColor[
              0.3656444287828603, 0.48387268995411137`, 0.9450248073537576], 
             UndirectedEdge[143, 185] -> 
             RGBColor[
              0.41822549913320267`, 0.5344264087640556, 0.9484481661960105], 
             UndirectedEdge[139, 273] -> 
             RGBColor[
              0.3398266519904991, 0.46230754637230465`, 0.9431107790825377], 
             UndirectedEdge[130, 281] -> 
             RGBColor[
              0.9451323785335899, 0.8357466481470239, 0.5846180445889815], 
             UndirectedEdge[220, 248] -> 
             RGBColor[
              0.27752408340790014`, 0.40677506874540165`, 0.9391983678257189],
              UndirectedEdge[88, 273] -> 
             RGBColor[
              0.23089430452924603`, 0.3600149319776501, 0.936460461114203], 
             UndirectedEdge[24, 218] -> 
             RGBColor[
              0.945476791560533, 0.8552536816107574, 0.5989703095762722], 
             UndirectedEdge[66, 215] -> 
             RGBColor[
              0.3055417316872413, 0.4312998537559559, 0.940974206355727], 
             UndirectedEdge[151, 154] -> 
             RGBColor[
              0.5475628360948273, 0.6435752036232633, 0.9575252987275946], 
             UndirectedEdge[8, 64] -> 
             RGBColor[
              0.21988638356939655`, 0.34844490910634823`, 0.9358335763002992],
              UndirectedEdge[71, 108] -> 
             RGBColor[
              0.23200115605283045`, 0.3611783031073773, 0.936523494671031], 
             UndirectedEdge[43, 182] -> 
             RGBColor[
              0.23996509971424826`, 0.36954891283871966`, 0.9369770294809499],
              UndirectedEdge[58, 297] -> 
             RGBColor[
              0.19156703343003767`, 0.3186794765593771, 0.934220831204587], 
             UndirectedEdge[46, 207] -> 
             RGBColor[
              0.1949982416588687, 0.3222858939590454, 0.9344162334372013], 
             UndirectedEdge[100, 266] -> 
             RGBColor[
              0.1894062944527255, 0.3164084028954582, 0.9340977803163559], 
             UndirectedEdge[12, 151] -> 
             RGBColor[
              0.5137240937710055, 0.6154599354387978, 0.9550391768879118], 
             UndirectedEdge[196, 265] -> 
             RGBColor[
              0.21288778030859679`, 0.34108893334217194`, 0.9354350161981024],
              UndirectedEdge[93, 139] -> 
             RGBColor[
              0.3409266080048823, 0.4634636698846607, 0.9431734199503177], 
             UndirectedEdge[30, 104] -> 
             RGBColor[
              0.2921921290764705, 0.4220073511871032, 0.9400404564262714], 
             UndirectedEdge[85, 121] -> 
             RGBColor[
              0.22879896787362192`, 0.35781260030057205`, 0.936341134791438], 
             UndirectedEdge[79, 160] -> 
             RGBColor[
              0.1894526235362595, 0.316457097699686, 0.9341004186891254], 
             UndirectedEdge[60, 196] -> 
             RGBColor[
              0.24516356622564123`, 0.3750128307440074, 0.9372730744583317], 
             UndirectedEdge[25, 297] -> 
             RGBColor[
              0.19155439006973912`, 0.318666187586068, 0.9342201111839221], 
             UndirectedEdge[9, 133] -> 
             RGBColor[
              0.19212471165815448`, 0.3192656317359698, 0.9342525901546672], 
             UndirectedEdge[151, 192] -> 
             RGBColor[
              0.4642226762503304, 0.5725842955959759, 0.9518849903358793], 
             UndirectedEdge[45, 141] -> 
             RGBColor[
              0.2968912603514489, 0.4293819169954668, 0.9402188901145307], 
             UndirectedEdge[177, 280] -> 
             RGBColor[
              0.27699231630764354`, 0.4084668651395046, 0.9390856746890857], 
             UndirectedEdge[141, 188] -> 
             RGBColor[
              0.3248560928052687, 0.45441830964122576`, 0.9419709558048517], 
             UndirectedEdge[129, 183] -> 
             RGBColor[
              0.1909140048229797, 0.31799310208895415`, 0.9341836421914842], 
             UndirectedEdge[41, 55] -> 
             RGBColor[
              0.19536579579315563`, 0.32267221665845913`, 0.9344371651014012],
              UndirectedEdge[120, 261] -> 
             RGBColor[
              0.2619133763504623, 0.3926179431844944, 0.9382269513658168], 
             UndirectedEdge[71, 279] -> 
             RGBColor[
              0.22999178600981598`, 0.35906632779075, 0.9364090640196779], 
             UndirectedEdge[180, 230] -> 
             RGBColor[
              0.1934850620461379, 0.3206954462449366, 0.9343300600968047], 
             UndirectedEdge[106, 194] -> 
             RGBColor[
              0.7739330746560312, 0.8236601401446212, 0.9780122537987794], 
             UndirectedEdge[90, 234] -> 
             RGBColor[
              0.20491562163947707`, 0.33270968911687326`, 0.9349810135556479],
              UndirectedEdge[44, 136] -> 
             RGBColor[
              0.3544174046992013, 0.48140027523890294`, 0.9438041415217957], 
             UndirectedEdge[120, 131] -> 
             RGBColor[
              0.2542490675591432, 0.38456226869957383`, 0.93779048031848], 
             UndirectedEdge[44, 279] -> 
             RGBColor[
              0.27644302038079716`, 0.4071985613343865, 0.9390796924908837], 
             UndirectedEdge[105, 139] -> 
             RGBColor[
              0.3622816914289454, 0.48590921655384295`, 0.9443895603593033], 
             UndirectedEdge[157, 184] -> 
             RGBColor[
              0.18701393581723674`, 0.31389388228526116`, 0.9339615390312422],
              UndirectedEdge[83, 149] -> 
             RGBColor[
              0.8710281964790996, 0.48860908470804376`, 0.21336513442340005`],
              UndirectedEdge[145, 168] -> 
             RGBColor[
              0.6326576416445393, 0.7081764296337532, 0.9668556680760403], 
             UndirectedEdge[112, 170] -> 
             RGBColor[
              0.1934039006537554, 0.3206101404756131, 0.9343254380755761], 
             UndirectedEdge[159, 270] -> 
             RGBColor[
              0.2520399731872973, 0.38224037045009085`, 0.9376646756620657], 
             UndirectedEdge[86, 162] -> 
             RGBColor[
              0.7927626721159106, 0.8360545204331631, 0.8771199562466196], 
             UndirectedEdge[3, 264] -> 
             RGBColor[
              0.6252141606717125, 0.697021267014214, 0.9512803143951285], 
             UndirectedEdge[60, 282] -> 
             RGBColor[
              0.36394977931359895`, 0.4876708967869795, 0.9444842474150733], 
             UndirectedEdge[135, 186] -> 
             RGBColor[
              0.20309625090443267`, 0.3307974151195744, 0.934877403083805], 
             UndirectedEdge[89, 294] -> 
             RGBColor[
              0.4583968818459615, 0.569215720181254, 0.9510502956112238], 
             UndirectedEdge[201, 203] -> 
             RGBColor[
              0.8912445921234382, 0.6511612232387863, 0.591194505299895], 
             UndirectedEdge[181, 203] -> 
             RGBColor[
              0.961709527951959, 0.9590285203678879, 0.6962850331189814], 
             UndirectedEdge[70, 211] -> 
             RGBColor[
              0.24025127894135917`, 0.3698497053512242, 0.9369933269645696], 
             UndirectedEdge[156, 159] -> 
             RGBColor[
              0.3428661620319342, 0.4697766941100199, 0.9431273668629003], 
             UndirectedEdge[56, 270] -> 
             RGBColor[
              0.20609791902538932`, 0.3339523586314509, 0.9350483436427234], 
             UndirectedEdge[113, 264] -> 
             RGBColor[
              0.28192127958218227`, 0.41364751805536637`, 0.939366371855823], 
             UndirectedEdge[144, 240] -> 
             RGBColor[
              0.18908519234139687`, 0.31607090421740214`, 0.9340794940261437],
              UndirectedEdge[231, 232] -> 
             RGBColor[
              0.20954424282732975`, 0.33757466345683984`, 0.9352446066848648],
              UndirectedEdge[90, 248] -> 
             RGBColor[
              0.21881740302399694`, 0.347321342775852, 0.9357726994396538], 
             UndirectedEdge[27, 109] -> 
             RGBColor[
              0.9813263327288758, 0.9506128482774708, 0.5530707745780536], 
             UndirectedEdge[42, 145] -> 
             RGBColor[
              0.8512542986237088, 0.5925834616705845, 0.5853100694048696], 
             UndirectedEdge[160, 230] -> 
             RGBColor[
              0.19392496192438957`, 0.3211578089082423, 0.9343551117440977], 
             UndirectedEdge[247, 251] -> 
             RGBColor[
              0.24168185283923999`, 0.37135332922152087`, 0.9370747960317096],
              UndirectedEdge[109, 220] -> 
             RGBColor[
              0.6629503007752218, 0.7271111544395208, 0.8556231628289728], 
             UndirectedEdge[139, 163] -> 
             RGBColor[
              0.5309367698880918, 0.6297354344441368, 0.9563109238850767], 
             UndirectedEdge[31, 279] -> 
             RGBColor[
              0.32815763679560045`, 0.4519911628206914, 0.9423749021193952], 
             UndirectedEdge[9, 112] -> 
             RGBColor[
              0.19409572030031721`, 0.3213372867880486, 0.9343648361809924], 
             UndirectedEdge[196, 276] -> 
             RGBColor[
              0.22221678398010425`, 0.35089430769392205`, 0.9359662891561706],
              UndirectedEdge[137, 251] -> 
             RGBColor[
              0.27357072658534587`, 0.4048705574000514, 0.9388908202161892], 
             UndirectedEdge[162, 181] -> 
             RGBColor[
              0.9888211205061603, 0.9780593840975029, 0.5971500192561076], 
             UndirectedEdge[96, 236] -> 
             RGBColor[
              0.2161907003932258, 0.34456051176834573`, 0.9356231126106896], 
             UndirectedEdge[251, 295] -> 
             RGBColor[
              0.24126505067228732`, 0.3709152437172699, 0.9370510597649051], 
             UndirectedEdge[20, 268] -> 
             RGBColor[
              0.21202685048114545`, 0.34018404150741677`, 0.9353859875180606],
              UndirectedEdge[187, 215] -> 
             RGBColor[
              0.224740944415305, 0.35354736035233314`, 0.9361100363587946], 
             UndirectedEdge[55, 250] -> 
             RGBColor[
              0.1923953966842939, 0.31955013886086425`, 0.9342680052664631], 
             UndirectedEdge[193, 230] -> 
             RGBColor[
              0.2358246326636532, 0.3651970194477707, 0.9367412360076905], 
             UndirectedEdge[55, 242] -> 
             RGBColor[
              0.19150951150427703`, 0.318619017368302, 0.9342175554160109], 
             UndirectedEdge[51, 116] -> 
             RGBColor[
              0.5493242790295518, 0.6359329023080253, 0.960750884061716], 
             UndirectedEdge[130, 203] -> 
             RGBColor[
              0.92446413705714, 0.8203323074950271, 0.6196039862679017], 
             UndirectedEdge[34, 124] -> 
             RGBColor[
              0.1848087064384265, 0.3115760463885134, 0.9338359544804635], 
             UndirectedEdge[190, 261] -> 
             RGBColor[
              0.2245754678269734, 0.353373433966175, 0.9361006127118898], 
             UndirectedEdge[76, 85] -> 
             RGBColor[
              0.2795331222505161, 0.40945731042738504`, 0.9392918866244364], 
             UndirectedEdge[130, 237] -> 
             RGBColor[
              0.8684389229143985, 0.44088823341152344`, 0.20976890313790728`],
              UndirectedEdge[175, 183] -> 
             RGBColor[
              0.18767445593923526`, 0.3145881308128762, 0.9339991546750381], 
             UndirectedEdge[93, 289] -> 
             RGBColor[
              0.24228732684798865`, 0.37198972079398507`, 0.9371092768807893],
              UndirectedEdge[69, 234] -> 
             RGBColor[
              0.20086201360397116`, 0.32844909005796263`, 0.9347501665748015],
              UndirectedEdge[32, 269] -> 
             RGBColor[
              0.980420530285405, 0.9551564158081671, 0.6020762664235486], 
             UndirectedEdge[226, 243] -> 
             RGBColor[
              0.9868373224355939, 0.9888249088088037, 0.8678031613671959], 
             UndirectedEdge[72, 218] -> 
             RGBColor[
              0.898302513009544, 0.6010781396556649, 0.5581126298969585], 
             UndirectedEdge[81, 181] -> 
             RGBColor[
              0.9378794291938042, 0.7781980948822975, 0.31536710248397326`], 
             UndirectedEdge[8, 67] -> 
             RGBColor[
              0.1916976136601492, 0.31881672466048916`, 0.9342282675555156], 
             UndirectedEdge[145, 156] -> 
             RGBColor[
              0.6296976932681398, 0.7056126711214472, 0.9666670627828757], 
             UndirectedEdge[20, 177] -> 
             RGBColor[
              0.2554879446971804, 0.38586440712099823`, 0.9378610325387366], 
             UndirectedEdge[180, 297] -> 
             RGBColor[
              0.19343887791696943`, 0.3206469037969376, 0.9343274299789719], 
             UndirectedEdge[140, 216] -> 
             RGBColor[
              0.8418913589267707, 0.3103258778057786, 0.18725219585712266`], 
             UndirectedEdge[287, 300] -> 
             RGBColor[
              0.2343234420650949, 0.3636191729477046, 0.9366557454239152], 
             UndirectedEdge[140, 167] -> 
             RGBColor[
              0.862500511580873, 0.40291200775905295`, 0.20439749636787896`], 
             UndirectedEdge[248, 285] -> 
             RGBColor[
              0.21081919728396287`, 0.3389147214275427, 0.9353172134550438], 
             UndirectedEdge[185, 292] -> 
             RGBColor[
              0.6516360083701964, 0.726054278090207, 0.9670940826236099], 
             UndirectedEdge[23, 241] -> 
             RGBColor[
              0.9877354309295805, 0.9891962997514028, 0.8529191793915591], 
             UndirectedEdge[10, 48] -> 
             RGBColor[
              0.19160641114189197`, 0.3187208650312271, 0.934223073707023], 
             UndirectedEdge[46, 62] -> 
             RGBColor[
              0.20319287451419632`, 0.3308989726597267, 0.9348829056554392], 
             UndirectedEdge[15, 276] -> 
             RGBColor[
              0.24987495920564082`, 0.37996480348555506`, 0.9375413813186614],
              UndirectedEdge[85, 154] -> 
             RGBColor[
              0.36472305205370464`, 0.48205039622074985`, 0.9450500607222323],
              UndirectedEdge[32, 179] -> 
             RGBColor[
              0.7552164634617963, 0.8063041539020928, 0.9047369408488604], 
             UndirectedEdge[145, 277] -> 
             RGBColor[
              0.9289575250796454, 0.9412874203114796, 0.7338327759362018], 
             UndirectedEdge[58, 164] -> 
             RGBColor[
              0.1865510290497441, 0.3134073379226422, 0.9339351771756428], 
             UndirectedEdge[18, 253] -> 
             RGBColor[
              0.19591234458530662`, 0.3232466740922047, 0.9344682902465677], 
             UndirectedEdge[59, 136] -> 
             RGBColor[
              0.6888115905499252, 0.7512769242124885, 0.9221815319720392], 
             UndirectedEdge[232, 288] -> 
             RGBColor[
              0.19838654644971515`, 0.32584721712515685`, 0.9346091923824922],
              UndirectedEdge[136, 177] -> 
             RGBColor[
              0.34229360740819775`, 0.46934835455154167`, 0.9430884098094023],
              UndirectedEdge[31, 65] -> 
             RGBColor[
              0.3985559674737674, 0.5196308798455622, 0.9466166117115924], 
             UndirectedEdge[62, 214] -> 
             RGBColor[
              0.20125370240405008`, 0.3288607798213499, 0.9347724726725144], 
             UndirectedEdge[24, 109] -> 
             RGBColor[
              0.9582875876148832, 0.8633759964057863, 0.5131590613985512], 
             UndirectedEdge[71, 268] -> 
             RGBColor[
              0.21418318831071842`, 0.34245048928601285`, 0.9355087877674388],
              UndirectedEdge[64, 118] -> 
             RGBColor[
              0.2120127678097534, 0.3401692397268907, 0.9353851855307582], 
             UndirectedEdge[21, 206] -> 
             RGBColor[
              0.20800021126608947`, 0.33595178838872103`, 0.9351566763716421],
              UndirectedEdge[6, 124] -> 
             RGBColor[
              0.19825974011141095`, 0.3257139356236129, 0.9346019709491189], 
             UndirectedEdge[7, 140] -> 
             RGBColor[
              0.8778193430883396, 0.5438232517297938, 0.5767554309436527], 
             UndirectedEdge[78, 229] -> 
             RGBColor[
              0.20592187570768378`, 0.3337673259427514, 0.9350383182362128], 
             UndirectedEdge[67, 213] -> 
             RGBColor[
              0.19065103236232478`, 0.3177167013593888, 0.9341686662988828], 
             UndirectedEdge[189, 300] -> 
             RGBColor[
              0.22074088939765935`, 0.34934304891065115`, 0.9358822391430908],
              UndirectedEdge[77, 225] -> 
             RGBColor[
              0.32068966156322254`, 0.4446841856418027, 0.9419297543163823], 
             UndirectedEdge[153, 239] -> 
             RGBColor[
              0.22932262896951866`, 0.3583630013143907, 0.9363709565161622], 
             UndirectedEdge[7, 168] -> 
             RGBColor[
              0.6693655533207783, 0.7373787417141351, 0.9680138507113893], 
             UndirectedEdge[5, 256] -> 
             RGBColor[
              0.8944703960572045, 0.5263449866913684, 0.2533457371184724], 
             UndirectedEdge[193, 200] -> 
             RGBColor[
              0.3225670309120143, 0.4511149836272068, 0.9418734544780243], 
             UndirectedEdge[17, 202] -> 
             RGBColor[
              0.7851169381087426, 0.6277184794555003, 0.5907369568935974], 
             UndirectedEdge[12, 220] -> 
             RGBColor[
              0.38135478455479077`, 0.5047320797577364, 0.9455205675464041], 
             UndirectedEdge[196, 207] -> 
             RGBColor[
              0.19417373721693681`, 0.32141928751397403`, 0.9343692791289782],
              UndirectedEdge[222, 285] -> 
             RGBColor[
              0.21055261927690455`, 0.33863453104010255`, 0.9353020322319088],
              UndirectedEdge[169, 227] -> 
             RGBColor[
              0.7787217249901721, 0.7700947212036731, 0.6214147685810579], 
             UndirectedEdge[139, 298] -> 
             RGBColor[
              0.350430471977903, 0.4734528335000848, 0.9437146509438744], 
             UndirectedEdge[210, 241] -> 
             RGBColor[
              0.7289016289330998, 0.7852496727746727, 0.9155863904520005], 
             UndirectedEdge[58, 288] -> 
             RGBColor[
              0.200003126765576, 0.32754634553423856`, 0.9347012542399642], 
             UndirectedEdge[85, 258] -> 
             RGBColor[
              0.2861550048473763, 0.41519285230728875`, 0.9397138271280076], 
             UndirectedEdge[87, 162] -> 
             RGBColor[
              0.9922481634967688, 0.9892215006042993, 0.6443153424349913], 
             UndirectedEdge[222, 248] -> 
             RGBColor[
              0.22169214906401963`, 0.3503428831333422, 0.9359364119738274], 
             UndirectedEdge[76, 87] -> 
             RGBColor[
              0.6600329022141906, 0.7226670785503484, 0.7188188011286823], 
             UndirectedEdge[80, 282] -> 
             RGBColor[
              0.7097202776306235, 0.7481265393121519, 0.6607363832345532], 
             UndirectedEdge[273, 289] -> 
             RGBColor[
              0.24118737083360547`, 0.370833597281629, 0.9370466360130092], 
             UndirectedEdge[215, 296] -> 
             RGBColor[
              0.20597442651804665`, 0.33382256017635653`, 0.935041310927121], 
             UndirectedEdge[142, 277] -> 
             RGBColor[
              0.9114733897375824, 0.6092818085693412, 0.32849435906876756`], 
             UndirectedEdge[134, 180] -> 
             RGBColor[
              0.21984183187712564`, 0.34839808245303105`, 0.9358310391473328],
              UndirectedEdge[86, 178] -> 
             RGBColor[
              0.4265942001520806, 0.5354932240498018, 0.9496283130255976], 
             UndirectedEdge[3, 210] -> 
             RGBColor[
              0.7129487102103079, 0.7736730218742174, 0.9569659936880668], 
             UndirectedEdge[79, 176] -> 
             RGBColor[
              0.18866673983198834`, 0.31563108409859225`, 0.9340556637747779],
              UndirectedEdge[131, 141] -> 
             RGBColor[
              0.26162779894186294`, 0.392317783221403, 0.938210688154871], 
             UndirectedEdge[150, 256] -> 
             RGBColor[
              0.8626687592440776, 0.4047125271654385, 0.20457946206091293`], 
             UndirectedEdge[74, 300] -> 
             RGBColor[
              0.2157736566163444, 0.3441221723167407, 0.9355993625845572], 
             UndirectedEdge[25, 230] -> 
             RGBColor[
              0.19160057419890764`, 0.31871473003406703`, 0.934222741301755], 
             UndirectedEdge[165, 253] -> 
             RGBColor[
              0.20482209384336109`, 0.3326113854731506, 0.9349756872860211], 
             UndirectedEdge[223, 295] -> 
             RGBColor[
              0.1892065910771333, 0.3161985019857855, 0.9340864075045505], 
             UndirectedEdge[164, 221] -> 
             RGBColor[
              0.184078374522518, 0.31080842123917557`, 0.9337943631582817], 
             UndirectedEdge[70, 138] -> 
             RGBColor[
              0.22052881830414905`, 0.3491201487452879, 0.9358701620080464], 
             UndirectedEdge[165, 224] -> 
             RGBColor[
              0.21323098705618415`, 0.3414496653944509, 0.9354545613146487], 
             UndirectedEdge[87, 258] -> 
             RGBColor[
              0.6666547848110509, 0.7284026204302521, 0.7192407416322534], 
             UndirectedEdge[90, 222] -> 
             RGBColor[
              0.2185508250169386, 0.3470411523884118, 0.9357575182165185], 
             UndirectedEdge[163, 185] -> 
             RGBColor[
              0.5753534134295759, 0.6661368462548543, 0.9597130747756251], 
             UndirectedEdge[64, 286] -> 
             RGBColor[
              0.22809764059378232`, 0.35707546086274283`, 0.9363011952403719],
              UndirectedEdge[131, 199] -> 
             RGBColor[
              0.21390129447571837`, 0.3421542009923264, 0.9354927343305601], 
             UndirectedEdge[2, 49] -> 
             RGBColor[
              0.20410648254439653`, 0.3318592326255619, 0.934934934281197], 
             UndirectedEdge[51, 283] -> 
             RGBColor[
              0.5585587587049552, 0.6456389259467026, 0.9612767740180419], 
             UndirectedEdge[66, 187] -> 
             RGBColor[
              0.305540960778381, 0.4312990434818653, 0.9409741624536079], 
             UndirectedEdge[120, 170] -> 
             RGBColor[
              0.23833338730926568`, 0.3678338796445412, 0.9368841058733883], 
             UndirectedEdge[17, 182] -> 
             RGBColor[
              0.47900337512465124`, 0.5765439495002909, 0.9544470440825916], 
             UndirectedEdge[156, 179] -> 
             RGBColor[
              0.4586241439822036, 0.5697734899723961, 0.9509650514168311], 
             UndirectedEdge[199, 284] -> 
             RGBColor[
              0.21967623885350168`, 0.3482240336859982, 0.9358216088696103], 
             UndirectedEdge[210, 291] -> 
             RGBColor[
              0.6992769373373419, 0.7632490848408453, 0.9722193956891239], 
             UndirectedEdge[212, 265] -> 
             RGBColor[
              0.22804223773896515`, 0.3570172289495861, 0.9362980401297512], 
             UndirectedEdge[85, 173] -> 
             RGBColor[
              0.21671771694106706`, 0.34511443957490595`, 0.9356531254234381],
              UndirectedEdge[47, 146] -> 
             RGBColor[
              0.19206431623757236`, 0.3192021523196471, 0.9342491507248121], 
             UndirectedEdge[198, 283] -> 
             RGBColor[
              0.6352059189617083, 0.705940028417498, 0.9427748448450561], 
             UndirectedEdge[168, 212] -> 
             RGBColor[
              0.31689002798285826`, 0.4419267953395609, 0.941668105069032], 
             UndirectedEdge[56, 271] -> 
             RGBColor[
              0.21099595483626973`, 0.3391005048220933, 0.9353272795361584], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.33246233459167696`, 0.45559373221858496`, 0.9426538050639501],
              UndirectedEdge[159, 191] -> 
             RGBColor[
              0.25930875612416715`, 0.38988032218419766`, 0.9380786220971196],
              UndirectedEdge[72, 83] -> 
             RGBColor[
              0.8379840210704871, 0.29296740741773747`, 0.18400684751490148`],
              UndirectedEdge[179, 277] -> 
             RGBColor[
              0.7578839757937091, 0.8054482391624284, 0.7181307645701571], 
             UndirectedEdge[86, 182] -> 
             RGBColor[
              0.4242603384632414, 0.5330401874394541, 0.9494954030550571], 
             UndirectedEdge[80, 293] -> 
             RGBColor[
              0.9392835874613179, 0.7889438610995526, 0.30512184711932616`], 
             UndirectedEdge[9, 96] -> 
             RGBColor[
              0.19995528537104273`, 0.3274960611952644, 0.9346985297433206], 
             UndirectedEdge[51, 226] -> 
             RGBColor[
              0.8987769385879059, 0.920547716985024, 0.9296222387004919], 
             UndirectedEdge[185, 235] -> 
             RGBColor[
              0.4690251433139141, 0.5785976856950342, 0.951678806922862], 
             UndirectedEdge[136, 210] -> 
             RGBColor[
              0.43214727310106515`, 0.5482274348494092, 0.9488947696323751], 
             UndirectedEdge[78, 284] -> 
             RGBColor[
              0.2175445595822431, 0.34598350361563335`, 0.935700212888649], 
             UndirectedEdge[81, 216] -> 
             RGBColor[
              0.8779643061000555, 0.5387462408083503, 0.21988276445235083`], 
             UndirectedEdge[2, 165] -> 
             RGBColor[
              0.2081927032562806, 0.336154109675109, 0.935167638505717], 
             UndirectedEdge[181, 216] -> 
             RGBColor[
              0.92637884094729, 0.7259766096855043, 0.3057707297458678], 
             UndirectedEdge[7, 203] -> 
             RGBColor[
              0.9377223890197792, 0.9530740402179558, 0.990303930173889], 
             UndirectedEdge[44, 177] -> 
             RGBColor[
              0.3040955168977345, 0.4362630884432308, 0.9406544612593207], 
             UndirectedEdge[140, 237] -> 
             RGBColor[
              0.8211968317886982, 0.16393371440465854`, 0.16793141610024187`],
              UndirectedEdge[38, 124] -> 
             RGBColor[
              0.186021974396972, 0.31285126793857626`, 0.9339050482958335], 
             UndirectedEdge[5, 59] -> 
             RGBColor[
              0.978010186853574, 0.9509747189595588, 0.6200075845730131], 
             UndirectedEdge[35, 253] -> 
             RGBColor[
              0.19912169776175326`, 0.3266199077653942, 0.9346510581621539], 
             UndirectedEdge[200, 231] -> 
             RGBColor[
              0.2983755222047893, 0.4256881741456715, 0.9404957838452779], 
             UndirectedEdge[213, 234] -> 
             RGBColor[
              0.19826511451334394`, 0.3257195844608012, 0.9346022770133582], 
             UndirectedEdge[53, 88] -> 
             RGBColor[
              0.21936792560639845`, 0.34789997691510377`, 0.9358040508862964],
              UndirectedEdge[150, 269] -> 
             RGBColor[
              0.9402871560451271, 0.7958786263011822, 0.2973043850963], 
             UndirectedEdge[4, 135] -> 
             RGBColor[
              0.21680708920312736`, 0.3452083754888601, 0.935658215041548], 
             UndirectedEdge[91, 139] -> 
             RGBColor[
              0.4654409733450266, 0.5765629962584664, 0.9511548548621985], 
             UndirectedEdge[28, 232] -> 
             RGBColor[
              0.18568890069969585`, 0.3125011863646469, 0.9338860802415121], 
             UndirectedEdge[127, 276] -> 
             RGBColor[
              0.29510454675664893`, 0.4237974430003376, 0.9402528534454749], 
             UndirectedEdge[60, 103] -> 
             RGBColor[
              0.35429852491084235`, 0.47931146530946245`, 0.9438692780187988],
              UndirectedEdge[145, 159] -> 
             RGBColor[
              0.5780723315879956, 0.6592789022873965, 0.963436800696632], 
             UndirectedEdge[20, 252] -> 
             RGBColor[
              0.2284732256377411, 0.3574702245574107, 0.936322584252997], 
             UndirectedEdge[80, 128] -> 
             RGBColor[
              0.9118743315068152, 0.6433069966832056, 0.2814216211923882], 
             UndirectedEdge[167, 237] -> 
             RGBColor[
              0.8663783433695712, 0.4327187221637115, 0.20811091246812083`], 
             UndirectedEdge[24, 291] -> 
             RGBColor[
              0.9253194185531315, 0.839992794616319, 0.6252021408895034], 
             UndirectedEdge[22, 244] -> 
             RGBColor[
              0.18902260313051494`, 0.31600511898838, 0.9340759296631764], 
             UndirectedEdge[51, 83] -> 
             RGBColor[
              0.8289246632002845, 0.6056697988799424, 0.5870191249815166], 
             UndirectedEdge[29, 229] -> 
             RGBColor[
              0.20648377022612274`, 0.3343579127078008, 0.9350703172977894], 
             UndirectedEdge[151, 181] -> 
             RGBColor[
              0.7920610111090953, 0.8249056195457978, 0.6813687144574905], 
             UndirectedEdge[22, 63] -> 
             RGBColor[
              0.18571205303560948`, 0.312525520937635, 0.9338873987327916], 
             UndirectedEdge[163, 292] -> 
             RGBColor[
              0.6974329821497556, 0.7632343245346107, 0.9706993881593793], 
             UndirectedEdge[247, 289] -> 
             RGBColor[
              0.22060050259813557`, 0.34919549348331447`, 0.9358742443225416],
              UndirectedEdge[155, 299] -> 
             RGBColor[
              0.8725038681798738, 0.44513051276199045`, 0.2125515962932238], 
             UndirectedEdge[31, 71] -> 
             RGBColor[
              0.32148269623256015`, 0.4449753770732606, 0.9419947741290198], 
             UndirectedEdge[45, 260] -> 
             RGBColor[
              0.2790511539192304, 0.41063083400712647`, 0.9392029224452882], 
             UndirectedEdge[80, 125] -> 
             RGBColor[
              0.9070014402205765, 0.6058518189425977, 0.2767553349935425], 
             UndirectedEdge[97, 261] -> 
             RGBColor[
              0.34679730240272766`, 0.46888200483462256`, 0.9435352867345028],
              UndirectedEdge[107, 147] -> 
             RGBColor[
              0.3109365240034128, 0.43492372492699083`, 0.9413563604380197], 
             UndirectedEdge[15, 286] -> 
             RGBColor[
              0.23963340623012278`, 0.3692002819563222, 0.9369581400277256], 
             UndirectedEdge[94, 202] -> 
             RGBColor[
              0.8317297748330001, 0.6641327817751705, 0.595382888836546], 
             UndirectedEdge[86, 130] -> 
             RGBColor[
              0.75299012475597, 0.6847273872222507, 0.6045439579169226], 
             UndirectedEdge[73, 161] -> 
             RGBColor[
              0.19216173018569271`, 0.31930454055552265`, 0.9342546983050465],
              UndirectedEdge[7, 167] -> 
             RGBColor[
              0.9230008546692128, 0.8126082594888467, 0.6169349273115317], 
             UndirectedEdge[288, 297] -> 
             RGBColor[
              0.20042924344964513`, 0.3279942211865534, 0.9347255209547387], 
             UndirectedEdge[15, 46] -> 
             RGBColor[
              0.23154240030757095`, 0.3606961217323153, 0.9364973692100068], 
             UndirectedEdge[1, 92] -> 
             RGBColor[
              0.82512404738325, 0.19412001438123114`, 0.1716921221887404], 
             UndirectedEdge[85, 213] -> 
             RGBColor[
              0.21726177740977812`, 0.34568628162294734`, 0.9356841088622658],
              UndirectedEdge[2, 174] -> 
             RGBColor[
              0.21589796346133705`, 0.34425282669233714`, 0.9356064416754841],
              UndirectedEdge[104, 204] -> 
             RGBColor[
              0.40934807922423605`, 0.5281560108098651, 0.9475315219665212], 
             UndirectedEdge[125, 243] -> 
             RGBColor[
              0.9113059901364808, 0.6302952707033915, 0.519761776336199], 
             UndirectedEdge[149, 243] -> 
             RGBColor[
              0.9414606577081649, 0.8037269245686582, 0.5463530672768225], 
             UndirectedEdge[35, 175] -> 
             RGBColor[
              0.19450102624862847`, 0.3217632890376051, 0.9343879177551523], 
             UndirectedEdge[82, 201] -> 
             RGBColor[
              0.7294018709234232, 0.5233754189666472, 0.5768926874649807], 
             UndirectedEdge[39, 69] -> 
             RGBColor[
              0.20464654155210055`, 0.3324268688843776, 0.9349656898427401], 
             UndirectedEdge[5, 204] -> 
             RGBColor[
              0.7273105149978081, 0.7527675975931751, 0.6471903809836539], 
             UndirectedEdge[107, 277] -> 
             RGBColor[
              0.7007432409432577, 0.7578412318622451, 0.7139688588587303], 
             UndirectedEdge[236, 260] -> 
             RGBColor[
              0.2447992469285118, 0.3746299080635468, 0.9372523270133223], 
             UndirectedEdge[11, 51] -> 
             RGBColor[
              0.6715557743614986, 0.7416503460034106, 0.9690558457242018], 
             UndirectedEdge[41, 242] -> 
             RGBColor[
              0.18473837996455222`, 0.31150212880551553`, 0.933831949491815], 
             UndirectedEdge[53, 93] -> 
             RGBColor[
              0.22850372850548528`, 0.3575022850054033, 0.93632432134619], 
             UndirectedEdge[82, 293] -> 
             RGBColor[
              0.7565992079701278, 0.6673833817942012, 0.600389979606483], 
             UndirectedEdge[76, 151] -> 
             RGBColor[
              0.46237290629163863`, 0.5709821178298984, 0.9517671246297987], 
             UndirectedEdge[130, 269] -> 
             RGBColor[
              0.9424840400754735, 0.8045885394133, 0.29907204955461253`], 
             UndirectedEdge[13, 289] -> 
             RGBColor[
              0.2883666647778183, 0.41815288261871875`, 0.9398165114828785], 
             UndirectedEdge[86, 120] -> 
             RGBColor[
              0.4366336879326583, 0.5460453622474791, 0.9502000470026102], 
             UndirectedEdge[86, 284] -> 
             RGBColor[
              0.41756739126480746`, 0.526005475576538, 0.9491142496134344], 
             UndirectedEdge[49, 102] -> 
             RGBColor[
              0.20090857647606358`, 0.32849803058878846`, 0.9347528182614836],
              UndirectedEdge[27, 299] -> 
             RGBColor[
              0.8942677012180347, 0.5273127630922669, 0.2514374852904795], 
             UndirectedEdge[120, 182] -> 
             RGBColor[
              0.2667169591353605, 0.3976668132561618, 0.9385005082991529], 
             UndirectedEdge[97, 182] -> 
             RGBColor[
              0.35160088518762583`, 0.47393087490628993`, 0.9438088436678389],
              UndirectedEdge[42, 130] -> 
             RGBColor[
              0.8747039583373085, 0.4890440410280375, 0.21576830813423137`], 
             UndirectedEdge[15, 127] -> 
             RGBColor[
              0.3036056586421837, 0.43273265059365945`, 0.9407369791910881], 
             UndirectedEdge[28, 176] -> 
             RGBColor[
              0.18883134167646898`, 0.3158040910735011, 0.9340650376063144], 
             UndirectedEdge[26, 35] -> 
             RGBColor[
              0.21774452951257628`, 0.3461936846912394, 0.9357116008803525], 
             UndirectedEdge[44, 59] -> 
             RGBColor[
              0.650613500039462, 0.7181916581041776, 0.9197475834219577], 
             UndirectedEdge[155, 218] -> 
             RGBColor[
              0.9467517036363646, 0.8603082831521655, 0.5999961337585191], 
             UndirectedEdge[65, 155] -> 
             RGBColor[
              0.6518886127524492, 0.6234637492866453, 0.6024205995762867], 
             UndirectedEdge[55, 252] -> 
             RGBColor[
              0.22003960441036646`, 0.34860595392497, 0.9358423020005227], 
             UndirectedEdge[160, 296] -> 
             RGBColor[
              0.1914857715941317, 0.31859406521754197`, 0.9342162034632482], 
             UndirectedEdge[88, 147] -> 
             RGBColor[
              0.21812810554997109`, 0.34659684742666674`, 0.9357334449682322],
              UndirectedEdge[204, 243] -> 
             RGBColor[
              0.7355129252278461, 0.7903594474546665, 0.9053392735975632], 
             UndirectedEdge[65, 106] -> 
             RGBColor[
              0.6196619973862446, 0.6970249085872788, 0.9659794196694249], 
             UndirectedEdge[115, 245] -> 
             RGBColor[
              0.2884856169676899, 0.4165730051879058, 0.9398857105111442], 
             UndirectedEdge[60, 205] -> 
             RGBColor[
              0.3298135622578278, 0.45810382130942706`, 0.9423091178497511], 
             UndirectedEdge[75, 111] -> 
             RGBColor[
              0.4735665439631073, 0.5802328466571501, 0.952603227994324], 
             UndirectedEdge[17, 86] -> 
             RGBColor[
              0.648920103921949, 0.7249224984916083, 0.966146582786049], 
             UndirectedEdge[67, 166] -> 
             RGBColor[
              0.1825106958270533, 0.309160691533672, 0.9337050861757479], 
             UndirectedEdge[3, 169] -> 
             RGBColor[
              0.7794786659769637, 0.8276850371059405, 0.962203475513276], 
             UndirectedEdge[7, 255] -> 
             RGBColor[
              0.6521687790491231, 0.722483760175034, 0.9669180874613099], 
             UndirectedEdge[211, 231] -> 
             RGBColor[
              0.25095672851015194`, 0.3811018116127316, 0.937602986480219], 
             UndirectedEdge[218, 290] -> 
             RGBColor[
              0.956800253470921, 0.9001474347654498, 0.6080814328251828], 
             UndirectedEdge[201, 269] -> 
             RGBColor[
              0.9092644951417719, 0.6354174551570593, 0.2706625685866058], 
             UndirectedEdge[34, 223] -> 
             RGBColor[
              0.1825916590093845, 0.3092457889716643, 0.9337096969092074], 
             UndirectedEdge[63, 208] -> 
             RGBColor[
              0.1860996055764639, 0.3129328632303233, 0.9339094692766605], 
             UndirectedEdge[131, 190] -> 
             RGBColor[
              0.21691115903565433`, 0.3453177594812544, 0.9356641416645529], 
             UndirectedEdge[27, 181] -> 
             RGBColor[
              0.9780677338465346, 0.9376794577026863, 0.3692977168650637], 
             UndirectedEdge[108, 136] -> 
             RGBColor[
              0.3166504809342749, 0.4423958027593246, 0.9416280716923184], 
             UndirectedEdge[101, 254] -> 
             RGBColor[
              0.4830549298600605, 0.587475687952538, 0.9535083702036646], 
             UndirectedEdge[62, 212] -> 
             RGBColor[
              0.2175228275026328, 0.34596066182206947`, 0.9356989752788649], 
             UndirectedEdge[69, 195] -> 
             RGBColor[
              0.1956464700099377, 0.32296722305607023`, 0.9344531490828267], 
             UndirectedEdge[136, 252] -> 
             RGBColor[
              0.3152788883487585, 0.44095417198795417`, 0.9415499615236627], 
             UndirectedEdge[26, 175] -> 
             RGBColor[
              0.20585209939384108`, 0.33369398661282884`, 0.9350343445783642],
              UndirectedEdge[24, 27] -> 
             RGBColor[
              0.9468027585380377, 0.8226935997742366, 0.2974286527731346], 
             UndirectedEdge[231, 266] -> 
             RGBColor[
              0.21466524015743277`, 0.342957156340762, 0.9355362399069774], 
             UndirectedEdge[153, 157] -> 
             RGBColor[
              0.2018036290672552, 0.32943878761174283`, 0.9348037901824403], 
             UndirectedEdge[161, 244] -> 
             RGBColor[
              0.19557921069497186`, 0.3228965292515542, 0.9344493187643406], 
             UndirectedEdge[128, 150] -> 
             RGBColor[
              0.8761748343795548, 0.5085261390565783, 0.21751289486357597`], 
             UndirectedEdge[113, 200] -> 
             RGBColor[
              0.3166014610591278, 0.4448447914728484, 0.9415337241001722], 
             UndirectedEdge[211, 264] -> 
             RGBColor[
              0.28347133969758304`, 0.41527672951614025`, 0.9394546454862865],
              UndirectedEdge[144, 232] -> 
             RGBColor[
              0.19277383312180774`, 0.31994789955094727`, 0.9342895566617331],
              UndirectedEdge[208, 244] -> 
             RGBColor[
              0.18941015567136937`, 0.31641246128106837`, 0.9340980002070455],
              UndirectedEdge[47, 133] -> 
             RGBColor[
              0.18469446291568115`, 0.3114559692026503, 0.9338294484808514], 
             UndirectedEdge[181, 258] -> 
             RGBColor[
              0.6632277418204424, 0.717240503923456, 0.6720754184533696], 
             UndirectedEdge[53, 147] -> 
             RGBColor[
              0.21463757351182716`, 0.3429280769420639, 0.9355346643324394], 
             UndirectedEdge[123, 267] -> 
             RGBColor[
              0.19740462411574278`, 0.32481515449468, 0.9345532733581963], 
             UndirectedEdge[59, 227] -> 
             RGBColor[
              0.9688560866723765, 0.9191321953350291, 0.5894640490955131], 
             UndirectedEdge[213, 286] -> 
             RGBColor[
              0.21163290304685975`, 0.3397699777762725, 0.935363552794471], 
             UndirectedEdge[16, 126] -> 
             RGBColor[
              0.23513936956710785`, 0.3644767644851118, 0.9367022112880983], 
             UndirectedEdge[68, 109] -> 
             RGBColor[
              0.9348338843673183, 0.947970458954174, 0.8784588716115629], 
             UndirectedEdge[137, 156] -> 
             RGBColor[
              0.32801284307365003`, 0.4541649141300481, 0.9422814923217423], 
             UndirectedEdge[181, 202] -> 
             RGBColor[
              0.9264323498375825, 0.7262195810590035, 0.3058153788755507], 
             UndirectedEdge[135, 214] -> 
             RGBColor[
              0.20695344714813524`, 0.3348515729320728, 0.9350970647036734], 
             UndirectedEdge[166, 234] -> 
             RGBColor[
              0.19012477797807242`, 0.3171635746350845, 0.9341386968902232], 
             UndirectedEdge[63, 152] -> 
             RGBColor[
              0.18270109795627662`, 0.30936081624367795`, 0.9337159292953324],
              UndirectedEdge[130, 167] -> 
             RGBColor[
              0.9097426027065735, 0.6798665267659179, 0.24623498340554434`], 
             UndirectedEdge[30, 74] -> 
             RGBColor[
              0.22759891531018372`, 0.3565512689686714, 0.9362727935732689], 
             UndirectedEdge[31, 177] -> 
             RGBColor[
              0.3558101333125378, 0.4810556899295358, 0.9439496708878323], 
             UndirectedEdge[24, 72] -> 
             RGBColor[
              0.8765897348730561, 0.4812812059474597, 0.21665925991431845`], 
             UndirectedEdge[39, 285] -> 
             RGBColor[
              0.20070194384757245`, 0.3282808465949789, 0.9347410508389766], 
             UndirectedEdge[27, 72] -> 
             RGBColor[
              0.8996284799870488, 0.5685180578191442, 0.256570973093821], 
             UndirectedEdge[109, 151] -> 
             RGBColor[
              0.7953196099914366, 0.8378390101205823, 0.8651417721704804], 
             UndirectedEdge[29, 178] -> 
             RGBColor[
              0.22713326298795516`, 0.3560618388539467, 0.9362462753623888], 
             UndirectedEdge[149, 256] -> 
             RGBColor[
              0.8567159557183694, 0.3785989305571812, 0.19965971650756104`], 
             UndirectedEdge[93, 137] -> 
             RGBColor[
              0.25133211293896884`, 0.38149636444816565`, 0.9376243640681086],
              UndirectedEdge[7, 145] -> 
             RGBColor[
              0.9016117745004403, 0.9243171913792056, 0.9881346792519563], 
             UndirectedEdge[271, 278] -> 
             RGBColor[
              0.21163260011638724`, 0.339769659377139, 0.9353635355430288], 
             UndirectedEdge[15, 135] -> 
             RGBColor[
              0.2357262900418861, 0.3650936551170112, 0.9367356355408658], 
             UndirectedEdge[94, 130] -> 
             RGBColor[
              0.8543459981416374, 0.7646454516027577, 0.6141415308874059], 
             UndirectedEdge[265, 286] -> 
             RGBColor[
              0.22180329067308052`, 0.3504597000112502, 0.9359427413240442], 
             UndirectedEdge[140, 201] -> 
             RGBColor[
              0.8313415461919986, 0.24191043475062424`, 0.1776460060696587], 
             UndirectedEdge[29, 259] -> 
             RGBColor[
              0.19020824390880345`, 0.3172513026203284, 0.9341434501515016], 
             UndirectedEdge[21, 123] -> 
             RGBColor[
              0.1960904957019222, 0.3234339222112008, 0.934478435689108], 
             UndirectedEdge[21, 189] -> 
             RGBColor[
              0.20470683599275827`, 0.3324902421643972, 0.934969123521938], 
             UndirectedEdge[107, 289] -> 
             RGBColor[
              0.32595994240234355`, 0.45071429020400966`, 0.942211921890683], 
             UndirectedEdge[17, 66] -> 
             RGBColor[
              0.5450024443168381, 0.6387388987189666, 0.9584682781320619], 
             UndirectedEdge[71, 208] -> 
             RGBColor[
              0.20631669235829492`, 0.33418230327536513`, 0.9350608024603861],
              UndirectedEdge[6, 289] -> 
             RGBColor[
              0.22701980203641853`, 0.3559425842000419, 0.9362398139290493], 
             UndirectedEdge[96, 132] -> 
             RGBColor[
              0.1989233882773373, 0.32641147192372544`, 0.9346397647303889], 
             UndirectedEdge[55, 283] -> 
             RGBColor[
              0.25397885208056453`, 0.38427825509893676`, 0.9377750919467229],
              UndirectedEdge[48, 244] -> 
             RGBColor[
              0.19115682833937214`, 0.31824832500058275`, 0.9341974706315176],
              UndirectedEdge[110, 278] -> 
             RGBColor[
              0.19327360105018532`, 0.32047318733078894`, 0.9343180177059138],
              UndirectedEdge[245, 288] -> 
             RGBColor[
              0.2170539171587743, 0.34546780732004123`, 0.9356722715284729], 
             UndirectedEdge[106, 210] -> 
             RGBColor[
              0.6667698289178824, 0.73732879896912, 0.9691188386686375], 
             UndirectedEdge[176, 296] -> 
             RGBColor[
              0.19069988788986053`, 0.3177680516164482, 0.9341714485489008], 
             UndirectedEdge[82, 154] -> 
             RGBColor[
              0.5553686317376758, 0.6499123001732142, 0.9581397995541713], 
             UndirectedEdge[46, 117] -> 
             RGBColor[
              0.1951092767006187, 0.3224025988279529, 0.9344225567185672], 
             UndirectedEdge[249, 258] -> 
             RGBColor[
              0.2738091064777124, 0.40221653034560445`, 0.9390107464799751], 
             UndirectedEdge[146, 170] -> 
             RGBColor[
              0.19880274533348388`, 0.3262846685405311, 0.9346328942932117], 
             UndirectedEdge[18, 129] -> 
             RGBColor[
              0.1945312219559263, 0.32179502664049353`, 0.9343896373560123], 
             UndirectedEdge[13, 179] -> 
             RGBColor[
              0.42802275177735205`, 0.5432681021152472, 0.9490151577652866], 
             UndirectedEdge[144, 160] -> 
             RGBColor[
              0.19670215780285202`, 0.3240768178608952, 0.934513268940883], 
             UndirectedEdge[17, 130] -> 
             RGBColor[
              0.8077331614173798, 0.7282311492830874, 0.6094955989444572], 
             UndirectedEdge[111, 163] -> 
             RGBColor[
              0.6176770518281398, 0.70049708256499, 0.9630449466269559], 
             UndirectedEdge[107, 251] -> 
             RGBColor[
              0.34704129264344796`, 0.47287212594221606`, 0.943412473599851], 
             UndirectedEdge[1, 198] -> 
             RGBColor[
              0.8916422332040788, 0.5589019666811266, 0.5551782044510756], 
             UndirectedEdge[168, 269] -> 
             RGBColor[
              0.6867881591822118, 0.7211895103907764, 0.6484929822846838], 
             UndirectedEdge[145, 201] -> 
             RGBColor[
              0.8551339776040994, 0.6224043744000362, 0.5890252543779623], 
             UndirectedEdge[197, 226] -> 
             RGBColor[
              0.9862994243091077, 0.9886024741101505, 0.8767175253588012], 
             UndirectedEdge[105, 174] -> 
             RGBColor[
              0.25852249961576723`, 0.3890539167423275, 0.9380338459521285], 
             UndirectedEdge[178, 284] -> 
             RGBColor[
              0.24998452415634886`, 0.38007996319556836`, 0.9375476208805174],
              UndirectedEdge[201, 202] -> 
             RGBColor[
              0.8559674140090618, 0.41835228392990204`, 0.20072485105646432`],
              UndirectedEdge[24, 65] -> 
             RGBColor[
              0.6506137006766177, 0.6184091477452374, 0.6013947753940398], 
             UndirectedEdge[134, 169] -> 
             RGBColor[
              0.42476901028009817`, 0.532311534169465, 0.9496393645496872], 
             UndirectedEdge[104, 300] -> 
             RGBColor[
              0.2803668703826312, 0.4095782545351725, 0.9393670254375599], 
             UndirectedEdge[168, 225] -> 
             RGBColor[
              0.31400402532006444`, 0.4388934235578272, 0.9415037514868442], 
             UndirectedEdge[27, 202] -> 
             RGBColor[
              0.9182061196430783, 0.6984705750022384, 0.2738580279631242], 
             UndirectedEdge[113, 187] -> 
             RGBColor[
              0.24618639037776724`, 0.3760878837786886, 0.9373313227806626], 
             UndirectedEdge[7, 201] -> 
             RGBColor[
              0.8918418892803384, 0.651606686480418, 0.5901834370133114], 
             UndirectedEdge[51, 104] -> 
             RGBColor[
              0.5731922784257398, 0.6585842020957557, 0.9621993062038972], 
             UndirectedEdge[2, 183] -> 
             RGBColor[
              0.19566573686527955`, 0.3229874737426237, 0.9344542463017356], 
             UndirectedEdge[135, 249] -> 
             RGBColor[
              0.21026660117408774`, 0.33833390787944695`, 0.9352857439240791],
              UndirectedEdge[84, 270] -> 
             RGBColor[
              0.20015353292457566`, 0.32770443194364846`, 0.9347098196482133],
              UndirectedEdge[114, 116] -> 
             RGBColor[
              0.26324193971723214`, 0.3940143475187522, 0.9383026110841209], 
             UndirectedEdge[15, 168] -> 
             RGBColor[
              0.3293937457780264, 0.4550689955237798, 0.942380173299874], 
             UndirectedEdge[42, 237] -> 
             RGBColor[
              0.8313396990003062, 0.24189623642583113`, 0.17764423719680783`],
              UndirectedEdge[40, 140] -> 
             RGBColor[
              0.7532763216794478, 0.4456404138262269, 0.5669390131907837], 
             UndirectedEdge[42, 167] -> 
             RGBColor[
              0.8726433787924812, 0.48087452978022555`, 0.21411031746444492`],
              UndirectedEdge[16, 285] -> 
             RGBColor[
              0.22323502267117318`, 0.3519645411182973, 0.9360242763432778], 
             UndirectedEdge[8, 286] -> 
             RGBColor[
              0.21267948434468417`, 0.34087000107737286`, 0.9354231540511039],
              UndirectedEdge[9, 236] -> 
             RGBColor[
              0.21519552032906075`, 0.34351451442284786`, 0.9355664385782725],
              UndirectedEdge[54, 238] -> 
             RGBColor[
              0.21574020514797415`, 0.344087012702538, 0.9355974575729206], 
             UndirectedEdge[165, 183] -> 
             RGBColor[
              0.2052672821395783, 0.33307930659904317`, 0.9350010401008936], 
             UndirectedEdge[249, 263] -> 
             RGBColor[
              0.20867298294508915`, 0.33665891407953785`, 0.9351949897234846],
              UndirectedEdge[33, 98] -> 
             RGBColor[
              0.18977923539730202`, 0.3168003874740297, 0.9341190187514328], 
             UndirectedEdge[282, 293] -> 
             RGBColor[
              0.6701954566467123, 0.5968924733689558, 0.5936831325375491], 
             UndirectedEdge[54, 163] -> 
             RGBColor[
              0.4325936369919836, 0.5385727559524309, 0.9502636460208878], 
             UndirectedEdge[145, 237] -> 
             RGBColor[
              0.8449892632007987, 0.5444276540540705, 0.5793106644085455], 
             UndirectedEdge[140, 181] -> 
             RGBColor[
              0.9018064820205194, 0.5497777318797257, 0.2827365338887451], 
             UndirectedEdge[15, 265] -> 
             RGBColor[
              0.24054595553413333`, 0.37015942913380495`, 0.9370101083605932],
              UndirectedEdge[144, 230] -> 
             RGBColor[
              0.19486271425090618`, 0.32214344606034284`, 0.9344085153518125],
              UndirectedEdge[22, 266] -> 
             RGBColor[
              0.1933455924812791, 0.32054885488938883`, 0.9343221175114128], 
             UndirectedEdge[18, 165] -> 
             RGBColor[
              0.2088844992725249, 0.33688123115058255`, 0.9352070352654217], 
             UndirectedEdge[17, 140] -> 
             RGBColor[
              0.7604910702916794, 0.4512766302762225, 0.5676581119067918], 
             UndirectedEdge[80, 237] -> 
             RGBColor[
              0.9019415360113127, 0.566959177926033, 0.27190996500840703`], 
             UndirectedEdge[7, 127] -> 
             RGBColor[
              0.6435774661849356, 0.7150423967840147, 0.9663706566026036], 
             UndirectedEdge[60, 212] -> 
             RGBColor[
              0.2603180236560096, 0.39094112635142153`, 0.9381360983899805], 
             UndirectedEdge[53, 270] -> 
             RGBColor[
              0.21435826979552958`, 0.3426345110273567, 0.935518758398989], 
             UndirectedEdge[243, 254] -> 
             RGBColor[
              0.6530996726183891, 0.7197996840615158, 0.8998607275791879], 
             UndirectedEdge[201, 277] -> 
             RGBColor[
              0.9191876398595434, 0.6685769154126919, 0.3358815336975568], 
             UndirectedEdge[288, 296] -> 
             RGBColor[
              0.1980362372485557, 0.3254790199438521, 0.9345892427917222], 
             UndirectedEdge[93, 273] -> 
             RGBColor[
              0.24003010742833283`, 0.36961724006794966`, 0.9369807315740968],
              UndirectedEdge[128, 277] -> 
             RGBColor[
              0.9189757209517455, 0.6669480138238988, 0.3356785999121213], 
             UndirectedEdge[3, 115] -> 
             RGBColor[
              0.6529735529155825, 0.7222241006469869, 0.9530066800693597], 
             UndirectedEdge[74, 123] -> 
             RGBColor[
              0.20225228122772315`, 0.32991034947858455`, 0.9348293402592576],
              UndirectedEdge[52, 147] -> 
             RGBColor[
              0.20606540532151835`, 0.3339181846671946, 0.9350464920353876], 
             UndirectedEdge[64, 76] -> 
             RGBColor[
              0.28111114711231006`, 0.41111591460968555`, 0.939381752805837], 
             UndirectedEdge[132, 260] -> 
             RGBColor[
              0.2275319348126233, 0.35648086821892655`, 0.9362689791330215], 
             UndirectedEdge[171, 285] -> 
             RGBColor[
              0.18941388075270052`, 0.31641637657773114`, 0.9340982123449165],
              UndirectedEdge[226, 290] -> 
             RGBColor[
              0.9663340369194856, 0.9069146206326038, 0.576578764162101], 
             UndirectedEdge[24, 290] -> 
             RGBColor[
              0.9350874753344331, 0.7803505010572445, 0.2666280628425426], 
             UndirectedEdge[103, 265] -> 
             RGBColor[
              0.3220227389937979, 0.445387567907627, 0.9420312197585695], 
             UndirectedEdge[41, 208] -> 
             RGBColor[
              0.1889556017616225, 0.3159346963015419, 0.9340721140343375], 
             UndirectedEdge[80, 179] -> 
             RGBColor[
              0.7507825863487789, 0.7818072220217351, 0.663873785850424], 
             UndirectedEdge[102, 183] -> 
             RGBColor[
              0.19246783079694663`, 0.31962627170585023`, 0.934272130282022], 
             UndirectedEdge[16, 220] -> 
             RGBColor[
              0.2899399087951104, 0.41982488843615623`, 0.9399054307139528], 
             UndirectedEdge[52, 217] -> 
             RGBColor[
              0.19938565089971289`, 0.32689733924898534`, 0.9346660899028769],
              UndirectedEdge[24, 241] -> 
             RGBColor[
              0.9549441101488896, 0.8619933825501465, 0.5685691356523801], 
             UndirectedEdge[105, 163] -> 
             RGBColor[
              0.4524953087499887, 0.5594906748089641, 0.9513970167856213], 
             UndirectedEdge[2, 102] -> 
             RGBColor[
              0.19539325191364892`, 0.3227010747819161, 0.9344387286868456], 
             UndirectedEdge[49, 54] -> 
             RGBColor[
              0.22682934694082163`, 0.355742403819019, 0.936228967793108], 
             UndirectedEdge[216, 237] -> 
             RGBColor[
              0.8457691907154687, 0.3401325922104371, 0.19096561195736456`], 
             UndirectedEdge[89, 281] -> 
             RGBColor[
              0.6796029595718664, 0.743830302697593, 0.9334123929687868], 
             UndirectedEdge[145, 167] -> 
             RGBColor[
              0.8862929429929738, 0.7834059474084649, 0.6157767446761826], 
             UndirectedEdge[16, 90] -> 
             RGBColor[
              0.2312332284112072, 0.3603711624666066, 0.9364797623278878], 
             UndirectedEdge[210, 290] -> 
             RGBColor[
              0.7090449941186435, 0.7036067912817707, 0.613645317642163], 
             UndirectedEdge[152, 242] -> 
             RGBColor[
              0.1817008098525566, 0.3083094500247394, 0.9336589643676192], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.18784627824446665`, 0.31476872694983776`, 0.9340089397011326],
              UndirectedEdge[77, 282] -> 
             RGBColor[
              0.42720741988360567`, 0.5444473278590943, 0.9484422569236628], 
             UndirectedEdge[81, 162] -> 
             RGBColor[
              0.9404065856589258, 0.790829015220349, 0.5112620539625906], 
             UndirectedEdge[34, 247] -> 
             RGBColor[
              0.1907246807083084, 0.31779411044059236`, 0.9341728604632337], 
             UndirectedEdge[7, 60] -> 
             RGBColor[
              0.6127935489939296, 0.6863930727259957, 0.9644818440323379], 
             UndirectedEdge[155, 162] -> 
             RGBColor[
              0.9588310572734952, 0.8681281277104613, 0.5263067793464253], 
             UndirectedEdge[234, 249] -> 
             RGBColor[
              0.2008059288288086, 0.3283901414032867, 0.934746972629826], 
             UndirectedEdge[118, 234] -> 
             RGBColor[
              0.19143808005152518`, 0.3185439383824441, 0.9342134875004501], 
             UndirectedEdge[223, 271] -> 
             RGBColor[
              0.20206279459486376`, 0.3297111870133029, 0.9348185492758365], 
             UndirectedEdge[154, 216] -> 
             RGBColor[
              0.6818806659330219, 0.5446461937629699, 0.581927314015972], 
             UndirectedEdge[147, 247] -> 
             RGBColor[
              0.2055770841992048, 0.33340492820629564`, 0.9350186828698783], 
             UndirectedEdge[4, 286] -> 
             RGBColor[
              0.22071420539136402`, 0.34931500232817103`, 0.9358807195284078],
              UndirectedEdge[88, 124] -> 
             RGBColor[
              0.20439146202389424`, 0.3321587641272566, 0.9349511634409652], 
             UndirectedEdge[23, 136] -> 
             RGBColor[
              0.6909810750975458, 0.7521740618261392, 0.8862275585719336], 
             UndirectedEdge[11, 104] -> 
             RGBColor[
              0.4334513122055766, 0.547724101182389, 0.9494290167598639], 
             UndirectedEdge[4, 121] -> 
             RGBColor[
              0.2229935575329976, 0.35171074594830076`, 0.9360105252608744], 
             UndirectedEdge[4, 213] -> 
             RGBColor[
              0.21145636706915383`, 0.33958442727067606`, 0.9353534993317023],
              UndirectedEdge[198, 204] -> 
             RGBColor[
              0.7240997016369111, 0.7823833581016821, 0.9486564217578735], 
             UndirectedEdge[156, 168] -> 
             RGBColor[
              0.3974514720884778, 0.5186742214563766, 0.9465462342423088], 
             UndirectedEdge[31, 226] -> 
             RGBColor[
              0.7029528418062473, 0.7632425995782364, 0.912689477230743], 
             UndirectedEdge[36, 242] -> 
             RGBColor[
              0.18110760662426995`, 0.30768595582055314`, 0.9336251823213337],
              UndirectedEdge[216, 269] -> 
             RGBColor[
              0.9198143078765437, 0.7038328982122137, 0.28026875837406984`], 
             UndirectedEdge[97, 202] -> 
             RGBColor[
              0.6577144481717172, 0.5251054048614994, 0.5800987564788447], 
             UndirectedEdge[23, 59] -> 
             RGBColor[
              0.9871771704378065, 0.988965444691414, 0.8621710004720957], 
             UndirectedEdge[174, 238] -> 
             RGBColor[
              0.21032414623090429`, 0.3383943913827284, 0.9352890210299346], 
             UndirectedEdge[86, 97] -> 
             RGBColor[
              0.5215176139849236, 0.6223094238976072, 0.9555083823712963], 
             UndirectedEdge[46, 212] -> 
             RGBColor[
              0.21903868251240277`, 0.34755392154809645`, 0.9357853009791648],
              UndirectedEdge[59, 291] -> 
             RGBColor[
              0.955941254786202, 0.9662985742039245, 0.945506158028788], 
             UndirectedEdge[125, 149] -> 
             RGBColor[
              0.865349139567608, 0.4449573647077131, 0.20792686311137834`], 
             UndirectedEdge[32, 80] -> 
             RGBColor[
              0.9832422855582464, 0.9646748589231064, 0.6130382528147665], 
             UndirectedEdge[69, 90] -> 
             RGBColor[
              0.21162247094140993`, 0.33975901297201105`, 0.9353629587014987],
              UndirectedEdge[215, 229] -> 
             RGBColor[
              0.2212270314220612, 0.34985401500148217`, 0.9359099242121978], 
             UndirectedEdge[187, 245] -> 
             RGBColor[
              0.22499133551940492`, 0.35381053727845513`, 0.9361242957617526],
              UndirectedEdge[98, 275] -> 
             RGBColor[
              0.17961340510331275`, 0.30611545528417883`, 0.9335400897551883],
              UndirectedEdge[252, 280] -> 
             RGBColor[
              0.2499775972482043, 0.3800726825759171, 0.937547226403346], 
             UndirectedEdge[96, 146] -> 
             RGBColor[
              0.20048974504421074`, 0.3280578121984645, 0.9347289664310452], 
             UndirectedEdge[191, 270] -> 
             RGBColor[
              0.22010792895967446`, 0.34867776735831935`, 0.9358461929825286],
              UndirectedEdge[40, 120] -> 
             RGBColor[
              0.4841619759818365, 0.5839129078583203, 0.9544325893141365], 
             UndirectedEdge[215, 233] -> 
             RGBColor[
              0.2150686635576537, 0.34338117991291517`, 0.9355592142728086], 
             UndirectedEdge[21, 257] -> 
             RGBColor[
              0.1888268034733999, 0.3157993211343368, 0.9340647791623633], 
             UndirectedEdge[200, 245] -> 
             RGBColor[
              0.2954064062007655, 0.4225674449726149, 0.9403266970812623], 
             UndirectedEdge[41, 108] -> 
             RGBColor[
              0.21464006545615802`, 0.34293069613355404`, 0.9355348062449824],
              UndirectedEdge[63, 73] -> 
             RGBColor[
              0.18277574146873998`, 0.309439271307949, 0.933720180132942]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.8649038628242013, 0.8951148792988238, 0.9869764966166072], 
             160 -> RGBColor[
              0.19576440547633542`, 0.32309118070879467`, 0.9344598653331682],
              245 -> RGBColor[
              0.22524249753236514`, 0.35407452447866766`, 0.9361385990668298],
              155 -> RGBColor[
              0.9263138375757084, 0.7455659509853682, 0.2595685879581257], 
             213 -> RGBColor[
              0.20237506472464956`, 0.3300394027187775, 0.9348363325977657], 
             27 -> RGBColor[
              0.9698415036520304, 0.9099304516459211, 0.33734036595263717`], 
             19 -> RGBColor[
              0.18771789764902583`, 0.31463379080422954`, 0.9340016286161444],
              164 -> RGBColor[
              0.18196114135351968`, 0.30858307493822207`, 0.9336737898614731],
              190 -> RGBColor[
              0.2044144915577996, 0.3321829696275479, 0.9349524749388519], 
             103 -> RGBColor[
              0.4213296380105047, 0.5393562886265211, 0.9480677298602272], 
             138 -> RGBColor[
              0.231287806205471, 0.36042852718880986`, 0.9364828704525304], 
             291 -> RGBColor[
              0.926874823682218, 0.9445288413300859, 0.9928873421853748], 28 -> 
             RGBColor[
              0.18347004528514485`, 0.31016902864039503`, 0.9337597197081559],
              195 -> RGBColor[
              0.18372407711397143`, 0.31043603219904004`, 0.9337741864450011],
              114 -> RGBColor[
              0.23913206195702244`, 0.3686733373382309, 0.9369295892130448], 
             93 -> RGBColor[
              0.24113006344271598`, 0.3707733635803057, 0.9370433724418767], 
             34 -> RGBColor[
              0.1836929464736069, 0.31040331192222026`, 0.933772413601086], 
             161 -> RGBColor[
              0.2016546493170191, 0.3292822004483829, 0.9347953060060602], 22 -> 
             RGBColor[
              0.18854143418810532`, 0.3154993799220345, 0.9340485278037318], 
             124 -> 
             RGBColor[
              0.1859244664032461, 0.3127487808548065, 0.9338994953598411], 84 -> 
             RGBColor[
              0.18746791982634672`, 0.31437104826308443`, 0.9339873927489519],
              46 -> RGBColor[
              0.2047087295239663, 0.33249223238575365`, 0.9349692313557391], 
             241 -> RGBColor[
              0.986124206873734, 0.9885300171977407, 0.8796213317111282], 185 -> 
             RGBColor[
              0.5295564396500168, 0.6289567998104505, 0.9561077692398556], 
             121 -> RGBColor[
              0.22544944565233713`, 0.35429204007402687`, 0.9361503844561099],
              126 -> RGBColor[
              0.22348836128871713`, 0.3522308160679321, 0.9360387036027661], 
             236 -> RGBColor[
              0.23143093535124384`, 0.3605789649959291, 0.9364910214456416], 
             78 -> RGBColor[
              0.19413140389541048`, 0.3213747925089622, 0.9343668683089438], 
             254 -> RGBColor[
              0.31878183695974033`, 0.45053453755869494`, 0.9415334746567325],
              290 -> RGBColor[
              0.9464109372448213, 0.8252442542119368, 0.27573918609145315`], 
             251 -> RGBColor[
              0.28560729073547014`, 0.4175217494840773, 0.9395762847380378], 
             165 -> RGBColor[
              0.21779424853057935`, 0.34624594253152846`, 0.935714432304875], 
             100 -> RGBColor[
              0.1806628381309981, 0.3072184759341732, 0.933599853413618], 235 -> 
             RGBColor[
              0.40849384697781144`, 0.528238571579618, 0.9472498446058684], 
             70 -> RGBColor[
              0.20976983040282712`, 0.33781177030176596`, 0.9352574535635624],
              234 -> RGBColor[
              0.1941551643020383, 0.3213997662028249, 0.9343682214289508], 
             257 -> RGBColor[
              0.18407578926115742`, 0.31080570396557056`, 0.9337942159314718],
              135 -> RGBColor[
              0.21307650899259664`, 0.34128729915514544`, 0.9354457640174572],
              265 -> RGBColor[
              0.22271583997709107`, 0.35141884718873295`, 0.9359947096569118],
              111 -> RGBColor[
              0.6142037164471443, 0.6976772724307221, 0.9627715129425172], 
             182 -> RGBColor[
              0.2543436096659436, 0.38466163844813683`, 0.9377958643515997], 
             188 -> RGBColor[
              0.35586441424032067`, 0.4826536021746064, 0.9438963436902155], 
             154 -> RGBColor[
              0.4972976140125026, 0.6027676319143825, 0.9535682363176986], 
             269 -> 
             RGBColor[
              0.9731648978995463, 0.9211410408128702, 0.3502511250338943], 
             208 -> RGBColor[
              0.18931653926981418`, 0.3163140645074111, 0.9340926688914699], 
             86 -> RGBColor[
              0.5941770672605392, 0.6814187364307716, 0.9611949417585145], 
             119 -> RGBColor[
              0.18085158366002294`, 0.307416859452336, 0.933610602192272], 
             140 -> RGBColor[0.817319, 0.134127, 0.164218], 85 -> 
             RGBColor[
              0.23214849009490668`, 0.36133316052711717`, 0.9365318851267661],
              242 -> RGBColor[
              0.18088209567567362`, 0.3074489295153584, 0.9336123398064248], 
             117 -> RGBColor[
              0.1855098238772711, 0.3123129652701522, 0.9338758820813954], 47 -> 
             RGBColor[
              0.18409960782193097`, 0.31083073878312756`, 0.9337955723632715],
              81 -> RGBColor[
              0.8894648943465696, 0.5909677260051436, 0.2294791371904563], 
             275 -> RGBColor[
              0.1801747671672662, 0.30670548240580453`, 0.9335720584942697], 
             23 -> RGBColor[
              0.989346654985427, 0.9898625823050647, 0.82621702707199], 110 -> 
             RGBColor[
              0.18591721951216156`, 0.3127411639127972, 0.9338990826601146], 
             6 -> RGBColor[
              0.2105950138195758, 0.3386790903924193, 0.9353044465383967], 
             218 -> RGBColor[
              0.9671895696970209, 0.9750506153189628, 0.9404236795589124], 
             108 -> RGBColor[
              0.24068546665888524`, 0.3703060641714354, 0.9370180533127597], 
             297 -> RGBColor[
              0.19199315011410678`, 0.319127352211692, 0.9342450979193615], 
             157 -> RGBColor[
              0.18253809113335498`, 0.30918948573755783`, 0.933706646297914], 
             270 -> RGBColor[
              0.2128391460228046, 0.3410378156242125, 0.9354322465474746], 33 -> 
             RGBColor[
              0.20050642775524471`, 0.3280753467855062, 0.9347299164867587], 
             252 -> RGBColor[
              0.23794228148785246`, 0.3674228026286945, 0.9368618329754481], 
             260 -> RGBColor[
              0.25816755850577977`, 0.38868085113116446`, 0.938013632581003], 
             159 -> RGBColor[
              0.29124080035179, 0.42344292527596916`, 0.9398971047766567], 
             183 -> RGBColor[
              0.19274031574857725`, 0.3199126706665578, 0.9342876478969121], 
             99 -> RGBColor[
              0.19567419878950365`, 0.3229963677615002, 0.9344547281958019], 
             17 -> RGBColor[
              0.7036631405833589, 0.768426260552445, 0.9710982238135836], 277 -> 
             RGBColor[
              0.9930111873350895, 0.9874599613241353, 0.4806890552557963], 
             104 -> RGBColor[
              0.3350878162698179, 0.46465795727473413`, 0.9425724772395593], 
             79 -> RGBColor[
              0.18314084159618357`, 0.3098230146905773, 0.9337409720450827], 
             191 -> RGBColor[
              0.2273767118965443, 0.3563177190924262, 0.9362601394175826], 50 -> 
             RGBColor[
              0.1818234123124711, 0.30843831298355445`, 0.9336659463963373], 
             225 -> RGBColor[
              0.2275966301752516, 0.35654886714697176`, 0.936272663438215], 
             61 -> RGBColor[
              0.2772592389822082, 0.4087474177943471, 0.9391008755405253], 
             196 -> RGBColor[
              0.2030597206401025, 0.3307590194956109, 0.934875322739293], 1 -> 
             RGBColor[
              0.8186934053129894, 0.1446912815038851, 0.16553413207988746`], 
             263 -> RGBColor[
              0.20988927253459944`, 0.3379373115553272, 0.935264255616268], 
             201 -> RGBColor[
              0.8453640923839973, 0.3496938695012485, 0.19107401213931735`], 
             293 -> RGBColor[
              0.8997587664774066, 0.6377097951563564, 0.23806859642232206`], 
             184 -> RGBColor[
              0.1914897805011185, 0.3185982788329645, 0.9342164317645705], 
             106 -> RGBColor[
              0.861860606843299, 0.8926882695866354, 0.9866862281444021], 206 -> 
             RGBColor[
              0.22242260484653656`, 0.35111063847433904`, 0.9359780103500293],
              247 -> RGBColor[
              0.19775641494300986`, 0.32518490895896446`, 0.9345733073253814],
              220 -> RGBColor[
              0.33308943974472227`, 0.4629270639700209, 0.9424451424544752], 
             107 -> RGBColor[
              0.40847529455142584`, 0.5282225024003548, 0.9472486624616643], 
             131 -> RGBColor[
              0.22940782651350908`, 0.3584525493349609, 0.9363758083902539], 
             127 -> RGBColor[
              0.34883524619319184`, 0.47656529010844195`, 0.9434484513179017],
              210 -> RGBColor[
              0.4716790509924657, 0.5819693283516046, 0.9515514491928728], 
             181 -> RGBColor[
              0.9862939640410388, 0.9654284637594515, 0.4012550677774902], 
             194 -> 
             RGBColor[
              0.6860055424687634, 0.754632010702607, 0.9693382794531569], 118 -> 
             RGBColor[
              0.1887209958010121, 0.3156881105620633, 0.9340587535719493], 
             276 -> RGBColor[
              0.24137384732010603`, 0.3710295958922332, 0.9370572555730482], 
             280 -> RGBColor[
              0.2620129130085561, 0.39272256252313964`, 0.938232619831244], 
             189 -> RGBColor[
              0.21583585429987417`, 0.3441875460256914, 0.935602904650621], 
             168 -> RGBColor[
              0.4004114204648772, 0.5212379799686826, 0.9467348395354733], 41 -> 
             RGBColor[
              0.1885946642534308, 0.31555532809567266`, 0.9340515591772053], 
             14 -> RGBColor[
              0.1801938510546308, 0.30672554078141306`, 0.9335731452934231], 
             77 -> RGBColor[
              0.4137826929511934, 0.5328195041366336, 0.9475868451945494], 51 -> 
             RGBColor[
              0.8112967405816618, 0.8525104469167772, 0.981826135168235], 179 -> 
             RGBColor[
              0.5227567642523288, 0.6234365170007214, 0.9555724738845179], 
             223 -> RGBColor[
              0.1814903715451621, 0.30808826602110845`, 0.9336469802173286], 
             292 -> RGBColor[
              0.773715577090376, 0.8231517563699634, 0.978080396007364], 143 -> 
             RGBColor[
              0.3068945586163886, 0.4398960177176607, 0.9407885631521654], 
             112 -> RGBColor[
              0.18923133529375677`, 0.3162245097263307, 0.9340878166510814], 
             197 -> RGBColor[
              0.9863417120240653, 0.9886199611670301, 0.8760167084848537], 54 -> 
             RGBColor[
              0.24403688677483204`, 0.37382861920560384`, 0.937208911730381], 
             71 -> RGBColor[
              0.22331684544677569`, 0.35205054204331915`, 0.9360289360293025],
              177 -> RGBColor[
              0.29197171960673096`, 0.42421116775586953`, 0.9399387295469274],
              158 -> RGBColor[
              0.19294565339664288`, 0.32012849355383366`, 0.9342993415721996],
              226 -> RGBColor[
              0.9862571365941499, 0.9885849870532707, 0.8774183422327487], 
             203 -> RGBColor[
              0.9371250918628792, 0.9526285769763242, 0.9913149984604726], 
             115 -> RGBColor[
              0.3517287364030146, 0.47907148589714393`, 0.9436328219554587], 
             173 -> RGBColor[
              0.20128694378722742`, 0.32889571862269473`, 0.9347743657201101],
              212 -> 
             RGBColor[
              0.23336863550083925`, 0.36261561071043924`, 0.9366013706025906],
              129 -> RGBColor[
              0.18908769389738214`, 0.3160735335113504, 0.9340796364860563], 
             279 -> RGBColor[
              0.23666672657285628`, 0.3660821135381808, 0.9367891920100534], 
             26 -> RGBColor[
              0.2290956026577889, 0.35812438226646315`, 0.9363580277035645], 
             40 -> RGBColor[
              0.6892336433588957, 0.7571538276524538, 0.9696600263815672], 
             146 -> RGBColor[
              0.20002902465321373`, 0.3275735658561667, 0.9347027290863527], 
             192 -> RGBColor[
              0.3306172943235091, 0.4607858158598078, 0.9422876195342679], 
             300 -> RGBColor[
              0.2256459244954445, 0.3544985517956109, 0.9361615736355604], 
             221 -> RGBColor[
              0.1861956076915163, 0.31303376754012907`, 0.9339149364550904], 
             62 -> RGBColor[
              0.20167701950442632`, 0.3293057129336997, 0.9347965799551393], 
             286 -> RGBColor[
              0.22089074136906994`, 0.34950055283376746`, 0.9358907729911765],
              152 -> RGBColor[
              0.1825195240294396, 0.3091699705341204, 0.9337055889288136], 64 -> 
             RGBColor[
              0.2353045398184947, 0.3646503688917182, 0.9367116174895672], 37 -> 
             RGBColor[
              0.22656828106141946`, 0.3554680070272346, 0.9362141004774884], 
             148 -> RGBColor[
              0.2462972527349853, 0.37620440714520426`, 0.9373376362279], 261 -> 
             RGBColor[
              0.24473644409614725`, 0.3745638983048021, 0.9372487504849276], 
             15 -> RGBColor[
              0.2583760710911756, 0.38890001107887695`, 0.9380255070642746], 
             136 -> RGBColor[
              0.39261549520966454`, 0.5144855413472138, 0.9462380900718772], 
             198 -> RGBColor[
              0.964591061095168, 0.9731126518583681, 0.9448222768222637], 63 -> 
             RGBColor[
              0.18288267188311363`, 0.3095516619532356, 0.9337262696618512], 
             171 -> RGBColor[
              0.17914809400855325`, 0.30562638382115925`, 0.9335135909767078],
              59 -> RGBColor[
              0.985007685890186, 0.9880683070777632, 0.8981249738722014], 229 -> 
             RGBColor[
              0.2177123475199571, 0.3461598593765405, 0.9357097681634818], 
             102 -> RGBColor[
              0.19219534584531597`, 0.31933987274514264`, 0.9342566126671321],
              299 -> 
             RGBColor[
              0.8186938987840391, 0.1446950745386128, 0.16553460462832187`], 
             128 -> RGBColor[
              0.8449402545684014, 0.34643606632366236`, 0.19066814456844627`],
              12 -> RGBColor[
              0.42962012936485927`, 0.5465370955454517, 0.948595992638333], 
             222 -> RGBColor[
              0.2214255710569613, 0.35006269274590207`, 0.9359212307506922], 
             92 -> RGBColor[
              0.8315546894535105, 0.24354874725857717`, 0.17785011229759332`],
              271 -> RGBColor[
              0.2226352176445654, 0.3513341080054973, 0.9359901183343445], 
             132 -> RGBColor[
              0.19689631111946682`, 0.3242808853066886, 0.9345243256850401], 
             80 -> RGBColor[
              0.9788084084452291, 0.9401779270427488, 0.37217509781633024`], 
             244 -> RGBColor[
              0.1895037720729246, 0.31651085805472556`, 0.934103331522621], 
             150 -> RGBColor[
              0.9074094141907081, 0.6706162117894943, 0.24435764515870567`], 
             125 -> RGBColor[
              0.8351944719959239, 0.27152571084244637`, 0.18133557217075477`],
              258 -> RGBColor[
              0.340161519599846, 0.46905254408746033`, 0.942895769129249], 
             133 -> RGBColor[
              0.18528931800943133`, 0.31208119962217307`, 0.9338633245984311],
              255 -> RGBColor[
              0.3660178719215669, 0.49144801689048034`, 0.9445433130353144], 
             176 -> RGBColor[
              0.19419263806779313`, 0.3214391535066072, 0.9343703555044731], 
             230 -> RGBColor[
              0.19208551837244375`, 0.31922443710768994`, 0.9342503581550272],
              274 -> RGBColor[
              0.46304655962256364`, 0.5749610829682137, 0.9508718678503764], 
             87 -> RGBColor[
              0.9931480500222558, 0.9877526967730439, 0.4955857141352578], 
             130 -> RGBColor[
              0.9118031822514008, 0.6880360380137298, 0.24789297407533079`], 
             35 -> RGBColor[
              0.20639345636736367`, 0.33426298711601565`, 0.9350651740571405],
              31 -> RGBColor[
              0.41964854701834464`, 0.537900212103202, 0.9479606122287372], 
             18 -> RGBColor[
              0.19997475001447043`, 0.3275165197696367, 0.9346996382259684], 
             24 -> RGBColor[
              0.9237640134240451, 0.7354567479025522, 0.2575169395936321], 
             151 -> RGBColor[
              0.5978280581771518, 0.684382775332144, 0.9614823611374906], 137 -> 
             RGBColor[
              0.26153416243522165`, 0.3922193653160256, 0.9382053556943405], 
             296 -> RGBColor[
              0.18720713771192796`, 0.31409694972628927`, 0.9339725415933283],
              266 -> RGBColor[
              0.1981497507744529, 0.3255983298567432, 0.9345957072190938], 
             283 -> RGBColor[
              0.3058207768282486, 0.438767404976628, 0.9407274128678487], 284 -> 
             RGBColor[
              0.24095771526907575`, 0.3705922147223045, 0.9370335574683543], 
             238 -> RGBColor[
              0.1874435235211163, 0.31434540619947215`, 0.9339860034154601], 
             72 -> RGBColor[
              0.8294154563220671, 0.22710566399236717`, 0.1758015802350048], 
             288 -> RGBColor[
              0.20886533678518346`, 0.33686109016141486`, 0.9352059439901159],
              172 -> RGBColor[
              0.19058407149220488`, 0.3176463212393284, 0.9341648529763892], 
             243 -> RGBColor[
              0.9874175082770378, 0.9890648305643368, 0.8581879805016432], 88 -> 
             RGBColor[
              0.22285845764454237`, 0.35156874739970667`, 0.9360028315220893],
              273 -> RGBColor[
              0.2389301514139497, 0.3684611165555936, 0.9369180907063167], 
             202 -> RGBColor[
              0.8665707356341262, 0.4870106983585556, 0.21037568997361125`], 
             98 -> RGBColor[
              0.1790520430393593, 0.3055254281625532, 0.9335081210161069], 30 -> 
             RGBColor[
              0.24929644188312317`, 0.37935674509947226`, 0.9375084356129837],
              116 -> RGBColor[
              0.2873518174774419, 0.41935535769927346`, 0.9396756329551971], 
             240 -> RGBColor[
              0.18053047455342514`, 0.3070793534218085, 0.9335923155036896], 
             73 -> RGBColor[
              0.1826688110543663, 0.3093268806626624, 0.9337140906040328], 29 -> 
             RGBColor[
              0.19525519293228838`, 0.32255596603906117`, 0.934430866432097], 
             75 -> RGBColor[
              0.3329293714790703, 0.46278842088357813`, 0.9424349430461306], 
             200 -> RGBColor[
              0.3655703148691659, 0.4910603654665621, 0.9445147950956946], 
             156 -> RGBColor[
              0.3944915237120784, 0.5161104629440706, 0.9463576289491441], 25 -> 
             RGBColor[
              0.1911156300253715, 0.31820502296044406`, 0.9341951244484827], 
             38 -> RGBColor[
              0.18611948239069784`, 0.312953755022346, 0.9339106012318261], 3 -> 
             RGBColor[
              0.9542183694281502, 0.96537671539683, 0.9623805381832607], 57 -> 
             RGBColor[
              0.17967566298483006`, 0.30618089226503126`, 0.9335436352494385],
              227 -> RGBColor[
              0.952704487454567, 0.8501960835922951, 0.28080312431882476`], 
             39 -> RGBColor[
              0.20172422019829714`, 0.3293553238556548, 0.934799267964828], 
             109 -> RGBColor[
              0.9928111618057213, 0.9912952449090205, 0.7688011832034702], 
             256 -> RGBColor[
              0.817928104297447, 0.13880884254138265`, 0.16480127896312016`], 
             287 -> RGBColor[
              0.2430009596347453, 0.3727397940997984, 0.9371499172122699], 
             239 -> RGBColor[
              0.23757609093788187`, 0.36703791314285356`, 0.9368409789653577],
              285 -> RGBColor[
              0.1996796674968478, 0.327206369334303, 0.9346828337131252], 216 -> 
             RGBColor[
              0.8664637178535413, 0.48652475561155717`, 0.21028639171424535`],
              21 -> RGBColor[
              0.19357781768564236`, 0.320792938303103, 0.9343353423932549], 
             175 -> RGBColor[
              0.18260859612989327`, 0.30926359095919453`, 0.9337106614531641],
              7 -> RGBColor[
              0.9383196861766793, 0.9535195034595876, 0.9892928618873055], 13 -> 
             RGBColor[
              0.33328873930237535`, 0.463099687229773, 0.9424578416460552], 
             294 -> RGBColor[
              0.5360494193639693, 0.63422809324764, 0.9566189203875064], 193 -> 
             RGBColor[
              0.27956374695486264`, 0.41116960178785156`, 0.939232113860354], 
             60 -> RGBColor[
              0.28726741181117993`, 0.4192666419924039, 0.9396708261773704], 
             65 -> RGBColor[
              0.3774633879291902, 0.5013615475879224, 0.9452726111944477], 69 -> 
             RGBColor[
              0.20756886290590398`, 0.3354984139131004, 0.9351321117206522], 
             217 -> RGBColor[
              0.20003824461178885`, 0.32758325661720833`, 0.9347032541493537],
              214 -> RGBColor[
              0.20083038530367384`, 0.32841584670900015`, 0.9347483653898895],
              170 -> RGBColor[
              0.19757646601375403`, 0.32499577122489554`, 0.9345630595000708],
              74 -> RGBColor[
              0.20590138873724428`, 0.3337457928378705, 0.935037151533554], 
             246 -> RGBColor[
              0.1844498116639085, 0.31119882522525194`, 0.9338155159539919], 
             264 -> 
             RGBColor[
              0.2962099519152749, 0.42866581863159803`, 0.9401800906069961], 
             278 -> RGBColor[
              0.2006299825882091, 0.3282052107487807, 0.934736952751713], 45 -> 
             RGBColor[
              0.29993474933268105`, 0.43258081688308847`, 0.9403922123095734],
              237 -> RGBColor[
              0.8250746635773962, 0.19374042880931708`, 0.17164483220048377`],
              228 -> RGBColor[
              0.426257062503514, 0.5436241760628097, 0.9483817009917713], 180 -> 
             RGBColor[
              0.19488460571983207`, 0.32216645538218325`, 0.9344097620385824],
              53 -> RGBColor[
              0.21587739356825456`, 0.3442312064305009, 0.9356052702505034], 
             48 -> RGBColor[
              0.1928098846058197, 0.31998579194643995`, 0.9342916097404141], 
             5 -> RGBColor[
              0.9710126878169619, 0.9138811308413543, 0.3418901952738247], 
             101 -> RGBColor[
              0.6473280227603806, 0.724416838346381, 0.9654832657505968], 267 -> 
             RGBColor[
              0.1962060745132835, 0.32355540287006146`, 0.9344850177314316], 
             120 -> RGBColor[
              0.27909030860477735`, 0.41067198806418675`, 0.939205152246706], 
             147 -> RGBColor[
              0.21339775345539977`, 0.34162494745362687`, 0.9354640584143752],
              89 -> RGBColor[
              0.3807443443279537, 0.5042033471148679, 0.9454816708349412], 43 -> 
             RGBColor[
              0.2255865897625529, 0.3544361872293025, 0.9361581946103001], 
             199 -> RGBColor[
              0.19839476243792764`, 0.32585585264969186`, 0.9346096602708663],
              268 -> RGBColor[
              0.20504953117466115`, 0.3328504365287066, 0.9349886395055752], 
             169 -> RGBColor[
              0.6047389625257771, 0.6899933588150511, 0.9620264128432912], 20 -> 
             RGBColor[
              0.21900416978762977`, 0.3475176464861269, 0.9357833355305459], 
             4 -> RGBColor[
              0.2205376694136581, 0.34912945182257465`, 0.935870666065639], 
             167 -> RGBColor[
              0.9076820231617462, 0.6716970155181059, 0.2445769927357579], 
             142 -> RGBColor[
              0.8299355921400753, 0.23110365581454728`, 0.17629966288173887`],
              16 -> RGBColor[
              0.24679037784549854`, 0.37672271290229153`, 0.9373657189734305],
              281 -> RGBColor[
              0.9784615748157791, 0.9834572582803182, 0.9213431151026323], 
             289 -> 
             RGBColor[
              0.2434445902532613, 0.3732060780076645, 0.9371751813197018], 
             178 -> RGBColor[
              0.25901133304362195`, 0.3895677116688322, 0.9380616842926806], 
             58 -> RGBColor[
              0.19114091674596853`, 0.31823160090706226`, 0.9341965644898124],
              186 -> RGBColor[
              0.19311599281626868`, 0.32030753108400334`, 0.9343090421501528],
              122 -> RGBColor[
              0.18504035865818397`, 0.31181952755907755`, 0.93384914673168], 
             249 -> RGBColor[
              0.20745669335557887`, 0.3353805166037485, 0.9351257238307011], 
             113 -> RGBColor[
              0.2676326072490897, 0.3986292174791347, 0.9385526531046497], 52 -> 
             RGBColor[
              0.1987330571876369, 0.3262114218807623, 0.9346289256564001], 
             187 -> RGBColor[
              0.22474017350644473`, 0.35354655007824254`, 0.9361099924566755],
              259 -> RGBColor[
              0.18516129488531852`, 0.3119466392015956, 0.9338560338709061], 
             42 -> RGBColor[
              0.8376047344232163, 0.2900520440423452, 0.18364364219313192`], 
             134 -> RGBColor[
              0.24479905803441923`, 0.3746297095238789, 0.9372523162560832], 
             248 -> RGBColor[
              0.22195872707107797`, 0.35062307352078237`, 0.9359515931969625],
              174 -> RGBColor[
              0.23320476894069225`, 0.36244337656598474`, 0.9365920386444091],
              215 -> RGBColor[
              0.22474171532416531`, 0.3535481706264238, 0.9361100802609137], 
             83 -> RGBColor[
              0.846552585818907, 0.35882915084310774`, 0.19221211479479816`], 
             95 -> RGBColor[
              0.28755638833203334`, 0.4195703746379904, 0.9396872829627306], 
             166 -> RGBColor[
              0.18609439165410657`, 0.312927383067344, 0.9339091723514956], 
             233 -> RGBColor[
              0.20539561179114207`, 0.3332141891994065, 0.9350083482847035], 
             295 -> RGBColor[
              0.19692281060910452`, 0.3243087379504625, 0.9345258347917725], 
             141 -> RGBColor[
              0.2938477713702168, 0.42618301710784506`, 0.940045567919488], 
             205 -> RGBColor[
              0.3723597127044757, 0.4969410006264502, 0.9449474095221317], 
             224 -> RGBColor[
              0.20866772558178895`, 0.33665338825737323`, 0.9351946903244223],
              231 -> RGBColor[
              0.23118072954041266`, 0.36031598282478083`, 0.9364767725948611],
              68 -> 
             RGBColor[
              0.8768566069289154, 0.9046456729993274, 0.9881165600196555], 10 -> 
             RGBColor[
              0.19040293767796423`, 0.3174559381160143, 0.9341545376736317], 
             250 -> RGBColor[
              0.18265386603570732`, 0.30931117250048296`, 0.9337132395073293],
              282 -> RGBColor[
              0.4406321468160179, 0.5560751515815551, 0.9492976686527762], 
             232 -> RGBColor[
              0.18790775611424687`, 0.3148333440888988, 0.9340124407748683], 
             253 -> RGBColor[
              0.19184993915614282`, 0.3189768284147727, 0.9342369422671671], 
             55 -> RGBColor[
              0.20213692733288047`, 0.32978910522124555`, 0.9348227710255971],
              91 -> RGBColor[
              0.49015879412300467`, 0.5969720163279171, 0.9530062422656385], 
             105 -> RGBColor[
              0.28384023029084227`, 0.41566445691867016`, 0.9394756532598479],
              36 -> RGBColor[
              0.18133311757286624`, 0.3079229821257478, 0.9336380248362428], 
             123 -> RGBColor[
              0.19860317371820202`, 0.3260749061192986, 0.9346215289849611], 
             94 -> RGBColor[
              0.796888814031874, 0.8412548651917855, 0.9803900876994809], 96 -> 
             RGBColor[
              0.20095046543520778`, 0.32854205854076235`, 0.9347552037757377],
              2 -> RGBColor[
              0.19859115798198185`, 0.32606227681868954`, 0.934620844706559], 
             262 -> RGBColor[
              0.3038398335581257, 0.4366853080006712, 0.9406146010791581], 
             272 -> RGBColor[
              0.17908821045117204`, 0.30556344240551475`, 0.9335101806967048],
              97 -> RGBColor[
              0.44885816070930806`, 0.563200111364443, 0.9498218229840781], 
             209 -> RGBColor[
              0.1804556557285978, 0.30700071409312746`, 0.9335880546823002], 
             66 -> RGBColor[
              0.3863417480503173, 0.5090515368854881, 0.9458383324505404], 
             139 -> RGBColor[
              0.4407231525670485, 0.5561539761890157, 0.9493034674587586], 56 -> 
             RGBColor[
              0.19935669202797407`, 0.3268669016386893, 0.9346644407379722], 
             144 -> RGBColor[
              0.19763991012936863`, 0.32506245501299574`, 0.9345666725485978],
              298 -> RGBColor[
              0.2601377913887575, 0.39075169081115385`, 0.9381258344289902], 
             204 -> RGBColor[
              0.4836083421786542, 0.5916540643449961, 0.9524905666934831], 
             207 -> 
             RGBColor[
              0.18528775379377113`, 0.3120795555323372, 0.9338632355186633], 
             149 -> RGBColor[
              0.895503807139292, 0.6183890185729798, 0.2345181540520019], 219 -> 
             RGBColor[
              0.18433414396946993`, 0.31107725114464163`, 0.9338089288499086],
              9 -> RGBColor[
              0.19896010530687766`, 0.32645006384976655`, 0.9346418557109033],
              11 -> RGBColor[
              0.5318148081413353, 0.630790245090044, 0.9562855562801685], 44 -> 
             RGBColor[
              0.31621931418873805`, 0.44831500913059213`, 0.9413701929717141],
              153 -> RGBColor[
              0.22106916700115545`, 0.3496880894859278, 0.9359009340669666], 
             32 -> RGBColor[
              0.9876761626712638, 0.9891717908034641, 0.8539014078132029], 
             162 -> RGBColor[
              0.9913482769712819, 0.9906903044355545, 0.7930449707347249], 90 -> 
             RGBColor[
              0.21567607897691587`, 0.34401961203092163`, 0.935593805682345], 
             8 -> RGBColor[
              0.2044682273202984, 0.33223944932097826`, 0.9349555351110312], 
             163 -> RGBColor[
              0.6211503872091352, 0.7033168926992579, 0.9633183803113946], 49 -> 
             RGBColor[
              0.20962180710681122`, 0.3376561884324342, 0.9352490238558351], 
             76 -> RGBColor[
              0.3269177544061254, 0.4575814603276529, 0.9420518881221068], 82 -> 
             RGBColor[
              0.6134396494628491, 0.6970569684320459, 0.962711362790644], 67 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 211 -> 
             RGBColor[
              0.2707327274798912, 0.4018876404006824, 
               0.9387292003655769]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJwtl3k4FGrYxsc2dmbMmGEYZp8hUUJS8qQSUSklLeLUoUhCylJkaUGShISD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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 5}], {
             RGBColor[
             0.8948530465649757, 0.5292862061726197, 0.25371216367685606`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 32}], {
             RGBColor[
             0.9031847839921265, 0.5669315361536746, 0.5097177699465452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 51}], {
             RGBColor[
             0.8149950729473256, 0.4986008642103312, 0.5736801336240612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 80}], {
             RGBColor[
             0.8987509068791093, 0.542434604273317, 0.26885461494810886`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 83}], {
             RGBColor[
             0.8326229955659482, 0.2517602161734964, 0.1788731234373428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 92}], {
             RGBColor[
             0.82512404738325, 0.19412001438123114`, 0.1716921221887404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 125}], {
             RGBColor[
             0.8269439386544566, 0.20810849617316574`, 0.17343485212532112`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 128}], {
             RGBColor[
             0.8318168299406954, 0.24556367391377373`, 0.17810113832416685`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 142}], {
             RGBColor[
             0.8243144987265323, 0.1878974686592162, 0.17091689748081318`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 149}], {
             RGBColor[
             0.8570986062261408, 0.38154015003843245`, 0.20002614306594468`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 150}], {
             RGBColor[
             0.8630514097518487, 0.4076537466466897, 0.20494588861929658`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 197}], {
             RGBColor[
             0.9025175586685273, 0.5666556213354577, 0.5207754202823706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 198}], {
             RGBColor[
             0.8916422332040788, 0.5589019666811266, 0.5551782044510756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 237}], {
             RGBColor[
             0.8218840344451928, 0.1692158551566011, 0.1685894821401856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 243}], {
             RGBColor[
             0.9030554567950135, 0.5668780560341109, 0.5118610562907654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 256}], {
             RGBColor[
             0.8183107548052182, 0.14175006202263388`, 0.1651677055215038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 277}], {
             RGBColor[
             0.9058522963240394, 0.5660756214140101, 0.3231115936678419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 281}], {
             RGBColor[
             0.8985774900643843, 0.5640742698921016, 0.5434386235912599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 49}], {
             RGBColor[
             0.20410648254439653`, 0.3318592326255619, 0.934934934281197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 54}], {
             RGBColor[
             0.22131402237840694`, 0.34994544801214666`, 0.9359148782184701]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 102}], {
             RGBColor[
             0.19539325191364892`, 0.3227010747819161, 0.9344387286868456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 165}], {
             RGBColor[
             0.2081927032562806, 0.336154109675109, 0.935167638505717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 172}], {
             RGBColor[
             0.19458761473709335`, 0.321854299029009, 0.9343928488414741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 174}], {
             RGBColor[
             0.21589796346133705`, 0.34425282669233714`, 0.9356064416754841]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 183}], {
             RGBColor[
             0.19566573686527955`, 0.3229874737426237, 0.9344542463017356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 238}], {
             RGBColor[
             0.19301734075154908`, 0.3202038415090809, 0.9343034240610095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 253}], {
             RGBColor[
             0.19522054856906235`, 0.32251955261673115`, 0.9344288934868631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 24}], {
             RGBColor[
             0.9389911914260977, 0.8504167316496911, 0.6099487388884464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 59}], {
             RGBColor[
             0.9696130276591681, 0.9767225112372966, 0.930252756027731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 65}], {
             RGBColor[
             0.6658408786786703, 0.7333691314923763, 0.9538265746888542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 72}], {
             RGBColor[
             0.8918169128751087, 0.5962411896945986, 0.5690910592091327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 106}], {
             RGBColor[
             0.9080394881357245, 0.9290324924917327, 0.9745333831638314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 115}], {
             RGBColor[
             0.6529735529155825, 0.7222241006469869, 0.9530066800693597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 155}], {
             RGBColor[
             0.9402661035019293, 0.855471333191099, 0.6109745630706932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[
             0.972783323199716, 0.9780335099161923, 0.8777127544589929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 169}], {
             RGBColor[
             0.7794786659769637, 0.8276850371059405, 0.962203475513276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 194}], {
             RGBColor[
             0.8201119559484569, 0.8600043630497185, 0.9658594088182089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 200}], {
             RGBColor[
             0.659894342148658, 0.7282185404316961, 0.9534476666394777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 210}], {
             RGBColor[
             0.7129487102103079, 0.7736730218742174, 0.9569659936880668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 227}], {
             RGBColor[
             0.9534614284413586, 0.9077863994945625, 0.6215918312510428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 228}], {
             RGBColor[
             0.690237715965832, 0.7545004457298199, 0.955381119587516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 241}], {
             RGBColor[
             0.9701712881509421, 0.9769533662972854, 0.9210009349471945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 264}], {
             RGBColor[
             0.6252141606717125, 0.697021267014214, 0.9512803143951285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 290}], {
             RGBColor[
             0.9503146533364857, 0.8953104848043834, 0.619059862137357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 291}], {
             RGBColor[
             0.940546596555184, 0.9549527783634579, 0.9776339401843177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 8}], {
             RGBColor[
             0.21250294836697825`, 0.34068445057177643`, 0.935413100588335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 15}], {
             RGBColor[
             0.23945687025241685`, 0.36901473145072583`, 0.9369480865649568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 62}], {
             RGBColor[
             0.21110734445904222`, 0.33921758237813715`, 0.9353336230103891]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 85}], {
             RGBColor[
             0.2263430797542824, 0.3552313061748459, 0.9362012755962026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 121}], {
             RGBColor[
             0.2229935575329976, 0.35171074594830076`, 0.9360105252608744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 135}], {
             RGBColor[
             0.21680708920312736`, 0.3452083754888601, 0.935658215041548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 158}], {
             RGBColor[
             0.2067416614051505, 0.33462897268820413`, 0.9350850038189193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 173}], {
             RGBColor[
             0.21091230660044274`, 0.33901258522263467`, 0.9353225158928745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 186}], {
             RGBColor[
             0.2068268311149634, 0.334718491453289, 0.9350898541078958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 213}], {
             RGBColor[
             0.21145636706915383`, 0.33958442727067606`, 0.9353534993317023]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 214}], {
             RGBColor[
             0.21068402735866598`, 0.33877264926578743`, 0.9353095157277642]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 249}], {
             RGBColor[
             0.21399718138461848`, 0.3422549842131616, 0.93549819494817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 255}], {
             RGBColor[
             0.2932777706676125, 0.42028873435652747`, 0.9402069895504767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 263}], {
             RGBColor[
             0.21521347097412877`, 0.3435333816889509, 0.9355674608409534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 265}], {
             RGBColor[
             0.22162675469537457`, 0.35027414950565383`, 0.9359326878612754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 276}], {
             RGBColor[
             0.23095575836688206`, 0.36007952385740394`, 0.9364639608193436]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 286}], {
             RGBColor[
             0.22071420539136402`, 0.34931500232817103`, 0.9358807195284078]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.7514137479791486, 0.7723356879656991, 0.6490878757769967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 23}], {
             RGBColor[
             0.9801796714011944, 0.9518718565732095, 0.5840536111729073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 51}], {
             RGBColor[
             0.8911547141993119, 0.8831957888790658, 0.6618581652210298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.978010186853574, 0.9509747189595588, 0.6200075845730131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[
             0.9087826368179345, 0.636355140842231, 0.2670511550343114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 92}], {
             RGBColor[
             0.9012836886352362, 0.5787149390499657, 0.259870153785709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 101}], {
             RGBColor[
             0.8091703552886713, 0.8191489845938676, 0.6536867305122107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 128}], {
             RGBColor[
             0.9079764711926817, 0.6301585985825083, 0.2662791699211355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 142}], {
             RGBColor[
             0.9004741399785186, 0.5724923933279508, 0.25909492907778175`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 149}], {
             RGBColor[
             0.933258247478127, 0.766135074707167, 0.2882041746629133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 197}], {
             RGBColor[
             0.9786771999205136, 0.9512505460041922, 0.6089534518793391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 198}], {
             RGBColor[
             0.967801874456065, 0.9434968913498611, 0.6433562360480443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 204}], {
             RGBColor[
             0.7273105149978081, 0.7527675975931751, 0.6471903809836539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 226}], {
             RGBColor[
             0.978634912205556, 0.9512330589473125, 0.6096542687532867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 243}], {
             RGBColor[
             0.9792150980469998, 0.9514729807028455, 0.600039087887734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 256}], {
             RGBColor[
             0.8944703960572045, 0.5263449866913684, 0.2533457371184724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 290}], {
             RGBColor[
             0.9587118125308915, 0.8695626925266455, 0.3088146906826389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 38}], {
             RGBColor[
             0.19835724810513683`, 0.32581642270738265`, 0.9346075238851115]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 52}], {
             RGBColor[
             0.20466403550360635`, 0.3324452561365908, 0.9349666860973984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.21323620369391516`, 0.3414551484114601, 0.9354548583944501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 88}], {
             RGBColor[
             0.21672673573205908`, 0.345123918896063, 0.935653639030243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 93}], {
             RGBColor[
             0.2258625386311459, 0.35472622698636247`, 0.9361739094901367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 124}], {
             RGBColor[
             0.19825974011141095`, 0.3257139356236129, 0.9346019709491189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 147}], {
             RGBColor[
             0.2119963836374878, 0.34015201892302305`, 0.935384252476386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 273}], {
             RGBColor[
             0.22476258261676274`, 0.3535701034740064, 0.9361112686223567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 289}], {
             RGBColor[
             0.22701980203641853`, 0.3559425842000419, 0.9362398139290493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 42}], {
             RGBColor[
             0.8879622102999478, 0.6217857737509664, 0.5864682520402187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 60}], {
             RGBColor[
             0.6127935489939296, 0.6863930727259957, 0.9644818440323379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 77}], {
             RGBColor[
             0.6760511895639363, 0.7431695037981105, 0.9684398535409274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 80}], {
             RGBColor[
             0.9585640473109542, 0.9468487152511682, 0.6807339798518178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 81}], {
             RGBColor[
             0.9138922902616244, 0.7722436147323656, 0.6093859995388808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 82}], {
             RGBColor[
             0.7758796678197641, 0.8252882359458167, 0.9760021123389747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 103}], {
             RGBColor[
             0.6798246620935919, 0.7464378960430543, 0.9686802958737664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 127}], {
             RGBColor[
             0.6435774661849356, 0.7150423967840147, 0.9663706566026036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 130}], {
             RGBColor[
             0.92506143421404, 0.8207777707366587, 0.6185929179813181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 140}], {
             RGBColor[
             0.8778193430883396, 0.5438232517297938, 0.5767554309436527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 145}], {
             RGBColor[
             0.9016117745004403, 0.9243171913792056, 0.9881346792519563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 154}], {
             RGBColor[
             0.7178086500945909, 0.778143567686985, 0.971430549102502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 167}], {
             RGBColor[
             0.9230008546692128, 0.8126082594888467, 0.6169349273115317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 168}], {
             RGBColor[
             0.6693655533207783, 0.7373787417141351, 0.9680138507113893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 181}], {
             RGBColor[
             0.962306825108859, 0.9594739836095195, 0.6952739648323978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 201}], {
             RGBColor[
             0.8918418892803384, 0.651606686480418, 0.5901834370133114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 202}], {
             RGBColor[
             0.9024452109054028, 0.7202651009090716, 0.5998342759304583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 203}], {
             RGBColor[
             0.9377223890197792, 0.9530740402179558, 0.990303930173889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 205}], {
             RGBColor[
             0.6553396994405775, 0.7252302520430189, 0.9671201357047186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 216}], {
             RGBColor[
             0.9023917020151102, 0.7200221295355724, 0.5997896268007754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 237}], {
             RGBColor[
             0.8816971748770377, 0.5736299661344524, 0.5804688470438946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 255}], {
             RGBColor[
             0.6521687790491231, 0.722483760175034, 0.9669180874613099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 269}], {
             RGBColor[
             0.9557422920381128, 0.9373302721362289, 0.6697719934605999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 282}], {
             RGBColor[
             0.6894759164963487, 0.7547973275205713, 0.9692952652700408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 293}], {
             RGBColor[
             0.9190392263270429, 0.795614649307972, 0.6136807291548138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 299}], {
             RGBColor[
             0.8785067924803591, 0.5491072889991002, 0.5774137332578136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 14}], {
             RGBColor[
             0.19233103918746458`, 0.31948249505119564`, 0.9342643402022272]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 64}], {
             RGBColor[
             0.21988638356939655`, 0.34844490910634823`, 0.9358335763002992]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 67}], {
             RGBColor[
             0.1916976136601492, 0.31881672466048916`, 0.9342282675555156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 69}], {
             RGBColor[
             0.2060185451131012, 0.33386893161703934`, 0.9350438234158418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 85}], {
             RGBColor[
             0.21830835870760254`, 0.3467863049240477, 0.9357437101188987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 121}], {
             RGBColor[
             0.21495883648631775`, 0.3432657446975026, 0.9355529597835706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 135}], {
             RGBColor[
             0.2087723681564475, 0.33676337423806185`, 0.9352006495642442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 173}], {
             RGBColor[
             0.2028775855537629, 0.3305675839718365, 0.9348649504155706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 186}], {
             RGBColor[
             0.19879211006828354`, 0.3262734902024908, 0.934632288630592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 213}], {
             RGBColor[
             0.20342164602247398`, 0.3311394260198779, 0.9348959338543985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 234}], {
             RGBColor[
             0.19931169581116837`, 0.32681960776190155`, 0.934661878269991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 249}], {
             RGBColor[
             0.20596246033793864`, 0.3338099829623634, 0.9350406294708662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 263}], {
             RGBColor[
             0.20717874992744892`, 0.3350883804381527, 0.9351098953636496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 286}], {
             RGBColor[
             0.21267948434468417`, 0.34087000107737286`, 0.9354231540511039]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 45}], {
             RGBColor[
             0.24944742731977937`, 0.3795154403664275, 0.9375170340102383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 47}], {
             RGBColor[
             0.1915298565644043, 0.31864040131644705`, 0.9342187140370874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 96}], {
             RGBColor[
             0.19995528537104273`, 0.3274960611952644, 0.9346985297433206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 112}], {
             RGBColor[
             0.19409572030031721`, 0.3213372867880486, 0.9343648361809924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 132}], {
             RGBColor[
             0.19792820821317225`, 0.32536547457822756`, 0.9345830906979717]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 133}], {
             RGBColor[
             0.19212471165815448`, 0.3192656317359698, 0.9342525901546672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 141}], {
             RGBColor[
             0.24640393833854723`, 0.3763165404788058, 0.9373437118151957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 146}], {
             RGBColor[
             0.1994945649800457, 0.3270118148529666, 0.9346722923986279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 236}], {
             RGBColor[
             0.21519552032906075`, 0.34351451442284786`, 0.9355664385782725]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 22}], {
             RGBColor[
             0.18947218593303478`, 0.31647765901902436`, 0.9341015327386817]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 48}], {
             RGBColor[
             0.19160641114189197`, 0.3187208650312271, 0.934223073707023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 63}], {
             RGBColor[
             0.18664280478053893`, 0.31350380003462497`, 0.9339404036677414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 71}], {
             RGBColor[
             0.20685989156236995`, 0.3347532400796667, 0.9350917368514671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 73}], {
             RGBColor[
             0.18653587436616526`, 0.31339140938933835`, 0.9339343141388322]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 100}], {
             RGBColor[
             0.18553288790448116`, 0.3123372070250937, 0.9338771955436248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 119}], {
             RGBColor[
             0.1856272606689936, 0.3124363987841752, 0.9338825699329518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 122}], {
             RGBColor[
             0.1877216481680741, 0.3146377328375459, 0.9340018422026558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 161}], {
             RGBColor[
             0.19602879349749167`, 0.3233690692821986, 0.9344749218398459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 244}], {
             RGBColor[
             0.1899533548754444, 0.3169833980853699, 0.9341289345981263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 266}], {
             RGBColor[
             0.19427634422620857`, 0.3215271339863788, 0.9343751224463628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 51}], {
             RGBColor[
             0.6715557743614986, 0.7416503460034106, 0.9690558457242018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 101}], {
             RGBColor[
             0.589571415450858, 0.6776035417182125, 0.9608844110153827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 104}], {
             RGBColor[
             0.4334513122055766, 0.547724101182389, 0.9494290167598639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 114}], {
             RGBColor[
             0.38547343504917886`, 0.49973179121413747`, 0.9466075727466067]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 116}], {
             RGBColor[
             0.4095833128093886, 0.5250728013946587, 0.9479805946176828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 149}], {
             RGBColor[
             0.7136593076403137, 0.6245896318315118, 0.5954018551660852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 197}], {
             RGBColor[
             0.7590782600827003, 0.809705103128537, 0.9161511323825111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 198}], {
             RGBColor[
             0.7482029346182517, 0.8019514484742061, 0.9505539165512161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 204}], {
             RGBColor[
             0.5077115751599948, 0.6112221547175201, 0.9543880614868259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 243}], {
             RGBColor[
             0.7596161582091865, 0.8099275378271904, 0.907236768390906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 254}], {
             RGBColor[
             0.4252983225505378, 0.5406623913243694, 0.9489095154684506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 283}], {
             RGBColor[
             0.41881779248479195`, 0.534778825033336, 0.9485064845740085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.3382052536051789, 0.4616299042238716, 0.9429808558058818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 27}], {
             RGBColor[
             0.6997308165084448, 0.7282337735956864, 0.6429681792954851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.33246233459167696`, 0.45559373221858496`, 0.9426538050639501]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 76}], {
             RGBColor[
             0.3782689418854923, 0.5020592779365523, 0.9453239403802199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 87}], {
             RGBColor[
             0.7113840896935575, 0.7671448961592477, 0.7220908533867955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 151}], {
             RGBColor[
             0.5137240937710055, 0.6154599354387978, 0.9550391768879118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 154}], {
             RGBColor[
             0.46345887168868094`, 0.5746523637299171, 0.9510821144780158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 181}], {
             RGBColor[
             0.707957046702949, 0.7559827796524516, 0.6749255302079116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 192}], {
             RGBColor[
             0.3801187118441842, 0.5036614557026298, 0.9454418060863005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 220}], {
             RGBColor[
             0.38135478455479077`, 0.5047320797577364, 0.9455205675464041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 239}], {
             RGBColor[
             0.3335981101513706, 0.4567875043441526, 0.9427184858018454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 258}], {
             RGBColor[
             0.3848908244823526, 0.507794819816456, 0.9457458808837911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 32}], {
             RGBColor[
             0.6604824509868196, 0.7261357390166185, 0.898179624729629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 53}], {
             RGBColor[
             0.27458306643531494`, 0.40366544683013694`, 0.9390315559482794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 93}], {
             RGBColor[
             0.2872094013725457, 0.41693652540503934`, 0.939750607043966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 107}], {
             RGBColor[
             0.3708820169269006, 0.49566109481506393`, 0.9448532520538597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 137}], {
             RGBColor[
             0.2974114508687985, 0.42765952627289927`, 0.9403315986701979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 147}], {
             RGBColor[
             0.27334324637888757`, 0.4023623173416999, 0.9389609500302152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 156}], {
             RGBColor[
             0.3638901315072269, 0.4896050750869218, 0.9444077352975997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 179}], {
             RGBColor[
             0.42802275177735205`, 0.5432681021152472, 0.9490151577652866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 251}], {
             RGBColor[
             0.3094480150189227, 0.44031071835692515`, 0.9410170631920465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 270}], {
             RGBColor[
             0.27306394266259, 0.4020687514269927, 0.9389450440967648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 271}], {
             RGBColor[
             0.2779619784734704, 0.40721689761763513`, 0.9392239799901998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 273}], {
             RGBColor[
             0.2861094453581625, 0.4157804018926833, 0.9396879661761859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 274}], {
             RGBColor[
             0.3981676494624695, 0.5190303850989934, 0.9466648547482157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 277}], {
             RGBColor[
             0.6631499633187324, 0.7252798242769541, 0.7115734484509257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 282}], {
             RGBColor[
             0.38696044305919663`, 0.509587419405664, 0.9458777551494157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 289}], {
             RGBColor[
             0.2883666647778183, 0.41815288261871875`, 0.9398165114828785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 67}], {
             RGBColor[
             0.17956042552731538`, 0.30605977039070653`, 0.9335370726467116]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 173}], {
             RGBColor[
             0.1907403974209291, 0.31781062970205387`, 0.9341737555067666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 186}], {
             RGBColor[
             0.18665492193544975`, 0.31351653593270823`, 0.9339410937217879]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.19128445788964016`, 0.31838247175009526`, 0.9342047389455943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 249}], {
             RGBColor[
             0.19382527220510481`, 0.3210530286925808, 0.9343494345620621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 46}], {
             RGBColor[
             0.23154240030757095`, 0.3606961217323153, 0.9364973692100068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 60}], {
             RGBColor[
             0.27282174145117777`, 0.4040833265356404, 0.9388481666208225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.23002654529780098`, 0.3591028620062883, 0.9364110435097069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 77}], {
             RGBColor[
             0.3360793820211845, 0.46085975760775527`, 0.942806176129412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 82}], {
             RGBColor[
             0.43590786027701234`, 0.5429784897554615, 0.9503684349274593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 103}], {
             RGBColor[
             0.33985285455084013`, 0.464128149852699, 0.9430466184622509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 127}], {
             RGBColor[
             0.3036056586421837, 0.43273265059365945`, 0.9407369791910881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 135}], {
             RGBColor[
             0.2357262900418861, 0.3650936551170112, 0.9367356355408658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 158}], {
             RGBColor[
             0.22566086224390924`, 0.3545142523163553, 0.9361624243182372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 168}], {
             RGBColor[
             0.3293937457780264, 0.4550689955237798, 0.942380173299874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 186}], {
             RGBColor[
             0.22574603195372214`, 0.35460377108144014`, 0.9361672746072136]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 196}], {
             RGBColor[
             0.23071789586563907`, 0.35982951528724394`, 0.9364504149017838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 212}], {
             RGBColor[
             0.24587235329600743`, 0.3757578108946581, 0.9373134388334325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 214}], {
             RGBColor[
             0.22960322819742474`, 0.35865792889393855`, 0.936386936227082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 225}], {
             RGBColor[
             0.2429863506332136, 0.37272443911292436`, 0.9371490852512447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 255}], {
             RGBColor[
             0.31219697150637127`, 0.44017401398467865`, 0.9412844100497945]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 265}], {
             RGBColor[
             0.24054595553413333`, 0.37015942913380495`, 0.9370101083605932]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 276}], {
             RGBColor[
             0.24987495920564082`, 0.37996480348555506`, 0.9375413813186614]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 286}], {
             RGBColor[
             0.23963340623012278`, 0.3692002819563222, 0.9369581400277256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.22364840280037163`, 0.35239902984389887`, 0.9360478177300946]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 39}], {
             RGBColor[
             0.22425729902189784`, 0.35303901837897317`, 0.9360824934691292]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 76}], {
             RGBColor[
             0.286854066125812, 0.4171520866149722, 0.9397088035477686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 90}], {
             RGBColor[
             0.2312332284112072, 0.3603711624666066, 0.9364797623278878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 126}], {
             RGBColor[
             0.23513936956710785`, 0.3644767644851118, 0.9367022112880983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 151}], {
             RGBColor[
             0.42230921801132515`, 0.5305527441172178, 0.9494240400554605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 153}], {
             RGBColor[
             0.233929772423327, 0.36320540119410966`, 0.9366333265201985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 192}], {
             RGBColor[
             0.28870383608450384`, 0.4187542643810497, 0.9398266692538492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 220}], {
             RGBColor[
             0.2899399087951104, 0.41982488843615623`, 0.9399054307139528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 222}], {
             RGBColor[
             0.23410797445122994`, 0.3633927028240968, 0.9366434748620613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 239}], {
             RGBColor[
             0.2421832343916902, 0.3718803130225725, 0.9371033489693941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 248}], {
             RGBColor[
             0.23437455245828825`, 0.36367289321153695`, 0.9366586560851965]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 285}], {
             RGBColor[
             0.22323502267117318`, 0.3519645411182973, 0.9360242763432778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 40}], {
             RGBColor[
             0.6964483919711273, 0.7627900441024493, 0.9703791250975754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[
             0.7706339375032876, 0.5292391522973952, 0.5773709330033577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 66}], {
             RGBColor[
             0.5450024443168381, 0.6387388987189666, 0.9584682781320619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 81}], {
             RGBColor[
             0.7965640174649642, 0.6796969932787943, 0.60028868050202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 86}], {
             RGBColor[
             0.648920103921949, 0.7249224984916083, 0.966146582786049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 94}], {
             RGBColor[
             0.7502759773076164, 0.8048405628721153, 0.9757441557565323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 97}], {
             RGBColor[
             0.5762606506463335, 0.665813185958444, 0.9604600233988309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 120}], {
             RGBColor[
             0.4913767245940681, 0.5895491243083159, 0.9551516880301447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 130}], {
             RGBColor[
             0.8077331614173798, 0.7282311492830874, 0.6094955989444572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 140}], {
             RGBColor[
             0.7604910702916794, 0.4512766302762225, 0.5676581119067918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 162}], {
             RGBColor[
             0.8475057087773203, 0.8795582824939998, 0.8820715972741542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 169}], {
             RGBColor[
             0.654201051554568, 0.729209809683748, 0.9665623183284373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 178}], {
             RGBColor[
             0.4813372368134904, 0.5789969861106385, 0.9545799540531321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 182}], {
             RGBColor[
             0.47900337512465124`, 0.5765439495002909, 0.9544470440825916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 201}], {
             RGBColor[
             0.7745136164836781, 0.5590600650268467, 0.5810861179764505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 202}], {
             RGBColor[
             0.7851169381087426, 0.6277184794555003, 0.5907369568935974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 294}], {
             RGBColor[
             0.6198562799736641, 0.7013271769000424, 0.963858572100545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 26}], {
             RGBColor[
             0.21453517633612967`, 0.3428204510180499, 0.9355288329647664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 33}], {
             RGBColor[
             0.20024058888485757`, 0.32779593327757145`, 0.9347147773563635]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 35}], {
             RGBColor[
             0.20318410319091706`, 0.3308897534428262, 0.9348824061415544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 129}], {
             RGBColor[
             0.1945312219559263, 0.32179502664049353`, 0.9343896373560123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 165}], {
             RGBColor[
             0.2088844992725249, 0.33688123115058255`, 0.9352070352654217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 175}], {
             RGBColor[
             0.19129167307218187`, 0.3183900553644156, 0.9342051498395663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 183}], {
             RGBColor[
             0.19635753288152386`, 0.32371459521809726`, 0.9344936430614402]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 184}], {
             RGBColor[
             0.19573226525779447`, 0.3230573993013006, 0.9344580349952694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.2043212377981297, 0.33208495401350496`, 0.9349471642751953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 253}], {
             RGBColor[
             0.19591234458530662`, 0.3232466740922047, 0.9344682902465677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 262}], {
             RGBColor[
             0.25190729178629806`, 0.38210091388515394`, 0.9376571196525632]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 36}], {
             RGBColor[
             0.200168643680248, 0.32772031430593734`, 0.9347106801833944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 37}], {
             RGBColor[
             0.22278622542452461`, 0.3514928267566807, 0.9359987180040172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 41}], {
             RGBColor[
             0.20379941702053028`, 0.3315364872908998, 0.9349174473538756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 44}], {
             RGBColor[
             0.26761174198818394`, 0.3979163278083595, 0.93857676425113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 55}], {
             RGBColor[
             0.21057054856025512`, 0.3386533758536862, 0.9353030532780715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 61}], {
             RGBColor[
             0.248131704384919, 0.378132532140237, 0.9374421055355356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 71}], {
             RGBColor[
             0.22116050761720274`, 0.349784094264723, 0.9359061357799242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 108}], {
             RGBColor[
             0.2298448182232575, 0.3589118553287811, 0.9364006944216527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 136}], {
             RGBColor[
             0.3058098324986471, 0.43100159391667037`, 0.9410107128012115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 152}], {
             RGBColor[
             0.20076184690853469`, 0.3283438085101236, 0.9347444622296798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 177}], {
             RGBColor[
             0.2554879446971804, 0.38586440712099823`, 0.9378610325387366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 208}], {
             RGBColor[
             0.20416035452872197`, 0.331915855496769, 0.9349380022110079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 252}], {
             RGBColor[
             0.2284732256377411, 0.3574702245574107, 0.936322584252997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 268}], {
             RGBColor[
             0.21202685048114545`, 0.34018404150741677`, 0.9353859875180606]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 279}], {
             RGBColor[
             0.22783544818024304`, 0.35679988001215385`, 0.9362862637702997]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 280}], {
             RGBColor[
             0.24050854139809294`, 0.3701201045046333, 0.9370079776808949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 50}], {
             RGBColor[
             0.18770061499905671`, 0.31461562564332873`, 0.9340006443947961]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 74}], {
             RGBColor[
             0.19973960321144332`, 0.32726936557048675`, 0.9346862469634045]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[
             0.21635493982133241`, 0.34473313782066695`, 0.9356324658031498]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 123}], {
             RGBColor[
             0.1960904957019222, 0.3234339222112008, 0.934478435689108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 189}], {
             RGBColor[
             0.20470683599275827`, 0.3324902421643972, 0.934969123521938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 206}], {
             RGBColor[
             0.20800021126608947`, 0.33595178838872103`, 0.9351566763716421]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 257}], {
             RGBColor[
             0.1888268034733999, 0.3157993211343368, 0.9340647791623633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 287}], {
             RGBColor[
             0.21828938866019382`, 0.34676636620145074`, 0.9357426298027625]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 300}], {
             RGBColor[
             0.2096118710905434, 0.33764574504935696`, 0.9352484580144076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.19067565939696252`, 0.3177425859342372, 0.934170068772073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 63}], {
             RGBColor[
             0.18571205303560948`, 0.312525520937635, 0.9338873987327916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 70}], {
             RGBColor[
             0.19915563229546623`, 0.32665557511190024`, 0.9346529906836472]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 73}], {
             RGBColor[
             0.1856051226212358, 0.3124131302923484, 0.9338813092038822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 100}], {
             RGBColor[
             0.1846021361595517, 0.3113589279281038, 0.9338241906086748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 119}], {
             RGBColor[
             0.18469650892406414`, 0.31145811968718523`, 0.933829564998002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 122}], {
             RGBColor[
             0.18679089642314464`, 0.31365945374055604`, 0.9339488372677058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 161}], {
             RGBColor[
             0.1950980417525622, 0.32239079018520866`, 0.934421916904896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 244}], {
             RGBColor[
             0.18902260313051494`, 0.31600511898838, 0.9340759296631764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 266}], {
             RGBColor[
             0.1933455924812791, 0.32054885488938883`, 0.9343221175114128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 24}], {
             RGBColor[
             0.956555334204736, 0.8626596651038085, 0.541866983332811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 31}], {
             RGBColor[
             0.7044976010018857, 0.7638813972041334, 0.8870888196503636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 44}], {
             RGBColor[
             0.6527829845870825, 0.7190887957178285, 0.883793610021852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 59}], {
             RGBColor[
             0.9871771704378065, 0.988965444691414, 0.8621710004720957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 72}], {
             RGBColor[
             0.909381055653747, 0.6084841231487159, 0.5010093036534974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 83}], {
             RGBColor[
             0.917949620402167, 0.6743458665740862, 0.5092145709333941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 106}], {
             RGBColor[
             0.9256036309143629, 0.94127542594585, 0.906451627608196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 136}], {
             RGBColor[
             0.6909810750975458, 0.7521740618261392, 0.8862275585719336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 155}], {
             RGBColor[
             0.9578302462805677, 0.8677142666452164, 0.5428928075150579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 194}], {
             RGBColor[
             0.8376760987270953, 0.8722472965038359, 0.8977776532625734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 197}], {
             RGBColor[
             0.9878441835047461, 0.9892412717360475, 0.8511168677784218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 198}], {
             RGBColor[
             0.9769688580402975, 0.9814876170817164, 0.8855196519471269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 210}], {
             RGBColor[
             0.7305128529889463, 0.7859159553283347, 0.8888842381324313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 226}], {
             RGBColor[
             0.9878018957897885, 0.9892237846791677, 0.8518176846523693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 241}], {
             RGBColor[
             0.9877354309295805, 0.9891962997514028, 0.8529191793915591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 290}], {
             RGBColor[
             0.9678787961151241, 0.9075534182585008, 0.5509781065817215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 291}], {
             RGBColor[
             0.9581107393338224, 0.9671957118175754, 0.9095521846286824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.9468027585380377, 0.8226935997742366, 0.2974286527731346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 59}], {
             RGBColor[
             0.9543858496571156, 0.8617625274901577, 0.5778209567329167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 65}], {
             RGBColor[
             0.6506137006766177, 0.6184091477452374, 0.6013947753940398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 72}], {
             RGBColor[
             0.8765897348730561, 0.4812812059474597, 0.21665925991431845`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 87}], {
             RGBColor[
             0.9584560317231505, 0.8616047223377981, 0.3765513268644449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 106}], {
             RGBColor[
             0.892812310133672, 0.8140725087445938, 0.6221015838690171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 109}], {
             RGBColor[
             0.9582875876148832, 0.8633759964057863, 0.5131590613985512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 155}], {
             RGBColor[
             0.9250389254998768, 0.7405113494439601, 0.2585427637758789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 162}], {
             RGBColor[
             0.9575561451976635, 0.8630735261690534, 0.5252809551641785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 194}], {
             RGBColor[
             0.8048847779464043, 0.7450443793025796, 0.6134276095233945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 210}], {
             RGBColor[
             0.6977215322082554, 0.6587130381270785, 0.6045341943932525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 218}], {
             RGBColor[
             0.945476791560533, 0.8552536816107574, 0.5989703095762722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 226}], {
             RGBColor[
             0.9550105750090976, 0.8620208674779115, 0.5674676409131905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 227}], {
             RGBColor[
             0.9382342504393061, 0.7928264157474236, 0.2691600319562284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 241}], {
             RGBColor[
             0.9549441101488896, 0.8619933825501465, 0.5685691356523801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 290}], {
             RGBColor[
             0.9350874753344331, 0.7803505010572445, 0.2666280628425426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 291}], {
             RGBColor[
             0.9253194185531315, 0.839992794616319, 0.6252021408895034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 299}], {
             RGBColor[
             0.871228956104042, 0.44007591122058254`, 0.21152577211097698`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 28}], {
             RGBColor[
             0.18729283765525817`, 0.3141870258004196, 0.9339774220783192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 58}], {
             RGBColor[
             0.19112827338567, 0.31821831193375316`, 0.9341958444691476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 79}], {
             RGBColor[
             0.18712823581077753`, 0.3140140188255107, 0.9339680482467827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 113}], {
             RGBColor[
             0.22937411863723062`, 0.3584171202197894, 0.9363738887765662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 134}], {
             RGBColor[
             0.21795734402989536`, 0.34641736624216146`, 0.935723720352283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 144}], {
             RGBColor[
             0.19437777007737006`, 0.3216337389867199, 0.9343808984985402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 160}], {
             RGBColor[
             0.19344001775085345`, 0.32064810183461934`, 0.9343274948908254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 176}], {
             RGBColor[
             0.19265413404658233`, 0.31982208823352565`, 0.9342827399764779]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.1930001178726018, 0.32018573917131365`, 0.9343024432435325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 221}], {
             RGBColor[
             0.1886556188584439, 0.3156193952502866, 0.9340550304517865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 230}], {
             RGBColor[
             0.19160057419890764`, 0.31871473003406703`, 0.934222741301755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 232}], {
             RGBColor[
             0.1895116930698092, 0.31651918352467145`, 0.9341037826116756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 245}], {
             RGBColor[
             0.2081790637788683, 0.33613977371955583`, 0.9351668617576563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 288}], {
             RGBColor[
             0.19999048340527747`, 0.32753305656092946`, 0.9347005342192993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 297}], {
             RGBColor[
             0.19155439006973912`, 0.318666187586068, 0.9342201111839221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 35}], {
             RGBColor[
             0.21774452951257628`, 0.3461936846912394, 0.9357116008803525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 54}], {
             RGBColor[
             0.23656624471631046`, 0.3659765007360335, 0.9367834697169728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 75}], {
             RGBColor[
             0.28101248706842963`, 0.4104564015750206, 0.9393964853748475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 102}], {
             RGBColor[
             0.21064547425155244`, 0.3387321275058029, 0.9353073201853483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 129}], {
             RGBColor[
             0.20909164827758553`, 0.33709895788890676`, 0.9352188320948104]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 165}], {
             RGBColor[
             0.2234449255941841, 0.3521851623989958, 0.9360362300042198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 175}], {
             RGBColor[
             0.20585209939384108`, 0.33369398661282884`, 0.9350343445783642]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 183}], {
             RGBColor[
             0.21091795920318307`, 0.3390185264665105, 0.9353228378002383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 224}], {
             RGBColor[
             0.21888166411978893`, 0.3473888852619182, 0.9357763590139934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 253}], {
             RGBColor[
             0.21047277090696587`, 0.3385506053406179, 0.9352974849853658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 262}], {
             RGBColor[
             0.26646771810795733`, 0.39740484513356716`, 0.9384863143913613]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 42}], {
             RGBColor[
             0.9037231190376234, 0.5999912478441332, 0.26049200407288453`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 72}], {
             RGBColor[
             0.8996284799870488, 0.5685180578191442, 0.256570973093821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 87}], {
             RGBColor[
             0.9814947768371431, 0.9488415742094825, 0.4164630400439475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 109}], {
             RGBColor[
             0.9813263327288758, 0.9506128482774708, 0.5530707745780536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 140}], {
             RGBColor[
             0.8935802518260152, 0.5220287258229606, 0.25077918297631857`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 151}], {
             RGBColor[
             0.7838347809145911, 0.7971566134890326, 0.6494113635450639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 154}], {
             RGBColor[
             0.7335695588322665, 0.7563490417801518, 0.6454543011351679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 155}], {
             RGBColor[
             0.9480776706138694, 0.8277482013156446, 0.2984544769553814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 162}], {
             RGBColor[
             0.9805948903116561, 0.9503103780407378, 0.565192668343681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 181}], {
             RGBColor[
             0.9780677338465346, 0.9376794577026863, 0.3692977168650637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 202}], {
             RGBColor[
             0.9182061196430783, 0.6984705750022384, 0.2738580279631242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 203}], {
             RGBColor[
             0.9534832977574548, 0.9312795143111227, 0.6643276822065549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 216}], {
             RGBColor[
             0.9181526107527858, 0.6982276036287391, 0.27381337883344126`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 227}], {
             RGBColor[
             0.9612729955532987, 0.8800632676191081, 0.309071745135731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 299}], {
             RGBColor[
             0.8942677012180347, 0.5273127630922669, 0.2514374852904795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 79}], {
             RGBColor[
             0.1833054434406642, 0.3099960216654862, 0.9337503458766192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 144}], {
             RGBColor[
             0.19055497770725674`, 0.3176157418266954, 0.9341631961283768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 160}], {
             RGBColor[
             0.18961722538074013`, 0.31663010467459485`, 0.9341097925206621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 176}], {
             RGBColor[
             0.18883134167646898`, 0.3158040910735011, 0.9340650376063144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 221}], {
             RGBColor[
             0.18483282648833058`, 0.31160139809026205`, 0.9338373280816231]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 230}], {
             RGBColor[
             0.1877777818287943, 0.3146967328740425, 0.9340050389315915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 232}], {
             RGBColor[
             0.18568890069969585`, 0.3125011863646469, 0.9338860802415121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 240}], {
             RGBColor[
             0.18200025991928498`, 0.3086241910311017, 0.9336760176059227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 245}], {
             RGBColor[
             0.204356271408755, 0.33212177655953135`, 0.9349491593874928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 288}], {
             RGBColor[
             0.19616769103516415`, 0.32351505940090497`, 0.9344828318491358]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 297}], {
             RGBColor[
             0.18773159769962583`, 0.31464819042604353`, 0.9340024088137586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 43}], {
             RGBColor[
             0.21042089134742065`, 0.3384960766341818, 0.9352945305211986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 78}], {
             RGBColor[
             0.1946932984138494, 0.3219653792740117, 0.9343988673705204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 99}], {
             RGBColor[
             0.19546469586089602`, 0.32277616690028066`, 0.9344427973139495]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 131}], {
             RGBColor[
             0.21233150972289871`, 0.34050425768701104`, 0.9354033374111754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 170}], {
             RGBColor[
             0.19641582947302122`, 0.3237758686319784, 0.934496962966084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 178}], {
             RGBColor[
             0.22713326298795516`, 0.3560618388539467, 0.9362462753623888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 182}], {
             RGBColor[
             0.224799401299116, 0.35360880224359903`, 0.9361133653918483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 190}], {
             RGBColor[
             0.199834842245044, 0.32736946783330456`, 0.9346916706854744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 199}], {
             RGBColor[
             0.196824977685108, 0.32420590934437654`, 0.9345202633514818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 209}], {
             RGBColor[
             0.1878554243304431, 0.3147783400660943, 0.9340094605571987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 229}], {
             RGBColor[
             0.20648377022612274`, 0.3343579127078008, 0.9350703172977894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 259}], {
             RGBColor[
             0.19020824390880345`, 0.3172513026203284, 0.9341434501515016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 261}], {
             RGBColor[
             0.21999581851421782`, 0.3485599321719316, 0.9358398084585123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 284}], {
             RGBColor[
             0.21810645410068208`, 0.3465740903806829, 0.9357322119502256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 74}], {
             RGBColor[
             0.22759891531018372`, 0.3565512689686714, 0.9362727935732689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 104}], {
             RGBColor[
             0.2921921290764705, 0.4220073511871032, 0.9400404564262714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 123}], {
             RGBColor[
             0.2239498078006626, 0.3527158256093854, 0.9360649822989724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 189}], {
             RGBColor[
             0.23256614809149867`, 0.36177214556258186`, 0.9365556701318023]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 236}], {
             RGBColor[
             0.2403636886171835, 0.3699678550477007, 0.9369997285293126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 260}], {
             RGBColor[
             0.25373200019445147`, 0.38401879811531836`, 0.9377610340969933]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 267}], {
             RGBColor[
             0.22275125819820335`, 0.35145607398476686`, 0.9359967266722076]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 287}], {
             RGBColor[
             0.24614870075893425`, 0.37604826959963533`, 0.9373291764126268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 300}], {
             RGBColor[
             0.23747118318928384`, 0.36692764844754155`, 0.936835004624272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 37}], {
             RGBColor[
             0.32310841403988205`, 0.4466841095652183, 0.9420873563531128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 44}], {
             RGBColor[
             0.36793393060354135`, 0.4931076106168971, 0.9446654026002257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 59}], {
             RGBColor[
             0.7023281164542653, 0.7629842595904825, 0.9230427930504692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 61}], {
             RGBColor[
             0.3484538930002764, 0.47332381494877457`, 0.9435307438846312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 65}], {
             RGBColor[
             0.3985559674737674, 0.5196308798455622, 0.9466166117115924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 71}], {
             RGBColor[
             0.32148269623256015`, 0.4449753770732606, 0.9419947741290198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 136}], {
             RGBColor[
             0.4061320211140046, 0.526192876725208, 0.9470993511503072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 177}], {
             RGBColor[
             0.3558101333125378, 0.4810556899295358, 0.9439496708878323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 194}], {
             RGBColor[
             0.552827044743554, 0.6462661114029045, 0.958649445840947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 210}], {
             RGBColor[
             0.4456637990054052, 0.5599347702274033, 0.949756030710805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 226}], {
             RGBColor[
             0.7029528418062473, 0.7632425995782364, 0.912689477230743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 241}], {
             RGBColor[
             0.7028863769460394, 0.7632151146504713, 0.9137909719699326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 279}], {
             RGBColor[
             0.32815763679560045`, 0.4519911628206914, 0.9423749021193952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 280}], {
             RGBColor[
             0.3408307300134504, 0.46531138731317084`, 0.9430966160299905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 290}], {
             RGBColor[
             0.683029742131583, 0.6815722331575694, 0.6118498991600951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 291}], {
             RGBColor[
             0.6732616853502813, 0.7412145267166439, 0.970423977207056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 80}], {
             RGBColor[
             0.9832422855582464, 0.9646748589231064, 0.6130382528147665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 92}], {
             RGBColor[
             0.9096154260623872, 0.6163602690310206, 0.515875760055398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 107}], {
             RGBColor[
             0.6980757286113448, 0.7586971466019095, 0.9005750351374335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 125}], {
             RGBColor[
             0.9114353173335938, 0.6303487508229553, 0.5176184899919789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 128}], {
             RGBColor[
             0.9163082086198326, 0.6678039285635632, 0.5222847761908246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 142}], {
             RGBColor[
             0.9088058774056695, 0.6101377233090057, 0.5151005353474709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 145}], {
             RGBColor[
             0.9262900127477325, 0.9421433350511439, 0.920438952214905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 149}], {
             RGBColor[
             0.9415899849052779, 0.803780404688222, 0.5442097809326024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 150}], {
             RGBColor[
             0.9475427884309859, 0.8298940012964792, 0.5491295264859543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 156}], {
             RGBColor[
             0.691083843191671, 0.7526411268737674, 0.9001295183811735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 167}], {
             RGBColor[
             0.947679092916505, 0.830434403160785, 0.5492392002744804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 179}], {
             RGBColor[
             0.7552164634617963, 0.8063041539020928, 0.9047369408488604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 205}], {
             RGBColor[
             0.6800179376878698, 0.7430563957149572, 0.8994244086676673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 237}], {
             RGBColor[
             0.90637541312433, 0.5914561098063906, 0.5127731200068433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 256}], {
             RGBColor[
             0.9028021334843555, 0.5639903166724234, 0.5093513433881616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 269}], {
             RGBColor[
             0.980420530285405, 0.9551564158081671, 0.6020762664235486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 277}], {
             RGBColor[
             0.9903436750031767, 0.9883158760637997, 0.6672952315344995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 282}], {
             RGBColor[
             0.7141541547436409, 0.7726234711925095, 0.9015995382329896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 293}], {
             RGBColor[
             0.9437174645743351, 0.8134407929799102, 0.5459850021177625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 98}], {
             RGBColor[
             0.18977923539730202`, 0.3168003874740297, 0.9341190187514328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 126}], {
             RGBColor[
             0.2119973945219809, 0.3401530814267192, 0.9353843100447624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 153}], {
             RGBColor[
             0.21078779737820008`, 0.338881718135717, 0.9353154252768627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 157}], {
             RGBColor[
             0.19152225944429985`, 0.31863241626153205`, 0.9342182813923363]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 171}], {
             RGBColor[
             0.189827260881899, 0.31685086530333273`, 0.9341217537317332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 184}], {
             RGBColor[
             0.1959981041281816, 0.3233368128092353, 0.9344731741256647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 222}], {
             RGBColor[
             0.210965999406103, 0.33906901976570414`, 0.9353255736187255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 248}], {
             RGBColor[
             0.21123257741316134`, 0.3393492101531443, 0.9353407548418606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 275}], {
             RGBColor[
             0.19034059746125545`, 0.31739041459565537`, 0.9341509874905143]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 285}], {
             RGBColor[
             0.20009304762604624`, 0.3276408580599046, 0.934706375099942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 38}], {
             RGBColor[
             0.18490621443215238`, 0.31167853347228314`, 0.9338415074164561]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 52}], {
             RGBColor[
             0.1912130018306219, 0.3183073669014913, 0.934200669628743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 53}], {
             RGBColor[
             0.1997851700209307, 0.32731725917636056`, 0.9346888419257947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 57}], {
             RGBColor[
             0.18168430472921848`, 0.3082921020936258, 0.9336580244252622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 84}], {
             RGBColor[
             0.1855804331499768, 0.3123871800926523, 0.9338799031750189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 124}], {
             RGBColor[
             0.1848087064384265, 0.3115760463885134, 0.9338359544804635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 147}], {
             RGBColor[
             0.19854534996450335`, 0.32601412968792354`, 0.9346182360077306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 217}], {
             RGBColor[
             0.1918655955426979, 0.3189932842697143, 0.9342378338752199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 223}], {
             RGBColor[
             0.1825916590093845, 0.3092457889716643, 0.9337096969092074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 247}], {
             RGBColor[
             0.1907246807083084, 0.31779411044059236`, 0.9341728604632337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 270}], {
             RGBColor[
             0.19826604624820576`, 0.32572056377321634`, 0.9346023300742803]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 295}], {
             RGBColor[
             0.19030787854135572`, 0.3173560249363414, 0.9341491241964293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 102}], {
             RGBColor[
             0.19929440110633984`, 0.32680142993057915`, 0.9346608933621363]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 129}], {
             RGBColor[
             0.19774057513237292`, 0.32516826031368307`, 0.9345724052715985]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 165}], {
             RGBColor[
             0.2120938524489715, 0.3402544648237721, 0.9353898031810077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 175}], {
             RGBColor[
             0.19450102624862847`, 0.3217632890376051, 0.9343879177551523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 183}], {
             RGBColor[
             0.19956688605797046`, 0.32708782889128674`, 0.9346764109770263]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 224}], {
             RGBColor[
             0.20753059097457632`, 0.33545818768669444`, 0.9351299321907813]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 253}], {
             RGBColor[
             0.19912169776175326`, 0.3266199077653942, 0.9346510581621539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 262}], {
             RGBColor[
             0.25511664496274467`, 0.3854741475583434, 0.9378398875681493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 41}], {
             RGBColor[
             0.18496389091314852`, 0.31173915511071026`, 0.9338447920067241]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 55}], {
             RGBColor[
             0.19173502245287335`, 0.3188560436734967, 0.9342303979309199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 152}], {
             RGBColor[
             0.18192632080115292`, 0.3085464763299341, 0.9336718068825283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 208}], {
             RGBColor[
             0.1853248284213402, 0.31211852331657947`, 0.9338653468638564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 242}], {
             RGBColor[
             0.18110760662426995`, 0.30768595582055314`, 0.9336251823213337]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 250}], {
             RGBColor[
             0.18199349180428678`, 0.3086170773131154, 0.9336756321717861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 268}], {
             RGBColor[
             0.19319132437376368`, 0.32038670932722724`, 0.934313332170909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 41}], {
             RGBColor[
             0.20758147265742513`, 0.3355116675614536, 0.9351328298273469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 44}], {
             RGBColor[
             0.27139379762507876`, 0.4018915080789134, 0.9387921467246012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 55}], {
             RGBColor[
             0.21435260419714997`, 0.34262855612424004`, 0.9355184357515427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 61}], {
             RGBColor[
             0.25191376002181387`, 0.38210771241079083`, 0.937657488009007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 71}], {
             RGBColor[
             0.22494256325409756`, 0.3537592745352769, 0.9361215182533955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 108}], {
             RGBColor[
             0.23362687386015235`, 0.362887035599335, 0.936616076895124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 136}], {
             RGBColor[
             0.309591888135542, 0.4349767741872242, 0.9412260952746828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 152}], {
             RGBColor[
             0.20454390254542953`, 0.33231898878067745`, 0.9349598447031511]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 161}], {
             RGBColor[
             0.21411146518921928`, 0.3423751037378088, 0.9355047032417743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 177}], {
             RGBColor[
             0.2592700003340752, 0.38983958739155206`, 0.9380764150122078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 208}], {
             RGBColor[
             0.20794241016561682`, 0.3358910357673228, 0.9351533846844792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 252}], {
             RGBColor[
             0.23225528127463596`, 0.3614454048279645, 0.9365379667264683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 268}], {
             RGBColor[
             0.21580890611804032`, 0.3441592217779706, 0.9356013699915318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 279}], {
             RGBColor[
             0.23161750381713786`, 0.36077506028270767`, 0.936501646243771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 280}], {
             RGBColor[
             0.2442905970349878, 0.3740952847751871, 0.9372233601543662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 52}], {
             RGBColor[
             0.19242626978916738`, 0.3195825884515542, 0.934269763444113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 53}], {
             RGBColor[
             0.2009984379794762, 0.32859248072642344`, 0.9347579357411648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 57}], {
             RGBColor[
             0.18289757268776397`, 0.30956732364368866`, 0.9337271182406324]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 88}], {
             RGBColor[
             0.20448897001762012`, 0.33226125121102634`, 0.9349567163769577]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 124}], {
             RGBColor[
             0.186021974396972, 0.31285126793857626`, 0.9339050482958335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 147}], {
             RGBColor[
             0.1997586179230488, 0.3272893512379864, 0.9346873298231007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 247}], {
             RGBColor[
             0.19193794866685385`, 0.31906933199065524`, 0.9342419542786038]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 289}], {
             RGBColor[
             0.21478203632197956`, 0.34307991651500525`, 0.935542891275764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 64}], {
             RGBColor[
             0.2185143800083959, 0.3470028463736865, 0.9357554427271977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 69}], {
             RGBColor[
             0.20464654155210055`, 0.3324268688843776, 0.9349656898427401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 76}], {
             RGBColor[
             0.26432098730221126`, 0.39346839209165385`, 0.9384255780434674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 85}], {
             RGBColor[
             0.21693635514660192`, 0.345344242191386, 0.9356655765457971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 90}], {
             RGBColor[
             0.20870014958760652`, 0.3366874679432882, 0.9351965368235865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 118}], {
             RGBColor[
             0.19522260799965463`, 0.322521717208859, 0.9344290107683887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 126}], {
             RGBColor[
             0.21260629074350712`, 0.3407930699617935, 0.9354189857837971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 153}], {
             RGBColor[
             0.2113966935997263, 0.3395217066707913, 0.9353501010158973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 166}], {
             RGBColor[
             0.19390930592620187`, 0.3211413534614994, 0.9343542201581618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 195}], {
             RGBColor[
             0.1927241486561343, 0.3198956780273474, 0.9342867272049146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 234}], {
             RGBColor[
             0.19793969225016772`, 0.3253775450292399, 0.9345837446968894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 239}], {
             RGBColor[
             0.2196501555680895, 0.3481966184992542, 0.9358201234650929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 248}], {
             RGBColor[
             0.21184147363468755`, 0.3399891986882186, 0.9353754305808952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 263}], {
             RGBColor[
             0.2058067463664483, 0.333646317705491, 0.935031761790548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 285}], {
             RGBColor[
             0.20070194384757245`, 0.3282808465949789, 0.9347410508389766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 42}], {
             RGBColor[
             0.763419188891056, 0.5236029358473995, 0.5766518342873496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 66}], {
             RGBColor[
             0.5377876957046065, 0.6331026822689709, 0.9577491794160538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 81}], {
             RGBColor[
             0.7893492688527326, 0.6740607768287987, 0.5995695817860118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 86}], {
             RGBColor[
             0.6417053553097174, 0.7192862820416126, 0.9654274840700409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 94}], {
             RGBColor[
             0.7430612286953848, 0.7992043464221197, 0.9750250570405241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 97}], {
             RGBColor[
             0.5690459020341019, 0.6601769695084484, 0.9597409246828227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 120}], {
             RGBColor[
             0.4841619759818365, 0.5839129078583203, 0.9544325893141365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 130}], {
             RGBColor[
             0.8005184128051482, 0.7225949328330918, 0.608776500228449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 140}], {
             RGBColor[
             0.7532763216794478, 0.4456404138262269, 0.5669390131907837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 162}], {
             RGBColor[
             0.8402909601650888, 0.8739220660440041, 0.881352498558146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 169}], {
             RGBColor[
             0.6469863029423364, 0.7235735932337524, 0.9658432196124291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 178}], {
             RGBColor[
             0.4741224882012588, 0.573360769660643, 0.953860855337124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 182}], {
             RGBColor[
             0.47178862651241965`, 0.5709077330502953, 0.9537279453665835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 201}], {
             RGBColor[
             0.7672988678714465, 0.5534238485768511, 0.5803670192604423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 202}], {
             RGBColor[
             0.777902189496511, 0.6220822630055047, 0.5900178581775892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 55}], {
             RGBColor[
             0.19536579579315563`, 0.32267221665845913`, 0.9344371651014012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 108}], {
             RGBColor[
             0.21464006545615802`, 0.34293069613355404`, 0.9355348062449824]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 152}], {
             RGBColor[
             0.1855570941414352, 0.31236264931489655`, 0.9338785740530094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 208}], {
             RGBColor[
             0.1889556017616225, 0.3159346963015419, 0.9340721140343375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 219}], {
             RGBColor[
             0.18646440411145038`, 0.3133162896201571, 0.933930244013557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 242}], {
             RGBColor[
             0.18473837996455222`, 0.31150212880551553`, 0.933831949491815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.18562426514456906`, 0.3124332502980778, 0.9338823993422674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 252}], {
             RGBColor[
             0.21326847287064163`, 0.3414890653621836, 0.9354566960763266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 268}], {
             RGBColor[
             0.19682209771404596`, 0.32420288231218963`, 0.9345200993413902]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 80}], {
             RGBColor[
             0.9082065714342227, 0.6151149855425471, 0.2779093700047311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 81}], {
             RGBColor[
             0.8635348143848929, 0.4405098850237444, 0.2065613896917941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 82}], {
             RGBColor[
             0.7255221919430327, 0.49355450623719554`, 0.5731775024918879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 87}], {
             RGBColor[
             0.915376392222736, 0.6389023704076946, 0.3396146781641949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 130}], {
             RGBColor[
             0.8747039583373085, 0.4890440410280375, 0.21576830813423137`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 140}], {
             RGBColor[
             0.8274618672116081, 0.2120895220211726, 0.17393082109656596`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 145}], {
             RGBColor[
             0.8512542986237088, 0.5925834616705845, 0.5853100694048696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 162}], {
             RGBColor[
             0.914476505697249, 0.6403711742389498, 0.48834430646392846`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 167}], {
             RGBColor[
             0.8726433787924812, 0.48087452978022555`, 0.21411031746444492`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 181}], {
             RGBColor[
             0.9119493492321276, 0.6277402539008983, 0.29244935498531105`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 201}], {
             RGBColor[
             0.8414844134036068, 0.31987295677179683`, 0.18735882716622465`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 202}], {
             RGBColor[
             0.8520877350286713, 0.3885313712004504, 0.1970096660833716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 203}], {
             RGBColor[
             0.8873649131430477, 0.6213403105093347, 0.5874793203268023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 216}], {
             RGBColor[
             0.8520342261383788, 0.3882883998269512, 0.19696501695368862`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 237}], {
             RGBColor[
             0.8313396990003062, 0.24189623642583113`, 0.17764423719680783`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 269}], {
             RGBColor[
             0.9053848161613813, 0.6055965424276077, 0.2669473836135131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 293}], {
             RGBColor[
             0.8686817504503115, 0.4638809195993508, 0.210856119307727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 299}], {
             RGBColor[
             0.8281493166036277, 0.217373559290479, 0.1745891234107269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 66}], {
             RGBColor[
             0.3059641689064351, 0.4317438620573953, 0.9409982635304203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 78}], {
             RGBColor[
             0.20985899682898168`, 0.3379054898691324, 0.9352625314596219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 97}], {
             RGBColor[
             0.33722237523593046`, 0.45881814929687276`, 0.9429900087971892]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 99}], {
             RGBColor[
             0.21063039427602828`, 0.33871627749540134`, 0.9353064614030511]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 178}], {
             RGBColor[
             0.24229896140308743`, 0.37200194944906734`, 0.9371099394514903]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 182}], {
             RGBColor[
             0.23996509971424826`, 0.36954891283871966`, 0.9369770294809499]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 199}], {
             RGBColor[
             0.21199067610024028`, 0.34014601993949717`, 0.9353839274405833]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 215}], {
             RGBColor[
             0.22516415254335911`, 0.35399217892786317`, 0.9361341374356069]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 229}], {
             RGBColor[
             0.221649468641255, 0.3502980233029215, 0.935933981386891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 233}], {
             RGBColor[
             0.2154911007768475, 0.3438251882143545, 0.9355832714475019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 259}], {
             RGBColor[
             0.20537394232393572`, 0.33319141321544904`, 0.9350071142406031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 261}], {
             RGBColor[
             0.23516151692935008`, 0.3645000427670523, 0.9367034725476139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 284}], {
             RGBColor[
             0.23327215251581435`, 0.3625142009758035, 0.9365958760393271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 59}], {
             RGBColor[
             0.650613500039462, 0.7181916581041776, 0.9197475834219577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 61}], {
             RGBColor[
             0.29673927658547317`, 0.4285312134624696, 0.9402355342561197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 71}], {
             RGBColor[
             0.26976807981775686`, 0.40018277558695564`, 0.9386995645005083]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 108}], {
             RGBColor[
             0.27845239042381165`, 0.4093105366510138, 0.9391941231422369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 136}], {
             RGBColor[
             0.3544174046992013, 0.48140027523890294`, 0.9438041415217957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 177}], {
             RGBColor[
             0.3040955168977345, 0.4362630884432308, 0.9406544612593207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 194}], {
             RGBColor[
             0.5011124283287507, 0.6014735099165995, 0.9553542362124354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 204}], {
             RGBColor[
             0.39991382818369614`, 0.5199845367377941, 0.9469303798325985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 226}], {
             RGBColor[
             0.6512382253914439, 0.7184499980919314, 0.9093942676022314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 252}], {
             RGBColor[
             0.27708079783829526`, 0.4078689058796433, 0.9391160129735812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 268}], {
             RGBColor[
             0.2606344226816996, 0.39058272282964934`, 0.9381794162386446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 279}], {
             RGBColor[
             0.27644302038079716`, 0.4071985613343865, 0.9390796924908837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 280}], {
             RGBColor[
             0.2891161135986471, 0.42051878582686586`, 0.939801406401479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 283}], {
             RGBColor[
             0.3110200455084933, 0.44354120705361005`, 0.9410488029197814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 89}], {
             RGBColor[
             0.34033954683031736`, 0.4683920819989782, 0.9429369415722573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 94}], {
             RGBColor[
             0.5484117816822776, 0.636917841037437, 0.9603911500045271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 96}], {
             RGBColor[
             0.2504426073839444, 0.3805614377119254, 0.9375737080426556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 120}], {
             RGBColor[
             0.2895125289687292, 0.4216264024736376, 0.9397986822781397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 131}], {
             RGBColor[
             0.2646712879230951, 0.39551668310902466`, 0.9383840103499137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 132}], {
             RGBColor[
             0.24841553022607393`, 0.3784308510948885, 0.9374582689973068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 141}], {
             RGBColor[
             0.2968912603514489, 0.4293819169954668, 0.9402188901145307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 146}], {
             RGBColor[
             0.24998188699294738`, 0.3800771913696276, 0.937547470697963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 188}], {
             RGBColor[
             0.32789958178650086`, 0.45761720952884744`, 0.9421442779998944]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 236}], {
             RGBColor[
             0.26568284234196243`, 0.3965798909395088, 0.9384416168776075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 260}], {
             RGBColor[
             0.2790511539192304, 0.41063083400712647`, 0.9392029224452882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 281}], {
             RGBColor[
             0.6391981620742301, 0.7080190375817033, 0.9308676637061029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 294}], {
             RGBColor[
             0.4179920843483252, 0.5334044550653643, 0.9485055663485399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 60}], {
             RGBColor[
             0.2459880706675731, 0.3758794371890788, 0.9373200287665547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 62}], {
             RGBColor[
             0.20319287451419632`, 0.3308989726597267, 0.9348829056554392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 117}], {
             RGBColor[
             0.1951092767006187, 0.3224025988279529, 0.9344225567185672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 158}], {
             RGBColor[
             0.1988271914603046, 0.32631036296979365`, 0.9346342864639694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 196}], {
             RGBColor[
             0.2038842250820344, 0.33162562594068223`, 0.9349222770475161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 207}], {
             RGBColor[
             0.1949982416588687, 0.3222858939590454, 0.9344162334372013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 212}], {
             RGBColor[
             0.21903868251240277`, 0.34755392154809645`, 0.9357853009791648]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 214}], {
             RGBColor[
             0.20276955741382008`, 0.3304540395473769, 0.9348587983728143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 225}], {
             RGBColor[
             0.21615267984960895`, 0.3445205497663627, 0.935620947396977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 265}], {
             RGBColor[
             0.21371228475052867`, 0.3419555397872433, 0.9354819705063254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 276}], {
             RGBColor[
             0.22304128842203616`, 0.35176091413899346`, 0.9360132434643936]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.19252503662856937`, 0.3196863986619449, 0.9342753880695046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 112}], {
             RGBColor[
             0.18666547155784385`, 0.31352762425472913`, 0.9339416945071765]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 131}], {
             RGBColor[
             0.20675371716772, 0.33464164405904423`, 0.9350856903767627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 133}], {
             RGBColor[
             0.18469446291568115`, 0.3114559692026503, 0.9338294484808514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 146}], {
             RGBColor[
             0.19206431623757236`, 0.3192021523196471, 0.9342491507248121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 170}], {
             RGBColor[
             0.1908380369178425, 0.3179132550040116, 0.9341793159316711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 190}], {
             RGBColor[
             0.1942570496898653, 0.32150685420533776`, 0.9343740236510617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.18784627824446665`, 0.31476872694983776`, 0.9340089397011326]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 70}], {
             RGBColor[
             0.2012898575043234, 0.328898781124103, 0.9347745316519882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 71}], {
             RGBColor[
             0.2080633650262977, 0.3360181669948795, 0.9351602728848583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 73}], {
             RGBColor[
             0.187739347830093, 0.31465633630455114`, 0.9340028501722235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 100}], {
             RGBColor[
             0.18673636136840888`, 0.31360213394030656`, 0.9339457315770161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 119}], {
             RGBColor[
             0.1868307341329213, 0.31370132569938797`, 0.933951105966343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 122}], {
             RGBColor[
             0.1889251216320018, 0.3159026597527588, 0.9340703782360471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 138}], {
             RGBColor[
             0.21204884540564534`, 0.34020715956762493`, 0.9353872400964722]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 161}], {
             RGBColor[
             0.19723226696141938`, 0.3246339961974114, 0.9345434578732372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 244}], {
             RGBColor[
             0.19115682833937214`, 0.31824832500058275`, 0.9341974706315176]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 266}], {
             RGBColor[
             0.19547981769013628`, 0.32279206090159157`, 0.934443658479754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 54}], {
             RGBColor[
             0.22682934694082163`, 0.355742403819019, 0.936228967793108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 102}], {
             RGBColor[
             0.20090857647606358`, 0.32849803058878846`, 0.9347528182614836]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 143}], {
             RGBColor[
             0.2582581828615999, 0.38877610307504745`, 0.9380187935040003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 172}], {
             RGBColor[
             0.20010293929950806`, 0.3276512548358813, 0.9347069384161122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 174}], {
             RGBColor[
             0.22141328802375174`, 0.3500497824992095, 0.9359205312501221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 238}], {
             RGBColor[
             0.19853266531396374`, 0.3260007973159532, 0.9346175136356476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 298}], {
             RGBColor[
             0.23487979924778435`, 0.36420393962179404`, 0.9366874291424127]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 206}], {
             RGBColor[
             0.20212300857950383`, 0.32977447572894675`, 0.9348219783731833]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 219}], {
             RGBColor[
             0.1830787781409705, 0.30975778206409804`, 0.9337374376231229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 83}], {
             RGBColor[
             0.8289246632002845, 0.6056697988799424, 0.5870191249815166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 101}], {
             RGBColor[
             0.7293123816710212, 0.7884636426315792, 0.9736547004594159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 104}], {
             RGBColor[
             0.5731922784257398, 0.6585842020957557, 0.9621993062038972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 116}], {
             RGBColor[
             0.5493242790295518, 0.6359329023080253, 0.960750884061716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 142}], {
             RGBColor[
             0.8206161663608685, 0.5418070513656623, 0.579062899024987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 149}], {
             RGBColor[
             0.8534002738604769, 0.7354497327448786, 0.6081721446101185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 197}], {
             RGBColor[
             0.8988192263028636, 0.9205652040419037, 0.9289214218265444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 198}], {
             RGBColor[
             0.8879439008384149, 0.9128115493875727, 0.9633242059952494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 204}], {
             RGBColor[
             0.647452541380158, 0.7220822556308867, 0.967158350930859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 226}], {
             RGBColor[
             0.8987769385879059, 0.920547716985024, 0.9296222387004919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 243}], {
             RGBColor[
             0.8993571244293498, 0.920787638740557, 0.9200070578349391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 254}], {
             RGBColor[
             0.5650392887707011, 0.6515224922377361, 0.9616798049124837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 283}], {
             RGBColor[
             0.5585587587049552, 0.6456389259467026, 0.9612767740180419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 53}], {
             RGBColor[
             0.2073052253779457, 0.3352213141556316, 0.9351170979534518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 57}], {
             RGBColor[
             0.18920436008623348`, 0.3161961570728968, 0.9340862804529193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 84}], {
             RGBColor[
             0.1931004885069918, 0.32029123507192336`, 0.9343081592026761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 88}], {
             RGBColor[
             0.21079575741608964`, 0.3388900846402345, 0.9353158785892447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 93}], {
             RGBColor[
             0.21993156031517644`, 0.348492392730534, 0.9358361490491385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 124}], {
             RGBColor[
             0.1923287617954415, 0.3194801013677844, 0.9342642105081206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 137}], {
             RGBColor[
             0.23013360981142927`, 0.35921539359839394`, 0.9364171406753703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 147}], {
             RGBColor[
             0.20606540532151835`, 0.3339181846671946, 0.9350464920353876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 217}], {
             RGBColor[
             0.19938565089971289`, 0.32689733924898534`, 0.9346660899028769]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 247}], {
             RGBColor[
             0.1982447360653234, 0.3256981654198634, 0.9346011164908907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 270}], {
             RGBColor[
             0.20578610160522076`, 0.3336246187524874, 0.9350305861019373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 271}], {
             RGBColor[
             0.21068413741610115`, 0.3387727649431298, 0.9353095219953723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 273}], {
             RGBColor[
             0.2188316043007933, 0.34733626921817795`, 0.9357735081813584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 289}], {
             RGBColor[
             0.22108882372044908`, 0.3497087499442134, 0.9359020534880509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 295}], {
             RGBColor[
             0.19782793389837072`, 0.3252600799156124, 0.9345773802240863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 88}], {
             RGBColor[
             0.21936792560639845`, 0.34789997691510377`, 0.9358040508862964]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 93}], {
             RGBColor[
             0.22850372850548528`, 0.3575022850054033, 0.93632432134619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 107}], {
             RGBColor[
             0.3121763440598402, 0.43622685441542786`, 0.9414269663560839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 124}], {
             RGBColor[
             0.20090092998575032`, 0.32848999364265374`, 0.9347523828051723]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 137}], {
             RGBColor[
             0.2387057780017381, 0.36822528587326325`, 0.936905312972422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 147}], {
             RGBColor[
             0.21463757351182716`, 0.3429280769420639, 0.9355346643324394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 217}], {
             RGBColor[
             0.2079578190900217, 0.3359072315238546, 0.9351542621999286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 247}], {
             RGBColor[
             0.2068169042556322, 0.33470805769473266`, 0.9350892887879424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 251}], {
             RGBColor[
             0.25074234215186236`, 0.3808764779572891, 0.9375907774942707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 270}], {
             RGBColor[
             0.21435826979552958`, 0.3426345110273567, 0.935518758398989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 271}], {
             RGBColor[
             0.21925630560640996`, 0.3477826572179991, 0.935797694292424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 273}], {
             RGBColor[
             0.2274037724911021, 0.35634616149304726`, 0.9362616804784101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 289}], {
             RGBColor[
             0.22966099191075792`, 0.3587186422190827, 0.9363902257851027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 75}], {
             RGBColor[
             0.2884831291269512, 0.41830852004459096`, 0.9398219273882558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 102}], {
             RGBColor[
             0.218116116310074, 0.34658424597537324`, 0.9357327621987566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 111}], {
             RGBColor[
             0.4291203016109882, 0.5357529458181629, 0.9499902123364491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 143}], {
             RGBColor[
             0.2754657226956103, 0.40686231846163223`, 0.9389987374412732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 163}], {
             RGBColor[
             0.4325936369919836, 0.5385727559524309, 0.9502636460208878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 165}], {
             RGBColor[
             0.2309155676527057, 0.3600372808685661, 0.936461672017628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 172}], {
             RGBColor[
             0.21731047913351847`, 0.34573747022246615`, 0.935686882353385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 174}], {
             RGBColor[
             0.23862082785776215`, 0.3681359978857943, 0.936900475187395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 185}], {
             RGBColor[
             0.3867966632124244, 0.5013927095080272, 0.9466583404851183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 235}], {
             RGBColor[
             0.32626536687632174`, 0.4510335953926109, 0.9422293781681247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 238}], {
             RGBColor[
             0.21574020514797415`, 0.344087012702538, 0.9355974575729206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 298}], {
             RGBColor[
             0.25208733908179476`, 0.3822901550083788, 0.9376673730796856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 108}], {
             RGBColor[
             0.22141119699588285`, 0.35004758469634045`, 0.9359204121691784]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 114}], {
             RGBColor[
             0.22063449464495144`, 0.3492312212797382, 0.9358761801193209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 208}], {
             RGBColor[
             0.19572673330134732`, 0.32305158486432833`, 0.9344577199585336]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 219}], {
             RGBColor[
             0.19323553565117518`, 0.3204331781829436, 0.9343158499377529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 242}], {
             RGBColor[
             0.19150951150427703`, 0.318619017368302, 0.9342175554160109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 250}], {
             RGBColor[
             0.1923953966842939, 0.31955013886086425`, 0.9342680052664631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 252}], {
             RGBColor[
             0.22003960441036646`, 0.34860595392497, 0.9358423020005227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 268}], {
             RGBColor[
             0.20359322925377082`, 0.3313197708749761, 0.9349057052655861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 283}], {
             RGBColor[
             0.25397885208056453`, 0.38427825509893676`, 0.9377750919467229]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 57}], {
             RGBColor[
             0.18951617750640207`, 0.3165238969518603, 0.9341040379937053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 84}], {
             RGBColor[
             0.1934123059271604, 0.32061897495088687`, 0.9343259167434621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 110}], {
             RGBColor[
             0.1926369557700678, 0.31980403277574326`, 0.9342817616990433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 148}], {
             RGBColor[
             0.2228269723814797, 0.3515356543919468, 0.936001038482936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 191}], {
             RGBColor[
             0.21336670196225918`, 0.34159231036555776`, 0.9354622900777774]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 217}], {
             RGBColor[
             0.19969746831988144`, 0.32722507912794885`, 0.934683847443663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 223}], {
             RGBColor[
             0.19042353178656807`, 0.3174775838298989, 0.9341557104776503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 246}], {
             RGBColor[
             0.1919032518459413, 0.3190328634319706, 0.934239978345982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 247}], {
             RGBColor[
             0.19855655348549195`, 0.3260259052988269, 0.9346188740316768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 251}], {
             RGBColor[
             0.2424819913817221, 0.3721943255613833, 0.9371203627380049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 270}], {
             RGBColor[
             0.20609791902538932`, 0.3339523586314509, 0.9350483436427234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 271}], {
             RGBColor[
             0.21099595483626973`, 0.3391005048220933, 0.9353272795361584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 278}], {
             RGBColor[
             0.1999933373080916, 0.327536056193735, 0.9347006967448426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 295}], {
             RGBColor[
             0.19813975131853928`, 0.3255878197945759, 0.9345951377648724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.18357179140558838`, 0.31027597026405784`, 0.9337655139991952]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 217}], {
             RGBColor[
             0.18985695379830947`, 0.3168820744411198, 0.9341234446993961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 223}], {
             RGBColor[
             0.1805830172649961, 0.30713457914306985`, 0.9335953077333836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 247}], {
             RGBColor[
             0.18871603896391997`, 0.3156829006119979, 0.9340584712874099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 278}], {
             RGBColor[
             0.19015282278651957`, 0.31719305150690597`, 0.9341402940005757]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 295}], {
             RGBColor[
             0.1882992367969673, 0.3152448151077469, 0.9340347350206055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 134}], {
             RGBColor[
             0.21796998739019388`, 0.34643065521547056`, 0.9357244403729478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 160}], {
             RGBColor[
             0.19345266111115197`, 0.32066139080792844`, 0.9343282149114902]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 164}], {
             RGBColor[
             0.1865510290497441, 0.3134073379226422, 0.9339351771756428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 176}], {
             RGBColor[
             0.19266677740688082`, 0.31983537720683475`, 0.9342834599971428]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 180}], {
             RGBColor[
             0.1930127612329003, 0.32019902814462275`, 0.9343031632641974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 187}], {
             RGBColor[
             0.20794054512620663`, 0.3358890754926524, 0.9351532784732439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 215}], {
             RGBColor[
             0.20794131603506694`, 0.33588988576674306`, 0.935153322375363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 221}], {
             RGBColor[
             0.18866826221874242`, 0.3156326842235957, 0.9340557504724514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 230}], {
             RGBColor[
             0.19161321755920613`, 0.31872801900737613`, 0.9342234613224198]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[
             0.20819170713916685`, 0.33615306269286493`, 0.9351675817783212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 288}], {
             RGBColor[
             0.200003126765576, 0.32754634553423856`, 0.9347012542399642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 296}], {
             RGBColor[
             0.18917402722894824`, 0.3161642753166758, 0.9340845530415703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 297}], {
             RGBColor[
             0.19156703343003767`, 0.3186794765593771, 0.934220831204587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 72}], {
             RGBColor[
             0.9072115711061266, 0.6075869855350652, 0.536963277053603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 83}], {
             RGBColor[
             0.9157801358545465, 0.6734487289604354, 0.5451685443334997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 106}], {
             RGBColor[
             0.9234341463667425, 0.9403782883321993, 0.9424056010083017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 136}], {
             RGBColor[
             0.6888115905499252, 0.7512769242124885, 0.9221815319720392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 155}], {
             RGBColor[
             0.9556607617329471, 0.8668171290315656, 0.5788467809151635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[
             0.8355066141794747, 0.8713501588901851, 0.9337316266626792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 197}], {
             RGBColor[
             0.9856746989571257, 0.9883441341223966, 0.8870708411785275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 198}], {
             RGBColor[
             0.974799373492677, 0.9805904794680657, 0.9214736253472325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 210}], {
             RGBColor[
             0.7283433684413259, 0.785018817714684, 0.9248382115325371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 226}], {
             RGBColor[
             0.9856324112421679, 0.988326647065517, 0.887771658052475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 227}], {
             RGBColor[
             0.9688560866723765, 0.9191321953350291, 0.5894640490955131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 241}], {
             RGBColor[
             0.9855659463819599, 0.9882991621377519, 0.8888731527916648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 290}], {
             RGBColor[
             0.9657093115675036, 0.9066562806448499, 0.5869320799818273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 291}], {
             RGBColor[
             0.955941254786202, 0.9662985742039245, 0.945506158028788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 77}], {
             RGBColor[
             0.3505250523811867, 0.47604307306451876`, 0.9436288356859599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 95}], {
             RGBColor[
             0.28741190007160666`, 0.4194185083151971, 0.9396790545700505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 103}], {
             RGBColor[
             0.35429852491084235`, 0.47931146530946245`, 0.9438692780187988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 127}], {
             RGBColor[
             0.3180513290021859, 0.44791596605042294`, 0.941559638747636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 145}], {
             RGBColor[
             0.5760856373176906, 0.6571907606456139, 0.9633236613969889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 148}], {
             RGBColor[
             0.2667823322730826, 0.39773552456880407`, 0.9385042312026353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 159}], {
             RGBColor[
             0.28925410608148494`, 0.42135478363418655`, 0.9397839654770135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 168}], {
             RGBColor[
             0.3438394161380286, 0.4702523109805432, 0.9432028328564219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 196}], {
             RGBColor[
             0.24516356622564123`, 0.3750128307440074, 0.9372730744583317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 205}], {
             RGBColor[
             0.3298135622578278, 0.45810382130942706`, 0.9423091178497511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 212}], {
             RGBColor[
             0.2603180236560096, 0.39094112635142153`, 0.9381360983899805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 225}], {
             RGBColor[
             0.25743202099321577`, 0.38790775456968785`, 0.9379717448077927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 265}], {
             RGBColor[
             0.2549916258941355, 0.3853427445905684, 0.9378327679171411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 276}], {
             RGBColor[
             0.26432062956564295`, 0.39514811894231855`, 0.9383640408752093]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 282}], {
             RGBColor[
             0.36394977931359895`, 0.4876708967869795, 0.9444842474150733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 71}], {
             RGBColor[
             0.25028804221449197`, 0.3803989799188331, 0.9375649057849139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 108}], {
             RGBColor[
             0.25897235282054676`, 0.38952674098289125`, 0.9380594644266425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 136}], {
             RGBColor[
             0.33493736709593636`, 0.46161647957078045`, 0.9426694828062012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 161}], {
             RGBColor[
             0.23945694414961366`, 0.369014809121365, 0.9369480907732928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 177}], {
             RGBColor[
             0.2846154792944696, 0.4164792927751083, 0.9395198025437264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 194}], {
             RGBColor[
             0.4816323907254858, 0.581689714248477, 0.9542195774968412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 252}], {
             RGBColor[
             0.2576007602350303, 0.3880851102115208, 0.9379813542579867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 268}], {
             RGBColor[
             0.24115438507843467`, 0.37079892716152685`, 0.9370447575230503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 279}], {
             RGBColor[
             0.25696298277753227`, 0.387414765666264, 0.9379450337752894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 280}], {
             RGBColor[
             0.2696360759953822, 0.40073499015874336`, 0.9386667476858847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 117}], {
             RGBColor[
             0.1935934216908487, 0.32080933910192594`, 0.9343362310182673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 135}], {
             RGBColor[
             0.20737676424851148`, 0.33529650604442257`, 0.9351211719862982]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 158}], {
             RGBColor[
             0.1973113364505346, 0.3247171032437667, 0.9345479607636695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 186}], {
             RGBColor[
             0.19739650616034748`, 0.3248066220088515, 0.934552811052646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 196}], {
             RGBColor[
             0.2023683700722644, 0.33003236621465526`, 0.9348359513472162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 207}], {
             RGBColor[
             0.19348238664909873`, 0.3206926342330184, 0.9343299077369014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 212}], {
             RGBColor[
             0.2175228275026328, 0.34596066182206947`, 0.9356989752788649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 214}], {
             RGBColor[
             0.20125370240405008`, 0.3288607798213499, 0.9347724726725144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 225}], {
             RGBColor[
             0.21463682483983898`, 0.34292729004033573`, 0.9355346216966771]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 265}], {
             RGBColor[
             0.2121964297407587, 0.3403622800612163, 0.9353956448060256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 276}], {
             RGBColor[
             0.22152543341226616`, 0.3501676544129665, 0.9359269177640938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 286}], {
             RGBColor[
             0.21128388043674812`, 0.3394031328837336, 0.935343676473158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 71}], {
             RGBColor[
             0.20309975866494467`, 0.3308011019982774, 0.9348776028455769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 73}], {
             RGBColor[
             0.18277574146873998`, 0.309439271307949, 0.933720180132942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 152}], {
             RGBColor[
             0.18270109795627662`, 0.30936081624367795`, 0.9337159292953324]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 161}], {
             RGBColor[
             0.19226866060006637`, 0.3194169312008093, 0.9342607878339557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 208}], {
             RGBColor[
             0.1860996055764639, 0.3129328632303233, 0.9339094692766605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 244}], {
             RGBColor[
             0.18619322197801913`, 0.31303126000398057`, 0.9339148005922362]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 69}], {
             RGBColor[
             0.22143670136219934`, 0.3500743914024093, 0.9359218646051097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 76}], {
             RGBColor[
             0.28111114711231006`, 0.41111591460968555`, 0.939381752805837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 85}], {
             RGBColor[
             0.2337265149567007, 0.3629917647094177, 0.9366217513081667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 90}], {
             RGBColor[
             0.22549030939770529`, 0.3543349904613199, 0.936152711585956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 118}], {
             RGBColor[
             0.2120127678097534, 0.3401692397268907, 0.9353851855307582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 121}], {
             RGBColor[
             0.2303769927354159, 0.3594712044828725, 0.9364310009728385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 173}], {
             RGBColor[
             0.21829574180286104`, 0.34677304375720647`, 0.9357429916048386]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 213}], {
             RGBColor[
             0.21883980227157213`, 0.34734488580524786`, 0.9357739750436664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 234}], {
             RGBColor[
             0.2147298520602665, 0.3430250675472716, 0.9355399194592591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 239}], {
             RGBColor[
             0.23644031537818827`, 0.3658441410172859, 0.9367762982274624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 249}], {
             RGBColor[
             0.22138061658703678`, 0.35001544274773333`, 0.9359186706601341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 258}], {
             RGBColor[
             0.28773302970917036`, 0.41685145648958927`, 0.939803693309408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 263}], {
             RGBColor[
             0.22259690617654707`, 0.3512938402235227, 0.9359879365529176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 286}], {
             RGBColor[
             0.22809764059378232`, 0.35707546086274283`, 0.9363011952403719]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 70}], {
             RGBColor[
             0.2936166091660087, 0.41958665894484415`, 0.940265032379005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 106}], {
             RGBColor[
             0.6196619973862446, 0.6970249085872788, 0.9659794196694249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 115}], {
             RGBColor[
             0.3645960621661024, 0.4902165167425332, 0.9444527165749532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 138}], {
             RGBColor[
             0.30437559706733064`, 0.4308950373883661, 0.9408777408234891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 155}], {
             RGBColor[
             0.6518886127524492, 0.6234637492866453, 0.6024205995762867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 194}], {
             RGBColor[
             0.5317344651989768, 0.6279967791452647, 0.9573054453238024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 200}], {
             RGBColor[
             0.37151685139917806`, 0.49621095652724223`, 0.9448937031450712]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[
             0.424571219460828, 0.5416654379697635, 0.9484120301936603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 211}], {
             RGBColor[
             0.3240980577045407, 0.45162459399430244`, 0.9420009057800123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 231}], {
             RGBColor[
             0.30432205873480145`, 0.4308387652063516, 0.9408746918946544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 241}], {
             RGBColor[
             0.6817937974014621, 0.7449457823928316, 0.912446971452788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 264}], {
             RGBColor[
             0.33683666992223255`, 0.4650136831097602, 0.942726350900722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 291}], {
             RGBColor[
             0.6521691058057041, 0.7229451944590042, 0.9690799766899112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 86}], {
             RGBColor[
             0.49025940765542825`, 0.5952351366581299, 0.9535166371045274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 97}], {
             RGBColor[
             0.4175999543798127, 0.5361258241249656, 0.9478300777173092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 162}], {
             RGBColor[
             0.6888450125107997, 0.7498709206605213, 0.8694416515926326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 169}], {
             RGBColor[
             0.4955403552880472, 0.5995224478502696, 0.9539323726469158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 187}], {
             RGBColor[
             0.305540960778381, 0.4312990434818653, 0.9409741624536079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 193}], {
             RGBColor[
             0.33295274750258996`, 0.46011056933666983`, 0.9425352231554471]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 215}], {
             RGBColor[
             0.3055417316872413, 0.4312998537559559, 0.940974206355727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 228}], {
             RGBColor[
             0.40629940527691566`, 0.5263378564741489, 0.9471100167211559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 118}], {
             RGBColor[
             0.18382399790050605`, 0.31054105528103165`, 0.9337798767859746]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 166}], {
             RGBColor[
             0.1825106958270533, 0.309160691533672, 0.9337050861757479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 173}], {
             RGBColor[
             0.1901069718936137, 0.3171448593113474, 0.934137682860055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 195}], {
             RGBColor[
             0.18132553855698572`, 0.30791501609952, 0.9336375932225005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 213}], {
             RGBColor[
             0.19065103236232478`, 0.3177167013593888, 0.9341686662988828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 234}], {
             RGBColor[
             0.18654108215101917`, 0.31339688310141245`, 0.9339346107144755]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 263}], {
             RGBColor[
             0.19440813626729972`, 0.3216656557776636, 0.934382627808134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 75}], {
             RGBColor[
             0.6048929892039929, 0.6837170469414527, 0.9652757515328931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 83}], {
             RGBColor[
             0.8617045963739112, 0.6317374119212176, 0.5901643374072268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 109}], {
             RGBColor[
             0.9348338843673183, 0.947970458954174, 0.8784588716115629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 111}], {
             RGBColor[
             0.7455301616880299, 0.8011614727150247, 0.9754440364810864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 143}], {
             RGBColor[
             0.5918755827726521, 0.672270845358494, 0.9644525615859105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 163}], {
             RGBColor[
             0.7490034970690254, 0.8039812828492927, 0.9757174701655251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 185}], {
             RGBColor[
             0.7032065232894661, 0.766801236404889, 0.9721121646297556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 218}], {
             RGBColor[
             0.9220230883129681, 0.9398481441591451, 0.964270119789284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 235}], {
             RGBColor[
             0.6426752269533634, 0.7164421222894727, 0.967683202312762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 292}], {
             RGBColor[
             0.8252860920096456, 0.8638987146846454, 0.9830984780135097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 76}], {
             RGBColor[
             0.2672433086560147, 0.39653993712037666`, 0.9385919999213795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 85}], {
             RGBColor[
             0.21985867650040533`, 0.3484157872201088, 0.9358319984237091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 90}], {
             RGBColor[
             0.21162247094140993`, 0.33975901297201105`, 0.9353629587014987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 118}], {
             RGBColor[
             0.19814492935345804`, 0.3255932622375819, 0.9345954326463008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 121}], {
             RGBColor[
             0.21650915427912054`, 0.3448952269935637, 0.9356412480883811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 126}], {
             RGBColor[
             0.21552861209731056`, 0.34386461499051624`, 0.9355854076617092]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 166}], {
             RGBColor[
             0.19683162728000528`, 0.3242128984902222, 0.9345206420360739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 173}], {
             RGBColor[
             0.2044279033465657, 0.3321970662678976, 0.9349532387203812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 195}], {
             RGBColor[
             0.1956464700099377, 0.32296722305607023`, 0.9344531490828267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 213}], {
             RGBColor[
             0.20497196381527677`, 0.33276890831593897`, 0.934984222159209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 234}], {
             RGBColor[
             0.20086201360397116`, 0.32844909005796263`, 0.9347501665748015]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 239}], {
             RGBColor[
             0.22257247692189291`, 0.35126816352797696`, 0.935986545343005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 249}], {
             RGBColor[
             0.20751277813074143`, 0.3354394652584245, 0.9351289177756767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 258}], {
             RGBColor[
             0.273865191252875, 0.4022754790002804, 0.9390139404249507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 263}], {
             RGBColor[
             0.2087290677202517, 0.3367178627342138, 0.9351981836684602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 285}], {
             RGBColor[
             0.2036242652013759, 0.3313523916237017, 0.9349074727168887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 122}], {
             RGBColor[
             0.19740509453050553`, 0.32481564893042175`, 0.9345533001476212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 138}], {
             RGBColor[
             0.22052881830414905`, 0.3491201487452879, 0.9358701620080464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 211}], {
             RGBColor[
             0.24025127894135917`, 0.3698497053512242, 0.9369933269645696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 231}], {
             RGBColor[
             0.2204752799716199, 0.3490638765632734, 0.9358671130792118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 266}], {
             RGBColor[
             0.20395979058864, 0.33170505007925455`, 0.934926580391328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 108}], {
             RGBColor[
             0.23200115605283045`, 0.3611783031073773, 0.936523494671031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 136}], {
             RGBColor[
             0.3079661703282201, 0.43326804169526645`, 0.9411335130505898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 161}], {
             RGBColor[
             0.2124857473818974, 0.34066637124585103`, 0.9354121210176813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 177}], {
             RGBColor[
             0.2576442825267533, 0.3881308548995943, 0.9379838327881149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 208}], {
             RGBColor[
             0.20631669235829492`, 0.33418230327536513`, 0.9350608024603861]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 244}], {
             RGBColor[
             0.20641030875985014`, 0.33428070004902233`, 0.9350661337759618]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 252}], {
             RGBColor[
             0.23062956346731406`, 0.3597366723360068, 0.9364453845023752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 268}], {
             RGBColor[
             0.21418318831071842`, 0.34245048928601285`, 0.9355087877674388]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 279}], {
             RGBColor[
             0.22999178600981598`, 0.35906632779075, 0.9364090640196779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 280}], {
             RGBColor[
             0.2426648792276659, 0.37238655228322937`, 0.9371307779302732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 83}], {
             RGBColor[
             0.8379840210704871, 0.29296740741773747`, 0.18400684751490148`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 87}], {
             RGBColor[
             0.9112817531721615, 0.6074291803827055, 0.3356936471851313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 106}], {
             RGBColor[
             0.845638031582683, 0.5598969667895013, 0.5812439041897035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 109}], {
             RGBColor[
             0.9111133090638942, 0.6092004544506938, 0.4723013817192375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 155}], {
             RGBColor[
             0.8778646469488878, 0.4863358074888676, 0.21768508409656526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 194}], {
             RGBColor[
             0.7577104993954153, 0.4908688373474871, 0.5725699298440808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 210}], {
             RGBColor[
             0.6505472536572664, 0.40453749617198587`, 0.5636765147139389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 218}], {
             RGBColor[
             0.898302513009544, 0.6010781396556649, 0.5581126298969585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 226}], {
             RGBColor[
             0.9078362964581086, 0.6078453255228189, 0.5266099612338768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 227}], {
             RGBColor[
             0.8910599718883171, 0.5386508737923311, 0.22830235227691478`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 241}], {
             RGBColor[
             0.9077698315979006, 0.607817840595054, 0.5277114559730665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 290}], {
             RGBColor[
             0.8879131967834442, 0.526174959102152, 0.22577038316322898`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 291}], {
             RGBColor[
             0.8781451400021425, 0.5858172526612265, 0.5843444612101898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 100}], {
             RGBColor[
             0.1816658245926822, 0.30827267829841776`, 0.9336569720088254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 119}], {
             RGBColor[
             0.18176019735719462`, 0.3083718700574992, 0.9336623463981524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 122}], {
             RGBColor[
             0.18385458485627515`, 0.31057320411086997`, 0.9337816186678564]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 161}], {
             RGBColor[
             0.19216173018569271`, 0.31930454055552265`, 0.9342546983050465]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 244}], {
             RGBColor[
             0.18608629156364545`, 0.31291886935869395`, 0.9339087110633268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 123}], {
             RGBColor[
             0.20225228122772315`, 0.32991034947858455`, 0.9348293402592576]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 189}], {
             RGBColor[
             0.21086862151855923`, 0.33896666943178094`, 0.9353200280920875]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 257}], {
             RGBColor[
             0.19498858899920085`, 0.3222757484017205, 0.9344156837325129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 260}], {
             RGBColor[
             0.23203447362151203`, 0.3612133219845175, 0.9365253920572785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 267}], {
             RGBColor[
             0.2010537316252639, 0.328650597853966, 0.9347610846324927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 287}], {
             RGBColor[
             0.2244511741859948, 0.35324279346883447`, 0.936093534372912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 300}], {
             RGBColor[
             0.2157736566163444, 0.3441221723167407, 0.9355993625845572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 111}], {
             RGBColor[
             0.4735665439631073, 0.5802328466571501, 0.952603227994324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 143}], {
             RGBColor[
             0.31991196504772945`, 0.4513422193006194, 0.941611753099148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.47703987934410275`, 0.583052656791418, 0.9528766616787626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 165}], {
             RGBColor[
             0.27536181000482485`, 0.4045171817075533, 0.9390746876755028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 185}], {
             RGBColor[
             0.43124290556454353`, 0.5458726103470143, 0.9492713561429931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 235}], {
             RGBColor[
             0.3707116092284409, 0.495513496231598, 0.9448423938259995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 262}], {
             RGBColor[
             0.318384602518598, 0.4497368644421247, 0.9415247720626443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 292}], {
             RGBColor[
             0.5533224742847231, 0.6429700886267707, 0.9602576695267473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 85}], {
             RGBColor[
             0.2795331222505161, 0.40945731042738504`, 0.9392918866244364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 87}], {
             RGBColor[
             0.6600329022141906, 0.7226670785503484, 0.7188188011286823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 90}], {
             RGBColor[
             0.2712969166915207, 0.40080053617928724`, 0.938822846902226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 126}], {
             RGBColor[
             0.2752030578474213, 0.40490613819779253`, 0.9390452958624365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 151}], {
             RGBColor[
             0.46237290629163863`, 0.5709821178298984, 0.9517671246297987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 153}], {
             RGBColor[
             0.27399346070364045`, 0.40363477490679034`, 0.9389764110945367]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 192}], {
             RGBColor[
             0.32876752436481727`, 0.45918363809373036`, 0.9421697538281874]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 220}], {
             RGBColor[
             0.3300035970754238, 0.4602542621488369, 0.942248515288291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 239}], {
             RGBColor[
             0.28224692267200363`, 0.41230968673525326`, 0.9394464335437323]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 248}], {
             RGBColor[
             0.2744382407386017, 0.40410226692421763`, 0.9390017406595347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 258}], {
             RGBColor[
             0.3335396370029857, 0.4633170022075566, 0.942473828625678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 82}], {
             RGBColor[
             0.5136111712070213, 0.6149382362843397, 0.9551491039925967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 95}], {
             RGBColor[
             0.3506695406416134, 0.476194939387312, 0.94363706407864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 103}], {
             RGBColor[
             0.41755616548084906`, 0.5360878963815774, 0.9478272875273883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 127}], {
             RGBColor[
             0.3813089695721926, 0.5046923971225378, 0.9455176482562255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 145}], {
             RGBColor[
             0.6393432778876973, 0.7139671917177287, 0.9672816709055783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 154}], {
             RGBColor[
             0.455540153481848, 0.5677935680255081, 0.950577540756124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 159}], {
             RGBColor[
             0.3525117466514917, 0.4781312147063014, 0.9437419749856031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 167}], {
             RGBColor[
             0.6607323580564698, 0.6022582598273698, 0.5960819189651536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 168}], {
             RGBColor[
             0.4070970567080353, 0.527028742052658, 0.9471608423650113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 203}], {
             RGBColor[
             0.6754538924070363, 0.7427240405564789, 0.9694509218275109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 205}], {
             RGBColor[
             0.3930712028278346, 0.5148802523815419, 0.9462671273583405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 212}], {
             RGBColor[
             0.32357566422601636`, 0.4477175574235364, 0.9420941078985701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 225}], {
             RGBColor[
             0.32068966156322254`, 0.4446841856418027, 0.9419297543163823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 255}], {
             RGBColor[
             0.38990028243638014`, 0.512133760513557, 0.9460650791149319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 265}], {
             RGBColor[
             0.31824926646414226`, 0.4421191756626833, 0.9417907774257306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 269}], {
             RGBColor[
             0.6934737954253698, 0.7269802724747518, 0.6489189851142219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 276}], {
             RGBColor[
             0.3275782701356497, 0.45192455001443343`, 0.9423220503837988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 282}], {
             RGBColor[
             0.42720741988360567`, 0.5444473278590943, 0.9484422569236628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 293}], {
             RGBColor[
             0.6567707297143, 0.585264649646495, 0.5928277208084357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 99}], {
             RGBColor[
             0.19490280134245708`, 0.32218558013523124`, 0.9344107982523728]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 131}], {
             RGBColor[
             0.21176961520445978`, 0.33991367092196156`, 0.9353713383495988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 170}], {
             RGBColor[
             0.19585393495458225`, 0.32318528186692885`, 0.9344649639045073]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 178}], {
             RGBColor[
             0.2265713684695162, 0.3554712520888972, 0.9362142763008121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 182}], {
             RGBColor[
             0.22423750678067705`, 0.3530182154785495, 0.9360813663302717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 190}], {
             RGBColor[
             0.19927294772660503`, 0.32677888106825503`, 0.9346596716238978]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.19626308316666907`, 0.323615322579327, 0.9344882642899051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 209}], {
             RGBColor[
             0.18729352981200414`, 0.31418775330104487`, 0.933977461495622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 229}], {
             RGBColor[
             0.20592187570768378`, 0.3337673259427514, 0.9350383182362128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 261}], {
             RGBColor[
             0.21943392399577888`, 0.3479693454068822, 0.9358078093969358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 284}], {
             RGBColor[
             0.2175445595822431, 0.34598350361563335`, 0.935700212888649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 144}], {
             RGBColor[
             0.1903903758627761, 0.31744273485178653`, 0.9341538222968402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 160}], {
             RGBColor[
             0.1894526235362595, 0.316457097699686, 0.9341004186891254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 176}], {
             RGBColor[
             0.18866673983198834`, 0.31563108409859225`, 0.9340556637747779]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 221}], {
             RGBColor[
             0.18466822464384994`, 0.3114283911153532, 0.9338279542500865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 232}], {
             RGBColor[
             0.1855242988552152, 0.31232817938973806`, 0.9338767064099756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 240}], {
             RGBColor[
             0.18183565807480434`, 0.3084511840561929, 0.9336666437743861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 245}], {
             RGBColor[
             0.20419166956427437`, 0.3319487695846225, 0.9349397855559562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 288}], {
             RGBColor[
             0.19600308919068352`, 0.3233420524259961, 0.9344734580175993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 297}], {
             RGBColor[
             0.1875669958551452, 0.3144751834511347, 0.9339930349822221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 92}], {
             RGBColor[
             0.9051815489493698, 0.591863337150663, 0.2750126050569618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 125}], {
             RGBColor[
             0.9070014402205765, 0.6058518189425977, 0.2767553349935425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 128}], {
             RGBColor[
             0.9118743315068152, 0.6433069966832056, 0.2814216211923882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 145}], {
             RGBColor[
             0.9218561356347152, 0.9176464031707863, 0.6795757972164687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 149}], {
             RGBColor[
             0.9371561077922606, 0.7792834728078644, 0.30334662593416606`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 150}], {
             RGBColor[
             0.9431089113179686, 0.8053970694161215, 0.30826637148751795`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 156}], {
             RGBColor[
             0.6866499660786538, 0.7281441949934098, 0.6592663633827371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 167}], {
             RGBColor[
             0.9432452158034876, 0.8059374712804274, 0.30837604527604406`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 179}], {
             RGBColor[
             0.7507825863487789, 0.7818072220217351, 0.663873785850424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 201}], {
             RGBColor[
             0.9120862504146132, 0.6449358982719986, 0.2816245549778238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 205}], {
             RGBColor[
             0.6755840605748524, 0.7185594638345996, 0.6585612536692309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 237}], {
             RGBColor[
             0.9019415360113127, 0.566959177926033, 0.27190996500840703`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 256}], {
             RGBColor[
             0.898368256371338, 0.5394933847920658, 0.2684881883897252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 269}], {
             RGBColor[
             0.9759866531723878, 0.9306594839278095, 0.36121311142511225`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 277}], {
             RGBColor[
             0.9859097978901593, 0.963818944183442, 0.4264320765360633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 281}], {
             RGBColor[
             0.9786349916305042, 0.9618175926615335, 0.6467591064594813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 282}], {
             RGBColor[
             0.7097202776306235, 0.7481265393121519, 0.6607363832345532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 293}], {
             RGBColor[
             0.9392835874613179, 0.7889438610995526, 0.30512184711932616`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 86}], {
             RGBColor[
             0.7418209808035544, 0.6361932312179576, 0.5953370394744854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 94}], {
             RGBColor[
             0.8431768541892217, 0.7161112955984645, 0.6049346124449686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 97}], {
             RGBColor[
             0.6691615275279388, 0.5770839186847934, 0.5896504800872672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.9006340382989853, 0.6395018820094367, 0.23868605563289352`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 140}], {
             RGBColor[
             0.8533919471732848, 0.3625473630025718, 0.19684856859522815`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 162}], {
             RGBColor[
             0.9404065856589258, 0.790829015220349, 0.5112620539625906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 167}], {
             RGBColor[
             0.8985734587541578, 0.6313323707616247, 0.23702806496310708`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 181}], {
             RGBColor[
             0.9378794291938042, 0.7781980948822975, 0.31536710248397326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 201}], {
             RGBColor[
             0.8674144933652834, 0.47033079775319603`, 0.2102765746648868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 202}], {
             RGBColor[
             0.8780178149903479, 0.5389892121818496, 0.21992741358203377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 203}], {
             RGBColor[
             0.9132949931047244, 0.7717981514907339, 0.6103970678254644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 216}], {
             RGBColor[
             0.8779643061000555, 0.5387462408083503, 0.21988276445235083`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 237}], {
             RGBColor[
             0.857269778961983, 0.39235407740723033`, 0.20056198469547004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 269}], {
             RGBColor[
             0.931314896123058, 0.7560543834090069, 0.28986513111217527`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 293}], {
             RGBColor[
             0.8946118304119881, 0.61433876058075, 0.23377386680638917`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 299}], {
             RGBColor[
             0.8540793965653044, 0.3678314002718782, 0.19750687090938907`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 103}], {
             RGBColor[
             0.5173846437366769, 0.6182066285292835, 0.9553895463254356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 140}], {
             RGBColor[
             0.7153793247314246, 0.41559198421602295`, 0.5634646813953219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 145}], {
             RGBColor[
             0.7391717561435251, 0.7960859238654349, 0.9748439297036255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 154}], {
             RGBColor[
             0.5553686317376758, 0.6499123001732142, 0.9581397995541713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 167}], {
             RGBColor[
             0.7605608363122977, 0.684376991975076, 0.6036441777632009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 168}], {
             RGBColor[
             0.5069255349638632, 0.6091474742003642, 0.9547231011630586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 181}], {
             RGBColor[
             0.7998668067519439, 0.8312427160957487, 0.681983215284067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 201}], {
             RGBColor[
             0.7294018709234232, 0.5233754189666472, 0.5768926874649807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 203}], {
             RGBColor[
             0.7752823706628642, 0.824842772704185, 0.9770131806255582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 216}], {
             RGBColor[
             0.7399516836581952, 0.5917908620218015, 0.5864988772524447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 255}], {
             RGBColor[
             0.489728760692208, 0.5942524926612631, 0.9536273379129792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 258}], {
             RGBColor[
             0.47680058453134755`, 0.5830547562597531, 0.9528035659599465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 293}], {
             RGBColor[
             0.7565992079701278, 0.6673833817942012, 0.600389979606483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 101}], {
             RGBColor[
             0.7469403042896439, 0.5416229945947444, 0.5788476902726976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 142}], {
             RGBColor[
             0.8382440889794911, 0.2949664033288275, 0.18425588883826852`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 149}], {
             RGBColor[
             0.8710281964790996, 0.48860908470804376`, 0.21336513442340005`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 194}], {
             RGBColor[
             0.7662790641438353, 0.5567305807728573, 0.5807751971239775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[
             0.9164471489214862, 0.6737245560050689, 0.534114411639826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 198}], {
             RGBColor[
             0.9055718234570376, 0.665970901350738, 0.5685171958085309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 226}], {
             RGBColor[
             0.9164048612065285, 0.6737070689481892, 0.5348152285137735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 241}], {
             RGBColor[
             0.9163383963463205, 0.6736795840204242, 0.5359167232529631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 243}], {
             RGBColor[
             0.9169850470479723, 0.6739469907037223, 0.5252000476482207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 290}], {
             RGBColor[
             0.8964817615318641, 0.5920367025275223, 0.23397565044312565`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 291}], {
             RGBColor[
             0.8867137047505624, 0.6516789960865967, 0.5925497284900865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 191}], {
             RGBColor[
             0.2074223158614455, 0.3353443836777553, 0.9351237660832672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 217}], {
             RGBColor[
             0.19375308221906778`, 0.32097715244014635`, 0.9343453234491528]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 223}], {
             RGBColor[
             0.1844791456857544, 0.31122965714209644`, 0.9338171864831403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 246}], {
             RGBColor[
             0.1859588657451276, 0.3127849367441682, 0.9339014543514719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 247}], {
             RGBColor[
             0.1926121673846783, 0.3197779786110244, 0.9342803500371666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 270}], {
             RGBColor[
             0.20015353292457566`, 0.32770443194364846`, 0.9347098196482133]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 271}], {
             RGBColor[
             0.20505156873545605`, 0.33285257813429087`, 0.9349887555416483]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 278}], {
             RGBColor[
             0.19404895120727791`, 0.32128812950593255`, 0.9343621727503324]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 295}], {
             RGBColor[
             0.19219536521772562`, 0.31933989310677346`, 0.9342566137703623]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[
             0.22879896787362192`, 0.35781260030057205`, 0.936341134791438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 135}], {
             RGBColor[
             0.22261249954375167`, 0.3513102298411313, 0.9359888245721116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 154}], {
             RGBColor[
             0.36472305205370464`, 0.48205039622074985`, 0.9450500607222323]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 173}], {
             RGBColor[
             0.21671771694106706`, 0.34511443957490595`, 0.9356531254234381]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 213}], {
             RGBColor[
             0.21726177740977812`, 0.34568628162294734`, 0.9356841088622658]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 234}], {
             RGBColor[
             0.21315182719847248`, 0.341366463364971, 0.9354500532778585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 239}], {
             RGBColor[
             0.2348622905163943, 0.36418553683498534`, 0.936686432046062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 249}], {
             RGBColor[
             0.21980259172524277`, 0.34835683856543287`, 0.9358288044787336]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 255}], {
             RGBColor[
             0.2990831810082368, 0.42639058870879876`, 0.9405375990810403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 258}], {
             RGBColor[
             0.2861550048473763, 0.41519285230728875`, 0.9397138271280076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 263}], {
             RGBColor[
             0.22101888131475306`, 0.34963523604122215`, 0.9358980703715171]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 286}], {
             RGBColor[
             0.2265196157319883, 0.3554168566804423, 0.9362113290589713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[
             0.6955329406462065, 0.7613368008112785, 0.9707925147289977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 97}], {
             RGBColor[
             0.5215176139849236, 0.6223094238976072, 0.9555083823712963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 120}], {
             RGBColor[
             0.4366336879326583, 0.5460453622474791, 0.9502000470026102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 130}], {
             RGBColor[
             0.75299012475597, 0.6847273872222507, 0.6045439579169226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 140}], {
             RGBColor[
             0.7057480336302696, 0.4077728682153858, 0.5627064708792573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 162}], {
             RGBColor[
             0.7927626721159106, 0.8360545204331631, 0.8771199562466196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 169}], {
             RGBColor[
             0.5994580148931581, 0.6857060476229113, 0.9616106773009028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[
             0.4265942001520806, 0.5354932240498018, 0.9496283130255976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 182}], {
             RGBColor[
             0.4242603384632414, 0.5330401874394541, 0.9494954030550571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 202}], {
             RGBColor[
             0.7303739014473327, 0.5842147173946636, 0.5857853158660629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 261}], {
             RGBColor[
             0.41945675567834323`, 0.5279913173677868, 0.949221846121721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 284}], {
             RGBColor[
             0.41756739126480746`, 0.526005475576538, 0.9491142496134344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 109}], {
             RGBColor[
             0.9929796059139886, 0.9895239708410322, 0.632193448669364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 140}], {
             RGBColor[
             0.9052335250111279, 0.560939848386522, 0.3299018570676289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 151}], {
             RGBColor[
             0.7954880540997038, 0.8360677360525939, 0.7285340376363743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[
             0.7452228320173793, 0.7952601643437132, 0.7245769752264782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 155}], {
             RGBColor[
             0.959730943798982, 0.866659323879206, 0.37757715104669176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 162}], {
             RGBColor[
             0.9922481634967688, 0.9892215006042993, 0.6443153424349913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 181}], {
             RGBColor[
             0.9897210070316473, 0.9765905802662477, 0.448420390956374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 202}], {
             RGBColor[
             0.9298593928281911, 0.7373816975657997, 0.35298070205443455`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 203}], {
             RGBColor[
             0.9651365709425674, 0.970190636874684, 0.7434503562978652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 216}], {
             RGBColor[
             0.9298058839378985, 0.7371387261923006, 0.3529360529247516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 227}], {
             RGBColor[
             0.9729262687384115, 0.9189743901826695, 0.3881944192270413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 258}], {
             RGBColor[
             0.6666547848110509, 0.7284026204302521, 0.7192407416322534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 299}], {
             RGBColor[
             0.9059209744031474, 0.5662238856558284, 0.33056015938178984`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 93}], {
             RGBColor[
             0.23199426054362918`, 0.36117105549000617`, 0.9365231019819831]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 107}], {
             RGBColor[
             0.3156668760979841, 0.43989562490003076`, 0.9416257469918767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 124}], {
             RGBColor[
             0.20439146202389424`, 0.3321587641272566, 0.9349511634409652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 137}], {
             RGBColor[
             0.242196310039882, 0.3718940563578661, 0.9371040936082149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 147}], {
             RGBColor[
             0.21812810554997109`, 0.34659684742666674`, 0.9357334449682322]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 273}], {
             RGBColor[
             0.23089430452924603`, 0.3600149319776501, 0.936460461114203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 274}], {
             RGBColor[
             0.342952508633553, 0.4632649151839602, 0.9434373496862328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 289}], {
             RGBColor[
             0.23315152394890182`, 0.3623874127036856, 0.9365890064208955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 94}], {
             RGBColor[
             0.5888165791799138, 0.6727291061533267, 0.962935879267211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 120}], {
             RGBColor[
             0.3299173264663655, 0.4574376675895273, 0.9423434115408236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 131}], {
             RGBColor[
             0.3050760854207314, 0.4313279482249144, 0.9409287396125976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 141}], {
             RGBColor[
             0.33729605784908523`, 0.4651931821113565, 0.9427636193772146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 188}], {
             RGBColor[
             0.3683043792841372, 0.49342847464473716`, 0.9446890072625783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 236}], {
             RGBColor[
             0.30608763983959875`, 0.4323911560553985, 0.9409863461402914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 260}], {
             RGBColor[
             0.3194559514168667, 0.4464420991230162, 0.9417476517079721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 281}], {
             RGBColor[
             0.6796029595718664, 0.743830302697593, 0.9334123929687868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 294}], {
             RGBColor[
             0.4583968818459615, 0.569215720181254, 0.9510502956112238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 118}], {
             RGBColor[
             0.20219853738896398`, 0.32985386129649247`, 0.9348262796271471]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 126}], {
             RGBColor[
             0.2195822201328165, 0.34812521404942687`, 0.9358162546425555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 153}], {
             RGBColor[
             0.21837262298903565`, 0.3468538507584247, 0.9357473698746558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.20088523531551122`, 0.3284734975491328, 0.9347514890169203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 195}], {
             RGBColor[
             0.19970007804544365`, 0.3272278221149808, 0.934683996063673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 222}], {
             RGBColor[
             0.2185508250169386, 0.3470411523884118, 0.9357575182165185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 234}], {
             RGBColor[
             0.20491562163947707`, 0.33270968911687326`, 0.9349810135556479]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 239}], {
             RGBColor[
             0.2266260849573989, 0.3555287625868876, 0.9362173923238513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 248}], {
             RGBColor[
             0.21881740302399694`, 0.347321342775852, 0.9357726994396538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 285}], {
             RGBColor[
             0.20767787323688183`, 0.3356129906826123, 0.9351383196977351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 93}], {
             RGBColor[
             0.3656444287828603, 0.48387268995411137`, 0.9450248073537576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 105}], {
             RGBColor[
             0.38699951220692347`, 0.5063182366232937, 0.9462409477627431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 107}], {
             RGBColor[
             0.44931704433721525`, 0.562597259364136, 0.9501274523636514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 139}], {
             RGBColor[
             0.4654409733450266, 0.5765629962584664, 0.9511548548621985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 142}], {
             RGBColor[
             0.6600471931315399, 0.4140378360712322, 0.5646529525736886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 143}], {
             RGBColor[
             0.39852667636969663`, 0.5184340170227889, 0.9468974027089019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 150}], {
             RGBColor[
             0.6987841041568563, 0.6337941140587057, 0.5986819437121721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 163}], {
             RGBColor[
             0.5556545906660699, 0.6501444545135875, 0.9581623112885165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 179}], {
             RGBColor[
             0.5064577791876668, 0.6102042666643193, 0.9542893580750782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 235}], {
             RGBColor[
             0.44932632055040805`, 0.5626052939537676, 0.9501280434357534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 273}], {
             RGBColor[
             0.3645444727684772, 0.4827165664417553, 0.9449621664859775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 274}], {
             RGBColor[
             0.4766026768727841, 0.5859665496480654, 0.9519390550580074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 298}], {
             RGBColor[
             0.3751482927558811, 0.4938618535695355, 0.9455660383473143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 125}], {
             RGBColor[
             0.8333745807247173, 0.2575372290505118, 0.17959284223417404`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 128}], {
             RGBColor[
             0.838247472010956, 0.29499240679111977`, 0.18425912843301978`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 142}], {
             RGBColor[
             0.830745140796793, 0.23732620153656223`, 0.1770748875896661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 149}], {
             RGBColor[
             0.8635292482964012, 0.4309688829157785, 0.2061841331747976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 150}], {
             RGBColor[
             0.8694820518221094, 0.4570824795240357, 0.2111038787281495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 179}], {
             RGBColor[
             0.6771557268529196, 0.4334926321296493, 0.5667112930910556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 237}], {
             RGBColor[
             0.8283146765154534, 0.21864458803394712`, 0.17474747224903853`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 243}], {
             RGBColor[
             0.9094860988652742, 0.6163067889114571, 0.5180190463996183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 256}], {
             RGBColor[
             0.8247413968754788, 0.1911787948999799, 0.17132569563035674`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 269}], {
             RGBColor[
             0.9023597936765284, 0.5823448940357236, 0.2640506186657438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 277}], {
             RGBColor[
             0.9122829383943001, 0.6155043542913563, 0.3292695837766948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 281}], {
             RGBColor[
             0.9050081321346448, 0.6135030027694477, 0.5495966137001128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 105}], {
             RGBColor[
             0.26248514686677915`, 0.39321891024948796`, 0.9382595128508624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 107}], {
             RGBColor[
             0.32480267899707094`, 0.44949793299033025`, 0.9421460174517705]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 137}], {
             RGBColor[
             0.25133211293896884`, 0.38149636444816565`, 0.9376243640681086]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 139}], {
             RGBColor[
             0.3409266080048823, 0.4634636698846607, 0.9431734199503177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 147}], {
             RGBColor[
             0.22726390844905786`, 0.3561991555169663, 0.936253715428126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 273}], {
             RGBColor[
             0.24003010742833283`, 0.36961724006794966`, 0.9369807315740968]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 274}], {
             RGBColor[
             0.3520883115326398, 0.4728672232742597, 0.9439576201461266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 289}], {
             RGBColor[
             0.24228732684798865`, 0.37198972079398507`, 0.9371092768807893]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 97}], {
             RGBColor[
             0.622873487370591, 0.7022274882781143, 0.9651059553417796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 120}], {
             RGBColor[
             0.5379895613183256, 0.6259634266279861, 0.9597976199730934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 130}], {
             RGBColor[
             0.8543459981416374, 0.7646454516027577, 0.6141415308874059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 141}], {
             RGBColor[
             0.5453682927010454, 0.6337189411498153, 0.9602178278094844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 188}], {
             RGBColor[
             0.5763766141360973, 0.661954233683196, 0.9621432156948482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 201}], {
             RGBColor[
             0.8211264532079356, 0.595474367346517, 0.5857320499193991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 202}], {
             RGBColor[
             0.8317297748330001, 0.6641327817751705, 0.595382888836546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.8109817388046351, 0.5174976470005512, 0.5760174599499823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 281}], {
             RGBColor[
             0.8876751944238266, 0.9123560617360518, 0.9508666014010566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 293}], {
             RGBColor[
             0.8483237902546403, 0.739482330174071, 0.6092293420609014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 294}], {
             RGBColor[
             0.6664691166979216, 0.7377414792197128, 0.9685045040434936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 103}], {
             RGBColor[
             0.35444301317126903`, 0.47946333163225574`, 0.9438775064114789]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 127}], {
             RGBColor[
             0.3181958172626126, 0.4480678323732162, 0.9415678671403162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 145}], {
             RGBColor[
             0.5762301255781173, 0.6573426269684071, 0.963331889789669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 148}], {
             RGBColor[
             0.2669268205335093, 0.3978873908915973, 0.9385124595953154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 156}], {
             RGBColor[
             0.3410239560220559, 0.4678404187910305, 0.9430224559559374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 159}], {
             RGBColor[
             0.2893985943419117, 0.4215066499569798, 0.9397921938696936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 168}], {
             RGBColor[
             0.3439839043984553, 0.4704041773033365, 0.943211061249102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 191}], {
             RGBColor[
             0.2574665501142888, 0.38794404686520834`, 0.9379737111901566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 205}], {
             RGBColor[
             0.32995805051825455`, 0.4582556876322203, 0.9423173462424312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 212}], {
             RGBColor[
             0.2604625119164363, 0.3910929926742148, 0.9381443267826606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 225}], {
             RGBColor[
             0.2575765092536425, 0.3880596208924811, 0.9379799732004728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 251}], {
             RGBColor[
             0.2865818395337517, 0.41854606206103384`, 0.9396317838503843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 271}], {
             RGBColor[
             0.25509580298829937`, 0.3854522413217438, 0.9378387006485376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 276}], {
             RGBColor[
             0.2644651178260697, 0.3952999852651118, 0.9383722692678894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 282}], {
             RGBColor[
             0.36409426757402563`, 0.48782276310977274`, 0.9444924758077534]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 112}], {
             RGBColor[
             0.1950909003644823, 0.32238328413354655`, 0.9344215102134096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 132}], {
             RGBColor[
             0.1989233882773373, 0.32641147192372544`, 0.9346397647303889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 133}], {
             RGBColor[
             0.19311989172231955`, 0.3203116290814677, 0.9343092641870845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 146}], {
             RGBColor[
             0.20048974504421074`, 0.3280578121984645, 0.9347289664310452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 236}], {
             RGBColor[
             0.2161907003932258, 0.34456051176834573`, 0.9356231126106896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 260}], {
             RGBColor[
             0.22955901197049378`, 0.3586114548359634, 0.9363844181783704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 267}], {
             RGBColor[
             0.19857826997424566`, 0.3260487307054119, 0.9346201107535846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 120}], {
             RGBColor[
             0.3639742346570427, 0.4869360497143149, 0.944513487615392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 130}], {
             RGBColor[
             0.6803306714803544, 0.6256180746890865, 0.5988573985297044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 178}], {
             RGBColor[
             0.353934746876465, 0.4763839115166376, 0.9439417536383794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 182}], {
             RGBColor[
             0.35160088518762583`, 0.47393087490628993`, 0.9438088436678389]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 202}], {
             RGBColor[
             0.6577144481717172, 0.5251054048614994, 0.5800987564788447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 261}], {
             RGBColor[
             0.34679730240272766`, 0.46888200483462256`, 0.9435352867345028]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 284}], {
             RGBColor[
             0.3449079379891919, 0.4668961630433738, 0.9434276902262162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 157}], {
             RGBColor[
             0.18079506708635712`, 0.3073574569500555, 0.9336073836570105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.17910006852395627`, 0.30557590599185624`, 0.9335108559964074]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 275}], {
             RGBColor[
             0.17961340510331275`, 0.30611545528417883`, 0.9335400897551883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 285}], {
             RGBColor[
             0.18936585526810354`, 0.31636589874842813`, 0.9340954773646161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 182}], {
             RGBColor[
             0.22500890422772363`, 0.3538290031048185, 0.9361252962737008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 199}], {
             RGBColor[
             0.19703448061371565`, 0.32442611020559603`, 0.9345321942333341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 209}], {
             RGBColor[
             0.18806492725905072`, 0.31499854092731383`, 0.934021391439051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 215}], {
             RGBColor[
             0.21020795705683448`, 0.338272269193962, 0.9352824042283578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 229}], {
             RGBColor[
             0.20669327315473038`, 0.33457811356902034`, 0.9350822481796419]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 233}], {
             RGBColor[
             0.20053490529032286`, 0.32810527848045334`, 0.9347315382402527]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 259}], {
             RGBColor[
             0.19041774683741108`, 0.3174715034815479, 0.934155381033354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 284}], {
             RGBColor[
             0.2183159570292897, 0.34679429124190236`, 0.9357441428320781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 119}], {
             RGBColor[
             0.1807572108955105, 0.3073176676932546, 0.933605227802945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 122}], {
             RGBColor[
             0.18285159839459103`, 0.3095190017466254, 0.933724500072649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 161}], {
             RGBColor[
             0.1911587437240086, 0.318250338191278, 0.9341975797098391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 244}], {
             RGBColor[
             0.18508330510196136`, 0.31186466699444937`, 0.9338515924681194]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 266}], {
             RGBColor[
             0.1894062944527255, 0.3164084028954582, 0.9340977803163559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 104}], {
             RGBColor[
             0.49120791951509923`, 0.5945373978105576, 0.9540278714950781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 116}], {
             RGBColor[
             0.46733992011891123`, 0.5718860980228273, 0.952579449352897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 136}], {
             RGBColor[
             0.5199717589850226, 0.6194511898467974, 0.9558606779112371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 149}], {
             RGBColor[
             0.7714159149498363, 0.6714029284596804, 0.6000007099012994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 197}], {
             RGBColor[
             0.816834867392223, 0.8565183997567056, 0.9207499871177253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 198}], {
             RGBColor[
             0.8059595419277743, 0.8487647451023745, 0.9551527712864303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[
             0.5654681824695174, 0.6580354513456885, 0.9589869162220399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 226}], {
             RGBColor[
             0.8167925796772653, 0.8565009126998259, 0.9214508039916728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 243}], {
             RGBColor[
             0.8173727655187092, 0.8567408344553589, 0.91183562312612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 254}], {
             RGBColor[
             0.4830549298600605, 0.587475687952538, 0.9535083702036646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 283}], {
             RGBColor[
             0.4765743997943146, 0.5815921216615045, 0.9531053393092228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 165}], {
             RGBColor[
             0.20499479718794766`, 0.3327929076383356, 0.9349855224860035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 172}], {
             RGBColor[
             0.19138970866876043`, 0.3184930969922355, 0.9342107328217606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 175}], {
             RGBColor[
             0.18740197098760464`, 0.3143017318521686, 0.9339836370601481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 183}], {
             RGBColor[
             0.19246783079694663`, 0.31962627170585023`, 0.934272130282022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 238}], {
             RGBColor[
             0.18981943468321613`, 0.3168426394723074, 0.9341213080412961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 253}], {
             RGBColor[
             0.1920226425007294, 0.3191583505799577, 0.9342467774671497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 127}], {
             RGBColor[
             0.3850824421018483, 0.5079607893674816, 0.9457580905890645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 145}], {
             RGBColor[
             0.643116750417353, 0.7172355839626725, 0.9675221132384173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 154}], {
             RGBColor[
             0.45931362601150366`, 0.5710619602704519, 0.9508179830889629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 159}], {
             RGBColor[
             0.35628521918114736`, 0.4813996069512451, 0.9439824173184419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 167}], {
             RGBColor[
             0.6645058305861254, 0.6055266520723135, 0.5963223612979925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 168}], {
             RGBColor[
             0.41087052923769096`, 0.5302971342976018, 0.9474012846978503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 203}], {
             RGBColor[
             0.679227364936692, 0.7459924328014227, 0.96969136416035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 205}], {
             RGBColor[
             0.39684467535749024`, 0.5181486446264856, 0.9465075696911796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 212}], {
             RGBColor[
             0.327349136755672, 0.45098594966848016`, 0.9423345502314089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 225}], {
             RGBColor[
             0.3244631340928782, 0.4479525778867464, 0.9421701966492211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 255}], {
             RGBColor[
             0.3936737549660358, 0.5154021527585007, 0.9463055214477708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 265}], {
             RGBColor[
             0.3220227389937979, 0.445387567907627, 0.9420312197585695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 269}], {
             RGBColor[
             0.6972472679550255, 0.7302486647196956, 0.6491594274470608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 276}], {
             RGBColor[
             0.33135174266530537`, 0.4551929422593771, 0.9425624927166377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 282}], {
             RGBColor[
             0.4309808924132613, 0.5477157201040381, 0.9486826992565017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 293}], {
             RGBColor[
             0.6605442022439556, 0.5885330418914387, 0.5930681631412746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 114}], {
             RGBColor[
             0.28710993911342014`, 0.4166656473064825, 0.939751033226302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 116}], {
             RGBColor[
             0.3112198168736299, 0.4420066574870038, 0.9411240550973782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 204}], {
             RGBColor[
             0.40934807922423605`, 0.5281560108098651, 0.9475315219665212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 206}], {
             RGBColor[
             0.2787552105581772, 0.4078842978745366, 0.9392752437947942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 243}], {
             RGBColor[
             0.6612526622734278, 0.7268613939195354, 0.9003802288706013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 254}], {
             RGBColor[
             0.32693482661477913`, 0.45759624741671456`, 0.942052975948146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 283}], {
             RGBColor[
             0.32045429654903324`, 0.4517126811256811, 0.9416499450537039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 287}], {
             RGBColor[
             0.2890443879522816, 0.41869887568726627`, 0.9398611972259145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 300}], {
             RGBColor[
             0.2803668703826312, 0.4095782545351725, 0.9393670254375599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 139}], {
             RGBColor[
             0.3622816914289454, 0.48590921655384295`, 0.9443895603593033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 143}], {
             RGBColor[
             0.29536739445361543`, 0.4277802373181654, 0.9401321082060067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 163}], {
             RGBColor[
             0.4524953087499887, 0.5594906748089641, 0.9513970167856213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 174}], {
             RGBColor[
             0.25852249961576723`, 0.3890539167423275, 0.9380338459521285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 235}], {
             RGBColor[
             0.34616703863432685`, 0.47195151424914406`, 0.9433627489328582]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 274}], {
             RGBColor[
             0.373443394956703, 0.4953127699434419, 0.9451737605551122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 298}], {
             RGBColor[
             0.27198901083979987`, 0.403208073864912, 0.938800743844419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 115}], {
             RGBColor[
             0.6067946716231568, 0.6858798777418896, 0.9651595250499304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 155}], {
             RGBColor[
             0.8940872222095038, 0.8191271102860018, 0.6231274080512639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 162}], {
             RGBColor[
             0.9266044419072905, 0.9416892870110949, 0.8898655994395634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 194}], {
             RGBColor[
             0.7739330746560312, 0.8236601401446212, 0.9780122537987794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 200}], {
             RGBColor[
             0.6137154608562325, 0.6918743175265988, 0.9656005116200483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 210}], {
             RGBColor[
             0.6667698289178824, 0.73732879896912, 0.9691188386686375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 211}], {
             RGBColor[
             0.5662966671615951, 0.6472879549936589, 0.9627077142549896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 227}], {
             RGBColor[
             0.907282547148933, 0.8714421765894653, 0.6337446762316135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 241}], {
             RGBColor[
             0.9239924068585166, 0.940609143392188, 0.9331537799277652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 264}], {
             RGBColor[
             0.579035279379287, 0.6606770441091168, 0.9634331593756991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 290}], {
             RGBColor[
             0.9041357720440601, 0.8589662618992862, 0.6312127071179277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 291}], {
             RGBColor[
             0.8943677152627585, 0.9186085554583606, 0.9897867851648885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 137}], {
             RGBColor[
             0.33500472849332374`, 0.4602209338581902, 0.9427270090780024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 139}], {
             RGBColor[
             0.4245992235592372, 0.5421882392946853, 0.9482760649602114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[
             0.3109365240034128, 0.43492372492699083`, 0.9413563604380197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 150}], {
             RGBColor[
             0.657942354371067, 0.5994193570949246, 0.595803153810185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.4014834091317521, 0.5221664826722128, 0.9468031457054042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.4656160294018773, 0.5758295097005381, 0.9514105681730911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 251}], {
             RGBColor[
             0.34704129264344796`, 0.47287212594221606`, 0.943412473599851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 273}], {
             RGBColor[
             0.32370272298268776`, 0.4483418094779742, 0.9420833765839904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 274}], {
             RGBColor[
             0.43576092708699476`, 0.5515917926842843, 0.9490602651560203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 277}], {
             RGBColor[
             0.7007432409432577, 0.7578412318622451, 0.7139688588587303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 289}], {
             RGBColor[
             0.32595994240234355`, 0.45071429020400966`, 0.942211921890683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 136}], {
             RGBColor[
             0.3166504809342749, 0.4423958027593246, 0.9416280716923184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 177}], {
             RGBColor[
             0.2663285931328081, 0.3972586159636525, 0.9384783914298436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 204}], {
             RGBColor[
             0.36214690441876973`, 0.48098006425821577`, 0.9447543100031214]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 208}], {
             RGBColor[
             0.2150010029643497, 0.34331006433942324`, 0.9355553611021148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 252}], {
             RGBColor[
             0.23931387407336885`, 0.3688644334000649, 0.9369399431441039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 254}], {
             RGBColor[
             0.27973365180931276`, 0.4104203008650652, 0.9392757639847461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 268}], {
             RGBColor[
             0.2228674989167732, 0.351578250350071, 0.9360033464091675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 279}], {
             RGBColor[
             0.23867609661587075`, 0.3681940888548081, 0.9369036226614065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 280}], {
             RGBColor[
             0.2513491898337207, 0.3815143133472875, 0.9376253365720018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 283}], {
             RGBColor[
             0.2732531217435669, 0.4045367345740317, 0.9388727330903042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 111}], {
             RGBColor[
             0.8035074391264327, 0.8444862586698714, 0.8657863480729937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 151}], {
             RGBColor[
             0.7953196099914366, 0.8378390101205823, 0.8651417721704804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 155}], {
             RGBColor[
             0.9595624996907148, 0.8684305979471943, 0.514184885580798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 192}], {
             RGBColor[
             0.6617142280646152, 0.7260405303844142, 0.8555444013688691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 218}], {
             RGBColor[
             0.9800003657513711, 0.9831729301139916, 0.8546124313811914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 220}], {
             RGBColor[
             0.6629503007752218, 0.7271111544395208, 0.8556231628289728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 227}], {
             RGBColor[
             0.9727578246301442, 0.9207456642506578, 0.5248021537611475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 290}], {
             RGBColor[
             0.9696110495252712, 0.9082697495604787, 0.5222701846474617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 292}], {
             RGBColor[
             0.8832633694480486, 0.907223500639492, 0.873440789605417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 148}], {
             RGBColor[
             0.2161072361235734, 0.34447278552900074`, 0.9356183594440073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 191}], {
             RGBColor[
             0.20664696570435293`, 0.3345294415026117, 0.9350796110388486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 223}], {
             RGBColor[
             0.18370379552866184`, 0.31041471496695283`, 0.9337730314387216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 246}], {
             RGBColor[
             0.18518351558803503`, 0.3119699945690246, 0.9338572993070533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 278}], {
             RGBColor[
             0.19327360105018532`, 0.32047318733078894`, 0.9343180177059138]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 295}], {
             RGBColor[
             0.19142001506063305`, 0.31852495093162986`, 0.9342124587259435]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 143}], {
             RGBColor[
             0.46054913753176646`, 0.5687866450741914, 0.9517800380473413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 163}], {
             RGBColor[
             0.6176770518281398, 0.70049708256499, 0.9630449466269559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.5718800780485805, 0.6633170361205862, 0.9594396410911864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 218}], {
             RGBColor[
             0.7906966430720825, 0.8363639438748425, 0.9515975962507148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 235}], {
             RGBColor[
             0.5113487817124779, 0.61295792200517, 0.9550106787741928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 262}], {
             RGBColor[
             0.459021775002635, 0.5671812902156966, 0.9516930570108376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 292}], {
             RGBColor[
             0.6939596467687601, 0.7604145144003427, 0.9704259544749405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 131}], {
             RGBColor[
             0.20931958090363292`, 0.3373385295306458, 0.9352318125206677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 132}], {
             RGBColor[
             0.1930638232066118, 0.32025269751650964`, 0.9343060711680607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 133}], {
             RGBColor[
             0.18726032665159403`, 0.3141528546742519, 0.9339755706247563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 146}], {
             RGBColor[
             0.19463017997348525`, 0.32189903779124873`, 0.934395272868717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 170}], {
             RGBColor[
             0.1934039006537554, 0.3206101404756131, 0.9343254380755761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 190}], {
             RGBColor[
             0.19682291342577818`, 0.3242037396769393, 0.9345201457949667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 115}], {
             RGBColor[
             0.3096806718260522, 0.43885035168813935`, 0.9410927375300542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 134}], {
             RGBColor[
             0.25621583264175446`, 0.38662946350150684`, 0.9379024846803665]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 144}], {
             RGBColor[
             0.23263625868922916`, 0.36184583624606526`, 0.9365596628266237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 160}], {
             RGBColor[
             0.23169850636271255`, 0.3608601990939647, 0.936506259218909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 169}], {
             RGBColor[
             0.4361857848874334, 0.5443112881470928, 0.9502895329739705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 176}], {
             RGBColor[
             0.23091262265844142`, 0.3600341854928709, 0.9364615043045614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 187}], {
             RGBColor[
             0.24618639037776724`, 0.3760878837786886, 0.9373313227806626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 193}], {
             RGBColor[
             0.2735981771019762, 0.40489940963349313`, 0.9388923834825018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 200}], {
             RGBColor[
             0.3166014610591278, 0.4448447914728484, 0.9415337241001722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 228}], {
             RGBColor[
             0.34694483487630184`, 0.4711266967709722, 0.9434671770482106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 231}], {
             RGBColor[
             0.24940666839475117`, 0.3794726001519578, 0.9375147128497554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 245}], {
             RGBColor[
             0.24643755239072743`, 0.3763518709789012, 0.9373456260857398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 264}], {
             RGBColor[
             0.28192127958218227`, 0.41364751805536637`, 0.939366371855823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 288}], {
             RGBColor[
             0.23824897201713657`, 0.3677451538202748, 0.9368792985473828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 297}], {
             RGBColor[
             0.22981287868159825`, 0.35887828484541334`, 0.9363988755120056]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 116}], {
             RGBColor[
             0.26324193971723214`, 0.3940143475187522, 0.9383026110841209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 204}], {
             RGBColor[
             0.3613702020678383, 0.4801637008416135, 0.944710077953264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 206}], {
             RGBColor[
             0.2307773334017795, 0.35989198790628496`, 0.936453799781537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 254}], {
             RGBColor[
             0.2789569494583814, 0.4096039374484629, 0.9392315319348887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 283}], {
             RGBColor[
             0.2724764193926355, 0.4037203711574294, 0.9388285010404467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 134}], {
             RGBColor[
             0.29826389721871693`, 0.4268505977105114, 0.940442569105771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 169}], {
             RGBColor[
             0.47823384946439584`, 0.5845324223560975, 0.9528296173993749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 193}], {
             RGBColor[
             0.3156462416789386, 0.4451205438424978, 0.9414324679079064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 200}], {
             RGBColor[
             0.35864952563609026`, 0.485065925681853, 0.9440738085255767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 210}], {
             RGBColor[
             0.4117038936977402, 0.5305204071243743, 0.9475921355741658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 211}], {
             RGBColor[
             0.3112307319414529, 0.4404795631489132, 0.9411810111605179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 227}], {
             RGBColor[
             0.6522166119287909, 0.6646337847447196, 0.6122179731371418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 228}], {
             RGBColor[
             0.3889928994532643, 0.5113478309799768, 0.946007261473615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 231}], {
             RGBColor[
             0.29145473297171365`, 0.41969373436096236`, 0.9400547972751598]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 245}], {
             RGBColor[
             0.2884856169676899, 0.4165730051879058, 0.9398857105111442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 264}], {
             RGBColor[
             0.32396934415914475`, 0.453868652264371, 0.9419064562812274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 204}], {
             RGBColor[
             0.38548007982804805`, 0.5055047110221348, 0.9460830998243401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 206}], {
             RGBColor[
             0.2548872111619892, 0.3852329980868062, 0.9378268216526131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 254}], {
             RGBColor[
             0.30306682721859113`, 0.43494494762898417`, 0.9406045538059649]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 283}], {
             RGBColor[
             0.29658629715284524`, 0.4290613813379507, 0.9402015229115228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 287}], {
             RGBColor[
             0.2651763885560936, 0.39604757589953593`, 0.9384127750837334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 158}], {
             RGBColor[
             0.189227738636957, 0.3162207294119929, 0.9340876118267976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 196}], {
             RGBColor[
             0.1942847722586868, 0.32153599238288155`, 0.9343756024103442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 207}], {
             RGBColor[
             0.18539878883552113`, 0.3121962604012447, 0.9338695588000294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 212}], {
             RGBColor[
             0.20943922968905518`, 0.3374642879902957, 0.935238626341993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 214}], {
             RGBColor[
             0.19317010459047246`, 0.32036440598957616`, 0.9343121237356424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 225}], {
             RGBColor[
             0.20655322702626136`, 0.33443091620856197`, 0.9350742727598051]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 265}], {
             RGBColor[
             0.2041128319271811, 0.33186590622944256`, 0.9349352958691536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 276}], {
             RGBColor[
             0.21344183559868857`, 0.34167128058119267`, 0.9354665688272218]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 166}], {
             RGBColor[
             0.18740769372755933`, 0.31430774681470364`, 0.9339839629617225]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.18622253645749176`, 0.31306207138055164`, 0.9339164700084752]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 234}], {
             RGBColor[
             0.19143808005152518`, 0.3185439383824441, 0.9342134875004501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 239}], {
             RGBColor[
             0.213148543369447, 0.34136301185245843`, 0.9354498662686535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 263}], {
             RGBColor[
             0.19930513416780576`, 0.32681271105869525`, 0.9346615045941087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 285}], {
             RGBColor[
             0.19420033164892994`, 0.32144723994818314`, 0.9343707936425373]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 122}], {
             RGBColor[
             0.18294597115910344`, 0.30961819350570674`, 0.933729874461976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 161}], {
             RGBColor[
             0.191253116488521, 0.3183495299503595, 0.9342029540991661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 244}], {
             RGBColor[
             0.18517767786647377`, 0.3119638587535308, 0.9338569668574466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 266}], {
             RGBColor[
             0.1895006672172379, 0.3165075946545396, 0.9341031547056828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 131}], {
             RGBColor[
             0.2542490675591432, 0.38456226869957383`, 0.93779048031848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 141}], {
             RGBColor[
             0.28646903998749706`, 0.4184275025860159, 0.939625360083097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 170}], {
             RGBColor[
             0.23833338730926568`, 0.3678338796445412, 0.9368841058733883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 178}], {
             RGBColor[
             0.2690508208241996, 0.4001198498665095, 0.9386334182696933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 182}], {
             RGBColor[
             0.2667169591353605, 0.3976668132561618, 0.9385005082991529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 188}], {
             RGBColor[
             0.317477361422549, 0.44666279511939655`, 0.9415507479684607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 190}], {
             RGBColor[
             0.24175240008128845`, 0.37142747884586735`, 0.937078813592779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 261}], {
             RGBColor[
             0.2619133763504623, 0.3926179431844944, 0.9382269513658168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 284}], {
             RGBColor[
             0.26002401193692654`, 0.39063210139324567`, 0.9381193548575302]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 294}], {
             RGBColor[
             0.40756986398437334`, 0.5224500406559134, 0.9479120363171062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 135}], {
             RGBColor[
             0.21926297732246688`, 0.3477896696145861, 0.9357980742367835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 154}], {
             RGBColor[
             0.3613735298324199, 0.47852983599420473`, 0.9448593103869043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 173}], {
             RGBColor[
             0.21336819471978227`, 0.34159387934836083`, 0.9354623750881099]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.21391225518849333`, 0.3421657213964022, 0.9354933585269378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 234}], {
             RGBColor[
             0.20980230497718771`, 0.3378459031384259, 0.9352593029425303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 239}], {
             RGBColor[
             0.2315127682951095, 0.3606649766084402, 0.9364956817107337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 249}], {
             RGBColor[
             0.21645306950395798`, 0.3448362783388877, 0.9356380541434055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 255}], {
             RGBColor[
             0.295733658786952, 0.42287002848225363`, 0.9403468487457121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 258}], {
             RGBColor[
             0.28280548262609156`, 0.41167229208074363`, 0.9395230767926794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 263}], {
             RGBColor[
             0.2176693590934683, 0.34611467581467703`, 0.935707320036189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 286}], {
             RGBColor[
             0.22317009351070355`, 0.3518962964538972, 0.9360205787236432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 138}], {
             RGBColor[
             0.2081640824318275, 0.3361240273739437, 0.9351660085921052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 161}], {
             RGBColor[
             0.19334750398760153`, 0.32055086400373023`, 0.9343222263688701]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 266}], {
             RGBColor[
             0.19159505471631844`, 0.31870892870791034`, 0.9342224269753869]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 189}], {
             RGBColor[
             0.2072195140090381, 0.335131226072495, 0.935112216817791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 257}], {
             RGBColor[
             0.19133948148967972`, 0.3184403050424346, 0.9342078724582165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 267}], {
             RGBColor[
             0.19740462411574278`, 0.32481515449468, 0.9345532733581963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 287}], {
             RGBColor[
             0.22080206667647367`, 0.3494073501095485, 0.9358857230986155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 300}], {
             RGBColor[
             0.21212454910682327`, 0.34028672895745476`, 0.9353915513102607]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 147}], {
             RGBColor[
             0.19966110992932296`, 0.3271868641542167, 0.9346817768871081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 247}], {
             RGBColor[
             0.191840440673128, 0.3189668449068855, 0.9342364013426112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 273}], {
             RGBColor[
             0.2124273089085979, 0.3406049487052001, 0.9354087930330789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 289}], {
             RGBColor[
             0.2146845283282537, 0.3429774294312355, 0.9355373383397714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 128}], {
             RGBColor[
             0.8400673632821627, 0.3089808885830544, 0.18600185836960054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 130}], {
             RGBColor[
             0.8734988271236623, 0.4797808744280881, 0.21461427312304276`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 142}], {
             RGBColor[
             0.8325650320679996, 0.2513146833284968, 0.1788176175262468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.865349139567608, 0.4449573647077131, 0.20792686311137834`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 150}], {
             RGBColor[
             0.871301943093316, 0.4710709613159703, 0.2128466086647302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 167}], {
             RGBColor[
             0.871438247578835, 0.47161136318027613`, 0.21295628245325632`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 237}], {
             RGBColor[
             0.8301345677866601, 0.23263306982588172`, 0.17649020218561928`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 243}], {
             RGBColor[
             0.9113059901364808, 0.6302952707033915, 0.519761776336199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 256}], {
             RGBColor[
             0.8265612881466855, 0.2051672766919145, 0.17306842556693747`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 269}], {
             RGBColor[
             0.904179684947735, 0.5963333758276583, 0.2657933486023245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 277}], {
             RGBColor[
             0.9141028296655067, 0.6294928360832908, 0.33101231371327555`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 281}], {
             RGBColor[
             0.9068280234058514, 0.6274914845613823, 0.5513393436366936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 293}], {
             RGBColor[
             0.8674766192366652, 0.4546177529994014, 0.20970208429653842`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 153}], {
             RGBColor[
             0.2222787641449363, 0.35095945277692997`, 0.9359698188348664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 157}], {
             RGBColor[
             0.20301322621103607`, 0.33071015090274497`, 0.93487267495034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 192}], {
             RGBColor[
             0.2770528278061131, 0.40650831596386994`, 0.939163161568517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 220}], {
             RGBColor[
             0.27828890051671973`, 0.40757894001897654`, 0.9392419230286206]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 222}], {
             RGBColor[
             0.22245696617283922`, 0.3511467544069171, 0.9359799671767292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 239}], {
             RGBColor[
             0.2305322261132995, 0.35963436460539283`, 0.9364398412840619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 248}], {
             RGBColor[
             0.22272354417989754`, 0.3514269447943572, 0.9359951483998643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 285}], {
             RGBColor[
             0.21158401439278246`, 0.3397185927011176, 0.9353607686579457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 145}], {
             RGBColor[
             0.6068695545086966, 0.6858400847036329, 0.9652124739672545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 148}], {
             RGBColor[
             0.29756624946408855`, 0.42638484862682313`, 0.9403930437729009]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 156}], {
             RGBColor[
             0.3716633849526351, 0.49633787652625627`, 0.9449030401335229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 159}], {
             RGBColor[
             0.3200380232724909, 0.45000410769220556`, 0.9416727780472791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 168}], {
             RGBColor[
             0.3746233333290345, 0.4989016350385623, 0.9450916454266876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 191}], {
             RGBColor[
             0.28810597904486807`, 0.41644150460043405`, 0.9398542953677421]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 205}], {
             RGBColor[
             0.3605974794488338, 0.48675314536744607`, 0.9441979304200168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 212}], {
             RGBColor[
             0.2911019408470156, 0.4195904504094406, 0.9400249109602461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 225}], {
             RGBColor[
             0.28821593818422175`, 0.41655707862770686`, 0.9398605573780583]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 251}], {
             RGBColor[
             0.31722126846433096`, 0.4470435197962596, 0.9415123680279698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 269}], {
             RGBColor[
             0.6610000720463691, 0.698853165460656, 0.646849788175898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 276}], {
             RGBColor[
             0.29510454675664893`, 0.4237974430003376, 0.9402528534454749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 282}], {
             RGBColor[
             0.3947336965046049, 0.5163202208449985, 0.9463730599853389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 142}], {
             RGBColor[
             0.8374379233542384, 0.28876986106910485`, 0.18348390372509257`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 149}], {
             RGBColor[
             0.8702220308538466, 0.4824125424483211, 0.2125931493102241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 150}], {
             RGBColor[
             0.8761748343795548, 0.5085261390565783, 0.21751289486357597`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 197}], {
             RGBColor[
             0.9156409832962333, 0.6675280137453463, 0.53334242652665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 198}], {
             RGBColor[
             0.9047656578317846, 0.6597743590910152, 0.567745210695355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 237}], {
             RGBColor[
             0.8350074590728989, 0.27008824756648975`, 0.18115648838446502`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 243}], {
             RGBColor[
             0.9161788814227196, 0.6677504484439996, 0.5244280625350448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 256}], {
             RGBColor[
             0.8314341794329242, 0.2426224544325225, 0.1777347117657832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 269}], {
             RGBColor[
             0.9090525762339738, 0.6337885535682664, 0.2704596348011703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 277}], {
             RGBColor[
             0.9189757209517455, 0.6669480138238988, 0.3356785999121213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 281}], {
             RGBColor[
             0.9117009146920902, 0.6649466623019902, 0.5560056298355394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 165}], {
             RGBColor[
             0.20344097121398075`, 0.33115973802143944`, 0.9348970343954657]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 175}], {
             RGBColor[
             0.18584814501363772`, 0.3126685622352725, 0.9338951489696101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 183}], {
             RGBColor[
             0.1909140048229797, 0.31799310208895415`, 0.9341836421914842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 184}], {
             RGBColor[
             0.19028873719925032`, 0.31733590617215746`, 0.9341480341253134]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 224}], {
             RGBColor[
             0.19887770973958555`, 0.32636346088436186`, 0.9346371634052393]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 253}], {
             RGBColor[
             0.19046881652676248`, 0.3175251809630616, 0.9341582893766117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 140}], {
             RGBColor[
             0.8645610911257005, 0.4110815190068649, 0.2060554870376654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 162}], {
             RGBColor[
             0.9515757296113414, 0.8393631712246421, 0.5204689724050278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 167}], {
             RGBColor[
             0.9097426027065735, 0.6798665267659179, 0.24623498340554434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 201}], {
             RGBColor[
             0.8785836373176991, 0.5188649537574892, 0.21948349310732407`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 202}], {
             RGBColor[
             0.8891869589427635, 0.5875233681861427, 0.22913433202447103`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 203}], {
             RGBColor[
             0.92446413705714, 0.8203323074950271, 0.6196039862679017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 216}], {
             RGBColor[
             0.889133450052471, 0.5872803968126434, 0.22908968289478807`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 237}], {
             RGBColor[
             0.8684389229143985, 0.44088823341152344`, 0.20976890313790728`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 269}], {
             RGBColor[
             0.9424840400754735, 0.8045885394133, 0.29907204955461253`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 281}], {
             RGBColor[
             0.9451323785335899, 0.8357466481470239, 0.5846180445889815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 293}], {
             RGBColor[
             0.9057809743644036, 0.6628729165850431, 0.24298078524882644`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 294}], {
             RGBColor[
             0.723926300807685, 0.6611320656306849, 0.6022559472314186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 299}], {
             RGBColor[
             0.8652485405177199, 0.41636555627617133`, 0.20671378935182633`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 141}], {
             RGBColor[
             0.26162779894186294`, 0.392317783221403, 0.938210688154871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 146}], {
             RGBColor[
             0.2147184255833614, 0.3430130575955638, 0.9355392687383033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 170}], {
             RGBColor[
             0.21349214626363155`, 0.34172416027992825`, 0.9354694339451624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 178}], {
             RGBColor[
             0.2442095797785655, 0.3740101305018966, 0.9372187463414672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 182}], {
             RGBColor[
             0.24187571808972635`, 0.3715570938915489, 0.9370858363709268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 188}], {
             RGBColor[
             0.2926361203769149, 0.4205530757547836, 0.9401360760402346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 190}], {
             RGBColor[
             0.21691115903565433`, 0.3453177594812544, 0.9356641416645529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 199}], {
             RGBColor[
             0.21390129447571837`, 0.3421542009923264, 0.9354927343305601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 261}], {
             RGBColor[
             0.23707213530482818`, 0.36650822381988146`, 0.9368122794375908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 284}], {
             RGBColor[
             0.23518277089129241`, 0.36452238202863274`, 0.9367046829293041]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 133}], {
             RGBColor[
             0.19109281456444907`, 0.3181810424644308, 0.9341938251417357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 146}], {
             RGBColor[
             0.19846266788634026`, 0.3259272255814276, 0.9346135273856964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 236}], {
             RGBColor[
             0.21416362323535532`, 0.3424299251513089, 0.9355076735653408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 260}], {
             RGBColor[
             0.2275319348126233, 0.35648086821892655`, 0.9362689791330215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 267}], {
             RGBColor[
             0.19655119281637518`, 0.32391814408837505`, 0.9345046717082358]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 146}], {
             RGBColor[
             0.19265917133132254`, 0.3198273827391699, 0.9342830268423918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 170}], {
             RGBColor[
             0.1914328920115927, 0.3185384854235343, 0.9342131920492509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 144}], {
             RGBColor[
             0.22121948408189393`, 0.34984608226843733`, 0.9359094944023405]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 160}], {
             RGBColor[
             0.22028173175537732`, 0.3488604451163368, 0.9358560907946256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 169}], {
             RGBColor[
             0.42476901028009817`, 0.532311534169465, 0.9496393645496872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 176}], {
             RGBColor[
             0.21949584805110617`, 0.34803443151524305`, 0.9358113358802782]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 180}], {
             RGBColor[
             0.21984183187712564`, 0.34839808245303105`, 0.9358310391473328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 187}], {
             RGBColor[
             0.23476961577043198`, 0.36408812980106076`, 0.9366811543563793]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 193}], {
             RGBColor[
             0.26218140249464095`, 0.39289965565586527`, 0.9382422150582186]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 200}], {
             RGBColor[
             0.3051846864517926, 0.4328450374952205, 0.9408835556758889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 221}], {
             RGBColor[
             0.21549733286296777`, 0.343831738532004, 0.9355836263555868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 228}], {
             RGBColor[
             0.3355280602689666, 0.4591269427933443, 0.9428170086239273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 230}], {
             RGBColor[
             0.21844228820343148`, 0.34692707331578443`, 0.9357513372055553]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 245}], {
             RGBColor[
             0.2350207777833922, 0.3643521170012733, 0.9366954576614566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 264}], {
             RGBColor[
             0.27050450497484707`, 0.4016477640777385, 0.9387162034315397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 288}], {
             RGBColor[
             0.22683219740980134`, 0.35574539984264686`, 0.9362291301230996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 297}], {
             RGBColor[
             0.21839610407426302`, 0.3468785308677854, 0.9357487070877224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 158}], {
             RGBColor[
             0.20301108119461975`, 0.33070789635448955`, 0.9348725527948284]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 173}], {
             RGBColor[
             0.20718172638991203`, 0.3350915088889201, 0.9351100648687836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 186}], {
             RGBColor[
             0.20309625090443267`, 0.3307974151195744, 0.934877403083805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 213}], {
             RGBColor[
             0.20772578685862308`, 0.3356633509369615, 0.9351410483076115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 214}], {
             RGBColor[
             0.20695344714813524`, 0.3348515729320728, 0.9350970647036734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 249}], {
             RGBColor[
             0.21026660117408774`, 0.33833390787944695`, 0.9352857439240791]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 255}], {
             RGBColor[
             0.28954719045708177`, 0.4163676580228129, 0.9399945385263857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 263}], {
             RGBColor[
             0.21148289076359805`, 0.33961230535523634`, 0.9353550098168626]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 265}], {
             RGBColor[
             0.21789617448484386`, 0.3463530731719392, 0.9357202368371844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 276}], {
             RGBColor[
             0.22722517815635135`, 0.3561584475236893, 0.9362515097952526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 286}], {
             RGBColor[
             0.2169836251808333, 0.34539392599445645`, 0.9356682685043168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 177}], {
             RGBColor[
             0.34229360740819775`, 0.46934835455154167`, 0.9430884098094023]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 194}], {
             RGBColor[
             0.539310518839214, 0.6345587760249104, 0.957788184762517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 197}], {
             RGBColor[
             0.689478603616865, 0.751552751257122, 0.9111273992783655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 204}], {
             RGBColor[
             0.4381119186941594, 0.553069802846105, 0.9493643283826801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 210}], {
             RGBColor[
             0.43214727310106515`, 0.5482274348494092, 0.9488947696323751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 226}], {
             RGBColor[
             0.6894363159019072, 0.7515352642002422, 0.911828216152313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 252}], {
             RGBColor[
             0.3152788883487585, 0.44095417198795417`, 0.9415499615236627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 279}], {
             RGBColor[
             0.3146411108912604, 0.44028382744269734`, 0.9415136410409652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 280}], {
             RGBColor[
             0.32731420410911033`, 0.4536040519351767, 0.9422353549515605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 147}], {
             RGBColor[
             0.23746595794531072`, 0.3669221563848262, 0.9368347070543579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 156}], {
             RGBColor[
             0.32801284307365003`, 0.4541649141300481, 0.9422814923217423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 179}], {
             RGBColor[
             0.3921454633437752, 0.5078279411583735, 0.9468889147894293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 191}], {
             RGBColor[
             0.24445543716588297`, 0.3742685422042259, 0.9372327475559615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 217}], {
             RGBColor[
             0.23078620352350526`, 0.3599013109666169, 0.9364543049218471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 247}], {
             RGBColor[
             0.22964528868911577`, 0.358702137137495, 0.9363893315098609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 251}], {
             RGBColor[
             0.27357072658534587`, 0.4048705574000514, 0.9388908202161892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 270}], {
             RGBColor[
             0.23718665422901314`, 0.36662859047011903`, 0.9368188011209075]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 271}], {
             RGBColor[
             0.24208469003989352`, 0.37177673666076144`, 0.9370977370143425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 273}], {
             RGBColor[
             0.25023215692458567`, 0.3803402409358096, 0.9375617232003286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 278}], {
             RGBColor[
             0.23108207251171536`, 0.3602122880324031, 0.9364711542230267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 289}], {
             RGBColor[
             0.25248937634424146`, 0.382712721661845, 0.9376902685070212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 295}], {
             RGBColor[
             0.2292284865221631, 0.35826405163324404`, 0.9363655952430565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 210}], {
             RGBColor[
             0.35148342859896836`, 0.4711989277702072, 0.9440171598227016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 211}], {
             RGBColor[
             0.25101026684268113`, 0.38115808379474614`, 0.9376060354090536]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 231}], {
             RGBColor[
             0.23123426787294182`, 0.3603722550067954, 0.9364798215236958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 266}], {
             RGBColor[
             0.21471877848996196`, 0.3430134285227765, 0.935539288835812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 143}], {
             RGBColor[
             0.37380885559171856`, 0.49802499695333824`, 0.9450460153054621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 163}], {
             RGBColor[
             0.5309367698880918, 0.6297354344441368, 0.9563109238850767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 235}], {
             RGBColor[
             0.42460849977243, 0.5421962738843169, 0.9482766560323135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 273}], {
             RGBColor[
             0.3398266519904991, 0.46230754637230465`, 0.9431107790825377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 274}], {
             RGBColor[
             0.4518848560948061, 0.5655575295786147, 0.9500876676545675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 298}], {
             RGBColor[
             0.350430471977903, 0.4734528335000848, 0.9437146509438744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 162}], {
             RGBColor[
             0.904333638485641, 0.5624086522177772, 0.47863148536736244`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 167}], {
             RGBColor[
             0.862500511580873, 0.40291200775905295`, 0.20439749636787896`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 181}], {
             RGBColor[
             0.9018064820205194, 0.5497777318797257, 0.2827365338887451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 201}], {
             RGBColor[
             0.8313415461919986, 0.24191043475062424`, 0.1776460060696587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 202}], {
             RGBColor[
             0.8419448678170631, 0.3105688491792778, 0.18729684498680563`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 203}], {
             RGBColor[
             0.8772220459314396, 0.5433777884881621, 0.5777664992302363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 216}], {
             RGBColor[
             0.8418913589267707, 0.3103258778057786, 0.18725219585712266`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 237}], {
             RGBColor[
             0.8211968317886982, 0.16393371440465854`, 0.16793141610024187`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 269}], {
             RGBColor[
             0.8952419489497732, 0.5276340204064351, 0.25723456251694715`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 293}], {
             RGBColor[
             0.8585388832387033, 0.3859183975781782, 0.20114329821116103`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 299}], {
             RGBColor[
             0.8180064493920196, 0.1394110372693064, 0.16487630231416095`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 146}], {
             RGBColor[
             0.24693839801171524`, 0.3768782914820059, 0.9373741485029203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 178}], {
             RGBColor[
             0.27642955220691934`, 0.4078753643883386, 0.9390536261060842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 182}], {
             RGBColor[
             0.2740956905180802, 0.4054223277779909, 0.9389207161355438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 188}], {
             RGBColor[
             0.3248560928052687, 0.45441830964122576`, 0.9419709558048517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 236}], {
             RGBColor[
             0.2626393533607303, 0.39338099105188706`, 0.9382682946825648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 261}], {
             RGBColor[
             0.269292107733182, 0.4003734577063236, 0.9386471592022079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 294}], {
             RGBColor[
             0.41494859536709305`, 0.5302055551777425, 0.9483322441534972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 149}], {
             RGBColor[
             0.8627196996396836, 0.42474633719376353`, 0.20540890846687038`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[
             0.8686725031653917, 0.4508599338020208, 0.21032865402022227`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 163}], {
             RGBColor[
             0.7255429896746053, 0.4672102742569026, 0.5698090215965668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 197}], {
             RGBColor[
             0.9081386520820702, 0.6098618084907887, 0.5261581856832962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 198}], {
             RGBColor[
             0.8972633266176216, 0.6021081538364577, 0.5605609698520013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 243}], {
             RGBColor[
             0.9086765502085565, 0.610084243189442, 0.517243821691691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 256}], {
             RGBColor[
             0.8239318482187612, 0.18495624917796497`, 0.17055047092242953`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 277}], {
             RGBColor[
             0.9114733897375824, 0.6092818085693412, 0.32849435906876756`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 163}], {
             RGBColor[
             0.4640224729127619, 0.5716064552084593, 0.95205347173178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 174}], {
             RGBColor[
             0.27004966377854045`, 0.4011696971418227, 0.9386903008982872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 185}], {
             RGBColor[
             0.41822549913320267`, 0.5344264087640556, 0.9484481661960105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 235}], {
             RGBColor[
             0.3576942027971, 0.4840672946486393, 0.9440192038790169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 298}], {
             RGBColor[
             0.28351617500257303`, 0.41532385426440727`, 0.9394571987905778]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 160}], {
             RGBColor[
             0.19670215780285202`, 0.3240768178608952, 0.934513268940883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 176}], {
             RGBColor[
             0.19591627409858087`, 0.32325080425980146`, 0.9344685140265354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 221}], {
             RGBColor[
             0.19191775891044247`, 0.3190481112765624, 0.9342408045018441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 230}], {
             RGBColor[
             0.19486271425090618`, 0.32214344606034284`, 0.9344085153518125]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 231}], {
             RGBColor[
             0.21441031983489064`, 0.34268921891888826`, 0.9355217225717294]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 232}], {
             RGBColor[
             0.19277383312180774`, 0.31994789955094727`, 0.9342895566617331]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 240}], {
             RGBColor[
             0.18908519234139687`, 0.31607090421740214`, 0.9340794940261437]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 245}], {
             RGBColor[
             0.2114412038308669, 0.3395684897458317, 0.9353526358077138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 264}], {
             RGBColor[
             0.24692493102232177`, 0.3768641368222969, 0.9373733815777969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 288}], {
             RGBColor[
             0.20325262345727604`, 0.33096177258720527`, 0.9348863082693568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 297}], {
             RGBColor[
             0.19481653012173772`, 0.32209490361234383`, 0.9344058852339796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 156}], {
             RGBColor[
             0.6296976932681398, 0.7056126711214472, 0.9666670627828757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 159}], {
             RGBColor[
             0.5780723315879956, 0.6592789022873965, 0.963436800696632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 167}], {
             RGBColor[
             0.8862929429929738, 0.7834059474084649, 0.6157767446761826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 168}], {
             RGBColor[
             0.6326576416445393, 0.7081764296337532, 0.9668556680760403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 201}], {
             RGBColor[
             0.8551339776040994, 0.6224043744000362, 0.5890252543779623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 203}], {
             RGBColor[
             0.9010144773435402, 0.923871728137574, 0.9891457475385399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 205}], {
             RGBColor[
             0.6186317877643385, 0.696027939962637, 0.9659619530693695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 216}], {
             RGBColor[
             0.8656837903388712, 0.6908198174551905, 0.5986314441654264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 237}], {
             RGBColor[
             0.8449892632007987, 0.5444276540540705, 0.5793106644085455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 269}], {
             RGBColor[
             0.9190343803618738, 0.908127960055847, 0.6686138108252507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 277}], {
             RGBColor[
             0.9289575250796454, 0.9412874203114796, 0.7338327759362018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 282}], {
             RGBColor[
             0.6527680048201097, 0.7255950154401895, 0.9681370826346918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 293}], {
             RGBColor[
             0.8823313146508039, 0.7664123372275902, 0.6125225465194646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 170}], {
             RGBColor[
             0.19880274533348388`, 0.3262846685405311, 0.9346328942932117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 236}], {
             RGBColor[
             0.2157299800022288, 0.3440762654260479, 0.9355968752659971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 247}], {
             RGBColor[
             0.2055770841992048, 0.33340492820629564`, 0.9350186828698783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 273}], {
             RGBColor[
             0.22616395243467474`, 0.35504303200461024`, 0.9361910745603459]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 289}], {
             RGBColor[
             0.22842117185433053`, 0.35741551273064565`, 0.9363196198670385]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 156}], {
             RGBColor[
             0.32039438822353183`, 0.44615743504463745`, 0.9418476325885221]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 159}], {
             RGBColor[
             0.26876902654338763`, 0.39982366621058674`, 0.9386173705022783]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 168}], {
             RGBColor[
             0.32335433659993124`, 0.4487211935569434, 0.9420362378816867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 191}], {
             RGBColor[
             0.23683698231576478`, 0.36626106311881523`, 0.9367988878227413]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 205}], {
             RGBColor[
             0.3093284827197305, 0.43657270388582725`, 0.9411425228750159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 217}], {
             RGBColor[
             0.22316774867338707`, 0.35189383188120626`, 0.9360204451886269]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 225}], {
             RGBColor[
             0.23694694145511846`, 0.36637663714608804`, 0.9368051498330575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 251}], {
             RGBColor[
             0.26595227173522773`, 0.39686307831464074`, 0.9384569604829689]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 270}], {
             RGBColor[
             0.22956819937889494`, 0.35862111138470837`, 0.9363849413876872]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 271}], {
             RGBColor[
             0.23446623518977533`, 0.3637692575753508, 0.9366638772811222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 278}], {
             RGBColor[
             0.2234636176615972, 0.35220480894699246`, 0.9360372944898065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.3434646997755016, 0.4661397793633797, 0.9433176524403382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 295}], {
             RGBColor[
             0.2216100316720449, 0.3502565725478334, 0.9359317355098362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 150}], {
             RGBColor[
             0.901456610665, 0.644502615181237, 0.23943789960535378`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.9409227595816787, 0.803504489870005, 0.5552674312684278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 198}], {
             RGBColor[
             0.93004743411723, 0.7957508352156739, 0.5896702154371328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 243}], {
             RGBColor[
             0.9414606577081649, 0.8037269245686582, 0.5463530672768225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 256}], {
             RGBColor[
             0.8567159557183694, 0.3785989305571812, 0.19965971650756104`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 277}], {
             RGBColor[
             0.9442574972371908, 0.8029244899485575, 0.3576036046538991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 281}], {
             RGBColor[
             0.9369826909775356, 0.800923138426649, 0.5779306345773171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 179}], {
             RGBColor[
             0.7150830892215184, 0.6470263643951079, 0.5999650595216117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 237}], {
             RGBColor[
             0.8662420388840522, 0.43217832029940567`, 0.20800123867959472`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 256}], {
             RGBColor[
             0.8626687592440776, 0.4047125271654385, 0.20457946206091293`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 269}], {
             RGBColor[
             0.9402871560451271, 0.7958786263011822, 0.2973043850963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 274}], {
             RGBColor[
             0.6852279869066359, 0.622788647378854, 0.5976147565045411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 277}], {
             RGBColor[
             0.9502103007628988, 0.8290380865568148, 0.362523350207251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 281}], {
             RGBColor[
             0.9429354945032435, 0.8270367350349062, 0.582850380130669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 293}], {
             RGBColor[
             0.9035840903340573, 0.6541630034729253, 0.24121312079051388`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 154}], {
             RGBColor[
             0.5475628360948273, 0.6435752036232633, 0.9575252987275946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 181}], {
             RGBColor[
             0.7920610111090953, 0.8249056195457978, 0.6813687144574905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 192}], {
             RGBColor[
             0.4642226762503304, 0.5725842955959759, 0.9518849903358793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 220}], {
             RGBColor[
             0.46545874896093703`, 0.5736549196510825, 0.9519637517959829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 239}], {
             RGBColor[
             0.41770207455751684`, 0.5257103442374987, 0.9491616700514242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 258}], {
             RGBColor[
             0.4689947888884989, 0.5767176597098022, 0.9521890651333698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 208}], {
             RGBColor[
             0.1859180316496269, 0.31274201752076575`, 0.9338991289101417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 242}], {
             RGBColor[
             0.1817008098525566, 0.3083094500247394, 0.9336589643676192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 244}], {
             RGBColor[
             0.1860116480511821, 0.312840414294423, 0.9339044602257174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 268}], {
             RGBColor[
             0.1937845276020504, 0.3210102035314135, 0.9343471142171944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 157}], {
             RGBColor[
             0.2018036290672552, 0.32943878761174283`, 0.9348037901824403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 192}], {
             RGBColor[
             0.2758432306623323, 0.4052369526728678, 0.9390942768006172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 220}], {
             RGBColor[
             0.27707930337293885`, 0.40630757672797435`, 0.9391730382607208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 222}], {
             RGBColor[
             0.2212473690290584, 0.3498753911159149, 0.9359110824088295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 239}], {
             RGBColor[
             0.22932262896951866`, 0.3583630013143907, 0.9363709565161622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 248}], {
             RGBColor[
             0.2215139470361167, 0.3501555815033551, 0.9359262636319645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 285}], {
             RGBColor[
             0.21037441724900163`, 0.3384472294101154, 0.9352918838900459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 181}], {
             RGBColor[
             0.7417957890267707, 0.7840980478369171, 0.6774116520475943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[
             0.7172113529376909, 0.7776981044453534, 0.9724416173890855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 216}], {
             RGBColor[
             0.6818806659330219, 0.5446461937629699, 0.581927314015972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 255}], {
             RGBColor[
             0.43165774296703474`, 0.5471078244024314, 0.9490557746765065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 258}], {
             RGBColor[
             0.4187295668061743, 0.5359100880009214, 0.9482320027234739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 162}], {
             RGBColor[
             0.9588310572734952, 0.8681281277104613, 0.5263067793464253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 194}], {
             RGBColor[
             0.8061596900222359, 0.7500989808439875, 0.6144534337056413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 210}], {
             RGBColor[
             0.698996444284087, 0.6637676396684864, 0.6055600185754992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 218}], {
             RGBColor[
             0.9467517036363646, 0.8603082831521655, 0.5999961337585191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 226}], {
             RGBColor[
             0.9562854870849291, 0.8670754690193194, 0.5684934650954372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 227}], {
             RGBColor[
             0.9395091625151377, 0.7978810172888317, 0.27018585613847523`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 241}], {
             RGBColor[
             0.9562190222247212, 0.8670479840915544, 0.569594959834627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 290}], {
             RGBColor[
             0.9363623874102649, 0.7854051025986525, 0.2676538870247894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 291}], {
             RGBColor[
             0.9265943306289632, 0.845047396157727, 0.6262279650717502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.8725038681798738, 0.44513051276199045`, 0.2125515962932238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 159}], {
             RGBColor[
             0.3428661620319342, 0.4697766941100199, 0.9431273668629003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 168}], {
             RGBColor[
             0.3974514720884778, 0.5186742214563766, 0.9465462342423088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.4586241439822036, 0.5697734899723961, 0.9509650514168311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 191}], {
             RGBColor[
             0.31093411780431135`, 0.4362140910182484, 0.9413088841833633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 205}], {
             RGBColor[
             0.38342561820827703`, 0.5065257317852604, 0.945652519235638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 251}], {
             RGBColor[
             0.3400494072237743, 0.46681610621407393`, 0.942966956843591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 269}], {
             RGBColor[
             0.6838282108058124, 0.7186257518784704, 0.6483043769915192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 270}], {
             RGBColor[
             0.3036653348674415, 0.42857413928414156`, 0.9408949377483093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 271}], {
             RGBColor[
             0.3085633706783219, 0.433722285474784, 0.9411738736417443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 277}], {
             RGBColor[
             0.6937513555235839, 0.7517852121341029, 0.7135233421024703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 282}], {
             RGBColor[
             0.41756183526404816`, 0.5360928072628128, 0.9478276488009602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 171}], {
             RGBColor[
             0.1808430925709541, 0.30740793477935857`, 0.9336101186373109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 184}], {
             RGBColor[
             0.18701393581723674`, 0.31389388228526116`, 0.9339615390312422]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 222}], {
             RGBColor[
             0.20198183109515816`, 0.32962608924173, 0.9348139385243031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 248}], {
             RGBColor[
             0.20224840910221648`, 0.3299062796291701, 0.9348291197474383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 275}], {
             RGBColor[
             0.18135642915031058`, 0.30794748407168115`, 0.9336393523960919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 285}], {
             RGBColor[
             0.1911088793151014, 0.31819792753593046`, 0.9341947400055196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 186}], {
             RGBColor[
             0.19303082310645578`, 0.3202180123189185, 0.9343041918611762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 196}], {
             RGBColor[
             0.1980026870183727, 0.32544375652472224`, 0.9345873321557463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 207}], {
             RGBColor[
             0.189116703595207, 0.3161040245430854, 0.9340812885454315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 212}], {
             RGBColor[
             0.21315714444874106`, 0.34137205213213645`, 0.9354503560873951]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 214}], {
             RGBColor[
             0.19688801935015837`, 0.3242721701314169, 0.9345238534810445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 225}], {
             RGBColor[
             0.21027114178594725`, 0.3383386803504027, 0.9352860025052073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 265}], {
             RGBColor[
             0.20783074668686696`, 0.3357736703712833, 0.9351470256145558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 276}], {
             RGBColor[
             0.21715975035837445`, 0.34557904472303347`, 0.935678298572624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 168}], {
             RGBColor[
             0.3458261104083336, 0.4723404526223259, 0.943315972156065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 191}], {
             RGBColor[
             0.25930875612416715`, 0.38988032218419766`, 0.9380786220971196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 205}], {
             RGBColor[
             0.33180025652813283`, 0.4601919629512097, 0.9424222571493942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 212}], {
             RGBColor[
             0.2623047179263146, 0.3930292679932042, 0.9382492376896236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 225}], {
             RGBColor[
             0.2594187152635208, 0.38999589621147046`, 0.9380848841074358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 251}], {
             RGBColor[
             0.2884240455436301, 0.4204823373800232, 0.9397366947573472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 270}], {
             RGBColor[
             0.2520399731872973, 0.38224037045009085`, 0.9376646756620657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 271}], {
             RGBColor[
             0.2569380089981777, 0.38738851664073326`, 0.9379436115555007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 282}], {
             RGBColor[
             0.36593647358390397`, 0.4897590384287621, 0.9445973867147164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 176}], {
             RGBColor[
             0.19497852177206426`, 0.3222651671077009, 0.9344151104188206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 180}], {
             RGBColor[
             0.19532450559808373`, 0.32262881804548893`, 0.9344348136858753]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 193}], {
             RGBColor[
             0.23766407621559904`, 0.36713039124832314`, 0.9368459895967611]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 221}], {
             RGBColor[
             0.19098000658392586`, 0.31806247412446187`, 0.9341874008941293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 230}], {
             RGBColor[
             0.19392496192438957`, 0.3211578089082423, 0.9343551117440977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 232}], {
             RGBColor[
             0.19183608079529113`, 0.31896226239884673`, 0.9342361530540182]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 245}], {
             RGBColor[
             0.2105034515043503, 0.33858285259373117`, 0.935299232199999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 288}], {
             RGBColor[
             0.20231487113075944`, 0.32997613543510473`, 0.934832904661642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 296}], {
             RGBColor[
             0.1914857715941317, 0.31859406521754197`, 0.9342162034632482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 297}], {
             RGBColor[
             0.1938787777952211, 0.3211092664602433, 0.9343524816262648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 177}], {
             RGBColor[
             0.24681318446187503`, 0.3767466841021262, 0.9373670177764938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 244}], {
             RGBColor[
             0.19557921069497186`, 0.3228965292515542, 0.9344493187643406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 279}], {
             RGBColor[
             0.2191606879449377, 0.34768215699328187`, 0.9357922490080568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 280}], {
             RGBColor[
             0.2318337811627876, 0.36100238148576125`, 0.9365139629186521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 169}], {
             RGBColor[
             0.7980436197485294, 0.8403418316253028, 0.877535691789008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 181}], {
             RGBColor[
             0.9888211205061603, 0.9780593840975029, 0.5971500192561076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 202}], {
             RGBColor[
             0.9289595063027041, 0.738850501397055, 0.5017103303541681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 216}], {
             RGBColor[
             0.9289059974124116, 0.7386075300235558, 0.5016656812244851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 227}], {
             RGBColor[
             0.9720263822129245, 0.9204431940139248, 0.5369240475267748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 228}], {
             RGBColor[
             0.7088026697373979, 0.7671572402491821, 0.8707133358632482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 299}], {
             RGBColor[
             0.9050210878776606, 0.5676926894870836, 0.4792897876815234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 185}], {
             RGBColor[
             0.5753534134295759, 0.6661368462548543, 0.9597130747756251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 235}], {
             RGBColor[
             0.5148221170934733, 0.615777732139438, 0.9552841124586315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 274}], {
             RGBColor[
             0.5420984734158494, 0.6391389878337358, 0.9570951240808855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 292}], {
             RGBColor[
             0.6974329821497556, 0.7632343245346107, 0.9706993881593793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 298}], {
             RGBColor[
             0.44064408929894633`, 0.5470342917552059, 0.9507221073701924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 176}], {
             RGBColor[
             0.1880768897106564, 0.3150111142224146, 0.9340220726829731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 180}], {
             RGBColor[
             0.18842287353667586`, 0.3153747651602027, 0.9340417759500277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 187}], {
             RGBColor[
             0.2033506574299822, 0.3310648125082323, 0.9348918911590742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 221}], {
             RGBColor[
             0.184078374522518, 0.31080842123917557`, 0.9337943631582817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 230}], {
             RGBColor[
             0.1870233298629817, 0.313903756022956, 0.9339620740082502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 296}], {
             RGBColor[
             0.18458413953272382`, 0.31134001233225567`, 0.9338231657274008]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 297}], {
             RGBColor[
             0.18697714573381324`, 0.31385521357495705`, 0.9339594438904173]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 175}], {
             RGBColor[
             0.2002014223302363, 0.3277547667453615, 0.9347125468790196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 183}], {
             RGBColor[
             0.2052672821395783, 0.33307930659904317`, 0.9350010401008936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 224}], {
             RGBColor[
             0.21323098705618415`, 0.3414496653944509, 0.9354545613146487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 253}], {
             RGBColor[
             0.20482209384336109`, 0.3326113854731506, 0.9349756872860211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 262}], {
             RGBColor[
             0.26081704104435255`, 0.39146562526609985`, 0.9381645166920165]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 195}], {
             RGBColor[
             0.184909234384039, 0.31168170763319203`, 0.9338416793982484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 234}], {
             RGBColor[
             0.19012477797807242`, 0.3171635746350845, 0.9341386968902232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.21183524129599424`, 0.3399826481050988, 0.9353750756584267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 285}], {
             RGBColor[
             0.19288702957547718`, 0.3200668762008235, 0.9342960030323104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 168}], {
             RGBColor[
             0.6540467218133117, 0.5964674977433942, 0.5956559161356156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[
             0.8765230577728718, 0.5106954425096772, 0.21782550243753762`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 202}], {
             RGBColor[
             0.8871263793979363, 0.5793538569383307, 0.22747634135468459`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.9224035575123126, 0.8121627962472151, 0.6179459955981152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 216}], {
             RGBColor[
             0.8870728705076437, 0.5791108855648315, 0.22743169222500162`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 237}], {
             RGBColor[
             0.8663783433695712, 0.4327187221637115, 0.20811091246812083`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 269}], {
             RGBColor[
             0.9404234605306463, 0.796419028165488, 0.2974140588848261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 277}], {
             RGBColor[
             0.9503466052484179, 0.8295784884211206, 0.3626330239957771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 282}], {
             RGBColor[
             0.674157084988882, 0.6138860835498305, 0.5969373306942671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 293}], {
             RGBColor[
             0.9037203948195764, 0.6547034053372311, 0.24132279457904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 203}], {
             RGBColor[
             0.6687682561638781, 0.7369332784725033, 0.9690249189979729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 205}], {
             RGBColor[
             0.3863855665846765, 0.5090894902975664, 0.9458411245288025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 212}], {
             RGBColor[
             0.31689002798285826`, 0.4419267953395609, 0.941668105069032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 225}], {
             RGBColor[
             0.31400402532006444`, 0.4388934235578272, 0.9415037514868442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 269}], {
             RGBColor[
             0.6867881591822118, 0.7211895103907764, 0.6484929822846838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 276}], {
             RGBColor[
             0.3208926338924916, 0.4461337879304579, 0.9418960475542608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 282}], {
             RGBColor[
             0.42052178364044757`, 0.5386565657751188, 0.9480162540941248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 293}], {
             RGBColor[
             0.650085093471142, 0.5794738875625195, 0.5924017179788976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 193}], {
             RGBColor[
             0.44215135474031986`, 0.5505814803014513, 0.9506292633518225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 200}], {
             RGBColor[
             0.4851546386974715, 0.5905268621408066, 0.9532706039694929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 202}], {
             RGBColor[
             0.7356548490799517, 0.5885020285868033, 0.5862010514084512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 227}], {
             RGBColor[
             0.7787217249901721, 0.7700947212036731, 0.6214147685810579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 228}], {
             RGBColor[
             0.5154980125146456, 0.6168087674389304, 0.9552040569175313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 264}], {
             RGBColor[
             0.450474457220526, 0.5593295887233245, 0.9511032517251437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 299}], {
             RGBColor[
             0.7117164306549081, 0.41734421667683197`, 0.5637805087358065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 178}], {
             RGBColor[
             0.228293899528688, 0.35728174144686387`, 0.9363123718963757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 182}], {
             RGBColor[
             0.2259600378398488, 0.3548287048365162, 0.9361794619258352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 190}], {
             RGBColor[
             0.2009954787857768, 0.3285893704262217, 0.9347577672194614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 199}], {
             RGBColor[
             0.19798561422584082`, 0.3254258119372937, 0.9345863598854686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 261}], {
             RGBColor[
             0.22115645505495063`, 0.3497798347648488, 0.9359059049924991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 284}], {
             RGBColor[
             0.2192670906414149, 0.34779399297360003`, 0.9357983084842125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 184}], {
             RGBColor[
             0.1853189372548359, 0.31211233132706184`, 0.9338650113706392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 275}], {
             RGBColor[
             0.17966143058790973`, 0.3061659331134819, 0.9335428247354888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 285}], {
             RGBColor[
             0.18941388075270052`, 0.31641637657773114`, 0.9340982123449165]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 174}], {
             RGBColor[
             0.21189442021644855`, 0.34004484890265657`, 0.9353784458103991]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 238}], {
             RGBColor[
             0.18901379750666059`, 0.31599586371940025`, 0.9340754281959247]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 186}], {
             RGBColor[
             0.19720146830174806`, 0.32460162485334904`, 0.9345417039351314]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 213}], {
             RGBColor[
             0.20183100425593847`, 0.3294675606707361, 0.9348053491589379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 234}], {
             RGBColor[
             0.19772105404463286`, 0.3251477424127598, 0.9345712935745305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 249}], {
             RGBColor[
             0.20437181857140313`, 0.33213811761322165`, 0.9349500447754056]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 263}], {
             RGBColor[
             0.20558810816091344`, 0.33341651508901093`, 0.935019310668189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 286}], {
             RGBColor[
             0.2110888425781487, 0.3391981357282311, 0.9353325693556434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 235}], {
             RGBColor[
             0.3208493079592518, 0.4453409740728014, 0.9419209416251387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 238}], {
             RGBColor[
             0.21032414623090429`, 0.3383943913827284, 0.9352890210299346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 298}], {
             RGBColor[
             0.24667128016472487`, 0.3765975336885693, 0.9373589365366997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 183}], {
             RGBColor[
             0.18767445593923526`, 0.3145881308128762, 0.9339991546750381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 224}], {
             RGBColor[
             0.19563816085584113`, 0.3229584896082839, 0.9344526758887932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 253}], {
             RGBColor[
             0.18722926764301806`, 0.3141202096869836, 0.9339738018601655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 180}], {
             RGBColor[
             0.1945386218938126, 0.32180280444439524`, 0.9343900587715277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 187}], {
             RGBColor[
             0.20946640578711895`, 0.33749285179242483`, 0.9352401739805742]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 193}], {
             RGBColor[
             0.23687819251132788`, 0.36630437764722934`, 0.9368012346824135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 221}], {
             RGBColor[
             0.1901941228796547, 0.3172364605233681, 0.9341426459797817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 230}], {
             RGBColor[
             0.19313907822011844`, 0.32033179530714856`, 0.9343103568297502]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 245}], {
             RGBColor[
             0.20971756780007914`, 0.3377568389926374, 0.9352544772856515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 288}], {
             RGBColor[
             0.20152898742648828`, 0.32915012183401104`, 0.9347881497472945]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 296}], {
             RGBColor[
             0.19069988788986053`, 0.3177680516164482, 0.9341714485489008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 297}], {
             RGBColor[
             0.19309289409094996`, 0.3202832528591496, 0.9343077267119173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 194}], {
             RGBColor[
             0.4889886310377472, 0.5894215892292383, 0.9546385045000421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 226}], {
             RGBColor[
             0.6391144281004404, 0.7063980774045702, 0.908678535889838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 252}], {
             RGBColor[
             0.2649570005472917, 0.39581698519228203`, 0.9384002812611878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 268}], {
             RGBColor[
             0.24851062539069607`, 0.37853080214228807`, 0.9374636845262513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 279}], {
             RGBColor[
             0.2643192230897936, 0.3951466406470252, 0.9383639607784904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 280}], {
             RGBColor[
             0.27699231630764354`, 0.4084668651395046, 0.9390856746890857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 182}], {
             RGBColor[
             0.2566774713547828, 0.3871146750584845, 0.9379287743221401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 190}], {
             RGBColor[
             0.23171291230071078`, 0.36087534064819005`, 0.9365070796157662]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 199}], {
             RGBColor[
             0.2287030477407748, 0.357711782159262, 0.9363356722817735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 229}], {
             RGBColor[
             0.23836184028178953`, 0.36786378552268634`, 0.9368857262280812]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 261}], {
             RGBColor[
             0.2518738885698846, 0.38206580498681714`, 0.9376552173888041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 284}], {
             RGBColor[
             0.24998452415634886`, 0.38007996319556836`, 0.9375476208805174]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 205}], {
             RGBColor[
             0.44755823847840226`, 0.5601887588135859, 0.9502599417033248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 251}], {
             RGBColor[
             0.4041820274938994, 0.5204791332423994, 0.9475743793112779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 269}], {
             RGBColor[
             0.7479608310759376, 0.7722887789067958, 0.6529117994592061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 274}], {
             RGBColor[
             0.4929016619374462, 0.5991987999844676, 0.9532221708674471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 277}], {
             RGBColor[
             0.7578839757937091, 0.8054482391624284, 0.7181307645701571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 282}], {
             RGBColor[
             0.48169445553417334`, 0.5897558342911382, 0.9524350712686471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 289}], {
             RGBColor[
             0.383100677252795, 0.49832129750419296`, 0.9463738276021099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 187}], {
             RGBColor[
             0.20981238961313842`, 0.3378565027302129, 0.9352598772476289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 193}], {
             RGBColor[
             0.23722417633734735`, 0.3666680285850174, 0.9368209379494682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 215}], {
             RGBColor[
             0.2098131605219987, 0.33785731300430355`, 0.9352599211497481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 221}], {
             RGBColor[
             0.19054010670567417`, 0.3176001114611562, 0.9341623492468364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 230}], {
             RGBColor[
             0.1934850620461379, 0.3206954462449366, 0.9343300600968047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 233}], {
             RGBColor[
             0.20014010875548707`, 0.32769032229079487`, 0.9347090551616429]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 245}], {
             RGBColor[
             0.2100635516260986, 0.3381204899304254, 0.9352741805527061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 288}], {
             RGBColor[
             0.20187497125250775`, 0.32951377277179905`, 0.9348078530143491]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 296}], {
             RGBColor[
             0.19104587171588, 0.3181317025542363, 0.9341911518159554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 297}], {
             RGBColor[
             0.19343887791696943`, 0.3206469037969376, 0.9343274299789719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 201}], {
             RGBColor[
             0.9158290282125181, 0.65756116663035, 0.29616453995840375`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 202}], {
             RGBColor[
             0.9264323498375825, 0.7262195810590035, 0.3058153788755507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 203}], {
             RGBColor[
             0.961709527951959, 0.9590285203678879, 0.6962850331189814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 216}], {
             RGBColor[
             0.92637884094729, 0.7259766096855043, 0.3057707297458678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 227}], {
             RGBColor[
             0.9694992257478029, 0.9078122736758734, 0.34102909604815745`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 258}], {
             RGBColor[
             0.6632277418204424, 0.717240503923456, 0.6720754184533696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 299}], {
             RGBColor[
             0.9024939314125389, 0.5550617691490322, 0.28339483620290606`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 190}], {
             RGBColor[
             0.22937905061187158`, 0.35842230403784237`, 0.9363741696452258]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 199}], {
             RGBColor[
             0.22636918605193562`, 0.35525874554891435`, 0.936202762311233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 229}], {
             RGBColor[
             0.23602797859295035`, 0.36541074891233866`, 0.9367528162575407]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 261}], {
             RGBColor[
             0.24954002688104543`, 0.37961276837646946`, 0.9375223074182637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 284}], {
             RGBColor[
             0.24765066246750966`, 0.3776269265852207, 0.937414710909977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 224}], {
             RGBColor[
             0.2007040206651831, 0.3282830294619655, 0.9347411691106672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 253}], {
             RGBColor[
             0.19229512745236005`, 0.31944474954066526`, 0.9342622950820396]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 222}], {
             RGBColor[
             0.2064576757790399, 0.33433048578943325`, 0.9350688312576314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 224}], {
             RGBColor[
             0.20007875304145373`, 0.32762583354516883`, 0.9347055610444963]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 248}], {
             RGBColor[
             0.20672425378609824`, 0.33461067617687346`, 0.9350840124807664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 275}], {
             RGBColor[
             0.18583227383419235`, 0.31265188061938454`, 0.9338942451294201]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 218}], {
             RGBColor[
             0.7483730046735189, 0.8020037075647066, 0.948265724399384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 235}], {
             RGBColor[
             0.4690251433139141, 0.5785976856950342, 0.951678806922862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 262}], {
             RGBColor[
             0.41669813660407123`, 0.5328210539055609, 0.9483611851595068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 292}], {
             RGBColor[
             0.6516360083701964, 0.726054278090207, 0.9670940826236099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 196}], {
             RGBColor[
             0.19808785672818557`, 0.32553327528980713`, 0.9345921824447229]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 214}], {
             RGBColor[
             0.19697318905997124`, 0.32436168889650174`, 0.9345287037700212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 249}], {
             RGBColor[
             0.20028634308592377`, 0.3278440238438759, 0.934717382990427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 265}], {
             RGBColor[
             0.2079159163966799, 0.33586318913636815`, 0.9351518759035322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 286}], {
             RGBColor[
             0.2070033670926693, 0.3349040419588854, 0.9350999075706646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 193}], {
             RGBColor[
             0.25215196023065367`, 0.38235807593304705`, 0.9376710531585147]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 215}], {
             RGBColor[
             0.224740944415305, 0.35354736035233314`, 0.9361100363587946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 228}], {
             RGBColor[
             0.32549861800497937`, 0.4485853630705261, 0.9422458467242234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 229}], {
             RGBColor[
             0.22122626051320093`, 0.3498532047273915, 0.9359098803100787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 230}], {
             RGBColor[
             0.20841284593944426`, 0.3363854935929662, 0.9351801753058513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 233}], {
             RGBColor[
             0.2150678926487934, 0.3433803696388245, 0.9355591703706895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 245}], {
             RGBColor[
             0.22499133551940492`, 0.35381053727845513`, 0.9361242957617526]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 288}], {
             RGBColor[
             0.2168027551458141, 0.3452038201198287, 0.9356579682233956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 296}], {
             RGBColor[
             0.20597365560918635`, 0.3338217499022659, 0.9350412670250019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 297}], {
             RGBColor[
             0.20836666181027574`, 0.33633695114496726`, 0.9351775451880184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 236}], {
             RGBColor[
             0.29364767479578224`, 0.42161628358526776`, 0.9401936825679285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 260}], {
             RGBColor[
             0.3070159863730502, 0.43566722665288543`, 0.9409549881356092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 261}], {
             RGBColor[
             0.30030042916823396`, 0.42860875023970424`, 0.9405725470875715]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 281}], {
             RGBColor[
             0.66716299452805, 0.7330554302274623, 0.9326197293964239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 294}], {
             RGBColor[
             0.445956916802145, 0.5584408477111231, 0.9502576320388609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 257}], {
             RGBColor[
             0.1999558217805158, 0.327496624995631, 0.9346985602910465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 260}], {
             RGBColor[
             0.23700170640282697`, 0.36643419857842796`, 0.936808268615812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 267}], {
             RGBColor[
             0.20602096440657885`, 0.33387147444787646`, 0.9350439611910263]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 287}], {
             RGBColor[
             0.22941840696730975`, 0.35846367006274493`, 0.9363764109314454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 300}], {
             RGBColor[
             0.22074088939765935`, 0.34934304891065115`, 0.9358822391430908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 199}], {
             RGBColor[
             0.2014046269978636, 0.3290194111386199, 0.9347810676048591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 261}], {
             RGBColor[
             0.2245754678269734, 0.353373433966175, 0.9361006127118898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 284}], {
             RGBColor[
             0.22268610341343767`, 0.3513875921749262, 0.9359930162036031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 205}], {
             RGBColor[
             0.29986821230051, 0.4266293598594382, 0.9406037744698572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 217}], {
             RGBColor[
             0.21370747825416658`, 0.3419504878548173, 0.9354816967834682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 225}], {
             RGBColor[
             0.22748667103589795`, 0.35643329311969896`, 0.9362664014278987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 246}], {
             RGBColor[
             0.2059132617802264, 0.3337582721588391, 0.9350378276857872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 251}], {
             RGBColor[
             0.25649200131600725`, 0.38691973428825177`, 0.9379182120778102]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 270}], {
             RGBColor[
             0.22010792895967446`, 0.34867776735831935`, 0.9358461929825286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 271}], {
             RGBColor[
             0.22500596477055484`, 0.35382591354896176`, 0.9361251288759636]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 278}], {
             RGBColor[
             0.21400334724237668`, 0.34226146492060344`, 0.9354985460846478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 282}], {
             RGBColor[
             0.3340044293562811, 0.4561964353369906, 0.9427789040351794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 295}], {
             RGBColor[
             0.21214976125282442`, 0.34031322852144436`, 0.9353929871046776]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 218}], {
             RGBColor[
             0.6489034320102649, 0.7179182155893853, 0.9413556495465901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 220}], {
             RGBColor[
             0.3318533670341157, 0.4618564399149144, 0.9423663809943715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 222}], {
             RGBColor[
             0.2760214326902352, 0.40542425430285495`, 0.93910442514248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 248}], {
             RGBColor[
             0.27628801069729353`, 0.4057044446902951, 0.9391196063656152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 262}], {
             RGBColor[
             0.31722856394081744`, 0.4487355619302395, 0.9414511103067129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 200}], {
             RGBColor[
             0.3225670309120143, 0.4511149836272068, 0.9418734544780243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 215}], {
             RGBColor[
             0.252152731139514, 0.38235888620713765`, 0.9376710970606339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 228}], {
             RGBColor[
             0.35291040472918833`, 0.4773968889253306, 0.9438069074260627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 230}], {
             RGBColor[
             0.2358246326636532, 0.3651970194477707, 0.9367412360076905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 245}], {
             RGBColor[
             0.2524031222436139, 0.38262206313325964`, 0.9376853564635919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 264}], {
             RGBColor[
             0.28788684943506876`, 0.4199177102097248, 0.939706102233675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 288}], {
             RGBColor[
             0.24421454187002306`, 0.3740153459746332, 0.9372190289252349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 210}], {
             RGBColor[
             0.5788422967306146, 0.6683006695271059, 0.9604448643230148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 226}], {
             RGBColor[
             0.8361313395314567, 0.8716084988779389, 0.9233783108429527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 241}], {
             RGBColor[
             0.8360648746712487, 0.8715810139501738, 0.9244798055821426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 280}], {
             RGBColor[
             0.4740092277386598, 0.5736772866128733, 0.9537854496422005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 290}], {
             RGBColor[
             0.8162082398567924, 0.7899381324572718, 0.622538732772305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 291}], {
             RGBColor[
             0.8064401830754907, 0.8495804260163464, 0.9811128108192658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 234}], {
             RGBColor[
             0.18893962070800485`, 0.3159178992009325, 0.934071203936976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 207}], {
             RGBColor[
             0.19417373721693681`, 0.32141928751397403`, 0.9343692791289782]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 212}], {
             RGBColor[
             0.2182141780704709, 0.3466873151030251, 0.9357383466709418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 214}], {
             RGBColor[
             0.20194505297188817`, 0.32958743310230554`, 0.9348118440645912]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 225}], {
             RGBColor[
             0.21532817540767707`, 0.3436539433212913, 0.935573993088754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 265}], {
             RGBColor[
             0.21288778030859679`, 0.34108893334217194`, 0.9354350161981024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 276}], {
             RGBColor[
             0.22221678398010425`, 0.35089430769392205`, 0.9359662891561706]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 198}], {
             RGBColor[
             0.9754663865596167, 0.9808663065126991, 0.9104194926535587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 204}], {
             RGBColor[
             0.7349750271013598, 0.7901370127560131, 0.9142536375891683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 226}], {
             RGBColor[
             0.9862994243091077, 0.9886024741101505, 0.8767175253588012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 243}], {
             RGBColor[
             0.9868796101505515, 0.9888423958656835, 0.8671023444932484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 254}], {
             RGBColor[
             0.6525617744919028, 0.7195772493628625, 0.9087750915707931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 283}], {
             RGBColor[
             0.646081244426157, 0.713693683071829, 0.9083720606763512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 204}], {
             RGBColor[
             0.7240997016369111, 0.7823833581016821, 0.9486564217578735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 226}], {
             RGBColor[
             0.975424098844659, 0.9808488194558194, 0.9111203095275062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 243}], {
             RGBColor[
             0.9760042846861029, 0.9810887412113525, 0.9015051286619535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 254}], {
             RGBColor[
             0.6416864490274542, 0.7118235947085315, 0.9431778757394982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 256}], {
             RGBColor[
             0.8912595826963075, 0.5559607471998754, 0.554811777892692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 283}], {
             RGBColor[
             0.6352059189617083, 0.705940028417498, 0.9427748448450561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 209}], {
             RGBColor[
             0.1894252090832627, 0.31642828337140966`, 0.9340988574765833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 229}], {
             RGBColor[
             0.20805355497894237`, 0.33600785601311617`, 0.9351597142171741]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 233}], {
             RGBColor[
             0.20189518711453486`, 0.32953502092454917`, 0.9348090042777849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 259}], {
             RGBColor[
             0.19177802866162308`, 0.31890124592564373`, 0.9342328470708863]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 261}], {
             RGBColor[
             0.22156560326703745`, 0.35020987547724697`, 0.9359292053778969]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 284}], {
             RGBColor[
             0.21967623885350168`, 0.3482240336859982, 0.9358216088696103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 210}], {
             RGBColor[
             0.4186246829308158, 0.5365148469090834, 0.9480331221442837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 211}], {
             RGBColor[
             0.31815152117452855`, 0.44647400293362227`, 0.9416219977306357]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 227}], {
             RGBColor[
             0.6591374011618665, 0.6706282245294286, 0.6126589597072597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 228}], {
             RGBColor[
             0.3959136886863399, 0.5173422707646859, 0.946448248043733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 231}], {
             RGBColor[
             0.2983755222047893, 0.4256881741456715, 0.9404957838452779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 245}], {
             RGBColor[
             0.2954064062007655, 0.4225674449726149, 0.9403266970812623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 264}], {
             RGBColor[
             0.3308901333922204, 0.45986309204908005`, 0.9423474428513454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 202}], {
             RGBColor[
             0.8559674140090618, 0.41835228392990204`, 0.20072485105646432`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 203}], {
             RGBColor[
             0.8912445921234382, 0.6511612232387863, 0.591194505299895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 216}], {
             RGBColor[
             0.8559139051187693, 0.4181093125564028, 0.20068020192678135`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 237}], {
             RGBColor[
             0.8352193779806968, 0.2717171491552828, 0.18135942216990056`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 269}], {
             RGBColor[
             0.9092644951417719, 0.6354174551570593, 0.2706625685866058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 277}], {
             RGBColor[
             0.9191876398595434, 0.6685769154126919, 0.3358815336975568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 293}], {
             RGBColor[
             0.872561429430702, 0.49370183232880244`, 0.21457130428081972`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 299}], {
             RGBColor[
             0.8320289955840182, 0.24719447201993064`, 0.1783043083838196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 203}], {
             RGBColor[
             0.9018479137485027, 0.71981963766744, 0.6008453442170419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 216}], {
             RGBColor[
             0.8665172267438337, 0.4867677269850564, 0.21033104084392829`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 237}], {
             RGBColor[
             0.8458226996057612, 0.34037556358393634`, 0.1910102610870475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 269}], {
             RGBColor[
             0.9198678167668363, 0.7040758695857129, 0.2803134075037528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 293}], {
             RGBColor[
             0.8831647510557664, 0.562360246757456, 0.22422214319796666`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 299}], {
             RGBColor[
             0.8426323172090826, 0.3158528864485842, 0.18795514730096657`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 216}], {
             RGBColor[
             0.9017944048582103, 0.7195766662939407, 0.600800695087359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 237}], {
             RGBColor[
             0.8810998777201378, 0.5731845028928206, 0.5814799153304782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 255}], {
             RGBColor[
             0.651571481892223, 0.7220382969334023, 0.9679291557478935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 269}], {
             RGBColor[
             0.9551449948812127, 0.9368848088945971, 0.6707830617471834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 293}], {
             RGBColor[
             0.9184419291701429, 0.7951691860663403, 0.6146917974413972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 299}], {
             RGBColor[
             0.8779094953234592, 0.5486618257574685, 0.5784248015443972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 226}], {
             RGBColor[
             0.734932739386402, 0.7901195256991334, 0.9149544544631159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 243}], {
             RGBColor[
             0.7355129252278461, 0.7903594474546665, 0.9053392735975632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 254}], {
             RGBColor[
             0.40119508956919725`, 0.5210943009518455, 0.9470120206751078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 283}], {
             RGBColor[
             0.3947145595034514, 0.515210734660812, 0.9466089897806659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 225}], {
             RGBColor[
             0.29997817143986366`, 0.426744933886711, 0.9406100364801734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 251}], {
             RGBColor[
             0.3289835017199729, 0.45723137505526373`, 0.9422618471300848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 269}], {
             RGBColor[
             0.6727623053020111, 0.7090410207196602, 0.647599267278013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 282}], {
             RGBColor[
             0.40649592976024684`, 0.5265080761040026, 0.947122539087454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 219}], {
             RGBColor[
             0.20337837440800324`, 0.33109394480949034`, 0.9348934695999689]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 254}], {
             RGBColor[
             0.27060222090313846`, 0.400822588016517, 0.9387557425033809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 283}], {
             RGBColor[
             0.26412169083739256`, 0.3949390217254835, 0.938352711608939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 212}], {
             RGBColor[
             0.20932819464730518`, 0.33734758312138824`, 0.935232303060627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 214}], {
             RGBColor[
             0.19305906954872248`, 0.3202477011206687, 0.9343058004542764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 225}], {
             RGBColor[
             0.20644219198451136`, 0.33431421133965444`, 0.9350679494784392]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 242}], {
             RGBColor[
             0.18509931747274389`, 0.3118814970113848, 0.9338525043489474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 244}], {
             RGBColor[
             0.18941015567136937`, 0.31641246128106837`, 0.9340980002070455]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 252}], {
             RGBColor[
             0.21362941037883332`, 0.3418684335680528, 0.935477250933459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 268}], {
             RGBColor[
             0.19718303522223768`, 0.3245822505180589, 0.9345406541985226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 279}], {
             RGBColor[
             0.21299163292133522`, 0.34119808902279597`, 0.9354409304507616]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 259}], {
             RGBColor[
             0.18280847530695815`, 0.30947367664736153`, 0.9337220442766032]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 211}], {
             RGBColor[
             0.3712058892361785, 0.49192848437614356`, 0.9451403247792249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 226}], {
             RGBColor[
             0.7289680937933078, 0.7852771577024377, 0.9144848957128108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 227}], {
             RGBColor[
             0.7121917692235163, 0.7160827059719499, 0.6161772867558488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 241}], {
             RGBColor[
             0.7289016289330998, 0.7852496727746727, 0.9155863904520005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 290}], {
             RGBColor[
             0.7090449941186435, 0.7036067912817707, 0.613645317642163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 291}], {
             RGBColor[
             0.6992769373373419, 0.7632490848408453, 0.9722193956891239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 231}], {
             RGBColor[
             0.25095672851015194`, 0.3811018116127316, 0.937602986480219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 264}], {
             RGBColor[
             0.28347133969758304`, 0.41527672951614025`, 0.9394546454862865]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 266}], {
             RGBColor[
             0.23444123912717205`, 0.36374298512871284`, 0.9366624537923354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 214}], {
             RGBColor[
             0.21709951040225656`, 0.3455157287097197, 0.9356748679962401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 225}], {
             RGBColor[
             0.23048263283804543`, 0.3595822389287055, 0.9364370170204028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 265}], {
             RGBColor[
             0.22804223773896515`, 0.3570172289495861, 0.9362980401297512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 276}], {
             RGBColor[
             0.23737124141047264`, 0.3668226033013362, 0.9368293130878194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 234}], {
             RGBColor[
             0.19826511451334394`, 0.3257195844608012, 0.9346022770133582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 249}], {
             RGBColor[
             0.2049158790401142, 0.33270995966126304`, 0.9349810282142335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 263}], {
             RGBColor[
             0.2061321686296245, 0.3339883571370523, 0.9350502941070169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 286}], {
             RGBColor[
             0.21163290304685975`, 0.3397699777762725, 0.935363552794471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 265}], {
             RGBColor[
             0.21177311264038245`, 0.33991734694886655`, 0.9353715375234006]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 276}], {
             RGBColor[
             0.22110211631188992`, 0.34972272130061666`, 0.9359028104814688]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 286}], {
             RGBColor[
             0.21086056333637188`, 0.3389581997713838, 0.9353195691905329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 229}], {
             RGBColor[
             0.2212270314220612, 0.34985401500148217`, 0.9359099242121978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 233}], {
             RGBColor[
             0.2150686635576537, 0.34338117991291517`, 0.9355592142728086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 259}], {
             RGBColor[
             0.20495150510474192`, 0.33274740491400967`, 0.9349830570659099]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 296}], {
             RGBColor[
             0.20597442651804665`, 0.33382256017635653`, 0.935041310927121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 237}], {
             RGBColor[
             0.8457691907154687, 0.3401325922104371, 0.19096561195736456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 269}], {
             RGBColor[
             0.9198143078765437, 0.7038328982122137, 0.28026875837406984`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 293}], {
             RGBColor[
             0.8831112421654739, 0.5621172753839567, 0.2241774940682837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 299}], {
             RGBColor[
             0.8425788083187902, 0.31560991507508496`, 0.1879104981712836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 223}], {
             RGBColor[
             0.19076430807847547`, 0.31783576131915836`, 0.9341751171833412]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 246}], {
             RGBColor[
             0.1922440281378487, 0.31939104092123016`, 0.9342593850516728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 247}], {
             RGBColor[
             0.19889732977739935`, 0.3263840827880864, 0.9346382807373675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 251}], {
             RGBColor[
             0.24282276767362948`, 0.3725525030506428, 0.9371397694436958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 270}], {
             RGBColor[
             0.20643869531729672`, 0.3343105361207104, 0.9350677503484142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 271}], {
             RGBColor[
             0.21133673112817714`, 0.3394586823113528, 0.9353466862418491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 278}], {
             RGBColor[
             0.20033411359999898`, 0.32789423368299453`, 0.9347201034505334]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 295}], {
             RGBColor[
             0.19848052761044668`, 0.32594599728383544`, 0.9346145444705631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 220}], {
             RGBColor[
             0.6501395047208716, 0.7189888396444919, 0.9414344110066938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 262}], {
             RGBColor[
             0.6355147016275733, 0.7058679616598169, 0.9405191403190352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 290}], {
             RGBColor[
             0.956800253470921, 0.9001474347654498, 0.6080814328251828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 292}], {
             RGBColor[
             0.8704525733936984, 0.8991011858444631, 0.9592520377831382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 250}], {
             RGBColor[
             0.1834940050025886, 0.3101942118225623, 0.933761084178619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 222}], {
             RGBColor[
             0.2772575054008418, 0.4064948783579615, 0.9391831866025837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 248}], {
             RGBColor[
             0.27752408340790014`, 0.40677506874540165`, 0.9391983678257189]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 262}], {
             RGBColor[
             0.318464636651424, 0.44980618598534605`, 0.9415298717668166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 230}], {
             RGBColor[
             0.18914056303198, 0.3161291023239095, 0.9340826473050587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 232}], {
             RGBColor[
             0.18705168190288157`, 0.31393355581451393`, 0.9339636886149794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 245}], {
             RGBColor[
             0.20571905261194073`, 0.33355414600939837`, 0.93502676776096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 288}], {
             RGBColor[
             0.19753047223834988`, 0.324947428850772, 0.9345604402226031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 296}], {
             RGBColor[
             0.18670137270172213`, 0.31356535863320917`, 0.9339437390242094]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 297}], {
             RGBColor[
             0.18909437890281156`, 0.31608055987591055`, 0.9340800171872259]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 248}], {
             RGBColor[
             0.22169214906401963`, 0.3503428831333422, 0.9359364119738274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 285}], {
             RGBColor[
             0.21055261927690455`, 0.33863453104010255`, 0.9353020322319088]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 246}], {
             RGBColor[
             0.1829700916045353, 0.3096435456231802, 0.9337312480856603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 247}], {
             RGBColor[
             0.18962339324408597`, 0.3166365874900364, 0.934110143771355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 270}], {
             RGBColor[
             0.19716475878398335`, 0.32456304082266046`, 0.9345396133824015]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 271}], {
             RGBColor[
             0.20206279459486376`, 0.3297111870133029, 0.9348185492758365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 278}], {
             RGBColor[
             0.1910601770666856, 0.31814673838494456`, 0.9341919664845209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 295}], {
             RGBColor[
             0.1892065910771333, 0.3161985019857855, 0.9340864075045505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 253}], {
             RGBColor[
             0.20025883236896588`, 0.32781510833607297`, 0.9347158162957947]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 262}], {
             RGBColor[
             0.2562537795699573, 0.3866693481290222, 0.9379046457017901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 265}], {
             RGBColor[
             0.22515623507617133`, 0.35398385716785236`, 0.9361336865475633]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 276}], {
             RGBColor[
             0.23448523874767882`, 0.3637892315196025, 0.9366649595056316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 241}], {
             RGBColor[
             0.9861906717339419, 0.9885575021255057, 0.8785198369719385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 243}], {
             RGBColor[
             0.9868373224355939, 0.9888249088088037, 0.8678031613671959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 290}], {
             RGBColor[
             0.9663340369194856, 0.9069146206326038, 0.576578764162101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 291}], {
             RGBColor[
             0.956565980138184, 0.9665569141916783, 0.9351528422090618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 241}], {
             RGBColor[
             0.9694143471641505, 0.9193630503950179, 0.5802122280149764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 290}], {
             RGBColor[
             0.9495577123496941, 0.837720168902116, 0.27827115520513895`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 291}], {
             RGBColor[
             0.9397896555683924, 0.8973624624611904, 0.6368452332520997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 299}], {
             RGBColor[
             0.885699193119303, 0.49744557906545395`, 0.22316886447357331`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 264}], {
             RGBColor[
             0.3612335072093944, 0.48614499734720384`, 0.9442808957993838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 233}], {
             RGBColor[
             0.2115539796555496, 0.3396870242879735, 0.9353590582240927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 259}], {
             RGBColor[
             0.2014368212026378, 0.32905324928906804`, 0.934782901017194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 284}], {
             RGBColor[
             0.22933503139451644`, 0.3583760370494225, 0.936371662815918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 245}], {
             RGBColor[
             0.20866400795240445`, 0.3366494807931788, 0.9351944786109285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 288}], {
             RGBColor[
             0.2004754275788136, 0.3280427636345524, 0.9347281510725716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 296}], {
             RGBColor[
             0.18964632804218584`, 0.3166606934169896, 0.9341114498741778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 297}], {
             RGBColor[
             0.19203933424327527`, 0.319175894659691, 0.9342477280371944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 232}], {
             RGBColor[
             0.20954424282732975`, 0.33757466345683984`, 0.9352446066848648]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 245}], {
             RGBColor[
             0.2282116135363889, 0.3571952536517242, 0.9363076858308454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 264}], {
             RGBColor[
             0.2636953407278438, 0.39449090072818943`, 0.9383284316009286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 266}], {
             RGBColor[
             0.21466524015743277`, 0.342957156340762, 0.9355362399069774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 240}], {
             RGBColor[
             0.184219115333836, 0.3109563487553536, 0.933802378139279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 245}], {
             RGBColor[
             0.206575126823306, 0.3344539342837832, 0.9350755199208491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 288}], {
             RGBColor[
             0.19838654644971515`, 0.32584721712515685`, 0.9346091923824922]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 297}], {
             RGBColor[
             0.18995045311417683`, 0.3169803481502954, 0.934128769347115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 259}], {
             RGBColor[
             0.1952784533382303, 0.32258041420050104`, 0.9344321910778048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[
             0.2158656276199601, 0.3442188396728392, 0.9356046001971543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 249}], {
             RGBColor[
             0.2008059288288086, 0.3283901414032867, 0.934746972629826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 263}], {
             RGBColor[
             0.20202221841831886`, 0.32966853887907605`, 0.9348162385226094]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 274}], {
             RGBColor[
             0.43577020330018756`, 0.5515998272739158, 0.9490608562281224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 298}], {
             RGBColor[
             0.33431581918328446`, 0.4594951311953859, 0.9426878395174293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 260}], {
             RGBColor[
             0.2447992469285118, 0.3746299080635468, 0.9372523270133223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 267}], {
             RGBColor[
             0.21381850493226368`, 0.3420671839329953, 0.9354880195885366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 294}], {
             RGBColor[
             0.38374017735760657`, 0.49740352912178454`, 0.9465549709165739]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 256}], {
             RGBColor[
             0.8215013839374217, 0.16627463567534986`, 0.16822305558180195`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 269}], {
             RGBColor[
             0.8991197807384712, 0.5574407348110937, 0.260947978617189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 277}], {
             RGBColor[
             0.9090429254562429, 0.5906001950667261, 0.32616694372814004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 281}], {
             RGBColor[
             0.9017681191965876, 0.5885988435448176, 0.546493973651558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 293}], {
             RGBColor[
             0.8624167150274014, 0.41572511198283674`, 0.2048567143114029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 248}], {
             RGBColor[
             0.22976740900447992`, 0.35883049333181793`, 0.9363962860811601]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 258}], {
             RGBColor[
             0.28886880526886394`, 0.4180452286151569, 0.9398683740473033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 263}], {
             RGBColor[
             0.22373268173624067`, 0.3524876123490904, 0.9360526172908128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 285}], {
             RGBColor[
             0.21862787921736482`, 0.3471221412385783, 0.9357619063392415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 290}], {
             RGBColor[
             0.9662675720592777, 0.9068871357048387, 0.5776802589012907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 291}], {
             RGBColor[
             0.956499515277976, 0.9665294292639133, 0.9362543369482514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 250}], {
             RGBColor[
             0.18176798085569046`, 0.30838005100792065`, 0.933662789656877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 268}], {
             RGBColor[
             0.1929658134251674, 0.3201496830220325, 0.934300489656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 254}], {
             RGBColor[
             0.6530996726183891, 0.7197996840615158, 0.8998607275791879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 256}], {
             RGBColor[
             0.9026728062872424, 0.5639368365528598, 0.5114946297323817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 283}], {
             RGBColor[
             0.6466191425526432, 0.7139161177704824, 0.899457696684746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 279}], {
             RGBColor[
             0.21308524932289044`, 0.3412964857964532, 0.9354462617663373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 280}], {
             RGBColor[
             0.22575834254074034`, 0.3546167102889326, 0.9361679756769326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 264}], {
             RGBColor[
             0.26072622472382, 0.3913701715551329, 0.938159344836913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 288}], {
             RGBColor[
             0.2170539171587743, 0.34546780732004123`, 0.9356722715284729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 297}], {
             RGBColor[
             0.20861782382323596`, 0.3366009383451798, 0.9351918484930957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 270}], {
             RGBColor[
             0.19864447884335656`, 0.3261183204247322, 0.9346238812507333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 278}], {
             RGBColor[
             0.1925398971260588, 0.3197020179870163, 0.9342762343528525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 295}], {
             RGBColor[
             0.19068631113650653`, 0.3177537815878572, 0.9341706753728822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 251}], {
             RGBColor[
             0.24168185283923999`, 0.37135332922152087`, 0.9370747960317096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 270}], {
             RGBColor[
             0.20529778048290723`, 0.33311136229158844`, 0.935002776936428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 271}], {
             RGBColor[
             0.21019581629378764`, 0.33825950848223085`, 0.9352817128298629]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 278}], {
             RGBColor[
             0.19919319876560948`, 0.3266950598538726, 0.9346551300385472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 289}], {
             RGBColor[
             0.22060050259813557`, 0.34919549348331447`, 0.9358742443225416]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 295}], {
             RGBColor[
             0.1973396127760572, 0.3247468234547135, 0.9345495710585769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 285}], {
             RGBColor[
             0.21081919728396287`, 0.3389147214275427, 0.9353172134550438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 258}], {
             RGBColor[
             0.2738091064777124, 0.40221653034560445`, 0.9390107464799751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 263}], {
             RGBColor[
             0.20867298294508915`, 0.33665891407953785`, 0.9351949897234846]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 286}], {
             RGBColor[
             0.2141737173623244, 0.342440534718758, 0.9355082484109388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 270}], {
             RGBColor[
             0.24922321837913736`, 0.37927978255414485`, 0.9375042656427561]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 271}], {
             RGBColor[
             0.25412125419001774`, 0.38442792874478726`, 0.9377832015361911]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 278}], {
             RGBColor[
             0.24311863666183964`, 0.372863480116429, 0.9371566187448754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 282}], {
             RGBColor[
             0.363119718775744, 0.4867984505328162, 0.944436976695407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 289}], {
             RGBColor[
             0.26452594049436573`, 0.3953639137458709, 0.9383757330288698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 295}], {
             RGBColor[
             0.24126505067228732`, 0.3709152437172699, 0.9370510597649051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 268}], {
             RGBColor[
             0.22149590633125682`, 0.35013661957870057`, 0.9359252362405117]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 279}], {
             RGBColor[
             0.23730450403035436`, 0.36675245808343765`, 0.9368255124927507]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 280}], {
             RGBColor[
             0.2499775972482043, 0.3800726825759171, 0.937547226403346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 283}], {
             RGBColor[
             0.27188152915805053`, 0.4030951038026612, 0.9387946229216484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 283}], {
             RGBColor[
             0.3123013068939945, 0.44465097126766145`, 0.9411304437622906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 258}], {
             RGBColor[
             0.3530896957607064, 0.48025028048897034`, 0.9437195410822816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 286}], {
             RGBColor[
             0.2934543066453184, 0.4204742848621239, 0.9402170430132455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 269}], {
             RGBColor[
             0.8955465010984967, 0.5299749416771264, 0.25752620199850723`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 277}], {
             RGBColor[
             0.9054696458162683, 0.5631344019327589, 0.3227451671094582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 281}], {
             RGBColor[
             0.8981948395566131, 0.5611330504108505, 0.5430721970328762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 293}], {
             RGBColor[
             0.8588434353874268, 0.38825931884886955`, 0.2014349376927211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 267}], {
             RGBColor[
             0.19014093188722048`, 0.31718055341781604`, 0.9341396168314517]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 272}], {
             RGBColor[
             0.18158199985616474`, 0.30818457318554265`, 0.9336521983140883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 300}], {
             RGBColor[
             0.20486085687830097`, 0.33265212788059073`, 0.9349778947835161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 263}], {
             RGBColor[
             0.2750253960672227, 0.40349492782139373`, 0.9390800123727585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 286}], {
             RGBColor[
             0.28052613048445796`, 0.4092765484606139, 0.9393932710602128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 267}], {
             RGBColor[
             0.22718681650953165`, 0.35611812700061296`, 0.9362493251562173]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 287}], {
             RGBColor[
             0.25058425907026255`, 0.38071032261548143`, 0.9375817748966364]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 294}], {
             RGBColor[
             0.39710848893487455`, 0.5114544721894022, 0.9473162764842546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 300}], {
             RGBColor[
             0.24190674150061214`, 0.37158970146338766`, 0.9370876031082818]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 284}], {
             RGBColor[
             0.2428470796826115, 0.3725780565135533, 0.937141153976641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 292}], {
             RGBColor[
             0.5387777053242508, 0.6299185321853173, 0.9593474985432611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 286}], {
             RGBColor[
             0.2153900069518347, 0.3437189321945473, 0.9355775143037223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 288}], {
             RGBColor[
             0.2525376443502292, 0.38276345439650644`, 0.937693017298556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 276}], {
             RGBColor[
             0.23204484364859856`, 0.36122422154048306`, 0.93652598261498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 286}], {
             RGBColor[
             0.22180329067308052`, 0.3504597000112502, 0.9359427413240442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 272}], {
             RGBColor[
             0.18764714248222777`, 0.31455942263778813`, 0.9339975992140681]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 287}], {
             RGBColor[
             0.2196035170740144, 0.34814759848492993`, 0.9358174674718507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 300}], {
             RGBColor[
             0.210925999504364, 0.33902697733283615`, 0.935323295683496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 279}], {
             RGBColor[
             0.22085812887375872`, 0.34946627503344374`, 0.9358889157578143]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 280}], {
             RGBColor[
             0.23353122209160865`, 0.3627864995259231, 0.9366106296684096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 277}], {
             RGBColor[
             0.9830880426173179, 0.9543005010685027, 0.41547009014484526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 282}], {
             RGBColor[
             0.7068985223577822, 0.7386080961972126, 0.6497743968433352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 293}], {
             RGBColor[
             0.9364618321884765, 0.7794254179846133, 0.2941598607281082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 271}], {
             RGBColor[
             0.217737181833685, 0.3461859618148549, 0.9357111824409096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 278}], {
             RGBColor[
             0.20673456430550685`, 0.3346215131864966, 0.9350845996495938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 289}], {
             RGBColor[
             0.22814186813803294`, 0.35712194681593845`, 0.9363037139335881]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 295}], {
             RGBColor[
             0.20488097831595456`, 0.3326732767873375, 0.9349790406696236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 278}], {
             RGBColor[
             0.21163260011638724`, 0.339769659377139, 0.9353635355430288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 289}], {
             RGBColor[
             0.23303990394891333`, 0.36227009300658086`, 0.9365826498270231]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 295}], {
             RGBColor[
             0.20977901412683497`, 0.3378214229779799, 0.9352579765630585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 274}], {
             RGBColor[
             0.3509883555182567, 0.4717110997619036, 0.9438949792783465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 289}], {
             RGBColor[
             0.24118737083360547`, 0.370833597281629, 0.9370466360130092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 289}], {
             RGBColor[
             0.3532455749379125, 0.4740835804879391, 0.944023524585039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 281}], {
             RGBColor[
             0.9857363810754343, 0.9854586098022267, 0.7010160851792143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 282}], {
             RGBColor[
             0.7168216670755537, 0.7717675564528452, 0.7149933619542863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 293}], {
             RGBColor[
             0.946384976906248, 0.8125848782402458, 0.35937882583905917`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 295}], {
             RGBColor[
             0.1987763965986568, 0.3262569743496216, 0.9346313937717428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 280}], {
             RGBColor[
             0.24933981979070619`, 0.37940233803066026`, 0.9375109059206487]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 294}], {
             RGBColor[
             0.7572554970898742, 0.8088426757639791, 0.9389810177450694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 293}], {
             RGBColor[
             0.6701954566467123, 0.5968924733689558, 0.5936831325375491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 300}], {
             RGBColor[
             0.2343234420650949, 0.3636191729477046, 0.9366557454239152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 296}], {
             RGBColor[
             0.1980362372485557, 0.3254790199438521, 0.9345892427917222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 297}], {
             RGBColor[
             0.20042924344964513`, 0.3279942211865534, 0.9347255209547387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 291}], {
             RGBColor[
             0.9366428804635196, 0.8848865477710113, 0.6343132641384139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 297}], {
             RGBColor[
             0.18960014391301738`, 0.31661215096899065`, 0.934108819756345]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.032105813875877395`], {
             RGBColor[
             0.8186934053129894, 0.1446912815038851, 0.16553413207988746`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.032105813875877395`], {
             RGBColor[
             0.19859115798198185`, 0.32606227681868954`, 0.934620844706559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.032105813875877395`], {
             RGBColor[
             0.9542183694281502, 0.96537671539683, 0.9623805381832607]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.032105813875877395`], {
             RGBColor[
             0.2205376694136581, 0.34912945182257465`, 0.935870666065639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.032105813875877395`], {
             RGBColor[
             0.9710126878169619, 0.9138811308413543, 0.3418901952738247]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.032105813875877395`], {
             RGBColor[
             0.2105950138195758, 0.3386790903924193, 0.9353044465383967]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.032105813875877395`], {
             RGBColor[
             0.9383196861766793, 0.9535195034595876, 0.9892928618873055]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.032105813875877395`], {
             RGBColor[
             0.2044682273202984, 0.33223944932097826`, 0.9349555351110312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.032105813875877395`], {
             RGBColor[
             0.19896010530687766`, 0.32645006384976655`, 0.9346418557109033]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.032105813875877395`], {
             RGBColor[
             0.19040293767796423`, 0.3174559381160143, 0.9341545376736317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.032105813875877395`], {
             RGBColor[
             0.5318148081413353, 0.630790245090044, 0.9562855562801685]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.032105813875877395`], {
             RGBColor[
             0.42962012936485927`, 0.5465370955454517, 0.948595992638333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.032105813875877395`], {
             RGBColor[
             0.33328873930237535`, 0.463099687229773, 0.9424578416460552]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.032105813875877395`], {
             RGBColor[
             0.1801938510546308, 0.30672554078141306`, 0.9335731452934231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.032105813875877395`], {
             RGBColor[
             0.2583760710911756, 0.38890001107887695`, 0.9380255070642746]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.032105813875877395`], {
             RGBColor[
             0.24679037784549854`, 0.37672271290229153`, 0.9373657189734305]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.032105813875877395`], {
             RGBColor[
             0.7036631405833589, 0.768426260552445, 0.9710982238135836]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.032105813875877395`], {
             RGBColor[
             0.19997475001447043`, 0.3275165197696367, 0.9346996382259684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.032105813875877395`], {
             RGBColor[
             0.18771789764902583`, 0.31463379080422954`, 0.9340016286161444]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.032105813875877395`], {
             RGBColor[
             0.21900416978762977`, 0.3475176464861269, 0.9357833355305459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.032105813875877395`], {
             RGBColor[
             0.19357781768564236`, 0.320792938303103, 0.9343353423932549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.032105813875877395`], {
             RGBColor[
             0.18854143418810532`, 0.3154993799220345, 0.9340485278037318]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.032105813875877395`], {
             RGBColor[
             0.989346654985427, 0.9898625823050647, 0.82621702707199]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.032105813875877395`], {
             RGBColor[
             0.9237640134240451, 0.7354567479025522, 0.2575169395936321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.032105813875877395`], {
             RGBColor[
             0.1911156300253715, 0.31820502296044406`, 0.9341951244484827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.032105813875877395`], {
             RGBColor[
             0.2290956026577889, 0.35812438226646315`, 0.9363580277035645]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.032105813875877395`], {
             RGBColor[
             0.9698415036520304, 0.9099304516459211, 0.33734036595263717`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.032105813875877395`], {
             RGBColor[
             0.18347004528514485`, 0.31016902864039503`, 0.9337597197081559]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.032105813875877395`], {
             RGBColor[
             0.19525519293228838`, 0.32255596603906117`, 0.934430866432097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.032105813875877395`], {
             RGBColor[
             0.24929644188312317`, 0.37935674509947226`, 0.9375084356129837]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.032105813875877395`], {
             RGBColor[
             0.41964854701834464`, 0.537900212103202, 0.9479606122287372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.032105813875877395`], {
             RGBColor[
             0.9876761626712638, 0.9891717908034641, 0.8539014078132029]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.032105813875877395`], {
             RGBColor[
             0.20050642775524471`, 0.3280753467855062, 0.9347299164867587]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.032105813875877395`], {
             RGBColor[
             0.1836929464736069, 0.31040331192222026`, 0.933772413601086]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.032105813875877395`], {
             RGBColor[
             0.20639345636736367`, 0.33426298711601565`, 0.9350651740571405]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.032105813875877395`], {
             RGBColor[
             0.18133311757286624`, 0.3079229821257478, 0.9336380248362428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.032105813875877395`], {
             RGBColor[
             0.22656828106141946`, 0.3554680070272346, 0.9362141004774884]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.032105813875877395`], {
             RGBColor[
             0.18611948239069784`, 0.312953755022346, 0.9339106012318261]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.032105813875877395`], {
             RGBColor[
             0.20172422019829714`, 0.3293553238556548, 0.934799267964828]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.032105813875877395`], {
             RGBColor[
             0.6892336433588957, 0.7571538276524538, 0.9696600263815672]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.032105813875877395`], {
             RGBColor[
             0.1885946642534308, 0.31555532809567266`, 0.9340515591772053]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.032105813875877395`], {
             RGBColor[
             0.8376047344232163, 0.2900520440423452, 0.18364364219313192`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.032105813875877395`], {
             RGBColor[
             0.2255865897625529, 0.3544361872293025, 0.9361581946103001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.032105813875877395`], {
             RGBColor[
             0.31621931418873805`, 0.44831500913059213`, 0.9413701929717141]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.032105813875877395`], {
             RGBColor[
             0.29993474933268105`, 0.43258081688308847`, 0.9403922123095734]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.032105813875877395`], {
             RGBColor[
             0.2047087295239663, 0.33249223238575365`, 0.9349692313557391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.032105813875877395`], {
             RGBColor[
             0.18409960782193097`, 0.31083073878312756`, 0.9337955723632715]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.032105813875877395`], {
             RGBColor[
             0.1928098846058197, 0.31998579194643995`, 0.9342916097404141]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.032105813875877395`], {
             RGBColor[
             0.20962180710681122`, 0.3376561884324342, 0.9352490238558351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.032105813875877395`], {
             RGBColor[
             0.1818234123124711, 0.30843831298355445`, 0.9336659463963373]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.032105813875877395`], {
             RGBColor[
             0.8112967405816618, 0.8525104469167772, 0.981826135168235]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.032105813875877395`], {
             RGBColor[
             0.1987330571876369, 0.3262114218807623, 0.9346289256564001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.032105813875877395`], {
             RGBColor[
             0.21587739356825456`, 0.3442312064305009, 0.9356052702505034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.032105813875877395`], {
             RGBColor[
             0.24403688677483204`, 0.37382861920560384`, 0.937208911730381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.032105813875877395`], {
             RGBColor[
             0.20213692733288047`, 0.32978910522124555`, 0.9348227710255971]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.032105813875877395`], {
             RGBColor[
             0.19935669202797407`, 0.3268669016386893, 0.9346644407379722]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.032105813875877395`], {
             RGBColor[
             0.17967566298483006`, 0.30618089226503126`, 0.9335436352494385]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.032105813875877395`], {
             RGBColor[
             0.19114091674596853`, 0.31823160090706226`, 0.9341965644898124]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.032105813875877395`], {
             RGBColor[
             0.985007685890186, 0.9880683070777632, 0.8981249738722014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.032105813875877395`], {
             RGBColor[
             0.28726741181117993`, 0.4192666419924039, 0.9396708261773704]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.032105813875877395`], {
             RGBColor[
             0.2772592389822082, 0.4087474177943471, 0.9391008755405253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.032105813875877395`], {
             RGBColor[
             0.20167701950442632`, 0.3293057129336997, 0.9347965799551393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.032105813875877395`], {
             RGBColor[
             0.18288267188311363`, 0.3095516619532356, 0.9337262696618512]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.032105813875877395`], {
             RGBColor[
             0.2353045398184947, 0.3646503688917182, 0.9367116174895672]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.032105813875877395`], {
             RGBColor[
             0.3774633879291902, 0.5013615475879224, 0.9452726111944477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.032105813875877395`], {
             RGBColor[
             0.3863417480503173, 0.5090515368854881, 0.9458383324505404]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.032105813875877395`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.032105813875877395`], {
             RGBColor[
             0.8768566069289154, 0.9046456729993274, 0.9881165600196555]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.032105813875877395`], {
             RGBColor[
             0.20756886290590398`, 0.3354984139131004, 0.9351321117206522]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.032105813875877395`], {
             RGBColor[
             0.20976983040282712`, 0.33781177030176596`, 0.9352574535635624]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.032105813875877395`], {
             RGBColor[
             0.22331684544677569`, 0.35205054204331915`, 0.9360289360293025]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.032105813875877395`], {
             RGBColor[
             0.8294154563220671, 0.22710566399236717`, 0.1758015802350048]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.032105813875877395`], {
             RGBColor[
             0.1826688110543663, 0.3093268806626624, 0.9337140906040328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.032105813875877395`], {
             RGBColor[
             0.20590138873724428`, 0.3337457928378705, 0.935037151533554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.032105813875877395`], {
             RGBColor[
             0.3329293714790703, 0.46278842088357813`, 0.9424349430461306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.032105813875877395`], {
             RGBColor[
             0.3269177544061254, 0.4575814603276529, 0.9420518881221068]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.032105813875877395`], {
             RGBColor[
             0.4137826929511934, 0.5328195041366336, 0.9475868451945494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.032105813875877395`], {
             RGBColor[
             0.19413140389541048`, 0.3213747925089622, 0.9343668683089438]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.032105813875877395`], {
             RGBColor[
             0.18314084159618357`, 0.3098230146905773, 0.9337409720450827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.032105813875877395`], {
             RGBColor[
             0.9788084084452291, 0.9401779270427488, 0.37217509781633024`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.032105813875877395`], {
             RGBColor[
             0.8894648943465696, 0.5909677260051436, 0.2294791371904563]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.032105813875877395`], {
             RGBColor[
             0.6134396494628491, 0.6970569684320459, 0.962711362790644]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.032105813875877395`], {
             RGBColor[
             0.846552585818907, 0.35882915084310774`, 0.19221211479479816`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.032105813875877395`], {
             RGBColor[
             0.18746791982634672`, 0.31437104826308443`, 0.9339873927489519]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.032105813875877395`], {
             RGBColor[
             0.23214849009490668`, 0.36133316052711717`, 0.9365318851267661]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.032105813875877395`], {
             RGBColor[
             0.5941770672605392, 0.6814187364307716, 0.9611949417585145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.032105813875877395`], {
             RGBColor[
             0.9931480500222558, 0.9877526967730439, 0.4955857141352578]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.032105813875877395`], {
             RGBColor[
             0.22285845764454237`, 0.35156874739970667`, 0.9360028315220893]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.032105813875877395`], {
             RGBColor[
             0.3807443443279537, 0.5042033471148679, 0.9454816708349412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.032105813875877395`], {
             RGBColor[
             0.21567607897691587`, 0.34401961203092163`, 0.935593805682345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.032105813875877395`], {
             RGBColor[
             0.49015879412300467`, 0.5969720163279171, 0.9530062422656385]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.032105813875877395`], {
             RGBColor[
             0.8315546894535105, 0.24354874725857717`, 0.17785011229759332`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.032105813875877395`], {
             RGBColor[
             0.24113006344271598`, 0.3707733635803057, 0.9370433724418767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.032105813875877395`], {
             RGBColor[
             0.796888814031874, 0.8412548651917855, 0.9803900876994809]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.032105813875877395`], {
             RGBColor[
             0.28755638833203334`, 0.4195703746379904, 0.9396872829627306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.032105813875877395`], {
             RGBColor[
             0.20095046543520778`, 0.32854205854076235`, 0.9347552037757377]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.032105813875877395`], {
             RGBColor[
             0.44885816070930806`, 0.563200111364443, 0.9498218229840781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.032105813875877395`], {
             RGBColor[
             0.1790520430393593, 0.3055254281625532, 0.9335081210161069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.032105813875877395`], {
             RGBColor[
             0.19567419878950365`, 0.3229963677615002, 0.9344547281958019]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.032105813875877395`], {
             RGBColor[
             0.1806628381309981, 0.3072184759341732, 0.933599853413618]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.032105813875877395`], {
             RGBColor[
             0.6473280227603806, 0.724416838346381, 0.9654832657505968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.032105813875877395`], {
             RGBColor[
             0.19219534584531597`, 0.31933987274514264`, 0.9342566126671321]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.032105813875877395`], {
             RGBColor[
             0.4213296380105047, 0.5393562886265211, 0.9480677298602272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.032105813875877395`], {
             RGBColor[
             0.3350878162698179, 0.46465795727473413`, 0.9425724772395593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.032105813875877395`], {
             RGBColor[
             0.28384023029084227`, 0.41566445691867016`, 0.9394756532598479]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.032105813875877395`], {
             RGBColor[
             0.861860606843299, 0.8926882695866354, 0.9866862281444021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.032105813875877395`], {
             RGBColor[
             0.40847529455142584`, 0.5282225024003548, 0.9472486624616643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.032105813875877395`], {
             RGBColor[
             0.24068546665888524`, 0.3703060641714354, 0.9370180533127597]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.032105813875877395`], {
             RGBColor[
             0.9928111618057213, 0.9912952449090205, 0.7688011832034702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.032105813875877395`], {
             RGBColor[
             0.18591721951216156`, 0.3127411639127972, 0.9338990826601146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.032105813875877395`], {
             RGBColor[
             0.6142037164471443, 0.6976772724307221, 0.9627715129425172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.032105813875877395`], {
             RGBColor[
             0.18923133529375677`, 0.3162245097263307, 0.9340878166510814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.032105813875877395`], {
             RGBColor[
             0.2676326072490897, 0.3986292174791347, 0.9385526531046497]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.032105813875877395`], {
             RGBColor[
             0.23913206195702244`, 0.3686733373382309, 0.9369295892130448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.032105813875877395`], {
             RGBColor[
             0.3517287364030146, 0.47907148589714393`, 0.9436328219554587]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.032105813875877395`], {
             RGBColor[
             0.2873518174774419, 0.41935535769927346`, 0.9396756329551971]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.032105813875877395`], {
             RGBColor[
             0.1855098238772711, 0.3123129652701522, 0.9338758820813954]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.032105813875877395`], {
             RGBColor[
             0.1887209958010121, 0.3156881105620633, 0.9340587535719493]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.032105813875877395`], {
             RGBColor[
             0.18085158366002294`, 0.307416859452336, 0.933610602192272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.032105813875877395`], {
             RGBColor[
             0.27909030860477735`, 0.41067198806418675`, 0.939205152246706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.032105813875877395`], {
             RGBColor[
             0.22544944565233713`, 0.35429204007402687`, 0.9361503844561099]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.032105813875877395`], {
             RGBColor[
             0.18504035865818397`, 0.31181952755907755`, 0.93384914673168]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.032105813875877395`], {
             RGBColor[
             0.19860317371820202`, 0.3260749061192986, 0.9346215289849611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.032105813875877395`], {
             RGBColor[
             0.1859244664032461, 0.3127487808548065, 0.9338994953598411]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.032105813875877395`], {
             RGBColor[
             0.8351944719959239, 0.27152571084244637`, 0.18133557217075477`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.032105813875877395`], {
             RGBColor[
             0.22348836128871713`, 0.3522308160679321, 0.9360387036027661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.032105813875877395`], {
             RGBColor[
             0.34883524619319184`, 0.47656529010844195`, 0.9434484513179017]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.032105813875877395`], {
             RGBColor[
             0.8449402545684014, 0.34643606632366236`, 0.19066814456844627`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.032105813875877395`], {
             RGBColor[
             0.18908769389738214`, 0.3160735335113504, 0.9340796364860563]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.032105813875877395`], {
             RGBColor[
             0.9118031822514008, 0.6880360380137298, 0.24789297407533079`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.032105813875877395`], {
             RGBColor[
             0.22940782651350908`, 0.3584525493349609, 0.9363758083902539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.032105813875877395`], {
             RGBColor[
             0.19689631111946682`, 0.3242808853066886, 0.9345243256850401]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.032105813875877395`], {
             RGBColor[
             0.18528931800943133`, 0.31208119962217307`, 0.9338633245984311]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.032105813875877395`], {
             RGBColor[
             0.24479905803441923`, 0.3746297095238789, 0.9372523162560832]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.032105813875877395`], {
             RGBColor[
             0.21307650899259664`, 0.34128729915514544`, 0.9354457640174572]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.032105813875877395`], {
             RGBColor[
             0.39261549520966454`, 0.5144855413472138, 0.9462380900718772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.032105813875877395`], {
             RGBColor[
             0.26153416243522165`, 0.3922193653160256, 0.9382053556943405]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.032105813875877395`], {
             RGBColor[
             0.231287806205471, 0.36042852718880986`, 0.9364828704525304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.032105813875877395`], {
             RGBColor[
             0.4407231525670485, 0.5561539761890157, 0.9493034674587586]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.032105813875877395`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.032105813875877395`], {
             RGBColor[
             0.2938477713702168, 0.42618301710784506`, 0.940045567919488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.032105813875877395`], {
             RGBColor[
             0.8299355921400753, 0.23110365581454728`, 0.17629966288173887`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.032105813875877395`], {
             RGBColor[
             0.3068945586163886, 0.4398960177176607, 0.9407885631521654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.032105813875877395`], {
             RGBColor[
             0.19763991012936863`, 0.32506245501299574`, 0.9345666725485978]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.032105813875877395`], {
             RGBColor[
             0.8649038628242013, 0.8951148792988238, 0.9869764966166072]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.032105813875877395`], {
             RGBColor[
             0.20002902465321373`, 0.3275735658561667, 0.9347027290863527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.032105813875877395`], {
             RGBColor[
             0.21339775345539977`, 0.34162494745362687`, 0.9354640584143752]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.032105813875877395`], {
             RGBColor[
             0.2462972527349853, 0.37620440714520426`, 0.9373376362279]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.032105813875877395`], {
             RGBColor[
             0.895503807139292, 0.6183890185729798, 0.2345181540520019]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.032105813875877395`], {
             RGBColor[
             0.9074094141907081, 0.6706162117894943, 0.24435764515870567`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.032105813875877395`], {
             RGBColor[
             0.5978280581771518, 0.684382775332144, 0.9614823611374906]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.032105813875877395`], {
             RGBColor[
             0.1825195240294396, 0.3091699705341204, 0.9337055889288136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.032105813875877395`], {
             RGBColor[
             0.22106916700115545`, 0.3496880894859278, 0.9359009340669666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.032105813875877395`], {
             RGBColor[
             0.4972976140125026, 0.6027676319143825, 0.9535682363176986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.032105813875877395`], {
             RGBColor[
             0.9263138375757084, 0.7455659509853682, 0.2595685879581257]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.032105813875877395`], {
             RGBColor[
             0.3944915237120784, 0.5161104629440706, 0.9463576289491441]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.032105813875877395`], {
             RGBColor[
             0.18253809113335498`, 0.30918948573755783`, 0.933706646297914]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.032105813875877395`], {
             RGBColor[
             0.19294565339664288`, 0.32012849355383366`, 0.9342993415721996]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.032105813875877395`], {
             RGBColor[
             0.29124080035179, 0.42344292527596916`, 0.9398971047766567]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.032105813875877395`], {
             RGBColor[
             0.19576440547633542`, 0.32309118070879467`, 0.9344598653331682]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.032105813875877395`], {
             RGBColor[
             0.2016546493170191, 0.3292822004483829, 0.9347953060060602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.032105813875877395`], {
             RGBColor[
             0.9913482769712819, 0.9906903044355545, 0.7930449707347249]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.032105813875877395`], {
             RGBColor[
             0.6211503872091352, 0.7033168926992579, 0.9633183803113946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.032105813875877395`], {
             RGBColor[
             0.18196114135351968`, 0.30858307493822207`, 0.9336737898614731]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.032105813875877395`], {
             RGBColor[
             0.21779424853057935`, 0.34624594253152846`, 0.935714432304875]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.032105813875877395`], {
             RGBColor[
             0.18609439165410657`, 0.312927383067344, 0.9339091723514956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.032105813875877395`], {
             RGBColor[
             0.9076820231617462, 0.6716970155181059, 0.2445769927357579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.032105813875877395`], {
             RGBColor[
             0.4004114204648772, 0.5212379799686826, 0.9467348395354733]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.032105813875877395`], {
             RGBColor[
             0.6047389625257771, 0.6899933588150511, 0.9620264128432912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.032105813875877395`], {
             RGBColor[
             0.19757646601375403`, 0.32499577122489554`, 0.9345630595000708]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.032105813875877395`], {
             RGBColor[
             0.17914809400855325`, 0.30562638382115925`, 0.9335135909767078]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.032105813875877395`], {
             RGBColor[
             0.19058407149220488`, 0.3176463212393284, 0.9341648529763892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.032105813875877395`], {
             RGBColor[
             0.20128694378722742`, 0.32889571862269473`, 0.9347743657201101]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.032105813875877395`], {
             RGBColor[
             0.23320476894069225`, 0.36244337656598474`, 0.9365920386444091]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.032105813875877395`], {
             RGBColor[
             0.18260859612989327`, 0.30926359095919453`, 0.9337106614531641]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.032105813875877395`], {
             RGBColor[
             0.19419263806779313`, 0.3214391535066072, 0.9343703555044731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.032105813875877395`], {
             RGBColor[
             0.29197171960673096`, 0.42421116775586953`, 0.9399387295469274]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.032105813875877395`], {
             RGBColor[
             0.25901133304362195`, 0.3895677116688322, 0.9380616842926806]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.032105813875877395`], {
             RGBColor[
             0.5227567642523288, 0.6234365170007214, 0.9555724738845179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.032105813875877395`], {
             RGBColor[
             0.19488460571983207`, 0.32216645538218325`, 0.9344097620385824]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.032105813875877395`], {
             RGBColor[
             0.9862939640410388, 0.9654284637594515, 0.4012550677774902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.032105813875877395`], {
             RGBColor[
             0.2543436096659436, 0.38466163844813683`, 0.9377958643515997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.032105813875877395`], {
             RGBColor[
             0.19274031574857725`, 0.3199126706665578, 0.9342876478969121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.032105813875877395`], {
             RGBColor[
             0.1914897805011185, 0.3185982788329645, 0.9342164317645705]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.032105813875877395`], {
             RGBColor[
             0.5295564396500168, 0.6289567998104505, 0.9561077692398556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.032105813875877395`], {
             RGBColor[
             0.19311599281626868`, 0.32030753108400334`, 0.9343090421501528]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.032105813875877395`], {
             RGBColor[
             0.22474017350644473`, 0.35354655007824254`, 0.9361099924566755]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.032105813875877395`], {
             RGBColor[
             0.35586441424032067`, 0.4826536021746064, 0.9438963436902155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.032105813875877395`], {
             RGBColor[
             0.21583585429987417`, 0.3441875460256914, 0.935602904650621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.032105813875877395`], {
             RGBColor[
             0.2044144915577996, 0.3321829696275479, 0.9349524749388519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.032105813875877395`], {
             RGBColor[
             0.2273767118965443, 0.3563177190924262, 0.9362601394175826]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.032105813875877395`], {
             RGBColor[
             0.3306172943235091, 0.4607858158598078, 0.9422876195342679]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.032105813875877395`], {
             RGBColor[
             0.27956374695486264`, 0.41116960178785156`, 0.939232113860354]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.032105813875877395`], {
             RGBColor[
             0.6860055424687634, 0.754632010702607, 0.9693382794531569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.032105813875877395`], {
             RGBColor[
             0.18372407711397143`, 0.31043603219904004`, 0.9337741864450011]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.032105813875877395`], {
             RGBColor[
             0.2030597206401025, 0.3307590194956109, 0.934875322739293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.032105813875877395`], {
             RGBColor[
             0.9863417120240653, 0.9886199611670301, 0.8760167084848537]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.032105813875877395`], {
             RGBColor[
             0.964591061095168, 0.9731126518583681, 0.9448222768222637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.032105813875877395`], {
             RGBColor[
             0.19839476243792764`, 0.32585585264969186`, 0.9346096602708663]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.032105813875877395`], {
             RGBColor[
             0.3655703148691659, 0.4910603654665621, 0.9445147950956946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.032105813875877395`], {
             RGBColor[
             0.8453640923839973, 0.3496938695012485, 0.19107401213931735`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.032105813875877395`], {
             RGBColor[
             0.8665707356341262, 0.4870106983585556, 0.21037568997361125`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.032105813875877395`], {
             RGBColor[
             0.9371250918628792, 0.9526285769763242, 0.9913149984604726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.032105813875877395`], {
             RGBColor[
             0.4836083421786542, 0.5916540643449961, 0.9524905666934831]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.032105813875877395`], {
             RGBColor[
             0.3723597127044757, 0.4969410006264502, 0.9449474095221317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.032105813875877395`], {
             RGBColor[
             0.22242260484653656`, 0.35111063847433904`, 0.9359780103500293]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.032105813875877395`], {
             RGBColor[
             0.18528775379377113`, 0.3120795555323372, 0.9338632355186633]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.032105813875877395`], {
             RGBColor[
             0.18931653926981418`, 0.3163140645074111, 0.9340926688914699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.032105813875877395`], {
             RGBColor[
             0.1804556557285978, 0.30700071409312746`, 0.9335880546823002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.032105813875877395`], {
             RGBColor[
             0.4716790509924657, 0.5819693283516046, 0.9515514491928728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.032105813875877395`], {
             RGBColor[
             0.2707327274798912, 0.4018876404006824, 0.9387292003655769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.032105813875877395`], {
             RGBColor[
             0.23336863550083925`, 0.36261561071043924`, 0.9366013706025906]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.032105813875877395`], {
             RGBColor[
             0.20237506472464956`, 0.3300394027187775, 0.9348363325977657]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.032105813875877395`], {
             RGBColor[
             0.20083038530367384`, 0.32841584670900015`, 0.9347483653898895]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.032105813875877395`], {
             RGBColor[
             0.22474171532416531`, 0.3535481706264238, 0.9361100802609137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.032105813875877395`], {
             RGBColor[
             0.8664637178535413, 0.48652475561155717`, 0.21028639171424535`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.032105813875877395`], {
             RGBColor[
             0.20003824461178885`, 0.32758325661720833`, 0.9347032541493537]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.032105813875877395`], {
             RGBColor[
             0.9671895696970209, 0.9750506153189628, 0.9404236795589124]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.032105813875877395`], {
             RGBColor[
             0.18433414396946993`, 0.31107725114464163`, 0.9338089288499086]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.032105813875877395`], {
             RGBColor[
             0.33308943974472227`, 0.4629270639700209, 0.9424451424544752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.032105813875877395`], {
             RGBColor[
             0.1861956076915163, 0.31303376754012907`, 0.9339149364550904]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.032105813875877395`], {
             RGBColor[
             0.2214255710569613, 0.35006269274590207`, 0.9359212307506922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.032105813875877395`], {
             RGBColor[
             0.1814903715451621, 0.30808826602110845`, 0.9336469802173286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.032105813875877395`], {
             RGBColor[
             0.20866772558178895`, 0.33665338825737323`, 0.9351946903244223]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.032105813875877395`], {
             RGBColor[
             0.2275966301752516, 0.35654886714697176`, 0.936272663438215]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.032105813875877395`], {
             RGBColor[
             0.9862571365941499, 0.9885849870532707, 0.8774183422327487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.032105813875877395`], {
             RGBColor[
             0.952704487454567, 0.8501960835922951, 0.28080312431882476`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.032105813875877395`], {
             RGBColor[
             0.426257062503514, 0.5436241760628097, 0.9483817009917713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.032105813875877395`], {
             RGBColor[
             0.2177123475199571, 0.3461598593765405, 0.9357097681634818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.032105813875877395`], {
             RGBColor[
             0.19208551837244375`, 0.31922443710768994`, 0.9342503581550272]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.032105813875877395`], {
             RGBColor[
             0.23118072954041266`, 0.36031598282478083`, 0.9364767725948611]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.032105813875877395`], {
             RGBColor[
             0.18790775611424687`, 0.3148333440888988, 0.9340124407748683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.032105813875877395`], {
             RGBColor[
             0.20539561179114207`, 0.3332141891994065, 0.9350083482847035]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.032105813875877395`], {
             RGBColor[
             0.1941551643020383, 0.3213997662028249, 0.9343682214289508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.032105813875877395`], {
             RGBColor[
             0.40849384697781144`, 0.528238571579618, 0.9472498446058684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.032105813875877395`], {
             RGBColor[
             0.23143093535124384`, 0.3605789649959291, 0.9364910214456416]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.032105813875877395`], {
             RGBColor[
             0.8250746635773962, 0.19374042880931708`, 0.17164483220048377`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.032105813875877395`], {
             RGBColor[
             0.1874435235211163, 0.31434540619947215`, 0.9339860034154601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.032105813875877395`], {
             RGBColor[
             0.23757609093788187`, 0.36703791314285356`, 0.9368409789653577]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.032105813875877395`], {
             RGBColor[
             0.18053047455342514`, 0.3070793534218085, 0.9335923155036896]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.032105813875877395`], {
             RGBColor[
             0.986124206873734, 0.9885300171977407, 0.8796213317111282]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.032105813875877395`], {
             RGBColor[
             0.18088209567567362`, 0.3074489295153584, 0.9336123398064248]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.032105813875877395`], {
             RGBColor[
             0.9874175082770378, 0.9890648305643368, 0.8581879805016432]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.032105813875877395`], {
             RGBColor[
             0.1895037720729246, 0.31651085805472556`, 0.934103331522621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.032105813875877395`], {
             RGBColor[
             0.22524249753236514`, 0.35407452447866766`, 0.9361385990668298]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.032105813875877395`], {
             RGBColor[
             0.1844498116639085, 0.31119882522525194`, 0.9338155159539919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.032105813875877395`], {
             RGBColor[
             0.19775641494300986`, 0.32518490895896446`, 0.9345733073253814]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.032105813875877395`], {
             RGBColor[
             0.22195872707107797`, 0.35062307352078237`, 0.9359515931969625]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.032105813875877395`], {
             RGBColor[
             0.20745669335557887`, 0.3353805166037485, 0.9351257238307011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.032105813875877395`], {
             RGBColor[
             0.18265386603570732`, 0.30931117250048296`, 0.9337132395073293]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.032105813875877395`], {
             RGBColor[
             0.28560729073547014`, 0.4175217494840773, 0.9395762847380378]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.032105813875877395`], {
             RGBColor[
             0.23794228148785246`, 0.3674228026286945, 0.9368618329754481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.032105813875877395`], {
             RGBColor[
             0.19184993915614282`, 0.3189768284147727, 0.9342369422671671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.032105813875877395`], {
             RGBColor[
             0.31878183695974033`, 0.45053453755869494`, 0.9415334746567325]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.032105813875877395`], {
             RGBColor[
             0.3660178719215669, 0.49144801689048034`, 0.9445433130353144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.032105813875877395`], {
             RGBColor[
             0.817928104297447, 0.13880884254138265`, 0.16480127896312016`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.032105813875877395`], {
             RGBColor[
             0.18407578926115742`, 0.31080570396557056`, 0.9337942159314718]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.032105813875877395`], {
             RGBColor[
             0.340161519599846, 0.46905254408746033`, 0.942895769129249]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.032105813875877395`], {
             RGBColor[
             0.18516129488531852`, 0.3119466392015956, 0.9338560338709061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.032105813875877395`], {
             RGBColor[
             0.25816755850577977`, 0.38868085113116446`, 0.938013632581003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.032105813875877395`], {
             RGBColor[
             0.24473644409614725`, 0.3745638983048021, 0.9372487504849276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.032105813875877395`], {
             RGBColor[
             0.3038398335581257, 0.4366853080006712, 0.9406146010791581]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.032105813875877395`], {
             RGBColor[
             0.20988927253459944`, 0.3379373115553272, 0.935264255616268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.032105813875877395`], {
             RGBColor[
             0.2962099519152749, 0.42866581863159803`, 0.9401800906069961]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.032105813875877395`], {
             RGBColor[
             0.22271583997709107`, 0.35141884718873295`, 0.9359947096569118]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.032105813875877395`], {
             RGBColor[
             0.1981497507744529, 0.3255983298567432, 0.9345957072190938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.032105813875877395`], {
             RGBColor[
             0.1962060745132835, 0.32355540287006146`, 0.9344850177314316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.032105813875877395`], {
             RGBColor[
             0.20504953117466115`, 0.3328504365287066, 0.9349886395055752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.032105813875877395`], {
             RGBColor[
             0.9731648978995463, 0.9211410408128702, 0.3502511250338943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.032105813875877395`], {
             RGBColor[
             0.2128391460228046, 0.3410378156242125, 0.9354322465474746]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.032105813875877395`], {
             RGBColor[
             0.2226352176445654, 0.3513341080054973, 0.9359901183343445]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.032105813875877395`], {
             RGBColor[
             0.17908821045117204`, 0.30556344240551475`, 0.9335101806967048]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.032105813875877395`], {
             RGBColor[
             0.2389301514139497, 0.3684611165555936, 0.9369180907063167]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.032105813875877395`], {
             RGBColor[
             0.46304655962256364`, 0.5749610829682137, 0.9508718678503764]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.032105813875877395`], {
             RGBColor[
             0.1801747671672662, 0.30670548240580453`, 0.9335720584942697]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.032105813875877395`], {
             RGBColor[
             0.24137384732010603`, 0.3710295958922332, 0.9370572555730482]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.032105813875877395`], {
             RGBColor[
             0.9930111873350895, 0.9874599613241353, 0.4806890552557963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.032105813875877395`], {
             RGBColor[
             0.2006299825882091, 0.3282052107487807, 0.934736952751713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.032105813875877395`], {
             RGBColor[
             0.23666672657285628`, 0.3660821135381808, 0.9367891920100534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.032105813875877395`], {
             RGBColor[
             0.2620129130085561, 0.39272256252313964`, 0.938232619831244]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.032105813875877395`], {
             RGBColor[
             0.9784615748157791, 0.9834572582803182, 0.9213431151026323]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.032105813875877395`], {
             RGBColor[
             0.4406321468160179, 0.5560751515815551, 0.9492976686527762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.032105813875877395`], {
             RGBColor[
             0.3058207768282486, 0.438767404976628, 0.9407274128678487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.032105813875877395`], {
             RGBColor[
             0.24095771526907575`, 0.3705922147223045, 0.9370335574683543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.032105813875877395`], {
             RGBColor[
             0.1996796674968478, 0.327206369334303, 0.9346828337131252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.032105813875877395`], {
             RGBColor[
             0.22089074136906994`, 0.34950055283376746`, 0.9358907729911765]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.032105813875877395`], {
             RGBColor[
             0.2430009596347453, 0.3727397940997984, 0.9371499172122699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.032105813875877395`], {
             RGBColor[
             0.20886533678518346`, 0.33686109016141486`, 0.9352059439901159]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.032105813875877395`], {
             RGBColor[
             0.2434445902532613, 0.3732060780076645, 0.9371751813197018]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.032105813875877395`], {
             RGBColor[
             0.9464109372448213, 0.8252442542119368, 0.27573918609145315`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.032105813875877395`], {
             RGBColor[
             0.926874823682218, 0.9445288413300859, 0.9928873421853748]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.032105813875877395`], {
             RGBColor[
             0.773715577090376, 0.8231517563699634, 0.978080396007364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.032105813875877395`], {
             RGBColor[
             0.8997587664774066, 0.6377097951563564, 0.23806859642232206`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.032105813875877395`], {
             RGBColor[
             0.5360494193639693, 0.63422809324764, 0.9566189203875064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.032105813875877395`], {
             RGBColor[
             0.19692281060910452`, 0.3243087379504625, 0.9345258347917725]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.032105813875877395`], {
             RGBColor[
             0.18720713771192796`, 0.31409694972628927`, 0.9339725415933283]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.032105813875877395`], {
             RGBColor[
             0.19199315011410678`, 0.319127352211692, 0.9342450979193615]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.032105813875877395`], {
             RGBColor[
             0.2601377913887575, 0.39075169081115385`, 0.9381258344289902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.032105813875877395`], {
             RGBColor[
             0.8186938987840391, 0.1446950745386128, 0.16553460462832187`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.032105813875877395`], {
             RGBColor[
             0.2256459244954445, 0.3544985517956109, 0.9361615736355604]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{{3.8349502435193233`*^9, 3.8349502581408367`*^9}, {
   3.835008837468545*^9, 3.8350088466663265`*^9}, 3.8350238942345033`*^9},
 CellLabel->
  "Out[153]=",ExpressionUUID->"51a65e35-ccc7-4c79-bdae-d42cf30906f9"]
}, Open  ]],

Cell["Estimated with Max-Min Deviation v Calculated: (r = 6)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 3.8349503922098827`*^9}, {3.8349504781120467`*^9, 
  3.834950521977162*^9}},ExpressionUUID->"ea209531-75b8-411f-9341-\
15ca7dc3126a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphin3", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsi3", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}], 
     "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"mMDi6300", ",", "kri3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502554527807`*^9}, {3.8349505249112787`*^9, 3.834950525026289*^9}, {
   3.8350088639795384`*^9, 3.8350088695421896`*^9}},
 CellLabel->
  "In[154]:=",ExpressionUUID->"54d21065-25ad-4d7a-9b35-66be2a97e5ae"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1FO4EAYYBuBzsm2dTrZdW7WsZbtVy3bLtWxr2bat5WVjyzZXrfc8u3i/
//a7+f7gJu2rtAsMCAjIJEJuKEIThrCEIzwRiEgkIhOFqEQjOjGISSxiE4e4
xCM+CUhIIhKThKQkI4jkBJOClKQiNWlISzrSk4GMIX3JTBayko3s5CAnuchN
HvKSj/wUoCCF+IEfKUwRivITxShOCUpSitKUoSzlKE8FfqYilahMFapSjerU
oCa1qE0d6lKP+jSgIY1oTBN+oSnNaM6vtKAlrWhNG9rSjvZ0oCOd6EwXutKN
7vSgJ73ozW/0oS/96M8ABjKIwQzhd4YyjOGMYCSjGM0YxjKO8UxgIpOYzBSm
Mo3pzGAms5jNH8xhLvOYzwIWsojFLGEpy1jOClayitWsYS3rWM8GNrKJzWxh
K9vYzg52sovd7GEv+9jPAQ5yiMMc4U+OcozjnOAkpzjNX5zhLOc4zwUuconL
XOEq17jODW5yi9v8zT/c4S73uM8DHvKIxzzhKc94zgte8orXvOEt73jPBz7y
ic/8yxe+8o3/CBl/IKEITRjCEo7wRCAikYhMFKISjejEICaxiE0c4hKP+CQg
IYlITBKSkowgkhNMClKSitSkIS3pSE8GMgb+/6++Az6VhWw=
          "], {Null, CompressedData["
1:eJxN2guYllWBB/D3qyhJJoMEhjQEkUhkrd1Es1FL08DywkWybEVNDSyNClNB
EwWFrQAlLl4YuUwas+aqQJgbq4DKUtKWYgKWGnghRCZKVGBhab//nt887vP4
f34PMN+5n/Oe9xt7f23MsG+9q6qqsw6oqnhCPfPr+UQ9V9czqZ5p9dxezxv1
nFHP8/UMqKdTrfx9fIPj6m6r58B6ZtdzaD1n1zOsnmXKPqj+c8P9+xX1zGXK
Ham+Zj/b7OfTjjX19FdWf+U9rr58Zru8p/7zY+tOruc0bY7j+Di36e8oZY6S
1Pvhejbp/6OS+j/u7z7u7w5Q1gHKP+D/lbtZeZuVuVm7+9ZKfXEkRzHj0qdW
xiSmvCnKnuLzLcasRZaZr8+rt1V/WtXfahxbtaNVNjP1Hl53l2S876/7ej1d
67lWuWfKMI7ifLZyM1Nuxn6l+V0pz5v7OZKfy5+rWvlzTPL3HY11R3Pc0Ryn
PRPUM0FbJkgz57OVaVf61b9W+tbf+H5OHuc249CtVsYiZj0fUivrPqa8Fepa
oa4Vspn57ArlvEvdmadL5GrrZYQ1FM/gCHM+wryP0K7Uv0+y3/Zpz3FV2YPH
+bfj/Ptx/v1k6yOO5VxmnWW9PyCbtKtnrdTb076OUzi4Kmt1sLkdrLzByst4
jZbUf4v+x9eZ8c94X6X/V8njbD9HrlTOldI+DyfKPqa/2R8NtbIuGuyrBvPV
YH3FZrYy661B+mr/fvXuV+9+Sf3vrdu5Vtq9w7ztME87tH+HOdyhL/Eyfb/M
eFxmPC4zHjkve9XKmRknM2fOobVy5sQ1PNU8nGoeTlX+qcrNOA2y7gYZp0Gy
j53Uu6Uq9W2RXvbvHbKSzzP9yXqYJ5vN16XadKmM5pWczf08xLwNkdmcw2Zm
joaYr5h5Sr9Ol0uYfZX9dmxV1vWxcgvv5+vsr/6jnLuxhcv4aWMTN3ALe9lf
z1Rlj8WxzHh8UobzUo7mlZzN/TzEvCxQTzybk7lAOxZoR+a7sVbmOQ7iPmau
Y8qfrk3TZTbnMOOd8RlTlfUUr+AY4zmmemeddVdvd/V2V2939XaXRufi29LN
en66KvM53jiON5/jze14cxvzvDpedrGb82l9Vdbjeulpv870uZmyi53N/9qq
nBtxGEexlcuYZB3GvjzK+C+uyjjEQUz2MWOx2LgsNi+pf6p6p0oLl3EtU+9U
9U6t3lmfd0vWQ8prq8o+iSM5lXO4lm3mu035bcrvrKzOyuisjM7al3W/rirn
fhzLuUyeYR/n/U+rcm7Gq5g8zm3M+XJ0VZ71R5vTo81pzHmT8+m2qqzL22QZ
V/J5przsx9VVWf9xOC/ldM5msp/Zj4363KjPjepu1OdG49Koz4363Wiecn+5
uSp3mphzv4vnUhf3kpg1GftWZU3F43giB/F2LuY+dvL57mz0XNup/zv1f6f+
x9GcztlczZ3GY6f1stO4dDIXnYx1J/PQyTx0Mg+dzEMHc9FBWzpoSwdt6aAN
HbShgzZ0UHcH9WfdL6/KeRjvZrKBW9jLOCysyjmz0FguNJbxdF7CqzmeC43z
QuO60LjmXDmnKufQObKCb3MXcy+M3XyuX618rp+/7+d8jG9zF/PZ2I3vtsbi
yRzMsZzLFq5j1mXNWNbMQxzC4ZzO2ZzD1WzjTlbuDburck/YbQ3stgZ2WwO7
1d1dGjmAgzmcc7ma69jHPeiIWtmLcQwz309VZe88ZZ7j7Uze4D5m3zxlftOf
Hu4bcSRncw7bmA/Er1Zlb3/V+MVbOIevs7Of78L295Jnq3JextM4guM4hck2
9nTO3CQ3czvzfpz3un/KmlJ2PIMjeBXv4E/5OLdxB3dbO0v1a6m+xmYmeb4s
1d+vVGVM4yRO43a+x8/18Bw/pir75hg5nudwJncxe+YY4xz7Kec65Vzn566T
mdzFzu6Zn5FBPJ23cyGzdnJvO9L5FM/mZC7g3VzOLcxZdaT9/VhV1nls5ACe
yJM5mMM5l4uZrGsvq1bsYzwGGo+BxmOgXMeZ3MWM60Dj87W6H6qVfr9QlX7H
szmZC3g3ky1Mn1/Q/7Osh/go1/BpHmpe3jTub5qbN81NvIRX83Yu5FNMst/f
NC659/6kKudK/Cov4xhO5y1MXmfWdzyC2de5tzxRlTtNnMdkPXOvyXz0tl57
G+d4HWdyKXcxc9Lb/aG3O0R8T1XOlDiC4ziF8/gs17OncX5/rdzL4yW8muP5
DLNuX6nKM+gV8x9buJwPV+X7hribH3I+/bYqZ1QczSuZ7Gf7/ePcquyP2J+D
eQaTKziVt3EuW7iMa5n7W+69Q5U/VEZyKlu4jGvZxpx/sS9Tbs7YF/U/ruTz
fNH4pN5FVXlPiUM4lMM4ilOZtHIt25j2LNKelD+jKutzhnpmqGeG8mcoP05g
0sz5XMRWrmUbU++M6p33jIn6N1F/JhrbiTKVLVzEtWxjyo092JcZ59y7763K
+REn8WYmj3IND9W+U6SFy7mBWc95Dl5flWdqPIPJHVzJ5/kidzDznPo+Jv15
CodyJCdyKlu04zztOE87zpOreD3v4E/5OF/kNu5g2pfvVb5YlXMynspkDG/h
T/g6j7Bf76zK+orDOILnchTH8TYmy5j5z9Wrq3tanM4ZnM05bOYiLmUbU2Bs
YFf3utj+vfQ/yFc4kpN4E6dxO3OfiT2U8+2qrMtvyyTexJt5Lx81/jfKA3yY
m+r5VFXuRfEcruDb3MU8M2I39uOsqpwDcQKTZs5nK1dwM1PuLOXOUm7uB3+t
yr0g5n5+eVXuM/E4nshBTBbzKe7jfubeHruzkYfYv0uqsj/iWZzEabyXS4xz
XMNDtf/BqtxvHtSPOJkLeDeT5XyBW5j7Tsx9J+N8QVX2wwUyihM4g7PYzPls
5Qpu5kHeY26oyvtWHMJkOmdzDlezjTuZwmIDuzLrOeW/VJX7amzkAH6Sgzmc
l3IuF/MxruY6vqQ9sY/3ph9V5X72I7mFP+HrzN0odmF/981XzfOr5iyu4QYm
h7pPnVSV+9xJMoXz+ATXczNznzqiKms93s6n+AaznrPP+8iNfICbqtLui2UN
n+YGvsr2dr+vVu6CsR8/x9M4gldxHKfwWW7jDibpX+p7zTi+pm2vadNr2hR7
VuVuF6/ldra/pw6olT/H0byW+ZkB5q9DreznOI33cgkf5RomhzqHf1yVczl+
nN/mJN7EmzmNyb1M+/Me9aeqnKPxeJ7D5G3uYvZp7MZ+7v17lRMv4ATOYjPn
cylXcBf3qmevemJvtn+fdECtvE/GsZzMZ/gKk5xj+X3LPVVZr/dYn/FYfpE3
MnmAm6qyLg+ulf10sPMwnsQzeQFHcQKncB5b+QTXczPfX3mnqcq7YxzE03kJ
r+Z4LuSbfL/1c6H1c6H1c6F8mzfxZv6Y25m1nPe+86vy3hcH8qtMLuOPOJM5
12IX9jafL1flHI6DeS6v4FjOZQuXcR2TnLfxKPvzC1XZn1+Qa5n+xAHOnYPk
aJ7Ak3gmh3EUJ3AK57GVT3A9NzPzHHt6/l9Tlef/NeYpfoUjmUziNN7LJXyU
OTti+/vBRcqPp3AoR/Iin40TuYQp7yLl5Tn6m6p8Rx4H8JO8lKN5Oa/kaiYv
cSf3s/33i7dW5R4TJzNZwAf5Arfwr8wZEHvxSOVuVe5WP7dVmVuVtVX+ynx+
q89n/FZVZV2u0q5VPr9Km+JyJhv4Crcw7Vul/Ky931VlzcV5fILJemYdZV4f
Mq/xLF7Ei3kNJ3Ea7+USJo9yDV9l5v8h839wVe4AsS8H8DieyEG8nLdzMZ/i
PnZSfnc22sePVGUfxy/wWibZzzH7OWfnD6vynIif53gm6/gM3+/e89/6EN9g
nh/3VeV5cZ/c7+9/UZXnSuzDG3kPH2Cyyc+/t1Z+Pn6RY3gPV/J5bmJyhHOr
o3Oko/XT0fOpo+dTR8+njp5LHT2POnoedfQc6ug51NFzKCYHM+dUF23voq9d
9LWLvnbR1y76Gh/mJr7XefTrqqzb2J9DOJTDOJITOZUzuIjLmKxlG/M+ELuy
L4/yvO0mn+Bn+Hmezkt4NcdzId9k1lP6tVF/NupPPJcTOZUzeCdbuIjL+Guu
5Ub93KifG/Vvo/7V/6v+syrndjyQ3flJDuelvIHTOZurmfyGL3En9zOVx0M8
77+h3tjIkzmYyVjOZQsf4zo+w5eZ8zT2cc6/VZX34Xg2x3Iyb+UCPsjlXMUX
uIVb+ZZ6Yy+2/36kybg36XeTfscBbNL3JnPQpC9N+t+k303GvsnYNhmHJuPf
ZBya9P+oqjyr4lm8iBdzCR/iGm7gq3yNHZR7qHO55h4Vr+UjTD7IAfb9R2vl
fhO/wpG8hhM5jduZMz72YNb196tybnxfbuBETudszuEitnEnU2hsYFf2YF/n
7e+rct7GE3gSz+QFHMUJnMf5bOUT/B2T9dzMnMUx53K+p/yg9OMZPI/X8zbe
wZV8ni9yB/M9au7336zK/T6ez+RHnMk5bOZS7mXu/7ELuzLvAdkPf6jK97Rx
MK/gGM7lSv5B+2OeKzHPxY9UZY3Gs3gxJ/FeLuFDfJRr+DRfZQflZ/1nPx8m
fTmATTyRJ3MQF/MxruNLzP0nNjL7Ob/HvMuc3mUu75KH+SJ3M7+vajCXDeaw
wZw0mL8G89Zg3hrMWzzI5zuzC7sy85fz9edVOU/jAt7NB5ks5ypu4Avcwtf4
FnOuxiPdc75Xlf32PZnHJ/g7/p7ruZnZR/Fg50gv/e0lQ/hNfp83cDpncDbn
sJmLuJRtTKX/Vye7sq9x/UCtfE8Tj+FAforncBabOZ8r+Ce+zV3cy+QgdmNv
tn/v8reqrPfYyMPYxJM5mMP5Dc7lY1zHl/gyk/bf+3+0KuPwUTmGA3k8r+NM
7mL6kfOsd1Xun73la7yed/AuPswXuZsfMv7fkllcwT/xbWY8Y/s4Hl4r94HD
nR+HO/8Ot89jEwdzOL/BKziXj3Ed/8CX+DL/xqSP5/GTVbmHx/4cynM5khdx
IqeyhYu4jL9mspYb2cas/9iXua/m+9/PVuX5FvsxOY1ncATP41Ucx2e5jTuY
74JjT/vtw/ZfPIFncggv4ChO4AzOYjPncxFbuZQruJcZi9iVScYl75l/qcr7
Z7yP9zPj9C79iafxDA7jCJ7LcbyNd3IZdzB5H3tax7+qyn6P3+BYTuYqJuv4
DF/mK3yLuUd/R1nfUVa8lQv4IJdzFX/FV/gW28vtxSOtsw/I55j1kv+v449V
+R4g/pZJvg/IufTlqpwv8RgOZHI+v8nrOJN5nsYubP//YH5ZlXb9UnviQTyJ
UziPyRNczzzfYuYr36P8S1XOm3gY+3IAm3giB/FSXs5kMR/jav6G6/gS97W3
oVZs/17nsFr5Xid+gaN5Ja/lI8x7wGGS94oeVXnXi5/m2fwOJ/NWLuCD/Dlf
4BZu5Vvspb6sn7xHf7cq/fiu9RJHM7mSv+FvuZ95L06bP1YrbYp380H+nMu5
gS9wC9O2j8mRzo2vV+U7m9iHxzK5h/fxAf6COV+yLv+tKusyfoCf5ed4Gkdw
HKcw+SWf5TbmfIlZr2nfv1flfSB+kWN4C3/C5A98nXkfiHkfyPvmf1TlfTOO
5DWcxGlMtjNrLXZgD37UvjqyKt8bxr480lqIl/N2PsU/8g3+N/exk/Ngj3Hf
Y9z3GPc9xnuP8d5jvPcY7z3GdY8x32PM9xjzPZIzfY/x32P831eVu0A8gWdy
CIdyGEdxAidyKmfwTi5iK5fx13ySa7mRbWzQzg+zL48ybn/3c/EgnslhHMFR
HMcpvJNr+Xfj9XfjlP31P1W5V8YPsw+/zht5Dx/gL7iJuY99qSr3sXgKhzIZ
yYt4DSdyKlu4hA/xSWY9x7zH5v5wSFXuoYdIfw7mubyCU3kb7+RctnAZn+Ra
buTLPMo97AdVeZ7Ggfwyz+c3mcxkM5dyBXdxL/NOEw9iZ3Zjb+a+3rvuz6ry
rhDvYvIwP2Qd/KMcy6/zFt7H+/kX5v/vyPvJR9QX+/E0nsev8Spezzt4F3/K
n/FF7uBu5nuMd9fKdyXxYq7h09zAV/ka6/9V/1yV95nYi0OYfJ83cDpncw6X
so07mUpiA7uyh3vDge4N8UJey5v4CLcz30ce6B5xoHyQhzH3irx3Pmc9Pmc9
xk/xeJ7DH3AWVzD5E9/mLu5l1uVz1uVz1uNz1Tvvjf9alfMhfoyn8Ev8Dsdy
MluYrOKv+CRf5ivMfTke5Vz9L/MbT+CZHMILOIoTOIOz2Mz5bOVSrmCymXuZ
dRBz7p9c989V+R3Nn/X/z/off8hb+Ss+w2Qr32L6HfP7m/8FjHdEAw==
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[72, 227] -> 
             RGBColor[
              0.8789789545454545, 0.7565088181818183, 0.6107753181818183], 
             UndirectedEdge[132, 236] -> 
             RGBColor[
              0.6959147272727273, 0.7606839999999999, 0.9717653636363637], 
             UndirectedEdge[187, 193] -> 
             RGBColor[
              0.8421578636363636, 0.8734568181818181, 0.7525919999999997], 
             UndirectedEdge[196, 225] -> 
             RGBColor[
              0.9499209545454546, 0.8419288181818183, 0.5637961818181818], 
             UndirectedEdge[39, 166] -> 
             RGBColor[
              0.862316409090909, 0.6808480909090907, 0.5968716818181818], 
             UndirectedEdge[7, 216] -> 
             RGBColor[
              0.8410230909090908, 0.8760729999999999, 0.9846987272727272], 
             UndirectedEdge[92, 281] -> 
             RGBColor[
              0.546662409090909, 0.6319629545454544, 0.9607848636363636], 
             UndirectedEdge[99, 229] -> 
             RGBColor[
              0.9596615909090909, 0.9482023636363637, 0.6800120454545453], 
             UndirectedEdge[187, 296] -> 
             RGBColor[
              0.7406013181818183, 0.7917507272727273, 0.744089727272727], 
             UndirectedEdge[100, 244] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[232, 245] -> 
             RGBColor[
              0.6445471818181818, 0.7185722727272726, 0.9675682727272727], 
             UndirectedEdge[6, 52] -> 
             RGBColor[
              0.6923867272727273, 0.7561498181818181, 0.9524241363636363], 
             UndirectedEdge[113, 160] -> 
             RGBColor[
              0.9047646363636365, 0.6577307272727275, 0.2421054545454546], 
             UndirectedEdge[176, 288] -> 
             RGBColor[0.5831206818181818, 0.6549321363636362, 0.961228], 
             UndirectedEdge[187, 228] -> 
             RGBColor[
              0.9277878636363637, 0.9406917272727272, 0.7610365454545452], 
             UndirectedEdge[61, 268] -> 
             RGBColor[0.8385052727272726, 0.873472, 0.9240215], 
             UndirectedEdge[51, 101] -> 
             RGBColor[
              0.9844443181818182, 0.984844909090909, 0.7309676818181816], 
             UndirectedEdge[207, 214] -> 
             RGBColor[
              0.6531326818181818, 0.5444017272727274, 0.5846863181818183], 
             UndirectedEdge[17, 162] -> 
             RGBColor[
              0.9282931363636363, 0.9417724545454544, 0.8160323636363638], 
             UndirectedEdge[20, 279] -> 
             RGBColor[
              0.8477502727272728, 0.8818454545454546, 0.9812604090909091], 
             UndirectedEdge[51, 197] -> 
             RGBColor[
              0.8330886363636363, 0.8697672727272727, 0.9481920454545454], 
             UndirectedEdge[86, 94] -> 
             RGBColor[0.7102728636363637, 0.766415, 0.7418993636363634], 
             UndirectedEdge[55, 114] -> 
             RGBColor[
              0.9187186363636364, 0.9370021818181817, 0.9566365909090909], 
             UndirectedEdge[13, 270] -> 
             RGBColor[
              0.8976795454545454, 0.9202261818181818, 0.9546298636363637], 
             UndirectedEdge[151, 220] -> 
             RGBColor[
              0.9922574545454546, 0.9910662727272728, 0.7779775454545457], 
             UndirectedEdge[117, 225] -> 
             RGBColor[
              0.8708007272727272, 0.8987014545454546, 0.9272404090909091], 
             UndirectedEdge[13, 277] -> 
             RGBColor[
              0.8976795454545454, 0.9202261818181818, 0.9546298636363637], 
             UndirectedEdge[81, 237] -> 
             RGBColor[
              0.9761326818181818, 0.9793499999999999, 0.8008882272727275], 
             UndirectedEdge[172, 174] -> 
             RGBColor[
              0.8800457272727272, 0.907074909090909, 0.9844793181818181], 
             UndirectedEdge[128, 197] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[44, 71] -> 
             RGBColor[
              0.8653840909090909, 0.8949967272727273, 0.9514109545454545], 
             UndirectedEdge[70, 122] -> 
             RGBColor[
              0.9010848181818181, 0.9238509090909091, 0.9864860454545454], 
             UndirectedEdge[42, 293] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999998, 0.9867054545454546], 
             UndirectedEdge[154, 181] -> 
             RGBColor[
              0.9801011363636363, 0.9443154545454545, 0.5333500454545455], 
             UndirectedEdge[42, 216] -> 
             RGBColor[
              0.8831012727272726, 0.9096249999999999, 0.9887121818181819], 
             UndirectedEdge[125, 130] -> 
             RGBColor[
              0.9706517727272728, 0.9389430909090909, 0.6243533181818182], 
             UndirectedEdge[173, 263] -> 
             RGBColor[
              0.8283653181818181, 0.8275549999999999, 0.6459776363636363], 
             UndirectedEdge[112, 132] -> 
             RGBColor[0.5415336818181817, 0.6158975, 0.9621099545454546], 
             UndirectedEdge[208, 279] -> 
             RGBColor[
              0.6902832727272727, 0.7577105454545454, 0.9699446363636364], 
             UndirectedEdge[271, 295] -> 
             RGBColor[
              0.6655862727272726, 0.7353482727272727, 0.9695750000000001], 
             UndirectedEdge[193, 264] -> 
             RGBColor[
              0.8330886363636363, 0.8697672727272727, 0.9481920454545454], 
             UndirectedEdge[16, 39] -> 
             RGBColor[
              0.8789789545454545, 0.7565088181818183, 0.6107753181818183], 
             UndirectedEdge[168, 282] -> 
             RGBColor[
              0.7974712727272726, 0.8423900909090908, 0.9802676363636363], 
             UndirectedEdge[92, 243] -> 
             RGBColor[
              0.907128909090909, 0.9255985454545455, 0.863626590909091], 
             UndirectedEdge[71, 280] -> 
             RGBColor[
              0.9753750909090909, 0.9811553636363637, 0.9265677272727273], 
             UndirectedEdge[69, 118] -> 
             RGBColor[
              0.7092467272727272, 0.7718119999999999, 0.9724644545454546], 
             UndirectedEdge[175, 253] -> 
             RGBColor[
              0.7400960454545455, 0.7906700000000001, 0.6890939090909092], 
             UndirectedEdge[137, 179] -> 
             RGBColor[
              0.6571959545454547, 0.7197993636363638, 0.6835537272727275], 
             UndirectedEdge[134, 221] -> 
             RGBColor[
              0.9092338636363637, 0.6187650000000003, 0.5283757727272728], 
             UndirectedEdge[91, 163] -> 
             RGBColor[
              0.7754776818181817, 0.8207354545454545, 0.8017913636363638], 
             UndirectedEdge[160, 232] -> 
             RGBColor[
              0.6614639545454546, 0.582232090909091, 0.5916381363636365], 
             UndirectedEdge[135, 263] -> 
             RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             UndirectedEdge[160, 297] -> 
             RGBColor[
              0.8789789545454545, 0.7565088181818183, 0.6107753181818183], 
             UndirectedEdge[179, 274] -> 
             RGBColor[
              0.29761486363636364`, 0.4289273181818182, 0.940304590909091], 
             UndirectedEdge[209, 259] -> 
             RGBColor[
              0.9309408181818181, 0.9472025454545454, 0.9735680454545454], 
             UndirectedEdge[14, 173] -> 
             RGBColor[
              0.8283653181818181, 0.8275549999999999, 0.6459776363636363], 
             UndirectedEdge[260, 267] -> 
             RGBColor[
              0.8002742727272727, 0.8438691818181818, 0.9451014090909091], 
             UndirectedEdge[203, 216] -> 
             RGBColor[
              0.8972544090909091, 0.8313647272727276, 0.6256043181818183], 
             UndirectedEdge[37, 279] -> 
             RGBColor[
              0.8439198636363637, 0.789359272727273, 0.6203786818181818], 
             UndirectedEdge[192, 220] -> 
             RGBColor[
              0.7409814545454546, 0.7934335454545456, 0.8486865000000001], 
             UndirectedEdge[60, 225] -> 
             RGBColor[
              0.7369487272727273, 0.7917659090909092, 0.9155192272727273], 
             UndirectedEdge[177, 226] -> 
             RGBColor[
              0.9673157727272728, 0.9727743636363637, 0.8158129545454547], 
             UndirectedEdge[91, 273] -> 
             RGBColor[
              0.9673157727272728, 0.9727743636363637, 0.8158129545454547], 
             UndirectedEdge[52, 273] -> 
             RGBColor[
              0.9489243636363636, 0.9614284545454546, 0.971341909090909], 
             UndirectedEdge[21, 114] -> 
             RGBColor[0.9272825909090909, 0.939611, 0.7060407272727274], 
             UndirectedEdge[7, 202] -> 
             RGBColor[
              0.7876885454545455, 0.8340675454545454, 0.979473090909091], 
             UndirectedEdge[94, 293] -> 
             RGBColor[
              0.9067487727272727, 0.9239157272727272, 0.759029818181818], 
             UndirectedEdge[132, 133] -> 
             RGBColor[
              0.6130146363636363, 0.6898133636363636, 0.9662251818181818], 
             UndirectedEdge[13, 93] -> 
             RGBColor[
              0.9051125454545454, 0.9247647272727273, 0.8970429545454546], 
             UndirectedEdge[141, 178] -> 
             RGBColor[
              0.7678234999999999, 0.7961634545454545, 0.6659904545454545], 
             UndirectedEdge[245, 264] -> 
             RGBColor[
              0.9187186363636364, 0.9370021818181817, 0.9566365909090909], 
             UndirectedEdge[5, 83] -> 
             RGBColor[
              0.9489243636363636, 0.9614284545454546, 0.971341909090909], 
             UndirectedEdge[210, 226] -> 
             RGBColor[
              0.9401074545454545, 0.9548528181818182, 0.9862666363636363], 
             UndirectedEdge[91, 298] -> 
             RGBColor[
              0.8098487727272727, 0.8486394545454545, 0.804497181818182], 
             UndirectedEdge[126, 192] -> 
             RGBColor[
              0.6959147272727273, 0.7606839999999999, 0.9717653636363637], 
             UndirectedEdge[127, 156] -> 
             RGBColor[
              0.6182613636363635, 0.695804818181818, 0.9658933636363636], 
             UndirectedEdge[36, 268] -> 
             RGBColor[
              0.43486459090909085`, 0.5318865909090909, 0.9516586818181818], 
             UndirectedEdge[25, 221] -> 
             RGBColor[0.7287164090909092, 0.4777740909090913, 0.57108], 
             UndirectedEdge[69, 249] -> 
             RGBColor[
              0.6882076363636362, 0.7550359999999998, 0.9704577272727273], 
             UndirectedEdge[22, 161] -> 
             RGBColor[
              0.6882076363636362, 0.7550359999999998, 0.9704577272727273], 
             UndirectedEdge[96, 112] -> 
             RGBColor[
              0.5771510454545454, 0.6432746818181818, 0.9300343636363637], 
             UndirectedEdge[219, 250] -> 
             RGBColor[0.621541090909091, 0.7019025454545456, 0.964533], 
             UndirectedEdge[41, 219] -> 
             RGBColor[
              0.8653840909090909, 0.8949967272727273, 0.9514109545454545], 
             UndirectedEdge[202, 237] -> 
             RGBColor[
              0.8565671818181818, 0.8884210909090908, 0.9663356818181819], 
             UndirectedEdge[91, 235] -> 
             RGBColor[
              0.9935135454545454, 0.9885344545454546, 0.5353676363636367], 
             UndirectedEdge[69, 263] -> 
             RGBColor[
              0.6236167272727271, 0.7045770909090908, 0.9640199090909091], 
             UndirectedEdge[12, 239] -> 
             RGBColor[
              0.922123909090909, 0.940626909090909, 0.9884927727272728], 
             UndirectedEdge[122, 266] -> 
             RGBColor[
              0.8477502727272728, 0.8818454545454546, 0.9812604090909091], 
             UndirectedEdge[206, 254] -> 
             RGBColor[
              0.9577412727272727, 0.968004090909091, 0.9564171818181818], 
             UndirectedEdge[137, 270] -> 
             RGBColor[
              0.9839390454545455, 0.9837641818181819, 0.6759718636363639], 
             UndirectedEdge[25, 58] -> 
             RGBColor[
              0.8021945909090908, 0.8240674545454545, 0.6686962727272726], 
             UndirectedEdge[107, 156] -> 
             RGBColor[
              0.6844923181818181, 0.7447282727272726, 0.7952202727272729], 
             UndirectedEdge[136, 194] -> 
             RGBColor[
              0.9577412727272727, 0.968004090909091, 0.9564171818181818], 
             UndirectedEdge[45, 281] -> 
             RGBColor[
              0.5143669545454546, 0.6067334999999999, 0.9575659545454546], 
             UndirectedEdge[137, 147] -> 
             RGBColor[
              0.8088382272727273, 0.8464780000000001, 0.6945055454545457], 
             UndirectedEdge[164, 187] -> 
             RGBColor[
              0.8744533181818182, 0.8986862727272726, 0.7558109090909089], 
             UndirectedEdge[199, 229] -> 
             RGBColor[0.9668105, 0.9716936363636364, 0.7608171363636361], 
             UndirectedEdge[191, 271] -> 
             RGBColor[
              0.9492070909090908, 0.9591505454545454, 0.8676400454545455], 
             UndirectedEdge[153, 222] -> 
             RGBColor[
              0.8748334545454546, 0.9003690909090909, 0.8604076818181818], 
             UndirectedEdge[158, 186] -> 
             RGBColor[
              0.8963470454545455, 0.5576411818181819, 0.5453928636363636], 
             UndirectedEdge[16, 192] -> 
             RGBColor[
              0.6917924090909092, 0.6075678181818184, 0.5938285000000001], 
             UndirectedEdge[75, 143] -> 
             RGBColor[
              0.7974712727272726, 0.8423900909090908, 0.9802676363636363], 
             UndirectedEdge[204, 226] -> 
             RGBColor[
              0.9401074545454545, 0.9548528181818182, 0.9862666363636363], 
             UndirectedEdge[137, 191] -> 
             RGBColor[
              0.9933884090909091, 0.9891365454545455, 0.5849685909090911], 
             UndirectedEdge[197, 198] -> 
             RGBColor[
              0.8405216363636363, 0.8743058181818182, 0.8906051363636365], 
             UndirectedEdge[80, 156] -> 
             RGBColor[
              0.666100909090909, 0.7333823636363636, 0.9507492272727273], 
             UndirectedEdge[103, 159] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[28, 288] -> 
             RGBColor[
              0.6093184545454544, 0.6706922272727271, 0.6807826818181819], 
             UndirectedEdge[118, 263] -> 
             RGBColor[
              0.7764321818181817, 0.8256140909090908, 0.9782609090909091], 
             UndirectedEdge[68, 83] -> 
             RGBColor[
              0.5683341363636363, 0.6366990454545454, 0.9449590909090909], 
             UndirectedEdge[64, 90] -> 
             RGBColor[
              0.6823508181818181, 0.7444965454545454, 0.8782375909090909], 
             UndirectedEdge[213, 263] -> 
             RGBColor[
              0.7764321818181817, 0.8256140909090908, 0.9782609090909091], 
             UndirectedEdge[52, 53] -> 
             RGBColor[
              0.8888626363636363, 0.9136505454545454, 0.9695545909090909], 
             UndirectedEdge[245, 297] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             UndirectedEdge[189, 267] -> 
             RGBColor[
              0.9848244545454545, 0.9865277272727273, 0.8355644545454546], 
             UndirectedEdge[145, 203] -> 
             RGBColor[
              0.9633602272727273, 0.880890272727273, 0.5045321818181819], 
             UndirectedEdge[136, 279] -> 
             RGBColor[
              0.8477502727272728, 0.8818454545454546, 0.9812604090909091], 
             UndirectedEdge[80, 256] -> 
             RGBColor[
              0.5683341363636364, 0.6366990454545455, 0.9449590909090909], 
             UndirectedEdge[40, 130] -> 
             RGBColor[
              0.9753750909090909, 0.9811553636363637, 0.9265677272727273], 
             UndirectedEdge[83, 101] -> 
             RGBColor[
              0.9756274090909092, 0.9782692727272727, 0.7458924090909089], 
             UndirectedEdge[83, 194] -> 
             RGBColor[
              0.9665581818181819, 0.9745797272727272, 0.9414924545454546], 
             UndirectedEdge[149, 197] -> 
             RGBColor[
              0.8421578636363636, 0.8734568181818181, 0.7525919999999997], 
             UndirectedEdge[23, 44] -> 
             RGBColor[
              0.4671600454545454, 0.5571160454545454, 0.954877590909091], 
             UndirectedEdge[97, 284] -> 
             RGBColor[
              0.9483216818181817, 0.9563869999999999, 0.7080474545454547], 
             UndirectedEdge[135, 276] -> 
             RGBColor[
              0.6579878181818182, 0.7324810909090909, 0.9667257272727272], 
             UndirectedEdge[142, 150] -> 
             RGBColor[
              0.9010848181818181, 0.9238509090909091, 0.9864860454545454], 
             UndirectedEdge[46, 214] -> 
             RGBColor[
              0.9273041363636364, 0.7628316363636365, 0.5737546363636363], 
             UndirectedEdge[5, 243] -> 
             RGBColor[
              0.9671906363636363, 0.9733764545454546, 0.8654139090909092], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.9802262727272727, 0.9437133636363636, 0.4837490909090911], 
             UndirectedEdge[198, 243] -> 
             RGBColor[
              0.9922574545454546, 0.9910662727272728, 0.7779775454545457], 
             UndirectedEdge[13, 32] -> 
             RGBColor[
              0.8929562272727272, 0.8780139090909089, 0.6524154545454546], 
             UndirectedEdge[86, 140] -> 
             RGBColor[
              0.4917317272727272, 0.5975352727272727, 0.9533272727272728], 
             UndirectedEdge[171, 275] -> 
             RGBColor[
              0.9940188181818181, 0.9896151818181818, 0.5903634545454546], 
             UndirectedEdge[36, 250] -> 
             RGBColor[
              0.3333080454545455, 0.4501805000000001, 0.943156409090909], 
             UndirectedEdge[168, 203] -> 
             RGBColor[0.9182935, 0.8481407272727275, 0.6276110454545455], 
             UndirectedEdge[17, 169] -> 
             RGBColor[
              0.9285473636363636, 0.7297715454545453, 0.42619859090909107`], 
             UndirectedEdge[191, 246] -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909092], 
             UndirectedEdge[17, 178] -> 
             RGBColor[
              0.7754776818181817, 0.8207354545454545, 0.8017913636363638], 
             UndirectedEdge[9, 132] -> 
             RGBColor[
              0.6130146363636363, 0.6898133636363636, 0.9662251818181818], 
             UndirectedEdge[11, 283] -> 
             RGBColor[
              0.8421578636363636, 0.8734568181818181, 0.7525919999999997], 
             UndirectedEdge[64, 69] -> 
             RGBColor[
              0.4654459090909089, 0.5747678181818181, 0.9516523636363636], 
             UndirectedEdge[193, 288] -> 
             RGBColor[
              0.45846804545454534`, 0.556695318181818, 0.9530028636363637], 
             UndirectedEdge[221, 288] -> 
             RGBColor[
              0.5291966363636363, 0.3019883181818184, 0.5573571363636365], 
             UndirectedEdge[65, 264] -> 
             RGBColor[
              0.9849495909090908, 0.9859256363636364, 0.7859635000000003], 
             UndirectedEdge[27, 151] -> 
             RGBColor[
              0.9051125454545454, 0.9247647272727273, 0.8970429545454546], 
             UndirectedEdge[201, 293] -> 
             RGBColor[
              0.6882076363636362, 0.7550359999999998, 0.9704577272727273], 
             UndirectedEdge[43, 99] -> 
             RGBColor[0.9867447727272727, 0.966726, 0.5591593181818182], 
             UndirectedEdge[77, 293] -> 
             RGBColor[
              0.8412773181818181, 0.6640720909090907, 0.5948649545454545], 
             UndirectedEdge[61, 280] -> 
             RGBColor[
              0.9807917272727272, 0.984860090909091, 0.9023971818181818], 
             UndirectedEdge[20, 55] -> 
             RGBColor[
              0.9577412727272727, 0.968004090909091, 0.9564171818181818], 
             UndirectedEdge[208, 242] -> 
             RGBColor[
              0.7522033181818182, 0.6255454545454547, 0.5922883181818182], 
             UndirectedEdge[29, 261] -> 
             RGBColor[
              0.6486320000000001, 0.7171905454545455, 0.9341495909090909], 
             UndirectedEdge[12, 76] -> 
             RGBColor[
              0.9041403636363634, 0.9264009999999998, 0.9907189090909091], 
             UndirectedEdge[168, 276] -> 
             RGBColor[0.764656909090909, 0.816492, 0.977177], 
             UndirectedEdge[148, 271] -> 
             RGBColor[
              0.6655862727272726, 0.7353482727272727, 0.9695750000000001], 
             UndirectedEdge[131, 170] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[141, 261] -> 
             RGBColor[
              0.9772954090909091, 0.9613536363636364, 0.6501625909090909], 
             UndirectedEdge[129, 184] -> 
             RGBColor[
              0.731532090909091, 0.788061181818182, 0.9396897727272727], 
             UndirectedEdge[111, 185] -> 
             RGBColor[
              0.8888626363636363, 0.9136505454545454, 0.9695545909090909], 
             UndirectedEdge[234, 239] -> 
             RGBColor[0.5831206818181817, 0.6549321363636362, 0.961228], 
             UndirectedEdge[103, 203] -> 
             RGBColor[
              0.9450939545454546, 0.8689422727272731, 0.6104601818181818], 
             UndirectedEdge[28, 160] -> 
             RGBColor[
              0.9441993636363637, 0.8032708181818183, 0.3301105909090911], 
             UndirectedEdge[133, 170] -> 
             RGBColor[
              0.6398150909090909, 0.7106149090909091, 0.9490743181818182], 
             UndirectedEdge[87, 299] -> 
             RGBColor[
              0.45736063636363644`, 0.5696312727272728, 0.9506214545454545], 
             UndirectedEdge[5, 290] -> 
             RGBColor[
              0.6572839999999999, 0.7268067272727272, 0.9656739545454545], 
             UndirectedEdge[183, 253] -> 
             RGBColor[0.6748756363636363, 0.743908, 0.9697586363636364], 
             UndirectedEdge[176, 245] -> 
             RGBColor[
              0.9010848181818181, 0.9238509090909091, 0.9864860454545454], 
             UndirectedEdge[29, 190] -> 
             RGBColor[
              0.5063455454545455, 0.6058024545454546, 0.9557739090909091], 
             UndirectedEdge[159, 168] -> 
             RGBColor[
              0.8831012727272726, 0.9096249999999999, 0.9887121818181819], 
             UndirectedEdge[202, 299] -> 
             RGBColor[0.621541090909091, 0.7019025454545456, 0.964533], 
             UndirectedEdge[65, 115] -> 
             RGBColor[0.9943989545454546, 0.991298, 0.6949602272727275], 
             UndirectedEdge[51, 142] -> 
             RGBColor[
              0.9187186363636364, 0.9370021818181817, 0.9566365909090909], 
             UndirectedEdge[134, 187] -> 
             RGBColor[
              0.9898609545454545, 0.9885496363636364, 0.7067971363636362], 
             UndirectedEdge[85, 239] -> 
             RGBColor[
              0.8800457272727272, 0.907074909090909, 0.9844793181818181], 
             UndirectedEdge[120, 284] -> 
             RGBColor[
              0.8739480454545454, 0.8976055454545455, 0.7008150909090911], 
             UndirectedEdge[31, 61] -> 
             RGBColor[
              0.9903662272727272, 0.9896303636363637, 0.7617929545454547], 
             UndirectedEdge[217, 247] -> 
             RGBColor[
              0.9772954090909091, 0.9613536363636364, 0.6501625909090909], 
             UndirectedEdge[66, 169] -> 
             RGBColor[0.6448014090909091, 0.5065713636363635, 0.5777345], 
             UndirectedEdge[168, 293] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999998, 0.9867054545454546], 
             UndirectedEdge[93, 105] -> 
             RGBColor[0.7086366363636363, 0.767264, 0.8799125000000001], 
             UndirectedEdge[169, 193] -> 
             RGBColor[
              0.776686409090909, 0.6136131818181816, 0.5884271363636363], 
             UndirectedEdge[87, 216] -> 
             RGBColor[
              0.6445471818181818, 0.7185722727272726, 0.9675682727272727], 
             UndirectedEdge[81, 201] -> 
             RGBColor[
              0.7754776818181817, 0.8207354545454545, 0.8017913636363638], 
             UndirectedEdge[63, 244] -> 
             RGBColor[
              0.8888626363636363, 0.9136505454545454, 0.9695545909090909], 
             UndirectedEdge[32, 150] -> 
             RGBColor[
              0.9530179545454545, 0.9257918181818181, 0.6542027727272727], 
             UndirectedEdge[95, 282] -> 
             RGBColor[0.8385052727272726, 0.873472, 0.9240215], 
             UndirectedEdge[126, 239] -> 
             RGBColor[
              0.922123909090909, 0.940626909090909, 0.9884927727272728], 
             UndirectedEdge[149, 150] -> 
             RGBColor[0.9668105, 0.9716936363636364, 0.7608171363636361], 
             UndirectedEdge[16, 222] -> 
             RGBColor[
              0.9450847727272728, 0.8060343636363638, 0.4897031818181819], 
             UndirectedEdge[192, 262] -> 
             RGBColor[
              0.5892456363636365, 0.676673090909091, 0.9613140909090909], 
             UndirectedEdge[214, 276] -> 
             RGBColor[
              0.7522033181818182, 0.6255454545454547, 0.5922883181818182], 
             UndirectedEdge[48, 100] -> 
             RGBColor[
              0.7230976363636363, 0.7836086363636363, 0.9730352727272726], 
             UndirectedEdge[105, 143] -> 
             RGBColor[
              0.5589171818181817, 0.6513373636363635, 0.9591237272727273], 
             UndirectedEdge[268, 279] -> 
             RGBColor[
              0.7230976363636363, 0.7836086363636363, 0.9730352727272726], 
             UndirectedEdge[24, 106] -> 
             RGBColor[
              0.9450939545454546, 0.8689422727272731, 0.6104601818181818], 
             UndirectedEdge[33, 222] -> 
             RGBColor[0.9867447727272727, 0.966726, 0.5591593181818182], 
             UndirectedEdge[155, 291] -> 
             RGBColor[
              0.9187204090909091, 0.6770179090909094, 0.5021128636363638], 
             UndirectedEdge[99, 233] -> 
             RGBColor[
              0.7031239545454545, 0.7429237272727272, 0.6610942727272726], 
             UndirectedEdge[237, 269] -> 
             RGBColor[
              0.9489243636363636, 0.9614284545454546, 0.971341909090909], 
             UndirectedEdge[85, 135] -> 
             RGBColor[
              0.7553930909090909, 0.8088380909090909, 0.9762541818181818], 
             UndirectedEdge[126, 248] -> 
             RGBColor[
              0.9488269545454544, 0.9574677272727272, 0.7630432727272725], 
             UndirectedEdge[188, 261] -> 
             RGBColor[
              0.7012036363636364, 0.7627254545454545, 0.9374994090909091], 
             UndirectedEdge[37, 177] -> 
             RGBColor[
              0.9634853636363637, 0.8802881818181821, 0.4549312272727275], 
             UndirectedEdge[160, 180] -> 
             RGBColor[
              0.6088923181818182, 0.536697181818182, 0.5882883181818181], 
             UndirectedEdge[23, 194] -> 
             RGBColor[
              0.5771510454545454, 0.6432746818181818, 0.9300343636363637], 
             UndirectedEdge[51, 243] -> 
             RGBColor[
              0.9848244545454545, 0.9865277272727273, 0.8355644545454546], 
             UndirectedEdge[108, 208] -> 
             RGBColor[0.7436178181818182, 0.799716, 0.9751702727272726], 
             UndirectedEdge[179, 251] -> 
             RGBColor[
              0.6486320000000001, 0.7171905454545455, 0.9341495909090909], 
             UndirectedEdge[26, 224] -> 
             RGBColor[0.49945549999999994`, 0.5823455, 0.9580965], 
             UndirectedEdge[106, 291] -> 
             RGBColor[
              0.9613438636363637, 0.8800564545454549, 0.5379485454545456], 
             UndirectedEdge[48, 161] -> 
             RGBColor[
              0.7876885454545455, 0.8340675454545454, 0.979473090909091], 
             UndirectedEdge[227, 299] -> 
             RGBColor[0.6748756363636363, 0.743908, 0.9697586363636364], 
             UndirectedEdge[162, 299] -> 
             RGBColor[0.6748756363636363, 0.743908, 0.9697586363636364], 
             UndirectedEdge[200, 227] -> 
             RGBColor[
              0.9206389545454545, 0.9172004545454544, 0.6802314545454544], 
             UndirectedEdge[202, 293] -> 
             RGBColor[
              0.7876885454545455, 0.8340675454545454, 0.979473090909091], 
             UndirectedEdge[3, 155] -> 
             RGBColor[
              0.9203566363636364, 0.6761689090909093, 0.3640997272727271], 
             UndirectedEdge[39, 234] -> 
             RGBColor[
              0.5440980454545453, 0.6239302272727272, 0.9614474090909091], 
             UndirectedEdge[144, 176] -> 
             RGBColor[
              0.8800457272727272, 0.907074909090909, 0.9844793181818181], 
             UndirectedEdge[140, 162] -> 
             RGBColor[
              0.7092467272727272, 0.7718119999999999, 0.9724644545454546], 
             UndirectedEdge[123, 257] -> 
             RGBColor[
              0.8283653181818181, 0.8275549999999999, 0.6459776363636363], 
             UndirectedEdge[121, 286] -> 
             RGBColor[
              0.8681998636363636, 0.5876830909090911, 0.5846219090909092], 
             UndirectedEdge[176, 230] -> 
             RGBColor[
              0.9489243636363636, 0.9614284545454546, 0.971341909090909], 
             UndirectedEdge[39, 64] -> 
             RGBColor[
              0.6182613636363635, 0.695804818181818, 0.9658933636363636], 
             UndirectedEdge[269, 277] -> 
             RGBColor[
              0.9577412727272727, 0.968004090909091, 0.9564171818181818], 
             UndirectedEdge[154, 203] -> 
             RGBColor[
              0.9633602272727273, 0.880890272727273, 0.5045321818181819], 
             UndirectedEdge[107, 137] -> 
             RGBColor[
              0.9935135454545454, 0.9885344545454546, 0.5353676363636367], 
             UndirectedEdge[192, 218] -> 
             RGBColor[0.5220601818181818, 0.622871, 0.9555176363636364], 
             UndirectedEdge[247, 270] -> 
             RGBColor[
              0.9772954090909091, 0.9613536363636364, 0.6501625909090909], 
             UndirectedEdge[28, 240] -> 
             RGBColor[0.9272825909090909, 0.939611, 0.7060407272727274], 
             UndirectedEdge[31, 194] -> 
             RGBColor[
              0.9849495909090908, 0.9859256363636364, 0.7859635000000003], 
             UndirectedEdge[58, 187] -> 
             RGBColor[
              0.9863646363636364, 0.9650431818181817, 0.45456254545454516`], 
             UndirectedEdge[8, 121] -> 
             RGBColor[
              0.922123909090909, 0.940626909090909, 0.9884927727272728], 
             UndirectedEdge[62, 186] -> 
             RGBColor[
              0.9577412727272727, 0.968004090909091, 0.9564171818181818], 
             UndirectedEdge[271, 289] -> 
             RGBColor[
              0.9483216818181817, 0.9563869999999999, 0.7080474545454547], 
             UndirectedEdge[236, 294] -> 
             RGBColor[
              0.7334524090909091, 0.7682594545454546, 0.6632846363636362], 
             UndirectedEdge[115, 211] -> 
             RGBColor[
              0.9281679999999999, 0.9423745454545454, 0.8656333181818183], 
             UndirectedEdge[43, 284] -> 
             RGBColor[
              0.9933884090909091, 0.9891365454545455, 0.5849685909090911], 
             UndirectedEdge[87, 181] -> 
             RGBColor[0.6964803181818182, 0.7205131818181818, 0.635285], 
             UndirectedEdge[77, 205] -> 
             RGBColor[
              0.8709019090909091, 0.5066775454545455, 0.21398972727272725`], 
             UndirectedEdge[132, 267] -> 
             RGBColor[
              0.9397577272727271, 0.9537781818181817, 0.9586433181818181], 
             UndirectedEdge[108, 280] -> 
             RGBColor[
              0.9187186363636364, 0.9370021818181817, 0.9566365909090909], 
             UndirectedEdge[40, 97] -> 
             RGBColor[
              0.9397577272727271, 0.9537781818181817, 0.9586433181818181], 
             UndirectedEdge[35, 262] -> 
             RGBColor[
              0.8416525909090908, 0.872376090909091, 0.697596181818182], 
             UndirectedEdge[201, 216] -> 
             RGBColor[
              0.7092467272727272, 0.7718119999999999, 0.9724644545454546], 
             UndirectedEdge[244, 279] -> 
             RGBColor[
              0.8565671818181818, 0.8884210909090908, 0.9663356818181819], 
             UndirectedEdge[143, 163] -> 
             RGBColor[
              0.6236167272727271, 0.7045770909090908, 0.9640199090909091], 
             UndirectedEdge[102, 165] -> 
             RGBColor[
              0.8297667272727272, 0.8676195454545453, 0.9834865454545454], 
             UndirectedEdge[7, 282] -> 
             RGBColor[
              0.7553930909090909, 0.8088380909090909, 0.9762541818181818], 
             UndirectedEdge[10, 122] -> 
             RGBColor[
              0.9489243636363636, 0.9614284545454546, 0.971341909090909], 
             UndirectedEdge[113, 193] -> 
             RGBColor[0.8022178636363637, 0.726836, 0.6095910454545455], 
             UndirectedEdge[22, 100] -> 
             RGBColor[
              0.6236167272727271, 0.7045770909090908, 0.9640199090909091], 
             UndirectedEdge[116, 254] -> 
             RGBColor[
              0.9596615909090909, 0.9482023636363637, 0.6800120454545453], 
             UndirectedEdge[174, 298] -> 
             RGBColor[0.7225787272727273, 0.78294, 0.9731635454545454], 
             UndirectedEdge[159, 271] -> 
             RGBColor[
              0.8831012727272726, 0.9096249999999999, 0.9887121818181819], 
             UndirectedEdge[11, 101] -> 
             RGBColor[
              0.8421578636363636, 0.8734568181818181, 0.7525919999999997], 
             UndirectedEdge[148, 225] -> 
             RGBColor[
              0.7066202727272727, 0.7664301818181818, 0.9133288636363637], 
             UndirectedEdge[239, 248] -> 
             RGBColor[0.9668105, 0.9716936363636364, 0.7608171363636361], 
             UndirectedEdge[22, 119] -> 
             RGBColor[
              0.7678234999999999, 0.7961634545454545, 0.6659904545454545], 
             UndirectedEdge[38, 247] -> 
             RGBColor[0.9684785, 0.9547779999999999, 0.6650873181818181], 
             UndirectedEdge[157, 222] -> 
             RGBColor[
              0.9760075454545454, 0.9799520909090909, 0.8504891818181819], 
             UndirectedEdge[42, 203] -> 
             RGBColor[0.9182935, 0.8481407272727275, 0.6276110454545455], 
             UndirectedEdge[155, 241] -> 
             RGBColor[
              0.5602702727272727, 0.3842161363636366, 0.5658547727272728], 
             UndirectedEdge[103, 154] -> 
             RGBColor[
              0.9760075454545454, 0.9799520909090909, 0.8504891818181819], 
             UndirectedEdge[88, 107] -> 
             RGBColor[
              0.9493322272727271, 0.9585484545454545, 0.8180390909090911], 
             UndirectedEdge[58, 176] -> 
             RGBColor[
              0.9596615909090909, 0.9482023636363637, 0.6800120454545453], 
             UndirectedEdge[48, 119] -> 
             RGBColor[0.867304409090909, 0.875195, 0.6750058181818182], 
             UndirectedEdge[206, 219] -> 
             RGBColor[
              0.8653840909090909, 0.8949967272727273, 0.9514109545454545], 
             UndirectedEdge[1, 125] -> 
             RGBColor[
              0.9797210000000001, 0.9426326363636364, 0.4287532727272725], 
             UndirectedEdge[191, 278] -> 
             RGBColor[0.9943989545454546, 0.991298, 0.6949602272727275], 
             UndirectedEdge[90, 118] -> 
             RGBColor[
              0.9261516363636363, 0.9415407272727272, 0.8990496818181819], 
             UndirectedEdge[101, 283] -> 
             RGBColor[
              0.9935135454545455, 0.9885344545454545, 0.5353676363636359], 
             UndirectedEdge[5, 226] -> 
             RGBColor[
              0.9401074545454545, 0.9548528181818182, 0.9862666363636363], 
             UndirectedEdge[3, 241] -> 
             RGBColor[
              0.6334271818181818, 0.6965816818181818, 0.7371226818181816], 
             UndirectedEdge[194, 241] -> 
             RGBColor[
              0.6243579545454545, 0.6928921363636363, 0.9327227272727273], 
             UndirectedEdge[139, 235] -> 
             RGBColor[
              0.9663052272727273, 0.9706129090909091, 0.7058213181818184], 
             UndirectedEdge[40, 94] -> 
             RGBColor[
              0.9844443181818182, 0.984844909090909, 0.7309676818181816], 
             UndirectedEdge[161, 177] -> 
             RGBColor[
              0.9072540454545455, 0.9249964545454545, 0.8140256363636366], 
             UndirectedEdge[34, 295] -> 
             RGBColor[
              0.6923867272727273, 0.7561498181818181, 0.9524241363636363], 
             UndirectedEdge[1, 281] -> 
             RGBColor[
              0.6334271818181818, 0.6965816818181818, 0.7371226818181816], 
             UndirectedEdge[191, 295] -> 
             RGBColor[0.710653, 0.7680978181818181, 0.8464961363636365], 
             UndirectedEdge[144, 297] -> 
             RGBColor[
              0.8410230909090908, 0.8760729999999999, 0.9846987272727272], 
             UndirectedEdge[141, 294] -> 
             RGBColor[
              0.9792157272727272, 0.941551909090909, 0.3737574545454544], 
             UndirectedEdge[80, 201] -> 
             RGBColor[
              0.7570862727272727, 0.8093895454545454, 0.9573203181818182], 
             UndirectedEdge[113, 115] -> 
             RGBColor[
              0.9539536818181819, 0.8435964545454546, 0.49696345454545465`], 
             UndirectedEdge[129, 253] -> 
             RGBColor[
              0.731532090909091, 0.788061181818182, 0.9396897727272727], 
             UndirectedEdge[37, 108] -> 
             RGBColor[
              0.8972544090909091, 0.8313647272727276, 0.6256043181818183], 
             UndirectedEdge[265, 276] -> 
             RGBColor[
              0.6902832727272727, 0.7577105454545454, 0.9699446363636364], 
             UndirectedEdge[59, 194] -> 
             RGBColor[
              0.731532090909091, 0.788061181818182, 0.9396897727272727], 
             UndirectedEdge[103, 225] -> 
             RGBColor[
              0.9719748181818182, 0.9782844545454545, 0.917321909090909], 
             UndirectedEdge[46, 265] -> 
             RGBColor[
              0.8653840909090909, 0.8949967272727273, 0.9514109545454545], 
             UndirectedEdge[51, 149] -> 
             RGBColor[
              0.9844443181818182, 0.984844909090909, 0.7309676818181816], 
             UndirectedEdge[52, 124] -> 
             RGBColor[
              0.8950003181818182, 0.6084846363636367, 0.5674710454545455], 
             UndirectedEdge[82, 258] -> 
             RGBColor[
              0.6923867272727273, 0.7561498181818181, 0.9524241363636363], 
             UndirectedEdge[45, 132] -> 
             RGBColor[
              0.8297667272727272, 0.8676195454545453, 0.9834865454545454], 
             UndirectedEdge[74, 287] -> 
             RGBColor[0.9668105, 0.9716936363636364, 0.7608171363636361], 
             UndirectedEdge[128, 269] -> 
             RGBColor[
              0.9489243636363636, 0.9614284545454546, 0.971341909090909], 
             UndirectedEdge[14, 249] -> 
             RGBColor[
              0.7553930909090909, 0.8088380909090909, 0.9762541818181818], 
             UndirectedEdge[101, 198] -> 
             RGBColor[
              0.9918773181818181, 0.9893834545454545, 0.6733807727272726], 
             UndirectedEdge[164, 297] -> 
             RGBColor[
              0.8087276363636363, 0.8508435454545453, 0.9814798181818182], 
             UndirectedEdge[68, 235] -> 
             RGBColor[0.585715, 0.6458835, 0.6794385000000002], 
             UndirectedEdge[108, 177] -> 
             RGBColor[
              0.9282931363636363, 0.9417724545454544, 0.8160323636363638], 
             UndirectedEdge[62, 276] -> 
             RGBColor[
              0.7826404545454546, 0.8307179090909091, 0.9749508636363635], 
             UndirectedEdge[13, 107] -> 
             RGBColor[
              0.9072540454545455, 0.9249964545454545, 0.8140256363636366], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.8831012727272726, 0.9096249999999999, 0.9887121818181819], 
             UndirectedEdge[62, 135] -> 
             RGBColor[0.8154548181818182, 0.856616, 0.9780415], 
             UndirectedEdge[18, 35] -> 
             RGBColor[
              0.7097675909090909, 0.7653342727272727, 0.6869035454545457], 
             UndirectedEdge[42, 202] -> 
             RGBColor[
              0.8297667272727272, 0.8676195454545453, 0.9834865454545454], 
             UndirectedEdge[121, 255] -> 
             RGBColor[
              0.8681998636363636, 0.5876830909090911, 0.5846219090909092], 
             UndirectedEdge[128, 281] -> 
             RGBColor[0.6155410454545454, 0.6863165, 0.9476474545454545], 
             UndirectedEdge[82, 181] -> 
             RGBColor[0.6964803181818182, 0.7205131818181818, 0.635285], 
             UndirectedEdge[136, 204] -> 
             RGBColor[
              0.9401074545454545, 0.9548528181818182, 0.9862666363636363], 
             UndirectedEdge[118, 166] -> 
             RGBColor[
              0.862316409090909, 0.6808480909090907, 0.5968716818181818], 
             UndirectedEdge[39, 263] -> 
             RGBColor[
              0.7764321818181817, 0.8256140909090908, 0.9782609090909091], 
             UndirectedEdge[52, 84] -> 
             RGBColor[
              0.9665581818181819, 0.9745797272727272, 0.9414924545454546], 
             UndirectedEdge[129, 165] -> 
             RGBColor[
              0.9397577272727271, 0.9537781818181817, 0.9586433181818181], 
             UndirectedEdge[141, 236] -> 
             RGBColor[
              0.7334524090909091, 0.7682594545454546, 0.6632846363636362], 
             UndirectedEdge[97, 178] -> 
             RGBColor[
              0.7302858181818179, 0.7885879999999998, 0.9744711818181818], 
             UndirectedEdge[115, 227] -> 
             RGBColor[
              0.9281679999999999, 0.9423745454545454, 0.8656333181818183], 
             UndirectedEdge[256, 281] -> 
             RGBColor[
              0.22613390909090905`, 0.35501145454545446`, 0.9361893636363636],
              UndirectedEdge[221, 297] -> 
             RGBColor[
              0.8471607727272727, 0.5709070909090912, 0.582615181818182], 
             UndirectedEdge[224, 262] -> 
             RGBColor[
              0.43486459090909085`, 0.5318865909090909, 0.9516586818181818], 
             UndirectedEdge[73, 119] -> 
             RGBColor[
              0.8995998636363636, 0.9004244545454545, 0.6782247272727272], 
             UndirectedEdge[3, 227] -> 
             RGBColor[
              0.9277878636363637, 0.9406917272727272, 0.7610365454545452], 
             UndirectedEdge[45, 188] -> 
             RGBColor[
              0.5912126363636363, 0.6765668181818181, 0.9623426363636364], 
             UndirectedEdge[260, 300] -> 
             RGBColor[0.764656909090909, 0.816492, 0.977177], 
             UndirectedEdge[23, 291] -> 
             RGBColor[
              0.5845840454545455, 0.6478132272727273, 0.8724474545454546], 
             UndirectedEdge[142, 149] -> 
             RGBColor[
              0.9277878636363637, 0.9406917272727272, 0.7610365454545452], 
             UndirectedEdge[81, 97] -> 
             RGBColor[
              0.9493322272727271, 0.9585484545454545, 0.8180390909090911], 
             UndirectedEdge[181, 201] -> 
             RGBColor[
              0.7611798636363636, 0.773752909090909, 0.6401811818181817], 
             UndirectedEdge[56, 57] -> 
             RGBColor[
              0.9593275000000001, 0.8792226363636366, 0.5713649090909092], 
             UndirectedEdge[197, 243] -> 
             RGBColor[0.842538, 0.8751396363636363, 0.8571887727272728], 
             UndirectedEdge[65, 200] -> 
             RGBColor[
              0.986869909090909, 0.9661239090909091, 0.5095583636363638], 
             UndirectedEdge[8, 173] -> 
             RGBColor[
              0.9530179545454545, 0.9257918181818181, 0.6542027727272727], 
             UndirectedEdge[53, 273] -> 
             RGBColor[
              0.8800457272727272, 0.907074909090909, 0.9844793181818181], 
             UndirectedEdge[26, 253] -> 
             RGBColor[0.6538365454545455, 0.727132, 0.967751909090909], 
             UndirectedEdge[114, 206] -> 
             RGBColor[
              0.9187186363636364, 0.9370021818181817, 0.9566365909090909], 
             UndirectedEdge[9, 45] -> 
             RGBColor[0.538641, 0.6310319090909091, 0.9589928181818181], 
             UndirectedEdge[47, 190] -> 
             RGBColor[
              0.7933489545454546, 0.6892739090909092, 0.6023307727272726], 
             UndirectedEdge[191, 282] -> 
             RGBColor[0.842538, 0.8751396363636363, 0.8571887727272728], 
             UndirectedEdge[59, 155] -> 
             RGBColor[
              0.6674444090909092, 0.4793851818181821, 0.5728218181818182], 
             UndirectedEdge[214, 265] -> 
             RGBColor[
              0.8173131363636363, 0.6766730000000001, 0.5985978636363637], 
             UndirectedEdge[167, 282] -> 
             RGBColor[
              0.6579878181818182, 0.7324810909090909, 0.9667257272727272], 
             UndirectedEdge[28, 221] -> 
             RGBColor[
              0.912381181818182, 0.6176690909090913, 0.30195045454545477`], 
             UndirectedEdge[136, 197] -> 
             RGBColor[0.8154548181818182, 0.856616, 0.9780415], 
             UndirectedEdge[121, 234] -> 
             RGBColor[
              0.5651371363636362, 0.6407062272727271, 0.9634541363636364], 
             UndirectedEdge[141, 146] -> 
             RGBColor[
              0.9206389545454545, 0.9172004545454544, 0.6802314545454544], 
             UndirectedEdge[32, 167] -> 
             RGBColor[0.7955509545454545, 0.8016569090909091, 0.642887], 
             UndirectedEdge[101, 136] -> 
             RGBColor[0.9668105, 0.9716936363636364, 0.7608171363636361], 
             UndirectedEdge[91, 274] -> 
             RGBColor[
              0.6339324545454545, 0.697662409090909, 0.7921185000000002], 
             UndirectedEdge[84, 295] -> 
             RGBColor[
              0.7012036363636364, 0.7627254545454545, 0.9374994090909091], 
             UndirectedEdge[73, 122] -> 
             RGBColor[
              0.8800457272727272, 0.907074909090909, 0.9844793181818181], 
             UndirectedEdge[157, 248] -> 
             RGBColor[
              0.9756274090909092, 0.9782692727272727, 0.7458924090909089], 
             UndirectedEdge[125, 167] -> 
             RGBColor[0.7955509545454545, 0.8016569090909091, 0.642887], 
             UndirectedEdge[20, 208] -> 
             RGBColor[
              0.7826404545454546, 0.8307179090909091, 0.9749508636363635], 
             UndirectedEdge[77, 103] -> 
             RGBColor[
              0.9101559545454545, 0.7184256363636362, 0.5817275454545454], 
             UndirectedEdge[46, 276] -> 
             RGBColor[
              0.8002742727272727, 0.8438691818181818, 0.9451014090909091], 
             UndirectedEdge[3, 291] -> 
             RGBColor[
              0.9918773181818181, 0.9893834545454545, 0.6733807727272726], 
             UndirectedEdge[79, 297] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[18, 262] -> 
             RGBColor[
              0.5589171818181817, 0.6513373636363635, 0.9591237272727273], 
             UndirectedEdge[127, 225] -> 
             RGBColor[
              0.9241352727272727, 0.940706909090909, 0.9324660454545455], 
             UndirectedEdge[109, 292] -> 
             RGBColor[
              0.6835698181818182, 0.7495741818181818, 0.9673488636363636], 
             UndirectedEdge[267, 287] -> 
             RGBColor[
              0.9844443181818182, 0.984844909090909, 0.7309676818181816], 
             UndirectedEdge[218, 262] -> 
             RGBColor[
              0.6236167272727271, 0.7045770909090908, 0.9640199090909091], 
             UndirectedEdge[207, 225] -> 
             RGBColor[
              0.7066202727272727, 0.7664301818181818, 0.9133288636363637], 
             UndirectedEdge[203, 299] -> 
             RGBColor[
              0.7100678636363638, 0.6824237272727276, 0.6086575000000001], 
             UndirectedEdge[142, 163] -> 
             RGBColor[
              0.7092467272727272, 0.7718119999999999, 0.9724644545454546], 
             UndirectedEdge[2, 54] -> 
             RGBColor[
              0.935868090909091, 0.7654404545454547, 0.32315877272727295`], 
             UndirectedEdge[90, 195] -> 
             RGBColor[
              0.9882247272727271, 0.9893986363636365, 0.8448102727272728], 
             UndirectedEdge[88, 93] -> 
             RGBColor[
              0.9471907272727271, 0.9583167272727272, 0.9010564090909092], 
             UndirectedEdge[77, 82] -> 
             RGBColor[0.6448014090909091, 0.5065713636363635, 0.5777345], 
             UndirectedEdge[167, 168] -> 
             RGBColor[0.764656909090909, 0.816492, 0.977177], 
             UndirectedEdge[18, 26] -> 
             RGBColor[
              0.6235080909090909, 0.7017962727272726, 0.9655615454545454], 
             UndirectedEdge[129, 224] -> 
             RGBColor[
              0.5771510454545454, 0.6432746818181818, 0.9300343636363637], 
             UndirectedEdge[38, 289] -> 
             RGBColor[
              0.9751221363636364, 0.9771885454545455, 0.6908965909090911], 
             UndirectedEdge[31, 241] -> 
             RGBColor[
              0.6339324545454545, 0.697662409090909, 0.7921185000000002], 
             UndirectedEdge[5, 197] -> 
             RGBColor[0.8154548181818182, 0.856616, 0.9780415], 
             UndirectedEdge[59, 241] -> 
             RGBColor[
              0.3805149545454546, 0.49979795454545456`, 0.9458447727272727], 
             UndirectedEdge[155, 226] -> 
             RGBColor[
              0.8936535909090909, 0.6593280909090913, 0.5895492272727273], 
             UndirectedEdge[15, 186] -> 
             RGBColor[
              0.9189728636363637, 0.7250012727272725, 0.5668028181818181], 
             UndirectedEdge[198, 256] -> 
             RGBColor[
              0.5845840454545455, 0.6478132272727273, 0.8724474545454546], 
             UndirectedEdge[72, 291] -> 
             RGBColor[
              0.9430684090909092, 0.8052005454545457, 0.5231195454545456], 
             UndirectedEdge[230, 297] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[138, 231] -> 
             RGBColor[
              0.8976795454545454, 0.9202261818181818, 0.9546298636363637], 
             UndirectedEdge[54, 165] -> 
             RGBColor[
              0.8916867727272726, 0.7354544545454547, 0.6058302272727273], 
             UndirectedEdge[103, 167] -> 
             RGBColor[
              0.7914573636363637, 0.8372935454545455, 0.9600261363636363], 
             UndirectedEdge[78, 131] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[16, 239] -> 
             RGBColor[
              0.918001590909091, 0.7875107272727274, 0.6105559090909092], 
             UndirectedEdge[12, 87] -> 
             RGBColor[
              0.6655862727272726, 0.7353482727272727, 0.9695750000000001], 
             UndirectedEdge[125, 281] -> 
             RGBColor[
              0.6196346363636362, 0.6506798636363635, 0.6305083181818182], 
             UndirectedEdge[148, 205] -> 
             RGBColor[
              0.6531326818181818, 0.5444017272727274, 0.5846863181818183], 
             UndirectedEdge[103, 269] -> 
             RGBColor[
              0.9489243636363636, 0.9614284545454546, 0.971341909090909], 
             UndirectedEdge[40, 169] -> 
             RGBColor[
              0.9189728636363637, 0.7250012727272725, 0.5668028181818181], 
             UndirectedEdge[38, 53] -> 
             RGBColor[
              0.8888626363636363, 0.9136505454545454, 0.9695545909090909], 
             UndirectedEdge[118, 285] -> 
             RGBColor[
              0.8087276363636363, 0.8508435454545453, 0.9814798181818182], 
             UndirectedEdge[74, 267] -> 
             RGBColor[
              0.9577412727272727, 0.968004090909091, 0.9564171818181818], 
             UndirectedEdge[3, 200] -> 
             RGBColor[
              0.9863646363636364, 0.9650431818181817, 0.45456254545454516`], 
             UndirectedEdge[124, 273] -> 
             RGBColor[
              0.8861834090909091, 0.6019090000000004, 0.5823957727272728], 
             UndirectedEdge[131, 182] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             UndirectedEdge[62, 207] -> 
             RGBColor[
              0.6835698181818182, 0.7495741818181818, 0.9673488636363636], 
             UndirectedEdge[75, 262] -> 
             RGBColor[
              0.7974712727272726, 0.8423900909090908, 0.9802676363636363], 
             UndirectedEdge[197, 283] -> 
             RGBColor[
              0.8421578636363636, 0.8734568181818181, 0.7525919999999997], 
             UndirectedEdge[246, 278] -> 
             RGBColor[
              0.9903662272727272, 0.9896303636363637, 0.7617929545454547], 
             UndirectedEdge[225, 265] -> 
             RGBColor[
              0.8708007272727272, 0.8987014545454546, 0.9272404090909091], 
             UndirectedEdge[101, 204] -> 
             RGBColor[0.9668105, 0.9716936363636364, 0.7608171363636361], 
             UndirectedEdge[87, 140] -> 
             RGBColor[
              0.4917317272727272, 0.5975352727272727, 0.9533272727272728], 
             UndirectedEdge[57, 247] -> 
             RGBColor[
              0.9558311818181819, 0.8557161818181821, 0.31913031818181814`], 
             UndirectedEdge[40, 66] -> 
             RGBColor[
              0.7012036363636364, 0.7627254545454545, 0.9374994090909091], 
             UndirectedEdge[167, 293] -> 
             RGBColor[0.7225787272727273, 0.78294, 0.9731635454545454], 
             UndirectedEdge[42, 140] -> 
             RGBColor[
              0.7302858181818179, 0.7885879999999998, 0.9744711818181818], 
             UndirectedEdge[107, 150] -> 
             RGBColor[
              0.9673157727272728, 0.9727743636363637, 0.8158129545454547], 
             UndirectedEdge[91, 143] -> 
             RGBColor[
              0.8426631363636363, 0.8745375454545454, 0.8075878181818184], 
             UndirectedEdge[91, 142] -> 
             RGBColor[
              0.9282931363636363, 0.9417724545454544, 0.8160323636363638], 
             UndirectedEdge[44, 283] -> 
             RGBColor[
              0.8744533181818182, 0.8986862727272726, 0.7558109090909089], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.9756274090909092, 0.9782692727272727, 0.7458924090909089], 
             UndirectedEdge[199, 233] -> 
             RGBColor[0.7102728636363637, 0.766415, 0.7418993636363634], 
             UndirectedEdge[249, 286] -> 
             RGBColor[
              0.8261216818181818, 0.5541310909090912, 0.5806084545454546], 
             UndirectedEdge[48, 266] -> 
             RGBColor[
              0.7553930909090909, 0.8088380909090909, 0.9762541818181818], 
             UndirectedEdge[113, 169] -> 
             RGBColor[
              0.8881020909090909, 0.5820699999999999, 0.22820181818181817`], 
             UndirectedEdge[18, 33] -> 
             RGBColor[
              0.7031239545454545, 0.7429237272727272, 0.6610942727272726], 
             UndirectedEdge[269, 293] -> 
             RGBColor[
              0.8800457272727272, 0.907074909090909, 0.9844793181818181], 
             UndirectedEdge[189, 257] -> 
             RGBColor[
              0.9801011363636363, 0.9443154545454545, 0.5333500454545455], 
             UndirectedEdge[11, 197] -> 
             RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             UndirectedEdge[221, 296] -> 
             RGBColor[
              0.6599742272727274, 0.4219660909090913, 0.5656683636363637], 
             UndirectedEdge[126, 157] -> 
             RGBColor[
              0.9309408181818181, 0.9472025454545454, 0.9735680454545454], 
             UndirectedEdge[24, 87] -> 
             RGBColor[
              0.6923867272727273, 0.7561498181818181, 0.9524241363636363], 
             UndirectedEdge[53, 137] -> 
             RGBColor[0.9062435, 0.922835, 0.7040340000000002], 
             UndirectedEdge[27, 140] -> 
             RGBColor[
              0.6882076363636362, 0.7550359999999998, 0.9704577272727273], 
             UndirectedEdge[115, 200] -> 
             RGBColor[0.9867447727272727, 0.966726, 0.5591593181818182], 
             UndirectedEdge[1, 5] -> 
             RGBColor[0.9668105, 0.9716936363636364, 0.7608171363636361], 
             UndirectedEdge[40, 42] -> 
             RGBColor[
              0.9397577272727271, 0.9537781818181817, 0.9586433181818181], 
             UndirectedEdge[82, 167] -> 
             RGBColor[
              0.5261028181818181, 0.6254392727272727, 0.9560330909090908], 
             UndirectedEdge[52, 57] -> 
             RGBColor[
              0.9450939545454546, 0.8689422727272731, 0.6104601818181818], 
             UndirectedEdge[27, 203] -> 
             RGBColor[
              0.8762153181818182, 0.8145887272727275, 0.623597590909091], 
             UndirectedEdge[251, 270] -> 
             RGBColor[
              0.9753750909090909, 0.9811553636363637, 0.9265677272727273], 
             UndirectedEdge[200, 264] -> 
             RGBColor[
              0.9772954090909091, 0.9613536363636364, 0.6501625909090909], 
             UndirectedEdge[84, 271] -> 
             RGBColor[
              0.9397577272727271, 0.9537781818181817, 0.9586433181818181], 
             UndirectedEdge[80, 145] -> 
             RGBColor[
              0.9760075454545454, 0.9799520909090909, 0.8504891818181819], 
             UndirectedEdge[199, 259] -> 
             RGBColor[
              0.9756274090909092, 0.9782692727272727, 0.7458924090909089], 
             UndirectedEdge[273, 274] -> 
             RGBColor[
              0.6067241363636363, 0.6797408636363635, 0.9625721818181818], 
             UndirectedEdge[281, 294] -> 
             RGBColor[
              0.6262782727272727, 0.673090409090909, 0.6563175909090908], 
             UndirectedEdge[18, 183] -> 
             RGBColor[
              0.6445471818181818, 0.7185722727272726, 0.9675682727272727], 
             UndirectedEdge[77, 269] -> 
             RGBColor[
              0.9013390454545454, 0.7118499999999999, 0.5966522727272727], 
             UndirectedEdge[134, 144] -> 
             RGBColor[
              0.9030961818181817, 0.923930909090909, 0.9304593181818182], 
             UndirectedEdge[200, 210] -> 
             RGBColor[
              0.9596615909090909, 0.9482023636363637, 0.6800120454545453], 
             UndirectedEdge[87, 151] -> 
             RGBColor[0.7086366363636363, 0.767264, 0.8799125000000001], 
             UndirectedEdge[109, 290] -> 
             RGBColor[
              0.4007463636363635, 0.5215280909090908, 0.9467561818181818], 
             UndirectedEdge[247, 278] -> 
             RGBColor[
              0.986869909090909, 0.9661239090909091, 0.5095583636363638], 
             UndirectedEdge[156, 205] -> 
             RGBColor[
              0.6268468636363635, 0.5216342727272728, 0.5830114090909091], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.9539108636363638, 0.8755179090909094, 0.5955354545454545], 
             UndirectedEdge[64, 121] -> 
             RGBColor[
              0.6393004545454544, 0.7125808181818181, 0.9679000909090909], 
             UndirectedEdge[106, 264] -> 
             RGBColor[
              0.9539108636363638, 0.8755179090909094, 0.5955354545454545], 
             UndirectedEdge[91, 107] -> 
             RGBColor[
              0.9945240909090909, 0.9906959090909091, 0.6453592727272731], 
             UndirectedEdge[7, 299] -> 
             RGBColor[0.6538365454545455, 0.727132, 0.967751909090909], 
             UndirectedEdge[160, 221] -> 
             RGBColor[
              0.8640775454545455, 0.43456690909090956`, 0.20668504545454552`],
              UndirectedEdge[8, 234] -> 
             RGBColor[0.5831206818181818, 0.6549321363636362, 0.961228], 
             UndirectedEdge[49, 174] -> 
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692], 
             UndirectedEdge[79, 245] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[13, 147] -> 
             RGBColor[0.7225787272727273, 0.78294, 0.9731635454545454], 
             UndirectedEdge[1, 197] -> 
             RGBColor[
              0.8421578636363636, 0.8734568181818181, 0.7525919999999997], 
             UndirectedEdge[129, 175] -> 
             RGBColor[
              0.9839390454545455, 0.9837641818181819, 0.6759718636363639], 
             UndirectedEdge[116, 283] -> 
             RGBColor[
              0.9863646363636364, 0.9650431818181817, 0.45456254545454516`], 
             UndirectedEdge[62, 265] -> 
             RGBColor[
              0.8477502727272728, 0.8818454545454546, 0.9812604090909091], 
             UndirectedEdge[31, 291] -> 
             RGBColor[
              0.9923825909090909, 0.9904641818181819, 0.7283765909090911], 
             UndirectedEdge[92, 277] -> 
             RGBColor[
              0.8976795454545454, 0.9202261818181818, 0.9546298636363637], 
             UndirectedEdge[124, 289] -> 
             RGBColor[
              0.912381181818182, 0.6176690909090913, 0.30195045454545477`], 
             UndirectedEdge[80, 277] -> 
             RGBColor[
              0.9665581818181819, 0.9745797272727272, 0.9414924545454546], 
             UndirectedEdge[119, 244] -> 
             RGBColor[0.9684785, 0.9547779999999999, 0.6650873181818181], 
             UndirectedEdge[252, 268] -> 
             RGBColor[
              0.8416525909090908, 0.872376090909091, 0.697596181818182], 
             UndirectedEdge[3, 194] -> 
             RGBColor[
              0.9844443181818182, 0.984844909090909, 0.7309676818181816], 
             UndirectedEdge[1, 237] -> 
             RGBColor[
              0.9756274090909092, 0.9782692727272727, 0.7458924090909089], 
             UndirectedEdge[149, 281] -> 
             RGBColor[
              0.6334271818181818, 0.6965816818181818, 0.7371226818181816], 
             UndirectedEdge[29, 209] -> 
             RGBColor[
              0.6130146363636363, 0.6898133636363636, 0.9662251818181818], 
             UndirectedEdge[123, 287] -> 
             RGBColor[
              0.8421578636363636, 0.8734568181818181, 0.7525919999999997], 
             UndirectedEdge[17, 81] -> 
             RGBColor[
              0.9945240909090909, 0.9906959090909091, 0.6453592727272731], 
             UndirectedEdge[176, 187] -> 
             RGBColor[0.9668105, 0.9716936363636364, 0.7608171363636361], 
             UndirectedEdge[246, 270] -> 
             RGBColor[
              0.9807917272727272, 0.984860090909091, 0.9023971818181818], 
             UndirectedEdge[45, 131] -> 
             RGBColor[
              0.8087276363636363, 0.8508435454545453, 0.9814798181818182], 
             UndirectedEdge[4, 158] -> 
             RGBColor[
              0.8787132272727273, 0.5444899090909091, 0.5752423181818181], 
             UndirectedEdge[169, 264] -> 
             RGBColor[
              0.9189728636363637, 0.7250012727272725, 0.5668028181818181], 
             UndirectedEdge[42, 181] -> 
             RGBColor[
              0.935034409090909, 0.911565909090909, 0.656428909090909], 
             UndirectedEdge[8, 263] -> 
             RGBColor[0.8154548181818182, 0.856616, 0.9780415], 
             UndirectedEdge[145, 205] -> 
             RGBColor[0.9367535, 0.7682040000000001, 0.48275136363636373`], 
             UndirectedEdge[167, 269] -> 
             RGBColor[
              0.7826404545454546, 0.8307179090909091, 0.9749508636363635], 
             UndirectedEdge[187, 288] -> 
             RGBColor[
              0.6098237272727272, 0.6717729545454545, 0.7357784999999998], 
             UndirectedEdge[47, 131] -> 
             RGBColor[
              0.8789789545454545, 0.7565088181818183, 0.6107753181818183], 
             UndirectedEdge[43, 97] -> 
             RGBColor[
              0.9492070909090908, 0.9591505454545454, 0.8676400454545455], 
             UndirectedEdge[104, 114] -> 
             RGBColor[
              0.9241352727272727, 0.940706909090909, 0.9324660454545455], 
             UndirectedEdge[26, 129] -> 
             RGBColor[
              0.8976795454545454, 0.9202261818181818, 0.9546298636363637], 
             UndirectedEdge[28, 79] -> 
             RGBColor[
              0.9751221363636364, 0.9771885454545455, 0.6908965909090912], 
             UndirectedEdge[53, 247] -> 
             RGBColor[
              0.8995998636363636, 0.9004244545454545, 0.6782247272727272], 
             UndirectedEdge[150, 281] -> 
             RGBColor[
              0.6067241363636363, 0.6797408636363635, 0.9625721818181818], 
             UndirectedEdge[76, 248] -> 
             RGBColor[
              0.9488269545454544, 0.9574677272727272, 0.7630432727272725], 
             UndirectedEdge[194, 210] -> 
             RGBColor[
              0.9577412727272727, 0.968004090909091, 0.9564171818181818], 
             UndirectedEdge[60, 265] -> 
             RGBColor[0.621541090909091, 0.7019025454545456, 0.964533], 
             UndirectedEdge[78, 178] -> 
             RGBColor[
              0.7570862727272727, 0.8093895454545454, 0.9573203181818182], 
             UndirectedEdge[120, 190] -> 
             RGBColor[
              0.7230976363636363, 0.7836086363636363, 0.9730352727272726], 
             UndirectedEdge[96, 267] -> 
             RGBColor[
              0.9753750909090909, 0.9811553636363637, 0.9265677272727273], 
             UndirectedEdge[159, 212] -> 
             RGBColor[
              0.5440980454545453, 0.6239302272727272, 0.9614474090909091], 
             UndirectedEdge[34, 147] -> 
             RGBColor[
              0.7914573636363637, 0.8372935454545455, 0.9600261363636363], 
             UndirectedEdge[41, 250] -> 
             RGBColor[
              0.731532090909091, 0.788061181818182, 0.9396897727272727], 
             UndirectedEdge[146, 236] -> 
             RGBColor[0.6748756363636363, 0.743908, 0.9697586363636364], 
             UndirectedEdge[82, 103] -> 
             RGBColor[
              0.6923867272727273, 0.7561498181818181, 0.9524241363636363], 
             UndirectedEdge[179, 289] -> 
             RGBColor[
              0.6571959545454547, 0.7197993636363638, 0.6835537272727275], 
             UndirectedEdge[124, 247] -> 
             RGBColor[
              0.9057375454545455, 0.5952585454545458, 0.2761411818181818], 
             UndirectedEdge[162, 227] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             UndirectedEdge[156, 191] -> 
             RGBColor[
              0.6843671818181818, 0.7453303636363635, 0.8448212272727273], 
             UndirectedEdge[1, 51] -> 
             RGBColor[
              0.9844443181818182, 0.984844909090909, 0.7309676818181816], 
             UndirectedEdge[23, 198] -> 
             RGBColor[
              0.5845840454545455, 0.6478132272727273, 0.8724474545454546], 
             UndirectedEdge[77, 159] -> 
             RGBColor[
              0.862316409090909, 0.6808480909090907, 0.5968716818181818], 
             UndirectedEdge[2, 238] -> 
             RGBColor[
              0.9624748181818183, 0.8781267272727276, 0.34493959090909115`], 
             UndirectedEdge[113, 245] -> 
             RGBColor[
              0.8878478636363636, 0.794070909090909, 0.6180355909090909], 
             UndirectedEdge[167, 201] -> 
             RGBColor[0.5908023636363635, 0.678679, 0.9609292727272727], 
             UndirectedEdge[125, 150] -> 
             RGBColor[
              0.9530179545454545, 0.9257918181818181, 0.6542027727272727], 
             UndirectedEdge[142, 198] -> 
             RGBColor[
              0.9261516363636363, 0.9415407272727272, 0.8990496818181819], 
             UndirectedEdge[34, 52] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[13, 251] -> 
             RGBColor[
              0.8976795454545454, 0.9202261818181818, 0.9546298636363637], 
             UndirectedEdge[120, 188] -> 
             RGBColor[
              0.5912126363636363, 0.6765668181818181, 0.9623426363636364], 
             UndirectedEdge[67, 173] -> 
             RGBColor[
              0.9725720909090909, 0.9191413636363636, 0.3479481818181817], 
             UndirectedEdge[20, 280] -> 
             RGBColor[
              0.9577412727272727, 0.968004090909091, 0.9564171818181818], 
             UndirectedEdge[32, 107] -> 
             RGBColor[
              0.9802262727272727, 0.9437133636363636, 0.4837490909090911], 
             UndirectedEdge[189, 287] -> 
             RGBColor[
              0.9938936818181818, 0.9902172727272727, 0.6399644090909089], 
             UndirectedEdge[159, 205] -> 
             RGBColor[
              0.8706476818181819, 0.7186784545454546, 0.6038235000000001], 
             UndirectedEdge[66, 86] -> 
             RGBColor[
              0.4270321818181818, 0.5442955454545454, 0.948431090909091], 
             UndirectedEdge[119, 266] -> 
             RGBColor[0.867304409090909, 0.875195, 0.6750058181818182], 
             UndirectedEdge[28, 230] -> 
             RGBColor[
              0.9751221363636364, 0.9771885454545455, 0.6908965909090912], 
             UndirectedEdge[83, 142] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[191, 217] -> 
             RGBColor[
              0.9848244545454545, 0.9865277272727273, 0.8355644545454546], 
             UndirectedEdge[43, 233] -> 
             RGBColor[0.710653, 0.7680978181818181, 0.8464961363636365], 
             UndirectedEdge[113, 297] -> 
             RGBColor[
              0.8878478636363636, 0.794070909090909, 0.6180355909090909], 
             UndirectedEdge[158, 207] -> 
             RGBColor[
              0.6221755909090909, 0.3392112727272727, 0.5563245454545455], 
             UndirectedEdge[40, 201] -> 
             RGBColor[
              0.7659031818181817, 0.8159651818181818, 0.9423955909090909], 
             UndirectedEdge[194, 226] -> 
             RGBColor[
              0.9577412727272727, 0.968004090909091, 0.9564171818181818], 
             UndirectedEdge[134, 230] -> 
             RGBColor[
              0.9719748181818182, 0.9782844545454545, 0.917321909090909], 
             UndirectedEdge[134, 264] -> 
             RGBColor[
              0.9807917272727272, 0.984860090909091, 0.9023971818181818], 
             UndirectedEdge[59, 226] -> 
             RGBColor[
              0.7138982727272728, 0.7749099090909092, 0.9695392272727272], 
             UndirectedEdge[42, 201] -> 
             RGBColor[
              0.7302858181818179, 0.7885879999999998, 0.9744711818181818], 
             UndirectedEdge[217, 295] -> 
             RGBColor[
              0.7012036363636364, 0.7627254545454545, 0.9374994090909091], 
             UndirectedEdge[45, 94] -> 
             RGBColor[
              0.8744533181818182, 0.8986862727272726, 0.7558109090909089], 
             UndirectedEdge[197, 254] -> 
             RGBColor[0.8154548181818182, 0.856616, 0.9780415], 
             UndirectedEdge[30, 189] -> 
             RGBColor[
              0.9281679999999999, 0.9423745454545454, 0.8656333181818183], 
             UndirectedEdge[92, 179] -> 
             RGBColor[
              0.5709364545454545, 0.6562613636363637, 0.9622117272727273], 
             UndirectedEdge[134, 288] -> 
             RGBColor[0.6061711363636362, 0.6717881363636362, 0.907208], 
             UndirectedEdge[59, 83] -> 
             RGBColor[
              0.7227151818181818, 0.7814855454545455, 0.9546144999999999], 
             UndirectedEdge[10, 22] -> 
             RGBColor[
              0.7570862727272727, 0.8093895454545454, 0.9573203181818182], 
             UndirectedEdge[148, 168] -> 
             RGBColor[
              0.6655862727272726, 0.7353482727272727, 0.9695750000000001], 
             UndirectedEdge[130, 216] -> 
             RGBColor[
              0.9187186363636364, 0.9370021818181817, 0.9566365909090909], 
             UndirectedEdge[158, 196] -> 
             RGBColor[
              0.8654762727272728, 0.41470990909090916`, 0.20679186363636365`],
              UndirectedEdge[203, 237] -> 
             RGBColor[
              0.9450939545454546, 0.8689422727272731, 0.6104601818181818], 
             UndirectedEdge[160, 193] -> 
             RGBColor[
              0.7933489545454546, 0.6892739090909092, 0.6023307727272726], 
             UndirectedEdge[38, 88] -> 
             RGBColor[
              0.9309408181818181, 0.9472025454545454, 0.9735680454545454], 
             UndirectedEdge[22, 73] -> 
             RGBColor[
              0.6882076363636362, 0.7550359999999998, 0.9704577272727273], 
             UndirectedEdge[181, 227] -> 
             RGBColor[
              0.9139953181818181, 0.894789909090909, 0.6544221818181818], 
             UndirectedEdge[85, 255] -> 
             RGBColor[
              0.8261216818181818, 0.5541310909090912, 0.5806084545454546], 
             UndirectedEdge[106, 227] -> 
             RGBColor[
              0.8972544090909091, 0.8313647272727276, 0.6256043181818183], 
             UndirectedEdge[131, 261] -> 
             RGBColor[
              0.9187186363636364, 0.9370021818181817, 0.9566365909090909], 
             UndirectedEdge[81, 94] -> 
             RGBColor[
              0.9940188181818181, 0.9896151818181818, 0.5903634545454546], 
             UndirectedEdge[77, 154] -> 
             RGBColor[
              0.9284222272727272, 0.7303736363636362, 0.4757995454545455], 
             UndirectedEdge[167, 277] -> 
             RGBColor[
              0.8002742727272727, 0.8438691818181818, 0.9451014090909091], 
             UndirectedEdge[113, 176] -> 
             RGBColor[0.9268705, 0.8250728181818183, 0.6178161818181818], 
             UndirectedEdge[4, 276] -> 
             RGBColor[
              0.7826404545454546, 0.8307179090909091, 0.9749508636363635], 
             UndirectedEdge[101, 243] -> 
             RGBColor[
              0.9938936818181818, 0.9902172727272727, 0.6399644090909089], 
             UndirectedEdge[52, 271] -> 
             RGBColor[
              0.9309408181818181, 0.9472025454545454, 0.9735680454545454], 
             UndirectedEdge[37, 71] -> 
             RGBColor[
              0.9539108636363638, 0.8755179090909094, 0.5955354545454545], 
             UndirectedEdge[83, 291] -> 
             RGBColor[
              0.9739911818181818, 0.9791182727272727, 0.8839055454545455], 
             UndirectedEdge[80, 149] -> 
             RGBColor[
              0.9756274090909092, 0.9782692727272727, 0.7458924090909089], 
             UndirectedEdge[104, 206] -> 
             RGBColor[
              0.9807917272727272, 0.984860090909091, 0.9023971818181818], 
             UndirectedEdge[61, 108] -> 
             RGBColor[
              0.9241352727272727, 0.940706909090909, 0.9324660454545455], 
             UndirectedEdge[115, 264] -> 
             RGBColor[
              0.9848244545454545, 0.9865277272727273, 0.8355644545454546], 
             UndirectedEdge[38, 52] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[33, 285] -> 
             RGBColor[0.867304409090909, 0.875195, 0.6750058181818182], 
             UndirectedEdge[100, 122] -> 
             RGBColor[0.8154548181818182, 0.856616, 0.9780415], 
             UndirectedEdge[205, 269] -> 
             RGBColor[
              0.9096703181818182, 0.7496803636363638, 0.603604090909091], 
             UndirectedEdge[177, 252] -> 
             RGBColor[
              0.9935135454545454, 0.9885344545454546, 0.5353676363636367], 
             UndirectedEdge[152, 244] -> 
             RGBColor[
              0.9309408181818181, 0.9472025454545454, 0.9735680454545454], 
             UndirectedEdge[10, 71] -> 
             RGBColor[
              0.9665581818181819, 0.9745797272727272, 0.9414924545454546], 
             UndirectedEdge[233, 259] -> 
             RGBColor[
              0.6923867272727273, 0.7561498181818181, 0.9524241363636363], 
             UndirectedEdge[130, 299] -> 
             RGBColor[
              0.731532090909091, 0.788061181818182, 0.9396897727272727], 
             UndirectedEdge[81, 86] -> 
             RGBColor[
              0.7107781363636363, 0.7674957272727272, 0.796895181818182], 
             UndirectedEdge[205, 282] -> 
             RGBColor[
              0.7850176818181818, 0.6514435454545455, 0.5953789545454545], 
             UndirectedEdge[176, 297] -> 
             RGBColor[
              0.9010848181818181, 0.9238509090909091, 0.9864860454545454], 
             UndirectedEdge[92, 128] -> 
             RGBColor[
              0.8888626363636363, 0.9136505454545454, 0.9695545909090909], 
             UndirectedEdge[166, 285] -> 
             RGBColor[
              0.8089818636363636, 0.6388426363636361, 0.5916460454545454], 
             UndirectedEdge[132, 146] -> 
             RGBColor[
              0.8831012727272726, 0.9096249999999999, 0.9887121818181819], 
             UndirectedEdge[81, 130] -> 
             RGBColor[
              0.9849495909090908, 0.9859256363636364, 0.7859635000000003], 
             UndirectedEdge[1, 128] -> 
             RGBColor[
              0.9756274090909092, 0.9782692727272727, 0.7458924090909089], 
             UndirectedEdge[296, 297] -> 
             RGBColor[0.6748756363636363, 0.743908, 0.9697586363636364], 
             UndirectedEdge[128, 237] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[112, 146] -> 
             RGBColor[
              0.5204945909090908, 0.5991214999999999, 0.9601032272727272], 
             UndirectedEdge[116, 287] -> 
             RGBColor[
              0.9863646363636364, 0.9650431818181817, 0.45456254545454516`], 
             UndirectedEdge[10, 266] -> 
             RGBColor[
              0.8565671818181818, 0.8884210909090908, 0.9663356818181819], 
             UndirectedEdge[16, 76] -> 
             RGBColor[
              0.9000180454545454, 0.7732848181818182, 0.6127820454545454], 
             UndirectedEdge[23, 72] -> 
             RGBColor[
              0.5374113636363638, 0.46278131818181834`, 0.584173090909091], 
             UndirectedEdge[237, 277] -> 
             RGBColor[
              0.9665581818181819, 0.9745797272727272, 0.9414924545454546], 
             UndirectedEdge[56, 278] -> 
             RGBColor[
              0.9903662272727272, 0.9896303636363637, 0.7617929545454547], 
             UndirectedEdge[88, 274] -> 
             RGBColor[
              0.5887405909090908, 0.6655149545454544, 0.9647983181818183], 
             UndirectedEdge[103, 282] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[46, 60] -> 
             RGBColor[
              0.731532090909091, 0.788061181818182, 0.9396897727272727], 
             UndirectedEdge[82, 216] -> 
             RGBColor[
              0.6445471818181818, 0.7185722727272726, 0.9675682727272727], 
             UndirectedEdge[48, 70] -> 
             RGBColor[
              0.8087276363636363, 0.8508435454545453, 0.9814798181818182], 
             UndirectedEdge[143, 174] -> 
             RGBColor[
              0.7553930909090909, 0.8088380909090909, 0.9762541818181818], 
             UndirectedEdge[95, 205] -> 
             RGBColor[
              0.9327207727272727, 0.7665363636363638, 0.549584090909091], 
             UndirectedEdge[78, 190] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[68, 292] -> 
             RGBColor[
              0.5595172272727273, 0.6301234090909091, 0.9598838181818181], 
             UndirectedEdge[145, 269] -> 
             RGBColor[
              0.9671906363636363, 0.9733764545454546, 0.8654139090909092], 
             UndirectedEdge[198, 254] -> 
             RGBColor[
              0.9651742727272727, 0.9725426363636365, 0.8988302727272728], 
             UndirectedEdge[124, 147] -> 
             RGBColor[0.7287164090909092, 0.4777740909090913, 0.57108], 
             UndirectedEdge[44, 194] -> 
             RGBColor[
              0.8653840909090909, 0.8949967272727273, 0.9514109545454545], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.5589171818181817, 0.6513373636363635, 0.9591237272727273], 
             UndirectedEdge[5, 11] -> 
             RGBColor[0.8154548181818182, 0.856616, 0.9780415], 
             UndirectedEdge[108, 254] -> 
             RGBColor[
              0.9010848181818181, 0.9238509090909091, 0.9864860454545454], 
             UndirectedEdge[61, 71] -> 
             RGBColor[
              0.9807917272727272, 0.984860090909091, 0.9023971818181818], 
             UndirectedEdge[229, 284] -> 
             RGBColor[
              0.9663052272727273, 0.9706129090909091, 0.7058213181818184], 
             UndirectedEdge[37, 136] -> 
             RGBColor[
              0.9362770454545455, 0.8623666363636366, 0.6253849090909092], 
             UndirectedEdge[148, 159] -> 
             RGBColor[
              0.6445471818181818, 0.7185722727272726, 0.9675682727272727], 
             UndirectedEdge[164, 230] -> 
             RGBColor[
              0.8565671818181818, 0.8884210909090908, 0.9663356818181819], 
             UndirectedEdge[176, 193] -> 
             RGBColor[0.8154548181818182, 0.856616, 0.9780415], 
             UndirectedEdge[216, 299] -> 
             RGBColor[0.6748756363636363, 0.743908, 0.9697586363636364], 
             UndirectedEdge[149, 277] -> 
             RGBColor[
              0.9844443181818182, 0.984844909090909, 0.7309676818181816], 
             UndirectedEdge[39, 248] -> 
             RGBColor[
              0.9277878636363637, 0.9406917272727272, 0.7610365454545452], 
             UndirectedEdge[13, 137] -> 
             RGBColor[0.9062435, 0.922835, 0.7040340000000002], 
             UndirectedEdge[68, 75] -> 
             RGBColor[0.5415336818181817, 0.6158975, 0.9621099545454546], 
             UndirectedEdge[66, 97] -> 
             RGBColor[
              0.6655862727272726, 0.7353482727272727, 0.9695750000000001], 
             UndirectedEdge[59, 106] -> 
             RGBColor[
              0.7100678636363638, 0.6824237272727276, 0.6086575000000001], 
             UndirectedEdge[51, 198] -> 
             RGBColor[
              0.9828080909090908, 0.9856939090909091, 0.8689808181818183], 
             UndirectedEdge[193, 228] -> 
             RGBColor[
              0.7764321818181817, 0.8256140909090908, 0.9782609090909091], 
             UndirectedEdge[30, 287] -> 
             RGBColor[
              0.9277878636363637, 0.9406917272727272, 0.7610365454545452], 
             UndirectedEdge[93, 147] -> 
             RGBColor[0.8077072727272727, 0.8484077272727273, 0.8875145], 
             UndirectedEdge[69, 121] -> 
             RGBColor[
              0.7302858181818179, 0.7885879999999998, 0.9744711818181818], 
             UndirectedEdge[148, 251] -> 
             RGBColor[
              0.7012036363636364, 0.7627254545454545, 0.9374994090909091], 
             UndirectedEdge[125, 269] -> 
             RGBColor[
              0.9530179545454545, 0.9257918181818181, 0.6542027727272727], 
             UndirectedEdge[37, 44] -> 
             RGBColor[
              0.8439198636363637, 0.789359272727273, 0.6203786818181818], 
             UndirectedEdge[91, 105] -> 
             RGBColor[
              0.7107781363636363, 0.7674957272727272, 0.796895181818182], 
             UndirectedEdge[81, 203] -> 
             RGBColor[
              0.9634853636363637, 0.8802881818181821, 0.4549312272727275], 
             UndirectedEdge[8, 69] -> 
             RGBColor[
              0.7482693636363635, 0.802813909090909, 0.9722450454545455], 
             UndirectedEdge[52, 270] -> 
             RGBColor[
              0.9665581818181819, 0.9745797272727272, 0.9414924545454546], 
             UndirectedEdge[108, 268] -> 
             RGBColor[
              0.7764321818181817, 0.8256140909090908, 0.9782609090909091], 
             UndirectedEdge[11, 254] -> 
             RGBColor[0.8154548181818182, 0.856616, 0.9780415], 
             UndirectedEdge[82, 255] -> 
             RGBColor[0.6296457727272728, 0.39663036363636395`, 0.563478], 
             UndirectedEdge[43, 66] -> 
             RGBColor[0.710653, 0.7680978181818181, 0.8464961363636365], 
             UndirectedEdge[252, 283] -> 
             RGBColor[
              0.9930082727272728, 0.9874537272727273, 0.4803718181818182], 
             UndirectedEdge[99, 215] -> 
             RGBColor[
              0.9792157272727272, 0.941551909090909, 0.3737574545454544], 
             UndirectedEdge[114, 283] -> 
             RGBColor[
              0.9277878636363637, 0.9406917272727272, 0.7610365454545452], 
             UndirectedEdge[24, 194] -> 
             RGBColor[
              0.9665581818181819, 0.9745797272727272, 0.9414924545454546], 
             UndirectedEdge[134, 228] -> 
             RGBColor[
              0.9241352727272727, 0.940706909090909, 0.9324660454545455], 
             UndirectedEdge[49, 143] -> 
             RGBColor[
              0.7553930909090909, 0.8088380909090909, 0.9762541818181818], 
             UndirectedEdge[123, 189] -> 
             RGBColor[0.842538, 0.8751396363636363, 0.8571887727272728], 
             UndirectedEdge[232, 240] -> 
             RGBColor[
              0.6445471818181818, 0.7185722727272726, 0.9675682727272727], 
             UndirectedEdge[11, 243] -> 
             RGBColor[0.842538, 0.8751396363636363, 0.8571887727272728], 
             UndirectedEdge[155, 210] -> 
             RGBColor[
              0.8936535909090909, 0.6593280909090913, 0.5895492272727273], 
             UndirectedEdge[148, 156] -> 
             RGBColor[
              0.4007463636363635, 0.5215280909090908, 0.9467561818181818], 
             UndirectedEdge[15, 212] -> 
             RGBColor[
              0.5443522727272726, 0.41192931818181794`, 0.5716136363636364], 
             UndirectedEdge[51, 204] -> 
             RGBColor[
              0.9577412727272727, 0.968004090909091, 0.9564171818181818], 
             UndirectedEdge[95, 156] -> 
             RGBColor[
              0.6803344545454544, 0.7436627272727272, 0.9116539545454545], 
             UndirectedEdge[87, 109] -> 
             RGBColor[
              0.4270321818181818, 0.5442955454545454, 0.948431090909091], 
             UndirectedEdge[113, 288] -> 
             RGBColor[
              0.5698837272727273, 0.5251521363636363, 0.5927775454545454], 
             UndirectedEdge[164, 176] -> 
             RGBColor[
              0.8477502727272728, 0.8818454545454546, 0.9812604090909091], 
             UndirectedEdge[17, 294] -> 
             RGBColor[
              0.986869909090909, 0.9661239090909091, 0.5095583636363638], 
             UndirectedEdge[77, 212] -> 
             RGBColor[
              0.5443522727272726, 0.41192931818181794`, 0.5716136363636364], 
             UndirectedEdge[180, 296] -> 
             RGBColor[
              0.4047890000000001, 0.5240963636363638, 0.9472716363636364], 
             UndirectedEdge[217, 271] -> 
             RGBColor[
              0.9397577272727271, 0.9537781818181817, 0.9586433181818181], 
             UndirectedEdge[4, 85] -> 
             RGBColor[
              0.8800457272727272, 0.907074909090909, 0.9844793181818181], 
             UndirectedEdge[95, 127] -> 
             RGBColor[
              0.9241352727272727, 0.940706909090909, 0.9324660454545455], 
             UndirectedEdge[54, 75] -> 
             RGBColor[
              0.8916867727272726, 0.7354544545454547, 0.6058302272727273], 
             UndirectedEdge[134, 193] -> 
             RGBColor[0.8385052727272726, 0.873472, 0.9240215], 
             UndirectedEdge[40, 178] -> 
             RGBColor[
              0.7659031818181817, 0.8159651818181818, 0.9423955909090909], 
             UndirectedEdge[69, 239] -> 
             RGBColor[
              0.7482693636363635, 0.802813909090909, 0.9722450454545455], 
             UndirectedEdge[134, 200] -> 
             RGBColor[
              0.9827120454545454, 0.9650583636363637, 0.6259920454545453], 
             UndirectedEdge[89, 141] -> 
             RGBColor[
              0.8350089545454544, 0.8499655454545454, 0.671786909090909], 
             UndirectedEdge[38, 147] -> 
             RGBColor[
              0.7914573636363637, 0.8372935454545455, 0.9600261363636363], 
             UndirectedEdge[170, 182] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[94, 120] -> 
             RGBColor[
              0.8744533181818182, 0.8986862727272726, 0.7558109090909089], 
             UndirectedEdge[80, 269] -> 
             RGBColor[
              0.9489243636363636, 0.9614284545454546, 0.971341909090909], 
             UndirectedEdge[263, 286] -> 
             RGBColor[
              0.7615307727272728, 0.5036721818181822, 0.5741706363636364], 
             UndirectedEdge[130, 140] -> 
             RGBColor[
              0.7659031818181817, 0.8159651818181818, 0.9423955909090909], 
             UndirectedEdge[25, 288] -> 
             RGBColor[
              0.42565368181818175`, 0.5307972272727273, 0.9499122272727272], 
             UndirectedEdge[148, 191] -> 
             RGBColor[0.710653, 0.7680978181818181, 0.8464961363636365], 
             UndirectedEdge[177, 268] -> 
             RGBColor[
              0.8426631363636363, 0.8745375454545454, 0.8075878181818184], 
             UndirectedEdge[69, 126] -> 
             RGBColor[
              0.7302858181818179, 0.7885879999999998, 0.9744711818181818], 
             UndirectedEdge[20, 37] -> 
             RGBColor[
              0.9362770454545455, 0.8623666363636366, 0.6253849090909092], 
             UndirectedEdge[3, 72] -> 
             RGBColor[
              0.9447046363636364, 0.8043515454545456, 0.3851064090909089], 
             UndirectedEdge[87, 154] -> 
             RGBColor[0.710653, 0.7680978181818181, 0.8464961363636365], 
             UndirectedEdge[11, 204] -> 
             RGBColor[0.8154548181818182, 0.856616, 0.9780415], 
             UndirectedEdge[55, 268] -> 
             RGBColor[
              0.8330886363636363, 0.8697672727272727, 0.9481920454545454], 
             UndirectedEdge[125, 142] -> 
             RGBColor[
              0.9139953181818181, 0.894789909090909, 0.6544221818181818], 
             UndirectedEdge[176, 221] -> 
             RGBColor[
              0.8861834090909091, 0.6019090000000004, 0.5823957727272727], 
             UndirectedEdge[29, 182] -> 
             RGBColor[
              0.5919755454545454, 0.6730373636363636, 0.9642184545454546], 
             UndirectedEdge[122, 161] -> 
             RGBColor[
              0.8800457272727272, 0.907074909090909, 0.9844793181818181], 
             UndirectedEdge[44, 226] -> 
             RGBColor[
              0.8477502727272728, 0.8818454545454546, 0.9812604090909091], 
             UndirectedEdge[89, 131] -> 
             RGBColor[
              0.7764321818181817, 0.8256140909090908, 0.9782609090909091], 
             UndirectedEdge[56, 110] -> 
             RGBColor[
              0.9827120454545454, 0.9650583636363637, 0.6259920454545453], 
             UndirectedEdge[43, 178] -> 
             RGBColor[
              0.7753525454545453, 0.8213375454545454, 0.8513923181818183], 
             UndirectedEdge[66, 162] -> 
             RGBColor[
              0.6445471818181818, 0.7185722727272726, 0.9675682727272727], 
             UndirectedEdge[5, 142] -> 
             RGBColor[
              0.9010848181818181, 0.9238509090909091, 0.9864860454545454], 
             UndirectedEdge[147, 273] -> 
             RGBColor[
              0.7826404545454546, 0.8307179090909091, 0.9749508636363635], 
             UndirectedEdge[81, 167] -> 
             RGBColor[
              0.8098487727272727, 0.8486394545454545, 0.804497181818182], 
             UndirectedEdge[95, 212] -> 
             RGBColor[0.6061711363636362, 0.6717881363636362, 0.907208], 
             UndirectedEdge[56, 217] -> 
             RGBColor[
              0.9807917272727272, 0.984860090909091, 0.9023971818181818], 
             UndirectedEdge[6, 93] -> 
             RGBColor[0.7086366363636363, 0.767264, 0.8799125000000001], 
             UndirectedEdge[131, 146] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             UndirectedEdge[7, 80] -> 
             RGBColor[
              0.8888626363636363, 0.9136505454545454, 0.9695545909090909], 
             UndirectedEdge[76, 239] -> 
             RGBColor[
              0.922123909090909, 0.940626909090909, 0.9884927727272728], 
             UndirectedEdge[148, 278] -> 
             RGBColor[
              0.7107781363636363, 0.7674957272727272, 0.796895181818182], 
             UndirectedEdge[29, 170] -> 
             RGBColor[
              0.6398150909090909, 0.7106149090909091, 0.9490743181818182], 
             UndirectedEdge[147, 289] -> 
             RGBColor[
              0.8088382272727273, 0.8464780000000001, 0.6945055454545456], 
             UndirectedEdge[25, 28] -> 
             RGBColor[
              0.8088382272727273, 0.8464780000000001, 0.6945055454545456], 
             UndirectedEdge[5, 149] -> 
             RGBColor[0.9668105, 0.9716936363636364, 0.7608171363636361], 
             UndirectedEdge[140, 202] -> 
             RGBColor[
              0.6559121818181817, 0.7298065454545454, 0.9672388181818181], 
             UndirectedEdge[10, 63] -> 
             RGBColor[
              0.8888626363636363, 0.9136505454545454, 0.9695545909090909], 
             UndirectedEdge[43, 259] -> 
             RGBColor[
              0.9760075454545454, 0.9799520909090909, 0.8504891818181819], 
             UndirectedEdge[21, 50] -> 
             RGBColor[0.992503, 0.986373, 0.42537600000000036`], 
             UndirectedEdge[87, 155] -> 
             RGBColor[
              0.6371159545454546, 0.45404945454545476`, 0.5706314545454546], 
             UndirectedEdge[127, 282] -> 
             RGBColor[
              0.7764321818181817, 0.8256140909090908, 0.9782609090909091], 
             UndirectedEdge[79, 144] -> 
             RGBColor[
              0.8888626363636363, 0.9136505454545454, 0.9695545909090909], 
             UndirectedEdge[54, 298] -> 
             RGBColor[
              0.7522033181818182, 0.6255454545454547, 0.5922883181818182], 
             UndirectedEdge[234, 263] -> 
             RGBColor[
              0.45846804545454534`, 0.556695318181818, 0.9530028636363637], 
             UndirectedEdge[34, 38] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[39, 85] -> 
             RGBColor[
              0.8410230909090908, 0.8760729999999999, 0.9846987272727272], 
             UndirectedEdge[20, 108] -> 
             RGBColor[
              0.9010848181818181, 0.9238509090909091, 0.9864860454545454], 
             UndirectedEdge[94, 201] -> 
             RGBColor[
              0.774972409090909, 0.8196547272727273, 0.7467955454545452], 
             UndirectedEdge[260, 294] -> 
             RGBColor[
              0.8021945909090908, 0.8240674545454545, 0.6686962727272726], 
             UndirectedEdge[138, 266] -> 
             RGBColor[
              0.7876885454545455, 0.8340675454545454, 0.979473090909091], 
             UndirectedEdge[127, 168] -> 
             RGBColor[
              0.8831012727272726, 0.9096249999999999, 0.9887121818181819], 
             UndirectedEdge[128, 198] -> 
             RGBColor[
              0.9739911818181818, 0.9791182727272727, 0.8839055454545455], 
             UndirectedEdge[145, 216] -> 
             RGBColor[
              0.9281679999999999, 0.9423745454545454, 0.8656333181818183], 
             UndirectedEdge[141, 182] -> 
             RGBColor[
              0.9206389545454545, 0.9172004545454544, 0.6802314545454544], 
             UndirectedEdge[41, 252] -> 
             RGBColor[
              0.9839390454545455, 0.9837641818181819, 0.6759718636363639], 
             UndirectedEdge[55, 208] -> 
             RGBColor[
              0.8002742727272727, 0.8438691818181818, 0.9451014090909091], 
             UndirectedEdge[121, 249] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999998, 0.9867054545454546], 
             UndirectedEdge[89, 120] -> 
             RGBColor[
              0.7230976363636363, 0.7836086363636363, 0.9730352727272726], 
             UndirectedEdge[32, 142] -> 
             RGBColor[
              0.9139953181818181, 0.894789909090909, 0.6544221818181818], 
             UndirectedEdge[7, 77] -> 
             RGBColor[
              0.8412773181818181, 0.6640720909090907, 0.5948649545454545], 
             UndirectedEdge[45, 146] -> 
             RGBColor[
              0.8087276363636363, 0.8508435454545453, 0.9814798181818182], 
             UndirectedEdge[110, 223] -> 
             RGBColor[
              0.9792157272727272, 0.941551909090909, 0.3737574545454544], 
             UndirectedEdge[225, 276] -> 
             RGBColor[
              0.805690909090909, 0.8475739090909091, 0.9209308636363636], 
             UndirectedEdge[65, 291] -> 
             RGBColor[
              0.9923825909090909, 0.9904641818181819, 0.7283765909090911], 
             UndirectedEdge[194, 290] -> 
             RGBColor[
              0.6749178181818181, 0.7399579999999999, 0.9358245000000001], 
             UndirectedEdge[154, 258] -> 
             RGBColor[
              0.9760075454545454, 0.9799520909090909, 0.8504891818181819], 
             UndirectedEdge[31, 280] -> 
             RGBColor[
              0.9849495909090908, 0.9859256363636364, 0.7859635000000003], 
             UndirectedEdge[156, 271] -> 
             RGBColor[
              0.6393004545454544, 0.7125808181818181, 0.9679000909090909], 
             UndirectedEdge[83, 241] -> 
             RGBColor[0.6155410454545454, 0.6863165, 0.9476474545454545], 
             UndirectedEdge[208, 268] -> 
             RGBColor[
              0.6579878181818182, 0.7324810909090909, 0.9667257272727272], 
             UndirectedEdge[1, 80] -> 
             RGBColor[
              0.9756274090909092, 0.9782692727272727, 0.7458924090909089], 
             UndirectedEdge[116, 206] -> 
             RGBColor[
              0.9772954090909091, 0.9613536363636364, 0.6501625909090909], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.9375557272727273, 0.7808602727272729, 0.30430131818181816`], 
             UndirectedEdge[108, 204] -> 
             RGBColor[
              0.9010848181818181, 0.9238509090909091, 0.9864860454545454], 
             UndirectedEdge[251, 271] -> 
             RGBColor[
              0.9397577272727271, 0.9537781818181817, 0.9586433181818181], 
             UndirectedEdge[6, 38] -> 
             RGBColor[
              0.6923867272727273, 0.7561498181818181, 0.9524241363636363], 
             UndirectedEdge[135, 158] -> 
             RGBColor[
              0.7540605909090909, 0.4462530909090909, 0.5670171818181817], 
             UndirectedEdge[25, 180] -> 
             RGBColor[
              0.4735311818181819, 0.5799043636363637, 0.9526832727272727], 
             UndirectedEdge[57, 217] -> 
             RGBColor[
              0.9539108636363638, 0.8755179090909094, 0.5955354545454545], 
             UndirectedEdge[71, 136] -> 
             RGBColor[
              0.9577412727272727, 0.968004090909091, 0.9564171818181818], 
             UndirectedEdge[135, 173] -> 
             RGBColor[
              0.8283653181818181, 0.8275549999999999, 0.6459776363636363], 
             UndirectedEdge[143, 235] -> 
             RGBColor[
              0.8416525909090908, 0.872376090909091, 0.697596181818182], 
             UndirectedEdge[264, 288] -> 
             RGBColor[
              0.6007544999999999, 0.668083409090909, 0.9313785454545455], 
             UndirectedEdge[223, 247] -> 
             RGBColor[
              0.9792157272727272, 0.941551909090909, 0.3737574545454544], 
             UndirectedEdge[191, 225] -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909092], 
             UndirectedEdge[1, 243] -> 
             RGBColor[
              0.9938936818181818, 0.9902172727272727, 0.6399644090909089], 
             UndirectedEdge[29, 284] -> 
             RGBColor[
              0.6571959545454547, 0.7197993636363638, 0.6835537272727275], 
             UndirectedEdge[6, 273] -> 
             RGBColor[
              0.6835698181818182, 0.7495741818181818, 0.9673488636363636], 
             UndirectedEdge[103, 276] -> 
             RGBColor[
              0.7914573636363637, 0.8372935454545455, 0.9600261363636363], 
             UndirectedEdge[99, 199] -> 
             RGBColor[
              0.9863646363636364, 0.9650431818181817, 0.45456254545454516`], 
             UndirectedEdge[35, 129] -> 
             RGBColor[
              0.9839390454545455, 0.9837641818181819, 0.6759718636363639], 
             UndirectedEdge[77, 145] -> 
             RGBColor[
              0.9284222272727272, 0.7303736363636362, 0.4757995454545455], 
             UndirectedEdge[72, 155] -> 
             RGBColor[
              0.8715477272727273, 0.49198600000000037`, 0.21383850000000004`],
              UndirectedEdge[20, 44] -> 
             RGBColor[
              0.8477502727272728, 0.8818454545454546, 0.9812604090909091], 
             UndirectedEdge[131, 178] -> 
             RGBColor[
              0.7092467272727272, 0.7718119999999999, 0.9724644545454546], 
             UndirectedEdge[106, 241] -> 
             RGBColor[
              0.6028937272727273, 0.5872546818181821, 0.6016904545454547], 
             UndirectedEdge[85, 286] -> 
             RGBColor[
              0.8261216818181818, 0.5541310909090912, 0.5806084545454546], 
             UndirectedEdge[86, 261] -> 
             RGBColor[
              0.7012036363636364, 0.7627254545454545, 0.9374994090909091], 
             UndirectedEdge[256, 269] -> 
             RGBColor[
              0.5595172272727273, 0.6301234090909091, 0.9598838181818181], 
             UndirectedEdge[37, 61] -> 
             RGBColor[
              0.9593275000000001, 0.8792226363636366, 0.5713649090909092], 
             UndirectedEdge[73, 244] -> 
             RGBColor[
              0.8888626363636363, 0.9136505454545454, 0.9695545909090909], 
             UndirectedEdge[180, 193] -> 
             RGBColor[
              0.5063455454545455, 0.6058024545454546, 0.9557739090909091], 
             UndirectedEdge[8, 213] -> 
             RGBColor[
              0.9010848181818181, 0.9238509090909091, 0.9864860454545454], 
             UndirectedEdge[48, 138] -> 
             RGBColor[
              0.7876885454545455, 0.8340675454545454, 0.979473090909091], 
             UndirectedEdge[170, 284] -> 
             RGBColor[
              0.9751221363636364, 0.9771885454545455, 0.6908965909090911], 
             UndirectedEdge[55, 219] -> 
             RGBColor[
              0.8653840909090909, 0.8949967272727273, 0.9514109545454545], 
             UndirectedEdge[111, 235] -> 
             RGBColor[
              0.9751221363636364, 0.9771885454545455, 0.6908965909090911], 
             UndirectedEdge[56, 247] -> 
             RGBColor[
              0.9827120454545454, 0.9650583636363637, 0.6259920454545453], 
             UndirectedEdge[7, 82] -> 
             RGBColor[
              0.6235080909090909, 0.7017962727272726, 0.9655615454545454], 
             UndirectedEdge[182, 190] -> 
             RGBColor[
              0.7764321818181817, 0.8256140909090908, 0.9782609090909091], 
             UndirectedEdge[113, 228] -> 
             RGBColor[
              0.8878478636363636, 0.794070909090909, 0.6180355909090909], 
             UndirectedEdge[133, 146] -> 
             RGBColor[
              0.5919755454545454, 0.6730373636363636, 0.9642184545454546], 
             UndirectedEdge[93, 274] -> 
             RGBColor[
              0.6317909545454545, 0.6974306818181818, 0.8751358181818183], 
             UndirectedEdge[153, 220] -> 
             RGBColor[
              0.8748334545454546, 0.9003690909090909, 0.8604076818181818], 
             UndirectedEdge[90, 153] -> 
             RGBColor[
              0.8728170909090909, 0.8995352727272727, 0.8938240454545455], 
             UndirectedEdge[178, 190] -> 
             RGBColor[
              0.6236167272727271, 0.7045770909090908, 0.9640199090909091], 
             UndirectedEdge[39, 126] -> 
             RGBColor[
              0.8831012727272726, 0.9096249999999999, 0.9887121818181819], 
             UndirectedEdge[15, 77] -> 
             RGBColor[
              0.8625706363636363, 0.4688471818181815, 0.20703790909090902`], 
             UndirectedEdge[103, 293] -> 
             RGBColor[
              0.8888626363636363, 0.9136505454545454, 0.9695545909090909], 
             UndirectedEdge[92, 269] -> 
             RGBColor[
              0.8800457272727272, 0.907074909090909, 0.9844793181818181], 
             UndirectedEdge[8, 14] -> 
             RGBColor[0.8154548181818182, 0.856616, 0.9780415], 
             UndirectedEdge[157, 171] -> 
             RGBColor[
              0.9761326818181818, 0.9793499999999999, 0.8008882272727275], 
             UndirectedEdge[198, 226] -> 
             RGBColor[
              0.9651742727272727, 0.9725426363636365, 0.8988302727272728], 
             UndirectedEdge[86, 169] -> 
             RGBColor[0.6448014090909091, 0.5065713636363635, 0.5777345], 
             UndirectedEdge[163, 235] -> 
             RGBColor[
              0.7744671363636363, 0.8185739999999999, 0.6917997272727274], 
             UndirectedEdge[31, 136] -> 
             RGBColor[
              0.9673157727272728, 0.9727743636363637, 0.8158129545454547], 
             UndirectedEdge[111, 292] -> 
             RGBColor[
              0.9489243636363636, 0.9614284545454546, 0.971341909090909], 
             UndirectedEdge[48, 122] -> 
             RGBColor[
              0.8477502727272728, 0.8818454545454546, 0.9812604090909091], 
             UndirectedEdge[246, 295] -> 
             RGBColor[
              0.7066202727272727, 0.7664301818181818, 0.9133288636363637], 
             UndirectedEdge[258, 263] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[24, 299] -> 
             RGBColor[
              0.7227151818181818, 0.7814855454545455, 0.9546144999999999], 
             UndirectedEdge[66, 193] -> 
             RGBColor[
              0.5589171818181817, 0.6513373636363635, 0.9591237272727273], 
             UndirectedEdge[29, 199] -> 
             RGBColor[
              0.6577012272727274, 0.7208800909090909, 0.7385495454545452], 
             UndirectedEdge[27, 87] -> 
             RGBColor[
              0.6235080909090909, 0.7017962727272726, 0.9655615454545454], 
             UndirectedEdge[164, 180] -> 
             RGBColor[0.538641, 0.6310319090909091, 0.9589928181818181], 
             UndirectedEdge[106, 200] -> 
             RGBColor[
              0.9558311818181819, 0.8557161818181821, 0.31913031818181814`], 
             UndirectedEdge[69, 285] -> 
             RGBColor[
              0.6559121818181817, 0.7298065454545454, 0.9672388181818181], 
             UndirectedEdge[88, 137] -> 
             RGBColor[
              0.9483216818181817, 0.9563869999999999, 0.7080474545454547], 
             UndirectedEdge[43, 261] -> 
             RGBColor[
              0.9848244545454545, 0.9865277272727273, 0.8355644545454546], 
             UndirectedEdge[224, 253] -> 
             RGBColor[
              0.3333080454545455, 0.4501805000000001, 0.943156409090909], 
             UndirectedEdge[5, 23] -> 
             RGBColor[
              0.5595172272727272, 0.6301234090909091, 0.9598838181818181], 
             UndirectedEdge[42, 162] -> 
             RGBColor[
              0.8831012727272726, 0.9096249999999999, 0.9887121818181819], 
             UndirectedEdge[29, 131] -> 
             RGBColor[
              0.5919755454545454, 0.6730373636363636, 0.9642184545454546], 
             UndirectedEdge[12, 192] -> 
             RGBColor[
              0.6959147272727273, 0.7606839999999999, 0.9717653636363637], 
             UndirectedEdge[69, 76] -> 
             RGBColor[
              0.7302858181818179, 0.7885879999999998, 0.9744711818181818], 
             UndirectedEdge[176, 180] -> 
             RGBColor[
              0.6309981818181818, 0.7040392727272728, 0.9639990454545455], 
             UndirectedEdge[101, 116] -> 
             RGBColor[
              0.9863646363636364, 0.9650431818181817, 0.45456254545454516`], 
             UndirectedEdge[125, 293] -> 
             RGBColor[
              0.8929562272727272, 0.8780139090909089, 0.6524154545454546], 
             UndirectedEdge[30, 300] -> 
             RGBColor[
              0.8831012727272726, 0.9096249999999999, 0.9887121818181819], 
             UndirectedEdge[155, 290] -> 
             RGBColor[
              0.6108301363636363, 0.43128200000000017`, 0.5689565454545454], 
             UndirectedEdge[217, 246] -> 
             RGBColor[
              0.9807917272727272, 0.984860090909091, 0.9023971818181818], 
             UndirectedEdge[42, 82] -> 
             RGBColor[
              0.6655862727272726, 0.7353482727272727, 0.9695750000000001], 
             UndirectedEdge[122, 138] -> 
             RGBColor[
              0.8800457272727272, 0.907074909090909, 0.9844793181818181], 
             UndirectedEdge[58, 160] -> 
             RGBColor[
              0.9375557272727273, 0.7808602727272729, 0.30430131818181816`], 
             UndirectedEdge[158, 225] -> 
             RGBColor[
              0.9017636818181818, 0.5613459090909091, 0.5212223181818182], 
             UndirectedEdge[197, 204] -> 
             RGBColor[0.8154548181818182, 0.856616, 0.9780415], 
             UndirectedEdge[40, 182] -> 
             RGBColor[
              0.9187186363636364, 0.9370021818181817, 0.9566365909090909], 
             UndirectedEdge[1, 149] -> 
             RGBColor[
              0.9935135454545455, 0.9885344545454545, 0.5353676363636359], 
             UndirectedEdge[32, 156] -> 
             RGBColor[
              0.6701944999999999, 0.6977457272727272, 0.6336100909090909], 
             UndirectedEdge[258, 286] -> 
             RGBColor[
              0.8950003181818182, 0.6084846363636367, 0.5674710454545455], 
             UndirectedEdge[101, 197] -> 
             RGBColor[
              0.8421578636363636, 0.8734568181818181, 0.7525919999999997], 
             UndirectedEdge[53, 271] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999998, 0.9867054545454546], 
             UndirectedEdge[22, 70] -> 
             RGBColor[
              0.7092467272727272, 0.7718119999999999, 0.9724644545454546], 
             UndirectedEdge[76, 258] -> 
             RGBColor[
              0.9309408181818181, 0.9472025454545454, 0.9735680454545454], 
             UndirectedEdge[232, 297] -> 
             RGBColor[
              0.6445471818181818, 0.7185722727272726, 0.9675682727272727], 
             UndirectedEdge[178, 261] -> 
             RGBColor[
              0.7659031818181817, 0.8159651818181818, 0.9423955909090909], 
             UndirectedEdge[155, 227] -> 
             RGBColor[
              0.8546309545454545, 0.628326181818182, 0.5897686363636364], 
             UndirectedEdge[178, 182] -> 
             RGBColor[
              0.7092467272727272, 0.7718119999999999, 0.9724644545454546], 
             UndirectedEdge[5, 51] -> 
             RGBColor[
              0.9577412727272727, 0.968004090909091, 0.9564171818181818], 
             UndirectedEdge[110, 295] -> 
             RGBColor[
              0.7031239545454545, 0.7429237272727272, 0.6610942727272726], 
             UndirectedEdge[186, 286] -> 
             RGBColor[
              0.9038172272727274, 0.6150602727272731, 0.5525463181818182], 
             UndirectedEdge[34, 270] -> 
             RGBColor[
              0.9665581818181819, 0.9745797272727272, 0.9414924545454546], 
             UndirectedEdge[4, 8] -> 
             RGBColor[
              0.9401074545454545, 0.9548528181818182, 0.9862666363636363], 
             UndirectedEdge[69, 166] -> 
             RGBColor[
              0.7095009545454545, 0.5598110909090908, 0.5826306818181818], 
             UndirectedEdge[25, 176] -> 
             RGBColor[
              0.7826404545454546, 0.8307179090909091, 0.9749508636363635], 
             UndirectedEdge[32, 149] -> 
             RGBColor[
              0.9797210000000001, 0.9426326363636364, 0.4287532727272725], 
             UndirectedEdge[16, 153] -> 
             RGBColor[
              0.8256444090909092, 0.7145033636363638, 0.6055496818181818], 
             UndirectedEdge[169, 299] -> 
             RGBColor[
              0.6751298636363636, 0.5319070909090908, 0.5799248636363636], 
             UndirectedEdge[187, 229] -> 
             RGBColor[0.9668105, 0.9716936363636364, 0.7608171363636361], 
             UndirectedEdge[15, 82] -> 
             RGBColor[0.6448014090909091, 0.5065713636363635, 0.5777345], 
             UndirectedEdge[44, 280] -> 
             RGBColor[
              0.8653840909090909, 0.8949967272727273, 0.9514109545454545], 
             UndirectedEdge[186, 265] -> 
             RGBColor[
              0.8653840909090909, 0.8949967272727273, 0.9514109545454545], 
             UndirectedEdge[117, 265] -> 
             RGBColor[
              0.7553930909090909, 0.8088380909090909, 0.9762541818181818], 
             UndirectedEdge[106, 162] -> 
             RGBColor[
              0.8972544090909091, 0.8313647272727276, 0.6256043181818183], 
             UndirectedEdge[9, 146] -> 
             RGBColor[
              0.5919755454545454, 0.6730373636363636, 0.9642184545454546], 
             UndirectedEdge[130, 294] -> 
             RGBColor[
              0.9772954090909091, 0.9613536363636364, 0.6501625909090909], 
             UndirectedEdge[13, 53] -> 
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692], 
             UndirectedEdge[34, 57] -> 
             RGBColor[
              0.9450939545454546, 0.8689422727272731, 0.6104601818181818], 
             UndirectedEdge[25, 144] -> 
             RGBColor[0.7225787272727273, 0.78294, 0.9731635454545454], 
             UndirectedEdge[206, 283] -> 
             RGBColor[
              0.9844443181818182, 0.984844909090909, 0.7309676818181816], 
             UndirectedEdge[107, 273] -> 
             RGBColor[
              0.9673157727272728, 0.9727743636363637, 0.8158129545454547], 
             UndirectedEdge[64, 85] -> 
             RGBColor[
              0.5972222727272726, 0.679028818181818, 0.9638866363636364], 
             UndirectedEdge[175, 224] -> 
             RGBColor[0.585715, 0.6458835, 0.6794385000000003], 
             UndirectedEdge[68, 163] -> 
             RGBColor[
              0.36767913636363625`, 0.4780844999999999, 0.9458622272727273], 
             UndirectedEdge[7, 237] -> 
             RGBColor[
              0.8888626363636363, 0.9136505454545454, 0.9695545909090909], 
             UndirectedEdge[76, 126] -> 
             RGBColor[
              0.9041403636363634, 0.9264009999999998, 0.9907189090909091], 
             UndirectedEdge[30, 236] -> 
             RGBColor[0.6748756363636363, 0.743908, 0.9697586363636364], 
             UndirectedEdge[7, 269] -> 
             RGBColor[
              0.8800457272727272, 0.907074909090909, 0.9844793181818181], 
             UndirectedEdge[237, 256] -> 
             RGBColor[
              0.5683341363636364, 0.6366990454545455, 0.9449590909090909], 
             UndirectedEdge[106, 290] -> 
             RGBColor[
              0.6534535909090909, 0.6343205454545457, 0.6047922272727273], 
             UndirectedEdge[180, 288] -> 
             RGBColor[
              0.27401140909090904`, 0.40411859090909086`, 0.9389604090909092],
              UndirectedEdge[201, 237] -> 
             RGBColor[
              0.7570862727272727, 0.8093895454545454, 0.9573203181818182], 
             UndirectedEdge[10, 73] -> 
             RGBColor[
              0.8888626363636363, 0.9136505454545454, 0.9695545909090909], 
             UndirectedEdge[18, 175] -> 
             RGBColor[
              0.7097675909090909, 0.7653342727272727, 0.6869035454545457], 
             UndirectedEdge[57, 295] -> 
             RGBColor[
              0.6797394090909092, 0.6570880000000003, 0.6064671363636365], 
             UndirectedEdge[71, 161] -> 
             RGBColor[
              0.8976795454545454, 0.9202261818181818, 0.9546298636363637], 
             UndirectedEdge[218, 220] -> 
             RGBColor[
              0.7753525454545453, 0.8213375454545454, 0.8513923181818183], 
             UndirectedEdge[192, 248] -> 
             RGBColor[
              0.7406013181818183, 0.7917507272727273, 0.744089727272727], 
             UndirectedEdge[23, 24] -> 
             RGBColor[
              0.5683341363636363, 0.6366990454545454, 0.9449590909090909], 
             UndirectedEdge[39, 195] -> 
             RGBColor[
              0.9241352727272727, 0.940706909090909, 0.9324660454545455], 
             UndirectedEdge[79, 232] -> 
             RGBColor[
              0.6923867272727273, 0.7561498181818181, 0.9524241363636363], 
             UndirectedEdge[12, 154] -> 
             RGBColor[
              0.9492070909090908, 0.9591505454545454, 0.8676400454545455], 
             UndirectedEdge[106, 155] -> 
             RGBColor[
              0.8898231818181819, 0.5668419090909097, 0.22866750000000008`], 
             UndirectedEdge[95, 103] -> 
             RGBColor[
              0.9719748181818182, 0.9782844545454545, 0.917321909090909], 
             UndirectedEdge[3, 228] -> 
             RGBColor[
              0.9277878636363637, 0.9406917272727272, 0.7610365454545452], 
             UndirectedEdge[81, 293] -> 
             RGBColor[
              0.9072540454545455, 0.9249964545454545, 0.8140256363636366], 
             UndirectedEdge[95, 145] -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909092], 
             UndirectedEdge[39, 153] -> 
             RGBColor[
              0.8087276363636363, 0.8508435454545453, 0.9814798181818182], 
             UndirectedEdge[39, 90] -> 
             RGBColor[
              0.9261516363636363, 0.9415407272727272, 0.8990496818181819], 
             UndirectedEdge[120, 141] -> 
             RGBColor[0.867304409090909, 0.875195, 0.6750058181818182], 
             UndirectedEdge[102, 172] -> 
             RGBColor[
              0.8477502727272728, 0.8818454545454546, 0.9812604090909091], 
             UndirectedEdge[155, 194] -> 
             RGBColor[
              0.9112874090909091, 0.672479363636364, 0.5596997727272728], 
             UndirectedEdge[53, 251] -> 
             RGBColor[
              0.8976795454545454, 0.9202261818181818, 0.9546298636363637], 
             UndirectedEdge[128, 243] -> 
             RGBColor[
              0.9760075454545454, 0.9799520909090909, 0.8504891818181819], 
             UndirectedEdge[72, 87] -> 
             RGBColor[
              0.6614639545454546, 0.582232090909091, 0.5916381363636365], 
             UndirectedEdge[76, 90] -> 
             RGBColor[
              0.9471907272727271, 0.9583167272727272, 0.9010564090909092], 
             UndirectedEdge[3, 106] -> 
             RGBColor[
              0.9629800909090911, 0.8792074545454549, 0.39993540909090897`], 
             UndirectedEdge[104, 243] -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909092], 
             UndirectedEdge[34, 217] -> 
             RGBColor[
              0.9665581818181819, 0.9745797272727272, 0.9414924545454546], 
             UndirectedEdge[31, 37] -> 
             RGBColor[
              0.9634853636363637, 0.8802881818181821, 0.4549312272727275], 
             UndirectedEdge[64, 249] -> 
             RGBColor[
              0.5972222727272726, 0.679028818181818, 0.9638866363636364], 
             UndirectedEdge[89, 188] -> 
             RGBColor[
              0.5589171818181817, 0.6513373636363635, 0.9591237272727273], 
             UndirectedEdge[179, 269] -> 
             RGBColor[
              0.6309981818181818, 0.7040392727272728, 0.9639990454545455], 
             UndirectedEdge[213, 249] -> 
             RGBColor[
              0.8410230909090908, 0.8760729999999999, 0.9846987272727272], 
             UndirectedEdge[44, 252] -> 
             RGBColor[
              0.8739480454545454, 0.8976055454545455, 0.7008150909090911], 
             UndirectedEdge[149, 198] -> 
             RGBColor[
              0.9918773181818181, 0.9893834545454545, 0.6733807727272726], 
             UndirectedEdge[158, 214] -> 
             RGBColor[
              0.848276090909091, 0.3393174545454547, 0.19257977272727275`], 
             UndirectedEdge[202, 216] -> 
             RGBColor[
              0.8087276363636363, 0.8508435454545453, 0.9814798181818182], 
             UndirectedEdge[78, 209] -> 
             RGBColor[
              0.9309408181818181, 0.9472025454545454, 0.9735680454545454], 
             UndirectedEdge[77, 265] -> 
             RGBColor[
              0.8089818636363636, 0.6388426363636361, 0.5916460454545454], 
             UndirectedEdge[44, 204] -> 
             RGBColor[
              0.8477502727272728, 0.8818454545454546, 0.9812604090909091], 
             UndirectedEdge[54, 102] -> 
             RGBColor[
              0.8173131363636363, 0.6766730000000001, 0.5985978636363637], 
             UndirectedEdge[2, 253] -> 
             RGBColor[
              0.7400960454545455, 0.7906700000000001, 0.6890939090909092], 
             UndirectedEdge[40, 86] -> 
             RGBColor[
              0.7012036363636364, 0.7627254545454545, 0.9374994090909091], 
             UndirectedEdge[75, 165] -> 
             RGBColor[
              0.9041403636363634, 0.9264009999999998, 0.9907189090909091], 
             UndirectedEdge[73, 100] -> 
             RGBColor[
              0.7553930909090909, 0.8088380909090909, 0.9762541818181818], 
             UndirectedEdge[50, 206] -> 
             RGBColor[
              0.9839390454545455, 0.9837641818181819, 0.6759718636363639], 
             UndirectedEdge[32, 277] -> 
             RGBColor[
              0.9706517727272728, 0.9389430909090909, 0.6243533181818182], 
             UndirectedEdge[156, 251] -> 
             RGBColor[
              0.6749178181818181, 0.7399579999999999, 0.9358245000000001], 
             UndirectedEdge[31, 44] -> 
             RGBColor[0.8749585909090909, 0.899767, 0.8108067272727275], 
             UndirectedEdge[80, 92] -> 
             RGBColor[
              0.8888626363636363, 0.9136505454545454, 0.9695545909090909], 
             UndirectedEdge[11, 149] -> 
             RGBColor[
              0.8421578636363636, 0.8734568181818181, 0.7525919999999997], 
             UndirectedEdge[103, 145] -> 
             RGBColor[
              0.9760075454545454, 0.9799520909090909, 0.8504891818181819], 
             UndirectedEdge[150, 274] -> 
             RGBColor[
              0.6067241363636363, 0.6797408636363635, 0.9625721818181818], 
             UndirectedEdge[13, 156] -> 
             RGBColor[
              0.5972222727272726, 0.679028818181818, 0.9638866363636364], 
             UndirectedEdge[84, 278] -> 
             RGBColor[
              0.9849495909090908, 0.9859256363636364, 0.7859635000000003], 
             UndirectedEdge[150, 293] -> 
             RGBColor[
              0.8800457272727272, 0.907074909090909, 0.9844793181818181], 
             UndirectedEdge[52, 137] -> 
             RGBColor[
              0.9751221363636364, 0.9771885454545455, 0.6908965909090911], 
             UndirectedEdge[41, 152] -> 
             RGBColor[
              0.9397577272727271, 0.9537781818181817, 0.9586433181818181], 
             UndirectedEdge[177, 279] -> 
             RGBColor[0.8749585909090909, 0.899767, 0.8108067272727275], 
             UndirectedEdge[108, 279] -> 
             RGBColor[
              0.8087276363636363, 0.8508435454545453, 0.9814798181818182], 
             UndirectedEdge[161, 279] -> 
             RGBColor[
              0.7876885454545455, 0.8340675454545454, 0.979473090909091], 
             UndirectedEdge[89, 260] -> 
             RGBColor[
              0.6579878181818182, 0.7324810909090909, 0.9667257272727272], 
             UndirectedEdge[63, 161] -> 
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692], 
             UndirectedEdge[110, 148] -> 
             RGBColor[
              0.7031239545454545, 0.7429237272727272, 0.6610942727272726], 
             UndirectedEdge[200, 228] -> 
             RGBColor[
              0.9206389545454545, 0.9172004545454544, 0.6802314545454544], 
             UndirectedEdge[67, 118] -> 
             RGBColor[
              0.9206389545454545, 0.9172004545454544, 0.6802314545454544], 
             UndirectedEdge[140, 203] -> 
             RGBColor[
              0.7444389545454546, 0.7103277272727275, 0.6113633181818182], 
             UndirectedEdge[144, 231] -> 
             RGBColor[
              0.8976795454545454, 0.9202261818181818, 0.9546298636363637], 
             UndirectedEdge[101, 149] -> 
             RGBColor[
              0.9935135454545455, 0.9885344545454545, 0.5353676363636359], 
             UndirectedEdge[131, 284] -> 
             RGBColor[0.9272825909090909, 0.939611, 0.7060407272727275], 
             UndirectedEdge[157, 275] -> 
             RGBColor[
              0.9756274090909092, 0.9782692727272727, 0.7458924090909089], 
             UndirectedEdge[113, 144] -> 
             RGBColor[
              0.8668087727272727, 0.7772949090909091, 0.6160288636363637], 
             UndirectedEdge[48, 73] -> 
             RGBColor[
              0.7876885454545455, 0.8340675454545454, 0.979473090909091], 
             UndirectedEdge[35, 183] -> 
             RGBColor[0.9272825909090909, 0.939611, 0.7060407272727274], 
             UndirectedEdge[93, 107] -> 
             RGBColor[
              0.9923825909090909, 0.9904641818181819, 0.7283765909090911], 
             UndirectedEdge[23, 226] -> 
             RGBColor[
              0.5595172272727273, 0.6301234090909091, 0.9598838181818181], 
             UndirectedEdge[200, 211] -> 
             RGBColor[
              0.9206389545454545, 0.9172004545454544, 0.6802314545454544], 
             UndirectedEdge[87, 227] -> 
             RGBColor[
              0.6445471818181818, 0.7185722727272726, 0.9675682727272727], 
             UndirectedEdge[223, 278] -> 
             RGBColor[
              0.986869909090909, 0.9661239090909091, 0.5095583636363638], 
             UndirectedEdge[182, 229] -> 
             RGBColor[
              0.9010848181818181, 0.9238509090909091, 0.9864860454545454], 
             UndirectedEdge[79, 221] -> 
             RGBColor[
              0.8950003181818182, 0.6084846363636367, 0.5674710454545455], 
             UndirectedEdge[115, 228] -> 
             RGBColor[
              0.9281679999999999, 0.9423745454545454, 0.8656333181818183], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.9000180454545454, 0.7732848181818182, 0.6127820454545455], 
             UndirectedEdge[9, 47] -> 
             RGBColor[
              0.6088923181818182, 0.536697181818182, 0.5882883181818183], 
             UndirectedEdge[18, 224] -> 
             RGBColor[
              0.3029795909090909, 0.4248447727272727, 0.9409660454545454], 
             UndirectedEdge[194, 291] -> 
             RGBColor[
              0.9828080909090908, 0.9856939090909091, 0.8689808181818183], 
             UndirectedEdge[5, 198] -> 
             RGBColor[
              0.9651742727272727, 0.9725426363636365, 0.8988302727272728], 
             UndirectedEdge[49, 172] -> 
             RGBColor[
              0.8800457272727272, 0.907074909090909, 0.9844793181818181], 
             UndirectedEdge[162, 228] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             UndirectedEdge[100, 161] -> 
             RGBColor[
              0.7553930909090909, 0.8088380909090909, 0.9762541818181818], 
             UndirectedEdge[174, 235] -> 
             RGBColor[0.9062435, 0.922835, 0.7040340000000002], 
             UndirectedEdge[14, 67] -> 
             RGBColor[
              0.8350089545454544, 0.8499655454545454, 0.671786909090909], 
             UndirectedEdge[190, 199] -> 
             RGBColor[
              0.8421578636363636, 0.8734568181818181, 0.7525919999999997], 
             UndirectedEdge[160, 288] -> 
             RGBColor[
              0.5610148181818182, 0.4875900454545455, 0.5855172727272728], 
             UndirectedEdge[33, 275] -> 
             RGBColor[
              0.9863646363636364, 0.9650431818181817, 0.45456254545454516`], 
             UndirectedEdge[109, 218] -> 
             RGBColor[
              0.4917317272727272, 0.5975352727272727, 0.9533272727272728], 
             UndirectedEdge[231, 264] -> 
             RGBColor[
              0.9753750909090909, 0.9811553636363637, 0.9265677272727273], 
             UndirectedEdge[221, 230] -> 
             RGBColor[
              0.8950003181818182, 0.6084846363636367, 0.5674710454545455], 
             UndirectedEdge[45, 236] -> 
             RGBColor[0.621541090909091, 0.7019025454545456, 0.964533], 
             UndirectedEdge[279, 280] -> 
             RGBColor[
              0.8653840909090909, 0.8949967272727273, 0.9514109545454545], 
             UndirectedEdge[71, 252] -> 
             RGBColor[
              0.9839390454545455, 0.9837641818181819, 0.6759718636363639], 
             UndirectedEdge[230, 296] -> 
             RGBColor[
              0.7227151818181818, 0.7814855454545455, 0.9546144999999999], 
             UndirectedEdge[27, 154] -> 
             RGBColor[
              0.907128909090909, 0.9255985454545455, 0.863626590909091], 
             UndirectedEdge[5, 101] -> 
             RGBColor[0.9668105, 0.9716936363636364, 0.7608171363636361], 
             UndirectedEdge[68, 143] -> 
             RGBColor[
              0.43486459090909085`, 0.5318865909090909, 0.9516586818181818], 
             UndirectedEdge[58, 221] -> 
             RGBColor[
              0.9057375454545455, 0.5952585454545458, 0.2761411818181818], 
             UndirectedEdge[85, 249] -> 
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692], 
             UndirectedEdge[26, 54] -> 
             RGBColor[
              0.8496085909090909, 0.7019024545454546, 0.6018167727272727], 
             UndirectedEdge[269, 282] -> 
             RGBColor[0.8154548181818182, 0.856616, 0.9780415], 
             UndirectedEdge[24, 210] -> 
             RGBColor[
              0.9489243636363636, 0.9614284545454546, 0.971341909090909], 
             UndirectedEdge[144, 288] -> 
             RGBColor[
              0.5230589545454545, 0.607154227272727, 0.9594406818181818], 
             UndirectedEdge[182, 199] -> 
             RGBColor[
              0.9277878636363637, 0.9406917272727272, 0.7610365454545452], 
             UndirectedEdge[35, 224] -> 
             RGBColor[0.585715, 0.6458835, 0.6794385000000003], 
             UndirectedEdge[161, 280] -> 
             RGBColor[
              0.8976795454545454, 0.9202261818181818, 0.9546298636363637], 
             UndirectedEdge[27, 42] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999998, 0.9867054545454546], 
             UndirectedEdge[13, 273] -> 
             RGBColor[
              0.8800457272727272, 0.907074909090909, 0.9844793181818181], 
             UndirectedEdge[167, 202] -> 
             RGBColor[
              0.6902832727272727, 0.7577105454545454, 0.9699446363636364], 
             UndirectedEdge[117, 207] -> 
             RGBColor[
              0.5912126363636363, 0.6765668181818181, 0.9623426363636364], 
             UndirectedEdge[33, 248] -> 
             RGBColor[
              0.9863646363636364, 0.9650431818181817, 0.45456254545454516`], 
             UndirectedEdge[23, 210] -> 
             RGBColor[
              0.5595172272727273, 0.6301234090909091, 0.9598838181818181], 
             UndirectedEdge[54, 111] -> 
             RGBColor[
              0.9184872272727274, 0.7562560000000002, 0.5886793636363636], 
             UndirectedEdge[30, 267] -> 
             RGBColor[
              0.9187186363636364, 0.9370021818181817, 0.9566365909090909], 
             UndirectedEdge[170, 199] -> 
             RGBColor[
              0.9756274090909092, 0.9782692727272727, 0.7458924090909089], 
             UndirectedEdge[169, 200] -> 
             RGBColor[
              0.9208931818181818, 0.7051995454545452, 0.2903976818181817], 
             UndirectedEdge[137, 278] -> 
             RGBColor[
              0.9935135454545454, 0.9885344545454546, 0.5353676363636367], 
             UndirectedEdge[92, 150] -> 
             RGBColor[
              0.8800457272727272, 0.907074909090909, 0.9844793181818181], 
             UndirectedEdge[68, 185] -> 
             RGBColor[0.4994555, 0.5823455, 0.9580965], 
             UndirectedEdge[26, 102] -> 
             RGBColor[
              0.7876885454545455, 0.8340675454545454, 0.979473090909091], 
             UndirectedEdge[270, 271] -> 
             RGBColor[
              0.9397577272727271, 0.9537781818181817, 0.9586433181818181], 
             UndirectedEdge[169, 202] -> 
             RGBColor[
              0.8089818636363636, 0.6388426363636361, 0.5916460454545454], 
             UndirectedEdge[17, 97] -> 
             RGBColor[
              0.9493322272727271, 0.9585484545454545, 0.8180390909090911], 
             UndirectedEdge[46, 158] -> 
             RGBColor[
              0.8963470454545455, 0.5576411818181819, 0.5453928636363636], 
             UndirectedEdge[98, 285] -> 
             RGBColor[
              0.8606607727272727, 0.8527844545454545, 0.6491965454545454], 
             UndirectedEdge[77, 168] -> 
             RGBColor[
              0.8833554999999998, 0.6976240909090907, 0.5988784090909091], 
             UndirectedEdge[242, 268] -> 
             RGBColor[
              0.7850176818181818, 0.6514435454545455, 0.5953789545454545], 
             UndirectedEdge[115, 134] -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909092], 
             UndirectedEdge[99, 284] -> 
             RGBColor[
              0.9858593636363636, 0.9639624545454546, 0.39956672727272735`], 
             UndirectedEdge[204, 283] -> 
             RGBColor[0.9668105, 0.9716936363636364, 0.7608171363636361], 
             UndirectedEdge[77, 167] -> 
             RGBColor[
              0.7438720454545454, 0.5877150909090908, 0.5853364999999999], 
             UndirectedEdge[227, 290] -> 
             RGBColor[
              0.6182613636363635, 0.695804818181818, 0.9658933636363636], 
             UndirectedEdge[60, 145] -> 
             RGBColor[
              0.7409814545454546, 0.7934335454545456, 0.8486865000000001], 
             UndirectedEdge[32, 125] -> 
             RGBColor[
              0.9659284545454545, 0.8967308181818181, 0.32213890909090903`], 
             UndirectedEdge[15, 60] -> 
             RGBColor[
              0.6751298636363636, 0.5319070909090908, 0.5799248636363636], 
             UndirectedEdge[30, 260] -> 
             RGBColor[0.7436178181818182, 0.799716, 0.9751702727272726], 
             UndirectedEdge[42, 80] -> 
             RGBColor[
              0.9309408181818181, 0.9472025454545454, 0.9735680454545454], 
             UndirectedEdge[97, 130] -> 
             RGBColor[
              0.9397577272727271, 0.9537781818181817, 0.9586433181818181], 
             UndirectedEdge[65, 211] -> 
             RGBColor[
              0.9282931363636363, 0.9417724545454544, 0.8160323636363638], 
             UndirectedEdge[1, 256] -> 
             RGBColor[
              0.5862202727272727, 0.6469642272727273, 0.734434318181818], 
             UndirectedEdge[5, 128] -> 
             RGBColor[
              0.9489243636363636, 0.9614284545454546, 0.971341909090909], 
             UndirectedEdge[125, 256] -> 
             RGBColor[
              0.5724277272727273, 0.601062409090909, 0.6278199545454546], 
             UndirectedEdge[39, 239] -> 
             RGBColor[
              0.9010848181818181, 0.9238509090909091, 0.9864860454545454], 
             UndirectedEdge[156, 269] -> 
             RGBColor[0.657284, 0.7268067272727272, 0.9656739545454545], 
             UndirectedEdge[78, 170] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[23, 155] -> 
             RGBColor[
              0.5130633636363637, 0.3345986818181821, 0.5631664090909092], 
             UndirectedEdge[127, 251] -> 
             RGBColor[
              0.9187186363636364, 0.9370021818181817, 0.9566365909090909], 
             UndirectedEdge[241, 290] -> 
             RGBColor[0.32390068181818166`, 0.4516947727272726, 0.9419795], 
             UndirectedEdge[85, 234] -> 
             RGBColor[
              0.5230589545454545, 0.607154227272727, 0.9594406818181818], 
             UndirectedEdge[270, 289] -> 
             RGBColor[
              0.9839390454545455, 0.9837641818181819, 0.6759718636363639], 
             UndirectedEdge[69, 258] -> 
             RGBColor[
              0.7570862727272727, 0.8093895454545454, 0.9573203181818182], 
             UndirectedEdge[52, 289] -> 
             RGBColor[
              0.9751221363636364, 0.9771885454545455, 0.6908965909090911], 
             UndirectedEdge[47, 170] -> 
             RGBColor[0.9268185, 0.7940863636363638, 0.5956311818181819], 
             UndirectedEdge[72, 241] -> 
             RGBColor[
              0.5846182727272727, 0.5123987727272727, 0.5868614545454547], 
             UndirectedEdge[115, 210] -> 
             RGBColor[
              0.9671906363636363, 0.9733764545454546, 0.8654139090909092], 
             UndirectedEdge[166, 239] -> 
             RGBColor[
              0.9013390454545454, 0.7118499999999999, 0.5966522727272727], 
             UndirectedEdge[180, 215] -> 
             RGBColor[
              0.6505523181818182, 0.6973888181818182, 0.6577444545454545], 
             UndirectedEdge[51, 254] -> 
             RGBColor[
              0.9577412727272727, 0.968004090909091, 0.9564171818181818], 
             UndirectedEdge[109, 227] -> 
             RGBColor[
              0.6445471818181818, 0.7185722727272726, 0.9675682727272727], 
             UndirectedEdge[203, 255] -> 
             RGBColor[
              0.8823530000000002, 0.5094228181818188, 0.22151404545454556`], 
             UndirectedEdge[257, 272] -> 
             RGBColor[
              0.8916237272727272, 0.515428909090909, 0.2431784545454545], 
             UndirectedEdge[32, 128] -> 
             RGBColor[
              0.9618348636363636, 0.9323674545454546, 0.6392780454545455], 
             UndirectedEdge[39, 76] -> 
             RGBColor[
              0.8831012727272726, 0.9096249999999999, 0.9887121818181819], 
             UndirectedEdge[144, 221] -> 
             RGBColor[
              0.8261216818181818, 0.5541310909090912, 0.5806084545454546], 
             UndirectedEdge[165, 262] -> 
             RGBColor[
              0.7974712727272726, 0.8423900909090908, 0.9802676363636363], 
             UndirectedEdge[101, 226] -> 
             RGBColor[0.9668105, 0.9716936363636364, 0.7608171363636361], 
             UndirectedEdge[56, 191] -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909092], 
             UndirectedEdge[63, 71] -> 
             RGBColor[
              0.8976795454545454, 0.9202261818181818, 0.9546298636363637], 
             UndirectedEdge[137, 289] -> 
             RGBColor[0.992503, 0.986373, 0.42537600000000036`], 
             UndirectedEdge[148, 295] -> 
             RGBColor[
              0.4270321818181818, 0.5442955454545454, 0.948431090909091], 
             UndirectedEdge[10, 119] -> 
             RGBColor[0.9684785, 0.9547779999999999, 0.6650873181818181], 
             UndirectedEdge[115, 231] -> 
             RGBColor[
              0.9848244545454545, 0.9865277272727273, 0.8355644545454546], 
             UndirectedEdge[33, 171] -> 
             RGBColor[
              0.986869909090909, 0.9661239090909091, 0.5095583636363638], 
             UndirectedEdge[173, 234] -> 
             RGBColor[
              0.5960311818181817, 0.6258711363636362, 0.6291641363636363], 
             UndirectedEdge[69, 173] -> 
             RGBColor[
              0.7611798636363636, 0.773752909090909, 0.6401811818181817], 
             UndirectedEdge[4, 263] -> 
             RGBColor[0.8154548181818182, 0.856616, 0.9780415], 
             UndirectedEdge[134, 160] -> 
             RGBColor[
              0.9410520454545455, 0.8043667272727274, 0.5565359090909091], 
             UndirectedEdge[7, 205] -> 
             RGBColor[
              0.8496085909090909, 0.7019024545454546, 0.6018167727272727], 
             UndirectedEdge[23, 106] -> 
             RGBColor[
              0.5556868181818182, 0.5376372272727276, 0.599002090909091], 
             UndirectedEdge[45, 96] -> 
             RGBColor[
              0.8653840909090909, 0.8949967272727273, 0.9514109545454545], 
             UndirectedEdge[65, 210] -> 
             RGBColor[
              0.9673157727272728, 0.9727743636363637, 0.8158129545454547], 
             UndirectedEdge[138, 211] -> 
             RGBColor[
              0.8410230909090908, 0.8760729999999999, 0.9846987272727272], 
             UndirectedEdge[72, 210] -> 
             RGBColor[
              0.918001590909091, 0.7875107272727274, 0.6105559090909092], 
             UndirectedEdge[37, 41] -> 
             RGBColor[
              0.9539108636363638, 0.8755179090909094, 0.5955354545454545], 
             UndirectedEdge[52, 88] -> 
             RGBColor[
              0.9309408181818181, 0.9472025454545454, 0.9735680454545454], 
             UndirectedEdge[157, 285] -> 
             RGBColor[
              0.8565671818181818, 0.8884210909090908, 0.9663356818181819], 
             UndirectedEdge[135, 265] -> 
             RGBColor[
              0.7230976363636363, 0.7836086363636363, 0.9730352727272726], 
             UndirectedEdge[17, 42] -> 
             RGBColor[
              0.9493322272727271, 0.9585484545454545, 0.8180390909090911], 
             UndirectedEdge[242, 250] -> 
             RGBColor[
              0.6834611363636365, 0.5697374545454548, 0.5868766818181819], 
             UndirectedEdge[81, 202] -> 
             RGBColor[0.8749585909090909, 0.899767, 0.8108067272727275], 
             UndirectedEdge[229, 259] -> 
             RGBColor[
              0.9489243636363636, 0.9614284545454546, 0.971341909090909], 
             UndirectedEdge[40, 81] -> 
             RGBColor[
              0.9849495909090908, 0.9859256363636364, 0.7859635000000003], 
             UndirectedEdge[100, 119] -> 
             RGBColor[
              0.8350089545454544, 0.8499655454545454, 0.671786909090909], 
             UndirectedEdge[81, 269] -> 
             RGBColor[
              0.9673157727272728, 0.9727743636363637, 0.8158129545454547], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.9756274090909092, 0.9782692727272727, 0.7458924090909089], 
             UndirectedEdge[180, 233] -> 
             RGBColor[
              0.3744605454545455, 0.4987606363636364, 0.9450812727272728], 
             UndirectedEdge[33, 184] -> 
             RGBColor[
              0.7334524090909091, 0.7682594545454546, 0.6632846363636362], 
             UndirectedEdge[103, 168] -> 
             RGBColor[
              0.9309408181818181, 0.9472025454545454, 0.9735680454545454], 
             UndirectedEdge[49, 238] -> 
             RGBColor[
              0.8762153181818182, 0.8145887272727275, 0.623597590909091], 
             UndirectedEdge[97, 120] -> 
             RGBColor[
              0.8297667272727272, 0.8676195454545453, 0.9834865454545454], 
             UndirectedEdge[117, 212] -> 
             RGBColor[
              0.4907634999999999, 0.5819247727272726, 0.9562217727272727], 
             UndirectedEdge[270, 278] -> 
             RGBColor[
              0.9849495909090908, 0.9859256363636364, 0.7859635000000003], 
             UndirectedEdge[26, 165] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999998, 0.9867054545454546], 
             UndirectedEdge[65, 70] -> 
             RGBColor[
              0.9282931363636363, 0.9417724545454544, 0.8160323636363638], 
             UndirectedEdge[56, 223] -> 
             RGBColor[
              0.9827120454545454, 0.9650583636363637, 0.6259920454545453], 
             UndirectedEdge[207, 212] -> 
             RGBColor[
              0.32658304545454536`, 0.4496534999999999, 0.9423102272727273], 
             UndirectedEdge[171, 184] -> 
             RGBColor[
              0.741106590909091, 0.7928314545454547, 0.7990855454545456], 
             UndirectedEdge[32, 205] -> 
             RGBColor[
              0.9225808181818183, 0.7206193636363638, 0.27154022727272725`], 
             UndirectedEdge[23, 31] -> 
             RGBColor[
              0.5867255454545455, 0.6480449545454545, 0.7894301363636366], 
             UndirectedEdge[235, 274] -> 
             RGBColor[
              0.6329219090909091, 0.6955009545454545, 0.6821268636363638], 
             UndirectedEdge[178, 199] -> 
             RGBColor[
              0.774972409090909, 0.8196547272727273, 0.7467955454545452], 
             UndirectedEdge[117, 158] -> 
             RGBColor[
              0.7863560454545455, 0.47148254545454543`, 0.5702360909090909], 
             UndirectedEdge[112, 190] -> 
             RGBColor[
              0.43486459090909085`, 0.5318865909090909, 0.9516586818181818], 
             UndirectedEdge[64, 213] -> 
             RGBColor[
              0.6182613636363635, 0.695804818181818, 0.9658933636363636], 
             UndirectedEdge[127, 205] -> 
             RGBColor[
              0.8706476818181819, 0.7186784545454546, 0.6038235000000001], 
             UndirectedEdge[121, 263] -> 
             RGBColor[
              0.7974712727272726, 0.8423900909090908, 0.9802676363636363], 
             UndirectedEdge[14, 213] -> 
             RGBColor[
              0.7764321818181817, 0.8256140909090908, 0.9782609090909091], 
             UndirectedEdge[109, 111] -> 
             RGBColor[
              0.6923867272727273, 0.7561498181818181, 0.9524241363636363], 
             UndirectedEdge[55, 108] -> 
             RGBColor[
              0.9187186363636364, 0.9370021818181817, 0.9566365909090909], 
             UndirectedEdge[40, 162] -> 
             RGBColor[
              0.9187186363636364, 0.9370021818181817, 0.9566365909090909], 
             UndirectedEdge[15, 225] -> 
             RGBColor[0.9243895, 0.7287059999999999, 0.5426322727272728], 
             UndirectedEdge[31, 59] -> 
             RGBColor[
              0.741106590909091, 0.7928314545454547, 0.7990855454545456], 
             UndirectedEdge[210, 227] -> 
             RGBColor[
              0.9010848181818181, 0.9238509090909091, 0.9864860454545454], 
             UndirectedEdge[52, 93] -> 
             RGBColor[
              0.9739911818181818, 0.9791182727272727, 0.8839055454545455], 
             UndirectedEdge[32, 293] -> 
             RGBColor[
              0.8929562272727272, 0.8780139090909089, 0.6524154545454546], 
             UndirectedEdge[99, 209] -> 
             RGBColor[
              0.9416780454545453, 0.9339764545454544, 0.6822381818181817], 
             UndirectedEdge[201, 299] -> 
             RGBColor[0.5220601818181818, 0.622871, 0.9555176363636364], 
             UndirectedEdge[127, 148] -> 
             RGBColor[
              0.6445471818181818, 0.7185722727272726, 0.9675682727272727], 
             UndirectedEdge[24, 226] -> 
             RGBColor[
              0.9489243636363636, 0.9614284545454546, 0.971341909090909], 
             UndirectedEdge[144, 264] -> 
             RGBColor[
              0.8976795454545454, 0.9202261818181818, 0.9546298636363637], 
             UndirectedEdge[148, 217] -> 
             RGBColor[
              0.7012036363636364, 0.7627254545454545, 0.9374994090909091], 
             UndirectedEdge[230, 288] -> 
             RGBColor[
              0.5919375909090908, 0.6615077727272727, 0.9463032727272727], 
             UndirectedEdge[1, 83] -> 
             RGBColor[
              0.9756274090909092, 0.9782692727272727, 0.7458924090909089], 
             UndirectedEdge[15, 214] -> 
             RGBColor[
              0.8709019090909091, 0.5066775454545455, 0.21398972727272725`], 
             UndirectedEdge[173, 249] -> 
             RGBColor[
              0.8929562272727272, 0.8780139090909089, 0.6524154545454546], 
             UndirectedEdge[114, 204] -> 
             RGBColor[
              0.9010848181818181, 0.9238509090909091, 0.9864860454545454], 
             UndirectedEdge[77, 95] -> 
             RGBColor[0.9243895, 0.7287059999999999, 0.5426322727272728], 
             UndirectedEdge[52, 295] -> 
             RGBColor[
              0.6923867272727273, 0.7561498181818181, 0.9524241363636363], 
             UndirectedEdge[7, 103] -> 
             RGBColor[
              0.8888626363636363, 0.9136505454545454, 0.9695545909090909], 
             UndirectedEdge[29, 99] -> 
             RGBColor[
              0.6505523181818182, 0.6973888181818182, 0.6577444545454545], 
             UndirectedEdge[28, 144] -> 
             RGBColor[0.9062435, 0.922835, 0.7040340000000003], 
             UndirectedEdge[75, 185] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999998, 0.9867054545454546], 
             UndirectedEdge[227, 291] -> 
             RGBColor[
              0.9261516363636363, 0.9415407272727272, 0.8990496818181819], 
             UndirectedEdge[76, 192] -> 
             RGBColor[
              0.6959147272727273, 0.7606839999999999, 0.9717653636363637], 
             UndirectedEdge[59, 72] -> 
             RGBColor[0.6917924090909092, 0.6075678181818184, 0.5938285], 
             UndirectedEdge[104, 254] -> 
             RGBColor[
              0.963157909090909, 0.9717088181818182, 0.9322466363636364], 
             UndirectedEdge[32, 237] -> 
             RGBColor[
              0.9618348636363636, 0.9323674545454546, 0.6392780454545455], 
             UndirectedEdge[25, 232] -> 
             RGBColor[
              0.5261028181818181, 0.6254392727272727, 0.9560330909090908], 
             UndirectedEdge[9, 141] -> 
             RGBColor[
              0.6505523181818182, 0.6973888181818182, 0.6577444545454545], 
             UndirectedEdge[22, 48] -> 
             RGBColor[
              0.6559121818181817, 0.7298065454545454, 0.9672388181818181], 
             UndirectedEdge[25, 160] -> 
             RGBColor[
              0.760534590909091, 0.6633758181818183, 0.5992401363636364], 
             UndirectedEdge[72, 106] -> 
             RGBColor[
              0.9141711818181819, 0.6950245454545458, 0.2496741818181819], 
             UndirectedEdge[4, 186] -> 
             RGBColor[
              0.9577412727272727, 0.968004090909091, 0.9564171818181818], 
             UndirectedEdge[78, 182] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[106, 211] -> 
             RGBColor[
              0.8972544090909091, 0.8313647272727276, 0.6256043181818183], 
             UndirectedEdge[180, 245] -> 
             RGBColor[
              0.5919755454545454, 0.6730373636363636, 0.9642184545454546], 
             UndirectedEdge[136, 280] -> 
             RGBColor[
              0.9577412727272727, 0.968004090909091, 0.9564171818181818], 
             UndirectedEdge[82, 140] -> 
             RGBColor[
              0.4917317272727272, 0.5975352727272727, 0.9533272727272728], 
             UndirectedEdge[50, 219] -> 
             RGBColor[
              0.8739480454545454, 0.8976055454545455, 0.7008150909090911], 
             UndirectedEdge[251, 278] -> 
             RGBColor[
              0.9849495909090908, 0.9859256363636364, 0.7859635000000003], 
             UndirectedEdge[80, 150] -> 
             RGBColor[
              0.9489243636363636, 0.9614284545454546, 0.971341909090909], 
             UndirectedEdge[26, 183] -> 
             RGBColor[
              0.8410230909090908, 0.8760729999999999, 0.9846987272727272], 
             UndirectedEdge[243, 256] -> 
             RGBColor[
              0.586600409090909, 0.6486470454545454, 0.839031090909091], 
             UndirectedEdge[184, 248] -> 
             RGBColor[
              0.7406013181818183, 0.7917507272727273, 0.744089727272727], 
             UndirectedEdge[4, 255] -> 
             RGBColor[
              0.8861834090909091, 0.6019090000000004, 0.5823957727272727], 
             UndirectedEdge[37, 280] -> 
             RGBColor[
              0.9539108636363638, 0.8755179090909094, 0.5955354545454545], 
             UndirectedEdge[188, 260] -> 
             RGBColor[
              0.5261028181818181, 0.6254392727272727, 0.9560330909090908], 
             UndirectedEdge[70, 266] -> 
             RGBColor[
              0.8087276363636363, 0.8508435454545453, 0.9814798181818182], 
             UndirectedEdge[103, 127] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[37, 268] -> 
             RGBColor[
              0.8116244090909092, 0.7641298181818185, 0.6171597727272728], 
             UndirectedEdge[186, 196] -> 
             RGBColor[
              0.9445043181818182, 0.838224090909091, 0.5879667272727274], 
             UndirectedEdge[139, 274] -> 
             RGBColor[
              0.6067241363636363, 0.6797408636363635, 0.9625721818181818], 
             UndirectedEdge[15, 255] -> 
             RGBColor[0.847415, 0.358906181818182, 0.1927814090909091], 
             UndirectedEdge[118, 195] -> 
             RGBColor[
              0.9241352727272727, 0.940706909090909, 0.9324660454545455], 
             UndirectedEdge[125, 128] -> 
             RGBColor[
              0.9618348636363636, 0.9323674545454546, 0.6392780454545455], 
             UndirectedEdge[61, 177] -> 
             RGBColor[
              0.9903662272727272, 0.9896303636363637, 0.7617929545454547], 
             UndirectedEdge[117, 276] -> 
             RGBColor[
              0.6902832727272727, 0.7577105454545454, 0.9699446363636364], 
             UndirectedEdge[7, 154] -> 
             RGBColor[
              0.907128909090909, 0.9255985454545455, 0.863626590909091], 
             UndirectedEdge[59, 198] -> 
             RGBColor[
              0.738965090909091, 0.7925997272727274, 0.8821028636363637], 
             UndirectedEdge[83, 197] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[243, 283] -> 
             RGBColor[
              0.9938936818181818, 0.9902172727272727, 0.6399644090909089], 
             UndirectedEdge[95, 225] -> 
             RGBColor[
              0.9862083636363635, 0.9885648181818182, 0.8782266363636364], 
             UndirectedEdge[21, 74] -> 
             RGBColor[
              0.9663052272727273, 0.9706129090909091, 0.7058213181818183], 
             UndirectedEdge[62, 225] -> 
             RGBColor[
              0.963157909090909, 0.9717088181818182, 0.9322466363636364], 
             UndirectedEdge[236, 267] -> 
             RGBColor[
              0.731532090909091, 0.788061181818182, 0.9396897727272727], 
             UndirectedEdge[123, 300] -> 
             RGBColor[
              0.7974712727272726, 0.8423900909090908, 0.9802676363636363], 
             UndirectedEdge[111, 218] -> 
             RGBColor[
              0.7570862727272727, 0.8093895454545454, 0.9573203181818182], 
             UndirectedEdge[61, 161] -> 
             RGBColor[
              0.9030961818181817, 0.923930909090909, 0.9304593181818182], 
             UndirectedEdge[58, 180] -> 
             RGBColor[
              0.6505523181818182, 0.6973888181818182, 0.6577444545454545], 
             UndirectedEdge[188, 236] -> 
             RGBColor[
              0.45736063636363644`, 0.5696312727272728, 0.9506214545454545], 
             UndirectedEdge[41, 268] -> 
             RGBColor[
              0.8330886363636363, 0.8697672727272727, 0.9481920454545454], 
             UndirectedEdge[65, 138] -> 
             RGBColor[
              0.9072540454545455, 0.9249964545454545, 0.8140256363636366], 
             UndirectedEdge[241, 291] -> 
             RGBColor[
              0.6317909545454545, 0.6974306818181818, 0.8751358181818183], 
             UndirectedEdge[270, 295] -> 
             RGBColor[
              0.7012036363636364, 0.7627254545454545, 0.9374994090909091], 
             UndirectedEdge[127, 212] -> 
             RGBColor[
              0.5440980454545453, 0.6239302272727272, 0.9614474090909091], 
             UndirectedEdge[105, 274] -> 
             RGBColor[
              0.35018649999999996`, 0.4744622272727272, 0.9436544090909091], 
             UndirectedEdge[128, 142] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[38, 57] -> 
             RGBColor[
              0.9450939545454546, 0.8689422727272731, 0.6104601818181818], 
             UndirectedEdge[135, 255] -> 
             RGBColor[
              0.7615307727272728, 0.5036721818181822, 0.5741706363636364], 
             UndirectedEdge[46, 196] -> 
             RGBColor[
              0.9445043181818182, 0.838224090909091, 0.5879667272727274], 
             UndirectedEdge[138, 210] -> 
             RGBColor[
              0.8800457272727272, 0.907074909090909, 0.9844793181818181], 
             UndirectedEdge[72, 109] -> 
             RGBColor[
              0.6614639545454546, 0.582232090909091, 0.5916381363636365], 
             UndirectedEdge[277, 282] -> 
             RGBColor[
              0.8330886363636363, 0.8697672727272727, 0.9481920454545454], 
             UndirectedEdge[62, 117] -> 
             RGBColor[
              0.8477502727272728, 0.8818454545454546, 0.9812604090909091], 
             UndirectedEdge[33, 126] -> 
             RGBColor[
              0.9416780454545453, 0.9339764545454544, 0.6822381818181817], 
             UndirectedEdge[217, 278] -> 
             RGBColor[
              0.9849495909090908, 0.9859256363636364, 0.7859635000000003], 
             UndirectedEdge[228, 264] -> 
             RGBColor[
              0.9187186363636364, 0.9370021818181817, 0.9566365909090909], 
             UndirectedEdge[121, 239] -> 
             RGBColor[
              0.922123909090909, 0.940626909090909, 0.9884927727272728], 
             UndirectedEdge[56, 84] -> 
             RGBColor[
              0.9807917272727272, 0.984860090909091, 0.9023971818181818], 
             UndirectedEdge[45, 120] -> 
             RGBColor[
              0.7553930909090909, 0.8088380909090909, 0.9762541818181818], 
             UndirectedEdge[67, 234] -> 
             RGBColor[
              0.602674818181818, 0.6482816818181817, 0.654973409090909], 
             UndirectedEdge[153, 192] -> 
             RGBColor[0.621541090909091, 0.7019025454545456, 0.964533], 
             UndirectedEdge[77, 127] -> 
             RGBColor[
              0.862316409090909, 0.6808480909090907, 0.5968716818181818], 
             UndirectedEdge[36, 152] -> 
             RGBColor[0.5415336818181817, 0.6158975, 0.9621099545454546], 
             UndirectedEdge[22, 122] -> 
             RGBColor[
              0.7482693636363635, 0.802813909090909, 0.9722450454545455], 
             UndirectedEdge[68, 218] -> 
             RGBColor[
              0.36767913636363625`, 0.4780844999999999, 0.9458622272727273], 
             UndirectedEdge[56, 148] -> 
             RGBColor[
              0.7066202727272727, 0.7664301818181818, 0.9133288636363637], 
             UndirectedEdge[7, 130] -> 
             RGBColor[
              0.8976795454545454, 0.9202261818181818, 0.9546298636363637], 
             UndirectedEdge[58, 296] -> 
             RGBColor[
              0.7334524090909091, 0.7682594545454546, 0.6632846363636362], 
             UndirectedEdge[104, 116] -> 
             RGBColor[
              0.9827120454545454, 0.9650583636363637, 0.6259920454545453], 
             UndirectedEdge[252, 279] -> 
             RGBColor[
              0.8739480454545454, 0.8976055454545455, 0.7008150909090911], 
             UndirectedEdge[64, 173] -> 
             RGBColor[
              0.6701944999999998, 0.6977457272727272, 0.6336100909090909], 
             UndirectedEdge[109, 155] -> 
             RGBColor[
              0.6371159545454546, 0.45404945454545476`, 0.5706314545454546], 
             UndirectedEdge[151, 258] -> 
             RGBColor[
              0.9739911818181818, 0.9791182727272727, 0.8839055454545455], 
             UndirectedEdge[167, 216] -> 
             RGBColor[0.7436178181818182, 0.799716, 0.9751702727272726], 
             UndirectedEdge[12, 258] -> 
             RGBColor[
              0.9309408181818181, 0.9472025454545454, 0.9735680454545454], 
             UndirectedEdge[151, 239] -> 
             RGBColor[
              0.9651742727272727, 0.9725426363636365, 0.8988302727272728], 
             UndirectedEdge[136, 226] -> 
             RGBColor[
              0.9401074545454545, 0.9548528181818182, 0.9862666363636363], 
             UndirectedEdge[59, 210] -> 
             RGBColor[
              0.7138982727272728, 0.7749099090909092, 0.9695392272727272], 
             UndirectedEdge[191, 205] -> 
             RGBColor[0.9367535, 0.7682040000000001, 0.48275136363636373`], 
             UndirectedEdge[212, 276] -> 
             RGBColor[
              0.42565368181818175`, 0.5307972272727273, 0.9499122272727272], 
             UndirectedEdge[218, 292] -> 
             RGBColor[
              0.7482693636363635, 0.802813909090909, 0.9722450454545455], 
             UndirectedEdge[144, 245] -> 
             RGBColor[
              0.8410230909090908, 0.8760729999999999, 0.9846987272727272], 
             UndirectedEdge[1, 277] -> 
             RGBColor[
              0.9844443181818182, 0.984844909090909, 0.7309676818181816], 
             UndirectedEdge[64, 239] -> 
             RGBColor[0.657284, 0.7268067272727272, 0.9656739545454545], 
             UndirectedEdge[128, 256] -> 
             RGBColor[
              0.5683341363636364, 0.6366990454545455, 0.9449590909090909], 
             UndirectedEdge[7, 81] -> 
             RGBColor[
              0.9072540454545455, 0.9249964545454545, 0.8140256363636366], 
             UndirectedEdge[32, 145] -> 
             RGBColor[
              0.9801011363636363, 0.9443154545454545, 0.5333500454545455], 
             UndirectedEdge[84, 247] -> 
             RGBColor[
              0.9772954090909091, 0.9613536363636364, 0.6501625909090909], 
             UndirectedEdge[215, 259] -> 
             RGBColor[0.9684785, 0.9547779999999999, 0.6650873181818181], 
             UndirectedEdge[187, 233] -> 
             RGBColor[0.7102728636363637, 0.766415, 0.7418993636363634], 
             UndirectedEdge[37, 152] -> 
             RGBColor[0.9182935, 0.8481407272727275, 0.6276110454545456], 
             UndirectedEdge[257, 300] -> 
             RGBColor[
              0.935034409090909, 0.911565909090909, 0.656428909090909], 
             UndirectedEdge[10, 244] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[98, 157] -> 
             RGBColor[
              0.9618348636363636, 0.9323674545454546, 0.6392780454545455], 
             UndirectedEdge[13, 271] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999998, 0.9867054545454546], 
             UndirectedEdge[202, 203] -> 
             RGBColor[
              0.8439198636363637, 0.789359272727273, 0.6203786818181819], 
             UndirectedEdge[166, 195] -> 
             RGBColor[0.9243895, 0.7287059999999999, 0.5426322727272728], 
             UndirectedEdge[260, 287] -> 
             RGBColor[0.8093435, 0.8475587272727273, 0.7495013636363634], 
             UndirectedEdge[212, 214] -> 
             RGBColor[
              0.5526835454545453, 0.4497596818181819, 0.5785654545454546], 
             UndirectedEdge[25, 113] -> 
             RGBColor[
              0.7694035000000001, 0.7009379090909091, 0.6065004090909091], 
             UndirectedEdge[244, 280] -> 
             RGBColor[
              0.9665581818181819, 0.9745797272727272, 0.9414924545454546], 
             UndirectedEdge[58, 134] -> 
             RGBColor[
              0.9827120454545454, 0.9650583636363637, 0.6259920454545453], 
             UndirectedEdge[64, 263] -> 
             RGBColor[
              0.5326313636363635, 0.6285699090909089, 0.9574488181818182], 
             UndirectedEdge[182, 261] -> 
             RGBColor[
              0.9187186363636364, 0.9370021818181817, 0.9566365909090909], 
             UndirectedEdge[150, 277] -> 
             RGBColor[
              0.9577412727272727, 0.968004090909091, 0.9564171818181818], 
             UndirectedEdge[86, 202] -> 
             RGBColor[
              0.5912126363636363, 0.6765668181818181, 0.9623426363636364], 
             UndirectedEdge[257, 267] -> 
             RGBColor[
              0.9706517727272728, 0.9389430909090909, 0.6243533181818182], 
             UndirectedEdge[134, 245] -> 
             RGBColor[
              0.9241352727272727, 0.940706909090909, 0.9324660454545455], 
             UndirectedEdge[187, 297] -> 
             RGBColor[
              0.9277878636363637, 0.9406917272727272, 0.7610365454545452], 
             UndirectedEdge[75, 292] -> 
             RGBColor[
              0.922123909090909, 0.940626909090909, 0.9884927727272728], 
             UndirectedEdge[54, 174] -> 
             RGBColor[
              0.8496085909090909, 0.7019024545454546, 0.6018167727272727], 
             UndirectedEdge[44, 108] -> 
             RGBColor[
              0.8087276363636363, 0.8508435454545453, 0.9814798181818182], 
             UndirectedEdge[94, 141] -> 
             RGBColor[
              0.9863646363636364, 0.9650431818181817, 0.45456254545454516`], 
             UndirectedEdge[185, 262] -> 
             RGBColor[
              0.7553930909090909, 0.8088380909090909, 0.9762541818181818], 
             UndirectedEdge[40, 202] -> 
             RGBColor[
              0.8653840909090909, 0.8949967272727273, 0.9514109545454545], 
             UndirectedEdge[110, 191] -> 
             RGBColor[0.9867447727272727, 0.966726, 0.5591593181818182], 
             UndirectedEdge[92, 125] -> 
             RGBColor[
              0.8929562272727272, 0.8780139090909089, 0.6524154545454546], 
             UndirectedEdge[72, 226] -> 
             RGBColor[
              0.918001590909091, 0.7875107272727274, 0.6105559090909092], 
             UndirectedEdge[130, 162] -> 
             RGBColor[
              0.9187186363636364, 0.9370021818181817, 0.9566365909090909], 
             UndirectedEdge[29, 43] -> 
             RGBColor[
              0.6580813636363636, 0.7225629090909091, 0.8431463181818183], 
             UndirectedEdge[152, 268] -> 
             RGBColor[
              0.7974712727272726, 0.8423900909090908, 0.9802676363636363], 
             UndirectedEdge[4, 62] -> 
             RGBColor[
              0.9401074545454545, 0.9548528181818182, 0.9862666363636363], 
             UndirectedEdge[18, 184] -> 
             RGBColor[
              0.45736063636363644`, 0.5696312727272728, 0.9506214545454545], 
             UndirectedEdge[95, 159] -> 
             RGBColor[
              0.9241352727272727, 0.940706909090909, 0.9324660454545455], 
             UndirectedEdge[154, 255] -> 
             RGBColor[
              0.9132665909090909, 0.6204326363636368, 0.4615430454545456], 
             UndirectedEdge[140, 269] -> 
             RGBColor[
              0.7482693636363635, 0.802813909090909, 0.9722450454545455], 
             UndirectedEdge[10, 161] -> 
             RGBColor[
              0.8888626363636363, 0.9136505454545454, 0.9695545909090909], 
             UndirectedEdge[216, 293] -> 
             RGBColor[
              0.8410230909090908, 0.8760729999999999, 0.9846987272727272], 
             UndirectedEdge[188, 294] -> 
             RGBColor[
              0.7031239545454545, 0.7429237272727272, 0.6610942727272726], 
             UndirectedEdge[32, 282] -> 
             RGBColor[
              0.8283653181818181, 0.8275549999999999, 0.6459776363636363], 
             UndirectedEdge[251, 282] -> 
             RGBColor[
              0.8330886363636363, 0.8697672727272727, 0.9481920454545454], 
             UndirectedEdge[181, 299] -> 
             RGBColor[
              0.7268087727272727, 0.7458489090909091, 0.6374753636363636], 
             UndirectedEdge[60, 159] -> 
             RGBColor[0.6748756363636363, 0.743908, 0.9697586363636364], 
             UndirectedEdge[137, 217] -> 
             RGBColor[
              0.9839390454545455, 0.9837641818181819, 0.6759718636363639], 
             UndirectedEdge[20, 152] -> 
             RGBColor[
              0.922123909090909, 0.940626909090909, 0.9884927727272728], 
             UndirectedEdge[62, 196] -> 
             RGBColor[0.9268705, 0.8250728181818183, 0.6178161818181818], 
             UndirectedEdge[251, 289] -> 
             RGBColor[
              0.9839390454545455, 0.9837641818181819, 0.6759718636363639], 
             UndirectedEdge[104, 283] -> 
             RGBColor[
              0.9898609545454545, 0.9885496363636364, 0.7067971363636362], 
             UndirectedEdge[45, 294] -> 
             RGBColor[0.867304409090909, 0.875195, 0.6750058181818182], 
             UndirectedEdge[15, 158] -> 
             RGBColor[
              0.8399448181818181, 0.30148709090909076`, 0.1856279545454545], 
             UndirectedEdge[150, 237] -> 
             RGBColor[
              0.9489243636363636, 0.9614284545454546, 0.971341909090909], 
             UndirectedEdge[169, 228] -> 
             RGBColor[
              0.862316409090909, 0.6808480909090907, 0.5968716818181818], 
             UndirectedEdge[159, 251] -> 
             RGBColor[
              0.9187186363636364, 0.9370021818181817, 0.9566365909090909], 
             UndirectedEdge[203, 293] -> 
             RGBColor[
              0.8762153181818182, 0.8145887272727275, 0.623597590909091], 
             UndirectedEdge[145, 282] -> 
             RGBColor[0.842538, 0.8751396363636363, 0.8571887727272728], 
             UndirectedEdge[195, 234] -> 
             RGBColor[0.6061711363636362, 0.6717881363636362, 0.907208], 
             UndirectedEdge[156, 270] -> 
             RGBColor[
              0.6749178181818181, 0.7399579999999999, 0.9358245000000001], 
             UndirectedEdge[25, 134] -> 
             RGBColor[
              0.805690909090909, 0.8475739090909091, 0.9209308636363636], 
             UndirectedEdge[158, 276] -> 
             RGBColor[
              0.7212462272727274, 0.42035500000000003`, 0.5639265454545455], 
             UndirectedEdge[268, 280] -> 
             RGBColor[
              0.8330886363636363, 0.8697672727272727, 0.9481920454545454], 
             UndirectedEdge[8, 186] -> 
             RGBColor[
              0.9577412727272727, 0.968004090909091, 0.9564171818181818], 
             UndirectedEdge[32, 256] -> 
             RGBColor[
              0.5724277272727273, 0.601062409090909, 0.6278199545454546], 
             UndirectedEdge[60, 168] -> 
             RGBColor[
              0.6959147272727273, 0.7606839999999999, 0.9717653636363637], 
             UndirectedEdge[162, 216] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             UndirectedEdge[106, 115] -> 
             RGBColor[
              0.9633602272727273, 0.880890272727273, 0.5045321818181819], 
             UndirectedEdge[77, 276] -> 
             RGBColor[
              0.7438720454545454, 0.5877150909090908, 0.5853364999999999], 
             UndirectedEdge[80, 281] -> 
             RGBColor[0.6155410454545454, 0.6863165, 0.9476474545454545], 
             UndirectedEdge[130, 293] -> 
             RGBColor[
              0.8976795454545454, 0.9202261818181818, 0.9546298636363637], 
             UndirectedEdge[39, 118] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             UndirectedEdge[58, 245] -> 
             RGBColor[
              0.9206389545454545, 0.9172004545454544, 0.6802314545454544], 
             UndirectedEdge[54, 143] -> 
             RGBColor[
              0.7850176818181818, 0.6514435454545455, 0.5953789545454545], 
             UndirectedEdge[239, 258] -> 
             RGBColor[
              0.9489243636363636, 0.9614284545454546, 0.971341909090909], 
             UndirectedEdge[184, 222] -> 
             RGBColor[
              0.7409814545454546, 0.7934335454545456, 0.8486865000000001], 
             UndirectedEdge[143, 298] -> 
             RGBColor[
              0.6579878181818182, 0.7324810909090909, 0.9667257272727272], 
             UndirectedEdge[203, 269] -> 
             RGBColor[
              0.9362770454545455, 0.8623666363636366, 0.6253849090909092], 
             UndirectedEdge[107, 139] -> 
             RGBColor[
              0.9673157727272728, 0.9727743636363637, 0.8158129545454547], 
             UndirectedEdge[108, 283] -> 
             RGBColor[
              0.9277878636363637, 0.9406917272727272, 0.7610365454545452], 
             UndirectedEdge[173, 186] -> 
             RGBColor[
              0.9706517727272728, 0.9389430909090909, 0.6243533181818182], 
             UndirectedEdge[164, 296] -> 
             RGBColor[0.621541090909091, 0.7019025454545456, 0.964533], 
             UndirectedEdge[11, 116] -> 
             RGBColor[
              0.8350089545454544, 0.8499655454545454, 0.671786909090909], 
             UndirectedEdge[43, 229] -> 
             RGBColor[
              0.9671906363636363, 0.9733764545454546, 0.8654139090909092], 
             UndirectedEdge[128, 149] -> 
             RGBColor[
              0.9756274090909092, 0.9782692727272727, 0.7458924090909089], 
             UndirectedEdge[221, 232] -> 
             RGBColor[
              0.6296457727272728, 0.39663036363636395`, 0.5634780000000001], 
             UndirectedEdge[8, 85] -> 
             RGBColor[
              0.8800457272727272, 0.907074909090909, 0.9844793181818181], 
             UndirectedEdge[20, 41] -> 
             RGBColor[
              0.9577412727272727, 0.968004090909091, 0.9564171818181818], 
             UndirectedEdge[108, 252] -> 
             RGBColor[0.9272825909090909, 0.939611, 0.7060407272727275], 
             UndirectedEdge[65, 241] -> 
             RGBColor[
              0.6339324545454545, 0.697662409090909, 0.7921185000000002], 
             UndirectedEdge[231, 245] -> 
             RGBColor[
              0.9187186363636364, 0.9370021818181817, 0.9566365909090909], 
             UndirectedEdge[80, 167] -> 
             RGBColor[
              0.7914573636363637, 0.8372935454545455, 0.9600261363636363], 
             UndirectedEdge[17, 201] -> 
             RGBColor[
              0.7754776818181817, 0.8207354545454545, 0.8017913636363638], 
             UndirectedEdge[57, 223] -> 
             RGBColor[
              0.9558311818181819, 0.8557161818181821, 0.31913031818181814`], 
             UndirectedEdge[162, 202] -> 
             RGBColor[
              0.8087276363636363, 0.8508435454545453, 0.9814798181818182], 
             UndirectedEdge[3, 59] -> 
             RGBColor[
              0.7406013181818183, 0.7917507272727273, 0.744089727272727], 
             UndirectedEdge[180, 187] -> 
             RGBColor[
              0.6577012272727274, 0.7208800909090909, 0.7385495454545452], 
             UndirectedEdge[193, 215] -> 
             RGBColor[
              0.8350089545454544, 0.8499655454545454, 0.671786909090909], 
             UndirectedEdge[43, 78] -> 
             RGBColor[
              0.9760075454545454, 0.9799520909090909, 0.8504891818181819], 
             UndirectedEdge[56, 251] -> 
             RGBColor[
              0.9807917272727272, 0.984860090909091, 0.9023971818181818], 
             UndirectedEdge[261, 284] -> 
             RGBColor[
              0.9839390454545455, 0.9837641818181819, 0.6759718636363639], 
             UndirectedEdge[36, 41] -> 
             RGBColor[
              0.5771510454545454, 0.6432746818181818, 0.9300343636363637], 
             UndirectedEdge[95, 168] -> 
             RGBColor[
              0.9451743636363634, 0.9574829090909089, 0.9344727727272728], 
             UndirectedEdge[194, 280] -> 
             RGBColor[
              0.9753750909090909, 0.9811553636363637, 0.9265677272727273], 
             UndirectedEdge[99, 182] -> 
             RGBColor[
              0.9206389545454545, 0.9172004545454544, 0.6802314545454544], 
             UndirectedEdge[94, 97] -> 
             RGBColor[
              0.9488269545454544, 0.9574677272727272, 0.7630432727272725], 
             UndirectedEdge[79, 240] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[83, 198] -> 
             RGBColor[
              0.9739911818181818, 0.9791182727272727, 0.8839055454545455], 
             UndirectedEdge[69, 213] -> 
             RGBColor[
              0.7092467272727272, 0.7718119999999999, 0.9724644545454546], 
             UndirectedEdge[214, 286] -> 
             RGBColor[
              0.8557462727272729, 0.39673654545454595`, 0.19973322727272735`],
              UndirectedEdge[277, 293] -> 
             RGBColor[
              0.8976795454545454, 0.9202261818181818, 0.9546298636363637], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.9013390454545454, 0.7118499999999999, 0.5966522727272727], 
             UndirectedEdge[107, 179] -> 
             RGBColor[0.6582065, 0.7219608181818182, 0.7935453636363639], 
             UndirectedEdge[43, 199] -> 
             RGBColor[
              0.9938936818181818, 0.9902172727272727, 0.6399644090909089], 
             UndirectedEdge[192, 222] -> 
             RGBColor[
              0.7409814545454546, 0.7934335454545456, 0.8486865000000001], 
             UndirectedEdge[130, 202] -> 
             RGBColor[
              0.8653840909090909, 0.8949967272727273, 0.9514109545454545], 
             UndirectedEdge[4, 265] -> 
             RGBColor[
              0.8477502727272728, 0.8818454545454546, 0.9812604090909091], 
             UndirectedEdge[121, 173] -> 
             RGBColor[
              0.935034409090909, 0.911565909090909, 0.656428909090909], 
             UndirectedEdge[53, 107] -> 
             RGBColor[
              0.9072540454545455, 0.9249964545454545, 0.8140256363636366], 
             UndirectedEdge[172, 238] -> 
             RGBColor[
              0.9362770454545455, 0.8623666363636366, 0.6253849090909092], 
             UndirectedEdge[210, 211] -> 
             RGBColor[
              0.9010848181818181, 0.9238509090909091, 0.9864860454545454], 
             UndirectedEdge[180, 221] -> 
             RGBColor[
              0.5770741363636365, 0.35109545454545493`, 0.5601281818181819], 
             UndirectedEdge[196, 212] -> 
             RGBColor[
              0.5698837272727273, 0.5251521363636363, 0.5927775454545454], 
             UndirectedEdge[160, 176] -> 
             RGBColor[
              0.918001590909091, 0.7875107272727274, 0.6105559090909092], 
             UndirectedEdge[115, 193] -> 
             RGBColor[0.842538, 0.8751396363636363, 0.8571887727272728], 
             UndirectedEdge[21, 300] -> 
             RGBColor[
              0.9483216818181817, 0.9563869999999999, 0.7080474545454547], 
             UndirectedEdge[75, 235] -> 
             RGBColor[
              0.9483216818181817, 0.9563869999999999, 0.7080474545454547], 
             UndirectedEdge[77, 255] -> 
             RGBColor[0.847415, 0.358906181818182, 0.1927814090909091], 
             UndirectedEdge[62, 286] -> 
             RGBColor[
              0.8861834090909091, 0.6019090000000004, 0.5823957727272727], 
             UndirectedEdge[46, 225] -> 
             RGBColor[
              0.9807917272727272, 0.984860090909091, 0.9023971818181818], 
             UndirectedEdge[37, 161] -> 
             RGBColor[
              0.8762153181818182, 0.8145887272727275, 0.623597590909091], 
             UndirectedEdge[3, 162] -> 
             RGBColor[
              0.9277878636363637, 0.9406917272727272, 0.7610365454545452], 
             UndirectedEdge[107, 274] -> 
             RGBColor[
              0.6339324545454545, 0.697662409090909, 0.7921185000000002], 
             UndirectedEdge[6, 147] -> 
             RGBColor[
              0.5261028181818181, 0.6254392727272727, 0.9560330909090908], 
             UndirectedEdge[8, 135] -> 
             RGBColor[0.8154548181818182, 0.856616, 0.9780415], 
             UndirectedEdge[186, 249] -> 
             RGBColor[
              0.8976795454545454, 0.9202261818181818, 0.9546298636363637], 
             UndirectedEdge[277, 281] -> 
             RGBColor[
              0.6243579545454545, 0.6928921363636363, 0.9327227272727273], 
             UndirectedEdge[256, 277] -> 
             RGBColor[
              0.5771510454545454, 0.6432746818181818, 0.9300343636363637], 
             UndirectedEdge[8, 249] -> 
             RGBColor[
              0.8800457272727272, 0.907074909090909, 0.9844793181818181], 
             UndirectedEdge[114, 254] -> 
             RGBColor[
              0.9010848181818181, 0.9238509090909091, 0.9864860454545454], 
             UndirectedEdge[223, 270] -> 
             RGBColor[
              0.9772954090909091, 0.9613536363636364, 0.6501625909090909], 
             UndirectedEdge[120, 294] -> 
             RGBColor[0.867304409090909, 0.875195, 0.6750058181818182], 
             UndirectedEdge[23, 290] -> 
             RGBColor[
              0.27669377272727264`, 0.40207731818181813`, 0.9392911363636364],
              UndirectedEdge[7, 293] -> 
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692], 
             UndirectedEdge[95, 191] -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909092], 
             UndirectedEdge[65, 194] -> 
             RGBColor[
              0.9849495909090908, 0.9859256363636364, 0.7859635000000003], 
             UndirectedEdge[94, 188] -> 
             RGBColor[0.7102728636363637, 0.766415, 0.7418993636363634], 
             UndirectedEdge[24, 162] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[34, 84] -> 
             RGBColor[
              0.9665581818181819, 0.9745797272727272, 0.9414924545454546], 
             UndirectedEdge[130, 201] -> 
             RGBColor[
              0.7659031818181817, 0.8159651818181818, 0.9423955909090909], 
             UndirectedEdge[74, 260] -> 
             RGBColor[
              0.7826404545454546, 0.8307179090909091, 0.9749508636363635], 
             UndirectedEdge[69, 85] -> 
             RGBColor[
              0.6882076363636362, 0.7550359999999998, 0.9704577272727273], 
             UndirectedEdge[220, 262] -> 
             RGBColor[0.842538, 0.8751396363636363, 0.8571887727272728], 
             UndirectedEdge[26, 262] -> 
             RGBColor[
              0.7553930909090909, 0.8088380909090909, 0.9762541818181818], 
             UndirectedEdge[217, 270] -> 
             RGBColor[
              0.9753750909090909, 0.9811553636363637, 0.9265677272727273], 
             UndirectedEdge[221, 245] -> 
             RGBColor[
              0.8471607727272727, 0.5709070909090912, 0.582615181818182], 
             UndirectedEdge[3, 24] -> 
             RGBColor[
              0.9756274090909092, 0.9782692727272727, 0.7458924090909089], 
             UndirectedEdge[59, 197] -> 
             RGBColor[
              0.5892456363636365, 0.676673090909091, 0.9613140909090909], 
             UndirectedEdge[54, 235] -> 
             RGBColor[
              0.935868090909091, 0.7654404545454547, 0.32315877272727295`], 
             UndirectedEdge[159, 282] -> 
             RGBColor[
              0.7764321818181817, 0.8256140909090908, 0.9782609090909091], 
             UndirectedEdge[6, 53] -> 
             RGBColor[
              0.6235080909090909, 0.7017962727272726, 0.9655615454545454], 
             UndirectedEdge[31, 210] -> 
             RGBColor[
              0.9673157727272728, 0.9727743636363637, 0.8158129545454547], 
             UndirectedEdge[137, 273] -> 
             RGBColor[
              0.9663052272727273, 0.9706129090909091, 0.7058213181818183], 
             UndirectedEdge[99, 259] -> 
             RGBColor[0.9684785, 0.9547779999999999, 0.6650873181818181], 
             UndirectedEdge[16, 151] -> 
             RGBColor[
              0.9430684090909092, 0.8052005454545457, 0.5231195454545456], 
             UndirectedEdge[24, 227] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[87, 202] -> 
             RGBColor[
              0.5912126363636363, 0.6765668181818181, 0.9623426363636364], 
             UndirectedEdge[17, 94] -> 
             RGBColor[
              0.9940188181818181, 0.9896151818181818, 0.5903634545454546], 
             UndirectedEdge[5, 92] -> 
             RGBColor[
              0.8800457272727272, 0.907074909090909, 0.9844793181818181], 
             UndirectedEdge[72, 290] -> 
             RGBColor[
              0.6351781363636363, 0.5594646363636364, 0.5899632272727273], 
             UndirectedEdge[103, 212] -> 
             RGBColor[
              0.5919375909090908, 0.6615077727272727, 0.9463032727272727], 
             UndirectedEdge[112, 133] -> 
             RGBColor[
              0.2504079545454546, 0.37930986363636365`, 0.9376162272727273], 
             UndirectedEdge[71, 244] -> 
             RGBColor[
              0.9665581818181819, 0.9745797272727272, 0.9414924545454546], 
             UndirectedEdge[142, 197] -> 
             RGBColor[
              0.7764321818181817, 0.8256140909090908, 0.9782609090909091], 
             UndirectedEdge[117, 196] -> 
             RGBColor[
              0.8345133181818183, 0.7520654545454546, 0.6128099545454546], 
             UndirectedEdge[131, 188] -> 
             RGBColor[
              0.6445471818181818, 0.7185722727272726, 0.9675682727272727], 
             UndirectedEdge[13, 282] -> 
             RGBColor[
              0.7553930909090909, 0.8088380909090909, 0.9762541818181818], 
             UndirectedEdge[139, 143] -> 
             RGBColor[0.8154548181818182, 0.856616, 0.9780415], 
             UndirectedEdge[45, 89] -> 
             RGBColor[
              0.7230976363636363, 0.7836086363636363, 0.9730352727272726], 
             UndirectedEdge[127, 269] -> 
             RGBColor[
              0.9010848181818181, 0.9238509090909091, 0.9864860454545454], 
             UndirectedEdge[25, 79] -> 
             RGBColor[
              0.7914573636363637, 0.8372935454545455, 0.9600261363636363], 
             UndirectedEdge[29, 78] -> 
             RGBColor[
              0.6398150909090909, 0.7106149090909091, 0.9490743181818182], 
             UndirectedEdge[150, 179] -> 
             RGBColor[
              0.6309981818181818, 0.7040392727272728, 0.9639990454545455], 
             UndirectedEdge[11, 198] -> 
             RGBColor[
              0.8405216363636363, 0.8743058181818182, 0.8906051363636365], 
             UndirectedEdge[135, 286] -> 
             RGBColor[
              0.7615307727272728, 0.5036721818181822, 0.5741706363636364], 
             UndirectedEdge[101, 104] -> 
             RGBColor[
              0.9898609545454545, 0.9885496363636364, 0.7067971363636362], 
             UndirectedEdge[3, 290] -> 
             RGBColor[
              0.6839870454545454, 0.7436475454545454, 0.7402244545454544], 
             UndirectedEdge[158, 212] -> 
             RGBColor[
              0.5217264545454545, 0.24456922727272717`, 0.5502036818181818], 
             UndirectedEdge[102, 175] -> 
             RGBColor[
              0.8739480454545454, 0.8976055454545455, 0.7008150909090911], 
             UndirectedEdge[103, 255] -> 
             RGBColor[
              0.8950003181818182, 0.6084846363636367, 0.5674710454545455], 
             UndirectedEdge[3, 65] -> 
             RGBColor[
              0.9940188181818181, 0.9896151818181818, 0.5903634545454546], 
             UndirectedEdge[148, 270] -> 
             RGBColor[
              0.7012036363636364, 0.7627254545454545, 0.9374994090909091], 
             UndirectedEdge[49, 298] -> 
             RGBColor[0.7225787272727273, 0.78294, 0.9731635454545454], 
             UndirectedEdge[15, 103] -> 
             RGBColor[
              0.9101559545454545, 0.7184256363636362, 0.5817275454545454], 
             UndirectedEdge[4, 15] -> 
             RGBColor[
              0.9013390454545454, 0.7118499999999999, 0.5966522727272727], 
             UndirectedEdge[83, 290] -> 
             RGBColor[
              0.666100909090909, 0.7333823636363636, 0.9507492272727273], 
             UndirectedEdge[182, 284] -> 
             RGBColor[0.9272825909090909, 0.939611, 0.7060407272727275], 
             UndirectedEdge[32, 92] -> 
             RGBColor[
              0.8929562272727272, 0.8780139090909089, 0.6524154545454546], 
             UndirectedEdge[87, 203] -> 
             RGBColor[
              0.6797394090909092, 0.6570880000000003, 0.6064671363636365], 
             UndirectedEdge[115, 169] -> 
             RGBColor[
              0.9284222272727272, 0.7303736363636362, 0.4757995454545455], 
             UndirectedEdge[111, 143] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[163, 274] -> 
             RGBColor[
              0.4148860454545453, 0.5277019545454544, 0.948550590909091], 
             UndirectedEdge[96, 260] -> 
             RGBColor[
              0.8002742727272727, 0.8438691818181818, 0.9451014090909091], 
             UndirectedEdge[27, 227] -> 
             RGBColor[
              0.8410230909090908, 0.8760729999999999, 0.9846987272727272], 
             UndirectedEdge[103, 205] -> 
             RGBColor[
              0.9184872272727274, 0.7562560000000002, 0.5886793636363636], 
             UndirectedEdge[27, 216] -> 
             RGBColor[
              0.8410230909090908, 0.8760729999999999, 0.9846987272727272], 
             UndirectedEdge[145, 293] -> 
             RGBColor[
              0.907128909090909, 0.9255985454545455, 0.863626590909091], 
             UndirectedEdge[96, 133] -> 
             RGBColor[
              0.6486320000000001, 0.7171905454545455, 0.9341495909090909], 
             UndirectedEdge[127, 159] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             UndirectedEdge[186, 214] -> 
             RGBColor[
              0.9273041363636364, 0.7628316363636365, 0.5737546363636363], 
             UndirectedEdge[111, 262] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[33, 157] -> 
             RGBColor[0.9684785, 0.9547779999999999, 0.6650873181818181], 
             UndirectedEdge[112, 131] -> 
             RGBColor[
              0.5204945909090908, 0.5991214999999999, 0.9601032272727272], 
             UndirectedEdge[37, 55] -> 
             RGBColor[
              0.9539108636363638, 0.8755179090909094, 0.5955354545454545], 
             UndirectedEdge[20, 71] -> 
             RGBColor[
              0.9577412727272727, 0.968004090909091, 0.9564171818181818], 
             UndirectedEdge[37, 252] -> 
             RGBColor[
              0.9624748181818183, 0.8781267272727276, 0.34493959090909115`], 
             UndirectedEdge[120, 178] -> 
             RGBColor[
              0.6559121818181817, 0.7298065454545454, 0.9672388181818181], 
             UndirectedEdge[113, 231] -> 
             RGBColor[
              0.9445043181818182, 0.838224090909091, 0.5879667272727274], 
             UndirectedEdge[7, 181] -> 
             RGBColor[
              0.8929562272727272, 0.8780139090909089, 0.6524154545454546], 
             UndirectedEdge[42, 299] -> 
             RGBColor[
              0.6959147272727273, 0.7606839999999999, 0.9717653636363637], 
             UndirectedEdge[64, 234] -> 
             RGBColor[
              0.30029722727272706`, 0.4268860454545453, 0.9406353181818181], 
             UndirectedEdge[78, 261] -> 
             RGBColor[
              0.9665581818181819, 0.9745797272727272, 0.9414924545454546], 
             UndirectedEdge[10, 100] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[6, 88] -> 
             RGBColor[
              0.6655862727272726, 0.7353482727272727, 0.9695750000000001], 
             UndirectedEdge[36, 208] -> 
             RGBColor[
              0.4020502272727273, 0.5059885000000001, 0.9485680454545454], 
             UndirectedEdge[92, 142] -> 
             RGBColor[
              0.8410230909090908, 0.8760729999999999, 0.9846987272727272], 
             UndirectedEdge[237, 293] -> 
             RGBColor[
              0.8888626363636363, 0.9136505454545454, 0.9695545909090909], 
             UndirectedEdge[127, 145] -> 
             RGBColor[
              0.9281679999999999, 0.9423745454545454, 0.8656333181818183], 
             UndirectedEdge[90, 285] -> 
             RGBColor[
              0.8728170909090909, 0.8995352727272727, 0.8938240454545455], 
             UndirectedEdge[134, 176] -> 
             RGBColor[
              0.963157909090909, 0.9717088181818182, 0.9322466363636364], 
             UndirectedEdge[28, 297] -> 
             RGBColor[0.9272825909090909, 0.939611, 0.7060407272727274], 
             UndirectedEdge[20, 136] -> 
             RGBColor[
              0.9401074545454545, 0.9548528181818182, 0.9862666363636363], 
             UndirectedEdge[113, 134] -> 
             RGBColor[
              0.9499209545454546, 0.8419288181818183, 0.5637961818181818], 
             UndirectedEdge[12, 181] -> 
             RGBColor[
              0.935034409090909, 0.911565909090909, 0.656428909090909], 
             UndirectedEdge[84, 217] -> 
             RGBColor[
              0.9753750909090909, 0.9811553636363637, 0.9265677272727273], 
             UndirectedEdge[126, 153] -> 
             RGBColor[
              0.8297667272727272, 0.8676195454545453, 0.9834865454545454], 
             UndirectedEdge[217, 251] -> 
             RGBColor[
              0.9753750909090909, 0.9811553636363637, 0.9265677272727273], 
             UndirectedEdge[211, 266] -> 
             RGBColor[
              0.8087276363636363, 0.8508435454545453, 0.9814798181818182], 
             UndirectedEdge[156, 282] -> 
             RGBColor[
              0.5326313636363635, 0.6285699090909089, 0.9574488181818182], 
             UndirectedEdge[92, 256] -> 
             RGBColor[0.49945549999999994`, 0.5823455, 0.9580965], 
             UndirectedEdge[56, 246] -> 
             RGBColor[
              0.9862083636363635, 0.9885648181818182, 0.8782266363636364], 
             UndirectedEdge[223, 246] -> 
             RGBColor[
              0.9827120454545454, 0.9650583636363637, 0.6259920454545453], 
             UndirectedEdge[66, 228] -> 
             RGBColor[
              0.6445471818181818, 0.7185722727272726, 0.9675682727272727], 
             UndirectedEdge[170, 261] -> 
             RGBColor[
              0.9665581818181819, 0.9745797272727272, 0.9414924545454546], 
             UndirectedEdge[104, 287] -> 
             RGBColor[
              0.9898609545454545, 0.9885496363636364, 0.7067971363636362], 
             UndirectedEdge[255, 258] -> 
             RGBColor[
              0.8950003181818182, 0.6084846363636367, 0.5674710454545455], 
             UndirectedEdge[27, 162] -> 
             RGBColor[
              0.8410230909090908, 0.8760729999999999, 0.9846987272727272], 
             UndirectedEdge[162, 169] -> 
             RGBColor[
              0.862316409090909, 0.6808480909090907, 0.5968716818181818], 
             UndirectedEdge[90, 166] -> 
             RGBColor[
              0.9264058636363636, 0.729539818181818, 0.5092159090909092], 
             UndirectedEdge[74, 257] -> 
             RGBColor[
              0.9530179545454545, 0.9257918181818181, 0.6542027727272727], 
             UndirectedEdge[82, 203] -> 
             RGBColor[
              0.6797394090909092, 0.6570880000000003, 0.6064671363636365], 
             UndirectedEdge[1, 142] -> 
             RGBColor[
              0.9277878636363637, 0.9406917272727272, 0.7610365454545452], 
             UndirectedEdge[82, 145] -> 
             RGBColor[0.710653, 0.7680978181818181, 0.8464961363636365], 
             UndirectedEdge[77, 203] -> 
             RGBColor[
              0.8975086363636364, 0.6193638181818184, 0.23577054545454548`], 
             UndirectedEdge[12, 27] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999998, 0.9867054545454546], 
             UndirectedEdge[54, 185] -> 
             RGBColor[
              0.8496085909090909, 0.7019024545454546, 0.6018167727272727], 
             UndirectedEdge[35, 165] -> 
             RGBColor[
              0.9483216818181817, 0.9563869999999999, 0.7080474545454547], 
             UndirectedEdge[60, 95] -> 
             RGBColor[
              0.7369487272727273, 0.7917659090909092, 0.9155192272727273], 
             UndirectedEdge[47, 112] -> 
             RGBColor[
              0.5374113636363637, 0.46278131818181834`, 0.584173090909091], 
             UndirectedEdge[24, 59] -> 
             RGBColor[
              0.7227151818181818, 0.7814855454545455, 0.9546144999999999], 
             UndirectedEdge[239, 285] -> 
             RGBColor[
              0.8477502727272728, 0.8818454545454546, 0.9812604090909091], 
             UndirectedEdge[173, 286] -> 
             RGBColor[
              0.8990939090909091, 0.5728480000000002, 0.2503319090909091], 
             UndirectedEdge[17, 40] -> 
             RGBColor[
              0.9849495909090908, 0.9859256363636364, 0.7859635000000003], 
             UndirectedEdge[226, 241] -> 
             RGBColor[
              0.6067241363636363, 0.6797408636363635, 0.9625721818181818], 
             UndirectedEdge[255, 286] -> 
             RGBColor[
              0.8322593636363638, 0.2489651818181825, 0.17852490909090918`], 
             UndirectedEdge[95, 271] -> 
             RGBColor[
              0.9451743636363634, 0.9574829090909089, 0.9344727727272728], 
             UndirectedEdge[189, 260] -> 
             RGBColor[
              0.8097236363636364, 0.8492415454545454, 0.8540981363636364], 
             UndirectedEdge[193, 245] -> 
             RGBColor[
              0.7764321818181817, 0.8256140909090908, 0.9782609090909091], 
             UndirectedEdge[84, 223] -> 
             RGBColor[
              0.9772954090909091, 0.9613536363636364, 0.6501625909090909], 
             UndirectedEdge[44, 61] -> 
             RGBColor[
              0.8708007272727272, 0.8987014545454546, 0.9272404090909091], 
             UndirectedEdge[262, 292] -> 
             RGBColor[0.8154548181818182, 0.856616, 0.9780415], 
             UndirectedEdge[153, 248] -> 
             RGBColor[
              0.8744533181818182, 0.8986862727272726, 0.7558109090909089], 
             UndirectedEdge[78, 99] -> 
             RGBColor[0.9684785, 0.9547779999999999, 0.6650873181818181], 
             UndirectedEdge[199, 261] -> 
             RGBColor[
              0.9844443181818182, 0.984844909090909, 0.7309676818181816], 
             UndirectedEdge[58, 215] -> 
             RGBColor[
              0.9792157272727272, 0.941551909090909, 0.3737574545454544], 
             UndirectedEdge[23, 197] -> 
             RGBColor[
              0.43486459090909085`, 0.5318865909090909, 0.9516586818181818], 
             UndirectedEdge[196, 214] -> 
             RGBColor[
              0.8964333636363637, 0.6199003636363638, 0.2351536363636364], 
             UndirectedEdge[88, 289] -> 
             RGBColor[
              0.9483216818181817, 0.9563869999999999, 0.7080474545454547], 
             UndirectedEdge[47, 96] -> 
             RGBColor[
              0.9356354090909091, 0.8006620000000002, 0.5807064545454546], 
             UndirectedEdge[179, 205] -> 
             RGBColor[0.6005610454545456, 0.4988668181818184, 0.5813365], 
             UndirectedEdge[72, 194] -> 
             RGBColor[
              0.9356354090909091, 0.8006620000000002, 0.5807064545454546], 
             UndirectedEdge[140, 299] -> 
             RGBColor[0.5220601818181818, 0.622871, 0.9555176363636364], 
             UndirectedEdge[134, 297] -> 
             RGBColor[
              0.9241352727272727, 0.940706909090909, 0.9324660454545455], 
             UndirectedEdge[67, 195] -> 
             RGBColor[
              0.9827120454545454, 0.9650583636363637, 0.6259920454545453], 
             UndirectedEdge[24, 155] -> 
             RGBColor[0.9024705, 0.6659037272727275, 0.5746245000000001], 
             UndirectedEdge[156, 277] -> 
             RGBColor[
              0.6749178181818181, 0.7399579999999999, 0.9358245000000001], 
             UndirectedEdge[267, 272] -> 
             RGBColor[
              0.8963470454545455, 0.5576411818181819, 0.5453928636363636], 
             UndirectedEdge[71, 177] -> 
             RGBColor[
              0.9849495909090908, 0.9859256363636364, 0.7859635000000003], 
             UndirectedEdge[188, 281] -> 
             RGBColor[
              0.35018649999999996`, 0.4744622272727272, 0.9436544090909091], 
             UndirectedEdge[1, 150] -> 
             RGBColor[0.9668105, 0.9716936363636364, 0.7608171363636361], 
             UndirectedEdge[84, 246] -> 
             RGBColor[
              0.9807917272727272, 0.984860090909091, 0.9023971818181818], 
             UndirectedEdge[58, 230] -> 
             RGBColor[0.9684785, 0.9547779999999999, 0.6650873181818181], 
             UndirectedEdge[74, 189] -> 
             RGBColor[
              0.9671906363636363, 0.9733764545454546, 0.8654139090909092], 
             UndirectedEdge[48, 71] -> 
             RGBColor[
              0.8653840909090909, 0.8949967272727273, 0.9514109545454545], 
             UndirectedEdge[80, 205] -> 
             RGBColor[
              0.9184872272727274, 0.7562560000000002, 0.5886793636363636], 
             UndirectedEdge[1, 32] -> 
             RGBColor[
              0.9797210000000001, 0.9426326363636364, 0.4287532727272725], 
             UndirectedEdge[229, 233] -> 
             RGBColor[
              0.6835698181818182, 0.7495741818181818, 0.9673488636363636], 
             UndirectedEdge[54, 172] -> 
             RGBColor[
              0.9096703181818182, 0.7496803636363638, 0.603604090909091], 
             UndirectedEdge[61, 194] -> 
             RGBColor[
              0.9807917272727272, 0.984860090909091, 0.9023971818181818], 
             UndirectedEdge[177, 194] -> 
             RGBColor[
              0.9849495909090908, 0.9859256363636364, 0.7859635000000003], 
             UndirectedEdge[7, 42] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999998, 0.9867054545454546], 
             UndirectedEdge[26, 75] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999998, 0.9867054545454546], 
             UndirectedEdge[170, 190] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[20, 36] -> 
             RGBColor[
              0.5595172272727272, 0.6301234090909091, 0.9598838181818181], 
             UndirectedEdge[119, 161] -> 
             RGBColor[
              0.8995998636363636, 0.9004244545454545, 0.6782247272727272], 
             UndirectedEdge[212, 225] -> 
             RGBColor[0.6061711363636362, 0.6717881363636362, 0.907208], 
             UndirectedEdge[102, 253] -> 
             RGBColor[0.621541090909091, 0.7019025454545456, 0.964533], 
             UndirectedEdge[91, 179] -> 
             RGBColor[0.6582065, 0.7219608181818182, 0.7935453636363639], 
             UndirectedEdge[118, 239] -> 
             RGBColor[
              0.9010848181818181, 0.9238509090909091, 0.9864860454545454], 
             UndirectedEdge[105, 298] -> 
             RGBColor[
              0.5261028181818181, 0.6254392727272727, 0.9560330909090908], 
             UndirectedEdge[90, 239] -> 
             RGBColor[
              0.9651742727272727, 0.9725426363636365, 0.8988302727272728], 
             UndirectedEdge[208, 252] -> 
             RGBColor[
              0.8088382272727273, 0.8464780000000001, 0.6945055454545456], 
             UndirectedEdge[117, 214] -> 
             RGBColor[
              0.8173131363636363, 0.6766730000000001, 0.5985978636363636], 
             UndirectedEdge[179, 282] -> 
             RGBColor[
              0.5063455454545455, 0.6058024545454546, 0.9557739090909091], 
             UndirectedEdge[44, 268] -> 
             RGBColor[
              0.7230976363636363, 0.7836086363636363, 0.9730352727272726], 
             UndirectedEdge[53, 124] -> 
             RGBColor[
              0.8261216818181818, 0.5541310909090912, 0.5806084545454546], 
             UndirectedEdge[42, 81] -> 
             RGBColor[
              0.9493322272727271, 0.9585484545454545, 0.8180390909090911], 
             UndirectedEdge[173, 213] -> 
             RGBColor[
              0.9139953181818181, 0.894789909090909, 0.6544221818181818], 
             UndirectedEdge[119, 122] -> 
             RGBColor[
              0.9596615909090909, 0.9482023636363637, 0.6800120454545453], 
             UndirectedEdge[68, 111] -> 
             RGBColor[
              0.5683341363636363, 0.6366990454545454, 0.9449590909090909], 
             UndirectedEdge[34, 53] -> 
             RGBColor[
              0.8888626363636363, 0.9136505454545454, 0.9695545909090909], 
             UndirectedEdge[85, 263] -> 
             RGBColor[
              0.7553930909090909, 0.8088380909090909, 0.9762541818181818], 
             UndirectedEdge[37, 208] -> 
             RGBColor[
              0.7788100454545456, 0.7382317272727277, 0.6140691363636364], 
             UndirectedEdge[256, 293] -> 
             RGBColor[0.4994555, 0.5823455, 0.9580965], 
             UndirectedEdge[76, 153] -> 
             RGBColor[
              0.8297667272727272, 0.8676195454545453, 0.9834865454545454], 
             UndirectedEdge[135, 213] -> 
             RGBColor[
              0.7764321818181817, 0.8256140909090908, 0.9782609090909091], 
             UndirectedEdge[36, 55] -> 
             RGBColor[
              0.5771510454545454, 0.6432746818181818, 0.9300343636363637], 
             UndirectedEdge[121, 135] -> 
             RGBColor[
              0.7974712727272726, 0.8423900909090908, 0.9802676363636363], 
             UndirectedEdge[83, 226] -> 
             RGBColor[
              0.9489243636363636, 0.9614284545454546, 0.971341909090909], 
             UndirectedEdge[60, 127] -> 
             RGBColor[0.6748756363636363, 0.743908, 0.9697586363636364], 
             UndirectedEdge[247, 271] -> 
             RGBColor[
              0.9416780454545453, 0.9339764545454544, 0.6822381818181817], 
             UndirectedEdge[202, 269] -> 
             RGBColor[
              0.8477502727272728, 0.8818454545454546, 0.9812604090909091], 
             UndirectedEdge[190, 284] -> 
             RGBColor[
              0.8416525909090908, 0.872376090909091, 0.697596181818182], 
             UndirectedEdge[53, 217] -> 
             RGBColor[
              0.8976795454545454, 0.9202261818181818, 0.9546298636363637], 
             UndirectedEdge[42, 87] -> 
             RGBColor[
              0.6655862727272726, 0.7353482727272727, 0.9695750000000001], 
             UndirectedEdge[205, 225] -> 
             RGBColor[
              0.9327207727272727, 0.7665363636363638, 0.549584090909091], 
             UndirectedEdge[110, 246] -> 
             RGBColor[
              0.9827120454545454, 0.9650583636363637, 0.6259920454545453], 
             UndirectedEdge[191, 251] -> 
             RGBColor[
              0.9848244545454545, 0.9865277272727273, 0.8355644545454546], 
             UndirectedEdge[23, 83] -> 
             RGBColor[
              0.5683341363636363, 0.6366990454545454, 0.9449590909090909], 
             UndirectedEdge[226, 291] -> 
             RGBColor[
              0.9651742727272727, 0.9725426363636365, 0.8988302727272728], 
             UndirectedEdge[60, 276] -> 
             RGBColor[
              0.5564312727272729, 0.6507750000000001, 0.9582234545454544], 
             UndirectedEdge[27, 155] -> 
             RGBColor[
              0.8335918636363636, 0.611550181818182, 0.5877619090909092], 
             UndirectedEdge[167, 203] -> 
             RGBColor[
              0.7788100454545456, 0.7382317272727277, 0.6140691363636364], 
             UndirectedEdge[137, 271] -> 
             RGBColor[
              0.9483216818181817, 0.9563869999999999, 0.7080474545454547], 
             UndirectedEdge[52, 247] -> 
             RGBColor[0.9684785, 0.9547779999999999, 0.6650873181818181], 
             UndirectedEdge[81, 299] -> 
             RGBColor[
              0.741106590909091, 0.7928314545454547, 0.7990855454545456], 
             UndirectedEdge[31, 290] -> 
             RGBColor[
              0.6844923181818181, 0.7447282727272726, 0.7952202727272729], 
             UndirectedEdge[79, 288] -> 
             RGBColor[
              0.5919375909090908, 0.6615077727272727, 0.9463032727272727], 
             UndirectedEdge[237, 281] -> 
             RGBColor[0.6155410454545454, 0.6863165, 0.9476474545454545], 
             UndirectedEdge[43, 215] -> 
             RGBColor[0.9867447727272727, 0.966726, 0.5591593181818182], 
             UndirectedEdge[56, 295] -> 
             RGBColor[
              0.7066202727272727, 0.7664301818181818, 0.9133288636363637], 
             UndirectedEdge[89, 94] -> 
             RGBColor[
              0.8421578636363636, 0.8734568181818181, 0.7525919999999997], 
             UndirectedEdge[92, 237] -> 
             RGBColor[
              0.8888626363636363, 0.9136505454545454, 0.9695545909090909], 
             UndirectedEdge[126, 285] -> 
             RGBColor[
              0.8297667272727272, 0.8676195454545453, 0.9834865454545454], 
             UndirectedEdge[4, 214] -> 
             RGBColor[
              0.9096703181818182, 0.7496803636363638, 0.603604090909091], 
             UndirectedEdge[220, 222] -> 
             RGBColor[
              0.9942738181818181, 0.9919000909090909, 0.744561181818182], 
             UndirectedEdge[199, 209] -> 
             RGBColor[
              0.9488269545454544, 0.9574677272727272, 0.7630432727272725], 
             UndirectedEdge[290, 291] -> 
             RGBColor[
              0.6823508181818181, 0.7444965454545454, 0.8782375909090909], 
             UndirectedEdge[91, 150] -> 
             RGBColor[
              0.9673157727272728, 0.9727743636363637, 0.8158129545454547], 
             UndirectedEdge[60, 148] -> 
             RGBColor[
              0.45736063636363644`, 0.5696312727272728, 0.9506214545454545], 
             UndirectedEdge[81, 140] -> 
             RGBColor[
              0.7754776818181817, 0.8207354545454545, 0.8017913636363638], 
             UndirectedEdge[142, 256] -> 
             RGBColor[0.5204945909090909, 0.5991215, 0.9601032272727272], 
             UndirectedEdge[30, 123] -> 
             RGBColor[
              0.7764321818181817, 0.8256140909090908, 0.9782609090909091], 
             UndirectedEdge[53, 289] -> 
             RGBColor[0.9062435, 0.922835, 0.7040340000000002], 
             UndirectedEdge[274, 289] -> 
             RGBColor[
              0.6329219090909091, 0.6955009545454545, 0.6821268636363639], 
             UndirectedEdge[11, 114] -> 
             RGBColor[
              0.7764321818181817, 0.8256140909090908, 0.9782609090909091], 
             UndirectedEdge[137, 247] -> 
             RGBColor[
              0.9858593636363636, 0.9639624545454546, 0.39956672727272735`], 
             UndirectedEdge[84, 191] -> 
             RGBColor[
              0.9848244545454545, 0.9865277272727273, 0.8355644545454546], 
             UndirectedEdge[17, 120] -> 
             RGBColor[0.8749585909090909, 0.899767, 0.8108067272727275], 
             UndirectedEdge[126, 222] -> 
             RGBColor[
              0.9492070909090908, 0.9591505454545454, 0.8676400454545455], 
             UndirectedEdge[184, 224] -> 
             RGBColor[
              0.3333080454545455, 0.4501805000000001, 0.943156409090909], 
             UndirectedEdge[278, 295] -> 
             RGBColor[
              0.7107781363636363, 0.7674957272727272, 0.796895181818182], 
             UndirectedEdge[28, 245] -> 
             RGBColor[0.9272825909090909, 0.939611, 0.7060407272727274], 
             UndirectedEdge[14, 186] -> 
             RGBColor[
              0.8330886363636363, 0.8697672727272727, 0.9481920454545454], 
             UndirectedEdge[227, 241] -> 
             RGBColor[
              0.5677014999999999, 0.6487389545454545, 0.9627915909090909], 
             UndirectedEdge[121, 154] -> 
             RGBColor[
              0.9492070909090908, 0.9591505454545454, 0.8676400454545455], 
             UndirectedEdge[187, 230] -> 
             RGBColor[
              0.9756274090909092, 0.9782692727272727, 0.7458924090909089], 
             UndirectedEdge[125, 277] -> 
             RGBColor[
              0.9706517727272728, 0.9389430909090909, 0.6243533181818182], 
             UndirectedEdge[62, 158] -> 
             RGBColor[
              0.8787132272727273, 0.5444899090909091, 0.5752423181818181], 
             UndirectedEdge[20, 61] -> 
             RGBColor[
              0.963157909090909, 0.9717088181818182, 0.9322466363636364], 
             UndirectedEdge[64, 258] -> 
             RGBColor[
              0.6661009090909089, 0.7333823636363636, 0.9507492272727273], 
             UndirectedEdge[94, 294] -> 
             RGBColor[
              0.9863646363636364, 0.9650431818181817, 0.45456254545454516`], 
             UndirectedEdge[125, 237] -> 
             RGBColor[
              0.9618348636363636, 0.9323674545454546, 0.6392780454545455], 
             UndirectedEdge[267, 300] -> 
             RGBColor[
              0.9397577272727271, 0.9537781818181817, 0.9586433181818181], 
             UndirectedEdge[165, 175] -> 
             RGBColor[
              0.9483216818181817, 0.9563869999999999, 0.7080474545454547], 
             UndirectedEdge[67, 263] -> 
             RGBColor[
              0.8350089545454544, 0.8499655454545454, 0.671786909090909], 
             UndirectedEdge[163, 298] -> 
             RGBColor[0.5908023636363635, 0.678679, 0.9609292727272727], 
             UndirectedEdge[92, 149] -> 
             RGBColor[
              0.9067487727272727, 0.9239157272727272, 0.759029818181818], 
             UndirectedEdge[95, 276] -> 
             RGBColor[
              0.805690909090909, 0.8475739090909091, 0.9209308636363636], 
             UndirectedEdge[70, 231] -> 
             RGBColor[
              0.9187186363636364, 0.9370021818181817, 0.9566365909090909], 
             UndirectedEdge[239, 263] -> 
             RGBColor[0.8154548181818182, 0.856616, 0.9780415], 
             UndirectedEdge[116, 204] -> 
             RGBColor[
              0.9596615909090909, 0.9482023636363637, 0.6800120454545453], 
             UndirectedEdge[121, 258] -> 
             RGBColor[
              0.9309408181818181, 0.9472025454545454, 0.9735680454545454], 
             UndirectedEdge[95, 148] -> 
             RGBColor[
              0.7066202727272727, 0.7664301818181818, 0.9133288636363637], 
             UndirectedEdge[60, 77] -> 
             RGBColor[
              0.6751298636363636, 0.5319070909090908, 0.5799248636363636], 
             UndirectedEdge[42, 269] -> 
             RGBColor[
              0.922123909090909, 0.940626909090909, 0.9884927727272728], 
             UndirectedEdge[61, 136] -> 
             RGBColor[
              0.963157909090909, 0.9717088181818182, 0.9322466363636364], 
             UndirectedEdge[95, 251] -> 
             RGBColor[
              0.9807917272727272, 0.984860090909091, 0.9023971818181818], 
             UndirectedEdge[158, 265] -> 
             RGBColor[
              0.7863560454545455, 0.47148254545454543`, 0.5702360909090909], 
             UndirectedEdge[152, 208] -> 
             RGBColor[0.764656909090909, 0.816492, 0.977177], 
             UndirectedEdge[153, 285] -> 
             RGBColor[
              0.7553930909090909, 0.8088380909090909, 0.9762541818181818], 
             UndirectedEdge[61, 279] -> 
             RGBColor[
              0.8708007272727272, 0.8987014545454546, 0.9272404090909091], 
             UndirectedEdge[82, 168] -> 
             RGBColor[
              0.6655862727272726, 0.7353482727272727, 0.9695750000000001], 
             UndirectedEdge[4, 249] -> 
             RGBColor[
              0.8800457272727272, 0.907074909090909, 0.9844793181818181], 
             UndirectedEdge[75, 163] -> 
             RGBColor[
              0.7302858181818179, 0.7885879999999998, 0.9744711818181818], 
             UndirectedEdge[59, 290] -> 
             RGBColor[
              0.43107481818181814`, 0.5468638181818182, 0.9489465454545454], 
             UndirectedEdge[205, 251] -> 
             RGBColor[
              0.9273041363636364, 0.7628316363636365, 0.5737546363636364], 
             UndirectedEdge[183, 224] -> 
             RGBColor[0.5204945909090909, 0.5991215, 0.9601032272727272], 
             UndirectedEdge[170, 178] -> 
             RGBColor[
              0.7570862727272727, 0.8093895454545454, 0.9573203181818182], 
             UndirectedEdge[102, 238] -> 
             RGBColor[
              0.8439198636363637, 0.789359272727273, 0.6203786818181819], 
             UndirectedEdge[89, 236] -> 
             RGBColor[
              0.5892456363636365, 0.676673090909091, 0.9613140909090909], 
             UndirectedEdge[65, 231] -> 
             RGBColor[
              0.9849495909090908, 0.9859256363636364, 0.7859635000000003], 
             UndirectedEdge[25, 245] -> 
             RGBColor[0.7436178181818182, 0.799716, 0.9751702727272726], 
             UndirectedEdge[217, 223] -> 
             RGBColor[
              0.9772954090909091, 0.9613536363636364, 0.6501625909090909], 
             UndirectedEdge[254, 283] -> 
             RGBColor[0.9668105, 0.9716936363636364, 0.7608171363636361], 
             UndirectedEdge[168, 205] -> 
             RGBColor[
              0.8916867727272726, 0.7354544545454547, 0.6058302272727273], 
             UndirectedEdge[142, 243] -> 
             RGBColor[
              0.9281679999999999, 0.9423745454545454, 0.8656333181818183], 
             UndirectedEdge[57, 278] -> 
             RGBColor[
              0.9634853636363637, 0.8802881818181821, 0.4549312272727275], 
             UndirectedEdge[185, 218] -> 
             RGBColor[
              0.6882076363636362, 0.7550359999999998, 0.9704577272727273], 
             UndirectedEdge[16, 248] -> 
             RGBColor[
              0.9447046363636364, 0.8043515454545456, 0.3851064090909089], 
             UndirectedEdge[184, 275] -> 
             RGBColor[
              0.7406013181818183, 0.7917507272727273, 0.744089727272727], 
             UndirectedEdge[127, 191] -> 
             RGBColor[
              0.9281679999999999, 0.9423745454545454, 0.8656333181818183], 
             UndirectedEdge[33, 153] -> 
             RGBColor[0.867304409090909, 0.875195, 0.6750058181818182], 
             UndirectedEdge[83, 243] -> 
             RGBColor[
              0.9760075454545454, 0.9799520909090909, 0.8504891818181819], 
             UndirectedEdge[94, 281] -> 
             RGBColor[
              0.6334271818181818, 0.6965816818181818, 0.7371226818181816], 
             UndirectedEdge[140, 293] -> 
             RGBColor[
              0.6882076363636362, 0.7550359999999998, 0.9704577272727273], 
             UndirectedEdge[126, 220] -> 
             RGBColor[
              0.9492070909090908, 0.9591505454545454, 0.8676400454545455], 
             UndirectedEdge[76, 220] -> 
             RGBColor[
              0.9492070909090908, 0.9591505454545454, 0.8676400454545455], 
             UndirectedEdge[90, 126] -> 
             RGBColor[
              0.9471907272727271, 0.9583167272727272, 0.9010564090909092], 
             UndirectedEdge[35, 102] -> 
             RGBColor[
              0.8739480454545454, 0.8976055454545455, 0.7008150909090911], 
             UndirectedEdge[105, 235] -> 
             RGBColor[
              0.7097675909090909, 0.7653342727272727, 0.6869035454545457], 
             UndirectedEdge[21, 287] -> 
             RGBColor[
              0.9930082727272728, 0.9874537272727273, 0.4803718181818182], 
             UndirectedEdge[160, 245] -> 
             RGBColor[
              0.8789789545454545, 0.7565088181818183, 0.6107753181818183], 
             UndirectedEdge[235, 298] -> 
             RGBColor[
              0.8088382272727273, 0.8464780000000001, 0.6945055454545457], 
             UndirectedEdge[15, 196] -> 
             RGBColor[
              0.8881020909090909, 0.5820699999999999, 0.22820181818181817`], 
             UndirectedEdge[13, 274] -> 
             RGBColor[
              0.546662409090909, 0.6319629545454544, 0.9607848636363636], 
             UndirectedEdge[2, 172] -> 
             RGBColor[
              0.9663052272727273, 0.9706129090909091, 0.7058213181818183], 
             UndirectedEdge[247, 295] -> 
             RGBColor[
              0.7031239545454545, 0.7429237272727272, 0.6610942727272726], 
             UndirectedEdge[159, 225] -> 
             RGBColor[
              0.9241352727272727, 0.940706909090909, 0.9324660454545455], 
             UndirectedEdge[204, 254] -> 
             RGBColor[
              0.9401074545454545, 0.9548528181818182, 0.9862666363636363], 
             UndirectedEdge[61, 252] -> 
             RGBColor[
              0.9893556818181818, 0.9874689090909091, 0.6518013181818184], 
             UndirectedEdge[4, 173] -> 
             RGBColor[
              0.9530179545454545, 0.9257918181818181, 0.6542027727272727], 
             UndirectedEdge[230, 245] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[137, 295] -> 
             RGBColor[
              0.7097675909090909, 0.7653342727272727, 0.6869035454545456], 
             UndirectedEdge[109, 192] -> 
             RGBColor[
              0.45736063636363644`, 0.5696312727272728, 0.9506214545454545], 
             UndirectedEdge[178, 229] -> 
             RGBColor[
              0.7482693636363635, 0.802813909090909, 0.9722450454545455], 
             UndirectedEdge[91, 93] -> 
             RGBColor[
              0.9923825909090909, 0.9904641818181819, 0.7283765909090911], 
             UndirectedEdge[143, 185] -> 
             RGBColor[
              0.7553930909090909, 0.8088380909090909, 0.9762541818181818], 
             UndirectedEdge[139, 273] -> 
             RGBColor[
              0.9401074545454545, 0.9548528181818182, 0.9862666363636363], 
             UndirectedEdge[130, 281] -> 
             RGBColor[
              0.6243579545454545, 0.6928921363636363, 0.9327227272727273], 
             UndirectedEdge[220, 248] -> 
             RGBColor[
              0.9938936818181818, 0.9902172727272727, 0.6399644090909089], 
             UndirectedEdge[88, 273] -> 
             RGBColor[
              0.922123909090909, 0.940626909090909, 0.9884927727272728], 
             UndirectedEdge[24, 218] -> 
             RGBColor[
              0.7570862727272727, 0.8093895454545454, 0.9573203181818182], 
             UndirectedEdge[66, 215] -> 
             RGBColor[
              0.7031239545454545, 0.7429237272727272, 0.6610942727272726], 
             UndirectedEdge[151, 154] -> 
             RGBColor[
              0.9922574545454546, 0.9910662727272728, 0.7779775454545457], 
             UndirectedEdge[8, 64] -> 
             RGBColor[
              0.6572839999999999, 0.7268067272727272, 0.9656739545454545], 
             UndirectedEdge[71, 108] -> 
             RGBColor[
              0.9187186363636364, 0.9370021818181817, 0.9566365909090909], 
             UndirectedEdge[43, 182] -> 
             RGBColor[
              0.9281679999999999, 0.9423745454545454, 0.8656333181818183], 
             UndirectedEdge[58, 297] -> 
             RGBColor[
              0.9206389545454545, 0.9172004545454544, 0.6802314545454544], 
             UndirectedEdge[46, 207] -> 
             RGBColor[
              0.7012036363636364, 0.7627254545454545, 0.9374994090909091], 
             UndirectedEdge[100, 266] -> 
             RGBColor[
              0.7230976363636363, 0.7836086363636363, 0.9730352727272726], 
             UndirectedEdge[12, 151] -> 
             RGBColor[
              0.9471907272727271, 0.9583167272727272, 0.9010564090909092], 
             UndirectedEdge[196, 265] -> 
             RGBColor[
              0.8345133181818183, 0.7520654545454546, 0.6128099545454546], 
             UndirectedEdge[93, 139] -> 
             RGBColor[
              0.9651742727272727, 0.9725426363636365, 0.8988302727272728], 
             UndirectedEdge[30, 104] -> 
             RGBColor[
              0.9241352727272727, 0.940706909090909, 0.9324660454545455], 
             UndirectedEdge[85, 121] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999998, 0.9867054545454546], 
             UndirectedEdge[79, 160] -> 
             RGBColor[0.9268185, 0.7940863636363638, 0.5956311818181819], 
             UndirectedEdge[60, 196] -> 
             RGBColor[
              0.7006613181818183, 0.6451299090909093, 0.6010887727272727], 
             UndirectedEdge[25, 297] -> 
             RGBColor[0.7436178181818182, 0.799716, 0.9751702727272726], 
             UndirectedEdge[9, 133] -> 
             RGBColor[
              0.32188890909090917`, 0.45322572727272736`, 0.9417314545454546],
              UndirectedEdge[151, 192] -> 
             RGBColor[
              0.738965090909091, 0.7925997272727274, 0.8821028636363637], 
             UndirectedEdge[45, 141] -> 
             RGBColor[0.867304409090909, 0.875195, 0.6750058181818182], 
             UndirectedEdge[177, 280] -> 
             RGBColor[
              0.9849495909090908, 0.9859256363636364, 0.7859635000000003], 
             UndirectedEdge[141, 188] -> 
             RGBColor[
              0.7031239545454545, 0.7429237272727272, 0.6610942727272726], 
             UndirectedEdge[129, 183] -> 
             RGBColor[
              0.9187186363636364, 0.9370021818181817, 0.9566365909090909], 
             UndirectedEdge[41, 55] -> 
             RGBColor[
              0.9753750909090909, 0.9811553636363637, 0.9265677272727273], 
             UndirectedEdge[120, 261] -> 
             RGBColor[
              0.8653840909090909, 0.8949967272727273, 0.9514109545454545], 
             UndirectedEdge[71, 279] -> 
             RGBColor[
              0.8653840909090909, 0.8949967272727273, 0.9514109545454545], 
             UndirectedEdge[180, 230] -> 
             RGBColor[
              0.6398150909090909, 0.7106149090909091, 0.9490743181818182], 
             UndirectedEdge[106, 194] -> 
             RGBColor[
              0.9539108636363638, 0.8755179090909094, 0.5955354545454545], 
             UndirectedEdge[90, 234] -> 
             RGBColor[
              0.6081874999999999, 0.6726219545454545, 0.8737916363636364], 
             UndirectedEdge[44, 136] -> 
             RGBColor[
              0.8477502727272728, 0.8818454545454546, 0.9812604090909091], 
             UndirectedEdge[120, 131] -> 
             RGBColor[
              0.8087276363636363, 0.8508435454545453, 0.9814798181818182], 
             UndirectedEdge[44, 279] -> 
             RGBColor[
              0.7553930909090909, 0.8088380909090909, 0.9762541818181818], 
             UndirectedEdge[105, 139] -> 
             RGBColor[
              0.6835698181818182, 0.7495741818181818, 0.9673488636363636], 
             UndirectedEdge[157, 184] -> 
             RGBColor[
              0.7227151818181818, 0.7814855454545455, 0.9546144999999999], 
             UndirectedEdge[83, 149] -> 
             RGBColor[
              0.9756274090909092, 0.9782692727272727, 0.7458924090909089], 
             UndirectedEdge[145, 168] -> 
             RGBColor[
              0.9492070909090908, 0.9591505454545454, 0.8676400454545455], 
             UndirectedEdge[112, 170] -> 
             RGBColor[
              0.5683341363636363, 0.6366990454545454, 0.9449590909090909], 
             UndirectedEdge[159, 270] -> 
             RGBColor[
              0.9187186363636364, 0.9370021818181817, 0.9566365909090909], 
             UndirectedEdge[86, 162] -> 
             RGBColor[
              0.6445471818181818, 0.7185722727272726, 0.9675682727272727], 
             UndirectedEdge[3, 264] -> 
             RGBColor[
              0.9844443181818182, 0.984844909090909, 0.7309676818181816], 
             UndirectedEdge[60, 282] -> 
             RGBColor[
              0.5892456363636365, 0.676673090909091, 0.9613140909090909], 
             UndirectedEdge[135, 186] -> 
             RGBColor[
              0.8330886363636363, 0.8697672727272727, 0.9481920454545454], 
             UndirectedEdge[89, 294] -> 
             RGBColor[
              0.8350089545454544, 0.8499655454545454, 0.671786909090909], 
             UndirectedEdge[201, 203] -> 
             RGBColor[
              0.7444389545454546, 0.7103277272727275, 0.6113633181818182], 
             UndirectedEdge[181, 203] -> 
             RGBColor[
              0.9491875454545455, 0.8333056363636366, 0.2933210454545455], 
             UndirectedEdge[70, 211] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             UndirectedEdge[156, 159] -> 
             RGBColor[
              0.6182613636363635, 0.695804818181818, 0.9658933636363636], 
             UndirectedEdge[56, 270] -> 
             RGBColor[
              0.9807917272727272, 0.984860090909091, 0.9023971818181818], 
             UndirectedEdge[113, 264] -> 
             RGBColor[
              0.9445043181818182, 0.838224090909091, 0.5879667272727274], 
             UndirectedEdge[144, 240] -> 
             RGBColor[
              0.8410230909090908, 0.8760729999999999, 0.9846987272727272], 
             UndirectedEdge[231, 232] -> 
             RGBColor[
              0.7012036363636364, 0.7627254545454545, 0.9374994090909091], 
             UndirectedEdge[90, 248] -> 
             RGBColor[
              0.9918773181818181, 0.9893834545454545, 0.6733807727272726], 
             UndirectedEdge[27, 109] -> 
             RGBColor[
              0.6235080909090909, 0.7017962727272726, 0.9655615454545454], 
             UndirectedEdge[42, 145] -> 
             RGBColor[
              0.9492070909090908, 0.9591505454545454, 0.8676400454545455], 
             UndirectedEdge[160, 230] -> 
             RGBColor[0.9268185, 0.7940863636363638, 0.5956311818181819], 
             UndirectedEdge[247, 251] -> 
             RGBColor[
              0.9772954090909091, 0.9613536363636364, 0.6501625909090909], 
             UndirectedEdge[109, 220] -> 
             RGBColor[0.710653, 0.7680978181818181, 0.8464961363636365], 
             UndirectedEdge[139, 163] -> 
             RGBColor[
              0.7482693636363635, 0.802813909090909, 0.9722450454545455], 
             UndirectedEdge[31, 279] -> 
             RGBColor[0.8749585909090909, 0.899767, 0.8108067272727275], 
             UndirectedEdge[9, 112] -> 
             RGBColor[
              0.2504079545454546, 0.37930986363636365`, 0.9376162272727273], 
             UndirectedEdge[196, 276] -> 
             RGBColor[
              0.7694035000000001, 0.7009379090909091, 0.6065004090909091], 
             UndirectedEdge[137, 251] -> 
             RGBColor[
              0.9839390454545455, 0.9837641818181819, 0.6759718636363639], 
             UndirectedEdge[162, 181] -> 
             RGBColor[
              0.9139953181818181, 0.894789909090909, 0.6544221818181818], 
             UndirectedEdge[96, 236] -> 
             RGBColor[
              0.731532090909091, 0.788061181818182, 0.9396897727272727], 
             UndirectedEdge[251, 295] -> 
             RGBColor[
              0.7012036363636364, 0.7627254545454545, 0.9374994090909091], 
             UndirectedEdge[20, 268] -> 
             RGBColor[0.8154548181818182, 0.856616, 0.9780415], 
             UndirectedEdge[187, 215] -> 
             RGBColor[
              0.9863646363636364, 0.9650431818181817, 0.45456254545454516`], 
             UndirectedEdge[55, 250] -> 
             RGBColor[
              0.731532090909091, 0.788061181818182, 0.9396897727272727], 
             UndirectedEdge[193, 230] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[55, 242] -> 
             RGBColor[
              0.9273041363636364, 0.7628316363636365, 0.5737546363636363], 
             UndirectedEdge[51, 116] -> 
             RGBColor[
              0.9772954090909091, 0.9613536363636364, 0.6501625909090909], 
             UndirectedEdge[130, 203] -> 
             RGBColor[
              0.9539108636363638, 0.8755179090909094, 0.5955354545454546], 
             UndirectedEdge[34, 124] -> 
             RGBColor[
              0.8950003181818182, 0.6084846363636367, 0.5674710454545455], 
             UndirectedEdge[190, 261] -> 
             RGBColor[
              0.8330886363636363, 0.8697672727272727, 0.9481920454545454], 
             UndirectedEdge[76, 85] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999998, 0.9867054545454546], 
             UndirectedEdge[130, 237] -> 
             RGBColor[
              0.9665581818181819, 0.9745797272727272, 0.9414924545454546], 
             UndirectedEdge[175, 183] -> 
             RGBColor[0.9272825909090909, 0.939611, 0.7060407272727274], 
             UndirectedEdge[93, 289] -> 
             RGBColor[
              0.9913720454545454, 0.9883027272727274, 0.6183849545454548], 
             UndirectedEdge[69, 234] -> 
             RGBColor[
              0.39128259090909073`, 0.5028932272727271, 0.9472064090909091], 
             UndirectedEdge[32, 269] -> 
             RGBColor[
              0.9530179545454545, 0.9257918181818181, 0.6542027727272727], 
             UndirectedEdge[226, 243] -> 
             RGBColor[
              0.9671906363636363, 0.9733764545454546, 0.8654139090909092], 
             UndirectedEdge[72, 218] -> 
             RGBColor[0.7261635, 0.6354718181818182, 0.5965343181818181], 
             UndirectedEdge[81, 181] -> 
             RGBColor[
              0.9802262727272727, 0.9437133636363636, 0.4837490909090911], 
             UndirectedEdge[8, 67] -> 
             RGBColor[
              0.9596615909090909, 0.9482023636363637, 0.6800120454545453], 
             UndirectedEdge[145, 156] -> 
             RGBColor[
              0.6843671818181817, 0.7453303636363635, 0.8448212272727273], 
             UndirectedEdge[20, 177] -> 
             RGBColor[
              0.9673157727272728, 0.9727743636363637, 0.8158129545454547], 
             UndirectedEdge[180, 297] -> 
             RGBColor[
              0.5919755454545454, 0.6730373636363636, 0.9642184545454546], 
             UndirectedEdge[140, 216] -> 
             RGBColor[
              0.7092467272727272, 0.7718119999999999, 0.9724644545454546], 
             UndirectedEdge[287, 300] -> 
             RGBColor[
              0.9488269545454544, 0.9574677272727272, 0.7630432727272725], 
             UndirectedEdge[140, 167] -> 
             RGBColor[0.5908023636363635, 0.678679, 0.9609292727272727], 
             UndirectedEdge[248, 285] -> 
             RGBColor[
              0.8744533181818182, 0.8986862727272726, 0.7558109090909089], 
             UndirectedEdge[185, 292] -> 
             RGBColor[
              0.8800457272727272, 0.907074909090909, 0.9844793181818181], 
             UndirectedEdge[23, 241] -> 
             RGBColor[
              0.22613390909090905`, 0.35501145454545446`, 0.9361893636363636],
              UndirectedEdge[10, 48] -> 
             RGBColor[
              0.8565671818181818, 0.8884210909090908, 0.9663356818181819], 
             UndirectedEdge[46, 62] -> 
             RGBColor[
              0.9577412727272727, 0.968004090909091, 0.9564171818181818], 
             UndirectedEdge[15, 276] -> 
             RGBColor[
              0.7438720454545454, 0.5877150909090908, 0.5853364999999999], 
             UndirectedEdge[85, 154] -> 
             RGBColor[
              0.907128909090909, 0.9255985454545455, 0.863626590909091], 
             UndirectedEdge[32, 179] -> 
             RGBColor[
              0.6439086818181818, 0.6749782727272727, 0.6319351818181818], 
             UndirectedEdge[145, 277] -> 
             RGBColor[
              0.9848244545454545, 0.9865277272727273, 0.8355644545454546], 
             UndirectedEdge[58, 164] -> 
             RGBColor[0.867304409090909, 0.875195, 0.6750058181818182], 
             UndirectedEdge[18, 253] -> 
             RGBColor[
              0.45736063636363644`, 0.5696312727272728, 0.9506214545454545], 
             UndirectedEdge[59, 136] -> 
             RGBColor[
              0.7138982727272728, 0.7749099090909092, 0.9695392272727272], 
             UndirectedEdge[232, 288] -> 
             RGBColor[
              0.32658304545454536`, 0.4496534999999999, 0.9423102272727273], 
             UndirectedEdge[136, 177] -> 
             RGBColor[
              0.9673157727272728, 0.9727743636363637, 0.8158129545454547], 
             UndirectedEdge[31, 65] -> 
             RGBColor[
              0.9945240909090909, 0.9906959090909091, 0.6453592727272731], 
             UndirectedEdge[62, 214] -> 
             RGBColor[
              0.9096703181818182, 0.7496803636363638, 0.603604090909091], 
             UndirectedEdge[24, 109] -> 
             RGBColor[
              0.6923867272727273, 0.7561498181818181, 0.9524241363636363], 
             UndirectedEdge[71, 268] -> 
             RGBColor[
              0.8330886363636363, 0.8697672727272727, 0.9481920454545454], 
             UndirectedEdge[64, 118] -> 
             RGBColor[
              0.6182613636363635, 0.695804818181818, 0.9658933636363636], 
             UndirectedEdge[21, 206] -> 
             RGBColor[
              0.9839390454545455, 0.9837641818181819, 0.6759718636363639], 
             UndirectedEdge[6, 124] -> 
             RGBColor[0.6296457727272728, 0.39663036363636395`, 0.563478], 
             UndirectedEdge[7, 140] -> 
             RGBColor[
              0.6882076363636362, 0.7550359999999998, 0.9704577272727273], 
             UndirectedEdge[78, 229] -> 
             RGBColor[
              0.9489243636363636, 0.9614284545454546, 0.971341909090909], 
             UndirectedEdge[67, 213] -> 
             RGBColor[
              0.9206389545454545, 0.9172004545454544, 0.6802314545454544], 
             UndirectedEdge[189, 300] -> 
             RGBColor[
              0.9492070909090908, 0.9591505454545454, 0.8676400454545455], 
             UndirectedEdge[77, 225] -> 
             RGBColor[0.9243895, 0.7287059999999999, 0.5426322727272728], 
             UndirectedEdge[153, 239] -> 
             RGBColor[
              0.8477502727272728, 0.8818454545454546, 0.9812604090909091], 
             UndirectedEdge[7, 168] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999998, 0.9867054545454546], 
             UndirectedEdge[5, 256] -> 
             RGBColor[
              0.5595172272727272, 0.6301234090909091, 0.9598838181818181], 
             UndirectedEdge[193, 200] -> 
             RGBColor[
              0.8350089545454544, 0.8499655454545454, 0.671786909090909], 
             UndirectedEdge[17, 202] -> 
             RGBColor[0.8749585909090909, 0.899767, 0.8108067272727275], 
             UndirectedEdge[12, 220] -> 
             RGBColor[
              0.9492070909090908, 0.9591505454545454, 0.8676400454545455], 
             UndirectedEdge[196, 207] -> 
             RGBColor[
              0.6703328636363637, 0.6197941818181818, 0.5988984090909091], 
             UndirectedEdge[222, 285] -> 
             RGBColor[
              0.8748334545454546, 0.9003690909090909, 0.8604076818181818], 
             UndirectedEdge[169, 227] -> 
             RGBColor[
              0.862316409090909, 0.6808480909090907, 0.5968716818181818], 
             UndirectedEdge[139, 298] -> 
             RGBColor[
              0.7826404545454546, 0.8307179090909091, 0.9749508636363635], 
             UndirectedEdge[210, 241] -> 
             RGBColor[
              0.6067241363636363, 0.6797408636363635, 0.9625721818181818], 
             UndirectedEdge[58, 288] -> 
             RGBColor[
              0.602674818181818, 0.6482816818181817, 0.654973409090909], 
             UndirectedEdge[85, 258] -> 
             RGBColor[
              0.8888626363636363, 0.9136505454545454, 0.9695545909090909], 
             UndirectedEdge[87, 162] -> 
             RGBColor[
              0.6445471818181818, 0.7185722727272726, 0.9675682727272727], 
             UndirectedEdge[222, 248] -> 
             RGBColor[
              0.9938936818181818, 0.9902172727272727, 0.6399644090909089], 
             UndirectedEdge[76, 87] -> 
             RGBColor[
              0.6655862727272726, 0.7353482727272727, 0.9695750000000001], 
             UndirectedEdge[80, 282] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[273, 289] -> 
             RGBColor[
              0.9663052272727273, 0.9706129090909091, 0.7058213181818184], 
             UndirectedEdge[215, 296] -> 
             RGBColor[
              0.7334524090909091, 0.7682594545454546, 0.6632846363636362], 
             UndirectedEdge[142, 277] -> 
             RGBColor[
              0.9187186363636364, 0.9370021818181817, 0.9566365909090909], 
             UndirectedEdge[134, 180] -> 
             RGBColor[
              0.6540486363636364, 0.7208952727272728, 0.9099790454545456], 
             UndirectedEdge[86, 178] -> 
             RGBColor[
              0.4917317272727272, 0.5975352727272727, 0.9533272727272728], 
             UndirectedEdge[3, 210] -> 
             RGBColor[0.9668105, 0.9716936363636364, 0.7608171363636361], 
             UndirectedEdge[79, 176] -> 
             RGBColor[
              0.9489243636363636, 0.9614284545454546, 0.971341909090909], 
             UndirectedEdge[131, 141] -> 
             RGBColor[
              0.9206389545454545, 0.9172004545454544, 0.6802314545454544], 
             UndirectedEdge[150, 256] -> 
             RGBColor[
              0.5595172272727272, 0.6301234090909091, 0.9598838181818181], 
             UndirectedEdge[74, 300] -> 
             RGBColor[
              0.922123909090909, 0.940626909090909, 0.9884927727272728], 
             UndirectedEdge[25, 230] -> 
             RGBColor[
              0.7914573636363637, 0.8372935454545455, 0.9600261363636363], 
             UndirectedEdge[165, 253] -> 
             RGBColor[
              0.6959147272727273, 0.7606839999999999, 0.9717653636363637], 
             UndirectedEdge[223, 295] -> 
             RGBColor[
              0.7031239545454545, 0.7429237272727272, 0.6610942727272726], 
             UndirectedEdge[164, 221] -> 
             RGBColor[
              0.7938262272727273, 0.5289016363636367, 0.5773895454545455], 
             UndirectedEdge[70, 138] -> 
             RGBColor[
              0.8410230909090908, 0.8760729999999999, 0.9846987272727272], 
             UndirectedEdge[165, 224] -> 
             RGBColor[
              0.5415336818181817, 0.6158974999999999, 0.9621099545454546], 
             UndirectedEdge[87, 258] -> 
             RGBColor[
              0.6923867272727273, 0.7561498181818181, 0.9524241363636363], 
             UndirectedEdge[90, 222] -> 
             RGBColor[
              0.9922574545454546, 0.9910662727272728, 0.7779775454545457], 
             UndirectedEdge[163, 185] -> 
             RGBColor[
              0.6882076363636362, 0.7550359999999998, 0.9704577272727273], 
             UndirectedEdge[64, 286] -> 
             RGBColor[
              0.6033599545454545, 0.37386290909090936`, 0.561803090909091], 
             UndirectedEdge[131, 199] -> 
             RGBColor[
              0.9277878636363637, 0.9406917272727272, 0.7610365454545452], 
             UndirectedEdge[2, 49] -> 
             RGBColor[0.9062435, 0.922835, 0.7040340000000003], 
             UndirectedEdge[51, 283] -> 
             RGBColor[
              0.9844443181818182, 0.984844909090909, 0.7309676818181816], 
             UndirectedEdge[66, 187] -> 
             RGBColor[0.7102728636363637, 0.766415, 0.7418993636363634], 
             UndirectedEdge[120, 170] -> 
             RGBColor[
              0.8565671818181818, 0.8884210909090908, 0.9663356818181819], 
             UndirectedEdge[17, 182] -> 
             RGBColor[
              0.9282931363636363, 0.9417724545454544, 0.8160323636363638], 
             UndirectedEdge[156, 179] -> 
             RGBColor[
              0.34817472727272725`, 0.4759931818181818, 0.9434063636363637], 
             UndirectedEdge[199, 284] -> 
             RGBColor[
              0.9930082727272728, 0.9874537272727273, 0.4803718181818182], 
             UndirectedEdge[210, 291] -> 
             RGBColor[
              0.9651742727272727, 0.9725426363636365, 0.8988302727272728], 
             UndirectedEdge[212, 265] -> 
             RGBColor[
              0.4907634999999999, 0.5819247727272726, 0.9562217727272727], 
             UndirectedEdge[85, 173] -> 
             RGBColor[
              0.8929562272727272, 0.8780139090909089, 0.6524154545454546], 
             UndirectedEdge[47, 146] -> 
             RGBColor[
              0.8789789545454545, 0.7565088181818183, 0.6107753181818183], 
             UndirectedEdge[198, 283] -> 
             RGBColor[
              0.9918773181818181, 0.9893834545454545, 0.6733807727272726], 
             UndirectedEdge[168, 212] -> 
             RGBColor[
              0.5651371363636362, 0.6407062272727271, 0.9634541363636364], 
             UndirectedEdge[56, 271] -> 
             RGBColor[
              0.9451743636363634, 0.9574829090909089, 0.9344727727272728], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.6393004545454544, 0.7125808181818181, 0.9679000909090909], 
             UndirectedEdge[159, 191] -> 
             RGBColor[
              0.9281679999999999, 0.9423745454545454, 0.8656333181818183], 
             UndirectedEdge[72, 83] -> 
             RGBColor[0.9268185, 0.7940863636363638, 0.5956311818181819], 
             UndirectedEdge[179, 277] -> 
             RGBColor[
              0.6486320000000001, 0.7171905454545455, 0.9341495909090909], 
             UndirectedEdge[86, 182] -> 
             RGBColor[
              0.6445471818181818, 0.7185722727272726, 0.9675682727272727], 
             UndirectedEdge[80, 293] -> 
             RGBColor[
              0.8888626363636363, 0.9136505454545454, 0.9695545909090909], 
             UndirectedEdge[9, 96] -> 
             RGBColor[
              0.6486320000000001, 0.7171905454545455, 0.9341495909090909], 
             UndirectedEdge[51, 226] -> 
             RGBColor[
              0.9577412727272727, 0.968004090909091, 0.9564171818181818], 
             UndirectedEdge[185, 235] -> 
             RGBColor[0.9062435, 0.922835, 0.7040340000000002], 
             UndirectedEdge[136, 210] -> 
             RGBColor[
              0.9401074545454545, 0.9548528181818182, 0.9862666363636363], 
             UndirectedEdge[78, 284] -> 
             RGBColor[
              0.9751221363636364, 0.9771885454545455, 0.6908965909090911], 
             UndirectedEdge[81, 216] -> 
             RGBColor[
              0.9282931363636363, 0.9417724545454544, 0.8160323636363638], 
             UndirectedEdge[2, 165] -> 
             RGBColor[
              0.9483216818181817, 0.9563869999999999, 0.7080474545454547], 
             UndirectedEdge[181, 216] -> 
             RGBColor[
              0.9139953181818181, 0.894789909090909, 0.6544221818181818], 
             UndirectedEdge[7, 203] -> 
             RGBColor[
              0.8762153181818182, 0.8145887272727275, 0.623597590909091], 
             UndirectedEdge[44, 177] -> 
             RGBColor[0.8749585909090909, 0.899767, 0.8108067272727275], 
             UndirectedEdge[140, 237] -> 
             RGBColor[
              0.7570862727272727, 0.8093895454545454, 0.9573203181818182], 
             UndirectedEdge[38, 124] -> 
             RGBColor[
              0.8950003181818182, 0.6084846363636367, 0.5674710454545455], 
             UndirectedEdge[5, 59] -> 
             RGBColor[
              0.7138982727272728, 0.7749099090909092, 0.9695392272727272], 
             UndirectedEdge[35, 253] -> 
             RGBColor[
              0.7400960454545455, 0.7906700000000001, 0.6890939090909092], 
             UndirectedEdge[200, 231] -> 
             RGBColor[
              0.9772954090909091, 0.9613536363636364, 0.6501625909090909], 
             UndirectedEdge[213, 234] -> 
             RGBColor[
              0.5440980454545453, 0.6239302272727272, 0.9614474090909091], 
             UndirectedEdge[53, 88] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999998, 0.9867054545454546], 
             UndirectedEdge[150, 269] -> 
             RGBColor[
              0.9401074545454545, 0.9548528181818182, 0.9862666363636363], 
             UndirectedEdge[4, 135] -> 
             RGBColor[0.8154548181818182, 0.856616, 0.9780415], 
             UndirectedEdge[91, 139] -> 
             RGBColor[
              0.9673157727272728, 0.9727743636363637, 0.8158129545454547], 
             UndirectedEdge[28, 232] -> 
             RGBColor[
              0.7097675909090909, 0.7653342727272727, 0.6869035454545456], 
             UndirectedEdge[127, 276] -> 
             RGBColor[0.7436178181818182, 0.799716, 0.9751702727272726], 
             UndirectedEdge[60, 103] -> 
             RGBColor[
              0.7227151818181818, 0.7814855454545455, 0.9546144999999999], 
             UndirectedEdge[145, 159] -> 
             RGBColor[
              0.9281679999999999, 0.9423745454545454, 0.8656333181818183], 
             UndirectedEdge[20, 252] -> 
             RGBColor[
              0.9663052272727273, 0.9706129090909091, 0.7058213181818184], 
             UndirectedEdge[80, 128] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[167, 237] -> 
             RGBColor[
              0.7914573636363637, 0.8372935454545455, 0.9600261363636363], 
             UndirectedEdge[24, 291] -> 
             RGBColor[
              0.9739911818181818, 0.9791182727272727, 0.8839055454545455], 
             UndirectedEdge[22, 244] -> 
             RGBColor[
              0.7570862727272727, 0.8093895454545454, 0.9573203181818182], 
             UndirectedEdge[51, 83] -> 
             RGBColor[
              0.9665581818181819, 0.9745797272727272, 0.9414924545454546], 
             UndirectedEdge[29, 229] -> 
             RGBColor[
              0.6309981818181818, 0.7040392727272728, 0.9639990454545455], 
             UndirectedEdge[151, 181] -> 
             RGBColor[
              0.9780847727272727, 0.9434816363636364, 0.5667664090909091], 
             UndirectedEdge[22, 63] -> 
             RGBColor[
              0.6882076363636362, 0.7550359999999998, 0.9704577272727273], 
             UndirectedEdge[163, 292] -> 
             RGBColor[
              0.7482693636363635, 0.802813909090909, 0.9722450454545455], 
             UndirectedEdge[247, 289] -> 
             RGBColor[
              0.9858593636363636, 0.9639624545454546, 0.39956672727272735`], 
             UndirectedEdge[155, 299] -> 
             RGBColor[
              0.6674444090909092, 0.4793851818181821, 0.5728218181818182], 
             UndirectedEdge[31, 71] -> 
             RGBColor[
              0.9849495909090908, 0.9859256363636364, 0.7859635000000003], 
             UndirectedEdge[45, 260] -> 
             RGBColor[
              0.6902832727272727, 0.7577105454545454, 0.9699446363636364], 
             UndirectedEdge[80, 125] -> 
             RGBColor[
              0.9618348636363636, 0.9323674545454546, 0.6392780454545455], 
             UndirectedEdge[97, 261] -> 
             RGBColor[
              0.9397577272727271, 0.9537781818181817, 0.9586433181818181], 
             UndirectedEdge[107, 147] -> 
             RGBColor[
              0.8098487727272727, 0.8486394545454545, 0.804497181818182], 
             UndirectedEdge[15, 286] -> 
             RGBColor[0.847415, 0.358906181818182, 0.1927814090909091], 
             UndirectedEdge[94, 202] -> 
             RGBColor[
              0.8744533181818182, 0.8986862727272726, 0.7558109090909089], 
             UndirectedEdge[86, 130] -> 
             RGBColor[
              0.7012036363636364, 0.7627254545454545, 0.9374994090909091], 
             UndirectedEdge[73, 161] -> 
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692], 
             UndirectedEdge[7, 167] -> 
             RGBColor[0.7225787272727273, 0.78294, 0.9731635454545454], 
             UndirectedEdge[288, 297] -> 
             RGBColor[
              0.5440980454545453, 0.6239302272727272, 0.9614474090909091], 
             UndirectedEdge[15, 46] -> 
             RGBColor[
              0.9189728636363637, 0.7250012727272725, 0.5668028181818181], 
             UndirectedEdge[1, 92] -> 
             RGBColor[
              0.9067487727272727, 0.9239157272727272, 0.759029818181818], 
             UndirectedEdge[85, 213] -> 
             RGBColor[
              0.8410230909090908, 0.8760729999999999, 0.9846987272727272], 
             UndirectedEdge[2, 174] -> 
             RGBColor[0.9062435, 0.922835, 0.7040340000000003], 
             UndirectedEdge[104, 204] -> 
             RGBColor[
              0.963157909090909, 0.9717088181818182, 0.9322466363636364], 
             UndirectedEdge[125, 243] -> 
             RGBColor[
              0.9801011363636363, 0.9443154545454545, 0.5333500454545455], 
             UndirectedEdge[149, 243] -> 
             RGBColor[
              0.9938936818181818, 0.9902172727272727, 0.6399644090909089], 
             UndirectedEdge[35, 175] -> 
             RGBColor[0.992503, 0.986373, 0.42537600000000036`], 
             UndirectedEdge[82, 201] -> 
             RGBColor[
              0.4917317272727272, 0.5975352727272727, 0.9533272727272728], 
             UndirectedEdge[39, 69] -> 
             RGBColor[
              0.7092467272727272, 0.7718119999999999, 0.9724644545454546], 
             UndirectedEdge[5, 204] -> 
             RGBColor[
              0.9401074545454545, 0.9548528181818182, 0.9862666363636363], 
             UndirectedEdge[107, 277] -> 
             RGBColor[
              0.9849495909090908, 0.9859256363636364, 0.7859635000000003], 
             UndirectedEdge[236, 260] -> 
             RGBColor[
              0.5564312727272729, 0.6507750000000001, 0.9582234545454544], 
             UndirectedEdge[11, 51] -> 
             RGBColor[
              0.8330886363636363, 0.8697672727272727, 0.9481920454545454], 
             UndirectedEdge[41, 242] -> 
             RGBColor[
              0.9273041363636364, 0.7628316363636365, 0.5737546363636363], 
             UndirectedEdge[53, 93] -> 
             RGBColor[
              0.9051125454545454, 0.9247647272727273, 0.8970429545454546], 
             UndirectedEdge[82, 293] -> 
             RGBColor[
              0.6235080909090909, 0.7017962727272726, 0.9655615454545454], 
             UndirectedEdge[76, 151] -> 
             RGBColor[
              0.9471907272727271, 0.9583167272727272, 0.9010564090909092], 
             UndirectedEdge[130, 269] -> 
             RGBColor[
              0.9577412727272727, 0.968004090909091, 0.9564171818181818], 
             UndirectedEdge[13, 289] -> 
             RGBColor[0.9062435, 0.922835, 0.7040340000000002], 
             UndirectedEdge[86, 120] -> 
             RGBColor[
              0.5912126363636363, 0.6765668181818181, 0.9623426363636364], 
             UndirectedEdge[86, 284] -> 
             RGBColor[
              0.7097675909090909, 0.7653342727272727, 0.6869035454545457], 
             UndirectedEdge[49, 102] -> 
             RGBColor[
              0.7876885454545455, 0.8340675454545454, 0.979473090909091], 
             UndirectedEdge[27, 299] -> 
             RGBColor[0.6538365454545455, 0.727132, 0.967751909090909], 
             UndirectedEdge[120, 182] -> 
             RGBColor[
              0.8087276363636363, 0.8508435454545453, 0.9814798181818182], 
             UndirectedEdge[97, 182] -> 
             RGBColor[
              0.8831012727272726, 0.9096249999999999, 0.9887121818181819], 
             UndirectedEdge[42, 130] -> 
             RGBColor[
              0.9397577272727271, 0.9537781818181817, 0.9586433181818181], 
             UndirectedEdge[15, 127] -> 
             RGBColor[
              0.862316409090909, 0.6808480909090907, 0.5968716818181818], 
             UndirectedEdge[28, 176] -> 
             RGBColor[
              0.9663052272727273, 0.9706129090909091, 0.7058213181818183], 
             UndirectedEdge[26, 35] -> 
             RGBColor[0.9062435, 0.922835, 0.7040340000000002], 
             UndirectedEdge[44, 59] -> 
             RGBColor[0.621541090909091, 0.7019025454545456, 0.964533], 
             UndirectedEdge[155, 218] -> 
             RGBColor[
              0.7018154999999999, 0.5072891818181821, 0.5755276363636364], 
             UndirectedEdge[65, 155] -> 
             RGBColor[
              0.9208619090909091, 0.6772496363636367, 0.4190955454545457], 
             UndirectedEdge[55, 252] -> 
             RGBColor[
              0.9839390454545455, 0.9837641818181819, 0.6759718636363639], 
             UndirectedEdge[160, 296] -> 
             RGBColor[
              0.6917924090909092, 0.6075678181818184, 0.5938285000000001], 
             UndirectedEdge[88, 147] -> 
             RGBColor[0.764656909090909, 0.816492, 0.977177], 
             UndirectedEdge[204, 243] -> 
             RGBColor[
              0.9671906363636363, 0.9733764545454546, 0.8654139090909092], 
             UndirectedEdge[65, 106] -> 
             RGBColor[
              0.9634853636363637, 0.8802881818181821, 0.4549312272727275], 
             UndirectedEdge[115, 245] -> 
             RGBColor[
              0.9281679999999999, 0.9423745454545454, 0.8656333181818183], 
             UndirectedEdge[60, 205] -> 
             RGBColor[
              0.6834611363636365, 0.5697374545454548, 0.5868766818181819], 
             UndirectedEdge[75, 111] -> 
             RGBColor[
              0.9309408181818181, 0.9472025454545454, 0.9735680454545454], 
             UndirectedEdge[17, 86] -> 
             RGBColor[
              0.7107781363636363, 0.7674957272727272, 0.796895181818182], 
             UndirectedEdge[67, 166] -> 
             RGBColor[
              0.9208931818181818, 0.7051995454545452, 0.2903976818181817], 
             UndirectedEdge[3, 169] -> 
             RGBColor[
              0.928042090909091, 0.728690818181818, 0.3712027727272725], 
             UndirectedEdge[7, 255] -> 
             RGBColor[
              0.8261216818181818, 0.5541310909090912, 0.5806084545454546], 
             UndirectedEdge[211, 231] -> 
             RGBColor[
              0.9187186363636364, 0.9370021818181817, 0.9566365909090909], 
             UndirectedEdge[218, 290] -> 
             RGBColor[
              0.4654459090909089, 0.5747678181818181, 0.9516523636363636], 
             UndirectedEdge[201, 269] -> 
             RGBColor[
              0.7482693636363635, 0.802813909090909, 0.9722450454545455], 
             UndirectedEdge[34, 223] -> 
             RGBColor[0.9684785, 0.9547779999999999, 0.6650873181818181], 
             UndirectedEdge[63, 208] -> 
             RGBColor[0.7225787272727273, 0.78294, 0.9731635454545454], 
             UndirectedEdge[131, 190] -> 
             RGBColor[
              0.7764321818181817, 0.8256140909090908, 0.9782609090909091], 
             UndirectedEdge[27, 181] -> 
             RGBColor[
              0.8929562272727272, 0.8780139090909089, 0.6524154545454546], 
             UndirectedEdge[108, 136] -> 
             RGBColor[
              0.9010848181818181, 0.9238509090909091, 0.9864860454545454], 
             UndirectedEdge[101, 254] -> 
             RGBColor[0.9668105, 0.9716936363636364, 0.7608171363636361], 
             UndirectedEdge[62, 212] -> 
             RGBColor[0.5831206818181818, 0.6549321363636362, 0.961228], 
             UndirectedEdge[69, 195] -> 
             RGBColor[
              0.771319818181818, 0.819669909090909, 0.9182250454545455], 
             UndirectedEdge[136, 252] -> 
             RGBColor[
              0.9663052272727273, 0.9706129090909091, 0.7058213181818184], 
             UndirectedEdge[26, 175] -> 
             RGBColor[0.9062435, 0.922835, 0.7040340000000002], 
             UndirectedEdge[24, 27] -> 
             RGBColor[
              0.8888626363636363, 0.9136505454545454, 0.9695545909090909], 
             UndirectedEdge[231, 266] -> 
             RGBColor[
              0.8653840909090909, 0.8949967272727273, 0.9514109545454545], 
             UndirectedEdge[153, 157] -> 
             RGBColor[
              0.8565671818181818, 0.8884210909090908, 0.9663356818181819], 
             UndirectedEdge[161, 244] -> 
             RGBColor[
              0.8888626363636363, 0.9136505454545454, 0.9695545909090909], 
             UndirectedEdge[128, 150] -> 
             RGBColor[
              0.9489243636363636, 0.9614284545454546, 0.971341909090909], 
             UndirectedEdge[113, 200] -> 
             RGBColor[
              0.9464246363636364, 0.8184223636363637, 0.31156159090909086`], 
             UndirectedEdge[211, 264] -> 
             RGBColor[
              0.9187186363636364, 0.9370021818181817, 0.9566365909090909], 
             UndirectedEdge[144, 232] -> 
             RGBColor[
              0.6235080909090909, 0.7017962727272726, 0.9655615454545454], 
             UndirectedEdge[208, 244] -> 
             RGBColor[
              0.7914573636363637, 0.8372935454545455, 0.9600261363636363], 
             UndirectedEdge[47, 133] -> 
             RGBColor[
              0.6088923181818182, 0.536697181818182, 0.5882883181818181], 
             UndirectedEdge[181, 258] -> 
             RGBColor[
              0.9618348636363636, 0.9323674545454546, 0.6392780454545455], 
             UndirectedEdge[53, 147] -> 
             RGBColor[0.7225787272727273, 0.78294, 0.9731635454545454], 
             UndirectedEdge[123, 267] -> 
             RGBColor[
              0.8330886363636363, 0.8697672727272727, 0.9481920454545454], 
             UndirectedEdge[59, 227] -> 
             RGBColor[0.6748756363636363, 0.743908, 0.9697586363636364], 
             UndirectedEdge[213, 286] -> 
             RGBColor[
              0.8471607727272727, 0.5709070909090912, 0.5826151818181818], 
             UndirectedEdge[16, 126] -> 
             RGBColor[
              0.9000180454545454, 0.7732848181818182, 0.6127820454545454], 
             UndirectedEdge[68, 109] -> 
             RGBColor[
              0.3029795909090909, 0.4248447727272727, 0.9409660454545454], 
             UndirectedEdge[137, 156] -> 
             RGBColor[
              0.6834817727272726, 0.7425668181818181, 0.6852286363636366], 
             UndirectedEdge[181, 202] -> 
             RGBColor[
              0.8606607727272727, 0.8527844545454545, 0.6491965454545454], 
             UndirectedEdge[135, 214] -> 
             RGBColor[
              0.7850176818181818, 0.6514435454545455, 0.5953789545454545], 
             UndirectedEdge[166, 234] -> 
             RGBColor[
              0.5443522727272726, 0.41192931818181794`, 0.5716136363636364], 
             UndirectedEdge[63, 152] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999998, 0.9867054545454546], 
             UndirectedEdge[130, 167] -> 
             RGBColor[
              0.8002742727272727, 0.8438691818181818, 0.9451014090909091], 
             UndirectedEdge[30, 74] -> 
             RGBColor[
              0.9010848181818181, 0.9238509090909091, 0.9864860454545454], 
             UndirectedEdge[31, 177] -> 
             RGBColor[
              0.9945240909090909, 0.9906959090909091, 0.6453592727272731], 
             UndirectedEdge[24, 72] -> 
             RGBColor[0.9268185, 0.7940863636363638, 0.5956311818181819], 
             UndirectedEdge[39, 285] -> 
             RGBColor[
              0.8087276363636363, 0.8508435454545453, 0.9814798181818182], 
             UndirectedEdge[27, 72] -> 
             RGBColor[
              0.8579398636363637, 0.7397328181818182, 0.608768590909091], 
             UndirectedEdge[109, 151] -> 
             RGBColor[0.7086366363636363, 0.767264, 0.8799125000000001], 
             UndirectedEdge[29, 178] -> 
             RGBColor[
              0.43916009090909086`, 0.5520003636363636, 0.9499774545454546], 
             UndirectedEdge[149, 256] -> 
             RGBColor[
              0.5862202727272727, 0.6469642272727273, 0.734434318181818], 
             UndirectedEdge[93, 137] -> 
             RGBColor[
              0.9913720454545454, 0.9883027272727274, 0.6183849545454548], 
             UndirectedEdge[7, 145] -> 
             RGBColor[
              0.907128909090909, 0.9255985454545455, 0.863626590909091], 
             UndirectedEdge[271, 278] -> 
             RGBColor[
              0.9493322272727271, 0.9585484545454545, 0.8180390909090911], 
             UndirectedEdge[15, 135] -> 
             RGBColor[
              0.776686409090909, 0.6136131818181816, 0.5884271363636363], 
             UndirectedEdge[94, 130] -> 
             RGBColor[
              0.9844443181818182, 0.984844909090909, 0.7309676818181816], 
             UndirectedEdge[265, 286] -> 
             RGBColor[
              0.7938262272727273, 0.5289016363636367, 0.5773895454545455], 
             UndirectedEdge[140, 201] -> 
             RGBColor[
              0.5564312727272726, 0.6507749999999999, 0.9582234545454545], 
             UndirectedEdge[29, 259] -> 
             RGBColor[
              0.6398150909090909, 0.7106149090909091, 0.9490743181818182], 
             UndirectedEdge[21, 123] -> 
             RGBColor[
              0.8416525909090908, 0.872376090909091, 0.697596181818182], 
             UndirectedEdge[21, 189] -> 
             RGBColor[
              0.9933884090909091, 0.9891365454545455, 0.5849685909090911], 
             UndirectedEdge[107, 289] -> 
             RGBColor[
              0.9935135454545454, 0.9885344545454546, 0.5353676363636367], 
             UndirectedEdge[17, 66] -> 
             RGBColor[
              0.7107781363636363, 0.7674957272727272, 0.796895181818182], 
             UndirectedEdge[71, 208] -> 
             RGBColor[
              0.8002742727272727, 0.8438691818181818, 0.9451014090909091], 
             UndirectedEdge[6, 289] -> 
             RGBColor[
              0.7097675909090909, 0.7653342727272727, 0.6869035454545457], 
             UndirectedEdge[96, 132] -> 
             RGBColor[
              0.9397577272727271, 0.9537781818181817, 0.9586433181818181], 
             UndirectedEdge[55, 283] -> 
             RGBColor[
              0.9844443181818182, 0.984844909090909, 0.7309676818181816], 
             UndirectedEdge[48, 244] -> 
             RGBColor[
              0.8565671818181818, 0.8884210909090908, 0.9663356818181819], 
             UndirectedEdge[110, 278] -> 
             RGBColor[
              0.986869909090909, 0.9661239090909091, 0.5095583636363638], 
             UndirectedEdge[245, 288] -> 
             RGBColor[
              0.5440980454545453, 0.6239302272727272, 0.9614474090909091], 
             UndirectedEdge[106, 210] -> 
             RGBColor[
              0.9362770454545455, 0.8623666363636366, 0.6253849090909092], 
             UndirectedEdge[176, 296] -> 
             RGBColor[
              0.7138982727272728, 0.7749099090909092, 0.9695392272727272], 
             UndirectedEdge[82, 154] -> 
             RGBColor[0.710653, 0.7680978181818181, 0.8464961363636365], 
             UndirectedEdge[46, 117] -> 
             RGBColor[
              0.8653840909090909, 0.8949967272727273, 0.9514109545454545], 
             UndirectedEdge[249, 258] -> 
             RGBColor[
              0.8888626363636363, 0.9136505454545454, 0.9695545909090909], 
             UndirectedEdge[146, 170] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[18, 129] -> 
             RGBColor[
              0.7012036363636364, 0.7627254545454545, 0.9374994090909091], 
             UndirectedEdge[13, 179] -> 
             RGBColor[
              0.5709364545454545, 0.6562613636363637, 0.9622117272727273], 
             UndirectedEdge[144, 160] -> 
             RGBColor[
              0.8579398636363637, 0.7397328181818182, 0.608768590909091], 
             UndirectedEdge[17, 130] -> 
             RGBColor[
              0.9849495909090908, 0.9859256363636364, 0.7859635000000003], 
             UndirectedEdge[111, 163] -> 
             RGBColor[
              0.7570862727272727, 0.8093895454545454, 0.9573203181818182], 
             UndirectedEdge[107, 251] -> 
             RGBColor[
              0.9849495909090908, 0.9859256363636364, 0.7859635000000003], 
             UndirectedEdge[1, 198] -> 
             RGBColor[
              0.9918773181818181, 0.9893834545454545, 0.6733807727272726], 
             UndirectedEdge[168, 269] -> 
             RGBColor[
              0.922123909090909, 0.940626909090909, 0.9884927727272728], 
             UndirectedEdge[145, 201] -> 
             RGBColor[
              0.7753525454545453, 0.8213375454545454, 0.8513923181818183], 
             UndirectedEdge[197, 226] -> 
             RGBColor[0.8154548181818182, 0.856616, 0.9780415], 
             UndirectedEdge[105, 174] -> 
             RGBColor[
              0.6235080909090909, 0.7017962727272726, 0.9655615454545454], 
             UndirectedEdge[178, 284] -> 
             RGBColor[
              0.7744671363636363, 0.8185739999999999, 0.6917997272727274], 
             UndirectedEdge[201, 202] -> 
             RGBColor[
              0.6559121818181817, 0.7298065454545454, 0.9672388181818181], 
             UndirectedEdge[24, 65] -> 
             RGBColor[
              0.9761326818181818, 0.9793499999999999, 0.8008882272727275], 
             UndirectedEdge[134, 169] -> 
             RGBColor[0.9243895, 0.7287059999999999, 0.5426322727272728], 
             UndirectedEdge[104, 300] -> 
             RGBColor[
              0.9451743636363634, 0.9574829090909089, 0.9344727727272728], 
             UndirectedEdge[168, 225] -> 
             RGBColor[
              0.9451743636363634, 0.9574829090909089, 0.9344727727272728], 
             UndirectedEdge[27, 202] -> 
             RGBColor[
              0.7876885454545455, 0.8340675454545454, 0.979473090909091], 
             UndirectedEdge[113, 187] -> 
             RGBColor[
              0.9535735454545455, 0.8419136363636364, 0.39236668181818163`], 
             UndirectedEdge[7, 201] -> 
             RGBColor[
              0.6882076363636362, 0.7550359999999998, 0.9704577272727273], 
             UndirectedEdge[51, 104] -> 
             RGBColor[
              0.9807917272727272, 0.984860090909091, 0.9023971818181818], 
             UndirectedEdge[2, 183] -> 
             RGBColor[0.9272825909090909, 0.939611, 0.7060407272727274], 
             UndirectedEdge[135, 249] -> 
             RGBColor[
              0.7553930909090909, 0.8088380909090909, 0.9762541818181818], 
             UndirectedEdge[84, 270] -> 
             RGBColor[
              0.9753750909090909, 0.9811553636363637, 0.9265677272727273], 
             UndirectedEdge[114, 116] -> 
             RGBColor[
              0.9206389545454545, 0.9172004545454544, 0.6802314545454544], 
             UndirectedEdge[15, 168] -> 
             RGBColor[
              0.8833554999999998, 0.6976240909090907, 0.5988784090909091], 
             UndirectedEdge[42, 237] -> 
             RGBColor[
              0.9309408181818181, 0.9472025454545454, 0.9735680454545454], 
             UndirectedEdge[40, 140] -> 
             RGBColor[
              0.7659031818181817, 0.8159651818181818, 0.9423955909090909], 
             UndirectedEdge[42, 167] -> 
             RGBColor[0.764656909090909, 0.816492, 0.977177], 
             UndirectedEdge[16, 285] -> 
             RGBColor[
              0.8256444090909092, 0.7145033636363638, 0.6055496818181818], 
             UndirectedEdge[8, 286] -> 
             RGBColor[
              0.8861834090909091, 0.6019090000000004, 0.5823957727272727], 
             UndirectedEdge[9, 236] -> 
             RGBColor[
              0.4047890000000001, 0.5240963636363638, 0.9472716363636364], 
             UndirectedEdge[54, 238] -> 
             RGBColor[
              0.9058399090909093, 0.6571941818181823, 0.24272236363636374`], 
             UndirectedEdge[165, 183] -> 
             RGBColor[
              0.8831012727272726, 0.9096249999999999, 0.9887121818181819], 
             UndirectedEdge[249, 263] -> 
             RGBColor[
              0.7553930909090909, 0.8088380909090909, 0.9762541818181818], 
             UndirectedEdge[33, 98] -> 
             RGBColor[
              0.9725720909090909, 0.9191413636363636, 0.3479481818181817], 
             UndirectedEdge[282, 293] -> 
             RGBColor[
              0.7553930909090909, 0.8088380909090909, 0.9762541818181818], 
             UndirectedEdge[54, 163] -> 
             RGBColor[0.7178322272727272, 0.5976414545454547, 0.5895825], 
             UndirectedEdge[145, 237] -> 
             RGBColor[
              0.9760075454545454, 0.9799520909090909, 0.8504891818181819], 
             UndirectedEdge[140, 181] -> 
             RGBColor[
              0.7611798636363636, 0.773752909090909, 0.6401811818181817], 
             UndirectedEdge[15, 265] -> 
             RGBColor[
              0.8089818636363636, 0.6388426363636361, 0.5916460454545454], 
             UndirectedEdge[144, 230] -> 
             RGBColor[
              0.8888626363636363, 0.9136505454545454, 0.9695545909090909], 
             UndirectedEdge[22, 266] -> 
             RGBColor[
              0.6559121818181817, 0.7298065454545454, 0.9672388181818181], 
             UndirectedEdge[18, 165] -> 
             RGBColor[
              0.6655862727272726, 0.7353482727272727, 0.9695750000000001], 
             UndirectedEdge[17, 140] -> 
             RGBColor[
              0.7754776818181817, 0.8207354545454545, 0.8017913636363638], 
             UndirectedEdge[80, 237] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[7, 127] -> 
             RGBColor[
              0.8410230909090908, 0.8760729999999999, 0.9846987272727272], 
             UndirectedEdge[60, 212] -> 
             RGBColor[0.3569115, 0.47498922727272724`, 0.9445005909090909], 
             UndirectedEdge[53, 270] -> 
             RGBColor[
              0.8976795454545454, 0.9202261818181818, 0.9546298636363637], 
             UndirectedEdge[243, 254] -> 
             RGBColor[
              0.9671906363636363, 0.9733764545454546, 0.8654139090909092], 
             UndirectedEdge[201, 277] -> 
             RGBColor[
              0.7659031818181817, 0.8159651818181818, 0.9423955909090909], 
             UndirectedEdge[288, 296] -> 
             RGBColor[
              0.35691149999999994`, 0.47498922727272724`, 0.9445005909090909],
              UndirectedEdge[93, 273] -> 
             RGBColor[
              0.9651742727272727, 0.9725426363636365, 0.8988302727272728], 
             UndirectedEdge[128, 277] -> 
             RGBColor[
              0.9665581818181819, 0.9745797272727272, 0.9414924545454546], 
             UndirectedEdge[3, 115] -> 
             RGBColor[
              0.9938936818181818, 0.9902172727272727, 0.6399644090909089], 
             UndirectedEdge[74, 123] -> 
             RGBColor[0.8154548181818182, 0.856616, 0.9780415], 
             UndirectedEdge[52, 147] -> 
             RGBColor[
              0.7914573636363637, 0.8372935454545455, 0.9600261363636363], 
             UndirectedEdge[64, 76] -> 
             RGBColor[
              0.6393004545454544, 0.7125808181818181, 0.9679000909090909], 
             UndirectedEdge[132, 260] -> 
             RGBColor[0.764656909090909, 0.816492, 0.977177], 
             UndirectedEdge[171, 285] -> 
             RGBColor[0.8749585909090909, 0.899767, 0.8108067272727275], 
             UndirectedEdge[226, 290] -> 
             RGBColor[
              0.6572839999999999, 0.7268067272727272, 0.9656739545454545], 
             UndirectedEdge[24, 290] -> 
             RGBColor[
              0.666100909090909, 0.7333823636363636, 0.9507492272727273], 
             UndirectedEdge[103, 265] -> 
             RGBColor[
              0.8565671818181818, 0.8884210909090908, 0.9663356818181819], 
             UndirectedEdge[41, 208] -> 
             RGBColor[
              0.8002742727272727, 0.8438691818181818, 0.9451014090909091], 
             UndirectedEdge[80, 179] -> 
             RGBColor[
              0.6398150909090909, 0.7106149090909091, 0.9490743181818182], 
             UndirectedEdge[102, 183] -> 
             RGBColor[
              0.8087276363636363, 0.8508435454545453, 0.9814798181818182], 
             UndirectedEdge[16, 220] -> 
             RGBColor[
              0.9450847727272728, 0.8060343636363638, 0.4897031818181819], 
             UndirectedEdge[52, 217] -> 
             RGBColor[
              0.9665581818181819, 0.9745797272727272, 0.9414924545454546], 
             UndirectedEdge[24, 241] -> 
             RGBColor[0.6155410454545454, 0.6863165, 0.9476474545454545], 
             UndirectedEdge[105, 163] -> 
             RGBColor[
              0.4917317272727272, 0.5975352727272727, 0.9533272727272728], 
             UndirectedEdge[2, 102] -> 
             RGBColor[
              0.8739480454545454, 0.8976055454545455, 0.7008150909090911], 
             UndirectedEdge[49, 54] -> 
             RGBColor[
              0.8496085909090909, 0.7019024545454546, 0.6018167727272727], 
             UndirectedEdge[216, 237] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[89, 281] -> 
             RGBColor[
              0.48207149999999993`, 0.5815040454545454, 0.9543470454545455], 
             UndirectedEdge[145, 167] -> 
             RGBColor[
              0.8097236363636364, 0.8492415454545454, 0.8540981363636364], 
             UndirectedEdge[16, 90] -> 
             RGBColor[
              0.9430684090909092, 0.8052005454545457, 0.5231195454545456], 
             UndirectedEdge[210, 290] -> 
             RGBColor[
              0.6572839999999999, 0.7268067272727272, 0.9656739545454545], 
             UndirectedEdge[152, 242] -> 
             RGBColor[
              0.8916867727272726, 0.7354544545454547, 0.6058302272727273], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.7876885454545455, 0.8340675454545454, 0.979473090909091], 
             UndirectedEdge[77, 282] -> 
             RGBColor[
              0.776686409090909, 0.6136131818181816, 0.5884271363636363], 
             UndirectedEdge[81, 162] -> 
             RGBColor[
              0.9282931363636363, 0.9417724545454544, 0.8160323636363638], 
             UndirectedEdge[34, 247] -> 
             RGBColor[0.9684785, 0.9547779999999999, 0.6650873181818181], 
             UndirectedEdge[7, 60] -> 
             RGBColor[0.6538365454545455, 0.727132, 0.967751909090909], 
             UndirectedEdge[155, 162] -> 
             RGBColor[
              0.8546309545454545, 0.628326181818182, 0.5897686363636364], 
             UndirectedEdge[234, 249] -> 
             RGBColor[
              0.5230589545454544, 0.607154227272727, 0.9594406818181818], 
             UndirectedEdge[118, 234] -> 
             RGBColor[
              0.5440980454545453, 0.6239302272727272, 0.9614474090909091], 
             UndirectedEdge[223, 271] -> 
             RGBColor[
              0.9416780454545453, 0.9339764545454544, 0.6822381818181817], 
             UndirectedEdge[154, 216] -> 
             RGBColor[
              0.9281679999999999, 0.9423745454545454, 0.8656333181818183], 
             UndirectedEdge[147, 247] -> 
             RGBColor[
              0.8021945909090908, 0.8240674545454545, 0.6686962727272726], 
             UndirectedEdge[4, 286] -> 
             RGBColor[
              0.8861834090909091, 0.6019090000000004, 0.5823957727272727], 
             UndirectedEdge[88, 124] -> 
             RGBColor[
              0.8681998636363636, 0.5876830909090911, 0.5846219090909092], 
             UndirectedEdge[23, 136] -> 
             RGBColor[
              0.5595172272727273, 0.6301234090909091, 0.9598838181818181], 
             UndirectedEdge[11, 104] -> 
             RGBColor[0.8385052727272726, 0.873472, 0.9240215], 
             UndirectedEdge[4, 121] -> 
             RGBColor[
              0.922123909090909, 0.940626909090909, 0.9884927727272728], 
             UndirectedEdge[4, 213] -> 
             RGBColor[
              0.9010848181818181, 0.9238509090909091, 0.9864860454545454], 
             UndirectedEdge[198, 204] -> 
             RGBColor[
              0.9651742727272727, 0.9725426363636365, 0.8988302727272728], 
             UndirectedEdge[156, 168] -> 
             RGBColor[
              0.6393004545454544, 0.7125808181818181, 0.9679000909090909], 
             UndirectedEdge[31, 226] -> 
             RGBColor[
              0.9673157727272728, 0.9727743636363637, 0.8158129545454547], 
             UndirectedEdge[36, 242] -> 
             RGBColor[
              0.5290800909090909, 0.42495095454545473`, 0.5772212727272727], 
             UndirectedEdge[216, 269] -> 
             RGBColor[
              0.9010848181818181, 0.9238509090909091, 0.9864860454545454], 
             UndirectedEdge[97, 202] -> 
             RGBColor[
              0.8297667272727272, 0.8676195454545453, 0.9834865454545454], 
             UndirectedEdge[23, 59] -> 
             RGBColor[
              0.3333080454545455, 0.4501805000000001, 0.943156409090909], 
             UndirectedEdge[174, 238] -> 
             RGBColor[
              0.8762153181818182, 0.8145887272727275, 0.623597590909091], 
             UndirectedEdge[86, 97] -> 
             RGBColor[
              0.6655862727272726, 0.7353482727272727, 0.9695750000000001], 
             UndirectedEdge[46, 212] -> 
             RGBColor[
              0.6007544999999999, 0.668083409090909, 0.9313785454545455], 
             UndirectedEdge[59, 291] -> 
             RGBColor[
              0.738965090909091, 0.7925997272727274, 0.8821028636363637], 
             UndirectedEdge[125, 149] -> 
             RGBColor[
              0.9797210000000001, 0.9426326363636364, 0.4287532727272725], 
             UndirectedEdge[32, 80] -> 
             RGBColor[
              0.9618348636363636, 0.9323674545454546, 0.6392780454545455], 
             UndirectedEdge[69, 90] -> 
             RGBColor[
              0.7733361818181816, 0.8205037272727272, 0.884808681818182], 
             UndirectedEdge[215, 229] -> 
             RGBColor[
              0.9596615909090909, 0.9482023636363637, 0.6800120454545453], 
             UndirectedEdge[187, 245] -> 
             RGBColor[
              0.9277878636363637, 0.9406917272727272, 0.7610365454545452], 
             UndirectedEdge[98, 275] -> 
             RGBColor[
              0.9797210000000001, 0.9426326363636364, 0.4287532727272725], 
             UndirectedEdge[252, 280] -> 
             RGBColor[
              0.9839390454545455, 0.9837641818181819, 0.6759718636363639], 
             UndirectedEdge[96, 146] -> 
             RGBColor[
              0.9187186363636364, 0.9370021818181817, 0.9566365909090909], 
             UndirectedEdge[191, 270] -> 
             RGBColor[
              0.9848244545454545, 0.9865277272727273, 0.8355644545454546], 
             UndirectedEdge[40, 120] -> 
             RGBColor[
              0.8653840909090909, 0.8949967272727273, 0.9514109545454545], 
             UndirectedEdge[215, 233] -> 
             RGBColor[
              0.7031239545454545, 0.7429237272727272, 0.6610942727272726], 
             UndirectedEdge[21, 257] -> 
             RGBColor[
              0.9792157272727273, 0.941551909090909, 0.3737574545454547], 
             UndirectedEdge[200, 245] -> 
             RGBColor[
              0.9206389545454545, 0.9172004545454544, 0.6802314545454544], 
             UndirectedEdge[41, 108] -> 
             RGBColor[
              0.9187186363636364, 0.9370021818181817, 0.9566365909090909], 
             UndirectedEdge[63, 73] -> 
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.9942738181818181, 0.9919000909090909, 0.744561181818182], 160 -> 
             RGBColor[
              0.8958957272727274, 0.6201686363636366, 0.23484518181818187`], 
             245 -> RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             155 -> RGBColor[
              0.8471997272727273, 0.3638033636363642, 0.19283181818181824`], 
             213 -> RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 27 -> 
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692], 19 -> 
             RGBColor[
              0.9945240909090909, 0.9906959090909091, 0.6453592727272731], 
             164 -> RGBColor[
              0.7553930909090909, 0.8088380909090909, 0.9762541818181818], 
             190 -> RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             103 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             138 -> RGBColor[
              0.8199839999999999, 0.8592969999999999, 0.982692], 291 -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909092], 28 -> 
             RGBColor[0.992503, 0.986373, 0.42537600000000036`], 195 -> 
             RGBColor[
              0.9862083636363635, 0.9885648181818182, 0.8782266363636364], 
             114 -> RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 93 -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909092], 34 -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             161 -> RGBColor[
              0.8199839999999999, 0.8592969999999999, 0.982692], 22 -> 
             RGBColor[
              0.5564312727272726, 0.6507749999999999, 0.9582234545454545], 
             124 -> RGBColor[
              0.8322593636363638, 0.2489651818181825, 0.17852490909090918`], 
             84 -> RGBColor[
              0.9753750909090909, 0.9811553636363637, 0.9265677272727273], 46 -> 
             RGBColor[
              0.9753750909090909, 0.9811553636363637, 0.9265677272727273], 
             241 -> RGBColor[
              0.2733408181818181, 0.404628909090909, 0.9388777272727273], 185 -> 
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692], 121 -> 
             RGBColor[
              0.9041403636363634, 0.9264009999999998, 0.9907189090909091], 
             126 -> RGBColor[
              0.9041403636363634, 0.9264009999999998, 0.9907189090909091], 
             236 -> RGBColor[
              0.48768909090909107`, 0.5949670000000001, 0.9528118181818181], 
             78 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             254 -> RGBColor[
              0.9401074545454545, 0.9548528181818182, 0.9862666363636363], 
             290 -> RGBColor[
              0.37446054545454527`, 0.4987606363636362, 0.9450812727272727], 
             251 -> 
             RGBColor[
              0.9753750909090909, 0.9811553636363637, 0.9265677272727273], 
             165 -> RGBColor[
              0.9041403636363634, 0.9264009999999998, 0.9907189090909091], 
             100 -> RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             235 -> RGBColor[0.992503, 0.986373, 0.42537600000000036`], 70 -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             234 -> RGBColor[
              0.22613390909090889`, 0.35501145454545435`, 0.9361893636363636],
              257 -> RGBColor[
              0.9659284545454545, 0.8967308181818181, 0.32213890909090903`], 
             135 -> RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             265 -> RGBColor[
              0.7553930909090909, 0.8088380909090909, 0.9762541818181818], 
             111 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             182 -> RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             188 -> RGBColor[
              0.4270321818181818, 0.5442955454545454, 0.948431090909091], 154 -> 
             RGBColor[
              0.9942738181818181, 0.9919000909090909, 0.744561181818182], 269 -> 
             RGBColor[
              0.9401074545454545, 0.9548528181818182, 0.9862666363636363], 
             208 -> RGBColor[
              0.6251734545454546, 0.7065830000000001, 0.9636350909090908], 86 -> 
             RGBColor[
              0.4270321818181818, 0.5442955454545454, 0.948431090909091], 119 -> 
             RGBColor[
              0.9792157272727272, 0.941551909090909, 0.3737574545454544], 140 -> 
             RGBColor[
              0.5564312727272726, 0.6507749999999999, 0.9582234545454545], 85 -> 
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692], 242 -> 
             RGBColor[
              0.8792331818181819, 0.5445079090909094, 0.2209415454545455], 
             117 -> RGBColor[
              0.7553930909090909, 0.8088380909090909, 0.9762541818181818], 47 -> 
             RGBColor[
              0.8958957272727274, 0.6201686363636366, 0.23484518181818187`], 
             81 -> RGBColor[
              0.9945240909090909, 0.9906959090909091, 0.6453592727272731], 
             275 -> RGBColor[
              0.9935135454545455, 0.9885344545454545, 0.5353676363636359], 23 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 110 -> 
             RGBColor[
              0.9792157272727272, 0.941551909090909, 0.3737574545454544], 6 -> 
             RGBColor[
              0.4270321818181818, 0.5442955454545454, 0.948431090909091], 218 -> 
             RGBColor[
              0.5564312727272726, 0.6507749999999999, 0.9582234545454545], 
             108 -> RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             297 -> RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             157 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             270 -> RGBColor[
              0.9753750909090909, 0.9811553636363637, 0.9265677272727273], 33 -> 
             RGBColor[
              0.9792157272727272, 0.941551909090909, 0.3737574545454544], 252 -> 
             RGBColor[0.992503, 0.986373, 0.42537600000000036`], 260 -> 
             RGBColor[
              0.6251734545454546, 0.7065830000000001, 0.9636350909090908], 
             159 -> RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             183 -> RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 99 -> 
             RGBColor[
              0.9792157272727272, 0.941551909090909, 0.3737574545454544], 17 -> 
             RGBColor[
              0.9945240909090909, 0.9906959090909091, 0.6453592727272731], 
             277 -> RGBColor[
              0.9753750909090909, 0.9811553636363637, 0.9265677272727273], 
             104 -> RGBColor[
              0.9862083636363635, 0.9885648181818182, 0.8782266363636364], 79 -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             191 -> RGBColor[
              0.9942738181818181, 0.9919000909090909, 0.744561181818182], 50 -> 
             RGBColor[0.992503, 0.986373, 0.42537600000000036`], 225 -> 
             RGBColor[
              0.9862083636363635, 0.9885648181818182, 0.8782266363636364], 61 -> 
             RGBColor[
              0.9862083636363635, 0.9885648181818182, 0.8782266363636364], 
             196 -> RGBColor[
              0.9136335454545456, 0.6952928181818183, 0.24936572727272732`], 
             1 -> RGBColor[
              0.9935135454545455, 0.9885344545454545, 0.5353676363636359], 
             263 -> RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             201 -> RGBColor[
              0.5564312727272726, 0.6507749999999999, 0.9582234545454545], 
             293 -> 
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692], 184 -> 
             RGBColor[
              0.48768909090909107`, 0.5949670000000001, 0.9528118181818181], 
             106 -> RGBColor[
              0.9324466363636366, 0.7698804545454552, 0.26450318181818194`], 
             206 -> RGBColor[
              0.9753750909090909, 0.9811553636363637, 0.9265677272727273], 
             247 -> RGBColor[
              0.9792157272727272, 0.941551909090909, 0.3737574545454544], 220 -> 
             RGBColor[
              0.9942738181818181, 0.9919000909090909, 0.744561181818182], 107 -> 
             RGBColor[
              0.9945240909090909, 0.9906959090909091, 0.6453592727272731], 
             131 -> RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             127 -> RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             210 -> RGBColor[
              0.9401074545454545, 0.9548528181818182, 0.9862666363636363], 
             181 -> RGBColor[
              0.9659284545454545, 0.8967308181818181, 0.32213890909090903`], 
             194 -> RGBColor[
              0.9753750909090909, 0.9811553636363637, 0.9265677272727273], 
             118 -> RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             276 -> RGBColor[
              0.6251734545454546, 0.7065830000000001, 0.9636350909090908], 
             280 -> RGBColor[
              0.9753750909090909, 0.9811553636363637, 0.9265677272727273], 
             189 -> RGBColor[
              0.9942738181818181, 0.9919000909090909, 0.744561181818182], 168 -> 
             RGBColor[
              0.9041403636363634, 0.9264009999999998, 0.9907189090909091], 41 -> 
             RGBColor[
              0.9753750909090909, 0.9811553636363637, 0.9265677272727273], 14 -> 
             RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 77 -> 
             RGBColor[
              0.8625706363636363, 0.4688471818181815, 0.20703790909090902`], 
             51 -> RGBColor[
              0.9753750909090909, 0.9811553636363637, 0.9265677272727273], 
             179 -> RGBColor[
              0.32188890909090917`, 0.45322572727272736`, 0.9417314545454546],
              223 -> RGBColor[
              0.9792157272727272, 0.941551909090909, 0.3737574545454544], 292 -> 
             RGBColor[
              0.9401074545454545, 0.9548528181818182, 0.9862666363636363], 
             143 -> RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             112 -> RGBColor[0.178927, 0.305394, 0.933501], 197 -> 
             RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 54 -> 
             RGBColor[
              0.8792331818181819, 0.5445079090909094, 0.2209415454545455], 71 -> 
             RGBColor[
              0.9753750909090909, 0.9811553636363637, 0.9265677272727273], 
             177 -> RGBColor[
              0.9945240909090909, 0.9906959090909091, 0.6453592727272731], 
             158 -> RGBColor[0.817319, 0.134127, 0.164218], 226 -> 
             RGBColor[
              0.9401074545454545, 0.9548528181818182, 0.9862666363636363], 
             203 -> RGBColor[
              0.9324466363636366, 0.7698804545454552, 0.26450318181818194`], 
             115 -> RGBColor[
              0.9942738181818181, 0.9919000909090909, 0.744561181818182], 173 -> 
             RGBColor[
              0.9659284545454545, 0.8967308181818181, 0.32213890909090903`], 
             212 -> RGBColor[
              0.22613390909090889`, 0.35501145454545435`, 0.9361893636363636],
              129 -> RGBColor[
              0.9753750909090909, 0.9811553636363637, 0.9265677272727273], 
             279 -> RGBColor[
              0.7553930909090909, 0.8088380909090909, 0.9762541818181818], 26 -> 
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692], 40 -> 
             RGBColor[
              0.9753750909090909, 0.9811553636363637, 0.9265677272727273], 
             146 -> RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             192 -> RGBColor[
              0.48768909090909107`, 0.5949670000000001, 0.9528118181818181], 
             300 -> RGBColor[
              0.9041403636363634, 0.9264009999999998, 0.9907189090909091], 
             221 -> RGBColor[
              0.8322593636363638, 0.2489651818181825, 0.17852490909090918`], 
             62 -> RGBColor[
              0.9401074545454545, 0.9548528181818182, 0.9862666363636363], 
             286 -> RGBColor[
              0.8322593636363638, 0.2489651818181825, 0.17852490909090918`], 
             152 -> RGBColor[
              0.9041403636363634, 0.9264009999999998, 0.9907189090909091], 64 -> 
             RGBColor[
              0.37446054545454527`, 0.4987606363636362, 0.9450812727272727], 
             37 -> RGBColor[
              0.9324466363636366, 0.7698804545454552, 0.26450318181818194`], 
             148 -> 
             RGBColor[
              0.4270321818181818, 0.5442955454545454, 0.948431090909091], 261 -> 
             RGBColor[
              0.9753750909090909, 0.9811553636363637, 0.9265677272727273], 15 -> 
             RGBColor[
              0.8625706363636363, 0.4688471818181815, 0.20703790909090902`], 
             136 -> RGBColor[
              0.9401074545454545, 0.9548528181818182, 0.9862666363636363], 
             198 -> RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909092], 63 -> 
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692], 171 -> 
             RGBColor[
              0.9945240909090909, 0.9906959090909091, 0.6453592727272731], 59 -> 
             RGBColor[
              0.48768909090909107`, 0.5949670000000001, 0.9528118181818181], 
             229 -> RGBColor[
              0.9401074545454545, 0.9548528181818182, 0.9862666363636363], 
             102 -> RGBColor[
              0.7553930909090909, 0.8088380909090909, 0.9762541818181818], 
             299 -> RGBColor[
              0.48768909090909107`, 0.5949670000000001, 0.9528118181818181], 
             128 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 12 -> 
             RGBColor[
              0.9041403636363634, 0.9264009999999998, 0.9907189090909091], 
             222 -> RGBColor[
              0.9942738181818181, 0.9919000909090909, 0.744561181818182], 92 -> 
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692], 271 -> 
             RGBColor[
              0.9041403636363634, 0.9264009999999998, 0.9907189090909091], 
             132 -> RGBColor[
              0.9041403636363634, 0.9264009999999998, 0.9907189090909091], 80 -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             244 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             150 -> RGBColor[
              0.9401074545454545, 0.9548528181818182, 0.9862666363636363], 
             125 -> RGBColor[
              0.9659284545454545, 0.8967308181818181, 0.32213890909090903`], 
             258 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             133 -> RGBColor[
              0.32188890909090917`, 0.45322572727272736`, 0.9417314545454546],
              255 -> RGBColor[
              0.8322593636363638, 0.2489651818181825, 0.17852490909090918`], 
             176 -> RGBColor[
              0.9401074545454545, 0.9548528181818182, 0.9862666363636363], 
             230 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             274 -> RGBColor[
              0.2733408181818181, 0.404628909090909, 0.9388777272727273], 87 -> 
             RGBColor[
              0.4270321818181818, 0.5442955454545454, 0.948431090909091], 130 -> 
             RGBColor[
              0.9753750909090909, 0.9811553636363637, 0.9265677272727273], 35 -> 
             RGBColor[0.992503, 0.986373, 0.42537600000000036`], 31 -> 
             RGBColor[
              0.9945240909090909, 0.9906959090909091, 0.6453592727272731], 18 -> 
             RGBColor[
              0.4270321818181818, 0.5442955454545454, 0.948431090909091], 24 -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             151 -> RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909092], 
             137 -> RGBColor[0.992503, 0.986373, 0.42537600000000036`], 296 -> 
             RGBColor[
              0.48768909090909107`, 0.5949670000000001, 0.9528118181818181], 
             266 -> RGBColor[
              0.7553930909090909, 0.8088380909090909, 0.9762541818181818], 
             283 -> RGBColor[
              0.9935135454545455, 0.9885344545454545, 0.5353676363636359], 
             284 -> RGBColor[0.992503, 0.986373, 0.42537600000000036`], 238 -> 
             RGBColor[
              0.9324466363636366, 0.7698804545454552, 0.26450318181818194`], 
             72 -> RGBColor[
              0.8958957272727274, 0.6201686363636366, 0.23484518181818187`], 
             288 -> RGBColor[
              0.22613390909090889`, 0.35501145454545435`, 0.9361893636363636],
              172 -> RGBColor[
              0.9401074545454545, 0.9548528181818182, 0.9862666363636363], 
             243 -> RGBColor[
              0.9942738181818181, 0.9919000909090909, 0.744561181818182], 88 -> 
             RGBColor[
              0.9041403636363634, 0.9264009999999998, 0.9907189090909091], 
             273 -> RGBColor[
              0.9401074545454545, 0.9548528181818182, 0.9862666363636363], 
             202 -> RGBColor[
              0.7553930909090909, 0.8088380909090909, 0.9762541818181818], 98 -> 
             RGBColor[
              0.9659284545454545, 0.8967308181818181, 0.32213890909090903`], 
             30 -> RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             116 -> 
             RGBColor[
              0.9792157272727272, 0.941551909090909, 0.3737574545454544], 240 -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 73 -> 
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692], 29 -> 
             RGBColor[
              0.32188890909090917`, 0.45322572727272736`, 0.9417314545454546],
              75 -> RGBColor[
              0.9041403636363634, 0.9264009999999998, 0.9907189090909091], 
             200 -> RGBColor[
              0.9792157272727272, 0.941551909090909, 0.3737574545454544], 156 -> 
             RGBColor[
              0.37446054545454527`, 0.4987606363636362, 0.9450812727272727], 
             25 -> RGBColor[
              0.6251734545454546, 0.7065830000000001, 0.9636350909090908], 38 -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 3 -> 
             RGBColor[
              0.9935135454545455, 0.9885344545454545, 0.5353676363636359], 57 -> 
             RGBColor[
              0.9324466363636366, 0.7698804545454552, 0.26450318181818194`], 
             227 -> RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 39 -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             109 -> RGBColor[
              0.4270321818181818, 0.5442955454545454, 0.948431090909091], 256 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 287 -> 
             RGBColor[
              0.9935135454545455, 0.9885344545454545, 0.5353676363636359], 
             239 -> RGBColor[
              0.9401074545454545, 0.9548528181818182, 0.9862666363636363], 
             285 -> RGBColor[
              0.7553930909090909, 0.8088380909090909, 0.9762541818181818], 
             216 -> RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 21 -> 
             RGBColor[0.992503, 0.986373, 0.42537600000000036`], 175 -> 
             RGBColor[0.992503, 0.986373, 0.42537600000000036`], 7 -> 
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692], 13 -> 
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692], 294 -> 
             RGBColor[
              0.9792157272727272, 0.941551909090909, 0.3737574545454544], 193 -> 
             RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 60 -> 
             RGBColor[
              0.48768909090909107`, 0.5949670000000001, 0.9528118181818181], 
             65 -> 
             RGBColor[
              0.9945240909090909, 0.9906959090909091, 0.6453592727272731], 69 -> 
             RGBColor[
              0.5564312727272726, 0.6507749999999999, 0.9582234545454545], 
             217 -> RGBColor[
              0.9753750909090909, 0.9811553636363637, 0.9265677272727273], 
             214 -> RGBColor[
              0.8792331818181819, 0.5445079090909094, 0.2209415454545455], 
             170 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 74 -> 
             RGBColor[
              0.9401074545454545, 0.9548528181818182, 0.9862666363636363], 
             246 -> RGBColor[
              0.9862083636363635, 0.9885648181818182, 0.8782266363636364], 
             264 -> RGBColor[
              0.9753750909090909, 0.9811553636363637, 0.9265677272727273], 
             278 -> RGBColor[
              0.9945240909090909, 0.9906959090909091, 0.6453592727272731], 45 -> 
             RGBColor[
              0.7553930909090909, 0.8088380909090909, 0.9762541818181818], 
             237 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             228 -> RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             180 -> RGBColor[
              0.32188890909090917`, 0.45322572727272736`, 0.9417314545454546],
              53 -> RGBColor[
              0.8199839999999999, 0.8592969999999999, 0.982692], 48 -> 
             RGBColor[
              0.7553930909090909, 0.8088380909090909, 0.9762541818181818], 5 -> 
             RGBColor[
              0.9401074545454545, 0.9548528181818182, 0.9862666363636363], 
             101 -> RGBColor[
              0.9935135454545455, 0.9885344545454545, 0.5353676363636359], 
             267 -> RGBColor[
              0.9753750909090909, 0.9811553636363637, 0.9265677272727273], 
             120 -> RGBColor[
              0.7553930909090909, 0.8088380909090909, 0.9762541818181818], 
             147 -> RGBColor[
              0.6251734545454546, 0.7065830000000001, 0.9636350909090908], 89 -> 
             RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 43 -> 
             RGBColor[
              0.9942738181818181, 0.9919000909090909, 0.744561181818182], 199 -> 
             RGBColor[
              0.9935135454545455, 0.9885344545454545, 0.5353676363636359], 
             268 -> RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             169 -> RGBColor[
              0.8625706363636363, 0.4688471818181815, 0.20703790909090902`], 
             20 -> 
             RGBColor[
              0.9401074545454545, 0.9548528181818182, 0.9862666363636363], 4 -> 
             RGBColor[
              0.9401074545454545, 0.9548528181818182, 0.9862666363636363], 
             167 -> RGBColor[
              0.6251734545454546, 0.7065830000000001, 0.9636350909090908], 
             142 -> RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 16 -> 
             RGBColor[
              0.8958957272727274, 0.6201686363636366, 0.23484518181818187`], 
             281 -> RGBColor[
              0.2733408181818181, 0.404628909090909, 0.9388777272727273], 289 -> 
             RGBColor[0.992503, 0.986373, 0.42537600000000036`], 178 -> 
             RGBColor[
              0.5564312727272726, 0.6507749999999999, 0.9582234545454545], 58 -> 
             RGBColor[
              0.9792157272727272, 0.941551909090909, 0.3737574545454544], 186 -> 
             RGBColor[
              0.9753750909090909, 0.9811553636363637, 0.9265677272727273], 
             122 -> RGBColor[
              0.9401074545454545, 0.9548528181818182, 0.9862666363636363], 
             249 -> RGBColor[
              0.8199839999999999, 0.8592969999999999, 0.982692], 113 -> 
             RGBColor[
              0.9136335454545456, 0.6952928181818183, 0.24936572727272732`], 
             52 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             187 -> RGBColor[
              0.9935135454545455, 0.9885344545454545, 0.5353676363636359], 
             259 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 42 -> 
             RGBColor[
              0.9041403636363634, 0.9264009999999998, 0.9907189090909091], 
             134 -> RGBColor[
              0.9862083636363635, 0.9885648181818182, 0.8782266363636364], 
             248 -> RGBColor[
              0.9935135454545455, 0.9885344545454545, 0.5353676363636359], 
             174 -> RGBColor[
              0.8199839999999999, 0.8592969999999999, 0.982692], 215 -> 
             RGBColor[
              0.9792157272727272, 0.941551909090909, 0.3737574545454544], 83 -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 95 -> 
             RGBColor[
              0.9862083636363635, 0.9885648181818182, 0.8782266363636364], 
             166 -> RGBColor[
              0.8625706363636363, 0.4688471818181815, 0.20703790909090902`], 
             233 -> RGBColor[
              0.4270321818181818, 0.5442955454545454, 0.948431090909091], 295 -> 
             RGBColor[
              0.4270321818181818, 0.5442955454545454, 0.948431090909091], 141 -> 
             RGBColor[
              0.9792157272727272, 0.941551909090909, 0.3737574545454544], 205 -> 
             RGBColor[
              0.8792331818181819, 0.5445079090909094, 0.2209415454545455], 
             224 -> RGBColor[0.178927, 0.305394, 0.933501], 231 -> 
             RGBColor[
              0.9753750909090909, 0.9811553636363637, 0.9265677272727273], 68 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 10 -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             250 -> RGBColor[
              0.48768909090909107`, 0.5949670000000001, 0.9528118181818181], 
             282 -> RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             232 -> RGBColor[
              0.4270321818181818, 0.5442955454545454, 0.948431090909091], 253 -> 
             RGBColor[
              0.48768909090909107`, 0.5949670000000001, 0.9528118181818181], 
             55 -> RGBColor[
              0.9753750909090909, 0.9811553636363637, 0.9265677272727273], 91 -> 
             RGBColor[
              0.9945240909090909, 0.9906959090909091, 0.6453592727272731], 
             105 -> RGBColor[
              0.4270321818181818, 0.5442955454545454, 0.948431090909091], 36 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 123 -> 
             RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 94 -> 
             RGBColor[
              0.9935135454545455, 0.9885344545454545, 0.5353676363636359], 96 -> 
             RGBColor[
              0.9753750909090909, 0.9811553636363637, 0.9265677272727273], 2 -> 
             RGBColor[0.992503, 0.986373, 0.42537600000000036`], 262 -> 
             RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             272 -> RGBColor[0.817319, 0.134127, 0.164218], 97 -> 
             RGBColor[
              0.9041403636363634, 0.9264009999999998, 0.9907189090909091], 
             209 -> RGBColor[
              0.9041403636363634, 0.9264009999999998, 0.9907189090909091], 66 -> 
             RGBColor[
              0.4270321818181818, 0.5442955454545454, 0.948431090909091], 139 -> 
             RGBColor[
              0.9401074545454545, 0.9548528181818182, 0.9862666363636363], 56 -> 
             RGBColor[
              0.9862083636363635, 0.9885648181818182, 0.8782266363636364], 
             144 -> RGBColor[
              0.8199839999999999, 0.8592969999999999, 0.982692], 298 -> 
             RGBColor[
              0.6251734545454546, 0.7065830000000001, 0.9636350909090908], 
             204 -> RGBColor[
              0.9401074545454545, 0.9548528181818182, 0.9862666363636363], 
             207 -> RGBColor[
              0.4270321818181818, 0.5442955454545454, 0.948431090909091], 149 -> 
             RGBColor[
              0.9935135454545455, 0.9885344545454545, 0.5353676363636359], 
             219 -> RGBColor[
              0.7553930909090909, 0.8088380909090909, 0.9762541818181818], 9 -> 
             RGBColor[
              0.32188890909090917`, 0.45322572727272736`, 0.9417314545454546],
              11 -> RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 44 -> 
             RGBColor[
              0.7553930909090909, 0.8088380909090909, 0.9762541818181818], 
             153 -> RGBColor[
              0.7553930909090909, 0.8088380909090909, 0.9762541818181818], 32 -> 
             RGBColor[
              0.9659284545454545, 0.8967308181818181, 0.32213890909090903`], 
             162 -> RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 90 -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909092], 8 -> 
             RGBColor[
              0.9401074545454545, 0.9548528181818182, 0.9862666363636363], 
             163 -> RGBColor[
              0.5564312727272726, 0.6507749999999999, 0.9582234545454545], 49 -> 
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692], 76 -> 
             RGBColor[
              0.9041403636363634, 0.9264009999999998, 0.9907189090909091], 82 -> 
             RGBColor[
              0.4270321818181818, 0.5442955454545454, 0.948431090909091], 67 -> 
             RGBColor[
              0.9792157272727272, 0.941551909090909, 0.3737574545454544], 211 -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999999, 
               0.9867054545454546]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJwtl3k4FGrYxsc2dmbMmGEYZp8hUUJS8qQSUSklLeLUoUhCylJkaUGShISD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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 5}], {
             RGBColor[0.9668105, 0.9716936363636364, 0.7608171363636361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 32}], {
             RGBColor[
             0.9797210000000001, 0.9426326363636364, 0.4287532727272725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 51}], {
             RGBColor[
             0.9844443181818182, 0.984844909090909, 0.7309676818181816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 80}], {
             RGBColor[
             0.9756274090909092, 0.9782692727272727, 0.7458924090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 83}], {
             RGBColor[
             0.9756274090909092, 0.9782692727272727, 0.7458924090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 92}], {
             RGBColor[
             0.9067487727272727, 0.9239157272727272, 0.759029818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 125}], {
             RGBColor[
             0.9797210000000001, 0.9426326363636364, 0.4287532727272725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 128}], {
             RGBColor[
             0.9756274090909092, 0.9782692727272727, 0.7458924090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 142}], {
             RGBColor[
             0.9277878636363637, 0.9406917272727272, 0.7610365454545452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 149}], {
             RGBColor[
             0.9935135454545455, 0.9885344545454545, 0.5353676363636359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 150}], {
             RGBColor[0.9668105, 0.9716936363636364, 0.7608171363636361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 197}], {
             RGBColor[
             0.8421578636363636, 0.8734568181818181, 0.7525919999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 198}], {
             RGBColor[
             0.9918773181818181, 0.9893834545454545, 0.6733807727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 237}], {
             RGBColor[
             0.9756274090909092, 0.9782692727272727, 0.7458924090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 243}], {
             RGBColor[
             0.9938936818181818, 0.9902172727272727, 0.6399644090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 256}], {
             RGBColor[
             0.5862202727272727, 0.6469642272727273, 0.734434318181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 277}], {
             RGBColor[
             0.9844443181818182, 0.984844909090909, 0.7309676818181816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 281}], {
             RGBColor[
             0.6334271818181818, 0.6965816818181818, 0.7371226818181816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 49}], {
             RGBColor[0.9062435, 0.922835, 0.7040340000000003]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{2, 54}], {
             RGBColor[
             0.935868090909091, 0.7654404545454547, 0.32315877272727295`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 102}], {
             RGBColor[
             0.8739480454545454, 0.8976055454545455, 0.7008150909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 165}], {
             RGBColor[
             0.9483216818181817, 0.9563869999999999, 0.7080474545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 172}], {
             RGBColor[
             0.9663052272727273, 0.9706129090909091, 0.7058213181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 174}], {
             RGBColor[0.9062435, 0.922835, 0.7040340000000003]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{2, 183}], {
             RGBColor[0.9272825909090909, 0.939611, 0.7060407272727274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 238}], {
             RGBColor[
             0.9624748181818183, 0.8781267272727276, 0.34493959090909115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 253}], {
             RGBColor[
             0.7400960454545455, 0.7906700000000001, 0.6890939090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 24}], {
             RGBColor[
             0.9756274090909092, 0.9782692727272727, 0.7458924090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 59}], {
             RGBColor[
             0.7406013181818183, 0.7917507272727273, 0.744089727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 65}], {
             RGBColor[
             0.9940188181818181, 0.9896151818181818, 0.5903634545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 72}], {
             RGBColor[
             0.9447046363636364, 0.8043515454545456, 0.3851064090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 106}], {
             RGBColor[
             0.9629800909090911, 0.8792074545454549, 0.39993540909090897`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 115}], {
             RGBColor[
             0.9938936818181818, 0.9902172727272727, 0.6399644090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 155}], {
             RGBColor[
             0.9203566363636364, 0.6761689090909093, 0.3640997272727271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[
             0.9277878636363637, 0.9406917272727272, 0.7610365454545452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 169}], {
             RGBColor[
             0.928042090909091, 0.728690818181818, 0.3712027727272725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 194}], {
             RGBColor[
             0.9844443181818182, 0.984844909090909, 0.7309676818181816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 200}], {
             RGBColor[
             0.9863646363636364, 0.9650431818181817, 0.45456254545454516`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 210}], {
             RGBColor[0.9668105, 0.9716936363636364, 0.7608171363636361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 227}], {
             RGBColor[
             0.9277878636363637, 0.9406917272727272, 0.7610365454545452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 228}], {
             RGBColor[
             0.9277878636363637, 0.9406917272727272, 0.7610365454545452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 241}], {
             RGBColor[
             0.6334271818181818, 0.6965816818181818, 0.7371226818181816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 264}], {
             RGBColor[
             0.9844443181818182, 0.984844909090909, 0.7309676818181816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 290}], {
             RGBColor[
             0.6839870454545454, 0.7436475454545454, 0.7402244545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 291}], {
             RGBColor[
             0.9918773181818181, 0.9893834545454545, 0.6733807727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 8}], {
             RGBColor[
             0.9401074545454545, 0.9548528181818182, 0.9862666363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 15}], {
             RGBColor[
             0.9013390454545454, 0.7118499999999999, 0.5966522727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 62}], {
             RGBColor[
             0.9401074545454545, 0.9548528181818182, 0.9862666363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 85}], {
             RGBColor[
             0.8800457272727272, 0.907074909090909, 0.9844793181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 121}], {
             RGBColor[
             0.922123909090909, 0.940626909090909, 0.9884927727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 135}], {
             RGBColor[0.8154548181818182, 0.856616, 0.9780415]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{4, 158}], {
             RGBColor[
             0.8787132272727273, 0.5444899090909091, 0.5752423181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 173}], {
             RGBColor[
             0.9530179545454545, 0.9257918181818181, 0.6542027727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 186}], {
             RGBColor[
             0.9577412727272727, 0.968004090909091, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 213}], {
             RGBColor[
             0.9010848181818181, 0.9238509090909091, 0.9864860454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 214}], {
             RGBColor[
             0.9096703181818182, 0.7496803636363638, 0.603604090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 249}], {
             RGBColor[
             0.8800457272727272, 0.907074909090909, 0.9844793181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 255}], {
             RGBColor[
             0.8861834090909091, 0.6019090000000004, 0.5823957727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 263}], {
             RGBColor[0.8154548181818182, 0.856616, 0.9780415]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{4, 265}], {
             RGBColor[
             0.8477502727272728, 0.8818454545454546, 0.9812604090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 276}], {
             RGBColor[
             0.7826404545454546, 0.8307179090909091, 0.9749508636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 286}], {
             RGBColor[
             0.8861834090909091, 0.6019090000000004, 0.5823957727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[0.8154548181818182, 0.856616, 0.9780415]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{5, 23}], {
             RGBColor[
             0.5595172272727272, 0.6301234090909091, 0.9598838181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 51}], {
             RGBColor[
             0.9577412727272727, 0.968004090909091, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.7138982727272728, 0.7749099090909092, 0.9695392272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[
             0.9489243636363636, 0.9614284545454546, 0.971341909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 92}], {
             RGBColor[
             0.8800457272727272, 0.907074909090909, 0.9844793181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 101}], {
             RGBColor[0.9668105, 0.9716936363636364, 0.7608171363636361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 128}], {
             RGBColor[
             0.9489243636363636, 0.9614284545454546, 0.971341909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 142}], {
             RGBColor[
             0.9010848181818181, 0.9238509090909091, 0.9864860454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 149}], {
             RGBColor[0.9668105, 0.9716936363636364, 0.7608171363636361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 197}], {
             RGBColor[0.8154548181818182, 0.856616, 0.9780415]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{5, 198}], {
             RGBColor[
             0.9651742727272727, 0.9725426363636365, 0.8988302727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 204}], {
             RGBColor[
             0.9401074545454545, 0.9548528181818182, 0.9862666363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 226}], {
             RGBColor[
             0.9401074545454545, 0.9548528181818182, 0.9862666363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 243}], {
             RGBColor[
             0.9671906363636363, 0.9733764545454546, 0.8654139090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 256}], {
             RGBColor[
             0.5595172272727272, 0.6301234090909091, 0.9598838181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 290}], {
             RGBColor[
             0.6572839999999999, 0.7268067272727272, 0.9656739545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 38}], {
             RGBColor[
             0.6923867272727273, 0.7561498181818181, 0.9524241363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 52}], {
             RGBColor[
             0.6923867272727273, 0.7561498181818181, 0.9524241363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.6235080909090909, 0.7017962727272726, 0.9655615454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 88}], {
             RGBColor[
             0.6655862727272726, 0.7353482727272727, 0.9695750000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 93}], {
             RGBColor[0.7086366363636363, 0.767264, 0.8799125000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 124}], {
             RGBColor[0.6296457727272728, 0.39663036363636395`, 0.563478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 147}], {
             RGBColor[
             0.5261028181818181, 0.6254392727272727, 0.9560330909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 273}], {
             RGBColor[
             0.6835698181818182, 0.7495741818181818, 0.9673488636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 289}], {
             RGBColor[
             0.7097675909090909, 0.7653342727272727, 0.6869035454545457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 42}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999998, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 60}], {
             RGBColor[0.6538365454545455, 0.727132, 0.967751909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 77}], {
             RGBColor[
             0.8412773181818181, 0.6640720909090907, 0.5948649545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 80}], {
             RGBColor[
             0.8888626363636363, 0.9136505454545454, 0.9695545909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 81}], {
             RGBColor[
             0.9072540454545455, 0.9249964545454545, 0.8140256363636366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 82}], {
             RGBColor[
             0.6235080909090909, 0.7017962727272726, 0.9655615454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 103}], {
             RGBColor[
             0.8888626363636363, 0.9136505454545454, 0.9695545909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 127}], {
             RGBColor[
             0.8410230909090908, 0.8760729999999999, 0.9846987272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 130}], {
             RGBColor[
             0.8976795454545454, 0.9202261818181818, 0.9546298636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 140}], {
             RGBColor[
             0.6882076363636362, 0.7550359999999998, 0.9704577272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 145}], {
             RGBColor[
             0.907128909090909, 0.9255985454545455, 0.863626590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 154}], {
             RGBColor[
             0.907128909090909, 0.9255985454545455, 0.863626590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 167}], {
             RGBColor[0.7225787272727273, 0.78294, 0.9731635454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 168}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999998, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 181}], {
             RGBColor[
             0.8929562272727272, 0.8780139090909089, 0.6524154545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 201}], {
             RGBColor[
             0.6882076363636362, 0.7550359999999998, 0.9704577272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 202}], {
             RGBColor[
             0.7876885454545455, 0.8340675454545454, 0.979473090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 203}], {
             RGBColor[
             0.8762153181818182, 0.8145887272727275, 0.623597590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 205}], {
             RGBColor[
             0.8496085909090909, 0.7019024545454546, 0.6018167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 216}], {
             RGBColor[
             0.8410230909090908, 0.8760729999999999, 0.9846987272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 237}], {
             RGBColor[
             0.8888626363636363, 0.9136505454545454, 0.9695545909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 255}], {
             RGBColor[
             0.8261216818181818, 0.5541310909090912, 0.5806084545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 269}], {
             RGBColor[
             0.8800457272727272, 0.907074909090909, 0.9844793181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 282}], {
             RGBColor[
             0.7553930909090909, 0.8088380909090909, 0.9762541818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 293}], {
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 299}], {
             RGBColor[0.6538365454545455, 0.727132, 0.967751909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 14}], {
             RGBColor[0.8154548181818182, 0.856616, 0.9780415]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{8, 64}], {
             RGBColor[
             0.6572839999999999, 0.7268067272727272, 0.9656739545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 67}], {
             RGBColor[
             0.9596615909090909, 0.9482023636363637, 0.6800120454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 69}], {
             RGBColor[
             0.7482693636363635, 0.802813909090909, 0.9722450454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 85}], {
             RGBColor[
             0.8800457272727272, 0.907074909090909, 0.9844793181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 121}], {
             RGBColor[
             0.922123909090909, 0.940626909090909, 0.9884927727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 135}], {
             RGBColor[0.8154548181818182, 0.856616, 0.9780415]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{8, 173}], {
             RGBColor[
             0.9530179545454545, 0.9257918181818181, 0.6542027727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 186}], {
             RGBColor[
             0.9577412727272727, 0.968004090909091, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 213}], {
             RGBColor[
             0.9010848181818181, 0.9238509090909091, 0.9864860454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 234}], {
             RGBColor[0.5831206818181818, 0.6549321363636362, 0.961228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 249}], {
             RGBColor[
             0.8800457272727272, 0.907074909090909, 0.9844793181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 263}], {
             RGBColor[0.8154548181818182, 0.856616, 0.9780415]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{8, 286}], {
             RGBColor[
             0.8861834090909091, 0.6019090000000004, 0.5823957727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 45}], {
             RGBColor[0.538641, 0.6310319090909091, 0.9589928181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 47}], {
             RGBColor[
             0.6088923181818182, 0.536697181818182, 0.5882883181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 96}], {
             RGBColor[
             0.6486320000000001, 0.7171905454545455, 0.9341495909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 112}], {
             RGBColor[
             0.2504079545454546, 0.37930986363636365`, 0.9376162272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 132}], {
             RGBColor[
             0.6130146363636363, 0.6898133636363636, 0.9662251818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 133}], {
             RGBColor[
             0.32188890909090917`, 0.45322572727272736`, 0.9417314545454546]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 141}], {
             RGBColor[
             0.6505523181818182, 0.6973888181818182, 0.6577444545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 146}], {
             RGBColor[
             0.5919755454545454, 0.6730373636363636, 0.9642184545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 236}], {
             RGBColor[
             0.4047890000000001, 0.5240963636363638, 0.9472716363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 22}], {
             RGBColor[
             0.7570862727272727, 0.8093895454545454, 0.9573203181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 48}], {
             RGBColor[
             0.8565671818181818, 0.8884210909090908, 0.9663356818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 63}], {
             RGBColor[
             0.8888626363636363, 0.9136505454545454, 0.9695545909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 71}], {
             RGBColor[
             0.9665581818181819, 0.9745797272727272, 0.9414924545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 73}], {
             RGBColor[
             0.8888626363636363, 0.9136505454545454, 0.9695545909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 100}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 119}], {
             RGBColor[0.9684785, 0.9547779999999999, 0.6650873181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 122}], {
             RGBColor[
             0.9489243636363636, 0.9614284545454546, 0.971341909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 161}], {
             RGBColor[
             0.8888626363636363, 0.9136505454545454, 0.9695545909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 244}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 266}], {
             RGBColor[
             0.8565671818181818, 0.8884210909090908, 0.9663356818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 51}], {
             RGBColor[
             0.8330886363636363, 0.8697672727272727, 0.9481920454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 101}], {
             RGBColor[
             0.8421578636363636, 0.8734568181818181, 0.7525919999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 104}], {
             RGBColor[0.8385052727272726, 0.873472, 0.9240215]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{11, 114}], {
             RGBColor[
             0.7764321818181817, 0.8256140909090908, 0.9782609090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 116}], {
             RGBColor[
             0.8350089545454544, 0.8499655454545454, 0.671786909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 149}], {
             RGBColor[
             0.8421578636363636, 0.8734568181818181, 0.7525919999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 197}], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 198}], {
             RGBColor[
             0.8405216363636363, 0.8743058181818182, 0.8906051363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 204}], {
             RGBColor[0.8154548181818182, 0.856616, 0.9780415]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{11, 243}], {
             RGBColor[0.842538, 0.8751396363636363, 0.8571887727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 254}], {
             RGBColor[0.8154548181818182, 0.856616, 0.9780415]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{11, 283}], {
             RGBColor[
             0.8421578636363636, 0.8734568181818181, 0.7525919999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.9000180454545454, 0.7732848181818182, 0.6127820454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 27}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999998, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.6393004545454544, 0.7125808181818181, 0.9679000909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 76}], {
             RGBColor[
             0.9041403636363634, 0.9264009999999998, 0.9907189090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 87}], {
             RGBColor[
             0.6655862727272726, 0.7353482727272727, 0.9695750000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 151}], {
             RGBColor[
             0.9471907272727271, 0.9583167272727272, 0.9010564090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 154}], {
             RGBColor[
             0.9492070909090908, 0.9591505454545454, 0.8676400454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 181}], {
             RGBColor[
             0.935034409090909, 0.911565909090909, 0.656428909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 192}], {
             RGBColor[
             0.6959147272727273, 0.7606839999999999, 0.9717653636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 220}], {
             RGBColor[
             0.9492070909090908, 0.9591505454545454, 0.8676400454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 239}], {
             RGBColor[
             0.922123909090909, 0.940626909090909, 0.9884927727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 258}], {
             RGBColor[
             0.9309408181818181, 0.9472025454545454, 0.9735680454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 32}], {
             RGBColor[
             0.8929562272727272, 0.8780139090909089, 0.6524154545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 53}], {
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 93}], {
             RGBColor[
             0.9051125454545454, 0.9247647272727273, 0.8970429545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 107}], {
             RGBColor[
             0.9072540454545455, 0.9249964545454545, 0.8140256363636366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 137}], {
             RGBColor[0.9062435, 0.922835, 0.7040340000000002]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{13, 147}], {
             RGBColor[0.7225787272727273, 0.78294, 0.9731635454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 156}], {
             RGBColor[
             0.5972222727272726, 0.679028818181818, 0.9638866363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 179}], {
             RGBColor[
             0.5709364545454545, 0.6562613636363637, 0.9622117272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 251}], {
             RGBColor[
             0.8976795454545454, 0.9202261818181818, 0.9546298636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 270}], {
             RGBColor[
             0.8976795454545454, 0.9202261818181818, 0.9546298636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 271}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999998, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 273}], {
             RGBColor[
             0.8800457272727272, 0.907074909090909, 0.9844793181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 274}], {
             RGBColor[
             0.546662409090909, 0.6319629545454544, 0.9607848636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 277}], {
             RGBColor[
             0.8976795454545454, 0.9202261818181818, 0.9546298636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 282}], {
             RGBColor[
             0.7553930909090909, 0.8088380909090909, 0.9762541818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 289}], {
             RGBColor[0.9062435, 0.922835, 0.7040340000000002]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{14, 67}], {
             RGBColor[
             0.8350089545454544, 0.8499655454545454, 0.671786909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 173}], {
             RGBColor[
             0.8283653181818181, 0.8275549999999999, 0.6459776363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 186}], {
             RGBColor[
             0.8330886363636363, 0.8697672727272727, 0.9481920454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.7764321818181817, 0.8256140909090908, 0.9782609090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 249}], {
             RGBColor[
             0.7553930909090909, 0.8088380909090909, 0.9762541818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 46}], {
             RGBColor[
             0.9189728636363637, 0.7250012727272725, 0.5668028181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 60}], {
             RGBColor[
             0.6751298636363636, 0.5319070909090908, 0.5799248636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.9013390454545454, 0.7118499999999999, 0.5966522727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 77}], {
             RGBColor[
             0.8625706363636363, 0.4688471818181815, 0.20703790909090902`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 82}], {
             RGBColor[0.6448014090909091, 0.5065713636363635, 0.5777345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 103}], {
             RGBColor[
             0.9101559545454545, 0.7184256363636362, 0.5817275454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 127}], {
             RGBColor[
             0.862316409090909, 0.6808480909090907, 0.5968716818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 135}], {
             RGBColor[
             0.776686409090909, 0.6136131818181816, 0.5884271363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 158}], {
             RGBColor[
             0.8399448181818181, 0.30148709090909076`, 0.1856279545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 168}], {
             RGBColor[
             0.8833554999999998, 0.6976240909090907, 0.5988784090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 186}], {
             RGBColor[
             0.9189728636363637, 0.7250012727272725, 0.5668028181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 196}], {
             RGBColor[
             0.8881020909090909, 0.5820699999999999, 0.22820181818181817`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 212}], {
             RGBColor[
             0.5443522727272726, 0.41192931818181794`, 0.5716136363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 214}], {
             RGBColor[
             0.8709019090909091, 0.5066775454545455, 0.21398972727272725`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 225}], {
             RGBColor[0.9243895, 0.7287059999999999, 0.5426322727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 255}], {
             RGBColor[0.847415, 0.358906181818182, 0.1927814090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 265}], {
             RGBColor[
             0.8089818636363636, 0.6388426363636361, 0.5916460454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 276}], {
             RGBColor[
             0.7438720454545454, 0.5877150909090908, 0.5853364999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 286}], {
             RGBColor[0.847415, 0.358906181818182, 0.1927814090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.9375557272727273, 0.7808602727272729, 0.30430131818181816`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 39}], {
             RGBColor[
             0.8789789545454545, 0.7565088181818183, 0.6107753181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 76}], {
             RGBColor[
             0.9000180454545454, 0.7732848181818182, 0.6127820454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 90}], {
             RGBColor[
             0.9430684090909092, 0.8052005454545457, 0.5231195454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 126}], {
             RGBColor[
             0.9000180454545454, 0.7732848181818182, 0.6127820454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 151}], {
             RGBColor[
             0.9430684090909092, 0.8052005454545457, 0.5231195454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 153}], {
             RGBColor[
             0.8256444090909092, 0.7145033636363638, 0.6055496818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 192}], {
             RGBColor[
             0.6917924090909092, 0.6075678181818184, 0.5938285000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 220}], {
             RGBColor[
             0.9450847727272728, 0.8060343636363638, 0.4897031818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 222}], {
             RGBColor[
             0.9450847727272728, 0.8060343636363638, 0.4897031818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 239}], {
             RGBColor[
             0.918001590909091, 0.7875107272727274, 0.6105559090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 248}], {
             RGBColor[
             0.9447046363636364, 0.8043515454545456, 0.3851064090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 285}], {
             RGBColor[
             0.8256444090909092, 0.7145033636363638, 0.6055496818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 40}], {
             RGBColor[
             0.9849495909090908, 0.9859256363636364, 0.7859635000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[
             0.9493322272727271, 0.9585484545454545, 0.8180390909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 66}], {
             RGBColor[
             0.7107781363636363, 0.7674957272727272, 0.796895181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 81}], {
             RGBColor[
             0.9945240909090909, 0.9906959090909091, 0.6453592727272731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 86}], {
             RGBColor[
             0.7107781363636363, 0.7674957272727272, 0.796895181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 94}], {
             RGBColor[
             0.9940188181818181, 0.9896151818181818, 0.5903634545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 97}], {
             RGBColor[
             0.9493322272727271, 0.9585484545454545, 0.8180390909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 120}], {
             RGBColor[0.8749585909090909, 0.899767, 0.8108067272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 130}], {
             RGBColor[
             0.9849495909090908, 0.9859256363636364, 0.7859635000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 140}], {
             RGBColor[
             0.7754776818181817, 0.8207354545454545, 0.8017913636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 162}], {
             RGBColor[
             0.9282931363636363, 0.9417724545454544, 0.8160323636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 169}], {
             RGBColor[
             0.9285473636363636, 0.7297715454545453, 0.42619859090909107`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 178}], {
             RGBColor[
             0.7754776818181817, 0.8207354545454545, 0.8017913636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 182}], {
             RGBColor[
             0.9282931363636363, 0.9417724545454544, 0.8160323636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 201}], {
             RGBColor[
             0.7754776818181817, 0.8207354545454545, 0.8017913636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 202}], {
             RGBColor[0.8749585909090909, 0.899767, 0.8108067272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 294}], {
             RGBColor[
             0.986869909090909, 0.9661239090909091, 0.5095583636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 26}], {
             RGBColor[
             0.6235080909090909, 0.7017962727272726, 0.9655615454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 33}], {
             RGBColor[
             0.7031239545454545, 0.7429237272727272, 0.6610942727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 35}], {
             RGBColor[
             0.7097675909090909, 0.7653342727272727, 0.6869035454545457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 129}], {
             RGBColor[
             0.7012036363636364, 0.7627254545454545, 0.9374994090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 165}], {
             RGBColor[
             0.6655862727272726, 0.7353482727272727, 0.9695750000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 175}], {
             RGBColor[
             0.7097675909090909, 0.7653342727272727, 0.6869035454545457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 183}], {
             RGBColor[
             0.6445471818181818, 0.7185722727272726, 0.9675682727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 184}], {
             RGBColor[
             0.45736063636363644`, 0.5696312727272728, 0.9506214545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.3029795909090909, 0.4248447727272727, 0.9409660454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 253}], {
             RGBColor[
             0.45736063636363644`, 0.5696312727272728, 0.9506214545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 262}], {
             RGBColor[
             0.5589171818181817, 0.6513373636363635, 0.9591237272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 36}], {
             RGBColor[
             0.5595172272727272, 0.6301234090909091, 0.9598838181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 37}], {
             RGBColor[
             0.9362770454545455, 0.8623666363636366, 0.6253849090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 41}], {
             RGBColor[
             0.9577412727272727, 0.968004090909091, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 44}], {
             RGBColor[
             0.8477502727272728, 0.8818454545454546, 0.9812604090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 55}], {
             RGBColor[
             0.9577412727272727, 0.968004090909091, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 61}], {
             RGBColor[
             0.963157909090909, 0.9717088181818182, 0.9322466363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 71}], {
             RGBColor[
             0.9577412727272727, 0.968004090909091, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 108}], {
             RGBColor[
             0.9010848181818181, 0.9238509090909091, 0.9864860454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 136}], {
             RGBColor[
             0.9401074545454545, 0.9548528181818182, 0.9862666363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 152}], {
             RGBColor[
             0.922123909090909, 0.940626909090909, 0.9884927727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 177}], {
             RGBColor[
             0.9673157727272728, 0.9727743636363637, 0.8158129545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 208}], {
             RGBColor[
             0.7826404545454546, 0.8307179090909091, 0.9749508636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 252}], {
             RGBColor[
             0.9663052272727273, 0.9706129090909091, 0.7058213181818184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 268}], {
             RGBColor[0.8154548181818182, 0.856616, 0.9780415]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{20, 279}], {
             RGBColor[
             0.8477502727272728, 0.8818454545454546, 0.9812604090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 280}], {
             RGBColor[
             0.9577412727272727, 0.968004090909091, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 50}], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 74}], {
             RGBColor[
             0.9663052272727273, 0.9706129090909091, 0.7058213181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[0.9272825909090909, 0.939611, 0.7060407272727274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 123}], {
             RGBColor[
             0.8416525909090908, 0.872376090909091, 0.697596181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 189}], {
             RGBColor[
             0.9933884090909091, 0.9891365454545455, 0.5849685909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 206}], {
             RGBColor[
             0.9839390454545455, 0.9837641818181819, 0.6759718636363639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 257}], {
             RGBColor[
             0.9792157272727273, 0.941551909090909, 0.3737574545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 287}], {
             RGBColor[
             0.9930082727272728, 0.9874537272727273, 0.4803718181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 300}], {
             RGBColor[
             0.9483216818181817, 0.9563869999999999, 0.7080474545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.6559121818181817, 0.7298065454545454, 0.9672388181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 63}], {
             RGBColor[
             0.6882076363636362, 0.7550359999999998, 0.9704577272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 70}], {
             RGBColor[
             0.7092467272727272, 0.7718119999999999, 0.9724644545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 73}], {
             RGBColor[
             0.6882076363636362, 0.7550359999999998, 0.9704577272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 100}], {
             RGBColor[
             0.6236167272727271, 0.7045770909090908, 0.9640199090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 119}], {
             RGBColor[
             0.7678234999999999, 0.7961634545454545, 0.6659904545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 122}], {
             RGBColor[
             0.7482693636363635, 0.802813909090909, 0.9722450454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 161}], {
             RGBColor[
             0.6882076363636362, 0.7550359999999998, 0.9704577272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 244}], {
             RGBColor[
             0.7570862727272727, 0.8093895454545454, 0.9573203181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 266}], {
             RGBColor[
             0.6559121818181817, 0.7298065454545454, 0.9672388181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 24}], {
             RGBColor[
             0.5683341363636363, 0.6366990454545454, 0.9449590909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 31}], {
             RGBColor[
             0.5867255454545455, 0.6480449545454545, 0.7894301363636366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 44}], {
             RGBColor[
             0.4671600454545454, 0.5571160454545454, 0.954877590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 59}], {
             RGBColor[
             0.3333080454545455, 0.4501805000000001, 0.943156409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 72}], {
             RGBColor[
             0.5374113636363638, 0.46278131818181834`, 0.584173090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 83}], {
             RGBColor[
             0.5683341363636363, 0.6366990454545454, 0.9449590909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 106}], {
             RGBColor[
             0.5556868181818182, 0.5376372272727276, 0.599002090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 136}], {
             RGBColor[
             0.5595172272727273, 0.6301234090909091, 0.9598838181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 155}], {
             RGBColor[
             0.5130633636363637, 0.3345986818181821, 0.5631664090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 194}], {
             RGBColor[
             0.5771510454545454, 0.6432746818181818, 0.9300343636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 197}], {
             RGBColor[
             0.43486459090909085`, 0.5318865909090909, 0.9516586818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 198}], {
             RGBColor[
             0.5845840454545455, 0.6478132272727273, 0.8724474545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 210}], {
             RGBColor[
             0.5595172272727273, 0.6301234090909091, 0.9598838181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 226}], {
             RGBColor[
             0.5595172272727273, 0.6301234090909091, 0.9598838181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 241}], {
             RGBColor[
             0.22613390909090905`, 0.35501145454545446`, 0.9361893636363636]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 290}], {
             RGBColor[
             0.27669377272727264`, 0.40207731818181813`, 0.9392911363636364]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 291}], {
             RGBColor[
             0.5845840454545455, 0.6478132272727273, 0.8724474545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.8888626363636363, 0.9136505454545454, 0.9695545909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 59}], {
             RGBColor[
             0.7227151818181818, 0.7814855454545455, 0.9546144999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 65}], {
             RGBColor[
             0.9761326818181818, 0.9793499999999999, 0.8008882272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 72}], {
             RGBColor[0.9268185, 0.7940863636363638, 0.5956311818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 87}], {
             RGBColor[
             0.6923867272727273, 0.7561498181818181, 0.9524241363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 106}], {
             RGBColor[
             0.9450939545454546, 0.8689422727272731, 0.6104601818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 109}], {
             RGBColor[
             0.6923867272727273, 0.7561498181818181, 0.9524241363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 155}], {
             RGBColor[0.9024705, 0.6659037272727275, 0.5746245000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 162}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 194}], {
             RGBColor[
             0.9665581818181819, 0.9745797272727272, 0.9414924545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 210}], {
             RGBColor[
             0.9489243636363636, 0.9614284545454546, 0.971341909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 218}], {
             RGBColor[
             0.7570862727272727, 0.8093895454545454, 0.9573203181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 226}], {
             RGBColor[
             0.9489243636363636, 0.9614284545454546, 0.971341909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 227}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 241}], {
             RGBColor[0.6155410454545454, 0.6863165, 0.9476474545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 290}], {
             RGBColor[
             0.666100909090909, 0.7333823636363636, 0.9507492272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 291}], {
             RGBColor[
             0.9739911818181818, 0.9791182727272727, 0.8839055454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 299}], {
             RGBColor[
             0.7227151818181818, 0.7814855454545455, 0.9546144999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 28}], {
             RGBColor[
             0.8088382272727273, 0.8464780000000001, 0.6945055454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 58}], {
             RGBColor[
             0.8021945909090908, 0.8240674545454545, 0.6686962727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 79}], {
             RGBColor[
             0.7914573636363637, 0.8372935454545455, 0.9600261363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 113}], {
             RGBColor[
             0.7694035000000001, 0.7009379090909091, 0.6065004090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 134}], {
             RGBColor[
             0.805690909090909, 0.8475739090909091, 0.9209308636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 144}], {
             RGBColor[0.7225787272727273, 0.78294, 0.9731635454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 160}], {
             RGBColor[
             0.760534590909091, 0.6633758181818183, 0.5992401363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 176}], {
             RGBColor[
             0.7826404545454546, 0.8307179090909091, 0.9749508636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.4735311818181819, 0.5799043636363637, 0.9526832727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 221}], {
             RGBColor[0.7287164090909092, 0.4777740909090913, 0.57108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 230}], {
             RGBColor[
             0.7914573636363637, 0.8372935454545455, 0.9600261363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 232}], {
             RGBColor[
             0.5261028181818181, 0.6254392727272727, 0.9560330909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 245}], {
             RGBColor[0.7436178181818182, 0.799716, 0.9751702727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 288}], {
             RGBColor[
             0.42565368181818175`, 0.5307972272727273, 0.9499122272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 297}], {
             RGBColor[0.7436178181818182, 0.799716, 0.9751702727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 35}], {
             RGBColor[0.9062435, 0.922835, 0.7040340000000002]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{26, 54}], {
             RGBColor[
             0.8496085909090909, 0.7019024545454546, 0.6018167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 75}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999998, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 102}], {
             RGBColor[
             0.7876885454545455, 0.8340675454545454, 0.979473090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 129}], {
             RGBColor[
             0.8976795454545454, 0.9202261818181818, 0.9546298636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 165}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999998, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 175}], {
             RGBColor[0.9062435, 0.922835, 0.7040340000000002]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{26, 183}], {
             RGBColor[
             0.8410230909090908, 0.8760729999999999, 0.9846987272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 224}], {
             RGBColor[0.49945549999999994`, 0.5823455, 0.9580965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 253}], {
             RGBColor[0.6538365454545455, 0.727132, 0.967751909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 262}], {
             RGBColor[
             0.7553930909090909, 0.8088380909090909, 0.9762541818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 42}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999998, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 72}], {
             RGBColor[
             0.8579398636363637, 0.7397328181818182, 0.608768590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 87}], {
             RGBColor[
             0.6235080909090909, 0.7017962727272726, 0.9655615454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 109}], {
             RGBColor[
             0.6235080909090909, 0.7017962727272726, 0.9655615454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 140}], {
             RGBColor[
             0.6882076363636362, 0.7550359999999998, 0.9704577272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 151}], {
             RGBColor[
             0.9051125454545454, 0.9247647272727273, 0.8970429545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 154}], {
             RGBColor[
             0.907128909090909, 0.9255985454545455, 0.863626590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 155}], {
             RGBColor[
             0.8335918636363636, 0.611550181818182, 0.5877619090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 162}], {
             RGBColor[
             0.8410230909090908, 0.8760729999999999, 0.9846987272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 181}], {
             RGBColor[
             0.8929562272727272, 0.8780139090909089, 0.6524154545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 202}], {
             RGBColor[
             0.7876885454545455, 0.8340675454545454, 0.979473090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 203}], {
             RGBColor[
             0.8762153181818182, 0.8145887272727275, 0.623597590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 216}], {
             RGBColor[
             0.8410230909090908, 0.8760729999999999, 0.9846987272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 227}], {
             RGBColor[
             0.8410230909090908, 0.8760729999999999, 0.9846987272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 299}], {
             RGBColor[0.6538365454545455, 0.727132, 0.967751909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 79}], {
             RGBColor[
             0.9751221363636364, 0.9771885454545455, 0.6908965909090912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 144}], {
             RGBColor[0.9062435, 0.922835, 0.7040340000000003]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{28, 160}], {
             RGBColor[
             0.9441993636363637, 0.8032708181818183, 0.3301105909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 176}], {
             RGBColor[
             0.9663052272727273, 0.9706129090909091, 0.7058213181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 221}], {
             RGBColor[
             0.912381181818182, 0.6176690909090913, 0.30195045454545477`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 230}], {
             RGBColor[
             0.9751221363636364, 0.9771885454545455, 0.6908965909090912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 232}], {
             RGBColor[
             0.7097675909090909, 0.7653342727272727, 0.6869035454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 240}], {
             RGBColor[0.9272825909090909, 0.939611, 0.7060407272727274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 245}], {
             RGBColor[0.9272825909090909, 0.939611, 0.7060407272727274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 288}], {
             RGBColor[
             0.6093184545454544, 0.6706922272727271, 0.6807826818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 297}], {
             RGBColor[0.9272825909090909, 0.939611, 0.7060407272727274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 43}], {
             RGBColor[
             0.6580813636363636, 0.7225629090909091, 0.8431463181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 78}], {
             RGBColor[
             0.6398150909090909, 0.7106149090909091, 0.9490743181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 99}], {
             RGBColor[
             0.6505523181818182, 0.6973888181818182, 0.6577444545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 131}], {
             RGBColor[
             0.5919755454545454, 0.6730373636363636, 0.9642184545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 170}], {
             RGBColor[
             0.6398150909090909, 0.7106149090909091, 0.9490743181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 178}], {
             RGBColor[
             0.43916009090909086`, 0.5520003636363636, 0.9499774545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 182}], {
             RGBColor[
             0.5919755454545454, 0.6730373636363636, 0.9642184545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 190}], {
             RGBColor[
             0.5063455454545455, 0.6058024545454546, 0.9557739090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 199}], {
             RGBColor[
             0.6577012272727274, 0.7208800909090909, 0.7385495454545452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 209}], {
             RGBColor[
             0.6130146363636363, 0.6898133636363636, 0.9662251818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 229}], {
             RGBColor[
             0.6309981818181818, 0.7040392727272728, 0.9639990454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 259}], {
             RGBColor[
             0.6398150909090909, 0.7106149090909091, 0.9490743181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 261}], {
             RGBColor[
             0.6486320000000001, 0.7171905454545455, 0.9341495909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 284}], {
             RGBColor[
             0.6571959545454547, 0.7197993636363638, 0.6835537272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 74}], {
             RGBColor[
             0.9010848181818181, 0.9238509090909091, 0.9864860454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 104}], {
             RGBColor[
             0.9241352727272727, 0.940706909090909, 0.9324660454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 123}], {
             RGBColor[
             0.7764321818181817, 0.8256140909090908, 0.9782609090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 189}], {
             RGBColor[
             0.9281679999999999, 0.9423745454545454, 0.8656333181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 236}], {
             RGBColor[0.6748756363636363, 0.743908, 0.9697586363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 260}], {
             RGBColor[0.7436178181818182, 0.799716, 0.9751702727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 267}], {
             RGBColor[
             0.9187186363636364, 0.9370021818181817, 0.9566365909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 287}], {
             RGBColor[
             0.9277878636363637, 0.9406917272727272, 0.7610365454545452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 300}], {
             RGBColor[
             0.8831012727272726, 0.9096249999999999, 0.9887121818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 37}], {
             RGBColor[
             0.9634853636363637, 0.8802881818181821, 0.4549312272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 44}], {
             RGBColor[0.8749585909090909, 0.899767, 0.8108067272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 59}], {
             RGBColor[
             0.741106590909091, 0.7928314545454547, 0.7990855454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 61}], {
             RGBColor[
             0.9903662272727272, 0.9896303636363637, 0.7617929545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 65}], {
             RGBColor[
             0.9945240909090909, 0.9906959090909091, 0.6453592727272731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 71}], {
             RGBColor[
             0.9849495909090908, 0.9859256363636364, 0.7859635000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 136}], {
             RGBColor[
             0.9673157727272728, 0.9727743636363637, 0.8158129545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 177}], {
             RGBColor[
             0.9945240909090909, 0.9906959090909091, 0.6453592727272731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 194}], {
             RGBColor[
             0.9849495909090908, 0.9859256363636364, 0.7859635000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 210}], {
             RGBColor[
             0.9673157727272728, 0.9727743636363637, 0.8158129545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 226}], {
             RGBColor[
             0.9673157727272728, 0.9727743636363637, 0.8158129545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 241}], {
             RGBColor[
             0.6339324545454545, 0.697662409090909, 0.7921185000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 279}], {
             RGBColor[0.8749585909090909, 0.899767, 0.8108067272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 280}], {
             RGBColor[
             0.9849495909090908, 0.9859256363636364, 0.7859635000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 290}], {
             RGBColor[
             0.6844923181818181, 0.7447282727272726, 0.7952202727272729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 291}], {
             RGBColor[
             0.9923825909090909, 0.9904641818181819, 0.7283765909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 80}], {
             RGBColor[
             0.9618348636363636, 0.9323674545454546, 0.6392780454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 92}], {
             RGBColor[
             0.8929562272727272, 0.8780139090909089, 0.6524154545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 107}], {
             RGBColor[
             0.9802262727272727, 0.9437133636363636, 0.4837490909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 125}], {
             RGBColor[
             0.9659284545454545, 0.8967308181818181, 0.32213890909090903`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 128}], {
             RGBColor[
             0.9618348636363636, 0.9323674545454546, 0.6392780454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 142}], {
             RGBColor[
             0.9139953181818181, 0.894789909090909, 0.6544221818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 145}], {
             RGBColor[
             0.9801011363636363, 0.9443154545454545, 0.5333500454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 149}], {
             RGBColor[
             0.9797210000000001, 0.9426326363636364, 0.4287532727272725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 150}], {
             RGBColor[
             0.9530179545454545, 0.9257918181818181, 0.6542027727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 156}], {
             RGBColor[
             0.6701944999999999, 0.6977457272727272, 0.6336100909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 167}], {
             RGBColor[0.7955509545454545, 0.8016569090909091, 0.642887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 179}], {
             RGBColor[
             0.6439086818181818, 0.6749782727272727, 0.6319351818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 205}], {
             RGBColor[
             0.9225808181818183, 0.7206193636363638, 0.27154022727272725`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 237}], {
             RGBColor[
             0.9618348636363636, 0.9323674545454546, 0.6392780454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 256}], {
             RGBColor[
             0.5724277272727273, 0.601062409090909, 0.6278199545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 269}], {
             RGBColor[
             0.9530179545454545, 0.9257918181818181, 0.6542027727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 277}], {
             RGBColor[
             0.9706517727272728, 0.9389430909090909, 0.6243533181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 282}], {
             RGBColor[
             0.8283653181818181, 0.8275549999999999, 0.6459776363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 293}], {
             RGBColor[
             0.8929562272727272, 0.8780139090909089, 0.6524154545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 98}], {
             RGBColor[
             0.9725720909090909, 0.9191413636363636, 0.3479481818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 126}], {
             RGBColor[
             0.9416780454545453, 0.9339764545454544, 0.6822381818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 153}], {
             RGBColor[0.867304409090909, 0.875195, 0.6750058181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 157}], {
             RGBColor[0.9684785, 0.9547779999999999, 0.6650873181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 171}], {
             RGBColor[
             0.986869909090909, 0.9661239090909091, 0.5095583636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 184}], {
             RGBColor[
             0.7334524090909091, 0.7682594545454546, 0.6632846363636362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 222}], {
             RGBColor[0.9867447727272727, 0.966726, 0.5591593181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 248}], {
             RGBColor[
             0.9863646363636364, 0.9650431818181817, 0.45456254545454516`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 275}], {
             RGBColor[
             0.9863646363636364, 0.9650431818181817, 0.45456254545454516`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 285}], {
             RGBColor[0.867304409090909, 0.875195, 0.6750058181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 38}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 52}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 53}], {
             RGBColor[
             0.8888626363636363, 0.9136505454545454, 0.9695545909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 57}], {
             RGBColor[
             0.9450939545454546, 0.8689422727272731, 0.6104601818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 84}], {
             RGBColor[
             0.9665581818181819, 0.9745797272727272, 0.9414924545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 124}], {
             RGBColor[
             0.8950003181818182, 0.6084846363636367, 0.5674710454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 147}], {
             RGBColor[
             0.7914573636363637, 0.8372935454545455, 0.9600261363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 217}], {
             RGBColor[
             0.9665581818181819, 0.9745797272727272, 0.9414924545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 223}], {
             RGBColor[0.9684785, 0.9547779999999999, 0.6650873181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 247}], {
             RGBColor[0.9684785, 0.9547779999999999, 0.6650873181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 270}], {
             RGBColor[
             0.9665581818181819, 0.9745797272727272, 0.9414924545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 295}], {
             RGBColor[
             0.6923867272727273, 0.7561498181818181, 0.9524241363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 102}], {
             RGBColor[
             0.8739480454545454, 0.8976055454545455, 0.7008150909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 129}], {
             RGBColor[
             0.9839390454545455, 0.9837641818181819, 0.6759718636363639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 165}], {
             RGBColor[
             0.9483216818181817, 0.9563869999999999, 0.7080474545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 175}], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 183}], {
             RGBColor[0.9272825909090909, 0.939611, 0.7060407272727274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 224}], {
             RGBColor[0.585715, 0.6458835, 0.6794385000000003]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{35, 253}], {
             RGBColor[
             0.7400960454545455, 0.7906700000000001, 0.6890939090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 262}], {
             RGBColor[
             0.8416525909090908, 0.872376090909091, 0.697596181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 41}], {
             RGBColor[
             0.5771510454545454, 0.6432746818181818, 0.9300343636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 55}], {
             RGBColor[
             0.5771510454545454, 0.6432746818181818, 0.9300343636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 152}], {
             RGBColor[0.5415336818181817, 0.6158975, 0.9621099545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 208}], {
             RGBColor[
             0.4020502272727273, 0.5059885000000001, 0.9485680454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 242}], {
             RGBColor[
             0.5290800909090909, 0.42495095454545473`, 0.5772212727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 250}], {
             RGBColor[
             0.3333080454545455, 0.4501805000000001, 0.943156409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 268}], {
             RGBColor[
             0.43486459090909085`, 0.5318865909090909, 0.9516586818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 41}], {
             RGBColor[
             0.9539108636363638, 0.8755179090909094, 0.5955354545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 44}], {
             RGBColor[
             0.8439198636363637, 0.789359272727273, 0.6203786818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 55}], {
             RGBColor[
             0.9539108636363638, 0.8755179090909094, 0.5955354545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 61}], {
             RGBColor[
             0.9593275000000001, 0.8792226363636366, 0.5713649090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 71}], {
             RGBColor[
             0.9539108636363638, 0.8755179090909094, 0.5955354545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 108}], {
             RGBColor[
             0.8972544090909091, 0.8313647272727276, 0.6256043181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 136}], {
             RGBColor[
             0.9362770454545455, 0.8623666363636366, 0.6253849090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 152}], {
             RGBColor[0.9182935, 0.8481407272727275, 0.6276110454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 161}], {
             RGBColor[
             0.8762153181818182, 0.8145887272727275, 0.623597590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 177}], {
             RGBColor[
             0.9634853636363637, 0.8802881818181821, 0.4549312272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 208}], {
             RGBColor[
             0.7788100454545456, 0.7382317272727277, 0.6140691363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 252}], {
             RGBColor[
             0.9624748181818183, 0.8781267272727276, 0.34493959090909115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 268}], {
             RGBColor[
             0.8116244090909092, 0.7641298181818185, 0.6171597727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 279}], {
             RGBColor[
             0.8439198636363637, 0.789359272727273, 0.6203786818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 280}], {
             RGBColor[
             0.9539108636363638, 0.8755179090909094, 0.5955354545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 52}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 53}], {
             RGBColor[
             0.8888626363636363, 0.9136505454545454, 0.9695545909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 57}], {
             RGBColor[
             0.9450939545454546, 0.8689422727272731, 0.6104601818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 88}], {
             RGBColor[
             0.9309408181818181, 0.9472025454545454, 0.9735680454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 124}], {
             RGBColor[
             0.8950003181818182, 0.6084846363636367, 0.5674710454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 147}], {
             RGBColor[
             0.7914573636363637, 0.8372935454545455, 0.9600261363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 247}], {
             RGBColor[0.9684785, 0.9547779999999999, 0.6650873181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 289}], {
             RGBColor[
             0.9751221363636364, 0.9771885454545455, 0.6908965909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 64}], {
             RGBColor[
             0.6182613636363635, 0.695804818181818, 0.9658933636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 69}], {
             RGBColor[
             0.7092467272727272, 0.7718119999999999, 0.9724644545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 76}], {
             RGBColor[
             0.8831012727272726, 0.9096249999999999, 0.9887121818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 85}], {
             RGBColor[
             0.8410230909090908, 0.8760729999999999, 0.9846987272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 90}], {
             RGBColor[
             0.9261516363636363, 0.9415407272727272, 0.8990496818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 118}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 126}], {
             RGBColor[
             0.8831012727272726, 0.9096249999999999, 0.9887121818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 153}], {
             RGBColor[
             0.8087276363636363, 0.8508435454545453, 0.9814798181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 166}], {
             RGBColor[
             0.862316409090909, 0.6808480909090907, 0.5968716818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 195}], {
             RGBColor[
             0.9241352727272727, 0.940706909090909, 0.9324660454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 234}], {
             RGBColor[
             0.5440980454545453, 0.6239302272727272, 0.9614474090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 239}], {
             RGBColor[
             0.9010848181818181, 0.9238509090909091, 0.9864860454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 248}], {
             RGBColor[
             0.9277878636363637, 0.9406917272727272, 0.7610365454545452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 263}], {
             RGBColor[
             0.7764321818181817, 0.8256140909090908, 0.9782609090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 285}], {
             RGBColor[
             0.8087276363636363, 0.8508435454545453, 0.9814798181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 42}], {
             RGBColor[
             0.9397577272727271, 0.9537781818181817, 0.9586433181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 66}], {
             RGBColor[
             0.7012036363636364, 0.7627254545454545, 0.9374994090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 81}], {
             RGBColor[
             0.9849495909090908, 0.9859256363636364, 0.7859635000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 86}], {
             RGBColor[
             0.7012036363636364, 0.7627254545454545, 0.9374994090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 94}], {
             RGBColor[
             0.9844443181818182, 0.984844909090909, 0.7309676818181816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 97}], {
             RGBColor[
             0.9397577272727271, 0.9537781818181817, 0.9586433181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 120}], {
             RGBColor[
             0.8653840909090909, 0.8949967272727273, 0.9514109545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 130}], {
             RGBColor[
             0.9753750909090909, 0.9811553636363637, 0.9265677272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 140}], {
             RGBColor[
             0.7659031818181817, 0.8159651818181818, 0.9423955909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 162}], {
             RGBColor[
             0.9187186363636364, 0.9370021818181817, 0.9566365909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 169}], {
             RGBColor[
             0.9189728636363637, 0.7250012727272725, 0.5668028181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 178}], {
             RGBColor[
             0.7659031818181817, 0.8159651818181818, 0.9423955909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 182}], {
             RGBColor[
             0.9187186363636364, 0.9370021818181817, 0.9566365909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 201}], {
             RGBColor[
             0.7659031818181817, 0.8159651818181818, 0.9423955909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 202}], {
             RGBColor[
             0.8653840909090909, 0.8949967272727273, 0.9514109545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 55}], {
             RGBColor[
             0.9753750909090909, 0.9811553636363637, 0.9265677272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 108}], {
             RGBColor[
             0.9187186363636364, 0.9370021818181817, 0.9566365909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 152}], {
             RGBColor[
             0.9397577272727271, 0.9537781818181817, 0.9586433181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 208}], {
             RGBColor[
             0.8002742727272727, 0.8438691818181818, 0.9451014090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 219}], {
             RGBColor[
             0.8653840909090909, 0.8949967272727273, 0.9514109545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 242}], {
             RGBColor[
             0.9273041363636364, 0.7628316363636365, 0.5737546363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.731532090909091, 0.788061181818182, 0.9396897727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 252}], {
             RGBColor[
             0.9839390454545455, 0.9837641818181819, 0.6759718636363639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 268}], {
             RGBColor[
             0.8330886363636363, 0.8697672727272727, 0.9481920454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 80}], {
             RGBColor[
             0.9309408181818181, 0.9472025454545454, 0.9735680454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 81}], {
             RGBColor[
             0.9493322272727271, 0.9585484545454545, 0.8180390909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 82}], {
             RGBColor[
             0.6655862727272726, 0.7353482727272727, 0.9695750000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 87}], {
             RGBColor[
             0.6655862727272726, 0.7353482727272727, 0.9695750000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 130}], {
             RGBColor[
             0.9397577272727271, 0.9537781818181817, 0.9586433181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 140}], {
             RGBColor[
             0.7302858181818179, 0.7885879999999998, 0.9744711818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 145}], {
             RGBColor[
             0.9492070909090908, 0.9591505454545454, 0.8676400454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 162}], {
             RGBColor[
             0.8831012727272726, 0.9096249999999999, 0.9887121818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 167}], {
             RGBColor[0.764656909090909, 0.816492, 0.977177]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{42, 181}], {
             RGBColor[
             0.935034409090909, 0.911565909090909, 0.656428909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 201}], {
             RGBColor[
             0.7302858181818179, 0.7885879999999998, 0.9744711818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 202}], {
             RGBColor[
             0.8297667272727272, 0.8676195454545453, 0.9834865454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 203}], {
             RGBColor[0.9182935, 0.8481407272727275, 0.6276110454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 216}], {
             RGBColor[
             0.8831012727272726, 0.9096249999999999, 0.9887121818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 237}], {
             RGBColor[
             0.9309408181818181, 0.9472025454545454, 0.9735680454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 269}], {
             RGBColor[
             0.922123909090909, 0.940626909090909, 0.9884927727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 293}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999998, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 299}], {
             RGBColor[
             0.6959147272727273, 0.7606839999999999, 0.9717653636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 66}], {
             RGBColor[0.710653, 0.7680978181818181, 0.8464961363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 78}], {
             RGBColor[
             0.9760075454545454, 0.9799520909090909, 0.8504891818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 97}], {
             RGBColor[
             0.9492070909090908, 0.9591505454545454, 0.8676400454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 99}], {
             RGBColor[0.9867447727272727, 0.966726, 0.5591593181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 178}], {
             RGBColor[
             0.7753525454545453, 0.8213375454545454, 0.8513923181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 182}], {
             RGBColor[
             0.9281679999999999, 0.9423745454545454, 0.8656333181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 199}], {
             RGBColor[
             0.9938936818181818, 0.9902172727272727, 0.6399644090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 215}], {
             RGBColor[0.9867447727272727, 0.966726, 0.5591593181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 229}], {
             RGBColor[
             0.9671906363636363, 0.9733764545454546, 0.8654139090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 233}], {
             RGBColor[0.710653, 0.7680978181818181, 0.8464961363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 259}], {
             RGBColor[
             0.9760075454545454, 0.9799520909090909, 0.8504891818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 261}], {
             RGBColor[
             0.9848244545454545, 0.9865277272727273, 0.8355644545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 284}], {
             RGBColor[
             0.9933884090909091, 0.9891365454545455, 0.5849685909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 59}], {
             RGBColor[0.621541090909091, 0.7019025454545456, 0.964533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 61}], {
             RGBColor[
             0.8708007272727272, 0.8987014545454546, 0.9272404090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 71}], {
             RGBColor[
             0.8653840909090909, 0.8949967272727273, 0.9514109545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 108}], {
             RGBColor[
             0.8087276363636363, 0.8508435454545453, 0.9814798181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 136}], {
             RGBColor[
             0.8477502727272728, 0.8818454545454546, 0.9812604090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 177}], {
             RGBColor[0.8749585909090909, 0.899767, 0.8108067272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 194}], {
             RGBColor[
             0.8653840909090909, 0.8949967272727273, 0.9514109545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 204}], {
             RGBColor[
             0.8477502727272728, 0.8818454545454546, 0.9812604090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 226}], {
             RGBColor[
             0.8477502727272728, 0.8818454545454546, 0.9812604090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 252}], {
             RGBColor[
             0.8739480454545454, 0.8976055454545455, 0.7008150909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 268}], {
             RGBColor[
             0.7230976363636363, 0.7836086363636363, 0.9730352727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 279}], {
             RGBColor[
             0.7553930909090909, 0.8088380909090909, 0.9762541818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 280}], {
             RGBColor[
             0.8653840909090909, 0.8949967272727273, 0.9514109545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 283}], {
             RGBColor[
             0.8744533181818182, 0.8986862727272726, 0.7558109090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 89}], {
             RGBColor[
             0.7230976363636363, 0.7836086363636363, 0.9730352727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 94}], {
             RGBColor[
             0.8744533181818182, 0.8986862727272726, 0.7558109090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 96}], {
             RGBColor[
             0.8653840909090909, 0.8949967272727273, 0.9514109545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 120}], {
             RGBColor[
             0.7553930909090909, 0.8088380909090909, 0.9762541818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 131}], {
             RGBColor[
             0.8087276363636363, 0.8508435454545453, 0.9814798181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 132}], {
             RGBColor[
             0.8297667272727272, 0.8676195454545453, 0.9834865454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 141}], {
             RGBColor[0.867304409090909, 0.875195, 0.6750058181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 146}], {
             RGBColor[
             0.8087276363636363, 0.8508435454545453, 0.9814798181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 188}], {
             RGBColor[
             0.5912126363636363, 0.6765668181818181, 0.9623426363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 236}], {
             RGBColor[0.621541090909091, 0.7019025454545456, 0.964533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 260}], {
             RGBColor[
             0.6902832727272727, 0.7577105454545454, 0.9699446363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 281}], {
             RGBColor[
             0.5143669545454546, 0.6067334999999999, 0.9575659545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 294}], {
             RGBColor[0.867304409090909, 0.875195, 0.6750058181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 60}], {
             RGBColor[
             0.731532090909091, 0.788061181818182, 0.9396897727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 62}], {
             RGBColor[
             0.9577412727272727, 0.968004090909091, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 117}], {
             RGBColor[
             0.8653840909090909, 0.8949967272727273, 0.9514109545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 158}], {
             RGBColor[
             0.8963470454545455, 0.5576411818181819, 0.5453928636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 196}], {
             RGBColor[
             0.9445043181818182, 0.838224090909091, 0.5879667272727274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 207}], {
             RGBColor[
             0.7012036363636364, 0.7627254545454545, 0.9374994090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 212}], {
             RGBColor[
             0.6007544999999999, 0.668083409090909, 0.9313785454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 214}], {
             RGBColor[
             0.9273041363636364, 0.7628316363636365, 0.5737546363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 225}], {
             RGBColor[
             0.9807917272727272, 0.984860090909091, 0.9023971818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 265}], {
             RGBColor[
             0.8653840909090909, 0.8949967272727273, 0.9514109545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 276}], {
             RGBColor[
             0.8002742727272727, 0.8438691818181818, 0.9451014090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.9356354090909091, 0.8006620000000002, 0.5807064545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 112}], {
             RGBColor[
             0.5374113636363637, 0.46278131818181834`, 0.584173090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 131}], {
             RGBColor[
             0.8789789545454545, 0.7565088181818183, 0.6107753181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 133}], {
             RGBColor[
             0.6088923181818182, 0.536697181818182, 0.5882883181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 146}], {
             RGBColor[
             0.8789789545454545, 0.7565088181818183, 0.6107753181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 170}], {
             RGBColor[0.9268185, 0.7940863636363638, 0.5956311818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 190}], {
             RGBColor[
             0.7933489545454546, 0.6892739090909092, 0.6023307727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.7876885454545455, 0.8340675454545454, 0.979473090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 70}], {
             RGBColor[
             0.8087276363636363, 0.8508435454545453, 0.9814798181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 71}], {
             RGBColor[
             0.8653840909090909, 0.8949967272727273, 0.9514109545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 73}], {
             RGBColor[
             0.7876885454545455, 0.8340675454545454, 0.979473090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 100}], {
             RGBColor[
             0.7230976363636363, 0.7836086363636363, 0.9730352727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 119}], {
             RGBColor[0.867304409090909, 0.875195, 0.6750058181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 122}], {
             RGBColor[
             0.8477502727272728, 0.8818454545454546, 0.9812604090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 138}], {
             RGBColor[
             0.7876885454545455, 0.8340675454545454, 0.979473090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 161}], {
             RGBColor[
             0.7876885454545455, 0.8340675454545454, 0.979473090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 244}], {
             RGBColor[
             0.8565671818181818, 0.8884210909090908, 0.9663356818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 266}], {
             RGBColor[
             0.7553930909090909, 0.8088380909090909, 0.9762541818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 54}], {
             RGBColor[
             0.8496085909090909, 0.7019024545454546, 0.6018167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 102}], {
             RGBColor[
             0.7876885454545455, 0.8340675454545454, 0.979473090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 143}], {
             RGBColor[
             0.7553930909090909, 0.8088380909090909, 0.9762541818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 172}], {
             RGBColor[
             0.8800457272727272, 0.907074909090909, 0.9844793181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 174}], {
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 238}], {
             RGBColor[
             0.8762153181818182, 0.8145887272727275, 0.623597590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 298}], {
             RGBColor[0.7225787272727273, 0.78294, 0.9731635454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 206}], {
             RGBColor[
             0.9839390454545455, 0.9837641818181819, 0.6759718636363639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 219}], {
             RGBColor[
             0.8739480454545454, 0.8976055454545455, 0.7008150909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 83}], {
             RGBColor[
             0.9665581818181819, 0.9745797272727272, 0.9414924545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 101}], {
             RGBColor[
             0.9844443181818182, 0.984844909090909, 0.7309676818181816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 104}], {
             RGBColor[
             0.9807917272727272, 0.984860090909091, 0.9023971818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 116}], {
             RGBColor[
             0.9772954090909091, 0.9613536363636364, 0.6501625909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 142}], {
             RGBColor[
             0.9187186363636364, 0.9370021818181817, 0.9566365909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 149}], {
             RGBColor[
             0.9844443181818182, 0.984844909090909, 0.7309676818181816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 197}], {
             RGBColor[
             0.8330886363636363, 0.8697672727272727, 0.9481920454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 198}], {
             RGBColor[
             0.9828080909090908, 0.9856939090909091, 0.8689808181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 204}], {
             RGBColor[
             0.9577412727272727, 0.968004090909091, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 226}], {
             RGBColor[
             0.9577412727272727, 0.968004090909091, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 243}], {
             RGBColor[
             0.9848244545454545, 0.9865277272727273, 0.8355644545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 254}], {
             RGBColor[
             0.9577412727272727, 0.968004090909091, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 283}], {
             RGBColor[
             0.9844443181818182, 0.984844909090909, 0.7309676818181816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 53}], {
             RGBColor[
             0.8888626363636363, 0.9136505454545454, 0.9695545909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 57}], {
             RGBColor[
             0.9450939545454546, 0.8689422727272731, 0.6104601818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 84}], {
             RGBColor[
             0.9665581818181819, 0.9745797272727272, 0.9414924545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 88}], {
             RGBColor[
             0.9309408181818181, 0.9472025454545454, 0.9735680454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 93}], {
             RGBColor[
             0.9739911818181818, 0.9791182727272727, 0.8839055454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 124}], {
             RGBColor[
             0.8950003181818182, 0.6084846363636367, 0.5674710454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 137}], {
             RGBColor[
             0.9751221363636364, 0.9771885454545455, 0.6908965909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 147}], {
             RGBColor[
             0.7914573636363637, 0.8372935454545455, 0.9600261363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 217}], {
             RGBColor[
             0.9665581818181819, 0.9745797272727272, 0.9414924545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 247}], {
             RGBColor[0.9684785, 0.9547779999999999, 0.6650873181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 270}], {
             RGBColor[
             0.9665581818181819, 0.9745797272727272, 0.9414924545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 271}], {
             RGBColor[
             0.9309408181818181, 0.9472025454545454, 0.9735680454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 273}], {
             RGBColor[
             0.9489243636363636, 0.9614284545454546, 0.971341909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 289}], {
             RGBColor[
             0.9751221363636364, 0.9771885454545455, 0.6908965909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 295}], {
             RGBColor[
             0.6923867272727273, 0.7561498181818181, 0.9524241363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 88}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999998, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 93}], {
             RGBColor[
             0.9051125454545454, 0.9247647272727273, 0.8970429545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 107}], {
             RGBColor[
             0.9072540454545455, 0.9249964545454545, 0.8140256363636366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 124}], {
             RGBColor[
             0.8261216818181818, 0.5541310909090912, 0.5806084545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 137}], {
             RGBColor[0.9062435, 0.922835, 0.7040340000000002]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{53, 147}], {
             RGBColor[0.7225787272727273, 0.78294, 0.9731635454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 217}], {
             RGBColor[
             0.8976795454545454, 0.9202261818181818, 0.9546298636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 247}], {
             RGBColor[
             0.8995998636363636, 0.9004244545454545, 0.6782247272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 251}], {
             RGBColor[
             0.8976795454545454, 0.9202261818181818, 0.9546298636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 270}], {
             RGBColor[
             0.8976795454545454, 0.9202261818181818, 0.9546298636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 271}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999998, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 273}], {
             RGBColor[
             0.8800457272727272, 0.907074909090909, 0.9844793181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 289}], {
             RGBColor[0.9062435, 0.922835, 0.7040340000000002]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{54, 75}], {
             RGBColor[
             0.8916867727272726, 0.7354544545454547, 0.6058302272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 102}], {
             RGBColor[
             0.8173131363636363, 0.6766730000000001, 0.5985978636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 111}], {
             RGBColor[
             0.9184872272727274, 0.7562560000000002, 0.5886793636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 143}], {
             RGBColor[
             0.7850176818181818, 0.6514435454545455, 0.5953789545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 163}], {
             RGBColor[0.7178322272727272, 0.5976414545454547, 0.5895825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 165}], {
             RGBColor[
             0.8916867727272726, 0.7354544545454547, 0.6058302272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 172}], {
             RGBColor[
             0.9096703181818182, 0.7496803636363638, 0.603604090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 174}], {
             RGBColor[
             0.8496085909090909, 0.7019024545454546, 0.6018167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 185}], {
             RGBColor[
             0.8496085909090909, 0.7019024545454546, 0.6018167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 235}], {
             RGBColor[
             0.935868090909091, 0.7654404545454547, 0.32315877272727295`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 238}], {
             RGBColor[
             0.9058399090909093, 0.6571941818181823, 0.24272236363636374`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 298}], {
             RGBColor[
             0.7522033181818182, 0.6255454545454547, 0.5922883181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 108}], {
             RGBColor[
             0.9187186363636364, 0.9370021818181817, 0.9566365909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 114}], {
             RGBColor[
             0.9187186363636364, 0.9370021818181817, 0.9566365909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 208}], {
             RGBColor[
             0.8002742727272727, 0.8438691818181818, 0.9451014090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 219}], {
             RGBColor[
             0.8653840909090909, 0.8949967272727273, 0.9514109545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 242}], {
             RGBColor[
             0.9273041363636364, 0.7628316363636365, 0.5737546363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 250}], {
             RGBColor[
             0.731532090909091, 0.788061181818182, 0.9396897727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 252}], {
             RGBColor[
             0.9839390454545455, 0.9837641818181819, 0.6759718636363639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 268}], {
             RGBColor[
             0.8330886363636363, 0.8697672727272727, 0.9481920454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 283}], {
             RGBColor[
             0.9844443181818182, 0.984844909090909, 0.7309676818181816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 57}], {
             RGBColor[
             0.9593275000000001, 0.8792226363636366, 0.5713649090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 84}], {
             RGBColor[
             0.9807917272727272, 0.984860090909091, 0.9023971818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 110}], {
             RGBColor[
             0.9827120454545454, 0.9650583636363637, 0.6259920454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 148}], {
             RGBColor[
             0.7066202727272727, 0.7664301818181818, 0.9133288636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 191}], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 217}], {
             RGBColor[
             0.9807917272727272, 0.984860090909091, 0.9023971818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 223}], {
             RGBColor[
             0.9827120454545454, 0.9650583636363637, 0.6259920454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 246}], {
             RGBColor[
             0.9862083636363635, 0.9885648181818182, 0.8782266363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 247}], {
             RGBColor[
             0.9827120454545454, 0.9650583636363637, 0.6259920454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 251}], {
             RGBColor[
             0.9807917272727272, 0.984860090909091, 0.9023971818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 270}], {
             RGBColor[
             0.9807917272727272, 0.984860090909091, 0.9023971818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 271}], {
             RGBColor[
             0.9451743636363634, 0.9574829090909089, 0.9344727727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 278}], {
             RGBColor[
             0.9903662272727272, 0.9896303636363637, 0.7617929545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 295}], {
             RGBColor[
             0.7066202727272727, 0.7664301818181818, 0.9133288636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.9539108636363638, 0.8755179090909094, 0.5955354545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 217}], {
             RGBColor[
             0.9539108636363638, 0.8755179090909094, 0.5955354545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 223}], {
             RGBColor[
             0.9558311818181819, 0.8557161818181821, 0.31913031818181814`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 247}], {
             RGBColor[
             0.9558311818181819, 0.8557161818181821, 0.31913031818181814`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 278}], {
             RGBColor[
             0.9634853636363637, 0.8802881818181821, 0.4549312272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 295}], {
             RGBColor[
             0.6797394090909092, 0.6570880000000003, 0.6064671363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 134}], {
             RGBColor[
             0.9827120454545454, 0.9650583636363637, 0.6259920454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 160}], {
             RGBColor[
             0.9375557272727273, 0.7808602727272729, 0.30430131818181816`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 164}], {
             RGBColor[0.867304409090909, 0.875195, 0.6750058181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 176}], {
             RGBColor[
             0.9596615909090909, 0.9482023636363637, 0.6800120454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 180}], {
             RGBColor[
             0.6505523181818182, 0.6973888181818182, 0.6577444545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 187}], {
             RGBColor[
             0.9863646363636364, 0.9650431818181817, 0.45456254545454516`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 215}], {
             RGBColor[
             0.9792157272727272, 0.941551909090909, 0.3737574545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 221}], {
             RGBColor[
             0.9057375454545455, 0.5952585454545458, 0.2761411818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 230}], {
             RGBColor[0.9684785, 0.9547779999999999, 0.6650873181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[
             0.9206389545454545, 0.9172004545454544, 0.6802314545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 288}], {
             RGBColor[
             0.602674818181818, 0.6482816818181817, 0.654973409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 296}], {
             RGBColor[
             0.7334524090909091, 0.7682594545454546, 0.6632846363636362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 297}], {
             RGBColor[
             0.9206389545454545, 0.9172004545454544, 0.6802314545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 72}], {
             RGBColor[0.6917924090909092, 0.6075678181818184, 0.5938285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 83}], {
             RGBColor[
             0.7227151818181818, 0.7814855454545455, 0.9546144999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 106}], {
             RGBColor[
             0.7100678636363638, 0.6824237272727276, 0.6086575000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 136}], {
             RGBColor[
             0.7138982727272728, 0.7749099090909092, 0.9695392272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 155}], {
             RGBColor[
             0.6674444090909092, 0.4793851818181821, 0.5728218181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[
             0.731532090909091, 0.788061181818182, 0.9396897727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 197}], {
             RGBColor[
             0.5892456363636365, 0.676673090909091, 0.9613140909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 198}], {
             RGBColor[
             0.738965090909091, 0.7925997272727274, 0.8821028636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 210}], {
             RGBColor[
             0.7138982727272728, 0.7749099090909092, 0.9695392272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 226}], {
             RGBColor[
             0.7138982727272728, 0.7749099090909092, 0.9695392272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 227}], {
             RGBColor[0.6748756363636363, 0.743908, 0.9697586363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 241}], {
             RGBColor[
             0.3805149545454546, 0.49979795454545456`, 0.9458447727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 290}], {
             RGBColor[
             0.43107481818181814`, 0.5468638181818182, 0.9489465454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 291}], {
             RGBColor[
             0.738965090909091, 0.7925997272727274, 0.8821028636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 77}], {
             RGBColor[
             0.6751298636363636, 0.5319070909090908, 0.5799248636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 95}], {
             RGBColor[
             0.7369487272727273, 0.7917659090909092, 0.9155192272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 103}], {
             RGBColor[
             0.7227151818181818, 0.7814855454545455, 0.9546144999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 127}], {
             RGBColor[0.6748756363636363, 0.743908, 0.9697586363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 145}], {
             RGBColor[
             0.7409814545454546, 0.7934335454545456, 0.8486865000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 148}], {
             RGBColor[
             0.45736063636363644`, 0.5696312727272728, 0.9506214545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 159}], {
             RGBColor[0.6748756363636363, 0.743908, 0.9697586363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 168}], {
             RGBColor[
             0.6959147272727273, 0.7606839999999999, 0.9717653636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 196}], {
             RGBColor[
             0.7006613181818183, 0.6451299090909093, 0.6010887727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 205}], {
             RGBColor[
             0.6834611363636365, 0.5697374545454548, 0.5868766818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 212}], {
             RGBColor[0.3569115, 0.47498922727272724`, 0.9445005909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 225}], {
             RGBColor[
             0.7369487272727273, 0.7917659090909092, 0.9155192272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 265}], {
             RGBColor[0.621541090909091, 0.7019025454545456, 0.964533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 276}], {
             RGBColor[
             0.5564312727272729, 0.6507750000000001, 0.9582234545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 282}], {
             RGBColor[
             0.5892456363636365, 0.676673090909091, 0.9613140909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 71}], {
             RGBColor[
             0.9807917272727272, 0.984860090909091, 0.9023971818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 108}], {
             RGBColor[
             0.9241352727272727, 0.940706909090909, 0.9324660454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 136}], {
             RGBColor[
             0.963157909090909, 0.9717088181818182, 0.9322466363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 161}], {
             RGBColor[
             0.9030961818181817, 0.923930909090909, 0.9304593181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 177}], {
             RGBColor[
             0.9903662272727272, 0.9896303636363637, 0.7617929545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 194}], {
             RGBColor[
             0.9807917272727272, 0.984860090909091, 0.9023971818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 252}], {
             RGBColor[
             0.9893556818181818, 0.9874689090909091, 0.6518013181818184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 268}], {
             RGBColor[0.8385052727272726, 0.873472, 0.9240215]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{61, 279}], {
             RGBColor[
             0.8708007272727272, 0.8987014545454546, 0.9272404090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 280}], {
             RGBColor[
             0.9807917272727272, 0.984860090909091, 0.9023971818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 117}], {
             RGBColor[
             0.8477502727272728, 0.8818454545454546, 0.9812604090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 135}], {
             RGBColor[0.8154548181818182, 0.856616, 0.9780415]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{62, 158}], {
             RGBColor[
             0.8787132272727273, 0.5444899090909091, 0.5752423181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 186}], {
             RGBColor[
             0.9577412727272727, 0.968004090909091, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 196}], {
             RGBColor[0.9268705, 0.8250728181818183, 0.6178161818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 207}], {
             RGBColor[
             0.6835698181818182, 0.7495741818181818, 0.9673488636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 212}], {
             RGBColor[0.5831206818181818, 0.6549321363636362, 0.961228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 214}], {
             RGBColor[
             0.9096703181818182, 0.7496803636363638, 0.603604090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 225}], {
             RGBColor[
             0.963157909090909, 0.9717088181818182, 0.9322466363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 265}], {
             RGBColor[
             0.8477502727272728, 0.8818454545454546, 0.9812604090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 276}], {
             RGBColor[
             0.7826404545454546, 0.8307179090909091, 0.9749508636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 286}], {
             RGBColor[
             0.8861834090909091, 0.6019090000000004, 0.5823957727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 71}], {
             RGBColor[
             0.8976795454545454, 0.9202261818181818, 0.9546298636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 73}], {
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 152}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999998, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 161}], {
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 208}], {
             RGBColor[0.7225787272727273, 0.78294, 0.9731635454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 244}], {
             RGBColor[
             0.8888626363636363, 0.9136505454545454, 0.9695545909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 69}], {
             RGBColor[
             0.4654459090909089, 0.5747678181818181, 0.9516523636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 76}], {
             RGBColor[
             0.6393004545454544, 0.7125808181818181, 0.9679000909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 85}], {
             RGBColor[
             0.5972222727272726, 0.679028818181818, 0.9638866363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 90}], {
             RGBColor[
             0.6823508181818181, 0.7444965454545454, 0.8782375909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 118}], {
             RGBColor[
             0.6182613636363635, 0.695804818181818, 0.9658933636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 121}], {
             RGBColor[
             0.6393004545454544, 0.7125808181818181, 0.9679000909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 173}], {
             RGBColor[
             0.6701944999999998, 0.6977457272727272, 0.6336100909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 213}], {
             RGBColor[
             0.6182613636363635, 0.695804818181818, 0.9658933636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 234}], {
             RGBColor[
             0.30029722727272706`, 0.4268860454545453, 0.9406353181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 239}], {
             RGBColor[0.657284, 0.7268067272727272, 0.9656739545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 249}], {
             RGBColor[
             0.5972222727272726, 0.679028818181818, 0.9638866363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 258}], {
             RGBColor[
             0.6661009090909089, 0.7333823636363636, 0.9507492272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 263}], {
             RGBColor[
             0.5326313636363635, 0.6285699090909089, 0.9574488181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 286}], {
             RGBColor[
             0.6033599545454545, 0.37386290909090936`, 0.561803090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 70}], {
             RGBColor[
             0.9282931363636363, 0.9417724545454544, 0.8160323636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 106}], {
             RGBColor[
             0.9634853636363637, 0.8802881818181821, 0.4549312272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 115}], {
             RGBColor[0.9943989545454546, 0.991298, 0.6949602272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 138}], {
             RGBColor[
             0.9072540454545455, 0.9249964545454545, 0.8140256363636366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 155}], {
             RGBColor[
             0.9208619090909091, 0.6772496363636367, 0.4190955454545457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 194}], {
             RGBColor[
             0.9849495909090908, 0.9859256363636364, 0.7859635000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 200}], {
             RGBColor[
             0.986869909090909, 0.9661239090909091, 0.5095583636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[
             0.9673157727272728, 0.9727743636363637, 0.8158129545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 211}], {
             RGBColor[
             0.9282931363636363, 0.9417724545454544, 0.8160323636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 231}], {
             RGBColor[
             0.9849495909090908, 0.9859256363636364, 0.7859635000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 241}], {
             RGBColor[
             0.6339324545454545, 0.697662409090909, 0.7921185000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 264}], {
             RGBColor[
             0.9849495909090908, 0.9859256363636364, 0.7859635000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 291}], {
             RGBColor[
             0.9923825909090909, 0.9904641818181819, 0.7283765909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 86}], {
             RGBColor[
             0.4270321818181818, 0.5442955454545454, 0.948431090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 97}], {
             RGBColor[
             0.6655862727272726, 0.7353482727272727, 0.9695750000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 162}], {
             RGBColor[
             0.6445471818181818, 0.7185722727272726, 0.9675682727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 169}], {
             RGBColor[0.6448014090909091, 0.5065713636363635, 0.5777345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 187}], {
             RGBColor[0.7102728636363637, 0.766415, 0.7418993636363634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 193}], {
             RGBColor[
             0.5589171818181817, 0.6513373636363635, 0.9591237272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 215}], {
             RGBColor[
             0.7031239545454545, 0.7429237272727272, 0.6610942727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 228}], {
             RGBColor[
             0.6445471818181818, 0.7185722727272726, 0.9675682727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 118}], {
             RGBColor[
             0.9206389545454545, 0.9172004545454544, 0.6802314545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 166}], {
             RGBColor[
             0.9208931818181818, 0.7051995454545452, 0.2903976818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 173}], {
             RGBColor[
             0.9725720909090909, 0.9191413636363636, 0.3479481818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 195}], {
             RGBColor[
             0.9827120454545454, 0.9650583636363637, 0.6259920454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 213}], {
             RGBColor[
             0.9206389545454545, 0.9172004545454544, 0.6802314545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 234}], {
             RGBColor[
             0.602674818181818, 0.6482816818181817, 0.654973409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 263}], {
             RGBColor[
             0.8350089545454544, 0.8499655454545454, 0.671786909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 75}], {
             RGBColor[0.5415336818181817, 0.6158975, 0.9621099545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 83}], {
             RGBColor[
             0.5683341363636363, 0.6366990454545454, 0.9449590909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 109}], {
             RGBColor[
             0.3029795909090909, 0.4248447727272727, 0.9409660454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 111}], {
             RGBColor[
             0.5683341363636363, 0.6366990454545454, 0.9449590909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 143}], {
             RGBColor[
             0.43486459090909085`, 0.5318865909090909, 0.9516586818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 163}], {
             RGBColor[
             0.36767913636363625`, 0.4780844999999999, 0.9458622272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 185}], {
             RGBColor[0.4994555, 0.5823455, 0.9580965]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{68, 218}], {
             RGBColor[
             0.36767913636363625`, 0.4780844999999999, 0.9458622272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 235}], {
             RGBColor[0.585715, 0.6458835, 0.6794385000000002]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{68, 292}], {
             RGBColor[
             0.5595172272727273, 0.6301234090909091, 0.9598838181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 76}], {
             RGBColor[
             0.7302858181818179, 0.7885879999999998, 0.9744711818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 85}], {
             RGBColor[
             0.6882076363636362, 0.7550359999999998, 0.9704577272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 90}], {
             RGBColor[
             0.7733361818181816, 0.8205037272727272, 0.884808681818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 118}], {
             RGBColor[
             0.7092467272727272, 0.7718119999999999, 0.9724644545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 121}], {
             RGBColor[
             0.7302858181818179, 0.7885879999999998, 0.9744711818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 126}], {
             RGBColor[
             0.7302858181818179, 0.7885879999999998, 0.9744711818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 166}], {
             RGBColor[
             0.7095009545454545, 0.5598110909090908, 0.5826306818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 173}], {
             RGBColor[
             0.7611798636363636, 0.773752909090909, 0.6401811818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 195}], {
             RGBColor[
             0.771319818181818, 0.819669909090909, 0.9182250454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 213}], {
             RGBColor[
             0.7092467272727272, 0.7718119999999999, 0.9724644545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 234}], {
             RGBColor[
             0.39128259090909073`, 0.5028932272727271, 0.9472064090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 239}], {
             RGBColor[
             0.7482693636363635, 0.802813909090909, 0.9722450454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 249}], {
             RGBColor[
             0.6882076363636362, 0.7550359999999998, 0.9704577272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 258}], {
             RGBColor[
             0.7570862727272727, 0.8093895454545454, 0.9573203181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 263}], {
             RGBColor[
             0.6236167272727271, 0.7045770909090908, 0.9640199090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 285}], {
             RGBColor[
             0.6559121818181817, 0.7298065454545454, 0.9672388181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 122}], {
             RGBColor[
             0.9010848181818181, 0.9238509090909091, 0.9864860454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 138}], {
             RGBColor[
             0.8410230909090908, 0.8760729999999999, 0.9846987272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 211}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 231}], {
             RGBColor[
             0.9187186363636364, 0.9370021818181817, 0.9566365909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 266}], {
             RGBColor[
             0.8087276363636363, 0.8508435454545453, 0.9814798181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 108}], {
             RGBColor[
             0.9187186363636364, 0.9370021818181817, 0.9566365909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 136}], {
             RGBColor[
             0.9577412727272727, 0.968004090909091, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 161}], {
             RGBColor[
             0.8976795454545454, 0.9202261818181818, 0.9546298636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 177}], {
             RGBColor[
             0.9849495909090908, 0.9859256363636364, 0.7859635000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 208}], {
             RGBColor[
             0.8002742727272727, 0.8438691818181818, 0.9451014090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 244}], {
             RGBColor[
             0.9665581818181819, 0.9745797272727272, 0.9414924545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 252}], {
             RGBColor[
             0.9839390454545455, 0.9837641818181819, 0.6759718636363639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 268}], {
             RGBColor[
             0.8330886363636363, 0.8697672727272727, 0.9481920454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 279}], {
             RGBColor[
             0.8653840909090909, 0.8949967272727273, 0.9514109545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 280}], {
             RGBColor[
             0.9753750909090909, 0.9811553636363637, 0.9265677272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 83}], {
             RGBColor[0.9268185, 0.7940863636363638, 0.5956311818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 87}], {
             RGBColor[
             0.6614639545454546, 0.582232090909091, 0.5916381363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 106}], {
             RGBColor[
             0.9141711818181819, 0.6950245454545458, 0.2496741818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 109}], {
             RGBColor[
             0.6614639545454546, 0.582232090909091, 0.5916381363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 155}], {
             RGBColor[
             0.8715477272727273, 0.49198600000000037`, 0.21383850000000004`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 194}], {
             RGBColor[
             0.9356354090909091, 0.8006620000000002, 0.5807064545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 210}], {
             RGBColor[
             0.918001590909091, 0.7875107272727274, 0.6105559090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 218}], {
             RGBColor[0.7261635, 0.6354718181818182, 0.5965343181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 226}], {
             RGBColor[
             0.918001590909091, 0.7875107272727274, 0.6105559090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 227}], {
             RGBColor[
             0.8789789545454545, 0.7565088181818183, 0.6107753181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 241}], {
             RGBColor[
             0.5846182727272727, 0.5123987727272727, 0.5868614545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 290}], {
             RGBColor[
             0.6351781363636363, 0.5594646363636364, 0.5899632272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 291}], {
             RGBColor[
             0.9430684090909092, 0.8052005454545457, 0.5231195454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 100}], {
             RGBColor[
             0.7553930909090909, 0.8088380909090909, 0.9762541818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 119}], {
             RGBColor[
             0.8995998636363636, 0.9004244545454545, 0.6782247272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 122}], {
             RGBColor[
             0.8800457272727272, 0.907074909090909, 0.9844793181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 161}], {
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 244}], {
             RGBColor[
             0.8888626363636363, 0.9136505454545454, 0.9695545909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 123}], {
             RGBColor[0.8154548181818182, 0.856616, 0.9780415]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{74, 189}], {
             RGBColor[
             0.9671906363636363, 0.9733764545454546, 0.8654139090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 257}], {
             RGBColor[
             0.9530179545454545, 0.9257918181818181, 0.6542027727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 260}], {
             RGBColor[
             0.7826404545454546, 0.8307179090909091, 0.9749508636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 267}], {
             RGBColor[
             0.9577412727272727, 0.968004090909091, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 287}], {
             RGBColor[0.9668105, 0.9716936363636364, 0.7608171363636361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 300}], {
             RGBColor[
             0.922123909090909, 0.940626909090909, 0.9884927727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 111}], {
             RGBColor[
             0.9309408181818181, 0.9472025454545454, 0.9735680454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 143}], {
             RGBColor[
             0.7974712727272726, 0.8423900909090908, 0.9802676363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.7302858181818179, 0.7885879999999998, 0.9744711818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 165}], {
             RGBColor[
             0.9041403636363634, 0.9264009999999998, 0.9907189090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 185}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999998, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 235}], {
             RGBColor[
             0.9483216818181817, 0.9563869999999999, 0.7080474545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 262}], {
             RGBColor[
             0.7974712727272726, 0.8423900909090908, 0.9802676363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 292}], {
             RGBColor[
             0.922123909090909, 0.940626909090909, 0.9884927727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 85}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999998, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 87}], {
             RGBColor[
             0.6655862727272726, 0.7353482727272727, 0.9695750000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 90}], {
             RGBColor[
             0.9471907272727271, 0.9583167272727272, 0.9010564090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 126}], {
             RGBColor[
             0.9041403636363634, 0.9264009999999998, 0.9907189090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 151}], {
             RGBColor[
             0.9471907272727271, 0.9583167272727272, 0.9010564090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 153}], {
             RGBColor[
             0.8297667272727272, 0.8676195454545453, 0.9834865454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 192}], {
             RGBColor[
             0.6959147272727273, 0.7606839999999999, 0.9717653636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 220}], {
             RGBColor[
             0.9492070909090908, 0.9591505454545454, 0.8676400454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 239}], {
             RGBColor[
             0.922123909090909, 0.940626909090909, 0.9884927727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 248}], {
             RGBColor[
             0.9488269545454544, 0.9574677272727272, 0.7630432727272725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 258}], {
             RGBColor[
             0.9309408181818181, 0.9472025454545454, 0.9735680454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 82}], {
             RGBColor[0.6448014090909091, 0.5065713636363635, 0.5777345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 95}], {
             RGBColor[0.9243895, 0.7287059999999999, 0.5426322727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 103}], {
             RGBColor[
             0.9101559545454545, 0.7184256363636362, 0.5817275454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 127}], {
             RGBColor[
             0.862316409090909, 0.6808480909090907, 0.5968716818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 145}], {
             RGBColor[
             0.9284222272727272, 0.7303736363636362, 0.4757995454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 154}], {
             RGBColor[
             0.9284222272727272, 0.7303736363636362, 0.4757995454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 159}], {
             RGBColor[
             0.862316409090909, 0.6808480909090907, 0.5968716818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 167}], {
             RGBColor[
             0.7438720454545454, 0.5877150909090908, 0.5853364999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 168}], {
             RGBColor[
             0.8833554999999998, 0.6976240909090907, 0.5988784090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 203}], {
             RGBColor[
             0.8975086363636364, 0.6193638181818184, 0.23577054545454548`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 205}], {
             RGBColor[
             0.8709019090909091, 0.5066775454545455, 0.21398972727272725`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 212}], {
             RGBColor[
             0.5443522727272726, 0.41192931818181794`, 0.5716136363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 225}], {
             RGBColor[0.9243895, 0.7287059999999999, 0.5426322727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 255}], {
             RGBColor[0.847415, 0.358906181818182, 0.1927814090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 265}], {
             RGBColor[
             0.8089818636363636, 0.6388426363636361, 0.5916460454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 269}], {
             RGBColor[
             0.9013390454545454, 0.7118499999999999, 0.5966522727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 276}], {
             RGBColor[
             0.7438720454545454, 0.5877150909090908, 0.5853364999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 282}], {
             RGBColor[
             0.776686409090909, 0.6136131818181816, 0.5884271363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 293}], {
             RGBColor[
             0.8412773181818181, 0.6640720909090907, 0.5948649545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 99}], {
             RGBColor[0.9684785, 0.9547779999999999, 0.6650873181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 131}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 170}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 178}], {
             RGBColor[
             0.7570862727272727, 0.8093895454545454, 0.9573203181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 182}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 190}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.9756274090909092, 0.9782692727272727, 0.7458924090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 209}], {
             RGBColor[
             0.9309408181818181, 0.9472025454545454, 0.9735680454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 229}], {
             RGBColor[
             0.9489243636363636, 0.9614284545454546, 0.971341909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 261}], {
             RGBColor[
             0.9665581818181819, 0.9745797272727272, 0.9414924545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 284}], {
             RGBColor[
             0.9751221363636364, 0.9771885454545455, 0.6908965909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 144}], {
             RGBColor[
             0.8888626363636363, 0.9136505454545454, 0.9695545909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 160}], {
             RGBColor[0.9268185, 0.7940863636363638, 0.5956311818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 176}], {
             RGBColor[
             0.9489243636363636, 0.9614284545454546, 0.971341909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 221}], {
             RGBColor[
             0.8950003181818182, 0.6084846363636367, 0.5674710454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 232}], {
             RGBColor[
             0.6923867272727273, 0.7561498181818181, 0.9524241363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 240}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 245}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 288}], {
             RGBColor[
             0.5919375909090908, 0.6615077727272727, 0.9463032727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 297}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 92}], {
             RGBColor[
             0.8888626363636363, 0.9136505454545454, 0.9695545909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 125}], {
             RGBColor[
             0.9618348636363636, 0.9323674545454546, 0.6392780454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 128}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 145}], {
             RGBColor[
             0.9760075454545454, 0.9799520909090909, 0.8504891818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 149}], {
             RGBColor[
             0.9756274090909092, 0.9782692727272727, 0.7458924090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 150}], {
             RGBColor[
             0.9489243636363636, 0.9614284545454546, 0.971341909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 156}], {
             RGBColor[
             0.666100909090909, 0.7333823636363636, 0.9507492272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 167}], {
             RGBColor[
             0.7914573636363637, 0.8372935454545455, 0.9600261363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 179}], {
             RGBColor[
             0.6398150909090909, 0.7106149090909091, 0.9490743181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 201}], {
             RGBColor[
             0.7570862727272727, 0.8093895454545454, 0.9573203181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 205}], {
             RGBColor[
             0.9184872272727274, 0.7562560000000002, 0.5886793636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 237}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 256}], {
             RGBColor[
             0.5683341363636364, 0.6366990454545455, 0.9449590909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 269}], {
             RGBColor[
             0.9489243636363636, 0.9614284545454546, 0.971341909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 277}], {
             RGBColor[
             0.9665581818181819, 0.9745797272727272, 0.9414924545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 281}], {
             RGBColor[0.6155410454545454, 0.6863165, 0.9476474545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 282}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 293}], {
             RGBColor[
             0.8888626363636363, 0.9136505454545454, 0.9695545909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 86}], {
             RGBColor[
             0.7107781363636363, 0.7674957272727272, 0.796895181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 94}], {
             RGBColor[
             0.9940188181818181, 0.9896151818181818, 0.5903634545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 97}], {
             RGBColor[
             0.9493322272727271, 0.9585484545454545, 0.8180390909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.9849495909090908, 0.9859256363636364, 0.7859635000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 140}], {
             RGBColor[
             0.7754776818181817, 0.8207354545454545, 0.8017913636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 162}], {
             RGBColor[
             0.9282931363636363, 0.9417724545454544, 0.8160323636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 167}], {
             RGBColor[
             0.8098487727272727, 0.8486394545454545, 0.804497181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 181}], {
             RGBColor[
             0.9802262727272727, 0.9437133636363636, 0.4837490909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 201}], {
             RGBColor[
             0.7754776818181817, 0.8207354545454545, 0.8017913636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 202}], {
             RGBColor[0.8749585909090909, 0.899767, 0.8108067272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 203}], {
             RGBColor[
             0.9634853636363637, 0.8802881818181821, 0.4549312272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 216}], {
             RGBColor[
             0.9282931363636363, 0.9417724545454544, 0.8160323636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 237}], {
             RGBColor[
             0.9761326818181818, 0.9793499999999999, 0.8008882272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 269}], {
             RGBColor[
             0.9673157727272728, 0.9727743636363637, 0.8158129545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 293}], {
             RGBColor[
             0.9072540454545455, 0.9249964545454545, 0.8140256363636366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 299}], {
             RGBColor[
             0.741106590909091, 0.7928314545454547, 0.7990855454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 103}], {
             RGBColor[
             0.6923867272727273, 0.7561498181818181, 0.9524241363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 140}], {
             RGBColor[
             0.4917317272727272, 0.5975352727272727, 0.9533272727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 145}], {
             RGBColor[0.710653, 0.7680978181818181, 0.8464961363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 154}], {
             RGBColor[0.710653, 0.7680978181818181, 0.8464961363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 167}], {
             RGBColor[
             0.5261028181818181, 0.6254392727272727, 0.9560330909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 168}], {
             RGBColor[
             0.6655862727272726, 0.7353482727272727, 0.9695750000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 181}], {
             RGBColor[0.6964803181818182, 0.7205131818181818, 0.635285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 201}], {
             RGBColor[
             0.4917317272727272, 0.5975352727272727, 0.9533272727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 203}], {
             RGBColor[
             0.6797394090909092, 0.6570880000000003, 0.6064671363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 216}], {
             RGBColor[
             0.6445471818181818, 0.7185722727272726, 0.9675682727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 255}], {
             RGBColor[0.6296457727272728, 0.39663036363636395`, 0.563478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 258}], {
             RGBColor[
             0.6923867272727273, 0.7561498181818181, 0.9524241363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 293}], {
             RGBColor[
             0.6235080909090909, 0.7017962727272726, 0.9655615454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 101}], {
             RGBColor[
             0.9756274090909092, 0.9782692727272727, 0.7458924090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 142}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 149}], {
             RGBColor[
             0.9756274090909092, 0.9782692727272727, 0.7458924090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 194}], {
             RGBColor[
             0.9665581818181819, 0.9745797272727272, 0.9414924545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 198}], {
             RGBColor[
             0.9739911818181818, 0.9791182727272727, 0.8839055454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 226}], {
             RGBColor[
             0.9489243636363636, 0.9614284545454546, 0.971341909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 241}], {
             RGBColor[0.6155410454545454, 0.6863165, 0.9476474545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 243}], {
             RGBColor[
             0.9760075454545454, 0.9799520909090909, 0.8504891818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 290}], {
             RGBColor[
             0.666100909090909, 0.7333823636363636, 0.9507492272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 291}], {
             RGBColor[
             0.9739911818181818, 0.9791182727272727, 0.8839055454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 191}], {
             RGBColor[
             0.9848244545454545, 0.9865277272727273, 0.8355644545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 217}], {
             RGBColor[
             0.9753750909090909, 0.9811553636363637, 0.9265677272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 223}], {
             RGBColor[
             0.9772954090909091, 0.9613536363636364, 0.6501625909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 246}], {
             RGBColor[
             0.9807917272727272, 0.984860090909091, 0.9023971818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 247}], {
             RGBColor[
             0.9772954090909091, 0.9613536363636364, 0.6501625909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 270}], {
             RGBColor[
             0.9753750909090909, 0.9811553636363637, 0.9265677272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 271}], {
             RGBColor[
             0.9397577272727271, 0.9537781818181817, 0.9586433181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 278}], {
             RGBColor[
             0.9849495909090908, 0.9859256363636364, 0.7859635000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 295}], {
             RGBColor[
             0.7012036363636364, 0.7627254545454545, 0.9374994090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999998, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 135}], {
             RGBColor[
             0.7553930909090909, 0.8088380909090909, 0.9762541818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 154}], {
             RGBColor[
             0.907128909090909, 0.9255985454545455, 0.863626590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 173}], {
             RGBColor[
             0.8929562272727272, 0.8780139090909089, 0.6524154545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 213}], {
             RGBColor[
             0.8410230909090908, 0.8760729999999999, 0.9846987272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 234}], {
             RGBColor[
             0.5230589545454545, 0.607154227272727, 0.9594406818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 239}], {
             RGBColor[
             0.8800457272727272, 0.907074909090909, 0.9844793181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 249}], {
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 255}], {
             RGBColor[
             0.8261216818181818, 0.5541310909090912, 0.5806084545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 258}], {
             RGBColor[
             0.8888626363636363, 0.9136505454545454, 0.9695545909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 263}], {
             RGBColor[
             0.7553930909090909, 0.8088380909090909, 0.9762541818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 286}], {
             RGBColor[
             0.8261216818181818, 0.5541310909090912, 0.5806084545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[0.7102728636363637, 0.766415, 0.7418993636363634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 97}], {
             RGBColor[
             0.6655862727272726, 0.7353482727272727, 0.9695750000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 120}], {
             RGBColor[
             0.5912126363636363, 0.6765668181818181, 0.9623426363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 130}], {
             RGBColor[
             0.7012036363636364, 0.7627254545454545, 0.9374994090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 140}], {
             RGBColor[
             0.4917317272727272, 0.5975352727272727, 0.9533272727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 162}], {
             RGBColor[
             0.6445471818181818, 0.7185722727272726, 0.9675682727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 169}], {
             RGBColor[0.6448014090909091, 0.5065713636363635, 0.5777345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[
             0.4917317272727272, 0.5975352727272727, 0.9533272727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 182}], {
             RGBColor[
             0.6445471818181818, 0.7185722727272726, 0.9675682727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 202}], {
             RGBColor[
             0.5912126363636363, 0.6765668181818181, 0.9623426363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 261}], {
             RGBColor[
             0.7012036363636364, 0.7627254545454545, 0.9374994090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 284}], {
             RGBColor[
             0.7097675909090909, 0.7653342727272727, 0.6869035454545457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 109}], {
             RGBColor[
             0.4270321818181818, 0.5442955454545454, 0.948431090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 140}], {
             RGBColor[
             0.4917317272727272, 0.5975352727272727, 0.9533272727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 151}], {
             RGBColor[0.7086366363636363, 0.767264, 0.8799125000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[0.710653, 0.7680978181818181, 0.8464961363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 155}], {
             RGBColor[
             0.6371159545454546, 0.45404945454545476`, 0.5706314545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 162}], {
             RGBColor[
             0.6445471818181818, 0.7185722727272726, 0.9675682727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 181}], {
             RGBColor[0.6964803181818182, 0.7205131818181818, 0.635285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 202}], {
             RGBColor[
             0.5912126363636363, 0.6765668181818181, 0.9623426363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 203}], {
             RGBColor[
             0.6797394090909092, 0.6570880000000003, 0.6064671363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 216}], {
             RGBColor[
             0.6445471818181818, 0.7185722727272726, 0.9675682727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 227}], {
             RGBColor[
             0.6445471818181818, 0.7185722727272726, 0.9675682727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 258}], {
             RGBColor[
             0.6923867272727273, 0.7561498181818181, 0.9524241363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 299}], {
             RGBColor[
             0.45736063636363644`, 0.5696312727272728, 0.9506214545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 93}], {
             RGBColor[
             0.9471907272727271, 0.9583167272727272, 0.9010564090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 107}], {
             RGBColor[
             0.9493322272727271, 0.9585484545454545, 0.8180390909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 124}], {
             RGBColor[
             0.8681998636363636, 0.5876830909090911, 0.5846219090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 137}], {
             RGBColor[
             0.9483216818181817, 0.9563869999999999, 0.7080474545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 147}], {
             RGBColor[0.764656909090909, 0.816492, 0.977177]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{88, 273}], {
             RGBColor[
             0.922123909090909, 0.940626909090909, 0.9884927727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 274}], {
             RGBColor[
             0.5887405909090908, 0.6655149545454544, 0.9647983181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 289}], {
             RGBColor[
             0.9483216818181817, 0.9563869999999999, 0.7080474545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 94}], {
             RGBColor[
             0.8421578636363636, 0.8734568181818181, 0.7525919999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 120}], {
             RGBColor[
             0.7230976363636363, 0.7836086363636363, 0.9730352727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 131}], {
             RGBColor[
             0.7764321818181817, 0.8256140909090908, 0.9782609090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 141}], {
             RGBColor[
             0.8350089545454544, 0.8499655454545454, 0.671786909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 188}], {
             RGBColor[
             0.5589171818181817, 0.6513373636363635, 0.9591237272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 236}], {
             RGBColor[
             0.5892456363636365, 0.676673090909091, 0.9613140909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 260}], {
             RGBColor[
             0.6579878181818182, 0.7324810909090909, 0.9667257272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 281}], {
             RGBColor[
             0.48207149999999993`, 0.5815040454545454, 0.9543470454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 294}], {
             RGBColor[
             0.8350089545454544, 0.8499655454545454, 0.671786909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 118}], {
             RGBColor[
             0.9261516363636363, 0.9415407272727272, 0.8990496818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 126}], {
             RGBColor[
             0.9471907272727271, 0.9583167272727272, 0.9010564090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 153}], {
             RGBColor[
             0.8728170909090909, 0.8995352727272727, 0.8938240454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.9264058636363636, 0.729539818181818, 0.5092159090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 195}], {
             RGBColor[
             0.9882247272727271, 0.9893986363636365, 0.8448102727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 222}], {
             RGBColor[
             0.9922574545454546, 0.9910662727272728, 0.7779775454545457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 234}], {
             RGBColor[
             0.6081874999999999, 0.6726219545454545, 0.8737916363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 239}], {
             RGBColor[
             0.9651742727272727, 0.9725426363636365, 0.8988302727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 248}], {
             RGBColor[
             0.9918773181818181, 0.9893834545454545, 0.6733807727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 285}], {
             RGBColor[
             0.8728170909090909, 0.8995352727272727, 0.8938240454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 93}], {
             RGBColor[
             0.9923825909090909, 0.9904641818181819, 0.7283765909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 105}], {
             RGBColor[
             0.7107781363636363, 0.7674957272727272, 0.796895181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 107}], {
             RGBColor[
             0.9945240909090909, 0.9906959090909091, 0.6453592727272731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 139}], {
             RGBColor[
             0.9673157727272728, 0.9727743636363637, 0.8158129545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 142}], {
             RGBColor[
             0.9282931363636363, 0.9417724545454544, 0.8160323636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 143}], {
             RGBColor[
             0.8426631363636363, 0.8745375454545454, 0.8075878181818184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 150}], {
             RGBColor[
             0.9673157727272728, 0.9727743636363637, 0.8158129545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 163}], {
             RGBColor[
             0.7754776818181817, 0.8207354545454545, 0.8017913636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 179}], {
             RGBColor[0.6582065, 0.7219608181818182, 0.7935453636363639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 235}], {
             RGBColor[
             0.9935135454545454, 0.9885344545454546, 0.5353676363636367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 273}], {
             RGBColor[
             0.9673157727272728, 0.9727743636363637, 0.8158129545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 274}], {
             RGBColor[
             0.6339324545454545, 0.697662409090909, 0.7921185000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 298}], {
             RGBColor[
             0.8098487727272727, 0.8486394545454545, 0.804497181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 125}], {
             RGBColor[
             0.8929562272727272, 0.8780139090909089, 0.6524154545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 128}], {
             RGBColor[
             0.8888626363636363, 0.9136505454545454, 0.9695545909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 142}], {
             RGBColor[
             0.8410230909090908, 0.8760729999999999, 0.9846987272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 149}], {
             RGBColor[
             0.9067487727272727, 0.9239157272727272, 0.759029818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 150}], {
             RGBColor[
             0.8800457272727272, 0.907074909090909, 0.9844793181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 179}], {
             RGBColor[
             0.5709364545454545, 0.6562613636363637, 0.9622117272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 237}], {
             RGBColor[
             0.8888626363636363, 0.9136505454545454, 0.9695545909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 243}], {
             RGBColor[
             0.907128909090909, 0.9255985454545455, 0.863626590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 256}], {
             RGBColor[0.49945549999999994`, 0.5823455, 0.9580965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 269}], {
             RGBColor[
             0.8800457272727272, 0.907074909090909, 0.9844793181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 277}], {
             RGBColor[
             0.8976795454545454, 0.9202261818181818, 0.9546298636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 281}], {
             RGBColor[
             0.546662409090909, 0.6319629545454544, 0.9607848636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 105}], {
             RGBColor[0.7086366363636363, 0.767264, 0.8799125000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 107}], {
             RGBColor[
             0.9923825909090909, 0.9904641818181819, 0.7283765909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 137}], {
             RGBColor[
             0.9913720454545454, 0.9883027272727274, 0.6183849545454548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 139}], {
             RGBColor[
             0.9651742727272727, 0.9725426363636365, 0.8988302727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 147}], {
             RGBColor[0.8077072727272727, 0.8484077272727273, 0.8875145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 273}], {
             RGBColor[
             0.9651742727272727, 0.9725426363636365, 0.8988302727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 274}], {
             RGBColor[
             0.6317909545454545, 0.6974306818181818, 0.8751358181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 289}], {
             RGBColor[
             0.9913720454545454, 0.9883027272727274, 0.6183849545454548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 97}], {
             RGBColor[
             0.9488269545454544, 0.9574677272727272, 0.7630432727272725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 120}], {
             RGBColor[
             0.8744533181818182, 0.8986862727272726, 0.7558109090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 130}], {
             RGBColor[
             0.9844443181818182, 0.984844909090909, 0.7309676818181816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 141}], {
             RGBColor[
             0.9863646363636364, 0.9650431818181817, 0.45456254545454516`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 188}], {
             RGBColor[0.7102728636363637, 0.766415, 0.7418993636363634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 201}], {
             RGBColor[
             0.774972409090909, 0.8196547272727273, 0.7467955454545452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 202}], {
             RGBColor[
             0.8744533181818182, 0.8986862727272726, 0.7558109090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.9756274090909092, 0.9782692727272727, 0.7458924090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 281}], {
             RGBColor[
             0.6334271818181818, 0.6965816818181818, 0.7371226818181816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 293}], {
             RGBColor[
             0.9067487727272727, 0.9239157272727272, 0.759029818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 294}], {
             RGBColor[
             0.9863646363636364, 0.9650431818181817, 0.45456254545454516`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 103}], {
             RGBColor[
             0.9719748181818182, 0.9782844545454545, 0.917321909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 127}], {
             RGBColor[
             0.9241352727272727, 0.940706909090909, 0.9324660454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 145}], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 148}], {
             RGBColor[
             0.7066202727272727, 0.7664301818181818, 0.9133288636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 156}], {
             RGBColor[
             0.6803344545454544, 0.7436627272727272, 0.9116539545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 159}], {
             RGBColor[
             0.9241352727272727, 0.940706909090909, 0.9324660454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 168}], {
             RGBColor[
             0.9451743636363634, 0.9574829090909089, 0.9344727727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 191}], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 205}], {
             RGBColor[
             0.9327207727272727, 0.7665363636363638, 0.549584090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 212}], {
             RGBColor[0.6061711363636362, 0.6717881363636362, 0.907208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 225}], {
             RGBColor[
             0.9862083636363635, 0.9885648181818182, 0.8782266363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 251}], {
             RGBColor[
             0.9807917272727272, 0.984860090909091, 0.9023971818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 271}], {
             RGBColor[
             0.9451743636363634, 0.9574829090909089, 0.9344727727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 276}], {
             RGBColor[
             0.805690909090909, 0.8475739090909091, 0.9209308636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 282}], {
             RGBColor[0.8385052727272726, 0.873472, 0.9240215]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{96, 112}], {
             RGBColor[
             0.5771510454545454, 0.6432746818181818, 0.9300343636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 132}], {
             RGBColor[
             0.9397577272727271, 0.9537781818181817, 0.9586433181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 133}], {
             RGBColor[
             0.6486320000000001, 0.7171905454545455, 0.9341495909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 146}], {
             RGBColor[
             0.9187186363636364, 0.9370021818181817, 0.9566365909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 236}], {
             RGBColor[
             0.731532090909091, 0.788061181818182, 0.9396897727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 260}], {
             RGBColor[
             0.8002742727272727, 0.8438691818181818, 0.9451014090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 267}], {
             RGBColor[
             0.9753750909090909, 0.9811553636363637, 0.9265677272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 120}], {
             RGBColor[
             0.8297667272727272, 0.8676195454545453, 0.9834865454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 130}], {
             RGBColor[
             0.9397577272727271, 0.9537781818181817, 0.9586433181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 178}], {
             RGBColor[
             0.7302858181818179, 0.7885879999999998, 0.9744711818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 182}], {
             RGBColor[
             0.8831012727272726, 0.9096249999999999, 0.9887121818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 202}], {
             RGBColor[
             0.8297667272727272, 0.8676195454545453, 0.9834865454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 261}], {
             RGBColor[
             0.9397577272727271, 0.9537781818181817, 0.9586433181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 284}], {
             RGBColor[
             0.9483216818181817, 0.9563869999999999, 0.7080474545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 157}], {
             RGBColor[
             0.9618348636363636, 0.9323674545454546, 0.6392780454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.9802262727272727, 0.9437133636363636, 0.4837490909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 275}], {
             RGBColor[
             0.9797210000000001, 0.9426326363636364, 0.4287532727272725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 285}], {
             RGBColor[
             0.8606607727272727, 0.8527844545454545, 0.6491965454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 182}], {
             RGBColor[
             0.9206389545454545, 0.9172004545454544, 0.6802314545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 199}], {
             RGBColor[
             0.9863646363636364, 0.9650431818181817, 0.45456254545454516`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 209}], {
             RGBColor[
             0.9416780454545453, 0.9339764545454544, 0.6822381818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 215}], {
             RGBColor[
             0.9792157272727272, 0.941551909090909, 0.3737574545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 229}], {
             RGBColor[
             0.9596615909090909, 0.9482023636363637, 0.6800120454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 233}], {
             RGBColor[
             0.7031239545454545, 0.7429237272727272, 0.6610942727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 259}], {
             RGBColor[0.9684785, 0.9547779999999999, 0.6650873181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 284}], {
             RGBColor[
             0.9858593636363636, 0.9639624545454546, 0.39956672727272735`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 119}], {
             RGBColor[
             0.8350089545454544, 0.8499655454545454, 0.671786909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 122}], {
             RGBColor[0.8154548181818182, 0.856616, 0.9780415]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{100, 161}], {
             RGBColor[
             0.7553930909090909, 0.8088380909090909, 0.9762541818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 244}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 266}], {
             RGBColor[
             0.7230976363636363, 0.7836086363636363, 0.9730352727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 104}], {
             RGBColor[
             0.9898609545454545, 0.9885496363636364, 0.7067971363636362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 116}], {
             RGBColor[
             0.9863646363636364, 0.9650431818181817, 0.45456254545454516`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 136}], {
             RGBColor[0.9668105, 0.9716936363636364, 0.7608171363636361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 149}], {
             RGBColor[
             0.9935135454545455, 0.9885344545454545, 0.5353676363636359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 197}], {
             RGBColor[
             0.8421578636363636, 0.8734568181818181, 0.7525919999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 198}], {
             RGBColor[
             0.9918773181818181, 0.9893834545454545, 0.6733807727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[0.9668105, 0.9716936363636364, 0.7608171363636361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 226}], {
             RGBColor[0.9668105, 0.9716936363636364, 0.7608171363636361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 243}], {
             RGBColor[
             0.9938936818181818, 0.9902172727272727, 0.6399644090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 254}], {
             RGBColor[0.9668105, 0.9716936363636364, 0.7608171363636361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 283}], {
             RGBColor[
             0.9935135454545455, 0.9885344545454545, 0.5353676363636359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 165}], {
             RGBColor[
             0.8297667272727272, 0.8676195454545453, 0.9834865454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 172}], {
             RGBColor[
             0.8477502727272728, 0.8818454545454546, 0.9812604090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 175}], {
             RGBColor[
             0.8739480454545454, 0.8976055454545455, 0.7008150909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 183}], {
             RGBColor[
             0.8087276363636363, 0.8508435454545453, 0.9814798181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 238}], {
             RGBColor[
             0.8439198636363637, 0.789359272727273, 0.6203786818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 253}], {
             RGBColor[0.621541090909091, 0.7019025454545456, 0.964533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 127}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 145}], {
             RGBColor[
             0.9760075454545454, 0.9799520909090909, 0.8504891818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 154}], {
             RGBColor[
             0.9760075454545454, 0.9799520909090909, 0.8504891818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 159}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 167}], {
             RGBColor[
             0.7914573636363637, 0.8372935454545455, 0.9600261363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 168}], {
             RGBColor[
             0.9309408181818181, 0.9472025454545454, 0.9735680454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 203}], {
             RGBColor[
             0.9450939545454546, 0.8689422727272731, 0.6104601818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 205}], {
             RGBColor[
             0.9184872272727274, 0.7562560000000002, 0.5886793636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 212}], {
             RGBColor[
             0.5919375909090908, 0.6615077727272727, 0.9463032727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 225}], {
             RGBColor[
             0.9719748181818182, 0.9782844545454545, 0.917321909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 255}], {
             RGBColor[
             0.8950003181818182, 0.6084846363636367, 0.5674710454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 265}], {
             RGBColor[
             0.8565671818181818, 0.8884210909090908, 0.9663356818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 269}], {
             RGBColor[
             0.9489243636363636, 0.9614284545454546, 0.971341909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 276}], {
             RGBColor[
             0.7914573636363637, 0.8372935454545455, 0.9600261363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 282}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 293}], {
             RGBColor[
             0.8888626363636363, 0.9136505454545454, 0.9695545909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 114}], {
             RGBColor[
             0.9241352727272727, 0.940706909090909, 0.9324660454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 116}], {
             RGBColor[
             0.9827120454545454, 0.9650583636363637, 0.6259920454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 204}], {
             RGBColor[
             0.963157909090909, 0.9717088181818182, 0.9322466363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 206}], {
             RGBColor[
             0.9807917272727272, 0.984860090909091, 0.9023971818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 243}], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 254}], {
             RGBColor[
             0.963157909090909, 0.9717088181818182, 0.9322466363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 283}], {
             RGBColor[
             0.9898609545454545, 0.9885496363636364, 0.7067971363636362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 287}], {
             RGBColor[
             0.9898609545454545, 0.9885496363636364, 0.7067971363636362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 300}], {
             RGBColor[
             0.9451743636363634, 0.9574829090909089, 0.9344727727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 139}], {
             RGBColor[
             0.6835698181818182, 0.7495741818181818, 0.9673488636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 143}], {
             RGBColor[
             0.5589171818181817, 0.6513373636363635, 0.9591237272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 163}], {
             RGBColor[
             0.4917317272727272, 0.5975352727272727, 0.9533272727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 174}], {
             RGBColor[
             0.6235080909090909, 0.7017962727272726, 0.9655615454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 235}], {
             RGBColor[
             0.7097675909090909, 0.7653342727272727, 0.6869035454545457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 274}], {
             RGBColor[
             0.35018649999999996`, 0.4744622272727272, 0.9436544090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 298}], {
             RGBColor[
             0.5261028181818181, 0.6254392727272727, 0.9560330909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 115}], {
             RGBColor[
             0.9633602272727273, 0.880890272727273, 0.5045321818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 155}], {
             RGBColor[
             0.8898231818181819, 0.5668419090909097, 0.22866750000000008`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 162}], {
             RGBColor[
             0.8972544090909091, 0.8313647272727276, 0.6256043181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 194}], {
             RGBColor[
             0.9539108636363638, 0.8755179090909094, 0.5955354545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 200}], {
             RGBColor[
             0.9558311818181819, 0.8557161818181821, 0.31913031818181814`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 210}], {
             RGBColor[
             0.9362770454545455, 0.8623666363636366, 0.6253849090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 211}], {
             RGBColor[
             0.8972544090909091, 0.8313647272727276, 0.6256043181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 227}], {
             RGBColor[
             0.8972544090909091, 0.8313647272727276, 0.6256043181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 241}], {
             RGBColor[
             0.6028937272727273, 0.5872546818181821, 0.6016904545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 264}], {
             RGBColor[
             0.9539108636363638, 0.8755179090909094, 0.5955354545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 290}], {
             RGBColor[
             0.6534535909090909, 0.6343205454545457, 0.6047922272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 291}], {
             RGBColor[
             0.9613438636363637, 0.8800564545454549, 0.5379485454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 137}], {
             RGBColor[
             0.9935135454545454, 0.9885344545454546, 0.5353676363636367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 139}], {
             RGBColor[
             0.9673157727272728, 0.9727743636363637, 0.8158129545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[
             0.8098487727272727, 0.8486394545454545, 0.804497181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 150}], {
             RGBColor[
             0.9673157727272728, 0.9727743636363637, 0.8158129545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.6844923181818181, 0.7447282727272726, 0.7952202727272729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[0.6582065, 0.7219608181818182, 0.7935453636363639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 251}], {
             RGBColor[
             0.9849495909090908, 0.9859256363636364, 0.7859635000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 273}], {
             RGBColor[
             0.9673157727272728, 0.9727743636363637, 0.8158129545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 274}], {
             RGBColor[
             0.6339324545454545, 0.697662409090909, 0.7921185000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 277}], {
             RGBColor[
             0.9849495909090908, 0.9859256363636364, 0.7859635000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 289}], {
             RGBColor[
             0.9935135454545454, 0.9885344545454546, 0.5353676363636367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 136}], {
             RGBColor[
             0.9010848181818181, 0.9238509090909091, 0.9864860454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 177}], {
             RGBColor[
             0.9282931363636363, 0.9417724545454544, 0.8160323636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 204}], {
             RGBColor[
             0.9010848181818181, 0.9238509090909091, 0.9864860454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 208}], {
             RGBColor[0.7436178181818182, 0.799716, 0.9751702727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 252}], {
             RGBColor[0.9272825909090909, 0.939611, 0.7060407272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 254}], {
             RGBColor[
             0.9010848181818181, 0.9238509090909091, 0.9864860454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 268}], {
             RGBColor[
             0.7764321818181817, 0.8256140909090908, 0.9782609090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 279}], {
             RGBColor[
             0.8087276363636363, 0.8508435454545453, 0.9814798181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 280}], {
             RGBColor[
             0.9187186363636364, 0.9370021818181817, 0.9566365909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 283}], {
             RGBColor[
             0.9277878636363637, 0.9406917272727272, 0.7610365454545452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 111}], {
             RGBColor[
             0.6923867272727273, 0.7561498181818181, 0.9524241363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 151}], {
             RGBColor[0.7086366363636363, 0.767264, 0.8799125000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 155}], {
             RGBColor[
             0.6371159545454546, 0.45404945454545476`, 0.5706314545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 192}], {
             RGBColor[
             0.45736063636363644`, 0.5696312727272728, 0.9506214545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 218}], {
             RGBColor[
             0.4917317272727272, 0.5975352727272727, 0.9533272727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 220}], {
             RGBColor[0.710653, 0.7680978181818181, 0.8464961363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 227}], {
             RGBColor[
             0.6445471818181818, 0.7185722727272726, 0.9675682727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 290}], {
             RGBColor[
             0.4007463636363635, 0.5215280909090908, 0.9467561818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 292}], {
             RGBColor[
             0.6835698181818182, 0.7495741818181818, 0.9673488636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 148}], {
             RGBColor[
             0.7031239545454545, 0.7429237272727272, 0.6610942727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 191}], {
             RGBColor[0.9867447727272727, 0.966726, 0.5591593181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 223}], {
             RGBColor[
             0.9792157272727272, 0.941551909090909, 0.3737574545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 246}], {
             RGBColor[
             0.9827120454545454, 0.9650583636363637, 0.6259920454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 278}], {
             RGBColor[
             0.986869909090909, 0.9661239090909091, 0.5095583636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 295}], {
             RGBColor[
             0.7031239545454545, 0.7429237272727272, 0.6610942727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 143}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 163}], {
             RGBColor[
             0.7570862727272727, 0.8093895454545454, 0.9573203181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.8888626363636363, 0.9136505454545454, 0.9695545909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 218}], {
             RGBColor[
             0.7570862727272727, 0.8093895454545454, 0.9573203181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 235}], {
             RGBColor[
             0.9751221363636364, 0.9771885454545455, 0.6908965909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 262}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 292}], {
             RGBColor[
             0.9489243636363636, 0.9614284545454546, 0.971341909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 131}], {
             RGBColor[
             0.5204945909090908, 0.5991214999999999, 0.9601032272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 132}], {
             RGBColor[0.5415336818181817, 0.6158975, 0.9621099545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 133}], {
             RGBColor[
             0.2504079545454546, 0.37930986363636365`, 0.9376162272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 146}], {
             RGBColor[
             0.5204945909090908, 0.5991214999999999, 0.9601032272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 170}], {
             RGBColor[
             0.5683341363636363, 0.6366990454545454, 0.9449590909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 190}], {
             RGBColor[
             0.43486459090909085`, 0.5318865909090909, 0.9516586818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 115}], {
             RGBColor[
             0.9539536818181819, 0.8435964545454546, 0.49696345454545465`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 134}], {
             RGBColor[
             0.9499209545454546, 0.8419288181818183, 0.5637961818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 144}], {
             RGBColor[
             0.8668087727272727, 0.7772949090909091, 0.6160288636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 160}], {
             RGBColor[
             0.9047646363636365, 0.6577307272727275, 0.2421054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 169}], {
             RGBColor[
             0.8881020909090909, 0.5820699999999999, 0.22820181818181817`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 176}], {
             RGBColor[0.9268705, 0.8250728181818183, 0.6178161818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 187}], {
             RGBColor[
             0.9535735454545455, 0.8419136363636364, 0.39236668181818163`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 193}], {
             RGBColor[0.8022178636363637, 0.726836, 0.6095910454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 200}], {
             RGBColor[
             0.9464246363636364, 0.8184223636363637, 0.31156159090909086`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 228}], {
             RGBColor[
             0.8878478636363636, 0.794070909090909, 0.6180355909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 231}], {
             RGBColor[
             0.9445043181818182, 0.838224090909091, 0.5879667272727274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 245}], {
             RGBColor[
             0.8878478636363636, 0.794070909090909, 0.6180355909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 264}], {
             RGBColor[
             0.9445043181818182, 0.838224090909091, 0.5879667272727274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 288}], {
             RGBColor[
             0.5698837272727273, 0.5251521363636363, 0.5927775454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 297}], {
             RGBColor[
             0.8878478636363636, 0.794070909090909, 0.6180355909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 116}], {
             RGBColor[
             0.9206389545454545, 0.9172004545454544, 0.6802314545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 204}], {
             RGBColor[
             0.9010848181818181, 0.9238509090909091, 0.9864860454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 206}], {
             RGBColor[
             0.9187186363636364, 0.9370021818181817, 0.9566365909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 254}], {
             RGBColor[
             0.9010848181818181, 0.9238509090909091, 0.9864860454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 283}], {
             RGBColor[
             0.9277878636363637, 0.9406917272727272, 0.7610365454545452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 134}], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 169}], {
             RGBColor[
             0.9284222272727272, 0.7303736363636362, 0.4757995454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 193}], {
             RGBColor[0.842538, 0.8751396363636363, 0.8571887727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 200}], {
             RGBColor[0.9867447727272727, 0.966726, 0.5591593181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 210}], {
             RGBColor[
             0.9671906363636363, 0.9733764545454546, 0.8654139090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 211}], {
             RGBColor[
             0.9281679999999999, 0.9423745454545454, 0.8656333181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 227}], {
             RGBColor[
             0.9281679999999999, 0.9423745454545454, 0.8656333181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 228}], {
             RGBColor[
             0.9281679999999999, 0.9423745454545454, 0.8656333181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 231}], {
             RGBColor[
             0.9848244545454545, 0.9865277272727273, 0.8355644545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 245}], {
             RGBColor[
             0.9281679999999999, 0.9423745454545454, 0.8656333181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 264}], {
             RGBColor[
             0.9848244545454545, 0.9865277272727273, 0.8355644545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 204}], {
             RGBColor[
             0.9596615909090909, 0.9482023636363637, 0.6800120454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 206}], {
             RGBColor[
             0.9772954090909091, 0.9613536363636364, 0.6501625909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 254}], {
             RGBColor[
             0.9596615909090909, 0.9482023636363637, 0.6800120454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 283}], {
             RGBColor[
             0.9863646363636364, 0.9650431818181817, 0.45456254545454516`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 287}], {
             RGBColor[
             0.9863646363636364, 0.9650431818181817, 0.45456254545454516`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 158}], {
             RGBColor[
             0.7863560454545455, 0.47148254545454543`, 0.5702360909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 196}], {
             RGBColor[
             0.8345133181818183, 0.7520654545454546, 0.6128099545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 207}], {
             RGBColor[
             0.5912126363636363, 0.6765668181818181, 0.9623426363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 212}], {
             RGBColor[
             0.4907634999999999, 0.5819247727272726, 0.9562217727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 214}], {
             RGBColor[
             0.8173131363636363, 0.6766730000000001, 0.5985978636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 225}], {
             RGBColor[
             0.8708007272727272, 0.8987014545454546, 0.9272404090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 265}], {
             RGBColor[
             0.7553930909090909, 0.8088380909090909, 0.9762541818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 276}], {
             RGBColor[
             0.6902832727272727, 0.7577105454545454, 0.9699446363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 166}], {
             RGBColor[
             0.862316409090909, 0.6808480909090907, 0.5968716818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.9241352727272727, 0.940706909090909, 0.9324660454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 234}], {
             RGBColor[
             0.5440980454545453, 0.6239302272727272, 0.9614474090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 239}], {
             RGBColor[
             0.9010848181818181, 0.9238509090909091, 0.9864860454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 263}], {
             RGBColor[
             0.7764321818181817, 0.8256140909090908, 0.9782609090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 285}], {
             RGBColor[
             0.8087276363636363, 0.8508435454545453, 0.9814798181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 122}], {
             RGBColor[
             0.9596615909090909, 0.9482023636363637, 0.6800120454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 161}], {
             RGBColor[
             0.8995998636363636, 0.9004244545454545, 0.6782247272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 244}], {
             RGBColor[0.9684785, 0.9547779999999999, 0.6650873181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 266}], {
             RGBColor[0.867304409090909, 0.875195, 0.6750058181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 131}], {
             RGBColor[
             0.8087276363636363, 0.8508435454545453, 0.9814798181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 141}], {
             RGBColor[0.867304409090909, 0.875195, 0.6750058181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 170}], {
             RGBColor[
             0.8565671818181818, 0.8884210909090908, 0.9663356818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 178}], {
             RGBColor[
             0.6559121818181817, 0.7298065454545454, 0.9672388181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 182}], {
             RGBColor[
             0.8087276363636363, 0.8508435454545453, 0.9814798181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 188}], {
             RGBColor[
             0.5912126363636363, 0.6765668181818181, 0.9623426363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 190}], {
             RGBColor[
             0.7230976363636363, 0.7836086363636363, 0.9730352727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 261}], {
             RGBColor[
             0.8653840909090909, 0.8949967272727273, 0.9514109545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 284}], {
             RGBColor[
             0.8739480454545454, 0.8976055454545455, 0.7008150909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 294}], {
             RGBColor[0.867304409090909, 0.875195, 0.6750058181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 135}], {
             RGBColor[
             0.7974712727272726, 0.8423900909090908, 0.9802676363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 154}], {
             RGBColor[
             0.9492070909090908, 0.9591505454545454, 0.8676400454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 173}], {
             RGBColor[
             0.935034409090909, 0.911565909090909, 0.656428909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.8831012727272726, 0.9096249999999999, 0.9887121818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 234}], {
             RGBColor[
             0.5651371363636362, 0.6407062272727271, 0.9634541363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 239}], {
             RGBColor[
             0.922123909090909, 0.940626909090909, 0.9884927727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 249}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999998, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 255}], {
             RGBColor[
             0.8681998636363636, 0.5876830909090911, 0.5846219090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 258}], {
             RGBColor[
             0.9309408181818181, 0.9472025454545454, 0.9735680454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 263}], {
             RGBColor[
             0.7974712727272726, 0.8423900909090908, 0.9802676363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 286}], {
             RGBColor[
             0.8681998636363636, 0.5876830909090911, 0.5846219090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 138}], {
             RGBColor[
             0.8800457272727272, 0.907074909090909, 0.9844793181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 161}], {
             RGBColor[
             0.8800457272727272, 0.907074909090909, 0.9844793181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 266}], {
             RGBColor[
             0.8477502727272728, 0.8818454545454546, 0.9812604090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 189}], {
             RGBColor[0.842538, 0.8751396363636363, 0.8571887727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 257}], {
             RGBColor[
             0.8283653181818181, 0.8275549999999999, 0.6459776363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 267}], {
             RGBColor[
             0.8330886363636363, 0.8697672727272727, 0.9481920454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 287}], {
             RGBColor[
             0.8421578636363636, 0.8734568181818181, 0.7525919999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 300}], {
             RGBColor[
             0.7974712727272726, 0.8423900909090908, 0.9802676363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 147}], {
             RGBColor[0.7287164090909092, 0.4777740909090913, 0.57108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 247}], {
             RGBColor[
             0.9057375454545455, 0.5952585454545458, 0.2761411818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 273}], {
             RGBColor[
             0.8861834090909091, 0.6019090000000004, 0.5823957727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 289}], {
             RGBColor[
             0.912381181818182, 0.6176690909090913, 0.30195045454545477`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 128}], {
             RGBColor[
             0.9618348636363636, 0.9323674545454546, 0.6392780454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 130}], {
             RGBColor[
             0.9706517727272728, 0.9389430909090909, 0.6243533181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 142}], {
             RGBColor[
             0.9139953181818181, 0.894789909090909, 0.6544221818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.9797210000000001, 0.9426326363636364, 0.4287532727272725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 150}], {
             RGBColor[
             0.9530179545454545, 0.9257918181818181, 0.6542027727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 167}], {
             RGBColor[0.7955509545454545, 0.8016569090909091, 0.642887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 237}], {
             RGBColor[
             0.9618348636363636, 0.9323674545454546, 0.6392780454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 243}], {
             RGBColor[
             0.9801011363636363, 0.9443154545454545, 0.5333500454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 256}], {
             RGBColor[
             0.5724277272727273, 0.601062409090909, 0.6278199545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 269}], {
             RGBColor[
             0.9530179545454545, 0.9257918181818181, 0.6542027727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 277}], {
             RGBColor[
             0.9706517727272728, 0.9389430909090909, 0.6243533181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 281}], {
             RGBColor[
             0.6196346363636362, 0.6506798636363635, 0.6305083181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 293}], {
             RGBColor[
             0.8929562272727272, 0.8780139090909089, 0.6524154545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 153}], {
             RGBColor[
             0.8297667272727272, 0.8676195454545453, 0.9834865454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 157}], {
             RGBColor[
             0.9309408181818181, 0.9472025454545454, 0.9735680454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 192}], {
             RGBColor[
             0.6959147272727273, 0.7606839999999999, 0.9717653636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 220}], {
             RGBColor[
             0.9492070909090908, 0.9591505454545454, 0.8676400454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 222}], {
             RGBColor[
             0.9492070909090908, 0.9591505454545454, 0.8676400454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 239}], {
             RGBColor[
             0.922123909090909, 0.940626909090909, 0.9884927727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 248}], {
             RGBColor[
             0.9488269545454544, 0.9574677272727272, 0.7630432727272725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 285}], {
             RGBColor[
             0.8297667272727272, 0.8676195454545453, 0.9834865454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 145}], {
             RGBColor[
             0.9281679999999999, 0.9423745454545454, 0.8656333181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 148}], {
             RGBColor[
             0.6445471818181818, 0.7185722727272726, 0.9675682727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 156}], {
             RGBColor[
             0.6182613636363635, 0.695804818181818, 0.9658933636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 159}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 168}], {
             RGBColor[
             0.8831012727272726, 0.9096249999999999, 0.9887121818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 191}], {
             RGBColor[
             0.9281679999999999, 0.9423745454545454, 0.8656333181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 205}], {
             RGBColor[
             0.8706476818181819, 0.7186784545454546, 0.6038235000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 212}], {
             RGBColor[
             0.5440980454545453, 0.6239302272727272, 0.9614474090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 225}], {
             RGBColor[
             0.9241352727272727, 0.940706909090909, 0.9324660454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 251}], {
             RGBColor[
             0.9187186363636364, 0.9370021818181817, 0.9566365909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 269}], {
             RGBColor[
             0.9010848181818181, 0.9238509090909091, 0.9864860454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 276}], {
             RGBColor[0.7436178181818182, 0.799716, 0.9751702727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 282}], {
             RGBColor[
             0.7764321818181817, 0.8256140909090908, 0.9782609090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 142}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 149}], {
             RGBColor[
             0.9756274090909092, 0.9782692727272727, 0.7458924090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 150}], {
             RGBColor[
             0.9489243636363636, 0.9614284545454546, 0.971341909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 197}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 198}], {
             RGBColor[
             0.9739911818181818, 0.9791182727272727, 0.8839055454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 237}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 243}], {
             RGBColor[
             0.9760075454545454, 0.9799520909090909, 0.8504891818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 256}], {
             RGBColor[
             0.5683341363636364, 0.6366990454545455, 0.9449590909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 269}], {
             RGBColor[
             0.9489243636363636, 0.9614284545454546, 0.971341909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 277}], {
             RGBColor[
             0.9665581818181819, 0.9745797272727272, 0.9414924545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 281}], {
             RGBColor[0.6155410454545454, 0.6863165, 0.9476474545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 165}], {
             RGBColor[
             0.9397577272727271, 0.9537781818181817, 0.9586433181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 175}], {
             RGBColor[
             0.9839390454545455, 0.9837641818181819, 0.6759718636363639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 183}], {
             RGBColor[
             0.9187186363636364, 0.9370021818181817, 0.9566365909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 184}], {
             RGBColor[
             0.731532090909091, 0.788061181818182, 0.9396897727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 224}], {
             RGBColor[
             0.5771510454545454, 0.6432746818181818, 0.9300343636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 253}], {
             RGBColor[
             0.731532090909091, 0.788061181818182, 0.9396897727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 140}], {
             RGBColor[
             0.7659031818181817, 0.8159651818181818, 0.9423955909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 162}], {
             RGBColor[
             0.9187186363636364, 0.9370021818181817, 0.9566365909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 167}], {
             RGBColor[
             0.8002742727272727, 0.8438691818181818, 0.9451014090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 201}], {
             RGBColor[
             0.7659031818181817, 0.8159651818181818, 0.9423955909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 202}], {
             RGBColor[
             0.8653840909090909, 0.8949967272727273, 0.9514109545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 203}], {
             RGBColor[
             0.9539108636363638, 0.8755179090909094, 0.5955354545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 216}], {
             RGBColor[
             0.9187186363636364, 0.9370021818181817, 0.9566365909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 237}], {
             RGBColor[
             0.9665581818181819, 0.9745797272727272, 0.9414924545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 269}], {
             RGBColor[
             0.9577412727272727, 0.968004090909091, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 281}], {
             RGBColor[
             0.6243579545454545, 0.6928921363636363, 0.9327227272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 293}], {
             RGBColor[
             0.8976795454545454, 0.9202261818181818, 0.9546298636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 294}], {
             RGBColor[
             0.9772954090909091, 0.9613536363636364, 0.6501625909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 299}], {
             RGBColor[
             0.731532090909091, 0.788061181818182, 0.9396897727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 141}], {
             RGBColor[
             0.9206389545454545, 0.9172004545454544, 0.6802314545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 146}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 170}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 178}], {
             RGBColor[
             0.7092467272727272, 0.7718119999999999, 0.9724644545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 182}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 188}], {
             RGBColor[
             0.6445471818181818, 0.7185722727272726, 0.9675682727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 190}], {
             RGBColor[
             0.7764321818181817, 0.8256140909090908, 0.9782609090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 199}], {
             RGBColor[
             0.9277878636363637, 0.9406917272727272, 0.7610365454545452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 261}], {
             RGBColor[
             0.9187186363636364, 0.9370021818181817, 0.9566365909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 284}], {
             RGBColor[0.9272825909090909, 0.939611, 0.7060407272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 133}], {
             RGBColor[
             0.6130146363636363, 0.6898133636363636, 0.9662251818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 146}], {
             RGBColor[
             0.8831012727272726, 0.9096249999999999, 0.9887121818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 236}], {
             RGBColor[
             0.6959147272727273, 0.7606839999999999, 0.9717653636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 260}], {
             RGBColor[0.764656909090909, 0.816492, 0.977177]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{132, 267}], {
             RGBColor[
             0.9397577272727271, 0.9537781818181817, 0.9586433181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 146}], {
             RGBColor[
             0.5919755454545454, 0.6730373636363636, 0.9642184545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 170}], {
             RGBColor[
             0.6398150909090909, 0.7106149090909091, 0.9490743181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 144}], {
             RGBColor[
             0.9030961818181817, 0.923930909090909, 0.9304593181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 160}], {
             RGBColor[
             0.9410520454545455, 0.8043667272727274, 0.5565359090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 169}], {
             RGBColor[0.9243895, 0.7287059999999999, 0.5426322727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 176}], {
             RGBColor[
             0.963157909090909, 0.9717088181818182, 0.9322466363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 180}], {
             RGBColor[
             0.6540486363636364, 0.7208952727272728, 0.9099790454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 187}], {
             RGBColor[
             0.9898609545454545, 0.9885496363636364, 0.7067971363636362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 193}], {
             RGBColor[0.8385052727272726, 0.873472, 0.9240215]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{134, 200}], {
             RGBColor[
             0.9827120454545454, 0.9650583636363637, 0.6259920454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 221}], {
             RGBColor[
             0.9092338636363637, 0.6187650000000003, 0.5283757727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 228}], {
             RGBColor[
             0.9241352727272727, 0.940706909090909, 0.9324660454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 230}], {
             RGBColor[
             0.9719748181818182, 0.9782844545454545, 0.917321909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 245}], {
             RGBColor[
             0.9241352727272727, 0.940706909090909, 0.9324660454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 264}], {
             RGBColor[
             0.9807917272727272, 0.984860090909091, 0.9023971818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 288}], {
             RGBColor[0.6061711363636362, 0.6717881363636362, 0.907208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 297}], {
             RGBColor[
             0.9241352727272727, 0.940706909090909, 0.9324660454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 158}], {
             RGBColor[
             0.7540605909090909, 0.4462530909090909, 0.5670171818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 173}], {
             RGBColor[
             0.8283653181818181, 0.8275549999999999, 0.6459776363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 186}], {
             RGBColor[
             0.8330886363636363, 0.8697672727272727, 0.9481920454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 213}], {
             RGBColor[
             0.7764321818181817, 0.8256140909090908, 0.9782609090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 214}], {
             RGBColor[
             0.7850176818181818, 0.6514435454545455, 0.5953789545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 249}], {
             RGBColor[
             0.7553930909090909, 0.8088380909090909, 0.9762541818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 255}], {
             RGBColor[
             0.7615307727272728, 0.5036721818181822, 0.5741706363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 263}], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 265}], {
             RGBColor[
             0.7230976363636363, 0.7836086363636363, 0.9730352727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 276}], {
             RGBColor[
             0.6579878181818182, 0.7324810909090909, 0.9667257272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 286}], {
             RGBColor[
             0.7615307727272728, 0.5036721818181822, 0.5741706363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 177}], {
             RGBColor[
             0.9673157727272728, 0.9727743636363637, 0.8158129545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 194}], {
             RGBColor[
             0.9577412727272727, 0.968004090909091, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 197}], {
             RGBColor[0.8154548181818182, 0.856616, 0.9780415]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{136, 204}], {
             RGBColor[
             0.9401074545454545, 0.9548528181818182, 0.9862666363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 210}], {
             RGBColor[
             0.9401074545454545, 0.9548528181818182, 0.9862666363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 226}], {
             RGBColor[
             0.9401074545454545, 0.9548528181818182, 0.9862666363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 252}], {
             RGBColor[
             0.9663052272727273, 0.9706129090909091, 0.7058213181818184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 279}], {
             RGBColor[
             0.8477502727272728, 0.8818454545454546, 0.9812604090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 280}], {
             RGBColor[
             0.9577412727272727, 0.968004090909091, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 147}], {
             RGBColor[
             0.8088382272727273, 0.8464780000000001, 0.6945055454545457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 156}], {
             RGBColor[
             0.6834817727272726, 0.7425668181818181, 0.6852286363636366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 179}], {
             RGBColor[
             0.6571959545454547, 0.7197993636363638, 0.6835537272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 191}], {
             RGBColor[
             0.9933884090909091, 0.9891365454545455, 0.5849685909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 217}], {
             RGBColor[
             0.9839390454545455, 0.9837641818181819, 0.6759718636363639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 247}], {
             RGBColor[
             0.9858593636363636, 0.9639624545454546, 0.39956672727272735`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 251}], {
             RGBColor[
             0.9839390454545455, 0.9837641818181819, 0.6759718636363639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 270}], {
             RGBColor[
             0.9839390454545455, 0.9837641818181819, 0.6759718636363639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 271}], {
             RGBColor[
             0.9483216818181817, 0.9563869999999999, 0.7080474545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 273}], {
             RGBColor[
             0.9663052272727273, 0.9706129090909091, 0.7058213181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 278}], {
             RGBColor[
             0.9935135454545454, 0.9885344545454546, 0.5353676363636367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 289}], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 295}], {
             RGBColor[
             0.7097675909090909, 0.7653342727272727, 0.6869035454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 210}], {
             RGBColor[
             0.8800457272727272, 0.907074909090909, 0.9844793181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 211}], {
             RGBColor[
             0.8410230909090908, 0.8760729999999999, 0.9846987272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 231}], {
             RGBColor[
             0.8976795454545454, 0.9202261818181818, 0.9546298636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 266}], {
             RGBColor[
             0.7876885454545455, 0.8340675454545454, 0.979473090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 143}], {
             RGBColor[0.8154548181818182, 0.856616, 0.9780415]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{139, 163}], {
             RGBColor[
             0.7482693636363635, 0.802813909090909, 0.9722450454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 235}], {
             RGBColor[
             0.9663052272727273, 0.9706129090909091, 0.7058213181818184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 273}], {
             RGBColor[
             0.9401074545454545, 0.9548528181818182, 0.9862666363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 274}], {
             RGBColor[
             0.6067241363636363, 0.6797408636363635, 0.9625721818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 298}], {
             RGBColor[
             0.7826404545454546, 0.8307179090909091, 0.9749508636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 162}], {
             RGBColor[
             0.7092467272727272, 0.7718119999999999, 0.9724644545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 167}], {
             RGBColor[0.5908023636363635, 0.678679, 0.9609292727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 181}], {
             RGBColor[
             0.7611798636363636, 0.773752909090909, 0.6401811818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 201}], {
             RGBColor[
             0.5564312727272726, 0.6507749999999999, 0.9582234545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 202}], {
             RGBColor[
             0.6559121818181817, 0.7298065454545454, 0.9672388181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 203}], {
             RGBColor[
             0.7444389545454546, 0.7103277272727275, 0.6113633181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 216}], {
             RGBColor[
             0.7092467272727272, 0.7718119999999999, 0.9724644545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 237}], {
             RGBColor[
             0.7570862727272727, 0.8093895454545454, 0.9573203181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 269}], {
             RGBColor[
             0.7482693636363635, 0.802813909090909, 0.9722450454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 293}], {
             RGBColor[
             0.6882076363636362, 0.7550359999999998, 0.9704577272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 299}], {
             RGBColor[0.5220601818181818, 0.622871, 0.9555176363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 146}], {
             RGBColor[
             0.9206389545454545, 0.9172004545454544, 0.6802314545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 178}], {
             RGBColor[
             0.7678234999999999, 0.7961634545454545, 0.6659904545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 182}], {
             RGBColor[
             0.9206389545454545, 0.9172004545454544, 0.6802314545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 188}], {
             RGBColor[
             0.7031239545454545, 0.7429237272727272, 0.6610942727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 236}], {
             RGBColor[
             0.7334524090909091, 0.7682594545454546, 0.6632846363636362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 261}], {
             RGBColor[
             0.9772954090909091, 0.9613536363636364, 0.6501625909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 294}], {
             RGBColor[
             0.9792157272727272, 0.941551909090909, 0.3737574545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 149}], {
             RGBColor[
             0.9277878636363637, 0.9406917272727272, 0.7610365454545452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[
             0.9010848181818181, 0.9238509090909091, 0.9864860454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 163}], {
             RGBColor[
             0.7092467272727272, 0.7718119999999999, 0.9724644545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 197}], {
             RGBColor[
             0.7764321818181817, 0.8256140909090908, 0.9782609090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 198}], {
             RGBColor[
             0.9261516363636363, 0.9415407272727272, 0.8990496818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 243}], {
             RGBColor[
             0.9281679999999999, 0.9423745454545454, 0.8656333181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 256}], {
             RGBColor[0.5204945909090909, 0.5991215, 0.9601032272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 277}], {
             RGBColor[
             0.9187186363636364, 0.9370021818181817, 0.9566365909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 163}], {
             RGBColor[
             0.6236167272727271, 0.7045770909090908, 0.9640199090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 174}], {
             RGBColor[
             0.7553930909090909, 0.8088380909090909, 0.9762541818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 185}], {
             RGBColor[
             0.7553930909090909, 0.8088380909090909, 0.9762541818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 235}], {
             RGBColor[
             0.8416525909090908, 0.872376090909091, 0.697596181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 298}], {
             RGBColor[
             0.6579878181818182, 0.7324810909090909, 0.9667257272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 160}], {
             RGBColor[
             0.8579398636363637, 0.7397328181818182, 0.608768590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 176}], {
             RGBColor[
             0.8800457272727272, 0.907074909090909, 0.9844793181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 221}], {
             RGBColor[
             0.8261216818181818, 0.5541310909090912, 0.5806084545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 230}], {
             RGBColor[
             0.8888626363636363, 0.9136505454545454, 0.9695545909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 231}], {
             RGBColor[
             0.8976795454545454, 0.9202261818181818, 0.9546298636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 232}], {
             RGBColor[
             0.6235080909090909, 0.7017962727272726, 0.9655615454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 240}], {
             RGBColor[
             0.8410230909090908, 0.8760729999999999, 0.9846987272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 245}], {
             RGBColor[
             0.8410230909090908, 0.8760729999999999, 0.9846987272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 264}], {
             RGBColor[
             0.8976795454545454, 0.9202261818181818, 0.9546298636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 288}], {
             RGBColor[
             0.5230589545454545, 0.607154227272727, 0.9594406818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 297}], {
             RGBColor[
             0.8410230909090908, 0.8760729999999999, 0.9846987272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 156}], {
             RGBColor[
             0.6843671818181817, 0.7453303636363635, 0.8448212272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 159}], {
             RGBColor[
             0.9281679999999999, 0.9423745454545454, 0.8656333181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 167}], {
             RGBColor[
             0.8097236363636364, 0.8492415454545454, 0.8540981363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 168}], {
             RGBColor[
             0.9492070909090908, 0.9591505454545454, 0.8676400454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 201}], {
             RGBColor[
             0.7753525454545453, 0.8213375454545454, 0.8513923181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 203}], {
             RGBColor[
             0.9633602272727273, 0.880890272727273, 0.5045321818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 205}], {
             RGBColor[0.9367535, 0.7682040000000001, 0.48275136363636373`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 216}], {
             RGBColor[
             0.9281679999999999, 0.9423745454545454, 0.8656333181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 237}], {
             RGBColor[
             0.9760075454545454, 0.9799520909090909, 0.8504891818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 269}], {
             RGBColor[
             0.9671906363636363, 0.9733764545454546, 0.8654139090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 277}], {
             RGBColor[
             0.9848244545454545, 0.9865277272727273, 0.8355644545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 282}], {
             RGBColor[0.842538, 0.8751396363636363, 0.8571887727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 293}], {
             RGBColor[
             0.907128909090909, 0.9255985454545455, 0.863626590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 170}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 236}], {
             RGBColor[0.6748756363636363, 0.743908, 0.9697586363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 247}], {
             RGBColor[
             0.8021945909090908, 0.8240674545454545, 0.6686962727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 273}], {
             RGBColor[
             0.7826404545454546, 0.8307179090909091, 0.9749508636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 289}], {
             RGBColor[
             0.8088382272727273, 0.8464780000000001, 0.6945055454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 156}], {
             RGBColor[
             0.4007463636363635, 0.5215280909090908, 0.9467561818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 159}], {
             RGBColor[
             0.6445471818181818, 0.7185722727272726, 0.9675682727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 168}], {
             RGBColor[
             0.6655862727272726, 0.7353482727272727, 0.9695750000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 191}], {
             RGBColor[0.710653, 0.7680978181818181, 0.8464961363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 205}], {
             RGBColor[
             0.6531326818181818, 0.5444017272727274, 0.5846863181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 217}], {
             RGBColor[
             0.7012036363636364, 0.7627254545454545, 0.9374994090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 225}], {
             RGBColor[
             0.7066202727272727, 0.7664301818181818, 0.9133288636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 251}], {
             RGBColor[
             0.7012036363636364, 0.7627254545454545, 0.9374994090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 270}], {
             RGBColor[
             0.7012036363636364, 0.7627254545454545, 0.9374994090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 271}], {
             RGBColor[
             0.6655862727272726, 0.7353482727272727, 0.9695750000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 278}], {
             RGBColor[
             0.7107781363636363, 0.7674957272727272, 0.796895181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.5589171818181817, 0.6513373636363635, 0.9591237272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 295}], {
             RGBColor[
             0.4270321818181818, 0.5442955454545454, 0.948431090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 150}], {
             RGBColor[0.9668105, 0.9716936363636364, 0.7608171363636361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.8421578636363636, 0.8734568181818181, 0.7525919999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 198}], {
             RGBColor[
             0.9918773181818181, 0.9893834545454545, 0.6733807727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 243}], {
             RGBColor[
             0.9938936818181818, 0.9902172727272727, 0.6399644090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 256}], {
             RGBColor[
             0.5862202727272727, 0.6469642272727273, 0.734434318181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 277}], {
             RGBColor[
             0.9844443181818182, 0.984844909090909, 0.7309676818181816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 281}], {
             RGBColor[
             0.6334271818181818, 0.6965816818181818, 0.7371226818181816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 179}], {
             RGBColor[
             0.6309981818181818, 0.7040392727272728, 0.9639990454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 237}], {
             RGBColor[
             0.9489243636363636, 0.9614284545454546, 0.971341909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 256}], {
             RGBColor[
             0.5595172272727272, 0.6301234090909091, 0.9598838181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 269}], {
             RGBColor[
             0.9401074545454545, 0.9548528181818182, 0.9862666363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 274}], {
             RGBColor[
             0.6067241363636363, 0.6797408636363635, 0.9625721818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 277}], {
             RGBColor[
             0.9577412727272727, 0.968004090909091, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 281}], {
             RGBColor[
             0.6067241363636363, 0.6797408636363635, 0.9625721818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 293}], {
             RGBColor[
             0.8800457272727272, 0.907074909090909, 0.9844793181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 154}], {
             RGBColor[
             0.9922574545454546, 0.9910662727272728, 0.7779775454545457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 181}], {
             RGBColor[
             0.9780847727272727, 0.9434816363636364, 0.5667664090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 192}], {
             RGBColor[
             0.738965090909091, 0.7925997272727274, 0.8821028636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 220}], {
             RGBColor[
             0.9922574545454546, 0.9910662727272728, 0.7779775454545457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 239}], {
             RGBColor[
             0.9651742727272727, 0.9725426363636365, 0.8988302727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 258}], {
             RGBColor[
             0.9739911818181818, 0.9791182727272727, 0.8839055454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 208}], {
             RGBColor[0.764656909090909, 0.816492, 0.977177]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{152, 242}], {
             RGBColor[
             0.8916867727272726, 0.7354544545454547, 0.6058302272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 244}], {
             RGBColor[
             0.9309408181818181, 0.9472025454545454, 0.9735680454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 268}], {
             RGBColor[
             0.7974712727272726, 0.8423900909090908, 0.9802676363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 157}], {
             RGBColor[
             0.8565671818181818, 0.8884210909090908, 0.9663356818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 192}], {
             RGBColor[0.621541090909091, 0.7019025454545456, 0.964533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 220}], {
             RGBColor[
             0.8748334545454546, 0.9003690909090909, 0.8604076818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 222}], {
             RGBColor[
             0.8748334545454546, 0.9003690909090909, 0.8604076818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 239}], {
             RGBColor[
             0.8477502727272728, 0.8818454545454546, 0.9812604090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 248}], {
             RGBColor[
             0.8744533181818182, 0.8986862727272726, 0.7558109090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 285}], {
             RGBColor[
             0.7553930909090909, 0.8088380909090909, 0.9762541818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 181}], {
             RGBColor[
             0.9801011363636363, 0.9443154545454545, 0.5333500454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[
             0.9633602272727273, 0.880890272727273, 0.5045321818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 216}], {
             RGBColor[
             0.9281679999999999, 0.9423745454545454, 0.8656333181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 255}], {
             RGBColor[
             0.9132665909090909, 0.6204326363636368, 0.4615430454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 258}], {
             RGBColor[
             0.9760075454545454, 0.9799520909090909, 0.8504891818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 162}], {
             RGBColor[
             0.8546309545454545, 0.628326181818182, 0.5897686363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 194}], {
             RGBColor[
             0.9112874090909091, 0.672479363636364, 0.5596997727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 210}], {
             RGBColor[
             0.8936535909090909, 0.6593280909090913, 0.5895492272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 218}], {
             RGBColor[
             0.7018154999999999, 0.5072891818181821, 0.5755276363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 226}], {
             RGBColor[
             0.8936535909090909, 0.6593280909090913, 0.5895492272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 227}], {
             RGBColor[
             0.8546309545454545, 0.628326181818182, 0.5897686363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 241}], {
             RGBColor[
             0.5602702727272727, 0.3842161363636366, 0.5658547727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 290}], {
             RGBColor[
             0.6108301363636363, 0.43128200000000017`, 0.5689565454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 291}], {
             RGBColor[
             0.9187204090909091, 0.6770179090909094, 0.5021128636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.6674444090909092, 0.4793851818181821, 0.5728218181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 159}], {
             RGBColor[
             0.6182613636363635, 0.695804818181818, 0.9658933636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 168}], {
             RGBColor[
             0.6393004545454544, 0.7125808181818181, 0.9679000909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.34817472727272725`, 0.4759931818181818, 0.9434063636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 191}], {
             RGBColor[
             0.6843671818181818, 0.7453303636363635, 0.8448212272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 205}], {
             RGBColor[
             0.6268468636363635, 0.5216342727272728, 0.5830114090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 251}], {
             RGBColor[
             0.6749178181818181, 0.7399579999999999, 0.9358245000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 269}], {
             RGBColor[0.657284, 0.7268067272727272, 0.9656739545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 270}], {
             RGBColor[
             0.6749178181818181, 0.7399579999999999, 0.9358245000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 271}], {
             RGBColor[
             0.6393004545454544, 0.7125808181818181, 0.9679000909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 277}], {
             RGBColor[
             0.6749178181818181, 0.7399579999999999, 0.9358245000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 282}], {
             RGBColor[
             0.5326313636363635, 0.6285699090909089, 0.9574488181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 171}], {
             RGBColor[
             0.9761326818181818, 0.9793499999999999, 0.8008882272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 184}], {
             RGBColor[
             0.7227151818181818, 0.7814855454545455, 0.9546144999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 222}], {
             RGBColor[
             0.9760075454545454, 0.9799520909090909, 0.8504891818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 248}], {
             RGBColor[
             0.9756274090909092, 0.9782692727272727, 0.7458924090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 275}], {
             RGBColor[
             0.9756274090909092, 0.9782692727272727, 0.7458924090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 285}], {
             RGBColor[
             0.8565671818181818, 0.8884210909090908, 0.9663356818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 186}], {
             RGBColor[
             0.8963470454545455, 0.5576411818181819, 0.5453928636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 196}], {
             RGBColor[
             0.8654762727272728, 0.41470990909090916`, 0.20679186363636365`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 207}], {
             RGBColor[
             0.6221755909090909, 0.3392112727272727, 0.5563245454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 212}], {
             RGBColor[
             0.5217264545454545, 0.24456922727272717`, 0.5502036818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 214}], {
             RGBColor[
             0.848276090909091, 0.3393174545454547, 0.19257977272727275`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 225}], {
             RGBColor[
             0.9017636818181818, 0.5613459090909091, 0.5212223181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 265}], {
             RGBColor[
             0.7863560454545455, 0.47148254545454543`, 0.5702360909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 276}], {
             RGBColor[
             0.7212462272727274, 0.42035500000000003`, 0.5639265454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 168}], {
             RGBColor[
             0.8831012727272726, 0.9096249999999999, 0.9887121818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 191}], {
             RGBColor[
             0.9281679999999999, 0.9423745454545454, 0.8656333181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 205}], {
             RGBColor[
             0.8706476818181819, 0.7186784545454546, 0.6038235000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 212}], {
             RGBColor[
             0.5440980454545453, 0.6239302272727272, 0.9614474090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 225}], {
             RGBColor[
             0.9241352727272727, 0.940706909090909, 0.9324660454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 251}], {
             RGBColor[
             0.9187186363636364, 0.9370021818181817, 0.9566365909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 270}], {
             RGBColor[
             0.9187186363636364, 0.9370021818181817, 0.9566365909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 271}], {
             RGBColor[
             0.8831012727272726, 0.9096249999999999, 0.9887121818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 282}], {
             RGBColor[
             0.7764321818181817, 0.8256140909090908, 0.9782609090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 176}], {
             RGBColor[
             0.918001590909091, 0.7875107272727274, 0.6105559090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 180}], {
             RGBColor[
             0.6088923181818182, 0.536697181818182, 0.5882883181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 193}], {
             RGBColor[
             0.7933489545454546, 0.6892739090909092, 0.6023307727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 221}], {
             RGBColor[
             0.8640775454545455, 0.43456690909090956`, 0.20668504545454552`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 230}], {
             RGBColor[0.9268185, 0.7940863636363638, 0.5956311818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 232}], {
             RGBColor[
             0.6614639545454546, 0.582232090909091, 0.5916381363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 245}], {
             RGBColor[
             0.8789789545454545, 0.7565088181818183, 0.6107753181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 288}], {
             RGBColor[
             0.5610148181818182, 0.4875900454545455, 0.5855172727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 296}], {
             RGBColor[
             0.6917924090909092, 0.6075678181818184, 0.5938285000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 297}], {
             RGBColor[
             0.8789789545454545, 0.7565088181818183, 0.6107753181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 177}], {
             RGBColor[
             0.9072540454545455, 0.9249964545454545, 0.8140256363636366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 244}], {
             RGBColor[
             0.8888626363636363, 0.9136505454545454, 0.9695545909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 279}], {
             RGBColor[
             0.7876885454545455, 0.8340675454545454, 0.979473090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 280}], {
             RGBColor[
             0.8976795454545454, 0.9202261818181818, 0.9546298636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 169}], {
             RGBColor[
             0.862316409090909, 0.6808480909090907, 0.5968716818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 181}], {
             RGBColor[
             0.9139953181818181, 0.894789909090909, 0.6544221818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 202}], {
             RGBColor[
             0.8087276363636363, 0.8508435454545453, 0.9814798181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 216}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 227}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 228}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 299}], {
             RGBColor[0.6748756363636363, 0.743908, 0.9697586363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 185}], {
             RGBColor[
             0.6882076363636362, 0.7550359999999998, 0.9704577272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 235}], {
             RGBColor[
             0.7744671363636363, 0.8185739999999999, 0.6917997272727274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 274}], {
             RGBColor[
             0.4148860454545453, 0.5277019545454544, 0.948550590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 292}], {
             RGBColor[
             0.7482693636363635, 0.802813909090909, 0.9722450454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 298}], {
             RGBColor[0.5908023636363635, 0.678679, 0.9609292727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 176}], {
             RGBColor[
             0.8477502727272728, 0.8818454545454546, 0.9812604090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 180}], {
             RGBColor[0.538641, 0.6310319090909091, 0.9589928181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 187}], {
             RGBColor[
             0.8744533181818182, 0.8986862727272726, 0.7558109090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 221}], {
             RGBColor[
             0.7938262272727273, 0.5289016363636367, 0.5773895454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 230}], {
             RGBColor[
             0.8565671818181818, 0.8884210909090908, 0.9663356818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 296}], {
             RGBColor[0.621541090909091, 0.7019025454545456, 0.964533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 297}], {
             RGBColor[
             0.8087276363636363, 0.8508435454545453, 0.9814798181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 175}], {
             RGBColor[
             0.9483216818181817, 0.9563869999999999, 0.7080474545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 183}], {
             RGBColor[
             0.8831012727272726, 0.9096249999999999, 0.9887121818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 224}], {
             RGBColor[
             0.5415336818181817, 0.6158974999999999, 0.9621099545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 253}], {
             RGBColor[
             0.6959147272727273, 0.7606839999999999, 0.9717653636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 262}], {
             RGBColor[
             0.7974712727272726, 0.8423900909090908, 0.9802676363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 195}], {
             RGBColor[0.9243895, 0.7287059999999999, 0.5426322727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 234}], {
             RGBColor[
             0.5443522727272726, 0.41192931818181794`, 0.5716136363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.9013390454545454, 0.7118499999999999, 0.5966522727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 285}], {
             RGBColor[
             0.8089818636363636, 0.6388426363636361, 0.5916460454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 168}], {
             RGBColor[0.764656909090909, 0.816492, 0.977177]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[0.5908023636363635, 0.678679, 0.9609292727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 202}], {
             RGBColor[
             0.6902832727272727, 0.7577105454545454, 0.9699446363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.7788100454545456, 0.7382317272727277, 0.6140691363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 216}], {
             RGBColor[0.7436178181818182, 0.799716, 0.9751702727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 237}], {
             RGBColor[
             0.7914573636363637, 0.8372935454545455, 0.9600261363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 269}], {
             RGBColor[
             0.7826404545454546, 0.8307179090909091, 0.9749508636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 277}], {
             RGBColor[
             0.8002742727272727, 0.8438691818181818, 0.9451014090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 282}], {
             RGBColor[
             0.6579878181818182, 0.7324810909090909, 0.9667257272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 293}], {
             RGBColor[0.7225787272727273, 0.78294, 0.9731635454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 203}], {
             RGBColor[0.9182935, 0.8481407272727275, 0.6276110454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 205}], {
             RGBColor[
             0.8916867727272726, 0.7354544545454547, 0.6058302272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 212}], {
             RGBColor[
             0.5651371363636362, 0.6407062272727271, 0.9634541363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 225}], {
             RGBColor[
             0.9451743636363634, 0.9574829090909089, 0.9344727727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 269}], {
             RGBColor[
             0.922123909090909, 0.940626909090909, 0.9884927727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 276}], {
             RGBColor[0.764656909090909, 0.816492, 0.977177]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{168, 282}], {
             RGBColor[
             0.7974712727272726, 0.8423900909090908, 0.9802676363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 293}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999998, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 193}], {
             RGBColor[
             0.776686409090909, 0.6136131818181816, 0.5884271363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 200}], {
             RGBColor[
             0.9208931818181818, 0.7051995454545452, 0.2903976818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 202}], {
             RGBColor[
             0.8089818636363636, 0.6388426363636361, 0.5916460454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 227}], {
             RGBColor[
             0.862316409090909, 0.6808480909090907, 0.5968716818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 228}], {
             RGBColor[
             0.862316409090909, 0.6808480909090907, 0.5968716818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 264}], {
             RGBColor[
             0.9189728636363637, 0.7250012727272725, 0.5668028181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 299}], {
             RGBColor[
             0.6751298636363636, 0.5319070909090908, 0.5799248636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 178}], {
             RGBColor[
             0.7570862727272727, 0.8093895454545454, 0.9573203181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 182}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 190}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 199}], {
             RGBColor[
             0.9756274090909092, 0.9782692727272727, 0.7458924090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 261}], {
             RGBColor[
             0.9665581818181819, 0.9745797272727272, 0.9414924545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 284}], {
             RGBColor[
             0.9751221363636364, 0.9771885454545455, 0.6908965909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 184}], {
             RGBColor[
             0.741106590909091, 0.7928314545454547, 0.7990855454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 275}], {
             RGBColor[
             0.9940188181818181, 0.9896151818181818, 0.5903634545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 285}], {
             RGBColor[0.8749585909090909, 0.899767, 0.8108067272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 174}], {
             RGBColor[
             0.8800457272727272, 0.907074909090909, 0.9844793181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 238}], {
             RGBColor[
             0.9362770454545455, 0.8623666363636366, 0.6253849090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 186}], {
             RGBColor[
             0.9706517727272728, 0.9389430909090909, 0.6243533181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 213}], {
             RGBColor[
             0.9139953181818181, 0.894789909090909, 0.6544221818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 234}], {
             RGBColor[
             0.5960311818181817, 0.6258711363636362, 0.6291641363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 249}], {
             RGBColor[
             0.8929562272727272, 0.8780139090909089, 0.6524154545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 263}], {
             RGBColor[
             0.8283653181818181, 0.8275549999999999, 0.6459776363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 286}], {
             RGBColor[
             0.8990939090909091, 0.5728480000000002, 0.2503319090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 235}], {
             RGBColor[0.9062435, 0.922835, 0.7040340000000002]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{174, 238}], {
             RGBColor[
             0.8762153181818182, 0.8145887272727275, 0.623597590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 298}], {
             RGBColor[0.7225787272727273, 0.78294, 0.9731635454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 183}], {
             RGBColor[0.9272825909090909, 0.939611, 0.7060407272727274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 224}], {
             RGBColor[0.585715, 0.6458835, 0.6794385000000003]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{175, 253}], {
             RGBColor[
             0.7400960454545455, 0.7906700000000001, 0.6890939090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 180}], {
             RGBColor[
             0.6309981818181818, 0.7040392727272728, 0.9639990454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 187}], {
             RGBColor[0.9668105, 0.9716936363636364, 0.7608171363636361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 193}], {
             RGBColor[0.8154548181818182, 0.856616, 0.9780415]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{176, 221}], {
             RGBColor[
             0.8861834090909091, 0.6019090000000004, 0.5823957727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 230}], {
             RGBColor[
             0.9489243636363636, 0.9614284545454546, 0.971341909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 245}], {
             RGBColor[
             0.9010848181818181, 0.9238509090909091, 0.9864860454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 288}], {
             RGBColor[0.5831206818181818, 0.6549321363636362, 0.961228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 296}], {
             RGBColor[
             0.7138982727272728, 0.7749099090909092, 0.9695392272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 297}], {
             RGBColor[
             0.9010848181818181, 0.9238509090909091, 0.9864860454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 194}], {
             RGBColor[
             0.9849495909090908, 0.9859256363636364, 0.7859635000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 226}], {
             RGBColor[
             0.9673157727272728, 0.9727743636363637, 0.8158129545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 252}], {
             RGBColor[
             0.9935135454545454, 0.9885344545454546, 0.5353676363636367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 268}], {
             RGBColor[
             0.8426631363636363, 0.8745375454545454, 0.8075878181818184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 279}], {
             RGBColor[0.8749585909090909, 0.899767, 0.8108067272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 280}], {
             RGBColor[
             0.9849495909090908, 0.9859256363636364, 0.7859635000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 182}], {
             RGBColor[
             0.7092467272727272, 0.7718119999999999, 0.9724644545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 190}], {
             RGBColor[
             0.6236167272727271, 0.7045770909090908, 0.9640199090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 199}], {
             RGBColor[
             0.774972409090909, 0.8196547272727273, 0.7467955454545452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 229}], {
             RGBColor[
             0.7482693636363635, 0.802813909090909, 0.9722450454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 261}], {
             RGBColor[
             0.7659031818181817, 0.8159651818181818, 0.9423955909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 284}], {
             RGBColor[
             0.7744671363636363, 0.8185739999999999, 0.6917997272727274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 205}], {
             RGBColor[0.6005610454545456, 0.4988668181818184, 0.5813365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 251}], {
             RGBColor[
             0.6486320000000001, 0.7171905454545455, 0.9341495909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 269}], {
             RGBColor[
             0.6309981818181818, 0.7040392727272728, 0.9639990454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 274}], {
             RGBColor[
             0.29761486363636364`, 0.4289273181818182, 0.940304590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 277}], {
             RGBColor[
             0.6486320000000001, 0.7171905454545455, 0.9341495909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 282}], {
             RGBColor[
             0.5063455454545455, 0.6058024545454546, 0.9557739090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 289}], {
             RGBColor[
             0.6571959545454547, 0.7197993636363638, 0.6835537272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 187}], {
             RGBColor[
             0.6577012272727274, 0.7208800909090909, 0.7385495454545452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 193}], {
             RGBColor[
             0.5063455454545455, 0.6058024545454546, 0.9557739090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 215}], {
             RGBColor[
             0.6505523181818182, 0.6973888181818182, 0.6577444545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 221}], {
             RGBColor[
             0.5770741363636365, 0.35109545454545493`, 0.5601281818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 230}], {
             RGBColor[
             0.6398150909090909, 0.7106149090909091, 0.9490743181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 233}], {
             RGBColor[
             0.3744605454545455, 0.4987606363636364, 0.9450812727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 245}], {
             RGBColor[
             0.5919755454545454, 0.6730373636363636, 0.9642184545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 288}], {
             RGBColor[
             0.27401140909090904`, 0.40411859090909086`, 0.9389604090909092]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 296}], {
             RGBColor[
             0.4047890000000001, 0.5240963636363638, 0.9472716363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 297}], {
             RGBColor[
             0.5919755454545454, 0.6730373636363636, 0.9642184545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 201}], {
             RGBColor[
             0.7611798636363636, 0.773752909090909, 0.6401811818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 202}], {
             RGBColor[
             0.8606607727272727, 0.8527844545454545, 0.6491965454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 203}], {
             RGBColor[
             0.9491875454545455, 0.8333056363636366, 0.2933210454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 216}], {
             RGBColor[
             0.9139953181818181, 0.894789909090909, 0.6544221818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 227}], {
             RGBColor[
             0.9139953181818181, 0.894789909090909, 0.6544221818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 258}], {
             RGBColor[
             0.9618348636363636, 0.9323674545454546, 0.6392780454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 299}], {
             RGBColor[
             0.7268087727272727, 0.7458489090909091, 0.6374753636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 190}], {
             RGBColor[
             0.7764321818181817, 0.8256140909090908, 0.9782609090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 199}], {
             RGBColor[
             0.9277878636363637, 0.9406917272727272, 0.7610365454545452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 229}], {
             RGBColor[
             0.9010848181818181, 0.9238509090909091, 0.9864860454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 261}], {
             RGBColor[
             0.9187186363636364, 0.9370021818181817, 0.9566365909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 284}], {
             RGBColor[0.9272825909090909, 0.939611, 0.7060407272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 224}], {
             RGBColor[0.5204945909090909, 0.5991215, 0.9601032272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 253}], {
             RGBColor[0.6748756363636363, 0.743908, 0.9697586363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 222}], {
             RGBColor[
             0.7409814545454546, 0.7934335454545456, 0.8486865000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 224}], {
             RGBColor[
             0.3333080454545455, 0.4501805000000001, 0.943156409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 248}], {
             RGBColor[
             0.7406013181818183, 0.7917507272727273, 0.744089727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 275}], {
             RGBColor[
             0.7406013181818183, 0.7917507272727273, 0.744089727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 218}], {
             RGBColor[
             0.6882076363636362, 0.7550359999999998, 0.9704577272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 235}], {
             RGBColor[0.9062435, 0.922835, 0.7040340000000002]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{185, 262}], {
             RGBColor[
             0.7553930909090909, 0.8088380909090909, 0.9762541818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 292}], {
             RGBColor[
             0.8800457272727272, 0.907074909090909, 0.9844793181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 196}], {
             RGBColor[
             0.9445043181818182, 0.838224090909091, 0.5879667272727274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 214}], {
             RGBColor[
             0.9273041363636364, 0.7628316363636365, 0.5737546363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 249}], {
             RGBColor[
             0.8976795454545454, 0.9202261818181818, 0.9546298636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 265}], {
             RGBColor[
             0.8653840909090909, 0.8949967272727273, 0.9514109545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 286}], {
             RGBColor[
             0.9038172272727274, 0.6150602727272731, 0.5525463181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 193}], {
             RGBColor[
             0.8421578636363636, 0.8734568181818181, 0.7525919999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 215}], {
             RGBColor[
             0.9863646363636364, 0.9650431818181817, 0.45456254545454516`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 228}], {
             RGBColor[
             0.9277878636363637, 0.9406917272727272, 0.7610365454545452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 229}], {
             RGBColor[0.9668105, 0.9716936363636364, 0.7608171363636361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 230}], {
             RGBColor[
             0.9756274090909092, 0.9782692727272727, 0.7458924090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 233}], {
             RGBColor[0.7102728636363637, 0.766415, 0.7418993636363634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 245}], {
             RGBColor[
             0.9277878636363637, 0.9406917272727272, 0.7610365454545452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 288}], {
             RGBColor[
             0.6098237272727272, 0.6717729545454545, 0.7357784999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 296}], {
             RGBColor[
             0.7406013181818183, 0.7917507272727273, 0.744089727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 297}], {
             RGBColor[
             0.9277878636363637, 0.9406917272727272, 0.7610365454545452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 236}], {
             RGBColor[
             0.45736063636363644`, 0.5696312727272728, 0.9506214545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 260}], {
             RGBColor[
             0.5261028181818181, 0.6254392727272727, 0.9560330909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 261}], {
             RGBColor[
             0.7012036363636364, 0.7627254545454545, 0.9374994090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 281}], {
             RGBColor[
             0.35018649999999996`, 0.4744622272727272, 0.9436544090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 294}], {
             RGBColor[
             0.7031239545454545, 0.7429237272727272, 0.6610942727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 257}], {
             RGBColor[
             0.9801011363636363, 0.9443154545454545, 0.5333500454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 260}], {
             RGBColor[
             0.8097236363636364, 0.8492415454545454, 0.8540981363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 267}], {
             RGBColor[
             0.9848244545454545, 0.9865277272727273, 0.8355644545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 287}], {
             RGBColor[
             0.9938936818181818, 0.9902172727272727, 0.6399644090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 300}], {
             RGBColor[
             0.9492070909090908, 0.9591505454545454, 0.8676400454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 199}], {
             RGBColor[
             0.8421578636363636, 0.8734568181818181, 0.7525919999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 261}], {
             RGBColor[
             0.8330886363636363, 0.8697672727272727, 0.9481920454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 284}], {
             RGBColor[
             0.8416525909090908, 0.872376090909091, 0.697596181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 205}], {
             RGBColor[0.9367535, 0.7682040000000001, 0.48275136363636373`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 217}], {
             RGBColor[
             0.9848244545454545, 0.9865277272727273, 0.8355644545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 225}], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 246}], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 251}], {
             RGBColor[
             0.9848244545454545, 0.9865277272727273, 0.8355644545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 270}], {
             RGBColor[
             0.9848244545454545, 0.9865277272727273, 0.8355644545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 271}], {
             RGBColor[
             0.9492070909090908, 0.9591505454545454, 0.8676400454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 278}], {
             RGBColor[0.9943989545454546, 0.991298, 0.6949602272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 282}], {
             RGBColor[0.842538, 0.8751396363636363, 0.8571887727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 295}], {
             RGBColor[0.710653, 0.7680978181818181, 0.8464961363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 218}], {
             RGBColor[0.5220601818181818, 0.622871, 0.9555176363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 220}], {
             RGBColor[
             0.7409814545454546, 0.7934335454545456, 0.8486865000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 222}], {
             RGBColor[
             0.7409814545454546, 0.7934335454545456, 0.8486865000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 248}], {
             RGBColor[
             0.7406013181818183, 0.7917507272727273, 0.744089727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 262}], {
             RGBColor[
             0.5892456363636365, 0.676673090909091, 0.9613140909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 200}], {
             RGBColor[
             0.8350089545454544, 0.8499655454545454, 0.671786909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 215}], {
             RGBColor[
             0.8350089545454544, 0.8499655454545454, 0.671786909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 228}], {
             RGBColor[
             0.7764321818181817, 0.8256140909090908, 0.9782609090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 230}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 245}], {
             RGBColor[
             0.7764321818181817, 0.8256140909090908, 0.9782609090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 264}], {
             RGBColor[
             0.8330886363636363, 0.8697672727272727, 0.9481920454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 288}], {
             RGBColor[
             0.45846804545454534`, 0.556695318181818, 0.9530028636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 210}], {
             RGBColor[
             0.9577412727272727, 0.968004090909091, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 226}], {
             RGBColor[
             0.9577412727272727, 0.968004090909091, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 241}], {
             RGBColor[
             0.6243579545454545, 0.6928921363636363, 0.9327227272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 280}], {
             RGBColor[
             0.9753750909090909, 0.9811553636363637, 0.9265677272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 290}], {
             RGBColor[
             0.6749178181818181, 0.7399579999999999, 0.9358245000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 291}], {
             RGBColor[
             0.9828080909090908, 0.9856939090909091, 0.8689808181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 234}], {
             RGBColor[0.6061711363636362, 0.6717881363636362, 0.907208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 207}], {
             RGBColor[
             0.6703328636363637, 0.6197941818181818, 0.5988984090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 212}], {
             RGBColor[
             0.5698837272727273, 0.5251521363636363, 0.5927775454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 214}], {
             RGBColor[
             0.8964333636363637, 0.6199003636363638, 0.2351536363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 225}], {
             RGBColor[
             0.9499209545454546, 0.8419288181818183, 0.5637961818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 265}], {
             RGBColor[
             0.8345133181818183, 0.7520654545454546, 0.6128099545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 276}], {
             RGBColor[
             0.7694035000000001, 0.7009379090909091, 0.6065004090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 198}], {
             RGBColor[
             0.8405216363636363, 0.8743058181818182, 0.8906051363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 204}], {
             RGBColor[0.8154548181818182, 0.856616, 0.9780415]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{197, 226}], {
             RGBColor[0.8154548181818182, 0.856616, 0.9780415]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{197, 243}], {
             RGBColor[0.842538, 0.8751396363636363, 0.8571887727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 254}], {
             RGBColor[0.8154548181818182, 0.856616, 0.9780415]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{197, 283}], {
             RGBColor[
             0.8421578636363636, 0.8734568181818181, 0.7525919999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 204}], {
             RGBColor[
             0.9651742727272727, 0.9725426363636365, 0.8988302727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 226}], {
             RGBColor[
             0.9651742727272727, 0.9725426363636365, 0.8988302727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 243}], {
             RGBColor[
             0.9922574545454546, 0.9910662727272728, 0.7779775454545457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 254}], {
             RGBColor[
             0.9651742727272727, 0.9725426363636365, 0.8988302727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 256}], {
             RGBColor[
             0.5845840454545455, 0.6478132272727273, 0.8724474545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 283}], {
             RGBColor[
             0.9918773181818181, 0.9893834545454545, 0.6733807727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 209}], {
             RGBColor[
             0.9488269545454544, 0.9574677272727272, 0.7630432727272725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 229}], {
             RGBColor[0.9668105, 0.9716936363636364, 0.7608171363636361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 233}], {
             RGBColor[0.7102728636363637, 0.766415, 0.7418993636363634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 259}], {
             RGBColor[
             0.9756274090909092, 0.9782692727272727, 0.7458924090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 261}], {
             RGBColor[
             0.9844443181818182, 0.984844909090909, 0.7309676818181816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 284}], {
             RGBColor[
             0.9930082727272728, 0.9874537272727273, 0.4803718181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 210}], {
             RGBColor[
             0.9596615909090909, 0.9482023636363637, 0.6800120454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 211}], {
             RGBColor[
             0.9206389545454545, 0.9172004545454544, 0.6802314545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 227}], {
             RGBColor[
             0.9206389545454545, 0.9172004545454544, 0.6802314545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 228}], {
             RGBColor[
             0.9206389545454545, 0.9172004545454544, 0.6802314545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 231}], {
             RGBColor[
             0.9772954090909091, 0.9613536363636364, 0.6501625909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 245}], {
             RGBColor[
             0.9206389545454545, 0.9172004545454544, 0.6802314545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 264}], {
             RGBColor[
             0.9772954090909091, 0.9613536363636364, 0.6501625909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 202}], {
             RGBColor[
             0.6559121818181817, 0.7298065454545454, 0.9672388181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 203}], {
             RGBColor[
             0.7444389545454546, 0.7103277272727275, 0.6113633181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 216}], {
             RGBColor[
             0.7092467272727272, 0.7718119999999999, 0.9724644545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 237}], {
             RGBColor[
             0.7570862727272727, 0.8093895454545454, 0.9573203181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 269}], {
             RGBColor[
             0.7482693636363635, 0.802813909090909, 0.9722450454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 277}], {
             RGBColor[
             0.7659031818181817, 0.8159651818181818, 0.9423955909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 293}], {
             RGBColor[
             0.6882076363636362, 0.7550359999999998, 0.9704577272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 299}], {
             RGBColor[0.5220601818181818, 0.622871, 0.9555176363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 203}], {
             RGBColor[
             0.8439198636363637, 0.789359272727273, 0.6203786818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 216}], {
             RGBColor[
             0.8087276363636363, 0.8508435454545453, 0.9814798181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 237}], {
             RGBColor[
             0.8565671818181818, 0.8884210909090908, 0.9663356818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 269}], {
             RGBColor[
             0.8477502727272728, 0.8818454545454546, 0.9812604090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 293}], {
             RGBColor[
             0.7876885454545455, 0.8340675454545454, 0.979473090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 299}], {
             RGBColor[0.621541090909091, 0.7019025454545456, 0.964533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 216}], {
             RGBColor[
             0.8972544090909091, 0.8313647272727276, 0.6256043181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 237}], {
             RGBColor[
             0.9450939545454546, 0.8689422727272731, 0.6104601818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 255}], {
             RGBColor[
             0.8823530000000002, 0.5094228181818188, 0.22151404545454556`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 269}], {
             RGBColor[
             0.9362770454545455, 0.8623666363636366, 0.6253849090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 293}], {
             RGBColor[
             0.8762153181818182, 0.8145887272727275, 0.623597590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 299}], {
             RGBColor[
             0.7100678636363638, 0.6824237272727276, 0.6086575000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 226}], {
             RGBColor[
             0.9401074545454545, 0.9548528181818182, 0.9862666363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 243}], {
             RGBColor[
             0.9671906363636363, 0.9733764545454546, 0.8654139090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 254}], {
             RGBColor[
             0.9401074545454545, 0.9548528181818182, 0.9862666363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 283}], {
             RGBColor[0.9668105, 0.9716936363636364, 0.7608171363636361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 225}], {
             RGBColor[
             0.9327207727272727, 0.7665363636363638, 0.549584090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 251}], {
             RGBColor[
             0.9273041363636364, 0.7628316363636365, 0.5737546363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 269}], {
             RGBColor[
             0.9096703181818182, 0.7496803636363638, 0.603604090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 282}], {
             RGBColor[
             0.7850176818181818, 0.6514435454545455, 0.5953789545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 219}], {
             RGBColor[
             0.8653840909090909, 0.8949967272727273, 0.9514109545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 254}], {
             RGBColor[
             0.9577412727272727, 0.968004090909091, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 283}], {
             RGBColor[
             0.9844443181818182, 0.984844909090909, 0.7309676818181816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 212}], {
             RGBColor[
             0.32658304545454536`, 0.4496534999999999, 0.9423102272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 214}], {
             RGBColor[
             0.6531326818181818, 0.5444017272727274, 0.5846863181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 225}], {
             RGBColor[
             0.7066202727272727, 0.7664301818181818, 0.9133288636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 242}], {
             RGBColor[
             0.7522033181818182, 0.6255454545454547, 0.5922883181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 244}], {
             RGBColor[
             0.7914573636363637, 0.8372935454545455, 0.9600261363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 252}], {
             RGBColor[
             0.8088382272727273, 0.8464780000000001, 0.6945055454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 268}], {
             RGBColor[
             0.6579878181818182, 0.7324810909090909, 0.9667257272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 279}], {
             RGBColor[
             0.6902832727272727, 0.7577105454545454, 0.9699446363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 259}], {
             RGBColor[
             0.9309408181818181, 0.9472025454545454, 0.9735680454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 211}], {
             RGBColor[
             0.9010848181818181, 0.9238509090909091, 0.9864860454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 226}], {
             RGBColor[
             0.9401074545454545, 0.9548528181818182, 0.9862666363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 227}], {
             RGBColor[
             0.9010848181818181, 0.9238509090909091, 0.9864860454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 241}], {
             RGBColor[
             0.6067241363636363, 0.6797408636363635, 0.9625721818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 290}], {
             RGBColor[
             0.6572839999999999, 0.7268067272727272, 0.9656739545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 291}], {
             RGBColor[
             0.9651742727272727, 0.9725426363636365, 0.8988302727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 231}], {
             RGBColor[
             0.9187186363636364, 0.9370021818181817, 0.9566365909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 264}], {
             RGBColor[
             0.9187186363636364, 0.9370021818181817, 0.9566365909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 266}], {
             RGBColor[
             0.8087276363636363, 0.8508435454545453, 0.9814798181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 214}], {
             RGBColor[
             0.5526835454545453, 0.4497596818181819, 0.5785654545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 225}], {
             RGBColor[0.6061711363636362, 0.6717881363636362, 0.907208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 265}], {
             RGBColor[
             0.4907634999999999, 0.5819247727272726, 0.9562217727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 276}], {
             RGBColor[
             0.42565368181818175`, 0.5307972272727273, 0.9499122272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 234}], {
             RGBColor[
             0.5440980454545453, 0.6239302272727272, 0.9614474090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 249}], {
             RGBColor[
             0.8410230909090908, 0.8760729999999999, 0.9846987272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 263}], {
             RGBColor[
             0.7764321818181817, 0.8256140909090908, 0.9782609090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 286}], {
             RGBColor[
             0.8471607727272727, 0.5709070909090912, 0.5826151818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 265}], {
             RGBColor[
             0.8173131363636363, 0.6766730000000001, 0.5985978636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 276}], {
             RGBColor[
             0.7522033181818182, 0.6255454545454547, 0.5922883181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 286}], {
             RGBColor[
             0.8557462727272729, 0.39673654545454595`, 0.19973322727272735`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 229}], {
             RGBColor[
             0.9596615909090909, 0.9482023636363637, 0.6800120454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 233}], {
             RGBColor[
             0.7031239545454545, 0.7429237272727272, 0.6610942727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 259}], {
             RGBColor[0.9684785, 0.9547779999999999, 0.6650873181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 296}], {
             RGBColor[
             0.7334524090909091, 0.7682594545454546, 0.6632846363636362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 237}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 269}], {
             RGBColor[
             0.9010848181818181, 0.9238509090909091, 0.9864860454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 293}], {
             RGBColor[
             0.8410230909090908, 0.8760729999999999, 0.9846987272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 299}], {
             RGBColor[0.6748756363636363, 0.743908, 0.9697586363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 223}], {
             RGBColor[
             0.9772954090909091, 0.9613536363636364, 0.6501625909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 246}], {
             RGBColor[
             0.9807917272727272, 0.984860090909091, 0.9023971818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 247}], {
             RGBColor[
             0.9772954090909091, 0.9613536363636364, 0.6501625909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 251}], {
             RGBColor[
             0.9753750909090909, 0.9811553636363637, 0.9265677272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 270}], {
             RGBColor[
             0.9753750909090909, 0.9811553636363637, 0.9265677272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 271}], {
             RGBColor[
             0.9397577272727271, 0.9537781818181817, 0.9586433181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 278}], {
             RGBColor[
             0.9849495909090908, 0.9859256363636364, 0.7859635000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 295}], {
             RGBColor[
             0.7012036363636364, 0.7627254545454545, 0.9374994090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 220}], {
             RGBColor[
             0.7753525454545453, 0.8213375454545454, 0.8513923181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 262}], {
             RGBColor[
             0.6236167272727271, 0.7045770909090908, 0.9640199090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 290}], {
             RGBColor[
             0.4654459090909089, 0.5747678181818181, 0.9516523636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 292}], {
             RGBColor[
             0.7482693636363635, 0.802813909090909, 0.9722450454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 250}], {
             RGBColor[0.621541090909091, 0.7019025454545456, 0.964533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 222}], {
             RGBColor[
             0.9942738181818181, 0.9919000909090909, 0.744561181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 248}], {
             RGBColor[
             0.9938936818181818, 0.9902172727272727, 0.6399644090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 262}], {
             RGBColor[0.842538, 0.8751396363636363, 0.8571887727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 230}], {
             RGBColor[
             0.8950003181818182, 0.6084846363636367, 0.5674710454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 232}], {
             RGBColor[
             0.6296457727272728, 0.39663036363636395`, 0.5634780000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 245}], {
             RGBColor[
             0.8471607727272727, 0.5709070909090912, 0.582615181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 288}], {
             RGBColor[
             0.5291966363636363, 0.3019883181818184, 0.5573571363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 296}], {
             RGBColor[
             0.6599742272727274, 0.4219660909090913, 0.5656683636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 297}], {
             RGBColor[
             0.8471607727272727, 0.5709070909090912, 0.582615181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 248}], {
             RGBColor[
             0.9938936818181818, 0.9902172727272727, 0.6399644090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 285}], {
             RGBColor[
             0.8748334545454546, 0.9003690909090909, 0.8604076818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 246}], {
             RGBColor[
             0.9827120454545454, 0.9650583636363637, 0.6259920454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 247}], {
             RGBColor[
             0.9792157272727272, 0.941551909090909, 0.3737574545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 270}], {
             RGBColor[
             0.9772954090909091, 0.9613536363636364, 0.6501625909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 271}], {
             RGBColor[
             0.9416780454545453, 0.9339764545454544, 0.6822381818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 278}], {
             RGBColor[
             0.986869909090909, 0.9661239090909091, 0.5095583636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 295}], {
             RGBColor[
             0.7031239545454545, 0.7429237272727272, 0.6610942727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 253}], {
             RGBColor[
             0.3333080454545455, 0.4501805000000001, 0.943156409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 262}], {
             RGBColor[
             0.43486459090909085`, 0.5318865909090909, 0.9516586818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 265}], {
             RGBColor[
             0.8708007272727272, 0.8987014545454546, 0.9272404090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 276}], {
             RGBColor[
             0.805690909090909, 0.8475739090909091, 0.9209308636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 241}], {
             RGBColor[
             0.6067241363636363, 0.6797408636363635, 0.9625721818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 243}], {
             RGBColor[
             0.9671906363636363, 0.9733764545454546, 0.8654139090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 290}], {
             RGBColor[
             0.6572839999999999, 0.7268067272727272, 0.9656739545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 291}], {
             RGBColor[
             0.9651742727272727, 0.9725426363636365, 0.8988302727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 241}], {
             RGBColor[
             0.5677014999999999, 0.6487389545454545, 0.9627915909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 290}], {
             RGBColor[
             0.6182613636363635, 0.695804818181818, 0.9658933636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 291}], {
             RGBColor[
             0.9261516363636363, 0.9415407272727272, 0.8990496818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 299}], {
             RGBColor[0.6748756363636363, 0.743908, 0.9697586363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 264}], {
             RGBColor[
             0.9187186363636364, 0.9370021818181817, 0.9566365909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 233}], {
             RGBColor[
             0.6835698181818182, 0.7495741818181818, 0.9673488636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 259}], {
             RGBColor[
             0.9489243636363636, 0.9614284545454546, 0.971341909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 284}], {
             RGBColor[
             0.9663052272727273, 0.9706129090909091, 0.7058213181818184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 245}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 288}], {
             RGBColor[
             0.5919375909090908, 0.6615077727272727, 0.9463032727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 296}], {
             RGBColor[
             0.7227151818181818, 0.7814855454545455, 0.9546144999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 297}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 232}], {
             RGBColor[
             0.7012036363636364, 0.7627254545454545, 0.9374994090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 245}], {
             RGBColor[
             0.9187186363636364, 0.9370021818181817, 0.9566365909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 264}], {
             RGBColor[
             0.9753750909090909, 0.9811553636363637, 0.9265677272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 266}], {
             RGBColor[
             0.8653840909090909, 0.8949967272727273, 0.9514109545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 240}], {
             RGBColor[
             0.6445471818181818, 0.7185722727272726, 0.9675682727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 245}], {
             RGBColor[
             0.6445471818181818, 0.7185722727272726, 0.9675682727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 288}], {
             RGBColor[
             0.32658304545454536`, 0.4496534999999999, 0.9423102272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 297}], {
             RGBColor[
             0.6445471818181818, 0.7185722727272726, 0.9675682727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 259}], {
             RGBColor[
             0.6923867272727273, 0.7561498181818181, 0.9524241363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[0.5831206818181817, 0.6549321363636362, 0.961228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 249}], {
             RGBColor[
             0.5230589545454544, 0.607154227272727, 0.9594406818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 263}], {
             RGBColor[
             0.45846804545454534`, 0.556695318181818, 0.9530028636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 274}], {
             RGBColor[
             0.6329219090909091, 0.6955009545454545, 0.6821268636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 298}], {
             RGBColor[
             0.8088382272727273, 0.8464780000000001, 0.6945055454545457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 260}], {
             RGBColor[
             0.5564312727272729, 0.6507750000000001, 0.9582234545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 267}], {
             RGBColor[
             0.731532090909091, 0.788061181818182, 0.9396897727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 294}], {
             RGBColor[
             0.7334524090909091, 0.7682594545454546, 0.6632846363636362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 256}], {
             RGBColor[
             0.5683341363636364, 0.6366990454545455, 0.9449590909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 269}], {
             RGBColor[
             0.9489243636363636, 0.9614284545454546, 0.971341909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 277}], {
             RGBColor[
             0.9665581818181819, 0.9745797272727272, 0.9414924545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 281}], {
             RGBColor[0.6155410454545454, 0.6863165, 0.9476474545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 293}], {
             RGBColor[
             0.8888626363636363, 0.9136505454545454, 0.9695545909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 248}], {
             RGBColor[0.9668105, 0.9716936363636364, 0.7608171363636361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 258}], {
             RGBColor[
             0.9489243636363636, 0.9614284545454546, 0.971341909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 263}], {
             RGBColor[0.8154548181818182, 0.856616, 0.9780415]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{239, 285}], {
             RGBColor[
             0.8477502727272728, 0.8818454545454546, 0.9812604090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 290}], {
             RGBColor[0.32390068181818166`, 0.4516947727272726, 0.9419795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 291}], {
             RGBColor[
             0.6317909545454545, 0.6974306818181818, 0.8751358181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 250}], {
             RGBColor[
             0.6834611363636365, 0.5697374545454548, 0.5868766818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 268}], {
             RGBColor[
             0.7850176818181818, 0.6514435454545455, 0.5953789545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 254}], {
             RGBColor[
             0.9671906363636363, 0.9733764545454546, 0.8654139090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 256}], {
             RGBColor[
             0.586600409090909, 0.6486470454545454, 0.839031090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 283}], {
             RGBColor[
             0.9938936818181818, 0.9902172727272727, 0.6399644090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 279}], {
             RGBColor[
             0.8565671818181818, 0.8884210909090908, 0.9663356818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 280}], {
             RGBColor[
             0.9665581818181819, 0.9745797272727272, 0.9414924545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 264}], {
             RGBColor[
             0.9187186363636364, 0.9370021818181817, 0.9566365909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 288}], {
             RGBColor[
             0.5440980454545453, 0.6239302272727272, 0.9614474090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 297}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 270}], {
             RGBColor[
             0.9807917272727272, 0.984860090909091, 0.9023971818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 278}], {
             RGBColor[
             0.9903662272727272, 0.9896303636363637, 0.7617929545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 295}], {
             RGBColor[
             0.7066202727272727, 0.7664301818181818, 0.9133288636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 251}], {
             RGBColor[
             0.9772954090909091, 0.9613536363636364, 0.6501625909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 270}], {
             RGBColor[
             0.9772954090909091, 0.9613536363636364, 0.6501625909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 271}], {
             RGBColor[
             0.9416780454545453, 0.9339764545454544, 0.6822381818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 278}], {
             RGBColor[
             0.986869909090909, 0.9661239090909091, 0.5095583636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 289}], {
             RGBColor[
             0.9858593636363636, 0.9639624545454546, 0.39956672727272735`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 295}], {
             RGBColor[
             0.7031239545454545, 0.7429237272727272, 0.6610942727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 285}], {
             RGBColor[
             0.8744533181818182, 0.8986862727272726, 0.7558109090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 258}], {
             RGBColor[
             0.8888626363636363, 0.9136505454545454, 0.9695545909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 263}], {
             RGBColor[
             0.7553930909090909, 0.8088380909090909, 0.9762541818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 286}], {
             RGBColor[
             0.8261216818181818, 0.5541310909090912, 0.5806084545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 270}], {
             RGBColor[
             0.9753750909090909, 0.9811553636363637, 0.9265677272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 271}], {
             RGBColor[
             0.9397577272727271, 0.9537781818181817, 0.9586433181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 278}], {
             RGBColor[
             0.9849495909090908, 0.9859256363636364, 0.7859635000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 282}], {
             RGBColor[
             0.8330886363636363, 0.8697672727272727, 0.9481920454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 289}], {
             RGBColor[
             0.9839390454545455, 0.9837641818181819, 0.6759718636363639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 295}], {
             RGBColor[
             0.7012036363636364, 0.7627254545454545, 0.9374994090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 268}], {
             RGBColor[
             0.8416525909090908, 0.872376090909091, 0.697596181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 279}], {
             RGBColor[
             0.8739480454545454, 0.8976055454545455, 0.7008150909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 280}], {
             RGBColor[
             0.9839390454545455, 0.9837641818181819, 0.6759718636363639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 283}], {
             RGBColor[
             0.9930082727272728, 0.9874537272727273, 0.4803718181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 283}], {
             RGBColor[0.9668105, 0.9716936363636364, 0.7608171363636361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 258}], {
             RGBColor[
             0.8950003181818182, 0.6084846363636367, 0.5674710454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 286}], {
             RGBColor[
             0.8322593636363638, 0.2489651818181825, 0.17852490909090918`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 269}], {
             RGBColor[
             0.5595172272727273, 0.6301234090909091, 0.9598838181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 277}], {
             RGBColor[
             0.5771510454545454, 0.6432746818181818, 0.9300343636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 281}], {
             RGBColor[
             0.22613390909090905`, 0.35501145454545446`, 0.9361893636363636]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 293}], {
             RGBColor[0.4994555, 0.5823455, 0.9580965]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{257, 267}], {
             RGBColor[
             0.9706517727272728, 0.9389430909090909, 0.6243533181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 272}], {
             RGBColor[
             0.8916237272727272, 0.515428909090909, 0.2431784545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 300}], {
             RGBColor[
             0.935034409090909, 0.911565909090909, 0.656428909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 263}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 286}], {
             RGBColor[
             0.8950003181818182, 0.6084846363636367, 0.5674710454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 267}], {
             RGBColor[
             0.8002742727272727, 0.8438691818181818, 0.9451014090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 287}], {
             RGBColor[0.8093435, 0.8475587272727273, 0.7495013636363634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 294}], {
             RGBColor[
             0.8021945909090908, 0.8240674545454545, 0.6686962727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 300}], {
             RGBColor[0.764656909090909, 0.816492, 0.977177]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{261, 284}], {
             RGBColor[
             0.9839390454545455, 0.9837641818181819, 0.6759718636363639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 292}], {
             RGBColor[0.8154548181818182, 0.856616, 0.9780415]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{263, 286}], {
             RGBColor[
             0.7615307727272728, 0.5036721818181822, 0.5741706363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 288}], {
             RGBColor[
             0.6007544999999999, 0.668083409090909, 0.9313785454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 276}], {
             RGBColor[
             0.6902832727272727, 0.7577105454545454, 0.9699446363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 286}], {
             RGBColor[
             0.7938262272727273, 0.5289016363636367, 0.5773895454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 272}], {
             RGBColor[
             0.8963470454545455, 0.5576411818181819, 0.5453928636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 287}], {
             RGBColor[
             0.9844443181818182, 0.984844909090909, 0.7309676818181816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 300}], {
             RGBColor[
             0.9397577272727271, 0.9537781818181817, 0.9586433181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 279}], {
             RGBColor[
             0.7230976363636363, 0.7836086363636363, 0.9730352727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 280}], {
             RGBColor[
             0.8330886363636363, 0.8697672727272727, 0.9481920454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 277}], {
             RGBColor[
             0.9577412727272727, 0.968004090909091, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 282}], {
             RGBColor[0.8154548181818182, 0.856616, 0.9780415]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{269, 293}], {
             RGBColor[
             0.8800457272727272, 0.907074909090909, 0.9844793181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 271}], {
             RGBColor[
             0.9397577272727271, 0.9537781818181817, 0.9586433181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 278}], {
             RGBColor[
             0.9849495909090908, 0.9859256363636364, 0.7859635000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 289}], {
             RGBColor[
             0.9839390454545455, 0.9837641818181819, 0.6759718636363639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 295}], {
             RGBColor[
             0.7012036363636364, 0.7627254545454545, 0.9374994090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 278}], {
             RGBColor[
             0.9493322272727271, 0.9585484545454545, 0.8180390909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 289}], {
             RGBColor[
             0.9483216818181817, 0.9563869999999999, 0.7080474545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 295}], {
             RGBColor[
             0.6655862727272726, 0.7353482727272727, 0.9695750000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 274}], {
             RGBColor[
             0.6067241363636363, 0.6797408636363635, 0.9625721818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 289}], {
             RGBColor[
             0.9663052272727273, 0.9706129090909091, 0.7058213181818184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 289}], {
             RGBColor[
             0.6329219090909091, 0.6955009545454545, 0.6821268636363639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 281}], {
             RGBColor[
             0.6243579545454545, 0.6928921363636363, 0.9327227272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 282}], {
             RGBColor[
             0.8330886363636363, 0.8697672727272727, 0.9481920454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 293}], {
             RGBColor[
             0.8976795454545454, 0.9202261818181818, 0.9546298636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 295}], {
             RGBColor[
             0.7107781363636363, 0.7674957272727272, 0.796895181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 280}], {
             RGBColor[
             0.8653840909090909, 0.8949967272727273, 0.9514109545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 294}], {
             RGBColor[
             0.6262782727272727, 0.673090409090909, 0.6563175909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 293}], {
             RGBColor[
             0.7553930909090909, 0.8088380909090909, 0.9762541818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 300}], {
             RGBColor[
             0.9488269545454544, 0.9574677272727272, 0.7630432727272725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 296}], {
             RGBColor[
             0.35691149999999994`, 0.47498922727272724`, 0.9445005909090909]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 297}], {
             RGBColor[
             0.5440980454545453, 0.6239302272727272, 0.9614474090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 291}], {
             RGBColor[
             0.6823508181818181, 0.7444965454545454, 0.8782375909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 297}], {
             RGBColor[0.6748756363636363, 0.743908, 0.9697586363636364]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.032105813875877395`], {
             RGBColor[
             0.9935135454545455, 0.9885344545454545, 0.5353676363636359]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.032105813875877395`], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.032105813875877395`], {
             RGBColor[
             0.9935135454545455, 0.9885344545454545, 0.5353676363636359]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.032105813875877395`], {
             RGBColor[
             0.9401074545454545, 0.9548528181818182, 0.9862666363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.032105813875877395`], {
             RGBColor[
             0.9401074545454545, 0.9548528181818182, 0.9862666363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.032105813875877395`], {
             RGBColor[
             0.4270321818181818, 0.5442955454545454, 0.948431090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.032105813875877395`], {
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.032105813875877395`], {
             RGBColor[
             0.9401074545454545, 0.9548528181818182, 0.9862666363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.032105813875877395`], {
             RGBColor[
             0.32188890909090917`, 0.45322572727272736`, 0.9417314545454546]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.032105813875877395`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.032105813875877395`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.032105813875877395`], {
             RGBColor[
             0.9041403636363634, 0.9264009999999998, 0.9907189090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.032105813875877395`], {
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.032105813875877395`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.032105813875877395`], {
             RGBColor[
             0.8625706363636363, 0.4688471818181815, 0.20703790909090902`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.032105813875877395`], {
             RGBColor[
             0.8958957272727274, 0.6201686363636366, 0.23484518181818187`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.032105813875877395`], {
             RGBColor[
             0.9945240909090909, 0.9906959090909091, 0.6453592727272731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.032105813875877395`], {
             RGBColor[
             0.4270321818181818, 0.5442955454545454, 0.948431090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.032105813875877395`], {
             RGBColor[
             0.9945240909090909, 0.9906959090909091, 0.6453592727272731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.032105813875877395`], {
             RGBColor[
             0.9401074545454545, 0.9548528181818182, 0.9862666363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.032105813875877395`], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.032105813875877395`], {
             RGBColor[
             0.5564312727272726, 0.6507749999999999, 0.9582234545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.032105813875877395`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.032105813875877395`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.032105813875877395`], {
             RGBColor[
             0.6251734545454546, 0.7065830000000001, 0.9636350909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.032105813875877395`], {
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.032105813875877395`], {
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.032105813875877395`], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.032105813875877395`], {
             RGBColor[
             0.32188890909090917`, 0.45322572727272736`, 0.9417314545454546]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.032105813875877395`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.032105813875877395`], {
             RGBColor[
             0.9945240909090909, 0.9906959090909091, 0.6453592727272731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.032105813875877395`], {
             RGBColor[
             0.9659284545454545, 0.8967308181818181, 0.32213890909090903`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.032105813875877395`], {
             RGBColor[
             0.9792157272727272, 0.941551909090909, 0.3737574545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.032105813875877395`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.032105813875877395`], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.032105813875877395`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.032105813875877395`], {
             RGBColor[
             0.9324466363636366, 0.7698804545454552, 0.26450318181818194`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.032105813875877395`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.032105813875877395`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.032105813875877395`], {
             RGBColor[
             0.9753750909090909, 0.9811553636363637, 0.9265677272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.032105813875877395`], {
             RGBColor[
             0.9753750909090909, 0.9811553636363637, 0.9265677272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.032105813875877395`], {
             RGBColor[
             0.9041403636363634, 0.9264009999999998, 0.9907189090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.032105813875877395`], {
             RGBColor[
             0.9942738181818181, 0.9919000909090909, 0.744561181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.032105813875877395`], {
             RGBColor[
             0.7553930909090909, 0.8088380909090909, 0.9762541818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.032105813875877395`], {
             RGBColor[
             0.7553930909090909, 0.8088380909090909, 0.9762541818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.032105813875877395`], {
             RGBColor[
             0.9753750909090909, 0.9811553636363637, 0.9265677272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.032105813875877395`], {
             RGBColor[
             0.8958957272727274, 0.6201686363636366, 0.23484518181818187`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.032105813875877395`], {
             RGBColor[
             0.7553930909090909, 0.8088380909090909, 0.9762541818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.032105813875877395`], {
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.032105813875877395`], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.032105813875877395`], {
             RGBColor[
             0.9753750909090909, 0.9811553636363637, 0.9265677272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.032105813875877395`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.032105813875877395`], {
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.032105813875877395`], {
             RGBColor[
             0.8792331818181819, 0.5445079090909094, 0.2209415454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.032105813875877395`], {
             RGBColor[
             0.9753750909090909, 0.9811553636363637, 0.9265677272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.032105813875877395`], {
             RGBColor[
             0.9862083636363635, 0.9885648181818182, 0.8782266363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.032105813875877395`], {
             RGBColor[
             0.9324466363636366, 0.7698804545454552, 0.26450318181818194`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.032105813875877395`], {
             RGBColor[
             0.9792157272727272, 0.941551909090909, 0.3737574545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.032105813875877395`], {
             RGBColor[
             0.48768909090909107`, 0.5949670000000001, 0.9528118181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.032105813875877395`], {
             RGBColor[
             0.48768909090909107`, 0.5949670000000001, 0.9528118181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.032105813875877395`], {
             RGBColor[
             0.9862083636363635, 0.9885648181818182, 0.8782266363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.032105813875877395`], {
             RGBColor[
             0.9401074545454545, 0.9548528181818182, 0.9862666363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.032105813875877395`], {
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.032105813875877395`], {
             RGBColor[
             0.37446054545454527`, 0.4987606363636362, 0.9450812727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.032105813875877395`], {
             RGBColor[
             0.9945240909090909, 0.9906959090909091, 0.6453592727272731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.032105813875877395`], {
             RGBColor[
             0.4270321818181818, 0.5442955454545454, 0.948431090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.032105813875877395`], {
             RGBColor[
             0.9792157272727272, 0.941551909090909, 0.3737574545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.032105813875877395`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.032105813875877395`], {
             RGBColor[
             0.5564312727272726, 0.6507749999999999, 0.9582234545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.032105813875877395`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.032105813875877395`], {
             RGBColor[
             0.9753750909090909, 0.9811553636363637, 0.9265677272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.032105813875877395`], {
             RGBColor[
             0.8958957272727274, 0.6201686363636366, 0.23484518181818187`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.032105813875877395`], {
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.032105813875877395`], {
             RGBColor[
             0.9401074545454545, 0.9548528181818182, 0.9862666363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.032105813875877395`], {
             RGBColor[
             0.9041403636363634, 0.9264009999999998, 0.9907189090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.032105813875877395`], {
             RGBColor[
             0.9041403636363634, 0.9264009999999998, 0.9907189090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.032105813875877395`], {
             RGBColor[
             0.8625706363636363, 0.4688471818181815, 0.20703790909090902`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.032105813875877395`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.032105813875877395`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.032105813875877395`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.032105813875877395`], {
             RGBColor[
             0.9945240909090909, 0.9906959090909091, 0.6453592727272731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.032105813875877395`], {
             RGBColor[
             0.4270321818181818, 0.5442955454545454, 0.948431090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.032105813875877395`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.032105813875877395`], {
             RGBColor[
             0.9753750909090909, 0.9811553636363637, 0.9265677272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.032105813875877395`], {
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.032105813875877395`], {
             RGBColor[
             0.4270321818181818, 0.5442955454545454, 0.948431090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.032105813875877395`], {
             RGBColor[
             0.4270321818181818, 0.5442955454545454, 0.948431090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.032105813875877395`], {
             RGBColor[
             0.9041403636363634, 0.9264009999999998, 0.9907189090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.032105813875877395`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.032105813875877395`], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.032105813875877395`], {
             RGBColor[
             0.9945240909090909, 0.9906959090909091, 0.6453592727272731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.032105813875877395`], {
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.032105813875877395`], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.032105813875877395`], {
             RGBColor[
             0.9935135454545455, 0.9885344545454545, 0.5353676363636359]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.032105813875877395`], {
             RGBColor[
             0.9862083636363635, 0.9885648181818182, 0.8782266363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.032105813875877395`], {
             RGBColor[
             0.9753750909090909, 0.9811553636363637, 0.9265677272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.032105813875877395`], {
             RGBColor[
             0.9041403636363634, 0.9264009999999998, 0.9907189090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.032105813875877395`], {
             RGBColor[
             0.9659284545454545, 0.8967308181818181, 0.32213890909090903`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.032105813875877395`], {
             RGBColor[
             0.9792157272727272, 0.941551909090909, 0.3737574545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.032105813875877395`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.032105813875877395`], {
             RGBColor[
             0.9935135454545455, 0.9885344545454545, 0.5353676363636359]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.032105813875877395`], {
             RGBColor[
             0.7553930909090909, 0.8088380909090909, 0.9762541818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.032105813875877395`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.032105813875877395`], {
             RGBColor[
             0.9862083636363635, 0.9885648181818182, 0.8782266363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.032105813875877395`], {
             RGBColor[
             0.4270321818181818, 0.5442955454545454, 0.948431090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.032105813875877395`], {
             RGBColor[
             0.9324466363636366, 0.7698804545454552, 0.26450318181818194`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.032105813875877395`], {
             RGBColor[
             0.9945240909090909, 0.9906959090909091, 0.6453592727272731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.032105813875877395`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.032105813875877395`], {
             RGBColor[
             0.4270321818181818, 0.5442955454545454, 0.948431090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.032105813875877395`], {
             RGBColor[
             0.9792157272727272, 0.941551909090909, 0.3737574545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.032105813875877395`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.032105813875877395`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.032105813875877395`], {
             RGBColor[
             0.9136335454545456, 0.6952928181818183, 0.24936572727272732`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.032105813875877395`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.032105813875877395`], {
             RGBColor[
             0.9942738181818181, 0.9919000909090909, 0.744561181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.032105813875877395`], {
             RGBColor[
             0.9792157272727272, 0.941551909090909, 0.3737574545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.032105813875877395`], {
             RGBColor[
             0.7553930909090909, 0.8088380909090909, 0.9762541818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.032105813875877395`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.032105813875877395`], {
             RGBColor[
             0.9792157272727272, 0.941551909090909, 0.3737574545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.032105813875877395`], {
             RGBColor[
             0.7553930909090909, 0.8088380909090909, 0.9762541818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.032105813875877395`], {
             RGBColor[
             0.9041403636363634, 0.9264009999999998, 0.9907189090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.032105813875877395`], {
             RGBColor[
             0.9401074545454545, 0.9548528181818182, 0.9862666363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.032105813875877395`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.032105813875877395`], {
             RGBColor[
             0.8322593636363638, 0.2489651818181825, 0.17852490909090918`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.032105813875877395`], {
             RGBColor[
             0.9659284545454545, 0.8967308181818181, 0.32213890909090903`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.032105813875877395`], {
             RGBColor[
             0.9041403636363634, 0.9264009999999998, 0.9907189090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.032105813875877395`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.032105813875877395`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.032105813875877395`], {
             RGBColor[
             0.9753750909090909, 0.9811553636363637, 0.9265677272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.032105813875877395`], {
             RGBColor[
             0.9753750909090909, 0.9811553636363637, 0.9265677272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.032105813875877395`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.032105813875877395`], {
             RGBColor[
             0.9041403636363634, 0.9264009999999998, 0.9907189090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.032105813875877395`], {
             RGBColor[
             0.32188890909090917`, 0.45322572727272736`, 0.9417314545454546]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.032105813875877395`], {
             RGBColor[
             0.9862083636363635, 0.9885648181818182, 0.8782266363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.032105813875877395`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.032105813875877395`], {
             RGBColor[
             0.9401074545454545, 0.9548528181818182, 0.9862666363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.032105813875877395`], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.032105813875877395`], {
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.032105813875877395`], {
             RGBColor[
             0.9401074545454545, 0.9548528181818182, 0.9862666363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.032105813875877395`], {
             RGBColor[
             0.5564312727272726, 0.6507749999999999, 0.9582234545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.032105813875877395`], {
             RGBColor[
             0.9792157272727272, 0.941551909090909, 0.3737574545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.032105813875877395`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.032105813875877395`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.032105813875877395`], {
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.032105813875877395`], {
             RGBColor[
             0.9942738181818181, 0.9919000909090909, 0.744561181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.032105813875877395`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.032105813875877395`], {
             RGBColor[
             0.6251734545454546, 0.7065830000000001, 0.9636350909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.032105813875877395`], {
             RGBColor[
             0.4270321818181818, 0.5442955454545454, 0.948431090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.032105813875877395`], {
             RGBColor[
             0.9935135454545455, 0.9885344545454545, 0.5353676363636359]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.032105813875877395`], {
             RGBColor[
             0.9401074545454545, 0.9548528181818182, 0.9862666363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.032105813875877395`], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.032105813875877395`], {
             RGBColor[
             0.9041403636363634, 0.9264009999999998, 0.9907189090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.032105813875877395`], {
             RGBColor[
             0.7553930909090909, 0.8088380909090909, 0.9762541818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.032105813875877395`], {
             RGBColor[
             0.9942738181818181, 0.9919000909090909, 0.744561181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.032105813875877395`], {
             RGBColor[
             0.8471997272727273, 0.3638033636363642, 0.19283181818181824`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.032105813875877395`], {
             RGBColor[
             0.37446054545454527`, 0.4987606363636362, 0.9450812727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.032105813875877395`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.032105813875877395`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.032105813875877395`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.032105813875877395`], {
             RGBColor[
             0.8958957272727274, 0.6201686363636366, 0.23484518181818187`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.032105813875877395`], {
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.032105813875877395`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.032105813875877395`], {
             RGBColor[
             0.5564312727272726, 0.6507749999999999, 0.9582234545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.032105813875877395`], {
             RGBColor[
             0.7553930909090909, 0.8088380909090909, 0.9762541818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.032105813875877395`], {
             RGBColor[
             0.9041403636363634, 0.9264009999999998, 0.9907189090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.032105813875877395`], {
             RGBColor[
             0.8625706363636363, 0.4688471818181815, 0.20703790909090902`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.032105813875877395`], {
             RGBColor[
             0.6251734545454546, 0.7065830000000001, 0.9636350909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.032105813875877395`], {
             RGBColor[
             0.9041403636363634, 0.9264009999999998, 0.9907189090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.032105813875877395`], {
             RGBColor[
             0.8625706363636363, 0.4688471818181815, 0.20703790909090902`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.032105813875877395`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.032105813875877395`], {
             RGBColor[
             0.9945240909090909, 0.9906959090909091, 0.6453592727272731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.032105813875877395`], {
             RGBColor[
             0.9401074545454545, 0.9548528181818182, 0.9862666363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.032105813875877395`], {
             RGBColor[
             0.9659284545454545, 0.8967308181818181, 0.32213890909090903`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.032105813875877395`], {
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.032105813875877395`], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.032105813875877395`], {
             RGBColor[
             0.9401074545454545, 0.9548528181818182, 0.9862666363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.032105813875877395`], {
             RGBColor[
             0.9945240909090909, 0.9906959090909091, 0.6453592727272731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.032105813875877395`], {
             RGBColor[
             0.5564312727272726, 0.6507749999999999, 0.9582234545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.032105813875877395`], {
             RGBColor[
             0.32188890909090917`, 0.45322572727272736`, 0.9417314545454546]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.032105813875877395`], {
             RGBColor[
             0.32188890909090917`, 0.45322572727272736`, 0.9417314545454546]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.032105813875877395`], {
             RGBColor[
             0.9659284545454545, 0.8967308181818181, 0.32213890909090903`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.032105813875877395`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.032105813875877395`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.032105813875877395`], {
             RGBColor[
             0.48768909090909107`, 0.5949670000000001, 0.9528118181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.032105813875877395`], {
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.032105813875877395`], {
             RGBColor[
             0.9753750909090909, 0.9811553636363637, 0.9265677272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.032105813875877395`], {
             RGBColor[
             0.9935135454545455, 0.9885344545454545, 0.5353676363636359]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.032105813875877395`], {
             RGBColor[
             0.4270321818181818, 0.5442955454545454, 0.948431090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.032105813875877395`], {
             RGBColor[
             0.9942738181818181, 0.9919000909090909, 0.744561181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.032105813875877395`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.032105813875877395`], {
             RGBColor[
             0.9942738181818181, 0.9919000909090909, 0.744561181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.032105813875877395`], {
             RGBColor[
             0.48768909090909107`, 0.5949670000000001, 0.9528118181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.032105813875877395`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.032105813875877395`], {
             RGBColor[
             0.9753750909090909, 0.9811553636363637, 0.9265677272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.032105813875877395`], {
             RGBColor[
             0.9862083636363635, 0.9885648181818182, 0.8782266363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.032105813875877395`], {
             RGBColor[
             0.9136335454545456, 0.6952928181818183, 0.24936572727272732`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.032105813875877395`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.032105813875877395`], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.032105813875877395`], {
             RGBColor[
             0.9935135454545455, 0.9885344545454545, 0.5353676363636359]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.032105813875877395`], {
             RGBColor[
             0.9792157272727272, 0.941551909090909, 0.3737574545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.032105813875877395`], {
             RGBColor[
             0.5564312727272726, 0.6507749999999999, 0.9582234545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.032105813875877395`], {
             RGBColor[
             0.7553930909090909, 0.8088380909090909, 0.9762541818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.032105813875877395`], {
             RGBColor[
             0.9324466363636366, 0.7698804545454552, 0.26450318181818194`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.032105813875877395`], {
             RGBColor[
             0.9401074545454545, 0.9548528181818182, 0.9862666363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.032105813875877395`], {
             RGBColor[
             0.8792331818181819, 0.5445079090909094, 0.2209415454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.032105813875877395`], {
             RGBColor[
             0.9753750909090909, 0.9811553636363637, 0.9265677272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.032105813875877395`], {
             RGBColor[
             0.4270321818181818, 0.5442955454545454, 0.948431090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.032105813875877395`], {
             RGBColor[
             0.6251734545454546, 0.7065830000000001, 0.9636350909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.032105813875877395`], {
             RGBColor[
             0.9041403636363634, 0.9264009999999998, 0.9907189090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.032105813875877395`], {
             RGBColor[
             0.9401074545454545, 0.9548528181818182, 0.9862666363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.032105813875877395`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.032105813875877395`], {
             RGBColor[
             0.22613390909090889`, 0.35501145454545435`, 0.9361893636363636]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.032105813875877395`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.032105813875877395`], {
             RGBColor[
             0.8792331818181819, 0.5445079090909094, 0.2209415454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.032105813875877395`], {
             RGBColor[
             0.9792157272727272, 0.941551909090909, 0.3737574545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.032105813875877395`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.032105813875877395`], {
             RGBColor[
             0.9753750909090909, 0.9811553636363637, 0.9265677272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.032105813875877395`], {
             RGBColor[
             0.5564312727272726, 0.6507749999999999, 0.9582234545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.032105813875877395`], {
             RGBColor[
             0.7553930909090909, 0.8088380909090909, 0.9762541818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.032105813875877395`], {
             RGBColor[
             0.9942738181818181, 0.9919000909090909, 0.744561181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.032105813875877395`], {
             RGBColor[
             0.8322593636363638, 0.2489651818181825, 0.17852490909090918`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.032105813875877395`], {
             RGBColor[
             0.9942738181818181, 0.9919000909090909, 0.744561181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.032105813875877395`], {
             RGBColor[
             0.9792157272727272, 0.941551909090909, 0.3737574545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.032105813875877395`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.032105813875877395`], {
             RGBColor[
             0.9862083636363635, 0.9885648181818182, 0.8782266363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.032105813875877395`], {
             RGBColor[
             0.9401074545454545, 0.9548528181818182, 0.9862666363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.032105813875877395`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.032105813875877395`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.032105813875877395`], {
             RGBColor[
             0.9401074545454545, 0.9548528181818182, 0.9862666363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.032105813875877395`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.032105813875877395`], {
             RGBColor[
             0.9753750909090909, 0.9811553636363637, 0.9265677272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.032105813875877395`], {
             RGBColor[
             0.4270321818181818, 0.5442955454545454, 0.948431090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.032105813875877395`], {
             RGBColor[
             0.4270321818181818, 0.5442955454545454, 0.948431090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.032105813875877395`], {
             RGBColor[
             0.22613390909090889`, 0.35501145454545435`, 0.9361893636363636]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.032105813875877395`], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.032105813875877395`], {
             RGBColor[
             0.48768909090909107`, 0.5949670000000001, 0.9528118181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.032105813875877395`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.032105813875877395`], {
             RGBColor[
             0.9324466363636366, 0.7698804545454552, 0.26450318181818194`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.032105813875877395`], {
             RGBColor[
             0.9401074545454545, 0.9548528181818182, 0.9862666363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.032105813875877395`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.032105813875877395`], {
             RGBColor[
             0.2733408181818181, 0.404628909090909, 0.9388777272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.032105813875877395`], {
             RGBColor[
             0.8792331818181819, 0.5445079090909094, 0.2209415454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.032105813875877395`], {
             RGBColor[
             0.9942738181818181, 0.9919000909090909, 0.744561181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.032105813875877395`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.032105813875877395`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.032105813875877395`], {
             RGBColor[
             0.9862083636363635, 0.9885648181818182, 0.8782266363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.032105813875877395`], {
             RGBColor[
             0.9792157272727272, 0.941551909090909, 0.3737574545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.032105813875877395`], {
             RGBColor[
             0.9935135454545455, 0.9885344545454545, 0.5353676363636359]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.032105813875877395`], {
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.032105813875877395`], {
             RGBColor[
             0.48768909090909107`, 0.5949670000000001, 0.9528118181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.032105813875877395`], {
             RGBColor[
             0.9753750909090909, 0.9811553636363637, 0.9265677272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.032105813875877395`], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.032105813875877395`], {
             RGBColor[
             0.48768909090909107`, 0.5949670000000001, 0.9528118181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.032105813875877395`], {
             RGBColor[
             0.9401074545454545, 0.9548528181818182, 0.9862666363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.032105813875877395`], {
             RGBColor[
             0.8322593636363638, 0.2489651818181825, 0.17852490909090918`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.032105813875877395`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.032105813875877395`], {
             RGBColor[
             0.9659284545454545, 0.8967308181818181, 0.32213890909090903`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.032105813875877395`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.032105813875877395`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.032105813875877395`], {
             RGBColor[
             0.6251734545454546, 0.7065830000000001, 0.9636350909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.032105813875877395`], {
             RGBColor[
             0.9753750909090909, 0.9811553636363637, 0.9265677272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.032105813875877395`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.032105813875877395`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.032105813875877395`], {
             RGBColor[
             0.9753750909090909, 0.9811553636363637, 0.9265677272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.032105813875877395`], {
             RGBColor[
             0.7553930909090909, 0.8088380909090909, 0.9762541818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.032105813875877395`], {
             RGBColor[
             0.7553930909090909, 0.8088380909090909, 0.9762541818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.032105813875877395`], {
             RGBColor[
             0.9753750909090909, 0.9811553636363637, 0.9265677272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.032105813875877395`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.032105813875877395`], {
             RGBColor[
             0.9401074545454545, 0.9548528181818182, 0.9862666363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.032105813875877395`], {
             RGBColor[
             0.9753750909090909, 0.9811553636363637, 0.9265677272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.032105813875877395`], {
             RGBColor[
             0.9041403636363634, 0.9264009999999998, 0.9907189090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.032105813875877395`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.032105813875877395`], {
             RGBColor[
             0.9401074545454545, 0.9548528181818182, 0.9862666363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.032105813875877395`], {
             RGBColor[
             0.2733408181818181, 0.404628909090909, 0.9388777272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.032105813875877395`], {
             RGBColor[
             0.9935135454545455, 0.9885344545454545, 0.5353676363636359]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.032105813875877395`], {
             RGBColor[
             0.6251734545454546, 0.7065830000000001, 0.9636350909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.032105813875877395`], {
             RGBColor[
             0.9753750909090909, 0.9811553636363637, 0.9265677272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.032105813875877395`], {
             RGBColor[
             0.9945240909090909, 0.9906959090909091, 0.6453592727272731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.032105813875877395`], {
             RGBColor[
             0.7553930909090909, 0.8088380909090909, 0.9762541818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.032105813875877395`], {
             RGBColor[
             0.9753750909090909, 0.9811553636363637, 0.9265677272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.032105813875877395`], {
             RGBColor[
             0.2733408181818181, 0.404628909090909, 0.9388777272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.032105813875877395`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.032105813875877395`], {
             RGBColor[
             0.9935135454545455, 0.9885344545454545, 0.5353676363636359]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.032105813875877395`], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.032105813875877395`], {
             RGBColor[
             0.7553930909090909, 0.8088380909090909, 0.9762541818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.032105813875877395`], {
             RGBColor[
             0.8322593636363638, 0.2489651818181825, 0.17852490909090918`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.032105813875877395`], {
             RGBColor[
             0.9935135454545455, 0.9885344545454545, 0.5353676363636359]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.032105813875877395`], {
             RGBColor[
             0.22613390909090889`, 0.35501145454545435`, 0.9361893636363636]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.032105813875877395`], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.032105813875877395`], {
             RGBColor[
             0.37446054545454527`, 0.4987606363636362, 0.9450812727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.032105813875877395`], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.032105813875877395`], {
             RGBColor[
             0.9401074545454545, 0.9548528181818182, 0.9862666363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.032105813875877395`], {
             RGBColor[0.8199839999999999, 0.8592969999999999, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.032105813875877395`], {
             RGBColor[
             0.9792157272727272, 0.941551909090909, 0.3737574545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.032105813875877395`], {
             RGBColor[
             0.4270321818181818, 0.5442955454545454, 0.948431090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.032105813875877395`], {
             RGBColor[
             0.48768909090909107`, 0.5949670000000001, 0.9528118181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.032105813875877395`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.032105813875877395`], {
             RGBColor[
             0.6251734545454546, 0.7065830000000001, 0.9636350909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.032105813875877395`], {
             RGBColor[
             0.48768909090909107`, 0.5949670000000001, 0.9528118181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.032105813875877395`], {
             RGBColor[
             0.9041403636363634, 0.9264009999999998, 0.9907189090909091]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1FO4EAYYBuBzsm2dTrZdW7WsZbtVy3bLtWxr2bat5WVjyzZXrfc8u3i/
//a7+f7gJu2rtAsMCAjIJEJuKEIThrCEIzwRiEgkIhOFqEQjOjGISSxiE4e4
xCM+CUhIIhKThKQkI4jkBJOClKQiNWlISzrSk4GMIX3JTBayko3s5CAnuchN
HvKSj/wUoCCF+IEfKUwRivITxShOCUpSitKUoSzlKE8FfqYilahMFapSjerU
oCa1qE0d6lKP+jSgIY1oTBN+oSnNaM6vtKAlrWhNG9rSjvZ0oCOd6EwXutKN
7vSgJ73ozW/0oS/96M8ABjKIwQzhd4YyjOGMYCSjGM0YxjKO8UxgIpOYzBSm
Mo3pzGAms5jNH8xhLvOYzwIWsojFLGEpy1jOClayitWsYS3rWM8GNrKJzWxh
K9vYzg52sovd7GEv+9jPAQ5yiMMc4U+OcozjnOAkpzjNX5zhLOc4zwUuconL
XOEq17jODW5yi9v8zT/c4S73uM8DHvKIxzzhKc94zgte8orXvOEt73jPBz7y
ic/8yxe+8o3/CBl/IKEITRjCEo7wRCAikYhMFKISjejEICaxiE0c4hKP+CQg
IYlITBKSkowgkhNMClKSitSkIS3pSE8GMgb+/6++Az6VhWw=
          "], {Null, CompressedData["
1:eJxN2guYllWBB/D3qyhJJoMEhjQEkUhkrd1Es1FL08DywkWybEVNDSyNClNB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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[72, 227] -> 
             RGBColor[
              0.8910599718883171, 0.5386508737923311, 0.22830235227691478`], 
             UndirectedEdge[132, 236] -> 
             RGBColor[
              0.21416362323535532`, 0.3424299251513089, 0.9355076735653408], 
             UndirectedEdge[187, 193] -> 
             RGBColor[
              0.25215196023065367`, 0.38235807593304705`, 0.9376710531585147],
              UndirectedEdge[196, 225] -> 
             RGBColor[
              0.21532817540767707`, 0.3436539433212913, 0.935573993088754], 
             UndirectedEdge[39, 166] -> 
             RGBColor[
              0.19390930592620187`, 0.3211413534614994, 0.9343542201581618], 
             UndirectedEdge[7, 216] -> 
             RGBColor[
              0.9023917020151102, 0.7200221295355724, 0.5997896268007754], 
             UndirectedEdge[92, 281] -> 
             RGBColor[
              0.9050081321346448, 0.6135030027694477, 0.5495966137001128], 
             UndirectedEdge[99, 229] -> 
             RGBColor[
              0.20669327315473038`, 0.33457811356902034`, 0.9350822481796419],
              UndirectedEdge[187, 296] -> 
             RGBColor[
              0.20597365560918635`, 0.3338217499022659, 0.9350412670250019], 
             UndirectedEdge[100, 244] -> 
             RGBColor[
              0.18508330510196136`, 0.31186466699444937`, 0.9338515924681194],
              UndirectedEdge[232, 245] -> 
             RGBColor[
              0.206575126823306, 0.3344539342837832, 0.9350755199208491], 
             UndirectedEdge[6, 52] -> 
             RGBColor[
              0.20466403550360635`, 0.3324452561365908, 0.9349666860973984], 
             UndirectedEdge[113, 160] -> 
             RGBColor[
              0.23169850636271255`, 0.3608601990939647, 0.936506259218909], 
             UndirectedEdge[176, 288] -> 
             RGBColor[
              0.20152898742648828`, 0.32915012183401104`, 0.9347881497472945],
              UndirectedEdge[187, 228] -> 
             RGBColor[
              0.32549861800497937`, 0.4485853630705261, 0.9422458467242234], 
             UndirectedEdge[61, 268] -> 
             RGBColor[
              0.24115438507843467`, 0.37079892716152685`, 0.9370447575230503],
              UndirectedEdge[51, 101] -> 
             RGBColor[
              0.7293123816710212, 0.7884636426315792, 0.9736547004594159], 
             UndirectedEdge[207, 214] -> 
             RGBColor[
              0.19305906954872248`, 0.3202477011206687, 0.9343058004542764], 
             UndirectedEdge[17, 162] -> 
             RGBColor[
              0.8475057087773203, 0.8795582824939998, 0.8820715972741542], 
             UndirectedEdge[20, 279] -> 
             RGBColor[
              0.22783544818024304`, 0.35679988001215385`, 0.9362862637702997],
              UndirectedEdge[51, 197] -> 
             RGBColor[
              0.8988192263028636, 0.9205652040419037, 0.9289214218265444], 
             UndirectedEdge[86, 94] -> 
             RGBColor[
              0.6955329406462065, 0.7613368008112785, 0.9707925147289977], 
             UndirectedEdge[55, 114] -> 
             RGBColor[
              0.22063449464495144`, 0.3492312212797382, 0.9358761801193209], 
             UndirectedEdge[13, 270] -> 
             RGBColor[
              0.27306394266259, 0.4020687514269927, 0.9389450440967648], 
             UndirectedEdge[151, 220] -> 
             RGBColor[
              0.46545874896093703`, 0.5736549196510825, 0.9519637517959829], 
             UndirectedEdge[117, 225] -> 
             RGBColor[
              0.20655322702626136`, 0.33443091620856197`, 0.9350742727598051],
              UndirectedEdge[13, 277] -> 
             RGBColor[
              0.6631499633187324, 0.7252798242769541, 0.7115734484509257], 
             UndirectedEdge[81, 237] -> 
             RGBColor[
              0.857269778961983, 0.39235407740723033`, 0.20056198469547004`], 
             UndirectedEdge[172, 174] -> 
             RGBColor[
              0.21189442021644855`, 0.34004484890265657`, 0.9353784458103991],
              UndirectedEdge[128, 197] -> 
             RGBColor[
              0.9156409832962333, 0.6675280137453463, 0.53334242652665], 
             UndirectedEdge[44, 71] -> 
             RGBColor[
              0.26976807981775686`, 0.40018277558695564`, 0.9386995645005083],
              UndirectedEdge[70, 122] -> 
             RGBColor[
              0.19740509453050553`, 0.32481564893042175`, 0.9345533001476212],
              UndirectedEdge[42, 293] -> 
             RGBColor[
              0.8686817504503115, 0.4638809195993508, 0.210856119307727], 
             UndirectedEdge[154, 181] -> 
             RGBColor[
              0.7417957890267707, 0.7840980478369171, 0.6774116520475943], 
             UndirectedEdge[42, 216] -> 
             RGBColor[
              0.8520342261383788, 0.3882883998269512, 0.19696501695368862`], 
             UndirectedEdge[125, 130] -> 
             RGBColor[
              0.8734988271236623, 0.4797808744280881, 0.21461427312304276`], 
             UndirectedEdge[173, 263] -> 
             RGBColor[
              0.20558810816091344`, 0.33341651508901093`, 0.935019310668189], 
             UndirectedEdge[112, 132] -> 
             RGBColor[
              0.1930638232066118, 0.32025269751650964`, 0.9343060711680607], 
             UndirectedEdge[208, 279] -> 
             RGBColor[
              0.21299163292133522`, 0.34119808902279597`, 0.9354409304507616],
              UndirectedEdge[271, 295] -> 
             RGBColor[
              0.20977901412683497`, 0.3378214229779799, 0.9352579765630585], 
             UndirectedEdge[193, 264] -> 
             RGBColor[
              0.28788684943506876`, 0.4199177102097248, 0.939706102233675], 
             UndirectedEdge[16, 39] -> 
             RGBColor[
              0.22425729902189784`, 0.35303901837897317`, 0.9360824934691292],
              UndirectedEdge[168, 282] -> 
             RGBColor[
              0.42052178364044757`, 0.5386565657751188, 0.9480162540941248], 
             UndirectedEdge[92, 243] -> 
             RGBColor[
              0.9094860988652742, 0.6163067889114571, 0.5180190463996183], 
             UndirectedEdge[71, 280] -> 
             RGBColor[
              0.2426648792276659, 0.37238655228322937`, 0.9371307779302732], 
             UndirectedEdge[69, 118] -> 
             RGBColor[
              0.19814492935345804`, 0.3255932622375819, 0.9345954326463008], 
             UndirectedEdge[175, 253] -> 
             RGBColor[
              0.18722926764301806`, 0.3141202096869836, 0.9339738018601655], 
             UndirectedEdge[137, 179] -> 
             RGBColor[
              0.3921454633437752, 0.5078279411583735, 0.9468889147894293], 
             UndirectedEdge[134, 221] -> 
             RGBColor[
              0.21549733286296777`, 0.343831738532004, 0.9355836263555868], 
             UndirectedEdge[91, 163] -> 
             RGBColor[
              0.5556545906660699, 0.6501444545135875, 0.9581623112885165], 
             UndirectedEdge[160, 232] -> 
             RGBColor[
              0.19183608079529113`, 0.31896226239884673`, 0.9342361530540182],
              UndirectedEdge[135, 263] -> 
             RGBColor[
              0.21148289076359805`, 0.33961230535523634`, 0.9353550098168626],
              UndirectedEdge[160, 297] -> 
             RGBColor[
              0.1938787777952211, 0.3211092664602433, 0.9343524816262648], 
             UndirectedEdge[179, 274] -> 
             RGBColor[
              0.4929016619374462, 0.5991987999844676, 0.9532221708674471], 
             UndirectedEdge[209, 259] -> 
             RGBColor[
              0.18280847530695815`, 0.30947367664736153`, 0.9337220442766032],
              UndirectedEdge[14, 173] -> 
             RGBColor[
              0.1907403974209291, 0.31781062970205387`, 0.9341737555067666], 
             UndirectedEdge[260, 267] -> 
             RGBColor[
              0.22718681650953165`, 0.35611812700061296`, 0.9362493251562173],
              UndirectedEdge[203, 216] -> 
             RGBColor[
              0.9017944048582103, 0.7195766662939407, 0.600800695087359], 
             UndirectedEdge[37, 279] -> 
             RGBColor[
              0.23161750381713786`, 0.36077506028270767`, 0.936501646243771], 
             UndirectedEdge[192, 220] -> 
             RGBColor[
              0.3318533670341157, 0.4618564399149144, 0.9423663809943715], 
             UndirectedEdge[60, 225] -> 
             RGBColor[
              0.25743202099321577`, 0.38790775456968785`, 0.9379717448077927],
              UndirectedEdge[177, 226] -> 
             RGBColor[
              0.6391144281004404, 0.7063980774045702, 0.908678535889838], 
             UndirectedEdge[91, 273] -> 
             RGBColor[
              0.3645444727684772, 0.4827165664417553, 0.9449621664859775], 
             UndirectedEdge[52, 273] -> 
             RGBColor[
              0.2188316043007933, 0.34733626921817795`, 0.9357735081813584], 
             UndirectedEdge[21, 114] -> 
             RGBColor[
              0.21635493982133241`, 0.34473313782066695`, 0.9356324658031498],
              UndirectedEdge[7, 202] -> 
             RGBColor[
              0.9024452109054028, 0.7202651009090716, 0.5998342759304583], 
             UndirectedEdge[94, 293] -> 
             RGBColor[
              0.8483237902546403, 0.739482330174071, 0.6092293420609014], 
             UndirectedEdge[132, 133] -> 
             RGBColor[
              0.19109281456444907`, 0.3181810424644308, 0.9341938251417357], 
             UndirectedEdge[13, 93] -> 
             RGBColor[
              0.2872094013725457, 0.41693652540503934`, 0.939750607043966], 
             UndirectedEdge[141, 178] -> 
             RGBColor[
              0.27642955220691934`, 0.4078753643883386, 0.9390536261060842], 
             UndirectedEdge[245, 264] -> 
             RGBColor[
              0.26072622472382, 0.3913701715551329, 0.938159344836913], 
             UndirectedEdge[5, 83] -> 
             RGBColor[
              0.9087826368179345, 0.636355140842231, 0.2670511550343114], 
             UndirectedEdge[210, 226] -> 
             RGBColor[
              0.7289680937933078, 0.7852771577024377, 0.9144848957128108], 
             UndirectedEdge[91, 298] -> 
             RGBColor[
              0.3751482927558811, 0.4938618535695355, 0.9455660383473143], 
             UndirectedEdge[126, 192] -> 
             RGBColor[
              0.2770528278061131, 0.40650831596386994`, 0.939163161568517], 
             UndirectedEdge[127, 156] -> 
             RGBColor[
              0.3716633849526351, 0.49633787652625627`, 0.9449030401335229], 
             UndirectedEdge[36, 268] -> 
             RGBColor[
              0.19319132437376368`, 0.32038670932722724`, 0.934313332170909], 
             UndirectedEdge[25, 221] -> 
             RGBColor[
              0.1886556188584439, 0.3156193952502866, 0.9340550304517865], 
             UndirectedEdge[69, 249] -> 
             RGBColor[
              0.20751277813074143`, 0.3354394652584245, 0.9351289177756767], 
             UndirectedEdge[22, 161] -> 
             RGBColor[
              0.1950980417525622, 0.32239079018520866`, 0.934421916904896], 
             UndirectedEdge[96, 112] -> 
             RGBColor[
              0.1950909003644823, 0.32238328413354655`, 0.9344215102134096], 
             UndirectedEdge[219, 250] -> 
             RGBColor[
              0.1834940050025886, 0.3101942118225623, 0.933761084178619], 
             UndirectedEdge[41, 219] -> 
             RGBColor[
              0.18646440411145038`, 0.3133162896201571, 0.933930244013557], 
             UndirectedEdge[202, 237] -> 
             RGBColor[
              0.8458226996057612, 0.34037556358393634`, 0.1910102610870475], 
             UndirectedEdge[91, 235] -> 
             RGBColor[
              0.44932632055040805`, 0.5626052939537676, 0.9501280434357534], 
             UndirectedEdge[69, 263] -> 
             RGBColor[
              0.2087290677202517, 0.3367178627342138, 0.9351981836684602], 
             UndirectedEdge[12, 239] -> 
             RGBColor[
              0.3335981101513706, 0.4567875043441526, 0.9427184858018454], 
             UndirectedEdge[122, 266] -> 
             RGBColor[
              0.19159505471631844`, 0.31870892870791034`, 0.9342224269753869],
              UndirectedEdge[206, 254] -> 
             RGBColor[
              0.27060222090313846`, 0.400822588016517, 0.9387557425033809], 
             UndirectedEdge[137, 270] -> 
             RGBColor[
              0.23718665422901314`, 0.36662859047011903`, 0.9368188011209075],
              UndirectedEdge[25, 58] -> 
             RGBColor[
              0.19112827338567, 0.31821831193375316`, 0.9341958444691476], 
             UndirectedEdge[107, 156] -> 
             RGBColor[
              0.4014834091317521, 0.5221664826722128, 0.9468031457054042], 
             UndirectedEdge[136, 194] -> 
             RGBColor[
              0.539310518839214, 0.6345587760249104, 0.957788184762517], 
             UndirectedEdge[45, 281] -> 
             RGBColor[
              0.6391981620742301, 0.7080190375817033, 0.9308676637061029], 
             UndirectedEdge[137, 147] -> 
             RGBColor[
              0.23746595794531072`, 0.3669221563848262, 0.9368347070543579], 
             UndirectedEdge[164, 187] -> 
             RGBColor[
              0.2033506574299822, 0.3310648125082323, 0.9348918911590742], 
             UndirectedEdge[199, 229] -> 
             RGBColor[
              0.20805355497894237`, 0.33600785601311617`, 0.9351597142171741],
              UndirectedEdge[191, 271] -> 
             RGBColor[
              0.22500596477055484`, 0.35382591354896176`, 0.9361251288759636],
              UndirectedEdge[153, 222] -> 
             RGBColor[
              0.2212473690290584, 0.3498753911159149, 0.9359110824088295], 
             UndirectedEdge[158, 186] -> 
             RGBColor[
              0.19303082310645578`, 0.3202180123189185, 0.9343041918611762], 
             UndirectedEdge[16, 192] -> 
             RGBColor[
              0.28870383608450384`, 0.4187542643810497, 0.9398266692538492], 
             UndirectedEdge[75, 143] -> 
             RGBColor[
              0.31991196504772945`, 0.4513422193006194, 0.941611753099148], 
             UndirectedEdge[204, 226] -> 
             RGBColor[
              0.734932739386402, 0.7901195256991334, 0.9149544544631159], 
             UndirectedEdge[137, 191] -> 
             RGBColor[
              0.24445543716588297`, 0.3742685422042259, 0.9372327475559615], 
             UndirectedEdge[197, 198] -> 
             RGBColor[
              0.9754663865596167, 0.9808663065126991, 0.9104194926535587], 
             UndirectedEdge[80, 156] -> 
             RGBColor[
              0.6866499660786538, 0.7281441949934098, 0.6592663633827371], 
             UndirectedEdge[103, 159] -> 
             RGBColor[
              0.35628521918114736`, 0.4813996069512451, 0.9439824173184419], 
             UndirectedEdge[28, 288] -> 
             RGBColor[
              0.19616769103516415`, 0.32351505940090497`, 0.9344828318491358],
              UndirectedEdge[118, 263] -> 
             RGBColor[
              0.19930513416780576`, 0.32681271105869525`, 0.9346615045941087],
              UndirectedEdge[68, 83] -> 
             RGBColor[
              0.8617045963739112, 0.6317374119212176, 0.5901643374072268], 
             UndirectedEdge[64, 90] -> 
             RGBColor[
              0.22549030939770529`, 0.3543349904613199, 0.936152711585956], 
             UndirectedEdge[213, 263] -> 
             RGBColor[
              0.2061321686296245, 0.3339883571370523, 0.9350502941070169], 
             UndirectedEdge[52, 53] -> 
             RGBColor[
              0.2073052253779457, 0.3352213141556316, 0.9351170979534518], 
             UndirectedEdge[245, 297] -> 
             RGBColor[
              0.20861782382323596`, 0.3366009383451798, 0.9351918484930957], 
             UndirectedEdge[189, 267] -> 
             RGBColor[
              0.20602096440657885`, 0.33387147444787646`, 0.9350439611910263],
              UndirectedEdge[145, 203] -> 
             RGBColor[
              0.9010144773435402, 0.923871728137574, 0.9891457475385399], 
             UndirectedEdge[136, 279] -> 
             RGBColor[
              0.3146411108912604, 0.44028382744269734`, 0.9415136410409652], 
             UndirectedEdge[80, 256] -> 
             RGBColor[
              0.898368256371338, 0.5394933847920658, 0.2684881883897252], 
             UndirectedEdge[40, 130] -> 
             RGBColor[
              0.8005184128051482, 0.7225949328330918, 0.608776500228449], 
             UndirectedEdge[83, 101] -> 
             RGBColor[
              0.7469403042896439, 0.5416229945947444, 0.5788476902726976], 
             UndirectedEdge[83, 194] -> 
             RGBColor[
              0.7662790641438353, 0.5567305807728573, 0.5807751971239775], 
             UndirectedEdge[149, 197] -> 
             RGBColor[
              0.9409227595816787, 0.803504489870005, 0.5552674312684278], 
             UndirectedEdge[23, 44] -> 
             RGBColor[
              0.6527829845870825, 0.7190887957178285, 0.883793610021852], 
             UndirectedEdge[97, 284] -> 
             RGBColor[
              0.3449079379891919, 0.4668961630433738, 0.9434276902262162], 
             UndirectedEdge[135, 276] -> 
             RGBColor[
              0.22722517815635135`, 0.3561584475236893, 0.9362515097952526], 
             UndirectedEdge[142, 150] -> 
             RGBColor[
              0.8686725031653917, 0.4508599338020208, 0.21032865402022227`], 
             UndirectedEdge[46, 214] -> 
             RGBColor[
              0.20276955741382008`, 0.3304540395473769, 0.9348587983728143], 
             UndirectedEdge[5, 243] -> 
             RGBColor[
              0.9792150980469998, 0.9514729807028455, 0.600039087887734], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.17910006852395627`, 0.30557590599185624`, 0.9335108559964074],
              UndirectedEdge[198, 243] -> 
             RGBColor[
              0.9760042846861029, 0.9810887412113525, 0.9015051286619535], 
             UndirectedEdge[13, 32] -> 
             RGBColor[
              0.6604824509868196, 0.7261357390166185, 0.898179624729629], 
             UndirectedEdge[86, 140] -> 
             RGBColor[
              0.7057480336302696, 0.4077728682153858, 0.5627064708792573], 
             UndirectedEdge[171, 275] -> 
             RGBColor[
              0.17966143058790973`, 0.3061659331134819, 0.9335428247354888], 
             UndirectedEdge[36, 250] -> 
             RGBColor[
              0.18199349180428678`, 0.3086170773131154, 0.9336756321717861], 
             UndirectedEdge[168, 203] -> 
             RGBColor[
              0.6687682561638781, 0.7369332784725033, 0.9690249189979729], 
             UndirectedEdge[17, 169] -> 
             RGBColor[
              0.654201051554568, 0.729209809683748, 0.9665623183284373], 
             UndirectedEdge[191, 246] -> 
             RGBColor[
              0.2059132617802264, 0.3337582721588391, 0.9350378276857872], 
             UndirectedEdge[17, 178] -> 
             RGBColor[
              0.4813372368134904, 0.5789969861106385, 0.9545799540531321], 
             UndirectedEdge[9, 132] -> 
             RGBColor[
              0.19792820821317225`, 0.32536547457822756`, 0.9345830906979717],
              UndirectedEdge[11, 283] -> 
             RGBColor[
              0.41881779248479195`, 0.534778825033336, 0.9485064845740085], 
             UndirectedEdge[64, 69] -> 
             RGBColor[
              0.22143670136219934`, 0.3500743914024093, 0.9359218646051097], 
             UndirectedEdge[193, 288] -> 
             RGBColor[
              0.24421454187002306`, 0.3740153459746332, 0.9372190289252349], 
             UndirectedEdge[221, 288] -> 
             RGBColor[
              0.19753047223834988`, 0.324947428850772, 0.9345604402226031], 
             UndirectedEdge[65, 264] -> 
             RGBColor[
              0.33683666992223255`, 0.4650136831097602, 0.942726350900722], 
             UndirectedEdge[27, 151] -> 
             RGBColor[
              0.7838347809145911, 0.7971566134890326, 0.6494113635450639], 
             UndirectedEdge[201, 293] -> 
             RGBColor[
              0.872561429430702, 0.49370183232880244`, 0.21457130428081972`], 
             UndirectedEdge[43, 99] -> 
             RGBColor[
              0.21063039427602828`, 0.33871627749540134`, 0.9353064614030511],
              UndirectedEdge[77, 293] -> 
             RGBColor[0.6567707297143, 0.585264649646495, 0.5928277208084357],
              UndirectedEdge[61, 280] -> 
             RGBColor[
              0.2696360759953822, 0.40073499015874336`, 0.9386667476858847], 
             UndirectedEdge[20, 55] -> 
             RGBColor[
              0.21057054856025512`, 0.3386533758536862, 0.9353030532780715], 
             UndirectedEdge[208, 242] -> 
             RGBColor[
              0.18509931747274389`, 0.3118814970113848, 0.9338525043489474], 
             UndirectedEdge[29, 261] -> 
             RGBColor[
              0.21999581851421782`, 0.3485599321719316, 0.9358398084585123], 
             UndirectedEdge[12, 76] -> 
             RGBColor[
              0.3782689418854923, 0.5020592779365523, 0.9453239403802199], 
             UndirectedEdge[168, 276] -> 
             RGBColor[
              0.3208926338924916, 0.4461337879304579, 0.9418960475542608], 
             UndirectedEdge[148, 271] -> 
             RGBColor[
              0.23446623518977533`, 0.3637692575753508, 0.9366638772811222], 
             UndirectedEdge[131, 170] -> 
             RGBColor[
              0.21349214626363155`, 0.34172416027992825`, 0.9354694339451624],
              UndirectedEdge[141, 261] -> 
             RGBColor[
              0.269292107733182, 0.4003734577063236, 0.9386471592022079], 
             UndirectedEdge[129, 184] -> 
             RGBColor[
              0.19028873719925032`, 0.31733590617215746`, 0.9341480341253134],
              UndirectedEdge[111, 185] -> 
             RGBColor[
              0.5718800780485805, 0.6633170361205862, 0.9594396410911864], 
             UndirectedEdge[234, 239] -> 
             RGBColor[
              0.2158656276199601, 0.3442188396728392, 0.9356046001971543], 
             UndirectedEdge[103, 203] -> 
             RGBColor[
              0.679227364936692, 0.7459924328014227, 0.96969136416035], 
             UndirectedEdge[28, 160] -> 
             RGBColor[
              0.18961722538074013`, 0.31663010467459485`, 0.9341097925206621],
              UndirectedEdge[133, 170] -> 
             RGBColor[
              0.1914328920115927, 0.3185384854235343, 0.9342131920492509], 
             UndirectedEdge[87, 299] -> 
             RGBColor[
              0.9059209744031474, 0.5662238856558284, 0.33056015938178984`], 
             UndirectedEdge[5, 290] -> 
             RGBColor[
              0.9587118125308915, 0.8695626925266455, 0.3088146906826389], 
             UndirectedEdge[183, 253] -> 
             RGBColor[
              0.19229512745236005`, 0.31944474954066526`, 0.9342622950820396],
              UndirectedEdge[176, 245] -> 
             RGBColor[
              0.20971756780007914`, 0.3377568389926374, 0.9352544772856515], 
             UndirectedEdge[29, 190] -> 
             RGBColor[
              0.199834842245044, 0.32736946783330456`, 0.9346916706854744], 
             UndirectedEdge[159, 168] -> 
             RGBColor[
              0.3458261104083336, 0.4723404526223259, 0.943315972156065], 
             UndirectedEdge[202, 299] -> 
             RGBColor[
              0.8426323172090826, 0.3158528864485842, 0.18795514730096657`], 
             UndirectedEdge[65, 115] -> 
             RGBColor[
              0.3645960621661024, 0.4902165167425332, 0.9444527165749532], 
             UndirectedEdge[51, 142] -> 
             RGBColor[
              0.8206161663608685, 0.5418070513656623, 0.579062899024987], 
             UndirectedEdge[134, 187] -> 
             RGBColor[
              0.23476961577043198`, 0.36408812980106076`, 0.9366811543563793],
              UndirectedEdge[85, 239] -> 
             RGBColor[
              0.2348622905163943, 0.36418553683498534`, 0.936686432046062], 
             UndirectedEdge[120, 284] -> 
             RGBColor[
              0.26002401193692654`, 0.39063210139324567`, 0.9381193548575302],
              UndirectedEdge[31, 61] -> 
             RGBColor[
              0.3484538930002764, 0.47332381494877457`, 0.9435307438846312], 
             UndirectedEdge[217, 247] -> 
             RGBColor[
              0.19889732977739935`, 0.3263840827880864, 0.9346382807373675], 
             UndirectedEdge[66, 169] -> 
             RGBColor[
              0.4955403552880472, 0.5995224478502696, 0.9539323726469158], 
             UndirectedEdge[168, 293] -> 
             RGBColor[
              0.650085093471142, 0.5794738875625195, 0.5924017179788976], 
             UndirectedEdge[93, 105] -> 
             RGBColor[
              0.26248514686677915`, 0.39321891024948796`, 0.9382595128508624],
              UndirectedEdge[169, 193] -> 
             RGBColor[
              0.44215135474031986`, 0.5505814803014513, 0.9506292633518225], 
             UndirectedEdge[87, 216] -> 
             RGBColor[
              0.9298058839378985, 0.7371387261923006, 0.3529360529247516], 
             UndirectedEdge[81, 201] -> 
             RGBColor[
              0.8674144933652834, 0.47033079775319603`, 0.2102765746648868], 
             UndirectedEdge[63, 244] -> 
             RGBColor[
              0.18619322197801913`, 0.31303126000398057`, 0.9339148005922362],
              UndirectedEdge[32, 150] -> 
             RGBColor[
              0.9475427884309859, 0.8298940012964792, 0.5491295264859543], 
             UndirectedEdge[95, 282] -> 
             RGBColor[
              0.36409426757402563`, 0.48782276310977274`, 0.9444924758077534],
              UndirectedEdge[126, 239] -> 
             RGBColor[
              0.2305322261132995, 0.35963436460539283`, 0.9364398412840619], 
             UndirectedEdge[149, 150] -> 
             RGBColor[
              0.901456610665, 0.644502615181237, 0.23943789960535378`], 
             UndirectedEdge[16, 222] -> 
             RGBColor[
              0.23410797445122994`, 0.3633927028240968, 0.9366434748620613], 
             UndirectedEdge[192, 262] -> 
             RGBColor[
              0.31722856394081744`, 0.4487355619302395, 0.9414511103067129], 
             UndirectedEdge[214, 276] -> 
             RGBColor[
              0.22110211631188992`, 0.34972272130061666`, 0.9359028104814688],
              UndirectedEdge[48, 100] -> 
             RGBColor[
              0.18673636136840888`, 0.31360213394030656`, 0.9339457315770161],
              UndirectedEdge[105, 143] -> 
             RGBColor[
              0.29536739445361543`, 0.4277802373181654, 0.9401321082060067], 
             UndirectedEdge[268, 279] -> 
             RGBColor[
              0.22085812887375872`, 0.34946627503344374`, 0.9358889157578143],
              UndirectedEdge[24, 106] -> 
             RGBColor[
              0.892812310133672, 0.8140725087445938, 0.6221015838690171], 
             UndirectedEdge[33, 222] -> 
             RGBColor[
              0.210965999406103, 0.33906901976570414`, 0.9353255736187255], 
             UndirectedEdge[155, 291] -> 
             RGBColor[
              0.9265943306289632, 0.845047396157727, 0.6262279650717502], 
             UndirectedEdge[99, 233] -> 
             RGBColor[
              0.20053490529032286`, 0.32810527848045334`, 0.9347315382402527],
              UndirectedEdge[237, 269] -> 
             RGBColor[
              0.8991197807384712, 0.5574407348110937, 0.260947978617189], 
             UndirectedEdge[85, 135] -> 
             RGBColor[
              0.22261249954375167`, 0.3513102298411313, 0.9359888245721116], 
             UndirectedEdge[126, 248] -> 
             RGBColor[
              0.22272354417989754`, 0.3514269447943572, 0.9359951483998643], 
             UndirectedEdge[188, 261] -> 
             RGBColor[
              0.30030042916823396`, 0.42860875023970424`, 0.9405725470875715],
              UndirectedEdge[37, 177] -> 
             RGBColor[
              0.2592700003340752, 0.38983958739155206`, 0.9380764150122078], 
             UndirectedEdge[160, 180] -> 
             RGBColor[
              0.19532450559808373`, 0.32262881804548893`, 0.9344348136858753],
              UndirectedEdge[23, 194] -> 
             RGBColor[
              0.8376760987270953, 0.8722472965038359, 0.8977776532625734], 
             UndirectedEdge[51, 243] -> 
             RGBColor[
              0.8993571244293498, 0.920787638740557, 0.9200070578349391], 
             UndirectedEdge[108, 208] -> 
             RGBColor[
              0.2150010029643497, 0.34331006433942324`, 0.9355553611021148], 
             UndirectedEdge[179, 251] -> 
             RGBColor[
              0.4041820274938994, 0.5204791332423994, 0.9475743793112779], 
             UndirectedEdge[26, 224] -> 
             RGBColor[
              0.21888166411978893`, 0.3473888852619182, 0.9357763590139934], 
             UndirectedEdge[106, 291] -> 
             RGBColor[
              0.8943677152627585, 0.9186085554583606, 0.9897867851648885], 
             UndirectedEdge[48, 161] -> 
             RGBColor[
              0.19723226696141938`, 0.3246339961974114, 0.9345434578732372], 
             UndirectedEdge[227, 299] -> 
             RGBColor[
              0.885699193119303, 0.49744557906545395`, 0.22316886447357331`], 
             UndirectedEdge[162, 299] -> 
             RGBColor[
              0.9050210878776606, 0.5676926894870836, 0.4792897876815234], 
             UndirectedEdge[200, 227] -> 
             RGBColor[
              0.6591374011618665, 0.6706282245294286, 0.6126589597072597], 
             UndirectedEdge[202, 293] -> 
             RGBColor[
              0.8831647510557664, 0.562360246757456, 0.22422214319796666`], 
             UndirectedEdge[3, 155] -> 
             RGBColor[
              0.9402661035019293, 0.855471333191099, 0.6109745630706932], 
             UndirectedEdge[39, 234] -> 
             RGBColor[
              0.19793969225016772`, 0.3253775450292399, 0.9345837446968894], 
             UndirectedEdge[144, 176] -> 
             RGBColor[
              0.19591627409858087`, 0.32325080425980146`, 0.9344685140265354],
              UndirectedEdge[140, 162] -> 
             RGBColor[
              0.904333638485641, 0.5624086522177772, 0.47863148536736244`], 
             UndirectedEdge[123, 257] -> 
             RGBColor[
              0.19133948148967972`, 0.3184403050424346, 0.9342078724582165], 
             UndirectedEdge[121, 286] -> 
             RGBColor[
              0.22317009351070355`, 0.3518962964538972, 0.9360205787236432], 
             UndirectedEdge[176, 230] -> 
             RGBColor[
              0.19313907822011844`, 0.32033179530714856`, 0.9343103568297502],
              UndirectedEdge[39, 64] -> 
             RGBColor[
              0.2185143800083959, 0.3470028463736865, 0.9357554427271977], 
             UndirectedEdge[269, 277] -> 
             RGBColor[
              0.9830880426173179, 0.9543005010685027, 0.41547009014484526`], 
             UndirectedEdge[154, 203] -> 
             RGBColor[
              0.7172113529376909, 0.7776981044453534, 0.9724416173890855], 
             UndirectedEdge[107, 137] -> 
             RGBColor[
              0.33500472849332374`, 0.4602209338581902, 0.9427270090780024], 
             UndirectedEdge[192, 218] -> 
             RGBColor[
              0.6489034320102649, 0.7179182155893853, 0.9413556495465901], 
             UndirectedEdge[247, 270] -> 
             RGBColor[
              0.20529778048290723`, 0.33311136229158844`, 0.935002776936428], 
             UndirectedEdge[28, 240] -> 
             RGBColor[
              0.18200025991928498`, 0.3086241910311017, 0.9336760176059227], 
             UndirectedEdge[31, 194] -> 
             RGBColor[
              0.552827044743554, 0.6462661114029045, 0.958649445840947], 
             UndirectedEdge[58, 187] -> 
             RGBColor[
              0.20794054512620663`, 0.3358890754926524, 0.9351532784732439], 
             UndirectedEdge[8, 121] -> 
             RGBColor[
              0.21495883648631775`, 0.3432657446975026, 0.9355529597835706], 
             UndirectedEdge[62, 186] -> 
             RGBColor[
              0.19739650616034748`, 0.3248066220088515, 0.934552811052646], 
             UndirectedEdge[271, 289] -> 
             RGBColor[
              0.23303990394891333`, 0.36227009300658086`, 0.9365826498270231],
              UndirectedEdge[236, 294] -> 
             RGBColor[
              0.38374017735760657`, 0.49740352912178454`, 0.9465549709165739],
              UndirectedEdge[115, 211] -> 
             RGBColor[
              0.3112307319414529, 0.4404795631489132, 0.9411810111605179], 
             UndirectedEdge[43, 284] -> 
             RGBColor[
              0.23327215251581435`, 0.3625142009758035, 0.9365958760393271], 
             UndirectedEdge[87, 181] -> 
             RGBColor[
              0.9897210070316473, 0.9765905802662477, 0.448420390956374], 
             UndirectedEdge[77, 205] -> 
             RGBColor[
              0.3930712028278346, 0.5148802523815419, 0.9462671273583405], 
             UndirectedEdge[132, 267] -> 
             RGBColor[
              0.19655119281637518`, 0.32391814408837505`, 0.9345046717082358],
              UndirectedEdge[108, 280] -> 
             RGBColor[
              0.2513491898337207, 0.3815143133472875, 0.9376253365720018], 
             UndirectedEdge[40, 97] -> 
             RGBColor[
              0.5690459020341019, 0.6601769695084484, 0.9597409246828227], 
             UndirectedEdge[35, 262] -> 
             RGBColor[
              0.25511664496274467`, 0.3854741475583434, 0.9378398875681493], 
             UndirectedEdge[201, 216] -> 
             RGBColor[
              0.8559139051187693, 0.4181093125564028, 0.20068020192678135`], 
             UndirectedEdge[244, 279] -> 
             RGBColor[
              0.21308524932289044`, 0.3412964857964532, 0.9354462617663373], 
             UndirectedEdge[143, 163] -> 
             RGBColor[
              0.4640224729127619, 0.5716064552084593, 0.95205347173178], 
             UndirectedEdge[102, 165] -> 
             RGBColor[
              0.20499479718794766`, 0.3327929076383356, 0.9349855224860035], 
             UndirectedEdge[7, 282] -> 
             RGBColor[
              0.6894759164963487, 0.7547973275205713, 0.9692952652700408], 
             UndirectedEdge[10, 122] -> 
             RGBColor[
              0.1877216481680741, 0.3146377328375459, 0.9340018422026558], 
             UndirectedEdge[113, 193] -> 
             RGBColor[
              0.2735981771019762, 0.40489940963349313`, 0.9388923834825018], 
             UndirectedEdge[22, 100] -> 
             RGBColor[
              0.1846021361595517, 0.3113589279281038, 0.9338241906086748], 
             UndirectedEdge[116, 254] -> 
             RGBColor[
              0.30306682721859113`, 0.43494494762898417`, 0.9406045538059649],
              UndirectedEdge[174, 298] -> 
             RGBColor[
              0.24667128016472487`, 0.3765975336885693, 0.9373589365366997], 
             UndirectedEdge[159, 271] -> 
             RGBColor[
              0.2569380089981777, 0.38738851664073326`, 0.9379436115555007], 
             UndirectedEdge[11, 101] -> 
             RGBColor[
              0.589571415450858, 0.6776035417182125, 0.9608844110153827], 
             UndirectedEdge[148, 225] -> 
             RGBColor[
              0.23694694145511846`, 0.36637663714608804`, 0.9368051498330575],
              UndirectedEdge[239, 248] -> 
             RGBColor[
              0.22976740900447992`, 0.35883049333181793`, 0.9363962860811601],
              UndirectedEdge[22, 119] -> 
             RGBColor[
              0.18469650892406414`, 0.31145811968718523`, 0.933829564998002], 
             UndirectedEdge[38, 247] -> 
             RGBColor[
              0.19193794866685385`, 0.31906933199065524`, 0.9342419542786038],
              UndirectedEdge[157, 222] -> 
             RGBColor[
              0.20198183109515816`, 0.32962608924173, 0.9348139385243031], 
             UndirectedEdge[42, 203] -> 
             RGBColor[
              0.8873649131430477, 0.6213403105093347, 0.5874793203268023], 
             UndirectedEdge[155, 241] -> 
             RGBColor[
              0.9562190222247212, 0.8670479840915544, 0.569594959834627], 
             UndirectedEdge[103, 154] -> 
             RGBColor[
              0.45931362601150366`, 0.5710619602704519, 0.9508179830889629], 
             UndirectedEdge[88, 107] -> 
             RGBColor[
              0.3156668760979841, 0.43989562490003076`, 0.9416257469918767], 
             UndirectedEdge[58, 176] -> 
             RGBColor[
              0.19266677740688082`, 0.31983537720683475`, 0.9342834599971428],
              UndirectedEdge[48, 119] -> 
             RGBColor[
              0.1868307341329213, 0.31370132569938797`, 0.933951105966343], 
             UndirectedEdge[206, 219] -> 
             RGBColor[
              0.20337837440800324`, 0.33109394480949034`, 0.9348934695999689],
              UndirectedEdge[1, 125] -> 
             RGBColor[
              0.8269439386544566, 0.20810849617316574`, 0.17343485212532112`],
              UndirectedEdge[191, 278] -> 
             RGBColor[
              0.21400334724237668`, 0.34226146492060344`, 0.9354985460846478],
              UndirectedEdge[90, 118] -> 
             RGBColor[
              0.20219853738896398`, 0.32985386129649247`, 0.9348262796271471],
              UndirectedEdge[101, 283] -> 
             RGBColor[
              0.4765743997943146, 0.5815921216615045, 0.9531053393092228], 
             UndirectedEdge[5, 226] -> 
             RGBColor[
              0.978634912205556, 0.9512330589473125, 0.6096542687532867], 
             UndirectedEdge[3, 241] -> 
             RGBColor[
              0.9701712881509421, 0.9769533662972854, 0.9210009349471945], 
             UndirectedEdge[194, 241] -> 
             RGBColor[
              0.8360648746712487, 0.8715810139501738, 0.9244798055821426], 
             UndirectedEdge[139, 235] -> 
             RGBColor[
              0.42460849977243, 0.5421962738843169, 0.9482766560323135], 
             UndirectedEdge[40, 94] -> 
             RGBColor[
              0.7430612286953848, 0.7992043464221197, 0.9750250570405241], 
             UndirectedEdge[161, 177] -> 
             RGBColor[
              0.24681318446187503`, 0.3767466841021262, 0.9373670177764938], 
             UndirectedEdge[34, 295] -> 
             RGBColor[
              0.19030787854135572`, 0.3173560249363414, 0.9341491241964293], 
             UndirectedEdge[1, 281] -> 
             RGBColor[
              0.8985774900643843, 0.5640742698921016, 0.5434386235912599], 
             UndirectedEdge[191, 295] -> 
             RGBColor[
              0.21214976125282442`, 0.34031322852144436`, 0.9353929871046776],
              UndirectedEdge[144, 297] -> 
             RGBColor[
              0.19481653012173772`, 0.32209490361234383`, 0.9344058852339796],
              UndirectedEdge[141, 294] -> 
             RGBColor[
              0.41494859536709305`, 0.5302055551777425, 0.9483322441534972], 
             UndirectedEdge[80, 201] -> 
             RGBColor[
              0.9120862504146132, 0.6449358982719986, 0.2816245549778238], 
             UndirectedEdge[113, 115] -> 
             RGBColor[
              0.3096806718260522, 0.43885035168813935`, 0.9410927375300542], 
             UndirectedEdge[129, 253] -> 
             RGBColor[
              0.19046881652676248`, 0.3175251809630616, 0.9341582893766117], 
             UndirectedEdge[37, 108] -> 
             RGBColor[
              0.23362687386015235`, 0.362887035599335, 0.936616076895124], 
             UndirectedEdge[265, 276] -> 
             RGBColor[
              0.23204484364859856`, 0.36122422154048306`, 0.93652598261498], 
             UndirectedEdge[59, 194] -> 
             RGBColor[
              0.8355066141794747, 0.8713501588901851, 0.9337316266626792], 
             UndirectedEdge[103, 225] -> 
             RGBColor[
              0.3244631340928782, 0.4479525778867464, 0.9421701966492211], 
             UndirectedEdge[46, 265] -> 
             RGBColor[
              0.21371228475052867`, 0.3419555397872433, 0.9354819705063254], 
             UndirectedEdge[51, 149] -> 
             RGBColor[
              0.8534002738604769, 0.7354497327448786, 0.6081721446101185], 
             UndirectedEdge[52, 124] -> 
             RGBColor[
              0.1923287617954415, 0.3194801013677844, 0.9342642105081206], 
             UndirectedEdge[82, 258] -> 
             RGBColor[
              0.47680058453134755`, 0.5830547562597531, 0.9528035659599465], 
             UndirectedEdge[45, 132] -> 
             RGBColor[
              0.24841553022607393`, 0.3784308510948885, 0.9374582689973068], 
             UndirectedEdge[74, 287] -> 
             RGBColor[
              0.2244511741859948, 0.35324279346883447`, 0.936093534372912], 
             UndirectedEdge[128, 269] -> 
             RGBColor[
              0.9090525762339738, 0.6337885535682664, 0.2704596348011703], 
             UndirectedEdge[14, 249] -> 
             RGBColor[
              0.19382527220510481`, 0.3210530286925808, 0.9343494345620621], 
             UndirectedEdge[101, 198] -> 
             RGBColor[
              0.8059595419277743, 0.8487647451023745, 0.9551527712864303], 
             UndirectedEdge[164, 297] -> 
             RGBColor[
              0.18697714573381324`, 0.31385521357495705`, 0.9339594438904173],
              UndirectedEdge[68, 235] -> 
             RGBColor[
              0.6426752269533634, 0.7164421222894727, 0.967683202312762], 
             UndirectedEdge[108, 177] -> 
             RGBColor[
              0.2663285931328081, 0.3972586159636525, 0.9384783914298436], 
             UndirectedEdge[62, 276] -> 
             RGBColor[
              0.22152543341226616`, 0.3501676544129665, 0.9359269177640938], 
             UndirectedEdge[13, 107] -> 
             RGBColor[
              0.3708820169269006, 0.49566109481506393`, 0.9448532520538597], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.21391225518849333`, 0.3421657213964022, 0.9354933585269378], 
             UndirectedEdge[62, 135] -> 
             RGBColor[
              0.20737676424851148`, 0.33529650604442257`, 0.9351211719862982],
              UndirectedEdge[18, 35] -> 
             RGBColor[
              0.20318410319091706`, 0.3308897534428262, 0.9348824061415544], 
             UndirectedEdge[42, 202] -> 
             RGBColor[
              0.8520877350286713, 0.3885313712004504, 0.1970096660833716], 
             UndirectedEdge[121, 255] -> 
             RGBColor[
              0.295733658786952, 0.42287002848225363`, 0.9403468487457121], 
             UndirectedEdge[128, 281] -> 
             RGBColor[
              0.9117009146920902, 0.6649466623019902, 0.5560056298355394], 
             UndirectedEdge[82, 181] -> 
             RGBColor[
              0.7998668067519439, 0.8312427160957487, 0.681983215284067], 
             UndirectedEdge[136, 204] -> 
             RGBColor[
              0.4381119186941594, 0.553069802846105, 0.9493643283826801], 
             UndirectedEdge[118, 166] -> 
             RGBColor[
              0.18740769372755933`, 0.31430774681470364`, 0.9339839629617225],
              UndirectedEdge[39, 263] -> 
             RGBColor[
              0.2058067463664483, 0.333646317705491, 0.935031761790548], 
             UndirectedEdge[52, 84] -> 
             RGBColor[
              0.1931004885069918, 0.32029123507192336`, 0.9343081592026761], 
             UndirectedEdge[129, 165] -> 
             RGBColor[
              0.20344097121398075`, 0.33115973802143944`, 0.9348970343954657],
              UndirectedEdge[141, 236] -> 
             RGBColor[
              0.2626393533607303, 0.39338099105188706`, 0.9382682946825648], 
             UndirectedEdge[97, 178] -> 
             RGBColor[
              0.353934746876465, 0.4763839115166376, 0.9439417536383794], 
             UndirectedEdge[115, 227] -> 
             RGBColor[
              0.6522166119287909, 0.6646337847447196, 0.6122179731371418], 
             UndirectedEdge[256, 281] -> 
             RGBColor[
              0.8981948395566131, 0.5611330504108505, 0.5430721970328762], 
             UndirectedEdge[221, 297] -> 
             RGBColor[
              0.18909437890281156`, 0.31608055987591055`, 0.9340800171872259],
              UndirectedEdge[224, 262] -> 
             RGBColor[
              0.2562537795699573, 0.3866693481290222, 0.9379046457017901], 
             UndirectedEdge[73, 119] -> 
             RGBColor[
              0.18176019735719462`, 0.3083718700574992, 0.9336623463981524], 
             UndirectedEdge[3, 227] -> 
             RGBColor[
              0.9534614284413586, 0.9077863994945625, 0.6215918312510428], 
             UndirectedEdge[45, 188] -> 
             RGBColor[
              0.32789958178650086`, 0.45761720952884744`, 0.9421442779998944],
              UndirectedEdge[260, 300] -> 
             RGBColor[
              0.24190674150061214`, 0.37158970146338766`, 0.9370876031082818],
              UndirectedEdge[23, 291] -> 
             RGBColor[
              0.9581107393338224, 0.9671957118175754, 0.9095521846286824], 
             UndirectedEdge[142, 149] -> 
             RGBColor[
              0.8627196996396836, 0.42474633719376353`, 0.20540890846687038`],
              UndirectedEdge[81, 97] -> 
             RGBColor[
              0.6691615275279388, 0.5770839186847934, 0.5896504800872672], 
             UndirectedEdge[181, 201] -> 
             RGBColor[
              0.9158290282125181, 0.65756116663035, 0.29616453995840375`], 
             UndirectedEdge[56, 57] -> 
             RGBColor[
              0.18951617750640207`, 0.3165238969518603, 0.9341040379937053], 
             UndirectedEdge[197, 243] -> 
             RGBColor[
              0.9868796101505515, 0.9888423958656835, 0.8671023444932484], 
             UndirectedEdge[65, 200] -> 
             RGBColor[
              0.37151685139917806`, 0.49621095652724223`, 0.9448937031450712],
              UndirectedEdge[8, 173] -> 
             RGBColor[
              0.2028775855537629, 0.3305675839718365, 0.9348649504155706], 
             UndirectedEdge[53, 273] -> 
             RGBColor[
              0.2274037724911021, 0.35634616149304726`, 0.9362616804784101], 
             UndirectedEdge[26, 253] -> 
             RGBColor[
              0.21047277090696587`, 0.3385506053406179, 0.9352974849853658], 
             UndirectedEdge[114, 206] -> 
             RGBColor[
              0.2307773334017795, 0.35989198790628496`, 0.936453799781537], 
             UndirectedEdge[9, 45] -> 
             RGBColor[
              0.24944742731977937`, 0.3795154403664275, 0.9375170340102383], 
             UndirectedEdge[47, 190] -> 
             RGBColor[
              0.1942570496898653, 0.32150685420533776`, 0.9343740236510617], 
             UndirectedEdge[191, 282] -> 
             RGBColor[
              0.3340044293562811, 0.4561964353369906, 0.9427789040351794], 
             UndirectedEdge[59, 155] -> 
             RGBColor[
              0.9556607617329471, 0.8668171290315656, 0.5788467809151635], 
             UndirectedEdge[214, 265] -> 
             RGBColor[
              0.21177311264038245`, 0.33991734694886655`, 0.9353715375234006],
              UndirectedEdge[167, 282] -> 
             RGBColor[
              0.674157084988882, 0.6138860835498305, 0.5969373306942671], 
             UndirectedEdge[28, 221] -> 
             RGBColor[
              0.18483282648833058`, 0.31160139809026205`, 0.9338373280816231],
              UndirectedEdge[136, 197] -> 
             RGBColor[
              0.689478603616865, 0.751552751257122, 0.9111273992783655], 
             UndirectedEdge[121, 234] -> 
             RGBColor[
              0.20980230497718771`, 0.3378459031384259, 0.9352593029425303], 
             UndirectedEdge[141, 146] -> 
             RGBColor[
              0.24693839801171524`, 0.3768782914820059, 0.9373741485029203], 
             UndirectedEdge[32, 167] -> 
             RGBColor[
              0.947679092916505, 0.830434403160785, 0.5492392002744804], 
             UndirectedEdge[101, 136] -> 
             RGBColor[
              0.5199717589850226, 0.6194511898467974, 0.9558606779112371], 
             UndirectedEdge[91, 274] -> 
             RGBColor[
              0.4766026768727841, 0.5859665496480654, 0.9519390550580074], 
             UndirectedEdge[84, 295] -> 
             RGBColor[
              0.19219536521772562`, 0.31933989310677346`, 0.9342566137703623],
              UndirectedEdge[73, 122] -> 
             RGBColor[
              0.18385458485627515`, 0.31057320411086997`, 0.9337816186678564],
              UndirectedEdge[157, 248] -> 
             RGBColor[
              0.20224840910221648`, 0.3299062796291701, 0.9348291197474383], 
             UndirectedEdge[125, 167] -> 
             RGBColor[
              0.871438247578835, 0.47161136318027613`, 0.21295628245325632`], 
             UndirectedEdge[20, 208] -> 
             RGBColor[
              0.20416035452872197`, 0.331915855496769, 0.9349380022110079], 
             UndirectedEdge[77, 103] -> 
             RGBColor[
              0.41755616548084906`, 0.5360878963815774, 0.9478272875273883], 
             UndirectedEdge[46, 276] -> 
             RGBColor[
              0.22304128842203616`, 0.35176091413899346`, 0.9360132434643936],
              UndirectedEdge[3, 291] -> 
             RGBColor[
              0.940546596555184, 0.9549527783634579, 0.9776339401843177], 
             UndirectedEdge[79, 297] -> 
             RGBColor[
              0.1875669958551452, 0.3144751834511347, 0.9339930349822221], 
             UndirectedEdge[18, 262] -> 
             RGBColor[
              0.25190729178629806`, 0.38210091388515394`, 0.9376571196525632],
              UndirectedEdge[127, 225] -> 
             RGBColor[
              0.28821593818422175`, 0.41655707862770686`, 0.9398605573780583],
              UndirectedEdge[109, 292] -> 
             RGBColor[
              0.8832633694480486, 0.907223500639492, 0.873440789605417], 
             UndirectedEdge[267, 287] -> 
             RGBColor[
              0.2196035170740144, 0.34814759848492993`, 0.9358174674718507], 
             UndirectedEdge[218, 262] -> 
             RGBColor[
              0.6355147016275733, 0.7058679616598169, 0.9405191403190352], 
             UndirectedEdge[207, 225] -> 
             RGBColor[
              0.20644219198451136`, 0.33431421133965444`, 0.9350679494784392],
              UndirectedEdge[203, 299] -> 
             RGBColor[
              0.8779094953234592, 0.5486618257574685, 0.5784248015443972], 
             UndirectedEdge[142, 163] -> 
             RGBColor[
              0.7255429896746053, 0.4672102742569026, 0.5698090215965668], 
             UndirectedEdge[2, 54] -> 
             RGBColor[
              0.22131402237840694`, 0.34994544801214666`, 0.9359148782184701],
              UndirectedEdge[90, 195] -> 
             RGBColor[
              0.19970007804544365`, 0.3272278221149808, 0.934683996063673], 
             UndirectedEdge[88, 93] -> 
             RGBColor[
              0.23199426054362918`, 0.36117105549000617`, 0.9365231019819831],
              UndirectedEdge[77, 82] -> 
             RGBColor[
              0.5136111712070213, 0.6149382362843397, 0.9551491039925967], 
             UndirectedEdge[167, 168] -> 
             RGBColor[
              0.6540467218133117, 0.5964674977433942, 0.5956559161356156], 
             UndirectedEdge[18, 26] -> 
             RGBColor[
              0.21453517633612967`, 0.3428204510180499, 0.9355288329647664], 
             UndirectedEdge[129, 224] -> 
             RGBColor[
              0.19887770973958555`, 0.32636346088436186`, 0.9346371634052393],
              UndirectedEdge[38, 289] -> 
             RGBColor[
              0.21478203632197956`, 0.34307991651500525`, 0.935542891275764], 
             UndirectedEdge[31, 241] -> 
             RGBColor[
              0.7028863769460394, 0.7632151146504713, 0.9137909719699326], 
             UndirectedEdge[5, 197] -> 
             RGBColor[
              0.9786771999205136, 0.9512505460041922, 0.6089534518793391], 
             UndirectedEdge[59, 241] -> 
             RGBColor[
              0.9855659463819599, 0.9882991621377519, 0.8888731527916648], 
             UndirectedEdge[155, 226] -> 
             RGBColor[
              0.9562854870849291, 0.8670754690193194, 0.5684934650954372], 
             UndirectedEdge[15, 186] -> 
             RGBColor[
              0.22574603195372214`, 0.35460377108144014`, 0.9361672746072136],
              UndirectedEdge[198, 256] -> 
             RGBColor[
              0.8912595826963075, 0.5559607471998754, 0.554811777892692], 
             UndirectedEdge[72, 291] -> 
             RGBColor[
              0.8781451400021425, 0.5858172526612265, 0.5843444612101898], 
             UndirectedEdge[230, 297] -> 
             RGBColor[
              0.19203933424327527`, 0.319175894659691, 0.9342477280371944], 
             UndirectedEdge[138, 231] -> 
             RGBColor[
              0.23123426787294182`, 0.3603722550067954, 0.9364798215236958], 
             UndirectedEdge[54, 165] -> 
             RGBColor[
              0.2309155676527057, 0.3600372808685661, 0.936461672017628], 
             UndirectedEdge[103, 167] -> 
             RGBColor[
              0.6645058305861254, 0.6055266520723135, 0.5963223612979925], 
             UndirectedEdge[78, 131] -> 
             RGBColor[
              0.21176961520445978`, 0.33991367092196156`, 0.9353713383495988],
              UndirectedEdge[16, 239] -> 
             RGBColor[
              0.2421832343916902, 0.3718803130225725, 0.9371033489693941], 
             UndirectedEdge[12, 87] -> 
             RGBColor[
              0.7113840896935575, 0.7671448961592477, 0.7220908533867955], 
             UndirectedEdge[125, 281] -> 
             RGBColor[
              0.9068280234058514, 0.6274914845613823, 0.5513393436366936], 
             UndirectedEdge[148, 205] -> 
             RGBColor[
              0.3093284827197305, 0.43657270388582725`, 0.9411425228750159], 
             UndirectedEdge[103, 269] -> 
             RGBColor[
              0.6972472679550255, 0.7302486647196956, 0.6491594274470608], 
             UndirectedEdge[40, 169] -> 
             RGBColor[
              0.6469863029423364, 0.7235735932337524, 0.9658432196124291], 
             UndirectedEdge[38, 53] -> 
             RGBColor[
              0.2009984379794762, 0.32859248072642344`, 0.9347579357411648], 
             UndirectedEdge[118, 285] -> 
             RGBColor[
              0.19420033164892994`, 0.32144723994818314`, 0.9343707936425373],
              UndirectedEdge[74, 267] -> 
             RGBColor[
              0.2010537316252639, 0.328650597853966, 0.9347610846324927], 
             UndirectedEdge[3, 200] -> 
             RGBColor[
              0.659894342148658, 0.7282185404316961, 0.9534476666394777], 
             UndirectedEdge[124, 273] -> 
             RGBColor[
              0.2124273089085979, 0.3406049487052001, 0.9354087930330789], 
             UndirectedEdge[131, 182] -> 
             RGBColor[
              0.24187571808972635`, 0.3715570938915489, 0.9370858363709268], 
             UndirectedEdge[62, 207] -> 
             RGBColor[
              0.19348238664909873`, 0.3206926342330184, 0.9343299077369014], 
             UndirectedEdge[75, 262] -> 
             RGBColor[
              0.318384602518598, 0.4497368644421247, 0.9415247720626443], 
             UndirectedEdge[197, 283] -> 
             RGBColor[
              0.646081244426157, 0.713693683071829, 0.9083720606763512], 
             UndirectedEdge[246, 278] -> 
             RGBColor[
              0.1925398971260588, 0.3197020179870163, 0.9342762343528525], 
             UndirectedEdge[225, 265] -> 
             RGBColor[
              0.22515623507617133`, 0.35398385716785236`, 0.9361336865475633],
              UndirectedEdge[101, 204] -> 
             RGBColor[
              0.5654681824695174, 0.6580354513456885, 0.9589869162220399], 
             UndirectedEdge[87, 140] -> 
             RGBColor[
              0.9052335250111279, 0.560939848386522, 0.3299018570676289], 
             UndirectedEdge[57, 247] -> 
             RGBColor[
              0.18871603896391997`, 0.3156829006119979, 0.9340584712874099], 
             UndirectedEdge[40, 66] -> 
             RGBColor[
              0.5377876957046065, 0.6331026822689709, 0.9577491794160538], 
             UndirectedEdge[167, 293] -> 
             RGBColor[
              0.9037203948195764, 0.6547034053372311, 0.24132279457904], 
             UndirectedEdge[42, 140] -> 
             RGBColor[
              0.8274618672116081, 0.2120895220211726, 0.17393082109656596`], 
             UndirectedEdge[107, 150] -> 
             RGBColor[
              0.657942354371067, 0.5994193570949246, 0.595803153810185], 
             UndirectedEdge[91, 143] -> 
             RGBColor[
              0.39852667636969663`, 0.5184340170227889, 0.9468974027089019], 
             UndirectedEdge[91, 142] -> 
             RGBColor[
              0.6600471931315399, 0.4140378360712322, 0.5646529525736886], 
             UndirectedEdge[44, 283] -> 
             RGBColor[
              0.3110200455084933, 0.44354120705361005`, 0.9410488029197814], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.19626308316666907`, 0.323615322579327, 0.9344882642899051], 
             UndirectedEdge[199, 233] -> 
             RGBColor[
              0.20189518711453486`, 0.32953502092454917`, 0.9348090042777849],
              UndirectedEdge[249, 286] -> 
             RGBColor[
              0.2141737173623244, 0.342440534718758, 0.9355082484109388], 
             UndirectedEdge[48, 266] -> 
             RGBColor[
              0.19547981769013628`, 0.32279206090159157`, 0.934443658479754], 
             UndirectedEdge[113, 169] -> 
             RGBColor[
              0.4361857848874334, 0.5443112881470928, 0.9502895329739705], 
             UndirectedEdge[18, 33] -> 
             RGBColor[
              0.20024058888485757`, 0.32779593327757145`, 0.9347147773563635],
              UndirectedEdge[269, 293] -> 
             RGBColor[
              0.9364618321884765, 0.7794254179846133, 0.2941598607281082], 
             UndirectedEdge[189, 257] -> 
             RGBColor[
              0.1999558217805158, 0.327496624995631, 0.9346985602910465], 
             UndirectedEdge[11, 197] -> 
             RGBColor[
              0.7590782600827003, 0.809705103128537, 0.9161511323825111], 
             UndirectedEdge[221, 296] -> 
             RGBColor[
              0.18670137270172213`, 0.31356535863320917`, 0.9339437390242094],
              UndirectedEdge[126, 157] -> 
             RGBColor[
              0.20301322621103607`, 0.33071015090274497`, 0.93487267495034], 
             UndirectedEdge[24, 87] -> 
             RGBColor[
              0.9584560317231505, 0.8616047223377981, 0.3765513268644449], 
             UndirectedEdge[53, 137] -> 
             RGBColor[
              0.2387057780017381, 0.36822528587326325`, 0.936905312972422], 
             UndirectedEdge[27, 140] -> 
             RGBColor[
              0.8935802518260152, 0.5220287258229606, 0.25077918297631857`], 
             UndirectedEdge[115, 200] -> 
             RGBColor[
              0.35864952563609026`, 0.485065925681853, 0.9440738085255767], 
             UndirectedEdge[1, 5] -> 
             RGBColor[
              0.8948530465649757, 0.5292862061726197, 0.25371216367685606`], 
             UndirectedEdge[40, 42] -> 
             RGBColor[
              0.763419188891056, 0.5236029358473995, 0.5766518342873496], 
             UndirectedEdge[82, 167] -> 
             RGBColor[
              0.7605608363122977, 0.684376991975076, 0.6036441777632009], 
             UndirectedEdge[52, 57] -> 
             RGBColor[
              0.18920436008623348`, 0.3161961570728968, 0.9340862804529193], 
             UndirectedEdge[27, 203] -> 
             RGBColor[
              0.9534832977574548, 0.9312795143111227, 0.6643276822065549], 
             UndirectedEdge[251, 270] -> 
             RGBColor[
              0.24922321837913736`, 0.37927978255414485`, 0.9375042656427561],
              UndirectedEdge[200, 264] -> 
             RGBColor[
              0.3308901333922204, 0.45986309204908005`, 0.9423474428513454], 
             UndirectedEdge[84, 271] -> 
             RGBColor[
              0.20505156873545605`, 0.33285257813429087`, 0.9349887555416483],
              UndirectedEdge[80, 145] -> 
             RGBColor[
              0.9218561356347152, 0.9176464031707863, 0.6795757972164687], 
             UndirectedEdge[199, 259] -> 
             RGBColor[
              0.19177802866162308`, 0.31890124592564373`, 0.9342328470708863],
              UndirectedEdge[273, 274] -> 
             RGBColor[
              0.3509883555182567, 0.4717110997619036, 0.9438949792783465], 
             UndirectedEdge[281, 294] -> 
             RGBColor[
              0.7572554970898742, 0.8088426757639791, 0.9389810177450694], 
             UndirectedEdge[18, 183] -> 
             RGBColor[
              0.19635753288152386`, 0.32371459521809726`, 0.9344936430614402],
              UndirectedEdge[77, 269] -> 
             RGBColor[
              0.6934737954253698, 0.7269802724747518, 0.6489189851142219], 
             UndirectedEdge[134, 144] -> 
             RGBColor[
              0.22121948408189393`, 0.34984608226843733`, 0.9359094944023405],
              UndirectedEdge[200, 210] -> 
             RGBColor[
              0.4186246829308158, 0.5365148469090834, 0.9480331221442837], 
             UndirectedEdge[87, 151] -> 
             RGBColor[
              0.7954880540997038, 0.8360677360525939, 0.7285340376363743], 
             UndirectedEdge[109, 290] -> 
             RGBColor[
              0.9696110495252712, 0.9082697495604787, 0.5222701846474617], 
             UndirectedEdge[247, 278] -> 
             RGBColor[
              0.19919319876560948`, 0.3266950598538726, 0.9346551300385472], 
             UndirectedEdge[156, 205] -> 
             RGBColor[
              0.38342561820827703`, 0.5065257317852604, 0.945652519235638], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.18357179140558838`, 0.31027597026405784`, 0.9337655139991952],
              UndirectedEdge[64, 121] -> 
             RGBColor[
              0.2303769927354159, 0.3594712044828725, 0.9364310009728385], 
             UndirectedEdge[106, 264] -> 
             RGBColor[
              0.579035279379287, 0.6606770441091168, 0.9634331593756991], 
             UndirectedEdge[91, 107] -> 
             RGBColor[
              0.44931704433721525`, 0.562597259364136, 0.9501274523636514], 
             UndirectedEdge[7, 299] -> 
             RGBColor[
              0.8785067924803591, 0.5491072889991002, 0.5774137332578136], 
             UndirectedEdge[160, 221] -> 
             RGBColor[
              0.19098000658392586`, 0.31806247412446187`, 0.9341874008941293],
              UndirectedEdge[8, 234] -> 
             RGBColor[
              0.19931169581116837`, 0.32681960776190155`, 0.934661878269991], 
             UndirectedEdge[49, 174] -> 
             RGBColor[
              0.22141328802375174`, 0.3500497824992095, 0.9359205312501221], 
             UndirectedEdge[79, 245] -> 
             RGBColor[
              0.20419166956427437`, 0.3319487695846225, 0.9349397855559562], 
             UndirectedEdge[13, 147] -> 
             RGBColor[
              0.27334324637888757`, 0.4023623173416999, 0.9389609500302152], 
             UndirectedEdge[1, 197] -> 
             RGBColor[
              0.9025175586685273, 0.5666556213354577, 0.5207754202823706], 
             UndirectedEdge[129, 175] -> 
             RGBColor[
              0.18584814501363772`, 0.3126685622352725, 0.9338951489696101], 
             UndirectedEdge[116, 283] -> 
             RGBColor[
              0.29658629715284524`, 0.4290613813379507, 0.9402015229115228], 
             UndirectedEdge[62, 265] -> 
             RGBColor[
              0.2121964297407587, 0.3403622800612163, 0.9353956448060256], 
             UndirectedEdge[31, 291] -> 
             RGBColor[
              0.6732616853502813, 0.7412145267166439, 0.970423977207056], 
             UndirectedEdge[92, 277] -> 
             RGBColor[
              0.9122829383943001, 0.6155043542913563, 0.3292695837766948], 
             UndirectedEdge[124, 289] -> 
             RGBColor[
              0.2146845283282537, 0.3429774294312355, 0.9355373383397714], 
             UndirectedEdge[80, 277] -> 
             RGBColor[
              0.9859097978901593, 0.963818944183442, 0.4264320765360633], 
             UndirectedEdge[119, 244] -> 
             RGBColor[
              0.18517767786647377`, 0.3119638587535308, 0.9338569668574466], 
             UndirectedEdge[252, 268] -> 
             RGBColor[
              0.22149590633125682`, 0.35013661957870057`, 0.9359252362405117],
              UndirectedEdge[3, 194] -> 
             RGBColor[
              0.8201119559484569, 0.8600043630497185, 0.9658594088182089], 
             UndirectedEdge[1, 237] -> 
             RGBColor[
              0.8218840344451928, 0.1692158551566011, 0.1685894821401856], 
             UndirectedEdge[149, 281] -> 
             RGBColor[
              0.9369826909775356, 0.800923138426649, 0.5779306345773171], 
             UndirectedEdge[29, 209] -> 
             RGBColor[
              0.1878554243304431, 0.3147783400660943, 0.9340094605571987], 
             UndirectedEdge[123, 287] -> 
             RGBColor[
              0.22080206667647367`, 0.3494073501095485, 0.9358857230986155], 
             UndirectedEdge[17, 81] -> 
             RGBColor[
              0.7965640174649642, 0.6796969932787943, 0.60028868050202], 
             UndirectedEdge[176, 187] -> 
             RGBColor[
              0.20946640578711895`, 0.33749285179242483`, 0.9352401739805742],
              UndirectedEdge[246, 270] -> 
             RGBColor[
              0.19864447884335656`, 0.3261183204247322, 0.9346238812507333], 
             UndirectedEdge[45, 131] -> 
             RGBColor[
              0.2646712879230951, 0.39551668310902466`, 0.9383840103499137], 
             UndirectedEdge[4, 158] -> 
             RGBColor[
              0.2067416614051505, 0.33462897268820413`, 0.9350850038189193], 
             UndirectedEdge[169, 264] -> 
             RGBColor[
              0.450474457220526, 0.5593295887233245, 0.9511032517251437], 
             UndirectedEdge[42, 181] -> 
             RGBColor[
              0.9119493492321276, 0.6277402539008983, 0.29244935498531105`], 
             UndirectedEdge[8, 263] -> 
             RGBColor[
              0.20717874992744892`, 0.3350883804381527, 0.9351098953636496], 
             UndirectedEdge[145, 205] -> 
             RGBColor[
              0.6186317877643385, 0.696027939962637, 0.9659619530693695], 
             UndirectedEdge[167, 269] -> 
             RGBColor[
              0.9404234605306463, 0.796419028165488, 0.2974140588848261], 
             UndirectedEdge[187, 288] -> 
             RGBColor[
              0.2168027551458141, 0.3452038201198287, 0.9356579682233956], 
             UndirectedEdge[47, 131] -> 
             RGBColor[
              0.20675371716772, 0.33464164405904423`, 0.9350856903767627], 
             UndirectedEdge[43, 97] -> 
             RGBColor[
              0.33722237523593046`, 0.45881814929687276`, 0.9429900087971892],
              UndirectedEdge[104, 114] -> 
             RGBColor[
              0.28710993911342014`, 0.4166656473064825, 0.939751033226302], 
             UndirectedEdge[26, 129] -> 
             RGBColor[
              0.20909164827758553`, 0.33709895788890676`, 0.9352188320948104],
              UndirectedEdge[28, 79] -> 
             RGBColor[
              0.1833054434406642, 0.3099960216654862, 0.9337503458766192], 
             UndirectedEdge[53, 247] -> 
             RGBColor[
              0.2068169042556322, 0.33470805769473266`, 0.9350892887879424], 
             UndirectedEdge[150, 281] -> 
             RGBColor[
              0.9429354945032435, 0.8270367350349062, 0.582850380130669], 
             UndirectedEdge[76, 248] -> 
             RGBColor[
              0.2744382407386017, 0.40410226692421763`, 0.9390017406595347], 
             UndirectedEdge[194, 210] -> 
             RGBColor[
              0.5788422967306146, 0.6683006695271059, 0.9604448643230148], 
             UndirectedEdge[60, 265] -> 
             RGBColor[
              0.2549916258941355, 0.3853427445905684, 0.9378327679171411], 
             UndirectedEdge[78, 178] -> 
             RGBColor[
              0.2265713684695162, 0.3554712520888972, 0.9362142763008121], 
             UndirectedEdge[120, 190] -> 
             RGBColor[
              0.24175240008128845`, 0.37142747884586735`, 0.937078813592779], 
             UndirectedEdge[96, 267] -> 
             RGBColor[
              0.19857826997424566`, 0.3260487307054119, 0.9346201107535846], 
             UndirectedEdge[159, 212] -> 
             RGBColor[
              0.2623047179263146, 0.3930292679932042, 0.9382492376896236], 
             UndirectedEdge[34, 147] -> 
             RGBColor[
              0.19854534996450335`, 0.32601412968792354`, 0.9346182360077306],
              UndirectedEdge[41, 250] -> 
             RGBColor[
              0.18562426514456906`, 0.3124332502980778, 0.9338823993422674], 
             UndirectedEdge[146, 236] -> 
             RGBColor[
              0.2157299800022288, 0.3440762654260479, 0.9355968752659971], 
             UndirectedEdge[82, 103] -> 
             RGBColor[
              0.5173846437366769, 0.6182066285292835, 0.9553895463254356], 
             UndirectedEdge[179, 289] -> 
             RGBColor[
              0.383100677252795, 0.49832129750419296`, 0.9463738276021099], 
             UndirectedEdge[124, 247] -> 
             RGBColor[
              0.191840440673128, 0.3189668449068855, 0.9342364013426112], 
             UndirectedEdge[162, 227] -> 
             RGBColor[
              0.9720263822129245, 0.9204431940139248, 0.5369240475267748], 
             UndirectedEdge[156, 191] -> 
             RGBColor[
              0.31093411780431135`, 0.4362140910182484, 0.9413088841833633], 
             UndirectedEdge[1, 51] -> 
             RGBColor[
              0.8149950729473256, 0.4986008642103312, 0.5736801336240612], 
             UndirectedEdge[23, 198] -> 
             RGBColor[
              0.9769688580402975, 0.9814876170817164, 0.8855196519471269], 
             UndirectedEdge[77, 159] -> 
             RGBColor[
              0.3525117466514917, 0.4781312147063014, 0.9437419749856031], 
             UndirectedEdge[2, 238] -> 
             RGBColor[
              0.19301734075154908`, 0.3202038415090809, 0.9343034240610095], 
             UndirectedEdge[113, 245] -> 
             RGBColor[
              0.24643755239072743`, 0.3763518709789012, 0.9373456260857398], 
             UndirectedEdge[167, 201] -> 
             RGBColor[
              0.8765230577728718, 0.5106954425096772, 0.21782550243753762`], 
             UndirectedEdge[125, 150] -> 
             RGBColor[
              0.871301943093316, 0.4710709613159703, 0.2128466086647302], 
             UndirectedEdge[142, 198] -> 
             RGBColor[
              0.8972633266176216, 0.6021081538364577, 0.5605609698520013], 
             UndirectedEdge[34, 52] -> 
             RGBColor[
              0.1912130018306219, 0.3183073669014913, 0.934200669628743], 
             UndirectedEdge[13, 251] -> 
             RGBColor[
              0.3094480150189227, 0.44031071835692515`, 0.9410170631920465], 
             UndirectedEdge[120, 188] -> 
             RGBColor[
              0.317477361422549, 0.44666279511939655`, 0.9415507479684607], 
             UndirectedEdge[67, 173] -> 
             RGBColor[
              0.1901069718936137, 0.3171448593113474, 0.934137682860055], 
             UndirectedEdge[20, 280] -> 
             RGBColor[
              0.24050854139809294`, 0.3701201045046333, 0.9370079776808949], 
             UndirectedEdge[32, 107] -> 
             RGBColor[
              0.6980757286113448, 0.7586971466019095, 0.9005750351374335], 
             UndirectedEdge[189, 287] -> 
             RGBColor[
              0.22941840696730975`, 0.35846367006274493`, 0.9363764109314454],
              UndirectedEdge[159, 205] -> 
             RGBColor[
              0.33180025652813283`, 0.4601919629512097, 0.9424222571493942], 
             UndirectedEdge[66, 86] -> 
             RGBColor[
              0.49025940765542825`, 0.5952351366581299, 0.9535166371045274], 
             UndirectedEdge[119, 266] -> 
             RGBColor[
              0.1895006672172379, 0.3165075946545396, 0.9341031547056828], 
             UndirectedEdge[28, 230] -> 
             RGBColor[
              0.1877777818287943, 0.3146967328740425, 0.9340050389315915], 
             UndirectedEdge[83, 142] -> 
             RGBColor[
              0.8382440889794911, 0.2949664033288275, 0.18425588883826852`], 
             UndirectedEdge[191, 217] -> 
             RGBColor[
              0.21370747825416658`, 0.3419504878548173, 0.9354816967834682], 
             UndirectedEdge[43, 233] -> 
             RGBColor[
              0.2154911007768475, 0.3438251882143545, 0.9355832714475019], 
             UndirectedEdge[113, 297] -> 
             RGBColor[
              0.22981287868159825`, 0.35887828484541334`, 0.9363988755120056],
              UndirectedEdge[158, 207] -> 
             RGBColor[
              0.189116703595207, 0.3161040245430854, 0.9340812885454315], 
             UndirectedEdge[40, 201] -> 
             RGBColor[
              0.7672988678714465, 0.5534238485768511, 0.5803670192604423], 
             UndirectedEdge[194, 226] -> 
             RGBColor[
              0.8361313395314567, 0.8716084988779389, 0.9233783108429527], 
             UndirectedEdge[134, 230] -> 
             RGBColor[
              0.21844228820343148`, 0.34692707331578443`, 0.9357513372055553],
              UndirectedEdge[134, 264] -> 
             RGBColor[
              0.27050450497484707`, 0.4016477640777385, 0.9387162034315397], 
             UndirectedEdge[59, 226] -> 
             RGBColor[
              0.9856324112421679, 0.988326647065517, 0.887771658052475], 
             UndirectedEdge[42, 201] -> 
             RGBColor[
              0.8414844134036068, 0.31987295677179683`, 0.18735882716622465`],
              UndirectedEdge[217, 295] -> 
             RGBColor[
              0.19848052761044668`, 0.32594599728383544`, 0.9346145444705631],
              UndirectedEdge[45, 94] -> 
             RGBColor[
              0.5484117816822776, 0.636917841037437, 0.9603911500045271], 
             UndirectedEdge[197, 254] -> 
             RGBColor[
              0.6525617744919028, 0.7195772493628625, 0.9087750915707931], 
             UndirectedEdge[30, 189] -> 
             RGBColor[
              0.23256614809149867`, 0.36177214556258186`, 0.9365556701318023],
              UndirectedEdge[92, 179] -> 
             RGBColor[
              0.6771557268529196, 0.4334926321296493, 0.5667112930910556], 
             UndirectedEdge[134, 288] -> 
             RGBColor[
              0.22683219740980134`, 0.35574539984264686`, 0.9362291301230996],
              UndirectedEdge[59, 83] -> 
             RGBColor[
              0.9157801358545465, 0.6734487289604354, 0.5451685443334997], 
             UndirectedEdge[10, 22] -> 
             RGBColor[
              0.18947218593303478`, 0.31647765901902436`, 0.9341015327386817],
              UndirectedEdge[148, 168] -> 
             RGBColor[
              0.32335433659993124`, 0.4487211935569434, 0.9420362378816867], 
             UndirectedEdge[130, 216] -> 
             RGBColor[
              0.889133450052471, 0.5872803968126434, 0.22908968289478807`], 
             UndirectedEdge[158, 196] -> 
             RGBColor[
              0.1980026870183727, 0.32544375652472224`, 0.9345873321557463], 
             UndirectedEdge[203, 237] -> 
             RGBColor[
              0.8810998777201378, 0.5731845028928206, 0.5814799153304782], 
             UndirectedEdge[160, 193] -> 
             RGBColor[
              0.23766407621559904`, 0.36713039124832314`, 0.9368459895967611],
              UndirectedEdge[38, 88] -> 
             RGBColor[
              0.20448897001762012`, 0.33226125121102634`, 0.9349567163769577],
              UndirectedEdge[22, 73] -> 
             RGBColor[
              0.1856051226212358, 0.3124131302923484, 0.9338813092038822], 
             UndirectedEdge[181, 227] -> 
             RGBColor[
              0.9694992257478029, 0.9078122736758734, 0.34102909604815745`], 
             UndirectedEdge[85, 255] -> 
             RGBColor[
              0.2990831810082368, 0.42639058870879876`, 0.9405375990810403], 
             UndirectedEdge[106, 227] -> 
             RGBColor[
              0.907282547148933, 0.8714421765894653, 0.6337446762316135], 
             UndirectedEdge[131, 261] -> 
             RGBColor[
              0.23707213530482818`, 0.36650822381988146`, 0.9368122794375908],
              UndirectedEdge[81, 94] -> 
             RGBColor[
              0.8431768541892217, 0.7161112955984645, 0.6049346124449686], 
             UndirectedEdge[77, 154] -> 
             RGBColor[
              0.455540153481848, 0.5677935680255081, 0.950577540756124], 
             UndirectedEdge[167, 277] -> 
             RGBColor[
              0.9503466052484179, 0.8295784884211206, 0.3626330239957771], 
             UndirectedEdge[113, 176] -> 
             RGBColor[
              0.23091262265844142`, 0.3600341854928709, 0.9364615043045614], 
             UndirectedEdge[4, 276] -> 
             RGBColor[
              0.23095575836688206`, 0.36007952385740394`, 0.9364639608193436],
              UndirectedEdge[101, 243] -> 
             RGBColor[
              0.8173727655187092, 0.8567408344553589, 0.91183562312612], 
             UndirectedEdge[52, 271] -> 
             RGBColor[
              0.21068413741610115`, 0.3387727649431298, 0.9353095219953723], 
             UndirectedEdge[37, 71] -> 
             RGBColor[
              0.22494256325409756`, 0.3537592745352769, 0.9361215182533955], 
             UndirectedEdge[83, 291] -> 
             RGBColor[
              0.8867137047505624, 0.6516789960865967, 0.5925497284900865], 
             UndirectedEdge[80, 149] -> 
             RGBColor[
              0.9371561077922606, 0.7792834728078644, 0.30334662593416606`], 
             UndirectedEdge[104, 206] -> 
             RGBColor[
              0.2787552105581772, 0.4078842978745366, 0.9392752437947942], 
             UndirectedEdge[61, 108] -> 
             RGBColor[
              0.25897235282054676`, 0.38952674098289125`, 0.9380594644266425],
              UndirectedEdge[115, 264] -> 
             RGBColor[
              0.32396934415914475`, 0.453868652264371, 0.9419064562812274], 
             UndirectedEdge[38, 52] -> 
             RGBColor[
              0.19242626978916738`, 0.3195825884515542, 0.934269763444113], 
             UndirectedEdge[33, 285] -> 
             RGBColor[
              0.20009304762604624`, 0.3276408580599046, 0.934706375099942], 
             UndirectedEdge[100, 122] -> 
             RGBColor[
              0.18285159839459103`, 0.3095190017466254, 0.933724500072649], 
             UndirectedEdge[205, 269] -> 
             RGBColor[
              0.6727623053020111, 0.7090410207196602, 0.647599267278013], 
             UndirectedEdge[177, 252] -> 
             RGBColor[
              0.2649570005472917, 0.39581698519228203`, 0.9384002812611878], 
             UndirectedEdge[152, 244] -> 
             RGBColor[
              0.1860116480511821, 0.312840414294423, 0.9339044602257174], 
             UndirectedEdge[10, 71] -> 
             RGBColor[
              0.20685989156236995`, 0.3347532400796667, 0.9350917368514671], 
             UndirectedEdge[233, 259] -> 
             RGBColor[
              0.1952784533382303, 0.32258041420050104`, 0.9344321910778048], 
             UndirectedEdge[130, 299] -> 
             RGBColor[
              0.8652485405177199, 0.41636555627617133`, 0.20671378935182633`],
              UndirectedEdge[81, 86] -> 
             RGBColor[
              0.7418209808035544, 0.6361932312179576, 0.5953370394744854], 
             UndirectedEdge[205, 282] -> 
             RGBColor[
              0.40649592976024684`, 0.5265080761040026, 0.947122539087454], 
             UndirectedEdge[176, 297] -> 
             RGBColor[
              0.19309289409094996`, 0.3202832528591496, 0.9343077267119173], 
             UndirectedEdge[92, 128] -> 
             RGBColor[
              0.838247472010956, 0.29499240679111977`, 0.18425912843301978`], 
             UndirectedEdge[166, 285] -> 
             RGBColor[
              0.19288702957547718`, 0.3200668762008235, 0.9342960030323104], 
             UndirectedEdge[132, 146] -> 
             RGBColor[
              0.19846266788634026`, 0.3259272255814276, 0.9346135273856964], 
             UndirectedEdge[81, 130] -> 
             RGBColor[
              0.9006340382989853, 0.6395018820094367, 0.23868605563289352`], 
             UndirectedEdge[1, 128] -> 
             RGBColor[
              0.8318168299406954, 0.24556367391377373`, 0.17810113832416685`],
              UndirectedEdge[296, 297] -> 
             RGBColor[
              0.18960014391301738`, 0.31661215096899065`, 0.934108819756345], 
             UndirectedEdge[128, 237] -> 
             RGBColor[
              0.8350074590728989, 0.27008824756648975`, 0.18115648838446502`],
              UndirectedEdge[112, 146] -> 
             RGBColor[
              0.19463017997348525`, 0.32189903779124873`, 0.934395272868717], 
             UndirectedEdge[116, 287] -> 
             RGBColor[
              0.2651763885560936, 0.39604757589953593`, 0.9384127750837334], 
             UndirectedEdge[10, 266] -> 
             RGBColor[
              0.19427634422620857`, 0.3215271339863788, 0.9343751224463628], 
             UndirectedEdge[16, 76] -> 
             RGBColor[
              0.286854066125812, 0.4171520866149722, 0.9397088035477686], 
             UndirectedEdge[23, 72] -> 
             RGBColor[
              0.909381055653747, 0.6084841231487159, 0.5010093036534974], 
             UndirectedEdge[237, 277] -> 
             RGBColor[
              0.9090429254562429, 0.5906001950667261, 0.32616694372814004`], 
             UndirectedEdge[56, 278] -> 
             RGBColor[
              0.1999933373080916, 0.327536056193735, 0.9347006967448426], 
             UndirectedEdge[88, 274] -> 
             RGBColor[
              0.342952508633553, 0.4632649151839602, 0.9434373496862328], 
             UndirectedEdge[103, 282] -> 
             RGBColor[
              0.4309808924132613, 0.5477157201040381, 0.9486826992565017], 
             UndirectedEdge[46, 60] -> 
             RGBColor[
              0.2459880706675731, 0.3758794371890788, 0.9373200287665547], 
             UndirectedEdge[82, 216] -> 
             RGBColor[
              0.7399516836581952, 0.5917908620218015, 0.5864988772524447], 
             UndirectedEdge[48, 70] -> 
             RGBColor[
              0.2012898575043234, 0.328898781124103, 0.9347745316519882], 
             UndirectedEdge[143, 174] -> 
             RGBColor[
              0.27004966377854045`, 0.4011696971418227, 0.9386903008982872], 
             UndirectedEdge[95, 205] -> 
             RGBColor[
              0.32995805051825455`, 0.4582556876322203, 0.9423173462424312], 
             UndirectedEdge[78, 190] -> 
             RGBColor[
              0.19927294772660503`, 0.32677888106825503`, 0.9346596716238978],
              UndirectedEdge[68, 292] -> 
             RGBColor[
              0.8252860920096456, 0.8638987146846454, 0.9830984780135097], 
             UndirectedEdge[145, 269] -> 
             RGBColor[
              0.9190343803618738, 0.908127960055847, 0.6686138108252507], 
             UndirectedEdge[198, 254] -> 
             RGBColor[
              0.6416864490274542, 0.7118235947085315, 0.9431778757394982], 
             UndirectedEdge[124, 147] -> 
             RGBColor[
              0.19966110992932296`, 0.3271868641542167, 0.9346817768871081], 
             UndirectedEdge[44, 194] -> 
             RGBColor[
              0.5011124283287507, 0.6014735099165995, 0.9553542362124354], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.3434646997755016, 0.4661397793633797, 0.9433176524403382], 
             UndirectedEdge[5, 11] -> 
             RGBColor[
              0.7514137479791486, 0.7723356879656991, 0.6490878757769967], 
             UndirectedEdge[108, 254] -> 
             RGBColor[
              0.27973365180931276`, 0.4104203008650652, 0.9392757639847461], 
             UndirectedEdge[61, 71] -> 
             RGBColor[
              0.25028804221449197`, 0.3803989799188331, 0.9375649057849139], 
             UndirectedEdge[229, 284] -> 
             RGBColor[
              0.22933503139451644`, 0.3583760370494225, 0.936371662815918], 
             UndirectedEdge[37, 136] -> 
             RGBColor[
              0.309591888135542, 0.4349767741872242, 0.9412260952746828], 
             UndirectedEdge[148, 159] -> 
             RGBColor[
              0.26876902654338763`, 0.39982366621058674`, 0.9386173705022783],
              UndirectedEdge[164, 230] -> 
             RGBColor[
              0.1870233298629817, 0.313903756022956, 0.9339620740082502], 
             UndirectedEdge[176, 193] -> 
             RGBColor[
              0.23687819251132788`, 0.36630437764722934`, 0.9368012346824135],
              UndirectedEdge[216, 299] -> 
             RGBColor[
              0.8425788083187902, 0.31560991507508496`, 0.1879104981712836], 
             UndirectedEdge[149, 277] -> 
             RGBColor[
              0.9442574972371908, 0.8029244899485575, 0.3576036046538991], 
             UndirectedEdge[39, 248] -> 
             RGBColor[
              0.21184147363468755`, 0.3399891986882186, 0.9353754305808952], 
             UndirectedEdge[13, 137] -> 
             RGBColor[
              0.2974114508687985, 0.42765952627289927`, 0.9403315986701979], 
             UndirectedEdge[68, 75] -> 
             RGBColor[
              0.6048929892039929, 0.6837170469414527, 0.9652757515328931], 
             UndirectedEdge[66, 97] -> 
             RGBColor[
              0.4175999543798127, 0.5361258241249656, 0.9478300777173092], 
             UndirectedEdge[59, 106] -> 
             RGBColor[
              0.9234341463667425, 0.9403782883321993, 0.9424056010083017], 
             UndirectedEdge[51, 198] -> 
             RGBColor[
              0.8879439008384149, 0.9128115493875727, 0.9633242059952494], 
             UndirectedEdge[193, 228] -> 
             RGBColor[
              0.35291040472918833`, 0.4773968889253306, 0.9438069074260627], 
             UndirectedEdge[30, 287] -> 
             RGBColor[
              0.24614870075893425`, 0.37604826959963533`, 0.9373291764126268],
              UndirectedEdge[93, 147] -> 
             RGBColor[
              0.22726390844905786`, 0.3561991555169663, 0.936253715428126], 
             UndirectedEdge[69, 121] -> 
             RGBColor[
              0.21650915427912054`, 0.3448952269935637, 0.9356412480883811], 
             UndirectedEdge[148, 251] -> 
             RGBColor[
              0.26595227173522773`, 0.39686307831464074`, 0.9384569604829689],
              UndirectedEdge[125, 269] -> 
             RGBColor[
              0.904179684947735, 0.5963333758276583, 0.2657933486023245], 
             UndirectedEdge[37, 44] -> 
             RGBColor[
              0.27139379762507876`, 0.4018915080789134, 0.9387921467246012], 
             UndirectedEdge[91, 105] -> 
             RGBColor[
              0.38699951220692347`, 0.5063182366232937, 0.9462409477627431], 
             UndirectedEdge[81, 203] -> 
             RGBColor[
              0.9132949931047244, 0.7717981514907339, 0.6103970678254644], 
             UndirectedEdge[8, 69] -> 
             RGBColor[
              0.2060185451131012, 0.33386893161703934`, 0.9350438234158418], 
             UndirectedEdge[52, 270] -> 
             RGBColor[
              0.20578610160522076`, 0.3336246187524874, 0.9350305861019373], 
             UndirectedEdge[108, 268] -> 
             RGBColor[
              0.2228674989167732, 0.351578250350071, 0.9360033464091675], 
             UndirectedEdge[11, 254] -> 
             RGBColor[
              0.4252983225505378, 0.5406623913243694, 0.9489095154684506], 
             UndirectedEdge[82, 255] -> 
             RGBColor[
              0.489728760692208, 0.5942524926612631, 0.9536273379129792], 
             UndirectedEdge[43, 66] -> 
             RGBColor[
              0.3059641689064351, 0.4317438620573953, 0.9409982635304203], 
             UndirectedEdge[252, 283] -> 
             RGBColor[
              0.27188152915805053`, 0.4030951038026612, 0.9387946229216484], 
             UndirectedEdge[99, 215] -> 
             RGBColor[
              0.21020795705683448`, 0.338272269193962, 0.9352824042283578], 
             UndirectedEdge[114, 283] -> 
             RGBColor[
              0.2724764193926355, 0.4037203711574294, 0.9388285010404467], 
             UndirectedEdge[24, 194] -> 
             RGBColor[
              0.8048847779464043, 0.7450443793025796, 0.6134276095233945], 
             UndirectedEdge[134, 228] -> 
             RGBColor[
              0.3355280602689666, 0.4591269427933443, 0.9428170086239273], 
             UndirectedEdge[49, 143] -> 
             RGBColor[
              0.2582581828615999, 0.38877610307504745`, 0.9380187935040003], 
             UndirectedEdge[123, 189] -> 
             RGBColor[
              0.2072195140090381, 0.335131226072495, 0.935112216817791], 
             UndirectedEdge[232, 240] -> 
             RGBColor[
              0.184219115333836, 0.3109563487553536, 0.933802378139279], 
             UndirectedEdge[11, 243] -> 
             RGBColor[
              0.7596161582091865, 0.8099275378271904, 0.907236768390906], 
             UndirectedEdge[155, 210] -> 
             RGBColor[
              0.698996444284087, 0.6637676396684864, 0.6055600185754992], 
             UndirectedEdge[148, 156] -> 
             RGBColor[
              0.32039438822353183`, 0.44615743504463745`, 0.9418476325885221],
              UndirectedEdge[15, 212] -> 
             RGBColor[
              0.24587235329600743`, 0.3757578108946581, 0.9373134388334325], 
             UndirectedEdge[51, 204] -> 
             RGBColor[
              0.647452541380158, 0.7220822556308867, 0.967158350930859], 
             UndirectedEdge[95, 156] -> 
             RGBColor[
              0.3410239560220559, 0.4678404187910305, 0.9430224559559374], 
             UndirectedEdge[87, 109] -> 
             RGBColor[
              0.9929796059139886, 0.9895239708410322, 0.632193448669364], 
             UndirectedEdge[113, 288] -> 
             RGBColor[
              0.23824897201713657`, 0.3677451538202748, 0.9368792985473828], 
             UndirectedEdge[164, 176] -> 
             RGBColor[
              0.1880768897106564, 0.3150111142224146, 0.9340220726829731], 
             UndirectedEdge[17, 294] -> 
             RGBColor[
              0.6198562799736641, 0.7013271769000424, 0.963858572100545], 
             UndirectedEdge[77, 212] -> 
             RGBColor[
              0.32357566422601636`, 0.4477175574235364, 0.9420941078985701], 
             UndirectedEdge[180, 296] -> 
             RGBColor[
              0.19104587171588, 0.3181317025542363, 0.9341911518159554], 
             UndirectedEdge[217, 271] -> 
             RGBColor[
              0.21133673112817714`, 0.3394586823113528, 0.9353466862418491], 
             UndirectedEdge[4, 85] -> 
             RGBColor[
              0.2263430797542824, 0.3552313061748459, 0.9362012755962026], 
             UndirectedEdge[95, 127] -> 
             RGBColor[
              0.3181958172626126, 0.4480678323732162, 0.9415678671403162], 
             UndirectedEdge[54, 75] -> 
             RGBColor[
              0.2884831291269512, 0.41830852004459096`, 0.9398219273882558], 
             UndirectedEdge[134, 193] -> 
             RGBColor[
              0.26218140249464095`, 0.39289965565586527`, 0.9382422150582186],
              UndirectedEdge[40, 178] -> 
             RGBColor[
              0.4741224882012588, 0.573360769660643, 0.953860855337124], 
             UndirectedEdge[69, 239] -> 
             RGBColor[
              0.22257247692189291`, 0.35126816352797696`, 0.935986545343005], 
             UndirectedEdge[134, 200] -> 
             RGBColor[
              0.3051846864517926, 0.4328450374952205, 0.9408835556758889], 
             UndirectedEdge[89, 141] -> 
             RGBColor[
              0.33729605784908523`, 0.4651931821113565, 0.9427636193772146], 
             UndirectedEdge[38, 147] -> 
             RGBColor[
              0.1997586179230488, 0.3272893512379864, 0.9346873298231007], 
             UndirectedEdge[170, 182] -> 
             RGBColor[
              0.2259600378398488, 0.3548287048365162, 0.9361794619258352], 
             UndirectedEdge[94, 120] -> 
             RGBColor[
              0.5379895613183256, 0.6259634266279861, 0.9597976199730934], 
             UndirectedEdge[80, 269] -> 
             RGBColor[
              0.9759866531723878, 0.9306594839278095, 0.36121311142511225`], 
             UndirectedEdge[263, 286] -> 
             RGBColor[
              0.2153900069518347, 0.3437189321945473, 0.9355775143037223], 
             UndirectedEdge[130, 140] -> 
             RGBColor[
              0.8645610911257005, 0.4110815190068649, 0.2060554870376654], 
             UndirectedEdge[25, 288] -> 
             RGBColor[
              0.19999048340527747`, 0.32753305656092946`, 0.9347005342192993],
              UndirectedEdge[148, 191] -> 
             RGBColor[
              0.23683698231576478`, 0.36626106311881523`, 0.9367988878227413],
              UndirectedEdge[177, 268] -> 
             RGBColor[
              0.24851062539069607`, 0.37853080214228807`, 0.9374636845262513],
              UndirectedEdge[69, 126] -> 
             RGBColor[
              0.21552861209731056`, 0.34386461499051624`, 0.9355854076617092],
              UndirectedEdge[20, 37] -> 
             RGBColor[
              0.22278622542452461`, 0.3514928267566807, 0.9359987180040172], 
             UndirectedEdge[3, 72] -> 
             RGBColor[
              0.8918169128751087, 0.5962411896945986, 0.5690910592091327], 
             UndirectedEdge[87, 154] -> 
             RGBColor[
              0.7452228320173793, 0.7952601643437132, 0.7245769752264782], 
             UndirectedEdge[11, 204] -> 
             RGBColor[
              0.5077115751599948, 0.6112221547175201, 0.9543880614868259], 
             UndirectedEdge[55, 268] -> 
             RGBColor[
              0.20359322925377082`, 0.3313197708749761, 0.9349057052655861], 
             UndirectedEdge[125, 142] -> 
             RGBColor[
              0.8325650320679996, 0.2513146833284968, 0.1788176175262468], 
             UndirectedEdge[176, 221] -> 
             RGBColor[
              0.1901941228796547, 0.3172364605233681, 0.9341426459797817], 
             UndirectedEdge[29, 182] -> 
             RGBColor[
              0.224799401299116, 0.35360880224359903`, 0.9361133653918483], 
             UndirectedEdge[122, 161] -> 
             RGBColor[
              0.19334750398760153`, 0.32055086400373023`, 0.9343222263688701],
              UndirectedEdge[44, 226] -> 
             RGBColor[
              0.6512382253914439, 0.7184499980919314, 0.9093942676022314], 
             UndirectedEdge[89, 131] -> 
             RGBColor[
              0.3050760854207314, 0.4313279482249144, 0.9409287396125976], 
             UndirectedEdge[56, 110] -> 
             RGBColor[
              0.1926369557700678, 0.31980403277574326`, 0.9342817616990433], 
             UndirectedEdge[43, 178] -> 
             RGBColor[
              0.24229896140308743`, 0.37200194944906734`, 0.9371099394514903],
              UndirectedEdge[66, 162] -> 
             RGBColor[
              0.6888450125107997, 0.7498709206605213, 0.8694416515926326], 
             UndirectedEdge[5, 142] -> 
             RGBColor[
              0.9004741399785186, 0.5724923933279508, 0.25909492907778175`], 
             UndirectedEdge[147, 273] -> 
             RGBColor[
              0.22616395243467474`, 0.35504303200461024`, 0.9361910745603459],
              UndirectedEdge[81, 167] -> 
             RGBColor[
              0.8985734587541578, 0.6313323707616247, 0.23702806496310708`], 
             UndirectedEdge[95, 212] -> 
             RGBColor[
              0.2604625119164363, 0.3910929926742148, 0.9381443267826606], 
             UndirectedEdge[56, 217] -> 
             RGBColor[
              0.19969746831988144`, 0.32722507912794885`, 0.934683847443663], 
             UndirectedEdge[6, 93] -> 
             RGBColor[
              0.2258625386311459, 0.35472622698636247`, 0.9361739094901367], 
             UndirectedEdge[131, 146] -> 
             RGBColor[
              0.2147184255833614, 0.3430130575955638, 0.9355392687383033], 
             UndirectedEdge[7, 80] -> 
             RGBColor[
              0.9585640473109542, 0.9468487152511682, 0.6807339798518178], 
             UndirectedEdge[76, 239] -> 
             RGBColor[
              0.28224692267200363`, 0.41230968673525326`, 0.9394464335437323],
              UndirectedEdge[148, 278] -> 
             RGBColor[
              0.2234636176615972, 0.35220480894699246`, 0.9360372944898065], 
             UndirectedEdge[29, 170] -> 
             RGBColor[
              0.19641582947302122`, 0.3237758686319784, 0.934496962966084], 
             UndirectedEdge[147, 289] -> 
             RGBColor[
              0.22842117185433053`, 0.35741551273064565`, 0.9363196198670385],
              UndirectedEdge[25, 28] -> 
             RGBColor[
              0.18729283765525817`, 0.3141870258004196, 0.9339774220783192], 
             UndirectedEdge[5, 149] -> 
             RGBColor[
              0.933258247478127, 0.766135074707167, 0.2882041746629133], 
             UndirectedEdge[140, 202] -> 
             RGBColor[
              0.8419448678170631, 0.3105688491792778, 0.18729684498680563`], 
             UndirectedEdge[10, 63] -> 
             RGBColor[
              0.18664280478053893`, 0.31350380003462497`, 0.9339404036677414],
              UndirectedEdge[43, 259] -> 
             RGBColor[
              0.20537394232393572`, 0.33319141321544904`, 0.9350071142406031],
              UndirectedEdge[21, 50] -> 
             RGBColor[
              0.18770061499905671`, 0.31461562564332873`, 0.9340006443947961],
              UndirectedEdge[87, 155] -> 
             RGBColor[
              0.959730943798982, 0.866659323879206, 0.37757715104669176`], 
             UndirectedEdge[127, 282] -> 
             RGBColor[
              0.3947336965046049, 0.5163202208449985, 0.9463730599853389], 
             UndirectedEdge[79, 144] -> 
             RGBColor[
              0.1903903758627761, 0.31744273485178653`, 0.9341538222968402], 
             UndirectedEdge[54, 298] -> 
             RGBColor[
              0.25208733908179476`, 0.3822901550083788, 0.9376673730796856], 
             UndirectedEdge[234, 263] -> 
             RGBColor[
              0.20202221841831886`, 0.32966853887907605`, 0.9348162385226094],
              UndirectedEdge[34, 38] -> 
             RGBColor[
              0.18490621443215238`, 0.31167853347228314`, 0.9338415074164561],
              UndirectedEdge[39, 85] -> 
             RGBColor[
              0.21693635514660192`, 0.345344242191386, 0.9356655765457971], 
             UndirectedEdge[20, 108] -> 
             RGBColor[
              0.2298448182232575, 0.3589118553287811, 0.9364006944216527], 
             UndirectedEdge[94, 201] -> 
             RGBColor[
              0.8211264532079356, 0.595474367346517, 0.5857320499193991], 
             UndirectedEdge[260, 294] -> 
             RGBColor[
              0.39710848893487455`, 0.5114544721894022, 0.9473162764842546], 
             UndirectedEdge[138, 266] -> 
             RGBColor[
              0.21471877848996196`, 0.3430134285227765, 0.935539288835812], 
             UndirectedEdge[127, 168] -> 
             RGBColor[
              0.3746233333290345, 0.4989016350385623, 0.9450916454266876], 
             UndirectedEdge[128, 198] -> 
             RGBColor[
              0.9047656578317846, 0.6597743590910152, 0.567745210695355], 
             UndirectedEdge[145, 216] -> 
             RGBColor[
              0.8656837903388712, 0.6908198174551905, 0.5986314441654264], 
             UndirectedEdge[141, 182] -> 
             RGBColor[
              0.2740956905180802, 0.4054223277779909, 0.9389207161355438], 
             UndirectedEdge[41, 252] -> 
             RGBColor[
              0.21326847287064163`, 0.3414890653621836, 0.9354566960763266], 
             UndirectedEdge[55, 208] -> 
             RGBColor[
              0.19572673330134732`, 0.32305158486432833`, 0.9344577199585336],
              UndirectedEdge[121, 249] -> 
             RGBColor[
              0.21645306950395798`, 0.3448362783388877, 0.9356380541434055], 
             UndirectedEdge[89, 120] -> 
             RGBColor[
              0.3299173264663655, 0.4574376675895273, 0.9423434115408236], 
             UndirectedEdge[32, 142] -> 
             RGBColor[
              0.9088058774056695, 0.6101377233090057, 0.5151005353474709], 
             UndirectedEdge[7, 77] -> 
             RGBColor[
              0.6760511895639363, 0.7431695037981105, 0.9684398535409274], 
             UndirectedEdge[45, 146] -> 
             RGBColor[
              0.24998188699294738`, 0.3800771913696276, 0.937547470697963], 
             UndirectedEdge[110, 223] -> 
             RGBColor[
              0.18370379552866184`, 0.31041471496695283`, 0.9337730314387216],
              UndirectedEdge[225, 276] -> 
             RGBColor[
              0.23448523874767882`, 0.3637892315196025, 0.9366649595056316], 
             UndirectedEdge[65, 291] -> 
             RGBColor[
              0.6521691058057041, 0.7229451944590042, 0.9690799766899112], 
             UndirectedEdge[194, 290] -> 
             RGBColor[
              0.8162082398567924, 0.7899381324572718, 0.622538732772305], 
             UndirectedEdge[154, 258] -> 
             RGBColor[
              0.4187295668061743, 0.5359100880009214, 0.9482320027234739], 
             UndirectedEdge[31, 280] -> 
             RGBColor[
              0.3408307300134504, 0.46531138731317084`, 0.9430966160299905], 
             UndirectedEdge[156, 271] -> 
             RGBColor[
              0.3085633706783219, 0.433722285474784, 0.9411738736417443], 
             UndirectedEdge[83, 241] -> 
             RGBColor[
              0.9163383963463205, 0.6736795840204242, 0.5359167232529631], 
             UndirectedEdge[208, 268] -> 
             RGBColor[
              0.19718303522223768`, 0.3245822505180589, 0.9345406541985226], 
             UndirectedEdge[1, 80] -> 
             RGBColor[
              0.8987509068791093, 0.542434604273317, 0.26885461494810886`], 
             UndirectedEdge[116, 206] -> 
             RGBColor[
              0.2548872111619892, 0.3852329980868062, 0.9378268216526131], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.22364840280037163`, 0.35239902984389887`, 0.9360478177300946],
              UndirectedEdge[108, 204] -> 
             RGBColor[
              0.36214690441876973`, 0.48098006425821577`, 0.9447543100031214],
              UndirectedEdge[251, 271] -> 
             RGBColor[
              0.25412125419001774`, 0.38442792874478726`, 0.9377832015361911],
              UndirectedEdge[6, 38] -> 
             RGBColor[
              0.19835724810513683`, 0.32581642270738265`, 0.9346075238851115],
              UndirectedEdge[135, 158] -> 
             RGBColor[
              0.20301108119461975`, 0.33070789635448955`, 0.9348725527948284],
              UndirectedEdge[25, 180] -> 
             RGBColor[
              0.1930001178726018, 0.32018573917131365`, 0.9343024432435325], 
             UndirectedEdge[57, 217] -> 
             RGBColor[
              0.18985695379830947`, 0.3168820744411198, 0.9341234446993961], 
             UndirectedEdge[71, 136] -> 
             RGBColor[
              0.3079661703282201, 0.43326804169526645`, 0.9411335130505898], 
             UndirectedEdge[135, 173] -> 
             RGBColor[
              0.20718172638991203`, 0.3350915088889201, 0.9351100648687836], 
             UndirectedEdge[143, 235] -> 
             RGBColor[
              0.3576942027971, 0.4840672946486393, 0.9440192038790169], 
             UndirectedEdge[264, 288] -> 
             RGBColor[
              0.2525376443502292, 0.38276345439650644`, 0.937693017298556], 
             UndirectedEdge[223, 247] -> 
             RGBColor[
              0.18962339324408597`, 0.3166365874900364, 0.934110143771355], 
             UndirectedEdge[191, 225] -> 
             RGBColor[
              0.22748667103589795`, 0.35643329311969896`, 0.9362664014278987],
              UndirectedEdge[1, 243] -> 
             RGBColor[
              0.9030554567950135, 0.5668780560341109, 0.5118610562907654], 
             UndirectedEdge[29, 284] -> 
             RGBColor[
              0.21810645410068208`, 0.3465740903806829, 0.9357322119502256], 
             UndirectedEdge[6, 273] -> 
             RGBColor[
              0.22476258261676274`, 0.3535701034740064, 0.9361112686223567], 
             UndirectedEdge[103, 276] -> 
             RGBColor[
              0.33135174266530537`, 0.4551929422593771, 0.9425624927166377], 
             UndirectedEdge[99, 199] -> 
             RGBColor[
              0.19703448061371565`, 0.32442611020559603`, 0.9345321942333341],
              UndirectedEdge[35, 129] -> 
             RGBColor[
              0.19774057513237292`, 0.32516826031368307`, 0.9345724052715985],
              UndirectedEdge[77, 145] -> 
             RGBColor[
              0.6393432778876973, 0.7139671917177287, 0.9672816709055783], 
             UndirectedEdge[72, 155] -> 
             RGBColor[
              0.8778646469488878, 0.4863358074888676, 0.21768508409656526`], 
             UndirectedEdge[20, 44] -> 
             RGBColor[
              0.26761174198818394`, 0.3979163278083595, 0.93857676425113], 
             UndirectedEdge[131, 178] -> 
             RGBColor[
              0.2442095797785655, 0.3740101305018966, 0.9372187463414672], 
             UndirectedEdge[106, 241] -> 
             RGBColor[
              0.9239924068585166, 0.940609143392188, 0.9331537799277652], 
             UndirectedEdge[85, 286] -> 
             RGBColor[
              0.2265196157319883, 0.3554168566804423, 0.9362113290589713], 
             UndirectedEdge[86, 261] -> 
             RGBColor[
              0.41945675567834323`, 0.5279913173677868, 0.949221846121721], 
             UndirectedEdge[256, 269] -> 
             RGBColor[
              0.8955465010984967, 0.5299749416771264, 0.25752620199850723`], 
             UndirectedEdge[37, 61] -> 
             RGBColor[
              0.25191376002181387`, 0.38210771241079083`, 0.937657488009007], 
             UndirectedEdge[73, 244] -> 
             RGBColor[
              0.18608629156364545`, 0.31291886935869395`, 0.9339087110633268],
              UndirectedEdge[180, 193] -> 
             RGBColor[
              0.23722417633734735`, 0.3666680285850174, 0.9368209379494682], 
             UndirectedEdge[8, 213] -> 
             RGBColor[
              0.20342164602247398`, 0.3311394260198779, 0.9348959338543985], 
             UndirectedEdge[48, 138] -> 
             RGBColor[
              0.21204884540564534`, 0.34020715956762493`, 0.9353872400964722],
              UndirectedEdge[170, 284] -> 
             RGBColor[
              0.2192670906414149, 0.34779399297360003`, 0.9357983084842125], 
             UndirectedEdge[55, 219] -> 
             RGBColor[
              0.19323553565117518`, 0.3204331781829436, 0.9343158499377529], 
             UndirectedEdge[111, 235] -> 
             RGBColor[
              0.5113487817124779, 0.61295792200517, 0.9550106787741928], 
             UndirectedEdge[56, 247] -> 
             RGBColor[
              0.19855655348549195`, 0.3260259052988269, 0.9346188740316768], 
             UndirectedEdge[7, 82] -> 
             RGBColor[
              0.7758796678197641, 0.8252882359458167, 0.9760021123389747], 
             UndirectedEdge[182, 190] -> 
             RGBColor[
              0.22937905061187158`, 0.35842230403784237`, 0.9363741696452258],
              UndirectedEdge[113, 228] -> 
             RGBColor[
              0.34694483487630184`, 0.4711266967709722, 0.9434671770482106], 
             UndirectedEdge[133, 146] -> 
             RGBColor[
              0.19265917133132254`, 0.3198273827391699, 0.9342830268423918], 
             UndirectedEdge[93, 274] -> 
             RGBColor[
              0.3520883115326398, 0.4728672232742597, 0.9439576201461266], 
             UndirectedEdge[153, 220] -> 
             RGBColor[
              0.27707930337293885`, 0.40630757672797435`, 0.9391730382607208],
              UndirectedEdge[90, 153] -> 
             RGBColor[
              0.21837262298903565`, 0.3468538507584247, 0.9357473698746558], 
             UndirectedEdge[178, 190] -> 
             RGBColor[
              0.23171291230071078`, 0.36087534064819005`, 0.9365070796157662],
              UndirectedEdge[39, 126] -> 
             RGBColor[
              0.21260629074350712`, 0.3407930699617935, 0.9354189857837971], 
             UndirectedEdge[15, 77] -> 
             RGBColor[
              0.3360793820211845, 0.46085975760775527`, 0.942806176129412], 
             UndirectedEdge[103, 293] -> 
             RGBColor[
              0.6605442022439556, 0.5885330418914387, 0.5930681631412746], 
             UndirectedEdge[92, 269] -> 
             RGBColor[
              0.9023597936765284, 0.5823448940357236, 0.2640506186657438], 
             UndirectedEdge[8, 14] -> 
             RGBColor[
              0.19233103918746458`, 0.31948249505119564`, 0.9342643402022272],
              UndirectedEdge[157, 171] -> 
             RGBColor[
              0.1808430925709541, 0.30740793477935857`, 0.9336101186373109], 
             UndirectedEdge[198, 226] -> 
             RGBColor[
              0.975424098844659, 0.9808488194558194, 0.9111203095275062], 
             UndirectedEdge[86, 169] -> 
             RGBColor[
              0.5994580148931581, 0.6857060476229113, 0.9616106773009028], 
             UndirectedEdge[163, 235] -> 
             RGBColor[
              0.5148221170934733, 0.615777732139438, 0.9552841124586315], 
             UndirectedEdge[31, 136] -> 
             RGBColor[
              0.4061320211140046, 0.526192876725208, 0.9470993511503072], 
             UndirectedEdge[111, 292] -> 
             RGBColor[
              0.6939596467687601, 0.7604145144003427, 0.9704259544749405], 
             UndirectedEdge[48, 122] -> 
             RGBColor[
              0.1889251216320018, 0.3159026597527588, 0.9340703782360471], 
             UndirectedEdge[246, 295] -> 
             RGBColor[
              0.19068631113650653`, 0.3177537815878572, 0.9341706753728822], 
             UndirectedEdge[258, 263] -> 
             RGBColor[
              0.2750253960672227, 0.40349492782139373`, 0.9390800123727585], 
             UndirectedEdge[24, 299] -> 
             RGBColor[
              0.871228956104042, 0.44007591122058254`, 0.21152577211097698`], 
             UndirectedEdge[66, 193] -> 
             RGBColor[
              0.33295274750258996`, 0.46011056933666983`, 0.9425352231554471],
              UndirectedEdge[29, 199] -> 
             RGBColor[
              0.196824977685108, 0.32420590934437654`, 0.9345202633514818], 
             UndirectedEdge[27, 87] -> 
             RGBColor[
              0.9814947768371431, 0.9488415742094825, 0.4164630400439475], 
             UndirectedEdge[164, 180] -> 
             RGBColor[
              0.18842287353667586`, 0.3153747651602027, 0.9340417759500277], 
             UndirectedEdge[106, 200] -> 
             RGBColor[
              0.6137154608562325, 0.6918743175265988, 0.9656005116200483], 
             UndirectedEdge[69, 285] -> 
             RGBColor[
              0.2036242652013759, 0.3313523916237017, 0.9349074727168887], 
             UndirectedEdge[88, 137] -> 
             RGBColor[
              0.242196310039882, 0.3718940563578661, 0.9371040936082149], 
             UndirectedEdge[43, 261] -> 
             RGBColor[
              0.23516151692935008`, 0.3645000427670523, 0.9367034725476139], 
             UndirectedEdge[224, 253] -> 
             RGBColor[
              0.20025883236896588`, 0.32781510833607297`, 0.9347158162957947],
              UndirectedEdge[5, 23] -> 
             RGBColor[
              0.9801796714011944, 0.9518718565732095, 0.5840536111729073], 
             UndirectedEdge[42, 162] -> 
             RGBColor[
              0.914476505697249, 0.6403711742389498, 0.48834430646392846`], 
             UndirectedEdge[29, 131] -> 
             RGBColor[
              0.21233150972289871`, 0.34050425768701104`, 0.9354033374111754],
              UndirectedEdge[12, 192] -> 
             RGBColor[
              0.3801187118441842, 0.5036614557026298, 0.9454418060863005], 
             UndirectedEdge[69, 76] -> 
             RGBColor[
              0.2672433086560147, 0.39653993712037666`, 0.9385919999213795], 
             UndirectedEdge[176, 180] -> 
             RGBColor[
              0.1945386218938126, 0.32180280444439524`, 0.9343900587715277], 
             UndirectedEdge[101, 116] -> 
             RGBColor[
              0.46733992011891123`, 0.5718860980228273, 0.952579449352897], 
             UndirectedEdge[125, 293] -> 
             RGBColor[
              0.8674766192366652, 0.4546177529994014, 0.20970208429653842`], 
             UndirectedEdge[30, 300] -> 
             RGBColor[
              0.23747118318928384`, 0.36692764844754155`, 0.936835004624272], 
             UndirectedEdge[155, 290] -> 
             RGBColor[
              0.9363623874102649, 0.7854051025986525, 0.2676538870247894], 
             UndirectedEdge[217, 246] -> 
             RGBColor[
              0.1922440281378487, 0.31939104092123016`, 0.9342593850516728], 
             UndirectedEdge[42, 82] -> 
             RGBColor[
              0.7255221919430327, 0.49355450623719554`, 0.5731775024918879], 
             UndirectedEdge[122, 138] -> 
             RGBColor[
              0.2081640824318275, 0.3361240273739437, 0.9351660085921052], 
             UndirectedEdge[58, 160] -> 
             RGBColor[
              0.19345266111115197`, 0.32066139080792844`, 0.9343282149114902],
              UndirectedEdge[158, 225] -> 
             RGBColor[
              0.21027114178594725`, 0.3383386803504027, 0.9352860025052073], 
             UndirectedEdge[197, 204] -> 
             RGBColor[
              0.7349750271013598, 0.7901370127560131, 0.9142536375891683], 
             UndirectedEdge[40, 182] -> 
             RGBColor[
              0.47178862651241965`, 0.5709077330502953, 0.9537279453665835], 
             UndirectedEdge[1, 149] -> 
             RGBColor[
              0.8570986062261408, 0.38154015003843245`, 0.20002614306594468`],
              UndirectedEdge[32, 156] -> 
             RGBColor[
              0.691083843191671, 0.7526411268737674, 0.9001295183811735], 
             UndirectedEdge[258, 286] -> 
             RGBColor[
              0.28052613048445796`, 0.4092765484606139, 0.9393932710602128], 
             UndirectedEdge[101, 197] -> 
             RGBColor[
              0.816834867392223, 0.8565183997567056, 0.9207499871177253], 
             UndirectedEdge[53, 271] -> 
             RGBColor[
              0.21925630560640996`, 0.3477826572179991, 0.935797694292424], 
             UndirectedEdge[22, 70] -> 
             RGBColor[
              0.19915563229546623`, 0.32665557511190024`, 0.9346529906836472],
              UndirectedEdge[76, 258] -> 
             RGBColor[
              0.3335396370029857, 0.4633170022075566, 0.942473828625678], 
             UndirectedEdge[232, 297] -> 
             RGBColor[
              0.18995045311417683`, 0.3169803481502954, 0.934128769347115], 
             UndirectedEdge[178, 261] -> 
             RGBColor[
              0.2518738885698846, 0.38206580498681714`, 0.9376552173888041], 
             UndirectedEdge[155, 227] -> 
             RGBColor[
              0.9395091625151377, 0.7978810172888317, 0.27018585613847523`], 
             UndirectedEdge[178, 182] -> 
             RGBColor[
              0.2566774713547828, 0.3871146750584845, 0.9379287743221401], 
             UndirectedEdge[5, 51] -> 
             RGBColor[
              0.8911547141993119, 0.8831957888790658, 0.6618581652210298], 
             UndirectedEdge[110, 295] -> 
             RGBColor[
              0.19142001506063305`, 0.31852495093162986`, 0.9342124587259435],
              UndirectedEdge[186, 286] -> 
             RGBColor[
              0.2070033670926693, 0.3349040419588854, 0.9350999075706646], 
             UndirectedEdge[34, 270] -> 
             RGBColor[
              0.19826604624820576`, 0.32572056377321634`, 0.9346023300742803],
              UndirectedEdge[4, 8] -> 
             RGBColor[
              0.21250294836697825`, 0.34068445057177643`, 0.935413100588335], 
             UndirectedEdge[69, 166] -> 
             RGBColor[
              0.19683162728000528`, 0.3242128984902222, 0.9345206420360739], 
             UndirectedEdge[25, 176] -> 
             RGBColor[
              0.19265413404658233`, 0.31982208823352565`, 0.9342827399764779],
              UndirectedEdge[32, 149] -> 
             RGBColor[
              0.9415899849052779, 0.803780404688222, 0.5442097809326024], 
             UndirectedEdge[16, 153] -> 
             RGBColor[
              0.233929772423327, 0.36320540119410966`, 0.9366333265201985], 
             UndirectedEdge[169, 299] -> 
             RGBColor[
              0.7117164306549081, 0.41734421667683197`, 0.5637805087358065], 
             UndirectedEdge[187, 229] -> 
             RGBColor[
              0.22122626051320093`, 0.3498532047273915, 0.9359098803100787], 
             UndirectedEdge[15, 82] -> 
             RGBColor[
              0.43590786027701234`, 0.5429784897554615, 0.9503684349274593], 
             UndirectedEdge[44, 280] -> 
             RGBColor[
              0.2891161135986471, 0.42051878582686586`, 0.939801406401479], 
             UndirectedEdge[186, 265] -> 
             RGBColor[
              0.2079159163966799, 0.33586318913636815`, 0.9351518759035322], 
             UndirectedEdge[117, 265] -> 
             RGBColor[
              0.2041128319271811, 0.33186590622944256`, 0.9349352958691536], 
             UndirectedEdge[106, 162] -> 
             RGBColor[
              0.9266044419072905, 0.9416892870110949, 0.8898655994395634], 
             UndirectedEdge[9, 146] -> 
             RGBColor[
              0.1994945649800457, 0.3270118148529666, 0.9346722923986279], 
             UndirectedEdge[130, 294] -> 
             RGBColor[
              0.723926300807685, 0.6611320656306849, 0.6022559472314186], 
             UndirectedEdge[13, 53] -> 
             RGBColor[
              0.27458306643531494`, 0.40366544683013694`, 0.9390315559482794],
              UndirectedEdge[34, 57] -> 
             RGBColor[
              0.18168430472921848`, 0.3082921020936258, 0.9336580244252622], 
             UndirectedEdge[25, 144] -> 
             RGBColor[
              0.19437777007737006`, 0.3216337389867199, 0.9343808984985402], 
             UndirectedEdge[206, 283] -> 
             RGBColor[
              0.26412169083739256`, 0.3949390217254835, 0.938352711608939], 
             UndirectedEdge[107, 273] -> 
             RGBColor[
              0.32370272298268776`, 0.4483418094779742, 0.9420833765839904], 
             UndirectedEdge[64, 85] -> 
             RGBColor[
              0.2337265149567007, 0.3629917647094177, 0.9366217513081667], 
             UndirectedEdge[175, 224] -> 
             RGBColor[
              0.19563816085584113`, 0.3229584896082839, 0.9344526758887932], 
             UndirectedEdge[68, 163] -> 
             RGBColor[
              0.7490034970690254, 0.8039812828492927, 0.9757174701655251], 
             UndirectedEdge[7, 237] -> 
             RGBColor[
              0.8816971748770377, 0.5736299661344524, 0.5804688470438946], 
             UndirectedEdge[76, 126] -> 
             RGBColor[
              0.2752030578474213, 0.40490613819779253`, 0.9390452958624365], 
             UndirectedEdge[30, 236] -> 
             RGBColor[
              0.2403636886171835, 0.3699678550477007, 0.9369997285293126], 
             UndirectedEdge[7, 269] -> 
             RGBColor[
              0.9557422920381128, 0.9373302721362289, 0.6697719934605999], 
             UndirectedEdge[237, 256] -> 
             RGBColor[
              0.8215013839374217, 0.16627463567534986`, 0.16822305558180195`],
              UndirectedEdge[106, 290] -> 
             RGBColor[
              0.9041357720440601, 0.8589662618992862, 0.6312127071179277], 
             UndirectedEdge[180, 288] -> 
             RGBColor[
              0.20187497125250775`, 0.32951377277179905`, 0.9348078530143491],
              UndirectedEdge[201, 237] -> 
             RGBColor[
              0.8352193779806968, 0.2717171491552828, 0.18135942216990056`], 
             UndirectedEdge[10, 73] -> 
             RGBColor[
              0.18653587436616526`, 0.31339140938933835`, 0.9339343141388322],
              UndirectedEdge[18, 175] -> 
             RGBColor[
              0.19129167307218187`, 0.3183900553644156, 0.9342051498395663], 
             UndirectedEdge[57, 295] -> 
             RGBColor[
              0.1882992367969673, 0.3152448151077469, 0.9340347350206055], 
             UndirectedEdge[71, 161] -> 
             RGBColor[
              0.2124857473818974, 0.34066637124585103`, 0.9354121210176813], 
             UndirectedEdge[218, 220] -> 
             RGBColor[
              0.6501395047208716, 0.7189888396444919, 0.9414344110066938], 
             UndirectedEdge[192, 248] -> 
             RGBColor[
              0.27628801069729353`, 0.4057044446902951, 0.9391196063656152], 
             UndirectedEdge[23, 24] -> 
             RGBColor[
              0.956555334204736, 0.8626596651038085, 0.541866983332811], 
             UndirectedEdge[39, 195] -> 
             RGBColor[
              0.1927241486561343, 0.3198956780273474, 0.9342867272049146], 
             UndirectedEdge[79, 232] -> 
             RGBColor[
              0.1855242988552152, 0.31232817938973806`, 0.9338767064099756], 
             UndirectedEdge[12, 154] -> 
             RGBColor[
              0.46345887168868094`, 0.5746523637299171, 0.9510821144780158], 
             UndirectedEdge[106, 155] -> 
             RGBColor[
              0.8940872222095038, 0.8191271102860018, 0.6231274080512639], 
             UndirectedEdge[95, 103] -> 
             RGBColor[
              0.35444301317126903`, 0.47946333163225574`, 0.9438775064114789],
              UndirectedEdge[3, 228] -> 
             RGBColor[
              0.690237715965832, 0.7545004457298199, 0.955381119587516], 
             UndirectedEdge[81, 293] -> 
             RGBColor[
              0.8946118304119881, 0.61433876058075, 0.23377386680638917`], 
             UndirectedEdge[95, 145] -> 
             RGBColor[
              0.5762301255781173, 0.6573426269684071, 0.963331889789669], 
             UndirectedEdge[39, 153] -> 
             RGBColor[
              0.2113966935997263, 0.3395217066707913, 0.9353501010158973], 
             UndirectedEdge[39, 90] -> 
             RGBColor[
              0.20870014958760652`, 0.3366874679432882, 0.9351965368235865], 
             UndirectedEdge[120, 141] -> 
             RGBColor[
              0.28646903998749706`, 0.4184275025860159, 0.939625360083097], 
             UndirectedEdge[102, 172] -> 
             RGBColor[
              0.19138970866876043`, 0.3184930969922355, 0.9342107328217606], 
             UndirectedEdge[155, 194] -> 
             RGBColor[
              0.8061596900222359, 0.7500989808439875, 0.6144534337056413], 
             UndirectedEdge[53, 251] -> 
             RGBColor[
              0.25074234215186236`, 0.3808764779572891, 0.9375907774942707], 
             UndirectedEdge[128, 243] -> 
             RGBColor[
              0.9161788814227196, 0.6677504484439996, 0.5244280625350448], 
             UndirectedEdge[72, 87] -> 
             RGBColor[
              0.9112817531721615, 0.6074291803827055, 0.3356936471851313], 
             UndirectedEdge[76, 90] -> 
             RGBColor[
              0.2712969166915207, 0.40080053617928724`, 0.938822846902226], 
             UndirectedEdge[3, 106] -> 
             RGBColor[
              0.9080394881357245, 0.9290324924917327, 0.9745333831638314], 
             UndirectedEdge[104, 243] -> 
             RGBColor[
              0.6612526622734278, 0.7268613939195354, 0.9003802288706013], 
             UndirectedEdge[34, 217] -> 
             RGBColor[
              0.1918655955426979, 0.3189932842697143, 0.9342378338752199], 
             UndirectedEdge[31, 37] -> 
             RGBColor[
              0.32310841403988205`, 0.4466841095652183, 0.9420873563531128], 
             UndirectedEdge[64, 249] -> 
             RGBColor[
              0.22138061658703678`, 0.35001544274773333`, 0.9359186706601341],
              UndirectedEdge[89, 188] -> 
             RGBColor[
              0.3683043792841372, 0.49342847464473716`, 0.9446890072625783], 
             UndirectedEdge[179, 269] -> 
             RGBColor[
              0.7479608310759376, 0.7722887789067958, 0.6529117994592061], 
             UndirectedEdge[213, 249] -> 
             RGBColor[
              0.2049158790401142, 0.33270995966126304`, 0.9349810282142335], 
             UndirectedEdge[44, 252] -> 
             RGBColor[
              0.27708079783829526`, 0.4078689058796433, 0.9391160129735812], 
             UndirectedEdge[149, 198] -> 
             RGBColor[
              0.93004743411723, 0.7957508352156739, 0.5896702154371328], 
             UndirectedEdge[158, 214] -> 
             RGBColor[
              0.19688801935015837`, 0.3242721701314169, 0.9345238534810445], 
             UndirectedEdge[202, 216] -> 
             RGBColor[
              0.8665172267438337, 0.4867677269850564, 0.21033104084392829`], 
             UndirectedEdge[78, 209] -> 
             RGBColor[
              0.18729352981200414`, 0.31418775330104487`, 0.933977461495622], 
             UndirectedEdge[77, 265] -> 
             RGBColor[
              0.31824926646414226`, 0.4421191756626833, 0.9417907774257306], 
             UndirectedEdge[44, 204] -> 
             RGBColor[
              0.39991382818369614`, 0.5199845367377941, 0.9469303798325985], 
             UndirectedEdge[54, 102] -> 
             RGBColor[
              0.218116116310074, 0.34658424597537324`, 0.9357327621987566], 
             UndirectedEdge[2, 253] -> 
             RGBColor[
              0.19522054856906235`, 0.32251955261673115`, 0.9344288934868631],
              UndirectedEdge[40, 86] -> 
             RGBColor[
              0.6417053553097174, 0.7192862820416126, 0.9654274840700409], 
             UndirectedEdge[75, 165] -> 
             RGBColor[
              0.27536181000482485`, 0.4045171817075533, 0.9390746876755028], 
             UndirectedEdge[73, 100] -> 
             RGBColor[
              0.1816658245926822, 0.30827267829841776`, 0.9336569720088254], 
             UndirectedEdge[50, 206] -> 
             RGBColor[
              0.20212300857950383`, 0.32977447572894675`, 0.9348219783731833],
              UndirectedEdge[32, 277] -> 
             RGBColor[
              0.9903436750031767, 0.9883158760637997, 0.6672952315344995], 
             UndirectedEdge[156, 251] -> 
             RGBColor[
              0.3400494072237743, 0.46681610621407393`, 0.942966956843591], 
             UndirectedEdge[31, 44] -> 
             RGBColor[
              0.36793393060354135`, 0.4931076106168971, 0.9446654026002257], 
             UndirectedEdge[80, 92] -> 
             RGBColor[
              0.9051815489493698, 0.591863337150663, 0.2750126050569618], 
             UndirectedEdge[11, 149] -> 
             RGBColor[
              0.7136593076403137, 0.6245896318315118, 0.5954018551660852], 
             UndirectedEdge[103, 145] -> 
             RGBColor[
              0.643116750417353, 0.7172355839626725, 0.9675221132384173], 
             UndirectedEdge[150, 274] -> 
             RGBColor[
              0.6852279869066359, 0.622788647378854, 0.5976147565045411], 
             UndirectedEdge[13, 156] -> 
             RGBColor[
              0.3638901315072269, 0.4896050750869218, 0.9444077352975997], 
             UndirectedEdge[84, 278] -> 
             RGBColor[
              0.19404895120727791`, 0.32128812950593255`, 0.9343621727503324],
              UndirectedEdge[150, 293] -> 
             RGBColor[
              0.9035840903340573, 0.6541630034729253, 0.24121312079051388`], 
             UndirectedEdge[52, 137] -> 
             RGBColor[
              0.23013360981142927`, 0.35921539359839394`, 0.9364171406753703],
              UndirectedEdge[41, 152] -> 
             RGBColor[
              0.1855570941414352, 0.31236264931489655`, 0.9338785740530094], 
             UndirectedEdge[177, 279] -> 
             RGBColor[
              0.2643192230897936, 0.3951466406470252, 0.9383639607784904], 
             UndirectedEdge[108, 279] -> 
             RGBColor[
              0.23867609661587075`, 0.3681940888548081, 0.9369036226614065], 
             UndirectedEdge[161, 279] -> 
             RGBColor[
              0.2191606879449377, 0.34768215699328187`, 0.9357922490080568], 
             UndirectedEdge[89, 260] -> 
             RGBColor[
              0.3194559514168667, 0.4464420991230162, 0.9417476517079721], 
             UndirectedEdge[63, 161] -> 
             RGBColor[
              0.19226866060006637`, 0.3194169312008093, 0.9342607878339557], 
             UndirectedEdge[110, 148] -> 
             RGBColor[
              0.2161072361235734, 0.34447278552900074`, 0.9356183594440073], 
             UndirectedEdge[200, 228] -> 
             RGBColor[
              0.3959136886863399, 0.5173422707646859, 0.946448248043733], 
             UndirectedEdge[67, 118] -> 
             RGBColor[
              0.18382399790050605`, 0.31054105528103165`, 0.9337798767859746],
              UndirectedEdge[140, 203] -> 
             RGBColor[
              0.8772220459314396, 0.5433777884881621, 0.5777664992302363], 
             UndirectedEdge[144, 231] -> 
             RGBColor[
              0.21441031983489064`, 0.34268921891888826`, 0.9355217225717294],
              UndirectedEdge[101, 149] -> 
             RGBColor[
              0.7714159149498363, 0.6714029284596804, 0.6000007099012994], 
             UndirectedEdge[131, 284] -> 
             RGBColor[
              0.23518277089129241`, 0.36452238202863274`, 0.9367046829293041],
              UndirectedEdge[157, 275] -> 
             RGBColor[
              0.18135642915031058`, 0.30794748407168115`, 0.9336393523960919],
              UndirectedEdge[113, 144] -> 
             RGBColor[
              0.23263625868922916`, 0.36184583624606526`, 0.9365596628266237],
              UndirectedEdge[48, 73] -> 
             RGBColor[
              0.187739347830093, 0.31465633630455114`, 0.9340028501722235], 
             UndirectedEdge[35, 183] -> 
             RGBColor[
              0.19956688605797046`, 0.32708782889128674`, 0.9346764109770263],
              UndirectedEdge[93, 107] -> 
             RGBColor[
              0.32480267899707094`, 0.44949793299033025`, 0.9421460174517705],
              UndirectedEdge[23, 226] -> 
             RGBColor[
              0.9878018957897885, 0.9892237846791677, 0.8518176846523693], 
             UndirectedEdge[200, 211] -> 
             RGBColor[
              0.31815152117452855`, 0.44647400293362227`, 0.9416219977306357],
              UndirectedEdge[87, 227] -> 
             RGBColor[
              0.9729262687384115, 0.9189743901826695, 0.3881944192270413], 
             UndirectedEdge[223, 278] -> 
             RGBColor[
              0.1910601770666856, 0.31814673838494456`, 0.9341919664845209], 
             UndirectedEdge[182, 229] -> 
             RGBColor[
              0.23602797859295035`, 0.36541074891233866`, 0.9367528162575407],
              UndirectedEdge[79, 221] -> 
             RGBColor[
              0.18466822464384994`, 0.3114283911153532, 0.9338279542500865], 
             UndirectedEdge[115, 228] -> 
             RGBColor[
              0.3889928994532643, 0.5113478309799768, 0.946007261473615], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.3382052536051789, 0.4616299042238716, 0.9429808558058818], 
             UndirectedEdge[9, 47] -> 
             RGBColor[
              0.1915298565644043, 0.31864040131644705`, 0.9342187140370874], 
             UndirectedEdge[18, 224] -> 
             RGBColor[
              0.2043212377981297, 0.33208495401350496`, 0.9349471642751953], 
             UndirectedEdge[194, 291] -> 
             RGBColor[
              0.8064401830754907, 0.8495804260163464, 0.9811128108192658], 
             UndirectedEdge[5, 198] -> 
             RGBColor[
              0.967801874456065, 0.9434968913498611, 0.6433562360480443], 
             UndirectedEdge[49, 172] -> 
             RGBColor[
              0.20010293929950806`, 0.3276512548358813, 0.9347069384161122], 
             UndirectedEdge[162, 228] -> 
             RGBColor[
              0.7088026697373979, 0.7671572402491821, 0.8707133358632482], 
             UndirectedEdge[100, 161] -> 
             RGBColor[
              0.1911587437240086, 0.318250338191278, 0.9341975797098391], 
             UndirectedEdge[174, 235] -> 
             RGBColor[
              0.3208493079592518, 0.4453409740728014, 0.9419209416251387], 
             UndirectedEdge[14, 67] -> 
             RGBColor[
              0.17956042552731538`, 0.30605977039070653`, 0.9335370726467116],
              UndirectedEdge[190, 199] -> 
             RGBColor[
              0.2014046269978636, 0.3290194111386199, 0.9347810676048591], 
             UndirectedEdge[160, 288] -> 
             RGBColor[
              0.20231487113075944`, 0.32997613543510473`, 0.934832904661642], 
             UndirectedEdge[33, 275] -> 
             RGBColor[
              0.19034059746125545`, 0.31739041459565537`, 0.9341509874905143],
              UndirectedEdge[109, 218] -> 
             RGBColor[
              0.9800003657513711, 0.9831729301139916, 0.8546124313811914], 
             UndirectedEdge[231, 264] -> 
             RGBColor[
              0.2636953407278438, 0.39449090072818943`, 0.9383284316009286], 
             UndirectedEdge[221, 230] -> 
             RGBColor[
              0.18914056303198, 0.3161291023239095, 0.9340826473050587], 
             UndirectedEdge[45, 236] -> 
             RGBColor[
              0.26568284234196243`, 0.3965798909395088, 0.9384416168776075], 
             UndirectedEdge[279, 280] -> 
             RGBColor[
              0.24933981979070619`, 0.37940233803066026`, 0.9375109059206487],
              UndirectedEdge[71, 252] -> 
             RGBColor[
              0.23062956346731406`, 0.3597366723360068, 0.9364453845023752], 
             UndirectedEdge[230, 296] -> 
             RGBColor[
              0.18964632804218584`, 0.3166606934169896, 0.9341114498741778], 
             UndirectedEdge[27, 154] -> 
             RGBColor[
              0.7335695588322665, 0.7563490417801518, 0.6454543011351679], 
             UndirectedEdge[5, 101] -> 
             RGBColor[
              0.8091703552886713, 0.8191489845938676, 0.6536867305122107], 
             UndirectedEdge[68, 143] -> 
             RGBColor[
              0.5918755827726521, 0.672270845358494, 0.9644525615859105], 
             UndirectedEdge[58, 221] -> 
             RGBColor[
              0.18866826221874242`, 0.3156326842235957, 0.9340557504724514], 
             UndirectedEdge[85, 249] -> 
             RGBColor[
              0.21980259172524277`, 0.34835683856543287`, 0.9358288044787336],
              UndirectedEdge[26, 54] -> 
             RGBColor[
              0.23656624471631046`, 0.3659765007360335, 0.9367834697169728], 
             UndirectedEdge[269, 282] -> 
             RGBColor[
              0.7068985223577822, 0.7386080961972126, 0.6497743968433352], 
             UndirectedEdge[24, 210] -> 
             RGBColor[
              0.6977215322082554, 0.6587130381270785, 0.6045341943932525], 
             UndirectedEdge[144, 288] -> 
             RGBColor[
              0.20325262345727604`, 0.33096177258720527`, 0.9348863082693568],
              UndirectedEdge[182, 199] -> 
             RGBColor[
              0.22636918605193562`, 0.35525874554891435`, 0.936202762311233], 
             UndirectedEdge[35, 224] -> 
             RGBColor[
              0.20753059097457632`, 0.33545818768669444`, 0.9351299321907813],
              UndirectedEdge[161, 280] -> 
             RGBColor[
              0.2318337811627876, 0.36100238148576125`, 0.9365139629186521], 
             UndirectedEdge[27, 42] -> 
             RGBColor[
              0.9037231190376234, 0.5999912478441332, 0.26049200407288453`], 
             UndirectedEdge[13, 273] -> 
             RGBColor[
              0.2861094453581625, 0.4157804018926833, 0.9396879661761859], 
             UndirectedEdge[167, 202] -> 
             RGBColor[
              0.8871263793979363, 0.5793538569383307, 0.22747634135468459`], 
             UndirectedEdge[117, 207] -> 
             RGBColor[
              0.18539878883552113`, 0.3121962604012447, 0.9338695588000294], 
             UndirectedEdge[33, 248] -> 
             RGBColor[
              0.21123257741316134`, 0.3393492101531443, 0.9353407548418606], 
             UndirectedEdge[23, 210] -> 
             RGBColor[
              0.7305128529889463, 0.7859159553283347, 0.8888842381324313], 
             UndirectedEdge[54, 111] -> 
             RGBColor[
              0.4291203016109882, 0.5357529458181629, 0.9499902123364491], 
             UndirectedEdge[30, 267] -> 
             RGBColor[
              0.22275125819820335`, 0.35145607398476686`, 0.9359967266722076],
              UndirectedEdge[170, 199] -> 
             RGBColor[
              0.19798561422584082`, 0.3254258119372937, 0.9345863598854686], 
             UndirectedEdge[169, 200] -> 
             RGBColor[
              0.4851546386974715, 0.5905268621408066, 0.9532706039694929], 
             UndirectedEdge[137, 278] -> 
             RGBColor[
              0.23108207251171536`, 0.3602122880324031, 0.9364711542230267], 
             UndirectedEdge[92, 150] -> 
             RGBColor[
              0.8694820518221094, 0.4570824795240357, 0.2111038787281495], 
             UndirectedEdge[68, 185] -> 
             RGBColor[
              0.7032065232894661, 0.766801236404889, 0.9721121646297556], 
             UndirectedEdge[26, 102] -> 
             RGBColor[
              0.21064547425155244`, 0.3387321275058029, 0.9353073201853483], 
             UndirectedEdge[270, 271] -> 
             RGBColor[
              0.217737181833685, 0.3461859618148549, 0.9357111824409096], 
             UndirectedEdge[169, 202] -> 
             RGBColor[
              0.7356548490799517, 0.5885020285868033, 0.5862010514084512], 
             UndirectedEdge[17, 97] -> 
             RGBColor[
              0.5762606506463335, 0.665813185958444, 0.9604600233988309], 
             UndirectedEdge[46, 158] -> 
             RGBColor[
              0.1988271914603046, 0.32631036296979365`, 0.9346342864639694], 
             UndirectedEdge[98, 285] -> 
             RGBColor[
              0.18936585526810354`, 0.31636589874842813`, 0.9340954773646161],
              UndirectedEdge[77, 168] -> 
             RGBColor[
              0.4070970567080353, 0.527028742052658, 0.9471608423650113], 
             UndirectedEdge[242, 268] -> 
             RGBColor[0.1929658134251674, 0.3201496830220325, 0.934300489656],
              UndirectedEdge[115, 134] -> 
             RGBColor[
              0.29826389721871693`, 0.4268505977105114, 0.940442569105771], 
             UndirectedEdge[99, 284] -> 
             RGBColor[
              0.2183159570292897, 0.34679429124190236`, 0.9357441428320781], 
             UndirectedEdge[204, 283] -> 
             RGBColor[
              0.3947145595034514, 0.515210734660812, 0.9466089897806659], 
             UndirectedEdge[77, 167] -> 
             RGBColor[
              0.6607323580564698, 0.6022582598273698, 0.5960819189651536], 
             UndirectedEdge[227, 290] -> 
             RGBColor[
              0.9495577123496941, 0.837720168902116, 0.27827115520513895`], 
             UndirectedEdge[60, 145] -> 
             RGBColor[
              0.5760856373176906, 0.6571907606456139, 0.9633236613969889], 
             UndirectedEdge[32, 125] -> 
             RGBColor[
              0.9114353173335938, 0.6303487508229553, 0.5176184899919789], 
             UndirectedEdge[15, 60] -> 
             RGBColor[
              0.27282174145117777`, 0.4040833265356404, 0.9388481666208225], 
             UndirectedEdge[30, 260] -> 
             RGBColor[
              0.25373200019445147`, 0.38401879811531836`, 0.9377610340969933],
              UndirectedEdge[42, 80] -> 
             RGBColor[
              0.9082065714342227, 0.6151149855425471, 0.2779093700047311], 
             UndirectedEdge[97, 130] -> 
             RGBColor[
              0.6803306714803544, 0.6256180746890865, 0.5988573985297044], 
             UndirectedEdge[65, 211] -> 
             RGBColor[
              0.3240980577045407, 0.45162459399430244`, 0.9420009057800123], 
             UndirectedEdge[1, 256] -> 
             RGBColor[
              0.8183107548052182, 0.14175006202263388`, 0.1651677055215038], 
             UndirectedEdge[5, 128] -> 
             RGBColor[
              0.9079764711926817, 0.6301585985825083, 0.2662791699211355], 
             UndirectedEdge[125, 256] -> 
             RGBColor[
              0.8265612881466855, 0.2051672766919145, 0.17306842556693747`], 
             UndirectedEdge[39, 239] -> 
             RGBColor[
              0.2196501555680895, 0.3481966184992542, 0.9358201234650929], 
             UndirectedEdge[156, 269] -> 
             RGBColor[
              0.6838282108058124, 0.7186257518784704, 0.6483043769915192], 
             UndirectedEdge[78, 170] -> 
             RGBColor[
              0.19585393495458225`, 0.32318528186692885`, 0.9344649639045073],
              UndirectedEdge[23, 155] -> 
             RGBColor[
              0.9578302462805677, 0.8677142666452164, 0.5428928075150579], 
             UndirectedEdge[127, 251] -> 
             RGBColor[
              0.31722126846433096`, 0.4470435197962596, 0.9415123680279698], 
             UndirectedEdge[241, 290] -> 
             RGBColor[
              0.9662675720592777, 0.9068871357048387, 0.5776802589012907], 
             UndirectedEdge[85, 234] -> 
             RGBColor[
              0.21315182719847248`, 0.341366463364971, 0.9354500532778585], 
             UndirectedEdge[270, 289] -> 
             RGBColor[
              0.22814186813803294`, 0.35712194681593845`, 0.9363037139335881],
              UndirectedEdge[69, 258] -> 
             RGBColor[
              0.273865191252875, 0.4022754790002804, 0.9390139404249507], 
             UndirectedEdge[52, 289] -> 
             RGBColor[
              0.22108882372044908`, 0.3497087499442134, 0.9359020534880509], 
             UndirectedEdge[47, 170] -> 
             RGBColor[
              0.1908380369178425, 0.3179132550040116, 0.9341793159316711], 
             UndirectedEdge[72, 241] -> 
             RGBColor[
              0.9077698315979006, 0.607817840595054, 0.5277114559730665], 
             UndirectedEdge[115, 210] -> 
             RGBColor[
              0.4117038936977402, 0.5305204071243743, 0.9475921355741658], 
             UndirectedEdge[166, 239] -> 
             RGBColor[
              0.21183524129599424`, 0.3399826481050988, 0.9353750756584267], 
             UndirectedEdge[180, 215] -> 
             RGBColor[
              0.2098131605219987, 0.33785731300430355`, 0.9352599211497481], 
             UndirectedEdge[51, 254] -> 
             RGBColor[
              0.5650392887707011, 0.6515224922377361, 0.9616798049124837], 
             UndirectedEdge[109, 227] -> 
             RGBColor[
              0.9727578246301442, 0.9207456642506578, 0.5248021537611475], 
             UndirectedEdge[203, 255] -> 
             RGBColor[
              0.651571481892223, 0.7220382969334023, 0.9679291557478935], 
             UndirectedEdge[257, 272] -> 
             RGBColor[
              0.18158199985616474`, 0.30818457318554265`, 0.9336521983140883],
              UndirectedEdge[32, 128] -> 
             RGBColor[
              0.9163082086198326, 0.6678039285635632, 0.5222847761908246], 
             UndirectedEdge[39, 76] -> 
             RGBColor[
              0.26432098730221126`, 0.39346839209165385`, 0.9384255780434674],
              UndirectedEdge[144, 221] -> 
             RGBColor[
              0.19191775891044247`, 0.3190481112765624, 0.9342408045018441], 
             UndirectedEdge[165, 262] -> 
             RGBColor[
              0.26081704104435255`, 0.39146562526609985`, 0.9381645166920165],
              UndirectedEdge[101, 226] -> 
             RGBColor[
              0.8167925796772653, 0.8565009126998259, 0.9214508039916728], 
             UndirectedEdge[56, 191] -> 
             RGBColor[
              0.21336670196225918`, 0.34159231036555776`, 0.9354622900777774],
              UndirectedEdge[63, 71] -> 
             RGBColor[
              0.20309975866494467`, 0.3308011019982774, 0.9348776028455769], 
             UndirectedEdge[137, 289] -> 
             RGBColor[
              0.25248937634424146`, 0.382712721661845, 0.9376902685070212], 
             UndirectedEdge[148, 295] -> 
             RGBColor[
              0.2216100316720449, 0.3502565725478334, 0.9359317355098362], 
             UndirectedEdge[10, 119] -> 
             RGBColor[
              0.1856272606689936, 0.3124363987841752, 0.9338825699329518], 
             UndirectedEdge[115, 231] -> 
             RGBColor[
              0.29145473297171365`, 0.41969373436096236`, 0.9400547972751598],
              UndirectedEdge[33, 171] -> 
             RGBColor[
              0.189827260881899, 0.31685086530333273`, 0.9341217537317332], 
             UndirectedEdge[173, 234] -> 
             RGBColor[
              0.19772105404463286`, 0.3251477424127598, 0.9345712935745305], 
             UndirectedEdge[69, 173] -> 
             RGBColor[
              0.2044279033465657, 0.3321970662678976, 0.9349532387203812], 
             UndirectedEdge[4, 263] -> 
             RGBColor[
              0.21521347097412877`, 0.3435333816889509, 0.9355674608409534], 
             UndirectedEdge[134, 160] -> 
             RGBColor[
              0.22028173175537732`, 0.3488604451163368, 0.9358560907946256], 
             UndirectedEdge[7, 205] -> 
             RGBColor[
              0.6553396994405775, 0.7252302520430189, 0.9671201357047186], 
             UndirectedEdge[23, 106] -> 
             RGBColor[
              0.9256036309143629, 0.94127542594585, 0.906451627608196], 
             UndirectedEdge[45, 96] -> 
             RGBColor[
              0.2504426073839444, 0.3805614377119254, 0.9375737080426556], 
             UndirectedEdge[65, 210] -> 
             RGBColor[
              0.424571219460828, 0.5416654379697635, 0.9484120301936603], 
             UndirectedEdge[138, 211] -> 
             RGBColor[
              0.25101026684268113`, 0.38115808379474614`, 0.9376060354090536],
              UndirectedEdge[72, 210] -> 
             RGBColor[
              0.6505472536572664, 0.40453749617198587`, 0.5636765147139389], 
             UndirectedEdge[37, 41] -> 
             RGBColor[
              0.20758147265742513`, 0.3355116675614536, 0.9351328298273469], 
             UndirectedEdge[52, 88] -> 
             RGBColor[
              0.21079575741608964`, 0.3388900846402345, 0.9353158785892447], 
             UndirectedEdge[157, 285] -> 
             RGBColor[
              0.1911088793151014, 0.31819792753593046`, 0.9341947400055196], 
             UndirectedEdge[135, 265] -> 
             RGBColor[
              0.21789617448484386`, 0.3463530731719392, 0.9357202368371844], 
             UndirectedEdge[17, 42] -> 
             RGBColor[
              0.7706339375032876, 0.5292391522973952, 0.5773709330033577], 
             UndirectedEdge[242, 250] -> 
             RGBColor[
              0.18176798085569046`, 0.30838005100792065`, 0.933662789656877], 
             UndirectedEdge[81, 202] -> 
             RGBColor[
              0.8780178149903479, 0.5389892121818496, 0.21992741358203377`], 
             UndirectedEdge[229, 259] -> 
             RGBColor[
              0.2014368212026378, 0.32905324928906804`, 0.934782901017194], 
             UndirectedEdge[40, 81] -> 
             RGBColor[
              0.7893492688527326, 0.6740607768287987, 0.5995695817860118], 
             UndirectedEdge[100, 119] -> 
             RGBColor[
              0.1807572108955105, 0.3073176676932546, 0.933605227802945], 
             UndirectedEdge[81, 269] -> 
             RGBColor[
              0.931314896123058, 0.7560543834090069, 0.28986513111217527`], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.8109817388046351, 0.5174976470005512, 0.5760174599499823], 
             UndirectedEdge[180, 233] -> 
             RGBColor[
              0.20014010875548707`, 0.32769032229079487`, 0.9347090551616429],
              UndirectedEdge[33, 184] -> 
             RGBColor[
              0.1959981041281816, 0.3233368128092353, 0.9344731741256647], 
             UndirectedEdge[103, 168] -> 
             RGBColor[
              0.41087052923769096`, 0.5302971342976018, 0.9474012846978503], 
             UndirectedEdge[49, 238] -> 
             RGBColor[
              0.19853266531396374`, 0.3260007973159532, 0.9346175136356476], 
             UndirectedEdge[97, 120] -> 
             RGBColor[
              0.3639742346570427, 0.4869360497143149, 0.944513487615392], 
             UndirectedEdge[117, 212] -> 
             RGBColor[
              0.20943922968905518`, 0.3374642879902957, 0.935238626341993], 
             UndirectedEdge[270, 278] -> 
             RGBColor[
              0.20673456430550685`, 0.3346215131864966, 0.9350845996495938], 
             UndirectedEdge[26, 165] -> 
             RGBColor[
              0.2234449255941841, 0.3521851623989958, 0.9360362300042198], 
             UndirectedEdge[65, 70] -> 
             RGBColor[
              0.2936166091660087, 0.41958665894484415`, 0.940265032379005], 
             UndirectedEdge[56, 223] -> 
             RGBColor[
              0.19042353178656807`, 0.3174775838298989, 0.9341557104776503], 
             UndirectedEdge[207, 212] -> 
             RGBColor[
              0.20932819464730518`, 0.33734758312138824`, 0.935232303060627], 
             UndirectedEdge[171, 184] -> 
             RGBColor[
              0.1853189372548359, 0.31211233132706184`, 0.9338650113706392], 
             UndirectedEdge[32, 205] -> 
             RGBColor[
              0.6800179376878698, 0.7430563957149572, 0.8994244086676673], 
             UndirectedEdge[23, 31] -> 
             RGBColor[
              0.7044976010018857, 0.7638813972041334, 0.8870888196503636], 
             UndirectedEdge[235, 274] -> 
             RGBColor[
              0.43577020330018756`, 0.5515998272739158, 0.9490608562281224], 
             UndirectedEdge[178, 199] -> 
             RGBColor[
              0.2287030477407748, 0.357711782159262, 0.9363356722817735], 
             UndirectedEdge[117, 158] -> 
             RGBColor[
              0.189227738636957, 0.3162207294119929, 0.9340876118267976], 
             UndirectedEdge[112, 190] -> 
             RGBColor[
              0.19682291342577818`, 0.3242037396769393, 0.9345201457949667], 
             UndirectedEdge[64, 213] -> 
             RGBColor[
              0.21883980227157213`, 0.34734488580524786`, 0.9357739750436664],
              UndirectedEdge[127, 205] -> 
             RGBColor[
              0.3605974794488338, 0.48675314536744607`, 0.9441979304200168], 
             UndirectedEdge[121, 263] -> 
             RGBColor[
              0.2176693590934683, 0.34611467581467703`, 0.935707320036189], 
             UndirectedEdge[14, 213] -> 
             RGBColor[
              0.19128445788964016`, 0.31838247175009526`, 0.9342047389455943],
              UndirectedEdge[109, 111] -> 
             RGBColor[
              0.8035074391264327, 0.8444862586698714, 0.8657863480729937], 
             UndirectedEdge[55, 108] -> 
             RGBColor[
              0.22141119699588285`, 0.35004758469634045`, 0.9359204121691784],
              UndirectedEdge[40, 162] -> 
             RGBColor[
              0.8402909601650888, 0.8739220660440041, 0.881352498558146], 
             UndirectedEdge[15, 225] -> 
             RGBColor[
              0.2429863506332136, 0.37272443911292436`, 0.9371490852512447], 
             UndirectedEdge[31, 59] -> 
             RGBColor[
              0.7023281164542653, 0.7629842595904825, 0.9230427930504692], 
             UndirectedEdge[210, 227] -> 
             RGBColor[
              0.7121917692235163, 0.7160827059719499, 0.6161772867558488], 
             UndirectedEdge[52, 93] -> 
             RGBColor[
              0.21993156031517644`, 0.348492392730534, 0.9358361490491385], 
             UndirectedEdge[32, 293] -> 
             RGBColor[
              0.9437174645743351, 0.8134407929799102, 0.5459850021177625], 
             UndirectedEdge[99, 209] -> 
             RGBColor[
              0.18806492725905072`, 0.31499854092731383`, 0.934021391439051], 
             UndirectedEdge[201, 299] -> 
             RGBColor[
              0.8320289955840182, 0.24719447201993064`, 0.1783043083838196], 
             UndirectedEdge[127, 148] -> 
             RGBColor[
              0.29756624946408855`, 0.42638484862682313`, 0.9403930437729009],
              UndirectedEdge[24, 226] -> 
             RGBColor[
              0.9550105750090976, 0.8620208674779115, 0.5674676409131905], 
             UndirectedEdge[144, 264] -> 
             RGBColor[
              0.24692493102232177`, 0.3768641368222969, 0.9373733815777969], 
             UndirectedEdge[148, 217] -> 
             RGBColor[
              0.22316774867338707`, 0.35189383188120626`, 0.9360204451886269],
              UndirectedEdge[230, 288] -> 
             RGBColor[
              0.2004754275788136, 0.3280427636345524, 0.9347281510725716], 
             UndirectedEdge[1, 83] -> 
             RGBColor[
              0.8326229955659482, 0.2517602161734964, 0.1788731234373428], 
             UndirectedEdge[15, 214] -> 
             RGBColor[
              0.22960322819742474`, 0.35865792889393855`, 0.936386936227082], 
             UndirectedEdge[173, 249] -> 
             RGBColor[
              0.20437181857140313`, 0.33213811761322165`, 0.9349500447754056],
              UndirectedEdge[114, 204] -> 
             RGBColor[
              0.3613702020678383, 0.4801637008416135, 0.944710077953264], 
             UndirectedEdge[77, 95] -> 
             RGBColor[
              0.3506695406416134, 0.476194939387312, 0.94363706407864], 
             UndirectedEdge[52, 295] -> 
             RGBColor[
              0.19782793389837072`, 0.3252600799156124, 0.9345773802240863], 
             UndirectedEdge[7, 103] -> 
             RGBColor[
              0.6798246620935919, 0.7464378960430543, 0.9686802958737664], 
             UndirectedEdge[29, 99] -> 
             RGBColor[
              0.19546469586089602`, 0.32277616690028066`, 0.9344427973139495],
              UndirectedEdge[28, 144] -> 
             RGBColor[
              0.19055497770725674`, 0.3176157418266954, 0.9341631961283768], 
             UndirectedEdge[75, 185] -> 
             RGBColor[
              0.43124290556454353`, 0.5458726103470143, 0.9492713561429931], 
             UndirectedEdge[227, 291] -> 
             RGBColor[
              0.9397896555683924, 0.8973624624611904, 0.6368452332520997], 
             UndirectedEdge[76, 192] -> 
             RGBColor[
              0.32876752436481727`, 0.45918363809373036`, 0.9421697538281874],
              UndirectedEdge[59, 72] -> 
             RGBColor[
              0.9072115711061266, 0.6075869855350652, 0.536963277053603], 
             UndirectedEdge[104, 254] -> 
             RGBColor[
              0.32693482661477913`, 0.45759624741671456`, 0.942052975948146], 
             UndirectedEdge[32, 237] -> 
             RGBColor[
              0.90637541312433, 0.5914561098063906, 0.5127731200068433], 
             UndirectedEdge[25, 232] -> 
             RGBColor[
              0.1895116930698092, 0.31651918352467145`, 0.9341037826116756], 
             UndirectedEdge[9, 141] -> 
             RGBColor[
              0.24640393833854723`, 0.3763165404788058, 0.9373437118151957], 
             UndirectedEdge[22, 48] -> 
             RGBColor[
              0.19067565939696252`, 0.3177425859342372, 0.934170068772073], 
             UndirectedEdge[25, 160] -> 
             RGBColor[
              0.19344001775085345`, 0.32064810183461934`, 0.9343274948908254],
              UndirectedEdge[72, 106] -> 
             RGBColor[
              0.845638031582683, 0.5598969667895013, 0.5812439041897035], 
             UndirectedEdge[4, 186] -> 
             RGBColor[
              0.2068268311149634, 0.334718491453289, 0.9350898541078958], 
             UndirectedEdge[78, 182] -> 
             RGBColor[
              0.22423750678067705`, 0.3530182154785495, 0.9360813663302717], 
             UndirectedEdge[106, 211] -> 
             RGBColor[
              0.5662966671615951, 0.6472879549936589, 0.9627077142549896], 
             UndirectedEdge[180, 245] -> 
             RGBColor[
              0.2100635516260986, 0.3381204899304254, 0.9352741805527061], 
             UndirectedEdge[136, 280] -> 
             RGBColor[
              0.32731420410911033`, 0.4536040519351767, 0.9422353549515605], 
             UndirectedEdge[82, 140] -> 
             RGBColor[
              0.7153793247314246, 0.41559198421602295`, 0.5634646813953219], 
             UndirectedEdge[50, 219] -> 
             RGBColor[
              0.1830787781409705, 0.30975778206409804`, 0.9337374376231229], 
             UndirectedEdge[251, 278] -> 
             RGBColor[
              0.24311863666183964`, 0.372863480116429, 0.9371566187448754], 
             UndirectedEdge[80, 150] -> 
             RGBColor[
              0.9431089113179686, 0.8053970694161215, 0.30826637148751795`], 
             UndirectedEdge[26, 183] -> 
             RGBColor[
              0.21091795920318307`, 0.3390185264665105, 0.9353228378002383], 
             UndirectedEdge[243, 256] -> 
             RGBColor[
              0.9026728062872424, 0.5639368365528598, 0.5114946297323817], 
             UndirectedEdge[184, 248] -> 
             RGBColor[
              0.20672425378609824`, 0.33461067617687346`, 0.9350840124807664],
              UndirectedEdge[4, 255] -> 
             RGBColor[
              0.2932777706676125, 0.42028873435652747`, 0.9402069895504767], 
             UndirectedEdge[37, 280] -> 
             RGBColor[
              0.2442905970349878, 0.3740952847751871, 0.9372233601543662], 
             UndirectedEdge[188, 260] -> 
             RGBColor[
              0.3070159863730502, 0.43566722665288543`, 0.9409549881356092], 
             UndirectedEdge[70, 266] -> 
             RGBColor[
              0.20395979058864, 0.33170505007925455`, 0.934926580391328], 
             UndirectedEdge[103, 127] -> 
             RGBColor[
              0.3850824421018483, 0.5079607893674816, 0.9457580905890645], 
             UndirectedEdge[37, 268] -> 
             RGBColor[
              0.21580890611804032`, 0.3441592217779706, 0.9356013699915318], 
             UndirectedEdge[186, 196] -> 
             RGBColor[
              0.19808785672818557`, 0.32553327528980713`, 0.9345921824447229],
              UndirectedEdge[139, 274] -> 
             RGBColor[
              0.4518848560948061, 0.5655575295786147, 0.9500876676545675], 
             UndirectedEdge[15, 255] -> 
             RGBColor[
              0.31219697150637127`, 0.44017401398467865`, 0.9412844100497945],
              UndirectedEdge[118, 195] -> 
             RGBColor[
              0.18622253645749176`, 0.31306207138055164`, 0.9339164700084752],
              UndirectedEdge[125, 128] -> 
             RGBColor[
              0.8400673632821627, 0.3089808885830544, 0.18600185836960054`], 
             UndirectedEdge[61, 177] -> 
             RGBColor[
              0.2846154792944696, 0.4164792927751083, 0.9395198025437264], 
             UndirectedEdge[117, 276] -> 
             RGBColor[
              0.21344183559868857`, 0.34167128058119267`, 0.9354665688272218],
              UndirectedEdge[7, 154] -> 
             RGBColor[
              0.7178086500945909, 0.778143567686985, 0.971430549102502], 
             UndirectedEdge[59, 198] -> 
             RGBColor[
              0.974799373492677, 0.9805904794680657, 0.9214736253472325], 
             UndirectedEdge[83, 197] -> 
             RGBColor[
              0.9164471489214862, 0.6737245560050689, 0.534114411639826], 
             UndirectedEdge[243, 283] -> 
             RGBColor[
              0.6466191425526432, 0.7139161177704824, 0.899457696684746], 
             UndirectedEdge[95, 225] -> 
             RGBColor[
              0.2575765092536425, 0.3880596208924811, 0.9379799732004728], 
             UndirectedEdge[21, 74] -> 
             RGBColor[
              0.19973960321144332`, 0.32726936557048675`, 0.9346862469634045],
              UndirectedEdge[62, 225] -> 
             RGBColor[
              0.21463682483983898`, 0.34292729004033573`, 0.9355346216966771],
              UndirectedEdge[236, 267] -> 
             RGBColor[
              0.21381850493226368`, 0.3420671839329953, 0.9354880195885366], 
             UndirectedEdge[123, 300] -> 
             RGBColor[
              0.21212454910682327`, 0.34028672895745476`, 0.9353915513102607],
              UndirectedEdge[111, 218] -> 
             RGBColor[
              0.7906966430720825, 0.8363639438748425, 0.9515975962507148], 
             UndirectedEdge[61, 161] -> 
             RGBColor[
              0.23945694414961366`, 0.369014809121365, 0.9369480907732928], 
             UndirectedEdge[58, 180] -> 
             RGBColor[
              0.1930127612329003, 0.32019902814462275`, 0.9343031632641974], 
             UndirectedEdge[188, 236] -> 
             RGBColor[
              0.29364767479578224`, 0.42161628358526776`, 0.9401936825679285],
              UndirectedEdge[41, 268] -> 
             RGBColor[
              0.19682209771404596`, 0.32420288231218963`, 0.9345200993413902],
              UndirectedEdge[65, 138] -> 
             RGBColor[
              0.30437559706733064`, 0.4308950373883661, 0.9408777408234891], 
             UndirectedEdge[241, 291] -> 
             RGBColor[
              0.956499515277976, 0.9665294292639133, 0.9362543369482514], 
             UndirectedEdge[270, 295] -> 
             RGBColor[
              0.20488097831595456`, 0.3326732767873375, 0.9349790406696236], 
             UndirectedEdge[127, 212] -> 
             RGBColor[
              0.2911019408470156, 0.4195904504094406, 0.9400249109602461], 
             UndirectedEdge[105, 274] -> 
             RGBColor[
              0.373443394956703, 0.4953127699434419, 0.9451737605551122], 
             UndirectedEdge[128, 142] -> 
             RGBColor[
              0.8374379233542384, 0.28876986106910485`, 0.18348390372509257`],
              UndirectedEdge[38, 57] -> 
             RGBColor[
              0.18289757268776397`, 0.30956732364368866`, 0.9337271182406324],
              UndirectedEdge[135, 255] -> 
             RGBColor[
              0.28954719045708177`, 0.4163676580228129, 0.9399945385263857], 
             UndirectedEdge[46, 196] -> 
             RGBColor[
              0.2038842250820344, 0.33162562594068223`, 0.9349222770475161], 
             UndirectedEdge[138, 210] -> 
             RGBColor[
              0.35148342859896836`, 0.4711989277702072, 0.9440171598227016], 
             UndirectedEdge[72, 109] -> 
             RGBColor[
              0.9111133090638942, 0.6092004544506938, 0.4723013817192375], 
             UndirectedEdge[277, 282] -> 
             RGBColor[
              0.7168216670755537, 0.7717675564528452, 0.7149933619542863], 
             UndirectedEdge[62, 117] -> 
             RGBColor[
              0.1935934216908487, 0.32080933910192594`, 0.9343362310182673], 
             UndirectedEdge[33, 126] -> 
             RGBColor[
              0.2119973945219809, 0.3401530814267192, 0.9353843100447624], 
             UndirectedEdge[217, 278] -> 
             RGBColor[
              0.20033411359999898`, 0.32789423368299453`, 0.9347201034505334],
              UndirectedEdge[228, 264] -> 
             RGBColor[
              0.3612335072093944, 0.48614499734720384`, 0.9442808957993838], 
             UndirectedEdge[121, 239] -> 
             RGBColor[
              0.2315127682951095, 0.3606649766084402, 0.9364956817107337], 
             UndirectedEdge[56, 84] -> 
             RGBColor[
              0.1934123059271604, 0.32061897495088687`, 0.9343259167434621], 
             UndirectedEdge[45, 120] -> 
             RGBColor[
              0.2895125289687292, 0.4216264024736376, 0.9397986822781397], 
             UndirectedEdge[67, 234] -> 
             RGBColor[
              0.18654108215101917`, 0.31339688310141245`, 0.9339346107144755],
              UndirectedEdge[153, 192] -> 
             RGBColor[
              0.2758432306623323, 0.4052369526728678, 0.9390942768006172], 
             UndirectedEdge[77, 127] -> 
             RGBColor[
              0.3813089695721926, 0.5046923971225378, 0.9455176482562255], 
             UndirectedEdge[36, 152] -> 
             RGBColor[
              0.18192632080115292`, 0.3085464763299341, 0.9336718068825283], 
             UndirectedEdge[22, 122] -> 
             RGBColor[
              0.18679089642314464`, 0.31365945374055604`, 0.9339488372677058],
              UndirectedEdge[68, 218] -> 
             RGBColor[
              0.9220230883129681, 0.9398481441591451, 0.964270119789284], 
             UndirectedEdge[56, 148] -> 
             RGBColor[
              0.2228269723814797, 0.3515356543919468, 0.936001038482936], 
             UndirectedEdge[7, 130] -> 
             RGBColor[
              0.92506143421404, 0.8207777707366587, 0.6185929179813181], 
             UndirectedEdge[58, 296] -> 
             RGBColor[
              0.18917402722894824`, 0.3161642753166758, 0.9340845530415703], 
             UndirectedEdge[104, 116] -> 
             RGBColor[
              0.3112198168736299, 0.4420066574870038, 0.9411240550973782], 
             UndirectedEdge[252, 279] -> 
             RGBColor[
              0.23730450403035436`, 0.36675245808343765`, 0.9368255124927507],
              UndirectedEdge[64, 173] -> 
             RGBColor[
              0.21829574180286104`, 0.34677304375720647`, 0.9357429916048386],
              UndirectedEdge[109, 155] -> 
             RGBColor[
              0.9595624996907148, 0.8684305979471943, 0.514184885580798], 
             UndirectedEdge[151, 258] -> 
             RGBColor[
              0.4689947888884989, 0.5767176597098022, 0.9521890651333698], 
             UndirectedEdge[167, 216] -> 
             RGBColor[
              0.8870728705076437, 0.5791108855648315, 0.22743169222500162`], 
             UndirectedEdge[12, 258] -> 
             RGBColor[
              0.3848908244823526, 0.507794819816456, 0.9457458808837911], 
             UndirectedEdge[151, 239] -> 
             RGBColor[
              0.41770207455751684`, 0.5257103442374987, 0.9491616700514242], 
             UndirectedEdge[136, 226] -> 
             RGBColor[
              0.6894363159019072, 0.7515352642002422, 0.911828216152313], 
             UndirectedEdge[59, 210] -> 
             RGBColor[
              0.7283433684413259, 0.785018817714684, 0.9248382115325371], 
             UndirectedEdge[191, 205] -> 
             RGBColor[
              0.29986821230051, 0.4266293598594382, 0.9406037744698572], 
             UndirectedEdge[212, 276] -> 
             RGBColor[
              0.23737124141047264`, 0.3668226033013362, 0.9368293130878194], 
             UndirectedEdge[218, 292] -> 
             RGBColor[
              0.8704525733936984, 0.8991011858444631, 0.9592520377831382], 
             UndirectedEdge[144, 245] -> 
             RGBColor[
              0.2114412038308669, 0.3395684897458317, 0.9353526358077138], 
             UndirectedEdge[1, 277] -> 
             RGBColor[
              0.9058522963240394, 0.5660756214140101, 0.3231115936678419], 
             UndirectedEdge[64, 239] -> 
             RGBColor[
              0.23644031537818827`, 0.3658441410172859, 0.9367762982274624], 
             UndirectedEdge[128, 256] -> 
             RGBColor[
              0.8314341794329242, 0.2426224544325225, 0.1777347117657832], 
             UndirectedEdge[7, 81] -> 
             RGBColor[
              0.9138922902616244, 0.7722436147323656, 0.6093859995388808], 
             UndirectedEdge[32, 145] -> 
             RGBColor[
              0.9262900127477325, 0.9421433350511439, 0.920438952214905], 
             UndirectedEdge[84, 247] -> 
             RGBColor[
              0.1926121673846783, 0.3197779786110244, 0.9342803500371666], 
             UndirectedEdge[215, 259] -> 
             RGBColor[
              0.20495150510474192`, 0.33274740491400967`, 0.9349830570659099],
              UndirectedEdge[187, 233] -> 
             RGBColor[
              0.2150678926487934, 0.3433803696388245, 0.9355591703706895], 
             UndirectedEdge[37, 152] -> 
             RGBColor[
              0.20454390254542953`, 0.33231898878067745`, 0.9349598447031511],
              UndirectedEdge[257, 300] -> 
             RGBColor[
              0.20486085687830097`, 0.33265212788059073`, 0.9349778947835161],
              UndirectedEdge[10, 244] -> 
             RGBColor[
              0.1899533548754444, 0.3169833980853699, 0.9341289345981263], 
             UndirectedEdge[98, 157] -> 
             RGBColor[
              0.18079506708635712`, 0.3073574569500555, 0.9336073836570105], 
             UndirectedEdge[13, 271] -> 
             RGBColor[
              0.2779619784734704, 0.40721689761763513`, 0.9392239799901998], 
             UndirectedEdge[202, 203] -> 
             RGBColor[
              0.9018479137485027, 0.71981963766744, 0.6008453442170419], 
             UndirectedEdge[166, 195] -> 
             RGBColor[
              0.184909234384039, 0.31168170763319203`, 0.9338416793982484], 
             UndirectedEdge[260, 287] -> 
             RGBColor[
              0.25058425907026255`, 0.38071032261548143`, 0.9375817748966364],
              UndirectedEdge[212, 214] -> 
             RGBColor[
              0.21709951040225656`, 0.3455157287097197, 0.9356748679962401], 
             UndirectedEdge[25, 113] -> 
             RGBColor[
              0.22937411863723062`, 0.3584171202197894, 0.9363738887765662], 
             UndirectedEdge[244, 280] -> 
             RGBColor[
              0.22575834254074034`, 0.3546167102889326, 0.9361679756769326], 
             UndirectedEdge[58, 134] -> 
             RGBColor[
              0.21796998739019388`, 0.34643065521547056`, 0.9357244403729478],
              UndirectedEdge[64, 263] -> 
             RGBColor[
              0.22259690617654707`, 0.3512938402235227, 0.9359879365529176], 
             UndirectedEdge[182, 261] -> 
             RGBColor[
              0.24954002688104543`, 0.37961276837646946`, 0.9375223074182637],
              UndirectedEdge[150, 277] -> 
             RGBColor[
              0.9502103007628988, 0.8290380865568148, 0.362523350207251], 
             UndirectedEdge[86, 202] -> 
             RGBColor[
              0.7303739014473327, 0.5842147173946636, 0.5857853158660629], 
             UndirectedEdge[257, 267] -> 
             RGBColor[
              0.19014093188722048`, 0.31718055341781604`, 0.9341396168314517],
              UndirectedEdge[134, 245] -> 
             RGBColor[
              0.2350207777833922, 0.3643521170012733, 0.9366954576614566], 
             UndirectedEdge[187, 297] -> 
             RGBColor[
              0.20836666181027574`, 0.33633695114496726`, 0.9351775451880184],
              UndirectedEdge[75, 292] -> 
             RGBColor[
              0.5533224742847231, 0.6429700886267707, 0.9602576695267473], 
             UndirectedEdge[54, 174] -> 
             RGBColor[
              0.23862082785776215`, 0.3681359978857943, 0.936900475187395], 
             UndirectedEdge[44, 108] -> 
             RGBColor[
              0.27845239042381165`, 0.4093105366510138, 0.9391941231422369], 
             UndirectedEdge[94, 141] -> 
             RGBColor[
              0.5453682927010454, 0.6337189411498153, 0.9602178278094844], 
             UndirectedEdge[185, 262] -> 
             RGBColor[
              0.41669813660407123`, 0.5328210539055609, 0.9483611851595068], 
             UndirectedEdge[40, 202] -> 
             RGBColor[
              0.777902189496511, 0.6220822630055047, 0.5900178581775892], 
             UndirectedEdge[110, 191] -> 
             RGBColor[
              0.20664696570435293`, 0.3345294415026117, 0.9350796110388486], 
             UndirectedEdge[92, 125] -> 
             RGBColor[
              0.8333745807247173, 0.2575372290505118, 0.17959284223417404`], 
             UndirectedEdge[72, 226] -> 
             RGBColor[
              0.9078362964581086, 0.6078453255228189, 0.5266099612338768], 
             UndirectedEdge[130, 162] -> 
             RGBColor[
              0.9515757296113414, 0.8393631712246421, 0.5204689724050278], 
             UndirectedEdge[29, 43] -> 
             RGBColor[
              0.21042089134742065`, 0.3384960766341818, 0.9352945305211986], 
             UndirectedEdge[152, 268] -> 
             RGBColor[
              0.1937845276020504, 0.3210102035314135, 0.9343471142171944], 
             UndirectedEdge[4, 62] -> 
             RGBColor[
              0.21110734445904222`, 0.33921758237813715`, 0.9353336230103891],
              UndirectedEdge[18, 184] -> 
             RGBColor[
              0.19573226525779447`, 0.3230573993013006, 0.9344580349952694], 
             UndirectedEdge[95, 159] -> 
             RGBColor[
              0.2893985943419117, 0.4215066499569798, 0.9397921938696936], 
             UndirectedEdge[154, 255] -> 
             RGBColor[
              0.43165774296703474`, 0.5471078244024314, 0.9490557746765065], 
             UndirectedEdge[140, 269] -> 
             RGBColor[
              0.8952419489497732, 0.5276340204064351, 0.25723456251694715`], 
             UndirectedEdge[10, 161] -> 
             RGBColor[
              0.19602879349749167`, 0.3233690692821986, 0.9344749218398459], 
             UndirectedEdge[216, 293] -> 
             RGBColor[
              0.8831112421654739, 0.5621172753839567, 0.2241774940682837], 
             UndirectedEdge[188, 294] -> 
             RGBColor[
              0.445956916802145, 0.5584408477111231, 0.9502576320388609], 
             UndirectedEdge[32, 282] -> 
             RGBColor[
              0.7141541547436409, 0.7726234711925095, 0.9015995382329896], 
             UndirectedEdge[251, 282] -> 
             RGBColor[
              0.363119718775744, 0.4867984505328162, 0.944436976695407], 
             UndirectedEdge[181, 299] -> 
             RGBColor[
              0.9024939314125389, 0.5550617691490322, 0.28339483620290606`], 
             UndirectedEdge[60, 159] -> 
             RGBColor[
              0.28925410608148494`, 0.42135478363418655`, 0.9397839654770135],
              UndirectedEdge[137, 217] -> 
             RGBColor[
              0.23078620352350526`, 0.3599013109666169, 0.9364543049218471], 
             UndirectedEdge[20, 152] -> 
             RGBColor[
              0.20076184690853469`, 0.3283438085101236, 0.9347444622296798], 
             UndirectedEdge[62, 196] -> 
             RGBColor[
              0.2023683700722644, 0.33003236621465526`, 0.9348359513472162], 
             UndirectedEdge[251, 289] -> 
             RGBColor[
              0.26452594049436573`, 0.3953639137458709, 0.9383757330288698], 
             UndirectedEdge[104, 283] -> 
             RGBColor[
              0.32045429654903324`, 0.4517126811256811, 0.9416499450537039], 
             UndirectedEdge[45, 294] -> 
             RGBColor[
              0.4179920843483252, 0.5334044550653643, 0.9485055663485399], 
             UndirectedEdge[15, 158] -> 
             RGBColor[
              0.22566086224390924`, 0.3545142523163553, 0.9361624243182372], 
             UndirectedEdge[150, 237] -> 
             RGBColor[
              0.8662420388840522, 0.43217832029940567`, 0.20800123867959472`],
              UndirectedEdge[169, 228] -> 
             RGBColor[
              0.5154980125146456, 0.6168087674389304, 0.9552040569175313], 
             UndirectedEdge[159, 251] -> 
             RGBColor[
              0.2884240455436301, 0.4204823373800232, 0.9397366947573472], 
             UndirectedEdge[203, 293] -> 
             RGBColor[
              0.9184419291701429, 0.7951691860663403, 0.6146917974413972], 
             UndirectedEdge[145, 282] -> 
             RGBColor[
              0.6527680048201097, 0.7255950154401895, 0.9681370826346918], 
             UndirectedEdge[195, 234] -> 
             RGBColor[
              0.18893962070800485`, 0.3159178992009325, 0.934071203936976], 
             UndirectedEdge[156, 270] -> 
             RGBColor[
              0.3036653348674415, 0.42857413928414156`, 0.9408949377483093], 
             UndirectedEdge[25, 134] -> 
             RGBColor[
              0.21795734402989536`, 0.34641736624216146`, 0.935723720352283], 
             UndirectedEdge[158, 276] -> 
             RGBColor[
              0.21715975035837445`, 0.34557904472303347`, 0.935678298572624], 
             UndirectedEdge[268, 280] -> 
             RGBColor[
              0.23353122209160865`, 0.3627864995259231, 0.9366106296684096], 
             UndirectedEdge[8, 186] -> 
             RGBColor[
              0.19879211006828354`, 0.3262734902024908, 0.934632288630592], 
             UndirectedEdge[32, 256] -> 
             RGBColor[
              0.9028021334843555, 0.5639903166724234, 0.5093513433881616], 
             UndirectedEdge[60, 168] -> 
             RGBColor[
              0.3438394161380286, 0.4702523109805432, 0.9432028328564219], 
             UndirectedEdge[162, 216] -> 
             RGBColor[
              0.9289059974124116, 0.7386075300235558, 0.5016656812244851], 
             UndirectedEdge[106, 115] -> 
             RGBColor[
              0.6067946716231568, 0.6858798777418896, 0.9651595250499304], 
             UndirectedEdge[77, 276] -> 
             RGBColor[
              0.3275782701356497, 0.45192455001443343`, 0.9423220503837988], 
             UndirectedEdge[80, 281] -> 
             RGBColor[
              0.9786349916305042, 0.9618175926615335, 0.6467591064594813], 
             UndirectedEdge[130, 293] -> 
             RGBColor[
              0.9057809743644036, 0.6628729165850431, 0.24298078524882644`], 
             UndirectedEdge[39, 118] -> 
             RGBColor[
              0.19522260799965463`, 0.322521717208859, 0.9344290107683887], 
             UndirectedEdge[58, 245] -> 
             RGBColor[
              0.20819170713916685`, 0.33615306269286493`, 0.9351675817783212],
              UndirectedEdge[54, 143] -> 
             RGBColor[
              0.2754657226956103, 0.40686231846163223`, 0.9389987374412732], 
             UndirectedEdge[239, 258] -> 
             RGBColor[
              0.28886880526886394`, 0.4180452286151569, 0.9398683740473033], 
             UndirectedEdge[184, 222] -> 
             RGBColor[
              0.2064576757790399, 0.33433048578943325`, 0.9350688312576314], 
             UndirectedEdge[143, 298] -> 
             RGBColor[
              0.28351617500257303`, 0.41532385426440727`, 0.9394571987905778],
              UndirectedEdge[203, 269] -> 
             RGBColor[
              0.9551449948812127, 0.9368848088945971, 0.6707830617471834], 
             UndirectedEdge[107, 139] -> 
             RGBColor[
              0.4245992235592372, 0.5421882392946853, 0.9482760649602114], 
             UndirectedEdge[108, 283] -> 
             RGBColor[
              0.2732531217435669, 0.4045367345740317, 0.9388727330903042], 
             UndirectedEdge[173, 186] -> 
             RGBColor[
              0.19720146830174806`, 0.32460162485334904`, 0.9345417039351314],
              UndirectedEdge[164, 296] -> 
             RGBColor[
              0.18458413953272382`, 0.31134001233225567`, 0.9338231657274008],
              UndirectedEdge[11, 116] -> 
             RGBColor[
              0.4095833128093886, 0.5250728013946587, 0.9479805946176828], 
             UndirectedEdge[43, 229] -> 
             RGBColor[
              0.221649468641255, 0.3502980233029215, 0.935933981386891], 
             UndirectedEdge[128, 149] -> 
             RGBColor[
              0.8702220308538466, 0.4824125424483211, 0.2125931493102241], 
             UndirectedEdge[221, 232] -> 
             RGBColor[
              0.18705168190288157`, 0.31393355581451393`, 0.9339636886149794],
              UndirectedEdge[8, 85] -> 
             RGBColor[
              0.21830835870760254`, 0.3467863049240477, 0.9357437101188987], 
             UndirectedEdge[20, 41] -> 
             RGBColor[
              0.20379941702053028`, 0.3315364872908998, 0.9349174473538756], 
             UndirectedEdge[108, 252] -> 
             RGBColor[
              0.23931387407336885`, 0.3688644334000649, 0.9369399431441039], 
             UndirectedEdge[65, 241] -> 
             RGBColor[
              0.6817937974014621, 0.7449457823928316, 0.912446971452788], 
             UndirectedEdge[231, 245] -> 
             RGBColor[
              0.2282116135363889, 0.3571952536517242, 0.9363076858308454], 
             UndirectedEdge[80, 167] -> 
             RGBColor[
              0.9432452158034876, 0.8059374712804274, 0.30837604527604406`], 
             UndirectedEdge[17, 201] -> 
             RGBColor[
              0.7745136164836781, 0.5590600650268467, 0.5810861179764505], 
             UndirectedEdge[57, 223] -> 
             RGBColor[
              0.1805830172649961, 0.30713457914306985`, 0.9335953077333836], 
             UndirectedEdge[162, 202] -> 
             RGBColor[
              0.9289595063027041, 0.738850501397055, 0.5017103303541681], 
             UndirectedEdge[3, 59] -> 
             RGBColor[
              0.9696130276591681, 0.9767225112372966, 0.930252756027731], 
             UndirectedEdge[180, 187] -> 
             RGBColor[
              0.20981238961313842`, 0.3378565027302129, 0.9352598772476289], 
             UndirectedEdge[193, 215] -> 
             RGBColor[
              0.252152731139514, 0.38235888620713765`, 0.9376710970606339], 
             UndirectedEdge[43, 78] -> 
             RGBColor[
              0.20985899682898168`, 0.3379054898691324, 0.9352625314596219], 
             UndirectedEdge[56, 251] -> 
             RGBColor[
              0.2424819913817221, 0.3721943255613833, 0.9371203627380049], 
             UndirectedEdge[261, 284] -> 
             RGBColor[
              0.2428470796826115, 0.3725780565135533, 0.937141153976641], 
             UndirectedEdge[36, 41] -> 
             RGBColor[
              0.18496389091314852`, 0.31173915511071026`, 0.9338447920067241],
              UndirectedEdge[95, 168] -> 
             RGBColor[
              0.3439839043984553, 0.4704041773033365, 0.943211061249102], 
             UndirectedEdge[194, 280] -> 
             RGBColor[
              0.4740092277386598, 0.5736772866128733, 0.9537854496422005], 
             UndirectedEdge[99, 182] -> 
             RGBColor[
              0.22500890422772363`, 0.3538290031048185, 0.9361252962737008], 
             UndirectedEdge[94, 97] -> 
             RGBColor[
              0.622873487370591, 0.7022274882781143, 0.9651059553417796], 
             UndirectedEdge[79, 240] -> 
             RGBColor[
              0.18183565807480434`, 0.3084511840561929, 0.9336666437743861], 
             UndirectedEdge[83, 198] -> 
             RGBColor[
              0.9055718234570376, 0.665970901350738, 0.5685171958085309], 
             UndirectedEdge[69, 213] -> 
             RGBColor[
              0.20497196381527677`, 0.33276890831593897`, 0.934984222159209], 
             UndirectedEdge[214, 286] -> 
             RGBColor[
              0.21086056333637188`, 0.3389581997713838, 0.9353195691905329], 
             UndirectedEdge[277, 293] -> 
             RGBColor[
              0.946384976906248, 0.8125848782402458, 0.35937882583905917`], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.23002654529780098`, 0.3591028620062883, 0.9364110435097069], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.4656160294018773, 0.5758295097005381, 0.9514105681730911], 
             UndirectedEdge[43, 199] -> 
             RGBColor[
              0.21199067610024028`, 0.34014601993949717`, 0.9353839274405833],
              UndirectedEdge[192, 222] -> 
             RGBColor[
              0.2760214326902352, 0.40542425430285495`, 0.93910442514248], 
             UndirectedEdge[130, 202] -> 
             RGBColor[
              0.8891869589427635, 0.5875233681861427, 0.22913433202447103`], 
             UndirectedEdge[4, 265] -> 
             RGBColor[
              0.22162675469537457`, 0.35027414950565383`, 0.9359326878612754],
              UndirectedEdge[121, 173] -> 
             RGBColor[
              0.21336819471978227`, 0.34159387934836083`, 0.9354623750881099],
              UndirectedEdge[53, 107] -> 
             RGBColor[
              0.3121763440598402, 0.43622685441542786`, 0.9414269663560839], 
             UndirectedEdge[172, 238] -> 
             RGBColor[
              0.18901379750666059`, 0.31599586371940025`, 0.9340754281959247],
              UndirectedEdge[210, 211] -> 
             RGBColor[
              0.3712058892361785, 0.49192848437614356`, 0.9451403247792249], 
             UndirectedEdge[180, 221] -> 
             RGBColor[
              0.19054010670567417`, 0.3176001114611562, 0.9341623492468364], 
             UndirectedEdge[196, 212] -> 
             RGBColor[
              0.2182141780704709, 0.3466873151030251, 0.9357383466709418], 
             UndirectedEdge[160, 176] -> 
             RGBColor[
              0.19497852177206426`, 0.3222651671077009, 0.9344151104188206], 
             UndirectedEdge[115, 193] -> 
             RGBColor[
              0.3156462416789386, 0.4451205438424978, 0.9414324679079064], 
             UndirectedEdge[21, 300] -> 
             RGBColor[
              0.2096118710905434, 0.33764574504935696`, 0.9352484580144076], 
             UndirectedEdge[75, 235] -> 
             RGBColor[
              0.3707116092284409, 0.495513496231598, 0.9448423938259995], 
             UndirectedEdge[77, 255] -> 
             RGBColor[
              0.38990028243638014`, 0.512133760513557, 0.9460650791149319], 
             UndirectedEdge[62, 286] -> 
             RGBColor[
              0.21128388043674812`, 0.3394031328837336, 0.935343676473158], 
             UndirectedEdge[46, 225] -> 
             RGBColor[
              0.21615267984960895`, 0.3445205497663627, 0.935620947396977], 
             UndirectedEdge[37, 161] -> 
             RGBColor[
              0.21411146518921928`, 0.3423751037378088, 0.9355047032417743], 
             UndirectedEdge[3, 162] -> 
             RGBColor[
              0.972783323199716, 0.9780335099161923, 0.8777127544589929], 
             UndirectedEdge[107, 274] -> 
             RGBColor[
              0.43576092708699476`, 0.5515917926842843, 0.9490602651560203], 
             UndirectedEdge[6, 147] -> 
             RGBColor[
              0.2119963836374878, 0.34015201892302305`, 0.935384252476386], 
             UndirectedEdge[8, 135] -> 
             RGBColor[
              0.2087723681564475, 0.33676337423806185`, 0.9352006495642442], 
             UndirectedEdge[186, 249] -> 
             RGBColor[
              0.20028634308592377`, 0.3278440238438759, 0.934717382990427], 
             UndirectedEdge[277, 281] -> 
             RGBColor[
              0.9857363810754343, 0.9854586098022267, 0.7010160851792143], 
             UndirectedEdge[256, 277] -> 
             RGBColor[
              0.9054696458162683, 0.5631344019327589, 0.3227451671094582], 
             UndirectedEdge[8, 249] -> 
             RGBColor[
              0.20596246033793864`, 0.3338099829623634, 0.9350406294708662], 
             UndirectedEdge[114, 254] -> 
             RGBColor[
              0.2789569494583814, 0.4096039374484629, 0.9392315319348887], 
             UndirectedEdge[223, 270] -> 
             RGBColor[
              0.19716475878398335`, 0.32456304082266046`, 0.9345396133824015],
              UndirectedEdge[120, 294] -> 
             RGBColor[
              0.40756986398437334`, 0.5224500406559134, 0.9479120363171062], 
             UndirectedEdge[23, 290] -> 
             RGBColor[
              0.9678787961151241, 0.9075534182585008, 0.5509781065817215], 
             UndirectedEdge[7, 293] -> 
             RGBColor[
              0.9190392263270429, 0.795614649307972, 0.6136807291548138], 
             UndirectedEdge[95, 191] -> 
             RGBColor[
              0.2574665501142888, 0.38794404686520834`, 0.9379737111901566], 
             UndirectedEdge[65, 194] -> 
             RGBColor[
              0.5317344651989768, 0.6279967791452647, 0.9573054453238024], 
             UndirectedEdge[94, 188] -> 
             RGBColor[
              0.5763766141360973, 0.661954233683196, 0.9621432156948482], 
             UndirectedEdge[24, 162] -> 
             RGBColor[
              0.9575561451976635, 0.8630735261690534, 0.5252809551641785], 
             UndirectedEdge[34, 84] -> 
             RGBColor[
              0.1855804331499768, 0.3123871800926523, 0.9338799031750189], 
             UndirectedEdge[130, 201] -> 
             RGBColor[
              0.8785836373176991, 0.5188649537574892, 0.21948349310732407`], 
             UndirectedEdge[74, 260] -> 
             RGBColor[
              0.23203447362151203`, 0.3612133219845175, 0.9365253920572785], 
             UndirectedEdge[69, 85] -> 
             RGBColor[
              0.21985867650040533`, 0.3484157872201088, 0.9358319984237091], 
             UndirectedEdge[220, 262] -> 
             RGBColor[
              0.318464636651424, 0.44980618598534605`, 0.9415298717668166], 
             UndirectedEdge[26, 262] -> 
             RGBColor[
              0.26646771810795733`, 0.39740484513356716`, 0.9384863143913613],
              UndirectedEdge[217, 270] -> 
             RGBColor[
              0.20643869531729672`, 0.3343105361207104, 0.9350677503484142], 
             UndirectedEdge[221, 245] -> 
             RGBColor[
              0.20571905261194073`, 0.33355414600939837`, 0.93502676776096], 
             UndirectedEdge[3, 24] -> 
             RGBColor[
              0.9389911914260977, 0.8504167316496911, 0.6099487388884464], 
             UndirectedEdge[59, 197] -> 
             RGBColor[
              0.9856746989571257, 0.9883441341223966, 0.8870708411785275], 
             UndirectedEdge[54, 235] -> 
             RGBColor[
              0.32626536687632174`, 0.4510335953926109, 0.9422293781681247], 
             UndirectedEdge[159, 282] -> 
             RGBColor[
              0.36593647358390397`, 0.4897590384287621, 0.9445973867147164], 
             UndirectedEdge[6, 53] -> 
             RGBColor[
              0.21323620369391516`, 0.3414551484114601, 0.9354548583944501], 
             UndirectedEdge[31, 210] -> 
             RGBColor[
              0.4456637990054052, 0.5599347702274033, 0.949756030710805], 
             UndirectedEdge[137, 273] -> 
             RGBColor[
              0.25023215692458567`, 0.3803402409358096, 0.9375617232003286], 
             UndirectedEdge[99, 259] -> 
             RGBColor[
              0.19041774683741108`, 0.3174715034815479, 0.934155381033354], 
             UndirectedEdge[16, 151] -> 
             RGBColor[
              0.42230921801132515`, 0.5305527441172178, 0.9494240400554605], 
             UndirectedEdge[24, 227] -> 
             RGBColor[
              0.9382342504393061, 0.7928264157474236, 0.2691600319562284], 
             UndirectedEdge[87, 202] -> 
             RGBColor[
              0.9298593928281911, 0.7373816975657997, 0.35298070205443455`], 
             UndirectedEdge[17, 94] -> 
             RGBColor[
              0.7502759773076164, 0.8048405628721153, 0.9757441557565323], 
             UndirectedEdge[5, 92] -> 
             RGBColor[
              0.9012836886352362, 0.5787149390499657, 0.259870153785709], 
             UndirectedEdge[72, 290] -> 
             RGBColor[
              0.8879131967834442, 0.526174959102152, 0.22577038316322898`], 
             UndirectedEdge[103, 212] -> 
             RGBColor[
              0.327349136755672, 0.45098594966848016`, 0.9423345502314089], 
             UndirectedEdge[112, 133] -> 
             RGBColor[
              0.18726032665159403`, 0.3141528546742519, 0.9339755706247563], 
             UndirectedEdge[71, 244] -> 
             RGBColor[
              0.20641030875985014`, 0.33428070004902233`, 0.9350661337759618],
              UndirectedEdge[142, 197] -> 
             RGBColor[
              0.9081386520820702, 0.6098618084907887, 0.5261581856832962], 
             UndirectedEdge[117, 196] -> 
             RGBColor[
              0.1942847722586868, 0.32153599238288155`, 0.9343756024103442], 
             UndirectedEdge[131, 188] -> 
             RGBColor[
              0.2926361203769149, 0.4205530757547836, 0.9401360760402346], 
             UndirectedEdge[13, 282] -> 
             RGBColor[
              0.38696044305919663`, 0.509587419405664, 0.9458777551494157], 
             UndirectedEdge[139, 143] -> 
             RGBColor[
              0.37380885559171856`, 0.49802499695333824`, 0.9450460153054621],
              UndirectedEdge[45, 89] -> 
             RGBColor[
              0.34033954683031736`, 0.4683920819989782, 0.9429369415722573], 
             UndirectedEdge[127, 269] -> 
             RGBColor[
              0.6610000720463691, 0.698853165460656, 0.646849788175898], 
             UndirectedEdge[25, 79] -> 
             RGBColor[
              0.18712823581077753`, 0.3140140188255107, 0.9339680482467827], 
             UndirectedEdge[29, 78] -> 
             RGBColor[
              0.1946932984138494, 0.3219653792740117, 0.9343988673705204], 
             UndirectedEdge[150, 179] -> 
             RGBColor[
              0.7150830892215184, 0.6470263643951079, 0.5999650595216117], 
             UndirectedEdge[11, 198] -> 
             RGBColor[
              0.7482029346182517, 0.8019514484742061, 0.9505539165512161], 
             UndirectedEdge[135, 286] -> 
             RGBColor[
              0.2169836251808333, 0.34539392599445645`, 0.9356682685043168], 
             UndirectedEdge[101, 104] -> 
             RGBColor[
              0.49120791951509923`, 0.5945373978105576, 0.9540278714950781], 
             UndirectedEdge[3, 290] -> 
             RGBColor[
              0.9503146533364857, 0.8953104848043834, 0.619059862137357], 
             UndirectedEdge[158, 212] -> 
             RGBColor[
              0.21315714444874106`, 0.34137205213213645`, 0.9354503560873951],
              UndirectedEdge[102, 175] -> 
             RGBColor[
              0.18740197098760464`, 0.3143017318521686, 0.9339836370601481], 
             UndirectedEdge[103, 255] -> 
             RGBColor[
              0.3936737549660358, 0.5154021527585007, 0.9463055214477708], 
             UndirectedEdge[3, 65] -> 
             RGBColor[
              0.6658408786786703, 0.7333691314923763, 0.9538265746888542], 
             UndirectedEdge[148, 270] -> 
             RGBColor[
              0.22956819937889494`, 0.35862111138470837`, 0.9363849413876872],
              UndirectedEdge[49, 298] -> 
             RGBColor[
              0.23487979924778435`, 0.36420393962179404`, 0.9366874291424127],
              UndirectedEdge[15, 103] -> 
             RGBColor[
              0.33985285455084013`, 0.464128149852699, 0.9430466184622509], 
             UndirectedEdge[4, 15] -> 
             RGBColor[
              0.23945687025241685`, 0.36901473145072583`, 0.9369480865649568],
              UndirectedEdge[83, 290] -> 
             RGBColor[
              0.8964817615318641, 0.5920367025275223, 0.23397565044312565`], 
             UndirectedEdge[182, 284] -> 
             RGBColor[
              0.24765066246750966`, 0.3776269265852207, 0.937414710909977], 
             UndirectedEdge[32, 92] -> 
             RGBColor[
              0.9096154260623872, 0.6163602690310206, 0.515875760055398], 
             UndirectedEdge[87, 203] -> 
             RGBColor[
              0.9651365709425674, 0.970190636874684, 0.7434503562978652], 
             UndirectedEdge[115, 169] -> 
             RGBColor[
              0.47823384946439584`, 0.5845324223560975, 0.9528296173993749], 
             UndirectedEdge[111, 143] -> 
             RGBColor[
              0.46054913753176646`, 0.5687866450741914, 0.9517800380473413], 
             UndirectedEdge[163, 274] -> 
             RGBColor[
              0.5420984734158494, 0.6391389878337358, 0.9570951240808855], 
             UndirectedEdge[96, 260] -> 
             RGBColor[
              0.22955901197049378`, 0.3586114548359634, 0.9363844181783704], 
             UndirectedEdge[27, 227] -> 
             RGBColor[
              0.9612729955532987, 0.8800632676191081, 0.309071745135731], 
             UndirectedEdge[103, 205] -> 
             RGBColor[
              0.39684467535749024`, 0.5181486446264856, 0.9465075696911796], 
             UndirectedEdge[27, 216] -> 
             RGBColor[
              0.9181526107527858, 0.6982276036287391, 0.27381337883344126`], 
             UndirectedEdge[145, 293] -> 
             RGBColor[
              0.8823313146508039, 0.7664123372275902, 0.6125225465194646], 
             UndirectedEdge[96, 133] -> 
             RGBColor[
              0.19311989172231955`, 0.3203116290814677, 0.9343092641870845], 
             UndirectedEdge[127, 159] -> 
             RGBColor[
              0.3200380232724909, 0.45000410769220556`, 0.9416727780472791], 
             UndirectedEdge[186, 214] -> 
             RGBColor[
              0.19697318905997124`, 0.32436168889650174`, 0.9345287037700212],
              UndirectedEdge[111, 262] -> 
             RGBColor[
              0.459021775002635, 0.5671812902156966, 0.9516930570108376], 
             UndirectedEdge[33, 157] -> 
             RGBColor[
              0.19152225944429985`, 0.31863241626153205`, 0.9342182813923363],
              UndirectedEdge[112, 131] -> 
             RGBColor[
              0.20931958090363292`, 0.3373385295306458, 0.9352318125206677], 
             UndirectedEdge[37, 55] -> 
             RGBColor[
              0.21435260419714997`, 0.34262855612424004`, 0.9355184357515427],
              UndirectedEdge[20, 71] -> 
             RGBColor[
              0.22116050761720274`, 0.349784094264723, 0.9359061357799242], 
             UndirectedEdge[37, 252] -> 
             RGBColor[
              0.23225528127463596`, 0.3614454048279645, 0.9365379667264683], 
             UndirectedEdge[120, 178] -> 
             RGBColor[
              0.2690508208241996, 0.4001198498665095, 0.9386334182696933], 
             UndirectedEdge[113, 231] -> 
             RGBColor[
              0.24940666839475117`, 0.3794726001519578, 0.9375147128497554], 
             UndirectedEdge[7, 181] -> 
             RGBColor[
              0.962306825108859, 0.9594739836095195, 0.6952739648323978], 
             UndirectedEdge[42, 299] -> 
             RGBColor[
              0.8281493166036277, 0.217373559290479, 0.1745891234107269], 
             UndirectedEdge[64, 234] -> 
             RGBColor[
              0.2147298520602665, 0.3430250675472716, 0.9355399194592591], 
             UndirectedEdge[78, 261] -> 
             RGBColor[
              0.21943392399577888`, 0.3479693454068822, 0.9358078093969358], 
             UndirectedEdge[10, 100] -> 
             RGBColor[
              0.18553288790448116`, 0.3123372070250937, 0.9338771955436248], 
             UndirectedEdge[6, 88] -> 
             RGBColor[
              0.21672673573205908`, 0.345123918896063, 0.935653639030243], 
             UndirectedEdge[36, 208] -> 
             RGBColor[
              0.1853248284213402, 0.31211852331657947`, 0.9338653468638564], 
             UndirectedEdge[92, 142] -> 
             RGBColor[
              0.830745140796793, 0.23732620153656223`, 0.1770748875896661], 
             UndirectedEdge[237, 293] -> 
             RGBColor[
              0.8624167150274014, 0.41572511198283674`, 0.2048567143114029], 
             UndirectedEdge[127, 145] -> 
             RGBColor[
              0.6068695545086966, 0.6858400847036329, 0.9652124739672545], 
             UndirectedEdge[90, 285] -> 
             RGBColor[
              0.20767787323688183`, 0.3356129906826123, 0.9351383196977351], 
             UndirectedEdge[134, 176] -> 
             RGBColor[
              0.21949584805110617`, 0.34803443151524305`, 0.9358113358802782],
              UndirectedEdge[28, 297] -> 
             RGBColor[
              0.18773159769962583`, 0.31464819042604353`, 0.9340024088137586],
              UndirectedEdge[20, 136] -> 
             RGBColor[
              0.3058098324986471, 0.43100159391667037`, 0.9410107128012115], 
             UndirectedEdge[113, 134] -> 
             RGBColor[
              0.25621583264175446`, 0.38662946350150684`, 0.9379024846803665],
              UndirectedEdge[12, 181] -> 
             RGBColor[
              0.707957046702949, 0.7559827796524516, 0.6749255302079116], 
             UndirectedEdge[84, 217] -> 
             RGBColor[
              0.19375308221906778`, 0.32097715244014635`, 0.9343453234491528],
              UndirectedEdge[126, 153] -> 
             RGBColor[
              0.2222787641449363, 0.35095945277692997`, 0.9359698188348664], 
             UndirectedEdge[217, 251] -> 
             RGBColor[
              0.24282276767362948`, 0.3725525030506428, 0.9371397694436958], 
             UndirectedEdge[211, 266] -> 
             RGBColor[
              0.23444123912717205`, 0.36374298512871284`, 0.9366624537923354],
              UndirectedEdge[156, 282] -> 
             RGBColor[
              0.41756183526404816`, 0.5360928072628128, 0.9478276488009602], 
             UndirectedEdge[92, 256] -> 
             RGBColor[
              0.8247413968754788, 0.1911787948999799, 0.17132569563035674`], 
             UndirectedEdge[56, 246] -> 
             RGBColor[
              0.1919032518459413, 0.3190328634319706, 0.934239978345982], 
             UndirectedEdge[223, 246] -> 
             RGBColor[
              0.1829700916045353, 0.3096435456231802, 0.9337312480856603], 
             UndirectedEdge[66, 228] -> 
             RGBColor[
              0.40629940527691566`, 0.5263378564741489, 0.9471100167211559], 
             UndirectedEdge[170, 261] -> 
             RGBColor[
              0.22115645505495063`, 0.3497798347648488, 0.9359059049924991], 
             UndirectedEdge[104, 287] -> 
             RGBColor[
              0.2890443879522816, 0.41869887568726627`, 0.9398611972259145], 
             UndirectedEdge[255, 258] -> 
             RGBColor[
              0.3530896957607064, 0.48025028048897034`, 0.9437195410822816], 
             UndirectedEdge[27, 162] -> 
             RGBColor[
              0.9805948903116561, 0.9503103780407378, 0.565192668343681], 
             UndirectedEdge[162, 169] -> 
             RGBColor[
              0.7980436197485294, 0.8403418316253028, 0.877535691789008], 
             UndirectedEdge[90, 166] -> 
             RGBColor[
              0.20088523531551122`, 0.3284734975491328, 0.9347514890169203], 
             UndirectedEdge[74, 257] -> 
             RGBColor[
              0.19498858899920085`, 0.3222757484017205, 0.9344156837325129], 
             UndirectedEdge[82, 203] -> 
             RGBColor[
              0.7752823706628642, 0.824842772704185, 0.9770131806255582], 
             UndirectedEdge[1, 142] -> 
             RGBColor[
              0.8243144987265323, 0.1878974686592162, 0.17091689748081318`], 
             UndirectedEdge[82, 145] -> 
             RGBColor[
              0.7391717561435251, 0.7960859238654349, 0.9748439297036255], 
             UndirectedEdge[77, 203] -> 
             RGBColor[
              0.6754538924070363, 0.7427240405564789, 0.9694509218275109], 
             UndirectedEdge[12, 27] -> 
             RGBColor[
              0.6997308165084448, 0.7282337735956864, 0.6429681792954851], 
             UndirectedEdge[54, 185] -> 
             RGBColor[
              0.3867966632124244, 0.5013927095080272, 0.9466583404851183], 
             UndirectedEdge[35, 165] -> 
             RGBColor[
              0.2120938524489715, 0.3402544648237721, 0.9353898031810077], 
             UndirectedEdge[60, 95] -> 
             RGBColor[
              0.28741190007160666`, 0.4194185083151971, 0.9396790545700505], 
             UndirectedEdge[47, 112] -> 
             RGBColor[
              0.18666547155784385`, 0.31352762425472913`, 0.9339416945071765],
              UndirectedEdge[24, 59] -> 
             RGBColor[
              0.9543858496571156, 0.8617625274901577, 0.5778209567329167], 
             UndirectedEdge[239, 285] -> 
             RGBColor[
              0.21862787921736482`, 0.3471221412385783, 0.9357619063392415], 
             UndirectedEdge[173, 286] -> 
             RGBColor[
              0.2110888425781487, 0.3391981357282311, 0.9353325693556434], 
             UndirectedEdge[17, 40] -> 
             RGBColor[
              0.6964483919711273, 0.7627900441024493, 0.9703791250975754], 
             UndirectedEdge[226, 241] -> 
             RGBColor[
              0.9861906717339419, 0.9885575021255057, 0.8785198369719385], 
             UndirectedEdge[255, 286] -> 
             RGBColor[
              0.2934543066453184, 0.4204742848621239, 0.9402170430132455], 
             UndirectedEdge[95, 271] -> 
             RGBColor[
              0.25509580298829937`, 0.3854522413217438, 0.9378387006485376], 
             UndirectedEdge[189, 260] -> 
             RGBColor[
              0.23700170640282697`, 0.36643419857842796`, 0.936808268615812], 
             UndirectedEdge[193, 245] -> 
             RGBColor[
              0.2524031222436139, 0.38262206313325964`, 0.9376853564635919], 
             UndirectedEdge[84, 223] -> 
             RGBColor[
              0.1844791456857544, 0.31122965714209644`, 0.9338171864831403], 
             UndirectedEdge[44, 61] -> 
             RGBColor[
              0.29673927658547317`, 0.4285312134624696, 0.9402355342561197], 
             UndirectedEdge[262, 292] -> 
             RGBColor[
              0.5387777053242508, 0.6299185321853173, 0.9593474985432611], 
             UndirectedEdge[153, 248] -> 
             RGBColor[
              0.2215139470361167, 0.3501555815033551, 0.9359262636319645], 
             UndirectedEdge[78, 99] -> 
             RGBColor[
              0.19490280134245708`, 0.32218558013523124`, 0.9344107982523728],
              UndirectedEdge[199, 261] -> 
             RGBColor[
              0.22156560326703745`, 0.35020987547724697`, 0.9359292053778969],
              UndirectedEdge[58, 215] -> 
             RGBColor[
              0.20794131603506694`, 0.33588988576674306`, 0.935153322375363], 
             UndirectedEdge[23, 197] -> 
             RGBColor[
              0.9878441835047461, 0.9892412717360475, 0.8511168677784218], 
             UndirectedEdge[196, 214] -> 
             RGBColor[
              0.20194505297188817`, 0.32958743310230554`, 0.9348118440645912],
              UndirectedEdge[88, 289] -> 
             RGBColor[
              0.23315152394890182`, 0.3623874127036856, 0.9365890064208955], 
             UndirectedEdge[47, 96] -> 
             RGBColor[
              0.19252503662856937`, 0.3196863986619449, 0.9342753880695046], 
             UndirectedEdge[179, 205] -> 
             RGBColor[
              0.44755823847840226`, 0.5601887588135859, 0.9502599417033248], 
             UndirectedEdge[72, 194] -> 
             RGBColor[
              0.7577104993954153, 0.4908688373474871, 0.5725699298440808], 
             UndirectedEdge[140, 299] -> 
             RGBColor[
              0.8180064493920196, 0.1394110372693064, 0.16487630231416095`], 
             UndirectedEdge[134, 297] -> 
             RGBColor[
              0.21839610407426302`, 0.3468785308677854, 0.9357487070877224], 
             UndirectedEdge[67, 195] -> 
             RGBColor[
              0.18132553855698572`, 0.30791501609952, 0.9336375932225005], 
             UndirectedEdge[24, 155] -> 
             RGBColor[
              0.9250389254998768, 0.7405113494439601, 0.2585427637758789], 
             UndirectedEdge[156, 277] -> 
             RGBColor[
              0.6937513555235839, 0.7517852121341029, 0.7135233421024703], 
             UndirectedEdge[267, 272] -> 
             RGBColor[
              0.18764714248222777`, 0.31455942263778813`, 0.9339975992140681],
              UndirectedEdge[71, 177] -> 
             RGBColor[
              0.2576442825267533, 0.3881308548995943, 0.9379838327881149], 
             UndirectedEdge[188, 281] -> 
             RGBColor[
              0.66716299452805, 0.7330554302274623, 0.9326197293964239], 
             UndirectedEdge[1, 150] -> 
             RGBColor[
              0.8630514097518487, 0.4076537466466897, 0.20494588861929658`], 
             UndirectedEdge[84, 246] -> 
             RGBColor[
              0.1859588657451276, 0.3127849367441682, 0.9339014543514719], 
             UndirectedEdge[58, 230] -> 
             RGBColor[
              0.19161321755920613`, 0.31872801900737613`, 0.9342234613224198],
              UndirectedEdge[74, 189] -> 
             RGBColor[
              0.21086862151855923`, 0.33896666943178094`, 0.9353200280920875],
              UndirectedEdge[48, 71] -> 
             RGBColor[
              0.2080633650262977, 0.3360181669948795, 0.9351602728848583], 
             UndirectedEdge[80, 205] -> 
             RGBColor[
              0.6755840605748524, 0.7185594638345996, 0.6585612536692309], 
             UndirectedEdge[1, 32] -> 
             RGBColor[
              0.9031847839921265, 0.5669315361536746, 0.5097177699465452], 
             UndirectedEdge[229, 233] -> 
             RGBColor[
              0.2115539796555496, 0.3396870242879735, 0.9353590582240927], 
             UndirectedEdge[54, 172] -> 
             RGBColor[
              0.21731047913351847`, 0.34573747022246615`, 0.935686882353385], 
             UndirectedEdge[61, 194] -> 
             RGBColor[
              0.4816323907254858, 0.581689714248477, 0.9542195774968412], 
             UndirectedEdge[177, 194] -> 
             RGBColor[
              0.4889886310377472, 0.5894215892292383, 0.9546385045000421], 
             UndirectedEdge[7, 42] -> 
             RGBColor[
              0.8879622102999478, 0.6217857737509664, 0.5864682520402187], 
             UndirectedEdge[26, 75] -> 
             RGBColor[
              0.28101248706842963`, 0.4104564015750206, 0.9393964853748475], 
             UndirectedEdge[170, 190] -> 
             RGBColor[
              0.2009954787857768, 0.3285893704262217, 0.9347577672194614], 
             UndirectedEdge[20, 36] -> 
             RGBColor[
              0.200168643680248, 0.32772031430593734`, 0.9347106801833944], 
             UndirectedEdge[119, 161] -> 
             RGBColor[
              0.191253116488521, 0.3183495299503595, 0.9342029540991661], 
             UndirectedEdge[212, 225] -> 
             RGBColor[
              0.23048263283804543`, 0.3595822389287055, 0.9364370170204028], 
             UndirectedEdge[102, 253] -> 
             RGBColor[
              0.1920226425007294, 0.3191583505799577, 0.9342467774671497], 
             UndirectedEdge[91, 179] -> 
             RGBColor[
              0.5064577791876668, 0.6102042666643193, 0.9542893580750782], 
             UndirectedEdge[118, 239] -> 
             RGBColor[
              0.213148543369447, 0.34136301185245843`, 0.9354498662686535], 
             UndirectedEdge[105, 298] -> 
             RGBColor[
              0.27198901083979987`, 0.403208073864912, 0.938800743844419], 
             UndirectedEdge[90, 239] -> 
             RGBColor[
              0.2266260849573989, 0.3555287625868876, 0.9362173923238513], 
             UndirectedEdge[208, 252] -> 
             RGBColor[
              0.21362941037883332`, 0.3418684335680528, 0.935477250933459], 
             UndirectedEdge[117, 214] -> 
             RGBColor[
              0.19317010459047246`, 0.32036440598957616`, 0.9343121237356424],
              UndirectedEdge[179, 282] -> 
             RGBColor[
              0.48169445553417334`, 0.5897558342911382, 0.9524350712686471], 
             UndirectedEdge[44, 268] -> 
             RGBColor[
              0.2606344226816996, 0.39058272282964934`, 0.9381794162386446], 
             UndirectedEdge[53, 124] -> 
             RGBColor[
              0.20090092998575032`, 0.32848999364265374`, 0.9347523828051723],
              UndirectedEdge[42, 81] -> 
             RGBColor[
              0.8635348143848929, 0.4405098850237444, 0.2065613896917941], 
             UndirectedEdge[173, 213] -> 
             RGBColor[
              0.20183100425593847`, 0.3294675606707361, 0.9348053491589379], 
             UndirectedEdge[119, 122] -> 
             RGBColor[
              0.18294597115910344`, 0.30961819350570674`, 0.933729874461976], 
             UndirectedEdge[68, 111] -> 
             RGBColor[
              0.7455301616880299, 0.8011614727150247, 0.9754440364810864], 
             UndirectedEdge[34, 53] -> 
             RGBColor[
              0.1997851700209307, 0.32731725917636056`, 0.9346888419257947], 
             UndirectedEdge[85, 263] -> 
             RGBColor[
              0.22101888131475306`, 0.34963523604122215`, 0.9358980703715171],
              UndirectedEdge[37, 208] -> 
             RGBColor[
              0.20794241016561682`, 0.3358910357673228, 0.9351533846844792], 
             UndirectedEdge[256, 293] -> 
             RGBColor[
              0.8588434353874268, 0.38825931884886955`, 0.2014349376927211], 
             UndirectedEdge[76, 153] -> 
             RGBColor[
              0.27399346070364045`, 0.40363477490679034`, 0.9389764110945367],
              UndirectedEdge[135, 213] -> 
             RGBColor[
              0.20772578685862308`, 0.3356633509369615, 0.9351410483076115], 
             UndirectedEdge[36, 55] -> 
             RGBColor[
              0.19173502245287335`, 0.3188560436734967, 0.9342303979309199], 
             UndirectedEdge[121, 135] -> 
             RGBColor[
              0.21926297732246688`, 0.3477896696145861, 0.9357980742367835], 
             UndirectedEdge[83, 226] -> 
             RGBColor[
              0.9164048612065285, 0.6737070689481892, 0.5348152285137735], 
             UndirectedEdge[60, 127] -> 
             RGBColor[
              0.3180513290021859, 0.44791596605042294`, 0.941559638747636], 
             UndirectedEdge[247, 271] -> 
             RGBColor[
              0.21019581629378764`, 0.33825950848223085`, 0.9352817128298629],
              UndirectedEdge[202, 269] -> 
             RGBColor[
              0.9198678167668363, 0.7040758695857129, 0.2803134075037528], 
             UndirectedEdge[190, 284] -> 
             RGBColor[
              0.22268610341343767`, 0.3513875921749262, 0.9359930162036031], 
             UndirectedEdge[53, 217] -> 
             RGBColor[
              0.2079578190900217, 0.3359072315238546, 0.9351542621999286], 
             UndirectedEdge[42, 87] -> 
             RGBColor[
              0.915376392222736, 0.6389023704076946, 0.3396146781641949], 
             UndirectedEdge[205, 225] -> 
             RGBColor[
              0.29997817143986366`, 0.426744933886711, 0.9406100364801734], 
             UndirectedEdge[110, 246] -> 
             RGBColor[
              0.18518351558803503`, 0.3119699945690246, 0.9338572993070533], 
             UndirectedEdge[191, 251] -> 
             RGBColor[
              0.25649200131600725`, 0.38691973428825177`, 0.9379182120778102],
              UndirectedEdge[23, 83] -> 
             RGBColor[
              0.917949620402167, 0.6743458665740862, 0.5092145709333941], 
             UndirectedEdge[226, 291] -> 
             RGBColor[
              0.956565980138184, 0.9665569141916783, 0.9351528422090618], 
             UndirectedEdge[60, 276] -> 
             RGBColor[
              0.26432062956564295`, 0.39514811894231855`, 0.9383640408752093],
              UndirectedEdge[27, 155] -> 
             RGBColor[
              0.9480776706138694, 0.8277482013156446, 0.2984544769553814], 
             UndirectedEdge[167, 203] -> 
             RGBColor[
              0.9224035575123126, 0.8121627962472151, 0.6179459955981152], 
             UndirectedEdge[137, 271] -> 
             RGBColor[
              0.24208469003989352`, 0.37177673666076144`, 0.9370977370143425],
              UndirectedEdge[52, 247] -> 
             RGBColor[
              0.1982447360653234, 0.3256981654198634, 0.9346011164908907], 
             UndirectedEdge[81, 299] -> 
             RGBColor[
              0.8540793965653044, 0.3678314002718782, 0.19750687090938907`], 
             UndirectedEdge[31, 290] -> 
             RGBColor[
              0.683029742131583, 0.6815722331575694, 0.6118498991600951], 
             UndirectedEdge[79, 288] -> 
             RGBColor[
              0.19600308919068352`, 0.3233420524259961, 0.9344734580175993], 
             UndirectedEdge[237, 281] -> 
             RGBColor[
              0.9017681191965876, 0.5885988435448176, 0.546493973651558], 
             UndirectedEdge[43, 215] -> 
             RGBColor[
              0.22516415254335911`, 0.35399217892786317`, 0.9361341374356069],
              UndirectedEdge[56, 295] -> 
             RGBColor[
              0.19813975131853928`, 0.3255878197945759, 0.9345951377648724], 
             UndirectedEdge[89, 94] -> 
             RGBColor[
              0.5888165791799138, 0.6727291061533267, 0.962935879267211], 
             UndirectedEdge[92, 237] -> 
             RGBColor[
              0.8283146765154534, 0.21864458803394712`, 0.17474747224903853`],
              UndirectedEdge[126, 285] -> 
             RGBColor[
              0.21158401439278246`, 0.3397185927011176, 0.9353607686579457], 
             UndirectedEdge[4, 214] -> 
             RGBColor[
              0.21068402735866598`, 0.33877264926578743`, 0.9353095157277642],
              UndirectedEdge[220, 222] -> 
             RGBColor[
              0.2772575054008418, 0.4064948783579615, 0.9391831866025837], 
             UndirectedEdge[199, 209] -> 
             RGBColor[
              0.1894252090832627, 0.31642828337140966`, 0.9340988574765833], 
             UndirectedEdge[290, 291] -> 
             RGBColor[
              0.9366428804635196, 0.8848865477710113, 0.6343132641384139], 
             UndirectedEdge[91, 150] -> 
             RGBColor[
              0.6987841041568563, 0.6337941140587057, 0.5986819437121721], 
             UndirectedEdge[60, 148] -> 
             RGBColor[
              0.2667823322730826, 0.39773552456880407`, 0.9385042312026353], 
             UndirectedEdge[81, 140] -> 
             RGBColor[
              0.8533919471732848, 0.3625473630025718, 0.19684856859522815`], 
             UndirectedEdge[142, 256] -> 
             RGBColor[
              0.8239318482187612, 0.18495624917796497`, 0.17055047092242953`],
              UndirectedEdge[30, 123] -> 
             RGBColor[
              0.2239498078006626, 0.3527158256093854, 0.9360649822989724], 
             UndirectedEdge[53, 289] -> 
             RGBColor[
              0.22966099191075792`, 0.3587186422190827, 0.9363902257851027], 
             UndirectedEdge[274, 289] -> 
             RGBColor[
              0.3532455749379125, 0.4740835804879391, 0.944023524585039], 
             UndirectedEdge[11, 114] -> 
             RGBColor[
              0.38547343504917886`, 0.49973179121413747`, 0.9466075727466067],
              UndirectedEdge[137, 247] -> 
             RGBColor[
              0.22964528868911577`, 0.358702137137495, 0.9363893315098609], 
             UndirectedEdge[84, 191] -> 
             RGBColor[
              0.2074223158614455, 0.3353443836777553, 0.9351237660832672], 
             UndirectedEdge[17, 120] -> 
             RGBColor[
              0.4913767245940681, 0.5895491243083159, 0.9551516880301447], 
             UndirectedEdge[126, 222] -> 
             RGBColor[
              0.22245696617283922`, 0.3511467544069171, 0.9359799671767292], 
             UndirectedEdge[184, 224] -> 
             RGBColor[
              0.20007875304145373`, 0.32762583354516883`, 0.9347055610444963],
              UndirectedEdge[278, 295] -> 
             RGBColor[
              0.1987763965986568, 0.3262569743496216, 0.9346313937717428], 
             UndirectedEdge[28, 245] -> 
             RGBColor[
              0.204356271408755, 0.33212177655953135`, 0.9349491593874928], 
             UndirectedEdge[14, 186] -> 
             RGBColor[
              0.18665492193544975`, 0.31351653593270823`, 0.9339410937217879],
              UndirectedEdge[227, 241] -> 
             RGBColor[
              0.9694143471641505, 0.9193630503950179, 0.5802122280149764], 
             UndirectedEdge[121, 154] -> 
             RGBColor[
              0.3613735298324199, 0.47852983599420473`, 0.9448593103869043], 
             UndirectedEdge[187, 230] -> 
             RGBColor[
              0.20841284593944426`, 0.3363854935929662, 0.9351801753058513], 
             UndirectedEdge[125, 277] -> 
             RGBColor[
              0.9141028296655067, 0.6294928360832908, 0.33101231371327555`], 
             UndirectedEdge[62, 158] -> 
             RGBColor[
              0.1973113364505346, 0.3247171032437667, 0.9345479607636695], 
             UndirectedEdge[20, 61] -> 
             RGBColor[
              0.248131704384919, 0.378132532140237, 0.9374421055355356], 
             UndirectedEdge[64, 258] -> 
             RGBColor[
              0.28773302970917036`, 0.41685145648958927`, 0.939803693309408], 
             UndirectedEdge[94, 294] -> 
             RGBColor[
              0.6664691166979216, 0.7377414792197128, 0.9685045040434936], 
             UndirectedEdge[125, 237] -> 
             RGBColor[
              0.8301345677866601, 0.23263306982588172`, 0.17649020218561928`],
              UndirectedEdge[267, 300] -> 
             RGBColor[
              0.210925999504364, 0.33902697733283615`, 0.935323295683496], 
             UndirectedEdge[165, 175] -> 
             RGBColor[
              0.2002014223302363, 0.3277547667453615, 0.9347125468790196], 
             UndirectedEdge[67, 263] -> 
             RGBColor[
              0.19440813626729972`, 0.3216656557776636, 0.934382627808134], 
             UndirectedEdge[163, 298] -> 
             RGBColor[
              0.44064408929894633`, 0.5470342917552059, 0.9507221073701924], 
             UndirectedEdge[92, 149] -> 
             RGBColor[
              0.8635292482964012, 0.4309688829157785, 0.2061841331747976], 
             UndirectedEdge[95, 276] -> 
             RGBColor[
              0.2644651178260697, 0.3952999852651118, 0.9383722692678894], 
             UndirectedEdge[70, 231] -> 
             RGBColor[
              0.2204752799716199, 0.3490638765632734, 0.9358671130792118], 
             UndirectedEdge[239, 263] -> 
             RGBColor[
              0.22373268173624067`, 0.3524876123490904, 0.9360526172908128], 
             UndirectedEdge[116, 204] -> 
             RGBColor[
              0.38548007982804805`, 0.5055047110221348, 0.9460830998243401], 
             UndirectedEdge[121, 258] -> 
             RGBColor[
              0.28280548262609156`, 0.41167229208074363`, 0.9395230767926794],
              UndirectedEdge[95, 148] -> 
             RGBColor[
              0.2669268205335093, 0.3978873908915973, 0.9385124595953154], 
             UndirectedEdge[60, 77] -> 
             RGBColor[
              0.3505250523811867, 0.47604307306451876`, 0.9436288356859599], 
             UndirectedEdge[42, 269] -> 
             RGBColor[
              0.9053848161613813, 0.6055965424276077, 0.2669473836135131], 
             UndirectedEdge[61, 136] -> 
             RGBColor[
              0.33493736709593636`, 0.46161647957078045`, 0.9426694828062012],
              UndirectedEdge[95, 251] -> 
             RGBColor[
              0.2865818395337517, 0.41854606206103384`, 0.9396317838503843], 
             UndirectedEdge[158, 265] -> 
             RGBColor[
              0.20783074668686696`, 0.3357736703712833, 0.9351470256145558], 
             UndirectedEdge[152, 208] -> 
             RGBColor[
              0.1859180316496269, 0.31274201752076575`, 0.9338991289101417], 
             UndirectedEdge[153, 285] -> 
             RGBColor[
              0.21037441724900163`, 0.3384472294101154, 0.9352918838900459], 
             UndirectedEdge[61, 279] -> 
             RGBColor[
              0.25696298277753227`, 0.387414765666264, 0.9379450337752894], 
             UndirectedEdge[82, 168] -> 
             RGBColor[
              0.5069255349638632, 0.6091474742003642, 0.9547231011630586], 
             UndirectedEdge[4, 249] -> 
             RGBColor[
              0.21399718138461848`, 0.3422549842131616, 0.93549819494817], 
             UndirectedEdge[75, 163] -> 
             RGBColor[
              0.47703987934410275`, 0.583052656791418, 0.9528766616787626], 
             UndirectedEdge[59, 290] -> 
             RGBColor[
              0.9657093115675036, 0.9066562806448499, 0.5869320799818273], 
             UndirectedEdge[205, 251] -> 
             RGBColor[
              0.3289835017199729, 0.45723137505526373`, 0.9422618471300848], 
             UndirectedEdge[183, 224] -> 
             RGBColor[
              0.2007040206651831, 0.3282830294619655, 0.9347411691106672], 
             UndirectedEdge[170, 178] -> 
             RGBColor[
              0.228293899528688, 0.35728174144686387`, 0.9363123718963757], 
             UndirectedEdge[102, 238] -> 
             RGBColor[
              0.18981943468321613`, 0.3168426394723074, 0.9341213080412961], 
             UndirectedEdge[89, 236] -> 
             RGBColor[
              0.30608763983959875`, 0.4323911560553985, 0.9409863461402914], 
             UndirectedEdge[65, 231] -> 
             RGBColor[
              0.30432205873480145`, 0.4308387652063516, 0.9408746918946544], 
             UndirectedEdge[25, 245] -> 
             RGBColor[
              0.2081790637788683, 0.33613977371955583`, 0.9351668617576563], 
             UndirectedEdge[217, 223] -> 
             RGBColor[
              0.19076430807847547`, 0.31783576131915836`, 0.9341751171833412],
              UndirectedEdge[254, 283] -> 
             RGBColor[
              0.3123013068939945, 0.44465097126766145`, 0.9411304437622906], 
             UndirectedEdge[168, 205] -> 
             RGBColor[
              0.3863855665846765, 0.5090894902975664, 0.9458411245288025], 
             UndirectedEdge[142, 243] -> 
             RGBColor[
              0.9086765502085565, 0.610084243189442, 0.517243821691691], 
             UndirectedEdge[57, 278] -> 
             RGBColor[
              0.19015282278651957`, 0.31719305150690597`, 0.9341402940005757],
              UndirectedEdge[185, 218] -> 
             RGBColor[
              0.7483730046735189, 0.8020037075647066, 0.948265724399384], 
             UndirectedEdge[16, 248] -> 
             RGBColor[
              0.23437455245828825`, 0.36367289321153695`, 0.9366586560851965],
              UndirectedEdge[184, 275] -> 
             RGBColor[
              0.18583227383419235`, 0.31265188061938454`, 0.9338942451294201],
              UndirectedEdge[127, 191] -> 
             RGBColor[
              0.28810597904486807`, 0.41644150460043405`, 0.9398542953677421],
              UndirectedEdge[33, 153] -> 
             RGBColor[
              0.21078779737820008`, 0.338881718135717, 0.9353154252768627], 
             UndirectedEdge[83, 243] -> 
             RGBColor[
              0.9169850470479723, 0.6739469907037223, 0.5252000476482207], 
             UndirectedEdge[94, 281] -> 
             RGBColor[
              0.8876751944238266, 0.9123560617360518, 0.9508666014010566], 
             UndirectedEdge[140, 293] -> 
             RGBColor[
              0.8585388832387033, 0.3859183975781782, 0.20114329821116103`], 
             UndirectedEdge[126, 220] -> 
             RGBColor[
              0.27828890051671973`, 0.40757894001897654`, 0.9392419230286206],
              UndirectedEdge[76, 220] -> 
             RGBColor[
              0.3300035970754238, 0.4602542621488369, 0.942248515288291], 
             UndirectedEdge[90, 126] -> 
             RGBColor[
              0.2195822201328165, 0.34812521404942687`, 0.9358162546425555], 
             UndirectedEdge[35, 102] -> 
             RGBColor[
              0.19929440110633984`, 0.32680142993057915`, 0.9346608933621363],
              UndirectedEdge[105, 235] -> 
             RGBColor[
              0.34616703863432685`, 0.47195151424914406`, 0.9433627489328582],
              UndirectedEdge[21, 287] -> 
             RGBColor[
              0.21828938866019382`, 0.34676636620145074`, 0.9357426298027625],
              UndirectedEdge[160, 245] -> 
             RGBColor[
              0.2105034515043503, 0.33858285259373117`, 0.935299232199999], 
             UndirectedEdge[235, 298] -> 
             RGBColor[
              0.33431581918328446`, 0.4594951311953859, 0.9426878395174293], 
             UndirectedEdge[15, 196] -> 
             RGBColor[
              0.23071789586563907`, 0.35982951528724394`, 0.9364504149017838],
              UndirectedEdge[13, 274] -> 
             RGBColor[
              0.3981676494624695, 0.5190303850989934, 0.9466648547482157], 
             UndirectedEdge[2, 172] -> 
             RGBColor[
              0.19458761473709335`, 0.321854299029009, 0.9343928488414741], 
             UndirectedEdge[247, 295] -> 
             RGBColor[
              0.1973396127760572, 0.3247468234547135, 0.9345495710585769], 
             UndirectedEdge[159, 225] -> 
             RGBColor[
              0.2594187152635208, 0.38999589621147046`, 0.9380848841074358], 
             UndirectedEdge[204, 254] -> 
             RGBColor[
              0.40119508956919725`, 0.5210943009518455, 0.9470120206751078], 
             UndirectedEdge[61, 252] -> 
             RGBColor[
              0.2576007602350303, 0.3880851102115208, 0.9379813542579867], 
             UndirectedEdge[4, 173] -> 
             RGBColor[
              0.21091230660044274`, 0.33901258522263467`, 0.9353225158928745],
              UndirectedEdge[230, 245] -> 
             RGBColor[
              0.20866400795240445`, 0.3366494807931788, 0.9351944786109285], 
             UndirectedEdge[137, 295] -> 
             RGBColor[
              0.2292284865221631, 0.35826405163324404`, 0.9363655952430565], 
             UndirectedEdge[109, 192] -> 
             RGBColor[
              0.6617142280646152, 0.7260405303844142, 0.8555444013688691], 
             UndirectedEdge[178, 229] -> 
             RGBColor[
              0.23836184028178953`, 0.36786378552268634`, 0.9368857262280812],
              UndirectedEdge[91, 93] -> 
             RGBColor[
              0.3656444287828603, 0.48387268995411137`, 0.9450248073537576], 
             UndirectedEdge[143, 185] -> 
             RGBColor[
              0.41822549913320267`, 0.5344264087640556, 0.9484481661960105], 
             UndirectedEdge[139, 273] -> 
             RGBColor[
              0.3398266519904991, 0.46230754637230465`, 0.9431107790825377], 
             UndirectedEdge[130, 281] -> 
             RGBColor[
              0.9451323785335899, 0.8357466481470239, 0.5846180445889815], 
             UndirectedEdge[220, 248] -> 
             RGBColor[
              0.27752408340790014`, 0.40677506874540165`, 0.9391983678257189],
              UndirectedEdge[88, 273] -> 
             RGBColor[
              0.23089430452924603`, 0.3600149319776501, 0.936460461114203], 
             UndirectedEdge[24, 218] -> 
             RGBColor[
              0.945476791560533, 0.8552536816107574, 0.5989703095762722], 
             UndirectedEdge[66, 215] -> 
             RGBColor[
              0.3055417316872413, 0.4312998537559559, 0.940974206355727], 
             UndirectedEdge[151, 154] -> 
             RGBColor[
              0.5475628360948273, 0.6435752036232633, 0.9575252987275946], 
             UndirectedEdge[8, 64] -> 
             RGBColor[
              0.21988638356939655`, 0.34844490910634823`, 0.9358335763002992],
              UndirectedEdge[71, 108] -> 
             RGBColor[
              0.23200115605283045`, 0.3611783031073773, 0.936523494671031], 
             UndirectedEdge[43, 182] -> 
             RGBColor[
              0.23996509971424826`, 0.36954891283871966`, 0.9369770294809499],
              UndirectedEdge[58, 297] -> 
             RGBColor[
              0.19156703343003767`, 0.3186794765593771, 0.934220831204587], 
             UndirectedEdge[46, 207] -> 
             RGBColor[
              0.1949982416588687, 0.3222858939590454, 0.9344162334372013], 
             UndirectedEdge[100, 266] -> 
             RGBColor[
              0.1894062944527255, 0.3164084028954582, 0.9340977803163559], 
             UndirectedEdge[12, 151] -> 
             RGBColor[
              0.5137240937710055, 0.6154599354387978, 0.9550391768879118], 
             UndirectedEdge[196, 265] -> 
             RGBColor[
              0.21288778030859679`, 0.34108893334217194`, 0.9354350161981024],
              UndirectedEdge[93, 139] -> 
             RGBColor[
              0.3409266080048823, 0.4634636698846607, 0.9431734199503177], 
             UndirectedEdge[30, 104] -> 
             RGBColor[
              0.2921921290764705, 0.4220073511871032, 0.9400404564262714], 
             UndirectedEdge[85, 121] -> 
             RGBColor[
              0.22879896787362192`, 0.35781260030057205`, 0.936341134791438], 
             UndirectedEdge[79, 160] -> 
             RGBColor[
              0.1894526235362595, 0.316457097699686, 0.9341004186891254], 
             UndirectedEdge[60, 196] -> 
             RGBColor[
              0.24516356622564123`, 0.3750128307440074, 0.9372730744583317], 
             UndirectedEdge[25, 297] -> 
             RGBColor[
              0.19155439006973912`, 0.318666187586068, 0.9342201111839221], 
             UndirectedEdge[9, 133] -> 
             RGBColor[
              0.19212471165815448`, 0.3192656317359698, 0.9342525901546672], 
             UndirectedEdge[151, 192] -> 
             RGBColor[
              0.4642226762503304, 0.5725842955959759, 0.9518849903358793], 
             UndirectedEdge[45, 141] -> 
             RGBColor[
              0.2968912603514489, 0.4293819169954668, 0.9402188901145307], 
             UndirectedEdge[177, 280] -> 
             RGBColor[
              0.27699231630764354`, 0.4084668651395046, 0.9390856746890857], 
             UndirectedEdge[141, 188] -> 
             RGBColor[
              0.3248560928052687, 0.45441830964122576`, 0.9419709558048517], 
             UndirectedEdge[129, 183] -> 
             RGBColor[
              0.1909140048229797, 0.31799310208895415`, 0.9341836421914842], 
             UndirectedEdge[41, 55] -> 
             RGBColor[
              0.19536579579315563`, 0.32267221665845913`, 0.9344371651014012],
              UndirectedEdge[120, 261] -> 
             RGBColor[
              0.2619133763504623, 0.3926179431844944, 0.9382269513658168], 
             UndirectedEdge[71, 279] -> 
             RGBColor[
              0.22999178600981598`, 0.35906632779075, 0.9364090640196779], 
             UndirectedEdge[180, 230] -> 
             RGBColor[
              0.1934850620461379, 0.3206954462449366, 0.9343300600968047], 
             UndirectedEdge[106, 194] -> 
             RGBColor[
              0.7739330746560312, 0.8236601401446212, 0.9780122537987794], 
             UndirectedEdge[90, 234] -> 
             RGBColor[
              0.20491562163947707`, 0.33270968911687326`, 0.9349810135556479],
              UndirectedEdge[44, 136] -> 
             RGBColor[
              0.3544174046992013, 0.48140027523890294`, 0.9438041415217957], 
             UndirectedEdge[120, 131] -> 
             RGBColor[
              0.2542490675591432, 0.38456226869957383`, 0.93779048031848], 
             UndirectedEdge[44, 279] -> 
             RGBColor[
              0.27644302038079716`, 0.4071985613343865, 0.9390796924908837], 
             UndirectedEdge[105, 139] -> 
             RGBColor[
              0.3622816914289454, 0.48590921655384295`, 0.9443895603593033], 
             UndirectedEdge[157, 184] -> 
             RGBColor[
              0.18701393581723674`, 0.31389388228526116`, 0.9339615390312422],
              UndirectedEdge[83, 149] -> 
             RGBColor[
              0.8710281964790996, 0.48860908470804376`, 0.21336513442340005`],
              UndirectedEdge[145, 168] -> 
             RGBColor[
              0.6326576416445393, 0.7081764296337532, 0.9668556680760403], 
             UndirectedEdge[112, 170] -> 
             RGBColor[
              0.1934039006537554, 0.3206101404756131, 0.9343254380755761], 
             UndirectedEdge[159, 270] -> 
             RGBColor[
              0.2520399731872973, 0.38224037045009085`, 0.9376646756620657], 
             UndirectedEdge[86, 162] -> 
             RGBColor[
              0.7927626721159106, 0.8360545204331631, 0.8771199562466196], 
             UndirectedEdge[3, 264] -> 
             RGBColor[
              0.6252141606717125, 0.697021267014214, 0.9512803143951285], 
             UndirectedEdge[60, 282] -> 
             RGBColor[
              0.36394977931359895`, 0.4876708967869795, 0.9444842474150733], 
             UndirectedEdge[135, 186] -> 
             RGBColor[
              0.20309625090443267`, 0.3307974151195744, 0.934877403083805], 
             UndirectedEdge[89, 294] -> 
             RGBColor[
              0.4583968818459615, 0.569215720181254, 0.9510502956112238], 
             UndirectedEdge[201, 203] -> 
             RGBColor[
              0.8912445921234382, 0.6511612232387863, 0.591194505299895], 
             UndirectedEdge[181, 203] -> 
             RGBColor[
              0.961709527951959, 0.9590285203678879, 0.6962850331189814], 
             UndirectedEdge[70, 211] -> 
             RGBColor[
              0.24025127894135917`, 0.3698497053512242, 0.9369933269645696], 
             UndirectedEdge[156, 159] -> 
             RGBColor[
              0.3428661620319342, 0.4697766941100199, 0.9431273668629003], 
             UndirectedEdge[56, 270] -> 
             RGBColor[
              0.20609791902538932`, 0.3339523586314509, 0.9350483436427234], 
             UndirectedEdge[113, 264] -> 
             RGBColor[
              0.28192127958218227`, 0.41364751805536637`, 0.939366371855823], 
             UndirectedEdge[144, 240] -> 
             RGBColor[
              0.18908519234139687`, 0.31607090421740214`, 0.9340794940261437],
              UndirectedEdge[231, 232] -> 
             RGBColor[
              0.20954424282732975`, 0.33757466345683984`, 0.9352446066848648],
              UndirectedEdge[90, 248] -> 
             RGBColor[
              0.21881740302399694`, 0.347321342775852, 0.9357726994396538], 
             UndirectedEdge[27, 109] -> 
             RGBColor[
              0.9813263327288758, 0.9506128482774708, 0.5530707745780536], 
             UndirectedEdge[42, 145] -> 
             RGBColor[
              0.8512542986237088, 0.5925834616705845, 0.5853100694048696], 
             UndirectedEdge[160, 230] -> 
             RGBColor[
              0.19392496192438957`, 0.3211578089082423, 0.9343551117440977], 
             UndirectedEdge[247, 251] -> 
             RGBColor[
              0.24168185283923999`, 0.37135332922152087`, 0.9370747960317096],
              UndirectedEdge[109, 220] -> 
             RGBColor[
              0.6629503007752218, 0.7271111544395208, 0.8556231628289728], 
             UndirectedEdge[139, 163] -> 
             RGBColor[
              0.5309367698880918, 0.6297354344441368, 0.9563109238850767], 
             UndirectedEdge[31, 279] -> 
             RGBColor[
              0.32815763679560045`, 0.4519911628206914, 0.9423749021193952], 
             UndirectedEdge[9, 112] -> 
             RGBColor[
              0.19409572030031721`, 0.3213372867880486, 0.9343648361809924], 
             UndirectedEdge[196, 276] -> 
             RGBColor[
              0.22221678398010425`, 0.35089430769392205`, 0.9359662891561706],
              UndirectedEdge[137, 251] -> 
             RGBColor[
              0.27357072658534587`, 0.4048705574000514, 0.9388908202161892], 
             UndirectedEdge[162, 181] -> 
             RGBColor[
              0.9888211205061603, 0.9780593840975029, 0.5971500192561076], 
             UndirectedEdge[96, 236] -> 
             RGBColor[
              0.2161907003932258, 0.34456051176834573`, 0.9356231126106896], 
             UndirectedEdge[251, 295] -> 
             RGBColor[
              0.24126505067228732`, 0.3709152437172699, 0.9370510597649051], 
             UndirectedEdge[20, 268] -> 
             RGBColor[
              0.21202685048114545`, 0.34018404150741677`, 0.9353859875180606],
              UndirectedEdge[187, 215] -> 
             RGBColor[
              0.224740944415305, 0.35354736035233314`, 0.9361100363587946], 
             UndirectedEdge[55, 250] -> 
             RGBColor[
              0.1923953966842939, 0.31955013886086425`, 0.9342680052664631], 
             UndirectedEdge[193, 230] -> 
             RGBColor[
              0.2358246326636532, 0.3651970194477707, 0.9367412360076905], 
             UndirectedEdge[55, 242] -> 
             RGBColor[
              0.19150951150427703`, 0.318619017368302, 0.9342175554160109], 
             UndirectedEdge[51, 116] -> 
             RGBColor[
              0.5493242790295518, 0.6359329023080253, 0.960750884061716], 
             UndirectedEdge[130, 203] -> 
             RGBColor[
              0.92446413705714, 0.8203323074950271, 0.6196039862679017], 
             UndirectedEdge[34, 124] -> 
             RGBColor[
              0.1848087064384265, 0.3115760463885134, 0.9338359544804635], 
             UndirectedEdge[190, 261] -> 
             RGBColor[
              0.2245754678269734, 0.353373433966175, 0.9361006127118898], 
             UndirectedEdge[76, 85] -> 
             RGBColor[
              0.2795331222505161, 0.40945731042738504`, 0.9392918866244364], 
             UndirectedEdge[130, 237] -> 
             RGBColor[
              0.8684389229143985, 0.44088823341152344`, 0.20976890313790728`],
              UndirectedEdge[175, 183] -> 
             RGBColor[
              0.18767445593923526`, 0.3145881308128762, 0.9339991546750381], 
             UndirectedEdge[93, 289] -> 
             RGBColor[
              0.24228732684798865`, 0.37198972079398507`, 0.9371092768807893],
              UndirectedEdge[69, 234] -> 
             RGBColor[
              0.20086201360397116`, 0.32844909005796263`, 0.9347501665748015],
              UndirectedEdge[32, 269] -> 
             RGBColor[
              0.980420530285405, 0.9551564158081671, 0.6020762664235486], 
             UndirectedEdge[226, 243] -> 
             RGBColor[
              0.9868373224355939, 0.9888249088088037, 0.8678031613671959], 
             UndirectedEdge[72, 218] -> 
             RGBColor[
              0.898302513009544, 0.6010781396556649, 0.5581126298969585], 
             UndirectedEdge[81, 181] -> 
             RGBColor[
              0.9378794291938042, 0.7781980948822975, 0.31536710248397326`], 
             UndirectedEdge[8, 67] -> 
             RGBColor[
              0.1916976136601492, 0.31881672466048916`, 0.9342282675555156], 
             UndirectedEdge[145, 156] -> 
             RGBColor[
              0.6296976932681398, 0.7056126711214472, 0.9666670627828757], 
             UndirectedEdge[20, 177] -> 
             RGBColor[
              0.2554879446971804, 0.38586440712099823`, 0.9378610325387366], 
             UndirectedEdge[180, 297] -> 
             RGBColor[
              0.19343887791696943`, 0.3206469037969376, 0.9343274299789719], 
             UndirectedEdge[140, 216] -> 
             RGBColor[
              0.8418913589267707, 0.3103258778057786, 0.18725219585712266`], 
             UndirectedEdge[287, 300] -> 
             RGBColor[
              0.2343234420650949, 0.3636191729477046, 0.9366557454239152], 
             UndirectedEdge[140, 167] -> 
             RGBColor[
              0.862500511580873, 0.40291200775905295`, 0.20439749636787896`], 
             UndirectedEdge[248, 285] -> 
             RGBColor[
              0.21081919728396287`, 0.3389147214275427, 0.9353172134550438], 
             UndirectedEdge[185, 292] -> 
             RGBColor[
              0.6516360083701964, 0.726054278090207, 0.9670940826236099], 
             UndirectedEdge[23, 241] -> 
             RGBColor[
              0.9877354309295805, 0.9891962997514028, 0.8529191793915591], 
             UndirectedEdge[10, 48] -> 
             RGBColor[
              0.19160641114189197`, 0.3187208650312271, 0.934223073707023], 
             UndirectedEdge[46, 62] -> 
             RGBColor[
              0.20319287451419632`, 0.3308989726597267, 0.9348829056554392], 
             UndirectedEdge[15, 276] -> 
             RGBColor[
              0.24987495920564082`, 0.37996480348555506`, 0.9375413813186614],
              UndirectedEdge[85, 154] -> 
             RGBColor[
              0.36472305205370464`, 0.48205039622074985`, 0.9450500607222323],
              UndirectedEdge[32, 179] -> 
             RGBColor[
              0.7552164634617963, 0.8063041539020928, 0.9047369408488604], 
             UndirectedEdge[145, 277] -> 
             RGBColor[
              0.9289575250796454, 0.9412874203114796, 0.7338327759362018], 
             UndirectedEdge[58, 164] -> 
             RGBColor[
              0.1865510290497441, 0.3134073379226422, 0.9339351771756428], 
             UndirectedEdge[18, 253] -> 
             RGBColor[
              0.19591234458530662`, 0.3232466740922047, 0.9344682902465677], 
             UndirectedEdge[59, 136] -> 
             RGBColor[
              0.6888115905499252, 0.7512769242124885, 0.9221815319720392], 
             UndirectedEdge[232, 288] -> 
             RGBColor[
              0.19838654644971515`, 0.32584721712515685`, 0.9346091923824922],
              UndirectedEdge[136, 177] -> 
             RGBColor[
              0.34229360740819775`, 0.46934835455154167`, 0.9430884098094023],
              UndirectedEdge[31, 65] -> 
             RGBColor[
              0.3985559674737674, 0.5196308798455622, 0.9466166117115924], 
             UndirectedEdge[62, 214] -> 
             RGBColor[
              0.20125370240405008`, 0.3288607798213499, 0.9347724726725144], 
             UndirectedEdge[24, 109] -> 
             RGBColor[
              0.9582875876148832, 0.8633759964057863, 0.5131590613985512], 
             UndirectedEdge[71, 268] -> 
             RGBColor[
              0.21418318831071842`, 0.34245048928601285`, 0.9355087877674388],
              UndirectedEdge[64, 118] -> 
             RGBColor[
              0.2120127678097534, 0.3401692397268907, 0.9353851855307582], 
             UndirectedEdge[21, 206] -> 
             RGBColor[
              0.20800021126608947`, 0.33595178838872103`, 0.9351566763716421],
              UndirectedEdge[6, 124] -> 
             RGBColor[
              0.19825974011141095`, 0.3257139356236129, 0.9346019709491189], 
             UndirectedEdge[7, 140] -> 
             RGBColor[
              0.8778193430883396, 0.5438232517297938, 0.5767554309436527], 
             UndirectedEdge[78, 229] -> 
             RGBColor[
              0.20592187570768378`, 0.3337673259427514, 0.9350383182362128], 
             UndirectedEdge[67, 213] -> 
             RGBColor[
              0.19065103236232478`, 0.3177167013593888, 0.9341686662988828], 
             UndirectedEdge[189, 300] -> 
             RGBColor[
              0.22074088939765935`, 0.34934304891065115`, 0.9358822391430908],
              UndirectedEdge[77, 225] -> 
             RGBColor[
              0.32068966156322254`, 0.4446841856418027, 0.9419297543163823], 
             UndirectedEdge[153, 239] -> 
             RGBColor[
              0.22932262896951866`, 0.3583630013143907, 0.9363709565161622], 
             UndirectedEdge[7, 168] -> 
             RGBColor[
              0.6693655533207783, 0.7373787417141351, 0.9680138507113893], 
             UndirectedEdge[5, 256] -> 
             RGBColor[
              0.8944703960572045, 0.5263449866913684, 0.2533457371184724], 
             UndirectedEdge[193, 200] -> 
             RGBColor[
              0.3225670309120143, 0.4511149836272068, 0.9418734544780243], 
             UndirectedEdge[17, 202] -> 
             RGBColor[
              0.7851169381087426, 0.6277184794555003, 0.5907369568935974], 
             UndirectedEdge[12, 220] -> 
             RGBColor[
              0.38135478455479077`, 0.5047320797577364, 0.9455205675464041], 
             UndirectedEdge[196, 207] -> 
             RGBColor[
              0.19417373721693681`, 0.32141928751397403`, 0.9343692791289782],
              UndirectedEdge[222, 285] -> 
             RGBColor[
              0.21055261927690455`, 0.33863453104010255`, 0.9353020322319088],
              UndirectedEdge[169, 227] -> 
             RGBColor[
              0.7787217249901721, 0.7700947212036731, 0.6214147685810579], 
             UndirectedEdge[139, 298] -> 
             RGBColor[
              0.350430471977903, 0.4734528335000848, 0.9437146509438744], 
             UndirectedEdge[210, 241] -> 
             RGBColor[
              0.7289016289330998, 0.7852496727746727, 0.9155863904520005], 
             UndirectedEdge[58, 288] -> 
             RGBColor[
              0.200003126765576, 0.32754634553423856`, 0.9347012542399642], 
             UndirectedEdge[85, 258] -> 
             RGBColor[
              0.2861550048473763, 0.41519285230728875`, 0.9397138271280076], 
             UndirectedEdge[87, 162] -> 
             RGBColor[
              0.9922481634967688, 0.9892215006042993, 0.6443153424349913], 
             UndirectedEdge[222, 248] -> 
             RGBColor[
              0.22169214906401963`, 0.3503428831333422, 0.9359364119738274], 
             UndirectedEdge[76, 87] -> 
             RGBColor[
              0.6600329022141906, 0.7226670785503484, 0.7188188011286823], 
             UndirectedEdge[80, 282] -> 
             RGBColor[
              0.7097202776306235, 0.7481265393121519, 0.6607363832345532], 
             UndirectedEdge[273, 289] -> 
             RGBColor[
              0.24118737083360547`, 0.370833597281629, 0.9370466360130092], 
             UndirectedEdge[215, 296] -> 
             RGBColor[
              0.20597442651804665`, 0.33382256017635653`, 0.935041310927121], 
             UndirectedEdge[142, 277] -> 
             RGBColor[
              0.9114733897375824, 0.6092818085693412, 0.32849435906876756`], 
             UndirectedEdge[134, 180] -> 
             RGBColor[
              0.21984183187712564`, 0.34839808245303105`, 0.9358310391473328],
              UndirectedEdge[86, 178] -> 
             RGBColor[
              0.4265942001520806, 0.5354932240498018, 0.9496283130255976], 
             UndirectedEdge[3, 210] -> 
             RGBColor[
              0.7129487102103079, 0.7736730218742174, 0.9569659936880668], 
             UndirectedEdge[79, 176] -> 
             RGBColor[
              0.18866673983198834`, 0.31563108409859225`, 0.9340556637747779],
              UndirectedEdge[131, 141] -> 
             RGBColor[
              0.26162779894186294`, 0.392317783221403, 0.938210688154871], 
             UndirectedEdge[150, 256] -> 
             RGBColor[
              0.8626687592440776, 0.4047125271654385, 0.20457946206091293`], 
             UndirectedEdge[74, 300] -> 
             RGBColor[
              0.2157736566163444, 0.3441221723167407, 0.9355993625845572], 
             UndirectedEdge[25, 230] -> 
             RGBColor[
              0.19160057419890764`, 0.31871473003406703`, 0.934222741301755], 
             UndirectedEdge[165, 253] -> 
             RGBColor[
              0.20482209384336109`, 0.3326113854731506, 0.9349756872860211], 
             UndirectedEdge[223, 295] -> 
             RGBColor[
              0.1892065910771333, 0.3161985019857855, 0.9340864075045505], 
             UndirectedEdge[164, 221] -> 
             RGBColor[
              0.184078374522518, 0.31080842123917557`, 0.9337943631582817], 
             UndirectedEdge[70, 138] -> 
             RGBColor[
              0.22052881830414905`, 0.3491201487452879, 0.9358701620080464], 
             UndirectedEdge[165, 224] -> 
             RGBColor[
              0.21323098705618415`, 0.3414496653944509, 0.9354545613146487], 
             UndirectedEdge[87, 258] -> 
             RGBColor[
              0.6666547848110509, 0.7284026204302521, 0.7192407416322534], 
             UndirectedEdge[90, 222] -> 
             RGBColor[
              0.2185508250169386, 0.3470411523884118, 0.9357575182165185], 
             UndirectedEdge[163, 185] -> 
             RGBColor[
              0.5753534134295759, 0.6661368462548543, 0.9597130747756251], 
             UndirectedEdge[64, 286] -> 
             RGBColor[
              0.22809764059378232`, 0.35707546086274283`, 0.9363011952403719],
              UndirectedEdge[131, 199] -> 
             RGBColor[
              0.21390129447571837`, 0.3421542009923264, 0.9354927343305601], 
             UndirectedEdge[2, 49] -> 
             RGBColor[
              0.20410648254439653`, 0.3318592326255619, 0.934934934281197], 
             UndirectedEdge[51, 283] -> 
             RGBColor[
              0.5585587587049552, 0.6456389259467026, 0.9612767740180419], 
             UndirectedEdge[66, 187] -> 
             RGBColor[
              0.305540960778381, 0.4312990434818653, 0.9409741624536079], 
             UndirectedEdge[120, 170] -> 
             RGBColor[
              0.23833338730926568`, 0.3678338796445412, 0.9368841058733883], 
             UndirectedEdge[17, 182] -> 
             RGBColor[
              0.47900337512465124`, 0.5765439495002909, 0.9544470440825916], 
             UndirectedEdge[156, 179] -> 
             RGBColor[
              0.4586241439822036, 0.5697734899723961, 0.9509650514168311], 
             UndirectedEdge[199, 284] -> 
             RGBColor[
              0.21967623885350168`, 0.3482240336859982, 0.9358216088696103], 
             UndirectedEdge[210, 291] -> 
             RGBColor[
              0.6992769373373419, 0.7632490848408453, 0.9722193956891239], 
             UndirectedEdge[212, 265] -> 
             RGBColor[
              0.22804223773896515`, 0.3570172289495861, 0.9362980401297512], 
             UndirectedEdge[85, 173] -> 
             RGBColor[
              0.21671771694106706`, 0.34511443957490595`, 0.9356531254234381],
              UndirectedEdge[47, 146] -> 
             RGBColor[
              0.19206431623757236`, 0.3192021523196471, 0.9342491507248121], 
             UndirectedEdge[198, 283] -> 
             RGBColor[
              0.6352059189617083, 0.705940028417498, 0.9427748448450561], 
             UndirectedEdge[168, 212] -> 
             RGBColor[
              0.31689002798285826`, 0.4419267953395609, 0.941668105069032], 
             UndirectedEdge[56, 271] -> 
             RGBColor[
              0.21099595483626973`, 0.3391005048220933, 0.9353272795361584], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.33246233459167696`, 0.45559373221858496`, 0.9426538050639501],
              UndirectedEdge[159, 191] -> 
             RGBColor[
              0.25930875612416715`, 0.38988032218419766`, 0.9380786220971196],
              UndirectedEdge[72, 83] -> 
             RGBColor[
              0.8379840210704871, 0.29296740741773747`, 0.18400684751490148`],
              UndirectedEdge[179, 277] -> 
             RGBColor[
              0.7578839757937091, 0.8054482391624284, 0.7181307645701571], 
             UndirectedEdge[86, 182] -> 
             RGBColor[
              0.4242603384632414, 0.5330401874394541, 0.9494954030550571], 
             UndirectedEdge[80, 293] -> 
             RGBColor[
              0.9392835874613179, 0.7889438610995526, 0.30512184711932616`], 
             UndirectedEdge[9, 96] -> 
             RGBColor[
              0.19995528537104273`, 0.3274960611952644, 0.9346985297433206], 
             UndirectedEdge[51, 226] -> 
             RGBColor[
              0.8987769385879059, 0.920547716985024, 0.9296222387004919], 
             UndirectedEdge[185, 235] -> 
             RGBColor[
              0.4690251433139141, 0.5785976856950342, 0.951678806922862], 
             UndirectedEdge[136, 210] -> 
             RGBColor[
              0.43214727310106515`, 0.5482274348494092, 0.9488947696323751], 
             UndirectedEdge[78, 284] -> 
             RGBColor[
              0.2175445595822431, 0.34598350361563335`, 0.935700212888649], 
             UndirectedEdge[81, 216] -> 
             RGBColor[
              0.8779643061000555, 0.5387462408083503, 0.21988276445235083`], 
             UndirectedEdge[2, 165] -> 
             RGBColor[
              0.2081927032562806, 0.336154109675109, 0.935167638505717], 
             UndirectedEdge[181, 216] -> 
             RGBColor[
              0.92637884094729, 0.7259766096855043, 0.3057707297458678], 
             UndirectedEdge[7, 203] -> 
             RGBColor[
              0.9377223890197792, 0.9530740402179558, 0.990303930173889], 
             UndirectedEdge[44, 177] -> 
             RGBColor[
              0.3040955168977345, 0.4362630884432308, 0.9406544612593207], 
             UndirectedEdge[140, 237] -> 
             RGBColor[
              0.8211968317886982, 0.16393371440465854`, 0.16793141610024187`],
              UndirectedEdge[38, 124] -> 
             RGBColor[
              0.186021974396972, 0.31285126793857626`, 0.9339050482958335], 
             UndirectedEdge[5, 59] -> 
             RGBColor[
              0.978010186853574, 0.9509747189595588, 0.6200075845730131], 
             UndirectedEdge[35, 253] -> 
             RGBColor[
              0.19912169776175326`, 0.3266199077653942, 0.9346510581621539], 
             UndirectedEdge[200, 231] -> 
             RGBColor[
              0.2983755222047893, 0.4256881741456715, 0.9404957838452779], 
             UndirectedEdge[213, 234] -> 
             RGBColor[
              0.19826511451334394`, 0.3257195844608012, 0.9346022770133582], 
             UndirectedEdge[53, 88] -> 
             RGBColor[
              0.21936792560639845`, 0.34789997691510377`, 0.9358040508862964],
              UndirectedEdge[150, 269] -> 
             RGBColor[
              0.9402871560451271, 0.7958786263011822, 0.2973043850963], 
             UndirectedEdge[4, 135] -> 
             RGBColor[
              0.21680708920312736`, 0.3452083754888601, 0.935658215041548], 
             UndirectedEdge[91, 139] -> 
             RGBColor[
              0.4654409733450266, 0.5765629962584664, 0.9511548548621985], 
             UndirectedEdge[28, 232] -> 
             RGBColor[
              0.18568890069969585`, 0.3125011863646469, 0.9338860802415121], 
             UndirectedEdge[127, 276] -> 
             RGBColor[
              0.29510454675664893`, 0.4237974430003376, 0.9402528534454749], 
             UndirectedEdge[60, 103] -> 
             RGBColor[
              0.35429852491084235`, 0.47931146530946245`, 0.9438692780187988],
              UndirectedEdge[145, 159] -> 
             RGBColor[
              0.5780723315879956, 0.6592789022873965, 0.963436800696632], 
             UndirectedEdge[20, 252] -> 
             RGBColor[
              0.2284732256377411, 0.3574702245574107, 0.936322584252997], 
             UndirectedEdge[80, 128] -> 
             RGBColor[
              0.9118743315068152, 0.6433069966832056, 0.2814216211923882], 
             UndirectedEdge[167, 237] -> 
             RGBColor[
              0.8663783433695712, 0.4327187221637115, 0.20811091246812083`], 
             UndirectedEdge[24, 291] -> 
             RGBColor[
              0.9253194185531315, 0.839992794616319, 0.6252021408895034], 
             UndirectedEdge[22, 244] -> 
             RGBColor[
              0.18902260313051494`, 0.31600511898838, 0.9340759296631764], 
             UndirectedEdge[51, 83] -> 
             RGBColor[
              0.8289246632002845, 0.6056697988799424, 0.5870191249815166], 
             UndirectedEdge[29, 229] -> 
             RGBColor[
              0.20648377022612274`, 0.3343579127078008, 0.9350703172977894], 
             UndirectedEdge[151, 181] -> 
             RGBColor[
              0.7920610111090953, 0.8249056195457978, 0.6813687144574905], 
             UndirectedEdge[22, 63] -> 
             RGBColor[
              0.18571205303560948`, 0.312525520937635, 0.9338873987327916], 
             UndirectedEdge[163, 292] -> 
             RGBColor[
              0.6974329821497556, 0.7632343245346107, 0.9706993881593793], 
             UndirectedEdge[247, 289] -> 
             RGBColor[
              0.22060050259813557`, 0.34919549348331447`, 0.9358742443225416],
              UndirectedEdge[155, 299] -> 
             RGBColor[
              0.8725038681798738, 0.44513051276199045`, 0.2125515962932238], 
             UndirectedEdge[31, 71] -> 
             RGBColor[
              0.32148269623256015`, 0.4449753770732606, 0.9419947741290198], 
             UndirectedEdge[45, 260] -> 
             RGBColor[
              0.2790511539192304, 0.41063083400712647`, 0.9392029224452882], 
             UndirectedEdge[80, 125] -> 
             RGBColor[
              0.9070014402205765, 0.6058518189425977, 0.2767553349935425], 
             UndirectedEdge[97, 261] -> 
             RGBColor[
              0.34679730240272766`, 0.46888200483462256`, 0.9435352867345028],
              UndirectedEdge[107, 147] -> 
             RGBColor[
              0.3109365240034128, 0.43492372492699083`, 0.9413563604380197], 
             UndirectedEdge[15, 286] -> 
             RGBColor[
              0.23963340623012278`, 0.3692002819563222, 0.9369581400277256], 
             UndirectedEdge[94, 202] -> 
             RGBColor[
              0.8317297748330001, 0.6641327817751705, 0.595382888836546], 
             UndirectedEdge[86, 130] -> 
             RGBColor[
              0.75299012475597, 0.6847273872222507, 0.6045439579169226], 
             UndirectedEdge[73, 161] -> 
             RGBColor[
              0.19216173018569271`, 0.31930454055552265`, 0.9342546983050465],
              UndirectedEdge[7, 167] -> 
             RGBColor[
              0.9230008546692128, 0.8126082594888467, 0.6169349273115317], 
             UndirectedEdge[288, 297] -> 
             RGBColor[
              0.20042924344964513`, 0.3279942211865534, 0.9347255209547387], 
             UndirectedEdge[15, 46] -> 
             RGBColor[
              0.23154240030757095`, 0.3606961217323153, 0.9364973692100068], 
             UndirectedEdge[1, 92] -> 
             RGBColor[
              0.82512404738325, 0.19412001438123114`, 0.1716921221887404], 
             UndirectedEdge[85, 213] -> 
             RGBColor[
              0.21726177740977812`, 0.34568628162294734`, 0.9356841088622658],
              UndirectedEdge[2, 174] -> 
             RGBColor[
              0.21589796346133705`, 0.34425282669233714`, 0.9356064416754841],
              UndirectedEdge[104, 204] -> 
             RGBColor[
              0.40934807922423605`, 0.5281560108098651, 0.9475315219665212], 
             UndirectedEdge[125, 243] -> 
             RGBColor[
              0.9113059901364808, 0.6302952707033915, 0.519761776336199], 
             UndirectedEdge[149, 243] -> 
             RGBColor[
              0.9414606577081649, 0.8037269245686582, 0.5463530672768225], 
             UndirectedEdge[35, 175] -> 
             RGBColor[
              0.19450102624862847`, 0.3217632890376051, 0.9343879177551523], 
             UndirectedEdge[82, 201] -> 
             RGBColor[
              0.7294018709234232, 0.5233754189666472, 0.5768926874649807], 
             UndirectedEdge[39, 69] -> 
             RGBColor[
              0.20464654155210055`, 0.3324268688843776, 0.9349656898427401], 
             UndirectedEdge[5, 204] -> 
             RGBColor[
              0.7273105149978081, 0.7527675975931751, 0.6471903809836539], 
             UndirectedEdge[107, 277] -> 
             RGBColor[
              0.7007432409432577, 0.7578412318622451, 0.7139688588587303], 
             UndirectedEdge[236, 260] -> 
             RGBColor[
              0.2447992469285118, 0.3746299080635468, 0.9372523270133223], 
             UndirectedEdge[11, 51] -> 
             RGBColor[
              0.6715557743614986, 0.7416503460034106, 0.9690558457242018], 
             UndirectedEdge[41, 242] -> 
             RGBColor[
              0.18473837996455222`, 0.31150212880551553`, 0.933831949491815], 
             UndirectedEdge[53, 93] -> 
             RGBColor[
              0.22850372850548528`, 0.3575022850054033, 0.93632432134619], 
             UndirectedEdge[82, 293] -> 
             RGBColor[
              0.7565992079701278, 0.6673833817942012, 0.600389979606483], 
             UndirectedEdge[76, 151] -> 
             RGBColor[
              0.46237290629163863`, 0.5709821178298984, 0.9517671246297987], 
             UndirectedEdge[130, 269] -> 
             RGBColor[
              0.9424840400754735, 0.8045885394133, 0.29907204955461253`], 
             UndirectedEdge[13, 289] -> 
             RGBColor[
              0.2883666647778183, 0.41815288261871875`, 0.9398165114828785], 
             UndirectedEdge[86, 120] -> 
             RGBColor[
              0.4366336879326583, 0.5460453622474791, 0.9502000470026102], 
             UndirectedEdge[86, 284] -> 
             RGBColor[
              0.41756739126480746`, 0.526005475576538, 0.9491142496134344], 
             UndirectedEdge[49, 102] -> 
             RGBColor[
              0.20090857647606358`, 0.32849803058878846`, 0.9347528182614836],
              UndirectedEdge[27, 299] -> 
             RGBColor[
              0.8942677012180347, 0.5273127630922669, 0.2514374852904795], 
             UndirectedEdge[120, 182] -> 
             RGBColor[
              0.2667169591353605, 0.3976668132561618, 0.9385005082991529], 
             UndirectedEdge[97, 182] -> 
             RGBColor[
              0.35160088518762583`, 0.47393087490628993`, 0.9438088436678389],
              UndirectedEdge[42, 130] -> 
             RGBColor[
              0.8747039583373085, 0.4890440410280375, 0.21576830813423137`], 
             UndirectedEdge[15, 127] -> 
             RGBColor[
              0.3036056586421837, 0.43273265059365945`, 0.9407369791910881], 
             UndirectedEdge[28, 176] -> 
             RGBColor[
              0.18883134167646898`, 0.3158040910735011, 0.9340650376063144], 
             UndirectedEdge[26, 35] -> 
             RGBColor[
              0.21774452951257628`, 0.3461936846912394, 0.9357116008803525], 
             UndirectedEdge[44, 59] -> 
             RGBColor[
              0.650613500039462, 0.7181916581041776, 0.9197475834219577], 
             UndirectedEdge[155, 218] -> 
             RGBColor[
              0.9467517036363646, 0.8603082831521655, 0.5999961337585191], 
             UndirectedEdge[65, 155] -> 
             RGBColor[
              0.6518886127524492, 0.6234637492866453, 0.6024205995762867], 
             UndirectedEdge[55, 252] -> 
             RGBColor[
              0.22003960441036646`, 0.34860595392497, 0.9358423020005227], 
             UndirectedEdge[160, 296] -> 
             RGBColor[
              0.1914857715941317, 0.31859406521754197`, 0.9342162034632482], 
             UndirectedEdge[88, 147] -> 
             RGBColor[
              0.21812810554997109`, 0.34659684742666674`, 0.9357334449682322],
              UndirectedEdge[204, 243] -> 
             RGBColor[
              0.7355129252278461, 0.7903594474546665, 0.9053392735975632], 
             UndirectedEdge[65, 106] -> 
             RGBColor[
              0.6196619973862446, 0.6970249085872788, 0.9659794196694249], 
             UndirectedEdge[115, 245] -> 
             RGBColor[
              0.2884856169676899, 0.4165730051879058, 0.9398857105111442], 
             UndirectedEdge[60, 205] -> 
             RGBColor[
              0.3298135622578278, 0.45810382130942706`, 0.9423091178497511], 
             UndirectedEdge[75, 111] -> 
             RGBColor[
              0.4735665439631073, 0.5802328466571501, 0.952603227994324], 
             UndirectedEdge[17, 86] -> 
             RGBColor[
              0.648920103921949, 0.7249224984916083, 0.966146582786049], 
             UndirectedEdge[67, 166] -> 
             RGBColor[
              0.1825106958270533, 0.309160691533672, 0.9337050861757479], 
             UndirectedEdge[3, 169] -> 
             RGBColor[
              0.7794786659769637, 0.8276850371059405, 0.962203475513276], 
             UndirectedEdge[7, 255] -> 
             RGBColor[
              0.6521687790491231, 0.722483760175034, 0.9669180874613099], 
             UndirectedEdge[211, 231] -> 
             RGBColor[
              0.25095672851015194`, 0.3811018116127316, 0.937602986480219], 
             UndirectedEdge[218, 290] -> 
             RGBColor[
              0.956800253470921, 0.9001474347654498, 0.6080814328251828], 
             UndirectedEdge[201, 269] -> 
             RGBColor[
              0.9092644951417719, 0.6354174551570593, 0.2706625685866058], 
             UndirectedEdge[34, 223] -> 
             RGBColor[
              0.1825916590093845, 0.3092457889716643, 0.9337096969092074], 
             UndirectedEdge[63, 208] -> 
             RGBColor[
              0.1860996055764639, 0.3129328632303233, 0.9339094692766605], 
             UndirectedEdge[131, 190] -> 
             RGBColor[
              0.21691115903565433`, 0.3453177594812544, 0.9356641416645529], 
             UndirectedEdge[27, 181] -> 
             RGBColor[
              0.9780677338465346, 0.9376794577026863, 0.3692977168650637], 
             UndirectedEdge[108, 136] -> 
             RGBColor[
              0.3166504809342749, 0.4423958027593246, 0.9416280716923184], 
             UndirectedEdge[101, 254] -> 
             RGBColor[
              0.4830549298600605, 0.587475687952538, 0.9535083702036646], 
             UndirectedEdge[62, 212] -> 
             RGBColor[
              0.2175228275026328, 0.34596066182206947`, 0.9356989752788649], 
             UndirectedEdge[69, 195] -> 
             RGBColor[
              0.1956464700099377, 0.32296722305607023`, 0.9344531490828267], 
             UndirectedEdge[136, 252] -> 
             RGBColor[
              0.3152788883487585, 0.44095417198795417`, 0.9415499615236627], 
             UndirectedEdge[26, 175] -> 
             RGBColor[
              0.20585209939384108`, 0.33369398661282884`, 0.9350343445783642],
              UndirectedEdge[24, 27] -> 
             RGBColor[
              0.9468027585380377, 0.8226935997742366, 0.2974286527731346], 
             UndirectedEdge[231, 266] -> 
             RGBColor[
              0.21466524015743277`, 0.342957156340762, 0.9355362399069774], 
             UndirectedEdge[153, 157] -> 
             RGBColor[
              0.2018036290672552, 0.32943878761174283`, 0.9348037901824403], 
             UndirectedEdge[161, 244] -> 
             RGBColor[
              0.19557921069497186`, 0.3228965292515542, 0.9344493187643406], 
             UndirectedEdge[128, 150] -> 
             RGBColor[
              0.8761748343795548, 0.5085261390565783, 0.21751289486357597`], 
             UndirectedEdge[113, 200] -> 
             RGBColor[
              0.3166014610591278, 0.4448447914728484, 0.9415337241001722], 
             UndirectedEdge[211, 264] -> 
             RGBColor[
              0.28347133969758304`, 0.41527672951614025`, 0.9394546454862865],
              UndirectedEdge[144, 232] -> 
             RGBColor[
              0.19277383312180774`, 0.31994789955094727`, 0.9342895566617331],
              UndirectedEdge[208, 244] -> 
             RGBColor[
              0.18941015567136937`, 0.31641246128106837`, 0.9340980002070455],
              UndirectedEdge[47, 133] -> 
             RGBColor[
              0.18469446291568115`, 0.3114559692026503, 0.9338294484808514], 
             UndirectedEdge[181, 258] -> 
             RGBColor[
              0.6632277418204424, 0.717240503923456, 0.6720754184533696], 
             UndirectedEdge[53, 147] -> 
             RGBColor[
              0.21463757351182716`, 0.3429280769420639, 0.9355346643324394], 
             UndirectedEdge[123, 267] -> 
             RGBColor[
              0.19740462411574278`, 0.32481515449468, 0.9345532733581963], 
             UndirectedEdge[59, 227] -> 
             RGBColor[
              0.9688560866723765, 0.9191321953350291, 0.5894640490955131], 
             UndirectedEdge[213, 286] -> 
             RGBColor[
              0.21163290304685975`, 0.3397699777762725, 0.935363552794471], 
             UndirectedEdge[16, 126] -> 
             RGBColor[
              0.23513936956710785`, 0.3644767644851118, 0.9367022112880983], 
             UndirectedEdge[68, 109] -> 
             RGBColor[
              0.9348338843673183, 0.947970458954174, 0.8784588716115629], 
             UndirectedEdge[137, 156] -> 
             RGBColor[
              0.32801284307365003`, 0.4541649141300481, 0.9422814923217423], 
             UndirectedEdge[181, 202] -> 
             RGBColor[
              0.9264323498375825, 0.7262195810590035, 0.3058153788755507], 
             UndirectedEdge[135, 214] -> 
             RGBColor[
              0.20695344714813524`, 0.3348515729320728, 0.9350970647036734], 
             UndirectedEdge[166, 234] -> 
             RGBColor[
              0.19012477797807242`, 0.3171635746350845, 0.9341386968902232], 
             UndirectedEdge[63, 152] -> 
             RGBColor[
              0.18270109795627662`, 0.30936081624367795`, 0.9337159292953324],
              UndirectedEdge[130, 167] -> 
             RGBColor[
              0.9097426027065735, 0.6798665267659179, 0.24623498340554434`], 
             UndirectedEdge[30, 74] -> 
             RGBColor[
              0.22759891531018372`, 0.3565512689686714, 0.9362727935732689], 
             UndirectedEdge[31, 177] -> 
             RGBColor[
              0.3558101333125378, 0.4810556899295358, 0.9439496708878323], 
             UndirectedEdge[24, 72] -> 
             RGBColor[
              0.8765897348730561, 0.4812812059474597, 0.21665925991431845`], 
             UndirectedEdge[39, 285] -> 
             RGBColor[
              0.20070194384757245`, 0.3282808465949789, 0.9347410508389766], 
             UndirectedEdge[27, 72] -> 
             RGBColor[
              0.8996284799870488, 0.5685180578191442, 0.256570973093821], 
             UndirectedEdge[109, 151] -> 
             RGBColor[
              0.7953196099914366, 0.8378390101205823, 0.8651417721704804], 
             UndirectedEdge[29, 178] -> 
             RGBColor[
              0.22713326298795516`, 0.3560618388539467, 0.9362462753623888], 
             UndirectedEdge[149, 256] -> 
             RGBColor[
              0.8567159557183694, 0.3785989305571812, 0.19965971650756104`], 
             UndirectedEdge[93, 137] -> 
             RGBColor[
              0.25133211293896884`, 0.38149636444816565`, 0.9376243640681086],
              UndirectedEdge[7, 145] -> 
             RGBColor[
              0.9016117745004403, 0.9243171913792056, 0.9881346792519563], 
             UndirectedEdge[271, 278] -> 
             RGBColor[
              0.21163260011638724`, 0.339769659377139, 0.9353635355430288], 
             UndirectedEdge[15, 135] -> 
             RGBColor[
              0.2357262900418861, 0.3650936551170112, 0.9367356355408658], 
             UndirectedEdge[94, 130] -> 
             RGBColor[
              0.8543459981416374, 0.7646454516027577, 0.6141415308874059], 
             UndirectedEdge[265, 286] -> 
             RGBColor[
              0.22180329067308052`, 0.3504597000112502, 0.9359427413240442], 
             UndirectedEdge[140, 201] -> 
             RGBColor[
              0.8313415461919986, 0.24191043475062424`, 0.1776460060696587], 
             UndirectedEdge[29, 259] -> 
             RGBColor[
              0.19020824390880345`, 0.3172513026203284, 0.9341434501515016], 
             UndirectedEdge[21, 123] -> 
             RGBColor[
              0.1960904957019222, 0.3234339222112008, 0.934478435689108], 
             UndirectedEdge[21, 189] -> 
             RGBColor[
              0.20470683599275827`, 0.3324902421643972, 0.934969123521938], 
             UndirectedEdge[107, 289] -> 
             RGBColor[
              0.32595994240234355`, 0.45071429020400966`, 0.942211921890683], 
             UndirectedEdge[17, 66] -> 
             RGBColor[
              0.5450024443168381, 0.6387388987189666, 0.9584682781320619], 
             UndirectedEdge[71, 208] -> 
             RGBColor[
              0.20631669235829492`, 0.33418230327536513`, 0.9350608024603861],
              UndirectedEdge[6, 289] -> 
             RGBColor[
              0.22701980203641853`, 0.3559425842000419, 0.9362398139290493], 
             UndirectedEdge[96, 132] -> 
             RGBColor[
              0.1989233882773373, 0.32641147192372544`, 0.9346397647303889], 
             UndirectedEdge[55, 283] -> 
             RGBColor[
              0.25397885208056453`, 0.38427825509893676`, 0.9377750919467229],
              UndirectedEdge[48, 244] -> 
             RGBColor[
              0.19115682833937214`, 0.31824832500058275`, 0.9341974706315176],
              UndirectedEdge[110, 278] -> 
             RGBColor[
              0.19327360105018532`, 0.32047318733078894`, 0.9343180177059138],
              UndirectedEdge[245, 288] -> 
             RGBColor[
              0.2170539171587743, 0.34546780732004123`, 0.9356722715284729], 
             UndirectedEdge[106, 210] -> 
             RGBColor[
              0.6667698289178824, 0.73732879896912, 0.9691188386686375], 
             UndirectedEdge[176, 296] -> 
             RGBColor[
              0.19069988788986053`, 0.3177680516164482, 0.9341714485489008], 
             UndirectedEdge[82, 154] -> 
             RGBColor[
              0.5553686317376758, 0.6499123001732142, 0.9581397995541713], 
             UndirectedEdge[46, 117] -> 
             RGBColor[
              0.1951092767006187, 0.3224025988279529, 0.9344225567185672], 
             UndirectedEdge[249, 258] -> 
             RGBColor[
              0.2738091064777124, 0.40221653034560445`, 0.9390107464799751], 
             UndirectedEdge[146, 170] -> 
             RGBColor[
              0.19880274533348388`, 0.3262846685405311, 0.9346328942932117], 
             UndirectedEdge[18, 129] -> 
             RGBColor[
              0.1945312219559263, 0.32179502664049353`, 0.9343896373560123], 
             UndirectedEdge[13, 179] -> 
             RGBColor[
              0.42802275177735205`, 0.5432681021152472, 0.9490151577652866], 
             UndirectedEdge[144, 160] -> 
             RGBColor[
              0.19670215780285202`, 0.3240768178608952, 0.934513268940883], 
             UndirectedEdge[17, 130] -> 
             RGBColor[
              0.8077331614173798, 0.7282311492830874, 0.6094955989444572], 
             UndirectedEdge[111, 163] -> 
             RGBColor[
              0.6176770518281398, 0.70049708256499, 0.9630449466269559], 
             UndirectedEdge[107, 251] -> 
             RGBColor[
              0.34704129264344796`, 0.47287212594221606`, 0.943412473599851], 
             UndirectedEdge[1, 198] -> 
             RGBColor[
              0.8916422332040788, 0.5589019666811266, 0.5551782044510756], 
             UndirectedEdge[168, 269] -> 
             RGBColor[
              0.6867881591822118, 0.7211895103907764, 0.6484929822846838], 
             UndirectedEdge[145, 201] -> 
             RGBColor[
              0.8551339776040994, 0.6224043744000362, 0.5890252543779623], 
             UndirectedEdge[197, 226] -> 
             RGBColor[
              0.9862994243091077, 0.9886024741101505, 0.8767175253588012], 
             UndirectedEdge[105, 174] -> 
             RGBColor[
              0.25852249961576723`, 0.3890539167423275, 0.9380338459521285], 
             UndirectedEdge[178, 284] -> 
             RGBColor[
              0.24998452415634886`, 0.38007996319556836`, 0.9375476208805174],
              UndirectedEdge[201, 202] -> 
             RGBColor[
              0.8559674140090618, 0.41835228392990204`, 0.20072485105646432`],
              UndirectedEdge[24, 65] -> 
             RGBColor[
              0.6506137006766177, 0.6184091477452374, 0.6013947753940398], 
             UndirectedEdge[134, 169] -> 
             RGBColor[
              0.42476901028009817`, 0.532311534169465, 0.9496393645496872], 
             UndirectedEdge[104, 300] -> 
             RGBColor[
              0.2803668703826312, 0.4095782545351725, 0.9393670254375599], 
             UndirectedEdge[168, 225] -> 
             RGBColor[
              0.31400402532006444`, 0.4388934235578272, 0.9415037514868442], 
             UndirectedEdge[27, 202] -> 
             RGBColor[
              0.9182061196430783, 0.6984705750022384, 0.2738580279631242], 
             UndirectedEdge[113, 187] -> 
             RGBColor[
              0.24618639037776724`, 0.3760878837786886, 0.9373313227806626], 
             UndirectedEdge[7, 201] -> 
             RGBColor[
              0.8918418892803384, 0.651606686480418, 0.5901834370133114], 
             UndirectedEdge[51, 104] -> 
             RGBColor[
              0.5731922784257398, 0.6585842020957557, 0.9621993062038972], 
             UndirectedEdge[2, 183] -> 
             RGBColor[
              0.19566573686527955`, 0.3229874737426237, 0.9344542463017356], 
             UndirectedEdge[135, 249] -> 
             RGBColor[
              0.21026660117408774`, 0.33833390787944695`, 0.9352857439240791],
              UndirectedEdge[84, 270] -> 
             RGBColor[
              0.20015353292457566`, 0.32770443194364846`, 0.9347098196482133],
              UndirectedEdge[114, 116] -> 
             RGBColor[
              0.26324193971723214`, 0.3940143475187522, 0.9383026110841209], 
             UndirectedEdge[15, 168] -> 
             RGBColor[
              0.3293937457780264, 0.4550689955237798, 0.942380173299874], 
             UndirectedEdge[42, 237] -> 
             RGBColor[
              0.8313396990003062, 0.24189623642583113`, 0.17764423719680783`],
              UndirectedEdge[40, 140] -> 
             RGBColor[
              0.7532763216794478, 0.4456404138262269, 0.5669390131907837], 
             UndirectedEdge[42, 167] -> 
             RGBColor[
              0.8726433787924812, 0.48087452978022555`, 0.21411031746444492`],
              UndirectedEdge[16, 285] -> 
             RGBColor[
              0.22323502267117318`, 0.3519645411182973, 0.9360242763432778], 
             UndirectedEdge[8, 286] -> 
             RGBColor[
              0.21267948434468417`, 0.34087000107737286`, 0.9354231540511039],
              UndirectedEdge[9, 236] -> 
             RGBColor[
              0.21519552032906075`, 0.34351451442284786`, 0.9355664385782725],
              UndirectedEdge[54, 238] -> 
             RGBColor[
              0.21574020514797415`, 0.344087012702538, 0.9355974575729206], 
             UndirectedEdge[165, 183] -> 
             RGBColor[
              0.2052672821395783, 0.33307930659904317`, 0.9350010401008936], 
             UndirectedEdge[249, 263] -> 
             RGBColor[
              0.20867298294508915`, 0.33665891407953785`, 0.9351949897234846],
              UndirectedEdge[33, 98] -> 
             RGBColor[
              0.18977923539730202`, 0.3168003874740297, 0.9341190187514328], 
             UndirectedEdge[282, 293] -> 
             RGBColor[
              0.6701954566467123, 0.5968924733689558, 0.5936831325375491], 
             UndirectedEdge[54, 163] -> 
             RGBColor[
              0.4325936369919836, 0.5385727559524309, 0.9502636460208878], 
             UndirectedEdge[145, 237] -> 
             RGBColor[
              0.8449892632007987, 0.5444276540540705, 0.5793106644085455], 
             UndirectedEdge[140, 181] -> 
             RGBColor[
              0.9018064820205194, 0.5497777318797257, 0.2827365338887451], 
             UndirectedEdge[15, 265] -> 
             RGBColor[
              0.24054595553413333`, 0.37015942913380495`, 0.9370101083605932],
              UndirectedEdge[144, 230] -> 
             RGBColor[
              0.19486271425090618`, 0.32214344606034284`, 0.9344085153518125],
              UndirectedEdge[22, 266] -> 
             RGBColor[
              0.1933455924812791, 0.32054885488938883`, 0.9343221175114128], 
             UndirectedEdge[18, 165] -> 
             RGBColor[
              0.2088844992725249, 0.33688123115058255`, 0.9352070352654217], 
             UndirectedEdge[17, 140] -> 
             RGBColor[
              0.7604910702916794, 0.4512766302762225, 0.5676581119067918], 
             UndirectedEdge[80, 237] -> 
             RGBColor[
              0.9019415360113127, 0.566959177926033, 0.27190996500840703`], 
             UndirectedEdge[7, 127] -> 
             RGBColor[
              0.6435774661849356, 0.7150423967840147, 0.9663706566026036], 
             UndirectedEdge[60, 212] -> 
             RGBColor[
              0.2603180236560096, 0.39094112635142153`, 0.9381360983899805], 
             UndirectedEdge[53, 270] -> 
             RGBColor[
              0.21435826979552958`, 0.3426345110273567, 0.935518758398989], 
             UndirectedEdge[243, 254] -> 
             RGBColor[
              0.6530996726183891, 0.7197996840615158, 0.8998607275791879], 
             UndirectedEdge[201, 277] -> 
             RGBColor[
              0.9191876398595434, 0.6685769154126919, 0.3358815336975568], 
             UndirectedEdge[288, 296] -> 
             RGBColor[
              0.1980362372485557, 0.3254790199438521, 0.9345892427917222], 
             UndirectedEdge[93, 273] -> 
             RGBColor[
              0.24003010742833283`, 0.36961724006794966`, 0.9369807315740968],
              UndirectedEdge[128, 277] -> 
             RGBColor[
              0.9189757209517455, 0.6669480138238988, 0.3356785999121213], 
             UndirectedEdge[3, 115] -> 
             RGBColor[
              0.6529735529155825, 0.7222241006469869, 0.9530066800693597], 
             UndirectedEdge[74, 123] -> 
             RGBColor[
              0.20225228122772315`, 0.32991034947858455`, 0.9348293402592576],
              UndirectedEdge[52, 147] -> 
             RGBColor[
              0.20606540532151835`, 0.3339181846671946, 0.9350464920353876], 
             UndirectedEdge[64, 76] -> 
             RGBColor[
              0.28111114711231006`, 0.41111591460968555`, 0.939381752805837], 
             UndirectedEdge[132, 260] -> 
             RGBColor[
              0.2275319348126233, 0.35648086821892655`, 0.9362689791330215], 
             UndirectedEdge[171, 285] -> 
             RGBColor[
              0.18941388075270052`, 0.31641637657773114`, 0.9340982123449165],
              UndirectedEdge[226, 290] -> 
             RGBColor[
              0.9663340369194856, 0.9069146206326038, 0.576578764162101], 
             UndirectedEdge[24, 290] -> 
             RGBColor[
              0.9350874753344331, 0.7803505010572445, 0.2666280628425426], 
             UndirectedEdge[103, 265] -> 
             RGBColor[
              0.3220227389937979, 0.445387567907627, 0.9420312197585695], 
             UndirectedEdge[41, 208] -> 
             RGBColor[
              0.1889556017616225, 0.3159346963015419, 0.9340721140343375], 
             UndirectedEdge[80, 179] -> 
             RGBColor[
              0.7507825863487789, 0.7818072220217351, 0.663873785850424], 
             UndirectedEdge[102, 183] -> 
             RGBColor[
              0.19246783079694663`, 0.31962627170585023`, 0.934272130282022], 
             UndirectedEdge[16, 220] -> 
             RGBColor[
              0.2899399087951104, 0.41982488843615623`, 0.9399054307139528], 
             UndirectedEdge[52, 217] -> 
             RGBColor[
              0.19938565089971289`, 0.32689733924898534`, 0.9346660899028769],
              UndirectedEdge[24, 241] -> 
             RGBColor[
              0.9549441101488896, 0.8619933825501465, 0.5685691356523801], 
             UndirectedEdge[105, 163] -> 
             RGBColor[
              0.4524953087499887, 0.5594906748089641, 0.9513970167856213], 
             UndirectedEdge[2, 102] -> 
             RGBColor[
              0.19539325191364892`, 0.3227010747819161, 0.9344387286868456], 
             UndirectedEdge[49, 54] -> 
             RGBColor[
              0.22682934694082163`, 0.355742403819019, 0.936228967793108], 
             UndirectedEdge[216, 237] -> 
             RGBColor[
              0.8457691907154687, 0.3401325922104371, 0.19096561195736456`], 
             UndirectedEdge[89, 281] -> 
             RGBColor[
              0.6796029595718664, 0.743830302697593, 0.9334123929687868], 
             UndirectedEdge[145, 167] -> 
             RGBColor[
              0.8862929429929738, 0.7834059474084649, 0.6157767446761826], 
             UndirectedEdge[16, 90] -> 
             RGBColor[
              0.2312332284112072, 0.3603711624666066, 0.9364797623278878], 
             UndirectedEdge[210, 290] -> 
             RGBColor[
              0.7090449941186435, 0.7036067912817707, 0.613645317642163], 
             UndirectedEdge[152, 242] -> 
             RGBColor[
              0.1817008098525566, 0.3083094500247394, 0.9336589643676192], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.18784627824446665`, 0.31476872694983776`, 0.9340089397011326],
              UndirectedEdge[77, 282] -> 
             RGBColor[
              0.42720741988360567`, 0.5444473278590943, 0.9484422569236628], 
             UndirectedEdge[81, 162] -> 
             RGBColor[
              0.9404065856589258, 0.790829015220349, 0.5112620539625906], 
             UndirectedEdge[34, 247] -> 
             RGBColor[
              0.1907246807083084, 0.31779411044059236`, 0.9341728604632337], 
             UndirectedEdge[7, 60] -> 
             RGBColor[
              0.6127935489939296, 0.6863930727259957, 0.9644818440323379], 
             UndirectedEdge[155, 162] -> 
             RGBColor[
              0.9588310572734952, 0.8681281277104613, 0.5263067793464253], 
             UndirectedEdge[234, 249] -> 
             RGBColor[
              0.2008059288288086, 0.3283901414032867, 0.934746972629826], 
             UndirectedEdge[118, 234] -> 
             RGBColor[
              0.19143808005152518`, 0.3185439383824441, 0.9342134875004501], 
             UndirectedEdge[223, 271] -> 
             RGBColor[
              0.20206279459486376`, 0.3297111870133029, 0.9348185492758365], 
             UndirectedEdge[154, 216] -> 
             RGBColor[
              0.6818806659330219, 0.5446461937629699, 0.581927314015972], 
             UndirectedEdge[147, 247] -> 
             RGBColor[
              0.2055770841992048, 0.33340492820629564`, 0.9350186828698783], 
             UndirectedEdge[4, 286] -> 
             RGBColor[
              0.22071420539136402`, 0.34931500232817103`, 0.9358807195284078],
              UndirectedEdge[88, 124] -> 
             RGBColor[
              0.20439146202389424`, 0.3321587641272566, 0.9349511634409652], 
             UndirectedEdge[23, 136] -> 
             RGBColor[
              0.6909810750975458, 0.7521740618261392, 0.8862275585719336], 
             UndirectedEdge[11, 104] -> 
             RGBColor[
              0.4334513122055766, 0.547724101182389, 0.9494290167598639], 
             UndirectedEdge[4, 121] -> 
             RGBColor[
              0.2229935575329976, 0.35171074594830076`, 0.9360105252608744], 
             UndirectedEdge[4, 213] -> 
             RGBColor[
              0.21145636706915383`, 0.33958442727067606`, 0.9353534993317023],
              UndirectedEdge[198, 204] -> 
             RGBColor[
              0.7240997016369111, 0.7823833581016821, 0.9486564217578735], 
             UndirectedEdge[156, 168] -> 
             RGBColor[
              0.3974514720884778, 0.5186742214563766, 0.9465462342423088], 
             UndirectedEdge[31, 226] -> 
             RGBColor[
              0.7029528418062473, 0.7632425995782364, 0.912689477230743], 
             UndirectedEdge[36, 242] -> 
             RGBColor[
              0.18110760662426995`, 0.30768595582055314`, 0.9336251823213337],
              UndirectedEdge[216, 269] -> 
             RGBColor[
              0.9198143078765437, 0.7038328982122137, 0.28026875837406984`], 
             UndirectedEdge[97, 202] -> 
             RGBColor[
              0.6577144481717172, 0.5251054048614994, 0.5800987564788447], 
             UndirectedEdge[23, 59] -> 
             RGBColor[
              0.9871771704378065, 0.988965444691414, 0.8621710004720957], 
             UndirectedEdge[174, 238] -> 
             RGBColor[
              0.21032414623090429`, 0.3383943913827284, 0.9352890210299346], 
             UndirectedEdge[86, 97] -> 
             RGBColor[
              0.5215176139849236, 0.6223094238976072, 0.9555083823712963], 
             UndirectedEdge[46, 212] -> 
             RGBColor[
              0.21903868251240277`, 0.34755392154809645`, 0.9357853009791648],
              UndirectedEdge[59, 291] -> 
             RGBColor[
              0.955941254786202, 0.9662985742039245, 0.945506158028788], 
             UndirectedEdge[125, 149] -> 
             RGBColor[
              0.865349139567608, 0.4449573647077131, 0.20792686311137834`], 
             UndirectedEdge[32, 80] -> 
             RGBColor[
              0.9832422855582464, 0.9646748589231064, 0.6130382528147665], 
             UndirectedEdge[69, 90] -> 
             RGBColor[
              0.21162247094140993`, 0.33975901297201105`, 0.9353629587014987],
              UndirectedEdge[215, 229] -> 
             RGBColor[
              0.2212270314220612, 0.34985401500148217`, 0.9359099242121978], 
             UndirectedEdge[187, 245] -> 
             RGBColor[
              0.22499133551940492`, 0.35381053727845513`, 0.9361242957617526],
              UndirectedEdge[98, 275] -> 
             RGBColor[
              0.17961340510331275`, 0.30611545528417883`, 0.9335400897551883],
              UndirectedEdge[252, 280] -> 
             RGBColor[
              0.2499775972482043, 0.3800726825759171, 0.937547226403346], 
             UndirectedEdge[96, 146] -> 
             RGBColor[
              0.20048974504421074`, 0.3280578121984645, 0.9347289664310452], 
             UndirectedEdge[191, 270] -> 
             RGBColor[
              0.22010792895967446`, 0.34867776735831935`, 0.9358461929825286],
              UndirectedEdge[40, 120] -> 
             RGBColor[
              0.4841619759818365, 0.5839129078583203, 0.9544325893141365], 
             UndirectedEdge[215, 233] -> 
             RGBColor[
              0.2150686635576537, 0.34338117991291517`, 0.9355592142728086], 
             UndirectedEdge[21, 257] -> 
             RGBColor[
              0.1888268034733999, 0.3157993211343368, 0.9340647791623633], 
             UndirectedEdge[200, 245] -> 
             RGBColor[
              0.2954064062007655, 0.4225674449726149, 0.9403266970812623], 
             UndirectedEdge[41, 108] -> 
             RGBColor[
              0.21464006545615802`, 0.34293069613355404`, 0.9355348062449824],
              UndirectedEdge[63, 73] -> 
             RGBColor[
              0.18277574146873998`, 0.309439271307949, 0.933720180132942]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.8649038628242013, 0.8951148792988238, 0.9869764966166072], 
             160 -> RGBColor[
              0.19576440547633542`, 0.32309118070879467`, 0.9344598653331682],
              245 -> RGBColor[
              0.22524249753236514`, 0.35407452447866766`, 0.9361385990668298],
              155 -> RGBColor[
              0.9263138375757084, 0.7455659509853682, 0.2595685879581257], 
             213 -> RGBColor[
              0.20237506472464956`, 0.3300394027187775, 0.9348363325977657], 
             27 -> RGBColor[
              0.9698415036520304, 0.9099304516459211, 0.33734036595263717`], 
             19 -> RGBColor[
              0.18771789764902583`, 0.31463379080422954`, 0.9340016286161444],
              164 -> RGBColor[
              0.18196114135351968`, 0.30858307493822207`, 0.9336737898614731],
              190 -> RGBColor[
              0.2044144915577996, 0.3321829696275479, 0.9349524749388519], 
             103 -> RGBColor[
              0.4213296380105047, 0.5393562886265211, 0.9480677298602272], 
             138 -> RGBColor[
              0.231287806205471, 0.36042852718880986`, 0.9364828704525304], 
             291 -> RGBColor[
              0.926874823682218, 0.9445288413300859, 0.9928873421853748], 28 -> 
             RGBColor[
              0.18347004528514485`, 0.31016902864039503`, 0.9337597197081559],
              195 -> RGBColor[
              0.18372407711397143`, 0.31043603219904004`, 0.9337741864450011],
              114 -> RGBColor[
              0.23913206195702244`, 0.3686733373382309, 0.9369295892130448], 
             93 -> RGBColor[
              0.24113006344271598`, 0.3707733635803057, 0.9370433724418767], 
             34 -> RGBColor[
              0.1836929464736069, 0.31040331192222026`, 0.933772413601086], 
             161 -> RGBColor[
              0.2016546493170191, 0.3292822004483829, 0.9347953060060602], 22 -> 
             RGBColor[
              0.18854143418810532`, 0.3154993799220345, 0.9340485278037318], 
             124 -> 
             RGBColor[
              0.1859244664032461, 0.3127487808548065, 0.9338994953598411], 84 -> 
             RGBColor[
              0.18746791982634672`, 0.31437104826308443`, 0.9339873927489519],
              46 -> RGBColor[
              0.2047087295239663, 0.33249223238575365`, 0.9349692313557391], 
             241 -> RGBColor[
              0.986124206873734, 0.9885300171977407, 0.8796213317111282], 185 -> 
             RGBColor[
              0.5295564396500168, 0.6289567998104505, 0.9561077692398556], 
             121 -> RGBColor[
              0.22544944565233713`, 0.35429204007402687`, 0.9361503844561099],
              126 -> RGBColor[
              0.22348836128871713`, 0.3522308160679321, 0.9360387036027661], 
             236 -> RGBColor[
              0.23143093535124384`, 0.3605789649959291, 0.9364910214456416], 
             78 -> RGBColor[
              0.19413140389541048`, 0.3213747925089622, 0.9343668683089438], 
             254 -> RGBColor[
              0.31878183695974033`, 0.45053453755869494`, 0.9415334746567325],
              290 -> RGBColor[
              0.9464109372448213, 0.8252442542119368, 0.27573918609145315`], 
             251 -> RGBColor[
              0.28560729073547014`, 0.4175217494840773, 0.9395762847380378], 
             165 -> RGBColor[
              0.21779424853057935`, 0.34624594253152846`, 0.935714432304875], 
             100 -> RGBColor[
              0.1806628381309981, 0.3072184759341732, 0.933599853413618], 235 -> 
             RGBColor[
              0.40849384697781144`, 0.528238571579618, 0.9472498446058684], 
             70 -> RGBColor[
              0.20976983040282712`, 0.33781177030176596`, 0.9352574535635624],
              234 -> RGBColor[
              0.1941551643020383, 0.3213997662028249, 0.9343682214289508], 
             257 -> RGBColor[
              0.18407578926115742`, 0.31080570396557056`, 0.9337942159314718],
              135 -> RGBColor[
              0.21307650899259664`, 0.34128729915514544`, 0.9354457640174572],
              265 -> RGBColor[
              0.22271583997709107`, 0.35141884718873295`, 0.9359947096569118],
              111 -> RGBColor[
              0.6142037164471443, 0.6976772724307221, 0.9627715129425172], 
             182 -> RGBColor[
              0.2543436096659436, 0.38466163844813683`, 0.9377958643515997], 
             188 -> RGBColor[
              0.35586441424032067`, 0.4826536021746064, 0.9438963436902155], 
             154 -> RGBColor[
              0.4972976140125026, 0.6027676319143825, 0.9535682363176986], 
             269 -> 
             RGBColor[
              0.9731648978995463, 0.9211410408128702, 0.3502511250338943], 
             208 -> RGBColor[
              0.18931653926981418`, 0.3163140645074111, 0.9340926688914699], 
             86 -> RGBColor[
              0.5941770672605392, 0.6814187364307716, 0.9611949417585145], 
             119 -> RGBColor[
              0.18085158366002294`, 0.307416859452336, 0.933610602192272], 
             140 -> RGBColor[0.817319, 0.134127, 0.164218], 85 -> 
             RGBColor[
              0.23214849009490668`, 0.36133316052711717`, 0.9365318851267661],
              242 -> RGBColor[
              0.18088209567567362`, 0.3074489295153584, 0.9336123398064248], 
             117 -> RGBColor[
              0.1855098238772711, 0.3123129652701522, 0.9338758820813954], 47 -> 
             RGBColor[
              0.18409960782193097`, 0.31083073878312756`, 0.9337955723632715],
              81 -> RGBColor[
              0.8894648943465696, 0.5909677260051436, 0.2294791371904563], 
             275 -> RGBColor[
              0.1801747671672662, 0.30670548240580453`, 0.9335720584942697], 
             23 -> RGBColor[
              0.989346654985427, 0.9898625823050647, 0.82621702707199], 110 -> 
             RGBColor[
              0.18591721951216156`, 0.3127411639127972, 0.9338990826601146], 
             6 -> RGBColor[
              0.2105950138195758, 0.3386790903924193, 0.9353044465383967], 
             218 -> RGBColor[
              0.9671895696970209, 0.9750506153189628, 0.9404236795589124], 
             108 -> RGBColor[
              0.24068546665888524`, 0.3703060641714354, 0.9370180533127597], 
             297 -> RGBColor[
              0.19199315011410678`, 0.319127352211692, 0.9342450979193615], 
             157 -> RGBColor[
              0.18253809113335498`, 0.30918948573755783`, 0.933706646297914], 
             270 -> RGBColor[
              0.2128391460228046, 0.3410378156242125, 0.9354322465474746], 33 -> 
             RGBColor[
              0.20050642775524471`, 0.3280753467855062, 0.9347299164867587], 
             252 -> RGBColor[
              0.23794228148785246`, 0.3674228026286945, 0.9368618329754481], 
             260 -> RGBColor[
              0.25816755850577977`, 0.38868085113116446`, 0.938013632581003], 
             159 -> RGBColor[
              0.29124080035179, 0.42344292527596916`, 0.9398971047766567], 
             183 -> RGBColor[
              0.19274031574857725`, 0.3199126706665578, 0.9342876478969121], 
             99 -> RGBColor[
              0.19567419878950365`, 0.3229963677615002, 0.9344547281958019], 
             17 -> RGBColor[
              0.7036631405833589, 0.768426260552445, 0.9710982238135836], 277 -> 
             RGBColor[
              0.9930111873350895, 0.9874599613241353, 0.4806890552557963], 
             104 -> RGBColor[
              0.3350878162698179, 0.46465795727473413`, 0.9425724772395593], 
             79 -> RGBColor[
              0.18314084159618357`, 0.3098230146905773, 0.9337409720450827], 
             191 -> RGBColor[
              0.2273767118965443, 0.3563177190924262, 0.9362601394175826], 50 -> 
             RGBColor[
              0.1818234123124711, 0.30843831298355445`, 0.9336659463963373], 
             225 -> RGBColor[
              0.2275966301752516, 0.35654886714697176`, 0.936272663438215], 
             61 -> RGBColor[
              0.2772592389822082, 0.4087474177943471, 0.9391008755405253], 
             196 -> RGBColor[
              0.2030597206401025, 0.3307590194956109, 0.934875322739293], 1 -> 
             RGBColor[
              0.8186934053129894, 0.1446912815038851, 0.16553413207988746`], 
             263 -> RGBColor[
              0.20988927253459944`, 0.3379373115553272, 0.935264255616268], 
             201 -> RGBColor[
              0.8453640923839973, 0.3496938695012485, 0.19107401213931735`], 
             293 -> RGBColor[
              0.8997587664774066, 0.6377097951563564, 0.23806859642232206`], 
             184 -> RGBColor[
              0.1914897805011185, 0.3185982788329645, 0.9342164317645705], 
             106 -> RGBColor[
              0.861860606843299, 0.8926882695866354, 0.9866862281444021], 206 -> 
             RGBColor[
              0.22242260484653656`, 0.35111063847433904`, 0.9359780103500293],
              247 -> RGBColor[
              0.19775641494300986`, 0.32518490895896446`, 0.9345733073253814],
              220 -> RGBColor[
              0.33308943974472227`, 0.4629270639700209, 0.9424451424544752], 
             107 -> RGBColor[
              0.40847529455142584`, 0.5282225024003548, 0.9472486624616643], 
             131 -> RGBColor[
              0.22940782651350908`, 0.3584525493349609, 0.9363758083902539], 
             127 -> RGBColor[
              0.34883524619319184`, 0.47656529010844195`, 0.9434484513179017],
              210 -> RGBColor[
              0.4716790509924657, 0.5819693283516046, 0.9515514491928728], 
             181 -> RGBColor[
              0.9862939640410388, 0.9654284637594515, 0.4012550677774902], 
             194 -> 
             RGBColor[
              0.6860055424687634, 0.754632010702607, 0.9693382794531569], 118 -> 
             RGBColor[
              0.1887209958010121, 0.3156881105620633, 0.9340587535719493], 
             276 -> RGBColor[
              0.24137384732010603`, 0.3710295958922332, 0.9370572555730482], 
             280 -> RGBColor[
              0.2620129130085561, 0.39272256252313964`, 0.938232619831244], 
             189 -> RGBColor[
              0.21583585429987417`, 0.3441875460256914, 0.935602904650621], 
             168 -> RGBColor[
              0.4004114204648772, 0.5212379799686826, 0.9467348395354733], 41 -> 
             RGBColor[
              0.1885946642534308, 0.31555532809567266`, 0.9340515591772053], 
             14 -> RGBColor[
              0.1801938510546308, 0.30672554078141306`, 0.9335731452934231], 
             77 -> RGBColor[
              0.4137826929511934, 0.5328195041366336, 0.9475868451945494], 51 -> 
             RGBColor[
              0.8112967405816618, 0.8525104469167772, 0.981826135168235], 179 -> 
             RGBColor[
              0.5227567642523288, 0.6234365170007214, 0.9555724738845179], 
             223 -> RGBColor[
              0.1814903715451621, 0.30808826602110845`, 0.9336469802173286], 
             292 -> RGBColor[
              0.773715577090376, 0.8231517563699634, 0.978080396007364], 143 -> 
             RGBColor[
              0.3068945586163886, 0.4398960177176607, 0.9407885631521654], 
             112 -> RGBColor[
              0.18923133529375677`, 0.3162245097263307, 0.9340878166510814], 
             197 -> RGBColor[
              0.9863417120240653, 0.9886199611670301, 0.8760167084848537], 54 -> 
             RGBColor[
              0.24403688677483204`, 0.37382861920560384`, 0.937208911730381], 
             71 -> RGBColor[
              0.22331684544677569`, 0.35205054204331915`, 0.9360289360293025],
              177 -> RGBColor[
              0.29197171960673096`, 0.42421116775586953`, 0.9399387295469274],
              158 -> RGBColor[
              0.19294565339664288`, 0.32012849355383366`, 0.9342993415721996],
              226 -> RGBColor[
              0.9862571365941499, 0.9885849870532707, 0.8774183422327487], 
             203 -> RGBColor[
              0.9371250918628792, 0.9526285769763242, 0.9913149984604726], 
             115 -> RGBColor[
              0.3517287364030146, 0.47907148589714393`, 0.9436328219554587], 
             173 -> RGBColor[
              0.20128694378722742`, 0.32889571862269473`, 0.9347743657201101],
              212 -> 
             RGBColor[
              0.23336863550083925`, 0.36261561071043924`, 0.9366013706025906],
              129 -> RGBColor[
              0.18908769389738214`, 0.3160735335113504, 0.9340796364860563], 
             279 -> RGBColor[
              0.23666672657285628`, 0.3660821135381808, 0.9367891920100534], 
             26 -> RGBColor[
              0.2290956026577889, 0.35812438226646315`, 0.9363580277035645], 
             40 -> RGBColor[
              0.6892336433588957, 0.7571538276524538, 0.9696600263815672], 
             146 -> RGBColor[
              0.20002902465321373`, 0.3275735658561667, 0.9347027290863527], 
             192 -> RGBColor[
              0.3306172943235091, 0.4607858158598078, 0.9422876195342679], 
             300 -> RGBColor[
              0.2256459244954445, 0.3544985517956109, 0.9361615736355604], 
             221 -> RGBColor[
              0.1861956076915163, 0.31303376754012907`, 0.9339149364550904], 
             62 -> RGBColor[
              0.20167701950442632`, 0.3293057129336997, 0.9347965799551393], 
             286 -> RGBColor[
              0.22089074136906994`, 0.34950055283376746`, 0.9358907729911765],
              152 -> RGBColor[
              0.1825195240294396, 0.3091699705341204, 0.9337055889288136], 64 -> 
             RGBColor[
              0.2353045398184947, 0.3646503688917182, 0.9367116174895672], 37 -> 
             RGBColor[
              0.22656828106141946`, 0.3554680070272346, 0.9362141004774884], 
             148 -> RGBColor[
              0.2462972527349853, 0.37620440714520426`, 0.9373376362279], 261 -> 
             RGBColor[
              0.24473644409614725`, 0.3745638983048021, 0.9372487504849276], 
             15 -> RGBColor[
              0.2583760710911756, 0.38890001107887695`, 0.9380255070642746], 
             136 -> RGBColor[
              0.39261549520966454`, 0.5144855413472138, 0.9462380900718772], 
             198 -> RGBColor[
              0.964591061095168, 0.9731126518583681, 0.9448222768222637], 63 -> 
             RGBColor[
              0.18288267188311363`, 0.3095516619532356, 0.9337262696618512], 
             171 -> RGBColor[
              0.17914809400855325`, 0.30562638382115925`, 0.9335135909767078],
              59 -> RGBColor[
              0.985007685890186, 0.9880683070777632, 0.8981249738722014], 229 -> 
             RGBColor[
              0.2177123475199571, 0.3461598593765405, 0.9357097681634818], 
             102 -> RGBColor[
              0.19219534584531597`, 0.31933987274514264`, 0.9342566126671321],
              299 -> 
             RGBColor[
              0.8186938987840391, 0.1446950745386128, 0.16553460462832187`], 
             128 -> RGBColor[
              0.8449402545684014, 0.34643606632366236`, 0.19066814456844627`],
              12 -> RGBColor[
              0.42962012936485927`, 0.5465370955454517, 0.948595992638333], 
             222 -> RGBColor[
              0.2214255710569613, 0.35006269274590207`, 0.9359212307506922], 
             92 -> RGBColor[
              0.8315546894535105, 0.24354874725857717`, 0.17785011229759332`],
              271 -> RGBColor[
              0.2226352176445654, 0.3513341080054973, 0.9359901183343445], 
             132 -> RGBColor[
              0.19689631111946682`, 0.3242808853066886, 0.9345243256850401], 
             80 -> RGBColor[
              0.9788084084452291, 0.9401779270427488, 0.37217509781633024`], 
             244 -> RGBColor[
              0.1895037720729246, 0.31651085805472556`, 0.934103331522621], 
             150 -> RGBColor[
              0.9074094141907081, 0.6706162117894943, 0.24435764515870567`], 
             125 -> RGBColor[
              0.8351944719959239, 0.27152571084244637`, 0.18133557217075477`],
              258 -> RGBColor[
              0.340161519599846, 0.46905254408746033`, 0.942895769129249], 
             133 -> RGBColor[
              0.18528931800943133`, 0.31208119962217307`, 0.9338633245984311],
              255 -> RGBColor[
              0.3660178719215669, 0.49144801689048034`, 0.9445433130353144], 
             176 -> RGBColor[
              0.19419263806779313`, 0.3214391535066072, 0.9343703555044731], 
             230 -> RGBColor[
              0.19208551837244375`, 0.31922443710768994`, 0.9342503581550272],
              274 -> RGBColor[
              0.46304655962256364`, 0.5749610829682137, 0.9508718678503764], 
             87 -> RGBColor[
              0.9931480500222558, 0.9877526967730439, 0.4955857141352578], 
             130 -> RGBColor[
              0.9118031822514008, 0.6880360380137298, 0.24789297407533079`], 
             35 -> RGBColor[
              0.20639345636736367`, 0.33426298711601565`, 0.9350651740571405],
              31 -> RGBColor[
              0.41964854701834464`, 0.537900212103202, 0.9479606122287372], 
             18 -> RGBColor[
              0.19997475001447043`, 0.3275165197696367, 0.9346996382259684], 
             24 -> RGBColor[
              0.9237640134240451, 0.7354567479025522, 0.2575169395936321], 
             151 -> RGBColor[
              0.5978280581771518, 0.684382775332144, 0.9614823611374906], 137 -> 
             RGBColor[
              0.26153416243522165`, 0.3922193653160256, 0.9382053556943405], 
             296 -> RGBColor[
              0.18720713771192796`, 0.31409694972628927`, 0.9339725415933283],
              266 -> RGBColor[
              0.1981497507744529, 0.3255983298567432, 0.9345957072190938], 
             283 -> RGBColor[
              0.3058207768282486, 0.438767404976628, 0.9407274128678487], 284 -> 
             RGBColor[
              0.24095771526907575`, 0.3705922147223045, 0.9370335574683543], 
             238 -> RGBColor[
              0.1874435235211163, 0.31434540619947215`, 0.9339860034154601], 
             72 -> RGBColor[
              0.8294154563220671, 0.22710566399236717`, 0.1758015802350048], 
             288 -> RGBColor[
              0.20886533678518346`, 0.33686109016141486`, 0.9352059439901159],
              172 -> RGBColor[
              0.19058407149220488`, 0.3176463212393284, 0.9341648529763892], 
             243 -> RGBColor[
              0.9874175082770378, 0.9890648305643368, 0.8581879805016432], 88 -> 
             RGBColor[
              0.22285845764454237`, 0.35156874739970667`, 0.9360028315220893],
              273 -> RGBColor[
              0.2389301514139497, 0.3684611165555936, 0.9369180907063167], 
             202 -> RGBColor[
              0.8665707356341262, 0.4870106983585556, 0.21037568997361125`], 
             98 -> RGBColor[
              0.1790520430393593, 0.3055254281625532, 0.9335081210161069], 30 -> 
             RGBColor[
              0.24929644188312317`, 0.37935674509947226`, 0.9375084356129837],
              116 -> RGBColor[
              0.2873518174774419, 0.41935535769927346`, 0.9396756329551971], 
             240 -> RGBColor[
              0.18053047455342514`, 0.3070793534218085, 0.9335923155036896], 
             73 -> RGBColor[
              0.1826688110543663, 0.3093268806626624, 0.9337140906040328], 29 -> 
             RGBColor[
              0.19525519293228838`, 0.32255596603906117`, 0.934430866432097], 
             75 -> RGBColor[
              0.3329293714790703, 0.46278842088357813`, 0.9424349430461306], 
             200 -> RGBColor[
              0.3655703148691659, 0.4910603654665621, 0.9445147950956946], 
             156 -> RGBColor[
              0.3944915237120784, 0.5161104629440706, 0.9463576289491441], 25 -> 
             RGBColor[
              0.1911156300253715, 0.31820502296044406`, 0.9341951244484827], 
             38 -> RGBColor[
              0.18611948239069784`, 0.312953755022346, 0.9339106012318261], 3 -> 
             RGBColor[
              0.9542183694281502, 0.96537671539683, 0.9623805381832607], 57 -> 
             RGBColor[
              0.17967566298483006`, 0.30618089226503126`, 0.9335436352494385],
              227 -> RGBColor[
              0.952704487454567, 0.8501960835922951, 0.28080312431882476`], 
             39 -> RGBColor[
              0.20172422019829714`, 0.3293553238556548, 0.934799267964828], 
             109 -> RGBColor[
              0.9928111618057213, 0.9912952449090205, 0.7688011832034702], 
             256 -> RGBColor[
              0.817928104297447, 0.13880884254138265`, 0.16480127896312016`], 
             287 -> RGBColor[
              0.2430009596347453, 0.3727397940997984, 0.9371499172122699], 
             239 -> RGBColor[
              0.23757609093788187`, 0.36703791314285356`, 0.9368409789653577],
              285 -> RGBColor[
              0.1996796674968478, 0.327206369334303, 0.9346828337131252], 216 -> 
             RGBColor[
              0.8664637178535413, 0.48652475561155717`, 0.21028639171424535`],
              21 -> RGBColor[
              0.19357781768564236`, 0.320792938303103, 0.9343353423932549], 
             175 -> RGBColor[
              0.18260859612989327`, 0.30926359095919453`, 0.9337106614531641],
              7 -> RGBColor[
              0.9383196861766793, 0.9535195034595876, 0.9892928618873055], 13 -> 
             RGBColor[
              0.33328873930237535`, 0.463099687229773, 0.9424578416460552], 
             294 -> RGBColor[
              0.5360494193639693, 0.63422809324764, 0.9566189203875064], 193 -> 
             RGBColor[
              0.27956374695486264`, 0.41116960178785156`, 0.939232113860354], 
             60 -> RGBColor[
              0.28726741181117993`, 0.4192666419924039, 0.9396708261773704], 
             65 -> RGBColor[
              0.3774633879291902, 0.5013615475879224, 0.9452726111944477], 69 -> 
             RGBColor[
              0.20756886290590398`, 0.3354984139131004, 0.9351321117206522], 
             217 -> RGBColor[
              0.20003824461178885`, 0.32758325661720833`, 0.9347032541493537],
              214 -> RGBColor[
              0.20083038530367384`, 0.32841584670900015`, 0.9347483653898895],
              170 -> RGBColor[
              0.19757646601375403`, 0.32499577122489554`, 0.9345630595000708],
              74 -> RGBColor[
              0.20590138873724428`, 0.3337457928378705, 0.935037151533554], 
             246 -> RGBColor[
              0.1844498116639085, 0.31119882522525194`, 0.9338155159539919], 
             264 -> 
             RGBColor[
              0.2962099519152749, 0.42866581863159803`, 0.9401800906069961], 
             278 -> RGBColor[
              0.2006299825882091, 0.3282052107487807, 0.934736952751713], 45 -> 
             RGBColor[
              0.29993474933268105`, 0.43258081688308847`, 0.9403922123095734],
              237 -> RGBColor[
              0.8250746635773962, 0.19374042880931708`, 0.17164483220048377`],
              228 -> RGBColor[
              0.426257062503514, 0.5436241760628097, 0.9483817009917713], 180 -> 
             RGBColor[
              0.19488460571983207`, 0.32216645538218325`, 0.9344097620385824],
              53 -> RGBColor[
              0.21587739356825456`, 0.3442312064305009, 0.9356052702505034], 
             48 -> RGBColor[
              0.1928098846058197, 0.31998579194643995`, 0.9342916097404141], 
             5 -> RGBColor[
              0.9710126878169619, 0.9138811308413543, 0.3418901952738247], 
             101 -> RGBColor[
              0.6473280227603806, 0.724416838346381, 0.9654832657505968], 267 -> 
             RGBColor[
              0.1962060745132835, 0.32355540287006146`, 0.9344850177314316], 
             120 -> RGBColor[
              0.27909030860477735`, 0.41067198806418675`, 0.939205152246706], 
             147 -> RGBColor[
              0.21339775345539977`, 0.34162494745362687`, 0.9354640584143752],
              89 -> RGBColor[
              0.3807443443279537, 0.5042033471148679, 0.9454816708349412], 43 -> 
             RGBColor[
              0.2255865897625529, 0.3544361872293025, 0.9361581946103001], 
             199 -> RGBColor[
              0.19839476243792764`, 0.32585585264969186`, 0.9346096602708663],
              268 -> RGBColor[
              0.20504953117466115`, 0.3328504365287066, 0.9349886395055752], 
             169 -> RGBColor[
              0.6047389625257771, 0.6899933588150511, 0.9620264128432912], 20 -> 
             RGBColor[
              0.21900416978762977`, 0.3475176464861269, 0.9357833355305459], 
             4 -> RGBColor[
              0.2205376694136581, 0.34912945182257465`, 0.935870666065639], 
             167 -> RGBColor[
              0.9076820231617462, 0.6716970155181059, 0.2445769927357579], 
             142 -> RGBColor[
              0.8299355921400753, 0.23110365581454728`, 0.17629966288173887`],
              16 -> RGBColor[
              0.24679037784549854`, 0.37672271290229153`, 0.9373657189734305],
              281 -> RGBColor[
              0.9784615748157791, 0.9834572582803182, 0.9213431151026323], 
             289 -> 
             RGBColor[
              0.2434445902532613, 0.3732060780076645, 0.9371751813197018], 
             178 -> RGBColor[
              0.25901133304362195`, 0.3895677116688322, 0.9380616842926806], 
             58 -> RGBColor[
              0.19114091674596853`, 0.31823160090706226`, 0.9341965644898124],
              186 -> RGBColor[
              0.19311599281626868`, 0.32030753108400334`, 0.9343090421501528],
              122 -> RGBColor[
              0.18504035865818397`, 0.31181952755907755`, 0.93384914673168], 
             249 -> RGBColor[
              0.20745669335557887`, 0.3353805166037485, 0.9351257238307011], 
             113 -> RGBColor[
              0.2676326072490897, 0.3986292174791347, 0.9385526531046497], 52 -> 
             RGBColor[
              0.1987330571876369, 0.3262114218807623, 0.9346289256564001], 
             187 -> RGBColor[
              0.22474017350644473`, 0.35354655007824254`, 0.9361099924566755],
              259 -> RGBColor[
              0.18516129488531852`, 0.3119466392015956, 0.9338560338709061], 
             42 -> RGBColor[
              0.8376047344232163, 0.2900520440423452, 0.18364364219313192`], 
             134 -> RGBColor[
              0.24479905803441923`, 0.3746297095238789, 0.9372523162560832], 
             248 -> RGBColor[
              0.22195872707107797`, 0.35062307352078237`, 0.9359515931969625],
              174 -> RGBColor[
              0.23320476894069225`, 0.36244337656598474`, 0.9365920386444091],
              215 -> RGBColor[
              0.22474171532416531`, 0.3535481706264238, 0.9361100802609137], 
             83 -> RGBColor[
              0.846552585818907, 0.35882915084310774`, 0.19221211479479816`], 
             95 -> RGBColor[
              0.28755638833203334`, 0.4195703746379904, 0.9396872829627306], 
             166 -> RGBColor[
              0.18609439165410657`, 0.312927383067344, 0.9339091723514956], 
             233 -> RGBColor[
              0.20539561179114207`, 0.3332141891994065, 0.9350083482847035], 
             295 -> RGBColor[
              0.19692281060910452`, 0.3243087379504625, 0.9345258347917725], 
             141 -> RGBColor[
              0.2938477713702168, 0.42618301710784506`, 0.940045567919488], 
             205 -> RGBColor[
              0.3723597127044757, 0.4969410006264502, 0.9449474095221317], 
             224 -> RGBColor[
              0.20866772558178895`, 0.33665338825737323`, 0.9351946903244223],
              231 -> RGBColor[
              0.23118072954041266`, 0.36031598282478083`, 0.9364767725948611],
              68 -> 
             RGBColor[
              0.8768566069289154, 0.9046456729993274, 0.9881165600196555], 10 -> 
             RGBColor[
              0.19040293767796423`, 0.3174559381160143, 0.9341545376736317], 
             250 -> RGBColor[
              0.18265386603570732`, 0.30931117250048296`, 0.9337132395073293],
              282 -> RGBColor[
              0.4406321468160179, 0.5560751515815551, 0.9492976686527762], 
             232 -> RGBColor[
              0.18790775611424687`, 0.3148333440888988, 0.9340124407748683], 
             253 -> RGBColor[
              0.19184993915614282`, 0.3189768284147727, 0.9342369422671671], 
             55 -> RGBColor[
              0.20213692733288047`, 0.32978910522124555`, 0.9348227710255971],
              91 -> RGBColor[
              0.49015879412300467`, 0.5969720163279171, 0.9530062422656385], 
             105 -> RGBColor[
              0.28384023029084227`, 0.41566445691867016`, 0.9394756532598479],
              36 -> RGBColor[
              0.18133311757286624`, 0.3079229821257478, 0.9336380248362428], 
             123 -> RGBColor[
              0.19860317371820202`, 0.3260749061192986, 0.9346215289849611], 
             94 -> RGBColor[
              0.796888814031874, 0.8412548651917855, 0.9803900876994809], 96 -> 
             RGBColor[
              0.20095046543520778`, 0.32854205854076235`, 0.9347552037757377],
              2 -> RGBColor[
              0.19859115798198185`, 0.32606227681868954`, 0.934620844706559], 
             262 -> RGBColor[
              0.3038398335581257, 0.4366853080006712, 0.9406146010791581], 
             272 -> RGBColor[
              0.17908821045117204`, 0.30556344240551475`, 0.9335101806967048],
              97 -> RGBColor[
              0.44885816070930806`, 0.563200111364443, 0.9498218229840781], 
             209 -> RGBColor[
              0.1804556557285978, 0.30700071409312746`, 0.9335880546823002], 
             66 -> RGBColor[
              0.3863417480503173, 0.5090515368854881, 0.9458383324505404], 
             139 -> RGBColor[
              0.4407231525670485, 0.5561539761890157, 0.9493034674587586], 56 -> 
             RGBColor[
              0.19935669202797407`, 0.3268669016386893, 0.9346644407379722], 
             144 -> RGBColor[
              0.19763991012936863`, 0.32506245501299574`, 0.9345666725485978],
              298 -> RGBColor[
              0.2601377913887575, 0.39075169081115385`, 0.9381258344289902], 
             204 -> RGBColor[
              0.4836083421786542, 0.5916540643449961, 0.9524905666934831], 
             207 -> 
             RGBColor[
              0.18528775379377113`, 0.3120795555323372, 0.9338632355186633], 
             149 -> RGBColor[
              0.895503807139292, 0.6183890185729798, 0.2345181540520019], 219 -> 
             RGBColor[
              0.18433414396946993`, 0.31107725114464163`, 0.9338089288499086],
              9 -> RGBColor[
              0.19896010530687766`, 0.32645006384976655`, 0.9346418557109033],
              11 -> RGBColor[
              0.5318148081413353, 0.630790245090044, 0.9562855562801685], 44 -> 
             RGBColor[
              0.31621931418873805`, 0.44831500913059213`, 0.9413701929717141],
              153 -> RGBColor[
              0.22106916700115545`, 0.3496880894859278, 0.9359009340669666], 
             32 -> RGBColor[
              0.9876761626712638, 0.9891717908034641, 0.8539014078132029], 
             162 -> RGBColor[
              0.9913482769712819, 0.9906903044355545, 0.7930449707347249], 90 -> 
             RGBColor[
              0.21567607897691587`, 0.34401961203092163`, 0.935593805682345], 
             8 -> RGBColor[
              0.2044682273202984, 0.33223944932097826`, 0.9349555351110312], 
             163 -> RGBColor[
              0.6211503872091352, 0.7033168926992579, 0.9633183803113946], 49 -> 
             RGBColor[
              0.20962180710681122`, 0.3376561884324342, 0.9352490238558351], 
             76 -> RGBColor[
              0.3269177544061254, 0.4575814603276529, 0.9420518881221068], 82 -> 
             RGBColor[
              0.6134396494628491, 0.6970569684320459, 0.962711362790644], 67 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 211 -> 
             RGBColor[
              0.2707327274798912, 0.4018876404006824, 
               0.9387292003655769]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJwtl3k4FGrYxsc2dmbMmGEYZp8hUUJS8qQSUSklLeLUoUhCylJkaUGShISD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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 5}], {
             RGBColor[
             0.8948530465649757, 0.5292862061726197, 0.25371216367685606`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 32}], {
             RGBColor[
             0.9031847839921265, 0.5669315361536746, 0.5097177699465452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 51}], {
             RGBColor[
             0.8149950729473256, 0.4986008642103312, 0.5736801336240612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 80}], {
             RGBColor[
             0.8987509068791093, 0.542434604273317, 0.26885461494810886`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 83}], {
             RGBColor[
             0.8326229955659482, 0.2517602161734964, 0.1788731234373428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 92}], {
             RGBColor[
             0.82512404738325, 0.19412001438123114`, 0.1716921221887404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 125}], {
             RGBColor[
             0.8269439386544566, 0.20810849617316574`, 0.17343485212532112`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 128}], {
             RGBColor[
             0.8318168299406954, 0.24556367391377373`, 0.17810113832416685`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 142}], {
             RGBColor[
             0.8243144987265323, 0.1878974686592162, 0.17091689748081318`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 149}], {
             RGBColor[
             0.8570986062261408, 0.38154015003843245`, 0.20002614306594468`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 150}], {
             RGBColor[
             0.8630514097518487, 0.4076537466466897, 0.20494588861929658`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 197}], {
             RGBColor[
             0.9025175586685273, 0.5666556213354577, 0.5207754202823706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 198}], {
             RGBColor[
             0.8916422332040788, 0.5589019666811266, 0.5551782044510756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 237}], {
             RGBColor[
             0.8218840344451928, 0.1692158551566011, 0.1685894821401856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 243}], {
             RGBColor[
             0.9030554567950135, 0.5668780560341109, 0.5118610562907654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 256}], {
             RGBColor[
             0.8183107548052182, 0.14175006202263388`, 0.1651677055215038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 277}], {
             RGBColor[
             0.9058522963240394, 0.5660756214140101, 0.3231115936678419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 281}], {
             RGBColor[
             0.8985774900643843, 0.5640742698921016, 0.5434386235912599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 49}], {
             RGBColor[
             0.20410648254439653`, 0.3318592326255619, 0.934934934281197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 54}], {
             RGBColor[
             0.22131402237840694`, 0.34994544801214666`, 0.9359148782184701]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 102}], {
             RGBColor[
             0.19539325191364892`, 0.3227010747819161, 0.9344387286868456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 165}], {
             RGBColor[
             0.2081927032562806, 0.336154109675109, 0.935167638505717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 172}], {
             RGBColor[
             0.19458761473709335`, 0.321854299029009, 0.9343928488414741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 174}], {
             RGBColor[
             0.21589796346133705`, 0.34425282669233714`, 0.9356064416754841]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 183}], {
             RGBColor[
             0.19566573686527955`, 0.3229874737426237, 0.9344542463017356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 238}], {
             RGBColor[
             0.19301734075154908`, 0.3202038415090809, 0.9343034240610095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 253}], {
             RGBColor[
             0.19522054856906235`, 0.32251955261673115`, 0.9344288934868631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 24}], {
             RGBColor[
             0.9389911914260977, 0.8504167316496911, 0.6099487388884464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 59}], {
             RGBColor[
             0.9696130276591681, 0.9767225112372966, 0.930252756027731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 65}], {
             RGBColor[
             0.6658408786786703, 0.7333691314923763, 0.9538265746888542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 72}], {
             RGBColor[
             0.8918169128751087, 0.5962411896945986, 0.5690910592091327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 106}], {
             RGBColor[
             0.9080394881357245, 0.9290324924917327, 0.9745333831638314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 115}], {
             RGBColor[
             0.6529735529155825, 0.7222241006469869, 0.9530066800693597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 155}], {
             RGBColor[
             0.9402661035019293, 0.855471333191099, 0.6109745630706932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[
             0.972783323199716, 0.9780335099161923, 0.8777127544589929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 169}], {
             RGBColor[
             0.7794786659769637, 0.8276850371059405, 0.962203475513276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 194}], {
             RGBColor[
             0.8201119559484569, 0.8600043630497185, 0.9658594088182089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 200}], {
             RGBColor[
             0.659894342148658, 0.7282185404316961, 0.9534476666394777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 210}], {
             RGBColor[
             0.7129487102103079, 0.7736730218742174, 0.9569659936880668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 227}], {
             RGBColor[
             0.9534614284413586, 0.9077863994945625, 0.6215918312510428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 228}], {
             RGBColor[
             0.690237715965832, 0.7545004457298199, 0.955381119587516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 241}], {
             RGBColor[
             0.9701712881509421, 0.9769533662972854, 0.9210009349471945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 264}], {
             RGBColor[
             0.6252141606717125, 0.697021267014214, 0.9512803143951285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 290}], {
             RGBColor[
             0.9503146533364857, 0.8953104848043834, 0.619059862137357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 291}], {
             RGBColor[
             0.940546596555184, 0.9549527783634579, 0.9776339401843177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 8}], {
             RGBColor[
             0.21250294836697825`, 0.34068445057177643`, 0.935413100588335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 15}], {
             RGBColor[
             0.23945687025241685`, 0.36901473145072583`, 0.9369480865649568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 62}], {
             RGBColor[
             0.21110734445904222`, 0.33921758237813715`, 0.9353336230103891]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 85}], {
             RGBColor[
             0.2263430797542824, 0.3552313061748459, 0.9362012755962026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 121}], {
             RGBColor[
             0.2229935575329976, 0.35171074594830076`, 0.9360105252608744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 135}], {
             RGBColor[
             0.21680708920312736`, 0.3452083754888601, 0.935658215041548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 158}], {
             RGBColor[
             0.2067416614051505, 0.33462897268820413`, 0.9350850038189193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 173}], {
             RGBColor[
             0.21091230660044274`, 0.33901258522263467`, 0.9353225158928745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 186}], {
             RGBColor[
             0.2068268311149634, 0.334718491453289, 0.9350898541078958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 213}], {
             RGBColor[
             0.21145636706915383`, 0.33958442727067606`, 0.9353534993317023]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 214}], {
             RGBColor[
             0.21068402735866598`, 0.33877264926578743`, 0.9353095157277642]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 249}], {
             RGBColor[
             0.21399718138461848`, 0.3422549842131616, 0.93549819494817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 255}], {
             RGBColor[
             0.2932777706676125, 0.42028873435652747`, 0.9402069895504767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 263}], {
             RGBColor[
             0.21521347097412877`, 0.3435333816889509, 0.9355674608409534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 265}], {
             RGBColor[
             0.22162675469537457`, 0.35027414950565383`, 0.9359326878612754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 276}], {
             RGBColor[
             0.23095575836688206`, 0.36007952385740394`, 0.9364639608193436]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 286}], {
             RGBColor[
             0.22071420539136402`, 0.34931500232817103`, 0.9358807195284078]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.7514137479791486, 0.7723356879656991, 0.6490878757769967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 23}], {
             RGBColor[
             0.9801796714011944, 0.9518718565732095, 0.5840536111729073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 51}], {
             RGBColor[
             0.8911547141993119, 0.8831957888790658, 0.6618581652210298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.978010186853574, 0.9509747189595588, 0.6200075845730131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[
             0.9087826368179345, 0.636355140842231, 0.2670511550343114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 92}], {
             RGBColor[
             0.9012836886352362, 0.5787149390499657, 0.259870153785709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 101}], {
             RGBColor[
             0.8091703552886713, 0.8191489845938676, 0.6536867305122107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 128}], {
             RGBColor[
             0.9079764711926817, 0.6301585985825083, 0.2662791699211355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 142}], {
             RGBColor[
             0.9004741399785186, 0.5724923933279508, 0.25909492907778175`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 149}], {
             RGBColor[
             0.933258247478127, 0.766135074707167, 0.2882041746629133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 197}], {
             RGBColor[
             0.9786771999205136, 0.9512505460041922, 0.6089534518793391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 198}], {
             RGBColor[
             0.967801874456065, 0.9434968913498611, 0.6433562360480443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 204}], {
             RGBColor[
             0.7273105149978081, 0.7527675975931751, 0.6471903809836539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 226}], {
             RGBColor[
             0.978634912205556, 0.9512330589473125, 0.6096542687532867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 243}], {
             RGBColor[
             0.9792150980469998, 0.9514729807028455, 0.600039087887734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 256}], {
             RGBColor[
             0.8944703960572045, 0.5263449866913684, 0.2533457371184724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 290}], {
             RGBColor[
             0.9587118125308915, 0.8695626925266455, 0.3088146906826389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 38}], {
             RGBColor[
             0.19835724810513683`, 0.32581642270738265`, 0.9346075238851115]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 52}], {
             RGBColor[
             0.20466403550360635`, 0.3324452561365908, 0.9349666860973984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.21323620369391516`, 0.3414551484114601, 0.9354548583944501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 88}], {
             RGBColor[
             0.21672673573205908`, 0.345123918896063, 0.935653639030243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 93}], {
             RGBColor[
             0.2258625386311459, 0.35472622698636247`, 0.9361739094901367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 124}], {
             RGBColor[
             0.19825974011141095`, 0.3257139356236129, 0.9346019709491189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 147}], {
             RGBColor[
             0.2119963836374878, 0.34015201892302305`, 0.935384252476386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 273}], {
             RGBColor[
             0.22476258261676274`, 0.3535701034740064, 0.9361112686223567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 289}], {
             RGBColor[
             0.22701980203641853`, 0.3559425842000419, 0.9362398139290493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 42}], {
             RGBColor[
             0.8879622102999478, 0.6217857737509664, 0.5864682520402187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 60}], {
             RGBColor[
             0.6127935489939296, 0.6863930727259957, 0.9644818440323379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 77}], {
             RGBColor[
             0.6760511895639363, 0.7431695037981105, 0.9684398535409274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 80}], {
             RGBColor[
             0.9585640473109542, 0.9468487152511682, 0.6807339798518178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 81}], {
             RGBColor[
             0.9138922902616244, 0.7722436147323656, 0.6093859995388808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 82}], {
             RGBColor[
             0.7758796678197641, 0.8252882359458167, 0.9760021123389747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 103}], {
             RGBColor[
             0.6798246620935919, 0.7464378960430543, 0.9686802958737664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 127}], {
             RGBColor[
             0.6435774661849356, 0.7150423967840147, 0.9663706566026036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 130}], {
             RGBColor[
             0.92506143421404, 0.8207777707366587, 0.6185929179813181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 140}], {
             RGBColor[
             0.8778193430883396, 0.5438232517297938, 0.5767554309436527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 145}], {
             RGBColor[
             0.9016117745004403, 0.9243171913792056, 0.9881346792519563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 154}], {
             RGBColor[
             0.7178086500945909, 0.778143567686985, 0.971430549102502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 167}], {
             RGBColor[
             0.9230008546692128, 0.8126082594888467, 0.6169349273115317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 168}], {
             RGBColor[
             0.6693655533207783, 0.7373787417141351, 0.9680138507113893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 181}], {
             RGBColor[
             0.962306825108859, 0.9594739836095195, 0.6952739648323978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 201}], {
             RGBColor[
             0.8918418892803384, 0.651606686480418, 0.5901834370133114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 202}], {
             RGBColor[
             0.9024452109054028, 0.7202651009090716, 0.5998342759304583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 203}], {
             RGBColor[
             0.9377223890197792, 0.9530740402179558, 0.990303930173889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 205}], {
             RGBColor[
             0.6553396994405775, 0.7252302520430189, 0.9671201357047186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 216}], {
             RGBColor[
             0.9023917020151102, 0.7200221295355724, 0.5997896268007754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 237}], {
             RGBColor[
             0.8816971748770377, 0.5736299661344524, 0.5804688470438946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 255}], {
             RGBColor[
             0.6521687790491231, 0.722483760175034, 0.9669180874613099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 269}], {
             RGBColor[
             0.9557422920381128, 0.9373302721362289, 0.6697719934605999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 282}], {
             RGBColor[
             0.6894759164963487, 0.7547973275205713, 0.9692952652700408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 293}], {
             RGBColor[
             0.9190392263270429, 0.795614649307972, 0.6136807291548138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 299}], {
             RGBColor[
             0.8785067924803591, 0.5491072889991002, 0.5774137332578136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 14}], {
             RGBColor[
             0.19233103918746458`, 0.31948249505119564`, 0.9342643402022272]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 64}], {
             RGBColor[
             0.21988638356939655`, 0.34844490910634823`, 0.9358335763002992]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 67}], {
             RGBColor[
             0.1916976136601492, 0.31881672466048916`, 0.9342282675555156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 69}], {
             RGBColor[
             0.2060185451131012, 0.33386893161703934`, 0.9350438234158418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 85}], {
             RGBColor[
             0.21830835870760254`, 0.3467863049240477, 0.9357437101188987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 121}], {
             RGBColor[
             0.21495883648631775`, 0.3432657446975026, 0.9355529597835706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 135}], {
             RGBColor[
             0.2087723681564475, 0.33676337423806185`, 0.9352006495642442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 173}], {
             RGBColor[
             0.2028775855537629, 0.3305675839718365, 0.9348649504155706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 186}], {
             RGBColor[
             0.19879211006828354`, 0.3262734902024908, 0.934632288630592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 213}], {
             RGBColor[
             0.20342164602247398`, 0.3311394260198779, 0.9348959338543985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 234}], {
             RGBColor[
             0.19931169581116837`, 0.32681960776190155`, 0.934661878269991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 249}], {
             RGBColor[
             0.20596246033793864`, 0.3338099829623634, 0.9350406294708662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 263}], {
             RGBColor[
             0.20717874992744892`, 0.3350883804381527, 0.9351098953636496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 286}], {
             RGBColor[
             0.21267948434468417`, 0.34087000107737286`, 0.9354231540511039]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 45}], {
             RGBColor[
             0.24944742731977937`, 0.3795154403664275, 0.9375170340102383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 47}], {
             RGBColor[
             0.1915298565644043, 0.31864040131644705`, 0.9342187140370874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 96}], {
             RGBColor[
             0.19995528537104273`, 0.3274960611952644, 0.9346985297433206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 112}], {
             RGBColor[
             0.19409572030031721`, 0.3213372867880486, 0.9343648361809924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 132}], {
             RGBColor[
             0.19792820821317225`, 0.32536547457822756`, 0.9345830906979717]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 133}], {
             RGBColor[
             0.19212471165815448`, 0.3192656317359698, 0.9342525901546672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 141}], {
             RGBColor[
             0.24640393833854723`, 0.3763165404788058, 0.9373437118151957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 146}], {
             RGBColor[
             0.1994945649800457, 0.3270118148529666, 0.9346722923986279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 236}], {
             RGBColor[
             0.21519552032906075`, 0.34351451442284786`, 0.9355664385782725]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 22}], {
             RGBColor[
             0.18947218593303478`, 0.31647765901902436`, 0.9341015327386817]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 48}], {
             RGBColor[
             0.19160641114189197`, 0.3187208650312271, 0.934223073707023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 63}], {
             RGBColor[
             0.18664280478053893`, 0.31350380003462497`, 0.9339404036677414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 71}], {
             RGBColor[
             0.20685989156236995`, 0.3347532400796667, 0.9350917368514671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 73}], {
             RGBColor[
             0.18653587436616526`, 0.31339140938933835`, 0.9339343141388322]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 100}], {
             RGBColor[
             0.18553288790448116`, 0.3123372070250937, 0.9338771955436248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 119}], {
             RGBColor[
             0.1856272606689936, 0.3124363987841752, 0.9338825699329518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 122}], {
             RGBColor[
             0.1877216481680741, 0.3146377328375459, 0.9340018422026558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 161}], {
             RGBColor[
             0.19602879349749167`, 0.3233690692821986, 0.9344749218398459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 244}], {
             RGBColor[
             0.1899533548754444, 0.3169833980853699, 0.9341289345981263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 266}], {
             RGBColor[
             0.19427634422620857`, 0.3215271339863788, 0.9343751224463628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 51}], {
             RGBColor[
             0.6715557743614986, 0.7416503460034106, 0.9690558457242018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 101}], {
             RGBColor[
             0.589571415450858, 0.6776035417182125, 0.9608844110153827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 104}], {
             RGBColor[
             0.4334513122055766, 0.547724101182389, 0.9494290167598639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 114}], {
             RGBColor[
             0.38547343504917886`, 0.49973179121413747`, 0.9466075727466067]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 116}], {
             RGBColor[
             0.4095833128093886, 0.5250728013946587, 0.9479805946176828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 149}], {
             RGBColor[
             0.7136593076403137, 0.6245896318315118, 0.5954018551660852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 197}], {
             RGBColor[
             0.7590782600827003, 0.809705103128537, 0.9161511323825111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 198}], {
             RGBColor[
             0.7482029346182517, 0.8019514484742061, 0.9505539165512161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 204}], {
             RGBColor[
             0.5077115751599948, 0.6112221547175201, 0.9543880614868259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 243}], {
             RGBColor[
             0.7596161582091865, 0.8099275378271904, 0.907236768390906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 254}], {
             RGBColor[
             0.4252983225505378, 0.5406623913243694, 0.9489095154684506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 283}], {
             RGBColor[
             0.41881779248479195`, 0.534778825033336, 0.9485064845740085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.3382052536051789, 0.4616299042238716, 0.9429808558058818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 27}], {
             RGBColor[
             0.6997308165084448, 0.7282337735956864, 0.6429681792954851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.33246233459167696`, 0.45559373221858496`, 0.9426538050639501]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 76}], {
             RGBColor[
             0.3782689418854923, 0.5020592779365523, 0.9453239403802199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 87}], {
             RGBColor[
             0.7113840896935575, 0.7671448961592477, 0.7220908533867955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 151}], {
             RGBColor[
             0.5137240937710055, 0.6154599354387978, 0.9550391768879118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 154}], {
             RGBColor[
             0.46345887168868094`, 0.5746523637299171, 0.9510821144780158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 181}], {
             RGBColor[
             0.707957046702949, 0.7559827796524516, 0.6749255302079116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 192}], {
             RGBColor[
             0.3801187118441842, 0.5036614557026298, 0.9454418060863005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 220}], {
             RGBColor[
             0.38135478455479077`, 0.5047320797577364, 0.9455205675464041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 239}], {
             RGBColor[
             0.3335981101513706, 0.4567875043441526, 0.9427184858018454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 258}], {
             RGBColor[
             0.3848908244823526, 0.507794819816456, 0.9457458808837911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 32}], {
             RGBColor[
             0.6604824509868196, 0.7261357390166185, 0.898179624729629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 53}], {
             RGBColor[
             0.27458306643531494`, 0.40366544683013694`, 0.9390315559482794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 93}], {
             RGBColor[
             0.2872094013725457, 0.41693652540503934`, 0.939750607043966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 107}], {
             RGBColor[
             0.3708820169269006, 0.49566109481506393`, 0.9448532520538597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 137}], {
             RGBColor[
             0.2974114508687985, 0.42765952627289927`, 0.9403315986701979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 147}], {
             RGBColor[
             0.27334324637888757`, 0.4023623173416999, 0.9389609500302152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 156}], {
             RGBColor[
             0.3638901315072269, 0.4896050750869218, 0.9444077352975997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 179}], {
             RGBColor[
             0.42802275177735205`, 0.5432681021152472, 0.9490151577652866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 251}], {
             RGBColor[
             0.3094480150189227, 0.44031071835692515`, 0.9410170631920465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 270}], {
             RGBColor[
             0.27306394266259, 0.4020687514269927, 0.9389450440967648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 271}], {
             RGBColor[
             0.2779619784734704, 0.40721689761763513`, 0.9392239799901998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 273}], {
             RGBColor[
             0.2861094453581625, 0.4157804018926833, 0.9396879661761859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 274}], {
             RGBColor[
             0.3981676494624695, 0.5190303850989934, 0.9466648547482157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 277}], {
             RGBColor[
             0.6631499633187324, 0.7252798242769541, 0.7115734484509257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 282}], {
             RGBColor[
             0.38696044305919663`, 0.509587419405664, 0.9458777551494157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 289}], {
             RGBColor[
             0.2883666647778183, 0.41815288261871875`, 0.9398165114828785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 67}], {
             RGBColor[
             0.17956042552731538`, 0.30605977039070653`, 0.9335370726467116]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 173}], {
             RGBColor[
             0.1907403974209291, 0.31781062970205387`, 0.9341737555067666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 186}], {
             RGBColor[
             0.18665492193544975`, 0.31351653593270823`, 0.9339410937217879]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.19128445788964016`, 0.31838247175009526`, 0.9342047389455943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 249}], {
             RGBColor[
             0.19382527220510481`, 0.3210530286925808, 0.9343494345620621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 46}], {
             RGBColor[
             0.23154240030757095`, 0.3606961217323153, 0.9364973692100068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 60}], {
             RGBColor[
             0.27282174145117777`, 0.4040833265356404, 0.9388481666208225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.23002654529780098`, 0.3591028620062883, 0.9364110435097069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 77}], {
             RGBColor[
             0.3360793820211845, 0.46085975760775527`, 0.942806176129412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 82}], {
             RGBColor[
             0.43590786027701234`, 0.5429784897554615, 0.9503684349274593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 103}], {
             RGBColor[
             0.33985285455084013`, 0.464128149852699, 0.9430466184622509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 127}], {
             RGBColor[
             0.3036056586421837, 0.43273265059365945`, 0.9407369791910881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 135}], {
             RGBColor[
             0.2357262900418861, 0.3650936551170112, 0.9367356355408658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 158}], {
             RGBColor[
             0.22566086224390924`, 0.3545142523163553, 0.9361624243182372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 168}], {
             RGBColor[
             0.3293937457780264, 0.4550689955237798, 0.942380173299874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 186}], {
             RGBColor[
             0.22574603195372214`, 0.35460377108144014`, 0.9361672746072136]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 196}], {
             RGBColor[
             0.23071789586563907`, 0.35982951528724394`, 0.9364504149017838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 212}], {
             RGBColor[
             0.24587235329600743`, 0.3757578108946581, 0.9373134388334325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 214}], {
             RGBColor[
             0.22960322819742474`, 0.35865792889393855`, 0.936386936227082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 225}], {
             RGBColor[
             0.2429863506332136, 0.37272443911292436`, 0.9371490852512447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 255}], {
             RGBColor[
             0.31219697150637127`, 0.44017401398467865`, 0.9412844100497945]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 265}], {
             RGBColor[
             0.24054595553413333`, 0.37015942913380495`, 0.9370101083605932]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 276}], {
             RGBColor[
             0.24987495920564082`, 0.37996480348555506`, 0.9375413813186614]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 286}], {
             RGBColor[
             0.23963340623012278`, 0.3692002819563222, 0.9369581400277256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.22364840280037163`, 0.35239902984389887`, 0.9360478177300946]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 39}], {
             RGBColor[
             0.22425729902189784`, 0.35303901837897317`, 0.9360824934691292]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 76}], {
             RGBColor[
             0.286854066125812, 0.4171520866149722, 0.9397088035477686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 90}], {
             RGBColor[
             0.2312332284112072, 0.3603711624666066, 0.9364797623278878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 126}], {
             RGBColor[
             0.23513936956710785`, 0.3644767644851118, 0.9367022112880983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 151}], {
             RGBColor[
             0.42230921801132515`, 0.5305527441172178, 0.9494240400554605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 153}], {
             RGBColor[
             0.233929772423327, 0.36320540119410966`, 0.9366333265201985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 192}], {
             RGBColor[
             0.28870383608450384`, 0.4187542643810497, 0.9398266692538492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 220}], {
             RGBColor[
             0.2899399087951104, 0.41982488843615623`, 0.9399054307139528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 222}], {
             RGBColor[
             0.23410797445122994`, 0.3633927028240968, 0.9366434748620613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 239}], {
             RGBColor[
             0.2421832343916902, 0.3718803130225725, 0.9371033489693941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 248}], {
             RGBColor[
             0.23437455245828825`, 0.36367289321153695`, 0.9366586560851965]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 285}], {
             RGBColor[
             0.22323502267117318`, 0.3519645411182973, 0.9360242763432778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 40}], {
             RGBColor[
             0.6964483919711273, 0.7627900441024493, 0.9703791250975754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[
             0.7706339375032876, 0.5292391522973952, 0.5773709330033577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 66}], {
             RGBColor[
             0.5450024443168381, 0.6387388987189666, 0.9584682781320619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 81}], {
             RGBColor[
             0.7965640174649642, 0.6796969932787943, 0.60028868050202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 86}], {
             RGBColor[
             0.648920103921949, 0.7249224984916083, 0.966146582786049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 94}], {
             RGBColor[
             0.7502759773076164, 0.8048405628721153, 0.9757441557565323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 97}], {
             RGBColor[
             0.5762606506463335, 0.665813185958444, 0.9604600233988309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 120}], {
             RGBColor[
             0.4913767245940681, 0.5895491243083159, 0.9551516880301447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 130}], {
             RGBColor[
             0.8077331614173798, 0.7282311492830874, 0.6094955989444572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 140}], {
             RGBColor[
             0.7604910702916794, 0.4512766302762225, 0.5676581119067918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 162}], {
             RGBColor[
             0.8475057087773203, 0.8795582824939998, 0.8820715972741542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 169}], {
             RGBColor[
             0.654201051554568, 0.729209809683748, 0.9665623183284373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 178}], {
             RGBColor[
             0.4813372368134904, 0.5789969861106385, 0.9545799540531321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 182}], {
             RGBColor[
             0.47900337512465124`, 0.5765439495002909, 0.9544470440825916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 201}], {
             RGBColor[
             0.7745136164836781, 0.5590600650268467, 0.5810861179764505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 202}], {
             RGBColor[
             0.7851169381087426, 0.6277184794555003, 0.5907369568935974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 294}], {
             RGBColor[
             0.6198562799736641, 0.7013271769000424, 0.963858572100545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 26}], {
             RGBColor[
             0.21453517633612967`, 0.3428204510180499, 0.9355288329647664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 33}], {
             RGBColor[
             0.20024058888485757`, 0.32779593327757145`, 0.9347147773563635]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 35}], {
             RGBColor[
             0.20318410319091706`, 0.3308897534428262, 0.9348824061415544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 129}], {
             RGBColor[
             0.1945312219559263, 0.32179502664049353`, 0.9343896373560123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 165}], {
             RGBColor[
             0.2088844992725249, 0.33688123115058255`, 0.9352070352654217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 175}], {
             RGBColor[
             0.19129167307218187`, 0.3183900553644156, 0.9342051498395663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 183}], {
             RGBColor[
             0.19635753288152386`, 0.32371459521809726`, 0.9344936430614402]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 184}], {
             RGBColor[
             0.19573226525779447`, 0.3230573993013006, 0.9344580349952694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.2043212377981297, 0.33208495401350496`, 0.9349471642751953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 253}], {
             RGBColor[
             0.19591234458530662`, 0.3232466740922047, 0.9344682902465677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 262}], {
             RGBColor[
             0.25190729178629806`, 0.38210091388515394`, 0.9376571196525632]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 36}], {
             RGBColor[
             0.200168643680248, 0.32772031430593734`, 0.9347106801833944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 37}], {
             RGBColor[
             0.22278622542452461`, 0.3514928267566807, 0.9359987180040172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 41}], {
             RGBColor[
             0.20379941702053028`, 0.3315364872908998, 0.9349174473538756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 44}], {
             RGBColor[
             0.26761174198818394`, 0.3979163278083595, 0.93857676425113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 55}], {
             RGBColor[
             0.21057054856025512`, 0.3386533758536862, 0.9353030532780715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 61}], {
             RGBColor[
             0.248131704384919, 0.378132532140237, 0.9374421055355356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 71}], {
             RGBColor[
             0.22116050761720274`, 0.349784094264723, 0.9359061357799242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 108}], {
             RGBColor[
             0.2298448182232575, 0.3589118553287811, 0.9364006944216527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 136}], {
             RGBColor[
             0.3058098324986471, 0.43100159391667037`, 0.9410107128012115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 152}], {
             RGBColor[
             0.20076184690853469`, 0.3283438085101236, 0.9347444622296798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 177}], {
             RGBColor[
             0.2554879446971804, 0.38586440712099823`, 0.9378610325387366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 208}], {
             RGBColor[
             0.20416035452872197`, 0.331915855496769, 0.9349380022110079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 252}], {
             RGBColor[
             0.2284732256377411, 0.3574702245574107, 0.936322584252997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 268}], {
             RGBColor[
             0.21202685048114545`, 0.34018404150741677`, 0.9353859875180606]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 279}], {
             RGBColor[
             0.22783544818024304`, 0.35679988001215385`, 0.9362862637702997]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 280}], {
             RGBColor[
             0.24050854139809294`, 0.3701201045046333, 0.9370079776808949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 50}], {
             RGBColor[
             0.18770061499905671`, 0.31461562564332873`, 0.9340006443947961]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 74}], {
             RGBColor[
             0.19973960321144332`, 0.32726936557048675`, 0.9346862469634045]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[
             0.21635493982133241`, 0.34473313782066695`, 0.9356324658031498]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 123}], {
             RGBColor[
             0.1960904957019222, 0.3234339222112008, 0.934478435689108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 189}], {
             RGBColor[
             0.20470683599275827`, 0.3324902421643972, 0.934969123521938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 206}], {
             RGBColor[
             0.20800021126608947`, 0.33595178838872103`, 0.9351566763716421]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 257}], {
             RGBColor[
             0.1888268034733999, 0.3157993211343368, 0.9340647791623633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 287}], {
             RGBColor[
             0.21828938866019382`, 0.34676636620145074`, 0.9357426298027625]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 300}], {
             RGBColor[
             0.2096118710905434, 0.33764574504935696`, 0.9352484580144076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.19067565939696252`, 0.3177425859342372, 0.934170068772073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 63}], {
             RGBColor[
             0.18571205303560948`, 0.312525520937635, 0.9338873987327916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 70}], {
             RGBColor[
             0.19915563229546623`, 0.32665557511190024`, 0.9346529906836472]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 73}], {
             RGBColor[
             0.1856051226212358, 0.3124131302923484, 0.9338813092038822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 100}], {
             RGBColor[
             0.1846021361595517, 0.3113589279281038, 0.9338241906086748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 119}], {
             RGBColor[
             0.18469650892406414`, 0.31145811968718523`, 0.933829564998002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 122}], {
             RGBColor[
             0.18679089642314464`, 0.31365945374055604`, 0.9339488372677058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 161}], {
             RGBColor[
             0.1950980417525622, 0.32239079018520866`, 0.934421916904896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 244}], {
             RGBColor[
             0.18902260313051494`, 0.31600511898838, 0.9340759296631764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 266}], {
             RGBColor[
             0.1933455924812791, 0.32054885488938883`, 0.9343221175114128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 24}], {
             RGBColor[
             0.956555334204736, 0.8626596651038085, 0.541866983332811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 31}], {
             RGBColor[
             0.7044976010018857, 0.7638813972041334, 0.8870888196503636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 44}], {
             RGBColor[
             0.6527829845870825, 0.7190887957178285, 0.883793610021852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 59}], {
             RGBColor[
             0.9871771704378065, 0.988965444691414, 0.8621710004720957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 72}], {
             RGBColor[
             0.909381055653747, 0.6084841231487159, 0.5010093036534974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 83}], {
             RGBColor[
             0.917949620402167, 0.6743458665740862, 0.5092145709333941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 106}], {
             RGBColor[
             0.9256036309143629, 0.94127542594585, 0.906451627608196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 136}], {
             RGBColor[
             0.6909810750975458, 0.7521740618261392, 0.8862275585719336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 155}], {
             RGBColor[
             0.9578302462805677, 0.8677142666452164, 0.5428928075150579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 194}], {
             RGBColor[
             0.8376760987270953, 0.8722472965038359, 0.8977776532625734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 197}], {
             RGBColor[
             0.9878441835047461, 0.9892412717360475, 0.8511168677784218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 198}], {
             RGBColor[
             0.9769688580402975, 0.9814876170817164, 0.8855196519471269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 210}], {
             RGBColor[
             0.7305128529889463, 0.7859159553283347, 0.8888842381324313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 226}], {
             RGBColor[
             0.9878018957897885, 0.9892237846791677, 0.8518176846523693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 241}], {
             RGBColor[
             0.9877354309295805, 0.9891962997514028, 0.8529191793915591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 290}], {
             RGBColor[
             0.9678787961151241, 0.9075534182585008, 0.5509781065817215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 291}], {
             RGBColor[
             0.9581107393338224, 0.9671957118175754, 0.9095521846286824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.9468027585380377, 0.8226935997742366, 0.2974286527731346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 59}], {
             RGBColor[
             0.9543858496571156, 0.8617625274901577, 0.5778209567329167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 65}], {
             RGBColor[
             0.6506137006766177, 0.6184091477452374, 0.6013947753940398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 72}], {
             RGBColor[
             0.8765897348730561, 0.4812812059474597, 0.21665925991431845`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 87}], {
             RGBColor[
             0.9584560317231505, 0.8616047223377981, 0.3765513268644449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 106}], {
             RGBColor[
             0.892812310133672, 0.8140725087445938, 0.6221015838690171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 109}], {
             RGBColor[
             0.9582875876148832, 0.8633759964057863, 0.5131590613985512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 155}], {
             RGBColor[
             0.9250389254998768, 0.7405113494439601, 0.2585427637758789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 162}], {
             RGBColor[
             0.9575561451976635, 0.8630735261690534, 0.5252809551641785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 194}], {
             RGBColor[
             0.8048847779464043, 0.7450443793025796, 0.6134276095233945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 210}], {
             RGBColor[
             0.6977215322082554, 0.6587130381270785, 0.6045341943932525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 218}], {
             RGBColor[
             0.945476791560533, 0.8552536816107574, 0.5989703095762722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 226}], {
             RGBColor[
             0.9550105750090976, 0.8620208674779115, 0.5674676409131905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 227}], {
             RGBColor[
             0.9382342504393061, 0.7928264157474236, 0.2691600319562284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 241}], {
             RGBColor[
             0.9549441101488896, 0.8619933825501465, 0.5685691356523801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 290}], {
             RGBColor[
             0.9350874753344331, 0.7803505010572445, 0.2666280628425426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 291}], {
             RGBColor[
             0.9253194185531315, 0.839992794616319, 0.6252021408895034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 299}], {
             RGBColor[
             0.871228956104042, 0.44007591122058254`, 0.21152577211097698`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 28}], {
             RGBColor[
             0.18729283765525817`, 0.3141870258004196, 0.9339774220783192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 58}], {
             RGBColor[
             0.19112827338567, 0.31821831193375316`, 0.9341958444691476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 79}], {
             RGBColor[
             0.18712823581077753`, 0.3140140188255107, 0.9339680482467827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 113}], {
             RGBColor[
             0.22937411863723062`, 0.3584171202197894, 0.9363738887765662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 134}], {
             RGBColor[
             0.21795734402989536`, 0.34641736624216146`, 0.935723720352283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 144}], {
             RGBColor[
             0.19437777007737006`, 0.3216337389867199, 0.9343808984985402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 160}], {
             RGBColor[
             0.19344001775085345`, 0.32064810183461934`, 0.9343274948908254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 176}], {
             RGBColor[
             0.19265413404658233`, 0.31982208823352565`, 0.9342827399764779]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.1930001178726018, 0.32018573917131365`, 0.9343024432435325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 221}], {
             RGBColor[
             0.1886556188584439, 0.3156193952502866, 0.9340550304517865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 230}], {
             RGBColor[
             0.19160057419890764`, 0.31871473003406703`, 0.934222741301755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 232}], {
             RGBColor[
             0.1895116930698092, 0.31651918352467145`, 0.9341037826116756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 245}], {
             RGBColor[
             0.2081790637788683, 0.33613977371955583`, 0.9351668617576563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 288}], {
             RGBColor[
             0.19999048340527747`, 0.32753305656092946`, 0.9347005342192993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 297}], {
             RGBColor[
             0.19155439006973912`, 0.318666187586068, 0.9342201111839221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 35}], {
             RGBColor[
             0.21774452951257628`, 0.3461936846912394, 0.9357116008803525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 54}], {
             RGBColor[
             0.23656624471631046`, 0.3659765007360335, 0.9367834697169728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 75}], {
             RGBColor[
             0.28101248706842963`, 0.4104564015750206, 0.9393964853748475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 102}], {
             RGBColor[
             0.21064547425155244`, 0.3387321275058029, 0.9353073201853483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 129}], {
             RGBColor[
             0.20909164827758553`, 0.33709895788890676`, 0.9352188320948104]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 165}], {
             RGBColor[
             0.2234449255941841, 0.3521851623989958, 0.9360362300042198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 175}], {
             RGBColor[
             0.20585209939384108`, 0.33369398661282884`, 0.9350343445783642]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 183}], {
             RGBColor[
             0.21091795920318307`, 0.3390185264665105, 0.9353228378002383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 224}], {
             RGBColor[
             0.21888166411978893`, 0.3473888852619182, 0.9357763590139934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 253}], {
             RGBColor[
             0.21047277090696587`, 0.3385506053406179, 0.9352974849853658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 262}], {
             RGBColor[
             0.26646771810795733`, 0.39740484513356716`, 0.9384863143913613]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 42}], {
             RGBColor[
             0.9037231190376234, 0.5999912478441332, 0.26049200407288453`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 72}], {
             RGBColor[
             0.8996284799870488, 0.5685180578191442, 0.256570973093821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 87}], {
             RGBColor[
             0.9814947768371431, 0.9488415742094825, 0.4164630400439475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 109}], {
             RGBColor[
             0.9813263327288758, 0.9506128482774708, 0.5530707745780536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 140}], {
             RGBColor[
             0.8935802518260152, 0.5220287258229606, 0.25077918297631857`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 151}], {
             RGBColor[
             0.7838347809145911, 0.7971566134890326, 0.6494113635450639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 154}], {
             RGBColor[
             0.7335695588322665, 0.7563490417801518, 0.6454543011351679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 155}], {
             RGBColor[
             0.9480776706138694, 0.8277482013156446, 0.2984544769553814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 162}], {
             RGBColor[
             0.9805948903116561, 0.9503103780407378, 0.565192668343681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 181}], {
             RGBColor[
             0.9780677338465346, 0.9376794577026863, 0.3692977168650637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 202}], {
             RGBColor[
             0.9182061196430783, 0.6984705750022384, 0.2738580279631242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 203}], {
             RGBColor[
             0.9534832977574548, 0.9312795143111227, 0.6643276822065549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 216}], {
             RGBColor[
             0.9181526107527858, 0.6982276036287391, 0.27381337883344126`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 227}], {
             RGBColor[
             0.9612729955532987, 0.8800632676191081, 0.309071745135731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 299}], {
             RGBColor[
             0.8942677012180347, 0.5273127630922669, 0.2514374852904795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 79}], {
             RGBColor[
             0.1833054434406642, 0.3099960216654862, 0.9337503458766192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 144}], {
             RGBColor[
             0.19055497770725674`, 0.3176157418266954, 0.9341631961283768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 160}], {
             RGBColor[
             0.18961722538074013`, 0.31663010467459485`, 0.9341097925206621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 176}], {
             RGBColor[
             0.18883134167646898`, 0.3158040910735011, 0.9340650376063144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 221}], {
             RGBColor[
             0.18483282648833058`, 0.31160139809026205`, 0.9338373280816231]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 230}], {
             RGBColor[
             0.1877777818287943, 0.3146967328740425, 0.9340050389315915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 232}], {
             RGBColor[
             0.18568890069969585`, 0.3125011863646469, 0.9338860802415121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 240}], {
             RGBColor[
             0.18200025991928498`, 0.3086241910311017, 0.9336760176059227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 245}], {
             RGBColor[
             0.204356271408755, 0.33212177655953135`, 0.9349491593874928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 288}], {
             RGBColor[
             0.19616769103516415`, 0.32351505940090497`, 0.9344828318491358]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 297}], {
             RGBColor[
             0.18773159769962583`, 0.31464819042604353`, 0.9340024088137586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 43}], {
             RGBColor[
             0.21042089134742065`, 0.3384960766341818, 0.9352945305211986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 78}], {
             RGBColor[
             0.1946932984138494, 0.3219653792740117, 0.9343988673705204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 99}], {
             RGBColor[
             0.19546469586089602`, 0.32277616690028066`, 0.9344427973139495]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 131}], {
             RGBColor[
             0.21233150972289871`, 0.34050425768701104`, 0.9354033374111754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 170}], {
             RGBColor[
             0.19641582947302122`, 0.3237758686319784, 0.934496962966084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 178}], {
             RGBColor[
             0.22713326298795516`, 0.3560618388539467, 0.9362462753623888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 182}], {
             RGBColor[
             0.224799401299116, 0.35360880224359903`, 0.9361133653918483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 190}], {
             RGBColor[
             0.199834842245044, 0.32736946783330456`, 0.9346916706854744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 199}], {
             RGBColor[
             0.196824977685108, 0.32420590934437654`, 0.9345202633514818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 209}], {
             RGBColor[
             0.1878554243304431, 0.3147783400660943, 0.9340094605571987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 229}], {
             RGBColor[
             0.20648377022612274`, 0.3343579127078008, 0.9350703172977894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 259}], {
             RGBColor[
             0.19020824390880345`, 0.3172513026203284, 0.9341434501515016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 261}], {
             RGBColor[
             0.21999581851421782`, 0.3485599321719316, 0.9358398084585123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 284}], {
             RGBColor[
             0.21810645410068208`, 0.3465740903806829, 0.9357322119502256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 74}], {
             RGBColor[
             0.22759891531018372`, 0.3565512689686714, 0.9362727935732689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 104}], {
             RGBColor[
             0.2921921290764705, 0.4220073511871032, 0.9400404564262714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 123}], {
             RGBColor[
             0.2239498078006626, 0.3527158256093854, 0.9360649822989724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 189}], {
             RGBColor[
             0.23256614809149867`, 0.36177214556258186`, 0.9365556701318023]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 236}], {
             RGBColor[
             0.2403636886171835, 0.3699678550477007, 0.9369997285293126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 260}], {
             RGBColor[
             0.25373200019445147`, 0.38401879811531836`, 0.9377610340969933]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 267}], {
             RGBColor[
             0.22275125819820335`, 0.35145607398476686`, 0.9359967266722076]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 287}], {
             RGBColor[
             0.24614870075893425`, 0.37604826959963533`, 0.9373291764126268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 300}], {
             RGBColor[
             0.23747118318928384`, 0.36692764844754155`, 0.936835004624272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 37}], {
             RGBColor[
             0.32310841403988205`, 0.4466841095652183, 0.9420873563531128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 44}], {
             RGBColor[
             0.36793393060354135`, 0.4931076106168971, 0.9446654026002257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 59}], {
             RGBColor[
             0.7023281164542653, 0.7629842595904825, 0.9230427930504692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 61}], {
             RGBColor[
             0.3484538930002764, 0.47332381494877457`, 0.9435307438846312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 65}], {
             RGBColor[
             0.3985559674737674, 0.5196308798455622, 0.9466166117115924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 71}], {
             RGBColor[
             0.32148269623256015`, 0.4449753770732606, 0.9419947741290198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 136}], {
             RGBColor[
             0.4061320211140046, 0.526192876725208, 0.9470993511503072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 177}], {
             RGBColor[
             0.3558101333125378, 0.4810556899295358, 0.9439496708878323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 194}], {
             RGBColor[
             0.552827044743554, 0.6462661114029045, 0.958649445840947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 210}], {
             RGBColor[
             0.4456637990054052, 0.5599347702274033, 0.949756030710805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 226}], {
             RGBColor[
             0.7029528418062473, 0.7632425995782364, 0.912689477230743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 241}], {
             RGBColor[
             0.7028863769460394, 0.7632151146504713, 0.9137909719699326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 279}], {
             RGBColor[
             0.32815763679560045`, 0.4519911628206914, 0.9423749021193952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 280}], {
             RGBColor[
             0.3408307300134504, 0.46531138731317084`, 0.9430966160299905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 290}], {
             RGBColor[
             0.683029742131583, 0.6815722331575694, 0.6118498991600951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 291}], {
             RGBColor[
             0.6732616853502813, 0.7412145267166439, 0.970423977207056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 80}], {
             RGBColor[
             0.9832422855582464, 0.9646748589231064, 0.6130382528147665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 92}], {
             RGBColor[
             0.9096154260623872, 0.6163602690310206, 0.515875760055398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 107}], {
             RGBColor[
             0.6980757286113448, 0.7586971466019095, 0.9005750351374335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 125}], {
             RGBColor[
             0.9114353173335938, 0.6303487508229553, 0.5176184899919789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 128}], {
             RGBColor[
             0.9163082086198326, 0.6678039285635632, 0.5222847761908246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 142}], {
             RGBColor[
             0.9088058774056695, 0.6101377233090057, 0.5151005353474709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 145}], {
             RGBColor[
             0.9262900127477325, 0.9421433350511439, 0.920438952214905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 149}], {
             RGBColor[
             0.9415899849052779, 0.803780404688222, 0.5442097809326024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 150}], {
             RGBColor[
             0.9475427884309859, 0.8298940012964792, 0.5491295264859543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 156}], {
             RGBColor[
             0.691083843191671, 0.7526411268737674, 0.9001295183811735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 167}], {
             RGBColor[
             0.947679092916505, 0.830434403160785, 0.5492392002744804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 179}], {
             RGBColor[
             0.7552164634617963, 0.8063041539020928, 0.9047369408488604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 205}], {
             RGBColor[
             0.6800179376878698, 0.7430563957149572, 0.8994244086676673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 237}], {
             RGBColor[
             0.90637541312433, 0.5914561098063906, 0.5127731200068433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 256}], {
             RGBColor[
             0.9028021334843555, 0.5639903166724234, 0.5093513433881616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 269}], {
             RGBColor[
             0.980420530285405, 0.9551564158081671, 0.6020762664235486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 277}], {
             RGBColor[
             0.9903436750031767, 0.9883158760637997, 0.6672952315344995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 282}], {
             RGBColor[
             0.7141541547436409, 0.7726234711925095, 0.9015995382329896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 293}], {
             RGBColor[
             0.9437174645743351, 0.8134407929799102, 0.5459850021177625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 98}], {
             RGBColor[
             0.18977923539730202`, 0.3168003874740297, 0.9341190187514328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 126}], {
             RGBColor[
             0.2119973945219809, 0.3401530814267192, 0.9353843100447624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 153}], {
             RGBColor[
             0.21078779737820008`, 0.338881718135717, 0.9353154252768627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 157}], {
             RGBColor[
             0.19152225944429985`, 0.31863241626153205`, 0.9342182813923363]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 171}], {
             RGBColor[
             0.189827260881899, 0.31685086530333273`, 0.9341217537317332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 184}], {
             RGBColor[
             0.1959981041281816, 0.3233368128092353, 0.9344731741256647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 222}], {
             RGBColor[
             0.210965999406103, 0.33906901976570414`, 0.9353255736187255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 248}], {
             RGBColor[
             0.21123257741316134`, 0.3393492101531443, 0.9353407548418606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 275}], {
             RGBColor[
             0.19034059746125545`, 0.31739041459565537`, 0.9341509874905143]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 285}], {
             RGBColor[
             0.20009304762604624`, 0.3276408580599046, 0.934706375099942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 38}], {
             RGBColor[
             0.18490621443215238`, 0.31167853347228314`, 0.9338415074164561]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 52}], {
             RGBColor[
             0.1912130018306219, 0.3183073669014913, 0.934200669628743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 53}], {
             RGBColor[
             0.1997851700209307, 0.32731725917636056`, 0.9346888419257947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 57}], {
             RGBColor[
             0.18168430472921848`, 0.3082921020936258, 0.9336580244252622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 84}], {
             RGBColor[
             0.1855804331499768, 0.3123871800926523, 0.9338799031750189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 124}], {
             RGBColor[
             0.1848087064384265, 0.3115760463885134, 0.9338359544804635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 147}], {
             RGBColor[
             0.19854534996450335`, 0.32601412968792354`, 0.9346182360077306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 217}], {
             RGBColor[
             0.1918655955426979, 0.3189932842697143, 0.9342378338752199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 223}], {
             RGBColor[
             0.1825916590093845, 0.3092457889716643, 0.9337096969092074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 247}], {
             RGBColor[
             0.1907246807083084, 0.31779411044059236`, 0.9341728604632337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 270}], {
             RGBColor[
             0.19826604624820576`, 0.32572056377321634`, 0.9346023300742803]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 295}], {
             RGBColor[
             0.19030787854135572`, 0.3173560249363414, 0.9341491241964293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 102}], {
             RGBColor[
             0.19929440110633984`, 0.32680142993057915`, 0.9346608933621363]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 129}], {
             RGBColor[
             0.19774057513237292`, 0.32516826031368307`, 0.9345724052715985]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 165}], {
             RGBColor[
             0.2120938524489715, 0.3402544648237721, 0.9353898031810077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 175}], {
             RGBColor[
             0.19450102624862847`, 0.3217632890376051, 0.9343879177551523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 183}], {
             RGBColor[
             0.19956688605797046`, 0.32708782889128674`, 0.9346764109770263]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 224}], {
             RGBColor[
             0.20753059097457632`, 0.33545818768669444`, 0.9351299321907813]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 253}], {
             RGBColor[
             0.19912169776175326`, 0.3266199077653942, 0.9346510581621539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 262}], {
             RGBColor[
             0.25511664496274467`, 0.3854741475583434, 0.9378398875681493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 41}], {
             RGBColor[
             0.18496389091314852`, 0.31173915511071026`, 0.9338447920067241]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 55}], {
             RGBColor[
             0.19173502245287335`, 0.3188560436734967, 0.9342303979309199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 152}], {
             RGBColor[
             0.18192632080115292`, 0.3085464763299341, 0.9336718068825283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 208}], {
             RGBColor[
             0.1853248284213402, 0.31211852331657947`, 0.9338653468638564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 242}], {
             RGBColor[
             0.18110760662426995`, 0.30768595582055314`, 0.9336251823213337]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 250}], {
             RGBColor[
             0.18199349180428678`, 0.3086170773131154, 0.9336756321717861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 268}], {
             RGBColor[
             0.19319132437376368`, 0.32038670932722724`, 0.934313332170909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 41}], {
             RGBColor[
             0.20758147265742513`, 0.3355116675614536, 0.9351328298273469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 44}], {
             RGBColor[
             0.27139379762507876`, 0.4018915080789134, 0.9387921467246012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 55}], {
             RGBColor[
             0.21435260419714997`, 0.34262855612424004`, 0.9355184357515427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 61}], {
             RGBColor[
             0.25191376002181387`, 0.38210771241079083`, 0.937657488009007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 71}], {
             RGBColor[
             0.22494256325409756`, 0.3537592745352769, 0.9361215182533955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 108}], {
             RGBColor[
             0.23362687386015235`, 0.362887035599335, 0.936616076895124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 136}], {
             RGBColor[
             0.309591888135542, 0.4349767741872242, 0.9412260952746828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 152}], {
             RGBColor[
             0.20454390254542953`, 0.33231898878067745`, 0.9349598447031511]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 161}], {
             RGBColor[
             0.21411146518921928`, 0.3423751037378088, 0.9355047032417743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 177}], {
             RGBColor[
             0.2592700003340752, 0.38983958739155206`, 0.9380764150122078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 208}], {
             RGBColor[
             0.20794241016561682`, 0.3358910357673228, 0.9351533846844792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 252}], {
             RGBColor[
             0.23225528127463596`, 0.3614454048279645, 0.9365379667264683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 268}], {
             RGBColor[
             0.21580890611804032`, 0.3441592217779706, 0.9356013699915318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 279}], {
             RGBColor[
             0.23161750381713786`, 0.36077506028270767`, 0.936501646243771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 280}], {
             RGBColor[
             0.2442905970349878, 0.3740952847751871, 0.9372233601543662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 52}], {
             RGBColor[
             0.19242626978916738`, 0.3195825884515542, 0.934269763444113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 53}], {
             RGBColor[
             0.2009984379794762, 0.32859248072642344`, 0.9347579357411648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 57}], {
             RGBColor[
             0.18289757268776397`, 0.30956732364368866`, 0.9337271182406324]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 88}], {
             RGBColor[
             0.20448897001762012`, 0.33226125121102634`, 0.9349567163769577]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 124}], {
             RGBColor[
             0.186021974396972, 0.31285126793857626`, 0.9339050482958335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 147}], {
             RGBColor[
             0.1997586179230488, 0.3272893512379864, 0.9346873298231007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 247}], {
             RGBColor[
             0.19193794866685385`, 0.31906933199065524`, 0.9342419542786038]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 289}], {
             RGBColor[
             0.21478203632197956`, 0.34307991651500525`, 0.935542891275764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 64}], {
             RGBColor[
             0.2185143800083959, 0.3470028463736865, 0.9357554427271977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 69}], {
             RGBColor[
             0.20464654155210055`, 0.3324268688843776, 0.9349656898427401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 76}], {
             RGBColor[
             0.26432098730221126`, 0.39346839209165385`, 0.9384255780434674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 85}], {
             RGBColor[
             0.21693635514660192`, 0.345344242191386, 0.9356655765457971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 90}], {
             RGBColor[
             0.20870014958760652`, 0.3366874679432882, 0.9351965368235865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 118}], {
             RGBColor[
             0.19522260799965463`, 0.322521717208859, 0.9344290107683887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 126}], {
             RGBColor[
             0.21260629074350712`, 0.3407930699617935, 0.9354189857837971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 153}], {
             RGBColor[
             0.2113966935997263, 0.3395217066707913, 0.9353501010158973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 166}], {
             RGBColor[
             0.19390930592620187`, 0.3211413534614994, 0.9343542201581618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 195}], {
             RGBColor[
             0.1927241486561343, 0.3198956780273474, 0.9342867272049146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 234}], {
             RGBColor[
             0.19793969225016772`, 0.3253775450292399, 0.9345837446968894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 239}], {
             RGBColor[
             0.2196501555680895, 0.3481966184992542, 0.9358201234650929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 248}], {
             RGBColor[
             0.21184147363468755`, 0.3399891986882186, 0.9353754305808952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 263}], {
             RGBColor[
             0.2058067463664483, 0.333646317705491, 0.935031761790548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 285}], {
             RGBColor[
             0.20070194384757245`, 0.3282808465949789, 0.9347410508389766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 42}], {
             RGBColor[
             0.763419188891056, 0.5236029358473995, 0.5766518342873496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 66}], {
             RGBColor[
             0.5377876957046065, 0.6331026822689709, 0.9577491794160538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 81}], {
             RGBColor[
             0.7893492688527326, 0.6740607768287987, 0.5995695817860118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 86}], {
             RGBColor[
             0.6417053553097174, 0.7192862820416126, 0.9654274840700409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 94}], {
             RGBColor[
             0.7430612286953848, 0.7992043464221197, 0.9750250570405241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 97}], {
             RGBColor[
             0.5690459020341019, 0.6601769695084484, 0.9597409246828227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 120}], {
             RGBColor[
             0.4841619759818365, 0.5839129078583203, 0.9544325893141365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 130}], {
             RGBColor[
             0.8005184128051482, 0.7225949328330918, 0.608776500228449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 140}], {
             RGBColor[
             0.7532763216794478, 0.4456404138262269, 0.5669390131907837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 162}], {
             RGBColor[
             0.8402909601650888, 0.8739220660440041, 0.881352498558146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 169}], {
             RGBColor[
             0.6469863029423364, 0.7235735932337524, 0.9658432196124291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 178}], {
             RGBColor[
             0.4741224882012588, 0.573360769660643, 0.953860855337124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 182}], {
             RGBColor[
             0.47178862651241965`, 0.5709077330502953, 0.9537279453665835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 201}], {
             RGBColor[
             0.7672988678714465, 0.5534238485768511, 0.5803670192604423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 202}], {
             RGBColor[
             0.777902189496511, 0.6220822630055047, 0.5900178581775892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 55}], {
             RGBColor[
             0.19536579579315563`, 0.32267221665845913`, 0.9344371651014012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 108}], {
             RGBColor[
             0.21464006545615802`, 0.34293069613355404`, 0.9355348062449824]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 152}], {
             RGBColor[
             0.1855570941414352, 0.31236264931489655`, 0.9338785740530094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 208}], {
             RGBColor[
             0.1889556017616225, 0.3159346963015419, 0.9340721140343375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 219}], {
             RGBColor[
             0.18646440411145038`, 0.3133162896201571, 0.933930244013557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 242}], {
             RGBColor[
             0.18473837996455222`, 0.31150212880551553`, 0.933831949491815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.18562426514456906`, 0.3124332502980778, 0.9338823993422674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 252}], {
             RGBColor[
             0.21326847287064163`, 0.3414890653621836, 0.9354566960763266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 268}], {
             RGBColor[
             0.19682209771404596`, 0.32420288231218963`, 0.9345200993413902]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 80}], {
             RGBColor[
             0.9082065714342227, 0.6151149855425471, 0.2779093700047311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 81}], {
             RGBColor[
             0.8635348143848929, 0.4405098850237444, 0.2065613896917941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 82}], {
             RGBColor[
             0.7255221919430327, 0.49355450623719554`, 0.5731775024918879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 87}], {
             RGBColor[
             0.915376392222736, 0.6389023704076946, 0.3396146781641949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 130}], {
             RGBColor[
             0.8747039583373085, 0.4890440410280375, 0.21576830813423137`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 140}], {
             RGBColor[
             0.8274618672116081, 0.2120895220211726, 0.17393082109656596`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 145}], {
             RGBColor[
             0.8512542986237088, 0.5925834616705845, 0.5853100694048696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 162}], {
             RGBColor[
             0.914476505697249, 0.6403711742389498, 0.48834430646392846`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 167}], {
             RGBColor[
             0.8726433787924812, 0.48087452978022555`, 0.21411031746444492`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 181}], {
             RGBColor[
             0.9119493492321276, 0.6277402539008983, 0.29244935498531105`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 201}], {
             RGBColor[
             0.8414844134036068, 0.31987295677179683`, 0.18735882716622465`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 202}], {
             RGBColor[
             0.8520877350286713, 0.3885313712004504, 0.1970096660833716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 203}], {
             RGBColor[
             0.8873649131430477, 0.6213403105093347, 0.5874793203268023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 216}], {
             RGBColor[
             0.8520342261383788, 0.3882883998269512, 0.19696501695368862`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 237}], {
             RGBColor[
             0.8313396990003062, 0.24189623642583113`, 0.17764423719680783`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 269}], {
             RGBColor[
             0.9053848161613813, 0.6055965424276077, 0.2669473836135131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 293}], {
             RGBColor[
             0.8686817504503115, 0.4638809195993508, 0.210856119307727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 299}], {
             RGBColor[
             0.8281493166036277, 0.217373559290479, 0.1745891234107269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 66}], {
             RGBColor[
             0.3059641689064351, 0.4317438620573953, 0.9409982635304203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 78}], {
             RGBColor[
             0.20985899682898168`, 0.3379054898691324, 0.9352625314596219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 97}], {
             RGBColor[
             0.33722237523593046`, 0.45881814929687276`, 0.9429900087971892]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 99}], {
             RGBColor[
             0.21063039427602828`, 0.33871627749540134`, 0.9353064614030511]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 178}], {
             RGBColor[
             0.24229896140308743`, 0.37200194944906734`, 0.9371099394514903]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 182}], {
             RGBColor[
             0.23996509971424826`, 0.36954891283871966`, 0.9369770294809499]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 199}], {
             RGBColor[
             0.21199067610024028`, 0.34014601993949717`, 0.9353839274405833]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 215}], {
             RGBColor[
             0.22516415254335911`, 0.35399217892786317`, 0.9361341374356069]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 229}], {
             RGBColor[
             0.221649468641255, 0.3502980233029215, 0.935933981386891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 233}], {
             RGBColor[
             0.2154911007768475, 0.3438251882143545, 0.9355832714475019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 259}], {
             RGBColor[
             0.20537394232393572`, 0.33319141321544904`, 0.9350071142406031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 261}], {
             RGBColor[
             0.23516151692935008`, 0.3645000427670523, 0.9367034725476139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 284}], {
             RGBColor[
             0.23327215251581435`, 0.3625142009758035, 0.9365958760393271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 59}], {
             RGBColor[
             0.650613500039462, 0.7181916581041776, 0.9197475834219577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 61}], {
             RGBColor[
             0.29673927658547317`, 0.4285312134624696, 0.9402355342561197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 71}], {
             RGBColor[
             0.26976807981775686`, 0.40018277558695564`, 0.9386995645005083]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 108}], {
             RGBColor[
             0.27845239042381165`, 0.4093105366510138, 0.9391941231422369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 136}], {
             RGBColor[
             0.3544174046992013, 0.48140027523890294`, 0.9438041415217957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 177}], {
             RGBColor[
             0.3040955168977345, 0.4362630884432308, 0.9406544612593207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 194}], {
             RGBColor[
             0.5011124283287507, 0.6014735099165995, 0.9553542362124354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 204}], {
             RGBColor[
             0.39991382818369614`, 0.5199845367377941, 0.9469303798325985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 226}], {
             RGBColor[
             0.6512382253914439, 0.7184499980919314, 0.9093942676022314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 252}], {
             RGBColor[
             0.27708079783829526`, 0.4078689058796433, 0.9391160129735812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 268}], {
             RGBColor[
             0.2606344226816996, 0.39058272282964934`, 0.9381794162386446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 279}], {
             RGBColor[
             0.27644302038079716`, 0.4071985613343865, 0.9390796924908837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 280}], {
             RGBColor[
             0.2891161135986471, 0.42051878582686586`, 0.939801406401479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 283}], {
             RGBColor[
             0.3110200455084933, 0.44354120705361005`, 0.9410488029197814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 89}], {
             RGBColor[
             0.34033954683031736`, 0.4683920819989782, 0.9429369415722573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 94}], {
             RGBColor[
             0.5484117816822776, 0.636917841037437, 0.9603911500045271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 96}], {
             RGBColor[
             0.2504426073839444, 0.3805614377119254, 0.9375737080426556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 120}], {
             RGBColor[
             0.2895125289687292, 0.4216264024736376, 0.9397986822781397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 131}], {
             RGBColor[
             0.2646712879230951, 0.39551668310902466`, 0.9383840103499137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 132}], {
             RGBColor[
             0.24841553022607393`, 0.3784308510948885, 0.9374582689973068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 141}], {
             RGBColor[
             0.2968912603514489, 0.4293819169954668, 0.9402188901145307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 146}], {
             RGBColor[
             0.24998188699294738`, 0.3800771913696276, 0.937547470697963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 188}], {
             RGBColor[
             0.32789958178650086`, 0.45761720952884744`, 0.9421442779998944]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 236}], {
             RGBColor[
             0.26568284234196243`, 0.3965798909395088, 0.9384416168776075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 260}], {
             RGBColor[
             0.2790511539192304, 0.41063083400712647`, 0.9392029224452882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 281}], {
             RGBColor[
             0.6391981620742301, 0.7080190375817033, 0.9308676637061029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 294}], {
             RGBColor[
             0.4179920843483252, 0.5334044550653643, 0.9485055663485399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 60}], {
             RGBColor[
             0.2459880706675731, 0.3758794371890788, 0.9373200287665547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 62}], {
             RGBColor[
             0.20319287451419632`, 0.3308989726597267, 0.9348829056554392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 117}], {
             RGBColor[
             0.1951092767006187, 0.3224025988279529, 0.9344225567185672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 158}], {
             RGBColor[
             0.1988271914603046, 0.32631036296979365`, 0.9346342864639694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 196}], {
             RGBColor[
             0.2038842250820344, 0.33162562594068223`, 0.9349222770475161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 207}], {
             RGBColor[
             0.1949982416588687, 0.3222858939590454, 0.9344162334372013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 212}], {
             RGBColor[
             0.21903868251240277`, 0.34755392154809645`, 0.9357853009791648]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 214}], {
             RGBColor[
             0.20276955741382008`, 0.3304540395473769, 0.9348587983728143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 225}], {
             RGBColor[
             0.21615267984960895`, 0.3445205497663627, 0.935620947396977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 265}], {
             RGBColor[
             0.21371228475052867`, 0.3419555397872433, 0.9354819705063254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 276}], {
             RGBColor[
             0.22304128842203616`, 0.35176091413899346`, 0.9360132434643936]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.19252503662856937`, 0.3196863986619449, 0.9342753880695046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 112}], {
             RGBColor[
             0.18666547155784385`, 0.31352762425472913`, 0.9339416945071765]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 131}], {
             RGBColor[
             0.20675371716772, 0.33464164405904423`, 0.9350856903767627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 133}], {
             RGBColor[
             0.18469446291568115`, 0.3114559692026503, 0.9338294484808514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 146}], {
             RGBColor[
             0.19206431623757236`, 0.3192021523196471, 0.9342491507248121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 170}], {
             RGBColor[
             0.1908380369178425, 0.3179132550040116, 0.9341793159316711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 190}], {
             RGBColor[
             0.1942570496898653, 0.32150685420533776`, 0.9343740236510617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.18784627824446665`, 0.31476872694983776`, 0.9340089397011326]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 70}], {
             RGBColor[
             0.2012898575043234, 0.328898781124103, 0.9347745316519882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 71}], {
             RGBColor[
             0.2080633650262977, 0.3360181669948795, 0.9351602728848583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 73}], {
             RGBColor[
             0.187739347830093, 0.31465633630455114`, 0.9340028501722235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 100}], {
             RGBColor[
             0.18673636136840888`, 0.31360213394030656`, 0.9339457315770161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 119}], {
             RGBColor[
             0.1868307341329213, 0.31370132569938797`, 0.933951105966343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 122}], {
             RGBColor[
             0.1889251216320018, 0.3159026597527588, 0.9340703782360471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 138}], {
             RGBColor[
             0.21204884540564534`, 0.34020715956762493`, 0.9353872400964722]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 161}], {
             RGBColor[
             0.19723226696141938`, 0.3246339961974114, 0.9345434578732372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 244}], {
             RGBColor[
             0.19115682833937214`, 0.31824832500058275`, 0.9341974706315176]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 266}], {
             RGBColor[
             0.19547981769013628`, 0.32279206090159157`, 0.934443658479754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 54}], {
             RGBColor[
             0.22682934694082163`, 0.355742403819019, 0.936228967793108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 102}], {
             RGBColor[
             0.20090857647606358`, 0.32849803058878846`, 0.9347528182614836]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 143}], {
             RGBColor[
             0.2582581828615999, 0.38877610307504745`, 0.9380187935040003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 172}], {
             RGBColor[
             0.20010293929950806`, 0.3276512548358813, 0.9347069384161122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 174}], {
             RGBColor[
             0.22141328802375174`, 0.3500497824992095, 0.9359205312501221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 238}], {
             RGBColor[
             0.19853266531396374`, 0.3260007973159532, 0.9346175136356476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 298}], {
             RGBColor[
             0.23487979924778435`, 0.36420393962179404`, 0.9366874291424127]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 206}], {
             RGBColor[
             0.20212300857950383`, 0.32977447572894675`, 0.9348219783731833]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 219}], {
             RGBColor[
             0.1830787781409705, 0.30975778206409804`, 0.9337374376231229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 83}], {
             RGBColor[
             0.8289246632002845, 0.6056697988799424, 0.5870191249815166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 101}], {
             RGBColor[
             0.7293123816710212, 0.7884636426315792, 0.9736547004594159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 104}], {
             RGBColor[
             0.5731922784257398, 0.6585842020957557, 0.9621993062038972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 116}], {
             RGBColor[
             0.5493242790295518, 0.6359329023080253, 0.960750884061716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 142}], {
             RGBColor[
             0.8206161663608685, 0.5418070513656623, 0.579062899024987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 149}], {
             RGBColor[
             0.8534002738604769, 0.7354497327448786, 0.6081721446101185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 197}], {
             RGBColor[
             0.8988192263028636, 0.9205652040419037, 0.9289214218265444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 198}], {
             RGBColor[
             0.8879439008384149, 0.9128115493875727, 0.9633242059952494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 204}], {
             RGBColor[
             0.647452541380158, 0.7220822556308867, 0.967158350930859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 226}], {
             RGBColor[
             0.8987769385879059, 0.920547716985024, 0.9296222387004919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 243}], {
             RGBColor[
             0.8993571244293498, 0.920787638740557, 0.9200070578349391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 254}], {
             RGBColor[
             0.5650392887707011, 0.6515224922377361, 0.9616798049124837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 283}], {
             RGBColor[
             0.5585587587049552, 0.6456389259467026, 0.9612767740180419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 53}], {
             RGBColor[
             0.2073052253779457, 0.3352213141556316, 0.9351170979534518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 57}], {
             RGBColor[
             0.18920436008623348`, 0.3161961570728968, 0.9340862804529193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 84}], {
             RGBColor[
             0.1931004885069918, 0.32029123507192336`, 0.9343081592026761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 88}], {
             RGBColor[
             0.21079575741608964`, 0.3388900846402345, 0.9353158785892447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 93}], {
             RGBColor[
             0.21993156031517644`, 0.348492392730534, 0.9358361490491385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 124}], {
             RGBColor[
             0.1923287617954415, 0.3194801013677844, 0.9342642105081206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 137}], {
             RGBColor[
             0.23013360981142927`, 0.35921539359839394`, 0.9364171406753703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 147}], {
             RGBColor[
             0.20606540532151835`, 0.3339181846671946, 0.9350464920353876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 217}], {
             RGBColor[
             0.19938565089971289`, 0.32689733924898534`, 0.9346660899028769]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 247}], {
             RGBColor[
             0.1982447360653234, 0.3256981654198634, 0.9346011164908907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 270}], {
             RGBColor[
             0.20578610160522076`, 0.3336246187524874, 0.9350305861019373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 271}], {
             RGBColor[
             0.21068413741610115`, 0.3387727649431298, 0.9353095219953723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 273}], {
             RGBColor[
             0.2188316043007933, 0.34733626921817795`, 0.9357735081813584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 289}], {
             RGBColor[
             0.22108882372044908`, 0.3497087499442134, 0.9359020534880509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 295}], {
             RGBColor[
             0.19782793389837072`, 0.3252600799156124, 0.9345773802240863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 88}], {
             RGBColor[
             0.21936792560639845`, 0.34789997691510377`, 0.9358040508862964]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 93}], {
             RGBColor[
             0.22850372850548528`, 0.3575022850054033, 0.93632432134619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 107}], {
             RGBColor[
             0.3121763440598402, 0.43622685441542786`, 0.9414269663560839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 124}], {
             RGBColor[
             0.20090092998575032`, 0.32848999364265374`, 0.9347523828051723]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 137}], {
             RGBColor[
             0.2387057780017381, 0.36822528587326325`, 0.936905312972422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 147}], {
             RGBColor[
             0.21463757351182716`, 0.3429280769420639, 0.9355346643324394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 217}], {
             RGBColor[
             0.2079578190900217, 0.3359072315238546, 0.9351542621999286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 247}], {
             RGBColor[
             0.2068169042556322, 0.33470805769473266`, 0.9350892887879424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 251}], {
             RGBColor[
             0.25074234215186236`, 0.3808764779572891, 0.9375907774942707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 270}], {
             RGBColor[
             0.21435826979552958`, 0.3426345110273567, 0.935518758398989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 271}], {
             RGBColor[
             0.21925630560640996`, 0.3477826572179991, 0.935797694292424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 273}], {
             RGBColor[
             0.2274037724911021, 0.35634616149304726`, 0.9362616804784101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 289}], {
             RGBColor[
             0.22966099191075792`, 0.3587186422190827, 0.9363902257851027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 75}], {
             RGBColor[
             0.2884831291269512, 0.41830852004459096`, 0.9398219273882558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 102}], {
             RGBColor[
             0.218116116310074, 0.34658424597537324`, 0.9357327621987566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 111}], {
             RGBColor[
             0.4291203016109882, 0.5357529458181629, 0.9499902123364491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 143}], {
             RGBColor[
             0.2754657226956103, 0.40686231846163223`, 0.9389987374412732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 163}], {
             RGBColor[
             0.4325936369919836, 0.5385727559524309, 0.9502636460208878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 165}], {
             RGBColor[
             0.2309155676527057, 0.3600372808685661, 0.936461672017628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 172}], {
             RGBColor[
             0.21731047913351847`, 0.34573747022246615`, 0.935686882353385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 174}], {
             RGBColor[
             0.23862082785776215`, 0.3681359978857943, 0.936900475187395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 185}], {
             RGBColor[
             0.3867966632124244, 0.5013927095080272, 0.9466583404851183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 235}], {
             RGBColor[
             0.32626536687632174`, 0.4510335953926109, 0.9422293781681247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 238}], {
             RGBColor[
             0.21574020514797415`, 0.344087012702538, 0.9355974575729206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 298}], {
             RGBColor[
             0.25208733908179476`, 0.3822901550083788, 0.9376673730796856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 108}], {
             RGBColor[
             0.22141119699588285`, 0.35004758469634045`, 0.9359204121691784]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 114}], {
             RGBColor[
             0.22063449464495144`, 0.3492312212797382, 0.9358761801193209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 208}], {
             RGBColor[
             0.19572673330134732`, 0.32305158486432833`, 0.9344577199585336]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 219}], {
             RGBColor[
             0.19323553565117518`, 0.3204331781829436, 0.9343158499377529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 242}], {
             RGBColor[
             0.19150951150427703`, 0.318619017368302, 0.9342175554160109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 250}], {
             RGBColor[
             0.1923953966842939, 0.31955013886086425`, 0.9342680052664631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 252}], {
             RGBColor[
             0.22003960441036646`, 0.34860595392497, 0.9358423020005227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 268}], {
             RGBColor[
             0.20359322925377082`, 0.3313197708749761, 0.9349057052655861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 283}], {
             RGBColor[
             0.25397885208056453`, 0.38427825509893676`, 0.9377750919467229]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 57}], {
             RGBColor[
             0.18951617750640207`, 0.3165238969518603, 0.9341040379937053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 84}], {
             RGBColor[
             0.1934123059271604, 0.32061897495088687`, 0.9343259167434621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 110}], {
             RGBColor[
             0.1926369557700678, 0.31980403277574326`, 0.9342817616990433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 148}], {
             RGBColor[
             0.2228269723814797, 0.3515356543919468, 0.936001038482936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 191}], {
             RGBColor[
             0.21336670196225918`, 0.34159231036555776`, 0.9354622900777774]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 217}], {
             RGBColor[
             0.19969746831988144`, 0.32722507912794885`, 0.934683847443663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 223}], {
             RGBColor[
             0.19042353178656807`, 0.3174775838298989, 0.9341557104776503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 246}], {
             RGBColor[
             0.1919032518459413, 0.3190328634319706, 0.934239978345982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 247}], {
             RGBColor[
             0.19855655348549195`, 0.3260259052988269, 0.9346188740316768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 251}], {
             RGBColor[
             0.2424819913817221, 0.3721943255613833, 0.9371203627380049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 270}], {
             RGBColor[
             0.20609791902538932`, 0.3339523586314509, 0.9350483436427234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 271}], {
             RGBColor[
             0.21099595483626973`, 0.3391005048220933, 0.9353272795361584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 278}], {
             RGBColor[
             0.1999933373080916, 0.327536056193735, 0.9347006967448426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 295}], {
             RGBColor[
             0.19813975131853928`, 0.3255878197945759, 0.9345951377648724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.18357179140558838`, 0.31027597026405784`, 0.9337655139991952]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 217}], {
             RGBColor[
             0.18985695379830947`, 0.3168820744411198, 0.9341234446993961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 223}], {
             RGBColor[
             0.1805830172649961, 0.30713457914306985`, 0.9335953077333836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 247}], {
             RGBColor[
             0.18871603896391997`, 0.3156829006119979, 0.9340584712874099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 278}], {
             RGBColor[
             0.19015282278651957`, 0.31719305150690597`, 0.9341402940005757]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 295}], {
             RGBColor[
             0.1882992367969673, 0.3152448151077469, 0.9340347350206055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 134}], {
             RGBColor[
             0.21796998739019388`, 0.34643065521547056`, 0.9357244403729478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 160}], {
             RGBColor[
             0.19345266111115197`, 0.32066139080792844`, 0.9343282149114902]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 164}], {
             RGBColor[
             0.1865510290497441, 0.3134073379226422, 0.9339351771756428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 176}], {
             RGBColor[
             0.19266677740688082`, 0.31983537720683475`, 0.9342834599971428]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 180}], {
             RGBColor[
             0.1930127612329003, 0.32019902814462275`, 0.9343031632641974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 187}], {
             RGBColor[
             0.20794054512620663`, 0.3358890754926524, 0.9351532784732439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 215}], {
             RGBColor[
             0.20794131603506694`, 0.33588988576674306`, 0.935153322375363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 221}], {
             RGBColor[
             0.18866826221874242`, 0.3156326842235957, 0.9340557504724514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 230}], {
             RGBColor[
             0.19161321755920613`, 0.31872801900737613`, 0.9342234613224198]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[
             0.20819170713916685`, 0.33615306269286493`, 0.9351675817783212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 288}], {
             RGBColor[
             0.200003126765576, 0.32754634553423856`, 0.9347012542399642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 296}], {
             RGBColor[
             0.18917402722894824`, 0.3161642753166758, 0.9340845530415703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 297}], {
             RGBColor[
             0.19156703343003767`, 0.3186794765593771, 0.934220831204587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 72}], {
             RGBColor[
             0.9072115711061266, 0.6075869855350652, 0.536963277053603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 83}], {
             RGBColor[
             0.9157801358545465, 0.6734487289604354, 0.5451685443334997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 106}], {
             RGBColor[
             0.9234341463667425, 0.9403782883321993, 0.9424056010083017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 136}], {
             RGBColor[
             0.6888115905499252, 0.7512769242124885, 0.9221815319720392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 155}], {
             RGBColor[
             0.9556607617329471, 0.8668171290315656, 0.5788467809151635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[
             0.8355066141794747, 0.8713501588901851, 0.9337316266626792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 197}], {
             RGBColor[
             0.9856746989571257, 0.9883441341223966, 0.8870708411785275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 198}], {
             RGBColor[
             0.974799373492677, 0.9805904794680657, 0.9214736253472325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 210}], {
             RGBColor[
             0.7283433684413259, 0.785018817714684, 0.9248382115325371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 226}], {
             RGBColor[
             0.9856324112421679, 0.988326647065517, 0.887771658052475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 227}], {
             RGBColor[
             0.9688560866723765, 0.9191321953350291, 0.5894640490955131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 241}], {
             RGBColor[
             0.9855659463819599, 0.9882991621377519, 0.8888731527916648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 290}], {
             RGBColor[
             0.9657093115675036, 0.9066562806448499, 0.5869320799818273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 291}], {
             RGBColor[
             0.955941254786202, 0.9662985742039245, 0.945506158028788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 77}], {
             RGBColor[
             0.3505250523811867, 0.47604307306451876`, 0.9436288356859599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 95}], {
             RGBColor[
             0.28741190007160666`, 0.4194185083151971, 0.9396790545700505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 103}], {
             RGBColor[
             0.35429852491084235`, 0.47931146530946245`, 0.9438692780187988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 127}], {
             RGBColor[
             0.3180513290021859, 0.44791596605042294`, 0.941559638747636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 145}], {
             RGBColor[
             0.5760856373176906, 0.6571907606456139, 0.9633236613969889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 148}], {
             RGBColor[
             0.2667823322730826, 0.39773552456880407`, 0.9385042312026353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 159}], {
             RGBColor[
             0.28925410608148494`, 0.42135478363418655`, 0.9397839654770135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 168}], {
             RGBColor[
             0.3438394161380286, 0.4702523109805432, 0.9432028328564219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 196}], {
             RGBColor[
             0.24516356622564123`, 0.3750128307440074, 0.9372730744583317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 205}], {
             RGBColor[
             0.3298135622578278, 0.45810382130942706`, 0.9423091178497511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 212}], {
             RGBColor[
             0.2603180236560096, 0.39094112635142153`, 0.9381360983899805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 225}], {
             RGBColor[
             0.25743202099321577`, 0.38790775456968785`, 0.9379717448077927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 265}], {
             RGBColor[
             0.2549916258941355, 0.3853427445905684, 0.9378327679171411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 276}], {
             RGBColor[
             0.26432062956564295`, 0.39514811894231855`, 0.9383640408752093]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 282}], {
             RGBColor[
             0.36394977931359895`, 0.4876708967869795, 0.9444842474150733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 71}], {
             RGBColor[
             0.25028804221449197`, 0.3803989799188331, 0.9375649057849139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 108}], {
             RGBColor[
             0.25897235282054676`, 0.38952674098289125`, 0.9380594644266425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 136}], {
             RGBColor[
             0.33493736709593636`, 0.46161647957078045`, 0.9426694828062012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 161}], {
             RGBColor[
             0.23945694414961366`, 0.369014809121365, 0.9369480907732928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 177}], {
             RGBColor[
             0.2846154792944696, 0.4164792927751083, 0.9395198025437264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 194}], {
             RGBColor[
             0.4816323907254858, 0.581689714248477, 0.9542195774968412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 252}], {
             RGBColor[
             0.2576007602350303, 0.3880851102115208, 0.9379813542579867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 268}], {
             RGBColor[
             0.24115438507843467`, 0.37079892716152685`, 0.9370447575230503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 279}], {
             RGBColor[
             0.25696298277753227`, 0.387414765666264, 0.9379450337752894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 280}], {
             RGBColor[
             0.2696360759953822, 0.40073499015874336`, 0.9386667476858847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 117}], {
             RGBColor[
             0.1935934216908487, 0.32080933910192594`, 0.9343362310182673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 135}], {
             RGBColor[
             0.20737676424851148`, 0.33529650604442257`, 0.9351211719862982]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 158}], {
             RGBColor[
             0.1973113364505346, 0.3247171032437667, 0.9345479607636695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 186}], {
             RGBColor[
             0.19739650616034748`, 0.3248066220088515, 0.934552811052646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 196}], {
             RGBColor[
             0.2023683700722644, 0.33003236621465526`, 0.9348359513472162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 207}], {
             RGBColor[
             0.19348238664909873`, 0.3206926342330184, 0.9343299077369014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 212}], {
             RGBColor[
             0.2175228275026328, 0.34596066182206947`, 0.9356989752788649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 214}], {
             RGBColor[
             0.20125370240405008`, 0.3288607798213499, 0.9347724726725144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 225}], {
             RGBColor[
             0.21463682483983898`, 0.34292729004033573`, 0.9355346216966771]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 265}], {
             RGBColor[
             0.2121964297407587, 0.3403622800612163, 0.9353956448060256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 276}], {
             RGBColor[
             0.22152543341226616`, 0.3501676544129665, 0.9359269177640938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 286}], {
             RGBColor[
             0.21128388043674812`, 0.3394031328837336, 0.935343676473158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 71}], {
             RGBColor[
             0.20309975866494467`, 0.3308011019982774, 0.9348776028455769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 73}], {
             RGBColor[
             0.18277574146873998`, 0.309439271307949, 0.933720180132942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 152}], {
             RGBColor[
             0.18270109795627662`, 0.30936081624367795`, 0.9337159292953324]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 161}], {
             RGBColor[
             0.19226866060006637`, 0.3194169312008093, 0.9342607878339557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 208}], {
             RGBColor[
             0.1860996055764639, 0.3129328632303233, 0.9339094692766605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 244}], {
             RGBColor[
             0.18619322197801913`, 0.31303126000398057`, 0.9339148005922362]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 69}], {
             RGBColor[
             0.22143670136219934`, 0.3500743914024093, 0.9359218646051097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 76}], {
             RGBColor[
             0.28111114711231006`, 0.41111591460968555`, 0.939381752805837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 85}], {
             RGBColor[
             0.2337265149567007, 0.3629917647094177, 0.9366217513081667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 90}], {
             RGBColor[
             0.22549030939770529`, 0.3543349904613199, 0.936152711585956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 118}], {
             RGBColor[
             0.2120127678097534, 0.3401692397268907, 0.9353851855307582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 121}], {
             RGBColor[
             0.2303769927354159, 0.3594712044828725, 0.9364310009728385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 173}], {
             RGBColor[
             0.21829574180286104`, 0.34677304375720647`, 0.9357429916048386]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 213}], {
             RGBColor[
             0.21883980227157213`, 0.34734488580524786`, 0.9357739750436664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 234}], {
             RGBColor[
             0.2147298520602665, 0.3430250675472716, 0.9355399194592591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 239}], {
             RGBColor[
             0.23644031537818827`, 0.3658441410172859, 0.9367762982274624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 249}], {
             RGBColor[
             0.22138061658703678`, 0.35001544274773333`, 0.9359186706601341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 258}], {
             RGBColor[
             0.28773302970917036`, 0.41685145648958927`, 0.939803693309408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 263}], {
             RGBColor[
             0.22259690617654707`, 0.3512938402235227, 0.9359879365529176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 286}], {
             RGBColor[
             0.22809764059378232`, 0.35707546086274283`, 0.9363011952403719]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 70}], {
             RGBColor[
             0.2936166091660087, 0.41958665894484415`, 0.940265032379005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 106}], {
             RGBColor[
             0.6196619973862446, 0.6970249085872788, 0.9659794196694249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 115}], {
             RGBColor[
             0.3645960621661024, 0.4902165167425332, 0.9444527165749532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 138}], {
             RGBColor[
             0.30437559706733064`, 0.4308950373883661, 0.9408777408234891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 155}], {
             RGBColor[
             0.6518886127524492, 0.6234637492866453, 0.6024205995762867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 194}], {
             RGBColor[
             0.5317344651989768, 0.6279967791452647, 0.9573054453238024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 200}], {
             RGBColor[
             0.37151685139917806`, 0.49621095652724223`, 0.9448937031450712]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[
             0.424571219460828, 0.5416654379697635, 0.9484120301936603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 211}], {
             RGBColor[
             0.3240980577045407, 0.45162459399430244`, 0.9420009057800123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 231}], {
             RGBColor[
             0.30432205873480145`, 0.4308387652063516, 0.9408746918946544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 241}], {
             RGBColor[
             0.6817937974014621, 0.7449457823928316, 0.912446971452788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 264}], {
             RGBColor[
             0.33683666992223255`, 0.4650136831097602, 0.942726350900722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 291}], {
             RGBColor[
             0.6521691058057041, 0.7229451944590042, 0.9690799766899112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 86}], {
             RGBColor[
             0.49025940765542825`, 0.5952351366581299, 0.9535166371045274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 97}], {
             RGBColor[
             0.4175999543798127, 0.5361258241249656, 0.9478300777173092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 162}], {
             RGBColor[
             0.6888450125107997, 0.7498709206605213, 0.8694416515926326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 169}], {
             RGBColor[
             0.4955403552880472, 0.5995224478502696, 0.9539323726469158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 187}], {
             RGBColor[
             0.305540960778381, 0.4312990434818653, 0.9409741624536079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 193}], {
             RGBColor[
             0.33295274750258996`, 0.46011056933666983`, 0.9425352231554471]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 215}], {
             RGBColor[
             0.3055417316872413, 0.4312998537559559, 0.940974206355727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 228}], {
             RGBColor[
             0.40629940527691566`, 0.5263378564741489, 0.9471100167211559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 118}], {
             RGBColor[
             0.18382399790050605`, 0.31054105528103165`, 0.9337798767859746]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 166}], {
             RGBColor[
             0.1825106958270533, 0.309160691533672, 0.9337050861757479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 173}], {
             RGBColor[
             0.1901069718936137, 0.3171448593113474, 0.934137682860055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 195}], {
             RGBColor[
             0.18132553855698572`, 0.30791501609952, 0.9336375932225005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 213}], {
             RGBColor[
             0.19065103236232478`, 0.3177167013593888, 0.9341686662988828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 234}], {
             RGBColor[
             0.18654108215101917`, 0.31339688310141245`, 0.9339346107144755]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 263}], {
             RGBColor[
             0.19440813626729972`, 0.3216656557776636, 0.934382627808134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 75}], {
             RGBColor[
             0.6048929892039929, 0.6837170469414527, 0.9652757515328931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 83}], {
             RGBColor[
             0.8617045963739112, 0.6317374119212176, 0.5901643374072268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 109}], {
             RGBColor[
             0.9348338843673183, 0.947970458954174, 0.8784588716115629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 111}], {
             RGBColor[
             0.7455301616880299, 0.8011614727150247, 0.9754440364810864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 143}], {
             RGBColor[
             0.5918755827726521, 0.672270845358494, 0.9644525615859105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 163}], {
             RGBColor[
             0.7490034970690254, 0.8039812828492927, 0.9757174701655251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 185}], {
             RGBColor[
             0.7032065232894661, 0.766801236404889, 0.9721121646297556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 218}], {
             RGBColor[
             0.9220230883129681, 0.9398481441591451, 0.964270119789284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 235}], {
             RGBColor[
             0.6426752269533634, 0.7164421222894727, 0.967683202312762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 292}], {
             RGBColor[
             0.8252860920096456, 0.8638987146846454, 0.9830984780135097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 76}], {
             RGBColor[
             0.2672433086560147, 0.39653993712037666`, 0.9385919999213795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 85}], {
             RGBColor[
             0.21985867650040533`, 0.3484157872201088, 0.9358319984237091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 90}], {
             RGBColor[
             0.21162247094140993`, 0.33975901297201105`, 0.9353629587014987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 118}], {
             RGBColor[
             0.19814492935345804`, 0.3255932622375819, 0.9345954326463008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 121}], {
             RGBColor[
             0.21650915427912054`, 0.3448952269935637, 0.9356412480883811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 126}], {
             RGBColor[
             0.21552861209731056`, 0.34386461499051624`, 0.9355854076617092]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 166}], {
             RGBColor[
             0.19683162728000528`, 0.3242128984902222, 0.9345206420360739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 173}], {
             RGBColor[
             0.2044279033465657, 0.3321970662678976, 0.9349532387203812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 195}], {
             RGBColor[
             0.1956464700099377, 0.32296722305607023`, 0.9344531490828267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 213}], {
             RGBColor[
             0.20497196381527677`, 0.33276890831593897`, 0.934984222159209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 234}], {
             RGBColor[
             0.20086201360397116`, 0.32844909005796263`, 0.9347501665748015]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 239}], {
             RGBColor[
             0.22257247692189291`, 0.35126816352797696`, 0.935986545343005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 249}], {
             RGBColor[
             0.20751277813074143`, 0.3354394652584245, 0.9351289177756767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 258}], {
             RGBColor[
             0.273865191252875, 0.4022754790002804, 0.9390139404249507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 263}], {
             RGBColor[
             0.2087290677202517, 0.3367178627342138, 0.9351981836684602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 285}], {
             RGBColor[
             0.2036242652013759, 0.3313523916237017, 0.9349074727168887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 122}], {
             RGBColor[
             0.19740509453050553`, 0.32481564893042175`, 0.9345533001476212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 138}], {
             RGBColor[
             0.22052881830414905`, 0.3491201487452879, 0.9358701620080464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 211}], {
             RGBColor[
             0.24025127894135917`, 0.3698497053512242, 0.9369933269645696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 231}], {
             RGBColor[
             0.2204752799716199, 0.3490638765632734, 0.9358671130792118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 266}], {
             RGBColor[
             0.20395979058864, 0.33170505007925455`, 0.934926580391328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 108}], {
             RGBColor[
             0.23200115605283045`, 0.3611783031073773, 0.936523494671031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 136}], {
             RGBColor[
             0.3079661703282201, 0.43326804169526645`, 0.9411335130505898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 161}], {
             RGBColor[
             0.2124857473818974, 0.34066637124585103`, 0.9354121210176813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 177}], {
             RGBColor[
             0.2576442825267533, 0.3881308548995943, 0.9379838327881149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 208}], {
             RGBColor[
             0.20631669235829492`, 0.33418230327536513`, 0.9350608024603861]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 244}], {
             RGBColor[
             0.20641030875985014`, 0.33428070004902233`, 0.9350661337759618]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 252}], {
             RGBColor[
             0.23062956346731406`, 0.3597366723360068, 0.9364453845023752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 268}], {
             RGBColor[
             0.21418318831071842`, 0.34245048928601285`, 0.9355087877674388]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 279}], {
             RGBColor[
             0.22999178600981598`, 0.35906632779075, 0.9364090640196779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 280}], {
             RGBColor[
             0.2426648792276659, 0.37238655228322937`, 0.9371307779302732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 83}], {
             RGBColor[
             0.8379840210704871, 0.29296740741773747`, 0.18400684751490148`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 87}], {
             RGBColor[
             0.9112817531721615, 0.6074291803827055, 0.3356936471851313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 106}], {
             RGBColor[
             0.845638031582683, 0.5598969667895013, 0.5812439041897035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 109}], {
             RGBColor[
             0.9111133090638942, 0.6092004544506938, 0.4723013817192375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 155}], {
             RGBColor[
             0.8778646469488878, 0.4863358074888676, 0.21768508409656526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 194}], {
             RGBColor[
             0.7577104993954153, 0.4908688373474871, 0.5725699298440808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 210}], {
             RGBColor[
             0.6505472536572664, 0.40453749617198587`, 0.5636765147139389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 218}], {
             RGBColor[
             0.898302513009544, 0.6010781396556649, 0.5581126298969585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 226}], {
             RGBColor[
             0.9078362964581086, 0.6078453255228189, 0.5266099612338768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 227}], {
             RGBColor[
             0.8910599718883171, 0.5386508737923311, 0.22830235227691478`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 241}], {
             RGBColor[
             0.9077698315979006, 0.607817840595054, 0.5277114559730665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 290}], {
             RGBColor[
             0.8879131967834442, 0.526174959102152, 0.22577038316322898`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 291}], {
             RGBColor[
             0.8781451400021425, 0.5858172526612265, 0.5843444612101898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 100}], {
             RGBColor[
             0.1816658245926822, 0.30827267829841776`, 0.9336569720088254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 119}], {
             RGBColor[
             0.18176019735719462`, 0.3083718700574992, 0.9336623463981524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 122}], {
             RGBColor[
             0.18385458485627515`, 0.31057320411086997`, 0.9337816186678564]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 161}], {
             RGBColor[
             0.19216173018569271`, 0.31930454055552265`, 0.9342546983050465]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 244}], {
             RGBColor[
             0.18608629156364545`, 0.31291886935869395`, 0.9339087110633268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 123}], {
             RGBColor[
             0.20225228122772315`, 0.32991034947858455`, 0.9348293402592576]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 189}], {
             RGBColor[
             0.21086862151855923`, 0.33896666943178094`, 0.9353200280920875]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 257}], {
             RGBColor[
             0.19498858899920085`, 0.3222757484017205, 0.9344156837325129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 260}], {
             RGBColor[
             0.23203447362151203`, 0.3612133219845175, 0.9365253920572785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 267}], {
             RGBColor[
             0.2010537316252639, 0.328650597853966, 0.9347610846324927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 287}], {
             RGBColor[
             0.2244511741859948, 0.35324279346883447`, 0.936093534372912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 300}], {
             RGBColor[
             0.2157736566163444, 0.3441221723167407, 0.9355993625845572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 111}], {
             RGBColor[
             0.4735665439631073, 0.5802328466571501, 0.952603227994324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 143}], {
             RGBColor[
             0.31991196504772945`, 0.4513422193006194, 0.941611753099148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.47703987934410275`, 0.583052656791418, 0.9528766616787626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 165}], {
             RGBColor[
             0.27536181000482485`, 0.4045171817075533, 0.9390746876755028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 185}], {
             RGBColor[
             0.43124290556454353`, 0.5458726103470143, 0.9492713561429931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 235}], {
             RGBColor[
             0.3707116092284409, 0.495513496231598, 0.9448423938259995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 262}], {
             RGBColor[
             0.318384602518598, 0.4497368644421247, 0.9415247720626443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 292}], {
             RGBColor[
             0.5533224742847231, 0.6429700886267707, 0.9602576695267473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 85}], {
             RGBColor[
             0.2795331222505161, 0.40945731042738504`, 0.9392918866244364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 87}], {
             RGBColor[
             0.6600329022141906, 0.7226670785503484, 0.7188188011286823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 90}], {
             RGBColor[
             0.2712969166915207, 0.40080053617928724`, 0.938822846902226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 126}], {
             RGBColor[
             0.2752030578474213, 0.40490613819779253`, 0.9390452958624365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 151}], {
             RGBColor[
             0.46237290629163863`, 0.5709821178298984, 0.9517671246297987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 153}], {
             RGBColor[
             0.27399346070364045`, 0.40363477490679034`, 0.9389764110945367]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 192}], {
             RGBColor[
             0.32876752436481727`, 0.45918363809373036`, 0.9421697538281874]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 220}], {
             RGBColor[
             0.3300035970754238, 0.4602542621488369, 0.942248515288291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 239}], {
             RGBColor[
             0.28224692267200363`, 0.41230968673525326`, 0.9394464335437323]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 248}], {
             RGBColor[
             0.2744382407386017, 0.40410226692421763`, 0.9390017406595347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 258}], {
             RGBColor[
             0.3335396370029857, 0.4633170022075566, 0.942473828625678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 82}], {
             RGBColor[
             0.5136111712070213, 0.6149382362843397, 0.9551491039925967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 95}], {
             RGBColor[
             0.3506695406416134, 0.476194939387312, 0.94363706407864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 103}], {
             RGBColor[
             0.41755616548084906`, 0.5360878963815774, 0.9478272875273883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 127}], {
             RGBColor[
             0.3813089695721926, 0.5046923971225378, 0.9455176482562255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 145}], {
             RGBColor[
             0.6393432778876973, 0.7139671917177287, 0.9672816709055783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 154}], {
             RGBColor[
             0.455540153481848, 0.5677935680255081, 0.950577540756124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 159}], {
             RGBColor[
             0.3525117466514917, 0.4781312147063014, 0.9437419749856031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 167}], {
             RGBColor[
             0.6607323580564698, 0.6022582598273698, 0.5960819189651536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 168}], {
             RGBColor[
             0.4070970567080353, 0.527028742052658, 0.9471608423650113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 203}], {
             RGBColor[
             0.6754538924070363, 0.7427240405564789, 0.9694509218275109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 205}], {
             RGBColor[
             0.3930712028278346, 0.5148802523815419, 0.9462671273583405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 212}], {
             RGBColor[
             0.32357566422601636`, 0.4477175574235364, 0.9420941078985701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 225}], {
             RGBColor[
             0.32068966156322254`, 0.4446841856418027, 0.9419297543163823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 255}], {
             RGBColor[
             0.38990028243638014`, 0.512133760513557, 0.9460650791149319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 265}], {
             RGBColor[
             0.31824926646414226`, 0.4421191756626833, 0.9417907774257306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 269}], {
             RGBColor[
             0.6934737954253698, 0.7269802724747518, 0.6489189851142219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 276}], {
             RGBColor[
             0.3275782701356497, 0.45192455001443343`, 0.9423220503837988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 282}], {
             RGBColor[
             0.42720741988360567`, 0.5444473278590943, 0.9484422569236628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 293}], {
             RGBColor[
             0.6567707297143, 0.585264649646495, 0.5928277208084357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 99}], {
             RGBColor[
             0.19490280134245708`, 0.32218558013523124`, 0.9344107982523728]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 131}], {
             RGBColor[
             0.21176961520445978`, 0.33991367092196156`, 0.9353713383495988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 170}], {
             RGBColor[
             0.19585393495458225`, 0.32318528186692885`, 0.9344649639045073]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 178}], {
             RGBColor[
             0.2265713684695162, 0.3554712520888972, 0.9362142763008121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 182}], {
             RGBColor[
             0.22423750678067705`, 0.3530182154785495, 0.9360813663302717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 190}], {
             RGBColor[
             0.19927294772660503`, 0.32677888106825503`, 0.9346596716238978]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.19626308316666907`, 0.323615322579327, 0.9344882642899051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 209}], {
             RGBColor[
             0.18729352981200414`, 0.31418775330104487`, 0.933977461495622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 229}], {
             RGBColor[
             0.20592187570768378`, 0.3337673259427514, 0.9350383182362128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 261}], {
             RGBColor[
             0.21943392399577888`, 0.3479693454068822, 0.9358078093969358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 284}], {
             RGBColor[
             0.2175445595822431, 0.34598350361563335`, 0.935700212888649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 144}], {
             RGBColor[
             0.1903903758627761, 0.31744273485178653`, 0.9341538222968402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 160}], {
             RGBColor[
             0.1894526235362595, 0.316457097699686, 0.9341004186891254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 176}], {
             RGBColor[
             0.18866673983198834`, 0.31563108409859225`, 0.9340556637747779]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 221}], {
             RGBColor[
             0.18466822464384994`, 0.3114283911153532, 0.9338279542500865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 232}], {
             RGBColor[
             0.1855242988552152, 0.31232817938973806`, 0.9338767064099756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 240}], {
             RGBColor[
             0.18183565807480434`, 0.3084511840561929, 0.9336666437743861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 245}], {
             RGBColor[
             0.20419166956427437`, 0.3319487695846225, 0.9349397855559562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 288}], {
             RGBColor[
             0.19600308919068352`, 0.3233420524259961, 0.9344734580175993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 297}], {
             RGBColor[
             0.1875669958551452, 0.3144751834511347, 0.9339930349822221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 92}], {
             RGBColor[
             0.9051815489493698, 0.591863337150663, 0.2750126050569618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 125}], {
             RGBColor[
             0.9070014402205765, 0.6058518189425977, 0.2767553349935425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 128}], {
             RGBColor[
             0.9118743315068152, 0.6433069966832056, 0.2814216211923882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 145}], {
             RGBColor[
             0.9218561356347152, 0.9176464031707863, 0.6795757972164687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 149}], {
             RGBColor[
             0.9371561077922606, 0.7792834728078644, 0.30334662593416606`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 150}], {
             RGBColor[
             0.9431089113179686, 0.8053970694161215, 0.30826637148751795`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 156}], {
             RGBColor[
             0.6866499660786538, 0.7281441949934098, 0.6592663633827371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 167}], {
             RGBColor[
             0.9432452158034876, 0.8059374712804274, 0.30837604527604406`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 179}], {
             RGBColor[
             0.7507825863487789, 0.7818072220217351, 0.663873785850424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 201}], {
             RGBColor[
             0.9120862504146132, 0.6449358982719986, 0.2816245549778238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 205}], {
             RGBColor[
             0.6755840605748524, 0.7185594638345996, 0.6585612536692309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 237}], {
             RGBColor[
             0.9019415360113127, 0.566959177926033, 0.27190996500840703`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 256}], {
             RGBColor[
             0.898368256371338, 0.5394933847920658, 0.2684881883897252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 269}], {
             RGBColor[
             0.9759866531723878, 0.9306594839278095, 0.36121311142511225`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 277}], {
             RGBColor[
             0.9859097978901593, 0.963818944183442, 0.4264320765360633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 281}], {
             RGBColor[
             0.9786349916305042, 0.9618175926615335, 0.6467591064594813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 282}], {
             RGBColor[
             0.7097202776306235, 0.7481265393121519, 0.6607363832345532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 293}], {
             RGBColor[
             0.9392835874613179, 0.7889438610995526, 0.30512184711932616`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 86}], {
             RGBColor[
             0.7418209808035544, 0.6361932312179576, 0.5953370394744854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 94}], {
             RGBColor[
             0.8431768541892217, 0.7161112955984645, 0.6049346124449686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 97}], {
             RGBColor[
             0.6691615275279388, 0.5770839186847934, 0.5896504800872672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.9006340382989853, 0.6395018820094367, 0.23868605563289352`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 140}], {
             RGBColor[
             0.8533919471732848, 0.3625473630025718, 0.19684856859522815`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 162}], {
             RGBColor[
             0.9404065856589258, 0.790829015220349, 0.5112620539625906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 167}], {
             RGBColor[
             0.8985734587541578, 0.6313323707616247, 0.23702806496310708`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 181}], {
             RGBColor[
             0.9378794291938042, 0.7781980948822975, 0.31536710248397326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 201}], {
             RGBColor[
             0.8674144933652834, 0.47033079775319603`, 0.2102765746648868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 202}], {
             RGBColor[
             0.8780178149903479, 0.5389892121818496, 0.21992741358203377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 203}], {
             RGBColor[
             0.9132949931047244, 0.7717981514907339, 0.6103970678254644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 216}], {
             RGBColor[
             0.8779643061000555, 0.5387462408083503, 0.21988276445235083`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 237}], {
             RGBColor[
             0.857269778961983, 0.39235407740723033`, 0.20056198469547004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 269}], {
             RGBColor[
             0.931314896123058, 0.7560543834090069, 0.28986513111217527`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 293}], {
             RGBColor[
             0.8946118304119881, 0.61433876058075, 0.23377386680638917`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 299}], {
             RGBColor[
             0.8540793965653044, 0.3678314002718782, 0.19750687090938907`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 103}], {
             RGBColor[
             0.5173846437366769, 0.6182066285292835, 0.9553895463254356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 140}], {
             RGBColor[
             0.7153793247314246, 0.41559198421602295`, 0.5634646813953219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 145}], {
             RGBColor[
             0.7391717561435251, 0.7960859238654349, 0.9748439297036255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 154}], {
             RGBColor[
             0.5553686317376758, 0.6499123001732142, 0.9581397995541713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 167}], {
             RGBColor[
             0.7605608363122977, 0.684376991975076, 0.6036441777632009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 168}], {
             RGBColor[
             0.5069255349638632, 0.6091474742003642, 0.9547231011630586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 181}], {
             RGBColor[
             0.7998668067519439, 0.8312427160957487, 0.681983215284067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 201}], {
             RGBColor[
             0.7294018709234232, 0.5233754189666472, 0.5768926874649807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 203}], {
             RGBColor[
             0.7752823706628642, 0.824842772704185, 0.9770131806255582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 216}], {
             RGBColor[
             0.7399516836581952, 0.5917908620218015, 0.5864988772524447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 255}], {
             RGBColor[
             0.489728760692208, 0.5942524926612631, 0.9536273379129792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 258}], {
             RGBColor[
             0.47680058453134755`, 0.5830547562597531, 0.9528035659599465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 293}], {
             RGBColor[
             0.7565992079701278, 0.6673833817942012, 0.600389979606483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 101}], {
             RGBColor[
             0.7469403042896439, 0.5416229945947444, 0.5788476902726976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 142}], {
             RGBColor[
             0.8382440889794911, 0.2949664033288275, 0.18425588883826852`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 149}], {
             RGBColor[
             0.8710281964790996, 0.48860908470804376`, 0.21336513442340005`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 194}], {
             RGBColor[
             0.7662790641438353, 0.5567305807728573, 0.5807751971239775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[
             0.9164471489214862, 0.6737245560050689, 0.534114411639826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 198}], {
             RGBColor[
             0.9055718234570376, 0.665970901350738, 0.5685171958085309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 226}], {
             RGBColor[
             0.9164048612065285, 0.6737070689481892, 0.5348152285137735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 241}], {
             RGBColor[
             0.9163383963463205, 0.6736795840204242, 0.5359167232529631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 243}], {
             RGBColor[
             0.9169850470479723, 0.6739469907037223, 0.5252000476482207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 290}], {
             RGBColor[
             0.8964817615318641, 0.5920367025275223, 0.23397565044312565`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 291}], {
             RGBColor[
             0.8867137047505624, 0.6516789960865967, 0.5925497284900865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 191}], {
             RGBColor[
             0.2074223158614455, 0.3353443836777553, 0.9351237660832672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 217}], {
             RGBColor[
             0.19375308221906778`, 0.32097715244014635`, 0.9343453234491528]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 223}], {
             RGBColor[
             0.1844791456857544, 0.31122965714209644`, 0.9338171864831403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 246}], {
             RGBColor[
             0.1859588657451276, 0.3127849367441682, 0.9339014543514719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 247}], {
             RGBColor[
             0.1926121673846783, 0.3197779786110244, 0.9342803500371666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 270}], {
             RGBColor[
             0.20015353292457566`, 0.32770443194364846`, 0.9347098196482133]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 271}], {
             RGBColor[
             0.20505156873545605`, 0.33285257813429087`, 0.9349887555416483]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 278}], {
             RGBColor[
             0.19404895120727791`, 0.32128812950593255`, 0.9343621727503324]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 295}], {
             RGBColor[
             0.19219536521772562`, 0.31933989310677346`, 0.9342566137703623]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[
             0.22879896787362192`, 0.35781260030057205`, 0.936341134791438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 135}], {
             RGBColor[
             0.22261249954375167`, 0.3513102298411313, 0.9359888245721116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 154}], {
             RGBColor[
             0.36472305205370464`, 0.48205039622074985`, 0.9450500607222323]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 173}], {
             RGBColor[
             0.21671771694106706`, 0.34511443957490595`, 0.9356531254234381]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 213}], {
             RGBColor[
             0.21726177740977812`, 0.34568628162294734`, 0.9356841088622658]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 234}], {
             RGBColor[
             0.21315182719847248`, 0.341366463364971, 0.9354500532778585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 239}], {
             RGBColor[
             0.2348622905163943, 0.36418553683498534`, 0.936686432046062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 249}], {
             RGBColor[
             0.21980259172524277`, 0.34835683856543287`, 0.9358288044787336]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 255}], {
             RGBColor[
             0.2990831810082368, 0.42639058870879876`, 0.9405375990810403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 258}], {
             RGBColor[
             0.2861550048473763, 0.41519285230728875`, 0.9397138271280076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 263}], {
             RGBColor[
             0.22101888131475306`, 0.34963523604122215`, 0.9358980703715171]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 286}], {
             RGBColor[
             0.2265196157319883, 0.3554168566804423, 0.9362113290589713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[
             0.6955329406462065, 0.7613368008112785, 0.9707925147289977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 97}], {
             RGBColor[
             0.5215176139849236, 0.6223094238976072, 0.9555083823712963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 120}], {
             RGBColor[
             0.4366336879326583, 0.5460453622474791, 0.9502000470026102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 130}], {
             RGBColor[
             0.75299012475597, 0.6847273872222507, 0.6045439579169226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 140}], {
             RGBColor[
             0.7057480336302696, 0.4077728682153858, 0.5627064708792573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 162}], {
             RGBColor[
             0.7927626721159106, 0.8360545204331631, 0.8771199562466196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 169}], {
             RGBColor[
             0.5994580148931581, 0.6857060476229113, 0.9616106773009028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[
             0.4265942001520806, 0.5354932240498018, 0.9496283130255976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 182}], {
             RGBColor[
             0.4242603384632414, 0.5330401874394541, 0.9494954030550571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 202}], {
             RGBColor[
             0.7303739014473327, 0.5842147173946636, 0.5857853158660629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 261}], {
             RGBColor[
             0.41945675567834323`, 0.5279913173677868, 0.949221846121721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 284}], {
             RGBColor[
             0.41756739126480746`, 0.526005475576538, 0.9491142496134344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 109}], {
             RGBColor[
             0.9929796059139886, 0.9895239708410322, 0.632193448669364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 140}], {
             RGBColor[
             0.9052335250111279, 0.560939848386522, 0.3299018570676289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 151}], {
             RGBColor[
             0.7954880540997038, 0.8360677360525939, 0.7285340376363743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[
             0.7452228320173793, 0.7952601643437132, 0.7245769752264782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 155}], {
             RGBColor[
             0.959730943798982, 0.866659323879206, 0.37757715104669176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 162}], {
             RGBColor[
             0.9922481634967688, 0.9892215006042993, 0.6443153424349913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 181}], {
             RGBColor[
             0.9897210070316473, 0.9765905802662477, 0.448420390956374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 202}], {
             RGBColor[
             0.9298593928281911, 0.7373816975657997, 0.35298070205443455`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 203}], {
             RGBColor[
             0.9651365709425674, 0.970190636874684, 0.7434503562978652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 216}], {
             RGBColor[
             0.9298058839378985, 0.7371387261923006, 0.3529360529247516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 227}], {
             RGBColor[
             0.9729262687384115, 0.9189743901826695, 0.3881944192270413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 258}], {
             RGBColor[
             0.6666547848110509, 0.7284026204302521, 0.7192407416322534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 299}], {
             RGBColor[
             0.9059209744031474, 0.5662238856558284, 0.33056015938178984`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 93}], {
             RGBColor[
             0.23199426054362918`, 0.36117105549000617`, 0.9365231019819831]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 107}], {
             RGBColor[
             0.3156668760979841, 0.43989562490003076`, 0.9416257469918767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 124}], {
             RGBColor[
             0.20439146202389424`, 0.3321587641272566, 0.9349511634409652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 137}], {
             RGBColor[
             0.242196310039882, 0.3718940563578661, 0.9371040936082149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 147}], {
             RGBColor[
             0.21812810554997109`, 0.34659684742666674`, 0.9357334449682322]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 273}], {
             RGBColor[
             0.23089430452924603`, 0.3600149319776501, 0.936460461114203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 274}], {
             RGBColor[
             0.342952508633553, 0.4632649151839602, 0.9434373496862328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 289}], {
             RGBColor[
             0.23315152394890182`, 0.3623874127036856, 0.9365890064208955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 94}], {
             RGBColor[
             0.5888165791799138, 0.6727291061533267, 0.962935879267211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 120}], {
             RGBColor[
             0.3299173264663655, 0.4574376675895273, 0.9423434115408236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 131}], {
             RGBColor[
             0.3050760854207314, 0.4313279482249144, 0.9409287396125976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 141}], {
             RGBColor[
             0.33729605784908523`, 0.4651931821113565, 0.9427636193772146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 188}], {
             RGBColor[
             0.3683043792841372, 0.49342847464473716`, 0.9446890072625783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 236}], {
             RGBColor[
             0.30608763983959875`, 0.4323911560553985, 0.9409863461402914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 260}], {
             RGBColor[
             0.3194559514168667, 0.4464420991230162, 0.9417476517079721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 281}], {
             RGBColor[
             0.6796029595718664, 0.743830302697593, 0.9334123929687868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 294}], {
             RGBColor[
             0.4583968818459615, 0.569215720181254, 0.9510502956112238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 118}], {
             RGBColor[
             0.20219853738896398`, 0.32985386129649247`, 0.9348262796271471]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 126}], {
             RGBColor[
             0.2195822201328165, 0.34812521404942687`, 0.9358162546425555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 153}], {
             RGBColor[
             0.21837262298903565`, 0.3468538507584247, 0.9357473698746558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.20088523531551122`, 0.3284734975491328, 0.9347514890169203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 195}], {
             RGBColor[
             0.19970007804544365`, 0.3272278221149808, 0.934683996063673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 222}], {
             RGBColor[
             0.2185508250169386, 0.3470411523884118, 0.9357575182165185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 234}], {
             RGBColor[
             0.20491562163947707`, 0.33270968911687326`, 0.9349810135556479]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 239}], {
             RGBColor[
             0.2266260849573989, 0.3555287625868876, 0.9362173923238513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 248}], {
             RGBColor[
             0.21881740302399694`, 0.347321342775852, 0.9357726994396538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 285}], {
             RGBColor[
             0.20767787323688183`, 0.3356129906826123, 0.9351383196977351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 93}], {
             RGBColor[
             0.3656444287828603, 0.48387268995411137`, 0.9450248073537576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 105}], {
             RGBColor[
             0.38699951220692347`, 0.5063182366232937, 0.9462409477627431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 107}], {
             RGBColor[
             0.44931704433721525`, 0.562597259364136, 0.9501274523636514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 139}], {
             RGBColor[
             0.4654409733450266, 0.5765629962584664, 0.9511548548621985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 142}], {
             RGBColor[
             0.6600471931315399, 0.4140378360712322, 0.5646529525736886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 143}], {
             RGBColor[
             0.39852667636969663`, 0.5184340170227889, 0.9468974027089019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 150}], {
             RGBColor[
             0.6987841041568563, 0.6337941140587057, 0.5986819437121721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 163}], {
             RGBColor[
             0.5556545906660699, 0.6501444545135875, 0.9581623112885165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 179}], {
             RGBColor[
             0.5064577791876668, 0.6102042666643193, 0.9542893580750782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 235}], {
             RGBColor[
             0.44932632055040805`, 0.5626052939537676, 0.9501280434357534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 273}], {
             RGBColor[
             0.3645444727684772, 0.4827165664417553, 0.9449621664859775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 274}], {
             RGBColor[
             0.4766026768727841, 0.5859665496480654, 0.9519390550580074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 298}], {
             RGBColor[
             0.3751482927558811, 0.4938618535695355, 0.9455660383473143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 125}], {
             RGBColor[
             0.8333745807247173, 0.2575372290505118, 0.17959284223417404`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 128}], {
             RGBColor[
             0.838247472010956, 0.29499240679111977`, 0.18425912843301978`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 142}], {
             RGBColor[
             0.830745140796793, 0.23732620153656223`, 0.1770748875896661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 149}], {
             RGBColor[
             0.8635292482964012, 0.4309688829157785, 0.2061841331747976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 150}], {
             RGBColor[
             0.8694820518221094, 0.4570824795240357, 0.2111038787281495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 179}], {
             RGBColor[
             0.6771557268529196, 0.4334926321296493, 0.5667112930910556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 237}], {
             RGBColor[
             0.8283146765154534, 0.21864458803394712`, 0.17474747224903853`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 243}], {
             RGBColor[
             0.9094860988652742, 0.6163067889114571, 0.5180190463996183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 256}], {
             RGBColor[
             0.8247413968754788, 0.1911787948999799, 0.17132569563035674`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 269}], {
             RGBColor[
             0.9023597936765284, 0.5823448940357236, 0.2640506186657438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 277}], {
             RGBColor[
             0.9122829383943001, 0.6155043542913563, 0.3292695837766948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 281}], {
             RGBColor[
             0.9050081321346448, 0.6135030027694477, 0.5495966137001128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 105}], {
             RGBColor[
             0.26248514686677915`, 0.39321891024948796`, 0.9382595128508624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 107}], {
             RGBColor[
             0.32480267899707094`, 0.44949793299033025`, 0.9421460174517705]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 137}], {
             RGBColor[
             0.25133211293896884`, 0.38149636444816565`, 0.9376243640681086]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 139}], {
             RGBColor[
             0.3409266080048823, 0.4634636698846607, 0.9431734199503177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 147}], {
             RGBColor[
             0.22726390844905786`, 0.3561991555169663, 0.936253715428126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 273}], {
             RGBColor[
             0.24003010742833283`, 0.36961724006794966`, 0.9369807315740968]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 274}], {
             RGBColor[
             0.3520883115326398, 0.4728672232742597, 0.9439576201461266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 289}], {
             RGBColor[
             0.24228732684798865`, 0.37198972079398507`, 0.9371092768807893]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 97}], {
             RGBColor[
             0.622873487370591, 0.7022274882781143, 0.9651059553417796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 120}], {
             RGBColor[
             0.5379895613183256, 0.6259634266279861, 0.9597976199730934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 130}], {
             RGBColor[
             0.8543459981416374, 0.7646454516027577, 0.6141415308874059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 141}], {
             RGBColor[
             0.5453682927010454, 0.6337189411498153, 0.9602178278094844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 188}], {
             RGBColor[
             0.5763766141360973, 0.661954233683196, 0.9621432156948482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 201}], {
             RGBColor[
             0.8211264532079356, 0.595474367346517, 0.5857320499193991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 202}], {
             RGBColor[
             0.8317297748330001, 0.6641327817751705, 0.595382888836546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.8109817388046351, 0.5174976470005512, 0.5760174599499823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 281}], {
             RGBColor[
             0.8876751944238266, 0.9123560617360518, 0.9508666014010566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 293}], {
             RGBColor[
             0.8483237902546403, 0.739482330174071, 0.6092293420609014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 294}], {
             RGBColor[
             0.6664691166979216, 0.7377414792197128, 0.9685045040434936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 103}], {
             RGBColor[
             0.35444301317126903`, 0.47946333163225574`, 0.9438775064114789]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 127}], {
             RGBColor[
             0.3181958172626126, 0.4480678323732162, 0.9415678671403162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 145}], {
             RGBColor[
             0.5762301255781173, 0.6573426269684071, 0.963331889789669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 148}], {
             RGBColor[
             0.2669268205335093, 0.3978873908915973, 0.9385124595953154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 156}], {
             RGBColor[
             0.3410239560220559, 0.4678404187910305, 0.9430224559559374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 159}], {
             RGBColor[
             0.2893985943419117, 0.4215066499569798, 0.9397921938696936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 168}], {
             RGBColor[
             0.3439839043984553, 0.4704041773033365, 0.943211061249102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 191}], {
             RGBColor[
             0.2574665501142888, 0.38794404686520834`, 0.9379737111901566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 205}], {
             RGBColor[
             0.32995805051825455`, 0.4582556876322203, 0.9423173462424312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 212}], {
             RGBColor[
             0.2604625119164363, 0.3910929926742148, 0.9381443267826606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 225}], {
             RGBColor[
             0.2575765092536425, 0.3880596208924811, 0.9379799732004728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 251}], {
             RGBColor[
             0.2865818395337517, 0.41854606206103384`, 0.9396317838503843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 271}], {
             RGBColor[
             0.25509580298829937`, 0.3854522413217438, 0.9378387006485376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 276}], {
             RGBColor[
             0.2644651178260697, 0.3952999852651118, 0.9383722692678894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 282}], {
             RGBColor[
             0.36409426757402563`, 0.48782276310977274`, 0.9444924758077534]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 112}], {
             RGBColor[
             0.1950909003644823, 0.32238328413354655`, 0.9344215102134096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 132}], {
             RGBColor[
             0.1989233882773373, 0.32641147192372544`, 0.9346397647303889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 133}], {
             RGBColor[
             0.19311989172231955`, 0.3203116290814677, 0.9343092641870845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 146}], {
             RGBColor[
             0.20048974504421074`, 0.3280578121984645, 0.9347289664310452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 236}], {
             RGBColor[
             0.2161907003932258, 0.34456051176834573`, 0.9356231126106896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 260}], {
             RGBColor[
             0.22955901197049378`, 0.3586114548359634, 0.9363844181783704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 267}], {
             RGBColor[
             0.19857826997424566`, 0.3260487307054119, 0.9346201107535846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 120}], {
             RGBColor[
             0.3639742346570427, 0.4869360497143149, 0.944513487615392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 130}], {
             RGBColor[
             0.6803306714803544, 0.6256180746890865, 0.5988573985297044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 178}], {
             RGBColor[
             0.353934746876465, 0.4763839115166376, 0.9439417536383794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 182}], {
             RGBColor[
             0.35160088518762583`, 0.47393087490628993`, 0.9438088436678389]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 202}], {
             RGBColor[
             0.6577144481717172, 0.5251054048614994, 0.5800987564788447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 261}], {
             RGBColor[
             0.34679730240272766`, 0.46888200483462256`, 0.9435352867345028]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 284}], {
             RGBColor[
             0.3449079379891919, 0.4668961630433738, 0.9434276902262162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 157}], {
             RGBColor[
             0.18079506708635712`, 0.3073574569500555, 0.9336073836570105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.17910006852395627`, 0.30557590599185624`, 0.9335108559964074]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 275}], {
             RGBColor[
             0.17961340510331275`, 0.30611545528417883`, 0.9335400897551883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 285}], {
             RGBColor[
             0.18936585526810354`, 0.31636589874842813`, 0.9340954773646161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 182}], {
             RGBColor[
             0.22500890422772363`, 0.3538290031048185, 0.9361252962737008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 199}], {
             RGBColor[
             0.19703448061371565`, 0.32442611020559603`, 0.9345321942333341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 209}], {
             RGBColor[
             0.18806492725905072`, 0.31499854092731383`, 0.934021391439051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 215}], {
             RGBColor[
             0.21020795705683448`, 0.338272269193962, 0.9352824042283578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 229}], {
             RGBColor[
             0.20669327315473038`, 0.33457811356902034`, 0.9350822481796419]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 233}], {
             RGBColor[
             0.20053490529032286`, 0.32810527848045334`, 0.9347315382402527]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 259}], {
             RGBColor[
             0.19041774683741108`, 0.3174715034815479, 0.934155381033354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 284}], {
             RGBColor[
             0.2183159570292897, 0.34679429124190236`, 0.9357441428320781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 119}], {
             RGBColor[
             0.1807572108955105, 0.3073176676932546, 0.933605227802945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 122}], {
             RGBColor[
             0.18285159839459103`, 0.3095190017466254, 0.933724500072649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 161}], {
             RGBColor[
             0.1911587437240086, 0.318250338191278, 0.9341975797098391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 244}], {
             RGBColor[
             0.18508330510196136`, 0.31186466699444937`, 0.9338515924681194]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 266}], {
             RGBColor[
             0.1894062944527255, 0.3164084028954582, 0.9340977803163559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 104}], {
             RGBColor[
             0.49120791951509923`, 0.5945373978105576, 0.9540278714950781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 116}], {
             RGBColor[
             0.46733992011891123`, 0.5718860980228273, 0.952579449352897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 136}], {
             RGBColor[
             0.5199717589850226, 0.6194511898467974, 0.9558606779112371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 149}], {
             RGBColor[
             0.7714159149498363, 0.6714029284596804, 0.6000007099012994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 197}], {
             RGBColor[
             0.816834867392223, 0.8565183997567056, 0.9207499871177253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 198}], {
             RGBColor[
             0.8059595419277743, 0.8487647451023745, 0.9551527712864303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[
             0.5654681824695174, 0.6580354513456885, 0.9589869162220399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 226}], {
             RGBColor[
             0.8167925796772653, 0.8565009126998259, 0.9214508039916728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 243}], {
             RGBColor[
             0.8173727655187092, 0.8567408344553589, 0.91183562312612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 254}], {
             RGBColor[
             0.4830549298600605, 0.587475687952538, 0.9535083702036646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 283}], {
             RGBColor[
             0.4765743997943146, 0.5815921216615045, 0.9531053393092228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 165}], {
             RGBColor[
             0.20499479718794766`, 0.3327929076383356, 0.9349855224860035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 172}], {
             RGBColor[
             0.19138970866876043`, 0.3184930969922355, 0.9342107328217606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 175}], {
             RGBColor[
             0.18740197098760464`, 0.3143017318521686, 0.9339836370601481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 183}], {
             RGBColor[
             0.19246783079694663`, 0.31962627170585023`, 0.934272130282022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 238}], {
             RGBColor[
             0.18981943468321613`, 0.3168426394723074, 0.9341213080412961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 253}], {
             RGBColor[
             0.1920226425007294, 0.3191583505799577, 0.9342467774671497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 127}], {
             RGBColor[
             0.3850824421018483, 0.5079607893674816, 0.9457580905890645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 145}], {
             RGBColor[
             0.643116750417353, 0.7172355839626725, 0.9675221132384173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 154}], {
             RGBColor[
             0.45931362601150366`, 0.5710619602704519, 0.9508179830889629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 159}], {
             RGBColor[
             0.35628521918114736`, 0.4813996069512451, 0.9439824173184419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 167}], {
             RGBColor[
             0.6645058305861254, 0.6055266520723135, 0.5963223612979925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 168}], {
             RGBColor[
             0.41087052923769096`, 0.5302971342976018, 0.9474012846978503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 203}], {
             RGBColor[
             0.679227364936692, 0.7459924328014227, 0.96969136416035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 205}], {
             RGBColor[
             0.39684467535749024`, 0.5181486446264856, 0.9465075696911796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 212}], {
             RGBColor[
             0.327349136755672, 0.45098594966848016`, 0.9423345502314089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 225}], {
             RGBColor[
             0.3244631340928782, 0.4479525778867464, 0.9421701966492211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 255}], {
             RGBColor[
             0.3936737549660358, 0.5154021527585007, 0.9463055214477708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 265}], {
             RGBColor[
             0.3220227389937979, 0.445387567907627, 0.9420312197585695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 269}], {
             RGBColor[
             0.6972472679550255, 0.7302486647196956, 0.6491594274470608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 276}], {
             RGBColor[
             0.33135174266530537`, 0.4551929422593771, 0.9425624927166377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 282}], {
             RGBColor[
             0.4309808924132613, 0.5477157201040381, 0.9486826992565017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 293}], {
             RGBColor[
             0.6605442022439556, 0.5885330418914387, 0.5930681631412746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 114}], {
             RGBColor[
             0.28710993911342014`, 0.4166656473064825, 0.939751033226302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 116}], {
             RGBColor[
             0.3112198168736299, 0.4420066574870038, 0.9411240550973782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 204}], {
             RGBColor[
             0.40934807922423605`, 0.5281560108098651, 0.9475315219665212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 206}], {
             RGBColor[
             0.2787552105581772, 0.4078842978745366, 0.9392752437947942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 243}], {
             RGBColor[
             0.6612526622734278, 0.7268613939195354, 0.9003802288706013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 254}], {
             RGBColor[
             0.32693482661477913`, 0.45759624741671456`, 0.942052975948146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 283}], {
             RGBColor[
             0.32045429654903324`, 0.4517126811256811, 0.9416499450537039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 287}], {
             RGBColor[
             0.2890443879522816, 0.41869887568726627`, 0.9398611972259145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 300}], {
             RGBColor[
             0.2803668703826312, 0.4095782545351725, 0.9393670254375599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 139}], {
             RGBColor[
             0.3622816914289454, 0.48590921655384295`, 0.9443895603593033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 143}], {
             RGBColor[
             0.29536739445361543`, 0.4277802373181654, 0.9401321082060067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 163}], {
             RGBColor[
             0.4524953087499887, 0.5594906748089641, 0.9513970167856213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 174}], {
             RGBColor[
             0.25852249961576723`, 0.3890539167423275, 0.9380338459521285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 235}], {
             RGBColor[
             0.34616703863432685`, 0.47195151424914406`, 0.9433627489328582]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 274}], {
             RGBColor[
             0.373443394956703, 0.4953127699434419, 0.9451737605551122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 298}], {
             RGBColor[
             0.27198901083979987`, 0.403208073864912, 0.938800743844419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 115}], {
             RGBColor[
             0.6067946716231568, 0.6858798777418896, 0.9651595250499304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 155}], {
             RGBColor[
             0.8940872222095038, 0.8191271102860018, 0.6231274080512639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 162}], {
             RGBColor[
             0.9266044419072905, 0.9416892870110949, 0.8898655994395634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 194}], {
             RGBColor[
             0.7739330746560312, 0.8236601401446212, 0.9780122537987794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 200}], {
             RGBColor[
             0.6137154608562325, 0.6918743175265988, 0.9656005116200483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 210}], {
             RGBColor[
             0.6667698289178824, 0.73732879896912, 0.9691188386686375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 211}], {
             RGBColor[
             0.5662966671615951, 0.6472879549936589, 0.9627077142549896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 227}], {
             RGBColor[
             0.907282547148933, 0.8714421765894653, 0.6337446762316135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 241}], {
             RGBColor[
             0.9239924068585166, 0.940609143392188, 0.9331537799277652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 264}], {
             RGBColor[
             0.579035279379287, 0.6606770441091168, 0.9634331593756991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 290}], {
             RGBColor[
             0.9041357720440601, 0.8589662618992862, 0.6312127071179277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 291}], {
             RGBColor[
             0.8943677152627585, 0.9186085554583606, 0.9897867851648885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 137}], {
             RGBColor[
             0.33500472849332374`, 0.4602209338581902, 0.9427270090780024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 139}], {
             RGBColor[
             0.4245992235592372, 0.5421882392946853, 0.9482760649602114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[
             0.3109365240034128, 0.43492372492699083`, 0.9413563604380197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 150}], {
             RGBColor[
             0.657942354371067, 0.5994193570949246, 0.595803153810185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.4014834091317521, 0.5221664826722128, 0.9468031457054042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.4656160294018773, 0.5758295097005381, 0.9514105681730911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 251}], {
             RGBColor[
             0.34704129264344796`, 0.47287212594221606`, 0.943412473599851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 273}], {
             RGBColor[
             0.32370272298268776`, 0.4483418094779742, 0.9420833765839904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 274}], {
             RGBColor[
             0.43576092708699476`, 0.5515917926842843, 0.9490602651560203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 277}], {
             RGBColor[
             0.7007432409432577, 0.7578412318622451, 0.7139688588587303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 289}], {
             RGBColor[
             0.32595994240234355`, 0.45071429020400966`, 0.942211921890683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 136}], {
             RGBColor[
             0.3166504809342749, 0.4423958027593246, 0.9416280716923184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 177}], {
             RGBColor[
             0.2663285931328081, 0.3972586159636525, 0.9384783914298436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 204}], {
             RGBColor[
             0.36214690441876973`, 0.48098006425821577`, 0.9447543100031214]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 208}], {
             RGBColor[
             0.2150010029643497, 0.34331006433942324`, 0.9355553611021148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 252}], {
             RGBColor[
             0.23931387407336885`, 0.3688644334000649, 0.9369399431441039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 254}], {
             RGBColor[
             0.27973365180931276`, 0.4104203008650652, 0.9392757639847461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 268}], {
             RGBColor[
             0.2228674989167732, 0.351578250350071, 0.9360033464091675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 279}], {
             RGBColor[
             0.23867609661587075`, 0.3681940888548081, 0.9369036226614065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 280}], {
             RGBColor[
             0.2513491898337207, 0.3815143133472875, 0.9376253365720018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 283}], {
             RGBColor[
             0.2732531217435669, 0.4045367345740317, 0.9388727330903042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 111}], {
             RGBColor[
             0.8035074391264327, 0.8444862586698714, 0.8657863480729937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 151}], {
             RGBColor[
             0.7953196099914366, 0.8378390101205823, 0.8651417721704804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 155}], {
             RGBColor[
             0.9595624996907148, 0.8684305979471943, 0.514184885580798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 192}], {
             RGBColor[
             0.6617142280646152, 0.7260405303844142, 0.8555444013688691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 218}], {
             RGBColor[
             0.9800003657513711, 0.9831729301139916, 0.8546124313811914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 220}], {
             RGBColor[
             0.6629503007752218, 0.7271111544395208, 0.8556231628289728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 227}], {
             RGBColor[
             0.9727578246301442, 0.9207456642506578, 0.5248021537611475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 290}], {
             RGBColor[
             0.9696110495252712, 0.9082697495604787, 0.5222701846474617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 292}], {
             RGBColor[
             0.8832633694480486, 0.907223500639492, 0.873440789605417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 148}], {
             RGBColor[
             0.2161072361235734, 0.34447278552900074`, 0.9356183594440073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 191}], {
             RGBColor[
             0.20664696570435293`, 0.3345294415026117, 0.9350796110388486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 223}], {
             RGBColor[
             0.18370379552866184`, 0.31041471496695283`, 0.9337730314387216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 246}], {
             RGBColor[
             0.18518351558803503`, 0.3119699945690246, 0.9338572993070533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 278}], {
             RGBColor[
             0.19327360105018532`, 0.32047318733078894`, 0.9343180177059138]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 295}], {
             RGBColor[
             0.19142001506063305`, 0.31852495093162986`, 0.9342124587259435]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 143}], {
             RGBColor[
             0.46054913753176646`, 0.5687866450741914, 0.9517800380473413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 163}], {
             RGBColor[
             0.6176770518281398, 0.70049708256499, 0.9630449466269559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.5718800780485805, 0.6633170361205862, 0.9594396410911864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 218}], {
             RGBColor[
             0.7906966430720825, 0.8363639438748425, 0.9515975962507148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 235}], {
             RGBColor[
             0.5113487817124779, 0.61295792200517, 0.9550106787741928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 262}], {
             RGBColor[
             0.459021775002635, 0.5671812902156966, 0.9516930570108376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 292}], {
             RGBColor[
             0.6939596467687601, 0.7604145144003427, 0.9704259544749405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 131}], {
             RGBColor[
             0.20931958090363292`, 0.3373385295306458, 0.9352318125206677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 132}], {
             RGBColor[
             0.1930638232066118, 0.32025269751650964`, 0.9343060711680607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 133}], {
             RGBColor[
             0.18726032665159403`, 0.3141528546742519, 0.9339755706247563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 146}], {
             RGBColor[
             0.19463017997348525`, 0.32189903779124873`, 0.934395272868717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 170}], {
             RGBColor[
             0.1934039006537554, 0.3206101404756131, 0.9343254380755761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 190}], {
             RGBColor[
             0.19682291342577818`, 0.3242037396769393, 0.9345201457949667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 115}], {
             RGBColor[
             0.3096806718260522, 0.43885035168813935`, 0.9410927375300542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 134}], {
             RGBColor[
             0.25621583264175446`, 0.38662946350150684`, 0.9379024846803665]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 144}], {
             RGBColor[
             0.23263625868922916`, 0.36184583624606526`, 0.9365596628266237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 160}], {
             RGBColor[
             0.23169850636271255`, 0.3608601990939647, 0.936506259218909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 169}], {
             RGBColor[
             0.4361857848874334, 0.5443112881470928, 0.9502895329739705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 176}], {
             RGBColor[
             0.23091262265844142`, 0.3600341854928709, 0.9364615043045614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 187}], {
             RGBColor[
             0.24618639037776724`, 0.3760878837786886, 0.9373313227806626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 193}], {
             RGBColor[
             0.2735981771019762, 0.40489940963349313`, 0.9388923834825018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 200}], {
             RGBColor[
             0.3166014610591278, 0.4448447914728484, 0.9415337241001722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 228}], {
             RGBColor[
             0.34694483487630184`, 0.4711266967709722, 0.9434671770482106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 231}], {
             RGBColor[
             0.24940666839475117`, 0.3794726001519578, 0.9375147128497554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 245}], {
             RGBColor[
             0.24643755239072743`, 0.3763518709789012, 0.9373456260857398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 264}], {
             RGBColor[
             0.28192127958218227`, 0.41364751805536637`, 0.939366371855823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 288}], {
             RGBColor[
             0.23824897201713657`, 0.3677451538202748, 0.9368792985473828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 297}], {
             RGBColor[
             0.22981287868159825`, 0.35887828484541334`, 0.9363988755120056]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 116}], {
             RGBColor[
             0.26324193971723214`, 0.3940143475187522, 0.9383026110841209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 204}], {
             RGBColor[
             0.3613702020678383, 0.4801637008416135, 0.944710077953264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 206}], {
             RGBColor[
             0.2307773334017795, 0.35989198790628496`, 0.936453799781537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 254}], {
             RGBColor[
             0.2789569494583814, 0.4096039374484629, 0.9392315319348887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 283}], {
             RGBColor[
             0.2724764193926355, 0.4037203711574294, 0.9388285010404467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 134}], {
             RGBColor[
             0.29826389721871693`, 0.4268505977105114, 0.940442569105771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 169}], {
             RGBColor[
             0.47823384946439584`, 0.5845324223560975, 0.9528296173993749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 193}], {
             RGBColor[
             0.3156462416789386, 0.4451205438424978, 0.9414324679079064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 200}], {
             RGBColor[
             0.35864952563609026`, 0.485065925681853, 0.9440738085255767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 210}], {
             RGBColor[
             0.4117038936977402, 0.5305204071243743, 0.9475921355741658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 211}], {
             RGBColor[
             0.3112307319414529, 0.4404795631489132, 0.9411810111605179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 227}], {
             RGBColor[
             0.6522166119287909, 0.6646337847447196, 0.6122179731371418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 228}], {
             RGBColor[
             0.3889928994532643, 0.5113478309799768, 0.946007261473615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 231}], {
             RGBColor[
             0.29145473297171365`, 0.41969373436096236`, 0.9400547972751598]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 245}], {
             RGBColor[
             0.2884856169676899, 0.4165730051879058, 0.9398857105111442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 264}], {
             RGBColor[
             0.32396934415914475`, 0.453868652264371, 0.9419064562812274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 204}], {
             RGBColor[
             0.38548007982804805`, 0.5055047110221348, 0.9460830998243401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 206}], {
             RGBColor[
             0.2548872111619892, 0.3852329980868062, 0.9378268216526131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 254}], {
             RGBColor[
             0.30306682721859113`, 0.43494494762898417`, 0.9406045538059649]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 283}], {
             RGBColor[
             0.29658629715284524`, 0.4290613813379507, 0.9402015229115228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 287}], {
             RGBColor[
             0.2651763885560936, 0.39604757589953593`, 0.9384127750837334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 158}], {
             RGBColor[
             0.189227738636957, 0.3162207294119929, 0.9340876118267976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 196}], {
             RGBColor[
             0.1942847722586868, 0.32153599238288155`, 0.9343756024103442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 207}], {
             RGBColor[
             0.18539878883552113`, 0.3121962604012447, 0.9338695588000294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 212}], {
             RGBColor[
             0.20943922968905518`, 0.3374642879902957, 0.935238626341993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 214}], {
             RGBColor[
             0.19317010459047246`, 0.32036440598957616`, 0.9343121237356424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 225}], {
             RGBColor[
             0.20655322702626136`, 0.33443091620856197`, 0.9350742727598051]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 265}], {
             RGBColor[
             0.2041128319271811, 0.33186590622944256`, 0.9349352958691536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 276}], {
             RGBColor[
             0.21344183559868857`, 0.34167128058119267`, 0.9354665688272218]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 166}], {
             RGBColor[
             0.18740769372755933`, 0.31430774681470364`, 0.9339839629617225]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.18622253645749176`, 0.31306207138055164`, 0.9339164700084752]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 234}], {
             RGBColor[
             0.19143808005152518`, 0.3185439383824441, 0.9342134875004501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 239}], {
             RGBColor[
             0.213148543369447, 0.34136301185245843`, 0.9354498662686535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 263}], {
             RGBColor[
             0.19930513416780576`, 0.32681271105869525`, 0.9346615045941087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 285}], {
             RGBColor[
             0.19420033164892994`, 0.32144723994818314`, 0.9343707936425373]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 122}], {
             RGBColor[
             0.18294597115910344`, 0.30961819350570674`, 0.933729874461976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 161}], {
             RGBColor[
             0.191253116488521, 0.3183495299503595, 0.9342029540991661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 244}], {
             RGBColor[
             0.18517767786647377`, 0.3119638587535308, 0.9338569668574466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 266}], {
             RGBColor[
             0.1895006672172379, 0.3165075946545396, 0.9341031547056828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 131}], {
             RGBColor[
             0.2542490675591432, 0.38456226869957383`, 0.93779048031848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 141}], {
             RGBColor[
             0.28646903998749706`, 0.4184275025860159, 0.939625360083097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 170}], {
             RGBColor[
             0.23833338730926568`, 0.3678338796445412, 0.9368841058733883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 178}], {
             RGBColor[
             0.2690508208241996, 0.4001198498665095, 0.9386334182696933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 182}], {
             RGBColor[
             0.2667169591353605, 0.3976668132561618, 0.9385005082991529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 188}], {
             RGBColor[
             0.317477361422549, 0.44666279511939655`, 0.9415507479684607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 190}], {
             RGBColor[
             0.24175240008128845`, 0.37142747884586735`, 0.937078813592779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 261}], {
             RGBColor[
             0.2619133763504623, 0.3926179431844944, 0.9382269513658168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 284}], {
             RGBColor[
             0.26002401193692654`, 0.39063210139324567`, 0.9381193548575302]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 294}], {
             RGBColor[
             0.40756986398437334`, 0.5224500406559134, 0.9479120363171062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 135}], {
             RGBColor[
             0.21926297732246688`, 0.3477896696145861, 0.9357980742367835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 154}], {
             RGBColor[
             0.3613735298324199, 0.47852983599420473`, 0.9448593103869043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 173}], {
             RGBColor[
             0.21336819471978227`, 0.34159387934836083`, 0.9354623750881099]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.21391225518849333`, 0.3421657213964022, 0.9354933585269378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 234}], {
             RGBColor[
             0.20980230497718771`, 0.3378459031384259, 0.9352593029425303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 239}], {
             RGBColor[
             0.2315127682951095, 0.3606649766084402, 0.9364956817107337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 249}], {
             RGBColor[
             0.21645306950395798`, 0.3448362783388877, 0.9356380541434055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 255}], {
             RGBColor[
             0.295733658786952, 0.42287002848225363`, 0.9403468487457121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 258}], {
             RGBColor[
             0.28280548262609156`, 0.41167229208074363`, 0.9395230767926794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 263}], {
             RGBColor[
             0.2176693590934683, 0.34611467581467703`, 0.935707320036189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 286}], {
             RGBColor[
             0.22317009351070355`, 0.3518962964538972, 0.9360205787236432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 138}], {
             RGBColor[
             0.2081640824318275, 0.3361240273739437, 0.9351660085921052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 161}], {
             RGBColor[
             0.19334750398760153`, 0.32055086400373023`, 0.9343222263688701]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 266}], {
             RGBColor[
             0.19159505471631844`, 0.31870892870791034`, 0.9342224269753869]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 189}], {
             RGBColor[
             0.2072195140090381, 0.335131226072495, 0.935112216817791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 257}], {
             RGBColor[
             0.19133948148967972`, 0.3184403050424346, 0.9342078724582165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 267}], {
             RGBColor[
             0.19740462411574278`, 0.32481515449468, 0.9345532733581963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 287}], {
             RGBColor[
             0.22080206667647367`, 0.3494073501095485, 0.9358857230986155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 300}], {
             RGBColor[
             0.21212454910682327`, 0.34028672895745476`, 0.9353915513102607]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 147}], {
             RGBColor[
             0.19966110992932296`, 0.3271868641542167, 0.9346817768871081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 247}], {
             RGBColor[
             0.191840440673128, 0.3189668449068855, 0.9342364013426112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 273}], {
             RGBColor[
             0.2124273089085979, 0.3406049487052001, 0.9354087930330789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 289}], {
             RGBColor[
             0.2146845283282537, 0.3429774294312355, 0.9355373383397714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 128}], {
             RGBColor[
             0.8400673632821627, 0.3089808885830544, 0.18600185836960054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 130}], {
             RGBColor[
             0.8734988271236623, 0.4797808744280881, 0.21461427312304276`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 142}], {
             RGBColor[
             0.8325650320679996, 0.2513146833284968, 0.1788176175262468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.865349139567608, 0.4449573647077131, 0.20792686311137834`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 150}], {
             RGBColor[
             0.871301943093316, 0.4710709613159703, 0.2128466086647302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 167}], {
             RGBColor[
             0.871438247578835, 0.47161136318027613`, 0.21295628245325632`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 237}], {
             RGBColor[
             0.8301345677866601, 0.23263306982588172`, 0.17649020218561928`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 243}], {
             RGBColor[
             0.9113059901364808, 0.6302952707033915, 0.519761776336199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 256}], {
             RGBColor[
             0.8265612881466855, 0.2051672766919145, 0.17306842556693747`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 269}], {
             RGBColor[
             0.904179684947735, 0.5963333758276583, 0.2657933486023245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 277}], {
             RGBColor[
             0.9141028296655067, 0.6294928360832908, 0.33101231371327555`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 281}], {
             RGBColor[
             0.9068280234058514, 0.6274914845613823, 0.5513393436366936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 293}], {
             RGBColor[
             0.8674766192366652, 0.4546177529994014, 0.20970208429653842`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 153}], {
             RGBColor[
             0.2222787641449363, 0.35095945277692997`, 0.9359698188348664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 157}], {
             RGBColor[
             0.20301322621103607`, 0.33071015090274497`, 0.93487267495034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 192}], {
             RGBColor[
             0.2770528278061131, 0.40650831596386994`, 0.939163161568517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 220}], {
             RGBColor[
             0.27828890051671973`, 0.40757894001897654`, 0.9392419230286206]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 222}], {
             RGBColor[
             0.22245696617283922`, 0.3511467544069171, 0.9359799671767292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 239}], {
             RGBColor[
             0.2305322261132995, 0.35963436460539283`, 0.9364398412840619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 248}], {
             RGBColor[
             0.22272354417989754`, 0.3514269447943572, 0.9359951483998643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 285}], {
             RGBColor[
             0.21158401439278246`, 0.3397185927011176, 0.9353607686579457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 145}], {
             RGBColor[
             0.6068695545086966, 0.6858400847036329, 0.9652124739672545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 148}], {
             RGBColor[
             0.29756624946408855`, 0.42638484862682313`, 0.9403930437729009]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 156}], {
             RGBColor[
             0.3716633849526351, 0.49633787652625627`, 0.9449030401335229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 159}], {
             RGBColor[
             0.3200380232724909, 0.45000410769220556`, 0.9416727780472791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 168}], {
             RGBColor[
             0.3746233333290345, 0.4989016350385623, 0.9450916454266876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 191}], {
             RGBColor[
             0.28810597904486807`, 0.41644150460043405`, 0.9398542953677421]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 205}], {
             RGBColor[
             0.3605974794488338, 0.48675314536744607`, 0.9441979304200168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 212}], {
             RGBColor[
             0.2911019408470156, 0.4195904504094406, 0.9400249109602461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 225}], {
             RGBColor[
             0.28821593818422175`, 0.41655707862770686`, 0.9398605573780583]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 251}], {
             RGBColor[
             0.31722126846433096`, 0.4470435197962596, 0.9415123680279698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 269}], {
             RGBColor[
             0.6610000720463691, 0.698853165460656, 0.646849788175898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 276}], {
             RGBColor[
             0.29510454675664893`, 0.4237974430003376, 0.9402528534454749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 282}], {
             RGBColor[
             0.3947336965046049, 0.5163202208449985, 0.9463730599853389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 142}], {
             RGBColor[
             0.8374379233542384, 0.28876986106910485`, 0.18348390372509257`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 149}], {
             RGBColor[
             0.8702220308538466, 0.4824125424483211, 0.2125931493102241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 150}], {
             RGBColor[
             0.8761748343795548, 0.5085261390565783, 0.21751289486357597`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 197}], {
             RGBColor[
             0.9156409832962333, 0.6675280137453463, 0.53334242652665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 198}], {
             RGBColor[
             0.9047656578317846, 0.6597743590910152, 0.567745210695355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 237}], {
             RGBColor[
             0.8350074590728989, 0.27008824756648975`, 0.18115648838446502`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 243}], {
             RGBColor[
             0.9161788814227196, 0.6677504484439996, 0.5244280625350448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 256}], {
             RGBColor[
             0.8314341794329242, 0.2426224544325225, 0.1777347117657832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 269}], {
             RGBColor[
             0.9090525762339738, 0.6337885535682664, 0.2704596348011703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 277}], {
             RGBColor[
             0.9189757209517455, 0.6669480138238988, 0.3356785999121213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 281}], {
             RGBColor[
             0.9117009146920902, 0.6649466623019902, 0.5560056298355394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 165}], {
             RGBColor[
             0.20344097121398075`, 0.33115973802143944`, 0.9348970343954657]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 175}], {
             RGBColor[
             0.18584814501363772`, 0.3126685622352725, 0.9338951489696101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 183}], {
             RGBColor[
             0.1909140048229797, 0.31799310208895415`, 0.9341836421914842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 184}], {
             RGBColor[
             0.19028873719925032`, 0.31733590617215746`, 0.9341480341253134]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 224}], {
             RGBColor[
             0.19887770973958555`, 0.32636346088436186`, 0.9346371634052393]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 253}], {
             RGBColor[
             0.19046881652676248`, 0.3175251809630616, 0.9341582893766117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 140}], {
             RGBColor[
             0.8645610911257005, 0.4110815190068649, 0.2060554870376654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 162}], {
             RGBColor[
             0.9515757296113414, 0.8393631712246421, 0.5204689724050278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 167}], {
             RGBColor[
             0.9097426027065735, 0.6798665267659179, 0.24623498340554434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 201}], {
             RGBColor[
             0.8785836373176991, 0.5188649537574892, 0.21948349310732407`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 202}], {
             RGBColor[
             0.8891869589427635, 0.5875233681861427, 0.22913433202447103`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 203}], {
             RGBColor[
             0.92446413705714, 0.8203323074950271, 0.6196039862679017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 216}], {
             RGBColor[
             0.889133450052471, 0.5872803968126434, 0.22908968289478807`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 237}], {
             RGBColor[
             0.8684389229143985, 0.44088823341152344`, 0.20976890313790728`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 269}], {
             RGBColor[
             0.9424840400754735, 0.8045885394133, 0.29907204955461253`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 281}], {
             RGBColor[
             0.9451323785335899, 0.8357466481470239, 0.5846180445889815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 293}], {
             RGBColor[
             0.9057809743644036, 0.6628729165850431, 0.24298078524882644`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 294}], {
             RGBColor[
             0.723926300807685, 0.6611320656306849, 0.6022559472314186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 299}], {
             RGBColor[
             0.8652485405177199, 0.41636555627617133`, 0.20671378935182633`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 141}], {
             RGBColor[
             0.26162779894186294`, 0.392317783221403, 0.938210688154871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 146}], {
             RGBColor[
             0.2147184255833614, 0.3430130575955638, 0.9355392687383033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 170}], {
             RGBColor[
             0.21349214626363155`, 0.34172416027992825`, 0.9354694339451624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 178}], {
             RGBColor[
             0.2442095797785655, 0.3740101305018966, 0.9372187463414672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 182}], {
             RGBColor[
             0.24187571808972635`, 0.3715570938915489, 0.9370858363709268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 188}], {
             RGBColor[
             0.2926361203769149, 0.4205530757547836, 0.9401360760402346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 190}], {
             RGBColor[
             0.21691115903565433`, 0.3453177594812544, 0.9356641416645529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 199}], {
             RGBColor[
             0.21390129447571837`, 0.3421542009923264, 0.9354927343305601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 261}], {
             RGBColor[
             0.23707213530482818`, 0.36650822381988146`, 0.9368122794375908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 284}], {
             RGBColor[
             0.23518277089129241`, 0.36452238202863274`, 0.9367046829293041]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 133}], {
             RGBColor[
             0.19109281456444907`, 0.3181810424644308, 0.9341938251417357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 146}], {
             RGBColor[
             0.19846266788634026`, 0.3259272255814276, 0.9346135273856964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 236}], {
             RGBColor[
             0.21416362323535532`, 0.3424299251513089, 0.9355076735653408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 260}], {
             RGBColor[
             0.2275319348126233, 0.35648086821892655`, 0.9362689791330215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 267}], {
             RGBColor[
             0.19655119281637518`, 0.32391814408837505`, 0.9345046717082358]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 146}], {
             RGBColor[
             0.19265917133132254`, 0.3198273827391699, 0.9342830268423918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 170}], {
             RGBColor[
             0.1914328920115927, 0.3185384854235343, 0.9342131920492509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 144}], {
             RGBColor[
             0.22121948408189393`, 0.34984608226843733`, 0.9359094944023405]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 160}], {
             RGBColor[
             0.22028173175537732`, 0.3488604451163368, 0.9358560907946256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 169}], {
             RGBColor[
             0.42476901028009817`, 0.532311534169465, 0.9496393645496872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 176}], {
             RGBColor[
             0.21949584805110617`, 0.34803443151524305`, 0.9358113358802782]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 180}], {
             RGBColor[
             0.21984183187712564`, 0.34839808245303105`, 0.9358310391473328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 187}], {
             RGBColor[
             0.23476961577043198`, 0.36408812980106076`, 0.9366811543563793]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 193}], {
             RGBColor[
             0.26218140249464095`, 0.39289965565586527`, 0.9382422150582186]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 200}], {
             RGBColor[
             0.3051846864517926, 0.4328450374952205, 0.9408835556758889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 221}], {
             RGBColor[
             0.21549733286296777`, 0.343831738532004, 0.9355836263555868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 228}], {
             RGBColor[
             0.3355280602689666, 0.4591269427933443, 0.9428170086239273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 230}], {
             RGBColor[
             0.21844228820343148`, 0.34692707331578443`, 0.9357513372055553]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 245}], {
             RGBColor[
             0.2350207777833922, 0.3643521170012733, 0.9366954576614566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 264}], {
             RGBColor[
             0.27050450497484707`, 0.4016477640777385, 0.9387162034315397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 288}], {
             RGBColor[
             0.22683219740980134`, 0.35574539984264686`, 0.9362291301230996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 297}], {
             RGBColor[
             0.21839610407426302`, 0.3468785308677854, 0.9357487070877224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 158}], {
             RGBColor[
             0.20301108119461975`, 0.33070789635448955`, 0.9348725527948284]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 173}], {
             RGBColor[
             0.20718172638991203`, 0.3350915088889201, 0.9351100648687836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 186}], {
             RGBColor[
             0.20309625090443267`, 0.3307974151195744, 0.934877403083805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 213}], {
             RGBColor[
             0.20772578685862308`, 0.3356633509369615, 0.9351410483076115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 214}], {
             RGBColor[
             0.20695344714813524`, 0.3348515729320728, 0.9350970647036734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 249}], {
             RGBColor[
             0.21026660117408774`, 0.33833390787944695`, 0.9352857439240791]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 255}], {
             RGBColor[
             0.28954719045708177`, 0.4163676580228129, 0.9399945385263857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 263}], {
             RGBColor[
             0.21148289076359805`, 0.33961230535523634`, 0.9353550098168626]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 265}], {
             RGBColor[
             0.21789617448484386`, 0.3463530731719392, 0.9357202368371844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 276}], {
             RGBColor[
             0.22722517815635135`, 0.3561584475236893, 0.9362515097952526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 286}], {
             RGBColor[
             0.2169836251808333, 0.34539392599445645`, 0.9356682685043168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 177}], {
             RGBColor[
             0.34229360740819775`, 0.46934835455154167`, 0.9430884098094023]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 194}], {
             RGBColor[
             0.539310518839214, 0.6345587760249104, 0.957788184762517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 197}], {
             RGBColor[
             0.689478603616865, 0.751552751257122, 0.9111273992783655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 204}], {
             RGBColor[
             0.4381119186941594, 0.553069802846105, 0.9493643283826801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 210}], {
             RGBColor[
             0.43214727310106515`, 0.5482274348494092, 0.9488947696323751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 226}], {
             RGBColor[
             0.6894363159019072, 0.7515352642002422, 0.911828216152313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 252}], {
             RGBColor[
             0.3152788883487585, 0.44095417198795417`, 0.9415499615236627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 279}], {
             RGBColor[
             0.3146411108912604, 0.44028382744269734`, 0.9415136410409652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 280}], {
             RGBColor[
             0.32731420410911033`, 0.4536040519351767, 0.9422353549515605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 147}], {
             RGBColor[
             0.23746595794531072`, 0.3669221563848262, 0.9368347070543579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 156}], {
             RGBColor[
             0.32801284307365003`, 0.4541649141300481, 0.9422814923217423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 179}], {
             RGBColor[
             0.3921454633437752, 0.5078279411583735, 0.9468889147894293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 191}], {
             RGBColor[
             0.24445543716588297`, 0.3742685422042259, 0.9372327475559615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 217}], {
             RGBColor[
             0.23078620352350526`, 0.3599013109666169, 0.9364543049218471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 247}], {
             RGBColor[
             0.22964528868911577`, 0.358702137137495, 0.9363893315098609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 251}], {
             RGBColor[
             0.27357072658534587`, 0.4048705574000514, 0.9388908202161892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 270}], {
             RGBColor[
             0.23718665422901314`, 0.36662859047011903`, 0.9368188011209075]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 271}], {
             RGBColor[
             0.24208469003989352`, 0.37177673666076144`, 0.9370977370143425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 273}], {
             RGBColor[
             0.25023215692458567`, 0.3803402409358096, 0.9375617232003286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 278}], {
             RGBColor[
             0.23108207251171536`, 0.3602122880324031, 0.9364711542230267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 289}], {
             RGBColor[
             0.25248937634424146`, 0.382712721661845, 0.9376902685070212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 295}], {
             RGBColor[
             0.2292284865221631, 0.35826405163324404`, 0.9363655952430565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 210}], {
             RGBColor[
             0.35148342859896836`, 0.4711989277702072, 0.9440171598227016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 211}], {
             RGBColor[
             0.25101026684268113`, 0.38115808379474614`, 0.9376060354090536]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 231}], {
             RGBColor[
             0.23123426787294182`, 0.3603722550067954, 0.9364798215236958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 266}], {
             RGBColor[
             0.21471877848996196`, 0.3430134285227765, 0.935539288835812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 143}], {
             RGBColor[
             0.37380885559171856`, 0.49802499695333824`, 0.9450460153054621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 163}], {
             RGBColor[
             0.5309367698880918, 0.6297354344441368, 0.9563109238850767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 235}], {
             RGBColor[
             0.42460849977243, 0.5421962738843169, 0.9482766560323135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 273}], {
             RGBColor[
             0.3398266519904991, 0.46230754637230465`, 0.9431107790825377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 274}], {
             RGBColor[
             0.4518848560948061, 0.5655575295786147, 0.9500876676545675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 298}], {
             RGBColor[
             0.350430471977903, 0.4734528335000848, 0.9437146509438744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 162}], {
             RGBColor[
             0.904333638485641, 0.5624086522177772, 0.47863148536736244`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 167}], {
             RGBColor[
             0.862500511580873, 0.40291200775905295`, 0.20439749636787896`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 181}], {
             RGBColor[
             0.9018064820205194, 0.5497777318797257, 0.2827365338887451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 201}], {
             RGBColor[
             0.8313415461919986, 0.24191043475062424`, 0.1776460060696587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 202}], {
             RGBColor[
             0.8419448678170631, 0.3105688491792778, 0.18729684498680563`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 203}], {
             RGBColor[
             0.8772220459314396, 0.5433777884881621, 0.5777664992302363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 216}], {
             RGBColor[
             0.8418913589267707, 0.3103258778057786, 0.18725219585712266`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 237}], {
             RGBColor[
             0.8211968317886982, 0.16393371440465854`, 0.16793141610024187`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 269}], {
             RGBColor[
             0.8952419489497732, 0.5276340204064351, 0.25723456251694715`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 293}], {
             RGBColor[
             0.8585388832387033, 0.3859183975781782, 0.20114329821116103`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 299}], {
             RGBColor[
             0.8180064493920196, 0.1394110372693064, 0.16487630231416095`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 146}], {
             RGBColor[
             0.24693839801171524`, 0.3768782914820059, 0.9373741485029203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 178}], {
             RGBColor[
             0.27642955220691934`, 0.4078753643883386, 0.9390536261060842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 182}], {
             RGBColor[
             0.2740956905180802, 0.4054223277779909, 0.9389207161355438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 188}], {
             RGBColor[
             0.3248560928052687, 0.45441830964122576`, 0.9419709558048517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 236}], {
             RGBColor[
             0.2626393533607303, 0.39338099105188706`, 0.9382682946825648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 261}], {
             RGBColor[
             0.269292107733182, 0.4003734577063236, 0.9386471592022079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 294}], {
             RGBColor[
             0.41494859536709305`, 0.5302055551777425, 0.9483322441534972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 149}], {
             RGBColor[
             0.8627196996396836, 0.42474633719376353`, 0.20540890846687038`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[
             0.8686725031653917, 0.4508599338020208, 0.21032865402022227`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 163}], {
             RGBColor[
             0.7255429896746053, 0.4672102742569026, 0.5698090215965668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 197}], {
             RGBColor[
             0.9081386520820702, 0.6098618084907887, 0.5261581856832962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 198}], {
             RGBColor[
             0.8972633266176216, 0.6021081538364577, 0.5605609698520013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 243}], {
             RGBColor[
             0.9086765502085565, 0.610084243189442, 0.517243821691691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 256}], {
             RGBColor[
             0.8239318482187612, 0.18495624917796497`, 0.17055047092242953`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 277}], {
             RGBColor[
             0.9114733897375824, 0.6092818085693412, 0.32849435906876756`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 163}], {
             RGBColor[
             0.4640224729127619, 0.5716064552084593, 0.95205347173178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 174}], {
             RGBColor[
             0.27004966377854045`, 0.4011696971418227, 0.9386903008982872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 185}], {
             RGBColor[
             0.41822549913320267`, 0.5344264087640556, 0.9484481661960105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 235}], {
             RGBColor[
             0.3576942027971, 0.4840672946486393, 0.9440192038790169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 298}], {
             RGBColor[
             0.28351617500257303`, 0.41532385426440727`, 0.9394571987905778]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 160}], {
             RGBColor[
             0.19670215780285202`, 0.3240768178608952, 0.934513268940883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 176}], {
             RGBColor[
             0.19591627409858087`, 0.32325080425980146`, 0.9344685140265354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 221}], {
             RGBColor[
             0.19191775891044247`, 0.3190481112765624, 0.9342408045018441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 230}], {
             RGBColor[
             0.19486271425090618`, 0.32214344606034284`, 0.9344085153518125]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 231}], {
             RGBColor[
             0.21441031983489064`, 0.34268921891888826`, 0.9355217225717294]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 232}], {
             RGBColor[
             0.19277383312180774`, 0.31994789955094727`, 0.9342895566617331]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 240}], {
             RGBColor[
             0.18908519234139687`, 0.31607090421740214`, 0.9340794940261437]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 245}], {
             RGBColor[
             0.2114412038308669, 0.3395684897458317, 0.9353526358077138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 264}], {
             RGBColor[
             0.24692493102232177`, 0.3768641368222969, 0.9373733815777969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 288}], {
             RGBColor[
             0.20325262345727604`, 0.33096177258720527`, 0.9348863082693568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 297}], {
             RGBColor[
             0.19481653012173772`, 0.32209490361234383`, 0.9344058852339796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 156}], {
             RGBColor[
             0.6296976932681398, 0.7056126711214472, 0.9666670627828757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 159}], {
             RGBColor[
             0.5780723315879956, 0.6592789022873965, 0.963436800696632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 167}], {
             RGBColor[
             0.8862929429929738, 0.7834059474084649, 0.6157767446761826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 168}], {
             RGBColor[
             0.6326576416445393, 0.7081764296337532, 0.9668556680760403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 201}], {
             RGBColor[
             0.8551339776040994, 0.6224043744000362, 0.5890252543779623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 203}], {
             RGBColor[
             0.9010144773435402, 0.923871728137574, 0.9891457475385399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 205}], {
             RGBColor[
             0.6186317877643385, 0.696027939962637, 0.9659619530693695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 216}], {
             RGBColor[
             0.8656837903388712, 0.6908198174551905, 0.5986314441654264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 237}], {
             RGBColor[
             0.8449892632007987, 0.5444276540540705, 0.5793106644085455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 269}], {
             RGBColor[
             0.9190343803618738, 0.908127960055847, 0.6686138108252507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 277}], {
             RGBColor[
             0.9289575250796454, 0.9412874203114796, 0.7338327759362018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 282}], {
             RGBColor[
             0.6527680048201097, 0.7255950154401895, 0.9681370826346918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 293}], {
             RGBColor[
             0.8823313146508039, 0.7664123372275902, 0.6125225465194646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 170}], {
             RGBColor[
             0.19880274533348388`, 0.3262846685405311, 0.9346328942932117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 236}], {
             RGBColor[
             0.2157299800022288, 0.3440762654260479, 0.9355968752659971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 247}], {
             RGBColor[
             0.2055770841992048, 0.33340492820629564`, 0.9350186828698783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 273}], {
             RGBColor[
             0.22616395243467474`, 0.35504303200461024`, 0.9361910745603459]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 289}], {
             RGBColor[
             0.22842117185433053`, 0.35741551273064565`, 0.9363196198670385]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 156}], {
             RGBColor[
             0.32039438822353183`, 0.44615743504463745`, 0.9418476325885221]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 159}], {
             RGBColor[
             0.26876902654338763`, 0.39982366621058674`, 0.9386173705022783]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 168}], {
             RGBColor[
             0.32335433659993124`, 0.4487211935569434, 0.9420362378816867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 191}], {
             RGBColor[
             0.23683698231576478`, 0.36626106311881523`, 0.9367988878227413]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 205}], {
             RGBColor[
             0.3093284827197305, 0.43657270388582725`, 0.9411425228750159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 217}], {
             RGBColor[
             0.22316774867338707`, 0.35189383188120626`, 0.9360204451886269]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 225}], {
             RGBColor[
             0.23694694145511846`, 0.36637663714608804`, 0.9368051498330575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 251}], {
             RGBColor[
             0.26595227173522773`, 0.39686307831464074`, 0.9384569604829689]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 270}], {
             RGBColor[
             0.22956819937889494`, 0.35862111138470837`, 0.9363849413876872]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 271}], {
             RGBColor[
             0.23446623518977533`, 0.3637692575753508, 0.9366638772811222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 278}], {
             RGBColor[
             0.2234636176615972, 0.35220480894699246`, 0.9360372944898065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.3434646997755016, 0.4661397793633797, 0.9433176524403382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 295}], {
             RGBColor[
             0.2216100316720449, 0.3502565725478334, 0.9359317355098362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 150}], {
             RGBColor[
             0.901456610665, 0.644502615181237, 0.23943789960535378`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.9409227595816787, 0.803504489870005, 0.5552674312684278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 198}], {
             RGBColor[
             0.93004743411723, 0.7957508352156739, 0.5896702154371328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 243}], {
             RGBColor[
             0.9414606577081649, 0.8037269245686582, 0.5463530672768225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 256}], {
             RGBColor[
             0.8567159557183694, 0.3785989305571812, 0.19965971650756104`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 277}], {
             RGBColor[
             0.9442574972371908, 0.8029244899485575, 0.3576036046538991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 281}], {
             RGBColor[
             0.9369826909775356, 0.800923138426649, 0.5779306345773171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 179}], {
             RGBColor[
             0.7150830892215184, 0.6470263643951079, 0.5999650595216117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 237}], {
             RGBColor[
             0.8662420388840522, 0.43217832029940567`, 0.20800123867959472`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 256}], {
             RGBColor[
             0.8626687592440776, 0.4047125271654385, 0.20457946206091293`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 269}], {
             RGBColor[
             0.9402871560451271, 0.7958786263011822, 0.2973043850963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 274}], {
             RGBColor[
             0.6852279869066359, 0.622788647378854, 0.5976147565045411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 277}], {
             RGBColor[
             0.9502103007628988, 0.8290380865568148, 0.362523350207251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 281}], {
             RGBColor[
             0.9429354945032435, 0.8270367350349062, 0.582850380130669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 293}], {
             RGBColor[
             0.9035840903340573, 0.6541630034729253, 0.24121312079051388`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 154}], {
             RGBColor[
             0.5475628360948273, 0.6435752036232633, 0.9575252987275946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 181}], {
             RGBColor[
             0.7920610111090953, 0.8249056195457978, 0.6813687144574905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 192}], {
             RGBColor[
             0.4642226762503304, 0.5725842955959759, 0.9518849903358793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 220}], {
             RGBColor[
             0.46545874896093703`, 0.5736549196510825, 0.9519637517959829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 239}], {
             RGBColor[
             0.41770207455751684`, 0.5257103442374987, 0.9491616700514242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 258}], {
             RGBColor[
             0.4689947888884989, 0.5767176597098022, 0.9521890651333698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 208}], {
             RGBColor[
             0.1859180316496269, 0.31274201752076575`, 0.9338991289101417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 242}], {
             RGBColor[
             0.1817008098525566, 0.3083094500247394, 0.9336589643676192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 244}], {
             RGBColor[
             0.1860116480511821, 0.312840414294423, 0.9339044602257174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 268}], {
             RGBColor[
             0.1937845276020504, 0.3210102035314135, 0.9343471142171944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 157}], {
             RGBColor[
             0.2018036290672552, 0.32943878761174283`, 0.9348037901824403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 192}], {
             RGBColor[
             0.2758432306623323, 0.4052369526728678, 0.9390942768006172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 220}], {
             RGBColor[
             0.27707930337293885`, 0.40630757672797435`, 0.9391730382607208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 222}], {
             RGBColor[
             0.2212473690290584, 0.3498753911159149, 0.9359110824088295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 239}], {
             RGBColor[
             0.22932262896951866`, 0.3583630013143907, 0.9363709565161622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 248}], {
             RGBColor[
             0.2215139470361167, 0.3501555815033551, 0.9359262636319645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 285}], {
             RGBColor[
             0.21037441724900163`, 0.3384472294101154, 0.9352918838900459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 181}], {
             RGBColor[
             0.7417957890267707, 0.7840980478369171, 0.6774116520475943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[
             0.7172113529376909, 0.7776981044453534, 0.9724416173890855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 216}], {
             RGBColor[
             0.6818806659330219, 0.5446461937629699, 0.581927314015972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 255}], {
             RGBColor[
             0.43165774296703474`, 0.5471078244024314, 0.9490557746765065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 258}], {
             RGBColor[
             0.4187295668061743, 0.5359100880009214, 0.9482320027234739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 162}], {
             RGBColor[
             0.9588310572734952, 0.8681281277104613, 0.5263067793464253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 194}], {
             RGBColor[
             0.8061596900222359, 0.7500989808439875, 0.6144534337056413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 210}], {
             RGBColor[
             0.698996444284087, 0.6637676396684864, 0.6055600185754992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 218}], {
             RGBColor[
             0.9467517036363646, 0.8603082831521655, 0.5999961337585191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 226}], {
             RGBColor[
             0.9562854870849291, 0.8670754690193194, 0.5684934650954372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 227}], {
             RGBColor[
             0.9395091625151377, 0.7978810172888317, 0.27018585613847523`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 241}], {
             RGBColor[
             0.9562190222247212, 0.8670479840915544, 0.569594959834627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 290}], {
             RGBColor[
             0.9363623874102649, 0.7854051025986525, 0.2676538870247894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 291}], {
             RGBColor[
             0.9265943306289632, 0.845047396157727, 0.6262279650717502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.8725038681798738, 0.44513051276199045`, 0.2125515962932238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 159}], {
             RGBColor[
             0.3428661620319342, 0.4697766941100199, 0.9431273668629003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 168}], {
             RGBColor[
             0.3974514720884778, 0.5186742214563766, 0.9465462342423088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.4586241439822036, 0.5697734899723961, 0.9509650514168311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 191}], {
             RGBColor[
             0.31093411780431135`, 0.4362140910182484, 0.9413088841833633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 205}], {
             RGBColor[
             0.38342561820827703`, 0.5065257317852604, 0.945652519235638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 251}], {
             RGBColor[
             0.3400494072237743, 0.46681610621407393`, 0.942966956843591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 269}], {
             RGBColor[
             0.6838282108058124, 0.7186257518784704, 0.6483043769915192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 270}], {
             RGBColor[
             0.3036653348674415, 0.42857413928414156`, 0.9408949377483093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 271}], {
             RGBColor[
             0.3085633706783219, 0.433722285474784, 0.9411738736417443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 277}], {
             RGBColor[
             0.6937513555235839, 0.7517852121341029, 0.7135233421024703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 282}], {
             RGBColor[
             0.41756183526404816`, 0.5360928072628128, 0.9478276488009602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 171}], {
             RGBColor[
             0.1808430925709541, 0.30740793477935857`, 0.9336101186373109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 184}], {
             RGBColor[
             0.18701393581723674`, 0.31389388228526116`, 0.9339615390312422]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 222}], {
             RGBColor[
             0.20198183109515816`, 0.32962608924173, 0.9348139385243031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 248}], {
             RGBColor[
             0.20224840910221648`, 0.3299062796291701, 0.9348291197474383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 275}], {
             RGBColor[
             0.18135642915031058`, 0.30794748407168115`, 0.9336393523960919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 285}], {
             RGBColor[
             0.1911088793151014, 0.31819792753593046`, 0.9341947400055196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 186}], {
             RGBColor[
             0.19303082310645578`, 0.3202180123189185, 0.9343041918611762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 196}], {
             RGBColor[
             0.1980026870183727, 0.32544375652472224`, 0.9345873321557463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 207}], {
             RGBColor[
             0.189116703595207, 0.3161040245430854, 0.9340812885454315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 212}], {
             RGBColor[
             0.21315714444874106`, 0.34137205213213645`, 0.9354503560873951]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 214}], {
             RGBColor[
             0.19688801935015837`, 0.3242721701314169, 0.9345238534810445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 225}], {
             RGBColor[
             0.21027114178594725`, 0.3383386803504027, 0.9352860025052073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 265}], {
             RGBColor[
             0.20783074668686696`, 0.3357736703712833, 0.9351470256145558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 276}], {
             RGBColor[
             0.21715975035837445`, 0.34557904472303347`, 0.935678298572624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 168}], {
             RGBColor[
             0.3458261104083336, 0.4723404526223259, 0.943315972156065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 191}], {
             RGBColor[
             0.25930875612416715`, 0.38988032218419766`, 0.9380786220971196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 205}], {
             RGBColor[
             0.33180025652813283`, 0.4601919629512097, 0.9424222571493942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 212}], {
             RGBColor[
             0.2623047179263146, 0.3930292679932042, 0.9382492376896236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 225}], {
             RGBColor[
             0.2594187152635208, 0.38999589621147046`, 0.9380848841074358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 251}], {
             RGBColor[
             0.2884240455436301, 0.4204823373800232, 0.9397366947573472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 270}], {
             RGBColor[
             0.2520399731872973, 0.38224037045009085`, 0.9376646756620657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 271}], {
             RGBColor[
             0.2569380089981777, 0.38738851664073326`, 0.9379436115555007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 282}], {
             RGBColor[
             0.36593647358390397`, 0.4897590384287621, 0.9445973867147164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 176}], {
             RGBColor[
             0.19497852177206426`, 0.3222651671077009, 0.9344151104188206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 180}], {
             RGBColor[
             0.19532450559808373`, 0.32262881804548893`, 0.9344348136858753]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 193}], {
             RGBColor[
             0.23766407621559904`, 0.36713039124832314`, 0.9368459895967611]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 221}], {
             RGBColor[
             0.19098000658392586`, 0.31806247412446187`, 0.9341874008941293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 230}], {
             RGBColor[
             0.19392496192438957`, 0.3211578089082423, 0.9343551117440977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 232}], {
             RGBColor[
             0.19183608079529113`, 0.31896226239884673`, 0.9342361530540182]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 245}], {
             RGBColor[
             0.2105034515043503, 0.33858285259373117`, 0.935299232199999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 288}], {
             RGBColor[
             0.20231487113075944`, 0.32997613543510473`, 0.934832904661642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 296}], {
             RGBColor[
             0.1914857715941317, 0.31859406521754197`, 0.9342162034632482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 297}], {
             RGBColor[
             0.1938787777952211, 0.3211092664602433, 0.9343524816262648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 177}], {
             RGBColor[
             0.24681318446187503`, 0.3767466841021262, 0.9373670177764938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 244}], {
             RGBColor[
             0.19557921069497186`, 0.3228965292515542, 0.9344493187643406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 279}], {
             RGBColor[
             0.2191606879449377, 0.34768215699328187`, 0.9357922490080568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 280}], {
             RGBColor[
             0.2318337811627876, 0.36100238148576125`, 0.9365139629186521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 169}], {
             RGBColor[
             0.7980436197485294, 0.8403418316253028, 0.877535691789008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 181}], {
             RGBColor[
             0.9888211205061603, 0.9780593840975029, 0.5971500192561076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 202}], {
             RGBColor[
             0.9289595063027041, 0.738850501397055, 0.5017103303541681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 216}], {
             RGBColor[
             0.9289059974124116, 0.7386075300235558, 0.5016656812244851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 227}], {
             RGBColor[
             0.9720263822129245, 0.9204431940139248, 0.5369240475267748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 228}], {
             RGBColor[
             0.7088026697373979, 0.7671572402491821, 0.8707133358632482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 299}], {
             RGBColor[
             0.9050210878776606, 0.5676926894870836, 0.4792897876815234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 185}], {
             RGBColor[
             0.5753534134295759, 0.6661368462548543, 0.9597130747756251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 235}], {
             RGBColor[
             0.5148221170934733, 0.615777732139438, 0.9552841124586315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 274}], {
             RGBColor[
             0.5420984734158494, 0.6391389878337358, 0.9570951240808855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 292}], {
             RGBColor[
             0.6974329821497556, 0.7632343245346107, 0.9706993881593793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 298}], {
             RGBColor[
             0.44064408929894633`, 0.5470342917552059, 0.9507221073701924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 176}], {
             RGBColor[
             0.1880768897106564, 0.3150111142224146, 0.9340220726829731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 180}], {
             RGBColor[
             0.18842287353667586`, 0.3153747651602027, 0.9340417759500277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 187}], {
             RGBColor[
             0.2033506574299822, 0.3310648125082323, 0.9348918911590742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 221}], {
             RGBColor[
             0.184078374522518, 0.31080842123917557`, 0.9337943631582817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 230}], {
             RGBColor[
             0.1870233298629817, 0.313903756022956, 0.9339620740082502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 296}], {
             RGBColor[
             0.18458413953272382`, 0.31134001233225567`, 0.9338231657274008]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 297}], {
             RGBColor[
             0.18697714573381324`, 0.31385521357495705`, 0.9339594438904173]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 175}], {
             RGBColor[
             0.2002014223302363, 0.3277547667453615, 0.9347125468790196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 183}], {
             RGBColor[
             0.2052672821395783, 0.33307930659904317`, 0.9350010401008936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 224}], {
             RGBColor[
             0.21323098705618415`, 0.3414496653944509, 0.9354545613146487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 253}], {
             RGBColor[
             0.20482209384336109`, 0.3326113854731506, 0.9349756872860211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 262}], {
             RGBColor[
             0.26081704104435255`, 0.39146562526609985`, 0.9381645166920165]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 195}], {
             RGBColor[
             0.184909234384039, 0.31168170763319203`, 0.9338416793982484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 234}], {
             RGBColor[
             0.19012477797807242`, 0.3171635746350845, 0.9341386968902232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.21183524129599424`, 0.3399826481050988, 0.9353750756584267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 285}], {
             RGBColor[
             0.19288702957547718`, 0.3200668762008235, 0.9342960030323104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 168}], {
             RGBColor[
             0.6540467218133117, 0.5964674977433942, 0.5956559161356156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[
             0.8765230577728718, 0.5106954425096772, 0.21782550243753762`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 202}], {
             RGBColor[
             0.8871263793979363, 0.5793538569383307, 0.22747634135468459`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.9224035575123126, 0.8121627962472151, 0.6179459955981152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 216}], {
             RGBColor[
             0.8870728705076437, 0.5791108855648315, 0.22743169222500162`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 237}], {
             RGBColor[
             0.8663783433695712, 0.4327187221637115, 0.20811091246812083`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 269}], {
             RGBColor[
             0.9404234605306463, 0.796419028165488, 0.2974140588848261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 277}], {
             RGBColor[
             0.9503466052484179, 0.8295784884211206, 0.3626330239957771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 282}], {
             RGBColor[
             0.674157084988882, 0.6138860835498305, 0.5969373306942671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 293}], {
             RGBColor[
             0.9037203948195764, 0.6547034053372311, 0.24132279457904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 203}], {
             RGBColor[
             0.6687682561638781, 0.7369332784725033, 0.9690249189979729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 205}], {
             RGBColor[
             0.3863855665846765, 0.5090894902975664, 0.9458411245288025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 212}], {
             RGBColor[
             0.31689002798285826`, 0.4419267953395609, 0.941668105069032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 225}], {
             RGBColor[
             0.31400402532006444`, 0.4388934235578272, 0.9415037514868442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 269}], {
             RGBColor[
             0.6867881591822118, 0.7211895103907764, 0.6484929822846838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 276}], {
             RGBColor[
             0.3208926338924916, 0.4461337879304579, 0.9418960475542608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 282}], {
             RGBColor[
             0.42052178364044757`, 0.5386565657751188, 0.9480162540941248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 293}], {
             RGBColor[
             0.650085093471142, 0.5794738875625195, 0.5924017179788976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 193}], {
             RGBColor[
             0.44215135474031986`, 0.5505814803014513, 0.9506292633518225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 200}], {
             RGBColor[
             0.4851546386974715, 0.5905268621408066, 0.9532706039694929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 202}], {
             RGBColor[
             0.7356548490799517, 0.5885020285868033, 0.5862010514084512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 227}], {
             RGBColor[
             0.7787217249901721, 0.7700947212036731, 0.6214147685810579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 228}], {
             RGBColor[
             0.5154980125146456, 0.6168087674389304, 0.9552040569175313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 264}], {
             RGBColor[
             0.450474457220526, 0.5593295887233245, 0.9511032517251437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 299}], {
             RGBColor[
             0.7117164306549081, 0.41734421667683197`, 0.5637805087358065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 178}], {
             RGBColor[
             0.228293899528688, 0.35728174144686387`, 0.9363123718963757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 182}], {
             RGBColor[
             0.2259600378398488, 0.3548287048365162, 0.9361794619258352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 190}], {
             RGBColor[
             0.2009954787857768, 0.3285893704262217, 0.9347577672194614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 199}], {
             RGBColor[
             0.19798561422584082`, 0.3254258119372937, 0.9345863598854686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 261}], {
             RGBColor[
             0.22115645505495063`, 0.3497798347648488, 0.9359059049924991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 284}], {
             RGBColor[
             0.2192670906414149, 0.34779399297360003`, 0.9357983084842125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 184}], {
             RGBColor[
             0.1853189372548359, 0.31211233132706184`, 0.9338650113706392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 275}], {
             RGBColor[
             0.17966143058790973`, 0.3061659331134819, 0.9335428247354888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 285}], {
             RGBColor[
             0.18941388075270052`, 0.31641637657773114`, 0.9340982123449165]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 174}], {
             RGBColor[
             0.21189442021644855`, 0.34004484890265657`, 0.9353784458103991]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 238}], {
             RGBColor[
             0.18901379750666059`, 0.31599586371940025`, 0.9340754281959247]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 186}], {
             RGBColor[
             0.19720146830174806`, 0.32460162485334904`, 0.9345417039351314]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 213}], {
             RGBColor[
             0.20183100425593847`, 0.3294675606707361, 0.9348053491589379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 234}], {
             RGBColor[
             0.19772105404463286`, 0.3251477424127598, 0.9345712935745305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 249}], {
             RGBColor[
             0.20437181857140313`, 0.33213811761322165`, 0.9349500447754056]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 263}], {
             RGBColor[
             0.20558810816091344`, 0.33341651508901093`, 0.935019310668189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 286}], {
             RGBColor[
             0.2110888425781487, 0.3391981357282311, 0.9353325693556434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 235}], {
             RGBColor[
             0.3208493079592518, 0.4453409740728014, 0.9419209416251387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 238}], {
             RGBColor[
             0.21032414623090429`, 0.3383943913827284, 0.9352890210299346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 298}], {
             RGBColor[
             0.24667128016472487`, 0.3765975336885693, 0.9373589365366997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 183}], {
             RGBColor[
             0.18767445593923526`, 0.3145881308128762, 0.9339991546750381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 224}], {
             RGBColor[
             0.19563816085584113`, 0.3229584896082839, 0.9344526758887932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 253}], {
             RGBColor[
             0.18722926764301806`, 0.3141202096869836, 0.9339738018601655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 180}], {
             RGBColor[
             0.1945386218938126, 0.32180280444439524`, 0.9343900587715277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 187}], {
             RGBColor[
             0.20946640578711895`, 0.33749285179242483`, 0.9352401739805742]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 193}], {
             RGBColor[
             0.23687819251132788`, 0.36630437764722934`, 0.9368012346824135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 221}], {
             RGBColor[
             0.1901941228796547, 0.3172364605233681, 0.9341426459797817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 230}], {
             RGBColor[
             0.19313907822011844`, 0.32033179530714856`, 0.9343103568297502]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 245}], {
             RGBColor[
             0.20971756780007914`, 0.3377568389926374, 0.9352544772856515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 288}], {
             RGBColor[
             0.20152898742648828`, 0.32915012183401104`, 0.9347881497472945]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 296}], {
             RGBColor[
             0.19069988788986053`, 0.3177680516164482, 0.9341714485489008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 297}], {
             RGBColor[
             0.19309289409094996`, 0.3202832528591496, 0.9343077267119173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 194}], {
             RGBColor[
             0.4889886310377472, 0.5894215892292383, 0.9546385045000421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 226}], {
             RGBColor[
             0.6391144281004404, 0.7063980774045702, 0.908678535889838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 252}], {
             RGBColor[
             0.2649570005472917, 0.39581698519228203`, 0.9384002812611878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 268}], {
             RGBColor[
             0.24851062539069607`, 0.37853080214228807`, 0.9374636845262513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 279}], {
             RGBColor[
             0.2643192230897936, 0.3951466406470252, 0.9383639607784904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 280}], {
             RGBColor[
             0.27699231630764354`, 0.4084668651395046, 0.9390856746890857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 182}], {
             RGBColor[
             0.2566774713547828, 0.3871146750584845, 0.9379287743221401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 190}], {
             RGBColor[
             0.23171291230071078`, 0.36087534064819005`, 0.9365070796157662]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 199}], {
             RGBColor[
             0.2287030477407748, 0.357711782159262, 0.9363356722817735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 229}], {
             RGBColor[
             0.23836184028178953`, 0.36786378552268634`, 0.9368857262280812]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 261}], {
             RGBColor[
             0.2518738885698846, 0.38206580498681714`, 0.9376552173888041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 284}], {
             RGBColor[
             0.24998452415634886`, 0.38007996319556836`, 0.9375476208805174]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 205}], {
             RGBColor[
             0.44755823847840226`, 0.5601887588135859, 0.9502599417033248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 251}], {
             RGBColor[
             0.4041820274938994, 0.5204791332423994, 0.9475743793112779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 269}], {
             RGBColor[
             0.7479608310759376, 0.7722887789067958, 0.6529117994592061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 274}], {
             RGBColor[
             0.4929016619374462, 0.5991987999844676, 0.9532221708674471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 277}], {
             RGBColor[
             0.7578839757937091, 0.8054482391624284, 0.7181307645701571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 282}], {
             RGBColor[
             0.48169445553417334`, 0.5897558342911382, 0.9524350712686471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 289}], {
             RGBColor[
             0.383100677252795, 0.49832129750419296`, 0.9463738276021099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 187}], {
             RGBColor[
             0.20981238961313842`, 0.3378565027302129, 0.9352598772476289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 193}], {
             RGBColor[
             0.23722417633734735`, 0.3666680285850174, 0.9368209379494682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 215}], {
             RGBColor[
             0.2098131605219987, 0.33785731300430355`, 0.9352599211497481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 221}], {
             RGBColor[
             0.19054010670567417`, 0.3176001114611562, 0.9341623492468364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 230}], {
             RGBColor[
             0.1934850620461379, 0.3206954462449366, 0.9343300600968047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 233}], {
             RGBColor[
             0.20014010875548707`, 0.32769032229079487`, 0.9347090551616429]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 245}], {
             RGBColor[
             0.2100635516260986, 0.3381204899304254, 0.9352741805527061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 288}], {
             RGBColor[
             0.20187497125250775`, 0.32951377277179905`, 0.9348078530143491]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 296}], {
             RGBColor[
             0.19104587171588, 0.3181317025542363, 0.9341911518159554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 297}], {
             RGBColor[
             0.19343887791696943`, 0.3206469037969376, 0.9343274299789719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 201}], {
             RGBColor[
             0.9158290282125181, 0.65756116663035, 0.29616453995840375`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 202}], {
             RGBColor[
             0.9264323498375825, 0.7262195810590035, 0.3058153788755507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 203}], {
             RGBColor[
             0.961709527951959, 0.9590285203678879, 0.6962850331189814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 216}], {
             RGBColor[
             0.92637884094729, 0.7259766096855043, 0.3057707297458678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 227}], {
             RGBColor[
             0.9694992257478029, 0.9078122736758734, 0.34102909604815745`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 258}], {
             RGBColor[
             0.6632277418204424, 0.717240503923456, 0.6720754184533696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 299}], {
             RGBColor[
             0.9024939314125389, 0.5550617691490322, 0.28339483620290606`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 190}], {
             RGBColor[
             0.22937905061187158`, 0.35842230403784237`, 0.9363741696452258]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 199}], {
             RGBColor[
             0.22636918605193562`, 0.35525874554891435`, 0.936202762311233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 229}], {
             RGBColor[
             0.23602797859295035`, 0.36541074891233866`, 0.9367528162575407]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 261}], {
             RGBColor[
             0.24954002688104543`, 0.37961276837646946`, 0.9375223074182637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 284}], {
             RGBColor[
             0.24765066246750966`, 0.3776269265852207, 0.937414710909977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 224}], {
             RGBColor[
             0.2007040206651831, 0.3282830294619655, 0.9347411691106672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 253}], {
             RGBColor[
             0.19229512745236005`, 0.31944474954066526`, 0.9342622950820396]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 222}], {
             RGBColor[
             0.2064576757790399, 0.33433048578943325`, 0.9350688312576314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 224}], {
             RGBColor[
             0.20007875304145373`, 0.32762583354516883`, 0.9347055610444963]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 248}], {
             RGBColor[
             0.20672425378609824`, 0.33461067617687346`, 0.9350840124807664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 275}], {
             RGBColor[
             0.18583227383419235`, 0.31265188061938454`, 0.9338942451294201]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 218}], {
             RGBColor[
             0.7483730046735189, 0.8020037075647066, 0.948265724399384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 235}], {
             RGBColor[
             0.4690251433139141, 0.5785976856950342, 0.951678806922862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 262}], {
             RGBColor[
             0.41669813660407123`, 0.5328210539055609, 0.9483611851595068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 292}], {
             RGBColor[
             0.6516360083701964, 0.726054278090207, 0.9670940826236099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 196}], {
             RGBColor[
             0.19808785672818557`, 0.32553327528980713`, 0.9345921824447229]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 214}], {
             RGBColor[
             0.19697318905997124`, 0.32436168889650174`, 0.9345287037700212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 249}], {
             RGBColor[
             0.20028634308592377`, 0.3278440238438759, 0.934717382990427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 265}], {
             RGBColor[
             0.2079159163966799, 0.33586318913636815`, 0.9351518759035322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 286}], {
             RGBColor[
             0.2070033670926693, 0.3349040419588854, 0.9350999075706646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 193}], {
             RGBColor[
             0.25215196023065367`, 0.38235807593304705`, 0.9376710531585147]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 215}], {
             RGBColor[
             0.224740944415305, 0.35354736035233314`, 0.9361100363587946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 228}], {
             RGBColor[
             0.32549861800497937`, 0.4485853630705261, 0.9422458467242234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 229}], {
             RGBColor[
             0.22122626051320093`, 0.3498532047273915, 0.9359098803100787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 230}], {
             RGBColor[
             0.20841284593944426`, 0.3363854935929662, 0.9351801753058513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 233}], {
             RGBColor[
             0.2150678926487934, 0.3433803696388245, 0.9355591703706895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 245}], {
             RGBColor[
             0.22499133551940492`, 0.35381053727845513`, 0.9361242957617526]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 288}], {
             RGBColor[
             0.2168027551458141, 0.3452038201198287, 0.9356579682233956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 296}], {
             RGBColor[
             0.20597365560918635`, 0.3338217499022659, 0.9350412670250019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 297}], {
             RGBColor[
             0.20836666181027574`, 0.33633695114496726`, 0.9351775451880184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 236}], {
             RGBColor[
             0.29364767479578224`, 0.42161628358526776`, 0.9401936825679285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 260}], {
             RGBColor[
             0.3070159863730502, 0.43566722665288543`, 0.9409549881356092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 261}], {
             RGBColor[
             0.30030042916823396`, 0.42860875023970424`, 0.9405725470875715]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 281}], {
             RGBColor[
             0.66716299452805, 0.7330554302274623, 0.9326197293964239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 294}], {
             RGBColor[
             0.445956916802145, 0.5584408477111231, 0.9502576320388609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 257}], {
             RGBColor[
             0.1999558217805158, 0.327496624995631, 0.9346985602910465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 260}], {
             RGBColor[
             0.23700170640282697`, 0.36643419857842796`, 0.936808268615812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 267}], {
             RGBColor[
             0.20602096440657885`, 0.33387147444787646`, 0.9350439611910263]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 287}], {
             RGBColor[
             0.22941840696730975`, 0.35846367006274493`, 0.9363764109314454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 300}], {
             RGBColor[
             0.22074088939765935`, 0.34934304891065115`, 0.9358822391430908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 199}], {
             RGBColor[
             0.2014046269978636, 0.3290194111386199, 0.9347810676048591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 261}], {
             RGBColor[
             0.2245754678269734, 0.353373433966175, 0.9361006127118898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 284}], {
             RGBColor[
             0.22268610341343767`, 0.3513875921749262, 0.9359930162036031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 205}], {
             RGBColor[
             0.29986821230051, 0.4266293598594382, 0.9406037744698572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 217}], {
             RGBColor[
             0.21370747825416658`, 0.3419504878548173, 0.9354816967834682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 225}], {
             RGBColor[
             0.22748667103589795`, 0.35643329311969896`, 0.9362664014278987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 246}], {
             RGBColor[
             0.2059132617802264, 0.3337582721588391, 0.9350378276857872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 251}], {
             RGBColor[
             0.25649200131600725`, 0.38691973428825177`, 0.9379182120778102]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 270}], {
             RGBColor[
             0.22010792895967446`, 0.34867776735831935`, 0.9358461929825286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 271}], {
             RGBColor[
             0.22500596477055484`, 0.35382591354896176`, 0.9361251288759636]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 278}], {
             RGBColor[
             0.21400334724237668`, 0.34226146492060344`, 0.9354985460846478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 282}], {
             RGBColor[
             0.3340044293562811, 0.4561964353369906, 0.9427789040351794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 295}], {
             RGBColor[
             0.21214976125282442`, 0.34031322852144436`, 0.9353929871046776]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 218}], {
             RGBColor[
             0.6489034320102649, 0.7179182155893853, 0.9413556495465901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 220}], {
             RGBColor[
             0.3318533670341157, 0.4618564399149144, 0.9423663809943715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 222}], {
             RGBColor[
             0.2760214326902352, 0.40542425430285495`, 0.93910442514248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 248}], {
             RGBColor[
             0.27628801069729353`, 0.4057044446902951, 0.9391196063656152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 262}], {
             RGBColor[
             0.31722856394081744`, 0.4487355619302395, 0.9414511103067129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 200}], {
             RGBColor[
             0.3225670309120143, 0.4511149836272068, 0.9418734544780243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 215}], {
             RGBColor[
             0.252152731139514, 0.38235888620713765`, 0.9376710970606339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 228}], {
             RGBColor[
             0.35291040472918833`, 0.4773968889253306, 0.9438069074260627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 230}], {
             RGBColor[
             0.2358246326636532, 0.3651970194477707, 0.9367412360076905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 245}], {
             RGBColor[
             0.2524031222436139, 0.38262206313325964`, 0.9376853564635919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 264}], {
             RGBColor[
             0.28788684943506876`, 0.4199177102097248, 0.939706102233675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 288}], {
             RGBColor[
             0.24421454187002306`, 0.3740153459746332, 0.9372190289252349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 210}], {
             RGBColor[
             0.5788422967306146, 0.6683006695271059, 0.9604448643230148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 226}], {
             RGBColor[
             0.8361313395314567, 0.8716084988779389, 0.9233783108429527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 241}], {
             RGBColor[
             0.8360648746712487, 0.8715810139501738, 0.9244798055821426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 280}], {
             RGBColor[
             0.4740092277386598, 0.5736772866128733, 0.9537854496422005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 290}], {
             RGBColor[
             0.8162082398567924, 0.7899381324572718, 0.622538732772305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 291}], {
             RGBColor[
             0.8064401830754907, 0.8495804260163464, 0.9811128108192658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 234}], {
             RGBColor[
             0.18893962070800485`, 0.3159178992009325, 0.934071203936976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 207}], {
             RGBColor[
             0.19417373721693681`, 0.32141928751397403`, 0.9343692791289782]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 212}], {
             RGBColor[
             0.2182141780704709, 0.3466873151030251, 0.9357383466709418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 214}], {
             RGBColor[
             0.20194505297188817`, 0.32958743310230554`, 0.9348118440645912]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 225}], {
             RGBColor[
             0.21532817540767707`, 0.3436539433212913, 0.935573993088754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 265}], {
             RGBColor[
             0.21288778030859679`, 0.34108893334217194`, 0.9354350161981024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 276}], {
             RGBColor[
             0.22221678398010425`, 0.35089430769392205`, 0.9359662891561706]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 198}], {
             RGBColor[
             0.9754663865596167, 0.9808663065126991, 0.9104194926535587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 204}], {
             RGBColor[
             0.7349750271013598, 0.7901370127560131, 0.9142536375891683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 226}], {
             RGBColor[
             0.9862994243091077, 0.9886024741101505, 0.8767175253588012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 243}], {
             RGBColor[
             0.9868796101505515, 0.9888423958656835, 0.8671023444932484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 254}], {
             RGBColor[
             0.6525617744919028, 0.7195772493628625, 0.9087750915707931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 283}], {
             RGBColor[
             0.646081244426157, 0.713693683071829, 0.9083720606763512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 204}], {
             RGBColor[
             0.7240997016369111, 0.7823833581016821, 0.9486564217578735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 226}], {
             RGBColor[
             0.975424098844659, 0.9808488194558194, 0.9111203095275062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 243}], {
             RGBColor[
             0.9760042846861029, 0.9810887412113525, 0.9015051286619535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 254}], {
             RGBColor[
             0.6416864490274542, 0.7118235947085315, 0.9431778757394982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 256}], {
             RGBColor[
             0.8912595826963075, 0.5559607471998754, 0.554811777892692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 283}], {
             RGBColor[
             0.6352059189617083, 0.705940028417498, 0.9427748448450561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 209}], {
             RGBColor[
             0.1894252090832627, 0.31642828337140966`, 0.9340988574765833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 229}], {
             RGBColor[
             0.20805355497894237`, 0.33600785601311617`, 0.9351597142171741]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 233}], {
             RGBColor[
             0.20189518711453486`, 0.32953502092454917`, 0.9348090042777849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 259}], {
             RGBColor[
             0.19177802866162308`, 0.31890124592564373`, 0.9342328470708863]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 261}], {
             RGBColor[
             0.22156560326703745`, 0.35020987547724697`, 0.9359292053778969]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 284}], {
             RGBColor[
             0.21967623885350168`, 0.3482240336859982, 0.9358216088696103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 210}], {
             RGBColor[
             0.4186246829308158, 0.5365148469090834, 0.9480331221442837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 211}], {
             RGBColor[
             0.31815152117452855`, 0.44647400293362227`, 0.9416219977306357]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 227}], {
             RGBColor[
             0.6591374011618665, 0.6706282245294286, 0.6126589597072597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 228}], {
             RGBColor[
             0.3959136886863399, 0.5173422707646859, 0.946448248043733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 231}], {
             RGBColor[
             0.2983755222047893, 0.4256881741456715, 0.9404957838452779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 245}], {
             RGBColor[
             0.2954064062007655, 0.4225674449726149, 0.9403266970812623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 264}], {
             RGBColor[
             0.3308901333922204, 0.45986309204908005`, 0.9423474428513454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 202}], {
             RGBColor[
             0.8559674140090618, 0.41835228392990204`, 0.20072485105646432`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 203}], {
             RGBColor[
             0.8912445921234382, 0.6511612232387863, 0.591194505299895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 216}], {
             RGBColor[
             0.8559139051187693, 0.4181093125564028, 0.20068020192678135`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 237}], {
             RGBColor[
             0.8352193779806968, 0.2717171491552828, 0.18135942216990056`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 269}], {
             RGBColor[
             0.9092644951417719, 0.6354174551570593, 0.2706625685866058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 277}], {
             RGBColor[
             0.9191876398595434, 0.6685769154126919, 0.3358815336975568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 293}], {
             RGBColor[
             0.872561429430702, 0.49370183232880244`, 0.21457130428081972`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 299}], {
             RGBColor[
             0.8320289955840182, 0.24719447201993064`, 0.1783043083838196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 203}], {
             RGBColor[
             0.9018479137485027, 0.71981963766744, 0.6008453442170419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 216}], {
             RGBColor[
             0.8665172267438337, 0.4867677269850564, 0.21033104084392829`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 237}], {
             RGBColor[
             0.8458226996057612, 0.34037556358393634`, 0.1910102610870475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 269}], {
             RGBColor[
             0.9198678167668363, 0.7040758695857129, 0.2803134075037528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 293}], {
             RGBColor[
             0.8831647510557664, 0.562360246757456, 0.22422214319796666`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 299}], {
             RGBColor[
             0.8426323172090826, 0.3158528864485842, 0.18795514730096657`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 216}], {
             RGBColor[
             0.9017944048582103, 0.7195766662939407, 0.600800695087359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 237}], {
             RGBColor[
             0.8810998777201378, 0.5731845028928206, 0.5814799153304782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 255}], {
             RGBColor[
             0.651571481892223, 0.7220382969334023, 0.9679291557478935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 269}], {
             RGBColor[
             0.9551449948812127, 0.9368848088945971, 0.6707830617471834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 293}], {
             RGBColor[
             0.9184419291701429, 0.7951691860663403, 0.6146917974413972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 299}], {
             RGBColor[
             0.8779094953234592, 0.5486618257574685, 0.5784248015443972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 226}], {
             RGBColor[
             0.734932739386402, 0.7901195256991334, 0.9149544544631159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 243}], {
             RGBColor[
             0.7355129252278461, 0.7903594474546665, 0.9053392735975632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 254}], {
             RGBColor[
             0.40119508956919725`, 0.5210943009518455, 0.9470120206751078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 283}], {
             RGBColor[
             0.3947145595034514, 0.515210734660812, 0.9466089897806659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 225}], {
             RGBColor[
             0.29997817143986366`, 0.426744933886711, 0.9406100364801734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 251}], {
             RGBColor[
             0.3289835017199729, 0.45723137505526373`, 0.9422618471300848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 269}], {
             RGBColor[
             0.6727623053020111, 0.7090410207196602, 0.647599267278013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 282}], {
             RGBColor[
             0.40649592976024684`, 0.5265080761040026, 0.947122539087454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 219}], {
             RGBColor[
             0.20337837440800324`, 0.33109394480949034`, 0.9348934695999689]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 254}], {
             RGBColor[
             0.27060222090313846`, 0.400822588016517, 0.9387557425033809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 283}], {
             RGBColor[
             0.26412169083739256`, 0.3949390217254835, 0.938352711608939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 212}], {
             RGBColor[
             0.20932819464730518`, 0.33734758312138824`, 0.935232303060627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 214}], {
             RGBColor[
             0.19305906954872248`, 0.3202477011206687, 0.9343058004542764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 225}], {
             RGBColor[
             0.20644219198451136`, 0.33431421133965444`, 0.9350679494784392]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 242}], {
             RGBColor[
             0.18509931747274389`, 0.3118814970113848, 0.9338525043489474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 244}], {
             RGBColor[
             0.18941015567136937`, 0.31641246128106837`, 0.9340980002070455]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 252}], {
             RGBColor[
             0.21362941037883332`, 0.3418684335680528, 0.935477250933459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 268}], {
             RGBColor[
             0.19718303522223768`, 0.3245822505180589, 0.9345406541985226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 279}], {
             RGBColor[
             0.21299163292133522`, 0.34119808902279597`, 0.9354409304507616]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 259}], {
             RGBColor[
             0.18280847530695815`, 0.30947367664736153`, 0.9337220442766032]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 211}], {
             RGBColor[
             0.3712058892361785, 0.49192848437614356`, 0.9451403247792249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 226}], {
             RGBColor[
             0.7289680937933078, 0.7852771577024377, 0.9144848957128108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 227}], {
             RGBColor[
             0.7121917692235163, 0.7160827059719499, 0.6161772867558488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 241}], {
             RGBColor[
             0.7289016289330998, 0.7852496727746727, 0.9155863904520005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 290}], {
             RGBColor[
             0.7090449941186435, 0.7036067912817707, 0.613645317642163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 291}], {
             RGBColor[
             0.6992769373373419, 0.7632490848408453, 0.9722193956891239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 231}], {
             RGBColor[
             0.25095672851015194`, 0.3811018116127316, 0.937602986480219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 264}], {
             RGBColor[
             0.28347133969758304`, 0.41527672951614025`, 0.9394546454862865]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 266}], {
             RGBColor[
             0.23444123912717205`, 0.36374298512871284`, 0.9366624537923354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 214}], {
             RGBColor[
             0.21709951040225656`, 0.3455157287097197, 0.9356748679962401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 225}], {
             RGBColor[
             0.23048263283804543`, 0.3595822389287055, 0.9364370170204028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 265}], {
             RGBColor[
             0.22804223773896515`, 0.3570172289495861, 0.9362980401297512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 276}], {
             RGBColor[
             0.23737124141047264`, 0.3668226033013362, 0.9368293130878194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 234}], {
             RGBColor[
             0.19826511451334394`, 0.3257195844608012, 0.9346022770133582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 249}], {
             RGBColor[
             0.2049158790401142, 0.33270995966126304`, 0.9349810282142335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 263}], {
             RGBColor[
             0.2061321686296245, 0.3339883571370523, 0.9350502941070169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 286}], {
             RGBColor[
             0.21163290304685975`, 0.3397699777762725, 0.935363552794471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 265}], {
             RGBColor[
             0.21177311264038245`, 0.33991734694886655`, 0.9353715375234006]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 276}], {
             RGBColor[
             0.22110211631188992`, 0.34972272130061666`, 0.9359028104814688]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 286}], {
             RGBColor[
             0.21086056333637188`, 0.3389581997713838, 0.9353195691905329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 229}], {
             RGBColor[
             0.2212270314220612, 0.34985401500148217`, 0.9359099242121978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 233}], {
             RGBColor[
             0.2150686635576537, 0.34338117991291517`, 0.9355592142728086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 259}], {
             RGBColor[
             0.20495150510474192`, 0.33274740491400967`, 0.9349830570659099]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 296}], {
             RGBColor[
             0.20597442651804665`, 0.33382256017635653`, 0.935041310927121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 237}], {
             RGBColor[
             0.8457691907154687, 0.3401325922104371, 0.19096561195736456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 269}], {
             RGBColor[
             0.9198143078765437, 0.7038328982122137, 0.28026875837406984`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 293}], {
             RGBColor[
             0.8831112421654739, 0.5621172753839567, 0.2241774940682837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 299}], {
             RGBColor[
             0.8425788083187902, 0.31560991507508496`, 0.1879104981712836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 223}], {
             RGBColor[
             0.19076430807847547`, 0.31783576131915836`, 0.9341751171833412]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 246}], {
             RGBColor[
             0.1922440281378487, 0.31939104092123016`, 0.9342593850516728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 247}], {
             RGBColor[
             0.19889732977739935`, 0.3263840827880864, 0.9346382807373675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 251}], {
             RGBColor[
             0.24282276767362948`, 0.3725525030506428, 0.9371397694436958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 270}], {
             RGBColor[
             0.20643869531729672`, 0.3343105361207104, 0.9350677503484142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 271}], {
             RGBColor[
             0.21133673112817714`, 0.3394586823113528, 0.9353466862418491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 278}], {
             RGBColor[
             0.20033411359999898`, 0.32789423368299453`, 0.9347201034505334]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 295}], {
             RGBColor[
             0.19848052761044668`, 0.32594599728383544`, 0.9346145444705631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 220}], {
             RGBColor[
             0.6501395047208716, 0.7189888396444919, 0.9414344110066938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 262}], {
             RGBColor[
             0.6355147016275733, 0.7058679616598169, 0.9405191403190352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 290}], {
             RGBColor[
             0.956800253470921, 0.9001474347654498, 0.6080814328251828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 292}], {
             RGBColor[
             0.8704525733936984, 0.8991011858444631, 0.9592520377831382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 250}], {
             RGBColor[
             0.1834940050025886, 0.3101942118225623, 0.933761084178619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 222}], {
             RGBColor[
             0.2772575054008418, 0.4064948783579615, 0.9391831866025837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 248}], {
             RGBColor[
             0.27752408340790014`, 0.40677506874540165`, 0.9391983678257189]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 262}], {
             RGBColor[
             0.318464636651424, 0.44980618598534605`, 0.9415298717668166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 230}], {
             RGBColor[
             0.18914056303198, 0.3161291023239095, 0.9340826473050587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 232}], {
             RGBColor[
             0.18705168190288157`, 0.31393355581451393`, 0.9339636886149794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 245}], {
             RGBColor[
             0.20571905261194073`, 0.33355414600939837`, 0.93502676776096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 288}], {
             RGBColor[
             0.19753047223834988`, 0.324947428850772, 0.9345604402226031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 296}], {
             RGBColor[
             0.18670137270172213`, 0.31356535863320917`, 0.9339437390242094]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 297}], {
             RGBColor[
             0.18909437890281156`, 0.31608055987591055`, 0.9340800171872259]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 248}], {
             RGBColor[
             0.22169214906401963`, 0.3503428831333422, 0.9359364119738274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 285}], {
             RGBColor[
             0.21055261927690455`, 0.33863453104010255`, 0.9353020322319088]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 246}], {
             RGBColor[
             0.1829700916045353, 0.3096435456231802, 0.9337312480856603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 247}], {
             RGBColor[
             0.18962339324408597`, 0.3166365874900364, 0.934110143771355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 270}], {
             RGBColor[
             0.19716475878398335`, 0.32456304082266046`, 0.9345396133824015]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 271}], {
             RGBColor[
             0.20206279459486376`, 0.3297111870133029, 0.9348185492758365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 278}], {
             RGBColor[
             0.1910601770666856, 0.31814673838494456`, 0.9341919664845209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 295}], {
             RGBColor[
             0.1892065910771333, 0.3161985019857855, 0.9340864075045505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 253}], {
             RGBColor[
             0.20025883236896588`, 0.32781510833607297`, 0.9347158162957947]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 262}], {
             RGBColor[
             0.2562537795699573, 0.3866693481290222, 0.9379046457017901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 265}], {
             RGBColor[
             0.22515623507617133`, 0.35398385716785236`, 0.9361336865475633]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 276}], {
             RGBColor[
             0.23448523874767882`, 0.3637892315196025, 0.9366649595056316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 241}], {
             RGBColor[
             0.9861906717339419, 0.9885575021255057, 0.8785198369719385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 243}], {
             RGBColor[
             0.9868373224355939, 0.9888249088088037, 0.8678031613671959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 290}], {
             RGBColor[
             0.9663340369194856, 0.9069146206326038, 0.576578764162101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 291}], {
             RGBColor[
             0.956565980138184, 0.9665569141916783, 0.9351528422090618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 241}], {
             RGBColor[
             0.9694143471641505, 0.9193630503950179, 0.5802122280149764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 290}], {
             RGBColor[
             0.9495577123496941, 0.837720168902116, 0.27827115520513895`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 291}], {
             RGBColor[
             0.9397896555683924, 0.8973624624611904, 0.6368452332520997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 299}], {
             RGBColor[
             0.885699193119303, 0.49744557906545395`, 0.22316886447357331`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 264}], {
             RGBColor[
             0.3612335072093944, 0.48614499734720384`, 0.9442808957993838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 233}], {
             RGBColor[
             0.2115539796555496, 0.3396870242879735, 0.9353590582240927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 259}], {
             RGBColor[
             0.2014368212026378, 0.32905324928906804`, 0.934782901017194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 284}], {
             RGBColor[
             0.22933503139451644`, 0.3583760370494225, 0.936371662815918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 245}], {
             RGBColor[
             0.20866400795240445`, 0.3366494807931788, 0.9351944786109285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 288}], {
             RGBColor[
             0.2004754275788136, 0.3280427636345524, 0.9347281510725716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 296}], {
             RGBColor[
             0.18964632804218584`, 0.3166606934169896, 0.9341114498741778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 297}], {
             RGBColor[
             0.19203933424327527`, 0.319175894659691, 0.9342477280371944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 232}], {
             RGBColor[
             0.20954424282732975`, 0.33757466345683984`, 0.9352446066848648]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 245}], {
             RGBColor[
             0.2282116135363889, 0.3571952536517242, 0.9363076858308454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 264}], {
             RGBColor[
             0.2636953407278438, 0.39449090072818943`, 0.9383284316009286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 266}], {
             RGBColor[
             0.21466524015743277`, 0.342957156340762, 0.9355362399069774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 240}], {
             RGBColor[
             0.184219115333836, 0.3109563487553536, 0.933802378139279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 245}], {
             RGBColor[
             0.206575126823306, 0.3344539342837832, 0.9350755199208491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 288}], {
             RGBColor[
             0.19838654644971515`, 0.32584721712515685`, 0.9346091923824922]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 297}], {
             RGBColor[
             0.18995045311417683`, 0.3169803481502954, 0.934128769347115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 259}], {
             RGBColor[
             0.1952784533382303, 0.32258041420050104`, 0.9344321910778048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[
             0.2158656276199601, 0.3442188396728392, 0.9356046001971543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 249}], {
             RGBColor[
             0.2008059288288086, 0.3283901414032867, 0.934746972629826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 263}], {
             RGBColor[
             0.20202221841831886`, 0.32966853887907605`, 0.9348162385226094]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 274}], {
             RGBColor[
             0.43577020330018756`, 0.5515998272739158, 0.9490608562281224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 298}], {
             RGBColor[
             0.33431581918328446`, 0.4594951311953859, 0.9426878395174293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 260}], {
             RGBColor[
             0.2447992469285118, 0.3746299080635468, 0.9372523270133223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 267}], {
             RGBColor[
             0.21381850493226368`, 0.3420671839329953, 0.9354880195885366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 294}], {
             RGBColor[
             0.38374017735760657`, 0.49740352912178454`, 0.9465549709165739]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 256}], {
             RGBColor[
             0.8215013839374217, 0.16627463567534986`, 0.16822305558180195`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 269}], {
             RGBColor[
             0.8991197807384712, 0.5574407348110937, 0.260947978617189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 277}], {
             RGBColor[
             0.9090429254562429, 0.5906001950667261, 0.32616694372814004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 281}], {
             RGBColor[
             0.9017681191965876, 0.5885988435448176, 0.546493973651558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 293}], {
             RGBColor[
             0.8624167150274014, 0.41572511198283674`, 0.2048567143114029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 248}], {
             RGBColor[
             0.22976740900447992`, 0.35883049333181793`, 0.9363962860811601]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 258}], {
             RGBColor[
             0.28886880526886394`, 0.4180452286151569, 0.9398683740473033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 263}], {
             RGBColor[
             0.22373268173624067`, 0.3524876123490904, 0.9360526172908128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 285}], {
             RGBColor[
             0.21862787921736482`, 0.3471221412385783, 0.9357619063392415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 290}], {
             RGBColor[
             0.9662675720592777, 0.9068871357048387, 0.5776802589012907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 291}], {
             RGBColor[
             0.956499515277976, 0.9665294292639133, 0.9362543369482514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 250}], {
             RGBColor[
             0.18176798085569046`, 0.30838005100792065`, 0.933662789656877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 268}], {
             RGBColor[
             0.1929658134251674, 0.3201496830220325, 0.934300489656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 254}], {
             RGBColor[
             0.6530996726183891, 0.7197996840615158, 0.8998607275791879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 256}], {
             RGBColor[
             0.9026728062872424, 0.5639368365528598, 0.5114946297323817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 283}], {
             RGBColor[
             0.6466191425526432, 0.7139161177704824, 0.899457696684746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 279}], {
             RGBColor[
             0.21308524932289044`, 0.3412964857964532, 0.9354462617663373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 280}], {
             RGBColor[
             0.22575834254074034`, 0.3546167102889326, 0.9361679756769326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 264}], {
             RGBColor[
             0.26072622472382, 0.3913701715551329, 0.938159344836913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 288}], {
             RGBColor[
             0.2170539171587743, 0.34546780732004123`, 0.9356722715284729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 297}], {
             RGBColor[
             0.20861782382323596`, 0.3366009383451798, 0.9351918484930957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 270}], {
             RGBColor[
             0.19864447884335656`, 0.3261183204247322, 0.9346238812507333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 278}], {
             RGBColor[
             0.1925398971260588, 0.3197020179870163, 0.9342762343528525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 295}], {
             RGBColor[
             0.19068631113650653`, 0.3177537815878572, 0.9341706753728822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 251}], {
             RGBColor[
             0.24168185283923999`, 0.37135332922152087`, 0.9370747960317096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 270}], {
             RGBColor[
             0.20529778048290723`, 0.33311136229158844`, 0.935002776936428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 271}], {
             RGBColor[
             0.21019581629378764`, 0.33825950848223085`, 0.9352817128298629]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 278}], {
             RGBColor[
             0.19919319876560948`, 0.3266950598538726, 0.9346551300385472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 289}], {
             RGBColor[
             0.22060050259813557`, 0.34919549348331447`, 0.9358742443225416]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 295}], {
             RGBColor[
             0.1973396127760572, 0.3247468234547135, 0.9345495710585769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 285}], {
             RGBColor[
             0.21081919728396287`, 0.3389147214275427, 0.9353172134550438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 258}], {
             RGBColor[
             0.2738091064777124, 0.40221653034560445`, 0.9390107464799751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 263}], {
             RGBColor[
             0.20867298294508915`, 0.33665891407953785`, 0.9351949897234846]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 286}], {
             RGBColor[
             0.2141737173623244, 0.342440534718758, 0.9355082484109388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 270}], {
             RGBColor[
             0.24922321837913736`, 0.37927978255414485`, 0.9375042656427561]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 271}], {
             RGBColor[
             0.25412125419001774`, 0.38442792874478726`, 0.9377832015361911]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 278}], {
             RGBColor[
             0.24311863666183964`, 0.372863480116429, 0.9371566187448754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 282}], {
             RGBColor[
             0.363119718775744, 0.4867984505328162, 0.944436976695407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 289}], {
             RGBColor[
             0.26452594049436573`, 0.3953639137458709, 0.9383757330288698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 295}], {
             RGBColor[
             0.24126505067228732`, 0.3709152437172699, 0.9370510597649051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 268}], {
             RGBColor[
             0.22149590633125682`, 0.35013661957870057`, 0.9359252362405117]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 279}], {
             RGBColor[
             0.23730450403035436`, 0.36675245808343765`, 0.9368255124927507]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 280}], {
             RGBColor[
             0.2499775972482043, 0.3800726825759171, 0.937547226403346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 283}], {
             RGBColor[
             0.27188152915805053`, 0.4030951038026612, 0.9387946229216484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 283}], {
             RGBColor[
             0.3123013068939945, 0.44465097126766145`, 0.9411304437622906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 258}], {
             RGBColor[
             0.3530896957607064, 0.48025028048897034`, 0.9437195410822816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 286}], {
             RGBColor[
             0.2934543066453184, 0.4204742848621239, 0.9402170430132455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 269}], {
             RGBColor[
             0.8955465010984967, 0.5299749416771264, 0.25752620199850723`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 277}], {
             RGBColor[
             0.9054696458162683, 0.5631344019327589, 0.3227451671094582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 281}], {
             RGBColor[
             0.8981948395566131, 0.5611330504108505, 0.5430721970328762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 293}], {
             RGBColor[
             0.8588434353874268, 0.38825931884886955`, 0.2014349376927211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 267}], {
             RGBColor[
             0.19014093188722048`, 0.31718055341781604`, 0.9341396168314517]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 272}], {
             RGBColor[
             0.18158199985616474`, 0.30818457318554265`, 0.9336521983140883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 300}], {
             RGBColor[
             0.20486085687830097`, 0.33265212788059073`, 0.9349778947835161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 263}], {
             RGBColor[
             0.2750253960672227, 0.40349492782139373`, 0.9390800123727585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 286}], {
             RGBColor[
             0.28052613048445796`, 0.4092765484606139, 0.9393932710602128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 267}], {
             RGBColor[
             0.22718681650953165`, 0.35611812700061296`, 0.9362493251562173]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 287}], {
             RGBColor[
             0.25058425907026255`, 0.38071032261548143`, 0.9375817748966364]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 294}], {
             RGBColor[
             0.39710848893487455`, 0.5114544721894022, 0.9473162764842546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 300}], {
             RGBColor[
             0.24190674150061214`, 0.37158970146338766`, 0.9370876031082818]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 284}], {
             RGBColor[
             0.2428470796826115, 0.3725780565135533, 0.937141153976641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 292}], {
             RGBColor[
             0.5387777053242508, 0.6299185321853173, 0.9593474985432611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 286}], {
             RGBColor[
             0.2153900069518347, 0.3437189321945473, 0.9355775143037223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 288}], {
             RGBColor[
             0.2525376443502292, 0.38276345439650644`, 0.937693017298556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 276}], {
             RGBColor[
             0.23204484364859856`, 0.36122422154048306`, 0.93652598261498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 286}], {
             RGBColor[
             0.22180329067308052`, 0.3504597000112502, 0.9359427413240442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 272}], {
             RGBColor[
             0.18764714248222777`, 0.31455942263778813`, 0.9339975992140681]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 287}], {
             RGBColor[
             0.2196035170740144, 0.34814759848492993`, 0.9358174674718507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 300}], {
             RGBColor[
             0.210925999504364, 0.33902697733283615`, 0.935323295683496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 279}], {
             RGBColor[
             0.22085812887375872`, 0.34946627503344374`, 0.9358889157578143]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 280}], {
             RGBColor[
             0.23353122209160865`, 0.3627864995259231, 0.9366106296684096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 277}], {
             RGBColor[
             0.9830880426173179, 0.9543005010685027, 0.41547009014484526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 282}], {
             RGBColor[
             0.7068985223577822, 0.7386080961972126, 0.6497743968433352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 293}], {
             RGBColor[
             0.9364618321884765, 0.7794254179846133, 0.2941598607281082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 271}], {
             RGBColor[
             0.217737181833685, 0.3461859618148549, 0.9357111824409096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 278}], {
             RGBColor[
             0.20673456430550685`, 0.3346215131864966, 0.9350845996495938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 289}], {
             RGBColor[
             0.22814186813803294`, 0.35712194681593845`, 0.9363037139335881]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 295}], {
             RGBColor[
             0.20488097831595456`, 0.3326732767873375, 0.9349790406696236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 278}], {
             RGBColor[
             0.21163260011638724`, 0.339769659377139, 0.9353635355430288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 289}], {
             RGBColor[
             0.23303990394891333`, 0.36227009300658086`, 0.9365826498270231]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 295}], {
             RGBColor[
             0.20977901412683497`, 0.3378214229779799, 0.9352579765630585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 274}], {
             RGBColor[
             0.3509883555182567, 0.4717110997619036, 0.9438949792783465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 289}], {
             RGBColor[
             0.24118737083360547`, 0.370833597281629, 0.9370466360130092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 289}], {
             RGBColor[
             0.3532455749379125, 0.4740835804879391, 0.944023524585039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 281}], {
             RGBColor[
             0.9857363810754343, 0.9854586098022267, 0.7010160851792143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 282}], {
             RGBColor[
             0.7168216670755537, 0.7717675564528452, 0.7149933619542863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 293}], {
             RGBColor[
             0.946384976906248, 0.8125848782402458, 0.35937882583905917`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 295}], {
             RGBColor[
             0.1987763965986568, 0.3262569743496216, 0.9346313937717428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 280}], {
             RGBColor[
             0.24933981979070619`, 0.37940233803066026`, 0.9375109059206487]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 294}], {
             RGBColor[
             0.7572554970898742, 0.8088426757639791, 0.9389810177450694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 293}], {
             RGBColor[
             0.6701954566467123, 0.5968924733689558, 0.5936831325375491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 300}], {
             RGBColor[
             0.2343234420650949, 0.3636191729477046, 0.9366557454239152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 296}], {
             RGBColor[
             0.1980362372485557, 0.3254790199438521, 0.9345892427917222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 297}], {
             RGBColor[
             0.20042924344964513`, 0.3279942211865534, 0.9347255209547387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 291}], {
             RGBColor[
             0.9366428804635196, 0.8848865477710113, 0.6343132641384139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 297}], {
             RGBColor[
             0.18960014391301738`, 0.31661215096899065`, 0.934108819756345]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.032105813875877395`], {
             RGBColor[
             0.8186934053129894, 0.1446912815038851, 0.16553413207988746`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.032105813875877395`], {
             RGBColor[
             0.19859115798198185`, 0.32606227681868954`, 0.934620844706559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.032105813875877395`], {
             RGBColor[
             0.9542183694281502, 0.96537671539683, 0.9623805381832607]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.032105813875877395`], {
             RGBColor[
             0.2205376694136581, 0.34912945182257465`, 0.935870666065639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.032105813875877395`], {
             RGBColor[
             0.9710126878169619, 0.9138811308413543, 0.3418901952738247]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.032105813875877395`], {
             RGBColor[
             0.2105950138195758, 0.3386790903924193, 0.9353044465383967]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.032105813875877395`], {
             RGBColor[
             0.9383196861766793, 0.9535195034595876, 0.9892928618873055]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.032105813875877395`], {
             RGBColor[
             0.2044682273202984, 0.33223944932097826`, 0.9349555351110312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.032105813875877395`], {
             RGBColor[
             0.19896010530687766`, 0.32645006384976655`, 0.9346418557109033]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.032105813875877395`], {
             RGBColor[
             0.19040293767796423`, 0.3174559381160143, 0.9341545376736317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.032105813875877395`], {
             RGBColor[
             0.5318148081413353, 0.630790245090044, 0.9562855562801685]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.032105813875877395`], {
             RGBColor[
             0.42962012936485927`, 0.5465370955454517, 0.948595992638333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.032105813875877395`], {
             RGBColor[
             0.33328873930237535`, 0.463099687229773, 0.9424578416460552]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.032105813875877395`], {
             RGBColor[
             0.1801938510546308, 0.30672554078141306`, 0.9335731452934231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.032105813875877395`], {
             RGBColor[
             0.2583760710911756, 0.38890001107887695`, 0.9380255070642746]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.032105813875877395`], {
             RGBColor[
             0.24679037784549854`, 0.37672271290229153`, 0.9373657189734305]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.032105813875877395`], {
             RGBColor[
             0.7036631405833589, 0.768426260552445, 0.9710982238135836]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.032105813875877395`], {
             RGBColor[
             0.19997475001447043`, 0.3275165197696367, 0.9346996382259684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.032105813875877395`], {
             RGBColor[
             0.18771789764902583`, 0.31463379080422954`, 0.9340016286161444]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.032105813875877395`], {
             RGBColor[
             0.21900416978762977`, 0.3475176464861269, 0.9357833355305459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.032105813875877395`], {
             RGBColor[
             0.19357781768564236`, 0.320792938303103, 0.9343353423932549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.032105813875877395`], {
             RGBColor[
             0.18854143418810532`, 0.3154993799220345, 0.9340485278037318]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.032105813875877395`], {
             RGBColor[
             0.989346654985427, 0.9898625823050647, 0.82621702707199]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.032105813875877395`], {
             RGBColor[
             0.9237640134240451, 0.7354567479025522, 0.2575169395936321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.032105813875877395`], {
             RGBColor[
             0.1911156300253715, 0.31820502296044406`, 0.9341951244484827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.032105813875877395`], {
             RGBColor[
             0.2290956026577889, 0.35812438226646315`, 0.9363580277035645]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.032105813875877395`], {
             RGBColor[
             0.9698415036520304, 0.9099304516459211, 0.33734036595263717`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.032105813875877395`], {
             RGBColor[
             0.18347004528514485`, 0.31016902864039503`, 0.9337597197081559]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.032105813875877395`], {
             RGBColor[
             0.19525519293228838`, 0.32255596603906117`, 0.934430866432097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.032105813875877395`], {
             RGBColor[
             0.24929644188312317`, 0.37935674509947226`, 0.9375084356129837]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.032105813875877395`], {
             RGBColor[
             0.41964854701834464`, 0.537900212103202, 0.9479606122287372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.032105813875877395`], {
             RGBColor[
             0.9876761626712638, 0.9891717908034641, 0.8539014078132029]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.032105813875877395`], {
             RGBColor[
             0.20050642775524471`, 0.3280753467855062, 0.9347299164867587]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.032105813875877395`], {
             RGBColor[
             0.1836929464736069, 0.31040331192222026`, 0.933772413601086]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.032105813875877395`], {
             RGBColor[
             0.20639345636736367`, 0.33426298711601565`, 0.9350651740571405]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.032105813875877395`], {
             RGBColor[
             0.18133311757286624`, 0.3079229821257478, 0.9336380248362428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.032105813875877395`], {
             RGBColor[
             0.22656828106141946`, 0.3554680070272346, 0.9362141004774884]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.032105813875877395`], {
             RGBColor[
             0.18611948239069784`, 0.312953755022346, 0.9339106012318261]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.032105813875877395`], {
             RGBColor[
             0.20172422019829714`, 0.3293553238556548, 0.934799267964828]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.032105813875877395`], {
             RGBColor[
             0.6892336433588957, 0.7571538276524538, 0.9696600263815672]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.032105813875877395`], {
             RGBColor[
             0.1885946642534308, 0.31555532809567266`, 0.9340515591772053]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.032105813875877395`], {
             RGBColor[
             0.8376047344232163, 0.2900520440423452, 0.18364364219313192`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.032105813875877395`], {
             RGBColor[
             0.2255865897625529, 0.3544361872293025, 0.9361581946103001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.032105813875877395`], {
             RGBColor[
             0.31621931418873805`, 0.44831500913059213`, 0.9413701929717141]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.032105813875877395`], {
             RGBColor[
             0.29993474933268105`, 0.43258081688308847`, 0.9403922123095734]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.032105813875877395`], {
             RGBColor[
             0.2047087295239663, 0.33249223238575365`, 0.9349692313557391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.032105813875877395`], {
             RGBColor[
             0.18409960782193097`, 0.31083073878312756`, 0.9337955723632715]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.032105813875877395`], {
             RGBColor[
             0.1928098846058197, 0.31998579194643995`, 0.9342916097404141]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.032105813875877395`], {
             RGBColor[
             0.20962180710681122`, 0.3376561884324342, 0.9352490238558351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.032105813875877395`], {
             RGBColor[
             0.1818234123124711, 0.30843831298355445`, 0.9336659463963373]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.032105813875877395`], {
             RGBColor[
             0.8112967405816618, 0.8525104469167772, 0.981826135168235]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.032105813875877395`], {
             RGBColor[
             0.1987330571876369, 0.3262114218807623, 0.9346289256564001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.032105813875877395`], {
             RGBColor[
             0.21587739356825456`, 0.3442312064305009, 0.9356052702505034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.032105813875877395`], {
             RGBColor[
             0.24403688677483204`, 0.37382861920560384`, 0.937208911730381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.032105813875877395`], {
             RGBColor[
             0.20213692733288047`, 0.32978910522124555`, 0.9348227710255971]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.032105813875877395`], {
             RGBColor[
             0.19935669202797407`, 0.3268669016386893, 0.9346644407379722]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.032105813875877395`], {
             RGBColor[
             0.17967566298483006`, 0.30618089226503126`, 0.9335436352494385]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.032105813875877395`], {
             RGBColor[
             0.19114091674596853`, 0.31823160090706226`, 0.9341965644898124]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.032105813875877395`], {
             RGBColor[
             0.985007685890186, 0.9880683070777632, 0.8981249738722014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.032105813875877395`], {
             RGBColor[
             0.28726741181117993`, 0.4192666419924039, 0.9396708261773704]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.032105813875877395`], {
             RGBColor[
             0.2772592389822082, 0.4087474177943471, 0.9391008755405253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.032105813875877395`], {
             RGBColor[
             0.20167701950442632`, 0.3293057129336997, 0.9347965799551393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.032105813875877395`], {
             RGBColor[
             0.18288267188311363`, 0.3095516619532356, 0.9337262696618512]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.032105813875877395`], {
             RGBColor[
             0.2353045398184947, 0.3646503688917182, 0.9367116174895672]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.032105813875877395`], {
             RGBColor[
             0.3774633879291902, 0.5013615475879224, 0.9452726111944477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.032105813875877395`], {
             RGBColor[
             0.3863417480503173, 0.5090515368854881, 0.9458383324505404]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.032105813875877395`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.032105813875877395`], {
             RGBColor[
             0.8768566069289154, 0.9046456729993274, 0.9881165600196555]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.032105813875877395`], {
             RGBColor[
             0.20756886290590398`, 0.3354984139131004, 0.9351321117206522]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.032105813875877395`], {
             RGBColor[
             0.20976983040282712`, 0.33781177030176596`, 0.9352574535635624]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.032105813875877395`], {
             RGBColor[
             0.22331684544677569`, 0.35205054204331915`, 0.9360289360293025]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.032105813875877395`], {
             RGBColor[
             0.8294154563220671, 0.22710566399236717`, 0.1758015802350048]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.032105813875877395`], {
             RGBColor[
             0.1826688110543663, 0.3093268806626624, 0.9337140906040328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.032105813875877395`], {
             RGBColor[
             0.20590138873724428`, 0.3337457928378705, 0.935037151533554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.032105813875877395`], {
             RGBColor[
             0.3329293714790703, 0.46278842088357813`, 0.9424349430461306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.032105813875877395`], {
             RGBColor[
             0.3269177544061254, 0.4575814603276529, 0.9420518881221068]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.032105813875877395`], {
             RGBColor[
             0.4137826929511934, 0.5328195041366336, 0.9475868451945494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.032105813875877395`], {
             RGBColor[
             0.19413140389541048`, 0.3213747925089622, 0.9343668683089438]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.032105813875877395`], {
             RGBColor[
             0.18314084159618357`, 0.3098230146905773, 0.9337409720450827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.032105813875877395`], {
             RGBColor[
             0.9788084084452291, 0.9401779270427488, 0.37217509781633024`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.032105813875877395`], {
             RGBColor[
             0.8894648943465696, 0.5909677260051436, 0.2294791371904563]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.032105813875877395`], {
             RGBColor[
             0.6134396494628491, 0.6970569684320459, 0.962711362790644]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.032105813875877395`], {
             RGBColor[
             0.846552585818907, 0.35882915084310774`, 0.19221211479479816`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.032105813875877395`], {
             RGBColor[
             0.18746791982634672`, 0.31437104826308443`, 0.9339873927489519]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.032105813875877395`], {
             RGBColor[
             0.23214849009490668`, 0.36133316052711717`, 0.9365318851267661]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.032105813875877395`], {
             RGBColor[
             0.5941770672605392, 0.6814187364307716, 0.9611949417585145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.032105813875877395`], {
             RGBColor[
             0.9931480500222558, 0.9877526967730439, 0.4955857141352578]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.032105813875877395`], {
             RGBColor[
             0.22285845764454237`, 0.35156874739970667`, 0.9360028315220893]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.032105813875877395`], {
             RGBColor[
             0.3807443443279537, 0.5042033471148679, 0.9454816708349412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.032105813875877395`], {
             RGBColor[
             0.21567607897691587`, 0.34401961203092163`, 0.935593805682345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.032105813875877395`], {
             RGBColor[
             0.49015879412300467`, 0.5969720163279171, 0.9530062422656385]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.032105813875877395`], {
             RGBColor[
             0.8315546894535105, 0.24354874725857717`, 0.17785011229759332`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.032105813875877395`], {
             RGBColor[
             0.24113006344271598`, 0.3707733635803057, 0.9370433724418767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.032105813875877395`], {
             RGBColor[
             0.796888814031874, 0.8412548651917855, 0.9803900876994809]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.032105813875877395`], {
             RGBColor[
             0.28755638833203334`, 0.4195703746379904, 0.9396872829627306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.032105813875877395`], {
             RGBColor[
             0.20095046543520778`, 0.32854205854076235`, 0.9347552037757377]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.032105813875877395`], {
             RGBColor[
             0.44885816070930806`, 0.563200111364443, 0.9498218229840781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.032105813875877395`], {
             RGBColor[
             0.1790520430393593, 0.3055254281625532, 0.9335081210161069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.032105813875877395`], {
             RGBColor[
             0.19567419878950365`, 0.3229963677615002, 0.9344547281958019]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.032105813875877395`], {
             RGBColor[
             0.1806628381309981, 0.3072184759341732, 0.933599853413618]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.032105813875877395`], {
             RGBColor[
             0.6473280227603806, 0.724416838346381, 0.9654832657505968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.032105813875877395`], {
             RGBColor[
             0.19219534584531597`, 0.31933987274514264`, 0.9342566126671321]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.032105813875877395`], {
             RGBColor[
             0.4213296380105047, 0.5393562886265211, 0.9480677298602272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.032105813875877395`], {
             RGBColor[
             0.3350878162698179, 0.46465795727473413`, 0.9425724772395593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.032105813875877395`], {
             RGBColor[
             0.28384023029084227`, 0.41566445691867016`, 0.9394756532598479]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.032105813875877395`], {
             RGBColor[
             0.861860606843299, 0.8926882695866354, 0.9866862281444021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.032105813875877395`], {
             RGBColor[
             0.40847529455142584`, 0.5282225024003548, 0.9472486624616643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.032105813875877395`], {
             RGBColor[
             0.24068546665888524`, 0.3703060641714354, 0.9370180533127597]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.032105813875877395`], {
             RGBColor[
             0.9928111618057213, 0.9912952449090205, 0.7688011832034702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.032105813875877395`], {
             RGBColor[
             0.18591721951216156`, 0.3127411639127972, 0.9338990826601146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.032105813875877395`], {
             RGBColor[
             0.6142037164471443, 0.6976772724307221, 0.9627715129425172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.032105813875877395`], {
             RGBColor[
             0.18923133529375677`, 0.3162245097263307, 0.9340878166510814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.032105813875877395`], {
             RGBColor[
             0.2676326072490897, 0.3986292174791347, 0.9385526531046497]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.032105813875877395`], {
             RGBColor[
             0.23913206195702244`, 0.3686733373382309, 0.9369295892130448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.032105813875877395`], {
             RGBColor[
             0.3517287364030146, 0.47907148589714393`, 0.9436328219554587]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.032105813875877395`], {
             RGBColor[
             0.2873518174774419, 0.41935535769927346`, 0.9396756329551971]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.032105813875877395`], {
             RGBColor[
             0.1855098238772711, 0.3123129652701522, 0.9338758820813954]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.032105813875877395`], {
             RGBColor[
             0.1887209958010121, 0.3156881105620633, 0.9340587535719493]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.032105813875877395`], {
             RGBColor[
             0.18085158366002294`, 0.307416859452336, 0.933610602192272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.032105813875877395`], {
             RGBColor[
             0.27909030860477735`, 0.41067198806418675`, 0.939205152246706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.032105813875877395`], {
             RGBColor[
             0.22544944565233713`, 0.35429204007402687`, 0.9361503844561099]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.032105813875877395`], {
             RGBColor[
             0.18504035865818397`, 0.31181952755907755`, 0.93384914673168]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.032105813875877395`], {
             RGBColor[
             0.19860317371820202`, 0.3260749061192986, 0.9346215289849611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.032105813875877395`], {
             RGBColor[
             0.1859244664032461, 0.3127487808548065, 0.9338994953598411]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.032105813875877395`], {
             RGBColor[
             0.8351944719959239, 0.27152571084244637`, 0.18133557217075477`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.032105813875877395`], {
             RGBColor[
             0.22348836128871713`, 0.3522308160679321, 0.9360387036027661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.032105813875877395`], {
             RGBColor[
             0.34883524619319184`, 0.47656529010844195`, 0.9434484513179017]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.032105813875877395`], {
             RGBColor[
             0.8449402545684014, 0.34643606632366236`, 0.19066814456844627`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.032105813875877395`], {
             RGBColor[
             0.18908769389738214`, 0.3160735335113504, 0.9340796364860563]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.032105813875877395`], {
             RGBColor[
             0.9118031822514008, 0.6880360380137298, 0.24789297407533079`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.032105813875877395`], {
             RGBColor[
             0.22940782651350908`, 0.3584525493349609, 0.9363758083902539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.032105813875877395`], {
             RGBColor[
             0.19689631111946682`, 0.3242808853066886, 0.9345243256850401]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.032105813875877395`], {
             RGBColor[
             0.18528931800943133`, 0.31208119962217307`, 0.9338633245984311]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.032105813875877395`], {
             RGBColor[
             0.24479905803441923`, 0.3746297095238789, 0.9372523162560832]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.032105813875877395`], {
             RGBColor[
             0.21307650899259664`, 0.34128729915514544`, 0.9354457640174572]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.032105813875877395`], {
             RGBColor[
             0.39261549520966454`, 0.5144855413472138, 0.9462380900718772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.032105813875877395`], {
             RGBColor[
             0.26153416243522165`, 0.3922193653160256, 0.9382053556943405]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.032105813875877395`], {
             RGBColor[
             0.231287806205471, 0.36042852718880986`, 0.9364828704525304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.032105813875877395`], {
             RGBColor[
             0.4407231525670485, 0.5561539761890157, 0.9493034674587586]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.032105813875877395`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.032105813875877395`], {
             RGBColor[
             0.2938477713702168, 0.42618301710784506`, 0.940045567919488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.032105813875877395`], {
             RGBColor[
             0.8299355921400753, 0.23110365581454728`, 0.17629966288173887`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.032105813875877395`], {
             RGBColor[
             0.3068945586163886, 0.4398960177176607, 0.9407885631521654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.032105813875877395`], {
             RGBColor[
             0.19763991012936863`, 0.32506245501299574`, 0.9345666725485978]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.032105813875877395`], {
             RGBColor[
             0.8649038628242013, 0.8951148792988238, 0.9869764966166072]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.032105813875877395`], {
             RGBColor[
             0.20002902465321373`, 0.3275735658561667, 0.9347027290863527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.032105813875877395`], {
             RGBColor[
             0.21339775345539977`, 0.34162494745362687`, 0.9354640584143752]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.032105813875877395`], {
             RGBColor[
             0.2462972527349853, 0.37620440714520426`, 0.9373376362279]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.032105813875877395`], {
             RGBColor[
             0.895503807139292, 0.6183890185729798, 0.2345181540520019]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.032105813875877395`], {
             RGBColor[
             0.9074094141907081, 0.6706162117894943, 0.24435764515870567`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.032105813875877395`], {
             RGBColor[
             0.5978280581771518, 0.684382775332144, 0.9614823611374906]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.032105813875877395`], {
             RGBColor[
             0.1825195240294396, 0.3091699705341204, 0.9337055889288136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.032105813875877395`], {
             RGBColor[
             0.22106916700115545`, 0.3496880894859278, 0.9359009340669666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.032105813875877395`], {
             RGBColor[
             0.4972976140125026, 0.6027676319143825, 0.9535682363176986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.032105813875877395`], {
             RGBColor[
             0.9263138375757084, 0.7455659509853682, 0.2595685879581257]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.032105813875877395`], {
             RGBColor[
             0.3944915237120784, 0.5161104629440706, 0.9463576289491441]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.032105813875877395`], {
             RGBColor[
             0.18253809113335498`, 0.30918948573755783`, 0.933706646297914]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.032105813875877395`], {
             RGBColor[
             0.19294565339664288`, 0.32012849355383366`, 0.9342993415721996]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.032105813875877395`], {
             RGBColor[
             0.29124080035179, 0.42344292527596916`, 0.9398971047766567]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.032105813875877395`], {
             RGBColor[
             0.19576440547633542`, 0.32309118070879467`, 0.9344598653331682]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.032105813875877395`], {
             RGBColor[
             0.2016546493170191, 0.3292822004483829, 0.9347953060060602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.032105813875877395`], {
             RGBColor[
             0.9913482769712819, 0.9906903044355545, 0.7930449707347249]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.032105813875877395`], {
             RGBColor[
             0.6211503872091352, 0.7033168926992579, 0.9633183803113946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.032105813875877395`], {
             RGBColor[
             0.18196114135351968`, 0.30858307493822207`, 0.9336737898614731]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.032105813875877395`], {
             RGBColor[
             0.21779424853057935`, 0.34624594253152846`, 0.935714432304875]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.032105813875877395`], {
             RGBColor[
             0.18609439165410657`, 0.312927383067344, 0.9339091723514956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.032105813875877395`], {
             RGBColor[
             0.9076820231617462, 0.6716970155181059, 0.2445769927357579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.032105813875877395`], {
             RGBColor[
             0.4004114204648772, 0.5212379799686826, 0.9467348395354733]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.032105813875877395`], {
             RGBColor[
             0.6047389625257771, 0.6899933588150511, 0.9620264128432912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.032105813875877395`], {
             RGBColor[
             0.19757646601375403`, 0.32499577122489554`, 0.9345630595000708]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.032105813875877395`], {
             RGBColor[
             0.17914809400855325`, 0.30562638382115925`, 0.9335135909767078]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.032105813875877395`], {
             RGBColor[
             0.19058407149220488`, 0.3176463212393284, 0.9341648529763892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.032105813875877395`], {
             RGBColor[
             0.20128694378722742`, 0.32889571862269473`, 0.9347743657201101]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.032105813875877395`], {
             RGBColor[
             0.23320476894069225`, 0.36244337656598474`, 0.9365920386444091]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.032105813875877395`], {
             RGBColor[
             0.18260859612989327`, 0.30926359095919453`, 0.9337106614531641]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.032105813875877395`], {
             RGBColor[
             0.19419263806779313`, 0.3214391535066072, 0.9343703555044731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.032105813875877395`], {
             RGBColor[
             0.29197171960673096`, 0.42421116775586953`, 0.9399387295469274]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.032105813875877395`], {
             RGBColor[
             0.25901133304362195`, 0.3895677116688322, 0.9380616842926806]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.032105813875877395`], {
             RGBColor[
             0.5227567642523288, 0.6234365170007214, 0.9555724738845179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.032105813875877395`], {
             RGBColor[
             0.19488460571983207`, 0.32216645538218325`, 0.9344097620385824]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.032105813875877395`], {
             RGBColor[
             0.9862939640410388, 0.9654284637594515, 0.4012550677774902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.032105813875877395`], {
             RGBColor[
             0.2543436096659436, 0.38466163844813683`, 0.9377958643515997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.032105813875877395`], {
             RGBColor[
             0.19274031574857725`, 0.3199126706665578, 0.9342876478969121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.032105813875877395`], {
             RGBColor[
             0.1914897805011185, 0.3185982788329645, 0.9342164317645705]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.032105813875877395`], {
             RGBColor[
             0.5295564396500168, 0.6289567998104505, 0.9561077692398556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.032105813875877395`], {
             RGBColor[
             0.19311599281626868`, 0.32030753108400334`, 0.9343090421501528]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.032105813875877395`], {
             RGBColor[
             0.22474017350644473`, 0.35354655007824254`, 0.9361099924566755]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.032105813875877395`], {
             RGBColor[
             0.35586441424032067`, 0.4826536021746064, 0.9438963436902155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.032105813875877395`], {
             RGBColor[
             0.21583585429987417`, 0.3441875460256914, 0.935602904650621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.032105813875877395`], {
             RGBColor[
             0.2044144915577996, 0.3321829696275479, 0.9349524749388519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.032105813875877395`], {
             RGBColor[
             0.2273767118965443, 0.3563177190924262, 0.9362601394175826]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.032105813875877395`], {
             RGBColor[
             0.3306172943235091, 0.4607858158598078, 0.9422876195342679]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.032105813875877395`], {
             RGBColor[
             0.27956374695486264`, 0.41116960178785156`, 0.939232113860354]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.032105813875877395`], {
             RGBColor[
             0.6860055424687634, 0.754632010702607, 0.9693382794531569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.032105813875877395`], {
             RGBColor[
             0.18372407711397143`, 0.31043603219904004`, 0.9337741864450011]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.032105813875877395`], {
             RGBColor[
             0.2030597206401025, 0.3307590194956109, 0.934875322739293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.032105813875877395`], {
             RGBColor[
             0.9863417120240653, 0.9886199611670301, 0.8760167084848537]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.032105813875877395`], {
             RGBColor[
             0.964591061095168, 0.9731126518583681, 0.9448222768222637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.032105813875877395`], {
             RGBColor[
             0.19839476243792764`, 0.32585585264969186`, 0.9346096602708663]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.032105813875877395`], {
             RGBColor[
             0.3655703148691659, 0.4910603654665621, 0.9445147950956946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.032105813875877395`], {
             RGBColor[
             0.8453640923839973, 0.3496938695012485, 0.19107401213931735`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.032105813875877395`], {
             RGBColor[
             0.8665707356341262, 0.4870106983585556, 0.21037568997361125`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.032105813875877395`], {
             RGBColor[
             0.9371250918628792, 0.9526285769763242, 0.9913149984604726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.032105813875877395`], {
             RGBColor[
             0.4836083421786542, 0.5916540643449961, 0.9524905666934831]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.032105813875877395`], {
             RGBColor[
             0.3723597127044757, 0.4969410006264502, 0.9449474095221317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.032105813875877395`], {
             RGBColor[
             0.22242260484653656`, 0.35111063847433904`, 0.9359780103500293]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.032105813875877395`], {
             RGBColor[
             0.18528775379377113`, 0.3120795555323372, 0.9338632355186633]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.032105813875877395`], {
             RGBColor[
             0.18931653926981418`, 0.3163140645074111, 0.9340926688914699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.032105813875877395`], {
             RGBColor[
             0.1804556557285978, 0.30700071409312746`, 0.9335880546823002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.032105813875877395`], {
             RGBColor[
             0.4716790509924657, 0.5819693283516046, 0.9515514491928728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.032105813875877395`], {
             RGBColor[
             0.2707327274798912, 0.4018876404006824, 0.9387292003655769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.032105813875877395`], {
             RGBColor[
             0.23336863550083925`, 0.36261561071043924`, 0.9366013706025906]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.032105813875877395`], {
             RGBColor[
             0.20237506472464956`, 0.3300394027187775, 0.9348363325977657]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.032105813875877395`], {
             RGBColor[
             0.20083038530367384`, 0.32841584670900015`, 0.9347483653898895]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.032105813875877395`], {
             RGBColor[
             0.22474171532416531`, 0.3535481706264238, 0.9361100802609137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.032105813875877395`], {
             RGBColor[
             0.8664637178535413, 0.48652475561155717`, 0.21028639171424535`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.032105813875877395`], {
             RGBColor[
             0.20003824461178885`, 0.32758325661720833`, 0.9347032541493537]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.032105813875877395`], {
             RGBColor[
             0.9671895696970209, 0.9750506153189628, 0.9404236795589124]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.032105813875877395`], {
             RGBColor[
             0.18433414396946993`, 0.31107725114464163`, 0.9338089288499086]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.032105813875877395`], {
             RGBColor[
             0.33308943974472227`, 0.4629270639700209, 0.9424451424544752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.032105813875877395`], {
             RGBColor[
             0.1861956076915163, 0.31303376754012907`, 0.9339149364550904]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.032105813875877395`], {
             RGBColor[
             0.2214255710569613, 0.35006269274590207`, 0.9359212307506922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.032105813875877395`], {
             RGBColor[
             0.1814903715451621, 0.30808826602110845`, 0.9336469802173286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.032105813875877395`], {
             RGBColor[
             0.20866772558178895`, 0.33665338825737323`, 0.9351946903244223]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.032105813875877395`], {
             RGBColor[
             0.2275966301752516, 0.35654886714697176`, 0.936272663438215]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.032105813875877395`], {
             RGBColor[
             0.9862571365941499, 0.9885849870532707, 0.8774183422327487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.032105813875877395`], {
             RGBColor[
             0.952704487454567, 0.8501960835922951, 0.28080312431882476`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.032105813875877395`], {
             RGBColor[
             0.426257062503514, 0.5436241760628097, 0.9483817009917713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.032105813875877395`], {
             RGBColor[
             0.2177123475199571, 0.3461598593765405, 0.9357097681634818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.032105813875877395`], {
             RGBColor[
             0.19208551837244375`, 0.31922443710768994`, 0.9342503581550272]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.032105813875877395`], {
             RGBColor[
             0.23118072954041266`, 0.36031598282478083`, 0.9364767725948611]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.032105813875877395`], {
             RGBColor[
             0.18790775611424687`, 0.3148333440888988, 0.9340124407748683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.032105813875877395`], {
             RGBColor[
             0.20539561179114207`, 0.3332141891994065, 0.9350083482847035]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.032105813875877395`], {
             RGBColor[
             0.1941551643020383, 0.3213997662028249, 0.9343682214289508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.032105813875877395`], {
             RGBColor[
             0.40849384697781144`, 0.528238571579618, 0.9472498446058684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.032105813875877395`], {
             RGBColor[
             0.23143093535124384`, 0.3605789649959291, 0.9364910214456416]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.032105813875877395`], {
             RGBColor[
             0.8250746635773962, 0.19374042880931708`, 0.17164483220048377`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.032105813875877395`], {
             RGBColor[
             0.1874435235211163, 0.31434540619947215`, 0.9339860034154601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.032105813875877395`], {
             RGBColor[
             0.23757609093788187`, 0.36703791314285356`, 0.9368409789653577]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.032105813875877395`], {
             RGBColor[
             0.18053047455342514`, 0.3070793534218085, 0.9335923155036896]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.032105813875877395`], {
             RGBColor[
             0.986124206873734, 0.9885300171977407, 0.8796213317111282]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.032105813875877395`], {
             RGBColor[
             0.18088209567567362`, 0.3074489295153584, 0.9336123398064248]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.032105813875877395`], {
             RGBColor[
             0.9874175082770378, 0.9890648305643368, 0.8581879805016432]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.032105813875877395`], {
             RGBColor[
             0.1895037720729246, 0.31651085805472556`, 0.934103331522621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.032105813875877395`], {
             RGBColor[
             0.22524249753236514`, 0.35407452447866766`, 0.9361385990668298]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.032105813875877395`], {
             RGBColor[
             0.1844498116639085, 0.31119882522525194`, 0.9338155159539919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.032105813875877395`], {
             RGBColor[
             0.19775641494300986`, 0.32518490895896446`, 0.9345733073253814]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.032105813875877395`], {
             RGBColor[
             0.22195872707107797`, 0.35062307352078237`, 0.9359515931969625]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.032105813875877395`], {
             RGBColor[
             0.20745669335557887`, 0.3353805166037485, 0.9351257238307011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.032105813875877395`], {
             RGBColor[
             0.18265386603570732`, 0.30931117250048296`, 0.9337132395073293]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.032105813875877395`], {
             RGBColor[
             0.28560729073547014`, 0.4175217494840773, 0.9395762847380378]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.032105813875877395`], {
             RGBColor[
             0.23794228148785246`, 0.3674228026286945, 0.9368618329754481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.032105813875877395`], {
             RGBColor[
             0.19184993915614282`, 0.3189768284147727, 0.9342369422671671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.032105813875877395`], {
             RGBColor[
             0.31878183695974033`, 0.45053453755869494`, 0.9415334746567325]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.032105813875877395`], {
             RGBColor[
             0.3660178719215669, 0.49144801689048034`, 0.9445433130353144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.032105813875877395`], {
             RGBColor[
             0.817928104297447, 0.13880884254138265`, 0.16480127896312016`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.032105813875877395`], {
             RGBColor[
             0.18407578926115742`, 0.31080570396557056`, 0.9337942159314718]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.032105813875877395`], {
             RGBColor[
             0.340161519599846, 0.46905254408746033`, 0.942895769129249]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.032105813875877395`], {
             RGBColor[
             0.18516129488531852`, 0.3119466392015956, 0.9338560338709061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.032105813875877395`], {
             RGBColor[
             0.25816755850577977`, 0.38868085113116446`, 0.938013632581003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.032105813875877395`], {
             RGBColor[
             0.24473644409614725`, 0.3745638983048021, 0.9372487504849276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.032105813875877395`], {
             RGBColor[
             0.3038398335581257, 0.4366853080006712, 0.9406146010791581]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.032105813875877395`], {
             RGBColor[
             0.20988927253459944`, 0.3379373115553272, 0.935264255616268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.032105813875877395`], {
             RGBColor[
             0.2962099519152749, 0.42866581863159803`, 0.9401800906069961]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.032105813875877395`], {
             RGBColor[
             0.22271583997709107`, 0.35141884718873295`, 0.9359947096569118]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.032105813875877395`], {
             RGBColor[
             0.1981497507744529, 0.3255983298567432, 0.9345957072190938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.032105813875877395`], {
             RGBColor[
             0.1962060745132835, 0.32355540287006146`, 0.9344850177314316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.032105813875877395`], {
             RGBColor[
             0.20504953117466115`, 0.3328504365287066, 0.9349886395055752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.032105813875877395`], {
             RGBColor[
             0.9731648978995463, 0.9211410408128702, 0.3502511250338943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.032105813875877395`], {
             RGBColor[
             0.2128391460228046, 0.3410378156242125, 0.9354322465474746]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.032105813875877395`], {
             RGBColor[
             0.2226352176445654, 0.3513341080054973, 0.9359901183343445]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.032105813875877395`], {
             RGBColor[
             0.17908821045117204`, 0.30556344240551475`, 0.9335101806967048]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.032105813875877395`], {
             RGBColor[
             0.2389301514139497, 0.3684611165555936, 0.9369180907063167]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.032105813875877395`], {
             RGBColor[
             0.46304655962256364`, 0.5749610829682137, 0.9508718678503764]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.032105813875877395`], {
             RGBColor[
             0.1801747671672662, 0.30670548240580453`, 0.9335720584942697]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.032105813875877395`], {
             RGBColor[
             0.24137384732010603`, 0.3710295958922332, 0.9370572555730482]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.032105813875877395`], {
             RGBColor[
             0.9930111873350895, 0.9874599613241353, 0.4806890552557963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.032105813875877395`], {
             RGBColor[
             0.2006299825882091, 0.3282052107487807, 0.934736952751713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.032105813875877395`], {
             RGBColor[
             0.23666672657285628`, 0.3660821135381808, 0.9367891920100534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.032105813875877395`], {
             RGBColor[
             0.2620129130085561, 0.39272256252313964`, 0.938232619831244]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.032105813875877395`], {
             RGBColor[
             0.9784615748157791, 0.9834572582803182, 0.9213431151026323]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.032105813875877395`], {
             RGBColor[
             0.4406321468160179, 0.5560751515815551, 0.9492976686527762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.032105813875877395`], {
             RGBColor[
             0.3058207768282486, 0.438767404976628, 0.9407274128678487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.032105813875877395`], {
             RGBColor[
             0.24095771526907575`, 0.3705922147223045, 0.9370335574683543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.032105813875877395`], {
             RGBColor[
             0.1996796674968478, 0.327206369334303, 0.9346828337131252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.032105813875877395`], {
             RGBColor[
             0.22089074136906994`, 0.34950055283376746`, 0.9358907729911765]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.032105813875877395`], {
             RGBColor[
             0.2430009596347453, 0.3727397940997984, 0.9371499172122699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.032105813875877395`], {
             RGBColor[
             0.20886533678518346`, 0.33686109016141486`, 0.9352059439901159]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.032105813875877395`], {
             RGBColor[
             0.2434445902532613, 0.3732060780076645, 0.9371751813197018]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.032105813875877395`], {
             RGBColor[
             0.9464109372448213, 0.8252442542119368, 0.27573918609145315`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.032105813875877395`], {
             RGBColor[
             0.926874823682218, 0.9445288413300859, 0.9928873421853748]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.032105813875877395`], {
             RGBColor[
             0.773715577090376, 0.8231517563699634, 0.978080396007364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.032105813875877395`], {
             RGBColor[
             0.8997587664774066, 0.6377097951563564, 0.23806859642232206`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.032105813875877395`], {
             RGBColor[
             0.5360494193639693, 0.63422809324764, 0.9566189203875064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.032105813875877395`], {
             RGBColor[
             0.19692281060910452`, 0.3243087379504625, 0.9345258347917725]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.032105813875877395`], {
             RGBColor[
             0.18720713771192796`, 0.31409694972628927`, 0.9339725415933283]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.032105813875877395`], {
             RGBColor[
             0.19199315011410678`, 0.319127352211692, 0.9342450979193615]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.032105813875877395`], {
             RGBColor[
             0.2601377913887575, 0.39075169081115385`, 0.9381258344289902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.032105813875877395`], {
             RGBColor[
             0.8186938987840391, 0.1446950745386128, 0.16553460462832187`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.032105813875877395`], {
             RGBColor[
             0.2256459244954445, 0.3544985517956109, 0.9361615736355604]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{{3.8349502435193233`*^9, 3.8349502581408367`*^9}, 
   3.834950528174912*^9, 3.835008873029399*^9, 3.8350238978014936`*^9},
 CellLabel->
  "Out[154]=",ExpressionUUID->"09600472-3986-4a73-85c7-c12d971a77fd"]
}, Open  ]],

Cell["r = 3 :", "Text",
 CellChangeTimes->{{3.834793779215767*^9, 3.8347938725231647`*^9}, {
  3.8347953347101345`*^9, 3.8347953431477337`*^9}, {3.8348851911359825`*^9, 
  3.83488519180678*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"6ed1f520-530f-4d18-9e9d-801fb0910d6d"],

Cell["Cubic Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.834795179278664*^9}},ExpressionUUID->"5c75a326-2793-46e7-aa67-\
df79fc80f650"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c\[Rho]3i3", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"CMDi3300", ",", "kri3"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.834947911760502*^9, 
   3.834947914304406*^9}, {3.834947957535968*^9, 3.8349479704802837`*^9}, {
   3.8349480487781425`*^9, 3.834948105065866*^9}, {3.8349497992119355`*^9, 
   3.83494980454772*^9}, {3.835008879910736*^9, 3.835008883995765*^9}},
 CellLabel->
  "In[155]:=",ExpressionUUID->"99cd3dfc-fba2-4be3-abea-08cd3946edee"],

Cell[BoxData[
 RowBox[{"-", "0.0128884764873504`"}]], "Output",
 CellChangeTimes->{
  3.834948013482303*^9, {3.834948049945756*^9, 3.834948058990469*^9}, 
   3.8349481059508953`*^9, 3.8349499476386404`*^9, 3.8350088849011827`*^9, 
   3.8350238983155303`*^9},
 CellLabel->
  "Out[155]=",ExpressionUUID->"31f780aa-c0d5-498a-b130-5717758996c2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CP3i3", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"CMDi3300", ",", "kri3"}], "}"}], "]"}], ",", "c\[Rho]3i3"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8349481210775223`*^9, 3.834948150679065*^9}, {
  3.8349481924167476`*^9, 3.8349481986802473`*^9}, {3.834949807949147*^9, 
  3.834949815491851*^9}, {3.8350088874351416`*^9, 3.8350088931564846`*^9}},
 CellLabel->
  "In[156]:=",ExpressionUUID->"3506d6a6-4299-4bde-9fb8-e7f24d7ef746"],

Cell[BoxData["0.6692069610555993`"], "Output",
 CellChangeTimes->{3.8349481513130674`*^9, 3.8349482002632475`*^9, 
  3.8349499490044084`*^9, 3.835008894242751*^9, 3.8350238983314986`*^9},
 CellLabel->
  "Out[156]=",ExpressionUUID->"0afb3ce6-dc91-4b57-8445-2bc674b69d2e"]
}, Open  ]],

Cell["Absolute Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.8347951985065947`*^9}},ExpressionUUID->"deb7d15f-7a92-4fba-af35-\
5b71dbfd3986"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a\[Rho]3i3", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"AMDi3300", ",", "kri3"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.8348873709111376`*^9, 
   3.8348873755217657`*^9}, {3.8349481641806583`*^9, 
   3.8349481824982553`*^9}, {3.834949818653184*^9, 3.8349498238056817`*^9}, {
   3.835008897589061*^9, 3.8350089016862154`*^9}},
 CellLabel->
  "In[157]:=",ExpressionUUID->"202cd144-9335-4c8a-8fc9-8000b83ebef5"],

Cell[BoxData[
 RowBox[{"-", "0.08376424379789134`"}]], "Output",
 CellChangeTimes->{3.834948182946122*^9, 3.83494995054953*^9, 
  3.83500890252067*^9, 3.835023898343504*^9},
 CellLabel->
  "Out[157]=",ExpressionUUID->"e1d61c8f-733b-4dcb-a25b-058c41453c48"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"aP3i3", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"AMDi3300", ",", "kri3"}], "}"}], "]"}], ",", "a\[Rho]3i3"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8349482041094093`*^9, 
  3.8349482202691827`*^9}, {3.8349498269490285`*^9, 3.8349498405604887`*^9}, {
  3.835008904460665*^9, 3.8350089110779324`*^9}},
 CellLabel->
  "In[158]:=",ExpressionUUID->"8b60f5bc-81cd-4cfa-ad6a-54484bd36a40"],

Cell[BoxData["0.6710208600021409`"], "Output",
 CellChangeTimes->{3.834887440036944*^9, 3.8349482220989213`*^9, 
  3.8349499520491343`*^9, 3.835008911524804*^9, 3.8350238983584967`*^9},
 CellLabel->
  "Out[158]=",ExpressionUUID->"75498662-1532-4f9c-a120-0f22be49b8ed"]
}, Open  ]],

Cell["Max-min Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 3.8347951985065947`*^9}, {
  3.8348543263190746`*^9, 
  3.834854330052075*^9}},ExpressionUUID->"54a275e1-2b02-446b-8bc2-\
48e6b7aa8ad4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mM\[Rho]3i3", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"mMDi3300", ",", "kri3"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8348874651734295`*^9, 3.8348874872060013`*^9}, {
  3.8349482319487157`*^9, 3.834948245258479*^9}, {3.834949844516972*^9, 
  3.8349498489188633`*^9}, {3.835008915278119*^9, 3.8350089195875688`*^9}},
 CellLabel->
  "In[159]:=",ExpressionUUID->"db6e0f1c-b312-48e6-91e6-144dc89e5045"],

Cell[BoxData[
 RowBox[{"-", "0.04579383261326383`"}]], "Output",
 CellChangeTimes->{3.834948246413353*^9, 3.834949953689977*^9, 
  3.8350089200404987`*^9, 3.835023898375507*^9},
 CellLabel->
  "Out[159]=",ExpressionUUID->"25e9c830-7fac-410d-9854-b2b2421fed6c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mMP3i3", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"mMDi3300", ",", "kri3"}], "}"}], "]"}], ",", "mM\[Rho]3i3"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8348875260806427`*^9, 
  3.8348875488478312`*^9}, {3.8349482525846663`*^9, 3.8349482707073736`*^9}, {
  3.8349498532537427`*^9, 3.834949860995207*^9}, {3.8350089226503*^9, 
  3.8350089289165187`*^9}},
 CellLabel->
  "In[160]:=",ExpressionUUID->"49c6c200-6175-455b-a460-93a8baef7aca"],

Cell[BoxData["0.335213782057464`"], "Output",
 CellChangeTimes->{3.834887440036944*^9, 3.8348875533996215`*^9, 
  3.834948277702903*^9, 3.834949955989804*^9, 3.835008929560822*^9, 
  3.8350238983984995`*^9},
 CellLabel->
  "Out[160]=",ExpressionUUID->"9bda0ecc-1225-4902-b0ba-201685b34f34"]
}, Open  ]],

Cell["r = 6 :", "Text",
 CellChangeTimes->{{3.834793779215767*^9, 3.8347938725231647`*^9}, {
  3.8347953347101345`*^9, 3.8347953431477337`*^9}, {3.8348851911359825`*^9, 
  3.83488519180678*^9}, {3.834948305866973*^9, 3.8349483068980722`*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"ad27565b-c3cb-45d1-8393-ff41c01bb6f1"],

Cell["Cubic Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.834795179278664*^9}},ExpressionUUID->"f96d71f5-b891-4cfe-9566-\
d484977ff19b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c\[Rho]6i3", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"CMDi6300", ",", "kri3"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.834947911760502*^9, 
   3.834947914304406*^9}, {3.834947957535968*^9, 3.8349479704802837`*^9}, {
   3.8349480487781425`*^9, 3.834948105065866*^9}, {3.8349483158342133`*^9, 
   3.8349483193845987`*^9}, {3.834949864783629*^9, 3.834949869574106*^9}, {
   3.8350089326609488`*^9, 3.8350089367728987`*^9}},
 CellLabel->
  "In[161]:=",ExpressionUUID->"97eb9478-8f63-4c88-bbd1-836113bb861d"],

Cell[BoxData[
 RowBox[{"-", "0.06432826848579082`"}]], "Output",
 CellChangeTimes->{
  3.834948013482303*^9, {3.834948049945756*^9, 3.834948058990469*^9}, 
   3.8349481059508953`*^9, 3.834948360850016*^9, 3.8349499580565577`*^9, 
   3.835008938985528*^9, 3.835023898416498*^9},
 CellLabel->
  "Out[161]=",ExpressionUUID->"f483611e-8d25-407b-b354-d9e78935cf7a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CP6i3", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"CMDi6300", ",", "kri3"}], "}"}], "]"}], ",", "c\[Rho]6i3"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8349481210775223`*^9, 3.834948150679065*^9}, {
  3.8349481924167476`*^9, 3.8349481986802473`*^9}, {3.8349483230197706`*^9, 
  3.834948338654296*^9}, {3.8349498724373255`*^9, 3.8349498802583637`*^9}, {
  3.8350089413107834`*^9, 3.8350089475639453`*^9}},
 CellLabel->
  "In[162]:=",ExpressionUUID->"8d63659a-32bb-4b79-8f6c-364cf6817dd7"],

Cell[BoxData["0.979413528988404`"], "Output",
 CellChangeTimes->{3.8349481513130674`*^9, 3.8349482002632475`*^9, 
  3.834948361143017*^9, 3.8349499593900194`*^9, 3.8350089481253815`*^9, 
  3.835023898434498*^9},
 CellLabel->
  "Out[162]=",ExpressionUUID->"7dde0557-986d-4eca-884c-4fd4b37f41d3"]
}, Open  ]],

Cell["Absolute Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.8347951985065947`*^9}},ExpressionUUID->"974f7505-7b8a-45c3-9c7d-\
83ae7161a481"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a\[Rho]6i3", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"AMDi6300", ",", "kri3"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.8348873709111376`*^9, 
   3.8348873755217657`*^9}, {3.8349481641806583`*^9, 
   3.8349481824982553`*^9}, {3.834948329127375*^9, 3.834948332212267*^9}, {
   3.834949883458797*^9, 3.8349498875077024`*^9}, {3.835056968395503*^9, 
   3.835056976026181*^9}},
 CellLabel->
  "In[534]:=",ExpressionUUID->"d39438c1-c401-4ddc-abd2-7ed44c07dd36"],

Cell[BoxData[
 RowBox[{"-", "0.04403262979629878`"}]], "Output",
 CellChangeTimes->{3.834948182946122*^9, 3.8349483612910123`*^9, 
  3.8349499607430162`*^9, 3.835023898451494*^9, 3.8350569922666035`*^9},
 CellLabel->
  "Out[534]=",ExpressionUUID->"3e845861-0124-4997-9b59-61d24b5623f7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"aP6i3", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"AMDi6300", ",", "kri3"}], "}"}], "]"}], ",", "a\[Rho]6i3"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8349482041094093`*^9, 
  3.8349482202691827`*^9}, {3.834948340881687*^9, 3.834948354997751*^9}, {
  3.8349498907390194`*^9, 3.8349498979971194`*^9}, {3.8350569783264713`*^9, 
  3.83505698894604*^9}},
 CellLabel->
  "In[535]:=",ExpressionUUID->"653fe7c1-bd8e-416f-adfa-3d0bb272b01b"],

Cell[BoxData["0.8930149582571227`"], "Output",
 CellChangeTimes->{
  3.834887440036944*^9, 3.8349482220989213`*^9, 3.834948361458013*^9, 
   3.834949962307019*^9, 3.8350238984734964`*^9, {3.8350569897413235`*^9, 
   3.8350569930287075`*^9}},
 CellLabel->
  "Out[535]=",ExpressionUUID->"928bb34b-5965-4f8d-9b45-3c711fa8103e"]
}, Open  ]],

Cell["Max-min Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 3.8347951985065947`*^9}, {
  3.8348543263190746`*^9, 
  3.834854330052075*^9}},ExpressionUUID->"fb4d05a8-dd6b-43d8-9dbf-\
cb9f5cc591a4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mM\[Rho]6i3", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"mMDi6300", ",", "kri3"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8348874651734295`*^9, 3.8348874872060013`*^9}, {
   3.8349482319487157`*^9, 3.834948245258479*^9}, 3.8349483527075925`*^9, {
   3.8349499042423377`*^9, 3.8349499090679235`*^9}, {3.834949978751977*^9, 
   3.8349499794842105`*^9}, {3.83505699643799*^9, 3.8350570016837473`*^9}},
 CellLabel->
  "In[536]:=",ExpressionUUID->"0d154ace-caf9-4ec6-8c7d-9d4f5234ad7b"],

Cell[BoxData[
 RowBox[{"-", "0.06217930065275616`"}]], "Output",
 CellChangeTimes->{
  3.834948246413353*^9, 3.8349483615970154`*^9, {3.834949963955017*^9, 
   3.8349499810066743`*^9}, 3.8350238984924974`*^9, 3.8350570025620856`*^9},
 CellLabel->
  "Out[536]=",ExpressionUUID->"d2f9f5df-073e-4e31-995b-9b9b5e523b92"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mMP6i3", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"mMDi6300", ",", "kri3"}], "}"}], "]"}], ",", "mM\[Rho]6i3"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8348875260806427`*^9, 
  3.8348875488478312`*^9}, {3.8349482525846663`*^9, 3.8349482707073736`*^9}, {
  3.83494834565068*^9, 3.8349483504716325`*^9}, {3.8349499122654495`*^9, 
  3.83494991854418*^9}, {3.8350570049481544`*^9, 3.8350570120793457`*^9}},
 CellLabel->
  "In[537]:=",ExpressionUUID->"21344c17-862f-49cc-934e-447c239a2008"],

Cell[BoxData["0.9480013690168706`"], "Output",
 CellChangeTimes->{
  3.834887440036944*^9, 3.8348875533996215`*^9, 3.834948277702903*^9, 
   3.8349483617580156`*^9, {3.834949965578516*^9, 3.8349499927811513`*^9}, 
   3.835023898515499*^9, 3.8350570125039062`*^9},
 CellLabel->
  "Out[537]=",ExpressionUUID->"30d06509-e431-41d2-9ae5-e6e697dcfd8c"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4th imported file", "Subsection",
 CellChangeTimes->{{3.834947473073307*^9, 3.8349474798089457`*^9}, {
   3.8349497159535103`*^9, 3.8349497173354855`*^9}, {3.834956622993673*^9, 
   3.834956623710862*^9}, 3.8352016148859215`*^9},
 Background->RGBColor[
  1, 1, 0],ExpressionUUID->"bcf23fa3-b03e-41ce-928c-c0d0306ea6d5"],

Cell["Dividing stuff", "Text",
 CellChangeTimes->{{3.83494752022309*^9, 
  3.834947523245259*^9}},ExpressionUUID->"4e1e1f7d-c365-4c3d-9e28-\
975ca404ca7d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data4", "=", 
   RowBox[{"StringSplit", "[", 
    RowBox[{
     RowBox[{"Import", "[", "\"\<ariadnaComputation4.txt\>\"", "]"}], ",", 
     "\"\<]\n{\>\""}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8349434033501863`*^9, 3.834943479535334*^9}, {
   3.834943567297134*^9, 3.8349435736474867`*^9}, {3.8349441109152327`*^9, 
   3.8349441401892223`*^9}, 3.834944204627252*^9, {3.834949720382628*^9, 
   3.8349497230261507`*^9}, {3.834956627593688*^9, 3.834956631231691*^9}},
 CellLabel->
  "In[167]:=",ExpressionUUID->"b4a0bca2-72ff-40c7-8900-2d9c00308ac2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"graphi4", "=", 
   RowBox[{"ToExpression", "@", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"data4", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
       "<>", "\"\<]\>\""}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834944474381714*^9, 3.83494454689666*^9}, 
   3.8349475108233376`*^9, {3.834949726505718*^9, 3.8349497324197383`*^9}, {
   3.8349566345564103`*^9, 3.834956636582815*^9}},
 CellLabel->
  "In[168]:=",ExpressionUUID->"80852a47-c27c-4e51-95eb-cb13a619c54b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"otheri4", "=", 
   RowBox[{"ToExpression", "@", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "<>", "\"\<}}\>\""}], "&"}], ",", 
      RowBox[{"StringSplit", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\"\<{\>\"", "<>", 
          RowBox[{
          "data4", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
         ")"}], ",", "\"\<}}\>\""}], "]"}]}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834944518155362*^9, 3.8349445533517303`*^9}, 
   3.8349446259294133`*^9, {3.8349447635371876`*^9, 3.8349447780382657`*^9}, {
   3.834944820013957*^9, 3.8349448816359477`*^9}, {3.834944915595456*^9, 
   3.834944918286141*^9}, {3.8349449615053425`*^9, 3.834944967406804*^9}, {
   3.834945029266304*^9, 3.834945031628281*^9}, {3.834945108799203*^9, 
   3.8349451822852197`*^9}, 3.834945584171259*^9, {3.834949734758335*^9, 
   3.8349497379503355`*^9}, {3.834956638769047*^9, 3.8349566423540664`*^9}},
 CellLabel->
  "In[169]:=",ExpressionUUID->"9237ab99-75ee-4b22-bf2a-0023e526030a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "CMDi3400", "}"}], ",", 
     RowBox[{"{", "AMDi3400", "}"}], ",", 
     RowBox[{"{", "mMDi3400", "}"}], ",", 
     RowBox[{"{", "CMDi6400", "}"}], ",", 
     RowBox[{"{", "AMDi6400", "}"}], ",", 
     RowBox[{"{", "mMDi6400", "}"}]}], "}"}], "=", "otheri4"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.834945694541313*^9, 3.834945753140644*^9}, {
  3.8349459487260857`*^9, 3.8349459670133495`*^9}, {3.8349471029719105`*^9, 
  3.8349471182020655`*^9}, {3.83494974203613*^9, 3.8349497544188104`*^9}, {
  3.834956647753375*^9, 3.8349566844693546`*^9}},
 CellLabel->
  "In[170]:=",ExpressionUUID->"1482888e-e8d9-49a3-9784-25f94b456975"],

Cell["\[OpenCurlyDoubleQuote]Cleaning\[CloseCurlyDoubleQuote] the graph:", \
"Text",
 CellChangeTimes->{{3.8349477786156034`*^9, 
  3.8349478283202667`*^9}},ExpressionUUID->"b599c76c-1339-4a73-8beb-\
6be63da924da"],

Cell[BoxData[
 RowBox[{
  RowBox[{"graphin4", "=", 
   RowBox[{"IndexGraph", "@", "graphi4"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834946654863307*^9, 3.834946693639777*^9}, {
  3.834949757637121*^9, 3.834949759707878*^9}, {3.8349566892836237`*^9, 
  3.834956691608691*^9}},
 CellLabel->
  "In[171]:=",ExpressionUUID->"cb50788d-e896-4bb9-96fd-150a967b107f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pointsi4", "=", 
   RowBox[{"VertexList", "@", "graphin4"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834784420352569*^9, 3.8347844264642625`*^9}, {
  3.8348756828269844`*^9, 3.8348756865131674`*^9}, {3.834878831782991*^9, 
  3.8348788488376627`*^9}, {3.8349467020325813`*^9, 3.834946739879963*^9}, {
  3.8349497621629615`*^9, 3.8349497641865125`*^9}, {3.834956695197647*^9, 
  3.834956697830969*^9}},
 CellLabel->
  "In[172]:=",ExpressionUUID->"9d2af732-b1f4-4b60-96df-dbc45d6c86f7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"coordpointsi4", "=", 
   RowBox[{"VertexList", "@", "graphi4"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834879134322084*^9, 3.834879146224797*^9}, {
  3.834946724882841*^9, 3.834946736706849*^9}, {3.834949767417904*^9, 
  3.8349497706963253`*^9}, {3.8349567000470257`*^9, 3.8349567019660654`*^9}},
 CellLabel->
  "In[173]:=",ExpressionUUID->"082a91f3-2f43-4560-9915-0e7df3ca947f"],

Cell["Kretchmann \[OpenCurlyDoubleQuote]real\[CloseCurlyDoubleQuote] \
values:", "Text",
 CellChangeTimes->{
  3.8347933561184683`*^9, {3.8347935444076195`*^9, 
   3.834793546974228*^9}},ExpressionUUID->"b3da3db0-285e-40a1-84ea-\
a2d1dda0d9bd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rvali4", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Sinh", "[", "\[Nu]", "]"}], "\[Equal]", "#"}], ",", 
       RowBox[{"{", "\[Nu]", "}"}]}], "]"}], "&"}], "/@", 
    RowBox[{"coordpointsi4", "\[LeftDoubleBracket]", 
     RowBox[{";;", ",", "3"}], "\[RightDoubleBracket]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834105426841242*^9, 3.8341054487325706`*^9}, {
   3.8341407674337025`*^9, 3.834140799285215*^9}, {3.8341408938375945`*^9, 
   3.834140946496229*^9}, {3.8341410168099756`*^9, 3.8341410671886864`*^9}, {
   3.8341411610986195`*^9, 3.834141210381962*^9}, {3.834141332672348*^9, 
   3.834141336755044*^9}, {3.834141461053176*^9, 3.834141468978607*^9}, {
   3.834141967115094*^9, 3.8341420256686225`*^9}, {3.8341640069512*^9, 
   3.834164012603241*^9}, {3.834164792400744*^9, 3.8341647947633886`*^9}, {
   3.83466546628111*^9, 3.834665483801684*^9}, {3.8347933895124626`*^9, 
   3.834793417249506*^9}, 3.8347960586942053`*^9, 3.834879156483405*^9, {
   3.8348862453609915`*^9, 3.8348862641404076`*^9}, 3.834886374221485*^9, {
   3.834946768449996*^9, 3.8349467823353415`*^9}, {3.8349468446168528`*^9, 
   3.834946857637892*^9}, 3.8349474594107084`*^9, {3.834949773350379*^9, 
   3.8349497766098785`*^9}, {3.8349567056279964`*^9, 3.8349567091770997`*^9}},
 CellLabel->
  "In[174]:=",ExpressionUUID->"20e4d4f5-b8a8-4220-b0b5-a422efabf9b4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"kri4", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"KHyperboloid", "/.", "rvali4"}], ")"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834792366597866*^9, 3.834792376019791*^9}, {
   3.834793346399704*^9, 3.8347933590872536`*^9}, {3.834793445378667*^9, 
   3.8347934527754736`*^9}, {3.834793487784485*^9, 3.834793489659489*^9}, 
   3.8348550102643666`*^9, {3.8348863808528233`*^9, 3.83488645374378*^9}, {
   3.834886485165092*^9, 3.834886521271514*^9}, 3.8348865820814276`*^9, {
   3.83494679091998*^9, 3.8349467979310513`*^9}, {3.8349468742957215`*^9, 
   3.834946904080855*^9}, 3.8349474644429636`*^9, {3.834949779141443*^9, 
   3.834949781745859*^9}, {3.8349567110647635`*^9, 3.8349567138998594`*^9}},
 CellLabel->
  "In[175]:=",ExpressionUUID->"f396ba17-881a-4824-993d-23c8159bc5c8"],

Cell["Estimated with cubic Mean Deviation v Calculated: (r=3)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 
  3.8349503319477153`*^9}},ExpressionUUID->"4629a87b-4333-40da-8de1-\
1b12bf69157a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraphb", "[", 
     RowBox[{"graphin4", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsi4", ",", "#"}], "}"}], "]"}], ",", "500", ",", "3"}], 
     "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"CMDi3400", ",", "kri4"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349567344957485`*^9, 3.834956749729442*^9}, {
   3.8349587420893497`*^9, 3.834958755264699*^9}, 3.835051788014969*^9},
 Background->RGBColor[1, 1, 0.85],
 CellLabel->
  "In[403]:=",ExpressionUUID->"877ea5ba-426b-439d-8ce7-67b1680043c9"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN3AuYzmXewPH7z7a1WxZbu0o1DqFsy5TT0CKyGGKYrMNM4zSN46CIkAnD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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[37, 104] -> 
             RGBColor[
              0.4290595493500651, 0.5460515493122077, 0.9485602729754918], 
             UndirectedEdge[119, 243] -> 
             RGBColor[
              0.23779007658236562`, 0.3672628256226794, 0.9368531651312475], 
             UndirectedEdge[165, 226] -> 
             RGBColor[
              0.49203904341994353`, 0.5956210321100361, 0.9539493118510342], 
             UndirectedEdge[235, 261] -> 
             RGBColor[
              0.45150579367600396`, 0.5639692489278748, 0.9504116436839067], 
             UndirectedEdge[56, 198] -> 
             RGBColor[
              0.4367055119429081, 0.5526740978128746, 0.9490474669508485], 
             UndirectedEdge[50, 254] -> 
             RGBColor[
              0.31810851055103634`, 0.4435593049981188, 0.9417246144628966], 
             UndirectedEdge[249, 268] -> 
             RGBColor[
              0.3051594481305492, 0.42687959183385743`, 0.941099571292759], 
             UndirectedEdge[38, 224] -> 
             RGBColor[
              0.5960635299248768, 0.6802523636540716, 0.9628701498266832], 
             UndirectedEdge[79, 87] -> 
             RGBColor[
              0.30275725164593387`, 0.4355474457712999, 0.9405529496407952], 
             UndirectedEdge[38, 311] -> 
             RGBColor[
              0.314519052497135, 0.4371999004889925, 0.9416149103027242], 
             UndirectedEdge[37, 145] -> 
             RGBColor[
              0.6623425399678051, 0.732281090134559, 0.9694869108382729], 
             UndirectedEdge[147, 359] -> 
             RGBColor[
              0.43465423061798325`, 0.5489196469100502, 0.9494632149486012], 
             UndirectedEdge[192, 349] -> 
             RGBColor[
              0.4161236320572723, 0.5346921407353606, 0.9477788256623403], 
             UndirectedEdge[213, 308] -> 
             RGBColor[
              0.22181287368836833`, 0.350469772367916, 0.9359432870625879], 
             UndirectedEdge[262, 397] -> 
             RGBColor[
              0.36384479206171855`, 0.48956580433804925`, 0.944404846308224], 
             UndirectedEdge[129, 364] -> 
             RGBColor[
              0.28437622265530144`, 0.4091697996384081, 0.9397646058909828], 
             UndirectedEdge[54, 83] -> 
             RGBColor[
              0.2376645887247637, 0.3671309299279501, 0.9368460187833998], 
             UndirectedEdge[13, 277] -> 
             RGBColor[
              0.2660921383474147, 0.39701008699210466`, 0.9384649256796189], 
             UndirectedEdge[191, 235] -> 
             RGBColor[
              0.4523572463672474, 0.5647067344537732, 0.9504658974964826], 
             UndirectedEdge[54, 214] -> 
             RGBColor[
              0.2928197128657555, 0.42095740481082217`, 0.9401387923732956], 
             UndirectedEdge[87, 176] -> 
             RGBColor[
              0.42862397234863614`, 0.5429990868352793, 0.9492548723254175], 
             UndirectedEdge[16, 377] -> 
             RGBColor[
              0.42523410434925035`, 0.542134010929524, 0.9484834419757535], 
             UndirectedEdge[158, 344] -> 
             RGBColor[
              0.3145065111634542, 0.4356140856431781, 0.9416717778941766], 
             UndirectedEdge[95, 228] -> 
             RGBColor[
              0.2966341866733978, 0.42503309693245744`, 0.9403535883820795], 
             UndirectedEdge[193, 283] -> 
             RGBColor[
              0.456310023160806, 0.5613065822313281, 0.9518139341791091], 
             UndirectedEdge[11, 366] -> 
             RGBColor[
              0.7086197974446211, 0.7722984385644506, 0.9715922570469223], 
             UndirectedEdge[106, 231] -> 
             RGBColor[
              0.38978028028100054`, 0.5119085219881768, 0.9460909478731268], 
             UndirectedEdge[76, 388] -> 
             RGBColor[
              0.39334817798444677`, 0.5151201543410232, 0.9462847759704004], 
             UndirectedEdge[208, 351] -> 
             RGBColor[
              0.3245853530999122, 0.4546021280284075, 0.9419383877837022], 
             UndirectedEdge[208, 225] -> 
             RGBColor[
              0.3783304253405996, 0.5021125318151178, 0.9453278580516117], 
             UndirectedEdge[163, 374] -> 
             RGBColor[
              0.3785263005293362, 0.49969603587544964`, 0.945550535956833], 
             UndirectedEdge[165, 288] -> 
             RGBColor[
              0.35971837799736545`, 0.4859917118751079, 0.944141914852888], 
             UndirectedEdge[110, 239] -> 
             RGBColor[
              0.3290148182199084, 0.453826869880462, 0.942389491372604], 
             UndirectedEdge[14, 273] -> 
             RGBColor[
              0.31277887220929795`, 0.4431380988406663, 0.9412314129716111], 
             UndirectedEdge[231, 372] -> 
             RGBColor[
              0.31985654593988244`, 0.4396188844598151, 0.94206478684874], 
             UndirectedEdge[5, 162] -> 
             RGBColor[
              0.4176731562326734, 0.5361892278906815, 0.9478347420746438], 
             UndirectedEdge[36, 90] -> 
             RGBColor[
              0.583147820117444, 0.6654355671624435, 0.9636013142161808], 
             UndirectedEdge[258, 328] -> 
             RGBColor[
              0.31216047928985435`, 0.4402268439525911, 0.9412789931205052], 
             UndirectedEdge[91, 208] -> 
             RGBColor[
              0.4541083128700075, 0.5649209654558992, 0.9509373460451624], 
             UndirectedEdge[155, 370] -> 
             RGBColor[
              0.31753717500632817`, 0.4406802809774522, 0.9417755053130255], 
             UndirectedEdge[66, 243] -> 
             RGBColor[
              0.5162505847811232, 0.6101248817825817, 0.9574497527336324], 
             UndirectedEdge[253, 334] -> 
             RGBColor[
              0.34492868721767933`, 0.4723893941947755, 0.9432285362877151], 
             UndirectedEdge[50, 210] -> 
             RGBColor[
              0.5203980192475548, 0.619953682343107, 0.9558314253436271], 
             UndirectedEdge[239, 365] -> 
             RGBColor[
              0.6798144276394691, 0.745720715480676, 0.958342184145386], 
             UndirectedEdge[13, 51] -> 
             RGBColor[
              0.4261046754744209, 0.5402466053624965, 0.9491209180424394], 
             UndirectedEdge[258, 300] -> 
             RGBColor[
              0.502431005714497, 0.5955131092121666, 0.9566764453393188], 
             UndirectedEdge[30, 294] -> 
             RGBColor[
              0.4463853368997126, 0.5538670505429453, 0.9509763927327985], 
             UndirectedEdge[31, 292] -> 
             RGBColor[
              0.34799167068220427`, 0.4717108787293341, 0.9435456900718073], 
             UndirectedEdge[203, 216] -> 
             RGBColor[
              0.28192360376204434`, 0.40881296027387726`, 0.9395436105025605],
              UndirectedEdge[64, 233] -> 
             RGBColor[
              0.6626604874496049, 0.2495746934509701, 0.42405723695495967`], 
             UndirectedEdge[50, 242] -> 
             RGBColor[
              0.46525159934266525`, 0.575211378566935, 0.9514709231739868], 
             UndirectedEdge[133, 398] -> 
             RGBColor[
              0.3436871423874652, 0.47032013701100694`, 0.943185817457036], 
             UndirectedEdge[7, 390] -> 
             RGBColor[
              0.6942427353695978, 0.7610669684017235, 0.9701592858605679], 
             UndirectedEdge[186, 342] -> 
             RGBColor[
              0.5179167290078415, 0.6176322093039792, 0.9557462470049176], 
             UndirectedEdge[347, 398] -> 
             RGBColor[
              0.2938443902487113, 0.41793224430016573`, 0.940347346458478], 
             UndirectedEdge[321, 375] -> 
             RGBColor[
              0.26346785646448745`, 0.3942518003440666, 0.9383154767086632], 
             UndirectedEdge[149, 279] -> 
             RGBColor[
              0.3327755542981793, 0.4572169303586688, 0.9426242633563702], 
             UndirectedEdge[38, 306] -> 
             RGBColor[
              0.4116309085152033, 0.5309557366100093, 0.9474497353930363], 
             UndirectedEdge[12, 358] -> 
             RGBColor[
              0.2933026519412741, 0.41740361217462923`, 0.9403150025037688], 
             UndirectedEdge[139, 378] -> 
             RGBColor[
              0.558720129286741, 0.6487647773545002, 0.9601277731065874], 
             UndirectedEdge[272, 374] -> 
             RGBColor[
              0.4329090453962371, 0.5489038914396962, 0.9489387092758825], 
             UndirectedEdge[21, 114] -> 
             RGBColor[
              0.2550913227765558, 0.38544753233513956`, 0.9378384455071067], 
             UndirectedEdge[250, 321] -> 
             RGBColor[
              0.3408713580680569, 0.4653695056150755, 0.9430983652954807], 
             UndirectedEdge[19, 152] -> 
             RGBColor[
              0.3125665306304194, 0.440298006507962, 0.9413151382491884], 
             UndirectedEdge[270, 336] -> 
             RGBColor[
              0.2018795970887927, 0.32951863481902943`, 0.9348081164488823], 
             UndirectedEdge[87, 277] -> 
             RGBColor[
              0.26904844485534046`, 0.40011735257259334`, 0.9386332829617816],
              UndirectedEdge[37, 377] -> 
             RGBColor[
              0.3939768388740182, 0.5156646688061549, 0.9463248336863809], 
             UndirectedEdge[312, 356] -> 
             RGBColor[
              0.30268137064558565`, 0.4250143200444211, 0.940931377412308], 
             UndirectedEdge[294, 343] -> 
             RGBColor[
              0.24653697026784116`, 0.3764563654712052, 0.9373512877867658], 
             UndirectedEdge[170, 349] -> 
             RGBColor[
              0.4706543602164961, 0.5789626424363271, 0.9520716843356734], 
             UndirectedEdge[176, 390] -> 
             RGBColor[
              0.6420412281963688, 0.7188606027060882, 0.9659313950771236], 
             UndirectedEdge[235, 327] -> 
             RGBColor[
              0.3830240852140834, 0.4998324335736244, 0.9462245849029391], 
             UndirectedEdge[271, 400] -> 
             RGBColor[
              0.3192493857619392, 0.4478199203696701, 0.9416774897217803], 
             UndirectedEdge[45, 103] -> 
             RGBColor[
              0.503196287699479, 0.6065525548675816, 0.9543099782323532], 
             UndirectedEdge[30, 343] -> 
             RGBColor[
              0.41462741949187853`, 0.5204874657790498, 0.949167826318051], 
             UndirectedEdge[200, 234] -> 
             RGBColor[
              0.4872661341795151, 0.5903991349449189, 0.9540831721556672], 
             UndirectedEdge[282, 382] -> 
             RGBColor[
              0.25514559786847923`, 0.3855045788979907, 0.9378415363932988], 
             UndirectedEdge[305, 382] -> 
             RGBColor[
              0.2463547834040689, 0.37626487552606624`, 0.9373409125143952], 
             UndirectedEdge[50, 164] -> 
             RGBColor[
              0.40611545058610343`, 0.5261785241667989, 0.9470982952909222], 
             UndirectedEdge[259, 287] -> 
             RGBColor[
              0.39933117614422986`, 0.5203023266327962, 0.9466660073225842], 
             UndirectedEdge[90, 95] -> 
             RGBColor[
              0.605641629517414, 0.6849993677037357, 0.9650316416181075], 
             UndirectedEdge[44, 243] -> 
             RGBColor[
              0.4612823892907527, 0.5670705035396909, 0.9520481628963953], 
             UndirectedEdge[82, 194] -> 
             RGBColor[
              0.3719483407706125, 0.49658469093349245`, 0.9449211972662679], 
             UndirectedEdge[124, 150] -> 
             RGBColor[
              0.4885320918515657, 0.5948300610445724, 0.9531051168755444], 
             UndirectedEdge[233, 316] -> 
             RGBColor[
              0.6579368911480887, 0.2454833517494499, 0.42375625357553925`], 
             UndirectedEdge[87, 390] -> 
             RGBColor[
              0.5214047830158487, 0.6169063128345438, 0.9575273288459903], 
             UndirectedEdge[72, 376] -> 
             RGBColor[
              0.2152977024227995, 0.3436219142820862, 0.935572257697346], 
             UndirectedEdge[99, 169] -> 
             RGBColor[
              0.6597644356217042, 0.730027863625674, 0.9693319364470201], 
             UndirectedEdge[127, 137] -> 
             RGBColor[
              0.6916628484086904, 0.7548641435232208, 0.942764855624637], 
             UndirectedEdge[68, 391] -> 
             RGBColor[
              0.42597283246750234`, 0.5433779902914334, 0.9483635901052114], 
             UndirectedEdge[292, 309] -> 
             RGBColor[
              0.28032751008556567`, 0.4119723652635998, 0.9392756090407612], 
             UndirectedEdge[88, 140] -> 
             RGBColor[
              0.3745459542603531, 0.49883461317845557`, 0.9450867149008548], 
             UndirectedEdge[153, 216] -> 
             RGBColor[
              0.28460330401715694`, 0.4111339819492048, 0.9397143586332504], 
             UndirectedEdge[145, 165] -> 
             RGBColor[
              0.6294877451842205, 0.7038239182230183, 0.9673934323670172], 
             UndirectedEdge[37, 76] -> 
             RGBColor[
              0.3761624686083318, 0.5002347566583012, 0.9451897177656805], 
             UndirectedEdge[6, 391] -> 
             RGBColor[
              0.6440824603578597, 0.7189368207058582, 0.967185538312024], 
             UndirectedEdge[203, 206] -> 
             RGBColor[
              0.35831968112500334`, 0.4847802309448167, 0.9440527911250002], 
             UndirectedEdge[298, 320] -> 
             RGBColor[
              0.735055587104642, 0.7912652437287115, 0.9491810738138217], 
             UndirectedEdge[39, 164] -> 
             RGBColor[
              0.35411726005158994`, 0.47964841624780197`, 0.9438396419268027],
              UndirectedEdge[107, 156] -> 
             RGBColor[
              0.4352493604431399, 0.5490158323945837, 0.9496169860818751], 
             UndirectedEdge[31, 222] -> 
             RGBColor[
              0.34181620344627384`, 0.4652200711171337, 0.9431940063485061], 
             UndirectedEdge[301, 329] -> 
             RGBColor[
              0.3159315590071293, 0.4399044828698345, 0.9416506821689066], 
             UndirectedEdge[126, 320] -> 
             RGBColor[
              0.5934029680323232, 0.6619442594852092, 0.940060545984561], 
             UndirectedEdge[49, 191] -> 
             RGBColor[
              0.3994785064049896, 0.5204299366996321, 0.9466753950765208], 
             UndirectedEdge[122, 173] -> 
             RGBColor[
              0.3302273145917095, 0.4521933774473511, 0.9425650138206703], 
             UndirectedEdge[60, 102] -> 
             RGBColor[
              0.3507741662489978, 0.47824468520782554`, 0.943571997589338], 
             UndirectedEdge[120, 380] -> 
             RGBColor[
              0.3548520635155872, 0.4785904473603473, 0.9439485039232633], 
             UndirectedEdge[110, 247] -> 
             RGBColor[
              0.37378391412344647`, 0.4913611583833361, 0.9455854318229407], 
             UndirectedEdge[59, 149] -> 
             RGBColor[
              0.29686014620171963`, 0.42610880902641374`, 0.9403357653112121],
              UndirectedEdge[92, 346] -> 
             RGBColor[
              0.529326362006567, 0.6223109649381697, 0.9584409562400533], 
             UndirectedEdge[6, 142] -> 
             RGBColor[
              0.8716131209686426, 0.9004646596252406, 0.9876164316478495], 
             UndirectedEdge[176, 232] -> 
             RGBColor[
              0.44661467745898087`, 0.5586518573583492, 0.9503986564902724], 
             UndirectedEdge[60, 345] -> 
             RGBColor[
              0.29330335211106706`, 0.42043069597593163`, 0.9402042329566408],
              UndirectedEdge[79, 126] -> 
             RGBColor[
              0.2596802157124989, 0.39027074976343246`, 0.9380997761711498], 
             UndirectedEdge[14, 212] -> 
             RGBColor[
              0.2784564154111087, 0.4070630205763188, 0.9392767998324787], 
             UndirectedEdge[22, 338] -> 
             RGBColor[
              0.41399801851110696`, 0.5330060083140533, 0.9476005655488222], 
             UndirectedEdge[195, 389] -> 
             RGBColor[
              0.3765762497706513, 0.4864350255186002, 0.946460013297822], 
             UndirectedEdge[14, 293] -> 
             RGBColor[
              0.2891141295358485, 0.4182649538595246, 0.9398837408852075], 
             UndirectedEdge[201, 394] -> 
             RGBColor[
              0.25511607245644247`, 0.3854735458179208, 0.9378398549647624], 
             UndirectedEdge[20, 189] -> 
             RGBColor[
              0.24208672072774712`, 0.3717788710424486, 0.9370978526590117], 
             UndirectedEdge[195, 359] -> 
             RGBColor[
              0.45397571595956177`, 0.564605699133339, 0.9509842730516231], 
             UndirectedEdge[222, 224] -> 
             RGBColor[
              0.5096685052046901, 0.6001556586303735, 0.9575579374753759], 
             UndirectedEdge[54, 389] -> 
             RGBColor[
              0.2102070848149799, 0.33827135241246953`, 0.9352823545554745], 
             UndirectedEdge[123, 366] -> 
             RGBColor[
              0.4939271884319915, 0.5967309548134938, 0.9542695956945524], 
             UndirectedEdge[120, 263] -> 
             RGBColor[
              0.42129425182405256`, 0.5393256388903777, 0.9480654750837172], 
             UndirectedEdge[332, 364] -> 
             RGBColor[
              0.24057962139849923`, 0.3701948140917926, 0.9370120255817647], 
             UndirectedEdge[70, 228] -> 
             RGBColor[
              0.6138017101706127, 0.6794939030450512, 0.8994404295239377], 
             UndirectedEdge[74, 141] -> 
             RGBColor[
              0.3578985708077199, 0.482921237251163, 0.9440806701273567], 
             UndirectedEdge[212, 385] -> 
             RGBColor[
              0.48957957933892293`, 0.5796782708985421, 0.9563130014727718], 
             UndirectedEdge[256, 384] -> 
             RGBColor[
              0.3097136995340689, 0.43540967827579896`, 0.9412218693748171], 
             UndirectedEdge[158, 317] -> 
             RGBColor[
              0.3450419389801562, 0.46770875633647696`, 0.9434107253352205], 
             UndirectedEdge[76, 208] -> 
             RGBColor[
              0.34503513360542426`, 0.4732738235841299, 0.9432063115041167], 
             UndirectedEdge[101, 253] -> 
             RGBColor[
              0.39514045276771914`, 0.5148814875320402, 0.9467039609455591], 
             UndirectedEdge[111, 309] -> 
             RGBColor[
              0.3034055799586872, 0.43608517812100767`, 0.9405951326064195], 
             UndirectedEdge[145, 170] -> 
             RGBColor[
              0.7398593694111419, 0.7963060302568434, 0.9752872414575811], 
             UndirectedEdge[59, 279] -> 
             RGBColor[
              0.3797091696858843, 0.5033067308692978, 0.9454157104221175], 
             UndirectedEdge[83, 334] -> 
             RGBColor[
              0.3164740695065664, 0.44248178685343154`, 0.9416080879039018], 
             UndirectedEdge[242, 312] -> 
             RGBColor[
              0.3587257240308266, 0.4713692166920729, 0.9451069988282795], 
             UndirectedEdge[140, 356] -> 
             RGBColor[
              0.38230023234440325`, 0.505550979113511, 0.9455808106435315], 
             UndirectedEdge[172, 316] -> 
             RGBColor[
              0.2637628866395626, 0.3917487419120175, 0.938435281583774], 
             UndirectedEdge[217, 331] -> 
             RGBColor[
              0.312026021155332, 0.43560624132103987`, 0.941435344260749], 
             UndirectedEdge[263, 336] -> 
             RGBColor[
              0.29484867463317666`, 0.41813526883792984`, 0.9404357547083059],
              UndirectedEdge[122, 338] -> 
             RGBColor[
              0.43476713737598727`, 0.5509951751885462, 0.9489239554374816], 
             UndirectedEdge[303, 400] -> 
             RGBColor[
              0.4134308830225186, 0.5267196415203234, 0.9484179161142381], 
             UndirectedEdge[133, 367] -> 
             RGBColor[
              0.3399560673020606, 0.467088467301316, 0.9429480766518542], 
             UndirectedEdge[136, 279] -> 
             RGBColor[
              0.30915242006442445`, 0.4323875184857736, 0.9412789608090533], 
             UndirectedEdge[117, 365] -> 
             RGBColor[
              0.6490142207902415, 0.7190431243712834, 0.9563796222005068], 
             UndirectedEdge[33, 245] -> 
             RGBColor[
              0.3438603717279032, 0.465673731471384, 0.9433724769378949], 
             UndirectedEdge[162, 368] -> 
             RGBColor[
              0.35237292876352183`, 0.4790450429792539, 0.9436952674345638], 
             UndirectedEdge[46, 128] -> 
             RGBColor[
              0.36531266707208715`, 0.490188261363094, 0.9445221389708915], 
             UndirectedEdge[117, 269] -> 
             RGBColor[
              0.26664251011997886`, 0.39396499856974454`, 0.9386289449682355],
              UndirectedEdge[98, 134] -> 
             RGBColor[
              0.35754832514074986`, 0.48313544815262705`, 0.9440394017869447],
              UndirectedEdge[90, 326] -> 
             RGBColor[
              0.5776112280444863, 0.6596162578535524, 0.9632860134882798], 
             UndirectedEdge[119, 306] -> 
             RGBColor[
              0.29334450951824415`, 0.4173391751915072, 0.9403213564557271], 
             UndirectedEdge[150, 211] -> 
             RGBColor[
              0.5299018917302543, 0.6284159282743378, 0.956361899064565], 
             UndirectedEdge[388, 395] -> 
             RGBColor[
              0.3908557371692224, 0.5129613273805937, 0.9461259598456332], 
             UndirectedEdge[102, 108] -> 
             RGBColor[
              0.27563673886155354`, 0.4044505870079427, 0.9391033633469204], 
             UndirectedEdge[15, 392] -> 
             RGBColor[
              0.5608470382962906, 0.6540487978923428, 0.9587837939046493], 
             UndirectedEdge[32, 292] -> 
             RGBColor[
              0.28386928695489866`, 0.4156949973148924, 0.9394773079938805], 
             UndirectedEdge[115, 332] -> 
             RGBColor[
              0.24847532066764905`, 0.37849369463991694`, 0.9374616739745024],
              UndirectedEdge[93, 293] -> 
             RGBColor[
              0.20982393743288352`, 0.3378686402209391, 0.9352605348788798], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.3711431632156278, 0.49491061359665695`, 0.9449056528476327], 
             UndirectedEdge[276, 305] -> 
             RGBColor[
              0.3006044237454838, 0.4290693005647257, 0.9405846952291841], 
             UndirectedEdge[75, 347] -> 
             RGBColor[
              0.5646537359850512, 0.6356049338669465, 0.9606505093994288], 
             UndirectedEdge[64, 193] -> 
             RGBColor[
              0.3132366987531669, 0.4424386690072624, 0.9413007143306729], 
             UndirectedEdge[18, 99] -> 
             RGBColor[
              0.42016750166141875`, 0.5383497045316141, 0.9479936795597004], 
             UndirectedEdge[74, 290] -> 
             RGBColor[
              0.4470442918043138, 0.5561111782378115, 0.9508726898469093], 
             UndirectedEdge[39, 230] -> 
             RGBColor[
              0.3012233549407334, 0.4338343741657489, 0.9404692890653826], 
             UndirectedEdge[259, 345] -> 
             RGBColor[
              0.2976037303479497, 0.4241554674614245, 0.9404782492552198], 
             UndirectedEdge[30, 168] -> 
             RGBColor[
              0.48014767096609356`, 0.5859257007604816, 0.9530246127286695], 
             UndirectedEdge[231, 331] -> 
             RGBColor[
              0.43563210084782567`, 0.5516230643836504, 0.9490125853344719], 
             UndirectedEdge[137, 242] -> 
             RGBColor[
              0.4742676157127719, 0.5830205987885625, 0.9520454157645399], 
             UndirectedEdge[172, 221] -> 
             RGBColor[
              0.2705147637280181, 0.3975968784868279, 0.9388655052213999], 
             UndirectedEdge[157, 211] -> 
             RGBColor[
              0.5405534570037609, 0.6376417787510122, 0.9570406073849835], 
             UndirectedEdge[46, 213] -> 
             RGBColor[
              0.24474198659438468`, 0.37456972382186426`, 0.9372490661220028],
              UndirectedEdge[184, 318] -> 
             RGBColor[
              0.3709398870874825, 0.4861889349222955, 0.945622176263597], 
             UndirectedEdge[201, 293] -> 
             RGBColor[
              0.2607710241397998, 0.3914172585817747, 0.9381618960973782], 
             UndirectedEdge[64, 115] -> 
             RGBColor[
              0.27640138510843804`, 0.40372241887287563`, 0.9392029977115688],
              UndirectedEdge[174, 266] -> 
             RGBColor[
              0.3413186912644534, 0.47005482802220433`, 0.942969503084471], 
             UndirectedEdge[80, 104] -> 
             RGBColor[
              0.33796951638667605`, 0.45995405517952587`, 0.9430197197150556],
              UndirectedEdge[265, 321] -> 
             RGBColor[
              0.27995911798998896`, 0.4115851618137407, 0.9392546296559054], 
             UndirectedEdge[178, 296] -> 
             RGBColor[
              0.5459231614742472, 0.6315864895770376, 0.9606793546196979], 
             UndirectedEdge[114, 249] -> 
             RGBColor[
              0.3517559007598093, 0.4758554179329437, 0.9437531703367211], 
             UndirectedEdge[255, 380] -> 
             RGBColor[
              0.33841816989285706`, 0.46435623469584875`, 0.9429013507535445],
              UndirectedEdge[253, 391] -> 
             RGBColor[
              0.3742930086491344, 0.4978232935249932, 0.9450996048834774], 
             UndirectedEdge[40, 63] -> 
             RGBColor[
              0.41011882220556206`, 0.5270437380275292, 0.9478829186762534], 
             UndirectedEdge[23, 311] -> 
             RGBColor[
              0.43594394135082615`, 0.5361742097894691, 0.9512209588155527], 
             UndirectedEdge[156, 396] -> 
             RGBColor[
              0.3522429661392933, 0.4795168858487705, 0.9436655882195388], 
             UndirectedEdge[93, 281] -> 
             RGBColor[
              0.3440080289890475, 0.4592340104485719, 0.9439653642305587], 
             UndirectedEdge[27, 325] -> 
             RGBColor[
              0.3738678249541858, 0.4950832338236514, 0.9452594320758394], 
             UndirectedEdge[12, 107] -> 
             RGBColor[
              0.36534895886266183`, 0.4774094818997658, 0.9455680332897194], 
             UndirectedEdge[255, 312] -> 
             RGBColor[
              0.2930537814816602, 0.41667538620733025`, 0.9403179159441255], 
             UndirectedEdge[257, 310] -> 
             RGBColor[
              0.22327809201599425`, 0.3520098097304584, 0.9360267290787501], 
             UndirectedEdge[50, 197] -> 
             RGBColor[
              0.4280452751041821, 0.5450056084243284, 0.9485419050386771], 
             UndirectedEdge[215, 350] -> 
             RGBColor[
              0.36918534496674715`, 0.4848974998485005, 0.9454719474992561], 
             UndirectedEdge[49, 235] -> 
             RGBColor[
              0.4565710256375674, 0.5683564982670202, 0.9507343957854888], 
             UndirectedEdge[239, 323] -> 
             RGBColor[
              0.3358172290476781, 0.46097663495820496`, 0.9427768786059805], 
             UndirectedEdge[211, 216] -> 
             RGBColor[
              0.41975972505853665`, 0.5232194911719175, 0.9497024474718663], 
             UndirectedEdge[98, 151] -> 
             RGBColor[
              0.3838827360190774, 0.5055033575810177, 0.945839431859945], 
             UndirectedEdge[10, 32] -> 
             RGBColor[
              0.24567564942948578`, 0.37555106265919835`, 0.9373022368392314],
              UndirectedEdge[330, 367] -> 
             RGBColor[
              0.30392924660370463`, 0.42922199451498055`, 0.9408964025099879],
              UndirectedEdge[99, 384] -> 
             RGBColor[
              0.31870940313582824`, 0.44320130459843343`, 0.9417950676537329],
              UndirectedEdge[127, 138] -> 
             RGBColor[
              0.5773563512856834, 0.6445112394367143, 0.9358967925809056], 
             UndirectedEdge[292, 385] -> 
             RGBColor[
              0.5134821664072813, 0.6048014054189386, 0.957674218445606], 
             UndirectedEdge[177, 219] -> 
             RGBColor[
              0.2583998798867059, 0.3889250356325441, 0.9380268629399581], 
             UndirectedEdge[170, 322] -> 
             RGBColor[
              0.4965674459719359, 0.6014072548881292, 0.9537228432459679], 
             UndirectedEdge[261, 335] -> 
             RGBColor[
              0.3875581837907631, 0.5101051523840242, 0.9459158426602696], 
             UndirectedEdge[6, 253] -> 
             RGBColor[
              0.5699667947853777, 0.6539493254701992, 0.9624919610929539], 
             UndirectedEdge[95, 246] -> 
             RGBColor[
              0.40373221693338235`, 0.5240793509861914, 0.9469560906640837], 
             UndirectedEdge[50, 331] -> 
             RGBColor[
              0.4050425937382462, 0.525249269488538, 0.9470299338012667], 
             UndirectedEdge[9, 358] -> 
             RGBColor[
              0.3601754207746066, 0.4863875793571163, 0.9441710372145068], 
             UndirectedEdge[99, 144] -> 
             RGBColor[
              0.4345809747212525, 0.5506021986143326, 0.9489761215154355], 
             UndirectedEdge[2, 28] -> 
             RGBColor[
              0.39479390093917255`, 0.5163723669002582, 0.9463768961586729], 
             UndirectedEdge[138, 258] -> 
             RGBColor[
              0.22265734954202776`, 0.3513573700329736, 0.9359913787131638], 
             UndirectedEdge[144, 384] -> 
             RGBColor[
              0.34598093412798914`, 0.4665908021973509, 0.9435968136909818], 
             UndirectedEdge[79, 277] -> 
             RGBColor[
              0.26381816933315827`, 0.3946200013801584, 0.9383354265082926], 
             UndirectedEdge[346, 354] -> 
             RGBColor[
              0.5485766865539135, 0.6395918015949325, 0.9596453383169263], 
             UndirectedEdge[144, 148] -> 
             RGBColor[
              0.38101492439503293`, 0.5034137472512921, 0.9455919476085459], 
             UndirectedEdge[38, 346] -> 
             RGBColor[
              0.590528527860057, 0.6759283779734608, 0.9623184725483971], 
             UndirectedEdge[38, 363] -> 
             RGBColor[
              0.3333629807403148, 0.45700606384663195`, 0.9426880441390796], 
             UndirectedEdge[78, 104] -> 
             RGBColor[
              0.4230020806128471, 0.5408048743492607, 0.9481742964239656], 
             UndirectedEdge[95, 282] -> 
             RGBColor[
              0.3086556105681386, 0.43766837564812766`, 0.9410381906887821], 
             UndirectedEdge[92, 306] -> 
             RGBColor[
              0.3504287426617133, 0.4773383235747183, 0.9435722190846926], 
             UndirectedEdge[9, 339] -> 
             RGBColor[
              0.30325277142100315`, 0.43476471563288704`, 0.9406288982140053],
              UndirectedEdge[36, 148] -> 
             RGBColor[
              0.3040247464970235, 0.4368796632236103, 0.9406251315974741], 
             UndirectedEdge[62, 395] -> 
             RGBColor[
              0.315435518646874, 0.44651167425754806`, 0.9413614218564724], 
             UndirectedEdge[32, 247] -> 
             RGBColor[
              0.40133550801582585`, 0.5203196304361741, 0.9471544543361812], 
             UndirectedEdge[168, 379] -> 
             RGBColor[
              0.3339730566654361, 0.4636924085348655, 0.9425014457433113], 
             UndirectedEdge[137, 230] -> 
             RGBColor[
              0.3622375618453535, 0.48817370230637336`, 0.9443024350200551], 
             UndirectedEdge[268, 279] -> 
             RGBColor[
              0.29806932864427377`, 0.42073848669461267`, 0.94064779514864], 
             UndirectedEdge[185, 288] -> 
             RGBColor[
              0.42172555069878326`, 0.5392093833668172, 0.9482282971545408], 
             UndirectedEdge[233, 310] -> 
             RGBColor[
              0.6270577168155351, 0.21490281757456758`, 0.42192906138354613`],
              UndirectedEdge[150, 386] -> 
             RGBColor[
              0.39337573041046753`, 0.5151440188676172, 0.9462865315866228], 
             UndirectedEdge[138, 281] -> 
             RGBColor[
              0.34602395890708204`, 0.4613528806097655, 0.9440801684570896], 
             UndirectedEdge[88, 257] -> 
             RGBColor[
              0.3031603229711344, 0.4269516012868123, 0.940906151961485], 
             UndirectedEdge[27, 40] -> 
             RGBColor[
              0.38444523886173065`, 0.5062007664872575, 0.9458618001499925], 
             UndirectedEdge[159, 250] -> 
             RGBColor[
              0.33962566484498014`, 0.4640602030561098, 0.9430274249092645], 
             UndirectedEdge[169, 363] -> 
             RGBColor[
              0.5771810776607114, 0.6523403821349208, 0.96429526979759], 
             UndirectedEdge[144, 382] -> 
             RGBColor[
              0.3538461245157146, 0.47485761597672344`, 0.9440447246480563], 
             UndirectedEdge[35, 207] -> 
             RGBColor[
              0.3906855748518043, 0.5123233460015316, 0.946250670205286], 
             UndirectedEdge[71, 287] -> 
             RGBColor[
              0.3528062977889359, 0.47737703030729073`, 0.9437976992992465], 
             UndirectedEdge[148, 361] -> 
             RGBColor[
              0.4278258971485843, 0.5414170037429158, 0.9492770788579487], 
             UndirectedEdge[215, 393] -> 
             RGBColor[
              0.5234980754913647, 0.6240383468602617, 0.9556308326207674], 
             UndirectedEdge[33, 124] -> 
             RGBColor[
              0.5020829351949274, 0.6065671204634024, 0.9539685646308431], 
             UndirectedEdge[31, 111] -> 
             RGBColor[
              0.3710697405553258, 0.4958236915867419, 0.9448652136374655], 
             UndirectedEdge[113, 357] -> 
             RGBColor[
              0.5581024680331361, 0.636157128686124, 0.9626225572336329], 
             UndirectedEdge[30, 329] -> 
             RGBColor[
              0.4174752301837634, 0.5234806953778474, 0.9493300049239954], 
             UndirectedEdge[117, 239] -> 
             RGBColor[
              0.37873816217056155`, 0.502465692963782, 0.9453538386818694], 
             UndirectedEdge[209, 338] -> 
             RGBColor[
              0.5086817828757734, 0.6113371527842292, 0.9546502978274238], 
             UndirectedEdge[208, 323] -> 
             RGBColor[
              0.30644726966828084`, 0.4355378523208513, 0.9409054507651606], 
             UndirectedEdge[71, 212] -> 
             RGBColor[
              0.24833159662617993`, 0.3783426315597024, 0.9374534891029614], 
             UndirectedEdge[199, 292] -> 
             RGBColor[
              0.22578226524581724`, 0.3546418545687555, 0.9361693380395961], 
             UndirectedEdge[11, 386] -> 
             RGBColor[
              0.5648928177309122, 0.6533150357936209, 0.9608580868753814], 
             UndirectedEdge[130, 267] -> 
             RGBColor[
              0.41089319858962225`, 0.522910199057897, 0.9483773666330338], 
             UndirectedEdge[67, 347] -> 
             RGBColor[
              0.3291694320065597, 0.4481141637642143, 0.9427128528917824], 
             UndirectedEdge[211, 358] -> 
             RGBColor[
              0.5171201774428971, 0.6173450497862686, 0.9555474595326008], 
             UndirectedEdge[2, 164] -> 
             RGBColor[
              0.42225479624494683`, 0.54015761418939, 0.9481266801248406], 
             UndirectedEdge[266, 358] -> 
             RGBColor[
              0.35424296220959706`, 0.4812491819221423, 0.9437930262006116], 
             UndirectedEdge[57, 397] -> 
             RGBColor[
              0.266398856292208, 0.39623213023189846`, 0.9385226815320072], 
             UndirectedEdge[209, 386] -> 
             RGBColor[
              0.47625068014290645`, 0.5832469616316385, 0.9525838166389837], 
             UndirectedEdge[74, 386] -> 
             RGBColor[
              0.3281333234706979, 0.45714007605266505`, 0.9421840548874165], 
             UndirectedEdge[47, 268] -> 
             RGBColor[
              0.2493647169807538, 0.3785530000366316, 0.9375443803612376], 
             UndirectedEdge[108, 397] -> 
             RGBColor[
              0.26757274035215856`, 0.3974659568074547, 0.9385895324926157], 
             UndirectedEdge[157, 358] -> 
             RGBColor[
              0.4209390783064113, 0.5390180054409369, 0.9480428437412408], 
             UndirectedEdge[10, 129] -> 
             RGBColor[
              0.2864206898175132, 0.4113186642525976, 0.9398810352713525], 
             UndirectedEdge[171, 308] -> 
             RGBColor[
              0.34998639350824, 0.4726735072175164, 0.9437008061114329], 
             UndirectedEdge[225, 335] -> 
             RGBColor[
              0.3937084731247739, 0.5154322238826143, 0.9463077336581456], 
             UndirectedEdge[45, 116] -> 
             RGBColor[
              0.4302052765777473, 0.5397826967884024, 0.9497889913094454], 
             UndirectedEdge[261, 349] -> 
             RGBColor[
              0.3833918815158458, 0.5064965107579319, 0.9456503695634284], 
             UndirectedEdge[118, 209] -> 
             RGBColor[
              0.3948654421328919, 0.5027851465033322, 0.9477630722362484], 
             UndirectedEdge[329, 343] -> 
             RGBColor[
              0.21762686355189195`, 0.3460700103061074, 0.9357048999779627], 
             UndirectedEdge[163, 171] -> 
             RGBColor[
              0.36504527797870423`, 0.4885013495843957, 0.9445583873044027], 
             UndirectedEdge[106, 217] -> 
             RGBColor[
              0.2661742005885068, 0.3958916989255662, 0.9385137067994039], 
             UndirectedEdge[55, 123] -> 
             RGBColor[
              0.28097374812527676`, 0.4100653828906481, 0.9394071055068757], 
             UndirectedEdge[129, 353] -> 
             RGBColor[
              0.31678790170043447`, 0.4432365293339866, 0.9416104030638208], 
             UndirectedEdge[38, 66] -> 
             RGBColor[
              0.584757342875322, 0.6714198844007553, 0.9617432547639087], 
             UndirectedEdge[23, 119] -> 
             RGBColor[
              0.42772172353025556`, 0.5275321375413297, 0.9507527156743524], 
             UndirectedEdge[306, 354] -> 
             RGBColor[
              0.36967906720905974`, 0.49461916023148095`, 0.9447766011615656],
              UndirectedEdge[28, 39] -> 
             RGBColor[
              0.3266563647458157, 0.4558631689586702, 0.9420898579606349], 
             UndirectedEdge[158, 267] -> 
             RGBColor[
              0.5014992937161936, 0.6058603729670411, 0.9539869750161167], 
             UndirectedEdge[194, 399] -> 
             RGBColor[
              0.3687090668542313, 0.493778994677764, 0.9447147935966935], 
             UndirectedEdge[102, 333] -> 
             RGBColor[
              0.34406339251805484`, 0.4724321502953778, 0.9431443930213066], 
             UndirectedEdge[16, 80] -> 
             RGBColor[
              0.35322035277865305`, 0.4725594329374971, 0.9441584124971729], 
             UndirectedEdge[72, 333] -> 
             RGBColor[
              0.28384494799700677`, 0.4117302273209994, 0.9396201549030457], 
             UndirectedEdge[167, 211] -> 
             RGBColor[
              0.5232348458309425, 0.6226412682118242, 0.955937080795298], 
             UndirectedEdge[193, 255] -> 
             RGBColor[
              0.3378414626773269, 0.46375007884697717`, 0.9428685081307819], 
             UndirectedEdge[168, 211] -> 
             RGBColor[
              0.4912770559743419, 0.5949610368832586, 0.9539007586847994], 
             UndirectedEdge[70, 246] -> 
             RGBColor[
              0.7208997404305972, 0.7785401570987851, 0.9060429318059418], 
             UndirectedEdge[322, 349] -> 
             RGBColor[
              0.3991350270349485, 0.5201324321330776, 0.9466535088747887], 
             UndirectedEdge[193, 312] -> 
             RGBColor[
              0.22834225396185226`, 0.35733256502196764`, 0.9363151256098103],
              UndirectedEdge[194, 221] -> 
             RGBColor[
              0.3723885253546363, 0.49696595669585336`, 0.9449492454387219], 
             UndirectedEdge[208, 221] -> 
             RGBColor[
              0.35173743894108583`, 0.47907902359821897`, 0.9436333764734892],
              UndirectedEdge[112, 251] -> 
             RGBColor[
              0.3058000939286941, 0.4275712697466507, 0.9411353843910082], 
             UndirectedEdge[297, 325] -> 
             RGBColor[
              0.25522351303313373`, 0.3855864726761493, 0.9378459735466609], 
             UndirectedEdge[170, 225] -> 
             RGBColor[
              0.48697458978684394`, 0.5930984050115735, 0.9531115949324835], 
             UndirectedEdge[27, 250] -> 
             RGBColor[
              0.44408854749289284`, 0.5586513828829938, 0.9496332720208824], 
             UndirectedEdge[67, 126] -> 
             RGBColor[
              0.34521514563862266`, 0.4649792261485165, 0.9436266325456223], 
             UndirectedEdge[12, 157] -> 
             RGBColor[
              0.31673593150213786`, 0.4377003411393729, 0.9418081503561515], 
             UndirectedEdge[316, 399] -> 
             RGBColor[
              0.34224509203231646`, 0.47085722980507083`, 0.9430285325222152],
              UndirectedEdge[76, 377] -> 
             RGBColor[
              0.3570861872155402, 0.48371184051764626`, 0.9439741939838251], 
             UndirectedEdge[3, 51] -> 
             RGBColor[
              0.534313538658442, 0.6328188270903583, 0.9564822654996268], 
             UndirectedEdge[23, 186] -> 
             RGBColor[
              0.5275098886910923, 0.6251264585592488, 0.9567024035089698], 
             UndirectedEdge[17, 319] -> 
             RGBColor[
              0.4182810118294027, 0.5258114383482931, 0.9492408268925256], 
             UndirectedEdge[115, 360] -> 
             RGBColor[
              0.27459943446702406`, 0.40216165979595553`, 0.9390881790101002],
              UndirectedEdge[131, 142] -> 
             RGBColor[
              0.623411736869345, 0.6988418624382754, 0.9668770633444985], 
             UndirectedEdge[23, 130] -> 
             RGBColor[
              0.463906715834024, 0.5655648587136125, 0.952813397455153], 
             UndirectedEdge[348, 354] -> 
             RGBColor[
              0.30377137990998915`, 0.43366088389269786`, 0.9407188073173696],
              UndirectedEdge[76, 80] -> 
             RGBColor[
              0.28507243564494283`, 0.41413726252561933`, 0.9396491645052443],
              UndirectedEdge[38, 81] -> 
             RGBColor[
              0.4016959045346063, 0.5223505355098355, 0.9468166857245718], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.30156642675182793`, 0.4330956846772289, 0.9405290765127792], 
             UndirectedEdge[131, 281] -> 
             RGBColor[
              0.42468801711280485`, 0.5408340955471888, 0.9486771268103829], 
             UndirectedEdge[157, 167] -> 
             RGBColor[
              0.4270537466944567, 0.5443142238664925, 0.9484324650039382], 
             UndirectedEdge[165, 172] -> 
             RGBColor[
              0.2678483152672498, 0.3952873348497068, 0.9386956014833274], 
             UndirectedEdge[255, 331] -> 
             RGBColor[
              0.4080159271418822, 0.5278246214386855, 0.9472193919765308], 
             UndirectedEdge[59, 268] -> 
             RGBColor[
              0.2621539205478141, 0.3896303653623576, 0.938359297103482], 
             UndirectedEdge[161, 364] -> 
             RGBColor[
              0.25840710146116547`, 0.3866766521060304, 0.9381098764520845], 
             UndirectedEdge[149, 164] -> 
             RGBColor[
              0.3327755542981793, 0.4572169303586688, 0.9426242633563702], 
             UndirectedEdge[10, 52] -> 
             RGBColor[
              0.2167924708772871, 0.34519301070154657`, 0.9356573825495174], 
             UndirectedEdge[132, 155] -> 
             RGBColor[
              0.28137028031267686`, 0.40935433459479365`, 0.9394709827642751],
              UndirectedEdge[353, 400] -> 
             RGBColor[
              0.2617481419606836, 0.39244427136437154`, 0.9382175415117613], 
             UndirectedEdge[250, 265] -> 
             RGBColor[
              0.3585695735565054, 0.4839714522251082, 0.9441062524853845], 
             UndirectedEdge[82, 233] -> 
             RGBColor[
              0.6621446861510432, 0.24912793229108293`, 0.42402437055232045`],
              UndirectedEdge[66, 81] -> 
             RGBColor[
              0.5618700137364048, 0.6515960302512358, 0.9602848943896474], 
             UndirectedEdge[69, 201] -> 
             RGBColor[
              0.2964743180380608, 0.4289145639276468, 0.9401962121019904], 
             UndirectedEdge[84, 184] -> 
             RGBColor[
              0.5846058757199406, 0.6557983942210938, 0.957330337056217], 
             UndirectedEdge[180, 268] -> 
             RGBColor[
              0.32593597780433975`, 0.44438535264740975`, 0.9425587734795176],
              UndirectedEdge[17, 247] -> 
             RGBColor[
              0.3667841647525505, 0.4840039779847811, 0.9451868064514695], 
             UndirectedEdge[188, 394] -> 
             RGBColor[
              0.3738481711460866, 0.48876436484886543`, 0.9458316152118592], 
             UndirectedEdge[241, 312] -> 
             RGBColor[
              0.2586313655895732, 0.3868604196825327, 0.9381245500420289], 
             UndirectedEdge[81, 128] -> 
             RGBColor[
              0.4038533900026396, 0.5242192409838733, 0.9469541587908055], 
             UndirectedEdge[65, 198] -> 
             RGBColor[
              0.37020517158148936`, 0.4946521492040462, 0.9448256010451808], 
             UndirectedEdge[356, 380] -> 
             RGBColor[
              0.3480457590567825, 0.47269516853293964`, 0.9435148122217271], 
             UndirectedEdge[40, 265] -> 
             RGBColor[
              0.29892626492534324`, 0.43152083582937195`, 0.9403347806144945],
              UndirectedEdge[19, 168] -> 
             RGBColor[
              0.3573487733866523, 0.4839392794610988, 0.9439909257424525], 
             UndirectedEdge[195, 241] -> 
             RGBColor[
              0.4492537790597021, 0.56051579472213, 0.9506833954078089], 
             UndirectedEdge[33, 141] -> 
             RGBColor[
              0.43669182109085125`, 0.5526622394849452, 0.9490465945818618], 
             UndirectedEdge[65, 100] -> 
             RGBColor[
              0.3238608067033406, 0.454510989682101, 0.9418725790958578], 
             UndirectedEdge[15, 207] -> 
             RGBColor[
              0.3845051115761162, 0.5073057674876305, 0.9457641214964408], 
             UndirectedEdge[81, 135] -> 
             RGBColor[
              0.35113186998035106`, 0.4785545102012114, 0.9435947901547947], 
             UndirectedEdge[259, 271] -> 
             RGBColor[
              0.368433880208596, 0.49354064183659774`, 0.9446972589469718], 
             UndirectedEdge[194, 233] -> 
             RGBColor[
              0.6755795410293652, 0.2607645283312454, 0.4248804276251915], 
             UndirectedEdge[101, 283] -> 
             RGBColor[
              0.5647968368114393, 0.6575665417878938, 0.9588820223942311], 
             UndirectedEdge[145, 192] -> 
             RGBColor[
              0.6853286412519182, 0.752035528555877, 0.970994382784248], 
             UndirectedEdge[68, 397] -> 
             RGBColor[
              0.36209203863585304`, 0.48804765741651324`, 0.9442931624098267],
              UndirectedEdge[142, 201] -> 
             RGBColor[
              0.593678835452504, 0.6707903957004941, 0.9650666619831727], 
             UndirectedEdge[146, 354] -> 
             RGBColor[
              0.5063318831527537, 0.606589840105549, 0.9554347711140319], 
             UndirectedEdge[153, 329] -> 
             RGBColor[
              0.29344819415063206`, 0.4204305222779118, 0.9402180620415095], 
             UndirectedEdge[132, 279] -> 
             RGBColor[
              0.3822705989220544, 0.5055253121324915, 0.9455789224280633], 
             UndirectedEdge[257, 389] -> 
             RGBColor[
              0.1941870667101213, 0.32143329765644957`, 0.9343700382238957], 
             UndirectedEdge[107, 386] -> 
             RGBColor[
              0.4526403230444982, 0.5640790101046845, 0.9507251228406093], 
             UndirectedEdge[157, 203] -> 
             RGBColor[
              0.40271733570726853`, 0.523235247852972, 0.9468817704156778], 
             UndirectedEdge[264, 281] -> 
             RGBColor[
              0.3721272367959483, 0.48878908071437277`, 0.9455667115165216], 
             UndirectedEdge[244, 302] -> 
             RGBColor[
              0.3779416276560085, 0.49557206122866065`, 0.94583669133981], 
             UndirectedEdge[46, 105] -> 
             RGBColor[
              0.3217147365822906, 0.4524259252685334, 0.9417441173922179], 
             UndirectedEdge[126, 347] -> 
             RGBColor[
              0.20578774166918312`, 0.33362634256369783`, 0.9350306795011537],
              UndirectedEdge[129, 253] -> 
             RGBColor[
              0.3426309395287469, 0.4703992006347791, 0.9430821258367947], 
             UndirectedEdge[14, 69] -> 
             RGBColor[
              0.32481742343410946`, 0.4557622592053967, 0.9419180568898198], 
             UndirectedEdge[118, 124] -> 
             RGBColor[
              0.37745335693175686`, 0.48864923133155147`, 0.9463923291066454],
              UndirectedEdge[181, 245] -> 
             RGBColor[
              0.3074490275469484, 0.4341360552292117, 0.9410523782839719], 
             UndirectedEdge[33, 152] -> 
             RGBColor[
              0.35321299215147817`, 0.4755039285269457, 0.9439050948350556], 
             UndirectedEdge[47, 371] -> 
             RGBColor[
              0.25651238701015394`, 0.38606565442598595`, 0.9379514295953817],
              UndirectedEdge[131, 273] -> 
             RGBColor[
              0.3141686682300903, 0.4443418703006976, 0.9413199695451075], 
             UndirectedEdge[230, 299] -> 
             RGBColor[
              0.37753740854427503`, 0.5014256605243246, 0.9452773277225871], 
             UndirectedEdge[107, 181] -> 
             RGBColor[
              0.4594733191166993, 0.5699974078660568, 0.9511605153081487], 
             UndirectedEdge[4, 318] -> 
             RGBColor[
              0.40081685821758906`, 0.5175915258894173, 0.9473236255704387], 
             UndirectedEdge[10, 333] -> 
             RGBColor[
              0.2695542725565937, 0.3967098213519695, 0.938806322077874], 
             UndirectedEdge[152, 238] -> 
             RGBColor[
              0.3403075710840025, 0.4643259014436213, 0.9430827728164518], 
             UndirectedEdge[50, 147] -> 
             RGBColor[
              0.4613813762065746, 0.5720693570734913, 0.9511662450316194], 
             UndirectedEdge[39, 217] -> 
             RGBColor[
              0.25159156027243523`, 0.3817690600455499, 0.9376391392099317], 
             UndirectedEdge[98, 308] -> 
             RGBColor[
              0.27702567342993933`, 0.4085019255900012, 0.939087574327853], 
             UndirectedEdge[31, 363] -> 
             RGBColor[
              0.33699097523325183`, 0.4601484503281088, 0.94291921674006], 
             UndirectedEdge[286, 386] -> 
             RGBColor[
              0.36127960431583916`, 0.4873439676426534, 0.944241394813363], 
             UndirectedEdge[137, 138] -> 
             RGBColor[
              0.30033185900706916`, 0.4232077324887935, 0.9407733042519433], 
             UndirectedEdge[35, 372] -> 
             RGBColor[
              0.3266570018285775, 0.4451398009073043, 0.9426001436471887], 
             UndirectedEdge[130, 158] -> 
             RGBColor[
              0.3509865154137135, 0.47395688307606065`, 0.9437492601688988], 
             UndirectedEdge[277, 373] -> 
             RGBColor[
              0.26988789426484455`, 0.4009145674547718, 0.9386842042796391], 
             UndirectedEdge[234, 365] -> 
             RGBColor[
              0.807233722373474, 0.8500168717007641, 0.9682752559982832], 
             UndirectedEdge[310, 316] -> 
             RGBColor[
              0.29285391194543553`, 0.42232525398602627`, 0.9400919724386281],
              UndirectedEdge[218, 305] -> 
             RGBColor[
              0.30949175418355857`, 0.4367670594999701, 0.9411509880659406], 
             UndirectedEdge[155, 279] -> 
             RGBColor[
              0.31472425917296654`, 0.43824387466385495`, 0.9415962688034873],
              UndirectedEdge[32, 129] -> 
             RGBColor[
              0.34433949559281385`, 0.47219500138682463`, 0.9431794255770612],
              UndirectedEdge[92, 158] -> 
             RGBColor[
              0.3718857562534142, 0.4959233102869888, 0.9449394410170636], 
             UndirectedEdge[332, 334] -> 
             RGBColor[
              0.3435856824129715, 0.4709778109936048, 0.9431520541508845], 
             UndirectedEdge[268, 300] -> 
             RGBColor[
              0.463043376867602, 0.5541142139741728, 0.9544333781452633], 
             UndirectedEdge[224, 227] -> 
             RGBColor[
              0.575965920103866, 0.6628448241623528, 0.961589547900507], 
             UndirectedEdge[25, 91] -> 
             RGBColor[
              0.5661378636246894, 0.6586552477674597, 0.9589875929373132], 
             UndirectedEdge[74, 304] -> 
             RGBColor[
              0.23575570672036122`, 0.36512457391121367`, 0.936737310777187], 
             UndirectedEdge[86, 397] -> 
             RGBColor[
              0.33074301484166513`, 0.4608947086537376, 0.9422956303345145], 
             UndirectedEdge[32, 111] -> 
             RGBColor[
              0.3069473568280202, 0.4398078101723002, 0.9407968315595386], 
             UndirectedEdge[59, 394] -> 
             RGBColor[
              0.285069115520242, 0.41371568818565657`, 0.9396642835571687], 
             UndirectedEdge[170, 355] -> 
             RGBColor[
              0.5283024148935673, 0.6279387260199933, 0.9560090478173839], 
             UndirectedEdge[9, 56] -> 
             RGBColor[
              0.38000995070429067`, 0.5035672522697479, 0.9454348759226401], 
             UndirectedEdge[44, 317] -> 
             RGBColor[
              0.4417431642582036, 0.5465335391720616, 0.9509354329364846], 
             UndirectedEdge[236, 262] -> 
             RGBColor[
              0.3157336806752364, 0.4400983126174356, 0.9416247009695938], 
             UndirectedEdge[119, 346] -> 
             RGBColor[
              0.4722421288630979, 0.5623118165549588, 0.9551900936110879], 
             UndirectedEdge[80, 244] -> 
             RGBColor[
              0.2431747177100038, 0.37292242485379334`, 0.9371598124776039], 
             UndirectedEdge[20, 360] -> 
             RGBColor[
              0.3099366970930974, 0.43930336332781483`, 0.9411005838398598], 
             UndirectedEdge[196, 206] -> 
             RGBColor[
              0.4292170544081869, 0.5448428706494199, 0.9489419646459849], 
             UndirectedEdge[187, 302] -> 
             RGBColor[
              0.3677274455565175, 0.48483630822554585`, 0.9452550087797722], 
             UndirectedEdge[147, 312] -> 
             RGBColor[
              0.35485550089473594`, 0.4682271951986291, 0.944802320685912], 
             UndirectedEdge[259, 400] -> 
             RGBColor[
              0.3241895109479964, 0.45209880850792145`, 0.9419922701302547], 
             UndirectedEdge[120, 312] -> 
             RGBColor[
              0.30948767510439035`, 0.4309095988718288, 0.9413650691138442], 
             UndirectedEdge[52, 60] -> 
             RGBColor[
              0.3053006735106386, 0.4330406414409925, 0.9408874626618999], 
             UndirectedEdge[266, 384] -> 
             RGBColor[
              0.2705447441081057, 0.40148349777477155`, 0.9387260581708221], 
             UndirectedEdge[135, 393] -> 
             RGBColor[
              0.4288723869695894, 0.5436908696307439, 0.9491558183289959], 
             UndirectedEdge[77, 244] -> 
             RGBColor[
              0.32465046349933424`, 0.4506925066644295, 0.9420877518608893], 
             UndirectedEdge[239, 385] -> 
             RGBColor[
              0.5861792915646703, 0.6718917500373462, 0.96215542433757], 
             UndirectedEdge[278, 296] -> 
             RGBColor[
              0.5914062928067927, 0.6741173833301285, 0.9634626865048166], 
             UndirectedEdge[267, 275] -> 
             RGBColor[
              0.46154132396006875`, 0.5712507879102409, 0.9514408885167018], 
             UndirectedEdge[148, 340] -> 
             RGBColor[
              0.31883692219357773`, 0.4497900187411398, 0.9415659920924213], 
             UndirectedEdge[202, 212] -> 
             RGBColor[
              0.22038190417682385`, 0.34896573268257547`, 0.9358617954658353],
              UndirectedEdge[81, 346] -> 
             RGBColor[
              0.5676411987211398, 0.6561045238239411, 0.9608601121741358], 
             UndirectedEdge[50, 217] -> 
             RGBColor[
              0.3035897508069487, 0.42829916796454687`, 0.9408977925740512], 
             UndirectedEdge[5, 183] -> 
             RGBColor[
              0.3975086345830182, 0.518723732736077, 0.946549876585914], 
             UndirectedEdge[313, 339] -> 
             RGBColor[
              0.33313566137630035`, 0.4606477729544449, 0.9425330095375548], 
             UndirectedEdge[4, 184] -> 
             RGBColor[
              0.25442932131147, 0.3847517268220173, 0.9378007455030134], 
             UndirectedEdge[104, 349] -> 
             RGBColor[
              0.4091439598564145, 0.5288016666794405, 0.9472912692236206], 
             UndirectedEdge[119, 135] -> 
             RGBColor[
              0.25573280012230915`, 0.38476180293222895`, 0.9379247715917469],
              UndirectedEdge[53, 273] -> 
             RGBColor[
              0.3063571184099675, 0.4375758984664171, 0.9408222244980515], 
             UndirectedEdge[224, 259] -> 
             RGBColor[
              0.5704589157854416, 0.6580749338118187, 0.9612386464549897], 
             UndirectedEdge[110, 289] -> 
             RGBColor[
              0.28195401985612234`, 0.41306517168225176`, 0.9393908189150936],
              UndirectedEdge[59, 155] -> 
             RGBColor[
              0.2788088510765068, 0.4071357533315999, 0.9393077707583293], 
             UndirectedEdge[5, 29] -> 
             RGBColor[
              0.43901521765130813`, 0.5546746488083063, 0.9491946393561952], 
             UndirectedEdge[119, 311] -> 
             RGBColor[
              0.19623265350017588`, 0.3235833390704904, 0.9344865313654149], 
             UndirectedEdge[68, 72] -> 
             RGBColor[
              0.30993759262419984`, 0.43433036464262287`, 0.9412827551458708],
              UndirectedEdge[121, 234] -> 
             RGBColor[
              0.5442164551209335, 0.6397266405380169, 0.9577119962468629], 
             UndirectedEdge[20, 336] -> 
             RGBColor[
              0.22633172809052557`, 0.35521937485650046`, 0.9362006291357449],
              UndirectedEdge[17, 256] -> 
             RGBColor[
              0.3119049026019044, 0.4377127716303928, 0.9413466551479359], 
             UndirectedEdge[186, 272] -> 
             RGBColor[
              0.3911694641992803, 0.5132330619656509, 0.9461459502545706], 
             UndirectedEdge[45, 304] -> 
             RGBColor[
              0.38448696441157015`, 0.4917298519933374, 0.9471854010657634], 
             UndirectedEdge[165, 252] -> 
             RGBColor[
              0.33098836557519845`, 0.4611072191274377, 0.9423112638663], 
             UndirectedEdge[106, 254] -> 
             RGBColor[
              0.28069296033259444`, 0.4111518359591381, 0.9393405286882495], 
             UndirectedEdge[144, 169] -> 
             RGBColor[
              0.687035966613865, 0.7534173612245914, 0.9711336824842691], 
             UndirectedEdge[191, 355] -> 
             RGBColor[
              0.4418913888841604, 0.5562100798674965, 0.9496419868577148], 
             UndirectedEdge[96, 377] -> 
             RGBColor[
              0.5179256293070509, 0.6171003654463321, 0.9559751784620627], 
             UndirectedEdge[110, 303] -> 
             RGBColor[
              0.4001740084818627, 0.5127858258437011, 0.9476629567209361], 
             UndirectedEdge[177, 260] -> 
             RGBColor[
              0.605667706141141, 0.6736989738407962, 0.9342460564600041], 
             UndirectedEdge[20, 88] -> 
             RGBColor[
              0.33821672273854664`, 0.46379810014648515`, 0.9429025620669431],
              UndirectedEdge[57, 68] -> 
             RGBColor[
              0.3078438083697434, 0.4321296646375999, 0.9411635172300556], 
             UndirectedEdge[127, 264] -> 
             RGBColor[
              0.6034596291745496, 0.6719474395413216, 0.9373833356403376], 
             UndirectedEdge[171, 186] -> 
             RGBColor[
              0.4158453246476036, 0.5346060520411806, 0.9477182742623311], 
             UndirectedEdge[362, 385] -> 
             RGBColor[
              0.517965477783712, 0.6095136499339266, 0.957929536396029], 
             UndirectedEdge[109, 370] -> 
             RGBColor[
              0.376440418950949, 0.5004755032748858, 0.9452074285157301], 
             UndirectedEdge[123, 161] -> 
             RGBColor[
              0.3349322387642305, 0.46452320385894713`, 0.942562563978475], 
             UndirectedEdge[119, 213] -> 
             RGBColor[
              0.1878836396668952, 0.3148079961736612, 0.9340110673788686], 
             UndirectedEdge[140, 360] -> 
             RGBColor[
              0.34626592861490385`, 0.47433987635978525`, 0.9432847366737716],
              UndirectedEdge[320, 347] -> 
             RGBColor[
              0.5773572544002601, 0.645079197100907, 0.9391467663307211], 
             UndirectedEdge[10, 345] -> 
             RGBColor[
              0.2047951494777156, 0.3325830652364857, 0.9349741528442581], 
             UndirectedEdge[169, 383] -> 
             RGBColor[
              0.6184777249399975, 0.6942673899635956, 0.9667011837507866], 
             UndirectedEdge[154, 372] -> 
             RGBColor[
              0.1939120779765145, 0.3211442670621361, 0.9343543780223262], 
             UndirectedEdge[167, 341] -> 
             RGBColor[
              0.41718900133431763`, 0.5357698772520584, 0.9478038921526419], 
             UndirectedEdge[186, 308] -> 
             RGBColor[
              0.3217278348619152, 0.4481973640345249, 0.9419001957425513], 
             UndirectedEdge[145, 225] -> 
             RGBColor[
              0.6587471800445025, 0.7291669700770382, 0.9692578176832121], 
             UndirectedEdge[12, 65] -> 
             RGBColor[
              0.24663684150953938`, 0.3765613364784325, 0.9373569753062343], 
             UndirectedEdge[274, 288] -> 
             RGBColor[
              0.4040782617306708, 0.5244140135723123, 0.9469684874184693], 
             UndirectedEdge[143, 171] -> 
             RGBColor[
              0.5729627067355698, 0.6630348878652885, 0.9602167769651695], 
             UndirectedEdge[167, 168] -> 
             RGBColor[
              0.37777734566503773`, 0.5016334819987389, 0.945292616303754], 
             UndirectedEdge[203, 341] -> 
             RGBColor[
              0.3928525903471295, 0.5146909012385379, 0.9462531975643815], 
             UndirectedEdge[114, 299] -> 
             RGBColor[
              0.35947251714632145`, 0.4825391631985238, 0.9442448663093337], 
             UndirectedEdge[154, 231] -> 
             RGBColor[
              0.33184086964565396`, 0.45221516852459076`, 0.9427472763545655],
              UndirectedEdge[218, 384] -> 
             RGBColor[
              0.30111152370978, 0.4279589059347282, 0.9406737463378989], 
             UndirectedEdge[360, 380] -> 
             RGBColor[
              0.3120114553272831, 0.44148406577921384`, 0.941218738251967], 
             UndirectedEdge[98, 306] -> 
             RGBColor[
              0.3484305132471051, 0.47523805776490263`, 0.9434584228756462], 
             UndirectedEdge[57, 262] -> 
             RGBColor[
              0.30959656179560896`, 0.4336478115591359, 0.9412752011284529], 
             UndirectedEdge[152, 160] -> 
             RGBColor[
              0.5701316832368609, 0.6485094703214075, 0.9633517068656625], 
             UndirectedEdge[311, 354] -> 
             RGBColor[
              0.2725672111909915, 0.40086332411046416`, 0.9389417760712534], 
             UndirectedEdge[287, 303] -> 
             RGBColor[
              0.48857254821875207`, 0.594923159645198, 0.9530916533065676], 
             UndirectedEdge[222, 247] -> 
             RGBColor[
              0.3754348725300077, 0.49309642034544077`, 0.9456794514618203], 
             UndirectedEdge[24, 206] -> 
             RGBColor[
              0.31849174051273155`, 0.44775554076591906`, 0.9416075425391566],
              UndirectedEdge[92, 308] -> 
             RGBColor[
              0.27902390284454753`, 0.41060219139981685`, 0.9392013705368993],
              UndirectedEdge[18, 266] -> 
             RGBColor[
              0.3720028426336962, 0.49663189770795224`, 0.9449246700767895], 
             UndirectedEdge[28, 314] -> 
             RGBColor[
              0.32209068362192395`, 0.45106434861655703`, 0.9418298491749493],
              UndirectedEdge[128, 139] -> 
             RGBColor[
              0.5881271983913127, 0.6742357025706112, 0.9620015655462805], 
             UndirectedEdge[160, 181] -> 
             RGBColor[
              0.6306782609114131, 0.7058050178422812, 0.9670319838400678], 
             UndirectedEdge[42, 296] -> 
             RGBColor[
              0.5370591251119928, 0.6222698253479424, 0.9601745608620341], 
             UndirectedEdge[121, 289] -> 
             RGBColor[
              0.3697363620231426, 0.49466878611971843`, 0.9447802519364552], 
             UndirectedEdge[22, 286] -> 
             RGBColor[
              0.37916428659340584`, 0.5028347805212134, 0.945380990953286], 
             UndirectedEdge[128, 213] -> 
             RGBColor[
              0.30832752413188763`, 0.4302932630662011, 0.9412769193824115], 
             UndirectedEdge[178, 398] -> 
             RGBColor[
              0.3363887790758386, 0.46264909442752666`, 0.9427701864633999], 
             UndirectedEdge[6, 129] -> 
             RGBColor[
              0.6124203912374722, 0.6915127278156441, 0.9651680592653413], 
             UndirectedEdge[265, 375] -> 
             RGBColor[
              0.28116607195293597`, 0.41285374695409927`, 0.939323363898567], 
             UndirectedEdge[162, 270] -> 
             RGBColor[
              0.31177516199417155`, 0.43637421605758364`, 0.941383284676063], 
             UndirectedEdge[199, 271] -> 
             RGBColor[
              0.27545708340458114`, 0.401791433999749, 0.9391835828874344], 
             UndirectedEdge[60, 72] -> 
             RGBColor[
              0.2905557217279497, 0.41754276223344716`, 0.9400477594710772], 
             UndirectedEdge[230, 258] -> 
             RGBColor[
              0.2845630523803121, 0.4163233398505535, 0.9395205094812755], 
             UndirectedEdge[38, 135] -> 
             RGBColor[
              0.3740191991192683, 0.498378364350731, 0.945053150529056], 
             UndirectedEdge[42, 67] -> 
             RGBColor[
              0.3628497844714325, 0.48351434966248014`, 0.9446308991390405], 
             UndirectedEdge[220, 352] -> 
             RGBColor[
              0.2817937226567562, 0.4135134476391673, 0.9393591076776234], 
             UndirectedEdge[4, 226] -> 
             RGBColor[
              0.46052042429091167`, 0.5660615704427415, 0.9520237089930993], 
             UndirectedEdge[134, 163] -> 
             RGBColor[
              0.35145043990382635`, 0.4767261841403658, 0.9436921362437147], 
             UndirectedEdge[25, 76] -> 
             RGBColor[
              0.45706468436010617`, 0.5670081058956904, 0.9512565583962675], 
             UndirectedEdge[250, 375] -> 
             RGBColor[
              0.3420783120310039, 0.46663809075543405`, 0.9431670995381423], 
             UndirectedEdge[50, 138] -> 
             RGBColor[
              0.29131584263696253`, 0.41539851226716606`, 0.9401988116613904],
              UndirectedEdge[24, 157] -> 
             RGBColor[
              0.36288939509499674`, 0.4862105576740744, 0.9444365218298341], 
             UndirectedEdge[127, 328] -> 
             RGBColor[
              0.66685948103351, 0.7333807133563318, 0.941184406988247], 
             UndirectedEdge[107, 245] -> 
             RGBColor[
              0.38957412101857214`, 0.5028716632896213, 0.9469476204365828], 
             UndirectedEdge[16, 96] -> 
             RGBColor[
              0.5682591761750747, 0.660092623710356, 0.9593493105332908], 
             UndirectedEdge[42, 278] -> 
             RGBColor[
              0.31144990066166567`, 0.4394092099581134, 0.9412411179846125], 
             UndirectedEdge[51, 176] -> 
             RGBColor[
              0.5496974271628667, 0.6453081608145296, 0.9576933415557354], 
             UndirectedEdge[33, 386] -> 
             RGBColor[
              0.4069265737538292, 0.5268810782864473, 0.9471499793419215], 
             UndirectedEdge[78, 187] -> 
             RGBColor[
              0.3179930998366838, 0.4430374910204134, 0.941732706626476], 
             UndirectedEdge[107, 150] -> 
             RGBColor[
              0.4823338199542924, 0.589798024689399, 0.9526171662067731], 
             UndirectedEdge[312, 360] -> 
             RGBColor[
              0.26664706691608625`, 0.39380321729069534`, 0.9386353034425479],
              UndirectedEdge[78, 208] -> 
             RGBColor[
              0.3758683165266843, 0.49997997690969165`, 0.9451709746551464], 
             UndirectedEdge[28, 197] -> 
             RGBColor[
              0.4100935069946484, 0.5294566891699506, 0.9473980342488628], 
             UndirectedEdge[221, 316] -> 
             RGBColor[
              0.3459245505327215, 0.47404419182316015`, 0.9432629843642436], 
             UndirectedEdge[243, 383] -> 
             RGBColor[0.3061528699254021, 0.4376380690571331, 0.940800456062],
              UndirectedEdge[83, 332] -> 
             RGBColor[
              0.2703797205608318, 0.40151660774681963`, 0.9387090971437635], 
             UndirectedEdge[98, 354] -> 
             RGBColor[
              0.3194309970992818, 0.4501201344357201, 0.9416105993499722], 
             UndirectedEdge[46, 215] -> 
             RGBColor[
              0.40721683557157384`, 0.5248710078099499, 0.9476377846266525], 
             UndirectedEdge[375, 381] -> 
             RGBColor[
              0.31254952769541955`, 0.44106174192380543`, 0.9412855515115576],
              UndirectedEdge[286, 304] -> 
             RGBColor[
              0.26890198756550254`, 0.3953284655012021, 0.9387946507031335], 
             UndirectedEdge[225, 235] -> 
             RGBColor[
              0.4576560830100148, 0.5692963204264649, 0.9508035346817825], 
             UndirectedEdge[96, 225] -> 
             RGBColor[
              0.5334065507765399, 0.6305091615294662, 0.9569616090888571], 
             UndirectedEdge[20, 389] -> 
             RGBColor[
              0.22924346647753355`, 0.3582797965161224, 0.936366448329354], 
             UndirectedEdge[259, 393] -> 
             RGBColor[
              0.45383180738440954`, 0.565309465097115, 0.9507462105270794], 
             UndirectedEdge[97, 166] -> 
             RGBColor[
              0.2327616747180571, 0.3619776564441989, 0.9365668050839291], 
             UndirectedEdge[115, 334] -> 
             RGBColor[
              0.2945696696133837, 0.41945887374652885`, 0.9403606647346407], 
             UndirectedEdge[251, 260] -> 
             RGBColor[
              0.5772053404251727, 0.6437832228550975, 0.9326251668387765], 
             UndirectedEdge[119, 344] -> 
             RGBColor[
              0.1877154237331144, 0.31463119056175126`, 0.9340014877302931], 
             UndirectedEdge[329, 341] -> 
             RGBColor[
              0.32255877069538685`, 0.4456446405408586, 0.9420729622374691], 
             UndirectedEdge[283, 334] -> 
             RGBColor[
              0.5145850712613995, 0.6150744484506292, 0.955406597736387], 
             UndirectedEdge[1, 5] -> 
             RGBColor[
              0.44425420612536115`, 0.5591536164801236, 0.9495447043862439], 
             UndirectedEdge[364, 391] -> 
             RGBColor[
              0.31603829177568893`, 0.43659389252862224`, 0.9417820849376655],
              UndirectedEdge[48, 295] -> 
             RGBColor[
              0.29558123263195857`, 0.4193081939740615, 0.9404627184545509], 
             UndirectedEdge[105, 199] -> 
             RGBColor[
              0.2645613777083103, 0.3923541213597306, 0.9384893181551622], 
             UndirectedEdge[281, 293] -> 
             RGBColor[
              0.3718384643739381, 0.488485562589611, 0.9455502663542885], 
             UndirectedEdge[216, 358] -> 
             RGBColor[
              0.3001453463611871, 0.42459571786184214`, 0.9407046838281236], 
             UndirectedEdge[100, 206] -> 
             RGBColor[
              0.3495622421136738, 0.4771949774348861, 0.9434947748550975], 
             UndirectedEdge[168, 341] -> 
             RGBColor[
              0.385231211477717, 0.5080896459234928, 0.9457675700421433], 
             UndirectedEdge[199, 259] -> 
             RGBColor[
              0.28039720859063844`, 0.4060703221380003, 0.9394983632959089], 
             UndirectedEdge[19, 24] -> 
             RGBColor[
              0.325142211643793, 0.4535158445972463, 0.9420313046788471], 
             UndirectedEdge[136, 299] -> 
             RGBColor[
              0.3239591559372121, 0.44521236889059845`, 0.9422224329257848], 
             UndirectedEdge[64, 123] -> 
             RGBColor[
              0.3450308231423533, 0.473270090077668, 0.9432060368452215], 
             UndirectedEdge[101, 334] -> 
             RGBColor[
              0.4398917969087459, 0.5544350834374814, 0.9495264695688669], 
             UndirectedEdge[2, 328] -> 
             RGBColor[
              0.39695831804363246`, 0.5182470762093745, 0.9465148109026502], 
             UndirectedEdge[235, 349] -> 
             RGBColor[
              0.4413358534396669, 0.5551605578512184, 0.9497636240849723], 
             UndirectedEdge[45, 290] -> 
             RGBColor[
              0.5957755494955228, 0.6827164563199353, 0.9613207801354857], 
             UndirectedEdge[225, 327] -> 
             RGBColor[
              0.331230402624273, 0.45649545797892793`, 0.9425032213792711], 
             UndirectedEdge[24, 386] -> 
             RGBColor[
              0.3225443329116959, 0.45126569261268545`, 0.9418657701432518], 
             UndirectedEdge[363, 393] -> 
             RGBColor[
              0.3882161685906359, 0.5023185691266449, 0.9467907119390193], 
             UndirectedEdge[2, 258] -> 
             RGBColor[
              0.34408717595377153`, 0.46788014392044364`, 0.9433133340002606],
              UndirectedEdge[8, 234] -> 
             RGBColor[
              0.4830375222615084, 0.5860848960364049, 0.9538375880293517], 
             UndirectedEdge[44, 151] -> 
             RGBColor[
              0.5522890449986035, 0.6474121529246337, 0.9578973632051735], 
             UndirectedEdge[253, 283] -> 
             RGBColor[
              0.46983372712037275`, 0.5755208525451879, 0.9525840891130792], 
             UndirectedEdge[257, 360] -> 
             RGBColor[
              0.27488029732568514`, 0.402456864468142, 0.9391041737344017], 
             UndirectedEdge[65, 358] -> 
             RGBColor[
              0.3508399883138129, 0.4778790007799965, 0.9435916686913235], 
             UndirectedEdge[282, 340] -> 
             RGBColor[
              0.3009739768647228, 0.4310149306243649, 0.9405487237818024], 
             UndirectedEdge[256, 316] -> 
             RGBColor[
              0.36424535498491944`, 0.489912751809248, 0.9444303698234864], 
             UndirectedEdge[96, 182] -> 
             RGBColor[
              0.5386296319567697, 0.6350331319280882, 0.9572944192030721], 
             UndirectedEdge[2, 106] -> 
             RGBColor[
              0.37533011883026435`, 0.49951381711565546`, 0.94513668117384], 
             UndirectedEdge[210, 279] -> 
             RGBColor[
              0.5299071464437953, 0.6281900103778608, 0.9564373385199806], 
             UndirectedEdge[279, 371] -> 
             RGBColor[
              0.3052169986736739, 0.428251141083967, 0.9410548443827842], 
             UndirectedEdge[271, 353] -> 
             RGBColor[
              0.30599251122128324`, 0.43388610469304784`, 0.9409225303284783],
              UndirectedEdge[306, 311] -> 
             RGBColor[
              0.3015667273388148, 0.4259812474396467, 0.9407895995969274], 
             UndirectedEdge[64, 312] -> 
             RGBColor[
              0.2684490175575002, 0.39536397636761544`, 0.9387501221440164], 
             UndirectedEdge[137, 210] -> 
             RGBColor[
              0.5294140356176614, 0.6277629025647344, 0.9564059179341802], 
             UndirectedEdge[264, 394] -> 
             RGBColor[
              0.2322881935564269, 0.361479997722886, 0.936539841032227], 
             UndirectedEdge[199, 224] -> 
             RGBColor[
              0.4774821189814268, 0.5663257259749699, 0.9557249703954525], 
             UndirectedEdge[61, 301] -> 
             RGBColor[
              0.40887746871367386`, 0.5285708454458329, 0.9472742886436541], 
             UndirectedEdge[48, 103] -> 
             RGBColor[
              0.30234937320533845`, 0.4251704171620868, 0.9408939783870549], 
             UndirectedEdge[7, 14] -> 
             RGBColor[
              0.4971186590647686, 0.5993879117275827, 0.9545183824456223], 
             UndirectedEdge[88, 195] -> 
             RGBColor[
              0.48554950603166436`, 0.5919533291489629, 0.9529961270354113], 
             UndirectedEdge[211, 341] -> 
             RGBColor[
              0.5306887116436219, 0.6290974321365781, 0.9564120345336873], 
             UndirectedEdge[84, 185] -> 
             RGBColor[
              0.7080086386804969, 0.7699781183472195, 0.9650437715226463], 
             UndirectedEdge[368, 387] -> 
             RGBColor[
              0.3854015979795554, 0.5072438993973288, 0.9459128099577055], 
             UndirectedEdge[134, 171] -> 
             RGBColor[
              0.43050904521905053`, 0.5473070297801422, 0.9486526335705247], 
             UndirectedEdge[41, 295] -> 
             RGBColor[
              0.4128271852424238, 0.5319918913845112, 0.9475259610882689], 
             UndirectedEdge[77, 388] -> 
             RGBColor[
              0.42062454246886627`, 0.5387455703074863, 0.9480228017958056], 
             UndirectedEdge[142, 273] -> 
             RGBColor[
              0.5942269268039277, 0.6713664744618393, 0.9650978749748077], 
             UndirectedEdge[64, 140] -> 
             RGBColor[
              0.3480678792563178, 0.47590063543670535`, 0.94339955537524], 
             UndirectedEdge[150, 157] -> 
             RGBColor[
              0.4337207925937684, 0.5500888839290061, 0.9488572832732051], 
             UndirectedEdge[210, 264] -> 
             RGBColor[
              0.44121081638352055`, 0.5448461985828352, 0.9510243979498807], 
             UndirectedEdge[202, 309] -> 
             RGBColor[
              0.26046788262573684`, 0.39109863763021235`, 0.93814463263661], 
             UndirectedEdge[105, 287] -> 
             RGBColor[
              0.3834953452619017, 0.5065861258545264, 0.9456569621818376], 
             UndirectedEdge[157, 160] -> 
             RGBColor[
              0.6641903270225128, 0.7348314851422979, 0.9691673430591107], 
             UndirectedEdge[153, 379] -> 
             RGBColor[
              0.34427413578996113`, 0.4726146855252381, 0.9431578213962395], 
             UndirectedEdge[207, 387] -> 
             RGBColor[
              0.3891814958104324, 0.5111022668777573, 0.9461322635935261], 
             UndirectedEdge[93, 264] -> 
             RGBColor[
              0.21011270985489372`, 0.3381721583457008, 0.9352769800411129], 
             UndirectedEdge[202, 365] -> 
             RGBColor[
              0.5872576750222511, 0.6577566432288808, 0.9527300018492708], 
             UndirectedEdge[138, 230] -> 
             RGBColor[
              0.24793106472234647`, 0.3778207982198669, 0.9374343719763238], 
             UndirectedEdge[5, 291] -> 
             RGBColor[
              0.6862955017633641, 0.7519676478011552, 0.9679985512963789], 
             UndirectedEdge[241, 360] -> 
             RGBColor[
              0.34172385973947395`, 0.4704057645909074, 0.942995320061423], 
             UndirectedEdge[299, 300] -> 
             RGBColor[
              0.5954053618784598, 0.6806154298859377, 0.9624332635806303], 
             UndirectedEdge[9, 266] -> 
             RGBColor[
              0.3169125842386561, 0.4489154848030653, 0.9414143675262603], 
             UndirectedEdge[226, 322] -> 
             RGBColor[
              0.5308913344653174, 0.6292729338406118, 0.9564249454807134], 
             UndirectedEdge[175, 216] -> 
             RGBColor[
              0.27085375909209186`, 0.3992248172073352, 0.9388382497888704], 
             UndirectedEdge[115, 257] -> 
             RGBColor[
              0.19974017072672232`, 0.3272699620650275, 0.9346862792825601], 
             UndirectedEdge[146, 275] -> 
             RGBColor[
              0.516830443136153, 0.6156831650902019, 0.9561037300726619], 
             UndirectedEdge[64, 101] -> 
             RGBColor[
              0.4217235124038003, 0.5386986285638282, 0.9483688025457949], 
             UndirectedEdge[79, 390] -> 
             RGBColor[
              0.5161745074936666, 0.6114089616421088, 0.9572294723925013], 
             UndirectedEdge[98, 378] -> 
             RGBColor[
              0.3341332547688869, 0.46285449107217536`, 0.9425474142079834], 
             UndirectedEdge[37, 80] -> 
             RGBColor[
              0.3219630873034208, 0.44609009081412804`, 0.9419998042078002], 
             UndirectedEdge[344, 354] -> 
             RGBColor[
              0.26404998142393, 0.391911175601725, 0.9384567324361315], 
             UndirectedEdge[119, 227] -> 
             RGBColor[
              0.28619922485555366`, 0.41115028874913406`, 0.9398660652353477],
              UndirectedEdge[81, 166] -> 
             RGBColor[
              0.2812382423627253, 0.4064518388284541, 0.9395646565615468], 
             UndirectedEdge[192, 221] -> 
             RGBColor[
              0.4058508752281065, 0.5257943950937082, 0.9471242546810279], 
             UndirectedEdge[242, 331] -> 
             RGBColor[
              0.47368786969104854`, 0.5825184519234281, 0.952008474860685], 
             UndirectedEdge[225, 322] -> 
             RGBColor[
              0.41545525660529636`, 0.5342681947083241, 0.9476934194715989], 
             UndirectedEdge[165, 170] -> 
             RGBColor[
              0.4577151549265619, 0.5677553531575535, 0.9512472096162887], 
             UndirectedEdge[41, 250] -> 
             RGBColor[
              0.4211634093451815, 0.5392123097115138, 0.9480571379166631], 
             UndirectedEdge[31, 393] -> 
             RGBColor[
              0.4830644160167817, 0.5906292814208448, 0.9526088864997533], 
             UndirectedEdge[140, 312] -> 
             RGBColor[
              0.2631734344650032, 0.3907945314514106, 0.9384139666543775], 
             UndirectedEdge[56, 100] -> 
             RGBColor[
              0.39036114706475933`, 0.5125329382909294, 0.9460944450015256], 
             UndirectedEdge[89, 183] -> 
             RGBColor[
              0.3216990709475045, 0.4505335691834045, 0.9418119107983294], 
             UndirectedEdge[39, 210] -> 
             RGBColor[
              0.4683998287130413, 0.57342357442411, 0.9525727719795076], 
             UndirectedEdge[34, 321] -> 
             RGBColor[
              0.2463758335318303, 0.37628700054499864`, 0.9373421112880305], 
             UndirectedEdge[148, 301] -> 
             RGBColor[
              0.35578289342356717`, 0.4817907620620492, 0.9439201567091566], 
             UndirectedEdge[136, 155] -> 
             RGBColor[
              0.20825210145504697`, 0.33621654094807574`, 0.9351710211452651],
              UndirectedEdge[51, 205] -> 
             RGBColor[
              0.3816646463695007, 0.4935373171126398, 0.9465901241280457], 
             UndirectedEdge[11, 123] -> 
             RGBColor[
              0.5514107929485214, 0.6416375835533825, 0.9599990241779339], 
             UndirectedEdge[223, 400] -> 
             RGBColor[
              0.2789769856258655, 0.4105528784282585, 0.9391986986707033], 
             UndirectedEdge[6, 201] -> 
             RGBColor[
              0.5618219609779642, 0.6453885887263178, 0.9620281248568234], 
             UndirectedEdge[201, 273] -> 
             RGBColor[
              0.2844357668132493, 0.41629040356291636`, 0.9395095681837817], 
             UndirectedEdge[54, 196] -> 
             RGBColor[
              0.36745906495436487`, 0.48426115847936185`, 0.9452664014748602],
              UndirectedEdge[84, 288] -> 
             RGBColor[
              0.6583763132768041, 0.7274789176068897, 0.9617459035481568], 
             UndirectedEdge[177, 248] -> 
             RGBColor[
              0.3101241549011888, 0.43657963439002534`, 0.9412182025786466], 
             UndirectedEdge[76, 117] -> 
             RGBColor[
              0.3436048861355939, 0.4720350151120909, 0.9431151774000573], 
             UndirectedEdge[342, 348] -> 
             RGBColor[
              0.45755495038657307`, 0.5614775203164333, 0.9520418335576166], 
             UndirectedEdge[332, 389] -> 
             RGBColor[
              0.24292221665104802`, 0.372657030231339, 0.9371454329158382], 
             UndirectedEdge[68, 236] -> 
             RGBColor[
              0.3139809272493709, 0.4385801656958995, 0.9415130170711967], 
             UndirectedEdge[84, 318] -> 
             RGBColor[
              0.7309934126260597, 0.7886381932884938, 0.9668532171236421], 
             UndirectedEdge[15, 372] -> 
             RGBColor[
              0.32047653855288943`, 0.44012222239340315`, 0.9421135949383436],
              UndirectedEdge[88, 189] -> 
             RGBColor[
              0.3101696103460859, 0.43431880673237405`, 0.941305320508177], 
             UndirectedEdge[364, 380] -> 
             RGBColor[
              0.22897562945917044`, 0.357998282827975, 0.9363511954073875], 
             UndirectedEdge[103, 295] -> 
             RGBColor[
              0.4095775060024378, 0.5291771825604631, 0.9473188944006755], 
             UndirectedEdge[20, 257] -> 
             RGBColor[
              0.23507743335279563`, 0.36441166559688687`, 0.9366986841123197],
              UndirectedEdge[12, 24] -> 
             RGBColor[
              0.2352529687298595, 0.36459616440776677`, 0.9367086805923621], 
             UndirectedEdge[152, 157] -> 
             RGBColor[
              0.35031371408162315`, 0.4729927195847901, 0.9437203554001754], 
             UndirectedEdge[26, 70] -> 
             RGBColor[
              0.7542733442764391, 0.8056343521645595, 0.9086702241522255], 
             UndirectedEdge[33, 74] -> 
             RGBColor[
              0.3713776637238537, 0.4945961500562095, 0.944939546008879], 
             UndirectedEdge[124, 238] -> 
             RGBColor[
              0.4891775141274517, 0.5953890933800781, 0.9531462426122393], 
             UndirectedEdge[148, 339] -> 
             RGBColor[
              0.2919189215574966, 0.42415567365853457`, 0.9399357227761311], 
             UndirectedEdge[175, 229] -> 
             RGBColor[
              0.2791937088026044, 0.40799063313643663`, 0.9393131975870341], 
             UndirectedEdge[105, 337] -> 
             RGBColor[
              0.3495158809976345, 0.47715482176635027`, 0.943491820765779], 
             UndirectedEdge[158, 306] -> 
             RGBColor[
              0.42013559694858393`, 0.5383220702729341, 0.9479916466196107], 
             UndirectedEdge[136, 268] -> 
             RGBColor[
              0.19159717092635425`, 0.31871115297883346`, 0.9342225474904178],
              UndirectedEdge[133, 278] -> 
             RGBColor[
              0.3276123003355468, 0.4563969167706887, 0.9421615427359125], 
             UndirectedEdge[197, 254] -> 
             RGBColor[
              0.34954746226535555`, 0.47062271729040217`, 0.943774137387005], 
             UndirectedEdge[296, 398] -> 
             RGBColor[
              0.6074811348587111, 0.6880406035704467, 0.9644869612259401], 
             UndirectedEdge[10, 271] -> 
             RGBColor[
              0.27562529933836194`, 0.40196823961165884`, 0.93919316253601], 
             UndirectedEdge[221, 399] -> 
             RGBColor[
              0.348996969120772, 0.4767053663798812, 0.9434587561598411], 
             UndirectedEdge[187, 388] -> 
             RGBColor[
              0.34123627795001665`, 0.4631695636660824, 0.9432137413827222], 
             UndirectedEdge[143, 186] -> 
             RGBColor[
              0.5447041480892449, 0.6385587446822971, 0.958416166596288], 
             UndirectedEdge[372, 387] -> 
             RGBColor[
              0.32515292278720553`, 0.44391872178353, 0.9424817370354288], 
             UndirectedEdge[147, 255] -> 
             RGBColor[
              0.4643547096102106, 0.5746447090236386, 0.9513557032068836], 
             UndirectedEdge[27, 86] -> 
             RGBColor[
              0.40476711223811246`, 0.524593132018104, 0.9471277449370278], 
             UndirectedEdge[19, 157] -> 
             RGBColor[
              0.40662517441607127`, 0.5266200213288524, 0.9471307744426365], 
             UndirectedEdge[192, 208] -> 
             RGBColor[
              0.40491188654801524`, 0.5249810902939566, 0.9470644231526477], 
             UndirectedEdge[88, 89] -> 
             RGBColor[
              0.343853022339802, 0.46972220838943946`, 0.9432235409910765], 
             UndirectedEdge[54, 332] -> 
             RGBColor[
              0.2647762016311687, 0.39562695406812337`, 0.9383899850303825], 
             UndirectedEdge[282, 301] -> 
             RGBColor[
              0.33791994809471226`, 0.4630156739452743, 0.9429028883985378], 
             UndirectedEdge[264, 328] -> 
             RGBColor[
              0.3016317695207549, 0.4291605024265118, 0.9406793986749853], 
             UndirectedEdge[124, 156] -> 
             RGBColor[
              0.4414476323404132, 0.5540478687497571, 0.9501049367506466], 
             UndirectedEdge[64, 120] -> 
             RGBColor[
              0.394382119895705, 0.5160157028571235, 0.9463506578347067], 
             UndirectedEdge[55, 236] -> 
             RGBColor[
              0.22482708805000756`, 0.35363790277422746`, 0.9361149421113528],
              UndirectedEdge[11, 196] -> 
             RGBColor[
              0.63448023103739, 0.7122430540069045, 0.9656637909050025], 
             UndirectedEdge[223, 319] -> 
             RGBColor[
              0.4425096048654805, 0.551277225810735, 0.950620609422939], 
             UndirectedEdge[61, 70] -> 
             RGBColor[
              0.696780654684315, 0.75768435326128, 0.9044964320757566], 
             UndirectedEdge[307, 343] -> 
             RGBColor[
              0.2798783468242849, 0.4081504034515736, 0.9393726847423418], 
             UndirectedEdge[13, 87] -> 
             RGBColor[
              0.3050312206601903, 0.4379375313832462, 0.9406824488121214], 
             UndirectedEdge[119, 128] -> 
             RGBColor[
              0.30845432014459767`, 0.4304265337148909, 0.9412841402277574], 
             UndirectedEdge[92, 130] -> 
             RGBColor[
              0.2812796611268428, 0.4129731363778449, 0.9393298326339807], 
             UndirectedEdge[263, 359] -> 
             RGBColor[
              0.3751598792090951, 0.49936636411229074`, 0.945125833655716], 
             UndirectedEdge[22, 304] -> 
             RGBColor[
              0.28918929902790336`, 0.41290031502001134`, 0.9400873402501525],
              UndirectedEdge[139, 306] -> 
             RGBColor[
              0.5730173877649591, 0.6611483440472274, 0.9610387817742501], 
             UndirectedEdge[1, 73] -> 
             RGBColor[
              0.45134015416524564`, 0.5652911085221677, 0.9499962147294875], 
             UndirectedEdge[7, 13] -> 
             RGBColor[
              0.4778691730139394, 0.5820981869504258, 0.9533144058266989], 
             UndirectedEdge[170, 335] -> 
             RGBColor[
              0.4748206624914134, 0.5825712840624194, 0.9523371574325146], 
             UndirectedEdge[276, 361] -> 
             RGBColor[
              0.45490673761068084`, 0.5656652975070066, 0.9509736386122478], 
             UndirectedEdge[46, 345] -> 
             RGBColor[
              0.2617802924179151, 0.3924780635333786, 0.9382193724327382], 
             UndirectedEdge[36, 301] -> 
             RGBColor[
              0.3596302968439382, 0.48583462699632524`, 0.9441392606422234], 
             UndirectedEdge[50, 328] -> 
             RGBColor[
              0.38081897238478907`, 0.5042679861867836, 0.9454864260687317], 
             UndirectedEdge[55, 83] -> 
             RGBColor[
              0.23424870998454433`, 0.3635406247927584, 0.936651489542484], 
             UndirectedEdge[143, 306] -> 
             RGBColor[
              0.5502500567670471, 0.6433623320335342, 0.9587695469931831], 
             UndirectedEdge[32, 400] -> 
             RGBColor[
              0.28929973585306296`, 0.4214027434172096, 0.9397865640250017], 
             UndirectedEdge[20, 195] -> 
             RGBColor[
              0.4174666164133256, 0.5294133934590375, 0.948788659186246], 
             UndirectedEdge[203, 266] -> 
             RGBColor[
              0.3360212196104543, 0.4654664243341774, 0.9426319528750484], 
             UndirectedEdge[255, 359] -> 
             RGBColor[
              0.3728525112049075, 0.4973678379187514, 0.9449788102068146], 
             UndirectedEdge[128, 215] -> 
             RGBColor[
              0.4708023731090768, 0.5805945470542866, 0.9516656378870612], 
             UndirectedEdge[230, 328] -> 
             RGBColor[
              0.33743419447017303`, 0.4666902721394844, 0.9427219863836651], 
             UndirectedEdge[44, 146] -> 
             RGBColor[
              0.6534896381703252, 0.7291175329825867, 0.966174524173341], 
             UndirectedEdge[56, 206] -> 
             RGBColor[
              0.39637595365383016`, 0.5177426614454131, 0.9464777031586966], 
             UndirectedEdge[55, 196] -> 
             RGBColor[
              0.36404318621414555`, 0.48067085334417015`, 0.9450718722339444],
              UndirectedEdge[93, 188] -> 
             RGBColor[
              0.3516726874445534, 0.46545652547168026`, 0.9445687542207452], 
             UndirectedEdge[52, 271] -> 
             RGBColor[
              0.30466092656146393`, 0.4324865247882341, 0.9408466985520045], 
             UndirectedEdge[193, 253] -> 
             RGBColor[
              0.28665363911708575`, 0.4186215279754744, 0.939635872730437], 
             UndirectedEdge[120, 193] -> 
             RGBColor[
              0.354275356300057, 0.4779842915114757, 0.9439156613005008], 
             UndirectedEdge[28, 217] -> 
             RGBColor[
              0.28563798269741497`, 0.41275024871016897`, 0.9397539217842368],
              UndirectedEdge[124, 245] -> 
             RGBColor[
              0.39577239291584543`, 0.5079036996447946, 0.9474355711053541], 
             UndirectedEdge[36, 282] -> 
             RGBColor[
              0.2861618011681686, 0.41810457510683546`, 0.9396078632868553], 
             UndirectedEdge[276, 339] -> 
             RGBColor[
              0.3189997620195931, 0.4484039674226253, 0.9416322825304304], 
             UndirectedEdge[377, 388] -> 
             RGBColor[
              0.41116254825013315`, 0.5305500664888769, 0.9474198918911008], 
             UndirectedEdge[129, 131] -> 
             RGBColor[
              0.36421900713817446`, 0.4898899306286788, 0.9444286909619903], 
             UndirectedEdge[69, 142] -> 
             RGBColor[
              0.6062654780287391, 0.6839906348265697, 0.9657845188930164], 
             UndirectedEdge[11, 118] -> 
             RGBColor[
              0.48350757972089753`, 0.5728532206653145, 0.9560373424726463], 
             UndirectedEdge[53, 293] -> 
             RGBColor[
              0.28269237573651806`, 0.4127027534852754, 0.9394745524116481], 
             UndirectedEdge[2, 137] -> 
             RGBColor[
              0.42176168541881287`, 0.5397305063762635, 0.9480952595390402], 
             UndirectedEdge[102, 213] -> 
             RGBColor[
              0.2622659636156463, 0.3903970544683796, 0.9383419174769554], 
             UndirectedEdge[269, 362] -> 
             RGBColor[
              0.22922890318824815`, 0.35826448957571766`, 0.9363656189715737],
              UndirectedEdge[147, 242] -> 
             RGBColor[
              0.5300266521593769, 0.6293385395083813, 0.9561447860910377], 
             UndirectedEdge[58, 220] -> 
             RGBColor[
              0.30360170759542165`, 0.4345708590853202, 0.9406692963128784], 
             UndirectedEdge[177, 285] -> 
             RGBColor[
              0.2488719564652651, 0.37891058401137345`, 0.9374842617964065], 
             UndirectedEdge[213, 215] -> 
             RGBColor[
              0.3502316926313743, 0.4649760095130569, 0.9443925650381724], 
             UndirectedEdge[61, 382] -> 
             RGBColor[
              0.32610311848744084`, 0.4510597503985493, 0.9422129366384153], 
             UndirectedEdge[83, 123] -> 
             RGBColor[
              0.2899931457951592, 0.41954534170453606`, 0.9399207468611723], 
             UndirectedEdge[207, 368] -> 
             RGBColor[
              0.30620500248631966`, 0.4390567057053867, 0.9407534879968747], 
             UndirectedEdge[117, 377] -> 
             RGBColor[
              0.36141925640128025`, 0.4874649272599446, 0.9442502933207577], 
             UndirectedEdge[207, 392] -> 
             RGBColor[
              0.48632682703737096`, 0.5896581035905276, 0.9539926140409039], 
             UndirectedEdge[43, 325] -> 
             RGBColor[
              0.32585703650698217`, 0.4539162312041959, 0.942084862516906], 
             UndirectedEdge[83, 196] -> 
             RGBColor[
              0.373062583884028, 0.4901508121580581, 0.9455855135882411], 
             UndirectedEdge[81, 130] -> 
             RGBColor[
              0.3195944978414156, 0.4467666952636163, 0.9417489885680632], 
             UndirectedEdge[204, 229] -> 
             RGBColor[
              0.32474738677024867`, 0.4474469393975825, 0.9422158376655967], 
             UndirectedEdge[44, 267] -> 
             RGBColor[
              0.598200518994241, 0.6846851558026257, 0.9615116826173808], 
             UndirectedEdge[38, 130] -> 
             RGBColor[
              0.3424818269803328, 0.4665905494131359, 0.9432073489423245], 
             UndirectedEdge[226, 318] -> 
             RGBColor[
              0.5770309900669242, 0.6674987785430198, 0.9598451397536829], 
             UndirectedEdge[202, 362] -> 
             RGBColor[
              0.24876780262161294`, 0.37880111171795994`, 0.9374783303890923],
              UndirectedEdge[59, 230] -> 
             RGBColor[
              0.32681526457502774`, 0.45749268878724475`, 0.9420453575606975],
              UndirectedEdge[131, 394] -> 
             RGBColor[
              0.2848489738732835, 0.41352501255570207`, 0.9396502563260882], 
             UndirectedEdge[93, 142] -> 
             RGBColor[
              0.5427317487455877, 0.6172417773396586, 0.9621653007646743], 
             UndirectedEdge[301, 340] -> 
             RGBColor[
              0.3744424725404924, 0.4987449825138547, 0.9450801211371705], 
             UndirectedEdge[16, 76] -> 
             RGBColor[
              0.407419734083564, 0.5267040987816702, 0.9473483260550531], 
             UndirectedEdge[25, 239] -> 
             RGBColor[
              0.4921979603950738, 0.5974387837473815, 0.9534952196780795], 
             UndirectedEdge[46, 60] -> 
             RGBColor[
              0.33325018922773614`, 0.4624173545613103, 0.9424791462343854], 
             UndirectedEdge[57, 297] -> 
             RGBColor[
              0.22177864176760326`, 0.35043379244876277`, 0.935941337605342], 
             UndirectedEdge[221, 351] -> 
             RGBColor[
              0.3255243417800034, 0.45541543282815916`, 0.9419982193120824], 
             UndirectedEdge[365, 377] -> 
             RGBColor[
              0.6624955218701878, 0.7307199497768386, 0.9572386387842744], 
             UndirectedEdge[334, 366] -> 
             RGBColor[
              0.5204081121433988, 0.6196673999623894, 0.9559569367372818], 
             UndirectedEdge[209, 290] -> 
             RGBColor[
              0.5951616484765224, 0.682218063816785, 0.9612724515984765], 
             UndirectedEdge[174, 313] -> 
             RGBColor[
              0.3771340397847601, 0.5010762827787362, 0.9452516254219159], 
             UndirectedEdge[56, 358] -> 
             RGBColor[
              0.41734032867523163`, 0.5359009493888248, 0.9478135345969914], 
             UndirectedEdge[304, 338] -> 
             RGBColor[
              0.3037357194832036, 0.425499693294042, 0.9410142252986697], 
             UndirectedEdge[130, 306] -> 
             RGBColor[
              0.32952950182201257`, 0.4553718963637901, 0.9423820382365278], 
             UndirectedEdge[11, 206] -> 
             RGBColor[
              0.5608402253319478, 0.6498048839468545, 0.9605998592712861], 
             UndirectedEdge[120, 140] -> 
             RGBColor[
              0.38910653680320795`, 0.5114462579409187, 0.9460145023450679], 
             UndirectedEdge[193, 356] -> 
             RGBColor[
              0.3474690518412523, 0.47208901268406805`, 0.9434819695989645], 
             UndirectedEdge[166, 246] -> 
             RGBColor[
              0.3191362872395959, 0.4392422845142521, 0.941989139383278], 
             UndirectedEdge[76, 182] -> 
             RGBColor[
              0.377790189865259, 0.5016446069994023, 0.9452934347248345], 
             UndirectedEdge[6, 364] -> 
             RGBColor[
              0.5117120779119323, 0.5927199244738283, 0.9591744411471417], 
             UndirectedEdge[288, 318] -> 
             RGBColor[
              0.444710324644346, 0.5578694583080914, 0.9500377427555368], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.2823143977477976, 0.4140607101725594, 0.9393887593537884], 
             UndirectedEdge[128, 151] -> 
             RGBColor[
              0.4492406167552089, 0.5630897419001623, 0.9499682174435687], 
             UndirectedEdge[30, 379] -> 
             RGBColor[
              0.4683011718230925, 0.5756648586251737, 0.9522697642787255], 
             UndirectedEdge[70, 90] -> 
             RGBColor[
              0.9228091530146288, 0.9394601738163295, 0.9241184827599657], 
             UndirectedEdge[137, 394] -> 
             RGBColor[
              0.32049141279056775`, 0.4443967017047852, 0.9419213610165263], 
             UndirectedEdge[25, 269] -> 
             RGBColor[
              0.3801023083444911, 0.48893808935334404`, 0.9467703259644455], 
             UndirectedEdge[38, 227] -> 
             RGBColor[
              0.40448562385251274`, 0.5247668501676361, 0.9469944441726568], 
             UndirectedEdge[128, 135] -> 
             RGBColor[
              0.3761766845873016, 0.500247069824769, 0.9451906235952897], 
             UndirectedEdge[129, 303] -> 
             RGBColor[
              0.4684706427622695, 0.5775118994899384, 0.9518107776662976], 
             UndirectedEdge[132, 299] -> 
             RGBColor[
              0.397077334794842, 0.5183501625373164, 0.9465223945447949], 
             UndirectedEdge[352, 396] -> 
             RGBColor[
              0.33043909080923356`, 0.4584630339390369, 0.9423556614449102], 
             UndirectedEdge[155, 268] -> 
             RGBColor[
              0.19716901003489629`, 0.3245675091569148, 0.9345398554848519], 
             UndirectedEdge[8, 16] -> 
             RGBColor[
              0.388632868626246, 0.5097802323765035, 0.9461751028865708], 
             UndirectedEdge[213, 378] -> 
             RGBColor[
              0.27892045502731583`, 0.40482233785009014`, 0.9394031269427183],
              UndirectedEdge[164, 230] -> 
             RGBColor[
              0.3627306726714874, 0.4886008101194998, 0.9443338556058556], 
             UndirectedEdge[218, 339] -> 
             RGBColor[
              0.3278870924576679, 0.4561017263578697, 0.9421985753671869], 
             UndirectedEdge[101, 366] -> 
             RGBColor[
              0.5706198776934386, 0.662159493299654, 0.9594323613951259], 
             UndirectedEdge[169, 361] -> 
             RGBColor[
              0.7338469393674164, 0.7914206177162151, 0.9748188137336719], 
             UndirectedEdge[65, 341] -> 
             RGBColor[
              0.3644085225145376, 0.489631383130306, 0.94445624369241], 
             UndirectedEdge[46, 353] -> 
             RGBColor[
              0.2751091984773059, 0.40648758890325326`, 0.9389784339144711], 
             UndirectedEdge[279, 300] -> 
             RGBColor[
              0.5805986260056722, 0.667790579481113, 0.9614897914638988], 
             UndirectedEdge[203, 358] -> 
             RGBColor[
              0.3792840561464048, 0.5029385188882284, 0.945388622563295], 
             UndirectedEdge[81, 243] -> 
             RGBColor[
              0.33318914644040754`, 0.4610555328916619, 0.9425231836942956], 
             UndirectedEdge[176, 320] -> 
             RGBColor[
              0.7571164491462782, 0.809175245364621, 0.9509177856853397], 
             UndirectedEdge[112, 248] -> 
             RGBColor[
              0.40546838106592165`, 0.5256180650710772, 0.9470570645932772], 
             UndirectedEdge[58, 179] -> 
             RGBColor[
              0.2601942547844003, 0.3889468739894696, 0.9381973060908626], 
             UndirectedEdge[23, 213] -> 
             RGBColor[
              0.42759492751754546`, 0.5273988668926398, 0.9507454948290064], 
             UndirectedEdge[243, 326] -> 
             RGBColor[
              0.29218434162830254`, 0.424434646981556, 0.9399508380565098], 
             UndirectedEdge[269, 377] -> 
             RGBColor[
              0.28012381119992513`, 0.4056418239752999, 0.9394879615520031], 
             UndirectedEdge[222, 363] -> 
             RGBColor[
              0.2469679560201281, 0.37690935882293375`, 0.9373758317877723], 
             UndirectedEdge[30, 341] -> 
             RGBColor[
              0.5195593266353735, 0.620062096013801, 0.9555358885775573], 
             UndirectedEdge[23, 348] -> 
             RGBColor[
              0.4671481100698239, 0.5689717695717028, 0.9529979900616687], 
             UndirectedEdge[16, 25] -> 
             RGBColor[
              0.5252126014938163, 0.6254302763075681, 0.955765806388196], 
             UndirectedEdge[25, 62] -> 
             RGBColor[
              0.4357208268723508, 0.5473966787438754, 0.9499377183143825], 
             UndirectedEdge[16, 388] -> 
             RGBColor[
              0.461496095118157, 0.573542324752901, 0.9507940239623289], 
             UndirectedEdge[207, 372] -> 
             RGBColor[
              0.24595632729396982`, 0.37573152809158783`, 0.937322415074598], 
             UndirectedEdge[249, 279] -> 
             RGBColor[
              0.42271469726861943`, 0.5405559573407976, 0.9481559846113945], 
             UndirectedEdge[151, 267] -> 
             RGBColor[
              0.515494502896465, 0.6175406860708856, 0.9550007620680445], 
             UndirectedEdge[185, 252] -> 
             RGBColor[
              0.39299553827661626`, 0.514324890619147, 0.9463976461679529], 
             UndirectedEdge[218, 382] -> 
             RGBColor[
              0.3089767140975055, 0.43622571971410073`, 0.9411216572949733], 
             UndirectedEdge[284, 334] -> 
             RGBColor[
              0.33439993574292803`, 0.4613230088334118, 0.94262893946712], 
             UndirectedEdge[145, 235] -> 
             RGBColor[
              0.7105408626343128, 0.7725039456717347, 0.9729791812068801], 
             UndirectedEdge[78, 302] -> 
             RGBColor[
              0.4506725285122076, 0.5634930522260484, 0.95029070651848], 
             UndirectedEdge[235, 335] -> 
             RGBColor[
              0.4455021557145843, 0.5587691994773107, 0.9500290971818136], 
             UndirectedEdge[21, 109] -> 
             RGBColor[
              0.2840530446206092, 0.41377231650272905`, 0.9395652433206967], 
             UndirectedEdge[283, 389] -> 
             RGBColor[
              0.4139216054994761, 0.5167536676883634, 0.9493999765013408], 
             UndirectedEdge[91, 395] -> 
             RGBColor[
              0.44585255539921265`, 0.5577702432811322, 0.9504112964794031], 
             UndirectedEdge[240, 374] -> 
             RGBColor[
              0.4103724681030394, 0.5293838409096385, 0.9475026984990728], 
             UndirectedEdge[301, 339] -> 
             RGBColor[
              0.34752447190441127`, 0.4731106374312495, 0.9434498518208805], 
             UndirectedEdge[303, 353] -> 
             RGBColor[
              0.4001740084818627, 0.5127858258437011, 0.9476629567209361], 
             UndirectedEdge[92, 143] -> 
             RGBColor[
              0.5020002160718773, 0.600963572047589, 0.955717341390636], 
             UndirectedEdge[53, 394] -> 
             RGBColor[
              0.2770374240531607, 0.40675904072142155`, 0.9391525112790322], 
             UndirectedEdge[139, 345] -> 
             RGBColor[
              0.4845948237371407, 0.5765255047408957, 0.9556987990081272], 
             UndirectedEdge[224, 393] -> 
             RGBColor[
              0.6509167177751979, 0.7255648689340846, 0.966972817626623], 
             UndirectedEdge[175, 204] -> 
             RGBColor[
              0.38447630217500134`, 0.5074357814283252, 0.9457194678889143], 
             UndirectedEdge[131, 293] -> 
             RGBColor[
              0.29050392555664084`, 0.4194687253195559, 0.939972297458704], 
             UndirectedEdge[166, 383] -> 
             RGBColor[
              0.2542019658477199, 0.3830343749939253, 0.9378419289292512], 
             UndirectedEdge[92, 348] -> 
             RGBColor[
              0.2845210553626427, 0.41638004723593525`, 0.9395144252404966], 
             UndirectedEdge[212, 289] -> 
             RGBColor[
              0.26587785843025574`, 0.3961681067361603, 0.93847530530444], 
             UndirectedEdge[161, 214] -> 
             RGBColor[
              0.3433623247644898, 0.4718249206439295, 0.9430997216039791], 
             UndirectedEdge[124, 386] -> 
             RGBColor[
              0.4588385949417715, 0.5691110464598579, 0.9512130735093807], 
             UndirectedEdge[227, 350] -> 
             RGBColor[
              0.3050260811782164, 0.4309385084358879, 0.9409382268510853], 
             UndirectedEdge[258, 279] -> 
             RGBColor[
              0.3374569574911687, 0.4621373819326065, 0.9428908623426956], 
             UndirectedEdge[63, 103] -> 
             RGBColor[
              0.4681940473073464, 0.5781361592842882, 0.9515544736512532], 
             UndirectedEdge[291, 336] -> 
             RGBColor[
              0.5610475334969128, 0.6318145864054693, 0.9604451415026278], 
             UndirectedEdge[292, 400] -> 
             RGBColor[
              0.2695745676031752, 0.4006703409386766, 0.938663244873942], 
             UndirectedEdge[149, 300] -> 
             RGBColor[
              0.49774960252150746`, 0.5905926576382289, 0.9564098463529935], 
             UndirectedEdge[356, 364] -> 
             RGBColor[
              0.30273803892737366`, 0.42507388200155694`, 0.9409346045871225],
              UndirectedEdge[100, 167] -> 
             RGBColor[
              0.3766412855231207, 0.5006494838038533, 0.9452202275560897], 
             UndirectedEdge[334, 391] -> 
             RGBColor[
              0.41904435279016117`, 0.5373768894304345, 0.9479221135067852], 
             UndirectedEdge[309, 323] -> 
             RGBColor[
              0.27930349527084364`, 0.4108960607670378, 0.939217292911957], 
             UndirectedEdge[8, 202] -> 
             RGBColor[
              0.26306147491028553`, 0.3938246675645217, 0.9382923338803391], 
             UndirectedEdge[127, 380] -> 
             RGBColor[
              0.6214853451379421, 0.6908936099152496, 0.9384098734977957], 
             UndirectedEdge[130, 151] -> 
             RGBColor[
              0.3649817245939848, 0.4856371961799052, 0.9447630472208266], 
             UndirectedEdge[335, 355] -> 
             RGBColor[
              0.4350362982314973, 0.5502725448910342, 0.9492051865430459], 
             UndirectedEdge[117, 395] -> 
             RGBColor[
              0.34111244532036944`, 0.4698761881516613, 0.9429563612752901], 
             UndirectedEdge[256, 310] -> 
             RGBColor[
              0.31792659348608904`, 0.44404195054692447`, 0.9416895815354969],
              UndirectedEdge[362, 365] -> 
             RGBColor[
              0.6116006138585108, 0.6833426153772564, 0.954116296203845], 
             UndirectedEdge[163, 342] -> 
             RGBColor[
              0.46711668233894216`, 0.5715275068471943, 0.9525863600469893], 
             UndirectedEdge[125, 288] -> 
             RGBColor[
              0.35412433607264493`, 0.4811464339246373, 0.9437854674480619], 
             UndirectedEdge[161, 253] -> 
             RGBColor[
              0.31666181833461093`, 0.4479060531024014, 0.9414273963978967], 
             UndirectedEdge[12, 211] -> 
             RGBColor[
              0.4129170306386236, 0.5160273854847046, 0.9493127661475115], 
             UndirectedEdge[107, 152] -> 
             RGBColor[
              0.3989267414421472, 0.512701860345183, 0.9474802383337433], 
             UndirectedEdge[183, 291] -> 
             RGBColor[
              0.6507785767526364, 0.721204672489419, 0.9657354442410788], 
             UndirectedEdge[149, 299] -> 
             RGBColor[
              0.3475822901709669, 0.4700417807634936, 0.9435677354731018], 
             UndirectedEdge[57, 284] -> 
             RGBColor[
              0.24563523307662416`, 0.375508582509796, 0.9372999351877267], 
             UndirectedEdge[230, 279] -> 
             RGBColor[
              0.3627306726714874, 0.4886008101194998, 0.9443338556058556], 
             UndirectedEdge[186, 374] -> 
             RGBColor[
              0.4293263471982356, 0.5458007383322345, 0.9487104229147615], 
             UndirectedEdge[30, 175] -> 
             RGBColor[
              0.47669920516555353`, 0.5829388130089845, 0.9528048795372177], 
             UndirectedEdge[261, 327] -> 
             RGBColor[
              0.3250801132902622, 0.45116838648033786`, 0.9421113303813953], 
             UndirectedEdge[271, 333] -> 
             RGBColor[
              0.3574227282407705, 0.48400333543865703`, 0.9439956380803612], 
             UndirectedEdge[199, 247] -> 
             RGBColor[
              0.3432484863067444, 0.45926648769003725`, 0.9438464843818968], 
             UndirectedEdge[99, 223] -> 
             RGBColor[
              0.3451291992397415, 0.4709701854154691, 0.943299635957265], 
             UndirectedEdge[200, 367] -> 
             RGBColor[
              0.35031995608036226`, 0.4778512711890203, 0.9435430557190347], 
             UndirectedEdge[111, 400] -> 
             RGBColor[
              0.2926526374762968, 0.42478315379608445`, 0.9399827684396002], 
             UndirectedEdge[277, 390] -> 
             RGBColor[
              0.48246570070307315`, 0.5759788684434022, 0.9553098057134879], 
             UndirectedEdge[79, 298] -> 
             RGBColor[
              0.40133283478481785`, 0.5195917340069348, 0.9472203040004105], 
             UndirectedEdge[96, 388] -> 
             RGBColor[
              0.5541876200759575, 0.648508679269709, 0.958285760448638], 
             UndirectedEdge[153, 175] -> 
             RGBColor[
              0.35267216913242216`, 0.479888639909049, 0.9436929366547318], 
             UndirectedEdge[127, 331] -> 
             RGBColor[
              0.6910831023869671, 0.7543619966580863, 0.942727914720782], 
             UndirectedEdge[6, 93] -> 
             RGBColor[
              0.5108748742710479, 0.5918399703654821, 0.9591267636383252], 
             UndirectedEdge[76, 239] -> 
             RGBColor[
              0.3744050929848215, 0.4987126062214836, 0.9450777393449366], 
             UndirectedEdge[333, 337] -> 
             RGBColor[
              0.3543405599121371, 0.4813337161466793, 0.9437992450399151], 
             UndirectedEdge[253, 332] -> 
             RGBColor[
              0.29883433827194467`, 0.4314242150881636, 0.9403295455275767], 
             UndirectedEdge[31, 400] -> 
             RGBColor[
              0.3534221195803685, 0.4774186248316513, 0.9438549461029285], 
             UndirectedEdge[39, 149] -> 
             RGBColor[
              0.27126823656742527`, 0.40245049440491787`, 0.9387596968158973],
              UndirectedEdge[49, 335] -> 
             RGBColor[
              0.3926234157523265, 0.5144924017231696, 0.9462385947618517], 
             UndirectedEdge[57, 236] -> 
             RGBColor[
              0.21828774490572583`, 0.3467646385112848, 0.9357425361933771], 
             UndirectedEdge[76, 323] -> 
             RGBColor[
              0.3006839530127104, 0.4305459571065139, 0.9405382173241684], 
             UndirectedEdge[2, 210] -> 
             RGBColor[
              0.5365373649063981, 0.633932772365698, 0.9568598101775456], 
             UndirectedEdge[25, 395] -> 
             RGBColor[
              0.4545722435448817, 0.5648492789352608, 0.9510977422715003], 
             UndirectedEdge[62, 91] -> 
             RGBColor[
              0.4270011387266818, 0.5403176430897468, 0.9492512725222852], 
             UndirectedEdge[148, 313] -> 
             RGBColor[
              0.34139408289545625`, 0.4693278975852447, 0.943003314425831], 
             UndirectedEdge[98, 163] -> 
             RGBColor[
              0.29208455790040366`, 0.42432976795688054`, 0.9399451555208227],
              UndirectedEdge[271, 292] -> 
             RGBColor[
              0.3138189368637749, 0.4421121742673529, 0.941368233690659], 
             UndirectedEdge[148, 228] -> 
             RGBColor[
              0.2702929738530568, 0.40142543145688914`, 0.938704157047086], 
             UndirectedEdge[105, 333] -> 
             RGBColor[
              0.34652702254449963`, 0.4745660227986387, 0.9433013733480891], 
             UndirectedEdge[9, 65] -> 
             RGBColor[
              0.3135096103428719, 0.4455453036609195, 0.9412130100169722], 
             UndirectedEdge[129, 337] -> 
             RGBColor[
              0.3712069771730566, 0.4959425590473074, 0.9448739582333937], 
             UndirectedEdge[62, 323] -> 
             RGBColor[
              0.2793400955249551, 0.410934529954699, 0.9392193772422834], 
             UndirectedEdge[286, 290] -> 
             RGBColor[
              0.48019057264945514`, 0.5863150698277999, 0.9529300297728558], 
             UndirectedEdge[96, 261] -> 
             RGBColor[
              0.527256261442529, 0.6251820900308762, 0.9565697180909813], 
             UndirectedEdge[48, 86] -> 
             RGBColor[
              0.264596021479936, 0.3924703614361743, 0.9384883681990903], 
             UndirectedEdge[137, 328] -> 
             RGBColor[
              0.3898349887548957, 0.5120772064084109, 0.9460609186592847], 
             UndirectedEdge[110, 212] -> 
             RGBColor[
              0.23241510599416104`, 0.3616133907416579, 0.9365470685078058], 
             UndirectedEdge[163, 272] -> 
             RGBColor[
              0.3403694175303809, 0.4671283595088659, 0.9429860632966421], 
             UndirectedEdge[245, 396] -> 
             RGBColor[
              0.30656772671472565`, 0.43337271674380806`, 0.9409962225742465],
              UndirectedEdge[25, 37] -> 
             RGBColor[
              0.49395533601858416`, 0.598960934184199, 0.9536071980988233], 
             UndirectedEdge[79, 373] -> 
             RGBColor[
              0.30359670105543796`, 0.4363446606534783, 0.9406038709586525], 
             UndirectedEdge[34, 43] -> 
             RGBColor[
              0.30158223450946264`, 0.4284018751934614, 0.9407024484544986], 
             UndirectedEdge[100, 358] -> 
             RGBColor[
              0.3705266171350753, 0.49535326537829777`, 0.9448306062933923], 
             UndirectedEdge[273, 394] -> 
             RGBColor[
              0.25566416380786616`, 0.38604962457926595`, 0.9378710679563974],
              UndirectedEdge[89, 189] -> 
             RGBColor[
              0.2477230203290024, 0.37770297928540286`, 0.9374188315831451], 
             UndirectedEdge[268, 299] -> 
             RGBColor[
              0.3128760645170614, 0.4335633370994375, 0.9415912672653717], 
             UndirectedEdge[143, 272] -> 
             RGBColor[
              0.5482868462872464, 0.6416618977897587, 0.958644452957409], 
             UndirectedEdge[339, 382] -> 
             RGBColor[
              0.26475012167817824`, 0.3955995423839659, 0.9383884998156415], 
             UndirectedEdge[111, 223] -> 
             RGBColor[
              0.29662460660082274`, 0.4289579451833491, 0.9402089662052402], 
             UndirectedEdge[71, 131] -> 
             RGBColor[
              0.3118388634897865, 0.4418930978004859, 0.9411872906117844], 
             UndirectedEdge[114, 370] -> 
             RGBColor[
              0.34747869710689555`, 0.4721507191072962, 0.9434806307021402], 
             UndirectedEdge[4, 125] -> 
             RGBColor[
              0.310230869645888, 0.44086850150596313`, 0.9410713502629637], 
             UndirectedEdge[246, 251] -> 
             RGBColor[
              0.31829908359871156`, 0.438362330405906, 0.9419414618744615], 
             UndirectedEdge[30, 229] -> 
             RGBColor[
              0.41697028976080086`, 0.5229499709782418, 0.9493012493139001], 
             UndirectedEdge[115, 366] -> 
             RGBColor[
              0.42529775039807627`, 0.5271832836087015, 0.9502665565608996], 
             UndirectedEdge[89, 270] -> 
             RGBColor[
              0.2513180017197303, 0.381481532662043, 0.9376235604550487], 
             UndirectedEdge[197, 369] -> 
             RGBColor[
              0.3827280420085152, 0.5054976103707267, 0.9456637223171092], 
             UndirectedEdge[276, 301] -> 
             RGBColor[
              0.38286373388566375`, 0.50603905582614, 0.9456167164634558], 
             UndirectedEdge[69, 188] -> 
             RGBColor[
              0.41520641672770486`, 0.5322053829585914, 0.9481879723490872], 
             UndirectedEdge[191, 225] -> 
             RGBColor[
              0.400563563777437, 0.5213697588590767, 0.9467445339728146], 
             UndirectedEdge[223, 247] -> 
             RGBColor[
              0.3910127577886283, 0.509469765447223, 0.9465665889818827], 
             UndirectedEdge[72, 86] -> 
             RGBColor[
              0.27858856883001204`, 0.40717741587984724`, 0.9392852230705584],
              UndirectedEdge[19, 85] -> 
             RGBColor[
              0.3946907436044512, 0.516283017201761, 0.9463703230645228], 
             UndirectedEdge[320, 398] -> 
             RGBColor[
              0.6814596166118513, 0.7462501612216771, 0.9453772129418854], 
             UndirectedEdge[249, 300] -> 
             RGBColor[
              0.5876887454919476, 0.6739316846203577, 0.9619415676080177], 
             UndirectedEdge[18, 319] -> 
             RGBColor[
              0.5175479072871578, 0.61865674492688, 0.9553146530253743], 
             UndirectedEdge[6, 273] -> 
             RGBColor[
              0.562370052329388, 0.6459646674876629, 0.9620593378484585], 
             UndirectedEdge[158, 348] -> 
             RGBColor[
              0.3542279096495134, 0.47736379393415096`, 0.9439338527754146], 
             UndirectedEdge[61, 228] -> 
             RGBColor[
              0.3233875491431635, 0.44820551484067284`, 0.9420582889815835], 
             UndirectedEdge[70, 260] -> 
             RGBColor[
              0.9798059972570583, 0.9839610495479766, 0.8967266367702569], 
             UndirectedEdge[144, 305] -> 
             RGBColor[
              0.3543611646017677, 0.4753989557625928, 0.9440740554190235], 
             UndirectedEdge[165, 351] -> 
             RGBColor[
              0.3228578933192351, 0.4531058891910381, 0.9418283155740101], 
             UndirectedEdge[132, 370] -> 
             RGBColor[
              0.385083514755416, 0.5079617184460887, 0.9457581589376013], 
             UndirectedEdge[104, 145] -> 
             RGBColor[
              0.6783489690510603, 0.7461450544999568, 0.9705068263455284], 
             UndirectedEdge[207, 231] -> 
             RGBColor[
              0.3838851189631093, 0.5068024295540425, 0.9457153134068372], 
             UndirectedEdge[21, 249] -> 
             RGBColor[
              0.33314023877164134`, 0.4562891768822382, 0.9426930359258989], 
             UndirectedEdge[7, 93] -> 
             RGBColor[
              0.4178284669618036, 0.5189915980889971, 0.9498951764392946], 
             UndirectedEdge[140, 255] -> 
             RGBColor[
              0.3726726431804778, 0.49721204527642016`, 0.944967349175349], 
             UndirectedEdge[100, 157] -> 
             RGBColor[
              0.39395989669593906`, 0.5156499943430415, 0.9463237541457751], 
             UndirectedEdge[42, 178] -> 
             RGBColor[
              0.2659667693291203, 0.3968783162050224, 0.9384577860994938], 
             UndirectedEdge[115, 195] -> 
             RGBColor[
              0.3821293537872523, 0.49227168992717807`, 0.9467762543564864], 
             UndirectedEdge[281, 394] -> 
             RGBColor[
              0.3661835126905807, 0.48254184982575715`, 0.9452282252216727], 
             UndirectedEdge[215, 224] -> 
             RGBColor[
              0.6401251838923967, 0.7168038155749654, 0.9661232685486777], 
             UndirectedEdge[99, 222] -> 
             RGBColor[
              0.32955131398112086`, 0.45459684031368686`, 0.9424124984372025],
              UndirectedEdge[55, 284] -> 
             RGBColor[
              0.2521745762209059, 0.3823818467727387, 0.9376723411057022], 
             UndirectedEdge[32, 337] -> 
             RGBColor[
              0.33046193678502916`, 0.46017495745390813`, 0.9422951598012727],
              UndirectedEdge[172, 399] -> 
             RGBColor[
              0.2668353052276131, 0.39440991646873846`, 0.9386310533793714], 
             UndirectedEdge[267, 346] -> 
             RGBColor[
              0.6589398994693465, 0.7322480276182219, 0.9674884902391064], 
             UndirectedEdge[222, 393] -> 
             RGBColor[
              0.39304139680365796`, 0.5073901899156698, 0.9470655015474656], 
             UndirectedEdge[116, 179] -> 
             RGBColor[
              0.23092180319299346`, 0.3600438348167646, 0.9364620271224228], 
             UndirectedEdge[120, 360] -> 
             RGBColor[
              0.392580169254291, 0.5144549437802034, 0.9462358391332383], 
             UndirectedEdge[144, 222] -> 
             RGBColor[
              0.35682284497328176`, 0.4779863379126043, 0.9442142444744515], 
             UndirectedEdge[237, 307] -> 
             RGBColor[
              0.33165175256912927`, 0.4616818115987808, 0.9423535342989433], 
             UndirectedEdge[18, 144] -> 
             RGBColor[
              0.44743903265357965`, 0.5617392021305316, 0.9497954255969492], 
             UndirectedEdge[309, 365] -> 
             RGBColor[
              0.6233006938626346, 0.6956401412895088, 0.9547825984513625], 
             UndirectedEdge[189, 241] -> 
             RGBColor[
              0.27387388337412366`, 0.40288127230554116`, 0.9389925888805747],
              UndirectedEdge[268, 370] -> 
             RGBColor[
              0.30088224447763545`, 0.42317489300820993`, 0.940827031658178], 
             UndirectedEdge[336, 359] -> 
             RGBColor[
              0.2628408276367617, 0.3904116805308021, 0.9383962430011221], 
             UndirectedEdge[115, 123] -> 
             RGBColor[
              0.2680887459019765, 0.39652242859763337`, 0.9386733236919114], 
             UndirectedEdge[6, 394] -> 
             RGBColor[
              0.5330503579725812, 0.6151478097426673, 0.9603896246294392], 
             UndirectedEdge[259, 353] -> 
             RGBColor[
              0.3109326364073405, 0.43816499283129917`, 0.9412373107369527], 
             UndirectedEdge[98, 348] -> 
             RGBColor[
              0.2825228259480346, 0.41427978142611954`, 0.93940062903145], 
             UndirectedEdge[145, 349] -> 
             RGBColor[
              0.6424269504741547, 0.7150312075017918, 0.9682179070864019], 
             UndirectedEdge[287, 292] -> 
             RGBColor[
              0.34471623279940866`, 0.46887385906355133`, 0.9433369820662716],
              UndirectedEdge[53, 69] -> 
             RGBColor[
              0.31839566963477894`, 0.4502000588311475, 0.9415088684162602], 
             UndirectedEdge[236, 284] -> 
             RGBColor[
              0.2517723519562516, 0.3819590835680957, 0.9376494350288677], 
             UndirectedEdge[119, 146] -> 
             RGBColor[
              0.42999732546193814`, 0.5293098550655753, 0.9509795264081933], 
             UndirectedEdge[198, 310] -> 
             RGBColor[
              0.3413856578637528, 0.46436101302399774`, 0.9431843723736055], 
             UndirectedEdge[198, 384] -> 
             RGBColor[
              0.3331727639117327, 0.45572874075287223`, 0.9427166602129258], 
             UndirectedEdge[111, 292] -> 
             RGBColor[
              0.28722218857813253`, 0.4190754076937673, 0.939673512408479], 
             UndirectedEdge[40, 295] -> 
             RGBColor[
              0.3515022809006535, 0.47808476130370414`, 0.9436473394256757], 
             UndirectedEdge[5, 270] -> 
             RGBColor[
              0.327127565355244, 0.4496716962147155, 0.9423615262426334], 
             UndirectedEdge[104, 355] -> 
             RGBColor[
              0.46679201453348573`, 0.5777777502631067, 0.9512286327053312], 
             UndirectedEdge[356, 360] -> 
             RGBColor[
              0.3857738647954863, 0.5085596649527958, 0.945802147431702], 
             UndirectedEdge[42, 398] -> 
             RGBColor[
              0.3275247427135841, 0.45333243019843156`, 0.9422653927057361], 
             UndirectedEdge[153, 211] -> 
             RGBColor[
              0.501578135098867, 0.6038833138736313, 0.9545571343377276], 
             UndirectedEdge[223, 385] -> 
             RGBColor[
              0.5228845844299714, 0.6146839429085205, 0.9582096722423673], 
             UndirectedEdge[144, 361] -> 
             RGBColor[
              0.5086634784669648, 0.6119949527048736, 0.9544629988020872], 
             UndirectedEdge[216, 229] -> 
             RGBColor[
              0.2111248436873392, 0.33923597517659243`, 0.9353346195655527], 
             UndirectedEdge[161, 389] -> 
             RGBColor[
              0.2607496967137143, 0.38913886824557686`, 0.9382432837861581], 
             UndirectedEdge[313, 340] -> 
             RGBColor[
              0.3600536620123814, 0.4862821180370502, 0.9441632788538449], 
             UndirectedEdge[241, 380] -> 
             RGBColor[
              0.30399575400077006`, 0.4345412681710512, 0.9407079848514479], 
             UndirectedEdge[258, 281] -> 
             RGBColor[
              0.38265594656504776`, 0.49985542224045204`, 0.9461663059620415],
              UndirectedEdge[344, 346] -> 
             RGBColor[
              0.47194711691660707`, 0.5620017402943591, 0.9551732931171664], 
             UndirectedEdge[79, 205] -> 
             RGBColor[
              0.25536091603308797`, 0.38573089194095456`, 0.9378537984442387],
              UndirectedEdge[227, 306] -> 
             RGBColor[
              0.3915332986941925, 0.5135481971182904, 0.94616913346686], 
             UndirectedEdge[43, 381] -> 
             RGBColor[
              0.36654897471010484`, 0.49190803143190964`, 0.9445771544353643],
              UndirectedEdge[98, 143] -> 
             RGBColor[
              0.5000019866572691, 0.5988633062377733, 0.9556035451815896], 
             UndirectedEdge[243, 267] -> 
             RGBColor[
              0.42448784718861415`, 0.5371990366859427, 0.9491515617592661], 
             UndirectedEdge[58, 152] -> 
             RGBColor[
              0.2925817989055697, 0.4229882363497197, 0.9400417288154854], 
             UndirectedEdge[376, 397] -> 
             RGBColor[
              0.26745214843445264`, 0.3973392070559766, 0.938582664961302], 
             UndirectedEdge[114, 279] -> 
             RGBColor[
              0.34466578127353387`, 0.46971431279369896`, 0.9433013941926022],
              UndirectedEdge[148, 218] -> 
             RGBColor[
              0.3361455139768238, 0.4647818509886694, 0.9426688802554629], 
             UndirectedEdge[55, 366] -> 
             RGBColor[
              0.4381827526213766, 0.5407262379017161, 0.9510003383758641], 
             UndirectedEdge[99, 361] -> 
             RGBColor[
              0.48139194747480385`, 0.5886054551059562, 0.9526612527648384], 
             UndirectedEdge[97, 169] -> 
             RGBColor[
              0.5970374338103346, 0.6732106714138691, 0.9654260599054645], 
             UndirectedEdge[43, 250] -> 
             RGBColor[
              0.3960777590456892, 0.5174843802635383, 0.946458702461949], 
             UndirectedEdge[112, 177] -> 
             RGBColor[
              0.3342624596446624, 0.4574870207323496, 0.9427562740122359], 
             UndirectedEdge[255, 356] -> 
             RGBColor[
              0.4121805793610603, 0.5314318338694306, 0.9474847599332795], 
             UndirectedEdge[210, 328] -> 
             RGBColor[
              0.5046106682424809, 0.6062794723978455, 0.9548254692977902], 
             UndirectedEdge[91, 221] -> 
             RGBColor[
              0.4550473015500987, 0.5657342702556508, 0.9509971775735427], 
             UndirectedEdge[32, 345] -> 
             RGBColor[
              0.2627139552530162, 0.3934594023707127, 0.9382725431499669], 
             UndirectedEdge[210, 258] -> 
             RGBColor[
              0.45173952615262003`, 0.5559125401089146, 0.9516239923954006], 
             UndirectedEdge[189, 359] -> 
             RGBColor[
              0.2785958202739832, 0.4069711767167502, 0.9392934665243888], 
             UndirectedEdge[164, 258] -> 
             RGBColor[
              0.3374569574911687, 0.4621373819326065, 0.9428908623426956], 
             UndirectedEdge[354, 374] -> 
             RGBColor[
              0.4058727397282144, 0.5254864023542891, 0.9472159797859825], 
             UndirectedEdge[235, 322] -> 
             RGBColor[
              0.46724893919510674`, 0.5776051703030205, 0.9514147829952669], 
             UndirectedEdge[147, 392] -> 
             RGBColor[
              0.5944125913904158, 0.6812988260050887, 0.9614261971988912], 
             UndirectedEdge[123, 283] -> 
             RGBColor[
              0.4881041475499924, 0.5921380033017336, 0.9537192566936576], 
             UndirectedEdge[202, 239] -> 
             RGBColor[
              0.31698161640257116`, 0.44117921182137954`, 0.9417042183306334],
              UndirectedEdge[180, 249] -> 
             RGBColor[
              0.4505813464286854, 0.5642028232935947, 0.950066962942272], 
             UndirectedEdge[2, 197] -> 
             RGBColor[
              0.44418462076302545`, 0.5589846984469196, 0.9495702898725955], 
             UndirectedEdge[174, 329] -> 
             RGBColor[
              0.2960659655495186, 0.42269790429061116`, 0.9403848641202421], 
             UndirectedEdge[193, 242] -> 
             RGBColor[
              0.40351340522649326`, 0.5184439093317198, 0.9476575910149361], 
             UndirectedEdge[58, 160] -> 
             RGBColor[
              0.6064584118464593, 0.6848270019072276, 0.9654887164744206], 
             UndirectedEdge[50, 137] -> 
             RGBColor[
              0.40562233975996953`, 0.5257514163536725, 0.9470668747051216], 
             UndirectedEdge[326, 383] -> 
             RGBColor[
              0.3107674940685786, 0.4424883316156812, 0.9410632520802292], 
             UndirectedEdge[157, 238] -> 
             RGBColor[
              0.43436621486965443`, 0.5506479162645117, 0.9488984090099], 
             UndirectedEdge[243, 346] -> 
             RGBColor[
              0.5220217697658582, 0.6146333753552872, 0.9580249705181207], 
             UndirectedEdge[235, 355] -> 
             RGBColor[
              0.4989839081167382, 0.6041366414348848, 0.9537009875666829], 
             UndirectedEdge[44, 135] -> 
             RGBColor[
              0.47922511283069624`, 0.5845694808492404, 0.9531197693568945], 
             UndirectedEdge[33, 206] -> 
             RGBColor[
              0.40287398135486485`, 0.5233709264396809, 0.9468917517378261], 
             UndirectedEdge[88, 263] -> 
             RGBColor[
              0.4067336692811977, 0.5267139941279145, 0.9471376876395041], 
             UndirectedEdge[82, 399] -> 
             RGBColor[
              0.3485567845367482, 0.4763241006175203, 0.943430707987387], 
             UndirectedEdge[271, 287] -> 
             RGBColor[
              0.3943910509581726, 0.5160234384945448, 0.9463512269141099], 
             UndirectedEdge[31, 223] -> 
             RGBColor[
              0.3573940887048945, 0.48159341621891594`, 0.9440811438685686], 
             UndirectedEdge[108, 376] -> 
             RGBColor[
              0.2143778022282936, 0.3426550408526195, 0.9355198707421393], 
             UndirectedEdge[301, 361] -> 
             RGBColor[
              0.483431447495499, 0.5903719675156307, 0.9527912079026979], 
             UndirectedEdge[80, 388] -> 
             RGBColor[
              0.3391487966795358, 0.4609754884968501, 0.9430948624125202], 
             UndirectedEdge[47, 136] -> 
             RGBColor[
              0.26044780840090453`, 0.39020203182779256`, 0.9381755460216508],
              UndirectedEdge[39, 50] -> 
             RGBColor[
              0.3446081328553494, 0.47141208821304803`, 0.9432337287504492], 
             UndirectedEdge[120, 389] -> 
             RGBColor[
              0.3118869386387272, 0.433431376968511, 0.9415017036227324], 
             UndirectedEdge[28, 106] -> 
             RGBColor[
              0.3412390050618873, 0.4699858078386865, 0.9429644255501073], 
             UndirectedEdge[97, 326] -> 
             RGBColor[
              0.2893272029389158, 0.4214316130659548, 0.9397881282349071], 
             UndirectedEdge[195, 242] -> 
             RGBColor[
              0.5493481375009555, 0.6450245917316701, 0.9576658441940595], 
             UndirectedEdge[90, 260] -> 
             RGBColor[
              0.915420334559923, 0.9344484818986477, 0.9589665469121118], 
             UndirectedEdge[73, 368] -> 
             RGBColor[
              0.3748112801644788, 0.49848001517842966`, 0.9451250193443776], 
             UndirectedEdge[52, 287] -> 
             RGBColor[
              0.33555822249709777`, 0.4592482095844325, 0.9428154469276171], 
             UndirectedEdge[135, 243] -> 
             RGBColor[
              0.30551244102506947`, 0.43708336173255746`, 0.9407596484987798],
              UndirectedEdge[311, 317] -> 
             RGBColor[
              0.22647306937038708`, 0.3553679335031896, 0.9362086783125373], 
             UndirectedEdge[6, 10] -> 
             RGBColor[
              0.513756545074144, 0.5948687890880178, 0.9592908705275116], 
             UndirectedEdge[363, 383] -> 
             RGBColor[
              0.28343937508639216`, 0.41376474586258355`, 0.9395069561325228],
              UndirectedEdge[227, 346] -> 
             RGBColor[
              0.5704309180390463, 0.6585208384817418, 0.9610378706222209], 
             UndirectedEdge[157, 341] -> 
             RGBColor[
              0.434507612507136, 0.5507703877912464, 0.9489074187423273], 
             UndirectedEdge[18, 310] -> 
             RGBColor[
              0.3397803550201755, 0.462970580385758, 0.9430820838959263], 
             UndirectedEdge[37, 96] -> 
             RGBColor[
              0.5370019106998425, 0.633623281586987, 0.9571907022439181], 
             UndirectedEdge[218, 222] -> 
             RGBColor[
              0.31195343455507263`, 0.4393544416499816, 0.9412911771213686], 
             UndirectedEdge[65, 203] -> 
             RGBColor[
              0.33261824571467014`, 0.46209624319203163`, 0.9424305953657605],
              UndirectedEdge[105, 303] -> 
             RGBColor[
              0.4467795465868474, 0.5587241622089812, 0.950428640198683], 
             UndirectedEdge[119, 267] -> 
             RGBColor[
              0.3747082062858538, 0.4848774778856142, 0.9463166848522332], 
             UndirectedEdge[20, 312] -> 
             RGBColor[
              0.22684420294319674`, 0.3557580184194402, 0.9362298138204659], 
             UndirectedEdge[285, 324] -> 
             RGBColor[
              0.29159155852494356`, 0.4223682102831413, 0.9399699292971911], 
             UndirectedEdge[16, 302] -> 
             RGBColor[
              0.48798726272465776`, 0.5952090693123644, 0.9528352913593789], 
             UndirectedEdge[65, 313] -> 
             RGBColor[
              0.3433925002981691, 0.4714283609824774, 0.9431171213405218], 
             UndirectedEdge[280, 392] -> 
             RGBColor[
              0.49219758746924136`, 0.5947430612036149, 0.9543666937043129], 
             UndirectedEdge[1, 357] -> 
             RGBColor[
              0.3449873106676061, 0.4663083099015368, 0.9434708782533952], 
             UndirectedEdge[26, 177] -> 
             RGBColor[
              0.38013505316052165`, 0.4953722764573791, 0.9461896438419728], 
             UndirectedEdge[69, 293] -> 
             RGBColor[
              0.273357666716035, 0.40461749770785027`, 0.9388797530072219], 
             UndirectedEdge[165, 399] -> 
             RGBColor[
              0.3463305206600037, 0.47439582274276015`, 0.9432888524217687], 
             UndirectedEdge[108, 297] -> 
             RGBColor[
              0.22295252582755387`, 0.35166761902431903`, 0.9360081885659504],
              UndirectedEdge[192, 335] -> 
             RGBColor[
              0.42028993433218964`, 0.538300782361453, 0.9480442987591815], 
             UndirectedEdge[134, 272] -> 
             RGBColor[
              0.40583318477072716`, 0.5259340397046124, 0.9470803095627641], 
             UndirectedEdge[86, 236] -> 
             RGBColor[
              0.28263190345518296`, 0.4114272169331239, 0.9395154849958843], 
             UndirectedEdge[312, 389] -> 
             RGBColor[
              0.18595383630052237`, 0.3127796504790029, 0.933901167932042], 
             UndirectedEdge[156, 245] -> 
             RGBColor[
              0.28322506887338894`, 0.41315447975773867`, 0.9395088490576984],
              UndirectedEdge[153, 168] -> 
             RGBColor[
              0.3561206349329622, 0.482875527660546, 0.9439126698461835], 
             UndirectedEdge[118, 150] -> 
             RGBColor[
              0.3119904924004529, 0.43468220373931077`, 0.9414657871838876], 
             UndirectedEdge[195, 255] -> 
             RGBColor[
              0.4836761949517891, 0.5903307612469275, 0.9528767613099055], 
             UndirectedEdge[109, 180] -> 
             RGBColor[
              0.4014941522776533, 0.5216859629140855, 0.9469391703370696], 
             UndirectedEdge[143, 378] -> 
             RGBColor[
              0.5359527982888288, 0.630978765340807, 0.9578585383255203], 
             UndirectedEdge[135, 383] -> 
             RGBColor[
              0.3240955934653456, 0.4551370463666826, 0.9418720625224992], 
             UndirectedEdge[20, 120] -> 
             RGBColor[
              0.3527773052814015, 0.4764097449089483, 0.9438303495111562], 
             UndirectedEdge[149, 230] -> 
             RGBColor[
              0.2798816491873227, 0.41140288827661575`, 0.9392539104949502], 
             UndirectedEdge[16, 77] -> 
             RGBColor[
              0.4346960985679835, 0.5503295147481333, 0.9490863518804583], 
             UndirectedEdge[168, 238] -> 
             RGBColor[
              0.38508981384023544`, 0.5079671743967582, 0.9457585603097158], 
             UndirectedEdge[104, 335] -> 
             RGBColor[
              0.4133102621313318, 0.5324103083055328, 0.9475567423204619], 
             UndirectedEdge[79, 232] -> 
             RGBColor[
              0.32074795675627854`, 0.45120021629436985`, 0.9416967338056501],
              UndirectedEdge[47, 299] -> 
             RGBColor[
              0.3817267019916116, 0.5050542159483966, 0.9455442657966047], 
             UndirectedEdge[236, 397] -> 
             RGBColor[
              0.2725359751718354, 0.4026826312901981, 0.9388721813731482], 
             UndirectedEdge[33, 118] -> 
             RGBColor[
              0.32554133574381455`, 0.4464192631581408, 0.9423292349391863], 
             UndirectedEdge[51, 79] -> 
             RGBColor[
              0.42383070646016446`, 0.5378565197505502, 0.9489914188711132], 
             UndirectedEdge[24, 168] -> 
             RGBColor[
              0.31361299406557774`, 0.4435298158063208, 0.94129667312965], 
             UndirectedEdge[269, 365] -> 
             RGBColor[
              0.5677187755888864, 0.6372200210866386, 0.951617290431752], 
             UndirectedEdge[98, 240] -> 
             RGBColor[
              0.3239307254741068, 0.4540175729910694, 0.9418973180630624], 
             UndirectedEdge[29, 113] -> 
             RGBColor[
              0.6633590215484534, 0.734190376025204, 0.9690780390814628], 
             UndirectedEdge[330, 398] -> 
             RGBColor[
              0.3076603216891092, 0.43245366422467146`, 0.9411341433151696], 
             UndirectedEdge[43, 265] -> 
             RGBColor[
              0.33516551896762126`, 0.4637000364622035, 0.9426149668223736], 
             UndirectedEdge[209, 304] -> 
             RGBColor[
              0.38387306339256977`, 0.4912314594901872, 0.9471370725287542], 
             UndirectedEdge[107, 238] -> 
             RGBColor[
              0.4829792422301784, 0.5903570570249046, 0.9526582919434678], 
             UndirectedEdge[298, 347] -> 
             RGBColor[
              0.3474403607415021, 0.4629473268072002, 0.9441512073304144], 
             UndirectedEdge[153, 343] -> 
             RGBColor[
              0.29060038345874717`, 0.4174372926791142, 0.940055883435565], 
             UndirectedEdge[110, 292] -> 
             RGBColor[
              0.2563176930625193, 0.3867365252620544, 0.93790828548064], 
             UndirectedEdge[332, 366] -> 
             RGBColor[
              0.47431376319766405`, 0.5787022208557775, 0.9530579459771436], 
             UndirectedEdge[39, 136] -> 
             RGBColor[
              0.24764510233367043`, 0.37762108253202276`, 0.9374143942685803],
              UndirectedEdge[115, 380] -> 
             RGBColor[
              0.23687132872832026`, 0.36629716337609936`, 0.9368008438001254],
              UndirectedEdge[167, 238] -> 
             RGBColor[
              0.417047603696836, 0.5356474057253238, 0.9477948824202145], 
             UndirectedEdge[1, 162] -> 
             RGBColor[
              0.4289018027642887, 0.5458561363229919, 0.9485664628196736], 
             UndirectedEdge[128, 243] -> 
             RGBColor[
              0.35823396104735805`, 0.48274809251521933`, 0.9441190171347904],
              UndirectedEdge[196, 366] -> 
             RGBColor[
              0.5769966265208603, 0.667336425267016, 0.959934362421621], 
             UndirectedEdge[136, 149] -> 
             RGBColor[
              0.22630339658025977`, 0.35518959664288957`, 0.9361990156981479],
              UndirectedEdge[263, 360] -> 
             RGBColor[
              0.37845364363574846`, 0.5022192573092442, 0.9453357094124208], 
             UndirectedEdge[267, 354] -> 
             RGBColor[
              0.4510427639766694, 0.5621574629255879, 0.9507719295580717], 
             UndirectedEdge[192, 355] -> 
             RGBColor[
              0.47377168673434356`, 0.583668224319027, 0.9517161891440508], 
             UndirectedEdge[24, 100] -> 
             RGBColor[
              0.3124769339236607, 0.4425458176114353, 0.9412242843819856], 
             UndirectedEdge[11, 286] -> 
             RGBColor[
              0.562490188546078, 0.6512339991533717, 0.9607049934682854], 
             UndirectedEdge[71, 110] -> 
             RGBColor[
              0.2644077580520465, 0.39523969650579377`, 0.938369002713615], 
             UndirectedEdge[186, 306] -> 
             RGBColor[
              0.393132674679081, 0.5149334962094263, 0.9462710442903446], 
             UndirectedEdge[6, 131] -> 
             RGBColor[
              0.5915548623948053, 0.6734400554640989, 0.9638385262181492], 
             UndirectedEdge[53, 264] -> 
             RGBColor[
              0.28298114815852826`, 0.4130062716100371, 0.9394909975738811], 
             UndirectedEdge[83, 118] -> 
             RGBColor[
              0.22208993256753545`, 0.3507609788164681, 0.9359590651558847], 
             UndirectedEdge[98, 272] -> 
             RGBColor[
              0.3464673027673044, 0.4735376235211271, 0.9433333288398722], 
             UndirectedEdge[200, 330] -> 
             RGBColor[
              0.26376460039457356`, 0.3944333967024469, 0.9383371467697441], 
             UndirectedEdge[101, 389] -> 
             RGBColor[
              0.3392283311468225, 0.4561143026752156, 0.9435198483338205], 
             UndirectedEdge[10, 353] -> 
             RGBColor[
              0.2181240555371064, 0.34659259060636033`, 0.9357332143259911], 
             UndirectedEdge[174, 340] -> 
             RGBColor[
              0.3545768790828816, 0.4815384039346313, 0.9438143030885062], 
             UndirectedEdge[77, 187] -> 
             RGBColor[
              0.3144362813998432, 0.4399567536613147, 0.9415060693008517], 
             UndirectedEdge[137, 264] -> 
             RGBColor[
              0.3264351368959353, 0.4506439325934008, 0.9422598473113752], 
             UndirectedEdge[20, 356] -> 
             RGBColor[
              0.3459710008225968, 0.4705144660815406, 0.94339665780962], 
             UndirectedEdge[130, 227] -> 
             RGBColor[
              0.3223842171593221, 0.44918300992141696`, 0.9419267470161483], 
             UndirectedEdge[24, 150] -> 
             RGBColor[
              0.3522378298214901, 0.47698470719739994`, 0.9437578135094156], 
             UndirectedEdge[282, 339] -> 
             RGBColor[
              0.2740559762286417, 0.4053805855417597, 0.9389184544655124], 
             UndirectedEdge[69, 93] -> 
             RGBColor[
              0.24552723133114446`, 0.3753659455668112, 0.9372948508834921], 
             UndirectedEdge[65, 266] -> 
             RGBColor[
              0.3075771517778624, 0.4404069062259455, 0.940834999003077], 
             UndirectedEdge[189, 336] -> 
             RGBColor[
              0.1982846156980648, 0.32574008144238936`, 0.9346033875769787], 
             UndirectedEdge[191, 322] -> 
             RGBColor[
              0.41015641996252894`, 0.5296786087356323, 0.947355782286299], 
             UndirectedEdge[297, 376] -> 
             RGBColor[
              0.22283193390984793`, 0.3515408692728409, 0.9360013210346367], 
             UndirectedEdge[33, 286] -> 
             RGBColor[
              0.40452394456899504`, 0.524800041646198, 0.9469968859348254], 
             UndirectedEdge[145, 351] -> 
             RGBColor[
              0.6050021078038151, 0.681656566290328, 0.9658683474153025], 
             UndirectedEdge[83, 141] -> 
             RGBColor[
              0.33324041791457215`, 0.45700395514327247`, 0.9426764247985602],
              UndirectedEdge[148, 276] -> 
             RGBColor[
              0.327258183538749, 0.45708409205342504`, 0.9421025874187066], 
             UndirectedEdge[124, 160] -> 
             RGBColor[
              0.7190016262803101, 0.7795726622578643, 0.97341517666145], 
             UndirectedEdge[25, 362] -> 
             RGBColor[
              0.42398414661411554`, 0.5350606836439619, 0.9492693317365385], 
             UndirectedEdge[96, 208] -> 
             RGBColor[
              0.505874575696935, 0.6066623485128158, 0.9552072959823543], 
             UndirectedEdge[240, 272] -> 
             RGBColor[
              0.37221558510408403`, 0.4968161645430547, 0.9449382258388819], 
             UndirectedEdge[25, 182] -> 
             RGBColor[
              0.49558305727551133`, 0.6003707845253001, 0.9537109150579773], 
             UndirectedEdge[101, 380] -> 
             RGBColor[
              0.3821934560236825, 0.5012733730670519, 0.9459666486343514], 
             UndirectedEdge[24, 358] -> 
             RGBColor[
              0.339456115534133, 0.46591382870933074`, 0.9429433739774513], 
             UndirectedEdge[202, 234] -> 
             RGBColor[
              0.4444009111365761, 0.5454753680414677, 0.9516372901835307], 
             UndirectedEdge[17, 62] -> 
             RGBColor[
              0.26553793532628944`, 0.39642758447840104`, 0.9384333646374357],
              UndirectedEdge[24, 211] -> 
             RGBColor[
              0.45907049423148255`, 0.5645376020194061, 0.9519411376211941], 
             UndirectedEdge[2, 39] -> 
             RGBColor[
              0.36074747851419275`, 0.48539117823563904`, 0.9442621135843676],
              UndirectedEdge[164, 328] -> 
             RGBColor[
              0.39032809958102965`, 0.5125043142215374, 0.9460923392450851], 
             UndirectedEdge[228, 301] -> 
             RGBColor[
              0.32589852419997145`, 0.45038039522960405`, 0.9422182860918352],
              UndirectedEdge[118, 286] -> 
             RGBColor[
              0.27989436630582454`, 0.406882152514347, 0.9394206504106277], 
             UndirectedEdge[139, 215] -> 
             RGBColor[
              0.6300313668907994, 0.7089184490174669, 0.9651172112020414], 
             UndirectedEdge[239, 377] -> 
             RGBColor[
              0.3922194632505078, 0.5141425183693373, 0.946212855265637], 
             UndirectedEdge[348, 374] -> 
             RGBColor[
              0.36896456857696713`, 0.4896460493446887, 0.9450060094674604], 
             UndirectedEdge[8, 388] -> 
             RGBColor[
              0.37456131252712876`, 0.49819628793585646`, 0.945111552801918], 
             UndirectedEdge[249, 370] -> 
             RGBColor[
              0.4255276131019811, 0.5429923636543948, 0.9483352211209325], 
             UndirectedEdge[61, 285] -> 
             RGBColor[
              0.3325960865537333, 0.45788427151417543`, 0.9425827015643051], 
             UndirectedEdge[162, 280] -> 
             RGBColor[
              0.3620235870262692, 0.48798836807276963`, 0.9442888007337935], 
             UndirectedEdge[126, 205] -> 
             RGBColor[
              0.21751415562183513`, 0.3459515471255221, 0.9356984814280824], 
             UndirectedEdge[161, 334] -> 
             RGBColor[
              0.3614131624756377, 0.4874596490078426, 0.9442499050212045], 
             UndirectedEdge[192, 399] -> 
             RGBColor[
              0.4021714167277014, 0.5226074330756187, 0.9468898028389996], 
             UndirectedEdge[69, 281] -> 
             RGBColor[
              0.40754175827219896`, 0.5259828679354831, 0.9475845823589008], 
             UndirectedEdge[38, 128] -> 
             RGBColor[
              0.4267407191415568, 0.544043095133393, 0.9484125191650667], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.35530783404913385`, 0.4747535081067294, 0.9442772914673749], 
             UndirectedEdge[145, 355] -> 
             RGBColor[
              0.7000750051512259, 0.7640072910854581, 0.9721552705681124], 
             UndirectedEdge[23, 139] -> 
             RGBColor[
              0.7073946017769706, 0.7713413063970499, 0.9714701409928754], 
             UndirectedEdge[120, 359] -> 
             RGBColor[
              0.38928640482763766`, 0.5116020505832499, 0.9460259633765334], 
             UndirectedEdge[117, 309] -> 
             RGBColor[
              0.32222442839372717`, 0.4523851187726147, 0.9417942529878459], 
             UndirectedEdge[19, 167] -> 
             RGBColor[
              0.38930656324325286`, 0.5116195107896644, 0.9460272478529511], 
             UndirectedEdge[26, 285] -> 
             RGBColor[
              0.3900887761458573, 0.5058342704174549, 0.9467564936407742], 
             UndirectedEdge[166, 169] -> 
             RGBColor[
              0.5479436684220391, 0.6216100112662626, 0.9626302425943184], 
             UndirectedEdge[31, 383] -> 
             RGBColor[
              0.3782876225125379, 0.5020754581567834, 0.9453251306932566], 
             UndirectedEdge[146, 346] -> 
             RGBColor[
              0.7142290186454308, 0.776680404798183, 0.9721513317950665], 
             UndirectedEdge[191, 349] -> 
             RGBColor[
              0.3842433342070891, 0.5072339962838303, 0.9457046233760044], 
             UndirectedEdge[212, 362] -> 
             RGBColor[
              0.24472484301308356`, 0.374551704830951, 0.9372480898204094], 
             UndirectedEdge[242, 380] -> 
             RGBColor[
              0.4040901124420234, 0.5190500651805914, 0.9476904336376986], 
             UndirectedEdge[175, 307] -> 
             RGBColor[
              0.3419501324979599, 0.47060175068150845`, 0.9430097379615086], 
             UndirectedEdge[140, 193] -> 
             RGBColor[
              0.30796111566066986`, 0.43786922409105755`, 0.940964558841034], 
             UndirectedEdge[8, 25] -> 
             RGBColor[
              0.43827781890278816`, 0.5500842394905237, 0.9500833352277852], 
             UndirectedEdge[8, 269] -> 
             RGBColor[
              0.24352257547692074`, 0.37328804542227934`, 0.9371796224628204],
              UndirectedEdge[155, 371] -> 
             RGBColor[
              0.2043166800642964, 0.3320801635462691, 0.934946904718996], 
             UndirectedEdge[55, 161] -> 
             RGBColor[
              0.27918780295361556`, 0.40851848694716947`, 0.9392933066597867],
              UndirectedEdge[110, 202] -> 
             RGBColor[
              0.23645806560269045`, 0.3658627976286669, 0.9367773090764888], 
             UndirectedEdge[332, 380] -> 
             RGBColor[
              0.28588734152790807`, 0.4178161006231753, 0.9395922332163691], 
             UndirectedEdge[359, 360] -> 
             RGBColor[
              0.3464457966393335, 0.4744956690021165, 0.9432961977052371], 
             UndirectedEdge[128, 350] -> 
             RGBColor[
              0.3272811764672604, 0.45021475340164463`, 0.9423563018434952], 
             UndirectedEdge[272, 378] -> 
             RGBColor[
              0.38241811439886414`, 0.5056530826241608, 0.9455883219838028], 
             UndirectedEdge[52, 345] -> 
             RGBColor[
              0.23383077670081756`, 0.3631013504130609, 0.9366276888602527], 
             UndirectedEdge[32, 333] -> 
             RGBColor[
              0.3274730783318943, 0.45758615848619655`, 0.9421047123835826], 
             UndirectedEdge[85, 168] -> 
             RGBColor[
              0.3831615260262361, 0.5062969884108355, 0.9456356915153259], 
             UndirectedEdge[23, 354] -> 
             RGBColor[
              0.5040562812210712, 0.6048121225813033, 0.9552079603801908], 
             UndirectedEdge[51, 373] -> 
             RGBColor[
              0.42990043139185075`, 0.5441510858251636, 0.9493401966424595], 
             UndirectedEdge[55, 334] -> 
             RGBColor[
              0.30745467183668396`, 0.43300182803954357`, 0.9410944465496052],
              UndirectedEdge[66, 267] -> 
             RGBColor[
              0.6531687144846114, 0.7277395340455166, 0.9669132724546181], 
             UndirectedEdge[30, 153] -> 
             RGBColor[
              0.4904487500906186, 0.5948479777508542, 0.9536809883815976], 
             UndirectedEdge[179, 290] -> 
             RGBColor[
              0.39649207611076887`, 0.5029775943482975, 0.9479938159484631], 
             UndirectedEdge[178, 200] -> 
             RGBColor[
              0.29249305778130297`, 0.4246288269053021, 0.9399731899179744], 
             UndirectedEdge[340, 358] -> 
             RGBColor[
              0.36750115002802525`, 0.49273275783456927`, 0.9446378262046466],
              UndirectedEdge[31, 259] -> 
             RGBColor[
              0.40260661402702547`, 0.5231393462985789, 0.94687471532812], 
             UndirectedEdge[92, 146] -> 
             RGBColor[
              0.48708155860540725`, 0.5893090034487863, 0.9542303890371588], 
             UndirectedEdge[3, 373] -> 
             RGBColor[
              0.4140795332537155, 0.5313069679932865, 0.9480947175871661], 
             UndirectedEdge[174, 341] -> 
             RGBColor[
              0.3981500620011286, 0.5192793049265648, 0.946590747773804], 
             UndirectedEdge[248, 260] -> 
             RGBColor[
              0.6768736275624003, 0.7418300181795239, 0.9385468470410454], 
             UndirectedEdge[41, 325] -> 
             RGBColor[
              0.35094268680647445`, 0.4756441606521714, 0.9436832979716201], 
             UndirectedEdge[66, 346] -> 
             RGBColor[
              0.7507026370618555, 0.8051738727148611, 0.9757866812134728], 
             UndirectedEdge[53, 142] -> 
             RGBColor[
              0.6156001870492223, 0.6920758906039949, 0.9663793182974425], 
             UndirectedEdge[38, 44] -> 
             RGBColor[
              0.5297891473849515, 0.6283655061578645, 0.9563416649266715], 
             UndirectedEdge[76, 187] -> 
             RGBColor[
              0.2871599169154237, 0.41633133769485164`, 0.9397680434754465], 
             UndirectedEdge[156, 160] -> 
             RGBColor[
              0.6064543022378537, 0.6848234423708082, 0.9654884546137943], 
             UndirectedEdge[141, 290] -> 
             RGBColor[
              0.5123584491713113, 0.6141772676665471, 0.9549797384198921], 
             UndirectedEdge[3, 79] -> 
             RGBColor[
              0.4080098083220292, 0.525012401918673, 0.9477459398158197], 
             UndirectedEdge[301, 382] -> 
             RGBColor[
              0.32861409354424886`, 0.4532346307874805, 0.942372933748667], 
             UndirectedEdge[193, 389] -> 
             RGBColor[
              0.23074151749618907`, 0.35985434311864983`, 0.9364517601186986],
              UndirectedEdge[189, 291] -> 
             RGBColor[
              0.5768025261341343, 0.6483740825914175, 0.9613423650258945], 
             UndirectedEdge[161, 196] -> 
             RGBColor[
              0.41800167685309925`, 0.5351286743124692, 0.9482273307055438], 
             UndirectedEdge[83, 161] -> 
             RGBColor[
              0.288207200623498, 0.41799844576105744`, 0.9398069480140834], 
             UndirectedEdge[100, 211] -> 
             RGBColor[
              0.4901409958324249, 0.5939770386883731, 0.953828369937135], 
             UndirectedEdge[32, 287] -> 
             RGBColor[
              0.3644414010492964, 0.4896062615420843, 0.9444603012173313], 
             UndirectedEdge[156, 181] -> 
             RGBColor[
              0.3531242669715161, 0.4802802243341741, 0.9437217439292644], 
             UndirectedEdge[126, 176] -> 
             RGBColor[
              0.3855469364152011, 0.4977223908274119, 0.9468016988557721], 
             UndirectedEdge[46, 350] -> 
             RGBColor[
              0.26369563892975745`, 0.3944912141573078, 0.9383284485830865], 
             UndirectedEdge[47, 149] -> 
             RGBColor[
              0.2840709426346593, 0.4150314437006878, 0.9395208485689678], 
             UndirectedEdge[57, 108] -> 
             RGBColor[
              0.21332451008604897`, 0.3415479640285414, 0.9354598873128446], 
             UndirectedEdge[105, 400] -> 
             RGBColor[
              0.30835368006566827`, 0.4383826077296517, 0.940983224989508], 
             UndirectedEdge[62, 256] -> 
             RGBColor[
              0.34295106924995805`, 0.4703442612181544, 0.9431146884098549], 
             UndirectedEdge[193, 332] -> 
             RGBColor[
              0.2853106343123779, 0.41720994477430373`, 0.9395593905936066], 
             UndirectedEdge[1, 387] -> 
             RGBColor[
              0.4619304719803222, 0.5740549927410667, 0.9507840053428154], 
             UndirectedEdge[72, 284] -> 
             RGBColor[
              0.2477290173310806, 0.377709282514819, 0.9374191731035417], 
             UndirectedEdge[127, 394] -> 
             RGBColor[
              0.5975159050691821, 0.665700208652706, 0.9370448493454887], 
             UndirectedEdge[110, 385] -> 
             RGBColor[
              0.5056557407647895, 0.5965753358446335, 0.9572285150834253], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.4502438641829234, 0.5643415572406167, 0.9499263601012251], 
             UndirectedEdge[97, 393] -> 
             RGBColor[
              0.4080725247402592, 0.5231888584055931, 0.9479215020468938], 
             UndirectedEdge[19, 150] -> 
             RGBColor[
              0.39597360914256463`, 0.517394170852178, 0.946452066122218], 
             UndirectedEdge[272, 342] -> 
             RGBColor[
              0.521499427205843, 0.6207353624114409, 0.9559745333660385], 
             UndirectedEdge[96, 187] -> 
             RGBColor[
              0.4479993590069344, 0.5497198626235376, 0.9517690279536841], 
             UndirectedEdge[129, 333] -> 
             RGBColor[
              0.3682181187199217, 0.4933537600795958, 0.9446835108157037], 
             UndirectedEdge[19, 160] -> 
             RGBColor[
              0.6264431435713089, 0.7021367720654699, 0.9667621259081236], 
             UndirectedEdge[183, 357] -> 
             RGBColor[
              0.29824173912526314`, 0.42587842615749005`, 0.9404760504530654],
              UndirectedEdge[197, 217] -> 
             RGBColor[
              0.33502870252126793`, 0.4553625802568303, 0.9429473154981596], 
             UndirectedEdge[199, 345] -> 
             RGBColor[
              0.2046269335439348, 0.3324062596245758, 0.9349645731956826], 
             UndirectedEdge[44, 346] -> 
             RGBColor[
              0.695734441571485, 0.7621194944719702, 0.9703850913762355], 
             UndirectedEdge[78, 80] -> 
             RGBColor[
              0.3159056185662029, 0.4408434158511811, 0.941613827656274], 
             UndirectedEdge[42, 320] -> 
             RGBColor[
              0.611037606865133, 0.6804793829991729, 0.9410648125779792], 
             UndirectedEdge[161, 332] -> 
             RGBColor[
              0.3153188135299031, 0.4464944699012307, 0.9413509142610661], 
             UndirectedEdge[239, 309] -> 
             RGBColor[
              0.35302463524295474`, 0.47906270988200744`, 0.9437568149327251],
              UndirectedEdge[8, 377] -> 
             RGBColor[
              0.3382993217582222, 0.46678797411247946`, 0.9428009708153428], 
             UndirectedEdge[75, 126] -> 
             RGBColor[
              0.5806994496171142, 0.6524699962512487, 0.9615642890532686], 
             UndirectedEdge[54, 310] -> 
             RGBColor[
              0.23929811012085286`, 0.3688478644864783, 0.9369390454103288], 
             UndirectedEdge[65, 211] -> 
             RGBColor[
              0.4704543670111624, 0.5765027740900719, 0.9525894323350663], 
             UndirectedEdge[88, 356] -> 
             RGBColor[
              0.41405389044093555`, 0.533054401771466, 0.9476041256587853], 
             UndirectedEdge[98, 158] -> 
             RGBColor[
              0.369887526838806, 0.4938230444771732, 0.9448256448080172], 
             UndirectedEdge[13, 390] -> 
             RGBColor[
              0.5184484765079229, 0.6137990472540551, 0.9573589715638275], 
             UndirectedEdge[241, 242] -> 
             RGBColor[
              0.4338025168542142, 0.5479717639922849, 0.9494670154471545], 
             UndirectedEdge[12, 238] -> 
             RGBColor[
              0.30672978850451715`, 0.4290335229982041, 0.9411705677724279], 
             UndirectedEdge[175, 343] -> 
             RGBColor[
              0.2768508385336821, 0.4055281279372446, 0.939179774591185], 
             UndirectedEdge[59, 258] -> 
             RGBColor[
              0.301541549394709, 0.43102926060035146`, 0.9406023642975375], 
             UndirectedEdge[152, 156] -> 
             RGBColor[
              0.2925776892969639, 0.4229846768133004, 0.940041466954859], 
             UndirectedEdge[39, 258] -> 
             RGBColor[
              0.27594963976041464`, 0.4073709459788556, 0.9390262958022226], 
             UndirectedEdge[183, 368] -> 
             RGBColor[
              0.33220840711386657`, 0.46157954782464944`, 0.9424104019458341],
              UndirectedEdge[44, 119] -> 
             RGBColor[
              0.4115027483879924, 0.5147489447393624, 0.9492132859893623], 
             UndirectedEdge[149, 264] -> 
             RGBColor[
              0.2440792242379045, 0.3738731185636432, 0.9372113227862704], 
             UndirectedEdge[120, 241] -> 
             RGBColor[
              0.384564467927778, 0.5075121461720408, 0.9457250857327193], 
             UndirectedEdge[116, 304] -> 
             RGBColor[
              0.2246453121661772, 0.353446844795065, 0.936104590243682], 
             UndirectedEdge[82, 256] -> 
             RGBColor[
              0.37055704748935114`, 0.49537962262169744`, 0.9448325452886582],
              UndirectedEdge[98, 186] -> 
             RGBColor[
              0.34288460456930303`, 0.4704344704136655, 0.9431050424787512], 
             UndirectedEdge[72, 262] -> 
             RGBColor[
              0.3116903460500654, 0.4358485115641588, 0.9413944390442679], 
             UndirectedEdge[147, 241] -> 
             RGBColor[
              0.4299322937181236, 0.5448297424988411, 0.949162337304787], 
             UndirectedEdge[13, 205] -> 
             RGBColor[
              0.25763488504734433`, 0.38812097755290087`, 0.9379832976155649],
              UndirectedEdge[142, 394] -> 
             RGBColor[
              0.5649072324471209, 0.6405496167168437, 0.9634281617557884], 
             UndirectedEdge[42, 75] -> 
             RGBColor[
              0.5983340884499241, 0.6710051197652123, 0.9625685556466869], 
             UndirectedEdge[56, 341] -> 
             RGBColor[
              0.4309088628759563, 0.5476533317391343, 0.9486781095980779], 
             UndirectedEdge[306, 378] -> 
             RGBColor[
              0.38438132487866483`, 0.5073535168679363, 0.9457134160195768], 
             UndirectedEdge[27, 295] -> 
             RGBColor[
              0.43575232339013514`, 0.5514309645559912, 0.9491020951924882], 
             UndirectedEdge[111, 247] -> 
             RGBColor[
              0.40468840963905967`, 0.523700040815049, 0.9473506587507796], 
             UndirectedEdge[128, 259] -> 
             RGBColor[
              0.4011361050021217, 0.52186566529114, 0.9467810157933731], 
             UndirectedEdge[52, 68] -> 
             RGBColor[
              0.32468254440688876`, 0.44982824385016823`, 0.9421224583366936],
              UndirectedEdge[241, 359] -> 
             RGBColor[
              0.33843009531282053`, 0.46755287139395385`, 0.9427854443047181],
              UndirectedEdge[361, 382] -> 
             RGBColor[
              0.40065709726926596`, 0.5128608724683471, 0.9477298558974591], 
             UndirectedEdge[14, 390] -> 
             RGBColor[
              0.5376979625587521, 0.6310887720312119, 0.9585629481827509], 
             UndirectedEdge[11, 332] -> 
             RGBColor[
              0.531797367714194, 0.623608849595666, 0.9587873744605251], 
             UndirectedEdge[22, 209] -> 
             RGBColor[
              0.4941353624204731, 0.5987377745101985, 0.9537234127789067], 
             UndirectedEdge[33, 156] -> 
             RGBColor[
              0.3895356111524708, 0.5118179005763464, 0.9460418425831874], 
             UndirectedEdge[283, 332] -> 
             RGBColor[
              0.4684907223156649, 0.5741092693440173, 0.9525076069762488], 
             UndirectedEdge[150, 181] -> 
             RGBColor[
              0.4002087264826687, 0.5210624166289894, 0.9467219240541622], 
             UndirectedEdge[117, 323] -> 
             RGBColor[
              0.3050170221984505, 0.43429904384881224`, 0.9408143166611012], 
             UndirectedEdge[199, 223] -> 
             RGBColor[
              0.23518468326850744`, 0.3645243920583374, 0.9367047918363574], 
             UndirectedEdge[128, 306] -> 
             RGBColor[
              0.4137883939832366, 0.5328244420840471, 0.94758720845927], 
             UndirectedEdge[184, 288] -> 
             RGBColor[
              0.29832278773822696`, 0.4250296592406914, 0.9405148626881115], 
             UndirectedEdge[145, 182] -> 
             RGBColor[
              0.6639702612247323, 0.7336909404756602, 0.9695906277974269], 
             UndirectedEdge[284, 397] -> 
             RGBColor[
              0.29988346334273375`, 0.4314265752887094, 0.9404295803674978], 
             UndirectedEdge[61, 148] -> 
             RGBColor[
              0.3532719183667592, 0.47961588167311797`, 0.9437601595989049], 
             UndirectedEdge[34, 159] -> 
             RGBColor[
              0.24513014030875357`, 0.3749776979860329, 0.9372711709018142], 
             UndirectedEdge[276, 382] -> 
             RGBColor[
              0.3000893836594307, 0.42852796077885635`, 0.940555364458217], 
             UndirectedEdge[59, 164] -> 
             RGBColor[
              0.3797091696858843, 0.5033067308692978, 0.9454157104221175], 
             UndirectedEdge[80, 377] -> 
             RGBColor[
              0.3028868059106292, 0.4295671746734731, 0.9407842804259448], 
             UndirectedEdge[180, 370] -> 
             RGBColor[
              0.4463041427757717, 0.5604981244679472, 0.9497944233076909], 
             UndirectedEdge[98, 374] -> 
             RGBColor[
              0.3846241857662598, 0.5061052998877109, 0.9458978015000631], 
             UndirectedEdge[139, 350] -> 
             RGBColor[
              0.486510170248983, 0.578538655364825, 0.9558078751584753], 
             UndirectedEdge[36, 276] -> 
             RGBColor[
              0.33110558695912007`, 0.46112795698770104`, 0.9423216913517733],
              UndirectedEdge[53, 281] -> 
             RGBColor[
              0.416876467292682, 0.5340681237129082, 0.9481793817633268], 
             UndirectedEdge[73, 183] -> 
             RGBColor[
              0.4045945826229027, 0.5248612247781209, 0.9470013869291576], 
             UndirectedEdge[101, 115] -> 
             RGBColor[
              0.3447814351634235, 0.4619509670837935, 0.9438360893924848], 
             UndirectedEdge[283, 366] -> 
             RGBColor[
              0.6453131520460922, 0.7227988583128018, 0.965312489562646], 
             UndirectedEdge[22, 141] -> 
             RGBColor[
              0.41133216311526205`, 0.5306969783599607, 0.9474306996003223], 
             UndirectedEdge[197, 314] -> 
             RGBColor[
              0.37148140344577685`, 0.49367668016321836`, 0.9450232428888719],
              UndirectedEdge[13, 14] -> 
             RGBColor[
              0.3213244002030937, 0.4521199905799143, 0.9417180681488819], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.337727936928675, 0.4669446970931135, 0.9427407033933746], 
             UndirectedEdge[323, 395] -> 
             RGBColor[
              0.29819151219748596`, 0.42838713014608437`, 0.9403794011994012],
              UndirectedEdge[93, 131] -> 
             RGBColor[
              0.2626734901717503, 0.39021717317851684`, 0.9383873953349742], 
             UndirectedEdge[52, 105] -> 
             RGBColor[
              0.2937652208651931, 0.42304921214821567`, 0.9401524338197325], 
             UndirectedEdge[178, 330] -> 
             RGBColor[
              0.24610234830464534`, 0.3759995502312623, 0.9373265367089274], 
             UndirectedEdge[92, 98] -> 
             RGBColor[
              0.30018067255193537`, 0.4328392977789574, 0.9404062172730991], 
             UndirectedEdge[37, 323] -> 
             RGBColor[
              0.3375746046711884, 0.46249878539502254`, 0.9428888570267242], 
             UndirectedEdge[279, 370] -> 
             RGBColor[
              0.4184374936157057, 0.5368512585151501, 0.9478834449768135], 
             UndirectedEdge[150, 160] -> 
             RGBColor[
              0.6535387617490062, 0.7256056346656234, 0.9684886347386922], 
             UndirectedEdge[188, 273] -> 
             RGBColor[
              0.4031678655028934, 0.519581222593861, 0.9475013284308785], 
             UndirectedEdge[179, 386] -> 
             RGBColor[
              0.27758110777715295`, 0.404006492163151, 0.9393051809889703], 
             UndirectedEdge[141, 179] -> 
             RGBColor[
              0.30734635511417496`, 0.4297876533616489, 0.9412017962289105], 
             UndirectedEdge[117, 388] -> 
             RGBColor[
              0.3976812471701869, 0.5188732410833217, 0.9465608753073331], 
             UndirectedEdge[198, 214] -> 
             RGBColor[
              0.39490726060865544`, 0.5164705533483416, 0.9463841193365723], 
             UndirectedEdge[150, 238] -> 
             RGBColor[
              0.42371464959614774`, 0.5414220657878372, 0.9482197006894815], 
             UndirectedEdge[331, 392] -> 
             RGBColor[
              0.5380738089220873, 0.6344787384201356, 0.9572898859685385], 
             UndirectedEdge[323, 365] -> 
             RGBColor[
              0.6060932876673579, 0.6775540663657063, 0.9538026621246178], 
             UndirectedEdge[6, 71] -> 
             RGBColor[
              0.5600402475890842, 0.6435158949874512, 0.9619266589151355], 
             UndirectedEdge[132, 249] -> 
             RGBColor[
              0.38936071840832975`, 0.5116664172717362, 0.9460306985721822], 
             UndirectedEdge[348, 378] -> 
             RGBColor[
              0.31847363757959424`, 0.4463952405291532, 0.9416556221753807], 
             UndirectedEdge[174, 198] -> 
             RGBColor[
              0.4039467110680804, 0.524300071000305, 0.9469601051265748], 
             UndirectedEdge[72, 236] -> 
             RGBColor[
              0.22038152916018228`, 0.34896533851630773`, 0.9358617741091922],
              UndirectedEdge[9, 100] -> 
             RGBColor[
              0.3331962391641343, 0.46301956825922075`, 0.942451947619041], 
             UndirectedEdge[51, 298] -> 
             RGBColor[
              0.5276365651212307, 0.62739815917862, 0.9559566296842175], 
             UndirectedEdge[23, 128] -> 
             RGBColor[
              0.5481656079952479, 0.6430174044338696, 0.9580185676778952], 
             UndirectedEdge[215, 353] -> 
             RGBColor[
              0.38059890451429557`, 0.4968938745944459, 0.9461219328306407], 
             UndirectedEdge[80, 96] -> 
             RGBColor[
              0.4459118777364536, 0.5475257874543051, 0.9516501489834819], 
             UndirectedEdge[78, 388] -> 
             RGBColor[
              0.4241813609057069, 0.541826307666585, 0.94824943912143], 
             UndirectedEdge[312, 380] -> 
             RGBColor[
              0.22891896117738242`, 0.3579387208708392, 0.936347968232573], 
             UndirectedEdge[57, 325] -> 
             RGBColor[
              0.24559549729162883`, 0.3754668176803717, 0.937297672293555], 
             UndirectedEdge[308, 374] -> 
             RGBColor[
              0.363467416058872, 0.4838681935085703, 0.9446929547638633], 
             UndirectedEdge[76, 365] -> 
             RGBColor[
              0.6446811516045015, 0.7152900376289849, 0.9561035228635739], 
             UndirectedEdge[182, 187] -> 
             RGBColor[
              0.32567828983082886`, 0.4496940163244615, 0.9422224001371563], 
             UndirectedEdge[74, 286] -> 
             RGBColor[
              0.32573069428586376`, 0.45505903941241577`, 0.9420309614803204],
              UndirectedEdge[137, 164] -> 
             RGBColor[
              0.41513146695621006`, 0.5339877443884264, 0.947672787881475], 
             UndirectedEdge[149, 258] -> 
             RGBColor[
              0.254607934007004, 0.38493946008972246`, 0.9378109172317903], 
             UndirectedEdge[147, 331] -> 
             RGBColor[
              0.4698176465549579, 0.5793764304299842, 0.9517037967183174], 
             UndirectedEdge[42, 367] -> 
             RGBColor[
              0.32379366762817957`, 0.4501007604887406, 0.9420276519005543], 
             UndirectedEdge[16, 365] -> 
             RGBColor[
              0.7128290687382116, 0.7737122080408627, 0.9606127708555026], 
             UndirectedEdge[113, 183] -> 
             RGBColor[
              0.6218524384801635, 0.6982394599529747, 0.9664332763111816], 
             UndirectedEdge[16, 323] -> 
             RGBColor[
              0.3688318701464206, 0.4889681275183916, 0.945047465316097], 
             UndirectedEdge[340, 343] -> 
             RGBColor[
              0.276137777085255, 0.40491050995012756`, 0.9391343389462268], 
             UndirectedEdge[323, 362] -> 
             RGBColor[
              0.2676034152667198, 0.39859853485478536`, 0.9385509906644394], 
             UndirectedEdge[334, 364] -> 
             RGBColor[
              0.28667397034423386`, 0.4111599931984045, 0.939911016341903], 
             UndirectedEdge[94, 324] -> 
             RGBColor[
              0.34074372355347027`, 0.46955681988966813`, 0.9429328666503511],
              UndirectedEdge[135, 350] -> 
             RGBColor[
              0.2745596564449719, 0.40455002261898276`, 0.9389969332074846], 
             UndirectedEdge[31, 215] -> 
             RGBColor[
              0.47227288213398055`, 0.5818682280617256, 0.951759337421808], 
             UndirectedEdge[3, 21] -> 
             RGBColor[
              0.37748415065434726`, 0.49292800027145756`, 0.9460075487703089],
              UndirectedEdge[127, 193] -> 
             RGBColor[
              0.6209086379224118, 0.6902874540663781, 0.9383770308750331], 
             UndirectedEdge[50, 230] -> 
             RGBColor[
              0.35322154547524687`, 0.4803644820847459, 0.9437279424295021], 
             UndirectedEdge[169, 382] -> 
             RGBColor[
              0.5790295854161662, 0.6542832809880649, 0.9644005395796409], 
             UndirectedEdge[12, 19] -> 
             RGBColor[
              0.278988748050934, 0.4050056280625448, 0.9394029332051645], 
             UndirectedEdge[133, 296] -> 
             RGBColor[
              0.5532215247858738, 0.6392575321605178, 0.9610949856133341], 
             UndirectedEdge[214, 332] -> 
             RGBColor[
              0.3255348447018236, 0.4553430826296917, 0.9420018707336593], 
             UndirectedEdge[76, 395] -> 
             RGBColor[
              0.3367793761346294, 0.46612310140936297`, 0.9426802619383574], 
             UndirectedEdge[299, 370] -> 
             RGBColor[
              0.4332442294884933, 0.5496761089199749, 0.948826917093545], 
             UndirectedEdge[170, 235] -> 
             RGBColor[
              0.5387682723766543, 0.63643538060627, 0.9568329584561517], 
             UndirectedEdge[46, 400] -> 
             RGBColor[
              0.28836607301796185`, 0.42042140457987554`, 0.9397333933077731],
              UndirectedEdge[65, 329] -> 
             RGBColor[
              0.2623244260629275, 0.39304998249435236`, 0.9382503600388481], 
             UndirectedEdge[81, 267] -> 
             RGBColor[
              0.4701072761438957, 0.5786701851545967, 0.9519867034152811], 
             UndirectedEdge[104, 182] -> 
             RGBColor[
              0.4306872706069922, 0.5474613996533089, 0.9486639899346458], 
             UndirectedEdge[23, 306] -> 
             RGBColor[
              0.5330557973688944, 0.629930045910486, 0.9570557839058649], 
             UndirectedEdge[209, 286] -> 
             RGBColor[
              0.4738480509580723, 0.5811659249913893, 0.9524307232318876], 
             UndirectedEdge[150, 167] -> 
             RGBColor[
              0.41640218142095003`, 0.5350883733898181, 0.9477537566835197], 
             UndirectedEdge[4, 288] -> 
             RGBColor[
              0.3281997588683336, 0.4564322502078132, 0.9422163119949531], 
             UndirectedEdge[171, 272] -> 
             RGBColor[
              0.4194280228456051, 0.5377092051486423, 0.9479465606234521], 
             UndirectedEdge[78, 182] -> 
             RGBColor[
              0.40862337278651906`, 0.528350760324964, 0.947258097875864], 
             UndirectedEdge[143, 374] -> 
             RGBColor[
              0.5864437292862018, 0.6742295741563424, 0.9612089256176], 
             UndirectedEdge[55, 262] -> 
             RGBColor[
              0.3161359049398907, 0.44052107582207856`, 0.9416476070464284], 
             UndirectedEdge[165, 190] -> 
             RGBColor[
              0.3381219194987985, 0.46728594499321474`, 0.9427658076143578], 
             UndirectedEdge[2, 149] -> 
             RGBColor[
              0.3394057727607821, 0.4629596923465059, 0.9430467350139353], 
             UndirectedEdge[39, 47] -> 
             RGBColor[
              0.30541264838807003`, 0.4374629295898209, 0.9407362271394002], 
             UndirectedEdge[230, 300] -> 
             RGBColor[
              0.5277047208948156, 0.6219765373990599, 0.9581194386024787], 
             UndirectedEdge[40, 48] -> 
             RGBColor[
              0.24427414810355413`, 0.37407799590532786`, 0.937222423412055], 
             UndirectedEdge[25, 208] -> 
             RGBColor[
              0.46282800101567656`, 0.5720000011100278, 0.9516237918372596], 
             UndirectedEdge[32, 52] -> 
             RGBColor[
              0.27471127665258777`, 0.4060693478357736, 0.938955772855226], 
             UndirectedEdge[161, 366] -> 
             RGBColor[
              0.4921412432603303, 0.5951840588700152, 0.9541557968474634], 
             UndirectedEdge[190, 318] -> 
             RGBColor[
              0.42311386614577906`, 0.5391636914261984, 0.9486616355170066], 
             UndirectedEdge[179, 245] -> 
             RGBColor[
              0.2145149057512269, 0.34279914534808775`, 0.9355276785849438], 
             UndirectedEdge[37, 182] -> 
             RGBColor[
              0.41468084152373696`, 0.5335974352879109, 0.9476440744273903], 
             UndirectedEdge[12, 206] -> 
             RGBColor[
              0.2723382769198726, 0.39924532423121756`, 0.938979171065474], 
             UndirectedEdge[18, 218] -> 
             RGBColor[
              0.4025696222353705, 0.5231073058679089, 0.9468723582438663], 
             UndirectedEdge[92, 119] -> 
             RGBColor[
              0.2450946688230744, 0.374940415205562, 0.9372691508531801], 
             UndirectedEdge[215, 400] -> 
             RGBColor[
              0.3938557790549515, 0.5108276902710681, 0.9468768922239427], 
             UndirectedEdge[71, 292] -> 
             RGBColor[
              0.27223418369453817`, 0.4034657660800988, 0.9388147060757956], 
             UndirectedEdge[158, 346] -> 
             RGBColor[
              0.5990332162934378, 0.6832947116363856, 0.9628603837749714], 
             UndirectedEdge[92, 151] -> 
             RGBColor[
              0.38588096543368555`, 0.5076036233908334, 0.9459532280689913], 
             UndirectedEdge[104, 170] -> 
             RGBColor[
              0.5065763787934019, 0.6100764894344921, 0.9543606035948], 
             UndirectedEdge[82, 316] -> 
             RGBColor[
              0.3454843659486977, 0.4736629260607993, 0.9432349361917896], 
             UndirectedEdge[287, 353] -> 
             RGBColor[
              0.336889807156917, 0.4606477894892463, 0.9428912787040908], 
             UndirectedEdge[368, 372] -> 
             RGBColor[
              0.24217642946309287`, 0.3718731606111593, 0.9371029614387775], 
             UndirectedEdge[9, 203] -> 
             RGBColor[
              0.34195367817546385`, 0.4706048217691514, 0.9430099638889438], 
             UndirectedEdge[17, 384] -> 
             RGBColor[
              0.23230056561040036`, 0.3614930015360456, 0.9365405456023979], 
             UndirectedEdge[82, 310] -> 
             RGBColor[
              0.2991656044498673, 0.4277921247984758, 0.9404941479038], 
             UndirectedEdge[129, 287] -> 
             RGBColor[
              0.40518644143732385`, 0.5253738631354836, 0.9470390996494523], 
             UndirectedEdge[81, 363] -> 
             RGBColor[
              0.31047565160139756`, 0.43718220969711236`, 0.9412296837648183],
              UndirectedEdge[64, 356] -> 
             RGBColor[
              0.3875758154369003, 0.5101204240297159, 0.9459169661331706], 
             UndirectedEdge[245, 352] -> 
             RGBColor[
              0.26142119354332916`, 0.39210062784800515`, 0.9381989222830698],
              UndirectedEdge[87, 232] -> 
             RGBColor[
              0.3259782322784608, 0.4566975674868048, 0.9419945902591391], 
             UndirectedEdge[88, 255] -> 
             RGBColor[
              0.4044263012770102, 0.5247154679343752, 0.9469906641906027], 
             UndirectedEdge[154, 392] -> 
             RGBColor[
              0.43428257771991563`, 0.5350708425610758, 0.9510245769886321], 
             UndirectedEdge[22, 45] -> 
             RGBColor[
              0.49474926343947345`, 0.5992361670133488, 0.9537717413159159], 
             UndirectedEdge[116, 141] -> 
             RGBColor[
              0.3467881762535359, 0.47124350813501426`, 0.9434479495938517], 
             UndirectedEdge[97, 224] -> 
             RGBColor[
              0.5246996331412912, 0.6159543271202969, 0.9584139379748042], 
             UndirectedEdge[66, 151] -> 
             RGBColor[
              0.607257240488974, 0.6904665311675247, 0.9632989530424108], 
             UndirectedEdge[165, 221] -> 
             RGBColor[
              0.35000997916040866`, 0.4775827847608495, 0.9435233042637972], 
             UndirectedEdge[101, 332] -> 
             RGBColor[
              0.3937974479630113, 0.5134699043308695, 0.9466274788087286], 
             UndirectedEdge[58, 396] -> 
             RGBColor[
              0.35224707574789904`, 0.47952044538518984`, 0.9436658500801652],
              UndirectedEdge[35, 387] -> 
             RGBColor[
              0.46988217034504, 0.5805105396934738, 0.9514099921661168], 
             UndirectedEdge[198, 266] -> 
             RGBColor[
              0.3736081454772735, 0.498022330346192, 0.9450269585544686], 
             UndirectedEdge[188, 264] -> 
             RGBColor[
              0.3797918952514542, 0.49501159573748105`, 0.9461701015067081], 
             UndirectedEdge[119, 151] -> 
             RGBColor[
              0.32879673229021644`, 0.44760447500762235`, 0.942702365440026], 
             UndirectedEdge[247, 400] -> 
             RGBColor[
              0.3870407886641024, 0.5052949740599584, 0.9463403912162427], 
             UndirectedEdge[305, 361] -> 
             RGBColor[
              0.40117213735531904`, 0.5134022122542165, 0.9477591866684263], 
             UndirectedEdge[138, 210] -> 
             RGBColor[
              0.4151075384946544, 0.517409998478228, 0.9495378548904488], 
             UndirectedEdge[197, 231] -> 
             RGBColor[
              0.45863478221376164`, 0.5713794033194408, 0.9505245565718823], 
             UndirectedEdge[225, 261] -> 
             RGBColor[
              0.39971211108619364`, 0.5206322733331783, 0.9466902801602386], 
             UndirectedEdge[83, 286] -> 
             RGBColor[
              0.3010725413927159, 0.4291417573045253, 0.9406267161515238], 
             UndirectedEdge[19, 238] -> 
             RGBColor[
              0.39661903141845056`, 0.5179532031876837, 0.946493191858913], 
             UndirectedEdge[62, 117] -> 
             RGBColor[
              0.32226102864783857`, 0.45242358796027593`, 0.9417963373181724],
              UndirectedEdge[65, 167] -> 
             RGBColor[
              0.3569546567018582, 0.4831752192055521, 0.9439812899540209], 
             UndirectedEdge[268, 371] -> 
             RGBColor[
              0.18766174953560366`, 0.31457477557702684`, 0.9339984310641487],
              UndirectedEdge[172, 192] -> 
             RGBColor[
              0.32368921133494755`, 0.4434989451825655, 0.9422965519005583], 
             UndirectedEdge[52, 353] -> 
             RGBColor[
              0.24715968276020836`, 0.37711087578293556`, 0.9373867503419856],
              UndirectedEdge[126, 298] -> 
             RGBColor[
              0.36348607437356506`, 0.4798123891915023, 0.9450649869842542], 
             UndirectedEdge[146, 306] -> 
             RGBColor[
              0.535331399300577, 0.6317077634347316, 0.9572825946397059], 
             UndirectedEdge[21, 132] -> 
             RGBColor[
              0.29269614042507625`, 0.4212585316739321, 0.9401159737425677], 
             UndirectedEdge[89, 162] -> 
             RGBColor[
              0.3418635925971597, 0.467999064338009, 0.943096776287059], 
             UndirectedEdge[9, 18] -> 
             RGBColor[
              0.3779353011987058, 0.5017702951429263, 0.9453026810906848], 
             UndirectedEdge[255, 360] -> 
             RGBColor[
              0.3761462756315609, 0.5002207311157049, 0.9451886859635195], 
             UndirectedEdge[124, 152] -> 
             RGBColor[
              0.40512501333942047`, 0.5177338967003564, 0.9479681890025148], 
             UndirectedEdge[88, 389] -> 
             RGBColor[
              0.2973263560958723, 0.42081973220604785`, 0.9405739161785194], 
             UndirectedEdge[12, 167] -> 
             RGBColor[
              0.29941732032931945`, 0.42269983060018484`, 0.940704623766466], 
             UndirectedEdge[32, 303] -> 
             RGBColor[
              0.42772560237424206`, 0.5417442978965392, 0.9492319792341766], 
             UndirectedEdge[49, 261] -> 
             RGBColor[
              0.3986270537137463, 0.5196924511737337, 0.9466211412639448], 
             UndirectedEdge[283, 360] -> 
             RGBColor[
              0.49461483611504, 0.5977772345000558, 0.9541341120118466], 
             UndirectedEdge[282, 305] -> 
             RGBColor[
              0.2556606379545323, 0.38604591868386007`, 0.937870867164266], 
             UndirectedEdge[32, 385] -> 
             RGBColor[
              0.533207334657169, 0.6255338078974715, 0.9587975375966657], 
             UndirectedEdge[167, 216] -> 
             RGBColor[
              0.3062600147492325, 0.42989193628739775`, 0.9410943050908209], 
             UndirectedEdge[252, 318] -> 
             RGBColor[
              0.415980312222179, 0.5329849655604213, 0.9482070917689487], 
             UndirectedEdge[2, 217] -> 
             RGBColor[
              0.31972909646579206`, 0.4422782579871379, 0.9419261774079696], 
             UndirectedEdge[305, 329] -> 
             RGBColor[
              0.2336722488669494, 0.36293472760842027`, 0.9366186609346348], 
             UndirectedEdge[87, 373] -> 
             RGBColor[
              0.30882697657762015`, 0.4418420118459133, 0.9409017274121415], 
             UndirectedEdge[20, 241] -> 
             RGBColor[
              0.3019209957665844, 0.4323605657196522, 0.9405898304393409], 
             UndirectedEdge[59, 210] -> 
             RGBColor[
              0.4939917383473357, 0.5970818890456058, 0.9541488404748225], 
             UndirectedEdge[290, 304] -> 
             RGBColor[
              0.3902155850839526, 0.4963806043265978, 0.9476363790697224], 
             UndirectedEdge[115, 312] -> 
             RGBColor[
              0.1915069403171234, 0.3186163148875808, 0.9342174089907063], 
             UndirectedEdge[214, 389] -> 
             RGBColor[
              0.2709657278856348, 0.3979874809740378, 0.9388942402587512], 
             UndirectedEdge[144, 276] -> 
             RGBColor[
              0.4080957648571295, 0.5276620410153828, 0.9472885073628451], 
             UndirectedEdge[196, 286] -> 
             RGBColor[
              0.4308670176223171, 0.5462719858559371, 0.9490470988429841], 
             UndirectedEdge[124, 181] -> 
             RGBColor[
              0.4656715910139726, 0.57502944422123, 0.9516484659769202], 
             UndirectedEdge[216, 341] -> 
             RGBColor[
              0.3137138805619118, 0.43634810021215165`, 0.94156925882921], 
             UndirectedEdge[294, 340] -> 
             RGBColor[
              0.30789569449308907`, 0.43829009471402297`, 0.9409429053609744],
              UndirectedEdge[104, 235] -> 
             RGBColor[
              0.47725787201657266`, 0.5862744048493834, 0.952052543344099], 
             UndirectedEdge[125, 318] -> 
             RGBColor[
              0.4267414354219004, 0.5423057096062414, 0.9488927810235473], 
             UndirectedEdge[109, 232] -> 
             RGBColor[
              0.337799682920818, 0.46700683986544944`, 0.9427452749845515], 
             UndirectedEdge[182, 388] -> 
             RGBColor[
              0.43186655089985193`, 0.548482832970633, 0.9487391326321102], 
             UndirectedEdge[97, 382] -> 
             RGBColor[
              0.2638475917121842, 0.39465092616600117`, 0.9383371020692517], 
             UndirectedEdge[140, 147] -> 
             RGBColor[
              0.43447436259355354`, 0.548763854267719, 0.9494517539171357], 
             UndirectedEdge[59, 300] -> 
             RGBColor[
              0.5446832179092125, 0.6366824581488579, 0.9592012934187407], 
             UndirectedEdge[205, 373] -> 
             RGBColor[
              0.2614306409647742, 0.392025458015568, 0.938202576215585], 
             UndirectedEdge[215, 259] -> 
             RGBColor[
              0.44304027350160846`, 0.5565484117379957, 0.9498966614491341], 
             UndirectedEdge[136, 300] -> 
             RGBColor[
              0.4741264682877527, 0.5657632457653337, 0.9550645438056764], 
             UndirectedEdge[152, 245] -> 
             RGBColor[
              0.24690244987239626`, 0.376840507708338, 0.9373721013095666], 
             UndirectedEdge[44, 128] -> 
             RGBColor[
              0.5319466328529848, 0.6302342116319024, 0.9564791379929052], 
             UndirectedEdge[241, 392] -> 
             RGBColor[
              0.4981884560852531, 0.5999320504889923, 0.9547484265550081], 
             UndirectedEdge[240, 342] -> 
             RGBColor[
              0.4989628499126453, 0.6012153118813831, 0.9545385225892289], 
             UndirectedEdge[123, 214] -> 
             RGBColor[
              0.345148269936151, 0.4733718165874081, 0.9432135204510681], 
             UndirectedEdge[125, 274] -> 
             RGBColor[
              0.3861093725082252, 0.5088502648704623, 0.9458235256864799], 
             UndirectedEdge[298, 373] -> 
             RGBColor[
              0.40740255971650413`, 0.5258863000815481, 0.9475690817717568], 
             UndirectedEdge[119, 350] -> 
             RGBColor[
              0.20683729200226803`, 0.3347294865091047, 0.9350904498399524], 
             UndirectedEdge[22, 179] -> 
             RGBColor[
              0.2954657900547196, 0.419497305041711, 0.9404447771288933], 
             UndirectedEdge[1, 183] -> 
             RGBColor[
              0.4087372811146334, 0.5283906411683874, 0.9472815973309439], 
             UndirectedEdge[112, 260] -> 
             RGBColor[
              0.7010119323058739, 0.7627374045218481, 0.9400849184746347], 
             UndirectedEdge[183, 270] -> 
             RGBColor[
              0.29161064034451634`, 0.4189087209029792, 0.9400984191873334], 
             UndirectedEdge[152, 181] -> 
             RGBColor[
              0.31680164797052346`, 0.4439662522847734, 0.9415849961811327], 
             UndirectedEdge[169, 276] -> 
             RGBColor[
              0.6332792257575812, 0.7070877060267243, 0.9676443222944298], 
             UndirectedEdge[349, 355] -> 
             RGBColor[
              0.43086999595657993`, 0.5466639032649419, 0.9489397134462045], 
             UndirectedEdge[171, 240] -> 
             RGBColor[
              0.3968914455524074, 0.5181891546185846, 0.9465105498466424], 
             UndirectedEdge[114, 132] -> 
             RGBColor[
              0.3113118024132442, 0.44082477272463766`, 0.9411761081533899], 
             UndirectedEdge[17, 222] -> 
             RGBColor[
              0.24314247645569295`, 0.372888537251299, 0.9371579763858675], 
             UndirectedEdge[46, 259] -> 
             RGBColor[
              0.33755056746461876`, 0.46614212604680316`, 0.9427531625329645],
              UndirectedEdge[13, 79] -> 
             RGBColor[
              0.29980094513800803`, 0.4324401801908112, 0.9403845923586324], 
             UndirectedEdge[146, 311] -> 
             RGBColor[
              0.43821954328250873`, 0.5379519273137148, 0.9514477695493937], 
             UndirectedEdge[44, 275] -> 
             RGBColor[
              0.4983358660622073, 0.6011222547639892, 0.9543374896538308], 
             UndirectedEdge[193, 195] -> 
             RGBColor[
              0.41896466743198113`, 0.5309879400615649, 0.9488739709755905], 
             UndirectedEdge[86, 297] -> 
             RGBColor[
              0.28612280031706044`, 0.4150963708706019, 0.9397142864078492], 
             UndirectedEdge[197, 392] -> 
             RGBColor[
              0.5610764902880233, 0.654235077355926, 0.9588018572059489], 
             UndirectedEdge[217, 392] -> 
             RGBColor[
              0.4366209659907899, 0.5375286368961443, 0.9511577447413229], 
             UndirectedEdge[101, 193] -> 
             RGBColor[
              0.38161674880815233`, 0.5006672172181803, 0.9459338060115889], 
             UndirectedEdge[216, 340] -> 
             RGBColor[
              0.2701406976436648, 0.39860719922021814`, 0.9387928141439121], 
             UndirectedEdge[125, 190] -> 
             RGBColor[
              0.332527877574078, 0.46244066704274417`, 0.9424093602095316], 
             UndirectedEdge[99, 276] -> 
             RGBColor[
              0.3808242338649686, 0.5042725434164654, 0.9454867613255962], 
             UndirectedEdge[27, 63] -> 
             RGBColor[
              0.4943688646950437, 0.6003899412798163, 0.9533376744430659], 
             UndirectedEdge[184, 226] -> 
             RGBColor[
              0.43064345316080505`, 0.5346589794756197, 0.9503222596862576], 
             UndirectedEdge[107, 211] -> 
             RGBColor[
              0.5891664843642849, 0.6773509195114051, 0.9608004903185514], 
             UndirectedEdge[216, 294] -> 
             RGBColor[
              0.24053989082625093`, 0.37015305474129584`, 0.9370097629844512],
              UndirectedEdge[68, 284] -> 
             RGBColor[
              0.34132841542026915`, 0.46732410969441085`, 0.9430704160655462],
              UndirectedEdge[89, 359] -> 
             RGBColor[
              0.31227923226769927`, 0.4423745783738156, 0.9412116870072884], 
             UndirectedEdge[23, 267] -> 
             RGBColor[
              0.6144194941365041, 0.697468348604593, 0.963051112302371], 
             UndirectedEdge[140, 242] -> 
             RGBColor[
              0.4383445857296442, 0.5519058757611628, 0.9497564320595031], 
             UndirectedEdge[64, 214] -> 
             RGBColor[
              0.35346090914261263`, 0.4805718068626504, 0.9437431944707256], 
             UndirectedEdge[296, 367] -> 
             RGBColor[
              0.6037500597733065, 0.6848089338607557, 0.9642492204207583], 
             UndirectedEdge[275, 346] -> 
             RGBColor[
              0.5590752465373128, 0.6486851265795854, 0.9603142972755565], 
             UndirectedEdge[301, 305] -> 
             RGBColor[
              0.32912913363030194`, 0.45377597057334984`, 0.9424022645196342],
              UndirectedEdge[81, 119] -> 
             RGBColor[
              0.28340950553764716`, 0.4087339740913334, 0.9396883067872626], 
             UndirectedEdge[327, 355] -> 
             RGBColor[
              0.3725582277309964, 0.49133577898734776`, 0.9454006742641714], 
             UndirectedEdge[317, 344] -> 
             RGBColor[
              0.2179558396033256, 0.34641578499445047`, 0.9357236346774154], 
             UndirectedEdge[184, 190] -> 
             RGBColor[
              0.27672632923966, 0.4063238923587983, 0.9391387554495813], 
             UndirectedEdge[10, 303] -> 
             RGBColor[
              0.36980679659894145`, 0.48086796076231214`, 0.9459335889284679],
              UndirectedEdge[149, 268] -> 
             RGBColor[
              0.21522030516010907`, 0.3435405648517286, 0.9355678500377347], 
             UndirectedEdge[38, 267] -> 
             RGBColor[
              0.4929946052828129, 0.5984940393041163, 0.9534450637895424], 
             UndirectedEdge[253, 366] -> 
             RGBColor[
              0.4756567680023719, 0.5801138040569481, 0.953134428113974], 
             UndirectedEdge[165, 355] -> 
             RGBColor[
              0.4179307906666458, 0.5354566139861683, 0.9481152387268199], 
             UndirectedEdge[339, 340] -> 
             RGBColor[
              0.31057850067442183`, 0.4411098941103401, 0.9410956872041452], 
             UndirectedEdge[185, 318] -> 
             RGBColor[
              0.49434265004803873`, 0.6003686590484212, 0.9533356107300264], 
             UndirectedEdge[36, 70] -> 
             RGBColor[
              0.6475334828145793, 0.7149481348117723, 0.9013614040743259], 
             UndirectedEdge[69, 131] -> 
             RGBColor[
              0.32620721945490183`, 0.456966030665428, 0.9420066134633163], 
             UndirectedEdge[283, 312] -> 
             RGBColor[
              0.4115223419651393, 0.5142318895916811, 0.9492633419924525], 
             UndirectedEdge[75, 330] -> 
             RGBColor[
              0.5784696674254491, 0.6501263537914522, 0.9614373062561204], 
             UndirectedEdge[169, 222] -> 
             RGBColor[
              0.5820063058737335, 0.6574120029239457, 0.964570059406036], 
             UndirectedEdge[90, 246] -> 
             RGBColor[
              0.6565140777334618, 0.7290275894494562, 0.9682828419477967], 
             UndirectedEdge[62, 362] -> 
             RGBColor[
              0.2848474217161079, 0.41672307896624905`, 0.9395330113215106], 
             UndirectedEdge[158, 374] -> 
             RGBColor[
              0.45632926946773866`, 0.5691893123957423, 0.9504310252440276], 
             UndirectedEdge[82, 172] -> 
             RGBColor[
              0.2700745791439943, 0.3972156127244669, 0.9388374570489457], 
             UndirectedEdge[306, 346] -> 
             RGBColor[
              0.5775762027017368, 0.664709724924115, 0.9614931618426004], 
             UndirectedEdge[53, 188] -> 
             RGBColor[
              0.4245411257481879, 0.5402906387360166, 0.9487827717535133], 
             UndirectedEdge[84, 190] -> 
             RGBColor[
              0.6367798547782372, 0.7087731507249966, 0.9603697963096265], 
             UndirectedEdge[78, 96] -> 
             RGBColor[
              0.5309444419626246, 0.62837660662404, 0.9568047256923918], 
             UndirectedEdge[46, 199] -> 
             RGBColor[
              0.24457377066060387`, 0.3743929182099544, 0.9372394864734273], 
             UndirectedEdge[159, 265] -> 
             RGBColor[
              0.2787134247669122, 0.410275859254775, 0.9391836892696892], 
             UndirectedEdge[332, 356] -> 
             RGBColor[
              0.3596497509961113, 0.4848916997967572, 0.9441756423961041], 
             UndirectedEdge[199, 222] -> 
             RGBColor[
              0.2196067980098868, 0.34815104695655513`, 0.935817654316295], 
             UndirectedEdge[114, 300] -> 
             RGBColor[
              0.509639829496862, 0.6030900400732591, 0.9570869771892254], 
             UndirectedEdge[139, 213] -> 
             RGBColor[
              0.4675565179136102, 0.5586171650293814, 0.9547284926973917], 
             UndirectedEdge[106, 369] -> 
             RGBColor[
              0.3138735400757541, 0.4460267290394626, 0.9412301136183535], 
             UndirectedEdge[109, 114] -> 
             RGBColor[
              0.30266870660877715`, 0.43333855755343464`, 0.9406253777315188],
              UndirectedEdge[58, 245] -> 
             RGBColor[
              0.2832291784819947, 0.41315803929415806`, 0.9395091109183247], 
             UndirectedEdge[151, 317] -> 
             RGBColor[
              0.35903714816042764`, 0.4793890694403215, 0.9444245123871482], 
             UndirectedEdge[99, 218] -> 
             RGBColor[
              0.3897115643030433, 0.5119703023517098, 0.9460530541623526], 
             UndirectedEdge[55, 57] -> 
             RGBColor[
              0.21868996917038014`, 0.34718740171592777`, 0.9357654422702117],
              UndirectedEdge[247, 287] -> 
             RGBColor[
              0.46218245386033585`, 0.5734984921848331, 0.9510141284085722], 
             UndirectedEdge[44, 66] -> 
             RGBColor[
              0.68996325658675, 0.7576110008992647, 0.9698098735917471], 
             UndirectedEdge[116, 290] -> 
             RGBColor[
              0.4359338972501298, 0.5444334491216628, 0.9502399693134043], 
             UndirectedEdge[278, 367] -> 
             RGBColor[
              0.3781408353229795, 0.5019483184709267, 0.9453157775433367], 
             UndirectedEdge[102, 297] -> 
             RGBColor[
              0.28409087054310783`, 0.41333641542816413`, 0.9395848136394178],
              UndirectedEdge[104, 187] -> 
             RGBColor[
              0.3400569976571569, 0.4621481303487582, 0.9431385986852578], 
             UndirectedEdge[136, 371] -> 
             RGBColor[
              0.19874484095575437`, 0.3262238073681878, 0.9346295967245619], 
             UndirectedEdge[80, 302] -> 
             RGBColor[
              0.3656399642860366, 0.48264223305631354`, 0.9451361298095702], 
             UndirectedEdge[176, 373] -> 
             RGBColor[
              0.42946342175814023`, 0.5437963017174577, 0.9493057936432747], 
             UndirectedEdge[112, 219] -> 
             RGBColor[
              0.35374410605143874`, 0.477963466313596, 0.9438657249545888], 
             UndirectedEdge[33, 179] -> 
             RGBColor[
              0.32082544803030877`, 0.4414625661666955, 0.9420606721104328], 
             UndirectedEdge[123, 334] -> 
             RGBColor[
              0.3631991076472989, 0.48900654495132123`, 0.9443637038682935], 
             UndirectedEdge[94, 307] -> 
             RGBColor[
              0.3510538251481084, 0.4784869116901702, 0.9435898172070967], 
             UndirectedEdge[73, 89] -> 
             RGBColor[
              0.36430194399811666`, 0.48743403653718465`, 0.9445265281968729],
              UndirectedEdge[267, 311] -> 
             RGBColor[
              0.3829304241064244, 0.4935195501337537, 0.9467849279934335], 
             UndirectedEdge[52, 391] -> 
             RGBColor[
              0.34711838616100266`, 0.469261042319387, 0.9435520503340298], 
             UndirectedEdge[105, 271] -> 
             RGBColor[
              0.3525980493262679, 0.479824441058328, 0.9436882138062251], 
             UndirectedEdge[187, 377] -> 
             RGBColor[
              0.30497428718111, 0.4317612498427054, 0.9409031593961469], 
             UndirectedEdge[58, 124] -> 
             RGBColor[
              0.44145174194901887`, 0.5540514282861765, 0.950105198611273], 
             UndirectedEdge[11, 54] -> 
             RGBColor[
              0.49908223587812583`, 0.5892231717767965, 0.9569242961001614], 
             UndirectedEdge[115, 283] -> 
             RGBColor[
              0.4194747095160771, 0.5225903320969413, 0.9497162175600049], 
             UndirectedEdge[292, 362] -> 
             RGBColor[
              0.2686274300814418, 0.39967483935134746`, 0.9386093067932437], 
             UndirectedEdge[15, 154] -> 
             RGBColor[
              0.33246086225866095`, 0.4527185064581788, 0.9427960844441692], 
             UndirectedEdge[158, 311] -> 
             RGBColor[
              0.32302374093051567`, 0.44456623415191726`, 0.9421568215292985],
              UndirectedEdge[123, 253] -> 
             RGBColor[
              0.31844776350627213`, 0.44945294904588, 0.9415411952449857], 
             UndirectedEdge[236, 376] -> 
             RGBColor[
              0.21934103704797048`, 0.3478717153353629, 0.9358025196226719], 
             UndirectedEdge[206, 386] -> 
             RGBColor[
              0.359629641101709, 0.4859148524361363, 0.9441362606163637], 
             UndirectedEdge[74, 338] -> 
             RGBColor[
              0.3605644262035648, 0.48523026720525564`, 0.9442505360758566], 
             UndirectedEdge[293, 394] -> 
             RGBColor[
              0.2319994211344167, 0.36117647959812427`, 0.9365233958699939], 
             UndirectedEdge[41, 381] -> 
             RGBColor[
              0.3916346250095971, 0.5136359608798852, 0.9461755898900783], 
             UndirectedEdge[59, 328] -> 
             RGBColor[
              0.35441269148456994`, 0.48139619288928237`, 0.943803841199927], 
             UndirectedEdge[123, 196] -> 
             RGBColor[
              0.41978762202476044`, 0.5366755702559478, 0.9483411295526327], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.3774772310587775, 0.501373537810995, 0.9452734932664241], 
             UndirectedEdge[23, 38] -> 
             RGBColor[
              0.5460081225272146, 0.6411486989598316, 0.9578810946116616], 
             UndirectedEdge[61, 282] -> 
             RGBColor[
              0.3354089730379043, 0.4608407935563431, 0.942742891288286], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.36653919732097784`, 0.4786604979849328, 0.9456358156091205], 
             UndirectedEdge[3, 232] -> 
             RGBColor[
              0.43123078895455613`, 0.5461625236341779, 0.9491875804341636], 
             UndirectedEdge[110, 362] -> 
             RGBColor[
              0.26080100443895016`, 0.3914487697770424, 0.938163603431063], 
             UndirectedEdge[125, 252] -> 
             RGBColor[
              0.32539432365047793`, 0.4562619411769671, 0.9419548164614739], 
             UndirectedEdge[49, 327] -> 
             RGBColor[
              0.3301453452518256, 0.4555556358194833, 0.9424340824829773], 
             UndirectedEdge[89, 291] -> 
             RGBColor[
              0.6104859381278505, 0.6837774842484827, 0.9632605855087941], 
             UndirectedEdge[34, 250] -> 
             RGBColor[
              0.3249862890983468, 0.4486732909563661, 0.9421937341175094], 
             UndirectedEdge[125, 226] -> 
             RGBColor[
              0.48644500149522296`, 0.5907757541595655, 0.9535928644462079], 
             UndirectedEdge[3, 14] -> 
             RGBColor[
              0.42953326338711484`, 0.5446922123077761, 0.9490794156060693], 
             UndirectedEdge[105, 345] -> 
             RGBColor[
              0.28176789946562153`, 0.4104392666831548, 0.9394692041144732], 
             UndirectedEdge[88, 336] -> 
             RGBColor[
              0.29441461770886435`, 0.4177593105464259, 0.9404080969849102], 
             UndirectedEdge[162, 357] -> 
             RGBColor[
              0.3184062607749184, 0.44334392131209455`, 0.941760915941795], 
             UndirectedEdge[279, 328] -> 
             RGBColor[
              0.39032809958102965`, 0.5125043142215374, 0.9460923392450851], 
             UndirectedEdge[312, 359] -> 
             RGBColor[
              0.26335330248943284`, 0.3909503240937418, 0.938425427685843], 
             UndirectedEdge[202, 289] -> 
             RGBColor[
              0.26992081803878515`, 0.40041751362316935`, 0.938705545873123], 
             UndirectedEdge[27, 48] -> 
             RGBColor[
              0.3285241905930357, 0.4474241991576149, 0.9426771791788676], 
             UndirectedEdge[115, 193] -> 
             RGBColor[
              0.2362946215127901, 0.3656910075272278, 0.9367680011773627], 
             UndirectedEdge[117, 385] -> 
             RGBColor[
              0.5553790847154427, 0.6452141589279534, 0.9601928623926907], 
             UndirectedEdge[179, 352] -> 
             RGBColor[
              0.23838626984573483`, 0.36788946254331667`, 0.9368871174556075],
              UndirectedEdge[8, 365] -> 
             RGBColor[
              0.6258942861471835, 0.6983661712238182, 0.9549302996950917], 
             UndirectedEdge[105, 353] -> 
             RGBColor[
              0.29509680552501233`, 0.42444879205302943`, 0.9402282655962062],
              UndirectedEdge[231, 392] -> 
             RGBColor[
              0.5602270456832836, 0.6535454599587549, 0.9587349858150457], 
             UndirectedEdge[109, 132] -> 
             RGBColor[
              0.3402735242572976, 0.46914955689222715`, 0.94290290596698], 
             UndirectedEdge[23, 158] -> 
             RGBColor[
              0.5545128109605953, 0.6485150326227564, 0.9584230058382359], 
             UndirectedEdge[105, 350] -> 
             RGBColor[
              0.28368324597746386`, 0.41245241730708404`, 0.9395782802648215],
              UndirectedEdge[172, 351] -> 
             RGBColor[
              0.2433626778868445, 0.3731199829170164, 0.9371705165316128], 
             UndirectedEdge[34, 375] -> 
             RGBColor[
              0.24758278749477736`, 0.3775555856853572, 0.9374108455306919], 
             UndirectedEdge[32, 391] -> 
             RGBColor[
              0.37600156471320134`, 0.49961909427703877`, 0.945196904623744], 
             UndirectedEdge[140, 241] -> 
             RGBColor[
              0.3382502272883908, 0.4673970787516226, 0.9427739832732525], 
             UndirectedEdge[89, 336] -> 
             RGBColor[
              0.23196802769178085`, 0.36114348309945477`, 0.9365216080598783],
              UndirectedEdge[74, 118] -> 
             RGBColor[
              0.24674808546068328`, 0.37667826092435863`, 0.9373633104846812],
              UndirectedEdge[138, 328] -> 
             RGBColor[
              0.27552849163188864`, 0.40172430232190454`, 0.9391928556155533],
              UndirectedEdge[189, 207] -> 
             RGBColor[
              0.2620122543262415, 0.3926073254070763, 0.9382367763664704], 
             UndirectedEdge[273, 281] -> 
             RGBColor[
              0.3955032070473875, 0.5133587075707526, 0.946897938440692], 
             UndirectedEdge[49, 225] -> 
             RGBColor[
              0.40477734304775703`, 0.5250195226723238, 0.9470130322618207], 
             UndirectedEdge[43, 159] -> 
             RGBColor[
              0.31622161025609596`, 0.44378878729320503`, 0.9415361392462538],
              UndirectedEdge[113, 368] -> 
             RGBColor[
              0.5920691360217396, 0.6718582503532834, 0.9645569087264017], 
             UndirectedEdge[11, 83] -> 
             RGBColor[
              0.5046857548077889, 0.5951128254554927, 0.9572434082135424], 
             UndirectedEdge[151, 344] -> 
             RGBColor[
              0.32850172034372555`, 0.44729439874702265`, 0.9426855649461043],
              UndirectedEdge[182, 377] -> 
             RGBColor[
              0.39560456013094536`, 0.5170745191472561, 0.9464285506455349], 
             UndirectedEdge[198, 203] -> 
             RGBColor[
              0.39864923941408126`, 0.5197116673122781, 0.9466225549171521], 
             UndirectedEdge[208, 395] -> 
             RGBColor[
              0.3425426927901998, 0.4711149966237004, 0.9430474953793495], 
             UndirectedEdge[305, 339] -> 
             RGBColor[
              0.2652651617642313, 0.39614088216983523`, 0.9384178305866088], 
             UndirectedEdge[9, 313] -> 
             RGBColor[
              0.3527279327589628, 0.47993693955959715`, 0.943696489863705], 
             UndirectedEdge[267, 317] -> 
             RGBColor[
              0.404948622156065, 0.5166620723183134, 0.9480388317993556], 
             UndirectedEdge[306, 350] -> 
             RGBColor[
              0.3121713658409069, 0.437127394878261, 0.9413935180714648], 
             UndirectedEdge[111, 362] -> 
             RGBColor[
              0.29170549995456335`, 0.42378765220875525`, 0.9399288303589018],
              UndirectedEdge[104, 261] -> 
             RGBColor[
              0.41931390009275155`, 0.5376103577560969, 0.9479392888225551], 
             UndirectedEdge[243, 363] -> 
             RGBColor[
              0.264856222646116, 0.39571106122845834`, 0.9383945421088034], 
             UndirectedEdge[154, 369] -> 
             RGBColor[
              0.2559341294404075, 0.38633337557587655`, 0.9378864420997923], 
             UndirectedEdge[218, 282] -> 
             RGBColor[
              0.3182825686479689, 0.44600676287189456`, 0.9416516119448441], 
             UndirectedEdge[7, 293] -> 
             RGBColor[
              0.44565890234669414`, 0.5482431502300362, 0.9514800785630244], 
             UndirectedEdge[24, 167] -> 
             RGBColor[
              0.3455707839221784, 0.47121004713488635`, 0.9433329952401487], 
             UndirectedEdge[326, 363] -> 
             RGBColor[
              0.26947084678929256`, 0.4005613237870065, 0.9386573381270326], 
             UndirectedEdge[276, 282] -> 
             RGBColor[
              0.3093952382098941, 0.4383090039366502, 0.9410853191080877], 
             UndirectedEdge[337, 345] -> 
             RGBColor[
              0.289581436833259, 0.41720696003119545`, 0.9399670758062993], 
             UndirectedEdge[107, 124] -> 
             RGBColor[
              0.5477966844855964, 0.6437650522816397, 0.9575437081295308], 
             UndirectedEdge[128, 227] -> 
             RGBColor[
              0.40664310932054604`, 0.526635555641674, 0.9471319172388905], 
             UndirectedEdge[25, 365] -> 
             RGBColor[
              0.7624740190147538, 0.8140162151548829, 0.9645210031967169], 
             UndirectedEdge[97, 363] -> 
             RGBColor[
              0.26199908395672933`, 0.39270802731285714`, 0.9382318322872006],
              UndirectedEdge[13, 373] -> 
             RGBColor[
              0.3058706700696944, 0.43873474626542464`, 0.9407333701299787], 
             UndirectedEdge[64, 195] -> 
             RGBColor[
              0.4590714310276291, 0.5690193514072127, 0.9513089675097965], 
             UndirectedEdge[77, 96] -> 
             RGBColor[
              0.527387623525784, 0.6252958692649413, 0.9565780883667674], 
             UndirectedEdge[6, 53] -> 
             RGBColor[
              0.5837433125746825, 0.6666740836298184, 0.9633407811710935], 
             UndirectedEdge[216, 343] -> 
             RGBColor[
              0.20878197341841687`, 0.33677346997740043`, 0.9352011965697036],
              UndirectedEdge[26, 324] -> 
             RGBColor[
              0.42285465522020016`, 0.5388299027291469, 0.9486753113427573], 
             UndirectedEdge[142, 281] -> 
             RGBColor[
              0.7047462756866423, 0.7678586997083305, 0.972455032240083], 
             UndirectedEdge[100, 341] -> 
             RGBColor[
              0.38409515133579997`, 0.5071056477286073, 0.9456951812944788], 
             UndirectedEdge[115, 364] -> 
             RGBColor[
              0.19156360859891144`, 0.31867587684471665`, 0.9342206361655209],
              UndirectedEdge[150, 152] -> 
             RGBColor[
              0.3396621488081165, 0.46376686910811565`, 0.9430416470797569], 
             UndirectedEdge[10, 68] -> 
             RGBColor[
              0.2956469171837868, 0.419309958673593, 0.940468922320699], 
             UndirectedEdge[190, 288] -> 
             RGBColor[
              0.3504967667965236, 0.47800441574459424`, 0.943554321941521], 
             UndirectedEdge[23, 146] -> 
             RGBColor[
              0.6697086133125885, 0.741900725784554, 0.967713953858331], 
             UndirectedEdge[188, 201] -> 
             RGBColor[
              0.4026197741514697, 0.5190051438325158, 0.9474701154392435], 
             UndirectedEdge[148, 382] -> 
             RGBColor[
              0.27300854319733414`, 0.4042796670147656, 0.9388588047039177], 
             UndirectedEdge[14, 71] -> 
             RGBColor[
              0.31044906746899414`, 0.44068932634045466`, 0.9410987340382879],
              UndirectedEdge[228, 276] -> 
             RGBColor[
              0.2973738143151533, 0.4256737252209799, 0.9404007168013852], 
             UndirectedEdge[56, 174] -> 
             RGBColor[
              0.404416057730088, 0.5247065954888869, 0.9469900114808509], 
             UndirectedEdge[16, 182] -> 
             RGBColor[
              0.4459381069989692, 0.56006677741128, 0.9498026827167629], 
             UndirectedEdge[104, 192] -> 
             RGBColor[
              0.45204565063417806`, 0.5658059877335256, 0.9500677449214668], 
             UndirectedEdge[145, 395] -> 
             RGBColor[
              0.6229594474941027, 0.6981694348856208, 0.9669774550109499], 
             UndirectedEdge[219, 251] -> 
             RGBColor[
              0.2299375141707376, 0.35900928464684523`, 0.9364059733187304], 
             UndirectedEdge[150, 179] -> 
             RGBColor[
              0.3072746046869471, 0.42972550674786547`, 0.9411972243551341], 
             UndirectedEdge[73, 207] -> 
             RGBColor[
              0.37859117799535574`, 0.5023383826588581, 0.9453444729801983], 
             UndirectedEdge[265, 325] -> 
             RGBColor[
              0.2883488510177984, 0.4204033031657658, 0.9397324125403415], 
             UndirectedEdge[39, 314] -> 
             RGBColor[
              0.28804426119694415`, 0.4200831599519379, 0.939715066600644], 
             UndirectedEdge[20, 263] -> 
             RGBColor[
              0.33865077966285895`, 0.4641740584379891, 0.9429302197903389], 
             UndirectedEdge[66, 146] -> 
             RGBColor[
              0.7084578336606957, 0.7721719112254777, 0.9715761140105782], 
             UndirectedEdge[7, 21] -> 
             RGBColor[
              0.445069546332001, 0.5476236996912641, 0.9514465156098618], 
             UndirectedEdge[107, 167] -> 
             RGBColor[
              0.4756667740549807, 0.5840233646268854, 0.9521923479375061], 
             UndirectedEdge[120, 195] -> 
             RGBColor[
              0.5001100885745192, 0.604564973911426, 0.9539239144796243], 
             UndirectedEdge[365, 388] -> 
             RGBColor[
              0.6987575126390944, 0.7621282636002157, 0.9595492207708498], 
             UndirectedEdge[134, 342] -> 
             RGBColor[
              0.5325804495792884, 0.6303331870429407, 0.9566806063131112], 
             UndirectedEdge[227, 311] -> 
             RGBColor[
              0.29442144267612425`, 0.4197923609972736, 0.9403343083765479], 
             UndirectedEdge[78, 377] -> 
             RGBColor[
              0.3879193701368002, 0.510417993843208, 0.9459388571348546], 
             UndirectedEdge[21, 370] -> 
             RGBColor[
              0.3288630351187276, 0.4525844780565907, 0.9424204962913181], 
             UndirectedEdge[2, 230] -> 
             RGBColor[
              0.3693608911340902, 0.4943435721073369, 0.9447563272634205], 
             UndirectedEdge[24, 203] -> 
             RGBColor[
              0.32123437293499024`, 0.45013107112136586`, 0.9417823006518883],
              UndirectedEdge[54, 206] -> 
             RGBColor[
              0.2938190592489226, 0.4218229884193119, 0.9402024698411438], 
             UndirectedEdge[66, 130] -> 
             RGBColor[
              0.5026559361821312, 0.5958360441545362, 0.9566755576074002], 
             UndirectedEdge[101, 356] -> 
             RGBColor[
              0.4559558654918857, 0.5683489722406339, 0.9505500578140864], 
             UndirectedEdge[222, 383] -> 
             RGBColor[
              0.28826460329941417`, 0.41883636665160845`, 0.939781745740969], 
             UndirectedEdge[31, 247] -> 
             RGBColor[
              0.4654578917431314, 0.5763355118506158, 0.951222836414108], 
             UndirectedEdge[46, 333] -> 
             RGBColor[
              0.3265394154967932, 0.45660481964886246`, 0.942051541666354], 
             UndirectedEdge[287, 385] -> 
             RGBColor[
              0.594054280501679, 0.6787126696461305, 0.9626572116690568], 
             UndirectedEdge[42, 330] -> 
             RGBColor[
              0.23723831194239087`, 0.36668288600216725`, 0.9368217429512636],
              UndirectedEdge[151, 227] -> 
             RGBColor[
              0.4269855214661648, 0.5438134969344055, 0.9485501424511589], 
             UndirectedEdge[36, 382] -> 
             RGBColor[
              0.2768559466177052, 0.40832353194904164`, 0.9390779086369845], 
             UndirectedEdge[218, 361] -> 
             RGBColor[
              0.46379406804875556`, 0.5733630564422509, 0.9515399314490043], 
             UndirectedEdge[196, 334] -> 
             RGBColor[
              0.44626854573616764`, 0.5596120154048433, 0.9500284705953621], 
             UndirectedEdge[34, 265] -> 
             RGBColor[
              0.26407404902027887`, 0.3948889471550313, 0.938349998477934], 
             UndirectedEdge[372, 392] -> 
             RGBColor[
              0.4222982540141441, 0.5224745584963002, 0.9503420874828066], 
             UndirectedEdge[127, 210] -> 
             RGBColor[
              0.8064385278962758, 0.8490664095126552, 0.9515294062631425], 
             UndirectedEdge[33, 157] -> 
             RGBColor[
              0.44727163593713004`, 0.5618259433478361, 0.9497207310285037], 
             UndirectedEdge[139, 308] -> 
             RGBColor[
              0.5016125479477934, 0.5944122118723261, 0.9566679332264569], 
             UndirectedEdge[38, 146] -> 
             RGBColor[
              0.5482837244588973, 0.6429264164840773, 0.9581079053455026], 
             UndirectedEdge[55, 68] -> 
             RGBColor[
              0.3143831515140252, 0.43900292890054254`, 0.9415359231480314], 
             UndirectedEdge[35, 392] -> 
             RGBColor[
              0.5670275015719786, 0.6590663764062441, 0.9592703426134945], 
             UndirectedEdge[51, 126] -> 
             RGBColor[
              0.3859839460489116, 0.4980771749351177, 0.9468361018549569], 
             UndirectedEdge[130, 243] -> 
             RGBColor[
              0.273975068886134, 0.40529554679496227`, 0.9389138469120482], 
             UndirectedEdge[12, 203] -> 
             RGBColor[
              0.2750809093421313, 0.40162085458666436`, 0.9391539291782056], 
             UndirectedEdge[182, 395] -> 
             RGBColor[
              0.37529774905003455`, 0.4994857800389728, 0.9451346186000673], 
             UndirectedEdge[99, 382] -> 
             RGBColor[
              0.3265745935235537, 0.451468118377806, 0.9422429786108073], 
             UndirectedEdge[17, 31] -> 
             RGBColor[
              0.3331654956688167, 0.45612762875647406`, 0.9427013613381552], 
             UndirectedEdge[77, 78] -> 
             RGBColor[
              0.3973813643555334, 0.5186134976618173, 0.9465417670395594], 
             UndirectedEdge[243, 344] -> 
             RGBColor[
              0.23749506463587472`, 0.3669527493620798, 0.936836364637326], 
             UndirectedEdge[305, 313] -> 
             RGBColor[
              0.314740323102191, 0.44131310609654534`, 0.9414854222363085], 
             UndirectedEdge[189, 280] -> 
             RGBColor[
              0.2678830147581119, 0.3976922830201636, 0.9386108560298796], 
             UndirectedEdge[104, 208] -> 
             RGBColor[
              0.3979322143471574, 0.5190906162380364, 0.946576866713928], 
             UndirectedEdge[191, 335] -> 
             RGBColor[
              0.3884096364820065, 0.5108426379099226, 0.9459700964728457], 
             UndirectedEdge[225, 355] -> 
             RGBColor[
              0.44719022552692783`, 0.5607996658401883, 0.9499796240430147], 
             UndirectedEdge[308, 348] -> 
             RGBColor[
              0.26136605624064674`, 0.392042675046979, 0.9381957822952502], 
             UndirectedEdge[132, 149] -> 
             RGBColor[
              0.29942157543788966`, 0.4283273902896075, 0.9404989773171579], 
             UndirectedEdge[128, 224] -> 
             RGBColor[
              0.5982210153929101, 0.6821210691281095, 0.9630076228929167], 
             UndirectedEdge[192, 225] -> 
             RGBColor[
              0.43244386162762016`, 0.5488279033106072, 0.9488187362591505], 
             UndirectedEdge[84, 252] -> 
             RGBColor[
              0.6296463008546371, 0.7025944248592195, 0.9599152525615687], 
             UndirectedEdge[30, 211] -> 
             RGBColor[
              0.6256051711319983, 0.7069334869735668, 0.9636690772202136], 
             UndirectedEdge[138, 242] -> 
             RGBColor[
              0.3599611185897649, 0.47266769470205605`, 0.9451773527208086], 
             UndirectedEdge[27, 41] -> 
             RGBColor[
              0.44577014320350095`, 0.5601078965680646, 0.9497404218125858], 
             UndirectedEdge[102, 139] -> 
             RGBColor[
              0.5420656378750714, 0.6343394939727897, 0.9590665636408242], 
             UndirectedEdge[203, 329] -> 
             RGBColor[
              0.2907684938955194, 0.4181095006025842, 0.9400473139108195], 
             UndirectedEdge[195, 312] -> 
             RGBColor[
              0.37417698623631446`, 0.4839132474219179, 0.946323378788934], 
             UndirectedEdge[51, 87] -> 
             RGBColor[
              0.42906098198234666`, 0.5433538709429852, 0.9492892753246022], 
             UndirectedEdge[83, 366] -> 
             RGBColor[
              0.4472021502912591, 0.5502061967156042, 0.9515139797301608], 
             UndirectedEdge[8, 302] -> 
             RGBColor[
              0.4010524801336296, 0.51986303249532, 0.9471528201989681], 
             UndirectedEdge[146, 344] -> 
             RGBColor[
              0.42970231351544724`, 0.5289997788049756, 0.9509627259142718], 
             UndirectedEdge[67, 320] -> 
             RGBColor[
              0.7167846583696997, 0.7764320806857257, 0.9477427193751897], 
             UndirectedEdge[90, 166] -> 
             RGBColor[
              0.5210456998236275, 0.6001623012317965, 0.9600646903373018], 
             UndirectedEdge[12, 341] -> 
             RGBColor[
              0.30687118614199876`, 0.42915599452493874`, 0.9411795775048553],
              UndirectedEdge[3, 13] -> 
             RGBColor[
              0.4102837773362856, 0.5274024875306194, 0.947875438987146], 
             UndirectedEdge[153, 341] -> 
             RGBColor[
              0.3955322906022421, 0.5170119229138654, 0.9464239456950714], 
             UndirectedEdge[192, 351] -> 
             RGBColor[
              0.3786987893869328, 0.5013174995238967, 0.9454292659912409], 
             UndirectedEdge[12, 150] -> 
             RGBColor[
              0.30608436622863117`, 0.42847449066269844`, 0.941129442035733], 
             UndirectedEdge[99, 393] -> 
             RGBColor[
              0.4707995265516287, 0.580006050617398, 0.9518273785884497], 
             UndirectedEdge[4, 190] -> 
             RGBColor[
              0.30660330036976663`, 0.4377264833259201, 0.9408402047564229], 
             UndirectedEdge[373, 390] -> 
             RGBColor[
              0.5222442324253528, 0.6177035277167222, 0.9575782501638477], 
             UndirectedEdge[23, 308] -> 
             RGBColor[
              0.4616509575517287, 0.5631939137355845, 0.9526849353580716], 
             UndirectedEdge[37, 187] -> 
             RGBColor[
              0.3240505685739017, 0.44828416598336035`, 0.9421186831780023], 
             UndirectedEdge[17, 292] -> 
             RGBColor[
              0.24931794369162338`, 0.37937934486349945`, 0.9375096601091687],
              UndirectedEdge[309, 385] -> 
             RGBColor[
              0.529665557787836, 0.621811175846179, 0.9585958386435465], 
             UndirectedEdge[140, 380] -> 
             RGBColor[
              0.3085378228762, 0.43847537993992913`, 0.9409974014637965], 
             UndirectedEdge[119, 354] -> 
             RGBColor[
              0.26434499337042083`, 0.3922212518623247, 0.9384735329300531], 
             UndirectedEdge[36, 305] -> 
             RGBColor[
              0.27737098670375826`, 0.408864871734911, 0.9391072394079517], 
             UndirectedEdge[91, 351] -> 
             RGBColor[
              0.4278952157089251, 0.5412573746858393, 0.9493021888837556], 
             UndirectedEdge[130, 275] -> 
             RGBColor[
              0.31102854565758864`, 0.43934729801926053`, 0.9412031736694839],
              UndirectedEdge[46, 102] -> 
             RGBColor[
              0.3192511065558459, 0.4502920527652725, 0.9415871370654354], 
             UndirectedEdge[111, 271] -> 
             RGBColor[
              0.33689700673689643`, 0.4662249871247607, 0.9426877572563173], 
             UndirectedEdge[104, 351] -> 
             RGBColor[
              0.371719117186075, 0.4954270254679766, 0.9449417095525213], 
             UndirectedEdge[174, 203] -> 
             RGBColor[
              0.36635978520126117`, 0.49174416498829043`, 0.9445650994471545],
              UndirectedEdge[294, 313] -> 
             RGBColor[
              0.3304528551949676, 0.4578279735581279, 0.942380227694384], 
             UndirectedEdge[206, 266] -> 
             RGBColor[
              0.3332785871881956, 0.4630908939787306, 0.9424571947623167], 
             UndirectedEdge[167, 358] -> 
             RGBColor[
              0.40362046713359295`, 0.5240174949017489, 0.9469393171515554], 
             UndirectedEdge[315, 322] -> 
             RGBColor[
              0.3518149300873011, 0.4763572512808052, 0.9437404291113135], 
             UndirectedEdge[176, 347] -> 
             RGBColor[
              0.3695012227831382, 0.4808573284431097, 0.9458879192019323], 
             UndirectedEdge[92, 186] -> 
             RGBColor[
              0.3448828339839112, 0.47253473622348113`, 0.9432188386877975], 
             UndirectedEdge[149, 210] -> 
             RGBColor[
              0.44705812295963065`, 0.5509920885349768, 0.9513573934090753], 
             UndirectedEdge[171, 374] -> 
             RGBColor[
              0.4575849058445604, 0.570276881515226, 0.9505110332836431], 
             UndirectedEdge[228, 282] -> 
             RGBColor[
              0.2524300285242019, 0.3826503433401143, 0.9376868887364671], 
             UndirectedEdge[164, 210] -> 
             RGBColor[
              0.5299071464437953, 0.6281900103778608, 0.9564373385199806], 
             UndirectedEdge[196, 214] -> 
             RGBColor[
              0.4282177080250198, 0.5439772870409302, 0.9488782871781368], 
             UndirectedEdge[204, 307] -> 
             RGBColor[
              0.38750381046560417`, 0.5100580569426543, 0.9459123780400711], 
             UndirectedEdge[127, 255] -> 
             RGBColor[
              0.6856201654422198, 0.7496302752517408, 0.9423798212093482], 
             UndirectedEdge[68, 334] -> 
             RGBColor[
              0.3966085110360473, 0.5179440909612156, 0.9464925215094491], 
             UndirectedEdge[16, 269] -> 
             RGBColor[
              0.33045735806794896`, 0.4486340822393239, 0.9428620936232313], 
             UndirectedEdge[68, 337] -> 
             RGBColor[
              0.38043320453933016`, 0.5039338534683028, 0.9454618452827401], 
             UndirectedEdge[23, 374] -> 
             RGBColor[
              0.5692494698880491, 0.6607972880332942, 0.9594951625302818], 
             UndirectedEdge[22, 116] -> 
             RGBColor[
              0.3349076111940805, 0.46095315981507634`, 0.9426909304938345], 
             UndirectedEdge[192, 322] -> 
             RGBColor[
              0.44203671781271214`, 0.5571367531871627, 0.9494299845726348], 
             UndirectedEdge[70, 95] -> 
             RGBColor[
              0.6700272922145494, 0.7345119353530646, 0.9027917314762526], 
             UndirectedEdge[71, 273] -> 
             RGBColor[
              0.28265405342436917`, 0.41441770982404985`, 0.9394081022420937],
              UndirectedEdge[135, 215] -> 
             RGBColor[
              0.4180808530867883, 0.5349298162716247, 0.9483062692510507], 
             UndirectedEdge[161, 283] -> 
             RGBColor[
              0.4863182023783312, 0.590591107358255, 0.9536054578465687], 
             UndirectedEdge[18, 384] -> 
             RGBColor[
              0.3315674610681554, 0.4543383081146325, 0.9426143717352466], 
             UndirectedEdge[71, 303] -> 
             RGBColor[
              0.4160904991138816, 0.5295150666617456, 0.9485693773160918], 
             UndirectedEdge[32, 353] -> 
             RGBColor[
              0.276042861312407, 0.40746892774058735`, 0.9390316046316998], 
             UndirectedEdge[188, 281] -> 
             RGBColor[
              0.5136872143856079, 0.6160734478403522, 0.9548584856961538], 
             UndirectedEdge[54, 198] -> 
             RGBColor[
              0.3341486175380005, 0.45675442478677325`, 0.9427722336332957], 
             UndirectedEdge[271, 385] -> 
             RGBColor[
              0.5631569845660451, 0.6519509848499321, 0.9606884632934443], 
             UndirectedEdge[150, 206] -> 
             RGBColor[
              0.3893231380115032, 0.5116338670208508, 0.9460283039825275], 
             UndirectedEdge[317, 346] -> 
             RGBColor[
              0.502482544733309, 0.5940964109876579, 0.9569122405582102], 
             UndirectedEdge[146, 243] -> 
             RGBColor[
              0.47977696636469847`, 0.5816314138659038, 0.9538144033152263], 
             UndirectedEdge[91, 316] -> 
             RGBColor[
              0.44829542446164317`, 0.5598861336808404, 0.9505669539359168], 
             UndirectedEdge[196, 386] -> 
             RGBColor[
              0.43326964680715124`, 0.5483530224961863, 0.9492001922500801], 
             UndirectedEdge[151, 306] -> 
             RGBColor[
              0.43413080612885535`, 0.5500023833767786, 0.9490054336715383], 
             UndirectedEdge[27, 376] -> 
             RGBColor[
              0.34147624583089997`, 0.46103763042034296`, 0.9434147795638154],
              UndirectedEdge[280, 387] -> 
             RGBColor[
              0.3950522562423028, 0.5161872244908445, 0.9465063432569352], 
             UndirectedEdge[308, 354] -> 
             RGBColor[
              0.298274227391894, 0.4278830280565795, 0.9404057526137723], 
             UndirectedEdge[327, 349] -> 
             RGBColor[
              0.3149101730539251, 0.4423596954036815, 0.9414633107824609], 
             UndirectedEdge[60, 108] -> 
             RGBColor[
              0.2896358215334438, 0.41657588880398044`, 0.9399953725158705], 
             UndirectedEdge[353, 391] -> 
             RGBColor[
              0.34844997082082196`, 0.47066062222420074`, 0.9436278821105035],
              UndirectedEdge[140, 195] -> 
             RGBColor[
              0.45379584793513206`, 0.5644499064910078, 0.9509728120201575], 
             UndirectedEdge[17, 18] -> 
             RGBColor[
              0.33375866413599087`, 0.45664140146922627`, 0.9427391575083653],
              UndirectedEdge[87, 205] -> 
             RGBColor[
              0.2605911915552701, 0.39122824313338955`, 0.9381516548977277], 
             UndirectedEdge[221, 256] -> 
             RGBColor[
              0.370997232073375, 0.49576088838405835`, 0.9448605934611123], 
             UndirectedEdge[194, 316] -> 
             RGBColor[
              0.3656366482661808, 0.491117820121043, 0.944519021801096], 
             UndirectedEdge[16, 37] -> 
             RGBColor[
              0.444310385742042, 0.5586569270701789, 0.9496989657576089], 
             UndirectedEdge[252, 288] -> 
             RGBColor[
              0.34336321287292354`, 0.4718256898788172, 0.9430997781934634], 
             UndirectedEdge[60, 353] -> 
             RGBColor[
              0.30663225817045786`, 0.4344402213458063, 0.9409632944383737], 
             UndirectedEdge[206, 286] -> 
             RGBColor[
              0.35722701191687484`, 0.483833815795887, 0.9439831672092677], 
             UndirectedEdge[220, 396] -> 
             RGBColor[
              0.3269402558281526, 0.4547855365349702, 0.9421564079688002], 
             UndirectedEdge[133, 320] -> 
             RGBColor[
              0.627200006539014, 0.6974670898117482, 0.9419852373292792], 
             UndirectedEdge[28, 231] -> 
             RGBColor[
              0.4092440623899087, 0.5287670717727795, 0.9473311628579596], 
             UndirectedEdge[239, 269] -> 
             RGBColor[
              0.29744271696920643`, 0.42064258967913726`, 0.9405915069131147],
              UndirectedEdge[212, 239] -> 
             RGBColor[
              0.3129386567940418, 0.4369298049343706, 0.9414739777619504], 
             UndirectedEdge[77, 182] -> 
             RGBColor[
              0.4050665543496785, 0.5252700229658653, 0.9470314605502397], 
             UndirectedEdge[280, 336] -> 
             RGBColor[
              0.25212802212089036`, 0.3811327868342154, 0.9377136325066127], 
             UndirectedEdge[199, 400] -> 
             RGBColor[
              0.23121271414398153`, 0.3603496006710727, 0.9364785940707174], 
             UndirectedEdge[73, 336] -> 
             RGBColor[
              0.31486353936717904`, 0.43547113869417114`, 0.9417110841907066],
              UndirectedEdge[305, 340] -> 
             RGBColor[
              0.29218316240031245`, 0.42177522725244043`, 0.9400480999028988],
              UndirectedEdge[259, 350] -> 
             RGBColor[
              0.29951907685979207`, 0.4261686180853538, 0.9405873254055681], 
             UndirectedEdge[247, 393] -> 
             RGBColor[
              0.5166830851005155, 0.6185056306491519, 0.9550943316130673], 
             UndirectedEdge[30, 216] -> 
             RGBColor[
              0.4086303400502883, 0.5141841550491404, 0.9488263015157363], 
             UndirectedEdge[291, 387] -> 
             RGBColor[
              0.7039717676183253, 0.7668690240620983, 0.9692378522529503], 
             UndirectedEdge[45, 338] -> 
             RGBColor[
              0.5092956838947738, 0.6118355452873794, 0.954698626364433], 
             UndirectedEdge[219, 248] -> 
             RGBColor[
              0.32960580130796513`, 0.45705607997127173`, 0.9423276535209995],
              UndirectedEdge[158, 354] -> 
             RGBColor[
              0.3911360808007607, 0.5132041469437515, 0.9461438230939366], 
             UndirectedEdge[191, 327] -> 
             RGBColor[
              0.3259315659815056, 0.4519058720062362, 0.9421655841939712], 
             UndirectedEdge[165, 192] -> 
             RGBColor[
              0.4031844267673381, 0.5234848514565871, 0.9469543509429557], 
             UndirectedEdge[143, 354] -> 
             RGBColor[
              0.5212505406192238, 0.6182444087043517, 0.956921723467509], 
             UndirectedEdge[115, 161] -> 
             RGBColor[
              0.2663028007303153, 0.39497553265415475`, 0.9385595248448224], 
             UndirectedEdge[296, 330] -> 
             RGBColor[
              0.5171947040875179, 0.6013910593741824, 0.9590433114714677], 
             UndirectedEdge[45, 262] -> 
             RGBColor[
              0.49854471319412985`, 0.6025235948259807, 0.9540135840180981], 
             UndirectedEdge[37, 208] -> 
             RGBColor[
              0.38192578526390225`, 0.5052266518726386, 0.9455569512066726], 
             UndirectedEdge[306, 348] -> 
             RGBColor[
              0.3327708960578125, 0.45877880722188047`, 0.9425666308430436], 
             UndirectedEdge[189, 263] -> 
             RGBColor[
              0.3106036672703982, 0.434694765023878, 0.9413329782315727], 
             UndirectedEdge[2, 50] -> 
             RGBColor[
              0.41274566904870624`, 0.5319212861546361, 0.9475207669484871], 
             UndirectedEdge[241, 331] -> 
             RGBColor[
              0.37359351124979523`, 0.49800965491388793`, 0.9450260260744343],
              UndirectedEdge[135, 213] -> 
             RGBColor[
              0.25560600410959905`, 0.38462853228353916`, 0.9379175507464009],
              UndirectedEdge[49, 349] -> 
             RGBColor[
              0.3884571134774092, 0.5108837600970773, 0.9459731216650105], 
             UndirectedEdge[256, 319] -> 
             RGBColor[
              0.4956941457530713, 0.5997281150880465, 0.9539221506649449], 
             UndirectedEdge[64, 332] -> 
             RGBColor[
              0.3254173979080258, 0.4552413561199516, 0.9419943871278126], 
             UndirectedEdge[213, 350] -> 
             RGBColor[
              0.20671049598955793`, 0.3345962158604149, 0.9350832289946064], 
             UndirectedEdge[333, 345] -> 
             RGBColor[
              0.28659257838012414`, 0.41461816106348387`, 0.9397766283886093],
              UndirectedEdge[53, 201] -> 
             RGBColor[
              0.3058090270585438, 0.43699981970507196`, 0.9407910115064165], 
             UndirectedEdge[9, 384] -> 
             RGBColor[
              0.27647720267311526`, 0.40662189520974557`, 0.9391040691847173],
              UndirectedEdge[24, 33] -> 
             RGBColor[
              0.36578867316485175`, 0.48872176661623, 0.9446212612647142], 
             UndirectedEdge[20, 359] -> 
             RGBColor[
              0.30664293266644405`, 0.43645047013086136`, 0.940890708083155], 
             UndirectedEdge[35, 291] -> 
             RGBColor[
              0.7054758466596971, 0.7680901031858727, 0.9693562588647102], 
             UndirectedEdge[316, 351] -> 
             RGBColor[
              0.31877246469154785`, 0.4495672962533488, 0.9415679956744565], 
             UndirectedEdge[195, 263] -> 
             RGBColor[
              0.48598356295597667`, 0.5923292874404669, 0.953023784758807], 
             UndirectedEdge[67, 200] -> 
             RGBColor[
              0.3893760729236152, 0.5112648603627599, 0.946146302957521], 
             UndirectedEdge[232, 277] -> 
             RGBColor[
              0.2870391499656852, 0.4157701230956633, 0.9397770671266366], 
             UndirectedEdge[88, 120] -> 
             RGBColor[
              0.42086019489974025`, 0.5389496805988737, 0.9480378173603216], 
             UndirectedEdge[247, 271] -> 
             RGBColor[
              0.431285157924702, 0.5467368073886346, 0.9490453800329597], 
             UndirectedEdge[202, 269] -> 
             RGBColor[
              0.20488596435198847`, 0.3326785174273421, 0.9349793246169995], 
             UndirectedEdge[207, 291] -> 
             RGBColor[
              0.6247751721250895, 0.6986818303701563, 0.9640785302921195], 
             UndirectedEdge[72, 397] -> 
             RGBColor[
              0.26849264054666444`, 0.39843283023692144`, 0.9386419194478224],
              UndirectedEdge[200, 298] -> 
             RGBColor[
              0.4076470016585576, 0.5260980234057457, 0.9475846573961529], 
             UndirectedEdge[233, 389] -> 
             RGBColor[
              0.6076636999449531, 0.19451847619189505`, 0.42082460081364337`],
              UndirectedEdge[44, 311] -> 
             RGBColor[
              0.419724966208563, 0.5233910169875019, 0.9496815291305626], 
             UndirectedEdge[137, 258] -> 
             RGBColor[
              0.33696384666503476`, 0.46171027411948007`, 0.9428594417568952],
              UndirectedEdge[46, 287] -> 
             RGBColor[
              0.3635077382141953, 0.4886249227047502, 0.9444071305001026], 
             UndirectedEdge[84, 274] -> 
             RGBColor[
              0.6903613497123844, 0.7551827485527146, 0.9637839617865747], 
             UndirectedEdge[270, 357] -> 
             RGBColor[
              0.22786066989748896`, 0.35682638963612856`, 0.9362877001097847],
              UndirectedEdge[44, 344] -> 
             RGBColor[
              0.4112077364415015, 0.5144388684787627, 0.9491964854954407], 
             UndirectedEdge[44, 383] -> 
             RGBColor[
              0.47986554173102886`, 0.5851241881738161, 0.9531605769201147], 
             UndirectedEdge[193, 364] -> 
             RGBColor[
              0.22839892224364028`, 0.35739212697910344`, 0.936318352784625], 
             UndirectedEdge[43, 375] -> 
             RGBColor[
              0.31867425744211975`, 0.4463666749925293, 0.9416758138751314], 
             UndirectedEdge[184, 252] -> 
             RGBColor[
              0.26959277531605996`, 0.40014516649302123`, 0.9386842117015235],
              UndirectedEdge[16, 78] -> 
             RGBColor[
              0.43825291700482405`, 0.5534102521072319, 0.9493129892060828], 
             UndirectedEdge[345, 353] -> 
             RGBColor[
              0.23516236136063684`, 0.36450093031787467`, 0.9367035206367265],
              UndirectedEdge[167, 203] -> 
             RGBColor[
              0.3853987245344502, 0.508234737313784, 0.9457782438259923], 
             UndirectedEdge[329, 340] -> 
             RGBColor[
              0.2789855877771399, 0.4079037395489251, 0.9392965175521713], 
             UndirectedEdge[193, 380] -> 
             RGBColor[
              0.2737066423730491, 0.40501341351048614`, 0.9388985604192295], 
             UndirectedEdge[115, 253] -> 
             RGBColor[
              0.24981832547235688`, 0.37990527784108763`, 0.937538156111333], 
             UndirectedEdge[113, 270] -> 
             RGBColor[
              0.5514713692523893, 0.6291874234316132, 0.9622449259679009], 
             UndirectedEdge[121, 202] -> 
             RGBColor[
              0.3242404077697107, 0.4474664120661336, 0.9421667420978503], 
             UndirectedEdge[17, 111] -> 
             RGBColor[
              0.27239601356474497`, 0.40349215772090724`, 0.9388291836748268],
              UndirectedEdge[73, 280] -> 
             RGBColor[
              0.38446193842722615`, 0.5074233402719454, 0.9457185526436074], 
             UndirectedEdge[127, 242] -> 
             RGBColor[
              0.7512921079913861, 0.8043241057364834, 0.9471689040935023], 
             UndirectedEdge[19, 211] -> 
             RGBColor[
              0.502806273552557, 0.6049470656741841, 0.9546353902339966], 
             UndirectedEdge[213, 345] -> 
             RGBColor[
              0.2047951494777156, 0.3325830652364857, 0.9349741528442581], 
             UndirectedEdge[102, 350] -> 
             RGBColor[
              0.28121961595101913`, 0.4103185448038231, 0.9394212999380389], 
             UndirectedEdge[81, 227] -> 
             RGBColor[
              0.3815982947135955, 0.5049429960181165, 0.9455360837983955], 
             UndirectedEdge[144, 218] -> 
             RGBColor[
              0.4169830952952043, 0.5353597999506272, 0.9478548001996014], 
             UndirectedEdge[130, 354] -> 
             RGBColor[
              0.30052998567418926`, 0.43025397303460755`, 0.9405342147108537],
              UndirectedEdge[104, 327] -> 
             RGBColor[
              0.3508321916308309, 0.47347354240184647`, 0.9437522300415875], 
             UndirectedEdge[10, 253] -> 
             RGBColor[
              0.24396709336541883`, 0.3737552619071528, 0.937204937098965], 
             UndirectedEdge[40, 41] -> 
             RGBColor[
              0.3615201007140193, 0.48676169331577757`, 0.9442856660457731], 
             UndirectedEdge[5, 113] -> 
             RGBColor[
              0.6573693634908911, 0.7290024352647109, 0.9686963833664817], 
             UndirectedEdge[271, 337] -> 
             RGBColor[
              0.3604115866939054, 0.4865921344063686, 0.9441860854980513], 
             UndirectedEdge[325, 376] -> 
             RGBColor[
              0.2466487894338735, 0.3765738945044498, 0.9373576557228498], 
             UndirectedEdge[52, 337] -> 
             RGBColor[
              0.30157875823283053`, 0.42981690549625634`, 0.9406503055115585],
              UndirectedEdge[246, 260] -> 
             RGBColor[
              0.7135109219758913, 0.7735284651811034, 0.940890995958088], 
             UndirectedEdge[22, 290] -> 
             RGBColor[
              0.500477884111856, 0.6038869193466092, 0.9542227193198749], 
             UndirectedEdge[24, 107] -> 
             RGBColor[
              0.41150242245552077`, 0.5259196984344673, 0.9481964047634021], 
             UndirectedEdge[314, 369] -> 
             RGBColor[
              0.2947252186357907, 0.4271052698173331, 0.9400955372431955], 
             UndirectedEdge[187, 208] -> 
             RGBColor[
              0.2929232335709941, 0.42132323290918905`, 0.9401352769164386], 
             UndirectedEdge[9, 174] -> 
             RGBColor[
              0.3472511498294629, 0.4751932254571783, 0.9433475140983663], 
             UndirectedEdge[6, 303] -> 
             RGBColor[
              0.6958064980189004, 0.7610620243253585, 0.9712206129224566], 
             UndirectedEdge[100, 198] -> 
             RGBColor[
              0.38989180040275173`, 0.5121264138023475, 0.9460645386472495], 
             UndirectedEdge[101, 123] -> 
             RGBColor[
              0.4134108731973387, 0.5314986382885859, 0.9478391285261374], 
             UndirectedEdge[210, 394] -> 
             RGBColor[
              0.435267092278153, 0.5385989676942197, 0.9506859116550319], 
             UndirectedEdge[213, 227] -> 
             RGBColor[
              0.28607242884284356`, 0.4110170181004443, 0.9398588443900017], 
             UndirectedEdge[32, 46] -> 
             RGBColor[
              0.3026607923696853, 0.4354460609560913, 0.9405474564277115], 
             UndirectedEdge[303, 391] -> 
             RGBColor[
              0.5001327118826571, 0.6049359923801525, 0.9538282567129803], 
             UndirectedEdge[248, 251] -> 
             RGBColor[
              0.2816617891852205, 0.40666388340432646`, 0.9395973129574189], 
             UndirectedEdge[239, 388] -> 
             RGBColor[
              0.42848145401941445`, 0.5455508321927143, 0.9485234372522124], 
             UndirectedEdge[205, 277] -> 
             RGBColor[
              0.22165210924249457`, 0.350300798742248, 0.9359341317652252], 
             UndirectedEdge[308, 378] -> 
             RGBColor[
              0.31297648506149905`, 0.4406173846930348, 0.9413425674717836], 
             UndirectedEdge[119, 130] -> 
             RGBColor[
              0.22419542798337366`, 0.35297398799463386`, 0.9360789700050153],
              UndirectedEdge[28, 254] -> 
             RGBColor[
              0.30015674244150264`, 0.42801038574374084`, 0.9405807436730824],
              UndirectedEdge[217, 314] -> 
             RGBColor[
              0.24702587914854346`, 0.37697023970343674`, 0.9373791304242459],
              UndirectedEdge[229, 307] -> 
             RGBColor[
              0.28222121709320724`, 0.41061290865076566`, 0.939506107738191], 
             UndirectedEdge[114, 155] -> 
             RGBColor[
              0.24376546266415636`, 0.3735433352560011, 0.9371934545288141], 
             UndirectedEdge[226, 288] -> 
             RGBColor[
              0.5044138907176686, 0.6063395028614156, 0.9547378261781974], 
             UndirectedEdge[217, 231] -> 
             RGBColor[
              0.3341792579165282, 0.45467296285965925`, 0.9428804441072562], 
             UndirectedEdge[151, 346] -> 
             RGBColor[
              0.6130284254737091, 0.6949750247402301, 0.9638741708268992], 
             UndirectedEdge[114, 180] -> 
             RGBColor[
              0.37253243043359985`, 0.49336117874649604`, 0.9452123725234796],
              UndirectedEdge[215, 345] -> 
             RGBColor[
              0.3672699984549048, 0.48288434922457124`, 0.9453628713489078], 
             UndirectedEdge[190, 252] -> 
             RGBColor[
              0.3217667543743566, 0.45311992299692405`, 0.941723670954933], 
             UndirectedEdge[275, 311] -> 
             RGBColor[
              0.2830657711743908, 0.40995664909511714`, 0.9396107350298835], 
             UndirectedEdge[75, 320] -> 
             RGBColor[
              0.9522689623481913, 0.9639228507884579, 0.9656803758828361], 
             UndirectedEdge[169, 393] -> 
             RGBColor[
              0.7232545184442413, 0.7828212132276569, 0.9739849395572832], 
             UndirectedEdge[80, 182] -> 
             RGBColor[
              0.323590808560348, 0.4474999411552292, 0.9421035211669542], 
             UndirectedEdge[239, 362] -> 
             RGBColor[
              0.3413245552388309, 0.4667651839697551, 0.9430905126852076], 
             UndirectedEdge[171, 342] -> 
             RGBColor[
              0.5461752876541663, 0.6421083524869706, 0.9575468573737991], 
             UndirectedEdge[107, 157] -> 
             RGBColor[
              0.4929853852277991, 0.5990238751660735, 0.9532958745271916], 
             UndirectedEdge[116, 286] -> 
             RGBColor[
              0.3146202997316797, 0.4433813102962671, 0.9413982409468153], 
             UndirectedEdge[37, 117] -> 
             RGBColor[
              0.3804955377940719, 0.5039878434005995, 0.9454658171026131], 
             UndirectedEdge[111, 222] -> 
             RGBColor[
              0.2810467213422021, 0.41258460008156683`, 0.9393218286851778], 
             UndirectedEdge[57, 72] -> 
             RGBColor[
              0.21424441028055485`, 0.34251483745800804`, 0.9355122742680513],
              UndirectedEdge[8, 323] -> 
             RGBColor[
              0.2818970875553924, 0.41362209070134714`, 0.9393649941556861], 
             UndirectedEdge[115, 356] -> 
             RGBColor[
              0.3106337381965235, 0.43337276254968127`, 0.9413842529798604], 
             UndirectedEdge[129, 391] -> 
             RGBColor[
              0.41674660510122874`, 0.5353866958704381, 0.947775703055865], 
             UndirectedEdge[271, 303] -> 
             RGBColor[
              0.4576752522831183, 0.5681614748489996, 0.9511229049309551], 
             UndirectedEdge[141, 196] -> 
             RGBColor[
              0.4630348941441733, 0.5741341836946843, 0.9510968074900205], 
             UndirectedEdge[8, 117] -> 
             RGBColor[
              0.3248180206782759, 0.4551111487069241, 0.941941954231575], 
             UndirectedEdge[278, 330] -> 
             RGBColor[
              0.2915854796371907, 0.4185304439843533, 0.9401098685940461], 
             UndirectedEdge[95, 276] -> 
             RGBColor[
              0.3535993963590901, 0.4806917575289933, 0.9437520187537001], 
             UndirectedEdge[114, 268] -> 
             RGBColor[
              0.22711053213546362`, 0.3560379472867588, 0.9362449808739667], 
             UndirectedEdge[95, 148] -> 
             RGBColor[
              0.3265185558969935, 0.4564434637649025, 0.9420554589994009], 
             UndirectedEdge[236, 366] -> 
             RGBColor[
              0.4377805283567223, 0.5403034746970732, 0.9509774322990294], 
             UndirectedEdge[108, 378] -> 
             RGBColor[
              0.29229123027322307`, 0.41887587038965335`, 0.9401645728126835],
              UndirectedEdge[33, 107] -> 
             RGBColor[
              0.49588466329765407`, 0.601535084108229, 0.9534806139620717], 
             UndirectedEdge[309, 362] -> 
             RGBColor[
              0.2848108214619965, 0.41668460977858784`, 0.9395309269911842], 
             UndirectedEdge[178, 278] -> 
             RGBColor[
              0.3203139370239202, 0.44872587418720844`, 0.9417459117422764], 
             UndirectedEdge[21, 232] -> 
             RGBColor[
              0.29022229908859665`, 0.4191158146471544, 0.9399583427601392], 
             UndirectedEdge[20, 140] -> 
             RGBColor[
              0.30646306464201434`, 0.4362946774885301, 0.9408792470516895], 
             UndirectedEdge[33, 150] -> 
             RGBColor[
              0.4366200706636234, 0.5526000928711616, 0.9490420227080852], 
             UndirectedEdge[38, 213] -> 
             RGBColor[
              0.30617003866385434`, 0.4284245575921632, 0.941139446316178], 
             UndirectedEdge[86, 262] -> 
             RGBColor[
              0.3739407203450661, 0.49831038998097504`, 0.94504814993096], 
             UndirectedEdge[17, 310] -> 
             RGBColor[
              0.24051345956242046`, 0.3701252738071711, 0.9370082577630776], 
             UndirectedEdge[222, 223] -> 
             RGBColor[
              0.26737106949177075`, 0.3983543247137409, 0.9385377589162809], 
             UndirectedEdge[19, 124] -> 
             RGBColor[
              0.46143647367386853`, 0.5713611984444187, 0.951378608044976], 
             UndirectedEdge[184, 274] -> 
             RGBColor[
              0.3303078241738072, 0.4527334901865163, 0.9425529209265295], 
             UndirectedEdge[195, 360] -> 
             RGBColor[
              0.4572694803862151, 0.5674585923302926, 0.951194148808328], 
             UndirectedEdge[186, 378] -> 
             RGBColor[
              0.3788354162008627, 0.5025499295166991, 0.9453600356226818], 
             UndirectedEdge[31, 169] -> 
             RGBColor[
              0.6720293250868572, 0.7406510944291208, 0.9701134443583237], 
             UndirectedEdge[4, 84] -> 
             RGBColor[
              0.6144828468500472, 0.6872009851882155, 0.9590317863630586], 
             UndirectedEdge[81, 383] -> 
             RGBColor[
              0.3517722988806836, 0.47910921752578706`, 0.943635597718015], 
             UndirectedEdge[327, 335] -> 
             RGBColor[
              0.3190764753288425, 0.4459683370297738, 0.9417287838793023], 
             UndirectedEdge[11, 214] -> 
             RGBColor[
              0.5598408789487807, 0.6489393003383648, 0.9605361818034381], 
             UndirectedEdge[15, 35] -> 
             RGBColor[
              0.46520578611072394`, 0.5767140403033469, 0.9510418500690315], 
             UndirectedEdge[151, 354] -> 
             RGBColor[
              0.405131289981032, 0.524884460047596, 0.9471576101458643], 
             UndirectedEdge[91, 192] -> 
             RGBColor[
              0.5082217491570281, 0.6116363369513884, 0.9544282242527011], 
             UndirectedEdge[44, 130] -> 
             RGBColor[
              0.44768774069176076`, 0.5527816659116453, 0.9512739677701629], 
             UndirectedEdge[195, 356] -> 
             RGBColor[
              0.4933037841157145, 0.5986696950840183, 0.953490222778088], 
             UndirectedEdge[226, 315] -> 
             RGBColor[
              0.45765815176223024`, 0.5630531405365373, 0.9518607068069436], 
             UndirectedEdge[65, 206] -> 
             RGBColor[
              0.32987561329241144`, 0.45972071283658483`, 0.9422558372530287],
              UndirectedEdge[287, 400] -> 
             RGBColor[
              0.35014668169757296`, 0.47458160516586856`, 0.9436462380973928],
              UndirectedEdge[247, 319] -> 
             RGBColor[
              0.5505734079037174, 0.6460193214424348, 0.9577623019684784], 
             UndirectedEdge[55, 72] -> 
             RGBColor[
              0.22078375342483658`, 0.3493881017209507, 0.9358846801860268], 
             UndirectedEdge[313, 329] -> 
             RGBColor[
              0.3015427484790184, 0.42744161839303, 0.9407338398855809], 
             UndirectedEdge[5, 357] -> 
             RGBColor[
              0.33375866413599087`, 0.45664140146922627`, 0.9427391575083653],
              UndirectedEdge[39, 328] -> 
             RGBColor[
              0.3288207818502756, 0.45773787826778656`, 0.9422277727046122], 
             UndirectedEdge[310, 384] -> 
             RGBColor[
              0.238322256494585, 0.3678221804525773, 0.9368834719899588], 
             UndirectedEdge[66, 344] -> 
             RGBColor[
              0.46617593193187196`, 0.5574932467216536, 0.9545980753326779], 
             UndirectedEdge[271, 391] -> 
             RGBColor[
              0.4059512146220775, 0.5260362712294993, 0.9470878303205226], 
             UndirectedEdge[203, 211] -> 
             RGBColor[
              0.49889843484375435`, 0.6015622921983037, 0.9543863862070376], 
             UndirectedEdge[100, 203] -> 
             RGBColor[
              0.3523048745359325, 0.4795705077903329, 0.9436695329678293], 
             UndirectedEdge[323, 377] -> 
             RGBColor[
              0.3184983232783968, 0.4459758692543676, 0.9416733332448688], 
             UndirectedEdge[351, 395] -> 
             RGBColor[
              0.31632959562911733`, 0.4474514058536406, 0.9414123382179428], 
             UndirectedEdge[179, 209] -> 
             RGBColor[
              0.39014955441938604`, 0.4978284495118868, 0.9474945094074949], 
             UndirectedEdge[283, 356] -> 
             RGBColor[
              0.5306491398445394, 0.6289883372537816, 0.9564301859816067], 
             UndirectedEdge[77, 80] -> 
             RGBColor[
              0.31234880012936234`, 0.4377626784920824, 0.9413871903306494], 
             UndirectedEdge[200, 398] -> 
             RGBColor[
              0.3540510311657668, 0.4810829408987113, 0.9437807965242166], 
             UndirectedEdge[280, 368] -> 
             RGBColor[
              0.31207576291819006`, 0.44414166331847393`, 0.9411275676602839],
              UndirectedEdge[3, 390] -> 
             RGBColor[
              0.626657339691944, 0.7063712689819168, 0.964720319021015], 
             UndirectedEdge[64, 380] -> 
             RGBColor[
              0.31381340596869706`, 0.443044824856134, 0.9413335569534356], 
             UndirectedEdge[139, 186] -> 
             RGBColor[
              0.5674714790871571, 0.6563447566959904, 0.9606854013773551], 
             UndirectedEdge[160, 245] -> 
             RGBColor[
              0.5607790628132859, 0.6386792732658458, 0.9628190889685019], 
             UndirectedEdge[64, 360] -> 
             RGBColor[
              0.3515415117074009, 0.4789093212759902, 0.9436208921634104], 
             UndirectedEdge[72, 337] -> 
             RGBColor[
              0.2868338064501416, 0.414319026288711, 0.9398106023207358], 
             UndirectedEdge[11, 141] -> 
             RGBColor[
              0.5946580650679343, 0.6790961969921189, 0.9627547021153218], 
             UndirectedEdge[62, 223] -> 
             RGBColor[
              0.28976652836236727`, 0.4218933719408429, 0.939813147167849], 
             UndirectedEdge[351, 399] -> 
             RGBColor[
              0.32184488327959837`, 0.4522284708100698, 0.9417637674700541], 
             UndirectedEdge[205, 232] -> 
             RGBColor[
              0.27858189666561484`, 0.40688101365645946`, 0.9392954390625826],
              UndirectedEdge[175, 379] -> 
             RGBColor[
              0.33052459086489605`, 0.46070552078336846`, 0.9422817125518594],
              UndirectedEdge[144, 339] -> 
             RGBColor[
              0.372756502875877, 0.49473362262049236`, 0.9451216427202698], 
             UndirectedEdge[66, 275] -> 
             RGBColor[
              0.5533040615525777, 0.64417663300688, 0.9597390794910681], 
             UndirectedEdge[311, 346] -> 
             RGBColor[
              0.48046434668366855`, 0.5709538888030983, 0.9556583367522882], 
             UndirectedEdge[81, 326] -> 
             RGBColor[
              0.3378037705835841, 0.46590579545021, 0.9427859797125248], 
             UndirectedEdge[145, 335] -> 
             RGBColor[
              0.646593252749072, 0.7186398491278841, 0.9684833801832431], 
             UndirectedEdge[24, 56] -> 
             RGBColor[
              0.35929064546381706`, 0.4830935016219623, 0.9442072126855847], 
             UndirectedEdge[310, 319] -> 
             RGBColor[
              0.4243027027135874, 0.5321406172648249, 0.9495837532800866], 
             UndirectedEdge[131, 303] -> 
             RGBColor[
              0.4476051139196027, 0.5594392271383933, 0.9504812446191055], 
             UndirectedEdge[146, 317] -> 
             RGBColor[
              0.46023774133214934`, 0.5610944494982745, 0.9527016733553157], 
             UndirectedEdge[159, 321] -> 
             RGBColor[
              0.26101520927846367`, 0.3916739126447424, 0.9381758020797856], 
             UndirectedEdge[339, 361] -> 
             RGBColor[
              0.4195674756294284, 0.5327368791121161, 0.9488067739696726], 
             UndirectedEdge[60, 297] -> 
             RGBColor[
              0.2980899532149981, 0.4254617172242019, 0.940476822808368], 
             UndirectedEdge[1, 368] -> 
             RGBColor[
              0.3789539786562095, 0.5020094315686962, 0.9454052297461639], 
             UndirectedEdge[15, 106] -> 
             RGBColor[
              0.39040027289400747`, 0.5124118599217647, 0.9461397559627304], 
             UndirectedEdge[144, 282] -> 
             RGBColor[
              0.363151979066178, 0.48463865913451726`, 0.944574679297927], 
             UndirectedEdge[333, 391] -> 
             RGBColor[
              0.3998801878403092, 0.5207778529698099, 0.9467009898623864], 
             UndirectedEdge[85, 238] -> 
             RGBColor[
              0.4224317840580344, 0.5403109121374203, 0.9481379576317863], 
             UndirectedEdge[130, 135] -> 
             RGBColor[
              0.2919177924260775, 0.42279452410451185`, 0.9399854533725476], 
             UndirectedEdge[194, 256] -> 
             RGBColor[
              0.39070932980683426`, 0.5128345166819411, 0.9461166308979647], 
             UndirectedEdge[129, 271] -> 
             RGBColor[
              0.37428914550169, 0.4986121783392851, 0.9450703512738399], 
             UndirectedEdge[12, 168] -> 
             RGBColor[
              0.26745953047271886`, 0.3950195992716193, 0.9386683016559674], 
             UndirectedEdge[32, 271] -> 
             RGBColor[
              0.3335441051136626, 0.46284457674588586`, 0.9424915528417188], 
             UndirectedEdge[227, 363] -> 
             RGBColor[
              0.31326537091930406`, 0.43959852435491303`, 0.9414074422129033],
              UndirectedEdge[351, 355] -> 
             RGBColor[
              0.3934451532862405, 0.5132892620534779, 0.9465901537751052], 
             UndirectedEdge[70, 285] -> 
             RGBColor[
              0.6230102475811825, 0.6891726597185538, 0.8999648421066593], 
             UndirectedEdge[19, 107] -> 
             RGBColor[
              0.45523820177659524`, 0.5663291620892453, 0.9508906573762045], 
             UndirectedEdge[88, 359] -> 
             RGBColor[
              0.3747258222847828, 0.4989904058207868, 0.9450981759323204], 
             UndirectedEdge[128, 130] -> 
             RGBColor[
              0.3446393124483661, 0.46845925488717377`, 0.9433448220085581], 
             UndirectedEdge[72, 297] -> 
             RGBColor[
              0.22387242602205973`, 0.35263449245378575`, 0.9360605755211571],
              UndirectedEdge[125, 184] -> 
             RGBColor[
              0.28035389851578135`, 0.40946591053884135`, 0.939369900956122], 
             UndirectedEdge[41, 63] -> 
             RGBColor[
              0.47144372654733235`, 0.5809508681083363, 0.9517615403388466], 
             UndirectedEdge[67, 133] -> 
             RGBColor[
              0.37901218414531357`, 0.5005020564750555, 0.9455513238903405], 
             UndirectedEdge[272, 308] -> 
             RGBColor[
              0.32531053305991664`, 0.45130051714198655`, 0.9421284821036724],
              UndirectedEdge[199, 287] -> 
             RGBColor[
              0.306354379340215, 0.42855311879594743`, 0.941152331263047], 
             UndirectedEdge[60, 333] -> 
             RGBColor[
              0.35806247518994516`, 0.48455745209141554`, 0.9440364021902565],
              UndirectedEdge[86, 325] -> 
             RGBColor[
              0.309939655841086, 0.4401293961022108, 0.9410706210960622], 
             UndirectedEdge[77, 377] -> 
             RGBColor[
              0.3843625516999597, 0.5073372564841092, 0.9457122198092303], 
             UndirectedEdge[62, 319] -> 
             RGBColor[
              0.4493271784774564, 0.5584429279360548, 0.9510088601544446], 
             UndirectedEdge[52, 199] -> 
             RGBColor[
              0.2166242549435063, 0.3450162050896367, 0.9356478029009416], 
             UndirectedEdge[57, 376] -> 
             RGBColor[
              0.21320391816834305`, 0.34142121427706323`, 0.935453019781531], 
             UndirectedEdge[11, 161] -> 
             RGBColor[
              0.5496248477768602, 0.6400906876099038, 0.959885225330845], 
             UndirectedEdge[155, 300] -> 
             RGBColor[
              0.4796983073962947, 0.571619601943415, 0.9553818518001107], 
             UndirectedEdge[81, 275] -> 
             RGBColor[
              0.3702426232118621, 0.4951072841159601, 0.9448125104517311], 
             UndirectedEdge[100, 266] -> 
             RGBColor[
              0.32726378059912475`, 0.4578811708242468, 0.9420739366051458], 
             UndirectedEdge[56, 266] -> 
             RGBColor[
              0.3740774921392811, 0.49842885483477384`, 0.9450568649087447], 
             UndirectedEdge[82, 257] -> 
             RGBColor[
              0.2759085460192564, 0.4033474818052314, 0.9391696928319114], 
             UndirectedEdge[32, 259] -> 
             RGBColor[
              0.33848423029971986`, 0.46712346488413725`, 0.9428063332501931],
              UndirectedEdge[261, 355] -> 
             RGBColor[
              0.44103993619291704`, 0.5554725943415981, 0.949587733045139], 
             UndirectedEdge[74, 179] -> 
             RGBColor[
              0.2420321977471775, 0.37172156393291333`, 0.9370947476559277], 
             UndirectedEdge[100, 174] -> 
             RGBColor[
              0.3576023461899317, 0.48415891147835977`, 0.9440070831772518], 
             UndirectedEdge[208, 388] -> 
             RGBColor[
              0.3991114946400172, 0.5201120495553606, 0.9466520094113926], 
             UndirectedEdge[249, 299] -> 
             RGBColor[
              0.437521433141407, 0.5533808077456224, 0.9490994567281261], 
             UndirectedEdge[58, 181] -> 
             RGBColor[
              0.35312837658012186`, 0.48028378387059345`, 0.9437220057898907],
              UndirectedEdge[271, 345] -> 
             RGBColor[
              0.2926636051618924, 0.4198765793231732, 0.9401634688467455], 
             UndirectedEdge[20, 89] -> 
             RGBColor[
              0.27577013272146317`, 0.407182272699514, 0.9390160731419113], 
             UndirectedEdge[174, 358] -> 
             RGBColor[
              0.38458152780040394`, 0.5075269225762553, 0.9457261727727175], 
             UndirectedEdge[185, 274] -> 
             RGBColor[
              0.4537105871343635, 0.5669132143126421, 0.9502663553929589], 
             UndirectedEdge[106, 314] -> 
             RGBColor[
              0.30262690151301574`, 0.4342057988319543, 0.9405896341901163], 
             UndirectedEdge[73, 387] -> 
             RGBColor[
              0.45778777348859145`, 0.5705255763508003, 0.9505037949410291], 
             UndirectedEdge[191, 261] -> 
             RGBColor[
              0.3944132744434262, 0.5160426873604866, 0.9463526429749387], 
             UndirectedEdge[135, 227] -> 
             RGBColor[
              0.3539215892982575, 0.4809708248590121, 0.9437725486028798], 
             UndirectedEdge[102, 345] -> 
             RGBColor[
              0.27930426943917674`, 0.40830539417989387`, 0.9393122237876907],
              UndirectedEdge[72, 108] -> 
             RGBColor[
              0.2154182943405054, 0.3437486640335643, 0.9355791252286596], 
             UndirectedEdge[7, 273] -> 
             RGBColor[
              0.4693236450201436, 0.5731162952111779, 0.9528277506494279], 
             UndirectedEdge[111, 385] -> 
             RGBColor[
              0.5365602362804027, 0.6289142182763464, 0.9589937420112642], 
             UndirectedEdge[25, 187] -> 
             RGBColor[
              0.404952784325676, 0.5150575152207495, 0.9481855238085893], 
             UndirectedEdge[290, 338] -> 
             RGBColor[
              0.5150243045671562, 0.6164862976206398, 0.955149604368392], 
             UndirectedEdge[133, 200] -> 
             RGBColor[
              0.29979142109292956`, 0.4322998694887824, 0.9403888209116105], 
             UndirectedEdge[64, 88] -> 
             RGBColor[
              0.3798215373528502, 0.5034040580946604, 0.9454228703904937], 
             UndirectedEdge[23, 92] -> 
             RGBColor[
              0.48480595667372467`, 0.5875312859245407, 0.9540035783033178], 
             UndirectedEdge[38, 350] -> 
             RGBColor[
              0.3251236909992271, 0.4483460479276068, 0.9422188287772615], 
             UndirectedEdge[135, 224] -> 
             RGBColor[
              0.5454994953706215, 0.6364563383454476, 0.9596482542569063], 
             UndirectedEdge[329, 358] -> 
             RGBColor[
              0.3089902364946622, 0.4338922581905491, 0.9412083872363826], 
             UndirectedEdge[4, 185] -> 
             RGBColor[
              0.3778320842720263, 0.49893145094814306`, 0.9455141799694428], 
             UndirectedEdge[111, 199] -> 
             RGBColor[
              0.2488603351189388, 0.37875466742616337`, 0.9374888616052544], 
             UndirectedEdge[138, 264] -> 
             RGBColor[
              0.21212863977292828`, 0.34029102850689436`, 0.9353917842676439],
              UndirectedEdge[275, 344] -> 
             RGBColor[
              0.2745485414073293, 0.401004500586378, 0.9391256913947617], 
             UndirectedEdge[300, 371] -> 
             RGBColor[
              0.4701910468970021, 0.561626868363527, 0.9548404273794074], 
             UndirectedEdge[69, 273] -> 
             RGBColor[
              0.29702240938948443`, 0.42949064268899195`, 0.9402274250936254],
              UndirectedEdge[65, 174] -> 
             RGBColor[
              0.3379157173686692, 0.4666846468800585, 0.9427681455751831], 
             UndirectedEdge[217, 254] -> 
             RGBColor[
              0.22509193796812216`, 0.35391627683062055`, 0.9361300249223791],
              UndirectedEdge[102, 378] -> 
             RGBColor[
              0.35342957498877703`, 0.4805446667934984, 0.943741197886151], 
             UndirectedEdge[246, 326] -> 
             RGBColor[
              0.37570181546045467`, 0.498696241136008, 0.9452104625342559], 
             UndirectedEdge[120, 242] -> 
             RGBColor[
              0.48465882636903135`, 0.5920209431815809, 0.95270753451897], 
             UndirectedEdge[25, 117] -> 
             RGBColor[
              0.4613977535458462, 0.5707611926379887, 0.9515326577332002], 
             UndirectedEdge[44, 227] -> 
             RGBColor[
              0.5096915375639408, 0.6109579666661455, 0.9550610630004952], 
             UndirectedEdge[118, 206] -> 
             RGBColor[
              0.27824440309169435`, 0.4054530373078299, 0.9393155162136285], 
             UndirectedEdge[151, 158] -> 
             RGBColor[
              0.45558781972055623`, 0.5685873700890491, 0.9503726556039094], 
             UndirectedEdge[151, 308] -> 
             RGBColor[
              0.3627259663116896, 0.48326625120187716`, 0.9446345851237452], 
             UndirectedEdge[298, 390] -> 
             RGBColor[
              0.6199803661547327, 0.7009506010701787, 0.9641946832056056], 
             UndirectedEdge[62, 111] -> 
             RGBColor[
              0.3034421802127986, 0.43612364730866887`, 0.9405972169367458], 
             UndirectedEdge[131, 201] -> 
             RGBColor[
              0.3136205768786666, 0.44376579153935247`, 0.9412887565534724], 
             UndirectedEdge[291, 368] -> 
             RGBColor[
              0.6209952742942125, 0.6948234628897277, 0.9638590766562989], 
             UndirectedEdge[35, 73] -> 
             RGBColor[
              0.4592918525299634, 0.5717466554745746, 0.950622201552789], 
             UndirectedEdge[273, 293] -> 
             RGBColor[
              0.26131911549122355`, 0.3919933373431198, 0.9381931090890132], 
             UndirectedEdge[4, 274] -> 
             RGBColor[
              0.36018479530391384`, 0.48413608115363815`, 0.9442543702333712],
              UndirectedEdge[10, 337] -> 
             RGBColor[
              0.27254313100972855`, 0.3992986203196811, 0.9389967694955639], 
             UndirectedEdge[27, 265] -> 
             RGBColor[
              0.3831763074148249, 0.504867039081659, 0.9457895363813071], 
             UndirectedEdge[262, 325] -> 
             RGBColor[
              0.34304143306113943`, 0.4688004917865225, 0.9431798370697717], 
             UndirectedEdge[46, 337] -> 
             RGBColor[
              0.32952827394992806`, 0.45919361861657404`, 0.942241989084044], 
             UndirectedEdge[322, 327] -> 
             RGBColor[
              0.3408232588093649, 0.46480430785548354`, 0.9431144696927556], 
             UndirectedEdge[59, 299] -> 
             RGBColor[
              0.39451590555867194`, 0.5161315812741226, 0.9463591825388491], 
             UndirectedEdge[254, 369] -> 
             RGBColor[
              0.2727912774553694, 0.40405130694451696`, 0.9388464317413286], 
             UndirectedEdge[262, 376] -> 
             RGBColor[
              0.3106498539378536, 0.434754888383214, 0.9413351845577476], 
             UndirectedEdge[360, 389] -> 
             RGBColor[
              0.26904633045042303`, 0.3963249953873776, 0.9387719379514361], 
             UndirectedEdge[159, 381] -> 
             RGBColor[
              0.31009688050939577`, 0.43848385422448116`, 0.9411458768826799],
              UndirectedEdge[77, 302] -> 
             RGBColor[
              0.4471157100753671, 0.5604123148669498, 0.9500640691928556], 
             UndirectedEdge[67, 398] -> 
             RGBColor[
              0.4332717942181508, 0.5492851278849844, 0.9489432995029465], 
             UndirectedEdge[12, 100] -> 
             RGBColor[
              0.26632347033080184`, 0.39403560107673374`, 0.938595912908303], 
             UndirectedEdge[329, 339] -> 
             RGBColor[
              0.25206758714105876`, 0.3822693944663199, 0.9376662482358811], 
             UndirectedEdge[1, 113] -> 
             RGBColor[
              0.6685980100225064, 0.7386693436970213, 0.9694281041115115], 
             UndirectedEdge[232, 390] -> 
             RGBColor[
              0.5393954881261934, 0.6325590833576137, 0.9586711130108453], 
             UndirectedEdge[319, 384] -> 
             RGBColor[
              0.41608980876156726`, 0.5235083449936992, 0.9491160411194068], 
             UndirectedEdge[342, 374] -> 
             RGBColor[
              0.5596563102047983, 0.6533030387780245, 0.9585390060262295], 
             UndirectedEdge[200, 320] -> 
             RGBColor[
              0.6375638953173157, 0.7082298936994526, 0.9425802163964598], 
             UndirectedEdge[35, 231] -> 
             RGBColor[
              0.4645857934977169, 0.5762107023697589, 0.9509930419794279], 
             UndirectedEdge[96, 104] -> 
             RGBColor[
              0.5530083397830977, 0.6474872459523848, 0.9582106177511736], 
             UndirectedEdge[106, 197] -> 
             RGBColor[
              0.3906297248857402, 0.5125981393853478, 0.9461578192640299], 
             UndirectedEdge[41, 265] -> 
             RGBColor[
              0.36025116926711354`, 0.485427965910179, 0.9442134022770877], 
             UndirectedEdge[52, 303] -> 
             RGBColor[
              0.39884242382204343`, 0.5113862459388874, 0.9475871249444624], 
             UndirectedEdge[170, 208] -> 
             RGBColor[
              0.45944261470723907`, 0.569251591994923, 0.9513572818259808], 
             UndirectedEdge[49, 355] -> 
             RGBColor[
              0.4461051681544804, 0.5598598436807436, 0.949910485146721], 
             UndirectedEdge[140, 359] -> 
             RGBColor[
              0.3429721641882505, 0.4714869831628317, 0.9430748609170667], 
             UndirectedEdge[20, 255] -> 
             RGBColor[
              0.3363434116586714, 0.46217553224444974`, 0.9427831963414375], 
             UndirectedEdge[117, 362] -> 
             RGBColor[
              0.3105243483896033, 0.44008759286036236`, 0.9411279507403283], 
             UndirectedEdge[188, 293] -> 
             RGBColor[
              0.379503122829444, 0.4947080776127193, 0.946153656344475], 
             UndirectedEdge[149, 155] -> 
             RGBColor[
              0.2318752356888018, 0.3610459528209709, 0.9365163236925821], 
             UndirectedEdge[7, 188] -> 
             RGBColor[
              0.587507652358364, 0.6758310354807773, 0.9607882979048897], 
             UndirectedEdge[120, 331] -> 
             RGBColor[
              0.4244498207646123, 0.542058834103184, 0.9482665451462496], 
             UndirectedEdge[169, 218] -> 
             RGBColor[
              0.6421665561956559, 0.7147854649619687, 0.9682106151311861], 
             UndirectedEdge[345, 350] -> 
             RGBColor[
              0.2237488018130884, 0.3525045555719293, 0.9360535353053419], 
             UndirectedEdge[147, 217] -> 
             RGBColor[
              0.3683648036236604, 0.4824263289059931, 0.9455716554911018], 
             UndirectedEdge[141, 386] -> 
             RGBColor[
              0.3934474808376954, 0.5152061654814006, 0.9462911034603994], 
             UndirectedEdge[128, 383] -> 
             RGBColor[
              0.37681711348763414`, 0.5008017771493445, 0.9452314311585099], 
             UndirectedEdge[138, 394] -> 
             RGBColor[
              0.20618491566756073`, 0.33404379761827874`, 0.935053297972795], 
             UndirectedEdge[132, 300] -> 
             RGBColor[
              0.5472446471453826, 0.6389010394120516, 0.9593645054246865], 
             UndirectedEdge[103, 122] -> 
             RGBColor[
              0.4286677411806925, 0.5457121847687484, 0.9485353073054017], 
             UndirectedEdge[147, 195] -> 
             RGBColor[
              0.5454779143648648, 0.6418825702382263, 0.9573611660516921], 
             UndirectedEdge[123, 389] -> 
             RGBColor[
              0.2625356418853755, 0.39068576418905543`, 0.938357082633247], 
             UndirectedEdge[93, 394] -> 
             RGBColor[
              0.20416898574952613`, 0.33192492745708524`, 0.934938493746264], 
             UndirectedEdge[199, 350] -> 
             RGBColor[
              0.20654228005577713`, 0.3344194102485051, 0.9350736493460308], 
             UndirectedEdge[66, 158] -> 
             RGBColor[
              0.5932620313087027, 0.6787862180636801, 0.962285165990483], 
             UndirectedEdge[105, 215] -> 
             RGBColor[
              0.42720444261928026`, 0.542832210959726, 0.9488876163083875], 
             UndirectedEdge[253, 364] -> 
             RGBColor[
              0.24192262620320706`, 0.3716063972929633, 0.9370885077185952], 
             UndirectedEdge[76, 78] -> 
             RGBColor[
              0.3701049998711139, 0.49498808169535424`, 0.9448037412141542], 
             UndirectedEdge[153, 358] -> 
             RGBColor[
              0.3819637564015174, 0.5052595405635559, 0.9455593706939849], 
             UndirectedEdge[54, 64] -> 
             RGBColor[
              0.2927022660719577, 0.42085567830108206`, 0.940131308767449], 
             UndirectedEdge[84, 125] -> 
             RGBColor[
              0.6404074240543585, 0.7119151689050396, 0.9606009418161674], 
             UndirectedEdge[195, 380] -> 
             RGBColor[
              0.4195413746475113, 0.5315940959104364, 0.948906813598353], 
             UndirectedEdge[81, 146] -> 
             RGBColor[
              0.5253963953199801, 0.6231025623345577, 0.9566495449712413], 
             UndirectedEdge[275, 317] -> 
             RGBColor[
              0.30508396922403136`, 0.43309917127967684`, 0.9408646388358055],
              UndirectedEdge[25, 377] -> 
             RGBColor[
              0.4748790546257925, 0.5824380180435441, 0.9523916743169679], 
             UndirectedEdge[180, 232] -> 
             RGBColor[
              0.4076634067456407, 0.5270294610585109, 0.9473322697765123], 
             UndirectedEdge[52, 333] -> 
             RGBColor[
              0.29858989977969563`, 0.42722810652854476`, 0.9404598580938686],
              UndirectedEdge[97, 276] -> 
             RGBColor[
              0.3180972320535991, 0.4474553512046606, 0.9415808847840405], 
             UndirectedEdge[51, 390] -> 
             RGBColor[
              0.6424782378300793, 0.719215386813794, 0.9659657980763083], 
             UndirectedEdge[199, 393] -> 
             RGBColor[
              0.3608550105803947, 0.47356025726026624`, 0.9452325344675421], 
             UndirectedEdge[169, 224] -> 
             RGBColor[
              0.8398816268452733, 0.8755866819423606, 0.9844773754851934], 
             UndirectedEdge[132, 268] -> 
             RGBColor[
              0.26471534978398414`, 0.39184894662555136`, 0.9385225091094278],
              UndirectedEdge[162, 183] -> 
             RGBColor[
              0.38215623122194575`, 0.5054262525789451, 0.9455716350193437], 
             UndirectedEdge[15, 231] -> 
             RGBColor[
              0.4584053302220289, 0.5711931238558579, 0.9505064932705827], 
             UndirectedEdge[246, 248] -> 
             RGBColor[
              0.41796737073593915`, 0.5364091257303325, 0.9478631420767304], 
             UndirectedEdge[44, 81] -> 
             RGBColor[
              0.5069018182460343, 0.6085416520083449, 0.9548833045524102], 
             UndirectedEdge[39, 197] -> 
             RGBColor[
              0.3760470845696686, 0.4984755005053315, 0.9452832516745576], 
             UndirectedEdge[57, 86] -> 
             RGBColor[
              0.27649478457555554`, 0.40497671587482426`, 0.9391659851547434],
              UndirectedEdge[74, 209] -> 
             RGBColor[
              0.440701770112931, 0.5509620334014008, 0.9503733833059411], 
             UndirectedEdge[115, 389] -> 
             RGBColor[
              0.19390620385146023`, 0.3211380929842631, 0.9343540434995944], 
             UndirectedEdge[157, 168] -> 
             RGBColor[
              0.3950959568378561, 0.516633992537927, 0.9463961428934395], 
             UndirectedEdge[224, 363] -> 
             RGBColor[
              0.504843276991668, 0.5950840378413486, 0.9572831478669297], 
             UndirectedEdge[47, 279] -> 
             RGBColor[
              0.36691996611882405`, 0.4922293655435718, 0.944600793679873], 
             UndirectedEdge[58, 352] -> 
             RGBColor[
              0.3071005425765026, 0.4382483564893869, 0.9408685497889885], 
             UndirectedEdge[101, 161] -> 
             RGBColor[
              0.4116249280256775, 0.5299517423451072, 0.9477253296790484], 
             UndirectedEdge[23, 98] -> 
             RGBColor[
              0.48280772725911647`, 0.585431020114725, 0.9538897820942714], 
             UndirectedEdge[37, 388] -> 
             RGBColor[
              0.4302388296429248, 0.547072982629532, 0.9486354156729562], 
             UndirectedEdge[13, 21] -> 
             RGBColor[
              0.26927528747032614`, 0.4003557785435958, 0.9386462013131216], 
             UndirectedEdge[159, 375] -> 
             RGBColor[
              0.26222216324141073`, 0.3929424977851008, 0.938244536322447], 
             UndirectedEdge[130, 346] -> 
             RGBColor[
              0.5084271211668663, 0.6003445377272416, 0.9572507753918885], 
             UndirectedEdge[104, 225] -> 
             RGBColor[
              0.42546418942676234`, 0.5429374292546869, 0.9483311798204308], 
             UndirectedEdge[226, 252] -> 
             RGBColor[
              0.4756838782955016, 0.5814550101137455, 0.9529071751916094], 
             UndirectedEdge[64, 283] -> 
             RGBColor[
              0.49641678675645395`, 0.5993379935769759, 0.9542489307133151], 
             UndirectedEdge[262, 284] -> 
             RGBColor[
              0.3430811688461347, 0.4688422566159468, 0.9431820999639433], 
             UndirectedEdge[282, 313] -> 
             RGBColor[
              0.32353113756660135`, 0.4505528094684698, 0.9419860461152121], 
             UndirectedEdge[88, 360] -> 
             RGBColor[
              0.3780195867114362, 0.5018432990177403, 0.9453080516890252], 
             UndirectedEdge[210, 230] -> 
             RGBColor[
              0.47701324133293876`, 0.5823759682958078, 0.9530669856585605], 
             UndirectedEdge[2, 138] -> 
             RGBColor[
              0.30745518829580587`, 0.4293776022897571, 0.9412271964953088], 
             UndirectedEdge[178, 367] -> 
             RGBColor[
              0.33265770399043404`, 0.4594174247178357, 0.942532445658218], 
             UndirectedEdge[54, 123] -> 
             RGBColor[
              0.2843896268654962, 0.4136556880258398, 0.9396016347477915], 
             UndirectedEdge[36, 95] -> 
             RGBColor[
              0.33036595931736457`, 0.46048732869917863`, 0.9422745629324678],
              UndirectedEdge[294, 301] -> 
             RGBColor[
              0.34484166572307856`, 0.4702908380349324, 0.9432970699777097], 
             UndirectedEdge[60, 337] -> 
             RGBColor[
              0.36105133364308, 0.4871462510591271, 0.9442268496079466], 
             UndirectedEdge[251, 275] -> 
             RGBColor[
              0.271835086538014, 0.39815248747575216`, 0.9389711641541509], 
             UndirectedEdge[66, 311] -> 
             RGBColor[
              0.47469316169893344`, 0.5664453952303927, 0.9550831189677997], 
             UndirectedEdge[110, 400] -> 
             RGBColor[
              0.2617481419606836, 0.39244427136437154`, 0.9382175415117613], 
             UndirectedEdge[143, 151] -> 
             RGBColor[
              0.5857022795390194, 0.6736276318496492, 0.9611505559774818], 
             UndirectedEdge[157, 206] -> 
             RGBColor[
              0.39997470328500984`, 0.5208597174975252, 0.946707012302946], 
             UndirectedEdge[226, 274] -> 
             RGBColor[
              0.5363989271532489, 0.6340433338072405, 0.9567758844166154], 
             UndirectedEdge[86, 265] -> 
             RGBColor[
              0.3192481383017251, 0.4499132013602184, 0.9416007254015297], 
             UndirectedEdge[64, 389] -> 
             RGBColor[
              0.270848281091837, 0.39788575446429775`, 0.9388867566529046], 
             UndirectedEdge[120, 356] -> 
             RGBColor[
              0.4286144729837904, 0.5456660465339291, 0.9485319131029983], 
             UndirectedEdge[164, 279] -> 
             RGBColor[
              0.415624577782344, 0.5344148522015528, 0.9477042084672755], 
             UndirectedEdge[24, 238] -> 
             RGBColor[
              0.3528832520973761, 0.47754373953290563`, 0.9437989392461106], 
             UndirectedEdge[213, 259] -> 
             RGBColor[
              0.28056542452441924`, 0.40624712774991023`, 0.9395079429444844],
              UndirectedEdge[73, 162] -> 
             RGBColor[
              0.4247591042725579, 0.5423267199327253, 0.9482862524178873], 
             UndirectedEdge[257, 356] -> 
             RGBColor[
              0.31091460105518454`, 0.4336679672218678, 0.9414002477041618], 
             UndirectedEdge[6, 281] -> 
             RGBColor[
              0.6728894012121025, 0.742456892734154, 0.9694164951137338], 
             UndirectedEdge[176, 277] -> 
             RGBColor[
              0.38968489003586054`, 0.5020716424441378, 0.9470373491929149], 
             UndirectedEdge[140, 263] -> 
             RGBColor[
              0.3749800111846654, 0.4992105714699595, 0.9451143726242505], 
             UndirectedEdge[54, 161] -> 
             RGBColor[
              0.282603681693835, 0.4121087920823612, 0.9394878359007025], 
             UndirectedEdge[7, 142] -> 
             RGBColor[
              0.7785667136593983, 0.8276162873487556, 0.9783848444488189], 
             UndirectedEdge[81, 311] -> 
             RGBColor[
              0.2916317233582178, 0.4173760463394729, 0.9401565499284629], 
             UndirectedEdge[204, 237] -> 
             RGBColor[
              0.37417792224617075`, 0.49851584234559765`, 0.945063264226349], 
             UndirectedEdge[134, 374] -> 
             RGBColor[
              0.44399006776968253`, 0.5585017160711961, 0.949644782222955], 
             UndirectedEdge[264, 279] -> 
             RGBColor[
              0.32692824772206924`, 0.45107104040652723`, 0.9422912678971757],
              UndirectedEdge[81, 344] -> 
             RGBColor[
              0.2831144935911563, 0.40842389783073374`, 0.939671506293341], 
             UndirectedEdge[287, 391] -> 
             RGBColor[
              0.43684851055771134`, 0.5527979560256977, 0.949056578696135], 
             UndirectedEdge[90, 228] -> 
             RGBColor[
              0.5494160474734773, 0.6299813353957223, 0.9616803396657926], 
             UndirectedEdge[222, 259] -> 
             RGBColor[
              0.31258359481390174`, 0.4399002547934039, 0.9413313303758323], 
             UndirectedEdge[143, 342] -> 
             RGBColor[
              0.6750341110958077, 0.7460610451280871, 0.9682447497077561], 
             UndirectedEdge[68, 262] -> 
             RGBColor[
              0.405289744139254, 0.5254633387437506, 0.9470456820062724], 
             UndirectedEdge[73, 189] -> 
             RGBColor[
              0.3306185320044006, 0.4520306348801193, 0.9426083077139733], 
             UndirectedEdge[79, 176] -> 
             RGBColor[
              0.42339369682645395`, 0.5375017356428443, 0.9489570158719285], 
             UndirectedEdge[14, 289] -> 
             RGBColor[
              0.32799532927306996`, 0.45851480151691265`, 0.9421205502397665],
              UndirectedEdge[126, 373] -> 
             RGBColor[
              0.2657499406441851, 0.3965653158380459, 0.9384485539424963], 
             UndirectedEdge[313, 361] -> 
             RGBColor[
              0.469042636967388, 0.5779091030388261, 0.9518743656193722], 
             UndirectedEdge[56, 203] -> 
             RGBColor[
              0.39911858607608885`, 0.5201181918008599, 0.9466524612714282], 
             UndirectedEdge[163, 240] -> 
             RGBColor[
              0.3178328402371833, 0.44760830897880816`, 0.9415500525198324], 
             UndirectedEdge[283, 380] -> 
             RGBColor[
              0.45688673037633615`, 0.5619127380801996, 0.9518467768018717], 
             UndirectedEdge[165, 318] -> 
             RGBColor[
              0.4323354773466209, 0.547150987556712, 0.9492492284283736], 
             UndirectedEdge[184, 185] -> 
             RGBColor[
              0.3479551131419197, 0.4675288599810212, 0.9438127306626011], 
             UndirectedEdge[123, 364] -> 
             RGBColor[
              0.26019304663282666`, 0.38822354804950904`, 0.9382236752991735],
              UndirectedEdge[24, 341] -> 
             RGBColor[
              0.3530246497348577, 0.47766621105964024`, 0.9438079489785378], 
             UndirectedEdge[10, 364] -> 
             RGBColor[
              0.18571237649197336`, 0.3125258609107818, 0.9338874171531529], 
             UndirectedEdge[59, 132] -> 
             RGBColor[
              0.3463551908255947, 0.4744171908002365, 0.9432904243829052], 
             UndirectedEdge[110, 309] -> 
             RGBColor[
              0.27250108444307397`, 0.40374629568929477`, 0.9388299056785805],
              UndirectedEdge[28, 50] -> 
             RGBColor[
              0.3786545552803292, 0.5023932768776671, 0.9453485113247544], 
             UndirectedEdge[120, 147] -> 
             RGBColor[
              0.4807886032329407, 0.5888789216881372, 0.9524028563766024], 
             UndirectedEdge[322, 335] -> 
             RGBColor[
              0.40330132930986584`, 0.5237410737591699, 0.9469189819716299], 
             UndirectedEdge[9, 198] -> 
             RGBColor[
              0.37954060404228307`, 0.5031607277811659, 0.945404969568364], 
             UndirectedEdge[214, 257] -> 
             RGBColor[
              0.27679969476089683`, 0.40411935005480226`, 0.9392264760417168],
              UndirectedEdge[190, 274] -> 
             RGBColor[
              0.38248180323210385`, 0.5057082466904191, 0.9455923801799391], 
             UndirectedEdge[18, 198] -> 
             RGBColor[
              0.4346308624373232, 0.5508771406860529, 0.9489152721188931], 
             UndirectedEdge[280, 291] -> 
             RGBColor[
              0.6306459325569599, 0.7037667879832434, 0.9644526099555286], 
             UndirectedEdge[156, 179] -> 
             RGBColor[
              0.2601901451757946, 0.3889433144530502, 0.9381970442302362], 
             UndirectedEdge[76, 96] -> 
             RGBColor[
              0.5001112590413646, 0.6016704532984783, 0.9548400625413622], 
             UndirectedEdge[143, 158] -> 
             RGBColor[
              0.571707070358748, 0.6619473187458047, 0.9601367689255541], 
             UndirectedEdge[252, 274] -> 
             RGBColor[
              0.3753482493085038, 0.4995295208246421, 0.9451378364318812], 
             UndirectedEdge[272, 348] -> 
             RGBColor[
              0.3308076855780118, 0.45707837297810494`, 0.9424415368072695], 
             UndirectedEdge[51, 232] -> 
             RGBColor[
              0.4470516870926914, 0.559006641466055, 0.9504330594894571], 
             UndirectedEdge[66, 317] -> 
             RGBColor[
              0.49671135974857406`, 0.5895879174149525, 0.9563370227737218], 
             UndirectedEdge[258, 264] -> 
             RGBColor[
              0.24876062743089394`, 0.3787935701375809, 0.9374779217725957], 
             UndirectedEdge[17, 223] -> 
             RGBColor[
              0.25872036171431356`, 0.3892618823530813, 0.93804511390593], 
             UndirectedEdge[46, 271] -> 
             RGBColor[
              0.3326104422785615, 0.46186323790855177`, 0.9424383821244902], 
             UndirectedEdge[93, 201] -> 
             RGBColor[
              0.23294058875490925`, 0.36216570644073565`, 0.9365769939736484],
              UndirectedEdge[232, 373] -> 
             RGBColor[
              0.3268176816879649, 0.4574947823689832, 0.9420455115769965], 
             UndirectedEdge[182, 208] -> 
             RGBColor[
              0.3835535065208294, 0.5066365022137397, 0.9456606681658266], 
             UndirectedEdge[10, 391] -> 
             RGBColor[
              0.3180827589379007, 0.43874275714281175`, 0.9418985143180352], 
             UndirectedEdge[284, 366] -> 
             RGBColor[
              0.4651280165276206, 0.5690474186955845, 0.952534831293379], 
             UndirectedEdge[154, 387] -> 
             RGBColor[
              0.33713724649297705`, 0.4565150058483056, 0.9431642265412543], 
             UndirectedEdge[135, 363] -> 
             RGBColor[
              0.28279894618605955`, 0.4132100385380079, 0.9394661485693026], 
             UndirectedEdge[37, 269] -> 
             RGBColor[
              0.29920009259271674`, 0.42216474011595484`, 0.9407034853338585],
              UndirectedEdge[201, 281] -> 
             RGBColor[
              0.3949551156959638, 0.5127826288094075, 0.946866725449057], 
             UndirectedEdge[302, 377] -> 
             RGBColor[
              0.43765371585663393`, 0.5522168110483404, 0.9494611592881508], 
             UndirectedEdge[179, 286] -> 
             RGBColor[
              0.2751784785923188, 0.4019254555229017, 0.9391520875818742], 
             UndirectedEdge[108, 325] -> 
             RGBColor[
              0.24676938135157944`, 0.376700644255928, 0.9373645232541634], 
             UndirectedEdge[279, 299] -> 
             RGBColor[
              0.43043131365513165`, 0.5472397026063777, 0.9486476805840072], 
             UndirectedEdge[196, 332] -> 
             RGBColor[
              0.400174196790433, 0.5186468362982314, 0.9471294798352238], 
             UndirectedEdge[31, 224] -> 
             RGBColor[
              0.5996915244178138, 0.6833947501355485, 0.9631013224276636], 
             UndirectedEdge[200, 296] -> 
             RGBColor[
              0.5635854135641756, 0.6500203360482222, 0.9616899646805146], 
             UndirectedEdge[170, 221] -> 
             RGBColor[
              0.46038160338733025`, 0.5700648967946746, 0.9514171133543611], 
             UndirectedEdge[198, 206] -> 
             RGBColor[
              0.39590660699182256`, 0.5173361369568312, 0.9464477968044205], 
             UndirectedEdge[36, 361] -> 
             RGBColor[
              0.4316733005689553, 0.5454608686771918, 0.9494961827910156], 
             UndirectedEdge[132, 180] -> 
             RGBColor[
              0.4101372480821203, 0.5291721780852886, 0.9474899007589408], 
             UndirectedEdge[127, 312] -> 
             RGBColor[
              0.5761209567267451, 0.6432127614267311, 0.9358264386883766], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.7124109341421481, 0.7740812147314388, 0.9730584222302695], 
             UndirectedEdge[67, 75] -> 
             RGBColor[
              0.7040811399544908, 0.7669578174517652, 0.9692464624438973], 
             UndirectedEdge[110, 287] -> 
             RGBColor[
              0.336889807156917, 0.4606477894892463, 0.9428912787040908], 
             UndirectedEdge[88, 233] -> 
             RGBColor[
              0.6803125374522951, 0.2648640119454702, 0.42518200997203615`], 
             UndirectedEdge[168, 216] -> 
             RGBColor[
              0.27430222489263184`, 0.4022117049588322, 0.9390579829803223], 
             UndirectedEdge[1, 291] -> 
             RGBColor[
              0.6975241482949793, 0.7616345562334658, 0.9687302720414087], 
             UndirectedEdge[115, 214] -> 
             RGBColor[
              0.2765188319022358, 0.40382414538261574`, 0.9392104813174155], 
             UndirectedEdge[233, 256] -> 
             RGBColor[
              0.674652012175191, 0.25996114945671533`, 0.42482132630678504`], 
             UndirectedEdge[4, 252] -> 
             RGBColor[
              0.2994697464461666, 0.43154775746014307`, 0.9403856610083652], 
             UndirectedEdge[91, 399] -> 
             RGBColor[
              0.4513678430496937, 0.5625473082375614, 0.9507627257315143], 
             UndirectedEdge[76, 269] -> 
             RGBColor[
              0.26230944093423875`, 0.39021191182744613`, 0.9383528456313026],
              UndirectedEdge[91, 172] -> 
             RGBColor[
              0.37288563765693983`, 0.48343882034450814`, 0.9461694747930731],
              UndirectedEdge[165, 184] -> 
             RGBColor[
              0.28594794044050187`, 0.4143111884893119, 0.9397263483609483], 
             UndirectedEdge[60, 139] -> 
             RGBColor[
              0.5560647205469617, 0.6464647957688274, 0.9599585728097744], 
             UndirectedEdge[356, 359] -> 
             RGBColor[
              0.38248010036883295`, 0.5057067717558422, 0.9455922716749972], 
             UndirectedEdge[228, 305] -> 
             RGBColor[
              0.24363921405979153`, 0.3734106399681898, 0.9371862648575635], 
             UndirectedEdge[141, 209] -> 
             RGBColor[
              0.5060159274799285, 0.6090281228301364, 0.954480431878924], 
             UndirectedEdge[171, 348] -> 
             RGBColor[
              0.35548354602633514`, 0.4784513630536348, 0.94401386081503], 
             UndirectedEdge[10, 60] -> 
             RGBColor[
              0.2762650462875366, 0.40252235626441735`, 0.9392339266459053], 
             UndirectedEdge[234, 298] -> 
             RGBColor[
              0.5847578259668416, 0.6734344849741778, 0.960684029573029], 
             UndirectedEdge[323, 388] -> 
             RGBColor[
              0.35476031404730335`, 0.47738418307774466`, 0.9439839152314442],
              UndirectedEdge[294, 329] -> 
             RGBColor[
              0.24938478095972602`, 0.3794495950700028, 0.9375134663927103], 
             UndirectedEdge[211, 238] -> 
             RGBColor[
              0.5305473140061402, 0.6289749606098434, 0.9564030248012599], 
             UndirectedEdge[31, 99] -> 
             RGBColor[
              0.4195743331942446, 0.5378359318188619, 0.9479558833894902], 
             UndirectedEdge[111, 319] -> 
             RGBColor[
              0.45618525671591187`, 0.565507501178561, 0.9514046791918358], 
             UndirectedEdge[258, 394] -> 
             RGBColor[
              0.24281690332552638`, 0.3725463392489653, 0.9371394354777469], 
             UndirectedEdge[101, 364] -> 
             RGBColor[
              0.3368857358942737, 0.4536520865356692, 0.943386440999747], 
             UndirectedEdge[225, 349] -> 
             RGBColor[
              0.38954217084985654`, 0.511823582256522, 0.9460422605613042], 
             UndirectedEdge[118, 386] -> 
             RGBColor[
              0.2822969954906587, 0.4089631891545963, 0.9395737438177238], 
             UndirectedEdge[95, 326] -> 
             RGBColor[
              0.3248293672444068, 0.45466801939028745`, 0.9419592622045667], 
             UndirectedEdge[228, 382] -> 
             RGBColor[
              0.24312417397373845`, 0.37286930018232045`, 0.9371569340865964],
              UndirectedEdge[120, 255] -> 
             RGBColor[
              0.418986883819865, 0.5373271126968383, 0.9479184516348158], 
             UndirectedEdge[222, 292] -> 
             RGBColor[
              0.25796865146908055`, 0.38847178722415904`, 0.9380023051195197],
              UndirectedEdge[325, 397] -> 
             RGBColor[
              0.29984372755773847`, 0.431384810459285, 0.9404273174733261], 
             UndirectedEdge[155, 299] -> 
             RGBColor[
              0.3295309950457541, 0.4510687250686798, 0.942539740920219], 
             UndirectedEdge[17, 99] -> 
             RGBColor[
              0.3209006062036637, 0.4455043979530272, 0.9419198534268516], 
             UndirectedEdge[60, 105] -> 
             RGBColor[
              0.35323779627544255`, 0.48037855771108645`, 0.9437289779161204],
              UndirectedEdge[229, 340] -> 
             RGBColor[
              0.2784806473541773, 0.40737301514931956`, 0.939267761942076], 
             UndirectedEdge[297, 375] -> 
             RGBColor[
              0.24804073396827134`, 0.3780369164644828, 0.9374369249048863], 
             UndirectedEdge[155, 249] -> 
             RGBColor[
              0.3218143786592419, 0.4443849798030997, 0.9420480449476063], 
             UndirectedEdge[143, 348] -> 
             RGBColor[
              0.48434236946797654`, 0.5824040556947512, 0.954711753148987], 
             UndirectedEdge[175, 294] -> 
             RGBColor[
              0.30860875594151616`, 0.43890771270114004`, 0.9409883410059325],
              UndirectedEdge[19, 181] -> 
             RGBColor[
              0.3731131083049715, 0.49759355402883576`, 0.9449954152235938], 
             UndirectedEdge[153, 294] -> 
             RGBColor[
              0.32235830086658124`, 0.45081687744300963`, 0.9418644498503126],
              UndirectedEdge[68, 376] -> 
             RGBColor[
              0.30889710051198804`, 0.433236741461678, 0.9412235006593505], 
             UndirectedEdge[317, 354] -> 
             RGBColor[
              0.29458540924063203`, 0.42400584629502386`, 0.9401956798771754],
              UndirectedEdge[2, 254] -> 
             RGBColor[
              0.33424785620987973`, 0.4575383950207098, 0.9427529992968151], 
             UndirectedEdge[243, 311] -> 
             RGBColor[
              0.2460122944029362, 0.37590489787081893`, 0.9373214082724479], 
             UndirectedEdge[23, 143] -> 
             RGBColor[
              0.6846272707790585, 0.7535552943833566, 0.9692009062118083], 
             UndirectedEdge[20, 64] -> 
             RGBColor[
              0.3117386477345114, 0.440864122404735, 0.9412154025413284], 
             UndirectedEdge[75, 296] -> 
             RGBColor[
              0.8782904805950511, 0.9057132931372275, 0.9847901241668909], 
             UndirectedEdge[146, 227] -> 
             RGBColor[
              0.5281861146378866, 0.6255188769923584, 0.9568273034193263], 
             UndirectedEdge[160, 238] -> 
             RGBColor[
              0.6541841840248921, 0.7261646670011291, 0.9685297604753871], 
             UndirectedEdge[75, 178] -> 
             RGBColor[
              0.6071981248121785, 0.6803217839943074, 0.9630733494043506], 
             UndirectedEdge[95, 166] -> 
             RGBColor[
              0.2682638390235481, 0.39521406276853155`, 0.9387379390535888], 
             UndirectedEdge[25, 309] -> 
             RGBColor[
              0.4356842266182394, 0.5473582095562142, 0.9499356339840561], 
             UndirectedEdge[166, 326] -> 
             RGBColor[
              0.24023343755062035`, 0.3698309529183482, 0.936992310923761], 
             UndirectedEdge[158, 308] -> 
             RGBColor[
              0.3487307571314182, 0.4715859380980326, 0.9436207980718174], 
             UndirectedEdge[229, 343] -> 
             RGBColor[
              0.21712192312892942`, 0.34553928590650185`, 0.9356761443678674],
              UndirectedEdge[229, 294] -> 
             RGBColor[
              0.24887984053676349`, 0.37891887067039726`, 0.937484710782615], 
             UndirectedEdge[64, 257] -> 
             RGBColor[
              0.2766822479670991, 0.40401762354506215`, 0.9392189924358703], 
             UndirectedEdge[56, 65] -> 
             RGBColor[
              0.37067451824349695`, 0.49505867369262807`, 0.9448555073994569],
              UndirectedEdge[170, 192] -> 
             RGBColor[
              0.5135560509942597, 0.6159669634904122, 0.9548481600335195], 
             UndirectedEdge[133, 347] -> 
             RGBColor[
              0.2395847801758741, 0.36914917289023685`, 0.9369553708458719], 
             UndirectedEdge[223, 393] -> 
             RGBColor[
              0.4086192820622786, 0.523763535017452, 0.9479526390675279], 
             UndirectedEdge[116, 338] -> 
             RGBColor[
              0.3494540316493808, 0.473552538089107, 0.9436178155423516], 
             UndirectedEdge[32, 71] -> 
             RGBColor[
              0.2919593519444259, 0.4241981685586318, 0.9399380252268554], 
             UndirectedEdge[95, 361] -> 
             RGBColor[
              0.4541671099689253, 0.565024669218484, 0.9509265101929423], 
             UndirectedEdge[247, 292] -> 
             RGBColor[
              0.3816103397659381, 0.49958722795764116`, 0.9460311351851214], 
             UndirectedEdge[337, 391] -> 
             RGBColor[
              0.4028690462934441, 0.5233666519375215, 0.9468914372800764], 
             UndirectedEdge[181, 238] -> 
             RGBColor[
              0.40085414875855463`, 0.521621448964495, 0.9467630497908572], 
             UndirectedEdge[97, 246] -> 
             RGBColor[
              0.3682300526278914, 0.4908429446618587, 0.944784956694424], 
             UndirectedEdge[62, 247] -> 
             RGBColor[
              0.3978303314006042, 0.5166354675725428, 0.9469548397133885], 
             UndirectedEdge[207, 280] -> 
             RGBColor[
              0.315855660749067, 0.4480000307989024, 0.9413470212961044], 
             UndirectedEdge[145, 221] -> 
             RGBColor[
              0.6321541936449888, 0.7061334618601394, 0.9675633361050895], 
             UndirectedEdge[10, 334] -> 
             RGBColor[
              0.2887184375064456, 0.413308857812594, 0.9400274457222728], 
             UndirectedEdge[25, 78] -> 
             RGBColor[
              0.4878978672813662, 0.5937142592212521, 0.953221221547297], 
             UndirectedEdge[46, 139] -> 
             RGBColor[
              0.5245416608538097, 0.6185121633262743, 0.9579737122858718], 
             UndirectedEdge[224, 383] -> 
             RGBColor[
              0.5461399242709541, 0.6370110456700233, 0.9596890618201264], 
             UndirectedEdge[138, 164] -> 
             RGBColor[
              0.30082496983320306`, 0.42363484030191995`, 0.9408047248377438],
              UndirectedEdge[53, 93] -> 
             RGBColor[
              0.25486194035162746`, 0.3834512013442363, 0.9378896502879182], 
             UndirectedEdge[31, 199] -> 
             RGBColor[
              0.30962981722301053`, 0.4313901384617302, 0.9413610392685827], 
             UndirectedEdge[98, 342] -> 
             RGBColor[
              0.47321456757586566`, 0.5779367708594555, 0.9529336255902192], 
             UndirectedEdge[141, 304] -> 
             RGBColor[
              0.3010698640873587, 0.42319066333994926`, 0.9408443593501699], 
             UndirectedEdge[32, 105] -> 
             RGBColor[
              0.3226483994173917, 0.4534072641058675, 0.9417972881094465], 
             UndirectedEdge[216, 329] -> 
             RGBColor[
              0.2116297841103017, 0.339766699576198, 0.935363375175648], 
             UndirectedEdge[164, 264] -> 
             RGBColor[
              0.32692824772206924`, 0.45107104040652723`, 0.9422912678971757],
              UndirectedEdge[118, 196] -> 
             RGBColor[
              0.35188440879713667`, 0.46789120736787987`, 0.944379447847345], 
             UndirectedEdge[75, 398] -> 
             RGBColor[
              0.6687560981966424, 0.7367758979877166, 0.9668809560105929], 
             UndirectedEdge[45, 48] -> 
             RGBColor[
              0.38920001432899975`, 0.49668356628117993`, 0.9474538022862284],
              UndirectedEdge[248, 275] -> 
             RGBColor[
              0.3715033736752416, 0.49619928280017866`, 0.9448928443564198], 
             UndirectedEdge[200, 347] -> 
             RGBColor[
              0.24994866895417567`, 0.3799119767779412, 0.9375503499130524], 
             UndirectedEdge[33, 58] -> 
             RGBColor[
              0.38953972076107657`, 0.5118214601127657, 0.9460421044438136], 
             UndirectedEdge[134, 240] -> 
             RGBColor[
              0.38329660747752947`, 0.5064139891745547, 0.9456442987859544], 
             UndirectedEdge[267, 344] -> 
             RGBColor[
              0.37441319433936293`, 0.48456740162501455`, 0.9462998843583117],
              UndirectedEdge[141, 286] -> 
             RGBColor[
              0.39104485165286124`, 0.5131251288411514, 0.9461380100533032], 
             UndirectedEdge[33, 209] -> 
             RGBColor[
              0.5194950203960623, 0.620703035635183, 0.9553393077604462], 
             UndirectedEdge[47, 155] -> 
             RGBColor[
              0.2660196475094465, 0.3960583880058739, 0.938492854016085], 
             UndirectedEdge[153, 229] -> 
             RGBColor[
              0.2929432537276695, 0.4198997978783062, 0.9401893064314142], 
             UndirectedEdge[64, 161] -> 
             RGBColor[
              0.3432448779706921, 0.4717231941341894, 0.9430922379981326], 
             UndirectedEdge[3, 293] -> 
             RGBColor[
              0.3780735066690404, 0.4935474508102296, 0.9460411117234715], 
             UndirectedEdge[133, 178] -> 
             RGBColor[
              0.28212916900300133`, 0.4138660230175978, 0.9393782108507938], 
             UndirectedEdge[113, 162] -> 
             RGBColor[
              0.6420169601298187, 0.7157049551075791, 0.9677181417999113], 
             UndirectedEdge[313, 358] -> 
             RGBColor[
              0.3900583107299038, 0.5122706366786742, 0.9460751485380563], 
             UndirectedEdge[259, 292] -> 
             RGBColor[
              0.3187590620498322, 0.4463910624056042, 0.9416830140991335], 
             UndirectedEdge[4, 165] -> 
             RGBColor[
              0.3158249115706085, 0.44571377945643376`, 0.94142779766779], 
             UndirectedEdge[247, 385] -> 
             RGBColor[
              0.6309483874682084, 0.7094260385402202, 0.9653513647879067], 
             UndirectedEdge[38, 243] -> 
             RGBColor[
              0.35607647557932476`, 0.4808793870411815, 0.9439815440685568], 
             UndirectedEdge[265, 381] -> 
             RGBColor[
              0.32904078922092106`, 0.45839510339347955`, 0.9422247044587997],
              UndirectedEdge[15, 369] -> 
             RGBColor[
              0.38249859001678244`, 0.5053113309071435, 0.9456456590158095], 
             UndirectedEdge[30, 358] -> 
             RGBColor[
              0.5059907924346487, 0.6083097136634915, 0.9546713135764708], 
             UndirectedEdge[133, 330] -> 
             RGBColor[
              0.2534007116162719, 0.3836705928147426, 0.9377421677025636], 
             UndirectedEdge[223, 292] -> 
             RGBColor[
              0.2735465367277012, 0.4048451323259413, 0.938889442639582], 
             UndirectedEdge[44, 326] -> 
             RGBColor[
              0.4658970134339293, 0.571920766098239, 0.9523109589146245], 
             UndirectedEdge[123, 356] -> 
             RGBColor[
              0.3792631762304387, 0.5029204337544737, 0.945387292113513], 
             UndirectedEdge[35, 154] -> 
             RGBColor[
              0.33864132553434895`, 0.45773608497207996`, 0.9432826331530142],
              UndirectedEdge[146, 151] -> 
             RGBColor[
              0.5707836220725493, 0.6619730632508467, 0.9596636036240046], 
             UndirectedEdge[111, 287] -> 
             RGBColor[
              0.3677943026725302, 0.49298667192095913`, 0.9446565056319297], 
             UndirectedEdge[42, 133] -> 
             RGBColor[
              0.2732651326407469, 0.4045493587885027, 0.93887341709313], 
             UndirectedEdge[40, 103] -> 
             RGBColor[
              0.3582704214740334, 0.48394698449172946`, 0.9440785993581797], 
             UndirectedEdge[219, 260] -> 
             RGBColor[
              0.6251493525479173, 0.6941754194220426, 0.935355507402357], 
             UndirectedEdge[151, 186] -> 
             RGBColor[
              0.4285848974510532, 0.5451987960255414, 0.9486520532746434], 
             UndirectedEdge[8, 76] -> 
             RGBColor[
              0.3204849514925358, 0.4513580619646257, 0.9416658548946424], 
             UndirectedEdge[124, 167] -> 
             RGBColor[
              0.481865045952254, 0.5890554009820588, 0.9526802986062775], 
             UndirectedEdge[162, 291] -> 
             RGBColor[
              0.6709430984022917, 0.7386701676440235, 0.9670203097298086], 
             UndirectedEdge[242, 255] -> 
             RGBColor[
              0.4682249327463012, 0.5777867305170824, 0.951660381349251], 
             UndirectedEdge[182, 323] -> 
             RGBColor[
              0.33920232592811556`, 0.46390863573612373`, 0.9429925739858782],
              UndirectedEdge[138, 149] -> 
             RGBColor[
              0.21797594634903833`, 0.3464369184590359, 0.9357247797268384], 
             UndirectedEdge[199, 353] -> 
             RGBColor[
              0.2179558396033256, 0.34641578499445047`, 0.9357236346774154], 
             UndirectedEdge[34, 381] -> 
             RGBColor[
              0.29545750476276245`, 0.4230969421247375, 0.9403121860909247], 
             UndirectedEdge[148, 305] -> 
             RGBColor[
              0.2735235832833872, 0.40482100680063493`, 0.9388881354748848], 
             UndirectedEdge[97, 383] -> 
             RGBColor[
              0.3032957312360154, 0.43463503514153184`, 0.9406377462403973], 
             UndirectedEdge[154, 207] -> 
             RGBColor[
              0.2579406509997413, 0.38832781215636347`, 0.9380049045804235], 
             UndirectedEdge[272, 375] -> 
             RGBColor[
              0.3297134864123581, 0.45592830027876874`, 0.9423792237835081], 
             UndirectedEdge[25, 323] -> 
             RGBColor[
              0.41847682042296275`, 0.5292721346324117, 0.9489556976573112], 
             UndirectedEdge[236, 334] -> 
             RGBColor[
              0.30705244757202965`, 0.4325790648349006, 0.9410715404727705], 
             UndirectedEdge[23, 346] -> 
             RGBColor[
              0.7119534167137482, 0.7749026872739374, 0.9719245210612256], 
             UndirectedEdge[23, 151] -> 
             RGBColor[
              0.5685080201408668, 0.660195345726601, 0.9594367928901637], 
             UndirectedEdge[250, 381] -> 
             RGBColor[
              0.389953029298989, 0.5121794471948143, 0.9460684400983751], 
             UndirectedEdge[230, 264] -> 
             RGBColor[
              0.2740343426112126, 0.4052569983244742, 0.9389209150357556], 
             UndirectedEdge[60, 68] -> 
             RGBColor[
              0.38415511981713824`, 0.507157589413039, 0.9456990024330816], 
             UndirectedEdge[50, 258] -> 
             RGBColor[
              0.32794783029492813`, 0.4539010538978526, 0.9422849491663421], 
             UndirectedEdge[121, 298] -> 
             RGBColor[
              0.4645973225999761, 0.5754255289988437, 0.9512134814873486], 
             UndirectedEdge[95, 382] -> 
             RGBColor[
              0.2993497560176752, 0.42788733249033384`, 0.9405082360389113], 
             UndirectedEdge[42, 200] -> 
             RGBColor[
              0.2836290214190485, 0.415312162676207, 0.9394683961603105], 
             UndirectedEdge[254, 314] -> 
             RGBColor[
              0.2615446388926311, 0.39223037673700867`, 0.9382059523130915], 
             UndirectedEdge[95, 305] -> 
             RGBColor[
              0.2998647961037283, 0.4284286722762032, 0.9405375668098785], 
             UndirectedEdge[321, 381] -> 
             RGBColor[
              0.31134257373247254`, 0.4397931567834469, 0.9412168172688962], 
             UndirectedEdge[116, 209] -> 
             RGBColor[
              0.429591375558747, 0.5392843042852522, 0.9497406627724361], 
             UndirectedEdge[364, 366] -> 
             RGBColor[
              0.4174020511289265, 0.5188844030605771, 0.949816908168162], 
             UndirectedEdge[58, 156] -> 
             RGBColor[
              0.32890441790656233`, 0.4593022083991205, 0.9421784765636172], 
             UndirectedEdge[118, 179] -> 
             RGBColor[
              0.19619586976713832`, 0.3235446770348446, 0.934484436586235], 
             UndirectedEdge[149, 328] -> 
             RGBColor[
              0.3074790760968649, 0.4353063923786534, 0.9410123941341798], 
             UndirectedEdge[215, 227] -> 
             RGBColor[
              0.4485472778200328, 0.5613183020885298, 0.9502475628946514], 
             UndirectedEdge[70, 177] -> 
             RGBColor[
              0.6130565245958468, 0.678710665758478, 0.899397992307858], 
             UndirectedEdge[383, 393] -> 
             RGBColor[
              0.429512815869922, 0.5442455769553196, 0.949196625892216], 
             UndirectedEdge[14, 201] -> 
             RGBColor[
              0.31223078085787426`, 0.44256202007932116`, 0.941200199979976], 
             UndirectedEdge[5, 368] -> 
             RGBColor[
              0.3677253321245943, 0.4923425231363857, 0.9446735090011341], 
             UndirectedEdge[214, 310] -> 
             RGBColor[
              0.3000567531915077, 0.42856399304804665`, 0.9405509311136054], 
             UndirectedEdge[35, 280] -> 
             RGBColor[
              0.3965563352836747, 0.5174083036146189, 0.946624749868695], 
             UndirectedEdge[243, 275] -> 
             RGBColor[
              0.32462319425658054`, 0.4536361356473061, 0.9419773687957161], 
             UndirectedEdge[131, 391] -> 
             RGBColor[
              0.39588107625856195`, 0.5173140235188929, 0.946446170008673], 
             UndirectedEdge[2, 314] -> 
             RGBColor[
              0.356181797390301, 0.48059235789352595`, 0.944002104798682], 
             UndirectedEdge[282, 361] -> 
             RGBColor[
              0.4099629518197294, 0.5226419156261409, 0.9482598105473299], 
             UndirectedEdge[110, 269] -> 
             RGBColor[
              0.21691916616932566`, 0.3453261754864245, 0.93566459765897], 
             UndirectedEdge[193, 360] -> 
             RGBColor[
              0.3114347481117529, 0.44087790993034226`, 0.9411858956292044], 
             UndirectedEdge[71, 400] -> 
             RGBColor[
              0.27766463259270246`, 0.40917351218241604`, 0.939123962106917], 
             UndirectedEdge[110, 117] -> 
             RGBColor[
              0.29821461137068084`, 0.4271492787710693, 0.9404269294277248], 
             UndirectedEdge[170, 351] -> 
             RGBColor[
              0.43322951754615663`, 0.5455880012248633, 0.949722124664574], 
             UndirectedEdge[121, 200] -> 
             RGBColor[
              0.3671056308126497, 0.4923901789695847, 0.9446126240699868], 
             UndirectedEdge[38, 383] -> 
             RGBColor[
              0.37465962801960084`, 0.49893307167530665`, 0.9450939580922763],
              UndirectedEdge[172, 256] -> 
             RGBColor[
              0.28883556818021605`, 0.4134654384729156, 0.9400328906806426], 
             UndirectedEdge[127, 258] -> 
             RGBColor[
              0.6139883389436491, 0.6830137810674008, 0.9379829300858575], 
             UndirectedEdge[25, 388] -> 
             RGBColor[
              0.5111410453946992, 0.6138463318669212, 0.9547022563035432], 
             UndirectedEdge[51, 277] -> 
             RGBColor[
              0.39012189966957106`, 0.5024264265518437, 0.9470717521920997], 
             UndirectedEdge[85, 379] -> 
             RGBColor[
              0.37131502688323503`, 0.4960361462755276, 0.9448808430653817], 
             UndirectedEdge[267, 306] -> 
             RGBColor[
              0.4800422801244927, 0.5872753862547705, 0.9526197530837457], 
             UndirectedEdge[176, 298] -> 
             RGBColor[
              0.5271995554875202, 0.6270433750709141, 0.9559222266850327], 
             UndirectedEdge[269, 323] -> 
             RGBColor[
              0.22372157699709533`, 0.35247594056416753`, 0.9360519848923465],
              UndirectedEdge[21, 180] -> 
             RGBColor[
              0.35391676844543185`, 0.4737949376957905, 0.9441522381126575], 
             UndirectedEdge[36, 228] -> 
             RGBColor[
              0.27414037727342777`, 0.40546929639116525`, 0.9389232609801528],
              UndirectedEdge[74, 116] -> 
             RGBColor[
              0.28147401888653845`, 0.41317741870627867`, 0.9393409010208689],
              UndirectedEdge[3, 188] -> 
             RGBColor[
              0.5199222566807102, 0.6211353360609708, 0.9553493310653368], 
             UndirectedEdge[69, 394] -> 
             RGBColor[
              0.2677027150326776, 0.3986737849439964, 0.9385577118746061], 
             UndirectedEdge[37, 395] -> 
             RGBColor[
              0.37367002779310743`, 0.4980759296978716, 0.9450309016409133], 
             UndirectedEdge[172, 194] -> 
             RGBColor[
              0.2902268614614774, 0.4146705067847106, 0.9401215426582523], 
             UndirectedEdge[59, 264] -> 
             RGBColor[
              0.29101283962560953`, 0.4199629190742722, 0.9400027698520176], 
             UndirectedEdge[28, 369] -> 
             RGBColor[
              0.3333373221846622, 0.4628852788240653, 0.9424703286031864], 
             UndirectedEdge[130, 344] -> 
             RGBColor[
              0.22390041603688282`, 0.35266391173403416`, 0.9360621695110938],
              UndirectedEdge[29, 270] -> 
             RGBColor[
              0.33311722341280625`, 0.4548596369752085, 0.9427431819576145], 
             UndirectedEdge[41, 48] -> 
             RGBColor[
              0.30559905244532437`, 0.4279851259861349, 0.9411010450746482], 
             UndirectedEdge[12, 124] -> 
             RGBColor[
              0.3715472307599351, 0.48244151825493914`, 0.9460559839584909], 
             UndirectedEdge[61, 95] -> 
             RGBColor[
              0.37961313118710016`, 0.5032235471486862, 0.9454095909338984], 
             UndirectedEdge[213, 306] -> 
             RGBColor[
              0.2932177135055341, 0.4172059045428174, 0.9403141356103812], 
             UndirectedEdge[63, 295] -> 
             RGBColor[
              0.46142590673396655`, 0.5722739360962629, 0.9511232137187492], 
             UndirectedEdge[302, 367] -> 
             RGBColor[
              0.44544573826076733`, 0.5589658692163674, 0.9499576600655273], 
             UndirectedEdge[140, 331] -> 
             RGBColor[
              0.37813558012522513`, 0.5019437666827657, 0.9453154426867829], 
             UndirectedEdge[92, 354] -> 
             RGBColor[
              0.32142922651388994`, 0.4522204002455357, 0.9417243955590185], 
             UndirectedEdge[151, 311] -> 
             RGBColor[
              0.33701895011078703`, 0.4562465472557618, 0.9431706085812261], 
             UndirectedEdge[299, 371] -> 
             RGBColor[
              0.3200237345464615, 0.44107599148879184`, 0.9419983164995158], 
             UndirectedEdge[140, 389] -> 
             RGBColor[
              0.26557269799934, 0.3933163095480928, 0.9385506011632656], 
             UndirectedEdge[176, 205] -> 
             RGBColor[
              0.3812276367357902, 0.493182533004934, 0.9465557211288609], 
             UndirectedEdge[152, 179] -> 
             RGBColor[
              0.2238675261748019, 0.35262934240364946`, 0.9360602964821044], 
             UndirectedEdge[142, 293] -> 
             RGBColor[
              0.5705621841304782, 0.6464933294806976, 0.9637502028884042], 
             UndirectedEdge[105, 259] -> 
             RGBColor[
              0.35753817451232517`, 0.48410332919657934`, 0.9440029942146995],
              UndirectedEdge[274, 318] -> 
             RGBColor[
              0.47669536107992627`, 0.5855732892539163, 0.9520758009939547], 
             UndirectedEdge[231, 369] -> 
             RGBColor[
              0.38187859740377544`, 0.5048079929735556, 0.9455968509262058], 
             UndirectedEdge[151, 348] -> 
             RGBColor[
              0.36822311882978476`, 0.4890441070379955, 0.9449476398273423], 
             UndirectedEdge[147, 231] -> 
             RGBColor[
              0.49197088331615413`, 0.5984431519686036, 0.9531488965648246], 
             UndirectedEdge[66, 354] -> 
             RGBColor[
              0.5428055015691784, 0.635083308022227, 0.9590701205324379], 
             UndirectedEdge[24, 65] -> 
             RGBColor[
              0.29279030510239834`, 0.42507155301313404`, 0.9399853467799169],
              UndirectedEdge[42, 347] -> 
             RGBColor[
              0.22342238050199298`, 0.3521614660776615, 0.9360349460945719], 
             UndirectedEdge[52, 129] -> 
             RGBColor[
              0.31545631704061516`, 0.44183694942917284`, 0.9415345712873471],
              UndirectedEdge[3, 7] -> 
             RGBColor[
              0.5860780361979605, 0.6746704086782876, 0.9606757532838862], 
             UndirectedEdge[156, 352] -> 
             RGBColor[
              0.3070964329678969, 0.4382447969529676, 0.9408682879283621], 
             UndirectedEdge[229, 329] -> 
             RGBColor[
              0.21996973382081428`, 0.3485325155052994, 0.9358383229738119], 
             UndirectedEdge[80, 187] -> 
             RGBColor[
              0.23296053561051272`, 0.36218667185067854`, 0.9365781299175662],
              UndirectedEdge[247, 362] -> 
             RGBColor[
              0.38609365114236893`, 0.5042994724726292, 0.9462864531355444], 
             UndirectedEdge[43, 321] -> 
             RGBColor[
              0.31746730347917274`, 0.4450980898521708, 0.94160707963247], 
             UndirectedEdge[84, 270] -> 
             RGBColor[
              0.58294448618763, 0.6540521684844549, 0.9572357233801574], 
             UndirectedEdge[318, 322] -> 
             RGBColor[
              0.47118776839199494`, 0.5808028892872876, 0.9517248620580527], 
             UndirectedEdge[218, 276] -> 
             RGBColor[
              0.3632263544389204, 0.4890301447527602, 0.9443654400097621], 
             UndirectedEdge[201, 303] -> 
             RGBColor[
              0.4178722125027617, 0.5313877604006121, 0.9486708432577797], 
             UndirectedEdge[283, 364] -> 
             RGBColor[
              0.41157901024692733`, 0.514291451548817, 0.9492665691672673], 
             UndirectedEdge[65, 340] -> 
             RGBColor[
              0.3208353395962905, 0.4518904821383725, 0.9416797990071122], 
             UndirectedEdge[83, 214] -> 
             RGBColor[
              0.2984232317954186, 0.4268470584895184, 0.9404579044866765], 
             UndirectedEdge[124, 157] -> 
             RGBColor[
              0.4991836571250724, 0.6040559115212468, 0.9537838251959629], 
             UndirectedEdge[311, 344] -> 
             RGBColor[
              0.195937641553685, 0.32327326280989077`, 0.9344697308714933], 
             UndirectedEdge[190, 226] -> 
             RGBColor[
              0.48281743221910167`, 0.5876337359795225, 0.9533617189396671], 
             UndirectedEdge[380, 389] -> 
             RGBColor[
              0.23131822471171923`, 0.3604604989675214, 0.9364846027414611], 
             UndirectedEdge[124, 179] -> 
             RGBColor[
              0.3727374692182511, 0.4836925343401062, 0.946123766277892], 
             UndirectedEdge[199, 215] -> 
             RGBColor[
              0.3500634766975935, 0.46479920390114704`, 0.9443829853895969], 
             UndirectedEdge[146, 267] -> 
             RGBColor[
              0.6166950960681867, 0.6992460661288386, 0.9632779230362118], 
             UndirectedEdge[109, 249] -> 
             RGBColor[
              0.3807176226038627, 0.5041802021005333, 0.9454799681503112], 
             UndirectedEdge[36, 61] -> 
             RGBColor[
              0.3571193217871302, 0.483659746607394, 0.9439792635319717], 
             UndirectedEdge[13, 232] -> 
             RGBColor[
              0.32302192577053496`, 0.4535903019063161, 0.9418262329769763], 
             UndirectedEdge[38, 119] -> 
             RGBColor[
              0.3062968346765644, 0.428557828240853, 0.9411466671615238], 
             UndirectedEdge[91, 256] -> 
             RGBColor[
              0.4733681060022967, 0.5816028302417386, 0.9521645630327855], 
             UndirectedEdge[6, 69] -> 
             RGBColor[
              0.5744086035541994, 0.6585888278523933, 0.9627459817666673], 
             UndirectedEdge[90, 97] -> 
             RGBColor[
              0.5701394652119229, 0.651762961379403, 0.9628605076484479], 
             UndirectedEdge[233, 257] -> 
             RGBColor[
              0.6115530111951278, 0.19860638891240467`, 0.42104609133562043`],
              UndirectedEdge[66, 119] -> 
             RGBColor[
              0.46647094387836285`, 0.5578033229822533, 0.9546148758265995], 
             UndirectedEdge[33, 116] -> 
             RGBColor[
              0.3602672691696697, 0.4829184209400609, 0.9443068254753739], 
             UndirectedEdge[335, 349] -> 
             RGBColor[
              0.377388243554426, 0.5012964613073678, 0.9452678230613354], 
             UndirectedEdge[165, 274] -> 
             RGBColor[
              0.3917034144329457, 0.5136955428209328, 0.9461799730913061], 
             UndirectedEdge[95, 169] -> 
             RGBColor[
              0.6325395981158257, 0.7064470777382018, 0.9675971938751241], 
             UndirectedEdge[135, 259] -> 
             RGBColor[
              0.34841458497983313`, 0.476200934508478, 0.9434216471573627], 
             UndirectedEdge[93, 273] -> 
             RGBColor[
              0.23348868010633295`, 0.3627417852020808, 0.9366082069652834], 
             UndirectedEdge[89, 263] -> 
             RGBColor[
              0.3442870792641142, 0.4700981666809434, 0.9432511987144723], 
             UndirectedEdge[71, 289] -> 
             RGBColor[
              0.29787051048814117`, 0.4297944125002962, 0.9402972395102492], 
             UndirectedEdge[32, 215] -> 
             RGBColor[
              0.40815049840667494`, 0.525852346647284, 0.9476909553438811], 
             UndirectedEdge[8, 239] -> 
             RGBColor[
              0.3556182275275035, 0.4817887398163168, 0.9439045161764543], 
             UndirectedEdge[110, 111] -> 
             RGBColor[
              0.27939576293564083`, 0.4108493381194622, 0.9392278090462982], 
             UndirectedEdge[29, 162] -> 
             RGBColor[
              0.42366281429023567`, 0.5413771686511745, 0.948216397789625], 
             UndirectedEdge[337, 353] -> 
             RGBColor[
              0.3029103428926498, 0.4312164854010701, 0.9407261372880322], 
             UndirectedEdge[306, 308] -> 
             RGBColor[
              0.3272737435397173, 0.4530009513857621, 0.9422535761394464], 
             UndirectedEdge[185, 190] -> 
             RGBColor[
              0.4001290922002163, 0.520503616484924, 0.9468521899160106], 
             UndirectedEdge[71, 385] -> 
             RGBColor[
              0.5215722313968084, 0.6133045766626779, 0.958134935678581], 
             UndirectedEdge[146, 158] -> 
             RGBColor[
              0.556788412892278, 0.6502927501470022, 0.9586498165720769], 
             UndirectedEdge[157, 386] -> 
             RGBColor[
              0.4040272956839742, 0.5243698693442916, 0.9469652399070413], 
             UndirectedEdge[24, 124] -> 
             RGBColor[
              0.41770069435279406`, 0.5309517347896406, 0.9486843554321736], 
             UndirectedEdge[22, 74] -> 
             RGBColor[
              0.3460180057482646, 0.47263088893122507`, 0.9433236510273395], 
             UndirectedEdge[303, 385] -> 
             RGBColor[
              0.6573384818266246, 0.7308507060005853, 0.9674288896859021], 
             UndirectedEdge[130, 317] -> 
             RGBColor[
              0.25443584385358486`, 0.384758582427333, 0.9378011169521376], 
             UndirectedEdge[73, 291] -> 
             RGBColor[
              0.6933814498032487, 0.7581051398431993, 0.9684500616396224], 
             UndirectedEdge[241, 255] -> 
             RGBColor[
              0.3681305743050479, 0.49327793350754223`, 0.9446779325630004], 
             UndirectedEdge[385, 400] -> 
             RGBColor[
              0.5189126153054455, 0.6105091515212557, 0.9579834744767273], 
             UndirectedEdge[130, 311] -> 
             RGBColor[
              0.2324176458039443, 0.3616160602427733, 0.9365472131462156], 
             UndirectedEdge[143, 308] -> 
             RGBColor[
              0.47884521694988136`, 0.5766261998586328, 0.9543986984453898], 
             UndirectedEdge[297, 397] -> 
             RGBColor[
              0.2760268720337129, 0.4063517852276761, 0.9390709827851131], 
             UndirectedEdge[237, 324] -> 
             RGBColor[
              0.32134165097449113`, 0.4527517197982787, 0.9416965837421978], 
             UndirectedEdge[107, 160] -> 
             RGBColor[
              0.7128033543830368, 0.7745406259026908, 0.9729272259926787], 
             UndirectedEdge[125, 185] -> 
             RGBColor[
              0.4037566614763376, 0.5236456346649672, 0.9470833354225514], 
             UndirectedEdge[269, 388] -> 
             RGBColor[
              0.3163858019688317, 0.43705013779867685`, 0.9417985435385785], 
             UndirectedEdge[47, 300] -> 
             RGBColor[
              0.5318940143421522, 0.6256050928231319, 0.9583863766764964], 
             UndirectedEdge[37, 365] -> 
             RGBColor[
              0.6815718032629794, 0.7472428659174937, 0.9584541625661298], 
             UndirectedEdge[356, 389] -> 
             RGBColor[
              0.3050806341799225, 0.4275360981411034, 0.941068011921196], 
             UndirectedEdge[227, 243] -> 
             RGBColor[
              0.335978865758314, 0.4634718475494626, 0.9427009421423805], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.35419777393686713`, 0.4682671706978866, 0.9446982977051286], 
             UndirectedEdge[186, 348] -> 
             RGBColor[
              0.3272249873800104, 0.45397521987064327`, 0.9422132504461485], 
             UndirectedEdge[61, 90] -> 
             RGBColor[
              0.6323949919871796, 0.7081717856119512, 0.9667363422176115], 
             UndirectedEdge[72, 325] -> 
             RGBColor[
              0.2476892815460853, 0.37766751768539464`, 0.9374169102093701], 
             UndirectedEdge[341, 358] -> 
             RGBColor[
              0.41107433294627227`, 0.5304736588265028, 0.9474142708899446], 
             UndirectedEdge[102, 337] -> 
             RGBColor[
              0.34705225097118975`, 0.47502094926308935`, 0.9433348404389965],
              UndirectedEdge[297, 378] -> 
             RGBColor[
              0.30074536195477736`, 0.4277616988098747, 0.940646023105181], 
             UndirectedEdge[300, 370] -> 
             RGBColor[
              0.5834115418390339, 0.6702269857947102, 0.9616690279734368], 
             UndirectedEdge[46, 52] -> 
             RGBColor[
              0.27377761381748666`, 0.4050880089984395, 0.9389026021379974], 
             UndirectedEdge[75, 200] -> 
             RGBColor[
              0.6248603769021068, 0.698755630465492, 0.9640839594651673], 
             UndirectedEdge[204, 343] -> 
             RGBColor[
              0.32240451650132634`, 0.4449844341983905, 0.9420824146697475], 
             UndirectedEdge[32, 199] -> 
             RGBColor[
              0.24550743349570497`, 0.3753742570472885, 0.9372926571906559], 
             UndirectedEdge[301, 313] -> 
             RGBColor[
              0.396999633242371, 0.5182828613579595, 0.9465174434705802], 
             UndirectedEdge[166, 363] -> 
             RGBColor[
              0.21290531856843387`, 0.3411073671652506, 0.9354360149760546], 
             UndirectedEdge[333, 353] -> 
             RGBColor[
              0.29992148443951494`, 0.4286276864333585, 0.9405356898703423], 
             UndirectedEdge[130, 146] -> 
             RGBColor[
              0.4661823177657065, 0.5673425762378581, 0.9530402081889939], 
             UndirectedEdge[71, 271] -> 
             RGBColor[
              0.32190900185330207`, 0.4506153455110923, 0.941828950923634], 
             UndirectedEdge[123, 332] -> 
             RGBColor[
              0.3171047587015643, 0.4480413658447093, 0.941464713108155], 
             UndirectedEdge[340, 361] -> 
             RGBColor[
              0.4464854762655095, 0.5583712241947213, 0.9504370432859626], 
             UndirectedEdge[165, 322] -> 
             RGBColor[
              0.3861958217450143, 0.508925142854304, 0.9458290341554041], 
             UndirectedEdge[278, 302] -> 
             RGBColor[
              0.43310197129425343`, 0.5482743186857402, 0.9491711261495857], 
             UndirectedEdge[322, 355] -> 
             RGBColor[
              0.45678308171201976`, 0.5691085157167439, 0.9505908723564992], 
             UndirectedEdge[68, 333] -> 
             RGBColor[
              0.37744434608619537`, 0.5013450545005912, 0.9452713978650502], 
             UndirectedEdge[150, 156] -> 
             RGBColor[
              0.37598476780910917`, 0.5000808411575164, 0.9451783948278887], 
             UndirectedEdge[29, 357] -> 
             RGBColor[
              0.3397483221935531, 0.4618293422297194, 0.9431208132233465], 
             UndirectedEdge[250, 325] -> 
             RGBColor[
              0.34926109109586634`, 0.4741876469671006, 0.9435761481799168], 
             UndirectedEdge[53, 131] -> 
             RGBColor[
              0.33554192847538483`, 0.46505128644285315`, 0.9426014128677423],
              UndirectedEdge[92, 267] -> 
             RGBColor[
              0.43179243942932294`, 0.5448766262688253, 0.9495675474811986], 
             UndirectedEdge[269, 309] -> 
             RGBColor[
              0.24092898319237202`, 0.37056201548796996`, 0.9370319212190912],
              UndirectedEdge[162, 336] -> 
             RGBColor[
              0.2924251879662221, 0.4160361664949954, 0.9402813322808927], 
             UndirectedEdge[94, 204] -> 
             RGBColor[
              0.3935799948251498, 0.515320942436987, 0.9462995471345024], 
             UndirectedEdge[29, 183] -> 
             RGBColor[
              0.40349829264058046`, 0.52391167349657, 0.9469315323008952], 
             UndirectedEdge[145, 208] -> 
             RGBColor[
              0.6312152049648976, 0.7053201570603878, 0.9675035045767093], 
             UndirectedEdge[75, 133] -> 
             RGBColor[
              0.6144964881238052, 0.6879928265777877, 0.9634889803979868], 
             UndirectedEdge[169, 326] -> 
             RGBColor[
              0.6045091966428979, 0.6810639678880185, 0.9658515657452964], 
             UndirectedEdge[95, 97] -> 
             RGBColor[
              0.3173576044118436, 0.4468147229161381, 0.9415337563647348], 
             UndirectedEdge[37, 78] -> 
             RGBColor[
              0.40699565152959194`, 0.5269409099838629, 0.94715438091671], 
             UndirectedEdge[55, 397] -> 
             RGBColor[
              0.2729381994364897, 0.4031053944948411, 0.9388950874499828], 
             UndirectedEdge[185, 226] -> 
             RGBColor[
              0.5540462161213613, 0.6488387036017454, 0.958035694152687], 
             UndirectedEdge[39, 254] -> 
             RGBColor[
              0.26611032001652285`, 0.39702919707912177`, 0.9384659610987771],
              UndirectedEdge[71, 201] -> 
             RGBColor[
              0.28210596207294547`, 0.4138416310627047, 0.9393768892504586], 
             UndirectedEdge[227, 383] -> 
             RGBColor[
              0.3545620181985901, 0.48152553218358773`, 0.9438133561661], 
             UndirectedEdge[38, 151] -> 
             RGBColor[
              0.4470831312871756, 0.5612210364261243, 0.9498307443773351], 
             UndirectedEdge[45, 74] -> 
             RGBColor[
              0.4413156711319314, 0.551460425904551, 0.9504217118429503], 
             UndirectedEdge[292, 303] -> 
             RGBColor[
              0.4080004341243544, 0.5210118954180062, 0.9481086600831168], 
             UndirectedEdge[185, 357] -> 
             RGBColor[
              0.35292482239035583`, 0.47275233949889317`, 0.9440957482522736],
              UndirectedEdge[86, 376] -> 
             RGBColor[
              0.27754807671780024`, 0.4060837926989024, 0.9392259685840381], 
             UndirectedEdge[212, 309] -> 
             RGBColor[
              0.25642492301720743`, 0.3868492307432033, 0.9379143920679269], 
             UndirectedEdge[50, 127] -> 
             RGBColor[
              0.6826468320385839, 0.7470549233015933, 0.942190363034084], 
             UndirectedEdge[92, 374] -> 
             RGBColor[
              0.38662241518086793`, 0.5082055656975265, 0.9460115977091095], 
             UndirectedEdge[118, 141] -> 
             RGBColor[
              0.31206224282768075`, 0.4347443503530942, 0.9414703590576641], 
             UndirectedEdge[205, 390] -> 
             RGBColor[
              0.4740084474030028, 0.5670897590041984, 0.9548281776494338]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {3}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.9116319596688005, 0.9323745953223082, 0.9914334642083096], 
             316 -> RGBColor[
              0.33917267344426594`, 0.4681960552483498, 0.9428327607266177], 
             308 -> RGBColor[
              0.25586890372255156`, 0.38626481921086064`, 0.9378827275916531],
              160 -> RGBColor[
              0.8840082961777506, 0.9103482358789153, 0.9887986945245978], 
             245 -> RGBColor[
              0.23754982944882125`, 0.3670103106527763, 0.936839483412406], 
             155 -> RGBColor[
              0.213823940563589, 0.34207289712615707`, 0.9354883291396993], 
             213 -> RGBColor[
              0.18775684365418513`, 0.31467472552497133`, 0.9340038465335228],
              352 -> RGBColor[
              0.2852925576378371, 0.417190945043234, 0.9395583611537335], 27 -> 
             RGBColor[
              0.46869528135121225`, 0.5795469697395446, 0.9513165559168051], 
             367 -> 
             RGBColor[
              0.39048460228949333`, 0.5126398690015539, 0.9461023114592785], 
             19 -> RGBColor[
              0.36887799096486745`, 0.49392530825202435`, 0.9447255572916495],
              164 -> RGBColor[
              0.415624577782344, 0.5344148522015528, 0.9477042084672755], 190 -> 
             RGBColor[
              0.32890030829795663`, 0.4592986488627011, 0.9421782147029908], 
             103 -> RGBColor[
              0.4163456465758177, 0.5350394057484884, 0.9477501543331796], 
             138 -> RGBColor[
              0.1860253618840621, 0.31285482840228707`, 0.9339052412082121], 
             291 -> RGBColor[
              0.9395654439329824, 0.9544485875544974, 0.9871841189515437], 28 -> 
             RGBColor[
              0.36070278717079546`, 0.48684435762328926`, 0.9442046405349401],
              337 -> RGBColor[
              0.35732941836527193`, 0.4839225151143909, 0.9439896924576051], 
             195 -> RGBColor[
              0.5647993997064433, 0.6575686224615152, 0.958882224154714], 114 -> 
             RGBColor[
              0.2737069847647237, 0.4050137733858451, 0.9388985799179288], 93 -> 
             RGBColor[
              0.18199350204799294`, 0.3086170880799, 0.93367563275515], 34 -> 
             RGBColor[
              0.23049076456212023`, 0.35959078588628923`, 0.936437480110059], 
             161 -> RGBColor[
              0.3331462935925693, 0.4629763079154685, 0.9424487651313861], 22 -> 
             RGBColor[
              0.39945159805580666`, 0.5204066300400227, 0.946673680500305], 
             124 -> RGBColor[
              0.5539949563828697, 0.6487970886368131, 0.9580316587983023], 84 -> 
             RGBColor[
              0.9446594012585178, 0.958247652587292, 0.9785613779162622], 46 -> 
             RGBColor[
              0.3017271295345842, 0.4344647221187572, 0.9404942857104829], 
             241 -> RGBColor[
              0.3337081584129609, 0.46346296698274475`, 0.9424845666609039], 
             185 -> RGBColor[
              0.4713578761024759, 0.581708584107147, 0.9515261651290304], 390 -> 
             RGBColor[
              0.7348220388635813, 0.7927678287053527, 0.9742038515976965], 
             121 -> RGBColor[
              0.42405595175406813`, 0.5417176845626827, 0.9482414481611825], 
             322 -> RGBColor[
              0.42504811279038834`, 0.5425770445848797, 0.9483046677850833], 
             126 -> RGBColor[
              0.22183345530124604`, 0.350491404948, 0.9359444591549936], 236 -> 
             RGBColor[
              0.22442486378535326`, 0.35321513956958445`, 0.9360920360345182],
              78 -> RGBColor[
              0.400938182792374, 0.5216942350209159, 0.9467684043651838], 376 -> 
             RGBColor[
              0.2142572103105877, 0.34252829110114136`, 0.9355130032108256], 
             254 -> RGBColor[
              0.2396106977122098, 0.3691764138641925, 0.9369568468112246], 
             290 -> RGBColor[
              0.6015041701679052, 0.6873672086531957, 0.9617717581394447], 
             251 -> RGBColor[
              0.18199350204799294`, 0.3086170880799, 0.93367563275515], 165 -> 
             RGBColor[
              0.34734353069964036`, 0.47527324112372843`, 0.9433534005257248],
              100 -> RGBColor[
              0.34354743552460304`, 0.4719852542804023, 0.9431115166979266], 
             235 -> RGBColor[
              0.5094497655998251, 0.6126332960211613, 0.9545248982054506], 70 -> 
             RGBColor[
              0.9871948157117643, 0.9889727414656584, 0.8618785726181107], 
             234 -> RGBColor[
              0.664376958487799, 0.737735596513351, 0.9671825443325432], 257 -> 
             RGBColor[
              0.20002103358538337`, 0.32756516673721403`, 0.9347022740068615],
              135 -> RGBColor[
              0.323455164565013, 0.454582339042107, 0.9418312549592791], 265 -> 
             RGBColor[
              0.2976573334784375, 0.4301871084237734, 0.9402625168458091], 
             111 -> RGBColor[
              0.3103002584512541, 0.44318822055117507`, 0.9409930359741371], 
             381 -> RGBColor[
              0.36042424496340464`, 0.4866030983631857, 0.9441868920717904], 
             182 -> RGBColor[
              0.41630856278066414`, 0.5350072856290121, 0.9477477913865443], 
             188 -> RGBColor[
              0.5213518728411138, 0.6222959628634605, 0.9554618756863403], 
             154 -> RGBColor[
              0.20589640168228598`, 0.33374055112691176`, 0.9350368675281518],
              336 -> RGBColor[
              0.18252962306084325`, 0.3091805852564412, 0.9337061640537119], 
             315 -> RGBColor[
              0.2785817473842138, 0.41013745797673073`, 0.9391761904375437], 
             368 -> RGBColor[
              0.3024251046554427, 0.4351983382249582, 0.9405340343610542], 
             269 -> RGBColor[
              0.18534706491862368`, 0.3121418952850998, 0.9338666131994807], 
             208 -> RGBColor[
              0.35079845026099465`, 0.4782657187984673, 0.9435735449451089], 
             86 -> 
             RGBColor[
              0.3408389431250127, 0.4696392942966634, 0.9429389339572505], 
             119 -> RGBColor[
              0.18801043567960526`, 0.31494126682235096`, 0.9340182882242146],
              377 -> RGBColor[
              0.3749005574812265, 0.4991417526655, 0.9451093099045255], 140 -> 
             RGBColor[
              0.3427922961638208, 0.4713311905205005, 0.9430633998856011], 85 -> 
             RGBColor[
              0.42050349624403505`, 0.5386407261514976, 0.9480150888373963], 
             351 -> RGBColor[
              0.29837225593882977`, 0.43093853725834774`, 0.9403032306222954],
              242 -> RGBColor[
              0.5338968752954676, 0.632480561001825, 0.9564494642334052], 117 -> 
             RGBColor[
              0.347937955321334, 0.47578810185438924`, 0.9433912767369901], 
             47 -> RGBColor[
              0.3182153544553041, 0.4500438788855908, 0.9414973788924706], 81 -> 
             RGBColor[
              0.3788085753956891, 0.5025266813603159, 0.9453583253503105], 
             275 -> RGBColor[
              0.36167667102803513`, 0.48768788687160436`, 0.9442666955531518],
              23 -> RGBColor[
              0.6674330113809058, 0.7401230082603083, 0.9674871431244901], 
             328 -> RGBColor[
              0.36503162137971523`, 0.490593776241522, 0.9444804700228947], 
             110 -> RGBColor[
              0.24849126742002764`, 0.3785104556877493, 0.9374625821184593], 
             6 -> RGBColor[
              0.839756246494103, 0.8750628526510642, 0.9845778945215004], 218 -> 
             RGBColor[
              0.3721136848769951, 0.49672790368800457`, 0.9449317328465185], 
             108 -> RGBColor[
              0.21449839414599955`, 0.34278179060409764`, 0.9355267382734529],
              297 -> RGBColor[
              0.23140665750910816`, 0.36055344744454043`, 0.9364896388584478],
              157 -> RGBColor[
              0.4443723578672751, 0.5593147344056806, 0.9495359915936236], 
             354 -> RGBColor[
              0.34067955106123643`, 0.4695012369022984, 0.9429287776358916], 
             385 -> RGBColor[
              0.7628202141095515, 0.8146402160015177, 0.9769944480483913], 
             270 -> RGBColor[
              0.22122957111674213`, 0.3498566843816177, 0.9359100688440527], 
             392 -> RGBColor[
              0.6626687537575453, 0.73640113399524, 0.9670122864491123], 33 -> 
             RGBColor[
              0.45017091400698506`, 0.5643371522899917, 0.9499054704633839], 
             252 -> 
             RGBColor[
              0.31463320045075654`, 0.446941197131147, 0.9412691272068753], 
             394 -> RGBColor[
              0.22634446945105935`, 0.3552327668342704, 0.9362013547373781], 
             260 -> RGBColor[
              0.9724171788023525, 0.9789493576302948, 0.931574700922403], 159 -> 
             RGBColor[
              0.25976951605538695`, 0.3903646100857766, 0.9381048616935693], 
             183 -> RGBColor[
              0.3619917095722905, 0.4879607574243407, 0.9442867695306141], 99 -> 
             RGBColor[
              0.4073094437290916, 0.5272127010154151, 0.9471743754781866], 
             329 -> RGBColor[
              0.2204746742437768, 0.34906323990490495`, 0.9358670785839072], 
             309 -> RGBColor[
              0.29651090146612036`, 0.4289821356908402, 0.9401972292387017], 
             17 -> RGBColor[
              0.2344917686782358, 0.3637960948906394, 0.9366653313755167], 
             349 -> RGBColor[
              0.3732219412795087, 0.4976878196812755, 0.9450023499644941], 
             347 -> RGBColor[
              0.18974202803712018`, 0.3167612801793957, 0.9341168998473138], 
             340 -> RGBColor[
              0.3374965013105029, 0.4667442391929453, 0.9427259565204352], 
             277 -> RGBColor[
              0.2301093625425649, 0.3591899081814518, 0.9364157598292792], 
             104 -> RGBColor[
              0.44506597843332024`, 0.5599155136776055, 0.9495801884827473], 
             79 -> RGBColor[
              0.2975269761237517, 0.43005009457886495`, 0.9402550931873062], 
             327 -> RGBColor[
              0.25659840482834156`, 0.38703157112608744`, 0.9379242716004278],
              191 -> RGBColor[
              0.3952647271346696, 0.516780172886385, 0.9464068967875147], 50 -> 
             RGBColor[
              0.3966063233898629, 0.5179421961320451, 0.9464923821145687], 
             225 -> RGBColor[
              0.40586240042020444`, 0.5259593448317684, 0.9470821711581144], 
             61 -> RGBColor[
              0.40636649365686583`, 0.5263959650569017, 0.9471142915334024], 
             196 -> RGBColor[
              0.5028570601136292, 0.6072810407094699, 0.9540058962797013], 1 -> 
             RGBColor[
              0.45548285265697636`, 0.5688205249124342, 0.9502764251312737], 
             263 -> RGBColor[
              0.40716772620551, 0.5270899524194185, 0.9471653453628999], 201 -> 
             RGBColor[
              0.2838876754618256, 0.4157143248015712, 0.9394783551921466], 
             371 -> 
             RGBColor[
              0.1948094195650038, 0.3220874299663812, 0.9344054802982928], 
             293 -> RGBColor[
              0.23765437281777407`, 0.3671201923619781, 0.9368454370026098], 
             362 -> RGBColor[
              0.2731107414578726, 0.4043870838663355, 0.9388646247436666], 
             184 -> RGBColor[
              0.22455235018136344`, 0.35334913585489547`, 0.9360992961961717],
              106 -> RGBColor[
              0.3217752229529791, 0.45312725805408377`, 0.9417242105652743], 
             206 -> RGBColor[
              0.35557704870274465`, 0.4824047005893699, 0.9438780330122685], 
             358 -> RGBColor[
              0.3975057987455476, 0.5187212764761933, 0.9465496958888581], 
             247 -> RGBColor[
              0.49907656082686525`, 0.6042118610789229, 0.9537082815274222], 
             220 -> RGBColor[
              0.27829488767567523`, 0.40983595023510067`, 0.9391598542015134],
              107 -> RGBColor[
              0.5415984125883231, 0.6387330159264664, 0.9570557574607594], 
             375 -> RGBColor[
              0.2646748104274345, 0.3955203854844251, 0.9383842109513247], 
             131 -> RGBColor[
              0.34335347829550766`, 0.47181725827713367`, 0.9430991579147983],
              127 -> RGBColor[
              0.9686873406873048, 0.9761676504711416, 0.9378883439535993], 
             210 -> RGBColor[
              0.6441897151052467, 0.7219651685541689, 0.9651704685726856], 
             357 -> RGBColor[
              0.2344917686782358, 0.3637960948906394, 0.9366653313755167], 
             181 -> RGBColor[
              0.3773482256450756, 0.5012617998056471, 0.945265273155538], 194 -> 
             RGBColor[
              0.3921006230880956, 0.5140395849937361, 0.9462052828755744], 
             118 -> RGBColor[
              0.20091175748064408`, 0.32850137402628987`, 0.9347529994149886],
              348 -> RGBColor[
              0.2668632087587419, 0.3978205308830974, 0.9385088369988475], 
             276 -> RGBColor[
              0.3543390240008456, 0.48133238581751575`, 0.9437991471730057], 
             305 -> RGBColor[
              0.246869823490122, 0.3768062153119356, 0.9373702432853624], 343 -> 
             RGBColor[
              0.2147790528600071, 0.3430767807073098, 0.9355427213720182], 
             280 -> RGBColor[
              0.3217264211809374, 0.45308498841198963`, 0.9417211009595136], 
             189 -> RGBColor[
              0.21403960833528635`, 0.3422995776283375, 0.9355006111002455], 
             168 -> 
             RGBColor[
              0.3458195558084371, 0.47395325067017335`, 0.9432562941932554], 
             363 -> RGBColor[
              0.24214272780710608`, 0.37183773803390885`, 0.9371010421793261],
              41 -> RGBColor[
              0.4228450050557896, 0.5406688233965846, 0.9481642877083664], 14 -> 
             RGBColor[
              0.34057388625392293`, 0.4694097153570711, 0.9429220447678053], 
             77 -> RGBColor[
              0.3938245459186928, 0.5155327603027186, 0.9463151297139349], 51 -> 
             RGBColor[
              0.5501344367965773, 0.6456629449222354, 0.9577277445549202], 
             179 -> RGBColor[
              0.19147998205363254`, 0.3185879800433993, 0.9342158737574816], 
             223 -> RGBColor[
              0.2829489547503914, 0.41472766981552317`, 0.9394248964363433], 
             323 -> RGBColor[
              0.262096089075567, 0.3928099858432353, 0.9382373565852122], 292 -> 
             RGBColor[
              0.264144118705011, 0.3949625948363594, 0.9383539888428207], 396 -> 
             RGBColor[
              0.37558562398063, 0.49973512283483984`, 0.945152961736087], 321 -> 
             RGBColor[
              0.2622609025015404, 0.3929832152037081, 0.9382467424660018], 
             143 -> RGBColor[
              0.7018215301772112, 0.7669875805064049, 0.9709146692991265], 
             112 -> RGBColor[
              0.42960668580939526`, 0.5465254514134015, 0.9485951360268665], 
             197 -> RGBColor[
              0.4594842268185013, 0.5720690207166119, 0.9505914279627855], 54 -> 
             RGBColor[
              0.2320610697951006, 0.36124127624925384`, 0.9365269066700189], 
             71 -> RGBColor[
              0.28032424868406536`, 0.4119689373238382, 0.9392754233087707], 
             177 -> RGBColor[
              0.23891823347992946`, 0.3684485900512977, 0.9369174119976053], 
             158 -> RGBColor[
              0.44159261054028487`, 0.5569070569852046, 0.9493588685519817], 
             226 -> RGBColor[
              0.6367345561402467, 0.7159688230963439, 0.9645452231763435], 
             350 -> RGBColor[
              0.22566414832493076`, 0.3545177061958585, 0.93616261145569], 
             203 -> RGBColor[
              0.36106231354726204`, 0.4871557613002635, 0.9442275492377319], 
             115 -> RGBColor[
              0.19945930786806126`, 0.326974757392841, 0.9346702845582586], 
             173 -> RGBColor[
              0.21946479339785174`, 0.34800179110569385`, 0.9358095673637166],
              212 -> 
             RGBColor[
              0.21633894456829447`, 0.3447163257955665, 0.9356315548971522], 
             129 -> RGBColor[
              0.38508453598084125`, 0.5079626029802239, 0.9457582240091823], 
             279 -> RGBColor[
              0.415624577782344, 0.5344148522015528, 0.9477042084672755], 26 -> 
             RGBColor[
              0.5213518728411138, 0.6222959628634605, 0.9554618756863403], 40 -> 
             RGBColor[
              0.30019519637224906`, 0.4328545632349705, 0.9404070443831799], 
             146 -> RGBColor[
              0.671984215244271, 0.7436784433087996, 0.967940764592172], 386 -> 
             RGBColor[
              0.3636822335006733, 0.4894250042829027, 0.944394488220459], 192 -> 
             RGBColor[
              0.4590253228350359, 0.5716964617894458, 0.9505553013601864], 
             300 -> RGBColor[
              0.7455726742290004, 0.801166306760673, 0.975275374460522], 221 -> 
             RGBColor[
              0.352676427621177, 0.4798923283979706, 0.9436932080018695], 62 -> 
             RGBColor[
              0.29658410197434315`, 0.42905907406616267`, 0.9402013978993546],
              286 -> RGBColor[
              0.358876975131005, 0.4852629310024042, 0.9440883014062669], 152 -> 
             RGBColor[
              0.2562550702959713, 0.38667070476389964`, 0.9379047192067272], 
             64 -> RGBColor[
              0.35334346234881486`, 0.4804700803529103, 0.943735710864879], 
             307 -> RGBColor[
              0.34497764078856274`, 0.4732240261958375, 0.9432026481126653], 
             37 -> RGBColor[
              0.41305312026680985`, 0.5321875849468098, 0.9475403574682363], 
             148 -> RGBColor[
              0.3001773430766525, 0.4328357982893343, 0.9404060276644073], 
             261 -> RGBColor[
              0.39356182175218285`, 0.5153052018345883, 0.9462983891623628], 
             387 -> RGBColor[
              0.4683780913036681, 0.5792894605696994, 0.9512915855543569], 15 -> 
             RGBColor[
              0.4590253228350359, 0.5716964617894458, 0.9505553013601864], 
             136 -> RGBColor[
              0.20268026234650494`, 0.3303601847699944, 0.9348537131508309], 
             198 -> RGBColor[
              0.4362361652809005, 0.5522675733242927, 0.9490175605965724], 63 -> 
             RGBColor[
              0.5200424480388751, 0.621232912820088, 0.9553587929693269], 310 -> 
             RGBColor[
              0.24653515044660512`, 0.3764544527237028, 0.9373511841506386], 
             171 -> 
             RGBColor[
              0.4441038832939284, 0.5590821952241721, 0.9495188846312126], 
             395 -> RGBColor[
              0.33428693531940495`, 0.46396427444893346`, 0.9425214458135902],
              311 -> RGBColor[
              0.2044548713207465, 0.3322254113186299, 0.9349547745066152], 
             353 -> RGBColor[
              0.24849126742002764`, 0.3785104556877493, 0.9374625821184593], 
             59 -> RGBColor[
              0.34379376158942465`, 0.47219860953704273`, 0.9431272123769594],
              397 -> RGBColor[
              0.3206470865583176, 0.4521501230108118, 0.9416523267117783], 
             229 -> RGBColor[
              0.21946479339785174`, 0.34800179110569385`, 0.9358095673637166],
              102 -> RGBColor[
              0.3367750835771075, 0.46611938341178777`, 0.9426799884203879], 
             299 -> RGBColor[
              0.44523804952791923`, 0.5600645530112025, 0.9495911527007387], 
             128 -> RGBColor[
              0.4288982046095901, 0.5459118006074308, 0.9485499922313003], 12 -> 
             RGBColor[
              0.18909950513700058`, 0.3160859478730652, 0.9340803091186795], 
             222 -> RGBColor[
              0.2517931842331501, 0.38198097961195865`, 0.9376506213962185], 
             92 -> RGBColor[
              0.3021789019665435, 0.43493956358877306`, 0.9405200134821455], 
             271 -> RGBColor[
              0.3634937550225388, 0.48926175369834635`, 0.9443824785384973], 
             361 -> RGBColor[
              0.5554744512205161, 0.6499982091964973, 0.95814813005149], 344 -> 
             RGBColor[
              0.18742041178662353`, 0.3143211143011516, 0.9339846872363715], 
             132 -> RGBColor[
              0.3489166200617647, 0.4766357720634302, 0.943453636388851], 80 -> 
             RGBColor[
              0.23087305434003186`, 0.35999259668144623`, 0.936459250947364], 
             324 -> RGBColor[
              0.3243574375992864, 0.4553638425948333, 0.9418887469991744], 
             244 -> RGBColor[
              0.2554763810799757, 0.38585225302614046`, 0.9378603740078437], 
             150 -> RGBColor[
              0.42306922732026175`, 0.5408630334523317, 0.9481785749527866], 
             125 -> RGBColor[
              0.33615544685019927`, 0.46558268522278723`, 0.9426405057160725],
              258 -> RGBColor[
              0.2592893371999934, 0.3898599116636602, 0.9380775162181156], 
             133 -> RGBColor[
              0.289427532314628, 0.42153706560107806`, 0.9397938418444299], 
             255 -> 
             RGBColor[
              0.40255299019713486`, 0.5230929000323398, 0.946871298465097], 
             326 -> RGBColor[
              0.2967989657714791, 0.4292849095401041, 0.940213634074739], 176 -> 
             RGBColor[
              0.5492604175291562, 0.6449533767068237, 0.9576589385565507], 
             230 -> RGBColor[
              0.30983676756063083`, 0.44278676803744677`, 0.9409635027444355],
              274 -> RGBColor[
              0.43606329816625106`, 0.5521178445181372, 0.9490065456568872], 
             87 -> RGBColor[
              0.30798752716811606`, 0.4410447969637349, 0.9408508060942842], 
             130 -> RGBColor[
              0.2603804202871421, 0.3910067091669167, 0.9381396517858159], 35 -> 
             RGBColor[
              0.47138624938641194`, 0.5817316188172481, 0.9515283987778766], 
             379 -> RGBColor[
              0.322126557522435, 0.45343156639955756`, 0.9417465972933672], 
             31 -> RGBColor[
              0.43183922265939756`, 0.5484591626223088, 0.9487373913007938], 
             18 -> RGBColor[
              0.4330255595937459, 0.5494867080478132, 0.948812983641214], 24 -> 
             RGBColor[
              0.28140643232271845`, 0.41310638094246827`, 0.9393370520660447],
              151 -> RGBColor[
              0.4695830289008276, 0.5802676831928937, 0.9513864426558372], 
             137 -> RGBColor[
              0.41463835613007616`, 0.5335606365753, 0.9476413672956746], 330 -> 
             RGBColor[
              0.2173738909179159, 0.34580412002840716`, 0.9356904935606972], 
             296 -> RGBColor[
              0.8170155172571198, 0.8569779987199576, 0.9823961293822382], 
             266 -> RGBColor[
              0.3109801256736465, 0.4437770873680913, 0.941036356512365], 302 -> 
             RGBColor[
              0.5004068742320413, 0.6052918694311809, 0.9538130086717762], 
             283 -> RGBColor[
              0.639490111164093, 0.7182059068010416, 0.9647621505617513], 388 -> 
             RGBColor[
              0.4474245390190398, 0.561958380312254, 0.9497304738776762], 284 -> 
             RGBColor[
              0.2791198401271499, 0.410703027566607, 0.9392068340232171], 318 -> 
             RGBColor[
              0.5173274239936015, 0.6190287339896955, 0.9551450563310222], 
             238 -> RGBColor[
              0.42436007187203373`, 0.5419810981233429, 0.9482608264261764], 
             72 -> RGBColor[
              0.2163381945350113, 0.344715537463031, 0.9356315121838663], 288 -> 
             RGBColor[
              0.37209322529509054`, 0.49671018262648736`, 0.9449304291800513],
              382 -> RGBColor[
              0.24583974331801584`, 0.3757235357401969, 0.9373115817434281], 
             389 -> RGBColor[
              0.1883530998348592, 0.31530142857568516`, 0.9340378024409302], 
             172 -> RGBColor[
              0.1883530998348592, 0.31530142857568516`, 0.9340378024409302], 
             243 -> RGBColor[
              0.28756971748512594`, 0.4195843844230079, 0.9396880420382805], 
             88 -> RGBColor[
              0.40629961235688544`, 0.5263380358364106, 0.9471100299161085], 
             273 -> RGBColor[
              0.284983858164673, 0.4168664823242615, 0.9395407811754167], 202 -> 
             RGBColor[
              0.22442486378535326`, 0.35321513956958445`, 0.9360920360345182],
              393 -> RGBColor[
              0.5342896093741658, 0.6327994002193809, 0.9564803816987126], 98 -> 
             RGBColor[
              0.29818244313732717`, 0.43073903196914176`, 0.9402924210640528],
              30 -> RGBColor[
              0.61447578612375, 0.6978981508507898, 0.9627929312640836], 116 -> 
             RGBColor[
              0.2703636243323544, 0.40149968959013, 0.9387081804873639], 373 -> 
             RGBColor[
              0.30966642598712424`, 0.44263922672809175`, 0.9409526487299988],
              240 -> RGBColor[
              0.3496790078108864, 0.477296114012997, 0.9435022150620721], 317 -> 
             RGBColor[
              0.24849126742002764`, 0.3785104556877493, 0.9374625821184593], 
             391 -> RGBColor[
              0.44840867422161623`, 0.5628107887606522, 0.9497931821025477], 
             73 -> RGBColor[
              0.4471974556735149, 0.5617616921319011, 0.9497160043277012], 
             303 -> RGBColor[
              0.5518567495436978, 0.647061195999653, 0.957863331323413], 29 -> 
             RGBColor[
              0.4450048757088704, 0.5598625895687993, 0.9495762950711764], 
             360 -> RGBColor[
              0.3497395610659869, 0.47734856219907, 0.9435060734619419], 320 -> 
             RGBColor[
              0.9649724807634001, 0.9733971140224184, 0.9441766328141286], 75 -> 
             RGBColor[
              0.9395654439329824, 0.9544485875544974, 0.9871841189515437], 
             200 -> RGBColor[
              0.3101553098712312, 0.44306267337648675`, 0.9409837999787911], 
             301 -> RGBColor[
              0.4113884437704819, 0.5307457258347641, 0.9474342857539059], 
             156 -> 
             RGBColor[
              0.32890030829795663`, 0.4592986488627011, 0.9421782147029908], 
             25 -> RGBColor[
              0.5748575517703585, 0.6657342834215882, 0.9596740387294104], 38 -> 
             RGBColor[
              0.4245832336735235, 0.542174389659355, 0.9482750460988331], 365 -> 
             RGBColor[
              0.950090486259149, 0.9622981468881774, 0.9693679676640233], 380 -> 
             RGBColor[
              0.27428334958857925`, 0.4056195693593577, 0.9389314030419921], 
             370 -> RGBColor[
              0.4212504094490674, 0.5392876648287473, 0.9480626814863515], 3 -> 
             RGBColor[
              0.5184926405203067, 0.6199747092584811, 0.9552367864443333], 57 -> 
             RGBColor[
              0.21215062602609838`, 0.3403141374529851, 0.9353930363522361], 
             227 -> RGBColor[
              0.384388014031502, 0.5073593106759172, 0.9457138422464806], 39 -> 
             RGBColor[
              0.2926099423208359, 0.42488198029405105`, 0.9399750753863297], 
             109 -> RGBColor[
              0.3316304284528306, 0.46166334172102413`, 0.9423521755451089], 
             256 -> RGBColor[
              0.38931803652557295`, 0.5116294483701461, 0.9460279789203551], 
             339 -> RGBColor[
              0.2836605000383407, 0.4154755490277348, 0.9394654178878551], 
             287 -> RGBColor[
              0.4252883468938064, 0.5427851232907432, 0.9483199752897223], 
             239 -> RGBColor[
              0.40953836901978913`, 0.5291432840731747, 0.9473164006267486], 
             285 -> RGBColor[
              0.25882567945060075`, 0.38937257797144925`, 0.9380511115952079],
              345 -> RGBColor[
              0.22183345530124604`, 0.350491404948, 0.9359444591549936], 366 -> 
             RGBColor[
              0.6511361929280913, 0.727391809824562, 0.9658628285635408], 216 -> 
             RGBColor[
              0.2027848939768266, 0.330470159247491, 0.934859671767389], 21 -> 
             RGBColor[
              0.2364756607883878, 0.36588129128443403`, 0.9367783110962845], 
             355 -> RGBColor[
              0.4885180506336512, 0.5956399868486081, 0.9528770769279151], 
             175 -> RGBColor[
              0.3389226242073571, 0.4679794751671794, 0.9428168278103518], 7 -> 
             RGBColor[
              0.6536634318756143, 0.7293661080980942, 0.9661147201234391], 13 -> 
             RGBColor[
              0.30207491415226445`, 0.4348302658027575, 0.9405140915299586], 
             294 -> 
             RGBColor[
              0.27829488767567523`, 0.40983595023510067`, 0.9391598542015134],
              193 -> RGBColor[
              0.27312993515751893`, 0.40440725766161456`, 0.9388657177964669],
              60 -> RGBColor[
              0.3647732489208881, 0.4903699870038633, 0.944464006758288], 65 -> 
             RGBColor[
              0.3041741778820782, 0.43703672508379976`, 0.940633641493789], 
             69 -> RGBColor[
              0.30906096061429594`, 0.44211480305372236`, 0.9409140690118342],
              217 -> RGBColor[
              0.2105731782240345, 0.33865613979704867`, 0.9353032030335335], 
             214 -> RGBColor[
              0.35357835593641035`, 0.4806735333723905, 0.9437506780765723], 
             170 -> RGBColor[
              0.5680867791534835, 0.6602374651913787, 0.9591410187068526], 
             359 -> RGBColor[
              0.34315203221268015`, 0.47164277580516295`, 0.9430863219485323],
              74 -> RGBColor[
              0.29258441344072245`, 0.42485514782242734`, 0.9399736215543739],
              246 -> RGBColor[
              0.4546046651494302, 0.5681075727319119, 0.9502072909937729], 
             264 -> RGBColor[
              0.23823191766179447`, 0.36772722861150164`, 0.9368783273270758],
              278 -> RGBColor[
              0.3657970683564656, 0.49125676794029943`, 0.9445292436273951], 
             45 -> RGBColor[
              0.5900469288231402, 0.6780657039866748, 0.9608698021315268], 
             306 -> RGBColor[
              0.39867858335688305`, 0.5197370835606635, 0.9466244246872396], 
             237 -> RGBColor[
              0.31832586434969584`, 0.4501395970017241, 0.9415044204852212], 
             228 -> RGBColor[
              0.24040860462946106`, 0.37001506462444406`, 0.9370022864297646],
              180 -> RGBColor[
              0.4713578761024759, 0.581708584107147, 0.9515261651290304], 383 -> 
             RGBColor[
              0.3247360223656782, 0.45569175369125825`, 0.9419128700857194], 
             53 -> RGBColor[
              0.327730378655262, 0.45828531460857264`, 0.9421036678206864], 
             304 -> RGBColor[0.178927, 0.305394, 0.933501], 48 -> 
             RGBColor[
              0.1883530998348592, 0.31530142857568516`, 0.9340378024409302], 
             5 -> RGBColor[
              0.4330255595937459, 0.5494867080478132, 0.948812983641214], 101 -> 
             RGBColor[
              0.4901035624587857, 0.596927176774746, 0.9530018942267109], 333 -> 
             RGBColor[
              0.35135170145900224`, 0.4787449171789677, 0.9436087976222252], 
             267 -> RGBColor[
              0.5614059768921024, 0.6548136889488775, 0.9586150814802518], 
             120 -> RGBColor[
              0.4354207774425951, 0.5515613253613368, 0.9489656048045346], 
             147 -> RGBColor[
              0.5261564290232863, 0.6261965180149375, 0.9558401079486701], 89 -> 
             RGBColor[
              0.28140643232271845`, 0.41310638094246827`, 0.9393370520660447],
              43 -> RGBColor[
              0.37267370445680503`, 0.4972129645006335, 0.9449674167989381], 
             199 -> RGBColor[
              0.18742041178662353`, 0.3143211143011516, 0.9339846872363715], 
             268 -> RGBColor[
              0.18051407950620355`, 0.3070621211876725, 0.9335913818300046], 
             169 -> RGBColor[
              0.9122194275143167, 0.9328430262359328, 0.9914894974158537], 20 -> 
             RGBColor[
              0.2701338331202079, 0.4012581644565597, 0.9386950942177779], 4 -> 
             RGBColor[
              0.2843062924415766, 0.4161543177891391, 0.9395021948098551], 
             167 -> RGBColor[
              0.4097351355216383, 0.5293137133273045, 0.9473289384142527], 
             142 -> RGBColor[
              0.9034699954431824, 0.9258664665994171, 0.9906549687741987], 16 -> 
             RGBColor[
              0.4755676512172742, 0.5851262691935479, 0.9518575740469817], 
             281 -> RGBColor[
              0.506022555930102, 0.6098509328172439, 0.9542550957059673], 289 -> 
             RGBColor[
              0.31541677229221704`, 0.4476198876767542, 0.9413190557117278], 
             398 -> RGBColor[
              0.3979467524603024, 0.5191032084209358, 0.9465777930696422], 
             178 -> RGBColor[
              0.27483080569137475`, 0.4061949804341175, 0.9389625798571576], 
             58 -> RGBColor[
              0.3289085275151681, 0.45930576793553984`, 0.9421787384242435], 
             186 -> RGBColor[
              0.38758676600127884`, 0.5101299088581892, 0.9459176638934496], 
             122 -> RGBColor[
              0.4409898357855673, 0.5563849637890084, 0.949320460277624], 249 -> 
             RGBColor[
              0.42980481675489485`, 0.5466970624800424, 0.9486077607555135], 
             113 -> RGBColor[
              0.8817131673880364, 0.9085181624816085, 0.9885797830917492], 52 -> 
             RGBColor[
              0.24582809810038908`, 0.3757112958781218, 0.9373109185655119], 
             187 -> 
             RGBColor[
              0.23504801688099355`, 0.36438074701991086`, 0.9366970088877683],
              259 -> RGBColor[
              0.3733740053946533, 0.4978195299748491, 0.9450120393554461], 42 -> 
             RGBColor[
              0.2571027329668658, 0.3875616519759273, 0.93795299234183], 134 -> 
             RGBColor[
              0.4169142071441726, 0.5355318643361123, 0.9477863825098367], 
             313 -> RGBColor[
              0.38261082271426, 0.5058199968811551, 0.9456006011872545], 248 -> 
             RGBColor[
              0.3813300763224481, 0.504710678728753, 0.9455189931596879], 174 -> 
             RGBColor[
              0.3716572568552603, 0.4963325686763173, 0.9449026496565771], 
             215 -> RGBColor[
              0.5127065416085635, 0.6152772935011425, 0.9547812835428221], 
             399 -> RGBColor[
              0.345317510620367, 0.4735184043617918, 0.9432243043178127], 83 -> 
             RGBColor[
              0.2432681076544268, 0.37302058360664636`, 0.9371651308967808], 
             95 -> RGBColor[
              0.35285976871733454`, 0.48005112924047083`, 0.9437048903343945],
              166 -> RGBColor[
              0.18366790932976162`, 0.3103769962965923, 0.9337709877727831], 
             384 -> RGBColor[
              0.2301093625425649, 0.3591899081814518, 0.9364157598292792], 
             233 -> RGBColor[0.817319, 0.134127, 0.164218], 295 -> 
             RGBColor[
              0.402809365429058, 0.5233149593724378, 0.9468876344681715], 141 -> 
             RGBColor[
              0.42321272817471745`, 0.5409873266798986, 0.9481877187003396], 
             319 -> RGBColor[
              0.6020702549805697, 0.6878267818059468, 0.9618163224095346], 
             205 -> RGBColor[
              0.2131948559424242, 0.3414116893030442, 0.9354525037011712], 
             224 -> RGBColor[
              0.76754382617623, 0.8183303376487883, 0.9774652535545333], 231 -> 
             RGBColor[
              0.4577853376090219, 0.5706897859222698, 0.9504576851809791], 
             332 -> RGBColor[
              0.29749133346723683`, 0.4300126318869929, 0.9402530633907462], 
             68 -> RGBColor[
              0.40353699071338844`, 0.5239451918222147, 0.9469339981078753], 
             10 -> RGBColor[
              0.18775684365418513`, 0.31467472552497133`, 0.9340038465335228],
              250 -> RGBColor[
              0.4194818136345734, 0.537755796026443, 0.9479499881249598], 282 -> 
             RGBColor[
              0.2644514524189427, 0.39528562205578455`, 0.9383714910431696], 
             374 -> 
             RGBColor[
              0.4710659283951924, 0.58147156780628, 0.9515031819360734], 232 -> 
             RGBColor[
              0.34396893738880546`, 0.47235033800987475`, 0.9431383744239941],
              253 -> RGBColor[
              0.3001773430766525, 0.4328357982893343, 0.9404060276644073], 55 -> 
             RGBColor[
              0.22522931231466187`, 0.3540606659788704, 0.9361378481881873], 
             325 -> RGBColor[
              0.2790403685571593, 0.41061949790775826`, 0.9392023082348738], 
             91 -> RGBColor[
              0.5574181754790204, 0.651576212113331, 0.958301147145216], 105 -> 
             RGBColor[
              0.341702343629997, 0.4703871284183096, 0.942993949073953], 36 -> 
             RGBColor[
              0.30787214991739453`, 0.4409235281578864, 0.940844235530541], 
             123 -> RGBColor[
              0.3367181839358917, 0.46607009980242575`, 0.942676362825564], 
             94 -> RGBColor[
              0.35713000950765406`, 0.4837497971845029, 0.943976986301528], 
             312 -> RGBColor[
              0.18355457276618556`, 0.31025787238232067`, 0.9337645334231539],
              96 -> RGBColor[
              0.6609507011328752, 0.7350589782271642, 0.9668410470195998], 2 -> 
             RGBColor[
              0.42888501470754964`, 0.5459003761772271, 0.9485491517824056], 
             262 -> RGBColor[
              0.4070424975651195, 0.5269814856652867, 0.9471573659046695], 
             272 -> RGBColor[
              0.3947521623972817, 0.5163362150731124, 0.9463742366156915], 97 -> 
             RGBColor[
              0.28185544010635255`, 0.41357831659180544`, 0.9393626223950752],
              372 -> RGBColor[
              0.181927754270743, 0.30854798299736047`, 0.9336718885165007], 
             356 -> RGBColor[
              0.4218081685249857, 0.5397707677065215, 0.948098221401462], 346 -> 
             RGBColor[
              0.7564738220465905, 0.8096823662875665, 0.9763618989979611], 
             341 -> RGBColor[
              0.42464286714699695`, 0.5422260411768123, 0.9482788458910311], 
             209 -> RGBColor[
              0.5888191267851396, 0.6770689189803744, 0.9607731450575083], 
             378 -> RGBColor[
              0.37008406640044655`, 0.494969950175209, 0.944802407351914], 66 -> 
             RGBColor[
              0.7449314520771204, 0.8006653791421556, 0.9752114634289843], 
             139 -> RGBColor[
              0.7473561921730353, 0.8025596045337915, 0.9754531388612606], 56 -> 
             RGBColor[
              0.4371748586049157, 0.5530806223014564, 0.9490773733051246], 
             335 -> RGBColor[
              0.3815545458293434, 0.5049051029334601, 0.9455332961581766], 
             314 -> RGBColor[
              0.2834785800730524, 0.4152843396098248, 0.9394550578149583], 
             144 -> RGBColor[
              0.4618525057134134, 0.57399169621325, 0.9507778675526845], 298 -> 
             RGBColor[
              0.505138693445884, 0.6091333734350046, 0.9541855148135148], 204 -> 
             RGBColor[
              0.4300299801426456, 0.5468920876894712, 0.9486221079674768], 
             207 -> RGBColor[
              0.3099849003171966, 0.4429150731858152, 0.9409729416326953], 
             334 -> RGBColor[
              0.3896800313587061, 0.5119429901002167, 0.9460510449110229], 
             149 -> RGBColor[
              0.24992653081401459`, 0.38001900851578474`, 0.9375443182454649],
              219 -> RGBColor[
              0.27788152629348223`, 0.40940148121379044`, 0.9391363138823109],
              400 -> RGBColor[
              0.2750050165013395, 0.4063780870409938, 0.9389725009050632], 9 -> 
             RGBColor[
              0.3228450428036656, 0.4540538822380393, 0.9417923785401555], 11 -> 
             RGBColor[
              0.766103401961151, 0.8172050673043392, 0.9773216855303039], 44 -> 
             RGBColor[
              0.6349950610963795, 0.7145566226563739, 0.9644082837545099], 
             153 -> RGBColor[
              0.36642171405748725`, 0.4917978046509186, 0.9445690454991117], 
             32 -> RGBColor[
              0.3035944552047864, 0.4364273997934254, 0.9406006271449402], 
             162 -> RGBColor[
              0.40232075287160096`, 0.5228917477335496, 0.9468565005080735], 
             90 -> RGBColor[
              0.8584234903174934, 0.8899476061670006, 0.9863583929018206], 
             331 -> RGBColor[
              0.4134788640866295, 0.5325563428450311, 0.9475674854879647], 8 -> 
             RGBColor[
              0.3016980860352178, 0.43443419555945895`, 0.94049263172616], 
             364 -> RGBColor[
              0.18366790932976162`, 0.3103769962965923, 0.9337709877727831], 
             342 -> RGBColor[
              0.6482466920144042, 0.7251345097497692, 0.9655748301163857], 
             163 -> RGBColor[
              0.2859866726634801, 0.4179205039446193, 0.9395978899775927], 49 -> 
             RGBColor[
              0.4036922856753097, 0.5240797005128791, 0.9469438933655269], 
             338 -> RGBColor[
              0.4285444389664072, 0.545605386588084, 0.9485274505973393], 76 -> 
             RGBColor[
              0.3392718169498538, 0.4682819283697925, 0.9428390780631246], 
             369 -> RGBColor[
              0.305971857198529, 0.4389262000248414, 0.9407360166714327], 82 -> 
             RGBColor[
              0.3517960584531294, 0.47912979687324875`, 0.9436371116569614], 
             67 -> RGBColor[
              0.4685968359759992, 0.579467047349033, 0.951308805936251], 211 -> 
             RGBColor[
              0.6367345561402467, 0.7159688230963439, 
               0.9645452231763435]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9mGk41G3YxiVbGGbGGGMMZp+JsVWihTktLbQQJSTFQyShTSoPqYhQlpJK
qqfNXmhRyhaSilTaVCKRJUXIFu+8x/Ee7/3l/+H+ch3XfZ3X+Tv/LO9gJ19p
KSmppBlSUv/73TOaQg3xNcCuudfIQVpkmNPakkbt9TEPvi8NZNhgb/ns6fdD
H/sXHfyxyp0ND7fHqS/sJPcGTVUBJb/EIV13v7p5GCChatH2mBYiThm7fD2a
wMXSuP7uQgILxDHp2nhtPXyQ1mc/PcEGUValUrFSgL1qDx/o8inocZNuvLFX
DVyLS7FPPEloSs5kZR9joiF+nLmJz4T996mupTMZcLnp8o7irAb3UmmBWRgR
ZWJeSs2kPKrtmszXKxqgqOfAmPFKNhw7U0JMc4RIyGeqClVYSB2aXjO/RQTr
Ep2PcWVa8Ilq33jlkwDdLesDpQUkpPs90jq5QgeM26p3r2zTwDLDKvklLTRQ
VD5/igyjYLV8z4H4IhXcifTSGGyQxjYefcQ1jY/OjwNjcxI0kLa7/oumpQHC
73cRiM5cuGYx9G6L1DBn86n6kFAi1v1636Z+UQ2/Rn+ujf7Cxe3kS+naQhLa
19W7XjyiAE/j7z5jmnwo3nsku9GAjJI0Ajma0Snum+Oz/l6zJnzeBtttuqUM
pZ5wzHdiwnKv0plpRRGUHmlc7S9hYmWxo8+JmwZ4Y6G0Um9SBQh//02tXxa1
bEXtkKxZCDFeXlenpoVQ1cOHvPdrY9Fmh5wxDhPlPbq/ivt00UdzJ1MKJPXp
ac2zmiWpp/BMVitdBjIHqtwOhnAQuHjVa5dkEdquksQdR2h47SvbqGaqiPJb
Tk29uTQ4PFt9yposwJsT54efnlDFF79nv6NoFNjmf6wKlObgwDVuWG2BPso8
0+tEWWysVdCzaTOQg6s66R+pJF3cse1rM3FUwPjvLq/Ht5mg7ktvPOhhjDVV
Ff53GjUROMwwd3FWgH1kY6p/ORum5c8iMizJmKbLOPuociBNlaf8cCGhzOjV
2f1x6lBwzl+VsIEBzts3ZunuLMx8mmI8ai1C0NC3Ef1AHgYZT1e0+SohvPzn
Smm6NsjbFgWO2whRsq6Dt+TbgLgkibrzh1APXWfFaV0cFgyHijTKDxliKJWU
oLqHhTjusWKDVF20/r73XfUOE04WqW34zQc5d+2/N++yIQw6tL1VWxdlZczj
mzdQEG34/N3dUi04ik3nUjvpaFT1fvrzOBlaRZcuXhcScGgLwfKpQAPvCkoS
wlfrwqvTvOHmRhImeyotO+dNis2qJwj7NPRhO/h4g9ReLrZmBPj4uGvBsz9A
2cOHhQyVjUdNN8jBwl6/hfeRhgcY2J15i42P1sRXggEK1lbumccokkXYrqlz
LZt1sCLvlqXnSQ5WWRQKX6Zp4IQoiT1MIKGkzKH8ppoKLENTkv8jknBtU37A
8jEObi2ZIFxPMsZtm11rDV0Z8Mhk7L59TwtpVgtjrpnr4jhzx79l7XyI3pv/
OWXFRsfXd6tvrZkB2zW5YSkrtRAVUl636wkHMzasnqx5qosItSVDZhE0iNYq
lYTTmHhTfN+t/5c+XOXU73X1URA4RYzOlsxjjYfazElfVZikRt4bDjNGxFBq
rvl2LVQTOqsV/vChdNxDK8uEhOnMr+oL+oWw2Z22MkNZFePXnZZTuUJsnmjV
uvBEBa+tb5RLZxmC88NPXnCBBVHvQUphmhAczdycIiUV1KcvdttjTcbXitXO
+ofY0Ln02uU/Nw78iduE238ScJs3c/ffcgaOiJvTItXV4Vkht/ecpF4uPeNi
/I1RcVq9onmUSB516rlU86ppMSmC87LeXg3eh2u8ZCZ1kVbtIHWRYwThW+ON
STZs1OxVLH7gIenXybW+Q41UCIU2HquHZ6PuFfv8xTsUhGl2BAe2KkCz/nh2
WRUDyz+dVUqc5iLpdNjtwBQlJNlYO0U6kpF7OY9gE86DtP0ypSX/CBBhf8Rz
RQAbUv93XgXERey7qIpjvN7KwlZlJGntCTT6SofHjZLGk5MCzN/Ybbs9VREl
6bvGhBUkdOSHi1seamOvxylW1zQJ3xWfXlsYx4f504OdoWoaKPCa9Tp7ioYE
vteTGDky7lTttnjeo4SeD0rNl9ewoZaaa31vjyY+GJzXK/hPE0ybJBMHPzbu
H43s7ngoh6lnVqoFgXTw5jUxev4IoJy0zWJrlwysDW0ckwN0sMEn6WHMCBO7
NRqj3x4S4eD4DGeGqsQH8tlFtUtIuGjVMX1skQzGNrU9LsyiwmNN8YuHJ1lY
2rt4tY/kfdfbNq0/4MMDVZAbdCWJg7Uezisz3tGxXl+esa+Sie87lBc8GaKD
0Zy55ULpgNiaMkeQ/JAJn/AFO27mGaDfr2+iyJmISf+pSu0sA0TUWg06D/Iw
sLyAVdLARnChS2ZAHw3Ujz/Xhc9Qg+/CyYmiMFXEF1et6PDiwS90VarzJQr+
o9sVhP6lIlX74GauswrI9U5Da6rUMGH82fpcFQdMx+CvFYv5aFBnzuar0iGc
UB2zbteDIO9l9ISXFkb3zmr1WyUNeW/iY5N8Clq2Dnw59ZEJmzrhTu2rGvg7
lDjTz5CMBT/9ZvyOlcEducETNhQRRn/+yvC5/00c6+8ls3rSCM+LvpO0lJn4
e0I2QEtJiLTJ/o0DPkzM1w51cxdQ0fGPllFuIRtXayqnL6SzoOl9nly3i4kT
nZ9aLc6RMdbgbln2kQPPuJ/b2k14yDH5eO3UVRaO0Vnjq7kG2FLwNsphBw+n
+gOmL9gYw0yj9GdOjyYKCi5mhgar4mx+2MEsihCdOTGP5afU0dc9Y9TyLwtk
y4V/bheL4G/8aPKgLg9XMm0tEtJn43qVfFH8HxY8/DVXrToxGzee5pP8JHrx
WFZXbv5cA3Oajm9+c5SDtKyFHm3L+HC9LP2i65km0uWph/9cpCLLQ/1DfhIR
nV+mHOX5AsxptNvuHc7GNSVj8rzLZAS1jkcst+EjpbwxU3RPDZvfysa0n9SA
e/XXDQZ7BOBRpgvENBnIM2p0RTwyng3KrsnmcGE1sno0/V8h1NCk3GTJAJnt
ah70hgCjUXHIwBsqcoq/P82K1keJ344W6jwueu/sVSSYkDHvauKQt5YcfP7T
Z316QEZnTyi+F3LhUjMe2AbJvh32zbHvnoGsBkv612ZZPH1+Wf7nWkWJX9Xu
6h4RYZNro+ydo3Q8ayE8JKeKEC6yWvNigIfhfXbKpPMkVBsu3r5QJIUbmWZn
72uRoC8aUxjQl4cdq3b2kQMkyGZQH9114YGfop2ziCWL8OsR8kfCOPCRtw3b
bEvEy+R5zPhDUnib/qfxZBMTdMXP0wmfNJCXaKdz10miv42PGGLJnA1d9j2u
yyTilsoMKmeJEMzKTddcm/VA3pOyIX4pB++ijq2Q/yJEX2xQ7N7fY+KVwfzm
0zuIiJlfYk331sXOPU0H5g+qoNz7fe9EkDxev+8xXL9KEX7b541cfyiLIwTV
+c9kKDCz/uZdtZCB3X7JmzzPCJDmt54aP0cKBzJGvobmkiBK+9rSsF+ADwk7
bHgiHqz0mwp8t8lh86v97smiPrGirApdVKwG26n9Be3dRAxuJnCdBlUxGUr9
ouM+JXbiLDEZMlCE7aG8RNp2IxRmNp9v72KClvT2Qr/LoHj76R1l0p+1ITXL
RM7H1xiioJzQwSoapnYHZ/x1UIP9apXWe63yYJ3/R97a0xCykR8HN4fxkODv
8iXFiIjXtu5KlXunxPqdLX55fgK87B+VG99DgHDEtnrihggxFcdmeZ0mgVhp
kr0uVh9S78yMPs7rFcunNs+tNRZhiOoTEhc4LF4SlzJiH6aGjC35FnFEPpSL
lFdVKQuRTT1d8tVaBSKv9zknI4WYv6CacvwhG/WfMrrTDs/GqLjv/PQ7Kvx+
aHnlL9DHu4OW4aejfoi3OTjm/k4WIiz46f61boPiKbPWJ4VEAYq8u4q+npmB
ddkLDP4kcjFkp1H+YpoO5X+r5xcpcLHZKKhzvYIiLtz7eyzwDQ+XWd+62lM1
MSMYhtYjWiisKe5dv4qC9pwylsMnfYSsX9q00JkJOW+b5tEyDaR/6Na4pivh
MhfhXpa9NjzrHoasD9AF/o1NylY3Qtlcd7kkyXz7RS17QNCX8PQ3j1eT5Syo
jURHBI7yoVJ6mDR2lYZu9Xap1yIS5qvdD2lMUUbWvvVSV+n94r9eo3zmoBIa
hk8F2ptJ/FXBpXD1JxYmLmyknv6uDmge8lsaqQKZDo+hraYiRC+aVyqvQoPP
nnqd51N8eHX7XTTlKeKwbIuz9ZAaHH98kHg3AbMcu+8E2+gh0WTFb/xgIz0v
2ahkGwGaVt11xjMUkHNpaVyxZO8RtzpYzGzVwj9Svy1nHdLAziK74tdUDs5b
Wy12CZH4zWsL4SquOvqll5OdI+hI4T/z32XOQlDl7OERGQXom2nkhO5Tgv1L
G9PnFH2cmxNrHDeLiZycVTsvVKjhUdqRl8cdNOB/rofZdmtAvN3vx3hqGBOe
AzyLh0xVKJAvXuXu+SY+qnb5bvodHva9rQo6PyKLgsWPtpZ1aWLdiXcK14wY
CPB7qnhlnyTf/I7v98+hY8SAW5hurIFr+cMlDjuZ+KSoHbVVV4iQS4zalB/T
4t2zNR+vqtCD+eJA+wUhneK8TSWqT2so8Ig9drHzERsupTZjj1bMgsyxg8FV
FTSsrLFb+lZmBgbW7//TfIaAl4XxWcOK+vidWmS/7hQH+twPjKJb+vAVqpX/
kfDMudpBSn6wIWpvpW87O5ODyV7ZF2b7OYh/MmWhv4uMqLOP3Dbm6eFS6d7g
nS9oiH1bdsTTX4gXfU4G7P/GxHStjlCHTE0IhtUD7npo42DFCm/Ze3fF2tE5
9NH5RNwv33nk6woVnOzRflHmMhN0kjSRkMOD9sKQ+V9kqdDLHtiSmUfEJbD+
bV4rxFEv6XNPUgXwOV7SfNyNjp2853lpEj8ojTv73m5YGw/dny4Qx5IRW5zt
mSLR237r+4zsfXqooLruDv2ijNcRFyMdGkgYPXbwpUXtlNic7OKkFiWPUpNv
7y+M6MC8IkHcsIgJbu2Ok4sl3B7S05Y7ND4ltj2Q1dTVz0TLfumVWhkGCP0p
fYj7gIfYf8ditmxRwMYTuglhC9mIIZQG91lLwZG1YluNIwsJ+iN96Z4SvY18
T7Tq6hKnrIhZPvM7C2t25tDleAxcq3k8Za4twtx3cnk9TBYCEtXZdTl8WC19
QBBRtHBZ77n4JIUNe7eu4d4oIqTWLKC1HOegvd1018856qiNnp/nqqeHFlrA
Qwd9Dj5v2Flz5KkW9unXz/JJZCIvuG5K7cOkWPh8vsmGpboYKCj+VXtcCNGr
bCmLL3/FBhbsF2Z+VOzbu7XgIkcbIz2t8yfuC3CVsiLGM1gDK3VCV+mHzQZj
jvSZJXM5CC8ourLm2yzMi7kc1PSSBb+586zV/Cig6h1yOOpPxCKP797v4kno
/djaOM9B4sfLTyw+/1nCDwtNi4aqJf3i7ldeoSPhKc7Z54+TKSghKA//oyJC
cD3ft91fBcGMTj2CKxObFo5Rz9XpoiUw++SHOiLMP/vbNiXz0Zh8NJb+i49r
HmYqlBYWKnJV8g8K9GHse+O34rVucYHTTcEnPgENz8r8TQUcpCsOEk0k8/PA
JTTWKJ2GI4NL3Lp/GkLn69ZRLw82wv3XRCouNELpyssvez0kHDgcvfZciz44
j59HfannomTF5x2qJfq4aX+06F8eFc6OdyMNYwWw27Yte+wsG0Fdv6IcxQQJ
h07GNzRTsahyojRfMncmIo1sQpImbhmgZriKjuR8UU/2RwYW3971yPLwoFgQ
f5zh6qCJfy51uLNrqJAa34gzK4jYMvop+3U5EwNl+5be19TF37G//5Hi9VFx
Orgh6upP8a0NvK9iSX6L/hDmcHOJNtwcHlkcf0QGUSHYQHsdEU0ZZxfnkkR4
zKX99oug4AJrhNHcwMQNrQ11rtEMKMQ5W0/OF4L3XNs0Zh0bJy96jPgukcXj
NsYS6qgqOqxXq4R8l0F9hOqF3ps6OBtacGXU3hg+tyqztxygQfuilNcdvjqu
Od2vn32ThS1rW7zcWYbIXqBgHXRZB6FHA0e6Dkp4xHioxymFh2XRG9+dthIh
LPSNHmMuD4FXo02mzyiitstnt/VqdRDUOpZ0XdeD2W/RRLopGU/yy+rvG7Gx
VOeL/2sTJnwfmlifHCDjYJR1XvkySc5ZKpdT1ETAOSPy1ddyVJCMNvxqolFg
ZNZmm3SUC1rJ2PZ51f3i1AVNzEPflOG0iWpCeawG+sPpzcfO8+D01fWpzxYu
8vVC3o4VacCQEB2utFTig98yD692IKNi0a/Jh40kWLreydvax4Gjd4RrVCEP
/XVrHkdk0zGUpUpv+IeAv4LX+TF3yXgX+faEkYT3vDER3KvFgns/PXf3cr3/
z3VWlRHVvpI8veGS/bSblhKuy+2v+CuWvNOFKnm7DC7C3dYwZT/oYZTBCxy9
3i8eX/7ytmakLtpZV/yuPFHHrLnmLaWzJXm+d5rF0NIG5ZLB0pLemfB++MPs
swEH8roz+w/8FYKmIL13kdRv8TPu4NqKCR64fTohhSVk4OXm6TnNleJS6w4j
hx8UFFYuaK9XIYMyddN59lsmdr7mN1RnETH+bfpwrJiJXzOH6OcShVhb3msb
fmpE3PdI46Rsgh4crg7ZhHayITNw7N9MZUUsPOS/zsSBCNl6nsAi2BiNfpa3
o9bRUGLYonK1VYgbd0ccmnW10ccvDagOYCGnYUupXp0GBi8r1TmMaWPnp+Vd
0hVMZMSEuk/+0MUwbaJz9CIdbgopbvMHBTCfPSTroDgmfmdUNDmzcjYcZuw5
skVaHV3LFnmwp7Txftwrc+UPif+2eQxxVIlw916TeO0wCWsZUhuf3FRFr9Cs
cn0vBcfIpFzWVkUo19V1lKmT8eujX3P0IgKe2EXecdmtiCDNTv64OglpnQsf
N18RYOmejOGF/BmIXIZ9fZ+UIfVy5NGFEiKCzqjH1oq4+Lg/brPyJQb0TIvb
so6zkPTC11XpFQkKpTW1D1hcsDV6LyyGMZoSVnTGLtNGivnbyGoLMvR+msU5
S7hJoa1uYzNfsn8J7YkpvHGxk2nNgtMlNNx75JD2fjUbCed+tm6J4kPbwEVA
uyqDhpfmdxs0SPB/7J9loftHHK/XTamco4uaeYHXHYuYeL8lwkepjYSDv0VR
iuY87Fzkl0D5LsCtWJ0ne1MnxHlxaTe75nJBnU07rfyZBh3bjul2YwO82Foq
I1JQwsuExx8bDqqglZ5esfC7MgxG7spkbhWgqvlBo6EnDRbS3w5brOZh7T6m
h/oNGux6i0f69xHBOtYUclRPAz6EP9b28lxMaBmk5TzQgM6W5XO2S/pemJHc
FbyNidO2H5ebL2Bj1s1Ty/75pgW5+gK7nj4+ZC7Hpw5L8jdzWwFLtlgXK6oj
hHPkNJEzg3Ivi2GE3Z7/UbJHqCjqCbrrIjTA0hcfSx6ZUvBJo+vdpu8iXG5r
OXVmTAffj7zy7Y80wLypOYpaGnwkueHN/kYRJo0+XT12mI94z6iVjVIGSJyU
qS5V1sSc8lody1BDVC+onpmbzcKC4pVxXYkk0M4EHjHv5CPhMEl9E18JMWqa
jp/jOAiRMcned0AdOtLJjKMUJrTedjhpJgrQ0rGBOvsuCbYJyfIMia5op7fy
KyVcrlxNsCS4SaNm2vQBBTJ4sNw6M+AtFw7U2mLZajqIFuOcvFIZyHVbu+/+
3/9+lVYBS0yJEH3dw+nOpyE0q/uY8mcKMhb8jZlzU5L/aVIZeQp0nOuKCSnt
VMOnDKnbb2LYmLar+FK9Uwv7LTPtDJLUYW111KnIVBn3yEmjz2cb4K9UQ6nx
EiqepR4wSBMI0Kcke3KLhMu3zrUKHU/kwNM8+uiBBg08K8y79dfMAO/86re3
lrCw+XUGp8+KBSOpgm0kTSaIE9OBimx9KJinXDvnpgWnxD1hbjU0eBx3CL3v
q4Mdhz+MpcoK4Sq7zEovkY0cUc1ilW4eVJpt9VRVVPHKXtpxej0RsWdzH5bw
B8T3lhWrjblpoP02P8YvWRdBXIWlipnGuCIoctAooKPCdsa6t0k8bLvzJDzy
jgwSPl2/K7Bggn/vJfv4Ax38D4p/h4g=
         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 5}], {
             RGBColor[
             0.44425420612536115`, 0.5591536164801236, 0.9495447043862439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.4502438641829234, 0.5643415572406167, 0.9499263601012251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 73}], {
             RGBColor[
             0.45134015416524564`, 0.5652911085221677, 0.9499962147294875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[
             0.6685980100225064, 0.7386693436970213, 0.9694281041115115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 162}], {
             RGBColor[
             0.4289018027642887, 0.5458561363229919, 0.9485664628196736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 183}], {
             RGBColor[
             0.4087372811146334, 0.5283906411683874, 0.9472815973309439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 291}], {
             RGBColor[
             0.6975241482949793, 0.7616345562334658, 0.9687302720414087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 357}], {
             RGBColor[
             0.3449873106676061, 0.4663083099015368, 0.9434708782533952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 368}], {
             RGBColor[
             0.3789539786562095, 0.5020094315686962, 0.9454052297461639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 387}], {
             RGBColor[
             0.4619304719803222, 0.5740549927410667, 0.9507840053428154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 28}], {
             RGBColor[
             0.39479390093917255`, 0.5163723669002582, 0.9463768961586729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 39}], {
             RGBColor[
             0.36074747851419275`, 0.48539117823563904`, 0.9442621135843676]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 50}], {
             RGBColor[
             0.41274566904870624`, 0.5319212861546361, 0.9475207669484871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 106}], {
             RGBColor[
             0.37533011883026435`, 0.49951381711565546`, 0.94513668117384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 137}], {
             RGBColor[
             0.42176168541881287`, 0.5397305063762635, 0.9480952595390402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 138}], {
             RGBColor[
             0.30745518829580587`, 0.4293776022897571, 0.9412271964953088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 149}], {
             RGBColor[
             0.3394057727607821, 0.4629596923465059, 0.9430467350139353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 164}], {
             RGBColor[
             0.42225479624494683`, 0.54015761418939, 0.9481266801248406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 197}], {
             RGBColor[
             0.44418462076302545`, 0.5589846984469196, 0.9495702898725955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 210}], {
             RGBColor[
             0.5365373649063981, 0.633932772365698, 0.9568598101775456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 217}], {
             RGBColor[
             0.31972909646579206`, 0.4422782579871379, 0.9419261774079696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 230}], {
             RGBColor[
             0.3693608911340902, 0.4943435721073369, 0.9447563272634205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 254}], {
             RGBColor[
             0.33424785620987973`, 0.4575383950207098, 0.9427529992968151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 258}], {
             RGBColor[
             0.34408717595377153`, 0.46788014392044364`, 0.9433133340002606]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 314}], {
             RGBColor[
             0.356181797390301, 0.48059235789352595`, 0.944002104798682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 328}], {
             RGBColor[
             0.39695831804363246`, 0.5182470762093745, 0.9465148109026502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 7}], {
             RGBColor[
             0.5860780361979605, 0.6746704086782876, 0.9606757532838862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 13}], {
             RGBColor[
             0.4102837773362856, 0.5274024875306194, 0.947875438987146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 14}], {
             RGBColor[
             0.42953326338711484`, 0.5446922123077761, 0.9490794156060693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 21}], {
             RGBColor[
             0.37748415065434726`, 0.49292800027145756`, 0.9460075487703089]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 51}], {
             RGBColor[
             0.534313538658442, 0.6328188270903583, 0.9564822654996268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 79}], {
             RGBColor[
             0.4080098083220292, 0.525012401918673, 0.9477459398158197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 188}], {
             RGBColor[
             0.5199222566807102, 0.6211353360609708, 0.9553493310653368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 232}], {
             RGBColor[
             0.43123078895455613`, 0.5461625236341779, 0.9491875804341636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 293}], {
             RGBColor[
             0.3780735066690404, 0.4935474508102296, 0.9460411117234715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 373}], {
             RGBColor[
             0.4140795332537155, 0.5313069679932865, 0.9480947175871661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 390}], {
             RGBColor[
             0.626657339691944, 0.7063712689819168, 0.964720319021015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 84}], {
             RGBColor[
             0.6144828468500472, 0.6872009851882155, 0.9590317863630586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 125}], {
             RGBColor[
             0.310230869645888, 0.44086850150596313`, 0.9410713502629637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 165}], {
             RGBColor[
             0.3158249115706085, 0.44571377945643376`, 0.94142779766779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 184}], {
             RGBColor[
             0.25442932131147, 0.3847517268220173, 0.9378007455030134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 185}], {
             RGBColor[
             0.3778320842720263, 0.49893145094814306`, 0.9455141799694428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 190}], {
             RGBColor[
             0.30660330036976663`, 0.4377264833259201, 0.9408402047564229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.46052042429091167`, 0.5660615704427415, 0.9520237089930993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 252}], {
             RGBColor[
             0.2994697464461666, 0.43154775746014307`, 0.9403856610083652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 274}], {
             RGBColor[
             0.36018479530391384`, 0.48413608115363815`, 0.9442543702333712]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 288}], {
             RGBColor[
             0.3281997588683336, 0.4564322502078132, 0.9422163119949531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 318}], {
             RGBColor[
             0.40081685821758906`, 0.5175915258894173, 0.9473236255704387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.43901521765130813`, 0.5546746488083063, 0.9491946393561952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 113}], {
             RGBColor[
             0.6573693634908911, 0.7290024352647109, 0.9686963833664817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 162}], {
             RGBColor[
             0.4176731562326734, 0.5361892278906815, 0.9478347420746438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 183}], {
             RGBColor[
             0.3975086345830182, 0.518723732736077, 0.946549876585914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 270}], {
             RGBColor[
             0.327127565355244, 0.4496716962147155, 0.9423615262426334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 291}], {
             RGBColor[
             0.6862955017633641, 0.7519676478011552, 0.9679985512963789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 357}], {
             RGBColor[
             0.33375866413599087`, 0.45664140146922627`, 0.9427391575083653]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 368}], {
             RGBColor[
             0.3677253321245943, 0.4923425231363857, 0.9446735090011341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 10}], {
             RGBColor[
             0.513756545074144, 0.5948687890880178, 0.9592908705275116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.5837433125746825, 0.6666740836298184, 0.9633407811710935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 69}], {
             RGBColor[
             0.5744086035541994, 0.6585888278523933, 0.9627459817666673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 71}], {
             RGBColor[
             0.5600402475890842, 0.6435158949874512, 0.9619266589151355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 93}], {
             RGBColor[
             0.5108748742710479, 0.5918399703654821, 0.9591267636383252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 129}], {
             RGBColor[
             0.6124203912374722, 0.6915127278156441, 0.9651680592653413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 131}], {
             RGBColor[
             0.5915548623948053, 0.6734400554640989, 0.9638385262181492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 142}], {
             RGBColor[
             0.8716131209686426, 0.9004646596252406, 0.9876164316478495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 201}], {
             RGBColor[
             0.5618219609779642, 0.6453885887263178, 0.9620281248568234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 253}], {
             RGBColor[
             0.5699667947853777, 0.6539493254701992, 0.9624919610929539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 273}], {
             RGBColor[
             0.562370052329388, 0.6459646674876629, 0.9620593378484585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 281}], {
             RGBColor[
             0.6728894012121025, 0.742456892734154, 0.9694164951137338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 303}], {
             RGBColor[
             0.6958064980189004, 0.7610620243253585, 0.9712206129224566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 364}], {
             RGBColor[
             0.5117120779119323, 0.5927199244738283, 0.9591744411471417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 391}], {
             RGBColor[
             0.6440824603578597, 0.7189368207058582, 0.967185538312024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 394}], {
             RGBColor[
             0.5330503579725812, 0.6151478097426673, 0.9603896246294392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 13}], {
             RGBColor[
             0.4778691730139394, 0.5820981869504258, 0.9533144058266989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 14}], {
             RGBColor[
             0.4971186590647686, 0.5993879117275827, 0.9545183824456223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 21}], {
             RGBColor[
             0.445069546332001, 0.5476236996912641, 0.9514465156098618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 93}], {
             RGBColor[
             0.4178284669618036, 0.5189915980889971, 0.9498951764392946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 142}], {
             RGBColor[
             0.7785667136593983, 0.8276162873487556, 0.9783848444488189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 188}], {
             RGBColor[
             0.587507652358364, 0.6758310354807773, 0.9607882979048897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 273}], {
             RGBColor[
             0.4693236450201436, 0.5731162952111779, 0.9528277506494279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 293}], {
             RGBColor[
             0.44565890234669414`, 0.5482431502300362, 0.9514800785630244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 390}], {
             RGBColor[
             0.6942427353695978, 0.7610669684017235, 0.9701592858605679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 16}], {
             RGBColor[
             0.388632868626246, 0.5097802323765035, 0.9461751028865708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 25}], {
             RGBColor[
             0.43827781890278816`, 0.5500842394905237, 0.9500833352277852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 76}], {
             RGBColor[
             0.3204849514925358, 0.4513580619646257, 0.9416658548946424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 117}], {
             RGBColor[
             0.3248180206782759, 0.4551111487069241, 0.941941954231575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 202}], {
             RGBColor[
             0.26306147491028553`, 0.3938246675645217, 0.9382923338803391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 234}], {
             RGBColor[
             0.4830375222615084, 0.5860848960364049, 0.9538375880293517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 239}], {
             RGBColor[
             0.3556182275275035, 0.4817887398163168, 0.9439045161764543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 269}], {
             RGBColor[
             0.24352257547692074`, 0.37328804542227934`, 0.9371796224628204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 302}], {
             RGBColor[
             0.4010524801336296, 0.51986303249532, 0.9471528201989681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 323}], {
             RGBColor[
             0.2818970875553924, 0.41362209070134714`, 0.9393649941556861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 365}], {
             RGBColor[
             0.6258942861471835, 0.6983661712238182, 0.9549302996950917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 377}], {
             RGBColor[
             0.3382993217582222, 0.46678797411247946`, 0.9428009708153428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 388}], {
             RGBColor[
             0.37456131252712876`, 0.49819628793585646`, 0.945111552801918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 18}], {
             RGBColor[
             0.3779353011987058, 0.5017702951429263, 0.9453026810906848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 56}], {
             RGBColor[
             0.38000995070429067`, 0.5035672522697479, 0.9454348759226401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 65}], {
             RGBColor[
             0.3135096103428719, 0.4455453036609195, 0.9412130100169722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 100}], {
             RGBColor[
             0.3331962391641343, 0.46301956825922075`, 0.942451947619041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 174}], {
             RGBColor[
             0.3472511498294629, 0.4751932254571783, 0.9433475140983663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 198}], {
             RGBColor[
             0.37954060404228307`, 0.5031607277811659, 0.945404969568364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 203}], {
             RGBColor[
             0.34195367817546385`, 0.4706048217691514, 0.9430099638889438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 266}], {
             RGBColor[
             0.3169125842386561, 0.4489154848030653, 0.9414143675262603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 313}], {
             RGBColor[
             0.3527279327589628, 0.47993693955959715`, 0.943696489863705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 339}], {
             RGBColor[
             0.30325277142100315`, 0.43476471563288704`, 0.9406288982140053]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 358}], {
             RGBColor[
             0.3601754207746066, 0.4863875793571163, 0.9441710372145068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 384}], {
             RGBColor[
             0.27647720267311526`, 0.40662189520974557`, 0.9391040691847173]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 32}], {
             RGBColor[
             0.24567564942948578`, 0.37555106265919835`, 0.9373022368392314]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 52}], {
             RGBColor[
             0.2167924708772871, 0.34519301070154657`, 0.9356573825495174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 60}], {
             RGBColor[
             0.2762650462875366, 0.40252235626441735`, 0.9392339266459053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 68}], {
             RGBColor[
             0.2956469171837868, 0.419309958673593, 0.940468922320699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.2864206898175132, 0.4113186642525976, 0.9398810352713525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 253}], {
             RGBColor[
             0.24396709336541883`, 0.3737552619071528, 0.937204937098965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 271}], {
             RGBColor[
             0.27562529933836194`, 0.40196823961165884`, 0.93919316253601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 303}], {
             RGBColor[
             0.36980679659894145`, 0.48086796076231214`, 0.9459335889284679]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 333}], {
             RGBColor[
             0.2695542725565937, 0.3967098213519695, 0.938806322077874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 334}], {
             RGBColor[
             0.2887184375064456, 0.413308857812594, 0.9400274457222728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 337}], {
             RGBColor[
             0.27254313100972855`, 0.3992986203196811, 0.9389967694955639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 345}], {
             RGBColor[
             0.2047951494777156, 0.3325830652364857, 0.9349741528442581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 353}], {
             RGBColor[
             0.2181240555371064, 0.34659259060636033`, 0.9357332143259911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 364}], {
             RGBColor[
             0.18571237649197336`, 0.3125258609107818, 0.9338874171531529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 391}], {
             RGBColor[
             0.3180827589379007, 0.43874275714281175`, 0.9418985143180352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 54}], {
             RGBColor[
             0.49908223587812583`, 0.5892231717767965, 0.9569242961001614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 83}], {
             RGBColor[
             0.5046857548077889, 0.5951128254554927, 0.9572434082135424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 118}], {
             RGBColor[
             0.48350757972089753`, 0.5728532206653145, 0.9560373424726463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 123}], {
             RGBColor[
             0.5514107929485214, 0.6416375835533825, 0.9599990241779339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 141}], {
             RGBColor[
             0.5946580650679343, 0.6790961969921189, 0.9627547021153218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 161}], {
             RGBColor[
             0.5496248477768602, 0.6400906876099038, 0.959885225330845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 196}], {
             RGBColor[
             0.63448023103739, 0.7122430540069045, 0.9656637909050025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 206}], {
             RGBColor[
             0.5608402253319478, 0.6498048839468545, 0.9605998592712861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 214}], {
             RGBColor[
             0.5598408789487807, 0.6489393003383648, 0.9605361818034381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 286}], {
             RGBColor[
             0.562490188546078, 0.6512339991533717, 0.9607049934682854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 332}], {
             RGBColor[
             0.531797367714194, 0.623608849595666, 0.9587873744605251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 366}], {
             RGBColor[
             0.7086197974446211, 0.7722984385644506, 0.9715922570469223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 386}], {
             RGBColor[
             0.5648928177309122, 0.6533150357936209, 0.9608580868753814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 19}], {
             RGBColor[
             0.278988748050934, 0.4050056280625448, 0.9394029332051645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 24}], {
             RGBColor[
             0.2352529687298595, 0.36459616440776677`, 0.9367086805923621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 65}], {
             RGBColor[
             0.24663684150953938`, 0.3765613364784325, 0.9373569753062343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 100}], {
             RGBColor[
             0.26632347033080184`, 0.39403560107673374`, 0.938595912908303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 107}], {
             RGBColor[
             0.36534895886266183`, 0.4774094818997658, 0.9455680332897194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 124}], {
             RGBColor[
             0.3715472307599351, 0.48244151825493914`, 0.9460559839584909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 150}], {
             RGBColor[
             0.30608436622863117`, 0.42847449066269844`, 0.941129442035733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 157}], {
             RGBColor[
             0.31673593150213786`, 0.4377003411393729, 0.9418081503561515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 167}], {
             RGBColor[
             0.29941732032931945`, 0.42269983060018484`, 0.940704623766466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 168}], {
             RGBColor[
             0.26745953047271886`, 0.3950195992716193, 0.9386683016559674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 203}], {
             RGBColor[
             0.2750809093421313, 0.40162085458666436`, 0.9391539291782056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 206}], {
             RGBColor[
             0.2723382769198726, 0.39924532423121756`, 0.938979171065474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 211}], {
             RGBColor[
             0.4129170306386236, 0.5160273854847046, 0.9493127661475115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 238}], {
             RGBColor[
             0.30672978850451715`, 0.4290335229982041, 0.9411705677724279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 341}], {
             RGBColor[
             0.30687118614199876`, 0.42915599452493874`, 0.9411795775048553]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 358}], {
             RGBColor[
             0.2933026519412741, 0.41740361217462923`, 0.9403150025037688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 14}], {
             RGBColor[
             0.3213244002030937, 0.4521199905799143, 0.9417180681488819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 21}], {
             RGBColor[
             0.26927528747032614`, 0.4003557785435958, 0.9386462013131216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 51}], {
             RGBColor[
             0.4261046754744209, 0.5402466053624965, 0.9491209180424394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 79}], {
             RGBColor[
             0.29980094513800803`, 0.4324401801908112, 0.9403845923586324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 87}], {
             RGBColor[
             0.3050312206601903, 0.4379375313832462, 0.9406824488121214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 205}], {
             RGBColor[
             0.25763488504734433`, 0.38812097755290087`, 0.9379832976155649]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 232}], {
             RGBColor[
             0.32302192577053496`, 0.4535903019063161, 0.9418262329769763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 277}], {
             RGBColor[
             0.2660921383474147, 0.39701008699210466`, 0.9384649256796189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 373}], {
             RGBColor[
             0.3058706700696944, 0.43873474626542464`, 0.9407333701299787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 390}], {
             RGBColor[
             0.5184484765079229, 0.6137990472540551, 0.9573589715638275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 69}], {
             RGBColor[
             0.32481742343410946`, 0.4557622592053967, 0.9419180568898198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 71}], {
             RGBColor[
             0.31044906746899414`, 0.44068932634045466`, 0.9410987340382879]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 201}], {
             RGBColor[
             0.31223078085787426`, 0.44256202007932116`, 0.941200199979976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 212}], {
             RGBColor[
             0.2784564154111087, 0.4070630205763188, 0.9392767998324787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 273}], {
             RGBColor[
             0.31277887220929795`, 0.4431380988406663, 0.9412314129716111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 289}], {
             RGBColor[
             0.32799532927306996`, 0.45851480151691265`, 0.9421205502397665]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 293}], {
             RGBColor[
             0.2891141295358485, 0.4182649538595246, 0.9398837408852075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 390}], {
             RGBColor[
             0.5376979625587521, 0.6310887720312119, 0.9585629481827509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 35}], {
             RGBColor[
             0.46520578611072394`, 0.5767140403033469, 0.9510418500690315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 106}], {
             RGBColor[
             0.39040027289400747`, 0.5124118599217647, 0.9461397559627304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 154}], {
             RGBColor[
             0.33246086225866095`, 0.4527185064581788, 0.9427960844441692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 207}], {
             RGBColor[
             0.3845051115761162, 0.5073057674876305, 0.9457641214964408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 231}], {
             RGBColor[
             0.4584053302220289, 0.5711931238558579, 0.9505064932705827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 369}], {
             RGBColor[
             0.38249859001678244`, 0.5053113309071435, 0.9456456590158095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 372}], {
             RGBColor[
             0.32047653855288943`, 0.44012222239340315`, 0.9421135949383436]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 392}], {
             RGBColor[
             0.5608470382962906, 0.6540487978923428, 0.9587837939046493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 25}], {
             RGBColor[
             0.5252126014938163, 0.6254302763075681, 0.955765806388196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 37}], {
             RGBColor[
             0.444310385742042, 0.5586569270701789, 0.9496989657576089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 76}], {
             RGBColor[
             0.407419734083564, 0.5267040987816702, 0.9473483260550531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 77}], {
             RGBColor[
             0.4346960985679835, 0.5503295147481333, 0.9490863518804583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 78}], {
             RGBColor[
             0.43825291700482405`, 0.5534102521072319, 0.9493129892060828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 80}], {
             RGBColor[
             0.35322035277865305`, 0.4725594329374971, 0.9441584124971729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 96}], {
             RGBColor[
             0.5682591761750747, 0.660092623710356, 0.9593493105332908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 182}], {
             RGBColor[
             0.4459381069989692, 0.56006677741128, 0.9498026827167629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.35530783404913385`, 0.4747535081067294, 0.9442772914673749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 269}], {
             RGBColor[
             0.33045735806794896`, 0.4486340822393239, 0.9428620936232313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 302}], {
             RGBColor[
             0.48798726272465776`, 0.5952090693123644, 0.9528352913593789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 323}], {
             RGBColor[
             0.3688318701464206, 0.4889681275183916, 0.945047465316097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 365}], {
             RGBColor[
             0.7128290687382116, 0.7737122080408627, 0.9606127708555026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 377}], {
             RGBColor[
             0.42523410434925035`, 0.542134010929524, 0.9484834419757535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 388}], {
             RGBColor[
             0.461496095118157, 0.573542324752901, 0.9507940239623289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 18}], {
             RGBColor[
             0.33375866413599087`, 0.45664140146922627`, 0.9427391575083653]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 31}], {
             RGBColor[
             0.3331654956688167, 0.45612762875647406`, 0.9427013613381552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 62}], {
             RGBColor[
             0.26553793532628944`, 0.39642758447840104`, 0.9384333646374357]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.3209006062036637, 0.4455043979530272, 0.9419198534268516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 111}], {
             RGBColor[
             0.27239601356474497`, 0.40349215772090724`, 0.9388291836748268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 222}], {
             RGBColor[
             0.24314247645569295`, 0.372888537251299, 0.9371579763858675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 223}], {
             RGBColor[
             0.25872036171431356`, 0.3892618823530813, 0.93804511390593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 247}], {
             RGBColor[
             0.3667841647525505, 0.4840039779847811, 0.9451868064514695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 256}], {
             RGBColor[
             0.3119049026019044, 0.4377127716303928, 0.9413466551479359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 292}], {
             RGBColor[
             0.24931794369162338`, 0.37937934486349945`, 0.9375096601091687]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 310}], {
             RGBColor[
             0.24051345956242046`, 0.3701252738071711, 0.9370082577630776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 319}], {
             RGBColor[
             0.4182810118294027, 0.5258114383482931, 0.9492408268925256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 384}], {
             RGBColor[
             0.23230056561040036`, 0.3614930015360456, 0.9365405456023979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 99}], {
             RGBColor[
             0.42016750166141875`, 0.5383497045316141, 0.9479936795597004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 144}], {
             RGBColor[
             0.44743903265357965`, 0.5617392021305316, 0.9497954255969492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.4346308624373232, 0.5508771406860529, 0.9489152721188931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 218}], {
             RGBColor[
             0.4025696222353705, 0.5231073058679089, 0.9468723582438663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 266}], {
             RGBColor[
             0.3720028426336962, 0.49663189770795224`, 0.9449246700767895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 310}], {
             RGBColor[
             0.3397803550201755, 0.462970580385758, 0.9430820838959263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 319}], {
             RGBColor[
             0.5175479072871578, 0.61865674492688, 0.9553146530253743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 384}], {
             RGBColor[
             0.3315674610681554, 0.4543383081146325, 0.9426143717352466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 24}], {
             RGBColor[
             0.325142211643793, 0.4535158445972463, 0.9420313046788471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 85}], {
             RGBColor[
             0.3946907436044512, 0.516283017201761, 0.9463703230645228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 107}], {
             RGBColor[
             0.45523820177659524`, 0.5663291620892453, 0.9508906573762045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 124}], {
             RGBColor[
             0.46143647367386853`, 0.5713611984444187, 0.951378608044976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 150}], {
             RGBColor[
             0.39597360914256463`, 0.517394170852178, 0.946452066122218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 152}], {
             RGBColor[
             0.3125665306304194, 0.440298006507962, 0.9413151382491884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 157}], {
             RGBColor[
             0.40662517441607127`, 0.5266200213288524, 0.9471307744426365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 160}], {
             RGBColor[
             0.6264431435713089, 0.7021367720654699, 0.9667621259081236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 167}], {
             RGBColor[
             0.38930656324325286`, 0.5116195107896644, 0.9460272478529511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 168}], {
             RGBColor[
             0.3573487733866523, 0.4839392794610988, 0.9439909257424525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 181}], {
             RGBColor[
             0.3731131083049715, 0.49759355402883576`, 0.9449954152235938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 211}], {
             RGBColor[
             0.502806273552557, 0.6049470656741841, 0.9546353902339966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 238}], {
             RGBColor[
             0.39661903141845056`, 0.5179532031876837, 0.946493191858913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 64}], {
             RGBColor[
             0.3117386477345114, 0.440864122404735, 0.9412154025413284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 88}], {
             RGBColor[
             0.33821672273854664`, 0.46379810014648515`, 0.9429025620669431]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 89}], {
             RGBColor[
             0.27577013272146317`, 0.407182272699514, 0.9390160731419113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 120}], {
             RGBColor[
             0.3527773052814015, 0.4764097449089483, 0.9438303495111562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 140}], {
             RGBColor[
             0.30646306464201434`, 0.4362946774885301, 0.9408792470516895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 189}], {
             RGBColor[
             0.24208672072774712`, 0.3717788710424486, 0.9370978526590117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 195}], {
             RGBColor[
             0.4174666164133256, 0.5294133934590375, 0.948788659186246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 241}], {
             RGBColor[
             0.3019209957665844, 0.4323605657196522, 0.9405898304393409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 255}], {
             RGBColor[
             0.3363434116586714, 0.46217553224444974`, 0.9427831963414375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 257}], {
             RGBColor[
             0.23507743335279563`, 0.36441166559688687`, 0.9366986841123197]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 263}], {
             RGBColor[
             0.33865077966285895`, 0.4641740584379891, 0.9429302197903389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 312}], {
             RGBColor[
             0.22684420294319674`, 0.3557580184194402, 0.9362298138204659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 336}], {
             RGBColor[
             0.22633172809052557`, 0.35521937485650046`, 0.9362006291357449]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 356}], {
             RGBColor[
             0.3459710008225968, 0.4705144660815406, 0.94339665780962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 359}], {
             RGBColor[
             0.30664293266644405`, 0.43645047013086136`, 0.940890708083155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 360}], {
             RGBColor[
             0.3099366970930974, 0.43930336332781483`, 0.9411005838398598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 389}], {
             RGBColor[
             0.22924346647753355`, 0.3582797965161224, 0.936366448329354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 109}], {
             RGBColor[
             0.2840530446206092, 0.41377231650272905`, 0.9395652433206967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[
             0.2550913227765558, 0.38544753233513956`, 0.9378384455071067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 132}], {
             RGBColor[
             0.29269614042507625`, 0.4212585316739321, 0.9401159737425677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 180}], {
             RGBColor[
             0.35391676844543185`, 0.4737949376957905, 0.9441522381126575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 232}], {
             RGBColor[
             0.29022229908859665`, 0.4191158146471544, 0.9399583427601392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 249}], {
             RGBColor[
             0.33314023877164134`, 0.4562891768822382, 0.9426930359258989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 370}], {
             RGBColor[
             0.3288630351187276, 0.4525844780565907, 0.9424204962913181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 45}], {
             RGBColor[
             0.49474926343947345`, 0.5992361670133488, 0.9537717413159159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 74}], {
             RGBColor[
             0.3460180057482646, 0.47263088893122507`, 0.9433236510273395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 116}], {
             RGBColor[
             0.3349076111940805, 0.46095315981507634`, 0.9426909304938345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 141}], {
             RGBColor[
             0.41133216311526205`, 0.5306969783599607, 0.9474306996003223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 179}], {
             RGBColor[
             0.2954657900547196, 0.419497305041711, 0.9404447771288933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 209}], {
             RGBColor[
             0.4941353624204731, 0.5987377745101985, 0.9537234127789067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 286}], {
             RGBColor[
             0.37916428659340584`, 0.5028347805212134, 0.945380990953286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 290}], {
             RGBColor[
             0.500477884111856, 0.6038869193466092, 0.9542227193198749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 304}], {
             RGBColor[
             0.28918929902790336`, 0.41290031502001134`, 0.9400873402501525]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 338}], {
             RGBColor[
             0.41399801851110696`, 0.5330060083140533, 0.9476005655488222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 38}], {
             RGBColor[
             0.5460081225272146, 0.6411486989598316, 0.9578810946116616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 92}], {
             RGBColor[
             0.48480595667372467`, 0.5875312859245407, 0.9540035783033178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 98}], {
             RGBColor[
             0.48280772725911647`, 0.585431020114725, 0.9538897820942714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 119}], {
             RGBColor[
             0.42772172353025556`, 0.5275321375413297, 0.9507527156743524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 128}], {
             RGBColor[
             0.5481656079952479, 0.6430174044338696, 0.9580185676778952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 130}], {
             RGBColor[
             0.463906715834024, 0.5655648587136125, 0.952813397455153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 139}], {
             RGBColor[
             0.7073946017769706, 0.7713413063970499, 0.9714701409928754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 143}], {
             RGBColor[
             0.6846272707790585, 0.7535552943833566, 0.9692009062118083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 146}], {
             RGBColor[
             0.6697086133125885, 0.741900725784554, 0.967713953858331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 151}], {
             RGBColor[
             0.5685080201408668, 0.660195345726601, 0.9594367928901637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 158}], {
             RGBColor[
             0.5545128109605953, 0.6485150326227564, 0.9584230058382359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 186}], {
             RGBColor[
             0.5275098886910923, 0.6251264585592488, 0.9567024035089698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 213}], {
             RGBColor[
             0.42759492751754546`, 0.5273988668926398, 0.9507454948290064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 267}], {
             RGBColor[
             0.6144194941365041, 0.697468348604593, 0.963051112302371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 306}], {
             RGBColor[
             0.5330557973688944, 0.629930045910486, 0.9570557839058649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 308}], {
             RGBColor[
             0.4616509575517287, 0.5631939137355845, 0.9526849353580716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 311}], {
             RGBColor[
             0.43594394135082615`, 0.5361742097894691, 0.9512209588155527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 346}], {
             RGBColor[
             0.7119534167137482, 0.7749026872739374, 0.9719245210612256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 348}], {
             RGBColor[
             0.4671481100698239, 0.5689717695717028, 0.9529979900616687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 354}], {
             RGBColor[
             0.5040562812210712, 0.6048121225813033, 0.9552079603801908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 374}], {
             RGBColor[
             0.5692494698880491, 0.6607972880332942, 0.9594951625302818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 33}], {
             RGBColor[
             0.36578867316485175`, 0.48872176661623, 0.9446212612647142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 56}], {
             RGBColor[
             0.35929064546381706`, 0.4830935016219623, 0.9442072126855847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 65}], {
             RGBColor[
             0.29279030510239834`, 0.42507155301313404`, 0.9399853467799169]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 100}], {
             RGBColor[
             0.3124769339236607, 0.4425458176114353, 0.9412242843819856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 107}], {
             RGBColor[
             0.41150242245552077`, 0.5259196984344673, 0.9481964047634021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 124}], {
             RGBColor[
             0.41770069435279406`, 0.5309517347896406, 0.9486843554321736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 150}], {
             RGBColor[
             0.3522378298214901, 0.47698470719739994`, 0.9437578135094156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 157}], {
             RGBColor[
             0.36288939509499674`, 0.4862105576740744, 0.9444365218298341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 167}], {
             RGBColor[
             0.3455707839221784, 0.47121004713488635`, 0.9433329952401487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 168}], {
             RGBColor[
             0.31361299406557774`, 0.4435298158063208, 0.94129667312965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 203}], {
             RGBColor[
             0.32123437293499024`, 0.45013107112136586`, 0.9417823006518883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 206}], {
             RGBColor[
             0.31849174051273155`, 0.44775554076591906`, 0.9416075425391566]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 211}], {
             RGBColor[
             0.45907049423148255`, 0.5645376020194061, 0.9519411376211941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 238}], {
             RGBColor[
             0.3528832520973761, 0.47754373953290563`, 0.9437989392461106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 341}], {
             RGBColor[
             0.3530246497348577, 0.47766621105964024`, 0.9438079489785378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 358}], {
             RGBColor[
             0.339456115534133, 0.46591382870933074`, 0.9429433739774513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 386}], {
             RGBColor[
             0.3225443329116959, 0.45126569261268545`, 0.9418657701432518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 37}], {
             RGBColor[
             0.49395533601858416`, 0.598960934184199, 0.9536071980988233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 62}], {
             RGBColor[
             0.4357208268723508, 0.5473966787438754, 0.9499377183143825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[
             0.45706468436010617`, 0.5670081058956904, 0.9512565583962675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 78}], {
             RGBColor[
             0.4878978672813662, 0.5937142592212521, 0.953221221547297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 91}], {
             RGBColor[
             0.5661378636246894, 0.6586552477674597, 0.9589875929373132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 117}], {
             RGBColor[
             0.4613977535458462, 0.5707611926379887, 0.9515326577332002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 182}], {
             RGBColor[
             0.49558305727551133`, 0.6003707845253001, 0.9537109150579773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 187}], {
             RGBColor[
             0.404952784325676, 0.5150575152207495, 0.9481855238085893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 208}], {
             RGBColor[
             0.46282800101567656`, 0.5720000011100278, 0.9516237918372596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 239}], {
             RGBColor[
             0.4921979603950738, 0.5974387837473815, 0.9534952196780795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 269}], {
             RGBColor[
             0.3801023083444911, 0.48893808935334404`, 0.9467703259644455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 309}], {
             RGBColor[
             0.4356842266182394, 0.5473582095562142, 0.9499356339840561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 323}], {
             RGBColor[
             0.41847682042296275`, 0.5292721346324117, 0.9489556976573112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 362}], {
             RGBColor[
             0.42398414661411554`, 0.5350606836439619, 0.9492693317365385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 365}], {
             RGBColor[
             0.7624740190147538, 0.8140162151548829, 0.9645210031967169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 377}], {
             RGBColor[
             0.4748790546257925, 0.5824380180435441, 0.9523916743169679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 388}], {
             RGBColor[
             0.5111410453946992, 0.6138463318669212, 0.9547022563035432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 395}], {
             RGBColor[
             0.4545722435448817, 0.5648492789352608, 0.9510977422715003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 70}], {
             RGBColor[
             0.7542733442764391, 0.8056343521645595, 0.9086702241522255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 177}], {
             RGBColor[
             0.38013505316052165`, 0.4953722764573791, 0.9461896438419728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 285}], {
             RGBColor[
             0.3900887761458573, 0.5058342704174549, 0.9467564936407742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 324}], {
             RGBColor[
             0.42285465522020016`, 0.5388299027291469, 0.9486753113427573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 40}], {
             RGBColor[
             0.38444523886173065`, 0.5062007664872575, 0.9458618001499925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 41}], {
             RGBColor[
             0.44577014320350095`, 0.5601078965680646, 0.9497404218125858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 48}], {
             RGBColor[
             0.3285241905930357, 0.4474241991576149, 0.9426771791788676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 63}], {
             RGBColor[
             0.4943688646950437, 0.6003899412798163, 0.9533376744430659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 86}], {
             RGBColor[
             0.40476711223811246`, 0.524593132018104, 0.9471277449370278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 250}], {
             RGBColor[
             0.44408854749289284`, 0.5586513828829938, 0.9496332720208824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 265}], {
             RGBColor[
             0.3831763074148249, 0.504867039081659, 0.9457895363813071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 295}], {
             RGBColor[
             0.43575232339013514`, 0.5514309645559912, 0.9491020951924882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 325}], {
             RGBColor[
             0.3738678249541858, 0.4950832338236514, 0.9452594320758394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 376}], {
             RGBColor[
             0.34147624583089997`, 0.46103763042034296`, 0.9434147795638154]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 39}], {
             RGBColor[
             0.3266563647458157, 0.4558631689586702, 0.9420898579606349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 50}], {
             RGBColor[
             0.3786545552803292, 0.5023932768776671, 0.9453485113247544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 106}], {
             RGBColor[
             0.3412390050618873, 0.4699858078386865, 0.9429644255501073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 197}], {
             RGBColor[
             0.4100935069946484, 0.5294566891699506, 0.9473980342488628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 217}], {
             RGBColor[
             0.28563798269741497`, 0.41275024871016897`, 0.9397539217842368]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 231}], {
             RGBColor[
             0.4092440623899087, 0.5287670717727795, 0.9473311628579596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 254}], {
             RGBColor[
             0.30015674244150264`, 0.42801038574374084`, 0.9405807436730824]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 314}], {
             RGBColor[
             0.32209068362192395`, 0.45106434861655703`, 0.9418298491749493]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 369}], {
             RGBColor[
             0.3333373221846622, 0.4628852788240653, 0.9424703286031864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 113}], {
             RGBColor[
             0.6633590215484534, 0.734190376025204, 0.9690780390814628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 162}], {
             RGBColor[
             0.42366281429023567`, 0.5413771686511745, 0.948216397789625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 183}], {
             RGBColor[
             0.40349829264058046`, 0.52391167349657, 0.9469315323008952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 270}], {
             RGBColor[
             0.33311722341280625`, 0.4548596369752085, 0.9427431819576145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 357}], {
             RGBColor[
             0.3397483221935531, 0.4618293422297194, 0.9431208132233465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 153}], {
             RGBColor[
             0.4904487500906186, 0.5948479777508542, 0.9536809883815976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 168}], {
             RGBColor[
             0.48014767096609356`, 0.5859257007604816, 0.9530246127286695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 175}], {
             RGBColor[
             0.47669920516555353`, 0.5829388130089845, 0.9528048795372177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 211}], {
             RGBColor[
             0.6256051711319983, 0.7069334869735668, 0.9636690772202136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 216}], {
             RGBColor[
             0.4086303400502883, 0.5141841550491404, 0.9488263015157363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 229}], {
             RGBColor[
             0.41697028976080086`, 0.5229499709782418, 0.9493012493139001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 294}], {
             RGBColor[
             0.4463853368997126, 0.5538670505429453, 0.9509763927327985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 329}], {
             RGBColor[
             0.4174752301837634, 0.5234806953778474, 0.9493300049239954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 341}], {
             RGBColor[
             0.5195593266353735, 0.620062096013801, 0.9555358885775573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 343}], {
             RGBColor[
             0.41462741949187853`, 0.5204874657790498, 0.949167826318051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 358}], {
             RGBColor[
             0.5059907924346487, 0.6083097136634915, 0.9546713135764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 379}], {
             RGBColor[
             0.4683011718230925, 0.5756648586251737, 0.9522697642787255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 99}], {
             RGBColor[
             0.4195743331942446, 0.5378359318188619, 0.9479558833894902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 111}], {
             RGBColor[
             0.3710697405553258, 0.4958236915867419, 0.9448652136374655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 169}], {
             RGBColor[
             0.6720293250868572, 0.7406510944291208, 0.9701134443583237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 199}], {
             RGBColor[
             0.30962981722301053`, 0.4313901384617302, 0.9413610392685827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 215}], {
             RGBColor[
             0.47227288213398055`, 0.5818682280617256, 0.951759337421808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 222}], {
             RGBColor[
             0.34181620344627384`, 0.4652200711171337, 0.9431940063485061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 223}], {
             RGBColor[
             0.3573940887048945, 0.48159341621891594`, 0.9440811438685686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 224}], {
             RGBColor[
             0.5996915244178138, 0.6833947501355485, 0.9631013224276636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 247}], {
             RGBColor[
             0.4654578917431314, 0.5763355118506158, 0.951222836414108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 259}], {
             RGBColor[
             0.40260661402702547`, 0.5231393462985789, 0.94687471532812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 292}], {
             RGBColor[
             0.34799167068220427`, 0.4717108787293341, 0.9435456900718073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 363}], {
             RGBColor[
             0.33699097523325183`, 0.4601484503281088, 0.94291921674006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 383}], {
             RGBColor[
             0.3782876225125379, 0.5020754581567834, 0.9453251306932566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 393}], {
             RGBColor[
             0.4830644160167817, 0.5906292814208448, 0.9526088864997533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 400}], {
             RGBColor[
             0.3534221195803685, 0.4774186248316513, 0.9438549461029285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 46}], {
             RGBColor[
             0.3026607923696853, 0.4354460609560913, 0.9405474564277115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 52}], {
             RGBColor[
             0.27471127665258777`, 0.4060693478357736, 0.938955772855226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 71}], {
             RGBColor[
             0.2919593519444259, 0.4241981685586318, 0.9399380252268554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 105}], {
             RGBColor[
             0.3226483994173917, 0.4534072641058675, 0.9417972881094465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 111}], {
             RGBColor[
             0.3069473568280202, 0.4398078101723002, 0.9407968315595386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 129}], {
             RGBColor[
             0.34433949559281385`, 0.47219500138682463`, 0.9431794255770612]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 199}], {
             RGBColor[
             0.24550743349570497`, 0.3753742570472885, 0.9372926571906559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 215}], {
             RGBColor[
             0.40815049840667494`, 0.525852346647284, 0.9476909553438811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 247}], {
             RGBColor[
             0.40133550801582585`, 0.5203196304361741, 0.9471544543361812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 259}], {
             RGBColor[
             0.33848423029971986`, 0.46712346488413725`, 0.9428063332501931]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 271}], {
             RGBColor[
             0.3335441051136626, 0.46284457674588586`, 0.9424915528417188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 287}], {
             RGBColor[
             0.3644414010492964, 0.4896062615420843, 0.9444603012173313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 292}], {
             RGBColor[
             0.28386928695489866`, 0.4156949973148924, 0.9394773079938805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 303}], {
             RGBColor[
             0.42772560237424206`, 0.5417442978965392, 0.9492319792341766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 333}], {
             RGBColor[
             0.3274730783318943, 0.45758615848619655`, 0.9421047123835826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 337}], {
             RGBColor[
             0.33046193678502916`, 0.46017495745390813`, 0.9422951598012727]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 345}], {
             RGBColor[
             0.2627139552530162, 0.3934594023707127, 0.9382725431499669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 353}], {
             RGBColor[
             0.276042861312407, 0.40746892774058735`, 0.9390316046316998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 385}], {
             RGBColor[
             0.533207334657169, 0.6255338078974715, 0.9587975375966657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 391}], {
             RGBColor[
             0.37600156471320134`, 0.49961909427703877`, 0.945196904623744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 400}], {
             RGBColor[
             0.28929973585306296`, 0.4214027434172096, 0.9397865640250017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 58}], {
             RGBColor[
             0.38953972076107657`, 0.5118214601127657, 0.9460421044438136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 74}], {
             RGBColor[
             0.3713776637238537, 0.4945961500562095, 0.944939546008879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 107}], {
             RGBColor[
             0.49588466329765407`, 0.601535084108229, 0.9534806139620717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 116}], {
             RGBColor[
             0.3602672691696697, 0.4829184209400609, 0.9443068254753739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 118}], {
             RGBColor[
             0.32554133574381455`, 0.4464192631581408, 0.9423292349391863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 124}], {
             RGBColor[
             0.5020829351949274, 0.6065671204634024, 0.9539685646308431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 141}], {
             RGBColor[
             0.43669182109085125`, 0.5526622394849452, 0.9490465945818618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 150}], {
             RGBColor[
             0.4366200706636234, 0.5526000928711616, 0.9490420227080852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 152}], {
             RGBColor[
             0.35321299215147817`, 0.4755039285269457, 0.9439050948350556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 156}], {
             RGBColor[
             0.3895356111524708, 0.5118179005763464, 0.9460418425831874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 157}], {
             RGBColor[
             0.44727163593713004`, 0.5618259433478361, 0.9497207310285037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 179}], {
             RGBColor[
             0.32082544803030877`, 0.4414625661666955, 0.9420606721104328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 206}], {
             RGBColor[
             0.40287398135486485`, 0.5233709264396809, 0.9468917517378261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 209}], {
             RGBColor[
             0.5194950203960623, 0.620703035635183, 0.9553393077604462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 245}], {
             RGBColor[
             0.3438603717279032, 0.465673731471384, 0.9433724769378949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 286}], {
             RGBColor[
             0.40452394456899504`, 0.524800041646198, 0.9469968859348254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 386}], {
             RGBColor[
             0.4069265737538292, 0.5268810782864473, 0.9471499793419215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 43}], {
             RGBColor[
             0.30158223450946264`, 0.4284018751934614, 0.9407024484544986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 159}], {
             RGBColor[
             0.24513014030875357`, 0.3749776979860329, 0.9372711709018142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 250}], {
             RGBColor[
             0.3249862890983468, 0.4486732909563661, 0.9421937341175094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 265}], {
             RGBColor[
             0.26407404902027887`, 0.3948889471550313, 0.938349998477934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 321}], {
             RGBColor[
             0.2463758335318303, 0.37628700054499864`, 0.9373421112880305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 375}], {
             RGBColor[
             0.24758278749477736`, 0.3775555856853572, 0.9374108455306919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 381}], {
             RGBColor[
             0.29545750476276245`, 0.4230969421247375, 0.9403121860909247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 73}], {
             RGBColor[
             0.4592918525299634, 0.5717466554745746, 0.950622201552789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 154}], {
             RGBColor[
             0.33864132553434895`, 0.45773608497207996`, 0.9432826331530142]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 207}], {
             RGBColor[
             0.3906855748518043, 0.5123233460015316, 0.946250670205286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 231}], {
             RGBColor[
             0.4645857934977169, 0.5762107023697589, 0.9509930419794279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 280}], {
             RGBColor[
             0.3965563352836747, 0.5174083036146189, 0.946624749868695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 291}], {
             RGBColor[
             0.7054758466596971, 0.7680901031858727, 0.9693562588647102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 372}], {
             RGBColor[
             0.3266570018285775, 0.4451398009073043, 0.9426001436471887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 387}], {
             RGBColor[
             0.46988217034504, 0.5805105396934738, 0.9514099921661168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 392}], {
             RGBColor[
             0.5670275015719786, 0.6590663764062441, 0.9592703426134945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 61}], {
             RGBColor[
             0.3571193217871302, 0.483659746607394, 0.9439792635319717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 70}], {
             RGBColor[
             0.6475334828145793, 0.7149481348117723, 0.9013614040743259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 90}], {
             RGBColor[
             0.583147820117444, 0.6654355671624435, 0.9636013142161808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 95}], {
             RGBColor[
             0.33036595931736457`, 0.46048732869917863`, 0.9422745629324678]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 148}], {
             RGBColor[
             0.3040247464970235, 0.4368796632236103, 0.9406251315974741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 228}], {
             RGBColor[
             0.27414037727342777`, 0.40546929639116525`, 0.9389232609801528]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 276}], {
             RGBColor[
             0.33110558695912007`, 0.46112795698770104`, 0.9423216913517733]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 282}], {
             RGBColor[
             0.2861618011681686, 0.41810457510683546`, 0.9396078632868553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 301}], {
             RGBColor[
             0.3596302968439382, 0.48583462699632524`, 0.9441392606422234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 305}], {
             RGBColor[
             0.27737098670375826`, 0.408864871734911, 0.9391072394079517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 361}], {
             RGBColor[
             0.4316733005689553, 0.5454608686771918, 0.9494961827910156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 382}], {
             RGBColor[
             0.2768559466177052, 0.40832353194904164`, 0.9390779086369845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 76}], {
             RGBColor[
             0.3761624686083318, 0.5002347566583012, 0.9451897177656805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 78}], {
             RGBColor[
             0.40699565152959194`, 0.5269409099838629, 0.94715438091671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 80}], {
             RGBColor[
             0.3219630873034208, 0.44609009081412804`, 0.9419998042078002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 96}], {
             RGBColor[
             0.5370019106998425, 0.633623281586987, 0.9571907022439181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 104}], {
             RGBColor[
             0.4290595493500651, 0.5460515493122077, 0.9485602729754918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 117}], {
             RGBColor[
             0.3804955377940719, 0.5039878434005995, 0.9454658171026131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 145}], {
             RGBColor[
             0.6623425399678051, 0.732281090134559, 0.9694869108382729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 182}], {
             RGBColor[
             0.41468084152373696`, 0.5335974352879109, 0.9476440744273903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 187}], {
             RGBColor[
             0.3240505685739017, 0.44828416598336035`, 0.9421186831780023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 208}], {
             RGBColor[
             0.38192578526390225`, 0.5052266518726386, 0.9455569512066726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 269}], {
             RGBColor[
             0.29920009259271674`, 0.42216474011595484`, 0.9407034853338585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 323}], {
             RGBColor[
             0.3375746046711884, 0.46249878539502254`, 0.9428888570267242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 365}], {
             RGBColor[
             0.6815718032629794, 0.7472428659174937, 0.9584541625661298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 377}], {
             RGBColor[
             0.3939768388740182, 0.5156646688061549, 0.9463248336863809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 388}], {
             RGBColor[
             0.4302388296429248, 0.547072982629532, 0.9486354156729562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 395}], {
             RGBColor[
             0.37367002779310743`, 0.4980759296978716, 0.9450309016409133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 44}], {
             RGBColor[
             0.5297891473849515, 0.6283655061578645, 0.9563416649266715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 66}], {
             RGBColor[
             0.584757342875322, 0.6714198844007553, 0.9617432547639087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 81}], {
             RGBColor[
             0.4016959045346063, 0.5223505355098355, 0.9468166857245718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 119}], {
             RGBColor[
             0.3062968346765644, 0.428557828240853, 0.9411466671615238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 128}], {
             RGBColor[
             0.4267407191415568, 0.544043095133393, 0.9484125191650667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 130}], {
             RGBColor[
             0.3424818269803328, 0.4665905494131359, 0.9432073489423245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 135}], {
             RGBColor[
             0.3740191991192683, 0.498378364350731, 0.945053150529056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 146}], {
             RGBColor[
             0.5482837244588973, 0.6429264164840773, 0.9581079053455026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 151}], {
             RGBColor[
             0.4470831312871756, 0.5612210364261243, 0.9498307443773351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 213}], {
             RGBColor[
             0.30617003866385434`, 0.4284245575921632, 0.941139446316178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 224}], {
             RGBColor[
             0.5960635299248768, 0.6802523636540716, 0.9628701498266832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 227}], {
             RGBColor[
             0.40448562385251274`, 0.5247668501676361, 0.9469944441726568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 243}], {
             RGBColor[
             0.35607647557932476`, 0.4808793870411815, 0.9439815440685568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 267}], {
             RGBColor[
             0.4929946052828129, 0.5984940393041163, 0.9534450637895424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 306}], {
             RGBColor[
             0.4116309085152033, 0.5309557366100093, 0.9474497353930363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 311}], {
             RGBColor[
             0.314519052497135, 0.4371999004889925, 0.9416149103027242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 346}], {
             RGBColor[
             0.590528527860057, 0.6759283779734608, 0.9623184725483971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 350}], {
             RGBColor[
             0.3251236909992271, 0.4483460479276068, 0.9422188287772615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 363}], {
             RGBColor[
             0.3333629807403148, 0.45700606384663195`, 0.9426880441390796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 383}], {
             RGBColor[
             0.37465962801960084`, 0.49893307167530665`, 0.9450939580922763]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 47}], {
             RGBColor[
             0.30541264838807003`, 0.4374629295898209, 0.9407362271394002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 50}], {
             RGBColor[
             0.3446081328553494, 0.47141208821304803`, 0.9432337287504492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 136}], {
             RGBColor[
             0.24764510233367043`, 0.37762108253202276`, 0.9374143942685803]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 149}], {
             RGBColor[
             0.27126823656742527`, 0.40245049440491787`, 0.9387596968158973]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 164}], {
             RGBColor[
             0.35411726005158994`, 0.47964841624780197`, 0.9438396419268027]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 197}], {
             RGBColor[
             0.3760470845696686, 0.4984755005053315, 0.9452832516745576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 210}], {
             RGBColor[
             0.4683998287130413, 0.57342357442411, 0.9525727719795076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 217}], {
             RGBColor[
             0.25159156027243523`, 0.3817690600455499, 0.9376391392099317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 230}], {
             RGBColor[
             0.3012233549407334, 0.4338343741657489, 0.9404692890653826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 254}], {
             RGBColor[
             0.26611032001652285`, 0.39702919707912177`, 0.9384659610987771]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 258}], {
             RGBColor[
             0.27594963976041464`, 0.4073709459788556, 0.9390262958022226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 314}], {
             RGBColor[
             0.28804426119694415`, 0.4200831599519379, 0.939715066600644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 328}], {
             RGBColor[
             0.3288207818502756, 0.45773787826778656`, 0.9422277727046122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 41}], {
             RGBColor[
             0.3615201007140193, 0.48676169331577757`, 0.9442856660457731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 48}], {
             RGBColor[
             0.24427414810355413`, 0.37407799590532786`, 0.937222423412055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 63}], {
             RGBColor[
             0.41011882220556206`, 0.5270437380275292, 0.9478829186762534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 103}], {
             RGBColor[
             0.3582704214740334, 0.48394698449172946`, 0.9440785993581797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 265}], {
             RGBColor[
             0.29892626492534324`, 0.43152083582937195`, 0.9403347806144945]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 295}], {
             RGBColor[
             0.3515022809006535, 0.47808476130370414`, 0.9436473394256757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 48}], {
             RGBColor[
             0.30559905244532437`, 0.4279851259861349, 0.9411010450746482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 63}], {
             RGBColor[
             0.47144372654733235`, 0.5809508681083363, 0.9517615403388466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.4211634093451815, 0.5392123097115138, 0.9480571379166631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 265}], {
             RGBColor[
             0.36025116926711354`, 0.485427965910179, 0.9442134022770877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 295}], {
             RGBColor[
             0.4128271852424238, 0.5319918913845112, 0.9475259610882689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 325}], {
             RGBColor[
             0.35094268680647445`, 0.4756441606521714, 0.9436832979716201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 381}], {
             RGBColor[
             0.3916346250095971, 0.5136359608798852, 0.9461755898900783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 67}], {
             RGBColor[
             0.3628497844714325, 0.48351434966248014`, 0.9446308991390405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 75}], {
             RGBColor[
             0.5983340884499241, 0.6710051197652123, 0.9625685556466869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 133}], {
             RGBColor[
             0.2732651326407469, 0.4045493587885027, 0.93887341709313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 178}], {
             RGBColor[
             0.2659667693291203, 0.3968783162050224, 0.9384577860994938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 200}], {
             RGBColor[
             0.2836290214190485, 0.415312162676207, 0.9394683961603105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 278}], {
             RGBColor[
             0.31144990066166567`, 0.4394092099581134, 0.9412411179846125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 296}], {
             RGBColor[
             0.5370591251119928, 0.6222698253479424, 0.9601745608620341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 320}], {
             RGBColor[
             0.611037606865133, 0.6804793829991729, 0.9410648125779792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 330}], {
             RGBColor[
             0.23723831194239087`, 0.36668288600216725`, 0.9368217429512636]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 347}], {
             RGBColor[
             0.22342238050199298`, 0.3521614660776615, 0.9360349460945719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 367}], {
             RGBColor[
             0.32379366762817957`, 0.4501007604887406, 0.9420276519005543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 398}], {
             RGBColor[
             0.3275247427135841, 0.45333243019843156`, 0.9422653927057361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 159}], {
             RGBColor[
             0.31622161025609596`, 0.44378878729320503`, 0.9415361392462538]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 250}], {
             RGBColor[
             0.3960777590456892, 0.5174843802635383, 0.946458702461949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 265}], {
             RGBColor[
             0.33516551896762126`, 0.4637000364622035, 0.9426149668223736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 321}], {
             RGBColor[
             0.31746730347917274`, 0.4450980898521708, 0.94160707963247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 325}], {
             RGBColor[
             0.32585703650698217`, 0.4539162312041959, 0.942084862516906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 375}], {
             RGBColor[
             0.31867425744211975`, 0.4463666749925293, 0.9416758138751314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 381}], {
             RGBColor[
             0.36654897471010484`, 0.49190803143190964`, 0.9445771544353643]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 66}], {
             RGBColor[
             0.68996325658675, 0.7576110008992647, 0.9698098735917471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 81}], {
             RGBColor[
             0.5069018182460343, 0.6085416520083449, 0.9548833045524102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 119}], {
             RGBColor[
             0.4115027483879924, 0.5147489447393624, 0.9492132859893623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[
             0.5319466328529848, 0.6302342116319024, 0.9564791379929052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 130}], {
             RGBColor[
             0.44768774069176076`, 0.5527816659116453, 0.9512739677701629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 135}], {
             RGBColor[
             0.47922511283069624`, 0.5845694808492404, 0.9531197693568945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 146}], {
             RGBColor[
             0.6534896381703252, 0.7291175329825867, 0.966174524173341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 151}], {
             RGBColor[
             0.5522890449986035, 0.6474121529246337, 0.9578973632051735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 227}], {
             RGBColor[
             0.5096915375639408, 0.6109579666661455, 0.9550610630004952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 243}], {
             RGBColor[
             0.4612823892907527, 0.5670705035396909, 0.9520481628963953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 267}], {
             RGBColor[
             0.598200518994241, 0.6846851558026257, 0.9615116826173808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 275}], {
             RGBColor[
             0.4983358660622073, 0.6011222547639892, 0.9543374896538308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 311}], {
             RGBColor[
             0.419724966208563, 0.5233910169875019, 0.9496815291305626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 317}], {
             RGBColor[
             0.4417431642582036, 0.5465335391720616, 0.9509354329364846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 326}], {
             RGBColor[
             0.4658970134339293, 0.571920766098239, 0.9523109589146245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 344}], {
             RGBColor[
             0.4112077364415015, 0.5144388684787627, 0.9491964854954407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 346}], {
             RGBColor[
             0.695734441571485, 0.7621194944719702, 0.9703850913762355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 383}], {
             RGBColor[
             0.47986554173102886`, 0.5851241881738161, 0.9531605769201147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 48}], {
             RGBColor[
             0.38920001432899975`, 0.49668356628117993`, 0.9474538022862284]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 74}], {
             RGBColor[
             0.4413156711319314, 0.551460425904551, 0.9504217118429503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 103}], {
             RGBColor[
             0.503196287699479, 0.6065525548675816, 0.9543099782323532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 116}], {
             RGBColor[
             0.4302052765777473, 0.5397826967884024, 0.9497889913094454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 262}], {
             RGBColor[
             0.49854471319412985`, 0.6025235948259807, 0.9540135840180981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 290}], {
             RGBColor[
             0.5957755494955228, 0.6827164563199353, 0.9613207801354857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 304}], {
             RGBColor[
             0.38448696441157015`, 0.4917298519933374, 0.9471854010657634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 338}], {
             RGBColor[
             0.5092956838947738, 0.6118355452873794, 0.954698626364433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 52}], {
             RGBColor[
             0.27377761381748666`, 0.4050880089984395, 0.9389026021379974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 60}], {
             RGBColor[
             0.33325018922773614`, 0.4624173545613103, 0.9424791462343854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 102}], {
             RGBColor[
             0.3192511065558459, 0.4502920527652725, 0.9415871370654354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 105}], {
             RGBColor[
             0.3217147365822906, 0.4524259252685334, 0.9417441173922179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 128}], {
             RGBColor[
             0.36531266707208715`, 0.490188261363094, 0.9445221389708915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 139}], {
             RGBColor[
             0.5245416608538097, 0.6185121633262743, 0.9579737122858718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 199}], {
             RGBColor[
             0.24457377066060387`, 0.3743929182099544, 0.9372394864734273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 213}], {
             RGBColor[
             0.24474198659438468`, 0.37456972382186426`, 0.9372490661220028]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 215}], {
             RGBColor[
             0.40721683557157384`, 0.5248710078099499, 0.9476377846266525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 259}], {
             RGBColor[
             0.33755056746461876`, 0.46614212604680316`, 0.9427531625329645]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 271}], {
             RGBColor[
             0.3326104422785615, 0.46186323790855177`, 0.9424383821244902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 287}], {
             RGBColor[
             0.3635077382141953, 0.4886249227047502, 0.9444071305001026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 333}], {
             RGBColor[
             0.3265394154967932, 0.45660481964886246`, 0.942051541666354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 337}], {
             RGBColor[
             0.32952827394992806`, 0.45919361861657404`, 0.942241989084044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 345}], {
             RGBColor[
             0.2617802924179151, 0.3924780635333786, 0.9382193724327382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 350}], {
             RGBColor[
             0.26369563892975745`, 0.3944912141573078, 0.9383284485830865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 353}], {
             RGBColor[
             0.2751091984773059, 0.40648758890325326`, 0.9389784339144711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 400}], {
             RGBColor[
             0.28836607301796185`, 0.42042140457987554`, 0.9397333933077731]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 136}], {
             RGBColor[
             0.26044780840090453`, 0.39020203182779256`, 0.9381755460216508]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 149}], {
             RGBColor[
             0.2840709426346593, 0.4150314437006878, 0.9395208485689678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 155}], {
             RGBColor[
             0.2660196475094465, 0.3960583880058739, 0.938492854016085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 268}], {
             RGBColor[
             0.2493647169807538, 0.3785530000366316, 0.9375443803612376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 279}], {
             RGBColor[
             0.36691996611882405`, 0.4922293655435718, 0.944600793679873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 299}], {
             RGBColor[
             0.3817267019916116, 0.5050542159483966, 0.9455442657966047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 300}], {
             RGBColor[
             0.5318940143421522, 0.6256050928231319, 0.9583863766764964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 371}], {
             RGBColor[
             0.25651238701015394`, 0.38606565442598595`, 0.9379514295953817]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.35419777393686713`, 0.4682671706978866, 0.9446982977051286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 86}], {
             RGBColor[
             0.264596021479936, 0.3924703614361743, 0.9384883681990903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 103}], {
             RGBColor[
             0.30234937320533845`, 0.4251704171620868, 0.9408939783870549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 295}], {
             RGBColor[
             0.29558123263195857`, 0.4193081939740615, 0.9404627184545509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 191}], {
             RGBColor[
             0.3994785064049896, 0.5204299366996321, 0.9466753950765208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 225}], {
             RGBColor[
             0.40477734304775703`, 0.5250195226723238, 0.9470130322618207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 235}], {
             RGBColor[
             0.4565710256375674, 0.5683564982670202, 0.9507343957854888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 261}], {
             RGBColor[
             0.3986270537137463, 0.5196924511737337, 0.9466211412639448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 327}], {
             RGBColor[
             0.3301453452518256, 0.4555556358194833, 0.9424340824829773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 335}], {
             RGBColor[
             0.3926234157523265, 0.5144924017231696, 0.9462385947618517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 349}], {
             RGBColor[
             0.3884571134774092, 0.5108837600970773, 0.9459731216650105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 355}], {
             RGBColor[
             0.4461051681544804, 0.5598598436807436, 0.949910485146721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 127}], {
             RGBColor[
             0.6826468320385839, 0.7470549233015933, 0.942190363034084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 137}], {
             RGBColor[
             0.40562233975996953`, 0.5257514163536725, 0.9470668747051216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 138}], {
             RGBColor[
             0.29131584263696253`, 0.41539851226716606`, 0.9401988116613904]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 147}], {
             RGBColor[
             0.4613813762065746, 0.5720693570734913, 0.9511662450316194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 164}], {
             RGBColor[
             0.40611545058610343`, 0.5261785241667989, 0.9470982952909222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 197}], {
             RGBColor[
             0.4280452751041821, 0.5450056084243284, 0.9485419050386771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 210}], {
             RGBColor[
             0.5203980192475548, 0.619953682343107, 0.9558314253436271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 217}], {
             RGBColor[
             0.3035897508069487, 0.42829916796454687`, 0.9408977925740512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 230}], {
             RGBColor[
             0.35322154547524687`, 0.4803644820847459, 0.9437279424295021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 242}], {
             RGBColor[
             0.46525159934266525`, 0.575211378566935, 0.9514709231739868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 254}], {
             RGBColor[
             0.31810851055103634`, 0.4435593049981188, 0.9417246144628966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 258}], {
             RGBColor[
             0.32794783029492813`, 0.4539010538978526, 0.9422849491663421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 328}], {
             RGBColor[
             0.38081897238478907`, 0.5042679861867836, 0.9454864260687317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 331}], {
             RGBColor[
             0.4050425937382462, 0.525249269488538, 0.9470299338012667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 79}], {
             RGBColor[
             0.42383070646016446`, 0.5378565197505502, 0.9489914188711132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 87}], {
             RGBColor[
             0.42906098198234666`, 0.5433538709429852, 0.9492892753246022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 126}], {
             RGBColor[
             0.3859839460489116, 0.4980771749351177, 0.9468361018549569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 176}], {
             RGBColor[
             0.5496974271628667, 0.6453081608145296, 0.9576933415557354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 205}], {
             RGBColor[
             0.3816646463695007, 0.4935373171126398, 0.9465901241280457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 232}], {
             RGBColor[
             0.4470516870926914, 0.559006641466055, 0.9504330594894571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 277}], {
             RGBColor[
             0.39012189966957106`, 0.5024264265518437, 0.9470717521920997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 298}], {
             RGBColor[
             0.5276365651212307, 0.62739815917862, 0.9559566296842175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 373}], {
             RGBColor[
             0.42990043139185075`, 0.5441510858251636, 0.9493401966424595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 390}], {
             RGBColor[
             0.6424782378300793, 0.719215386813794, 0.9659657980763083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 60}], {
             RGBColor[
             0.3053006735106386, 0.4330406414409925, 0.9408874626618999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 68}], {
             RGBColor[
             0.32468254440688876`, 0.44982824385016823`, 0.9421224583366936]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 105}], {
             RGBColor[
             0.2937652208651931, 0.42304921214821567`, 0.9401524338197325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 129}], {
             RGBColor[
             0.31545631704061516`, 0.44183694942917284`, 0.9415345712873471]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 199}], {
             RGBColor[
             0.2166242549435063, 0.3450162050896367, 0.9356478029009416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 271}], {
             RGBColor[
             0.30466092656146393`, 0.4324865247882341, 0.9408466985520045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 287}], {
             RGBColor[
             0.33555822249709777`, 0.4592482095844325, 0.9428154469276171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 303}], {
             RGBColor[
             0.39884242382204343`, 0.5113862459388874, 0.9475871249444624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 333}], {
             RGBColor[
             0.29858989977969563`, 0.42722810652854476`, 0.9404598580938686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 337}], {
             RGBColor[
             0.30157875823283053`, 0.42981690549625634`, 0.9406503055115585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 345}], {
             RGBColor[
             0.23383077670081756`, 0.3631013504130609, 0.9366276888602527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 353}], {
             RGBColor[
             0.24715968276020836`, 0.37711087578293556`, 0.9373867503419856]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 391}], {
             RGBColor[
             0.34711838616100266`, 0.469261042319387, 0.9435520503340298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 69}], {
             RGBColor[
             0.31839566963477894`, 0.4502000588311475, 0.9415088684162602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 93}], {
             RGBColor[
             0.25486194035162746`, 0.3834512013442363, 0.9378896502879182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 131}], {
             RGBColor[
             0.33554192847538483`, 0.46505128644285315`, 0.9426014128677423]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 142}], {
             RGBColor[
             0.6156001870492223, 0.6920758906039949, 0.9663793182974425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 188}], {
             RGBColor[
             0.4245411257481879, 0.5402906387360166, 0.9487827717535133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 201}], {
             RGBColor[
             0.3058090270585438, 0.43699981970507196`, 0.9407910115064165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 264}], {
             RGBColor[
             0.28298114815852826`, 0.4130062716100371, 0.9394909975738811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 273}], {
             RGBColor[
             0.3063571184099675, 0.4375758984664171, 0.9408222244980515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 281}], {
             RGBColor[
             0.416876467292682, 0.5340681237129082, 0.9481793817633268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[
             0.28269237573651806`, 0.4127027534852754, 0.9394745524116481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 394}], {
             RGBColor[
             0.2770374240531607, 0.40675904072142155`, 0.9391525112790322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 64}], {
             RGBColor[
             0.2927022660719577, 0.42085567830108206`, 0.940131308767449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 83}], {
             RGBColor[
             0.2376645887247637, 0.3671309299279501, 0.9368460187833998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 123}], {
             RGBColor[
             0.2843896268654962, 0.4136556880258398, 0.9396016347477915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 161}], {
             RGBColor[
             0.282603681693835, 0.4121087920823612, 0.9394878359007025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 196}], {
             RGBColor[
             0.36745906495436487`, 0.48426115847936185`, 0.9452664014748602]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 198}], {
             RGBColor[
             0.3341486175380005, 0.45675442478677325`, 0.9427722336332957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 206}], {
             RGBColor[
             0.2938190592489226, 0.4218229884193119, 0.9402024698411438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 214}], {
             RGBColor[
             0.2928197128657555, 0.42095740481082217`, 0.9401387923732956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 310}], {
             RGBColor[
             0.23929811012085286`, 0.3688478644864783, 0.9369390454103288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 332}], {
             RGBColor[
             0.2647762016311687, 0.39562695406812337`, 0.9383899850303825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 389}], {
             RGBColor[
             0.2102070848149799, 0.33827135241246953`, 0.9352823545554745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 57}], {
             RGBColor[
             0.21868996917038014`, 0.34718740171592777`, 0.9357654422702117]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 68}], {
             RGBColor[
             0.3143831515140252, 0.43900292890054254`, 0.9415359231480314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 72}], {
             RGBColor[
             0.22078375342483658`, 0.3493881017209507, 0.9358846801860268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 83}], {
             RGBColor[
             0.23424870998454433`, 0.3635406247927584, 0.936651489542484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 123}], {
             RGBColor[
             0.28097374812527676`, 0.4100653828906481, 0.9394071055068757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 161}], {
             RGBColor[
             0.27918780295361556`, 0.40851848694716947`, 0.9392933066597867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 196}], {
             RGBColor[
             0.36404318621414555`, 0.48067085334417015`, 0.9450718722339444]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 236}], {
             RGBColor[
             0.22482708805000756`, 0.35363790277422746`, 0.9361149421113528]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 262}], {
             RGBColor[
             0.3161359049398907, 0.44052107582207856`, 0.9416476070464284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 284}], {
             RGBColor[
             0.2521745762209059, 0.3823818467727387, 0.9376723411057022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 334}], {
             RGBColor[
             0.30745467183668396`, 0.43300182803954357`, 0.9410944465496052]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 366}], {
             RGBColor[
             0.4381827526213766, 0.5407262379017161, 0.9510003383758641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 397}], {
             RGBColor[
             0.2729381994364897, 0.4031053944948411, 0.9388950874499828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 65}], {
             RGBColor[
             0.37067451824349695`, 0.49505867369262807`, 0.9448555073994569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 100}], {
             RGBColor[
             0.39036114706475933`, 0.5125329382909294, 0.9460944450015256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 174}], {
             RGBColor[
             0.404416057730088, 0.5247065954888869, 0.9469900114808509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 198}], {
             RGBColor[
             0.4367055119429081, 0.5526740978128746, 0.9490474669508485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 203}], {
             RGBColor[
             0.39911858607608885`, 0.5201181918008599, 0.9466524612714282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 206}], {
             RGBColor[
             0.39637595365383016`, 0.5177426614454131, 0.9464777031586966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 266}], {
             RGBColor[
             0.3740774921392811, 0.49842885483477384`, 0.9450568649087447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 341}], {
             RGBColor[
             0.4309088628759563, 0.5476533317391343, 0.9486781095980779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 358}], {
             RGBColor[
             0.41734032867523163`, 0.5359009493888248, 0.9478135345969914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 68}], {
             RGBColor[
             0.3078438083697434, 0.4321296646375999, 0.9411635172300556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 72}], {
             RGBColor[
             0.21424441028055485`, 0.34251483745800804`, 0.9355122742680513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 86}], {
             RGBColor[
             0.27649478457555554`, 0.40497671587482426`, 0.9391659851547434]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 108}], {
             RGBColor[
             0.21332451008604897`, 0.3415479640285414, 0.9354598873128446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 236}], {
             RGBColor[
             0.21828774490572583`, 0.3467646385112848, 0.9357425361933771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 262}], {
             RGBColor[
             0.30959656179560896`, 0.4336478115591359, 0.9412752011284529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 284}], {
             RGBColor[
             0.24563523307662416`, 0.375508582509796, 0.9372999351877267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 297}], {
             RGBColor[
             0.22177864176760326`, 0.35043379244876277`, 0.935941337605342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 325}], {
             RGBColor[
             0.24559549729162883`, 0.3754668176803717, 0.937297672293555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 376}], {
             RGBColor[
             0.21320391816834305`, 0.34142121427706323`, 0.935453019781531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 397}], {
             RGBColor[
             0.266398856292208, 0.39623213023189846`, 0.9385226815320072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 124}], {
             RGBColor[
             0.44145174194901887`, 0.5540514282861765, 0.950105198611273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 152}], {
             RGBColor[
             0.2925817989055697, 0.4229882363497197, 0.9400417288154854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 156}], {
             RGBColor[
             0.32890441790656233`, 0.4593022083991205, 0.9421784765636172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 160}], {
             RGBColor[
             0.6064584118464593, 0.6848270019072276, 0.9654887164744206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 179}], {
             RGBColor[
             0.2601942547844003, 0.3889468739894696, 0.9381973060908626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 181}], {
             RGBColor[
             0.35312837658012186`, 0.48028378387059345`, 0.9437220057898907]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 220}], {
             RGBColor[
             0.30360170759542165`, 0.4345708590853202, 0.9406692963128784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[
             0.2832291784819947, 0.41315803929415806`, 0.9395091109183247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 352}], {
             RGBColor[
             0.3071005425765026, 0.4382483564893869, 0.9408685497889885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 396}], {
             RGBColor[
             0.35224707574789904`, 0.47952044538518984`, 0.9436658500801652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 132}], {
             RGBColor[
             0.3463551908255947, 0.4744171908002365, 0.9432904243829052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 149}], {
             RGBColor[
             0.29686014620171963`, 0.42610880902641374`, 0.9403357653112121]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 155}], {
             RGBColor[
             0.2788088510765068, 0.4071357533315999, 0.9393077707583293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 164}], {
             RGBColor[
             0.3797091696858843, 0.5033067308692978, 0.9454157104221175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 210}], {
             RGBColor[
             0.4939917383473357, 0.5970818890456058, 0.9541488404748225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 230}], {
             RGBColor[
             0.32681526457502774`, 0.45749268878724475`, 0.9420453575606975]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 258}], {
             RGBColor[
             0.301541549394709, 0.43102926060035146`, 0.9406023642975375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 264}], {
             RGBColor[
             0.29101283962560953`, 0.4199629190742722, 0.9400027698520176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 268}], {
             RGBColor[
             0.2621539205478141, 0.3896303653623576, 0.938359297103482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 279}], {
             RGBColor[
             0.3797091696858843, 0.5033067308692978, 0.9454157104221175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 299}], {
             RGBColor[
             0.39451590555867194`, 0.5161315812741226, 0.9463591825388491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 300}], {
             RGBColor[
             0.5446832179092125, 0.6366824581488579, 0.9592012934187407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 328}], {
             RGBColor[
             0.35441269148456994`, 0.48139619288928237`, 0.943803841199927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 394}], {
             RGBColor[
             0.285069115520242, 0.41371568818565657`, 0.9396642835571687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 68}], {
             RGBColor[
             0.38415511981713824`, 0.507157589413039, 0.9456990024330816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 72}], {
             RGBColor[
             0.2905557217279497, 0.41754276223344716`, 0.9400477594710772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 102}], {
             RGBColor[
             0.3507741662489978, 0.47824468520782554`, 0.943571997589338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 105}], {
             RGBColor[
             0.35323779627544255`, 0.48037855771108645`, 0.9437289779161204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 108}], {
             RGBColor[
             0.2896358215334438, 0.41657588880398044`, 0.9399953725158705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 139}], {
             RGBColor[
             0.5560647205469617, 0.6464647957688274, 0.9599585728097744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 297}], {
             RGBColor[
             0.2980899532149981, 0.4254617172242019, 0.940476822808368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 333}], {
             RGBColor[
             0.35806247518994516`, 0.48455745209141554`, 0.9440364021902565]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 337}], {
             RGBColor[
             0.36105133364308, 0.4871462510591271, 0.9442268496079466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 345}], {
             RGBColor[
             0.29330335211106706`, 0.42043069597593163`, 0.9402042329566408]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 353}], {
             RGBColor[
             0.30663225817045786`, 0.4344402213458063, 0.9409632944383737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 70}], {
             RGBColor[
             0.696780654684315, 0.75768435326128, 0.9044964320757566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 90}], {
             RGBColor[
             0.6323949919871796, 0.7081717856119512, 0.9667363422176115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 95}], {
             RGBColor[
             0.37961313118710016`, 0.5032235471486862, 0.9454095909338984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 148}], {
             RGBColor[
             0.3532719183667592, 0.47961588167311797`, 0.9437601595989049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 228}], {
             RGBColor[
             0.3233875491431635, 0.44820551484067284`, 0.9420582889815835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 282}], {
             RGBColor[
             0.3354089730379043, 0.4608407935563431, 0.942742891288286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 285}], {
             RGBColor[
             0.3325960865537333, 0.45788427151417543`, 0.9425827015643051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 301}], {
             RGBColor[
             0.40887746871367386`, 0.5285708454458329, 0.9472742886436541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 382}], {
             RGBColor[
             0.32610311848744084`, 0.4510597503985493, 0.9422129366384153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 91}], {
             RGBColor[
             0.4270011387266818, 0.5403176430897468, 0.9492512725222852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 111}], {
             RGBColor[
             0.3034421802127986, 0.43612364730866887`, 0.9405972169367458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 117}], {
             RGBColor[
             0.32226102864783857`, 0.45242358796027593`, 0.9417963373181724]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 223}], {
             RGBColor[
             0.28976652836236727`, 0.4218933719408429, 0.939813147167849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 247}], {
             RGBColor[
             0.3978303314006042, 0.5166354675725428, 0.9469548397133885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 256}], {
             RGBColor[
             0.34295106924995805`, 0.4703442612181544, 0.9431146884098549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 319}], {
             RGBColor[
             0.4493271784774564, 0.5584429279360548, 0.9510088601544446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 323}], {
             RGBColor[
             0.2793400955249551, 0.410934529954699, 0.9392193772422834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 362}], {
             RGBColor[
             0.2848474217161079, 0.41672307896624905`, 0.9395330113215106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 395}], {
             RGBColor[
             0.315435518646874, 0.44651167425754806`, 0.9413614218564724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 103}], {
             RGBColor[
             0.4681940473073464, 0.5781361592842882, 0.9515544736512532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 295}], {
             RGBColor[
             0.46142590673396655`, 0.5722739360962629, 0.9511232137187492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 88}], {
             RGBColor[
             0.3798215373528502, 0.5034040580946604, 0.9454228703904937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 101}], {
             RGBColor[
             0.4217235124038003, 0.5386986285638282, 0.9483688025457949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 115}], {
             RGBColor[
             0.27640138510843804`, 0.40372241887287563`, 0.9392029977115688]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 120}], {
             RGBColor[
             0.394382119895705, 0.5160157028571235, 0.9463506578347067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 123}], {
             RGBColor[
             0.3450308231423533, 0.473270090077668, 0.9432060368452215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 140}], {
             RGBColor[
             0.3480678792563178, 0.47590063543670535`, 0.94339955537524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 161}], {
             RGBColor[
             0.3432448779706921, 0.4717231941341894, 0.9430922379981326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 193}], {
             RGBColor[
             0.3132366987531669, 0.4424386690072624, 0.9413007143306729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 195}], {
             RGBColor[
             0.4590714310276291, 0.5690193514072127, 0.9513089675097965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 214}], {
             RGBColor[
             0.35346090914261263`, 0.4805718068626504, 0.9437431944707256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 233}], {
             RGBColor[
             0.6626604874496049, 0.2495746934509701, 0.42405723695495967`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 257}], {
             RGBColor[
             0.2766822479670991, 0.40401762354506215`, 0.9392189924358703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 283}], {
             RGBColor[
             0.49641678675645395`, 0.5993379935769759, 0.9542489307133151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 312}], {
             RGBColor[
             0.2684490175575002, 0.39536397636761544`, 0.9387501221440164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 332}], {
             RGBColor[
             0.3254173979080258, 0.4552413561199516, 0.9419943871278126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 356}], {
             RGBColor[
             0.3875758154369003, 0.5101204240297159, 0.9459169661331706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 360}], {
             RGBColor[
             0.3515415117074009, 0.4789093212759902, 0.9436208921634104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 380}], {
             RGBColor[
             0.31381340596869706`, 0.443044824856134, 0.9413335569534356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 389}], {
             RGBColor[
             0.270848281091837, 0.39788575446429775`, 0.9388867566529046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 100}], {
             RGBColor[
             0.3238608067033406, 0.454510989682101, 0.9418725790958578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 167}], {
             RGBColor[
             0.3569546567018582, 0.4831752192055521, 0.9439812899540209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 174}], {
             RGBColor[
             0.3379157173686692, 0.4666846468800585, 0.9427681455751831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 198}], {
             RGBColor[
             0.37020517158148936`, 0.4946521492040462, 0.9448256010451808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 203}], {
             RGBColor[
             0.33261824571467014`, 0.46209624319203163`, 0.9424305953657605]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 206}], {
             RGBColor[
             0.32987561329241144`, 0.45972071283658483`, 0.9422558372530287]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 211}], {
             RGBColor[
             0.4704543670111624, 0.5765027740900719, 0.9525894323350663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 266}], {
             RGBColor[
             0.3075771517778624, 0.4404069062259455, 0.940834999003077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 313}], {
             RGBColor[
             0.3433925002981691, 0.4714283609824774, 0.9431171213405218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 329}], {
             RGBColor[
             0.2623244260629275, 0.39304998249435236`, 0.9382503600388481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 340}], {
             RGBColor[
             0.3208353395962905, 0.4518904821383725, 0.9416797990071122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 341}], {
             RGBColor[
             0.3644085225145376, 0.489631383130306, 0.94445624369241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 358}], {
             RGBColor[
             0.3508399883138129, 0.4778790007799965, 0.9435916686913235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 81}], {
             RGBColor[
             0.5618700137364048, 0.6515960302512358, 0.9602848943896474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 119}], {
             RGBColor[
             0.46647094387836285`, 0.5578033229822533, 0.9546148758265995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 130}], {
             RGBColor[
             0.5026559361821312, 0.5958360441545362, 0.9566755576074002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 146}], {
             RGBColor[
             0.7084578336606957, 0.7721719112254777, 0.9715761140105782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 151}], {
             RGBColor[
             0.607257240488974, 0.6904665311675247, 0.9632989530424108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 158}], {
             RGBColor[
             0.5932620313087027, 0.6787862180636801, 0.962285165990483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 243}], {
             RGBColor[
             0.5162505847811232, 0.6101248817825817, 0.9574497527336324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 267}], {
             RGBColor[
             0.6531687144846114, 0.7277395340455166, 0.9669132724546181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 275}], {
             RGBColor[
             0.5533040615525777, 0.64417663300688, 0.9597390794910681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 311}], {
             RGBColor[
             0.47469316169893344`, 0.5664453952303927, 0.9550831189677997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 317}], {
             RGBColor[
             0.49671135974857406`, 0.5895879174149525, 0.9563370227737218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 344}], {
             RGBColor[
             0.46617593193187196`, 0.5574932467216536, 0.9545980753326779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 346}], {
             RGBColor[
             0.7507026370618555, 0.8051738727148611, 0.9757866812134728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 354}], {
             RGBColor[
             0.5428055015691784, 0.635083308022227, 0.9590701205324379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 75}], {
             RGBColor[
             0.7040811399544908, 0.7669578174517652, 0.9692464624438973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 126}], {
             RGBColor[
             0.34521514563862266`, 0.4649792261485165, 0.9436266325456223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 133}], {
             RGBColor[
             0.37901218414531357`, 0.5005020564750555, 0.9455513238903405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 200}], {
             RGBColor[
             0.3893760729236152, 0.5112648603627599, 0.946146302957521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 320}], {
             RGBColor[
             0.7167846583696997, 0.7764320806857257, 0.9477427193751897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 347}], {
             RGBColor[
             0.3291694320065597, 0.4481141637642143, 0.9427128528917824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 398}], {
             RGBColor[
             0.4332717942181508, 0.5492851278849844, 0.9489432995029465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 72}], {
             RGBColor[
             0.30993759262419984`, 0.43433036464262287`, 0.9412827551458708]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 236}], {
             RGBColor[
             0.3139809272493709, 0.4385801656958995, 0.9415130170711967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 262}], {
             RGBColor[
             0.405289744139254, 0.5254633387437506, 0.9470456820062724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 284}], {
             RGBColor[
             0.34132841542026915`, 0.46732410969441085`, 0.9430704160655462]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 333}], {
             RGBColor[
             0.37744434608619537`, 0.5013450545005912, 0.9452713978650502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 334}], {
             RGBColor[
             0.3966085110360473, 0.5179440909612156, 0.9464925215094491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 337}], {
             RGBColor[
             0.38043320453933016`, 0.5039338534683028, 0.9454618452827401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 376}], {
             RGBColor[
             0.30889710051198804`, 0.433236741461678, 0.9412235006593505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 391}], {
             RGBColor[
             0.42597283246750234`, 0.5433779902914334, 0.9483635901052114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 397}], {
             RGBColor[
             0.36209203863585304`, 0.48804765741651324`, 0.9442931624098267]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 93}], {
             RGBColor[
             0.24552723133114446`, 0.3753659455668112, 0.9372948508834921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 131}], {
             RGBColor[
             0.32620721945490183`, 0.456966030665428, 0.9420066134633163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 142}], {
             RGBColor[
             0.6062654780287391, 0.6839906348265697, 0.9657845188930164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 188}], {
             RGBColor[
             0.41520641672770486`, 0.5322053829585914, 0.9481879723490872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 201}], {
             RGBColor[
             0.2964743180380608, 0.4289145639276468, 0.9401962121019904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 273}], {
             RGBColor[
             0.29702240938948443`, 0.42949064268899195`, 0.9402274250936254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 281}], {
             RGBColor[
             0.40754175827219896`, 0.5259828679354831, 0.9475845823589008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 293}], {
             RGBColor[
             0.273357666716035, 0.40461749770785027`, 0.9388797530072219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 394}], {
             RGBColor[
             0.2677027150326776, 0.3986737849439964, 0.9385577118746061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 90}], {
             RGBColor[
             0.9228091530146288, 0.9394601738163295, 0.9241184827599657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 95}], {
             RGBColor[
             0.6700272922145494, 0.7345119353530646, 0.9027917314762526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 177}], {
             RGBColor[
             0.6130565245958468, 0.678710665758478, 0.899397992307858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 228}], {
             RGBColor[
             0.6138017101706127, 0.6794939030450512, 0.8994404295239377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 246}], {
             RGBColor[
             0.7208997404305972, 0.7785401570987851, 0.9060429318059418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 260}], {
             RGBColor[
             0.9798059972570583, 0.9839610495479766, 0.8967266367702569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 285}], {
             RGBColor[
             0.6230102475811825, 0.6891726597185538, 0.8999648421066593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 110}], {
             RGBColor[
             0.2644077580520465, 0.39523969650579377`, 0.938369002713615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 131}], {
             RGBColor[
             0.3118388634897865, 0.4418930978004859, 0.9411872906117844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 201}], {
             RGBColor[
             0.28210596207294547`, 0.4138416310627047, 0.9393768892504586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 212}], {
             RGBColor[
             0.24833159662617993`, 0.3783426315597024, 0.9374534891029614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 271}], {
             RGBColor[
             0.32190900185330207`, 0.4506153455110923, 0.941828950923634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 273}], {
             RGBColor[
             0.28265405342436917`, 0.41441770982404985`, 0.9394081022420937]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 287}], {
             RGBColor[
             0.3528062977889359, 0.47737703030729073`, 0.9437976992992465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 289}], {
             RGBColor[
             0.29787051048814117`, 0.4297944125002962, 0.9402972395102492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 292}], {
             RGBColor[
             0.27223418369453817`, 0.4034657660800988, 0.9388147060757956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 303}], {
             RGBColor[
             0.4160904991138816, 0.5295150666617456, 0.9485693773160918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 385}], {
             RGBColor[
             0.5215722313968084, 0.6133045766626779, 0.958134935678581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 400}], {
             RGBColor[
             0.27766463259270246`, 0.40917351218241604`, 0.939123962106917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 86}], {
             RGBColor[
             0.27858856883001204`, 0.40717741587984724`, 0.9392852230705584]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 108}], {
             RGBColor[
             0.2154182943405054, 0.3437486640335643, 0.9355791252286596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 236}], {
             RGBColor[
             0.22038152916018228`, 0.34896533851630773`, 0.9358617741091922]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 262}], {
             RGBColor[
             0.3116903460500654, 0.4358485115641588, 0.9413944390442679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 284}], {
             RGBColor[
             0.2477290173310806, 0.377709282514819, 0.9374191731035417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 297}], {
             RGBColor[
             0.22387242602205973`, 0.35263449245378575`, 0.9360605755211571]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 325}], {
             RGBColor[
             0.2476892815460853, 0.37766751768539464`, 0.9374169102093701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 333}], {
             RGBColor[
             0.28384494799700677`, 0.4117302273209994, 0.9396201549030457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 337}], {
             RGBColor[
             0.2868338064501416, 0.414319026288711, 0.9398106023207358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 376}], {
             RGBColor[
             0.2152977024227995, 0.3436219142820862, 0.935572257697346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 397}], {
             RGBColor[
             0.26849264054666444`, 0.39843283023692144`, 0.9386419194478224]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.36430194399811666`, 0.48743403653718465`, 0.9445265281968729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 162}], {
             RGBColor[
             0.4247591042725579, 0.5423267199327253, 0.9482862524178873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 183}], {
             RGBColor[
             0.4045945826229027, 0.5248612247781209, 0.9470013869291576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 189}], {
             RGBColor[
             0.3306185320044006, 0.4520306348801193, 0.9426083077139733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 207}], {
             RGBColor[
             0.37859117799535574`, 0.5023383826588581, 0.9453444729801983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 280}], {
             RGBColor[
             0.38446193842722615`, 0.5074233402719454, 0.9457185526436074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 291}], {
             RGBColor[
             0.6933814498032487, 0.7581051398431993, 0.9684500616396224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 336}], {
             RGBColor[
             0.31486353936717904`, 0.43547113869417114`, 0.9417110841907066]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 368}], {
             RGBColor[
             0.3748112801644788, 0.49848001517842966`, 0.9451250193443776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 387}], {
             RGBColor[
             0.45778777348859145`, 0.5705255763508003, 0.9505037949410291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 116}], {
             RGBColor[
             0.28147401888653845`, 0.41317741870627867`, 0.9393409010208689]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 118}], {
             RGBColor[
             0.24674808546068328`, 0.37667826092435863`, 0.9373633104846812]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 141}], {
             RGBColor[
             0.3578985708077199, 0.482921237251163, 0.9440806701273567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 179}], {
             RGBColor[
             0.2420321977471775, 0.37172156393291333`, 0.9370947476559277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 209}], {
             RGBColor[
             0.440701770112931, 0.5509620334014008, 0.9503733833059411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 286}], {
             RGBColor[
             0.32573069428586376`, 0.45505903941241577`, 0.9420309614803204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 290}], {
             RGBColor[
             0.4470442918043138, 0.5561111782378115, 0.9508726898469093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 304}], {
             RGBColor[
             0.23575570672036122`, 0.36512457391121367`, 0.936737310777187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 338}], {
             RGBColor[
             0.3605644262035648, 0.48523026720525564`, 0.9442505360758566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 386}], {
             RGBColor[
             0.3281333234706979, 0.45714007605266505`, 0.9421840548874165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 126}], {
             RGBColor[
             0.5806994496171142, 0.6524699962512487, 0.9615642890532686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 133}], {
             RGBColor[
             0.6144964881238052, 0.6879928265777877, 0.9634889803979868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 178}], {
             RGBColor[
             0.6071981248121785, 0.6803217839943074, 0.9630733494043506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 200}], {
             RGBColor[
             0.6248603769021068, 0.698755630465492, 0.9640839594651673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 296}], {
             RGBColor[
             0.8782904805950511, 0.9057132931372275, 0.9847901241668909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 320}], {
             RGBColor[
             0.9522689623481913, 0.9639228507884579, 0.9656803758828361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 330}], {
             RGBColor[
             0.5784696674254491, 0.6501263537914522, 0.9614373062561204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 347}], {
             RGBColor[
             0.5646537359850512, 0.6356049338669465, 0.9606505093994288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 398}], {
             RGBColor[
             0.6687560981966424, 0.7367758979877166, 0.9668809560105929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 78}], {
             RGBColor[
             0.3701049998711139, 0.49498808169535424`, 0.9448037412141542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 80}], {
             RGBColor[
             0.28507243564494283`, 0.41413726252561933`, 0.9396491645052443]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.5001112590413646, 0.6016704532984783, 0.9548400625413622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 117}], {
             RGBColor[
             0.3436048861355939, 0.4720350151120909, 0.9431151774000573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.377790189865259, 0.5016446069994023, 0.9452934347248345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 187}], {
             RGBColor[
             0.2871599169154237, 0.41633133769485164`, 0.9397680434754465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 208}], {
             RGBColor[
             0.34503513360542426`, 0.4732738235841299, 0.9432063115041167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 239}], {
             RGBColor[
             0.3744050929848215, 0.4987126062214836, 0.9450777393449366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 269}], {
             RGBColor[
             0.26230944093423875`, 0.39021191182744613`, 0.9383528456313026]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 323}], {
             RGBColor[
             0.3006839530127104, 0.4305459571065139, 0.9405382173241684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 365}], {
             RGBColor[
             0.6446811516045015, 0.7152900376289849, 0.9561035228635739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 377}], {
             RGBColor[
             0.3570861872155402, 0.48371184051764626`, 0.9439741939838251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 388}], {
             RGBColor[
             0.39334817798444677`, 0.5151201543410232, 0.9462847759704004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 395}], {
             RGBColor[
             0.3367793761346294, 0.46612310140936297`, 0.9426802619383574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 78}], {
             RGBColor[
             0.3973813643555334, 0.5186134976618173, 0.9465417670395594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 80}], {
             RGBColor[
             0.31234880012936234`, 0.4377626784920824, 0.9413871903306494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 96}], {
             RGBColor[
             0.527387623525784, 0.6252958692649413, 0.9565780883667674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 182}], {
             RGBColor[
             0.4050665543496785, 0.5252700229658653, 0.9470314605502397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 187}], {
             RGBColor[
             0.3144362813998432, 0.4399567536613147, 0.9415060693008517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 244}], {
             RGBColor[
             0.32465046349933424`, 0.4506925066644295, 0.9420877518608893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 302}], {
             RGBColor[
             0.4471157100753671, 0.5604123148669498, 0.9500640691928556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 377}], {
             RGBColor[
             0.3843625516999597, 0.5073372564841092, 0.9457122198092303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 388}], {
             RGBColor[
             0.42062454246886627`, 0.5387455703074863, 0.9480228017958056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 80}], {
             RGBColor[
             0.3159056185662029, 0.4408434158511811, 0.941613827656274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 96}], {
             RGBColor[
             0.5309444419626246, 0.62837660662404, 0.9568047256923918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 104}], {
             RGBColor[
             0.4230020806128471, 0.5408048743492607, 0.9481742964239656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 182}], {
             RGBColor[
             0.40862337278651906`, 0.528350760324964, 0.947258097875864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 187}], {
             RGBColor[
             0.3179930998366838, 0.4430374910204134, 0.941732706626476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 208}], {
             RGBColor[
             0.3758683165266843, 0.49997997690969165`, 0.9451709746551464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 302}], {
             RGBColor[
             0.4506725285122076, 0.5634930522260484, 0.95029070651848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 377}], {
             RGBColor[
             0.3879193701368002, 0.510417993843208, 0.9459388571348546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 388}], {
             RGBColor[
             0.4241813609057069, 0.541826307666585, 0.94824943912143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 87}], {
             RGBColor[
             0.30275725164593387`, 0.4355474457712999, 0.9405529496407952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 126}], {
             RGBColor[
             0.2596802157124989, 0.39027074976343246`, 0.9380997761711498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 176}], {
             RGBColor[
             0.42339369682645395`, 0.5375017356428443, 0.9489570158719285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 205}], {
             RGBColor[
             0.25536091603308797`, 0.38573089194095456`, 0.9378537984442387]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 232}], {
             RGBColor[
             0.32074795675627854`, 0.45120021629436985`, 0.9416967338056501]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[
             0.26381816933315827`, 0.3946200013801584, 0.9383354265082926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 298}], {
             RGBColor[
             0.40133283478481785`, 0.5195917340069348, 0.9472203040004105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 373}], {
             RGBColor[
             0.30359670105543796`, 0.4363446606534783, 0.9406038709586525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 390}], {
             RGBColor[
             0.5161745074936666, 0.6114089616421088, 0.9572294723925013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 96}], {
             RGBColor[
             0.4459118777364536, 0.5475257874543051, 0.9516501489834819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 104}], {
             RGBColor[
             0.33796951638667605`, 0.45995405517952587`, 0.9430197197150556]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 182}], {
             RGBColor[
             0.323590808560348, 0.4474999411552292, 0.9421035211669542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 187}], {
             RGBColor[
             0.23296053561051272`, 0.36218667185067854`, 0.9365781299175662]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 244}], {
             RGBColor[
             0.2431747177100038, 0.37292242485379334`, 0.9371598124776039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 302}], {
             RGBColor[
             0.3656399642860366, 0.48264223305631354`, 0.9451361298095702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 377}], {
             RGBColor[
             0.3028868059106292, 0.4295671746734731, 0.9407842804259448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 388}], {
             RGBColor[
             0.3391487966795358, 0.4609754884968501, 0.9430948624125202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 119}], {
             RGBColor[
             0.28340950553764716`, 0.4087339740913334, 0.9396883067872626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 128}], {
             RGBColor[
             0.4038533900026396, 0.5242192409838733, 0.9469541587908055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.3195944978414156, 0.4467666952636163, 0.9417489885680632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 135}], {
             RGBColor[
             0.35113186998035106`, 0.4785545102012114, 0.9435947901547947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 146}], {
             RGBColor[
             0.5253963953199801, 0.6231025623345577, 0.9566495449712413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 166}], {
             RGBColor[
             0.2812382423627253, 0.4064518388284541, 0.9395646565615468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 227}], {
             RGBColor[
             0.3815982947135955, 0.5049429960181165, 0.9455360837983955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 243}], {
             RGBColor[
             0.33318914644040754`, 0.4610555328916619, 0.9425231836942956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[
             0.4701072761438957, 0.5786701851545967, 0.9519867034152811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 275}], {
             RGBColor[
             0.3702426232118621, 0.4951072841159601, 0.9448125104517311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 311}], {
             RGBColor[
             0.2916317233582178, 0.4173760463394729, 0.9401565499284629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 326}], {
             RGBColor[
             0.3378037705835841, 0.46590579545021, 0.9427859797125248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 344}], {
             RGBColor[
             0.2831144935911563, 0.40842389783073374`, 0.939671506293341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 346}], {
             RGBColor[
             0.5676411987211398, 0.6561045238239411, 0.9608601121741358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 363}], {
             RGBColor[
             0.31047565160139756`, 0.43718220969711236`, 0.9412296837648183]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 383}], {
             RGBColor[
             0.3517722988806836, 0.47910921752578706`, 0.943635597718015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 172}], {
             RGBColor[
             0.2700745791439943, 0.3972156127244669, 0.9388374570489457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 194}], {
             RGBColor[
             0.3719483407706125, 0.49658469093349245`, 0.9449211972662679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 233}], {
             RGBColor[
             0.6621446861510432, 0.24912793229108293`, 0.42402437055232045`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 256}], {
             RGBColor[
             0.37055704748935114`, 0.49537962262169744`, 0.9448325452886582]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 257}], {
             RGBColor[
             0.2759085460192564, 0.4033474818052314, 0.9391696928319114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 310}], {
             RGBColor[
             0.2991656044498673, 0.4277921247984758, 0.9404941479038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 316}], {
             RGBColor[
             0.3454843659486977, 0.4736629260607993, 0.9432349361917896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 399}], {
             RGBColor[
             0.3485567845367482, 0.4763241006175203, 0.943430707987387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 118}], {
             RGBColor[
             0.22208993256753545`, 0.3507609788164681, 0.9359590651558847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 123}], {
             RGBColor[
             0.2899931457951592, 0.41954534170453606`, 0.9399207468611723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 141}], {
             RGBColor[
             0.33324041791457215`, 0.45700395514327247`, 0.9426764247985602]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 161}], {
             RGBColor[
             0.288207200623498, 0.41799844576105744`, 0.9398069480140834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 196}], {
             RGBColor[
             0.373062583884028, 0.4901508121580581, 0.9455855135882411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 214}], {
             RGBColor[
             0.2984232317954186, 0.4268470584895184, 0.9404579044866765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 286}], {
             RGBColor[
             0.3010725413927159, 0.4291417573045253, 0.9406267161515238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 332}], {
             RGBColor[
             0.2703797205608318, 0.40151660774681963`, 0.9387090971437635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 334}], {
             RGBColor[
             0.3164740695065664, 0.44248178685343154`, 0.9416080879039018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 366}], {
             RGBColor[
             0.4472021502912591, 0.5502061967156042, 0.9515139797301608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 125}], {
             RGBColor[
             0.6404074240543585, 0.7119151689050396, 0.9606009418161674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 184}], {
             RGBColor[
             0.5846058757199406, 0.6557983942210938, 0.957330337056217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 185}], {
             RGBColor[
             0.7080086386804969, 0.7699781183472195, 0.9650437715226463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 190}], {
             RGBColor[
             0.6367798547782372, 0.7087731507249966, 0.9603697963096265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 252}], {
             RGBColor[
             0.6296463008546371, 0.7025944248592195, 0.9599152525615687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 270}], {
             RGBColor[
             0.58294448618763, 0.6540521684844549, 0.9572357233801574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 274}], {
             RGBColor[
             0.6903613497123844, 0.7551827485527146, 0.9637839617865747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 288}], {
             RGBColor[
             0.6583763132768041, 0.7274789176068897, 0.9617459035481568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 318}], {
             RGBColor[
             0.7309934126260597, 0.7886381932884938, 0.9668532171236421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 168}], {
             RGBColor[
             0.3831615260262361, 0.5062969884108355, 0.9456356915153259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 238}], {
             RGBColor[
             0.4224317840580344, 0.5403109121374203, 0.9481379576317863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 379}], {
             RGBColor[
             0.37131502688323503`, 0.4960361462755276, 0.9448808430653817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 236}], {
             RGBColor[
             0.28263190345518296`, 0.4114272169331239, 0.9395154849958843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 262}], {
             RGBColor[
             0.3739407203450661, 0.49831038998097504`, 0.94504814993096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 265}], {
             RGBColor[
             0.3192481383017251, 0.4499132013602184, 0.9416007254015297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 297}], {
             RGBColor[
             0.28612280031706044`, 0.4150963708706019, 0.9397142864078492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 325}], {
             RGBColor[
             0.309939655841086, 0.4401293961022108, 0.9410706210960622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 376}], {
             RGBColor[
             0.27754807671780024`, 0.4060837926989024, 0.9392259685840381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 397}], {
             RGBColor[
             0.33074301484166513`, 0.4608947086537376, 0.9422956303345145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 176}], {
             RGBColor[
             0.42862397234863614`, 0.5429990868352793, 0.9492548723254175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 205}], {
             RGBColor[
             0.2605911915552701, 0.39122824313338955`, 0.9381516548977277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 232}], {
             RGBColor[
             0.3259782322784608, 0.4566975674868048, 0.9419945902591391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 277}], {
             RGBColor[
             0.26904844485534046`, 0.40011735257259334`, 0.9386332829617816]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 373}], {
             RGBColor[
             0.30882697657762015`, 0.4418420118459133, 0.9409017274121415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 390}], {
             RGBColor[
             0.5214047830158487, 0.6169063128345438, 0.9575273288459903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 89}], {
             RGBColor[
             0.343853022339802, 0.46972220838943946`, 0.9432235409910765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 120}], {
             RGBColor[
             0.42086019489974025`, 0.5389496805988737, 0.9480378173603216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 140}], {
             RGBColor[
             0.3745459542603531, 0.49883461317845557`, 0.9450867149008548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 189}], {
             RGBColor[
             0.3101696103460859, 0.43431880673237405`, 0.941305320508177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 195}], {
             RGBColor[
             0.48554950603166436`, 0.5919533291489629, 0.9529961270354113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 233}], {
             RGBColor[
             0.6803125374522951, 0.2648640119454702, 0.42518200997203615`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 255}], {
             RGBColor[
             0.4044263012770102, 0.5247154679343752, 0.9469906641906027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 257}], {
             RGBColor[
             0.3031603229711344, 0.4269516012868123, 0.940906151961485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 263}], {
             RGBColor[
             0.4067336692811977, 0.5267139941279145, 0.9471376876395041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 336}], {
             RGBColor[
             0.29441461770886435`, 0.4177593105464259, 0.9404080969849102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 356}], {
             RGBColor[
             0.41405389044093555`, 0.533054401771466, 0.9476041256587853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 359}], {
             RGBColor[
             0.3747258222847828, 0.4989904058207868, 0.9450981759323204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 360}], {
             RGBColor[
             0.3780195867114362, 0.5018432990177403, 0.9453080516890252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 389}], {
             RGBColor[
             0.2973263560958723, 0.42081973220604785`, 0.9405739161785194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 162}], {
             RGBColor[
             0.3418635925971597, 0.467999064338009, 0.943096776287059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 183}], {
             RGBColor[
             0.3216990709475045, 0.4505335691834045, 0.9418119107983294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 189}], {
             RGBColor[
             0.2477230203290024, 0.37770297928540286`, 0.9374188315831451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 263}], {
             RGBColor[
             0.3442870792641142, 0.4700981666809434, 0.9432511987144723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 270}], {
             RGBColor[
             0.2513180017197303, 0.381481532662043, 0.9376235604550487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.30156642675182793`, 0.4330956846772289, 0.9405290765127792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 291}], {
             RGBColor[
             0.6104859381278505, 0.6837774842484827, 0.9632605855087941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 336}], {
             RGBColor[
             0.23196802769178085`, 0.36114348309945477`, 0.9365216080598783]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 359}], {
             RGBColor[
             0.31227923226769927`, 0.4423745783738156, 0.9412116870072884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 95}], {
             RGBColor[
             0.605641629517414, 0.6849993677037357, 0.9650316416181075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 97}], {
             RGBColor[
             0.5701394652119229, 0.651762961379403, 0.9628605076484479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.5210456998236275, 0.6001623012317965, 0.9600646903373018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 228}], {
             RGBColor[
             0.5494160474734773, 0.6299813353957223, 0.9616803396657926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 246}], {
             RGBColor[
             0.6565140777334618, 0.7290275894494562, 0.9682828419477967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 260}], {
             RGBColor[
             0.915420334559923, 0.9344484818986477, 0.9589665469121118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 326}], {
             RGBColor[
             0.5776112280444863, 0.6596162578535524, 0.9632860134882798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 172}], {
             RGBColor[
             0.37288563765693983`, 0.48343882034450814`, 0.9461694747930731]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 192}], {
             RGBColor[
             0.5082217491570281, 0.6116363369513884, 0.9544282242527011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 208}], {
             RGBColor[
             0.4541083128700075, 0.5649209654558992, 0.9509373460451624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 221}], {
             RGBColor[
             0.4550473015500987, 0.5657342702556508, 0.9509971775735427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 256}], {
             RGBColor[
             0.4733681060022967, 0.5816028302417386, 0.9521645630327855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 316}], {
             RGBColor[
             0.44829542446164317`, 0.5598861336808404, 0.9505669539359168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 351}], {
             RGBColor[
             0.4278952157089251, 0.5412573746858393, 0.9493021888837556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 395}], {
             RGBColor[
             0.44585255539921265`, 0.5577702432811322, 0.9504112964794031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 399}], {
             RGBColor[
             0.4513678430496937, 0.5625473082375614, 0.9507627257315143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 98}], {
             RGBColor[
             0.30018067255193537`, 0.4328392977789574, 0.9404062172730991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 119}], {
             RGBColor[
             0.2450946688230744, 0.374940415205562, 0.9372691508531801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 130}], {
             RGBColor[
             0.2812796611268428, 0.4129731363778449, 0.9393298326339807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 143}], {
             RGBColor[
             0.5020002160718773, 0.600963572047589, 0.955717341390636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 146}], {
             RGBColor[
             0.48708155860540725`, 0.5893090034487863, 0.9542303890371588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 151}], {
             RGBColor[
             0.38588096543368555`, 0.5076036233908334, 0.9459532280689913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 158}], {
             RGBColor[
             0.3718857562534142, 0.4959233102869888, 0.9449394410170636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 186}], {
             RGBColor[
             0.3448828339839112, 0.47253473622348113`, 0.9432188386877975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 267}], {
             RGBColor[
             0.43179243942932294`, 0.5448766262688253, 0.9495675474811986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 306}], {
             RGBColor[
             0.3504287426617133, 0.4773383235747183, 0.9435722190846926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 308}], {
             RGBColor[
             0.27902390284454753`, 0.41060219139981685`, 0.9392013705368993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 346}], {
             RGBColor[
             0.529326362006567, 0.6223109649381697, 0.9584409562400533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 348}], {
             RGBColor[
             0.2845210553626427, 0.41638004723593525`, 0.9395144252404966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 354}], {
             RGBColor[
             0.32142922651388994`, 0.4522204002455357, 0.9417243955590185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 374}], {
             RGBColor[
             0.38662241518086793`, 0.5082055656975265, 0.9460115977091095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 131}], {
             RGBColor[
             0.2626734901717503, 0.39021717317851684`, 0.9383873953349742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 142}], {
             RGBColor[
             0.5427317487455877, 0.6172417773396586, 0.9621653007646743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 188}], {
             RGBColor[
             0.3516726874445534, 0.46545652547168026`, 0.9445687542207452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 201}], {
             RGBColor[
             0.23294058875490925`, 0.36216570644073565`, 0.9365769939736484]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 264}], {
             RGBColor[
             0.21011270985489372`, 0.3381721583457008, 0.9352769800411129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 273}], {
             RGBColor[
             0.23348868010633295`, 0.3627417852020808, 0.9366082069652834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 281}], {
             RGBColor[
             0.3440080289890475, 0.4592340104485719, 0.9439653642305587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 293}], {
             RGBColor[
             0.20982393743288352`, 0.3378686402209391, 0.9352605348788798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 394}], {
             RGBColor[
             0.20416898574952613`, 0.33192492745708524`, 0.934938493746264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 204}], {
             RGBColor[
             0.3935799948251498, 0.515320942436987, 0.9462995471345024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.337727936928675, 0.4669446970931135, 0.9427407033933746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 307}], {
             RGBColor[
             0.3510538251481084, 0.4784869116901702, 0.9435898172070967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 324}], {
             RGBColor[
             0.34074372355347027`, 0.46955681988966813`, 0.9429328666503511]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 97}], {
             RGBColor[
             0.3173576044118436, 0.4468147229161381, 0.9415337563647348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 148}], {
             RGBColor[
             0.3265185558969935, 0.4564434637649025, 0.9420554589994009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 166}], {
             RGBColor[
             0.2682638390235481, 0.39521406276853155`, 0.9387379390535888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 169}], {
             RGBColor[
             0.6325395981158257, 0.7064470777382018, 0.9675971938751241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 228}], {
             RGBColor[
             0.2966341866733978, 0.42503309693245744`, 0.9403535883820795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 246}], {
             RGBColor[
             0.40373221693338235`, 0.5240793509861914, 0.9469560906640837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 276}], {
             RGBColor[
             0.3535993963590901, 0.4806917575289933, 0.9437520187537001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 282}], {
             RGBColor[
             0.3086556105681386, 0.43766837564812766`, 0.9410381906887821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 305}], {
             RGBColor[
             0.2998647961037283, 0.4284286722762032, 0.9405375668098785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 326}], {
             RGBColor[
             0.3248293672444068, 0.45466801939028745`, 0.9419592622045667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 361}], {
             RGBColor[
             0.4541671099689253, 0.565024669218484, 0.9509265101929423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 382}], {
             RGBColor[
             0.2993497560176752, 0.42788733249033384`, 0.9405082360389113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 104}], {
             RGBColor[
             0.5530083397830977, 0.6474872459523848, 0.9582106177511736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 182}], {
             RGBColor[
             0.5386296319567697, 0.6350331319280882, 0.9572944192030721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 187}], {
             RGBColor[
             0.4479993590069344, 0.5497198626235376, 0.9517690279536841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 208}], {
             RGBColor[
             0.505874575696935, 0.6066623485128158, 0.9552072959823543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 225}], {
             RGBColor[
             0.5334065507765399, 0.6305091615294662, 0.9569616090888571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 261}], {
             RGBColor[
             0.527256261442529, 0.6251820900308762, 0.9565697180909813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 377}], {
             RGBColor[
             0.5179256293070509, 0.6171003654463321, 0.9559751784620627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 388}], {
             RGBColor[
             0.5541876200759575, 0.648508679269709, 0.958285760448638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 166}], {
             RGBColor[
             0.2327616747180571, 0.3619776564441989, 0.9365668050839291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 169}], {
             RGBColor[
             0.5970374338103346, 0.6732106714138691, 0.9654260599054645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 224}], {
             RGBColor[
             0.5246996331412912, 0.6159543271202969, 0.9584139379748042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 246}], {
             RGBColor[
             0.3682300526278914, 0.4908429446618587, 0.944784956694424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 276}], {
             RGBColor[
             0.3180972320535991, 0.4474553512046606, 0.9415808847840405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 326}], {
             RGBColor[
             0.2893272029389158, 0.4214316130659548, 0.9397881282349071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 363}], {
             RGBColor[
             0.26199908395672933`, 0.39270802731285714`, 0.9382318322872006]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 382}], {
             RGBColor[
             0.2638475917121842, 0.39465092616600117`, 0.9383371020692517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 383}], {
             RGBColor[
             0.3032957312360154, 0.43463503514153184`, 0.9406377462403973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 393}], {
             RGBColor[
             0.4080725247402592, 0.5231888584055931, 0.9479215020468938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 134}], {
             RGBColor[
             0.35754832514074986`, 0.48313544815262705`, 0.9440394017869447]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 143}], {
             RGBColor[
             0.5000019866572691, 0.5988633062377733, 0.9556035451815896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 151}], {
             RGBColor[
             0.3838827360190774, 0.5055033575810177, 0.945839431859945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 158}], {
             RGBColor[
             0.369887526838806, 0.4938230444771732, 0.9448256448080172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 163}], {
             RGBColor[
             0.29208455790040366`, 0.42432976795688054`, 0.9399451555208227]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.3711431632156278, 0.49491061359665695`, 0.9449056528476327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 186}], {
             RGBColor[
             0.34288460456930303`, 0.4704344704136655, 0.9431050424787512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 240}], {
             RGBColor[
             0.3239307254741068, 0.4540175729910694, 0.9418973180630624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 272}], {
             RGBColor[
             0.3464673027673044, 0.4735376235211271, 0.9433333288398722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 306}], {
             RGBColor[
             0.3484305132471051, 0.47523805776490263`, 0.9434584228756462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 308}], {
             RGBColor[
             0.27702567342993933`, 0.4085019255900012, 0.939087574327853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 342}], {
             RGBColor[
             0.47321456757586566`, 0.5779367708594555, 0.9529336255902192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 348}], {
             RGBColor[
             0.2825228259480346, 0.41427978142611954`, 0.93940062903145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 354}], {
             RGBColor[
             0.3194309970992818, 0.4501201344357201, 0.9416105993499722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 374}], {
             RGBColor[
             0.3846241857662598, 0.5061052998877109, 0.9458978015000631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 378}], {
             RGBColor[
             0.3341332547688869, 0.46285449107217536`, 0.9425474142079834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 144}], {
             RGBColor[
             0.4345809747212525, 0.5506021986143326, 0.9489761215154355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 169}], {
             RGBColor[
             0.6597644356217042, 0.730027863625674, 0.9693319364470201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[
             0.3897115643030433, 0.5119703023517098, 0.9460530541623526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 222}], {
             RGBColor[
             0.32955131398112086`, 0.45459684031368686`, 0.9424124984372025]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 223}], {
             RGBColor[
             0.3451291992397415, 0.4709701854154691, 0.943299635957265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 276}], {
             RGBColor[
             0.3808242338649686, 0.5042725434164654, 0.9454867613255962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 361}], {
             RGBColor[
             0.48139194747480385`, 0.5886054551059562, 0.9526612527648384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 382}], {
             RGBColor[
             0.3265745935235537, 0.451468118377806, 0.9422429786108073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 384}], {
             RGBColor[
             0.31870940313582824`, 0.44320130459843343`, 0.9417950676537329]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 393}], {
             RGBColor[
             0.4707995265516287, 0.580006050617398, 0.9518273785884497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 157}], {
             RGBColor[
             0.39395989669593906`, 0.5156499943430415, 0.9463237541457751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 167}], {
             RGBColor[
             0.3766412855231207, 0.5006494838038533, 0.9452202275560897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 174}], {
             RGBColor[
             0.3576023461899317, 0.48415891147835977`, 0.9440070831772518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 198}], {
             RGBColor[
             0.38989180040275173`, 0.5121264138023475, 0.9460645386472495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 203}], {
             RGBColor[
             0.3523048745359325, 0.4795705077903329, 0.9436695329678293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 206}], {
             RGBColor[
             0.3495622421136738, 0.4771949774348861, 0.9434947748550975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 211}], {
             RGBColor[
             0.4901409958324249, 0.5939770386883731, 0.953828369937135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 266}], {
             RGBColor[
             0.32726378059912475`, 0.4578811708242468, 0.9420739366051458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 341}], {
             RGBColor[
             0.38409515133579997`, 0.5071056477286073, 0.9456951812944788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 358}], {
             RGBColor[
             0.3705266171350753, 0.49535326537829777`, 0.9448306062933923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 115}], {
             RGBColor[
             0.3447814351634235, 0.4619509670837935, 0.9438360893924848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 123}], {
             RGBColor[
             0.4134108731973387, 0.5314986382885859, 0.9478391285261374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 161}], {
             RGBColor[
             0.4116249280256775, 0.5299517423451072, 0.9477253296790484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 193}], {
             RGBColor[
             0.38161674880815233`, 0.5006672172181803, 0.9459338060115889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 253}], {
             RGBColor[
             0.39514045276771914`, 0.5148814875320402, 0.9467039609455591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 283}], {
             RGBColor[
             0.5647968368114393, 0.6575665417878938, 0.9588820223942311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 332}], {
             RGBColor[
             0.3937974479630113, 0.5134699043308695, 0.9466274788087286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 334}], {
             RGBColor[
             0.4398917969087459, 0.5544350834374814, 0.9495264695688669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 356}], {
             RGBColor[
             0.4559558654918857, 0.5683489722406339, 0.9505500578140864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 364}], {
             RGBColor[
             0.3368857358942737, 0.4536520865356692, 0.943386440999747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 366}], {
             RGBColor[
             0.5706198776934386, 0.662159493299654, 0.9594323613951259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 380}], {
             RGBColor[
             0.3821934560236825, 0.5012733730670519, 0.9459666486343514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 389}], {
             RGBColor[
             0.3392283311468225, 0.4561143026752156, 0.9435198483338205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 108}], {
             RGBColor[
             0.27563673886155354`, 0.4044505870079427, 0.9391033633469204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 139}], {
             RGBColor[
             0.5420656378750714, 0.6343394939727897, 0.9590665636408242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 213}], {
             RGBColor[
             0.2622659636156463, 0.3903970544683796, 0.9383419174769554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 297}], {
             RGBColor[
             0.28409087054310783`, 0.41333641542816413`, 0.9395848136394178]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 333}], {
             RGBColor[
             0.34406339251805484`, 0.4724321502953778, 0.9431443930213066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 337}], {
             RGBColor[
             0.34705225097118975`, 0.47502094926308935`, 0.9433348404389965]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 345}], {
             RGBColor[
             0.27930426943917674`, 0.40830539417989387`, 0.9393122237876907]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 350}], {
             RGBColor[
             0.28121961595101913`, 0.4103185448038231, 0.9394212999380389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 378}], {
             RGBColor[
             0.35342957498877703`, 0.4805446667934984, 0.943741197886151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 122}], {
             RGBColor[
             0.4286677411806925, 0.5457121847687484, 0.9485353073054017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 295}], {
             RGBColor[
             0.4095775060024378, 0.5291771825604631, 0.9473188944006755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 145}], {
             RGBColor[
             0.6783489690510603, 0.7461450544999568, 0.9705068263455284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 170}], {
             RGBColor[
             0.5065763787934019, 0.6100764894344921, 0.9543606035948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 182}], {
             RGBColor[
             0.4306872706069922, 0.5474613996533089, 0.9486639899346458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 187}], {
             RGBColor[
             0.3400569976571569, 0.4621481303487582, 0.9431385986852578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 192}], {
             RGBColor[
             0.45204565063417806`, 0.5658059877335256, 0.9500677449214668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 208}], {
             RGBColor[
             0.3979322143471574, 0.5190906162380364, 0.946576866713928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 225}], {
             RGBColor[
             0.42546418942676234`, 0.5429374292546869, 0.9483311798204308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 235}], {
             RGBColor[
             0.47725787201657266`, 0.5862744048493834, 0.952052543344099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 261}], {
             RGBColor[
             0.41931390009275155`, 0.5376103577560969, 0.9479392888225551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 327}], {
             RGBColor[
             0.3508321916308309, 0.47347354240184647`, 0.9437522300415875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 335}], {
             RGBColor[
             0.4133102621313318, 0.5324103083055328, 0.9475567423204619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 349}], {
             RGBColor[
             0.4091439598564145, 0.5288016666794405, 0.9472912692236206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 351}], {
             RGBColor[
             0.371719117186075, 0.4954270254679766, 0.9449417095525213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 355}], {
             RGBColor[
             0.46679201453348573`, 0.5777777502631067, 0.9512286327053312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 199}], {
             RGBColor[
             0.2645613777083103, 0.3923541213597306, 0.9384893181551622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 215}], {
             RGBColor[
             0.42720444261928026`, 0.542832210959726, 0.9488876163083875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 259}], {
             RGBColor[
             0.35753817451232517`, 0.48410332919657934`, 0.9440029942146995]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 271}], {
             RGBColor[
             0.3525980493262679, 0.479824441058328, 0.9436882138062251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 287}], {
             RGBColor[
             0.3834953452619017, 0.5065861258545264, 0.9456569621818376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 303}], {
             RGBColor[
             0.4467795465868474, 0.5587241622089812, 0.950428640198683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 333}], {
             RGBColor[
             0.34652702254449963`, 0.4745660227986387, 0.9433013733480891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 337}], {
             RGBColor[
             0.3495158809976345, 0.47715482176635027`, 0.943491820765779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 345}], {
             RGBColor[
             0.28176789946562153`, 0.4104392666831548, 0.9394692041144732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 350}], {
             RGBColor[
             0.28368324597746386`, 0.41245241730708404`, 0.9395782802648215]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 353}], {
             RGBColor[
             0.29509680552501233`, 0.42444879205302943`, 0.9402282655962062]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 400}], {
             RGBColor[
             0.30835368006566827`, 0.4383826077296517, 0.940983224989508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 197}], {
             RGBColor[
             0.3906297248857402, 0.5125981393853478, 0.9461578192640299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 217}], {
             RGBColor[
             0.2661742005885068, 0.3958916989255662, 0.9385137067994039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 231}], {
             RGBColor[
             0.38978028028100054`, 0.5119085219881768, 0.9460909478731268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 254}], {
             RGBColor[
             0.28069296033259444`, 0.4111518359591381, 0.9393405286882495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 314}], {
             RGBColor[
             0.30262690151301574`, 0.4342057988319543, 0.9405896341901163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 369}], {
             RGBColor[
             0.3138735400757541, 0.4460267290394626, 0.9412301136183535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 124}], {
             RGBColor[
             0.5477966844855964, 0.6437650522816397, 0.9575437081295308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 150}], {
             RGBColor[
             0.4823338199542924, 0.589798024689399, 0.9526171662067731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 152}], {
             RGBColor[
             0.3989267414421472, 0.512701860345183, 0.9474802383337433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.4352493604431399, 0.5490158323945837, 0.9496169860818751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.4929853852277991, 0.5990238751660735, 0.9532958745271916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 160}], {
             RGBColor[
             0.7128033543830368, 0.7745406259026908, 0.9729272259926787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 167}], {
             RGBColor[
             0.4756667740549807, 0.5840233646268854, 0.9521923479375061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.36653919732097784`, 0.4786604979849328, 0.9456358156091205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 181}], {
             RGBColor[
             0.4594733191166993, 0.5699974078660568, 0.9511605153081487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 211}], {
             RGBColor[
             0.5891664843642849, 0.6773509195114051, 0.9608004903185514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 238}], {
             RGBColor[
             0.4829792422301784, 0.5903570570249046, 0.9526582919434678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 245}], {
             RGBColor[
             0.38957412101857214`, 0.5028716632896213, 0.9469476204365828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 386}], {
             RGBColor[
             0.4526403230444982, 0.5640790101046845, 0.9507251228406093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 297}], {
             RGBColor[
             0.22295252582755387`, 0.35166761902431903`, 0.9360081885659504]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 325}], {
             RGBColor[
             0.24676938135157944`, 0.376700644255928, 0.9373645232541634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 376}], {
             RGBColor[
             0.2143778022282936, 0.3426550408526195, 0.9355198707421393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 378}], {
             RGBColor[
             0.29229123027322307`, 0.41887587038965335`, 0.9401645728126835]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 397}], {
             RGBColor[
             0.26757274035215856`, 0.3974659568074547, 0.9385895324926157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 114}], {
             RGBColor[
             0.30266870660877715`, 0.43333855755343464`, 0.9406253777315188]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 132}], {
             RGBColor[
             0.3402735242572976, 0.46914955689222715`, 0.94290290596698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 180}], {
             RGBColor[
             0.4014941522776533, 0.5216859629140855, 0.9469391703370696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 232}], {
             RGBColor[
             0.337799682920818, 0.46700683986544944`, 0.9427452749845515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 249}], {
             RGBColor[
             0.3807176226038627, 0.5041802021005333, 0.9454799681503112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 370}], {
             RGBColor[
             0.376440418950949, 0.5004755032748858, 0.9452074285157301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 111}], {
             RGBColor[
             0.27939576293564083`, 0.4108493381194622, 0.9392278090462982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 117}], {
             RGBColor[
             0.29821461137068084`, 0.4271492787710693, 0.9404269294277248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 202}], {
             RGBColor[
             0.23645806560269045`, 0.3658627976286669, 0.9367773090764888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 212}], {
             RGBColor[
             0.23241510599416104`, 0.3616133907416579, 0.9365470685078058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 239}], {
             RGBColor[
             0.3290148182199084, 0.453826869880462, 0.942389491372604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 247}], {
             RGBColor[
             0.37378391412344647`, 0.4913611583833361, 0.9455854318229407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 269}], {
             RGBColor[
             0.21691916616932566`, 0.3453261754864245, 0.93566459765897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 287}], {
             RGBColor[
             0.336889807156917, 0.4606477894892463, 0.9428912787040908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 289}], {
             RGBColor[
             0.28195401985612234`, 0.41306517168225176`, 0.9393908189150936]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 292}], {
             RGBColor[
             0.2563176930625193, 0.3867365252620544, 0.93790828548064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 303}], {
             RGBColor[
             0.4001740084818627, 0.5127858258437011, 0.9476629567209361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 309}], {
             RGBColor[
             0.27250108444307397`, 0.40374629568929477`, 0.9388299056785805]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 362}], {
             RGBColor[
             0.26080100443895016`, 0.3914487697770424, 0.938163603431063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 385}], {
             RGBColor[
             0.5056557407647895, 0.5965753358446335, 0.9572285150834253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 400}], {
             RGBColor[
             0.2617481419606836, 0.39244427136437154`, 0.9382175415117613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 199}], {
             RGBColor[
             0.2488603351189388, 0.37875466742616337`, 0.9374888616052544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 222}], {
             RGBColor[
             0.2810467213422021, 0.41258460008156683`, 0.9393218286851778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 223}], {
             RGBColor[
             0.29662460660082274`, 0.4289579451833491, 0.9402089662052402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 247}], {
             RGBColor[
             0.40468840963905967`, 0.523700040815049, 0.9473506587507796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 271}], {
             RGBColor[
             0.33689700673689643`, 0.4662249871247607, 0.9426877572563173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 287}], {
             RGBColor[
             0.3677943026725302, 0.49298667192095913`, 0.9446565056319297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 292}], {
             RGBColor[
             0.28722218857813253`, 0.4190754076937673, 0.939673512408479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 309}], {
             RGBColor[
             0.3034055799586872, 0.43608517812100767`, 0.9405951326064195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 319}], {
             RGBColor[
             0.45618525671591187`, 0.565507501178561, 0.9514046791918358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 362}], {
             RGBColor[
             0.29170549995456335`, 0.42378765220875525`, 0.9399288303589018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 385}], {
             RGBColor[
             0.5365602362804027, 0.6289142182763464, 0.9589937420112642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[
             0.2926526374762968, 0.42478315379608445`, 0.9399827684396002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 177}], {
             RGBColor[
             0.3342624596446624, 0.4574870207323496, 0.9427562740122359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 219}], {
             RGBColor[
             0.35374410605143874`, 0.477963466313596, 0.9438657249545888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 248}], {
             RGBColor[
             0.40546838106592165`, 0.5256180650710772, 0.9470570645932772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 251}], {
             RGBColor[
             0.3058000939286941, 0.4275712697466507, 0.9411353843910082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 260}], {
             RGBColor[
             0.7010119323058739, 0.7627374045218481, 0.9400849184746347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 162}], {
             RGBColor[
             0.6420169601298187, 0.7157049551075791, 0.9677181417999113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 183}], {
             RGBColor[
             0.6218524384801635, 0.6982394599529747, 0.9664332763111816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 270}], {
             RGBColor[
             0.5514713692523893, 0.6291874234316132, 0.9622449259679009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 357}], {
             RGBColor[
             0.5581024680331361, 0.636157128686124, 0.9626225572336329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 368}], {
             RGBColor[
             0.5920691360217396, 0.6718582503532834, 0.9645569087264017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 132}], {
             RGBColor[
             0.3113118024132442, 0.44082477272463766`, 0.9411761081533899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 155}], {
             RGBColor[
             0.24376546266415636`, 0.3735433352560011, 0.9371934545288141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 180}], {
             RGBColor[
             0.37253243043359985`, 0.49336117874649604`, 0.9452123725234796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 249}], {
             RGBColor[
             0.3517559007598093, 0.4758554179329437, 0.9437531703367211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 268}], {
             RGBColor[
             0.22711053213546362`, 0.3560379472867588, 0.9362449808739667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 279}], {
             RGBColor[
             0.34466578127353387`, 0.46971431279369896`, 0.9433013941926022]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 299}], {
             RGBColor[
             0.35947251714632145`, 0.4825391631985238, 0.9442448663093337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 300}], {
             RGBColor[
             0.509639829496862, 0.6030900400732591, 0.9570869771892254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 370}], {
             RGBColor[
             0.34747869710689555`, 0.4721507191072962, 0.9434806307021402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 123}], {
             RGBColor[
             0.2680887459019765, 0.39652242859763337`, 0.9386733236919114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 161}], {
             RGBColor[
             0.2663028007303153, 0.39497553265415475`, 0.9385595248448224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 193}], {
             RGBColor[
             0.2362946215127901, 0.3656910075272278, 0.9367680011773627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 195}], {
             RGBColor[
             0.3821293537872523, 0.49227168992717807`, 0.9467762543564864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 214}], {
             RGBColor[
             0.2765188319022358, 0.40382414538261574`, 0.9392104813174155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 253}], {
             RGBColor[
             0.24981832547235688`, 0.37990527784108763`, 0.937538156111333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 257}], {
             RGBColor[
             0.19974017072672232`, 0.3272699620650275, 0.9346862792825601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 283}], {
             RGBColor[
             0.4194747095160771, 0.5225903320969413, 0.9497162175600049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 312}], {
             RGBColor[
             0.1915069403171234, 0.3186163148875808, 0.9342174089907063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 332}], {
             RGBColor[
             0.24847532066764905`, 0.37849369463991694`, 0.9374616739745024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 334}], {
             RGBColor[
             0.2945696696133837, 0.41945887374652885`, 0.9403606647346407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 356}], {
             RGBColor[
             0.3106337381965235, 0.43337276254968127`, 0.9413842529798604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 360}], {
             RGBColor[
             0.27459943446702406`, 0.40216165979595553`, 0.9390881790101002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 364}], {
             RGBColor[
             0.19156360859891144`, 0.31867587684471665`, 0.9342206361655209]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 366}], {
             RGBColor[
             0.42529775039807627`, 0.5271832836087015, 0.9502665565608996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 380}], {
             RGBColor[
             0.23687132872832026`, 0.36629716337609936`, 0.9368008438001254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 389}], {
             RGBColor[
             0.19390620385146023`, 0.3211380929842631, 0.9343540434995944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 141}], {
             RGBColor[
             0.3467881762535359, 0.47124350813501426`, 0.9434479495938517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 179}], {
             RGBColor[
             0.23092180319299346`, 0.3600438348167646, 0.9364620271224228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 209}], {
             RGBColor[
             0.429591375558747, 0.5392843042852522, 0.9497406627724361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 286}], {
             RGBColor[
             0.3146202997316797, 0.4433813102962671, 0.9413982409468153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 290}], {
             RGBColor[
             0.4359338972501298, 0.5444334491216628, 0.9502399693134043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 304}], {
             RGBColor[
             0.2246453121661772, 0.353446844795065, 0.936104590243682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 338}], {
             RGBColor[
             0.3494540316493808, 0.473552538089107, 0.9436178155423516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 239}], {
             RGBColor[
             0.37873816217056155`, 0.502465692963782, 0.9453538386818694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 269}], {
             RGBColor[
             0.26664251011997886`, 0.39396499856974454`, 0.9386289449682355]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 309}], {
             RGBColor[
             0.32222442839372717`, 0.4523851187726147, 0.9417942529878459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 323}], {
             RGBColor[
             0.3050170221984505, 0.43429904384881224`, 0.9408143166611012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 362}], {
             RGBColor[
             0.3105243483896033, 0.44008759286036236`, 0.9411279507403283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 365}], {
             RGBColor[
             0.6490142207902415, 0.7190431243712834, 0.9563796222005068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 377}], {
             RGBColor[
             0.36141925640128025`, 0.4874649272599446, 0.9442502933207577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 385}], {
             RGBColor[
             0.5553790847154427, 0.6452141589279534, 0.9601928623926907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 388}], {
             RGBColor[
             0.3976812471701869, 0.5188732410833217, 0.9465608753073331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 395}], {
             RGBColor[
             0.34111244532036944`, 0.4698761881516613, 0.9429563612752901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 124}], {
             RGBColor[
             0.37745335693175686`, 0.48864923133155147`, 0.9463923291066454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[
             0.31206224282768075`, 0.4347443503530942, 0.9414703590576641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 150}], {
             RGBColor[
             0.3119904924004529, 0.43468220373931077`, 0.9414657871838876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 179}], {
             RGBColor[
             0.19619586976713832`, 0.3235446770348446, 0.934484436586235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 196}], {
             RGBColor[
             0.35188440879713667`, 0.46789120736787987`, 0.944379447847345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 206}], {
             RGBColor[
             0.27824440309169435`, 0.4054530373078299, 0.9393155162136285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 209}], {
             RGBColor[
             0.3948654421328919, 0.5027851465033322, 0.9477630722362484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 286}], {
             RGBColor[
             0.27989436630582454`, 0.406882152514347, 0.9394206504106277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 386}], {
             RGBColor[
             0.2822969954906587, 0.4089631891545963, 0.9395737438177238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 128}], {
             RGBColor[
             0.30845432014459767`, 0.4304265337148909, 0.9412841402277574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 130}], {
             RGBColor[
             0.22419542798337366`, 0.35297398799463386`, 0.9360789700050153]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 135}], {
             RGBColor[
             0.25573280012230915`, 0.38476180293222895`, 0.9379247715917469]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 146}], {
             RGBColor[
             0.42999732546193814`, 0.5293098550655753, 0.9509795264081933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 151}], {
             RGBColor[
             0.32879673229021644`, 0.44760447500762235`, 0.942702365440026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 213}], {
             RGBColor[
             0.1878836396668952, 0.3148079961736612, 0.9340110673788686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 227}], {
             RGBColor[
             0.28619922485555366`, 0.41115028874913406`, 0.9398660652353477]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 243}], {
             RGBColor[
             0.23779007658236562`, 0.3672628256226794, 0.9368531651312475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 267}], {
             RGBColor[
             0.3747082062858538, 0.4848774778856142, 0.9463166848522332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 306}], {
             RGBColor[
             0.29334450951824415`, 0.4173391751915072, 0.9403213564557271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 311}], {
             RGBColor[
             0.19623265350017588`, 0.3235833390704904, 0.9344865313654149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 344}], {
             RGBColor[
             0.1877154237331144, 0.31463119056175126`, 0.9340014877302931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 346}], {
             RGBColor[
             0.4722421288630979, 0.5623118165549588, 0.9551900936110879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 350}], {
             RGBColor[
             0.20683729200226803`, 0.3347294865091047, 0.9350904498399524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 354}], {
             RGBColor[
             0.26434499337042083`, 0.3922212518623247, 0.9384735329300531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 140}], {
             RGBColor[
             0.38910653680320795`, 0.5114462579409187, 0.9460145023450679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 147}], {
             RGBColor[
             0.4807886032329407, 0.5888789216881372, 0.9524028563766024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 193}], {
             RGBColor[
             0.354275356300057, 0.4779842915114757, 0.9439156613005008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 195}], {
             RGBColor[
             0.5001100885745192, 0.604564973911426, 0.9539239144796243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 241}], {
             RGBColor[
             0.384564467927778, 0.5075121461720408, 0.9457250857327193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 242}], {
             RGBColor[
             0.48465882636903135`, 0.5920209431815809, 0.95270753451897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 255}], {
             RGBColor[
             0.418986883819865, 0.5373271126968383, 0.9479184516348158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 263}], {
             RGBColor[
             0.42129425182405256`, 0.5393256388903777, 0.9480654750837172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 312}], {
             RGBColor[
             0.30948767510439035`, 0.4309095988718288, 0.9413650691138442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 331}], {
             RGBColor[
             0.4244498207646123, 0.542058834103184, 0.9482665451462496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 356}], {
             RGBColor[
             0.4286144729837904, 0.5456660465339291, 0.9485319131029983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 359}], {
             RGBColor[
             0.38928640482763766`, 0.5116020505832499, 0.9460259633765334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 360}], {
             RGBColor[
             0.392580169254291, 0.5144549437802034, 0.9462358391332383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 380}], {
             RGBColor[
             0.3548520635155872, 0.4785904473603473, 0.9439485039232633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 389}], {
             RGBColor[
             0.3118869386387272, 0.433431376968511, 0.9415017036227324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[
             0.3671056308126497, 0.4923901789695847, 0.9446126240699868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 202}], {
             RGBColor[
             0.3242404077697107, 0.4474664120661336, 0.9421667420978503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 234}], {
             RGBColor[
             0.5442164551209335, 0.6397266405380169, 0.9577119962468629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 289}], {
             RGBColor[
             0.3697363620231426, 0.49466878611971843`, 0.9447802519364552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 298}], {
             RGBColor[
             0.4645973225999761, 0.5754255289988437, 0.9512134814873486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 173}], {
             RGBColor[
             0.3302273145917095, 0.4521933774473511, 0.9425650138206703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 338}], {
             RGBColor[
             0.43476713737598727`, 0.5509951751885462, 0.9489239554374816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 161}], {
             RGBColor[
             0.3349322387642305, 0.46452320385894713`, 0.942562563978475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 196}], {
             RGBColor[
             0.41978762202476044`, 0.5366755702559478, 0.9483411295526327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 214}], {
             RGBColor[
             0.345148269936151, 0.4733718165874081, 0.9432135204510681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 253}], {
             RGBColor[
             0.31844776350627213`, 0.44945294904588, 0.9415411952449857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 283}], {
             RGBColor[
             0.4881041475499924, 0.5921380033017336, 0.9537192566936576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 332}], {
             RGBColor[
             0.3171047587015643, 0.4480413658447093, 0.941464713108155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 334}], {
             RGBColor[
             0.3631991076472989, 0.48900654495132123`, 0.9443637038682935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 356}], {
             RGBColor[
             0.3792631762304387, 0.5029204337544737, 0.945387292113513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 364}], {
             RGBColor[
             0.26019304663282666`, 0.38822354804950904`, 0.9382236752991735]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 366}], {
             RGBColor[
             0.4939271884319915, 0.5967309548134938, 0.9542695956945524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 389}], {
             RGBColor[
             0.2625356418853755, 0.39068576418905543`, 0.938357082633247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 150}], {
             RGBColor[
             0.4885320918515657, 0.5948300610445724, 0.9531051168755444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 152}], {
             RGBColor[
             0.40512501333942047`, 0.5177338967003564, 0.9479681890025148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 156}], {
             RGBColor[
             0.4414476323404132, 0.5540478687497571, 0.9501049367506466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 157}], {
             RGBColor[
             0.4991836571250724, 0.6040559115212468, 0.9537838251959629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 160}], {
             RGBColor[
             0.7190016262803101, 0.7795726622578643, 0.97341517666145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 167}], {
             RGBColor[
             0.481865045952254, 0.5890554009820588, 0.9526802986062775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 179}], {
             RGBColor[
             0.3727374692182511, 0.4836925343401062, 0.946123766277892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 181}], {
             RGBColor[
             0.4656715910139726, 0.57502944422123, 0.9516484659769202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 238}], {
             RGBColor[
             0.4891775141274517, 0.5953890933800781, 0.9531462426122393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 245}], {
             RGBColor[
             0.39577239291584543`, 0.5079036996447946, 0.9474355711053541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 386}], {
             RGBColor[
             0.4588385949417715, 0.5691110464598579, 0.9512130735093807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 184}], {
             RGBColor[
             0.28035389851578135`, 0.40946591053884135`, 0.939369900956122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 185}], {
             RGBColor[
             0.4037566614763376, 0.5236456346649672, 0.9470833354225514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 190}], {
             RGBColor[
             0.332527877574078, 0.46244066704274417`, 0.9424093602095316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 226}], {
             RGBColor[
             0.48644500149522296`, 0.5907757541595655, 0.9535928644462079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 252}], {
             RGBColor[
             0.32539432365047793`, 0.4562619411769671, 0.9419548164614739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 274}], {
             RGBColor[
             0.3861093725082252, 0.5088502648704623, 0.9458235256864799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 288}], {
             RGBColor[
             0.35412433607264493`, 0.4811464339246373, 0.9437854674480619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 318}], {
             RGBColor[
             0.4267414354219004, 0.5423057096062414, 0.9488927810235473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 176}], {
             RGBColor[
             0.3855469364152011, 0.4977223908274119, 0.9468016988557721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 205}], {
             RGBColor[
             0.21751415562183513`, 0.3459515471255221, 0.9356984814280824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 298}], {
             RGBColor[
             0.36348607437356506`, 0.4798123891915023, 0.9450649869842542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 320}], {
             RGBColor[
             0.5934029680323232, 0.6619442594852092, 0.940060545984561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 347}], {
             RGBColor[
             0.20578774166918312`, 0.33362634256369783`, 0.9350306795011537]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 373}], {
             RGBColor[
             0.2657499406441851, 0.3965653158380459, 0.9384485539424963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 137}], {
             RGBColor[
             0.6916628484086904, 0.7548641435232208, 0.942764855624637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 138}], {
             RGBColor[
             0.5773563512856834, 0.6445112394367143, 0.9358967925809056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 193}], {
             RGBColor[
             0.6209086379224118, 0.6902874540663781, 0.9383770308750331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 210}], {
             RGBColor[
             0.8064385278962758, 0.8490664095126552, 0.9515294062631425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 242}], {
             RGBColor[
             0.7512921079913861, 0.8043241057364834, 0.9471689040935023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 255}], {
             RGBColor[
             0.6856201654422198, 0.7496302752517408, 0.9423798212093482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 258}], {
             RGBColor[
             0.6139883389436491, 0.6830137810674008, 0.9379829300858575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 264}], {
             RGBColor[
             0.6034596291745496, 0.6719474395413216, 0.9373833356403376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 312}], {
             RGBColor[
             0.5761209567267451, 0.6432127614267311, 0.9358264386883766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 328}], {
             RGBColor[
             0.66685948103351, 0.7333807133563318, 0.941184406988247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 331}], {
             RGBColor[
             0.6910831023869671, 0.7543619966580863, 0.942727914720782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 380}], {
             RGBColor[
             0.6214853451379421, 0.6908936099152496, 0.9384098734977957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 394}], {
             RGBColor[
             0.5975159050691821, 0.665700208652706, 0.9370448493454887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 130}], {
             RGBColor[
             0.3446393124483661, 0.46845925488717377`, 0.9433448220085581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 135}], {
             RGBColor[
             0.3761766845873016, 0.500247069824769, 0.9451906235952897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 139}], {
             RGBColor[
             0.5881271983913127, 0.6742357025706112, 0.9620015655462805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 151}], {
             RGBColor[
             0.4492406167552089, 0.5630897419001623, 0.9499682174435687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 213}], {
             RGBColor[
             0.30832752413188763`, 0.4302932630662011, 0.9412769193824115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 215}], {
             RGBColor[
             0.4708023731090768, 0.5805945470542866, 0.9516656378870612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 224}], {
             RGBColor[
             0.5982210153929101, 0.6821210691281095, 0.9630076228929167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 227}], {
             RGBColor[
             0.40664310932054604`, 0.526635555641674, 0.9471319172388905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 243}], {
             RGBColor[
             0.35823396104735805`, 0.48274809251521933`, 0.9441190171347904]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 259}], {
             RGBColor[
             0.4011361050021217, 0.52186566529114, 0.9467810157933731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 306}], {
             RGBColor[
             0.4137883939832366, 0.5328244420840471, 0.94758720845927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 350}], {
             RGBColor[
             0.3272811764672604, 0.45021475340164463`, 0.9423563018434952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 383}], {
             RGBColor[
             0.37681711348763414`, 0.5008017771493445, 0.9452314311585099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 131}], {
             RGBColor[
             0.36421900713817446`, 0.4898899306286788, 0.9444286909619903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 253}], {
             RGBColor[
             0.3426309395287469, 0.4703992006347791, 0.9430821258367947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 271}], {
             RGBColor[
             0.37428914550169, 0.4986121783392851, 0.9450703512738399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 287}], {
             RGBColor[
             0.40518644143732385`, 0.5253738631354836, 0.9470390996494523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 303}], {
             RGBColor[
             0.4684706427622695, 0.5775118994899384, 0.9518107776662976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 333}], {
             RGBColor[
             0.3682181187199217, 0.4933537600795958, 0.9446835108157037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 337}], {
             RGBColor[
             0.3712069771730566, 0.4959425590473074, 0.9448739582333937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 353}], {
             RGBColor[
             0.31678790170043447`, 0.4432365293339866, 0.9416104030638208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 364}], {
             RGBColor[
             0.28437622265530144`, 0.4091697996384081, 0.9397646058909828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 391}], {
             RGBColor[
             0.41674660510122874`, 0.5353866958704381, 0.947775703055865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 135}], {
             RGBColor[
             0.2919177924260775, 0.42279452410451185`, 0.9399854533725476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 146}], {
             RGBColor[
             0.4661823177657065, 0.5673425762378581, 0.9530402081889939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 151}], {
             RGBColor[
             0.3649817245939848, 0.4856371961799052, 0.9447630472208266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 158}], {
             RGBColor[
             0.3509865154137135, 0.47395688307606065`, 0.9437492601688988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 227}], {
             RGBColor[
             0.3223842171593221, 0.44918300992141696`, 0.9419267470161483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 243}], {
             RGBColor[
             0.273975068886134, 0.40529554679496227`, 0.9389138469120482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 267}], {
             RGBColor[
             0.41089319858962225`, 0.522910199057897, 0.9483773666330338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 275}], {
             RGBColor[
             0.31102854565758864`, 0.43934729801926053`, 0.9412031736694839]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 306}], {
             RGBColor[
             0.32952950182201257`, 0.4553718963637901, 0.9423820382365278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 311}], {
             RGBColor[
             0.2324176458039443, 0.3616160602427733, 0.9365472131462156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 317}], {
             RGBColor[
             0.25443584385358486`, 0.384758582427333, 0.9378011169521376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 344}], {
             RGBColor[
             0.22390041603688282`, 0.35266391173403416`, 0.9360621695110938]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 346}], {
             RGBColor[
             0.5084271211668663, 0.6003445377272416, 0.9572507753918885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 354}], {
             RGBColor[
             0.30052998567418926`, 0.43025397303460755`, 0.9405342147108537]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 142}], {
             RGBColor[
             0.623411736869345, 0.6988418624382754, 0.9668770633444985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 201}], {
             RGBColor[
             0.3136205768786666, 0.44376579153935247`, 0.9412887565534724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 273}], {
             RGBColor[
             0.3141686682300903, 0.4443418703006976, 0.9413199695451075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 281}], {
             RGBColor[
             0.42468801711280485`, 0.5408340955471888, 0.9486771268103829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 293}], {
             RGBColor[
             0.29050392555664084`, 0.4194687253195559, 0.939972297458704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 303}], {
             RGBColor[
             0.4476051139196027, 0.5594392271383933, 0.9504812446191055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 391}], {
             RGBColor[
             0.39588107625856195`, 0.5173140235188929, 0.946446170008673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 394}], {
             RGBColor[
             0.2848489738732835, 0.41352501255570207`, 0.9396502563260882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 149}], {
             RGBColor[
             0.29942157543788966`, 0.4283273902896075, 0.9404989773171579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 155}], {
             RGBColor[
             0.28137028031267686`, 0.40935433459479365`, 0.9394709827642751]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 180}], {
             RGBColor[
             0.4101372480821203, 0.5291721780852886, 0.9474899007589408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 249}], {
             RGBColor[
             0.38936071840832975`, 0.5116664172717362, 0.9460306985721822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 268}], {
             RGBColor[
             0.26471534978398414`, 0.39184894662555136`, 0.9385225091094278]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 279}], {
             RGBColor[
             0.3822705989220544, 0.5055253121324915, 0.9455789224280633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 299}], {
             RGBColor[
             0.397077334794842, 0.5183501625373164, 0.9465223945447949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 300}], {
             RGBColor[
             0.5472446471453826, 0.6389010394120516, 0.9593645054246865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 370}], {
             RGBColor[
             0.385083514755416, 0.5079617184460887, 0.9457581589376013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 178}], {
             RGBColor[
             0.28212916900300133`, 0.4138660230175978, 0.9393782108507938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 200}], {
             RGBColor[
             0.29979142109292956`, 0.4322998694887824, 0.9403888209116105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 278}], {
             RGBColor[
             0.3276123003355468, 0.4563969167706887, 0.9421615427359125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 296}], {
             RGBColor[
             0.5532215247858738, 0.6392575321605178, 0.9610949856133341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 320}], {
             RGBColor[
             0.627200006539014, 0.6974670898117482, 0.9419852373292792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 330}], {
             RGBColor[
             0.2534007116162719, 0.3836705928147426, 0.9377421677025636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 347}], {
             RGBColor[
             0.2395847801758741, 0.36914917289023685`, 0.9369553708458719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 367}], {
             RGBColor[
             0.3399560673020606, 0.467088467301316, 0.9429480766518542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 398}], {
             RGBColor[
             0.3436871423874652, 0.47032013701100694`, 0.943185817457036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 163}], {
             RGBColor[
             0.35145043990382635`, 0.4767261841403658, 0.9436921362437147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 171}], {
             RGBColor[
             0.43050904521905053`, 0.5473070297801422, 0.9486526335705247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 240}], {
             RGBColor[
             0.38329660747752947`, 0.5064139891745547, 0.9456442987859544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 272}], {
             RGBColor[
             0.40583318477072716`, 0.5259340397046124, 0.9470803095627641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 342}], {
             RGBColor[
             0.5325804495792884, 0.6303331870429407, 0.9566806063131112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 374}], {
             RGBColor[
             0.44399006776968253`, 0.5585017160711961, 0.949644782222955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 213}], {
             RGBColor[
             0.25560600410959905`, 0.38462853228353916`, 0.9379175507464009]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 215}], {
             RGBColor[
             0.4180808530867883, 0.5349298162716247, 0.9483062692510507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 224}], {
             RGBColor[
             0.5454994953706215, 0.6364563383454476, 0.9596482542569063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 227}], {
             RGBColor[
             0.3539215892982575, 0.4809708248590121, 0.9437725486028798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 243}], {
             RGBColor[
             0.30551244102506947`, 0.43708336173255746`, 0.9407596484987798]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 259}], {
             RGBColor[
             0.34841458497983313`, 0.476200934508478, 0.9434216471573627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 350}], {
             RGBColor[
             0.2745596564449719, 0.40455002261898276`, 0.9389969332074846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 363}], {
             RGBColor[
             0.28279894618605955`, 0.4132100385380079, 0.9394661485693026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 383}], {
             RGBColor[
             0.3240955934653456, 0.4551370463666826, 0.9418720625224992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 393}], {
             RGBColor[
             0.4288723869695894, 0.5436908696307439, 0.9491558183289959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 149}], {
             RGBColor[
             0.22630339658025977`, 0.35518959664288957`, 0.9361990156981479]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 155}], {
             RGBColor[
             0.20825210145504697`, 0.33621654094807574`, 0.9351710211452651]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 268}], {
             RGBColor[
             0.19159717092635425`, 0.31871115297883346`, 0.9342225474904178]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 279}], {
             RGBColor[
             0.30915242006442445`, 0.4323875184857736, 0.9412789608090533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 299}], {
             RGBColor[
             0.3239591559372121, 0.44521236889059845`, 0.9422224329257848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 300}], {
             RGBColor[
             0.4741264682877527, 0.5657632457653337, 0.9550645438056764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 371}], {
             RGBColor[
             0.19874484095575437`, 0.3262238073681878, 0.9346295967245619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 138}], {
             RGBColor[
             0.30033185900706916`, 0.4232077324887935, 0.9407733042519433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 164}], {
             RGBColor[
             0.41513146695621006`, 0.5339877443884264, 0.947672787881475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 210}], {
             RGBColor[
             0.5294140356176614, 0.6277629025647344, 0.9564059179341802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 230}], {
             RGBColor[
             0.3622375618453535, 0.48817370230637336`, 0.9443024350200551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 242}], {
             RGBColor[
             0.4742676157127719, 0.5830205987885625, 0.9520454157645399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 258}], {
             RGBColor[
             0.33696384666503476`, 0.46171027411948007`, 0.9428594417568952]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 264}], {
             RGBColor[
             0.3264351368959353, 0.4506439325934008, 0.9422598473113752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 328}], {
             RGBColor[
             0.3898349887548957, 0.5120772064084109, 0.9460609186592847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 394}], {
             RGBColor[
             0.32049141279056775`, 0.4443967017047852, 0.9419213610165263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 149}], {
             RGBColor[
             0.21797594634903833`, 0.3464369184590359, 0.9357247797268384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 164}], {
             RGBColor[
             0.30082496983320306`, 0.42363484030191995`, 0.9408047248377438]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 210}], {
             RGBColor[
             0.4151075384946544, 0.517409998478228, 0.9495378548904488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 230}], {
             RGBColor[
             0.24793106472234647`, 0.3778207982198669, 0.9374343719763238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 242}], {
             RGBColor[
             0.3599611185897649, 0.47266769470205605`, 0.9451773527208086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 258}], {
             RGBColor[
             0.22265734954202776`, 0.3513573700329736, 0.9359913787131638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 264}], {
             RGBColor[
             0.21212863977292828`, 0.34029102850689436`, 0.9353917842676439]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 281}], {
             RGBColor[
             0.34602395890708204`, 0.4613528806097655, 0.9440801684570896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 328}], {
             RGBColor[
             0.27552849163188864`, 0.40172430232190454`, 0.9391928556155533]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 394}], {
             RGBColor[
             0.20618491566756073`, 0.33404379761827874`, 0.935053297972795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 186}], {
             RGBColor[
             0.5674714790871571, 0.6563447566959904, 0.9606854013773551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 213}], {
             RGBColor[
             0.4675565179136102, 0.5586171650293814, 0.9547284926973917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 215}], {
             RGBColor[
             0.6300313668907994, 0.7089184490174669, 0.9651172112020414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 306}], {
             RGBColor[
             0.5730173877649591, 0.6611483440472274, 0.9610387817742501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 308}], {
             RGBColor[
             0.5016125479477934, 0.5944122118723261, 0.9566679332264569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 345}], {
             RGBColor[
             0.4845948237371407, 0.5765255047408957, 0.9556987990081272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 350}], {
             RGBColor[
             0.486510170248983, 0.578538655364825, 0.9558078751584753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 378}], {
             RGBColor[
             0.558720129286741, 0.6487647773545002, 0.9601277731065874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 147}], {
             RGBColor[
             0.43447436259355354`, 0.548763854267719, 0.9494517539171357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 193}], {
             RGBColor[
             0.30796111566066986`, 0.43786922409105755`, 0.940964558841034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 195}], {
             RGBColor[
             0.45379584793513206`, 0.5644499064910078, 0.9509728120201575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 241}], {
             RGBColor[
             0.3382502272883908, 0.4673970787516226, 0.9427739832732525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 242}], {
             RGBColor[
             0.4383445857296442, 0.5519058757611628, 0.9497564320595031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 255}], {
             RGBColor[
             0.3726726431804778, 0.49721204527642016`, 0.944967349175349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 263}], {
             RGBColor[
             0.3749800111846654, 0.4992105714699595, 0.9451143726242505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 312}], {
             RGBColor[
             0.2631734344650032, 0.3907945314514106, 0.9384139666543775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 331}], {
             RGBColor[
             0.37813558012522513`, 0.5019437666827657, 0.9453154426867829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 356}], {
             RGBColor[
             0.38230023234440325`, 0.505550979113511, 0.9455808106435315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 359}], {
             RGBColor[
             0.3429721641882505, 0.4714869831628317, 0.9430748609170667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 360}], {
             RGBColor[
             0.34626592861490385`, 0.47433987635978525`, 0.9432847366737716]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 380}], {
             RGBColor[
             0.3085378228762, 0.43847537993992913`, 0.9409974014637965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 389}], {
             RGBColor[
             0.26557269799934, 0.3933163095480928, 0.9385506011632656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 179}], {
             RGBColor[
             0.30734635511417496`, 0.4297876533616489, 0.9412017962289105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 196}], {
             RGBColor[
             0.4630348941441733, 0.5741341836946843, 0.9510968074900205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 209}], {
             RGBColor[
             0.5060159274799285, 0.6090281228301364, 0.954480431878924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 286}], {
             RGBColor[
             0.39104485165286124`, 0.5131251288411514, 0.9461380100533032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 290}], {
             RGBColor[
             0.5123584491713113, 0.6141772676665471, 0.9549797384198921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 304}], {
             RGBColor[
             0.3010698640873587, 0.42319066333994926`, 0.9408443593501699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 386}], {
             RGBColor[
             0.3934474808376954, 0.5152061654814006, 0.9462911034603994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.7124109341421481, 0.7740812147314388, 0.9730584222302695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 201}], {
             RGBColor[
             0.593678835452504, 0.6707903957004941, 0.9650666619831727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 273}], {
             RGBColor[
             0.5942269268039277, 0.6713664744618393, 0.9650978749748077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 281}], {
             RGBColor[
             0.7047462756866423, 0.7678586997083305, 0.972455032240083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 293}], {
             RGBColor[
             0.5705621841304782, 0.6464933294806976, 0.9637502028884042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 394}], {
             RGBColor[
             0.5649072324471209, 0.6405496167168437, 0.9634281617557884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 151}], {
             RGBColor[
             0.5857022795390194, 0.6736276318496492, 0.9611505559774818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 158}], {
             RGBColor[
             0.571707070358748, 0.6619473187458047, 0.9601367689255541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 171}], {
             RGBColor[
             0.5729627067355698, 0.6630348878652885, 0.9602167769651695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 186}], {
             RGBColor[
             0.5447041480892449, 0.6385587446822971, 0.958416166596288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 272}], {
             RGBColor[
             0.5482868462872464, 0.6416618977897587, 0.958644452957409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 306}], {
             RGBColor[
             0.5502500567670471, 0.6433623320335342, 0.9587695469931831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 308}], {
             RGBColor[
             0.47884521694988136`, 0.5766261998586328, 0.9543986984453898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 342}], {
             RGBColor[
             0.6750341110958077, 0.7460610451280871, 0.9682447497077561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 348}], {
             RGBColor[
             0.48434236946797654`, 0.5824040556947512, 0.954711753148987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 354}], {
             RGBColor[
             0.5212505406192238, 0.6182444087043517, 0.956921723467509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 374}], {
             RGBColor[
             0.5864437292862018, 0.6742295741563424, 0.9612089256176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 378}], {
             RGBColor[
             0.5359527982888288, 0.630978765340807, 0.9578585383255203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 148}], {
             RGBColor[
             0.38101492439503293`, 0.5034137472512921, 0.9455919476085459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 169}], {
             RGBColor[
             0.687035966613865, 0.7534173612245914, 0.9711336824842691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 218}], {
             RGBColor[
             0.4169830952952043, 0.5353597999506272, 0.9478548001996014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 222}], {
             RGBColor[
             0.35682284497328176`, 0.4779863379126043, 0.9442142444744515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 276}], {
             RGBColor[
             0.4080957648571295, 0.5276620410153828, 0.9472885073628451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 282}], {
             RGBColor[
             0.363151979066178, 0.48463865913451726`, 0.944574679297927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 305}], {
             RGBColor[
             0.3543611646017677, 0.4753989557625928, 0.9440740554190235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 339}], {
             RGBColor[
             0.372756502875877, 0.49473362262049236`, 0.9451216427202698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 361}], {
             RGBColor[
             0.5086634784669648, 0.6119949527048736, 0.9544629988020872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 382}], {
             RGBColor[
             0.3538461245157146, 0.47485761597672344`, 0.9440447246480563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 384}], {
             RGBColor[
             0.34598093412798914`, 0.4665908021973509, 0.9435968136909818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 165}], {
             RGBColor[
             0.6294877451842205, 0.7038239182230183, 0.9673934323670172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 170}], {
             RGBColor[
             0.7398593694111419, 0.7963060302568434, 0.9752872414575811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 182}], {
             RGBColor[
             0.6639702612247323, 0.7336909404756602, 0.9695906277974269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 192}], {
             RGBColor[
             0.6853286412519182, 0.752035528555877, 0.970994382784248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 208}], {
             RGBColor[
             0.6312152049648976, 0.7053201570603878, 0.9675035045767093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 221}], {
             RGBColor[
             0.6321541936449888, 0.7061334618601394, 0.9675633361050895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 225}], {
             RGBColor[
             0.6587471800445025, 0.7291669700770382, 0.9692578176832121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 235}], {
             RGBColor[
             0.7105408626343128, 0.7725039456717347, 0.9729791812068801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 335}], {
             RGBColor[
             0.646593252749072, 0.7186398491278841, 0.9684833801832431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 349}], {
             RGBColor[
             0.6424269504741547, 0.7150312075017918, 0.9682179070864019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 351}], {
             RGBColor[
             0.6050021078038151, 0.681656566290328, 0.9658683474153025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 355}], {
             RGBColor[
             0.7000750051512259, 0.7640072910854581, 0.9721552705681124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 395}], {
             RGBColor[
             0.6229594474941027, 0.6981694348856208, 0.9669774550109499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 151}], {
             RGBColor[
             0.5707836220725493, 0.6619730632508467, 0.9596636036240046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 158}], {
             RGBColor[
             0.556788412892278, 0.6502927501470022, 0.9586498165720769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 227}], {
             RGBColor[
             0.5281861146378866, 0.6255188769923584, 0.9568273034193263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 243}], {
             RGBColor[
             0.47977696636469847`, 0.5816314138659038, 0.9538144033152263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 267}], {
             RGBColor[
             0.6166950960681867, 0.6992460661288386, 0.9632779230362118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 275}], {
             RGBColor[
             0.516830443136153, 0.6156831650902019, 0.9561037300726619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 306}], {
             RGBColor[
             0.535331399300577, 0.6317077634347316, 0.9572825946397059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 311}], {
             RGBColor[
             0.43821954328250873`, 0.5379519273137148, 0.9514477695493937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 317}], {
             RGBColor[
             0.46023774133214934`, 0.5610944494982745, 0.9527016733553157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 344}], {
             RGBColor[
             0.42970231351544724`, 0.5289997788049756, 0.9509627259142718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 346}], {
             RGBColor[
             0.7142290186454308, 0.776680404798183, 0.9721513317950665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 354}], {
             RGBColor[
             0.5063318831527537, 0.606589840105549, 0.9554347711140319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 195}], {
             RGBColor[
             0.5454779143648648, 0.6418825702382263, 0.9573611660516921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 217}], {
             RGBColor[
             0.3683648036236604, 0.4824263289059931, 0.9455716554911018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 231}], {
             RGBColor[
             0.49197088331615413`, 0.5984431519686036, 0.9531488965648246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 241}], {
             RGBColor[
             0.4299322937181236, 0.5448297424988411, 0.949162337304787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 242}], {
             RGBColor[
             0.5300266521593769, 0.6293385395083813, 0.9561447860910377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 255}], {
             RGBColor[
             0.4643547096102106, 0.5746447090236386, 0.9513557032068836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 312}], {
             RGBColor[
             0.35485550089473594`, 0.4682271951986291, 0.944802320685912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 331}], {
             RGBColor[
             0.4698176465549579, 0.5793764304299842, 0.9517037967183174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 359}], {
             RGBColor[
             0.43465423061798325`, 0.5489196469100502, 0.9494632149486012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 392}], {
             RGBColor[
             0.5944125913904158, 0.6812988260050887, 0.9614261971988912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 218}], {
             RGBColor[
             0.3361455139768238, 0.4647818509886694, 0.9426688802554629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 228}], {
             RGBColor[
             0.2702929738530568, 0.40142543145688914`, 0.938704157047086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 276}], {
             RGBColor[
             0.327258183538749, 0.45708409205342504`, 0.9421025874187066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.2823143977477976, 0.4140607101725594, 0.9393887593537884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 301}], {
             RGBColor[
             0.35578289342356717`, 0.4817907620620492, 0.9439201567091566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 305}], {
             RGBColor[
             0.2735235832833872, 0.40482100680063493`, 0.9388881354748848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 313}], {
             RGBColor[
             0.34139408289545625`, 0.4693278975852447, 0.943003314425831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 339}], {
             RGBColor[
             0.2919189215574966, 0.42415567365853457`, 0.9399357227761311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 340}], {
             RGBColor[
             0.31883692219357773`, 0.4497900187411398, 0.9415659920924213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 361}], {
             RGBColor[
             0.4278258971485843, 0.5414170037429158, 0.9492770788579487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 382}], {
             RGBColor[
             0.27300854319733414`, 0.4042796670147656, 0.9388588047039177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 155}], {
             RGBColor[
             0.2318752356888018, 0.3610459528209709, 0.9365163236925821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 164}], {
             RGBColor[
             0.3327755542981793, 0.4572169303586688, 0.9426242633563702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 210}], {
             RGBColor[
             0.44705812295963065`, 0.5509920885349768, 0.9513573934090753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 230}], {
             RGBColor[
             0.2798816491873227, 0.41140288827661575`, 0.9392539104949502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 258}], {
             RGBColor[
             0.254607934007004, 0.38493946008972246`, 0.9378109172317903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 264}], {
             RGBColor[
             0.2440792242379045, 0.3738731185636432, 0.9372113227862704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 268}], {
             RGBColor[
             0.21522030516010907`, 0.3435405648517286, 0.9355678500377347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 279}], {
             RGBColor[
             0.3327755542981793, 0.4572169303586688, 0.9426242633563702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 299}], {
             RGBColor[
             0.3475822901709669, 0.4700417807634936, 0.9435677354731018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 300}], {
             RGBColor[
             0.49774960252150746`, 0.5905926576382289, 0.9564098463529935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 328}], {
             RGBColor[
             0.3074790760968649, 0.4353063923786534, 0.9410123941341798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 152}], {
             RGBColor[
             0.3396621488081165, 0.46376686910811565`, 0.9430416470797569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 156}], {
             RGBColor[
             0.37598476780910917`, 0.5000808411575164, 0.9451783948278887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 157}], {
             RGBColor[
             0.4337207925937684, 0.5500888839290061, 0.9488572832732051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 160}], {
             RGBColor[
             0.6535387617490062, 0.7256056346656234, 0.9684886347386922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 167}], {
             RGBColor[
             0.41640218142095003`, 0.5350883733898181, 0.9477537566835197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 179}], {
             RGBColor[
             0.3072746046869471, 0.42972550674786547`, 0.9411972243551341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 181}], {
             RGBColor[
             0.4002087264826687, 0.5210624166289894, 0.9467219240541622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 206}], {
             RGBColor[
             0.3893231380115032, 0.5116338670208508, 0.9460283039825275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 211}], {
             RGBColor[
             0.5299018917302543, 0.6284159282743378, 0.956361899064565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 238}], {
             RGBColor[
             0.42371464959614774`, 0.5414220657878372, 0.9482197006894815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 386}], {
             RGBColor[
             0.39337573041046753`, 0.5151440188676172, 0.9462865315866228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 158}], {
             RGBColor[
             0.45558781972055623`, 0.5685873700890491, 0.9503726556039094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 186}], {
             RGBColor[
             0.4285848974510532, 0.5451987960255414, 0.9486520532746434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 227}], {
             RGBColor[
             0.4269855214661648, 0.5438134969344055, 0.9485501424511589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 267}], {
             RGBColor[
             0.515494502896465, 0.6175406860708856, 0.9550007620680445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 306}], {
             RGBColor[
             0.43413080612885535`, 0.5500023833767786, 0.9490054336715383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 308}], {
             RGBColor[
             0.3627259663116896, 0.48326625120187716`, 0.9446345851237452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 311}], {
             RGBColor[
             0.33701895011078703`, 0.4562465472557618, 0.9431706085812261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 317}], {
             RGBColor[
             0.35903714816042764`, 0.4793890694403215, 0.9444245123871482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 344}], {
             RGBColor[
             0.32850172034372555`, 0.44729439874702265`, 0.9426855649461043]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 346}], {
             RGBColor[
             0.6130284254737091, 0.6949750247402301, 0.9638741708268992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 348}], {
             RGBColor[
             0.36822311882978476`, 0.4890441070379955, 0.9449476398273423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 354}], {
             RGBColor[
             0.405131289981032, 0.524884460047596, 0.9471576101458643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 156}], {
             RGBColor[
             0.2925776892969639, 0.4229846768133004, 0.940041466954859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 157}], {
             RGBColor[
             0.35031371408162315`, 0.4729927195847901, 0.9437203554001754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 160}], {
             RGBColor[
             0.5701316832368609, 0.6485094703214075, 0.9633517068656625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 179}], {
             RGBColor[
             0.2238675261748019, 0.35262934240364946`, 0.9360602964821044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 181}], {
             RGBColor[
             0.31680164797052346`, 0.4439662522847734, 0.9415849961811327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 238}], {
             RGBColor[
             0.3403075710840025, 0.4643259014436213, 0.9430827728164518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 245}], {
             RGBColor[
             0.24690244987239626`, 0.376840507708338, 0.9373721013095666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 168}], {
             RGBColor[
             0.3561206349329622, 0.482875527660546, 0.9439126698461835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 175}], {
             RGBColor[
             0.35267216913242216`, 0.479888639909049, 0.9436929366547318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 211}], {
             RGBColor[
             0.501578135098867, 0.6038833138736313, 0.9545571343377276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 216}], {
             RGBColor[
             0.28460330401715694`, 0.4111339819492048, 0.9397143586332504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 229}], {
             RGBColor[
             0.2929432537276695, 0.4198997978783062, 0.9401893064314142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 294}], {
             RGBColor[
             0.32235830086658124`, 0.45081687744300963`, 0.9418644498503126]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 329}], {
             RGBColor[
             0.29344819415063206`, 0.4204305222779118, 0.9402180620415095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 341}], {
             RGBColor[
             0.3955322906022421, 0.5170119229138654, 0.9464239456950714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 343}], {
             RGBColor[
             0.29060038345874717`, 0.4174372926791142, 0.940055883435565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 358}], {
             RGBColor[
             0.3819637564015174, 0.5052595405635559, 0.9455593706939849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 379}], {
             RGBColor[
             0.34427413578996113`, 0.4726146855252381, 0.9431578213962395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 207}], {
             RGBColor[
             0.2579406509997413, 0.38832781215636347`, 0.9380049045804235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 231}], {
             RGBColor[
             0.33184086964565396`, 0.45221516852459076`, 0.9427472763545655]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 369}], {
             RGBColor[
             0.2559341294404075, 0.38633337557587655`, 0.9378864420997923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 372}], {
             RGBColor[
             0.1939120779765145, 0.3211442670621361, 0.9343543780223262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 387}], {
             RGBColor[
             0.33713724649297705`, 0.4565150058483056, 0.9431642265412543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 392}], {
             RGBColor[
             0.43428257771991563`, 0.5350708425610758, 0.9510245769886321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 249}], {
             RGBColor[
             0.3218143786592419, 0.4443849798030997, 0.9420480449476063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 268}], {
             RGBColor[
             0.19716901003489629`, 0.3245675091569148, 0.9345398554848519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 279}], {
             RGBColor[
             0.31472425917296654`, 0.43824387466385495`, 0.9415962688034873]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.3295309950457541, 0.4510687250686798, 0.942539740920219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 300}], {
             RGBColor[
             0.4796983073962947, 0.571619601943415, 0.9553818518001107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 370}], {
             RGBColor[
             0.31753717500632817`, 0.4406802809774522, 0.9417755053130255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 371}], {
             RGBColor[
             0.2043166800642964, 0.3320801635462691, 0.934946904718996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 160}], {
             RGBColor[
             0.6064543022378537, 0.6848234423708082, 0.9654884546137943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.2601901451757946, 0.3889433144530502, 0.9381970442302362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 181}], {
             RGBColor[
             0.3531242669715161, 0.4802802243341741, 0.9437217439292644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 245}], {
             RGBColor[
             0.28322506887338894`, 0.41315447975773867`, 0.9395088490576984]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 352}], {
             RGBColor[
             0.3070964329678969, 0.4382447969529676, 0.9408682879283621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 396}], {
             RGBColor[
             0.3522429661392933, 0.4795168858487705, 0.9436655882195388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 160}], {
             RGBColor[
             0.6641903270225128, 0.7348314851422979, 0.9691673430591107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 167}], {
             RGBColor[
             0.4270537466944567, 0.5443142238664925, 0.9484324650039382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 168}], {
             RGBColor[
             0.3950959568378561, 0.516633992537927, 0.9463961428934395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 203}], {
             RGBColor[
             0.40271733570726853`, 0.523235247852972, 0.9468817704156778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 206}], {
             RGBColor[
             0.39997470328500984`, 0.5208597174975252, 0.946707012302946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 211}], {
             RGBColor[
             0.5405534570037609, 0.6376417787510122, 0.9570406073849835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 238}], {
             RGBColor[
             0.43436621486965443`, 0.5506479162645117, 0.9488984090099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 341}], {
             RGBColor[
             0.434507612507136, 0.5507703877912464, 0.9489074187423273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 358}], {
             RGBColor[
             0.4209390783064113, 0.5390180054409369, 0.9480428437412408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 386}], {
             RGBColor[
             0.4040272956839742, 0.5243698693442916, 0.9469652399070413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 267}], {
             RGBColor[
             0.5014992937161936, 0.6058603729670411, 0.9539869750161167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 306}], {
             RGBColor[
             0.42013559694858393`, 0.5383220702729341, 0.9479916466196107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 308}], {
             RGBColor[
             0.3487307571314182, 0.4715859380980326, 0.9436207980718174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 311}], {
             RGBColor[
             0.32302374093051567`, 0.44456623415191726`, 0.9421568215292985]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 317}], {
             RGBColor[
             0.3450419389801562, 0.46770875633647696`, 0.9434107253352205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 344}], {
             RGBColor[
             0.3145065111634542, 0.4356140856431781, 0.9416717778941766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 346}], {
             RGBColor[
             0.5990332162934378, 0.6832947116363856, 0.9628603837749714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 348}], {
             RGBColor[
             0.3542279096495134, 0.47736379393415096`, 0.9439338527754146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 354}], {
             RGBColor[
             0.3911360808007607, 0.5132041469437515, 0.9461438230939366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 374}], {
             RGBColor[
             0.45632926946773866`, 0.5691893123957423, 0.9504310252440276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 250}], {
             RGBColor[
             0.33962566484498014`, 0.4640602030561098, 0.9430274249092645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 265}], {
             RGBColor[
             0.2787134247669122, 0.410275859254775, 0.9391836892696892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 321}], {
             RGBColor[
             0.26101520927846367`, 0.3916739126447424, 0.9381758020797856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 375}], {
             RGBColor[
             0.26222216324141073`, 0.3929424977851008, 0.938244536322447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 381}], {
             RGBColor[
             0.31009688050939577`, 0.43848385422448116`, 0.9411458768826799]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[
             0.6306782609114131, 0.7058050178422812, 0.9670319838400678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 238}], {
             RGBColor[
             0.6541841840248921, 0.7261646670011291, 0.9685297604753871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 245}], {
             RGBColor[
             0.5607790628132859, 0.6386792732658458, 0.9628190889685019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 196}], {
             RGBColor[
             0.41800167685309925`, 0.5351286743124692, 0.9482273307055438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 214}], {
             RGBColor[
             0.3433623247644898, 0.4718249206439295, 0.9430997216039791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 253}], {
             RGBColor[
             0.31666181833461093`, 0.4479060531024014, 0.9414273963978967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 283}], {
             RGBColor[
             0.4863182023783312, 0.590591107358255, 0.9536054578465687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 332}], {
             RGBColor[
             0.3153188135299031, 0.4464944699012307, 0.9413509142610661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 334}], {
             RGBColor[
             0.3614131624756377, 0.4874596490078426, 0.9442499050212045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.3774772310587775, 0.501373537810995, 0.9452734932664241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 364}], {
             RGBColor[
             0.25840710146116547`, 0.3866766521060304, 0.9381098764520845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 366}], {
             RGBColor[
             0.4921412432603303, 0.5951840588700152, 0.9541557968474634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 389}], {
             RGBColor[
             0.2607496967137143, 0.38913886824557686`, 0.9382432837861581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 183}], {
             RGBColor[
             0.38215623122194575`, 0.5054262525789451, 0.9455716350193437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 270}], {
             RGBColor[
             0.31177516199417155`, 0.43637421605758364`, 0.941383284676063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 280}], {
             RGBColor[
             0.3620235870262692, 0.48798836807276963`, 0.9442888007337935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 291}], {
             RGBColor[
             0.6709430984022917, 0.7386701676440235, 0.9670203097298086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 336}], {
             RGBColor[
             0.2924251879662221, 0.4160361664949954, 0.9402813322808927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 357}], {
             RGBColor[
             0.3184062607749184, 0.44334392131209455`, 0.941760915941795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 368}], {
             RGBColor[
             0.35237292876352183`, 0.4790450429792539, 0.9436952674345638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 171}], {
             RGBColor[
             0.36504527797870423`, 0.4885013495843957, 0.9445583873044027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 240}], {
             RGBColor[
             0.3178328402371833, 0.44760830897880816`, 0.9415500525198324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 272}], {
             RGBColor[
             0.3403694175303809, 0.4671283595088659, 0.9429860632966421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 342}], {
             RGBColor[
             0.46711668233894216`, 0.5715275068471943, 0.9525863600469893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 374}], {
             RGBColor[
             0.3785263005293362, 0.49969603587544964`, 0.945550535956833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 210}], {
             RGBColor[
             0.5299071464437953, 0.6281900103778608, 0.9564373385199806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 230}], {
             RGBColor[
             0.3627306726714874, 0.4886008101194998, 0.9443338556058556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 258}], {
             RGBColor[
             0.3374569574911687, 0.4621373819326065, 0.9428908623426956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 264}], {
             RGBColor[
             0.32692824772206924`, 0.45107104040652723`, 0.9422912678971757]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 279}], {
             RGBColor[
             0.415624577782344, 0.5344148522015528, 0.9477042084672755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 328}], {
             RGBColor[
             0.39032809958102965`, 0.5125043142215374, 0.9460923392450851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 170}], {
             RGBColor[
             0.4577151549265619, 0.5677553531575535, 0.9512472096162887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 172}], {
             RGBColor[
             0.2678483152672498, 0.3952873348497068, 0.9386956014833274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 184}], {
             RGBColor[
             0.28594794044050187`, 0.4143111884893119, 0.9397263483609483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 190}], {
             RGBColor[
             0.3381219194987985, 0.46728594499321474`, 0.9427658076143578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 192}], {
             RGBColor[
             0.4031844267673381, 0.5234848514565871, 0.9469543509429557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 221}], {
             RGBColor[
             0.35000997916040866`, 0.4775827847608495, 0.9435233042637972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 226}], {
             RGBColor[
             0.49203904341994353`, 0.5956210321100361, 0.9539493118510342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 252}], {
             RGBColor[
             0.33098836557519845`, 0.4611072191274377, 0.9423112638663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 274}], {
             RGBColor[
             0.3917034144329457, 0.5136955428209328, 0.9461799730913061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 288}], {
             RGBColor[
             0.35971837799736545`, 0.4859917118751079, 0.944141914852888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 318}], {
             RGBColor[
             0.4323354773466209, 0.547150987556712, 0.9492492284283736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 322}], {
             RGBColor[
             0.3861958217450143, 0.508925142854304, 0.9458290341554041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 351}], {
             RGBColor[
             0.3228578933192351, 0.4531058891910381, 0.9418283155740101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 355}], {
             RGBColor[
             0.4179307906666458, 0.5354566139861683, 0.9481152387268199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 399}], {
             RGBColor[
             0.3463305206600037, 0.47439582274276015`, 0.9432888524217687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 169}], {
             RGBColor[
             0.5479436684220391, 0.6216100112662626, 0.9626302425943184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 246}], {
             RGBColor[
             0.3191362872395959, 0.4392422845142521, 0.941989139383278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 326}], {
             RGBColor[
             0.24023343755062035`, 0.3698309529183482, 0.936992310923761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 363}], {
             RGBColor[
             0.21290531856843387`, 0.3411073671652506, 0.9354360149760546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 383}], {
             RGBColor[
             0.2542019658477199, 0.3830343749939253, 0.9378419289292512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 168}], {
             RGBColor[
             0.37777734566503773`, 0.5016334819987389, 0.945292616303754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.3853987245344502, 0.508234737313784, 0.9457782438259923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 211}], {
             RGBColor[
             0.5232348458309425, 0.6226412682118242, 0.955937080795298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 216}], {
             RGBColor[
             0.3062600147492325, 0.42989193628739775`, 0.9410943050908209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 238}], {
             RGBColor[
             0.417047603696836, 0.5356474057253238, 0.9477948824202145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 341}], {
             RGBColor[
             0.41718900133431763`, 0.5357698772520584, 0.9478038921526419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 358}], {
             RGBColor[
             0.40362046713359295`, 0.5240174949017489, 0.9469393171515554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 211}], {
             RGBColor[
             0.4912770559743419, 0.5949610368832586, 0.9539007586847994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 216}], {
             RGBColor[
             0.27430222489263184`, 0.4022117049588322, 0.9390579829803223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 238}], {
             RGBColor[
             0.38508981384023544`, 0.5079671743967582, 0.9457585603097158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 341}], {
             RGBColor[
             0.385231211477717, 0.5080896459234928, 0.9457675700421433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 379}], {
             RGBColor[
             0.3339730566654361, 0.4636924085348655, 0.9425014457433113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 218}], {
             RGBColor[
             0.6421665561956559, 0.7147854649619687, 0.9682106151311861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 222}], {
             RGBColor[
             0.5820063058737335, 0.6574120029239457, 0.964570059406036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 224}], {
             RGBColor[
             0.8398816268452733, 0.8755866819423606, 0.9844773754851934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 276}], {
             RGBColor[
             0.6332792257575812, 0.7070877060267243, 0.9676443222944298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 326}], {
             RGBColor[
             0.6045091966428979, 0.6810639678880185, 0.9658515657452964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 361}], {
             RGBColor[
             0.7338469393674164, 0.7914206177162151, 0.9748188137336719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 363}], {
             RGBColor[
             0.5771810776607114, 0.6523403821349208, 0.96429526979759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 382}], {
             RGBColor[
             0.5790295854161662, 0.6542832809880649, 0.9644005395796409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 383}], {
             RGBColor[
             0.6184777249399975, 0.6942673899635956, 0.9667011837507866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 393}], {
             RGBColor[
             0.7232545184442413, 0.7828212132276569, 0.9739849395572832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[
             0.5135560509942597, 0.6159669634904122, 0.9548481600335195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 208}], {
             RGBColor[
             0.45944261470723907`, 0.569251591994923, 0.9513572818259808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 221}], {
             RGBColor[
             0.46038160338733025`, 0.5700648967946746, 0.9514171133543611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 225}], {
             RGBColor[
             0.48697458978684394`, 0.5930984050115735, 0.9531115949324835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 235}], {
             RGBColor[
             0.5387682723766543, 0.63643538060627, 0.9568329584561517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 322}], {
             RGBColor[
             0.4965674459719359, 0.6014072548881292, 0.9537228432459679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 335}], {
             RGBColor[
             0.4748206624914134, 0.5825712840624194, 0.9523371574325146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 349}], {
             RGBColor[
             0.4706543602164961, 0.5789626424363271, 0.9520716843356734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 351}], {
             RGBColor[
             0.43322951754615663`, 0.5455880012248633, 0.949722124664574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 355}], {
             RGBColor[
             0.5283024148935673, 0.6279387260199933, 0.9560090478173839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 186}], {
             RGBColor[
             0.4158453246476036, 0.5346060520411806, 0.9477182742623311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 240}], {
             RGBColor[
             0.3968914455524074, 0.5181891546185846, 0.9465105498466424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 272}], {
             RGBColor[
             0.4194280228456051, 0.5377092051486423, 0.9479465606234521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 308}], {
             RGBColor[
             0.34998639350824, 0.4726735072175164, 0.9437008061114329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 342}], {
             RGBColor[
             0.5461752876541663, 0.6421083524869706, 0.9575468573737991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 348}], {
             RGBColor[
             0.35548354602633514`, 0.4784513630536348, 0.94401386081503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 374}], {
             RGBColor[
             0.4575849058445604, 0.570276881515226, 0.9505110332836431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 192}], {
             RGBColor[
             0.32368921133494755`, 0.4434989451825655, 0.9422965519005583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 194}], {
             RGBColor[
             0.2902268614614774, 0.4146705067847106, 0.9401215426582523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 221}], {
             RGBColor[
             0.2705147637280181, 0.3975968784868279, 0.9388655052213999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 256}], {
             RGBColor[
             0.28883556818021605`, 0.4134654384729156, 0.9400328906806426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 316}], {
             RGBColor[
             0.2637628866395626, 0.3917487419120175, 0.938435281583774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 351}], {
             RGBColor[
             0.2433626778868445, 0.3731199829170164, 0.9371705165316128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 399}], {
             RGBColor[
             0.2668353052276131, 0.39440991646873846`, 0.9386310533793714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 198}], {
             RGBColor[
             0.4039467110680804, 0.524300071000305, 0.9469601051265748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 203}], {
             RGBColor[
             0.36635978520126117`, 0.49174416498829043`, 0.9445650994471545]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 266}], {
             RGBColor[
             0.3413186912644534, 0.47005482802220433`, 0.942969503084471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 313}], {
             RGBColor[
             0.3771340397847601, 0.5010762827787362, 0.9452516254219159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 329}], {
             RGBColor[
             0.2960659655495186, 0.42269790429061116`, 0.9403848641202421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 340}], {
             RGBColor[
             0.3545768790828816, 0.4815384039346313, 0.9438143030885062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 341}], {
             RGBColor[
             0.3981500620011286, 0.5192793049265648, 0.946590747773804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 358}], {
             RGBColor[
             0.38458152780040394`, 0.5075269225762553, 0.9457261727727175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 204}], {
             RGBColor[
             0.38447630217500134`, 0.5074357814283252, 0.9457194678889143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 216}], {
             RGBColor[
             0.27085375909209186`, 0.3992248172073352, 0.9388382497888704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 229}], {
             RGBColor[
             0.2791937088026044, 0.40799063313643663`, 0.9393131975870341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 294}], {
             RGBColor[
             0.30860875594151616`, 0.43890771270114004`, 0.9409883410059325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 307}], {
             RGBColor[
             0.3419501324979599, 0.47060175068150845`, 0.9430097379615086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 343}], {
             RGBColor[
             0.2768508385336821, 0.4055281279372446, 0.939179774591185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 379}], {
             RGBColor[
             0.33052459086489605`, 0.46070552078336846`, 0.9422817125518594]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 205}], {
             RGBColor[
             0.3812276367357902, 0.493182533004934, 0.9465557211288609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 232}], {
             RGBColor[
             0.44661467745898087`, 0.5586518573583492, 0.9503986564902724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 277}], {
             RGBColor[
             0.38968489003586054`, 0.5020716424441378, 0.9470373491929149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 298}], {
             RGBColor[
             0.5271995554875202, 0.6270433750709141, 0.9559222266850327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 320}], {
             RGBColor[
             0.7571164491462782, 0.809175245364621, 0.9509177856853397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 347}], {
             RGBColor[
             0.3695012227831382, 0.4808573284431097, 0.9458879192019323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 373}], {
             RGBColor[
             0.42946342175814023`, 0.5437963017174577, 0.9493057936432747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 390}], {
             RGBColor[
             0.6420412281963688, 0.7188606027060882, 0.9659313950771236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 219}], {
             RGBColor[
             0.2583998798867059, 0.3889250356325441, 0.9380268629399581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 248}], {
             RGBColor[
             0.3101241549011888, 0.43657963439002534`, 0.9412182025786466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 260}], {
             RGBColor[
             0.605667706141141, 0.6736989738407962, 0.9342460564600041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 285}], {
             RGBColor[
             0.2488719564652651, 0.37891058401137345`, 0.9374842617964065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 200}], {
             RGBColor[
             0.29249305778130297`, 0.4246288269053021, 0.9399731899179744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 278}], {
             RGBColor[
             0.3203139370239202, 0.44872587418720844`, 0.9417459117422764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 296}], {
             RGBColor[
             0.5459231614742472, 0.6315864895770376, 0.9606793546196979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 330}], {
             RGBColor[
             0.24610234830464534`, 0.3759995502312623, 0.9373265367089274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 367}], {
             RGBColor[
             0.33265770399043404`, 0.4594174247178357, 0.942532445658218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 398}], {
             RGBColor[
             0.3363887790758386, 0.46264909442752666`, 0.9427701864633999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 209}], {
             RGBColor[
             0.39014955441938604`, 0.4978284495118868, 0.9474945094074949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 245}], {
             RGBColor[
             0.2145149057512269, 0.34279914534808775`, 0.9355276785849438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 286}], {
             RGBColor[
             0.2751784785923188, 0.4019254555229017, 0.9391520875818742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 290}], {
             RGBColor[
             0.39649207611076887`, 0.5029775943482975, 0.9479938159484631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 352}], {
             RGBColor[
             0.23838626984573483`, 0.36788946254331667`, 0.9368871174556075]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 386}], {
             RGBColor[
             0.27758110777715295`, 0.404006492163151, 0.9393051809889703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 232}], {
             RGBColor[
             0.4076634067456407, 0.5270294610585109, 0.9473322697765123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 249}], {
             RGBColor[
             0.4505813464286854, 0.5642028232935947, 0.950066962942272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 268}], {
             RGBColor[
             0.32593597780433975`, 0.44438535264740975`, 0.9425587734795176]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 370}], {
             RGBColor[
             0.4463041427757717, 0.5604981244679472, 0.9497944233076909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 238}], {
             RGBColor[
             0.40085414875855463`, 0.521621448964495, 0.9467630497908572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 245}], {
             RGBColor[
             0.3074490275469484, 0.4341360552292117, 0.9410523782839719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 187}], {
             RGBColor[
             0.32567828983082886`, 0.4496940163244615, 0.9422224001371563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 208}], {
             RGBColor[
             0.3835535065208294, 0.5066365022137397, 0.9456606681658266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 323}], {
             RGBColor[
             0.33920232592811556`, 0.46390863573612373`, 0.9429925739858782]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 377}], {
             RGBColor[
             0.39560456013094536`, 0.5170745191472561, 0.9464285506455349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 388}], {
             RGBColor[
             0.43186655089985193`, 0.548482832970633, 0.9487391326321102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 395}], {
             RGBColor[
             0.37529774905003455`, 0.4994857800389728, 0.9451346186000673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 270}], {
             RGBColor[
             0.29161064034451634`, 0.4189087209029792, 0.9400984191873334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 291}], {
             RGBColor[
             0.6507785767526364, 0.721204672489419, 0.9657354442410788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 357}], {
             RGBColor[
             0.29824173912526314`, 0.42587842615749005`, 0.9404760504530654]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 368}], {
             RGBColor[
             0.33220840711386657`, 0.46157954782464944`, 0.9424104019458341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 185}], {
             RGBColor[
             0.3479551131419197, 0.4675288599810212, 0.9438127306626011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 190}], {
             RGBColor[
             0.27672632923966, 0.4063238923587983, 0.9391387554495813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 226}], {
             RGBColor[
             0.43064345316080505`, 0.5346589794756197, 0.9503222596862576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 252}], {
             RGBColor[
             0.26959277531605996`, 0.40014516649302123`, 0.9386842117015235]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 274}], {
             RGBColor[
             0.3303078241738072, 0.4527334901865163, 0.9425529209265295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 288}], {
             RGBColor[
             0.29832278773822696`, 0.4250296592406914, 0.9405148626881115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 318}], {
             RGBColor[
             0.3709398870874825, 0.4861889349222955, 0.945622176263597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 190}], {
             RGBColor[
             0.4001290922002163, 0.520503616484924, 0.9468521899160106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 226}], {
             RGBColor[
             0.5540462161213613, 0.6488387036017454, 0.958035694152687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 252}], {
             RGBColor[
             0.39299553827661626`, 0.514324890619147, 0.9463976461679529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 274}], {
             RGBColor[
             0.4537105871343635, 0.5669132143126421, 0.9502663553929589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 288}], {
             RGBColor[
             0.42172555069878326`, 0.5392093833668172, 0.9482282971545408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 318}], {
             RGBColor[
             0.49434265004803873`, 0.6003686590484212, 0.9533356107300264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 357}], {
             RGBColor[
             0.35292482239035583`, 0.47275233949889317`, 0.9440957482522736]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 272}], {
             RGBColor[
             0.3911694641992803, 0.5132330619656509, 0.9461459502545706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 306}], {
             RGBColor[
             0.393132674679081, 0.5149334962094263, 0.9462710442903446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 308}], {
             RGBColor[
             0.3217278348619152, 0.4481973640345249, 0.9419001957425513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 342}], {
             RGBColor[
             0.5179167290078415, 0.6176322093039792, 0.9557462470049176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 348}], {
             RGBColor[
             0.3272249873800104, 0.45397521987064327`, 0.9422132504461485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 374}], {
             RGBColor[
             0.4293263471982356, 0.5458007383322345, 0.9487104229147615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 378}], {
             RGBColor[
             0.3788354162008627, 0.5025499295166991, 0.9453600356226818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 208}], {
             RGBColor[
             0.2929232335709941, 0.42132323290918905`, 0.9401352769164386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 302}], {
             RGBColor[
             0.3677274455565175, 0.48483630822554585`, 0.9452550087797722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 377}], {
             RGBColor[
             0.30497428718111, 0.4317612498427054, 0.9409031593961469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 388}], {
             RGBColor[
             0.34123627795001665`, 0.4631695636660824, 0.9432137413827222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 201}], {
             RGBColor[
             0.4026197741514697, 0.5190051438325158, 0.9474701154392435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 264}], {
             RGBColor[
             0.3797918952514542, 0.49501159573748105`, 0.9461701015067081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 273}], {
             RGBColor[
             0.4031678655028934, 0.519581222593861, 0.9475013284308785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 281}], {
             RGBColor[
             0.5136872143856079, 0.6160734478403522, 0.9548584856961538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 293}], {
             RGBColor[
             0.379503122829444, 0.4947080776127193, 0.946153656344475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 394}], {
             RGBColor[
             0.3738481711460866, 0.48876436484886543`, 0.9458316152118592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 207}], {
             RGBColor[
             0.2620122543262415, 0.3926073254070763, 0.9382367763664704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 241}], {
             RGBColor[
             0.27387388337412366`, 0.40288127230554116`, 0.9389925888805747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 263}], {
             RGBColor[
             0.3106036672703982, 0.434694765023878, 0.9413329782315727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 280}], {
             RGBColor[
             0.2678830147581119, 0.3976922830201636, 0.9386108560298796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 291}], {
             RGBColor[
             0.5768025261341343, 0.6483740825914175, 0.9613423650258945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 336}], {
             RGBColor[
             0.1982846156980648, 0.32574008144238936`, 0.9346033875769787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 359}], {
             RGBColor[
             0.2785958202739832, 0.4069711767167502, 0.9392934665243888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 226}], {
             RGBColor[
             0.48281743221910167`, 0.5876337359795225, 0.9533617189396671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 252}], {
             RGBColor[
             0.3217667543743566, 0.45311992299692405`, 0.941723670954933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 274}], {
             RGBColor[
             0.38248180323210385`, 0.5057082466904191, 0.9455923801799391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 288}], {
             RGBColor[
             0.3504967667965236, 0.47800441574459424`, 0.943554321941521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 318}], {
             RGBColor[
             0.42311386614577906`, 0.5391636914261984, 0.9486616355170066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 225}], {
             RGBColor[
             0.400563563777437, 0.5213697588590767, 0.9467445339728146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 235}], {
             RGBColor[
             0.4523572463672474, 0.5647067344537732, 0.9504658974964826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 261}], {
             RGBColor[
             0.3944132744434262, 0.5160426873604866, 0.9463526429749387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 322}], {
             RGBColor[
             0.41015641996252894`, 0.5296786087356323, 0.947355782286299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 327}], {
             RGBColor[
             0.3259315659815056, 0.4519058720062362, 0.9421655841939712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 335}], {
             RGBColor[
             0.3884096364820065, 0.5108426379099226, 0.9459700964728457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 349}], {
             RGBColor[
             0.3842433342070891, 0.5072339962838303, 0.9457046233760044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 355}], {
             RGBColor[
             0.4418913888841604, 0.5562100798674965, 0.9496419868577148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 208}], {
             RGBColor[
             0.40491188654801524`, 0.5249810902939566, 0.9470644231526477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 221}], {
             RGBColor[
             0.4058508752281065, 0.5257943950937082, 0.9471242546810279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[
             0.43244386162762016`, 0.5488279033106072, 0.9488187362591505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 322}], {
             RGBColor[
             0.44203671781271214`, 0.5571367531871627, 0.9494299845726348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 335}], {
             RGBColor[
             0.42028993433218964`, 0.538300782361453, 0.9480442987591815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 349}], {
             RGBColor[
             0.4161236320572723, 0.5346921407353606, 0.9477788256623403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 351}], {
             RGBColor[
             0.3786987893869328, 0.5013174995238967, 0.9454292659912409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 355}], {
             RGBColor[
             0.47377168673434356`, 0.583668224319027, 0.9517161891440508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 399}], {
             RGBColor[
             0.4021714167277014, 0.5226074330756187, 0.9468898028389996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 195}], {
             RGBColor[
             0.41896466743198113`, 0.5309879400615649, 0.9488739709755905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 242}], {
             RGBColor[
             0.40351340522649326`, 0.5184439093317198, 0.9476575910149361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 253}], {
             RGBColor[
             0.28665363911708575`, 0.4186215279754744, 0.939635872730437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 255}], {
             RGBColor[
             0.3378414626773269, 0.46375007884697717`, 0.9428685081307819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 283}], {
             RGBColor[
             0.456310023160806, 0.5613065822313281, 0.9518139341791091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 312}], {
             RGBColor[
             0.22834225396185226`, 0.35733256502196764`, 0.9363151256098103]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 332}], {
             RGBColor[
             0.2853106343123779, 0.41720994477430373`, 0.9395593905936066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 356}], {
             RGBColor[
             0.3474690518412523, 0.47208901268406805`, 0.9434819695989645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 360}], {
             RGBColor[
             0.3114347481117529, 0.44087790993034226`, 0.9411858956292044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 364}], {
             RGBColor[
             0.22839892224364028`, 0.35739212697910344`, 0.936318352784625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 380}], {
             RGBColor[
             0.2737066423730491, 0.40501341351048614`, 0.9388985604192295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 389}], {
             RGBColor[
             0.23074151749618907`, 0.35985434311864983`, 0.9364517601186986]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 221}], {
             RGBColor[
             0.3723885253546363, 0.49696595669585336`, 0.9449492454387219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 233}], {
             RGBColor[
             0.6755795410293652, 0.2607645283312454, 0.4248804276251915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 256}], {
             RGBColor[
             0.39070932980683426`, 0.5128345166819411, 0.9461166308979647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 316}], {
             RGBColor[
             0.3656366482661808, 0.491117820121043, 0.944519021801096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 399}], {
             RGBColor[
             0.3687090668542313, 0.493778994677764, 0.9447147935966935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 241}], {
             RGBColor[
             0.4492537790597021, 0.56051579472213, 0.9506833954078089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 242}], {
             RGBColor[
             0.5493481375009555, 0.6450245917316701, 0.9576658441940595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.4836761949517891, 0.5903307612469275, 0.9528767613099055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 263}], {
             RGBColor[
             0.48598356295597667`, 0.5923292874404669, 0.953023784758807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 312}], {
             RGBColor[
             0.37417698623631446`, 0.4839132474219179, 0.946323378788934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 356}], {
             RGBColor[
             0.4933037841157145, 0.5986696950840183, 0.953490222778088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 359}], {
             RGBColor[
             0.45397571595956177`, 0.564605699133339, 0.9509842730516231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 360}], {
             RGBColor[
             0.4572694803862151, 0.5674585923302926, 0.951194148808328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 380}], {
             RGBColor[
             0.4195413746475113, 0.5315940959104364, 0.948906813598353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 389}], {
             RGBColor[
             0.3765762497706513, 0.4864350255186002, 0.946460013297822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 206}], {
             RGBColor[
             0.4292170544081869, 0.5448428706494199, 0.9489419646459849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 214}], {
             RGBColor[
             0.4282177080250198, 0.5439772870409302, 0.9488782871781368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 286}], {
             RGBColor[
             0.4308670176223171, 0.5462719858559371, 0.9490470988429841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 332}], {
             RGBColor[
             0.400174196790433, 0.5186468362982314, 0.9471294798352238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 334}], {
             RGBColor[
             0.44626854573616764`, 0.5596120154048433, 0.9500284705953621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 366}], {
             RGBColor[
             0.5769966265208603, 0.667336425267016, 0.959934362421621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 386}], {
             RGBColor[
             0.43326964680715124`, 0.5483530224961863, 0.9492001922500801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 217}], {
             RGBColor[
             0.33502870252126793`, 0.4553625802568303, 0.9429473154981596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 231}], {
             RGBColor[
             0.45863478221376164`, 0.5713794033194408, 0.9505245565718823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 254}], {
             RGBColor[
             0.34954746226535555`, 0.47062271729040217`, 0.943774137387005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 314}], {
             RGBColor[
             0.37148140344577685`, 0.49367668016321836`, 0.9450232428888719]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 369}], {
             RGBColor[
             0.3827280420085152, 0.5054976103707267, 0.9456637223171092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 392}], {
             RGBColor[
             0.5610764902880233, 0.654235077355926, 0.9588018572059489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 203}], {
             RGBColor[
             0.39864923941408126`, 0.5197116673122781, 0.9466225549171521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 206}], {
             RGBColor[
             0.39590660699182256`, 0.5173361369568312, 0.9464477968044205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 214}], {
             RGBColor[
             0.39490726060865544`, 0.5164705533483416, 0.9463841193365723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 266}], {
             RGBColor[
             0.3736081454772735, 0.498022330346192, 0.9450269585544686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 310}], {
             RGBColor[
             0.3413856578637528, 0.46436101302399774`, 0.9431843723736055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 384}], {
             RGBColor[
             0.3331727639117327, 0.45572874075287223`, 0.9427166602129258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 215}], {
             RGBColor[
             0.3500634766975935, 0.46479920390114704`, 0.9443829853895969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 222}], {
             RGBColor[
             0.2196067980098868, 0.34815104695655513`, 0.935817654316295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 223}], {
             RGBColor[
             0.23518468326850744`, 0.3645243920583374, 0.9367047918363574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 224}], {
             RGBColor[
             0.4774821189814268, 0.5663257259749699, 0.9557249703954525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 247}], {
             RGBColor[
             0.3432484863067444, 0.45926648769003725`, 0.9438464843818968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 259}], {
             RGBColor[
             0.28039720859063844`, 0.4060703221380003, 0.9394983632959089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 271}], {
             RGBColor[
             0.27545708340458114`, 0.401791433999749, 0.9391835828874344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 287}], {
             RGBColor[
             0.306354379340215, 0.42855311879594743`, 0.941152331263047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 292}], {
             RGBColor[
             0.22578226524581724`, 0.3546418545687555, 0.9361693380395961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 345}], {
             RGBColor[
             0.2046269335439348, 0.3324062596245758, 0.9349645731956826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 350}], {
             RGBColor[
             0.20654228005577713`, 0.3344194102485051, 0.9350736493460308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 353}], {
             RGBColor[
             0.2179558396033256, 0.34641578499445047`, 0.9357236346774154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 393}], {
             RGBColor[
             0.3608550105803947, 0.47356025726026624`, 0.9452325344675421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 400}], {
             RGBColor[
             0.23121271414398153`, 0.3603496006710727, 0.9364785940707174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 234}], {
             RGBColor[
             0.4872661341795151, 0.5903991349449189, 0.9540831721556672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 296}], {
             RGBColor[
             0.5635854135641756, 0.6500203360482222, 0.9616899646805146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 298}], {
             RGBColor[
             0.4076470016585576, 0.5260980234057457, 0.9475846573961529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 320}], {
             RGBColor[
             0.6375638953173157, 0.7082298936994526, 0.9425802163964598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 330}], {
             RGBColor[
             0.26376460039457356`, 0.3944333967024469, 0.9383371467697441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 347}], {
             RGBColor[
             0.24994866895417567`, 0.3799119767779412, 0.9375503499130524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 367}], {
             RGBColor[
             0.35031995608036226`, 0.4778512711890203, 0.9435430557190347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 398}], {
             RGBColor[
             0.3540510311657668, 0.4810829408987113, 0.9437807965242166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 273}], {
             RGBColor[
             0.2844357668132493, 0.41629040356291636`, 0.9395095681837817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 281}], {
             RGBColor[
             0.3949551156959638, 0.5127826288094075, 0.946866725449057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 293}], {
             RGBColor[
             0.2607710241397998, 0.3914172585817747, 0.9381618960973782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 303}], {
             RGBColor[
             0.4178722125027617, 0.5313877604006121, 0.9486708432577797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 394}], {
             RGBColor[
             0.25511607245644247`, 0.3854735458179208, 0.9378398549647624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 212}], {
             RGBColor[
             0.22038190417682385`, 0.34896573268257547`, 0.9358617954658353]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 234}], {
             RGBColor[
             0.4444009111365761, 0.5454753680414677, 0.9516372901835307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 239}], {
             RGBColor[
             0.31698161640257116`, 0.44117921182137954`, 0.9417042183306334]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 269}], {
             RGBColor[
             0.20488596435198847`, 0.3326785174273421, 0.9349793246169995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 289}], {
             RGBColor[
             0.26992081803878515`, 0.40041751362316935`, 0.938705545873123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 309}], {
             RGBColor[
             0.26046788262573684`, 0.39109863763021235`, 0.93814463263661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 362}], {
             RGBColor[
             0.24876780262161294`, 0.37880111171795994`, 0.9374783303890923]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 365}], {
             RGBColor[
             0.5872576750222511, 0.6577566432288808, 0.9527300018492708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 206}], {
             RGBColor[
             0.35831968112500334`, 0.4847802309448167, 0.9440527911250002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 211}], {
             RGBColor[
             0.49889843484375435`, 0.6015622921983037, 0.9543863862070376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 216}], {
             RGBColor[
             0.28192360376204434`, 0.40881296027387726`, 0.9395436105025605]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 266}], {
             RGBColor[
             0.3360212196104543, 0.4654664243341774, 0.9426319528750484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 329}], {
             RGBColor[
             0.2907684938955194, 0.4181095006025842, 0.9400473139108195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 341}], {
             RGBColor[
             0.3928525903471295, 0.5146909012385379, 0.9462531975643815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 358}], {
             RGBColor[
             0.3792840561464048, 0.5029385188882284, 0.945388622563295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 229}], {
             RGBColor[
             0.32474738677024867`, 0.4474469393975825, 0.9422158376655967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 237}], {
             RGBColor[
             0.37417792224617075`, 0.49851584234559765`, 0.945063264226349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 307}], {
             RGBColor[
             0.38750381046560417`, 0.5100580569426543, 0.9459123780400711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 343}], {
             RGBColor[
             0.32240451650132634`, 0.4449844341983905, 0.9420824146697475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 232}], {
             RGBColor[
             0.27858189666561484`, 0.40688101365645946`, 0.9392954390625826]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 277}], {
             RGBColor[
             0.22165210924249457`, 0.350300798742248, 0.9359341317652252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 373}], {
             RGBColor[
             0.2614306409647742, 0.392025458015568, 0.938202576215585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 390}], {
             RGBColor[
             0.4740084474030028, 0.5670897590041984, 0.9548281776494338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 266}], {
             RGBColor[
             0.3332785871881956, 0.4630908939787306, 0.9424571947623167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 286}], {
             RGBColor[
             0.35722701191687484`, 0.483833815795887, 0.9439831672092677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 386}], {
             RGBColor[
             0.359629641101709, 0.4859148524361363, 0.9441362606163637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 231}], {
             RGBColor[
             0.3838851189631093, 0.5068024295540425, 0.9457153134068372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 280}], {
             RGBColor[
             0.315855660749067, 0.4480000307989024, 0.9413470212961044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 291}], {
             RGBColor[
             0.6247751721250895, 0.6986818303701563, 0.9640785302921195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 368}], {
             RGBColor[
             0.30620500248631966`, 0.4390567057053867, 0.9407534879968747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 372}], {
             RGBColor[
             0.24595632729396982`, 0.37573152809158783`, 0.937322415074598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 387}], {
             RGBColor[
             0.3891814958104324, 0.5111022668777573, 0.9461322635935261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 392}], {
             RGBColor[
             0.48632682703737096`, 0.5896581035905276, 0.9539926140409039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 221}], {
             RGBColor[
             0.35173743894108583`, 0.47907902359821897`, 0.9436333764734892]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 225}], {
             RGBColor[
             0.3783304253405996, 0.5021125318151178, 0.9453278580516117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 323}], {
             RGBColor[
             0.30644726966828084`, 0.4355378523208513, 0.9409054507651606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 351}], {
             RGBColor[
             0.3245853530999122, 0.4546021280284075, 0.9419383877837022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 388}], {
             RGBColor[
             0.3991114946400172, 0.5201120495553606, 0.9466520094113926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 395}], {
             RGBColor[
             0.3425426927901998, 0.4711149966237004, 0.9430474953793495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 286}], {
             RGBColor[
             0.4738480509580723, 0.5811659249913893, 0.9524307232318876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 290}], {
             RGBColor[
             0.5951616484765224, 0.682218063816785, 0.9612724515984765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 304}], {
             RGBColor[
             0.38387306339256977`, 0.4912314594901872, 0.9471370725287542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 338}], {
             RGBColor[
             0.5086817828757734, 0.6113371527842292, 0.9546502978274238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 386}], {
             RGBColor[
             0.47625068014290645`, 0.5832469616316385, 0.9525838166389837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 230}], {
             RGBColor[
             0.47701324133293876`, 0.5823759682958078, 0.9530669856585605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 258}], {
             RGBColor[
             0.45173952615262003`, 0.5559125401089146, 0.9516239923954006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 264}], {
             RGBColor[
             0.44121081638352055`, 0.5448461985828352, 0.9510243979498807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 279}], {
             RGBColor[
             0.5299071464437953, 0.6281900103778608, 0.9564373385199806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 328}], {
             RGBColor[
             0.5046106682424809, 0.6062794723978455, 0.9548254692977902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 394}], {
             RGBColor[
             0.435267092278153, 0.5385989676942197, 0.9506859116550319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 216}], {
             RGBColor[
             0.41975972505853665`, 0.5232194911719175, 0.9497024474718663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 238}], {
             RGBColor[
             0.5305473140061402, 0.6289749606098434, 0.9564030248012599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 341}], {
             RGBColor[
             0.5306887116436219, 0.6290974321365781, 0.9564120345336873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 358}], {
             RGBColor[
             0.5171201774428971, 0.6173450497862686, 0.9555474595326008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 239}], {
             RGBColor[
             0.3129386567940418, 0.4369298049343706, 0.9414739777619504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 289}], {
             RGBColor[
             0.26587785843025574`, 0.3961681067361603, 0.93847530530444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 309}], {
             RGBColor[
             0.25642492301720743`, 0.3868492307432033, 0.9379143920679269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 362}], {
             RGBColor[
             0.24472484301308356`, 0.374551704830951, 0.9372480898204094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 385}], {
             RGBColor[
             0.48957957933892293`, 0.5796782708985421, 0.9563130014727718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 215}], {
             RGBColor[
             0.3502316926313743, 0.4649760095130569, 0.9443925650381724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 227}], {
             RGBColor[
             0.28607242884284356`, 0.4110170181004443, 0.9398588443900017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 259}], {
             RGBColor[
             0.28056542452441924`, 0.40624712774991023`, 0.9395079429444844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 306}], {
             RGBColor[
             0.2932177135055341, 0.4172059045428174, 0.9403141356103812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 308}], {
             RGBColor[
             0.22181287368836833`, 0.350469772367916, 0.9359432870625879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 345}], {
             RGBColor[
             0.2047951494777156, 0.3325830652364857, 0.9349741528442581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 350}], {
             RGBColor[
             0.20671049598955793`, 0.3345962158604149, 0.9350832289946064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 378}], {
             RGBColor[
             0.27892045502731583`, 0.40482233785009014`, 0.9394031269427183]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 257}], {
             RGBColor[
             0.27679969476089683`, 0.40411935005480226`, 0.9392264760417168]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 310}], {
             RGBColor[
             0.3000567531915077, 0.42856399304804665`, 0.9405509311136054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 332}], {
             RGBColor[
             0.3255348447018236, 0.4553430826296917, 0.9420018707336593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 389}], {
             RGBColor[
             0.2709657278856348, 0.3979874809740378, 0.9388942402587512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 224}], {
             RGBColor[
             0.6401251838923967, 0.7168038155749654, 0.9661232685486777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 227}], {
             RGBColor[
             0.4485472778200328, 0.5613183020885298, 0.9502475628946514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 259}], {
             RGBColor[
             0.44304027350160846`, 0.5565484117379957, 0.9498966614491341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 345}], {
             RGBColor[
             0.3672699984549048, 0.48288434922457124`, 0.9453628713489078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 350}], {
             RGBColor[
             0.36918534496674715`, 0.4848974998485005, 0.9454719474992561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 353}], {
             RGBColor[
             0.38059890451429557`, 0.4968938745944459, 0.9461219328306407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 393}], {
             RGBColor[
             0.5234980754913647, 0.6240383468602617, 0.9556308326207674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 400}], {
             RGBColor[
             0.3938557790549515, 0.5108276902710681, 0.9468768922239427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 229}], {
             RGBColor[
             0.2111248436873392, 0.33923597517659243`, 0.9353346195655527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 294}], {
             RGBColor[
             0.24053989082625093`, 0.37015305474129584`, 0.9370097629844512]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 329}], {
             RGBColor[
             0.2116297841103017, 0.339766699576198, 0.935363375175648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 340}], {
             RGBColor[
             0.2701406976436648, 0.39860719922021814`, 0.9387928141439121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 341}], {
             RGBColor[
             0.3137138805619118, 0.43634810021215165`, 0.94156925882921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 343}], {
             RGBColor[
             0.20878197341841687`, 0.33677346997740043`, 0.9352011965697036]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 358}], {
             RGBColor[
             0.3001453463611871, 0.42459571786184214`, 0.9407046838281236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 231}], {
             RGBColor[
             0.3341792579165282, 0.45467296285965925`, 0.9428804441072562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 254}], {
             RGBColor[
             0.22509193796812216`, 0.35391627683062055`, 0.9361300249223791]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 314}], {
             RGBColor[
             0.24702587914854346`, 0.37697023970343674`, 0.9373791304242459]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 331}], {
             RGBColor[
             0.312026021155332, 0.43560624132103987`, 0.941435344260749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 392}], {
             RGBColor[
             0.4366209659907899, 0.5375286368961443, 0.9511577447413229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 222}], {
             RGBColor[
             0.31195343455507263`, 0.4393544416499816, 0.9412911771213686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 276}], {
             RGBColor[
             0.3632263544389204, 0.4890301447527602, 0.9443654400097621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 282}], {
             RGBColor[
             0.3182825686479689, 0.44600676287189456`, 0.9416516119448441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 305}], {
             RGBColor[
             0.30949175418355857`, 0.4367670594999701, 0.9411509880659406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 339}], {
             RGBColor[
             0.3278870924576679, 0.4561017263578697, 0.9421985753671869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 361}], {
             RGBColor[
             0.46379406804875556`, 0.5733630564422509, 0.9515399314490043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 382}], {
             RGBColor[
             0.3089767140975055, 0.43622571971410073`, 0.9411216572949733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 384}], {
             RGBColor[
             0.30111152370978, 0.4279589059347282, 0.9406737463378989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 248}], {
             RGBColor[
             0.32960580130796513`, 0.45705607997127173`, 0.9423276535209995]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 251}], {
             RGBColor[
             0.2299375141707376, 0.35900928464684523`, 0.9364059733187304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 260}], {
             RGBColor[
             0.6251493525479173, 0.6941754194220426, 0.935355507402357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 352}], {
             RGBColor[
             0.2817937226567562, 0.4135134476391673, 0.9393591076776234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 396}], {
             RGBColor[
             0.3269402558281526, 0.4547855365349702, 0.9421564079688002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 256}], {
             RGBColor[
             0.370997232073375, 0.49576088838405835`, 0.9448605934611123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 316}], {
             RGBColor[
             0.3459245505327215, 0.47404419182316015`, 0.9432629843642436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 351}], {
             RGBColor[
             0.3255243417800034, 0.45541543282815916`, 0.9419982193120824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 399}], {
             RGBColor[
             0.348996969120772, 0.4767053663798812, 0.9434587561598411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 223}], {
             RGBColor[
             0.26737106949177075`, 0.3983543247137409, 0.9385377589162809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 224}], {
             RGBColor[
             0.5096685052046901, 0.6001556586303735, 0.9575579374753759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 247}], {
             RGBColor[
             0.3754348725300077, 0.49309642034544077`, 0.9456794514618203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 259}], {
             RGBColor[
             0.31258359481390174`, 0.4399002547934039, 0.9413313303758323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 292}], {
             RGBColor[
             0.25796865146908055`, 0.38847178722415904`, 0.9380023051195197]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 363}], {
             RGBColor[
             0.2469679560201281, 0.37690935882293375`, 0.9373758317877723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 383}], {
             RGBColor[
             0.28826460329941417`, 0.41883636665160845`, 0.939781745740969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 393}], {
             RGBColor[
             0.39304139680365796`, 0.5073901899156698, 0.9470655015474656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 247}], {
             RGBColor[
             0.3910127577886283, 0.509469765447223, 0.9465665889818827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 292}], {
             RGBColor[
             0.2735465367277012, 0.4048451323259413, 0.938889442639582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 319}], {
             RGBColor[
             0.4425096048654805, 0.551277225810735, 0.950620609422939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 385}], {
             RGBColor[
             0.5228845844299714, 0.6146839429085205, 0.9582096722423673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 393}], {
             RGBColor[
             0.4086192820622786, 0.523763535017452, 0.9479526390675279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 400}], {
             RGBColor[
             0.2789769856258655, 0.4105528784282585, 0.9391986986707033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 227}], {
             RGBColor[
             0.575965920103866, 0.6628448241623528, 0.961589547900507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 259}], {
             RGBColor[
             0.5704589157854416, 0.6580749338118187, 0.9612386464549897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 363}], {
             RGBColor[
             0.504843276991668, 0.5950840378413486, 0.9572831478669297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 383}], {
             RGBColor[
             0.5461399242709541, 0.6370110456700233, 0.9596890618201264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 393}], {
             RGBColor[
             0.6509167177751979, 0.7255648689340846, 0.966972817626623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 235}], {
             RGBColor[
             0.4576560830100148, 0.5692963204264649, 0.9508035346817825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 261}], {
             RGBColor[
             0.39971211108619364`, 0.5206322733331783, 0.9466902801602386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 322}], {
             RGBColor[
             0.41545525660529636`, 0.5342681947083241, 0.9476934194715989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 327}], {
             RGBColor[
             0.331230402624273, 0.45649545797892793`, 0.9425032213792711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 335}], {
             RGBColor[
             0.3937084731247739, 0.5154322238826143, 0.9463077336581456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 349}], {
             RGBColor[
             0.38954217084985654`, 0.511823582256522, 0.9460422605613042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 355}], {
             RGBColor[
             0.44719022552692783`, 0.5607996658401883, 0.9499796240430147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 252}], {
             RGBColor[
             0.4756838782955016, 0.5814550101137455, 0.9529071751916094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 274}], {
             RGBColor[
             0.5363989271532489, 0.6340433338072405, 0.9567758844166154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 288}], {
             RGBColor[
             0.5044138907176686, 0.6063395028614156, 0.9547378261781974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 315}], {
             RGBColor[
             0.45765815176223024`, 0.5630531405365373, 0.9518607068069436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 318}], {
             RGBColor[
             0.5770309900669242, 0.6674987785430198, 0.9598451397536829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 322}], {
             RGBColor[
             0.5308913344653174, 0.6292729338406118, 0.9564249454807134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 243}], {
             RGBColor[
             0.335978865758314, 0.4634718475494626, 0.9427009421423805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 306}], {
             RGBColor[
             0.3915332986941925, 0.5135481971182904, 0.94616913346686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 311}], {
             RGBColor[
             0.29442144267612425`, 0.4197923609972736, 0.9403343083765479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 346}], {
             RGBColor[
             0.5704309180390463, 0.6585208384817418, 0.9610378706222209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 350}], {
             RGBColor[
             0.3050260811782164, 0.4309385084358879, 0.9409382268510853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 363}], {
             RGBColor[
             0.31326537091930406`, 0.43959852435491303`, 0.9414074422129033]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 383}], {
             RGBColor[
             0.3545620181985901, 0.48152553218358773`, 0.9438133561661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 276}], {
             RGBColor[
             0.2973738143151533, 0.4256737252209799, 0.9404007168013852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 282}], {
             RGBColor[
             0.2524300285242019, 0.3826503433401143, 0.9376868887364671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 301}], {
             RGBColor[
             0.32589852419997145`, 0.45038039522960405`, 0.9422182860918352]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 305}], {
             RGBColor[
             0.24363921405979153`, 0.3734106399681898, 0.9371862648575635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 382}], {
             RGBColor[
             0.24312417397373845`, 0.37286930018232045`, 0.9371569340865964]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 294}], {
             RGBColor[
             0.24887984053676349`, 0.37891887067039726`, 0.937484710782615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 307}], {
             RGBColor[
             0.28222121709320724`, 0.41061290865076566`, 0.939506107738191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[
             0.21996973382081428`, 0.3485325155052994, 0.9358383229738119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 340}], {
             RGBColor[
             0.2784806473541773, 0.40737301514931956`, 0.939267761942076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 343}], {
             RGBColor[
             0.21712192312892942`, 0.34553928590650185`, 0.9356761443678674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 258}], {
             RGBColor[
             0.2845630523803121, 0.4163233398505535, 0.9395205094812755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 264}], {
             RGBColor[
             0.2740343426112126, 0.4052569983244742, 0.9389209150357556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 279}], {
             RGBColor[
             0.3627306726714874, 0.4886008101194998, 0.9443338556058556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 299}], {
             RGBColor[
             0.37753740854427503`, 0.5014256605243246, 0.9452773277225871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 300}], {
             RGBColor[
             0.5277047208948156, 0.6219765373990599, 0.9581194386024787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 328}], {
             RGBColor[
             0.33743419447017303`, 0.4666902721394844, 0.9427219863836651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 331}], {
             RGBColor[
             0.43563210084782567`, 0.5516230643836504, 0.9490125853344719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 369}], {
             RGBColor[
             0.38187859740377544`, 0.5048079929735556, 0.9455968509262058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 372}], {
             RGBColor[
             0.31985654593988244`, 0.4396188844598151, 0.94206478684874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 392}], {
             RGBColor[
             0.5602270456832836, 0.6535454599587549, 0.9587349858150457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 277}], {
             RGBColor[
             0.2870391499656852, 0.4157701230956633, 0.9397770671266366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 373}], {
             RGBColor[
             0.3268176816879649, 0.4574947823689832, 0.9420455115769965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 390}], {
             RGBColor[
             0.5393954881261934, 0.6325590833576137, 0.9586711130108453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 256}], {
             RGBColor[
             0.674652012175191, 0.25996114945671533`, 0.42482132630678504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 257}], {
             RGBColor[
             0.6115530111951278, 0.19860638891240467`, 0.42104609133562043`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 310}], {
             RGBColor[
             0.6270577168155351, 0.21490281757456758`, 0.42192906138354613`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 316}], {
             RGBColor[
             0.6579368911480887, 0.2454833517494499, 0.42375625357553925`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 389}], {
             RGBColor[
             0.6076636999449531, 0.19451847619189505`, 0.42082460081364337`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 298}], {
             RGBColor[
             0.5847578259668416, 0.6734344849741778, 0.960684029573029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 365}], {
             RGBColor[
             0.807233722373474, 0.8500168717007641, 0.9682752559982832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 261}], {
             RGBColor[
             0.45150579367600396`, 0.5639692489278748, 0.9504116436839067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 322}], {
             RGBColor[
             0.46724893919510674`, 0.5776051703030205, 0.9514147829952669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 327}], {
             RGBColor[
             0.3830240852140834, 0.4998324335736244, 0.9462245849029391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 335}], {
             RGBColor[
             0.4455021557145843, 0.5587691994773107, 0.9500290971818136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 349}], {
             RGBColor[
             0.4413358534396669, 0.5551605578512184, 0.9497636240849723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 355}], {
             RGBColor[
             0.4989839081167382, 0.6041366414348848, 0.9537009875666829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 262}], {
             RGBColor[
             0.3157336806752364, 0.4400983126174356, 0.9416247009695938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 284}], {
             RGBColor[
             0.2517723519562516, 0.3819590835680957, 0.9376494350288677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 334}], {
             RGBColor[
             0.30705244757202965`, 0.4325790648349006, 0.9410715404727705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 366}], {
             RGBColor[
             0.4377805283567223, 0.5403034746970732, 0.9509774322990294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 376}], {
             RGBColor[
             0.21934103704797048`, 0.3478717153353629, 0.9358025196226719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 397}], {
             RGBColor[
             0.2725359751718354, 0.4026826312901981, 0.9388721813731482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 307}], {
             RGBColor[
             0.33165175256912927`, 0.4616818115987808, 0.9423535342989433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 324}], {
             RGBColor[
             0.32134165097449113`, 0.4527517197982787, 0.9416965837421978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 269}], {
             RGBColor[
             0.29744271696920643`, 0.42064258967913726`, 0.9405915069131147]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 309}], {
             RGBColor[
             0.35302463524295474`, 0.47906270988200744`, 0.9437568149327251]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 323}], {
             RGBColor[
             0.3358172290476781, 0.46097663495820496`, 0.9427768786059805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 362}], {
             RGBColor[
             0.3413245552388309, 0.4667651839697551, 0.9430905126852076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 365}], {
             RGBColor[
             0.6798144276394691, 0.745720715480676, 0.958342184145386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 377}], {
             RGBColor[
             0.3922194632505078, 0.5141425183693373, 0.946212855265637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 385}], {
             RGBColor[
             0.5861792915646703, 0.6718917500373462, 0.96215542433757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 388}], {
             RGBColor[
             0.42848145401941445`, 0.5455508321927143, 0.9485234372522124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 272}], {
             RGBColor[
             0.37221558510408403`, 0.4968161645430547, 0.9449382258388819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 342}], {
             RGBColor[
             0.4989628499126453, 0.6012153118813831, 0.9545385225892289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 374}], {
             RGBColor[
             0.4103724681030394, 0.5293838409096385, 0.9475026984990728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 242}], {
             RGBColor[
             0.4338025168542142, 0.5479717639922849, 0.9494670154471545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 255}], {
             RGBColor[
             0.3681305743050479, 0.49327793350754223`, 0.9446779325630004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 312}], {
             RGBColor[
             0.2586313655895732, 0.3868604196825327, 0.9381245500420289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 331}], {
             RGBColor[
             0.37359351124979523`, 0.49800965491388793`, 0.9450260260744343]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 359}], {
             RGBColor[
             0.33843009531282053`, 0.46755287139395385`, 0.9427854443047181]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 360}], {
             RGBColor[
             0.34172385973947395`, 0.4704057645909074, 0.942995320061423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 380}], {
             RGBColor[
             0.30399575400077006`, 0.4345412681710512, 0.9407079848514479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 392}], {
             RGBColor[
             0.4981884560852531, 0.5999320504889923, 0.9547484265550081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 255}], {
             RGBColor[
             0.4682249327463012, 0.5777867305170824, 0.951660381349251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 312}], {
             RGBColor[
             0.3587257240308266, 0.4713692166920729, 0.9451069988282795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 331}], {
             RGBColor[
             0.47368786969104854`, 0.5825184519234281, 0.952008474860685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 380}], {
             RGBColor[
             0.4040901124420234, 0.5190500651805914, 0.9476904336376986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 267}], {
             RGBColor[
             0.42448784718861415`, 0.5371990366859427, 0.9491515617592661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 275}], {
             RGBColor[
             0.32462319425658054`, 0.4536361356473061, 0.9419773687957161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 311}], {
             RGBColor[
             0.2460122944029362, 0.37590489787081893`, 0.9373214082724479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 326}], {
             RGBColor[
             0.29218434162830254`, 0.424434646981556, 0.9399508380565098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 344}], {
             RGBColor[
             0.23749506463587472`, 0.3669527493620798, 0.936836364637326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 346}], {
             RGBColor[
             0.5220217697658582, 0.6146333753552872, 0.9580249705181207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 363}], {
             RGBColor[
             0.264856222646116, 0.39571106122845834`, 0.9383945421088034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 383}], {
             RGBColor[
             0.3061528699254021, 0.4376380690571331, 0.940800456062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 302}], {
             RGBColor[
             0.3779416276560085, 0.49557206122866065`, 0.94583669133981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 352}], {
             RGBColor[
             0.26142119354332916`, 0.39210062784800515`, 0.9381989222830698]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 396}], {
             RGBColor[
             0.30656772671472565`, 0.43337271674380806`, 0.9409962225742465]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 248}], {
             RGBColor[
             0.41796737073593915`, 0.5364091257303325, 0.9478631420767304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 251}], {
             RGBColor[
             0.31829908359871156`, 0.438362330405906, 0.9419414618744615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 260}], {
             RGBColor[
             0.7135109219758913, 0.7735284651811034, 0.940890995958088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 326}], {
             RGBColor[
             0.37570181546045467`, 0.498696241136008, 0.9452104625342559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 271}], {
             RGBColor[
             0.431285157924702, 0.5467368073886346, 0.9490453800329597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 287}], {
             RGBColor[
             0.46218245386033585`, 0.5734984921848331, 0.9510141284085722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 292}], {
             RGBColor[
             0.3816103397659381, 0.49958722795764116`, 0.9460311351851214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 319}], {
             RGBColor[
             0.5505734079037174, 0.6460193214424348, 0.9577623019684784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 362}], {
             RGBColor[
             0.38609365114236893`, 0.5042994724726292, 0.9462864531355444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 385}], {
             RGBColor[
             0.6309483874682084, 0.7094260385402202, 0.9653513647879067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 393}], {
             RGBColor[
             0.5166830851005155, 0.6185056306491519, 0.9550943316130673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 400}], {
             RGBColor[
             0.3870407886641024, 0.5052949740599584, 0.9463403912162427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 251}], {
             RGBColor[
             0.2816617891852205, 0.40666388340432646`, 0.9395973129574189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 260}], {
             RGBColor[
             0.6768736275624003, 0.7418300181795239, 0.9385468470410454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 275}], {
             RGBColor[
             0.3715033736752416, 0.49619928280017866`, 0.9448928443564198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 268}], {
             RGBColor[
             0.3051594481305492, 0.42687959183385743`, 0.941099571292759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 279}], {
             RGBColor[
             0.42271469726861943`, 0.5405559573407976, 0.9481559846113945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 299}], {
             RGBColor[
             0.437521433141407, 0.5533808077456224, 0.9490994567281261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 300}], {
             RGBColor[
             0.5876887454919476, 0.6739316846203577, 0.9619415676080177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 370}], {
             RGBColor[
             0.4255276131019811, 0.5429923636543948, 0.9483352211209325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 265}], {
             RGBColor[
             0.3585695735565054, 0.4839714522251082, 0.9441062524853845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 321}], {
             RGBColor[
             0.3408713580680569, 0.4653695056150755, 0.9430983652954807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 325}], {
             RGBColor[
             0.34926109109586634`, 0.4741876469671006, 0.9435761481799168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 375}], {
             RGBColor[
             0.3420783120310039, 0.46663809075543405`, 0.9431670995381423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 381}], {
             RGBColor[
             0.389953029298989, 0.5121794471948143, 0.9460684400983751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 260}], {
             RGBColor[
             0.5772053404251727, 0.6437832228550975, 0.9326251668387765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 275}], {
             RGBColor[
             0.271835086538014, 0.39815248747575216`, 0.9389711641541509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 274}], {
             RGBColor[
             0.3753482493085038, 0.4995295208246421, 0.9451378364318812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 288}], {
             RGBColor[
             0.34336321287292354`, 0.4718256898788172, 0.9430997781934634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 318}], {
             RGBColor[
             0.415980312222179, 0.5329849655604213, 0.9482070917689487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 283}], {
             RGBColor[
             0.46983372712037275`, 0.5755208525451879, 0.9525840891130792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 332}], {
             RGBColor[
             0.29883433827194467`, 0.4314242150881636, 0.9403295455275767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 334}], {
             RGBColor[
             0.34492868721767933`, 0.4723893941947755, 0.9432285362877151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 364}], {
             RGBColor[
             0.24192262620320706`, 0.3716063972929633, 0.9370885077185952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 366}], {
             RGBColor[
             0.4756567680023719, 0.5801138040569481, 0.953134428113974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 391}], {
             RGBColor[
             0.3742930086491344, 0.4978232935249932, 0.9450996048834774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 314}], {
             RGBColor[
             0.2615446388926311, 0.39223037673700867`, 0.9382059523130915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 369}], {
             RGBColor[
             0.2727912774553694, 0.40405130694451696`, 0.9388464317413286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 312}], {
             RGBColor[
             0.2930537814816602, 0.41667538620733025`, 0.9403179159441255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 331}], {
             RGBColor[
             0.4080159271418822, 0.5278246214386855, 0.9472193919765308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 356}], {
             RGBColor[
             0.4121805793610603, 0.5314318338694306, 0.9474847599332795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 359}], {
             RGBColor[
             0.3728525112049075, 0.4973678379187514, 0.9449788102068146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 360}], {
             RGBColor[
             0.3761462756315609, 0.5002207311157049, 0.9451886859635195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 380}], {
             RGBColor[
             0.33841816989285706`, 0.46435623469584875`, 0.9429013507535445]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 310}], {
             RGBColor[
             0.31792659348608904`, 0.44404195054692447`, 0.9416895815354969]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 316}], {
             RGBColor[
             0.36424535498491944`, 0.489912751809248, 0.9444303698234864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 319}], {
             RGBColor[
             0.4956941457530713, 0.5997281150880465, 0.9539221506649449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 384}], {
             RGBColor[
             0.3097136995340689, 0.43540967827579896`, 0.9412218693748171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 310}], {
             RGBColor[
             0.22327809201599425`, 0.3520098097304584, 0.9360267290787501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 356}], {
             RGBColor[
             0.31091460105518454`, 0.4336679672218678, 0.9414002477041618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 360}], {
             RGBColor[
             0.27488029732568514`, 0.402456864468142, 0.9391041737344017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 389}], {
             RGBColor[
             0.1941870667101213, 0.32143329765644957`, 0.9343700382238957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 264}], {
             RGBColor[
             0.24876062743089394`, 0.3787935701375809, 0.9374779217725957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 279}], {
             RGBColor[
             0.3374569574911687, 0.4621373819326065, 0.9428908623426956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 281}], {
             RGBColor[
             0.38265594656504776`, 0.49985542224045204`, 0.9461663059620415]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 300}], {
             RGBColor[
             0.502431005714497, 0.5955131092121666, 0.9566764453393188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 328}], {
             RGBColor[
             0.31216047928985435`, 0.4402268439525911, 0.9412789931205052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 394}], {
             RGBColor[
             0.24281690332552638`, 0.3725463392489653, 0.9371394354777469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 271}], {
             RGBColor[
             0.368433880208596, 0.49354064183659774`, 0.9446972589469718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 287}], {
             RGBColor[
             0.39933117614422986`, 0.5203023266327962, 0.9466660073225842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 292}], {
             RGBColor[
             0.3187590620498322, 0.4463910624056042, 0.9416830140991335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 345}], {
             RGBColor[
             0.2976037303479497, 0.4241554674614245, 0.9404782492552198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 350}], {
             RGBColor[
             0.29951907685979207`, 0.4261686180853538, 0.9405873254055681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 353}], {
             RGBColor[
             0.3109326364073405, 0.43816499283129917`, 0.9412373107369527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 393}], {
             RGBColor[
             0.45383180738440954`, 0.565309465097115, 0.9507462105270794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 400}], {
             RGBColor[
             0.3241895109479964, 0.45209880850792145`, 0.9419922701302547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 327}], {
             RGBColor[
             0.3250801132902622, 0.45116838648033786`, 0.9421113303813953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 335}], {
             RGBColor[
             0.3875581837907631, 0.5101051523840242, 0.9459158426602696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 349}], {
             RGBColor[
             0.3833918815158458, 0.5064965107579319, 0.9456503695634284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 355}], {
             RGBColor[
             0.44103993619291704`, 0.5554725943415981, 0.949587733045139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 284}], {
             RGBColor[
             0.3430811688461347, 0.4688422566159468, 0.9431820999639433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 325}], {
             RGBColor[
             0.34304143306113943`, 0.4688004917865225, 0.9431798370697717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 376}], {
             RGBColor[
             0.3106498539378536, 0.434754888383214, 0.9413351845577476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 397}], {
             RGBColor[
             0.36384479206171855`, 0.48956580433804925`, 0.944404846308224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 336}], {
             RGBColor[
             0.29484867463317666`, 0.41813526883792984`, 0.9404357547083059]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 359}], {
             RGBColor[
             0.3751598792090951, 0.49936636411229074`, 0.945125833655716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 360}], {
             RGBColor[
             0.37845364363574846`, 0.5022192573092442, 0.9453357094124208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 279}], {
             RGBColor[
             0.32692824772206924`, 0.45107104040652723`, 0.9422912678971757]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 281}], {
             RGBColor[
             0.3721272367959483, 0.48878908071437277`, 0.9455667115165216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 328}], {
             RGBColor[
             0.3016317695207549, 0.4291605024265118, 0.9406793986749853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 394}], {
             RGBColor[
             0.2322881935564269, 0.361479997722886, 0.936539841032227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 321}], {
             RGBColor[
             0.27995911798998896`, 0.4115851618137407, 0.9392546296559054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 325}], {
             RGBColor[
             0.2883488510177984, 0.4204033031657658, 0.9397324125403415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 375}], {
             RGBColor[
             0.28116607195293597`, 0.41285374695409927`, 0.939323363898567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 381}], {
             RGBColor[
             0.32904078922092106`, 0.45839510339347955`, 0.9422247044587997]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 358}], {
             RGBColor[
             0.35424296220959706`, 0.4812491819221423, 0.9437930262006116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 384}], {
             RGBColor[
             0.2705447441081057, 0.40148349777477155`, 0.9387260581708221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 275}], {
             RGBColor[
             0.46154132396006875`, 0.5712507879102409, 0.9514408885167018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 306}], {
             RGBColor[
             0.4800422801244927, 0.5872753862547705, 0.9526197530837457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 311}], {
             RGBColor[
             0.3829304241064244, 0.4935195501337537, 0.9467849279934335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 317}], {
             RGBColor[
             0.404948622156065, 0.5166620723183134, 0.9480388317993556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 344}], {
             RGBColor[
             0.37441319433936293`, 0.48456740162501455`, 0.9462998843583117]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 346}], {
             RGBColor[
             0.6589398994693465, 0.7322480276182219, 0.9674884902391064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 354}], {
             RGBColor[
             0.4510427639766694, 0.5621574629255879, 0.9507719295580717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 279}], {
             RGBColor[
             0.29806932864427377`, 0.42073848669461267`, 0.94064779514864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 299}], {
             RGBColor[
             0.3128760645170614, 0.4335633370994375, 0.9415912672653717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 300}], {
             RGBColor[
             0.463043376867602, 0.5541142139741728, 0.9544333781452633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 370}], {
             RGBColor[
             0.30088224447763545`, 0.42317489300820993`, 0.940827031658178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 371}], {
             RGBColor[
             0.18766174953560366`, 0.31457477557702684`, 0.9339984310641487]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 309}], {
             RGBColor[
             0.24092898319237202`, 0.37056201548796996`, 0.9370319212190912]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 323}], {
             RGBColor[
             0.22372157699709533`, 0.35247594056416753`, 0.9360519848923465]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 362}], {
             RGBColor[
             0.22922890318824815`, 0.35826448957571766`, 0.9363656189715737]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 365}], {
             RGBColor[
             0.5677187755888864, 0.6372200210866386, 0.951617290431752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 377}], {
             RGBColor[
             0.28012381119992513`, 0.4056418239752999, 0.9394879615520031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 388}], {
             RGBColor[
             0.3163858019688317, 0.43705013779867685`, 0.9417985435385785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 336}], {
             RGBColor[
             0.2018795970887927, 0.32951863481902943`, 0.9348081164488823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 357}], {
             RGBColor[
             0.22786066989748896`, 0.35682638963612856`, 0.9362877001097847]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 287}], {
             RGBColor[
             0.3943910509581726, 0.5160234384945448, 0.9463512269141099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 292}], {
             RGBColor[
             0.3138189368637749, 0.4421121742673529, 0.941368233690659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 303}], {
             RGBColor[
             0.4576752522831183, 0.5681614748489996, 0.9511229049309551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 333}], {
             RGBColor[
             0.3574227282407705, 0.48400333543865703`, 0.9439956380803612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 337}], {
             RGBColor[
             0.3604115866939054, 0.4865921344063686, 0.9441860854980513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 345}], {
             RGBColor[
             0.2926636051618924, 0.4198765793231732, 0.9401634688467455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 353}], {
             RGBColor[
             0.30599251122128324`, 0.43388610469304784`, 0.9409225303284783]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 385}], {
             RGBColor[
             0.5631569845660451, 0.6519509848499321, 0.9606884632934443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 391}], {
             RGBColor[
             0.4059512146220775, 0.5260362712294993, 0.9470878303205226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 400}], {
             RGBColor[
             0.3192493857619392, 0.4478199203696701, 0.9416774897217803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 308}], {
             RGBColor[
             0.32531053305991664`, 0.45130051714198655`, 0.9421284821036724]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 342}], {
             RGBColor[
             0.521499427205843, 0.6207353624114409, 0.9559745333660385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 348}], {
             RGBColor[
             0.3308076855780118, 0.45707837297810494`, 0.9424415368072695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 374}], {
             RGBColor[
             0.4329090453962371, 0.5489038914396962, 0.9489387092758825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 375}], {
             RGBColor[
             0.3297134864123581, 0.45592830027876874`, 0.9423792237835081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 378}], {
             RGBColor[
             0.38241811439886414`, 0.5056530826241608, 0.9455883219838028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 281}], {
             RGBColor[
             0.3955032070473875, 0.5133587075707526, 0.946897938440692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 293}], {
             RGBColor[
             0.26131911549122355`, 0.3919933373431198, 0.9381931090890132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 394}], {
             RGBColor[
             0.25566416380786616`, 0.38604962457926595`, 0.9378710679563974]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 288}], {
             RGBColor[
             0.4040782617306708, 0.5244140135723123, 0.9469684874184693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 318}], {
             RGBColor[
             0.47669536107992627`, 0.5855732892539163, 0.9520758009939547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 311}], {
             RGBColor[
             0.2830657711743908, 0.40995664909511714`, 0.9396107350298835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 317}], {
             RGBColor[
             0.30508396922403136`, 0.43309917127967684`, 0.9408646388358055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 344}], {
             RGBColor[
             0.2745485414073293, 0.401004500586378, 0.9391256913947617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 346}], {
             RGBColor[
             0.5590752465373128, 0.6486851265795854, 0.9603142972755565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 282}], {
             RGBColor[
             0.3093952382098941, 0.4383090039366502, 0.9410853191080877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 301}], {
             RGBColor[
             0.38286373388566375`, 0.50603905582614, 0.9456167164634558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 305}], {
             RGBColor[
             0.3006044237454838, 0.4290693005647257, 0.9405846952291841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 339}], {
             RGBColor[
             0.3189997620195931, 0.4484039674226253, 0.9416322825304304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 361}], {
             RGBColor[
             0.45490673761068084`, 0.5656652975070066, 0.9509736386122478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 382}], {
             RGBColor[
             0.3000893836594307, 0.42852796077885635`, 0.940555364458217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 373}], {
             RGBColor[
             0.26988789426484455`, 0.4009145674547718, 0.9386842042796391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 390}], {
             RGBColor[
             0.48246570070307315`, 0.5759788684434022, 0.9553098057134879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 296}], {
             RGBColor[
             0.5914062928067927, 0.6741173833301285, 0.9634626865048166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 302}], {
             RGBColor[
             0.43310197129425343`, 0.5482743186857402, 0.9491711261495857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 330}], {
             RGBColor[
             0.2915854796371907, 0.4185304439843533, 0.9401098685940461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 367}], {
             RGBColor[
             0.3781408353229795, 0.5019483184709267, 0.9453157775433367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 299}], {
             RGBColor[
             0.43043131365513165`, 0.5472397026063777, 0.9486476805840072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 300}], {
             RGBColor[
             0.5805986260056722, 0.667790579481113, 0.9614897914638988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 328}], {
             RGBColor[
             0.39032809958102965`, 0.5125043142215374, 0.9460923392450851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 370}], {
             RGBColor[
             0.4184374936157057, 0.5368512585151501, 0.9478834449768135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 371}], {
             RGBColor[
             0.3052169986736739, 0.428251141083967, 0.9410548443827842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 291}], {
             RGBColor[
             0.6306459325569599, 0.7037667879832434, 0.9644526099555286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 336}], {
             RGBColor[
             0.25212802212089036`, 0.3811327868342154, 0.9377136325066127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 368}], {
             RGBColor[
             0.31207576291819006`, 0.44414166331847393`, 0.9411275676602839]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 387}], {
             RGBColor[
             0.3950522562423028, 0.5161872244908445, 0.9465063432569352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 392}], {
             RGBColor[
             0.49219758746924136`, 0.5947430612036149, 0.9543666937043129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 293}], {
             RGBColor[
             0.3718384643739381, 0.488485562589611, 0.9455502663542885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 394}], {
             RGBColor[
             0.3661835126905807, 0.48254184982575715`, 0.9452282252216727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 301}], {
             RGBColor[
             0.33791994809471226`, 0.4630156739452743, 0.9429028883985378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 305}], {
             RGBColor[
             0.2556606379545323, 0.38604591868386007`, 0.937870867164266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 313}], {
             RGBColor[
             0.32353113756660135`, 0.4505528094684698, 0.9419860461152121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 339}], {
             RGBColor[
             0.2740559762286417, 0.4053805855417597, 0.9389184544655124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 340}], {
             RGBColor[
             0.3009739768647228, 0.4310149306243649, 0.9405487237818024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 361}], {
             RGBColor[
             0.4099629518197294, 0.5226419156261409, 0.9482598105473299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 382}], {
             RGBColor[
             0.25514559786847923`, 0.3855045788979907, 0.9378415363932988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 312}], {
             RGBColor[
             0.4115223419651393, 0.5142318895916811, 0.9492633419924525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 332}], {
             RGBColor[
             0.4684907223156649, 0.5741092693440173, 0.9525076069762488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 334}], {
             RGBColor[
             0.5145850712613995, 0.6150744484506292, 0.955406597736387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 356}], {
             RGBColor[
             0.5306491398445394, 0.6289883372537816, 0.9564301859816067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 360}], {
             RGBColor[
             0.49461483611504, 0.5977772345000558, 0.9541341120118466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 364}], {
             RGBColor[
             0.41157901024692733`, 0.514291451548817, 0.9492665691672673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 366}], {
             RGBColor[
             0.6453131520460922, 0.7227988583128018, 0.965312489562646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 380}], {
             RGBColor[
             0.45688673037633615`, 0.5619127380801996, 0.9518467768018717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 389}], {
             RGBColor[
             0.4139216054994761, 0.5167536676883634, 0.9493999765013408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 334}], {
             RGBColor[
             0.33439993574292803`, 0.4613230088334118, 0.94262893946712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 366}], {
             RGBColor[
             0.4651280165276206, 0.5690474186955845, 0.952534831293379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 397}], {
             RGBColor[
             0.29988346334273375`, 0.4314265752887094, 0.9404295803674978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 324}], {
             RGBColor[
             0.29159155852494356`, 0.4223682102831413, 0.9399699292971911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 290}], {
             RGBColor[
             0.48019057264945514`, 0.5863150698277999, 0.9529300297728558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 304}], {
             RGBColor[
             0.26890198756550254`, 0.3953284655012021, 0.9387946507031335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 386}], {
             RGBColor[
             0.36127960431583916`, 0.4873439676426534, 0.944241394813363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 292}], {
             RGBColor[
             0.34471623279940866`, 0.46887385906355133`, 0.9433369820662716]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 303}], {
             RGBColor[
             0.48857254821875207`, 0.594923159645198, 0.9530916533065676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 353}], {
             RGBColor[
             0.336889807156917, 0.4606477894892463, 0.9428912787040908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 385}], {
             RGBColor[
             0.594054280501679, 0.6787126696461305, 0.9626572116690568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 391}], {
             RGBColor[
             0.43684851055771134`, 0.5527979560256977, 0.949056578696135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 400}], {
             RGBColor[
             0.35014668169757296`, 0.47458160516586856`, 0.9436462380973928]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 318}], {
             RGBColor[
             0.444710324644346, 0.5578694583080914, 0.9500377427555368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 304}], {
             RGBColor[
             0.3902155850839526, 0.4963806043265978, 0.9476363790697224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 338}], {
             RGBColor[
             0.5150243045671562, 0.6164862976206398, 0.955149604368392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 336}], {
             RGBColor[
             0.5610475334969128, 0.6318145864054693, 0.9604451415026278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 368}], {
             RGBColor[
             0.6209952742942125, 0.6948234628897277, 0.9638590766562989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 387}], {
             RGBColor[
             0.7039717676183253, 0.7668690240620983, 0.9692378522529503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 303}], {
             RGBColor[
             0.4080004341243544, 0.5210118954180062, 0.9481086600831168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 309}], {
             RGBColor[
             0.28032751008556567`, 0.4119723652635998, 0.9392756090407612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 362}], {
             RGBColor[
             0.2686274300814418, 0.39967483935134746`, 0.9386093067932437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 385}], {
             RGBColor[
             0.5134821664072813, 0.6048014054189386, 0.957674218445606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 400}], {
             RGBColor[
             0.2695745676031752, 0.4006703409386766, 0.938663244873942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 394}], {
             RGBColor[
             0.2319994211344167, 0.36117647959812427`, 0.9365233958699939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 301}], {
             RGBColor[
             0.34484166572307856`, 0.4702908380349324, 0.9432970699777097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 313}], {
             RGBColor[
             0.3304528551949676, 0.4578279735581279, 0.942380227694384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 329}], {
             RGBColor[
             0.24938478095972602`, 0.3794495950700028, 0.9375134663927103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 340}], {
             RGBColor[
             0.30789569449308907`, 0.43829009471402297`, 0.9409429053609744]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 343}], {
             RGBColor[
             0.24653697026784116`, 0.3764563654712052, 0.9373512877867658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 330}], {
             RGBColor[
             0.5171947040875179, 0.6013910593741824, 0.9590433114714677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 367}], {
             RGBColor[
             0.6037500597733065, 0.6848089338607557, 0.9642492204207583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 398}], {
             RGBColor[
             0.6074811348587111, 0.6880406035704467, 0.9644869612259401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 325}], {
             RGBColor[
             0.25522351303313373`, 0.3855864726761493, 0.9378459735466609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 375}], {
             RGBColor[
             0.24804073396827134`, 0.3780369164644828, 0.9374369249048863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 376}], {
             RGBColor[
             0.22283193390984793`, 0.3515408692728409, 0.9360013210346367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 378}], {
             RGBColor[
             0.30074536195477736`, 0.4277616988098747, 0.940646023105181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 397}], {
             RGBColor[
             0.2760268720337129, 0.4063517852276761, 0.9390709827851131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 320}], {
             RGBColor[
             0.735055587104642, 0.7912652437287115, 0.9491810738138217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 347}], {
             RGBColor[
             0.3474403607415021, 0.4629473268072002, 0.9441512073304144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 373}], {
             RGBColor[
             0.40740255971650413`, 0.5258863000815481, 0.9475690817717568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 390}], {
             RGBColor[
             0.6199803661547327, 0.7009506010701787, 0.9641946832056056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 300}], {
             RGBColor[
             0.5954053618784598, 0.6806154298859377, 0.9624332635806303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 370}], {
             RGBColor[
             0.4332442294884933, 0.5496761089199749, 0.948826917093545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 371}], {
             RGBColor[
             0.3200237345464615, 0.44107599148879184`, 0.9419983164995158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 370}], {
             RGBColor[
             0.5834115418390339, 0.6702269857947102, 0.9616690279734368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 371}], {
             RGBColor[
             0.4701910468970021, 0.561626868363527, 0.9548404273794074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 305}], {
             RGBColor[
             0.32912913363030194`, 0.45377597057334984`, 0.9424022645196342]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 313}], {
             RGBColor[
             0.396999633242371, 0.5182828613579595, 0.9465174434705802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 329}], {
             RGBColor[
             0.3159315590071293, 0.4399044828698345, 0.9416506821689066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 339}], {
             RGBColor[
             0.34752447190441127`, 0.4731106374312495, 0.9434498518208805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 340}], {
             RGBColor[
             0.3744424725404924, 0.4987449825138547, 0.9450801211371705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 361}], {
             RGBColor[
             0.483431447495499, 0.5903719675156307, 0.9527912079026979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 382}], {
             RGBColor[
             0.32861409354424886`, 0.4532346307874805, 0.942372933748667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 367}], {
             RGBColor[
             0.44544573826076733`, 0.5589658692163674, 0.9499576600655273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 377}], {
             RGBColor[
             0.43765371585663393`, 0.5522168110483404, 0.9494611592881508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 353}], {
             RGBColor[
             0.4001740084818627, 0.5127858258437011, 0.9476629567209361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 385}], {
             RGBColor[
             0.6573384818266246, 0.7308507060005853, 0.9674288896859021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 391}], {
             RGBColor[
             0.5001327118826571, 0.6049359923801525, 0.9538282567129803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 400}], {
             RGBColor[
             0.4134308830225186, 0.5267196415203234, 0.9484179161142381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 338}], {
             RGBColor[
             0.3037357194832036, 0.425499693294042, 0.9410142252986697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 313}], {
             RGBColor[
             0.314740323102191, 0.44131310609654534`, 0.9414854222363085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 329}], {
             RGBColor[
             0.2336722488669494, 0.36293472760842027`, 0.9366186609346348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 339}], {
             RGBColor[
             0.2652651617642313, 0.39614088216983523`, 0.9384178305866088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 340}], {
             RGBColor[
             0.29218316240031245`, 0.42177522725244043`, 0.9400480999028988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 361}], {
             RGBColor[
             0.40117213735531904`, 0.5134022122542165, 0.9477591866684263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 382}], {
             RGBColor[
             0.2463547834040689, 0.37626487552606624`, 0.9373409125143952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 308}], {
             RGBColor[
             0.3272737435397173, 0.4530009513857621, 0.9422535761394464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 311}], {
             RGBColor[
             0.3015667273388148, 0.4259812474396467, 0.9407895995969274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 346}], {
             RGBColor[
             0.5775762027017368, 0.664709724924115, 0.9614931618426004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 348}], {
             RGBColor[
             0.3327708960578125, 0.45877880722188047`, 0.9425666308430436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 350}], {
             RGBColor[
             0.3121713658409069, 0.437127394878261, 0.9413935180714648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 354}], {
             RGBColor[
             0.36967906720905974`, 0.49461916023148095`, 0.9447766011615656]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 378}], {
             RGBColor[
             0.38438132487866483`, 0.5073535168679363, 0.9457134160195768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 343}], {
             RGBColor[
             0.2798783468242849, 0.4081504034515736, 0.9393726847423418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 348}], {
             RGBColor[
             0.26136605624064674`, 0.392042675046979, 0.9381957822952502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 354}], {
             RGBColor[
             0.298274227391894, 0.4278830280565795, 0.9404057526137723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 374}], {
             RGBColor[
             0.363467416058872, 0.4838681935085703, 0.9446929547638633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 378}], {
             RGBColor[
             0.31297648506149905`, 0.4406173846930348, 0.9413425674717836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 323}], {
             RGBColor[
             0.27930349527084364`, 0.4108960607670378, 0.939217292911957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 362}], {
             RGBColor[
             0.2848108214619965, 0.41668460977858784`, 0.9395309269911842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 365}], {
             RGBColor[
             0.6233006938626346, 0.6956401412895088, 0.9547825984513625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 385}], {
             RGBColor[
             0.529665557787836, 0.621811175846179, 0.9585958386435465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 316}], {
             RGBColor[
             0.29285391194543553`, 0.42232525398602627`, 0.9400919724386281]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 319}], {
             RGBColor[
             0.4243027027135874, 0.5321406172648249, 0.9495837532800866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 384}], {
             RGBColor[
             0.238322256494585, 0.3678221804525773, 0.9368834719899588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 317}], {
             RGBColor[
             0.22647306937038708`, 0.3553679335031896, 0.9362086783125373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 344}], {
             RGBColor[
             0.195937641553685, 0.32327326280989077`, 0.9344697308714933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 346}], {
             RGBColor[
             0.48046434668366855`, 0.5709538888030983, 0.9556583367522882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 354}], {
             RGBColor[
             0.2725672111909915, 0.40086332411046416`, 0.9389417760712534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 356}], {
             RGBColor[
             0.30268137064558565`, 0.4250143200444211, 0.940931377412308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 359}], {
             RGBColor[
             0.26335330248943284`, 0.3909503240937418, 0.938425427685843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 360}], {
             RGBColor[
             0.26664706691608625`, 0.39380321729069534`, 0.9386353034425479]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 380}], {
             RGBColor[
             0.22891896117738242`, 0.3579387208708392, 0.936347968232573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 389}], {
             RGBColor[
             0.18595383630052237`, 0.3127796504790029, 0.933901167932042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 329}], {
             RGBColor[
             0.3015427484790184, 0.42744161839303, 0.9407338398855809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 339}], {
             RGBColor[
             0.33313566137630035`, 0.4606477729544449, 0.9425330095375548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 340}], {
             RGBColor[
             0.3600536620123814, 0.4862821180370502, 0.9441632788538449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 358}], {
             RGBColor[
             0.3900583107299038, 0.5122706366786742, 0.9460751485380563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 361}], {
             RGBColor[
             0.469042636967388, 0.5779091030388261, 0.9518743656193722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 369}], {
             RGBColor[
             0.2947252186357907, 0.4271052698173331, 0.9400955372431955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 322}], {
             RGBColor[
             0.3518149300873011, 0.4763572512808052, 0.9437404291113135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 351}], {
             RGBColor[
             0.31877246469154785`, 0.4495672962533488, 0.9415679956744565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 399}], {
             RGBColor[
             0.34224509203231646`, 0.47085722980507083`, 0.9430285325222152]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 344}], {
             RGBColor[
             0.2179558396033256, 0.34641578499445047`, 0.9357236346774154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 346}], {
             RGBColor[
             0.502482544733309, 0.5940964109876579, 0.9569122405582102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 354}], {
             RGBColor[
             0.29458540924063203`, 0.42400584629502386`, 0.9401956798771754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 322}], {
             RGBColor[
             0.47118776839199494`, 0.5808028892872876, 0.9517248620580527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 384}], {
             RGBColor[
             0.41608980876156726`, 0.5235083449936992, 0.9491160411194068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 347}], {
             RGBColor[
             0.5773572544002601, 0.645079197100907, 0.9391467663307211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 398}], {
             RGBColor[
             0.6814596166118513, 0.7462501612216771, 0.9453772129418854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 375}], {
             RGBColor[
             0.26346785646448745`, 0.3942518003440666, 0.9383154767086632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 381}], {
             RGBColor[
             0.31134257373247254`, 0.4397931567834469, 0.9412168172688962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 327}], {
             RGBColor[
             0.3408232588093649, 0.46480430785548354`, 0.9431144696927556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 335}], {
             RGBColor[
             0.40330132930986584`, 0.5237410737591699, 0.9469189819716299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 349}], {
             RGBColor[
             0.3991350270349485, 0.5201324321330776, 0.9466535088747887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 355}], {
             RGBColor[
             0.45678308171201976`, 0.5691085157167439, 0.9505908723564992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 362}], {
             RGBColor[
             0.2676034152667198, 0.39859853485478536`, 0.9385509906644394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 365}], {
             RGBColor[
             0.6060932876673579, 0.6775540663657063, 0.9538026621246178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 377}], {
             RGBColor[
             0.3184983232783968, 0.4459758692543676, 0.9416733332448688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 388}], {
             RGBColor[
             0.35476031404730335`, 0.47738418307774466`, 0.9439839152314442]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 395}], {
             RGBColor[
             0.29819151219748596`, 0.42838713014608437`, 0.9403794011994012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 376}], {
             RGBColor[
             0.2466487894338735, 0.3765738945044498, 0.9373576557228498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 397}], {
             RGBColor[
             0.29984372755773847`, 0.431384810459285, 0.9404273174733261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 363}], {
             RGBColor[
             0.26947084678929256`, 0.4005613237870065, 0.9386573381270326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 383}], {
             RGBColor[
             0.3107674940685786, 0.4424883316156812, 0.9410632520802292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 335}], {
             RGBColor[
             0.3190764753288425, 0.4459683370297738, 0.9417287838793023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 349}], {
             RGBColor[
             0.3149101730539251, 0.4423596954036815, 0.9414633107824609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 355}], {
             RGBColor[
             0.3725582277309964, 0.49133577898734776`, 0.9454006742641714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 339}], {
             RGBColor[
             0.25206758714105876`, 0.3822693944663199, 0.9376662482358811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 340}], {
             RGBColor[
             0.2789855877771399, 0.4079037395489251, 0.9392965175521713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 341}], {
             RGBColor[
             0.32255877069538685`, 0.4456446405408586, 0.9420729622374691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 343}], {
             RGBColor[
             0.21762686355189195`, 0.3460700103061074, 0.9357048999779627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 358}], {
             RGBColor[
             0.3089902364946622, 0.4338922581905491, 0.9412083872363826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 367}], {
             RGBColor[
             0.30392924660370463`, 0.42922199451498055`, 0.9408964025099879]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 398}], {
             RGBColor[
             0.3076603216891092, 0.43245366422467146`, 0.9411341433151696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 392}], {
             RGBColor[
             0.5380738089220873, 0.6344787384201356, 0.9572898859685385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 334}], {
             RGBColor[
             0.3435856824129715, 0.4709778109936048, 0.9431520541508845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 356}], {
             RGBColor[
             0.3596497509961113, 0.4848916997967572, 0.9441756423961041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 364}], {
             RGBColor[
             0.24057962139849923`, 0.3701948140917926, 0.9370120255817647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 366}], {
             RGBColor[
             0.47431376319766405`, 0.5787022208557775, 0.9530579459771436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 380}], {
             RGBColor[
             0.28588734152790807`, 0.4178161006231753, 0.9395922332163691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 389}], {
             RGBColor[
             0.24292221665104802`, 0.372657030231339, 0.9371454329158382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 337}], {
             RGBColor[
             0.3543405599121371, 0.4813337161466793, 0.9437992450399151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 345}], {
             RGBColor[
             0.28659257838012414`, 0.41461816106348387`, 0.9397766283886093]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 353}], {
             RGBColor[
             0.29992148443951494`, 0.4286276864333585, 0.9405356898703423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 391}], {
             RGBColor[
             0.3998801878403092, 0.5207778529698099, 0.9467009898623864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 364}], {
             RGBColor[
             0.28667397034423386`, 0.4111599931984045, 0.939911016341903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 366}], {
             RGBColor[
             0.5204081121433988, 0.6196673999623894, 0.9559569367372818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 391}], {
             RGBColor[
             0.41904435279016117`, 0.5373768894304345, 0.9479221135067852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 349}], {
             RGBColor[
             0.377388243554426, 0.5012964613073678, 0.9452678230613354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 355}], {
             RGBColor[
             0.4350362982314973, 0.5502725448910342, 0.9492051865430459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 359}], {
             RGBColor[
             0.2628408276367617, 0.3904116805308021, 0.9383962430011221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 345}], {
             RGBColor[
             0.289581436833259, 0.41720696003119545`, 0.9399670758062993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 353}], {
             RGBColor[
             0.3029103428926498, 0.4312164854010701, 0.9407261372880322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 391}], {
             RGBColor[
             0.4028690462934441, 0.5233666519375215, 0.9468914372800764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 340}], {
             RGBColor[
             0.31057850067442183`, 0.4411098941103401, 0.9410956872041452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 361}], {
             RGBColor[
             0.4195674756294284, 0.5327368791121161, 0.9488067739696726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 382}], {
             RGBColor[
             0.26475012167817824`, 0.3955995423839659, 0.9383884998156415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 343}], {
             RGBColor[
             0.276137777085255, 0.40491050995012756`, 0.9391343389462268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 358}], {
             RGBColor[
             0.36750115002802525`, 0.49273275783456927`, 0.9446378262046466]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 361}], {
             RGBColor[
             0.4464854762655095, 0.5583712241947213, 0.9504370432859626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 358}], {
             RGBColor[
             0.41107433294627227`, 0.5304736588265028, 0.9474142708899446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 348}], {
             RGBColor[
             0.45755495038657307`, 0.5614775203164333, 0.9520418335576166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 374}], {
             RGBColor[
             0.5596563102047983, 0.6533030387780245, 0.9585390060262295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 346}], {
             RGBColor[
             0.47194711691660707`, 0.5620017402943591, 0.9551732931171664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 354}], {
             RGBColor[
             0.26404998142393, 0.391911175601725, 0.9384567324361315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 350}], {
             RGBColor[
             0.2237488018130884, 0.3525045555719293, 0.9360535353053419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 353}], {
             RGBColor[
             0.23516236136063684`, 0.36450093031787467`, 0.9367035206367265]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 354}], {
             RGBColor[
             0.5485766865539135, 0.6395918015949325, 0.9596453383169263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 398}], {
             RGBColor[
             0.2938443902487113, 0.41793224430016573`, 0.940347346458478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 354}], {
             RGBColor[
             0.30377137990998915`, 0.43366088389269786`, 0.9407188073173696]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 374}], {
             RGBColor[
             0.36896456857696713`, 0.4896460493446887, 0.9450060094674604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 378}], {
             RGBColor[
             0.31847363757959424`, 0.4463952405291532, 0.9416556221753807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 355}], {
             RGBColor[
             0.43086999595657993`, 0.5466639032649419, 0.9489397134462045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 355}], {
             RGBColor[
             0.3934451532862405, 0.5132892620534779, 0.9465901537751052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 395}], {
             RGBColor[
             0.31632959562911733`, 0.4474514058536406, 0.9414123382179428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 399}], {
             RGBColor[
             0.32184488327959837`, 0.4522284708100698, 0.9417637674700541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 396}], {
             RGBColor[
             0.33043909080923356`, 0.4584630339390369, 0.9423556614449102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 391}], {
             RGBColor[
             0.34844997082082196`, 0.47066062222420074`, 0.9436278821105035]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 400}], {
             RGBColor[
             0.2617481419606836, 0.39244427136437154`, 0.9382175415117613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 374}], {
             RGBColor[
             0.4058727397282144, 0.5254864023542891, 0.9472159797859825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 359}], {
             RGBColor[
             0.38248010036883295`, 0.5057067717558422, 0.9455922716749972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 360}], {
             RGBColor[
             0.3857738647954863, 0.5085596649527958, 0.945802147431702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 364}], {
             RGBColor[
             0.30273803892737366`, 0.42507388200155694`, 0.9409346045871225]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 380}], {
             RGBColor[
             0.3480457590567825, 0.47269516853293964`, 0.9435148122217271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 389}], {
             RGBColor[
             0.3050806341799225, 0.4275360981411034, 0.941068011921196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 360}], {
             RGBColor[
             0.3464457966393335, 0.4744956690021165, 0.9432961977052371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 380}], {
             RGBColor[
             0.3120114553272831, 0.44148406577921384`, 0.941218738251967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 389}], {
             RGBColor[
             0.26904633045042303`, 0.3963249953873776, 0.9387719379514361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 382}], {
             RGBColor[
             0.40065709726926596`, 0.5128608724683471, 0.9477298558974591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 365}], {
             RGBColor[
             0.6116006138585108, 0.6833426153772564, 0.954116296203845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 385}], {
             RGBColor[
             0.517965477783712, 0.6095136499339266, 0.957929536396029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 383}], {
             RGBColor[
             0.28343937508639216`, 0.41376474586258355`, 0.9395069561325228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 393}], {
             RGBColor[
             0.3882161685906359, 0.5023185691266449, 0.9467907119390193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 366}], {
             RGBColor[
             0.4174020511289265, 0.5188844030605771, 0.949816908168162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 380}], {
             RGBColor[
             0.22897562945917044`, 0.357998282827975, 0.9363511954073875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 391}], {
             RGBColor[
             0.31603829177568893`, 0.43659389252862224`, 0.9417820849376655]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 377}], {
             RGBColor[
             0.6624955218701878, 0.7307199497768386, 0.9572386387842744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 388}], {
             RGBColor[
             0.6987575126390944, 0.7621282636002157, 0.9595492207708498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 372}], {
             RGBColor[
             0.24217642946309287`, 0.3718731606111593, 0.9371029614387775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 387}], {
             RGBColor[
             0.3854015979795554, 0.5072438993973288, 0.9459128099577055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 387}], {
             RGBColor[
             0.32515292278720553`, 0.44391872178353, 0.9424817370354288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 392}], {
             RGBColor[
             0.4222982540141441, 0.5224745584963002, 0.9503420874828066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 390}], {
             RGBColor[
             0.5222442324253528, 0.6177035277167222, 0.9575782501638477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 381}], {
             RGBColor[
             0.31254952769541955`, 0.44106174192380543`, 0.9412855515115576]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 397}], {
             RGBColor[
             0.26745214843445264`, 0.3973392070559766, 0.938582664961302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 388}], {
             RGBColor[
             0.41116254825013315`, 0.5305500664888769, 0.9474198918911008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 389}], {
             RGBColor[
             0.23131822471171923`, 0.3604604989675214, 0.9364846027414611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 393}], {
             RGBColor[
             0.429512815869922, 0.5442455769553196, 0.949196625892216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 400}], {
             RGBColor[
             0.5189126153054455, 0.6105091515212557, 0.9579834744767273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 395}], {
             RGBColor[
             0.3908557371692224, 0.5129613273805937, 0.9461259598456332]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.08365695714524007], {
             RGBColor[
             0.45548285265697636`, 0.5688205249124342, 0.9502764251312737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.08365695714524007], {
             RGBColor[
             0.42888501470754964`, 0.5459003761772271, 0.9485491517824056]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.08365695714524007], {
             RGBColor[
             0.5184926405203067, 0.6199747092584811, 0.9552367864443333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.08365695714524007], {
             RGBColor[
             0.2843062924415766, 0.4161543177891391, 0.9395021948098551]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.08365695714524007], {
             RGBColor[
             0.4330255595937459, 0.5494867080478132, 0.948812983641214]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.08365695714524007], {
             RGBColor[
             0.839756246494103, 0.8750628526510642, 0.9845778945215004]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.08365695714524007], {
             RGBColor[
             0.6536634318756143, 0.7293661080980942, 0.9661147201234391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.08365695714524007], {
             RGBColor[
             0.3016980860352178, 0.43443419555945895`, 0.94049263172616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.08365695714524007], {
             RGBColor[
             0.3228450428036656, 0.4540538822380393, 0.9417923785401555]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.08365695714524007], {
             RGBColor[
             0.18775684365418513`, 0.31467472552497133`, 0.9340038465335228]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.08365695714524007], {
             RGBColor[
             0.766103401961151, 0.8172050673043392, 0.9773216855303039]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.08365695714524007], {
             RGBColor[
             0.18909950513700058`, 0.3160859478730652, 0.9340803091186795]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.08365695714524007], {
             RGBColor[
             0.30207491415226445`, 0.4348302658027575, 0.9405140915299586]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.08365695714524007], {
             RGBColor[
             0.34057388625392293`, 0.4694097153570711, 0.9429220447678053]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.08365695714524007], {
             RGBColor[
             0.4590253228350359, 0.5716964617894458, 0.9505553013601864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.08365695714524007], {
             RGBColor[
             0.4755676512172742, 0.5851262691935479, 0.9518575740469817]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.08365695714524007], {
             RGBColor[
             0.2344917686782358, 0.3637960948906394, 0.9366653313755167]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.08365695714524007], {
             RGBColor[
             0.4330255595937459, 0.5494867080478132, 0.948812983641214]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.08365695714524007], {
             RGBColor[
             0.36887799096486745`, 0.49392530825202435`, 0.9447255572916495]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.08365695714524007], {
             RGBColor[
             0.2701338331202079, 0.4012581644565597, 0.9386950942177779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.08365695714524007], {
             RGBColor[
             0.2364756607883878, 0.36588129128443403`, 0.9367783110962845]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.08365695714524007], {
             RGBColor[
             0.39945159805580666`, 0.5204066300400227, 0.946673680500305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.08365695714524007], {
             RGBColor[
             0.6674330113809058, 0.7401230082603083, 0.9674871431244901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.08365695714524007], {
             RGBColor[
             0.28140643232271845`, 0.41310638094246827`, 0.9393370520660447]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.08365695714524007], {
             RGBColor[
             0.5748575517703585, 0.6657342834215882, 0.9596740387294104]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.08365695714524007], {
             RGBColor[
             0.5213518728411138, 0.6222959628634605, 0.9554618756863403]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.08365695714524007], {
             RGBColor[
             0.46869528135121225`, 0.5795469697395446, 0.9513165559168051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.08365695714524007], {
             RGBColor[
             0.36070278717079546`, 0.48684435762328926`, 0.9442046405349401]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.08365695714524007], {
             RGBColor[
             0.4450048757088704, 0.5598625895687993, 0.9495762950711764]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.08365695714524007], {
             RGBColor[
             0.61447578612375, 0.6978981508507898, 0.9627929312640836]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.08365695714524007], {
             RGBColor[
             0.43183922265939756`, 0.5484591626223088, 0.9487373913007938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.08365695714524007], {
             RGBColor[
             0.3035944552047864, 0.4364273997934254, 0.9406006271449402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.08365695714524007], {
             RGBColor[
             0.45017091400698506`, 0.5643371522899917, 0.9499054704633839]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.08365695714524007], {
             RGBColor[
             0.23049076456212023`, 0.35959078588628923`, 0.936437480110059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.08365695714524007], {
             RGBColor[
             0.47138624938641194`, 0.5817316188172481, 0.9515283987778766]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.08365695714524007], {
             RGBColor[
             0.30787214991739453`, 0.4409235281578864, 0.940844235530541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.08365695714524007], {
             RGBColor[
             0.41305312026680985`, 0.5321875849468098, 0.9475403574682363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.08365695714524007], {
             RGBColor[
             0.4245832336735235, 0.542174389659355, 0.9482750460988331]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.08365695714524007], {
             RGBColor[
             0.2926099423208359, 0.42488198029405105`, 0.9399750753863297]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.08365695714524007], {
             RGBColor[
             0.30019519637224906`, 0.4328545632349705, 0.9404070443831799]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.08365695714524007], {
             RGBColor[
             0.4228450050557896, 0.5406688233965846, 0.9481642877083664]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.08365695714524007], {
             RGBColor[
             0.2571027329668658, 0.3875616519759273, 0.93795299234183]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.08365695714524007], {
             RGBColor[
             0.37267370445680503`, 0.4972129645006335, 0.9449674167989381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.08365695714524007], {
             RGBColor[
             0.6349950610963795, 0.7145566226563739, 0.9644082837545099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.08365695714524007], {
             RGBColor[
             0.5900469288231402, 0.6780657039866748, 0.9608698021315268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.08365695714524007], {
             RGBColor[
             0.3017271295345842, 0.4344647221187572, 0.9404942857104829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.08365695714524007], {
             RGBColor[
             0.3182153544553041, 0.4500438788855908, 0.9414973788924706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.08365695714524007], {
             RGBColor[
             0.1883530998348592, 0.31530142857568516`, 0.9340378024409302]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.08365695714524007], {
             RGBColor[
             0.4036922856753097, 0.5240797005128791, 0.9469438933655269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.08365695714524007], {
             RGBColor[
             0.3966063233898629, 0.5179421961320451, 0.9464923821145687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.08365695714524007], {
             RGBColor[
             0.5501344367965773, 0.6456629449222354, 0.9577277445549202]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.08365695714524007], {
             RGBColor[
             0.24582809810038908`, 0.3757112958781218, 0.9373109185655119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.08365695714524007], {
             RGBColor[
             0.327730378655262, 0.45828531460857264`, 0.9421036678206864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.08365695714524007], {
             RGBColor[
             0.2320610697951006, 0.36124127624925384`, 0.9365269066700189]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.08365695714524007], {
             RGBColor[
             0.22522931231466187`, 0.3540606659788704, 0.9361378481881873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.08365695714524007], {
             RGBColor[
             0.4371748586049157, 0.5530806223014564, 0.9490773733051246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.08365695714524007], {
             RGBColor[
             0.21215062602609838`, 0.3403141374529851, 0.9353930363522361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.08365695714524007], {
             RGBColor[
             0.3289085275151681, 0.45930576793553984`, 0.9421787384242435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.08365695714524007], {
             RGBColor[
             0.34379376158942465`, 0.47219860953704273`, 0.9431272123769594]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.08365695714524007], {
             RGBColor[
             0.3647732489208881, 0.4903699870038633, 0.944464006758288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.08365695714524007], {
             RGBColor[
             0.40636649365686583`, 0.5263959650569017, 0.9471142915334024]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.08365695714524007], {
             RGBColor[
             0.29658410197434315`, 0.42905907406616267`, 0.9402013978993546]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.08365695714524007], {
             RGBColor[
             0.5200424480388751, 0.621232912820088, 0.9553587929693269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.08365695714524007], {
             RGBColor[
             0.35334346234881486`, 0.4804700803529103, 0.943735710864879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.08365695714524007], {
             RGBColor[
             0.3041741778820782, 0.43703672508379976`, 0.940633641493789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.08365695714524007], {
             RGBColor[
             0.7449314520771204, 0.8006653791421556, 0.9752114634289843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.08365695714524007], {
             RGBColor[
             0.4685968359759992, 0.579467047349033, 0.951308805936251]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.08365695714524007], {
             RGBColor[
             0.40353699071338844`, 0.5239451918222147, 0.9469339981078753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.08365695714524007], {
             RGBColor[
             0.30906096061429594`, 0.44211480305372236`, 0.9409140690118342]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.08365695714524007], {
             RGBColor[
             0.9871948157117643, 0.9889727414656584, 0.8618785726181107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.08365695714524007], {
             RGBColor[
             0.28032424868406536`, 0.4119689373238382, 0.9392754233087707]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.08365695714524007], {
             RGBColor[
             0.2163381945350113, 0.344715537463031, 0.9356315121838663]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.08365695714524007], {
             RGBColor[
             0.4471974556735149, 0.5617616921319011, 0.9497160043277012]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.08365695714524007], {
             RGBColor[
             0.29258441344072245`, 0.42485514782242734`, 0.9399736215543739]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.08365695714524007], {
             RGBColor[
             0.9395654439329824, 0.9544485875544974, 0.9871841189515437]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.08365695714524007], {
             RGBColor[
             0.3392718169498538, 0.4682819283697925, 0.9428390780631246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.08365695714524007], {
             RGBColor[
             0.3938245459186928, 0.5155327603027186, 0.9463151297139349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.08365695714524007], {
             RGBColor[
             0.400938182792374, 0.5216942350209159, 0.9467684043651838]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.08365695714524007], {
             RGBColor[
             0.2975269761237517, 0.43005009457886495`, 0.9402550931873062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.08365695714524007], {
             RGBColor[
             0.23087305434003186`, 0.35999259668144623`, 0.936459250947364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.08365695714524007], {
             RGBColor[
             0.3788085753956891, 0.5025266813603159, 0.9453583253503105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.08365695714524007], {
             RGBColor[
             0.3517960584531294, 0.47912979687324875`, 0.9436371116569614]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.08365695714524007], {
             RGBColor[
             0.2432681076544268, 0.37302058360664636`, 0.9371651308967808]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.08365695714524007], {
             RGBColor[
             0.9446594012585178, 0.958247652587292, 0.9785613779162622]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.08365695714524007], {
             RGBColor[
             0.42050349624403505`, 0.5386407261514976, 0.9480150888373963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.08365695714524007], {
             RGBColor[
             0.3408389431250127, 0.4696392942966634, 0.9429389339572505]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.08365695714524007], {
             RGBColor[
             0.30798752716811606`, 0.4410447969637349, 0.9408508060942842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.08365695714524007], {
             RGBColor[
             0.40629961235688544`, 0.5263380358364106, 0.9471100299161085]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.08365695714524007], {
             RGBColor[
             0.28140643232271845`, 0.41310638094246827`, 0.9393370520660447]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.08365695714524007], {
             RGBColor[
             0.8584234903174934, 0.8899476061670006, 0.9863583929018206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.08365695714524007], {
             RGBColor[
             0.5574181754790204, 0.651576212113331, 0.958301147145216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.08365695714524007], {
             RGBColor[
             0.3021789019665435, 0.43493956358877306`, 0.9405200134821455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.08365695714524007], {
             RGBColor[
             0.18199350204799294`, 0.3086170880799, 0.93367563275515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.08365695714524007], {
             RGBColor[
             0.35713000950765406`, 0.4837497971845029, 0.943976986301528]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.08365695714524007], {
             RGBColor[
             0.35285976871733454`, 0.48005112924047083`, 0.9437048903343945]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.08365695714524007], {
             RGBColor[
             0.6609507011328752, 0.7350589782271642, 0.9668410470195998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.08365695714524007], {
             RGBColor[
             0.28185544010635255`, 0.41357831659180544`, 0.9393626223950752]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.08365695714524007], {
             RGBColor[
             0.29818244313732717`, 0.43073903196914176`, 0.9402924210640528]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.08365695714524007], {
             RGBColor[
             0.4073094437290916, 0.5272127010154151, 0.9471743754781866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.08365695714524007], {
             RGBColor[
             0.34354743552460304`, 0.4719852542804023, 0.9431115166979266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.08365695714524007], {
             RGBColor[
             0.4901035624587857, 0.596927176774746, 0.9530018942267109]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.08365695714524007], {
             RGBColor[
             0.3367750835771075, 0.46611938341178777`, 0.9426799884203879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.08365695714524007], {
             RGBColor[
             0.4163456465758177, 0.5350394057484884, 0.9477501543331796]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.08365695714524007], {
             RGBColor[
             0.44506597843332024`, 0.5599155136776055, 0.9495801884827473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.08365695714524007], {
             RGBColor[
             0.341702343629997, 0.4703871284183096, 0.942993949073953]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.08365695714524007], {
             RGBColor[
             0.3217752229529791, 0.45312725805408377`, 0.9417242105652743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.08365695714524007], {
             RGBColor[
             0.5415984125883231, 0.6387330159264664, 0.9570557574607594]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.08365695714524007], {
             RGBColor[
             0.21449839414599955`, 0.34278179060409764`, 0.9355267382734529]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.08365695714524007], {
             RGBColor[
             0.3316304284528306, 0.46166334172102413`, 0.9423521755451089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.08365695714524007], {
             RGBColor[
             0.24849126742002764`, 0.3785104556877493, 0.9374625821184593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.08365695714524007], {
             RGBColor[
             0.3103002584512541, 0.44318822055117507`, 0.9409930359741371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.08365695714524007], {
             RGBColor[
             0.42960668580939526`, 0.5465254514134015, 0.9485951360268665]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.08365695714524007], {
             RGBColor[
             0.8817131673880364, 0.9085181624816085, 0.9885797830917492]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.08365695714524007], {
             RGBColor[
             0.2737069847647237, 0.4050137733858451, 0.9388985799179288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.08365695714524007], {
             RGBColor[
             0.19945930786806126`, 0.326974757392841, 0.9346702845582586]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.08365695714524007], {
             RGBColor[
             0.2703636243323544, 0.40149968959013, 0.9387081804873639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.08365695714524007], {
             RGBColor[
             0.347937955321334, 0.47578810185438924`, 0.9433912767369901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.08365695714524007], {
             RGBColor[
             0.20091175748064408`, 0.32850137402628987`, 0.9347529994149886]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.08365695714524007], {
             RGBColor[
             0.18801043567960526`, 0.31494126682235096`, 0.9340182882242146]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.08365695714524007], {
             RGBColor[
             0.4354207774425951, 0.5515613253613368, 0.9489656048045346]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.08365695714524007], {
             RGBColor[
             0.42405595175406813`, 0.5417176845626827, 0.9482414481611825]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.08365695714524007], {
             RGBColor[
             0.4409898357855673, 0.5563849637890084, 0.949320460277624]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.08365695714524007], {
             RGBColor[
             0.3367181839358917, 0.46607009980242575`, 0.942676362825564]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.08365695714524007], {
             RGBColor[
             0.5539949563828697, 0.6487970886368131, 0.9580316587983023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.08365695714524007], {
             RGBColor[
             0.33615544685019927`, 0.46558268522278723`, 0.9426405057160725]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.08365695714524007], {
             RGBColor[
             0.22183345530124604`, 0.350491404948, 0.9359444591549936]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.08365695714524007], {
             RGBColor[
             0.9686873406873048, 0.9761676504711416, 0.9378883439535993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.08365695714524007], {
             RGBColor[
             0.4288982046095901, 0.5459118006074308, 0.9485499922313003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.08365695714524007], {
             RGBColor[
             0.38508453598084125`, 0.5079626029802239, 0.9457582240091823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.08365695714524007], {
             RGBColor[
             0.2603804202871421, 0.3910067091669167, 0.9381396517858159]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.08365695714524007], {
             RGBColor[
             0.34335347829550766`, 0.47181725827713367`, 0.9430991579147983]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.08365695714524007], {
             RGBColor[
             0.3489166200617647, 0.4766357720634302, 0.943453636388851]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.08365695714524007], {
             RGBColor[
             0.289427532314628, 0.42153706560107806`, 0.9397938418444299]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.08365695714524007], {
             RGBColor[
             0.4169142071441726, 0.5355318643361123, 0.9477863825098367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.08365695714524007], {
             RGBColor[
             0.323455164565013, 0.454582339042107, 0.9418312549592791]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.08365695714524007], {
             RGBColor[
             0.20268026234650494`, 0.3303601847699944, 0.9348537131508309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.08365695714524007], {
             RGBColor[
             0.41463835613007616`, 0.5335606365753, 0.9476413672956746]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.08365695714524007], {
             RGBColor[
             0.1860253618840621, 0.31285482840228707`, 0.9339052412082121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.08365695714524007], {
             RGBColor[
             0.7473561921730353, 0.8025596045337915, 0.9754531388612606]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.08365695714524007], {
             RGBColor[
             0.3427922961638208, 0.4713311905205005, 0.9430633998856011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.08365695714524007], {
             RGBColor[
             0.42321272817471745`, 0.5409873266798986, 0.9481877187003396]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.08365695714524007], {
             RGBColor[
             0.9034699954431824, 0.9258664665994171, 0.9906549687741987]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.08365695714524007], {
             RGBColor[
             0.7018215301772112, 0.7669875805064049, 0.9709146692991265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.08365695714524007], {
             RGBColor[
             0.4618525057134134, 0.57399169621325, 0.9507778675526845]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.08365695714524007], {
             RGBColor[
             0.9116319596688005, 0.9323745953223082, 0.9914334642083096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.08365695714524007], {
             RGBColor[
             0.671984215244271, 0.7436784433087996, 0.967940764592172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.08365695714524007], {
             RGBColor[
             0.5261564290232863, 0.6261965180149375, 0.9558401079486701]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.08365695714524007], {
             RGBColor[
             0.3001773430766525, 0.4328357982893343, 0.9404060276644073]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.08365695714524007], {
             RGBColor[
             0.24992653081401459`, 0.38001900851578474`, 0.9375443182454649]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.08365695714524007], {
             RGBColor[
             0.42306922732026175`, 0.5408630334523317, 0.9481785749527866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.08365695714524007], {
             RGBColor[
             0.4695830289008276, 0.5802676831928937, 0.9513864426558372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.08365695714524007], {
             RGBColor[
             0.2562550702959713, 0.38667070476389964`, 0.9379047192067272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.08365695714524007], {
             RGBColor[
             0.36642171405748725`, 0.4917978046509186, 0.9445690454991117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.08365695714524007], {
             RGBColor[
             0.20589640168228598`, 0.33374055112691176`, 0.9350368675281518]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.08365695714524007], {
             RGBColor[
             0.213823940563589, 0.34207289712615707`, 0.9354883291396993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.08365695714524007], {
             RGBColor[
             0.32890030829795663`, 0.4592986488627011, 0.9421782147029908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.08365695714524007], {
             RGBColor[
             0.4443723578672751, 0.5593147344056806, 0.9495359915936236]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.08365695714524007], {
             RGBColor[
             0.44159261054028487`, 0.5569070569852046, 0.9493588685519817]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.08365695714524007], {
             RGBColor[
             0.25976951605538695`, 0.3903646100857766, 0.9381048616935693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.08365695714524007], {
             RGBColor[
             0.8840082961777506, 0.9103482358789153, 0.9887986945245978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.08365695714524007], {
             RGBColor[
             0.3331462935925693, 0.4629763079154685, 0.9424487651313861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.08365695714524007], {
             RGBColor[
             0.40232075287160096`, 0.5228917477335496, 0.9468565005080735]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.08365695714524007], {
             RGBColor[
             0.2859866726634801, 0.4179205039446193, 0.9395978899775927]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.08365695714524007], {
             RGBColor[
             0.415624577782344, 0.5344148522015528, 0.9477042084672755]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.08365695714524007], {
             RGBColor[
             0.34734353069964036`, 0.47527324112372843`, 0.9433534005257248]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.08365695714524007], {
             RGBColor[
             0.18366790932976162`, 0.3103769962965923, 0.9337709877727831]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.08365695714524007], {
             RGBColor[
             0.4097351355216383, 0.5293137133273045, 0.9473289384142527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.08365695714524007], {
             RGBColor[
             0.3458195558084371, 0.47395325067017335`, 0.9432562941932554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.08365695714524007], {
             RGBColor[
             0.9122194275143167, 0.9328430262359328, 0.9914894974158537]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.08365695714524007], {
             RGBColor[
             0.5680867791534835, 0.6602374651913787, 0.9591410187068526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.08365695714524007], {
             RGBColor[
             0.4441038832939284, 0.5590821952241721, 0.9495188846312126]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.08365695714524007], {
             RGBColor[
             0.1883530998348592, 0.31530142857568516`, 0.9340378024409302]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.08365695714524007], {
             RGBColor[
             0.21946479339785174`, 0.34800179110569385`, 0.9358095673637166]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.08365695714524007], {
             RGBColor[
             0.3716572568552603, 0.4963325686763173, 0.9449026496565771]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.08365695714524007], {
             RGBColor[
             0.3389226242073571, 0.4679794751671794, 0.9428168278103518]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.08365695714524007], {
             RGBColor[
             0.5492604175291562, 0.6449533767068237, 0.9576589385565507]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.08365695714524007], {
             RGBColor[
             0.23891823347992946`, 0.3684485900512977, 0.9369174119976053]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.08365695714524007], {
             RGBColor[
             0.27483080569137475`, 0.4061949804341175, 0.9389625798571576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.08365695714524007], {
             RGBColor[
             0.19147998205363254`, 0.3185879800433993, 0.9342158737574816]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.08365695714524007], {
             RGBColor[
             0.4713578761024759, 0.581708584107147, 0.9515261651290304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.08365695714524007], {
             RGBColor[
             0.3773482256450756, 0.5012617998056471, 0.945265273155538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.08365695714524007], {
             RGBColor[
             0.41630856278066414`, 0.5350072856290121, 0.9477477913865443]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.08365695714524007], {
             RGBColor[
             0.3619917095722905, 0.4879607574243407, 0.9442867695306141]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.08365695714524007], {
             RGBColor[
             0.22455235018136344`, 0.35334913585489547`, 0.9360992961961717]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.08365695714524007], {
             RGBColor[
             0.4713578761024759, 0.581708584107147, 0.9515261651290304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.08365695714524007], {
             RGBColor[
             0.38758676600127884`, 0.5101299088581892, 0.9459176638934496]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.08365695714524007], {
             RGBColor[
             0.23504801688099355`, 0.36438074701991086`, 0.9366970088877683]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.08365695714524007], {
             RGBColor[
             0.5213518728411138, 0.6222959628634605, 0.9554618756863403]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.08365695714524007], {
             RGBColor[
             0.21403960833528635`, 0.3422995776283375, 0.9355006111002455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.08365695714524007], {
             RGBColor[
             0.32890030829795663`, 0.4592986488627011, 0.9421782147029908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.08365695714524007], {
             RGBColor[
             0.3952647271346696, 0.516780172886385, 0.9464068967875147]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.08365695714524007], {
             RGBColor[
             0.4590253228350359, 0.5716964617894458, 0.9505553013601864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.08365695714524007], {
             RGBColor[
             0.27312993515751893`, 0.40440725766161456`, 0.9388657177964669]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.08365695714524007], {
             RGBColor[
             0.3921006230880956, 0.5140395849937361, 0.9462052828755744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.08365695714524007], {
             RGBColor[
             0.5647993997064433, 0.6575686224615152, 0.958882224154714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.08365695714524007], {
             RGBColor[
             0.5028570601136292, 0.6072810407094699, 0.9540058962797013]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.08365695714524007], {
             RGBColor[
             0.4594842268185013, 0.5720690207166119, 0.9505914279627855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.08365695714524007], {
             RGBColor[
             0.4362361652809005, 0.5522675733242927, 0.9490175605965724]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.08365695714524007], {
             RGBColor[
             0.18742041178662353`, 0.3143211143011516, 0.9339846872363715]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.08365695714524007], {
             RGBColor[
             0.3101553098712312, 0.44306267337648675`, 0.9409837999787911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.08365695714524007], {
             RGBColor[
             0.2838876754618256, 0.4157143248015712, 0.9394783551921466]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.08365695714524007], {
             RGBColor[
             0.22442486378535326`, 0.35321513956958445`, 0.9360920360345182]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.08365695714524007], {
             RGBColor[
             0.36106231354726204`, 0.4871557613002635, 0.9442275492377319]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.08365695714524007], {
             RGBColor[
             0.4300299801426456, 0.5468920876894712, 0.9486221079674768]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.08365695714524007], {
             RGBColor[
             0.2131948559424242, 0.3414116893030442, 0.9354525037011712]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.08365695714524007], {
             RGBColor[
             0.35557704870274465`, 0.4824047005893699, 0.9438780330122685]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.08365695714524007], {
             RGBColor[
             0.3099849003171966, 0.4429150731858152, 0.9409729416326953]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.08365695714524007], {
             RGBColor[
             0.35079845026099465`, 0.4782657187984673, 0.9435735449451089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.08365695714524007], {
             RGBColor[
             0.5888191267851396, 0.6770689189803744, 0.9607731450575083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.08365695714524007], {
             RGBColor[
             0.6441897151052467, 0.7219651685541689, 0.9651704685726856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.08365695714524007], {
             RGBColor[
             0.6367345561402467, 0.7159688230963439, 0.9645452231763435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.08365695714524007], {
             RGBColor[
             0.21633894456829447`, 0.3447163257955665, 0.9356315548971522]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.08365695714524007], {
             RGBColor[
             0.18775684365418513`, 0.31467472552497133`, 0.9340038465335228]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.08365695714524007], {
             RGBColor[
             0.35357835593641035`, 0.4806735333723905, 0.9437506780765723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.08365695714524007], {
             RGBColor[
             0.5127065416085635, 0.6152772935011425, 0.9547812835428221]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.08365695714524007], {
             RGBColor[
             0.2027848939768266, 0.330470159247491, 0.934859671767389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.08365695714524007], {
             RGBColor[
             0.2105731782240345, 0.33865613979704867`, 0.9353032030335335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.08365695714524007], {
             RGBColor[
             0.3721136848769951, 0.49672790368800457`, 0.9449317328465185]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.08365695714524007], {
             RGBColor[
             0.27788152629348223`, 0.40940148121379044`, 0.9391363138823109]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.08365695714524007], {
             RGBColor[
             0.27829488767567523`, 0.40983595023510067`, 0.9391598542015134]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.08365695714524007], {
             RGBColor[
             0.352676427621177, 0.4798923283979706, 0.9436932080018695]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.08365695714524007], {
             RGBColor[
             0.2517931842331501, 0.38198097961195865`, 0.9376506213962185]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.08365695714524007], {
             RGBColor[
             0.2829489547503914, 0.41472766981552317`, 0.9394248964363433]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.08365695714524007], {
             RGBColor[
             0.76754382617623, 0.8183303376487883, 0.9774652535545333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.08365695714524007], {
             RGBColor[
             0.40586240042020444`, 0.5259593448317684, 0.9470821711581144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.08365695714524007], {
             RGBColor[
             0.6367345561402467, 0.7159688230963439, 0.9645452231763435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.08365695714524007], {
             RGBColor[
             0.384388014031502, 0.5073593106759172, 0.9457138422464806]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.08365695714524007], {
             RGBColor[
             0.24040860462946106`, 0.37001506462444406`, 0.9370022864297646]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.08365695714524007], {
             RGBColor[
             0.21946479339785174`, 0.34800179110569385`, 0.9358095673637166]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.08365695714524007], {
             RGBColor[
             0.30983676756063083`, 0.44278676803744677`, 0.9409635027444355]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.08365695714524007], {
             RGBColor[
             0.4577853376090219, 0.5706897859222698, 0.9504576851809791]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.08365695714524007], {
             RGBColor[
             0.34396893738880546`, 0.47235033800987475`, 0.9431383744239941]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.08365695714524007], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.08365695714524007], {
             RGBColor[
             0.664376958487799, 0.737735596513351, 0.9671825443325432]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.08365695714524007], {
             RGBColor[
             0.5094497655998251, 0.6126332960211613, 0.9545248982054506]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.08365695714524007], {
             RGBColor[
             0.22442486378535326`, 0.35321513956958445`, 0.9360920360345182]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.08365695714524007], {
             RGBColor[
             0.31832586434969584`, 0.4501395970017241, 0.9415044204852212]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.08365695714524007], {
             RGBColor[
             0.42436007187203373`, 0.5419810981233429, 0.9482608264261764]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.08365695714524007], {
             RGBColor[
             0.40953836901978913`, 0.5291432840731747, 0.9473164006267486]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.08365695714524007], {
             RGBColor[
             0.3496790078108864, 0.477296114012997, 0.9435022150620721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.08365695714524007], {
             RGBColor[
             0.3337081584129609, 0.46346296698274475`, 0.9424845666609039]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.08365695714524007], {
             RGBColor[
             0.5338968752954676, 0.632480561001825, 0.9564494642334052]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.08365695714524007], {
             RGBColor[
             0.28756971748512594`, 0.4195843844230079, 0.9396880420382805]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.08365695714524007], {
             RGBColor[
             0.2554763810799757, 0.38585225302614046`, 0.9378603740078437]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.08365695714524007], {
             RGBColor[
             0.23754982944882125`, 0.3670103106527763, 0.936839483412406]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.08365695714524007], {
             RGBColor[
             0.4546046651494302, 0.5681075727319119, 0.9502072909937729]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.08365695714524007], {
             RGBColor[
             0.49907656082686525`, 0.6042118610789229, 0.9537082815274222]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.08365695714524007], {
             RGBColor[
             0.3813300763224481, 0.504710678728753, 0.9455189931596879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.08365695714524007], {
             RGBColor[
             0.42980481675489485`, 0.5466970624800424, 0.9486077607555135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.08365695714524007], {
             RGBColor[
             0.4194818136345734, 0.537755796026443, 0.9479499881249598]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.08365695714524007], {
             RGBColor[
             0.18199350204799294`, 0.3086170880799, 0.93367563275515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.08365695714524007], {
             RGBColor[
             0.31463320045075654`, 0.446941197131147, 0.9412691272068753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.08365695714524007], {
             RGBColor[
             0.3001773430766525, 0.4328357982893343, 0.9404060276644073]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.08365695714524007], {
             RGBColor[
             0.2396106977122098, 0.3691764138641925, 0.9369568468112246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.08365695714524007], {
             RGBColor[
             0.40255299019713486`, 0.5230929000323398, 0.946871298465097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.08365695714524007], {
             RGBColor[
             0.38931803652557295`, 0.5116294483701461, 0.9460279789203551]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.08365695714524007], {
             RGBColor[
             0.20002103358538337`, 0.32756516673721403`, 0.9347022740068615]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.08365695714524007], {
             RGBColor[
             0.2592893371999934, 0.3898599116636602, 0.9380775162181156]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.08365695714524007], {
             RGBColor[
             0.3733740053946533, 0.4978195299748491, 0.9450120393554461]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.08365695714524007], {
             RGBColor[
             0.9724171788023525, 0.9789493576302948, 0.931574700922403]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.08365695714524007], {
             RGBColor[
             0.39356182175218285`, 0.5153052018345883, 0.9462983891623628]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.08365695714524007], {
             RGBColor[
             0.4070424975651195, 0.5269814856652867, 0.9471573659046695]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.08365695714524007], {
             RGBColor[
             0.40716772620551, 0.5270899524194185, 0.9471653453628999]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.08365695714524007], {
             RGBColor[
             0.23823191766179447`, 0.36772722861150164`, 0.9368783273270758]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.08365695714524007], {
             RGBColor[
             0.2976573334784375, 0.4301871084237734, 0.9402625168458091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.08365695714524007], {
             RGBColor[
             0.3109801256736465, 0.4437770873680913, 0.941036356512365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.08365695714524007], {
             RGBColor[
             0.5614059768921024, 0.6548136889488775, 0.9586150814802518]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.08365695714524007], {
             RGBColor[
             0.18051407950620355`, 0.3070621211876725, 0.9335913818300046]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.08365695714524007], {
             RGBColor[
             0.18534706491862368`, 0.3121418952850998, 0.9338666131994807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.08365695714524007], {
             RGBColor[
             0.22122957111674213`, 0.3498566843816177, 0.9359100688440527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.08365695714524007], {
             RGBColor[
             0.3634937550225388, 0.48926175369834635`, 0.9443824785384973]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.08365695714524007], {
             RGBColor[
             0.3947521623972817, 0.5163362150731124, 0.9463742366156915]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.08365695714524007], {
             RGBColor[
             0.284983858164673, 0.4168664823242615, 0.9395407811754167]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.08365695714524007], {
             RGBColor[
             0.43606329816625106`, 0.5521178445181372, 0.9490065456568872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.08365695714524007], {
             RGBColor[
             0.36167667102803513`, 0.48768788687160436`, 0.9442666955531518]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.08365695714524007], {
             RGBColor[
             0.3543390240008456, 0.48133238581751575`, 0.9437991471730057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.08365695714524007], {
             RGBColor[
             0.2301093625425649, 0.3591899081814518, 0.9364157598292792]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.08365695714524007], {
             RGBColor[
             0.3657970683564656, 0.49125676794029943`, 0.9445292436273951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.08365695714524007], {
             RGBColor[
             0.415624577782344, 0.5344148522015528, 0.9477042084672755]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.08365695714524007], {
             RGBColor[
             0.3217264211809374, 0.45308498841198963`, 0.9417211009595136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.08365695714524007], {
             RGBColor[
             0.506022555930102, 0.6098509328172439, 0.9542550957059673]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.08365695714524007], {
             RGBColor[
             0.2644514524189427, 0.39528562205578455`, 0.9383714910431696]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.08365695714524007], {
             RGBColor[
             0.639490111164093, 0.7182059068010416, 0.9647621505617513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.08365695714524007], {
             RGBColor[
             0.2791198401271499, 0.410703027566607, 0.9392068340232171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.08365695714524007], {
             RGBColor[
             0.25882567945060075`, 0.38937257797144925`, 0.9380511115952079]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.08365695714524007], {
             RGBColor[
             0.358876975131005, 0.4852629310024042, 0.9440883014062669]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.08365695714524007], {
             RGBColor[
             0.4252883468938064, 0.5427851232907432, 0.9483199752897223]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.08365695714524007], {
             RGBColor[
             0.37209322529509054`, 0.49671018262648736`, 0.9449304291800513]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.08365695714524007], {
             RGBColor[
             0.31541677229221704`, 0.4476198876767542, 0.9413190557117278]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.08365695714524007], {
             RGBColor[
             0.6015041701679052, 0.6873672086531957, 0.9617717581394447]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.08365695714524007], {
             RGBColor[
             0.9395654439329824, 0.9544485875544974, 0.9871841189515437]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.08365695714524007], {
             RGBColor[
             0.264144118705011, 0.3949625948363594, 0.9383539888428207]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.08365695714524007], {
             RGBColor[
             0.23765437281777407`, 0.3671201923619781, 0.9368454370026098]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.08365695714524007], {
             RGBColor[
             0.27829488767567523`, 0.40983595023510067`, 0.9391598542015134]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.08365695714524007], {
             RGBColor[
             0.402809365429058, 0.5233149593724378, 0.9468876344681715]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.08365695714524007], {
             RGBColor[
             0.8170155172571198, 0.8569779987199576, 0.9823961293822382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.08365695714524007], {
             RGBColor[
             0.23140665750910816`, 0.36055344744454043`, 0.9364896388584478]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.08365695714524007], {
             RGBColor[
             0.505138693445884, 0.6091333734350046, 0.9541855148135148]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.08365695714524007], {
             RGBColor[
             0.44523804952791923`, 0.5600645530112025, 0.9495911527007387]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.08365695714524007], {
             RGBColor[
             0.7455726742290004, 0.801166306760673, 0.975275374460522]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.08365695714524007], {
             RGBColor[
             0.4113884437704819, 0.5307457258347641, 0.9474342857539059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.08365695714524007], {
             RGBColor[
             0.5004068742320413, 0.6052918694311809, 0.9538130086717762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.08365695714524007], {
             RGBColor[
             0.5518567495436978, 0.647061195999653, 0.957863331323413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.08365695714524007], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.08365695714524007], {
             RGBColor[
             0.246869823490122, 0.3768062153119356, 0.9373702432853624]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.08365695714524007], {
             RGBColor[
             0.39867858335688305`, 0.5197370835606635, 0.9466244246872396]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.08365695714524007], {
             RGBColor[
             0.34497764078856274`, 0.4732240261958375, 0.9432026481126653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.08365695714524007], {
             RGBColor[
             0.25586890372255156`, 0.38626481921086064`, 0.9378827275916531]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.08365695714524007], {
             RGBColor[
             0.29651090146612036`, 0.4289821356908402, 0.9401972292387017]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.08365695714524007], {
             RGBColor[
             0.24653515044660512`, 0.3764544527237028, 0.9373511841506386]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.08365695714524007], {
             RGBColor[
             0.2044548713207465, 0.3322254113186299, 0.9349547745066152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.08365695714524007], {
             RGBColor[
             0.18355457276618556`, 0.31025787238232067`, 0.9337645334231539]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.08365695714524007], {
             RGBColor[
             0.38261082271426, 0.5058199968811551, 0.9456006011872545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.08365695714524007], {
             RGBColor[
             0.2834785800730524, 0.4152843396098248, 0.9394550578149583]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.08365695714524007], {
             RGBColor[
             0.2785817473842138, 0.41013745797673073`, 0.9391761904375437]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.08365695714524007], {
             RGBColor[
             0.33917267344426594`, 0.4681960552483498, 0.9428327607266177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.08365695714524007], {
             RGBColor[
             0.24849126742002764`, 0.3785104556877493, 0.9374625821184593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.08365695714524007], {
             RGBColor[
             0.5173274239936015, 0.6190287339896955, 0.9551450563310222]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.08365695714524007], {
             RGBColor[
             0.6020702549805697, 0.6878267818059468, 0.9618163224095346]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.08365695714524007], {
             RGBColor[
             0.9649724807634001, 0.9733971140224184, 0.9441766328141286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.08365695714524007], {
             RGBColor[
             0.2622609025015404, 0.3929832152037081, 0.9382467424660018]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.08365695714524007], {
             RGBColor[
             0.42504811279038834`, 0.5425770445848797, 0.9483046677850833]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.08365695714524007], {
             RGBColor[
             0.262096089075567, 0.3928099858432353, 0.9382373565852122]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.08365695714524007], {
             RGBColor[
             0.3243574375992864, 0.4553638425948333, 0.9418887469991744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.08365695714524007], {
             RGBColor[
             0.2790403685571593, 0.41061949790775826`, 0.9392023082348738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.08365695714524007], {
             RGBColor[
             0.2967989657714791, 0.4292849095401041, 0.940213634074739]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.08365695714524007], {
             RGBColor[
             0.25659840482834156`, 0.38703157112608744`, 0.9379242716004278]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.08365695714524007], {
             RGBColor[
             0.36503162137971523`, 0.490593776241522, 0.9444804700228947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.08365695714524007], {
             RGBColor[
             0.2204746742437768, 0.34906323990490495`, 0.9358670785839072]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.08365695714524007], {
             RGBColor[
             0.2173738909179159, 0.34580412002840716`, 0.9356904935606972]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.08365695714524007], {
             RGBColor[
             0.4134788640866295, 0.5325563428450311, 0.9475674854879647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.08365695714524007], {
             RGBColor[
             0.29749133346723683`, 0.4300126318869929, 0.9402530633907462]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.08365695714524007], {
             RGBColor[
             0.35135170145900224`, 0.4787449171789677, 0.9436087976222252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.08365695714524007], {
             RGBColor[
             0.3896800313587061, 0.5119429901002167, 0.9460510449110229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.08365695714524007], {
             RGBColor[
             0.3815545458293434, 0.5049051029334601, 0.9455332961581766]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.08365695714524007], {
             RGBColor[
             0.18252962306084325`, 0.3091805852564412, 0.9337061640537119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.08365695714524007], {
             RGBColor[
             0.35732941836527193`, 0.4839225151143909, 0.9439896924576051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.08365695714524007], {
             RGBColor[
             0.4285444389664072, 0.545605386588084, 0.9485274505973393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.08365695714524007], {
             RGBColor[
             0.2836605000383407, 0.4154755490277348, 0.9394654178878551]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.08365695714524007], {
             RGBColor[
             0.3374965013105029, 0.4667442391929453, 0.9427259565204352]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.08365695714524007], {
             RGBColor[
             0.42464286714699695`, 0.5422260411768123, 0.9482788458910311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.08365695714524007], {
             RGBColor[
             0.6482466920144042, 0.7251345097497692, 0.9655748301163857]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.08365695714524007], {
             RGBColor[
             0.2147790528600071, 0.3430767807073098, 0.9355427213720182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.08365695714524007], {
             RGBColor[
             0.18742041178662353`, 0.3143211143011516, 0.9339846872363715]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.08365695714524007], {
             RGBColor[
             0.22183345530124604`, 0.350491404948, 0.9359444591549936]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.08365695714524007], {
             RGBColor[
             0.7564738220465905, 0.8096823662875665, 0.9763618989979611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.08365695714524007], {
             RGBColor[
             0.18974202803712018`, 0.3167612801793957, 0.9341168998473138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.08365695714524007], {
             RGBColor[
             0.2668632087587419, 0.3978205308830974, 0.9385088369988475]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.08365695714524007], {
             RGBColor[
             0.3732219412795087, 0.4976878196812755, 0.9450023499644941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.08365695714524007], {
             RGBColor[
             0.22566414832493076`, 0.3545177061958585, 0.93616261145569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.08365695714524007], {
             RGBColor[
             0.29837225593882977`, 0.43093853725834774`, 0.9403032306222954]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.08365695714524007], {
             RGBColor[
             0.2852925576378371, 0.417190945043234, 0.9395583611537335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.08365695714524007], {
             RGBColor[
             0.24849126742002764`, 0.3785104556877493, 0.9374625821184593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.08365695714524007], {
             RGBColor[
             0.34067955106123643`, 0.4695012369022984, 0.9429287776358916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.08365695714524007], {
             RGBColor[
             0.4885180506336512, 0.5956399868486081, 0.9528770769279151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.08365695714524007], {
             RGBColor[
             0.4218081685249857, 0.5397707677065215, 0.948098221401462]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.08365695714524007], {
             RGBColor[
             0.2344917686782358, 0.3637960948906394, 0.9366653313755167]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.08365695714524007], {
             RGBColor[
             0.3975057987455476, 0.5187212764761933, 0.9465496958888581]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.08365695714524007], {
             RGBColor[
             0.34315203221268015`, 0.47164277580516295`, 0.9430863219485323]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.08365695714524007], {
             RGBColor[
             0.3497395610659869, 0.47734856219907, 0.9435060734619419]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.08365695714524007], {
             RGBColor[
             0.5554744512205161, 0.6499982091964973, 0.95814813005149]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.08365695714524007], {
             RGBColor[
             0.2731107414578726, 0.4043870838663355, 0.9388646247436666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.08365695714524007], {
             RGBColor[
             0.24214272780710608`, 0.37183773803390885`, 0.9371010421793261]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.08365695714524007], {
             RGBColor[
             0.18366790932976162`, 0.3103769962965923, 0.9337709877727831]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.08365695714524007], {
             RGBColor[
             0.950090486259149, 0.9622981468881774, 0.9693679676640233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.08365695714524007], {
             RGBColor[
             0.6511361929280913, 0.727391809824562, 0.9658628285635408]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.08365695714524007], {
             RGBColor[
             0.39048460228949333`, 0.5126398690015539, 0.9461023114592785]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.08365695714524007], {
             RGBColor[
             0.3024251046554427, 0.4351983382249582, 0.9405340343610542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.08365695714524007], {
             RGBColor[
             0.305971857198529, 0.4389262000248414, 0.9407360166714327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.08365695714524007], {
             RGBColor[
             0.4212504094490674, 0.5392876648287473, 0.9480626814863515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.08365695714524007], {
             RGBColor[
             0.1948094195650038, 0.3220874299663812, 0.9344054802982928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.08365695714524007], {
             RGBColor[
             0.181927754270743, 0.30854798299736047`, 0.9336718885165007]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.08365695714524007], {
             RGBColor[
             0.30966642598712424`, 0.44263922672809175`, 0.9409526487299988]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.08365695714524007], {
             RGBColor[
             0.4710659283951924, 0.58147156780628, 0.9515031819360734]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.08365695714524007], {
             RGBColor[
             0.2646748104274345, 0.3955203854844251, 0.9383842109513247]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.08365695714524007], {
             RGBColor[
             0.2142572103105877, 0.34252829110114136`, 0.9355130032108256]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.08365695714524007], {
             RGBColor[
             0.3749005574812265, 0.4991417526655, 0.9451093099045255]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.08365695714524007], {
             RGBColor[
             0.37008406640044655`, 0.494969950175209, 0.944802407351914]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.08365695714524007], {
             RGBColor[
             0.322126557522435, 0.45343156639955756`, 0.9417465972933672]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.08365695714524007], {
             RGBColor[
             0.27428334958857925`, 0.4056195693593577, 0.9389314030419921]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.08365695714524007], {
             RGBColor[
             0.36042424496340464`, 0.4866030983631857, 0.9441868920717904]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.08365695714524007], {
             RGBColor[
             0.24583974331801584`, 0.3757235357401969, 0.9373115817434281]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.08365695714524007], {
             RGBColor[
             0.3247360223656782, 0.45569175369125825`, 0.9419128700857194]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.08365695714524007], {
             RGBColor[
             0.2301093625425649, 0.3591899081814518, 0.9364157598292792]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.08365695714524007], {
             RGBColor[
             0.7628202141095515, 0.8146402160015177, 0.9769944480483913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.08365695714524007], {
             RGBColor[
             0.3636822335006733, 0.4894250042829027, 0.944394488220459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.08365695714524007], {
             RGBColor[
             0.4683780913036681, 0.5792894605696994, 0.9512915855543569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.08365695714524007], {
             RGBColor[
             0.4474245390190398, 0.561958380312254, 0.9497304738776762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.08365695714524007], {
             RGBColor[
             0.1883530998348592, 0.31530142857568516`, 0.9340378024409302]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.08365695714524007], {
             RGBColor[
             0.7348220388635813, 0.7927678287053527, 0.9742038515976965]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.08365695714524007], {
             RGBColor[
             0.44840867422161623`, 0.5628107887606522, 0.9497931821025477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.08365695714524007], {
             RGBColor[
             0.6626687537575453, 0.73640113399524, 0.9670122864491123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.08365695714524007], {
             RGBColor[
             0.5342896093741658, 0.6327994002193809, 0.9564803816987126]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.08365695714524007], {
             RGBColor[
             0.22634446945105935`, 0.3552327668342704, 0.9362013547373781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.08365695714524007], {
             RGBColor[
             0.33428693531940495`, 0.46396427444893346`, 0.9425214458135902]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.08365695714524007], {
             RGBColor[
             0.37558562398063, 0.49973512283483984`, 0.945152961736087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.08365695714524007], {
             RGBColor[
             0.3206470865583176, 0.4521501230108118, 0.9416523267117783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.08365695714524007], {
             RGBColor[
             0.3979467524603024, 0.5191032084209358, 0.9465777930696422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.08365695714524007], {
             RGBColor[
             0.345317510620367, 0.4735184043617918, 0.9432243043178127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.08365695714524007], {
             RGBColor[
             0.2750050165013395, 0.4063780870409938, 0.9389725009050632]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN3AuYzmXewPH7z7a1WxZbu0o1DqFsy5TT0CKyGGKYrMNM4zSN46CIkAnD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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[37, 104] -> 
             RGBColor[
              0.2541903466574486, 0.3845005493087726, 0.9377871362499982], 
             UndirectedEdge[119, 243] -> 
             RGBColor[
              0.23559188807996673`, 0.3649523901334573, 0.9367279815479644], 
             UndirectedEdge[165, 226] -> 
             RGBColor[
              0.20872258864357046`, 0.33671105281382463`, 0.935197814694628], 
             UndirectedEdge[235, 261] -> 
             RGBColor[
              0.19122633777104836`, 0.31832138382042696`, 0.9342014290908216],
              UndirectedEdge[56, 198] -> 
             RGBColor[
              0.6735978276393025, 0.7431113232752183, 0.969380994432274], 
             UndirectedEdge[50, 254] -> 
             RGBColor[
              0.20910270252497706`, 0.33711057660379506`, 0.9352194616178461],
              UndirectedEdge[249, 268] -> 
             RGBColor[
              0.18564105657677243`, 0.3124508991579618, 0.9338833555894905], 
             UndirectedEdge[38, 224] -> 
             RGBColor[
              0.37823665311305865`, 0.49620023139778335`, 0.9458245390097163],
              UndirectedEdge[79, 87] -> 
             RGBColor[
              0.19294989757058154`, 0.3201329544497393, 0.9342995832716268], 
             UndirectedEdge[38, 311] -> 
             RGBColor[
              0.23066096804752526`, 0.35976968054097413`, 0.9364471729467594],
              UndirectedEdge[37, 145] -> 
             RGBColor[
              0.2671022972631469, 0.3980718280603137, 0.9385224527354736], 
             UndirectedEdge[147, 359] -> 
             RGBColor[
              0.28645237167494564`, 0.4168434263248926, 0.9396817701660576], 
             UndirectedEdge[192, 349] -> 
             RGBColor[
              0.22834058438598487`, 0.3573308101918738, 0.9363150305299347], 
             UndirectedEdge[213, 308] -> 
             RGBColor[
              0.2691305631056292, 0.398662652595457, 0.9386943834532097], 
             UndirectedEdge[262, 397] -> 
             RGBColor[
              0.364256395049981, 0.48992231415871446`, 0.9444310732866698], 
             UndirectedEdge[129, 364] -> 
             RGBColor[
              0.8533368890895888, 0.341701118375767, 0.1959548205416618], 
             UndirectedEdge[54, 83] -> 
             RGBColor[
              0.9496193654049732, 0.8977579075232218, 0.6225379522867944], 
             UndirectedEdge[13, 277] -> 
             RGBColor[
              0.19923872667069553`, 0.3267429125687539, 0.9346577227853893], 
             UndirectedEdge[191, 235] -> 
             RGBColor[
              0.18862912627732129`, 0.3155915498678, 0.9340535217384839], 
             UndirectedEdge[54, 214] -> 
             RGBColor[
              0.913587591361185, 0.6878213464055395, 0.24895168467498954`], 
             UndirectedEdge[87, 176] -> 
             RGBColor[
              0.18652655830038561`, 0.3133816176135313, 0.933933783602668], 
             UndirectedEdge[16, 377] -> 
             RGBColor[
              0.24182389785616784`, 0.37150262754048624`, 0.9370828852852868],
              UndirectedEdge[158, 344] -> 
             RGBColor[
              0.19135142545084088`, 0.31845285890290587`, 0.934208552649135], 
             UndirectedEdge[95, 228] -> 
             RGBColor[
              0.2356195787974104, 0.36498149483318354`, 0.9367295584933581], 
             UndirectedEdge[193, 283] -> 
             RGBColor[
              0.884925338733304, 0.8207038820590313, 0.6242425057097936], 
             UndirectedEdge[11, 366] -> 
             RGBColor[
              0.9332464444239088, 0.9449010522417576, 0.749948999978632], 
             UndirectedEdge[106, 231] -> 
             RGBColor[
              0.1888628748467801, 0.31583723443481654`, 0.9340668333737145], 
             UndirectedEdge[76, 388] -> 
             RGBColor[
              0.276858244918402, 0.40832594760879465`, 0.9390780395218092], 
             UndirectedEdge[208, 351] -> 
             RGBColor[
              0.301986411916915, 0.43466246314501933`, 0.9405117895645303], 
             UndirectedEdge[208, 225] -> 
             RGBColor[
              0.2514500268910438, 0.38162029948797277`, 0.9376310790932412], 
             UndirectedEdge[163, 374] -> 
             RGBColor[
              0.1813453905655848, 0.3079358818192477, 0.9336387237650219], 
             UndirectedEdge[165, 288] -> 
             RGBColor[
              0.2196372553710177, 0.3481830595742119, 0.9358193888179538], 
             UndirectedEdge[110, 239] -> 
             RGBColor[
              0.6800499902731076, 0.7481746185632971, 0.9700901941191247], 
             UndirectedEdge[14, 273] -> 
             RGBColor[
              0.4313475935937616, 0.5461129107315478, 0.9492366849727629], 
             UndirectedEdge[231, 372] -> 
             RGBColor[
              0.18557674124721385`, 0.3123832996687683, 0.9338796929266182], 
             UndirectedEdge[5, 162] -> 
             RGBColor[
              0.19105730741779076`, 0.3181437222020098, 0.9341918030622616], 
             UndirectedEdge[36, 90] -> 
             RGBColor[
              0.2306114538784999, 0.35971763800994894`, 0.9364443531880831], 
             UndirectedEdge[258, 328] -> 
             RGBColor[
              0.23450213577855084`, 0.36380699137038264`, 0.936665921766543], 
             UndirectedEdge[91, 208] -> 
             RGBColor[
              0.4434969579662055, 0.5534506067219376, 0.9505734674176423], 
             UndirectedEdge[155, 370] -> 
             RGBColor[
              0.18572317816153708`, 0.3125372141503586, 0.9338880322922549], 
             UndirectedEdge[66, 243] -> 
             RGBColor[
              0.21376058132167255`, 0.342006302545695, 0.9354847209246038], 
             UndirectedEdge[253, 334] -> 
             RGBColor[
              0.8701987937776897, 0.4222457469371983, 0.21448170260215638`], 
             UndirectedEdge[50, 210] -> 
             RGBColor[
              0.23840421569943582`, 0.3679083247733892, 0.9368881394454274], 
             UndirectedEdge[239, 365] -> 
             RGBColor[
              0.4065771465503478, 0.524864785093759, 0.9475407198960643], 
             UndirectedEdge[13, 51] -> 
             RGBColor[
              0.20728585719020337`, 0.33520095696230034`, 0.9351159949638125],
              UndirectedEdge[258, 300] -> 
             RGBColor[
              0.21690681128224154`, 0.345313189716754, 0.9356638940664279], 
             UndirectedEdge[30, 294] -> 
             RGBColor[
              0.2052159577699056, 0.3330253614323641, 0.9349981172539683], 
             UndirectedEdge[31, 292] -> 
             RGBColor[
              0.8744140526456051, 0.4298053132859735, 0.4143800934465462], 
             UndirectedEdge[203, 216] -> 
             RGBColor[
              0.26291297700315486`, 0.3935517624584167, 0.938288154657422], 
             UndirectedEdge[64, 233] -> 
             RGBColor[
              0.9814581324353071, 0.9819712119725741, 0.6847171998056071], 
             UndirectedEdge[50, 242] -> 
             RGBColor[
              0.2857631387189643, 0.41475906038865373`, 0.9396923133754758], 
             UndirectedEdge[133, 398] -> 
             RGBColor[
              0.18210607446438823`, 0.30873540882703493`, 0.9336820435877278],
              UndirectedEdge[7, 390] -> 
             RGBColor[
              0.23396569650741295`, 0.36324315968420245`, 0.9366353723436424],
              UndirectedEdge[186, 342] -> 
             RGBColor[
              0.19648760861210862`, 0.32385131305821946`, 0.9345010506818672],
              UndirectedEdge[347, 398] -> 
             RGBColor[
              0.182565782601332, 0.30921859122614215`, 0.9337082232860494], 
             UndirectedEdge[321, 375] -> 
             RGBColor[
              0.19367454863692518`, 0.3208946086659977, 0.9343408510778299], 
             UndirectedEdge[149, 279] -> 
             RGBColor[
              0.20468155953700706`, 0.33246367500678287`, 0.9349676840651762],
              UndirectedEdge[38, 306] -> 
             RGBColor[
              0.24051285588611682`, 0.3701246393051007, 0.9370082233846052], 
             UndirectedEdge[12, 358] -> 
             RGBColor[
              0.26019129073322267`, 0.39080792201424114`, 0.9381288811375124],
              UndirectedEdge[139, 378] -> 
             RGBColor[
              0.27359029407982893`, 0.40489112407740385`, 0.9388919345560525],
              UndirectedEdge[272, 374] -> 
             RGBColor[
              0.19014395523747457`, 0.3171837311506246, 0.934139789006776], 
             UndirectedEdge[21, 114] -> 
             RGBColor[
              0.19167285067202883`, 0.3187906971899105, 0.9342268573399758], 
             UndirectedEdge[250, 321] -> 
             RGBColor[
              0.18913677562513462`, 0.3161251215191795, 0.934082431617842], 
             UndirectedEdge[19, 152] -> 
             RGBColor[
              0.2001783639532218, 0.3277305309291337, 0.9347112337385604], 
             UndirectedEdge[270, 336] -> 
             RGBColor[
              0.2213730230293102, 0.3500074614371033, 0.9359182382182554], 
             UndirectedEdge[87, 277] -> 
             RGBColor[
              0.18598156789951187`, 0.3128087981478258, 0.9339027472055792], 
             UndirectedEdge[37, 377] -> 
             RGBColor[
              0.2695128080367538, 0.400605427718585, 0.9386597277579993], 
             UndirectedEdge[312, 356] -> 
             RGBColor[
              0.746600049419986, 0.8012844499471021, 0.9674404180913663], 
             UndirectedEdge[294, 343] -> 
             RGBColor[
              0.20522639813651683`, 0.33303633491963003`, 0.9349987118174017],
              UndirectedEdge[170, 349] -> 
             RGBColor[
              0.21695935367547547`, 0.34536841510342303`, 0.9356668862779931],
              UndirectedEdge[176, 390] -> 
             RGBColor[
              0.199593709897452, 0.3271160224473115, 0.9346779385550025], 
             UndirectedEdge[235, 327] -> 
             RGBColor[
              0.1895062149755763, 0.31651342570030144`, 0.934103470642313], 
             UndirectedEdge[271, 400] -> 
             RGBColor[
              0.8207069079646563, 0.1601679452070842, 0.16746226449304957`], 
             UndirectedEdge[45, 103] -> 
             RGBColor[
              0.21725551419299843`, 0.345679698585001, 0.9356837521813359], 
             UndirectedEdge[30, 343] -> 
             RGBColor[
              0.2007094287814945, 0.32828871373510315`, 0.9347414770948905], 
             UndirectedEdge[200, 234] -> 
             RGBColor[
              0.22049169370930496`, 0.34908112844227146`, 0.9358680478172909],
              UndirectedEdge[282, 382] -> 
             RGBColor[
              0.3185597546508585, 0.45034218102492296`, 0.9415193237683902], 
             UndirectedEdge[305, 382] -> 
             RGBColor[
              0.31007770460075973`, 0.44200741025601153`, 0.9410150322193817],
              UndirectedEdge[50, 164] -> 
             RGBColor[
              0.22306024288786463`, 0.3517808364843617, 0.9360143228931819], 
             UndirectedEdge[259, 287] -> 
             RGBColor[
              0.8433542070105785, 0.39590176780986674`, 0.4394411979268815], 
             UndirectedEdge[90, 95] -> 
             RGBColor[
              0.23140010342565426`, 0.3605465586872775, 0.936489265613091], 
             UndirectedEdge[44, 243] -> 
             RGBColor[
              0.2298536898894718, 0.3589211800124685, 0.9364011996499193], 
             UndirectedEdge[82, 194] -> 
             RGBColor[
              0.6075992658363466, 0.6905170696190597, 0.963481170694517], 
             UndirectedEdge[124, 150] -> 
             RGBColor[
              0.2325126629936997, 0.36171592933364405`, 0.9365526242346068], 
             UndirectedEdge[233, 316] -> 
             RGBColor[
              0.8412361363066468, 0.8762214650435611, 0.9535246374949702], 
             UndirectedEdge[87, 390] -> 
             RGBColor[
              0.19991574882843044`, 0.32745450578221735`, 0.9346962781957078],
              UndirectedEdge[72, 376] -> 
             RGBColor[
              0.3758578545249899, 0.4975526740121381, 0.9453383722532241], 
             UndirectedEdge[99, 169] -> 
             RGBColor[
              0.6797124063510102, 0.7475445119943138, 0.9704734146298177], 
             UndirectedEdge[127, 137] -> 
             RGBColor[
              0.31600670483300364`, 0.4466421785419929, 0.9414111535240912], 
             UndirectedEdge[68, 391] -> 
             RGBColor[
              0.8206909281236954, 0.3912194139027702, 0.4389552580327404], 
             UndirectedEdge[292, 309] -> 
             RGBColor[
              0.778783487932468, 0.35505497183403256`, 0.43435605547208284`], 
             UndirectedEdge[88, 140] -> 
             RGBColor[
              0.41837127081473313`, 0.5367938996534025, 0.947879225318494], 
             UndirectedEdge[153, 216] -> 
             RGBColor[
              0.21073387590110806`, 0.33882504324447416`, 0.935312354528512], 
             UndirectedEdge[145, 165] -> 
             RGBColor[
              0.23770682741222313`, 0.3671753254665574, 0.9368484242141641], 
             UndirectedEdge[37, 76] -> 
             RGBColor[
              0.28363325287465024`, 0.4154469105311262, 0.9394638662021915], 
             UndirectedEdge[6, 391] -> 
             RGBColor[
              0.8555439090552986, 0.41901023483866595`, 0.44227956646762], 
             UndirectedEdge[203, 206] -> 
             RGBColor[
              0.36944897924090714`, 0.4944198695980247, 0.9447619401596937], 
             UndirectedEdge[298, 320] -> 
             RGBColor[
              0.19458686072830475`, 0.3218535065179652, 0.9343928059017892], 
             UndirectedEdge[39, 164] -> 
             RGBColor[
              0.20658345954088297`, 0.3344626924982814, 0.9350759944567879], 
             UndirectedEdge[107, 156] -> 
             RGBColor[
              0.2124764155335251, 0.34065656288153834`, 0.9354115895827217], 
             UndirectedEdge[31, 222] -> 
             RGBColor[
              0.967672940132394, 0.9754000826172251, 0.9391115323234271], 
             UndirectedEdge[301, 329] -> 
             RGBColor[
              0.25610352101831557`, 0.38651141686430435`, 0.9378960886995618],
              UndirectedEdge[126, 320] -> 
             RGBColor[
              0.18313368370358218`, 0.3098154912916167, 0.9337405644136882], 
             UndirectedEdge[49, 191] -> 
             RGBColor[
              0.18385357890938503`, 0.3105721467969078, 0.933781561380669], 
             UndirectedEdge[122, 173] -> 
             RGBColor[
              0.18447873947082444`, 0.3112292301844495, 0.9338171633498009], 
             UndirectedEdge[60, 102] -> 
             RGBColor[
              0.5280292771941157, 0.6238948638185677, 0.9574471733011694], 
             UndirectedEdge[120, 380] -> 
             RGBColor[
              0.5664649447415552, 0.6566185624069654, 0.9601363872621158], 
             UndirectedEdge[110, 247] -> 
             RGBColor[
              0.8292133862002847, 0.38471694368869236`, 0.43810378344252143`],
              UndirectedEdge[59, 149] -> 
             RGBColor[
              0.21329928840113216`, 0.34152145443854653`, 0.9354584509752006],
              UndirectedEdge[92, 346] -> 
             RGBColor[
              0.2038983093069455, 0.33164042935405524`, 0.934923079123289], 
             UndirectedEdge[6, 142] -> 
             RGBColor[
              0.7001614603741532, 0.763972329138221, 0.9722831025823769], 
             UndirectedEdge[176, 232] -> 
             RGBColor[
              0.18828223277850703`, 0.3152269428062281, 0.9340337666669094], 
             UndirectedEdge[60, 345] -> 
             RGBColor[
              0.7675537628448912, 0.8184035673483785, 0.9774488709937861], 
             UndirectedEdge[79, 126] -> 
             RGBColor[
              0.19080527822884924`, 0.31787882354485875`, 0.9341774503727951],
              UndirectedEdge[14, 212] -> 
             RGBColor[
              0.45821441723172895`, 0.5679246084974616, 0.9513517397459614], 
             UndirectedEdge[22, 338] -> 
             RGBColor[
              0.2260845393342366, 0.35495956380096844`, 0.9361865521017572], 
             UndirectedEdge[195, 389] -> 
             RGBColor[
              0.7088707754207897, 0.764952224756877, 0.7205833028362763], 
             UndirectedEdge[14, 293] -> 
             RGBColor[
              0.32638953387049785`, 0.45712394224882835`, 0.9420182303766638],
              UndirectedEdge[201, 394] -> 
             RGBColor[
              0.5116695891716139, 0.6114793927942537, 0.9556621742335425], 
             UndirectedEdge[20, 189] -> 
             RGBColor[
              0.30889970680782364`, 0.4349879582915822, 0.9411596287595527], 
             UndirectedEdge[195, 359] -> 
             RGBColor[
              0.375153965132881, 0.49936124163672424`, 0.9451254568160093], 
             UndirectedEdge[222, 224] -> 
             RGBColor[
              0.724417520241849, 0.7830873105778803, 0.9606419773233753], 
             UndirectedEdge[54, 389] -> 
             RGBColor[
              0.9706885388162402, 0.9101251515870772, 0.3850556620267193], 
             UndirectedEdge[123, 366] -> 
             RGBColor[
              0.8932052278936042, 0.5511829000640883, 0.29668448216333426`], 
             UndirectedEdge[120, 263] -> 
             RGBColor[
              0.3571898835204337, 0.4831624157488532, 0.9440042071759314], 
             UndirectedEdge[332, 364] -> 
             RGBColor[
              0.8523160600837335, 0.33385457930663953`, 0.1949772735327932], 
             UndirectedEdge[70, 228] -> 
             RGBColor[
              0.21048617188066365`, 0.3385646906136451, 0.9352982481509928], 
             UndirectedEdge[74, 141] -> 
             RGBColor[
              0.3021503369999872, 0.43056214369424695`, 0.9406775662244785], 
             UndirectedEdge[212, 385] -> 
             RGBColor[
              0.7860985506073723, 0.8292872838004639, 0.7968353358505167], 
             UndirectedEdge[256, 384] -> 
             RGBColor[
              0.9629443447193516, 0.8827390749129462, 0.5213129511813582], 
             UndirectedEdge[158, 317] -> 
             RGBColor[
              0.18982224071375664`, 0.31684558878831803`, 0.9341214678405843],
              UndirectedEdge[76, 208] -> 
             RGBColor[
              0.28867650153937047`, 0.420747684638181, 0.9397510717528295], 
             UndirectedEdge[101, 253] -> 
             RGBColor[
              0.8443799630600709, 0.34212942026933035`, 0.1901316087873103], 
             UndirectedEdge[111, 309] -> 
             RGBColor[
              0.7835302879454197, 0.39154095679460776`, 0.43890159652522914`],
              UndirectedEdge[145, 170] -> 
             RGBColor[
              0.24268853638713495`, 0.37241141745778183`, 0.9371321251705074],
              UndirectedEdge[59, 279] -> 
             RGBColor[
              0.2076546436516325, 0.3355885749156745, 0.9351369968072203], 
             UndirectedEdge[83, 334] -> 
             RGBColor[
              0.9555982588691752, 0.9202058525384339, 0.6338919338224923], 
             UndirectedEdge[242, 312] -> 
             RGBColor[
              0.4441075478761082, 0.5565195124327971, 0.9502280720328274], 
             UndirectedEdge[140, 356] -> 
             RGBColor[
              0.6758651089866358, 0.7425832566534856, 0.9622242963377263], 
             UndirectedEdge[172, 316] -> 
             RGBColor[
              0.5458822960971526, 0.6391409074229324, 0.9586767421820886], 
             UndirectedEdge[217, 331] -> 
             RGBColor[
              0.22460790707912992`, 0.3534075296769589, 0.9361024600793104], 
             UndirectedEdge[263, 336] -> 
             RGBColor[
              0.2683165494931898, 0.3993480841421268, 0.9385916026036494], 
             UndirectedEdge[122, 338] -> 
             RGBColor[
              0.19975108063826336`, 0.32728142907378543`, 0.9346869005858826],
              UndirectedEdge[303, 400] -> 
             RGBColor[
              0.8460534982430635, 0.31774288769115266`, 0.1902755691417824], 
             UndirectedEdge[133, 367] -> 
             RGBColor[
              0.18474901765317286`, 0.31151330969072427`, 0.9338325552924449],
              UndirectedEdge[136, 279] -> 
             RGBColor[
              0.19083656061449622`, 0.3179117033155916, 0.9341792318583795], 
             UndirectedEdge[117, 365] -> 
             RGBColor[
              0.4322742926857367, 0.5457268859697086, 0.94956369337159], 
             UndirectedEdge[33, 245] -> 
             RGBColor[
              0.22074175679161856`, 0.34934396059669826`, 0.9358822885398935],
              UndirectedEdge[162, 368] -> 
             RGBColor[
              0.18956500601498782`, 0.31657521881029016`, 0.934106818705034], 
             UndirectedEdge[46, 128] -> 
             RGBColor[
              0.5547192055800235, 0.6423805327309791, 0.9609350717272003], 
             UndirectedEdge[117, 269] -> 
             RGBColor[
              0.45596747114210545`, 0.5665010427125681, 0.9510641632117192], 
             UndirectedEdge[98, 134] -> 
             RGBColor[
              0.1861818864522268, 0.313019345647659, 0.9339141550508117], 
             UndirectedEdge[90, 326] -> 
             RGBColor[
              0.22857029923452804`, 0.35757225506245527`, 0.9363281124507266],
              UndirectedEdge[119, 306] -> 
             RGBColor[
              0.2310448890646134, 0.36017320587193224`, 0.9364690366807222], 
             UndirectedEdge[150, 211] -> 
             RGBColor[
              0.23544785722092995`, 0.3648010045685258, 0.9367197792036168], 
             UndirectedEdge[388, 395] -> 
             RGBColor[
              0.35473118198517756`, 0.4781619748017699, 0.9439526563033052], 
             UndirectedEdge[102, 108] -> 
             RGBColor[
              0.3276991764172302, 0.45803801914073383`, 0.9421097447928497], 
             UndirectedEdge[15, 392] -> 
             RGBColor[
              0.19259602959164984`, 0.3197610167673564, 0.9342794310137273], 
             UndirectedEdge[32, 292] -> 
             RGBColor[
              0.820843205790226, 0.16121559002050154`, 0.16759278344474157`], 
             UndirectedEdge[115, 332] -> 
             RGBColor[
              0.8635725695202401, 0.3784828882129811, 0.20403452524964213`], 
             UndirectedEdge[93, 293] -> 
             RGBColor[
              0.3283292569566383, 0.4588040328927261, 0.9421418278164828], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.1906510637312114, 0.3177167343300775, 0.9341686680852945], 
             UndirectedEdge[276, 305] -> 
             RGBColor[
              0.33855234976798615`, 0.46667071672258365`, 0.9428294114302973],
              UndirectedEdge[75, 347] -> 
             RGBColor[
              0.18311704522785527`, 0.30979800319868733`, 0.9337396168771099],
              UndirectedEdge[64, 193] -> 
             RGBColor[
              0.9152566921622731, 0.9300770448033753, 0.7093659477350615], 
             UndirectedEdge[18, 99] -> 
             RGBColor[
              0.947350971343756, 0.9556350172112698, 0.7097411277967336], 
             UndirectedEdge[74, 290] -> 
             RGBColor[
              0.2530317916874394, 0.3832828345786652, 0.9377211582583846], 
             UndirectedEdge[39, 230] -> 
             RGBColor[
              0.20964976351428055`, 0.33768557238922303`, 0.9352506159318827],
              UndirectedEdge[259, 345] -> 
             RGBColor[
              0.8617541752858404, 0.8926034039517254, 0.9866760766074392], 
             UndirectedEdge[30, 168] -> 
             RGBColor[
              0.19933167973369648`, 0.3268406121315325, 0.9346630163248155], 
             UndirectedEdge[231, 331] -> 
             RGBColor[
              0.21608777115484973`, 0.34445232661272185`, 0.9356172509428343],
              UndirectedEdge[137, 242] -> 
             RGBColor[
              0.31652160790723577`, 0.4470881617051118, 0.9414439626926704], 
             UndirectedEdge[172, 221] -> 
             RGBColor[
              0.3747675504331488, 0.4990265486455837, 0.9451008348130354], 
             UndirectedEdge[157, 211] -> 
             RGBColor[
              0.23967520555955008`, 0.36924421570178084`, 0.9369605204376998],
              UndirectedEdge[46, 213] -> 
             RGBColor[
              0.5654749182769274, 0.6521444572622102, 0.9616040176321952], 
             UndirectedEdge[184, 318] -> 
             RGBColor[
              0.2135047362690546, 0.34173739317388024`, 0.935470150927346], 
             UndirectedEdge[201, 293] -> 
             RGBColor[
              0.4899219075938762, 0.5926426440818758, 0.9542764311941287], 
             UndirectedEdge[64, 115] -> 
             RGBColor[
              0.973846560757742, 0.9231368127839409, 0.35853265585475147`], 
             UndirectedEdge[174, 266] -> 
             RGBColor[
              0.5380286912692482, 0.6346285303347542, 0.9572070721400225], 
             UndirectedEdge[80, 104] -> 
             RGBColor[
              0.2135778861880246, 0.34181427837669043`, 0.9354743167070156], 
             UndirectedEdge[265, 321] -> 
             RGBColor[
              0.19177497299708612`, 0.31889803422847507`, 0.9342326730553113],
              UndirectedEdge[178, 296] -> 
             RGBColor[
              0.18104204814496305`, 0.30761704970215387`, 0.9336214488629224],
              UndirectedEdge[114, 249] -> 
             RGBColor[
              0.18514988407402466`, 0.3119346457154385, 0.9338553840420838], 
             UndirectedEdge[255, 380] -> 
             RGBColor[
              0.5472854839726642, 0.6400062774766795, 0.9589142889816533], 
             UndirectedEdge[253, 391] -> 
             RGBColor[
              0.8235396690014747, 0.18194178785987172`, 0.17017491966105283`],
              UndirectedEdge[40, 63] -> 
             RGBColor[
              0.19138658757193353`, 0.3184898165215815, 0.9342105550799136], 
             UndirectedEdge[23, 311] -> 
             RGBColor[
              0.2072579319428704, 0.33517160575679045`, 0.9351144046622886], 
             UndirectedEdge[156, 396] -> 
             RGBColor[
              0.19313485512094197`, 0.32032735656215416`, 0.9343101163304997],
              UndirectedEdge[93, 281] -> 
             RGBColor[
              0.3706399848182322, 0.4954514587674228, 0.944837829981916], 
             UndirectedEdge[27, 325] -> 
             RGBColor[
              0.22165235452841858`, 0.35030105655330623`, 0.9359341457338957],
              UndirectedEdge[12, 107] -> 
             RGBColor[
              0.23293330946253646`, 0.362158055442918, 0.9365765794287164], 
             UndirectedEdge[255, 312] -> 
             RGBColor[
              0.46100266352577723`, 0.571153212435337, 0.9513046138622602], 
             UndirectedEdge[257, 310] -> 
             RGBColor[
              0.8741512138365515, 0.46212106330300473`, 0.4275663759812295], 
             UndirectedEdge[50, 197] -> 
             RGBColor[
              0.21121964795225362`, 0.33933562046995513`, 0.9353400185281894],
              UndirectedEdge[215, 350] -> 
             RGBColor[
              0.5273081197953102, 0.6233107010129518, 0.9573840940310441], 
             UndirectedEdge[49, 235] -> 
             RGBColor[
              0.1884735679979762, 0.31542804825324383`, 0.9340446629246031], 
             UndirectedEdge[239, 323] -> 
             RGBColor[
              0.4638795886223883, 0.5747495967298069, 0.9511827422942791], 
             UndirectedEdge[211, 216] -> 
             RGBColor[
              0.22415272438939332`, 0.35292910380979625`, 0.9360765380985124],
              UndirectedEdge[98, 151] -> 
             RGBColor[
              0.20043054064394245`, 0.3279955846200067, 0.934725594828035], 
             UndirectedEdge[10, 32] -> 
             RGBColor[
              0.8358176878937263, 0.2763160213279036, 0.18193236441831204`], 
             UndirectedEdge[330, 367] -> 
             RGBColor[
              0.1873967228823739, 0.314296215760822, 0.9339833381883191], 
             UndirectedEdge[99, 384] -> 
             RGBColor[
              0.9178754148881313, 0.8496097092612407, 0.6279747633092586], 
             UndirectedEdge[127, 138] -> 
             RGBColor[
              0.31413697275722113`, 0.44467697158248487`, 0.9413046750483962],
              UndirectedEdge[292, 385] -> 
             RGBColor[
              0.8778004509205923, 0.4307085290171253, 0.32212137286959003`], 
             UndirectedEdge[177, 219] -> 
             RGBColor[
              0.18016175523476746`, 0.3066918060397442, 0.9335713174839634], 
             UndirectedEdge[170, 322] -> 
             RGBColor[
              0.2153075934140704, 0.3436323103410369, 0.9355728209746665], 
             UndirectedEdge[261, 335] -> 
             RGBColor[
              0.19373393161436922`, 0.3209570239403897, 0.934344232850546], 
             UndirectedEdge[6, 253] -> 
             RGBColor[
              0.858849364854881, 0.44441741657422273`, 0.4454448746742784], 
             UndirectedEdge[95, 246] -> 
             RGBColor[
              0.23196638865379215`, 0.3611417603666076, 0.9365215147190895], 
             UndirectedEdge[50, 331] -> 
             RGBColor[
              0.2360482874744978, 0.36543209483450245`, 0.9367539728183005], 
             UndirectedEdge[9, 358] -> 
             RGBColor[
              0.48197798109692647`, 0.5820052784935108, 0.954246805716025], 
             UndirectedEdge[99, 144] -> 
             RGBColor[
              0.7417116613175341, 0.797878300210745, 0.9753542230915366], 
             UndirectedEdge[2, 28] -> 
             RGBColor[
              0.1967107027357332, 0.32408579912713337`, 0.9345137555621694], 
             UndirectedEdge[138, 258] -> 
             RGBColor[
              0.26327890753170885`, 0.39405320303566205`, 0.9383047163464664],
              UndirectedEdge[144, 384] -> 
             RGBColor[
              0.757420984754537, 0.7226612405223014, 0.6127983851533676], 
             UndirectedEdge[79, 277] -> 
             RGBColor[
              0.19208286823872933`, 0.31922165164912797`, 0.9342502072338328],
              UndirectedEdge[346, 354] -> 
             RGBColor[
              0.1997636988090205, 0.3272946915712895, 0.9346876191720402], 
             UndirectedEdge[144, 148] -> 
             RGBColor[
              0.41890511783186646`, 0.5289568419765102, 0.9490497655266936], 
             UndirectedEdge[38, 346] -> 
             RGBColor[
              0.23107597310122763`, 0.36020587716525554`, 0.9364708068706228],
              UndirectedEdge[38, 363] -> 
             RGBColor[
              0.3166257823122153, 0.444042358182842, 0.9415654261663287], 
             UndirectedEdge[78, 104] -> 
             RGBColor[
              0.22225745398096258`, 0.35093705444345114`, 0.9359686052525535],
              UndirectedEdge[95, 282] -> 
             RGBColor[
              0.2811273621289757, 0.41223265884799526`, 0.9393424107780823], 
             UndirectedEdge[92, 306] -> 
             RGBColor[
              0.21333519209183469`, 0.34155919149390046`, 0.9354604956372714],
              UndirectedEdge[9, 339] -> 
             RGBColor[
              0.5341582021850244, 0.6300810922914106, 0.9574662349562233], 
             UndirectedEdge[36, 148] -> 
             RGBColor[
              0.2511034439451054, 0.38125601883716365`, 0.9376113417071936], 
             UndirectedEdge[62, 395] -> 
             RGBColor[
              0.7152423649203183, 0.772631878073945, 0.8673341109470382], 
             UndirectedEdge[32, 247] -> 
             RGBColor[
              0.820125492552776, 0.15569893157351436`, 0.16690550043801822`], 
             UndirectedEdge[168, 379] -> 
             RGBColor[
              0.190216267574, 0.31725973600117974`, 0.9341439070873645], 
             UndirectedEdge[137, 230] -> 
             RGBColor[
              0.2568850160495337, 0.38733281769176137`, 0.9379405936854713], 
             UndirectedEdge[268, 279] -> 
             RGBColor[
              0.19334852815726622`, 0.3205519404709839, 0.9343222846938173], 
             UndirectedEdge[185, 288] -> 
             RGBColor[
              0.2031417930336449, 0.3308452827849142, 0.93487999664069], 
             UndirectedEdge[233, 310] -> 
             RGBColor[
              0.8744547972846617, 0.4623474753415331, 0.4270524883908231], 
             UndirectedEdge[150, 386] -> 
             RGBColor[
              0.29016677848912364`, 0.4192462598996066, 0.9399482680174902], 
             UndirectedEdge[138, 281] -> 
             RGBColor[
              0.3438282004171828, 0.4703940206570502, 0.9431965738199672], 
             UndirectedEdge[88, 257] -> 
             RGBColor[
              0.6999080745469857, 0.7619616397704058, 0.9426465587738788], 
             UndirectedEdge[27, 40] -> 
             RGBColor[
              0.19924073649984758`, 0.3267450250266232, 0.9346578372421862], 
             UndirectedEdge[159, 250] -> 
             RGBColor[
              0.18793077615893167`, 0.3148575396154177, 0.934013751732358], 
             UndirectedEdge[169, 363] -> 
             RGBColor[
              0.4158922643017966, 0.5345397089893019, 0.947750829584961], 
             UndirectedEdge[144, 382] -> 
             RGBColor[
              0.451676599366216, 0.5621674511867154, 0.9509612465314614], 
             UndirectedEdge[35, 207] -> 
             RGBColor[
              0.19080850531779897`, 0.3178822154199542, 0.9341776341507367], 
             UndirectedEdge[71, 287] -> 
             RGBColor[
              0.8681139584839492, 0.4150599268113716, 0.4215345385839855], 
             UndirectedEdge[148, 361] -> 
             RGBColor[
              0.33306353105933184`, 0.4580790241212378, 0.94262018039587], 
             UndirectedEdge[215, 393] -> 
             RGBColor[
              0.7140213652809209, 0.7765181844116039, 0.9721306348483233], 
             UndirectedEdge[33, 124] -> 
             RGBColor[
              0.23660403432322674`, 0.366016220008902, 0.9367856217791819], 
             UndirectedEdge[31, 111] -> 
             RGBColor[
              0.8791608526585568, 0.4662912982465486, 0.4189256344996925], 
             UndirectedEdge[113, 357] -> 
             RGBColor[
              0.18582607626581804`, 0.31264536658207454`, 0.9338938921870696],
              UndirectedEdge[30, 329] -> 
             RGBColor[
              0.23151896311630302`, 0.36067148775828894`, 0.9364960344966363],
              UndirectedEdge[117, 239] -> 
             RGBColor[
              0.5328344578573876, 0.6316180426642315, 0.9563658268409162], 
             UndirectedEdge[209, 338] -> 
             RGBColor[
              0.23759083072429804`, 0.3670534055929334, 0.9368418183743885], 
             UndirectedEdge[208, 323] -> 
             RGBColor[
              0.3575199332630081, 0.48276280813906464`, 0.9440503364383386], 
             UndirectedEdge[71, 212] -> 
             RGBColor[
              0.7737416965530766, 0.822516123696677, 0.9480358411696325], 
             UndirectedEdge[199, 292] -> 
             RGBColor[
              0.8759065071929455, 0.430422481595631, 0.3896462592485583], 
             UndirectedEdge[11, 386] -> 
             RGBColor[
              0.6075598618760001, 0.6861529495738531, 0.9653876814635047], 
             UndirectedEdge[130, 267] -> 
             RGBColor[
              0.20661372269188627`, 0.33449450098878053`, 0.9350777178984673],
              UndirectedEdge[67, 347] -> 
             RGBColor[
              0.18186543483400505`, 0.3084824813180684, 0.9336683395167719], 
             UndirectedEdge[211, 358] -> 
             RGBColor[
              0.2550430737157216, 0.3853968195130357, 0.9378356977944702], 
             UndirectedEdge[2, 164] -> 
             RGBColor[
              0.20840908696131982`, 0.3363815426686245, 0.935179961237608], 
             UndirectedEdge[266, 358] -> 
             RGBColor[
              0.4679094050103473, 0.5710147999295367, 0.9528445815300333], 
             UndirectedEdge[57, 397] -> 
             RGBColor[
              0.3562392675894767, 0.4829782813049682, 0.943920229014154], 
             UndirectedEdge[209, 386] -> 
             RGBColor[
              0.30348621877337745`, 0.4332458361396474, 0.9407067904373323], 
             UndirectedEdge[74, 386] -> 
             RGBColor[
              0.29523037248077955`, 0.42456841823523894`, 0.9402366322043989],
              UndirectedEdge[47, 268] -> 
             RGBColor[
              0.18433220446865944`, 0.3110752126063183, 0.9338088183982067], 
             UndirectedEdge[108, 397] -> 
             RGBColor[
              0.3352715846751584, 0.4645968585734458, 0.9425922519510271], 
             UndirectedEdge[157, 358] -> 
             RGBColor[
              0.2622292284500658, 0.3929499237673575, 0.938244938675628], 
             UndirectedEdge[10, 129] -> 
             RGBColor[
              0.8350901197191642, 0.27072361351581226`, 0.18123564431268066`],
              UndirectedEdge[171, 308] -> 
             RGBColor[
              0.20045056014029836`, 0.3280166263799862, 0.9347267349087363], 
             UndirectedEdge[225, 335] -> 
             RGBColor[
              0.20337317791570175`, 0.3310884829666048, 0.93489317366742], 
             UndirectedEdge[45, 116] -> 
             RGBColor[
              0.23987123039501432`, 0.3694502502325462, 0.9369716837620867], 
             UndirectedEdge[261, 349] -> 
             RGBColor[
              0.19380914280268063`, 0.32103607566796977`, 0.9343485160164554],
              UndirectedEdge[118, 209] -> 
             RGBColor[
              0.3112464668184692, 0.43996737295489813`, 0.9412012665806477], 
             UndirectedEdge[329, 343] -> 
             RGBColor[
              0.23152940348291426`, 0.3606824612455548, 0.9364966290600697], 
             UndirectedEdge[163, 171] -> 
             RGBColor[
              0.18355378954190335`, 0.31025704916394076`, 0.9337644888196897],
              UndirectedEdge[106, 217] -> 
             RGBColor[
              0.1973830107710603, 0.32479243749905357`, 0.9345520425101908], 
             UndirectedEdge[55, 123] -> 
             RGBColor[
              0.830017651930728, 0.5040252837026356, 0.45299841203343794`], 
             UndirectedEdge[129, 353] -> 
             RGBColor[
              0.8773107079453166, 0.4290850996340871, 0.28001609828605356`], 
             UndirectedEdge[38, 66] -> 
             RGBColor[
              0.22742648369193186`, 0.3563700324050926, 0.9362629738476992], 
             UndirectedEdge[23, 119] -> 
             RGBColor[
              0.22585475434557115`, 0.35471804520867123`, 0.936173466186589], 
             UndirectedEdge[306, 354] -> 
             RGBColor[
              0.2092005815939097, 0.33721345371113465`, 0.9352250356860227], 
             UndirectedEdge[28, 39] -> 
             RGBColor[
              0.19488507531529636`, 0.3221669489567903, 0.9344097887813494], 
             UndirectedEdge[158, 267] -> 
             RGBColor[
              0.19435218965099377`, 0.3216068523367057, 0.934379441731101], 
             UndirectedEdge[194, 399] -> 
             RGBColor[
              0.40740786703989107`, 0.5272403351648417, 0.9471965661691704], 
             UndirectedEdge[102, 333] -> 
             RGBColor[
              0.6514056454646207, 0.7208926458479099, 0.9532948082895194], 
             UndirectedEdge[16, 80] -> 
             RGBColor[
              0.21603013302378776`, 0.34439174528250716`, 0.9356139685365383],
              UndirectedEdge[72, 333] -> 
             RGBColor[
              0.7096566263019076, 0.7710149507769987, 0.9570981774601166], 
             UndirectedEdge[167, 211] -> 
             RGBColor[
              0.23414776627805434`, 0.3634345265570368, 0.9366457409477322], 
             UndirectedEdge[193, 255] -> 
             RGBColor[
              0.606058461723811, 0.6860652101473173, 0.9647337421078497], 
             UndirectedEdge[168, 211] -> 
             RGBColor[
              0.2152267109388578, 0.3435472977313434, 0.935568214837358], 
             UndirectedEdge[70, 246] -> 
             RGBColor[
              0.2068329817370454, 0.33472495614706915`, 0.9350902043767244], 
             UndirectedEdge[322, 349] -> 
             RGBColor[
              0.19676296516777197`, 0.32414073025683565`, 0.9345167318303588],
              UndirectedEdge[193, 312] -> 
             RGBColor[
              0.6928723364666782, 0.7586931681891012, 0.9709743993376487], 
             UndirectedEdge[194, 221] -> 
             RGBColor[
              0.41267584437400284`, 0.5318031923554098, 0.9475322370266106], 
             UndirectedEdge[208, 221] -> 
             RGBColor[
              0.3321648835388723, 0.4608015384498717, 0.9424347350905069], 
             UndirectedEdge[112, 251] -> 
             RGBColor[
              0.18268323345773074`, 0.30934203952303163`, 0.9337149119385684],
              UndirectedEdge[297, 325] -> 
             RGBColor[
              0.267416015836295, 0.3984015661715987, 0.9385403185441094], 
             UndirectedEdge[170, 225] -> 
             RGBColor[
              0.22199301735031157`, 0.3506591147783862, 0.9359535459776369], 
             UndirectedEdge[27, 250] -> 
             RGBColor[
              0.19937642447535237`, 0.3268876416919933, 0.9346655644716588], 
             UndirectedEdge[67, 126] -> 
             RGBColor[
              0.18098291600078534`, 0.3075548980694286, 0.9336180813747896], 
             UndirectedEdge[12, 157] -> 
             RGBColor[
              0.24482342257705114`, 0.37465531820298625`, 0.937253703780742], 
             UndirectedEdge[316, 399] -> 
             RGBColor[
              0.5357585344043984, 0.6303722138797264, 0.9580316650391174], 
             UndirectedEdge[76, 377] -> 
             RGBColor[
              0.2688145572376063, 0.39987152185702324`, 0.9386199634079575], 
             UndirectedEdge[3, 51] -> 
             RGBColor[
              0.2187121116641707, 0.34721067488081686`, 0.9357667032524762], 
             UndirectedEdge[23, 186] -> 
             RGBColor[
              0.209250396089514, 0.3372658119044362, 0.9352278725478533], 
             UndirectedEdge[17, 319] -> 
             RGBColor[
              0.8292559200449149, 0.22587939825693307`, 0.17564880811583344`],
              UndirectedEdge[115, 360] -> 
             RGBColor[
              0.8089316906478522, 0.7980968050279984, 0.6248789386336926], 
             UndirectedEdge[131, 142] -> 
             RGBColor[
              0.6441352636384634, 0.7193460306737178, 0.9669266768382974], 
             UndirectedEdge[23, 130] -> 
             RGBColor[
              0.21379154943709947`, 0.3420388519985006, 0.935486484512964], 
             UndirectedEdge[348, 354] -> 
             RGBColor[
              0.19860265347109932`, 0.3260743593066081, 0.9346214993576583], 
             UndirectedEdge[76, 80] -> 
             RGBColor[
              0.24302079240522623`, 0.37276063959904404`, 0.9371510466592089],
              UndirectedEdge[38, 81] -> 
             RGBColor[
              0.2439408678768847, 0.37372769725591143`, 0.9372034435961902], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.22057742375863354`, 0.3491712361597149, 0.935872930016774], 
             UndirectedEdge[131, 281] -> 
             RGBColor[
              0.6064310569728814, 0.687254440774864, 0.9643678385927457], 
             UndirectedEdge[157, 167] -> 
             RGBColor[
              0.24133392101239853`, 0.37098763081135855`, 0.93705498182889], 
             UndirectedEdge[165, 172] -> 
             RGBColor[
              0.3025819493818708, 0.42881009810169846`, 0.9407829073040905], 
             UndirectedEdge[255, 331] -> 
             RGBColor[
              0.30757882188877433`, 0.4345645888368619, 0.9410490742458533], 
             UndirectedEdge[59, 268] -> 
             RGBColor[
              0.2019662570213913, 0.3296097199027477, 0.9348130516038419], 
             UndirectedEdge[161, 364] -> 
             RGBColor[
              0.9004423422818535, 0.6358848335091806, 0.23838402091941335`], 
             UndirectedEdge[149, 164] -> 
             RGBColor[
              0.21265948505393958`, 0.340848980554772, 0.9354220151210823], 
             UndirectedEdge[10, 52] -> 
             RGBColor[
              0.8916429525013146, 0.5507520246580102, 0.4032025959775474], 
             UndirectedEdge[132, 155] -> 
             RGBColor[
              0.18938684794258642`, 0.3163879633803221, 0.934096672866372], 
             UndirectedEdge[353, 400] -> 
             RGBColor[
              0.8791634122437909, 0.44332579673236017`, 0.28179025001460273`],
              UndirectedEdge[250, 265] -> 
             RGBColor[
              0.19635832810443649`, 0.32371543104779843`, 0.9344936883482087],
              UndirectedEdge[82, 233] -> 
             RGBColor[
              0.865044812104987, 0.8948209835298624, 0.9558976637938235], 
             UndirectedEdge[66, 81] -> 
             RGBColor[
              0.21264159429708712`, 0.3408301762349806, 0.9354209962689466], 
             UndirectedEdge[69, 201] -> 
             RGBColor[
              0.6192660008437627, 0.7014292931597987, 0.9634146436784279], 
             UndirectedEdge[84, 184] -> 
             RGBColor[
              0.21392003441563898`, 0.34217389785736374`, 0.9354938015424155],
              UndirectedEdge[180, 268] -> 
             RGBColor[
              0.1880422345433147, 0.314974689444274, 0.9340200991224608], 
             UndirectedEdge[17, 247] -> 
             RGBColor[
              0.8242207072500726, 0.18717654627145935`, 0.17082708265703297`],
              UndirectedEdge[188, 394] -> 
             RGBColor[
              0.3167171676025393, 0.44570099448454903`, 0.9415134165478973], 
             UndirectedEdge[241, 312] -> 
             RGBColor[
              0.41436397282412324`, 0.5281836244089898, 0.9484270661099586], 
             UndirectedEdge[81, 128] -> 
             RGBColor[
              0.2665289573662383, 0.3974692114768138, 0.9384898018765251], 
             UndirectedEdge[65, 198] -> 
             RGBColor[
              0.6026458427872066, 0.6834233570756016, 0.9643717480774334], 
             UndirectedEdge[356, 380] -> 
             RGBColor[
              0.8328828698668729, 0.8701375149884446, 0.9750500932107594], 
             UndirectedEdge[40, 265] -> 
             RGBColor[
              0.1962226401289317, 0.32357281438242835`, 0.9344859611187359], 
             UndirectedEdge[19, 168] -> 
             RGBColor[
              0.19873861175960342`, 0.3262172600880793, 0.9346292419810562], 
             UndirectedEdge[195, 241] -> 
             RGBColor[
              0.35276484059541724`, 0.47739540900316435`, 0.9437930699766406],
              UndirectedEdge[33, 141] -> 
             RGBColor[
              0.3011781143378584, 0.42954027603387246`, 0.9406221995821449], 
             UndirectedEdge[65, 100] -> 
             RGBColor[
              0.38210315454201915`, 0.5053802802265043, 0.9455682530202327], 
             UndirectedEdge[15, 207] -> 
             RGBColor[
              0.18682358813972555`, 0.3136938148074571, 0.9339506990126021], 
             UndirectedEdge[81, 135] -> 
             RGBColor[
              0.2822556151095555, 0.41153871876028536`, 0.9394754920042432], 
             UndirectedEdge[259, 271] -> 
             RGBColor[
              0.8451433755388915, 0.40965410113712897`, 0.44115450773017084`],
              UndirectedEdge[194, 233] -> 
             RGBColor[
              0.7128854689421396, 0.7730895863286765, 0.9426895386250231], 
             UndirectedEdge[101, 283] -> 
             RGBColor[
              0.8799566783602811, 0.5331818267657741, 0.22090624547796586`], 
             UndirectedEdge[145, 192] -> 
             RGBColor[
              0.25406976709764434`, 0.3843738125462326, 0.9377802694224489], 
             UndirectedEdge[68, 397] -> 
             RGBColor[
              0.5928919663607762, 0.6752224028696671, 0.9636363647773936], 
             UndirectedEdge[142, 201] -> 
             RGBColor[
              0.5699368421210522, 0.6613816598554264, 0.9595312716051138], 
             UndirectedEdge[146, 354] -> 
             RGBColor[
              0.197615256434939, 0.32503654241701563`, 0.9345652685571719], 
             UndirectedEdge[153, 329] -> 
             RGBColor[
              0.23399514583317907`, 0.36327411279277777`, 0.9366370494391784],
              UndirectedEdge[132, 279] -> 
             RGBColor[
              0.1959554713815859, 0.323292003089491, 0.9344707462538155], 
             UndirectedEdge[257, 389] -> 
             RGBColor[
              0.981271770948398, 0.982206986986089, 0.7147685106713391], 
             UndirectedEdge[107, 386] -> 
             RGBColor[
              0.2825040137132291, 0.4111922082727934, 0.9395118848995476], 
             UndirectedEdge[157, 203] -> 
             RGBColor[
              0.2784354581733116, 0.40986687435040126`, 0.9391721369966093], 
             UndirectedEdge[264, 281] -> 
             RGBColor[
              0.3293650670543722, 0.4551923504771167, 0.9423729197712435], 
             UndirectedEdge[244, 302] -> 
             RGBColor[
              0.18853043849765405`, 0.3154878227542032, 0.9340479016154273], 
             UndirectedEdge[46, 105] -> 
             RGBColor[
              0.8954193827902208, 0.9181003086598438, 0.937247307981482], 
             UndirectedEdge[126, 347] -> 
             RGBColor[
              0.18344187738111917`, 0.31013942238731573`, 0.9337581155876922],
              UndirectedEdge[129, 253] -> 
             RGBColor[
              0.8212882402079674, 0.16463631957058764`, 0.16801894890576527`],
              UndirectedEdge[14, 69] -> 
             RGBColor[
              0.45573362712038445`, 0.5659105913267511, 0.9511564428609628], 
             UndirectedEdge[118, 124] -> 
             RGBColor[
              0.29203302591126107`, 0.41977282835890883`, 0.9401070895447208],
              UndirectedEdge[181, 245] -> 
             RGBColor[
              0.1935081925729178, 0.3207197578951424, 0.9343313773460864], 
             UndirectedEdge[33, 152] -> 
             RGBColor[
              0.2237166408577273, 0.3524707523687224, 0.9360517037865118], 
             UndirectedEdge[47, 371] -> 
             RGBColor[
              0.18051873474236652`, 0.3070670141360388, 0.9335916469388172], 
             UndirectedEdge[131, 273] -> 
             RGBColor[
              0.6690783888345512, 0.7395959833828867, 0.9688902910234116], 
             UndirectedEdge[230, 299] -> 
             RGBColor[
              0.20475753633962784`, 0.33254353144354476`, 0.9349720108316877],
              UndirectedEdge[107, 181] -> 
             RGBColor[
              0.20760170595158578`, 0.3355329340364814, 0.935133982083517], 
             UndirectedEdge[4, 318] -> 
             RGBColor[
              0.20715075077545358`, 0.3350589515541568, 0.9351083008533645], 
             UndirectedEdge[10, 333] -> 
             RGBColor[
              0.8799035766623403, 0.5425287482789902, 0.44689524966387445`], 
             UndirectedEdge[152, 238] -> 
             RGBColor[
              0.20086303760420032`, 0.32845016634712887`, 0.9347502248900996],
              UndirectedEdge[50, 147] -> 
             RGBColor[
              0.23917140342485926`, 0.3687146877153205, 0.9369318296514377], 
             UndirectedEdge[39, 217] -> 
             RGBColor[
              0.2032105562120073, 0.33091755724521044`, 0.9348839126019717], 
             UndirectedEdge[98, 308] -> 
             RGBColor[
              0.20304826815792704`, 0.3307469822107151, 0.9348746705373756], 
             UndirectedEdge[31, 363] -> 
             RGBColor[
              0.6793920980440895, 0.7432878081939467, 0.9278140990011539], 
             UndirectedEdge[286, 386] -> 
             RGBColor[
              0.331585149915525, 0.4616241237277755, 0.94234929043675], 
             UndirectedEdge[137, 138] -> 
             RGBColor[
              0.29077492625511725`, 0.4229532620622423, 0.93987057393605], 
             UndirectedEdge[35, 372] -> 
             RGBColor[
              0.18502327958345532`, 0.31180157636866185`, 0.9338481741036404],
              UndirectedEdge[130, 158] -> 
             RGBColor[
              0.20340188077088672`, 0.3311186514872704, 0.9348948082525605], 
             UndirectedEdge[277, 373] -> 
             RGBColor[
              0.19154984531155025`, 0.31866141075705723`, 0.9342198523666666],
              UndirectedEdge[234, 365] -> 
             RGBColor[
              0.27647661087306347`, 0.4079248260301478, 0.9390563060275041], 
             UndirectedEdge[310, 316] -> 
             RGBColor[
              0.7883915446819063, 0.3948994518775877, 0.4393315589045834], 
             UndirectedEdge[218, 305] -> 
             RGBColor[
              0.42916789405553485`, 0.5422531768418173, 0.9494057845729981], 
             UndirectedEdge[155, 279] -> 
             RGBColor[
              0.19246829134850796`, 0.31962675577474187`, 0.9342721565097523],
              UndirectedEdge[32, 129] -> 
             RGBColor[
              0.8207912982104425, 0.1608166056162391, 0.16754307668771967`], 
             UndirectedEdge[92, 158] -> 
             RGBColor[
              0.19775538870657966`, 0.32518383031940923`, 0.9345732488827347],
              UndirectedEdge[332, 334] -> 
             RGBColor[
              0.865273808078536, 0.38439014871100835`, 0.20976553073467102`], 
             UndirectedEdge[268, 300] -> 
             RGBColor[
              0.1919105716037125, 0.31904055696148764`, 0.9342403951953585], 
             UndirectedEdge[224, 227] -> 
             RGBColor[
              0.3858696957004528, 0.504223043119987, 0.9462592294929938], 
             UndirectedEdge[25, 91] -> 
             RGBColor[
              0.47826887557608655`, 0.5848930154724093, 0.9527405987202289], 
             UndirectedEdge[74, 304] -> 
             RGBColor[
              0.2654021800822186, 0.39628489710950293`, 0.9384256335771177], 
             UndirectedEdge[86, 397] -> 
             RGBColor[
              0.3161394186740798, 0.4444877390569253, 0.9415027034007689], 
             UndirectedEdge[32, 111] -> 
             RGBColor[
              0.8232166057967019, 0.1794585825007891, 0.16986555397131473`], 
             UndirectedEdge[59, 394] -> 
             RGBColor[
              0.286948743301538, 0.41441249311708334`, 0.9398181488223927], 
             UndirectedEdge[170, 355] -> 
             RGBColor[
              0.2218222289646276, 0.3504796053564232, 0.9359438198317311], 
             UndirectedEdge[9, 56] -> 
             RGBColor[
              0.6023784760141789, 0.6874029877027437, 0.9623014191002394], 
             UndirectedEdge[44, 317] -> 
             RGBColor[
              0.2084087804726259, 0.3363812205295747, 0.9351799437835304], 
             UndirectedEdge[236, 262] -> 
             RGBColor[
              0.4369845815472029, 0.5513866495573997, 0.9494877616771007], 
             UndirectedEdge[119, 346] -> 
             RGBColor[
              0.2216080062797242, 0.35025444373208703`, 0.9359316201667398], 
             UndirectedEdge[80, 244] -> 
             RGBColor[
              0.1927330122426994, 0.31990499421881113`, 0.9342872319730569], 
             UndirectedEdge[20, 360] -> 
             RGBColor[
              0.523690607917635, 0.622017048024192, 0.9563749606192402], 
             UndirectedEdge[196, 206] -> 
             RGBColor[
              0.6365065028818196, 0.7122246861355508, 0.9667719599708235], 
             UndirectedEdge[187, 302] -> 
             RGBColor[
              0.20552429842574232`, 0.33334944701157526`, 0.9350156767981692],
              UndirectedEdge[147, 312] -> 
             RGBColor[
              0.3975158125820031, 0.5104751397594638, 0.9474675883087893], 
             UndirectedEdge[259, 400] -> 
             RGBColor[
              0.8465516858832649, 0.4204789915695107, 0.44250310730640185`], 
             UndirectedEdge[120, 312] -> 
             RGBColor[
              0.4801821242946682, 0.587765497365623, 0.9525267121427227], 
             UndirectedEdge[52, 60] -> 
             RGBColor[
              0.8480092281788032, 0.880384326820778, 0.9017418370121976], 
             UndirectedEdge[266, 384] -> 
             RGBColor[
              0.7959032258697958, 0.7536598609266292, 0.6159939861993788], 
             UndirectedEdge[135, 393] -> 
             RGBColor[
              0.5286635054610748, 0.6238093444947674, 0.9577562869015417], 
             UndirectedEdge[77, 244] -> 
             RGBColor[
              0.18965577385650711`, 0.31667062156674053`, 0.9341119877993296],
              UndirectedEdge[239, 385] -> 
             RGBColor[
              0.750777447641219, 0.8006120212149852, 0.7940547292395577], 
             UndirectedEdge[278, 296] -> 
             RGBColor[
              0.1835851599868279, 0.3102900214905575, 0.9337662753201197], 
             UndirectedEdge[267, 275] -> 
             RGBColor[
              0.19585412945824818`, 0.323185486302614, 0.9344649749812033], 
             UndirectedEdge[148, 340] -> 
             RGBColor[
              0.263972502592159, 0.39478221542066183`, 0.9383442155590771], 
             UndirectedEdge[202, 212] -> 
             RGBColor[
              0.45268550871471924`, 0.56313574583105, 0.9509994425842794], 
             UndirectedEdge[81, 346] -> 
             RGBColor[
              0.21629108370638292`, 0.34466602099514354`, 0.9356288292918702],
              UndirectedEdge[50, 217] -> 
             RGBColor[
              0.21968733955898895`, 0.34823570123129066`, 0.9358222410383658],
              UndirectedEdge[5, 183] -> 
             RGBColor[
              0.1877508166785864, 0.3146683907914848, 0.9340035033061785], 
             UndirectedEdge[313, 339] -> 
             RGBColor[
              0.3332875570200404, 0.460867825469856, 0.9425394482092617], 
             UndirectedEdge[4, 184] -> 
             RGBColor[
              0.20719899217930893`, 0.3351096563282905, 0.9351110481299474], 
             UndirectedEdge[104, 349] -> 
             RGBColor[
              0.21123195753513827`, 0.3393485586220395, 0.9353407195407242], 
             UndirectedEdge[119, 135] -> 
             RGBColor[
              0.2875725376828968, 0.4171271414972289, 0.9397782828791128], 
             UndirectedEdge[53, 273] -> 
             RGBColor[
              0.4633253395942303, 0.573810427068907, 0.9512742786711021], 
             UndirectedEdge[224, 259] -> 
             RGBColor[
              0.6965860849930616, 0.7612921063995717, 0.9717456253125671], 
             UndirectedEdge[110, 289] -> 
             RGBColor[
              0.6635885313279589, 0.7348104646113509, 0.9687942877706517], 
             UndirectedEdge[59, 155] -> 
             RGBColor[
              0.20108602021263303`, 0.3286845352065056, 0.9347629234197767], 
             UndirectedEdge[5, 29] -> 
             RGBColor[
              0.18632940584411195`, 0.31317439788179996`, 0.9339225560619441],
              UndirectedEdge[119, 311] -> 
             RGBColor[
              0.22119300122602184`, 0.3498182471078057, 0.9359079862428765], 
             UndirectedEdge[68, 72] -> 
             RGBColor[
              0.6435705389401349, 0.7187858683660439, 0.9669572267898132], 
             UndirectedEdge[121, 234] -> 
             RGBColor[
              0.2453302072944222, 0.37518798107295015`, 0.9372825644206755], 
             UndirectedEdge[20, 336] -> 
             RGBColor[
              0.3097133743307097, 0.43584317444763615`, 0.9412059659212678], 
             UndirectedEdge[17, 256] -> 
             RGBColor[
              0.8825424426584894, 0.4727787904011971, 0.3751504390784578], 
             UndirectedEdge[186, 272] -> 
             RGBColor[
              0.20161622991530592`, 0.3292418192212516, 0.9347931180779689], 
             UndirectedEdge[45, 304] -> 
             RGBColor[
              0.2609958832174149, 0.3916535997292371, 0.9381747014891992], 
             UndirectedEdge[165, 252] -> 
             RGBColor[
              0.21574093049341658`, 0.3440877750865875, 0.9355974988802704], 
             UndirectedEdge[106, 254] -> 
             RGBColor[
              0.18679837373704838`, 0.3136673128715579, 0.9339492630896711], 
             UndirectedEdge[144, 169] -> 
             RGBColor[
              0.5192579762174159, 0.6205960432553745, 0.9552970364739267], 
             UndirectedEdge[191, 355] -> 
             RGBColor[
              0.19607480659810572`, 0.32341743196834305`, 0.9344775422178556],
              UndirectedEdge[96, 377] -> 
             RGBColor[
              0.23316169487877575`, 0.36239810299585723`, 0.9365895856403053],
              UndirectedEdge[110, 303] -> 
             RGBColor[
              0.873446363467674, 0.7484181435664192, 0.6095212570798225], 
             UndirectedEdge[177, 260] -> 
             RGBColor[
              0.18516377148342406`, 0.31194924226322995`, 0.9338561749095045],
              UndirectedEdge[20, 88] -> 
             RGBColor[
              0.40751079531136875`, 0.5273871016357587, 0.9471872054229611], 
             UndirectedEdge[57, 68] -> 
             RGBColor[
              0.584951659196002, 0.6683449078949819, 0.9631304154261922], 
             UndirectedEdge[127, 264] -> 
             RGBColor[
              0.2996738393944105, 0.42947530140255136`, 0.9404810209996725], 
             UndirectedEdge[171, 186] -> 
             RGBColor[
              0.1973172314150955, 0.32472329922528254`, 0.9345482964731804], 
             UndirectedEdge[362, 385] -> 
             RGBColor[
              0.892844244734438, 0.9136671066548807, 0.806798376116899], 
             UndirectedEdge[109, 370] -> 
             RGBColor[
              0.18414849826566793`, 0.3108821257393283, 0.9337983566017154], 
             UndirectedEdge[123, 161] -> 
             RGBColor[
              0.8552873220803263, 0.4038002548740027, 0.1997084684807382], 
             UndirectedEdge[119, 213] -> 
             RGBColor[
              0.2826015926364835, 0.4128215587449884, 0.9394615386563896], 
             UndirectedEdge[140, 360] -> 
             RGBColor[
              0.5345510834209994, 0.6314238460418358, 0.9570669805147731], 
             UndirectedEdge[320, 347] -> 
             RGBColor[
              0.1840162025368019, 0.3107430745402564, 0.9337908225556705], 
             UndirectedEdge[10, 345] -> 
             RGBColor[
              0.8380059756120399, 0.5094315183430771, 0.453673951965273], 
             UndirectedEdge[169, 383] -> 
             RGBColor[
              0.4077881387207459, 0.527520322736191, 0.9472344418691334], 
             UndirectedEdge[154, 372] -> 
             RGBColor[
              0.18315975702077553`, 0.3098428960011307, 0.9337420492505304], 
             UndirectedEdge[167, 341] -> 
             RGBColor[
              0.2425749937598598, 0.37229207695749733`, 0.9371256590858552], 
             UndirectedEdge[186, 308] -> 
             RGBColor[
              0.20971443584181115`, 0.3377535471059201, 0.9352542989252615], 
             UndirectedEdge[145, 225] -> 
             RGBColor[
              0.22917757181567264`, 0.3582105370485437, 0.9363626957258434], 
             UndirectedEdge[12, 65] -> 
             RGBColor[
              0.30963980079837916`, 0.4365176650238572, 0.941174248166886], 
             UndirectedEdge[274, 288] -> 
             RGBColor[
              0.20843688657003606`, 0.3364107618199823, 0.9351815443841986], 
             UndirectedEdge[143, 171] -> 
             RGBColor[
              0.19347840745274208`, 0.320688451845352, 0.9343296811275554], 
             UndirectedEdge[167, 168] -> 
             RGBColor[
              0.21688542639170627`, 0.3452907128409211, 0.935662676228548], 
             UndirectedEdge[203, 341] -> 
             RGBColor[
              0.2796765309207728, 0.4111713204965401, 0.9392428142535747], 
             UndirectedEdge[114, 299] -> 
             RGBColor[
              0.1875337477163088, 0.31444023754916384`, 0.9339911415499016], 
             UndirectedEdge[154, 231] -> 
             RGBColor[
              0.18878970308862236`, 0.3157603262776354, 0.9340626663503354], 
             UndirectedEdge[218, 384] -> 
             RGBColor[
              0.7469305423915883, 0.7141446268230167, 0.6119725391027997], 
             UndirectedEdge[360, 380] -> 
             RGBColor[
              0.6915688443012366, 0.7589781043767949, 0.9698927773878063], 
             UndirectedEdge[98, 306] -> 
             RGBColor[
              0.20777436312467215`, 0.33571440767249217`, 0.9351438146541007],
              UndirectedEdge[57, 262] -> 
             RGBColor[
              0.35631608788520674`, 0.4830448191840292, 0.9439251239354682], 
             UndirectedEdge[152, 160] -> 
             RGBColor[
              0.19806967394342445`, 0.325514164030168, 0.9345911469620297], 
             UndirectedEdge[311, 354] -> 
             RGBColor[
              0.19934869375531813`, 0.32685849494700814`, 0.9346639852481768],
              UndirectedEdge[287, 303] -> 
             RGBColor[
              0.8428560193703771, 0.29316566393150867`, 0.187213659762262], 
             UndirectedEdge[222, 247] -> 
             RGBColor[
              0.8619216604353159, 0.4105330825046606, 0.4320513710856554], 
             UndirectedEdge[24, 206] -> 
             RGBColor[
              0.3445350824096081, 0.46835060878643464`, 0.9433388530787478], 
             UndirectedEdge[92, 308] -> 
             RGBColor[
              0.20860909712508957`, 0.3365917660321234, 0.9351913515205462], 
             UndirectedEdge[18, 266] -> 
             RGBColor[
              0.8253787823254205, 0.8596851688766582, 0.6977603506868537], 
             UndirectedEdge[28, 314] -> 
             RGBColor[
              0.18717488313259786`, 0.3140630481183549, 0.9339707047427519], 
             UndirectedEdge[128, 139] -> 
             RGBColor[
              0.3054227451460619, 0.43834904844198347`, 0.9407047455523833], 
             UndirectedEdge[160, 181] -> 
             RGBColor[
              0.19370887514270452`, 0.320930687999998, 0.9343428059215524], 
             UndirectedEdge[42, 296] -> 
             RGBColor[
              0.18148102360409654`, 0.30807844074235485`, 0.933646447865914], 
             UndirectedEdge[121, 289] -> 
             RGBColor[
              0.3589692840265578, 0.4787637861846151, 0.9444710719407625], 
             UndirectedEdge[22, 286] -> 
             RGBColor[
              0.2816381839372477, 0.41219449596583724`, 0.9393925574171622], 
             UndirectedEdge[128, 213] -> 
             RGBColor[
              0.3146576489473405, 0.4465145063990592, 0.9412870836406073], 
             UndirectedEdge[178, 398] -> 
             RGBColor[
              0.18190742429108608`, 0.30852661489974587`, 0.9336707307542348],
              UndirectedEdge[6, 129] -> 
             RGBColor[
              0.8549452081615826, 0.4144083574171603, 0.44170624981566164`], 
             UndirectedEdge[265, 375] -> 
             RGBColor[
              0.20089610111622702`, 0.32848491819461667`, 0.9347521078081966],
              UndirectedEdge[162, 270] -> 
             RGBColor[
              0.20162095796864934`, 0.3292467887050914, 0.9347933873336124], 
             UndirectedEdge[199, 271] -> 
             RGBColor[
              0.8762470859874794, 0.4330403194529975, 0.3899723978868326], 
             UndirectedEdge[60, 72] -> 
             RGBColor[
              0.5862802580314027, 0.6740171687476564, 0.9612505424717664], 
             UndirectedEdge[230, 258] -> 
             RGBColor[
              0.22938899732612533`, 0.3584327586651811, 0.9363747360958877], 
             UndirectedEdge[38, 135] -> 
             RGBColor[
              0.2970405045044002, 0.42707857493039736`, 0.9403174695829958], 
             UndirectedEdge[42, 67] -> 
             RGBColor[
              0.18164605198289263`, 0.3082518960318731, 0.9336558459879488], 
             UndirectedEdge[220, 352] -> 
             RGBColor[
              0.1830449444132805, 0.30972222067111355`, 0.9337355108423835], 
             UndirectedEdge[4, 226] -> 
             RGBColor[
              0.1963748100004493, 0.3237327545655205, 0.9344946269678038], 
             UndirectedEdge[134, 163] -> 
             RGBColor[
              0.17908461226291875`, 0.3055596604815222, 0.9335099757852068], 
             UndirectedEdge[25, 76] -> 
             RGBColor[
              0.32344841914925154`, 0.45219009338865274`, 0.9419182030554161],
              UndirectedEdge[250, 375] -> 
             RGBColor[
              0.19825790374427554`, 0.32571200548532114`, 0.9346018663707272],
              UndirectedEdge[50, 138] -> 
             RGBColor[
              0.26001645706684573`, 0.3906241607457843, 0.9381189246188555], 
             UndirectedEdge[24, 157] -> 
             RGBColor[
              0.2535215613420126, 0.38379761353881126`, 0.9377490499156633], 
             UndirectedEdge[127, 328] -> 
             RGBColor[
              0.2853602010040631, 0.41443075991720546`, 0.9396658804684725], 
             UndirectedEdge[107, 245] -> 
             RGBColor[
              0.20898762068619692`, 0.33698961829462715`, 0.9352129078773759],
              UndirectedEdge[16, 96] -> 
             RGBColor[
              0.22029148033523374`, 0.34887069149186156`, 0.9358566459618267],
              UndirectedEdge[42, 278] -> 
             RGBColor[
              0.18598976689484537`, 0.3128174158117676, 0.9339032141262342], 
             UndirectedEdge[51, 176] -> 
             RGBColor[
              0.19370665948804128`, 0.32092835920646634`, 0.9343426797432972],
              UndirectedEdge[33, 386] -> 
             RGBColor[
              0.2942581498186507, 0.4235465505748645, 0.9401812655620653], 
             UndirectedEdge[78, 187] -> 
             RGBColor[
              0.21840643996372563`, 0.3468893945429439, 0.9357492957013367], 
             UndirectedEdge[107, 150] -> 
             RGBColor[
              0.23074389884075946`, 0.35985684606277935`, 0.936451895732749], 
             UndirectedEdge[312, 360] -> 
             RGBColor[
              0.6052860238543496, 0.6901250393354524, 0.9622831022684131], 
             UndirectedEdge[78, 208] -> 
             RGBColor[
              0.257441859662032, 0.38791809563442126`, 0.9379723051054267], 
             UndirectedEdge[28, 197] -> 
             RGBColor[
              0.19145378666017485`, 0.3185604470239914, 0.9342143819685769], 
             UndirectedEdge[221, 316] -> 
             RGBColor[
              0.5410265117385101, 0.6349350710702945, 0.9583673358965574], 
             UndirectedEdge[243, 383] -> 
             RGBColor[
              0.29485575436090533`, 0.42265924207033345`, 0.9402707855274055],
              UndirectedEdge[83, 332] -> 
             RGBColor[
              0.8621982556376276, 0.41289639483243457`, 0.43240684643119587`],
              UndirectedEdge[98, 354] -> 
             RGBColor[
              0.19467499021807763`, 0.3219461361994489, 0.9343978247458558], 
             UndirectedEdge[46, 215] -> 
             RGBColor[
              0.7558037231431869, 0.8091588799312872, 0.9762951098017001], 
             UndirectedEdge[375, 381] -> 
             RGBColor[
              0.196072227977034, 0.3234147216741027, 0.9344773953692003], 
             UndirectedEdge[286, 304] -> 
             RGBColor[
              0.3017569575169641, 0.43334060260203944`, 0.9405382918094687], 
             UndirectedEdge[225, 235] -> 
             RGBColor[
              0.20086558407238086`, 0.32845284284664206`, 0.9347503699076954],
              UndirectedEdge[96, 225] -> 
             RGBColor[
              0.21005566506834547`, 0.33811220065819025`, 0.9352737314249091],
              UndirectedEdge[20, 389] -> 
             RGBColor[
              0.688874491712781, 0.747632448851442, 0.7193091573204213], 
             UndirectedEdge[259, 393] -> 
             RGBColor[
              0.808698190108407, 0.8510901979921818, 0.9814053247963395], 
             UndirectedEdge[97, 166] -> 
             RGBColor[
              0.27189959411517783`, 0.40311409121798647`, 0.9387956516942321],
              UndirectedEdge[115, 334] -> 
             RGBColor[
              0.9576597296930937, 0.8685855926092536, 0.2913334520501617], 
             UndirectedEdge[251, 260] -> 
             RGBColor[
              0.1869284496057658, 0.31380403085686637`, 0.9339566707179645], 
             UndirectedEdge[119, 344] -> 
             RGBColor[
              0.2156761634002051, 0.3440197007651513, 0.9355938104901265], 
             UndirectedEdge[329, 341] -> 
             RGBColor[
              0.2558412218032698, 0.3862357237585604, 0.9378811511473018], 
             UndirectedEdge[283, 334] -> 
             RGBColor[
              0.9460670651662169, 0.8226245407866379, 0.2820057220570269], 
             UndirectedEdge[1, 5] -> 
             RGBColor[
              0.18431548798727523`, 0.3110576425244974, 0.9338078664193217], 
             UndirectedEdge[364, 391] -> 
             RGBColor[
              0.8539355899833049, 0.3463029957972727, 0.1965281371936202], 
             UndirectedEdge[48, 295] -> 
             RGBColor[
              0.19691998178395526`, 0.3243057646758728, 0.9345256736943651], 
             UndirectedEdge[105, 199] -> 
             RGBColor[
              0.9870190215241651, 0.9889000460513815, 0.8647919372474027], 
             UndirectedEdge[281, 293] -> 
             RGBColor[
              0.356440478793437, 0.4831525603366694, 0.9439330500141462], 
             UndirectedEdge[216, 358] -> 
             RGBColor[
              0.24670674727990904`, 0.37663481187537284`, 0.9373609563364405],
              UndirectedEdge[100, 206] -> 
             RGBColor[
              0.40830029738828666`, 0.5280709286532568, 0.947237511797173], 
             UndirectedEdge[168, 341] -> 
             RGBColor[
              0.22365393842066325`, 0.35240484813180395`, 0.936048132975481], 
             UndirectedEdge[199, 259] -> 
             RGBColor[
              0.9420801867046171, 0.9545306309034027, 0.913114429015637], 
             UndirectedEdge[19, 24] -> 
             RGBColor[
              0.22984730742841403`, 0.35891447164122536`, 0.936400836178204], 
             UndirectedEdge[136, 299] -> 
             RGBColor[
              0.1855129526762866, 0.3123162538362948, 0.9338760602618706], 
             UndirectedEdge[64, 123] -> 
             RGBColor[
              0.8929669582944121, 0.5506732654841682, 0.2707503067207814], 
             UndirectedEdge[101, 334] -> 
             RGBColor[
              0.8893863599364948, 0.5697297884788785, 0.23285573762508466`], 
             UndirectedEdge[2, 328] -> 
             RGBColor[
              0.2165885293871429, 0.3449786552647677, 0.935645768383358], 
             UndirectedEdge[235, 349] -> 
             RGBColor[
              0.19583192039754477`, 0.3231621431716789, 0.9344637102080516], 
             UndirectedEdge[45, 290] -> 
             RGBColor[
              0.24862549482263574`, 0.3786515371983993, 0.9374702261704662], 
             UndirectedEdge[225, 327] -> 
             RGBColor[
              0.19712268368204472`, 0.3245188172228074, 0.9345372172675908], 
             UndirectedEdge[24, 386] -> 
             RGBColor[
              0.3010543278758621, 0.4306897646155703, 0.940568297848379], 
             UndirectedEdge[363, 393] -> 
             RGBColor[
              0.5482487832688899, 0.640773127747212, 0.9590042434848745], 
             UndirectedEdge[2, 258] -> 
             RGBColor[
              0.2197390144926751, 0.34829001486297484`, 0.935825183849393], 
             UndirectedEdge[8, 234] -> 
             RGBColor[
              0.2512674523014992, 0.38142840201846384`, 0.9376206817404615], 
             UndirectedEdge[44, 151] -> 
             RGBColor[
              0.21796286839338874`, 0.3464231726984579, 0.9357240349566114], 
             UndirectedEdge[253, 283] -> 
             RGBColor[
              0.8607691122014759, 0.3856977852240938, 0.20253221045503758`], 
             UndirectedEdge[257, 360] -> 
             RGBColor[
              0.816087887153252, 0.8565915861588391, 0.9518343139701578], 
             UndirectedEdge[65, 358] -> 
             RGBColor[
              0.3270456066713938, 0.4548122705882284, 0.942165483061772], 
             UndirectedEdge[282, 340] -> 
             RGBColor[
              0.29320777122887487`, 0.42492993475416496`, 0.9400303722049579],
              UndirectedEdge[256, 316] -> 
             RGBColor[
              0.8522226042580414, 0.8830674650503693, 0.8745751101286188], 
             UndirectedEdge[96, 182] -> 
             RGBColor[
              0.2267284521296566, 0.35563635697538404`, 0.9362232219828728], 
             UndirectedEdge[2, 106] -> 
             RGBColor[
              0.19417223523988333`, 0.32141770884085996`, 0.9343691935936069],
              UndirectedEdge[210, 279] -> 
             RGBColor[
              0.2223588131160111, 0.3510435893209275, 0.9359743775053473], 
             UndirectedEdge[279, 371] -> 
             RGBColor[
              0.1895350584309733, 0.3165437420007044, 0.9341051132344278], 
             UndirectedEdge[271, 353] -> 
             RGBColor[
              0.8777551018994175, 0.4325009062999784, 0.2804416504383717], 
             UndirectedEdge[306, 311] -> 
             RGBColor[
              0.21244806666191265`, 0.3406267664200514, 0.9354099751564218], 
             UndirectedEdge[64, 312] -> 
             RGBColor[
              0.7702008939642393, 0.8151650470913949, 0.695936819489472], 
             UndirectedEdge[137, 210] -> 
             RGBColor[
              0.2691626848877073, 0.40023742608984725`, 0.9386397887626219], 
             UndirectedEdge[264, 394] -> 
             RGBColor[
              0.30880202077051594`, 0.4373816733147978, 0.941062660645224], 
             UndirectedEdge[199, 224] -> 
             RGBColor[
              0.7432416506659434, 0.7963714338733744, 0.8949724605475597], 
             UndirectedEdge[61, 301] -> 
             RGBColor[
              0.23356716082772205`, 0.3628242734162258, 0.9366126763262647], 
             UndirectedEdge[48, 103] -> 
             RGBColor[
              0.2013643551866071, 0.328977082911609, 0.9347787741847848], 
             UndirectedEdge[7, 14] -> 
             RGBColor[
              0.29679890469924086`, 0.4265200793940456, 0.9403148622219284], 
             UndirectedEdge[88, 195] -> 
             RGBColor[
              0.42750707901937735`, 0.5447068775411936, 0.948461350938816], 
             UndirectedEdge[211, 341] -> 
             RGBColor[
              0.24091627830701134`, 0.3705486618479197, 0.9370311976946651], 
             UndirectedEdge[84, 185] -> 
             RGBColor[
              0.20341836522778634`, 0.3311359776966468, 0.9348957470179945], 
             UndirectedEdge[368, 387] -> 
             RGBColor[
              0.18468757746568928`, 0.3114487321581461, 0.9338290563646603], 
             UndirectedEdge[134, 171] -> 
             RGBColor[
              0.18358417843459812`, 0.31028898981693004`, 0.9337662194221723],
              UndirectedEdge[41, 295] -> 
             RGBColor[
              0.19034802985855803`, 0.31739822651646155`, 0.9341514107545453],
              UndirectedEdge[77, 388] -> 
             RGBColor[
              0.23386679686193323`, 0.36313920988620363`, 0.9366297401551412],
              UndirectedEdge[142, 273] -> 
             RGBColor[
              0.4991027451822828, 0.6042331187182427, 0.9537103428557971], 
             UndirectedEdge[64, 140] -> 
             RGBColor[
              0.6994659535308891, 0.7564638537977784, 0.690720697735832], 
             UndirectedEdge[150, 157] -> 
             RGBColor[
              0.24263401195527415`, 0.3723541088228476, 0.9371290200847746], 
             UndirectedEdge[210, 264] -> 
             RGBColor[
              0.2528298194491141, 0.3830705489504057, 0.9377096562382032], 
             UndirectedEdge[202, 309] -> 
             RGBColor[
              0.5124790971855998, 0.6108362268976354, 0.9562827357512269], 
             UndirectedEdge[105, 287] -> 
             RGBColor[
              0.8733134302236104, 0.41881471124185254`, 0.40722620341472526`],
              UndirectedEdge[157, 160] -> 
             RGBColor[
              0.22107841637049833`, 0.349697811159551, 0.9359014608048675], 
             UndirectedEdge[153, 379] -> 
             RGBColor[
              0.19405975897206282`, 0.32129948915197337`, 0.9343627882365483],
              UndirectedEdge[207, 387] -> 
             RGBColor[
              0.18852965084716983`, 0.3154869948836043, 0.9340478567598975], 
             UndirectedEdge[93, 264] -> 
             RGBColor[
              0.3012538452175734, 0.43084382303317337`, 0.9405816975735801], 
             UndirectedEdge[202, 365] -> 
             RGBColor[
              0.31680424057691503`, 0.4485693265510483, 0.9414167025039941], 
             UndirectedEdge[138, 230] -> 
             RGBColor[
              0.2550152839737512, 0.38536761073225334`, 0.9378341152097762], 
             UndirectedEdge[5, 291] -> 
             RGBColor[
              0.19113912643877223`, 0.3182297191806869, 0.9341964625344661], 
             UndirectedEdge[241, 360] -> 
             RGBColor[
              0.4718334584098283, 0.5745274932673213, 0.9531648972863125], 
             UndirectedEdge[299, 300] -> 
             RGBColor[
              0.19227535029574405`, 0.31942396249511773`, 0.934261168802228], 
             UndirectedEdge[9, 266] -> 
             RGBColor[
              0.6722902895010364, 0.7439175508444353, 0.9679712712136599], 
             UndirectedEdge[226, 322] -> 
             RGBColor[
              0.1935079091107788, 0.32071945995846174`, 0.9343313612033369], 
             UndirectedEdge[175, 216] -> 
             RGBColor[
              0.20297653411671235`, 0.3306715851851976, 0.9348705853898494], 
             UndirectedEdge[115, 257] -> 
             RGBColor[
              0.9622640683610495, 0.9182194829930534, 0.6096923191590835], 
             UndirectedEdge[146, 275] -> 
             RGBColor[
              0.1966367657635329, 0.324008086681476, 0.9345095449609826], 
             UndirectedEdge[64, 101] -> 
             RGBColor[
              0.9001775806462604, 0.6060972685953367, 0.2776552068281445], 
             UndirectedEdge[79, 390] -> 
             RGBColor[
              0.2060170491676479, 0.3338673592835195, 0.9350437382239613], 
             UndirectedEdge[98, 378] -> 
             RGBColor[
              0.21674290293340537`, 0.34514091164973765`, 0.9356545597284425],
              UndirectedEdge[37, 80] -> 
             RGBColor[
              0.24371904320437376`, 0.3734945454606058, 0.9371908110092508], 
             UndirectedEdge[344, 354] -> 
             RGBColor[
              0.1938318559295014, 0.32105994860435383`, 0.9343498094954268], 
             UndirectedEdge[119, 227] -> 
             RGBColor[
              0.25689083303762017`, 0.3873389317150586, 0.9379409249543373], 
             UndirectedEdge[81, 166] -> 
             RGBColor[
              0.2371652059079643, 0.3666060469247946, 0.9368175796707537], 
             UndirectedEdge[192, 221] -> 
             RGBColor[
              0.3140891047086496, 0.4418027488287358, 0.9414053462268441], 
             UndirectedEdge[242, 331] -> 
             RGBColor[
              0.2906837062391053, 0.4199308888343219, 0.9399725324164205], 
             UndirectedEdge[225, 322] -> 
             RGBColor[
              0.2017966288426081, 0.3294314299317988, 0.9348033915300026], 
             UndirectedEdge[165, 170] -> 
             RGBColor[
              0.23052227294686206`, 0.35962390319639986`, 0.9364392744659576],
              UndirectedEdge[41, 250] -> 
             RGBColor[
              0.1942575833696331, 0.32150741513661096`, 0.934374054043335], 
             UndirectedEdge[31, 393] -> 
             RGBColor[
              0.8531150739602782, 0.8852437730014981, 0.9417329113283139], 
             UndirectedEdge[140, 312] -> 
             RGBColor[
              0.4770815978352943, 0.5850799771835042, 0.9523291493384193], 
             UndirectedEdge[56, 100] -> 
             RGBColor[
              0.4530551393941151, 0.565068246426121, 0.9505774993750733], 
             UndirectedEdge[89, 183] -> 
             RGBColor[
              0.21045489979042858`, 0.338531821664043, 0.935296467251717], 
             UndirectedEdge[39, 210] -> 
             RGBColor[
              0.22192743235245416`, 0.35059018078730897`, 0.9359498110090333],
              UndirectedEdge[34, 321] -> 
             RGBColor[
              0.18374554341254123`, 0.3104585946398788, 0.9337754089189481], 
             UndirectedEdge[148, 301] -> 
             RGBColor[
              0.25321055434935075`, 0.3834707254705414, 0.9377313385275249], 
             UndirectedEdge[136, 155] -> 
             RGBColor[
              0.18426793717549678`, 0.3110076636064226, 0.933805158470936], 
             UndirectedEdge[51, 205] -> 
             RGBColor[
              0.19318129293550862`, 0.32037616564959115`, 0.9343127608953405],
              UndirectedEdge[11, 123] -> 
             RGBColor[
              0.853169485204603, 0.5223983832616403, 0.45522988600606007`], 
             UndirectedEdge[223, 400] -> 
             RGBColor[
              0.8468492899928622, 0.3594083059636659, 0.19242961479906362`], 
             UndirectedEdge[6, 201] -> 
             RGBColor[
              0.7959386825090102, 0.8413708229845736, 0.9800676455168078], 
             UndirectedEdge[201, 273] -> 
             RGBColor[
              0.5948799673171399, 0.6816316125645953, 0.9614948857902279], 
             UndirectedEdge[54, 196] -> 
             RGBColor[
              0.8961892019683437, 0.8555483275728113, 0.6311082747514651], 
             UndirectedEdge[84, 288] -> 
             RGBColor[
              0.21401051896422651`, 0.342269002854981, 0.9354989545035975], 
             UndirectedEdge[177, 248] -> 
             RGBColor[
              0.18215464872777276`, 0.30878646345763827`, 0.9336848098201683],
              UndirectedEdge[76, 117] -> 
             RGBColor[
              0.4207333030341396, 0.5335965741048728, 0.9489064510842957], 
             UndirectedEdge[342, 348] -> 
             RGBColor[
              0.1937491041812462, 0.3209729712701737, 0.9343450969057838], 
             UndirectedEdge[332, 389] -> 
             RGBColor[
              0.8762443712451391, 0.4211412242083381, 0.2740853195911458], 
             UndirectedEdge[68, 236] -> 
             RGBColor[
              0.6656201528579981, 0.7366867382683524, 0.9686930531678246], 
             UndirectedEdge[84, 318] -> 
             RGBColor[
              0.2138717930117836, 0.3421231930832301, 0.9354910542658326], 
             UndirectedEdge[15, 372] -> 
             RGBColor[
              0.1810383624053819, 0.30761317575616476`, 0.9336212389655058], 
             UndirectedEdge[88, 189] -> 
             RGBColor[
              0.331784795723977, 0.4548098720727408, 0.9426178463888004], 
             UndirectedEdge[364, 380] -> 
             RGBColor[
              0.8208602613542741, 0.753663537851497, 0.6141649050014586], 
             UndirectedEdge[103, 295] -> 
             RGBColor[
              0.1903453971129866, 0.3173954593339403, 0.9341512608235798], 
             UndirectedEdge[20, 257] -> 
             RGBColor[
              0.6770229856308323, 0.7421397259892473, 0.9411883411446311], 
             UndirectedEdge[12, 24] -> 
             RGBColor[
              0.25148362362516946`, 0.3816556117856949, 0.9376329923775478], 
             UndirectedEdge[152, 157] -> 
             RGBColor[
              0.22385261786682037`, 0.3526136728267195, 0.9360594474760198], 
             UndirectedEdge[26, 70] -> 
             RGBColor[
              0.1896105861046007, 0.3166231263744179, 0.9341094144237078], 
             UndirectedEdge[33, 74] -> 
             RGBColor[
              0.24756162893783695`, 0.3775333467004828, 0.9374096405821755], 
             UndirectedEdge[124, 238] -> 
             RGBColor[
              0.21375043106969976`, 0.3419956339873084, 0.9354841428827698], 
             UndirectedEdge[148, 339] -> 
             RGBColor[
              0.3192552716311131, 0.4461190038278132, 0.9417403303152683], 
             UndirectedEdge[175, 229] -> 
             RGBColor[
              0.1940292110138258, 0.32126738131101384`, 0.9343610485755184], 
             UndirectedEdge[105, 337] -> 
             RGBColor[
              0.9711407562018461, 0.97781294412538, 0.9254748728105828], 
             UndirectedEdge[158, 306] -> 
             RGBColor[
              0.20672015111524922`, 0.33460636400968674`, 0.935083778839731], 
             UndirectedEdge[136, 268] -> 
             RGBColor[
              0.18514817398425504`, 0.3119328483026647, 0.9338552866550012], 
             UndirectedEdge[133, 278] -> 
             RGBColor[
              0.18574944160901402`, 0.31256481869885566`, 0.9338895279567354],
              UndirectedEdge[197, 254] -> 
             RGBColor[
              0.18919463052287389`, 0.31618593068491585`, 0.9340857263686796],
              UndirectedEdge[296, 398] -> 
             RGBColor[
              0.17994179284220208`, 0.3064606116187368, 0.933558790951112], 
             UndirectedEdge[10, 271] -> 
             RGBColor[
              0.8353123166962146, 0.27243151684875794`, 0.18144842038883974`],
              UndirectedEdge[221, 399] -> 
             RGBColor[
              0.36464378874039466`, 0.49025785510237774`, 0.9444557576700642],
              UndirectedEdge[187, 388] -> 
             RGBColor[
              0.2435643246839634, 0.37333192648593383`, 0.937182000018399], 
             UndirectedEdge[143, 186] -> 
             RGBColor[
              0.20274228315425485`, 0.3304253725712859, 0.9348572451440806], 
             UndirectedEdge[372, 387] -> 
             RGBColor[
              0.18274442511282618`, 0.30940635583231196`, 0.9337183967128011],
              UndirectedEdge[147, 255] -> 
             RGBColor[
              0.3107019378391358, 0.4378471817176799, 0.9412269310789902], 
             UndirectedEdge[27, 86] -> 
             RGBColor[
              0.23656599040606416`, 0.3659762334398404, 0.9367834552343804], 
             UndirectedEdge[19, 157] -> 
             RGBColor[
              0.2231871063802957, 0.35191417805851677`, 0.9360215475813982], 
             UndirectedEdge[192, 208] -> 
             RGBColor[
              0.27634222217301546`, 0.40778357498566165`, 0.9390486527898467],
              UndirectedEdge[88, 89] -> 
             RGBColor[
              0.33131087657095276`, 0.4543117529947025, 0.9425908573941362], 
             UndirectedEdge[54, 332] -> 
             RGBColor[
              0.8612878791024013, 0.3694248520342004, 0.20219620971087243`], 
             UndirectedEdge[282, 301] -> 
             RGBColor[
              0.2824458229860667, 0.41361844480404447`, 0.9394174951734057], 
             UndirectedEdge[264, 328] -> 
             RGBColor[
              0.24566528906336602`, 0.3755401732575213, 0.9373016468317077], 
             UndirectedEdge[124, 156] -> 
             RGBColor[
              0.21424517968646528`, 0.3425156461524031, 0.9355123180845796], 
             UndirectedEdge[64, 120] -> 
             RGBColor[
              0.7025664799902631, 0.759149373979897, 0.6909182605401354], 
             UndirectedEdge[55, 236] -> 
             RGBColor[
              0.6566866391587384, 0.7296947127190476, 0.9678061194855357], 
             UndirectedEdge[11, 196] -> 
             RGBColor[
              0.8586587168624804, 0.8901351694289188, 0.9863808290196707], 
             UndirectedEdge[223, 319] -> 
             RGBColor[
              0.8502923449808009, 0.3858731353572784, 0.1957266881438881], 
             UndirectedEdge[61, 70] -> 
             RGBColor[
              0.20711529305388426`, 0.33502168324063814`, 0.9351062815885762],
              UndirectedEdge[307, 343] -> 
             RGBColor[
              0.1898749181249935, 0.3169009560874688, 0.9341244677412249], 
             UndirectedEdge[13, 87] -> 
             RGBColor[
              0.2001057560025477, 0.3276542153693653, 0.9347070988231834], 
             UndirectedEdge[119, 128] -> 
             RGBColor[
              0.2718458799395796, 0.4030576342137573, 0.9387925927513947], 
             UndirectedEdge[92, 130] -> 
             RGBColor[
              0.2100169217474722, 0.33807147897148404`, 0.935271525050101], 
             UndirectedEdge[263, 359] -> 
             RGBColor[
              0.31376085658735253`, 0.4455463754257799, 0.941236947982536], 
             UndirectedEdge[22, 304] -> 
             RGBColor[
              0.2621517349847551, 0.3928684732219464, 0.9382405255374198], 
             UndirectedEdge[139, 306] -> 
             RGBColor[
              0.2646217542710957, 0.39546462010015837`, 0.9383811894817108], 
             UndirectedEdge[1, 73] -> 
             RGBColor[
              0.19016251964762415`, 0.3172032435227433, 0.9341408462224705], 
             UndirectedEdge[7, 13] -> 
             RGBColor[
              0.23415570368153021`, 0.3634428692713504, 0.9366461929711178], 
             UndirectedEdge[170, 335] -> 
             RGBColor[
              0.21688414248716403`, 0.34528936337584293`, 0.9356626031120838],
              UndirectedEdge[276, 361] -> 
             RGBColor[
              0.3943096577609078, 0.5159529397980152, 0.9463460406115533], 
             UndirectedEdge[46, 345] -> 
             RGBColor[
              0.8168101022247779, 0.8568829940339906, 0.982358282576511], 
             UndirectedEdge[36, 301] -> 
             RGBColor[
              0.2477609938146631, 0.37774289182649035`, 0.9374209941169768], 
             UndirectedEdge[50, 328] -> 
             RGBColor[
              0.23123968531368772`, 0.36037794908050486`, 0.9364801300389318],
              UndirectedEdge[55, 83] -> 
             RGBColor[
              0.8773611303882973, 0.9047851000408222, 0.9744632955960668], 
             UndirectedEdge[143, 306] -> 
             RGBColor[
              0.21060170684620283`, 0.33868612518776664`, 0.9353048276963617],
              UndirectedEdge[32, 400] -> 
             RGBColor[
              0.8217176503596796, 0.1679369541653756, 0.16843015255199423`], 
             UndirectedEdge[20, 195] -> 
             RGBColor[
              0.40462199010322386`, 0.5248849637600351, 0.9470031333095683], 
             UndirectedEdge[203, 266] -> 
             RGBColor[
              0.4841156347335931, 0.5879317505125805, 0.9537717798510146], 
             UndirectedEdge[255, 359] -> 
             RGBColor[
              0.3499392226187198, 0.4775214990007658, 0.9435187957195283], 
             UndirectedEdge[128, 215] -> 
             RGBColor[
              0.5049864538136, 0.6035289290681363, 0.9559781758101122], 
             UndirectedEdge[230, 328] -> 
             RGBColor[
              0.2262385122205931, 0.35512139906697393`, 0.9361953206298528], 
             UndirectedEdge[44, 146] -> 
             RGBColor[
              0.21372136571514777`, 0.3419650844568244, 0.9354824876538264], 
             UndirectedEdge[56, 206] -> 
             RGBColor[
              0.4736432444349138, 0.5829006282242136, 0.9518893552229266], 
             UndirectedEdge[55, 196] -> 
             RGBColor[
              0.8239309669516679, 0.8625755200904117, 0.9830336180607375], 
             UndirectedEdge[93, 188] -> 
             RGBColor[
              0.3091689920495968, 0.43916314420292457`, 0.9410324534762535], 
             UndirectedEdge[52, 271] -> 
             RGBColor[
              0.8763333885975696, 0.43307600780014566`, 0.3885421402936417], 
             UndirectedEdge[193, 253] -> 
             RGBColor[
              0.8294376428224145, 0.4209653077854606, 0.4426395583706675], 
             UndirectedEdge[120, 193] -> 
             RGBColor[
              0.6252379224927019, 0.7026774950776031, 0.9659558403883122], 
             UndirectedEdge[28, 217] -> 
             RGBColor[
              0.19992147826691017`, 0.32746052778532697`, 0.9346966044787532],
              UndirectedEdge[124, 245] -> 
             RGBColor[
              0.21075638483913717`, 0.33884870156549185`, 0.9353136363792337],
              UndirectedEdge[36, 282] -> 
             RGBColor[
              0.28033871258182136`, 0.4114037381706667, 0.9392974983530744], 
             UndirectedEdge[276, 339] -> 
             RGBColor[
              0.38050139833268903`, 0.5039929195045905, 0.9454661905309516], 
             UndirectedEdge[377, 388] -> 
             RGBColor[
              0.26273780008050557`, 0.39348446479625343`, 0.9382739010776171],
              UndirectedEdge[129, 131] -> 
             RGBColor[
              0.8175944103377895, 0.3846574917741582, 0.4381352993196086], 
             UndirectedEdge[69, 142] -> 
             RGBColor[
              0.5234887787089056, 0.6240307993134462, 0.955630100743997], 
             UndirectedEdge[11, 118] -> 
             RGBColor[
              0.6153201099210919, 0.6928744863891039, 0.9658821576068201], 
             UndirectedEdge[53, 293] -> 
             RGBColor[
              0.35836727987096656`, 0.4848214585861875, 0.944055824075003], 
             UndirectedEdge[2, 137] -> 
             RGBColor[
              0.24723503321608348`, 0.3771900738895551, 0.9373910414389766], 
             UndirectedEdge[102, 213] -> 
             RGBColor[
              0.33722405994131943`, 0.4665082641722599, 0.9427085967973012], 
             UndirectedEdge[269, 362] -> 
             RGBColor[
              0.5723371220999356, 0.658694027276514, 0.9617848366135348], 
             UndirectedEdge[147, 242] -> 
             RGBColor[
              0.29380682218946674`, 0.42321348171513995`, 0.9401503892495575],
              UndirectedEdge[58, 220] -> 
             RGBColor[
              0.186453938859043, 0.31330528997634166`, 0.9339296480329143], 
             UndirectedEdge[177, 285] -> 
             RGBColor[
              0.18283630546897034`, 0.3095029279121705, 0.9337236291631588], 
             UndirectedEdge[213, 215] -> 
             RGBColor[
              0.5157421665105038, 0.6132928535993672, 0.9566471217151071], 
             UndirectedEdge[61, 382] -> 
             RGBColor[
              0.2696810924925139, 0.39954800963710424`, 0.9387145049212492], 
             UndirectedEdge[83, 123] -> 
             RGBColor[
              0.8791001851437382, 0.542812031489136, 0.4485921532142464], 
             UndirectedEdge[207, 368] -> 
             RGBColor[
              0.18767517326657374`, 0.3145888847693901, 0.9339991955257688], 
             UndirectedEdge[117, 377] -> 
             RGBColor[
              0.40661285819624315`, 0.5187550912923315, 0.9481023126401036], 
             UndirectedEdge[207, 392] -> 
             RGBColor[
              0.1972896880999786, 0.3246943494547476, 0.9345467279221311], 
             UndirectedEdge[43, 325] -> 
             RGBColor[
              0.21648460691960775`, 0.3448694261623232, 0.9356398501525713], 
             UndirectedEdge[83, 196] -> 
             RGBColor[
              0.8975547667711833, 0.9207556417701627, 0.9764242298319501], 
             UndirectedEdge[81, 130] -> 
             RGBColor[
              0.2224096961469096, 0.35109707061257234`, 0.9359772752186821], 
             UndirectedEdge[204, 229] -> 
             RGBColor[
              0.18893129430891603`, 0.3159091476275659, 0.9340707297608657], 
             UndirectedEdge[44, 267] -> 
             RGBColor[
              0.21293872940986303`, 0.3411424840779623, 0.935437917674047], 
             UndirectedEdge[38, 130] -> 
             RGBColor[
              0.23719458554175432`, 0.36663692678268434`, 0.9368192527974348],
              UndirectedEdge[226, 318] -> 
             RGBColor[
              0.20268055409019498`, 0.33036049141111024`, 0.9348537297652024],
              UndirectedEdge[202, 362] -> 
             RGBColor[
              0.5594312028417849, 0.6475155686854668, 0.9609624828506617], 
             UndirectedEdge[59, 230] -> 
             RGBColor[
              0.21869887314196257`, 0.34719676035460534`, 0.9357659493382211],
              UndirectedEdge[131, 394] -> 
             RGBColor[
              0.585868010689025, 0.6694437636125451, 0.9630575794667262], 
             UndirectedEdge[93, 142] -> 
             RGBColor[
              0.4083441914838143, 0.5275430486662767, 0.9473966682274677], 
             UndirectedEdge[301, 340] -> 
             RGBColor[
              0.26063005246171667`, 0.3912690884099886, 0.9381538679688604], 
             UndirectedEdge[16, 76] -> 
             RGBColor[
              0.2559443426940643, 0.3863441103530275, 0.937887023729479], 
             UndirectedEdge[25, 239] -> 
             RGBColor[
              0.43554957397249955`, 0.5502115619480115, 0.9493775788120367], 
             UndirectedEdge[46, 60] -> 
             RGBColor[
              0.7562801355297237, 0.809531056908518, 0.9763425941360632], 
             UndirectedEdge[57, 297] -> 
             RGBColor[
              0.3224295006293375, 0.45256728530617585`, 0.9418071536579791], 
             UndirectedEdge[221, 351] -> 
             RGBColor[
              0.33973329445254913`, 0.4686816369880935, 0.9428684830015278], 
             UndirectedEdge[365, 377] -> 
             RGBColor[
              0.2803555468892034, 0.41200183372185906`, 0.9392772056952516], 
             UndirectedEdge[334, 366] -> 
             RGBColor[
              0.9767558229939741, 0.9327621554008622, 0.40603042724612426`], 
             UndirectedEdge[209, 290] -> 
             RGBColor[
              0.2612876379800373, 0.3919602524830736, 0.938191316491318], 
             UndirectedEdge[174, 313] -> 
             RGBColor[
              0.35122662219084355`, 0.47640574207717373`, 0.9436825095790529],
              UndirectedEdge[56, 358] -> 
             RGBColor[
              0.3979975915234898, 0.5145002367878451, 0.9471747294166126], 
             UndirectedEdge[304, 338] -> 
             RGBColor[
              0.24620331291395298`, 0.37610567043717064`, 0.9373322864940637],
              UndirectedEdge[130, 306] -> 
             RGBColor[
              0.21898168415614172`, 0.3474940126617616, 0.9357820550070972], 
             UndirectedEdge[11, 206] -> 
             RGBColor[
              0.6510406164097462, 0.7238137937447175, 0.9681582366938735], 
             UndirectedEdge[120, 140] -> 
             RGBColor[
              0.409447183861318, 0.5290643040720063, 0.9473105903890827], 
             UndirectedEdge[193, 356] -> 
             RGBColor[
              0.8916558476180196, 0.9161964476590825, 0.9808695463369558], 
             UndirectedEdge[166, 246] -> 
             RGBColor[
              0.23093801406837325`, 0.3600608734746177, 0.9364629503077938], 
             UndirectedEdge[76, 182] -> 
             RGBColor[
              0.2623813144884871, 0.39310977583655005`, 0.9382535997505249], 
             UndirectedEdge[6, 364] -> 
             RGBColor[
              0.9237508221541206, 0.8349006337052781, 0.6241923325830713], 
             UndirectedEdge[288, 318] -> 
             RGBColor[
              0.21359522081764215`, 0.3418324981714975, 0.9354753038885282], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.285788273116509, 0.4171315718147177, 0.9396078427636225], 
             UndirectedEdge[128, 151] -> 
             RGBColor[
              0.2557571228947407, 0.38614733047351757`, 0.9378763618388744], 
             UndirectedEdge[30, 379] -> 
             RGBColor[
              0.19158357625518677`, 0.31869686411748455`, 0.9342217732940062],
              UndirectedEdge[70, 90] -> 
             RGBColor[
              0.2062666965089075, 0.33412975446773896`, 0.9350579552707259], 
             UndirectedEdge[137, 394] -> 
             RGBColor[
              0.32513488620910913`, 0.45454855045423936`, 0.9419927931696428],
              UndirectedEdge[25, 269] -> 
             RGBColor[
              0.35868258725721747`, 0.48509456199634804`, 0.9440759151828396],
              UndirectedEdge[38, 227] -> 
             RGBColor[
              0.2663587998591236, 0.39729036514822713`, 0.9384801116582203], 
             UndirectedEdge[128, 135] -> 
             RGBColor[
              0.31962859399375376`, 0.45082008915129973`, 0.9416038278633306],
              UndirectedEdge[129, 303] -> 
             RGBColor[
              0.8442007939445894, 0.3035021905928796, 0.18850141741323326`], 
             UndirectedEdge[132, 299] -> 
             RGBColor[
              0.19063186344337624`, 0.3176965536101942, 0.9341675746573066], 
             UndirectedEdge[352, 396] -> 
             RGBColor[
              0.18539177638104404`, 0.312188889866974, 0.9338691594511209], 
             UndirectedEdge[155, 268] -> 
             RGBColor[
              0.18677990471826675`, 0.31364790076181503`, 0.9339482113063738],
              UndirectedEdge[8, 16] -> 
             RGBColor[
              0.24227617377409713`, 0.3719779982061794, 0.9371086417297306], 
             UndirectedEdge[213, 378] -> 
             RGBColor[
              0.2828251978811075, 0.4130565820344796, 0.9394742726442766], 
             UndirectedEdge[164, 230] -> 
             RGBColor[
              0.21805906979477002`, 0.3465242864708308, 0.9357295134841028], 
             UndirectedEdge[218, 339] -> 
             RGBColor[
              0.47111694262023773`, 0.5795753796238241, 0.9520425636736524], 
             UndirectedEdge[101, 366] -> 
             RGBColor[
              0.9004158502454526, 0.6066069031752569, 0.3035893822706974], 
             UndirectedEdge[169, 361] -> 
             RGBColor[
              0.4334163894448813, 0.5497182254001022, 0.948867451343103], 
             UndirectedEdge[65, 341] -> 
             RGBColor[
              0.31291881126268356`, 0.4399641129231123, 0.9413609829619669], 
             UndirectedEdge[46, 353] -> 
             RGBColor[
              0.8993981375114619, 0.9180011012561393, 0.7445005138120175], 
             UndirectedEdge[279, 300] -> 
             RGBColor[
              0.1975989582339537, 0.32501941197441453`, 0.9345643403987369], 
             UndirectedEdge[203, 358] -> 
             RGBColor[
              0.29380332632948314`, 0.42601947816165614`, 0.9400473143533797],
              UndirectedEdge[81, 243] -> 
             RGBColor[
              0.2302749655066254, 0.3593639673965138, 0.9364251906730947], 
             UndirectedEdge[176, 320] -> 
             RGBColor[
              0.18495626411433608`, 0.3117311388615913, 0.9338443576718145], 
             UndirectedEdge[112, 248] -> 
             RGBColor[
              0.18167669359362687`, 0.3082841023075451, 0.9336575909823499], 
             UndirectedEdge[58, 179] -> 
             RGBColor[
              0.21000836012355356`, 0.3380624801619072, 0.9352710374782847], 
             UndirectedEdge[23, 213] -> 
             RGBColor[
              0.2686665233533321, 0.39817491739397315`, 0.9386679570758016], 
             UndirectedEdge[243, 326] -> 
             RGBColor[
              0.23648276332684243`, 0.36588875650267677`, 0.9367787155753422],
              UndirectedEdge[269, 377] -> 
             RGBColor[
              0.30404872534557215`, 0.4327759904647185, 0.9407776755353809], 
             UndirectedEdge[222, 363] -> 
             RGBColor[
              0.6628066494410058, 0.7309294373629389, 0.9563828644799877], 
             UndirectedEdge[30, 341] -> 
             RGBColor[
              0.22502124710185, 0.35384197624810876`, 0.9361259991821227], 
             UndirectedEdge[23, 348] -> 
             RGBColor[
              0.20651189165865158`, 0.3343874701163905, 0.93507191877177], 
             UndirectedEdge[16, 25] -> 
             RGBColor[
              0.2964577597678131, 0.4238211990721158, 0.9403811249327455], 
             UndirectedEdge[25, 62] -> 
             RGBColor[
              0.6778828449272916, 0.740272939600058, 0.8649535953688089], 
             UndirectedEdge[16, 388] -> 
             RGBColor[
              0.24986758553696356`, 0.3799570532922577, 0.9375409613991386], 
             UndirectedEdge[207, 372] -> 
             RGBColor[
              0.18573202091371066`, 0.31254650844355597`, 0.9338885358739095],
              UndirectedEdge[249, 279] -> 
             RGBColor[
              0.19132944320701362`, 0.3184297541708887, 0.934207300792869], 
             UndirectedEdge[151, 267] -> 
             RGBColor[
              0.20258817055551906`, 0.33026339045871145`, 0.9348484686595718],
              UndirectedEdge[185, 252] -> 
             RGBColor[
              0.1992454681560438, 0.3267499982972898, 0.9346581067030068], 
             UndirectedEdge[218, 382] -> 
             RGBColor[
              0.44118615700326724`, 0.5536508374874307, 0.9501354004808935], 
             UndirectedEdge[284, 334] -> 
             RGBColor[
              0.8500382234662116, 0.8370769008965131, 0.6373182165494112], 
             UndirectedEdge[145, 235] -> 
             RGBColor[
              0.22156110310920424`, 0.35020514552603776`, 0.9359289491005658],
              UndirectedEdge[78, 302] -> 
             RGBColor[
              0.2075835767828424, 0.33551387913067643`, 0.9351329496541767], 
             UndirectedEdge[235, 335] -> 
             RGBColor[
              0.19575670920923333`, 0.32308309144409886`, 0.9344594270421422],
              UndirectedEdge[21, 109] -> 
             RGBColor[
              0.1897091064701492, 0.31672667752516137`, 0.9341150250127779], 
             UndirectedEdge[283, 389] -> 
             RGBColor[
              0.9625229099161214, 0.8777511540326326, 0.378485405341739], 
             UndirectedEdge[91, 395] -> 
             RGBColor[
              0.5156283955691132, 0.6172519539462964, 0.9551211142984581], 
             UndirectedEdge[240, 374] -> 
             RGBColor[
              0.18148468566837106`, 0.3080822898040957, 0.933646656415057], 
             UndirectedEdge[301, 339] -> 
             RGBColor[
              0.3159128215006708, 0.4426058768171399, 0.9415499827250514], 
             UndirectedEdge[303, 353] -> 
             RGBColor[
              0.9435949291122223, 0.7996173553563373, 0.3704770005960165], 
             UndirectedEdge[92, 143] -> 
             RGBColor[
              0.20163694443753327`, 0.3292635914974891, 0.9347942977393655], 
             UndirectedEdge[53, 394] -> 
             RGBColor[
              0.38011496144870427`, 0.5036582072985654, 0.9454415671144167], 
             UndirectedEdge[139, 345] -> 
             RGBColor[
              0.5675136417908162, 0.652851509744995, 0.962127956401694], 
             UndirectedEdge[224, 393] -> 
             RGBColor[
              0.6098596540697332, 0.6929310009621534, 0.9632633563282622], 
             UndirectedEdge[175, 204] -> 
             RGBColor[
              0.1850387535749342, 0.31181784051481387`, 0.9338490553245634], 
             UndirectedEdge[131, 293] -> 
             RGBColor[
              0.5641203291112874, 0.6506070149001673, 0.9616718364273125], 
             UndirectedEdge[166, 383] -> 
             RGBColor[
              0.3017459947622442, 0.42990132159861427`, 0.9406631745250644], 
             UndirectedEdge[92, 348] -> 
             RGBColor[
              0.2027372639690243, 0.3304200970893739, 0.9348569593089071], 
             UndirectedEdge[212, 289] -> 
             RGBColor[
              0.5259969557430033, 0.6260670504218144, 0.9558275536278764], 
             UndirectedEdge[161, 214] -> 
             RGBColor[
              0.8792338615689066, 0.5445109956801907, 0.22094211265521246`], 
             UndirectedEdge[124, 386] -> 
             RGBColor[
              0.28427277786616933`, 0.41305129154365816`, 0.9396126134014054],
              UndirectedEdge[227, 350] -> 
             RGBColor[
              0.3112685553301875, 0.44081365131394507`, 0.9411723881594869], 
             UndirectedEdge[258, 279] -> 
             RGBColor[
              0.2183447678357952, 0.34682457322625027`, 0.9357457835648868], 
             UndirectedEdge[63, 103] -> 
             RGBColor[
              0.19205709543901506`, 0.31919456280253833`, 0.9342487395110164],
              UndirectedEdge[291, 336] -> 
             RGBColor[
              0.21513079622652476`, 0.34344648528733734`, 0.9355627526363838],
              UndirectedEdge[292, 400] -> 
             RGBColor[
              0.8203663291701224, 0.1575501073497178, 0.16713612585477525`], 
             UndirectedEdge[149, 300] -> 
             RGBColor[
              0.20324360298345337`, 0.33095229149728655`, 0.9348857945667173],
              UndirectedEdge[356, 364] -> 
             RGBColor[
              0.9333609520587287, 0.8423137522801358, 0.6164503768813724], 
             UndirectedEdge[100, 167] -> 
             RGBColor[
              0.3117593370391954, 0.4377082442608893, 0.941332929144121], 
             UndirectedEdge[334, 391] -> 
             RGBColor[
              0.8668933379781074, 0.3968385652016415, 0.21131639439549801`], 
             UndirectedEdge[309, 323] -> 
             RGBColor[
              0.5589942800594222, 0.6511253403818711, 0.9592466420721857], 
             UndirectedEdge[8, 202] -> 
             RGBColor[
              0.2915950820053508, 0.42207290253936436`, 0.9399810782169516], 
             UndirectedEdge[127, 380] -> 
             RGBColor[
              0.529875465248763, 0.6249265943110206, 0.9578049379836415], 
             UndirectedEdge[130, 151] -> 
             RGBColor[
              0.211637861675412, 0.3397751896092761, 0.9353638351810314], 
             UndirectedEdge[335, 355] -> 
             RGBColor[
              0.20320238953001776`, 0.3309089735446419, 0.934883447521514], 
             UndirectedEdge[117, 395] -> 
             RGBColor[
              0.49860624010091514`, 0.6034326012978481, 0.9537810678657916], 
             UndirectedEdge[256, 310] -> 
             RGBColor[
              0.8817791092522581, 0.4669114753460718, 0.37441947014658894`], 
             UndirectedEdge[362, 365] -> 
             RGBColor[
              0.5486439436435668, 0.6379198705336546, 0.9602843667734056], 
             UndirectedEdge[163, 342] -> 
             RGBColor[
              0.18272416673891645`, 0.30938506299687774`, 0.9337172430283764],
              UndirectedEdge[125, 288] -> 
             RGBColor[
              0.2031660717843796, 0.3308708012912981, 0.9348813792796271], 
             UndirectedEdge[161, 253] -> 
             RGBColor[
              0.8433103782733695, 0.3117402164434911, 0.18823933356517306`], 
             UndirectedEdge[12, 211] -> 
             RGBColor[
              0.23763726784270695`, 0.3671022139486645, 0.9368444628995842], 
             UndirectedEdge[107, 152] -> 
             RGBColor[
              0.2119625047523057, 0.3401164100666513, 0.9353823231239942], 
             UndirectedEdge[183, 291] -> 
             RGBColor[
              0.1920722404266596, 0.31921048114480044`, 0.9342496019956579], 
             UndirectedEdge[149, 299] -> 
             RGBColor[
              0.19935795159879743`, 0.32686822552748607`, 0.9346645124686672],
              UndirectedEdge[57, 284] -> 
             RGBColor[
              0.544081909913294, 0.6364040523835073, 0.9590603762420349], 
             UndirectedEdge[230, 279] -> 
             RGBColor[
              0.2100811442778375, 0.33813898092284156`, 0.9352751824281966], 
             UndirectedEdge[186, 374] -> 
             RGBColor[
              0.19510883243877694`, 0.3224021318805894, 0.9344225314185126], 
             UndirectedEdge[30, 175] -> 
             RGBColor[
              0.19541782934736363`, 0.32272690722304953`, 0.9344401283353366],
              UndirectedEdge[261, 327] -> 
             RGBColor[
              0.1874834373807122, 0.31438735819659225`, 0.9339882764507168], 
             UndirectedEdge[271, 333] -> 
             RGBColor[
              0.8645940127585953, 0.4248527314211257, 0.4322347939799689], 
             UndirectedEdge[199, 247] -> 
             RGBColor[
              0.8744710807180455, 0.41938916470165666`, 0.38827169323511157`],
              UndirectedEdge[99, 223] -> 
             RGBColor[
              0.8735329143735617, 0.6106862837337387, 0.46633619385844605`], 
             UndirectedEdge[200, 367] -> 
             RGBColor[
              0.19007010120853718`, 0.31710610588359545`, 0.9341355831290852],
              UndirectedEdge[111, 400] -> 
             RGBColor[
              0.8251131291830741, 0.19403609231029295`, 0.17168166690792155`],
              UndirectedEdge[277, 390] -> 
             RGBColor[
              0.19904871949657826`, 0.326543202981606, 0.9346469021579138], 
             UndirectedEdge[79, 298] -> 
             RGBColor[
              0.20225845525357178`, 0.3299168387712073, 0.934829691860896], 
             UndirectedEdge[96, 388] -> 
             RGBColor[
              0.24120538255957147`, 0.37085252874762864`, 0.937047661754157], 
             UndirectedEdge[153, 175] -> 
             RGBColor[
              0.19789401206423968`, 0.32532953225753836`, 0.9345811432778787],
              UndirectedEdge[127, 331] -> 
             RGBColor[
              0.29016880316487315`, 0.419484905671203, 0.9399397232478413], 
             UndirectedEdge[6, 93] -> 
             RGBColor[
              0.6343460318717724, 0.7075322117954237, 0.9679330421391619], 
             UndirectedEdge[76, 239] -> 
             RGBColor[
              0.3950361568987507, 0.5127344732289232, 0.94688347760877], 
             UndirectedEdge[333, 337] -> 
             RGBColor[
              0.9553778772118539, 0.9662414744033965, 0.9604177939535141], 
             UndirectedEdge[253, 332] -> 
             RGBColor[
              0.8227299040516889, 0.17571757961455517`, 0.16939948783063935`],
              UndirectedEdge[31, 400] -> 
             RGBColor[
              0.8761629417845124, 0.4432480415757216, 0.4160548316610515], 
             UndirectedEdge[39, 149] -> 
             RGBColor[
              0.2042501787734501, 0.33201026647316434`, 0.9349431175688622], 
             UndirectedEdge[49, 335] -> 
             RGBColor[
              0.1909811618412971, 0.3180636883732066, 0.9341874666843275], 
             UndirectedEdge[57, 236] -> 
             RGBColor[
              0.4289674540866987, 0.5444426167036535, 0.9489769174045849], 
             UndirectedEdge[76, 323] -> 
             RGBColor[
              0.3517784337991403, 0.4767281281704481, 0.9437233665376588], 
             UndirectedEdge[2, 210] -> 
             RGBColor[
              0.223753059772891, 0.352509030957652, 0.9360537777898534], 
             UndirectedEdge[25, 395] -> 
             RGBColor[
              0.4013213562160271, 0.522026120581628, 0.946792819836912], 
             UndirectedEdge[62, 91] -> 
             RGBColor[
              0.7921898842803778, 0.8354987729647263, 0.873281889830355], 
             UndirectedEdge[148, 313] -> 
             RGBColor[
              0.27058528986872044`, 0.4017326741232574, 0.9387208040117352], 
             UndirectedEdge[98, 163] -> 
             RGBColor[
              0.18615149755953203`, 0.3129874049946697, 0.933912424448329], 
             UndirectedEdge[271, 292] -> 
             RGBColor[
              0.8198324633952027, 0.15344658106221012`, 0.16662489538579692`],
              UndirectedEdge[148, 228] -> 
             RGBColor[
              0.2402804897849437, 0.36988040779990605`, 0.9369949904788982], 
             UndirectedEdge[105, 333] -> 
             RGBColor[
              0.969539411680839, 0.9766186640035739, 0.9281855313871071], 
             UndirectedEdge[9, 65] -> 
             RGBColor[
              0.531426491162083, 0.6277150215031269, 0.9572921727453987], 
             UndirectedEdge[129, 337] -> 
             RGBColor[
              0.8652171818184992, 0.4222331115031051, 0.43000213610996785`], 
             UndirectedEdge[62, 323] -> 
             RGBColor[
              0.7062128595771804, 0.7648109743818534, 0.8667587588510515], 
             UndirectedEdge[286, 290] -> 
             RGBColor[
              0.28938656912218486`, 0.4203385400712017, 0.9398338164907357], 
             UndirectedEdge[96, 261] -> 
             RGBColor[
              0.20041641876701294`, 0.3279807416319751, 0.9347247906080353], 
             UndirectedEdge[48, 86] -> 
             RGBColor[
              0.23801910122574216`, 0.3675035450438693, 0.9368662077458763], 
             UndirectedEdge[137, 328] -> 
             RGBColor[
              0.2619981545019592, 0.39270705039696285`, 0.9382317793561266], 
             UndirectedEdge[110, 212] -> 
             RGBColor[
              0.715371093239261, 0.7768498811487758, 0.9728708007300837], 
             UndirectedEdge[163, 272] -> 
             RGBColor[
              0.18785278804211375`, 0.3147755691599099, 0.9340093104244782], 
             UndirectedEdge[245, 396] -> 
             RGBColor[
              0.1896460602736138, 0.31666041197524286`, 0.9341114346251538], 
             UndirectedEdge[25, 37] -> 
             RGBColor[
              0.3241466699483991, 0.4529239992502145, 0.9419579674054581], 
             UndirectedEdge[79, 373] -> 
             RGBColor[
              0.19851817498261992`, 0.32598556705897075`, 0.9346166884327141],
              UndirectedEdge[34, 43] -> 
             RGBColor[
              0.18881744465394812`, 0.3157894844217095, 0.9340642461914408], 
             UndirectedEdge[100, 358] -> 
             RGBColor[
              0.33265464447686266`, 0.4596705372168882, 0.942522885990859], 
             UndirectedEdge[273, 394] -> 
             RGBColor[
              0.4408354922328445, 0.55433085165707, 0.9498412454842259], 
             UndirectedEdge[89, 189] -> 
             RGBColor[
              0.23269978806740765`, 0.361912609650526, 0.9365632807307278], 
             UndirectedEdge[268, 299] -> 
             RGBColor[
              0.18802492021905656`, 0.3149564909916871, 0.9340191130973085], 
             UndirectedEdge[143, 272] -> 
             RGBColor[
              0.19777740595295248`, 0.3252069718413211, 0.9345745027323441], 
             UndirectedEdge[339, 382] -> 
             RGBColor[
              0.3520267531654626, 0.47932961303801835`, 0.943651811320036], 
             UndirectedEdge[111, 223] -> 
             RGBColor[
              0.8374801650249903, 0.28824382747239297`, 0.1834910422728131], 
             UndirectedEdge[71, 131] -> 
             RGBColor[
              0.8919073913712897, 0.9158173378862382, 0.9591371203789343], 
             UndirectedEdge[114, 370] -> 
             RGBColor[
              0.18611224246754757`, 0.3129461454040774, 0.9339101889289132], 
             UndirectedEdge[4, 125] -> 
             RGBColor[
              0.196721601742191, 0.3240972546739574, 0.9345143762444637], 
             UndirectedEdge[246, 251] -> 
             RGBColor[
              0.20081373075853814`, 0.3283983417261034, 0.9347474169381822], 
             UndirectedEdge[30, 229] -> 
             RGBColor[
              0.19931037008134544`, 0.32681821433580155`, 0.9346618027716389],
              UndirectedEdge[115, 366] -> 
             RGBColor[
              0.9742039651565302, 0.9239012646538212, 0.3974339190185809], 
             UndirectedEdge[89, 270] -> 
             RGBColor[
              0.22008543635339983`, 0.34865412620301106`, 0.935844912061876], 
             UndirectedEdge[197, 369] -> 
             RGBColor[
              0.18585850163943218`, 0.31267944770563044`, 0.933895738764128], 
             UndirectedEdge[276, 301] -> 
             RGBColor[
              0.3144566810509267, 0.44134464114731864`, 0.9414571987432081], 
             UndirectedEdge[69, 188] -> 
             RGBColor[
              0.42431357927468827`, 0.535650894850094, 0.9492658859927827], 
             UndirectedEdge[191, 225] -> 
             RGBColor[
              0.19624559498378968`, 0.32359694139030604`, 0.9344872683637615],
              UndirectedEdge[223, 247] -> 
             RGBColor[
              0.8452571321859585, 0.34717028337180467`, 0.19090496268508764`],
              UndirectedEdge[72, 86] -> 
             RGBColor[
              0.3668179912534385, 0.4880512045533021, 0.9448235654131886], 
             UndirectedEdge[19, 85] -> 
             RGBColor[
              0.19070082938217475`, 0.3177690411845645, 0.9341715021654952], 
             UndirectedEdge[320, 398] -> 
             RGBColor[
              0.182257588923795, 0.30889466013044303`, 0.9336906721120455], 
             UndirectedEdge[249, 300] -> 
             RGBColor[
              0.18989148665345995`, 0.3169183706613924, 0.9341254112944102], 
             UndirectedEdge[18, 319] -> 
             RGBColor[
              0.8858082059273583, 0.49573930437115404`, 0.26211860751784904`],
              UndirectedEdge[6, 273] -> 
             RGBColor[
              0.7251045855702409, 0.7842222818473898, 0.9742467167674911], 
             UndirectedEdge[158, 348] -> 
             RGBColor[
              0.1961222229924388, 0.3234672696051602, 0.9344802425113666], 
             UndirectedEdge[61, 228] -> 
             RGBColor[
              0.220637096263315, 0.34923395574559046`, 0.935876328277638], 
             UndirectedEdge[70, 260] -> 
             RGBColor[
              0.19294770058427305`, 0.3201306452778321, 0.9342994581565066], 
             UndirectedEdge[144, 305] -> 
             RGBColor[
              0.4396583364184836, 0.550769790541102, 0.9502316306235659], 
             UndirectedEdge[165, 351] -> 
             RGBColor[
              0.26754769340127105`, 0.39846518644420825`, 0.9385505554925828],
              UndirectedEdge[132, 370] -> 
             RGBColor[
              0.189210358194615, 0.3162024614651078, 0.9340866220363182], 
             UndirectedEdge[104, 145] -> 
             RGBColor[
              0.2369611402467977, 0.36639156097639836`, 0.9368059584332384], 
             UndirectedEdge[207, 231] -> 
             RGBColor[
              0.1913619669815575, 0.3184639387200607, 0.9342091529737147], 
             UndirectedEdge[21, 249] -> 
             RGBColor[
              0.19014493822452405`, 0.31718476433233855`, 0.9341398449864342],
              UndirectedEdge[7, 93] -> 
             RGBColor[
              0.29873862778538124`, 0.4282001700379434, 0.9404384596617476], 
             UndirectedEdge[140, 255] -> 
             RGBColor[
              0.390267723092427, 0.5124520191417203, 0.9460884921086202], 
             UndirectedEdge[100, 157] -> 
             RGBColor[
              0.31728677632069113`, 0.4435179334056334, 0.9416477086340886], 
             UndirectedEdge[42, 178] -> 
             RGBColor[
              0.18344665505298052`, 0.31014444402336394`, 0.9337583876690367],
              UndirectedEdge[115, 195] -> 
             RGBColor[
              0.6898630728334411, 0.7009647207638414, 0.6155071113240207], 
             UndirectedEdge[281, 394] -> 
             RGBColor[
              0.3781881603711747, 0.5019893090490473, 0.9453187930535599], 
             UndirectedEdge[215, 224] -> 
             RGBColor[
              0.6019092601655756, 0.6867200928189938, 0.9624709353645509], 
             UndirectedEdge[99, 222] -> 
             RGBColor[
              0.9266267914902193, 0.9439342403679507, 0.9791054495248444], 
             UndirectedEdge[55, 284] -> 
             RGBColor[
              0.7718010949853338, 0.8216561483989014, 0.9778895783229857], 
             UndirectedEdge[32, 337] -> 
             RGBColor[
              0.8666723181676234, 0.43341792712728777`, 0.43139557632123066`],
              UndirectedEdge[172, 399] -> 
             RGBColor[
              0.369499573099037, 0.49446369145501556`, 0.9447651639555954], 
             UndirectedEdge[267, 346] -> 
             RGBColor[
              0.20049511025135958`, 0.32806345137135173`, 0.9347292719716551],
              UndirectedEdge[222, 393] -> 
             RGBColor[
              0.8365296253571944, 0.8728854021704904, 0.9703016768071477], 
             UndirectedEdge[116, 179] -> 
             RGBColor[
              0.23341719737643146`, 0.3626666523206874, 0.9366041361295647], 
             UndirectedEdge[120, 360] -> 
             RGBColor[
              0.5376516098803733, 0.6341093662239545, 0.9572645433190765], 
             UndirectedEdge[144, 222] -> 
             RGBColor[
              0.7661723613566251, 0.8169857716290115, 0.9639290713689532], 
             UndirectedEdge[237, 307] -> 
             RGBColor[
              0.1806275543927051, 0.307181390488109, 0.9335978440569198], 
             UndirectedEdge[18, 144] -> 
             RGBColor[
              0.7868965412101618, 0.8286865484723305, 0.6945647496408425], 
             UndirectedEdge[309, 365] -> 
             RGBColor[
              0.5016918379873817, 0.6012405287458232, 0.9556046196739707], 
             UndirectedEdge[189, 241] -> 
             RGBColor[
              0.2570425573000169, 0.3874984035347115, 0.937949565426625], 
             UndirectedEdge[268, 370] -> 
             RGBColor[
              0.18660341497029534`, 0.3134623988466007, 0.9339381604763201], 
             UndirectedEdge[336, 359] -> 
             RGBColor[
              0.2802453493603669, 0.4103194523243253, 0.9393282894277089], 
             UndirectedEdge[115, 123] -> 
             RGBColor[
              0.8804744990263506, 0.5083985248696827, 0.22021983203269263`], 
             UndirectedEdge[6, 394] -> 
             RGBColor[
              0.6418942074247149, 0.7140700620770483, 0.9684140052108057], 
             UndirectedEdge[259, 353] -> 
             RGBColor[
              0.9443422105725244, 0.9537215111738743, 0.7488183078429457], 
             UndirectedEdge[98, 348] -> 
             RGBColor[
              0.19717643500186177`, 0.3245753132679656, 0.9345402783257364], 
             UndirectedEdge[145, 349] -> 
             RGBColor[
              0.2241439081408365, 0.35291983737358057`, 0.9360760360261996], 
             UndirectedEdge[287, 292] -> 
             RGBColor[
              0.8180432948668896, 0.1396942477349479, 0.16491158558250754`], 
             UndirectedEdge[53, 69] -> 
             RGBColor[
              0.4877113731208531, 0.5936081076641104, 0.9531940365593021], 
             UndirectedEdge[236, 284] -> 
             RGBColor[
              0.6247504035752902, 0.7047458827568778, 0.9646230139836673], 
             UndirectedEdge[119, 146] -> 
             RGBColor[
              0.2194595639056427, 0.3479962945778132, 0.9358092695518716], 
             UndirectedEdge[198, 310] -> 
             RGBColor[
              0.8272769818270227, 0.4253245421128263, 0.4431946931706203], 
             UndirectedEdge[198, 384] -> 
             RGBColor[
              0.8811911535814985, 0.820358675063078, 0.6244757857174054], 
             UndirectedEdge[111, 292] -> 
             RGBColor[
              0.8242386846136205, 0.1873147281654189, 0.1708442978006689], 
             UndirectedEdge[40, 295] -> 
             RGBColor[
              0.1896748892459051, 0.31669071305298346`, 0.934113076392477], 
             UndirectedEdge[5, 270] -> 
             RGBColor[
              0.19738135324155764`, 0.32479069533045285`, 0.9345519481163376],
              UndirectedEdge[104, 355] -> 
             RGBColor[
              0.21609483282429037`, 0.34445974887503966`, 0.9356176530944622],
              UndirectedEdge[356, 360] -> 
             RGBColor[
              0.804069535005691, 0.8476283188054337, 0.97217824926772], 
             UndirectedEdge[42, 398] -> 
             RGBColor[
              0.18234639975021955`, 0.30898800593994685`, 0.9336957297572264],
              UndirectedEdge[153, 211] -> 
             RGBColor[
              0.21907020233692062`, 0.34758705088213704`, 0.9357870959865418],
              UndirectedEdge[223, 385] -> 
             RGBColor[
              0.9042834117433322, 0.6325667276310734, 0.3474148618138784], 
             UndirectedEdge[144, 361] -> 
             RGBColor[
              0.4954156444114053, 0.6000520136165334, 0.9537482598048219], 
             UndirectedEdge[216, 229] -> 
             RGBColor[
              0.2068690748506942, 0.33476289229794964`, 0.9350922598261517], 
             UndirectedEdge[161, 389] -> 
             RGBColor[
              0.9363348090239618, 0.7668148008617284, 0.3570460900069422], 
             UndirectedEdge[313, 340] -> 
             RGBColor[
              0.2780047879810863, 0.40953103706270466`, 0.9391433334530706], 
             UndirectedEdge[241, 380] -> 
             RGBColor[
              0.5006467932710101, 0.5970366894503322, 0.9560367412293518], 
             UndirectedEdge[258, 281] -> 
             RGBColor[
              0.318201913769557, 0.44345916858997797`, 0.9417371947060786], 
             UndirectedEdge[344, 346] -> 
             RGBColor[
              0.19749434605120672`, 0.3249094579375519, 0.9345583828896893], 
             UndirectedEdge[79, 205] -> 
             RGBColor[
              0.19210249208707042`, 0.3192422775579583, 0.9342513247829649], 
             UndirectedEdge[227, 306] -> 
             RGBColor[
              0.248145898473511, 0.3781474510273044, 0.9374429138678827], 
             UndirectedEdge[43, 381] -> 
             RGBColor[
              0.19202300109929993`, 0.3191587274897918, 0.9342467978888077], 
             UndirectedEdge[98, 143] -> 
             RGBColor[
              0.19607611547037074`, 0.3234188076760809, 0.9344776167561948], 
             UndirectedEdge[243, 267] -> 
             RGBColor[
              0.2144789920516021, 0.342761397772722, 0.9355256333528797], 
             UndirectedEdge[58, 152] -> 
             RGBColor[
              0.19702370192683044`, 0.32441478112227146`, 0.9345315804030616],
              UndirectedEdge[376, 397] -> 
             RGBColor[
              0.32517928194563106`, 0.4539892085157613, 0.9420175102408045], 
             UndirectedEdge[114, 279] -> 
             RGBColor[
              0.19285735565451845`, 0.32003568702846064`, 0.9342943131464105],
              UndirectedEdge[148, 218] -> 
             RGBColor[
              0.40841467546891774`, 0.5204402282772255, 0.9482239194761258], 
             UndirectedEdge[55, 366] -> 
             RGBColor[
              0.8985186945130963, 0.9173414029032505, 0.7466017890196988], 
             UndirectedEdge[99, 361] -> 
             RGBColor[
              0.6558700745449995, 0.7270004823554725, 0.968924637960713], 
             UndirectedEdge[97, 169] -> 
             RGBColor[
              0.37794173807367953`, 0.5007330923555633, 0.945366919038301], 
             UndirectedEdge[43, 250] -> 
             RGBColor[
              0.19420867686654147`, 0.32145601130101026`, 0.9343712688903346],
              UndirectedEdge[112, 177] -> 
             RGBColor[
              0.18091855533538903`, 0.3074872509293952, 0.9336144161301083], 
             UndirectedEdge[255, 356] -> 
             RGBColor[
              0.6597861746771188, 0.7286564919053182, 0.9611997608615672], 
             UndirectedEdge[210, 328] -> 
             RGBColor[
              0.2385161810587667, 0.36802600746505976`, 0.9368945157070033], 
             UndirectedEdge[91, 221] -> 
             RGBColor[
              0.48124384050183955`, 0.5874697805650118, 0.9529301608546397], 
             UndirectedEdge[32, 345] -> 
             RGBColor[
              0.8237071541033182, 0.3995245104435039, 0.439981384340312], 
             UndirectedEdge[210, 258] -> 
             RGBColor[
              0.24166666616429894`, 0.371337367063267, 0.9370739311730383], 
             UndirectedEdge[189, 359] -> 
             RGBColor[
              0.2794316818374808, 0.4094642361682714, 0.9392819522659938], 
             UndirectedEdge[164, 258] -> 
             RGBColor[
              0.22632269335272776`, 0.3552098787742395, 0.936200114620793], 
             UndirectedEdge[354, 374] -> 
             RGBColor[
              0.18986888322413037`, 0.3168946130240269, 0.9341241240625486], 
             UndirectedEdge[235, 322] -> 
             RGBColor[
              0.1941801601361397, 0.32142603840929285`, 0.934369644904725], 
             UndirectedEdge[147, 392] -> 
             RGBColor[
              0.2251386082236323, 0.35396533022822685`, 0.9361326827243879], 
             UndirectedEdge[123, 283] -> 
             RGBColor[
              0.8727460560084327, 0.47775782365460545`, 0.2140013453706027], 
             UndirectedEdge[202, 239] -> 
             RGBColor[
              0.4173644057485659, 0.5344604832455712, 0.9482188359733204], 
             UndirectedEdge[180, 249] -> 
             RGBColor[
              0.18602314959306215`, 0.3128525031441788, 0.9339051152215123], 
             UndirectedEdge[2, 197] -> 
             RGBColor[
              0.1965684920257088, 0.3239363266542179, 0.9345056568726156], 
             UndirectedEdge[174, 329] -> 
             RGBColor[
              0.34008730347088106`, 0.4646976118288939, 0.9430481418570962], 
             UndirectedEdge[193, 242] -> 
             RGBColor[
              0.5891633460741419, 0.6714315101447773, 0.963657200278417], 
             UndirectedEdge[58, 160] -> 
             RGBColor[
              0.1942495004305084, 0.32149891945510295`, 0.9343735937319094], 
             UndirectedEdge[50, 137] -> 
             RGBColor[
              0.2618861891426283, 0.3925893677052923, 0.9382254030945505], 
             UndirectedEdge[326, 383] -> 
             RGBColor[
              0.2999445651565369, 0.428007904865782, 0.9405605857739958], 
             UndirectedEdge[157, 238] -> 
             RGBColor[
              0.22387178003127423`, 0.3526338134765119, 0.9360605387329375], 
             UndirectedEdge[243, 346] -> 
             RGBColor[
              0.21741007073096835`, 0.3458421473058579, 0.9356925539475274], 
             UndirectedEdge[235, 355] -> 
             RGBColor[
              0.2006947956866969, 0.3282733334246791, 0.9347406437617896], 
             UndirectedEdge[44, 135] -> 
             RGBColor[
              0.2818343394924019, 0.41109593137624006`, 0.9394515009810677], 
             UndirectedEdge[33, 206] -> 
             RGBColor[
              0.33773890435239673`, 0.4612073947457289, 0.942951820792434], 
             UndirectedEdge[88, 263] -> 
             RGBColor[
              0.3661139704738488, 0.49089201133024934`, 0.9445728421053426], 
             UndirectedEdge[82, 399] -> 
             RGBColor[
              0.5595672102027384, 0.6489717323660277, 0.9604046913379707], 
             UndirectedEdge[271, 287] -> 
             RGBColor[
              0.819108168528313, 0.14787933332726222`, 0.1659313098032894], 
             UndirectedEdge[31, 223] -> 
             RGBColor[
              0.9008970134683449, 0.6316635118999215, 0.4396735823908346], 
             UndirectedEdge[108, 376] -> 
             RGBColor[
              0.29627129186653856`, 0.4287302908095537, 0.9401835838264763], 
             UndirectedEdge[301, 361] -> 
             RGBColor[
              0.3297210809288895, 0.45456589711056455`, 0.9424298328056531], 
             UndirectedEdge[80, 388] -> 
             RGBColor[
              0.23694403524812552`, 0.36637358253827423`, 0.9368049843288686],
              UndirectedEdge[47, 136] -> 
             RGBColor[
              0.18182023692588944`, 0.308434975450926, 0.9336657655627689], 
             UndirectedEdge[39, 50] -> 
             RGBColor[
              0.21465093660737516`, 0.342942122402754, 0.9355354253409618], 
             UndirectedEdge[120, 389] -> 
             RGBColor[
              0.7028354936755193, 0.7597247670512044, 0.7201987400202577], 
             UndirectedEdge[28, 106] -> 
             RGBColor[
              0.18905752987434937`, 0.31604182921063345`, 0.9340779186895682],
              UndirectedEdge[97, 326] -> 
             RGBColor[
              0.27009816450947055`, 0.40122067448515425`, 0.9386930629431633],
              UndirectedEdge[195, 242] -> 
             RGBColor[
              0.3825084156474021, 0.5057312970269716, 0.9455940758995094], 
             UndirectedEdge[90, 260] -> 
             RGBColor[
              0.20225002842194761`, 0.32990798163687834`, 0.9348292119653014],
              UndirectedEdge[73, 368] -> 
             RGBColor[
              0.19117243294824504`, 0.31826472643389747`, 0.934198359290908], 
             UndirectedEdge[52, 287] -> 
             RGBColor[
              0.8745442200692566, 0.41932367447288343`, 0.3868288304903523], 
             UndirectedEdge[135, 243] -> 
             RGBColor[
              0.2833746021341409, 0.41271484507099976`, 0.9395392166599004], 
             UndirectedEdge[311, 317] -> 
             RGBColor[
              0.19555015626042008`, 0.32286599119868276`, 0.934447664157275], 
             UndirectedEdge[6, 10] -> 
             RGBColor[
              0.8706991660194285, 0.5355001809409162, 0.45679225765188536`], 
             UndirectedEdge[363, 383] -> 
             RGBColor[
              0.36642168177165046`, 0.49179777668654956`, 0.9445690434418867],
              UndirectedEdge[227, 346] -> 
             RGBColor[
              0.23870901568862182`, 0.3682286888874592, 0.9369054973539003], 
             UndirectedEdge[157, 341] -> 
             RGBColor[
              0.24810243304135554`, 0.37810176610224144`, 0.9374404385758228],
              UndirectedEdge[18, 310] -> 
             RGBColor[
              0.8818564092931963, 0.4653640637526585, 0.25833436259805964`], 
             UndirectedEdge[37, 96] -> 
             RGBColor[
              0.24798039051581972`, 0.3779734916699602, 0.9374334884345392], 
             UndirectedEdge[218, 222] -> 
             RGBColor[
              0.7556819189936763, 0.8084691579297268, 0.9631032253183853], 
             UndirectedEdge[65, 203] -> 
             RGBColor[
              0.34325183639463963`, 0.4717292211712722, 0.9430926813827534], 
             UndirectedEdge[105, 303] -> 
             RGBColor[
              0.9396161743909813, 0.7997165627600418, 0.5632237947654809], 
             UndirectedEdge[119, 267] -> 
             RGBColor[
              0.21867692760035795`, 0.34717369419895117`, 0.9357646995720923],
              UndirectedEdge[20, 312] -> 
             RGBColor[
              0.4662211223319299, 0.5756731791658605, 0.9516371294428863], 
             UndirectedEdge[285, 324] -> 
             RGBColor[
              0.1849819453905557, 0.31175813151118514`, 0.9338458201825032], 
             UndirectedEdge[16, 302] -> 
             RGBColor[
              0.21182755927874247`, 0.3399745738178992, 0.9353746381789088], 
             UndirectedEdge[65, 313] -> 
             RGBColor[
              0.33055584599709903`, 0.45850175468157234`, 0.9423653859984371],
              UndirectedEdge[280, 392] -> 
             RGBColor[
              0.20599555407739328`, 0.33384476658079454`, 0.9350425141103704],
              UndirectedEdge[1, 357] -> 
             RGBColor[
              0.18390843895748787`, 0.3106298081857918, 0.9337846855792504], 
             UndirectedEdge[26, 177] -> 
             RGBColor[
              0.18182665700375172`, 0.3084417233598157, 0.9336661311767056], 
             UndirectedEdge[69, 293] -> 
             RGBColor[
              0.44347384418172964`, 0.5552917835398956, 0.950375260333012], 
             UndirectedEdge[165, 399] -> 
             RGBColor[
              0.2924581876891166, 0.42004140455849254`, 0.9401378301611192], 
             UndirectedEdge[108, 297] -> 
             RGBColor[
              0.30146181771501923`, 0.43418586257465347`, 0.9404791765948524],
              UndirectedEdge[192, 335] -> 
             RGBColor[
              0.22826537319767345`, 0.3572517584642937, 0.9363107473640253], 
             UndirectedEdge[134, 272] -> 
             RGBColor[
              0.18788317693480855`, 0.3148075098128992, 0.9340110410269609], 
             UndirectedEdge[86, 236] -> 
             RGBColor[
              0.3888676051713017, 0.5059520744556105, 0.9465593917911999], 
             UndirectedEdge[312, 389] -> 
             RGBColor[
              0.7704699076494956, 0.8157404401627024, 0.7252172989695943], 
             UndirectedEdge[156, 245] -> 
             RGBColor[
              0.1983829021548571, 0.32584338674019936`, 0.9346089848452912], 
             UndirectedEdge[153, 168] -> 
             RGBColor[
              0.20180786245057253`, 0.3294432371660213, 0.9348040312673576], 
             UndirectedEdge[118, 150] -> 
             RGBColor[
              0.29792702653421543`, 0.4259677967148573, 0.9404427441608055], 
             UndirectedEdge[195, 255] -> 
             RGBColor[
              0.3994035312970712, 0.5203649970295117, 0.9466706177289421], 
             UndirectedEdge[109, 180] -> 
             RGBColor[
              0.18558731783868732`, 0.3123944163370016, 0.933880295247856], 
             UndirectedEdge[143, 378] -> 
             RGBColor[
              0.21957024665493602`, 0.3481126291650121, 0.9358155727707034], 
             UndirectedEdge[135, 383] -> 
             RGBColor[
              0.3468364039638354, 0.47483399343410504`, 0.9433210868585539], 
             UndirectedEdge[20, 120] -> 
             RGBColor[
              0.3985867083579536, 0.5196575060543626, 0.9466185704935497], 
             UndirectedEdge[149, 230] -> 
             RGBColor[
              0.21572578902733716`, 0.34407186044571364`, 0.935596636596177], 
             UndirectedEdge[16, 77] -> 
             RGBColor[
              0.21295289463759554`, 0.3411573726304365, 0.9354387243628108], 
             UndirectedEdge[168, 238] -> 
             RGBColor[
              0.19942328541058194`, 0.3269368955060745, 0.9346682331325956], 
             UndirectedEdge[104, 335] -> 
             RGBColor[
              0.21115674634682685`, 0.33926950689445945`, 0.9353364363748149],
              UndirectedEdge[79, 232] -> 
             RGBColor[
              0.19470557204870292`, 0.32197827964243614`, 0.9343995663358682],
              UndirectedEdge[47, 299] -> 
             RGBColor[
              0.184696983160691, 0.3114586181399484, 0.9338295920050762], 
             UndirectedEdge[236, 397] -> 
             RGBColor[
              0.4369077612514729, 0.5513201116783387, 0.9494828667557864], 
             UndirectedEdge[33, 118] -> 
             RGBColor[
              0.30201839786374246`, 0.43026808739011524`, 0.9406757417053806],
              UndirectedEdge[51, 79] -> 
             RGBColor[
              0.20012999875823717`, 0.3276796960426744, 0.934708479412256], 
             UndirectedEdge[24, 168] -> 
             RGBColor[
              0.22907306672132033`, 0.35810069556837376`, 0.9363567443153216],
              UndirectedEdge[269, 365] -> 
             RGBColor[
              0.3297101598350657, 0.4597477851420956, 0.9422390562668672], 
             UndirectedEdge[98, 240] -> 
             RGBColor[
              0.18629079266231832`, 0.3131338129795177, 0.9339203570983641], 
             UndirectedEdge[29, 113] -> 
             RGBColor[
              0.1857448284490183, 0.3125599699752089, 0.9338892652440982], 
             UndirectedEdge[330, 398] -> 
             RGBColor[
              0.18475377969358928`, 0.31151831489713266`, 0.9338328264836019],
              UndirectedEdge[43, 265] -> 
             RGBColor[
              0.19684687423849298`, 0.3242289240103058, 0.934521510327804], 
             UndirectedEdge[209, 304] -> 
             RGBColor[
              0.2736580263748165, 0.40496231501391133`, 0.9388957918100511], 
             UndirectedEdge[107, 238] -> 
             RGBColor[
              0.21198166691675951`, 0.34013655071644366`, 0.9353834143809119],
              UndirectedEdge[298, 347] -> 
             RGBColor[
              0.1948950544058417, 0.32217743761366435`, 0.9344103570757931], 
             UndirectedEdge[153, 343] -> 
             RGBColor[
              0.20318561149837056`, 0.330891338769592, 0.9348824920374326], 
             UndirectedEdge[110, 292] -> 
             RGBColor[
              0.8306488126751848, 0.39575026058266666`, 0.4394783494559681], 
             UndirectedEdge[332, 366] -> 
             RGBColor[
              0.8763032983874938, 0.42126726340738674`, 0.2804991753802838], 
             UndirectedEdge[39, 136] -> 
             RGBColor[
              0.19040517985093924`, 0.31745829478197307`, 0.9341546653620656],
              UndirectedEdge[115, 380] -> 
             RGBColor[
              0.8377450255090341, 0.8206060012110092, 0.627750782576732], 
             UndirectedEdge[167, 238] -> 
             RGBColor[
              0.2183443407497785, 0.3468241243317679, 0.9357457592429699], 
             UndirectedEdge[1, 162] -> 
             RGBColor[
              0.18855509271436693`, 0.315513735899136, 0.9340493056365965], 
             UndirectedEdge[128, 243] -> 
             RGBColor[
              0.26764794439082373`, 0.39864533778752814`, 0.9385535265321823],
              UndirectedEdge[196, 366] -> 
             RGBColor[
              0.9187123308959824, 0.9333119446325909, 0.748562723255582], 
             UndirectedEdge[136, 149] -> 
             RGBColor[
              0.19648120536399588`, 0.3238445828384636, 0.9345006860263599], 
             UndirectedEdge[263, 360] -> 
             RGBColor[
              0.48229378308011506`, 0.5855219577186828, 0.9537605973016217], 
             UndirectedEdge[267, 354] -> 
             RGBColor[
              0.19683262012965425`, 0.3242139420381536, 0.9345206985773926], 
             UndirectedEdge[192, 355] -> 
             RGBColor[
              0.233203459675137, 0.36244200044487396`, 0.9365919640836726], 
             UndirectedEdge[24, 100] -> 
             RGBColor[
              0.32394697736880945`, 0.450518226988342, 0.9420269972308946], 
             UndirectedEdge[11, 286] -> 
             RGBColor[
              0.5972181184299319, 0.677195451192008, 0.9647287147159659], 
             UndirectedEdge[71, 110] -> 
             RGBColor[
              0.9113332721380322, 0.9312595378862136, 0.9610025753124077], 
             UndirectedEdge[186, 306] -> 
             RGBColor[
              0.21444053080855624`, 0.3427209725676972, 0.9355234430419865], 
             UndirectedEdge[6, 131] -> 
             RGBColor[
              0.8701371040264215, 0.8993351938028649, 0.9874630507499915], 
             UndirectedEdge[53, 264] -> 
             RGBColor[
              0.3312918681319017, 0.4568612487266348, 0.9424956938321003], 
             UndirectedEdge[83, 118] -> 
             RGBColor[
              0.6542161598297946, 0.7234949587303476, 0.9559255584190995], 
             UndirectedEdge[98, 272] -> 
             RGBColor[
              0.1949500622314218, 0.3222352543260466, 0.9344134896900831], 
             UndirectedEdge[200, 330] -> 
             RGBColor[
              0.1913737687250167, 0.31847634310071005`, 0.9342098250655455], 
             UndirectedEdge[101, 389] -> 
             RGBColor[
              0.9003569231030979, 0.6064808639762083, 0.2971755264815594], 
             UndirectedEdge[10, 353] -> 
             RGBColor[
              0.8930646658031626, 0.5501769231578431, 0.29510210612227733`], 
             UndirectedEdge[174, 340] -> 
             RGBColor[
              0.3446138349142821, 0.46945528337457815`, 0.9433059211263948], 
             UndirectedEdge[77, 187] -> 
             RGBColor[
              0.2066496337845954, 0.33453224582411256`, 0.9350797629820713], 
             UndirectedEdge[137, 264] -> 
             RGBColor[
              0.27631179289230656`, 0.4077515918823088, 0.9390469198873264], 
             UndirectedEdge[20, 356] -> 
             RGBColor[
              0.6650046334832713, 0.7331764586358418, 0.9615322764421933], 
             UndirectedEdge[130, 227] -> 
             RGBColor[
              0.24482762812914852`, 0.374659738504888, 0.9372539432807123], 
             UndirectedEdge[24, 150] -> 
             RGBColor[
              0.24929421300339247`, 0.3793544024055562, 0.9375083086815804], 
             UndirectedEdge[282, 339] -> 
             RGBColor[
              0.34849054026782905`, 0.4762667231613163, 0.9434264869611491], 
             UndirectedEdge[69, 93] -> 
             RGBColor[
              0.45767335020652483`, 0.5675906819706489, 0.951280040300782], 
             UndirectedEdge[65, 266] -> 
             RGBColor[
              0.5173579150755038, 0.6167245429391528, 0.9558899485594068], 
             UndirectedEdge[189, 336] -> 
             RGBColor[
              0.23398737474331802`, 0.3632659448846183, 0.936636606887107], 
             UndirectedEdge[191, 322] -> 
             RGBColor[
              0.18956017104754852`, 0.31657013695295677`, 0.934106543360791], 
             UndirectedEdge[297, 376] -> 
             RGBColor[
              0.2913695149854919, 0.423578212516969, 0.9399044348846297], 
             UndirectedEdge[33, 286] -> 
             RGBColor[
              0.2839164063725824, 0.41458905219301934`, 0.9395222988145264], 
             UndirectedEdge[145, 351] -> 
             RGBColor[
              0.2797139568415439, 0.4112527007055903, 0.9392434061971325], 
             UndirectedEdge[83, 141] -> 
             RGBColor[
              0.6533758763039106, 0.7227671473741049, 0.9558720162958637], 
             UndirectedEdge[148, 276] -> 
             RGBColor[
              0.31779913118136904`, 0.44485776815799194`, 0.9416475463334251],
              UndirectedEdge[124, 160] -> 
             RGBColor[
              0.21095706740892387`, 0.3390596316703475, 0.9353250649546998], 
             UndirectedEdge[25, 362] -> 
             RGBColor[
              0.5776163710657185, 0.6632666473879071, 0.9621212256893779], 
             UndirectedEdge[96, 208] -> 
             RGBColor[
              0.25302363918053994`, 0.383274265777015, 0.9377206939851772], 
             UndirectedEdge[240, 272] -> 
             RGBColor[
              0.18799208314490007`, 0.3149219771447579, 0.9340172430745133], 
             UndirectedEdge[25, 182] -> 
             RGBColor[
              0.30289473156223595`, 0.4305868645556383, 0.9407477009537915], 
             UndirectedEdge[101, 380] -> 
             RGBColor[
              0.8094432238137885, 0.5377433942133822, 0.4571339579761315], 
             UndirectedEdge[24, 358] -> 
             RGBColor[
              0.2688894294981841, 0.3999502173500661, 0.9386242272724338], 
             UndirectedEdge[202, 234] -> 
             RGBColor[
              0.28726387007128157`, 0.41752052418196, 0.9397344221047603], 
             UndirectedEdge[17, 62] -> 
             RGBColor[
              0.8823757434978273, 0.4727098560142903, 0.37791307557422715`], 
             UndirectedEdge[24, 211] -> 
             RGBColor[
              0.2463354066076684, 0.3762445092844895, 0.9373398090345058], 
             UndirectedEdge[2, 39] -> 
             RGBColor[
              0.19999978068083032`, 0.3275428285870168, 0.934701063685388], 
             UndirectedEdge[164, 328] -> 
             RGBColor[
              0.22317220824719552`, 0.35189851917603227`, 0.9360206991547579],
              UndirectedEdge[228, 301] -> 
             RGBColor[
              0.2369380396545014, 0.36636728078923275`, 0.9368046428886814], 
             UndirectedEdge[118, 286] -> 
             RGBColor[
              0.33934539796061675`, 0.46834566054302623`, 0.9428437665800653],
              UndirectedEdge[139, 215] -> 
             RGBColor[
              0.5065072627092252, 0.6051273956422916, 0.956064783626883], 
             UndirectedEdge[239, 377] -> 
             RGBColor[
              0.3809157120608543, 0.4978929904163819, 0.9460793391645779], 
             UndirectedEdge[348, 374] -> 
             RGBColor[
              0.19237032800791454`, 0.3195237900925436, 0.9342665776424293], 
             UndirectedEdge[8, 388] -> 
             RGBColor[
              0.26319007599843486`, 0.3939598354619466, 0.938299657522061], 
             UndirectedEdge[249, 370] -> 
             RGBColor[
              0.18458433002004276`, 0.31134021254650546`, 0.9338231765753717],
              UndirectedEdge[61, 285] -> 
             RGBColor[
              0.2007711589524707, 0.32835359605871806`, 0.934744992536806], 
             UndirectedEdge[162, 280] -> 
             RGBColor[
              0.20211294537388308`, 0.32976389866179523`, 0.9348214052885103],
              UndirectedEdge[126, 205] -> 
             RGBColor[
              0.18385657240612066`, 0.31057529315177557`, 0.9337817318558796],
              UndirectedEdge[161, 334] -> 
             RGBColor[
              0.9198789642740572, 0.7116881876157337, 0.2605664067222301], 
             UndirectedEdge[192, 399] -> 
             RGBColor[
              0.3088211273745378, 0.43723989163816773`, 0.941069675369404], 
             UndirectedEdge[69, 281] -> 
             RGBColor[
              0.4857845720433236, 0.5919392094145923, 0.9530712624984452], 
             UndirectedEdge[38, 128] -> 
             RGBColor[
              0.281313846761083, 0.4130090676469258, 0.9393317794552777], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.22265042245962569`, 0.35135008923016664`, 0.9359909842260687],
              UndirectedEdge[145, 355] -> 
             RGBColor[
              0.22900678342998865`, 0.3580310276265808, 0.9363529695799375], 
             UndirectedEdge[23, 139] -> 
             RGBColor[
              0.2594316195520534, 0.3900094594368974, 0.9380856189875776], 
             UndirectedEdge[120, 359] -> 
             RGBColor[
              0.3691186833876108, 0.4941337839310517, 0.9447408939999908], 
             UndirectedEdge[117, 309] -> 
             RGBColor[
              0.6279491492944215, 0.7079937863162957, 0.9644297266188226], 
             UndirectedEdge[19, 167] -> 
             RGBColor[
              0.21765966709879997`, 0.34610448891377266`, 0.9357067680914306],
              UndirectedEdge[26, 285] -> 
             RGBColor[
              0.1832664520031871, 0.30995503919249784`, 0.9337481253719375], 
             UndirectedEdge[166, 169] -> 
             RGBColor[
              0.3512165772923903, 0.4726432539013666, 0.9438449606681389], 
             UndirectedEdge[31, 383] -> 
             RGBColor[
              0.6712879724630387, 0.7362684219408357, 0.9272977112853262], 
             UndirectedEdge[146, 346] -> 
             RGBColor[
              0.20127774655664432`, 0.3288860517502138, 0.9347738419514344], 
             UndirectedEdge[191, 349] -> 
             RGBColor[
              0.1912119313089536, 0.3183062417153429, 0.9342006086641177], 
             UndirectedEdge[212, 362] -> 
             RGBColor[
              0.6845252117813709, 0.7524862898136562, 0.9698671068536907], 
             UndirectedEdge[242, 380] -> 
             RGBColor[
              0.5303903683229951, 0.6253725774741394, 0.9578377471522206], 
             UndirectedEdge[175, 307] -> 
             RGBColor[
              0.18458331869086259`, 0.3113391495754152, 0.933823118981671], 
             UndirectedEdge[140, 193] -> 
             RGBColor[
              0.6221373960333281, 0.6999919748954846, 0.9657582775840088], 
             UndirectedEdge[8, 25] -> 
             RGBColor[
              0.3097802502292844, 0.43782398124180466`, 0.9411398210556678], 
             UndirectedEdge[8, 269] -> 
             RGBColor[
              0.30450100126350144`, 0.4332513611304116, 0.9408034319798247], 
             UndirectedEdge[155, 371] -> 
             RGBColor[
              0.18296643499197385`, 0.3096397022915355, 0.9337310398469844], 
             UndirectedEdge[55, 161] -> 
             RGBColor[
              0.8416418357931794, 0.6962674351181222, 0.6011377684958046], 
             UndirectedEdge[110, 202] -> 
             RGBColor[
              0.590277084299675, 0.6718791600205865, 0.9639661767270546], 
             UndirectedEdge[332, 380] -> 
             RGBColor[
              0.7853306719558296, 0.3524037544455121, 0.43404375108571785`], 
             UndirectedEdge[359, 360] -> 
             RGBColor[
              0.49422258294729215`, 0.5964933259008812, 0.9544972841256812], 
             UndirectedEdge[128, 350] -> 
             RGBColor[
              0.32622360223214686`, 0.4565323538126437, 0.9420240559565443], 
             UndirectedEdge[272, 378] -> 
             RGBColor[
              0.2184441934159871, 0.34692907581497784`, 0.9357514457045917], 
             UndirectedEdge[52, 345] -> 
             RGBColor[
              0.9085391948738575, 0.9277362639462506, 0.9077575254526454], 
             UndirectedEdge[32, 333] -> 
             RGBColor[
              0.8656047551536187, 0.43262174037941703`, 0.4332026820389135], 
             UndirectedEdge[85, 168] -> 
             RGBColor[
              0.18992658867508105`, 0.3169552651117129, 0.9341274103026127], 
             UndirectedEdge[23, 354] -> 
             RGBColor[
              0.20401044687486744`, 0.3317582930478737, 0.9349294651918895], 
             UndirectedEdge[51, 373] -> 
             RGBColor[
              0.1995969758310581, 0.32711945515060364`, 0.9346781245450898], 
             UndirectedEdge[55, 334] -> 
             RGBColor[
              0.8819744590496598, 0.862025730858683, 0.6405013220512796], 
             UndirectedEdge[66, 267] -> 
             RGBColor[
              0.1968456208420638, 0.3242276066111888, 0.9345214389487315], 
             UndirectedEdge[30, 153] -> 
             RGBColor[
              0.2031751711317593, 0.3308803652823261, 0.9348818974739992], 
             UndirectedEdge[179, 290] -> 
             RGBColor[
              0.24217146180405288`, 0.37186793928654055`, 0.9371026785379442],
              UndirectedEdge[178, 200] -> 
             RGBColor[
              0.1885274133225135, 0.31548464310332325`, 0.9340477293361784], 
             UndirectedEdge[340, 358] -> 
             RGBColor[
              0.2744945486553811, 0.4058415529693607, 0.9389434305164055], 
             UndirectedEdge[31, 259] -> 
             RGBColor[
              0.9398415048836066, 0.9536048784389164, 0.9502151803126189], 
             UndirectedEdge[92, 146] -> 
             RGBColor[
              0.20174986693286398`, 0.32938228019978144`, 0.9348007285084208],
              UndirectedEdge[3, 373] -> 
             RGBColor[
              0.21710028788855346`, 0.3455165458971132, 0.9356749122729344], 
             UndirectedEdge[174, 341] -> 
             RGBColor[
              0.3335895874564281, 0.4578681003187137, 0.9426781065425826], 
             UndirectedEdge[248, 260] -> 
             RGBColor[
              0.1859219097416619, 0.3127460936413798, 0.933899349761746], 
             UndirectedEdge[41, 325] -> 
             RGBColor[
              0.2165335134226994, 0.3449208299979239, 0.9356426353055718], 
             UndirectedEdge[66, 346] -> 
             RGBColor[
              0.19977669952143007`, 0.3273083561443247, 0.9346883595433791], 
             UndirectedEdge[53, 142] -> 
             RGBColor[
              0.43838221439814257`, 0.5535604743597381, 0.949310664485988], 
             UndirectedEdge[38, 44] -> 
             RGBColor[
              0.24351959225973108`, 0.37328490987186613`, 0.9371794525730147],
              UndirectedEdge[76, 187] -> 
             RGBColor[
              0.24964108184106412`, 0.37971898354670364`, 0.9375280623487394],
              UndirectedEdge[156, 160] -> 
             RGBColor[
              0.19858358472464382`, 0.32605431684505504`, 0.9346204134207573],
              UndirectedEdge[141, 290] -> 
             RGBColor[
              0.3066482770874609, 0.4352897639120549, 0.9409337172583541], 
             UndirectedEdge[3, 79] -> 
             RGBColor[
              0.21763331081573253`, 0.34607678678918397`, 0.9357052671401005],
              UndirectedEdge[301, 382] -> 
             RGBColor[
              0.2859820358837003, 0.41668133468074653`, 0.9396428195322926], 
             UndirectedEdge[193, 389] -> 
             RGBColor[
              0.9155257058475293, 0.9306524378746825, 0.7386464272151838], 
             UndirectedEdge[189, 291] -> 
             RGBColor[
              0.21431712870363867`, 0.34259126913128346`, 0.9355164154746687],
              UndirectedEdge[161, 196] -> 
             RGBColor[
              0.8618354721760655, 0.7122379768474625, 0.603098702731688], 
             UndirectedEdge[83, 161] -> 
             RGBColor[
              0.9152656356126947, 0.754447556797873, 0.5945283802670174], 
             UndirectedEdge[100, 211] -> 
             RGBColor[
              0.31010062158634694`, 0.43596482915131163`, 0.941238467752931], 
             UndirectedEdge[32, 287] -> 
             RGBColor[
              0.8201189109233364, 0.1556483422855536, 0.16689919786223403`], 
             UndirectedEdge[156, 181] -> 
             RGBColor[
              0.19699698742024596`, 0.3243867024820536, 0.9345300590514323], 
             UndirectedEdge[126, 176] -> 
             RGBColor[
              0.18438193895865332`, 0.3111274867086507, 0.9338116507038363], 
             UndirectedEdge[46, 350] -> 
             RGBColor[
              0.5770408715617338, 0.6621623046757947, 0.9623409899481321], 
             UndirectedEdge[47, 149] -> 
             RGBColor[
              0.1956652358484003, 0.3229869471421173, 0.9344542177695655], 
             UndirectedEdge[57, 108] -> 
             RGBColor[
              0.32733127751038416`, 0.4577193635987606, 0.9420863025998256], 
             UndirectedEdge[105, 400] -> 
             RGBColor[
              0.8765109090962969, 0.44339193500149654`, 0.4102881127942457], 
             UndirectedEdge[62, 256] -> 
             RGBColor[
              0.992053902372576, 0.9909820986727351, 0.781350931735281], 
             UndirectedEdge[193, 332] -> 
             RGBColor[
              0.8245126571232608, 0.38310970955927065`, 0.4379233865031822], 
             UndirectedEdge[1, 387] -> 
             RGBColor[
              0.1836776641650684, 0.31038724924699196`, 0.9337715432962228], 
             UndirectedEdge[72, 284] -> 
             RGBColor[
              0.602700789657427, 0.6868450128545692, 0.9628871876056561], 
             UndirectedEdge[127, 394] -> 
             RGBColor[
              0.348496932711213, 0.47627225997448197`, 0.9434268942819889], 
             UndirectedEdge[110, 385] -> 
             RGBColor[
              0.923690126192328, 0.9380306979900004, 0.809802069993292], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.18382719114068813`, 0.31054441157892615`, 0.933780058636279], 
             UndirectedEdge[97, 393] -> 
             RGBColor[
              0.5102982570407728, 0.6069665111134733, 0.9566203329382144], 
             UndirectedEdge[19, 150] -> 
             RGBColor[
              0.21895975804167556`, 0.3474709669252617, 0.9357808063473152], 
             UndirectedEdge[272, 342] -> 
             RGBColor[
              0.19152273141080622`, 0.31863291232825464`, 0.9342183082701306],
              UndirectedEdge[96, 187] -> 
             RGBColor[
              0.2139882194822336, 0.34224556468553763`, 0.9354976845810872], 
             UndirectedEdge[129, 333] -> 
             RGBColor[
              0.8641496188044945, 0.42143692475523437`, 0.4318092418276507], 
             UndirectedEdge[19, 160] -> 
             RGBColor[
              0.19740416245689973`, 0.32481466926196517`, 0.9345532470674082],
              UndirectedEdge[183, 357] -> 
             RGBColor[
              0.18734376764879906`, 0.31424055645277915`, 0.9339803224661072],
              UndirectedEdge[197, 217] -> 
             RGBColor[
              0.19977926755688577`, 0.3273110553124115, 0.9346885057891993], 
             UndirectedEdge[199, 345] -> 
             RGBColor[
              0.9084097409587222, 0.9276827314255283, 0.9099029118424318], 
             UndirectedEdge[44, 346] -> 
             RGBColor[
              0.2158698080892293, 0.3442232336110982, 0.9356048382686947], 
             UndirectedEdge[78, 80] -> 
             RGBColor[
              0.21178615052788774`, 0.3399310505952844, 0.9353722800118063], 
             UndirectedEdge[42, 320] -> 
             RGBColor[
              0.18379681968568948`, 0.3105124892540611, 0.9337783290268474], 
             UndirectedEdge[161, 332] -> 
             RGBColor[
              0.8383853925742157, 0.27388461821730115`, 0.1835231616976877], 
             UndirectedEdge[239, 309] -> 
             RGBColor[
              0.6022520031590326, 0.6871316854403461, 0.9624067531432969], 
             UndirectedEdge[8, 377] -> 
             RGBColor[
              0.25514638831763914`, 0.3855054097101751, 0.9378415814082092], 
             UndirectedEdge[75, 126] -> 
             RGBColor[
              0.18223452639463555`, 0.3088704199500476, 0.9336893587351277], 
             UndirectedEdge[54, 310] -> 
             RGBColor[
              0.8670957257484463, 0.41406650637033016`, 0.20775781021814968`],
              UndirectedEdge[65, 211] -> 
             RGBColor[
              0.3044915837808781, 0.4311065625226518, 0.9408810648238439], 
             UndirectedEdge[88, 356] -> 
             RGBColor[
              0.6878897223994248, 0.7529983724170004, 0.962990494071441], 
             UndirectedEdge[98, 158] -> 
             RGBColor[
              0.19219455973941713`, 0.31933904649800093`, 0.9342565678995641],
              UndirectedEdge[13, 390] -> 
             RGBColor[
              0.2131729075996141, 0.34138862020314553`, 0.9354512537755177], 
             UndirectedEdge[241, 242] -> 
             RGBColor[
              0.31065498243158685`, 0.4409219663646659, 0.9411098670507269], 
             UndirectedEdge[12, 238] -> 
             RGBColor[
              0.2218338423144311, 0.3504918117233956, 0.9359444811948219], 
             UndirectedEdge[175, 343] -> 
             RGBColor[
              0.19542826971397487`, 0.32273788071031545`, 0.93444072289877], 
             UndirectedEdge[59, 258] -> 
             RGBColor[
              0.2269624966999203, 0.35588235265801405`, 0.9362365504749113], 
             UndirectedEdge[152, 156] -> 
             RGBColor[
              0.20135778622096587`, 0.32897017851222354`, 0.9347784000919095],
              UndirectedEdge[39, 258] -> 
             RGBColor[
              0.21791338707223826`, 0.34637116469263174`, 0.9357212170685729],
              UndirectedEdge[183, 368] -> 
             RGBColor[
              0.18625851527578347`, 0.31309988739976513`, 0.933918518948951], 
             UndirectedEdge[44, 119] -> 
             RGBColor[
              0.23405162543822766`, 0.3633334764386976, 0.9366402658691317], 
             UndirectedEdge[149, 264] -> 
             RGBColor[
              0.23515256587011008`, 0.3644906346362611, 0.9367029627980321], 
             UndirectedEdge[120, 241] -> 
             RGBColor[
              0.34672955885014695`, 0.4721679512974918, 0.9434085071606221], 
             UndirectedEdge[116, 304] -> 
             RGBColor[
              0.26114585574207083`, 0.3918112303614577, 0.938183242202614], 
             UndirectedEdge[82, 256] -> 
             RGBColor[
              0.8760312800563814, 0.9016669835366705, 0.876948136427472], 
             UndirectedEdge[98, 186] -> 
             RGBColor[
              0.1999149394327242, 0.32745365505601143`, 0.9346962321018197], 
             UndirectedEdge[72, 262] -> 
             RGBColor[
              0.4149349676293397, 0.5334857796550911, 0.9477519352990894], 
             UndirectedEdge[147, 241] -> 
             RGBColor[
              0.2640632471374818, 0.3948775936913327, 0.9383493833266887], 
             UndirectedEdge[13, 205] -> 
             RGBColor[
              0.19925835051903662`, 0.3267635384775842, 0.9346588403345214], 
             UndirectedEdge[142, 394] -> 
             RGBColor[
              0.4158923670367568, 0.5340808989479011, 0.9478776312991117], 
             UndirectedEdge[42, 75] -> 
             RGBColor[
              0.18289766237674282`, 0.30956741791249204`, 0.9337271233482869],
              UndirectedEdge[56, 341] -> 
             RGBColor[
              0.38387079611477953`, 0.499652079122729, 0.9463702293168075], 
             UndirectedEdge[306, 378] -> 
             RGBColor[
              0.23126849430923743`, 0.36040822916142345`, 0.9364817706686093],
              UndirectedEdge[27, 295] -> 
             RGBColor[
              0.19546687096427723`, 0.32277845307184394`, 0.9344429211828693],
              UndirectedEdge[111, 247] -> 
             RGBColor[
              0.8235209713761704, 0.1817980697184317, 0.17015701479394557`], 
             UndirectedEdge[128, 259] -> 
             RGBColor[
              0.599663278641086, 0.6781009426487141, 0.9652528657581285], 
             UndirectedEdge[52, 68] -> 
             RGBColor[
              0.9052995090875355, 0.9251530264391655, 0.9074485213302443], 
             UndirectedEdge[241, 359] -> 
             RGBColor[
              0.3033005319170658, 0.43455191097441853`, 0.9406412479672268], 
             UndirectedEdge[361, 382] -> 
             RGBColor[
              0.3658350125936814, 0.49128963333144304`, 0.9445316614006376], 
             UndirectedEdge[14, 390] -> 
             RGBColor[
              0.27581610861732475`, 0.40446583032584077`, 0.9391199230263283],
              UndirectedEdge[11, 332] -> 
             RGBColor[
              0.8362675556984924, 0.39248274660493876`, 0.43904457922300955`],
              UndirectedEdge[22, 209] -> 
             RGBColor[
              0.25353925279510015`, 0.38381620837770913`, 0.9377500574177445],
              UndirectedEdge[33, 156] -> 
             RGBColor[
              0.22423055163894667`, 0.35301090518360945`, 0.9360809702452394],
              UndirectedEdge[283, 332] -> 
             RGBColor[
              0.8558441265023222, 0.3478421869979039, 0.19781603858755223`], 
             UndirectedEdge[150, 181] -> 
             RGBColor[
              0.21526447072748034`, 0.3435869856632946, 0.9355703652014595], 
             UndirectedEdge[117, 323] -> 
             RGBColor[
              0.4895767347577772, 0.5956116976057565, 0.9532057157698048], 
             UndirectedEdge[199, 223] -> 
             RGBColor[
              0.9023894680156853, 0.6322806802095792, 0.4149397481928467], 
             UndirectedEdge[128, 306] -> 
             RGBColor[
              0.2631009453754704, 0.39386615352600307`, 0.9382945816649401], 
             UndirectedEdge[184, 288] -> 
             RGBColor[
              0.21364346222149755`, 0.3418832029456312, 0.9354780511651108], 
             UndirectedEdge[145, 182] -> 
             RGBColor[
              0.24585035887698375`, 0.3757346933657375, 0.937312186283807], 
             UndirectedEdge[284, 397] -> 
             RGBColor[
              0.5520222170780682, 0.6432815473581924, 0.9595663255932364], 
             UndirectedEdge[61, 148] -> 
             RGBColor[
              0.23690961095816437`, 0.3663374004268991, 0.9368030239164815], 
             UndirectedEdge[34, 159] -> 
             RGBColor[
              0.1825395439463383, 0.30919101273611693`, 0.9337067290334642], 
             UndirectedEdge[276, 382] -> 
             RGBColor[
              0.35057061271571854`, 0.4780683773681971, 0.9435590273381926], 
             UndirectedEdge[59, 164] -> 
             RGBColor[
              0.215632569168565, 0.3439738804636637, 0.9355913278631264], 
             UndirectedEdge[80, 377] -> 
             RGBColor[
              0.2289003475673298, 0.3579191567865028, 0.9363469082150169], 
             UndirectedEdge[180, 370] -> 
             RGBColor[
              0.18698550798658503`, 0.3138640028328177, 0.9339599201083417], 
             UndirectedEdge[98, 374] -> 
             RGBColor[
              0.18844266475489285`, 0.3153955669853844, 0.9340429030306268], 
             UndirectedEdge[139, 350] -> 
             RGBColor[
              0.3277444111277722, 0.4581308203867991, 0.942110663773315], 
             UndirectedEdge[36, 276] -> 
             RGBColor[
              0.31234957064668134`, 0.4391299345139409, 0.941337201922877], 
             UndirectedEdge[53, 281] -> 
             RGBColor[
              0.40067800773256046`, 0.5214688844608842, 0.9467518262404362], 
             UndirectedEdge[73, 183] -> 
             RGBColor[
              0.19359784833893534`, 0.3208139917897307, 0.9343364831093273], 
             UndirectedEdge[101, 115] -> 
             RGBColor[
              0.8876851213781989, 0.5638225279808512, 0.22712473214005577`], 
             UndirectedEdge[283, 366] -> 
             RGBColor[
              0.9626113006296535, 0.8779402128312055, 0.388106189025446], 
             UndirectedEdge[22, 141] -> 
             RGBColor[
              0.2988998919025237, 0.4271457198066904, 0.9404924581847806], 
             UndirectedEdge[197, 314] -> 
             RGBColor[
              0.18703267242257346`, 0.3139135756454394, 0.9339626060531978], 
             UndirectedEdge[13, 14] -> 
             RGBColor[
              0.27600611579144196`, 0.4046655399129887, 0.9391307436538039], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.18066543438157506`, 0.30722120475814135`, 0.9336000012662475],
              UndirectedEdge[323, 395] -> 
             RGBColor[
              0.42965137086591587`, 0.5465641553634234, 0.9485979833191546], 
             UndirectedEdge[93, 131] -> 
             RGBColor[
              0.5783198351360825, 0.6629059133309206, 0.9625766163950823], 
             UndirectedEdge[52, 105] -> 
             RGBColor[
              0.9871484754393005, 0.988953578572104, 0.8626465508576164], 
             UndirectedEdge[178, 330] -> 
             RGBColor[
              0.18585403499635023`, 0.3126747529805498, 0.9338954843954123], 
             UndirectedEdge[92, 98] -> 
             RGBColor[
              0.19880960071600262`, 0.32629187398221465`, 0.9346332846971046],
              UndirectedEdge[37, 323] -> 
             RGBColor[
              0.35247668459828785`, 0.4774620340320098, 0.9437631308877006], 
             UndirectedEdge[279, 370] -> 
             RGBColor[
              0.19229180160053655`, 0.3194412538595276, 0.9342621056796985], 
             UndirectedEdge[150, 160] -> 
             RGBColor[
              0.2168510680318782, 0.345254600026296, 0.9356607195707846], 
             UndirectedEdge[188, 273] -> 
             RGBColor[
              0.39992754574806544`, 0.5158532142548906, 0.9473461281045827], 
             UndirectedEdge[179, 386] -> 
             RGBColor[
              0.284370042597393, 0.41315352294311436`, 0.9396181524839584], 
             UndirectedEdge[141, 179] -> 
             RGBColor[
              0.2912900071166007, 0.41914724840212236`, 0.9400590865040379], 
             UndirectedEdge[117, 388] -> 
             RGBColor[
              0.4146565458770389, 0.527209517044103, 0.9485603887539554], 
             UndirectedEdge[198, 214] -> 
             RGBColor[
              0.8538594754790496, 0.7047084000192836, 0.6021070091036955], 
             UndirectedEdge[150, 238] -> 
             RGBColor[
              0.21964443169265407`, 0.3481906023432569, 0.9358197974988545], 
             UndirectedEdge[331, 392] -> 
             RGBColor[
              0.22201549227327083`, 0.35068273734740874`, 0.9359548258912509],
              UndirectedEdge[323, 365] -> 
             RGBColor[
              0.3633194234507374, 0.48885844003528395`, 0.9443806088249529], 
             UndirectedEdge[6, 71] -> 
             RGBColor[
              0.9479335881069795, 0.9604436363507414, 0.9644935461230137], 
             UndirectedEdge[132, 249] -> 
             RGBColor[
              0.18824799980109214`, 0.3151909617764689, 0.9340318171494888], 
             UndirectedEdge[348, 378] -> 
             RGBColor[
              0.22067056618642705`, 0.3492691347568969, 0.935878234340245], 
             UndirectedEdge[174, 198] -> 
             RGBColor[
              0.6233166189809511, 0.701327344471203, 0.9656888716580491], 
             UndirectedEdge[72, 236] -> 
             RGBColor[
              0.4875863338308316, 0.5948835771747154, 0.9528037287682061], 
             UndirectedEdge[9, 100] -> 
             RGBColor[
              0.5370355289675518, 0.6325732881317867, 0.9576495756744858], 
             UndirectedEdge[51, 298] -> 
             RGBColor[
              0.20333725610200998`, 0.3310507268628402, 0.9348911279732717], 
             UndirectedEdge[23, 128] -> 
             RGBColor[
              0.2579108106564282, 0.38841099286274205`, 0.9379990111708069], 
             UndirectedEdge[215, 353] -> 
             RGBColor[
              0.8496653857450382, 0.8791494975932964, 0.7395436178949295], 
             UndirectedEdge[80, 96] -> 
             RGBColor[
              0.2073679300463957, 0.3352872207378781, 0.9351206688915568], 
             UndirectedEdge[78, 388] -> 
             RGBColor[
              0.2456236030410635, 0.37549635860503494`, 0.9372992728744065], 
             UndirectedEdge[312, 380] -> 
             RGBColor[
              0.6340993587155315, 0.7126342355184634, 0.9651549462114524], 
             UndirectedEdge[57, 325] -> 
             RGBColor[
              0.29328547563165996`, 0.42193506719570584`, 0.9401474445490827],
              UndirectedEdge[308, 374] -> 
             RGBColor[
              0.1982421611639798, 0.32569545903529307`, 0.9346009698540684], 
             UndirectedEdge[76, 365] -> 
             RGBColor[
              0.2944759917270998, 0.42684331653440033`, 0.9400813441394438], 
             UndirectedEdge[182, 187] -> 
             RGBColor[
              0.22908739425404853`, 0.35811575471368917`, 0.9363575602471148],
              UndirectedEdge[74, 286] -> 
             RGBColor[
              0.28488862903471124`, 0.4156109198533938, 0.9395776654568602], 
             UndirectedEdge[137, 164] -> 
             RGBColor[
              0.2538187120761361, 0.3841099378008197, 0.9377659722103766], 
             UndirectedEdge[149, 258] -> 
             RGBColor[
              0.22398941258529487`, 0.35275745274912235`, 0.9360672377328672],
              UndirectedEdge[147, 331] -> 
             RGBColor[
              0.2440919709450002, 0.37388651616098867`, 0.9372120486923824], 
             UndirectedEdge[42, 367] -> 
             RGBColor[
              0.1849893429390042, 0.3117659068036362, 0.9338462414619436], 
             UndirectedEdge[16, 365] -> 
             RGBColor[
              0.2674853323456614, 0.39847442221786333`, 0.9385442660167731], 
             UndirectedEdge[113, 183] -> 
             RGBColor[
              0.18716623928349274`, 0.31405396288489373`, 0.9339702124883327],
              UndirectedEdge[16, 323] -> 
             RGBColor[
              0.3247877744177019, 0.4483592338539112, 0.9421862884149881], 
             UndirectedEdge[340, 343] -> 
             RGBColor[
              0.2360559349263153, 0.3654401327912391, 0.9367544083293682], 
             UndirectedEdge[323, 362] -> 
             RGBColor[
              0.6059463857156073, 0.6878046821697024, 0.9639263891716204], 
             UndirectedEdge[334, 364] -> 
             RGBColor[
              0.9407749655383337, 0.8016431292497415, 0.27774757447488835`], 
             UndirectedEdge[94, 324] -> 
             RGBColor[
              0.18239675869616345`, 0.30904093638507546`, 0.9336985976246985],
              UndirectedEdge[135, 350] -> 
             RGBColor[
              0.3419502599754641, 0.47060186109611535`, 0.9430097460842624], 
             UndirectedEdge[31, 215] -> 
             RGBColor[
              0.8451646800561206, 0.8790328648583385, 0.9409404903646027], 
             UndirectedEdge[3, 21] -> 
             RGBColor[
              0.21644166427209716`, 0.34482429071706844`, 0.9356374046323236],
              UndirectedEdge[127, 193] -> 
             RGBColor[
              0.5886484429999097, 0.6709855269816585, 0.9636243911098379], 
             UndirectedEdge[50, 230] -> 
             RGBColor[
              0.2261265468612622, 0.35500371637530337`, 0.9361889443682767], 
             UndirectedEdge[169, 382] -> 
             RGBColor[
              0.38967734439969204`, 0.5118336629702842, 0.9460804380697425], 
             UndirectedEdge[12, 19] -> 
             RGBColor[
              0.22114916866345258`, 0.3497721763054004, 0.9359054900432826], 
             UndirectedEdge[133, 296] -> 
             RGBColor[
              0.18124069831826523`, 0.30782584362944293`, 0.9336327616964153],
              UndirectedEdge[214, 332] -> 
             RGBColor[
              0.8381770729417689, 0.2729386874206463, 0.1833493346899926], 
             UndirectedEdge[76, 395] -> 
             RGBColor[
              0.36080793914227827`, 0.4845490318625397, 0.9442987186336453], 
             UndirectedEdge[299, 370] -> 
             RGBColor[
              0.1869681936623269, 0.3138458043802308, 0.9339589340831895], 
             UndirectedEdge[170, 235] -> 
             RGBColor[
              0.21437654864384317`, 0.34265372325588017`, 0.9355197993523594],
              UndirectedEdge[46, 400] -> 
             RGBColor[
              0.8165889705092233, 0.3966653849576874, 0.4396245779524498], 
             UndirectedEdge[65, 329] -> 
             RGBColor[
              0.31941652727713654`, 0.4467936244332925, 0.9417310182764805], 
             UndirectedEdge[81, 267] -> 
             RGBColor[
              0.21336000502701669`, 0.3415852714620077, 0.9354619086972226], 
             UndirectedEdge[104, 182] -> 
             RGBColor[
              0.23293840827128548`, 0.36216341461419643`, 0.9365768697983317],
              UndirectedEdge[23, 306] -> 
             RGBColor[
              0.21710981978146196`, 0.345526564520917, 0.9356754551001344], 
             UndirectedEdge[209, 286] -> 
             RGBColor[
              0.29314447532730914`, 0.4242883377578022, 0.9400478236897936], 
             UndirectedEdge[150, 167] -> 
             RGBColor[
              0.2371065726737784, 0.3665444196781035, 0.936814240594807], 
             UndirectedEdge[4, 288] -> 
             RGBColor[
              0.2072894767278965, 0.33520476132590776`, 0.9351162010911295], 
             UndirectedEdge[171, 272] -> 
             RGBColor[
              0.19235235421379315`, 0.3195048984953177, 0.9342655540614437], 
             UndirectedEdge[78, 182] -> 
             RGBColor[
              0.23114667261114863`, 0.3602801868327903, 0.9364748331031223], 
             UndirectedEdge[143, 374] -> 
             RGBColor[
              0.1912700084764235, 0.3183672845006589, 0.9342039160728877], 
             UndirectedEdge[55, 262] -> 
             RGBColor[
              0.5840352729572464, 0.6682969151994234, 0.9627543260164191], 
             UndirectedEdge[165, 190] -> 
             RGBColor[
              0.21884661716031273`, 0.34735204868540315`, 0.9357743631414985],
              UndirectedEdge[2, 149] -> 
             RGBColor[
              0.20607580619388693`, 0.3339291166435074, 0.9350470843496823], 
             UndirectedEdge[39, 47] -> 
             RGBColor[
              0.18958921033534365`, 0.3166006590856267, 0.9341081971052712], 
             UndirectedEdge[230, 300] -> 
             RGBColor[
              0.2086431877242838, 0.3366275974133453, 0.9351932929297377], 
             UndirectedEdge[40, 48] -> 
             RGBColor[
              0.20069384731952558`, 0.3282723366306521, 0.934740589753682], 
             UndirectedEdge[25, 208] -> 
             RGBColor[
              0.3291899186131193, 0.4582247733572693, 0.9422451729560961], 
             UndirectedEdge[32, 52] -> 
             RGBColor[
              0.8773441309925929, 0.440845016758437, 0.3895100283525863], 
             UndirectedEdge[161, 366] -> 
             RGBColor[
              0.9364231997374939, 0.7670038596603013, 0.3666668736906492], 
             UndirectedEdge[190, 318] -> 
             RGBColor[
              0.21280458260693721`, 0.34100148728268875`, 0.9354302782120729],
              UndirectedEdge[179, 245] -> 
             RGBColor[
              0.21085364957036085`, 0.33895093296494805`, 0.9353191754617867],
              UndirectedEdge[37, 182] -> 
             RGBColor[
              0.26307956528763465`, 0.3938436816981118, 0.9382933641005669], 
             UndirectedEdge[12, 206] -> 
             RGBColor[
              0.33583694364464667`, 0.4592083134506097, 0.9428435069438263], 
             UndirectedEdge[18, 218] -> 
             RGBColor[
              0.776406098847213, 0.8201699347730458, 0.6937389035902746], 
             UndirectedEdge[92, 119] -> 
             RGBColor[
              0.22208012665594387`, 0.3507506721816547, 0.9359585067237262], 
             UndirectedEdge[215, 400] -> 
             RGBColor[
              0.7834338026649409, 0.37076431584912545`, 0.43631998067439115`],
              UndirectedEdge[71, 292] -> 
             RGBColor[
              0.8695625482177284, 0.42619442228126747`, 0.42292170974900056`],
              UndirectedEdge[158, 346] -> 
             RGBColor[
              0.19728326833036003`, 0.3246876018698416, 0.9345463623257486], 
             UndirectedEdge[92, 151] -> 
             RGBColor[
              0.20599136961110498`, 0.33384036844141496`, 0.9350422758112056],
              UndirectedEdge[104, 170] -> 
             RGBColor[
              0.22977658578143667`, 0.35884013870624076`, 0.936396808685032], 
             UndirectedEdge[82, 316] -> 
             RGBColor[
              0.7359499332008539, 0.7936489483339444, 0.9743162695644639], 
             UndirectedEdge[287, 353] -> 
             RGBColor[
              0.8759659333711045, 0.41874857297271617`, 0.27872834063508234`],
              UndirectedEdge[368, 372] -> 
             RGBColor[
              0.1818899475322301, 0.30850824571809776`, 0.9336697354786725], 
             UndirectedEdge[9, 203] -> 
             RGBColor[
              0.4981842108201723, 0.5989222290765547, 0.9551740040370065], 
             UndirectedEdge[17, 384] -> 
             RGBColor[
              0.8629693717290111, 0.400547840174431, 0.20455442187161196`], 
             UndirectedEdge[82, 310] -> 
             RGBColor[
              0.804263995214133, 0.4072991308684552, 0.44091357643715234`], 
             UndirectedEdge[129, 287] -> 
             RGBColor[
              0.8186637745742122, 0.14446352666137094`, 0.16550575765097125`],
              UndirectedEdge[81, 363] -> 
             RGBColor[
              0.3018408929173706, 0.42850250201273, 0.940723448587576], 
             UndirectedEdge[64, 356] -> 
             RGBColor[
              0.9689844051155808, 0.9726683265613763, 0.7058319664887789], 
             UndirectedEdge[245, 352] -> 
             RGBColor[
              0.1906398234149592, 0.3177049200450192, 0.9341680279659126], 
             UndirectedEdge[87, 232] -> 
             RGBColor[
              0.18860427170948546`, 0.315565426141134, 0.9340521063076146], 
             UndirectedEdge[88, 255] -> 
             RGBColor[
              0.40229233650521606`, 0.5228671349052352, 0.9468546898423349], 
             UndirectedEdge[154, 392] -> 
             RGBColor[
              0.19471742420704347`, 0.3219907370123223, 0.934400241298752], 
             UndirectedEdge[22, 45] -> 
             RGBColor[
              0.24087710963769857`, 0.3705074930930349, 0.9370289670968927], 
             UndirectedEdge[116, 141] -> 
             RGBColor[
              0.29789401265983945`, 0.4260884769462017, 0.9404351748499746], 
             UndirectedEdge[97, 224] -> 
             RGBColor[
              0.3981861519254275, 0.5171684195208632, 0.946960633454442], 
             UndirectedEdge[66, 151] -> 
             RGBColor[
              0.20186975982558952`, 0.3295082952316844, 0.9348075562312959], 
             UndirectedEdge[165, 221] -> 
             RGBColor[
              0.29772616502322835`, 0.42460426174906063`, 0.9404735010185594],
              UndirectedEdge[101, 332] -> 
             RGBColor[
              0.8419174702104941, 0.3232016211562354, 0.18777352285356763`], 
             UndirectedEdge[58, 396] -> 
             RGBColor[
              0.18880077082680655`, 0.315771959172202, 0.9340632966416518], 
             UndirectedEdge[35, 387] -> 
             RGBColor[
              0.1878209095169145, 0.3147420628087102, 0.9340074949896282], 
             UndirectedEdge[198, 266] -> 
             RGBColor[0.74350964112616, 0.79962588641691, 0.9750508465456946],
              UndirectedEdge[188, 264] -> 
             RGBColor[
              0.26789407428573686`, 0.39890403591261847`, 0.9385675432655809],
              UndirectedEdge[119, 151] -> 
             RGBColor[
              0.22370106658388367`, 0.35245438281944674`, 0.9360508168546565],
              UndirectedEdge[247, 400] -> 
             RGBColor[
              0.8189309026952224, 0.14651679045574345`, 0.16576155984132857`],
              UndirectedEdge[305, 361] -> 
             RGBColor[
              0.353816749645949, 0.47989197268582956`, 0.9438020454927423], 
             UndirectedEdge[138, 210] -> 
             RGBColor[
              0.2672929528119248, 0.3982722191303392, 0.9385333102869269], 
             UndirectedEdge[197, 231] -> 
             RGBColor[
              0.19125913163260555`, 0.3183558522481745, 0.9342032966527232], 
             UndirectedEdge[225, 261] -> 
             RGBColor[
              0.19884280647751676`, 0.32632677534293286`, 0.9346351757160992],
              UndirectedEdge[83, 286] -> 
             RGBColor[
              0.6361141683386347, 0.7078159235332517, 0.9547721155282454], 
             UndirectedEdge[19, 238] -> 
             RGBColor[
              0.20019752611767563`, 0.32775067157892607`, 0.9347123249954781],
              UndirectedEdge[62, 117] -> 
             RGBColor[
              0.7751677288121797, 0.821679420316278, 0.8719418433976884], 
             UndirectedEdge[65, 167] -> 
             RGBColor[
              0.30615029923372655`, 0.43284997763222943`, 0.940975526215034], 
             UndirectedEdge[268, 371] -> 
             RGBColor[
              0.1838466718007321, 0.3105648869877775, 0.9337811680310495], 
             UndirectedEdge[172, 192] -> 
             RGBColor[
              0.31894488906729196`, 0.44600858518137365`, 0.9417147525123752],
              UndirectedEdge[52, 353] -> 
             RGBColor[
              0.9911272301605415, 0.9888543711683995, 0.6698997566881519], 
             UndirectedEdge[126, 298] -> 
             RGBColor[
              0.194012535572622, 0.32124985436502457`, 0.9343600989338109], 
             UndirectedEdge[146, 306] -> 
             RGBColor[
              0.2107146293415335, 0.33880481389005895`, 0.9353112584654169], 
             UndirectedEdge[21, 132] -> 
             RGBColor[
              0.1947709663990963, 0.3220470132509409, 0.9344032904473808], 
             UndirectedEdge[89, 162] -> 
             RGBColor[
              0.2137613905296329, 0.342007153074568, 0.9354847670077999], 
             UndirectedEdge[9, 18] -> 
             RGBColor[
              0.8394473584119997, 0.8706756474406323, 0.6991625748728455], 
             UndirectedEdge[255, 360] -> 
             RGBColor[
              0.5184721491114823, 0.6174970812936685, 0.956042445038614], 
             UndirectedEdge[124, 152] -> 
             RGBColor[
              0.2137312689052459, 0.34197549333751603`, 0.935483051625852], 
             UndirectedEdge[88, 389] -> 
             RGBColor[
              0.7117595806289345, 0.7674543626326005, 0.720767374949669], 
             UndirectedEdge[12, 167] -> 
             RGBColor[
              0.2392959832955554, 0.36884562905824225`, 0.9369389242907744], 
             UndirectedEdge[32, 303] -> 
             RGBColor[
              0.8456559302937136, 0.31468700621706225`, 0.18989485762449604`],
              UndirectedEdge[49, 261] -> 
             RGBColor[
              0.1864507904031121, 0.31330198074953464`, 0.9339294687330069], 
             UndirectedEdge[283, 360] -> 
             RGBColor[
              0.7973390261209754, 0.7521357532053826, 0.6155512086405578], 
             UndirectedEdge[282, 305] -> 
             RGBColor[
              0.30654149170312617`, 0.4389445203793095, 0.9407897078604948], 
             UndirectedEdge[32, 385] -> 
             RGBColor[
              0.8791517721101495, 0.4410953758327831, 0.323415399566809], 
             UndirectedEdge[167, 216] -> 
             RGBColor[
              0.22581143984224178`, 0.35467251891937396`, 0.9361709994897025],
              UndirectedEdge[252, 318] -> 
             RGBColor[
              0.20969889594004104`, 0.3377372136838731, 0.9352534139508448], 
             UndirectedEdge[2, 217] -> 
             RGBColor[
              0.20503618363244414`, 0.3328364074155535, 0.9349878793827919], 
             UndirectedEdge[305, 329] -> 
             RGBColor[
              0.28019918973537505`, 0.41183749243956935`, 0.9392683013866509],
              UndirectedEdge[87, 373] -> 
             RGBColor[
              0.19241687464340246`, 0.3195727135576686, 0.9342692284044607], 
             UndirectedEdge[20, 241] -> 
             RGBColor[
              0.33276855688740864`, 0.46007563309772936`, 0.9425189244607857],
              UndirectedEdge[59, 210] -> 
             RGBColor[
              0.23097654198013617`, 0.36010136875269116`, 0.9364651444153718],
              UndirectedEdge[290, 304] -> 
             RGBColor[
              0.2699001201696922, 0.4010125173273108, 0.9386817846109934], 
             UndirectedEdge[115, 312] -> 
             RGBColor[
              0.7514622050621471, 0.7517529361696669, 0.6201411074573389], 
             UndirectedEdge[214, 389] -> 
             RGBColor[
              0.9360223295752915, 0.7653959046667461, 0.35678534949539953`], 
             UndirectedEdge[144, 276] -> 
             RGBColor[
              0.48015124453344243`, 0.5868307576532874, 0.952775625742377], 
             UndirectedEdge[196, 286] -> 
             RGBColor[
              0.5826840049020053, 0.6656063435828412, 0.963342437992916], 
             UndirectedEdge[124, 181] -> 
             RGBColor[
              0.209370470104526, 0.33739201730734614`, 0.9352347105853747], 
             UndirectedEdge[216, 341] -> 
             RGBColor[
              0.2325799518711988, 0.3617866542102568, 0.9365564562366354], 
             UndirectedEdge[294, 340] -> 
             RGBColor[
              0.24056246391472638`, 0.3701767804885, 0.937011048488446], 
             UndirectedEdge[104, 235] -> 
             RGBColor[
              0.20864915250350596`, 0.3366338667744967, 0.9351936326150905], 
             UndirectedEdge[125, 318] -> 
             RGBColor[
              0.20302734583193666`, 0.33072499151954715`, 0.9348734790418622],
              UndirectedEdge[109, 232] -> 
             RGBColor[
              0.18655512715268852`, 0.3134116452886715, 0.9339354105565427], 
             UndirectedEdge[182, 388] -> 
             RGBColor[
              0.2563045573313864, 0.38672271877578024`, 0.9379075374201846], 
             UndirectedEdge[97, 382] -> 
             RGBColor[
              0.3103603612224796, 0.44230450028690405`, 0.9410311290958356], 
             UndirectedEdge[140, 147] -> 
             RGBColor[
              0.32678087214865287`, 0.45177394646584723`, 0.9422514665551494],
              UndirectedEdge[59, 300] -> 
             RGBColor[
              0.20621668709807878`, 0.3340771914061782, 0.9350551073087614], 
             UndirectedEdge[205, 373] -> 
             RGBColor[
              0.19156946915989134`, 0.31868203666588757`, 0.9342209699157987],
              UndirectedEdge[215, 259] -> 
             RGBColor[
              0.8007477962042493, 0.8448792898490222, 0.9806129038326282], 
             UndirectedEdge[136, 300] -> 
             RGBColor[
              0.18939860406094253`, 0.3164003198060953, 0.9340973423599207], 
             UndirectedEdge[152, 245] -> 
             RGBColor[
              0.19786899137363773`, 0.3253032339253123, 0.9345797183865636], 
             UndirectedEdge[44, 128] -> 
             RGBColor[
              0.26610768174908467`, 0.39702642409276845`, 0.9384658108533496],
              UndirectedEdge[241, 392] -> 
             RGBColor[
              0.24198676846575243`, 0.37167381487775275`, 0.9370921605255572],
              UndirectedEdge[240, 342] -> 
             RGBColor[
              0.18286346184170274`, 0.30953147098172573`, 0.9337251756784115],
              UndirectedEdge[123, 214] -> 
             RGBColor[
              0.8550790024478794, 0.40285432407734784`, 0.1995346414730431], 
             UndirectedEdge[125, 274] -> 
             RGBColor[
              0.19786901158433057`, 0.32530325516803194`, 0.9345797195375327],
              UndirectedEdge[298, 373] -> 
             RGBColor[
              0.20172543232639267`, 0.32935659787913657`, 0.93479933699373], 
             UndirectedEdge[119, 350] -> 
             RGBColor[
              0.2941675459212899, 0.42283940615857285`, 0.9401985109723265], 
             UndirectedEdge[22, 179] -> 
             RGBColor[
              0.2344230766191157, 0.3637238951811761, 0.9366614194643705], 
             UndirectedEdge[1, 183] -> 
             RGBColor[
              0.18524860197516257`, 0.312038404488611, 0.9338610058805135], 
             UndirectedEdge[112, 260] -> 
             RGBColor[
              0.18468581634927816`, 0.3114468811131368, 0.9338289560716861], 
             UndirectedEdge[183, 270] -> 
             RGBColor[
              0.198314467229445, 0.32577145729456636`, 0.9346050875775294], 
             UndirectedEdge[152, 181] -> 
             RGBColor[
              0.1964830766390266, 0.32384654966716653`, 0.9345007925927047], 
             UndirectedEdge[169, 276] -> 
             RGBColor[
              0.41815198956691846`, 0.5364969694368562, 0.947894817280658], 
             UndirectedEdge[349, 355] -> 
             RGBColor[
              0.20327760071832918`, 0.33098802527222193`, 0.9348877306874234],
              UndirectedEdge[171, 240] -> 
             RGBColor[
              0.18369308464468964`, 0.3104034571487888, 0.9337724214697247], 
             UndirectedEdge[114, 132] -> 
             RGBColor[
              0.1897759122485969, 0.31679689463404087`, 0.9341188295030303], 
             UndirectedEdge[17, 222] -> 
             RGBColor[
              0.8688036227970698, 0.46343086091223773`, 0.43864154601533567`],
              UndirectedEdge[46, 259] -> 
             RGBColor[
              0.850480547970673, 0.8837308935118651, 0.9855697997497163], 
             UndirectedEdge[13, 79] -> 
             RGBColor[
              0.20620705634176517`, 0.33406706887066745`, 0.9350545588514367],
              UndirectedEdge[146, 311] -> 
             RGBColor[
              0.20086274150294195`, 0.3284498551259324, 0.9347502080275711], 
             UndirectedEdge[44, 275] -> 
             RGBColor[
              0.21122882729611786`, 0.33934526854236047`, 0.9353405412782427],
              UndirectedEdge[193, 195] -> 
             RGBColor[
              0.6312732042379722, 0.7079049527832757, 0.9663404032043308], 
             UndirectedEdge[86, 297] -> 
             RGBColor[
              0.28232965171394053`, 0.4140767430581329, 0.9393896280445941], 
             UndirectedEdge[197, 392] -> 
             RGBColor[
              0.19718685275102665`, 0.3245862629828614, 0.9345408716011396], 
             UndirectedEdge[217, 392] -> 
             RGBColor[
              0.20565454435776198`, 0.333486343744197, 0.935023094111316], 
             UndirectedEdge[101, 193] -> 
             RGBColor[
              0.8486252089812196, 0.5684493493271408, 0.4610135933935957], 
             UndirectedEdge[216, 340] -> 
             RGBColor[
              0.2436041993290528, 0.3733738372661213, 0.9371842708204476], 
             UndirectedEdge[125, 190] -> 
             RGBColor[
              0.20237543357367466`, 0.3300397904024893, 0.934836353603172], 
             UndirectedEdge[99, 276] -> 
             RGBColor[
              0.6406056746670367, 0.7137792263922267, 0.9679520038982681], 
             UndirectedEdge[27, 63] -> 
             RGBColor[
              0.1971785692903057, 0.32457755654044196`, 0.9345403998703059], 
             UndirectedEdge[184, 226] -> 
             RGBColor[
              0.20272879549405032`, 0.3304111961852439, 0.9348564770417853], 
             UndirectedEdge[107, 211] -> 
             RGBColor[
              0.2277850924450354, 0.3567469529417126, 0.9362833960856742], 
             UndirectedEdge[216, 294] -> 
             RGBColor[
              0.21277466253925434`, 0.3409700393945122, 0.9354285743084811], 
             UndirectedEdge[68, 284] -> 
             RGBColor[
              0.7807346086845934, 0.8286481739482061, 0.9787765120052747], 
             UndirectedEdge[89, 359] -> 
             RGBColor[
              0.2789577626844565, 0.40896611709023306`, 0.9392549632713296], 
             UndirectedEdge[23, 267] -> 
             RGBColor[
              0.20474185831720654`, 0.33252705284793593`, 0.9349711179915043],
              UndirectedEdge[140, 242] -> 
             RGBColor[
              0.3733726074427579, 0.4978183191391804, 0.9450119502791875], 
             UndirectedEdge[64, 214] -> 
             RGBColor[
              0.9357533158900353, 0.7648205115954387, 0.32750487001527717`], 
             UndirectedEdge[296, 367] -> 
             RGBColor[
              0.18258473603098674`, 0.3092385124824261, 0.9337093026558292], 
             UndirectedEdge[275, 346] -> 
             RGBColor[
              0.1987852081376144, 0.3262662358357499, 0.9346318955758508], 
             UndirectedEdge[301, 305] -> 
             RGBColor[
              0.27396377293596785`, 0.4052836740351331, 0.9389132036243971], 
             UndirectedEdge[81, 119] -> 
             RGBColor[
              0.2344729010553813, 0.363776263822743, 0.9366642568923073], 
             UndirectedEdge[327, 355] -> 
             RGBColor[
              0.19695189529636073`, 0.3243393078008444, 0.9345274911216848], 
             UndirectedEdge[317, 344] -> 
             RGBColor[
              0.19003331843460333`, 0.31706744485602845`, 0.9341334884045249],
              UndirectedEdge[184, 190] -> 
             RGBColor[
              0.21285282401079259`, 0.34105219205682236`, 0.9354330254886557],
              UndirectedEdge[10, 303] -> 
             RGBColor[
              0.8599547518024352, 0.42459401411663544`, 0.20358742524945703`],
              UndirectedEdge[149, 268] -> 
             RGBColor[
              0.19899317290676588`, 0.326484819993856, 0.9346437388617977], 
             UndirectedEdge[38, 267] -> 
             RGBColor[
              0.22814489442186137`, 0.3571251276321197, 0.9363038862759752], 
             UndirectedEdge[253, 366] -> 
             RGBColor[
              0.8812282840866474, 0.45912286163357663`, 0.28521534724776915`],
              UndirectedEdge[165, 355] -> 
             RGBColor[
              0.2168405199897158, 0.34524351336519876`, 0.9356601188753879], 
             UndirectedEdge[339, 340] -> 
             RGBColor[
              0.326674769743479, 0.4539173667672604, 0.9421628597566036], 
             UndirectedEdge[185, 318] -> 
             RGBColor[
              0.20300306708120197`, 0.33069947301316327`, 0.9348720964029251],
              UndirectedEdge[36, 70] -> 
             RGBColor[
              0.22130912604082534`, 0.3499403016509027, 0.9359145993792883], 
             UndirectedEdge[69, 131] -> 
             RGBColor[
              0.693464422361174, 0.75939366397809, 0.9708100489116116], 
             UndirectedEdge[283, 312] -> 
             RGBColor[
              0.7398695405352704, 0.7057918843470511, 0.6108133774642039], 
             UndirectedEdge[75, 330] -> 
             RGBColor[
              0.18530504232011252`, 0.31209772686967785`, 0.9338642200746624],
              UndirectedEdge[169, 222] -> 
             RGBColor[
              0.7041731063901011, 0.7666519834125803, 0.9590482629072343], 
             UndirectedEdge[90, 246] -> 
             RGBColor[
              0.21613530957472, 0.3445022925061154, 0.9356199581855191], 
             UndirectedEdge[62, 362] -> 
             RGBColor[
              0.8915373797700097, 0.913872404880224, 0.882662516799504], 
             UndirectedEdge[158, 374] -> 
             RGBColor[
              0.1873884527454699, 0.3142875233225789, 0.9339828672162569], 
             UndirectedEdge[82, 172] -> 
             RGBColor[
              0.5696909718954926, 0.6577404259092337, 0.9610497684809419], 
             UndirectedEdge[306, 346] -> 
             RGBColor[
              0.21286307171561503`, 0.3410629630443328, 0.9354336090802852], 
             UndirectedEdge[53, 188] -> 
             RGBColor[
              0.33920701496392514`, 0.465180569896386, 0.9429464497347737], 
             UndirectedEdge[84, 190] -> 
             RGBColor[
              0.21321988075352158`, 0.3414379919661722, 0.9354539288271424], 
             UndirectedEdge[78, 96] -> 
             RGBColor[
              0.2160474978393337, 0.3444099968046388, 0.9356149574370947], 
             UndirectedEdge[46, 199] -> 
             RGBColor[
              0.8971361136435547, 0.9188102209856679, 0.9087966349847089], 
             UndirectedEdge[159, 265] -> 
             RGBColor[
              0.19056897353088317`, 0.3176304523247132, 0.9341639931698273], 
             UndirectedEdge[332, 356] -> 
             RGBColor[
              0.860331132425466, 0.41150389739793797`, 0.4355673990056604], 
             UndirectedEdge[199, 222] -> 
             RGBColor[
              0.9699116219534045, 0.9763258350817114, 0.9020107810264453], 
             UndirectedEdge[114, 300] -> 
             RGBColor[
              0.19141939910096473`, 0.3185243035189643, 0.9342124236479517], 
             UndirectedEdge[139, 213] -> 
             RGBColor[
              0.3161784578429658, 0.4481129729732145, 0.941373691457378], 
             UndirectedEdge[106, 369] -> 
             RGBColor[
              0.18346224485360668`, 0.3101608298922725, 0.9337592754851194], 
             UndirectedEdge[109, 114] -> 
             RGBColor[
              0.18471405231964982`, 0.3114765589082613, 0.9338305640684275], 
             UndirectedEdge[58, 245] -> 
             RGBColor[
              0.1940488178607217, 0.32128798935024727`, 0.9343621651564433], 
             UndirectedEdge[151, 317] -> 
             RGBColor[
              0.1980582216182819, 0.3255021269103238, 0.9345904947690551], 
             UndirectedEdge[99, 218] -> 
             RGBColor[
              0.7312212189545854, 0.7893616865114603, 0.9745283770409688], 
             UndirectedEdge[55, 57] -> 
             RGBColor[
              0.5760181454967422, 0.6613528823456771, 0.9622434817439033], 
             UndirectedEdge[247, 287] -> 
             RGBColor[
              0.8173321632588791, 0.13422817857592148`, 0.1642306051515684], 
             UndirectedEdge[44, 66] -> 
             RGBColor[
              0.21222031867993352`, 0.3403873888509353, 0.9353970052457711], 
             UndirectedEdge[116, 290] -> 
             RGBColor[
              0.24877546734729164`, 0.3788091678306199, 0.9374787668838809], 
             UndirectedEdge[278, 367] -> 
             RGBColor[
              0.18709347932173553`, 0.31397748755183885`, 0.9339660689161493],
              UndirectedEdge[102, 297] -> 
             RGBColor[
              0.32279739953618347`, 0.45288594084814915`, 0.9418305958510031],
              UndirectedEdge[104, 187] -> 
             RGBColor[
              0.2201981756238625, 0.34877262232435, 0.935851332396546], 
             UndirectedEdge[136, 371] -> 
             RGBColor[
              0.1813347042579621, 0.3079246498323852, 0.9336381151956117], 
             UndirectedEdge[80, 302] -> 
             RGBColor[
              0.1989040089899044, 0.3263911030639157, 0.9346386611086387], 
             UndirectedEdge[176, 373] -> 
             RGBColor[
              0.192094835712424, 0.3192342302227627, 0.9342508887637553], 
             UndirectedEdge[112, 219] -> 
             RGBColor[
              0.17968380010062157`, 0.30618944488965105`, 0.933544098646145], 
             UndirectedEdge[33, 179] -> 
             RGBColor[
              0.23670129905445042`, 0.3661184514083582, 0.9367911608617348], 
             UndirectedEdge[123, 334] -> 
             RGBColor[
              0.8821757375846465, 0.51430578536771, 0.2259508375177215], 
             UndirectedEdge[94, 307] -> 
             RGBColor[
              0.17906784709075121`, 0.30554203922260087`, 0.9335090210334537],
              UndirectedEdge[73, 89] -> 
             RGBColor[
              0.21536881746289013`, 0.3436966606981754, 0.9355763075936738], 
             UndirectedEdge[267, 311] -> 
             RGBColor[
              0.20008010519765723`, 0.3276272547470704, 0.9347056380477918], 
             UndirectedEdge[52, 391] -> 
             RGBColor[
              0.8764876955371848, 0.43426207855576004`, 0.3886899047932819], 
             UndirectedEdge[105, 271] -> 
             RGBColor[
              0.8751025987519235, 0.43256704456911477`, 0.4089395132180147], 
             UndirectedEdge[187, 377] -> 
             RGBColor[
              0.2355206370031677, 0.36487750073416236`, 0.9367239239045473], 
             UndirectedEdge[58, 124] -> 
             RGBColor[
              0.20991109539232988`, 0.337960248762451, 0.9352654983957317], 
             UndirectedEdge[11, 54] -> 
             RGBColor[
              0.9107233154962703, 0.8671374351819781, 0.6324945514745149], 
             UndirectedEdge[115, 283] -> 
             RGBColor[
              0.9435152073287729, 0.813763650039597, 0.2734092138294835], 
             UndirectedEdge[292, 362] -> 
             RGBColor[
              0.810084891703258, 0.3795078663592535, 0.437475886871706], 
             UndirectedEdge[15, 154] -> 
             RGBColor[
              0.18425132424679044`, 0.31099020236503183`, 0.933804212389223], 
             UndirectedEdge[158, 311] -> 
             RGBColor[
              0.19686826327665763`, 0.3242514052455602, 0.9345227284018851], 
             UndirectedEdge[123, 253] -> 
             RGBColor[
              0.8371693407082226, 0.2867054171581618, 0.18322670867994717`], 
             UndirectedEdge[236, 376] -> 
             RGBColor[
              0.397907468442853, 0.5154535439144465, 0.9470741986312354], 
             UndirectedEdge[206, 386] -> 
             RGBColor[
              0.3854076478953393, 0.5082424662804851, 0.9457788124146576], 
             UndirectedEdge[74, 338] -> 
             RGBColor[
              0.22933498443170014`, 0.35837598768852497`, 0.9363716601414551],
              UndirectedEdge[293, 394] -> 
             RGBColor[
              0.3358774325095808, 0.4653418831743506, 0.9426227908881267], 
             UndirectedEdge[41, 381] -> 
             RGBColor[
              0.19207190760239157`, 0.31921013132539244`, 0.934249583041808], 
             UndirectedEdge[59, 328] -> 
             RGBColor[
              0.22381201159438807`, 0.3525709930598068, 0.9360571350088763], 
             UndirectedEdge[123, 196] -> 
             RGBColor[
              0.8434800761859853, 0.5146723115221958, 0.4543057015240267], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.9124649507944522, 0.7523588106461282, 0.5992692091287142], 
             UndirectedEdge[23, 38] -> 
             RGBColor[
              0.23532272116707456`, 0.36466947864183974`, 0.936712652890472], 
             UndirectedEdge[61, 282] -> 
             RGBColor[
              0.2661448795948803, 0.3964851197604022, 0.9384891805623623], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.2249471629490288, 0.3537641091062871, 0.9361217801992172], 
             UndirectedEdge[3, 232] -> 
             RGBColor[
              0.21328768495463646`, 0.3415092584805786, 0.9354577901760884], 
             UndirectedEdge[110, 362] -> 
             RGBColor[
              0.8221167873663267, 0.8612297040031928, 0.982833840996466], 
             UndirectedEdge[125, 252] -> 
             RGBColor[
              0.19926974690677848`, 0.32677551680367367`, 0.934659489341944], 
             UndirectedEdge[49, 327] -> 
             RGBColor[
              0.18473066760764006`, 0.3114940226294092, 0.9338315102844983], 
             UndirectedEdge[89, 291] -> 
             RGBColor[
              0.2138432095506144, 0.34209315005324514`, 0.9354894264800044], 
             UndirectedEdge[34, 250] -> 
             RGBColor[
              0.1883288985198916, 0.31527599145920215`, 0.9340364242118455], 
             UndirectedEdge[125, 226] -> 
             RGBColor[
              0.1922514050569324, 0.3193987945309108, 0.9342598051563016], 
             UndirectedEdge[3, 14] -> 
             RGBColor[
              0.28743237026540935`, 0.41667525783150516`, 0.9397814519424676],
              UndirectedEdge[105, 345] -> 
             RGBColor[
              0.9066930101053883, 0.9269728190997042, 0.9383535848392048], 
             UndirectedEdge[88, 336] -> 
             RGBColor[
              0.33259846324686315`, 0.4556650882287947, 0.9426641835505155], 
             UndirectedEdge[162, 357] -> 
             RGBColor[
              0.1906502583880034, 0.3177158878633042, 0.9341686222221902], 
             UndirectedEdge[279, 328] -> 
             RGBColor[
              0.215194282730263, 0.3435132136280431, 0.9355663680988517], 
             UndirectedEdge[312, 359] -> 
             RGBColor[
              0.4367530973615871, 0.5501494570425497, 0.9497594529493274], 
             UndirectedEdge[202, 289] -> 
             RGBColor[
              0.4009029468034172, 0.5210963292936249, 0.9469229296248474], 
             UndirectedEdge[27, 48] -> 
             RGBColor[
              0.20648582903789775`, 0.33436007664951256`, 0.9350704345440743],
              UndirectedEdge[115, 193] -> 
             RGBColor[
              0.8965180032601808, 0.866664933881647, 0.6335702357029284], 
             UndirectedEdge[117, 385] -> 
             RGBColor[
              0.776474593776608, 0.8214741220909348, 0.7960777027150834], 
             UndirectedEdge[179, 352] -> 
             RGBColor[
              0.20659936567779108`, 0.3344794108566792, 0.9350769002877538], 
             UndirectedEdge[8, 365] -> 
             RGBColor[
              0.2808078228071327, 0.4124772043875522, 0.9393029621396956], 
             UndirectedEdge[105, 353] -> 
             RGBColor[
              0.9892810453920724, 0.988090926321853, 0.7004958160747115], 
             UndirectedEdge[231, 392] -> 
             RGBColor[
              0.1971344084334818, 0.32453114067996, 0.9345378849748398], 
             UndirectedEdge[109, 132] -> 
             RGBColor[
              0.1878121680467173, 0.3147328749692917, 0.9340069971758325], 
             UndirectedEdge[23, 158] -> 
             RGBColor[
              0.20153001639620693`, 0.3291512033464258, 0.9347882083455978], 
             UndirectedEdge[105, 350] -> 
             RGBColor[
              0.6669237794423443, 0.7322521297415084, 0.9183362922108259], 
             UndirectedEdge[172, 351] -> 
             RGBColor[
              0.3445890788111915, 0.47288747334073133`, 0.943177889287059], 
             UndirectedEdge[34, 375] -> 
             RGBColor[
              0.19286667153168213`, 0.3200454786060204, 0.9342948436718334], 
             UndirectedEdge[32, 391] -> 
             RGBColor[
              0.8210906486573005, 0.1631175443269919, 0.16782973501369886`], 
             UndirectedEdge[140, 241] -> 
             RGBColor[
              0.343629032390773, 0.46948243111537313`, 0.9432109443563187], 
             UndirectedEdge[89, 336] -> 
             RGBColor[
              0.23351345559029374`, 0.36276782580657996`, 0.9366096178924429],
              UndirectedEdge[74, 118] -> 
             RGBColor[
              0.3029906205258713, 0.4312899550504897, 0.9407311083477143], 
             UndirectedEdge[138, 328] -> 
             RGBColor[
              0.2601284224261766, 0.3907418434374549, 0.9381253008804314], 
             UndirectedEdge[189, 207] -> 
             RGBColor[
              0.2123454769342431, 0.3405189381117063, 0.935404132823199], 
             UndirectedEdge[273, 281] -> 
             RGBColor[
              0.46139853851670076`, 0.5721415288193888, 0.9511515046102453], 
             UndirectedEdge[49, 225] -> 
             RGBColor[
              0.19609003670444464`, 0.3234334397757498, 0.9344784095498806], 
             UndirectedEdge[43, 159] -> 
             RGBColor[
              0.1884193222929882, 0.31537103257792504`, 0.9340415737119533], 
             UndirectedEdge[113, 368] -> 
             RGBColor[
              0.18474082389280244`, 0.3115046975290605, 0.9338320886699134], 
             UndirectedEdge[11, 83] -> 
             RGBColor[0.9120888802991098, 0.9323447493793293, 0.977810506555],
              UndirectedEdge[151, 344] -> 
             RGBColor[
              0.1995874063553662, 0.3271093970249116, 0.9346775795776059], 
             UndirectedEdge[182, 377] -> 
             RGBColor[
              0.2482608696505907, 0.3782682930240088, 0.9374494613063329], 
             UndirectedEdge[198, 203] -> 
             RGBColor[
              0.5694035624452959, 0.6546305646490294, 0.9622535793690412], 
             UndirectedEdge[208, 395] -> 
             RGBColor[
              0.366549438606146, 0.4905837118311563, 0.9446256885343254], 
             UndirectedEdge[305, 339] -> 
             RGBColor[
              0.3400084902177303, 0.4679319523924049, 0.9429221954121405], 
             UndirectedEdge[9, 313] -> 
             RGBColor[
              0.4854882204226317, 0.5856947625868548, 0.9544467086526902], 
             UndirectedEdge[267, 317] -> 
             RGBColor[
              0.1930340826347562, 0.32022143828982824`, 0.9343043774864909], 
             UndirectedEdge[306, 350] -> 
             RGBColor[
              0.2854226113571807, 0.41364792547081863`, 0.9397004998858718], 
             UndirectedEdge[111, 362] -> 
             RGBColor[
              0.8148316917162097, 0.4159938513198287, 0.44202142792485233`], 
             UndirectedEdge[104, 261] -> 
             RGBColor[
              0.20662637490864183`, 0.3345077992707875, 0.9350784384234943], 
             UndirectedEdge[243, 363] -> 
             RGBColor[
              0.302959879941956, 0.42967862832344433`, 0.9407871732432331], 
             UndirectedEdge[154, 369] -> 
             RGBColor[
              0.183389073095449, 0.31008392173509136`, 0.9337551084617403], 
             UndirectedEdge[218, 282] -> 
             RGBColor[
              0.4376499441056336, 0.5505879476107286, 0.9499100761220066], 
             UndirectedEdge[7, 293] -> 
             RGBColor[
              0.28453912176058604`, 0.41590127160719004`, 0.9395336796939777],
              UndirectedEdge[24, 167] -> 
             RGBColor[
              0.24799412206051685`, 0.37798792439406714`, 0.9374342704256958],
              UndirectedEdge[326, 363] -> 
             RGBColor[
              0.3080486907375876, 0.43502729111889293`, 0.9410769734898234], 
             UndirectedEdge[276, 282] -> 
             RGBColor[
              0.3470343998180849, 0.475005487491495, 0.9433337029793059], 
             UndirectedEdge[337, 345] -> 
             RGBColor[
              0.8925314756364031, 0.9165956294995268, 0.9705858474056119], 
             UndirectedEdge[107, 124] -> 
             RGBColor[
              0.22484989821780513`, 0.3536618777068309, 0.9361162411166642], 
             UndirectedEdge[128, 227] -> 
             RGBColor[
              0.28894688934847723`, 0.42103187936912945`, 0.9397664699385552],
              UndirectedEdge[25, 365] -> 
             RGBColor[
              0.33498940880084865`, 0.4643204052534886, 0.9425754453427104], 
             UndirectedEdge[97, 363] -> 
             RGBColor[
              0.3365752811245841, 0.4650105463059218, 0.9427015206110543], 
             UndirectedEdge[13, 373] -> 
             RGBColor[
              0.2056740334145861, 0.3335068279785967, 0.9350242039842707], 
             UndirectedEdge[64, 195] -> 
             RGBColor[
              0.7086017617355334, 0.7643768316855696, 0.6913028233561538], 
             UndirectedEdge[77, 96] -> 
             RGBColor[
              0.20429069166020342`, 0.3320528480858075, 0.9349454247178293], 
             UndirectedEdge[6, 53] -> 
             RGBColor[
              0.6643840547861006, 0.7335496374888852, 0.969847038397682], 
             UndirectedEdge[216, 343] -> 
             RGBColor[
              0.20826813355084325`, 0.33623339169725125`, 0.9351719341494034],
              UndirectedEdge[26, 324] -> 
             RGBColor[
              0.1839722969253371, 0.31069692695883033`, 0.9337883221960501], 
             UndirectedEdge[142, 281] -> 
             RGBColor[
              0.436455413320613, 0.55189157611022, 0.9491878904251312], 
             UndirectedEdge[100, 341] -> 
             RGBColor[
              0.3185278490681524, 0.4448223795517722, 0.9417183858910539], 
             UndirectedEdge[115, 364] -> 
             RGBColor[
              0.9382231077008898, 0.7927822385027005, 0.26915106624734497`], 
             UndirectedEdge[150, 152] -> 
             RGBColor[
              0.21962526952820027`, 0.3481704616934645, 0.9358187062419367], 
             UndirectedEdge[10, 68] -> 
             RGBColor[
              0.8358461850878253, 0.5077093600050204, 0.4534679492170056], 
             UndirectedEdge[190, 288] -> 
             RGBColor[
              0.21294330855938015`, 0.3411472970544397, 0.9354381784498378], 
             UndirectedEdge[23, 146] -> 
             RGBColor[
              0.20552449462249126`, 0.333349653226798, 0.9350156879712836], 
             UndirectedEdge[188, 201] -> 
             RGBColor[
              0.47076164268683474`, 0.5730017553920743, 0.9531670568538995], 
             UndirectedEdge[148, 382] -> 
             RGBColor[
              0.2893244860141426, 0.42019446169141983`, 0.9398331671225094], 
             UndirectedEdge[14, 71] -> 
             RGBColor[
              0.6541765961305002, 0.7223342652348994, 0.9394835143282855], 
             UndirectedEdge[228, 276] -> 
             RGBColor[
              0.3015266164865197, 0.4277543234766833, 0.9407208506945814], 
             UndirectedEdge[56, 174] -> 
             RGBColor[
              0.4681168777823908, 0.5781139671930625, 0.9515372200266019], 
             UndirectedEdge[16, 182] -> 
             RGBColor[
              0.23539065510704868`, 0.36474088152001305`, 0.9367165216278543],
              UndirectedEdge[104, 192] -> 
             RGBColor[
              0.24115781649194606`, 0.3708025337946915, 0.9370449529369735], 
             UndirectedEdge[145, 395] -> 
             RGBColor[
              0.3442769835307749, 0.46717394939172724`, 0.9433573051669275], 
             UndirectedEdge[219, 251] -> 
             RGBColor[
              0.1819264333571092, 0.30854659463338063`, 0.9336718132924233], 
             UndirectedEdge[150, 179] -> 
             RGBColor[
              0.23260992772492337`, 0.36181816073310025`, 0.9365581633171598],
              UndirectedEdge[73, 207] -> 
             RGBColor[
              0.1950145063297256, 0.32230298915935574`, 0.934417159686145], 
             UndirectedEdge[265, 325] -> 
             RGBColor[
              0.2186342581575027, 0.34712884590911136`, 0.9357622696104455], 
             UndirectedEdge[39, 314] -> 
             RGBColor[
              0.19046396107769498`, 0.3175200775782383, 0.9341580128659703], 
             UndirectedEdge[20, 263] -> 
             RGBColor[
              0.3432288815576954, 0.4710700975490908, 0.943114624476095], 
             UndirectedEdge[66, 146] -> 
             RGBColor[
              0.19762825714734855`, 0.3250502069900508, 0.9345660089285108], 
             UndirectedEdge[7, 21] -> 
             RGBColor[
              0.22580819870592864`, 0.3546691122796089, 0.9361708149117844], 
             UndirectedEdge[107, 167] -> 
             RGBColor[
              0.22944380789788385`, 0.3584903680512903, 0.9363778574768644], 
             UndirectedEdge[120, 195] -> 
             RGBColor[
              0.41858299206596217`, 0.5369772819597975, 0.9478927160094046], 
             UndirectedEdge[365, 388] -> 
             RGBColor[
              0.2883992345699991, 0.4204562594736305, 0.9397352818091035], 
             UndirectedEdge[134, 342] -> 
             RGBColor[
              0.18275455563161122`, 0.309417003649867, 0.9337189736308591], 
             UndirectedEdge[227, 311] -> 
             RGBColor[
              0.23829401063491945`, 0.3677924922631779, 0.9368818634300369], 
             UndirectedEdge[78, 377] -> 
             RGBColor[
              0.2375799153602678, 0.3670419328532635, 0.9368411967605548], 
             UndirectedEdge[21, 370] -> 
             RGBColor[
              0.19110729661804693`, 0.31819626402097745`, 0.9341946498732637],
              UndirectedEdge[2, 230] -> 
             RGBColor[
              0.2114753909347174, 0.33960442255956613`, 0.9353545827127028], 
             UndirectedEdge[24, 203] -> 
             RGBColor[
              0.2850956592214299, 0.4168671679331099, 0.9395514255934152], 
             UndirectedEdge[54, 206] -> 
             RGBColor[
              0.6885711015156095, 0.68922695188861, 0.6128856824256679], 
             UndirectedEdge[66, 130] -> 
             RGBColor[
              0.20589531196195676`, 0.3337394057617535, 0.9350368054701912], 
             UndirectedEdge[101, 356] -> 
             RGBColor[
              0.8844436842834248, 0.5968435371658081, 0.458657605896074], 
             UndirectedEdge[222, 383] -> 
             RGBColor[
              0.6547025238599551, 0.723910051109828, 0.9558664767641599], 
             UndirectedEdge[31, 247] -> 
             RGBColor[
              0.8729786261707051, 0.41877199639199914`, 0.4130055274330995], 
             UndirectedEdge[46, 333] -> 
             RGBColor[
              0.8796565038002286, 0.9065288389378603, 0.9721902291244133], 
             UndirectedEdge[287, 385] -> 
             RGBColor[
              0.8763518611868132, 0.41957403354722944`, 0.320734201704575], 
             UndirectedEdge[42, 330] -> 
             RGBColor[
              0.18629301045548374`, 0.31313614402075074`, 0.9339204833984038],
              UndirectedEdge[151, 227] -> 
             RGBColor[
              0.2408020759927813, 0.3704286279748189, 0.937024694041817], 
             UndirectedEdge[36, 382] -> 
             RGBColor[
              0.2838749254794549, 0.4144666280473688, 0.9395228227119613], 
             UndirectedEdge[218, 361] -> 
             RGBColor[
              0.4849252020484565, 0.5915353999172487, 0.952922413754254], 
             UndirectedEdge[196, 334] -> 
             RGBColor[
              0.9021680954325457, 0.8779962725880234, 0.6424622562871629], 
             UndirectedEdge[34, 265] -> 
             RGBColor[
              0.19096709589184307`, 0.31804890416849774`, 0.9341866656493147],
              UndirectedEdge[372, 392] -> 
             RGBColor[
              0.19150446236563495`, 0.31861371040345526`, 0.9342172678750348],
              UndirectedEdge[127, 210] -> 
             RGBColor[
              0.29252473138981117`, 0.4219611356100898, 0.9400738898749681], 
             UndirectedEdge[33, 157] -> 
             RGBColor[
              0.2467253832848012, 0.3766543994981055, 0.9373620176293496], 
             UndirectedEdge[139, 308] -> 
             RGBColor[
              0.25989565930435055`, 0.3904971946383813, 0.9381120453649856], 
             UndirectedEdge[38, 146] -> 
             RGBColor[
              0.2289275307271461, 0.3579477280109817, 0.9363484562557545], 
             UndirectedEdge[55, 68] -> 
             RGBColor[
              0.8126708442680417, 0.8535970039103761, 0.981959617507143], 
             UndirectedEdge[35, 392] -> 
             RGBColor[
              0.19658094676972326`, 0.3239494173798535, 0.934506366151862], 
             UndirectedEdge[51, 126] -> 
             RGBColor[
              0.1918840790772874, 0.31901271163649164`, 0.9342388864851707], 
             UndirectedEdge[130, 243] -> 
             RGBColor[
              0.22352868317149505`, 0.3522731969232867, 0.9360409998743393], 
             UndirectedEdge[12, 203] -> 
             RGBColor[
              0.2763975204564685, 0.40772487259728496`, 0.9390560794584938], 
             UndirectedEdge[182, 395] -> 
             RGBColor[
              0.3402542515552627, 0.4629458030295253, 0.9431282165320207], 
             UndirectedEdge[99, 382] -> 
             RGBColor[
              0.6121310294998102, 0.6891159199256546, 0.9661376246873524], 
             UndirectedEdge[17, 31] -> 
             RGBColor[
              0.879860588532459, 0.47166977479957617`, 0.4195957023627799], 
             UndirectedEdge[77, 78] -> 
             RGBColor[
              0.20870891214169546`, 0.33669667794321373`, 0.9351970358380788],
              UndirectedEdge[243, 344] -> 
             RGBColor[
              0.2114782278514492, 0.3396074043389222, 0.9353547442709138], 
             UndirectedEdge[305, 313] -> 
             RGBColor[
              0.29133850845533754`, 0.4235456226878492, 0.9399026691086074], 
             UndirectedEdge[189, 280] -> 
             RGBColor[
              0.2210513429116578, 0.3496693552377532, 0.9358999190114381], 
             UndirectedEdge[104, 208] -> 
             RGBColor[
              0.25923359532216883`, 0.3898013234158274, 0.9380743418006362], 
             UndirectedEdge[191, 335] -> 
             RGBColor[
              0.19113672012064215`, 0.3182271899877628, 0.9341963254982084], 
             UndirectedEdge[225, 355] -> 
             RGBColor[
              0.2083112643931653, 0.336278724947185, 0.9351743903870672], 
             UndirectedEdge[308, 348] -> 
             RGBColor[
              0.20697593141094872`, 0.33487520531787435`, 0.9350983451491781],
              UndirectedEdge[132, 149] -> 
             RGBColor[
              0.20160011613108555`, 0.32922488261236305`, 0.9347922004217959],
              UndirectedEdge[128, 224] -> 
             RGBColor[
              0.40082474260241224`, 0.5199417456186857, 0.9471108972900512], 
             UndirectedEdge[192, 225] -> 
             RGBColor[
              0.233374248060821, 0.36262150986683694`, 0.9366016902295785], 
             UndirectedEdge[84, 252] -> 
             RGBColor[
              0.2101141940866254, 0.33817371836735655`, 0.9352770645659143], 
             UndirectedEdge[30, 211] -> 
             RGBColor[
              0.21659401962004457`, 0.3449844258476482, 0.9356460810439997], 
             UndirectedEdge[138, 242] -> 
             RGBColor[
              0.31465187583145326`, 0.4451229547456037, 0.9413374842169753], 
             UndirectedEdge[27, 41] -> 
             RGBColor[
              0.1999138771125005, 0.32745253849010136`, 0.9346961716042546], 
             UndirectedEdge[102, 139] -> 
             RGBColor[
              0.3279891561400408, 0.4583428062151842, 0.9421262587090772], 
             UndirectedEdge[203, 329] -> 
             RGBColor[
              0.28617424693522586`, 0.4180008320067203, 0.9396128495680883], 
             UndirectedEdge[195, 312] -> 
             RGBColor[
              0.48621740603993846`, 0.5929929550712956, 0.9529112749587412], 
             UndirectedEdge[51, 87] -> 
             RGBColor[
              0.1940286984190197, 0.3212668425413722, 0.9343610193840024], 
             UndirectedEdge[83, 366] -> 
             RGBColor[
              0.9721424943326117, 0.9755215245830015, 0.7399924007909114], 
             UndirectedEdge[8, 302] -> 
             RGBColor[
              0.22515004974021374`, 0.353977355987588, 0.936133334301831], 
             UndirectedEdge[146, 344] -> 
             RGBColor[
              0.1953459036771252, 0.3226513087832781, 0.9344360322748211], 
             UndirectedEdge[67, 320] -> 
             RGBColor[
              0.1815572411564681, 0.30815855022236927`, 0.9336507883427678], 
             UndirectedEdge[90, 166] -> 
             RGBColor[
              0.23037172884023532`, 0.35946567179528754`, 0.9364307012017953],
              UndirectedEdge[12, 341] -> 
             RGBColor[
              0.2460644953245124, 0.3759597643491251, 0.9373243810377072], 
             UndirectedEdge[3, 13] -> 
             RGBColor[
              0.2247891692476987, 0.3535980477088099, 0.9361127826916571], 
             UndirectedEdge[153, 341] -> 
             RGBColor[
              0.22749742981872606`, 0.3564446012825976, 0.9362670141246647], 
             UndirectedEdge[192, 351] -> 
             RGBColor[
              0.2839106330866923, 0.41566367352388345`, 0.9394824007008676], 
             UndirectedEdge[12, 150] -> 
             RGBColor[
              0.24059607423843102`, 0.37021210706973123`, 0.937012962546659], 
             UndirectedEdge[99, 393] -> 
             RGBColor[
              0.8120689253181035, 0.8537779307522239, 0.9817268285297311], 
             UndirectedEdge[4, 190] -> 
             RGBColor[
              0.20649883851719153`, 0.33437375043709894`, 0.9350711754146743],
              UndirectedEdge[373, 390] -> 
             RGBColor[
              0.20548402624046883`, 0.3333071183914488, 0.9350133833567951], 
             UndirectedEdge[23, 308] -> 
             RGBColor[
              0.21238372481471685`, 0.3405591390591399, 0.9354063109834092], 
             UndirectedEdge[37, 187] -> 
             RGBColor[
              0.2503393326402117, 0.3804528894082654, 0.9375678266987812], 
             UndirectedEdge[17, 292] -> 
             RGBColor[
              0.8249384204875226, 0.19269320471844653`, 0.1715143656637563], 
             UndirectedEdge[309, 385] -> 
             RGBColor[
              0.845892139078253, 0.8769877648670494, 0.8021186290174642], 
             UndirectedEdge[140, 380] -> 
             RGBColor[
              0.5633644182821813, 0.6539330422248467, 0.9599388244578124], 
             UndirectedEdge[119, 354] -> 
             RGBColor[
              0.21794551615801888`, 0.3464049343988889, 0.9357230467724773], 
             UndirectedEdge[36, 305] -> 
             RGBColor[
              0.2718566625317226, 0.40306896740175535`, 0.9387932068040659], 
             UndirectedEdge[91, 351] -> 
             RGBColor[
              0.45106536887988224`, 0.5613307052601594, 0.9510072153286632], 
             UndirectedEdge[130, 275] -> 
             RGBColor[
              0.2049038205781411, 0.33269728545317867`, 0.934980341502663], 
             UndirectedEdge[46, 102] -> 
             RGBColor[
              0.5772856165740025, 0.6623742905041798, 0.9623565848838942], 
             UndirectedEdge[111, 271] -> 
             RGBColor[
              0.8244089740108874, 0.1886236470941021, 0.17100736711980608`], 
             UndirectedEdge[104, 351] -> 
             RGBColor[
              0.26680200623584566`, 0.3976814219540492, 0.9385080897116571], 
             UndirectedEdge[174, 203] -> 
             RGBColor[
              0.3639226125883841, 0.4896332085668736, 0.9444098049633691], 
             UndirectedEdge[294, 313] -> 
             RGBColor[
              0.24717525119128783`, 0.3771272391910956, 0.937387636941104], 
             UndirectedEdge[206, 266] -> 
             RGBColor[
              0.5435550579217713, 0.6394151913659053, 0.9575592073363473], 
             UndirectedEdge[167, 358] -> 
             RGBColor[
              0.25670178916857006`, 0.3871402346226134, 0.9379301591856604], 
             UndirectedEdge[315, 322] -> 
             RGBColor[
              0.18811052101816012`, 0.31504646285894905`, 0.9340239879361825],
              UndirectedEdge[176, 347] -> 
             RGBColor[
              0.18526445779187303`, 0.3120550699572905, 0.9338619088458187], 
             UndirectedEdge[92, 186] -> 
             RGBColor[
              0.20547576839988674`, 0.33329843887741967`, 0.9350129130849905],
              UndirectedEdge[149, 210] -> 
             RGBColor[
              0.22800345786551077`, 0.3569764688437995, 0.9362958316733276], 
             UndirectedEdge[171, 374] -> 
             RGBColor[
              0.18584495673726414`, 0.3126652111546555, 0.9338949674019874], 
             UndirectedEdge[228, 282] -> 
             RGBColor[
              0.26951575842165965`, 0.40002812713340913`, 0.938681147124779], 
             UndirectedEdge[164, 210] -> 
             RGBColor[
              0.23033673863294363`, 0.3594288948689166, 0.9364287085612534], 
             UndirectedEdge[196, 214] -> 
             RGBColor[
              0.8615229927273951, 0.7108190806524803, 0.6028379622201453], 
             UndirectedEdge[204, 307] -> 
             RGBColor[
              0.17948540198595286`, 0.30598091589196724`, 0.9335328001670183],
              UndirectedEdge[127, 255] -> 
             RGBColor[
              0.35677877005900877`, 0.4834455712278943, 0.9439546056344492], 
             UndirectedEdge[68, 334] -> 
             RGBColor[
              0.8909079727489195, 0.8690177564079877, 0.6413882557335685], 
             UndirectedEdge[16, 269] -> 
             RGBColor[
              0.29117851080203017`, 0.41924857896072276`, 0.9400447358569024],
              UndirectedEdge[68, 337] -> 
             RGBColor[
              0.8892917898500812, 0.9140123919924417, 0.970276843283211], 
             UndirectedEdge[23, 374] -> 
             RGBColor[
              0.19777812141168266`, 0.3252077238338092, 0.9345745434766604], 
             UndirectedEdge[22, 116] -> 
             RGBColor[
              0.24102708216235447`, 0.3706651237252555, 0.9370375078103073], 
             UndirectedEdge[192, 322] -> 
             RGBColor[
              0.2266888241245798, 0.3555947054294877, 0.936220965226608], 
             UndirectedEdge[70, 95] -> 
             RGBColor[
              0.22209777558797966`, 0.3507692223282312, 0.9359595118042963], 
             UndirectedEdge[71, 273] -> 
             RGBColor[
              0.7468748729151091, 0.8007044259307632, 0.9459207863964338], 
             UndirectedEdge[135, 215] -> 
             RGBColor[
              0.5207131115569171, 0.6175984363516078, 0.9569638659378303], 
             UndirectedEdge[161, 283] -> 
             RGBColor[
              0.9057344419097366, 0.6568662450460772, 0.2426421685015519], 
             UndirectedEdge[18, 384] -> 
             RGBColor[
              0.9630602947807589, 0.8804179575228263, 0.3471852898585644], 
             UndirectedEdge[71, 303] -> 
             RGBColor[
              0.9318169667814895, 0.7940843861143203, 0.5846862975193713], 
             UndirectedEdge[32, 353] -> 
             RGBColor[
              0.8787658442944408, 0.4402699152582698, 0.2814095384973163], 
             UndirectedEdge[188, 281] -> 
             RGBColor[
              0.3372802138863956, 0.4635116716468679, 0.9428236756739168], 
             UndirectedEdge[54, 198] -> 
             RGBColor[
              0.8885256847199983, 0.8494376469396148, 0.6303773216350153], 
             UndirectedEdge[271, 385] -> 
             RGBColor[
              0.8781410297151262, 0.43332636687449166`, 0.3224475115078644], 
             UndirectedEdge[150, 206] -> 
             RGBColor[
              0.33364753302286965`, 0.45690710407047097`, 0.9427188232478589],
              UndirectedEdge[317, 346] -> 
             RGBColor[
              0.19596516131412245`, 0.3233021878229641, 0.9344712980811385], 
             UndirectedEdge[146, 243] -> 
             RGBColor[
              0.21526162835688684`, 0.343583998151584, 0.9355702033326591], 
             UndirectedEdge[91, 316] -> 
             RGBColor[
              0.6523585861658432, 0.7275841393423603, 0.9665060682236928], 
             UndirectedEdge[196, 386] -> 
             RGBColor[
              0.5930257483480736, 0.6745638419646864, 0.9640014047404548], 
             UndirectedEdge[151, 306] -> 
             RGBColor[
              0.21495613201977448`, 0.3432629021316925, 0.9355528057682019], 
             UndirectedEdge[27, 376] -> 
             RGBColor[
              0.24560585367761548`, 0.37547770289867644`, 0.937298262074416], 
             UndirectedEdge[280, 387] -> 
             RGBColor[
              0.19723551682458454`, 0.32463741200965124`, 0.9345436429481366],
              UndirectedEdge[308, 354] -> 
             RGBColor[
              0.20447448662716458`, 0.33224602824935756`, 0.9349558915692975],
              UndirectedEdge[327, 349] -> 
             RGBColor[
              0.19208902000720862`, 0.3192281175478443, 0.934250557567947], 
             UndirectedEdge[60, 108] -> 
             RGBColor[
              0.5066936953729514, 0.6051947855450721, 0.9560957540450186], 
             UndirectedEdge[353, 391] -> 
             RGBColor[
              0.8779094088390327, 0.4336869770555928, 0.280589414938012], 
             UndirectedEdge[140, 195] -> 
             RGBColor[
              0.4154824656065883, 0.5342917617776789, 0.9476951532051012], 
             UndirectedEdge[17, 18] -> 
             RGBColor[
              0.8826197426994277, 0.4712313788077837, 0.2590653315299285], 
             UndirectedEdge[87, 205] -> 
             RGBColor[
              0.18600119174785296`, 0.31282942405665615`, 0.9339038647547113],
              UndirectedEdge[221, 256] -> 
             RGBColor[
              0.6811078585940378, 0.7429531062730206, 0.8609992027595657], 
             UndirectedEdge[194, 316] -> 
             RGBColor[
              0.5837905900380065, 0.6719175511327584, 0.9611081443956637], 
             UndirectedEdge[16, 37] -> 
             RGBColor[
              0.25664259349321183`, 0.38707801621458926`, 0.9379267880795208],
              UndirectedEdge[252, 288] -> 
             RGBColor[
              0.20983762189248398`, 0.33788302345562404`, 0.9352613141886098],
              UndirectedEdge[60, 353] -> 
             RGBColor[
              0.8501417981315751, 0.8795216745705272, 0.7395911022292926], 
             UndirectedEdge[206, 286] -> 
             RGBColor[
              0.375065904449271, 0.49928496789863985`, 0.9451198456671187], 
             UndirectedEdge[220, 396] -> 
             RGBColor[
              0.18205118127193512`, 0.30867771260133725`, 0.9336789175016247],
              UndirectedEdge[133, 320] -> 
             RGBColor[
              0.18355649439985816`, 0.3102598921411492, 0.9337646428573487], 
             UndirectedEdge[28, 231] -> 
             RGBColor[
              0.19140134234262995`, 0.31850532472108994`, 0.934211395342277], 
             UndirectedEdge[239, 269] -> 
             RGBColor[
              0.4302703250067166, 0.5456389418366184, 0.9490411897361934], 
             UndirectedEdge[212, 239] -> 
             RGBColor[
              0.542458414688152, 0.6394312043737607, 0.9571234599763494], 
             UndirectedEdge[77, 182] -> 
             RGBColor[
              0.21938986643201835`, 0.34792303811395897`, 0.9358053003838569],
              UndirectedEdge[280, 336] -> 
             RGBColor[
              0.22186501043454393`, 0.3505245713938071, 0.9359462561731533], 
             UndirectedEdge[199, 400] -> 
             RGBColor[
              0.8776553963318527, 0.44386520988537914`, 0.3913209974630636], 
             UndirectedEdge[73, 336] -> 
             RGBColor[
              0.2166564041388005, 0.3450499959322676, 0.9356496337500533], 
             UndirectedEdge[305, 340] -> 
             RGBColor[
              0.2847257211787761, 0.4165951639852536, 0.9395260806559493], 
             UndirectedEdge[259, 350] -> 
             RGBColor[
              0.6219849446227963, 0.6978827145935297, 0.9666587839790601], 
             UndirectedEdge[247, 393] -> 
             RGBColor[
              0.7855497496539053, 0.35042887609417595`, 0.43379895708891325`],
              UndirectedEdge[30, 216] -> 
             RGBColor[
              0.208257693184232, 0.33622241820998533`, 0.93517133958597], 
             UndirectedEdge[291, 387] -> 
             RGBColor[
              0.1905013026165654, 0.3175593259031815, 0.9341601394113672], 
             UndirectedEdge[45, 338] -> 
             RGBColor[
              0.2249286875668965, 0.3537446903082591, 0.9361207280535366], 
             UndirectedEdge[219, 248] -> 
             RGBColor[
              0.1809198934930053, 0.30748865741789405`, 0.933614492336205], 
             UndirectedEdge[158, 354] -> 
             RGBColor[
              0.1936207782086547, 0.3208380925366434, 0.9343377889314861], 
             UndirectedEdge[191, 327] -> 
             RGBColor[
              0.1848862258869851, 0.3116575242439654, 0.9338403690983792], 
             UndirectedEdge[165, 192] -> 
             RGBColor[
              0.24190350365737148`, 0.3715862982848506, 0.9370874187178992], 
             UndirectedEdge[143, 354] -> 
             RGBColor[
              0.1975023339396083, 0.32491785371472337`, 0.9345588377881168], 
             UndirectedEdge[115, 161] -> 
             RGBColor[
              0.9173271064366133, 0.7028272968686928, 0.25196989849468676`], 
             UndirectedEdge[296, 330] -> 
             RGBColor[
              0.18388840354746627`, 0.31060874969954066`, 0.9337835445922895],
              UndirectedEdge[45, 262] -> 
             RGBColor[
              0.30202723660803465`, 0.4296407358190505, 0.9406995556283282], 
             UndirectedEdge[37, 208] -> 
             RGBColor[
              0.289374752338518, 0.42148159049974276`, 0.9397908361028714], 
             UndirectedEdge[306, 348] -> 
             RGBColor[
              0.21170202637769384`, 0.33984263077965143`, 0.9353674892659032],
              UndirectedEdge[189, 263] -> 
             RGBColor[
              0.2675028819703037, 0.39849286798607286`, 0.9385452654419342], 
             UndirectedEdge[2, 50] -> 
             RGBColor[
              0.216476564027812, 0.3448609725730971, 0.935639392121782], 
             UndirectedEdge[241, 331] -> 
             RGBColor[
              0.26094013118712034`, 0.3915950008105146, 0.9381715264935517], 
             UndirectedEdge[135, 213] -> 
             RGBColor[
              0.33038430669065766`, 0.46058401368253077`, 0.9422727737683254],
              UndirectedEdge[49, 349] -> 
             RGBColor[
              0.19105637302960854`, 0.3181427401007867, 0.9341917498502368], 
             UndirectedEdge[256, 319] -> 
             RGBColor[
              0.88573090588642, 0.4972867159645674, 0.37820371506637834`], 
             UndirectedEdge[64, 332] -> 
             RGBColor[
              0.8760650287883015, 0.4207576288274666, 0.25456499993773085`], 
             UndirectedEdge[213, 350] -> 
             RGBColor[
              0.33697931492905076`, 0.46629627834387477`, 0.942693001861539], 
             UndirectedEdge[333, 345] -> 
             RGBColor[
              0.8909301311153961, 0.9154013493777207, 0.9732965059821361], 
             UndirectedEdge[53, 201] -> 
             RGBColor[
              0.5341594365329997, 0.6309589682060907, 0.9570952074204189], 
             UndirectedEdge[9, 384] -> 
             RGBColor[
              0.8099718019563749, 0.7646503394906032, 0.6173962103853706], 
             UndirectedEdge[24, 33] -> 
             RGBColor[
              0.2533855843329195, 0.3836546930808141, 0.9377413062261555], 
             UndirectedEdge[20, 359] -> 
             RGBColor[
              0.3551576814248725, 0.48204146573128925`, 0.9438513113001545], 
             UndirectedEdge[35, 291] -> 
             RGBColor[
              0.19278015708719454`, 0.31995454643953136`, 0.9342899168022064],
              UndirectedEdge[316, 351] -> 
             RGBColor[
              0.5108480401165528, 0.6087959957654421, 0.956444390370581], 
             UndirectedEdge[195, 263] -> 
             RGBColor[
              0.3632251652657039, 0.4883898734545258, 0.9443887699919498], 
             UndirectedEdge[67, 200] -> 
             RGBColor[
              0.1867268102524256, 0.3135920951118324, 0.9339451876550904], 
             UndirectedEdge[232, 277] -> 
             RGBColor[
              0.18773724237763328`, 0.31465412334052256`, 0.9340027302698206],
              UndirectedEdge[88, 120] -> 
             RGBColor[
              0.42147179727410705`, 0.5394794198355211, 0.9480767881227974], 
             UndirectedEdge[247, 271] -> 
             RGBColor[
              0.8182267475230357, 0.1411043452395526, 0.1650872600532131], 
             UndirectedEdge[202, 269] -> 
             RGBColor[
              0.34049741903328384`, 0.46934348329390774`, 0.9429171723441234],
              UndirectedEdge[207, 291] -> 
             RGBColor[
              0.19348889841744987`, 0.3206994785144255, 0.9343302785724756], 
             UndirectedEdge[72, 397] -> 
             RGBColor[
              0.4148581473336097, 0.5334192417760302, 0.947747040377775], 
             UndirectedEdge[200, 298] -> 
             RGBColor[
              0.19975642982426225`, 0.3272870514074283, 0.9346872052141117], 
             UndirectedEdge[233, 389] -> 
             RGBColor[
              0.9817271461205633, 0.9825466050438816, 0.7139976792857294], 
             UndirectedEdge[44, 311] -> 
             RGBColor[
              0.21545480303552692`, 0.34378703698681684`, 0.9355812043448313],
              UndirectedEdge[137, 258] -> 
             RGBColor[
              0.2651486396074914, 0.3960184099951701, 0.9384111948221615], 
             UndirectedEdge[46, 287] -> 
             RGBColor[
              0.8133914916365368, 0.3720881611980434, 0.43656266857292936`], 
             UndirectedEdge[84, 274] -> 
             RGBColor[
              0.20871345876417752`, 0.33670145673171487`, 0.935197294761503], 
             UndirectedEdge[270, 357] -> 
             RGBColor[
              0.1969743042117703, 0.32436286099174727`, 0.9345287672762663], 
             UndirectedEdge[44, 344] -> 
             RGBColor[
              0.20993796520971017`, 0.3379884906441625, 0.9352670285920812], 
             UndirectedEdge[44, 383] -> 
             RGBColor[
              0.29331549171916627`, 0.4210403283755737, 0.9401830698485728], 
             UndirectedEdge[193, 364] -> 
             RGBColor[
              0.8796332391054209, 0.7997224705221349, 0.619984358127655], 
             UndirectedEdge[43, 375] -> 
             RGBColor[
              0.19874644987833204`, 0.3262254984478285, 0.9346296883503225], 
             UndirectedEdge[184, 252] -> 
             RGBColor[
              0.20974713734389644`, 0.3377879184580067, 0.9352561612274277], 
             UndirectedEdge[16, 78] -> 
             RGBColor[
              0.22470970081672578`, 0.3535145213492678, 0.9361082570820762], 
             UndirectedEdge[345, 353] -> 
             RGBColor[
              0.9106717648266294, 0.9268736116959997, 0.7456067906697404], 
             UndirectedEdge[167, 203] -> 
             RGBColor[
              0.2729080188918158, 0.40405718520565725`, 0.9388573575066418], 
             UndirectedEdge[329, 340] -> 
             RGBColor[
              0.2668654692611238, 0.39782290681442484`, 0.9385089657311141], 
             UndirectedEdge[193, 380] -> 
             RGBColor[
              0.7791551569135652, 0.8275462332304435, 0.978584074457042], 
             UndirectedEdge[115, 253] -> 
             RGBColor[
              0.8684975552193938, 0.416338486439171, 0.2087506971171275], 
             UndirectedEdge[113, 270] -> 
             RGBColor[
              0.196796775846464, 0.3241762674238618, 0.9345186572984918], 
             UndirectedEdge[121, 202] -> 
             RGBColor[
              0.2856578369982738, 0.41583248159385067`, 0.9396429608971655], 
             UndirectedEdge[17, 111] -> 
             RGBColor[
              0.8273118204939984, 0.2109361971987341, 0.17378713619032946`], 
             UndirectedEdge[73, 280] -> 
             RGBColor[
              0.2037203723071403, 0.3314534062854026, 0.9349129458743843], 
             UndirectedEdge[127, 242] -> 
             RGBColor[
              0.33988365440933965`, 0.4688118712253543, 0.9428780638050165], 
             UndirectedEdge[19, 211] -> 
             RGBColor[
              0.2160009516459515, 0.344361073804195, 0.9356123067002404], 
             UndirectedEdge[213, 345] -> 
             RGBColor[
              0.5767485455920949, 0.6610169677020706, 0.962710294489918], 
             UndirectedEdge[102, 350] -> 
             RGBColor[
              0.3487900132261258, 0.4765261115858444, 0.9434455691132382], 
             UndirectedEdge[81, 227] -> 
             RGBColor[
              0.2515739104642789, 0.38175050897811513`, 0.9376381340794677], 
             UndirectedEdge[144, 218] -> 
             RGBColor[
              0.5707667888209911, 0.662413217772521, 0.9593519988850778], 
             UndirectedEdge[130, 354] -> 
             RGBColor[
              0.2058823112495472, 0.3337257411887183, 0.9350360650988523], 
             UndirectedEdge[104, 327] -> 
             RGBColor[
              0.20490625211316982`, 0.332699841150662, 0.9349804799749857], 
             UndirectedEdge[10, 253] -> 
             RGBColor[
              0.8370421980658134, 0.2857281430943435, 0.18310495674198904`], 
             UndirectedEdge[40, 41] -> 
             RGBColor[
              0.19412189539412833`, 0.3213647984712409, 0.9343663268138622], 
             UndirectedEdge[5, 113] -> 
             RGBColor[
              0.18623312529560537`, 0.31307320092078017`, 0.9339170730271409],
              UndirectedEdge[271, 337] -> 
             RGBColor[
              0.8656615757726001, 0.4256489181689964, 0.43042768826228606`], 
             UndirectedEdge[325, 376] -> 
             RGBColor[
              0.26222548998781436`, 0.392945994406499, 0.9382447257757333], 
             UndirectedEdge[52, 337] -> 
             RGBColor[
              0.9729869409703154, 0.9785763889719264, 0.8948788134240234], 
             UndirectedEdge[246, 260] -> 
             RGBColor[
              0.20281631365008554`, 0.33050318331620854`, 0.9348614610713], 
             UndirectedEdge[22, 290] -> 
             RGBColor[
              0.2497813465899759, 0.3798664106911086, 0.9375360502186867], 
             UndirectedEdge[24, 107] -> 
             RGBColor[
              0.2416314482274979, 0.371300350778743, 0.9370719255636378], 
             UndirectedEdge[314, 369] -> 
             RGBColor[
              0.1815795981118552, 0.30818204879999395`, 0.9336520615383029], 
             UndirectedEdge[187, 208] -> 
             RGBColor[
              0.25538258130493185`, 0.38575366351532014`, 0.9378550322494192],
              UndirectedEdge[9, 174] -> 
             RGBColor[
              0.5520972673558275, 0.6456190088987284, 0.9586092963260144], 
             UndirectedEdge[6, 303] -> 
             RGBColor[
              0.9100466794366213, 0.777602242030947, 0.6130122278904285], 
             UndirectedEdge[100, 198] -> 
             RGBColor[
              0.6082548805926754, 0.6882816237042615, 0.9647291510065205], 
             UndirectedEdge[101, 123] -> 
             RGBColor[
              0.8503684349635493, 0.38815943948458614`, 0.19586617624509287`],
              UndirectedEdge[210, 394] -> 
             RGBColor[
              0.30165291276591666`, 0.42986750752233627`, 0.9406555295205197],
              UndirectedEdge[213, 227] -> 
             RGBColor[
              0.29970260204538113`, 0.43079580390036054`, 0.94043541584355], 
             UndirectedEdge[32, 46] -> 
             RGBColor[
              0.8161914025598732, 0.393609503483597, 0.4392438664351634], 
             UndirectedEdge[303, 391] -> 
             RGBColor[
              0.8447994948383054, 0.3081040680143853, 0.18907473406519165`], 
             UndirectedEdge[248, 251] -> 
             RGBColor[
              0.1839193268501145, 0.3106412520512747, 0.9337853056286283], 
             UndirectedEdge[239, 388] -> 
             RGBColor[
              0.38895939974165, 0.5063474161681534, 0.9465374152784297], 
             UndirectedEdge[205, 277] -> 
             RGBColor[
              0.18513416241600078`, 0.31191812125604473`, 0.9338544887169173],
              UndirectedEdge[308, 378] -> 
             RGBColor[
              0.22654239934249232`, 0.35544080369964637`, 0.9362126265518842],
              UndirectedEdge[119, 130] -> 
             RGBColor[
              0.2277266187202509, 0.3566854933495158, 0.936280066093552], 
             UndirectedEdge[28, 254] -> 
             RGBColor[
              0.1893368412328983, 0.3163354031578313, 0.9340938250582336], 
             UndirectedEdge[217, 314] -> 
             RGBColor[
              0.1955003640293088, 0.322813656406775, 0.9344448285633742], 
             UndirectedEdge[229, 307] -> 
             RGBColor[
              0.18847585942484443`, 0.31543045668816716`, 0.9340447934179733],
              UndirectedEdge[114, 155] -> 
             RGBColor[
              0.18628873221551898`, 0.3131316473192917, 0.933920239758967], 
             UndirectedEdge[226, 288] -> 
             RGBColor[
              0.20281928004263788`, 0.3305063011828612, 0.9348616300029674], 
             UndirectedEdge[217, 231] -> 
             RGBColor[
              0.19972682323934088`, 0.32725593300951006`, 0.9346855191628995],
              UndirectedEdge[151, 346] -> 
             RGBColor[
              0.2055192492348853, 0.3333441399918473, 0.9350153892542195], 
             UndirectedEdge[114, 180] -> 
             RGBColor[
              0.18755106204056693`, 0.3144584360017507, 0.9339921275750538], 
             UndirectedEdge[215, 345] -> 
             RGBColor[
              0.7670773504583543, 0.8180313903711476, 0.977401386659423], 
             UndirectedEdge[190, 252] -> 
             RGBColor[
              0.20904698368177904`, 0.3370520125668152, 0.9352162885121547], 
             UndirectedEdge[275, 311] -> 
             RGBColor[
              0.19837020308391207`, 0.32583003921146847`, 0.9346082616519875],
              UndirectedEdge[75, 320] -> 
             RGBColor[
              0.18280885155031829`, 0.3094740721029882, 0.933722065703106], 
             UndirectedEdge[169, 393] -> 
             RGBColor[
              0.5896152402179853, 0.6764956737968535, 0.9616696419121211], 
             UndirectedEdge[80, 182] -> 
             RGBColor[
              0.22246710481821064`, 0.35115741076602963`, 0.9359805445575843],
              UndirectedEdge[239, 362] -> 
             RGBColor[
              0.6492041088152176, 0.7238110272281775, 0.9670865002427318], 
             UndirectedEdge[171, 342] -> 
             RGBColor[
              0.18722373291059582`, 0.31411439233228555`, 0.933973486665342], 
             UndirectedEdge[107, 157] -> 
             RGBColor[
              0.2349712471793796, 0.36430005719603437`, 0.936692636966832], 
             UndirectedEdge[116, 286] -> 
             RGBColor[
              0.28063230469456346`, 0.41113725310534854`, 0.9393352740823563],
              UndirectedEdge[37, 117] -> 
             RGBColor[
              0.4214315538332871, 0.5343304799664346, 0.9489462154343377], 
             UndirectedEdge[111, 222] -> 
             RGBColor[
              0.8681038869231676, 0.45805238435921003`, 0.4379714781522483], 
             UndirectedEdge[57, 72] -> 
             RGBColor[
              0.4069178401688355, 0.5265417468013449, 0.9472410910265736], 
             UndirectedEdge[8, 323] -> 
             RGBColor[
              0.3381102648791732, 0.4623620160236, 0.9429449845379104], 
             UndirectedEdge[115, 356] -> 
             RGBColor[
              0.9502457162134885, 0.9092562156396481, 0.6300362544566458], 
             UndirectedEdge[129, 391] -> 
             RGBColor[
              0.8196355123081763, 0.15193272870280924`, 0.16643629480243607`],
              UndirectedEdge[271, 303] -> 
             RGBColor[
              0.8446451878986901, 0.3069179972587709, 0.1889269695655514], 
             UndirectedEdge[141, 196] -> 
             RGBColor[
              0.5999457128672814, 0.6805575674236943, 0.9644423387605343], 
             UndirectedEdge[8, 117] -> 
             RGBColor[
              0.40706513411417244`, 0.5192304619580248, 0.9481280690845475], 
             UndirectedEdge[278, 330] -> 
             RGBColor[
              0.18839714683821507`, 0.31534772476895345`, 0.9340403108526096],
              UndirectedEdge[95, 276] -> 
             RGBColor[
              0.3131382201938357, 0.4399588551912694, 0.9413821143478849], 
             UndirectedEdge[114, 268] -> 
             RGBColor[
              0.18716896902427724`, 0.3140568320155338, 0.9339703679430321], 
             UndirectedEdge[95, 148] -> 
             RGBColor[
              0.2518920934922597, 0.3820849395144922, 0.9376562541322015], 
             UndirectedEdge[236, 366] -> 
             RGBColor[
              0.7514680031030527, 0.8004311372612268, 0.7333352246803804], 
             UndirectedEdge[108, 378] -> 
             RGBColor[
              0.2733003143570183, 0.40458633700295354`, 0.938875420639825], 
             UndirectedEdge[33, 107] -> 
             RGBColor[
              0.23483527017028652`, 0.36415713673803723`, 0.9366848932773241],
              UndirectedEdge[309, 362] -> 
             RGBColor[
              0.7443188002522516, 0.8001867708802417, 0.9751504000206381], 
             UndirectedEdge[178, 278] -> 
             RGBColor[
              0.18555079143571185`, 0.31235602477156665`, 0.9338782151232425],
              UndirectedEdge[21, 232] -> 
             RGBColor[
              0.19351392550506752`, 0.32072578357032067`, 0.9343317038280912],
              UndirectedEdge[20, 140] -> 
             RGBColor[
              0.3954861818985797, 0.5169719858722439, 0.9464210076892463], 
             UndirectedEdge[33, 150] -> 
             RGBColor[
              0.24249803494618108`, 0.37221118836485045`, 0.9371212763952667],
              UndirectedEdge[38, 213] -> 
             RGBColor[
              0.2920695594579869, 0.42277299217815684`, 0.9400007253602725], 
             UndirectedEdge[86, 262] -> 
             RGBColor[
              0.31621623896980977`, 0.44455427693598626`, 0.9415075983220833],
              UndirectedEdge[17, 310] -> 
             RGBColor[
              0.8272800217278339, 0.2106917779476853, 0.17375668565593874`], 
             UndirectedEdge[222, 223] -> 
             RGBColor[
              0.8898400477329558, 0.6234245980125831, 0.45871942604339044`], 
             UndirectedEdge[19, 124] -> 
             RGBColor[
              0.21306575741872125`, 0.34127599856931323`, 0.9354451517312304],
              UndirectedEdge[184, 274] -> 
             RGBColor[
              0.20834640202144852`, 0.33631565682236503`, 0.9351763914230165],
              UndirectedEdge[195, 360] -> 
             RGBColor[
              0.5436868916256435, 0.6393368239296271, 0.957649106135095], 
             UndirectedEdge[186, 378] -> 
             RGBColor[
              0.22340907061728948`, 0.35214747654494266`, 0.9360341881163283],
              UndirectedEdge[31, 169] -> 
             RGBColor[
              0.7207585549931849, 0.779010354243588, 0.9304794974284005], 
             UndirectedEdge[4, 84] -> 
             RGBColor[
              0.20756604892203795`, 0.3354954562376403, 0.935131951468434], 
             UndirectedEdge[81, 383] -> 
             RGBColor[
              0.2937367673363199, 0.42148311575961905`, 0.9402070608717483], 
             UndirectedEdge[327, 335] -> 
             RGBColor[
              0.19201380881889718`, 0.3191490658202642, 0.9342462744020376], 
             UndirectedEdge[11, 214] -> 
             RGBColor[
              0.8760571062553216, 0.722408188261647, 0.6042242389431952], 
             UndirectedEdge[15, 35] -> 
             RGBColor[
              0.1861148468094702, 0.312948882732563, 0.933910337242333], 
             UndirectedEdge[151, 354] -> 
             RGBColor[
              0.20185675911317996`, 0.3294946306586492, 0.934806815859957], 
             UndirectedEdge[91, 192] -> 
             RGBColor[
              0.4254211791359827, 0.5344518171008017, 0.9495440785539795], 
             UndirectedEdge[44, 130] -> 
             RGBColor[
              0.22198842052975598`, 0.350654283228527, 0.9359532841955067], 
             UndirectedEdge[195, 356] -> 
             RGBColor[
              0.6850009171912799, 0.7504962345412768, 0.9628064219580481], 
             UndirectedEdge[226, 315] -> 
             RGBColor[
              0.186507225222572, 0.3133612973229612, 0.9339326826124872], 
             UndirectedEdge[65, 206] -> 
             RGBColor[
              0.4026912595828178, 0.5232126620245969, 0.9468801088680859], 
             UndirectedEdge[287, 400] -> 
             RGBColor[
              0.8189177394363433, 0.14641561187982197`, 0.1657489546897602], 
             UndirectedEdge[247, 319] -> 
             RGBColor[
              0.822373957683161, 0.17298161984935592`, 0.16905863318615305`], 
             UndirectedEdge[55, 72] -> 
             RGBColor[
              0.6346370252408752, 0.7117938428167392, 0.9660702931075245], 
             UndirectedEdge[313, 329] -> 
             RGBColor[
              0.27347825653768526`, 0.4047733655170204, 0.9388855541837721], 
             UndirectedEdge[5, 357] -> 
             RGBColor[
              0.1864106536609117, 0.3132597944886656, 0.9339271830049154], 
             UndirectedEdge[39, 328] -> 
             RGBColor[
              0.21476290196670605`, 0.3430598050944246, 0.9355418016025379], 
             UndirectedEdge[310, 384] -> 
             RGBColor[
              0.8622060383227799, 0.39468052511930574`, 0.20382345293974308`],
              UndirectedEdge[66, 344] -> 
             RGBColor[
              0.19384485664191092`, 0.32107361317738903`, 0.9343505498667657],
              UndirectedEdge[271, 391] -> 
             RGBColor[
              0.8200799062622772, 0.15534853536870052`, 0.16686184695475423`],
              UndirectedEdge[203, 211] -> 
             RGBColor[
              0.27124930343896736`, 0.4023137700960795, 0.9387628961154517], 
             UndirectedEdge[100, 203] -> 
             RGBColor[
              0.3488608742001085, 0.47658748779993204`, 0.9434500843118405], 
             UndirectedEdge[323, 377] -> 
             RGBColor[
              0.3376579889612439, 0.46188664535790686`, 0.9429192280934666], 
             UndirectedEdge[351, 395] -> 
             RGBColor[
              0.37411784951982285`, 0.4984638103693781, 0.9450594364453463], 
             UndirectedEdge[179, 209] -> 
             RGBColor[
              0.24592936800917714`, 0.3758177369731411, 0.9373166857370019], 
             UndirectedEdge[283, 356] -> 
             RGBColor[
              0.9386530516866118, 0.8632951638170323, 0.6207085244635109], 
             UndirectedEdge[77, 80] -> 
             RGBColor[
              0.20002934434875747`, 0.3275739018764531, 0.9347027472925409], 
             UndirectedEdge[200, 398] -> 
             RGBColor[
              0.18742715801975252`, 0.3143282050199061, 0.933985071424368], 
             UndirectedEdge[280, 368] -> 
             RGBColor[
              0.19638103924398845`, 0.323739301895437, 0.934494981714008], 
             UndirectedEdge[3, 390] -> 
             RGBColor[
              0.22459916207358144`, 0.353398338121662, 0.9361019620641815], 
             UndirectedEdge[64, 380] -> 
             RGBColor[
              0.8564837144111264, 0.8840181121327374, 0.7035464946088651], 
             UndirectedEdge[139, 186] -> 
             RGBColor[
              0.2567623305791477, 0.38720386748367763`, 0.9379336069294297], 
             UndirectedEdge[160, 245] -> 
             RGBColor[
              0.19509478987731566`, 0.3223873722581438, 0.9344217317154114], 
             UndirectedEdge[64, 360] -> 
             RGBColor[
              0.8276703795499445, 0.8615089159497265, 0.7006746506658257], 
             UndirectedEdge[72, 337] -> 
             RGBColor[
              0.7112579708229148, 0.7722092308988048, 0.9543875188835923], 
             UndirectedEdge[11, 141] -> 
             RGBColor[
              0.6144798263952078, 0.6921466750328611, 0.9658286154835842], 
             UndirectedEdge[62, 223] -> 
             RGBColor[
              0.9034121684337133, 0.6327035931146356, 0.3979909556022818], 
             UndirectedEdge[351, 399] -> 
             RGBColor[
              0.33446531711843736`, 0.46411877979752536`, 0.9425328121440877],
              UndirectedEdge[205, 232] -> 
             RGBColor[
              0.18775686622597437`, 0.3146747492493529, 0.9340038478189527], 
             UndirectedEdge[175, 379] -> 
             RGBColor[
              0.1863024171876671, 0.3131460310926968, 0.9339210190978857], 
             UndirectedEdge[144, 339] -> 
             RGBColor[
              0.48160738498318656`, 0.5880919933231088, 0.9528684097242202], 
             UndirectedEdge[66, 275] -> 
             RGBColor[
              0.19513571872831864`, 0.3224303910755869, 0.9344240625529272], 
             UndirectedEdge[311, 346] -> 
             RGBColor[
              0.20301118387702347`, 0.33070800428020625`, 0.9348725586424393],
              UndirectedEdge[81, 326] -> 
             RGBColor[
              0.23536377630225702`, 0.36471263019196243`, 0.936714990919685], 
             UndirectedEdge[145, 335] -> 
             RGBColor[
              0.2240686969525251, 0.3528407856460005, 0.9360717528602902], 
             UndirectedEdge[24, 56] -> 
             RGBColor[
              0.3892899244154366, 0.5053479265592988, 0.9466788406566481], 
             UndirectedEdge[310, 319] -> 
             RGBColor[
              0.8284925866386836, 0.2200120832018078, 0.17491783918396456`], 
             UndirectedEdge[131, 303] -> 
             RGBColor[
              0.8540204827009316, 0.7329759435664439, 0.607655802146349], 
             UndirectedEdge[146, 317] -> 
             RGBColor[
              0.19381671894004093`, 0.32104403866869025`, 0.9343489474662702],
              UndirectedEdge[159, 321] -> 
             RGBColor[
              0.1833474210515813, 0.31004014279609426`, 0.9337527364394607], 
             UndirectedEdge[339, 361] -> 
             RGBColor[
              0.39576579821065194`, 0.5172141754678363, 0.9464388245933966], 
             UndirectedEdge[60, 297] -> 
             RGBColor[
              0.5017919184919047, 0.6000427072524873, 0.955816605103172], 
             UndirectedEdge[1, 368] -> 
             RGBColor[
              0.1828231865844723, 0.30948913913277776`, 0.9337228820620942], 
             UndirectedEdge[15, 106] -> 
             RGBColor[
              0.18432449600494816`, 0.311067110522213, 0.933808379412602], 
             UndirectedEdge[144, 282] -> 
             RGBColor[
              0.44814038646858245`, 0.5591045613100133, 0.9507359221725744], 
             UndirectedEdge[333, 391] -> 
             RGBColor[
              0.8647483196982105, 0.42603880217674006`, 0.43238255847960916`],
              UndirectedEdge[85, 238] -> 
             RGBColor[
              0.19138550303315327`, 0.3184886766025597, 0.9342104933170345], 
             UndirectedEdge[130, 135] -> 
             RGBColor[
              0.27550933277442513`, 0.40444794828705827`, 0.9390913012054878],
              UndirectedEdge[194, 256] -> 
             RGBColor[
              0.7238719368935342, 0.7799355863354847, 0.863740011258672], 
             UndirectedEdge[129, 271] -> 
             RGBColor[
              0.8195583588383687, 0.15133969332500205`, 0.16636241255261597`],
              UndirectedEdge[12, 168] -> 
             RGBColor[
              0.22037492795635888`, 0.34895840023254887`, 0.9358613981804], 
             UndirectedEdge[32, 271] -> 
             RGBColor[
              0.8210134951874929, 0.16252450894918472`, 0.16775585276387872`],
              UndirectedEdge[227, 363] -> 
             RGBColor[
              0.3242588248996095, 0.45206516990504564`, 0.9420001166496061], 
             UndirectedEdge[351, 355] -> 
             RGBColor[
              0.2588476494190366, 0.38932088860423164`, 0.9380551008583563], 
             UndirectedEdge[70, 285] -> 
             RGBColor[
              0.1906202345698193, 0.31768433092677273`, 0.9341669124101608], 
             UndirectedEdge[19, 107] -> 
             RGBColor[
              0.211296993265781, 0.33941691529844853`, 0.9353444232293726], 
             UndirectedEdge[88, 359] -> 
             RGBColor[
              0.3780427703410259, 0.5018633795124479, 0.9453095289294022], 
             UndirectedEdge[128, 130] -> 
             RGBColor[
              0.2597826750311079, 0.39037844100358665`, 0.9381056110777697], 
             UndirectedEdge[72, 297] -> 
             RGBColor[
              0.3810483803734705, 0.5030082457772378, 0.9456339650216002], 
             UndirectedEdge[125, 184] -> 
             RGBColor[
              0.20307558723579205`, 0.3307756962936808, 0.934876226318445], 
             UndirectedEdge[41, 63] -> 
             RGBColor[
              0.19205972818458644`, 0.31919732998505956`, 0.9342488894419819],
              UndirectedEdge[67, 133] -> 
             RGBColor[
              0.1814057266970613, 0.30799929891896116`, 0.9336421598184501], 
             UndirectedEdge[272, 308] -> 
             RGBColor[
              0.20474955864050876`, 0.33253514637595527`, 0.9349715565135248],
              UndirectedEdge[199, 287] -> 
             RGBColor[
              0.8744579174591663, 0.41928798612573526`, 0.3882590880835432], 
             UndirectedEdge[60, 333] -> 
             RGBColor[
              0.8304001644203418, 0.8680494122522482, 0.9672808175416883], 
             UndirectedEdge[86, 325] -> 
             RGBColor[
              0.25318562671626305`, 0.38344452494766296`, 0.9377299189356977],
              UndirectedEdge[77, 377] -> 
             RGBColor[
              0.22582310918113752`, 0.35468478413443216`, 0.9361716640412894],
              UndirectedEdge[62, 319] -> 
             RGBColor[
              0.885564206725758, 0.4972177815776606, 0.3809663515621477], 
             UndirectedEdge[52, 199] -> 
             RGBColor[
              0.9888652062926342, 0.9896634908979279, 0.8341958778608433], 
             UndirectedEdge[57, 376] -> 
             RGBColor[
              0.31723897478085683`, 0.4471117135410761, 0.941511560889603], 
             UndirectedEdge[11, 161] -> 
             RGBColor[
              0.8763695857039919, 0.7238270844566292, 0.6044849794547379], 
             UndirectedEdge[155, 300] -> 
             RGBColor[
              0.19103033479495424`, 0.31811537226524556`, 0.9341902670112934],
              UndirectedEdge[81, 275] -> 
             RGBColor[
              0.21165010291327152`, 0.33978805592640576`, 0.9353645323014182],
              UndirectedEdge[100, 266] -> 
             RGBColor[
              0.5229669528809726, 0.6215828095678126, 0.9562473514884939], 
             UndirectedEdge[56, 266] -> 
             RGBColor[
              0.5883098999275997, 0.6764125091387695, 0.9608991949142476], 
             UndirectedEdge[82, 257] -> 
             RGBColor[
              0.8645894369328215, 0.89448136547207, 0.956668495179433], 
             UndirectedEdge[32, 259] -> 
             RGBColor[
              0.8461541179339149, 0.41742311009542027`, 0.44212239578911544`],
              UndirectedEdge[261, 355] -> 
             RGBColor[
              0.19867201809183277`, 0.32614726592096993`, 0.9346254495701933],
              UndirectedEdge[74, 179] -> 
             RGBColor[
              0.23767352171657924`, 0.3671403190687327, 0.9368465275040685], 
             UndirectedEdge[100, 174] -> 
             RGBColor[
              0.4027739307357637, 0.5232842676221057, 0.9468853766008484], 
             UndirectedEdge[208, 388] -> 
             RGBColor[
              0.28259974438226976`, 0.4143606275774112, 0.9394050094224892], 
             UndirectedEdge[249, 299] -> 
             RGBColor[
              0.186005835268804, 0.3128343046915919, 0.9339041291963601], 
             UndirectedEdge[58, 181] -> 
             RGBColor[
              0.19266290312611054`, 0.31983130509210156`, 0.9342832393625844],
              UndirectedEdge[271, 345] -> 
             RGBColor[
              0.8226964117082949, 0.39175550148521254`, 0.4390134962813673], 
             UndirectedEdge[20, 89] -> 
             RGBColor[
              0.30842578765479933`, 0.4344898392135439, 0.9411326397648885], 
             UndirectedEdge[174, 358] -> 
             RGBColor[
              0.34771638286513834`, 0.47271625798382977`, 0.9434826066423876],
              UndirectedEdge[185, 274] -> 
             RGBColor[
              0.19784473283359588`, 0.32527773666164805`, 0.9345783368985956],
              UndirectedEdge[106, 314] -> 
             RGBColor[
              0.18463641563674799`, 0.3113949578320815, 0.9338261427741893], 
             UndirectedEdge[73, 387] -> 
             RGBColor[
              0.19202691052884113`, 0.31916283654811173`, 0.9342470205250366],
              UndirectedEdge[191, 261] -> 
             RGBColor[
              0.18660634868245718`, 0.3134654823640909, 0.9339383275468877], 
             UndirectedEdge[135, 227] -> 
             RGBColor[
              0.3046735470917944, 0.4351013866526011, 0.9407521600662733], 
             UndirectedEdge[102, 345] -> 
             RGBColor[
              0.5885592438891699, 0.6712468009440402, 0.9634628617416172], 
             UndirectedEdge[72, 108] -> 
             RGBColor[
              0.3859501572545172, 0.5081603240698226, 0.9459131139634468], 
             UndirectedEdge[7, 273] -> 
             RGBColor[
              0.3894971814838498, 0.5048902400899095, 0.9467521342900769], 
             UndirectedEdge[111, 385] -> 
             RGBColor[
              0.882547250933544, 0.4671945139777004, 0.32666691392273633`], 
             UndirectedEdge[25, 187] -> 
             RGBColor[
              0.29015449891481293`, 0.4171960722657919, 0.940022163552006], 
             UndirectedEdge[290, 338] -> 
             RGBColor[
              0.2338329245191738, 0.3631036079063329, 0.9366278111753308], 
             UndirectedEdge[133, 200] -> 
             RGBColor[
              0.18872606349581567`, 0.31569343703061226`, 0.9340590421696713],
              UndirectedEdge[64, 88] -> 
             RGBColor[
              0.7114905669436782, 0.7668789695612932, 0.6914868954695467], 
             UndirectedEdge[23, 92] -> 
             RGBColor[
              0.20814505737279243`, 0.33610403083063944`, 0.9351649251431382],
              UndirectedEdge[38, 350] -> 
             RGBColor[
              0.3036355127427933, 0.43279083959174136`, 0.9407376976762094], 
             UndirectedEdge[135, 224] -> 
             RGBColor[
              0.41655140034572946`, 0.5340112529021572, 0.9480965874177693], 
             UndirectedEdge[329, 358] -> 
             RGBColor[
              0.26996801721198005`, 0.40108388142367646`, 0.9386856512471069],
              UndirectedEdge[4, 185] -> 
             RGBColor[
              0.1966973229914563, 0.32407173616757357`, 0.9345129936055264], 
             UndirectedEdge[111, 199] -> 
             RGBColor[
              0.8806533072058972, 0.4669084665562061, 0.39419180030170453`], 
             UndirectedEdge[138, 264] -> 
             RGBColor[
              0.27444206081652406`, 0.4057863849228008, 0.9389404414116314], 
             UndirectedEdge[275, 344] -> 
             RGBColor[
              0.19285336525809532`, 0.32003149286881416`, 0.9342940858992375],
              UndirectedEdge[300, 371] -> 
             RGBColor[
              0.1880971018774196, 0.31503235849120814`, 0.934023223735969], 
             UndirectedEdge[69, 273] -> 
             RGBColor[
              0.5484319039049934, 0.644280752022615, 0.9575937149291112], 
             UndirectedEdge[65, 174] -> 
             RGBColor[
              0.39716489293029483`, 0.5184260009934458, 0.9465279736717613], 
             UndirectedEdge[217, 254] -> 
             RGBColor[
              0.1976623221296092, 0.32508601144625143`, 0.934567948878856], 
             UndirectedEdge[102, 378] -> 
             RGBColor[
              0.29463589617818253`, 0.42328641527644917`, 0.9402268398959757],
              UndirectedEdge[246, 326] -> 
             RGBColor[
              0.22913658446266597`, 0.35816745674178546`, 0.9363603615567251],
              UndirectedEdge[120, 242] -> 
             RGBColor[
              0.3764731339021319, 0.500503839321299, 0.9452095130834909], 
             UndirectedEdge[25, 117] -> 
             RGBColor[
              0.4612467201078884, 0.5710736628239611, 0.9514005522875624], 
             UndirectedEdge[44, 227] -> 
             RGBColor[
              0.25115263484712524`, 0.3813077215940698, 0.9376141430562922], 
             UndirectedEdge[118, 206] -> 
             RGBColor[
              0.39316789594043106`, 0.5149640030957358, 0.9462732885579729], 
             UndirectedEdge[151, 158] -> 
             RGBColor[
              0.19937632863451948`, 0.3268875409572013, 0.9346655590136652], 
             UndirectedEdge[151, 308] -> 
             RGBColor[
              0.2102300370530294, 0.33829547666991544`, 0.9352836616514766], 
             UndirectedEdge[298, 390] -> 
             RGBColor[
              0.2092243065114207, 0.3372383901036854, 0.935226386784977], 
             UndirectedEdge[62, 111] -> 
             RGBColor[
              0.8816760076239252, 0.4673313794612627, 0.3772430077111397], 
             UndirectedEdge[131, 201] -> 
             RGBColor[
              0.7399124857733206, 0.7967445245200704, 0.9747112197727283], 
             UndirectedEdge[291, 368] -> 
             RGBColor[
              0.1896468250359693, 0.3166612157889672, 0.9341114781772385], 
             UndirectedEdge[35, 73] -> 
             RGBColor[
              0.19430576499947028`, 0.3215580570844616, 0.9343767979158759], 
             UndirectedEdge[273, 293] -> 
             RGBColor[
              0.4190878106551068, 0.5354941029446921, 0.9484555024448121], 
             UndirectedEdge[4, 274] -> 
             RGBColor[
              0.2019924165278475, 0.3296372152026416, 0.934814541349035], 
             UndirectedEdge[10, 337] -> 
             RGBColor[
              0.8809711396763451, 0.543324935026861, 0.44508814394619167`], 
             UndirectedEdge[27, 265] -> 
             RGBColor[
              0.20201462184730384`, 0.32966055440128883`, 0.9348158059091283],
              UndirectedEdge[262, 325] -> 
             RGBColor[
              0.3013026030921642, 0.42887910004945207`, 0.9406582888215985], 
             UndirectedEdge[46, 337] -> 
             RGBColor[
              0.8812578483212357, 0.9077231190596664, 0.969479570547889], 
             UndirectedEdge[322, 327] -> 
             RGBColor[
              0.19043725974580353`, 0.3174920127854582, 0.9341564922646202], 
             UndirectedEdge[59, 299] -> 
             RGBColor[
              0.20233103571342284`, 0.3299931254363777, 0.9348338252107113], 
             UndirectedEdge[254, 369] -> 
             RGBColor[
              0.1837415562121556, 0.31045440383947037`, 0.9337751818537847], 
             UndirectedEdge[262, 376] -> 
             RGBColor[
              0.3252561022413611, 0.4540557463948223, 0.9420224051621189], 
             UndirectedEdge[360, 389] -> 
             RGBColor[
              0.8279393932352007, 0.862084309021034, 0.7299551301459482], 
             UndirectedEdge[159, 381] -> 
             RGBColor[
              0.18574510039169012`, 0.3125602558041992, 0.9338892807308311], 
             UndirectedEdge[77, 302] -> 
             RGBColor[
              0.19582677060371215`, 0.3231567304118451, 0.9344634169349113], 
             UndirectedEdge[67, 398] -> 
             RGBColor[
              0.18010682122099816`, 0.306634066908255, 0.9335681890731469], 
             UndirectedEdge[12, 100] -> 
             RGBColor[
              0.315248838603848, 0.44137593165251704`, 0.941531651095973], 
             UndirectedEdge[329, 339] -> 
             RGBColor[
              0.322148238300078, 0.44915969522157617`, 0.9419050804873051], 
             UndirectedEdge[1, 113] -> 
             RGBColor[
              0.18373091059218155`, 0.31044321461790636`, 0.9337745756014759],
              UndirectedEdge[232, 390] -> 
             RGBColor[
              0.20167142330655186`, 0.3292998309749142, 0.9347962612599492], 
             UndirectedEdge[319, 384] -> 
             RGBColor[
              0.8661578349569418, 0.4250557657378013, 0.20760769785953248`], 
             UndirectedEdge[342, 374] -> 
             RGBColor[
              0.18501533393427727`, 0.31179322498759243`, 0.9338477216106742],
              UndirectedEdge[200, 320] -> 
             RGBColor[
              0.18887757795522245`, 0.31585268833402036`, 0.934067670693989], 
             UndirectedEdge[35, 231] -> 
             RGBColor[
              0.19065322565130216`, 0.31771900664516656`, 0.9341687912034454],
              UndirectedEdge[96, 104] -> 
             RGBColor[
              0.21783923349947054`, 0.34629322458604483`, 0.935716994132304], 
             UndirectedEdge[106, 197] -> 
             RGBColor[
              0.18891531916432497`, 0.315892356737718, 0.9340698200000144], 
             UndirectedEdge[41, 265] -> 
             RGBColor[
              0.19689578074158462`, 0.3242803278459065, 0.9345242954808043], 
             UndirectedEdge[52, 303] -> 
             RGBColor[
              0.9414623591594504, 0.8004800076065881, 0.5326277353789215], 
             UndirectedEdge[170, 208] -> 
             RGBColor[
              0.26496099146250607`, 0.3958211798972109, 0.9384005085379051], 
             UndirectedEdge[49, 355] -> 
             RGBColor[
              0.19591924831876065`, 0.3232539303537868, 0.9344686834039748], 
             UndirectedEdge[140, 359] -> 
             RGBColor[
              0.36601815692823686`, 0.491448263748933, 0.9445433311956875], 
             UndirectedEdge[20, 255] -> 
             RGBColor[
              0.37940724758906264`, 0.5030452211240766, 0.9453964722130872], 
             UndirectedEdge[117, 362] -> 
             RGBColor[
              0.6749012549506066, 0.7446731281041272, 0.9691094737182575], 
             UndirectedEdge[188, 293] -> 
             RGBColor[
              0.29496948602480166`, 0.4268642457721712, 0.9401276735084836], 
             UndirectedEdge[149, 155] -> 
             RGBColor[
              0.19811293609800762`, 0.3255596352976139, 0.9345936106777326], 
             UndirectedEdge[7, 188] -> 
             RGBColor[
              0.2653788568535447, 0.3962603829173885, 0.9384243053537484], 
             UndirectedEdge[120, 331] -> 
             RGBColor[
              0.3267582826576653, 0.45117687376714777`, 0.9422711725263158], 
             UndirectedEdge[169, 218] -> 
             RGBColor[
              0.5087675338544672, 0.6120794295560898, 0.9544711904233589], 
             UndirectedEdge[345, 350] -> 
             RGBColor[
              0.5883144988769012, 0.6710348151156551, 0.9634472668058549], 
             UndirectedEdge[147, 217] -> 
             RGBColor[
              0.2277310230294914, 0.3566901225577769, 0.9362803169124476], 
             UndirectedEdge[141, 386] -> 
             RGBColor[
              0.348846857880801, 0.4765753475686286, 0.9434491912043683], 
             UndirectedEdge[128, 383] -> 
             RGBColor[
              0.3311097462205182, 0.46076448615063337`, 0.9423353967308358], 
             UndirectedEdge[138, 394] -> 
             RGBColor[
              0.32326515413332657`, 0.4525833434947314, 0.9418863146939478], 
             UndirectedEdge[132, 300] -> 
             RGBColor[
              0.1945175148280322, 0.3217806195799947, 0.9343888567553567], 
             UndirectedEdge[103, 122] -> 
             RGBColor[
              0.1920779072643653, 0.3192164373505274, 0.9342499247136817], 
             UndirectedEdge[147, 195] -> 
             RGBColor[
              0.3359166803532971, 0.45968692435363845`, 0.9428335921754714], 
             UndirectedEdge[123, 389] -> 
             RGBColor[
              0.8931463007512496, 0.5510568608650397, 0.29027062637419626`], 
             UndirectedEdge[93, 394] -> 
             RGBColor[
              0.35007693853437594`, 0.4776407816051039, 0.9435275708558966], 
             UndirectedEdge[199, 350] -> 
             RGBColor[
              0.6686405102956781, 0.7329620420673324, 0.8898856192140527], 
             UndirectedEdge[66, 158] -> 
             RGBColor[
              0.19363377892106423`, 0.3208517571096786, 0.934338529302825], 
             UndirectedEdge[105, 215] -> 
             RGBColor[
              0.8456866310237973, 0.8792487049970009, 0.932290412064394], 
             UndirectedEdge[253, 364] -> 
             RGBColor[
              0.8572410457828872, 0.37171017753282953`, 0.19969344540027856`],
              UndirectedEdge[76, 78] -> 
             RGBColor[
              0.2517003601981642, 0.38188341566580475`, 0.9376453352047469], 
             UndirectedEdge[153, 358] -> 
             RGBColor[
              0.24162422522743635`, 0.37129275894771363`, 0.9370715142244698],
              UndirectedEdge[54, 64] -> 
             RGBColor[
              0.970419525130984, 0.9095497585157698, 0.3557751825465969], 
             UndirectedEdge[84, 125] -> 
             RGBColor[
              0.20344264397852102`, 0.33116149620303065`, 0.9348971296569317],
              UndirectedEdge[195, 380] -> 
             RGBColor[
              0.5725002264868254, 0.6618460201126379, 0.9605209500781344], 
             UndirectedEdge[81, 146] -> 
             RGBColor[
              0.2141426413323014, 0.3424078718408697, 0.9355064786770019], 
             UndirectedEdge[275, 317] -> 
             RGBColor[
              0.19132418052101102`, 0.3184242227542263, 0.9342070010906866], 
             UndirectedEdge[25, 377] -> 
             RGBColor[
              0.3093279743113551, 0.4373486105761115, 0.941114064611224], 
             UndirectedEdge[180, 232] -> 
             RGBColor[
              0.18939213687360562`, 0.3163935223821609, 0.9340969740631693], 
             UndirectedEdge[52, 333] -> 
             RGBColor[
              0.9713855964493081, 0.9773821088501203, 0.8975894720005477], 
             UndirectedEdge[97, 276] -> 
             RGBColor[
              0.33883500638970604`, 0.46696780675347616`, 0.9428455083067513],
              UndirectedEdge[51, 390] -> 
             RGBColor[
              0.2070958500160861, 0.33500124737515247`, 0.935105174336337], 
             UndirectedEdge[199, 393] -> 
             RGBColor[
              0.8553537557812887, 0.8861695254659845, 0.9046321600313321], 
             UndirectedEdge[169, 224] -> 
             RGBColor[
              0.4775031351026399, 0.5866975822042433, 0.9520099424283488], 
             UndirectedEdge[132, 268] -> 
             RGBColor[
              0.19026708475134468`, 0.3173131480765642, 0.9341468010504371], 
             UndirectedEdge[162, 183] -> 
             RGBColor[
              0.1919904214056781, 0.3191244841661233, 0.9342449425234534], 
             UndirectedEdge[15, 231] -> 
             RGBColor[
              0.18666830847322874`, 0.31353060603266947`, 0.9339418560653108],
              UndirectedEdge[246, 248] -> 
             RGBColor[
              0.19980719089443424`, 0.32734040451061686`, 0.9346900959819637],
              UndirectedEdge[44, 81] -> 
             RGBColor[
              0.22873470286488637`, 0.35774505370175413`, 0.9363374749942621],
              UndirectedEdge[39, 197] -> 
             RGBColor[
              0.19474286460527196`, 0.3220174764838748, 0.9344016900917953], 
             UndirectedEdge[57, 86] -> 
             RGBColor[
              0.30819911150930557`, 0.43761024408224003`, 0.9409967540495674],
              UndirectedEdge[74, 209] -> 
             RGBColor[
              0.2567896978925637, 0.3872326322652657, 0.9379351654574425], 
             UndirectedEdge[115, 389] -> 
             RGBColor[
              0.9741155744429982, 0.9237122058552483, 0.3878131353348738], 
             UndirectedEdge[157, 168] -> 
             RGBColor[
              0.222412865673202, 0.35110040198566517`, 0.9359774557185156], 
             UndirectedEdge[224, 363] -> 
             RGBColor[
              0.4361366781535445, 0.5509750361546019, 0.9493445440011021], 
             UndirectedEdge[47, 279] -> 
             RGBColor[
              0.19002059109890063`, 0.3170540676192452, 0.934132763601585], 
             UndirectedEdge[58, 352] -> 
             RGBColor[
              0.18979453396815193`, 0.3168164672419784, 0.9341198899824106], 
             UndirectedEdge[101, 161] -> 
             RGBColor[
              0.8624979444321746, 0.45922425798517125`, 0.20661336858810134`],
              UndirectedEdge[23, 98] -> 
             RGBColor[
              0.2025842284056299, 0.3302592470092312, 0.9348482441599675], 
             UndirectedEdge[37, 388] -> 
             RGBColor[
              0.27755649571754953`, 0.4090598534703564, 0.9391178038718512], 
             UndirectedEdge[13, 21] -> 
             RGBColor[
              0.2050154097981298, 0.332814572798552, 0.9349866963436598], 
             UndirectedEdge[159, 375] -> 
             RGBColor[
              0.19246854917072223`, 0.3196270267622359, 0.9342721711923458], 
             UndirectedEdge[130, 346] -> 
             RGBColor[
              0.20954480137125253`, 0.3375752505219164, 0.9352446384931148], 
             UndirectedEdge[104, 225] -> 
             RGBColor[
              0.2162656212099744, 0.3446392582970026, 0.935627379240368], 
             UndirectedEdge[226, 252] -> 
             RGBColor[
              0.19892295516503677`, 0.32641101669523676`, 0.9346397400652842],
              UndirectedEdge[64, 283] -> 
             RGBColor[
              0.9622538962308652, 0.8771757609613251, 0.3492049258616166], 
             UndirectedEdge[262, 284] -> 
             RGBColor[
              0.5520990373737982, 0.6433480852372535, 0.9595712205145508], 
             UndirectedEdge[282, 313] -> 
             RGBColor[
              0.2998205585054363, 0.43188039345676055`, 0.940406960657616], 
             UndirectedEdge[88, 360] -> 
             RGBColor[
              0.5465756968337885, 0.6418389618053506, 0.9578331782484879], 
             UndirectedEdge[210, 230] -> 
             RGBColor[
              0.2334030426063412, 0.36265177475985827`, 0.9366033300363481], 
             UndirectedEdge[2, 138] -> 
             RGBColor[
              0.24536530114030092`, 0.3752248669300471, 0.9372845629632816], 
             UndirectedEdge[178, 367] -> 
             RGBColor[
              0.18455036747987072`, 0.3113045157634352, 0.933821242458952], 
             UndirectedEdge[54, 123] -> 
             RGBColor[
              0.8781898086085118, 0.4993404886909019, 0.21838151649392293`], 
             UndirectedEdge[36, 95] -> 
             RGBColor[
              0.2464425329575721, 0.37635710587044113`, 0.9373459097216534], 
             UndirectedEdge[294, 301] -> 
             RGBColor[
              0.22980051567191817`, 0.3588652905383795, 0.9363981714568937], 
             UndirectedEdge[60, 337] -> 
             RGBColor[
              0.8320015089413489, 0.8692436923740543, 0.9645701589651641], 
             UndirectedEdge[251, 275] -> 
             RGBColor[
              0.1895350470293607, 0.3165437300168866, 0.9341051125851229], 
             UndirectedEdge[66, 311] -> 
             RGBColor[
              0.19936169446772767`, 0.32687215952004334`, 0.9346647256195157],
              UndirectedEdge[110, 400] -> 
             RGBColor[
              0.832397701814092, 0.40919298887241484`, 0.44115308767047345`], 
             UndirectedEdge[143, 151] -> 
             RGBColor[
              0.2032578843654731, 0.3309673021352812, 0.934886607870296], 
             UndirectedEdge[157, 206] -> 
             RGBColor[
              0.3378748813614898, 0.46135031520372605`, 0.942959564481942], 
             UndirectedEdge[226, 274] -> 
             RGBColor[
              0.1975222198425889, 0.324938755059595, 0.9345599702608729], 
             UndirectedEdge[86, 265] -> 
             RGBColor[
              0.23354789403514828`, 0.36280402279564555`, 0.9366115791109302],
              UndirectedEdge[64, 389] -> 
             RGBColor[
              0.9928542633450905, 0.9871243167769764, 0.4636088473670069], 
             UndirectedEdge[120, 356] -> 
             RGBColor[
              0.6789656354460096, 0.7452687768356042, 0.9624218591420297], 
             UndirectedEdge[164, 279] -> 
             RGBColor[
              0.20701484030443992`, 0.33491610103189995`, 0.9351005609531018],
              UndirectedEdge[24, 238] -> 
             RGBColor[
              0.23053198107939255`, 0.35963410705922055`, 0.9364398273297434],
              UndirectedEdge[213, 259] -> 
             RGBColor[
              0.6104189913379899, 0.6878648671799451, 0.9659218116631232], 
             UndirectedEdge[73, 162] -> 
             RGBColor[
              0.19690433907813965`, 0.3242893232002557, 0.9345247828654102], 
             UndirectedEdge[257, 356] -> 
             RGBColor[
              0.9574019127188883, 0.9677509967704889, 0.9569916297931109], 
             UndirectedEdge[6, 281] -> 
             RGBColor[
              0.6624572537085711, 0.7318807392393671, 0.9697242643368251], 
             UndirectedEdge[176, 277] -> 
             RGBColor[
              0.18565952896853344`, 0.31247031481291987`, 0.933884407564874], 
             UndirectedEdge[140, 263] -> 
             RGBColor[
              0.35408935706105976`, 0.48047689556673456`, 0.943806644371628], 
             UndirectedEdge[54, 161] -> 
             RGBColor[
              0.9139000708098552, 0.6892402426005217, 0.2492124251865322], 
             UndirectedEdge[7, 142] -> 
             RGBColor[
              0.36455405628776205`, 0.4846402873807406, 0.9447885201049626], 
             UndirectedEdge[81, 311] -> 
             RGBColor[
              0.21587607865268055`, 0.34422982437086214`, 0.9356051953680067],
              UndirectedEdge[204, 237] -> 
             RGBColor[
              0.18108298927677668`, 0.3076600814275077, 0.9336237803998122], 
             UndirectedEdge[134, 374] -> 
             RGBColor[
              0.18137577945827954`, 0.307967822472237, 0.9336404543675045], 
             UndirectedEdge[264, 279] -> 
             RGBColor[
              0.22950792112061041`, 0.35855775511338905`, 0.9363815086300517],
              UndirectedEdge[81, 344] -> 
             RGBColor[
              0.2103592408268638, 0.3384312780282078, 0.9352910196152566], 
             UndirectedEdge[287, 391] -> 
             RGBColor[
              0.8182907377339641, 0.1415962020414383, 0.16514853715146482`], 
             UndirectedEdge[90, 228] -> 
             RGBColor[
              0.21978849971833822`, 0.34834202697269134`, 0.9358280019597877],
              UndirectedEdge[222, 259] -> 
             RGBColor[
              0.9232560562805229, 0.9412465076079086, 0.9787839457914527], 
             UndirectedEdge[143, 342] -> 
             RGBColor[
              0.19264878464975516`, 0.3198164656782889, 0.9342824353362423], 
             UndirectedEdge[68, 262] -> 
             RGBColor[
              0.5929687866565062, 0.6752889407487281, 0.9636412596987081], 
             UndirectedEdge[73, 189] -> 
             RGBColor[
              0.2158427366159144, 0.3441947797762137, 0.9356032965883381], 
             UndirectedEdge[79, 176] -> 
             RGBColor[
              0.19262785863960308`, 0.31979447111483345`, 0.9342812436309215],
              UndirectedEdge[14, 289] -> 
             RGBColor[
              0.4064318553204269, 0.5258851919600367, 0.9472752267865294], 
             UndirectedEdge[126, 373] -> 
             RGBColor[
              0.19027225530167013`, 0.317318582652788, 0.934147095505629], 
             UndirectedEdge[313, 361] -> 
             RGBColor[
              0.3470958164482592, 0.47282784576328063`, 0.9434192982898635], 
             UndirectedEdge[56, 203] -> 
             RGBColor[
              0.4142038212467356, 0.5314171873708888, 0.948101927737594], 
             UndirectedEdge[163, 240] -> 
             RGBColor[
              0.17919351847301027`, 0.305674127813381, 0.9335161778327592], 
             UndirectedEdge[283, 380] -> 
             RGBColor[
              0.8261523609821573, 0.7746449493883936, 0.6184230525835972], 
             UndirectedEdge[165, 318] -> 
             RGBColor[
              0.21949852941857476`, 0.348037249802461, 0.9358114885801888], 
             UndirectedEdge[184, 185] -> 
             RGBColor[
              0.20305130848505737`, 0.330750177787297, 0.9348748436795078], 
             UndirectedEdge[123, 364] -> 
             RGBColor[
              0.869217989589844, 0.4637702159633411, 0.2111625803158437], 
             UndirectedEdge[24, 341] -> 
             RGBColor[
              0.25476263408947386`, 0.38510205968495004`, 0.9378197271726287],
              UndirectedEdge[10, 364] -> 
             RGBColor[
              0.8690908469474348, 0.46279294189952286`, 0.21104082837788557`],
              UndirectedEdge[59, 132] -> 
             RGBColor[
              0.20457320024571096`, 0.33234978252125474`, 0.93496151316384], 
             UndirectedEdge[110, 309] -> 
             RGBColor[
              0.7751646817101416, 0.8245503622153614, 0.9781540938970312], 
             UndirectedEdge[28, 50] -> 
             RGBColor[
              0.21136185866227802`, 0.33948509294287055`, 0.9353481172177434],
              UndirectedEdge[120, 147] -> 
             RGBColor[
              0.3298813986080268, 0.4544594666479659, 0.9424490293594527], 
             UndirectedEdge[322, 335] -> 
             RGBColor[
              0.19668775397946056`, 0.3240616785292556, 0.9345124486644494], 
             UndirectedEdge[9, 198] -> 
             RGBColor[
              0.7575782172127392, 0.8106163649808842, 0.9764530707316865], 
             UndirectedEdge[214, 257] -> 
             RGBColor[
              0.9241708234933428, 0.7599031818045514, 0.5786645333196092], 
             UndirectedEdge[190, 274] -> 
             RGBColor[
              0.20764624835933113`, 0.33557975093117354`, 0.9351365187077434],
              UndirectedEdge[18, 198] -> 
             RGBColor[
              0.9106667100371233, 0.9263839830131071, 0.7062421502048801], 
             UndirectedEdge[280, 291] -> 
             RGBColor[
              0.20219476439486456`, 0.32984989564047235`, 0.9348260647607148],
              UndirectedEdge[156, 179] -> 
             RGBColor[
              0.21434244441768896`, 0.34261787755185935`, 0.9355178571671325],
              UndirectedEdge[76, 96] -> 
             RGBColor[
              0.24728213971667218`, 0.37723958580839845`, 0.9373937240844974],
              UndirectedEdge[143, 158] -> 
             RGBColor[
              0.1950219034609478, 0.3223107640132754, 0.9344175809418251], 
             UndirectedEdge[252, 274] -> 
             RGBColor[
              0.20454056169243495`, 0.3323154773323579, 0.9349596544465153], 
             UndirectedEdge[272, 348] -> 
             RGBColor[
              0.1988777254844435, 0.3263634774332058, 0.9346371643018856], 
             UndirectedEdge[51, 232] -> 
             RGBColor[
              0.19578437289714112`, 0.32311216773406903`, 0.9344610024482438],
              UndirectedEdge[66, 317] -> 
             RGBColor[
              0.19231567190482668`, 0.3194663430628012, 0.9342634650582149], 
             UndirectedEdge[258, 264] -> 
             RGBColor[
              0.24881577416889822`, 0.37885153285572853`, 0.9374810622977428],
              UndirectedEdge[17, 223] -> 
             RGBColor[
              0.8381799008988925, 0.29362230402542056`, 0.1841611101359005], 
             UndirectedEdge[46, 271] -> 
             RGBColor[
              0.8151806601648499, 0.3858404945253056, 0.4382759783762188], 
             UndirectedEdge[93, 201] -> 
             RGBColor[
              0.5041214136186714, 0.6049415425126292, 0.9551812111618987], 
             UndirectedEdge[232, 373] -> 
             RGBColor[
              0.19417254912152382`, 0.3214180387503654, 0.934369211468702], 
             UndirectedEdge[182, 208] -> 
             RGBColor[
              0.2681228139523549, 0.39914445580516655`, 0.9385805696512048], 
             UndirectedEdge[10, 391] -> 
             RGBColor[
              0.8353894701660223, 0.27302455222656513`, 0.18152230263865984`],
              UndirectedEdge[284, 366] -> 
             RGBColor[
              0.8665824589296481, 0.8923925729410807, 0.7434186835178305], 
             UndirectedEdge[154, 387] -> 
             RGBColor[
              0.18595738695423472`, 0.312783382441179, 0.9339013701365182], 
             UndirectedEdge[135, 363] -> 
             RGBColor[
              0.3549405295448861, 0.4818533796872159, 0.9438374745743816], 
             UndirectedEdge[37, 269] -> 
             RGBColor[
              0.3188674209826161, 0.4483513791388215, 0.9416215783296149], 
             UndirectedEdge[201, 281] -> 
             RGBColor[
              0.5322326354554701, 0.6292900699565726, 0.956972433359562], 
             UndirectedEdge[302, 377] -> 
             RGBColor[
              0.22469777382228445`, 0.35350198532189486`, 0.9361075778573873],
              UndirectedEdge[179, 286] -> 
             RGBColor[
              0.2740282991513247, 0.4041960245612692, 0.9389591857364195], 
             UndirectedEdge[108, 325] -> 
             RGBColor[
              0.2723177927173417, 0.4035536444641835, 0.9388194674859559], 
             UndirectedEdge[279, 299] -> 
             RGBColor[
              0.19371330684929777`, 0.320935346004614, 0.9343430583006869], 
             UndirectedEdge[196, 332] -> 
             RGBColor[
              0.8265781466798748, 0.38475667486549425`, 0.4381203947409763], 
             UndirectedEdge[31, 224] -> 
             RGBColor[
              0.7410029688449329, 0.7954456814088879, 0.9320732118445416], 
             UndirectedEdge[200, 296] -> 
             RGBColor[
              0.1865617818736295, 0.3134186398223141, 0.9339357895330556], 
             UndirectedEdge[170, 221] -> 
             RGBColor[
              0.30270787399814014`, 0.42984035374028506`, 0.9407572019749026],
              UndirectedEdge[198, 206] -> 
             RGBColor[
              0.6288429856334741, 0.7061140055023541, 0.9660410068543737], 
             UndirectedEdge[36, 361] -> 
             RGBColor[
              0.32761397052464425`, 0.4523511904771868, 0.9423098359853219], 
             UndirectedEdge[132, 180] -> 
             RGBColor[
              0.1906491777676344, 0.3177147520627811, 0.9341685606824588], 
             UndirectedEdge[127, 312] -> 
             RGBColor[
              0.44359264480187605`, 0.5560735292696781, 0.9501952628642483], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.37498442055197767`, 0.49560326154572176`, 0.9453825139194686],
              UndirectedEdge[67, 75] -> 
             RGBColor[
              0.1806580838475214, 0.3072134788808002, 0.9335995826642074], 
             UndirectedEdge[110, 287] -> 
             RGBColor[
              0.8292002229414056, 0.38461576511277085`, 0.438091178290953], 
             UndirectedEdge[88, 233] -> 
             RGBColor[
              0.7003634497191511, 0.7623012578281982, 0.9418757273882692], 
             UndirectedEdge[168, 216] -> 
             RGBColor[
              0.20689038450304525`, 0.3347852900936806, 0.9350934733793282], 
             UndirectedEdge[1, 291] -> 
             RGBColor[
              0.1886369117353484, 0.31559973287781307`, 0.934053965108801], 
             UndirectedEdge[115, 214] -> 
             RGBColor[
              0.917014626987943, 0.7014084006737106, 0.2517091579831441], 
             UndirectedEdge[233, 256] -> 
             RGBColor[
              0.9813174831621745, 0.9842395002462874, 0.8561565043579783], 
             UndirectedEdge[4, 252] -> 
             RGBColor[
              0.20339315185029538`, 0.3311094768382833, 0.9348943111534462], 
             UndirectedEdge[91, 399] -> 
             RGBColor[
              0.4759758631677278, 0.5829069233744436, 0.9525944899971995], 
             UndirectedEdge[76, 269] -> 
             RGBColor[
              0.3181691701834686, 0.44761747327725976`, 0.9415818139795731], 
             UndirectedEdge[91, 172] -> 
             RGBColor[
              0.48609962486048197`, 0.5916756169176496, 0.9532395671401708], 
             UndirectedEdge[165, 184] -> 
             RGBColor[
              0.21954677082243013`, 0.3480879545765947, 0.9358142358567716], 
             UndirectedEdge[60, 139] -> 
             RGBColor[
              0.506983675095762, 0.6054995726195224, 0.9561122679612462], 
             UndirectedEdge[356, 359] -> 
             RGBColor[
              0.6355366085129286, 0.7076527365125309, 0.9596545999486343], 
             UndirectedEdge[228, 305] -> 
             RGBColor[
              0.26103370837156087`, 0.39169335636449776`, 0.9381768555757705],
              UndirectedEdge[141, 209] -> 
             RGBColor[
              0.3104061832925851, 0.4392395615986554, 0.9411477244574119], 
             UndirectedEdge[171, 348] -> 
             RGBColor[
              0.1945787269842331, 0.32184495743723673`, 0.934392342697097], 
             UndirectedEdge[10, 60] -> 
             RGBColor[
              0.7976526644820038, 0.4778635602594288, 0.44966349300497443`], 
             UndirectedEdge[234, 298] -> 
             RGBColor[
              0.22620097648238727`, 0.3550819466262163, 0.936193183025091], 
             UndirectedEdge[323, 388] -> 
             RGBColor[
              0.34570167664203966`, 0.47034107110967827`, 0.9433773042073184],
              UndirectedEdge[294, 329] -> 
             RGBColor[
              0.23603593247132534`, 0.36541910894281576`, 0.9367532692191475],
              UndirectedEdge[211, 238] -> 
             RGBColor[
              0.21668562529693003`, 0.34508070922219014`, 0.9356512978517798],
              UndirectedEdge[31, 99] -> 
             RGBColor[
              0.9432122400933031, 0.9562926111989585, 0.9505366840460105], 
             UndirectedEdge[111, 319] -> 
             RGBColor[
              0.8285561841710127, 0.22050092170390542`, 0.174978740252746], 
             UndirectedEdge[258, 394] -> 
             RGBColor[
              0.29763886748570073`, 0.42564849142765915`, 0.9404269355800592],
              UndirectedEdge[101, 364] -> 
             RGBColor[
              0.8764286119416923, 0.5191942190745097, 0.21806748042320684`], 
             UndirectedEdge[225, 349] -> 
             RGBColor[
              0.2034483891040132, 0.3311675346941849, 0.9348974568333293], 
             UndirectedEdge[118, 386] -> 
             RGBColor[
              0.34968714140668505`, 0.4773031589248714, 0.9435027333276041], 
             UndirectedEdge[95, 326] -> 
             RGBColor[
              0.24440137831360023`, 0.3742117229229475, 0.9372296689842969], 
             UndirectedEdge[228, 382] -> 
             RGBColor[
              0.27305197131929326`, 0.4030910170101112, 0.9389064714836659], 
             UndirectedEdge[120, 255] -> 
             RGBColor[
              0.39336824955180094`, 0.5151375393238391, 0.9462860549129236], 
             UndirectedEdge[222, 292] -> 
             RGBColor[
              0.863357086910216, 0.42156639939863494`, 0.43342593709910204`], 
             UndirectedEdge[325, 397] -> 
             RGBColor[
              0.3012257827964342, 0.4288125621703911, 0.9406533939002841], 
             UndirectedEdge[155, 299] -> 
             RGBColor[
              0.1871446834102983, 0.31403130629544507`, 0.9339689849132433], 
             UndirectedEdge[17, 99] -> 
             RGBColor[
              0.8524964894376759, 0.4506925466333933, 0.4462583138303914], 
             UndirectedEdge[60, 105] -> 
             RGBColor[
              0.8461630434103341, 0.8796208819742317, 0.932337896398757], 
             UndirectedEdge[229, 340] -> 
             RGBColor[
              0.23465687622616624`, 0.36396963339193744`, 0.9366747340061166],
              UndirectedEdge[297, 375] -> 
             RGBColor[
              0.2496778587950193, 0.3797576384571041, 0.9375301567418605], 
             UndirectedEdge[155, 249] -> 
             RGBColor[
              0.18476081976801417`, 0.3115257144617197, 0.9338332274054255], 
             UndirectedEdge[143, 348] -> 
             RGBColor[
              0.20000377872339242`, 0.3275470307832401, 0.9347012913679973], 
             UndirectedEdge[175, 294] -> 
             RGBColor[
              0.19993479870238595`, 0.3274745284075764, 0.9346973630578478], 
             UndirectedEdge[19, 181] -> 
             RGBColor[
              0.19581756515250187`, 0.3231470548989638, 0.9344628926980831], 
             UndirectedEdge[153, 294] -> 
             RGBColor[
              0.20769214048678164`, 0.33562798646685293`, 0.9351391321965103],
              UndirectedEdge[68, 376] -> 
             RGBColor[
              0.5538916735521564, 0.639355835105775, 0.9612276966528428], 
             UndirectedEdge[317, 354] -> 
             RGBColor[
              0.19230267119241712`, 0.319452678489766, 0.934262724686876], 
             UndirectedEdge[2, 254] -> 
             RGBColor[
              0.19445154659843222`, 0.32171128278805783`, 0.9343850999622723],
              UndirectedEdge[243, 311] -> 
             RGBColor[
              0.21699506567726595`, 0.34540595068157653`, 0.9356689200236639],
              UndirectedEdge[23, 143] -> 
             RGBColor[
              0.20541157212716055`, 0.3332309645245057, 0.9350092572022285], 
             UndirectedEdge[20, 64] -> 
             RGBColor[
              0.6886054780275248, 0.7470570557801346, 0.690028677840299], 
             UndirectedEdge[75, 296] -> 
             RGBColor[
              0.18049305546872535`, 0.30704002359128196`, 0.9335901845421726],
              UndirectedEdge[146, 227] -> 
             RGBColor[
              0.2365605733145403, 0.3659705397331854, 0.936783146739032], 
             UndirectedEdge[160, 238] -> 
             RGBColor[
              0.19808883610787825`, 0.32553430467996036`, 0.9345922382189475],
              UndirectedEdge[75, 178] -> 
             RGBColor[
              0.18245868691760933`, 0.30910602687229105`, 0.9337021243452953],
              UndirectedEdge[95, 166] -> 
             RGBColor[
              0.24620280791930751`, 0.37610513965577974`, 0.9373322577353658],
              UndirectedEdge[25, 309] -> 
             RGBColor[
              0.5306642654095335, 0.6265873056000757, 0.957441478589943], 
             UndirectedEdge[166, 326] -> 
             RGBColor[
              0.24337300372818133`, 0.3731308360309576, 0.9371711045730012], 
             UndirectedEdge[158, 308] -> 
             RGBColor[
              0.20199405614850408`, 0.32963893854790965`, 0.9348146347230057],
              UndirectedEdge[229, 343] -> 
             RGBColor[
              0.1993208104479567, 0.32682918782306747`, 0.9346623973350723], 
             UndirectedEdge[229, 294] -> 
             RGBColor[
              0.20382733943636777`, 0.33156583552032837`, 0.9349190374941501],
              UndirectedEdge[64, 257] -> 
             RGBColor[
              0.9810027572631417, 0.9816315939147817, 0.6854880311912166], 
             UndirectedEdge[56, 65] -> 
             RGBColor[
              0.4474461015886463, 0.5602099797974611, 0.9502200964459863], 
             UndirectedEdge[170, 192] -> 
             RGBColor[
              0.2468852126322833, 0.37682239027607506`, 0.9373711196742425], 
             UndirectedEdge[133, 347] -> 
             RGBColor[
              0.18386468807739512`, 0.3105838232368483, 0.9337821940313528], 
             UndirectedEdge[223, 393] -> 
             RGBColor[
              0.8134681369515452, 0.5633203916020985, 0.4604670120466483], 
             UndirectedEdge[116, 338] -> 
             RGBColor[
              0.22507866009155236`, 0.35390232094047974`, 0.9361292687669514],
              UndirectedEdge[32, 71] -> 
             RGBColor[
              0.8709138694072857, 0.43658126909692513`, 0.4242157364462195], 
             UndirectedEdge[95, 361] -> 
             RGBColor[
              0.32840262007179855`, 0.45318011115451534`, 0.9423547484103298],
              UndirectedEdge[247, 292] -> 
             RGBColor[
              0.8180564581257688, 0.1397954263108694, 0.1649241907340759], 
             UndirectedEdge[337, 391] -> 
             RGBColor[
              0.8658158827122152, 0.4268349889246108, 0.4305754527619263], 
             UndirectedEdge[181, 238] -> 
             RGBColor[
              0.1965022388034804, 0.3238666903169589, 0.9345018838496224], 
             UndirectedEdge[97, 246] -> 
             RGBColor[
              0.2576631748496625, 0.38815071192881434`, 0.9379849086779559], 
             UndirectedEdge[62, 247] -> 
             RGBColor[
              0.8754937811360735, 0.41981207760671324`, 0.37132290064454676`],
              UndirectedEdge[207, 280] -> 
             RGBColor[
              0.200223112625469, 0.32777756462089525`, 0.9347137821092452], 
             UndirectedEdge[145, 221] -> 
             RGBColor[
              0.3098924284635012, 0.43739177601044266`, 0.941166351723109], 
             UndirectedEdge[10, 334] -> 
             RGBColor[
              0.8820485949422373, 0.5133285113038917, 0.2258290855797634], 
             UndirectedEdge[25, 78] -> 
             RGBColor[
              0.29221377727191306`, 0.41936050438489303`, 0.9401394364080135],
              UndirectedEdge[46, 139] -> 
             RGBColor[
              0.5562400144756487, 0.6439789993051345, 0.961021679543971], 
             UndirectedEdge[224, 383] -> 
             RGBColor[
              0.42803255257249384`, 0.5439556499014909, 0.9488281562852744], 
             UndirectedEdge[138, 164] -> 
             RGBColor[
              0.2519489800003536, 0.38214473084131173`, 0.9376594937346815], 
             UndirectedEdge[53, 93] -> 
             RGBColor[
              0.37256678589576175`, 0.4971203570169409, 0.9449606040427729], 
             UndirectedEdge[31, 199] -> 
             RGBColor[
              0.9864970705564884, 0.9886842059127192, 0.8734420155476115], 
             UndirectedEdge[98, 342] -> 
             RGBColor[
              0.1898214409282245, 0.31684474816301444`, 0.9341214222939813], 
             UndirectedEdge[141, 304] -> 
             RGBColor[
              0.31901866548224, 0.4482918264428926, 0.9416381925770871], 
             UndirectedEdge[32, 105] -> 
             RGBColor[
              0.8761133411469468, 0.4403360535274061, 0.40990740127695935`], 
             UndirectedEdge[216, 329] -> 
             RGBColor[
              0.23907766788565177`, 0.368616165720437, 0.936926491551149], 
             UndirectedEdge[164, 264] -> 
             RGBColor[
              0.23748584663754294`, 0.36694306066137816`, 0.9368358396859577],
              UndirectedEdge[118, 196] -> 
             RGBColor[
              0.6007859963931654, 0.6812853787799371, 0.9644958808837701], 
             UndirectedEdge[75, 398] -> 
             RGBColor[
              0.18135843161484838`, 0.30794958878887396`, 0.9336394664334849],
              UndirectedEdge[45, 48] -> 
             RGBColor[
              0.2238300988639671, 0.3525900039269335, 0.9360581650521211], 
             UndirectedEdge[248, 275] -> 
             RGBColor[
              0.18852850716525682`, 0.3154857928014001, 0.9340477916289045], 
             UndirectedEdge[200, 347] -> 
             RGBColor[
              0.1891857716327594, 0.31617661942971953`, 0.9340852218679931], 
             UndirectedEdge[33, 58] -> 
             RGBColor[
              0.21989646734481127`, 0.3484555077936574, 0.9358341505563915], 
             UndirectedEdge[134, 240] -> 
             RGBColor[
              0.17922390736570504`, 0.3057060684663703, 0.9335179084352418], 
             UndirectedEdge[267, 344] -> 
             RGBColor[
              0.1945632673718405, 0.321828708404416, 0.9343914622950418], 
             UndirectedEdge[141, 286] -> 
             RGBColor[
              0.3385051144347327, 0.4676178491867835, 0.9427902244568296], 
             UndirectedEdge[33, 209] -> 
             RGBColor[
              0.25581747523043485`, 0.38621076460489123`, 0.9378797988151089],
              UndirectedEdge[47, 155] -> 
             RGBColor[
              0.18345196765990118`, 0.3101500279100763, 0.9337586902141416], 
             UndirectedEdge[153, 229] -> 
             RGBColor[
              0.2017865527982215, 0.3294208393702904, 0.934802817714181], 
             UndirectedEdge[64, 161] -> 
             RGBColor[
              0.9360657953387055, 0.766239407790421, 0.32776561052681985`], 
             UndirectedEdge[3, 293] -> 
             RGBColor[
              0.2751725873267546, 0.40605645004464963`, 0.939000269414517], 
             UndirectedEdge[133, 178] -> 
             RGBColor[
              0.18320632976714918`, 0.309891846910452, 0.9337447014995381], 
             UndirectedEdge[113, 162] -> 
             RGBColor[
              0.19047273002269705`, 0.31752929429541876`, 0.9341585122444157],
              UndirectedEdge[313, 358] -> 
             RGBColor[
              0.28110733593194254`, 0.4127920116719563, 0.9393200189690635], 
             UndirectedEdge[259, 292] -> 
             RGBColor[
              0.8448027967443577, 0.4070362632797625, 0.4408283690918966], 
             UndirectedEdge[4, 165] -> 
             RGBColor[
              0.21319278532882907`, 0.3414095129568713, 0.9354523857827901], 
             UndirectedEdge[247, 385] -> 
             RGBColor[
              0.8763650244456923, 0.41967521212315095`, 0.3207468068561434], 
             UndirectedEdge[38, 243] -> 
             RGBColor[
              0.24505985490147014`, 0.37490382356662577`, 0.9372671682518474],
              UndirectedEdge[265, 381] -> 
             RGBColor[
              0.19417265233719494`, 0.3214181472365799, 0.9343692173466818], 
             UndirectedEdge[15, 369] -> 
             RGBColor[
              0.18126767848005537`, 0.30785420149012543`, 0.9336342981767156],
              UndirectedEdge[30, 358] -> 
             RGBColor[
              0.2391480425105603, 0.3686901339132248, 0.9369304992819277], 
             UndirectedEdge[133, 330] -> 
             RGBColor[
              0.1860526851696524, 0.3128835469078388, 0.9339067972289052], 
             UndirectedEdge[223, 292] -> 
             RGBColor[
              0.8459748454234086, 0.3526869418187919, 0.19159224569181096`], 
             UndirectedEdge[44, 326] -> 
             RGBColor[
              0.2349425006851034, 0.3642698428079171, 0.9366909998965096], 
             UndirectedEdge[123, 356] -> 
             RGBColor[
              0.8772330619315765, 0.5414195340546395, 0.45175270578871085`], 
             UndirectedEdge[35, 154] -> 
             RGBColor[
              0.18823624142486384`, 0.31517860297752887`, 0.9340311475273575],
              UndirectedEdge[146, 151] -> 
             RGBColor[
              0.20337080686080378`, 0.3310859908375735, 0.9348930386393511], 
             UndirectedEdge[111, 287] -> 
             RGBColor[
              0.8235143897467309, 0.18174748043047098`, 0.17015071221816136`],
              UndirectedEdge[42, 133] -> 
             RGBColor[
              0.1836453052262827, 0.310353237950653, 0.9337697005025297], 
             UndirectedEdge[40, 103] -> 
             RGBColor[
              0.19411926264855695`, 0.32136203128871965`, 0.9343661768828968],
              UndirectedEdge[219, 260] -> 
             RGBColor[
              0.1839290162486566, 0.31065143622348573`, 0.9337858574255411], 
             UndirectedEdge[151, 186] -> 
             RGBColor[
              0.20709670832782653`, 0.33500214951521173`, 0.9351052232159208],
              UndirectedEdge[8, 76] -> 
             RGBColor[
              0.26926683315553557`, 0.4003468925227164, 0.9386457198524012], 
             UndirectedEdge[124, 167] -> 
             RGBColor[
              0.23121257205082407`, 0.360349451322155, 0.9364785859787222], 
             UndirectedEdge[162, 291] -> 
             RGBColor[
              0.1953787311658639, 0.32268581255532547`, 0.9344379017517408], 
             UndirectedEdge[242, 255] -> 
             RGBColor[
              0.3572936731332409, 0.48389155439101317`, 0.9439874148030284], 
             UndirectedEdge[182, 323] -> 
             RGBColor[
              0.3312247462121247, 0.45512489933743366`, 0.9425528644360341], 
             UndirectedEdge[138, 149] -> 
             RGBColor[
              0.2496156992329207, 0.3796923048161946, 0.9375266168467558], 
             UndirectedEdge[199, 353] -> 
             RGBColor[
              0.9909977762454061, 0.988800838647677, 0.6720451430779383], 
             UndirectedEdge[34, 381] -> 
             RGBColor[
              0.18614322275265005`, 0.3129787076479837, 0.9339119532103186], 
             UndirectedEdge[148, 305] -> 
             RGBColor[
              0.2773062230664102, 0.4087968010458064, 0.939103551214614], 
             UndirectedEdge[97, 383] -> 
             RGBColor[
              0.32847115554353346`, 0.45799116005281093`, 0.9421851328952267],
              UndirectedEdge[154, 207] -> 
             RGBColor[
              0.18894498275511917`, 0.315923535052423, 0.9340715092976267], 
             UndirectedEdge[272, 375] -> 
             RGBColor[
              0.1997235147350348, 0.3272524555617131, 0.9346853307484737], 
             UndirectedEdge[25, 323] -> 
             RGBColor[
              0.3922918508728892, 0.5142052168895364, 0.9462174677409253], 
             UndirectedEdge[236, 334] -> 
             RGBColor[
              0.7349237676396162, 0.7451154652166593, 0.6272347577119612], 
             UndirectedEdge[23, 346] -> 
             RGBColor[
              0.20767293699657277`, 0.3356078023810718, 0.935138038586152], 
             UndirectedEdge[23, 151] -> 
             RGBColor[
              0.20976599730073225`, 0.3378077414684315, 0.9352572352740687], 
             UndirectedEdge[250, 381] -> 
             RGBColor[
              0.19153445496524343`, 0.31864523452728444`, 0.9342189759092124],
              UndirectedEdge[230, 264] -> 
             RGBColor[
              0.2405521506109405, 0.3701659405523198, 0.9370104611610526], 
             UndirectedEdge[60, 68] -> 
             RGBColor[
              0.7643140770585692, 0.8158203298412934, 0.9771398668713851], 
             UndirectedEdge[50, 258] -> 
             RGBColor[
              0.23439017041921995`, 0.3636893086787121, 0.9366595455049669], 
             UndirectedEdge[121, 298] -> 
             RGBColor[
              0.2245949434093795, 0.353393904038107, 0.9361017218174963], 
             UndirectedEdge[95, 382] -> 
             RGBColor[
              0.2846635750266093, 0.4152955487246973, 0.9395677351369693], 
             UndirectedEdge[42, 200] -> 
             RGBColor[
              0.18896638878164698`, 0.3159460341435242, 0.9340727283391701], 
             UndirectedEdge[254, 314] -> 
             RGBColor[
              0.1849157269952969, 0.31168853177927935`, 0.9338420491428545], 
             UndirectedEdge[95, 305] -> 
             RGBColor[
              0.2726453120788769, 0.4038978880790839, 0.9388381192290738], 
             UndirectedEdge[321, 381] -> 
             RGBColor[
              0.18695109985789307`, 0.313827837707961, 0.9339579606163151], 
             UndirectedEdge[116, 209] -> 
             RGBColor[
              0.2525333735524159, 0.38275896551722044`, 0.9376927740829386], 
             UndirectedEdge[364, 366] -> 
             RGBColor[
              0.9573192010017704, 0.856958801294309, 0.38384804144330753`], 
             UndirectedEdge[58, 156] -> 
             RGBColor[
              0.19753761270804981`, 0.3249549339371585, 0.9345608468617892], 
             UndirectedEdge[118, 179] -> 
             RGBColor[
              0.29213029064248475`, 0.4198750597583651, 0.9401126286272736], 
             UndirectedEdge[149, 328] -> 
             RGBColor[
              0.22083892747976266`, 0.3494460931509151, 0.9358878222668322], 
             UndirectedEdge[215, 227] -> 
             RGBColor[
              0.4900314069116405, 0.5878102265694376, 0.9551265080130549], 
             UndirectedEdge[70, 177] -> 
             RGBColor[
              0.1891804395703839, 0.31617101509409057`, 0.9340849182149289], 
             UndirectedEdge[383, 393] -> 
             RGBColor[
              0.5401446576878393, 0.6337537414941011, 0.9584878557690468], 
             UndirectedEdge[14, 201] -> 
             RGBColor[
              0.5021816905325309, 0.6032614518687315, 0.9550576137220795], 
             UndirectedEdge[5, 368] -> 
             RGBColor[
              0.18532540128789612`, 0.31211912543565157`, 0.9338653794877592],
              UndirectedEdge[214, 310] -> 
             RGBColor[
              0.8439849195878139, 0.31758034175677613`, 0.18891093519726984`],
              UndirectedEdge[35, 280] -> 
             RGBColor[
              0.19951437129521365`, 0.3270326325460011, 0.9346734203389759], 
             UndirectedEdge[243, 275] -> 
             RGBColor[
              0.21276908993785693`, 0.3409641822371201, 0.9354282569570754], 
             UndirectedEdge[131, 391] -> 
             RGBColor[
              0.8181931112315055, 0.3892593691956639, 0.4387086159715671], 
             UndirectedEdge[2, 314] -> 
             RGBColor[
              0.19228958849813182`, 0.3194389277485814, 0.9342619796467905], 
             UndirectedEdge[282, 361] -> 
             RGBColor[
              0.36229879969604784`, 0.48822674345474093`, 0.9443063370417508],
              UndirectedEdge[110, 269] -> 
             RGBColor[
              0.6031830035578256, 0.6830576186116337, 0.9647885304899277], 
             UndirectedEdge[193, 360] -> 
             RGBColor[
              0.7503418220523833, 0.8050370370474327, 0.9757122305140027], 
             UndirectedEdge[71, 400] -> 
             RGBColor[
              0.8713114373566356, 0.4396371505710155, 0.42459644796350593`], 
             UndirectedEdge[110, 117] -> 
             RGBColor[
              0.7057471364084966, 0.7690367194392469, 0.9721131675946504], 
             UndirectedEdge[170, 351] -> 
             RGBColor[
              0.27252940237618284`, 0.4037012784354327, 0.938834256448926], 
             UndirectedEdge[121, 200] -> 
             RGBColor[
              0.2188856606362972, 0.3473930858541622, 0.9357765866096961], 
             UndirectedEdge[38, 383] -> 
             RGBColor[
              0.3085216567311646, 0.43702297192973105`, 0.9410490384505009], 
             UndirectedEdge[172, 256] -> 
             RGBColor[
              0.6859636429526801, 0.7471589426256584, 0.8613086090450968], 
             UndirectedEdge[127, 258] -> 
             RGBColor[
              0.2885106861095953, 0.4177421195154126, 0.9398452959345076], 
             UndirectedEdge[25, 388] -> 
             RGBColor[
              0.31737166199215083`, 0.44580303632788293`, 0.9415721407250759],
              UndirectedEdge[51, 277] -> 
             RGBColor[
              0.19316166908716753`, 0.3203555397407608, 0.9343116433462084], 
             UndirectedEdge[85, 379] -> 
             RGBColor[
              0.18217848519657132`, 0.30881151709766497`, 0.9336861672718034],
              UndirectedEdge[267, 306] -> 
             RGBColor[
              0.20993199303624877`, 0.33798221351119695`, 0.9352666884856375],
              UndirectedEdge[176, 298] -> 
             RGBColor[
              0.19583511598337588`, 0.32316550193499927`, 0.9344638921919373],
              UndirectedEdge[269, 323] -> 
             RGBColor[
              0.38701260190710624`, 0.5096325967781434, 0.9458810786650822], 
             UndirectedEdge[21, 180] -> 
             RGBColor[
              0.19254611619106632`, 0.3197085546186507, 0.9342765885194044], 
             UndirectedEdge[36, 228] -> 
             RGBColor[
              0.23483092925025606`, 0.364152574155855, 0.9366846460683501], 
             UndirectedEdge[74, 116] -> 
             RGBColor[
              0.244277527259818, 0.37408154761281204`, 0.9372226158500052], 
             UndirectedEdge[3, 188] -> 
             RGBColor[
              0.25601232241971317`, 0.38641556135484806`, 0.9378908950742876],
              UndirectedEdge[69, 394] -> 
             RGBColor[
              0.46522152575946735`, 0.5741285322522734, 0.9517610033724258], 
             UndirectedEdge[37, 395] -> 
             RGBColor[
              0.3615061899414258, 0.48528293772410147`, 0.9443384829836874], 
             UndirectedEdge[172, 194] -> 
             RGBColor[
              0.41753162873264527`, 0.5360090287080477, 0.9478416433121417], 
             UndirectedEdge[59, 264] -> 
             RGBColor[
              0.2381256499847355, 0.3676155345451527, 0.9368722755400762], 
             UndirectedEdge[28, 369] -> 
             RGBColor[
              0.1860007123494566, 0.3128289201785459, 0.9339038374536819], 
             UndirectedEdge[130, 344] -> 
             RGBColor[
              0.20361295849173341`, 0.3313405075549807, 0.9349068288165013], 
             UndirectedEdge[29, 270] -> 
             RGBColor[
              0.19689305639497057`, 0.3242774643848816, 0.9345241403332949], 
             UndirectedEdge[41, 48] -> 
             RGBColor[
              0.2013669879321785, 0.3289798500941302, 0.9347789241157504], 
             UndirectedEdge[12, 124] -> 
             RGBColor[
              0.23470207361547668`, 0.3640171387137828, 0.9366773079305742], 
             UndirectedEdge[61, 95] -> 
             RGBColor[
              0.23224869997063102`, 0.3614384874601766, 0.9365375919309413], 
             UndirectedEdge[213, 306] -> 
             RGBColor[
              0.2738566580723743, 0.4036300780572341, 0.9389635275699348], 
             UndirectedEdge[63, 295] -> 
             RGBColor[
              0.1876127220363632, 0.31452324456680214`, 0.9339956390205967], 
             UndirectedEdge[302, 367] -> 
             RGBColor[
              0.19039724530537674`, 0.31744995507150764`, 0.934154213501434], 
             UndirectedEdge[140, 331] -> 
             RGBColor[
              0.3236577561982914, 0.4484913535850291, 0.9420736097220124], 
             UndirectedEdge[92, 354] -> 
             RGBColor[
              0.20023581918524017`, 0.32779092002085713`, 0.9347145057290265],
              UndirectedEdge[151, 311] -> 
             RGBColor[
              0.20510424418118295`, 0.33290794336756596`, 0.934991755330356], 
             UndirectedEdge[299, 371] -> 
             RGBColor[
              0.18421145049276366`, 0.3109482925214076, 0.933801941637919], 
             UndirectedEdge[140, 389] -> 
             RGBColor[
              0.6997349672161455, 0.7570392468690857, 0.7200011772159544], 
             UndirectedEdge[176, 205] -> 
             RGBColor[
              0.18567915281687453`, 0.3124909407217502, 0.9338855251140061], 
             UndirectedEdge[152, 179] -> 
             RGBColor[
              0.2138285336364696, 0.3420777247369723, 0.935488590708405], 
             UndirectedEdge[142, 293] -> 
             RGBColor[
              0.3941446854590191, 0.5152441502355233, 0.946491888259698], 
             UndirectedEdge[105, 259] -> 
             RGBColor[
              0.9403634558512834, 0.9538207185775788, 0.9415651020124101], 
             UndirectedEdge[274, 318] -> 
             RGBColor[
              0.20829816061759315`, 0.33626495204823137`, 0.9351736441464337],
              UndirectedEdge[231, 369] -> 
             RGBColor[
              0.1858060573218873, 0.312624325402729, 0.9338927521378282], 
             UndirectedEdge[151, 348] -> 
             RGBColor[
              0.20435820389696413`, 0.332123807727166, 0.9349492694398375], 
             UndirectedEdge[147, 231] -> 
             RGBColor[
              0.2192108871052112, 0.34773491949353985`, 0.9357951077759714], 
             UndirectedEdge[66, 354] -> 
             RGBColor[
              0.19611420939972474`, 0.3234588468111266, 0.9344797861491166], 
             UndirectedEdge[24, 65] -> 
             RGBColor[
              0.3183379395633406, 0.44565996035968214`, 0.9416695943018074], 
             UndirectedEdge[42, 347] -> 
             RGBColor[
              0.18410501336322643`, 0.3108364203497602, 0.9337958802008515], 
             UndirectedEdge[52, 129] -> 
             RGBColor[
              0.8758889946434687, 0.4296602011342544, 0.38811658814132355`], 
             UndirectedEdge[3, 7] -> 
             RGBColor[
              0.24558195815549755`, 0.37545258718986685`, 0.9372969012597816],
              UndirectedEdge[156, 352] -> 
             RGBColor[
              0.19412861826228733`, 0.32137186463193046`, 0.9343667096712585],
              UndirectedEdge[229, 329] -> 
             RGBColor[
              0.2301303447827652, 0.3592119618462532, 0.9364169547368181], 
             UndirectedEdge[80, 187] -> 
             RGBColor[
              0.20972687217078761`, 0.3377666184761832, 0.9352550071557988], 
             UndirectedEdge[247, 362] -> 
             RGBColor[
              0.808649465228358, 0.36847454946527913`, 0.43610132085825937`], 
             UndirectedEdge[43, 321] -> 
             RGBColor[
              0.1896253217591911, 0.31663861448168684`, 0.9341102535974373], 
             UndirectedEdge[84, 270] -> 
             RGBColor[
              0.21111604747539212`, 0.339226729800124, 0.9353341186342953], 
             UndirectedEdge[318, 322] -> 
             RGBColor[
              0.20428384988578308`, 0.3320456569470981, 0.9349450350888977], 
             UndirectedEdge[218, 276] -> 
             RGBColor[
              0.46966080217049366`, 0.5783141439540027, 0.951949779691809], 
             UndirectedEdge[201, 303] -> 
             RGBColor[
              0.7798220611835203, 0.6750115727481525, 0.6002603969131654], 
             UndirectedEdge[283, 364] -> 
             RGBColor[
              0.9266304431740131, 0.7468211866800847, 0.25982333625421017`], 
             UndirectedEdge[65, 340] -> 
             RGBColor[
              0.3239430587205376, 0.45155129597897675`, 0.941988797545779], 
             UndirectedEdge[83, 214] -> 
             RGBColor[
              0.9149531561640245, 0.7530286606028909, 0.5942676397554747], 
             UndirectedEdge[124, 157] -> 
             RGBColor[
              0.2367400113323198, 0.3661591404668991, 0.9367933654686897], 
             UndirectedEdge[311, 344] -> 
             RGBColor[
              0.19707934099750435`, 0.3244732613132706, 0.9345347489658259], 
             UndirectedEdge[190, 226] -> 
             RGBColor[
              0.20202864183193292`, 0.3296752902940524, 0.9348166043265123], 
             UndirectedEdge[380, 389] -> 
             RGBColor[
              0.8567527280963826, 0.8845935052040448, 0.7328269740889874], 
             UndirectedEdge[124, 179] -> 
             RGBColor[
              0.22671592710196903`, 0.3556231923771518, 0.9362225087010749], 
             UndirectedEdge[199, 215] -> 
             RGBColor[
              0.8474033618771311, 0.8799586173228249, 0.9038397390676208], 
             UndirectedEdge[146, 267] -> 
             RGBColor[
              0.19834666787727806`, 0.32580530221707793`, 0.9346069213567869],
              UndirectedEdge[109, 249] -> 
             RGBColor[
              0.18318613987214505`, 0.3098706260506894, 0.9337435517148859], 
             UndirectedEdge[36, 61] -> 
             RGBColor[
              0.23146005042347673`, 0.36060956678284806`, 0.9364926795059334],
              UndirectedEdge[13, 232] -> 
             RGBColor[
              0.20186143048066912`, 0.3294995405620621, 0.9348070818874247], 
             UndirectedEdge[38, 119] -> 
             RGBColor[
              0.249257790450226, 0.37931611999285497`, 0.9375062344710599], 
             UndirectedEdge[91, 256] -> 
             RGBColor[
              0.792439933021371, 0.8356021745450866, 0.869137935086701], 
             UndirectedEdge[6, 69] -> 
             RGBColor[
              0.7494906190968638, 0.8040199624425932, 0.9761664746556911], 
             UndirectedEdge[90, 97] -> 
             RGBColor[
              0.2570968896215246, 0.3875555102494842, 0.9379526595719574], 
             UndirectedEdge[233, 257] -> 
             RGBColor[
              0.9698756400386146, 0.9770538821816868, 0.9358768631099392], 
             UndirectedEdge[66, 119] -> 
             RGBColor[
              0.21795851687042844`, 0.3464185989719241, 0.9357237871438162], 
             UndirectedEdge[33, 116] -> 
             RGBColor[
              0.24330530459768918`, 0.3730596799524376, 0.9371672492076716], 
             UndirectedEdge[335, 349] -> 
             RGBColor[
              0.19833951424086566`, 0.32579778329164166`, 0.9346065139677762],
              UndirectedEdge[165, 274] -> 
             RGBColor[
              0.21434019517096867`, 0.34261551345094576`, 0.9355177290758593],
              UndirectedEdge[95, 169] -> 
             RGBColor[
              0.3522449518778092, 0.4737241407933565, 0.9439035250794346], 
             UndirectedEdge[135, 259] -> 
             RGBColor[
              0.6153899363844033, 0.6921704499321857, 0.9662385558858466], 
             UndirectedEdge[93, 273] -> 
             RGBColor[
              0.433287316679902, 0.5477930013754455, 0.949360282412582], 
             UndirectedEdge[89, 263] -> 
             RGBColor[
              0.2670289628172794, 0.39799474890803455`, 0.93851827644727], 
             UndirectedEdge[71, 289] -> 
             RGBColor[
              0.7219591346417744, 0.780476707159252, 0.9439593282102003], 
             UndirectedEdge[32, 215] -> 
             RGBColor[
              0.7830362347155908, 0.3677084343750351, 0.4359392691571047], 
             UndirectedEdge[8, 239] -> 
             RGBColor[
              0.3813679879787836, 0.49836836108207505`, 0.9461050956090218], 
             UndirectedEdge[110, 111] -> 
             RGBColor[
              0.8353956126881364, 0.4322362455432418, 0.4440238905091144], 
             UndirectedEdge[29, 162] -> 
             RGBColor[
              0.19056901057120365`, 0.3176304912564385, 0.9341639952792189], 
             UndirectedEdge[337, 353] -> 
             RGBColor[
              0.9751195109230872, 0.9777137367216755, 0.7327280786411184], 
             UndirectedEdge[306, 308] -> 
             RGBColor[
              0.2175738595337591, 0.3460142997224009, 0.9357018814775424], 
             UndirectedEdge[185, 190] -> 
             RGBColor[
              0.20235115482293997`, 0.33001427189610544`, 0.9348349709642347],
              UndirectedEdge[71, 385] -> 
             RGBColor[
              0.9820607295061435, 0.9836969405379016, 0.7849671104328407], 
             UndirectedEdge[146, 158] -> 
             RGBColor[
              0.1951348259562785, 0.3224294527155677, 0.9344240117108803], 
             UndirectedEdge[157, 386] -> 
             RGBColor[
              0.2943941268277438, 0.42368947103286164`, 0.9401890092515732], 
             UndirectedEdge[24, 124] -> 
             RGBColor[
              0.24340021238043813`, 0.3731594340496077, 0.9371726540654957], 
             UndirectedEdge[22, 74] -> 
             RGBColor[
              0.24528340650250224`, 0.37513879047330073`, 0.9372798991848111],
              UndirectedEdge[303, 385] -> 
             RGBColor[
              0.9441738208357854, 0.8008555462181073, 0.4334857922002555], 
             UndirectedEdge[130, 317] -> 
             RGBColor[
              0.20208377375464914`, 0.3297332374403929, 0.9348197440079504], 
             UndirectedEdge[73, 291] -> 
             RGBColor[
              0.19698615809912115`, 0.32437532017893284`, 0.9345294423376147],
              UndirectedEdge[241, 255] -> 
             RGBColor[
              0.32755009808125596`, 0.4555556663672059, 0.9421864088801596], 
             UndirectedEdge[385, 400] -> 
             RGBColor[
              0.8795493400594996, 0.44415125730687344`, 0.3237961110840954], 
             UndirectedEdge[130, 311] -> 
             RGBColor[
              0.20912979631755016`, 0.33713905389763504`, 0.9352210045692514],
              UndirectedEdge[143, 308] -> 
             RGBColor[
              0.2058756118794577, 0.33371869972598955`, 0.9350356835796365], 
             UndirectedEdge[297, 397] -> 
             RGBColor[
              0.33036980779411174`, 0.4594447802808611, 0.9423131030091806], 
             UndirectedEdge[237, 324] -> 
             RGBColor[
              0.18395646599811732`, 0.31068028765058353`, 0.9337874206481647],
              UndirectedEdge[107, 160] -> 
             RGBColor[
              0.20918830325598364`, 0.33720054839948277`, 0.935224336452842], 
             UndirectedEdge[125, 185] -> 
             RGBColor[
              0.1925739180479394, 0.31973777613296384`, 0.9342781717940241], 
             UndirectedEdge[269, 388] -> 
             RGBColor[
              0.3120924130263679, 0.44123041621648995`, 0.9412357516492327], 
             UndirectedEdge[47, 300] -> 
             RGBColor[
              0.18858263454534693`, 0.31554268410974895`, 0.9340508741031263],
              UndirectedEdge[37, 365] -> 
             RGBColor[
              0.29517424252624735`, 0.4275772223959621, 0.9401211084894857], 
             UndirectedEdge[356, 389] -> 
             RGBColor[
              0.969253418800837, 0.9732437196326836, 0.7351124459689012], 
             UndirectedEdge[227, 243] -> 
             RGBColor[
              0.2526928974888643, 0.38292663528882953`, 0.9377018587351249], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.1986316801099837, 0.3261048681444708, 0.9346231523818017], 
             UndirectedEdge[186, 348] -> 
             RGBColor[
              0.2038426026857459, 0.33158187816317064`, 0.9349199067136222], 
             UndirectedEdge[61, 90] -> 
             RGBColor[
              0.21641762089155886`, 0.3447990195996844, 0.935636035397371], 
             UndirectedEdge[72, 325] -> 
             RGBColor[
              0.35190435537579295`, 0.4723760276667679, 0.9439742559127038], 
             UndirectedEdge[341, 358] -> 
             RGBColor[
              0.26347030119752707`, 0.39425436991349627`, 0.9383156159325932],
              UndirectedEdge[102, 337] -> 
             RGBColor[
              0.6530069899856277, 0.722086925969716, 0.9505841497129952], 
             UndirectedEdge[297, 378] -> 
             RGBColor[
              0.2683985374759716, 0.3994342587103688, 0.9385962716979784], 
             UndirectedEdge[300, 370] -> 
             RGBColor[
              0.19085384504698283`, 0.3179298703500313, 0.9341802161812396], 
             UndirectedEdge[46, 52] -> 
             RGBColor[
              0.89726556755869, 0.9188637535063902, 0.9066512485949225], 
             UndirectedEdge[75, 200] -> 
             RGBColor[
              0.1879784206462758, 0.3149076169924513, 0.9340164650154286], 
             UndirectedEdge[204, 343] -> 
             RGBColor[
              0.1903303530090651, 0.3173796470268675, 0.9341504040841173], 
             UndirectedEdge[32, 199] -> 
             RGBColor[
              0.8772578283825027, 0.4408093284112888, 0.39094028594577723`], 
             UndirectedEdge[301, 313] -> 
             RGBColor[
              0.2672428397382781, 0.39821954711258417`, 0.9385304564215183], 
             UndirectedEdge[166, 363] -> 
             RGBColor[
              0.3098501203432949, 0.43692070785172515`, 0.9411795622408922], 
             UndirectedEdge[333, 353] -> 
             RGBColor[
              0.97351816640208, 0.9765194565998694, 0.7354387372176427], 
             UndirectedEdge[130, 146] -> 
             RGBColor[
              0.20739635899717102`, 0.3353171013676426, 0.9351222878782466], 
             UndirectedEdge[71, 271] -> 
             RGBColor[
              0.8699031270122622, 0.4288122601386338, 0.4232478483872749], 
             UndirectedEdge[123, 332] -> 
             RGBColor[
              0.8347068478586457, 0.26777761804506683`, 0.1808686227462045], 
             UndirectedEdge[340, 361] -> 
             RGBColor[
              0.34048302917169776`, 0.46587738706068504`, 0.9430427098372054],
              UndirectedEdge[165, 322] -> 
             RGBColor[
              0.2103258844391586, 0.3383962183498125, 0.9352891200183233], 
             UndirectedEdge[278, 302] -> 
             RGBColor[
              0.19139766926121787`, 0.31850146407963903`, 0.9342111861657245],
              UndirectedEdge[322, 355] -> 
             RGBColor[
              0.2016258404569241, 0.32925192050983587`, 0.9347936653840967], 
             UndirectedEdge[68, 333] -> 
             RGBColor[
              0.8876904453290742, 0.9128181118706356, 0.9729875018597351], 
             UndirectedEdge[150, 156] -> 
             RGBColor[
              0.22013918030941965`, 0.34871061450835156`, 0.9358479727006643],
              UndirectedEdge[29, 357] -> 
             RGBColor[
              0.18592235681432462`, 0.3127465635430944, 0.9338993752218727], 
             UndirectedEdge[250, 325] -> 
             RGBColor[
              0.21599606078555122`, 0.34435593319981583`, 0.9356120281729761],
              UndirectedEdge[53, 131] -> 
             RGBColor[
              0.6083578580504109, 0.6889233390243821, 0.9644906126536026], 
             UndirectedEdge[92, 267] -> 
             RGBColor[
              0.20096723062757926`, 0.3285596798209194, 0.9347561585286415], 
             UndirectedEdge[269, 309] -> 
             RGBColor[
              0.5253850164437505, 0.6220146854886827, 0.9571050895141], 
             UndirectedEdge[162, 336] -> 
             RGBColor[
              0.21504897720554328`, 0.3433604883086603, 0.9355580931641793], 
             UndirectedEdge[94, 204] -> 
             RGBColor[
              0.1795232819748228, 0.3060207301619996, 0.9335349573763461], 
             UndirectedEdge[29, 183] -> 
             RGBColor[
              0.18726251983199932`, 0.31415515984591347`, 0.9339756955231359],
              UndirectedEdge[145, 208] -> 
             RGBColor[
              0.2721455459278671, 0.4033726021673685, 0.9388096582861116], 
             UndirectedEdge[75, 133] -> 
             RGBColor[
              0.18265733709091148`, 0.3093148207995801, 0.9337134371787883], 
             UndirectedEdge[169, 326] -> 
             RGBColor[
              0.349415147686683, 0.47074983716853436`, 0.9437423719170701], 
             UndirectedEdge[95, 97] -> 
             RGBColor[
              0.27292796870059677`, 0.4041949781099764, 0.9388542161055278], 
             UndirectedEdge[37, 78] -> 
             RGBColor[
              0.25239861099731176`, 0.3826173215273665, 0.9376850995547887], 
             UndirectedEdge[55, 397] -> 
             RGBColor[
              0.5839584526615165, 0.6682303773203624, 0.9627494310951048], 
             UndirectedEdge[185, 226] -> 
             RGBColor[
              0.1922271263061977, 0.3193732760245269, 0.9342584225173644], 
             UndirectedEdge[39, 254] -> 
             RGBColor[
              0.19262591917799537`, 0.31979243261771473`, 0.934281133181452], 
             UndirectedEdge[71, 201] -> 
             RGBColor[
              0.8177089698538784, 0.8578529670679469, 0.9517417151457506], 
             UndirectedEdge[227, 383] -> 
             RGBColor[
              0.3161546993185588, 0.44504578365193476`, 0.9414837289337784], 
             UndirectedEdge[38, 151] -> 
             RGBColor[
              0.23316903340538708`, 0.36240581625261525`, 0.9365900035585395],
              UndirectedEdge[45, 74] -> 
             RGBColor[
              0.2441275547351621, 0.3739239169805914, 0.9372140751365906], 
             UndirectedEdge[292, 303] -> 
             RGBColor[
              0.8443046091041563, 0.3043001594014045, 0.18860083092727706`], 
             UndirectedEdge[185, 357] -> 
             RGBColor[
              0.18927662196416456`, 0.31627210888827, 0.9340903956599655], 
             UndirectedEdge[86, 376] -> 
             RGBColor[
              0.2771391258654599, 0.4086211712930332, 0.939094035276218], 
             UndirectedEdge[212, 309] -> 
             RGBColor[
              0.6375731061251859, 0.7158069480258249, 0.965187359754256], 
             UndirectedEdge[50, 127] -> 
             RGBColor[
              0.28524823564473223`, 0.4143130772255349, 0.9396595042068966], 
             UndirectedEdge[92, 374] -> 
             RGBColor[
              0.1940034937220554, 0.32124035080679264`, 0.9343595840137974], 
             UndirectedEdge[118, 141] -> 
             RGBColor[
              0.35660710592589273`, 0.4832968843838794, 0.9439436673476838], 
             UndirectedEdge[205, 390] -> 
             RGBColor[
              0.19906834334491935`, 0.32656382889043634`, 
               0.9346480197070459]}, GraphLayout -> {"Dimension" -> 2}, 
           ImageSize -> 500, VertexSize -> {3}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.24987309085249598`, 0.3799628397279394, 0.9375412749187138], 
             316 -> RGBColor[
              0.7121412574025138, 0.7750494298476431, 0.9719432432656107], 
             308 -> 
             RGBColor[
              0.212847764567014, 0.3410468742606238, 0.9354327373608172], 160 -> 
             RGBColor[
              0.19529547244710238`, 0.32259830236299947`, 0.9344331602908775],
              245 -> RGBColor[
              0.19489410730752896`, 0.3221764421532881, 0.9344103031399453], 
             155 -> RGBColor[
              0.1858996679095085, 0.31272271606557295`, 0.9338980831223087], 
             213 -> RGBColor[
              0.3254133616442444, 0.45627843093029025`, 0.9419560295456021], 
             352 -> RGBColor[
              0.18638553952238943`, 0.3132333979367503, 0.9339257527918797], 
             27 -> RGBColor[
              0.20503271821821972`, 0.3328327650454837, 0.9349876820325784], 
             367 -> RGBColor[
              0.1860930553658944, 0.31292597854370746`, 0.9339090962518588], 
             19 -> RGBColor[
              0.19951285246669712`, 0.3270310361609309, 0.9346733338439388], 
             164 -> RGBColor[
              0.21499276582137244`, 0.3433014065798891, 0.935554892009008], 
             190 -> RGBColor[
              0.2121526703486752, 0.34031628616563087`, 0.9353931527733826], 
             103 -> RGBColor[
              0.19478977051563845`, 0.3220667775696765, 0.9344043613139996], 
             138 -> RGBColor[
              0.2889051941793347, 0.4209880551027343, 0.939764095460355], 291 -> 
             RGBColor[
              0.1954605501868454, 0.3227718095340026, 0.9344425612239453], 28 -> 
             RGBColor[
              0.19159599737019925`, 0.31870991949690686`, 0.9342224806581308],
              337 -> RGBColor[
              0.956979221732861, 0.9674357545252026, 0.9577071353769899], 195 -> 
             RGBColor[
              0.42461827381123246`, 0.5422047396654701, 0.9482772788254231], 
             114 -> RGBColor[
              0.18667779652152947`, 0.3135405785730105, 0.9339423963956253], 
             93 -> RGBColor[
              0.3425287629814334, 0.47110293132347947`, 0.9430466077842526], 
             34 -> RGBColor[
              0.1829376663072982, 0.30960946457990146`, 0.9337294015129516], 
             161 -> RGBColor[
              0.8795463410175769, 0.5459298918751729, 0.22120285316675511`], 
             22 -> RGBColor[
              0.24203296140503872`, 0.3717223665857442, 0.9370947911451132], 
             124 -> RGBColor[
              0.22661866237074535`, 0.3555209609776956, 0.9362169696185221], 
             84 -> RGBColor[
              0.21428709115836797`, 0.3425596977667136, 0.935514704880902], 
             46 -> 
             RGBColor[
              0.8055364749096104, 0.8480104835941301, 0.9812520057187881], 
             241 -> RGBColor[
              0.28091140737960196`, 0.41258607834085864`, 0.939308861127858], 
             185 -> RGBColor[
              0.19254963929720473`, 0.31971225762658, 0.9342767891550869], 
             390 -> RGBColor[
              0.21298290042549683`, 0.3411889106159976, 0.9354404331480423], 
             121 -> RGBColor[
              0.24372417422141443`, 0.37349993848484087`, 0.9371911032130806],
              322 -> RGBColor[
              0.1951112049063669, 0.3224046254944496, 0.9344226665270321], 
             126 -> RGBColor[
              0.18255935854789945`, 0.309211839138676, 0.9337078574457099], 
             236 -> RGBColor[
              0.5096359477486948, 0.612784447077024, 0.9545395551462174], 78 -> 
             RGBColor[
              0.22046571832082573`, 0.34905382666204504`, 0.9358665685573442],
              376 -> RGBColor[
              0.28617898913701123`, 0.4181226407518692, 0.9396088421162536], 
             254 -> RGBColor[
              0.1870776850955973, 0.3139608868187558, 0.9339651694583363], 
             290 -> RGBColor[
              0.25752973177491306`, 0.38801045479647306`, 0.9379773092922603],
              251 -> RGBColor[
              0.1849258667142184, 0.3116991892667612, 0.9338426265848467], 
             165 -> RGBColor[
              0.22554056397195027`, 0.35438781120517543`, 0.9361555735096144],
              100 -> RGBColor[
              0.387712192347488, 0.5102385468551641, 0.9459256559493198], 235 -> 
             RGBColor[
              0.19324911536591247`, 0.3204474513241361, 0.9343166232824178], 
             70 -> RGBColor[
              0.1969643686712329, 0.32435241810869275`, 0.934528201461931], 
             234 -> RGBColor[
              0.24693624036742998`, 0.3768760236610595, 0.9373740256282702], 
             257 -> RGBColor[
              0.9694202648664492, 0.9767142641238943, 0.9366476944955487], 
             135 -> RGBColor[
              0.335355251737071, 0.46488959643477135`, 0.9425895179910487], 
             265 -> RGBColor[
              0.19899652547638796`, 0.32648834375709396`, 0.934643929785678], 
             111 -> RGBColor[
              0.8266120846200963, 0.20555772064570646`, 0.17311706832724205`],
              381 -> RGBColor[
              0.1893487791980019, 0.3163479507160659, 0.9340945049076855], 
             182 -> RGBColor[
              0.24182762690147153`, 0.3715065470035356, 0.9370830976489003], 
             188 -> 
             RGBColor[
              0.27580922111776024`, 0.4072233570823697, 0.9390182991682543], 
             154 -> RGBColor[
              0.18637271886218407`, 0.3132199226099977, 0.9339250226742475], 
             336 -> RGBColor[
              0.23480104226620413`, 0.36412116104067216`, 0.9366829440488222],
              315 -> RGBColor[
              0.1811098371299533, 0.3076883002234485, 0.9336253093453327], 
             368 -> RGBColor[
              0.1838330998850932, 0.3105506220439319, 0.9337803951305317], 
             269 -> RGBColor[
              0.3534033382914345, 0.480521941884955, 0.9437395261069965], 208 -> 
             RGBColor[
              0.2944180010032382, 0.4267823646067975, 0.9400780416535094], 86 -> 
             RGBColor[
              0.2680992625939086, 0.39911970183419715`, 0.9385792284361825], 
             119 -> RGBColor[
              0.2397898236287226, 0.36936468655968646`, 0.936967047767177], 
             377 -> RGBColor[
              0.25469411239970985`, 0.38503003904448196`, 0.9378158249637654],
              140 -> RGBColor[
              0.4063466574019441, 0.5263787838898877, 0.9471130275847793], 85 -> 
             RGBColor[
              0.1818888062976524, 0.30850704620819813`, 0.9336696704870515], 
             351 -> RGBColor[
              0.3095548228305918, 0.44254256168324113`, 0.9409455374755513], 
             242 -> RGBColor[
              0.3403985574835718, 0.4692578543884732, 0.9429108729735957], 
             117 -> RGBColor[
              0.5585316039927765, 0.6524801435401812, 0.9583888003164419], 47 -> 
             RGBColor[
              0.18100426741029385`, 0.3075773397545796, 0.9336192973059745], 
             81 -> RGBColor[
              0.22915597848204, 0.35818784108579943`, 0.9363614660174375], 
             275 -> RGBColor[
              0.194144227344503, 0.3213882707670121, 0.934367598585399], 23 -> 
             RGBColor[
              0.2119196850624197, 0.340071403857656, 0.9353798846060012], 328 -> 
             RGBColor[
              0.2313516506730186, 0.3604956317721754, 0.9364865063005079], 
             110 -> RGBColor[
              0.8529626688242167, 0.8855932953383124, 0.985837534872859], 6 -> 
             RGBColor[
              0.9261633007621113, 0.943961492267368, 0.992819476494071], 218 -> 
             RGBColor[
              0.5602763464580424, 0.6538966040732364, 0.9585261528345099], 
             108 -> RGBColor[
              0.3063635945960659, 0.4393379408672382, 0.9407583255366989], 
             297 -> 
             RGBColor[
              0.2965600408339725, 0.42903378428206873`, 0.9402000276530058], 
             157 -> RGBColor[
              0.24686136029389427`, 0.3767973199561026, 0.9373697613188575], 
             354 -> RGBColor[
              0.19610120868731518`, 0.3234451822380914, 0.9344790457777777], 
             385 -> RGBColor[
              0.9944175835604394, 0.9904681006416884, 0.633766605113725], 270 -> 
             RGBColor[
              0.20794500379241626`, 0.3358937618335345, 0.9351535323876885], 
             392 -> RGBColor[
              0.2030621295519029, 0.3307615514146469, 0.9348754599232564], 33 -> 
             RGBColor[
              0.24658940627570813`, 0.37651147904010834`, 0.9373542739398417],
              252 -> RGBColor[
              0.20594129701488287`, 0.33378773896799957`, 0.9350394242509266],
              394 -> RGBColor[
              0.35762511408731845`, 0.48417863188672844`, 0.9440085339275405],
              260 -> RGBColor[
              0.1889310324973132, 0.31590887244697147`, 0.9340707148510822], 
             159 -> RGBColor[
              0.18214142158537838`, 0.30877256089233246`, 0.9336840565539767],
              183 -> RGBColor[
              0.18868393066647376`, 0.3156491527555983, 0.9340566427673703], 
             99 -> RGBColor[
              0.9021660914511284, 0.9248267689496842, 0.9905306012474278], 
             329 -> RGBColor[
              0.2623389378177228, 0.3930652352687406, 0.9382511864618155], 
             309 -> RGBColor[
              0.6973666945960665, 0.7635074290924103, 0.9704706529212034], 17 -> 
             RGBColor[
              0.8276616884309496, 0.21362543547524793`, 0.17412217012187317`],
              349 -> RGBColor[
              0.19841472542917707`, 0.32587683501922177`, 0.9346107971336854],
              347 -> RGBColor[
              0.18432439621433888`, 0.3110670056359555, 0.9338083737296745], 
             340 -> RGBColor[
              0.27139200070452485`, 0.4025805783601091, 0.9387667450004126], 
             277 -> RGBColor[
              0.1851145385676597, 0.3118974953472144, 0.9338533711677852], 
             104 -> RGBColor[
              0.22404918964109946`, 0.35282028222485723`, 0.936070641947763], 
             79 -> RGBColor[
              0.199051197909799, 0.3265458079510415, 0.9346470432998802], 327 -> 
             RGBColor[
              0.18576331458524015`, 0.3125794000764668, 0.9338903180022083], 
             191 -> RGBColor[
              0.1840091371887301, 0.310735648411464, 0.9337904201945499], 50 -> 
             RGBColor[
              0.23112771995435683`, 0.3602602663888343, 0.9364737537773559], 
             225 -> RGBColor[
              0.2084820527788493, 0.336458234369148, 0.9351841165329731], 61 -> 
             RGBColor[
              0.21726621743653565`, 0.3456909483725835, 0.9356843617152213], 
             196 -> RGBColor[
              0.844124603334554, 0.8785460618197521, 0.9849945522966208], 1 -> 
             RGBColor[
              0.1818132732838514, 0.3084276562216236, 0.9336653689936567], 
             263 -> RGBColor[
              0.30183205672017543`, 0.43457500724358145`, 0.9405002611584765],
              201 -> RGBColor[
              0.6657140642559093, 0.738780153701779, 0.9673158145395446], 371 -> 
             RGBColor[
              0.18003320207443918`, 0.306556688517498, 0.93356399657166], 293 -> 
             RGBColor[
              0.3141297509318431, 0.44650513446197276`, 0.941237047848713], 
             362 -> RGBColor[
              0.7912709059084366, 0.8368661126680731, 0.979830147120073], 184 -> 
             RGBColor[
              0.21355297767290998`, 0.3417880979480139, 0.9354728982039288], 
             106 -> RGBColor[
              0.1865190623784995, 0.31337373892436005`, 0.9339333567210057], 
             206 -> RGBColor[
              0.4288884024290853, 0.5459033104513494, 0.9485493676450263], 
             358 -> RGBColor[
              0.2775970966062373, 0.4091025275786123, 0.9391201160323983], 
             247 -> RGBColor[
              0.8173387448883187, 0.1342787678638822, 0.16423690772735258`], 
             220 -> RGBColor[
              0.17970434930417156`, 0.30621104340547683`, 0.9335452688928874],
              107 -> RGBColor[
              0.2230811340648649, 0.3518027944359661, 0.9360155126148064], 
             375 -> RGBColor[
              0.20279567675606608`, 0.3304814926321394, 0.9348602858307151], 
             131 -> RGBColor[
              0.8141109072907318, 0.8547088953383618, 0.982106625005912], 127 -> 
             RGBColor[
              0.3393687513351076, 0.46836588806223545`, 0.9428452546364373], 
             210 -> RGBColor[
              0.2456807114445148, 0.37555638315794415`, 0.9373025251134988], 
             357 -> RGBColor[
              0.18600360463112436`, 0.31283196014996, 0.9339040021648441], 
             181 -> RGBColor[
              0.19212227783830665`, 0.31926307363699663`, 0.9342524515522274],
              194 -> RGBColor[
              0.4554399226734993, 0.5687856724178738, 0.9502730455257168], 
             118 -> 
             RGBColor[
              0.3574473894517768, 0.48402469574012214`, 0.9439972094709195], 
             348 -> RGBColor[
              0.20110409825488346`, 0.3287035363751249, 0.9347639529375389], 
             276 -> RGBColor[
              0.37904525788294496`, 0.5027316838347692, 0.9453734065491083], 
             305 -> RGBColor[
              0.29805944165302733`, 0.4306097496103981, 0.9402854163114862], 
             343 -> RGBColor[
              0.20071986914810575`, 0.3282996872223691, 0.9347420716583239], 
             280 -> RGBColor[
              0.2089289786028837, 0.3369279817469421, 0.9352095682974844], 
             189 -> RGBColor[
              0.2331737072204319, 0.36241072872856434`, 0.9365902697253919], 
             168 -> RGBColor[
              0.19796437105250972`, 0.32540348401522773`, 0.9345851501181738],
              363 -> RGBColor[
              0.3745258073527012, 0.4988171629396605, 0.9450854311577144], 41 -> 
             RGBColor[
              0.19479503600678127`, 0.322072311934719, 0.9344046611759306], 
             14 -> RGBColor[
              0.3386493168091526, 0.46774275003568394`, 0.9427994129046144], 
             77 -> RGBColor[
              0.1969521059625652, 0.3243395292243824, 0.9345275031188135], 51 -> 
             RGBColor[
              0.20120879960667537`, 0.3288135841343073, 0.9347699155246316], 
             179 -> RGBColor[
              0.2268131918331927, 0.35572542377660804`, 0.9362280477836279], 
             223 -> RGBColor[
              0.8592163258347785, 0.4536160411257659, 0.20423899016395516`], 
             323 -> RGBColor[
              0.42062186552277797`, 0.5387432516713317, 0.9480226312231679], 
             292 -> RGBColor[
              0.8194918846006688, 0.15082874320484374`, 0.1662987567475226], 
             396 -> RGBColor[
              0.18439801323969868`, 0.31114438179719767`, 0.9338125661103621],
              321 -> RGBColor[
              0.18455342051778426`, 0.3113077246998561, 0.9338214163249446], 
             143 -> RGBColor[
              0.19890345919190142`, 0.32639052519135536`, 0.9346386297984558],
              112 -> RGBColor[
              0.1804406002012431, 0.3069848897793021, 0.93358719729229], 197 -> 
             RGBColor[
              0.19131157595015044`, 0.3184109745510759, 0.9342062832790229], 
             54 -> RGBColor[
              0.9482538006021336, 0.8325505933258706, 0.2772219972063093], 71 -> 
             RGBColor[
              0.9697038754518477, 0.9769257804341147, 0.9361676157519565], 
             177 -> 
             RGBColor[
              0.18139651046953492`, 0.3079896120794884, 0.9336416349679267], 
             158 -> RGBColor[
              0.1911403477299942, 0.3182310028351955, 0.9341965320851944], 
             226 -> RGBColor[
              0.19190461331519068`, 0.3190342944224739, 0.9342400558796418], 
             350 -> RGBColor[
              0.3485452682138572, 0.4763141257574593, 0.943429974177476], 203 -> 
             RGBColor[
              0.3100095560527289, 0.44293642874469996`, 0.9409745126743612], 
             115 -> RGBColor[
              0.9551078718556497, 0.8597247018622127, 0.2827369438226184], 
             173 -> RGBColor[
              0.17959143492855675`, 0.30609236323752076`, 0.933538838586238], 
             212 -> RGBColor[
              0.5777795176543054, 0.6681064669592394, 0.9599040665873084], 
             129 -> RGBColor[
              0.8193361618613183, 0.1496317899920564, 0.1661496364764569], 
             279 -> RGBColor[
              0.1990369147875074, 0.3265307954839108, 0.9346462298971957], 26 -> 
             RGBColor[
              0.1822568035379685, 0.30889383464014303`, 0.9336906273854845], 
             40 -> RGBColor[
              0.1934487547814754, 0.32065728500776275`, 0.934327992451794], 
             146 -> RGBColor[
              0.1991293041825628, 0.32662790259593993`, 0.9346514913365662], 
             386 -> RGBColor[
              0.3419268933615933, 0.4705816221096207, 0.9430082571842888], 
             192 -> RGBColor[
              0.2582664433427927, 0.3887847853645258, 0.938019263926184], 300 -> 
             RGBColor[
              0.19616100168040002`, 0.3235080284649182, 0.934482450900278], 
             221 -> RGBColor[
              0.36991176607450643`, 0.49482071229294583`, 0.9447914285275043],
              62 -> RGBColor[
              0.9918038536315829, 0.990878697092375, 0.7854948864789351], 286 -> 
             RGBColor[
              0.3212434064694567, 0.45266662534593033`, 0.9416903236892111], 
             152 -> RGBColor[
              0.2008438754397465, 0.3284300256973365, 0.9347491336331819], 64 -> 
             RGBColor[
              0.9925852496598342, 0.986548923705669, 0.43432836788688456`], 
             307 -> RGBColor[
              0.17902996710188124`, 0.3055022249525685, 0.933506863824126], 
             37 -> RGBColor[
              0.2843315036737978, 0.41618081639268795`, 0.9395036305522334], 
             148 -> RGBColor[
              0.25655300447979307`, 0.38698385248121464`, 0.9379216861177417],
              261 -> 
             RGBColor[
              0.18920356017618423`, 0.31619531631671777`, 0.9340862348992254],
              387 -> RGBColor[
              0.18554205504628538`, 0.3123468422723603, 0.933877717598789], 
             15 -> RGBColor[
              0.18212992963139682`, 0.3087604821200659, 0.9336834021041983], 
             136 -> RGBColor[
              0.18263620644148504`, 0.30929261114727236`, 0.9337122338195634],
              198 -> RGBColor[
              0.8287975688378628, 0.8663247005533589, 0.9835326460637211], 63 -> 
             RGBColor[
              0.18932442036239164`, 0.31632234803540016`, 0.9340931177080333],
              310 -> RGBColor[
              0.8265166883216026, 0.20482446289255998`, 0.17302571672406986`],
              171 -> RGBColor[
              0.18805335571358273`, 0.3149863784993486, 0.9340207324566552], 
             395 -> RGBColor[
              0.4386808762090538, 0.554385059055515, 0.9491733354151413], 311 -> 
             RGBColor[
              0.2025961788233211, 0.3302718076559249, 0.934848924718576], 353 -> 
             RGBColor[
              0.9932598001133134, 0.9879917189181485, 0.507749021905247], 59 -> 
             RGBColor[
              0.21627237251575757`, 0.34464635434743823`, 0.9356277637172448],
              397 -> RGBColor[
              0.36417957475425095`, 0.48985577627965343`, 0.9444261783653554],
              229 -> RGBColor[
              0.19792175174780763`, 0.3253586884237658, 0.9345827230118207], 
             102 -> RGBColor[
              0.34903475823839447`, 0.4767380974142295, 0.9434611640490004], 
             299 -> RGBColor[
              0.18838969891108812`, 0.3153398965253172, 0.9340398867041779], 
             128 -> RGBColor[
              0.3039019362504366, 0.4367505818678281, 0.9406181377356125], 12 -> 
             RGBColor[
              0.242785484860208, 0.37251331644986996`, 0.9371376462426264], 
             222 -> RGBColor[
              0.9510874915293103, 0.9630417117862173, 0.9676802978022608], 92 -> 
             RGBColor[
              0.20437042968316516`, 0.3321366578036229, 0.9349499656802752], 
             271 -> RGBColor[
              0.8200027527924696, 0.15475549999089333`, 0.1667879647049341], 
             361 -> RGBColor[
              0.40957405763887067`, 0.529174195761261, 0.9473186746739982], 
             344 -> RGBColor[
              0.1915625031716876, 0.3186747149706162, 0.9342205732130758], 
             132 -> RGBColor[
              0.19287402797566439`, 0.32005321069507126`, 0.9342952626104353],
              80 -> 
             RGBColor[
              0.20310658273494972`, 0.3308082745285237, 0.9348779914662683], 
             324 -> RGBColor[
              0.1856877903127057, 0.31250001927751764`, 0.9338860170066157], 
             244 -> RGBColor[
              0.18235944175044905`, 0.3090017139090986, 0.9336964724798456], 
             150 -> RGBColor[
              0.23840666361665402`, 0.3679108976895925, 0.9368882788506916], 
             125 -> RGBColor[
              0.1925981967986741, 0.3197632946393477, 0.9342795544329613], 
             258 -> RGBColor[
              0.23765262088408304`, 0.3671183509685898, 0.9368453372325779], 
             133 -> RGBColor[
              0.18340497994045135`, 0.3101006408377411, 0.933756014333031], 
             255 -> RGBColor[
              0.37418878878290995`, 0.4985252543935531, 0.9450639566324611], 
             326 -> RGBColor[
              0.24157157412247404`, 0.37123741929812537`, 0.9370685158219325],
              176 -> RGBColor[
              0.18620451936940718`, 0.3130431342786254, 0.9339154439619627], 
             230 -> RGBColor[
              0.2211253737681676, 0.3497471663617724, 0.9359041349591976], 
             274 -> RGBColor[
              0.20313982636998706`, 0.33084321569671615`, 0.9348798846421041],
              87 -> RGBColor[
              0.18684859723136407`, 0.31372010094843716`, 0.9339521232433733],
              130 -> RGBColor[
              0.21566341381177923`, 0.3440063001393452, 0.9355930844199268], 
             35 -> RGBColor[
              0.19009976398754364`, 0.3171372833450601, 0.9341372723804675], 
             379 -> RGBColor[
              0.18246816409549027`, 0.30911598798713175`, 0.9337026640565553],
              31 -> RGBColor[
              0.9842583887354778, 0.9877584534482328, 0.9105427668445933], 18 -> 
             RGBColor[
              0.9925358512363838, 0.9864432654728553, 0.42895165434603927`], 
             24 -> RGBColor[
              0.2601817623901309, 0.39079790712151985`, 0.9381283385124692], 
             151 -> RGBColor[
              0.20761230953904478`, 0.335544079079207, 0.935134585942136], 
             137 -> RGBColor[
              0.29264465833089975`, 0.42491846902175034`, 0.9399770524117451],
              330 -> RGBColor[
              0.18870039039885345`, 0.3156664529779366, 0.9340575801247794], 
             296 -> RGBColor[
              0.17907641669607907`, 0.3055510464211448, 0.9335095090597996], 
             266 -> RGBColor[
              0.6582217134144572, 0.7329270722804612, 0.9665690470276681], 
             302 -> 
             RGBColor[
              0.19470143524485908`, 0.32197393159930776`, 0.9343993307510091],
              283 -> RGBColor[
              0.9319225428018962, 0.7678025982169813, 0.26408148383634866`], 
             388 -> RGBColor[
              0.2707814877613013, 0.40193889054802484`, 0.938731977191469], 
             284 -> RGBColor[
              0.7398648594018855, 0.7967073184367315, 0.9747064728211174], 
             318 -> RGBColor[
              0.21345649486519924`, 0.3416866883997466, 0.9354674036507632], 
             238 -> RGBColor[
              0.20088219976865415`, 0.32847030699692126`, 0.9347513161470175],
              72 -> RGBColor[
              0.46553671991296847`, 0.576982707272407, 0.9510679023901947], 
             288 -> RGBColor[
              0.2137339467700851, 0.34197830794324846`, 0.935483204126293], 
             382 -> RGBColor[
              0.3220959675484921, 0.453405070901625, 0.9417446481272771], 389 -> 
             RGBColor[
              0.9931232770303468, 0.9876997098482838, 0.4928893268471293], 
             172 -> RGBColor[
              0.3796233347917912, 0.5032323849982215, 0.9454102410985666], 
             243 -> RGBColor[
              0.23139395253121084`, 0.36054009370722817`, 0.9364889153287519],
              88 -> RGBColor[
              0.4303958842275222, 0.5472090154169172, 0.9486454230522088], 
             273 -> RGBColor[
              0.5240458703783706, 0.6244830714274116, 0.9556739570409113], 
             202 -> RGBColor[
              0.3275914997751332, 0.4581650247028605, 0.9420948185812503], 
             393 -> RGBColor[
              0.7219717591850786, 0.7827290925547635, 0.9729230558120345], 98 -> 
             RGBColor[
              0.1932487717488401, 0.3204470901608064, 0.9343166037139339], 30 -> 
             RGBColor[
              0.20069898841488326`, 0.3282777402478373, 0.9347408825314572], 
             116 -> RGBColor[
              0.24002120291967022`, 0.3696078808647668, 0.9369802244755014], 
             373 -> RGBColor[
              0.19798515205544082`, 0.3254253261669, 0.934586333565548], 240 -> 
             RGBColor[
              0.17933281357579656`, 0.305820535798229, 0.9335241104827943], 
             317 -> RGBColor[
              0.18850413369751906`, 0.3154601747414406, 0.9340464035959741], 
             391 -> RGBColor[
              0.8202342132018924, 0.1565346061243149, 0.16700961145439447`], 
             73 -> RGBColor[
              0.1985117660113969, 0.3259788308238631, 0.9346163234512842], 
             303 -> 
             RGBColor[
              0.8939300581111314, 0.611242991794526, 0.23320497928678602`], 
             29 -> RGBColor[
              0.18584110899752487`, 0.3126611669362287, 0.9338947482789014], 
             360 -> RGBColor[
              0.6627555094400547, 0.736468908193784, 0.9670209334447669], 320 -> 
             RGBColor[
              0.18370800885926494`, 0.3104191434445573, 0.9337732713816664], 
             75 -> RGBColor[
              0.18190969424137163`, 0.30852900076141915`, 0.9336708600245455],
              200 -> RGBColor[
              0.19404714705117995`, 0.3212862332234835, 0.9343620700063117], 
             301 -> RGBColor[
              0.24986810421890843`, 0.3799575984598681, 0.937540990937308], 
             156 -> RGBColor[
              0.20187169700218524`, 0.3295103313271106, 0.9348076665506371], 
             25 -> RGBColor[
              0.3639618362230004, 0.489667182107741, 0.9444123042586827], 38 -> 
             RGBColor[
              0.2587257572717294, 0.3892675534260234, 0.9380454211749428], 
             365 -> RGBColor[
              0.30601698137869693`, 0.43897362839923615`, 0.940738586426738], 
             380 -> RGBColor[
              0.7203821791624184, 0.7814873005598058, 0.9727646213308456], 
             370 -> RGBColor[
              0.18554668841356567`, 0.31235171223514435`, 0.9338779814622011],
              3 -> RGBColor[
              0.23621542372166607`, 0.36560776562732644`, 0.9367634909803209],
              57 -> RGBColor[
              0.3482989604247025, 0.47610078633028297`, 0.9434142796629524], 
             227 -> RGBColor[
              0.2739918424465178, 0.40531317687043084`, 0.9389148021414978], 
             39 -> RGBColor[
              0.19817415326039348`, 0.32562397841667373`, 0.9345970969045678],
              109 -> RGBColor[
              0.1827503081177702, 0.3094125392435122, 0.9337187317412295], 
             256 -> RGBColor[
              0.9923039511135691, 0.9910855002530954, 0.777206976991627], 339 -> 
             RGBColor[
              0.38195753878243316`, 0.5052541551744117, 0.9455589745127948], 
             287 -> RGBColor[0.817319, 0.134127, 0.164218], 239 -> 
             RGBColor[
              0.5071373117219987, 0.6107559417882819, 0.9543428533653905], 
             285 -> RGBColor[
              0.18427610046840573`, 0.31101624374485265`, 0.9338056233583907],
              345 -> RGBColor[
              0.8280837295399454, 0.865755504473851, 0.9834645594342339], 366 -> 
             RGBColor[
              0.9933000584574108, 0.9880778274454297, 0.5121308942145434], 
             216 -> RGBColor[
              0.21581639795358076`, 0.3441670961721334, 0.9356017966404827], 
             21 -> RGBColor[
              0.19666790482252822`, 0.3240408158068105, 0.9345113182843263], 
             355 -> RGBColor[
              0.2081404760074813, 0.3360992155252221, 0.9351646642411613], 
             175 -> RGBColor[
              0.19013667027984396`, 0.3171760741982618, 0.9341393741392161], 
             7 -> RGBColor[
              0.25494849258932906`, 0.3852974087524073, 0.9378303115392425], 
             13 -> RGBColor[
              0.21336291477373137`, 0.3415883297902934, 0.9354620744029933], 
             294 -> RGBColor[
              0.20973292712492791`, 0.3377729826168909, 0.9352553519764795], 
             193 -> RGBColor[
              0.8379281346647119, 0.8736051659010814, 0.9844035275832383], 60 -> 
             RGBColor[
              0.7070237961498369, 0.7710516302229059, 0.9714331825533382], 65 -> 
             RGBColor[
              0.3764941167365503, 0.5005220135978444, 0.9452108500911456], 69 -> 
             RGBColor[
              0.5728179374316162, 0.6640784326178184, 0.9595134728173111], 
             217 -> RGBColor[
              0.2082469591636211, 0.3362111360737471, 0.9351707282993756], 
             214 -> RGBColor[
              0.8789213821202363, 0.5430920994852084, 0.22068137214366979`], 
             170 -> RGBColor[
              0.23550398192177388`, 0.3648599951876243, 0.9367229754223009], 
             359 -> RGBColor[
              0.32568965645452963`, 0.4565177436079784, 0.9419736348065956], 
             74 -> RGBColor[
              0.24853385159996577`, 0.37855521436085726`, 0.9374650072245091],
              246 -> RGBColor[
              0.2167015948028579, 0.34509749418544555`, 0.9356522072915177], 
             264 -> RGBColor[
              0.2599789274537134, 0.39058471474286727`, 0.9381167873629076], 
             278 -> RGBColor[
              0.1880939032775767, 0.3150289965599703, 0.9340230415804399], 45 -> 
             RGBColor[
              0.23972125787035842`, 0.36929261960032556`, 0.9369631430486721],
              306 -> RGBColor[
              0.22229995450050422`, 0.350981725184178, 0.9359710255942676], 
             237 -> RGBColor[
              0.18222514168352894`, 0.3088605560236495, 0.9336888242897137], 
             228 -> RGBColor[
              0.22400797509009437`, 0.3527769631185974, 0.9360682948400547], 
             180 -> 
             RGBColor[
              0.18842432755960442`, 0.31537629343049095`, 0.9340418587544824],
              383 -> RGBColor[
              0.3583175561905998, 0.4847783904334387, 0.944052655726059], 53 -> 
             RGBColor[
              0.40260480881009003`, 0.5231377827104023, 0.9468746003012931], 
             304 -> RGBColor[
              0.2822705085644714, 0.4140145798581486, 0.9393862599297264], 48 -> 
             RGBColor[
              0.20793893985757575`, 0.3358873882535414, 0.9351531870555702], 
             5 -> RGBColor[
              0.18681770269069906`, 0.3136876288273712, 0.9339503638449868], 
             101 -> RGBColor[
              0.8539737461394735, 0.41587144104017043`, 0.19931862629877445`],
              333 -> RGBColor[
              0.9537765326908467, 0.9650471942815904, 0.9631284525300384], 
             267 -> RGBColor[
              0.19756403157199334`, 0.32498270183821587`, 0.9345623513770076],
              120 -> RGBColor[
              0.41254771032069193`, 0.531749824254125, 0.9475081531933861], 
             147 -> RGBColor[
              0.24721508689536167`, 0.3771691090418067, 0.9373899055255195], 
             89 -> RGBColor[
              0.23222586891438338`, 0.3614144905724877, 0.9365362917360636], 
             43 -> RGBColor[
              0.194697223000598, 0.3219695042635176, 0.9343990908699299], 199 -> 
             RGBColor[
              0.9887357523774989, 0.9896099583772056, 0.8363412642506296], 
             268 -> RGBColor[
              0.187660141527025, 0.31457308545805707`, 0.933998339490439], 
             169 -> RGBColor[
              0.45725872125089195`, 0.5702622550389433, 0.9504162280122078], 
             20 -> RGBColor[
              0.3846257063952153, 0.5075651878546001, 0.9457289877937134], 4 -> 
             RGBColor[
              0.2008450066857079, 0.32843121470856707`, 0.9347491980559659], 
             167 -> RGBColor[
              0.2358064817309028, 0.3651779416666145, 0.9367402023389224], 
             142 -> RGBColor[
              0.4741596199861951, 0.5839831660090739, 0.9517467286706829], 16 -> 
             RGBColor[
              0.22895368331262583`, 0.3579752160364906, 0.9363499456068083], 
             281 -> RGBColor[
              0.39875120665503094`, 0.5197999862113661, 0.9466290521795794], 
             289 -> RGBColor[
              0.4742143938317012, 0.5840276338843894, 0.9517510406684443], 
             398 -> RGBColor[
              0.1808071689883251, 0.3073701768163288, 0.9336080728424244], 
             178 -> 
             RGBColor[
              0.18300767959384703`, 0.309683052983163, 0.9337333886660452], 
             58 -> RGBColor[
              0.19320352841391442`, 0.32039953654720643`, 0.9343140271729413],
              186 -> RGBColor[
              0.2065811071166083, 0.33446021995121644`, 0.9350758604897056], 
             122 -> RGBColor[
              0.18936604401309215`, 0.31636609713137825`, 0.934095488113364], 
             249 -> RGBColor[
              0.18362197162651986`, 0.31032871285786656`, 0.9337683716885422],
              113 -> RGBColor[
              0.1856485479005117, 0.3124587730141891, 0.9338837822092951], 52 -> 
             RGBColor[
              0.9889946602077696, 0.9897170234186503, 0.8320504914710569], 
             187 -> RGBColor[
              0.21634716160662554`, 0.34472496242384276`, 0.9356320228453292],
              259 -> RGBColor[
              0.8954246210317355, 0.9194513034296, 0.9898875937806444], 42 -> 
             RGBColor[
              0.183885630512114, 0.31060583506356493`, 0.9337833866720284], 
             134 -> RGBColor[
              0.17911500115561352`, 0.3055916011345115, 0.9335117063876894], 
             313 -> RGBColor[
              0.28461757525764775`, 0.41648149576530025`, 0.9395199219057286],
              248 -> RGBColor[
              0.1829127869860106, 0.3095833148357881, 0.9337279846724099], 
             174 -> RGBColor[
              0.41783566912403936`, 0.5363299883890472, 0.947845097252377], 
             215 -> RGBColor[
              0.7060709713767632, 0.7703072762684443, 0.9713382138846121], 
             399 -> RGBColor[
              0.3593758114062829, 0.48569499791180964`, 0.944120086812624], 
             83 -> RGBColor[
              0.9509849302078126, 0.9629652217205732, 0.9678539073672795], 95 -> 
             RGBColor[
              0.24723118250472642`, 0.37718602654776967`, 0.9373908221466615],
              166 -> RGBColor[
              0.2451744333338886, 0.3750242527637898, 0.93727369332407], 384 -> 
             RGBColor[
              0.9335847383251342, 0.7743926495727972, 0.2654189253710895], 
             233 -> RGBColor[
              0.9703310152107799, 0.9773935002394792, 0.9351060317243296], 
             295 -> RGBColor[
              0.18590102371033476`, 0.3127241410982041, 0.9338981603331601], 
             141 -> RGBColor[
              0.3557668224000087, 0.48256907302763663`, 0.9438901252244479], 
             319 -> RGBColor[
              0.8324443832728455, 0.2503873238203034, 0.17870208410375396`], 
             205 -> 
             RGBColor[
              0.18515378626434187`, 0.3119387471648751, 0.9338556062660495], 
             224 -> RGBColor[
              0.4977475489543879, 0.6031329093695432, 0.9536036568444898], 
             231 -> RGBColor[
              0.19120668731506069`, 0.31830072994527303`, 0.9342003100264233],
              332 -> RGBColor[
              0.8178049183525352, 0.13786198138836525`, 0.164683315963154], 
             68 -> RGBColor[
              0.8216043579673015, 0.8605890294596807, 0.9828465511894319], 10 -> 
             RGBColor[
              0.8429670986480872, 0.3312695252776902, 0.18877864823079255`], 
             250 -> RGBColor[
              0.19372013073248498`, 0.3209425183385029, 0.9343434469107393], 
             282 -> RGBColor[
              0.31502354175322494`, 0.44727929114822085`, 0.9412939994095033],
              374 -> RGBColor[
              0.1836365577609456, 0.3103440438099624, 0.9337692023473195], 
             232 -> RGBColor[
              0.19035994618760685`, 0.3174107513338308, 0.934152089371856], 
             253 -> RGBColor[
              0.8251923969012658, 0.19464537872765014`, 0.17175757376438203`],
              55 -> RGBColor[
              0.8037373305687819, 0.8466049783610714, 0.9810726838248541], 
             325 -> RGBColor[
              0.23827199083861747`, 0.36776934806112876`, 0.9368806094352129],
              91 -> RGBColor[
              0.5925759149291727, 0.6801188488370776, 0.961068893181775], 105 -> 
             RGBColor[
              0.9853022906708313, 0.9881901337255575, 0.8932426102441758], 36 -> 
             RGBColor[
              0.24565388341041777`, 0.3755281851931126, 0.9373009972966455], 
             123 -> RGBColor[
              0.843157812611701, 0.33273543637341757`, 0.18896127613772973`], 
             94 -> RGBColor[
              0.1791057270796212, 0.3055818534926332, 0.9335111782427814], 
             312 -> RGBColor[
              0.5478165382686445, 0.6437811704771209, 0.9575452710920592], 96 -> 
             RGBColor[
              0.21162927735784165`, 0.3397661669472325, 0.9353633463168451], 
             2 -> RGBColor[
              0.20182540810126717`, 0.3294616787573599, 0.9348050304662081], 
             262 -> RGBColor[
              0.36433321534571095`, 0.4899888520377754, 0.9444359682079841], 
             272 -> RGBColor[
              0.19665135271400355`, 0.3240234184912868, 0.9345103756662324], 
             97 -> RGBColor[
              0.2986247548964671, 0.43120392967218313`, 0.9403176100643942], 
             372 -> 
             RGBColor[
              0.179946795179367, 0.3064658693922636, 0.9335590758268132], 356 -> 
             RGBColor[
              0.9453835605713274, 0.9587877294170835, 0.9773355650906732], 
             346 -> RGBColor[
              0.20342618893072584`, 0.3311442009044876, 0.9348961925663027], 
             341 -> RGBColor[
              0.24934350578881678`, 0.3794062122483802, 0.9375111158327881], 
             209 -> RGBColor[
              0.2650455441851616, 0.3959100501696741, 0.9384053236903759], 
             378 -> RGBColor[
              0.24023703411797065`, 0.3698347331386689, 0.9369925157429511], 
             66 -> RGBColor[
              0.19612721011213427`, 0.3234725113841618, 0.9344805265204555], 
             139 -> RGBColor[
              0.30694355404168716`, 0.4399475150161388, 0.940791353369154], 
             56 -> RGBColor[
              0.5183980864407423, 0.6198979459970778, 0.9552293428008269], 
             335 -> RGBColor[
              0.1982643030525542, 0.3257187315640616, 0.9346022308018668], 
             314 -> RGBColor[
              0.18275376889499648`, 0.30941617673980293`, 0.9337189288273728],
              144 -> RGBColor[
              0.5812572311839399, 0.6709298314718057, 0.9601778449356456], 
             298 -> RGBColor[
              0.20546571259734456`, 0.33328786959137313`, 0.9350123404219118],
              204 -> RGBColor[
              0.17994083687002446`, 0.30645960683136597`, 0.9335587365099107],
              207 -> RGBColor[
              0.1915172466480543, 0.31862714749484833`, 0.934217995921006], 
             334 -> RGBColor[
              0.9602115875305376, 0.8774464833562946, 0.2999299602777051], 
             149 -> RGBColor[
              0.21032620428650672`, 0.3383965545296549, 0.9352891382331565], 
             219 -> RGBColor[0.178927, 0.305394, 0.933501], 400 -> 
             RGBColor[
              0.8221152183090297, 0.17099283563946593`, 0.16881086406928056`],
              9 -> RGBColor[
              0.6863588655876156, 0.7549080294084094, 0.9693734953996518], 11 -> 
             RGBColor[
              0.873192830390407, 0.9017242770380856, 0.9877671057427206], 44 -> 
             RGBColor[
              0.22831342724773274`, 0.3573022663177088, 0.9363134839710866], 
             153 -> RGBColor[
              0.20565135384863537`, 0.33348299031681494`, 0.9350229124165412],
              32 -> RGBColor[
              0.8215188663850046, 0.16640901342833042`, 0.16823979679335105`],
              162 -> RGBColor[
              0.19529691214488243`, 0.32259981557664835`, 0.9344332422795363],
              90 -> RGBColor[
              0.21556902434658207`, 0.3439070908267852, 0.9355877090795206], 
             331 -> RGBColor[
              0.24096885499463874`, 0.3706039232801706, 0.9370341918592453], 
             8 -> RGBColor[
              0.25559866423556843`, 0.38598078037586825`, 0.937867337852653], 
             364 -> RGBColor[
              0.92133834354613, 0.7258397751431882, 0.2555651886720716], 342 -> 
             RGBColor[
              0.18639411010760892`, 0.31324240616522253`, 0.9339262408740289],
              163 -> RGBColor[
              0.17905422337022397`, 0.30552771982853294`, 0.9335082451827241],
              49 -> RGBColor[
              0.18369802063003998`, 0.31040864518235156`, 0.9337727025667882],
              338 -> RGBColor[
              0.21013611726343454`, 0.33819676101619267`, 0.9352783130584011],
              76 -> RGBColor[
              0.2829350020755027, 0.41471300466956446`, 0.9394241018521495], 
             369 -> RGBColor[
              0.1804054273287139, 0.30694792086018496`, 0.933585194249233], 
             82 -> RGBColor[
              0.7597586089991939, 0.8122484668202457, 0.9766892958633172], 67 -> 
             RGBColor[
              0.17940647345367122`, 0.30589795700018124`, 0.9335283053038692],
              211 -> RGBColor[
              0.23248905082520588`, 0.3616911114474591, 
               0.9365512795565422]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9mGk41G3YxiVbGGbGGGMMZp+JsVWihTktLbQQJSTFQyShTSoPqYhQlpJK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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 5}], {
             RGBColor[
             0.18431548798727523`, 0.3110576425244974, 0.9338078664193217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.18382719114068813`, 0.31054441157892615`, 0.933780058636279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 73}], {
             RGBColor[
             0.19016251964762415`, 0.3172032435227433, 0.9341408462224705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[
             0.18373091059218155`, 0.31044321461790636`, 0.9337745756014759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 162}], {
             RGBColor[
             0.18855509271436693`, 0.315513735899136, 0.9340493056365965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 183}], {
             RGBColor[
             0.18524860197516257`, 0.312038404488611, 0.9338610058805135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 291}], {
             RGBColor[
             0.1886369117353484, 0.31559973287781307`, 0.934053965108801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 357}], {
             RGBColor[
             0.18390843895748787`, 0.3106298081857918, 0.9337846855792504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 368}], {
             RGBColor[
             0.1828231865844723, 0.30948913913277776`, 0.9337228820620942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 387}], {
             RGBColor[
             0.1836776641650684, 0.31038724924699196`, 0.9337715432962228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 28}], {
             RGBColor[
             0.1967107027357332, 0.32408579912713337`, 0.9345137555621694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 39}], {
             RGBColor[
             0.19999978068083032`, 0.3275428285870168, 0.934701063685388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 50}], {
             RGBColor[
             0.216476564027812, 0.3448609725730971, 0.935639392121782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 106}], {
             RGBColor[
             0.19417223523988333`, 0.32141770884085996`, 0.9343691935936069]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 137}], {
             RGBColor[
             0.24723503321608348`, 0.3771900738895551, 0.9373910414389766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 138}], {
             RGBColor[
             0.24536530114030092`, 0.3752248669300471, 0.9372845629632816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 149}], {
             RGBColor[
             0.20607580619388693`, 0.3339291166435074, 0.9350470843496823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 164}], {
             RGBColor[
             0.20840908696131982`, 0.3363815426686245, 0.935179961237608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 197}], {
             RGBColor[
             0.1965684920257088, 0.3239363266542179, 0.9345056568726156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 210}], {
             RGBColor[
             0.223753059772891, 0.352509030957652, 0.9360537777898534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 217}], {
             RGBColor[
             0.20503618363244414`, 0.3328364074155535, 0.9349878793827919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 230}], {
             RGBColor[
             0.2114753909347174, 0.33960442255956613`, 0.9353545827127028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 254}], {
             RGBColor[
             0.19445154659843222`, 0.32171128278805783`, 0.9343850999622723]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 258}], {
             RGBColor[
             0.2197390144926751, 0.34829001486297484`, 0.935825183849393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 314}], {
             RGBColor[
             0.19228958849813182`, 0.3194389277485814, 0.9342619796467905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 328}], {
             RGBColor[
             0.2165885293871429, 0.3449786552647677, 0.935645768383358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 7}], {
             RGBColor[
             0.24558195815549755`, 0.37545258718986685`, 0.9372969012597816]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 13}], {
             RGBColor[
             0.2247891692476987, 0.3535980477088099, 0.9361127826916571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 14}], {
             RGBColor[
             0.28743237026540935`, 0.41667525783150516`, 0.9397814519424676]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 21}], {
             RGBColor[
             0.21644166427209716`, 0.34482429071706844`, 0.9356374046323236]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 51}], {
             RGBColor[
             0.2187121116641707, 0.34721067488081686`, 0.9357667032524762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 79}], {
             RGBColor[
             0.21763331081573253`, 0.34607678678918397`, 0.9357052671401005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 188}], {
             RGBColor[
             0.25601232241971317`, 0.38641556135484806`, 0.9378908950742876]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 232}], {
             RGBColor[
             0.21328768495463646`, 0.3415092584805786, 0.9354577901760884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 293}], {
             RGBColor[
             0.2751725873267546, 0.40605645004464963`, 0.939000269414517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 373}], {
             RGBColor[
             0.21710028788855346`, 0.3455165458971132, 0.9356749122729344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 390}], {
             RGBColor[
             0.22459916207358144`, 0.353398338121662, 0.9361019620641815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 84}], {
             RGBColor[
             0.20756604892203795`, 0.3354954562376403, 0.935131951468434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 125}], {
             RGBColor[
             0.196721601742191, 0.3240972546739574, 0.9345143762444637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 165}], {
             RGBColor[
             0.21319278532882907`, 0.3414095129568713, 0.9354523857827901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 184}], {
             RGBColor[
             0.20719899217930893`, 0.3351096563282905, 0.9351110481299474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 185}], {
             RGBColor[
             0.1966973229914563, 0.32407173616757357`, 0.9345129936055264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 190}], {
             RGBColor[
             0.20649883851719153`, 0.33437375043709894`, 0.9350711754146743]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.1963748100004493, 0.3237327545655205, 0.9344946269678038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 252}], {
             RGBColor[
             0.20339315185029538`, 0.3311094768382833, 0.9348943111534462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 274}], {
             RGBColor[
             0.2019924165278475, 0.3296372152026416, 0.934814541349035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 288}], {
             RGBColor[
             0.2072894767278965, 0.33520476132590776`, 0.9351162010911295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 318}], {
             RGBColor[
             0.20715075077545358`, 0.3350589515541568, 0.9351083008533645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.18632940584411195`, 0.31317439788179996`, 0.9339225560619441]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 113}], {
             RGBColor[
             0.18623312529560537`, 0.31307320092078017`, 0.9339170730271409]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 162}], {
             RGBColor[
             0.19105730741779076`, 0.3181437222020098, 0.9341918030622616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 183}], {
             RGBColor[
             0.1877508166785864, 0.3146683907914848, 0.9340035033061785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 270}], {
             RGBColor[
             0.19738135324155764`, 0.32479069533045285`, 0.9345519481163376]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 291}], {
             RGBColor[
             0.19113912643877223`, 0.3182297191806869, 0.9341964625344661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 357}], {
             RGBColor[
             0.1864106536609117, 0.3132597944886656, 0.9339271830049154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 368}], {
             RGBColor[
             0.18532540128789612`, 0.31211912543565157`, 0.9338653794877592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 10}], {
             RGBColor[
             0.8706991660194285, 0.5355001809409162, 0.45679225765188536`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.6643840547861006, 0.7335496374888852, 0.969847038397682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 69}], {
             RGBColor[
             0.7494906190968638, 0.8040199624425932, 0.9761664746556911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 71}], {
             RGBColor[
             0.9479335881069795, 0.9604436363507414, 0.9644935461230137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 93}], {
             RGBColor[
             0.6343460318717724, 0.7075322117954237, 0.9679330421391619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 129}], {
             RGBColor[
             0.8549452081615826, 0.4144083574171603, 0.44170624981566164`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 131}], {
             RGBColor[
             0.8701371040264215, 0.8993351938028649, 0.9874630507499915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 142}], {
             RGBColor[
             0.7001614603741532, 0.763972329138221, 0.9722831025823769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 201}], {
             RGBColor[
             0.7959386825090102, 0.8413708229845736, 0.9800676455168078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 253}], {
             RGBColor[
             0.858849364854881, 0.44441741657422273`, 0.4454448746742784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 273}], {
             RGBColor[
             0.7251045855702409, 0.7842222818473898, 0.9742467167674911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 281}], {
             RGBColor[
             0.6624572537085711, 0.7318807392393671, 0.9697242643368251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 303}], {
             RGBColor[
             0.9100466794366213, 0.777602242030947, 0.6130122278904285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 364}], {
             RGBColor[
             0.9237508221541206, 0.8349006337052781, 0.6241923325830713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 391}], {
             RGBColor[
             0.8555439090552986, 0.41901023483866595`, 0.44227956646762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 394}], {
             RGBColor[
             0.6418942074247149, 0.7140700620770483, 0.9684140052108057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 13}], {
             RGBColor[
             0.23415570368153021`, 0.3634428692713504, 0.9366461929711178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 14}], {
             RGBColor[
             0.29679890469924086`, 0.4265200793940456, 0.9403148622219284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 21}], {
             RGBColor[
             0.22580819870592864`, 0.3546691122796089, 0.9361708149117844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 93}], {
             RGBColor[
             0.29873862778538124`, 0.4282001700379434, 0.9404384596617476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 142}], {
             RGBColor[
             0.36455405628776205`, 0.4846402873807406, 0.9447885201049626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 188}], {
             RGBColor[
             0.2653788568535447, 0.3962603829173885, 0.9384243053537484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 273}], {
             RGBColor[
             0.3894971814838498, 0.5048902400899095, 0.9467521342900769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 293}], {
             RGBColor[
             0.28453912176058604`, 0.41590127160719004`, 0.9395336796939777]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 390}], {
             RGBColor[
             0.23396569650741295`, 0.36324315968420245`, 0.9366353723436424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 16}], {
             RGBColor[
             0.24227617377409713`, 0.3719779982061794, 0.9371086417297306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 25}], {
             RGBColor[
             0.3097802502292844, 0.43782398124180466`, 0.9411398210556678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 76}], {
             RGBColor[
             0.26926683315553557`, 0.4003468925227164, 0.9386457198524012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 117}], {
             RGBColor[
             0.40706513411417244`, 0.5192304619580248, 0.9481280690845475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 202}], {
             RGBColor[
             0.2915950820053508, 0.42207290253936436`, 0.9399810782169516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 234}], {
             RGBColor[
             0.2512674523014992, 0.38142840201846384`, 0.9376206817404615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 239}], {
             RGBColor[
             0.3813679879787836, 0.49836836108207505`, 0.9461050956090218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 269}], {
             RGBColor[
             0.30450100126350144`, 0.4332513611304116, 0.9408034319798247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 302}], {
             RGBColor[
             0.22515004974021374`, 0.353977355987588, 0.936133334301831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 323}], {
             RGBColor[
             0.3381102648791732, 0.4623620160236, 0.9429449845379104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 365}], {
             RGBColor[
             0.2808078228071327, 0.4124772043875522, 0.9393029621396956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 377}], {
             RGBColor[
             0.25514638831763914`, 0.3855054097101751, 0.9378415814082092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 388}], {
             RGBColor[
             0.26319007599843486`, 0.3939598354619466, 0.938299657522061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 18}], {
             RGBColor[
             0.8394473584119997, 0.8706756474406323, 0.6991625748728455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 56}], {
             RGBColor[
             0.6023784760141789, 0.6874029877027437, 0.9623014191002394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 65}], {
             RGBColor[
             0.531426491162083, 0.6277150215031269, 0.9572921727453987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 100}], {
             RGBColor[
             0.5370355289675518, 0.6325732881317867, 0.9576495756744858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 174}], {
             RGBColor[
             0.5520972673558275, 0.6456190088987284, 0.9586092963260144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 198}], {
             RGBColor[
             0.7575782172127392, 0.8106163649808842, 0.9764530707316865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 203}], {
             RGBColor[
             0.4981842108201723, 0.5989222290765547, 0.9551740040370065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 266}], {
             RGBColor[
             0.6722902895010364, 0.7439175508444353, 0.9679712712136599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 313}], {
             RGBColor[
             0.4854882204226317, 0.5856947625868548, 0.9544467086526902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 339}], {
             RGBColor[
             0.5341582021850244, 0.6300810922914106, 0.9574662349562233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 358}], {
             RGBColor[
             0.48197798109692647`, 0.5820052784935108, 0.954246805716025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 384}], {
             RGBColor[
             0.8099718019563749, 0.7646503394906032, 0.6173962103853706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 32}], {
             RGBColor[
             0.8358176878937263, 0.2763160213279036, 0.18193236441831204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 52}], {
             RGBColor[
             0.8916429525013146, 0.5507520246580102, 0.4032025959775474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 60}], {
             RGBColor[
             0.7976526644820038, 0.4778635602594288, 0.44966349300497443`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 68}], {
             RGBColor[
             0.8358461850878253, 0.5077093600050204, 0.4534679492170056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.8350901197191642, 0.27072361351581226`, 0.18123564431268066`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 253}], {
             RGBColor[
             0.8370421980658134, 0.2857281430943435, 0.18310495674198904`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 271}], {
             RGBColor[
             0.8353123166962146, 0.27243151684875794`, 0.18144842038883974`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 303}], {
             RGBColor[
             0.8599547518024352, 0.42459401411663544`, 0.20358742524945703`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 333}], {
             RGBColor[
             0.8799035766623403, 0.5425287482789902, 0.44689524966387445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 334}], {
             RGBColor[
             0.8820485949422373, 0.5133285113038917, 0.2258290855797634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 337}], {
             RGBColor[
             0.8809711396763451, 0.543324935026861, 0.44508814394619167`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 345}], {
             RGBColor[
             0.8380059756120399, 0.5094315183430771, 0.453673951965273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 353}], {
             RGBColor[
             0.8930646658031626, 0.5501769231578431, 0.29510210612227733`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 364}], {
             RGBColor[
             0.8690908469474348, 0.46279294189952286`, 0.21104082837788557`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 391}], {
             RGBColor[
             0.8353894701660223, 0.27302455222656513`, 0.18152230263865984`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 54}], {
             RGBColor[
             0.9107233154962703, 0.8671374351819781, 0.6324945514745149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 83}], {
             RGBColor[
             0.9120888802991098, 0.9323447493793293, 0.977810506555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 118}], {
             RGBColor[
             0.6153201099210919, 0.6928744863891039, 0.9658821576068201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 123}], {
             RGBColor[
             0.853169485204603, 0.5223983832616403, 0.45522988600606007`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 141}], {
             RGBColor[
             0.6144798263952078, 0.6921466750328611, 0.9658286154835842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 161}], {
             RGBColor[
             0.8763695857039919, 0.7238270844566292, 0.6044849794547379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 196}], {
             RGBColor[
             0.8586587168624804, 0.8901351694289188, 0.9863808290196707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 206}], {
             RGBColor[
             0.6510406164097462, 0.7238137937447175, 0.9681582366938735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 214}], {
             RGBColor[
             0.8760571062553216, 0.722408188261647, 0.6042242389431952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 286}], {
             RGBColor[
             0.5972181184299319, 0.677195451192008, 0.9647287147159659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 332}], {
             RGBColor[
             0.8362675556984924, 0.39248274660493876`, 0.43904457922300955`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 366}], {
             RGBColor[
             0.9332464444239088, 0.9449010522417576, 0.749948999978632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 386}], {
             RGBColor[
             0.6075598618760001, 0.6861529495738531, 0.9653876814635047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 19}], {
             RGBColor[
             0.22114916866345258`, 0.3497721763054004, 0.9359054900432826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 24}], {
             RGBColor[
             0.25148362362516946`, 0.3816556117856949, 0.9376329923775478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 65}], {
             RGBColor[
             0.30963980079837916`, 0.4365176650238572, 0.941174248166886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 100}], {
             RGBColor[
             0.315248838603848, 0.44137593165251704`, 0.941531651095973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 107}], {
             RGBColor[
             0.23293330946253646`, 0.362158055442918, 0.9365765794287164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 124}], {
             RGBColor[
             0.23470207361547668`, 0.3640171387137828, 0.9366773079305742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 150}], {
             RGBColor[
             0.24059607423843102`, 0.37021210706973123`, 0.937012962546659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 157}], {
             RGBColor[
             0.24482342257705114`, 0.37465531820298625`, 0.937253703780742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 167}], {
             RGBColor[
             0.2392959832955554, 0.36884562905824225`, 0.9369389242907744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 168}], {
             RGBColor[
             0.22037492795635888`, 0.34895840023254887`, 0.9358613981804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 203}], {
             RGBColor[
             0.2763975204564685, 0.40772487259728496`, 0.9390560794584938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 206}], {
             RGBColor[
             0.33583694364464667`, 0.4592083134506097, 0.9428435069438263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 211}], {
             RGBColor[
             0.23763726784270695`, 0.3671022139486645, 0.9368444628995842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 238}], {
             RGBColor[
             0.2218338423144311, 0.3504918117233956, 0.9359444811948219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 341}], {
             RGBColor[
             0.2460644953245124, 0.3759597643491251, 0.9373243810377072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 358}], {
             RGBColor[
             0.26019129073322267`, 0.39080792201424114`, 0.9381288811375124]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 14}], {
             RGBColor[
             0.27600611579144196`, 0.4046655399129887, 0.9391307436538039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 21}], {
             RGBColor[
             0.2050154097981298, 0.332814572798552, 0.9349866963436598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 51}], {
             RGBColor[
             0.20728585719020337`, 0.33520095696230034`, 0.9351159949638125]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 79}], {
             RGBColor[
             0.20620705634176517`, 0.33406706887066745`, 0.9350545588514367]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 87}], {
             RGBColor[
             0.2001057560025477, 0.3276542153693653, 0.9347070988231834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 205}], {
             RGBColor[
             0.19925835051903662`, 0.3267635384775842, 0.9346588403345214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 232}], {
             RGBColor[
             0.20186143048066912`, 0.3294995405620621, 0.9348070818874247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 277}], {
             RGBColor[
             0.19923872667069553`, 0.3267429125687539, 0.9346577227853893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 373}], {
             RGBColor[
             0.2056740334145861, 0.3335068279785967, 0.9350242039842707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 390}], {
             RGBColor[
             0.2131729075996141, 0.34138862020314553`, 0.9354512537755177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 69}], {
             RGBColor[
             0.45573362712038445`, 0.5659105913267511, 0.9511564428609628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 71}], {
             RGBColor[
             0.6541765961305002, 0.7223342652348994, 0.9394835143282855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 201}], {
             RGBColor[
             0.5021816905325309, 0.6032614518687315, 0.9550576137220795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 212}], {
             RGBColor[
             0.45821441723172895`, 0.5679246084974616, 0.9513517397459614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 273}], {
             RGBColor[
             0.4313475935937616, 0.5461129107315478, 0.9492366849727629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 289}], {
             RGBColor[
             0.4064318553204269, 0.5258851919600367, 0.9472752267865294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 293}], {
             RGBColor[
             0.32638953387049785`, 0.45712394224882835`, 0.9420182303766638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 390}], {
             RGBColor[
             0.27581610861732475`, 0.40446583032584077`, 0.9391199230263283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 35}], {
             RGBColor[
             0.1861148468094702, 0.312948882732563, 0.933910337242333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 106}], {
             RGBColor[
             0.18432449600494816`, 0.311067110522213, 0.933808379412602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 154}], {
             RGBColor[
             0.18425132424679044`, 0.31099020236503183`, 0.933804212389223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 207}], {
             RGBColor[
             0.18682358813972555`, 0.3136938148074571, 0.9339506990126021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 231}], {
             RGBColor[
             0.18666830847322874`, 0.31353060603266947`, 0.9339418560653108]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 369}], {
             RGBColor[
             0.18126767848005537`, 0.30785420149012543`, 0.9336342981767156]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 372}], {
             RGBColor[
             0.1810383624053819, 0.30761317575616476`, 0.9336212389655058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 392}], {
             RGBColor[
             0.19259602959164984`, 0.3197610167673564, 0.9342794310137273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 25}], {
             RGBColor[
             0.2964577597678131, 0.4238211990721158, 0.9403811249327455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 37}], {
             RGBColor[
             0.25664259349321183`, 0.38707801621458926`, 0.9379267880795208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 76}], {
             RGBColor[
             0.2559443426940643, 0.3863441103530275, 0.937887023729479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 77}], {
             RGBColor[
             0.21295289463759554`, 0.3411573726304365, 0.9354387243628108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 78}], {
             RGBColor[
             0.22470970081672578`, 0.3535145213492678, 0.9361082570820762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 80}], {
             RGBColor[
             0.21603013302378776`, 0.34439174528250716`, 0.9356139685365383]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 96}], {
             RGBColor[
             0.22029148033523374`, 0.34887069149186156`, 0.9358566459618267]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 182}], {
             RGBColor[
             0.23539065510704868`, 0.36474088152001305`, 0.9367165216278543]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.22265042245962569`, 0.35135008923016664`, 0.9359909842260687]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 269}], {
             RGBColor[
             0.29117851080203017`, 0.41924857896072276`, 0.9400447358569024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 302}], {
             RGBColor[
             0.21182755927874247`, 0.3399745738178992, 0.9353746381789088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 323}], {
             RGBColor[
             0.3247877744177019, 0.4483592338539112, 0.9421862884149881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 365}], {
             RGBColor[
             0.2674853323456614, 0.39847442221786333`, 0.9385442660167731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 377}], {
             RGBColor[
             0.24182389785616784`, 0.37150262754048624`, 0.9370828852852868]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 388}], {
             RGBColor[
             0.24986758553696356`, 0.3799570532922577, 0.9375409613991386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 18}], {
             RGBColor[
             0.8826197426994277, 0.4712313788077837, 0.2590653315299285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 31}], {
             RGBColor[
             0.879860588532459, 0.47166977479957617`, 0.4195957023627799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 62}], {
             RGBColor[
             0.8823757434978273, 0.4727098560142903, 0.37791307557422715`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.8524964894376759, 0.4506925466333933, 0.4462583138303914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 111}], {
             RGBColor[
             0.8273118204939984, 0.2109361971987341, 0.17378713619032946`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 222}], {
             RGBColor[
             0.8688036227970698, 0.46343086091223773`, 0.43864154601533567`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 223}], {
             RGBColor[
             0.8381799008988925, 0.29362230402542056`, 0.1841611101359005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 247}], {
             RGBColor[
             0.8242207072500726, 0.18717654627145935`, 0.17082708265703297`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 256}], {
             RGBColor[
             0.8825424426584894, 0.4727787904011971, 0.3751504390784578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 292}], {
             RGBColor[
             0.8249384204875226, 0.19269320471844653`, 0.1715143656637563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 310}], {
             RGBColor[
             0.8272800217278339, 0.2106917779476853, 0.17375668565593874`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 319}], {
             RGBColor[
             0.8292559200449149, 0.22587939825693307`, 0.17564880811583344`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 384}], {
             RGBColor[
             0.8629693717290111, 0.400547840174431, 0.20455442187161196`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 99}], {
             RGBColor[
             0.947350971343756, 0.9556350172112698, 0.7097411277967336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 144}], {
             RGBColor[
             0.7868965412101618, 0.8286865484723305, 0.6945647496408425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.9106667100371233, 0.9263839830131071, 0.7062421502048801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 218}], {
             RGBColor[
             0.776406098847213, 0.8201699347730458, 0.6937389035902746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 266}], {
             RGBColor[
             0.8253787823254205, 0.8596851688766582, 0.6977603506868537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 310}], {
             RGBColor[
             0.8818564092931963, 0.4653640637526585, 0.25833436259805964`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 319}], {
             RGBColor[
             0.8858082059273583, 0.49573930437115404`, 0.26211860751784904`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 384}], {
             RGBColor[
             0.9630602947807589, 0.8804179575228263, 0.3471852898585644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 24}], {
             RGBColor[
             0.22984730742841403`, 0.35891447164122536`, 0.936400836178204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 85}], {
             RGBColor[
             0.19070082938217475`, 0.3177690411845645, 0.9341715021654952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 107}], {
             RGBColor[
             0.211296993265781, 0.33941691529844853`, 0.9353444232293726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 124}], {
             RGBColor[
             0.21306575741872125`, 0.34127599856931323`, 0.9354451517312304]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 150}], {
             RGBColor[
             0.21895975804167556`, 0.3474709669252617, 0.9357808063473152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 152}], {
             RGBColor[
             0.2001783639532218, 0.3277305309291337, 0.9347112337385604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 157}], {
             RGBColor[
             0.2231871063802957, 0.35191417805851677`, 0.9360215475813982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 160}], {
             RGBColor[
             0.19740416245689973`, 0.32481466926196517`, 0.9345532470674082]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 167}], {
             RGBColor[
             0.21765966709879997`, 0.34610448891377266`, 0.9357067680914306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 168}], {
             RGBColor[
             0.19873861175960342`, 0.3262172600880793, 0.9346292419810562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 181}], {
             RGBColor[
             0.19581756515250187`, 0.3231470548989638, 0.9344628926980831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 211}], {
             RGBColor[
             0.2160009516459515, 0.344361073804195, 0.9356123067002404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 238}], {
             RGBColor[
             0.20019752611767563`, 0.32775067157892607`, 0.9347123249954781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 64}], {
             RGBColor[
             0.6886054780275248, 0.7470570557801346, 0.690028677840299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 88}], {
             RGBColor[
             0.40751079531136875`, 0.5273871016357587, 0.9471872054229611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 89}], {
             RGBColor[
             0.30842578765479933`, 0.4344898392135439, 0.9411326397648885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 120}], {
             RGBColor[
             0.3985867083579536, 0.5196575060543626, 0.9466185704935497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 140}], {
             RGBColor[
             0.3954861818985797, 0.5169719858722439, 0.9464210076892463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 189}], {
             RGBColor[
             0.30889970680782364`, 0.4349879582915822, 0.9411596287595527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 195}], {
             RGBColor[
             0.40462199010322386`, 0.5248849637600351, 0.9470031333095683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 241}], {
             RGBColor[
             0.33276855688740864`, 0.46007563309772936`, 0.9425189244607857]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 255}], {
             RGBColor[
             0.37940724758906264`, 0.5030452211240766, 0.9453964722130872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 257}], {
             RGBColor[
             0.6770229856308323, 0.7421397259892473, 0.9411883411446311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 263}], {
             RGBColor[
             0.3432288815576954, 0.4710700975490908, 0.943114624476095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 312}], {
             RGBColor[
             0.4662211223319299, 0.5756731791658605, 0.9516371294428863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 336}], {
             RGBColor[
             0.3097133743307097, 0.43584317444763615`, 0.9412059659212678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 356}], {
             RGBColor[
             0.6650046334832713, 0.7331764586358418, 0.9615322764421933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 359}], {
             RGBColor[
             0.3551576814248725, 0.48204146573128925`, 0.9438513113001545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 360}], {
             RGBColor[
             0.523690607917635, 0.622017048024192, 0.9563749606192402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 389}], {
             RGBColor[
             0.688874491712781, 0.747632448851442, 0.7193091573204213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 109}], {
             RGBColor[
             0.1897091064701492, 0.31672667752516137`, 0.9341150250127779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[
             0.19167285067202883`, 0.3187906971899105, 0.9342268573399758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 132}], {
             RGBColor[
             0.1947709663990963, 0.3220470132509409, 0.9344032904473808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 180}], {
             RGBColor[
             0.19254611619106632`, 0.3197085546186507, 0.9342765885194044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 232}], {
             RGBColor[
             0.19351392550506752`, 0.32072578357032067`, 0.9343317038280912]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 249}], {
             RGBColor[
             0.19014493822452405`, 0.31718476433233855`, 0.9341398449864342]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 370}], {
             RGBColor[
             0.19110729661804693`, 0.31819626402097745`, 0.9341946498732637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 45}], {
             RGBColor[
             0.24087710963769857`, 0.3705074930930349, 0.9370289670968927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 74}], {
             RGBColor[
             0.24528340650250224`, 0.37513879047330073`, 0.9372798991848111]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 116}], {
             RGBColor[
             0.24102708216235447`, 0.3706651237252555, 0.9370375078103073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 141}], {
             RGBColor[
             0.2988998919025237, 0.4271457198066904, 0.9404924581847806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 179}], {
             RGBColor[
             0.2344230766191157, 0.3637238951811761, 0.9366614194643705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 209}], {
             RGBColor[
             0.25353925279510015`, 0.38381620837770913`, 0.9377500574177445]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 286}], {
             RGBColor[
             0.2816381839372477, 0.41219449596583724`, 0.9393925574171622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 290}], {
             RGBColor[
             0.2497813465899759, 0.3798664106911086, 0.9375360502186867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 304}], {
             RGBColor[
             0.2621517349847551, 0.3928684732219464, 0.9382405255374198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 338}], {
             RGBColor[
             0.2260845393342366, 0.35495956380096844`, 0.9361865521017572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 38}], {
             RGBColor[
             0.23532272116707456`, 0.36466947864183974`, 0.936712652890472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 92}], {
             RGBColor[
             0.20814505737279243`, 0.33610403083063944`, 0.9351649251431382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 98}], {
             RGBColor[
             0.2025842284056299, 0.3302592470092312, 0.9348482441599675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 119}], {
             RGBColor[
             0.22585475434557115`, 0.35471804520867123`, 0.936173466186589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 128}], {
             RGBColor[
             0.2579108106564282, 0.38841099286274205`, 0.9379990111708069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 130}], {
             RGBColor[
             0.21379154943709947`, 0.3420388519985006, 0.935486484512964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 139}], {
             RGBColor[
             0.2594316195520534, 0.3900094594368974, 0.9380856189875776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 143}], {
             RGBColor[
             0.20541157212716055`, 0.3332309645245057, 0.9350092572022285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 146}], {
             RGBColor[
             0.20552449462249126`, 0.333349653226798, 0.9350156879712836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 151}], {
             RGBColor[
             0.20976599730073225`, 0.3378077414684315, 0.9352572352740687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 158}], {
             RGBColor[
             0.20153001639620693`, 0.3291512033464258, 0.9347882083455978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 186}], {
             RGBColor[
             0.209250396089514, 0.3372658119044362, 0.9352278725478533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 213}], {
             RGBColor[
             0.2686665233533321, 0.39817491739397315`, 0.9386679570758016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 267}], {
             RGBColor[
             0.20474185831720654`, 0.33252705284793593`, 0.9349711179915043]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 306}], {
             RGBColor[
             0.21710981978146196`, 0.345526564520917, 0.9356754551001344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 308}], {
             RGBColor[
             0.21238372481471685`, 0.3405591390591399, 0.9354063109834092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 311}], {
             RGBColor[
             0.2072579319428704, 0.33517160575679045`, 0.9351144046622886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 346}], {
             RGBColor[
             0.20767293699657277`, 0.3356078023810718, 0.935138038586152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 348}], {
             RGBColor[
             0.20651189165865158`, 0.3343874701163905, 0.93507191877177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 354}], {
             RGBColor[
             0.20401044687486744`, 0.3317582930478737, 0.9349294651918895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 374}], {
             RGBColor[
             0.19777812141168266`, 0.3252077238338092, 0.9345745434766604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 33}], {
             RGBColor[
             0.2533855843329195, 0.3836546930808141, 0.9377413062261555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 56}], {
             RGBColor[
             0.3892899244154366, 0.5053479265592988, 0.9466788406566481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 65}], {
             RGBColor[
             0.3183379395633406, 0.44565996035968214`, 0.9416695943018074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 100}], {
             RGBColor[
             0.32394697736880945`, 0.450518226988342, 0.9420269972308946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 107}], {
             RGBColor[
             0.2416314482274979, 0.371300350778743, 0.9370719255636378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 124}], {
             RGBColor[
             0.24340021238043813`, 0.3731594340496077, 0.9371726540654957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 150}], {
             RGBColor[
             0.24929421300339247`, 0.3793544024055562, 0.9375083086815804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 157}], {
             RGBColor[
             0.2535215613420126, 0.38379761353881126`, 0.9377490499156633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 167}], {
             RGBColor[
             0.24799412206051685`, 0.37798792439406714`, 0.9374342704256958]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 168}], {
             RGBColor[
             0.22907306672132033`, 0.35810069556837376`, 0.9363567443153216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 203}], {
             RGBColor[
             0.2850956592214299, 0.4168671679331099, 0.9395514255934152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 206}], {
             RGBColor[
             0.3445350824096081, 0.46835060878643464`, 0.9433388530787478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 211}], {
             RGBColor[
             0.2463354066076684, 0.3762445092844895, 0.9373398090345058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 238}], {
             RGBColor[
             0.23053198107939255`, 0.35963410705922055`, 0.9364398273297434]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 341}], {
             RGBColor[
             0.25476263408947386`, 0.38510205968495004`, 0.9378197271726287]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 358}], {
             RGBColor[
             0.2688894294981841, 0.3999502173500661, 0.9386242272724338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 386}], {
             RGBColor[
             0.3010543278758621, 0.4306897646155703, 0.940568297848379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 37}], {
             RGBColor[
             0.3241466699483991, 0.4529239992502145, 0.9419579674054581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 62}], {
             RGBColor[
             0.6778828449272916, 0.740272939600058, 0.8649535953688089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[
             0.32344841914925154`, 0.45219009338865274`, 0.9419182030554161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 78}], {
             RGBColor[
             0.29221377727191306`, 0.41936050438489303`, 0.9401394364080135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 91}], {
             RGBColor[
             0.47826887557608655`, 0.5848930154724093, 0.9527405987202289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 117}], {
             RGBColor[
             0.4612467201078884, 0.5710736628239611, 0.9514005522875624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 182}], {
             RGBColor[
             0.30289473156223595`, 0.4305868645556383, 0.9407477009537915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 187}], {
             RGBColor[
             0.29015449891481293`, 0.4171960722657919, 0.940022163552006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 208}], {
             RGBColor[
             0.3291899186131193, 0.4582247733572693, 0.9422451729560961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 239}], {
             RGBColor[
             0.43554957397249955`, 0.5502115619480115, 0.9493775788120367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 269}], {
             RGBColor[
             0.35868258725721747`, 0.48509456199634804`, 0.9440759151828396]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 309}], {
             RGBColor[
             0.5306642654095335, 0.6265873056000757, 0.957441478589943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 323}], {
             RGBColor[
             0.3922918508728892, 0.5142052168895364, 0.9462174677409253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 362}], {
             RGBColor[
             0.5776163710657185, 0.6632666473879071, 0.9621212256893779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 365}], {
             RGBColor[
             0.33498940880084865`, 0.4643204052534886, 0.9425754453427104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 377}], {
             RGBColor[
             0.3093279743113551, 0.4373486105761115, 0.941114064611224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 388}], {
             RGBColor[
             0.31737166199215083`, 0.44580303632788293`, 0.9415721407250759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 395}], {
             RGBColor[
             0.4013213562160271, 0.522026120581628, 0.946792819836912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 70}], {
             RGBColor[
             0.1896105861046007, 0.3166231263744179, 0.9341094144237078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 177}], {
             RGBColor[
             0.18182665700375172`, 0.3084417233598157, 0.9336661311767056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 285}], {
             RGBColor[
             0.1832664520031871, 0.30995503919249784`, 0.9337481253719375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 324}], {
             RGBColor[
             0.1839722969253371, 0.31069692695883033`, 0.9337883221960501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 40}], {
             RGBColor[
             0.19924073649984758`, 0.3267450250266232, 0.9346578372421862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 41}], {
             RGBColor[
             0.1999138771125005, 0.32745253849010136`, 0.9346961716042546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 48}], {
             RGBColor[
             0.20648582903789775`, 0.33436007664951256`, 0.9350704345440743]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 63}], {
             RGBColor[
             0.1971785692903057, 0.32457755654044196`, 0.9345403998703059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 86}], {
             RGBColor[
             0.23656599040606416`, 0.3659762334398404, 0.9367834552343804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 250}], {
             RGBColor[
             0.19937642447535237`, 0.3268876416919933, 0.9346655644716588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 265}], {
             RGBColor[
             0.20201462184730384`, 0.32966055440128883`, 0.9348158059091283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 295}], {
             RGBColor[
             0.19546687096427723`, 0.32277845307184394`, 0.9344429211828693]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 325}], {
             RGBColor[
             0.22165235452841858`, 0.35030105655330623`, 0.9359341457338957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 376}], {
             RGBColor[
             0.24560585367761548`, 0.37547770289867644`, 0.937298262074416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 39}], {
             RGBColor[
             0.19488507531529636`, 0.3221669489567903, 0.9344097887813494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 50}], {
             RGBColor[
             0.21136185866227802`, 0.33948509294287055`, 0.9353481172177434]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 106}], {
             RGBColor[
             0.18905752987434937`, 0.31604182921063345`, 0.9340779186895682]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 197}], {
             RGBColor[
             0.19145378666017485`, 0.3185604470239914, 0.9342143819685769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 217}], {
             RGBColor[
             0.19992147826691017`, 0.32746052778532697`, 0.9346966044787532]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 231}], {
             RGBColor[
             0.19140134234262995`, 0.31850532472108994`, 0.934211395342277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 254}], {
             RGBColor[
             0.1893368412328983, 0.3163354031578313, 0.9340938250582336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 314}], {
             RGBColor[
             0.18717488313259786`, 0.3140630481183549, 0.9339707047427519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 369}], {
             RGBColor[
             0.1860007123494566, 0.3128289201785459, 0.9339038374536819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 113}], {
             RGBColor[
             0.1857448284490183, 0.3125599699752089, 0.9338892652440982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 162}], {
             RGBColor[
             0.19056901057120365`, 0.3176304912564385, 0.9341639952792189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 183}], {
             RGBColor[
             0.18726251983199932`, 0.31415515984591347`, 0.9339756955231359]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 270}], {
             RGBColor[
             0.19689305639497057`, 0.3242774643848816, 0.9345241403332949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 357}], {
             RGBColor[
             0.18592235681432462`, 0.3127465635430944, 0.9338993752218727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 153}], {
             RGBColor[
             0.2031751711317593, 0.3308803652823261, 0.9348818974739992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 168}], {
             RGBColor[
             0.19933167973369648`, 0.3268406121315325, 0.9346630163248155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 175}], {
             RGBColor[
             0.19541782934736363`, 0.32272690722304953`, 0.9344401283353366]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 211}], {
             RGBColor[
             0.21659401962004457`, 0.3449844258476482, 0.9356460810439997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 216}], {
             RGBColor[
             0.208257693184232, 0.33622241820998533`, 0.93517133958597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 229}], {
             RGBColor[
             0.19931037008134544`, 0.32681821433580155`, 0.9346618027716389]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 294}], {
             RGBColor[
             0.2052159577699056, 0.3330253614323641, 0.9349981172539683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 329}], {
             RGBColor[
             0.23151896311630302`, 0.36067148775828894`, 0.9364960344966363]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 341}], {
             RGBColor[
             0.22502124710185, 0.35384197624810876`, 0.9361259991821227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 343}], {
             RGBColor[
             0.2007094287814945, 0.32828871373510315`, 0.9347414770948905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 358}], {
             RGBColor[
             0.2391480425105603, 0.3686901339132248, 0.9369304992819277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 379}], {
             RGBColor[
             0.19158357625518677`, 0.31869686411748455`, 0.9342217732940062]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 99}], {
             RGBColor[
             0.9432122400933031, 0.9562926111989585, 0.9505366840460105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 111}], {
             RGBColor[
             0.8791608526585568, 0.4662912982465486, 0.4189256344996925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 169}], {
             RGBColor[
             0.7207585549931849, 0.779010354243588, 0.9304794974284005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 199}], {
             RGBColor[
             0.9864970705564884, 0.9886842059127192, 0.8734420155476115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 215}], {
             RGBColor[
             0.8451646800561206, 0.8790328648583385, 0.9409404903646027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 222}], {
             RGBColor[
             0.967672940132394, 0.9754000826172251, 0.9391115323234271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 223}], {
             RGBColor[
             0.9008970134683449, 0.6316635118999215, 0.4396735823908346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 224}], {
             RGBColor[
             0.7410029688449329, 0.7954456814088879, 0.9320732118445416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 247}], {
             RGBColor[
             0.8729786261707051, 0.41877199639199914`, 0.4130055274330995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 259}], {
             RGBColor[
             0.9398415048836066, 0.9536048784389164, 0.9502151803126189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 292}], {
             RGBColor[
             0.8744140526456051, 0.4298053132859735, 0.4143800934465462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 363}], {
             RGBColor[
             0.6793920980440895, 0.7432878081939467, 0.9278140990011539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 383}], {
             RGBColor[
             0.6712879724630387, 0.7362684219408357, 0.9272977112853262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 393}], {
             RGBColor[
             0.8531150739602782, 0.8852437730014981, 0.9417329113283139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 400}], {
             RGBColor[
             0.8761629417845124, 0.4432480415757216, 0.4160548316610515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 46}], {
             RGBColor[
             0.8161914025598732, 0.393609503483597, 0.4392438664351634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 52}], {
             RGBColor[
             0.8773441309925929, 0.440845016758437, 0.3895100283525863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 71}], {
             RGBColor[
             0.8709138694072857, 0.43658126909692513`, 0.4242157364462195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 105}], {
             RGBColor[
             0.8761133411469468, 0.4403360535274061, 0.40990740127695935`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 111}], {
             RGBColor[
             0.8232166057967019, 0.1794585825007891, 0.16986555397131473`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 129}], {
             RGBColor[
             0.8207912982104425, 0.1608166056162391, 0.16754307668771967`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 199}], {
             RGBColor[
             0.8772578283825027, 0.4408093284112888, 0.39094028594577723`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 215}], {
             RGBColor[
             0.7830362347155908, 0.3677084343750351, 0.4359392691571047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 247}], {
             RGBColor[
             0.820125492552776, 0.15569893157351436`, 0.16690550043801822`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 259}], {
             RGBColor[
             0.8461541179339149, 0.41742311009542027`, 0.44212239578911544`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 271}], {
             RGBColor[
             0.8210134951874929, 0.16252450894918472`, 0.16775585276387872`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 287}], {
             RGBColor[
             0.8201189109233364, 0.1556483422855536, 0.16689919786223403`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 292}], {
             RGBColor[
             0.820843205790226, 0.16121559002050154`, 0.16759278344474157`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 303}], {
             RGBColor[
             0.8456559302937136, 0.31468700621706225`, 0.18989485762449604`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 333}], {
             RGBColor[
             0.8656047551536187, 0.43262174037941703`, 0.4332026820389135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 337}], {
             RGBColor[
             0.8666723181676234, 0.43341792712728777`, 0.43139557632123066`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 345}], {
             RGBColor[
             0.8237071541033182, 0.3995245104435039, 0.439981384340312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 353}], {
             RGBColor[
             0.8787658442944408, 0.4402699152582698, 0.2814095384973163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 385}], {
             RGBColor[
             0.8791517721101495, 0.4410953758327831, 0.323415399566809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 391}], {
             RGBColor[
             0.8210906486573005, 0.1631175443269919, 0.16782973501369886`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 400}], {
             RGBColor[
             0.8217176503596796, 0.1679369541653756, 0.16843015255199423`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 58}], {
             RGBColor[
             0.21989646734481127`, 0.3484555077936574, 0.9358341505563915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 74}], {
             RGBColor[
             0.24756162893783695`, 0.3775333467004828, 0.9374096405821755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 107}], {
             RGBColor[
             0.23483527017028652`, 0.36415713673803723`, 0.9366848932773241]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 116}], {
             RGBColor[
             0.24330530459768918`, 0.3730596799524376, 0.9371672492076716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 118}], {
             RGBColor[
             0.30201839786374246`, 0.43026808739011524`, 0.9406757417053806]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 124}], {
             RGBColor[
             0.23660403432322674`, 0.366016220008902, 0.9367856217791819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 141}], {
             RGBColor[
             0.3011781143378584, 0.42954027603387246`, 0.9406221995821449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 150}], {
             RGBColor[
             0.24249803494618108`, 0.37221118836485045`, 0.9371212763952667]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 152}], {
             RGBColor[
             0.2237166408577273, 0.3524707523687224, 0.9360517037865118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 156}], {
             RGBColor[
             0.22423055163894667`, 0.35301090518360945`, 0.9360809702452394]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 157}], {
             RGBColor[
             0.2467253832848012, 0.3766543994981055, 0.9373620176293496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 179}], {
             RGBColor[
             0.23670129905445042`, 0.3661184514083582, 0.9367911608617348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 206}], {
             RGBColor[
             0.33773890435239673`, 0.4612073947457289, 0.942951820792434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 209}], {
             RGBColor[
             0.25581747523043485`, 0.38621076460489123`, 0.9378797988151089]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 245}], {
             RGBColor[
             0.22074175679161856`, 0.34934396059669826`, 0.9358822885398935]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 286}], {
             RGBColor[
             0.2839164063725824, 0.41458905219301934`, 0.9395222988145264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 386}], {
             RGBColor[
             0.2942581498186507, 0.4235465505748645, 0.9401812655620653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 43}], {
             RGBColor[
             0.18881744465394812`, 0.3157894844217095, 0.9340642461914408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 159}], {
             RGBColor[
             0.1825395439463383, 0.30919101273611693`, 0.9337067290334642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 250}], {
             RGBColor[
             0.1883288985198916, 0.31527599145920215`, 0.9340364242118455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 265}], {
             RGBColor[
             0.19096709589184307`, 0.31804890416849774`, 0.9341866656493147]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 321}], {
             RGBColor[
             0.18374554341254123`, 0.3104585946398788, 0.9337754089189481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 375}], {
             RGBColor[
             0.19286667153168213`, 0.3200454786060204, 0.9342948436718334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 381}], {
             RGBColor[
             0.18614322275265005`, 0.3129787076479837, 0.9339119532103186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 73}], {
             RGBColor[
             0.19430576499947028`, 0.3215580570844616, 0.9343767979158759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 154}], {
             RGBColor[
             0.18823624142486384`, 0.31517860297752887`, 0.9340311475273575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 207}], {
             RGBColor[
             0.19080850531779897`, 0.3178822154199542, 0.9341776341507367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 231}], {
             RGBColor[
             0.19065322565130216`, 0.31771900664516656`, 0.9341687912034454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 280}], {
             RGBColor[
             0.19951437129521365`, 0.3270326325460011, 0.9346734203389759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 291}], {
             RGBColor[
             0.19278015708719454`, 0.31995454643953136`, 0.9342899168022064]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 372}], {
             RGBColor[
             0.18502327958345532`, 0.31180157636866185`, 0.9338481741036404]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 387}], {
             RGBColor[
             0.1878209095169145, 0.3147420628087102, 0.9340074949896282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 392}], {
             RGBColor[
             0.19658094676972326`, 0.3239494173798535, 0.934506366151862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 61}], {
             RGBColor[
             0.23146005042347673`, 0.36060956678284806`, 0.9364926795059334]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 70}], {
             RGBColor[
             0.22130912604082534`, 0.3499403016509027, 0.9359145993792883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 90}], {
             RGBColor[
             0.2306114538784999, 0.35971763800994894`, 0.9364443531880831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 95}], {
             RGBColor[
             0.2464425329575721, 0.37635710587044113`, 0.9373459097216534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 148}], {
             RGBColor[
             0.2511034439451054, 0.38125601883716365`, 0.9376113417071936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 228}], {
             RGBColor[
             0.23483092925025606`, 0.364152574155855, 0.9366846460683501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 276}], {
             RGBColor[
             0.31234957064668134`, 0.4391299345139409, 0.941337201922877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 282}], {
             RGBColor[
             0.28033871258182136`, 0.4114037381706667, 0.9392974983530744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 301}], {
             RGBColor[
             0.2477609938146631, 0.37774289182649035`, 0.9374209941169768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 305}], {
             RGBColor[
             0.2718566625317226, 0.40306896740175535`, 0.9387932068040659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 361}], {
             RGBColor[
             0.32761397052464425`, 0.4523511904771868, 0.9423098359853219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 382}], {
             RGBColor[
             0.2838749254794549, 0.4144666280473688, 0.9395228227119613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 76}], {
             RGBColor[
             0.28363325287465024`, 0.4154469105311262, 0.9394638662021915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 78}], {
             RGBColor[
             0.25239861099731176`, 0.3826173215273665, 0.9376850995547887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 80}], {
             RGBColor[
             0.24371904320437376`, 0.3734945454606058, 0.9371908110092508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 96}], {
             RGBColor[
             0.24798039051581972`, 0.3779734916699602, 0.9374334884345392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 104}], {
             RGBColor[
             0.2541903466574486, 0.3845005493087726, 0.9377871362499982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 117}], {
             RGBColor[
             0.4214315538332871, 0.5343304799664346, 0.9489462154343377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 145}], {
             RGBColor[
             0.2671022972631469, 0.3980718280603137, 0.9385224527354736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 182}], {
             RGBColor[
             0.26307956528763465`, 0.3938436816981118, 0.9382933641005669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 187}], {
             RGBColor[
             0.2503393326402117, 0.3804528894082654, 0.9375678266987812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 208}], {
             RGBColor[
             0.289374752338518, 0.42148159049974276`, 0.9397908361028714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 269}], {
             RGBColor[
             0.3188674209826161, 0.4483513791388215, 0.9416215783296149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 323}], {
             RGBColor[
             0.35247668459828785`, 0.4774620340320098, 0.9437631308877006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 365}], {
             RGBColor[
             0.29517424252624735`, 0.4275772223959621, 0.9401211084894857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 377}], {
             RGBColor[
             0.2695128080367538, 0.400605427718585, 0.9386597277579993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 388}], {
             RGBColor[
             0.27755649571754953`, 0.4090598534703564, 0.9391178038718512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 395}], {
             RGBColor[
             0.3615061899414258, 0.48528293772410147`, 0.9443384829836874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 44}], {
             RGBColor[
             0.24351959225973108`, 0.37328490987186613`, 0.9371794525730147]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 66}], {
             RGBColor[
             0.22742648369193186`, 0.3563700324050926, 0.9362629738476992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 81}], {
             RGBColor[
             0.2439408678768847, 0.37372769725591143`, 0.9372034435961902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 119}], {
             RGBColor[
             0.249257790450226, 0.37931611999285497`, 0.9375062344710599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 128}], {
             RGBColor[
             0.281313846761083, 0.4130090676469258, 0.9393317794552777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 130}], {
             RGBColor[
             0.23719458554175432`, 0.36663692678268434`, 0.9368192527974348]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 135}], {
             RGBColor[
             0.2970405045044002, 0.42707857493039736`, 0.9403174695829958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 146}], {
             RGBColor[
             0.2289275307271461, 0.3579477280109817, 0.9363484562557545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 151}], {
             RGBColor[
             0.23316903340538708`, 0.36240581625261525`, 0.9365900035585395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 213}], {
             RGBColor[
             0.2920695594579869, 0.42277299217815684`, 0.9400007253602725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 224}], {
             RGBColor[
             0.37823665311305865`, 0.49620023139778335`, 0.9458245390097163]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 227}], {
             RGBColor[
             0.2663587998591236, 0.39729036514822713`, 0.9384801116582203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 243}], {
             RGBColor[
             0.24505985490147014`, 0.37490382356662577`, 0.9372671682518474]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 267}], {
             RGBColor[
             0.22814489442186137`, 0.3571251276321197, 0.9363038862759752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 306}], {
             RGBColor[
             0.24051285588611682`, 0.3701246393051007, 0.9370082233846052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 311}], {
             RGBColor[
             0.23066096804752526`, 0.35976968054097413`, 0.9364471729467594]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 346}], {
             RGBColor[
             0.23107597310122763`, 0.36020587716525554`, 0.9364708068706228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 350}], {
             RGBColor[
             0.3036355127427933, 0.43279083959174136`, 0.9407376976762094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 363}], {
             RGBColor[
             0.3166257823122153, 0.444042358182842, 0.9415654261663287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 383}], {
             RGBColor[
             0.3085216567311646, 0.43702297192973105`, 0.9410490384505009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 47}], {
             RGBColor[
             0.18958921033534365`, 0.3166006590856267, 0.9341081971052712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 50}], {
             RGBColor[
             0.21465093660737516`, 0.342942122402754, 0.9355354253409618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 136}], {
             RGBColor[
             0.19040517985093924`, 0.31745829478197307`, 0.9341546653620656]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 149}], {
             RGBColor[
             0.2042501787734501, 0.33201026647316434`, 0.9349431175688622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 164}], {
             RGBColor[
             0.20658345954088297`, 0.3344626924982814, 0.9350759944567879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 197}], {
             RGBColor[
             0.19474286460527196`, 0.3220174764838748, 0.9344016900917953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 210}], {
             RGBColor[
             0.22192743235245416`, 0.35059018078730897`, 0.9359498110090333]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 217}], {
             RGBColor[
             0.2032105562120073, 0.33091755724521044`, 0.9348839126019717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 230}], {
             RGBColor[
             0.20964976351428055`, 0.33768557238922303`, 0.9352506159318827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 254}], {
             RGBColor[
             0.19262591917799537`, 0.31979243261771473`, 0.934281133181452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 258}], {
             RGBColor[
             0.21791338707223826`, 0.34637116469263174`, 0.9357212170685729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 314}], {
             RGBColor[
             0.19046396107769498`, 0.3175200775782383, 0.9341580128659703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 328}], {
             RGBColor[
             0.21476290196670605`, 0.3430598050944246, 0.9355418016025379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 41}], {
             RGBColor[
             0.19412189539412833`, 0.3213647984712409, 0.9343663268138622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 48}], {
             RGBColor[
             0.20069384731952558`, 0.3282723366306521, 0.934740589753682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 63}], {
             RGBColor[
             0.19138658757193353`, 0.3184898165215815, 0.9342105550799136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 103}], {
             RGBColor[
             0.19411926264855695`, 0.32136203128871965`, 0.9343661768828968]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 265}], {
             RGBColor[
             0.1962226401289317, 0.32357281438242835`, 0.9344859611187359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 295}], {
             RGBColor[
             0.1896748892459051, 0.31669071305298346`, 0.934113076392477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 48}], {
             RGBColor[
             0.2013669879321785, 0.3289798500941302, 0.9347789241157504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 63}], {
             RGBColor[
             0.19205972818458644`, 0.31919732998505956`, 0.9342488894419819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.1942575833696331, 0.32150741513661096`, 0.934374054043335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 265}], {
             RGBColor[
             0.19689578074158462`, 0.3242803278459065, 0.9345242954808043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 295}], {
             RGBColor[
             0.19034802985855803`, 0.31739822651646155`, 0.9341514107545453]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 325}], {
             RGBColor[
             0.2165335134226994, 0.3449208299979239, 0.9356426353055718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 381}], {
             RGBColor[
             0.19207190760239157`, 0.31921013132539244`, 0.934249583041808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 67}], {
             RGBColor[
             0.18164605198289263`, 0.3082518960318731, 0.9336558459879488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 75}], {
             RGBColor[
             0.18289766237674282`, 0.30956741791249204`, 0.9337271233482869]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 133}], {
             RGBColor[
             0.1836453052262827, 0.310353237950653, 0.9337697005025297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 178}], {
             RGBColor[
             0.18344665505298052`, 0.31014444402336394`, 0.9337583876690367]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 200}], {
             RGBColor[
             0.18896638878164698`, 0.3159460341435242, 0.9340727283391701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 278}], {
             RGBColor[
             0.18598976689484537`, 0.3128174158117676, 0.9339032141262342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 296}], {
             RGBColor[
             0.18148102360409654`, 0.30807844074235485`, 0.933646447865914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 320}], {
             RGBColor[
             0.18379681968568948`, 0.3105124892540611, 0.9337783290268474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 330}], {
             RGBColor[
             0.18629301045548374`, 0.31313614402075074`, 0.9339204833984038]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 347}], {
             RGBColor[
             0.18410501336322643`, 0.3108364203497602, 0.9337958802008515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 367}], {
             RGBColor[
             0.1849893429390042, 0.3117659068036362, 0.9338462414619436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 398}], {
             RGBColor[
             0.18234639975021955`, 0.30898800593994685`, 0.9336957297572264]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 159}], {
             RGBColor[
             0.1884193222929882, 0.31537103257792504`, 0.9340415737119533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 250}], {
             RGBColor[
             0.19420867686654147`, 0.32145601130101026`, 0.9343712688903346]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 265}], {
             RGBColor[
             0.19684687423849298`, 0.3242289240103058, 0.934521510327804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 321}], {
             RGBColor[
             0.1896253217591911, 0.31663861448168684`, 0.9341102535974373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 325}], {
             RGBColor[
             0.21648460691960775`, 0.3448694261623232, 0.9356398501525713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 375}], {
             RGBColor[
             0.19874644987833204`, 0.3262254984478285, 0.9346296883503225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 381}], {
             RGBColor[
             0.19202300109929993`, 0.3191587274897918, 0.9342467978888077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 66}], {
             RGBColor[
             0.21222031867993352`, 0.3403873888509353, 0.9353970052457711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 81}], {
             RGBColor[
             0.22873470286488637`, 0.35774505370175413`, 0.9363374749942621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 119}], {
             RGBColor[
             0.23405162543822766`, 0.3633334764386976, 0.9366402658691317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[
             0.26610768174908467`, 0.39702642409276845`, 0.9384658108533496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 130}], {
             RGBColor[
             0.22198842052975598`, 0.350654283228527, 0.9359532841955067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 135}], {
             RGBColor[
             0.2818343394924019, 0.41109593137624006`, 0.9394515009810677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 146}], {
             RGBColor[
             0.21372136571514777`, 0.3419650844568244, 0.9354824876538264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 151}], {
             RGBColor[
             0.21796286839338874`, 0.3464231726984579, 0.9357240349566114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 227}], {
             RGBColor[
             0.25115263484712524`, 0.3813077215940698, 0.9376141430562922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 243}], {
             RGBColor[
             0.2298536898894718, 0.3589211800124685, 0.9364011996499193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 267}], {
             RGBColor[
             0.21293872940986303`, 0.3411424840779623, 0.935437917674047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 275}], {
             RGBColor[
             0.21122882729611786`, 0.33934526854236047`, 0.9353405412782427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 311}], {
             RGBColor[
             0.21545480303552692`, 0.34378703698681684`, 0.9355812043448313]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 317}], {
             RGBColor[
             0.2084087804726259, 0.3363812205295747, 0.9351799437835304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 326}], {
             RGBColor[
             0.2349425006851034, 0.3642698428079171, 0.9366909998965096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 344}], {
             RGBColor[
             0.20993796520971017`, 0.3379884906441625, 0.9352670285920812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 346}], {
             RGBColor[
             0.2158698080892293, 0.3442232336110982, 0.9356048382686947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 383}], {
             RGBColor[
             0.29331549171916627`, 0.4210403283755737, 0.9401830698485728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 48}], {
             RGBColor[
             0.2238300988639671, 0.3525900039269335, 0.9360581650521211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 74}], {
             RGBColor[
             0.2441275547351621, 0.3739239169805914, 0.9372140751365906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 103}], {
             RGBColor[
             0.21725551419299843`, 0.345679698585001, 0.9356837521813359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 116}], {
             RGBColor[
             0.23987123039501432`, 0.3694502502325462, 0.9369716837620867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 262}], {
             RGBColor[
             0.30202723660803465`, 0.4296407358190505, 0.9406995556283282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 290}], {
             RGBColor[
             0.24862549482263574`, 0.3786515371983993, 0.9374702261704662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 304}], {
             RGBColor[
             0.2609958832174149, 0.3916535997292371, 0.9381747014891992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 338}], {
             RGBColor[
             0.2249286875668965, 0.3537446903082591, 0.9361207280535366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 52}], {
             RGBColor[
             0.89726556755869, 0.9188637535063902, 0.9066512485949225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 60}], {
             RGBColor[
             0.7562801355297237, 0.809531056908518, 0.9763425941360632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 102}], {
             RGBColor[
             0.5772856165740025, 0.6623742905041798, 0.9623565848838942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 105}], {
             RGBColor[
             0.8954193827902208, 0.9181003086598438, 0.937247307981482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 128}], {
             RGBColor[
             0.5547192055800235, 0.6423805327309791, 0.9609350717272003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 139}], {
             RGBColor[
             0.5562400144756487, 0.6439789993051345, 0.961021679543971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 199}], {
             RGBColor[
             0.8971361136435547, 0.9188102209856679, 0.9087966349847089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 213}], {
             RGBColor[
             0.5654749182769274, 0.6521444572622102, 0.9616040176321952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 215}], {
             RGBColor[
             0.7558037231431869, 0.8091588799312872, 0.9762951098017001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 259}], {
             RGBColor[
             0.850480547970673, 0.8837308935118651, 0.9855697997497163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 271}], {
             RGBColor[
             0.8151806601648499, 0.3858404945253056, 0.4382759783762188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 287}], {
             RGBColor[
             0.8133914916365368, 0.3720881611980434, 0.43656266857292936`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 333}], {
             RGBColor[
             0.8796565038002286, 0.9065288389378603, 0.9721902291244133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 337}], {
             RGBColor[
             0.8812578483212357, 0.9077231190596664, 0.969479570547889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 345}], {
             RGBColor[
             0.8168101022247779, 0.8568829940339906, 0.982358282576511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 350}], {
             RGBColor[
             0.5770408715617338, 0.6621623046757947, 0.9623409899481321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 353}], {
             RGBColor[
             0.8993981375114619, 0.9180011012561393, 0.7445005138120175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 400}], {
             RGBColor[
             0.8165889705092233, 0.3966653849576874, 0.4396245779524498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 136}], {
             RGBColor[
             0.18182023692588944`, 0.308434975450926, 0.9336657655627689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 149}], {
             RGBColor[
             0.1956652358484003, 0.3229869471421173, 0.9344542177695655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 155}], {
             RGBColor[
             0.18345196765990118`, 0.3101500279100763, 0.9337586902141416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 268}], {
             RGBColor[
             0.18433220446865944`, 0.3110752126063183, 0.9338088183982067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 279}], {
             RGBColor[
             0.19002059109890063`, 0.3170540676192452, 0.934132763601585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 299}], {
             RGBColor[
             0.184696983160691, 0.3114586181399484, 0.9338295920050762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 300}], {
             RGBColor[
             0.18858263454534693`, 0.31554268410974895`, 0.9340508741031263]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 371}], {
             RGBColor[
             0.18051873474236652`, 0.3070670141360388, 0.9335916469388172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.1986316801099837, 0.3261048681444708, 0.9346231523818017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 86}], {
             RGBColor[
             0.23801910122574216`, 0.3675035450438693, 0.9368662077458763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 103}], {
             RGBColor[
             0.2013643551866071, 0.328977082911609, 0.9347787741847848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 295}], {
             RGBColor[
             0.19691998178395526`, 0.3243057646758728, 0.9345256736943651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 191}], {
             RGBColor[
             0.18385357890938503`, 0.3105721467969078, 0.933781561380669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 225}], {
             RGBColor[
             0.19609003670444464`, 0.3234334397757498, 0.9344784095498806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 235}], {
             RGBColor[
             0.1884735679979762, 0.31542804825324383`, 0.9340446629246031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 261}], {
             RGBColor[
             0.1864507904031121, 0.31330198074953464`, 0.9339294687330069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 327}], {
             RGBColor[
             0.18473066760764006`, 0.3114940226294092, 0.9338315102844983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 335}], {
             RGBColor[
             0.1909811618412971, 0.3180636883732066, 0.9341874666843275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 349}], {
             RGBColor[
             0.19105637302960854`, 0.3181427401007867, 0.9341917498502368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 355}], {
             RGBColor[
             0.19591924831876065`, 0.3232539303537868, 0.9344686834039748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 127}], {
             RGBColor[
             0.28524823564473223`, 0.4143130772255349, 0.9396595042068966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 137}], {
             RGBColor[
             0.2618861891426283, 0.3925893677052923, 0.9382254030945505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 138}], {
             RGBColor[
             0.26001645706684573`, 0.3906241607457843, 0.9381189246188555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 147}], {
             RGBColor[
             0.23917140342485926`, 0.3687146877153205, 0.9369318296514377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 164}], {
             RGBColor[
             0.22306024288786463`, 0.3517808364843617, 0.9360143228931819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 197}], {
             RGBColor[
             0.21121964795225362`, 0.33933562046995513`, 0.9353400185281894]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 210}], {
             RGBColor[
             0.23840421569943582`, 0.3679083247733892, 0.9368881394454274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 217}], {
             RGBColor[
             0.21968733955898895`, 0.34823570123129066`, 0.9358222410383658]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 230}], {
             RGBColor[
             0.2261265468612622, 0.35500371637530337`, 0.9361889443682767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 242}], {
             RGBColor[
             0.2857631387189643, 0.41475906038865373`, 0.9396923133754758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 254}], {
             RGBColor[
             0.20910270252497706`, 0.33711057660379506`, 0.9352194616178461]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 258}], {
             RGBColor[
             0.23439017041921995`, 0.3636893086787121, 0.9366595455049669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 328}], {
             RGBColor[
             0.23123968531368772`, 0.36037794908050486`, 0.9364801300389318]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 331}], {
             RGBColor[
             0.2360482874744978, 0.36543209483450245`, 0.9367539728183005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 79}], {
             RGBColor[
             0.20012999875823717`, 0.3276796960426744, 0.934708479412256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 87}], {
             RGBColor[
             0.1940286984190197, 0.3212668425413722, 0.9343610193840024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 126}], {
             RGBColor[
             0.1918840790772874, 0.31901271163649164`, 0.9342388864851707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 176}], {
             RGBColor[
             0.19370665948804128`, 0.32092835920646634`, 0.9343426797432972]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 205}], {
             RGBColor[
             0.19318129293550862`, 0.32037616564959115`, 0.9343127608953405]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 232}], {
             RGBColor[
             0.19578437289714112`, 0.32311216773406903`, 0.9344610024482438]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 277}], {
             RGBColor[
             0.19316166908716753`, 0.3203555397407608, 0.9343116433462084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 298}], {
             RGBColor[
             0.20333725610200998`, 0.3310507268628402, 0.9348911279732717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 373}], {
             RGBColor[
             0.1995969758310581, 0.32711945515060364`, 0.9346781245450898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 390}], {
             RGBColor[
             0.2070958500160861, 0.33500124737515247`, 0.935105174336337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 60}], {
             RGBColor[
             0.8480092281788032, 0.880384326820778, 0.9017418370121976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 68}], {
             RGBColor[
             0.9052995090875355, 0.9251530264391655, 0.9074485213302443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 105}], {
             RGBColor[
             0.9871484754393005, 0.988953578572104, 0.8626465508576164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 129}], {
             RGBColor[
             0.8758889946434687, 0.4296602011342544, 0.38811658814132355`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 199}], {
             RGBColor[
             0.9888652062926342, 0.9896634908979279, 0.8341958778608433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 271}], {
             RGBColor[
             0.8763333885975696, 0.43307600780014566`, 0.3885421402936417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 287}], {
             RGBColor[
             0.8745442200692566, 0.41932367447288343`, 0.3868288304903523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 303}], {
             RGBColor[
             0.9414623591594504, 0.8004800076065881, 0.5326277353789215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 333}], {
             RGBColor[
             0.9713855964493081, 0.9773821088501203, 0.8975894720005477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 337}], {
             RGBColor[
             0.9729869409703154, 0.9785763889719264, 0.8948788134240234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 345}], {
             RGBColor[
             0.9085391948738575, 0.9277362639462506, 0.9077575254526454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 353}], {
             RGBColor[
             0.9911272301605415, 0.9888543711683995, 0.6698997566881519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 391}], {
             RGBColor[
             0.8764876955371848, 0.43426207855576004`, 0.3886899047932819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 69}], {
             RGBColor[
             0.4877113731208531, 0.5936081076641104, 0.9531940365593021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 93}], {
             RGBColor[
             0.37256678589576175`, 0.4971203570169409, 0.9449606040427729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 131}], {
             RGBColor[
             0.6083578580504109, 0.6889233390243821, 0.9644906126536026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 142}], {
             RGBColor[
             0.43838221439814257`, 0.5535604743597381, 0.949310664485988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 188}], {
             RGBColor[
             0.33920701496392514`, 0.465180569896386, 0.9429464497347737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 201}], {
             RGBColor[
             0.5341594365329997, 0.6309589682060907, 0.9570952074204189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 264}], {
             RGBColor[
             0.3312918681319017, 0.4568612487266348, 0.9424956938321003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 273}], {
             RGBColor[
             0.4633253395942303, 0.573810427068907, 0.9512742786711021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 281}], {
             RGBColor[
             0.40067800773256046`, 0.5214688844608842, 0.9467518262404362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[
             0.35836727987096656`, 0.4848214585861875, 0.944055824075003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 394}], {
             RGBColor[
             0.38011496144870427`, 0.5036582072985654, 0.9454415671144167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 64}], {
             RGBColor[
             0.970419525130984, 0.9095497585157698, 0.3557751825465969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 83}], {
             RGBColor[
             0.9496193654049732, 0.8977579075232218, 0.6225379522867944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 123}], {
             RGBColor[
             0.8781898086085118, 0.4993404886909019, 0.21838151649392293`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 161}], {
             RGBColor[
             0.9139000708098552, 0.6892402426005217, 0.2492124251865322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 196}], {
             RGBColor[
             0.8961892019683437, 0.8555483275728113, 0.6311082747514651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 198}], {
             RGBColor[
             0.8885256847199983, 0.8494376469396148, 0.6303773216350153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 206}], {
             RGBColor[
             0.6885711015156095, 0.68922695188861, 0.6128856824256679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 214}], {
             RGBColor[
             0.913587591361185, 0.6878213464055395, 0.24895168467498954`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 310}], {
             RGBColor[
             0.8670957257484463, 0.41406650637033016`, 0.20775781021814968`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 332}], {
             RGBColor[
             0.8612878791024013, 0.3694248520342004, 0.20219620971087243`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 389}], {
             RGBColor[
             0.9706885388162402, 0.9101251515870772, 0.3850556620267193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 57}], {
             RGBColor[
             0.5760181454967422, 0.6613528823456771, 0.9622434817439033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 68}], {
             RGBColor[
             0.8126708442680417, 0.8535970039103761, 0.981959617507143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 72}], {
             RGBColor[
             0.6346370252408752, 0.7117938428167392, 0.9660702931075245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 83}], {
             RGBColor[
             0.8773611303882973, 0.9047851000408222, 0.9744632955960668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 123}], {
             RGBColor[
             0.830017651930728, 0.5040252837026356, 0.45299841203343794`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 161}], {
             RGBColor[
             0.8416418357931794, 0.6962674351181222, 0.6011377684958046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 196}], {
             RGBColor[
             0.8239309669516679, 0.8625755200904117, 0.9830336180607375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 236}], {
             RGBColor[
             0.6566866391587384, 0.7296947127190476, 0.9678061194855357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 262}], {
             RGBColor[
             0.5840352729572464, 0.6682969151994234, 0.9627543260164191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 284}], {
             RGBColor[
             0.7718010949853338, 0.8216561483989014, 0.9778895783229857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 334}], {
             RGBColor[
             0.8819744590496598, 0.862025730858683, 0.6405013220512796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 366}], {
             RGBColor[
             0.8985186945130963, 0.9173414029032505, 0.7466017890196988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 397}], {
             RGBColor[
             0.5839584526615165, 0.6682303773203624, 0.9627494310951048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 65}], {
             RGBColor[
             0.4474461015886463, 0.5602099797974611, 0.9502200964459863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 100}], {
             RGBColor[
             0.4530551393941151, 0.565068246426121, 0.9505774993750733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 174}], {
             RGBColor[
             0.4681168777823908, 0.5781139671930625, 0.9515372200266019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 198}], {
             RGBColor[
             0.6735978276393025, 0.7431113232752183, 0.969380994432274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 203}], {
             RGBColor[
             0.4142038212467356, 0.5314171873708888, 0.948101927737594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 206}], {
             RGBColor[
             0.4736432444349138, 0.5829006282242136, 0.9518893552229266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 266}], {
             RGBColor[
             0.5883098999275997, 0.6764125091387695, 0.9608991949142476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 341}], {
             RGBColor[
             0.38387079611477953`, 0.499652079122729, 0.9463702293168075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 358}], {
             RGBColor[
             0.3979975915234898, 0.5145002367878451, 0.9471747294166126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 68}], {
             RGBColor[
             0.584951659196002, 0.6683449078949819, 0.9631304154261922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 72}], {
             RGBColor[
             0.4069178401688355, 0.5265417468013449, 0.9472410910265736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 86}], {
             RGBColor[
             0.30819911150930557`, 0.43761024408224003`, 0.9409967540495674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 108}], {
             RGBColor[
             0.32733127751038416`, 0.4577193635987606, 0.9420863025998256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 236}], {
             RGBColor[
             0.4289674540866987, 0.5444426167036535, 0.9489769174045849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 262}], {
             RGBColor[
             0.35631608788520674`, 0.4830448191840292, 0.9439251239354682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 284}], {
             RGBColor[
             0.544081909913294, 0.6364040523835073, 0.9590603762420349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 297}], {
             RGBColor[
             0.3224295006293375, 0.45256728530617585`, 0.9418071536579791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 325}], {
             RGBColor[
             0.29328547563165996`, 0.42193506719570584`, 0.9401474445490827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 376}], {
             RGBColor[
             0.31723897478085683`, 0.4471117135410761, 0.941511560889603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 397}], {
             RGBColor[
             0.3562392675894767, 0.4829782813049682, 0.943920229014154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 124}], {
             RGBColor[
             0.20991109539232988`, 0.337960248762451, 0.9352654983957317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 152}], {
             RGBColor[
             0.19702370192683044`, 0.32441478112227146`, 0.9345315804030616]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 156}], {
             RGBColor[
             0.19753761270804981`, 0.3249549339371585, 0.9345608468617892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 160}], {
             RGBColor[
             0.1942495004305084, 0.32149891945510295`, 0.9343735937319094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 179}], {
             RGBColor[
             0.21000836012355356`, 0.3380624801619072, 0.9352710374782847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 181}], {
             RGBColor[
             0.19266290312611054`, 0.31983130509210156`, 0.9342832393625844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 220}], {
             RGBColor[
             0.186453938859043, 0.31330528997634166`, 0.9339296480329143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[
             0.1940488178607217, 0.32128798935024727`, 0.9343621651564433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 352}], {
             RGBColor[
             0.18979453396815193`, 0.3168164672419784, 0.9341198899824106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 396}], {
             RGBColor[
             0.18880077082680655`, 0.315771959172202, 0.9340632966416518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 132}], {
             RGBColor[
             0.20457320024571096`, 0.33234978252125474`, 0.93496151316384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 149}], {
             RGBColor[
             0.21329928840113216`, 0.34152145443854653`, 0.9354584509752006]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 155}], {
             RGBColor[
             0.20108602021263303`, 0.3286845352065056, 0.9347629234197767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 164}], {
             RGBColor[
             0.215632569168565, 0.3439738804636637, 0.9355913278631264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 210}], {
             RGBColor[
             0.23097654198013617`, 0.36010136875269116`, 0.9364651444153718]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 230}], {
             RGBColor[
             0.21869887314196257`, 0.34719676035460534`, 0.9357659493382211]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 258}], {
             RGBColor[
             0.2269624966999203, 0.35588235265801405`, 0.9362365504749113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 264}], {
             RGBColor[
             0.2381256499847355, 0.3676155345451527, 0.9368722755400762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 268}], {
             RGBColor[
             0.2019662570213913, 0.3296097199027477, 0.9348130516038419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 279}], {
             RGBColor[
             0.2076546436516325, 0.3355885749156745, 0.9351369968072203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 299}], {
             RGBColor[
             0.20233103571342284`, 0.3299931254363777, 0.9348338252107113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 300}], {
             RGBColor[
             0.20621668709807878`, 0.3340771914061782, 0.9350551073087614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 328}], {
             RGBColor[
             0.22381201159438807`, 0.3525709930598068, 0.9360571350088763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 394}], {
             RGBColor[
             0.286948743301538, 0.41441249311708334`, 0.9398181488223927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 68}], {
             RGBColor[
             0.7643140770585692, 0.8158203298412934, 0.9771398668713851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 72}], {
             RGBColor[
             0.5862802580314027, 0.6740171687476564, 0.9612505424717664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 102}], {
             RGBColor[
             0.5280292771941157, 0.6238948638185677, 0.9574471733011694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 105}], {
             RGBColor[
             0.8461630434103341, 0.8796208819742317, 0.932337896398757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 108}], {
             RGBColor[
             0.5066936953729514, 0.6051947855450721, 0.9560957540450186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 139}], {
             RGBColor[
             0.506983675095762, 0.6054995726195224, 0.9561122679612462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 297}], {
             RGBColor[
             0.5017919184919047, 0.6000427072524873, 0.955816605103172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 333}], {
             RGBColor[
             0.8304001644203418, 0.8680494122522482, 0.9672808175416883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 337}], {
             RGBColor[
             0.8320015089413489, 0.8692436923740543, 0.9645701589651641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 345}], {
             RGBColor[
             0.7675537628448912, 0.8184035673483785, 0.9774488709937861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 353}], {
             RGBColor[
             0.8501417981315751, 0.8795216745705272, 0.7395911022292926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 70}], {
             RGBColor[
             0.20711529305388426`, 0.33502168324063814`, 0.9351062815885762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 90}], {
             RGBColor[
             0.21641762089155886`, 0.3447990195996844, 0.935636035397371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 95}], {
             RGBColor[
             0.23224869997063102`, 0.3614384874601766, 0.9365375919309413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 148}], {
             RGBColor[
             0.23690961095816437`, 0.3663374004268991, 0.9368030239164815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 228}], {
             RGBColor[
             0.220637096263315, 0.34923395574559046`, 0.935876328277638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 282}], {
             RGBColor[
             0.2661448795948803, 0.3964851197604022, 0.9384891805623623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 285}], {
             RGBColor[
             0.2007711589524707, 0.32835359605871806`, 0.934744992536806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 301}], {
             RGBColor[
             0.23356716082772205`, 0.3628242734162258, 0.9366126763262647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 382}], {
             RGBColor[
             0.2696810924925139, 0.39954800963710424`, 0.9387145049212492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 91}], {
             RGBColor[
             0.7921898842803778, 0.8354987729647263, 0.873281889830355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 111}], {
             RGBColor[
             0.8816760076239252, 0.4673313794612627, 0.3772430077111397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 117}], {
             RGBColor[
             0.7751677288121797, 0.821679420316278, 0.8719418433976884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 223}], {
             RGBColor[
             0.9034121684337133, 0.6327035931146356, 0.3979909556022818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 247}], {
             RGBColor[
             0.8754937811360735, 0.41981207760671324`, 0.37132290064454676`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 256}], {
             RGBColor[
             0.992053902372576, 0.9909820986727351, 0.781350931735281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 319}], {
             RGBColor[
             0.885564206725758, 0.4972177815776606, 0.3809663515621477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 323}], {
             RGBColor[
             0.7062128595771804, 0.7648109743818534, 0.8667587588510515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 362}], {
             RGBColor[
             0.8915373797700097, 0.913872404880224, 0.882662516799504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 395}], {
             RGBColor[
             0.7152423649203183, 0.772631878073945, 0.8673341109470382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 103}], {
             RGBColor[
             0.19205709543901506`, 0.31919456280253833`, 0.9342487395110164]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 295}], {
             RGBColor[
             0.1876127220363632, 0.31452324456680214`, 0.9339956390205967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 88}], {
             RGBColor[
             0.7114905669436782, 0.7668789695612932, 0.6914868954695467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 101}], {
             RGBColor[
             0.9001775806462604, 0.6060972685953367, 0.2776552068281445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 115}], {
             RGBColor[
             0.973846560757742, 0.9231368127839409, 0.35853265585475147`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 120}], {
             RGBColor[
             0.7025664799902631, 0.759149373979897, 0.6909182605401354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 123}], {
             RGBColor[
             0.8929669582944121, 0.5506732654841682, 0.2707503067207814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 140}], {
             RGBColor[
             0.6994659535308891, 0.7564638537977784, 0.690720697735832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 161}], {
             RGBColor[
             0.9360657953387055, 0.766239407790421, 0.32776561052681985`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 193}], {
             RGBColor[
             0.9152566921622731, 0.9300770448033753, 0.7093659477350615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 195}], {
             RGBColor[
             0.7086017617355334, 0.7643768316855696, 0.6913028233561538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 214}], {
             RGBColor[
             0.9357533158900353, 0.7648205115954387, 0.32750487001527717`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 233}], {
             RGBColor[
             0.9814581324353071, 0.9819712119725741, 0.6847171998056071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 257}], {
             RGBColor[
             0.9810027572631417, 0.9816315939147817, 0.6854880311912166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 283}], {
             RGBColor[
             0.9622538962308652, 0.8771757609613251, 0.3492049258616166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 312}], {
             RGBColor[
             0.7702008939642393, 0.8151650470913949, 0.695936819489472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 332}], {
             RGBColor[
             0.8760650287883015, 0.4207576288274666, 0.25456499993773085`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 356}], {
             RGBColor[
             0.9689844051155808, 0.9726683265613763, 0.7058319664887789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 360}], {
             RGBColor[
             0.8276703795499445, 0.8615089159497265, 0.7006746506658257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 380}], {
             RGBColor[
             0.8564837144111264, 0.8840181121327374, 0.7035464946088651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 389}], {
             RGBColor[
             0.9928542633450905, 0.9871243167769764, 0.4636088473670069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 100}], {
             RGBColor[
             0.38210315454201915`, 0.5053802802265043, 0.9455682530202327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 167}], {
             RGBColor[
             0.30615029923372655`, 0.43284997763222943`, 0.940975526215034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 174}], {
             RGBColor[
             0.39716489293029483`, 0.5184260009934458, 0.9465279736717613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 198}], {
             RGBColor[
             0.6026458427872066, 0.6834233570756016, 0.9643717480774334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 203}], {
             RGBColor[
             0.34325183639463963`, 0.4717292211712722, 0.9430926813827534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 206}], {
             RGBColor[
             0.4026912595828178, 0.5232126620245969, 0.9468801088680859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 211}], {
             RGBColor[
             0.3044915837808781, 0.4311065625226518, 0.9408810648238439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 266}], {
             RGBColor[
             0.5173579150755038, 0.6167245429391528, 0.9558899485594068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 313}], {
             RGBColor[
             0.33055584599709903`, 0.45850175468157234`, 0.9423653859984371]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 329}], {
             RGBColor[
             0.31941652727713654`, 0.4467936244332925, 0.9417310182764805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 340}], {
             RGBColor[
             0.3239430587205376, 0.45155129597897675`, 0.941988797545779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 341}], {
             RGBColor[
             0.31291881126268356`, 0.4399641129231123, 0.9413609829619669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 358}], {
             RGBColor[
             0.3270456066713938, 0.4548122705882284, 0.942165483061772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 81}], {
             RGBColor[
             0.21264159429708712`, 0.3408301762349806, 0.9354209962689466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 119}], {
             RGBColor[
             0.21795851687042844`, 0.3464185989719241, 0.9357237871438162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 130}], {
             RGBColor[
             0.20589531196195676`, 0.3337394057617535, 0.9350368054701912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 146}], {
             RGBColor[
             0.19762825714734855`, 0.3250502069900508, 0.9345660089285108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 151}], {
             RGBColor[
             0.20186975982558952`, 0.3295082952316844, 0.9348075562312959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 158}], {
             RGBColor[
             0.19363377892106423`, 0.3208517571096786, 0.934338529302825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 243}], {
             RGBColor[
             0.21376058132167255`, 0.342006302545695, 0.9354847209246038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 267}], {
             RGBColor[
             0.1968456208420638, 0.3242276066111888, 0.9345214389487315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 275}], {
             RGBColor[
             0.19513571872831864`, 0.3224303910755869, 0.9344240625529272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 311}], {
             RGBColor[
             0.19936169446772767`, 0.32687215952004334`, 0.9346647256195157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 317}], {
             RGBColor[
             0.19231567190482668`, 0.3194663430628012, 0.9342634650582149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 344}], {
             RGBColor[
             0.19384485664191092`, 0.32107361317738903`, 0.9343505498667657]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 346}], {
             RGBColor[
             0.19977669952143007`, 0.3273083561443247, 0.9346883595433791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 354}], {
             RGBColor[
             0.19611420939972474`, 0.3234588468111266, 0.9344797861491166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 75}], {
             RGBColor[
             0.1806580838475214, 0.3072134788808002, 0.9335995826642074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 126}], {
             RGBColor[
             0.18098291600078534`, 0.3075548980694286, 0.9336180813747896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 133}], {
             RGBColor[
             0.1814057266970613, 0.30799929891896116`, 0.9336421598184501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 200}], {
             RGBColor[
             0.1867268102524256, 0.3135920951118324, 0.9339451876550904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 320}], {
             RGBColor[
             0.1815572411564681, 0.30815855022236927`, 0.9336507883427678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 347}], {
             RGBColor[
             0.18186543483400505`, 0.3084824813180684, 0.9336683395167719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 398}], {
             RGBColor[
             0.18010682122099816`, 0.306634066908255, 0.9335681890731469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 72}], {
             RGBColor[
             0.6435705389401349, 0.7187858683660439, 0.9669572267898132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 236}], {
             RGBColor[
             0.6656201528579981, 0.7366867382683524, 0.9686930531678246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 262}], {
             RGBColor[
             0.5929687866565062, 0.6752889407487281, 0.9636412596987081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 284}], {
             RGBColor[
             0.7807346086845934, 0.8286481739482061, 0.9787765120052747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 333}], {
             RGBColor[
             0.8876904453290742, 0.9128181118706356, 0.9729875018597351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 334}], {
             RGBColor[
             0.8909079727489195, 0.8690177564079877, 0.6413882557335685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 337}], {
             RGBColor[
             0.8892917898500812, 0.9140123919924417, 0.970276843283211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 376}], {
             RGBColor[
             0.5538916735521564, 0.639355835105775, 0.9612276966528428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 391}], {
             RGBColor[
             0.8206909281236954, 0.3912194139027702, 0.4389552580327404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 397}], {
             RGBColor[
             0.5928919663607762, 0.6752224028696671, 0.9636363647773936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 93}], {
             RGBColor[
             0.45767335020652483`, 0.5675906819706489, 0.951280040300782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 131}], {
             RGBColor[
             0.693464422361174, 0.75939366397809, 0.9708100489116116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 142}], {
             RGBColor[
             0.5234887787089056, 0.6240307993134462, 0.955630100743997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 188}], {
             RGBColor[
             0.42431357927468827`, 0.535650894850094, 0.9492658859927827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 201}], {
             RGBColor[
             0.6192660008437627, 0.7014292931597987, 0.9634146436784279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 273}], {
             RGBColor[
             0.5484319039049934, 0.644280752022615, 0.9575937149291112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 281}], {
             RGBColor[
             0.4857845720433236, 0.5919392094145923, 0.9530712624984452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 293}], {
             RGBColor[
             0.44347384418172964`, 0.5552917835398956, 0.950375260333012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 394}], {
             RGBColor[
             0.46522152575946735`, 0.5741285322522734, 0.9517610033724258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 90}], {
             RGBColor[
             0.2062666965089075, 0.33412975446773896`, 0.9350579552707259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 95}], {
             RGBColor[
             0.22209777558797966`, 0.3507692223282312, 0.9359595118042963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 177}], {
             RGBColor[
             0.1891804395703839, 0.31617101509409057`, 0.9340849182149289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 228}], {
             RGBColor[
             0.21048617188066365`, 0.3385646906136451, 0.9352982481509928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 246}], {
             RGBColor[
             0.2068329817370454, 0.33472495614706915`, 0.9350902043767244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 260}], {
             RGBColor[
             0.19294770058427305`, 0.3201306452778321, 0.9342994581565066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 285}], {
             RGBColor[
             0.1906202345698193, 0.31768433092677273`, 0.9341669124101608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 110}], {
             RGBColor[
             0.9113332721380322, 0.9312595378862136, 0.9610025753124077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 131}], {
             RGBColor[
             0.8919073913712897, 0.9158173378862382, 0.9591371203789343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 201}], {
             RGBColor[
             0.8177089698538784, 0.8578529670679469, 0.9517417151457506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 212}], {
             RGBColor[
             0.7737416965530766, 0.822516123696677, 0.9480358411696325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 271}], {
             RGBColor[
             0.8699031270122622, 0.4288122601386338, 0.4232478483872749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 273}], {
             RGBColor[
             0.7468748729151091, 0.8007044259307632, 0.9459207863964338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 287}], {
             RGBColor[
             0.8681139584839492, 0.4150599268113716, 0.4215345385839855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 289}], {
             RGBColor[
             0.7219591346417744, 0.780476707159252, 0.9439593282102003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 292}], {
             RGBColor[
             0.8695625482177284, 0.42619442228126747`, 0.42292170974900056`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 303}], {
             RGBColor[
             0.9318169667814895, 0.7940843861143203, 0.5846862975193713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 385}], {
             RGBColor[
             0.9820607295061435, 0.9836969405379016, 0.7849671104328407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 400}], {
             RGBColor[
             0.8713114373566356, 0.4396371505710155, 0.42459644796350593`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 86}], {
             RGBColor[
             0.3668179912534385, 0.4880512045533021, 0.9448235654131886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 108}], {
             RGBColor[
             0.3859501572545172, 0.5081603240698226, 0.9459131139634468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 236}], {
             RGBColor[
             0.4875863338308316, 0.5948835771747154, 0.9528037287682061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 262}], {
             RGBColor[
             0.4149349676293397, 0.5334857796550911, 0.9477519352990894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 284}], {
             RGBColor[
             0.602700789657427, 0.6868450128545692, 0.9628871876056561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 297}], {
             RGBColor[
             0.3810483803734705, 0.5030082457772378, 0.9456339650216002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 325}], {
             RGBColor[
             0.35190435537579295`, 0.4723760276667679, 0.9439742559127038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 333}], {
             RGBColor[
             0.7096566263019076, 0.7710149507769987, 0.9570981774601166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 337}], {
             RGBColor[
             0.7112579708229148, 0.7722092308988048, 0.9543875188835923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 376}], {
             RGBColor[
             0.3758578545249899, 0.4975526740121381, 0.9453383722532241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 397}], {
             RGBColor[
             0.4148581473336097, 0.5334192417760302, 0.947747040377775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.21536881746289013`, 0.3436966606981754, 0.9355763075936738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 162}], {
             RGBColor[
             0.19690433907813965`, 0.3242893232002557, 0.9345247828654102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 183}], {
             RGBColor[
             0.19359784833893534`, 0.3208139917897307, 0.9343364831093273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 189}], {
             RGBColor[
             0.2158427366159144, 0.3441947797762137, 0.9356032965883381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 207}], {
             RGBColor[
             0.1950145063297256, 0.32230298915935574`, 0.934417159686145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 280}], {
             RGBColor[
             0.2037203723071403, 0.3314534062854026, 0.9349129458743843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 291}], {
             RGBColor[
             0.19698615809912115`, 0.32437532017893284`, 0.9345294423376147]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 336}], {
             RGBColor[
             0.2166564041388005, 0.3450499959322676, 0.9356496337500533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 368}], {
             RGBColor[
             0.19117243294824504`, 0.31826472643389747`, 0.934198359290908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 387}], {
             RGBColor[
             0.19202691052884113`, 0.31916283654811173`, 0.9342470205250366]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 116}], {
             RGBColor[
             0.244277527259818, 0.37408154761281204`, 0.9372226158500052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 118}], {
             RGBColor[
             0.3029906205258713, 0.4312899550504897, 0.9407311083477143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 141}], {
             RGBColor[
             0.3021503369999872, 0.43056214369424695`, 0.9406775662244785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 179}], {
             RGBColor[
             0.23767352171657924`, 0.3671403190687327, 0.9368465275040685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 209}], {
             RGBColor[
             0.2567896978925637, 0.3872326322652657, 0.9379351654574425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 286}], {
             RGBColor[
             0.28488862903471124`, 0.4156109198533938, 0.9395776654568602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 290}], {
             RGBColor[
             0.2530317916874394, 0.3832828345786652, 0.9377211582583846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 304}], {
             RGBColor[
             0.2654021800822186, 0.39628489710950293`, 0.9384256335771177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 338}], {
             RGBColor[
             0.22933498443170014`, 0.35837598768852497`, 0.9363716601414551]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 386}], {
             RGBColor[
             0.29523037248077955`, 0.42456841823523894`, 0.9402366322043989]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 126}], {
             RGBColor[
             0.18223452639463555`, 0.3088704199500476, 0.9336893587351277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 133}], {
             RGBColor[
             0.18265733709091148`, 0.3093148207995801, 0.9337134371787883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 178}], {
             RGBColor[
             0.18245868691760933`, 0.30910602687229105`, 0.9337021243452953]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 200}], {
             RGBColor[
             0.1879784206462758, 0.3149076169924513, 0.9340164650154286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 296}], {
             RGBColor[
             0.18049305546872535`, 0.30704002359128196`, 0.9335901845421726]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 320}], {
             RGBColor[
             0.18280885155031829`, 0.3094740721029882, 0.933722065703106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 330}], {
             RGBColor[
             0.18530504232011252`, 0.31209772686967785`, 0.9338642200746624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 347}], {
             RGBColor[
             0.18311704522785527`, 0.30979800319868733`, 0.9337396168771099]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 398}], {
             RGBColor[
             0.18135843161484838`, 0.30794958878887396`, 0.9336394664334849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 78}], {
             RGBColor[
             0.2517003601981642, 0.38188341566580475`, 0.9376453352047469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 80}], {
             RGBColor[
             0.24302079240522623`, 0.37276063959904404`, 0.9371510466592089]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.24728213971667218`, 0.37723958580839845`, 0.9373937240844974]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 117}], {
             RGBColor[
             0.4207333030341396, 0.5335965741048728, 0.9489064510842957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.2623813144884871, 0.39310977583655005`, 0.9382535997505249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 187}], {
             RGBColor[
             0.24964108184106412`, 0.37971898354670364`, 0.9375280623487394]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 208}], {
             RGBColor[
             0.28867650153937047`, 0.420747684638181, 0.9397510717528295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 239}], {
             RGBColor[
             0.3950361568987507, 0.5127344732289232, 0.94688347760877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 269}], {
             RGBColor[
             0.3181691701834686, 0.44761747327725976`, 0.9415818139795731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 323}], {
             RGBColor[
             0.3517784337991403, 0.4767281281704481, 0.9437233665376588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 365}], {
             RGBColor[
             0.2944759917270998, 0.42684331653440033`, 0.9400813441394438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 377}], {
             RGBColor[
             0.2688145572376063, 0.39987152185702324`, 0.9386199634079575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 388}], {
             RGBColor[
             0.276858244918402, 0.40832594760879465`, 0.9390780395218092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 395}], {
             RGBColor[
             0.36080793914227827`, 0.4845490318625397, 0.9442987186336453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 78}], {
             RGBColor[
             0.20870891214169546`, 0.33669667794321373`, 0.9351970358380788]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 80}], {
             RGBColor[
             0.20002934434875747`, 0.3275739018764531, 0.9347027472925409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 96}], {
             RGBColor[
             0.20429069166020342`, 0.3320528480858075, 0.9349454247178293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 182}], {
             RGBColor[
             0.21938986643201835`, 0.34792303811395897`, 0.9358053003838569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 187}], {
             RGBColor[
             0.2066496337845954, 0.33453224582411256`, 0.9350797629820713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 244}], {
             RGBColor[
             0.18965577385650711`, 0.31667062156674053`, 0.9341119877993296]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 302}], {
             RGBColor[
             0.19582677060371215`, 0.3231567304118451, 0.9344634169349113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 377}], {
             RGBColor[
             0.22582310918113752`, 0.35468478413443216`, 0.9361716640412894]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 388}], {
             RGBColor[
             0.23386679686193323`, 0.36313920988620363`, 0.9366297401551412]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 80}], {
             RGBColor[
             0.21178615052788774`, 0.3399310505952844, 0.9353722800118063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 96}], {
             RGBColor[
             0.2160474978393337, 0.3444099968046388, 0.9356149574370947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 104}], {
             RGBColor[
             0.22225745398096258`, 0.35093705444345114`, 0.9359686052525535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 182}], {
             RGBColor[
             0.23114667261114863`, 0.3602801868327903, 0.9364748331031223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 187}], {
             RGBColor[
             0.21840643996372563`, 0.3468893945429439, 0.9357492957013367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 208}], {
             RGBColor[
             0.257441859662032, 0.38791809563442126`, 0.9379723051054267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 302}], {
             RGBColor[
             0.2075835767828424, 0.33551387913067643`, 0.9351329496541767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 377}], {
             RGBColor[
             0.2375799153602678, 0.3670419328532635, 0.9368411967605548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 388}], {
             RGBColor[
             0.2456236030410635, 0.37549635860503494`, 0.9372992728744065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 87}], {
             RGBColor[
             0.19294989757058154`, 0.3201329544497393, 0.9342995832716268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 126}], {
             RGBColor[
             0.19080527822884924`, 0.31787882354485875`, 0.9341774503727951]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 176}], {
             RGBColor[
             0.19262785863960308`, 0.31979447111483345`, 0.9342812436309215]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 205}], {
             RGBColor[
             0.19210249208707042`, 0.3192422775579583, 0.9342513247829649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 232}], {
             RGBColor[
             0.19470557204870292`, 0.32197827964243614`, 0.9343995663358682]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[
             0.19208286823872933`, 0.31922165164912797`, 0.9342502072338328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 298}], {
             RGBColor[
             0.20225845525357178`, 0.3299168387712073, 0.934829691860896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 373}], {
             RGBColor[
             0.19851817498261992`, 0.32598556705897075`, 0.9346166884327141]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 390}], {
             RGBColor[
             0.2060170491676479, 0.3338673592835195, 0.9350437382239613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 96}], {
             RGBColor[
             0.2073679300463957, 0.3352872207378781, 0.9351206688915568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 104}], {
             RGBColor[
             0.2135778861880246, 0.34181427837669043`, 0.9354743167070156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 182}], {
             RGBColor[
             0.22246710481821064`, 0.35115741076602963`, 0.9359805445575843]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 187}], {
             RGBColor[
             0.20972687217078761`, 0.3377666184761832, 0.9352550071557988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 244}], {
             RGBColor[
             0.1927330122426994, 0.31990499421881113`, 0.9342872319730569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 302}], {
             RGBColor[
             0.1989040089899044, 0.3263911030639157, 0.9346386611086387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 377}], {
             RGBColor[
             0.2289003475673298, 0.3579191567865028, 0.9363469082150169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 388}], {
             RGBColor[
             0.23694403524812552`, 0.36637358253827423`, 0.9368049843288686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 119}], {
             RGBColor[
             0.2344729010553813, 0.363776263822743, 0.9366642568923073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 128}], {
             RGBColor[
             0.2665289573662383, 0.3974692114768138, 0.9384898018765251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.2224096961469096, 0.35109707061257234`, 0.9359772752186821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 135}], {
             RGBColor[
             0.2822556151095555, 0.41153871876028536`, 0.9394754920042432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 146}], {
             RGBColor[
             0.2141426413323014, 0.3424078718408697, 0.9355064786770019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 166}], {
             RGBColor[
             0.2371652059079643, 0.3666060469247946, 0.9368175796707537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 227}], {
             RGBColor[
             0.2515739104642789, 0.38175050897811513`, 0.9376381340794677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 243}], {
             RGBColor[
             0.2302749655066254, 0.3593639673965138, 0.9364251906730947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[
             0.21336000502701669`, 0.3415852714620077, 0.9354619086972226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 275}], {
             RGBColor[
             0.21165010291327152`, 0.33978805592640576`, 0.9353645323014182]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 311}], {
             RGBColor[
             0.21587607865268055`, 0.34422982437086214`, 0.9356051953680067]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 326}], {
             RGBColor[
             0.23536377630225702`, 0.36471263019196243`, 0.936714990919685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 344}], {
             RGBColor[
             0.2103592408268638, 0.3384312780282078, 0.9352910196152566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 346}], {
             RGBColor[
             0.21629108370638292`, 0.34466602099514354`, 0.9356288292918702]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 363}], {
             RGBColor[
             0.3018408929173706, 0.42850250201273, 0.940723448587576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 383}], {
             RGBColor[
             0.2937367673363199, 0.42148311575961905`, 0.9402070608717483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 172}], {
             RGBColor[
             0.5696909718954926, 0.6577404259092337, 0.9610497684809419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 194}], {
             RGBColor[
             0.6075992658363466, 0.6905170696190597, 0.963481170694517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 233}], {
             RGBColor[
             0.865044812104987, 0.8948209835298624, 0.9558976637938235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 256}], {
             RGBColor[
             0.8760312800563814, 0.9016669835366705, 0.876948136427472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 257}], {
             RGBColor[
             0.8645894369328215, 0.89448136547207, 0.956668495179433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 310}], {
             RGBColor[
             0.804263995214133, 0.4072991308684552, 0.44091357643715234`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 316}], {
             RGBColor[
             0.7359499332008539, 0.7936489483339444, 0.9743162695644639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 399}], {
             RGBColor[
             0.5595672102027384, 0.6489717323660277, 0.9604046913379707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 118}], {
             RGBColor[
             0.6542161598297946, 0.7234949587303476, 0.9559255584190995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 123}], {
             RGBColor[
             0.8791001851437382, 0.542812031489136, 0.4485921532142464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 141}], {
             RGBColor[
             0.6533758763039106, 0.7227671473741049, 0.9558720162958637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 161}], {
             RGBColor[
             0.9152656356126947, 0.754447556797873, 0.5945283802670174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 196}], {
             RGBColor[
             0.8975547667711833, 0.9207556417701627, 0.9764242298319501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 214}], {
             RGBColor[
             0.9149531561640245, 0.7530286606028909, 0.5942676397554747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 286}], {
             RGBColor[
             0.6361141683386347, 0.7078159235332517, 0.9547721155282454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 332}], {
             RGBColor[
             0.8621982556376276, 0.41289639483243457`, 0.43240684643119587`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 334}], {
             RGBColor[
             0.9555982588691752, 0.9202058525384339, 0.6338919338224923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 366}], {
             RGBColor[
             0.9721424943326117, 0.9755215245830015, 0.7399924007909114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 125}], {
             RGBColor[
             0.20344264397852102`, 0.33116149620303065`, 0.9348971296569317]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 184}], {
             RGBColor[
             0.21392003441563898`, 0.34217389785736374`, 0.9354938015424155]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 185}], {
             RGBColor[
             0.20341836522778634`, 0.3311359776966468, 0.9348957470179945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 190}], {
             RGBColor[
             0.21321988075352158`, 0.3414379919661722, 0.9354539288271424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 252}], {
             RGBColor[
             0.2101141940866254, 0.33817371836735655`, 0.9352770645659143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 270}], {
             RGBColor[
             0.21111604747539212`, 0.339226729800124, 0.9353341186342953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 274}], {
             RGBColor[
             0.20871345876417752`, 0.33670145673171487`, 0.935197294761503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 288}], {
             RGBColor[
             0.21401051896422651`, 0.342269002854981, 0.9354989545035975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 318}], {
             RGBColor[
             0.2138717930117836, 0.3421231930832301, 0.9354910542658326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 168}], {
             RGBColor[
             0.18992658867508105`, 0.3169552651117129, 0.9341274103026127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 238}], {
             RGBColor[
             0.19138550303315327`, 0.3184886766025597, 0.9342104933170345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 379}], {
             RGBColor[
             0.18217848519657132`, 0.30881151709766497`, 0.9336861672718034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 236}], {
             RGBColor[
             0.3888676051713017, 0.5059520744556105, 0.9465593917911999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 262}], {
             RGBColor[
             0.31621623896980977`, 0.44455427693598626`, 0.9415075983220833]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 265}], {
             RGBColor[
             0.23354789403514828`, 0.36280402279564555`, 0.9366115791109302]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 297}], {
             RGBColor[
             0.28232965171394053`, 0.4140767430581329, 0.9393896280445941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 325}], {
             RGBColor[
             0.25318562671626305`, 0.38344452494766296`, 0.9377299189356977]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 376}], {
             RGBColor[
             0.2771391258654599, 0.4086211712930332, 0.939094035276218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 397}], {
             RGBColor[
             0.3161394186740798, 0.4444877390569253, 0.9415027034007689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 176}], {
             RGBColor[
             0.18652655830038561`, 0.3133816176135313, 0.933933783602668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 205}], {
             RGBColor[
             0.18600119174785296`, 0.31282942405665615`, 0.9339038647547113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 232}], {
             RGBColor[
             0.18860427170948546`, 0.315565426141134, 0.9340521063076146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 277}], {
             RGBColor[
             0.18598156789951187`, 0.3128087981478258, 0.9339027472055792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 373}], {
             RGBColor[
             0.19241687464340246`, 0.3195727135576686, 0.9342692284044607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 390}], {
             RGBColor[
             0.19991574882843044`, 0.32745450578221735`, 0.9346962781957078]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 89}], {
             RGBColor[
             0.33131087657095276`, 0.4543117529947025, 0.9425908573941362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 120}], {
             RGBColor[
             0.42147179727410705`, 0.5394794198355211, 0.9480767881227974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 140}], {
             RGBColor[
             0.41837127081473313`, 0.5367938996534025, 0.947879225318494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 189}], {
             RGBColor[
             0.331784795723977, 0.4548098720727408, 0.9426178463888004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 195}], {
             RGBColor[
             0.42750707901937735`, 0.5447068775411936, 0.948461350938816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 233}], {
             RGBColor[
             0.7003634497191511, 0.7623012578281982, 0.9418757273882692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 255}], {
             RGBColor[
             0.40229233650521606`, 0.5228671349052352, 0.9468546898423349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 257}], {
             RGBColor[
             0.6999080745469857, 0.7619616397704058, 0.9426465587738788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 263}], {
             RGBColor[
             0.3661139704738488, 0.49089201133024934`, 0.9445728421053426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 336}], {
             RGBColor[
             0.33259846324686315`, 0.4556650882287947, 0.9426641835505155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 356}], {
             RGBColor[
             0.6878897223994248, 0.7529983724170004, 0.962990494071441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 359}], {
             RGBColor[
             0.3780427703410259, 0.5018633795124479, 0.9453095289294022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 360}], {
             RGBColor[
             0.5465756968337885, 0.6418389618053506, 0.9578331782484879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 389}], {
             RGBColor[
             0.7117595806289345, 0.7674543626326005, 0.720767374949669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 162}], {
             RGBColor[
             0.2137613905296329, 0.342007153074568, 0.9354847670077999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 183}], {
             RGBColor[
             0.21045489979042858`, 0.338531821664043, 0.935296467251717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 189}], {
             RGBColor[
             0.23269978806740765`, 0.361912609650526, 0.9365632807307278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 263}], {
             RGBColor[
             0.2670289628172794, 0.39799474890803455`, 0.93851827644727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 270}], {
             RGBColor[
             0.22008543635339983`, 0.34865412620301106`, 0.935844912061876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.22057742375863354`, 0.3491712361597149, 0.935872930016774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 291}], {
             RGBColor[
             0.2138432095506144, 0.34209315005324514`, 0.9354894264800044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 336}], {
             RGBColor[
             0.23351345559029374`, 0.36276782580657996`, 0.9366096178924429]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 359}], {
             RGBColor[
             0.2789577626844565, 0.40896611709023306`, 0.9392549632713296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 95}], {
             RGBColor[
             0.23140010342565426`, 0.3605465586872775, 0.936489265613091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 97}], {
             RGBColor[
             0.2570968896215246, 0.3875555102494842, 0.9379526595719574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.23037172884023532`, 0.35946567179528754`, 0.9364307012017953]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 228}], {
             RGBColor[
             0.21978849971833822`, 0.34834202697269134`, 0.9358280019597877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 246}], {
             RGBColor[
             0.21613530957472, 0.3445022925061154, 0.9356199581855191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 260}], {
             RGBColor[
             0.20225002842194761`, 0.32990798163687834`, 0.9348292119653014]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 326}], {
             RGBColor[
             0.22857029923452804`, 0.35757225506245527`, 0.9363281124507266]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 172}], {
             RGBColor[
             0.48609962486048197`, 0.5916756169176496, 0.9532395671401708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 192}], {
             RGBColor[
             0.4254211791359827, 0.5344518171008017, 0.9495440785539795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 208}], {
             RGBColor[
             0.4434969579662055, 0.5534506067219376, 0.9505734674176423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 221}], {
             RGBColor[
             0.48124384050183955`, 0.5874697805650118, 0.9529301608546397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 256}], {
             RGBColor[
             0.792439933021371, 0.8356021745450866, 0.869137935086701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 316}], {
             RGBColor[
             0.6523585861658432, 0.7275841393423603, 0.9665060682236928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 351}], {
             RGBColor[
             0.45106536887988224`, 0.5613307052601594, 0.9510072153286632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 395}], {
             RGBColor[
             0.5156283955691132, 0.6172519539462964, 0.9551211142984581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 399}], {
             RGBColor[
             0.4759758631677278, 0.5829069233744436, 0.9525944899971995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 98}], {
             RGBColor[
             0.19880960071600262`, 0.32629187398221465`, 0.9346332846971046]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 119}], {
             RGBColor[
             0.22208012665594387`, 0.3507506721816547, 0.9359585067237262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 130}], {
             RGBColor[
             0.2100169217474722, 0.33807147897148404`, 0.935271525050101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 143}], {
             RGBColor[
             0.20163694443753327`, 0.3292635914974891, 0.9347942977393655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 146}], {
             RGBColor[
             0.20174986693286398`, 0.32938228019978144`, 0.9348007285084208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 151}], {
             RGBColor[
             0.20599136961110498`, 0.33384036844141496`, 0.9350422758112056]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 158}], {
             RGBColor[
             0.19775538870657966`, 0.32518383031940923`, 0.9345732488827347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 186}], {
             RGBColor[
             0.20547576839988674`, 0.33329843887741967`, 0.9350129130849905]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 267}], {
             RGBColor[
             0.20096723062757926`, 0.3285596798209194, 0.9347561585286415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 306}], {
             RGBColor[
             0.21333519209183469`, 0.34155919149390046`, 0.9354604956372714]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 308}], {
             RGBColor[
             0.20860909712508957`, 0.3365917660321234, 0.9351913515205462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 346}], {
             RGBColor[
             0.2038983093069455, 0.33164042935405524`, 0.934923079123289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 348}], {
             RGBColor[
             0.2027372639690243, 0.3304200970893739, 0.9348569593089071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 354}], {
             RGBColor[
             0.20023581918524017`, 0.32779092002085713`, 0.9347145057290265]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 374}], {
             RGBColor[
             0.1940034937220554, 0.32124035080679264`, 0.9343595840137974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 131}], {
             RGBColor[
             0.5783198351360825, 0.6629059133309206, 0.9625766163950823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 142}], {
             RGBColor[
             0.4083441914838143, 0.5275430486662767, 0.9473966682274677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 188}], {
             RGBColor[
             0.3091689920495968, 0.43916314420292457`, 0.9410324534762535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 201}], {
             RGBColor[
             0.5041214136186714, 0.6049415425126292, 0.9551812111618987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 264}], {
             RGBColor[
             0.3012538452175734, 0.43084382303317337`, 0.9405816975735801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 273}], {
             RGBColor[
             0.433287316679902, 0.5477930013754455, 0.949360282412582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 281}], {
             RGBColor[
             0.3706399848182322, 0.4954514587674228, 0.944837829981916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 293}], {
             RGBColor[
             0.3283292569566383, 0.4588040328927261, 0.9421418278164828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 394}], {
             RGBColor[
             0.35007693853437594`, 0.4776407816051039, 0.9435275708558966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 204}], {
             RGBColor[
             0.1795232819748228, 0.3060207301619996, 0.9335349573763461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.18066543438157506`, 0.30722120475814135`, 0.9336000012662475]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 307}], {
             RGBColor[
             0.17906784709075121`, 0.30554203922260087`, 0.9335090210334537]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 324}], {
             RGBColor[
             0.18239675869616345`, 0.30904093638507546`, 0.9336985976246985]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 97}], {
             RGBColor[
             0.27292796870059677`, 0.4041949781099764, 0.9388542161055278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 148}], {
             RGBColor[
             0.2518920934922597, 0.3820849395144922, 0.9376562541322015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 166}], {
             RGBColor[
             0.24620280791930751`, 0.37610513965577974`, 0.9373322577353658]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 169}], {
             RGBColor[
             0.3522449518778092, 0.4737241407933565, 0.9439035250794346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 228}], {
             RGBColor[
             0.2356195787974104, 0.36498149483318354`, 0.9367295584933581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 246}], {
             RGBColor[
             0.23196638865379215`, 0.3611417603666076, 0.9365215147190895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 276}], {
             RGBColor[
             0.3131382201938357, 0.4399588551912694, 0.9413821143478849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 282}], {
             RGBColor[
             0.2811273621289757, 0.41223265884799526`, 0.9393424107780823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 305}], {
             RGBColor[
             0.2726453120788769, 0.4038978880790839, 0.9388381192290738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 326}], {
             RGBColor[
             0.24440137831360023`, 0.3742117229229475, 0.9372296689842969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 361}], {
             RGBColor[
             0.32840262007179855`, 0.45318011115451534`, 0.9423547484103298]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 382}], {
             RGBColor[
             0.2846635750266093, 0.4152955487246973, 0.9395677351369693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 104}], {
             RGBColor[
             0.21783923349947054`, 0.34629322458604483`, 0.935716994132304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 182}], {
             RGBColor[
             0.2267284521296566, 0.35563635697538404`, 0.9362232219828728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 187}], {
             RGBColor[
             0.2139882194822336, 0.34224556468553763`, 0.9354976845810872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 208}], {
             RGBColor[
             0.25302363918053994`, 0.383274265777015, 0.9377206939851772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 225}], {
             RGBColor[
             0.21005566506834547`, 0.33811220065819025`, 0.9352737314249091]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 261}], {
             RGBColor[
             0.20041641876701294`, 0.3279807416319751, 0.9347247906080353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 377}], {
             RGBColor[
             0.23316169487877575`, 0.36239810299585723`, 0.9365895856403053]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 388}], {
             RGBColor[
             0.24120538255957147`, 0.37085252874762864`, 0.937047661754157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 166}], {
             RGBColor[
             0.27189959411517783`, 0.40311409121798647`, 0.9387956516942321]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 169}], {
             RGBColor[
             0.37794173807367953`, 0.5007330923555633, 0.945366919038301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 224}], {
             RGBColor[
             0.3981861519254275, 0.5171684195208632, 0.946960633454442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 246}], {
             RGBColor[
             0.2576631748496625, 0.38815071192881434`, 0.9379849086779559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 276}], {
             RGBColor[
             0.33883500638970604`, 0.46696780675347616`, 0.9428455083067513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 326}], {
             RGBColor[
             0.27009816450947055`, 0.40122067448515425`, 0.9386930629431633]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 363}], {
             RGBColor[
             0.3365752811245841, 0.4650105463059218, 0.9427015206110543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 382}], {
             RGBColor[
             0.3103603612224796, 0.44230450028690405`, 0.9410311290958356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 383}], {
             RGBColor[
             0.32847115554353346`, 0.45799116005281093`, 0.9421851328952267]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 393}], {
             RGBColor[
             0.5102982570407728, 0.6069665111134733, 0.9566203329382144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 134}], {
             RGBColor[
             0.1861818864522268, 0.313019345647659, 0.9339141550508117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 143}], {
             RGBColor[
             0.19607611547037074`, 0.3234188076760809, 0.9344776167561948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 151}], {
             RGBColor[
             0.20043054064394245`, 0.3279955846200067, 0.934725594828035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 158}], {
             RGBColor[
             0.19219455973941713`, 0.31933904649800093`, 0.9342565678995641]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 163}], {
             RGBColor[
             0.18615149755953203`, 0.3129874049946697, 0.933912424448329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.1906510637312114, 0.3177167343300775, 0.9341686680852945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 186}], {
             RGBColor[
             0.1999149394327242, 0.32745365505601143`, 0.9346962321018197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 240}], {
             RGBColor[
             0.18629079266231832`, 0.3131338129795177, 0.9339203570983641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 272}], {
             RGBColor[
             0.1949500622314218, 0.3222352543260466, 0.9344134896900831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 306}], {
             RGBColor[
             0.20777436312467215`, 0.33571440767249217`, 0.9351438146541007]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 308}], {
             RGBColor[
             0.20304826815792704`, 0.3307469822107151, 0.9348746705373756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 342}], {
             RGBColor[
             0.1898214409282245, 0.31684474816301444`, 0.9341214222939813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 348}], {
             RGBColor[
             0.19717643500186177`, 0.3245753132679656, 0.9345402783257364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 354}], {
             RGBColor[
             0.19467499021807763`, 0.3219461361994489, 0.9343978247458558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 374}], {
             RGBColor[
             0.18844266475489285`, 0.3153955669853844, 0.9340429030306268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 378}], {
             RGBColor[
             0.21674290293340537`, 0.34514091164973765`, 0.9356545597284425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 144}], {
             RGBColor[
             0.7417116613175341, 0.797878300210745, 0.9753542230915366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 169}], {
             RGBColor[
             0.6797124063510102, 0.7475445119943138, 0.9704734146298177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[
             0.7312212189545854, 0.7893616865114603, 0.9745283770409688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 222}], {
             RGBColor[
             0.9266267914902193, 0.9439342403679507, 0.9791054495248444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 223}], {
             RGBColor[
             0.8735329143735617, 0.6106862837337387, 0.46633619385844605`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 276}], {
             RGBColor[
             0.6406056746670367, 0.7137792263922267, 0.9679520038982681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 361}], {
             RGBColor[
             0.6558700745449995, 0.7270004823554725, 0.968924637960713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 382}], {
             RGBColor[
             0.6121310294998102, 0.6891159199256546, 0.9661376246873524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 384}], {
             RGBColor[
             0.9178754148881313, 0.8496097092612407, 0.6279747633092586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 393}], {
             RGBColor[
             0.8120689253181035, 0.8537779307522239, 0.9817268285297311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 157}], {
             RGBColor[
             0.31728677632069113`, 0.4435179334056334, 0.9416477086340886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 167}], {
             RGBColor[
             0.3117593370391954, 0.4377082442608893, 0.941332929144121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 174}], {
             RGBColor[
             0.4027739307357637, 0.5232842676221057, 0.9468853766008484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 198}], {
             RGBColor[
             0.6082548805926754, 0.6882816237042615, 0.9647291510065205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 203}], {
             RGBColor[
             0.3488608742001085, 0.47658748779993204`, 0.9434500843118405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 206}], {
             RGBColor[
             0.40830029738828666`, 0.5280709286532568, 0.947237511797173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 211}], {
             RGBColor[
             0.31010062158634694`, 0.43596482915131163`, 0.941238467752931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 266}], {
             RGBColor[
             0.5229669528809726, 0.6215828095678126, 0.9562473514884939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 341}], {
             RGBColor[
             0.3185278490681524, 0.4448223795517722, 0.9417183858910539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 358}], {
             RGBColor[
             0.33265464447686266`, 0.4596705372168882, 0.942522885990859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 115}], {
             RGBColor[
             0.8876851213781989, 0.5638225279808512, 0.22712473214005577`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 123}], {
             RGBColor[
             0.8503684349635493, 0.38815943948458614`, 0.19586617624509287`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 161}], {
             RGBColor[
             0.8624979444321746, 0.45922425798517125`, 0.20661336858810134`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 193}], {
             RGBColor[
             0.8486252089812196, 0.5684493493271408, 0.4610135933935957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 253}], {
             RGBColor[
             0.8443799630600709, 0.34212942026933035`, 0.1901316087873103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 283}], {
             RGBColor[
             0.8799566783602811, 0.5331818267657741, 0.22090624547796586`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 332}], {
             RGBColor[
             0.8419174702104941, 0.3232016211562354, 0.18777352285356763`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 334}], {
             RGBColor[
             0.8893863599364948, 0.5697297884788785, 0.23285573762508466`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 356}], {
             RGBColor[
             0.8844436842834248, 0.5968435371658081, 0.458657605896074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 364}], {
             RGBColor[
             0.8764286119416923, 0.5191942190745097, 0.21806748042320684`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 366}], {
             RGBColor[
             0.9004158502454526, 0.6066069031752569, 0.3035893822706974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 380}], {
             RGBColor[
             0.8094432238137885, 0.5377433942133822, 0.4571339579761315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 389}], {
             RGBColor[
             0.9003569231030979, 0.6064808639762083, 0.2971755264815594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 108}], {
             RGBColor[
             0.3276991764172302, 0.45803801914073383`, 0.9421097447928497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 139}], {
             RGBColor[
             0.3279891561400408, 0.4583428062151842, 0.9421262587090772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 213}], {
             RGBColor[
             0.33722405994131943`, 0.4665082641722599, 0.9427085967973012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 297}], {
             RGBColor[
             0.32279739953618347`, 0.45288594084814915`, 0.9418305958510031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 333}], {
             RGBColor[
             0.6514056454646207, 0.7208926458479099, 0.9532948082895194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 337}], {
             RGBColor[
             0.6530069899856277, 0.722086925969716, 0.9505841497129952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 345}], {
             RGBColor[
             0.5885592438891699, 0.6712468009440402, 0.9634628617416172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 350}], {
             RGBColor[
             0.3487900132261258, 0.4765261115858444, 0.9434455691132382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 378}], {
             RGBColor[
             0.29463589617818253`, 0.42328641527644917`, 0.9402268398959757]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 122}], {
             RGBColor[
             0.1920779072643653, 0.3192164373505274, 0.9342499247136817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 295}], {
             RGBColor[
             0.1903453971129866, 0.3173954593339403, 0.9341512608235798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 145}], {
             RGBColor[
             0.2369611402467977, 0.36639156097639836`, 0.9368059584332384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 170}], {
             RGBColor[
             0.22977658578143667`, 0.35884013870624076`, 0.936396808685032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 182}], {
             RGBColor[
             0.23293840827128548`, 0.36216341461419643`, 0.9365768697983317]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 187}], {
             RGBColor[
             0.2201981756238625, 0.34877262232435, 0.935851332396546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 192}], {
             RGBColor[
             0.24115781649194606`, 0.3708025337946915, 0.9370449529369735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 208}], {
             RGBColor[
             0.25923359532216883`, 0.3898013234158274, 0.9380743418006362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 225}], {
             RGBColor[
             0.2162656212099744, 0.3446392582970026, 0.935627379240368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 235}], {
             RGBColor[
             0.20864915250350596`, 0.3366338667744967, 0.9351936326150905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 261}], {
             RGBColor[
             0.20662637490864183`, 0.3345077992707875, 0.9350784384234943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 327}], {
             RGBColor[
             0.20490625211316982`, 0.332699841150662, 0.9349804799749857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 335}], {
             RGBColor[
             0.21115674634682685`, 0.33926950689445945`, 0.9353364363748149]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 349}], {
             RGBColor[
             0.21123195753513827`, 0.3393485586220395, 0.9353407195407242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 351}], {
             RGBColor[
             0.26680200623584566`, 0.3976814219540492, 0.9385080897116571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 355}], {
             RGBColor[
             0.21609483282429037`, 0.34445974887503966`, 0.9356176530944622]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 199}], {
             RGBColor[
             0.9870190215241651, 0.9889000460513815, 0.8647919372474027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 215}], {
             RGBColor[
             0.8456866310237973, 0.8792487049970009, 0.932290412064394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 259}], {
             RGBColor[
             0.9403634558512834, 0.9538207185775788, 0.9415651020124101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 271}], {
             RGBColor[
             0.8751025987519235, 0.43256704456911477`, 0.4089395132180147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 287}], {
             RGBColor[
             0.8733134302236104, 0.41881471124185254`, 0.40722620341472526`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 303}], {
             RGBColor[
             0.9396161743909813, 0.7997165627600418, 0.5632237947654809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 333}], {
             RGBColor[
             0.969539411680839, 0.9766186640035739, 0.9281855313871071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 337}], {
             RGBColor[
             0.9711407562018461, 0.97781294412538, 0.9254748728105828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 345}], {
             RGBColor[
             0.9066930101053883, 0.9269728190997042, 0.9383535848392048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 350}], {
             RGBColor[
             0.6669237794423443, 0.7322521297415084, 0.9183362922108259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 353}], {
             RGBColor[
             0.9892810453920724, 0.988090926321853, 0.7004958160747115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 400}], {
             RGBColor[
             0.8765109090962969, 0.44339193500149654`, 0.4102881127942457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 197}], {
             RGBColor[
             0.18891531916432497`, 0.315892356737718, 0.9340698200000144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 217}], {
             RGBColor[
             0.1973830107710603, 0.32479243749905357`, 0.9345520425101908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 231}], {
             RGBColor[
             0.1888628748467801, 0.31583723443481654`, 0.9340668333737145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 254}], {
             RGBColor[
             0.18679837373704838`, 0.3136673128715579, 0.9339492630896711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 314}], {
             RGBColor[
             0.18463641563674799`, 0.3113949578320815, 0.9338261427741893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 369}], {
             RGBColor[
             0.18346224485360668`, 0.3101608298922725, 0.9337592754851194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 124}], {
             RGBColor[
             0.22484989821780513`, 0.3536618777068309, 0.9361162411166642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 150}], {
             RGBColor[
             0.23074389884075946`, 0.35985684606277935`, 0.936451895732749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 152}], {
             RGBColor[
             0.2119625047523057, 0.3401164100666513, 0.9353823231239942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.2124764155335251, 0.34065656288153834`, 0.9354115895827217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.2349712471793796, 0.36430005719603437`, 0.936692636966832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 160}], {
             RGBColor[
             0.20918830325598364`, 0.33720054839948277`, 0.935224336452842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 167}], {
             RGBColor[
             0.22944380789788385`, 0.3584903680512903, 0.9363778574768644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.2249471629490288, 0.3537641091062871, 0.9361217801992172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 181}], {
             RGBColor[
             0.20760170595158578`, 0.3355329340364814, 0.935133982083517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 211}], {
             RGBColor[
             0.2277850924450354, 0.3567469529417126, 0.9362833960856742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 238}], {
             RGBColor[
             0.21198166691675951`, 0.34013655071644366`, 0.9353834143809119]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 245}], {
             RGBColor[
             0.20898762068619692`, 0.33698961829462715`, 0.9352129078773759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 386}], {
             RGBColor[
             0.2825040137132291, 0.4111922082727934, 0.9395118848995476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 297}], {
             RGBColor[
             0.30146181771501923`, 0.43418586257465347`, 0.9404791765948524]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 325}], {
             RGBColor[
             0.2723177927173417, 0.4035536444641835, 0.9388194674859559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 376}], {
             RGBColor[
             0.29627129186653856`, 0.4287302908095537, 0.9401835838264763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 378}], {
             RGBColor[
             0.2733003143570183, 0.40458633700295354`, 0.938875420639825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 397}], {
             RGBColor[
             0.3352715846751584, 0.4645968585734458, 0.9425922519510271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 114}], {
             RGBColor[
             0.18471405231964982`, 0.3114765589082613, 0.9338305640684275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 132}], {
             RGBColor[
             0.1878121680467173, 0.3147328749692917, 0.9340069971758325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 180}], {
             RGBColor[
             0.18558731783868732`, 0.3123944163370016, 0.933880295247856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 232}], {
             RGBColor[
             0.18655512715268852`, 0.3134116452886715, 0.9339354105565427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 249}], {
             RGBColor[
             0.18318613987214505`, 0.3098706260506894, 0.9337435517148859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 370}], {
             RGBColor[
             0.18414849826566793`, 0.3108821257393283, 0.9337983566017154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 111}], {
             RGBColor[
             0.8353956126881364, 0.4322362455432418, 0.4440238905091144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 117}], {
             RGBColor[
             0.7057471364084966, 0.7690367194392469, 0.9721131675946504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 202}], {
             RGBColor[
             0.590277084299675, 0.6718791600205865, 0.9639661767270546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 212}], {
             RGBColor[
             0.715371093239261, 0.7768498811487758, 0.9728708007300837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 239}], {
             RGBColor[
             0.6800499902731076, 0.7481746185632971, 0.9700901941191247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 247}], {
             RGBColor[
             0.8292133862002847, 0.38471694368869236`, 0.43810378344252143`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 269}], {
             RGBColor[
             0.6031830035578256, 0.6830576186116337, 0.9647885304899277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 287}], {
             RGBColor[
             0.8292002229414056, 0.38461576511277085`, 0.438091178290953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 289}], {
             RGBColor[
             0.6635885313279589, 0.7348104646113509, 0.9687942877706517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 292}], {
             RGBColor[
             0.8306488126751848, 0.39575026058266666`, 0.4394783494559681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 303}], {
             RGBColor[
             0.873446363467674, 0.7484181435664192, 0.6095212570798225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 309}], {
             RGBColor[
             0.7751646817101416, 0.8245503622153614, 0.9781540938970312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 362}], {
             RGBColor[
             0.8221167873663267, 0.8612297040031928, 0.982833840996466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 385}], {
             RGBColor[
             0.923690126192328, 0.9380306979900004, 0.809802069993292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 400}], {
             RGBColor[
             0.832397701814092, 0.40919298887241484`, 0.44115308767047345`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 199}], {
             RGBColor[
             0.8806533072058972, 0.4669084665562061, 0.39419180030170453`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 222}], {
             RGBColor[
             0.8681038869231676, 0.45805238435921003`, 0.4379714781522483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 223}], {
             RGBColor[
             0.8374801650249903, 0.28824382747239297`, 0.1834910422728131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 247}], {
             RGBColor[
             0.8235209713761704, 0.1817980697184317, 0.17015701479394557`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 271}], {
             RGBColor[
             0.8244089740108874, 0.1886236470941021, 0.17100736711980608`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 287}], {
             RGBColor[
             0.8235143897467309, 0.18174748043047098`, 0.17015071221816136`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 292}], {
             RGBColor[
             0.8242386846136205, 0.1873147281654189, 0.1708442978006689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 309}], {
             RGBColor[
             0.7835302879454197, 0.39154095679460776`, 0.43890159652522914`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 319}], {
             RGBColor[
             0.8285561841710127, 0.22050092170390542`, 0.174978740252746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 362}], {
             RGBColor[
             0.8148316917162097, 0.4159938513198287, 0.44202142792485233`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 385}], {
             RGBColor[
             0.882547250933544, 0.4671945139777004, 0.32666691392273633`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[
             0.8251131291830741, 0.19403609231029295`, 0.17168166690792155`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 177}], {
             RGBColor[
             0.18091855533538903`, 0.3074872509293952, 0.9336144161301083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 219}], {
             RGBColor[
             0.17968380010062157`, 0.30618944488965105`, 0.933544098646145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 248}], {
             RGBColor[
             0.18167669359362687`, 0.3082841023075451, 0.9336575909823499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 251}], {
             RGBColor[
             0.18268323345773074`, 0.30934203952303163`, 0.9337149119385684]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 260}], {
             RGBColor[
             0.18468581634927816`, 0.3114468811131368, 0.9338289560716861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 162}], {
             RGBColor[
             0.19047273002269705`, 0.31752929429541876`, 0.9341585122444157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 183}], {
             RGBColor[
             0.18716623928349274`, 0.31405396288489373`, 0.9339702124883327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 270}], {
             RGBColor[
             0.196796775846464, 0.3241762674238618, 0.9345186572984918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 357}], {
             RGBColor[
             0.18582607626581804`, 0.31264536658207454`, 0.9338938921870696]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 368}], {
             RGBColor[
             0.18474082389280244`, 0.3115046975290605, 0.9338320886699134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 132}], {
             RGBColor[
             0.1897759122485969, 0.31679689463404087`, 0.9341188295030303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 155}], {
             RGBColor[
             0.18628873221551898`, 0.3131316473192917, 0.933920239758967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 180}], {
             RGBColor[
             0.18755106204056693`, 0.3144584360017507, 0.9339921275750538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 249}], {
             RGBColor[
             0.18514988407402466`, 0.3119346457154385, 0.9338553840420838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 268}], {
             RGBColor[
             0.18716896902427724`, 0.3140568320155338, 0.9339703679430321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 279}], {
             RGBColor[
             0.19285735565451845`, 0.32003568702846064`, 0.9342943131464105]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 299}], {
             RGBColor[
             0.1875337477163088, 0.31444023754916384`, 0.9339911415499016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 300}], {
             RGBColor[
             0.19141939910096473`, 0.3185243035189643, 0.9342124236479517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 370}], {
             RGBColor[
             0.18611224246754757`, 0.3129461454040774, 0.9339101889289132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 123}], {
             RGBColor[
             0.8804744990263506, 0.5083985248696827, 0.22021983203269263`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 161}], {
             RGBColor[
             0.9173271064366133, 0.7028272968686928, 0.25196989849468676`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 193}], {
             RGBColor[
             0.8965180032601808, 0.866664933881647, 0.6335702357029284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 195}], {
             RGBColor[
             0.6898630728334411, 0.7009647207638414, 0.6155071113240207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 214}], {
             RGBColor[
             0.917014626987943, 0.7014084006737106, 0.2517091579831441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 253}], {
             RGBColor[
             0.8684975552193938, 0.416338486439171, 0.2087506971171275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 257}], {
             RGBColor[
             0.9622640683610495, 0.9182194829930534, 0.6096923191590835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 283}], {
             RGBColor[
             0.9435152073287729, 0.813763650039597, 0.2734092138294835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 312}], {
             RGBColor[
             0.7514622050621471, 0.7517529361696669, 0.6201411074573389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 332}], {
             RGBColor[
             0.8635725695202401, 0.3784828882129811, 0.20403452524964213`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 334}], {
             RGBColor[
             0.9576597296930937, 0.8685855926092536, 0.2913334520501617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 356}], {
             RGBColor[
             0.9502457162134885, 0.9092562156396481, 0.6300362544566458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 360}], {
             RGBColor[
             0.8089316906478522, 0.7980968050279984, 0.6248789386336926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 364}], {
             RGBColor[
             0.9382231077008898, 0.7927822385027005, 0.26915106624734497`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 366}], {
             RGBColor[
             0.9742039651565302, 0.9239012646538212, 0.3974339190185809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 380}], {
             RGBColor[
             0.8377450255090341, 0.8206060012110092, 0.627750782576732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 389}], {
             RGBColor[
             0.9741155744429982, 0.9237122058552483, 0.3878131353348738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 141}], {
             RGBColor[
             0.29789401265983945`, 0.4260884769462017, 0.9404351748499746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 179}], {
             RGBColor[
             0.23341719737643146`, 0.3626666523206874, 0.9366041361295647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 209}], {
             RGBColor[
             0.2525333735524159, 0.38275896551722044`, 0.9376927740829386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 286}], {
             RGBColor[
             0.28063230469456346`, 0.41113725310534854`, 0.9393352740823563]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 290}], {
             RGBColor[
             0.24877546734729164`, 0.3788091678306199, 0.9374787668838809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 304}], {
             RGBColor[
             0.26114585574207083`, 0.3918112303614577, 0.938183242202614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 338}], {
             RGBColor[
             0.22507866009155236`, 0.35390232094047974`, 0.9361292687669514]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 239}], {
             RGBColor[
             0.5328344578573876, 0.6316180426642315, 0.9563658268409162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 269}], {
             RGBColor[
             0.45596747114210545`, 0.5665010427125681, 0.9510641632117192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 309}], {
             RGBColor[
             0.6279491492944215, 0.7079937863162957, 0.9644297266188226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 323}], {
             RGBColor[
             0.4895767347577772, 0.5956116976057565, 0.9532057157698048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 362}], {
             RGBColor[
             0.6749012549506066, 0.7446731281041272, 0.9691094737182575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 365}], {
             RGBColor[
             0.4322742926857367, 0.5457268859697086, 0.94956369337159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 377}], {
             RGBColor[
             0.40661285819624315`, 0.5187550912923315, 0.9481023126401036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 385}], {
             RGBColor[
             0.776474593776608, 0.8214741220909348, 0.7960777027150834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 388}], {
             RGBColor[
             0.4146565458770389, 0.527209517044103, 0.9485603887539554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 395}], {
             RGBColor[
             0.49860624010091514`, 0.6034326012978481, 0.9537810678657916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 124}], {
             RGBColor[
             0.29203302591126107`, 0.41977282835890883`, 0.9401070895447208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[
             0.35660710592589273`, 0.4832968843838794, 0.9439436673476838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 150}], {
             RGBColor[
             0.29792702653421543`, 0.4259677967148573, 0.9404427441608055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 179}], {
             RGBColor[
             0.29213029064248475`, 0.4198750597583651, 0.9401126286272736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 196}], {
             RGBColor[
             0.6007859963931654, 0.6812853787799371, 0.9644958808837701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 206}], {
             RGBColor[
             0.39316789594043106`, 0.5149640030957358, 0.9462732885579729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 209}], {
             RGBColor[
             0.3112464668184692, 0.43996737295489813`, 0.9412012665806477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 286}], {
             RGBColor[
             0.33934539796061675`, 0.46834566054302623`, 0.9428437665800653]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 386}], {
             RGBColor[
             0.34968714140668505`, 0.4773031589248714, 0.9435027333276041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 128}], {
             RGBColor[
             0.2718458799395796, 0.4030576342137573, 0.9387925927513947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 130}], {
             RGBColor[
             0.2277266187202509, 0.3566854933495158, 0.936280066093552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 135}], {
             RGBColor[
             0.2875725376828968, 0.4171271414972289, 0.9397782828791128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 146}], {
             RGBColor[
             0.2194595639056427, 0.3479962945778132, 0.9358092695518716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 151}], {
             RGBColor[
             0.22370106658388367`, 0.35245438281944674`, 0.9360508168546565]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 213}], {
             RGBColor[
             0.2826015926364835, 0.4128215587449884, 0.9394615386563896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 227}], {
             RGBColor[
             0.25689083303762017`, 0.3873389317150586, 0.9379409249543373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 243}], {
             RGBColor[
             0.23559188807996673`, 0.3649523901334573, 0.9367279815479644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 267}], {
             RGBColor[
             0.21867692760035795`, 0.34717369419895117`, 0.9357646995720923]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 306}], {
             RGBColor[
             0.2310448890646134, 0.36017320587193224`, 0.9364690366807222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 311}], {
             RGBColor[
             0.22119300122602184`, 0.3498182471078057, 0.9359079862428765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 344}], {
             RGBColor[
             0.2156761634002051, 0.3440197007651513, 0.9355938104901265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 346}], {
             RGBColor[
             0.2216080062797242, 0.35025444373208703`, 0.9359316201667398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 350}], {
             RGBColor[
             0.2941675459212899, 0.42283940615857285`, 0.9401985109723265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 354}], {
             RGBColor[
             0.21794551615801888`, 0.3464049343988889, 0.9357230467724773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 140}], {
             RGBColor[
             0.409447183861318, 0.5290643040720063, 0.9473105903890827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 147}], {
             RGBColor[
             0.3298813986080268, 0.4544594666479659, 0.9424490293594527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 193}], {
             RGBColor[
             0.6252379224927019, 0.7026774950776031, 0.9659558403883122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 195}], {
             RGBColor[
             0.41858299206596217`, 0.5369772819597975, 0.9478927160094046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 241}], {
             RGBColor[
             0.34672955885014695`, 0.4721679512974918, 0.9434085071606221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 242}], {
             RGBColor[
             0.3764731339021319, 0.500503839321299, 0.9452095130834909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 255}], {
             RGBColor[
             0.39336824955180094`, 0.5151375393238391, 0.9462860549129236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 263}], {
             RGBColor[
             0.3571898835204337, 0.4831624157488532, 0.9440042071759314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 312}], {
             RGBColor[
             0.4801821242946682, 0.587765497365623, 0.9525267121427227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 331}], {
             RGBColor[
             0.3267582826576653, 0.45117687376714777`, 0.9422711725263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 356}], {
             RGBColor[
             0.6789656354460096, 0.7452687768356042, 0.9624218591420297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 359}], {
             RGBColor[
             0.3691186833876108, 0.4941337839310517, 0.9447408939999908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 360}], {
             RGBColor[
             0.5376516098803733, 0.6341093662239545, 0.9572645433190765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 380}], {
             RGBColor[
             0.5664649447415552, 0.6566185624069654, 0.9601363872621158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 389}], {
             RGBColor[
             0.7028354936755193, 0.7597247670512044, 0.7201987400202577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[
             0.2188856606362972, 0.3473930858541622, 0.9357765866096961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 202}], {
             RGBColor[
             0.2856578369982738, 0.41583248159385067`, 0.9396429608971655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 234}], {
             RGBColor[
             0.2453302072944222, 0.37518798107295015`, 0.9372825644206755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 289}], {
             RGBColor[
             0.3589692840265578, 0.4787637861846151, 0.9444710719407625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 298}], {
             RGBColor[
             0.2245949434093795, 0.353393904038107, 0.9361017218174963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 173}], {
             RGBColor[
             0.18447873947082444`, 0.3112292301844495, 0.9338171633498009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 338}], {
             RGBColor[
             0.19975108063826336`, 0.32728142907378543`, 0.9346869005858826]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 161}], {
             RGBColor[
             0.8552873220803263, 0.4038002548740027, 0.1997084684807382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 196}], {
             RGBColor[
             0.8434800761859853, 0.5146723115221958, 0.4543057015240267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 214}], {
             RGBColor[
             0.8550790024478794, 0.40285432407734784`, 0.1995346414730431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 253}], {
             RGBColor[
             0.8371693407082226, 0.2867054171581618, 0.18322670867994717`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 283}], {
             RGBColor[
             0.8727460560084327, 0.47775782365460545`, 0.2140013453706027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 332}], {
             RGBColor[
             0.8347068478586457, 0.26777761804506683`, 0.1808686227462045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 334}], {
             RGBColor[
             0.8821757375846465, 0.51430578536771, 0.2259508375177215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 356}], {
             RGBColor[
             0.8772330619315765, 0.5414195340546395, 0.45175270578871085`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 364}], {
             RGBColor[
             0.869217989589844, 0.4637702159633411, 0.2111625803158437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 366}], {
             RGBColor[
             0.8932052278936042, 0.5511829000640883, 0.29668448216333426`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 389}], {
             RGBColor[
             0.8931463007512496, 0.5510568608650397, 0.29027062637419626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 150}], {
             RGBColor[
             0.2325126629936997, 0.36171592933364405`, 0.9365526242346068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 152}], {
             RGBColor[
             0.2137312689052459, 0.34197549333751603`, 0.935483051625852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 156}], {
             RGBColor[
             0.21424517968646528`, 0.3425156461524031, 0.9355123180845796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 157}], {
             RGBColor[
             0.2367400113323198, 0.3661591404668991, 0.9367933654686897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 160}], {
             RGBColor[
             0.21095706740892387`, 0.3390596316703475, 0.9353250649546998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 167}], {
             RGBColor[
             0.23121257205082407`, 0.360349451322155, 0.9364785859787222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 179}], {
             RGBColor[
             0.22671592710196903`, 0.3556231923771518, 0.9362225087010749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 181}], {
             RGBColor[
             0.209370470104526, 0.33739201730734614`, 0.9352347105853747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 238}], {
             RGBColor[
             0.21375043106969976`, 0.3419956339873084, 0.9354841428827698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 245}], {
             RGBColor[
             0.21075638483913717`, 0.33884870156549185`, 0.9353136363792337]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 386}], {
             RGBColor[
             0.28427277786616933`, 0.41305129154365816`, 0.9396126134014054]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 184}], {
             RGBColor[
             0.20307558723579205`, 0.3307756962936808, 0.934876226318445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 185}], {
             RGBColor[
             0.1925739180479394, 0.31973777613296384`, 0.9342781717940241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 190}], {
             RGBColor[
             0.20237543357367466`, 0.3300397904024893, 0.934836353603172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 226}], {
             RGBColor[
             0.1922514050569324, 0.3193987945309108, 0.9342598051563016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 252}], {
             RGBColor[
             0.19926974690677848`, 0.32677551680367367`, 0.934659489341944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 274}], {
             RGBColor[
             0.19786901158433057`, 0.32530325516803194`, 0.9345797195375327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 288}], {
             RGBColor[
             0.2031660717843796, 0.3308708012912981, 0.9348813792796271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 318}], {
             RGBColor[
             0.20302734583193666`, 0.33072499151954715`, 0.9348734790418622]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 176}], {
             RGBColor[
             0.18438193895865332`, 0.3111274867086507, 0.9338116507038363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 205}], {
             RGBColor[
             0.18385657240612066`, 0.31057529315177557`, 0.9337817318558796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 298}], {
             RGBColor[
             0.194012535572622, 0.32124985436502457`, 0.9343600989338109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 320}], {
             RGBColor[
             0.18313368370358218`, 0.3098154912916167, 0.9337405644136882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 347}], {
             RGBColor[
             0.18344187738111917`, 0.31013942238731573`, 0.9337581155876922]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 373}], {
             RGBColor[
             0.19027225530167013`, 0.317318582652788, 0.934147095505629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 137}], {
             RGBColor[
             0.31600670483300364`, 0.4466421785419929, 0.9414111535240912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 138}], {
             RGBColor[
             0.31413697275722113`, 0.44467697158248487`, 0.9413046750483962]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 193}], {
             RGBColor[
             0.5886484429999097, 0.6709855269816585, 0.9636243911098379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 210}], {
             RGBColor[
             0.29252473138981117`, 0.4219611356100898, 0.9400738898749681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 242}], {
             RGBColor[
             0.33988365440933965`, 0.4688118712253543, 0.9428780638050165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 255}], {
             RGBColor[
             0.35677877005900877`, 0.4834455712278943, 0.9439546056344492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 258}], {
             RGBColor[
             0.2885106861095953, 0.4177421195154126, 0.9398452959345076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 264}], {
             RGBColor[
             0.2996738393944105, 0.42947530140255136`, 0.9404810209996725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 312}], {
             RGBColor[
             0.44359264480187605`, 0.5560735292696781, 0.9501952628642483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 328}], {
             RGBColor[
             0.2853602010040631, 0.41443075991720546`, 0.9396658804684725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 331}], {
             RGBColor[
             0.29016880316487315`, 0.419484905671203, 0.9399397232478413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 380}], {
             RGBColor[
             0.529875465248763, 0.6249265943110206, 0.9578049379836415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 394}], {
             RGBColor[
             0.348496932711213, 0.47627225997448197`, 0.9434268942819889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 130}], {
             RGBColor[
             0.2597826750311079, 0.39037844100358665`, 0.9381056110777697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 135}], {
             RGBColor[
             0.31962859399375376`, 0.45082008915129973`, 0.9416038278633306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 139}], {
             RGBColor[
             0.3054227451460619, 0.43834904844198347`, 0.9407047455523833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 151}], {
             RGBColor[
             0.2557571228947407, 0.38614733047351757`, 0.9378763618388744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 213}], {
             RGBColor[
             0.3146576489473405, 0.4465145063990592, 0.9412870836406073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 215}], {
             RGBColor[
             0.5049864538136, 0.6035289290681363, 0.9559781758101122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 224}], {
             RGBColor[
             0.40082474260241224`, 0.5199417456186857, 0.9471108972900512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 227}], {
             RGBColor[
             0.28894688934847723`, 0.42103187936912945`, 0.9397664699385552]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 243}], {
             RGBColor[
             0.26764794439082373`, 0.39864533778752814`, 0.9385535265321823]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 259}], {
             RGBColor[
             0.599663278641086, 0.6781009426487141, 0.9652528657581285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 306}], {
             RGBColor[
             0.2631009453754704, 0.39386615352600307`, 0.9382945816649401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 350}], {
             RGBColor[
             0.32622360223214686`, 0.4565323538126437, 0.9420240559565443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 383}], {
             RGBColor[
             0.3311097462205182, 0.46076448615063337`, 0.9423353967308358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 131}], {
             RGBColor[
             0.8175944103377895, 0.3846574917741582, 0.4381352993196086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 253}], {
             RGBColor[
             0.8212882402079674, 0.16463631957058764`, 0.16801894890576527`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 271}], {
             RGBColor[
             0.8195583588383687, 0.15133969332500205`, 0.16636241255261597`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 287}], {
             RGBColor[
             0.8186637745742122, 0.14446352666137094`, 0.16550575765097125`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 303}], {
             RGBColor[
             0.8442007939445894, 0.3035021905928796, 0.18850141741323326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 333}], {
             RGBColor[
             0.8641496188044945, 0.42143692475523437`, 0.4318092418276507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 337}], {
             RGBColor[
             0.8652171818184992, 0.4222331115031051, 0.43000213610996785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 353}], {
             RGBColor[
             0.8773107079453166, 0.4290850996340871, 0.28001609828605356`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 364}], {
             RGBColor[
             0.8533368890895888, 0.341701118375767, 0.1959548205416618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 391}], {
             RGBColor[
             0.8196355123081763, 0.15193272870280924`, 0.16643629480243607`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 135}], {
             RGBColor[
             0.27550933277442513`, 0.40444794828705827`, 0.9390913012054878]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 146}], {
             RGBColor[
             0.20739635899717102`, 0.3353171013676426, 0.9351222878782466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 151}], {
             RGBColor[
             0.211637861675412, 0.3397751896092761, 0.9353638351810314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 158}], {
             RGBColor[
             0.20340188077088672`, 0.3311186514872704, 0.9348948082525605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 227}], {
             RGBColor[
             0.24482762812914852`, 0.374659738504888, 0.9372539432807123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 243}], {
             RGBColor[
             0.22352868317149505`, 0.3522731969232867, 0.9360409998743393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 267}], {
             RGBColor[
             0.20661372269188627`, 0.33449450098878053`, 0.9350777178984673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 275}], {
             RGBColor[
             0.2049038205781411, 0.33269728545317867`, 0.934980341502663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 306}], {
             RGBColor[
             0.21898168415614172`, 0.3474940126617616, 0.9357820550070972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 311}], {
             RGBColor[
             0.20912979631755016`, 0.33713905389763504`, 0.9352210045692514]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 317}], {
             RGBColor[
             0.20208377375464914`, 0.3297332374403929, 0.9348197440079504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 344}], {
             RGBColor[
             0.20361295849173341`, 0.3313405075549807, 0.9349068288165013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 346}], {
             RGBColor[
             0.20954480137125253`, 0.3375752505219164, 0.9352446384931148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 354}], {
             RGBColor[
             0.2058823112495472, 0.3337257411887183, 0.9350360650988523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 142}], {
             RGBColor[
             0.6441352636384634, 0.7193460306737178, 0.9669266768382974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 201}], {
             RGBColor[
             0.7399124857733206, 0.7967445245200704, 0.9747112197727283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 273}], {
             RGBColor[
             0.6690783888345512, 0.7395959833828867, 0.9688902910234116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 281}], {
             RGBColor[
             0.6064310569728814, 0.687254440774864, 0.9643678385927457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 293}], {
             RGBColor[
             0.5641203291112874, 0.6506070149001673, 0.9616718364273125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 303}], {
             RGBColor[
             0.8540204827009316, 0.7329759435664439, 0.607655802146349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 391}], {
             RGBColor[
             0.8181931112315055, 0.3892593691956639, 0.4387086159715671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 394}], {
             RGBColor[
             0.585868010689025, 0.6694437636125451, 0.9630575794667262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 149}], {
             RGBColor[
             0.20160011613108555`, 0.32922488261236305`, 0.9347922004217959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 155}], {
             RGBColor[
             0.18938684794258642`, 0.3163879633803221, 0.934096672866372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 180}], {
             RGBColor[
             0.1906491777676344, 0.3177147520627811, 0.9341685606824588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 249}], {
             RGBColor[
             0.18824799980109214`, 0.3151909617764689, 0.9340318171494888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 268}], {
             RGBColor[
             0.19026708475134468`, 0.3173131480765642, 0.9341468010504371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 279}], {
             RGBColor[
             0.1959554713815859, 0.323292003089491, 0.9344707462538155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 299}], {
             RGBColor[
             0.19063186344337624`, 0.3176965536101942, 0.9341675746573066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 300}], {
             RGBColor[
             0.1945175148280322, 0.3217806195799947, 0.9343888567553567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 370}], {
             RGBColor[
             0.189210358194615, 0.3162024614651078, 0.9340866220363182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 178}], {
             RGBColor[
             0.18320632976714918`, 0.309891846910452, 0.9337447014995381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 200}], {
             RGBColor[
             0.18872606349581567`, 0.31569343703061226`, 0.9340590421696713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 278}], {
             RGBColor[
             0.18574944160901402`, 0.31256481869885566`, 0.9338895279567354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 296}], {
             RGBColor[
             0.18124069831826523`, 0.30782584362944293`, 0.9336327616964153]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 320}], {
             RGBColor[
             0.18355649439985816`, 0.3102598921411492, 0.9337646428573487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 330}], {
             RGBColor[
             0.1860526851696524, 0.3128835469078388, 0.9339067972289052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 347}], {
             RGBColor[
             0.18386468807739512`, 0.3105838232368483, 0.9337821940313528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 367}], {
             RGBColor[
             0.18474901765317286`, 0.31151330969072427`, 0.9338325552924449]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 398}], {
             RGBColor[
             0.18210607446438823`, 0.30873540882703493`, 0.9336820435877278]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 163}], {
             RGBColor[
             0.17908461226291875`, 0.3055596604815222, 0.9335099757852068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 171}], {
             RGBColor[
             0.18358417843459812`, 0.31028898981693004`, 0.9337662194221723]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 240}], {
             RGBColor[
             0.17922390736570504`, 0.3057060684663703, 0.9335179084352418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 272}], {
             RGBColor[
             0.18788317693480855`, 0.3148075098128992, 0.9340110410269609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 342}], {
             RGBColor[
             0.18275455563161122`, 0.309417003649867, 0.9337189736308591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 374}], {
             RGBColor[
             0.18137577945827954`, 0.307967822472237, 0.9336404543675045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 213}], {
             RGBColor[
             0.33038430669065766`, 0.46058401368253077`, 0.9422727737683254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 215}], {
             RGBColor[
             0.5207131115569171, 0.6175984363516078, 0.9569638659378303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 224}], {
             RGBColor[
             0.41655140034572946`, 0.5340112529021572, 0.9480965874177693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 227}], {
             RGBColor[
             0.3046735470917944, 0.4351013866526011, 0.9407521600662733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 243}], {
             RGBColor[
             0.2833746021341409, 0.41271484507099976`, 0.9395392166599004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 259}], {
             RGBColor[
             0.6153899363844033, 0.6921704499321857, 0.9662385558858466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 350}], {
             RGBColor[
             0.3419502599754641, 0.47060186109611535`, 0.9430097460842624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 363}], {
             RGBColor[
             0.3549405295448861, 0.4818533796872159, 0.9438374745743816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 383}], {
             RGBColor[
             0.3468364039638354, 0.47483399343410504`, 0.9433210868585539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 393}], {
             RGBColor[
             0.5286635054610748, 0.6238093444947674, 0.9577562869015417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 149}], {
             RGBColor[
             0.19648120536399588`, 0.3238445828384636, 0.9345006860263599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 155}], {
             RGBColor[
             0.18426793717549678`, 0.3110076636064226, 0.933805158470936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 268}], {
             RGBColor[
             0.18514817398425504`, 0.3119328483026647, 0.9338552866550012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 279}], {
             RGBColor[
             0.19083656061449622`, 0.3179117033155916, 0.9341792318583795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 299}], {
             RGBColor[
             0.1855129526762866, 0.3123162538362948, 0.9338760602618706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 300}], {
             RGBColor[
             0.18939860406094253`, 0.3164003198060953, 0.9340973423599207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 371}], {
             RGBColor[
             0.1813347042579621, 0.3079246498323852, 0.9336381151956117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 138}], {
             RGBColor[
             0.29077492625511725`, 0.4229532620622423, 0.93987057393605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 164}], {
             RGBColor[
             0.2538187120761361, 0.3841099378008197, 0.9377659722103766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 210}], {
             RGBColor[
             0.2691626848877073, 0.40023742608984725`, 0.9386397887626219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 230}], {
             RGBColor[
             0.2568850160495337, 0.38733281769176137`, 0.9379405936854713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 242}], {
             RGBColor[
             0.31652160790723577`, 0.4470881617051118, 0.9414439626926704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 258}], {
             RGBColor[
             0.2651486396074914, 0.3960184099951701, 0.9384111948221615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 264}], {
             RGBColor[
             0.27631179289230656`, 0.4077515918823088, 0.9390469198873264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 328}], {
             RGBColor[
             0.2619981545019592, 0.39270705039696285`, 0.9382317793561266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 394}], {
             RGBColor[
             0.32513488620910913`, 0.45454855045423936`, 0.9419927931696428]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 149}], {
             RGBColor[
             0.2496156992329207, 0.3796923048161946, 0.9375266168467558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 164}], {
             RGBColor[
             0.2519489800003536, 0.38214473084131173`, 0.9376594937346815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 210}], {
             RGBColor[
             0.2672929528119248, 0.3982722191303392, 0.9385333102869269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 230}], {
             RGBColor[
             0.2550152839737512, 0.38536761073225334`, 0.9378341152097762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 242}], {
             RGBColor[
             0.31465187583145326`, 0.4451229547456037, 0.9413374842169753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 258}], {
             RGBColor[
             0.26327890753170885`, 0.39405320303566205`, 0.9383047163464664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 264}], {
             RGBColor[
             0.27444206081652406`, 0.4057863849228008, 0.9389404414116314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 281}], {
             RGBColor[
             0.3438282004171828, 0.4703940206570502, 0.9431965738199672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 328}], {
             RGBColor[
             0.2601284224261766, 0.3907418434374549, 0.9381253008804314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 394}], {
             RGBColor[
             0.32326515413332657`, 0.4525833434947314, 0.9418863146939478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 186}], {
             RGBColor[
             0.2567623305791477, 0.38720386748367763`, 0.9379336069294297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 213}], {
             RGBColor[
             0.3161784578429658, 0.4481129729732145, 0.941373691457378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 215}], {
             RGBColor[
             0.5065072627092252, 0.6051273956422916, 0.956064783626883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 306}], {
             RGBColor[
             0.2646217542710957, 0.39546462010015837`, 0.9383811894817108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 308}], {
             RGBColor[
             0.25989565930435055`, 0.3904971946383813, 0.9381120453649856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 345}], {
             RGBColor[
             0.5675136417908162, 0.652851509744995, 0.962127956401694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 350}], {
             RGBColor[
             0.3277444111277722, 0.4581308203867991, 0.942110663773315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 378}], {
             RGBColor[
             0.27359029407982893`, 0.40489112407740385`, 0.9388919345560525]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 147}], {
             RGBColor[
             0.32678087214865287`, 0.45177394646584723`, 0.9422514665551494]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 193}], {
             RGBColor[
             0.6221373960333281, 0.6999919748954846, 0.9657582775840088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 195}], {
             RGBColor[
             0.4154824656065883, 0.5342917617776789, 0.9476951532051012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 241}], {
             RGBColor[
             0.343629032390773, 0.46948243111537313`, 0.9432109443563187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 242}], {
             RGBColor[
             0.3733726074427579, 0.4978183191391804, 0.9450119502791875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 255}], {
             RGBColor[
             0.390267723092427, 0.5124520191417203, 0.9460884921086202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 263}], {
             RGBColor[
             0.35408935706105976`, 0.48047689556673456`, 0.943806644371628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 312}], {
             RGBColor[
             0.4770815978352943, 0.5850799771835042, 0.9523291493384193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 331}], {
             RGBColor[
             0.3236577561982914, 0.4484913535850291, 0.9420736097220124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 356}], {
             RGBColor[
             0.6758651089866358, 0.7425832566534856, 0.9622242963377263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 359}], {
             RGBColor[
             0.36601815692823686`, 0.491448263748933, 0.9445433311956875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 360}], {
             RGBColor[
             0.5345510834209994, 0.6314238460418358, 0.9570669805147731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 380}], {
             RGBColor[
             0.5633644182821813, 0.6539330422248467, 0.9599388244578124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 389}], {
             RGBColor[
             0.6997349672161455, 0.7570392468690857, 0.7200011772159544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 179}], {
             RGBColor[
             0.2912900071166007, 0.41914724840212236`, 0.9400590865040379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 196}], {
             RGBColor[
             0.5999457128672814, 0.6805575674236943, 0.9644423387605343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 209}], {
             RGBColor[
             0.3104061832925851, 0.4392395615986554, 0.9411477244574119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 286}], {
             RGBColor[
             0.3385051144347327, 0.4676178491867835, 0.9427902244568296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 290}], {
             RGBColor[
             0.3066482770874609, 0.4352897639120549, 0.9409337172583541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 304}], {
             RGBColor[
             0.31901866548224, 0.4482918264428926, 0.9416381925770871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 386}], {
             RGBColor[
             0.348846857880801, 0.4765753475686286, 0.9434491912043683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.37498442055197767`, 0.49560326154572176`, 0.9453825139194686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 201}], {
             RGBColor[
             0.5699368421210522, 0.6613816598554264, 0.9595312716051138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 273}], {
             RGBColor[
             0.4991027451822828, 0.6042331187182427, 0.9537103428557971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 281}], {
             RGBColor[
             0.436455413320613, 0.55189157611022, 0.9491878904251312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 293}], {
             RGBColor[
             0.3941446854590191, 0.5152441502355233, 0.946491888259698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 394}], {
             RGBColor[
             0.4158923670367568, 0.5340808989479011, 0.9478776312991117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 151}], {
             RGBColor[
             0.2032578843654731, 0.3309673021352812, 0.934886607870296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 158}], {
             RGBColor[
             0.1950219034609478, 0.3223107640132754, 0.9344175809418251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 171}], {
             RGBColor[
             0.19347840745274208`, 0.320688451845352, 0.9343296811275554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 186}], {
             RGBColor[
             0.20274228315425485`, 0.3304253725712859, 0.9348572451440806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 272}], {
             RGBColor[
             0.19777740595295248`, 0.3252069718413211, 0.9345745027323441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 306}], {
             RGBColor[
             0.21060170684620283`, 0.33868612518776664`, 0.9353048276963617]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 308}], {
             RGBColor[
             0.2058756118794577, 0.33371869972598955`, 0.9350356835796365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 342}], {
             RGBColor[
             0.19264878464975516`, 0.3198164656782889, 0.9342824353362423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 348}], {
             RGBColor[
             0.20000377872339242`, 0.3275470307832401, 0.9347012913679973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 354}], {
             RGBColor[
             0.1975023339396083, 0.32491785371472337`, 0.9345588377881168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 374}], {
             RGBColor[
             0.1912700084764235, 0.3183672845006589, 0.9342039160728877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 378}], {
             RGBColor[
             0.21957024665493602`, 0.3481126291650121, 0.9358155727707034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 148}], {
             RGBColor[
             0.41890511783186646`, 0.5289568419765102, 0.9490497655266936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 169}], {
             RGBColor[
             0.5192579762174159, 0.6205960432553745, 0.9552970364739267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 218}], {
             RGBColor[
             0.5707667888209911, 0.662413217772521, 0.9593519988850778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 222}], {
             RGBColor[
             0.7661723613566251, 0.8169857716290115, 0.9639290713689532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 276}], {
             RGBColor[
             0.48015124453344243`, 0.5868307576532874, 0.952775625742377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 282}], {
             RGBColor[
             0.44814038646858245`, 0.5591045613100133, 0.9507359221725744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 305}], {
             RGBColor[
             0.4396583364184836, 0.550769790541102, 0.9502316306235659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 339}], {
             RGBColor[
             0.48160738498318656`, 0.5880919933231088, 0.9528684097242202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 361}], {
             RGBColor[
             0.4954156444114053, 0.6000520136165334, 0.9537482598048219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 382}], {
             RGBColor[
             0.451676599366216, 0.5621674511867154, 0.9509612465314614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 384}], {
             RGBColor[
             0.757420984754537, 0.7226612405223014, 0.6127983851533676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 165}], {
             RGBColor[
             0.23770682741222313`, 0.3671753254665574, 0.9368484242141641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 170}], {
             RGBColor[
             0.24268853638713495`, 0.37241141745778183`, 0.9371321251705074]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 182}], {
             RGBColor[
             0.24585035887698375`, 0.3757346933657375, 0.937312186283807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 192}], {
             RGBColor[
             0.25406976709764434`, 0.3843738125462326, 0.9377802694224489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 208}], {
             RGBColor[
             0.2721455459278671, 0.4033726021673685, 0.9388096582861116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 221}], {
             RGBColor[
             0.3098924284635012, 0.43739177601044266`, 0.941166351723109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 225}], {
             RGBColor[
             0.22917757181567264`, 0.3582105370485437, 0.9363626957258434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 235}], {
             RGBColor[
             0.22156110310920424`, 0.35020514552603776`, 0.9359289491005658]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 335}], {
             RGBColor[
             0.2240686969525251, 0.3528407856460005, 0.9360717528602902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 349}], {
             RGBColor[
             0.2241439081408365, 0.35291983737358057`, 0.9360760360261996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 351}], {
             RGBColor[
             0.2797139568415439, 0.4112527007055903, 0.9392434061971325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 355}], {
             RGBColor[
             0.22900678342998865`, 0.3580310276265808, 0.9363529695799375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 395}], {
             RGBColor[
             0.3442769835307749, 0.46717394939172724`, 0.9433573051669275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 151}], {
             RGBColor[
             0.20337080686080378`, 0.3310859908375735, 0.9348930386393511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 158}], {
             RGBColor[
             0.1951348259562785, 0.3224294527155677, 0.9344240117108803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 227}], {
             RGBColor[
             0.2365605733145403, 0.3659705397331854, 0.936783146739032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 243}], {
             RGBColor[
             0.21526162835688684`, 0.343583998151584, 0.9355702033326591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 267}], {
             RGBColor[
             0.19834666787727806`, 0.32580530221707793`, 0.9346069213567869]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 275}], {
             RGBColor[
             0.1966367657635329, 0.324008086681476, 0.9345095449609826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 306}], {
             RGBColor[
             0.2107146293415335, 0.33880481389005895`, 0.9353112584654169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 311}], {
             RGBColor[
             0.20086274150294195`, 0.3284498551259324, 0.9347502080275711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 317}], {
             RGBColor[
             0.19381671894004093`, 0.32104403866869025`, 0.9343489474662702]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 344}], {
             RGBColor[
             0.1953459036771252, 0.3226513087832781, 0.9344360322748211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 346}], {
             RGBColor[
             0.20127774655664432`, 0.3288860517502138, 0.9347738419514344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 354}], {
             RGBColor[
             0.197615256434939, 0.32503654241701563`, 0.9345652685571719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 195}], {
             RGBColor[
             0.3359166803532971, 0.45968692435363845`, 0.9428335921754714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 217}], {
             RGBColor[
             0.2277310230294914, 0.3566901225577769, 0.9362803169124476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 231}], {
             RGBColor[
             0.2192108871052112, 0.34773491949353985`, 0.9357951077759714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 241}], {
             RGBColor[
             0.2640632471374818, 0.3948775936913327, 0.9383493833266887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 242}], {
             RGBColor[
             0.29380682218946674`, 0.42321348171513995`, 0.9401503892495575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 255}], {
             RGBColor[
             0.3107019378391358, 0.4378471817176799, 0.9412269310789902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 312}], {
             RGBColor[
             0.3975158125820031, 0.5104751397594638, 0.9474675883087893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 331}], {
             RGBColor[
             0.2440919709450002, 0.37388651616098867`, 0.9372120486923824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 359}], {
             RGBColor[
             0.28645237167494564`, 0.4168434263248926, 0.9396817701660576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 392}], {
             RGBColor[
             0.2251386082236323, 0.35396533022822685`, 0.9361326827243879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 218}], {
             RGBColor[
             0.40841467546891774`, 0.5204402282772255, 0.9482239194761258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 228}], {
             RGBColor[
             0.2402804897849437, 0.36988040779990605`, 0.9369949904788982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 276}], {
             RGBColor[
             0.31779913118136904`, 0.44485776815799194`, 0.9416475463334251]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.285788273116509, 0.4171315718147177, 0.9396078427636225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 301}], {
             RGBColor[
             0.25321055434935075`, 0.3834707254705414, 0.9377313385275249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 305}], {
             RGBColor[
             0.2773062230664102, 0.4087968010458064, 0.939103551214614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 313}], {
             RGBColor[
             0.27058528986872044`, 0.4017326741232574, 0.9387208040117352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 339}], {
             RGBColor[
             0.3192552716311131, 0.4461190038278132, 0.9417403303152683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 340}], {
             RGBColor[
             0.263972502592159, 0.39478221542066183`, 0.9383442155590771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 361}], {
             RGBColor[
             0.33306353105933184`, 0.4580790241212378, 0.94262018039587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 382}], {
             RGBColor[
             0.2893244860141426, 0.42019446169141983`, 0.9398331671225094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 155}], {
             RGBColor[
             0.19811293609800762`, 0.3255596352976139, 0.9345936106777326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 164}], {
             RGBColor[
             0.21265948505393958`, 0.340848980554772, 0.9354220151210823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 210}], {
             RGBColor[
             0.22800345786551077`, 0.3569764688437995, 0.9362958316733276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 230}], {
             RGBColor[
             0.21572578902733716`, 0.34407186044571364`, 0.935596636596177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 258}], {
             RGBColor[
             0.22398941258529487`, 0.35275745274912235`, 0.9360672377328672]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 264}], {
             RGBColor[
             0.23515256587011008`, 0.3644906346362611, 0.9367029627980321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 268}], {
             RGBColor[
             0.19899317290676588`, 0.326484819993856, 0.9346437388617977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 279}], {
             RGBColor[
             0.20468155953700706`, 0.33246367500678287`, 0.9349676840651762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 299}], {
             RGBColor[
             0.19935795159879743`, 0.32686822552748607`, 0.9346645124686672]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 300}], {
             RGBColor[
             0.20324360298345337`, 0.33095229149728655`, 0.9348857945667173]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 328}], {
             RGBColor[
             0.22083892747976266`, 0.3494460931509151, 0.9358878222668322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 152}], {
             RGBColor[
             0.21962526952820027`, 0.3481704616934645, 0.9358187062419367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 156}], {
             RGBColor[
             0.22013918030941965`, 0.34871061450835156`, 0.9358479727006643]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 157}], {
             RGBColor[
             0.24263401195527415`, 0.3723541088228476, 0.9371290200847746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 160}], {
             RGBColor[
             0.2168510680318782, 0.345254600026296, 0.9356607195707846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 167}], {
             RGBColor[
             0.2371065726737784, 0.3665444196781035, 0.936814240594807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 179}], {
             RGBColor[
             0.23260992772492337`, 0.36181816073310025`, 0.9365581633171598]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 181}], {
             RGBColor[
             0.21526447072748034`, 0.3435869856632946, 0.9355703652014595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 206}], {
             RGBColor[
             0.33364753302286965`, 0.45690710407047097`, 0.9427188232478589]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 211}], {
             RGBColor[
             0.23544785722092995`, 0.3648010045685258, 0.9367197792036168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 238}], {
             RGBColor[
             0.21964443169265407`, 0.3481906023432569, 0.9358197974988545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 386}], {
             RGBColor[
             0.29016677848912364`, 0.4192462598996066, 0.9399482680174902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 158}], {
             RGBColor[
             0.19937632863451948`, 0.3268875409572013, 0.9346655590136652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 186}], {
             RGBColor[
             0.20709670832782653`, 0.33500214951521173`, 0.9351052232159208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 227}], {
             RGBColor[
             0.2408020759927813, 0.3704286279748189, 0.937024694041817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 267}], {
             RGBColor[
             0.20258817055551906`, 0.33026339045871145`, 0.9348484686595718]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 306}], {
             RGBColor[
             0.21495613201977448`, 0.3432629021316925, 0.9355528057682019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 308}], {
             RGBColor[
             0.2102300370530294, 0.33829547666991544`, 0.9352836616514766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 311}], {
             RGBColor[
             0.20510424418118295`, 0.33290794336756596`, 0.934991755330356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 317}], {
             RGBColor[
             0.1980582216182819, 0.3255021269103238, 0.9345904947690551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 344}], {
             RGBColor[
             0.1995874063553662, 0.3271093970249116, 0.9346775795776059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 346}], {
             RGBColor[
             0.2055192492348853, 0.3333441399918473, 0.9350153892542195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 348}], {
             RGBColor[
             0.20435820389696413`, 0.332123807727166, 0.9349492694398375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 354}], {
             RGBColor[
             0.20185675911317996`, 0.3294946306586492, 0.934806815859957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 156}], {
             RGBColor[
             0.20135778622096587`, 0.32897017851222354`, 0.9347784000919095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 157}], {
             RGBColor[
             0.22385261786682037`, 0.3526136728267195, 0.9360594474760198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 160}], {
             RGBColor[
             0.19806967394342445`, 0.325514164030168, 0.9345911469620297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 179}], {
             RGBColor[
             0.2138285336364696, 0.3420777247369723, 0.935488590708405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 181}], {
             RGBColor[
             0.1964830766390266, 0.32384654966716653`, 0.9345007925927047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 238}], {
             RGBColor[
             0.20086303760420032`, 0.32845016634712887`, 0.9347502248900996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 245}], {
             RGBColor[
             0.19786899137363773`, 0.3253032339253123, 0.9345797183865636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 168}], {
             RGBColor[
             0.20180786245057253`, 0.3294432371660213, 0.9348040312673576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 175}], {
             RGBColor[
             0.19789401206423968`, 0.32532953225753836`, 0.9345811432778787]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 211}], {
             RGBColor[
             0.21907020233692062`, 0.34758705088213704`, 0.9357870959865418]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 216}], {
             RGBColor[
             0.21073387590110806`, 0.33882504324447416`, 0.935312354528512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 229}], {
             RGBColor[
             0.2017865527982215, 0.3294208393702904, 0.934802817714181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 294}], {
             RGBColor[
             0.20769214048678164`, 0.33562798646685293`, 0.9351391321965103]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 329}], {
             RGBColor[
             0.23399514583317907`, 0.36327411279277777`, 0.9366370494391784]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 341}], {
             RGBColor[
             0.22749742981872606`, 0.3564446012825976, 0.9362670141246647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 343}], {
             RGBColor[
             0.20318561149837056`, 0.330891338769592, 0.9348824920374326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 358}], {
             RGBColor[
             0.24162422522743635`, 0.37129275894771363`, 0.9370715142244698]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 379}], {
             RGBColor[
             0.19405975897206282`, 0.32129948915197337`, 0.9343627882365483]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 207}], {
             RGBColor[
             0.18894498275511917`, 0.315923535052423, 0.9340715092976267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 231}], {
             RGBColor[
             0.18878970308862236`, 0.3157603262776354, 0.9340626663503354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 369}], {
             RGBColor[
             0.183389073095449, 0.31008392173509136`, 0.9337551084617403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 372}], {
             RGBColor[
             0.18315975702077553`, 0.3098428960011307, 0.9337420492505304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 387}], {
             RGBColor[
             0.18595738695423472`, 0.312783382441179, 0.9339013701365182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 392}], {
             RGBColor[
             0.19471742420704347`, 0.3219907370123223, 0.934400241298752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 249}], {
             RGBColor[
             0.18476081976801417`, 0.3115257144617197, 0.9338332274054255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 268}], {
             RGBColor[
             0.18677990471826675`, 0.31364790076181503`, 0.9339482113063738]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 279}], {
             RGBColor[
             0.19246829134850796`, 0.31962675577474187`, 0.9342721565097523]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.1871446834102983, 0.31403130629544507`, 0.9339689849132433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 300}], {
             RGBColor[
             0.19103033479495424`, 0.31811537226524556`, 0.9341902670112934]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 370}], {
             RGBColor[
             0.18572317816153708`, 0.3125372141503586, 0.9338880322922549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 371}], {
             RGBColor[
             0.18296643499197385`, 0.3096397022915355, 0.9337310398469844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 160}], {
             RGBColor[
             0.19858358472464382`, 0.32605431684505504`, 0.9346204134207573]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.21434244441768896`, 0.34261787755185935`, 0.9355178571671325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 181}], {
             RGBColor[
             0.19699698742024596`, 0.3243867024820536, 0.9345300590514323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 245}], {
             RGBColor[
             0.1983829021548571, 0.32584338674019936`, 0.9346089848452912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 352}], {
             RGBColor[
             0.19412861826228733`, 0.32137186463193046`, 0.9343667096712585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 396}], {
             RGBColor[
             0.19313485512094197`, 0.32032735656215416`, 0.9343101163304997]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 160}], {
             RGBColor[
             0.22107841637049833`, 0.349697811159551, 0.9359014608048675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 167}], {
             RGBColor[
             0.24133392101239853`, 0.37098763081135855`, 0.93705498182889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 168}], {
             RGBColor[
             0.222412865673202, 0.35110040198566517`, 0.9359774557185156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 203}], {
             RGBColor[
             0.2784354581733116, 0.40986687435040126`, 0.9391721369966093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 206}], {
             RGBColor[
             0.3378748813614898, 0.46135031520372605`, 0.942959564481942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 211}], {
             RGBColor[
             0.23967520555955008`, 0.36924421570178084`, 0.9369605204376998]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 238}], {
             RGBColor[
             0.22387178003127423`, 0.3526338134765119, 0.9360605387329375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 341}], {
             RGBColor[
             0.24810243304135554`, 0.37810176610224144`, 0.9374404385758228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 358}], {
             RGBColor[
             0.2622292284500658, 0.3929499237673575, 0.938244938675628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 386}], {
             RGBColor[
             0.2943941268277438, 0.42368947103286164`, 0.9401890092515732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 267}], {
             RGBColor[
             0.19435218965099377`, 0.3216068523367057, 0.934379441731101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 306}], {
             RGBColor[
             0.20672015111524922`, 0.33460636400968674`, 0.935083778839731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 308}], {
             RGBColor[
             0.20199405614850408`, 0.32963893854790965`, 0.9348146347230057]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 311}], {
             RGBColor[
             0.19686826327665763`, 0.3242514052455602, 0.9345227284018851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 317}], {
             RGBColor[
             0.18982224071375664`, 0.31684558878831803`, 0.9341214678405843]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 344}], {
             RGBColor[
             0.19135142545084088`, 0.31845285890290587`, 0.934208552649135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 346}], {
             RGBColor[
             0.19728326833036003`, 0.3246876018698416, 0.9345463623257486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 348}], {
             RGBColor[
             0.1961222229924388, 0.3234672696051602, 0.9344802425113666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 354}], {
             RGBColor[
             0.1936207782086547, 0.3208380925366434, 0.9343377889314861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 374}], {
             RGBColor[
             0.1873884527454699, 0.3142875233225789, 0.9339828672162569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 250}], {
             RGBColor[
             0.18793077615893167`, 0.3148575396154177, 0.934013751732358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 265}], {
             RGBColor[
             0.19056897353088317`, 0.3176304523247132, 0.9341639931698273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 321}], {
             RGBColor[
             0.1833474210515813, 0.31004014279609426`, 0.9337527364394607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 375}], {
             RGBColor[
             0.19246854917072223`, 0.3196270267622359, 0.9342721711923458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 381}], {
             RGBColor[
             0.18574510039169012`, 0.3125602558041992, 0.9338892807308311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[
             0.19370887514270452`, 0.320930687999998, 0.9343428059215524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 238}], {
             RGBColor[
             0.19808883610787825`, 0.32553430467996036`, 0.9345922382189475]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 245}], {
             RGBColor[
             0.19509478987731566`, 0.3223873722581438, 0.9344217317154114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 196}], {
             RGBColor[
             0.8618354721760655, 0.7122379768474625, 0.603098702731688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 214}], {
             RGBColor[
             0.8792338615689066, 0.5445109956801907, 0.22094211265521246`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 253}], {
             RGBColor[
             0.8433103782733695, 0.3117402164434911, 0.18823933356517306`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 283}], {
             RGBColor[
             0.9057344419097366, 0.6568662450460772, 0.2426421685015519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 332}], {
             RGBColor[
             0.8383853925742157, 0.27388461821730115`, 0.1835231616976877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 334}], {
             RGBColor[
             0.9198789642740572, 0.7116881876157337, 0.2605664067222301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.9124649507944522, 0.7523588106461282, 0.5992692091287142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 364}], {
             RGBColor[
             0.9004423422818535, 0.6358848335091806, 0.23838402091941335`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 366}], {
             RGBColor[
             0.9364231997374939, 0.7670038596603013, 0.3666668736906492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 389}], {
             RGBColor[
             0.9363348090239618, 0.7668148008617284, 0.3570460900069422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 183}], {
             RGBColor[
             0.1919904214056781, 0.3191244841661233, 0.9342449425234534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 270}], {
             RGBColor[
             0.20162095796864934`, 0.3292467887050914, 0.9347933873336124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 280}], {
             RGBColor[
             0.20211294537388308`, 0.32976389866179523`, 0.9348214052885103]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 291}], {
             RGBColor[
             0.1953787311658639, 0.32268581255532547`, 0.9344379017517408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 336}], {
             RGBColor[
             0.21504897720554328`, 0.3433604883086603, 0.9355580931641793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 357}], {
             RGBColor[
             0.1906502583880034, 0.3177158878633042, 0.9341686222221902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 368}], {
             RGBColor[
             0.18956500601498782`, 0.31657521881029016`, 0.934106818705034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 171}], {
             RGBColor[
             0.18355378954190335`, 0.31025704916394076`, 0.9337644888196897]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 240}], {
             RGBColor[
             0.17919351847301027`, 0.305674127813381, 0.9335161778327592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 272}], {
             RGBColor[
             0.18785278804211375`, 0.3147755691599099, 0.9340093104244782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 342}], {
             RGBColor[
             0.18272416673891645`, 0.30938506299687774`, 0.9337172430283764]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 374}], {
             RGBColor[
             0.1813453905655848, 0.3079358818192477, 0.9336387237650219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 210}], {
             RGBColor[
             0.23033673863294363`, 0.3594288948689166, 0.9364287085612534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 230}], {
             RGBColor[
             0.21805906979477002`, 0.3465242864708308, 0.9357295134841028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 258}], {
             RGBColor[
             0.22632269335272776`, 0.3552098787742395, 0.936200114620793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 264}], {
             RGBColor[
             0.23748584663754294`, 0.36694306066137816`, 0.9368358396859577]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 279}], {
             RGBColor[
             0.20701484030443992`, 0.33491610103189995`, 0.9351005609531018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 328}], {
             RGBColor[
             0.22317220824719552`, 0.35189851917603227`, 0.9360206991547579]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 170}], {
             RGBColor[
             0.23052227294686206`, 0.35962390319639986`, 0.9364392744659576]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 172}], {
             RGBColor[
             0.3025819493818708, 0.42881009810169846`, 0.9407829073040905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 184}], {
             RGBColor[
             0.21954677082243013`, 0.3480879545765947, 0.9358142358567716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 190}], {
             RGBColor[
             0.21884661716031273`, 0.34735204868540315`, 0.9357743631414985]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 192}], {
             RGBColor[
             0.24190350365737148`, 0.3715862982848506, 0.9370874187178992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 221}], {
             RGBColor[
             0.29772616502322835`, 0.42460426174906063`, 0.9404735010185594]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 226}], {
             RGBColor[
             0.20872258864357046`, 0.33671105281382463`, 0.935197814694628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 252}], {
             RGBColor[
             0.21574093049341658`, 0.3440877750865875, 0.9355974988802704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 274}], {
             RGBColor[
             0.21434019517096867`, 0.34261551345094576`, 0.9355177290758593]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 288}], {
             RGBColor[
             0.2196372553710177, 0.3481830595742119, 0.9358193888179538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 318}], {
             RGBColor[
             0.21949852941857476`, 0.348037249802461, 0.9358114885801888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 322}], {
             RGBColor[
             0.2103258844391586, 0.3383962183498125, 0.9352891200183233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 351}], {
             RGBColor[
             0.26754769340127105`, 0.39846518644420825`, 0.9385505554925828]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 355}], {
             RGBColor[
             0.2168405199897158, 0.34524351336519876`, 0.9356601188753879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 399}], {
             RGBColor[
             0.2924581876891166, 0.42004140455849254`, 0.9401378301611192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 169}], {
             RGBColor[
             0.3512165772923903, 0.4726432539013666, 0.9438449606681389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 246}], {
             RGBColor[
             0.23093801406837325`, 0.3600608734746177, 0.9364629503077938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 326}], {
             RGBColor[
             0.24337300372818133`, 0.3731308360309576, 0.9371711045730012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 363}], {
             RGBColor[
             0.3098501203432949, 0.43692070785172515`, 0.9411795622408922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 383}], {
             RGBColor[
             0.3017459947622442, 0.42990132159861427`, 0.9406631745250644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 168}], {
             RGBColor[
             0.21688542639170627`, 0.3452907128409211, 0.935662676228548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.2729080188918158, 0.40405718520565725`, 0.9388573575066418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 211}], {
             RGBColor[
             0.23414776627805434`, 0.3634345265570368, 0.9366457409477322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 216}], {
             RGBColor[
             0.22581143984224178`, 0.35467251891937396`, 0.9361709994897025]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 238}], {
             RGBColor[
             0.2183443407497785, 0.3468241243317679, 0.9357457592429699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 341}], {
             RGBColor[
             0.2425749937598598, 0.37229207695749733`, 0.9371256590858552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 358}], {
             RGBColor[
             0.25670178916857006`, 0.3871402346226134, 0.9379301591856604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 211}], {
             RGBColor[
             0.2152267109388578, 0.3435472977313434, 0.935568214837358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 216}], {
             RGBColor[
             0.20689038450304525`, 0.3347852900936806, 0.9350934733793282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 238}], {
             RGBColor[
             0.19942328541058194`, 0.3269368955060745, 0.9346682331325956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 341}], {
             RGBColor[
             0.22365393842066325`, 0.35240484813180395`, 0.936048132975481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 379}], {
             RGBColor[
             0.190216267574, 0.31725973600117974`, 0.9341439070873645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 218}], {
             RGBColor[
             0.5087675338544672, 0.6120794295560898, 0.9544711904233589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 222}], {
             RGBColor[
             0.7041731063901011, 0.7666519834125803, 0.9590482629072343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 224}], {
             RGBColor[
             0.4775031351026399, 0.5866975822042433, 0.9520099424283488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 276}], {
             RGBColor[
             0.41815198956691846`, 0.5364969694368562, 0.947894817280658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 326}], {
             RGBColor[
             0.349415147686683, 0.47074983716853436`, 0.9437423719170701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 361}], {
             RGBColor[
             0.4334163894448813, 0.5497182254001022, 0.948867451343103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 363}], {
             RGBColor[
             0.4158922643017966, 0.5345397089893019, 0.947750829584961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 382}], {
             RGBColor[
             0.38967734439969204`, 0.5118336629702842, 0.9460804380697425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 383}], {
             RGBColor[
             0.4077881387207459, 0.527520322736191, 0.9472344418691334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 393}], {
             RGBColor[
             0.5896152402179853, 0.6764956737968535, 0.9616696419121211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[
             0.2468852126322833, 0.37682239027607506`, 0.9373711196742425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 208}], {
             RGBColor[
             0.26496099146250607`, 0.3958211798972109, 0.9384005085379051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 221}], {
             RGBColor[
             0.30270787399814014`, 0.42984035374028506`, 0.9407572019749026]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 225}], {
             RGBColor[
             0.22199301735031157`, 0.3506591147783862, 0.9359535459776369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 235}], {
             RGBColor[
             0.21437654864384317`, 0.34265372325588017`, 0.9355197993523594]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 322}], {
             RGBColor[
             0.2153075934140704, 0.3436323103410369, 0.9355728209746665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 335}], {
             RGBColor[
             0.21688414248716403`, 0.34528936337584293`, 0.9356626031120838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 349}], {
             RGBColor[
             0.21695935367547547`, 0.34536841510342303`, 0.9356668862779931]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 351}], {
             RGBColor[
             0.27252940237618284`, 0.4037012784354327, 0.938834256448926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 355}], {
             RGBColor[
             0.2218222289646276, 0.3504796053564232, 0.9359438198317311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 186}], {
             RGBColor[
             0.1973172314150955, 0.32472329922528254`, 0.9345482964731804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 240}], {
             RGBColor[
             0.18369308464468964`, 0.3104034571487888, 0.9337724214697247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 272}], {
             RGBColor[
             0.19235235421379315`, 0.3195048984953177, 0.9342655540614437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 308}], {
             RGBColor[
             0.20045056014029836`, 0.3280166263799862, 0.9347267349087363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 342}], {
             RGBColor[
             0.18722373291059582`, 0.31411439233228555`, 0.933973486665342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 348}], {
             RGBColor[
             0.1945787269842331, 0.32184495743723673`, 0.934392342697097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 374}], {
             RGBColor[
             0.18584495673726414`, 0.3126652111546555, 0.9338949674019874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 192}], {
             RGBColor[
             0.31894488906729196`, 0.44600858518137365`, 0.9417147525123752]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 194}], {
             RGBColor[
             0.41753162873264527`, 0.5360090287080477, 0.9478416433121417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 221}], {
             RGBColor[
             0.3747675504331488, 0.4990265486455837, 0.9451008348130354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 256}], {
             RGBColor[
             0.6859636429526801, 0.7471589426256584, 0.8613086090450968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 316}], {
             RGBColor[
             0.5458822960971526, 0.6391409074229324, 0.9586767421820886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 351}], {
             RGBColor[
             0.3445890788111915, 0.47288747334073133`, 0.943177889287059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 399}], {
             RGBColor[
             0.369499573099037, 0.49446369145501556`, 0.9447651639555954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 198}], {
             RGBColor[
             0.6233166189809511, 0.701327344471203, 0.9656888716580491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 203}], {
             RGBColor[
             0.3639226125883841, 0.4896332085668736, 0.9444098049633691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 266}], {
             RGBColor[
             0.5380286912692482, 0.6346285303347542, 0.9572070721400225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 313}], {
             RGBColor[
             0.35122662219084355`, 0.47640574207717373`, 0.9436825095790529]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 329}], {
             RGBColor[
             0.34008730347088106`, 0.4646976118288939, 0.9430481418570962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 340}], {
             RGBColor[
             0.3446138349142821, 0.46945528337457815`, 0.9433059211263948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 341}], {
             RGBColor[
             0.3335895874564281, 0.4578681003187137, 0.9426781065425826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 358}], {
             RGBColor[
             0.34771638286513834`, 0.47271625798382977`, 0.9434826066423876]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 204}], {
             RGBColor[
             0.1850387535749342, 0.31181784051481387`, 0.9338490553245634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 216}], {
             RGBColor[
             0.20297653411671235`, 0.3306715851851976, 0.9348705853898494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 229}], {
             RGBColor[
             0.1940292110138258, 0.32126738131101384`, 0.9343610485755184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 294}], {
             RGBColor[
             0.19993479870238595`, 0.3274745284075764, 0.9346973630578478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 307}], {
             RGBColor[
             0.18458331869086259`, 0.3113391495754152, 0.933823118981671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 343}], {
             RGBColor[
             0.19542826971397487`, 0.32273788071031545`, 0.93444072289877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 379}], {
             RGBColor[
             0.1863024171876671, 0.3131460310926968, 0.9339210190978857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 205}], {
             RGBColor[
             0.18567915281687453`, 0.3124909407217502, 0.9338855251140061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 232}], {
             RGBColor[
             0.18828223277850703`, 0.3152269428062281, 0.9340337666669094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 277}], {
             RGBColor[
             0.18565952896853344`, 0.31247031481291987`, 0.933884407564874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 298}], {
             RGBColor[
             0.19583511598337588`, 0.32316550193499927`, 0.9344638921919373]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 320}], {
             RGBColor[
             0.18495626411433608`, 0.3117311388615913, 0.9338443576718145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 347}], {
             RGBColor[
             0.18526445779187303`, 0.3120550699572905, 0.9338619088458187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 373}], {
             RGBColor[
             0.192094835712424, 0.3192342302227627, 0.9342508887637553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 390}], {
             RGBColor[
             0.199593709897452, 0.3271160224473115, 0.9346779385550025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 219}], {
             RGBColor[
             0.18016175523476746`, 0.3066918060397442, 0.9335713174839634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 248}], {
             RGBColor[
             0.18215464872777276`, 0.30878646345763827`, 0.9336848098201683]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 260}], {
             RGBColor[
             0.18516377148342406`, 0.31194924226322995`, 0.9338561749095045]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 285}], {
             RGBColor[
             0.18283630546897034`, 0.3095029279121705, 0.9337236291631588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 200}], {
             RGBColor[
             0.1885274133225135, 0.31548464310332325`, 0.9340477293361784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 278}], {
             RGBColor[
             0.18555079143571185`, 0.31235602477156665`, 0.9338782151232425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 296}], {
             RGBColor[
             0.18104204814496305`, 0.30761704970215387`, 0.9336214488629224]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 330}], {
             RGBColor[
             0.18585403499635023`, 0.3126747529805498, 0.9338954843954123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 367}], {
             RGBColor[
             0.18455036747987072`, 0.3113045157634352, 0.933821242458952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 398}], {
             RGBColor[
             0.18190742429108608`, 0.30852661489974587`, 0.9336707307542348]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 209}], {
             RGBColor[
             0.24592936800917714`, 0.3758177369731411, 0.9373166857370019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 245}], {
             RGBColor[
             0.21085364957036085`, 0.33895093296494805`, 0.9353191754617867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 286}], {
             RGBColor[
             0.2740282991513247, 0.4041960245612692, 0.9389591857364195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 290}], {
             RGBColor[
             0.24217146180405288`, 0.37186793928654055`, 0.9371026785379442]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 352}], {
             RGBColor[
             0.20659936567779108`, 0.3344794108566792, 0.9350769002877538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 386}], {
             RGBColor[
             0.284370042597393, 0.41315352294311436`, 0.9396181524839584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 232}], {
             RGBColor[
             0.18939213687360562`, 0.3163935223821609, 0.9340969740631693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 249}], {
             RGBColor[
             0.18602314959306215`, 0.3128525031441788, 0.9339051152215123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 268}], {
             RGBColor[
             0.1880422345433147, 0.314974689444274, 0.9340200991224608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 370}], {
             RGBColor[
             0.18698550798658503`, 0.3138640028328177, 0.9339599201083417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 238}], {
             RGBColor[
             0.1965022388034804, 0.3238666903169589, 0.9345018838496224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 245}], {
             RGBColor[
             0.1935081925729178, 0.3207197578951424, 0.9343313773460864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 187}], {
             RGBColor[
             0.22908739425404853`, 0.35811575471368917`, 0.9363575602471148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 208}], {
             RGBColor[
             0.2681228139523549, 0.39914445580516655`, 0.9385805696512048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 323}], {
             RGBColor[
             0.3312247462121247, 0.45512489933743366`, 0.9425528644360341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 377}], {
             RGBColor[
             0.2482608696505907, 0.3782682930240088, 0.9374494613063329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 388}], {
             RGBColor[
             0.2563045573313864, 0.38672271877578024`, 0.9379075374201846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 395}], {
             RGBColor[
             0.3402542515552627, 0.4629458030295253, 0.9431282165320207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 270}], {
             RGBColor[
             0.198314467229445, 0.32577145729456636`, 0.9346050875775294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 291}], {
             RGBColor[
             0.1920722404266596, 0.31921048114480044`, 0.9342496019956579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 357}], {
             RGBColor[
             0.18734376764879906`, 0.31424055645277915`, 0.9339803224661072]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 368}], {
             RGBColor[
             0.18625851527578347`, 0.31309988739976513`, 0.933918518948951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 185}], {
             RGBColor[
             0.20305130848505737`, 0.330750177787297, 0.9348748436795078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 190}], {
             RGBColor[
             0.21285282401079259`, 0.34105219205682236`, 0.9354330254886557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 226}], {
             RGBColor[
             0.20272879549405032`, 0.3304111961852439, 0.9348564770417853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 252}], {
             RGBColor[
             0.20974713734389644`, 0.3377879184580067, 0.9352561612274277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 274}], {
             RGBColor[
             0.20834640202144852`, 0.33631565682236503`, 0.9351763914230165]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 288}], {
             RGBColor[
             0.21364346222149755`, 0.3418832029456312, 0.9354780511651108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 318}], {
             RGBColor[
             0.2135047362690546, 0.34173739317388024`, 0.935470150927346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 190}], {
             RGBColor[
             0.20235115482293997`, 0.33001427189610544`, 0.9348349709642347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 226}], {
             RGBColor[
             0.1922271263061977, 0.3193732760245269, 0.9342584225173644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 252}], {
             RGBColor[
             0.1992454681560438, 0.3267499982972898, 0.9346581067030068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 274}], {
             RGBColor[
             0.19784473283359588`, 0.32527773666164805`, 0.9345783368985956]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 288}], {
             RGBColor[
             0.2031417930336449, 0.3308452827849142, 0.93487999664069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 318}], {
             RGBColor[
             0.20300306708120197`, 0.33069947301316327`, 0.9348720964029251]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 357}], {
             RGBColor[
             0.18927662196416456`, 0.31627210888827, 0.9340903956599655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 272}], {
             RGBColor[
             0.20161622991530592`, 0.3292418192212516, 0.9347931180779689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 306}], {
             RGBColor[
             0.21444053080855624`, 0.3427209725676972, 0.9355234430419865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 308}], {
             RGBColor[
             0.20971443584181115`, 0.3377535471059201, 0.9352542989252615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 342}], {
             RGBColor[
             0.19648760861210862`, 0.32385131305821946`, 0.9345010506818672]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 348}], {
             RGBColor[
             0.2038426026857459, 0.33158187816317064`, 0.9349199067136222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 374}], {
             RGBColor[
             0.19510883243877694`, 0.3224021318805894, 0.9344225314185126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 378}], {
             RGBColor[
             0.22340907061728948`, 0.35214747654494266`, 0.9360341881163283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 208}], {
             RGBColor[
             0.25538258130493185`, 0.38575366351532014`, 0.9378550322494192]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 302}], {
             RGBColor[
             0.20552429842574232`, 0.33334944701157526`, 0.9350156767981692]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 377}], {
             RGBColor[
             0.2355206370031677, 0.36487750073416236`, 0.9367239239045473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 388}], {
             RGBColor[
             0.2435643246839634, 0.37333192648593383`, 0.937182000018399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 201}], {
             RGBColor[
             0.47076164268683474`, 0.5730017553920743, 0.9531670568538995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 264}], {
             RGBColor[
             0.26789407428573686`, 0.39890403591261847`, 0.9385675432655809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 273}], {
             RGBColor[
             0.39992754574806544`, 0.5158532142548906, 0.9473461281045827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 281}], {
             RGBColor[
             0.3372802138863956, 0.4635116716468679, 0.9428236756739168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 293}], {
             RGBColor[
             0.29496948602480166`, 0.4268642457721712, 0.9401276735084836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 394}], {
             RGBColor[
             0.3167171676025393, 0.44570099448454903`, 0.9415134165478973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 207}], {
             RGBColor[
             0.2123454769342431, 0.3405189381117063, 0.935404132823199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 241}], {
             RGBColor[
             0.2570425573000169, 0.3874984035347115, 0.937949565426625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 263}], {
             RGBColor[
             0.2675028819703037, 0.39849286798607286`, 0.9385452654419342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 280}], {
             RGBColor[
             0.2210513429116578, 0.3496693552377532, 0.9358999190114381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 291}], {
             RGBColor[
             0.21431712870363867`, 0.34259126913128346`, 0.9355164154746687]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 336}], {
             RGBColor[
             0.23398737474331802`, 0.3632659448846183, 0.936636606887107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 359}], {
             RGBColor[
             0.2794316818374808, 0.4094642361682714, 0.9392819522659938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 226}], {
             RGBColor[
             0.20202864183193292`, 0.3296752902940524, 0.9348166043265123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 252}], {
             RGBColor[
             0.20904698368177904`, 0.3370520125668152, 0.9352162885121547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 274}], {
             RGBColor[
             0.20764624835933113`, 0.33557975093117354`, 0.9351365187077434]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 288}], {
             RGBColor[
             0.21294330855938015`, 0.3411472970544397, 0.9354381784498378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 318}], {
             RGBColor[
             0.21280458260693721`, 0.34100148728268875`, 0.9354302782120729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 225}], {
             RGBColor[
             0.19624559498378968`, 0.32359694139030604`, 0.9344872683637615]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 235}], {
             RGBColor[
             0.18862912627732129`, 0.3155915498678, 0.9340535217384839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 261}], {
             RGBColor[
             0.18660634868245718`, 0.3134654823640909, 0.9339383275468877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 322}], {
             RGBColor[
             0.18956017104754852`, 0.31657013695295677`, 0.934106543360791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 327}], {
             RGBColor[
             0.1848862258869851, 0.3116575242439654, 0.9338403690983792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 335}], {
             RGBColor[
             0.19113672012064215`, 0.3182271899877628, 0.9341963254982084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 349}], {
             RGBColor[
             0.1912119313089536, 0.3183062417153429, 0.9342006086641177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 355}], {
             RGBColor[
             0.19607480659810572`, 0.32341743196834305`, 0.9344775422178556]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 208}], {
             RGBColor[
             0.27634222217301546`, 0.40778357498566165`, 0.9390486527898467]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 221}], {
             RGBColor[
             0.3140891047086496, 0.4418027488287358, 0.9414053462268441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[
             0.233374248060821, 0.36262150986683694`, 0.9366016902295785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 322}], {
             RGBColor[
             0.2266888241245798, 0.3555947054294877, 0.936220965226608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 335}], {
             RGBColor[
             0.22826537319767345`, 0.3572517584642937, 0.9363107473640253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 349}], {
             RGBColor[
             0.22834058438598487`, 0.3573308101918738, 0.9363150305299347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 351}], {
             RGBColor[
             0.2839106330866923, 0.41566367352388345`, 0.9394824007008676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 355}], {
             RGBColor[
             0.233203459675137, 0.36244200044487396`, 0.9365919640836726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 399}], {
             RGBColor[
             0.3088211273745378, 0.43723989163816773`, 0.941069675369404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 195}], {
             RGBColor[
             0.6312732042379722, 0.7079049527832757, 0.9663404032043308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 242}], {
             RGBColor[
             0.5891633460741419, 0.6714315101447773, 0.963657200278417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 253}], {
             RGBColor[
             0.8294376428224145, 0.4209653077854606, 0.4426395583706675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 255}], {
             RGBColor[
             0.606058461723811, 0.6860652101473173, 0.9647337421078497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 283}], {
             RGBColor[
             0.884925338733304, 0.8207038820590313, 0.6242425057097936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 312}], {
             RGBColor[
             0.6928723364666782, 0.7586931681891012, 0.9709743993376487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 332}], {
             RGBColor[
             0.8245126571232608, 0.38310970955927065`, 0.4379233865031822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 356}], {
             RGBColor[
             0.8916558476180196, 0.9161964476590825, 0.9808695463369558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 360}], {
             RGBColor[
             0.7503418220523833, 0.8050370370474327, 0.9757122305140027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 364}], {
             RGBColor[
             0.8796332391054209, 0.7997224705221349, 0.619984358127655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 380}], {
             RGBColor[
             0.7791551569135652, 0.8275462332304435, 0.978584074457042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 389}], {
             RGBColor[
             0.9155257058475293, 0.9306524378746825, 0.7386464272151838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 221}], {
             RGBColor[
             0.41267584437400284`, 0.5318031923554098, 0.9475322370266106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 233}], {
             RGBColor[
             0.7128854689421396, 0.7730895863286765, 0.9426895386250231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 256}], {
             RGBColor[
             0.7238719368935342, 0.7799355863354847, 0.863740011258672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 316}], {
             RGBColor[
             0.5837905900380065, 0.6719175511327584, 0.9611081443956637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 399}], {
             RGBColor[
             0.40740786703989107`, 0.5272403351648417, 0.9471965661691704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 241}], {
             RGBColor[
             0.35276484059541724`, 0.47739540900316435`, 0.9437930699766406]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 242}], {
             RGBColor[
             0.3825084156474021, 0.5057312970269716, 0.9455940758995094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.3994035312970712, 0.5203649970295117, 0.9466706177289421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 263}], {
             RGBColor[
             0.3632251652657039, 0.4883898734545258, 0.9443887699919498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 312}], {
             RGBColor[
             0.48621740603993846`, 0.5929929550712956, 0.9529112749587412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 356}], {
             RGBColor[
             0.6850009171912799, 0.7504962345412768, 0.9628064219580481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 359}], {
             RGBColor[
             0.375153965132881, 0.49936124163672424`, 0.9451254568160093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 360}], {
             RGBColor[
             0.5436868916256435, 0.6393368239296271, 0.957649106135095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 380}], {
             RGBColor[
             0.5725002264868254, 0.6618460201126379, 0.9605209500781344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 389}], {
             RGBColor[
             0.7088707754207897, 0.764952224756877, 0.7205833028362763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 206}], {
             RGBColor[
             0.6365065028818196, 0.7122246861355508, 0.9667719599708235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 214}], {
             RGBColor[
             0.8615229927273951, 0.7108190806524803, 0.6028379622201453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 286}], {
             RGBColor[
             0.5826840049020053, 0.6656063435828412, 0.963342437992916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 332}], {
             RGBColor[
             0.8265781466798748, 0.38475667486549425`, 0.4381203947409763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 334}], {
             RGBColor[
             0.9021680954325457, 0.8779962725880234, 0.6424622562871629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 366}], {
             RGBColor[
             0.9187123308959824, 0.9333119446325909, 0.748562723255582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 386}], {
             RGBColor[
             0.5930257483480736, 0.6745638419646864, 0.9640014047404548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 217}], {
             RGBColor[
             0.19977926755688577`, 0.3273110553124115, 0.9346885057891993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 231}], {
             RGBColor[
             0.19125913163260555`, 0.3183558522481745, 0.9342032966527232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 254}], {
             RGBColor[
             0.18919463052287389`, 0.31618593068491585`, 0.9340857263686796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 314}], {
             RGBColor[
             0.18703267242257346`, 0.3139135756454394, 0.9339626060531978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 369}], {
             RGBColor[
             0.18585850163943218`, 0.31267944770563044`, 0.933895738764128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 392}], {
             RGBColor[
             0.19718685275102665`, 0.3245862629828614, 0.9345408716011396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 203}], {
             RGBColor[
             0.5694035624452959, 0.6546305646490294, 0.9622535793690412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 206}], {
             RGBColor[
             0.6288429856334741, 0.7061140055023541, 0.9660410068543737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 214}], {
             RGBColor[
             0.8538594754790496, 0.7047084000192836, 0.6021070091036955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 266}], {
             RGBColor[
             0.74350964112616, 0.79962588641691, 0.9750508465456946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 310}], {
             RGBColor[
             0.8272769818270227, 0.4253245421128263, 0.4431946931706203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 384}], {
             RGBColor[
             0.8811911535814985, 0.820358675063078, 0.6244757857174054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 215}], {
             RGBColor[
             0.8474033618771311, 0.8799586173228249, 0.9038397390676208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 222}], {
             RGBColor[
             0.9699116219534045, 0.9763258350817114, 0.9020107810264453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 223}], {
             RGBColor[
             0.9023894680156853, 0.6322806802095792, 0.4149397481928467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 224}], {
             RGBColor[
             0.7432416506659434, 0.7963714338733744, 0.8949724605475597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 247}], {
             RGBColor[
             0.8744710807180455, 0.41938916470165666`, 0.38827169323511157`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 259}], {
             RGBColor[
             0.9420801867046171, 0.9545306309034027, 0.913114429015637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 271}], {
             RGBColor[
             0.8762470859874794, 0.4330403194529975, 0.3899723978868326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 287}], {
             RGBColor[
             0.8744579174591663, 0.41928798612573526`, 0.3882590880835432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 292}], {
             RGBColor[
             0.8759065071929455, 0.430422481595631, 0.3896462592485583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 345}], {
             RGBColor[
             0.9084097409587222, 0.9276827314255283, 0.9099029118424318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 350}], {
             RGBColor[
             0.6686405102956781, 0.7329620420673324, 0.8898856192140527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 353}], {
             RGBColor[
             0.9909977762454061, 0.988800838647677, 0.6720451430779383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 393}], {
             RGBColor[
             0.8553537557812887, 0.8861695254659845, 0.9046321600313321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 400}], {
             RGBColor[
             0.8776553963318527, 0.44386520988537914`, 0.3913209974630636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 234}], {
             RGBColor[
             0.22049169370930496`, 0.34908112844227146`, 0.9358680478172909]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 296}], {
             RGBColor[
             0.1865617818736295, 0.3134186398223141, 0.9339357895330556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 298}], {
             RGBColor[
             0.19975642982426225`, 0.3272870514074283, 0.9346872052141117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 320}], {
             RGBColor[
             0.18887757795522245`, 0.31585268833402036`, 0.934067670693989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 330}], {
             RGBColor[
             0.1913737687250167, 0.31847634310071005`, 0.9342098250655455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 347}], {
             RGBColor[
             0.1891857716327594, 0.31617661942971953`, 0.9340852218679931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 367}], {
             RGBColor[
             0.19007010120853718`, 0.31710610588359545`, 0.9341355831290852]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 398}], {
             RGBColor[
             0.18742715801975252`, 0.3143282050199061, 0.933985071424368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 273}], {
             RGBColor[
             0.5948799673171399, 0.6816316125645953, 0.9614948857902279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 281}], {
             RGBColor[
             0.5322326354554701, 0.6292900699565726, 0.956972433359562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 293}], {
             RGBColor[
             0.4899219075938762, 0.5926426440818758, 0.9542764311941287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 303}], {
             RGBColor[
             0.7798220611835203, 0.6750115727481525, 0.6002603969131654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 394}], {
             RGBColor[
             0.5116695891716139, 0.6114793927942537, 0.9556621742335425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 212}], {
             RGBColor[
             0.45268550871471924`, 0.56313574583105, 0.9509994425842794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 234}], {
             RGBColor[
             0.28726387007128157`, 0.41752052418196, 0.9397344221047603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 239}], {
             RGBColor[
             0.4173644057485659, 0.5344604832455712, 0.9482188359733204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 269}], {
             RGBColor[
             0.34049741903328384`, 0.46934348329390774`, 0.9429171723441234]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 289}], {
             RGBColor[
             0.4009029468034172, 0.5210963292936249, 0.9469229296248474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 309}], {
             RGBColor[
             0.5124790971855998, 0.6108362268976354, 0.9562827357512269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 362}], {
             RGBColor[
             0.5594312028417849, 0.6475155686854668, 0.9609624828506617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 365}], {
             RGBColor[
             0.31680424057691503`, 0.4485693265510483, 0.9414167025039941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 206}], {
             RGBColor[
             0.36944897924090714`, 0.4944198695980247, 0.9447619401596937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 211}], {
             RGBColor[
             0.27124930343896736`, 0.4023137700960795, 0.9387628961154517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 216}], {
             RGBColor[
             0.26291297700315486`, 0.3935517624584167, 0.938288154657422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 266}], {
             RGBColor[
             0.4841156347335931, 0.5879317505125805, 0.9537717798510146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 329}], {
             RGBColor[
             0.28617424693522586`, 0.4180008320067203, 0.9396128495680883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 341}], {
             RGBColor[
             0.2796765309207728, 0.4111713204965401, 0.9392428142535747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 358}], {
             RGBColor[
             0.29380332632948314`, 0.42601947816165614`, 0.9400473143533797]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 229}], {
             RGBColor[
             0.18893129430891603`, 0.3159091476275659, 0.9340707297608657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 237}], {
             RGBColor[
             0.18108298927677668`, 0.3076600814275077, 0.9336237803998122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 307}], {
             RGBColor[
             0.17948540198595286`, 0.30598091589196724`, 0.9335328001670183]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 343}], {
             RGBColor[
             0.1903303530090651, 0.3173796470268675, 0.9341504040841173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 232}], {
             RGBColor[
             0.18775686622597437`, 0.3146747492493529, 0.9340038478189527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 277}], {
             RGBColor[
             0.18513416241600078`, 0.31191812125604473`, 0.9338544887169173]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 373}], {
             RGBColor[
             0.19156946915989134`, 0.31868203666588757`, 0.9342209699157987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 390}], {
             RGBColor[
             0.19906834334491935`, 0.32656382889043634`, 0.9346480197070459]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 266}], {
             RGBColor[
             0.5435550579217713, 0.6394151913659053, 0.9575592073363473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 286}], {
             RGBColor[
             0.375065904449271, 0.49928496789863985`, 0.9451198456671187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 386}], {
             RGBColor[
             0.3854076478953393, 0.5082424662804851, 0.9457788124146576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 231}], {
             RGBColor[
             0.1913619669815575, 0.3184639387200607, 0.9342091529737147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 280}], {
             RGBColor[
             0.200223112625469, 0.32777756462089525`, 0.9347137821092452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 291}], {
             RGBColor[
             0.19348889841744987`, 0.3206994785144255, 0.9343302785724756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 368}], {
             RGBColor[
             0.18767517326657374`, 0.3145888847693901, 0.9339991955257688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 372}], {
             RGBColor[
             0.18573202091371066`, 0.31254650844355597`, 0.9338885358739095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 387}], {
             RGBColor[
             0.18852965084716983`, 0.3154869948836043, 0.9340478567598975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 392}], {
             RGBColor[
             0.1972896880999786, 0.3246943494547476, 0.9345467279221311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 221}], {
             RGBColor[
             0.3321648835388723, 0.4608015384498717, 0.9424347350905069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 225}], {
             RGBColor[
             0.2514500268910438, 0.38162029948797277`, 0.9376310790932412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 323}], {
             RGBColor[
             0.3575199332630081, 0.48276280813906464`, 0.9440503364383386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 351}], {
             RGBColor[
             0.301986411916915, 0.43466246314501933`, 0.9405117895645303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 388}], {
             RGBColor[
             0.28259974438226976`, 0.4143606275774112, 0.9394050094224892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 395}], {
             RGBColor[
             0.366549438606146, 0.4905837118311563, 0.9446256885343254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 286}], {
             RGBColor[
             0.29314447532730914`, 0.4242883377578022, 0.9400478236897936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 290}], {
             RGBColor[
             0.2612876379800373, 0.3919602524830736, 0.938191316491318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 304}], {
             RGBColor[
             0.2736580263748165, 0.40496231501391133`, 0.9388957918100511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 338}], {
             RGBColor[
             0.23759083072429804`, 0.3670534055929334, 0.9368418183743885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 386}], {
             RGBColor[
             0.30348621877337745`, 0.4332458361396474, 0.9407067904373323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 230}], {
             RGBColor[
             0.2334030426063412, 0.36265177475985827`, 0.9366033300363481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 258}], {
             RGBColor[
             0.24166666616429894`, 0.371337367063267, 0.9370739311730383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 264}], {
             RGBColor[
             0.2528298194491141, 0.3830705489504057, 0.9377096562382032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 279}], {
             RGBColor[
             0.2223588131160111, 0.3510435893209275, 0.9359743775053473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 328}], {
             RGBColor[
             0.2385161810587667, 0.36802600746505976`, 0.9368945157070033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 394}], {
             RGBColor[
             0.30165291276591666`, 0.42986750752233627`, 0.9406555295205197]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 216}], {
             RGBColor[
             0.22415272438939332`, 0.35292910380979625`, 0.9360765380985124]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 238}], {
             RGBColor[
             0.21668562529693003`, 0.34508070922219014`, 0.9356512978517798]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 341}], {
             RGBColor[
             0.24091627830701134`, 0.3705486618479197, 0.9370311976946651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 358}], {
             RGBColor[
             0.2550430737157216, 0.3853968195130357, 0.9378356977944702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 239}], {
             RGBColor[
             0.542458414688152, 0.6394312043737607, 0.9571234599763494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 289}], {
             RGBColor[
             0.5259969557430033, 0.6260670504218144, 0.9558275536278764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 309}], {
             RGBColor[
             0.6375731061251859, 0.7158069480258249, 0.965187359754256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 362}], {
             RGBColor[
             0.6845252117813709, 0.7524862898136562, 0.9698671068536907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 385}], {
             RGBColor[
             0.7860985506073723, 0.8292872838004639, 0.7968353358505167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 215}], {
             RGBColor[
             0.5157421665105038, 0.6132928535993672, 0.9566471217151071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 227}], {
             RGBColor[
             0.29970260204538113`, 0.43079580390036054`, 0.94043541584355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 259}], {
             RGBColor[
             0.6104189913379899, 0.6878648671799451, 0.9659218116631232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 306}], {
             RGBColor[
             0.2738566580723743, 0.4036300780572341, 0.9389635275699348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 308}], {
             RGBColor[
             0.2691305631056292, 0.398662652595457, 0.9386943834532097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 345}], {
             RGBColor[
             0.5767485455920949, 0.6610169677020706, 0.962710294489918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 350}], {
             RGBColor[
             0.33697931492905076`, 0.46629627834387477`, 0.942693001861539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 378}], {
             RGBColor[
             0.2828251978811075, 0.4130565820344796, 0.9394742726442766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 257}], {
             RGBColor[
             0.9241708234933428, 0.7599031818045514, 0.5786645333196092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 310}], {
             RGBColor[
             0.8439849195878139, 0.31758034175677613`, 0.18891093519726984`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 332}], {
             RGBColor[
             0.8381770729417689, 0.2729386874206463, 0.1833493346899926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 389}], {
             RGBColor[
             0.9360223295752915, 0.7653959046667461, 0.35678534949539953`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 224}], {
             RGBColor[
             0.6019092601655756, 0.6867200928189938, 0.9624709353645509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 227}], {
             RGBColor[
             0.4900314069116405, 0.5878102265694376, 0.9551265080130549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 259}], {
             RGBColor[
             0.8007477962042493, 0.8448792898490222, 0.9806129038326282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 345}], {
             RGBColor[
             0.7670773504583543, 0.8180313903711476, 0.977401386659423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 350}], {
             RGBColor[
             0.5273081197953102, 0.6233107010129518, 0.9573840940310441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 353}], {
             RGBColor[
             0.8496653857450382, 0.8791494975932964, 0.7395436178949295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 393}], {
             RGBColor[
             0.7140213652809209, 0.7765181844116039, 0.9721306348483233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 400}], {
             RGBColor[
             0.7834338026649409, 0.37076431584912545`, 0.43631998067439115`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 229}], {
             RGBColor[
             0.2068690748506942, 0.33476289229794964`, 0.9350922598261517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 294}], {
             RGBColor[
             0.21277466253925434`, 0.3409700393945122, 0.9354285743084811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 329}], {
             RGBColor[
             0.23907766788565177`, 0.368616165720437, 0.936926491551149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 340}], {
             RGBColor[
             0.2436041993290528, 0.3733738372661213, 0.9371842708204476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 341}], {
             RGBColor[
             0.2325799518711988, 0.3617866542102568, 0.9365564562366354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 343}], {
             RGBColor[
             0.20826813355084325`, 0.33623339169725125`, 0.9351719341494034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 358}], {
             RGBColor[
             0.24670674727990904`, 0.37663481187537284`, 0.9373609563364405]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 231}], {
             RGBColor[
             0.19972682323934088`, 0.32725593300951006`, 0.9346855191628995]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 254}], {
             RGBColor[
             0.1976623221296092, 0.32508601144625143`, 0.934567948878856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 314}], {
             RGBColor[
             0.1955003640293088, 0.322813656406775, 0.9344448285633742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 331}], {
             RGBColor[
             0.22460790707912992`, 0.3534075296769589, 0.9361024600793104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 392}], {
             RGBColor[
             0.20565454435776198`, 0.333486343744197, 0.935023094111316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 222}], {
             RGBColor[
             0.7556819189936763, 0.8084691579297268, 0.9631032253183853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 276}], {
             RGBColor[
             0.46966080217049366`, 0.5783141439540027, 0.951949779691809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 282}], {
             RGBColor[
             0.4376499441056336, 0.5505879476107286, 0.9499100761220066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 305}], {
             RGBColor[
             0.42916789405553485`, 0.5422531768418173, 0.9494057845729981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 339}], {
             RGBColor[
             0.47111694262023773`, 0.5795753796238241, 0.9520425636736524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 361}], {
             RGBColor[
             0.4849252020484565, 0.5915353999172487, 0.952922413754254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 382}], {
             RGBColor[
             0.44118615700326724`, 0.5536508374874307, 0.9501354004808935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 384}], {
             RGBColor[
             0.7469305423915883, 0.7141446268230167, 0.6119725391027997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 248}], {
             RGBColor[
             0.1809198934930053, 0.30748865741789405`, 0.933614492336205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 251}], {
             RGBColor[
             0.1819264333571092, 0.30854659463338063`, 0.9336718132924233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 260}], {
             RGBColor[
             0.1839290162486566, 0.31065143622348573`, 0.9337858574255411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 352}], {
             RGBColor[
             0.1830449444132805, 0.30972222067111355`, 0.9337355108423835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 396}], {
             RGBColor[
             0.18205118127193512`, 0.30867771260133725`, 0.9336789175016247]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 256}], {
             RGBColor[
             0.6811078585940378, 0.7429531062730206, 0.8609992027595657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 316}], {
             RGBColor[
             0.5410265117385101, 0.6349350710702945, 0.9583673358965574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 351}], {
             RGBColor[
             0.33973329445254913`, 0.4686816369880935, 0.9428684830015278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 399}], {
             RGBColor[
             0.36464378874039466`, 0.49025785510237774`, 0.9444557576700642]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 223}], {
             RGBColor[
             0.8898400477329558, 0.6234245980125831, 0.45871942604339044`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 224}], {
             RGBColor[
             0.724417520241849, 0.7830873105778803, 0.9606419773233753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 247}], {
             RGBColor[
             0.8619216604353159, 0.4105330825046606, 0.4320513710856554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 259}], {
             RGBColor[
             0.9232560562805229, 0.9412465076079086, 0.9787839457914527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 292}], {
             RGBColor[
             0.863357086910216, 0.42156639939863494`, 0.43342593709910204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 363}], {
             RGBColor[
             0.6628066494410058, 0.7309294373629389, 0.9563828644799877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 383}], {
             RGBColor[
             0.6547025238599551, 0.723910051109828, 0.9558664767641599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 393}], {
             RGBColor[
             0.8365296253571944, 0.8728854021704904, 0.9703016768071477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 247}], {
             RGBColor[
             0.8452571321859585, 0.34717028337180467`, 0.19090496268508764`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 292}], {
             RGBColor[
             0.8459748454234086, 0.3526869418187919, 0.19159224569181096`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 319}], {
             RGBColor[
             0.8502923449808009, 0.3858731353572784, 0.1957266881438881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 385}], {
             RGBColor[
             0.9042834117433322, 0.6325667276310734, 0.3474148618138784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 393}], {
             RGBColor[
             0.8134681369515452, 0.5633203916020985, 0.4604670120466483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 400}], {
             RGBColor[
             0.8468492899928622, 0.3594083059636659, 0.19242961479906362`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 227}], {
             RGBColor[
             0.3858696957004528, 0.504223043119987, 0.9462592294929938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 259}], {
             RGBColor[
             0.6965860849930616, 0.7612921063995717, 0.9717456253125671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 363}], {
             RGBColor[
             0.4361366781535445, 0.5509750361546019, 0.9493445440011021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 383}], {
             RGBColor[
             0.42803255257249384`, 0.5439556499014909, 0.9488281562852744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 393}], {
             RGBColor[
             0.6098596540697332, 0.6929310009621534, 0.9632633563282622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 235}], {
             RGBColor[
             0.20086558407238086`, 0.32845284284664206`, 0.9347503699076954]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 261}], {
             RGBColor[
             0.19884280647751676`, 0.32632677534293286`, 0.9346351757160992]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 322}], {
             RGBColor[
             0.2017966288426081, 0.3294314299317988, 0.9348033915300026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 327}], {
             RGBColor[
             0.19712268368204472`, 0.3245188172228074, 0.9345372172675908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 335}], {
             RGBColor[
             0.20337317791570175`, 0.3310884829666048, 0.93489317366742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 349}], {
             RGBColor[
             0.2034483891040132, 0.3311675346941849, 0.9348974568333293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 355}], {
             RGBColor[
             0.2083112643931653, 0.336278724947185, 0.9351743903870672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 252}], {
             RGBColor[
             0.19892295516503677`, 0.32641101669523676`, 0.9346397400652842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 274}], {
             RGBColor[
             0.1975222198425889, 0.324938755059595, 0.9345599702608729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 288}], {
             RGBColor[
             0.20281928004263788`, 0.3305063011828612, 0.9348616300029674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 315}], {
             RGBColor[
             0.186507225222572, 0.3133612973229612, 0.9339326826124872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 318}], {
             RGBColor[
             0.20268055409019498`, 0.33036049141111024`, 0.9348537297652024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 322}], {
             RGBColor[
             0.1935079091107788, 0.32071945995846174`, 0.9343313612033369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 243}], {
             RGBColor[
             0.2526928974888643, 0.38292663528882953`, 0.9377018587351249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 306}], {
             RGBColor[
             0.248145898473511, 0.3781474510273044, 0.9374429138678827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 311}], {
             RGBColor[
             0.23829401063491945`, 0.3677924922631779, 0.9368818634300369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 346}], {
             RGBColor[
             0.23870901568862182`, 0.3682286888874592, 0.9369054973539003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 350}], {
             RGBColor[
             0.3112685553301875, 0.44081365131394507`, 0.9411723881594869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 363}], {
             RGBColor[
             0.3242588248996095, 0.45206516990504564`, 0.9420001166496061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 383}], {
             RGBColor[
             0.3161546993185588, 0.44504578365193476`, 0.9414837289337784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 276}], {
             RGBColor[
             0.3015266164865197, 0.4277543234766833, 0.9407208506945814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 282}], {
             RGBColor[
             0.26951575842165965`, 0.40002812713340913`, 0.938681147124779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 301}], {
             RGBColor[
             0.2369380396545014, 0.36636728078923275`, 0.9368046428886814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 305}], {
             RGBColor[
             0.26103370837156087`, 0.39169335636449776`, 0.9381768555757705]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 382}], {
             RGBColor[
             0.27305197131929326`, 0.4030910170101112, 0.9389064714836659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 294}], {
             RGBColor[
             0.20382733943636777`, 0.33156583552032837`, 0.9349190374941501]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 307}], {
             RGBColor[
             0.18847585942484443`, 0.31543045668816716`, 0.9340447934179733]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[
             0.2301303447827652, 0.3592119618462532, 0.9364169547368181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 340}], {
             RGBColor[
             0.23465687622616624`, 0.36396963339193744`, 0.9366747340061166]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 343}], {
             RGBColor[
             0.1993208104479567, 0.32682918782306747`, 0.9346623973350723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 258}], {
             RGBColor[
             0.22938899732612533`, 0.3584327586651811, 0.9363747360958877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 264}], {
             RGBColor[
             0.2405521506109405, 0.3701659405523198, 0.9370104611610526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 279}], {
             RGBColor[
             0.2100811442778375, 0.33813898092284156`, 0.9352751824281966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 299}], {
             RGBColor[
             0.20475753633962784`, 0.33254353144354476`, 0.9349720108316877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 300}], {
             RGBColor[
             0.2086431877242838, 0.3366275974133453, 0.9351932929297377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 328}], {
             RGBColor[
             0.2262385122205931, 0.35512139906697393`, 0.9361953206298528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 331}], {
             RGBColor[
             0.21608777115484973`, 0.34445232661272185`, 0.9356172509428343]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 369}], {
             RGBColor[
             0.1858060573218873, 0.312624325402729, 0.9338927521378282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 372}], {
             RGBColor[
             0.18557674124721385`, 0.3123832996687683, 0.9338796929266182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 392}], {
             RGBColor[
             0.1971344084334818, 0.32453114067996, 0.9345378849748398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 277}], {
             RGBColor[
             0.18773724237763328`, 0.31465412334052256`, 0.9340027302698206]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 373}], {
             RGBColor[
             0.19417254912152382`, 0.3214180387503654, 0.934369211468702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 390}], {
             RGBColor[
             0.20167142330655186`, 0.3292998309749142, 0.9347962612599492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 256}], {
             RGBColor[
             0.9813174831621745, 0.9842395002462874, 0.8561565043579783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 257}], {
             RGBColor[
             0.9698756400386146, 0.9770538821816868, 0.9358768631099392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 310}], {
             RGBColor[
             0.8744547972846617, 0.4623474753415331, 0.4270524883908231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 316}], {
             RGBColor[
             0.8412361363066468, 0.8762214650435611, 0.9535246374949702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 389}], {
             RGBColor[
             0.9817271461205633, 0.9825466050438816, 0.7139976792857294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 298}], {
             RGBColor[
             0.22620097648238727`, 0.3550819466262163, 0.936193183025091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 365}], {
             RGBColor[
             0.27647661087306347`, 0.4079248260301478, 0.9390563060275041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 261}], {
             RGBColor[
             0.19122633777104836`, 0.31832138382042696`, 0.9342014290908216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 322}], {
             RGBColor[
             0.1941801601361397, 0.32142603840929285`, 0.934369644904725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 327}], {
             RGBColor[
             0.1895062149755763, 0.31651342570030144`, 0.934103470642313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 335}], {
             RGBColor[
             0.19575670920923333`, 0.32308309144409886`, 0.9344594270421422]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 349}], {
             RGBColor[
             0.19583192039754477`, 0.3231621431716789, 0.9344637102080516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 355}], {
             RGBColor[
             0.2006947956866969, 0.3282733334246791, 0.9347406437617896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 262}], {
             RGBColor[
             0.4369845815472029, 0.5513866495573997, 0.9494877616771007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 284}], {
             RGBColor[
             0.6247504035752902, 0.7047458827568778, 0.9646230139836673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 334}], {
             RGBColor[
             0.7349237676396162, 0.7451154652166593, 0.6272347577119612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 366}], {
             RGBColor[
             0.7514680031030527, 0.8004311372612268, 0.7333352246803804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 376}], {
             RGBColor[
             0.397907468442853, 0.5154535439144465, 0.9470741986312354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 397}], {
             RGBColor[
             0.4369077612514729, 0.5513201116783387, 0.9494828667557864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 307}], {
             RGBColor[
             0.1806275543927051, 0.307181390488109, 0.9335978440569198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 324}], {
             RGBColor[
             0.18395646599811732`, 0.31068028765058353`, 0.9337874206481647]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 269}], {
             RGBColor[
             0.4302703250067166, 0.5456389418366184, 0.9490411897361934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 309}], {
             RGBColor[
             0.6022520031590326, 0.6871316854403461, 0.9624067531432969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 323}], {
             RGBColor[
             0.4638795886223883, 0.5747495967298069, 0.9511827422942791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 362}], {
             RGBColor[
             0.6492041088152176, 0.7238110272281775, 0.9670865002427318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 365}], {
             RGBColor[
             0.4065771465503478, 0.524864785093759, 0.9475407198960643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 377}], {
             RGBColor[
             0.3809157120608543, 0.4978929904163819, 0.9460793391645779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 385}], {
             RGBColor[
             0.750777447641219, 0.8006120212149852, 0.7940547292395577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 388}], {
             RGBColor[
             0.38895939974165, 0.5063474161681534, 0.9465374152784297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 272}], {
             RGBColor[
             0.18799208314490007`, 0.3149219771447579, 0.9340172430745133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 342}], {
             RGBColor[
             0.18286346184170274`, 0.30953147098172573`, 0.9337251756784115]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 374}], {
             RGBColor[
             0.18148468566837106`, 0.3080822898040957, 0.933646656415057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 242}], {
             RGBColor[
             0.31065498243158685`, 0.4409219663646659, 0.9411098670507269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 255}], {
             RGBColor[
             0.32755009808125596`, 0.4555556663672059, 0.9421864088801596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 312}], {
             RGBColor[
             0.41436397282412324`, 0.5281836244089898, 0.9484270661099586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 331}], {
             RGBColor[
             0.26094013118712034`, 0.3915950008105146, 0.9381715264935517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 359}], {
             RGBColor[
             0.3033005319170658, 0.43455191097441853`, 0.9406412479672268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 360}], {
             RGBColor[
             0.4718334584098283, 0.5745274932673213, 0.9531648972863125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 380}], {
             RGBColor[
             0.5006467932710101, 0.5970366894503322, 0.9560367412293518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 392}], {
             RGBColor[
             0.24198676846575243`, 0.37167381487775275`, 0.9370921605255572]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 255}], {
             RGBColor[
             0.3572936731332409, 0.48389155439101317`, 0.9439874148030284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 312}], {
             RGBColor[
             0.4441075478761082, 0.5565195124327971, 0.9502280720328274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 331}], {
             RGBColor[
             0.2906837062391053, 0.4199308888343219, 0.9399725324164205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 380}], {
             RGBColor[
             0.5303903683229951, 0.6253725774741394, 0.9578377471522206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 267}], {
             RGBColor[
             0.2144789920516021, 0.342761397772722, 0.9355256333528797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 275}], {
             RGBColor[
             0.21276908993785693`, 0.3409641822371201, 0.9354282569570754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 311}], {
             RGBColor[
             0.21699506567726595`, 0.34540595068157653`, 0.9356689200236639]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 326}], {
             RGBColor[
             0.23648276332684243`, 0.36588875650267677`, 0.9367787155753422]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 344}], {
             RGBColor[
             0.2114782278514492, 0.3396074043389222, 0.9353547442709138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 346}], {
             RGBColor[
             0.21741007073096835`, 0.3458421473058579, 0.9356925539475274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 363}], {
             RGBColor[
             0.302959879941956, 0.42967862832344433`, 0.9407871732432331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 383}], {
             RGBColor[
             0.29485575436090533`, 0.42265924207033345`, 0.9402707855274055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 302}], {
             RGBColor[
             0.18853043849765405`, 0.3154878227542032, 0.9340479016154273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 352}], {
             RGBColor[
             0.1906398234149592, 0.3177049200450192, 0.9341680279659126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 396}], {
             RGBColor[
             0.1896460602736138, 0.31666041197524286`, 0.9341114346251538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 248}], {
             RGBColor[
             0.19980719089443424`, 0.32734040451061686`, 0.9346900959819637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 251}], {
             RGBColor[
             0.20081373075853814`, 0.3283983417261034, 0.9347474169381822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 260}], {
             RGBColor[
             0.20281631365008554`, 0.33050318331620854`, 0.9348614610713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 326}], {
             RGBColor[
             0.22913658446266597`, 0.35816745674178546`, 0.9363603615567251]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 271}], {
             RGBColor[
             0.8182267475230357, 0.1411043452395526, 0.1650872600532131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 287}], {
             RGBColor[
             0.8173321632588791, 0.13422817857592148`, 0.1642306051515684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 292}], {
             RGBColor[
             0.8180564581257688, 0.1397954263108694, 0.1649241907340759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 319}], {
             RGBColor[
             0.822373957683161, 0.17298161984935592`, 0.16905863318615305`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 362}], {
             RGBColor[
             0.808649465228358, 0.36847454946527913`, 0.43610132085825937`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 385}], {
             RGBColor[
             0.8763650244456923, 0.41967521212315095`, 0.3207468068561434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 393}], {
             RGBColor[
             0.7855497496539053, 0.35042887609417595`, 0.43379895708891325`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 400}], {
             RGBColor[
             0.8189309026952224, 0.14651679045574345`, 0.16576155984132857`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 251}], {
             RGBColor[
             0.1839193268501145, 0.3106412520512747, 0.9337853056286283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 260}], {
             RGBColor[
             0.1859219097416619, 0.3127460936413798, 0.933899349761746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 275}], {
             RGBColor[
             0.18852850716525682`, 0.3154857928014001, 0.9340477916289045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 268}], {
             RGBColor[
             0.18564105657677243`, 0.3124508991579618, 0.9338833555894905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 279}], {
             RGBColor[
             0.19132944320701362`, 0.3184297541708887, 0.934207300792869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 299}], {
             RGBColor[
             0.186005835268804, 0.3128343046915919, 0.9339041291963601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 300}], {
             RGBColor[
             0.18989148665345995`, 0.3169183706613924, 0.9341254112944102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 370}], {
             RGBColor[
             0.18458433002004276`, 0.31134021254650546`, 0.9338231765753717]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 265}], {
             RGBColor[
             0.19635832810443649`, 0.32371543104779843`, 0.9344936883482087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 321}], {
             RGBColor[
             0.18913677562513462`, 0.3161251215191795, 0.934082431617842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 325}], {
             RGBColor[
             0.21599606078555122`, 0.34435593319981583`, 0.9356120281729761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 375}], {
             RGBColor[
             0.19825790374427554`, 0.32571200548532114`, 0.9346018663707272]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 381}], {
             RGBColor[
             0.19153445496524343`, 0.31864523452728444`, 0.9342189759092124]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 260}], {
             RGBColor[
             0.1869284496057658, 0.31380403085686637`, 0.9339566707179645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 275}], {
             RGBColor[
             0.1895350470293607, 0.3165437300168866, 0.9341051125851229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 274}], {
             RGBColor[
             0.20454056169243495`, 0.3323154773323579, 0.9349596544465153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 288}], {
             RGBColor[
             0.20983762189248398`, 0.33788302345562404`, 0.9352613141886098]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 318}], {
             RGBColor[
             0.20969889594004104`, 0.3377372136838731, 0.9352534139508448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 283}], {
             RGBColor[
             0.8607691122014759, 0.3856977852240938, 0.20253221045503758`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 332}], {
             RGBColor[
             0.8227299040516889, 0.17571757961455517`, 0.16939948783063935`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 334}], {
             RGBColor[
             0.8701987937776897, 0.4222457469371983, 0.21448170260215638`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 364}], {
             RGBColor[
             0.8572410457828872, 0.37171017753282953`, 0.19969344540027856`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 366}], {
             RGBColor[
             0.8812282840866474, 0.45912286163357663`, 0.28521534724776915`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 391}], {
             RGBColor[
             0.8235396690014747, 0.18194178785987172`, 0.17017491966105283`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 314}], {
             RGBColor[
             0.1849157269952969, 0.31168853177927935`, 0.9338420491428545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 369}], {
             RGBColor[
             0.1837415562121556, 0.31045440383947037`, 0.9337751818537847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 312}], {
             RGBColor[
             0.46100266352577723`, 0.571153212435337, 0.9513046138622602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 331}], {
             RGBColor[
             0.30757882188877433`, 0.4345645888368619, 0.9410490742458533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 356}], {
             RGBColor[
             0.6597861746771188, 0.7286564919053182, 0.9611997608615672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 359}], {
             RGBColor[
             0.3499392226187198, 0.4775214990007658, 0.9435187957195283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 360}], {
             RGBColor[
             0.5184721491114823, 0.6174970812936685, 0.956042445038614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 380}], {
             RGBColor[
             0.5472854839726642, 0.6400062774766795, 0.9589142889816533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 310}], {
             RGBColor[
             0.8817791092522581, 0.4669114753460718, 0.37441947014658894`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 316}], {
             RGBColor[
             0.8522226042580414, 0.8830674650503693, 0.8745751101286188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 319}], {
             RGBColor[
             0.88573090588642, 0.4972867159645674, 0.37820371506637834`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 384}], {
             RGBColor[
             0.9629443447193516, 0.8827390749129462, 0.5213129511813582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 310}], {
             RGBColor[
             0.8741512138365515, 0.46212106330300473`, 0.4275663759812295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 356}], {
             RGBColor[
             0.9574019127188883, 0.9677509967704889, 0.9569916297931109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 360}], {
             RGBColor[
             0.816087887153252, 0.8565915861588391, 0.9518343139701578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 389}], {
             RGBColor[
             0.981271770948398, 0.982206986986089, 0.7147685106713391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 264}], {
             RGBColor[
             0.24881577416889822`, 0.37885153285572853`, 0.9374810622977428]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 279}], {
             RGBColor[
             0.2183447678357952, 0.34682457322625027`, 0.9357457835648868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 281}], {
             RGBColor[
             0.318201913769557, 0.44345916858997797`, 0.9417371947060786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 300}], {
             RGBColor[
             0.21690681128224154`, 0.345313189716754, 0.9356638940664279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 328}], {
             RGBColor[
             0.23450213577855084`, 0.36380699137038264`, 0.936665921766543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 394}], {
             RGBColor[
             0.29763886748570073`, 0.42564849142765915`, 0.9404269355800592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 271}], {
             RGBColor[
             0.8451433755388915, 0.40965410113712897`, 0.44115450773017084`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 287}], {
             RGBColor[
             0.8433542070105785, 0.39590176780986674`, 0.4394411979268815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 292}], {
             RGBColor[
             0.8448027967443577, 0.4070362632797625, 0.4408283690918966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 345}], {
             RGBColor[
             0.8617541752858404, 0.8926034039517254, 0.9866760766074392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 350}], {
             RGBColor[
             0.6219849446227963, 0.6978827145935297, 0.9666587839790601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 353}], {
             RGBColor[
             0.9443422105725244, 0.9537215111738743, 0.7488183078429457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 393}], {
             RGBColor[
             0.808698190108407, 0.8510901979921818, 0.9814053247963395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 400}], {
             RGBColor[
             0.8465516858832649, 0.4204789915695107, 0.44250310730640185`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 327}], {
             RGBColor[
             0.1874834373807122, 0.31438735819659225`, 0.9339882764507168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 335}], {
             RGBColor[
             0.19373393161436922`, 0.3209570239403897, 0.934344232850546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 349}], {
             RGBColor[
             0.19380914280268063`, 0.32103607566796977`, 0.9343485160164554]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 355}], {
             RGBColor[
             0.19867201809183277`, 0.32614726592096993`, 0.9346254495701933]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 284}], {
             RGBColor[
             0.5520990373737982, 0.6433480852372535, 0.9595712205145508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 325}], {
             RGBColor[
             0.3013026030921642, 0.42887910004945207`, 0.9406582888215985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 376}], {
             RGBColor[
             0.3252561022413611, 0.4540557463948223, 0.9420224051621189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 397}], {
             RGBColor[
             0.364256395049981, 0.48992231415871446`, 0.9444310732866698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 336}], {
             RGBColor[
             0.2683165494931898, 0.3993480841421268, 0.9385916026036494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 359}], {
             RGBColor[
             0.31376085658735253`, 0.4455463754257799, 0.941236947982536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 360}], {
             RGBColor[
             0.48229378308011506`, 0.5855219577186828, 0.9537605973016217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 279}], {
             RGBColor[
             0.22950792112061041`, 0.35855775511338905`, 0.9363815086300517]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 281}], {
             RGBColor[
             0.3293650670543722, 0.4551923504771167, 0.9423729197712435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 328}], {
             RGBColor[
             0.24566528906336602`, 0.3755401732575213, 0.9373016468317077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 394}], {
             RGBColor[
             0.30880202077051594`, 0.4373816733147978, 0.941062660645224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 321}], {
             RGBColor[
             0.19177497299708612`, 0.31889803422847507`, 0.9342326730553113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 325}], {
             RGBColor[
             0.2186342581575027, 0.34712884590911136`, 0.9357622696104455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 375}], {
             RGBColor[
             0.20089610111622702`, 0.32848491819461667`, 0.9347521078081966]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 381}], {
             RGBColor[
             0.19417265233719494`, 0.3214181472365799, 0.9343692173466818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 358}], {
             RGBColor[
             0.4679094050103473, 0.5710147999295367, 0.9528445815300333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 384}], {
             RGBColor[
             0.7959032258697958, 0.7536598609266292, 0.6159939861993788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 275}], {
             RGBColor[
             0.19585412945824818`, 0.323185486302614, 0.9344649749812033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 306}], {
             RGBColor[
             0.20993199303624877`, 0.33798221351119695`, 0.9352666884856375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 311}], {
             RGBColor[
             0.20008010519765723`, 0.3276272547470704, 0.9347056380477918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 317}], {
             RGBColor[
             0.1930340826347562, 0.32022143828982824`, 0.9343043774864909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 344}], {
             RGBColor[
             0.1945632673718405, 0.321828708404416, 0.9343914622950418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 346}], {
             RGBColor[
             0.20049511025135958`, 0.32806345137135173`, 0.9347292719716551]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 354}], {
             RGBColor[
             0.19683262012965425`, 0.3242139420381536, 0.9345206985773926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 279}], {
             RGBColor[
             0.19334852815726622`, 0.3205519404709839, 0.9343222846938173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 299}], {
             RGBColor[
             0.18802492021905656`, 0.3149564909916871, 0.9340191130973085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 300}], {
             RGBColor[
             0.1919105716037125, 0.31904055696148764`, 0.9342403951953585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 370}], {
             RGBColor[
             0.18660341497029534`, 0.3134623988466007, 0.9339381604763201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 371}], {
             RGBColor[
             0.1838466718007321, 0.3105648869877775, 0.9337811680310495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 309}], {
             RGBColor[
             0.5253850164437505, 0.6220146854886827, 0.9571050895141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 323}], {
             RGBColor[
             0.38701260190710624`, 0.5096325967781434, 0.9458810786650822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 362}], {
             RGBColor[
             0.5723371220999356, 0.658694027276514, 0.9617848366135348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 365}], {
             RGBColor[
             0.3297101598350657, 0.4597477851420956, 0.9422390562668672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 377}], {
             RGBColor[
             0.30404872534557215`, 0.4327759904647185, 0.9407776755353809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 388}], {
             RGBColor[
             0.3120924130263679, 0.44123041621648995`, 0.9412357516492327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 336}], {
             RGBColor[
             0.2213730230293102, 0.3500074614371033, 0.9359182382182554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 357}], {
             RGBColor[
             0.1969743042117703, 0.32436286099174727`, 0.9345287672762663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 287}], {
             RGBColor[
             0.819108168528313, 0.14787933332726222`, 0.1659313098032894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 292}], {
             RGBColor[
             0.8198324633952027, 0.15344658106221012`, 0.16662489538579692`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 303}], {
             RGBColor[
             0.8446451878986901, 0.3069179972587709, 0.1889269695655514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 333}], {
             RGBColor[
             0.8645940127585953, 0.4248527314211257, 0.4322347939799689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 337}], {
             RGBColor[
             0.8656615757726001, 0.4256489181689964, 0.43042768826228606`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 345}], {
             RGBColor[
             0.8226964117082949, 0.39175550148521254`, 0.4390134962813673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 353}], {
             RGBColor[
             0.8777551018994175, 0.4325009062999784, 0.2804416504383717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 385}], {
             RGBColor[
             0.8781410297151262, 0.43332636687449166`, 0.3224475115078644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 391}], {
             RGBColor[
             0.8200799062622772, 0.15534853536870052`, 0.16686184695475423`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 400}], {
             RGBColor[
             0.8207069079646563, 0.1601679452070842, 0.16746226449304957`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 308}], {
             RGBColor[
             0.20474955864050876`, 0.33253514637595527`, 0.9349715565135248]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 342}], {
             RGBColor[
             0.19152273141080622`, 0.31863291232825464`, 0.9342183082701306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 348}], {
             RGBColor[
             0.1988777254844435, 0.3263634774332058, 0.9346371643018856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 374}], {
             RGBColor[
             0.19014395523747457`, 0.3171837311506246, 0.934139789006776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 375}], {
             RGBColor[
             0.1997235147350348, 0.3272524555617131, 0.9346853307484737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 378}], {
             RGBColor[
             0.2184441934159871, 0.34692907581497784`, 0.9357514457045917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 281}], {
             RGBColor[
             0.46139853851670076`, 0.5721415288193888, 0.9511515046102453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 293}], {
             RGBColor[
             0.4190878106551068, 0.5354941029446921, 0.9484555024448121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 394}], {
             RGBColor[
             0.4408354922328445, 0.55433085165707, 0.9498412454842259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 288}], {
             RGBColor[
             0.20843688657003606`, 0.3364107618199823, 0.9351815443841986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 318}], {
             RGBColor[
             0.20829816061759315`, 0.33626495204823137`, 0.9351736441464337]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 311}], {
             RGBColor[
             0.19837020308391207`, 0.32583003921146847`, 0.9346082616519875]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 317}], {
             RGBColor[
             0.19132418052101102`, 0.3184242227542263, 0.9342070010906866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 344}], {
             RGBColor[
             0.19285336525809532`, 0.32003149286881416`, 0.9342940858992375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 346}], {
             RGBColor[
             0.1987852081376144, 0.3262662358357499, 0.9346318955758508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 282}], {
             RGBColor[
             0.3470343998180849, 0.475005487491495, 0.9433337029793059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 301}], {
             RGBColor[
             0.3144566810509267, 0.44134464114731864`, 0.9414571987432081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 305}], {
             RGBColor[
             0.33855234976798615`, 0.46667071672258365`, 0.9428294114302973]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 339}], {
             RGBColor[
             0.38050139833268903`, 0.5039929195045905, 0.9454661905309516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 361}], {
             RGBColor[
             0.3943096577609078, 0.5159529397980152, 0.9463460406115533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 382}], {
             RGBColor[
             0.35057061271571854`, 0.4780683773681971, 0.9435590273381926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 373}], {
             RGBColor[
             0.19154984531155025`, 0.31866141075705723`, 0.9342198523666666]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 390}], {
             RGBColor[
             0.19904871949657826`, 0.326543202981606, 0.9346469021579138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 296}], {
             RGBColor[
             0.1835851599868279, 0.3102900214905575, 0.9337662753201197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 302}], {
             RGBColor[
             0.19139766926121787`, 0.31850146407963903`, 0.9342111861657245]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 330}], {
             RGBColor[
             0.18839714683821507`, 0.31534772476895345`, 0.9340403108526096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 367}], {
             RGBColor[
             0.18709347932173553`, 0.31397748755183885`, 0.9339660689161493]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 299}], {
             RGBColor[
             0.19371330684929777`, 0.320935346004614, 0.9343430583006869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 300}], {
             RGBColor[
             0.1975989582339537, 0.32501941197441453`, 0.9345643403987369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 328}], {
             RGBColor[
             0.215194282730263, 0.3435132136280431, 0.9355663680988517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 370}], {
             RGBColor[
             0.19229180160053655`, 0.3194412538595276, 0.9342621056796985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 371}], {
             RGBColor[
             0.1895350584309733, 0.3165437420007044, 0.9341051132344278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 291}], {
             RGBColor[
             0.20219476439486456`, 0.32984989564047235`, 0.9348260647607148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 336}], {
             RGBColor[
             0.22186501043454393`, 0.3505245713938071, 0.9359462561731533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 368}], {
             RGBColor[
             0.19638103924398845`, 0.323739301895437, 0.934494981714008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 387}], {
             RGBColor[
             0.19723551682458454`, 0.32463741200965124`, 0.9345436429481366]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 392}], {
             RGBColor[
             0.20599555407739328`, 0.33384476658079454`, 0.9350425141103704]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 293}], {
             RGBColor[
             0.356440478793437, 0.4831525603366694, 0.9439330500141462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 394}], {
             RGBColor[
             0.3781881603711747, 0.5019893090490473, 0.9453187930535599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 301}], {
             RGBColor[
             0.2824458229860667, 0.41361844480404447`, 0.9394174951734057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 305}], {
             RGBColor[
             0.30654149170312617`, 0.4389445203793095, 0.9407897078604948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 313}], {
             RGBColor[
             0.2998205585054363, 0.43188039345676055`, 0.940406960657616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 339}], {
             RGBColor[
             0.34849054026782905`, 0.4762667231613163, 0.9434264869611491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 340}], {
             RGBColor[
             0.29320777122887487`, 0.42492993475416496`, 0.9400303722049579]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 361}], {
             RGBColor[
             0.36229879969604784`, 0.48822674345474093`, 0.9443063370417508]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 382}], {
             RGBColor[
             0.3185597546508585, 0.45034218102492296`, 0.9415193237683902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 312}], {
             RGBColor[
             0.7398695405352704, 0.7057918843470511, 0.6108133774642039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 332}], {
             RGBColor[
             0.8558441265023222, 0.3478421869979039, 0.19781603858755223`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 334}], {
             RGBColor[
             0.9460670651662169, 0.8226245407866379, 0.2820057220570269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 356}], {
             RGBColor[
             0.9386530516866118, 0.8632951638170323, 0.6207085244635109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 360}], {
             RGBColor[
             0.7973390261209754, 0.7521357532053826, 0.6155512086405578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 364}], {
             RGBColor[
             0.9266304431740131, 0.7468211866800847, 0.25982333625421017`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 366}], {
             RGBColor[
             0.9626113006296535, 0.8779402128312055, 0.388106189025446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 380}], {
             RGBColor[
             0.8261523609821573, 0.7746449493883936, 0.6184230525835972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 389}], {
             RGBColor[
             0.9625229099161214, 0.8777511540326326, 0.378485405341739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 334}], {
             RGBColor[
             0.8500382234662116, 0.8370769008965131, 0.6373182165494112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 366}], {
             RGBColor[
             0.8665824589296481, 0.8923925729410807, 0.7434186835178305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 397}], {
             RGBColor[
             0.5520222170780682, 0.6432815473581924, 0.9595663255932364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 324}], {
             RGBColor[
             0.1849819453905557, 0.31175813151118514`, 0.9338458201825032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 290}], {
             RGBColor[
             0.28938656912218486`, 0.4203385400712017, 0.9398338164907357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 304}], {
             RGBColor[
             0.3017569575169641, 0.43334060260203944`, 0.9405382918094687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 386}], {
             RGBColor[
             0.331585149915525, 0.4616241237277755, 0.94234929043675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 292}], {
             RGBColor[
             0.8180432948668896, 0.1396942477349479, 0.16491158558250754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 303}], {
             RGBColor[
             0.8428560193703771, 0.29316566393150867`, 0.187213659762262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 353}], {
             RGBColor[
             0.8759659333711045, 0.41874857297271617`, 0.27872834063508234`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 385}], {
             RGBColor[
             0.8763518611868132, 0.41957403354722944`, 0.320734201704575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 391}], {
             RGBColor[
             0.8182907377339641, 0.1415962020414383, 0.16514853715146482`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 400}], {
             RGBColor[
             0.8189177394363433, 0.14641561187982197`, 0.1657489546897602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 318}], {
             RGBColor[
             0.21359522081764215`, 0.3418324981714975, 0.9354753038885282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 304}], {
             RGBColor[
             0.2699001201696922, 0.4010125173273108, 0.9386817846109934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 338}], {
             RGBColor[
             0.2338329245191738, 0.3631036079063329, 0.9366278111753308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 336}], {
             RGBColor[
             0.21513079622652476`, 0.34344648528733734`, 0.9355627526363838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 368}], {
             RGBColor[
             0.1896468250359693, 0.3166612157889672, 0.9341114781772385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 387}], {
             RGBColor[
             0.1905013026165654, 0.3175593259031815, 0.9341601394113672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 303}], {
             RGBColor[
             0.8443046091041563, 0.3043001594014045, 0.18860083092727706`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 309}], {
             RGBColor[
             0.778783487932468, 0.35505497183403256`, 0.43435605547208284`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 362}], {
             RGBColor[
             0.810084891703258, 0.3795078663592535, 0.437475886871706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 385}], {
             RGBColor[
             0.8778004509205923, 0.4307085290171253, 0.32212137286959003`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 400}], {
             RGBColor[
             0.8203663291701224, 0.1575501073497178, 0.16713612585477525`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 394}], {
             RGBColor[
             0.3358774325095808, 0.4653418831743506, 0.9426227908881267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 301}], {
             RGBColor[
             0.22980051567191817`, 0.3588652905383795, 0.9363981714568937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 313}], {
             RGBColor[
             0.24717525119128783`, 0.3771272391910956, 0.937387636941104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 329}], {
             RGBColor[
             0.23603593247132534`, 0.36541910894281576`, 0.9367532692191475]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 340}], {
             RGBColor[
             0.24056246391472638`, 0.3701767804885, 0.937011048488446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 343}], {
             RGBColor[
             0.20522639813651683`, 0.33303633491963003`, 0.9349987118174017]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 330}], {
             RGBColor[
             0.18388840354746627`, 0.31060874969954066`, 0.9337835445922895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 367}], {
             RGBColor[
             0.18258473603098674`, 0.3092385124824261, 0.9337093026558292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 398}], {
             RGBColor[
             0.17994179284220208`, 0.3064606116187368, 0.933558790951112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 325}], {
             RGBColor[
             0.267416015836295, 0.3984015661715987, 0.9385403185441094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 375}], {
             RGBColor[
             0.2496778587950193, 0.3797576384571041, 0.9375301567418605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 376}], {
             RGBColor[
             0.2913695149854919, 0.423578212516969, 0.9399044348846297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 378}], {
             RGBColor[
             0.2683985374759716, 0.3994342587103688, 0.9385962716979784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 397}], {
             RGBColor[
             0.33036980779411174`, 0.4594447802808611, 0.9423131030091806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 320}], {
             RGBColor[
             0.19458686072830475`, 0.3218535065179652, 0.9343928059017892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 347}], {
             RGBColor[
             0.1948950544058417, 0.32217743761366435`, 0.9344103570757931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 373}], {
             RGBColor[
             0.20172543232639267`, 0.32935659787913657`, 0.93479933699373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 390}], {
             RGBColor[
             0.2092243065114207, 0.3372383901036854, 0.935226386784977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 300}], {
             RGBColor[
             0.19227535029574405`, 0.31942396249511773`, 0.934261168802228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 370}], {
             RGBColor[
             0.1869681936623269, 0.3138458043802308, 0.9339589340831895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 371}], {
             RGBColor[
             0.18421145049276366`, 0.3109482925214076, 0.933801941637919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 370}], {
             RGBColor[
             0.19085384504698283`, 0.3179298703500313, 0.9341802161812396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 371}], {
             RGBColor[
             0.1880971018774196, 0.31503235849120814`, 0.934023223735969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 305}], {
             RGBColor[
             0.27396377293596785`, 0.4052836740351331, 0.9389132036243971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 313}], {
             RGBColor[
             0.2672428397382781, 0.39821954711258417`, 0.9385304564215183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 329}], {
             RGBColor[
             0.25610352101831557`, 0.38651141686430435`, 0.9378960886995618]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 339}], {
             RGBColor[
             0.3159128215006708, 0.4426058768171399, 0.9415499827250514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 340}], {
             RGBColor[
             0.26063005246171667`, 0.3912690884099886, 0.9381538679688604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 361}], {
             RGBColor[
             0.3297210809288895, 0.45456589711056455`, 0.9424298328056531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 382}], {
             RGBColor[
             0.2859820358837003, 0.41668133468074653`, 0.9396428195322926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 367}], {
             RGBColor[
             0.19039724530537674`, 0.31744995507150764`, 0.934154213501434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 377}], {
             RGBColor[
             0.22469777382228445`, 0.35350198532189486`, 0.9361075778573873]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 353}], {
             RGBColor[
             0.9435949291122223, 0.7996173553563373, 0.3704770005960165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 385}], {
             RGBColor[
             0.9441738208357854, 0.8008555462181073, 0.4334857922002555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 391}], {
             RGBColor[
             0.8447994948383054, 0.3081040680143853, 0.18907473406519165`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 400}], {
             RGBColor[
             0.8460534982430635, 0.31774288769115266`, 0.1902755691417824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 338}], {
             RGBColor[
             0.24620331291395298`, 0.37610567043717064`, 0.9373322864940637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 313}], {
             RGBColor[
             0.29133850845533754`, 0.4235456226878492, 0.9399026691086074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 329}], {
             RGBColor[
             0.28019918973537505`, 0.41183749243956935`, 0.9392683013866509]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 339}], {
             RGBColor[
             0.3400084902177303, 0.4679319523924049, 0.9429221954121405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 340}], {
             RGBColor[
             0.2847257211787761, 0.4165951639852536, 0.9395260806559493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 361}], {
             RGBColor[
             0.353816749645949, 0.47989197268582956`, 0.9438020454927423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 382}], {
             RGBColor[
             0.31007770460075973`, 0.44200741025601153`, 0.9410150322193817]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 308}], {
             RGBColor[
             0.2175738595337591, 0.3460142997224009, 0.9357018814775424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 311}], {
             RGBColor[
             0.21244806666191265`, 0.3406267664200514, 0.9354099751564218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 346}], {
             RGBColor[
             0.21286307171561503`, 0.3410629630443328, 0.9354336090802852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 348}], {
             RGBColor[
             0.21170202637769384`, 0.33984263077965143`, 0.9353674892659032]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 350}], {
             RGBColor[
             0.2854226113571807, 0.41364792547081863`, 0.9397004998858718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 354}], {
             RGBColor[
             0.2092005815939097, 0.33721345371113465`, 0.9352250356860227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 378}], {
             RGBColor[
             0.23126849430923743`, 0.36040822916142345`, 0.9364817706686093]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 343}], {
             RGBColor[
             0.1898749181249935, 0.3169009560874688, 0.9341244677412249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 348}], {
             RGBColor[
             0.20697593141094872`, 0.33487520531787435`, 0.9350983451491781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 354}], {
             RGBColor[
             0.20447448662716458`, 0.33224602824935756`, 0.9349558915692975]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 374}], {
             RGBColor[
             0.1982421611639798, 0.32569545903529307`, 0.9346009698540684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 378}], {
             RGBColor[
             0.22654239934249232`, 0.35544080369964637`, 0.9362126265518842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 323}], {
             RGBColor[
             0.5589942800594222, 0.6511253403818711, 0.9592466420721857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 362}], {
             RGBColor[
             0.7443188002522516, 0.8001867708802417, 0.9751504000206381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 365}], {
             RGBColor[
             0.5016918379873817, 0.6012405287458232, 0.9556046196739707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 385}], {
             RGBColor[
             0.845892139078253, 0.8769877648670494, 0.8021186290174642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 316}], {
             RGBColor[
             0.7883915446819063, 0.3948994518775877, 0.4393315589045834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 319}], {
             RGBColor[
             0.8284925866386836, 0.2200120832018078, 0.17491783918396456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 384}], {
             RGBColor[
             0.8622060383227799, 0.39468052511930574`, 0.20382345293974308`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 317}], {
             RGBColor[
             0.19555015626042008`, 0.32286599119868276`, 0.934447664157275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 344}], {
             RGBColor[
             0.19707934099750435`, 0.3244732613132706, 0.9345347489658259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 346}], {
             RGBColor[
             0.20301118387702347`, 0.33070800428020625`, 0.9348725586424393]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 354}], {
             RGBColor[
             0.19934869375531813`, 0.32685849494700814`, 0.9346639852481768]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 356}], {
             RGBColor[
             0.746600049419986, 0.8012844499471021, 0.9674404180913663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 359}], {
             RGBColor[
             0.4367530973615871, 0.5501494570425497, 0.9497594529493274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 360}], {
             RGBColor[
             0.6052860238543496, 0.6901250393354524, 0.9622831022684131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 380}], {
             RGBColor[
             0.6340993587155315, 0.7126342355184634, 0.9651549462114524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 389}], {
             RGBColor[
             0.7704699076494956, 0.8157404401627024, 0.7252172989695943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 329}], {
             RGBColor[
             0.27347825653768526`, 0.4047733655170204, 0.9388855541837721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 339}], {
             RGBColor[
             0.3332875570200404, 0.460867825469856, 0.9425394482092617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 340}], {
             RGBColor[
             0.2780047879810863, 0.40953103706270466`, 0.9391433334530706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 358}], {
             RGBColor[
             0.28110733593194254`, 0.4127920116719563, 0.9393200189690635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 361}], {
             RGBColor[
             0.3470958164482592, 0.47282784576328063`, 0.9434192982898635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 369}], {
             RGBColor[
             0.1815795981118552, 0.30818204879999395`, 0.9336520615383029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 322}], {
             RGBColor[
             0.18811052101816012`, 0.31504646285894905`, 0.9340239879361825]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 351}], {
             RGBColor[
             0.5108480401165528, 0.6087959957654421, 0.956444390370581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 399}], {
             RGBColor[
             0.5357585344043984, 0.6303722138797264, 0.9580316650391174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 344}], {
             RGBColor[
             0.19003331843460333`, 0.31706744485602845`, 0.9341334884045249]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 346}], {
             RGBColor[
             0.19596516131412245`, 0.3233021878229641, 0.9344712980811385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 354}], {
             RGBColor[
             0.19230267119241712`, 0.319452678489766, 0.934262724686876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 322}], {
             RGBColor[
             0.20428384988578308`, 0.3320456569470981, 0.9349450350888977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 384}], {
             RGBColor[
             0.8661578349569418, 0.4250557657378013, 0.20760769785953248`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 347}], {
             RGBColor[
             0.1840162025368019, 0.3107430745402564, 0.9337908225556705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 398}], {
             RGBColor[
             0.182257588923795, 0.30889466013044303`, 0.9336906721120455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 375}], {
             RGBColor[
             0.19367454863692518`, 0.3208946086659977, 0.9343408510778299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 381}], {
             RGBColor[
             0.18695109985789307`, 0.313827837707961, 0.9339579606163151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 327}], {
             RGBColor[
             0.19043725974580353`, 0.3174920127854582, 0.9341564922646202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 335}], {
             RGBColor[
             0.19668775397946056`, 0.3240616785292556, 0.9345124486644494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 349}], {
             RGBColor[
             0.19676296516777197`, 0.32414073025683565`, 0.9345167318303588]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 355}], {
             RGBColor[
             0.2016258404569241, 0.32925192050983587`, 0.9347936653840967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 362}], {
             RGBColor[
             0.6059463857156073, 0.6878046821697024, 0.9639263891716204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 365}], {
             RGBColor[
             0.3633194234507374, 0.48885844003528395`, 0.9443806088249529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 377}], {
             RGBColor[
             0.3376579889612439, 0.46188664535790686`, 0.9429192280934666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 388}], {
             RGBColor[
             0.34570167664203966`, 0.47034107110967827`, 0.9433773042073184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 395}], {
             RGBColor[
             0.42965137086591587`, 0.5465641553634234, 0.9485979833191546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 376}], {
             RGBColor[
             0.26222548998781436`, 0.392945994406499, 0.9382447257757333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 397}], {
             RGBColor[
             0.3012257827964342, 0.4288125621703911, 0.9406533939002841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 363}], {
             RGBColor[
             0.3080486907375876, 0.43502729111889293`, 0.9410769734898234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 383}], {
             RGBColor[
             0.2999445651565369, 0.428007904865782, 0.9405605857739958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 335}], {
             RGBColor[
             0.19201380881889718`, 0.3191490658202642, 0.9342462744020376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 349}], {
             RGBColor[
             0.19208902000720862`, 0.3192281175478443, 0.934250557567947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 355}], {
             RGBColor[
             0.19695189529636073`, 0.3243393078008444, 0.9345274911216848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 339}], {
             RGBColor[
             0.322148238300078, 0.44915969522157617`, 0.9419050804873051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 340}], {
             RGBColor[
             0.2668654692611238, 0.39782290681442484`, 0.9385089657311141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 341}], {
             RGBColor[
             0.2558412218032698, 0.3862357237585604, 0.9378811511473018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 343}], {
             RGBColor[
             0.23152940348291426`, 0.3606824612455548, 0.9364966290600697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 358}], {
             RGBColor[
             0.26996801721198005`, 0.40108388142367646`, 0.9386856512471069]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 367}], {
             RGBColor[
             0.1873967228823739, 0.314296215760822, 0.9339833381883191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 398}], {
             RGBColor[
             0.18475377969358928`, 0.31151831489713266`, 0.9338328264836019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 392}], {
             RGBColor[
             0.22201549227327083`, 0.35068273734740874`, 0.9359548258912509]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 334}], {
             RGBColor[
             0.865273808078536, 0.38439014871100835`, 0.20976553073467102`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 356}], {
             RGBColor[
             0.860331132425466, 0.41150389739793797`, 0.4355673990056604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 364}], {
             RGBColor[
             0.8523160600837335, 0.33385457930663953`, 0.1949772735327932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 366}], {
             RGBColor[
             0.8763032983874938, 0.42126726340738674`, 0.2804991753802838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 380}], {
             RGBColor[
             0.7853306719558296, 0.3524037544455121, 0.43404375108571785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 389}], {
             RGBColor[
             0.8762443712451391, 0.4211412242083381, 0.2740853195911458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 337}], {
             RGBColor[
             0.9553778772118539, 0.9662414744033965, 0.9604177939535141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 345}], {
             RGBColor[
             0.8909301311153961, 0.9154013493777207, 0.9732965059821361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 353}], {
             RGBColor[
             0.97351816640208, 0.9765194565998694, 0.7354387372176427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 391}], {
             RGBColor[
             0.8647483196982105, 0.42603880217674006`, 0.43238255847960916`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 364}], {
             RGBColor[
             0.9407749655383337, 0.8016431292497415, 0.27774757447488835`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 366}], {
             RGBColor[
             0.9767558229939741, 0.9327621554008622, 0.40603042724612426`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 391}], {
             RGBColor[
             0.8668933379781074, 0.3968385652016415, 0.21131639439549801`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 349}], {
             RGBColor[
             0.19833951424086566`, 0.32579778329164166`, 0.9346065139677762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 355}], {
             RGBColor[
             0.20320238953001776`, 0.3309089735446419, 0.934883447521514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 359}], {
             RGBColor[
             0.2802453493603669, 0.4103194523243253, 0.9393282894277089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 345}], {
             RGBColor[
             0.8925314756364031, 0.9165956294995268, 0.9705858474056119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 353}], {
             RGBColor[
             0.9751195109230872, 0.9777137367216755, 0.7327280786411184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 391}], {
             RGBColor[
             0.8658158827122152, 0.4268349889246108, 0.4305754527619263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 340}], {
             RGBColor[
             0.326674769743479, 0.4539173667672604, 0.9421628597566036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 361}], {
             RGBColor[
             0.39576579821065194`, 0.5172141754678363, 0.9464388245933966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 382}], {
             RGBColor[
             0.3520267531654626, 0.47932961303801835`, 0.943651811320036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 343}], {
             RGBColor[
             0.2360559349263153, 0.3654401327912391, 0.9367544083293682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 358}], {
             RGBColor[
             0.2744945486553811, 0.4058415529693607, 0.9389434305164055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 361}], {
             RGBColor[
             0.34048302917169776`, 0.46587738706068504`, 0.9430427098372054]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 358}], {
             RGBColor[
             0.26347030119752707`, 0.39425436991349627`, 0.9383156159325932]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 348}], {
             RGBColor[
             0.1937491041812462, 0.3209729712701737, 0.9343450969057838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 374}], {
             RGBColor[
             0.18501533393427727`, 0.31179322498759243`, 0.9338477216106742]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 346}], {
             RGBColor[
             0.19749434605120672`, 0.3249094579375519, 0.9345583828896893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 354}], {
             RGBColor[
             0.1938318559295014, 0.32105994860435383`, 0.9343498094954268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 350}], {
             RGBColor[
             0.5883144988769012, 0.6710348151156551, 0.9634472668058549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 353}], {
             RGBColor[
             0.9106717648266294, 0.9268736116959997, 0.7456067906697404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 354}], {
             RGBColor[
             0.1997636988090205, 0.3272946915712895, 0.9346876191720402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 398}], {
             RGBColor[
             0.182565782601332, 0.30921859122614215`, 0.9337082232860494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 354}], {
             RGBColor[
             0.19860265347109932`, 0.3260743593066081, 0.9346214993576583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 374}], {
             RGBColor[
             0.19237032800791454`, 0.3195237900925436, 0.9342665776424293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 378}], {
             RGBColor[
             0.22067056618642705`, 0.3492691347568969, 0.935878234340245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 355}], {
             RGBColor[
             0.20327760071832918`, 0.33098802527222193`, 0.9348877306874234]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 355}], {
             RGBColor[
             0.2588476494190366, 0.38932088860423164`, 0.9380551008583563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 395}], {
             RGBColor[
             0.37411784951982285`, 0.4984638103693781, 0.9450594364453463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 399}], {
             RGBColor[
             0.33446531711843736`, 0.46411877979752536`, 0.9425328121440877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 396}], {
             RGBColor[
             0.18539177638104404`, 0.312188889866974, 0.9338691594511209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 391}], {
             RGBColor[
             0.8779094088390327, 0.4336869770555928, 0.280589414938012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 400}], {
             RGBColor[
             0.8791634122437909, 0.44332579673236017`, 0.28179025001460273`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 374}], {
             RGBColor[
             0.18986888322413037`, 0.3168946130240269, 0.9341241240625486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 359}], {
             RGBColor[
             0.6355366085129286, 0.7076527365125309, 0.9596545999486343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 360}], {
             RGBColor[
             0.804069535005691, 0.8476283188054337, 0.97217824926772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 364}], {
             RGBColor[
             0.9333609520587287, 0.8423137522801358, 0.6164503768813724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 380}], {
             RGBColor[
             0.8328828698668729, 0.8701375149884446, 0.9750500932107594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 389}], {
             RGBColor[
             0.969253418800837, 0.9732437196326836, 0.7351124459689012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 360}], {
             RGBColor[
             0.49422258294729215`, 0.5964933259008812, 0.9544972841256812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 380}], {
             RGBColor[
             0.6915688443012366, 0.7589781043767949, 0.9698927773878063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 389}], {
             RGBColor[
             0.8279393932352007, 0.862084309021034, 0.7299551301459482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 382}], {
             RGBColor[
             0.3658350125936814, 0.49128963333144304`, 0.9445316614006376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 365}], {
             RGBColor[
             0.5486439436435668, 0.6379198705336546, 0.9602843667734056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 385}], {
             RGBColor[
             0.892844244734438, 0.9136671066548807, 0.806798376116899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 383}], {
             RGBColor[
             0.36642168177165046`, 0.49179777668654956`, 0.9445690434418867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 393}], {
             RGBColor[
             0.5482487832688899, 0.640773127747212, 0.9590042434848745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 366}], {
             RGBColor[
             0.9573192010017704, 0.856958801294309, 0.38384804144330753`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 380}], {
             RGBColor[
             0.8208602613542741, 0.753663537851497, 0.6141649050014586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 391}], {
             RGBColor[
             0.8539355899833049, 0.3463029957972727, 0.1965281371936202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 377}], {
             RGBColor[
             0.2803555468892034, 0.41200183372185906`, 0.9392772056952516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 388}], {
             RGBColor[
             0.2883992345699991, 0.4204562594736305, 0.9397352818091035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 372}], {
             RGBColor[
             0.1818899475322301, 0.30850824571809776`, 0.9336697354786725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 387}], {
             RGBColor[
             0.18468757746568928`, 0.3114487321581461, 0.9338290563646603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 387}], {
             RGBColor[
             0.18274442511282618`, 0.30940635583231196`, 0.9337183967128011]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 392}], {
             RGBColor[
             0.19150446236563495`, 0.31861371040345526`, 0.9342172678750348]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 390}], {
             RGBColor[
             0.20548402624046883`, 0.3333071183914488, 0.9350133833567951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 381}], {
             RGBColor[
             0.196072227977034, 0.3234147216741027, 0.9344773953692003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 397}], {
             RGBColor[
             0.32517928194563106`, 0.4539892085157613, 0.9420175102408045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 388}], {
             RGBColor[
             0.26273780008050557`, 0.39348446479625343`, 0.9382739010776171]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 389}], {
             RGBColor[
             0.8567527280963826, 0.8845935052040448, 0.7328269740889874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 393}], {
             RGBColor[
             0.5401446576878393, 0.6337537414941011, 0.9584878557690468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 400}], {
             RGBColor[
             0.8795493400594996, 0.44415125730687344`, 0.3237961110840954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 395}], {
             RGBColor[
             0.35473118198517756`, 0.4781619748017699, 0.9439526563033052]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.08365695714524007], {
             RGBColor[
             0.1818132732838514, 0.3084276562216236, 0.9336653689936567]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.08365695714524007], {
             RGBColor[
             0.20182540810126717`, 0.3294616787573599, 0.9348050304662081]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.08365695714524007], {
             RGBColor[
             0.23621542372166607`, 0.36560776562732644`, 0.9367634909803209]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.08365695714524007], {
             RGBColor[
             0.2008450066857079, 0.32843121470856707`, 0.9347491980559659]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.08365695714524007], {
             RGBColor[
             0.18681770269069906`, 0.3136876288273712, 0.9339503638449868]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.08365695714524007], {
             RGBColor[
             0.9261633007621113, 0.943961492267368, 0.992819476494071]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.08365695714524007], {
             RGBColor[
             0.25494849258932906`, 0.3852974087524073, 0.9378303115392425]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.08365695714524007], {
             RGBColor[
             0.25559866423556843`, 0.38598078037586825`, 0.937867337852653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.08365695714524007], {
             RGBColor[
             0.6863588655876156, 0.7549080294084094, 0.9693734953996518]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.08365695714524007], {
             RGBColor[
             0.8429670986480872, 0.3312695252776902, 0.18877864823079255`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.08365695714524007], {
             RGBColor[
             0.873192830390407, 0.9017242770380856, 0.9877671057427206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.08365695714524007], {
             RGBColor[
             0.242785484860208, 0.37251331644986996`, 0.9371376462426264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.08365695714524007], {
             RGBColor[
             0.21336291477373137`, 0.3415883297902934, 0.9354620744029933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.08365695714524007], {
             RGBColor[
             0.3386493168091526, 0.46774275003568394`, 0.9427994129046144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.08365695714524007], {
             RGBColor[
             0.18212992963139682`, 0.3087604821200659, 0.9336834021041983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.08365695714524007], {
             RGBColor[
             0.22895368331262583`, 0.3579752160364906, 0.9363499456068083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.08365695714524007], {
             RGBColor[
             0.8276616884309496, 0.21362543547524793`, 0.17412217012187317`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.08365695714524007], {
             RGBColor[
             0.9925358512363838, 0.9864432654728553, 0.42895165434603927`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.08365695714524007], {
             RGBColor[
             0.19951285246669712`, 0.3270310361609309, 0.9346733338439388]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.08365695714524007], {
             RGBColor[
             0.3846257063952153, 0.5075651878546001, 0.9457289877937134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.08365695714524007], {
             RGBColor[
             0.19666790482252822`, 0.3240408158068105, 0.9345113182843263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.08365695714524007], {
             RGBColor[
             0.24203296140503872`, 0.3717223665857442, 0.9370947911451132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.08365695714524007], {
             RGBColor[
             0.2119196850624197, 0.340071403857656, 0.9353798846060012]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.08365695714524007], {
             RGBColor[
             0.2601817623901309, 0.39079790712151985`, 0.9381283385124692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.08365695714524007], {
             RGBColor[
             0.3639618362230004, 0.489667182107741, 0.9444123042586827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.08365695714524007], {
             RGBColor[
             0.1822568035379685, 0.30889383464014303`, 0.9336906273854845]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.08365695714524007], {
             RGBColor[
             0.20503271821821972`, 0.3328327650454837, 0.9349876820325784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.08365695714524007], {
             RGBColor[
             0.19159599737019925`, 0.31870991949690686`, 0.9342224806581308]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.08365695714524007], {
             RGBColor[
             0.18584110899752487`, 0.3126611669362287, 0.9338947482789014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.08365695714524007], {
             RGBColor[
             0.20069898841488326`, 0.3282777402478373, 0.9347408825314572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.08365695714524007], {
             RGBColor[
             0.9842583887354778, 0.9877584534482328, 0.9105427668445933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.08365695714524007], {
             RGBColor[
             0.8215188663850046, 0.16640901342833042`, 0.16823979679335105`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.08365695714524007], {
             RGBColor[
             0.24658940627570813`, 0.37651147904010834`, 0.9373542739398417]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.08365695714524007], {
             RGBColor[
             0.1829376663072982, 0.30960946457990146`, 0.9337294015129516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.08365695714524007], {
             RGBColor[
             0.19009976398754364`, 0.3171372833450601, 0.9341372723804675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.08365695714524007], {
             RGBColor[
             0.24565388341041777`, 0.3755281851931126, 0.9373009972966455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.08365695714524007], {
             RGBColor[
             0.2843315036737978, 0.41618081639268795`, 0.9395036305522334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.08365695714524007], {
             RGBColor[
             0.2587257572717294, 0.3892675534260234, 0.9380454211749428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.08365695714524007], {
             RGBColor[
             0.19817415326039348`, 0.32562397841667373`, 0.9345970969045678]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.08365695714524007], {
             RGBColor[
             0.1934487547814754, 0.32065728500776275`, 0.934327992451794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.08365695714524007], {
             RGBColor[
             0.19479503600678127`, 0.322072311934719, 0.9344046611759306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.08365695714524007], {
             RGBColor[
             0.183885630512114, 0.31060583506356493`, 0.9337833866720284]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.08365695714524007], {
             RGBColor[
             0.194697223000598, 0.3219695042635176, 0.9343990908699299]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.08365695714524007], {
             RGBColor[
             0.22831342724773274`, 0.3573022663177088, 0.9363134839710866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.08365695714524007], {
             RGBColor[
             0.23972125787035842`, 0.36929261960032556`, 0.9369631430486721]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.08365695714524007], {
             RGBColor[
             0.8055364749096104, 0.8480104835941301, 0.9812520057187881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.08365695714524007], {
             RGBColor[
             0.18100426741029385`, 0.3075773397545796, 0.9336192973059745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.08365695714524007], {
             RGBColor[
             0.20793893985757575`, 0.3358873882535414, 0.9351531870555702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.08365695714524007], {
             RGBColor[
             0.18369802063003998`, 0.31040864518235156`, 0.9337727025667882]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.08365695714524007], {
             RGBColor[
             0.23112771995435683`, 0.3602602663888343, 0.9364737537773559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.08365695714524007], {
             RGBColor[
             0.20120879960667537`, 0.3288135841343073, 0.9347699155246316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.08365695714524007], {
             RGBColor[
             0.9889946602077696, 0.9897170234186503, 0.8320504914710569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.08365695714524007], {
             RGBColor[
             0.40260480881009003`, 0.5231377827104023, 0.9468746003012931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.08365695714524007], {
             RGBColor[
             0.9482538006021336, 0.8325505933258706, 0.2772219972063093]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.08365695714524007], {
             RGBColor[
             0.8037373305687819, 0.8466049783610714, 0.9810726838248541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.08365695714524007], {
             RGBColor[
             0.5183980864407423, 0.6198979459970778, 0.9552293428008269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.08365695714524007], {
             RGBColor[
             0.3482989604247025, 0.47610078633028297`, 0.9434142796629524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.08365695714524007], {
             RGBColor[
             0.19320352841391442`, 0.32039953654720643`, 0.9343140271729413]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.08365695714524007], {
             RGBColor[
             0.21627237251575757`, 0.34464635434743823`, 0.9356277637172448]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.08365695714524007], {
             RGBColor[
             0.7070237961498369, 0.7710516302229059, 0.9714331825533382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.08365695714524007], {
             RGBColor[
             0.21726621743653565`, 0.3456909483725835, 0.9356843617152213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.08365695714524007], {
             RGBColor[
             0.9918038536315829, 0.990878697092375, 0.7854948864789351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.08365695714524007], {
             RGBColor[
             0.18932442036239164`, 0.31632234803540016`, 0.9340931177080333]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.08365695714524007], {
             RGBColor[
             0.9925852496598342, 0.986548923705669, 0.43432836788688456`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.08365695714524007], {
             RGBColor[
             0.3764941167365503, 0.5005220135978444, 0.9452108500911456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.08365695714524007], {
             RGBColor[
             0.19612721011213427`, 0.3234725113841618, 0.9344805265204555]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.08365695714524007], {
             RGBColor[
             0.17940647345367122`, 0.30589795700018124`, 0.9335283053038692]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.08365695714524007], {
             RGBColor[
             0.8216043579673015, 0.8605890294596807, 0.9828465511894319]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.08365695714524007], {
             RGBColor[
             0.5728179374316162, 0.6640784326178184, 0.9595134728173111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.08365695714524007], {
             RGBColor[
             0.1969643686712329, 0.32435241810869275`, 0.934528201461931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.08365695714524007], {
             RGBColor[
             0.9697038754518477, 0.9769257804341147, 0.9361676157519565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.08365695714524007], {
             RGBColor[
             0.46553671991296847`, 0.576982707272407, 0.9510679023901947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.08365695714524007], {
             RGBColor[
             0.1985117660113969, 0.3259788308238631, 0.9346163234512842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.08365695714524007], {
             RGBColor[
             0.24853385159996577`, 0.37855521436085726`, 0.9374650072245091]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.08365695714524007], {
             RGBColor[
             0.18190969424137163`, 0.30852900076141915`, 0.9336708600245455]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.08365695714524007], {
             RGBColor[
             0.2829350020755027, 0.41471300466956446`, 0.9394241018521495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.08365695714524007], {
             RGBColor[
             0.1969521059625652, 0.3243395292243824, 0.9345275031188135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.08365695714524007], {
             RGBColor[
             0.22046571832082573`, 0.34905382666204504`, 0.9358665685573442]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.08365695714524007], {
             RGBColor[
             0.199051197909799, 0.3265458079510415, 0.9346470432998802]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.08365695714524007], {
             RGBColor[
             0.20310658273494972`, 0.3308082745285237, 0.9348779914662683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.08365695714524007], {
             RGBColor[
             0.22915597848204, 0.35818784108579943`, 0.9363614660174375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.08365695714524007], {
             RGBColor[
             0.7597586089991939, 0.8122484668202457, 0.9766892958633172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.08365695714524007], {
             RGBColor[
             0.9509849302078126, 0.9629652217205732, 0.9678539073672795]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.08365695714524007], {
             RGBColor[
             0.21428709115836797`, 0.3425596977667136, 0.935514704880902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.08365695714524007], {
             RGBColor[
             0.1818888062976524, 0.30850704620819813`, 0.9336696704870515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.08365695714524007], {
             RGBColor[
             0.2680992625939086, 0.39911970183419715`, 0.9385792284361825]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.08365695714524007], {
             RGBColor[
             0.18684859723136407`, 0.31372010094843716`, 0.9339521232433733]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.08365695714524007], {
             RGBColor[
             0.4303958842275222, 0.5472090154169172, 0.9486454230522088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.08365695714524007], {
             RGBColor[
             0.23222586891438338`, 0.3614144905724877, 0.9365362917360636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.08365695714524007], {
             RGBColor[
             0.21556902434658207`, 0.3439070908267852, 0.9355877090795206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.08365695714524007], {
             RGBColor[
             0.5925759149291727, 0.6801188488370776, 0.961068893181775]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.08365695714524007], {
             RGBColor[
             0.20437042968316516`, 0.3321366578036229, 0.9349499656802752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.08365695714524007], {
             RGBColor[
             0.3425287629814334, 0.47110293132347947`, 0.9430466077842526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.08365695714524007], {
             RGBColor[
             0.1791057270796212, 0.3055818534926332, 0.9335111782427814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.08365695714524007], {
             RGBColor[
             0.24723118250472642`, 0.37718602654776967`, 0.9373908221466615]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.08365695714524007], {
             RGBColor[
             0.21162927735784165`, 0.3397661669472325, 0.9353633463168451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.08365695714524007], {
             RGBColor[
             0.2986247548964671, 0.43120392967218313`, 0.9403176100643942]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.08365695714524007], {
             RGBColor[
             0.1932487717488401, 0.3204470901608064, 0.9343166037139339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.08365695714524007], {
             RGBColor[
             0.9021660914511284, 0.9248267689496842, 0.9905306012474278]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.08365695714524007], {
             RGBColor[
             0.387712192347488, 0.5102385468551641, 0.9459256559493198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.08365695714524007], {
             RGBColor[
             0.8539737461394735, 0.41587144104017043`, 0.19931862629877445`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.08365695714524007], {
             RGBColor[
             0.34903475823839447`, 0.4767380974142295, 0.9434611640490004]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.08365695714524007], {
             RGBColor[
             0.19478977051563845`, 0.3220667775696765, 0.9344043613139996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.08365695714524007], {
             RGBColor[
             0.22404918964109946`, 0.35282028222485723`, 0.936070641947763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.08365695714524007], {
             RGBColor[
             0.9853022906708313, 0.9881901337255575, 0.8932426102441758]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.08365695714524007], {
             RGBColor[
             0.1865190623784995, 0.31337373892436005`, 0.9339333567210057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.08365695714524007], {
             RGBColor[
             0.2230811340648649, 0.3518027944359661, 0.9360155126148064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.08365695714524007], {
             RGBColor[
             0.3063635945960659, 0.4393379408672382, 0.9407583255366989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.08365695714524007], {
             RGBColor[
             0.1827503081177702, 0.3094125392435122, 0.9337187317412295]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.08365695714524007], {
             RGBColor[
             0.8529626688242167, 0.8855932953383124, 0.985837534872859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.08365695714524007], {
             RGBColor[
             0.8266120846200963, 0.20555772064570646`, 0.17311706832724205`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.08365695714524007], {
             RGBColor[
             0.1804406002012431, 0.3069848897793021, 0.93358719729229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.08365695714524007], {
             RGBColor[
             0.1856485479005117, 0.3124587730141891, 0.9338837822092951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.08365695714524007], {
             RGBColor[
             0.18667779652152947`, 0.3135405785730105, 0.9339423963956253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.08365695714524007], {
             RGBColor[
             0.9551078718556497, 0.8597247018622127, 0.2827369438226184]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.08365695714524007], {
             RGBColor[
             0.24002120291967022`, 0.3696078808647668, 0.9369802244755014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.08365695714524007], {
             RGBColor[
             0.5585316039927765, 0.6524801435401812, 0.9583888003164419]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.08365695714524007], {
             RGBColor[
             0.3574473894517768, 0.48402469574012214`, 0.9439972094709195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.08365695714524007], {
             RGBColor[
             0.2397898236287226, 0.36936468655968646`, 0.936967047767177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.08365695714524007], {
             RGBColor[
             0.41254771032069193`, 0.531749824254125, 0.9475081531933861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.08365695714524007], {
             RGBColor[
             0.24372417422141443`, 0.37349993848484087`, 0.9371911032130806]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.08365695714524007], {
             RGBColor[
             0.18936604401309215`, 0.31636609713137825`, 0.934095488113364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.08365695714524007], {
             RGBColor[
             0.843157812611701, 0.33273543637341757`, 0.18896127613772973`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.08365695714524007], {
             RGBColor[
             0.22661866237074535`, 0.3555209609776956, 0.9362169696185221]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.08365695714524007], {
             RGBColor[
             0.1925981967986741, 0.3197632946393477, 0.9342795544329613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.08365695714524007], {
             RGBColor[
             0.18255935854789945`, 0.309211839138676, 0.9337078574457099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.08365695714524007], {
             RGBColor[
             0.3393687513351076, 0.46836588806223545`, 0.9428452546364373]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.08365695714524007], {
             RGBColor[
             0.3039019362504366, 0.4367505818678281, 0.9406181377356125]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.08365695714524007], {
             RGBColor[
             0.8193361618613183, 0.1496317899920564, 0.1661496364764569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.08365695714524007], {
             RGBColor[
             0.21566341381177923`, 0.3440063001393452, 0.9355930844199268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.08365695714524007], {
             RGBColor[
             0.8141109072907318, 0.8547088953383618, 0.982106625005912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.08365695714524007], {
             RGBColor[
             0.19287402797566439`, 0.32005321069507126`, 0.9342952626104353]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.08365695714524007], {
             RGBColor[
             0.18340497994045135`, 0.3101006408377411, 0.933756014333031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.08365695714524007], {
             RGBColor[
             0.17911500115561352`, 0.3055916011345115, 0.9335117063876894]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.08365695714524007], {
             RGBColor[
             0.335355251737071, 0.46488959643477135`, 0.9425895179910487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.08365695714524007], {
             RGBColor[
             0.18263620644148504`, 0.30929261114727236`, 0.9337122338195634]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.08365695714524007], {
             RGBColor[
             0.29264465833089975`, 0.42491846902175034`, 0.9399770524117451]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.08365695714524007], {
             RGBColor[
             0.2889051941793347, 0.4209880551027343, 0.939764095460355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.08365695714524007], {
             RGBColor[
             0.30694355404168716`, 0.4399475150161388, 0.940791353369154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.08365695714524007], {
             RGBColor[
             0.4063466574019441, 0.5263787838898877, 0.9471130275847793]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.08365695714524007], {
             RGBColor[
             0.3557668224000087, 0.48256907302763663`, 0.9438901252244479]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.08365695714524007], {
             RGBColor[
             0.4741596199861951, 0.5839831660090739, 0.9517467286706829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.08365695714524007], {
             RGBColor[
             0.19890345919190142`, 0.32639052519135536`, 0.9346386297984558]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.08365695714524007], {
             RGBColor[
             0.5812572311839399, 0.6709298314718057, 0.9601778449356456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.08365695714524007], {
             RGBColor[
             0.24987309085249598`, 0.3799628397279394, 0.9375412749187138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.08365695714524007], {
             RGBColor[
             0.1991293041825628, 0.32662790259593993`, 0.9346514913365662]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.08365695714524007], {
             RGBColor[
             0.24721508689536167`, 0.3771691090418067, 0.9373899055255195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.08365695714524007], {
             RGBColor[
             0.25655300447979307`, 0.38698385248121464`, 0.9379216861177417]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.08365695714524007], {
             RGBColor[
             0.21032620428650672`, 0.3383965545296549, 0.9352891382331565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.08365695714524007], {
             RGBColor[
             0.23840666361665402`, 0.3679108976895925, 0.9368882788506916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.08365695714524007], {
             RGBColor[
             0.20761230953904478`, 0.335544079079207, 0.935134585942136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.08365695714524007], {
             RGBColor[
             0.2008438754397465, 0.3284300256973365, 0.9347491336331819]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.08365695714524007], {
             RGBColor[
             0.20565135384863537`, 0.33348299031681494`, 0.9350229124165412]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.08365695714524007], {
             RGBColor[
             0.18637271886218407`, 0.3132199226099977, 0.9339250226742475]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.08365695714524007], {
             RGBColor[
             0.1858996679095085, 0.31272271606557295`, 0.9338980831223087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.08365695714524007], {
             RGBColor[
             0.20187169700218524`, 0.3295103313271106, 0.9348076665506371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.08365695714524007], {
             RGBColor[
             0.24686136029389427`, 0.3767973199561026, 0.9373697613188575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.08365695714524007], {
             RGBColor[
             0.1911403477299942, 0.3182310028351955, 0.9341965320851944]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.08365695714524007], {
             RGBColor[
             0.18214142158537838`, 0.30877256089233246`, 0.9336840565539767]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.08365695714524007], {
             RGBColor[
             0.19529547244710238`, 0.32259830236299947`, 0.9344331602908775]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.08365695714524007], {
             RGBColor[
             0.8795463410175769, 0.5459298918751729, 0.22120285316675511`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.08365695714524007], {
             RGBColor[
             0.19529691214488243`, 0.32259981557664835`, 0.9344332422795363]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.08365695714524007], {
             RGBColor[
             0.17905422337022397`, 0.30552771982853294`, 0.9335082451827241]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.08365695714524007], {
             RGBColor[
             0.21499276582137244`, 0.3433014065798891, 0.935554892009008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.08365695714524007], {
             RGBColor[
             0.22554056397195027`, 0.35438781120517543`, 0.9361555735096144]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.08365695714524007], {
             RGBColor[
             0.2451744333338886, 0.3750242527637898, 0.93727369332407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.08365695714524007], {
             RGBColor[
             0.2358064817309028, 0.3651779416666145, 0.9367402023389224]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.08365695714524007], {
             RGBColor[
             0.19796437105250972`, 0.32540348401522773`, 0.9345851501181738]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.08365695714524007], {
             RGBColor[
             0.45725872125089195`, 0.5702622550389433, 0.9504162280122078]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.08365695714524007], {
             RGBColor[
             0.23550398192177388`, 0.3648599951876243, 0.9367229754223009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.08365695714524007], {
             RGBColor[
             0.18805335571358273`, 0.3149863784993486, 0.9340207324566552]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.08365695714524007], {
             RGBColor[
             0.3796233347917912, 0.5032323849982215, 0.9454102410985666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.08365695714524007], {
             RGBColor[
             0.17959143492855675`, 0.30609236323752076`, 0.933538838586238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.08365695714524007], {
             RGBColor[
             0.41783566912403936`, 0.5363299883890472, 0.947845097252377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.08365695714524007], {
             RGBColor[
             0.19013667027984396`, 0.3171760741982618, 0.9341393741392161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.08365695714524007], {
             RGBColor[
             0.18620451936940718`, 0.3130431342786254, 0.9339154439619627]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.08365695714524007], {
             RGBColor[
             0.18139651046953492`, 0.3079896120794884, 0.9336416349679267]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.08365695714524007], {
             RGBColor[
             0.18300767959384703`, 0.309683052983163, 0.9337333886660452]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.08365695714524007], {
             RGBColor[
             0.2268131918331927, 0.35572542377660804`, 0.9362280477836279]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.08365695714524007], {
             RGBColor[
             0.18842432755960442`, 0.31537629343049095`, 0.9340418587544824]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.08365695714524007], {
             RGBColor[
             0.19212227783830665`, 0.31926307363699663`, 0.9342524515522274]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.08365695714524007], {
             RGBColor[
             0.24182762690147153`, 0.3715065470035356, 0.9370830976489003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.08365695714524007], {
             RGBColor[
             0.18868393066647376`, 0.3156491527555983, 0.9340566427673703]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.08365695714524007], {
             RGBColor[
             0.21355297767290998`, 0.3417880979480139, 0.9354728982039288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.08365695714524007], {
             RGBColor[
             0.19254963929720473`, 0.31971225762658, 0.9342767891550869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.08365695714524007], {
             RGBColor[
             0.2065811071166083, 0.33446021995121644`, 0.9350758604897056]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.08365695714524007], {
             RGBColor[
             0.21634716160662554`, 0.34472496242384276`, 0.9356320228453292]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.08365695714524007], {
             RGBColor[
             0.27580922111776024`, 0.4072233570823697, 0.9390182991682543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.08365695714524007], {
             RGBColor[
             0.2331737072204319, 0.36241072872856434`, 0.9365902697253919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.08365695714524007], {
             RGBColor[
             0.2121526703486752, 0.34031628616563087`, 0.9353931527733826]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.08365695714524007], {
             RGBColor[
             0.1840091371887301, 0.310735648411464, 0.9337904201945499]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.08365695714524007], {
             RGBColor[
             0.2582664433427927, 0.3887847853645258, 0.938019263926184]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.08365695714524007], {
             RGBColor[
             0.8379281346647119, 0.8736051659010814, 0.9844035275832383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.08365695714524007], {
             RGBColor[
             0.4554399226734993, 0.5687856724178738, 0.9502730455257168]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.08365695714524007], {
             RGBColor[
             0.42461827381123246`, 0.5422047396654701, 0.9482772788254231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.08365695714524007], {
             RGBColor[
             0.844124603334554, 0.8785460618197521, 0.9849945522966208]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.08365695714524007], {
             RGBColor[
             0.19131157595015044`, 0.3184109745510759, 0.9342062832790229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.08365695714524007], {
             RGBColor[
             0.8287975688378628, 0.8663247005533589, 0.9835326460637211]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.08365695714524007], {
             RGBColor[
             0.9887357523774989, 0.9896099583772056, 0.8363412642506296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.08365695714524007], {
             RGBColor[
             0.19404714705117995`, 0.3212862332234835, 0.9343620700063117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.08365695714524007], {
             RGBColor[
             0.6657140642559093, 0.738780153701779, 0.9673158145395446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.08365695714524007], {
             RGBColor[
             0.3275914997751332, 0.4581650247028605, 0.9420948185812503]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.08365695714524007], {
             RGBColor[
             0.3100095560527289, 0.44293642874469996`, 0.9409745126743612]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.08365695714524007], {
             RGBColor[
             0.17994083687002446`, 0.30645960683136597`, 0.9335587365099107]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.08365695714524007], {
             RGBColor[
             0.18515378626434187`, 0.3119387471648751, 0.9338556062660495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.08365695714524007], {
             RGBColor[
             0.4288884024290853, 0.5459033104513494, 0.9485493676450263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.08365695714524007], {
             RGBColor[
             0.1915172466480543, 0.31862714749484833`, 0.934217995921006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.08365695714524007], {
             RGBColor[
             0.2944180010032382, 0.4267823646067975, 0.9400780416535094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.08365695714524007], {
             RGBColor[
             0.2650455441851616, 0.3959100501696741, 0.9384053236903759]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.08365695714524007], {
             RGBColor[
             0.2456807114445148, 0.37555638315794415`, 0.9373025251134988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.08365695714524007], {
             RGBColor[
             0.23248905082520588`, 0.3616911114474591, 0.9365512795565422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.08365695714524007], {
             RGBColor[
             0.5777795176543054, 0.6681064669592394, 0.9599040665873084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.08365695714524007], {
             RGBColor[
             0.3254133616442444, 0.45627843093029025`, 0.9419560295456021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.08365695714524007], {
             RGBColor[
             0.8789213821202363, 0.5430920994852084, 0.22068137214366979`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.08365695714524007], {
             RGBColor[
             0.7060709713767632, 0.7703072762684443, 0.9713382138846121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.08365695714524007], {
             RGBColor[
             0.21581639795358076`, 0.3441670961721334, 0.9356017966404827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.08365695714524007], {
             RGBColor[
             0.2082469591636211, 0.3362111360737471, 0.9351707282993756]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.08365695714524007], {
             RGBColor[
             0.5602763464580424, 0.6538966040732364, 0.9585261528345099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.08365695714524007], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.08365695714524007], {
             RGBColor[
             0.17970434930417156`, 0.30621104340547683`, 0.9335452688928874]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.08365695714524007], {
             RGBColor[
             0.36991176607450643`, 0.49482071229294583`, 0.9447914285275043]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.08365695714524007], {
             RGBColor[
             0.9510874915293103, 0.9630417117862173, 0.9676802978022608]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.08365695714524007], {
             RGBColor[
             0.8592163258347785, 0.4536160411257659, 0.20423899016395516`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.08365695714524007], {
             RGBColor[
             0.4977475489543879, 0.6031329093695432, 0.9536036568444898]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.08365695714524007], {
             RGBColor[
             0.2084820527788493, 0.336458234369148, 0.9351841165329731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.08365695714524007], {
             RGBColor[
             0.19190461331519068`, 0.3190342944224739, 0.9342400558796418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.08365695714524007], {
             RGBColor[
             0.2739918424465178, 0.40531317687043084`, 0.9389148021414978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.08365695714524007], {
             RGBColor[
             0.22400797509009437`, 0.3527769631185974, 0.9360682948400547]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.08365695714524007], {
             RGBColor[
             0.19792175174780763`, 0.3253586884237658, 0.9345827230118207]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.08365695714524007], {
             RGBColor[
             0.2211253737681676, 0.3497471663617724, 0.9359041349591976]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.08365695714524007], {
             RGBColor[
             0.19120668731506069`, 0.31830072994527303`, 0.9342003100264233]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.08365695714524007], {
             RGBColor[
             0.19035994618760685`, 0.3174107513338308, 0.934152089371856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.08365695714524007], {
             RGBColor[
             0.9703310152107799, 0.9773935002394792, 0.9351060317243296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.08365695714524007], {
             RGBColor[
             0.24693624036742998`, 0.3768760236610595, 0.9373740256282702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.08365695714524007], {
             RGBColor[
             0.19324911536591247`, 0.3204474513241361, 0.9343166232824178]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.08365695714524007], {
             RGBColor[
             0.5096359477486948, 0.612784447077024, 0.9545395551462174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.08365695714524007], {
             RGBColor[
             0.18222514168352894`, 0.3088605560236495, 0.9336888242897137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.08365695714524007], {
             RGBColor[
             0.20088219976865415`, 0.32847030699692126`, 0.9347513161470175]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.08365695714524007], {
             RGBColor[
             0.5071373117219987, 0.6107559417882819, 0.9543428533653905]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.08365695714524007], {
             RGBColor[
             0.17933281357579656`, 0.305820535798229, 0.9335241104827943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.08365695714524007], {
             RGBColor[
             0.28091140737960196`, 0.41258607834085864`, 0.939308861127858]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.08365695714524007], {
             RGBColor[
             0.3403985574835718, 0.4692578543884732, 0.9429108729735957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.08365695714524007], {
             RGBColor[
             0.23139395253121084`, 0.36054009370722817`, 0.9364889153287519]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.08365695714524007], {
             RGBColor[
             0.18235944175044905`, 0.3090017139090986, 0.9336964724798456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.08365695714524007], {
             RGBColor[
             0.19489410730752896`, 0.3221764421532881, 0.9344103031399453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.08365695714524007], {
             RGBColor[
             0.2167015948028579, 0.34509749418544555`, 0.9356522072915177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.08365695714524007], {
             RGBColor[
             0.8173387448883187, 0.1342787678638822, 0.16423690772735258`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.08365695714524007], {
             RGBColor[
             0.1829127869860106, 0.3095833148357881, 0.9337279846724099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.08365695714524007], {
             RGBColor[
             0.18362197162651986`, 0.31032871285786656`, 0.9337683716885422]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.08365695714524007], {
             RGBColor[
             0.19372013073248498`, 0.3209425183385029, 0.9343434469107393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.08365695714524007], {
             RGBColor[
             0.1849258667142184, 0.3116991892667612, 0.9338426265848467]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.08365695714524007], {
             RGBColor[
             0.20594129701488287`, 0.33378773896799957`, 0.9350394242509266]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.08365695714524007], {
             RGBColor[
             0.8251923969012658, 0.19464537872765014`, 0.17175757376438203`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.08365695714524007], {
             RGBColor[
             0.1870776850955973, 0.3139608868187558, 0.9339651694583363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.08365695714524007], {
             RGBColor[
             0.37418878878290995`, 0.4985252543935531, 0.9450639566324611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.08365695714524007], {
             RGBColor[
             0.9923039511135691, 0.9910855002530954, 0.777206976991627]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.08365695714524007], {
             RGBColor[
             0.9694202648664492, 0.9767142641238943, 0.9366476944955487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.08365695714524007], {
             RGBColor[
             0.23765262088408304`, 0.3671183509685898, 0.9368453372325779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.08365695714524007], {
             RGBColor[
             0.8954246210317355, 0.9194513034296, 0.9898875937806444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.08365695714524007], {
             RGBColor[
             0.1889310324973132, 0.31590887244697147`, 0.9340707148510822]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.08365695714524007], {
             RGBColor[
             0.18920356017618423`, 0.31619531631671777`, 0.9340862348992254]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.08365695714524007], {
             RGBColor[
             0.36433321534571095`, 0.4899888520377754, 0.9444359682079841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.08365695714524007], {
             RGBColor[
             0.30183205672017543`, 0.43457500724358145`, 0.9405002611584765]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.08365695714524007], {
             RGBColor[
             0.2599789274537134, 0.39058471474286727`, 0.9381167873629076]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.08365695714524007], {
             RGBColor[
             0.19899652547638796`, 0.32648834375709396`, 0.934643929785678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.08365695714524007], {
             RGBColor[
             0.6582217134144572, 0.7329270722804612, 0.9665690470276681]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.08365695714524007], {
             RGBColor[
             0.19756403157199334`, 0.32498270183821587`, 0.9345623513770076]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.08365695714524007], {
             RGBColor[
             0.187660141527025, 0.31457308545805707`, 0.933998339490439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.08365695714524007], {
             RGBColor[
             0.3534033382914345, 0.480521941884955, 0.9437395261069965]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.08365695714524007], {
             RGBColor[
             0.20794500379241626`, 0.3358937618335345, 0.9351535323876885]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.08365695714524007], {
             RGBColor[
             0.8200027527924696, 0.15475549999089333`, 0.1667879647049341]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.08365695714524007], {
             RGBColor[
             0.19665135271400355`, 0.3240234184912868, 0.9345103756662324]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.08365695714524007], {
             RGBColor[
             0.5240458703783706, 0.6244830714274116, 0.9556739570409113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.08365695714524007], {
             RGBColor[
             0.20313982636998706`, 0.33084321569671615`, 0.9348798846421041]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.08365695714524007], {
             RGBColor[
             0.194144227344503, 0.3213882707670121, 0.934367598585399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.08365695714524007], {
             RGBColor[
             0.37904525788294496`, 0.5027316838347692, 0.9453734065491083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.08365695714524007], {
             RGBColor[
             0.1851145385676597, 0.3118974953472144, 0.9338533711677852]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.08365695714524007], {
             RGBColor[
             0.1880939032775767, 0.3150289965599703, 0.9340230415804399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.08365695714524007], {
             RGBColor[
             0.1990369147875074, 0.3265307954839108, 0.9346462298971957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.08365695714524007], {
             RGBColor[
             0.2089289786028837, 0.3369279817469421, 0.9352095682974844]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.08365695714524007], {
             RGBColor[
             0.39875120665503094`, 0.5197999862113661, 0.9466290521795794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.08365695714524007], {
             RGBColor[
             0.31502354175322494`, 0.44727929114822085`, 0.9412939994095033]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.08365695714524007], {
             RGBColor[
             0.9319225428018962, 0.7678025982169813, 0.26408148383634866`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.08365695714524007], {
             RGBColor[
             0.7398648594018855, 0.7967073184367315, 0.9747064728211174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.08365695714524007], {
             RGBColor[
             0.18427610046840573`, 0.31101624374485265`, 0.9338056233583907]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.08365695714524007], {
             RGBColor[
             0.3212434064694567, 0.45266662534593033`, 0.9416903236892111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.08365695714524007], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.08365695714524007], {
             RGBColor[
             0.2137339467700851, 0.34197830794324846`, 0.935483204126293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.08365695714524007], {
             RGBColor[
             0.4742143938317012, 0.5840276338843894, 0.9517510406684443]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.08365695714524007], {
             RGBColor[
             0.25752973177491306`, 0.38801045479647306`, 0.9379773092922603]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.08365695714524007], {
             RGBColor[
             0.1954605501868454, 0.3227718095340026, 0.9344425612239453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.08365695714524007], {
             RGBColor[
             0.8194918846006688, 0.15082874320484374`, 0.1662987567475226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.08365695714524007], {
             RGBColor[
             0.3141297509318431, 0.44650513446197276`, 0.941237047848713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.08365695714524007], {
             RGBColor[
             0.20973292712492791`, 0.3377729826168909, 0.9352553519764795]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.08365695714524007], {
             RGBColor[
             0.18590102371033476`, 0.3127241410982041, 0.9338981603331601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.08365695714524007], {
             RGBColor[
             0.17907641669607907`, 0.3055510464211448, 0.9335095090597996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.08365695714524007], {
             RGBColor[
             0.2965600408339725, 0.42903378428206873`, 0.9402000276530058]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.08365695714524007], {
             RGBColor[
             0.20546571259734456`, 0.33328786959137313`, 0.9350123404219118]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.08365695714524007], {
             RGBColor[
             0.18838969891108812`, 0.3153398965253172, 0.9340398867041779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.08365695714524007], {
             RGBColor[
             0.19616100168040002`, 0.3235080284649182, 0.934482450900278]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.08365695714524007], {
             RGBColor[
             0.24986810421890843`, 0.3799575984598681, 0.937540990937308]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.08365695714524007], {
             RGBColor[
             0.19470143524485908`, 0.32197393159930776`, 0.9343993307510091]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.08365695714524007], {
             RGBColor[
             0.8939300581111314, 0.611242991794526, 0.23320497928678602`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.08365695714524007], {
             RGBColor[
             0.2822705085644714, 0.4140145798581486, 0.9393862599297264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.08365695714524007], {
             RGBColor[
             0.29805944165302733`, 0.4306097496103981, 0.9402854163114862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.08365695714524007], {
             RGBColor[
             0.22229995450050422`, 0.350981725184178, 0.9359710255942676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.08365695714524007], {
             RGBColor[
             0.17902996710188124`, 0.3055022249525685, 0.933506863824126]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.08365695714524007], {
             RGBColor[
             0.212847764567014, 0.3410468742606238, 0.9354327373608172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.08365695714524007], {
             RGBColor[
             0.6973666945960665, 0.7635074290924103, 0.9704706529212034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.08365695714524007], {
             RGBColor[
             0.8265166883216026, 0.20482446289255998`, 0.17302571672406986`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.08365695714524007], {
             RGBColor[
             0.2025961788233211, 0.3302718076559249, 0.934848924718576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.08365695714524007], {
             RGBColor[
             0.5478165382686445, 0.6437811704771209, 0.9575452710920592]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.08365695714524007], {
             RGBColor[
             0.28461757525764775`, 0.41648149576530025`, 0.9395199219057286]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.08365695714524007], {
             RGBColor[
             0.18275376889499648`, 0.30941617673980293`, 0.9337189288273728]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.08365695714524007], {
             RGBColor[
             0.1811098371299533, 0.3076883002234485, 0.9336253093453327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.08365695714524007], {
             RGBColor[
             0.7121412574025138, 0.7750494298476431, 0.9719432432656107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.08365695714524007], {
             RGBColor[
             0.18850413369751906`, 0.3154601747414406, 0.9340464035959741]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.08365695714524007], {
             RGBColor[
             0.21345649486519924`, 0.3416866883997466, 0.9354674036507632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.08365695714524007], {
             RGBColor[
             0.8324443832728455, 0.2503873238203034, 0.17870208410375396`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.08365695714524007], {
             RGBColor[
             0.18370800885926494`, 0.3104191434445573, 0.9337732713816664]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.08365695714524007], {
             RGBColor[
             0.18455342051778426`, 0.3113077246998561, 0.9338214163249446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.08365695714524007], {
             RGBColor[
             0.1951112049063669, 0.3224046254944496, 0.9344226665270321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.08365695714524007], {
             RGBColor[
             0.42062186552277797`, 0.5387432516713317, 0.9480226312231679]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.08365695714524007], {
             RGBColor[
             0.1856877903127057, 0.31250001927751764`, 0.9338860170066157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.08365695714524007], {
             RGBColor[
             0.23827199083861747`, 0.36776934806112876`, 0.9368806094352129]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.08365695714524007], {
             RGBColor[
             0.24157157412247404`, 0.37123741929812537`, 0.9370685158219325]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.08365695714524007], {
             RGBColor[
             0.18576331458524015`, 0.3125794000764668, 0.9338903180022083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.08365695714524007], {
             RGBColor[
             0.2313516506730186, 0.3604956317721754, 0.9364865063005079]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.08365695714524007], {
             RGBColor[
             0.2623389378177228, 0.3930652352687406, 0.9382511864618155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.08365695714524007], {
             RGBColor[
             0.18870039039885345`, 0.3156664529779366, 0.9340575801247794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.08365695714524007], {
             RGBColor[
             0.24096885499463874`, 0.3706039232801706, 0.9370341918592453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.08365695714524007], {
             RGBColor[
             0.8178049183525352, 0.13786198138836525`, 0.164683315963154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.08365695714524007], {
             RGBColor[
             0.9537765326908467, 0.9650471942815904, 0.9631284525300384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.08365695714524007], {
             RGBColor[
             0.9602115875305376, 0.8774464833562946, 0.2999299602777051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.08365695714524007], {
             RGBColor[
             0.1982643030525542, 0.3257187315640616, 0.9346022308018668]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.08365695714524007], {
             RGBColor[
             0.23480104226620413`, 0.36412116104067216`, 0.9366829440488222]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.08365695714524007], {
             RGBColor[
             0.956979221732861, 0.9674357545252026, 0.9577071353769899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.08365695714524007], {
             RGBColor[
             0.21013611726343454`, 0.33819676101619267`, 0.9352783130584011]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.08365695714524007], {
             RGBColor[
             0.38195753878243316`, 0.5052541551744117, 0.9455589745127948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.08365695714524007], {
             RGBColor[
             0.27139200070452485`, 0.4025805783601091, 0.9387667450004126]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.08365695714524007], {
             RGBColor[
             0.24934350578881678`, 0.3794062122483802, 0.9375111158327881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.08365695714524007], {
             RGBColor[
             0.18639411010760892`, 0.31324240616522253`, 0.9339262408740289]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.08365695714524007], {
             RGBColor[
             0.20071986914810575`, 0.3282996872223691, 0.9347420716583239]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.08365695714524007], {
             RGBColor[
             0.1915625031716876, 0.3186747149706162, 0.9342205732130758]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.08365695714524007], {
             RGBColor[
             0.8280837295399454, 0.865755504473851, 0.9834645594342339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.08365695714524007], {
             RGBColor[
             0.20342618893072584`, 0.3311442009044876, 0.9348961925663027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.08365695714524007], {
             RGBColor[
             0.18432439621433888`, 0.3110670056359555, 0.9338083737296745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.08365695714524007], {
             RGBColor[
             0.20110409825488346`, 0.3287035363751249, 0.9347639529375389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.08365695714524007], {
             RGBColor[
             0.19841472542917707`, 0.32587683501922177`, 0.9346107971336854]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.08365695714524007], {
             RGBColor[
             0.3485452682138572, 0.4763141257574593, 0.943429974177476]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.08365695714524007], {
             RGBColor[
             0.3095548228305918, 0.44254256168324113`, 0.9409455374755513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.08365695714524007], {
             RGBColor[
             0.18638553952238943`, 0.3132333979367503, 0.9339257527918797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.08365695714524007], {
             RGBColor[
             0.9932598001133134, 0.9879917189181485, 0.507749021905247]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.08365695714524007], {
             RGBColor[
             0.19610120868731518`, 0.3234451822380914, 0.9344790457777777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.08365695714524007], {
             RGBColor[
             0.2081404760074813, 0.3360992155252221, 0.9351646642411613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.08365695714524007], {
             RGBColor[
             0.9453835605713274, 0.9587877294170835, 0.9773355650906732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.08365695714524007], {
             RGBColor[
             0.18600360463112436`, 0.31283196014996, 0.9339040021648441]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.08365695714524007], {
             RGBColor[
             0.2775970966062373, 0.4091025275786123, 0.9391201160323983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.08365695714524007], {
             RGBColor[
             0.32568965645452963`, 0.4565177436079784, 0.9419736348065956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.08365695714524007], {
             RGBColor[
             0.6627555094400547, 0.736468908193784, 0.9670209334447669]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.08365695714524007], {
             RGBColor[
             0.40957405763887067`, 0.529174195761261, 0.9473186746739982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.08365695714524007], {
             RGBColor[
             0.7912709059084366, 0.8368661126680731, 0.979830147120073]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.08365695714524007], {
             RGBColor[
             0.3745258073527012, 0.4988171629396605, 0.9450854311577144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.08365695714524007], {
             RGBColor[
             0.92133834354613, 0.7258397751431882, 0.2555651886720716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.08365695714524007], {
             RGBColor[
             0.30601698137869693`, 0.43897362839923615`, 0.940738586426738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.08365695714524007], {
             RGBColor[
             0.9933000584574108, 0.9880778274454297, 0.5121308942145434]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.08365695714524007], {
             RGBColor[
             0.1860930553658944, 0.31292597854370746`, 0.9339090962518588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.08365695714524007], {
             RGBColor[
             0.1838330998850932, 0.3105506220439319, 0.9337803951305317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.08365695714524007], {
             RGBColor[
             0.1804054273287139, 0.30694792086018496`, 0.933585194249233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.08365695714524007], {
             RGBColor[
             0.18554668841356567`, 0.31235171223514435`, 0.9338779814622011]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.08365695714524007], {
             RGBColor[
             0.18003320207443918`, 0.306556688517498, 0.93356399657166]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.08365695714524007], {
             RGBColor[
             0.179946795179367, 0.3064658693922636, 0.9335590758268132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.08365695714524007], {
             RGBColor[
             0.19798515205544082`, 0.3254253261669, 0.934586333565548]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.08365695714524007], {
             RGBColor[
             0.1836365577609456, 0.3103440438099624, 0.9337692023473195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.08365695714524007], {
             RGBColor[
             0.20279567675606608`, 0.3304814926321394, 0.9348602858307151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.08365695714524007], {
             RGBColor[
             0.28617898913701123`, 0.4181226407518692, 0.9396088421162536]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.08365695714524007], {
             RGBColor[
             0.25469411239970985`, 0.38503003904448196`, 0.9378158249637654]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.08365695714524007], {
             RGBColor[
             0.24023703411797065`, 0.3698347331386689, 0.9369925157429511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.08365695714524007], {
             RGBColor[
             0.18246816409549027`, 0.30911598798713175`, 0.9337026640565553]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.08365695714524007], {
             RGBColor[
             0.7203821791624184, 0.7814873005598058, 0.9727646213308456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.08365695714524007], {
             RGBColor[
             0.1893487791980019, 0.3163479507160659, 0.9340945049076855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.08365695714524007], {
             RGBColor[
             0.3220959675484921, 0.453405070901625, 0.9417446481272771]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.08365695714524007], {
             RGBColor[
             0.3583175561905998, 0.4847783904334387, 0.944052655726059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.08365695714524007], {
             RGBColor[
             0.9335847383251342, 0.7743926495727972, 0.2654189253710895]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.08365695714524007], {
             RGBColor[
             0.9944175835604394, 0.9904681006416884, 0.633766605113725]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.08365695714524007], {
             RGBColor[
             0.3419268933615933, 0.4705816221096207, 0.9430082571842888]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.08365695714524007], {
             RGBColor[
             0.18554205504628538`, 0.3123468422723603, 0.933877717598789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.08365695714524007], {
             RGBColor[
             0.2707814877613013, 0.40193889054802484`, 0.938731977191469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.08365695714524007], {
             RGBColor[
             0.9931232770303468, 0.9876997098482838, 0.4928893268471293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.08365695714524007], {
             RGBColor[
             0.21298290042549683`, 0.3411889106159976, 0.9354404331480423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.08365695714524007], {
             RGBColor[
             0.8202342132018924, 0.1565346061243149, 0.16700961145439447`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.08365695714524007], {
             RGBColor[
             0.2030621295519029, 0.3307615514146469, 0.9348754599232564]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.08365695714524007], {
             RGBColor[
             0.7219717591850786, 0.7827290925547635, 0.9729230558120345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.08365695714524007], {
             RGBColor[
             0.35762511408731845`, 0.48417863188672844`, 0.9440085339275405]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.08365695714524007], {
             RGBColor[
             0.4386808762090538, 0.554385059055515, 0.9491733354151413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.08365695714524007], {
             RGBColor[
             0.18439801323969868`, 0.31114438179719767`, 0.9338125661103621]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.08365695714524007], {
             RGBColor[
             0.36417957475425095`, 0.48985577627965343`, 0.9444261783653554]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.08365695714524007], {
             RGBColor[
             0.1808071689883251, 0.3073701768163288, 0.9336080728424244]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.08365695714524007], {
             RGBColor[
             0.3593758114062829, 0.48569499791180964`, 0.944120086812624]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.08365695714524007], {
             RGBColor[
             0.8221152183090297, 0.17099283563946593`, 0.16881086406928056`]},
             StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{{3.834946926643799*^9, 3.8349469478612347`*^9}, 
   3.834947050298876*^9, {3.8349471234738255`*^9, 3.8349471300172663`*^9}, {
   3.8349471617829676`*^9, 3.834947218900016*^9}, {3.8349472753220577`*^9, 
   3.834947307624898*^9}, 3.83494993428115*^9, 3.8349573375769677`*^9, {
   3.8349587473655295`*^9, 3.83495875945916*^9}, 3.8350239046836166`*^9, 
   3.835051791746958*^9},
 Background->RGBColor[1, 1, 0.85],
 CellLabel->
  "Out[403]=",ExpressionUUID->"e65f485c-8757-4dd0-b3d4-1f07b90597e1"]
}, Open  ]],

Cell["Estimated with cubic Mean Deviation v Calculated: (r=6)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 
  3.834950339812094*^9}},ExpressionUUID->"6d849e8f-3978-43de-b9f6-\
e4e8db036904"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraphb", "[", 
     RowBox[{"graphin4", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsi4", ",", "#"}], "}"}], "]"}], ",", "500", ",", "3"}], 
     "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"CMDi6400", ",", "kri4"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.834950273560528*^9, 3.834950273964845*^9}, {
   3.834957360267254*^9, 3.8349573712318316`*^9}, {3.8349587856645794`*^9, 
   3.83495878977224*^9}, 3.8350518336177673`*^9},
 CellLabel->
  "In[404]:=",ExpressionUUID->"444e4803-5f46-4d92-9d8c-298d46689565"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN3AuYzmXewPH7z7a1WxZbu0o1DqFsy5TT0CKyGGKYrMNM4zSN46CIkAnD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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[37, 104] -> 
             RGBColor[
              0.5074633549072057, 0.611020638334111, 0.9543685206792656], 
             UndirectedEdge[119, 243] -> 
             RGBColor[
              0.3929403500474366, 0.5122455933379033, 0.9466081104844992], 
             UndirectedEdge[165, 226] -> 
             RGBColor[
              0.5201004881057794, 0.6173526540420873, 0.9568042717613049], 
             UndirectedEdge[235, 261] -> 
             RGBColor[
              0.5402578684949684, 0.636177713744277, 0.9575106321074667], 
             UndirectedEdge[56, 198] -> 
             RGBColor[
              0.9440875247088709, 0.9578211479929273, 0.9795294157455225], 
             UndirectedEdge[50, 254] -> 
             RGBColor[
              0.39754942995034304`, 0.5187590676328189, 0.9465524760306461], 
             UndirectedEdge[249, 268] -> 
             RGBColor[
              0.4935259754258813, 0.5847355009237027, 0.9563937845837269], 
             UndirectedEdge[38, 224] -> 
             RGBColor[
              0.600430576605977, 0.6354813923938663, 0.6376339390805636], 
             UndirectedEdge[79, 87] -> 
             RGBColor[
              0.890687091238358, 0.9154221338055843, 0.9807128726438937], 
             UndirectedEdge[38, 311] -> 
             RGBColor[
              0.6758174274870191, 0.7079992879583412, 0.6421731046104537], 
             UndirectedEdge[37, 145] -> 
             RGBColor[
              0.5902684165046813, 0.6780877088343735, 0.9609951332121542], 
             UndirectedEdge[147, 359] -> 
             RGBColor[
              0.6230258343526802, 0.6924537551948402, 0.9381593941841619], 
             UndirectedEdge[192, 349] -> 
             RGBColor[
              0.6077404693212453, 0.6910588814799103, 0.963200223836727], 
             UndirectedEdge[213, 308] -> 
             RGBColor[
              0.34450751430437054`, 0.4728168262644744, 0.943172692068809], 
             UndirectedEdge[262, 397] -> 
             RGBColor[
              0.8628477223836091, 0.8916172754233075, 0.8869424034590108], 
             UndirectedEdge[129, 364] -> 
             RGBColor[
              0.382814725870239, 0.5034173436653971, 0.9458663110694199], 
             UndirectedEdge[54, 83] -> 
             RGBColor[
              0.3879071513784854, 0.5104074105688883, 0.9459380785663795], 
             UndirectedEdge[13, 277] -> 
             RGBColor[
              0.596988111496805, 0.679193463626426, 0.9637161875800178], 
             UndirectedEdge[191, 235] -> 
             RGBColor[
              0.41484354978821325`, 0.5337383650086451, 0.9476544420541254], 
             UndirectedEdge[54, 214] -> 
             RGBColor[
              0.35005510987190747`, 0.47762187471481427`, 0.9435261799528264],
              UndirectedEdge[87, 176] -> 
             RGBColor[
              0.8581507238662502, 0.889875681812901, 0.9775041297183713], 
             UndirectedEdge[16, 377] -> 
             RGBColor[
              0.8932125065428015, 0.8316376692083884, 0.6260016120133918], 
             UndirectedEdge[158, 344] -> 
             RGBColor[
              0.6631212488367811, 0.7219914815023081, 0.6794502634068778], 
             UndirectedEdge[95, 228] -> 
             RGBColor[
              0.6729695989694744, 0.7444482325641222, 0.9680389784329659], 
             UndirectedEdge[193, 283] -> 
             RGBColor[
              0.6115917215876749, 0.6887777594134783, 0.966043892680517], 
             UndirectedEdge[11, 366] -> 
             RGBColor[
              0.8492025098957938, 0.8822250191536154, 0.9431905136860603], 
             UndirectedEdge[106, 231] -> 
             RGBColor[
              0.6357414872407372, 0.6990632975667288, 0.7421680299892524], 
             UndirectedEdge[76, 388] -> 
             RGBColor[
              0.9246696166553969, 0.9422830450496367, 0.9757777095660993], 
             UndirectedEdge[208, 351] -> 
             RGBColor[
              0.8801089265707447, 0.9060296897573235, 0.9307346103333681], 
             UndirectedEdge[208, 225] -> 
             RGBColor[
              0.7595901889615557, 0.8102085830323431, 0.9198648685231443], 
             UndirectedEdge[163, 374] -> 
             RGBColor[
              0.9525752033708221, 0.9641512448417123, 0.9651619897119725], 
             UndirectedEdge[165, 288] -> 
             RGBColor[
              0.8278475170401725, 0.8660100427936661, 0.9647372670982686], 
             UndirectedEdge[110, 239] -> 
             RGBColor[
              0.28260533421469036`, 0.4143665028457011, 0.9394053277551762], 
             UndirectedEdge[14, 273] -> 
             RGBColor[
              0.5915327107038746, 0.6700047586270209, 0.9647217369403303], 
             UndirectedEdge[231, 372] -> 
             RGBColor[
              0.6863178748411317, 0.7457238786851372, 0.7452862190279546], 
             UndirectedEdge[5, 162] -> 
             RGBColor[
              0.6733451326066084, 0.7395397781205004, 0.9495008266618349], 
             UndirectedEdge[36, 90] -> 
             RGBColor[
              0.455013316577665, 0.5650782796448561, 0.9511681309662149], 
             UndirectedEdge[258, 328] -> 
             RGBColor[
              0.5536022715090078, 0.64847828936596, 0.9580007452065797], 
             UndirectedEdge[91, 208] -> 
             RGBColor[
              0.829567501519264, 0.8665463443780492, 0.925697113420707], 
             UndirectedEdge[155, 370] -> 
             RGBColor[
              0.6956295871685776, 0.758113141494779, 0.9402914955867476], 
             UndirectedEdge[66, 243] -> 
             RGBColor[
              0.47297922626150873`, 0.5830203264401486, 0.951655058932834], 
             UndirectedEdge[253, 334] -> 
             RGBColor[
              0.7646974999531782, 0.8163645845907532, 0.9773647771237788], 
             UndirectedEdge[50, 210] -> 
             RGBColor[
              0.6534233698361304, 0.7262235926717653, 0.9681507911097564], 
             UndirectedEdge[239, 365] -> 
             RGBColor[
              0.5020877744326655, 0.600786408308521, 0.9557649449323151], 
             UndirectedEdge[13, 51] -> 
             RGBColor[
              0.43866172394452935`, 0.5532454189387326, 0.9494824174943842], 
             UndirectedEdge[258, 300] -> 
             RGBColor[
              0.40867013998652846`, 0.5271184645459196, 0.9476127571506475], 
             UndirectedEdge[30, 294] -> 
             RGBColor[
              0.3825721093750682, 0.5057864653325361, 0.9455981344075142], 
             UndirectedEdge[31, 292] -> 
             RGBColor[
              0.4399683176796678, 0.5465352975631576, 0.9506643907353627], 
             UndirectedEdge[203, 216] -> 
             RGBColor[
              0.5777252229132731, 0.6642679480480751, 0.9617442683475177], 
             UndirectedEdge[64, 233] -> 
             RGBColor[
              0.6082899367384019, 0.6927569379321472, 0.9623874984290908], 
             UndirectedEdge[50, 242] -> 
             RGBColor[
              0.4884973324072086, 0.5953624169262343, 0.9529474918965744], 
             UndirectedEdge[133, 398] -> 
             RGBColor[
              0.5491813994334678, 0.6448892262570193, 0.9576527179626053], 
             UndirectedEdge[7, 390] -> 
             RGBColor[
              0.7704021314598075, 0.8202730158182536, 0.9603280635613775], 
             UndirectedEdge[186, 342] -> 
             RGBColor[
              0.9255265777370437, 0.9422817700736097, 0.9521241962089857], 
             UndirectedEdge[347, 398] -> 
             RGBColor[
              0.4162913661979919, 0.5245248873462758, 0.9490542713819746], 
             UndirectedEdge[321, 375] -> 
             RGBColor[
              0.6295885950472697, 0.7085363225928336, 0.965097850283146], 
             UndirectedEdge[149, 279] -> 
             RGBColor[
              0.5895318608031056, 0.6745056530473279, 0.9624917566453823], 
             UndirectedEdge[38, 306] -> 
             RGBColor[
              0.960259652820102, 0.9368343493066614, 0.6539206947672336], 
             UndirectedEdge[12, 358] -> 
             RGBColor[
              0.6574175349373357, 0.7274916013527879, 0.9694141803504278], 
             UndirectedEdge[139, 378] -> 
             RGBColor[
              0.918028591951158, 0.9366297919967966, 0.9627363508306582], 
             UndirectedEdge[272, 374] -> 
             RGBColor[
              0.7987381649020054, 0.8430896866214064, 0.9575217885887768], 
             UndirectedEdge[21, 114] -> 
             RGBColor[
              0.41588683462670195`, 0.5329277196152347, 0.9481945816493405], 
             UndirectedEdge[250, 321] -> 
             RGBColor[
              0.695890942018861, 0.7608289491814628, 0.9715744319372019], 
             UndirectedEdge[19, 152] -> 
             RGBColor[
              0.49585294168007454`, 0.5980491555255716, 0.9545403506780745], 
             UndirectedEdge[270, 336] -> 
             RGBColor[
              0.38891166795556065`, 0.5112774723394797, 0.9460020854744116], 
             UndirectedEdge[87, 277] -> 
             RGBColor[
              0.8783936723466259, 0.9056896270178771, 0.9795217576417862], 
             UndirectedEdge[37, 377] -> 
             RGBColor[
              0.7312651196657809, 0.703112486524928, 0.6111274248736991], 
             UndirectedEdge[312, 356] -> 
             RGBColor[
              0.4936268671324774, 0.5997875542319158, 0.9532792616769141], 
             UndirectedEdge[294, 343] -> 
             RGBColor[
              0.37102918579384825`, 0.49578856509069164`, 0.9448626295239253],
              UndirectedEdge[170, 349] -> 
             RGBColor[
              0.8347518304927056, 0.871734818111779, 0.9821842944263086], 
             UndirectedEdge[176, 390] -> 
             RGBColor[
              0.6780606265850355, 0.7475509318577891, 0.9691442708463163], 
             UndirectedEdge[235, 327] -> 
             RGBColor[
              0.48359799414898463`, 0.5905593160512626, 0.9527899130536368], 
             UndirectedEdge[271, 400] -> 
             RGBColor[
              0.7214046793047659, 0.779665300376649, 0.9342257889505337], 
             UndirectedEdge[45, 103] -> 
             RGBColor[
              0.27688620768218286`, 0.4022439956676993, 0.9393033981487997], 
             UndirectedEdge[30, 343] -> 
             RGBColor[
              0.4132216370420498, 0.5323335457076233, 0.947551095208141], 
             UndirectedEdge[200, 234] -> 
             RGBColor[
              0.6810756455843666, 0.7449015617579675, 0.9305244815385927], 
             UndirectedEdge[282, 382] -> 
             RGBColor[
              0.5277305600962999, 0.6274744685338067, 0.9559640293129699], 
             UndirectedEdge[305, 382] -> 
             RGBColor[
              0.4275224934906994, 0.5410709187919869, 0.9492622753320865], 
             UndirectedEdge[50, 164] -> 
             RGBColor[
              0.606680690711054, 0.6893591075883401, 0.9635844649230019], 
             UndirectedEdge[259, 287] -> 
             RGBColor[
              0.558128388978993, 0.6521527954273624, 0.9583570577535316], 
             UndirectedEdge[90, 95] -> 
             RGBColor[
              0.49118679617534045`, 0.5942849743599955, 0.9541256193785633], 
             UndirectedEdge[44, 243] -> 
             RGBColor[
              0.43966510927905766`, 0.5541653127261549, 0.9495323128572292], 
             UndirectedEdge[82, 194] -> 
             RGBColor[
              0.7697990557225933, 0.3380334189472869, 0.4322177819555024], 
             UndirectedEdge[124, 150] -> 
             RGBColor[
              0.8205089568706868, 0.8588985545628779, 0.8988942489477413], 
             UndirectedEdge[233, 316] -> 
             RGBColor[
              0.5410520521772806, 0.638289455931526, 0.9570127459678179], 
             UndirectedEdge[87, 390] -> 
             RGBColor[
              0.7653653520256785, 0.8165165939632495, 0.9688540173408904], 
             UndirectedEdge[72, 376] -> 
             RGBColor[
              0.44350748121468864`, 0.5583637847204523, 0.9495366505822218], 
             UndirectedEdge[99, 169] -> 
             RGBColor[
              0.5903819869927152, 0.6715935190228673, 0.9641461857867847], 
             UndirectedEdge[127, 137] -> 
             RGBColor[
              0.9344481246424827, 0.9324677565982467, 0.687810078808645], 
             UndirectedEdge[68, 391] -> 
             RGBColor[
              0.7639572949061274, 0.7955019230116362, 0.6693671202657998], 
             UndirectedEdge[292, 309] -> 
             RGBColor[
              0.515032598941473, 0.6055280333816437, 0.957905467468042], 
             UndirectedEdge[88, 140] -> 
             RGBColor[
              0.7570022354682182, 0.8102502020872336, 0.9766059203198791], 
             UndirectedEdge[153, 216] -> 
             RGBColor[
              0.6665207181821675, 0.6689690838281972, 0.6112035320034273], 
             UndirectedEdge[145, 165] -> 
             RGBColor[
              0.6760124760165123, 0.7468253512399903, 0.9683422639797119], 
             UndirectedEdge[37, 76] -> 
             RGBColor[
              0.7412384433526549, 0.7966272742321531, 0.9588543796983187], 
             UndirectedEdge[6, 391] -> 
             RGBColor[
              0.6673862863084893, 0.7143942628529847, 0.662512639186317], 
             UndirectedEdge[203, 206] -> 
             RGBColor[
              0.751507356818355, 0.8058025259047351, 0.9758668881582668], 
             UndirectedEdge[298, 320] -> 
             RGBColor[
              0.7278800757775024, 0.7851572429387088, 0.9410365398965685], 
             UndirectedEdge[39, 164] -> 
             RGBColor[
              0.7360381192817282, 0.7937178399705627, 0.9743250591288597], 
             UndirectedEdge[107, 156] -> 
             RGBColor[
              0.5435041338038368, 0.6402801662609827, 0.9572057828157314], 
             UndirectedEdge[31, 222] -> 
             RGBColor[
              0.7466594156874787, 0.8020993937204886, 0.975508601741679], 
             UndirectedEdge[301, 329] -> 
             RGBColor[
              0.5368424177349916, 0.6299568516734364, 0.9586738769802976], 
             UndirectedEdge[126, 320] -> 
             RGBColor[
              0.3947062005645532, 0.5153667914843125, 0.9465935087528785], 
             UndirectedEdge[49, 191] -> 
             RGBColor[
              0.3697304682935355, 0.49466368126736027`, 0.9447798763932163], 
             UndirectedEdge[122, 173] -> 
             RGBColor[
              0.5489832050329719, 0.640195667916704, 0.9595646843614324], 
             UndirectedEdge[60, 102] -> 
             RGBColor[
              0.5377373808323019, 0.6300687468642698, 0.959011633441367], 
             UndirectedEdge[120, 380] -> 
             RGBColor[
              0.6435866403535839, 0.7118534516332689, 0.9266574306982515], 
             UndirectedEdge[110, 247] -> 
             RGBColor[
              0.26671418019762405`, 0.3976638924164059, 0.9385003500427598], 
             UndirectedEdge[59, 149] -> 
             RGBColor[
              0.5231848094724219, 0.6225920115850521, 0.955935527586531], 
             UndirectedEdge[92, 346] -> 
             RGBColor[
              0.6581770864208201, 0.728255401920691, 0.9694138196923874], 
             UndirectedEdge[6, 142] -> 
             RGBColor[
              0.5213581414417061, 0.6188781707586849, 0.9566997875485673], 
             UndirectedEdge[176, 232] -> 
             RGBColor[
              0.8398529227220777, 0.8755371038247153, 0.9844817204264158], 
             UndirectedEdge[60, 345] -> 
             RGBColor[
              0.31150706303234166`, 0.44408891333829287`, 0.9410752263020419],
              UndirectedEdge[79, 126] -> 
             RGBColor[
              0.5715504844824617, 0.6561006541825405, 0.9625084075083774], 
             UndirectedEdge[14, 212] -> 
             RGBColor[
              0.3238160284016348, 0.45327126192403416`, 0.9419136982698657], 
             UndirectedEdge[22, 338] -> 
             RGBColor[
              0.5727214634215301, 0.6639457604799572, 0.9595430375518297], 
             UndirectedEdge[195, 389] -> 
             RGBColor[
              0.6774407423011582, 0.7199969640514796, 0.658419447543892], 
             UndirectedEdge[14, 293] -> 
             RGBColor[
              0.3001650829319934, 0.43278600168931397`, 0.9404066809382501], 
             UndirectedEdge[201, 394] -> 
             RGBColor[
              0.35085787313205646`, 0.4780177348682897, 0.9435882957604041], 
             UndirectedEdge[20, 189] -> 
             RGBColor[
              0.841921406058469, 0.8760466621456158, 0.9200974899521261], 
             UndirectedEdge[195, 359] -> 
             RGBColor[
              0.9738730979684183, 0.9580873233412256, 0.6544400711408358], 
             UndirectedEdge[222, 224] -> 
             RGBColor[
              0.5522865804560084, 0.6310308982363153, 0.9621418824545598], 
             UndirectedEdge[54, 389] -> 
             RGBColor[
              0.36099339486898485`, 0.4870960674050933, 0.9442231578004945], 
             UndirectedEdge[123, 366] -> 
             RGBColor[
              0.8598190223436126, 0.8905187193663346, 0.9442486684299094], 
             UndirectedEdge[120, 263] -> 
             RGBColor[
              0.8073441186198518, 0.8493385147680308, 0.9384085198757051], 
             UndirectedEdge[332, 364] -> 
             RGBColor[
              0.4259256669840499, 0.5384167477873537, 0.9492601622744798], 
             UndirectedEdge[70, 228] -> 
             RGBColor[
              0.5769049873118788, 0.6666192187779874, 0.9603666407164151], 
             UndirectedEdge[74, 141] -> 
             RGBColor[
              0.6222852967186885, 0.6927814153288603, 0.9444565516019547], 
             UndirectedEdge[212, 385] -> 
             RGBColor[
              0.4986215184488251, 0.6012121653621778, 0.9543992108638839], 
             UndirectedEdge[256, 384] -> 
             RGBColor[
              0.8745059361795544, 0.9027901597500589, 0.9861026808886513], 
             UndirectedEdge[158, 317] -> 
             RGBColor[
              0.6275046629944347, 0.6870838605930881, 0.6773294011877802], 
             UndirectedEdge[76, 208] -> 
             RGBColor[
              0.9702506210449482, 0.977049699592265, 0.9225310571216002], 
             UndirectedEdge[101, 253] -> 
             RGBColor[
              0.9575369433378219, 0.9668486307046429, 0.9142934993215264], 
             UndirectedEdge[111, 309] -> 
             RGBColor[
              0.6662336190424265, 0.7379696619607914, 0.9681992390088585], 
             UndirectedEdge[145, 170] -> 
             RGBColor[
              0.7951458264211815, 0.8407943067143246, 0.9782367380796104], 
             UndirectedEdge[59, 279] -> 
             RGBColor[
              0.7032995499000375, 0.7680594000407633, 0.9711186094615635], 
             UndirectedEdge[83, 334] -> 
             RGBColor[
              0.5165645112946275, 0.6177772261547572, 0.9552596594730995], 
             UndirectedEdge[242, 312] -> 
             RGBColor[
              0.49363395180218717`, 0.5997933058859468, 0.9532798194080657], 
             UndirectedEdge[140, 356] -> 
             RGBColor[
              0.7205955671027617, 0.7806936286064367, 0.97373985402413], 
             UndirectedEdge[172, 316] -> 
             RGBColor[
              0.4459389040642512, 0.558978633379321, 0.9501035816966821], 
             UndirectedEdge[217, 331] -> 
             RGBColor[
              0.39947500146705994`, 0.5204269008985607, 0.9466751717449753], 
             UndirectedEdge[263, 336] -> 
             RGBColor[
              0.49751969121050776`, 0.6005203130159132, 0.9542564752481923], 
             UndirectedEdge[122, 338] -> 
             RGBColor[
              0.6250409902566195, 0.7048181724866606, 0.964757759032975], 
             UndirectedEdge[303, 400] -> 
             RGBColor[
              0.47158775810989506`, 0.5818952126768363, 0.95154426228274], 
             UndirectedEdge[133, 367] -> 
             RGBColor[
              0.7437223742684123, 0.7976203303954139, 0.9309041335094295], 
             UndirectedEdge[136, 279] -> 
             RGBColor[
              0.5194274815900961, 0.6101292385404467, 0.9581586142620655], 
             UndirectedEdge[117, 365] -> 
             RGBColor[
              0.590727389135987, 0.677676679985199, 0.9615670465650807], 
             UndirectedEdge[33, 245] -> 
             RGBColor[
              0.6236695338712075, 0.7004722177210074, 0.9662457408747052], 
             UndirectedEdge[162, 368] -> 
             RGBColor[
              0.3739962414725968, 0.4983584795910691, 0.9450516876881108], 
             UndirectedEdge[46, 128] -> 
             RGBColor[
              0.9231951547326323, 0.9400697215796485, 0.9372587814521931], 
             UndirectedEdge[117, 269] -> 
             RGBColor[
              0.4061658962119661, 0.5255618682847917, 0.9472839661338649], 
             UndirectedEdge[98, 134] -> 
             RGBColor[
              0.7473498798550435, 0.8007852097404649, 0.9377817327943244], 
             UndirectedEdge[90, 326] -> 
             RGBColor[
              0.42344113414988405`, 0.5394465596393737, 0.948682653112785], 
             UndirectedEdge[119, 306] -> 
             RGBColor[
              0.6216846759003902, 0.6939101731599664, 0.9545104167569336], 
             UndirectedEdge[150, 211] -> 
             RGBColor[
              0.4964235914670888, 0.598856082436863, 0.9544443799775393], 
             UndirectedEdge[388, 395] -> 
             RGBColor[
              0.9191505624284975, 0.9381669434438369, 0.9851200287723614], 
             UndirectedEdge[102, 108] -> 
             RGBColor[
              0.5926352749040491, 0.6776185434608324, 0.962509678707317], 
             UndirectedEdge[15, 392] -> 
             RGBColor[
              0.460504429213783, 0.5724650728770388, 0.95079115855103], 
             UndirectedEdge[32, 292] -> 
             RGBColor[
              0.4275448294895442, 0.5364493501786503, 0.9496863682362995], 
             UndirectedEdge[115, 332] -> 
             RGBColor[
              0.5063153221193815, 0.6099651410973657, 0.9543122591528216], 
             UndirectedEdge[93, 293] -> 
             RGBColor[
              0.30088830442129044`, 0.433546153329456, 0.9404478673321552], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.9322761349345796, 0.9477207585228787, 0.954746792473825], 
             UndirectedEdge[276, 305] -> 
             RGBColor[
              0.3731141089086943, 0.49672506989491544`, 0.945027310172827], 
             UndirectedEdge[75, 347] -> 
             RGBColor[
              0.28646247406025893`, 0.41592992645781757`, 0.9397161819730347],
              UndirectedEdge[64, 193] -> 
             RGBColor[
              0.48745591530240373`, 0.5911679876762688, 0.9538394228538906], 
             UndirectedEdge[18, 99] -> 
             RGBColor[
              0.9117997771345189, 0.9318897886577322, 0.970001535490524], 
             UndirectedEdge[74, 290] -> 
             RGBColor[
              0.5802238762156344, 0.6599165673496787, 0.9638053141361183], 
             UndirectedEdge[39, 230] -> 
             RGBColor[
              0.4897945300523448, 0.5880525715333715, 0.9550352354461604], 
             UndirectedEdge[259, 345] -> 
             RGBColor[
              0.46088314454564894`, 0.5690922158455183, 0.9518032001972037], 
             UndirectedEdge[30, 168] -> 
             RGBColor[
              0.39943458594117665`, 0.5203918950013839, 0.946672596503404], 
             UndirectedEdge[231, 331] -> 
             RGBColor[
              0.7034562710959347, 0.7605682961202055, 0.7463782624824218], 
             UndirectedEdge[137, 242] -> 
             RGBColor[
              0.7098278458811788, 0.7721078425170654, 0.9727127011505873], 
             UndirectedEdge[172, 221] -> 
             RGBColor[
              0.5659609140061944, 0.6546814753016514, 0.9607393624802185], 
             UndirectedEdge[157, 211] -> 
             RGBColor[
              0.6419508804596583, 0.7133479749533944, 0.9620995025592252], 
             UndirectedEdge[46, 213] -> 
             RGBColor[
              0.6768356282680001, 0.7407648030891594, 0.916304143307126], 
             UndirectedEdge[184, 318] -> 
             RGBColor[
              0.7195289266825871, 0.7782196723315511, 0.9361485299304331], 
             UndirectedEdge[201, 293] -> 
             RGBColor[
              0.3073261880916144, 0.44031277725236684`, 0.9408144952831847], 
             UndirectedEdge[64, 115] -> 
             RGBColor[
              0.5494574790896408, 0.6448706259395673, 0.9577901076725832], 
             UndirectedEdge[174, 266] -> 
             RGBColor[
              0.7045639575538257, 0.7675271163274784, 0.9726519643946969], 
             UndirectedEdge[80, 104] -> 
             RGBColor[
              0.3779333728175674, 0.4971609212010716, 0.9456908035457635], 
             UndirectedEdge[265, 321] -> 
             RGBColor[
              0.43547980738397807`, 0.5500641328975759, 0.9493971719098444], 
             UndirectedEdge[178, 296] -> 
             RGBColor[
              0.9565457445976503, 0.9671124679875163, 0.9584408990979578], 
             UndirectedEdge[114, 249] -> 
             RGBColor[
              0.5357003756575285, 0.6284556748422168, 0.9588178086281396], 
             UndirectedEdge[255, 380] -> 
             RGBColor[
              0.5910943750194417, 0.671231742353499, 0.964441099084651], 
             UndirectedEdge[253, 391] -> 
             RGBColor[
              0.9537263617557721, 0.946074679521362, 0.6870522786219737], 
             UndirectedEdge[40, 63] -> 
             RGBColor[
              0.607182222177751, 0.6882896395162421, 0.9642529308792056], 
             UndirectedEdge[23, 311] -> 
             RGBColor[
              0.6455721484739085, 0.717820744997987, 0.9683882436033369], 
             UndirectedEdge[156, 396] -> 
             RGBColor[
              0.48614041538084074`, 0.5937097154391291, 0.952689900771249], 
             UndirectedEdge[93, 281] -> 
             RGBColor[
              0.6415763333964606, 0.7076264212282513, 0.8733634092556395], 
             UndirectedEdge[27, 325] -> 
             RGBColor[
              0.7144036368759065, 0.77543224964222, 0.9725846994436051], 
             UndirectedEdge[12, 107] -> 
             RGBColor[
              0.49473490450918534`, 0.5989128727239132, 0.9538567171773455], 
             UndirectedEdge[255, 312] -> 
             RGBColor[
              0.6662816438474701, 0.7368115194238334, 0.9692196169317588], 
             UndirectedEdge[257, 310] -> 
             RGBColor[
              0.8053474704070231, 0.84874568801675, 0.9783312231417658], 
             UndirectedEdge[50, 197] -> 
             RGBColor[
              0.6145058551808922, 0.6954721855456304, 0.9643644041870358], 
             UndirectedEdge[215, 350] -> 
             RGBColor[
              0.6829870816984767, 0.7130978270027273, 0.6409359605858687], 
             UndirectedEdge[49, 235] -> 
             RGBColor[
              0.3681955817044077, 0.49333423964950085`, 0.9446820747770039], 
             UndirectedEdge[239, 323] -> 
             RGBColor[
              0.48058812134956586`, 0.5839907159165882, 0.9536220604386729], 
             UndirectedEdge[211, 216] -> 
             RGBColor[
              0.3631862062187099, 0.4889953703823221, 0.944362881800672], 
             UndirectedEdge[98, 151] -> 
             RGBColor[
              0.8218760700877559, 0.8609449008837221, 0.9438839209372628], 
             UndirectedEdge[10, 32] -> 
             RGBColor[
              0.48129284413538864`, 0.587458978281449, 0.9529479955634703], 
             UndirectedEdge[330, 367] -> 
             RGBColor[
              0.6659224597254085, 0.7315834867619726, 0.9255739120362372], 
             UndirectedEdge[99, 384] -> 
             RGBColor[
              0.8376215406418079, 0.8734306278900844, 0.9843557266378845], 
             UndirectedEdge[127, 138] -> 
             RGBColor[
              0.6710113808886973, 0.7192520306597081, 0.6653618977942797], 
             UndirectedEdge[292, 385] -> 
             RGBColor[
              0.450674317329397, 0.5552269103785956, 0.9515072062451584], 
             UndirectedEdge[177, 219] -> 
             RGBColor[
              0.3315112292636605, 0.4584788142444003, 0.9424574011476097], 
             UndirectedEdge[170, 322] -> 
             RGBColor[
              0.6751736305988127, 0.7424508510368892, 0.9689887976327638], 
             UndirectedEdge[261, 335] -> 
             RGBColor[
              0.7596795546536697, 0.8124467112202765, 0.9766124198606636], 
             UndirectedEdge[6, 253] -> 
             RGBColor[
              0.6399626365455333, 0.7123922383301377, 0.9682931342260526], 
             UndirectedEdge[95, 246] -> 
             RGBColor[
              0.7778400970720775, 0.8270435531874822, 0.9783137743562403], 
             UndirectedEdge[50, 331] -> 
             RGBColor[
              0.4285117216952361, 0.5455770485322133, 0.9485253658817511], 
             UndirectedEdge[9, 358] -> 
             RGBColor[
              0.6954600637320479, 0.760150476191656, 0.9719188008322599], 
             UndirectedEdge[99, 144] -> 
             RGBColor[
              0.9081263327686551, 0.8715401121178532, 0.6336964269577603], 
             UndirectedEdge[2, 28] -> 
             RGBColor[
              0.7339534821329479, 0.7877662575948341, 0.849735858878385], 
             UndirectedEdge[138, 258] -> 
             RGBColor[
              0.42984834166214336`, 0.5454619583899708, 0.9489622134342692], 
             UndirectedEdge[144, 384] -> 
             RGBColor[
              0.881836687513206, 0.8506473943451617, 0.6311703393905026], 
             UndirectedEdge[79, 277] -> 
             RGBColor[
              0.8236253142780908, 0.8622704169051001, 0.9830207540727344], 
             UndirectedEdge[346, 354] -> 
             RGBColor[
              0.6656878680852152, 0.734164266628119, 0.9673555588949185], 
             UndirectedEdge[144, 148] -> 
             RGBColor[
              0.9393220958164346, 0.8964147667857227, 0.6366719066860438], 
             UndirectedEdge[38, 346] -> 
             RGBColor[
              0.6813981043082182, 0.7128329897278911, 0.6425287004027018], 
             UndirectedEdge[38, 363] -> 
             RGBColor[
              0.6389966145869905, 0.6760167435399491, 0.639830217890242], 
             UndirectedEdge[78, 104] -> 
             RGBColor[
              0.6678181119785804, 0.738275901241334, 0.9690908013663384], 
             UndirectedEdge[95, 282] -> 
             RGBColor[
              0.5763000076010076, 0.6667447684278651, 0.9598973737268865], 
             UndirectedEdge[92, 306] -> 
             RGBColor[
              0.9370386349327038, 0.9522567614994615, 0.9808058140569191], 
             UndirectedEdge[9, 339] -> 
             RGBColor[
              0.5302559881194555, 0.6295247247722403, 0.9561628402579003], 
             UndirectedEdge[36, 148] -> 
             RGBColor[
              0.753398204963267, 0.8071913078905049, 0.9764752552314916], 
             UndirectedEdge[62, 395] -> 
             RGBColor[
              0.835256519416427, 0.8720240667556207, 0.9769185940637984], 
             UndirectedEdge[32, 247] -> 
             RGBColor[
              0.43155678724619106`, 0.5406661721536997, 0.9499148432953809], 
             UndirectedEdge[168, 379] -> 
             RGBColor[
              0.6682736753426723, 0.7349813905642757, 0.9467587089753864], 
             UndirectedEdge[137, 230] -> 
             RGBColor[
              0.5817676149556407, 0.6604392647419802, 0.9640598504943156], 
             UndirectedEdge[268, 279] -> 
             RGBColor[
              0.500308811256199, 0.5900343038258085, 0.9570698342700883], 
             UndirectedEdge[185, 288] -> 
             RGBColor[
              0.8475760913752655, 0.881422155006959, 0.9667036270139813], 
             UndirectedEdge[233, 310] -> 
             RGBColor[
              0.7525478073432252, 0.8063351390255875, 0.9738638304299803], 
             UndirectedEdge[150, 386] -> 
             RGBColor[
              0.5786643697236222, 0.6686769816173959, 0.9600748099464342], 
             UndirectedEdge[138, 281] -> 
             RGBColor[
              0.6750117976767456, 0.7380764455720652, 0.8754393347276159], 
             UndirectedEdge[88, 257] -> 
             RGBColor[
              0.6390569480124463, 0.7173996493590136, 0.9650388601955895], 
             UndirectedEdge[27, 40] -> 
             RGBColor[
              0.8708849347412899, 0.8999785081354031, 0.9866074853656299], 
             UndirectedEdge[159, 250] -> 
             RGBColor[
              0.6036238500293067, 0.6824601528110509, 0.9652674486545705], 
             UndirectedEdge[169, 363] -> 
             RGBColor[
              0.31231156123738696`, 0.44484010298125176`, 0.941124497327556], 
             UndirectedEdge[144, 382] -> 
             RGBColor[
              0.7540216208798534, 0.7494698144987935, 0.6193385322542577], 
             UndirectedEdge[35, 207] -> 
             RGBColor[
              0.727954773525495, 0.78458088854047, 0.9196887163194931], 
             UndirectedEdge[71, 287] -> 
             RGBColor[
              0.44165561629746697`, 0.5556486852618385, 0.9497256536018774], 
             UndirectedEdge[148, 361] -> 
             RGBColor[
              0.8390298333858817, 0.8750350843635398, 0.9843622697060312], 
             UndirectedEdge[215, 393] -> 
             RGBColor[
              0.8151230474417364, 0.8216265783306838, 0.6511072506266173], 
             UndirectedEdge[33, 124] -> 
             RGBColor[
              0.9257803300664473, 0.9414814224727052, 0.9092954097262993], 
             UndirectedEdge[31, 111] -> 
             RGBColor[
              0.5911693377806213, 0.6789769261423052, 0.9609581622761793], 
             UndirectedEdge[113, 357] -> 
             RGBColor[
              0.3097770661849383, 0.4403952628955604, 0.9410453699753649], 
             UndirectedEdge[30, 329] -> 
             RGBColor[
              0.37721183504946404`, 0.501143665126919, 0.9452565824673911], 
             UndirectedEdge[117, 239] -> 
             RGBColor[
              0.38899854472256945`, 0.509916929355957, 0.9462184704049199], 
             UndirectedEdge[209, 338] -> 
             RGBColor[
              0.5379994887413009, 0.6358112474177819, 0.9567724369922295], 
             UndirectedEdge[208, 323] -> 
             RGBColor[
              0.8233589029899824, 0.8616961400198782, 0.9250782983419603], 
             UndirectedEdge[71, 212] -> 
             RGBColor[
              0.3690428083219113, 0.4940680647627345, 0.9447360593078982], 
             UndirectedEdge[199, 292] -> 
             RGBColor[
              0.2983188082833236, 0.42835469135057636`, 0.940392737202776], 
             UndirectedEdge[11, 386] -> 
             RGBColor[
              0.6104876618544388, 0.6935375792959678, 0.9632466583004609], 
             UndirectedEdge[130, 267] -> 
             RGBColor[
              0.5051828176140705, 0.6091691954225096, 0.9541889884296666], 
             UndirectedEdge[67, 347] -> 
             RGBColor[
              0.6016592678047666, 0.6704533586735002, 0.939563245698428], 
             UndirectedEdge[211, 358] -> 
             RGBColor[
              0.6338487724150819, 0.7070775238564597, 0.9679123996435481], 
             UndirectedEdge[2, 164] -> 
             RGBColor[
              0.621736119926247, 0.701842533197393, 0.9646976374773382], 
             UndirectedEdge[266, 358] -> 
             RGBColor[
              0.7035750961086569, 0.7667386250530297, 0.9725576459072895], 
             UndirectedEdge[57, 397] -> 
             RGBColor[
              0.6773236587124611, 0.739982423517511, 0.8720419729179887], 
             UndirectedEdge[209, 386] -> 
             RGBColor[
              0.5408906421754616, 0.6381584160206116, 0.9570000391812106], 
             UndirectedEdge[74, 386] -> 
             RGBColor[
              0.39403058898309473`, 0.5118951309843417, 0.9468064071202233], 
             UndirectedEdge[47, 268] -> 
             RGBColor[
              0.46721383350534673`, 0.5641802556756959, 0.9537712361780343], 
             UndirectedEdge[108, 397] -> 
             RGBColor[
              0.7082875454811794, 0.7668017859463745, 0.8740149644026014], 
             UndirectedEdge[157, 358] -> 
             RGBColor[
              0.9349629336023382, 0.9507881307025481, 0.9870731099474448], 
             UndirectedEdge[10, 129] -> 
             RGBColor[
              0.4228434475947006, 0.540007125054411, 0.9483466449605931], 
             UndirectedEdge[171, 308] -> 
             RGBColor[
              0.6032916961619108, 0.6820288277069824, 0.9653124049368725], 
             UndirectedEdge[225, 335] -> 
             RGBColor[
              0.6927159600697592, 0.7584632892608059, 0.9710805542059333], 
             UndirectedEdge[45, 116] -> 
             RGBColor[
              0.5776139133456053, 0.6637269646403542, 0.9619253400182732], 
             UndirectedEdge[261, 349] -> 
             RGBColor[
              0.6995398885138837, 0.7652051446978947, 0.9706872565812796], 
             UndirectedEdge[118, 209] -> 
             RGBColor[
              0.45473274114058876`, 0.5649447019697965, 0.9511200136126554], 
             UndirectedEdge[329, 343] -> 
             RGBColor[
              0.3656689114682441, 0.49114576488507455`, 0.9445210775838022], 
             UndirectedEdge[163, 171] -> 
             RGBColor[
              0.9147758411548885, 0.9346690680760863, 0.9843702250352198], 
             UndirectedEdge[106, 217] -> 
             RGBColor[
              0.3317602176118625, 0.458921902345084, 0.9424649392518056], 
             UndirectedEdge[55, 123] -> 
             RGBColor[
              0.511287857079886, 0.6059937467434591, 0.9569953602922995], 
             UndirectedEdge[129, 353] -> 
             RGBColor[
              0.37124494891801196`, 0.49125677452237904`, 0.9452074293879418],
              UndirectedEdge[38, 66] -> 
             RGBColor[
              0.7116867940817407, 0.7390675304559038, 0.6444586689318339], 
             UndirectedEdge[23, 119] -> 
             RGBColor[
              0.601402638854558, 0.6781142543933044, 0.9656268594763823], 
             UndirectedEdge[306, 354] -> 
             RGBColor[
              0.9445494165970989, 0.9581656262068893, 0.9787475532594504], 
             UndirectedEdge[28, 39] -> 
             RGBColor[
              0.8482554814884292, 0.8796415643680038, 0.8593632805299065], 
             UndirectedEdge[158, 267] -> 
             RGBColor[
              0.7434377464842601, 0.7903791857564684, 0.6848935575843689], 
             UndirectedEdge[194, 399] -> 
             RGBColor[
              0.8301689362466288, 0.8544309925014956, 0.6833468842996584], 
             UndirectedEdge[102, 333] -> 
             RGBColor[
              0.7212040379283833, 0.7821293428741355, 0.9728465365319301], 
             UndirectedEdge[16, 80] -> 
             RGBColor[
              0.5602935427028768, 0.642258120716056, 0.9621719597383567], 
             UndirectedEdge[72, 333] -> 
             RGBColor[
              0.5717583530722083, 0.6625992427827353, 0.9598532526627856], 
             UndirectedEdge[167, 211] -> 
             RGBColor[
              0.5062312724032597, 0.6065179173253356, 0.9554219179552674], 
             UndirectedEdge[193, 255] -> 
             RGBColor[
              0.6016713718621862, 0.6808675418230934, 0.9650976808676992], 
             UndirectedEdge[168, 211] -> 
             RGBColor[
              0.35747066526574284`, 0.4840448560803031, 0.9439986925852034], 
             UndirectedEdge[70, 246] -> 
             RGBColor[
              0.6817754854144819, 0.7492145394013474, 0.9706414366396894], 
             UndirectedEdge[322, 349] -> 
             RGBColor[
              0.5722945033430233, 0.6611798182231312, 0.9607143925919941], 
             UndirectedEdge[193, 312] -> 
             RGBColor[
              0.3893777469960599, 0.5116629739923261, 0.9460368102845123], 
             UndirectedEdge[194, 221] -> 
             RGBColor[
              0.7152358867617277, 0.7774669778231154, 0.9722516869991815], 
             UndirectedEdge[208, 221] -> 
             RGBColor[
              0.8708065498278781, 0.8987626023451143, 0.9298074363552924], 
             UndirectedEdge[112, 251] -> 
             RGBColor[
              0.4488188469142208, 0.5575574609745519, 0.9510118778532721], 
             UndirectedEdge[297, 325] -> 
             RGBColor[
              0.7399979519169677, 0.7939039771917927, 0.901653382622073], 
             UndirectedEdge[170, 225] -> 
             RGBColor[
              0.7354554211857627, 0.7924927555521823, 0.973429795967319], 
             UndirectedEdge[27, 250] -> 
             RGBColor[
              0.909077201661814, 0.9303113265436176, 0.9902823169438288], 
             UndirectedEdge[67, 126] -> 
             RGBColor[
              0.636630305159863, 0.7072101362255394, 0.9415547945407872], 
             UndirectedEdge[12, 157] -> 
             RGBColor[
              0.6655196429819124, 0.7337620524497226, 0.9636012832661047], 
             UndirectedEdge[316, 399] -> 
             RGBColor[
              0.7506236458986331, 0.7903488715604198, 0.6767454446487962], 
             UndirectedEdge[76, 377] -> 
             RGBColor[
              0.9446274251029413, 0.8721471055914461, 0.6140063148398518], 
             UndirectedEdge[3, 51] -> 
             RGBColor[
              0.44539723664107134`, 0.5590793814997658, 0.9499115984074279], 
             UndirectedEdge[23, 186] -> 
             RGBColor[
              0.8898185140431781, 0.9149811458906447, 0.9893528782914449], 
             UndirectedEdge[17, 319] -> 
             RGBColor[
              0.328529305663705, 0.4566375102171071, 0.9422402460929977], 
             UndirectedEdge[115, 360] -> 
             RGBColor[
              0.3997912438630265, 0.5207008141671419, 0.9466953224308041], 
             UndirectedEdge[131, 142] -> 
             RGBColor[
              0.5853357938147974, 0.6735250760202841, 0.9609884002326561], 
             UndirectedEdge[23, 130] -> 
             RGBColor[
              0.7116900332997582, 0.7734506400428904, 0.9730538269037614], 
             UndirectedEdge[348, 354] -> 
             RGBColor[
              0.8500128632245607, 0.883636112535976, 0.9826554992308083], 
             UndirectedEdge[76, 80] -> 
             RGBColor[
              0.6117084612630166, 0.6827675570991136, 0.9501766625648167], 
             UndirectedEdge[38, 81] -> 
             RGBColor[
              0.7082966741101119, 0.7361311789288632, 0.644242653485007], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.8089634866625048, 0.8509439230089451, 0.9815255821851536], 
             UndirectedEdge[131, 281] -> 
             RGBColor[
              0.7360495707830839, 0.7901769751754315, 0.8795406209044603], 
             UndirectedEdge[157, 167] -> 
             RGBColor[
              0.807345433590516, 0.8502285241714239, 0.974582628259164], 
             UndirectedEdge[165, 172] -> 
             RGBColor[
              0.5377867392979351, 0.6326715958879007, 0.9579312240479312], 
             UndirectedEdge[255, 331] -> 
             RGBColor[
              0.6459419659563409, 0.7192125053226932, 0.9679185639764295], 
             UndirectedEdge[59, 268] -> 
             RGBColor[
              0.4339617599255153, 0.5381206623635326, 0.9505136052112368], 
             UndirectedEdge[161, 364] -> 
             RGBColor[
              0.6411653140429091, 0.7051641114153984, 0.782480933124478], 
             UndirectedEdge[149, 164] -> 
             RGBColor[
              0.5895318608031056, 0.6745056530473279, 0.9624917566453823], 
             UndirectedEdge[10, 52] -> 
             RGBColor[
              0.3592691325615621, 0.48560259805834716`, 0.9441132893309708], 
             UndirectedEdge[132, 155] -> 
             RGBColor[
              0.508225794648616, 0.610720506982116, 0.9546824967431243], 
             UndirectedEdge[353, 400] -> 
             RGBColor[
              0.363508617065882, 0.48497607180704166`, 0.9445983970054247], 
             UndirectedEdge[250, 265] -> 
             RGBColor[
              0.6210292673026377, 0.6975358504315015, 0.966376506452221], 
             UndirectedEdge[82, 233] -> 
             RGBColor[
              0.7336911726275909, 0.30905029896778097`, 0.4291490084569509], 
             UndirectedEdge[66, 81] -> 
             RGBColor[
              0.4497605734044723, 0.5639817358844135, 0.9498793239230419], 
             UndirectedEdge[69, 201] -> 
             RGBColor[
              0.64574112859686, 0.7134530646531393, 0.911400995717708], 
             UndirectedEdge[84, 184] -> 
             RGBColor[
              0.6756157856318072, 0.7443032519302195, 0.9700535852657441], 
             UndirectedEdge[180, 268] -> 
             RGBColor[
              0.4848962134455096, 0.577993865276016, 0.9555336505592342], 
             UndirectedEdge[17, 247] -> 
             RGBColor[
              0.27600786642761466`, 0.4074321458978667, 0.9390296117247812], 
             UndirectedEdge[188, 394] -> 
             RGBColor[
              0.5901157647988216, 0.674400822788736, 0.9627873882730957], 
             UndirectedEdge[241, 312] -> 
             RGBColor[
              0.4272748445864586, 0.544487535161621, 0.9484515798318848], 
             UndirectedEdge[81, 128] -> 
             RGBColor[
              0.653569121062809, 0.7264311352072691, 0.9681226513249249], 
             UndirectedEdge[65, 198] -> 
             RGBColor[
              0.771405612603804, 0.8212519760484067, 0.9648135186528578], 
             UndirectedEdge[356, 380] -> 
             RGBColor[
              0.41843959830444905`, 0.5342077771615814, 0.9485007438298063], 
             UndirectedEdge[40, 265] -> 
             RGBColor[
              0.5828370003821135, 0.667203032023287, 0.962701674874022], 
             UndirectedEdge[19, 168] -> 
             RGBColor[
              0.5167383813135189, 0.6161390736033427, 0.9558711524232485], 
             UndirectedEdge[195, 241] -> 
             RGBColor[
              0.6896169665685881, 0.7305433975171011, 0.6591953057872002], 
             UndirectedEdge[33, 141] -> 
             RGBColor[
              0.9121904506549765, 0.9321461338717416, 0.9681261152067236], 
             UndirectedEdge[65, 100] -> 
             RGBColor[
              0.7714776649118984, 0.8213057125418086, 0.9646915528895059], 
             UndirectedEdge[15, 207] -> 
             RGBColor[
              0.7346153780890323, 0.7899882673819658, 0.9202130635093332], 
             UndirectedEdge[81, 135] -> 
             RGBColor[
              0.5494633600644119, 0.644773283301185, 0.9578338383607976], 
             UndirectedEdge[259, 271] -> 
             RGBColor[
              0.797613958092049, 0.8415354260850505, 0.940225262540455], 
             UndirectedEdge[194, 233] -> 
             RGBColor[
              0.6205973425252762, 0.7023715768726018, 0.9636141856186802], 
             UndirectedEdge[101, 283] -> 
             RGBColor[
              0.9435935714237007, 0.9557305644230707, 0.9129635680609625], 
             UndirectedEdge[145, 192] -> 
             RGBColor[
              0.5681344652497212, 0.660118370082456, 0.9592526674900288], 
             UndirectedEdge[68, 397] -> 
             RGBColor[
              0.7688559954214044, 0.8167258393371877, 0.8785753942802466], 
             UndirectedEdge[142, 201] -> 
             RGBColor[
              0.49730044009849794`, 0.5977411459960148, 0.9551778165348648], 
             UndirectedEdge[146, 354] -> 
             RGBColor[
              0.6930433806749263, 0.7578582367052861, 0.969098627967605], 
             UndirectedEdge[153, 329] -> 
             RGBColor[
              0.6385824263374879, 0.6447703396517132, 0.6094233287519457], 
             UndirectedEdge[132, 279] -> 
             RGBColor[
              0.6833152318891275, 0.7518352303962397, 0.9695453707427757], 
             UndirectedEdge[257, 389] -> 
             RGBColor[
              0.5241220328335411, 0.6219966233423004, 0.9565692538115026], 
             UndirectedEdge[107, 386] -> 
             RGBColor[
              0.5534069202434648, 0.648319694408118, 0.9579853664393609], 
             UndirectedEdge[157, 203] -> 
             RGBColor[
              0.8564898971542215, 0.8886205526191474, 0.9794808891060709], 
             UndirectedEdge[264, 281] -> 
             RGBColor[
              0.6290704177579618, 0.6944819109713407, 0.8726512158608712], 
             UndirectedEdge[244, 302] -> 
             RGBColor[
              0.7194684653290362, 0.7765825766353935, 0.8782720742789323], 
             UndirectedEdge[46, 105] -> 
             RGBColor[
              0.7409262122264263, 0.7951116868345403, 0.9207098754899761], 
             UndirectedEdge[126, 347] -> 
             RGBColor[
              0.2722111984400043, 0.40344160712023436`, 0.9388133970995536], 
             UndirectedEdge[129, 253] -> 
             RGBColor[
              0.7019704357093536, 0.765439928015575, 0.9724266728496975], 
             UndirectedEdge[14, 69] -> 
             RGBColor[
              0.638580023437239, 0.7059262890900864, 0.9109931813727734], 
             UndirectedEdge[118, 124] -> 
             RGBColor[
              0.6610049618976606, 0.7262870253630389, 0.8871390656258705], 
             UndirectedEdge[181, 245] -> 
             RGBColor[
              0.5256774203050174, 0.623575962758223, 0.956570108667474], 
             UndirectedEdge[33, 152] -> 
             RGBColor[
              0.5974434710227459, 0.677756520241916, 0.9645746393407981], 
             UndirectedEdge[47, 371] -> 
             RGBColor[
              0.5503707807710646, 0.6433974519924154, 0.9588066318800146], 
             UndirectedEdge[131, 273] -> 
             RGBColor[
              0.6867291695797949, 0.7533154642143431, 0.9709401349830562], 
             UndirectedEdge[230, 299] -> 
             RGBColor[
              0.5580229089141671, 0.6415058806773845, 0.9617950592349305], 
             UndirectedEdge[107, 181] -> 
             RGBColor[
              0.6340322738111888, 0.7134041225041847, 0.9645860527640033], 
             UndirectedEdge[4, 318] -> 
             RGBColor[
              0.7807623429198213, 0.8279317181669035, 0.9409690487620226], 
             UndirectedEdge[10, 333] -> 
             RGBColor[
              0.5254069701126278, 0.6226538415501153, 0.9568440153633991], 
             UndirectedEdge[152, 238] -> 
             RGBColor[
              0.4688775467454064, 0.5764099344703422, 0.9522385616074367], 
             UndirectedEdge[50, 147] -> 
             RGBColor[
              0.36034625795275677`, 0.48359835684244823`, 0.944289467835722], 
             UndirectedEdge[39, 217] -> 
             RGBColor[
              0.5440354885338848, 0.6379537584222108, 0.9583844913946711], 
             UndirectedEdge[98, 308] -> 
             RGBColor[
              0.6499507316178997, 0.7181185342686581, 0.93110705379107], 
             UndirectedEdge[31, 363] -> 
             RGBColor[
              0.46357713163705755`, 0.571349657917635, 0.9520088777641257], 
             UndirectedEdge[286, 386] -> 
             RGBColor[
              0.744648471423672, 0.7984255315562094, 0.9331018846056114], 
             UndirectedEdge[137, 138] -> 
             RGBColor[
              0.6229390633855416, 0.6990202989167649, 0.9665763288192496], 
             UndirectedEdge[35, 372] -> 
             RGBColor[
              0.4246594484839896, 0.5417796542497288, 0.9484072087186067], 
             UndirectedEdge[130, 158] -> 
             RGBColor[
              0.7519026587085469, 0.7972513828400943, 0.6855599464826599], 
             UndirectedEdge[277, 373] -> 
             RGBColor[
              0.5975497339672291, 0.6796799127823413, 0.96375197366721], 
             UndirectedEdge[234, 365] -> 
             RGBColor[
              0.5420555755047536, 0.6361799506819661, 0.9582832651470232], 
             UndirectedEdge[310, 316] -> 
             RGBColor[
              0.7271643416377334, 0.7857276980537706, 0.9718655510269453], 
             UndirectedEdge[218, 305] -> 
             RGBColor[
              0.32902405792351164`, 0.45853648376194667`, 0.9422179311113524],
              UndirectedEdge[155, 279] -> 
             RGBColor[
              0.5945571639902097, 0.6788583180889154, 0.9628119645207635], 
             UndirectedEdge[32, 129] -> 
             RGBColor[
              0.536087555966579, 0.6342590542596729, 0.9566219226405628], 
             UndirectedEdge[92, 158] -> 
             RGBColor[
              0.9569692232956604, 0.9602615855300034, 0.7044283763552663], 
             UndirectedEdge[332, 334] -> 
             RGBColor[
              0.5834761647835265, 0.6727312617297696, 0.9603525275168268], 
             UndirectedEdge[268, 300] -> 
             RGBColor[
              0.27405846878110157`, 0.4046065757193509, 0.9389470326287013], 
             UndirectedEdge[224, 227] -> 
             RGBColor[
              0.38840924456149195`, 0.5010992767820838, 0.9469311673167332], 
             UndirectedEdge[25, 91] -> 
             RGBColor[
              0.5858968697656957, 0.6742235256551642, 0.9608664687980355], 
             UndirectedEdge[74, 304] -> 
             RGBColor[
              0.28722871498758484`, 0.41922596917728516`, 0.9396686224505135],
              UndirectedEdge[86, 397] -> 
             RGBColor[
              0.848733553534806, 0.8805911794469663, 0.8855356350125692], 
             UndirectedEdge[32, 111] -> 
             RGBColor[
              0.5787458495904977, 0.6688909787577979, 0.9599801397771159], 
             UndirectedEdge[59, 394] -> 
             RGBColor[
              0.5165805432108164, 0.6168717280893233, 0.9555147095802649], 
             UndirectedEdge[170, 355] -> 
             RGBColor[
              0.8181874262604476, 0.8587945796314043, 0.9805333094155957], 
             UndirectedEdge[9, 56] -> 
             RGBColor[
              0.7008401397430547, 0.7643908402548727, 0.970713593961114], 
             UndirectedEdge[44, 317] -> 
             RGBColor[
              0.32568709891066594`, 0.45245720399779493`, 0.9421220669784285],
              UndirectedEdge[236, 262] -> 
             RGBColor[
              0.5938877997400259, 0.6797607279556609, 0.9621419845948258], 
             UndirectedEdge[119, 346] -> 
             RGBColor[
              0.34282312738850645`, 0.4699088135811961, 0.9431184223924018], 
             UndirectedEdge[80, 244] -> 
             RGBColor[
              0.3586159143362778, 0.48134502800221945`, 0.9442068411863395], 
             UndirectedEdge[20, 360] -> 
             RGBColor[
              0.6687659084669344, 0.7335268600887085, 0.9066615145574488], 
             UndirectedEdge[196, 206] -> 
             RGBColor[
              0.5119115669703287, 0.6071606972220696, 0.9569499188151405], 
             UndirectedEdge[187, 302] -> 
             RGBColor[
              0.7623671940214056, 0.8115428073157169, 0.8816124406104114], 
             UndirectedEdge[147, 312] -> 
             RGBColor[
              0.36548287734773527`, 0.4880292458021607, 0.9446217953472134], 
             UndirectedEdge[259, 400] -> 
             RGBColor[
              0.5383747745089141, 0.6361159213103615, 0.956801980862573], 
             UndirectedEdge[120, 312] -> 
             RGBColor[
              0.7187739091816123, 0.7774332287036032, 0.9314359485453594], 
             UndirectedEdge[52, 60] -> 
             RGBColor[
              0.33316070981459833`, 0.4629887945224097, 0.942449683720306], 
             UndirectedEdge[266, 384] -> 
             RGBColor[
              0.6458106310229554, 0.7207487403089194, 0.9670294619267191], 
             UndirectedEdge[135, 393] -> 
             RGBColor[
              0.6567330590288261, 0.7317641241602137, 0.9664206718707746], 
             UndirectedEdge[77, 244] -> 
             RGBColor[
              0.5350742776557517, 0.6333033191171218, 0.9565789323945788], 
             UndirectedEdge[239, 385] -> 
             RGBColor[
              0.47057742910311023`, 0.5761463427829403, 0.9526406590166561], 
             UndirectedEdge[278, 296] -> 
             RGBColor[
              0.9831524350708742, 0.9853472511147432, 0.8413733456491058], 
             UndirectedEdge[267, 275] -> 
             RGBColor[
              0.6601773556782919, 0.7322533233320168, 0.9682815037126937], 
             UndirectedEdge[148, 340] -> 
             RGBColor[
              0.7035380422715775, 0.7667125816426592, 0.9725500805806078], 
             UndirectedEdge[202, 212] -> 
             RGBColor[
              0.4047373379863967, 0.5249848722988862, 0.947010483174686], 
             UndirectedEdge[81, 346] -> 
             RGBColor[
              0.4194718836309498, 0.5377471951564007, 0.9479493553939098], 
             UndirectedEdge[50, 217] -> 
             RGBColor[
              0.4146780599632106, 0.5335950260399883, 0.9476438971888133], 
             UndirectedEdge[5, 183] -> 
             RGBColor[
              0.976698898471791, 0.9792048301895663, 0.7549047808011962], 
             UndirectedEdge[313, 339] -> 
             RGBColor[
              0.7559581648551039, 0.8093480311193512, 0.9765865103243307], 
             UndirectedEdge[4, 184] -> 
             RGBColor[
              0.5219849179199055, 0.6228098973767794, 0.9555117113138634], 
             UndirectedEdge[104, 349] -> 
             RGBColor[
              0.6094616375679165, 0.692456203400304, 0.9633357205059521], 
             UndirectedEdge[119, 135] -> 
             RGBColor[
              0.4728146038219686, 0.5769349017259804, 0.9530029053592897], 
             UndirectedEdge[53, 273] -> 
             RGBColor[
              0.6476964504662999, 0.7202746063734053, 0.9682409913883305], 
             UndirectedEdge[224, 259] -> 
             RGBColor[
              0.42261115586038545`, 0.5288659291530708, 0.9496236670599113], 
             UndirectedEdge[110, 289] -> 
             RGBColor[
              0.5468149284517685, 0.6310077696943881, 0.9609625388053505], 
             UndirectedEdge[59, 155] -> 
             RGBColor[
              0.528210112659526, 0.6269446766266396, 0.9562557354619121], 
             UndirectedEdge[5, 29] -> 
             RGBColor[
              0.9745598119992768, 0.9796768992485436, 0.8889681161406762], 
             UndirectedEdge[119, 311] -> 
             RGBColor[
              0.3372424505673074, 0.46507511181164624`, 0.9427628266001538], 
             UndirectedEdge[68, 72] -> 
             RGBColor[
              0.503758039988099, 0.6080124967602453, 0.9540768247158177], 
             UndirectedEdge[121, 234] -> 
             RGBColor[
              0.5356761728992517, 0.6311963128812926, 0.9576474259142137], 
             UndirectedEdge[20, 336] -> 
             RGBColor[
              0.6753154381781294, 0.7391997335356109, 0.9070788447991245], 
             UndirectedEdge[17, 256] -> 
             RGBColor[
              0.6105595439214322, 0.6841426321788848, 0.9649142664044581], 
             UndirectedEdge[186, 272] -> 
             RGBColor[
              0.753082598609375, 0.807343185976001, 0.9759806921538725], 
             UndirectedEdge[45, 304] -> 
             RGBColor[
              0.33327997157940753`, 0.46151741709482863`, 0.9425149395756492],
              UndirectedEdge[165, 252] -> 
             RGBColor[
              0.6443513184452581, 0.7212792060348343, 0.9657418869180607], 
             UndirectedEdge[106, 254] -> 
             RGBColor[
              0.3146315875989949, 0.4440859439379146, 0.9413735180936386], 
             UndirectedEdge[144, 169] -> 
             RGBColor[
              0.6345971338641131, 0.6488102854779446, 0.6109607985394028], 
             UndirectedEdge[191, 355] -> 
             RGBColor[
              0.5575611655748707, 0.6498255574818879, 0.9591800815172253], 
             UndirectedEdge[96, 377] -> 
             RGBColor[
              0.9371484985147296, 0.8665693343875762, 0.6266661867372381], 
             UndirectedEdge[110, 303] -> 
             RGBColor[
              0.37293087945414594`, 0.49262548888191776`, 0.9453401520155132],
              UndirectedEdge[177, 260] -> 
             RGBColor[
              0.3439507117552165, 0.4692532687520168, 0.9432500339721692], 
             UndirectedEdge[20, 88] -> 
             RGBColor[
              0.796399491903795, 0.839928834296838, 0.9159402688539411], 
             UndirectedEdge[57, 68] -> 
             RGBColor[
              0.45523224158458353`, 0.5661837261593867, 0.9509290355871036], 
             UndirectedEdge[127, 264] -> 
             RGBColor[
              0.6250700009699135, 0.6756574960589836, 0.662573778927535], 
             UndirectedEdge[171, 186] -> 
             RGBColor[
              0.8777608954018938, 0.9053667280814237, 0.9882028118614761], 
             UndirectedEdge[362, 385] -> 
             RGBColor[
              0.6251268244346129, 0.7065451435753562, 0.9636314200159537], 
             UndirectedEdge[109, 370] -> 
             RGBColor[
              0.8530600963867476, 0.8854325761250258, 0.9533942926731969], 
             UndirectedEdge[123, 161] -> 
             RGBColor[
              0.8656147042951388, 0.8923420645408198, 0.7998298950216514], 
             UndirectedEdge[119, 213] -> 
             RGBColor[
              0.3305608383557335, 0.45928783514157534`, 0.9423370801783499], 
             UndirectedEdge[140, 360] -> 
             RGBColor[
              0.6293686520313576, 0.7038482278791042, 0.9673271660233869], 
             UndirectedEdge[320, 347] -> 
             RGBColor[
              0.359735163209457, 0.4786100139322733, 0.9446019599105193], 
             UndirectedEdge[10, 345] -> 
             RGBColor[
              0.3376154857793054, 0.4667027168742303, 0.9427388319127068], 
             UndirectedEdge[169, 383] -> 
             RGBColor[
              0.3853620439560417, 0.5081879430529411, 0.9457800575786848], 
             UndirectedEdge[154, 372] -> 
             RGBColor[
              0.33883121872835975`, 0.4669650634187544, 0.9428452472854076], 
             UndirectedEdge[167, 341] -> 
             RGBColor[
              0.8318686418439469, 0.8672021830053714, 0.8741510635732026], 
             UndirectedEdge[186, 308] -> 
             RGBColor[
              0.595435492085214, 0.675764503827203, 0.964563073178721], 
             UndirectedEdge[145, 225] -> 
             RGBColor[
              0.5929702898584492, 0.6802812113409699, 0.9612078345798512], 
             UndirectedEdge[12, 65] -> 
             RGBColor[
              0.49011569884327577`, 0.5951627934714842, 0.9534930763866173], 
             UndirectedEdge[274, 288] -> 
             RGBColor[
              0.7468905900612384, 0.801158810236118, 0.9577669969395448], 
             UndirectedEdge[143, 171] -> 
             RGBColor[
              0.639197413543629, 0.7131285554291978, 0.9676002854982564], 
             UndirectedEdge[167, 168] -> 
             RGBColor[
              0.5228652183966005, 0.6209254052983326, 0.9564818182851422], 
             UndirectedEdge[203, 341] -> 
             RGBColor[
              0.8810131054076524, 0.9055942114530949, 0.8790493244201095], 
             UndirectedEdge[114, 299] -> 
             RGBColor[
              0.5771031084006756, 0.6609525853558591, 0.962903902711716], 
             UndirectedEdge[154, 231] -> 
             RGBColor[
              0.646117222880012, 0.7099688535832424, 0.7427589127843837], 
             UndirectedEdge[218, 384] -> 
             RGBColor[
              0.5850183931858184, 0.6688258952409845, 0.9629534877136481], 
             UndirectedEdge[360, 380] -> 
             RGBColor[
              0.3272126832330449, 0.4573623764342488, 0.9420880558290632], 
             UndirectedEdge[98, 306] -> 
             RGBColor[
              0.9646157906216961, 0.973131095098762, 0.9447804161843452], 
             UndirectedEdge[57, 262] -> 
             RGBColor[
              0.5492239685467881, 0.6410751622455066, 0.9592960447658678], 
             UndirectedEdge[152, 160] -> 
             RGBColor[
              0.43547306024559973`, 0.5492906674748316, 0.9496088380655059], 
             UndirectedEdge[311, 354] -> 
             RGBColor[
              0.6601071912640162, 0.7293305648585691, 0.9669999631026704], 
             UndirectedEdge[287, 303] -> 
             RGBColor[
              0.4913413725799739, 0.5979320867938371, 0.9530993391736987], 
             UndirectedEdge[222, 247] -> 
             RGBColor[
              0.5712557622362792, 0.6509687110029703, 0.9632221492945566], 
             UndirectedEdge[24, 206] -> 
             RGBColor[
              0.7496706946012027, 0.804367711421546, 0.9756838268330454], 
             UndirectedEdge[92, 308] -> 
             RGBColor[
              0.6223735759289075, 0.6972442006693577, 0.9671324516636439], 
             UndirectedEdge[18, 266] -> 
             RGBColor[
              0.7199888675156664, 0.7792079010765671, 0.9526752707793587], 
             UndirectedEdge[28, 314] -> 
             RGBColor[
              0.6772159940285458, 0.7391799275771429, 0.8459667423896258], 
             UndirectedEdge[128, 139] -> 
             RGBColor[
              0.8641730185995239, 0.8945321239523041, 0.9869067880420253], 
             UndirectedEdge[160, 181] -> 
             RGBColor[
              0.6025906857099605, 0.6878784248562053, 0.9621108557743425], 
             UndirectedEdge[42, 296] -> 
             RGBColor[
              0.7172337497705495, 0.7765503546911439, 0.9411714697802616], 
             UndirectedEdge[121, 289] -> 
             RGBColor[
              0.7599179660642419, 0.8124440373565346, 0.97668631674968], 
             UndirectedEdge[22, 286] -> 
             RGBColor[
              0.8149428124938938, 0.8554392941706245, 0.9386728721533035], 
             UndirectedEdge[128, 213] -> 
             RGBColor[
              0.6144082622281423, 0.6925119675666762, 0.9656273560285678], 
             UndirectedEdge[178, 398] -> 
             RGBColor[
              0.7680013276239851, 0.8188149567007315, 0.9733089367297563], 
             UndirectedEdge[6, 129] -> 
             RGBColor[
              0.41563036026207073`, 0.5337595113471977, 0.9478870334140406], 
             UndirectedEdge[265, 375] -> 
             RGBColor[
              0.5547269203310463, 0.6452432238428722, 0.959899924798165], 
             UndirectedEdge[162, 270] -> 
             RGBColor[
              0.40045714409468225`, 0.5212775834786834, 0.9467377530047327], 
             UndirectedEdge[199, 271] -> 
             RGBColor[
              0.6583643864913633, 0.7253031974909505, 0.9301425409024044], 
             UndirectedEdge[60, 72] -> 
             RGBColor[
              0.388291695976127, 0.5105386467728696, 0.9460183495722224], 
             UndirectedEdge[230, 258] -> 
             RGBColor[
              0.3886768932322424, 0.5068809242151862, 0.9464457351093352], 
             UndirectedEdge[38, 135] -> 
             RGBColor[
              0.8113895807416804, 0.8198590778726754, 0.6524131833695896], 
             UndirectedEdge[42, 67] -> 
             RGBColor[
              0.7140572344036591, 0.7741813147315835, 0.9465484817285132], 
             UndirectedEdge[220, 352] -> 
             RGBColor[
              0.5267648353310687, 0.6225394808698901, 0.9574767276365947], 
             UndirectedEdge[4, 226] -> 
             RGBColor[
              0.462027526714771, 0.5710796556597189, 0.9516355112003907], 
             UndirectedEdge[134, 163] -> 
             RGBColor[
              0.7298495860753524, 0.7877335192936724, 0.9674051653557192], 
             UndirectedEdge[25, 76] -> 
             RGBColor[
              0.7265799892913798, 0.7847268808693799, 0.9577004124989287], 
             UndirectedEdge[250, 375] -> 
             RGBColor[
              0.8151380549659293, 0.8560080401267591, 0.9820771848255225], 
             UndirectedEdge[50, 138] -> 
             RGBColor[
              0.40160854991157147`, 0.5222748733259337, 0.9468111195652367], 
             UndirectedEdge[24, 157] -> 
             RGBColor[
              0.8546532349370692, 0.8871857381359582, 0.9792978277808495], 
             UndirectedEdge[127, 328] -> 
             RGBColor[
              0.7947653107355617, 0.8222683616356973, 0.6744004295665902], 
             UndirectedEdge[107, 245] -> 
             RGBColor[
              0.4931407111952894, 0.5975320626019024, 0.953755136589074], 
             UndirectedEdge[16, 96] -> 
             RGBColor[
              0.8957069036414638, 0.9195746857117436, 0.9863884387353976], 
             UndirectedEdge[42, 278] -> 
             RGBColor[
              0.7279547795830175, 0.7829376381079611, 0.8509941961862094], 
             UndirectedEdge[51, 176] -> 
             RGBColor[
              0.6327625593537074, 0.7107759202247232, 0.9655782410615784], 
             UndirectedEdge[33, 386] -> 
             RGBColor[
              0.6839357429193829, 0.7512598495272231, 0.9704759707249923], 
             UndirectedEdge[78, 187] -> 
             RGBColor[
              0.6913993821896602, 0.7574202387228054, 0.9709472053383935], 
             UndirectedEdge[107, 150] -> 
             RGBColor[
              0.6267530141816182, 0.707717509557142, 0.9638605241926765], 
             UndirectedEdge[312, 360] -> 
             RGBColor[
              0.40239995206107326`, 0.5229421535045832, 0.946866573676171], 
             UndirectedEdge[78, 208] -> 
             RGBColor[
              0.9172430726791625, 0.9352703434329698, 0.9343744478425202], 
             UndirectedEdge[28, 197] -> 
             RGBColor[
              0.8896891279072603, 0.9120098438577706, 0.8634929991854955], 
             UndirectedEdge[221, 316] -> 
             RGBColor[
              0.635690596413732, 0.7133848568820396, 0.9656502473483194], 
             UndirectedEdge[243, 383] -> 
             RGBColor[
              0.47333952948541336`, 0.5833173795958833, 0.9516821681423708], 
             UndirectedEdge[83, 332] -> 
             RGBColor[
              0.4969483881646138, 0.6018519737015355, 0.9537154064040783], 
             UndirectedEdge[98, 354] -> 
             RGBColor[
              0.9588687963659714, 0.9688449961926819, 0.9545085784031275], 
             UndirectedEdge[46, 215] -> 
             RGBColor[
              0.9774793821471456, 0.9482743238440345, 0.6116565472439084], 
             UndirectedEdge[375, 381] -> 
             RGBColor[
              0.68209819494029, 0.7511659813165054, 0.9692315983357268], 
             UndirectedEdge[286, 304] -> 
             RGBColor[
              0.6378465974281622, 0.7057563697491529, 0.9259640999359016], 
             UndirectedEdge[225, 235] -> 
             RGBColor[
              0.47329427391105794`, 0.5821942917848066, 0.9519787664527364], 
             UndirectedEdge[96, 225] -> 
             RGBColor[
              0.7364613901182111, 0.7932430055348794, 0.9717269529634018], 
             UndirectedEdge[20, 389] -> 
             RGBColor[
              0.6814645767248898, 0.7445258082801247, 0.9074706624698543], 
             UndirectedEdge[259, 393] -> 
             RGBColor[
              0.6377469523289345, 0.7165065565470966, 0.9648192149743318], 
             UndirectedEdge[97, 166] -> 
             RGBColor[
              0.3311638938560285, 0.4593403383686471, 0.9423927092342417], 
             UndirectedEdge[115, 334] -> 
             RGBColor[
              0.5259314452493953, 0.6258903935505874, 0.955856512221843], 
             UndirectedEdge[251, 260] -> 
             RGBColor[
              0.35255676815185377`, 0.4782987796803737, 0.9437401361524382], 
             UndirectedEdge[119, 344] -> 
             RGBColor[
              0.31457892552139133`, 0.4454451055187634, 0.9413187268247962], 
             UndirectedEdge[329, 341] -> 
             RGBColor[
              0.6608852838147175, 0.725480891885874, 0.8613118241671256], 
             UndirectedEdge[283, 334] -> 
             RGBColor[
              0.7507541280390571, 0.8052465183091809, 0.9760348458632149], 
             UndirectedEdge[1, 5] -> 
             RGBColor[
              0.9736047576254765, 0.9792819597211992, 0.9047958387160369], 
             UndirectedEdge[364, 391] -> 
             RGBColor[
              0.6345706519166576, 0.6840520951711841, 0.6604919168416962], 
             UndirectedEdge[48, 295] -> 
             RGBColor[
              0.4520242509029363, 0.5639189920847165, 0.9505826424911834], 
             UndirectedEdge[105, 199] -> 
             RGBColor[
              0.4161574068875941, 0.5337112031987561, 0.948060096712797], 
             UndirectedEdge[281, 293] -> 
             RGBColor[
              0.6498332467465647, 0.7162680502671088, 0.8738349797268632], 
             UndirectedEdge[216, 358] -> 
             RGBColor[
              0.6561982593613898, 0.7264355261314758, 0.9693364891888916], 
             UndirectedEdge[100, 206] -> 
             RGBColor[
              0.8418990687146684, 0.8770869448056349, 0.9711857588211894], 
             UndirectedEdge[168, 341] -> 
             RGBColor[
              0.68310803470643, 0.744729121760339, 0.8627278382031386], 
             UndirectedEdge[199, 259] -> 
             RGBColor[
              0.4753344816955115, 0.5817538184246631, 0.9527187328144439], 
             UndirectedEdge[19, 24] -> 
             RGBColor[
              0.7128067897975889, 0.7755693488129095, 0.9720095773149979], 
             UndirectedEdge[136, 299] -> 
             RGBColor[
              0.5540473785029254, 0.637327346151983, 0.9615686586592805], 
             UndirectedEdge[64, 123] -> 
             RGBColor[
              0.6935172142065389, 0.7605001857549767, 0.9700869726914149], 
             UndirectedEdge[101, 334] -> 
             RGBColor[
              0.795931731298184, 0.8391405602968811, 0.8988255027835956], 
             UndirectedEdge[2, 328] -> 
             RGBColor[
              0.5404179089736287, 0.6377746299109757, 0.9569628238918835], 
             UndirectedEdge[235, 349] -> 
             RGBColor[
              0.5725906832180008, 0.6614363543444033, 0.9607332649117261], 
             UndirectedEdge[45, 290] -> 
             RGBColor[
              0.626275132807457, 0.7022080152672222, 0.966651631261254], 
             UndirectedEdge[225, 327] -> 
             RGBColor[
              0.5435836048609571, 0.6403446844452834, 0.9572120390684601], 
             UndirectedEdge[24, 386] -> 
             RGBColor[
              0.6357798520063465, 0.7132960304704028, 0.9657675474458479], 
             UndirectedEdge[363, 393] -> 
             RGBColor[
              0.4843400928741363, 0.5879217898274874, 0.953837706391427], 
             UndirectedEdge[2, 258] -> 
             RGBColor[
              0.4870100011571516, 0.594415684346731, 0.9527583577489578], 
             UndirectedEdge[8, 234] -> 
             RGBColor[
              0.6199907322524667, 0.6973843914839499, 0.9659659551657649], 
             UndirectedEdge[44, 151] -> 
             RGBColor[
              0.5256697145980711, 0.6236436983331782, 0.9565381238825811], 
             UndirectedEdge[253, 283] -> 
             RGBColor[
              0.9123593400786949, 0.9329545887169428, 0.9915028424011455], 
             UndirectedEdge[257, 360] -> 
             RGBColor[
              0.5114233645755857, 0.6109976751508841, 0.9557601058990972], 
             UndirectedEdge[65, 358] -> 
             RGBColor[
              0.7595589894637016, 0.8121888717243095, 0.9769649030679572], 
             UndirectedEdge[282, 340] -> 
             RGBColor[
              0.4902663653116426, 0.5970593474648802, 0.9530147106636542], 
             UndirectedEdge[256, 316] -> 
             RGBColor[
              0.7266742817222694, 0.785362212171217, 0.9726950946357293], 
             UndirectedEdge[96, 182] -> 
             RGBColor[
              0.9099517299192211, 0.9309331235201187, 0.9877471229822767], 
             UndirectedEdge[2, 106] -> 
             RGBColor[
              0.37585236705523156`, 0.49655547558778956`, 0.9454283059429177],
              UndirectedEdge[210, 279] -> 
             RGBColor[
              0.8163892803557976, 0.8568375265864644, 0.9822411647071694], 
             UndirectedEdge[279, 371] -> 
             RGBColor[
              0.5834657585219168, 0.6692515001425281, 0.9621052299720686], 
             UndirectedEdge[271, 353] -> 
             RGBColor[
              0.6227478006490169, 0.6903955765817305, 0.9280216786833069], 
             UndirectedEdge[306, 311] -> 
             RGBColor[
              0.6658541855197407, 0.7336166637646491, 0.9572718008838881], 
             UndirectedEdge[64, 312] -> 
             RGBColor[
              0.5520661872876876, 0.6471119652770088, 0.9579613589179501], 
             UndirectedEdge[137, 210] -> 
             RGBColor[
              0.8747538833101005, 0.9029690182625965, 0.9879160003637695], 
             UndirectedEdge[264, 394] -> 
             RGBColor[
              0.3319140738232338, 0.4581066006884683, 0.9425094744146063], 
             UndirectedEdge[199, 224] -> 
             RGBColor[
              0.28336158425969976`, 0.412633700558971, 0.9395409454218607], 
             UndirectedEdge[61, 301] -> 
             RGBColor[
              0.7740492457317901, 0.8234124208486118, 0.9781136529792294], 
             UndirectedEdge[48, 103] -> 
             RGBColor[
              0.2775681108283568, 0.4028346258994665, 0.9393468484142906], 
             UndirectedEdge[7, 14] -> 
             RGBColor[
              0.6233569781338718, 0.6948692043193421, 0.9500279463635204], 
             UndirectedEdge[88, 195] -> 
             RGBColor[
              0.7923756574800634, 0.8153999900681927, 0.6668890539279788], 
             UndirectedEdge[211, 341] -> 
             RGBColor[
              0.6664740887130893, 0.7303216337873419, 0.8616679378732638], 
             UndirectedEdge[84, 185] -> 
             RGBColor[
              0.8146507375951428, 0.8557004083612332, 0.9820092245739607], 
             UndirectedEdge[368, 387] -> 
             RGBColor[
              0.6777076980214349, 0.7395280822374346, 0.8431409182370664], 
             UndirectedEdge[134, 171] -> 
             RGBColor[
              0.7006908443990546, 0.7646955031787891, 0.971987083940127], 
             UndirectedEdge[41, 295] -> 
             RGBColor[
              0.7041148322522393, 0.7675130717839046, 0.9722131015095059], 
             UndirectedEdge[77, 388] -> 
             RGBColor[
              0.7582356924480722, 0.8113469999649813, 0.9765931936746838], 
             UndirectedEdge[142, 273] -> 
             RGBColor[
              0.7904870975501594, 0.8368349080496684, 0.9795978150571389], 
             UndirectedEdge[64, 140] -> 
             RGBColor[
              0.779034887257972, 0.8280180396515296, 0.978421951265166], 
             UndirectedEdge[150, 157] -> 
             RGBColor[
              0.7975377526543451, 0.8425666892829513, 0.9736050902814357], 
             UndirectedEdge[210, 264] -> 
             RGBColor[
              0.5653757596375314, 0.6461587577233335, 0.9626797004826595], 
             UndirectedEdge[202, 309] -> 
             RGBColor[
              0.6112700293366202, 0.6933398578263583, 0.9638744827948433], 
             UndirectedEdge[105, 287] -> 
             RGBColor[
              0.49895131417107563`, 0.6041101802014553, 0.9536984216518848], 
             UndirectedEdge[157, 160] -> 
             RGBColor[
              0.7408387150729596, 0.796683704425694, 0.9690404497847016], 
             UndirectedEdge[153, 379] -> 
             RGBColor[
              0.9549742413127892, 0.9005476160371537, 0.6125394588482669], 
             UndirectedEdge[207, 387] -> 
             RGBColor[
              0.9900236653558012, 0.9901425434915875, 0.8149972131882132], 
             UndirectedEdge[93, 264] -> 
             RGBColor[
              0.2801254754326875, 0.411760014033688, 0.9392641034661633], 
             UndirectedEdge[202, 365] -> 
             RGBColor[
              0.5784220930540995, 0.6676788003488909, 0.9606005074876187], 
             UndirectedEdge[138, 230] -> 
             RGBColor[
              0.3183308712018552, 0.4472235388034417, 0.9416116694799503], 
             UndirectedEdge[5, 291] -> 
             RGBColor[
              0.6476865777036952, 0.7173156275000642, 0.9478658862323905], 
             UndirectedEdge[241, 360] -> 
             RGBColor[
              0.3756867776661881, 0.4998227370731382, 0.945159407159484], 
             UndirectedEdge[299, 300] -> 
             RGBColor[
              0.5780161556684531, 0.661743421008118, 0.9629620812762428], 
             UndirectedEdge[9, 266] -> 
             RGBColor[
              0.4721743342829432, 0.5823714216390723, 0.9515904397077817], 
             UndirectedEdge[226, 322] -> 
             RGBColor[
              0.3767765113607663, 0.5007666096277738, 0.9452288440268889], 
             UndirectedEdge[175, 216] -> 
             RGBColor[
              0.46609177150242076`, 0.5755928746095643, 0.9516201195019556], 
             UndirectedEdge[115, 257] -> 
             RGBColor[
              0.5604027232978094, 0.6534211339019257, 0.9588810273261309], 
             UndirectedEdge[146, 275] -> 
             RGBColor[
              0.6354605724876392, 0.7120232972174564, 0.9663809741754945], 
             UndirectedEdge[64, 101] -> 
             RGBColor[
              0.8194577651384296, 0.8581207926858611, 0.9007590982343359], 
             UndirectedEdge[79, 390] -> 
             RGBColor[
              0.7105969939571433, 0.7730973838504724, 0.9723530137718386], 
             UndirectedEdge[98, 378] -> 
             RGBColor[
              0.9737070528933056, 0.9799113436153526, 0.9293912805394616], 
             UndirectedEdge[37, 80] -> 
             RGBColor[
              0.3983461558258563, 0.5137329380325955, 0.947297772598664], 
             UndirectedEdge[344, 354] -> 
             RGBColor[0.6374436662181, 0.7097005585656861, 0.965555863327313],
              UndirectedEdge[119, 227] -> 
             RGBColor[
              0.41962658582318346`, 0.5339106817418762, 0.9487089487196687], 
             UndirectedEdge[81, 166] -> 
             RGBColor[
              0.36718087287371515`, 0.49053643532776603`, 0.9446876792886847],
              UndirectedEdge[192, 221] -> 
             RGBColor[
              0.6196604208806248, 0.7003708382330849, 0.9643882932098854], 
             UndirectedEdge[242, 331] -> 
             RGBColor[
              0.47329427391105794`, 0.5821942917848066, 0.9519787664527364], 
             UndirectedEdge[225, 322] -> 
             RGBColor[
              0.4729980940360805, 0.5819377556635345, 0.9519598941330044], 
             UndirectedEdge[165, 170] -> 
             RGBColor[
              0.8184976073438258, 0.8590368954512028, 0.9805642253671798], 
             UndirectedEdge[41, 250] -> 
             RGBColor[
              0.8809153931464201, 0.9078820389563487, 0.9885036906724023], 
             UndirectedEdge[31, 393] -> 
             RGBColor[
              0.640146890124593, 0.7184549341655778, 0.9650081468688678], 
             UndirectedEdge[140, 312] -> 
             RGBColor[
              0.6809567189516281, 0.748513025967587, 0.9706193386957876], 
             UndirectedEdge[56, 100] -> 
             RGBColor[
              0.9441595770169651, 0.9578748844863292, 0.9794074499821706], 
             UndirectedEdge[89, 183] -> 
             RGBColor[
              0.8799754283995127, 0.9031331615994389, 0.7670118737625318], 
             UndirectedEdge[39, 210] -> 
             RGBColor[
              0.7827807984068047, 0.8305823250539879, 0.9788913853156143], 
             UndirectedEdge[34, 321] -> 
             RGBColor[
              0.40592228232110983`, 0.5237932330858539, 0.9475383119802647], 
             UndirectedEdge[148, 301] -> 
             RGBColor[
              0.8351642189935705, 0.8720152370205088, 0.9839769813896261], 
             UndirectedEdge[136, 155] -> 
             RGBColor[
              0.3443380443495847, 0.4690145151263228, 0.9432957402624143], 
             UndirectedEdge[51, 205] -> 
             RGBColor[
              0.4779004701015447, 0.587020156656092, 0.9520412220949487], 
             UndirectedEdge[11, 123] -> 
             RGBColor[
              0.7262735603712274, 0.786089692336283, 0.9733518191516521], 
             UndirectedEdge[223, 400] -> 
             RGBColor[
              0.3795932324456107, 0.5018820223946538, 0.9455143920562441], 
             UndirectedEdge[6, 201] -> 
             RGBColor[
              0.32956485975504224`, 0.4595747968990903, 0.9422315237766932], 
             UndirectedEdge[201, 273] -> 
             RGBColor[
              0.5986938158634956, 0.6775315341900738, 0.9651295512852649], 
             UndirectedEdge[54, 196] -> 
             RGBColor[
              0.3182503705233659, 0.44840787454236736`, 0.9415606227175874], 
             UndirectedEdge[84, 288] -> 
             RGBColor[
              0.9234054233610658, 0.9412303989647379, 0.9741103804892353], 
             UndirectedEdge[177, 248] -> 
             RGBColor[
              0.45363813593863733`, 0.5594112502639255, 0.9515786680432092], 
             UndirectedEdge[76, 117] -> 
             RGBColor[
              0.7161194541078532, 0.7762345471656531, 0.9568769208510786], 
             UndirectedEdge[342, 348] -> 
             RGBColor[
              0.8711858841283188, 0.8994269168583588, 0.9468150976490154], 
             UndirectedEdge[332, 389] -> 
             RGBColor[
              0.47003463165511317`, 0.5785406305377405, 0.9520004856381933], 
             UndirectedEdge[68, 236] -> 
             RGBColor[
              0.4998960727778213, 0.6048692918695411, 0.9537749754160616], 
             UndirectedEdge[84, 318] -> 
             RGBColor[
              0.934393210631723, 0.9494250727203436, 0.9555109227139035], 
             UndirectedEdge[15, 372] -> 
             RGBColor[
              0.4313200530475269, 0.5471870330912245, 0.9489315559084468], 
             UndirectedEdge[88, 189] -> 
             RGBColor[
              0.651600966169198, 0.727199131681137, 0.9662891306949399], 
             UndirectedEdge[364, 380] -> 
             RGBColor[
              0.295802386819937, 0.42823744187527835`, 0.9401568803777551], 
             UndirectedEdge[103, 295] -> 
             RGBColor[
              0.3533831400745795, 0.46647836618525007`, 0.9447367940768928], 
             UndirectedEdge[20, 257] -> 
             RGBColor[
              0.8293773879017172, 0.8662471798234923, 0.9188472194527757], 
             UndirectedEdge[12, 24] -> 
             RGBColor[
              0.5771078362720669, 0.6638892087861981, 0.9616388981838325], 
             UndirectedEdge[152, 157] -> 
             RGBColor[
              0.6376993868195548, 0.7096655448486203, 0.961828601143926], 
             UndirectedEdge[26, 70] -> 
             RGBColor[
              0.6223671877796209, 0.7021346353089082, 0.9648978879906214], 
             UndirectedEdge[33, 74] -> 
             RGBColor[
              0.5726480561170086, 0.653875814043193, 0.9630827256520968], 
             UndirectedEdge[124, 238] -> 
             RGBColor[
              0.797214405789108, 0.8401348367011312, 0.8969593319929379], 
             UndirectedEdge[148, 339] -> 
             RGBColor[
              0.7613776931626965, 0.8136694158826485, 0.9771034297723791], 
             UndirectedEdge[175, 229] -> 
             RGBColor[
              0.44703412415483806`, 0.559086098342295, 0.9504057830649835], 
             UndirectedEdge[105, 337] -> 
             RGBColor[
              0.717212402114646, 0.7776636275548392, 0.9714941368274913], 
             UndirectedEdge[158, 306] -> 
             RGBColor[
              0.97022699921578, 0.9704565491435112, 0.6926419533390151], 
             UndirectedEdge[136, 268] -> 
             RGBColor[
              0.25008969161557393`, 0.38019050086321593`, 0.937553610011739], 
             UndirectedEdge[133, 278] -> 
             RGBColor[
              0.748446846219601, 0.7995740209606215, 0.8526074067367547], 
             UndirectedEdge[197, 254] -> 
             RGBColor[
              0.5683405049398484, 0.6554860795048083, 0.9614227888920928], 
             UndirectedEdge[296, 398] -> 
             RGBColor[
              0.783886988284741, 0.8306624564111411, 0.9464186568749564], 
             UndirectedEdge[10, 271] -> 
             RGBColor[
              0.6743462993257054, 0.7391459271137625, 0.9311608942559582], 
             UndirectedEdge[221, 399] -> 
             RGBColor[
              0.8706456558405764, 0.8860517134827501, 0.6873812254323326], 
             UndirectedEdge[187, 388] -> 
             RGBColor[
              0.7144757984210275, 0.775820746633066, 0.9731482545191013], 
             UndirectedEdge[143, 186] -> 
             RGBColor[
              0.6313412094669322, 0.7068642315494185, 0.9668509537401049], 
             UndirectedEdge[372, 387] -> 
             RGBColor[
              0.6867283403142959, 0.7473413092008463, 0.8437157055873268], 
             UndirectedEdge[147, 255] -> 
             RGBColor[
              0.5777765022138615, 0.657233813632928, 0.9636826659304004], 
             UndirectedEdge[27, 86] -> 
             RGBColor[
              0.8216168479532187, 0.8614899042852338, 0.981696902911043], 
             UndirectedEdge[19, 157] -> 
             RGBColor[
              0.8012185965074343, 0.845442192476434, 0.9739719623972702], 
             UndirectedEdge[192, 208] -> 
             RGBColor[
              0.7347543643528276, 0.7900457417738292, 0.917909701433322], 
             UndirectedEdge[88, 89] -> 
             RGBColor[
              0.686160240120874, 0.7541970991523965, 0.969733676147666], 
             UndirectedEdge[54, 332] -> 
             RGBColor[
              0.4548188048673844, 0.5653614461439008, 0.9510309466101066], 
             UndirectedEdge[282, 301] -> 
             RGBColor[
              0.6218925420336356, 0.7023620028427298, 0.9644416114726726], 
             UndirectedEdge[264, 328] -> 
             RGBColor[
              0.4373148695598369, 0.5452263693534911, 0.9503785607104502], 
             UndirectedEdge[124, 156] -> 
             RGBColor[
              0.7372600764929055, 0.7914612112667188, 0.8922395075707963], 
             UndirectedEdge[64, 120] -> 
             RGBColor[
              0.8168520774879562, 0.8569382423875458, 0.9392385611147377], 
             UndirectedEdge[55, 236] -> 
             RGBColor[
              0.36935660430142075`, 0.49220777134896737`, 0.9448341202859296],
              UndirectedEdge[11, 196] -> 
             RGBColor[
              0.5031901104444422, 0.6003474290985225, 0.956080645535285], 
             UndirectedEdge[223, 319] -> 
             RGBColor[
              0.33532023481344303`, 0.4637752073232584, 0.9426269794617959], 
             UndirectedEdge[61, 70] -> 
             RGBColor[
              0.6323920996415665, 0.7099661726476122, 0.9658970775168925], 
             UndirectedEdge[307, 343] -> 
             RGBColor[
              0.4475366970441955, 0.5609673501165603, 0.9500382867146361], 
             UndirectedEdge[13, 87] -> 
             RGBColor[
              0.664049888457072, 0.7323451805269102, 0.9614083061511771], 
             UndirectedEdge[119, 128] -> 
             RGBColor[
              0.5769203648203656, 0.6585927536320646, 0.963291718323417], 
             UndirectedEdge[92, 130] -> 
             RGBColor[
              0.7187142944254707, 0.7790515951960446, 0.9737238072005638], 
             UndirectedEdge[263, 359] -> 
             RGBColor[
              0.8001011854245281, 0.8439367470501733, 0.9506689165158659], 
             UndirectedEdge[22, 304] -> 
             RGBColor[
              0.46881074286018093`, 0.5736237672757303, 0.9526328550711011], 
             UndirectedEdge[139, 306] -> 
             RGBColor[
              0.9089373296795484, 0.929849543480206, 0.9781254864755418], 
             UndirectedEdge[1, 73] -> 
             RGBColor[
              0.9592215901304927, 0.9684318321378362, 0.9248718946578383], 
             UndirectedEdge[7, 13] -> 
             RGBColor[
              0.6690866678912013, 0.7361016023819142, 0.9528823523716641], 
             UndirectedEdge[170, 335] -> 
             RGBColor[
              0.8948914966324915, 0.9189763846341608, 0.9881094577056926], 
             UndirectedEdge[276, 361] -> 
             RGBColor[
              0.5993209738672953, 0.6837442831795391, 0.9627939301149857], 
             UndirectedEdge[46, 345] -> 
             RGBColor[
              0.6464023782837953, 0.7142604708872027, 0.914370257336332], 
             UndirectedEdge[36, 301] -> 
             RGBColor[
              0.6622597119640214, 0.7351338899124986, 0.9676194629594083], 
             UndirectedEdge[50, 328] -> 
             RGBColor[
              0.5253624797584359, 0.625291204301923, 0.9558496513375472], 
             UndirectedEdge[55, 83] -> 
             RGBColor[
              0.3578611880082202, 0.48225101953221955`, 0.9441016425247244], 
             UndirectedEdge[143, 306] -> 
             RGBColor[
              0.6715370692307454, 0.738538892005081, 0.9576339092087767], 
             UndirectedEdge[32, 400] -> 
             RGBColor[
              0.528351224114449, 0.6279783515443356, 0.9560128902580458], 
             UndirectedEdge[20, 195] -> 
             RGBColor[
              0.9826960973693344, 0.9642475205326714, 0.620697413185165], 
             UndirectedEdge[203, 266] -> 
             RGBColor[
              0.6251020596605403, 0.7045710469696289, 0.9649654250659158], 
             UndirectedEdge[255, 359] -> 
             RGBColor[
              0.9238246008524151, 0.9412360288165128, 0.9627572157687074], 
             UndirectedEdge[128, 215] -> 
             RGBColor[
              0.9150520161072877, 0.9000214883215514, 0.6609797599653502], 
             UndirectedEdge[230, 328] -> 
             RGBColor[
              0.4420848010487196, 0.5502398697794308, 0.9506502012522609], 
             UndirectedEdge[44, 146] -> 
             RGBColor[
              0.4169033992098386, 0.5355225030466149, 0.9477856938378181], 
             UndirectedEdge[56, 206] -> 
             RGBColor[
              0.8353604692774784, 0.8722104680513525, 0.9822539021284948], 
             UndirectedEdge[55, 196] -> 
             RGBColor[
              0.2882044071531007, 0.4202514835056986, 0.9397241866759325], 
             UndirectedEdge[93, 188] -> 
             RGBColor[
              0.5383271664082752, 0.6280542361339557, 0.9595420173246528], 
             UndirectedEdge[52, 271] -> 
             RGBColor[
              0.6655666961237574, 0.7315414760959227, 0.9306014657034283], 
             UndirectedEdge[193, 253] -> 
             RGBColor[
              0.625535093501796, 0.6998958256950505, 0.967373823941081], 
             UndirectedEdge[120, 193] -> 
             RGBColor[
              0.6541636371963284, 0.7214892511028632, 0.9273140124812997], 
             UndirectedEdge[28, 217] -> 
             RGBColor[
              0.6898613326895787, 0.7501326843521285, 0.8467724921872729], 
             UndirectedEdge[124, 245] -> 
             RGBColor[
              0.686896653884358, 0.7487131076076383, 0.8887888613441386], 
             UndirectedEdge[36, 282] -> 
             RGBColor[
              0.5401265280033323, 0.6375380737127259, 0.9569398853145381], 
             UndirectedEdge[276, 339] -> 
             RGBColor[
              0.5216688336441101, 0.6223786146986479, 0.9555350901813335], 
             UndirectedEdge[377, 388] -> 
             RGBColor[
              0.914696292968523, 0.8487682573424116, 0.6280507547414795], 
             UndirectedEdge[129, 131] -> 
             RGBColor[
              0.47960801263516195`, 0.5884064166087969, 0.9521756460981294], 
             UndirectedEdge[69, 142] -> 
             RGBColor[
              0.8375344102835238, 0.8727564385127339, 0.9258692594895822], 
             UndirectedEdge[11, 118] -> 
             RGBColor[
              0.5243297608195658, 0.6203238652451527, 0.9573666327319057], 
             UndirectedEdge[53, 293] -> 
             RGBColor[
              0.3563288226944187, 0.48305584943569846`, 0.9439259353862504], 
             UndirectedEdge[2, 137] -> 
             RGBColor[
              0.6801007228805498, 0.747974024873525, 0.9703724731339382], 
             UndirectedEdge[102, 213] -> 
             RGBColor[
              0.5638458035792657, 0.6526825504002073, 0.9606752390520317], 
             UndirectedEdge[269, 362] -> 
             RGBColor[
              0.4720756768401471, 0.5790703974005296, 0.952472625500397], 
             UndirectedEdge[147, 242] -> 
             RGBColor[
              0.4051288101685786, 0.5202156000950414, 0.9477428684067073], 
             UndirectedEdge[58, 220] -> 
             RGBColor[
              0.5927715798587588, 0.6743079679023132, 0.9640016560315106], 
             UndirectedEdge[177, 285] -> 
             RGBColor[
              0.3376784085164814, 0.4638205149417517, 0.942850368356177], 
             UndirectedEdge[213, 215] -> 
             RGBColor[
              0.6686924896426556, 0.7007165698310622, 0.6400251218202831], 
             UndirectedEdge[61, 382] -> 
             RGBColor[
              0.6798872637944544, 0.7485248865396886, 0.9696360708195266], 
             UndirectedEdge[83, 123] -> 
             RGBColor[
              0.5834634037473805, 0.6706406653377626, 0.9615162561279262], 
             UndirectedEdge[207, 368] -> 
             RGBColor[
              0.6733065534381237, 0.7377080958479788, 0.9160792737796046], 
             UndirectedEdge[117, 377] -> 
             RGBColor[
              0.7061461304209792, 0.682719759458428, 0.6091499660264588], 
             UndirectedEdge[207, 392] -> 
             RGBColor[
              0.7115115718972409, 0.7707993625972047, 0.9185136637724483], 
             UndirectedEdge[43, 325] -> 
             RGBColor[
              0.3765784414386586, 0.4951336491610948, 0.9456685449687706], 
             UndirectedEdge[83, 196] -> 
             RGBColor[
              0.3603799538205953, 0.484898402100002, 0.9442450825115591], 
             UndirectedEdge[81, 130] -> 
             RGBColor[
              0.48000909163560035`, 0.5885433884317541, 0.9522593429020862], 
             UndirectedEdge[204, 229] -> 
             RGBColor[
              0.3261622599535271, 0.45657188108206437`, 0.942016754585735], 
             UndirectedEdge[44, 267] -> 
             RGBColor[
              0.4416201824004914, 0.5557525291611751, 0.9496862233750172], 
             UndirectedEdge[38, 130] -> 
             RGBColor[
              0.7419353123128688, 0.7636291830032446, 0.6468386879108783], 
             UndirectedEdge[226, 318] -> 
             RGBColor[
              0.6595715354774523, 0.7264894306144907, 0.9322723298169604], 
             UndirectedEdge[202, 362] -> 
             RGBColor[
              0.5312426439721845, 0.6303178505120647, 0.9562426923267556], 
             UndirectedEdge[59, 230] -> 
             RGBColor[
              0.457055960670654, 0.5623941316035722, 0.9518287857788642], 
             UndirectedEdge[131, 394] -> 
             RGBColor[
              0.43889322684835586`, 0.553801664892559, 0.9493988794581953], 
             UndirectedEdge[93, 142] -> 
             RGBColor[
              0.490862556428174, 0.590974522073104, 0.9548111885838353], 
             UndirectedEdge[301, 340] -> 
             RGBColor[
              0.6123995492723319, 0.694655163664653, 0.9636942883085244], 
             UndirectedEdge[16, 76] -> 
             RGBColor[
              0.9031858302296755, 0.9251524569156135, 0.9737285668380113], 
             UndirectedEdge[25, 239] -> 
             RGBColor[
              0.39945907990609614`, 0.5184092630596837, 0.9470419620527701], 
             UndirectedEdge[46, 60] -> 
             RGBColor[
              0.6507272055210365, 0.7181509995532219, 0.9146405376964613], 
             UndirectedEdge[57, 297] -> 
             RGBColor[
              0.6758012681719352, 0.7393528759053511, 0.8972719239949303], 
             UndirectedEdge[221, 351] -> 
             RGBColor[
              0.7650149830985419, 0.8163547862165791, 0.9772132021099316], 
             UndirectedEdge[365, 377] -> 
             RGBColor[
              0.8192353601310751, 0.7735892384109921, 0.618696440553854], 
             UndirectedEdge[334, 366] -> 
             RGBColor[
              0.7929201298908597, 0.8376552801833292, 0.9379920717750828], 
             UndirectedEdge[209, 290] -> 
             RGBColor[
              0.7270839294080013, 0.7861798523859487, 0.9739989461971055], 
             UndirectedEdge[174, 313] -> 
             RGBColor[
              0.9221511019128651, 0.9407622738132155, 0.9924367893860977], 
             UndirectedEdge[56, 358] -> 
             RGBColor[
              0.9322409015687685, 0.9487580436688301, 0.9916808001606219], 
             UndirectedEdge[304, 338] -> 
             RGBColor[
              0.3956252483557984, 0.5142628360584857, 0.9468342653344277], 
             UndirectedEdge[130, 306] -> 
             RGBColor[
              0.7319720703455904, 0.7892465588095524, 0.9619373841843128], 
             UndirectedEdge[11, 206] -> 
             RGBColor[
              0.7243785044492951, 0.784609260247111, 0.9731629376876584], 
             UndirectedEdge[120, 140] -> 
             RGBColor[
              0.9457426091518967, 0.9583393030781241, 0.9518965408925752], 
             UndirectedEdge[193, 356] -> 
             RGBColor[
              0.4290165951471935, 0.5438435766311758, 0.9491573256128545], 
             UndirectedEdge[166, 246] -> 
             RGBColor[
              0.5954154146648365, 0.6726956212301753, 0.9651534425938322], 
             UndirectedEdge[76, 182] -> 
             RGBColor[
              0.9174306565074328, 0.9365108947239886, 0.9750872510848905], 
             UndirectedEdge[6, 364] -> 
             RGBColor[
              0.32080692670641864`, 0.45036965397995987`, 0.9417327724457749],
              UndirectedEdge[288, 318] -> 
             RGBColor[
              0.9673185644118456, 0.9751468193660695, 0.9402053251539241], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.7130310350328812, 0.774419420820736, 0.9732974037447559], 
             UndirectedEdge[128, 151] -> 
             RGBColor[
              0.7627923792388588, 0.8149481113700277, 0.976904197360069], 
             UndirectedEdge[30, 379] -> 
             RGBColor[
              0.6936036500247653, 0.7569209415123594, 0.9483727125637121], 
             UndirectedEdge[70, 90] -> 
             RGBColor[
              0.3951221845177448, 0.5164559605738606, 0.9464532816620124], 
             UndirectedEdge[137, 394] -> 
             RGBColor[
              0.641292197495803, 0.7149168612277312, 0.9677457742957163], 
             UndirectedEdge[25, 269] -> 
             RGBColor[
              0.41662643139549277`, 0.5340542019885184, 0.948107457781715], 
             UndirectedEdge[38, 227] -> 
             RGBColor[
              0.7582015627428953, 0.7768348578885711, 0.6481192267299687], 
             UndirectedEdge[128, 135] -> 
             RGBColor[
              0.7566620276943774, 0.8101590341510814, 0.9762931812095075], 
             UndirectedEdge[129, 303] -> 
             RGBColor[
              0.479324089962025, 0.5881759153921737, 0.9521532946652571], 
             UndirectedEdge[132, 299] -> 
             RGBColor[
              0.7179351288019568, 0.7790333380077761, 0.9729554151399906], 
             UndirectedEdge[352, 396] -> 
             RGBColor[
              0.5999590701953696, 0.6850283988641662, 0.9623915515732647], 
             UndirectedEdge[155, 268] -> 
             RGBColor[
              0.3252193740156875, 0.4489195804116847, 0.9422069602704368], 
             UndirectedEdge[8, 16] -> 
             RGBColor[
              0.8557289220055224, 0.8877990305371434, 0.9861013825707553], 
             UndirectedEdge[213, 378] -> 
             RGBColor[
              0.6682638355797765, 0.7346096356111689, 0.9414569188172008], 
             UndirectedEdge[164, 230] -> 
             RGBColor[
              0.5234030120013378, 0.614307773065848, 0.9583850148377155], 
             UndirectedEdge[218, 339] -> 
             RGBColor[
              0.4775787826589274, 0.584190028565679, 0.9527257111198589], 
             UndirectedEdge[101, 366] -> 
             RGBColor[
              0.9857595732755033, 0.9881393262972189, 0.8749207939728304], 
             UndirectedEdge[169, 361] -> 
             RGBColor[
              0.5343048714335602, 0.6274306030557617, 0.9586511615593902], 
             UndirectedEdge[65, 341] -> 
             RGBColor[
              0.7921843057617091, 0.8354329816551918, 0.8707204412976728], 
             UndirectedEdge[46, 353] -> 
             RGBColor[
              0.6252371295913115, 0.6920144525571275, 0.9131649277344747], 
             UndirectedEdge[279, 300] -> 
             RGBColor[
              0.5433962587556238, 0.6345453133965816, 0.9595520368790278], 
             UndirectedEdge[203, 358] -> 
             RGBColor[
              0.848387789109645, 0.8823501015222127, 0.9852937861903939], 
             UndirectedEdge[81, 243] -> 
             RGBColor[
              0.46958910628987993`, 0.5800839749131079, 0.9514390434860072], 
             UndirectedEdge[176, 320] -> 
             RGBColor[
              0.6265380818798065, 0.705722609001896, 0.9650882273938206], 
             UndirectedEdge[112, 248] -> 
             RGBColor[
              0.6184316481783092, 0.7011096978762357, 0.9631043512158188], 
             UndirectedEdge[58, 179] -> 
             RGBColor[
              0.5702743033299612, 0.6535866516935799, 0.9626133800695452], 
             UndirectedEdge[23, 213] -> 
             RGBColor[
              0.6388905362623347, 0.7120334683279161, 0.967962497181533], 
             UndirectedEdge[243, 326] -> 
             RGBColor[
              0.5050785461125363, 0.6090845431201865, 0.9541807797951067], 
             UndirectedEdge[269, 377] -> 
             RGBColor[
              0.6346738672070542, 0.6214744267105847, 0.6044133601226382], 
             UndirectedEdge[222, 363] -> 
             RGBColor[
              0.590852618437022, 0.6715662493823982, 0.9643381612642381], 
             UndirectedEdge[30, 341] -> 
             RGBColor[
              0.7084380093885232, 0.7666686727084229, 0.8643418417914643], 
             UndirectedEdge[23, 348] -> 
             RGBColor[
              0.8354778204344532, 0.8721262926753939, 0.9840437797314746], 
             UndirectedEdge[16, 25] -> 
             RGBColor[
              0.67516507073124, 0.7442174444863222, 0.9696957096724685], 
             UndirectedEdge[25, 62] -> 
             RGBColor[
              0.6127548141448911, 0.6952051559321292, 0.9635434176919935], 
             UndirectedEdge[16, 388] -> 
             RGBColor[
              0.8732546980952571, 0.901773608666579, 0.9877730067396392], 
             UndirectedEdge[207, 372] -> 
             RGBColor[
              0.6823271957309848, 0.7455213228113905, 0.9166540611298649], 
             UndirectedEdge[249, 279] -> 
             RGBColor[
              0.7628637654004036, 0.8146742386009334, 0.9769987888340534], 
             UndirectedEdge[151, 267] -> 
             RGBColor[
              0.5807674375873635, 0.6701881675108867, 0.9603745000389394], 
             UndirectedEdge[185, 252] -> 
             RGBColor[
              0.6640798927803511, 0.7366913182481273, 0.9677082468337734], 
             UndirectedEdge[218, 382] -> 
             RGBColor[
              0.45720332655246576`, 0.5676483153946161, 0.9511216805774032], 
             UndirectedEdge[284, 334] -> 
             RGBColor[
              0.681548662443895, 0.7505487462051363, 0.9693053190433593], 
             UndirectedEdge[145, 235] -> 
             RGBColor[
              0.5329846791464767, 0.6304958429469489, 0.9567857085650279], 
             UndirectedEdge[78, 302] -> 
             RGBColor[
              0.9195534638899895, 0.9362257495729924, 0.8960852863783295], 
             UndirectedEdge[235, 335] -> 
             RGBColor[
              0.6327303493577867, 0.708677920866785, 0.96665842819111], 
             UndirectedEdge[21, 109] -> 
             RGBColor[
              0.6253912963472354, 0.7053509945900742, 0.9646154849420521], 
             UndirectedEdge[283, 389] -> 
             RGBColor[
              0.6373125949106437, 0.7110558871171517, 0.9676828039845814], 
             UndirectedEdge[91, 395] -> 
             RGBColor[
              0.8083985750372316, 0.8510424364786557, 0.9742416451698406], 
             UndirectedEdge[240, 374] -> 
             RGBColor[
              0.7350165603798134, 0.7913576174447206, 0.9525053904608614], 
             UndirectedEdge[301, 339] -> 
             RGBColor[
              0.670239200163451, 0.7416119979046423, 0.9682476375002957], 
             UndirectedEdge[303, 353] -> 
             RGBColor[
              0.37293087945414594`, 0.49262548888191776`, 0.9453401520155132],
              UndirectedEdge[92, 143] -> 
             RGBColor[
              0.6582792933106257, 0.7283439283915731, 0.9694203322250277], 
             UndirectedEdge[53, 394] -> 
             RGBColor[
              0.39986050773486076`, 0.5207608070516213, 0.9466997358634697], 
             UndirectedEdge[139, 345] -> 
             RGBColor[
              0.587380242150687, 0.6687228732598581, 0.9640182639261642], 
             UndirectedEdge[224, 393] -> 
             RGBColor[
              0.4457740548931227, 0.5473864386814045, 0.9516414275817486], 
             UndirectedEdge[175, 204] -> 
             RGBColor[
              0.4257759856385128, 0.5403181593015598, 0.9490642391786471], 
             UndirectedEdge[131, 293] -> 
             RGBColor[
              0.3953615418079138, 0.5160967072766361, 0.946625078980976], 
             UndirectedEdge[166, 383] -> 
             RGBColor[
              0.3709312960692486, 0.49376984001054136`, 0.9449308039450482], 
             UndirectedEdge[92, 348] -> 
             RGBColor[
              0.8425020815601656, 0.877727247828548, 0.984713760028277], 
             UndirectedEdge[212, 289] -> 
             RGBColor[
              0.5926126136020409, 0.6747337471072035, 0.9637321316695566], 
             UndirectedEdge[161, 214] -> 
             RGBColor[
              0.6743359937168951, 0.735813801475506, 0.7845242786405233], 
             UndirectedEdge[124, 386] -> 
             RGBColor[
              0.7471628629325335, 0.799500739413854, 0.8930190911944257], 
             UndirectedEdge[227, 350] -> 
             RGBColor[
              0.4714090752867812, 0.5802111528481531, 0.951955425190405], 
             UndirectedEdge[258, 279] -> 
             RGBColor[
              0.6349204824616259, 0.7125461926523773, 0.9657355587920344], 
             UndirectedEdge[63, 103] -> 
             RGBColor[
              0.29411778812951483`, 0.41716912456676236`, 0.9404013792176154],
              UndirectedEdge[291, 336] -> 
             RGBColor[
              0.3497978657994014, 0.4773990628286725, 0.9435097885879983], 
             UndirectedEdge[292, 400] -> 
             RGBColor[
              0.3613591010967262, 0.4827167942362749, 0.9444759852509053], 
             UndirectedEdge[149, 300] -> 
             RGBColor[
              0.36328151832800815`, 0.4890779249408703, 0.9443689550039953], 
             UndirectedEdge[356, 364] -> 
             RGBColor[
              0.410628503799099, 0.5259978215844624, 0.9480559135532054], 
             UndirectedEdge[100, 167] -> 
             RGBColor[
              0.8111620009941363, 0.8530749138919882, 0.9681221751650356], 
             UndirectedEdge[334, 391] -> 
             RGBColor[
              0.7921211497161342, 0.8183666091136002, 0.6715842820840431], 
             UndirectedEdge[309, 323] -> 
             RGBColor[
              0.7151649020455042, 0.7774115240232977, 0.9722446119060583], 
             UndirectedEdge[8, 202] -> 
             RGBColor[
              0.6563572498018126, 0.7288832411508748, 0.9682831975063604], 
             UndirectedEdge[127, 380] -> 
             RGBColor[
              0.6430669617354627, 0.6945734428967936, 0.6635986792190156], 
             UndirectedEdge[130, 151] -> 
             RGBColor[
              0.5892323498116503, 0.6770603645945126, 0.9610408889372304], 
             UndirectedEdge[335, 355] -> 
             RGBColor[
              0.7754479651444441, 0.8247651133400278, 0.97818406765421], 
             UndirectedEdge[117, 395] -> 
             RGBColor[
              0.7106003998809537, 0.7721184455598533, 0.9662192400573406], 
             UndirectedEdge[256, 310] -> 
             RGBColor[
              0.938170036888214, 0.9534078952652785, 0.9895461790978916], 
             UndirectedEdge[362, 365] -> 
             RGBColor[
              0.6566371697641681, 0.731185209100937, 0.9667557059316128], 
             UndirectedEdge[163, 342] -> 
             RGBColor[
              0.9625415234900384, 0.9715841100682724, 0.9482916093827295], 
             UndirectedEdge[125, 288] -> 
             RGBColor[
              0.7601192724924197, 0.8118984505791033, 0.9588084072787879], 
             UndirectedEdge[161, 253] -> 
             RGBColor[
              0.9603210238820237, 0.9671866957655761, 0.8090412949047555], 
             UndirectedEdge[12, 211] -> 
             RGBColor[
              0.364405481794656, 0.4900514456036343, 0.9444405729622083], 
             UndirectedEdge[107, 152] -> 
             RGBColor[
              0.46691464834682783`, 0.574816365122811, 0.9520840350551667], 
             UndirectedEdge[183, 291] -> 
             RGBColor[
              0.6646971078037056, 0.727064226036942, 0.7496494102576806], 
             UndirectedEdge[149, 299] -> 
             RGBColor[
              0.6241517577159349, 0.7017037606588643, 0.9659018010425973], 
             UndirectedEdge[57, 284] -> 
             RGBColor[
              0.5618524709249451, 0.6509406442834956, 0.9605547358628581], 
             UndirectedEdge[230, 279] -> 
             RGBColor[
              0.5234030120013378, 0.614307773065848, 0.9583850148377155], 
             UndirectedEdge[186, 374] -> 
             RGBColor[
              0.9155602576178274, 0.9348489048470496, 0.9689945765382288], 
             UndirectedEdge[30, 175] -> 
             RGBColor[
              0.4857062052315468, 0.5925819112556292, 0.9528699338748128], 
             UndirectedEdge[261, 327] -> 
             RGBColor[
              0.6105471994448676, 0.6943281064047538, 0.9627439047231904], 
             UndirectedEdge[271, 333] -> 
             RGBColor[
              0.8317045336748232, 0.8685927195876907, 0.9433321917358566], 
             UndirectedEdge[199, 247] -> 
             RGBColor[
              0.30233076603997044`, 0.43257151332562593`, 0.9406212122618576],
              UndirectedEdge[99, 223] -> 
             RGBColor[
              0.5804660775334237, 0.6619207974250617, 0.9635540455224896], 
             UndirectedEdge[200, 367] -> 
             RGBColor[
              0.983140639993137, 0.9869082672454558, 0.9116927397380089], 
             UndirectedEdge[111, 400] -> 
             RGBColor[
              0.5125601211976797, 0.6151584228154225, 0.9547697567917217], 
             UndirectedEdge[277, 390] -> 
             RGBColor[
              0.6983035750654112, 0.7633648770627652, 0.971161898769731], 
             UndirectedEdge[79, 298] -> 
             RGBColor[
              0.9047243596954109, 0.9258911056369368, 0.9569514386520674], 
             UndirectedEdge[96, 388] -> 
             RGBColor[
              0.9171906900671852, 0.9367052738457666, 0.9884375814634856], 
             UndirectedEdge[153, 175] -> 
             RGBColor[
              0.7470767965195706, 0.7362085857804233, 0.6170366801593674], 
             UndirectedEdge[127, 331] -> 
             RGBColor[
              0.6979145526723618, 0.7425542058659877, 0.6670761441107941], 
             UndirectedEdge[6, 93] -> 
             RGBColor[
              0.3231269760847183, 0.4528081729761795, 0.9418648958256637], 
             UndirectedEdge[76, 239] -> 
             RGBColor[
              0.6274798394045316, 0.6993442754889752, 0.9510748192183129], 
             UndirectedEdge[333, 337] -> 
             RGBColor[
              0.8104800525053375, 0.8527635362833865, 0.9792597021245397], 
             UndirectedEdge[253, 332] -> 
             RGBColor[
              0.7450813768231644, 0.8004393321375315, 0.9758205240547574], 
             UndirectedEdge[31, 400] -> 
             RGBColor[
              0.5407747123045726, 0.6380642989288428, 0.956990912757109], 
             UndirectedEdge[39, 149] -> 
             RGBColor[
              0.5559233788541126, 0.6482504515148514, 0.9591419772538272], 
             UndirectedEdge[49, 335] -> 
             RGBColor[
              0.5876172678631089, 0.6696032371255002, 0.9637838625302009], 
             UndirectedEdge[57, 236] -> 
             RGBColor[
              0.4083637360688781, 0.5281258760498644, 0.9472415540538037], 
             UndirectedEdge[76, 323] -> 
             RGBColor[
              0.8077090307348496, 0.8503083337262844, 0.9642805108848316], 
             UndirectedEdge[2, 210] -> 
             RGBColor[
              0.6684787990513232, 0.7387070182808182, 0.9692639636640927], 
             UndirectedEdge[25, 395] -> 
             RGBColor[
              0.7210609350644803, 0.7806107792635801, 0.9670427317051908], 
             UndirectedEdge[62, 91] -> 
             RGBColor[
              0.7000924541176423, 0.7656368131472049, 0.9707423311566432], 
             UndirectedEdge[148, 313] -> 
             RGBColor[
              0.9208831836852236, 0.9397512702352177, 0.9923158542136612], 
             UndirectedEdge[98, 163] -> 
             RGBColor[
              0.9614348766108775, 0.9707587746377621, 0.9501648738894173], 
             UndirectedEdge[271, 292] -> 
             RGBColor[
              0.6205982846798611, 0.6881362990109637, 0.9278992669287873], 
             UndirectedEdge[148, 228] -> 
             RGBColor[
              0.809700626401348, 0.8521228849569931, 0.9814390084508353], 
             UndirectedEdge[105, 333] -> 
             RGBColor[
              0.589497554071054, 0.6770007252954962, 0.9612497475462491], 
             UndirectedEdge[9, 65] -> 
             RGBColor[
              0.5281582276379879, 0.6278216683103521, 0.9559976968684494], 
             UndirectedEdge[129, 337] -> 
             RGBColor[
              0.7079165299874102, 0.7701168197876822, 0.9707623317217338], 
             UndirectedEdge[62, 323] -> 
             RGBColor[
              0.6938838555883607, 0.7607866087890337, 0.9701235160778963], 
             UndirectedEdge[286, 290] -> 
             RGBColor[
              0.9308417586562117, 0.9464469679215465, 0.9501007916215063], 
             UndirectedEdge[96, 261] -> 
             RGBColor[
              0.8034249847021215, 0.8472264274943498, 0.9772588186181321], 
             UndirectedEdge[48, 86] -> 
             RGBColor[
              0.5413644580885217, 0.6354665369987769, 0.9582878176212939], 
             UndirectedEdge[137, 328] -> 
             RGBColor[
              0.746692993232406, 0.8020366298927541, 0.9756148605915602], 
             UndirectedEdge[110, 212] -> 
             RGBColor[
              0.31064942356040526`, 0.4394323254249385, 0.941163879602404], 
             UndirectedEdge[163, 272] -> 
             RGBColor[
              0.7900975443623697, 0.8366455259706637, 0.9721481053276162], 
             UndirectedEdge[245, 396] -> 
             RGBColor[
              0.43577699277229337`, 0.5509616117800487, 0.9492392545445913], 
             UndirectedEdge[25, 37] -> 
             RGBColor[
              0.5132176838542195, 0.6156922618028617, 0.9548215225327759], 
             UndirectedEdge[79, 373] -> 
             RGBColor[
              0.6098431528589612, 0.6894124195700486, 0.9649430886693176], 
             UndirectedEdge[34, 43] -> 
             RGBColor[
              0.28128334652681497`, 0.41297700996688347`, 0.9393300425120572],
              UndirectedEdge[100, 358] -> 
             RGBColor[
              0.9387795010059583, 0.9536345204231125, 0.9806126568533164], 
             UndirectedEdge[273, 394] -> 
             RGBColor[
              0.6440445305837179, 0.7171114969219432, 0.9680082942826783], 
             UndirectedEdge[89, 189] -> 
             RGBColor[
              0.731682154275548, 0.7903149270011742, 0.9738908972458511], 
             UndirectedEdge[268, 299] -> 
             RGBColor[
              0.5349287081690283, 0.6172324114373449, 0.9604798786673032], 
             UndirectedEdge[143, 272] -> 
             RGBColor[
              0.5145191167511102, 0.6151050133237752, 0.9553781657906528], 
             UndirectedEdge[339, 382] -> 
             RGBColor[
              0.5760772182261151, 0.6667244635957192, 0.959770055340593], 
             UndirectedEdge[111, 223] -> 
             RGBColor[
              0.42998785792165933`, 0.5427946496081162, 0.9494816415753145], 
             UndirectedEdge[71, 131] -> 
             RGBColor[
              0.431608186888789, 0.5474917294363371, 0.9489346831538796], 
             UndirectedEdge[114, 370] -> 
             RGBColor[
              0.6435556346662141, 0.7130093011501862, 0.9369733893804851], 
             UndirectedEdge[4, 125] -> 
             RGBColor[
              0.5735630510003955, 0.6646833493799371, 0.9595721308868863], 
             UndirectedEdge[246, 251] -> 
             RGBColor[
              0.5977354640431362, 0.675134140226395, 0.9652855659737208], 
             UndirectedEdge[30, 229] -> 
             RGBColor[
              0.386092479546561, 0.5088356330361337, 0.9458224492819005], 
             UndirectedEdge[115, 366] -> 
             RGBColor[
              0.7157592872267147, 0.7748891595509253, 0.9319518034110776], 
             UndirectedEdge[89, 270] -> 
             RGBColor[
              0.5900769097875761, 0.675122368420744, 0.9624652760801393], 
             UndirectedEdge[197, 369] -> 
             RGBColor[
              0.5840505480750652, 0.6690933292588062, 0.9624238189488231], 
             UndirectedEdge[276, 301] -> 
             RGBColor[
              0.5954553594749841, 0.6807244358365081, 0.9624086417985805], 
             UndirectedEdge[69, 188] -> 
             RGBColor[
              0.884999020263625, 0.9098361525735856, 0.9306000882303997], 
             UndirectedEdge[191, 225] -> 
             RGBColor[
              0.47482916050018575`, 0.583523733402666, 0.9520765680689487], 
             UndirectedEdge[223, 247] -> 
             RGBColor[
              0.2827987955773527, 0.4145698430040181, 0.9394163450935793], 
             UndirectedEdge[72, 86] -> 
             RGBColor[
              0.5836355981015006, 0.671877836870024, 0.9610370654481402], 
             UndirectedEdge[19, 85] -> 
             RGBColor[
              0.7234035555397961, 0.7838476227491242, 0.973065763891775], 
             UndirectedEdge[320, 398] -> 
             RGBColor[
              0.5387863683225409, 0.6364500717103538, 0.9568343830352994], 
             UndirectedEdge[249, 300] -> 
             RGBColor[
              0.5366134229253061, 0.6292465104944758, 0.9588759871926664], 
             UndirectedEdge[18, 319] -> 
             RGBColor[
              0.6666539344145381, 0.7337441985559289, 0.9490744694298304], 
             UndirectedEdge[6, 273] -> 
             RGBColor[
              0.6227515172067037, 0.6986685589527438, 0.9666515222989673], 
             UndirectedEdge[158, 348] -> 
             RGBColor[
              0.8756904458432417, 0.8959270354725979, 0.6965498993103731], 
             UndirectedEdge[61, 228] -> 
             RGBColor[
              0.7485856531395676, 0.8035200687850961, 0.9755756800404386], 
             UndirectedEdge[70, 260] -> 
             RGBColor[
              0.43659678952319947`, 0.5523791788553262, 0.9490960068184069], 
             UndirectedEdge[144, 305] -> 
             RGBColor[
              0.6258423522508991, 0.6403579828661239, 0.610434782788207], 
             UndirectedEdge[165, 351] -> 
             RGBColor[
              0.7368408083902825, 0.7943449068028283, 0.9744050636776442], 
             UndirectedEdge[132, 370] -> 
             RGBColor[
              0.7843876550674953, 0.8310900538021033, 0.9470249018087598], 
             UndirectedEdge[104, 145] -> 
             RGBColor[
              0.5698556334963925, 0.6615156920028497, 0.9593881641592539], 
             UndirectedEdge[207, 231] -> 
             RGBColor[
              0.9896131998826371, 0.9885251129758785, 0.7165677266288409], 
             UndirectedEdge[21, 249] -> 
             RGBColor[
              0.6362673885392591, 0.7138474804718453, 0.9656995121688929], 
             UndirectedEdge[7, 93] -> 
             RGBColor[
              0.6240801996231689, 0.695629355959484, 0.9500691327574255], 
             UndirectedEdge[140, 255] -> 
             RGBColor[
              0.8932503438177544, 0.9177175937983543, 0.9896802092789747], 
             UndirectedEdge[100, 157] -> 
             RGBColor[
              0.9468816090505348, 0.9599049715200472, 0.9747997597689934], 
             UndirectedEdge[42, 178] -> 
             RGBColor[
              0.7013480891097936, 0.7647028549807342, 0.9680617496350614], 
             UndirectedEdge[115, 195] -> 
             RGBColor[
              0.7137214327654265, 0.7514214746111048, 0.6607312210585203], 
             UndirectedEdge[281, 394] -> 
             RGBColor[
              0.6933649317870069, 0.7539730078830316, 0.8766087802040825], 
             UndirectedEdge[215, 224] -> 
             RGBColor[
              0.5999872509731874, 0.6339859509366581, 0.6359117027121968], 
             UndirectedEdge[99, 222] -> 
             RGBColor[
              0.8689230441923501, 0.8983196654240139, 0.9873598497234668], 
             UndirectedEdge[55, 284] -> 
             RGBColor[
              0.5228453391574877, 0.6150225395825987, 0.9581473020949841], 
             UndirectedEdge[32, 337] -> 
             RGBColor[
              0.7663659265280982, 0.8175686730147201, 0.975363682324611], 
             UndirectedEdge[172, 399] -> 
             RGBColor[
              0.6808939634910955, 0.7316454899800318, 0.6718345597806953], 
             UndirectedEdge[267, 346] -> 
             RGBColor[
              0.4446456096094199, 0.5583730021471561, 0.9498790009214899], 
             UndirectedEdge[222, 393] -> 
             RGBColor[
              0.7674223769245575, 0.818671525630341, 0.9773374303689804], 
             UndirectedEdge[116, 179] -> 
             RGBColor[
              0.5378837581980581, 0.6280793951217237, 0.9594390002691573], 
             UndirectedEdge[120, 360] -> 
             RGBColor[
              0.6671858422613418, 0.7327684306151203, 0.9281437758729586], 
             UndirectedEdge[144, 222] -> 
             RGBColor[
              0.9131381910637482, 0.8755364318790911, 0.6341744624760849], 
             UndirectedEdge[237, 307] -> 
             RGBColor[
              0.6090118276094058, 0.6922019920964959, 0.9632244426576759], 
             UndirectedEdge[18, 144] -> 
             RGBColor[
              0.9560149240059168, 0.9091065551128095, 0.6168161482431421], 
             UndirectedEdge[309, 365] -> 
             RGBColor[
              0.7366645551286038, 0.7942072164152305, 0.9743874963997005], 
             UndirectedEdge[189, 241] -> 
             RGBColor[
              0.5488422752577227, 0.6423425391300455, 0.9585953825541613], 
             UndirectedEdge[268, 370] -> 
             RGBColor[
              0.6013812344345668, 0.6692891272316721, 0.9345493653360724], 
             UndirectedEdge[336, 359] -> 
             RGBColor[
              0.6664924387772133, 0.7330395363441651, 0.9408215027547953], 
             UndirectedEdge[115, 123] -> 
             RGBColor[
              0.5928303377021482, 0.6787538327335928, 0.9621131088766695], 
             UndirectedEdge[6, 394] -> 
             RGBColor[
              0.37491557447526463`, 0.4991547596309598, 0.9451102667741067], 
             UndirectedEdge[259, 353] -> 
             RGBColor[
              0.4397178958531651, 0.546846197515443, 0.9505978705953462], 
             UndirectedEdge[98, 348] -> 
             RGBColor[
              0.8700792372491578, 0.8986015814278485, 0.9486883621557032], 
             UndirectedEdge[145, 349] -> 
             RGBColor[
              0.6922666991653921, 0.7595232739005666, 0.9699623330388408], 
             UndirectedEdge[287, 292] -> 
             RGBColor[
              0.38111271556680504`, 0.4987536683532757, 0.9460310621418639], 
             UndirectedEdge[53, 69] -> 
             RGBColor[
              0.6947437631996642, 0.7561961368364709, 0.9145124358207737], 
             UndirectedEdge[236, 284] -> 
             RGBColor[
              0.6065163021181827, 0.6896262099936499, 0.9634006756918161], 
             UndirectedEdge[119, 146] -> 
             RGBColor[
              0.37017863997821754`, 0.49360278365836324`, 0.9448614914650881],
              UndirectedEdge[198, 310] -> 
             RGBColor[
              0.9446070843208222, 0.9582086347008199, 0.9786499368453382], 
             UndirectedEdge[198, 384] -> 
             RGBColor[
              0.8809429836121626, 0.9075908991856003, 0.9752064386360979], 
             UndirectedEdge[111, 292] -> 
             RGBColor[
              0.41175372657277487`, 0.5236294214497373, 0.9484432347699754], 
             UndirectedEdge[40, 295] -> 
             RGBColor[
              0.6664475741228157, 0.7375988811347298, 0.9685883457384831], 
             UndirectedEdge[5, 270] -> 
             RGBColor[
              0.6868003798598544, 0.7511940370108714, 0.9503581831188037], 
             UndirectedEdge[104, 355] -> 
             RGBColor[
              0.5928972333356586, 0.6795159649199292, 0.961684735495239], 
             UndirectedEdge[356, 360] -> 
             RGBColor[
              0.4420388002122069, 0.5551227561434329, 0.9499870890045135], 
             UndirectedEdge[42, 398] -> 
             RGBColor[
              0.5286893327968843, 0.628252843404359, 0.95603950741206], 
             UndirectedEdge[153, 211] -> 
             RGBColor[
              0.6441712312358597, 0.649611081553181, 0.609779442458084], 
             UndirectedEdge[223, 385] -> 
             RGBColor[
              0.46890844867828146`, 0.5743921385369746, 0.9525456130504972], 
             UndirectedEdge[144, 361] -> 
             RGBColor[
              0.8520492172095002, 0.8273771961507476, 0.6282014027303657], 
             UndirectedEdge[216, 229] -> 
             RGBColor[
              0.36647804581743504`, 0.49184659639006884`, 0.9445726349090433],
              UndirectedEdge[161, 389] -> 
             RGBColor[
              0.6852742787139725, 0.7452879941657851, 0.7852212564881914], 
             UndirectedEdge[313, 340] -> 
             RGBColor[
              0.6981185139639848, 0.7623911968793617, 0.9720331611325596], 
             UndirectedEdge[241, 380] -> 
             RGBColor[
              0.3520875757584302, 0.47890775809128666`, 0.9436730619847769], 
             UndirectedEdge[258, 281] -> 
             RGBColor[
              0.7453578197071327, 0.7977338309838097, 0.8802734003570007], 
             UndirectedEdge[344, 346] -> 
             RGBColor[
              0.36432911196194095`, 0.4899852978929959, 0.9444357067439988], 
             UndirectedEdge[79, 205] -> 
             RGBColor[
              0.6485202765455523, 0.7227007081314926, 0.9674661071826898], 
             UndirectedEdge[227, 306] -> 
             RGBColor[
              0.7482383207756169, 0.802452233694879, 0.9632179230034031], 
             UndirectedEdge[43, 381] -> 
             RGBColor[
              0.4382121461989269, 0.5451706672522385, 0.9505205759791986], 
             UndirectedEdge[98, 143] -> 
             RGBColor[
              0.685856448999618, 0.7492182619908736, 0.9333949343524538], 
             UndirectedEdge[243, 267] -> 
             RGBColor[
              0.49476283226835005`, 0.6007097819038634, 0.9533686890135875], 
             UndirectedEdge[58, 152] -> 
             RGBColor[
              0.588748616791423, 0.6708234794933899, 0.9637453163822265], 
             UndirectedEdge[376, 397] -> 
             RGBColor[
              0.7086054366479941, 0.7670771272973946, 0.8740352201466508], 
             UndirectedEdge[114, 279] -> 
             RGBColor[
              0.5424832114878463, 0.6337544777443227, 0.959493858314501], 
             UndirectedEdge[148, 218] -> 
             RGBColor[
              0.6425038014890471, 0.7145932676815455, 0.9684550550091893], 
             UndirectedEdge[55, 366] -> 
             RGBColor[
              0.6342168066044522, 0.7021290735607916, 0.9268340548267077], 
             UndirectedEdge[99, 361] -> 
             RGBColor[
              0.8078340703381022, 0.8501604296956703, 0.9813867899777478], 
             UndirectedEdge[97, 169] -> 
             RGBColor[
              0.3455946417428216, 0.47375844141104684`, 0.9432419628678781], 
             UndirectedEdge[43, 250] -> 
             RGBColor[
              0.5712520062245662, 0.6500127260624924, 0.9633661624689942], 
             UndirectedEdge[112, 177] -> 
             RGBColor[
              0.44021279051758344`, 0.548511950046195, 0.9505217756730031], 
             UndirectedEdge[255, 356] -> 
             RGBColor[
              0.7059204919986037, 0.768992122062683, 0.9723401322601012], 
             UndirectedEdge[210, 328] -> 
             RGBColor[
              0.7350710694031795, 0.7927696233000472, 0.9745063511217147], 
             UndirectedEdge[91, 221] -> 
             RGBColor[
              0.7144735580470611, 0.776871440837305, 0.9721757051972705], 
             UndirectedEdge[32, 345] -> 
             RGBColor[
              0.4508595941511838, 0.5609546460794922, 0.9510141095926764], 
             UndirectedEdge[210, 258] -> 
             RGBColor[
              0.6816631615867023, 0.7494106777358025, 0.970301884978789], 
             UndirectedEdge[189, 359] -> 
             RGBColor[
              0.8330984066575529, 0.86988646495417, 0.9538401479077969], 
             UndirectedEdge[164, 258] -> 
             RGBColor[
              0.6349204824616259, 0.7125461926523773, 0.9657355587920344], 
             UndirectedEdge[354, 374] -> 
             RGBColor[
              0.9500091231259161, 0.9622374663966322, 0.969505694225683], 
             UndirectedEdge[235, 322] -> 
             RGBColor[
              0.413012483324108, 0.5321523872695135, 0.9475377681181811], 
             UndirectedEdge[147, 392] -> 
             RGBColor[
              0.35718917936805916`, 0.4808638540517666, 0.94408830158], 
             UndirectedEdge[123, 283] -> 
             RGBColor[
              0.81765302049181, 0.8581099574921863, 0.9822914425180413], 
             UndirectedEdge[202, 239] -> 
             RGBColor[
              0.3766932486406819, 0.49991904971964884`, 0.9452519313274579], 
             UndirectedEdge[180, 249] -> 
             RGBColor[
              0.7474511675897141, 0.8026338000511408, 0.9754626051231994], 
             UndirectedEdge[2, 197] -> 
             RGBColor[
              0.6295612843960852, 0.7079556111546832, 0.9654775767413719], 
             UndirectedEdge[174, 329] -> 
             RGBColor[
              0.6292488289618787, 0.7030252732294405, 0.9676506044248173], 
             UndirectedEdge[193, 242] -> 
             RGBColor[
              0.42902367981690326`, 0.5438493282852068, 0.9491578833440062], 
             UndirectedEdge[58, 160] -> 
             RGBColor[
              0.6918879450448278, 0.7578416390704636, 0.9709571650230022], 
             UndirectedEdge[50, 137] -> 
             RGBColor[
              0.6650452936653569, 0.7354905992644722, 0.969259300579602], 
             UndirectedEdge[326, 383] -> 
             RGBColor[
              0.48561031645103325`, 0.5932793572472266, 0.9526481694416782], 
             UndirectedEdge[157, 238] -> 
             RGBColor[
              0.7742432015727663, 0.8238029714212046, 0.9716701733266324], 
             UndirectedEdge[243, 346] -> 
             RGBColor[
              0.44269053648798623`, 0.5567857857121359, 0.9497250904037019], 
             UndirectedEdge[235, 355] -> 
             RGBColor[
              0.5560262789857429, 0.6484961158640286, 0.959082279901013], 
             UndirectedEdge[44, 135] -> 
             RGBColor[
              0.5195393630535897, 0.6188546211142321, 0.9559271077320195], 
             UndirectedEdge[33, 206] -> 
             RGBColor[
              0.7978265855142392, 0.8423315304783663, 0.9803922501121898], 
             UndirectedEdge[88, 263] -> 
             RGBColor[
              0.6186037449361733, 0.7012494137771403, 0.963117899303009], 
             UndirectedEdge[82, 399] -> 
             RGBColor[
              0.8734055684418258, 0.4104232427203768, 0.24230414091093644`], 
             UndirectedEdge[271, 287] -> 
             RGBColor[
              0.7411582937748449, 0.7957021744936499, 0.9357808658414923], 
             UndirectedEdge[31, 223] -> 
             RGBColor[
              0.4582024490285523, 0.5657005257215364, 0.9517027975407018], 
             UndirectedEdge[108, 376] -> 
             RGBColor[
              0.4259455695798915, 0.5433543765484574, 0.9483618529381206], 
             UndirectedEdge[301, 361] -> 
             RGBColor[
              0.7478913403866361, 0.8029776663855336, 0.9755064774339479], 
             UndirectedEdge[80, 388] -> 
             RGBColor[
              0.5817773291285984, 0.6593887088500789, 0.9642211024664444], 
             UndirectedEdge[47, 136] -> 
             RGBColor[
              0.48633250383924387`, 0.5842751903903339, 0.9548600161700116], 
             UndirectedEdge[39, 50] -> 
             RGBColor[
              0.573072208762061, 0.6631039060558636, 0.9602346855314469], 
             UndirectedEdge[120, 389] -> 
             RGBColor[
              0.6798845105192972, 0.7437673788065366, 0.928952923785364], 
             UndirectedEdge[28, 106] -> 
             RGBColor[
              0.6359802105664067, 0.7006097082908769, 0.8434437283870413], 
             UndirectedEdge[97, 326] -> 
             RGBColor[
              0.4458429142378132, 0.5588498556053324, 0.9501100747308715], 
             UndirectedEdge[195, 242] -> 
             RGBColor[
              0.7559760737843166, 0.7858491682414268, 0.6640235453633812], 
             UndirectedEdge[90, 260] -> 
             RGBColor[
              0.3710075402270666, 0.49576981678868326`, 0.9448612502875504], 
             UndirectedEdge[73, 368] -> 
             RGBColor[
              0.6459563097427852, 0.7174248055398942, 0.9687481737439834], 
             UndirectedEdge[52, 287] -> 
             RGBColor[
              0.4260811270107014, 0.5421588454382346, 0.9487332609165049], 
             UndirectedEdge[135, 243] -> 
             RGBColor[
              0.5726820129214484, 0.6638118738569201, 0.9596095733705897], 
             UndirectedEdge[311, 317] -> 
             RGBColor[
              0.32313184929839545`, 0.450243975214226, 0.9419592487326531], 
             UndirectedEdge[6, 10] -> 
             RGBColor[
              0.36083564843088034`, 0.4869594353689737, 0.9442131063369482], 
             UndirectedEdge[363, 383] -> 
             RGBColor[
              0.38082081710525556`, 0.504164353651234, 0.9454939975378136], 
             UndirectedEdge[227, 346] -> 
             RGBColor[
              0.4693767722637331, 0.5784508741161087, 0.9518259286388713], 
             UndirectedEdge[157, 341] -> 
             RGBColor[
              0.9675882499003456, 0.9740322406334303, 0.8808286481771603], 
             UndirectedEdge[18, 310] -> 
             RGBColor[
              0.9491742325877293, 0.9616148064002603, 0.9709189461325067], 
             UndirectedEdge[37, 96] -> 
             RGBColor[
              0.7337595167644432, 0.7910495030282831, 0.9715142515957049], 
             UndirectedEdge[218, 222] -> 
             RGBColor[
              0.6163198967363606, 0.6937149327749139, 0.9659576107992304], 
             UndirectedEdge[65, 203] -> 
             RGBColor[
              0.681085953015585, 0.750021293640909, 0.9693726822265833], 
             UndirectedEdge[105, 303] -> 
             RGBColor[
              0.48861996208926073`, 0.5957227231593307, 0.9528850997710147], 
             UndirectedEdge[119, 267] -> 
             RGBColor[
              0.3948954231688703, 0.5138328097729237, 0.9467620210022873], 
             UndirectedEdge[20, 312] -> 
             RGBColor[
              0.7203539753872049, 0.7781916581771913, 0.9099536872298496], 
             UndirectedEdge[285, 324] -> 
             RGBColor[
              0.41510083537583486`, 0.5339612128530934, 0.94767083606426], 
             UndirectedEdge[16, 302] -> 
             RGBColor[
              0.9211460936956353, 0.93749566934923, 0.8962371928309494], 
             UndirectedEdge[65, 313] -> 
             RGBColor[
              0.7538604043736363, 0.807644974657463, 0.9764213669348798], 
             UndirectedEdge[280, 392] -> 
             RGBColor[
              0.6445430840598887, 0.7189255598188671, 0.9674037402429376], 
             UndirectedEdge[1, 357] -> 
             RGBColor[
              0.6354801288746432, 0.7021752713823775, 0.897961615379204], 
             UndirectedEdge[26, 177] -> 
             RGBColor[
              0.5297211100116379, 0.6190087252055988, 0.9590519151443838], 
             UndirectedEdge[69, 293] -> 
             RGBColor[
              0.6475601582766403, 0.7153280697690859, 0.9115059382379022], 
             UndirectedEdge[165, 399] -> 
             RGBColor[
              0.8424714811323171, 0.8640418340689995, 0.6845730870000453], 
             UndirectedEdge[108, 297] -> 
             RGBColor[
              0.7067651549406535, 0.7661722383342147, 0.899244915479543], 
             UndirectedEdge[192, 335] -> 
             RGBColor[
              0.6678801354610311, 0.7383004480022921, 0.969125387116111], 
             UndirectedEdge[134, 272] -> 
             RGBColor[
              0.5760125476065359, 0.6666719610733665, 0.9597649642325234], 
             UndirectedEdge[86, 236] -> 
             RGBColor[
              0.5797736308912229, 0.6687346319793197, 0.9607352161483841], 
             UndirectedEdge[312, 389] -> 
             RGBColor[
              0.4150986203190287, 0.5339411016959995, 0.9476757215885765], 
             UndirectedEdge[156, 245] -> 
             RGBColor[
              0.43514928029766553`, 0.5504520065150211, 0.9491898387192022], 
             UndirectedEdge[153, 168] -> 
             RGBColor[
              0.6608051772292005, 0.6640185695261782, 0.6108393427879588], 
             UndirectedEdge[118, 150] -> 
             RGBColor[
              0.4925064686887494, 0.5954632675665807, 0.9541947843778791], 
             UndirectedEdge[195, 255] -> 
             RGBColor[
              0.9286237658295996, 0.9228673817793134, 0.6799633428870744], 
             UndirectedEdge[109, 180] -> 
             RGBColor[
              0.7365750753976903, 0.7941373141693697, 0.9743785778963587], 
             UndirectedEdge[143, 378] -> 
             RGBColor[
              0.6806283315023551, 0.7453191405216717, 0.942244773563893], 
             UndirectedEdge[135, 383] -> 
             RGBColor[
              0.5532137832599453, 0.6480066879839603, 0.9580769630171612], 
             UndirectedEdge[20, 120] -> 
             RGBColor[
              0.9851398655874735, 0.9880179352877284, 0.8912308894266372], 
             UndirectedEdge[149, 230] -> 
             RGBColor[
              0.3432882715737221, 0.4688403846101369, 0.9432019329626831], 
             UndirectedEdge[16, 77] -> 
             RGBColor[
              0.7367519060223506, 0.7942164118309583, 0.9745440509465959], 
             UndirectedEdge[168, 238] -> 
             RGBColor[
              0.48976298637885074`, 0.5944998525481133, 0.9535693633526106], 
             UndirectedEdge[104, 335] -> 
             RGBColor[
              0.6696013037077023, 0.7396977699226857, 0.969260883785336], 
             UndirectedEdge[79, 232] -> 
             RGBColor[
              0.8723892900941854, 0.9010835558173987, 0.9876904633519381], 
             UndirectedEdge[47, 299] -> 
             RGBColor[
              0.7711715203926983, 0.8213171009644629, 0.9777862848255758], 
             UndirectedEdge[236, 397] -> 
             RGBColor[
              0.721987489905699, 0.7786679892276652, 0.8748879127469467], 
             UndirectedEdge[33, 118] -> 
             RGBColor[
              0.59777784188451, 0.678046135476408, 0.9645959451564371], 
             UndirectedEdge[51, 79] -> 
             RGBColor[
              0.6652989267258153, 0.7363223722174068, 0.9687869839871008], 
             UndirectedEdge[24, 168] -> 
             RGBColor[
              0.5701730197431537, 0.657882619262867, 0.9611970178068276], 
             UndirectedEdge[269, 365] -> 
             RGBColor[
              0.5192551259220621, 0.6164313472373557, 0.9568304406612601], 
             UndirectedEdge[98, 240] -> 
             RGBColor[
              0.7438762336198688, 0.7979651472407703, 0.937508274638306], 
             UndirectedEdge[29, 113] -> 
             RGBColor[
              0.6627731385632676, 0.7277226188302374, 0.8837264526769679], 
             UndirectedEdge[330, 398] -> 
             RGBColor[
              0.47138148489046405`, 0.5788523826235779, 0.952322496489413], 
             UndirectedEdge[43, 265] -> 
             RGBColor[
              0.3108408715896832, 0.4392479097786054, 0.9411889024416368], 
             UndirectedEdge[209, 304] -> 
             RGBColor[
              0.4340887681799518, 0.5454892542135551, 0.9498622545115007], 
             UndirectedEdge[107, 238] -> 
             RGBColor[
              0.6034584631000393, 0.6889537916953953, 0.9619256072378731], 
             UndirectedEdge[298, 347] -> 
             RGBColor[
              0.6053850736529534, 0.6732320585746306, 0.9332564282432436], 
             UndirectedEdge[153, 343] -> 
             RGBColor[
              0.6745922283300736, 0.6759602202324175, 0.6117178414926958], 
             UndirectedEdge[110, 292] -> 
             RGBColor[
              0.26270222244097713`, 0.3934470704413564, 0.9382718749836785], 
             UndirectedEdge[332, 366] -> 
             RGBColor[
              0.7733040067608459, 0.8217300277301075, 0.9364478187060614], 
             UndirectedEdge[39, 136] -> 
             RGBColor[
              0.4858189996411032, 0.58387403700797, 0.9548088348705105], 
             UndirectedEdge[115, 380] -> 
             RGBColor[
              0.3761920419552687, 0.4997858351852904, 0.945208977256097], 
             UndirectedEdge[167, 238] -> 
             RGBColor[
              0.6385235935163676, 0.7169729137931458, 0.9649925887226747], 
             UndirectedEdge[1, 162] -> 
             RGBColor[
              0.6872615218603043, 0.7493655061890112, 0.9011754086019657], 
             UndirectedEdge[128, 243] -> 
             RGBColor[
              0.6767877739198453, 0.7454697257630043, 0.969898386334717], 
             UndirectedEdge[196, 366] -> 
             RGBColor[
              0.6367355724168273, 0.7047764561285741, 0.9269774948135423], 
             UndirectedEdge[136, 149] -> 
             RGBColor[
              0.33931274116248045`, 0.4646618500847354, 0.942975532387033], 
             UndirectedEdge[263, 360] -> 
             RGBColor[
              0.49097016149931266`, 0.5948474395690109, 0.9538391450065167], 
             UndirectedEdge[267, 354] -> 
             RGBColor[
              0.7177601638655791, 0.7780882628198464, 0.9709991575048041], 
             UndirectedEdge[192, 355] -> 
             RGBColor[
              0.5911760650889873, 0.6781186429995356, 0.9615492388260141], 
             UndirectedEdge[24, 100] -> 
             RGBColor[
              0.8584698023406894, 0.8900321278565226, 0.9728373746867212], 
             UndirectedEdge[11, 286] -> 
             RGBColor[
              0.8498178574926418, 0.8826839443838055, 0.9421488907129536], 
             UndirectedEdge[71, 110] -> 
             RGBColor[
              0.323245123171639, 0.45034208734991915`, 0.941966466443692], 
             UndirectedEdge[186, 306] -> 
             RGBColor[
              0.9101005510890103, 0.9307770646573068, 0.9782364355719964], 
             UndirectedEdge[6, 131] -> 
             RGBColor[
              0.4176002134713417, 0.5353587269233596, 0.9480421074744845], 
             UndirectedEdge[53, 264] -> 
             RGBColor[
              0.33556599370581575`, 0.46126971013993046`, 0.9427421715202584],
              UndirectedEdge[83, 118] -> 
             RGBColor[
              0.381519604195719, 0.5048748382466324, 0.9455310697081798], 
             UndirectedEdge[98, 272] -> 
             RGBColor[
              0.8075978381420608, 0.8496972164174561, 0.9425246727662214], 
             UndirectedEdge[200, 330] -> 
             RGBColor[
              0.6646385787375808, 0.7306646006062827, 0.9294771261738429], 
             UndirectedEdge[101, 389] -> 
             RGBColor[
              0.6824901981697706, 0.7449499291048518, 0.8904734609049623], 
             UndirectedEdge[10, 353] -> 
             RGBColor[
              0.3164502370868216, 0.4444566985441551, 0.9415335023108493], 
             UndirectedEdge[174, 340] -> 
             RGBColor[
              0.704805960499219, 0.767723585220657, 0.9726710157530443], 
             UndirectedEdge[77, 187] -> 
             RGBColor[
              0.577973006348121, 0.6682635497974452, 0.959919298726058], 
             UndirectedEdge[137, 264] -> 
             RGBColor[
              0.576997683466758, 0.6554257643160404, 0.963788209952505], 
             UndirectedEdge[20, 356] -> 
             RGBColor[
              0.7599928235383384, 0.810372260816041, 0.9130742025581919], 
             UndirectedEdge[130, 227] -> 
             RGBColor[
              0.5299139802683837, 0.6292470673914621, 0.956135916147048], 
             UndirectedEdge[24, 150] -> 
             RGBColor[
              0.7091259459444997, 0.7726938456194268, 0.9716427051991635], 
             UndirectedEdge[282, 339] -> 
             RGBColor[
              0.5481060162027617, 0.6440161817048695, 0.9575680598554255], 
             UndirectedEdge[69, 93] -> 
             RGBColor[
              0.639303244926536, 0.7066864407302285, 0.9110343677666786], 
             UndirectedEdge[65, 266] -> 
             RGBColor[
              0.536273260014597, 0.6344098171717258, 0.956636541943479], 
             UndirectedEdge[189, 336] -> 
             RGBColor[
              0.5305169124435325, 0.6264700309199099, 0.9574277066401233], 
             UndirectedEdge[191, 322] -> 
             RGBColor[
              0.4145473699132358, 0.533481828887373, 0.9476355697343934], 
             UndirectedEdge[297, 376] -> 
             RGBColor[
              0.707083046107468, 0.7664475796852348, 0.8992651712235923], 
             UndirectedEdge[33, 286] -> 
             RGBColor[
              0.9232659385575859, 0.9404062146150607, 0.949378203137485], 
             UndirectedEdge[145, 351] -> 
             RGBColor[
              0.7134890274676382, 0.7761023180659503, 0.972077576390075], 
             UndirectedEdge[83, 141] -> 
             RGBColor[
              0.6959322129661856, 0.758974836641966, 0.9490612397584663], 
             UndirectedEdge[148, 276] -> 
             RGBColor[
              0.6865938524742297, 0.7527818538145143, 0.9712644340706639], 
             UndirectedEdge[124, 160] -> 
             RGBColor[
              0.7638099192893013, 0.8130155697056207, 0.8943296084510072], 
             UndirectedEdge[25, 362] -> 
             RGBColor[
              0.5540084752375988, 0.6488080638520997, 0.9580327230520678], 
             UndirectedEdge[96, 208] -> 
             RGBColor[
              0.9627716944567364, 0.971471928388395, 0.9351909290189865], 
             UndirectedEdge[240, 272] -> 
             RGBColor[
              0.572538901371361, 0.6638518985736719, 0.959491506076505], 
             UndirectedEdge[25, 182] -> 
             RGBColor[
              0.6894098970089975, 0.7555758822946973, 0.9710543939193477], 
             UndirectedEdge[101, 380] -> 
             RGBColor[
              0.6461923280040573, 0.713036001931584, 0.8881779678178496], 
             UndirectedEdge[24, 358] -> 
             RGBColor[
              0.8465511268924928, 0.8809152870390236, 0.9851107248651725], 
             UndirectedEdge[202, 234] -> 
             RGBColor[
              0.41666104971276996`, 0.5353125920930939, 0.9477702515421661], 
             UndirectedEdge[17, 62] -> 
             RGBColor[
              0.5051947546834759, 0.6009306491996074, 0.9564360450764208], 
             UndirectedEdge[24, 211] -> 
             RGBColor[
              0.5535390737498129, 0.6434751312898699, 0.9601371174769529], 
             UndirectedEdge[2, 39] -> 
             RGBColor[
              0.588127637977254, 0.6755873316649164, 0.961347858085783], 
             UndirectedEdge[164, 328] -> 
             RGBColor[
              0.6883283902781031, 0.755905138216622, 0.9699400249349601], 
             UndirectedEdge[228, 301] -> 
             RGBColor[
              0.7185621334021024, 0.7800654669789868, 0.972583216178752], 
             UndirectedEdge[118, 286] -> 
             RGBColor[
              0.6584905703887991, 0.7252118175053943, 0.9272218590370562], 
             UndirectedEdge[139, 215] -> 
             RGBColor[
              0.9184572460140372, 0.90273672621669, 0.6613045538337405], 
             UndirectedEdge[239, 377] -> 
             RGBColor[
              0.6175065157176576, 0.60582948778175, 0.6033478643936931], 
             UndirectedEdge[348, 374] -> 
             RGBColor[
              0.8612195640091025, 0.8919940516317988, 0.9636854779782584], 
             UndirectedEdge[8, 388] -> 
             RGBColor[
              0.877212708431244, 0.9049296186711664, 0.9881505252988432], 
             UndirectedEdge[249, 370] -> 
             RGBColor[
              0.8639361885787713, 0.893929062006797, 0.9544783199000375], 
             UndirectedEdge[61, 285] -> 
             RGBColor[
              0.6020051521121532, 0.6838472750521698, 0.9639053805264381], 
             UndirectedEdge[162, 280] -> 
             RGBColor[
              0.619343720969611, 0.6970991380668843, 0.965798059109747], 
             UndirectedEdge[126, 205] -> 
             RGBColor[
              0.3841520278581912, 0.5067984386212256, 0.9457626456162251], 
             UndirectedEdge[161, 334] -> 
             RGBColor[
              0.7987158118423858, 0.8394786253578144, 0.7935732983668249], 
             UndirectedEdge[192, 399] -> 
             RGBColor[
              0.7345934703655259, 0.7773348529114652, 0.6754834905103622], 
             UndirectedEdge[69, 281] -> 
             RGBColor[
              0.9882481872518103, 0.9894083376678813, 0.8444214801613865], 
             UndirectedEdge[38, 128] -> 
             RGBColor[
              0.9154953417400773, 0.9015169297787595, 0.6627019963337168], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.692992011995306, 0.7586901584990429, 0.9710991117910134], 
             UndirectedEdge[145, 355] -> 
             RGBColor[
              0.6757022949331342, 0.7465830354201918, 0.9683113480281278], 
             UndirectedEdge[23, 139] -> 
             RGBColor[
              0.8886552926337163, 0.914053624713544, 0.9892419291949905], 
             UndirectedEdge[120, 359] -> 
             RGBColor[
              0.9763168661865573, 0.9818577380962826, 0.9249735473823079], 
             UndirectedEdge[117, 309] -> 
             RGBColor[
              0.6235753254185079, 0.7033377374626664, 0.9648410218723052], 
             UndirectedEdge[19, 167] -> 
             RGBColor[
              0.6654989884510358, 0.7386121348483752, 0.9672943777933125], 
             UndirectedEdge[26, 285] -> 
             RGBColor[
              0.5919802402502077, 0.6760157377134657, 0.9629061910001672], 
             UndirectedEdge[166, 169] -> 
             RGBColor[
              0.30242204020137997`, 0.4344455893405591, 0.9405613037347906], 
             UndirectedEdge[31, 383] -> 
             RGBColor[
              0.5366276143557123, 0.6346974979893244, 0.9566644380152545], 
             UndirectedEdge[146, 346] -> 
             RGBColor[
              0.41992882641876716`, 0.5381429760325958, 0.9479784713842908], 
             UndirectedEdge[191, 349] -> 
             RGBColor[
              0.5741255698071286, 0.6627657959622628, 0.9608310665279384], 
             UndirectedEdge[212, 362] -> 
             RGBColor[
              0.4829524146964653, 0.5884912810509323, 0.95316568161868], 
             UndirectedEdge[242, 380] -> 
             RGBColor[
              0.41844668297415877`, 0.5342135288156125, 0.9485013015609578], 
             UndirectedEdge[175, 307] -> 
             RGBColor[
              0.5200212652336925, 0.6212157156645661, 0.9553571253813078], 
             UndirectedEdge[140, 193] -> 
             RGBColor[
              0.6163464469663442, 0.692569048366847, 0.9664974026317281], 
             UndirectedEdge[8, 25] -> 
             RGBColor[
              0.6791230810672269, 0.7473734544909096, 0.9700732282316726], 
             UndirectedEdge[8, 269] -> 
             RGBColor[
              0.5971902826697753, 0.6776357880393395, 0.9645131306800018], 
             UndirectedEdge[155, 371] -> 
             RGBColor[
              0.4083763212814054, 0.5281367767284042, 0.9472423559724172], 
             UndirectedEdge[55, 161] -> 
             RGBColor[
              0.6400124885559785, 0.7039524187352767, 0.7824152814184497], 
             UndirectedEdge[110, 202] -> 
             RGBColor[
              0.3589396528361244, 0.4812588948860709, 0.9442408903104798], 
             UndirectedEdge[332, 380] -> 
             RGBColor[
              0.43373676148939994`, 0.5466267033644727, 0.9497049925510808], 
             UndirectedEdge[359, 360] -> 
             RGBColor[
              0.6599429090660183, 0.7273666628972627, 0.9404041725131196], 
             UndirectedEdge[128, 350] -> 
             RGBColor[
              0.6287028542839633, 0.7048932247383414, 0.9665381947941531], 
             UndirectedEdge[272, 378] -> 
             RGBColor[
              0.8023697206447978, 0.8457980949482542, 0.9513745119776607], 
             UndirectedEdge[52, 345] -> 
             RGBColor[
              0.3288358825773573, 0.45909826585639046`, 0.9421794033601769], 
             UndirectedEdge[32, 333] -> 
             RGBColor[
              0.6386510784845063, 0.7169057707553772, 0.9651192930433687], 
             UndirectedEdge[85, 168] -> 
             RGBColor[
              0.5807697854853608, 0.6661608931990817, 0.9622532043836047], 
             UndirectedEdge[23, 354] -> 
             RGBColor[
              0.9242673795512668, 0.9423697074402273, 0.9898639959788991], 
             UndirectedEdge[51, 373] -> 
             RGBColor[
              0.43922334641495353`, 0.5537318680946479, 0.9495182035815763], 
             UndirectedEdge[55, 334] -> 
             RGBColor[
              0.44438896462713295`, 0.5531303075604537, 0.9507387636374729], 
             UndirectedEdge[66, 267] -> 
             RGBColor[
              0.4749342993829424, 0.5846075428751689, 0.951808969450622], 
             UndirectedEdge[30, 153] -> 
             RGBColor[
              0.6861351519112935, 0.685958120474262, 0.6124533463762846], 
             UndirectedEdge[179, 290] -> 
             RGBColor[
              0.5865449776599099, 0.6665604457485917, 0.9641652915121381], 
             UndirectedEdge[178, 200] -> 
             RGBColor[
              0.9612584214711017, 0.9706271746834362, 0.9504635664141862], 
             UndirectedEdge[340, 358] -> 
             RGBColor[
              0.7038170990540502, 0.7669350939462083, 0.9725766972656369], 
             UndirectedEdge[31, 259] -> 
             RGBColor[
              0.6169839910918558, 0.6999344246372442, 0.9629903863470305], 
             UndirectedEdge[92, 146] -> 
             RGBColor[
              0.6855325990105312, 0.7519493719978583, 0.9711568887650737], 
             UndirectedEdge[3, 373] -> 
             RGBColor[
              0.38994146277421726`, 0.5121694288524076, 0.9460677030896445], 
             UndirectedEdge[174, 341] -> 
             RGBColor[
              0.9604750033009379, 0.9685502808109443, 0.8867358637488907], 
             UndirectedEdge[248, 260] -> 
             RGBColor[
              0.5221695694159422, 0.6218510165820574, 0.9558326095149848], 
             UndirectedEdge[41, 325] -> 
             RGBColor[
              0.6862418283605125, 0.7530029620549512, 0.9708060731721787], 
             UndirectedEdge[66, 346] -> 
             RGBColor[
              0.4228620036025786, 0.5406835466834414, 0.9481653708407365], 
             UndirectedEdge[53, 142] -> 
             RGBColor[
              0.5463030747013022, 0.6404842181793464, 0.9582892566379304], 
             UndirectedEdge[38, 44] -> 
             RGBColor[
              0.6783726770992897, 0.7102125167419102, 0.6423359228562291], 
             UndirectedEdge[76, 187] -> 
             RGBColor[
              0.7444069305554458, 0.7991995948821006, 0.9591038146174735], 
             UndirectedEdge[156, 160] -> 
             RGBColor[
              0.5120625457026087, 0.6147544686130033, 0.9547305858260706], 
             UndirectedEdge[141, 290] -> 
             RGBColor[
              0.9197662707536023, 0.9381868871782275, 0.9688487036907449], 
             UndirectedEdge[3, 79] -> 
             RGBColor[
              0.616017043085079, 0.6947599329751664, 0.965336483495169], 
             UndirectedEdge[301, 382] -> 
             RGBColor[
              0.6498637440569892, 0.7250702847335795, 0.96664360695784], 
             UndirectedEdge[193, 389] -> 
             RGBColor[
              0.3504883483337448, 0.4779971240952595, 0.9435537855245169], 
             UndirectedEdge[189, 291] -> 
             RGBColor[0.516403833679741, 0.6142459914386774, 0.956528433741], 
             UndirectedEdge[161, 196] -> 
             RGBColor[
              0.6425312543683536, 0.7065998013030592, 0.7825587214052844], 
             UndirectedEdge[83, 161] -> 
             RGBColor[
              0.7121880352234731, 0.7685993373295801, 0.7869361772540764], 
             UndirectedEdge[100, 211] -> 
             RGBColor[
              0.6457674478632786, 0.7161943646739588, 0.9556390494650968], 
             UndirectedEdge[32, 287] -> 
             RGBColor[
              0.548104838584528, 0.6440152256613363, 0.9575679671490045], 
             UndirectedEdge[156, 181] -> 
             RGBColor[
              0.5760408429135648, 0.6663240664173034, 0.9600207548941315], 
             UndirectedEdge[126, 176] -> 
             RGBColor[
              0.539014117110354, 0.630554202189857, 0.9592996645828549], 
             UndirectedEdge[46, 350] -> 
             RGBColor[
              0.6911302203238212, 0.7531460602608244, 0.9172149820727115], 
             UndirectedEdge[47, 149] -> 
             RGBColor[
              0.5564368830522533, 0.6486516048972153, 0.9591931585533284], 
             UndirectedEdge[57, 108] -> 
             RGBColor[
              0.3946637916443586, 0.5162596727685737, 0.9463686057094585], 
             UndirectedEdge[105, 400] -> 
             RGBColor[
              0.4791976997009968, 0.5880733060844545, 0.9521433447609261], 
             UndirectedEdge[62, 256] -> 
             RGBColor[
              0.8323151877347938, 0.8698304264034474, 0.9818975013786384], 
             UndirectedEdge[193, 332] -> 
             RGBColor[
              0.44431375833214437`, 0.5562625028340671, 0.9503615743341289], 
             UndirectedEdge[1, 387] -> 
             RGBColor[
              0.9909729784091423, 0.9905351088353767, 0.7992646391509213], 
             UndirectedEdge[72, 284] -> 
             RGBColor[
              0.6103782693284605, 0.6927694148843542, 0.963702524991572], 
             UndirectedEdge[127, 394] -> 
             RGBColor[
              0.6893645149989586, 0.7351485929706745, 0.6665313432707463], 
             UndirectedEdge[110, 385] -> 
             RGBColor[
              0.4528238332985528, 0.5574861879493624, 0.9516296179996778], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.9884762012529726, 0.9895026273170544, 0.840642698080807], 
             UndirectedEdge[97, 393] -> 
             RGBColor[
              0.517623173379571, 0.6168401282572825, 0.9559551719317491], 
             UndirectedEdge[19, 150] -> 
             RGBColor[
              0.6556913075148649, 0.7309502999599025, 0.9663168398155844], 
             UndirectedEdge[272, 342] -> 
             RGBColor[
              0.8087044850212217, 0.8505225518479664, 0.9406514082595336], 
             UndirectedEdge[96, 187] -> 
             RGBColor[
              0.7369280039672341, 0.7936218236782306, 0.9717636865148598], 
             UndirectedEdge[129, 333] -> 
             RGBColor[
              0.5802016819438183, 0.6694539175283392, 0.9605179424404915], 
             UndirectedEdge[19, 160] -> 
             RGBColor[
              0.5989922699334793, 0.6850673151026453, 0.9617521993188503], 
             UndirectedEdge[183, 357] -> 
             RGBColor[
              0.6385742697209579, 0.7020981418507444, 0.7480705574643634], 
             UndirectedEdge[197, 217] -> 
             RGBColor[
              0.585469134952716, 0.6703220379119776, 0.9625142100502599], 
             UndirectedEdge[199, 345] -> 
             RGBColor[
              0.3216335729449632, 0.45285998725141835`, 0.9417204785591531], 
             UndirectedEdge[44, 346] -> 
             RGBColor[
              0.3895478866201275, 0.5118285329694476, 0.9460426247651317], 
             UndirectedEdge[78, 80] -> 
             RGBColor[
              0.558700912897231, 0.6409882009398185, 0.9620200532857368], 
             UndirectedEdge[42, 320] -> 
             RGBColor[
              0.47213312980834937`, 0.5823379699903566, 0.9515871959406047], 
             UndirectedEdge[161, 332] -> 
             RGBColor[
              0.779099688712372, 0.8235533729045926, 0.7920290452978035], 
             UndirectedEdge[239, 309] -> 
             RGBColor[
              0.5349357107151862, 0.6264474657859884, 0.9590389202395396], 
             UndirectedEdge[8, 377] -> 
             RGBColor[
              0.8971705168787882, 0.834793679212976, 0.6263791305725956], 
             UndirectedEdge[75, 126] -> 
             RGBColor[
              0.32143351141535514`, 0.4526867040098568, 0.9417077308153938], 
             UndirectedEdge[54, 310] -> 
             RGBColor[
              0.6422188324424669, 0.7138451320795429, 0.9659851271307576], 
             UndirectedEdge[65, 211] -> 
             RGBColor[
              0.46654693632102184`, 0.5747487159751559, 0.9519912956797376], 
             UndirectedEdge[88, 356] -> 
             RGBColor[
              0.5696723836490676, 0.6615247303515623, 0.9592658433010057], 
             UndirectedEdge[98, 158] -> 
             RGBColor[
              0.9845463789846525, 0.9811359191293039, 0.6684029784826924], 
             UndirectedEdge[13, 390] -> 
             RGBColor[
              0.4839597911758574, 0.5900204305717983, 0.9530484472791221], 
             UndirectedEdge[241, 242] -> 
             RGBColor[
              0.46692077740730187`, 0.5766738894545017, 0.9515726528913787], 
             UndirectedEdge[12, 238] -> 
             RGBColor[
              0.4966978029077639, 0.6005064420714445, 0.9540112437296154], 
             UndirectedEdge[175, 343] -> 
             RGBColor[
              0.47416328165032684`, 0.5825840110137847, 0.9521344289912239], 
             UndirectedEdge[59, 258] -> 
             RGBColor[
              0.5685734311309422, 0.6606325511901014, 0.9591793297331832], 
             UndirectedEdge[152, 156] -> 
             RGBColor[
              0.4089232174492039, 0.5277363090359296, 0.947518737185295], 
             UndirectedEdge[39, 258] -> 
             RGBColor[
              0.6013120005126329, 0.6862909911199007, 0.9623857794004794], 
             UndirectedEdge[183, 368] -> 
             RGBColor[
              0.6773500073377795, 0.738023531660135, 0.750455641827472], 
             UndirectedEdge[44, 119] -> 
             RGBColor[
              0.3397977001795779, 0.4672883405952152, 0.9429256448459291], 
             UndirectedEdge[149, 264] -> 
             RGBColor[
              0.33851834008483933`, 0.4638268841841971, 0.9429302924208725], 
             UndirectedEdge[120, 241] -> 
             RGBColor[
              0.6920607347867271, 0.7543138122721581, 0.9297287820286724], 
             UndirectedEdge[116, 304] -> 
             RGBColor[
              0.5360484695606471, 0.6261503903997843, 0.9593344832963231], 
             UndirectedEdge[82, 256] -> 
             RGBColor[
              0.8574393256575834, 0.40709880312757496`, 0.4396039075688919], 
             UndirectedEdge[98, 186] -> 
             RGBColor[
              0.9244199308578828, 0.9414564346430994, 0.9539974607156735], 
             UndirectedEdge[72, 262] -> 
             RGBColor[
              0.5977497669503036, 0.6829039328463651, 0.9624438338945819], 
             UndirectedEdge[147, 241] -> 
             RGBColor[
              0.33876970295285, 0.4649098293707157, 0.9429146288305263], 
             UndirectedEdge[13, 205] -> 
             RGBColor[
              0.4218830737642665, 0.5396237548528184, 0.9481615406899732], 
             UndirectedEdge[142, 394] -> 
             RGBColor[
              0.5426511548187203, 0.6373211087278843, 0.9580565595322783], 
             UndirectedEdge[42, 75] -> 
             RGBColor[
              0.3988604406591513, 0.5196578825159008, 0.9467014180031201], 
             UndirectedEdge[56, 341] -> 
             RGBColor[
              0.964866217866776, 0.9720021535997123, 0.8854363383903375], 
             UndirectedEdge[306, 378] -> 
             RGBColor[
              0.9593876731244331, 0.9692319736295599, 0.9536302553957845], 
             UndirectedEdge[27, 295] -> 
             RGBColor[
              0.7322766407676332, 0.7899423593711734, 0.9739917277809325], 
             UndirectedEdge[111, 247] -> 
             RGBColor[
              0.41576568432942174`, 0.5278462434247868, 0.9486717098290569], 
             UndirectedEdge[128, 259] -> 
             RGBColor[
              0.7376759209944859, 0.7949014665379642, 0.9746917243130646], 
             UndirectedEdge[52, 68] -> 
             RGBColor[
              0.4486270538265703, 0.5604626445097853, 0.9505081588639013], 
             UndirectedEdge[241, 359] -> 
             RGBColor[
              0.6848178015914035, 0.7489120445543005, 0.9419891786688332], 
             UndirectedEdge[361, 382] -> 
             RGBColor[
              0.6537293584493005, 0.7280901320766104, 0.9670288952742452], 
             UndirectedEdge[14, 390] -> 
             RGBColor[
              0.4382301014185279, 0.548788032509226, 0.9501940412709784], 
             UndirectedEdge[11, 332] -> 
             RGBColor[
              0.6397585447884606, 0.7173010007000559, 0.9655509694278042], 
             UndirectedEdge[22, 209] -> 
             RGBColor[
              0.6111849832456835, 0.6951721786350267, 0.9625710267289027], 
             UndirectedEdge[33, 156] -> 
             RGBColor[
              0.6740329564797548, 0.7432203213800879, 0.9696963871013629], 
             UndirectedEdge[283, 332] -> 
             RGBColor[
              0.7311380049090432, 0.7893212658559592, 0.9744905927941935], 
             UndirectedEdge[150, 181] -> 
             RGBColor[
              0.6592897232913462, 0.7337614097134626, 0.9666754962710766], 
             UndirectedEdge[117, 323] -> 
             RGBColor[
              0.5692277360528875, 0.6608809875932662, 0.9594241620714385], 
             UndirectedEdge[199, 223] -> 
             RGBColor[
              0.31655293963220804`, 0.4475199195089553, 0.9414311440081151], 
             UndirectedEdge[128, 306] -> 
             RGBColor[
              0.9055320997727989, 0.9271343055850674, 0.9778006926071514], 
             UndirectedEdge[184, 288] -> 
             RGBColor[
              0.7085411394119299, 0.7700249985759455, 0.9547479877057647], 
             UndirectedEdge[145, 182] -> 
             RGBColor[
              0.7664606296594593, 0.8179713293262092, 0.977228004598726], 
             UndirectedEdge[284, 397] -> 
             RGBColor[
              0.8754762247617659, 0.9014827574612965, 0.888201094556001], 
             UndirectedEdge[61, 148] -> 
             RGBColor[
              0.8651877387310357, 0.895469838826618, 0.9869694452513127], 
             UndirectedEdge[34, 159] -> 
             RGBColor[
              0.3136551903315556, 0.445424436715442, 0.9412313286976333], 
             UndirectedEdge[276, 382] -> 
             RGBColor[
              0.5012933775376485, 0.605836901527585, 0.9539310596388778], 
             UndirectedEdge[59, 164] -> 
             RGBColor[
              0.7032995499000375, 0.7680594000407633, 0.9711186094615635], 
             UndirectedEdge[80, 377] -> 
             RGBColor[
              0.6017351375761426, 0.5892527693918885, 0.602449707740197], 
             UndirectedEdge[180, 370] -> 
             RGBColor[
              0.8553064265983996, 0.8871874263591103, 0.9536181858755449], 
             UndirectedEdge[98, 374] -> 
             RGBColor[
              0.9700754971505132, 0.9772029352885048, 0.9355385571505778], 
             UndirectedEdge[139, 350] -> 
             RGBColor[
              0.6321080841907128, 0.70760846263348, 0.9668629886625436], 
             UndirectedEdge[36, 276] -> 
             RGBColor[
              0.5136893454446807, 0.6159005067065042, 0.954906915640446], 
             UndirectedEdge[53, 281] -> 
             RGBColor[
              0.6970168516695887, 0.7571361173344937, 0.8768414773097346], 
             UndirectedEdge[73, 183] -> 
             RGBColor[
              0.9623157309768073, 0.9683547026062032, 0.7749808367429976], 
             UndirectedEdge[101, 115] -> 
             RGBColor[
              0.7187708886340389, 0.7763744396644772, 0.8927852344195906], 
             UndirectedEdge[283, 366] -> 
             RGBColor[
              0.9405819700163764, 0.9542452843095188, 0.9521301370524495], 
             UndirectedEdge[22, 141] -> 
             RGBColor[
              0.8038673245912844, 0.8471792134273055, 0.9574207842225422], 
             UndirectedEdge[197, 314] -> 
             RGBColor[
              0.572823796291683, 0.6593692811369921, 0.9617084602526128], 
             UndirectedEdge[13, 14] -> 
             RGBColor[
              0.3369146378499216, 0.46461661907288676`, 0.942748330081265], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.8301950889527709, 0.8682081602778, 0.9834058041123793], 
             UndirectedEdge[323, 395] -> 
             RGBColor[
              0.8021899765079501, 0.8461922321204847, 0.9736228300910936], 
             UndirectedEdge[93, 131] -> 
             RGBColor[
              0.3871046284578096, 0.5074550782377787, 0.9461535085097524], 
             UndirectedEdge[52, 105] -> 
             RGBColor[
              0.4233597165199882, 0.5399494818037281, 0.9485190215138208], 
             UndirectedEdge[178, 330] -> 
             RGBColor[
              0.6440402412033733, 0.715302394199953, 0.9643447387124144], 
             UndirectedEdge[92, 98] -> 
             RGBColor[
              0.9513580147015763, 0.962936131485254, 0.9565668392005964], 
             UndirectedEdge[37, 323] -> 
             RGBColor[
              0.5943467252976893, 0.6812737146597663, 0.9614016209186788], 
             UndirectedEdge[279, 370] -> 
             RGBColor[
              0.870719024409089, 0.8992278649089027, 0.9551543695863989], 
             UndirectedEdge[150, 160] -> 
             RGBColor[
              0.59531142608039, 0.6821918119091626, 0.9613853272030157], 
             UndirectedEdge[188, 273] -> 
             RGBColor[
              0.8379517075302605, 0.8739146221105201, 0.9843286437979566], 
             UndirectedEdge[179, 386] -> 
             RGBColor[
              0.4003516904273702, 0.5185390093832548, 0.9471663844962432], 
             UndirectedEdge[141, 179] -> 
             RGBColor[
              0.6286063981629638, 0.6994252937277734, 0.9448165289779746], 
             UndirectedEdge[117, 388] -> 
             RGBColor[
              0.6861883219734348, 0.7528556989166184, 0.9709213607527063], 
             UndirectedEdge[198, 214] -> 
             RGBColor[
              0.6524433617502627, 0.7219853773360914, 0.956190989667407], 
             UndirectedEdge[150, 238] -> 
             RGBColor[
              0.6287159125801967, 0.709311078904673, 0.9640150507449464], 
             UndirectedEdge[331, 392] -> 
             RGBColor[
              0.4253546431105385, 0.5428425457415318, 0.9483241996260291], 
             UndirectedEdge[323, 365] -> 
             RGBColor[
              0.6823169657629835, 0.7517504665458303, 0.9689706365988338], 
             UndirectedEdge[6, 71] -> 
             RGBColor[
              0.3676305345156977, 0.49284482417473774`, 0.944646070469791], 
             UndirectedEdge[132, 249] -> 
             RGBColor[
              0.6765323960588097, 0.746536427494134, 0.9688693210564143], 
             UndirectedEdge[348, 378] -> 
             RGBColor[
              0.8648511197518949, 0.8947024599586466, 0.9575382013671423], 
             UndirectedEdge[174, 198] -> 
             RGBColor[
              0.9396963101430329, 0.9543692752041593, 0.9808289411040756], 
             UndirectedEdge[72, 236] -> 
             RGBColor[
              0.45688953447239355`, 0.5699546466507228, 0.9503893431825177], 
             UndirectedEdge[9, 100] -> 
             RGBColor[
              0.7073787391802446, 0.7692673170091551, 0.9596454506538086], 
             UndirectedEdge[51, 298] -> 
             RGBColor[
              0.7341045532514032, 0.7902105541615361, 0.9415265535643262], 
             UndirectedEdge[23, 128] -> 
             RGBColor[
              0.8852500627269668, 0.9113383868184053, 0.9889171353266001], 
             UndirectedEdge[215, 353] -> 
             RGBColor[
              0.617093990965967, 0.6519662192990302, 0.6368859062476318], 
             UndirectedEdge[80, 96] -> 
             RGBColor[
              0.6042295346748048, 0.6771897858952436, 0.962836534462203], 
             UndirectedEdge[78, 388] -> 
             RGBColor[
              0.8716620682896115, 0.9005036888903415, 0.9876211002870193], 
             UndirectedEdge[312, 380] -> 
             RGBColor[
              0.3788007501533155, 0.5020271745227317, 0.9453802285014639], 
             UndirectedEdge[57, 325] -> 
             RGBColor[
              0.4278965886206729, 0.5439914116261517, 0.9487770728519884], 
             UndirectedEdge[308, 374] -> 
             RGBColor[
              0.6410910583778444, 0.7115110044726083, 0.9461041696136253], 
             UndirectedEdge[76, 365] -> 
             RGBColor[
              0.8292086838179491, 0.8671040261182172, 0.9664233953784738], 
             UndirectedEdge[182, 187] -> 
             RGBColor[
              0.7072368382730634, 0.770048596307418, 0.9724577960378924], 
             UndirectedEdge[74, 286] -> 
             RGBColor[
              0.6333607846212976, 0.7010414960721794, 0.9257086395327161], 
             UndirectedEdge[137, 164] -> 
             RGBColor[
              0.8280112041850242, 0.8661045331791712, 0.9833496741770149], 
             UndirectedEdge[149, 258] -> 
             RGBColor[
              0.45480574203401025`, 0.567078804196666, 0.950552476917002], 
             UndirectedEdge[147, 331] -> 
             RGBColor[
              0.3451431994566061, 0.47043023170102055`, 0.943320742391884], 
             UndirectedEdge[42, 367] -> 
             RGBColor[
              0.7232303076318288, 0.7809839475427538, 0.9292909229588842], 
             UndirectedEdge[16, 365] -> 
             RGBColor[
              0.7777937652578093, 0.8265945897351595, 0.9784186925520136], 
             UndirectedEdge[113, 183] -> 
             RGBColor[
              0.664912225035782, 0.72725054977126, 0.7496631173374878], 
             UndirectedEdge[16, 323] -> 
             RGBColor[
              0.7562941121747098, 0.8097988973432267, 0.9762758080583714], 
             UndirectedEdge[340, 343] -> 
             RGBColor[
              0.4412260430055843, 0.5558440768762911, 0.9495414889120292], 
             UndirectedEdge[323, 362] -> 
             RGBColor[
              0.6351375166810684, 0.7143895167090042, 0.9646128214379706], 
             UndirectedEdge[334, 364] -> 
             RGBColor[
              0.4455417901140636, 0.5543420002405753, 0.9508044153435011], 
             UndirectedEdge[94, 324] -> 
             RGBColor[
              0.6830126676554551, 0.7493531446932592, 0.9711303669653432], 
             UndirectedEdge[135, 350] -> 
             RGBColor[
              0.5245970932855664, 0.6232353728322573, 0.9562493818300258], 
             UndirectedEdge[31, 215] -> 
             RGBColor[
              0.7943600862046576, 0.8050544464208313, 0.6492784219993161], 
             UndirectedEdge[3, 21] -> 
             RGBColor[
              0.4562846002543839, 0.5679182337511943, 0.9507686915527949], 
             UndirectedEdge[127, 193] -> 
             RGBColor[
              0.6536439585782071, 0.7042092423663879, 0.6642552610020638], 
             UndirectedEdge[50, 230] -> 
             RGBColor[
              0.3604371014816705, 0.48369383915114905`, 0.9442946412403026], 
             UndirectedEdge[169, 382] -> 
             RGBColor[
              0.4362772751039133, 0.5495232214038076, 0.9497882910832822], 
             UndirectedEdge[12, 19] -> 
             RGBColor[
              0.523673197842432, 0.622145663126674, 0.9563130328002534], 
             UndirectedEdge[133, 296] -> 
             RGBColor[
              0.737725816407133, 0.7931867375438041, 0.9427846803308069], 
             UndirectedEdge[214, 332] -> 
             RGBColor[
              0.45909634665803584`, 0.5690664378474615, 0.9513035077905252], 
             UndirectedEdge[76, 395] -> 
             RGBColor[
              0.9490816945629158, 0.9615457916928715, 0.9710755888707336], 
             UndirectedEdge[299, 370] -> 
             RGBColor[
              0.9053389213219183, 0.9264259725204391, 0.9585644139836139], 
             UndirectedEdge[170, 235] -> 
             RGBColor[
              0.6754698104737902, 0.7427073871581614, 0.9690076699524957], 
             UndirectedEdge[46, 400] -> 
             RGBColor[
              0.7238940082470606, 0.781284176352046, 0.9193690380017014], 
             UndirectedEdge[65, 329] -> 
             RGBColor[
              0.46095813142265, 0.569907974073688, 0.9516351819735995], 
             UndirectedEdge[81, 267] -> 
             RGBColor[
              0.4715441794113136, 0.5816711913481282, 0.9515929540037953], 
             UndirectedEdge[104, 182] -> 
             RGBColor[
              0.6836555680619837, 0.7509042588259466, 0.9706013920658373], 
             UndirectedEdge[23, 306] -> 
             RGBColor[
              0.9300143738069915, 0.9466558063463073, 0.9801358337601167], 
             UndirectedEdge[209, 286] -> 
             RGBColor[
              0.7802208378136646, 0.8273047811084493, 0.9359022715937033], 
             UndirectedEdge[150, 167] -> 
             RGBColor[
              0.6618181445979465, 0.7357366316548923, 0.966927505677478], 
             UndirectedEdge[4, 288] -> 
             RGBColor[
              0.7697745556491642, 0.8197370444112977, 0.9595685065373544], 
             UndirectedEdge[171, 272] -> 
             RGBColor[
              0.7609388026860717, 0.8136075098557803, 0.976730023912024], 
             UndirectedEdge[78, 182] -> 
             RGBColor[
              0.8644231081416474, 0.8947315385646935, 0.9869306418058106], 
             UndirectedEdge[143, 374] -> 
             RGBColor[
              0.6769967757595627, 0.7426107321948239, 0.9483920501750092], 
             UndirectedEdge[55, 262] -> 
             RGBColor[
              0.5102168367793307, 0.6051570575446097, 0.9568886109979939], 
             UndirectedEdge[165, 190] -> 
             RGBColor[
              0.5924384799226847, 0.6791340250754849, 0.9616551181065705], 
             UndirectedEdge[2, 149] -> 
             RGBColor[
              0.44162137949863123`, 0.5563751447416817, 0.9495145556023057], 
             UndirectedEdge[39, 47] -> 
             RGBColor[
              0.702943141530876, 0.76786379182045, 0.9710264610368058], 
             UndirectedEdge[230, 300] -> 
             RGBColor[
              0.2971526695262403, 0.42888004495939047`, 0.9402622131963285], 
             UndirectedEdge[40, 48] -> 
             RGBColor[
              0.590632544876593, 0.6739551408489463, 0.9631984000758809], 
             UndirectedEdge[25, 208] -> 
             RGBColor[
              0.7422298615465127, 0.7961146871629736, 0.9184981999560574], 
             UndirectedEdge[32, 52] -> 
             RGBColor[
              0.4725132409334405, 0.5798545272636091, 0.9523885670109404], 
             UndirectedEdge[161, 366] -> 
             RGBColor[
              0.9885436538197052, 0.9884773913581522, 0.7696685895560595], 
             UndirectedEdge[190, 318] -> 
             RGBColor[
              0.7319095272943578, 0.7882708016478883, 0.9371231761622261], 
             UndirectedEdge[179, 245] -> 
             RGBColor[
              0.3400854813791947, 0.4677513775770392, 0.9429361546459561], 
             UndirectedEdge[37, 182] -> 
             RGBColor[
              0.7040683510702725, 0.7674762756574705, 0.9722083611187378], 
             UndirectedEdge[12, 206] -> 
             RGBColor[
              0.5605371026460457, 0.6509440257353103, 0.9599872823183008], 
             UndirectedEdge[18, 218] -> 
             RGBColor[
              0.6591966296785293, 0.7272850560086322, 0.9485992965662876], 
             UndirectedEdge[92, 119] -> 
             RGBColor[
              0.6084268999802704, 0.6837152095464586, 0.9662968397731847], 
             UndirectedEdge[215, 400] -> 
             RGBColor[
              0.7157508696217161, 0.7412359430939488, 0.6430900165148585], 
             UndirectedEdge[71, 292] -> 
             RGBColor[
              0.3210956072024832, 0.4480828097791524, 0.9418440546891725], 
             UndirectedEdge[158, 346] -> 
             RGBColor[
              0.6913654507038963, 0.7464551895647409, 0.6812499589744834], 
             UndirectedEdge[92, 151] -> 
             RGBColor[
              0.7942989143987637, 0.8400705672844216, 0.9799093188098367], 
             UndirectedEdge[104, 170] -> 
             RGBColor[
              0.7123407648237059, 0.7737272362140621, 0.9716101255467218], 
             UndirectedEdge[82, 316] -> 
             RGBColor[
              0.7167688621572629, 0.2953120049865697, 0.427816822188261], 
             UndirectedEdge[287, 353] -> 
             RGBColor[
              0.38326223153596084`, 0.5010129459240424, 0.9461534738963834], 
             UndirectedEdge[368, 372] -> 
             RGBColor[
              0.37001122839661843`, 0.4949068615572376, 0.9447977661787181], 
             UndirectedEdge[9, 203] -> 
             RGBColor[
              0.6169870272839313, 0.6979828981082553, 0.964326579990886], 
             UndirectedEdge[17, 384] -> 
             RGBColor[
              0.5473855031282364, 0.6338903825462188, 0.9606412245864336], 
             UndirectedEdge[82, 310] -> 
             RGBColor[
              0.8577660322678926, 0.4073424603826107, 0.43905087849636915`], 
             UndirectedEdge[129, 287] -> 
             RGBColor[
              0.48965544204383993`, 0.5965633724342984, 0.9529666165461272], 
             UndirectedEdge[81, 363] -> 
             RGBColor[
              0.37707039390972213`, 0.5009309489684587, 0.9452508728814499], 
             UndirectedEdge[64, 356] -> 
             RGBColor[
              0.5917050354388211, 0.6792925679158583, 0.9610818742462925], 
             UndirectedEdge[245, 352] -> 
             RGBColor[
              0.5489679351121943, 0.6417706899400583, 0.9588914895212179], 
             UndirectedEdge[87, 232] -> 
             RGBColor[
              0.9271576481627205, 0.9445027659301757, 0.9841914669209899], 
             UndirectedEdge[88, 255] -> 
             RGBColor[
              0.7423271603640602, 0.79854869554348, 0.9752061985558504], 
             UndirectedEdge[154, 392] -> 
             RGBColor[
              0.3680155948946158, 0.49224310320456865`, 0.9447048499279909], 
             UndirectedEdge[22, 45] -> 
             RGBColor[
              0.5103761866451392, 0.6112003415163002, 0.9552237117930512], 
             UndirectedEdge[116, 141] -> 
             RGBColor[
              0.8711050512917506, 0.8997058365513595, 0.9641224124477642], 
             UndirectedEdge[97, 224] -> 
             RGBColor[
              0.3024873769110219, 0.42919950086325687`, 0.9407596240173286], 
             UndirectedEdge[66, 151] -> 
             RGBColor[
              0.5589838315805221, 0.6524987120471719, 0.9586608699581859], 
             UndirectedEdge[165, 221] -> 
             RGBColor[
              0.7275384316474159, 0.7870778193906192, 0.9734778896995684], 
             UndirectedEdge[101, 332] -> 
             RGBColor[
              0.7763156081681702, 0.8232153078436594, 0.8972812497145743], 
             UndirectedEdge[58, 396] -> 
             RGBColor[
              0.6659658147230598, 0.7367968858965893, 0.9689164799681804], 
             UndirectedEdge[35, 387] -> 
             RGBColor[
              0.7323559181088062, 0.7864008749299258, 0.846750360776955], 
             UndirectedEdge[198, 266] -> 
             RGBColor[
              0.7154217192487593, 0.7758017293771269, 0.9604062614921902], 
             UndirectedEdge[188, 264] -> 
             RGBColor[
              0.5258212507697765, 0.6149097258770452, 0.9588298239298845], 
             UndirectedEdge[119, 151] -> 
             RGBColor[
              0.47894495536645, 0.5817239789449267, 0.9536139215098511], 
             UndirectedEdge[247, 400] -> 
             RGBColor[
              0.36537105885337307`, 0.48693361621132447`, 0.9447044603099866],
              UndirectedEdge[305, 361] -> 
             RGBColor[
              0.5255500898203462, 0.618978300443941, 0.9581251458081944], 
             UndirectedEdge[138, 210] -> 
             RGBColor[
              0.6113171395563151, 0.6897532923240579, 0.9654678193494042], 
             UndirectedEdge[197, 231] -> 
             RGBColor[
              0.8894504045815907, 0.9104634331336225, 0.7622173007877066], 
             UndirectedEdge[225, 261] -> 
             RGBColor[
              0.6002434792069409, 0.6859630821382979, 0.96193275812229], 
             UndirectedEdge[83, 286] -> 
             RGBColor[
              0.7070077008687949, 0.767234917385285, 0.9303133276892277], 
             UndirectedEdge[19, 238] -> 
             RGBColor[
              0.632396756433286, 0.7121865820981559, 0.9643819228607808], 
             UndirectedEdge[62, 117] -> 
             RGBColor[
              0.6022942789613643, 0.6867128222284025, 0.9627199260441432], 
             UndirectedEdge[65, 167] -> 
             RGBColor[
              0.6319414894518796, 0.7116292651931855, 0.9644744213796765], 
             UndirectedEdge[268, 371] -> 
             RGBColor[
              0.3141279685473946, 0.4393127624652974, 0.941500225721742], 
             UndirectedEdge[172, 192] -> 
             RGBColor[
              0.429908728531144, 0.5459646147303664, 0.9488416275582481], 
             UndirectedEdge[52, 353] -> 
             RGBColor[
              0.3076706338848735, 0.43685224752631524`, 0.9409740737583194], 
             UndirectedEdge[126, 298] -> 
             RGBColor[
              0.6403561110080496, 0.7099888361266699, 0.9352479770856028], 
             UndirectedEdge[146, 306] -> 
             RGBColor[
              0.6987903749306509, 0.7621443356113661, 0.9593704657488227], 
             UndirectedEdge[21, 132] -> 
             RGBColor[
              0.5567188550279831, 0.6510084722671516, 0.9582460940776152], 
             UndirectedEdge[89, 162] -> 
             RGBColor[
              0.5766216625343301, 0.6634681095303729, 0.9616079196231705], 
             UndirectedEdge[9, 18] -> 
             RGBColor[
              0.7118738351390574, 0.7726197522151935, 0.952036425704329], 
             UndirectedEdge[255, 360] -> 
             RGBColor[
              0.6146935769271995, 0.6921467213353505, 0.9659274442593582], 
             UndirectedEdge[124, 152] -> 
             RGBColor[
              0.6606705910358965, 0.7259974101285469, 0.8871177598102316], 
             UndirectedEdge[88, 389] -> 
             RGBColor[
              0.49114413683561886`, 0.5956782778156462, 0.9536623032126681], 
             UndirectedEdge[12, 167] -> 
             RGBColor[
              0.5298000349255136, 0.6269319948216638, 0.956923698662147], 
             UndirectedEdge[32, 303] -> 
             RGBColor[
              0.5377734865027131, 0.6356277686192116, 0.9567546452681344], 
             UndirectedEdge[49, 261] -> 
             RGBColor[
              0.49514478700029063`, 0.5971030300029923, 0.9546360664465574], 
             UndirectedEdge[283, 360] -> 
             RGBColor[
              0.6246139266526882, 0.7000569389257354, 0.966873656072176], 
             UndirectedEdge[282, 305] -> 
             RGBColor[
              0.3995512914673458, 0.5183626369011372, 0.947060279846919], 
             UndirectedEdge[32, 385] -> 
             RGBColor[
              0.6176664403471198, 0.7004884676866563, 0.9630441112522989], 
             UndirectedEdge[167, 216] -> 
             RGBColor[
              0.5285807593495676, 0.6258759196003516, 0.9568460075006109], 
             UndirectedEdge[252, 318] -> 
             RGBColor[
              0.7838223658169312, 0.8304159826072377, 0.9412099449737162], 
             UndirectedEdge[2, 217] -> 
             RGBColor[
              0.4297334891784035, 0.5460784516490411, 0.9487570697431493], 
             UndirectedEdge[305, 329] -> 
             RGBColor[
              0.3145011671687018, 0.4459574857318438, 0.941292545354544], 
             UndirectedEdge[87, 373] -> 
             RGBColor[
              0.6646115109274963, 0.7328316296828256, 0.9614440922383694], 
             UndirectedEdge[20, 241] -> 
             RGBColor[
              0.6936408009923196, 0.7550722417457463, 0.9082465207131626], 
             UndirectedEdge[59, 210] -> 
             RGBColor[
              0.7500422290251139, 0.8049238851241886, 0.975684935648318], 
             UndirectedEdge[290, 304] -> 
             RGBColor[
              0.5847096890224988, 0.6646314410266523, 0.9640607745393038], 
             UndirectedEdge[115, 312] -> 
             RGBColor[
              0.45137931078329707`, 0.5653656122556248, 0.9499874951032048], 
             UndirectedEdge[214, 389] -> 
             RGBColor[
              0.3652709366596363, 0.4908010591086539, 0.9444957189809131], 
             UndirectedEdge[144, 276] -> 
             RGBColor[
              0.6996132362978482, 0.7051239656017221, 0.6151035670949982], 
             UndirectedEdge[196, 286] -> 
             RGBColor[
              0.6373509200136753, 0.7052353813587641, 0.9259358718404356], 
             UndirectedEdge[124, 181] -> 
             RGBColor[
              0.8277882165002574, 0.8645851675099208, 0.8996197775190681], 
             UndirectedEdge[216, 341] -> 
             RGBColor[
              0.6888235756593972, 0.749679636062358, 0.8630920274186071], 
             UndirectedEdge[294, 340] -> 
             RGBColor[
              0.41057651533860273`, 0.5292969965012039, 0.9475885281114023], 
             UndirectedEdge[104, 235] -> 
             RGBColor[
              0.45017961754900115`, 0.5634287724466864, 0.9501590960321391], 
             UndirectedEdge[125, 318] -> 
             RGBColor[
              0.7711070597630769, 0.8200931243347089, 0.940208949503456], 
             UndirectedEdge[109, 232] -> 
             RGBColor[
              0.8215942961022931, 0.8612733259386376, 0.9826618711615225], 
             UndirectedEdge[182, 388] -> 
             RGBColor[
              0.8874995243730146, 0.913132046474954, 0.9891316909865182], 
             UndirectedEdge[97, 382] -> 
             RGBColor[
              0.4650191287585618, 0.5744179704318956, 0.9516196965827332], 
             UndirectedEdge[140, 147] -> 
             RGBColor[
              0.5924515773180196, 0.6689353201766817, 0.9650823876944292], 
             UndirectedEdge[59, 300] -> 
             RGBColor[
              0.47704920742494006`, 0.5826316719343058, 0.9529958078201766], 
             UndirectedEdge[205, 373] -> 
             RGBColor[
              0.4224446962346906, 0.5401102040087338, 0.9481973267771653], 
             UndirectedEdge[215, 259] -> 
             RGBColor[
              0.7919601484089991, 0.8031060688023501, 0.6490894901047799], 
             UndirectedEdge[136, 300] -> 
             RGBColor[
              0.29317713911499876`, 0.42470151043398896`, 0.9400358126206786],
              UndirectedEdge[152, 245] -> 
             RGBColor[
              0.35855979484065653`, 0.4849882053768493, 0.9440680909586374], 
             UndirectedEdge[44, 128] -> 
             RGBColor[
              0.6236451240519867, 0.700512473020316, 0.9662159206961469], 
             UndirectedEdge[241, 392] -> 
             RGBColor[
              0.41898114660678243`, 0.537322143411227, 0.9479180860646714], 
             UndirectedEdge[240, 342] -> 
             RGBColor[
              0.7449828804990297, 0.7987904826712806, 0.9356350101316182], 
             UndirectedEdge[123, 214] -> 
             RGBColor[
              0.5456113622408025, 0.6378551294836885, 0.9591043575143732], 
             UndirectedEdge[125, 274] -> 
             RGBColor[
              0.5506790854124697, 0.6461051152047574, 0.9577706212890769], 
             UndirectedEdge[298, 373] -> 
             RGBColor[
              0.678648779384549, 0.7433006015141779, 0.937682658246543], 
             UndirectedEdge[119, 350] -> 
             RGBColor[
              0.34485543041155453`, 0.47166909231324045`, 0.9432479189439353],
              UndirectedEdge[22, 179] -> 
             RGBColor[
              0.470646031497592, 0.5755527719976697, 0.9527373720439354], 
             UndirectedEdge[1, 183] -> 
             RGBColor[
              0.990615287725487, 0.9890305582580772, 0.7065793627413269], 
             UndirectedEdge[112, 260] -> 
             RGBColor[
              0.5087442239948883, 0.610951716364327, 0.9547757171447788], 
             UndirectedEdge[183, 270] -> 
             RGBColor[
              0.703810909959865, 0.7609426355477492, 0.7521417071440939], 
             UndirectedEdge[152, 181] -> 
             RGBColor[
              0.49945135745655583`, 0.6008602652791316, 0.9548990071335668], 
             UndirectedEdge[169, 276] -> 
             RGBColor[
              0.3818688905219082, 0.5051773725067362, 0.9455533259240227], 
             UndirectedEdge[349, 355] -> 
             RGBColor[
              0.7153082990046582, 0.7775235468176461, 0.972258904374826], 
             UndirectedEdge[171, 240] -> 
             RGBColor[
              0.6972171981638797, 0.7618754406790946, 0.9717136257841086], 
             UndirectedEdge[114, 132] -> 
             RGBColor[
              0.4561518421462525, 0.5656166666375232, 0.9513643905368618], 
             UndirectedEdge[17, 222] -> 
             RGBColor[
              0.5786870066787786, 0.6587794200801482, 0.9636453476720159], 
             UndirectedEdge[46, 259] -> 
             RGBColor[
              0.8001032870343436, 0.8431543020604473, 0.9253685115916228], 
             UndirectedEdge[13, 79] -> 
             RGBColor[
              0.609281530388537, 0.6889259704141333, 0.9649073025821253], 
             UndirectedEdge[146, 311] -> 
             RGBColor[
              0.41434814959756805`, 0.5333092742630459, 0.9476228755920427], 
             UndirectedEdge[44, 275] -> 
             RGBColor[
              0.6050796326889996, 0.6857088541543084, 0.9644451275563354], 
             UndirectedEdge[193, 195] -> 
             RGBColor[
              0.6517198689781893, 0.6977188363478062, 0.6567805362398277], 
             UndirectedEdge[86, 297] -> 
             RGBColor[
              0.8472111629942799, 0.8799616318348065, 0.9107655860895106], 
             UndirectedEdge[197, 392] -> 
             RGBColor[
              0.6113487765961946, 0.6927376827549487, 0.9641632379313139], 
             UndirectedEdge[217, 392] -> 
             RGBColor[
              0.411520981378513, 0.5308605232493067, 0.9474427309330913], 
             UndirectedEdge[101, 193] -> 
             RGBColor[
              0.6567693248468018, 0.7226718014011784, 0.8888345496008979], 
             UndirectedEdge[216, 340] -> 
             RGBColor[
              0.43315453285767824`, 0.5488529404720708, 0.9490271794227607], 
             UndirectedEdge[125, 190] -> 
             RGBColor[
              0.524710235374932, 0.6250224328609221, 0.9557262582870898], 
             UndirectedEdge[99, 276] -> 
             RGBColor[
              0.6553980894264502, 0.7279071991466448, 0.9682889543423803], 
             UndirectedEdge[27, 63] -> 
             RGBColor[
              0.6730112888225686, 0.7406331177526857, 0.969656312921655], 
             UndirectedEdge[184, 226] -> 
             RGBColor[
              0.40079411047753666`, 0.5213676098243666, 0.9468149923688012], 
             UndirectedEdge[107, 211] -> 
             RGBColor[
              0.4711661419869314, 0.5784987952275851, 0.952354936470466], 
             UndirectedEdge[216, 294] -> 
             RGBColor[
              0.36295767564594217`, 0.4887974286864713, 0.944348320034657], 
             UndirectedEdge[68, 284] -> 
             RGBColor[
              0.6533848076338882, 0.7276840601031723, 0.967088157225116], 
             UndirectedEdge[89, 359] -> 
             RGBColor[
              0.8676576806092289, 0.8968844324254294, 0.957284693360523], 
             UndirectedEdge[23, 267] -> 
             RGBColor[
              0.7032251210754715, 0.7665784429592644, 0.9723874380054705], 
             UndirectedEdge[140, 242] -> 
             RGBColor[
              0.7206026517724715, 0.7806993802604677, 0.9737404117552816], 
             UndirectedEdge[64, 214] -> 
             RGBColor[
              0.5022385036282951, 0.6039719226896632, 0.9547813563102867], 
             UndirectedEdge[296, 367] -> 
             RGBColor[
              0.9784279631196855, 0.9833935605495359, 0.9196700724217806], 
             UndirectedEdge[275, 346] -> 
             RGBColor[
              0.6081050598979282, 0.6883293271402893, 0.9646379051028081], 
             UndirectedEdge[301, 305] -> 
             RGBColor[
              0.5216844754280351, 0.6159584531009099, 0.9577398574917892], 
             UndirectedEdge[81, 119] -> 
             RGBColor[
              0.36972169719040016`, 0.49320700278216817`, 0.9448323754747071],
              UndirectedEdge[327, 355] -> 
             RGBColor[
              0.6263156099356421, 0.7066465085245053, 0.9643155525167367], 
             UndirectedEdge[317, 344] -> 
             RGBColor[
              0.3004683242524794, 0.4306139689213431, 0.9405151489572956], 
             UndirectedEdge[184, 190] -> 
             RGBColor[
              0.4731321022944421, 0.5831489808577643, 0.9516658387140667], 
             UndirectedEdge[10, 303] -> 
             RGBColor[
              0.4245293781308346, 0.5413758394139497, 0.9484793675881646], 
             UndirectedEdge[149, 268] -> 
             RGBColor[
              0.3201940708285833, 0.4445669153700973, 0.9418867523950558], 
             UndirectedEdge[38, 267] -> 
             RGBColor[
              0.7334704000885821, 0.7567569859196186, 0.6461722990125873], 
             UndirectedEdge[253, 366] -> 
             RGBColor[
              0.9545253419304975, 0.965363350591091, 0.9534600683130134], 
             UndirectedEdge[165, 355] -> 
             RGBColor[
              0.6990540758557784, 0.7648256241570699, 0.9706388353156971], 
             UndirectedEdge[339, 340] -> 
             RGBColor[
              0.5386130234414578, 0.6363093425267927, 0.9568207366912773], 
             UndirectedEdge[185, 318] -> 
             RGBColor[
              0.8585638786459225, 0.8896168287625648, 0.9481041692386496], 
             UndirectedEdge[36, 70] -> 
             RGBColor[
              0.5206025658737978, 0.6216876417114992, 0.9554028874970713], 
             UndirectedEdge[69, 131] -> 
             RGBColor[
              0.7337764823131594, 0.7892369946774086, 0.9172115794154994], 
             UndirectedEdge[283, 312] -> 
             RGBColor[
              0.6762019935729588, 0.7447217370142183, 0.9701658287445767], 
             UndirectedEdge[75, 330] -> 
             RGBColor[
              0.34155259275273103`, 0.47025742173511975`, 0.9429844070804732],
              UndirectedEdge[169, 222] -> 
             RGBColor[
              0.5953938452878081, 0.6755898387841053, 0.9646242213051093], 
             UndirectedEdge[90, 246] -> 
             RGBColor[
              0.616186236118349, 0.6926051773347044, 0.966406680108833], 
             UndirectedEdge[62, 362] -> 
             RGBColor[
              0.6682040595895453, 0.7402213513441402, 0.9679085854106754], 
             UndirectedEdge[158, 374] -> 
             RGBColor[
              0.9756867057445973, 0.9745283893332541, 0.6834000943052477], 
             UndirectedEdge[82, 172] -> 
             RGBColor[
              0.6702824072189045, 0.25617641726631096`, 0.42454289894286035`],
              UndirectedEdge[306, 346] -> 
             RGBColor[
              0.6714348623409399, 0.738450365534199, 0.9576273966761362], 
             UndirectedEdge[53, 188] -> 
             RGBColor[
              0.5937676846814034, 0.6775639322401982, 0.963020085378748], 
             UndirectedEdge[84, 190] -> 
             RGBColor[
              0.6879963862435781, 0.7543543812465567, 0.9710282314975371], 
             UndirectedEdge[78, 96] -> 
             RGBColor[
              0.8941142738358179, 0.9183047659355061, 0.9862365322827777], 
             UndirectedEdge[46, 199] -> 
             RGBColor[
              0.660853715433658, 0.7269220734663474, 0.9152857899535722], 
             UndirectedEdge[159, 265] -> 
             RGBColor[
              0.34321271539442383`, 0.47169533652716394`, 0.9430901886272129],
              UndirectedEdge[332, 356] -> 
             RGBColor[
              0.5485628784685619, 0.6443870830736567, 0.9576040257265309], 
             UndirectedEdge[199, 222] -> 
             RGBColor[
              0.6050099062911345, 0.6839187875079075, 0.9652369482090923], 
             UndirectedEdge[114, 300] -> 
             RGBColor[
              0.31623286901274883`, 0.448326749637865, 0.941371056673114], 
             UndirectedEdge[139, 213] -> 
             RGBColor[
              0.6178134921348918, 0.6952272054618149, 0.9659521498969581], 
             UndirectedEdge[106, 369] -> 
             RGBColor[
              0.33034163073421163`, 0.45769319369191247`, 0.9423745481503689],
              UndirectedEdge[109, 114] -> 
             RGBColor[
              0.5248242834655048, 0.6199591889604457, 0.957733781401299], 
             UndirectedEdge[58, 245] -> 
             RGBColor[
              0.6149746796398845, 0.6935391769724814, 0.9654164179161336], 
             UndirectedEdge[151, 317] -> 
             RGBColor[
              0.46483435409753804`, 0.5668928423475064, 0.9528103436423505], 
             UndirectedEdge[99, 218] -> 
             RGBColor[
              0.6113080384412676, 0.689718613013676, 0.9654795752809058], 
             UndirectedEdge[55, 57] -> 
             RGBColor[
              0.324692773108183, 0.45352220563881307`, 0.9419881804569717], 
             UndirectedEdge[247, 287] -> 
             RGBColor[
              0.38512467332345196`, 0.5029704903283252, 0.9462595372009452], 
             UndirectedEdge[44, 66] -> 
             RGBColor[
              0.41983657639365, 0.5380630736974604, 0.9479725932942638], 
             UndirectedEdge[116, 290] -> 
             RGBColor[
              0.8290436307886966, 0.8668409885721778, 0.9834711749819278], 
             UndirectedEdge[278, 367] -> 
             RGBColor[
              0.9891489929321535, 0.9897808439663531, 0.8294927988277284], 
             UndirectedEdge[102, 297] -> 
             RGBColor[
              0.8737727514316256, 0.9007117465976098, 0.9134129969927887], 
             UndirectedEdge[104, 187] -> 
             RGBColor[
              0.5106318421099966, 0.6135929589840585, 0.9546179555984202], 
             UndirectedEdge[136, 371] -> 
             RGBColor[
              0.3332466388812918, 0.45940769717993546`, 0.9425890057137194], 
             UndirectedEdge[80, 302] -> 
             RGBColor[
              0.6296687247289765, 0.6951107695327301, 0.8726852885577547], 
             UndirectedEdge[176, 373] -> 
             RGBColor[
              0.5773067854868534, 0.663865967577365, 0.961734345743795], 
             UndirectedEdge[112, 219] -> 
             RGBColor[
              0.4963047415033323, 0.6001772618567105, 0.9539830843202193], 
             UndirectedEdge[33, 179] -> 
             RGBColor[
              0.5789691575612841, 0.660519692442106, 0.9634427030281167], 
             UndirectedEdge[123, 334] -> 
             RGBColor[
              0.6699911803662932, 0.7415199533659967, 0.9681533772406746], 
             UndirectedEdge[94, 307] -> 
             RGBColor[
              0.7145779419709264, 0.775605222948646, 0.9734423445594234], 
             UndirectedEdge[73, 89] -> 
             RGBColor[
              0.8485817308045185, 0.882534435479198, 0.985304405679043], 
             UndirectedEdge[267, 311] -> 
             RGBColor[
              0.43906493278822084`, 0.5535393003776062, 0.9495234051292418], 
             UndirectedEdge[52, 391] -> 
             RGBColor[
              0.6658197704391711, 0.7130374255423582, 0.6624128221803396], 
             UndirectedEdge[105, 271] -> 
             RGBColor[
              0.7384368832841317, 0.7934928108591435, 0.9355666264388083], 
             UndirectedEdge[187, 377] -> 
             RGBColor[
              0.7344336068685718, 0.7056848071748755, 0.6113768597928537], 
             UndirectedEdge[58, 124] -> 
             RGBColor[
              0.9170854758351246, 0.9345483817241791, 0.9084660867677277], 
             UndirectedEdge[11, 54] -> 
             RGBColor[
              0.5307173080023323, 0.6258564375674087, 0.9577736415901055], 
             UndirectedEdge[115, 283] -> 
             RGBColor[
              0.673593285374912, 0.742480397676777, 0.9699945774992097], 
             UndirectedEdge[292, 362] -> 
             RGBColor[
              0.43500521357703725`, 0.5425060260673502, 0.9502736769999542], 
             UndirectedEdge[15, 154] -> 
             RGBColor[
              0.3911194010864072, 0.5114320079893296, 0.9464042496648759], 
             UndirectedEdge[158, 311] -> 
             RGBColor[
              0.6857847738826972, 0.741621487795191, 0.6808943631822353], 
             UndirectedEdge[123, 253] -> 
             RGBColor[
              0.8315963924059312, 0.8692280237737586, 0.9836213737786053], 
             UndirectedEdge[236, 376] -> 
             RGBColor[
              0.439645514004411, 0.555220579829748, 0.9492348012824657], 
             UndirectedEdge[206, 386] -> 
             RGBColor[
              0.6192091183803252, 0.700350847419515, 0.9641159315803162], 
             UndirectedEdge[74, 338] -> 
             RGBColor[
              0.391139435548934, 0.5095479623815121, 0.9465788049312422], 
             UndirectedEdge[293, 394] -> 
             RGBColor[
              0.3526769028118367, 0.4798927399842363, 0.9436932382805983], 
             UndirectedEdge[41, 381] -> 
             RGBColor[
              0.7478755331207808, 0.8030399801460949, 0.9756581041826067], 
             UndirectedEdge[59, 328] -> 
             RGBColor[
              0.6219813389474194, 0.7039914967543461, 0.9633837958761088], 
             UndirectedEdge[123, 196] -> 
             RGBColor[
              0.513806622892261, 0.6086411293112416, 0.9571388002791341], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.7638025255274212, 0.8111344467017013, 0.790824796576529], 
             UndirectedEdge[23, 38] -> 
             RGBColor[
              0.9399776157742699, 0.9210384305399995, 0.6650371374866823], 
             UndirectedEdge[61, 282] -> 
             RGBColor[
              0.6519160617711008, 0.725816604648839, 0.9674340753343591], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.44844033488536605`, 0.5575795373230009, 0.9509520987424855], 
             UndirectedEdge[3, 232] -> 
             RGBColor[
              0.6524876000094415, 0.7238405650997577, 0.9688150777722653], 
             UndirectedEdge[110, 362] -> 
             RGBColor[
              0.43715472954619305`, 0.5447653036381169, 0.9503960887544738], 
             UndirectedEdge[125, 252] -> 
             RGBColor[
              0.5766230738975053, 0.6671676138202716, 0.9598130270985801], 
             UndirectedEdge[49, 327] -> 
             RGBColor[
              0.4384849126543069, 0.5514846323099776, 0.9499153473927275], 
             UndirectedEdge[89, 291] -> 
             RGBColor[
              0.5509631076314168, 0.6412439589099368, 0.9599729791937262], 
             UndirectedEdge[34, 250] -> 
             RGBColor[
              0.5914717422397695, 0.6712649506197794, 0.9645176465226413], 
             UndirectedEdge[125, 226] -> 
             RGBColor[
              0.45237224355802663`, 0.5632410618275243, 0.9508754119418242], 
             UndirectedEdge[3, 14] -> 
             RGBColor[
              0.34365015054646364`, 0.47045058163391995`, 0.9431775109943087],
              UndirectedEdge[105, 345] -> 
             RGBColor[
              0.4017060697377315, 0.5210496006196113, 0.9471445640955567], 
             UndirectedEdge[88, 336] -> 
             RGBColor[
              0.4849949982888585, 0.5903522030711321, 0.9532704855419383], 
             UndirectedEdge[162, 357] -> 
             RGBColor[
              0.3352205038557752, 0.4624330897816785, 0.9426666033250022], 
             UndirectedEdge[279, 328] -> 
             RGBColor[
              0.6883283902781031, 0.755905138216622, 0.9699400249349601], 
             UndirectedEdge[312, 359] -> 
             RGBColor[
              0.7115309759862889, 0.7720314609857455, 0.9436963451855203], 
             UndirectedEdge[202, 289] -> 
             RGBColor[
              0.6409028428777601, 0.7165603165683359, 0.9668091423776324], 
             UndirectedEdge[27, 48] -> 
             RGBColor[
              0.6564616115214105, 0.7262986190853898, 0.9686017821183301], 
             UndirectedEdge[115, 193] -> 
             RGBColor[
              0.38676903879801316`, 0.5094216346548848, 0.9458655590391452], 
             UndirectedEdge[117, 385] -> 
             RGBColor[
              0.5592170438064319, 0.6530366144596182, 0.9584427606494217], 
             UndirectedEdge[179, 352] -> 
             RGBColor[
              0.504267558802271, 0.6018181646611568, 0.9560884516746295], 
             UndirectedEdge[8, 365] -> 
             RGBColor[
              0.7817517755937962, 0.829750599739747, 0.9787962111112176], 
             UndirectedEdge[105, 353] -> 
             RGBColor[
              0.38054082104524767`, 0.49880358228953603`, 0.9459392344936993],
              UndirectedEdge[231, 392] -> 
             RGBColor[
              0.7155022510073878, 0.7710019184709516, 0.7471458216705378], 
             UndirectedEdge[109, 132] -> 
             RGBColor[
              0.665656303866786, 0.7380399416123627, 0.9677852938295736], 
             UndirectedEdge[23, 158] -> 
             RGBColor[
              0.9499449621699478, 0.9546606303768492, 0.7037583960584639], 
             UndirectedEdge[105, 350] -> 
             RGBColor[
              0.4464339117777574, 0.5599351899932331, 0.9499892888319361], 
             UndirectedEdge[172, 351] -> 
             RGBColor[
              0.575263290749061, 0.6619485627138606, 0.9616665364582943], 
             UndirectedEdge[34, 375] -> 
             RGBColor[
              0.5251693952681782, 0.6189723240311502, 0.9580410648685853], 
             UndirectedEdge[32, 391] -> 
             RGBColor[
              0.7878434820129976, 0.81489380576546, 0.6712475284128391], 
             UndirectedEdge[140, 241] -> 
             RGBColor[
              0.6542435445567429, 0.725393609536142, 0.9689121721791006], 
             UndirectedEdge[89, 336] -> 
             RGBColor[
              0.5650761863952084, 0.6534679983911693, 0.9608722520928494], 
             UndirectedEdge[74, 118] -> 
             RGBColor[
              0.30787268794822187`, 0.43868141693352664`, 0.9409263815516682],
              UndirectedEdge[138, 328] -> 
             RGBColor[
              0.48325624947862056`, 0.5888209039542156, 0.9531666795771949], 
             UndirectedEdge[189, 207] -> 
             RGBColor[
              0.841372700548181, 0.8758197583160232, 0.9291909602619381], 
             UndirectedEdge[273, 281] -> 
             RGBColor[
              0.9412008745184459, 0.9534868072048157, 0.8981500357289433], 
             UndirectedEdge[49, 225] -> 
             RGBColor[
              0.4281811924163802, 0.5431196080435217, 0.9491042007918271], 
             UndirectedEdge[43, 159] -> 
             RGBColor[
              0.29343545431635226`, 0.42417221215815487`, 0.9400798446439863],
              UndirectedEdge[113, 368] -> 
             RGBColor[
              0.3485528038017599, 0.47632065270495094`, 0.9434304543384736], 
             UndirectedEdge[11, 83] -> 
             RGBColor[
              0.5728468912995617, 0.6623469651250433, 0.9604581013840772], 
             UndirectedEdge[151, 344] -> 
             RGBColor[
              0.5004509399398844, 0.6018004632567264, 0.9549312058614483], 
             UndirectedEdge[182, 377] -> 
             RGBColor[
              0.9074573328205588, 0.8429961070167635, 0.6273602962602708], 
             UndirectedEdge[198, 203] -> 
             RGBColor[
              0.8602344122497474, 0.8914132058463099, 0.9731424017752945], 
             UndirectedEdge[208, 395] -> 
             RGBColor[
              0.9647315668180487, 0.9729335979864652, 0.9318733763278624], 
             UndirectedEdge[305, 339] -> 
             RGBColor[
              0.44789794959716106`, 0.5576126319630497, 0.9508663058745421], 
             UndirectedEdge[9, 313] -> 
             RGBColor[
              0.6897614786419826, 0.7556065791248094, 0.9713752646991825], 
             UndirectedEdge[267, 317] -> 
             RGBColor[
              0.3807848218999583, 0.49900167317550337`, 0.9459584431347867], 
             UndirectedEdge[306, 350] -> 
             RGBColor[
              0.6734671653639879, 0.7402106442662433, 0.9577568932276699], 
             UndirectedEdge[111, 362] -> 
             RGBColor[
              0.5862062336779907, 0.6749476546464979, 0.9605674485407708], 
             UndirectedEdge[104, 261] -> 
             RGBColor[
              0.5771288228448841, 0.6671975628001777, 0.9601130877016927], 
             UndirectedEdge[243, 363] -> 
             RGBColor[
              0.4002890467667586, 0.5199695395241939, 0.9470266078912422], 
             UndirectedEdge[154, 369] -> 
             RGBColor[
              0.34071736637348643`, 0.46859874970842597`, 0.9429654309455002],
              UndirectedEdge[218, 282] -> 
             RGBColor[
              0.4292321245291122, 0.5449400335037665, 0.9489196850922358], 
             UndirectedEdge[7, 293] -> 
             RGBColor[
              0.632337112973273, 0.7042709849983415, 0.9505407032286493], 
             UndirectedEdge[24, 167] -> 
             RGBColor[
              0.7189336268806706, 0.7803556805078994, 0.9726202431768918], 
             UndirectedEdge[326, 363] -> 
             RGBColor[
              0.41255983373237853`, 0.5299315171755372, 0.9479926091905494], 
             UndirectedEdge[276, 282] -> 
             RGBColor[
              0.4733221755142949, 0.5831286196367353, 0.9517290641537104], 
             UndirectedEdge[337, 345] -> 
             RGBColor[
              0.622688568172015, 0.6968124116075015, 0.9651545186738473], 
             UndirectedEdge[107, 124] -> 
             RGBColor[
              0.7952515073905293, 0.8385412673536001, 0.896804805440668], 
             UndirectedEdge[128, 227] -> 
             RGBColor[
              0.7034740096955923, 0.7671348141669772, 0.9719992245698865], 
             UndirectedEdge[25, 365] -> 
             RGBColor[
              0.6011879243195137, 0.6861690136889258, 0.962390538212931], 
             UndirectedEdge[97, 363] -> 
             RGBColor[
              0.34105341489203544`, 0.46973485200933973`, 0.9429559028270069],
              UndirectedEdge[13, 373] -> 
             RGBColor[
              0.3832059500776753, 0.5063354662913744, 0.9456385221766008], 
             UndirectedEdge[64, 195] -> 
             RGBColor[
              0.8144083092698171, 0.8331678276324888, 0.6687050848732656], 
             UndirectedEdge[77, 96] -> 
             RGBColor[
              0.7806878979942787, 0.8291480770101459, 0.9752086256704422], 
             UndirectedEdge[6, 53] -> 
             RGBColor[
              0.37856749435784653`, 0.5023178690824219, 0.9453429638797588], 
             UndirectedEdge[216, 343] -> 
             RGBColor[
              0.39360720331292376`, 0.5153445090615585, 0.9463012808352838], 
             UndirectedEdge[26, 324] -> 
             RGBColor[
              0.6071435368709913, 0.6891494231169406, 0.9638723828524668], 
             UndirectedEdge[142, 281] -> 
             RGBColor[
              0.8398074987534483, 0.8736964190107568, 0.8881983009785432], 
             UndirectedEdge[100, 341] -> 
             RGBColor[
              0.9714048173039658, 0.9768786303539947, 0.874368195083032], 
             UndirectedEdge[115, 364] -> 
             RGBColor[
              0.36838094744991856`, 0.4915758796081714, 0.9447641469794961], 
             UndirectedEdge[150, 152] -> 
             RGBColor[
              0.4921720978269853, 0.5951736523320887, 0.95417347856224], 
             UndirectedEdge[10, 68] -> 
             RGBColor[
              0.45740665702851846`, 0.5680670955276252, 0.9510675874164312], 
             UndirectedEdge[190, 288] -> 
             RGBColor[
              0.7209217400237007, 0.7800761278922826, 0.9557226339375577], 
             UndirectedEdge[23, 146] -> 
             RGBColor[
              0.6785083378848187, 0.7463484168447041, 0.9704869084682712], 
             UndirectedEdge[188, 201] -> 
             RGBColor[
              0.5447650500785991, 0.6348208600568666, 0.9599086452756824], 
             UndirectedEdge[148, 382] -> 
             RGBColor[
              0.7410022370562348, 0.7971277027115857, 0.9754993992299233], 
             UndirectedEdge[14, 71] -> 
             RGBColor[
              0.3364117280128686, 0.46418102384901483`, 0.9427162851111537], 
             UndirectedEdge[228, 276] -> 
             RGBColor[
              0.5699917668827617, 0.6608320837729924, 0.9598706688597898], 
             UndirectedEdge[56, 174] -> 
             RGBColor[
              0.9332297630139372, 0.9495465349432788, 0.9917751186480293], 
             UndirectedEdge[16, 182] -> 
             RGBColor[
              0.866015737947293, 0.896001458340931, 0.9870825482584304], 
             UndirectedEdge[104, 192] -> 
             RGBColor[
              0.4853294036522456, 0.5930512995821935, 0.9526260549571401], 
             UndirectedEdge[145, 395] -> 
             RGBColor[
              0.7981116677149422, 0.8430062262950919, 0.9732163423845692], 
             UndirectedEdge[219, 251] -> 
             RGBColor[
              0.34011728566029775`, 0.4675243251727572, 0.9429475033278787], 
             UndirectedEdge[150, 179] -> 
             RGBColor[
              0.47369778436552346`, 0.5779368245322787, 0.9530415422495588], 
             UndirectedEdge[73, 207] -> 
             RGBColor[
              0.9582722770771516, 0.968039266794047, 0.94060446869513], 
             UndirectedEdge[265, 325] -> 
             RGBColor[
              0.42635570251673016`, 0.5426567735301039, 0.9486788889519973], 
             UndirectedEdge[39, 314] -> 
             RGBColor[
              0.5313901498728519, 0.6270010016472253, 0.9575787415970238], 
             UndirectedEdge[20, 263] -> 
             RGBColor[
              0.8089241848254443, 0.8500969442416191, 0.9169262585601953], 
             UndirectedEdge[66, 146] -> 
             RGBColor[
              0.45021751619228967`, 0.5643775167606084, 0.9499084399134229], 
             UndirectedEdge[7, 21] -> 
             RGBColor[
              0.7359914278417921, 0.7923368564366163, 0.9576191269220067], 
             UndirectedEdge[107, 167] -> 
             RGBColor[
              0.6365606951177891, 0.7153793444456146, 0.9648380621704047], 
             UndirectedEdge[120, 195] -> 
             RGBColor[
              0.9811160311637419, 0.9634890910590832, 0.6421796745006748], 
             UndirectedEdge[365, 388] -> 
             RGBColor[
              0.7992775516835309, 0.8437251778691826, 0.9804678352801015], 
             UndirectedEdge[134, 342] -> 
             RGBColor[
              0.7484565267342045, 0.8016105451709752, 0.9359084682876366], 
             UndirectedEdge[227, 311] -> 
             RGBColor[
              0.46379609544253403`, 0.5736171723465588, 0.9514703328466232], 
             UndirectedEdge[78, 377] -> 
             RGBColor[
              0.8916198767371557, 0.830367749432151, 0.6258497055607719], 
             UndirectedEdge[21, 370] -> 
             RGBColor[
              0.7441226475479448, 0.7984011067798147, 0.9438550929212384], 
             UndirectedEdge[2, 230] -> 
             RGBColor[
              0.37549253069686345`, 0.49617726476020185`, 0.9454078137946389],
              UndirectedEdge[24, 203] -> 
             RGBColor[
              0.7680780904443761, 0.8187477089556229, 0.9775185040237986], 
             UndirectedEdge[54, 206] -> 
             RGBColor[
              0.5394387645282188, 0.6326697056909559, 0.9586429148699607], 
             UndirectedEdge[66, 130] -> 
             RGBColor[
              0.4833992116072292, 0.5914797399587948, 0.9524753583489131], 
             UndirectedEdge[101, 356] -> 
             RGBColor[
              0.7610184449832194, 0.8107963816407681, 0.8960770009932999], 
             UndirectedEdge[222, 383] -> 
             RGBColor[
              0.6639031011556767, 0.7349140894540875, 0.9689937215153669], 
             UndirectedEdge[31, 247] -> 
             RGBColor[
              0.4439802754363147, 0.550752119538207, 0.9508928657944442], 
             UndirectedEdge[46, 333] -> 
             RGBColor[
              0.8341938626171178, 0.8702115955630876, 0.9284754407870244], 
             UndirectedEdge[287, 385] -> 
             RGBColor[
              0.5712343264243807, 0.6627927858612817, 0.9593888051578633], 
             UndirectedEdge[42, 330] -> 
             RGBColor[
              0.4047282463762726, 0.5247402809035806, 0.9470753093947182], 
             UndirectedEdge[151, 227] -> 
             RGBColor[
              0.6054986002416767, 0.6902660394798392, 0.9623214277563208], 
             UndirectedEdge[36, 382] -> 
             RGBColor[
              0.5680977300266858, 0.6602463556035756, 0.9591418807997055], 
             UndirectedEdge[218, 361] -> 
             RGBColor[
              0.5552309228821126, 0.6455556970465703, 0.9599845510535112], 
             UndirectedEdge[196, 334] -> 
             RGBColor[
              0.44690773043950804`, 0.5557776901282362, 0.9508822036243076], 
             UndirectedEdge[34, 265] -> 
             RGBColor[
              0.33106060760488654`, 0.46050013433589254`, 0.9423403864952837],
              UndirectedEdge[372, 392] -> 
             RGBColor[
              0.40821624685573554`, 0.5279981283064636, 0.9472321561715618], 
             UndirectedEdge[127, 210] -> 
             RGBColor[
              0.9228262008132562, 0.9232007500055397, 0.6867015693387994], 
             UndirectedEdge[33, 157] -> 
             RGBColor[
              0.9028091258501056, 0.9251495571927786, 0.9840062510599938], 
             UndirectedEdge[139, 308] -> 
             RGBColor[
              0.5942722706757522, 0.6748369826501022, 0.9644521240822665], 
             UndirectedEdge[38, 146] -> 
             RGBColor[
              0.7087536168979293, 0.7365269598050582, 0.6442717694753881], 
             UndirectedEdge[55, 68] -> 
             RGBColor[
              0.4162251098171261, 0.5302656214584898, 0.9485216018192297], 
             UndirectedEdge[35, 392] -> 
             RGBColor[
              0.4538438246502457, 0.5670576940355432, 0.9502668113611901], 
             UndirectedEdge[51, 126] -> 
             RGBColor[
              0.40093067803845406`, 0.5204201027071398, 0.9470835224206362], 
             UndirectedEdge[130, 243] -> 
             RGBColor[
              0.5032277444926369, 0.6075819789874892, 0.9540350779118785], 
             UndirectedEdge[12, 203] -> 
             RGBColor[
              0.5789444984892191, 0.6653240232693873, 0.961821959509054], 
             UndirectedEdge[182, 395] -> 
             RGBColor[
              0.9119116022805334, 0.9323947931181888, 0.9844295702911526], 
             UndirectedEdge[99, 382] -> 
             RGBColor[
              0.7098064740084553, 0.7722530480437162, 0.9725239195016397], 
             UndirectedEdge[17, 31] -> 
             RGBColor[
              0.4514115198788142, 0.5585628286153851, 0.9513160641719035], 
             UndirectedEdge[77, 78] -> 
             RGBColor[
              0.735159276216705, 0.7929464920547207, 0.974392144493976], 
             UndirectedEdge[243, 344] -> 
             RGBColor[
              0.4144463346208711, 0.5323220776497031, 0.9479253948360964], 
             UndirectedEdge[305, 313] -> 
             RGBColor[
              0.6074034401196882, 0.6836944863156188, 0.9660787303158243], 
             UndirectedEdge[189, 280] -> 
             RGBColor[
              0.7744042127108288, 0.8239459555376856, 0.9780810367324275], 
             UndirectedEdge[104, 208] -> 
             RGBColor[
              0.7364755325994989, 0.7914430636942229, 0.918045198102547], 
             UndirectedEdge[191, 335] -> 
             RGBColor[
              0.6342652359469145, 0.7100073624846445, 0.9667562298073223], 
             UndirectedEdge[225, 355] -> 
             RGBColor[
              0.6160118896977154, 0.6982814842580494, 0.9635044059158363], 
             UndirectedEdge[308, 348] -> 
             RGBColor[
              0.541094798476489, 0.6329096506119521, 0.9592539746187507], 
             UndirectedEdge[132, 149] -> 
             RGBColor[
              0.5032004914615118, 0.6063678419405285, 0.9543622888677432], 
             UndirectedEdge[128, 224] -> 
             RGBColor[
              0.5457030235586741, 0.6257813486722721, 0.9615139369204815], 
             UndirectedEdge[192, 225] -> 
             RGBColor[
              0.5084440600143024, 0.6118168189203137, 0.9544457253777374], 
             UndirectedEdge[84, 252] -> 
             RGBColor[
              0.7399092247661514, 0.7964995622059061, 0.9751150003090274], 
             UndirectedEdge[30, 211] -> 
             RGBColor[
              0.38280063994783586`, 0.505984407028387, 0.9456126961735292], 
             UndirectedEdge[138, 242] -> 
             RGBColor[
              0.4463911021273933, 0.5588921165785269, 0.950264520136222], 
             UndirectedEdge[27, 41] -> 
             RGBColor[
              0.9085521928707134, 0.9298926987845779, 0.9902322411366528], 
             UndirectedEdge[102, 139] -> 
             RGBColor[
              0.8136105599506473, 0.854702706785835, 0.9819546710654892], 
             UndirectedEdge[203, 329] -> 
             RGBColor[
              0.5497869310685934, 0.6400692038715912, 0.9599640650960362], 
             UndirectedEdge[195, 312] -> 
             RGBColor[
              0.7163301409634734, 0.7536628139485462, 0.6609024723038872], 
             UndirectedEdge[51, 87] -> 
             RGBColor[
              0.7200672847943503, 0.7797415823301838, 0.9652879875561526], 
             UndirectedEdge[83, 366] -> 
             RGBColor[
              0.7063923532719469, 0.766775992155095, 0.9313549506623344], 
             UndirectedEdge[8, 302] -> 
             RGBColor[
              0.9251041040316221, 0.9406516793538174, 0.8966147113901534], 
             UndirectedEdge[146, 344] -> 
             RGBColor[
              0.391684624551652, 0.513679267970163, 0.9461787758166853], 
             UndirectedEdge[67, 320] -> 
             RGBColor[
              0.7241542699293155, 0.7823785430375783, 0.9473433573517529], 
             UndirectedEdge[90, 166] -> 
             RGBColor[
              0.3087621137680994, 0.4399370424026885, 0.9409652876161552], 
             UndirectedEdge[12, 341] -> 
             RGBColor[
              0.6900428512353431, 0.7507357112836701, 0.8631697185801435], 
             UndirectedEdge[3, 13] -> 
             RGBColor[
              0.38937984030379313`, 0.5116829796964922, 0.9460319170024524], 
             UndirectedEdge[153, 341] -> 
             RGBColor[
              0.969808600676547, 0.9102953472332169, 0.5285085880760192], 
             UndirectedEdge[192, 351] -> 
             RGBColor[
              0.6289627976234914, 0.707637925645294, 0.9653154671879611], 
             UndirectedEdge[12, 150] -> 
             RGBColor[
              0.5199923539893427, 0.6192701599331911, 0.9559461606844188], 
             UndirectedEdge[99, 393] -> 
             RGBColor[
              0.7624105186294645, 0.8146752058691031, 0.9768593948506556], 
             UndirectedEdge[4, 190] -> 
             RGBColor[
              0.5343655185316764, 0.6328610266931165, 0.9564863575456564], 
             UndirectedEdge[373, 390] -> 
             RGBColor[
              0.4845214136462816, 0.5905068797277137, 0.9530842333663142], 
             UndirectedEdge[23, 308] -> 
             RGBColor[
              0.6153493148031951, 0.6916432455162035, 0.9664624713668415], 
             UndirectedEdge[37, 187] -> 
             RGBColor[
              0.5310446251182854, 0.6301649758155824, 0.9562249246513207], 
             UndirectedEdge[17, 292] -> 
             RGBColor[
              0.27199590867096773`, 0.4032153239228172, 0.9388011366656996], 
             UndirectedEdge[309, 385] -> 
             RGBColor[
              0.7051542097990486, 0.7695671508896498, 0.9712632104840413], 
             UndirectedEdge[140, 380] -> 
             RGBColor[
              0.6057694501235997, 0.6829332488972526, 0.9658408208486797], 
             UndirectedEdge[119, 354] -> 
             RGBColor[
              0.6159376816446656, 0.6896240742538864, 0.964238578975716], 
             UndirectedEdge[36, 305] -> 
             RGBColor[
              0.43991846139773166`, 0.551134523970906, 0.9502381313336548], 
             UndirectedEdge[91, 351] -> 
             RGBColor[
              0.7237759347899277, 0.7841385282495141, 0.9731028791753462], 
             UndirectedEdge[130, 275] -> 
             RGBColor[
              0.6686422679025787, 0.7391255204156427, 0.9689478926109847], 
             UndirectedEdge[46, 102] -> 
             RGBColor[
              0.8726326960837556, 0.9002403044131796, 0.932306664475657], 
             UndirectedEdge[111, 271] -> 
             RGBColor[
              0.7717993047808146, 0.8205779275901115, 0.9381930384696038], 
             UndirectedEdge[104, 351] -> 
             RGBColor[
              0.6306839658701626, 0.7090352475656876, 0.9654509638571862], 
             UndirectedEdge[174, 203] -> 
             RGBColor[
              0.8493766505548138, 0.8831385927966614, 0.9853881046778012], 
             UndirectedEdge[294, 313] -> 
             RGBColor[
              0.6279216567522488, 0.7023356850937623, 0.9673543017444557], 
             UndirectedEdge[206, 266] -> 
             RGBColor[
              0.6066946638173669, 0.6901910494355521, 0.9631307478751625], 
             UndirectedEdge[167, 358] -> 
             RGBColor[
              0.7992433255459395, 0.8439580730744892, 0.9803955253434871], 
             UndirectedEdge[315, 322] -> 
             RGBColor[
              0.4324140787775149, 0.5489570740987133, 0.9487740206243149], 
             UndirectedEdge[176, 347] -> 
             RGBColor[
              0.5040430797552576, 0.5937974246378178, 0.9573081157404958], 
             UndirectedEdge[92, 186] -> 
             RGBColor[
              0.8968427751688905, 0.9205821010437989, 0.9900228585882473], 
             UndirectedEdge[149, 210] -> 
             RGBColor[
              0.636274539928182, 0.7113701381307531, 0.9670580828321369], 
             UndirectedEdge[171, 374] -> 
             RGBColor[
              0.9234164616945242, 0.941113228726829, 0.9697439082963804], 
             UndirectedEdge[228, 282] -> 
             RGBColor[
              0.5964289494414131, 0.6824696507792141, 0.9619036385338817], 
             UndirectedEdge[164, 210] -> 
             RGBColor[
              0.8163892803557976, 0.8568375265864644, 0.9822411647071694], 
             UndirectedEdge[196, 214] -> 
             RGBColor[
              0.32252791231401734`, 0.45211286624592795`, 0.9418331838980061],
              UndirectedEdge[204, 307] -> 
             RGBColor[
              0.3991494010323815, 0.5187014984043354, 0.9469680969020593], 
             UndirectedEdge[127, 255] -> 
             RGBColor[
              0.9305478554296174, 0.9293577877978951, 0.6874380676493105], 
             UndirectedEdge[68, 334] -> 
             RGBColor[
              0.5749284331035335, 0.6657918280810273, 0.9596796187676049], 
             UndirectedEdge[16, 269] -> 
             RGBColor[
              0.5932322723337884, 0.6744797780347522, 0.9641356121207978], 
             UndirectedEdge[68, 337] -> 
             RGBColor[
              0.742479739421228, 0.7981767902608965, 0.9734832741775717], 
             UndirectedEdge[23, 374] -> 
             RGBColor[
              0.9354740803358086, 0.9507276465360501, 0.9708939747263492], 
             UndirectedEdge[22, 116] -> 
             RGBColor[
              0.7131446846263787, 0.7758333148212558, 0.9720432555137251], 
             UndirectedEdge[192, 322] -> 
             RGBColor[
              0.44816226942735243`, 0.5617749144050206, 0.9500047270431822], 
             UndirectedEdge[70, 95] -> 
             RGBColor[
              0.5567760454714733, 0.6508943364266384, 0.9583603759094197], 
             UndirectedEdge[71, 273] -> 
             RGBColor[
              0.6367594906241509, 0.7108015614657213, 0.9675440979783626], 
             UndirectedEdge[135, 215] -> 
             RGBColor[
              0.8109462551088907, 0.8183636364154673, 0.6506909470012228], 
             UndirectedEdge[161, 283] -> 
             RGBColor[
              0.9463776519679026, 0.956068629484004, 0.8077113636441916], 
             UndirectedEdge[18, 384] -> 
             RGBColor[
              0.8855101318790697, 0.9109970708850407, 0.9674754479232663], 
             UndirectedEdge[71, 303] -> 
             RGBColor[
              0.43132426421565206`, 0.5472612282197138, 0.9489123317210073], 
             UndirectedEdge[32, 353] -> 
             RGBColor[0.4296943454587, 0.538708627749417, 0.949808779990819], 
             UndirectedEdge[188, 281] -> 
             RGBColor[
              0.8872721087335496, 0.9107761330716084, 0.8929291297193607], 
             UndirectedEdge[54, 198] -> 
             RGBColor[
              0.6481658199596112, 0.7182803856325307, 0.9559184284869884], 
             UndirectedEdge[271, 385] -> 
             RGBColor[
              0.8107198955374367, 0.8521754165189698, 0.9412570099447868], 
             UndirectedEdge[150, 206] -> 
             RGBColor[
              0.6925552123184786, 0.759748662568539, 0.9699910893336318], 
             UndirectedEdge[317, 346] -> 
             RGBColor[
              0.3287125261195945, 0.4550776769837759, 0.9423148445249012], 
             UndirectedEdge[146, 243] -> 
             RGBColor[
              0.4700460490776973, 0.5804797557893029, 0.9514681594763883], 
             UndirectedEdge[91, 316] -> 
             RGBColor[
              0.5944515481051178, 0.6811685989149745, 0.9615399244137341], 
             UndirectedEdge[196, 386] -> 
             RGBColor[
              0.3980207243754723, 0.5160890162709264, 0.9470336394279428], 
             UndirectedEdge[151, 306] -> 
             RGBColor[
              0.8075566903188833, 0.8502655308979294, 0.9681228957935857], 
             UndirectedEdge[27, 376] -> 
             RGBColor[
              0.6814887310664067, 0.7479758521356621, 0.9701964880451246], 
             UndirectedEdge[280, 387] -> 
             RGBColor[
              0.923055177518449, 0.9382687407132498, 0.8638872896587027], 
             UndirectedEdge[308, 354] -> 
             RGBColor[
              0.6298843575933026, 0.7031530653767855, 0.9650741908661751], 
             UndirectedEdge[327, 349] -> 
             RGBColor[
              0.6428800141679001, 0.7195867470048801, 0.9659665375274498], 
             UndirectedEdge[60, 108] -> 
             RGBColor[
              0.37072978434132986`, 0.4955292386008747, 0.9448435519281211], 
             UndirectedEdge[353, 391] -> 
             RGBColor[
              0.6230008749644305, 0.6718915260281662, 0.659833035160218], 
             UndirectedEdge[140, 195] -> 
             RGBColor[
              0.9432988409337577, 0.9345688883230671, 0.6813630646511031], 
             UndirectedEdge[17, 18] -> 
             RGBColor[
              0.6215637396209475, 0.6923495433138667, 0.9462870334390732], 
             UndirectedEdge[87, 205] -> 
             RGBColor[
              0.7032886346140874, 0.7661199182442695, 0.9639671107517416], 
             UndirectedEdge[221, 256] -> 
             RGBColor[
              0.8466962916642127, 0.8810650540935474, 0.9833308754192657], 
             UndirectedEdge[194, 316] -> 
             RGBColor[
              0.5952138768197843, 0.6817641359007849, 0.9616159062156452], 
             UndirectedEdge[16, 37] -> 
             RGBColor[
              0.6898235247925151, 0.7561178378490954, 0.9708496768718586], 
             UndirectedEdge[252, 288] -> 
             RGBColor[
              0.772834578546274, 0.8222213088516321, 0.959809402749048], 
             UndirectedEdge[60, 353] -> 
             RGBColor[
              0.29034181433985784`, 0.42184289500821764`, 0.9398698967001845],
              UndirectedEdge[206, 286] -> 
             RGBColor[
              0.8585393140185282, 0.8894972125073526, 0.9430181639928089], 
             UndirectedEdge[220, 396] -> 
             RGBColor[
              0.41357389299116765`, 0.5317304027098806, 0.9478244926599684], 
             UndirectedEdge[133, 320] -> 
             RGBColor[
              0.49262519644493286`, 0.5989743528430168, 0.95320040649115], 
             UndirectedEdge[28, 231] -> 
             RGBColor[
              0.9938426023184536, 0.9902740795737733, 0.6464755829247195], 
             UndirectedEdge[239, 269] -> 
             RGBColor[
              0.3175262815086445, 0.44867159660811373`, 0.9414818645010993], 
             UndirectedEdge[212, 239] -> 
             RGBColor[
              0.3284030193649627, 0.45809248025851645`, 0.9421749206193822], 
             UndirectedEdge[77, 182] -> 
             RGBColor[
              0.7509967323001081, 0.8055748496393333, 0.975902735193475], 
             UndirectedEdge[280, 336] -> 
             RGBColor[
              0.6077982448304894, 0.6870990269276807, 0.9650623915794259], 
             UndirectedEdge[199, 400] -> 
             RGBColor[
              0.3991252029082284, 0.5198836927162617, 0.9467192592245224], 
             UndirectedEdge[73, 336] -> 
             RGBColor[
              0.647416488972503, 0.7186895393979337, 0.9688412150733152], 
             UndirectedEdge[305, 340] -> 
             RGBColor[
              0.39005829870604203`, 0.5106557977230604, 0.9463129566827708], 
             UndirectedEdge[259, 350] -> 
             RGBColor[
              0.5056109865856748, 0.6079778052191401, 0.9546479249335831], 
             UndirectedEdge[247, 393] -> 
             RGBColor[
              0.46474323667339346`, 0.5673242514480594, 0.9527216944217454], 
             UndirectedEdge[30, 216] -> 
             RGBColor[
              0.40515012689414376`, 0.5253424093034029, 0.9470367857188726], 
             UndirectedEdge[291, 387] -> 
             RGBColor[
              0.6650547984873612, 0.7285687766142417, 0.842334686667275], 
             UndirectedEdge[45, 338] -> 
             RGBColor[
              0.4371906921407567, 0.5518394102990556, 0.9494251220563779], 
             UndirectedEdge[219, 248] -> 
             RGBColor[
              0.5097300869243861, 0.6110765620744409, 0.9550399766904254], 
             UndirectedEdge[158, 354] -> 
             RGBColor[
              0.9644800049600555, 0.9661704502374312, 0.7023701155577975], 
             UndirectedEdge[191, 327] -> 
             RGBColor[
              0.48513288073811245`, 0.5918887576691219, 0.9528877146698491], 
             UndirectedEdge[165, 192] -> 
             RGBColor[
              0.5914862461723654, 0.6783609588193341, 0.9615801547775982], 
             UndirectedEdge[143, 354] -> 
             RGBColor[
              0.665790074975021, 0.734252793099001, 0.967362071427559], 
             UndirectedEdge[115, 161] -> 
             RGBColor[
              0.7215549691782408, 0.7767125047254104, 0.7875330300028197], 
             UndirectedEdge[296, 330] -> 
             RGBColor[
              0.6599259018641292, 0.7271498939103627, 0.9374544588576146], 
             UndirectedEdge[45, 262] -> 
             RGBColor[
              0.5547967237911509, 0.6459020027433509, 0.9596511358022447], 
             UndirectedEdge[37, 208] -> 
             RGBColor[
              0.7568883156077878, 0.8080150805257468, 0.9196521671554474], 
             UndirectedEdge[306, 348] -> 
             RGBColor[
              0.8557598574802854, 0.887922211442056, 0.9729273370120259], 
             UndirectedEdge[189, 263] -> 
             RGBColor[
              0.6641256590908473, 0.7373672416259182, 0.967275120401194], 
             UndirectedEdge[2, 50] -> 
             RGBColor[
              0.4587702094065797, 0.5712285992826939, 0.9506072638799252], 
             UndirectedEdge[241, 331] -> 
             RGBColor[
              0.40693516669532936`, 0.5268885210604808, 0.9471505268765554], 
             UndirectedEdge[135, 213] -> 
             RGBColor[
              0.5103025012297453, 0.6108541156605922, 0.9553385430644403], 
             UndirectedEdge[49, 349] -> 
             RGBColor[
              0.5274776017233231, 0.6223616706031185, 0.9578586992508169], 
             UndirectedEdge[256, 319] -> 
             RGBColor[
              0.655649738715023, 0.7255372874209471, 0.9677017023952152], 
             UndirectedEdge[64, 332] -> 
             RGBColor[
              0.6070021986237721, 0.6917114941187497, 0.962286122967567], 
             UndirectedEdge[213, 350] -> 
             RGBColor[
              0.3823433278193312, 0.5055883062478521, 0.9455835566490862], 
             UndirectedEdge[333, 345] -> 
             RGBColor[
              0.494973720128423, 0.5961495093481586, 0.9549101293926052], 
             UndirectedEdge[53, 201] -> 
             RGBColor[
              0.35450979301463836`, 0.48118084431975183`, 0.9438209928660564],
              UndirectedEdge[9, 384] -> 
             RGBColor[
              0.6376955986463465, 0.7141605914475457, 0.9663906168516894], 
             UndirectedEdge[24, 33] -> 
             RGBColor[
              0.8143973191402603, 0.855276713529254, 0.9820438659777215], 
             UndirectedEdge[20, 359] -> 
             RGBColor[
              0.9778969323921498, 0.9826161675698708, 0.9034912860667981], 
             UndirectedEdge[35, 291] -> 
             RGBColor[
              0.4029859066570548, 0.5230071216631241, 0.947026189798555], 
             UndirectedEdge[316, 351] -> 
             RGBColor[
              0.6449929731565986, 0.7206519442942487, 0.9665774213263951], 
             UndirectedEdge[195, 263] -> 
             RGBColor[
              0.8049003504017127, 0.8255681000129738, 0.6678750436342329], 
             UndirectedEdge[67, 200] -> 
             RGBColor[
              0.9739675667649672, 0.9801056344342856, 0.9289502985076381], 
             UndirectedEdge[232, 277] -> 
             RGBColor[
              0.8600958712024533, 0.8913510490296914, 0.9864993483498306], 
             UndirectedEdge[88, 120] -> 
             RGBColor[
              0.7948194256982024, 0.8391704048232498, 0.9374225301694509], 
             UndirectedEdge[247, 271] -> 
             RGBColor[
              0.624610242436508, 0.6923531209860132, 0.9281277419878687], 
             UndirectedEdge[202, 269] -> 
             RGBColor[
              0.3938606001300785, 0.5155639886484835, 0.946317427056403], 
             UndirectedEdge[207, 291] -> 
             RGBColor[
              0.66065365390405, 0.7267487902247858, 0.9152730422098132], 
             UndirectedEdge[72, 397] -> 
             RGBColor[
              0.7258494571159766, 0.7818111941183694, 0.8751897620467026], 
             UndirectedEdge[200, 298] -> 
             RGBColor[
              0.977693372613154, 0.982884334335416, 0.9226434810524538], 
             UndirectedEdge[233, 389] -> 
             RGBColor[
              0.47132236976974307`, 0.579586074351138, 0.9521018610997171], 
             UndirectedEdge[44, 311] -> 
             RGBColor[
              0.38396720979892845`, 0.5069948311998977, 0.9456870289728836], 
             UndirectedEdge[137, 258] -> 
             RGBColor[
              0.6932850854159288, 0.7586776843285093, 0.9714103944486345], 
             UndirectedEdge[46, 287] -> 
             RGBColor[
              0.7436476227171395, 0.7973210504690467, 0.9209241148926601], 
             UndirectedEdge[84, 274] -> 
             RGBColor[
              0.7139652362811157, 0.775437063590392, 0.9730725944995242], 
             UndirectedEdge[270, 357] -> 
             RGBColor[
              0.3486757511090212, 0.47408734867204955`, 0.943523959781971], 
             UndirectedEdge[44, 344] -> 
             RGBColor[
              0.3613036847530124, 0.48736482490701494`, 0.9442429291975261], 
             UndirectedEdge[44, 383] -> 
             RGBColor[
              0.42019687961755464`, 0.538360126853195, 0.9479997025038006], 
             UndirectedEdge[193, 364] -> 
             RGBColor[
              0.30637938366268147`, 0.4378732413448727, 0.9408134621608034], 
             UndirectedEdge[43, 375] -> 
             RGBColor[
              0.5049496592529747, 0.5977200994738632, 0.9568895808149384], 
             UndirectedEdge[184, 252] -> 
             RGBColor[
              0.5250449408170155, 0.6252941618171137, 0.9557526075255569], 
             UndirectedEdge[16, 78] -> 
             RGBColor[
              0.8501782818638899, 0.8833731007563184, 0.9855719575589315], 
             UndirectedEdge[345, 353] -> 
             RGBColor[
              0.28601698710261675`, 0.41795236634219834`, 0.9395996163400553],
              UndirectedEdge[167, 203] -> 
             RGBColor[
              0.7207702890978229, 0.7817904949910885, 0.9728033045021132], 
             UndirectedEdge[329, 340] -> 
             RGBColor[
              0.4052162410129986, 0.5246541962955867, 0.9472469761712792], 
             UndirectedEdge[193, 380] -> 
             RGBColor[
              0.3141904781680316, 0.4460831969219917, 0.9412582924374043], 
             UndirectedEdge[115, 253] -> 
             RGBColor[
              0.6875366572890331, 0.7535984639583493, 0.9713245087597736], 
             UndirectedEdge[113, 270] -> 
             RGBColor[
              0.37501370642384535`, 0.49923975659256514`, 0.9451165196550955],
              UndirectedEdge[121, 202] -> 
             RGBColor[
              0.5720426904485977, 0.6626951625482174, 0.9599646682548092], 
             UndirectedEdge[17, 111] -> 
             RGBColor[
              0.4231969287719213, 0.5356569525019649, 0.9490949082065162], 
             UndirectedEdge[73, 280] -> 
             RGBColor[
              0.8913037892397994, 0.9161654640157093, 0.9894945451656195], 
             UndirectedEdge[127, 242] -> 
             RGBColor[
              0.7579001633843343, 0.7923395742600086, 0.6714982701256174], 
             UndirectedEdge[19, 211] -> 
             RGBColor[
              0.5001044353201781, 0.6017315856303457, 0.9548112520933737], 
             UndirectedEdge[213, 345] -> 
             RGBColor[
              0.3376154857793054, 0.4667027168742303, 0.9427388319127068], 
             UndirectedEdge[102, 350] -> 
             RGBColor[
              0.5781403956350868, 0.6650638075718724, 0.9615860778176172], 
             UndirectedEdge[81, 227] -> 
             RGBColor[
              0.4962753420656268, 0.6017490633170808, 0.9535398817211767], 
             UndirectedEdge[144, 218] -> 
             RGBColor[
              0.6555231853126655, 0.6669353794687533, 0.6122941880335238], 
             UndirectedEdge[130, 354] -> 
             RGBColor[
              0.7262250760898659, 0.7849604599034724, 0.9716655464030952], 
             UndirectedEdge[104, 327] -> 
             RGBColor[
              0.5204689484989004, 0.6215791651071632, 0.9553923686478628], 
             UndirectedEdge[10, 253] -> 
             RGBColor[
              0.6471757238781632, 0.718639852037351, 0.9687527457726051], 
             UndirectedEdge[40, 41] -> 
             RGBColor[
              0.8427231262258958, 0.8775492205481343, 0.9848288590942034], 
             UndirectedEdge[5, 113] -> 
             RGBColor[
              0.6479016949357714, 0.7175019512343822, 0.9478795933121977], 
             UndirectedEdge[271, 337] -> 
             RGBColor[
              0.9594193817184151, 0.9692556218470336, 0.9535765810170989], 
             UndirectedEdge[325, 376] -> 
             RGBColor[
              0.45917836655620575`, 0.5710861154060354, 0.9507703200806505], 
             UndirectedEdge[52, 337] -> 
             RGBColor[
              0.6443422149542717, 0.7157122927916184, 0.9665289760921114], 
             UndirectedEdge[246, 260] -> 
             RGBColor[
              0.6576608411238036, 0.7285283956161701, 0.9690494052652274], 
             UndirectedEdge[22, 290] -> 
             RGBColor[
              0.7618059040882303, 0.8143143654481239, 0.9767695467567058], 
             UndirectedEdge[24, 107] -> 
             RGBColor[
              0.6838684964643422, 0.7523365584101489, 0.9695532616920902], 
             UndirectedEdge[314, 369] -> 
             RGBColor[
              0.3715774141963506, 0.4962634129781785, 0.9448975621529534], 
             UndirectedEdge[187, 208] -> 
             RGBColor[
              0.7600568028105787, 0.8105874011756943, 0.9199016020746023], 
             UndirectedEdge[9, 174] -> 
             RGBColor[
              0.6964489251772167, 0.7609389674661047, 0.9720131193196672], 
             UndirectedEdge[6, 303] -> 
             RGBColor[
              0.4173162907982047, 0.5351282257067363, 0.9480197560416121], 
             UndirectedEdge[100, 198] -> 
             RGBColor[
              0.9506261241460607, 0.9626976247472097, 0.9684612724382169], 
             UndirectedEdge[101, 123] -> 
             RGBColor[
              0.862830623750937, 0.8920039994798865, 0.9050820994384222], 
             UndirectedEdge[210, 394] -> 
             RGBColor[
              0.6296702736665765, 0.7056498546350244, 0.9666372648258708], 
             UndirectedEdge[213, 227] -> 
             RGBColor[
              0.45711448323096016`, 0.5678298956764879, 0.9510445864248195], 
             UndirectedEdge[32, 46] -> 
             RGBColor[
              0.7900797366398786, 0.8350167322944213, 0.9245794209870957], 
             UndirectedEdge[303, 391] -> 
             RGBColor[
              0.7310800160084436, 0.7688106668979607, 0.6667789004375333], 
             UndirectedEdge[248, 251] -> 
             RGBColor[
              0.4622441923352746, 0.5684567611922824, 0.9520687702234782], 
             UndirectedEdge[239, 388] -> 
             RGBColor[
              0.5975487072701133, 0.6759654272399405, 0.9651192591199407], 
             UndirectedEdge[205, 277] -> 
             RGBColor[
              0.6362268576538203, 0.7129682013437852, 0.9662749921805822], 
             UndirectedEdge[308, 378] -> 
             RGBColor[
              0.6447226141206368, 0.7142194127994561, 0.9399568930025092], 
             UndirectedEdge[119, 130] -> 
             RGBColor[
              0.4033603353931571, 0.5207050068565495, 0.9474284099005783], 
             UndirectedEdge[28, 254] -> 
             RGBColor[
              0.6727327026767111, 0.7352967259449591, 0.8456810710291058], 
             UndirectedEdge[217, 314] -> 
             RGBColor[
              0.37299600107400144`, 0.49749212163135004`, 0.9449879532543902],
              UndirectedEdge[229, 307] -> 
             RGBColor[
              0.4204075395487067, 0.5374694374450706, 0.9483096407883955], 
             UndirectedEdge[114, 155] -> 
             RGBColor[
              0.36739377424733477`, 0.49263975433019885`, 0.9446309843148497],
              UndirectedEdge[226, 288] -> 
             RGBColor[
              0.6485837482067953, 0.7182947568588849, 0.9508717875922923], 
             UndirectedEdge[217, 231] -> 
             RGBColor[
              0.6896226093639093, 0.7485862736279805, 0.745496793789484], 
             UndirectedEdge[151, 346] -> 
             RGBColor[
              0.5286951418069996, 0.6262641713191592, 0.9567309014290538], 
             UndirectedEdge[114, 180] -> 
             RGBColor[
              0.5270706136771568, 0.6217140391945302, 0.957957674603647], 
             UndirectedEdge[215, 345] -> 
             RGBColor[
              0.6382592396584508, 0.6742122376291054, 0.6380912358494892], 
             UndirectedEdge[190, 252] -> 
             RGBColor[
              0.5374255414287863, 0.635345291133451, 0.9567272537573499], 
             UndirectedEdge[275, 311] -> 
             RGBColor[
              0.6025243830767291, 0.6834956253707394, 0.96428230931056], 
             UndirectedEdge[75, 320] -> 
             RGBColor[
              0.4089574761848078, 0.5278551108218956, 0.9474962936263596], 
             UndirectedEdge[169, 393] -> 
             RGBColor[
              0.48888131972492244`, 0.5919453792291945, 0.9541237664322981], 
             UndirectedEdge[80, 182] -> 
             RGBColor[
              0.5745383689806343, 0.6536165585244311, 0.9635306439852357], 
             UndirectedEdge[239, 362] -> 
             RGBColor[
              0.4549083253507505, 0.5634254584716949, 0.9514071297714519], 
             UndirectedEdge[171, 342] -> 
             RGBColor[
              0.9333827818137406, 0.9485460939533891, 0.9528735279671372], 
             UndirectedEdge[107, 157] -> 
             RGBColor[
              0.7722803031741876, 0.8222094020736734, 0.9715156467743624], 
             UndirectedEdge[116, 286] -> 
             RGBColor[
              0.88218053919436, 0.9079659172946785, 0.9453745003785256], 
             UndirectedEdge[37, 117] -> 
             RGBColor[
              0.5027571486706928, 0.6071999280991349, 0.9539980308849257], 
             UndirectedEdge[111, 222] -> 
             RGBColor[
              0.7184448245805858, 0.7791935176070683, 0.9732874457762917], 
             UndirectedEdge[57, 72] -> 
             RGBColor[
              0.4122257032791558, 0.5312690809405686, 0.9475434033535597], 
             UndirectedEdge[8, 323] -> 
             RGBColor[
              0.7602521225106966, 0.8129549073478142, 0.9766533266175754], 
             UndirectedEdge[115, 356] -> 
             RGBColor[
              0.4910181589344306, 0.5975462148944743, 0.9531080104315471], 
             UndirectedEdge[129, 391] -> 
             RGBColor[
              0.7293940854723096, 0.767441952538422, 0.6666461778099618], 
             UndirectedEdge[271, 303] -> 
             RGBColor[
              0.73082694169303, 0.7873147174515251, 0.9349675439606222], 
             UndirectedEdge[141, 196] -> 
             RGBColor[
              0.6262754321110661, 0.6969753006154451, 0.9446837839096742], 
             UndirectedEdge[8, 117] -> 
             RGBColor[
              0.6686625458837001, 0.7388811207871828, 0.9692497365838224], 
             UndirectedEdge[278, 330] -> 
             RGBColor[
              0.6706469316765973, 0.73353717732718, 0.8472771852635624], 
             UndirectedEdge[95, 276] -> 
             RGBColor[
              0.5498628250423561, 0.6451072014216435, 0.9578644040527945], 
             UndirectedEdge[114, 268] -> 
             RGBColor[
              0.27314542151332405`, 0.403815740067092, 0.9388888540641744], 
             UndirectedEdge[95, 148] -> 
             RGBColor[
              0.7895716845609425, 0.8363980026056441, 0.97943274364384], 
             UndirectedEdge[236, 366] -> 
             RGBColor[
              0.7178877695651474, 0.7767327439718428, 0.9320874284235396], 
             UndirectedEdge[108, 378] -> 
             RGBColor[
              0.6970533069045598, 0.7595456286717939, 0.943291358472486], 
             UndirectedEdge[33, 107] -> 
             RGBColor[
              0.7320243873773787, 0.7903003774669692, 0.9742616849712346], 
             UndirectedEdge[309, 362] -> 
             RGBColor[
              0.6894851060466889, 0.7568462665784044, 0.9700296812388374], 
             UndirectedEdge[178, 278] -> 
             RGBColor[
              0.9672667744101182, 0.9734997514043335, 0.8682636255039057], 
             UndirectedEdge[21, 232] -> 
             RGBColor[
              0.7126568472634902, 0.7742418565934266, 0.973122671409564], 
             UndirectedEdge[20, 140] -> 
             RGBColor[
              0.9473226753574893, 0.9590977325517123, 0.9304142795770655], 
             UndirectedEdge[33, 150] -> 
             RGBColor[
              0.7572818368575363, 0.810657664676247, 0.9763511284783079], 
             UndirectedEdge[38, 213] -> 
             RGBColor[
              0.6691358152754453, 0.7022120112882704, 0.6417473581886499], 
             UndirectedEdge[86, 262] -> 
             RGBColor[
              0.7206338633691329, 0.781683918174962, 0.9727897068604483], 
             UndirectedEdge[17, 310] -> 
             RGBColor[
              0.611049603836896, 0.6845081180614384, 0.9640847227956739], 
             UndirectedEdge[222, 223] -> 
             RGBColor[
              0.5854779358285167, 0.6659171171862996, 0.9640320810408142], 
             UndirectedEdge[19, 124] -> 
             RGBColor[
              0.824189800723776, 0.8617740577563606, 0.8992611210635757], 
             UndirectedEdge[184, 274] -> 
             RGBColor[
              0.4991009523319797, 0.6042316632015996, 0.9537102017160537], 
             UndirectedEdge[195, 360] -> 
             RGBColor[
              0.6647420740432028, 0.7089980158600633, 0.6576102996314865], 
             UndirectedEdge[186, 378] -> 
             RGBColor[
              0.9191918133606198, 0.9375573131738975, 0.9628472999271127], 
             UndirectedEdge[31, 169] -> 
             RGBColor[
              0.46811835848784367`, 0.5753732473193421, 0.9522949378049969], 
             UndirectedEdge[4, 84] -> 
             RGBColor[
              0.7368492018690416, 0.7940152977655719, 0.9748741040973338], 
             UndirectedEdge[81, 383] -> 
             RGBColor[
              0.45012087662837685`, 0.564278789040148, 0.9499064331325786], 
             UndirectedEdge[327, 335] -> 
             RGBColor[
              0.7030196803076858, 0.7668283135272618, 0.9718917008068337], 
             UndirectedEdge[11, 214] -> 
             RGBColor[
              0.5349948497929837, 0.6295614292709693, 0.9580462027705241], 
             UndirectedEdge[15, 35] -> 
             RGBColor[
              0.47694763084203706`, 0.586246598820304, 0.951966211098075], 
             UndirectedEdge[151, 354] -> 
             RGBColor[
              0.8018096960631588, 0.8459794319918494, 0.977851058012368], 
             UndirectedEdge[91, 192] -> 
             RGBColor[
              0.5784213725720107, 0.6681545802660198, 0.9602779702753002], 
             UndirectedEdge[44, 130] -> 
             RGBColor[
              0.45008509462477814`, 0.5626247262448012, 0.9503526122733083], 
             UndirectedEdge[195, 356] -> 
             RGBColor[
              0.7559689891146069, 0.7858434165873958, 0.6640229876322297], 
             UndirectedEdge[226, 315] -> 
             RGBColor[
              0.39647428668915063`, 0.5178278325782457, 0.9464839688527547], 
             UndirectedEdge[65, 206] -> 
             RGBColor[
              0.6626785571724116, 0.7356412961068319, 0.9675380050358302], 
             UndirectedEdge[287, 400] -> 
             RGBColor[
              0.48191911019170997`, 0.5902826697189609, 0.9523575841636102], 
             UndirectedEdge[247, 319] -> 
             RGBColor[
              0.32109806122120543`, 0.448826801139929, 0.9418170477155383], 
             UndirectedEdge[55, 72] -> 
             RGBColor[
              0.37321857151169846`, 0.4953509762396716, 0.9451359695856858], 
             UndirectedEdge[313, 329] -> 
             RGBColor[
              0.6225613824266447, 0.6976928848881453, 0.9670127498043326], 
             UndirectedEdge[5, 357] -> 
             RGBColor[
              0.6215637396209474, 0.6923495433138667, 0.9462870334390732], 
             UndirectedEdge[39, 328] -> 
             RGBColor[
              0.6547199083291102, 0.7296499366841454, 0.966590245543405], 
             UndirectedEdge[310, 384] -> 
             RGBColor[
              0.8749959960950183, 0.9031556456326124, 0.9852731372798671], 
             UndirectedEdge[66, 344] -> 
             RGBColor[
              0.39461780173546346`, 0.5162198386210086, 0.9463656752731309], 
             UndirectedEdge[271, 391] -> 
             RGBColor[
              0.9808969372033145, 0.9665807545977735, 0.6494604271053269], 
             UndirectedEdge[203, 211] -> 
             RGBColor[
              0.5553757359669652, 0.644909945773059, 0.9603201788021744], 
             UndirectedEdge[100, 203] -> 
             RGBColor[
              0.8603064645578418, 0.8914669423397117, 0.9730204360119425], 
             UndirectedEdge[323, 377] -> 
             RGBColor[
              0.7977357070479756, 0.7567935460190593, 0.6165535560602118], 
             UndirectedEdge[351, 395] -> 
             RGBColor[
              0.8589400000887124, 0.89052578185793, 0.9792791420825016], 
             UndirectedEdge[179, 209] -> 
             RGBColor[
              0.4359240568173628, 0.5474182589354946, 0.9499667714843351], 
             UndirectedEdge[283, 356] -> 
             RGBColor[
              0.7158408417240925, 0.7769023396530679, 0.973286344072919], 
             UndirectedEdge[77, 80] -> 
             RGBColor[
              0.44527453705569187`, 0.5518315120144583, 0.9509921466734013], 
             UndirectedEdge[200, 398] -> 
             RGBColor[
              0.7885996651581926, 0.8341771631070611, 0.9384413241911846], 
             UndirectedEdge[280, 368] -> 
             RGBColor[
              0.6063380656007715, 0.6858342930696412, 0.964969350250094], 
             UndirectedEdge[3, 390] -> 
             RGBColor[
              0.49069530387239946`, 0.5958543931328315, 0.9534776281921657], 
             UndirectedEdge[64, 380] -> 
             RGBColor[
              0.47687891845965924`, 0.5815321882066744, 0.9531828410708423], 
             UndirectedEdge[139, 186] -> 
             RGBColor[
              0.8687414699157352, 0.8981748830245435, 0.9873425310068701], 
             UndirectedEdge[160, 245] -> 
             RGBColor[
              0.4616991230940613, 0.572006364953923, 0.9512799395994131], 
             UndirectedEdge[64, 360] -> 
             RGBColor[
              0.5004781203674171, 0.6024471671885259, 0.9546691862455494], 
             UndirectedEdge[72, 337] -> 
             RGBColor[
              0.6994732011158004, 0.7632621450420782, 0.9700976419440278], 
             UndirectedEdge[11, 141] -> 
             RGBColor[
              0.8387423695900325, 0.8744238636404864, 0.9608968027821922], 
             UndirectedEdge[62, 223] -> 
             RGBColor[
              0.511985683833214, 0.6080683463057587, 0.956822778445219], 
             UndirectedEdge[351, 399] -> 
             RGBColor[
              0.879948032583443, 0.8933188008949593, 0.6883083994104083], 
             UndirectedEdge[205, 232] -> 
             RGBColor[
              0.6849908334699149, 0.7517813402560839, 0.9709447014597861], 
             UndirectedEdge[175, 379] -> 
             RGBColor[
              0.7545452946330424, 0.8071714068185208, 0.952956046346795], 
             UndirectedEdge[144, 339] -> 
             RGBColor[
              0.774397076986315, 0.7660115276698563, 0.6209425627967134], 
             UndirectedEdge[66, 275] -> 
             RGBColor[
              0.6383937496714507, 0.714563867868302, 0.9665678736319402], 
             UndirectedEdge[311, 346] -> 
             RGBColor[
              0.386992637007857, 0.5096153041858787, 0.9458798065193563], 
             UndirectedEdge[81, 326] -> 
             RGBColor[
              0.4818598932554998, 0.5900459525644512, 0.9524050447853145], 
             UndirectedEdge[145, 335] -> 
             RGBColor[
              0.752406365305178, 0.8067648404229484, 0.9758874963182248], 
             UndirectedEdge[24, 56] -> 
             RGBColor[
              0.8519312029034996, 0.8851556511022403, 0.9839055179940266], 
             UndirectedEdge[310, 319] -> 
             RGBColor[
              0.6561397986304869, 0.7259027733035007, 0.9668721587864312], 
             UndirectedEdge[131, 303] -> 
             RGBColor[
              0.4812939431712959, 0.5897751309683357, 0.9523083687257009], 
             UndirectedEdge[146, 317] -> 
             RGBColor[
              0.3560680387093056, 0.478771647060943, 0.9440579135975875], 
             UndirectedEdge[159, 321] -> 
             RGBColor[
              0.4180743901106471, 0.5349884352771254, 0.9482881141121939], 
             UndirectedEdge[339, 361] -> 
             RGBColor[
              0.6741048145557621, 0.7446318452476733, 0.9686329258167009], 
             UndirectedEdge[60, 297] -> 
             RGBColor[
              0.6518672608689065, 0.7186224417376521, 0.8957468702135929], 
             UndirectedEdge[1, 368] -> 
             RGBColor[
              0.6742558664914649, 0.738100661191768, 0.9003466997423127], 
             UndirectedEdge[15, 106] -> 
             RGBColor[
              0.38074366544713245`, 0.5005264519728161, 0.9458133668697446], 
             UndirectedEdge[144, 282] -> 
             RGBColor[
              0.7260504188564998, 0.7267615326079437, 0.6171365367690903], 
             UndirectedEdge[333, 391] -> 
             RGBColor[
              0.8319576079902369, 0.8500886690341263, 0.6751435482127679], 
             UndirectedEdge[85, 238] -> 
             RGBColor[
              0.6964281606051279, 0.7622084016938948, 0.9707639748211372], 
             UndirectedEdge[130, 135] -> 
             RGBColor[
              0.5831019982671688, 0.6722712873755664, 0.9604298727866688], 
             UndirectedEdge[194, 256] -> 
             RGBColor[
              0.8062195720702652, 0.8494443331122928, 0.9792965342865915], 
             UndirectedEdge[129, 271] -> 
             RGBColor[
              0.7291410111568959, 0.7859460030919865, 0.9348348213330506], 
             UndirectedEdge[12, 168] -> 
             RGBColor[
              0.38103942778799677`, 0.5044589335766314, 0.9455004732920831], 
             UndirectedEdge[32, 271] -> 
             RGBColor[
              0.7875904076975839, 0.8333978563190243, 0.9394361719359279], 
             UndirectedEdge[227, 363] -> 
             RGBColor[
              0.4269752825425055, 0.5416346279281667, 0.9491274461264115], 
             UndirectedEdge[351, 355] -> 
             RGBColor[
              0.7365306273069043, 0.7941025909830297, 0.9743741477260601], 
             UndirectedEdge[70, 285] -> 
             RGBColor[
              0.4303244862844644, 0.5469464250450611, 0.9486963412024145], 
             UndirectedEdge[19, 107] -> 
             RGBColor[
              0.6304338580347074, 0.7105930127506247, 0.9642273963085111], 
             UndirectedEdge[88, 359] -> 
             RGBColor[
              0.787576492502879, 0.8337686371053922, 0.9496829268096119], 
             UndirectedEdge[128, 130] -> 
             RGBColor[
              0.6872077592655659, 0.7539291392816505, 0.9707186857507961], 
             UndirectedEdge[72, 297] -> 
             RGBColor[
              0.7243270665754507, 0.7811816465062096, 0.9004197131236442], 
             UndirectedEdge[125, 184] -> 
             RGBColor[
              0.5123296347631612, 0.614971303544585, 0.9547516120552968], 
             UndirectedEdge[41, 63] -> 
             RGBColor[
              0.6448494803071746, 0.7182038301654169, 0.9678776866502286], 
             UndirectedEdge[67, 133] -> 
             RGBColor[
              0.7345493010402426, 0.7908176975842438, 0.9481616922790586], 
             UndirectedEdge[272, 308] -> 
             RGBColor[
              0.47861339936939196`, 0.5840052856015597, 0.953090285229269], 
             UndirectedEdge[199, 287] -> 
             RGBColor[
              0.4188788173783073, 0.5359205668332625, 0.9482743361154811], 
             UndirectedEdge[60, 333] -> 
             RGBColor[
              0.49929854736566415`, 0.6000400380141778, 0.9551804097527343], 
             UndirectedEdge[86, 325] -> 
             RGBColor[
              0.5993064834430176, 0.684600167555607, 0.9622707349465689], 
             UndirectedEdge[77, 377] -> 
             RGBColor[
              0.7781935008956165, 0.7412110605067908, 0.6148217989484364], 
             UndirectedEdge[62, 319] -> 
             RGBColor[
              0.5502849494770667, 0.6423253044416696, 0.959223481067178], 
             UndirectedEdge[52, 199] -> 
             RGBColor[
              0.34328721972721987`, 0.4717598684355352, 0.9430949359774171], 
             UndirectedEdge[57, 376] -> 
             RGBColor[
              0.3949816828111732, 0.5165350141195938, 0.9463888614535079], 
             UndirectedEdge[11, 161] -> 
             RGBColor[
              0.85499819184732, 0.8840483643281005, 0.7987717402778023], 
             UndirectedEdge[155, 300] -> 
             RGBColor[
              0.36830682151511235`, 0.4934305899824578, 0.9446891628793765], 
             UndirectedEdge[81, 275] -> 
             RGBColor[
              0.6350036296998218, 0.7116275163412613, 0.9663518581851134], 
             UndirectedEdge[100, 266] -> 
             RGBColor[
              0.7154937715568536, 0.7758554658705287, 0.9602842957288382], 
             UndirectedEdge[56, 266] -> 
             RGBColor[
              0.7089551721196637, 0.7709789891162464, 0.9713524390361438], 
             UndirectedEdge[82, 257] -> 
             RGBColor[
              0.7688909480034561, 0.33732399829522264`, 0.432127270264808], 
             UndirectedEdge[32, 259] -> 
             RGBColor[
              0.6045605029017321, 0.6898484772527369, 0.9620123638479672], 
             UndirectedEdge[261, 355] -> 
             RGBColor[
              0.6829754842816258, 0.7522649062175198, 0.9690362715705666], 
             UndirectedEdge[74, 179] -> 
             RGBColor[
              0.2890640036249959, 0.4211549738992246, 0.9397731394233478], 
             UndirectedEdge[100, 174] -> 
             RGBColor[
              0.939768362451127, 0.9544230116975612, 0.9807069753407236], 
             UndirectedEdge[208, 388] -> 
             RGBColor[
              0.9403194889105299, 0.9536708513432304, 0.9365754970232281], 
             UndirectedEdge[249, 299] -> 
             RGBColor[
              0.7974836623132329, 0.8418723462124698, 0.9804088332312684], 
             UndirectedEdge[58, 181] -> 
             RGBColor[
              0.7558662422557838, 0.8094112368747637, 0.9762473340910631], 
             UndirectedEdge[271, 345] -> 
             RGBColor[
              0.6439130493415007, 0.7126415949118057, 0.9292270082851642], 
             UndirectedEdge[20, 89] -> 
             RGBColor[
              0.8764806800101449, 0.9030446296168751, 0.9235420354048522], 
             UndirectedEdge[174, 358] -> 
             RGBColor[
              0.9278496870029305, 0.9453061708800621, 0.992980325519175], 
             UndirectedEdge[185, 274] -> 
             RGBColor[
              0.6381359042953153, 0.7156288196326132, 0.9656658410242702], 
             UndirectedEdge[106, 314] -> 
             RGBColor[
              0.31911487895082946`, 0.4479691455700985, 0.9416591894541586], 
             UndirectedEdge[73, 387] -> 
             RGBColor[
              0.9626734216604627, 0.9698592531835029, 0.867666113152592], 
             UndirectedEdge[191, 261] -> 
             RGBColor[
              0.5417927550840962, 0.6375071553621365, 0.957608433723679], 
             UndirectedEdge[135, 227] -> 
             RGBColor[
              0.5993682486971953, 0.6854769622608929, 0.9617104116057591], 
             UndirectedEdge[102, 345] -> 
             RGBColor[
              0.5334125535950609, 0.6261782181982505, 0.9587413530812378], 
             UndirectedEdge[72, 108] -> 
             RGBColor[
              0.44318959004787406`, 0.5580884433694322, 0.9495163948381724], 
             UndirectedEdge[7, 273] -> 
             RGBColor[
              0.9237047407451542, 0.9414897419360484, 0.9748557592307293], 
             UndirectedEdge[111, 385] -> 
             RGBColor[
              0.6018753374303505, 0.6876685389577433, 0.9618009777859748], 
             UndirectedEdge[25, 187] -> 
             RGBColor[
              0.5163861710570103, 0.6182645824528092, 0.9550709574519307], 
             UndirectedEdge[290, 338] -> 
             RGBColor[
              0.6886204095838478, 0.7549534342308792, 0.9709709570200324], 
             UndirectedEdge[133, 200] -> 
             RGBColor[
              0.7424384932805845, 0.796701444239724, 0.9348073476470352], 
             UndirectedEdge[64, 88] -> 
             RGBColor[
              0.6281117038042777, 0.7088491413966553, 0.9639479405420417], 
             UndirectedEdge[23, 92] -> 
             RGBColor[
              0.9167565978868717, 0.9364608427327994, 0.9919222567763678], 
             UndirectedEdge[38, 350] -> 
             RGBColor[
              0.6834304073312663, 0.7145932684599354, 0.6426581969542353], 
             UndirectedEdge[135, 224] -> 
             RGBColor[
              0.4415972625602771, 0.5441234967661881, 0.9512251239563541], 
             UndirectedEdge[329, 358] -> 
             RGBColor[0.62825996751671, 0.7022367819549918, 0.96755628593741],
              UndirectedEdge[4, 185] -> 
             RGBColor[
              0.6610198698832411, 0.7342070538077929, 0.9674673506220799], 
             UndirectedEdge[111, 199] -> 
             RGBColor[
              0.44951982838427706`, 0.5607963199297241, 0.9506865087435926], 
             UndirectedEdge[138, 264] -> 
             RGBColor[
              0.3135609397129725, 0.4422100383775019, 0.9413400289381397], 
             UndirectedEdge[275, 344] -> 
             RGBColor[
              0.579860858030813, 0.6638656190778565, 0.9628382095352026], 
             UndirectedEdge[300, 371] -> 
             RGBColor[
              0.35721541604681945`, 0.4838237720360704, 0.9439824283306817], 
             UndirectedEdge[69, 273] -> 
             RGBColor[
              0.9389277860485215, 0.9525468267067929, 0.9358209942399822], 
             UndirectedEdge[65, 174] -> 
             RGBColor[
              0.7605478509088704, 0.8129773629987582, 0.9770592215553645], 
             UndirectedEdge[217, 254] -> 
             RGBColor[
              0.3685127097221668, 0.4936089199991662, 0.9447022818938702], 
             UndirectedEdge[102, 378] -> 
             RGBColor[
              0.864060903395532, 0.894085136935189, 0.9574594399857318], 
             UndirectedEdge[246, 326] -> 
             RGBColor[
              0.7100944350466212, 0.7722051384668606, 0.972870808090462], 
             UndirectedEdge[120, 242] -> 
             RGBColor[
              0.7584198420024557, 0.8096195829964838, 0.9345570216048533], 
             UndirectedEdge[25, 117] -> 
             RGBColor[
              0.48809869460941774`, 0.5952995347363617, 0.9528440636855358], 
             UndirectedEdge[44, 227] -> 
             RGBColor[
              0.4663513450548046, 0.5758304011301277, 0.9516331510923985], 
             UndirectedEdge[118, 206] -> 
             RGBColor[
              0.5330512173454525, 0.6271371333686999, 0.958235906011761], 
             UndirectedEdge[151, 158] -> 
             RGBColor[
              0.8274872786818399, 0.8582703549284714, 0.6917454580919328], 
             UndirectedEdge[151, 308] -> 
             RGBColor[
              0.49289163131508706`, 0.5952529700678257, 0.9544495334003104], 
             UndirectedEdge[298, 390] -> 
             RGBColor[
              0.7794026204827312, 0.8269855657946019, 0.9450925833490641], 
             UndirectedEdge[62, 111] -> 
             RGBColor[
              0.6449525725852829, 0.7213447467265275, 0.9660781431806965], 
             UndirectedEdge[131, 201] -> 
             RGBColor[
              0.3935425121281335, 0.5142217021606895, 0.946520136460782], 
             UndirectedEdge[291, 368] -> 
             RGBColor[
              0.34833768656968356`, 0.4761343289706329, 0.9434167472586664], 
             UndirectedEdge[35, 73] -> 
             RGBColor[
              0.7006045298301564, 0.7642975982323854, 0.9723576162838719], 
             UndirectedEdge[273, 293] -> 
             RGBColor[
              0.6005128455432758, 0.6794065393060205, 0.9652344938054589], 
             UndirectedEdge[4, 274] -> 
             RGBColor[
              0.560334368569214, 0.6539437090369519, 0.9585307205476433], 
             UndirectedEdge[10, 337] -> 
             RGBColor[
              0.6531218181562197, 0.7233167438094583, 0.9670884046446413], 
             UndirectedEdge[27, 265] -> 
             RGBColor[
              0.6486660670269311, 0.7195465102597306, 0.9681050569164713], 
             UndirectedEdge[262, 325] -> 
             RGBColor[
              0.6134206522918207, 0.6956262635319482, 0.9636775033930105], 
             UndirectedEdge[46, 337] -> 
             RGBColor[
              0.9619087106607098, 0.9708744978224306, 0.9387198300682666], 
             UndirectedEdge[322, 327] -> 
             RGBColor[
              0.4833018142740072, 0.5903027799299904, 0.9527710407339048], 
             UndirectedEdge[59, 299] -> 
             RGBColor[
              0.7379194468128668, 0.7952575076522997, 0.9745286538587785], 
             UndirectedEdge[254, 369] -> 
             RGBColor[
              0.36709412284451604`, 0.49238021134599463`, 0.9446118907924335],
              UndirectedEdge[262, 376] -> 
             RGBColor[
              0.580505746482321, 0.6681698660253903, 0.96128929199453], 
             UndirectedEdge[360, 389] -> 
             RGBColor[
              0.36351055339875815`, 0.4892763036075166, 0.9443835489161758], 
             UndirectedEdge[159, 381] -> 
             RGBColor[
              0.4705839900036675, 0.5776180940007971, 0.9524218621647748], 
             UndirectedEdge[77, 302] -> 
             RGBColor[
              0.8061270880484503, 0.8470690606476323, 0.885057379765994], 
             UndirectedEdge[67, 398] -> 
             RGBColor[
              0.7807104729178506, 0.8282934164515807, 0.9517956688232081], 
             UndirectedEdge[12, 100] -> 
             RGBColor[
              0.6693362103855325, 0.736608442170287, 0.9571408301719764], 
             UndirectedEdge[329, 339] -> 
             RGBColor[
              0.4630558919041176, 0.5716110305355762, 0.9518003253630505], 
             UndirectedEdge[1, 113] -> 
             RGBColor[
              0.6618180841894674, 0.7273276793028931, 0.8995541752523285], 
             UndirectedEdge[232, 390] -> 
             RGBColor[
              0.7470675508815059, 0.8021780159750638, 0.9758316080489349], 
             UndirectedEdge[319, 384] -> 
             RGBColor[
              0.5924756979218273, 0.6752850377882811, 0.9634286605771909], 
             UndirectedEdge[342, 374] -> 
             RGBColor[
              0.9711821440296742, 0.9780282707190151, 0.93366529264389], 
             UndirectedEdge[200, 320] -> 
             RGBColor[
              0.7320434621696575, 0.7882622896930587, 0.9339890127197295], 
             UndirectedEdge[35, 231] -> 
             RGBColor[
              0.7319454526356419, 0.7847834444142168, 0.7483208742175828], 
             UndirectedEdge[96, 104] -> 
             RGBColor[
              0.7133467337561543, 0.7744774861967592, 0.9699072825428046], 
             UndirectedEdge[106, 197] -> 
             RGBColor[
              0.531588012829544, 0.6207990618507261, 0.9591854462500282], 
             UndirectedEdge[41, 265] -> 
             RGBColor[
              0.6205042585115371, 0.6971172226724618, 0.9663264306450449], 
             UndirectedEdge[52, 303] -> 
             RGBColor[
              0.4157497749288865, 0.5337713883961098, 0.9479199390356348], 
             UndirectedEdge[170, 208] -> 
             RGBColor[
              0.961765725524288, 0.9707216784056979, 0.9368937720229036], 
             UndirectedEdge[49, 355] -> 
             RGBColor[
              0.5109131974910651, 0.6094214321227436, 0.9562077142401038], 
             UndirectedEdge[140, 359] -> 
             RGBColor[
              0.9384996759565731, 0.9529375353602665, 0.9641569375327361], 
             UndirectedEdge[20, 255] -> 
             RGBColor[
              0.9326476002533312, 0.9473962260079586, 0.9290145578130367], 
             UndirectedEdge[117, 362] -> 
             RGBColor[
              0.5435479400540721, 0.6403157301483728, 0.9572092314042175], 
             UndirectedEdge[188, 293] -> 
             RGBColor[
              0.5465840797583794, 0.6366958651728132, 0.9600135877958764], 
             UndirectedEdge[149, 155] -> 
             RGBColor[
              0.4144424235625941, 0.5333909296332042, 0.947628882645731], 
             UndirectedEdge[7, 188] -> 
             RGBColor[
              0.8697759749602578, 0.8987790678028412, 0.9696348532211467], 
             UndirectedEdge[120, 331] -> 
             RGBColor[
              0.6984342312904832, 0.759834214602463, 0.9301348955900299], 
             UndirectedEdge[169, 218] -> 
             RGBColor[
              0.3377788395367255, 0.4669887863737674, 0.9427439468625483], 
             UndirectedEdge[345, 350] -> 
             RGBColor[
              0.3519100778351264, 0.4790839740458954, 0.9436496706782922], 
             UndirectedEdge[147, 217] -> 
             RGBColor[
              0.33130953772458055`, 0.4584482092087955, 0.9424392736989462], 
             UndirectedEdge[141, 386] -> 
             RGBColor[
              0.7335729835210627, 0.7901654508128905, 0.95184979667485], 
             UndirectedEdge[128, 383] -> 
             RGBColor[
              0.6573195442583424, 0.7296645398900444, 0.9683657759812885], 
             UndirectedEdge[138, 394] -> 
             RGBColor[
              0.3778554537420175, 0.5017011352891927, 0.945297593281351], 
             UndirectedEdge[132, 300] -> 
             RGBColor[
              0.45706488941403, 0.5664075022897821, 0.9514225691013887], 
             UndirectedEdge[103, 122] -> 
             RGBColor[
              0.46473650579804576`, 0.5552227578553043, 0.9546360351253969], 
             UndirectedEdge[147, 195] -> 
             RGBColor[
              0.6278249993298648, 0.6740851081576408, 0.6553655213025289], 
             UndirectedEdge[123, 389] -> 
             RGBColor[
              0.5565496472378799, 0.6473293221739675, 0.9598013353620412], 
             UndirectedEdge[93, 394] -> 
             RGBColor[
              0.3444199894617326, 0.47125111094537886`, 0.9432216678093746], 
             UndirectedEdge[199, 350] -> 
             RGBColor[
              0.36636141498498903`, 0.4917455766250402, 0.9445652032955325], 
             UndirectedEdge[66, 158] -> 
             RGBColor[
              0.7216541404774188, 0.7726897302927536, 0.6831799275036154], 
             UndirectedEdge[105, 215] -> 
             RGBColor[
              0.7327830736010817, 0.7550634535764431, 0.6444308540031332], 
             UndirectedEdge[253, 364] -> 
             RGBColor[
              0.6071470021537015, 0.6820500706483372, 0.9662724118814319], 
             UndirectedEdge[76, 78] -> 
             RGBColor[
              0.9015932004240297, 0.9238825371393761, 0.9735766603853915], 
             UndirectedEdge[153, 358] -> 
             RGBColor[
              0.9371832843785395, 0.8870512373023347, 0.6347530498463034], 
             UndirectedEdge[54, 64] -> 
             RGBColor[
              0.4979609618376437, 0.6002669309861025, 0.9545087951298681], 
             UndirectedEdge[84, 125] -> 
             RGBColor[
              0.7271939187122972, 0.7861767039333774, 0.9741140048387673], 
             UndirectedEdge[195, 380] -> 
             RGBColor[
              0.641142872135445, 0.6880830368782118, 0.6561239544567794], 
             UndirectedEdge[81, 146] -> 
             RGBColor[
              0.4468273962206608, 0.5614411652335678, 0.9496924244665961], 
             UndirectedEdge[275, 317] -> 
             RGBColor[
              0.5442442721884666, 0.6289579981686365, 0.9607173473161048], 
             UndirectedEdge[25, 377] -> 
             RGBColor[
              0.7166066656045058, 0.6912120931621548, 0.609973457674309], 
             UndirectedEdge[180, 232] -> 
             RGBColor[
              0.8238406263139452, 0.8630281761727221, 0.9828857643638707], 
             UndirectedEdge[52, 333] -> 
             RGBColor[
              0.5166273669106798, 0.6150493905322754, 0.9562845868108693], 
             UndirectedEdge[97, 276] -> 
             RGBColor[
              0.41061074417655674`, 0.5300721215348242, 0.9473847314234737], 
             UndirectedEdge[51, 390] -> 
             RGBColor[
              0.5399771875131356, 0.6374168323750719, 0.9569281286840976], 
             UndirectedEdge[199, 393] -> 
             RGBColor[
              0.4984973807282488, 0.6002743279529967, 0.9547364933362812], 
             UndirectedEdge[169, 224] -> 
             RGBColor[
              0.2737455232563734, 0.4043047518351688, 0.9389282185178777], 
             UndirectedEdge[132, 268] -> 
             RGBColor[
              0.4139774419146052, 0.5218964927190091, 0.9489403664924492], 
             UndirectedEdge[162, 183] -> 
             RGBColor[
              0.690355662706619, 0.7492883766573781, 0.751284350687125], 
             UndirectedEdge[15, 231] -> 
             RGBColor[
              0.7386060571991793, 0.7901908232557125, 0.7488452214074228], 
             UndirectedEdge[246, 248] -> 
             RGBColor[
              0.7673482653072246, 0.8186863771280787, 0.9773780393362674], 
             UndirectedEdge[44, 81] -> 
             RGBColor[
              0.4164464564220212, 0.5351267221704197, 0.947756577847437], 
             UndirectedEdge[39, 197] -> 
             RGBColor[
              0.7438632837515664, 0.7998309179278529, 0.9751049983928937], 
             UndirectedEdge[57, 86] -> 
             RGBColor[
              0.5351097996979851, 0.6300490662691653, 0.9578892763194262], 
             UndirectedEdge[74, 209] -> 
             RGBColor[
              0.42960295537308735`, 0.5407743805365814, 0.9496067941083152], 
             UndirectedEdge[115, 389] -> 
             RGBColor[
              0.41248991212098196`, 0.5316997623585582, 0.9475044703432095], 
             UndirectedEdge[157, 168] -> 
             RGBColor[
              0.6585848264529991, 0.7277554629263915, 0.9631594028891], 
             UndirectedEdge[224, 363] -> 
             RGBColor[
              0.2692042964055873, 0.40028116243346173`, 0.9386421584770065], 
             UndirectedEdge[47, 279] -> 
             RGBColor[
              0.736551623479869, 0.7941189933529265, 0.9743762404283609], 
             UndirectedEdge[58, 352] -> 
             RGBColor[
              0.7791567570629608, 0.8276059640565989, 0.978568714944807], 
             UndirectedEdge[101, 161] -> 
             RGBColor[
              0.9915552552270295, 0.989962671471704, 0.7305020205645725], 
             UndirectedEdge[23, 98] -> 
             RGBColor[
              0.9443337535758639, 0.9573351763320999, 0.955896858903794], 
             UndirectedEdge[37, 388] -> 
             RGBColor[
              0.7113073112182366, 0.7732484259831185, 0.9728988195999465], 
             UndirectedEdge[13, 21] -> 
             RGBColor[
              0.44954908755784184`, 0.562084271190161, 0.9503395106397512], 
             UndirectedEdge[159, 375] -> 
             RGBColor[
              0.5373215030577154, 0.6301675262224217, 0.9587908670005145], 
             UndirectedEdge[130, 346] -> 
             RGBColor[
              0.4531105218337067, 0.5652451992307821, 0.950545389819781], 
             UndirectedEdge[104, 225] -> 
             RGBColor[
              0.5101652282609737, 0.6132141408407072, 0.9545812220469624], 
             UndirectedEdge[226, 252] -> 
             RGBColor[
              0.4650875496118808, 0.5735639201000532, 0.9518764074120845], 
             UndirectedEdge[64, 283] -> 
             RGBColor[
              0.7742801618793026, 0.8242267506981609, 0.9779684413139551], 
             UndirectedEdge[262, 284] -> 
             RGBColor[
              0.7473765345960928, 0.8025754961892921, 0.9754551664038802], 
             UndirectedEdge[282, 313] -> 
             RGBColor[
              0.7076115067252887, 0.7700980360574387, 0.9727804842967076], 
             UndirectedEdge[88, 360] -> 
             RGBColor[
              0.4784454685776634, 0.5846793296242299, 0.9528531553002626], 
             UndirectedEdge[210, 230] -> 
             RGBColor[
              0.5701456911264141, 0.6511722581492733, 0.9629513410244701], 
             UndirectedEdge[2, 138] -> 
             RGBColor[
              0.4166639791267644, 0.5347582989349865, 0.9479242921195729], 
             UndirectedEdge[178, 367] -> 
             RGBColor[
              0.9625423024589296, 0.9715460608391261, 0.9465603522765804], 
             UndirectedEdge[54, 123] -> 
             RGBColor[
              0.5413338204501512, 0.634150137780128, 0.9588317963339545], 
             UndirectedEdge[36, 95] -> 
             RGBColor[
              0.6166671775313934, 0.699516655497634, 0.9630752252136222], 
             UndirectedEdge[294, 301] -> 
             RGBColor[
              0.5422026920605958, 0.6345996518790535, 0.9590154289204206], 
             UndirectedEdge[60, 337] -> 
             RGBColor[
              0.627013395409256, 0.7007029402735208, 0.9654247990339765], 
             UndirectedEdge[251, 275] -> 
             RGBColor[
              0.5581340985189933, 0.6435570863078742, 0.9615083523774717], 
             UndirectedEdge[66, 311] -> 
             RGBColor[
              0.4172813267813795, 0.5358498449138915, 0.9478097750484884], 
             UndirectedEdge[110, 400] -> 
             RGBColor[
              0.363508617065882, 0.48497607180704166`, 0.9445983970054247], 
             UndirectedEdge[143, 151] -> 
             RGBColor[
              0.5287973486968053, 0.6263526977900412, 0.9567374139616942], 
             UndirectedEdge[157, 206] -> 
             RGBColor[
              0.8380825013110481, 0.8742405550850705, 0.9776462119153178], 
             UndirectedEdge[226, 274] -> 
             RGBColor[
              0.43914356112684516`, 0.5525014214845391, 0.9498340016025812], 
             UndirectedEdge[86, 265] -> 
             RGBColor[
              0.5335689135940422, 0.6287144281731176, 0.957791092419435], 
             UndirectedEdge[64, 389] -> 
             RGBColor[
              0.5131767886253725, 0.6134461153799422, 0.9554783341579549], 
             UndirectedEdge[120, 356] -> 
             RGBColor[
              0.7584127573327459, 0.8096138313424528, 0.9345564638737016], 
             UndirectedEdge[164, 279] -> 
             RGBColor[
              0.7696466012307213, 0.8199730415030392, 0.9776748385204148], 
             UndirectedEdge[24, 238] -> 
             RGBColor[
              0.6858313948629209, 0.7539301277576801, 0.9697077882443601], 
             UndirectedEdge[213, 259] -> 
             RGBColor[
              0.49131639452985376`, 0.595596548047475, 0.9537370861679976], 
             UndirectedEdge[73, 162] -> 
             RGBColor[
              0.6589619651116246, 0.7286896505371373, 0.9695768826036364], 
             UndirectedEdge[257, 356] -> 
             RGBColor[
              0.6026502796469897, 0.6878430758782166, 0.9621727938998402], 
             UndirectedEdge[6, 281] -> 
             RGBColor[
              0.6720719184099926, 0.7355300699138323, 0.8752520082203716], 
             UndirectedEdge[176, 277] -> 
             RGBColor[
              0.791088946905983, 0.8367239649124167, 0.979812011147212], 
             UndirectedEdge[140, 263] -> 
             RGBColor[
              0.7695269283898676, 0.8204183120320148, 0.9775919100261333], 
             UndirectedEdge[54, 161] -> 
             RGBColor[
              0.6700584519262437, 0.7321088097719455, 0.7842517174601047], 
             UndirectedEdge[7, 142] -> 
             RGBColor[
              0.8223113649801566, 0.8616993537419895, 0.9649040244803293], 
             UndirectedEdge[81, 311] -> 
             RGBColor[
              0.41389120680975067`, 0.5329134933868508, 0.9475937596016617], 
             UndirectedEdge[204, 237] -> 
             RGBColor[
              0.514766548014226, 0.6113044357334896, 0.9569315564550153], 
             UndirectedEdge[134, 374] -> 
             RGBColor[
              0.7384902066149883, 0.7941776799444151, 0.9527788486168798], 
             UndirectedEdge[264, 279] -> 
             RGBColor[
              0.518633080512455, 0.6092942726399083, 0.9581133742959049], 
             UndirectedEdge[81, 344] -> 
             RGBColor[
              0.3912276817638346, 0.513283487093968, 0.9461496598263042], 
             UndirectedEdge[287, 391] -> 
             RGBColor[
              0.7414113680902585, 0.7771981239400854, 0.6675922223184034], 
             UndirectedEdge[90, 228] -> 
             RGBColor[
              0.5113157380157459, 0.6100098567113443, 0.9561318841855586], 
             UndirectedEdge[222, 259] -> 
             RGBColor[
              0.7442594778918202, 0.8001510161020073, 0.9753196698471429], 
             UndirectedEdge[143, 342] -> 
             RGBColor[
              0.6869630958787789, 0.7500435974213839, 0.931521669845766], 
             UndirectedEdge[68, 262] -> 
             RGBColor[
              0.6407563052557312, 0.7178185780651833, 0.9658294661281258], 
             UndirectedEdge[73, 189] -> 
             RGBColor[
              0.8140224568528425, 0.8555364680079386, 0.9818598602263169], 
             UndirectedEdge[79, 176] -> 
             RGBColor[
              0.803382365797715, 0.846456471700124, 0.9810031261493195], 
             UndirectedEdge[14, 289] -> 
             RGBColor[
              0.5599815332929983, 0.6448467061934837, 0.9617123574728123], 
             UndirectedEdge[126, 373] -> 
             RGBColor[
              0.3454749041716, 0.47351015005978164`, 0.9432396271028529], 
             UndirectedEdge[313, 361] -> 
             RGBColor[
              0.8336103050782891, 0.8707136996002425, 0.9838453502579831], 
             UndirectedEdge[56, 203] -> 
             RGBColor[
              0.8537678651206518, 0.8865904655854295, 0.9840885793192481], 
             UndirectedEdge[163, 240] -> 
             RGBColor[
              0.7263759398401777, 0.784913456793978, 0.9671317071997008], 
             UndirectedEdge[283, 380] -> 
             RGBColor[
              0.6010147247449305, 0.6791419599438839, 0.9653873108974689], 
             UndirectedEdge[165, 318] -> 
             RGBColor[
              0.8388353043108296, 0.8742047165492718, 0.9461378093229367], 
             UndirectedEdge[184, 185] -> 
             RGBColor[
              0.5997864536460068, 0.6844950079724407, 0.9626468317904903], 
             UndirectedEdge[123, 364] -> 
             RGBColor[
              0.5124406825668166, 0.6072054394235807, 0.9570610119983277], 
             UndirectedEdge[24, 341] -> 
             RGBColor[
              0.8791764431905003, 0.9041593969699058, 0.878866263094888], 
             UndirectedEdge[10, 364] -> 
             RGBColor[
              0.32802001403904857`, 0.45661726768717326`, 0.9421923839923274],
              UndirectedEdge[59, 132] -> 
             RGBColor[
              0.6169681805584437, 0.6999215889339638, 0.9629891416839244], 
             UndirectedEdge[110, 309] -> 
             RGBColor[
              0.5171821149106288, 0.6077873109524106, 0.9580278792225614], 
             UndirectedEdge[28, 50] -> 
             RGBColor[
              0.7188980529177549, 0.7752828319857812, 0.8486226863240487], 
             UndirectedEdge[120, 147] -> 
             RGBColor[
              0.6302687675480038, 0.6978555229126978, 0.9258989975440008], 
             UndirectedEdge[322, 335] -> 
             RGBColor[
              0.6324341694828092, 0.708421384745513, 0.9666395558713781], 
             UndirectedEdge[9, 198] -> 
             RGBColor[
              0.7073066868721504, 0.7692135805157532, 0.9597674164171605], 
             UndirectedEdge[214, 257] -> 
             RGBColor[
              0.5131837478364637, 0.6125224306520214, 0.9558722759638345], 
             UndirectedEdge[190, 274] -> 
             RGBColor[
              0.5114815529437505, 0.6142827925179368, 0.9546848479478467], 
             UndirectedEdge[18, 198] -> 
             RGBColor[
              0.9551212201048735, 0.9660500599532481, 0.9608522474887374], 
             UndirectedEdge[280, 291] -> 
             RGBColor[
              0.5936851660666977, 0.6748749874464481, 0.9641631186803026], 
             UndirectedEdge[156, 179] -> 
             RGBColor[
              0.3904489039877421, 0.5104994812361195, 0.9463868008726137], 
             UndirectedEdge[76, 96] -> 
             RGBColor[
              0.9471218222016036, 0.9600841220948013, 0.9743931415618577], 
             UndirectedEdge[143, 158] -> 
             RGBColor[
              0.691467657593702, 0.746543716035623, 0.6812564715071238], 
             UndirectedEdge[252, 274] -> 
             RGBColor[
              0.563394391466324, 0.6564279734772862, 0.958771616759337], 
             UndirectedEdge[272, 348] -> 
             RGBColor[
              0.69874190500065, 0.7644883327607501, 0.9706715935939021], 
             UndirectedEdge[51, 232] -> 
             RGBColor[
              0.7017694836501778, 0.7654030043419981, 0.9722655782641971], 
             UndirectedEdge[66, 317] -> 
             RGBColor[
              0.359001215893117, 0.4813122177117886, 0.9442448130540333], 
             UndirectedEdge[258, 264] -> 
             RGBColor[
              0.3839069617433597, 0.5018674237892464, 0.9461740945675245], 
             UndirectedEdge[17, 223] -> 
             RGBColor[
              0.2902300400198522, 0.4223805520811961, 0.9398395434710387], 
             UndirectedEdge[46, 271] -> 
             RGBColor[
              0.9831331918301955, 0.9867036811267348, 0.9027923196795835], 
             UndirectedEdge[93, 201] -> 
             RGBColor[
              0.2990692747415101, 0.4316711482135094, 0.9403429248119612], 
             UndirectedEdge[232, 373] -> 
             RGBColor[
              0.6463137097833237, 0.71849305169464, 0.9684216829464137], 
             UndirectedEdge[182, 208] -> 
             RGBColor[
              0.9330805287625658, 0.9478987010175823, 0.9358850385420192], 
             UndirectedEdge[10, 391] -> 
             RGBColor[
              0.6745993736411191, 0.7206418765601981, 0.6629722507328695], 
             UndirectedEdge[284, 366] -> 
             RGBColor[
              0.8713765044212143, 0.8995475122054741, 0.945400610232594], 
             UndirectedEdge[154, 387] -> 
             RGBColor[
              0.6465276883531763, 0.7115862840989513, 0.8411883993437559], 
             UndirectedEdge[135, 363] -> 
             RGBColor[
              0.48016330054129064`, 0.584658847912271, 0.9534214027660324], 
             UndirectedEdge[37, 269] -> 
             RGBColor[
              0.43128488545676785`, 0.5459545953512916, 0.9492614249811051], 
             UndirectedEdge[201, 281] -> 
             RGBColor[
              0.6480142170667844, 0.7143930451511622, 0.8737300372066691], 
             UndirectedEdge[302, 377] -> 
             RGBColor[
              0.9625876885689011, 0.8844903180250625, 0.5365149408327898], 
             UndirectedEdge[179, 286] -> 
             RGBColor[
              0.6396818860655731, 0.7076853744710925, 0.926068616908736], 
             UndirectedEdge[108, 325] -> 
             RGBColor[
              0.45886047538939123`, 0.5708107740550152, 0.9507500643366011], 
             UndirectedEdge[279, 299] -> 
             RGBColor[
              0.8042664981435506, 0.8471711491145756, 0.9810848829176297], 
             UndirectedEdge[196, 332] -> 
             RGBColor[
              0.4272916073094942, 0.5398524376750145, 0.9493379505552862], 
             UndirectedEdge[31, 224] -> 
             RGBColor[
              0.425011093656044, 0.5308143067715521, 0.9498125989544474], 
             UndirectedEdge[200, 296] -> 
             RGBColor[
              0.9771440821318578, 0.982474674393846, 0.9235732865593863], 
             UndirectedEdge[170, 221] -> 
             RGBColor[
              0.8466717820520852, 0.8810467748649535, 0.983372363799467], 
             UndirectedEdge[198, 206] -> 
             RGBColor[
              0.841827016406574, 0.877033208312233, 0.9713077245845413], 
             UndirectedEdge[36, 361] -> 
             RGBColor[
              0.6661253263563327, 0.7381537372555297, 0.9680047512758134], 
             UndirectedEdge[132, 180] -> 
             RGBColor[
              0.667902634078438, 0.7397947918464473, 0.9680091870319216], 
             UndirectedEdge[127, 312] -> 
             RGBColor[
              0.718254230563491, 0.7601532199671279, 0.6683771970661234], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.736558331765263, 0.7941242339164611, 0.9743769090475565], 
             UndirectedEdge[67, 75] -> 
             RGBColor[
              0.6508815807801176, 0.7196984555631226, 0.9424575794142682], 
             UndirectedEdge[110, 287] -> 
             RGBColor[
              0.38326223153596084`, 0.5010129459240424, 0.9461534738963834], 
             UndirectedEdge[88, 233] -> 
             RGBColor[
              0.5862572849486483, 0.6749891003678512, 0.960571467483804], 
             UndirectedEdge[168, 216] -> 
             RGBColor[
              0.3798201522120507, 0.5034028583553192, 0.9454227821305468], 
             UndirectedEdge[1, 291] -> 
             RGBColor[
              0.6616029669573911, 0.7271413555685751, 0.8995404681725213], 
             UndirectedEdge[115, 214] -> 
             RGBColor[
              0.4015516271239046, 0.5222255696682792, 0.9468074924955414], 
             UndirectedEdge[233, 256] -> 
             RGBColor[
              0.7520577474277613, 0.805969653143034, 0.9746933740387642], 
             UndirectedEdge[4, 252] -> 
             RGBColor[
              0.5862783570542498, 0.675006207652466, 0.9605731263571465], 
             UndirectedEdge[91, 399] -> 
             RGBColor[
              0.8294066075319622, 0.8538354555156852, 0.6832709024977472], 
             UndirectedEdge[76, 269] -> 
             RGBColor[
              0.6446471908939282, 0.7149892144178098, 0.9521403149472578], 
             UndirectedEdge[91, 172] -> 
             RGBColor[
              0.5247218656975803, 0.6224652173345864, 0.9566290395456332], 
             UndirectedEdge[165, 184] -> 
             RGBColor[
              0.5800578793109139, 0.6690828957591477, 0.9606804718747775], 
             UndirectedEdge[60, 139] -> 
             RGBColor[
              0.591705069387928, 0.6726134019258774, 0.9642885442862934], 
             UndirectedEdge[356, 359] -> 
             RGBColor[
              0.7511698241374224, 0.8042120636245952, 0.9468168605138627], 
             UndirectedEdge[228, 305] -> 
             RGBColor[
              0.49622088283581256`, 0.5960661010373942, 0.9552018845529984], 
             UndirectedEdge[141, 209] -> 
             RGBColor[
              0.7691453499110553, 0.8190447003651302, 0.954650183662942], 
             UndirectedEdge[171, 348] -> 
             RGBColor[
              0.8234202017931689, 0.8625118748661728, 0.9828937133015057], 
             UndirectedEdge[10, 60] -> 
             RGBColor[
              0.3419403130165465, 0.4705932455402496, 0.9430091122728359], 
             UndirectedEdge[234, 298] -> 
             RGBColor[
              0.6769122591922114, 0.7417965150036177, 0.9375720087154318], 
             UndirectedEdge[323, 388] -> 
             RGBColor[
              0.7777778986004313, 0.8269294854772498, 0.9783249507864593], 
             UndirectedEdge[294, 329] -> 
             RGBColor[
              0.3350193838012625, 0.4645986845099873, 0.9425681167831754], 
             UndirectedEdge[211, 238] -> 
             RGBColor[
              0.47312904038550996`, 0.5800923645751163, 0.9525094630227358], 
             UndirectedEdge[31, 99] -> 
             RGBColor[
              0.7416475573923857, 0.7981030739592507, 0.9750305662233544], 
             UndirectedEdge[111, 319] -> 
             RGBColor[
              0.46828712356551205`, 0.5770516077440272, 0.9518823441972735], 
             UndirectedEdge[258, 394] -> 
             RGBColor[
              0.4482014757724047, 0.5613585207009373, 0.9501316589107358], 
             UndirectedEdge[101, 364] -> 
             RGBColor[
              0.6383812334987073, 0.7048260463544651, 0.8877331375412487], 
             UndirectedEdge[225, 349] -> 
             RGBColor[
              0.6325762939299733, 0.7112217227384242, 0.9651553909265493], 
             UndirectedEdge[118, 386] -> 
             RGBColor[
              0.4191603747505961, 0.5360654524175568, 0.9483196266245635], 
             UndirectedEdge[95, 326] -> 
             RGBColor[
              0.5850949951036126, 0.6738849354921517, 0.9605897473601923], 
             UndirectedEdge[228, 382] -> 
             RGBColor[
              0.6244001514647667, 0.7051779326700638, 0.9641056340190493], 
             UndirectedEdge[120, 255] -> 
             RGBColor[
              0.9310675340477386, 0.9466377965343704, 0.9504968191285463], 
             UndirectedEdge[222, 292] -> 
             RGBColor[
              0.5672438044796323, 0.6467518890279207, 0.9629936742354752], 
             UndirectedEdge[325, 397] -> 
             RGBColor[
              0.7415203424574938, 0.7945335248039526, 0.8764234315451314], 
             UndirectedEdge[155, 299] -> 
             RGBColor[
              0.629177060903039, 0.7060564257004518, 0.9662220089179785], 
             UndirectedEdge[17, 99] -> 
             RGBColor[
              0.5736751483836857, 0.6547831003189104, 0.9631673121536913], 
             UndirectedEdge[60, 105] -> 
             RGBColor[
              0.40603089697497263`, 0.5249401292856306, 0.9474148444556859], 
             UndirectedEdge[229, 340] -> 
             RGBColor[
              0.4140968855100955, 0.5323461642048014, 0.9478128429857886], 
             UndirectedEdge[297, 375] -> 
             RGBColor[
              0.868369169731284, 0.8964904275045611, 0.9128744184682407], 
             UndirectedEdge[155, 249] -> 
             RGBColor[
              0.5877743281598921, 0.6735595151868096, 0.9621359148344021], 
             UndirectedEdge[143, 348] -> 
             RGBColor[
              0.5770005158582072, 0.6640093783341676, 0.9615418551801345], 
             UndirectedEdge[175, 294] -> 
             RGBColor[
              0.44351375398334525`, 0.5560369306386974, 0.950181468190597], 
             UndirectedEdge[19, 181] -> 
             RGBColor[
              0.6629705671444355, 0.7366369129069453, 0.9670423683869112], 
             UndirectedEdge[153, 294] -> 
             RGBColor[
              0.643942700663092, 0.6494131398573303, 0.6097648806920688], 
             UndirectedEdge[68, 376] -> 
             RGBColor[
              0.4865140195201163, 0.5932784299392705, 0.9529222828157657], 
             UndirectedEdge[317, 354] -> 
             RGBColor[
              0.6018270803757537, 0.6747929376564662, 0.9634350011082153], 
             UndirectedEdge[2, 254] -> 
             RGBColor[
              0.4126048591655359, 0.5312424932418718, 0.9476656485849823], 
             UndirectedEdge[243, 311] -> 
             RGBColor[
              0.43710985966678717`, 0.551952083942586, 0.9493694946114538], 
             UndirectedEdge[23, 143] -> 
             RGBColor[
              0.6512550321849133, 0.722742973238419, 0.9687503519282252], 
             UndirectedEdge[20, 64] -> 
             RGBColor[
              0.8184321436935487, 0.857696671861134, 0.9177562997992279], 
             UndirectedEdge[75, 296] -> 
             RGBColor[
              0.6540580961470079, 0.7220674955226829, 0.9370805674660165], 
             UndirectedEdge[146, 227] -> 
             RGBColor[
              0.4967322848534442, 0.6021448441932757, 0.9535689977115578], 
             UndirectedEdge[160, 238] -> 
             RGBColor[
              0.5720168749988112, 0.6634280940474159, 0.9594504102482123], 
             UndirectedEdge[75, 178] -> 
             RGBColor[
              0.6381724354862521, 0.7102199958122732, 0.9639708473208164], 
             UndirectedEdge[95, 166] -> 
             RGBColor[
              0.47041597472182795`, 0.5743754182554663, 0.9528723818635625], 
             UndirectedEdge[25, 309] -> 
             RGBColor[
              0.6340358606020345, 0.7118300711663932, 0.9656645135201554], 
             UndirectedEdge[166, 326] -> 
             RGBColor[
              0.40267031269637155`, 0.5195370035348447, 0.947429415597784], 
             UndirectedEdge[158, 308] -> 
             RGBColor[
              0.6555619402119837, 0.7154439883134074, 0.6789685909457399], 
             UndirectedEdge[229, 343] -> 
             RGBColor[
              0.37454955596534106`, 0.49883773279428917`, 0.9450869443983116],
              UndirectedEdge[229, 294] -> 
             RGBColor[
              0.3439000282983595, 0.472290652419202, 0.9431339835976849], 
             UndirectedEdge[64, 257] -> 
             RGBColor[
              0.6610895998022, 0.7351674869233096, 0.9668548911408763], 
             UndirectedEdge[56, 65] -> 
             RGBColor[
              0.7649390654747085, 0.8164292357875264, 0.9757596961968114], 
             UndirectedEdge[170, 192] -> 
             RGBColor[
              0.7106195965770347, 0.7723299142936685, 0.9714746288774967], 
             UndirectedEdge[133, 347] -> 
             RGBColor[
              0.37013019432038397`, 0.48704916847893875`, 0.9454202948378252],
              UndirectedEdge[223, 393] -> 
             RGBColor[
              0.47896541026563105`, 0.5822726576313888, 0.9535316261680029], 
             UndirectedEdge[116, 338] -> 
             RGBColor[
              0.6399591901219962, 0.7164723836040112, 0.9662446657770517], 
             UndirectedEdge[32, 71] -> 
             RGBColor[
              0.488087730220206, 0.5933443670872129, 0.9533809596963131], 
             UndirectedEdge[95, 361] -> 
             RGBColor[
              0.7022988059540081, 0.767360431970669, 0.9709622396881619], 
             UndirectedEdge[247, 292] -> 
             RGBColor[
              0.26456466422846825`, 0.39540461484563916`, 0.9383779382882403],
              UndirectedEdge[337, 391] -> 
             RGBColor[
              0.9596724560338288, 0.9507515712934693, 0.68538793749401], 
             UndirectedEdge[181, 238] -> 
             RGBColor[
              0.6359951722097672, 0.7149976918517159, 0.9647405793162732], 
             UndirectedEdge[97, 246] -> 
             RGBColor[
              0.638588016206278, 0.7120084733006631, 0.9678341017269195], 
             UndirectedEdge[62, 247] -> 
             RGBColor[
              0.49776351024097637`, 0.5931199401224293, 0.9560128466989615], 
             UndirectedEdge[207, 280] -> 
             RGBColor[
              0.9186540329351379, 0.936448754323794, 0.9368256452012407], 
             UndirectedEdge[145, 221] -> 
             RGBColor[
              0.7041866507247716, 0.7688352306537412, 0.9711504024119992], 
             UndirectedEdge[10, 334] -> 
             RGBColor[
              0.4855705118385253, 0.5909317816295891, 0.9532847492346743], 
             UndirectedEdge[25, 78] -> 
             RGBColor[
              0.6735724409255943, 0.7429475247100847, 0.9695438032198487], 
             UndirectedEdge[46, 139] -> 
             RGBColor[
              0.9266003846393818, 0.9427849594747872, 0.9375835753205835], 
             UndirectedEdge[224, 383] -> 
             RGBColor[
              0.342254779124242, 0.4636290025051511, 0.9432977187281353], 
             UndirectedEdge[138, 164] -> 
             RGBColor[
              0.5645744604312387, 0.6528888072406327, 0.9609014931626496], 
             UndirectedEdge[53, 93] -> 
             RGBColor[
              0.3480719093443144, 0.474414220396841, 0.9434543649150268], 
             UndirectedEdge[31, 199] -> 
             RGBColor[
              0.47773441949117, 0.5837021960431443, 0.9529076647089799], 
             UndirectedEdge[98, 342] -> 
             RGBColor[
              0.9800418172697295, 0.9846358005150648, 0.9186681768213347], 
             UndirectedEdge[141, 304] -> 
             RGBColor[
              0.6267711095255528, 0.6974962890058339, 0.9447120120051402], 
             UndirectedEdge[32, 105] -> 
             RGBColor[
              0.5453834280938148, 0.6418058620268299, 0.9573537277463204], 
             UndirectedEdge[216, 329] -> 
             RGBColor[
              0.357597401320338, 0.4841546284808542, 0.9440067680945339], 
             UndirectedEdge[164, 264] -> 
             RGBColor[
              0.518633080512455, 0.6092942726399083, 0.9581133742959049], 
             UndirectedEdge[118, 196] -> 
             RGBColor[
              0.31186282334059945`, 0.4428753022201114, 0.9411536138593877], 
             UndirectedEdge[75, 398] -> 
             RGBColor[
              0.4655136791733428, 0.5737699842358981, 0.9519486050978149], 
             UndirectedEdge[45, 48] -> 
             RGBColor[
              0.37552731851053966`, 0.49968462156716575`, 0.9451492465630903],
              UndirectedEdge[248, 275] -> 
             RGBColor[
              0.7277468997830816, 0.7871093232095581, 0.9736008257400184], 
             UndirectedEdge[200, 347] -> 
             RGBColor[
              0.6095484600451087, 0.6763371053289805, 0.9262089010664045], 
             UndirectedEdge[33, 58] -> 
             RGBColor[
              0.8538583558219739, 0.8863074918375482, 0.9859229662982942], 
             UndirectedEdge[134, 240] -> 
             RGBColor[
              0.5122909430843439, 0.6149398918966806, 0.954748566104608], 
             UndirectedEdge[267, 344] -> 
             RGBColor[
              0.4164014077423048, 0.5339092940847234, 0.9480793053538844], 
             UndirectedEdge[141, 286] -> 
             RGBColor[
              0.9729031791592657, 0.9793118159007281, 0.9307520290873428], 
             UndirectedEdge[33, 209] -> 
             RGBColor[
              0.7195081093093756, 0.7801390990794628, 0.9732763577130841], 
             UndirectedEdge[47, 155] -> 
             RGBColor[
              0.5614621862393575, 0.6530042699388028, 0.9595133664287094], 
             UndirectedEdge[153, 229] -> 
             RGBColor[
              0.6474630708345848, 0.6524623075609278, 0.6099891955664551], 
             UndirectedEdge[64, 161] -> 
             RGBColor[
              0.8222418456826314, 0.8584588577467943, 0.7955068938175651], 
             UndirectedEdge[3, 293] -> 
             RGBColor[
              0.3526302853858649, 0.47985236231291944`, 0.9436902678594374], 
             UndirectedEdge[133, 178] -> 
             RGBColor[
              0.7218401557463772, 0.7813392378333943, 0.9696749601856067], 
             UndirectedEdge[113, 162] -> 
             RGBColor[
              0.3615584591705993, 0.48758549770219417`, 0.9442591631981265], 
             UndirectedEdge[313, 358] -> 
             RGBColor[
              0.9211622404676962, 0.9399737825387668, 0.9923424708986903], 
             UndirectedEdge[259, 292] -> 
             RGBColor[
              0.4375683798840093, 0.5445869199446763, 0.9504754588408266], 
             UndirectedEdge[4, 165] -> 
             RGBColor[
              0.6412912955481482, 0.7187949415945001, 0.965500990706367], 
             UndirectedEdge[247, 385] -> 
             RGBColor[
              0.45468627508604387`, 0.5594437323536452, 0.9517356813042397], 
             UndirectedEdge[38, 243] -> 
             RGBColor[
              0.7315153269671484, 0.7551697694845982, 0.6460183884947992], 
             UndirectedEdge[265, 381] -> 
             RGBColor[
              0.48798940727699847`, 0.5926937916212476, 0.9535309199624252], 
             UndirectedEdge[15, 369] -> 
             RGBColor[
              0.4332062006926536, 0.5488207193808962, 0.9490517395685394], 
             UndirectedEdge[30, 358] -> 
             RGBColor[
              0.6758126930905157, 0.7434245627775407, 0.9705863035617488], 
             UndirectedEdge[133, 330] -> 
             RGBColor[
              0.42522031301285607`, 0.5413766637562409, 0.9486885199452635], 
             UndirectedEdge[223, 292] -> 
             RGBColor[
              0.2787868378207058, 0.41035302102896853`, 0.9391878700344979], 
             UndirectedEdge[44, 326] -> 
             RGBColor[
              0.4519358962446776, 0.5641272903774983, 0.9504983141565364], 
             UndirectedEdge[123, 356] -> 
             RGBColor[
              0.6350778940513286, 0.7131757747098837, 0.9654048754503788], 
             UndirectedEdge[35, 154] -> 
             RGBColor[
              0.38445879652286996`, 0.5060246291478339, 0.9458799024750358], 
             UndirectedEdge[146, 151] -> 
             RGBColor[
              0.5560506543967108, 0.6499581413963262, 0.9584739705017402], 
             UndirectedEdge[111, 287] -> 
             RGBColor[
              0.5323137356677585, 0.6311952969324234, 0.9563248336826804], 
             UndirectedEdge[42, 133] -> 
             RGBColor[
              0.48252816091927636`, 0.590777124537022, 0.9524055308679105], 
             UndirectedEdge[40, 103] -> 
             RGBColor[
              0.4919914340482362, 0.5765145149494798, 0.9573525516615903], 
             UndirectedEdge[219, 260] -> 
             RGBColor[
              0.40004266274096534`, 0.5209185805625323, 0.9467113426193854], 
             UndirectedEdge[151, 186] -> 
             RGBColor[
              0.7673608305550701, 0.8185908704422671, 0.9773399403249139], 
             UndirectedEdge[8, 76] -> 
             RGBColor[
              0.9071438405656622, 0.9283084669202011, 0.9741060853972154], 
             UndirectedEdge[124, 167] -> 
             RGBColor[
              0.8303166378068577, 0.8665603894513505, 0.8998717869254695], 
             UndirectedEdge[162, 291] -> 
             RGBColor[
              0.361343341938523, 0.48739917396787613`, 0.9442454561183193], 
             UndirectedEdge[242, 255] -> 
             RGBColor[
              0.7059275766683134, 0.768997873716714, 0.9723406899912528], 
             UndirectedEdge[182, 323] -> 
             RGBColor[
              0.7705389384524672, 0.8211573351516018, 0.9776344923052505], 
             UndirectedEdge[138, 149] -> 
             RGBColor[
              0.38445972000362305`, 0.5074214187849215, 0.9457184112876171], 
             UndirectedEdge[199, 353] -> 
             RGBColor[
              0.3004683242524794, 0.4306139689213431, 0.9405151489572956], 
             UndirectedEdge[34, 381] -> 
             RGBColor[
              0.4584318822141302, 0.5664228918095258, 0.9516720600328457], 
             UndirectedEdge[148, 305] -> 
             RGBColor[
              0.6128229684272807, 0.6880158710789162, 0.9665956497638726], 
             UndirectedEdge[97, 383] -> 
             RGBColor[
              0.4141038976106902, 0.5330826920810291, 0.9476114630781356], 
             UndirectedEdge[154, 207] -> 
             RGBColor[
              0.6421265437698651, 0.7097662977094956, 0.914126754886294], 
             UndirectedEdge[272, 375] -> 
             RGBColor[
              0.6925481069439454, 0.7596496906442438, 0.9700542536879435], 
             UndirectedEdge[25, 323] -> 
             RGBColor[
              0.5796882712364142, 0.669373321296993, 0.9602476537192888], 
             UndirectedEdge[236, 334] -> 
             RGBColor[
              0.5280599275878282, 0.627733977971505, 0.9559921372343048], 
             UndirectedEdge[23, 346] -> 
             RGBColor[
              0.6511528252951077, 0.7226544467675369, 0.968743839395585], 
             UndirectedEdge[23, 151] -> 
             RGBColor[
              0.7872746532730512, 0.8344696121312675, 0.9792393385130342], 
             UndirectedEdge[250, 381] -> 
             RGBColor[
              0.7484005419118814, 0.8034586079051346, 0.9757081799897827], 
             UndirectedEdge[230, 264] -> 
             RGBColor[
              0.27238949128307155`, 0.4036290042027172, 0.9388235506132057], 
             UndirectedEdge[60, 68] -> 
             RGBColor[
              0.43129823428155467`, 0.5454532919916878, 0.9494039818057664], 
             UndirectedEdge[50, 258] -> 
             RGBColor[
              0.47195457194195867`, 0.5819322587376782, 0.9516451851946216], 
             UndirectedEdge[121, 298] -> 
             RGBColor[
              0.8322938999280391, 0.8691790854587411, 0.9497664254280749], 
             UndirectedEdge[95, 382] -> 
             RGBColor[
              0.6042712096243612, 0.6894530503187148, 0.962099369212054], 
             UndirectedEdge[42, 200] -> 
             RGBColor[
              0.721946426644001, 0.7800650613870639, 0.9331941370964899], 
             UndirectedEdge[254, 314] -> 
             RGBColor[
              0.35586737106113386`, 0.48265616322418065`, 0.9438965320962232],
              UndirectedEdge[95, 305] -> 
             RGBColor[
              0.4760919409954071, 0.5803412186860453, 0.9531956197460032], 
             UndirectedEdge[321, 381] -> 
             RGBColor[
              0.5628510819932218, 0.655986890371209, 0.9587288454474062], 
             UndirectedEdge[116, 209] -> 
             RGBColor[
              0.6784227099461496, 0.7476988017590807, 0.9692726549541246], 
             UndirectedEdge[364, 366] -> 
             RGBColor[
              0.6353696320913829, 0.7033407662409132, 0.9268997065327359], 
             UndirectedEdge[58, 156] -> 
             RGBColor[
              0.6653381022484319, 0.7362872806315617, 0.9688670641427912], 
             UndirectedEdge[118, 179] -> 
             RGBColor[
              0.3141937893924973, 0.4453252953324397, 0.9412863589276881], 
             UndirectedEdge[149, 328] -> 
             RGBColor[
              0.5082136498504874, 0.6104377497609108, 0.9547569430599276], 
             UndirectedEdge[215, 227] -> 
             RGBColor[
              0.7577582371101056, 0.775339416431363, 0.6463969903616018], 
             UndirectedEdge[70, 177] -> 
             RGBColor[
              0.36806535604589463`, 0.4899394125371941, 0.9448420653466312], 
             UndirectedEdge[383, 393] -> 
             RGBColor[
              0.557390575592791, 0.6512696298991768, 0.9584932666425556], 
             UndirectedEdge[14, 201] -> 
             RGBColor[
              0.2983460532522131, 0.43091099657336734`, 0.9403017384180561], 
             UndirectedEdge[5, 368] -> 
             RGBColor[
              0.660339477237769, 0.7282749331232572, 0.948672117802182], 
             UndirectedEdge[214, 310] -> 
             RGBColor[
              0.6464963742331185, 0.7175501237831035, 0.9662576883111762], 
             UndirectedEdge[35, 280] -> 
             RGBColor[
              0.6609862856881428, 0.7327070857621324, 0.9685787927899825], 
             UndirectedEdge[243, 275] -> 
             RGBColor[
              0.6582222825568583, 0.7306661068969964, 0.9681275931949056], 
             UndirectedEdge[131, 391] -> 
             RGBColor[
              0.7313639386815806, 0.7690411681145839, 0.6668012518704056], 
             UndirectedEdge[2, 314] -> 
             RGBColor[
              0.4170881505173706, 0.5351256948740556, 0.9479513199455023], 
             UndirectedEdge[282, 361] -> 
             RGBColor[
              0.6257581564259469, 0.7053818501857608, 0.9648268997890778], 
             UndirectedEdge[110, 269] -> 
             RGBColor[
              0.299772685704087, 0.43001144177453576`, 0.940470823484121], 
             UndirectedEdge[193, 360] -> 
             RGBColor[
              0.33778968007578936`, 0.4669981759038432, 0.9427446376121115], 
             UndirectedEdge[71, 400] -> 
             RGBColor[
              0.4219020018273881, 0.5396118111448377, 0.9481705767109188], 
             UndirectedEdge[110, 117] -> 
             RGBColor[
              0.37124494891801196`, 0.49125677452237904`, 0.9452074293879418],
              UndirectedEdge[170, 351] -> 
             RGBColor[
              0.8559741587949518, 0.8883138622771627, 0.9842995377775428], 
             UndirectedEdge[121, 200] -> 
             RGBColor[
              0.8364572863201943, 0.872284132213091, 0.9427188982512358], 
             UndirectedEdge[38, 383] -> 
             RGBColor[
              0.7120470973056453, 0.7393645836116385, 0.6444857781413706], 
             UndirectedEdge[172, 256] -> 
             RGBColor[
              0.6569445993147318, 0.726658830590829, 0.9677842097676284], 
             UndirectedEdge[127, 258] -> 
             RGBColor[
              0.7413574029190844, 0.7789094160714525, 0.6701959634236646], 
             UndirectedEdge[25, 388] -> 
             RGBColor[
              0.6966488571569616, 0.7613480326203452, 0.9717448524005565], 
             UndirectedEdge[51, 277] -> 
             RGBColor[
              0.6530055078340832, 0.7265898654296995, 0.9675958689849933], 
             UndirectedEdge[85, 379] -> 
             RGBColor[
              0.8749388495689495, 0.9026899397100572, 0.9639533204439129], 
             UndirectedEdge[267, 306] -> 
             RGBColor[
              0.7235071581213037, 0.7823743617259264, 0.9612709952860218], 
             UndirectedEdge[176, 298] -> 
             RGBColor[
              0.872187992323303, 0.9003446536442533, 0.9537426957265449], 
             UndirectedEdge[269, 323] -> 
             RGBColor[
              0.4977554728389625, 0.5996356548454229, 0.9546875561676179], 
             UndirectedEdge[21, 180] -> 
             RGBColor[
              0.6276376265588874, 0.7071058448241587, 0.9648393781444002], 
             UndirectedEdge[36, 228] -> 
             RGBColor[
              0.636796119371799, 0.7152415378489829, 0.9650814900206175], 
             UndirectedEdge[74, 116] -> 
             RGBColor[
              0.5315626567537827, 0.6214355167228107, 0.9590790228931374], 
             UndirectedEdge[3, 188] -> 
             RGBColor[
              0.5900691473728497, 0.6743604451174192, 0.962784417851935], 
             UndirectedEdge[69, 394] -> 
             RGBColor[
              0.6910918433170823, 0.7530330273850088, 0.9142797387151216], 
             UndirectedEdge[37, 395] -> 
             RGBColor[
              0.7357193891257554, 0.7925111726263533, 0.9681966989045809], 
             UndirectedEdge[172, 194] -> 
             RGBColor[
              0.5254841944122468, 0.6230607543203968, 0.9567050213475443], 
             UndirectedEdge[59, 264] -> 
             RGBColor[
              0.4522860291817713, 0.5573806311776325, 0.9515571452370536], 
             UndirectedEdge[28, 369] -> 
             RGBColor[
              0.688442745811928, 0.748903975698957, 0.8466821010858361], 
             UndirectedEdge[130, 344] -> 
             RGBColor[
              0.4248663199665915, 0.5407814911683493, 0.9487456942521755], 
             UndirectedEdge[29, 270] -> 
             RGBColor[
              0.7016718234873506, 0.7614147046067266, 0.886205042483574], 
             UndirectedEdge[41, 48] -> 
             RGBColor[
              0.6282998030060165, 0.703869331498121, 0.9668231558469038], 
             UndirectedEdge[12, 124] -> 
             RGBColor[
              0.688490847198254, 0.7500939177296493, 0.8888904419324103], 
             UndirectedEdge[61, 95] -> 
             RGBColor[
              0.7284567112991621, 0.7877951864337471, 0.9735694152334433], 
             UndirectedEdge[213, 306] -> 
             RGBColor[
              0.6591725733081668, 0.7278293870945782, 0.9568460544620844], 
             UndirectedEdge[63, 295] -> 
             RGBColor[
              0.4685739282040944, 0.5782534907520125, 0.9516371732945081], 
             UndirectedEdge[302, 367] -> 
             RGBColor[
              0.9874728983513499, 0.9890877357835248, 0.8572700236253753], 
             UndirectedEdge[140, 331] -> 
             RGBColor[
              0.660617041060499, 0.7309140118664468, 0.9693182857404583], 
             UndirectedEdge[92, 354] -> 
             RGBColor[
              0.9312916406769792, 0.9479706625933815, 0.9905339762757015], 
             UndirectedEdge[151, 311] -> 
             RGBColor[
              0.5231144649858006, 0.6214304695496093, 0.9563753056368057], 
             UndirectedEdge[299, 371] -> 
             RGBColor[
              0.6180856554347461, 0.6964496077540645, 0.9655152743692836], 
             UndirectedEdge[140, 389] -> 
             RGBColor[
              0.642067320289313, 0.7148471760705204, 0.9681363139357924], 
             UndirectedEdge[176, 205] -> 
             RGBColor[
              0.6159839091734446, 0.6971542561388091, 0.9642573642571673], 
             UndirectedEdge[152, 179] -> 
             RGBColor[
              0.3138594185307332, 0.44503568009794775`, 0.941265053112049], 
             UndirectedEdge[142, 293] -> 
             RGBColor[
              0.49911946977827826`, 0.5996161511119614, 0.9552827590550589], 
             UndirectedEdge[105, 259] -> 
             RGBColor[
              0.5554069784882798, 0.649943431792856, 0.9581428183508476], 
             UndirectedEdge[274, 318] -> 
             RGBColor[
              0.7578783773318954, 0.8093534839917236, 0.939167539164213], 
             UndirectedEdge[231, 369] -> 
             RGBColor[
              0.6882040224862584, 0.7473575649748089, 0.7454064026880471], 
             UndirectedEdge[151, 348] -> 
             RGBColor[
              0.7130201369463451, 0.7757360172270161, 0.9720308417649435], 
             UndirectedEdge[147, 231] -> 
             RGBColor[
              0.6352908073534553, 0.6985896044304403, 0.7421423644363927], 
             UndirectedEdge[66, 354] -> 
             RGBColor[
              0.6959765578587377, 0.7603988073561316, 0.9692855274240506], 
             UndirectedEdge[24, 65] -> 
             RGBColor[
              0.6792492907984328, 0.7485864791577197, 0.969189620901362], 
             UndirectedEdge[42, 347] -> 
             RGBColor[
              0.3496381276838004, 0.47041278562627853`, 0.9438070842872799], 
             UndirectedEdge[52, 129] -> 
             RGBColor[
              0.4140638443927525, 0.5324026740365712, 0.9477872164080632], 
             UndirectedEdge[3, 7] -> 
             RGBColor[
              0.6758221805877433, 0.7419355649429475, 0.9533115332847077], 
             UndirectedEdge[156, 352] -> 
             RGBColor[
              0.5993313577207418, 0.6845187935991386, 0.9623421357478754], 
             UndirectedEdge[229, 329] -> 
             RGBColor[
              0.3385397539727553, 0.46764785221358485`, 0.9427924316575618], 
             UndirectedEdge[80, 187] -> 
             RGBColor[
              0.40151464302864714`, 0.516305258682543, 0.9475472075178186], 
             UndirectedEdge[247, 362] -> 
             RGBColor[
              0.4390171713336841, 0.5467228480423997, 0.9505021520590358], 
             UndirectedEdge[43, 321] -> 
             RGBColor[
              0.3857025463059065, 0.5025410085285669, 0.9463868279266178], 
             UndirectedEdge[84, 270] -> 
             RGBColor[
              0.6521962304644358, 0.7242202473440331, 0.9685055437554582], 
             UndirectedEdge[318, 322] -> 
             RGBColor[
              0.6955113275658166, 0.7576186721349583, 0.9345623815885207], 
             UndirectedEdge[218, 276] -> 
             RGBColor[
              0.4027949419704606, 0.5233024664975447, 0.9468867154181437], 
             UndirectedEdge[201, 303] -> 
             RGBColor[
              0.39325858945499653`, 0.5139912009440664, 0.9464977850279097], 
             UndirectedEdge[283, 364] -> 
             RGBColor[
              0.5932036302395803, 0.6709320043667649, 0.964942480620868], 
             UndirectedEdge[65, 340] -> 
             RGBColor[
              0.5365152629599902, 0.6346062860649045, 0.9566555933018264], 
             UndirectedEdge[83, 214] -> 
             RGBColor[
              0.39218469316913684`, 0.5141124022724489, 0.9462106397467981], 
             UndirectedEdge[124, 157] -> 
             RGBColor[
              0.9660362458632563, 0.9733904470794095, 0.9065493715294273], 
             UndirectedEdge[311, 344] -> 
             RGBColor[
              0.35874843514074184`, 0.485151596123446, 0.9440801109517507], 
             UndirectedEdge[190, 226] -> 
             RGBColor[
              0.4131747110893075, 0.5314187391407037, 0.9477896386005942], 
             UndirectedEdge[380, 389] -> 
             RGBColor[
              0.3399113514910004, 0.46836132462566515`, 0.9428972037414687], 
             UndirectedEdge[124, 179] -> 
             RGBColor[
              0.6421962775744346, 0.7087605823287368, 0.8859858234975502], 
             UndirectedEdge[199, 215] -> 
             RGBColor[
              0.6527105768083135, 0.6868738402082502, 0.6390067684667294], 
             UndirectedEdge[146, 267] -> 
             RGBColor[
              0.472001122199131, 0.5820669722243232, 0.9516220699941764], 
             UndirectedEdge[109, 249] -> 
             RGBColor[
              0.745204837378062, 0.8008789498170563, 0.9752387119208513], 
             UndirectedEdge[36, 61] -> 
             RGBColor[
              0.6922832317014866, 0.7585884917186079, 0.9706119268210949], 
             UndirectedEdge[13, 232] -> 
             RGBColor[
              0.6457520873128995, 0.7180066025387246, 0.9683858968592216], 
             UndirectedEdge[38, 119] -> 
             RGBColor[
              0.6316479178676686, 0.6682927973536585, 0.639411720483499], 
             UndirectedEdge[91, 256] -> 
             RGBColor[
              0.8054572433555985, 0.8488487961264825, 0.9792205524846804], 
             UndirectedEdge[6, 69] -> 
             RGBColor[
              0.6697988299400681, 0.7345900894158093, 0.9129229667314106], 
             UndirectedEdge[90, 97] -> 
             RGBColor[
              0.351934715309541, 0.47924989447317623`, 0.9436459467492425], 
             UndirectedEdge[233, 257] -> 
             RGBColor[
              0.6192351809465705, 0.7013074458945054, 0.9634784180826385], 
             UndirectedEdge[66, 119] -> 
             RGBColor[
              0.37311181716202896`, 0.49614335430920886`, 0.9450483909215339],
              UndirectedEdge[33, 116] -> 
             RGBColor[
              0.8214678106900708, 0.860800235265692, 0.9827485864979064], 
             UndirectedEdge[335, 349] -> 
             RGBColor[
              0.792012369376702, 0.8377053518204027, 0.979835052664923], 
             UndirectedEdge[165, 274] -> 
             RGBColor[
              0.6184073299602224, 0.7002167074193202, 0.9636994811085575], 
             UndirectedEdge[95, 169] -> 
             RGBColor[
              0.484846722608621, 0.5887935212978661, 0.9537216354971989], 
             UndirectedEdge[135, 259] -> 
             RGBColor[
              0.6335701599960888, 0.7132436146318801, 0.9644029113489372], 
             UndirectedEdge[93, 273] -> 
             RGBColor[
              0.5922559321931715, 0.670764910267163, 0.9647629233342354], 
             UndirectedEdge[89, 263] -> 
             RGBColor[
              0.6986849330425232, 0.7643652090971775, 0.9707196658539201], 
             UndirectedEdge[71, 289] -> 
             RGBColor[
              0.6052083132132746, 0.6856435090321842, 0.9645347185108446], 
             UndirectedEdge[32, 215] -> 
             RGBColor[
              0.7819365980145341, 0.794968499036324, 0.6483003995002528], 
             UndirectedEdge[8, 239] -> 
             RGBColor[
              0.5800229311803786, 0.6619908491105049, 0.9634476349510568], 
             UndirectedEdge[110, 111] -> 
             RGBColor[
              0.41390324254193067`, 0.5258886990205041, 0.9485656465244949], 
             UndirectedEdge[29, 162] -> 
             RGBColor[
              0.6882165762341046, 0.7497604457163555, 0.8853476860266052], 
             UndirectedEdge[337, 353] -> 
             RGBColor[
              0.6015233194795312, 0.6745663932774263, 0.9639491890719899], 
             UndirectedEdge[306, 308] -> 
             RGBColor[
              0.6356313518490273, 0.7074391642828655, 0.9553460286473927], 
             UndirectedEdge[185, 190] -> 
             RGBColor[
              0.6121670542577776, 0.6945461372887778, 0.9636214780222833], 
             UndirectedEdge[71, 385] -> 
             RGBColor[
              0.5112172180600588, 0.6121219272871584, 0.9552017977051719], 
             UndirectedEdge[146, 158] -> 
             RGBColor[
              0.7187209632936074, 0.770149159641908, 0.6829930280471698], 
             UndirectedEdge[157, 386] -> 
             RGBColor[
              0.7241916587161918, 0.7831688741339273, 0.9677299325281201], 
             UndirectedEdge[24, 124] -> 
             RGBColor[
              0.8776244391534109, 0.9035176034158849, 0.904586986447155], 
             UndirectedEdge[22, 74] -> 
             RGBColor[
              0.46432493005331654`, 0.5689088935987567, 0.9523773946679155], 
             UndirectedEdge[303, 385] -> 
             RGBColor[
              0.5609029743425658, 0.654405328819157, 0.9585754832769932], 
             UndirectedEdge[130, 317] -> 
             RGBColor[
              0.38924973412424513`, 0.5058738702591293, 0.9466248320330777], 
             UndirectedEdge[73, 291] -> 
             RGBColor[
              0.6333034102087114, 0.7064654999167012, 0.9679419421741919], 
             UndirectedEdge[241, 255] -> 
             RGBColor[
              0.6395684694525848, 0.7136921029923883, 0.9675124504150718], 
             UndirectedEdge[385, 400] -> 
             RGBColor[
              0.5514807119543018, 0.6467559117442809, 0.9578337282669046], 
             UndirectedEdge[130, 311] -> 
             RGBColor[
              0.4475298450125076, 0.5604114974612322, 0.9501897940275329], 
             UndirectedEdge[143, 308] -> 
             RGBColor[
              0.35687201022694914`, 0.48352633117497723`, 0.9439605468155013],
              UndirectedEdge[297, 397] -> 
             RGBColor[
              0.989425022008756, 0.989894989083152, 0.8249182826880732], 
             UndirectedEdge[237, 324] -> 
             RGBColor[
              0.5774465532939345, 0.6659499138411091, 0.9609124650635957], 
             UndirectedEdge[107, 160] -> 
             RGBColor[
              0.5700539766002326, 0.6618345246998847, 0.9592958836959424], 
             UndirectedEdge[125, 185] -> 
             RGBColor[
              0.6513645867264968, 0.7263684599755984, 0.9667072513635133], 
             UndirectedEdge[269, 388] -> 
             RGBColor[
              0.61471605875951, 0.6916103661687751, 0.9661847548488857], 
             UndirectedEdge[47, 300] -> 
             RGBColor[
              0.5103012810047716, 0.6086912652464689, 0.9562534387869739], 
             UndirectedEdge[37, 365] -> 
             RGBColor[
              0.6158463783807888, 0.6980694070516991, 0.963544505412321], 
             UndirectedEdge[356, 389] -> 
             RGBColor[
              0.4547374684701623, 0.5661217043348492, 0.9507962369169188], 
             UndirectedEdge[227, 243] -> 
             RGBColor[
              0.5194939949226632, 0.6207876538728159, 0.9553156167309689], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.39275889895787164`, 0.5146097504662288, 0.946247227631906], 
             UndirectedEdge[186, 348] -> 
             RGBColor[
              0.815563997716472, 0.8562475509863934, 0.9821443815433542], 
             UndirectedEdge[61, 90] -> 
             RGBColor[
              0.5668028503454337, 0.6533568105809693, 0.961662320986036], 
             UndirectedEdge[72, 325] -> 
             RGBColor[
              0.4764223870241884, 0.5858201822270102, 0.9519248619807024], 
             UndirectedEdge[341, 358] -> 
             RGBColor[
              0.9594861418557691, 0.9677617895364956, 0.8866415452614833], 
             UndirectedEdge[102, 337] -> 
             RGBColor[
              0.8489188859719753, 0.8827922451334784, 0.9830909258131724], 
             UndirectedEdge[297, 378] -> 
             RGBColor[
              0.9781907834321364, 0.9826388318085714, 0.8941946767579578], 
             UndirectedEdge[300, 370] -> 
             RGBColor[
              0.6444686819339915, 0.7138001368024451, 0.937031567945012], 
             UndirectedEdge[46, 52] -> 
             RGBColor[
              0.6680560250660521, 0.7331603520713195, 0.9157447147545961], 
             UndirectedEdge[75, 200] -> 
             RGBColor[
              0.6587707730204595, 0.7255822022186029, 0.9291032347822448], 
             UndirectedEdge[204, 343] -> 
             RGBColor[
              0.3532914174490158, 0.480069793753554, 0.9437454005119754], 
             UndirectedEdge[32, 199] -> 
             RGBColor[
              0.4653109313010464, 0.5736162486586369, 0.9519296422099166], 
             UndirectedEdge[301, 313] -> 
             RGBColor[
              0.829744690685978, 0.8676938522572114, 0.9834600619415779], 
             UndirectedEdge[166, 363] -> 
             RGBColor[
              0.2978808133505939, 0.430421999938852, 0.9402752436939195], 
             UndirectedEdge[333, 353] -> 
             RGBColor[
              0.4738084714359392, 0.5739034910180834, 0.9537047997907477], 
             UndirectedEdge[130, 146] -> 
             RGBColor[
              0.48046603442341773`, 0.5889391693079492, 0.9522884588924674], 
             UndirectedEdge[71, 271] -> 
             RGBColor[
              0.6811411854105229, 0.7450313159195265, 0.9315938583888009], 
             UndirectedEdge[123, 332] -> 
             RGBColor[
              0.6503750572362795, 0.725594700912775, 0.9666091241716532], 
             UndirectedEdge[340, 361] -> 
             RGBColor[
              0.616265163664643, 0.6976750110076839, 0.9640795766249297], 
             UndirectedEdge[165, 322] -> 
             RGBColor[
              0.5560402801941435, 0.6484818955625549, 0.9590943235328652], 
             UndirectedEdge[278, 302] -> 
             RGBColor[
              0.9921973703025385, 0.9910414263487324, 0.7789732968527006], 
             UndirectedEdge[322, 355] -> 
             RGBColor[
              0.5557300991107654, 0.6482395797427564, 0.9590634075812811], 
             UndirectedEdge[68, 333] -> 
             RGBColor[
              0.614764891377636, 0.6975138880015535, 0.9632388848963296], 
             UndirectedEdge[150, 156] -> 
             RGBColor[
              0.5687615832839943, 0.6606374534702606, 0.9592952263228047], 
             UndirectedEdge[29, 357] -> 
             RGBColor[
              0.6364351832484435, 0.7025702109097217, 0.8821338928038435], 
             UndirectedEdge[250, 325] -> 
             RGBColor[
              0.6867668371516131, 0.7534215898139909, 0.9708561489793548], 
             UndirectedEdge[53, 131] -> 
             RGBColor[
              0.4425451467309378, 0.5569647743440211, 0.9496315765638476], 
             UndirectedEdge[92, 267] -> 
             RGBColor[
              0.7102493822011839, 0.7721793981124185, 0.9730574183022729], 
             UndirectedEdge[269, 309] -> 
             RGBColor[
              0.5521030622045828, 0.6420924047148231, 0.9601044159684846], 
             UndirectedEdge[162, 336] -> 
             RGBColor[
              0.37545642070231466`, 0.49962321344910865`, 0.9451447290174426],
              UndirectedEdge[94, 204] -> 
             RGBColor[
              0.6203326623757468, 0.6947076665856398, 0.9671494583567627], 
             UndirectedEdge[29, 183] -> 
             RGBColor[
              0.9915703420992872, 0.9894254977854213, 0.6907516401659664], 
             UndirectedEdge[145, 208] -> 
             RGBColor[
              0.8192805941969745, 0.8585101341944854, 0.9246718106354358], 
             UndirectedEdge[75, 133] -> 
             RGBColor[
              0.4193525072957348, 0.5362942653685611, 0.9483146285536654], 
             UndirectedEdge[169, 326] -> 
             RGBColor[
              0.41710106058316465`, 0.5339551065772443, 0.9482786692314206], 
             UndirectedEdge[95, 97] -> 
             RGBColor[
              0.5135885762632695, 0.6136882703259541, 0.9555530409966498], 
             UndirectedEdge[37, 78] -> 
             RGBColor[
              0.6882308949868694, 0.7548479180728579, 0.9706977704192388], 
             UndirectedEdge[55, 397] -> 
             RGBColor[
              0.6383165269450038, 0.704064318816614, 0.8696345391501147], 
             UndirectedEdge[185, 226] -> 
             RGBColor[
              0.5398290624408723, 0.6327647662553801, 0.9587706316770177], 
             UndirectedEdge[39, 254] -> 
             RGBColor[
              0.5269068585210173, 0.6231178000150415, 0.9572930702365039], 
             UndirectedEdge[71, 201] -> 
             RGBColor[
              0.34357283317248954`, 0.4717077994120677, 0.9431240994560884], 
             UndirectedEdge[227, 383] -> 
             RGBColor[
              0.5000257652611602, 0.6049824679998561, 0.9537830063775403], 
             UndirectedEdge[38, 151] -> 
             RGBColor[
              0.8175199322861617, 0.8246481550916216, 0.6530241995201511], 
             UndirectedEdge[45, 74] -> 
             RGBColor[
              0.32879415877254314`, 0.4568025434178551, 0.9422594791724637], 
             UndirectedEdge[292, 303] -> 
             RGBColor[
              0.37078136348499013`, 0.490366211311151, 0.9452177402609938], 
             UndirectedEdge[185, 357] -> 
             RGBColor[
              0.5111302582397282, 0.6055675096892494, 0.9570276406004736], 
             UndirectedEdge[86, 376] -> 
             RGBColor[
              0.5663915776335179, 0.6571437700490492, 0.9598825235480882], 
             UndirectedEdge[212, 309] -> 
             RGBColor[
              0.5629798000609011, 0.6515132883652259, 0.9607974720867676], 
             UndirectedEdge[50, 127] -> 
             RGBColor[
              0.7131176111685125, 0.7557223310074155, 0.668044869554632], 
             UndirectedEdge[92, 374] -> 
             RGBColor[
              0.942498341461521, 0.9563286016892043, 0.9715639550231516], 
             UndirectedEdge[118, 141] -> 
             RGBColor[
              0.6474150824861897, 0.7169517367620755, 0.9459697711062949], 
             UndirectedEdge[205, 390] -> 
             RGBColor[
              0.5231985373328728, 0.6237951682891576, 0.9556072518796865]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {3}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.652660695093868, 0.7285827625031123, 0.9660147766921426], 316 -> 
             RGBColor[
              0.5156685864717887, 0.6176820149597091, 0.9550144665647831], 
             308 -> RGBColor[
              0.3209662928452309, 0.4524266034527617, 0.9416726662541175], 
             160 -> RGBColor[
              0.5386123884990045, 0.6363088270519053, 0.9568206867062816], 
             245 -> RGBColor[
              0.3847858576891181, 0.5077039028559407, 0.9457391924925446], 
             155 -> RGBColor[
              0.4194677267496983, 0.5377435946747916, 0.9479490905211121], 
             213 -> RGBColor[
              0.3680487357635102, 0.49320704907618707`, 0.9446727178835007], 
             352 -> RGBColor[
              0.7131500125352707, 0.7758374770241758, 0.9720437865498912], 27 -> 
             RGBColor[
              0.9367140013861074, 0.9523219863718467, 0.9920108674080792], 
             367 -> RGBColor[
              0.9844245209809648, 0.9878271534011457, 0.9077895256004032], 19 -> 
             RGBColor[
              0.6593721513679541, 0.7338258031533853, 0.9666837119314188], 
             164 -> RGBColor[
              0.7696466012307213, 0.8199730415030392, 0.9776748385204148], 
             190 -> RGBColor[
              0.4855127029062129, 0.5932001101741015, 0.9526404849458597], 
             103 -> RGBColor[0.178927, 0.305394, 0.933501], 138 -> 
             RGBColor[
              0.35950231963175616`, 0.4858045729782263, 0.9441281478048843], 
             291 -> RGBColor[
              0.3356847870356098, 0.46517502334743993`, 0.942610515688875], 
             28 -> RGBColor[
              0.9940813256441231, 0.9918204902979214, 0.7477512813225085], 
             337 -> RGBColor[
              0.9381949005489294, 0.9534264385427295, 0.9895040914057819], 
             195 -> RGBColor[
              0.9786722629456028, 0.9397186763040262, 0.37164619825920275`], 
             114 -> RGBColor[
              0.3153198217449713, 0.4475359139856061, 0.9413128781085872], 93 -> 
             RGBColor[
              0.29263139107118624`, 0.4249045242905986, 0.9399762968609316], 
             34 -> RGBColor[
              0.3015030825420183, 0.4342292345241706, 0.9404815265657042], 
             161 -> RGBColor[
              0.9943393357712313, 0.9903007365326373, 0.6252498161478016], 22 -> 
             RGBColor[
              0.6459069579259126, 0.7233066916972019, 0.965341627288503], 124 -> 
             RGBColor[
              0.989007450079598, 0.989722312359336, 0.8318385301957327], 84 -> 
             RGBColor[
              0.8904800695809433, 0.915508652319012, 0.9894159780492147], 46 -> 
             RGBColor[
              0.9856225207724901, 0.9883225571021317, 0.8879355687307513], 
             241 -> RGBColor[
              0.40056167019157335`, 0.521368118730176, 0.9467444133151978], 
             185 -> RGBColor[
              0.7388214056093424, 0.7958921644034542, 0.9746024710987068], 
             390 -> RGBColor[
              0.5852752547444637, 0.6741918440081376, 0.9604941584688353], 
             121 -> RGBColor[
              0.6910578136350795, 0.7585788833364161, 0.9698418426268568], 
             322 -> RGBColor[
              0.4127163034491305, 0.5318958511482414, 0.9475188957984492], 
             126 -> RGBColor[
              0.30718223579510057`, 0.44019838467227357`, 0.9408049459419128],
              236 -> RGBColor[
              0.4530275672621159, 0.5668114417600186, 0.9500874938827616], 78 -> 
             RGBColor[
              0.8485856520582441, 0.8821031809800809, 0.9854200511063116], 
             376 -> RGBColor[
              0.426263460746706, 0.5436297178994776, 0.9483821086821699], 254 -> 
             RGBColor[
              0.35138407970929925`, 0.4787729615919968, 0.9436108607357031], 
             290 -> RGBColor[
              0.8777048502505482, 0.9053220391990459, 0.9881974662249086], 
             251 -> RGBColor[
              0.29263139107118624`, 0.4249045242905986, 0.9399762968609316], 
             165 -> RGBColor[
              0.6993642569391566, 0.7650679399768684, 0.9706697512672812], 
             100 -> RGBColor[
              0.950698176454155, 0.9627513612406114, 0.968339306674865], 235 -> 
             RGBColor[
              0.41330866319908544`, 0.5324089233907857, 0.9475566404379131], 
             70 -> RGBColor[
              0.46071143381387764`, 0.5730653226405035, 0.9506880381928688], 
             234 -> RGBColor[
              0.38029453216342407`, 0.5038137424261692, 0.9454530092015706], 
             257 -> RGBColor[
              0.6720348440103685, 0.7437179948856679, 0.967945810794424], 135 -> 
             RGBColor[
              0.6525562666959804, 0.7285011822449973, 0.96600436824538], 265 -> 
             RGBColor[
              0.3606181326677548, 0.48677103414761447`, 0.9441992464248634], 
             111 -> RGBColor[
              0.5629547466737284, 0.656071050028885, 0.958737006310792], 381 -> 
             RGBColor[
              0.6153606818862422, 0.6986165490948808, 0.962862593499987], 182 -> 
             RGBColor[
              0.8802605642250505, 0.9073598961493061, 0.9884412325053095], 
             188 -> RGBColor[
              0.7840229417453641, 0.8312039479773129, 0.979107737788374], 154 -> 
             RGBColor[
              0.2986305667672401, 0.43121003831685945`, 0.9403179410418367], 
             336 -> RGBColor[
              0.363910944563193, 0.489623102309905, 0.9444090614871216], 315 -> 
             RGBColor[
              0.45211185410589927`, 0.5660182970491853, 0.9500291454501808], 
             368 -> RGBColor[
              0.3609905861037574, 0.48709363459382593`, 0.9442229788284578], 
             269 -> RGBColor[
              0.3346936329980411, 0.4643165355369484, 0.9425473602300443], 
             208 -> RGBColor[
              0.985900493300081, 0.9884375058858587, 0.883328844578729], 86 -> 
             RGBColor[
              0.7065196945203298, 0.7706578221986208, 0.9713829384140066], 
             119 -> RGBColor[
              0.29307294094795683`, 0.4253686212069636, 0.9400014424731992], 
             377 -> RGBColor[
              0.9346541014160673, 0.778632317884221, 0.2662793600152321], 140 -> 
             RGBColor[
              0.9079254189219125, 0.929419100342108, 0.9910799310430035], 85 -> 
             RGBColor[
              0.787434959711638, 0.8338694423448632, 0.9794478158521314], 351 -> 
             RGBColor[
              0.7743173598414085, 0.8236218736287882, 0.9781403760880073], 
             242 -> RGBColor[
              0.5332798846230304, 0.6319796601788275, 0.9564008924675597], 
             117 -> RGBColor[
              0.47763815942589105`, 0.586807201032635, 0.9520205720376855], 
             47 -> RGBColor[
              0.7034566457290167, 0.7682649452028139, 0.9710776423363069], 81 -> 
             RGBColor[
              0.44637045343284343`, 0.5610453843573727, 0.949663308476215], 
             275 -> RGBColor[
              0.8236368059668002, 0.8622096483251499, 0.9830404078940118], 23 -> 
             RGBColor[
              0.9097323367611593, 0.9308598875796452, 0.9912522764795654], 
             328 -> 
             RGBColor[
              0.607010179325485, 0.6918372349302048, 0.9622052113495054], 110 -> 
             RGBColor[
              0.26485173841013293`, 0.3957063480121231, 0.9383942867381979], 
             6 -> RGBColor[
              0.3536225610982504, 0.48071182166176035`, 0.9437534947903957], 
             218 -> RGBColor[
              0.35870489098527797`, 0.48511388036457603`, 0.9440773363566692],
              108 -> RGBColor[
              0.4256276784130769, 0.5430790351974373, 0.9483415971940712], 
             297 -> RGBColor[
              0.98790263146823, 0.9892654414709922, 0.8501482337650147], 157 -> 
             RGBColor[
              0.9430650416469146, 0.9570585817994828, 0.9812602128631217], 
             354 -> RGBColor[
              0.9388024223413743, 0.9538795273008093, 0.9884757154782328], 
             385 -> RGBColor[
              0.6407959281869726, 0.7192660278866017, 0.9648649492611577], 
             270 -> RGBColor[
              0.4139123913479283, 0.5329318423690543, 0.9475951094617016], 
             392 -> RGBColor[
              0.43740062302199156`, 0.5532761680922779, 0.9490917588141451], 
             33 -> RGBColor[
              0.8625532100532968, 0.8932405325860743, 0.9867522892568659], 
             252 -> RGBColor[
              0.5893383799513596, 0.6774904720928003, 0.9608140225688402], 
             394 -> RGBColor[
              0.39620858785227886`, 0.5175976976001592, 0.9464670387578176], 
             260 -> RGBColor[
              0.41248214523252136`, 0.5316930350701489, 0.9475039754439448], 
             159 -> RGBColor[
              0.3258072981210929, 0.4566196389067134, 0.9419811308295625], 
             183 -> RGBColor[
              0.9937094285718016, 0.9889534287264441, 0.5566883048264862], 99 -> 
             RGBColor[
              0.8639111858972571, 0.8943233456627759, 0.9868818142051422], 
             329 -> RGBColor[
              0.32965910947565835`, 0.45995588430437023`, 0.9422265648430523],
              309 -> RGBColor[
              0.7695124914111247, 0.8198682738926979, 0.977661471706925], 17 -> 
             RGBColor[
              0.28343911087011414`, 0.41524285497504476`, 0.9394528101022405],
              349 -> RGBColor[
              0.7318727032369162, 0.790463785298021, 0.973909889385539], 347 -> 
             RGBColor[
              0.23724016108490803`, 0.3666848295681952, 0.9368218482571945], 
             340 -> RGBColor[
              0.48077337255033875`, 0.5893525082868033, 0.9522673874995061], 
             277 -> 
             RGBColor[
              0.8113318953863587, 0.8525379101173929, 0.9818296390706268], 
             104 -> RGBColor[
              0.4870505718989168, 0.594448621502587, 0.9527615516263651], 79 -> 
             RGBColor[
              0.8359187331698229, 0.8720029236928074, 0.9842118690748419], 
             327 -> RGBColor[
              0.5538873250988838, 0.6487097087117393, 0.9580231856693605], 
             191 -> RGBColor[
              0.41637843637734107`, 0.5350678066265045, 0.9477522436703377], 
             50 -> RGBColor[
              0.44371478019138677`, 0.5587451736736411, 0.949494091325589], 
             225 -> RGBColor[
              0.5332798846230304, 0.6319796601788275, 0.9564008924675597], 61 -> 
             RGBColor[
              0.8040727654692553, 0.8468670226547209, 0.981106116840916], 196 -> 
             RGBColor[
              0.29072317296547573`, 0.42289886607348104`, 0.9398676266627671],
              1 -> RGBColor[
              0.9875211468791724, 0.9891076877897101, 0.8564704206561676], 
             263 -> RGBColor[
              0.6311284378578226, 0.7114175237219215, 0.9641038890092631], 
             201 -> RGBColor[
              0.30550715841183407`, 0.4384377721364202, 0.9407095527629907], 
             371 -> RGBColor[
              0.3972849158131125, 0.5185299587820169, 0.9465356214237224], 
             293 -> RGBColor[
              0.30914521777139464`, 0.44218778236831346`, 0.9409194378033788],
              362 -> RGBColor[
              0.6094577206822531, 0.6938242592641107, 0.9623978907707497], 
             184 -> RGBColor[
              0.46075150168267126`, 0.5730978515414271, 0.9506911924822737], 
             106 -> RGBColor[
              0.2778790954886905, 0.40939892628383245`, 0.939136175451574], 
             206 -> RGBColor[
              0.7330999609751816, 0.7914225283706582, 0.9740322109675137], 
             358 -> RGBColor[
              0.9268608255577616, 0.9445176796056134, 0.9928860070317678], 
             247 -> RGBColor[
              0.2685766219851151, 0.3996214368206887, 0.9386064133473218], 
             220 -> RGBColor[
              0.34037965812686666`, 0.46924148471560445`, 0.9429096687232984],
              107 -> RGBColor[
              0.6014955647014607, 0.6873602223478641, 0.9617710806856032], 
             375 -> RGBColor[
              0.748835707994338, 0.8037154135381299, 0.9756006031714666], 131 -> 
             RGBColor[
              0.4815778658444329, 0.5900056321849588, 0.9523307201585732], 
             127 -> 
             RGBColor[
              0.9825204421456383, 0.9526994883411898, 0.38659564778367506`], 
             210 -> RGBColor[
              0.863131959480874, 0.8937020116698896, 0.9868074908939239], 357 -> 
             RGBColor[
              0.28343911087011414`, 0.41524285497504476`, 0.9394528101022405],
              181 -> RGBColor[
              0.6665689829209167, 0.7394480226605054, 0.9674010248424034], 
             194 -> RGBColor[
              0.6747591671677801, 0.7458462568418607, 0.9682173458665073], 
             118 -> RGBColor[
              0.3330024737157232, 0.4628517383667417, 0.9424396010560083], 
             348 -> RGBColor[
              0.7612233041077471, 0.8133926977711425, 0.9768352829833838], 
             276 -> RGBColor[
              0.4468849929556433, 0.5614910526305136, 0.9496960944796183], 
             305 -> RGBColor[
              0.29934322486174525`, 0.4319590871593173, 0.9403585258660356], 
             343 -> RGBColor[
              0.40167871346082984`, 0.5223356454657788, 0.9468155903245522], 
             280 -> RGBColor[
              0.8516855450977857, 0.8845749515454564, 0.9857157216717302], 
             189 -> RGBColor[
              0.697122880323872, 0.7633169595299149, 0.970446351793125], 168 -> 
             RGBColor[
              0.3741046112590836, 0.4984523440533002, 0.9450585929150782], 
             363 -> RGBColor[
              0.30777033438660084`, 0.44081651357954466`, 0.9408384372866848],
              41 -> RGBColor[
              0.8803903843553195, 0.907463411197309, 0.9884536148652263], 14 -> 
             RGBColor[
              0.29118494809259216`, 0.4233842210103145, 0.9398939240731213], 
             77 -> RGBColor[
              0.6217329003751657, 0.7037898031293606, 0.9633642378816405], 51 -> 
             RGBColor[
              0.4946791202818076, 0.6006418207420061, 0.9533620988993597], 
             179 -> RGBColor[
              0.29538510506927135`, 0.4277988522981377, 0.9401331167993677], 
             223 -> RGBColor[
              0.2970209691695903, 0.4295182491873475, 0.9402262768398368], 
             323 -> RGBColor[
              0.6608173126798839, 0.7349547741538975, 0.9668277521051916], 
             292 -> RGBColor[
              0.2605527064718213, 0.39118779287058963`, 0.9381494632291589], 
             396 -> RGBColor[
              0.48676812785546864`, 0.5942193207041566, 0.9527393165966382], 
             321 -> RGBColor[
              0.5103414821002014, 0.6133572316475373, 0.9545950973948254], 
             143 -> 
             RGBColor[
              0.3927777276086674, 0.5146260588971927, 0.9462484273768852], 
             112 -> RGBColor[
              0.6050063027572553, 0.6902103976585052, 0.9620474588456127], 
             197 -> RGBColor[
              0.7852969301703976, 0.8321991974176197, 0.9792347170484825], 54 -> 
             RGBColor[
              0.34577756808125604`, 0.4739168830112537, 0.9432536187724078], 
             71 -> RGBColor[
              0.3816385079331451, 0.5049778266877152, 0.9455386461491861], 
             177 -> RGBColor[
              0.2754192782779116, 0.40681350243388475`, 0.9389960925003936], 
             158 -> RGBColor[
              0.9901575875787365, 0.9784613731740531, 0.41626451563736233`], 
             226 -> RGBColor[
              0.34083671927240206`, 0.46963736810730605`, 0.9429387922553286],
              350 -> RGBColor[
              0.3966379198751523, 0.5179695634195173, 0.9464943954146716], 
             203 -> RGBColor[
              0.7699147526615284, 0.820182523438812, 0.9777015653490201], 115 -> 
             RGBColor[
              0.44877060258525026`, 0.5631242729181835, 0.9498162438578378], 
             173 -> RGBColor[
              0.3474203984698523, 0.4753398201227995, 0.9433582984720712], 
             212 -> RGBColor[
              0.35644710871067753`, 0.48315830283775385`, 0.9439334724666102],
              129 -> RGBColor[
              0.47763815942589105`, 0.586807201032635, 0.9520205720376855], 
             279 -> RGBColor[
              0.7696466012307213, 0.8199730415030392, 0.9776748385204148], 26 -> 
             RGBColor[
              0.7840229417453641, 0.8312039479773129, 0.979107737788374], 40 -> 
             RGBColor[
              0.8050558680964723, 0.8476350298989596, 0.9812041033231805], 
             146 -> RGBColor[
              0.4472843390084782, 0.5618369461097629, 0.9497215404569772], 
             386 -> RGBColor[
              0.505318275785469, 0.6092791664683719, 0.9541996521931186], 192 -> 
             RGBColor[
              0.48360823540557435`, 0.5916539776617998, 0.9524905582879151], 
             300 -> RGBColor[
              0.3171459162805264, 0.44911758529012397`, 0.9414292352376409], 
             221 -> RGBColor[
              0.7557126063556753, 0.8090876988043699, 0.9762860281318557], 62 -> 
             RGBColor[
              0.7269503984968376, 0.7866184434241699, 0.9734192800506011], 
             286 -> RGBColor[
              0.983978667061875, 0.9875718966440471, 0.9120041170181041], 152 -> 
             RGBColor[
              0.33233373199219496`, 0.4622725078977578, 0.9423969894247303], 
             64 -> RGBColor[
              0.6501443555940314, 0.7266169789609513, 0.9657639714873285], 
             307 -> RGBColor[
              0.49339468062756114`, 0.5995990547673418, 0.95326098310472], 37 -> 
             RGBColor[
              0.5278761379154946, 0.6275926551656349, 0.955975489732166], 148 -> 
             RGBColor[
              0.9263027119928161, 0.944072654998515, 0.9928327736617094], 261 -> 
             RGBColor[
              0.6672070737908513, 0.7399465040977684, 0.9674646237770202], 
             387 -> RGBColor[
              0.9944248099391124, 0.9919625298810433, 0.742058857645675], 15 -> 
             RGBColor[
              0.48360823540557435`, 0.5916539776617998, 0.9524905582879151], 
             136 -> RGBColor[
              0.26920836194947106`, 0.400285435577854, 0.9386423900037163], 
             198 -> RGBColor[
              0.9505540718379665, 0.9626438882538078, 0.9685832382015689], 63 -> 
             RGBColor[
              0.40930857625902967`, 0.5289442491335248, 0.9473017584352308], 
             310 -> RGBColor[
              0.9386600968036779, 0.9537733811478321, 0.9887166354891075], 
             171 -> RGBColor[
              0.8856170994785906, 0.911631051961203, 0.9889521436196276], 395 -> 
             RGBColor[
              0.9435626403360163, 0.9574296900870717, 0.9804179080769958], 
             311 -> RGBColor[
              0.3814119601866579, 0.5047816024163289, 0.9455242107271082], 
             353 -> RGBColor[
              0.26485173841013293`, 0.3957063480121231, 0.9383942867381979], 
             59 -> RGBColor[
              0.6369524985693538, 0.7161457585784875, 0.9645623804027121], 
             397 -> RGBColor[
              0.9909474125492821, 0.9905245366953118, 0.7996883316111316], 
             229 -> RGBColor[
              0.3474203984698523, 0.4753398201227995, 0.9433582984720712], 
             102 -> RGBColor[
              0.7596428713950212, 0.8121580517242275, 0.9766777602205627], 
             299 -> RGBColor[
              0.8388863950563799, 0.874369256726112, 0.9844949273148448], 128 -> 
             RGBColor[
              0.8607677886927744, 0.8918168860571655, 0.9865819941736348], 12 -> 
             RGBColor[
              0.3879742443169099, 0.5104655230999625, 0.9459423536690879], 
             222 -> RGBColor[
              0.8739349024874432, 0.9023159851852518, 0.9878378852417915], 92 -> 
             RGBColor[
              0.9237808590125841, 0.9420617978859536, 0.9925922370731702], 
             271 -> RGBColor[
              0.9806438628879008, 0.9850848051513379, 0.9176490706284157], 
             361 -> RGBColor[
              0.7517569547789473, 0.8059975137285647, 0.9758917657503532], 
             344 -> RGBColor[
              0.3360849100948258, 0.46552158983056313`, 0.9426360111763933], 
             132 -> RGBColor[
              0.5969838625475337, 0.6836974192894403, 0.9614159029651366], 80 -> 
             RGBColor[
              0.26881617373621797`, 0.39987322089955607`, 0.9386200554651619],
              324 -> RGBColor[
              0.43026413199661856`, 0.5470948982565682, 0.9486370279165596], 
             244 -> RGBColor[
              0.4484156549363376, 0.5628168351048829, 0.949793626907517], 150 -> 
             RGBColor[
              0.6520104636617756, 0.7280747967664197, 0.9659499676997498], 
             125 -> RGBColor[
              0.5639077678436512, 0.6568447555477427, 0.9588120316283198], 
             258 -> RGBColor[
              0.5001943636925306, 0.6051193438017153, 0.9537962790636542], 
             133 -> RGBColor[
              0.5030202275558598, 0.6074135073896823, 0.9540187414184558], 
             255 -> RGBColor[
              0.8785752687135964, 0.9060160872546006, 0.9882804875149459], 
             326 -> RGBColor[
              0.5173493330781562, 0.6190465207715299, 0.955146781094414], 176 -> 
             RGBColor[
              0.7708459984256073, 0.8209100197074405, 0.9777943832237971], 
             230 -> RGBColor[
              0.27715942277195427`, 0.408642504628657, 0.9390951911550163], 
             274 -> RGBColor[
              0.5374504029812882, 0.6353654748617721, 0.9567292109498338], 87 -> 
             RGBColor[
              0.9454554493068931, 0.9588413439183614, 0.9772138762129455], 
             130 -> RGBColor[
              0.5136477298383573, 0.6160413925061355, 0.9548553773279576], 35 -> 
             RGBColor[
              0.47028702627849983`, 0.5808392199788084, 0.9514418639082349], 
             379 -> RGBColor[
              0.962442739426261, 0.9715104370752512, 0.9484588250356945], 31 -> 
             RGBColor[
              0.6193839288875143, 0.7018828022557254, 0.9631793182415666], 18 -> 
             RGBColor[
              0.9596883683717806, 0.9694562316526885, 0.953121256775906], 24 -> 
             RGBColor[
              0.7662414282272239, 0.8173128944724337, 0.9773354426985772], 
             151 -> RGBColor[
              0.6648169697849432, 0.7380793366828897, 0.9672264005465032], 
             137 -> RGBColor[
              0.8863758071393271, 0.9122360248553034, 0.9890245098336149], 
             330 -> RGBColor[
              0.3474203984698523, 0.4753398201227995, 0.9433582984720712], 
             296 -> RGBColor[
              0.9724314052584062, 0.9789599676979259, 0.931550619243158], 266 -> 
             RGBColor[
              0.4802893666595522, 0.5889595705004459, 0.9522292847828114], 
             302 -> RGBColor[
              0.9905212757217349, 0.9903483181659041, 0.8067505216503474], 
             283 -> RGBColor[
              0.8984159681645738, 0.9218365224353705, 0.9901729111405816], 
             388 -> RGBColor[
              0.8947384845209787, 0.918904196800602, 0.9898221494677271], 284 -> 
             RGBColor[
              0.7600050369742497, 0.8124409782272812, 0.9767138575008705], 
             318 -> RGBColor[
              0.9783063516825027, 0.9833414931216752, 0.9216058673785923], 
             238 -> RGBColor[
              0.6054213614986178, 0.6905473610429265, 0.962080133790143], 72 -> 
             RGBColor[
              0.46075150168267126`, 0.5730978515414271, 0.9506911924822737], 
             288 -> RGBColor[
              0.9563307771411884, 0.9669521456104638, 0.9588047829292559], 
             382 -> RGBColor[
              0.5557017621196535, 0.6501827504246563, 0.9581660247981373], 
             389 -> RGBColor[
              0.3762092216567136, 0.500275251798933, 0.9451926968285812], 172 -> 
             RGBColor[
              0.3762092216567136, 0.500275251798933, 0.9451926968285812], 243 -> 
             RGBColor[
              0.4928077591469164, 0.599122565468843, 0.9532147784957994], 88 -> 
             RGBColor[
              0.6060790520145241, 0.6910813038323593, 0.9621319095967549], 
             273 -> RGBColor[
              0.891880473315157, 0.9166252962437273, 0.9895495498075391], 202 -> 
             RGBColor[
              0.4530275672621159, 0.5668114417600186, 0.9500874938827616], 
             393 -> RGBColor[
              0.6609098513616718, 0.7350270660754302, 0.9668369754961691], 98 -> 
             RGBColor[
              0.9789351703905685, 0.9838104650845545, 0.9205414413280224], 30 -> 
             RGBColor[
              0.4247645606232697, 0.5423314459494678, 0.9482866000917298], 
             116 -> RGBColor[
              0.7803824113268449, 0.8283599379453098, 0.978744883738947], 373 -> 
             RGBColor[
              0.38376757254809946`, 0.5068219154472897, 0.9456743082637931], 
             240 -> 
             RGBColor[
              0.508817296849169, 0.6121198293969862, 0.9544751079485896], 317 -> 
             RGBColor[
              0.26485173841013293`, 0.3957063480121231, 0.9383942867381979], 
             391 -> RGBColor[
              0.9811500115187282, 0.9480767040442091, 0.3812717835822381], 73 -> 
             RGBColor[
              0.930922033381813, 0.9477559764859623, 0.9932733686595089], 303 -> 
             RGBColor[
              0.481010020498159, 0.5895446297517124, 0.9522860172928286], 29 -> 
             RGBColor[
              0.9894312556267729, 0.9898975668443987, 0.8248149755054465], 
             360 -> RGBColor[
              0.35081188514080275`, 0.47827735541610034`, 0.9435744010037703],
              320 -> RGBColor[
              0.48223016533400587`, 0.5905351982963514, 0.9523820715638442], 
             75 -> RGBColor[
              0.3356847870356098, 0.46517502334743993`, 0.942610515688875], 
             200 -> RGBColor[
              0.9818567590053092, 0.9859893810897659, 0.9155959538756147], 
             301 -> RGBColor[
              0.7440257259943249, 0.7999578190425025, 0.9751211891175428], 
             156 -> RGBColor[
              0.4855127029062129, 0.5932001101741015, 0.9526404849458597], 25 -> 
             RGBColor[
              0.4985592297929444, 0.6037918684400885, 0.9536675553333859], 38 -> 
             RGBColor[
              0.9702228947873803, 0.9112169735003536, 0.33882199849379907`], 
             365 -> RGBColor[
              0.703816618846083, 0.7685461589377631, 0.971113521092476], 380 -> 
             RGBColor[
              0.3036134813252871, 0.43644739745239736`, 0.940601710654356], 
             370 -> RGBColor[
              0.9717914475874568, 0.9784826883147664, 0.932633900652383], 3 -> 
             RGBColor[
              0.3961153530003351, 0.5175169422575254, 0.946461097915496], 57 -> 
             RGBColor[
              0.36369990487564036`, 0.48944031033971, 0.9443956142248457], 
             227 -> RGBColor[
              0.5461802306984102, 0.6424527422767887, 0.9574164549661383], 39 -> 
             RGBColor[
              0.7024296373327353, 0.767462638438086, 0.9709752797373047], 109 -> 
             RGBColor[
              0.7343287451860383, 0.7923824639352852, 0.9741546846940106], 
             256 -> RGBColor[
              0.9376799769727502, 0.953042409382725, 0.9903757227066756], 339 -> 
             RGBColor[
              0.5964526743325769, 0.683266176766782, 0.9613740858830486], 287 -> 
             RGBColor[
              0.5016727246617888, 0.6063195438359618, 0.9539126610545688], 
             239 -> RGBColor[
              0.30035893001924785`, 0.43302665767927906`, 0.9404163687721543],
              285 -> RGBColor[
              0.39993753875505117`, 0.5208275274496186, 0.9467046442119603], 
             345 -> RGBColor[
              0.30718223579510057`, 0.44019838467227357`, 0.9408049459419128],
              366 -> RGBColor[
              0.982747971868179, 0.986654046183667, 0.9140873629643176], 216 -> 
             RGBColor[
              0.38553569316501773`, 0.5083533726573382, 0.9457869713460154], 
             21 -> RGBColor[
              0.5164538475084326, 0.6183195252448631, 0.9550762851900937], 
             355 -> RGBColor[
              0.6987438947724003, 0.7645833083372713, 0.970607919364113], 175 -> 
             RGBColor[
              0.5466478498398238, 0.6428323765617905, 0.9574532676578956], 7 -> 
             RGBColor[
              0.9555290081751514, 0.9663541876283696, 0.9601619686539196], 13 -> 
             RGBColor[
              0.3826443276072511, 0.505849017135459, 0.9456027360894087], 294 -> 
             RGBColor[
              0.34037965812686666`, 0.46924148471560445`, 0.9429096687232984],
              193 -> RGBColor[
              0.324767475010776, 0.4557189963915861, 0.9419148742204526], 60 -> 
             RGBColor[
              0.31583189026958275`, 0.44797944200431217`, 0.9413455066621711],
              65 -> RGBColor[
              0.5922571533696417, 0.6798600638430058, 0.9610437991041467], 69 -> 
             RGBColor[
              0.9859750987818858, 0.9884683571698584, 0.8820924386724255], 
             217 -> RGBColor[
              0.3856413397350344, 0.5084448784063356, 0.9457937030520374], 
             214 -> RGBColor[
              0.3543326516625589, 0.48132686641837485`, 0.943798741133245], 
             170 -> RGBColor[
              0.937630957748495, 0.9530058509255371, 0.9904586994670783], 359 -> 
             RGBColor[
              0.9690739329912338, 0.976455970378425, 0.9372339440224688], 74 -> 
             RGBColor[
              0.28274290218072046`, 0.41451109550031157`, 0.9394131620473279],
              246 -> RGBColor[
              0.902839537015086, 0.9253637561621912, 0.99059483508651], 264 -> 
             RGBColor[
              0.2676195597941888, 0.39861550377677746`, 0.938551910071395], 
             278 -> RGBColor[
              0.9938734648833422, 0.9917345345315606, 0.7511960720550537], 45 -> 
             RGBColor[
              0.3748454153643658, 0.49909399133539856`, 0.9451057962975994], 
             306 -> RGBColor[
              0.9502964108528236, 0.9624517251129693, 0.969019391040668], 237 -> 
             RGBColor[
              0.7246289745912503, 0.7848049294256499, 0.9731879022106319], 
             228 -> RGBColor[
              0.6930985408098799, 0.7601731149154711, 0.9700452432399612], 
             180 -> RGBColor[
              0.7388214056093424, 0.7958921644034542, 0.9746024710987068], 
             383 -> RGBColor[
              0.4538712998239103, 0.5675121937229234, 0.9501495577889423], 53 -> 
             RGBColor[
              0.40351242761744266`, 0.5239239165030835, 0.9469324329691219], 
             304 -> RGBColor[
              0.2917145277944493, 0.42394084285425876`, 0.9399240828536991], 
             48 -> RGBColor[
              0.3762092216567136, 0.500275251798933, 0.9451926968285812], 5 -> 
             RGBColor[
              0.9596883683717806, 0.9694562316526885, 0.953121256775906], 101 -> 
             RGBColor[
              0.9887711746828277, 0.9896246064107708, 0.8357542249813432], 
             333 -> RGBColor[
              0.6827652044617455, 0.7521006340240435, 0.9690153128432976], 
             267 -> RGBColor[
              0.4967179053897838, 0.6022969983388836, 0.9535225995313755], 
             120 -> RGBColor[
              0.9835597993818809, 0.9872595058141402, 0.9127131507421469], 
             147 -> RGBColor[
              0.2769777357141267, 0.4084515400112554, 0.9390848443458549], 89 -> 
             RGBColor[
              0.7662414282272239, 0.8173128944724337, 0.9773354426985772], 43 -> 
             RGBColor[
              0.26106361051161164`, 0.3917247854095963, 0.9381785584584101], 
             199 -> RGBColor[
              0.3360849100948258, 0.46552158983056313`, 0.9426360111763933], 
             268 -> RGBColor[
              0.23097102128167676`, 0.36009556614857785`, 0.9364648300197617],
              169 -> RGBColor[
              0.3168527880881731, 0.4488636923829588, 0.9414105573684272], 20 -> 
             RGBColor[
              0.9867199317930659, 0.9887763647613166, 0.8697486281111274], 4 -> 
             RGBColor[
              0.5832183341571399, 0.6725219432121317, 0.9603322301454529], 
             167 -> RGBColor[
              0.6716258255341174, 0.743398466543365, 0.9679050436552062], 142 -> 
             RGBColor[
              0.6890937217851618, 0.7570445198556094, 0.9696460803067389], 16 -> 
             RGBColor[
              0.8517709116695357, 0.884643020532556, 0.9857238640115513], 281 -> 
             RGBColor[
              0.9905212757217349, 0.9903483181659041, 0.8067505216503474], 
             289 -> RGBColor[
              0.8287781184934042, 0.8663091913766531, 0.9835307908725032], 
             398 -> RGBColor[
              0.5953425713110758, 0.6823649451243563, 0.9612866945067547], 
             178 -> RGBColor[
              0.9406600839368944, 0.9552649682771065, 0.9853311789527577], 58 -> 
             RGBColor[
              0.845163501590651, 0.879374451089022, 0.9850936433397227], 186 -> 
             RGBColor[
              0.869904691325197, 0.8991024042016443, 0.9874534801033246], 122 -> 
             RGBColor[
              0.7505460115960915, 0.8050515157106085, 0.9757710702507936], 
             249 -> RGBColor[
              0.7560809295700858, 0.8093754356988275, 0.9763227391476921], 
             113 -> RGBColor[
              0.33611502149976236`, 0.465547670816076, 0.9426379298484894], 
             52 -> RGBColor[
              0.35048952935961397`, 0.4779981470405073, 0.943553860778441], 
             187 -> RGBColor[
              0.5342131123210764, 0.6327372964655299, 0.9564743595704754], 
             259 -> RGBColor[
              0.6145840532961973, 0.697986047018763, 0.9628014544524944], 42 -> 
             RGBColor[
              0.4620360942826929, 0.5741407416843618, 0.9507923203173652], 
             134 -> RGBColor[
              0.5157645893195186, 0.6177599543963752, 0.9550220242606264], 
             313 -> RGBColor[
              0.915463655377631, 0.9354298854719203, 0.991798934765613], 248 -> 
             RGBColor[
              0.631856993599363, 0.7120089980939661, 0.9641612435860248], 174 -> 
             RGBColor[
              0.9288385484480992, 0.9460946621545108, 0.9930746440065823], 
             215 -> RGBColor[
              0.969336243521801, 0.9082260905859373, 0.33537752575706553`], 
             399 -> RGBColor[
              0.9855787053254775, 0.9630157281611305, 0.39847642273280937`], 
             83 -> RGBColor[
              0.4300367346757148, 0.546897938126523, 0.9486225383603512], 95 -> 
             RGBColor[
              0.6528406571290689, 0.7287233502127733, 0.9660327136259707], 
             166 -> RGBColor[
              0.2879912923145869, 0.4200274862981594, 0.9397120501011542], 
             384 -> RGBColor[
              0.8113318953863587, 0.8525379101173929, 0.9818296390706268], 
             233 -> RGBColor[
              0.5664355178827725, 0.658896896903343, 0.9590110253708529], 
             295 -> 
             RGBColor[
              0.527839280149159, 0.6275627323705002, 0.9559725881537856], 141 -> 
             RGBColor[
              0.9618276912566563, 0.9710517351574091, 0.9494999411565814], 
             319 -> RGBColor[
              0.37361950045729575`, 0.49803216545916934`, 0.9450276820837549],
              205 -> RGBColor[
              0.4611218199212818, 0.5733984925701777, 0.9507203452905376], 
             224 -> RGBColor[
              0.23063825842457372`, 0.3597458112873788, 0.9364458796673282], 
             231 -> RGBColor[
              0.993603878992784, 0.9887276688496253, 0.5451998845269306], 332 -> 
             RGBColor[
              0.5638600416535128, 0.656806009276548, 0.9588082744478054], 68 -> 
             RGBColor[
              0.5467645782935266, 0.6429271419790634, 0.9574624569493616], 10 -> 
             RGBColor[
              0.3680487357635102, 0.49320704907618707`, 0.9446727178835007], 
             250 -> RGBColor[
              0.8814404019375207, 0.9083006667153883, 0.9885537664795784], 
             282 -> RGBColor[
              0.4997593580729464, 0.604766186642957, 0.9537620338278023], 374 -> 
             RGBColor[
              0.9612158239104579, 0.970595405492455, 0.9505356729731331], 232 -> 
             RGBColor[
              0.9088598470185479, 0.9301641879419901, 0.9911690576290344], 
             253 -> RGBColor[
              0.9263027119928161, 0.944072654998515, 0.9928327736617094], 55 -> 
             RGBColor[
              0.2856856413407256, 0.4176041009379161, 0.9395807466890977], 
             325 -> RGBColor[
              0.4920932723657055, 0.5985425129125933, 0.9531585314791311], 91 -> 
             RGBColor[
              0.6732345097384469, 0.7446551828702399, 0.9680653822626852], 
             105 -> RGBColor[
              0.49622990368036246`, 0.6019008165669489, 0.9534841822492007], 
             36 -> RGBColor[
              0.5804936979337181, 0.6703099607824947, 0.9601177368012738], 
             123 -> RGBColor[
              0.7368900728190463, 0.7943833925490021, 0.9744099738955012], 94 -> 
             RGBColor[
              0.9357612033142917, 0.9516113911299502, 0.9936237060141268], 
             312 -> RGBColor[
              0.45398801898134383`, 0.5676069515930661, 0.9501587463485718], 
             96 -> RGBColor[
              0.9396428956133918, 0.9545063508909313, 0.987053013459244], 2 -> 
             RGBColor[
              0.4738256386217726, 0.5837120248917467, 0.9517204364342614], 
             262 -> RGBColor[
              0.7347480322179359, 0.7927100141513032, 0.97419647530689], 272 -> 
             RGBColor[
              0.636260505893553, 0.7155839677503577, 0.9645079042044205], 97 -> 
             RGBColor[
              0.3743364953974701, 0.49865319043913486`, 0.945073368367329], 
             372 -> RGBColor[
              0.37903187068947947`, 0.5027200885206493, 0.9453725535289785], 
             356 -> RGBColor[
              0.533265715283611, 0.6319681568707654, 0.9563997770052565], 346 -> 
             RGBColor[
              0.3925733138290561, 0.5144490059554286, 0.9462354023116044], 
             341 -> RGBColor[
              0.9921114581537765, 0.9910058994673778, 0.780397083491199], 209 -> 
             RGBColor[
              0.5764630085654543, 0.6670376655728514, 0.9598004261693024], 
             378 -> RGBColor[
              0.9684789353960427, 0.9760122221461506, 0.9382411197509009], 66 -> 
             RGBColor[
              0.4531506933761011, 0.5669180874114541, 0.9500953393698686], 
             139 -> RGBColor[
              0.8675782485062734, 0.8972473618474427, 0.9872315819104156], 56 -> 
             RGBColor[
              0.9376209775797752, 0.9529984077320469, 0.9904755932894761], 
             335 -> RGBColor[
              0.8521520355164879, 0.8849469183427844, 0.985760215944307], 314 -> 
             RGBColor[
              0.3603506624129685, 0.4865393648563645, 0.9441822034567431], 
             144 -> RGBColor[
              0.9523414796400531, 0.8487568785729305, 0.2805110397103783], 
             298 -> RGBColor[
              0.9735299862209987, 0.9797792875810661, 0.9296910082292928], 
             204 -> RGBColor[
              0.30490412143720186`, 0.4378039420413292, 0.9406752106993986], 
             207 -> RGBColor[
              0.9856225207724901, 0.9883225571021317, 0.8879355687307513], 
             334 -> RGBColor[
              0.6030922879135403, 0.6886565141829913, 0.961896780585848], 149 -> 
             RGBColor[
              0.4094171203754899, 0.5290382645916167, 0.9473086747703499], 
             219 -> RGBColor[
              0.3876031802494093, 0.5101441260549158, 0.9459187097948258], 
             400 -> RGBColor[
              0.46216549572163107`, 0.5742457956019602, 0.9508025072726515], 
             9 -> RGBColor[
              0.4640593019063342, 0.5757832727776986, 0.950951594632752], 11 -> 
             RGBColor[
              0.7156570479234086, 0.7777959921235638, 0.9722936644078031], 44 -> 
             RGBColor[
              0.386522459411199, 0.5092080599834667, 0.945849847218659], 153 -> 
             RGBColor[
              0.9475057431993174, 0.8295847949990561, 0.27662009266083926`], 
             32 -> RGBColor[
              0.594536952507267, 0.6817109074867108, 0.96122327324344], 162 -> 
             RGBColor[
              0.38700189684143627`, 0.5096233245883123, 0.9458803965477638], 
             90 -> RGBColor[
              0.3295329352216119, 0.4598465985072176, 0.942218525131156], 331 -> 
             RGBColor[
              0.41330866319908544`, 0.5324089233907857, 0.9475566404379131], 
             8 -> RGBColor[
              0.8596869323415093, 0.8909550405417308, 0.9864789011299593], 
             364 -> RGBColor[
              0.2879912923145869, 0.4200274862981594, 0.9397120501011542], 
             342 -> RGBColor[
              0.9811484641488905, 0.9854611359455752, 0.9167949123146469], 
             163 -> RGBColor[
              0.9439345828311864, 0.9577070841909696, 0.979788306450812], 49 -> 
             RGBColor[
              0.32308250020973, 0.454259555908216, 0.9418075091160947], 338 -> 
             RGBColor[
              0.4995359689171475, 0.6045848292627126, 0.9537444478151564], 76 -> 
             RGBColor[
              0.9546007487898153, 0.9656618932986712, 0.9617332696644715], 
             369 -> RGBColor[
              0.38280416597973277`, 0.5059874610999925, 0.9456129208491637], 
             82 -> RGBColor[0.817319, 0.134127, 0.164218], 67 -> 
             RGBColor[
              0.9660783745246253, 0.9742218877788053, 0.9423046431396614], 
             211 -> RGBColor[
              0.34083671927240206`, 0.46963736810730605`, 
               0.9429387922553286]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9mGk41G3YxiVbGGbGGGMMZp+JsVWihTktLbQQJSTFQyShTSoPqYhQlpJK
qqfNXmhRyhaSilTaVCKRJUXIFu+8x/Ee7/3l/+H+ch3XfZ3X+Tv/LO9gJ19p
KSmppBlSUv/73TOaQg3xNcCuudfIQVpkmNPakkbt9TEPvi8NZNhgb/ns6fdD
H/sXHfyxyp0ND7fHqS/sJPcGTVUBJb/EIV13v7p5GCChatH2mBYiThm7fD2a
wMXSuP7uQgILxDHp2nhtPXyQ1mc/PcEGUValUrFSgL1qDx/o8inocZNuvLFX
DVyLS7FPPEloSs5kZR9joiF+nLmJz4T996mupTMZcLnp8o7irAb3UmmBWRgR
ZWJeSs2kPKrtmszXKxqgqOfAmPFKNhw7U0JMc4RIyGeqClVYSB2aXjO/RQTr
Ep2PcWVa8Ilq33jlkwDdLesDpQUkpPs90jq5QgeM26p3r2zTwDLDKvklLTRQ
VD5/igyjYLV8z4H4IhXcifTSGGyQxjYefcQ1jY/OjwNjcxI0kLa7/oumpQHC
73cRiM5cuGYx9G6L1DBn86n6kFAi1v1636Z+UQ2/Rn+ujf7Cxe3kS+naQhLa
19W7XjyiAE/j7z5jmnwo3nsku9GAjJI0Ajma0Snum+Oz/l6zJnzeBtttuqUM
pZ5wzHdiwnKv0plpRRGUHmlc7S9hYmWxo8+JmwZ4Y6G0Um9SBQh//02tXxa1
bEXtkKxZCDFeXlenpoVQ1cOHvPdrY9Fmh5wxDhPlPbq/ivt00UdzJ1MKJPXp
ac2zmiWpp/BMVitdBjIHqtwOhnAQuHjVa5dkEdquksQdR2h47SvbqGaqiPJb
Tk29uTQ4PFt9yposwJsT54efnlDFF79nv6NoFNjmf6wKlObgwDVuWG2BPso8
0+tEWWysVdCzaTOQg6s66R+pJF3cse1rM3FUwPjvLq/Ht5mg7ktvPOhhjDVV
Ff53GjUROMwwd3FWgH1kY6p/ORum5c8iMizJmKbLOPuociBNlaf8cCGhzOjV
2f1x6lBwzl+VsIEBzts3ZunuLMx8mmI8ai1C0NC3Ef1AHgYZT1e0+SohvPzn
Smm6NsjbFgWO2whRsq6Dt+TbgLgkibrzh1APXWfFaV0cFgyHijTKDxliKJWU
oLqHhTjusWKDVF20/r73XfUOE04WqW34zQc5d+2/N++yIQw6tL1VWxdlZczj
mzdQEG34/N3dUi04ik3nUjvpaFT1fvrzOBlaRZcuXhcScGgLwfKpQAPvCkoS
wlfrwqvTvOHmRhImeyotO+dNis2qJwj7NPRhO/h4g9ReLrZmBPj4uGvBsz9A
2cOHhQyVjUdNN8jBwl6/hfeRhgcY2J15i42P1sRXggEK1lbumccokkXYrqlz
LZt1sCLvlqXnSQ5WWRQKX6Zp4IQoiT1MIKGkzKH8ppoKLENTkv8jknBtU37A
8jEObi2ZIFxPMsZtm11rDV0Z8Mhk7L59TwtpVgtjrpnr4jhzx79l7XyI3pv/
OWXFRsfXd6tvrZkB2zW5YSkrtRAVUl636wkHMzasnqx5qosItSVDZhE0iNYq
lYTTmHhTfN+t/5c+XOXU73X1URA4RYzOlsxjjYfazElfVZikRt4bDjNGxFBq
rvl2LVQTOqsV/vChdNxDK8uEhOnMr+oL+oWw2Z22MkNZFePXnZZTuUJsnmjV
uvBEBa+tb5RLZxmC88NPXnCBBVHvQUphmhAczdycIiUV1KcvdttjTcbXitXO
+ofY0Ln02uU/Nw78iduE238ScJs3c/ffcgaOiJvTItXV4Vkht/ecpF4uPeNi
/I1RcVq9onmUSB516rlU86ppMSmC87LeXg3eh2u8ZCZ1kVbtIHWRYwThW+ON
STZs1OxVLH7gIenXybW+Q41UCIU2HquHZ6PuFfv8xTsUhGl2BAe2KkCz/nh2
WRUDyz+dVUqc5iLpdNjtwBQlJNlYO0U6kpF7OY9gE86DtP0ypSX/CBBhf8Rz
RQAbUv93XgXERey7qIpjvN7KwlZlJGntCTT6SofHjZLGk5MCzN/Ybbs9VREl
6bvGhBUkdOSHi1seamOvxylW1zQJ3xWfXlsYx4f504OdoWoaKPCa9Tp7ioYE
vteTGDky7lTttnjeo4SeD0rNl9ewoZaaa31vjyY+GJzXK/hPE0ybJBMHPzbu
H43s7ngoh6lnVqoFgXTw5jUxev4IoJy0zWJrlwysDW0ckwN0sMEn6WHMCBO7
NRqj3x4S4eD4DGeGqsQH8tlFtUtIuGjVMX1skQzGNrU9LsyiwmNN8YuHJ1lY
2rt4tY/kfdfbNq0/4MMDVZAbdCWJg7Uezisz3tGxXl+esa+Sie87lBc8GaKD
0Zy55ULpgNiaMkeQ/JAJn/AFO27mGaDfr2+iyJmISf+pSu0sA0TUWg06D/Iw
sLyAVdLARnChS2ZAHw3Ujz/Xhc9Qg+/CyYmiMFXEF1et6PDiwS90VarzJQr+
o9sVhP6lIlX74GauswrI9U5Da6rUMGH82fpcFQdMx+CvFYv5aFBnzuar0iGc
UB2zbteDIO9l9ISXFkb3zmr1WyUNeW/iY5N8Clq2Dnw59ZEJmzrhTu2rGvg7
lDjTz5CMBT/9ZvyOlcEducETNhQRRn/+yvC5/00c6+8ls3rSCM+LvpO0lJn4
e0I2QEtJiLTJ/o0DPkzM1w51cxdQ0fGPllFuIRtXayqnL6SzoOl9nly3i4kT
nZ9aLc6RMdbgbln2kQPPuJ/b2k14yDH5eO3UVRaO0Vnjq7kG2FLwNsphBw+n
+gOmL9gYw0yj9GdOjyYKCi5mhgar4mx+2MEsihCdOTGP5afU0dc9Y9TyLwtk
y4V/bheL4G/8aPKgLg9XMm0tEtJn43qVfFH8HxY8/DVXrToxGzee5pP8JHrx
WFZXbv5cA3Oajm9+c5SDtKyFHm3L+HC9LP2i65km0uWph/9cpCLLQ/1DfhIR
nV+mHOX5AsxptNvuHc7GNSVj8rzLZAS1jkcst+EjpbwxU3RPDZvfysa0n9SA
e/XXDQZ7BOBRpgvENBnIM2p0RTwyng3KrsnmcGE1sno0/V8h1NCk3GTJAJnt
ah70hgCjUXHIwBsqcoq/P82K1keJ344W6jwueu/sVSSYkDHvauKQt5YcfP7T
Z316QEZnTyi+F3LhUjMe2AbJvh32zbHvnoGsBkv612ZZPH1+Wf7nWkWJX9Xu
6h4RYZNro+ydo3Q8ayE8JKeKEC6yWvNigIfhfXbKpPMkVBsu3r5QJIUbmWZn
72uRoC8aUxjQl4cdq3b2kQMkyGZQH9114YGfop2ziCWL8OsR8kfCOPCRtw3b
bEvEy+R5zPhDUnib/qfxZBMTdMXP0wmfNJCXaKdz10miv42PGGLJnA1d9j2u
yyTilsoMKmeJEMzKTddcm/VA3pOyIX4pB++ijq2Q/yJEX2xQ7N7fY+KVwfzm
0zuIiJlfYk331sXOPU0H5g+qoNz7fe9EkDxev+8xXL9KEX7b541cfyiLIwTV
+c9kKDCz/uZdtZCB3X7JmzzPCJDmt54aP0cKBzJGvobmkiBK+9rSsF+ADwk7
bHgiHqz0mwp8t8lh86v97smiPrGirApdVKwG26n9Be3dRAxuJnCdBlUxGUr9
ouM+JXbiLDEZMlCE7aG8RNp2IxRmNp9v72KClvT2Qr/LoHj76R1l0p+1ITXL
RM7H1xiioJzQwSoapnYHZ/x1UIP9apXWe63yYJ3/R97a0xCykR8HN4fxkODv
8iXFiIjXtu5KlXunxPqdLX55fgK87B+VG99DgHDEtnrihggxFcdmeZ0mgVhp
kr0uVh9S78yMPs7rFcunNs+tNRZhiOoTEhc4LF4SlzJiH6aGjC35FnFEPpSL
lFdVKQuRTT1d8tVaBSKv9zknI4WYv6CacvwhG/WfMrrTDs/GqLjv/PQ7Kvx+
aHnlL9DHu4OW4aejfoi3OTjm/k4WIiz46f61boPiKbPWJ4VEAYq8u4q+npmB
ddkLDP4kcjFkp1H+YpoO5X+r5xcpcLHZKKhzvYIiLtz7eyzwDQ+XWd+62lM1
MSMYhtYjWiisKe5dv4qC9pwylsMnfYSsX9q00JkJOW+b5tEyDaR/6Na4pivh
MhfhXpa9NjzrHoasD9AF/o1NylY3Qtlcd7kkyXz7RS17QNCX8PQ3j1eT5Syo
jURHBI7yoVJ6mDR2lYZu9Xap1yIS5qvdD2lMUUbWvvVSV+n94r9eo3zmoBIa
hk8F2ptJ/FXBpXD1JxYmLmyknv6uDmge8lsaqQKZDo+hraYiRC+aVyqvQoPP
nnqd51N8eHX7XTTlKeKwbIuz9ZAaHH98kHg3AbMcu+8E2+gh0WTFb/xgIz0v
2ahkGwGaVt11xjMUkHNpaVyxZO8RtzpYzGzVwj9Svy1nHdLAziK74tdUDs5b
Wy12CZH4zWsL4SquOvqll5OdI+hI4T/z32XOQlDl7OERGQXom2nkhO5Tgv1L
G9PnFH2cmxNrHDeLiZycVTsvVKjhUdqRl8cdNOB/rofZdmtAvN3vx3hqGBOe
AzyLh0xVKJAvXuXu+SY+qnb5bvodHva9rQo6PyKLgsWPtpZ1aWLdiXcK14wY
CPB7qnhlnyTf/I7v98+hY8SAW5hurIFr+cMlDjuZ+KSoHbVVV4iQS4zalB/T
4t2zNR+vqtCD+eJA+wUhneK8TSWqT2so8Ig9drHzERsupTZjj1bMgsyxg8FV
FTSsrLFb+lZmBgbW7//TfIaAl4XxWcOK+vidWmS/7hQH+twPjKJb+vAVqpX/
kfDMudpBSn6wIWpvpW87O5ODyV7ZF2b7OYh/MmWhv4uMqLOP3Dbm6eFS6d7g
nS9oiH1bdsTTX4gXfU4G7P/GxHStjlCHTE0IhtUD7npo42DFCm/Ze3fF2tE5
9NH5RNwv33nk6woVnOzRflHmMhN0kjSRkMOD9sKQ+V9kqdDLHtiSmUfEJbD+
bV4rxFEv6XNPUgXwOV7SfNyNjp2853lpEj8ojTv73m5YGw/dny4Qx5IRW5zt
mSLR237r+4zsfXqooLruDv2ijNcRFyMdGkgYPXbwpUXtlNic7OKkFiWPUpNv
7y+M6MC8IkHcsIgJbu2Ok4sl3B7S05Y7ND4ltj2Q1dTVz0TLfumVWhkGCP0p
fYj7gIfYf8ditmxRwMYTuglhC9mIIZQG91lLwZG1YluNIwsJ+iN96Z4SvY18
T7Tq6hKnrIhZPvM7C2t25tDleAxcq3k8Za4twtx3cnk9TBYCEtXZdTl8WC19
QBBRtHBZ77n4JIUNe7eu4d4oIqTWLKC1HOegvd1018856qiNnp/nqqeHFlrA
Qwd9Dj5v2Flz5KkW9unXz/JJZCIvuG5K7cOkWPh8vsmGpboYKCj+VXtcCNGr
bCmLL3/FBhbsF2Z+VOzbu7XgIkcbIz2t8yfuC3CVsiLGM1gDK3VCV+mHzQZj
jvSZJXM5CC8ourLm2yzMi7kc1PSSBb+586zV/Cig6h1yOOpPxCKP797v4kno
/djaOM9B4sfLTyw+/1nCDwtNi4aqJf3i7ldeoSPhKc7Z54+TKSghKA//oyJC
cD3ft91fBcGMTj2CKxObFo5Rz9XpoiUw++SHOiLMP/vbNiXz0Zh8NJb+i49r
HmYqlBYWKnJV8g8K9GHse+O34rVucYHTTcEnPgENz8r8TQUcpCsOEk0k8/PA
JTTWKJ2GI4NL3Lp/GkLn69ZRLw82wv3XRCouNELpyssvez0kHDgcvfZciz44
j59HfannomTF5x2qJfq4aX+06F8eFc6OdyMNYwWw27Yte+wsG0Fdv6IcxQQJ
h07GNzRTsahyojRfMncmIo1sQpImbhmgZriKjuR8UU/2RwYW3971yPLwoFgQ
f5zh6qCJfy51uLNrqJAa34gzK4jYMvop+3U5EwNl+5be19TF37G//5Hi9VFx
Orgh6upP8a0NvK9iSX6L/hDmcHOJNtwcHlkcf0QGUSHYQHsdEU0ZZxfnkkR4
zKX99oug4AJrhNHcwMQNrQ11rtEMKMQ5W0/OF4L3XNs0Zh0bJy96jPgukcXj
NsYS6qgqOqxXq4R8l0F9hOqF3ps6OBtacGXU3hg+tyqztxygQfuilNcdvjqu
Od2vn32ThS1rW7zcWYbIXqBgHXRZB6FHA0e6Dkp4xHioxymFh2XRG9+dthIh
LPSNHmMuD4FXo02mzyiitstnt/VqdRDUOpZ0XdeD2W/RRLopGU/yy+rvG7Gx
VOeL/2sTJnwfmlifHCDjYJR1XvkySc5ZKpdT1ETAOSPy1ddyVJCMNvxqolFg
ZNZmm3SUC1rJ2PZ51f3i1AVNzEPflOG0iWpCeawG+sPpzcfO8+D01fWpzxYu
8vVC3o4VacCQEB2utFTig98yD692IKNi0a/Jh40kWLreydvax4Gjd4RrVCEP
/XVrHkdk0zGUpUpv+IeAv4LX+TF3yXgX+faEkYT3vDER3KvFgns/PXf3cr3/
z3VWlRHVvpI8veGS/bSblhKuy+2v+CuWvNOFKnm7DC7C3dYwZT/oYZTBCxy9
3i8eX/7ytmakLtpZV/yuPFHHrLnmLaWzJXm+d5rF0NIG5ZLB0pLemfB++MPs
swEH8roz+w/8FYKmIL13kdRv8TPu4NqKCR64fTohhSVk4OXm6TnNleJS6w4j
hx8UFFYuaK9XIYMyddN59lsmdr7mN1RnETH+bfpwrJiJXzOH6OcShVhb3msb
fmpE3PdI46Rsgh4crg7ZhHayITNw7N9MZUUsPOS/zsSBCNl6nsAi2BiNfpa3
o9bRUGLYonK1VYgbd0ccmnW10ccvDagOYCGnYUupXp0GBi8r1TmMaWPnp+Vd
0hVMZMSEuk/+0MUwbaJz9CIdbgopbvMHBTCfPSTroDgmfmdUNDmzcjYcZuw5
skVaHV3LFnmwp7Txftwrc+UPif+2eQxxVIlw916TeO0wCWsZUhuf3FRFr9Cs
cn0vBcfIpFzWVkUo19V1lKmT8eujX3P0IgKe2EXecdmtiCDNTv64OglpnQsf
N18RYOmejOGF/BmIXIZ9fZ+UIfVy5NGFEiKCzqjH1oq4+Lg/brPyJQb0TIvb
so6zkPTC11XpFQkKpTW1D1hcsDV6LyyGMZoSVnTGLtNGivnbyGoLMvR+msU5
S7hJoa1uYzNfsn8J7YkpvHGxk2nNgtMlNNx75JD2fjUbCed+tm6J4kPbwEVA
uyqDhpfmdxs0SPB/7J9loftHHK/XTamco4uaeYHXHYuYeL8lwkepjYSDv0VR
iuY87Fzkl0D5LsCtWJ0ne1MnxHlxaTe75nJBnU07rfyZBh3bjul2YwO82Foq
I1JQwsuExx8bDqqglZ5esfC7MgxG7spkbhWgqvlBo6EnDRbS3w5brOZh7T6m
h/oNGux6i0f69xHBOtYUclRPAz6EP9b28lxMaBmk5TzQgM6W5XO2S/pemJHc
FbyNidO2H5ebL2Bj1s1Ty/75pgW5+gK7nj4+ZC7Hpw5L8jdzWwFLtlgXK6oj
hHPkNJEzg3Ivi2GE3Z7/UbJHqCjqCbrrIjTA0hcfSx6ZUvBJo+vdpu8iXG5r
OXVmTAffj7zy7Y80wLypOYpaGnwkueHN/kYRJo0+XT12mI94z6iVjVIGSJyU
qS5V1sSc8lody1BDVC+onpmbzcKC4pVxXYkk0M4EHjHv5CPhMEl9E18JMWqa
jp/jOAiRMcned0AdOtLJjKMUJrTedjhpJgrQ0rGBOvsuCbYJyfIMia5op7fy
KyVcrlxNsCS4SaNm2vQBBTJ4sNw6M+AtFw7U2mLZajqIFuOcvFIZyHVbu+/+
3/9+lVYBS0yJEH3dw+nOpyE0q/uY8mcKMhb8jZlzU5L/aVIZeQp0nOuKCSnt
VMOnDKnbb2LYmLar+FK9Uwv7LTPtDJLUYW111KnIVBn3yEmjz2cb4K9UQ6nx
EiqepR4wSBMI0Kcke3KLhMu3zrUKHU/kwNM8+uiBBg08K8y79dfMAO/86re3
lrCw+XUGp8+KBSOpgm0kTSaIE9OBimx9KJinXDvnpgWnxD1hbjU0eBx3CL3v
q4Mdhz+MpcoK4Sq7zEovkY0cUc1ilW4eVJpt9VRVVPHKXtpxej0RsWdzH5bw
B8T3lhWrjblpoP02P8YvWRdBXIWlipnGuCIoctAooKPCdsa6t0k8bLvzJDzy
jgwSPl2/K7Bggn/vJfv4Ax38D4p/h4g=
         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 5}], {
             RGBColor[
             0.9736047576254765, 0.9792819597211992, 0.9047958387160369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.9884762012529726, 0.9895026273170544, 0.840642698080807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 73}], {
             RGBColor[
             0.9592215901304927, 0.9684318321378362, 0.9248718946578383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[
             0.6618180841894674, 0.7273276793028931, 0.8995541752523285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 162}], {
             RGBColor[
             0.6872615218603043, 0.7493655061890112, 0.9011754086019657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 183}], {
             RGBColor[
             0.990615287725487, 0.9890305582580772, 0.7065793627413269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 291}], {
             RGBColor[
             0.6616029669573911, 0.7271413555685751, 0.8995404681725213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 357}], {
             RGBColor[
             0.6354801288746432, 0.7021752713823775, 0.897961615379204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 368}], {
             RGBColor[
             0.6742558664914649, 0.738100661191768, 0.9003466997423127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 387}], {
             RGBColor[
             0.9909729784091423, 0.9905351088353767, 0.7992646391509213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 28}], {
             RGBColor[
             0.7339534821329479, 0.7877662575948341, 0.849735858878385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 39}], {
             RGBColor[
             0.588127637977254, 0.6755873316649164, 0.961347858085783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 50}], {
             RGBColor[
             0.4587702094065797, 0.5712285992826939, 0.9506072638799252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 106}], {
             RGBColor[
             0.37585236705523156`, 0.49655547558778956`, 0.9454283059429177]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 137}], {
             RGBColor[
             0.6801007228805498, 0.747974024873525, 0.9703724731339382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 138}], {
             RGBColor[
             0.4166639791267644, 0.5347582989349865, 0.9479242921195729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 149}], {
             RGBColor[
             0.44162137949863123`, 0.5563751447416817, 0.9495145556023057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 164}], {
             RGBColor[
             0.621736119926247, 0.701842533197393, 0.9646976374773382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 197}], {
             RGBColor[
             0.6295612843960852, 0.7079556111546832, 0.9654775767413719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 210}], {
             RGBColor[
             0.6684787990513232, 0.7387070182808182, 0.9692639636640927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 217}], {
             RGBColor[
             0.4297334891784035, 0.5460784516490411, 0.9487570697431493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 230}], {
             RGBColor[
             0.37549253069686345`, 0.49617726476020185`, 0.9454078137946389]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 254}], {
             RGBColor[
             0.4126048591655359, 0.5312424932418718, 0.9476656485849823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 258}], {
             RGBColor[
             0.4870100011571516, 0.594415684346731, 0.9527583577489578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 314}], {
             RGBColor[
             0.4170881505173706, 0.5351256948740556, 0.9479513199455023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 328}], {
             RGBColor[
             0.5404179089736287, 0.6377746299109757, 0.9569628238918835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 7}], {
             RGBColor[
             0.6758221805877433, 0.7419355649429475, 0.9533115332847077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 13}], {
             RGBColor[
             0.38937984030379313`, 0.5116829796964922, 0.9460319170024524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 14}], {
             RGBColor[
             0.34365015054646364`, 0.47045058163391995`, 0.9431775109943087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 21}], {
             RGBColor[
             0.4562846002543839, 0.5679182337511943, 0.9507686915527949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 51}], {
             RGBColor[
             0.44539723664107134`, 0.5590793814997658, 0.9499115984074279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 79}], {
             RGBColor[
             0.616017043085079, 0.6947599329751664, 0.965336483495169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 188}], {
             RGBColor[
             0.5900691473728497, 0.6743604451174192, 0.962784417851935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 232}], {
             RGBColor[
             0.6524876000094415, 0.7238405650997577, 0.9688150777722653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 293}], {
             RGBColor[
             0.3526302853858649, 0.47985236231291944`, 0.9436902678594374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 373}], {
             RGBColor[
             0.38994146277421726`, 0.5121694288524076, 0.9460677030896445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 390}], {
             RGBColor[
             0.49069530387239946`, 0.5958543931328315, 0.9534776281921657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 84}], {
             RGBColor[
             0.7368492018690416, 0.7940152977655719, 0.9748741040973338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 125}], {
             RGBColor[
             0.5735630510003955, 0.6646833493799371, 0.9595721308868863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 165}], {
             RGBColor[
             0.6412912955481482, 0.7187949415945001, 0.965500990706367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 184}], {
             RGBColor[
             0.5219849179199055, 0.6228098973767794, 0.9555117113138634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 185}], {
             RGBColor[
             0.6610198698832411, 0.7342070538077929, 0.9674673506220799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 190}], {
             RGBColor[
             0.5343655185316764, 0.6328610266931165, 0.9564863575456564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.462027526714771, 0.5710796556597189, 0.9516355112003907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 252}], {
             RGBColor[
             0.5862783570542498, 0.675006207652466, 0.9605731263571465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 274}], {
             RGBColor[
             0.560334368569214, 0.6539437090369519, 0.9585307205476433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 288}], {
             RGBColor[
             0.7697745556491642, 0.8197370444112977, 0.9595685065373544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 318}], {
             RGBColor[
             0.7807623429198213, 0.8279317181669035, 0.9409690487620226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.9745598119992768, 0.9796768992485436, 0.8889681161406762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 113}], {
             RGBColor[
             0.6479016949357714, 0.7175019512343822, 0.9478795933121977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 162}], {
             RGBColor[
             0.6733451326066084, 0.7395397781205004, 0.9495008266618349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 183}], {
             RGBColor[
             0.976698898471791, 0.9792048301895663, 0.7549047808011962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 270}], {
             RGBColor[
             0.6868003798598544, 0.7511940370108714, 0.9503581831188037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 291}], {
             RGBColor[
             0.6476865777036952, 0.7173156275000642, 0.9478658862323905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 357}], {
             RGBColor[
             0.6215637396209474, 0.6923495433138667, 0.9462870334390732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 368}], {
             RGBColor[
             0.660339477237769, 0.7282749331232572, 0.948672117802182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 10}], {
             RGBColor[
             0.36083564843088034`, 0.4869594353689737, 0.9442131063369482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.37856749435784653`, 0.5023178690824219, 0.9453429638797588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 69}], {
             RGBColor[
             0.6697988299400681, 0.7345900894158093, 0.9129229667314106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 71}], {
             RGBColor[
             0.3676305345156977, 0.49284482417473774`, 0.944646070469791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 93}], {
             RGBColor[
             0.3231269760847183, 0.4528081729761795, 0.9418648958256637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 129}], {
             RGBColor[
             0.41563036026207073`, 0.5337595113471977, 0.9478870334140406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 131}], {
             RGBColor[
             0.4176002134713417, 0.5353587269233596, 0.9480421074744845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 142}], {
             RGBColor[
             0.5213581414417061, 0.6188781707586849, 0.9566997875485673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 201}], {
             RGBColor[
             0.32956485975504224`, 0.4595747968990903, 0.9422315237766932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 253}], {
             RGBColor[
             0.6399626365455333, 0.7123922383301377, 0.9682931342260526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 273}], {
             RGBColor[
             0.6227515172067037, 0.6986685589527438, 0.9666515222989673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 281}], {
             RGBColor[
             0.6720719184099926, 0.7355300699138323, 0.8752520082203716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 303}], {
             RGBColor[
             0.4173162907982047, 0.5351282257067363, 0.9480197560416121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 364}], {
             RGBColor[
             0.32080692670641864`, 0.45036965397995987`, 0.9417327724457749]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 391}], {
             RGBColor[
             0.6673862863084893, 0.7143942628529847, 0.662512639186317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 394}], {
             RGBColor[
             0.37491557447526463`, 0.4991547596309598, 0.9451102667741067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 13}], {
             RGBColor[
             0.6690866678912013, 0.7361016023819142, 0.9528823523716641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 14}], {
             RGBColor[
             0.6233569781338718, 0.6948692043193421, 0.9500279463635204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 21}], {
             RGBColor[
             0.7359914278417921, 0.7923368564366163, 0.9576191269220067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 93}], {
             RGBColor[
             0.6240801996231689, 0.695629355959484, 0.9500691327574255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 142}], {
             RGBColor[
             0.8223113649801566, 0.8616993537419895, 0.9649040244803293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 188}], {
             RGBColor[
             0.8697759749602578, 0.8987790678028412, 0.9696348532211467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 273}], {
             RGBColor[
             0.9237047407451542, 0.9414897419360484, 0.9748557592307293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 293}], {
             RGBColor[
             0.632337112973273, 0.7042709849983415, 0.9505407032286493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 390}], {
             RGBColor[
             0.7704021314598075, 0.8202730158182536, 0.9603280635613775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 16}], {
             RGBColor[
             0.8557289220055224, 0.8877990305371434, 0.9861013825707553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 25}], {
             RGBColor[
             0.6791230810672269, 0.7473734544909096, 0.9700732282316726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 76}], {
             RGBColor[
             0.9071438405656622, 0.9283084669202011, 0.9741060853972154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 117}], {
             RGBColor[
             0.6686625458837001, 0.7388811207871828, 0.9692497365838224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 202}], {
             RGBColor[
             0.6563572498018126, 0.7288832411508748, 0.9682831975063604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 234}], {
             RGBColor[
             0.6199907322524667, 0.6973843914839499, 0.9659659551657649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 239}], {
             RGBColor[
             0.5800229311803786, 0.6619908491105049, 0.9634476349510568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 269}], {
             RGBColor[
             0.5971902826697753, 0.6776357880393395, 0.9645131306800018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 302}], {
             RGBColor[
             0.9251041040316221, 0.9406516793538174, 0.8966147113901534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 323}], {
             RGBColor[
             0.7602521225106966, 0.8129549073478142, 0.9766533266175754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 365}], {
             RGBColor[
             0.7817517755937962, 0.829750599739747, 0.9787962111112176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 377}], {
             RGBColor[
             0.8971705168787882, 0.834793679212976, 0.6263791305725956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 388}], {
             RGBColor[
             0.877212708431244, 0.9049296186711664, 0.9881505252988432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 18}], {
             RGBColor[
             0.7118738351390574, 0.7726197522151935, 0.952036425704329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 56}], {
             RGBColor[
             0.7008401397430547, 0.7643908402548727, 0.970713593961114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 65}], {
             RGBColor[
             0.5281582276379879, 0.6278216683103521, 0.9559976968684494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 100}], {
             RGBColor[
             0.7073787391802446, 0.7692673170091551, 0.9596454506538086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 174}], {
             RGBColor[
             0.6964489251772167, 0.7609389674661047, 0.9720131193196672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 198}], {
             RGBColor[
             0.7073066868721504, 0.7692135805157532, 0.9597674164171605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 203}], {
             RGBColor[
             0.6169870272839313, 0.6979828981082553, 0.964326579990886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 266}], {
             RGBColor[
             0.4721743342829432, 0.5823714216390723, 0.9515904397077817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 313}], {
             RGBColor[
             0.6897614786419826, 0.7556065791248094, 0.9713752646991825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 339}], {
             RGBColor[
             0.5302559881194555, 0.6295247247722403, 0.9561628402579003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 358}], {
             RGBColor[
             0.6954600637320479, 0.760150476191656, 0.9719188008322599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 384}], {
             RGBColor[
             0.6376955986463465, 0.7141605914475457, 0.9663906168516894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 32}], {
             RGBColor[
             0.48129284413538864`, 0.587458978281449, 0.9529479955634703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 52}], {
             RGBColor[
             0.3592691325615621, 0.48560259805834716`, 0.9441132893309708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 60}], {
             RGBColor[
             0.3419403130165465, 0.4705932455402496, 0.9430091122728359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 68}], {
             RGBColor[
             0.45740665702851846`, 0.5680670955276252, 0.9510675874164312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.4228434475947006, 0.540007125054411, 0.9483466449605931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 253}], {
             RGBColor[
             0.6471757238781632, 0.718639852037351, 0.9687527457726051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 271}], {
             RGBColor[
             0.6743462993257054, 0.7391459271137625, 0.9311608942559582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 303}], {
             RGBColor[
             0.4245293781308346, 0.5413758394139497, 0.9484793675881646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 333}], {
             RGBColor[
             0.5254069701126278, 0.6226538415501153, 0.9568440153633991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 334}], {
             RGBColor[
             0.4855705118385253, 0.5909317816295891, 0.9532847492346743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 337}], {
             RGBColor[
             0.6531218181562197, 0.7233167438094583, 0.9670884046446413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 345}], {
             RGBColor[
             0.3376154857793054, 0.4667027168742303, 0.9427388319127068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 353}], {
             RGBColor[
             0.3164502370868216, 0.4444566985441551, 0.9415335023108493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 364}], {
             RGBColor[
             0.32802001403904857`, 0.45661726768717326`, 0.9421923839923274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 391}], {
             RGBColor[
             0.6745993736411191, 0.7206418765601981, 0.6629722507328695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 54}], {
             RGBColor[
             0.5307173080023323, 0.6258564375674087, 0.9577736415901055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 83}], {
             RGBColor[
             0.5728468912995617, 0.6623469651250433, 0.9604581013840772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 118}], {
             RGBColor[
             0.5243297608195658, 0.6203238652451527, 0.9573666327319057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 123}], {
             RGBColor[
             0.7262735603712274, 0.786089692336283, 0.9733518191516521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 141}], {
             RGBColor[
             0.8387423695900325, 0.8744238636404864, 0.9608968027821922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 161}], {
             RGBColor[
             0.85499819184732, 0.8840483643281005, 0.7987717402778023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 196}], {
             RGBColor[
             0.5031901104444422, 0.6003474290985225, 0.956080645535285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 206}], {
             RGBColor[
             0.7243785044492951, 0.784609260247111, 0.9731629376876584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 214}], {
             RGBColor[
             0.5349948497929837, 0.6295614292709693, 0.9580462027705241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 286}], {
             RGBColor[
             0.8498178574926418, 0.8826839443838055, 0.9421488907129536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 332}], {
             RGBColor[
             0.6397585447884606, 0.7173010007000559, 0.9655509694278042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 366}], {
             RGBColor[
             0.8492025098957938, 0.8822250191536154, 0.9431905136860603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 386}], {
             RGBColor[
             0.6104876618544388, 0.6935375792959678, 0.9632466583004609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 19}], {
             RGBColor[
             0.523673197842432, 0.622145663126674, 0.9563130328002534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 24}], {
             RGBColor[
             0.5771078362720669, 0.6638892087861981, 0.9616388981838325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 65}], {
             RGBColor[
             0.49011569884327577`, 0.5951627934714842, 0.9534930763866173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 100}], {
             RGBColor[
             0.6693362103855325, 0.736608442170287, 0.9571408301719764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 107}], {
             RGBColor[
             0.49473490450918534`, 0.5989128727239132, 0.9538567171773455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 124}], {
             RGBColor[
             0.688490847198254, 0.7500939177296493, 0.8888904419324103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 150}], {
             RGBColor[
             0.5199923539893427, 0.6192701599331911, 0.9559461606844188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 157}], {
             RGBColor[
             0.6655196429819124, 0.7337620524497226, 0.9636012832661047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 167}], {
             RGBColor[
             0.5298000349255136, 0.6269319948216638, 0.956923698662147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 168}], {
             RGBColor[
             0.38103942778799677`, 0.5044589335766314, 0.9455004732920831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 203}], {
             RGBColor[
             0.5789444984892191, 0.6653240232693873, 0.961821959509054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 206}], {
             RGBColor[
             0.5605371026460457, 0.6509440257353103, 0.9599872823183008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 211}], {
             RGBColor[
             0.364405481794656, 0.4900514456036343, 0.9444405729622083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 238}], {
             RGBColor[
             0.4966978029077639, 0.6005064420714445, 0.9540112437296154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 341}], {
             RGBColor[
             0.6900428512353431, 0.7507357112836701, 0.8631697185801435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 358}], {
             RGBColor[
             0.6574175349373357, 0.7274916013527879, 0.9694141803504278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 14}], {
             RGBColor[
             0.3369146378499216, 0.46461661907288676`, 0.942748330081265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 21}], {
             RGBColor[
             0.44954908755784184`, 0.562084271190161, 0.9503395106397512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 51}], {
             RGBColor[
             0.43866172394452935`, 0.5532454189387326, 0.9494824174943842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 79}], {
             RGBColor[
             0.609281530388537, 0.6889259704141333, 0.9649073025821253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 87}], {
             RGBColor[
             0.664049888457072, 0.7323451805269102, 0.9614083061511771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 205}], {
             RGBColor[
             0.4218830737642665, 0.5396237548528184, 0.9481615406899732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 232}], {
             RGBColor[
             0.6457520873128995, 0.7180066025387246, 0.9683858968592216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 277}], {
             RGBColor[
             0.596988111496805, 0.679193463626426, 0.9637161875800178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 373}], {
             RGBColor[
             0.3832059500776753, 0.5063354662913744, 0.9456385221766008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 390}], {
             RGBColor[
             0.4839597911758574, 0.5900204305717983, 0.9530484472791221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 69}], {
             RGBColor[
             0.638580023437239, 0.7059262890900864, 0.9109931813727734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 71}], {
             RGBColor[
             0.3364117280128686, 0.46418102384901483`, 0.9427162851111537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 201}], {
             RGBColor[
             0.2983460532522131, 0.43091099657336734`, 0.9403017384180561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 212}], {
             RGBColor[
             0.3238160284016348, 0.45327126192403416`, 0.9419136982698657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 273}], {
             RGBColor[
             0.5915327107038746, 0.6700047586270209, 0.9647217369403303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 289}], {
             RGBColor[
             0.5599815332929983, 0.6448467061934837, 0.9617123574728123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 293}], {
             RGBColor[
             0.3001650829319934, 0.43278600168931397`, 0.9404066809382501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 390}], {
             RGBColor[
             0.4382301014185279, 0.548788032509226, 0.9501940412709784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 35}], {
             RGBColor[
             0.47694763084203706`, 0.586246598820304, 0.951966211098075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 106}], {
             RGBColor[
             0.38074366544713245`, 0.5005264519728161, 0.9458133668697446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 154}], {
             RGBColor[
             0.3911194010864072, 0.5114320079893296, 0.9464042496648759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 207}], {
             RGBColor[
             0.7346153780890323, 0.7899882673819658, 0.9202130635093332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 231}], {
             RGBColor[
             0.7386060571991793, 0.7901908232557125, 0.7488452214074228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 369}], {
             RGBColor[
             0.4332062006926536, 0.5488207193808962, 0.9490517395685394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 372}], {
             RGBColor[
             0.4313200530475269, 0.5471870330912245, 0.9489315559084468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 392}], {
             RGBColor[
             0.460504429213783, 0.5724650728770388, 0.95079115855103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 25}], {
             RGBColor[
             0.67516507073124, 0.7442174444863222, 0.9696957096724685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 37}], {
             RGBColor[
             0.6898235247925151, 0.7561178378490954, 0.9708496768718586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 76}], {
             RGBColor[
             0.9031858302296755, 0.9251524569156135, 0.9737285668380113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 77}], {
             RGBColor[
             0.7367519060223506, 0.7942164118309583, 0.9745440509465959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 78}], {
             RGBColor[
             0.8501782818638899, 0.8833731007563184, 0.9855719575589315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 80}], {
             RGBColor[
             0.5602935427028768, 0.642258120716056, 0.9621719597383567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 96}], {
             RGBColor[
             0.8957069036414638, 0.9195746857117436, 0.9863884387353976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 182}], {
             RGBColor[
             0.866015737947293, 0.896001458340931, 0.9870825482584304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.692992011995306, 0.7586901584990429, 0.9710991117910134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 269}], {
             RGBColor[
             0.5932322723337884, 0.6744797780347522, 0.9641356121207978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 302}], {
             RGBColor[
             0.9211460936956353, 0.93749566934923, 0.8962371928309494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 323}], {
             RGBColor[
             0.7562941121747098, 0.8097988973432267, 0.9762758080583714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 365}], {
             RGBColor[
             0.7777937652578093, 0.8265945897351595, 0.9784186925520136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 377}], {
             RGBColor[
             0.8932125065428015, 0.8316376692083884, 0.6260016120133918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 388}], {
             RGBColor[
             0.8732546980952571, 0.901773608666579, 0.9877730067396392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 18}], {
             RGBColor[
             0.6215637396209475, 0.6923495433138667, 0.9462870334390732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 31}], {
             RGBColor[
             0.4514115198788142, 0.5585628286153851, 0.9513160641719035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 62}], {
             RGBColor[
             0.5051947546834759, 0.6009306491996074, 0.9564360450764208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.5736751483836857, 0.6547831003189104, 0.9631673121536913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 111}], {
             RGBColor[
             0.4231969287719213, 0.5356569525019649, 0.9490949082065162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 222}], {
             RGBColor[
             0.5786870066787786, 0.6587794200801482, 0.9636453476720159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 223}], {
             RGBColor[
             0.2902300400198522, 0.4223805520811961, 0.9398395434710387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 247}], {
             RGBColor[
             0.27600786642761466`, 0.4074321458978667, 0.9390296117247812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 256}], {
             RGBColor[
             0.6105595439214322, 0.6841426321788848, 0.9649142664044581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 292}], {
             RGBColor[
             0.27199590867096773`, 0.4032153239228172, 0.9388011366656996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 310}], {
             RGBColor[
             0.611049603836896, 0.6845081180614384, 0.9640847227956739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 319}], {
             RGBColor[
             0.328529305663705, 0.4566375102171071, 0.9422402460929977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 384}], {
             RGBColor[
             0.5473855031282364, 0.6338903825462188, 0.9606412245864336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 99}], {
             RGBColor[
             0.9117997771345189, 0.9318897886577322, 0.970001535490524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 144}], {
             RGBColor[
             0.9560149240059168, 0.9091065551128095, 0.6168161482431421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.9551212201048735, 0.9660500599532481, 0.9608522474887374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 218}], {
             RGBColor[
             0.6591966296785293, 0.7272850560086322, 0.9485992965662876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 266}], {
             RGBColor[
             0.7199888675156664, 0.7792079010765671, 0.9526752707793587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 310}], {
             RGBColor[
             0.9491742325877293, 0.9616148064002603, 0.9709189461325067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 319}], {
             RGBColor[
             0.6666539344145381, 0.7337441985559289, 0.9490744694298304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 384}], {
             RGBColor[
             0.8855101318790697, 0.9109970708850407, 0.9674754479232663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 24}], {
             RGBColor[
             0.7128067897975889, 0.7755693488129095, 0.9720095773149979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 85}], {
             RGBColor[
             0.7234035555397961, 0.7838476227491242, 0.973065763891775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 107}], {
             RGBColor[
             0.6304338580347074, 0.7105930127506247, 0.9642273963085111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 124}], {
             RGBColor[
             0.824189800723776, 0.8617740577563606, 0.8992611210635757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 150}], {
             RGBColor[
             0.6556913075148649, 0.7309502999599025, 0.9663168398155844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 152}], {
             RGBColor[
             0.49585294168007454`, 0.5980491555255716, 0.9545403506780745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 157}], {
             RGBColor[
             0.8012185965074343, 0.845442192476434, 0.9739719623972702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 160}], {
             RGBColor[
             0.5989922699334793, 0.6850673151026453, 0.9617521993188503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 167}], {
             RGBColor[
             0.6654989884510358, 0.7386121348483752, 0.9672943777933125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 168}], {
             RGBColor[
             0.5167383813135189, 0.6161390736033427, 0.9558711524232485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 181}], {
             RGBColor[
             0.6629705671444355, 0.7366369129069453, 0.9670423683869112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 211}], {
             RGBColor[
             0.5001044353201781, 0.6017315856303457, 0.9548112520933737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 238}], {
             RGBColor[
             0.632396756433286, 0.7121865820981559, 0.9643819228607808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 64}], {
             RGBColor[
             0.8184321436935487, 0.857696671861134, 0.9177562997992279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 88}], {
             RGBColor[
             0.796399491903795, 0.839928834296838, 0.9159402688539411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 89}], {
             RGBColor[
             0.8764806800101449, 0.9030446296168751, 0.9235420354048522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 120}], {
             RGBColor[
             0.9851398655874735, 0.9880179352877284, 0.8912308894266372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 140}], {
             RGBColor[
             0.9473226753574893, 0.9590977325517123, 0.9304142795770655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 189}], {
             RGBColor[
             0.841921406058469, 0.8760466621456158, 0.9200974899521261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 195}], {
             RGBColor[
             0.9826960973693344, 0.9642475205326714, 0.620697413185165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 241}], {
             RGBColor[
             0.6936408009923196, 0.7550722417457463, 0.9082465207131626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 255}], {
             RGBColor[
             0.9326476002533312, 0.9473962260079586, 0.9290145578130367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 257}], {
             RGBColor[
             0.8293773879017172, 0.8662471798234923, 0.9188472194527757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 263}], {
             RGBColor[
             0.8089241848254443, 0.8500969442416191, 0.9169262585601953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 312}], {
             RGBColor[
             0.7203539753872049, 0.7781916581771913, 0.9099536872298496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 336}], {
             RGBColor[
             0.6753154381781294, 0.7391997335356109, 0.9070788447991245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 356}], {
             RGBColor[
             0.7599928235383384, 0.810372260816041, 0.9130742025581919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 359}], {
             RGBColor[
             0.9778969323921498, 0.9826161675698708, 0.9034912860667981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 360}], {
             RGBColor[
             0.6687659084669344, 0.7335268600887085, 0.9066615145574488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 389}], {
             RGBColor[
             0.6814645767248898, 0.7445258082801247, 0.9074706624698543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 109}], {
             RGBColor[
             0.6253912963472354, 0.7053509945900742, 0.9646154849420521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[
             0.41588683462670195`, 0.5329277196152347, 0.9481945816493405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 132}], {
             RGBColor[
             0.5567188550279831, 0.6510084722671516, 0.9582460940776152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 180}], {
             RGBColor[
             0.6276376265588874, 0.7071058448241587, 0.9648393781444002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 232}], {
             RGBColor[
             0.7126568472634902, 0.7742418565934266, 0.973122671409564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 249}], {
             RGBColor[
             0.6362673885392591, 0.7138474804718453, 0.9656995121688929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 370}], {
             RGBColor[
             0.7441226475479448, 0.7984011067798147, 0.9438550929212384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 45}], {
             RGBColor[
             0.5103761866451392, 0.6112003415163002, 0.9552237117930512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 74}], {
             RGBColor[
             0.46432493005331654`, 0.5689088935987567, 0.9523773946679155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 116}], {
             RGBColor[
             0.7131446846263787, 0.7758333148212558, 0.9720432555137251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 141}], {
             RGBColor[
             0.8038673245912844, 0.8471792134273055, 0.9574207842225422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 179}], {
             RGBColor[
             0.470646031497592, 0.5755527719976697, 0.9527373720439354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 209}], {
             RGBColor[
             0.6111849832456835, 0.6951721786350267, 0.9625710267289027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 286}], {
             RGBColor[
             0.8149428124938938, 0.8554392941706245, 0.9386728721533035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 290}], {
             RGBColor[
             0.7618059040882303, 0.8143143654481239, 0.9767695467567058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 304}], {
             RGBColor[
             0.46881074286018093`, 0.5736237672757303, 0.9526328550711011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 338}], {
             RGBColor[
             0.5727214634215301, 0.6639457604799572, 0.9595430375518297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 38}], {
             RGBColor[
             0.9399776157742699, 0.9210384305399995, 0.6650371374866823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 92}], {
             RGBColor[
             0.9167565978868717, 0.9364608427327994, 0.9919222567763678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 98}], {
             RGBColor[
             0.9443337535758639, 0.9573351763320999, 0.955896858903794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 119}], {
             RGBColor[
             0.601402638854558, 0.6781142543933044, 0.9656268594763823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 128}], {
             RGBColor[
             0.8852500627269668, 0.9113383868184053, 0.9889171353266001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 130}], {
             RGBColor[
             0.7116900332997582, 0.7734506400428904, 0.9730538269037614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 139}], {
             RGBColor[
             0.8886552926337163, 0.914053624713544, 0.9892419291949905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 143}], {
             RGBColor[
             0.6512550321849133, 0.722742973238419, 0.9687503519282252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 146}], {
             RGBColor[
             0.6785083378848187, 0.7463484168447041, 0.9704869084682712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 151}], {
             RGBColor[
             0.7872746532730512, 0.8344696121312675, 0.9792393385130342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 158}], {
             RGBColor[
             0.9499449621699478, 0.9546606303768492, 0.7037583960584639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 186}], {
             RGBColor[
             0.8898185140431781, 0.9149811458906447, 0.9893528782914449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 213}], {
             RGBColor[
             0.6388905362623347, 0.7120334683279161, 0.967962497181533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 267}], {
             RGBColor[
             0.7032251210754715, 0.7665784429592644, 0.9723874380054705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 306}], {
             RGBColor[
             0.9300143738069915, 0.9466558063463073, 0.9801358337601167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 308}], {
             RGBColor[
             0.6153493148031951, 0.6916432455162035, 0.9664624713668415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 311}], {
             RGBColor[
             0.6455721484739085, 0.717820744997987, 0.9683882436033369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 346}], {
             RGBColor[
             0.6511528252951077, 0.7226544467675369, 0.968743839395585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 348}], {
             RGBColor[
             0.8354778204344532, 0.8721262926753939, 0.9840437797314746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 354}], {
             RGBColor[
             0.9242673795512668, 0.9423697074402273, 0.9898639959788991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 374}], {
             RGBColor[
             0.9354740803358086, 0.9507276465360501, 0.9708939747263492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 33}], {
             RGBColor[
             0.8143973191402603, 0.855276713529254, 0.9820438659777215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 56}], {
             RGBColor[
             0.8519312029034996, 0.8851556511022403, 0.9839055179940266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 65}], {
             RGBColor[
             0.6792492907984328, 0.7485864791577197, 0.969189620901362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 100}], {
             RGBColor[
             0.8584698023406894, 0.8900321278565226, 0.9728373746867212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 107}], {
             RGBColor[
             0.6838684964643422, 0.7523365584101489, 0.9695532616920902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 124}], {
             RGBColor[
             0.8776244391534109, 0.9035176034158849, 0.904586986447155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 150}], {
             RGBColor[
             0.7091259459444997, 0.7726938456194268, 0.9716427051991635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 157}], {
             RGBColor[
             0.8546532349370692, 0.8871857381359582, 0.9792978277808495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 167}], {
             RGBColor[
             0.7189336268806706, 0.7803556805078994, 0.9726202431768918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 168}], {
             RGBColor[
             0.5701730197431537, 0.657882619262867, 0.9611970178068276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 203}], {
             RGBColor[
             0.7680780904443761, 0.8187477089556229, 0.9775185040237986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 206}], {
             RGBColor[
             0.7496706946012027, 0.804367711421546, 0.9756838268330454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 211}], {
             RGBColor[
             0.5535390737498129, 0.6434751312898699, 0.9601371174769529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 238}], {
             RGBColor[
             0.6858313948629209, 0.7539301277576801, 0.9697077882443601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 341}], {
             RGBColor[
             0.8791764431905003, 0.9041593969699058, 0.878866263094888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 358}], {
             RGBColor[
             0.8465511268924928, 0.8809152870390236, 0.9851107248651725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 386}], {
             RGBColor[
             0.6357798520063465, 0.7132960304704028, 0.9657675474458479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 37}], {
             RGBColor[
             0.5132176838542195, 0.6156922618028617, 0.9548215225327759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 62}], {
             RGBColor[
             0.6127548141448911, 0.6952051559321292, 0.9635434176919935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[
             0.7265799892913798, 0.7847268808693799, 0.9577004124989287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 78}], {
             RGBColor[
             0.6735724409255943, 0.7429475247100847, 0.9695438032198487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 91}], {
             RGBColor[
             0.5858968697656957, 0.6742235256551642, 0.9608664687980355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 117}], {
             RGBColor[
             0.48809869460941774`, 0.5952995347363617, 0.9528440636855358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 182}], {
             RGBColor[
             0.6894098970089975, 0.7555758822946973, 0.9710543939193477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 187}], {
             RGBColor[
             0.5163861710570103, 0.6182645824528092, 0.9550709574519307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 208}], {
             RGBColor[
             0.7422298615465127, 0.7961146871629736, 0.9184981999560574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 239}], {
             RGBColor[
             0.39945907990609614`, 0.5184092630596837, 0.9470419620527701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 269}], {
             RGBColor[
             0.41662643139549277`, 0.5340542019885184, 0.948107457781715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 309}], {
             RGBColor[
             0.6340358606020345, 0.7118300711663932, 0.9656645135201554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 323}], {
             RGBColor[
             0.5796882712364142, 0.669373321296993, 0.9602476537192888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 362}], {
             RGBColor[
             0.5540084752375988, 0.6488080638520997, 0.9580327230520678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 365}], {
             RGBColor[
             0.6011879243195137, 0.6861690136889258, 0.962390538212931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 377}], {
             RGBColor[
             0.7166066656045058, 0.6912120931621548, 0.609973457674309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 388}], {
             RGBColor[
             0.6966488571569616, 0.7613480326203452, 0.9717448524005565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 395}], {
             RGBColor[
             0.7210609350644803, 0.7806107792635801, 0.9670427317051908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 70}], {
             RGBColor[
             0.6223671877796209, 0.7021346353089082, 0.9648978879906214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 177}], {
             RGBColor[
             0.5297211100116379, 0.6190087252055988, 0.9590519151443838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 285}], {
             RGBColor[
             0.5919802402502077, 0.6760157377134657, 0.9629061910001672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 324}], {
             RGBColor[
             0.6071435368709913, 0.6891494231169406, 0.9638723828524668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 40}], {
             RGBColor[
             0.8708849347412899, 0.8999785081354031, 0.9866074853656299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 41}], {
             RGBColor[
             0.9085521928707134, 0.9298926987845779, 0.9902322411366528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 48}], {
             RGBColor[
             0.6564616115214105, 0.7262986190853898, 0.9686017821183301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 63}], {
             RGBColor[
             0.6730112888225686, 0.7406331177526857, 0.969656312921655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 86}], {
             RGBColor[
             0.8216168479532187, 0.8614899042852338, 0.981696902911043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 250}], {
             RGBColor[
             0.909077201661814, 0.9303113265436176, 0.9902823169438288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 265}], {
             RGBColor[
             0.6486660670269311, 0.7195465102597306, 0.9681050569164713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 295}], {
             RGBColor[
             0.7322766407676332, 0.7899423593711734, 0.9739917277809325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 325}], {
             RGBColor[
             0.7144036368759065, 0.77543224964222, 0.9725846994436051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 376}], {
             RGBColor[
             0.6814887310664067, 0.7479758521356621, 0.9701964880451246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 39}], {
             RGBColor[
             0.8482554814884292, 0.8796415643680038, 0.8593632805299065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 50}], {
             RGBColor[
             0.7188980529177549, 0.7752828319857812, 0.8486226863240487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 106}], {
             RGBColor[
             0.6359802105664067, 0.7006097082908769, 0.8434437283870413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 197}], {
             RGBColor[
             0.8896891279072603, 0.9120098438577706, 0.8634929991854955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 217}], {
             RGBColor[
             0.6898613326895787, 0.7501326843521285, 0.8467724921872729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 231}], {
             RGBColor[
             0.9938426023184536, 0.9902740795737733, 0.6464755829247195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 254}], {
             RGBColor[
             0.6727327026767111, 0.7352967259449591, 0.8456810710291058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 314}], {
             RGBColor[
             0.6772159940285458, 0.7391799275771429, 0.8459667423896258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 369}], {
             RGBColor[
             0.688442745811928, 0.748903975698957, 0.8466821010858361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 113}], {
             RGBColor[
             0.6627731385632676, 0.7277226188302374, 0.8837264526769679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 162}], {
             RGBColor[
             0.6882165762341046, 0.7497604457163555, 0.8853476860266052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 183}], {
             RGBColor[
             0.9915703420992872, 0.9894254977854213, 0.6907516401659664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 270}], {
             RGBColor[
             0.7016718234873506, 0.7614147046067266, 0.886205042483574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 357}], {
             RGBColor[
             0.6364351832484435, 0.7025702109097217, 0.8821338928038435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 153}], {
             RGBColor[
             0.6861351519112935, 0.685958120474262, 0.6124533463762846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 168}], {
             RGBColor[
             0.39943458594117665`, 0.5203918950013839, 0.946672596503404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 175}], {
             RGBColor[
             0.4857062052315468, 0.5925819112556292, 0.9528699338748128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 211}], {
             RGBColor[
             0.38280063994783586`, 0.505984407028387, 0.9456126961735292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 216}], {
             RGBColor[
             0.40515012689414376`, 0.5253424093034029, 0.9470367857188726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 229}], {
             RGBColor[
             0.386092479546561, 0.5088356330361337, 0.9458224492819005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 294}], {
             RGBColor[
             0.3825721093750682, 0.5057864653325361, 0.9455981344075142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 329}], {
             RGBColor[
             0.37721183504946404`, 0.501143665126919, 0.9452565824673911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 341}], {
             RGBColor[
             0.7084380093885232, 0.7666686727084229, 0.8643418417914643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 343}], {
             RGBColor[
             0.4132216370420498, 0.5323335457076233, 0.947551095208141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 358}], {
             RGBColor[
             0.6758126930905157, 0.7434245627775407, 0.9705863035617488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 379}], {
             RGBColor[
             0.6936036500247653, 0.7569209415123594, 0.9483727125637121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 99}], {
             RGBColor[
             0.7416475573923857, 0.7981030739592507, 0.9750305662233544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 111}], {
             RGBColor[
             0.5911693377806213, 0.6789769261423052, 0.9609581622761793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 169}], {
             RGBColor[
             0.46811835848784367`, 0.5753732473193421, 0.9522949378049969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 199}], {
             RGBColor[
             0.47773441949117, 0.5837021960431443, 0.9529076647089799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 215}], {
             RGBColor[
             0.7943600862046576, 0.8050544464208313, 0.6492784219993161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 222}], {
             RGBColor[
             0.7466594156874787, 0.8020993937204886, 0.975508601741679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 223}], {
             RGBColor[
             0.4582024490285523, 0.5657005257215364, 0.9517027975407018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 224}], {
             RGBColor[
             0.425011093656044, 0.5308143067715521, 0.9498125989544474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 247}], {
             RGBColor[
             0.4439802754363147, 0.550752119538207, 0.9508928657944442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 259}], {
             RGBColor[
             0.6169839910918558, 0.6999344246372442, 0.9629903863470305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 292}], {
             RGBColor[
             0.4399683176796678, 0.5465352975631576, 0.9506643907353627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 363}], {
             RGBColor[
             0.46357713163705755`, 0.571349657917635, 0.9520088777641257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 383}], {
             RGBColor[
             0.5366276143557123, 0.6346974979893244, 0.9566644380152545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 393}], {
             RGBColor[
             0.640146890124593, 0.7184549341655778, 0.9650081468688678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 400}], {
             RGBColor[
             0.5407747123045726, 0.6380642989288428, 0.956990912757109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 46}], {
             RGBColor[
             0.7900797366398786, 0.8350167322944213, 0.9245794209870957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 52}], {
             RGBColor[
             0.4725132409334405, 0.5798545272636091, 0.9523885670109404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 71}], {
             RGBColor[
             0.488087730220206, 0.5933443670872129, 0.9533809596963131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 105}], {
             RGBColor[
             0.5453834280938148, 0.6418058620268299, 0.9573537277463204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 111}], {
             RGBColor[
             0.5787458495904977, 0.6688909787577979, 0.9599801397771159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 129}], {
             RGBColor[
             0.536087555966579, 0.6342590542596729, 0.9566219226405628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 199}], {
             RGBColor[
             0.4653109313010464, 0.5736162486586369, 0.9519296422099166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 215}], {
             RGBColor[
             0.7819365980145341, 0.794968499036324, 0.6483003995002528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 247}], {
             RGBColor[
             0.43155678724619106`, 0.5406661721536997, 0.9499148432953809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 259}], {
             RGBColor[
             0.6045605029017321, 0.6898484772527369, 0.9620123638479672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 271}], {
             RGBColor[
             0.7875904076975839, 0.8333978563190243, 0.9394361719359279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 287}], {
             RGBColor[
             0.548104838584528, 0.6440152256613363, 0.9575679671490045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 292}], {
             RGBColor[
             0.4275448294895442, 0.5364493501786503, 0.9496863682362995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 303}], {
             RGBColor[
             0.5377734865027131, 0.6356277686192116, 0.9567546452681344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 333}], {
             RGBColor[
             0.6386510784845063, 0.7169057707553772, 0.9651192930433687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 337}], {
             RGBColor[
             0.7663659265280982, 0.8175686730147201, 0.975363682324611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 345}], {
             RGBColor[
             0.4508595941511838, 0.5609546460794922, 0.9510141095926764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 353}], {
             RGBColor[0.4296943454587, 0.538708627749417, 0.949808779990819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 385}], {
             RGBColor[
             0.6176664403471198, 0.7004884676866563, 0.9630441112522989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 391}], {
             RGBColor[
             0.7878434820129976, 0.81489380576546, 0.6712475284128391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 400}], {
             RGBColor[
             0.528351224114449, 0.6279783515443356, 0.9560128902580458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 58}], {
             RGBColor[
             0.8538583558219739, 0.8863074918375482, 0.9859229662982942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 74}], {
             RGBColor[
             0.5726480561170086, 0.653875814043193, 0.9630827256520968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 107}], {
             RGBColor[
             0.7320243873773787, 0.7903003774669692, 0.9742616849712346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 116}], {
             RGBColor[
             0.8214678106900708, 0.860800235265692, 0.9827485864979064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 118}], {
             RGBColor[
             0.59777784188451, 0.678046135476408, 0.9645959451564371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 124}], {
             RGBColor[
             0.9257803300664473, 0.9414814224727052, 0.9092954097262993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 141}], {
             RGBColor[
             0.9121904506549765, 0.9321461338717416, 0.9681261152067236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 150}], {
             RGBColor[
             0.7572818368575363, 0.810657664676247, 0.9763511284783079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 152}], {
             RGBColor[
             0.5974434710227459, 0.677756520241916, 0.9645746393407981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 156}], {
             RGBColor[
             0.6740329564797548, 0.7432203213800879, 0.9696963871013629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 157}], {
             RGBColor[
             0.9028091258501056, 0.9251495571927786, 0.9840062510599938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 179}], {
             RGBColor[
             0.5789691575612841, 0.660519692442106, 0.9634427030281167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 206}], {
             RGBColor[
             0.7978265855142392, 0.8423315304783663, 0.9803922501121898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 209}], {
             RGBColor[
             0.7195081093093756, 0.7801390990794628, 0.9732763577130841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 245}], {
             RGBColor[
             0.6236695338712075, 0.7004722177210074, 0.9662457408747052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 286}], {
             RGBColor[
             0.9232659385575859, 0.9404062146150607, 0.949378203137485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 386}], {
             RGBColor[
             0.6839357429193829, 0.7512598495272231, 0.9704759707249923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 43}], {
             RGBColor[
             0.28128334652681497`, 0.41297700996688347`, 0.9393300425120572]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 159}], {
             RGBColor[
             0.3136551903315556, 0.445424436715442, 0.9412313286976333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 250}], {
             RGBColor[
             0.5914717422397695, 0.6712649506197794, 0.9645176465226413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 265}], {
             RGBColor[
             0.33106060760488654`, 0.46050013433589254`, 0.9423403864952837]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 321}], {
             RGBColor[
             0.40592228232110983`, 0.5237932330858539, 0.9475383119802647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 375}], {
             RGBColor[
             0.5251693952681782, 0.6189723240311502, 0.9580410648685853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 381}], {
             RGBColor[
             0.4584318822141302, 0.5664228918095258, 0.9516720600328457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 73}], {
             RGBColor[
             0.7006045298301564, 0.7642975982323854, 0.9723576162838719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 154}], {
             RGBColor[
             0.38445879652286996`, 0.5060246291478339, 0.9458799024750358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 207}], {
             RGBColor[
             0.727954773525495, 0.78458088854047, 0.9196887163194931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 231}], {
             RGBColor[
             0.7319454526356419, 0.7847834444142168, 0.7483208742175828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 280}], {
             RGBColor[
             0.6609862856881428, 0.7327070857621324, 0.9685787927899825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 291}], {
             RGBColor[
             0.4029859066570548, 0.5230071216631241, 0.947026189798555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 372}], {
             RGBColor[
             0.4246594484839896, 0.5417796542497288, 0.9484072087186067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 387}], {
             RGBColor[
             0.7323559181088062, 0.7864008749299258, 0.846750360776955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 392}], {
             RGBColor[
             0.4538438246502457, 0.5670576940355432, 0.9502668113611901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 61}], {
             RGBColor[
             0.6922832317014866, 0.7585884917186079, 0.9706119268210949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 70}], {
             RGBColor[
             0.5206025658737978, 0.6216876417114992, 0.9554028874970713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 90}], {
             RGBColor[
             0.455013316577665, 0.5650782796448561, 0.9511681309662149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 95}], {
             RGBColor[
             0.6166671775313934, 0.699516655497634, 0.9630752252136222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 148}], {
             RGBColor[
             0.753398204963267, 0.8071913078905049, 0.9764752552314916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 228}], {
             RGBColor[
             0.636796119371799, 0.7152415378489829, 0.9650814900206175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 276}], {
             RGBColor[
             0.5136893454446807, 0.6159005067065042, 0.954906915640446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 282}], {
             RGBColor[
             0.5401265280033323, 0.6375380737127259, 0.9569398853145381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 301}], {
             RGBColor[
             0.6622597119640214, 0.7351338899124986, 0.9676194629594083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 305}], {
             RGBColor[
             0.43991846139773166`, 0.551134523970906, 0.9502381313336548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 361}], {
             RGBColor[
             0.6661253263563327, 0.7381537372555297, 0.9680047512758134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 382}], {
             RGBColor[
             0.5680977300266858, 0.6602463556035756, 0.9591418807997055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 76}], {
             RGBColor[
             0.7412384433526549, 0.7966272742321531, 0.9588543796983187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 78}], {
             RGBColor[
             0.6882308949868694, 0.7548479180728579, 0.9706977704192388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 80}], {
             RGBColor[
             0.3983461558258563, 0.5137329380325955, 0.947297772598664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 96}], {
             RGBColor[
             0.7337595167644432, 0.7910495030282831, 0.9715142515957049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 104}], {
             RGBColor[
             0.5074633549072057, 0.611020638334111, 0.9543685206792656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 117}], {
             RGBColor[
             0.5027571486706928, 0.6071999280991349, 0.9539980308849257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 145}], {
             RGBColor[
             0.5902684165046813, 0.6780877088343735, 0.9609951332121542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 182}], {
             RGBColor[
             0.7040683510702725, 0.7674762756574705, 0.9722083611187378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 187}], {
             RGBColor[
             0.5310446251182854, 0.6301649758155824, 0.9562249246513207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 208}], {
             RGBColor[
             0.7568883156077878, 0.8080150805257468, 0.9196521671554474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 269}], {
             RGBColor[
             0.43128488545676785`, 0.5459545953512916, 0.9492614249811051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 323}], {
             RGBColor[
             0.5943467252976893, 0.6812737146597663, 0.9614016209186788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 365}], {
             RGBColor[
             0.6158463783807888, 0.6980694070516991, 0.963544505412321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 377}], {
             RGBColor[
             0.7312651196657809, 0.703112486524928, 0.6111274248736991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 388}], {
             RGBColor[
             0.7113073112182366, 0.7732484259831185, 0.9728988195999465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 395}], {
             RGBColor[
             0.7357193891257554, 0.7925111726263533, 0.9681966989045809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 44}], {
             RGBColor[
             0.6783726770992897, 0.7102125167419102, 0.6423359228562291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 66}], {
             RGBColor[
             0.7116867940817407, 0.7390675304559038, 0.6444586689318339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 81}], {
             RGBColor[
             0.7082966741101119, 0.7361311789288632, 0.644242653485007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 119}], {
             RGBColor[
             0.6316479178676686, 0.6682927973536585, 0.639411720483499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 128}], {
             RGBColor[
             0.9154953417400773, 0.9015169297787595, 0.6627019963337168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 130}], {
             RGBColor[
             0.7419353123128688, 0.7636291830032446, 0.6468386879108783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 135}], {
             RGBColor[
             0.8113895807416804, 0.8198590778726754, 0.6524131833695896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 146}], {
             RGBColor[
             0.7087536168979293, 0.7365269598050582, 0.6442717694753881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 151}], {
             RGBColor[
             0.8175199322861617, 0.8246481550916216, 0.6530241995201511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 213}], {
             RGBColor[
             0.6691358152754453, 0.7022120112882704, 0.6417473581886499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 224}], {
             RGBColor[
             0.600430576605977, 0.6354813923938663, 0.6376339390805636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 227}], {
             RGBColor[
             0.7582015627428953, 0.7768348578885711, 0.6481192267299687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 243}], {
             RGBColor[
             0.7315153269671484, 0.7551697694845982, 0.6460183884947992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 267}], {
             RGBColor[
             0.7334704000885821, 0.7567569859196186, 0.6461722990125873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 306}], {
             RGBColor[
             0.960259652820102, 0.9368343493066614, 0.6539206947672336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 311}], {
             RGBColor[
             0.6758174274870191, 0.7079992879583412, 0.6421731046104537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 346}], {
             RGBColor[
             0.6813981043082182, 0.7128329897278911, 0.6425287004027018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 350}], {
             RGBColor[
             0.6834304073312663, 0.7145932684599354, 0.6426581969542353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 363}], {
             RGBColor[
             0.6389966145869905, 0.6760167435399491, 0.639830217890242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 383}], {
             RGBColor[
             0.7120470973056453, 0.7393645836116385, 0.6444857781413706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 47}], {
             RGBColor[
             0.702943141530876, 0.76786379182045, 0.9710264610368058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 50}], {
             RGBColor[
             0.573072208762061, 0.6631039060558636, 0.9602346855314469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 136}], {
             RGBColor[
             0.4858189996411032, 0.58387403700797, 0.9548088348705105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 149}], {
             RGBColor[
             0.5559233788541126, 0.6482504515148514, 0.9591419772538272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 164}], {
             RGBColor[
             0.7360381192817282, 0.7937178399705627, 0.9743250591288597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 197}], {
             RGBColor[
             0.7438632837515664, 0.7998309179278529, 0.9751049983928937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 210}], {
             RGBColor[
             0.7827807984068047, 0.8305823250539879, 0.9788913853156143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 217}], {
             RGBColor[
             0.5440354885338848, 0.6379537584222108, 0.9583844913946711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 230}], {
             RGBColor[
             0.4897945300523448, 0.5880525715333715, 0.9550352354461604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 254}], {
             RGBColor[
             0.5269068585210173, 0.6231178000150415, 0.9572930702365039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 258}], {
             RGBColor[
             0.6013120005126329, 0.6862909911199007, 0.9623857794004794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 314}], {
             RGBColor[
             0.5313901498728519, 0.6270010016472253, 0.9575787415970238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 328}], {
             RGBColor[
             0.6547199083291102, 0.7296499366841454, 0.966590245543405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 41}], {
             RGBColor[
             0.8427231262258958, 0.8775492205481343, 0.9848288590942034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 48}], {
             RGBColor[
             0.590632544876593, 0.6739551408489463, 0.9631984000758809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 63}], {
             RGBColor[
             0.607182222177751, 0.6882896395162421, 0.9642529308792056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 103}], {
             RGBColor[
             0.4919914340482362, 0.5765145149494798, 0.9573525516615903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 265}], {
             RGBColor[
             0.5828370003821135, 0.667203032023287, 0.962701674874022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 295}], {
             RGBColor[
             0.6664475741228157, 0.7375988811347298, 0.9685883457384831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 48}], {
             RGBColor[
             0.6282998030060165, 0.703869331498121, 0.9668231558469038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 63}], {
             RGBColor[
             0.6448494803071746, 0.7182038301654169, 0.9678776866502286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.8809153931464201, 0.9078820389563487, 0.9885036906724023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 265}], {
             RGBColor[
             0.6205042585115371, 0.6971172226724618, 0.9663264306450449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 295}], {
             RGBColor[
             0.7041148322522393, 0.7675130717839046, 0.9722131015095059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 325}], {
             RGBColor[
             0.6862418283605125, 0.7530029620549512, 0.9708060731721787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 381}], {
             RGBColor[
             0.7478755331207808, 0.8030399801460949, 0.9756581041826067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 67}], {
             RGBColor[
             0.7140572344036591, 0.7741813147315835, 0.9465484817285132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 75}], {
             RGBColor[
             0.3988604406591513, 0.5196578825159008, 0.9467014180031201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 133}], {
             RGBColor[
             0.48252816091927636`, 0.590777124537022, 0.9524055308679105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 178}], {
             RGBColor[
             0.7013480891097936, 0.7647028549807342, 0.9680617496350614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 200}], {
             RGBColor[
             0.721946426644001, 0.7800650613870639, 0.9331941370964899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 278}], {
             RGBColor[
             0.7279547795830175, 0.7829376381079611, 0.8509941961862094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 296}], {
             RGBColor[
             0.7172337497705495, 0.7765503546911439, 0.9411714697802616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 320}], {
             RGBColor[
             0.47213312980834937`, 0.5823379699903566, 0.9515871959406047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 330}], {
             RGBColor[
             0.4047282463762726, 0.5247402809035806, 0.9470753093947182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 347}], {
             RGBColor[
             0.3496381276838004, 0.47041278562627853`, 0.9438070842872799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 367}], {
             RGBColor[
             0.7232303076318288, 0.7809839475427538, 0.9292909229588842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 398}], {
             RGBColor[
             0.5286893327968843, 0.628252843404359, 0.95603950741206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 159}], {
             RGBColor[
             0.29343545431635226`, 0.42417221215815487`, 0.9400798446439863]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 250}], {
             RGBColor[
             0.5712520062245662, 0.6500127260624924, 0.9633661624689942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 265}], {
             RGBColor[
             0.3108408715896832, 0.4392479097786054, 0.9411889024416368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 321}], {
             RGBColor[
             0.3857025463059065, 0.5025410085285669, 0.9463868279266178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 325}], {
             RGBColor[
             0.3765784414386586, 0.4951336491610948, 0.9456685449687706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 375}], {
             RGBColor[
             0.5049496592529747, 0.5977200994738632, 0.9568895808149384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 381}], {
             RGBColor[
             0.4382121461989269, 0.5451706672522385, 0.9505205759791986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 66}], {
             RGBColor[
             0.41983657639365, 0.5380630736974604, 0.9479725932942638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 81}], {
             RGBColor[
             0.4164464564220212, 0.5351267221704197, 0.947756577847437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 119}], {
             RGBColor[
             0.3397977001795779, 0.4672883405952152, 0.9429256448459291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[
             0.6236451240519867, 0.700512473020316, 0.9662159206961469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 130}], {
             RGBColor[
             0.45008509462477814`, 0.5626247262448012, 0.9503526122733083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 135}], {
             RGBColor[
             0.5195393630535897, 0.6188546211142321, 0.9559271077320195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 146}], {
             RGBColor[
             0.4169033992098386, 0.5355225030466149, 0.9477856938378181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 151}], {
             RGBColor[
             0.5256697145980711, 0.6236436983331782, 0.9565381238825811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 227}], {
             RGBColor[
             0.4663513450548046, 0.5758304011301277, 0.9516331510923985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 243}], {
             RGBColor[
             0.43966510927905766`, 0.5541653127261549, 0.9495323128572292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 267}], {
             RGBColor[
             0.4416201824004914, 0.5557525291611751, 0.9496862233750172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 275}], {
             RGBColor[
             0.6050796326889996, 0.6857088541543084, 0.9644451275563354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 311}], {
             RGBColor[
             0.38396720979892845`, 0.5069948311998977, 0.9456870289728836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 317}], {
             RGBColor[
             0.32568709891066594`, 0.45245720399779493`, 0.9421220669784285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 326}], {
             RGBColor[
             0.4519358962446776, 0.5641272903774983, 0.9504983141565364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 344}], {
             RGBColor[
             0.3613036847530124, 0.48736482490701494`, 0.9442429291975261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 346}], {
             RGBColor[
             0.3895478866201275, 0.5118285329694476, 0.9460426247651317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 383}], {
             RGBColor[
             0.42019687961755464`, 0.538360126853195, 0.9479997025038006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 48}], {
             RGBColor[
             0.37552731851053966`, 0.49968462156716575`, 0.9451492465630903]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 74}], {
             RGBColor[
             0.32879415877254314`, 0.4568025434178551, 0.9422594791724637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 103}], {
             RGBColor[
             0.27688620768218286`, 0.4022439956676993, 0.9393033981487997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 116}], {
             RGBColor[
             0.5776139133456053, 0.6637269646403542, 0.9619253400182732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 262}], {
             RGBColor[
             0.5547967237911509, 0.6459020027433509, 0.9596511358022447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 290}], {
             RGBColor[
             0.626275132807457, 0.7022080152672222, 0.966651631261254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 304}], {
             RGBColor[
             0.33327997157940753`, 0.46151741709482863`, 0.9425149395756492]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 338}], {
             RGBColor[
             0.4371906921407567, 0.5518394102990556, 0.9494251220563779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 52}], {
             RGBColor[
             0.6680560250660521, 0.7331603520713195, 0.9157447147545961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 60}], {
             RGBColor[
             0.6507272055210365, 0.7181509995532219, 0.9146405376964613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 102}], {
             RGBColor[
             0.8726326960837556, 0.9002403044131796, 0.932306664475657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 105}], {
             RGBColor[
             0.7409262122264263, 0.7951116868345403, 0.9207098754899761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 128}], {
             RGBColor[
             0.9231951547326323, 0.9400697215796485, 0.9372587814521931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 139}], {
             RGBColor[
             0.9266003846393818, 0.9427849594747872, 0.9375835753205835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 199}], {
             RGBColor[
             0.660853715433658, 0.7269220734663474, 0.9152857899535722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 213}], {
             RGBColor[
             0.6768356282680001, 0.7407648030891594, 0.916304143307126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 215}], {
             RGBColor[
             0.9774793821471456, 0.9482743238440345, 0.6116565472439084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 259}], {
             RGBColor[
             0.8001032870343436, 0.8431543020604473, 0.9253685115916228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 271}], {
             RGBColor[
             0.9831331918301955, 0.9867036811267348, 0.9027923196795835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 287}], {
             RGBColor[
             0.7436476227171395, 0.7973210504690467, 0.9209241148926601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 333}], {
             RGBColor[
             0.8341938626171178, 0.8702115955630876, 0.9284754407870244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 337}], {
             RGBColor[
             0.9619087106607098, 0.9708744978224306, 0.9387198300682666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 345}], {
             RGBColor[
             0.6464023782837953, 0.7142604708872027, 0.914370257336332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 350}], {
             RGBColor[
             0.6911302203238212, 0.7531460602608244, 0.9172149820727115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 353}], {
             RGBColor[
             0.6252371295913115, 0.6920144525571275, 0.9131649277344747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 400}], {
             RGBColor[
             0.7238940082470606, 0.781284176352046, 0.9193690380017014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 136}], {
             RGBColor[
             0.48633250383924387`, 0.5842751903903339, 0.9548600161700116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 149}], {
             RGBColor[
             0.5564368830522533, 0.6486516048972153, 0.9591931585533284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 155}], {
             RGBColor[
             0.5614621862393575, 0.6530042699388028, 0.9595133664287094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 268}], {
             RGBColor[
             0.46721383350534673`, 0.5641802556756959, 0.9537712361780343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 279}], {
             RGBColor[
             0.736551623479869, 0.7941189933529265, 0.9743762404283609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 299}], {
             RGBColor[
             0.7711715203926983, 0.8213171009644629, 0.9777862848255758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 300}], {
             RGBColor[
             0.5103012810047716, 0.6086912652464689, 0.9562534387869739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 371}], {
             RGBColor[
             0.5503707807710646, 0.6433974519924154, 0.9588066318800146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.39275889895787164`, 0.5146097504662288, 0.946247227631906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 86}], {
             RGBColor[
             0.5413644580885217, 0.6354665369987769, 0.9582878176212939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 103}], {
             RGBColor[
             0.2775681108283568, 0.4028346258994665, 0.9393468484142906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 295}], {
             RGBColor[
             0.4520242509029363, 0.5639189920847165, 0.9505826424911834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 191}], {
             RGBColor[
             0.3697304682935355, 0.49466368126736027`, 0.9447798763932163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 225}], {
             RGBColor[
             0.4281811924163802, 0.5431196080435217, 0.9491042007918271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 235}], {
             RGBColor[
             0.3681955817044077, 0.49333423964950085`, 0.9446820747770039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 261}], {
             RGBColor[
             0.49514478700029063`, 0.5971030300029923, 0.9546360664465574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 327}], {
             RGBColor[
             0.4384849126543069, 0.5514846323099776, 0.9499153473927275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 335}], {
             RGBColor[
             0.5876172678631089, 0.6696032371255002, 0.9637838625302009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 349}], {
             RGBColor[
             0.5274776017233231, 0.6223616706031185, 0.9578586992508169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 355}], {
             RGBColor[
             0.5109131974910651, 0.6094214321227436, 0.9562077142401038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 127}], {
             RGBColor[
             0.7131176111685125, 0.7557223310074155, 0.668044869554632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 137}], {
             RGBColor[
             0.6650452936653569, 0.7354905992644722, 0.969259300579602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 138}], {
             RGBColor[
             0.40160854991157147`, 0.5222748733259337, 0.9468111195652367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 147}], {
             RGBColor[
             0.36034625795275677`, 0.48359835684244823`, 0.944289467835722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 164}], {
             RGBColor[
             0.606680690711054, 0.6893591075883401, 0.9635844649230019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 197}], {
             RGBColor[
             0.6145058551808922, 0.6954721855456304, 0.9643644041870358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 210}], {
             RGBColor[
             0.6534233698361304, 0.7262235926717653, 0.9681507911097564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 217}], {
             RGBColor[
             0.4146780599632106, 0.5335950260399883, 0.9476438971888133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 230}], {
             RGBColor[
             0.3604371014816705, 0.48369383915114905`, 0.9442946412403026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 242}], {
             RGBColor[
             0.4884973324072086, 0.5953624169262343, 0.9529474918965744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 254}], {
             RGBColor[
             0.39754942995034304`, 0.5187590676328189, 0.9465524760306461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 258}], {
             RGBColor[
             0.47195457194195867`, 0.5819322587376782, 0.9516451851946216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 328}], {
             RGBColor[
             0.5253624797584359, 0.625291204301923, 0.9558496513375472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 331}], {
             RGBColor[
             0.4285117216952361, 0.5455770485322133, 0.9485253658817511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 79}], {
             RGBColor[
             0.6652989267258153, 0.7363223722174068, 0.9687869839871008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 87}], {
             RGBColor[
             0.7200672847943503, 0.7797415823301838, 0.9652879875561526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 126}], {
             RGBColor[
             0.40093067803845406`, 0.5204201027071398, 0.9470835224206362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 176}], {
             RGBColor[
             0.6327625593537074, 0.7107759202247232, 0.9655782410615784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 205}], {
             RGBColor[
             0.4779004701015447, 0.587020156656092, 0.9520412220949487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 232}], {
             RGBColor[
             0.7017694836501778, 0.7654030043419981, 0.9722655782641971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 277}], {
             RGBColor[
             0.6530055078340832, 0.7265898654296995, 0.9675958689849933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 298}], {
             RGBColor[
             0.7341045532514032, 0.7902105541615361, 0.9415265535643262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 373}], {
             RGBColor[
             0.43922334641495353`, 0.5537318680946479, 0.9495182035815763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 390}], {
             RGBColor[
             0.5399771875131356, 0.6374168323750719, 0.9569281286840976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 60}], {
             RGBColor[
             0.33316070981459833`, 0.4629887945224097, 0.942449683720306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 68}], {
             RGBColor[
             0.4486270538265703, 0.5604626445097853, 0.9505081588639013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 105}], {
             RGBColor[
             0.4233597165199882, 0.5399494818037281, 0.9485190215138208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 129}], {
             RGBColor[
             0.4140638443927525, 0.5324026740365712, 0.9477872164080632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 199}], {
             RGBColor[
             0.34328721972721987`, 0.4717598684355352, 0.9430949359774171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 271}], {
             RGBColor[
             0.6655666961237574, 0.7315414760959227, 0.9306014657034283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 287}], {
             RGBColor[
             0.4260811270107014, 0.5421588454382346, 0.9487332609165049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 303}], {
             RGBColor[
             0.4157497749288865, 0.5337713883961098, 0.9479199390356348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 333}], {
             RGBColor[
             0.5166273669106798, 0.6150493905322754, 0.9562845868108693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 337}], {
             RGBColor[
             0.6443422149542717, 0.7157122927916184, 0.9665289760921114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 345}], {
             RGBColor[
             0.3288358825773573, 0.45909826585639046`, 0.9421794033601769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 353}], {
             RGBColor[
             0.3076706338848735, 0.43685224752631524`, 0.9409740737583194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 391}], {
             RGBColor[
             0.6658197704391711, 0.7130374255423582, 0.6624128221803396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 69}], {
             RGBColor[
             0.6947437631996642, 0.7561961368364709, 0.9145124358207737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 93}], {
             RGBColor[
             0.3480719093443144, 0.474414220396841, 0.9434543649150268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 131}], {
             RGBColor[
             0.4425451467309378, 0.5569647743440211, 0.9496315765638476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 142}], {
             RGBColor[
             0.5463030747013022, 0.6404842181793464, 0.9582892566379304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 188}], {
             RGBColor[
             0.5937676846814034, 0.6775639322401982, 0.963020085378748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 201}], {
             RGBColor[
             0.35450979301463836`, 0.48118084431975183`, 0.9438209928660564]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 264}], {
             RGBColor[
             0.33556599370581575`, 0.46126971013993046`, 0.9427421715202584]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 273}], {
             RGBColor[
             0.6476964504662999, 0.7202746063734053, 0.9682409913883305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 281}], {
             RGBColor[
             0.6970168516695887, 0.7571361173344937, 0.8768414773097346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[
             0.3563288226944187, 0.48305584943569846`, 0.9439259353862504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 394}], {
             RGBColor[
             0.39986050773486076`, 0.5207608070516213, 0.9466997358634697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 64}], {
             RGBColor[
             0.4979609618376437, 0.6002669309861025, 0.9545087951298681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 83}], {
             RGBColor[
             0.3879071513784854, 0.5104074105688883, 0.9459380785663795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 123}], {
             RGBColor[
             0.5413338204501512, 0.634150137780128, 0.9588317963339545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 161}], {
             RGBColor[
             0.6700584519262437, 0.7321088097719455, 0.7842517174601047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 196}], {
             RGBColor[
             0.3182503705233659, 0.44840787454236736`, 0.9415606227175874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 198}], {
             RGBColor[
             0.6481658199596112, 0.7182803856325307, 0.9559184284869884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 206}], {
             RGBColor[
             0.5394387645282188, 0.6326697056909559, 0.9586429148699607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 214}], {
             RGBColor[
             0.35005510987190747`, 0.47762187471481427`, 0.9435261799528264]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 310}], {
             RGBColor[
             0.6422188324424669, 0.7138451320795429, 0.9659851271307576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 332}], {
             RGBColor[
             0.4548188048673844, 0.5653614461439008, 0.9510309466101066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 389}], {
             RGBColor[
             0.36099339486898485`, 0.4870960674050933, 0.9442231578004945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 57}], {
             RGBColor[
             0.324692773108183, 0.45352220563881307`, 0.9419881804569717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 68}], {
             RGBColor[
             0.4162251098171261, 0.5302656214584898, 0.9485216018192297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 72}], {
             RGBColor[
             0.37321857151169846`, 0.4953509762396716, 0.9451359695856858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 83}], {
             RGBColor[
             0.3578611880082202, 0.48225101953221955`, 0.9441016425247244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 123}], {
             RGBColor[
             0.511287857079886, 0.6059937467434591, 0.9569953602922995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 161}], {
             RGBColor[
             0.6400124885559785, 0.7039524187352767, 0.7824152814184497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 196}], {
             RGBColor[
             0.2882044071531007, 0.4202514835056986, 0.9397241866759325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 236}], {
             RGBColor[
             0.36935660430142075`, 0.49220777134896737`, 0.9448341202859296]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 262}], {
             RGBColor[
             0.5102168367793307, 0.6051570575446097, 0.9568886109979939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 284}], {
             RGBColor[
             0.5228453391574877, 0.6150225395825987, 0.9581473020949841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 334}], {
             RGBColor[
             0.44438896462713295`, 0.5531303075604537, 0.9507387636374729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 366}], {
             RGBColor[
             0.6342168066044522, 0.7021290735607916, 0.9268340548267077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 397}], {
             RGBColor[
             0.6383165269450038, 0.704064318816614, 0.8696345391501147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 65}], {
             RGBColor[
             0.7649390654747085, 0.8164292357875264, 0.9757596961968114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 100}], {
             RGBColor[
             0.9441595770169651, 0.9578748844863292, 0.9794074499821706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 174}], {
             RGBColor[
             0.9332297630139372, 0.9495465349432788, 0.9917751186480293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 198}], {
             RGBColor[
             0.9440875247088709, 0.9578211479929273, 0.9795294157455225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 203}], {
             RGBColor[
             0.8537678651206518, 0.8865904655854295, 0.9840885793192481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 206}], {
             RGBColor[
             0.8353604692774784, 0.8722104680513525, 0.9822539021284948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 266}], {
             RGBColor[
             0.7089551721196637, 0.7709789891162464, 0.9713524390361438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 341}], {
             RGBColor[
             0.964866217866776, 0.9720021535997123, 0.8854363383903375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 358}], {
             RGBColor[
             0.9322409015687685, 0.9487580436688301, 0.9916808001606219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 68}], {
             RGBColor[
             0.45523224158458353`, 0.5661837261593867, 0.9509290355871036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 72}], {
             RGBColor[
             0.4122257032791558, 0.5312690809405686, 0.9475434033535597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 86}], {
             RGBColor[
             0.5351097996979851, 0.6300490662691653, 0.9578892763194262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 108}], {
             RGBColor[
             0.3946637916443586, 0.5162596727685737, 0.9463686057094585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 236}], {
             RGBColor[
             0.4083637360688781, 0.5281258760498644, 0.9472415540538037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 262}], {
             RGBColor[
             0.5492239685467881, 0.6410751622455066, 0.9592960447658678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 284}], {
             RGBColor[
             0.5618524709249451, 0.6509406442834956, 0.9605547358628581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 297}], {
             RGBColor[
             0.6758012681719352, 0.7393528759053511, 0.8972719239949303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 325}], {
             RGBColor[
             0.4278965886206729, 0.5439914116261517, 0.9487770728519884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 376}], {
             RGBColor[
             0.3949816828111732, 0.5165350141195938, 0.9463888614535079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 397}], {
             RGBColor[
             0.6773236587124611, 0.739982423517511, 0.8720419729179887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 124}], {
             RGBColor[
             0.9170854758351246, 0.9345483817241791, 0.9084660867677277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 152}], {
             RGBColor[
             0.588748616791423, 0.6708234794933899, 0.9637453163822265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 156}], {
             RGBColor[
             0.6653381022484319, 0.7362872806315617, 0.9688670641427912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 160}], {
             RGBColor[
             0.6918879450448278, 0.7578416390704636, 0.9709571650230022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 179}], {
             RGBColor[
             0.5702743033299612, 0.6535866516935799, 0.9626133800695452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 181}], {
             RGBColor[
             0.7558662422557838, 0.8094112368747637, 0.9762473340910631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 220}], {
             RGBColor[
             0.5927715798587588, 0.6743079679023132, 0.9640016560315106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[
             0.6149746796398845, 0.6935391769724814, 0.9654164179161336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 352}], {
             RGBColor[
             0.7791567570629608, 0.8276059640565989, 0.978568714944807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 396}], {
             RGBColor[
             0.6659658147230598, 0.7367968858965893, 0.9689164799681804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 132}], {
             RGBColor[
             0.6169681805584437, 0.6999215889339638, 0.9629891416839244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 149}], {
             RGBColor[
             0.5231848094724219, 0.6225920115850521, 0.955935527586531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 155}], {
             RGBColor[
             0.528210112659526, 0.6269446766266396, 0.9562557354619121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 164}], {
             RGBColor[
             0.7032995499000375, 0.7680594000407633, 0.9711186094615635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 210}], {
             RGBColor[
             0.7500422290251139, 0.8049238851241886, 0.975684935648318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 230}], {
             RGBColor[
             0.457055960670654, 0.5623941316035722, 0.9518287857788642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 258}], {
             RGBColor[
             0.5685734311309422, 0.6606325511901014, 0.9591793297331832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 264}], {
             RGBColor[
             0.4522860291817713, 0.5573806311776325, 0.9515571452370536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 268}], {
             RGBColor[
             0.4339617599255153, 0.5381206623635326, 0.9505136052112368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 279}], {
             RGBColor[
             0.7032995499000375, 0.7680594000407633, 0.9711186094615635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 299}], {
             RGBColor[
             0.7379194468128668, 0.7952575076522997, 0.9745286538587785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 300}], {
             RGBColor[
             0.47704920742494006`, 0.5826316719343058, 0.9529958078201766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 328}], {
             RGBColor[
             0.6219813389474194, 0.7039914967543461, 0.9633837958761088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 394}], {
             RGBColor[
             0.5165805432108164, 0.6168717280893233, 0.9555147095802649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 68}], {
             RGBColor[
             0.43129823428155467`, 0.5454532919916878, 0.9494039818057664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 72}], {
             RGBColor[
             0.388291695976127, 0.5105386467728696, 0.9460183495722224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 102}], {
             RGBColor[
             0.5377373808323019, 0.6300687468642698, 0.959011633441367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 105}], {
             RGBColor[
             0.40603089697497263`, 0.5249401292856306, 0.9474148444556859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 108}], {
             RGBColor[
             0.37072978434132986`, 0.4955292386008747, 0.9448435519281211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 139}], {
             RGBColor[
             0.591705069387928, 0.6726134019258774, 0.9642885442862934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 297}], {
             RGBColor[
             0.6518672608689065, 0.7186224417376521, 0.8957468702135929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 333}], {
             RGBColor[
             0.49929854736566415`, 0.6000400380141778, 0.9551804097527343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 337}], {
             RGBColor[
             0.627013395409256, 0.7007029402735208, 0.9654247990339765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 345}], {
             RGBColor[
             0.31150706303234166`, 0.44408891333829287`, 0.9410752263020419]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 353}], {
             RGBColor[
             0.29034181433985784`, 0.42184289500821764`, 0.9398698967001845]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 70}], {
             RGBColor[
             0.6323920996415665, 0.7099661726476122, 0.9658970775168925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 90}], {
             RGBColor[
             0.5668028503454337, 0.6533568105809693, 0.961662320986036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 95}], {
             RGBColor[
             0.7284567112991621, 0.7877951864337471, 0.9735694152334433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 148}], {
             RGBColor[
             0.8651877387310357, 0.895469838826618, 0.9869694452513127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 228}], {
             RGBColor[
             0.7485856531395676, 0.8035200687850961, 0.9755756800404386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 282}], {
             RGBColor[
             0.6519160617711008, 0.725816604648839, 0.9674340753343591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 285}], {
             RGBColor[
             0.6020051521121532, 0.6838472750521698, 0.9639053805264381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 301}], {
             RGBColor[
             0.7740492457317901, 0.8234124208486118, 0.9781136529792294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 382}], {
             RGBColor[
             0.6798872637944544, 0.7485248865396886, 0.9696360708195266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 91}], {
             RGBColor[
             0.7000924541176423, 0.7656368131472049, 0.9707423311566432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 111}], {
             RGBColor[
             0.6449525725852829, 0.7213447467265275, 0.9660781431806965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 117}], {
             RGBColor[
             0.6022942789613643, 0.6867128222284025, 0.9627199260441432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 223}], {
             RGBColor[
             0.511985683833214, 0.6080683463057587, 0.956822778445219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 247}], {
             RGBColor[
             0.49776351024097637`, 0.5931199401224293, 0.9560128466989615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 256}], {
             RGBColor[
             0.8323151877347938, 0.8698304264034474, 0.9818975013786384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 319}], {
             RGBColor[
             0.5502849494770667, 0.6423253044416696, 0.959223481067178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 323}], {
             RGBColor[
             0.6938838555883607, 0.7607866087890337, 0.9701235160778963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 362}], {
             RGBColor[
             0.6682040595895453, 0.7402213513441402, 0.9679085854106754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 395}], {
             RGBColor[
             0.835256519416427, 0.8720240667556207, 0.9769185940637984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 103}], {
             RGBColor[
             0.29411778812951483`, 0.41716912456676236`, 0.9404013792176154]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 295}], {
             RGBColor[
             0.4685739282040944, 0.5782534907520125, 0.9516371732945081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 88}], {
             RGBColor[
             0.6281117038042777, 0.7088491413966553, 0.9639479405420417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 101}], {
             RGBColor[
             0.8194577651384296, 0.8581207926858611, 0.9007590982343359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 115}], {
             RGBColor[
             0.5494574790896408, 0.6448706259395673, 0.9577901076725832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 120}], {
             RGBColor[
             0.8168520774879562, 0.8569382423875458, 0.9392385611147377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 123}], {
             RGBColor[
             0.6935172142065389, 0.7605001857549767, 0.9700869726914149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 140}], {
             RGBColor[
             0.779034887257972, 0.8280180396515296, 0.978421951265166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 161}], {
             RGBColor[
             0.8222418456826314, 0.8584588577467943, 0.7955068938175651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 193}], {
             RGBColor[
             0.48745591530240373`, 0.5911679876762688, 0.9538394228538906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 195}], {
             RGBColor[
             0.8144083092698171, 0.8331678276324888, 0.6687050848732656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 214}], {
             RGBColor[
             0.5022385036282951, 0.6039719226896632, 0.9547813563102867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 233}], {
             RGBColor[
             0.6082899367384019, 0.6927569379321472, 0.9623874984290908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 257}], {
             RGBColor[
             0.6610895998022, 0.7351674869233096, 0.9668548911408763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 283}], {
             RGBColor[
             0.7742801618793026, 0.8242267506981609, 0.9779684413139551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 312}], {
             RGBColor[
             0.5520661872876876, 0.6471119652770088, 0.9579613589179501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 332}], {
             RGBColor[
             0.6070021986237721, 0.6917114941187497, 0.962286122967567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 356}], {
             RGBColor[
             0.5917050354388211, 0.6792925679158583, 0.9610818742462925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 360}], {
             RGBColor[
             0.5004781203674171, 0.6024471671885259, 0.9546691862455494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 380}], {
             RGBColor[
             0.47687891845965924`, 0.5815321882066744, 0.9531828410708423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 389}], {
             RGBColor[
             0.5131767886253725, 0.6134461153799422, 0.9554783341579549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 100}], {
             RGBColor[
             0.7714776649118984, 0.8213057125418086, 0.9646915528895059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 167}], {
             RGBColor[
             0.6319414894518796, 0.7116292651931855, 0.9644744213796765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 174}], {
             RGBColor[
             0.7605478509088704, 0.8129773629987582, 0.9770592215553645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 198}], {
             RGBColor[
             0.771405612603804, 0.8212519760484067, 0.9648135186528578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 203}], {
             RGBColor[
             0.681085953015585, 0.750021293640909, 0.9693726822265833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 206}], {
             RGBColor[
             0.6626785571724116, 0.7356412961068319, 0.9675380050358302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 211}], {
             RGBColor[
             0.46654693632102184`, 0.5747487159751559, 0.9519912956797376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 266}], {
             RGBColor[
             0.536273260014597, 0.6344098171717258, 0.956636541943479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 313}], {
             RGBColor[
             0.7538604043736363, 0.807644974657463, 0.9764213669348798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 329}], {
             RGBColor[
             0.46095813142265, 0.569907974073688, 0.9516351819735995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 340}], {
             RGBColor[
             0.5365152629599902, 0.6346062860649045, 0.9566555933018264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 341}], {
             RGBColor[
             0.7921843057617091, 0.8354329816551918, 0.8707204412976728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 358}], {
             RGBColor[
             0.7595589894637016, 0.8121888717243095, 0.9769649030679572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 81}], {
             RGBColor[
             0.4497605734044723, 0.5639817358844135, 0.9498793239230419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 119}], {
             RGBColor[
             0.37311181716202896`, 0.49614335430920886`, 0.9450483909215339]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 130}], {
             RGBColor[
             0.4833992116072292, 0.5914797399587948, 0.9524753583489131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 146}], {
             RGBColor[
             0.45021751619228967`, 0.5643775167606084, 0.9499084399134229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 151}], {
             RGBColor[
             0.5589838315805221, 0.6524987120471719, 0.9586608699581859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 158}], {
             RGBColor[
             0.7216541404774188, 0.7726897302927536, 0.6831799275036154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 243}], {
             RGBColor[
             0.47297922626150873`, 0.5830203264401486, 0.951655058932834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 267}], {
             RGBColor[
             0.4749342993829424, 0.5846075428751689, 0.951808969450622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 275}], {
             RGBColor[
             0.6383937496714507, 0.714563867868302, 0.9665678736319402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 311}], {
             RGBColor[
             0.4172813267813795, 0.5358498449138915, 0.9478097750484884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 317}], {
             RGBColor[
             0.359001215893117, 0.4813122177117886, 0.9442448130540333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 344}], {
             RGBColor[
             0.39461780173546346`, 0.5162198386210086, 0.9463656752731309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 346}], {
             RGBColor[
             0.4228620036025786, 0.5406835466834414, 0.9481653708407365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 354}], {
             RGBColor[
             0.6959765578587377, 0.7603988073561316, 0.9692855274240506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 75}], {
             RGBColor[
             0.6508815807801176, 0.7196984555631226, 0.9424575794142682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 126}], {
             RGBColor[
             0.636630305159863, 0.7072101362255394, 0.9415547945407872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 133}], {
             RGBColor[
             0.7345493010402426, 0.7908176975842438, 0.9481616922790586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 200}], {
             RGBColor[
             0.9739675667649672, 0.9801056344342856, 0.9289502985076381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 320}], {
             RGBColor[
             0.7241542699293155, 0.7823785430375783, 0.9473433573517529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 347}], {
             RGBColor[
             0.6016592678047666, 0.6704533586735002, 0.939563245698428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 398}], {
             RGBColor[
             0.7807104729178506, 0.8282934164515807, 0.9517956688232081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 72}], {
             RGBColor[
             0.503758039988099, 0.6080124967602453, 0.9540768247158177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 236}], {
             RGBColor[
             0.4998960727778213, 0.6048692918695411, 0.9537749754160616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 262}], {
             RGBColor[
             0.6407563052557312, 0.7178185780651833, 0.9658294661281258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 284}], {
             RGBColor[
             0.6533848076338882, 0.7276840601031723, 0.967088157225116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 333}], {
             RGBColor[
             0.614764891377636, 0.6975138880015535, 0.9632388848963296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 334}], {
             RGBColor[
             0.5749284331035335, 0.6657918280810273, 0.9596796187676049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 337}], {
             RGBColor[
             0.742479739421228, 0.7981767902608965, 0.9734832741775717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 376}], {
             RGBColor[
             0.4865140195201163, 0.5932784299392705, 0.9529222828157657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 391}], {
             RGBColor[
             0.7639572949061274, 0.7955019230116362, 0.6693671202657998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 397}], {
             RGBColor[
             0.7688559954214044, 0.8167258393371877, 0.8785753942802466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 93}], {
             RGBColor[
             0.639303244926536, 0.7066864407302285, 0.9110343677666786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 131}], {
             RGBColor[
             0.7337764823131594, 0.7892369946774086, 0.9172115794154994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 142}], {
             RGBColor[
             0.8375344102835238, 0.8727564385127339, 0.9258692594895822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 188}], {
             RGBColor[
             0.884999020263625, 0.9098361525735856, 0.9306000882303997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 201}], {
             RGBColor[
             0.64574112859686, 0.7134530646531393, 0.911400995717708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 273}], {
             RGBColor[
             0.9389277860485215, 0.9525468267067929, 0.9358209942399822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 281}], {
             RGBColor[
             0.9882481872518103, 0.9894083376678813, 0.8444214801613865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 293}], {
             RGBColor[
             0.6475601582766403, 0.7153280697690859, 0.9115059382379022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 394}], {
             RGBColor[
             0.6910918433170823, 0.7530330273850088, 0.9142797387151216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 90}], {
             RGBColor[
             0.3951221845177448, 0.5164559605738606, 0.9464532816620124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 95}], {
             RGBColor[
             0.5567760454714733, 0.6508943364266384, 0.9583603759094197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 177}], {
             RGBColor[
             0.36806535604589463`, 0.4899394125371941, 0.9448420653466312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 228}], {
             RGBColor[
             0.5769049873118788, 0.6666192187779874, 0.9603666407164151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 246}], {
             RGBColor[
             0.6817754854144819, 0.7492145394013474, 0.9706414366396894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 260}], {
             RGBColor[
             0.43659678952319947`, 0.5523791788553262, 0.9490960068184069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 285}], {
             RGBColor[
             0.4303244862844644, 0.5469464250450611, 0.9486963412024145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 110}], {
             RGBColor[
             0.323245123171639, 0.45034208734991915`, 0.941966466443692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 131}], {
             RGBColor[
             0.431608186888789, 0.5474917294363371, 0.9489346831538796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 201}], {
             RGBColor[
             0.34357283317248954`, 0.4717077994120677, 0.9431240994560884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 212}], {
             RGBColor[
             0.3690428083219113, 0.4940680647627345, 0.9447360593078982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 271}], {
             RGBColor[
             0.6811411854105229, 0.7450313159195265, 0.9315938583888009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 273}], {
             RGBColor[
             0.6367594906241509, 0.7108015614657213, 0.9675440979783626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 287}], {
             RGBColor[
             0.44165561629746697`, 0.5556486852618385, 0.9497256536018774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 289}], {
             RGBColor[
             0.6052083132132746, 0.6856435090321842, 0.9645347185108446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 292}], {
             RGBColor[
             0.3210956072024832, 0.4480828097791524, 0.9418440546891725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 303}], {
             RGBColor[
             0.43132426421565206`, 0.5472612282197138, 0.9489123317210073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 385}], {
             RGBColor[
             0.5112172180600588, 0.6121219272871584, 0.9552017977051719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 400}], {
             RGBColor[
             0.4219020018273881, 0.5396118111448377, 0.9481705767109188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 86}], {
             RGBColor[
             0.5836355981015006, 0.671877836870024, 0.9610370654481402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 108}], {
             RGBColor[
             0.44318959004787406`, 0.5580884433694322, 0.9495163948381724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 236}], {
             RGBColor[
             0.45688953447239355`, 0.5699546466507228, 0.9503893431825177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 262}], {
             RGBColor[
             0.5977497669503036, 0.6829039328463651, 0.9624438338945819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 284}], {
             RGBColor[
             0.6103782693284605, 0.6927694148843542, 0.963702524991572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 297}], {
             RGBColor[
             0.7243270665754507, 0.7811816465062096, 0.9004197131236442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 325}], {
             RGBColor[
             0.4764223870241884, 0.5858201822270102, 0.9519248619807024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 333}], {
             RGBColor[
             0.5717583530722083, 0.6625992427827353, 0.9598532526627856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 337}], {
             RGBColor[
             0.6994732011158004, 0.7632621450420782, 0.9700976419440278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 376}], {
             RGBColor[
             0.44350748121468864`, 0.5583637847204523, 0.9495366505822218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 397}], {
             RGBColor[
             0.7258494571159766, 0.7818111941183694, 0.8751897620467026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.8485817308045185, 0.882534435479198, 0.985304405679043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 162}], {
             RGBColor[
             0.6589619651116246, 0.7286896505371373, 0.9695768826036364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 183}], {
             RGBColor[
             0.9623157309768073, 0.9683547026062032, 0.7749808367429976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 189}], {
             RGBColor[
             0.8140224568528425, 0.8555364680079386, 0.9818598602263169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 207}], {
             RGBColor[
             0.9582722770771516, 0.968039266794047, 0.94060446869513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 280}], {
             RGBColor[
             0.8913037892397994, 0.9161654640157093, 0.9894945451656195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 291}], {
             RGBColor[
             0.6333034102087114, 0.7064654999167012, 0.9679419421741919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 336}], {
             RGBColor[
             0.647416488972503, 0.7186895393979337, 0.9688412150733152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 368}], {
             RGBColor[
             0.6459563097427852, 0.7174248055398942, 0.9687481737439834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 387}], {
             RGBColor[
             0.9626734216604627, 0.9698592531835029, 0.867666113152592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 116}], {
             RGBColor[
             0.5315626567537827, 0.6214355167228107, 0.9590790228931374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 118}], {
             RGBColor[
             0.30787268794822187`, 0.43868141693352664`, 0.9409263815516682]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 141}], {
             RGBColor[
             0.6222852967186885, 0.6927814153288603, 0.9444565516019547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 179}], {
             RGBColor[
             0.2890640036249959, 0.4211549738992246, 0.9397731394233478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 209}], {
             RGBColor[
             0.42960295537308735`, 0.5407743805365814, 0.9496067941083152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 286}], {
             RGBColor[
             0.6333607846212976, 0.7010414960721794, 0.9257086395327161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 290}], {
             RGBColor[
             0.5802238762156344, 0.6599165673496787, 0.9638053141361183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 304}], {
             RGBColor[
             0.28722871498758484`, 0.41922596917728516`, 0.9396686224505135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 338}], {
             RGBColor[
             0.391139435548934, 0.5095479623815121, 0.9465788049312422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 386}], {
             RGBColor[
             0.39403058898309473`, 0.5118951309843417, 0.9468064071202233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 126}], {
             RGBColor[
             0.32143351141535514`, 0.4526867040098568, 0.9417077308153938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 133}], {
             RGBColor[
             0.4193525072957348, 0.5362942653685611, 0.9483146285536654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 178}], {
             RGBColor[
             0.6381724354862521, 0.7102199958122732, 0.9639708473208164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 200}], {
             RGBColor[
             0.6587707730204595, 0.7255822022186029, 0.9291032347822448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 296}], {
             RGBColor[
             0.6540580961470079, 0.7220674955226829, 0.9370805674660165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 320}], {
             RGBColor[
             0.4089574761848078, 0.5278551108218956, 0.9474962936263596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 330}], {
             RGBColor[
             0.34155259275273103`, 0.47025742173511975`, 0.9429844070804732]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 347}], {
             RGBColor[
             0.28646247406025893`, 0.41592992645781757`, 0.9397161819730347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 398}], {
             RGBColor[
             0.4655136791733428, 0.5737699842358981, 0.9519486050978149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 78}], {
             RGBColor[
             0.9015932004240297, 0.9238825371393761, 0.9735766603853915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 80}], {
             RGBColor[
             0.6117084612630166, 0.6827675570991136, 0.9501766625648167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.9471218222016036, 0.9600841220948013, 0.9743931415618577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 117}], {
             RGBColor[
             0.7161194541078532, 0.7762345471656531, 0.9568769208510786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.9174306565074328, 0.9365108947239886, 0.9750872510848905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 187}], {
             RGBColor[
             0.7444069305554458, 0.7991995948821006, 0.9591038146174735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 208}], {
             RGBColor[
             0.9702506210449482, 0.977049699592265, 0.9225310571216002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 239}], {
             RGBColor[
             0.6274798394045316, 0.6993442754889752, 0.9510748192183129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 269}], {
             RGBColor[
             0.6446471908939282, 0.7149892144178098, 0.9521403149472578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 323}], {
             RGBColor[
             0.8077090307348496, 0.8503083337262844, 0.9642805108848316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 365}], {
             RGBColor[
             0.8292086838179491, 0.8671040261182172, 0.9664233953784738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 377}], {
             RGBColor[
             0.9446274251029413, 0.8721471055914461, 0.6140063148398518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 388}], {
             RGBColor[
             0.9246696166553969, 0.9422830450496367, 0.9757777095660993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 395}], {
             RGBColor[
             0.9490816945629158, 0.9615457916928715, 0.9710755888707336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 78}], {
             RGBColor[
             0.735159276216705, 0.7929464920547207, 0.974392144493976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 80}], {
             RGBColor[
             0.44527453705569187`, 0.5518315120144583, 0.9509921466734013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 96}], {
             RGBColor[
             0.7806878979942787, 0.8291480770101459, 0.9752086256704422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 182}], {
             RGBColor[
             0.7509967323001081, 0.8055748496393333, 0.975902735193475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 187}], {
             RGBColor[
             0.577973006348121, 0.6682635497974452, 0.959919298726058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 244}], {
             RGBColor[
             0.5350742776557517, 0.6333033191171218, 0.9565789323945788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 302}], {
             RGBColor[
             0.8061270880484503, 0.8470690606476323, 0.885057379765994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 377}], {
             RGBColor[
             0.7781935008956165, 0.7412110605067908, 0.6148217989484364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 388}], {
             RGBColor[
             0.7582356924480722, 0.8113469999649813, 0.9765931936746838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 80}], {
             RGBColor[
             0.558700912897231, 0.6409882009398185, 0.9620200532857368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 96}], {
             RGBColor[
             0.8941142738358179, 0.9183047659355061, 0.9862365322827777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 104}], {
             RGBColor[
             0.6678181119785804, 0.738275901241334, 0.9690908013663384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 182}], {
             RGBColor[
             0.8644231081416474, 0.8947315385646935, 0.9869306418058106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 187}], {
             RGBColor[
             0.6913993821896602, 0.7574202387228054, 0.9709472053383935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 208}], {
             RGBColor[
             0.9172430726791625, 0.9352703434329698, 0.9343744478425202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 302}], {
             RGBColor[
             0.9195534638899895, 0.9362257495729924, 0.8960852863783295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 377}], {
             RGBColor[
             0.8916198767371557, 0.830367749432151, 0.6258497055607719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 388}], {
             RGBColor[
             0.8716620682896115, 0.9005036888903415, 0.9876211002870193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 87}], {
             RGBColor[
             0.890687091238358, 0.9154221338055843, 0.9807128726438937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 126}], {
             RGBColor[
             0.5715504844824617, 0.6561006541825405, 0.9625084075083774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 176}], {
             RGBColor[
             0.803382365797715, 0.846456471700124, 0.9810031261493195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 205}], {
             RGBColor[
             0.6485202765455523, 0.7227007081314926, 0.9674661071826898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 232}], {
             RGBColor[
             0.8723892900941854, 0.9010835558173987, 0.9876904633519381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[
             0.8236253142780908, 0.8622704169051001, 0.9830207540727344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 298}], {
             RGBColor[
             0.9047243596954109, 0.9258911056369368, 0.9569514386520674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 373}], {
             RGBColor[
             0.6098431528589612, 0.6894124195700486, 0.9649430886693176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 390}], {
             RGBColor[
             0.7105969939571433, 0.7730973838504724, 0.9723530137718386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 96}], {
             RGBColor[
             0.6042295346748048, 0.6771897858952436, 0.962836534462203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 104}], {
             RGBColor[
             0.3779333728175674, 0.4971609212010716, 0.9456908035457635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 182}], {
             RGBColor[
             0.5745383689806343, 0.6536165585244311, 0.9635306439852357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 187}], {
             RGBColor[
             0.40151464302864714`, 0.516305258682543, 0.9475472075178186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 244}], {
             RGBColor[
             0.3586159143362778, 0.48134502800221945`, 0.9442068411863395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 302}], {
             RGBColor[
             0.6296687247289765, 0.6951107695327301, 0.8726852885577547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 377}], {
             RGBColor[
             0.6017351375761426, 0.5892527693918885, 0.602449707740197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 388}], {
             RGBColor[
             0.5817773291285984, 0.6593887088500789, 0.9642211024664444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 119}], {
             RGBColor[
             0.36972169719040016`, 0.49320700278216817`, 0.9448323754747071]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 128}], {
             RGBColor[
             0.653569121062809, 0.7264311352072691, 0.9681226513249249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.48000909163560035`, 0.5885433884317541, 0.9522593429020862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 135}], {
             RGBColor[
             0.5494633600644119, 0.644773283301185, 0.9578338383607976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 146}], {
             RGBColor[
             0.4468273962206608, 0.5614411652335678, 0.9496924244665961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 166}], {
             RGBColor[
             0.36718087287371515`, 0.49053643532776603`, 0.9446876792886847]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 227}], {
             RGBColor[
             0.4962753420656268, 0.6017490633170808, 0.9535398817211767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 243}], {
             RGBColor[
             0.46958910628987993`, 0.5800839749131079, 0.9514390434860072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[
             0.4715441794113136, 0.5816711913481282, 0.9515929540037953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 275}], {
             RGBColor[
             0.6350036296998218, 0.7116275163412613, 0.9663518581851134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 311}], {
             RGBColor[
             0.41389120680975067`, 0.5329134933868508, 0.9475937596016617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 326}], {
             RGBColor[
             0.4818598932554998, 0.5900459525644512, 0.9524050447853145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 344}], {
             RGBColor[
             0.3912276817638346, 0.513283487093968, 0.9461496598263042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 346}], {
             RGBColor[
             0.4194718836309498, 0.5377471951564007, 0.9479493553939098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 363}], {
             RGBColor[
             0.37707039390972213`, 0.5009309489684587, 0.9452508728814499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 383}], {
             RGBColor[
             0.45012087662837685`, 0.564278789040148, 0.9499064331325786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 172}], {
             RGBColor[
             0.6702824072189045, 0.25617641726631096`, 0.42454289894286035`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 194}], {
             RGBColor[
             0.7697990557225933, 0.3380334189472869, 0.4322177819555024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 233}], {
             RGBColor[
             0.7336911726275909, 0.30905029896778097`, 0.4291490084569509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 256}], {
             RGBColor[
             0.8574393256575834, 0.40709880312757496`, 0.4396039075688919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 257}], {
             RGBColor[
             0.7688909480034561, 0.33732399829522264`, 0.432127270264808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 310}], {
             RGBColor[
             0.8577660322678926, 0.4073424603826107, 0.43905087849636915`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 316}], {
             RGBColor[
             0.7167688621572629, 0.2953120049865697, 0.427816822188261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 399}], {
             RGBColor[
             0.8734055684418258, 0.4104232427203768, 0.24230414091093644`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 118}], {
             RGBColor[
             0.381519604195719, 0.5048748382466324, 0.9455310697081798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 123}], {
             RGBColor[
             0.5834634037473805, 0.6706406653377626, 0.9615162561279262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 141}], {
             RGBColor[
             0.6959322129661856, 0.758974836641966, 0.9490612397584663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 161}], {
             RGBColor[
             0.7121880352234731, 0.7685993373295801, 0.7869361772540764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 196}], {
             RGBColor[
             0.3603799538205953, 0.484898402100002, 0.9442450825115591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 214}], {
             RGBColor[
             0.39218469316913684`, 0.5141124022724489, 0.9462106397467981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 286}], {
             RGBColor[
             0.7070077008687949, 0.767234917385285, 0.9303133276892277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 332}], {
             RGBColor[
             0.4969483881646138, 0.6018519737015355, 0.9537154064040783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 334}], {
             RGBColor[
             0.5165645112946275, 0.6177772261547572, 0.9552596594730995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 366}], {
             RGBColor[
             0.7063923532719469, 0.766775992155095, 0.9313549506623344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 125}], {
             RGBColor[
             0.7271939187122972, 0.7861767039333774, 0.9741140048387673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 184}], {
             RGBColor[
             0.6756157856318072, 0.7443032519302195, 0.9700535852657441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 185}], {
             RGBColor[
             0.8146507375951428, 0.8557004083612332, 0.9820092245739607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 190}], {
             RGBColor[
             0.6879963862435781, 0.7543543812465567, 0.9710282314975371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 252}], {
             RGBColor[
             0.7399092247661514, 0.7964995622059061, 0.9751150003090274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 270}], {
             RGBColor[
             0.6521962304644358, 0.7242202473440331, 0.9685055437554582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 274}], {
             RGBColor[
             0.7139652362811157, 0.775437063590392, 0.9730725944995242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 288}], {
             RGBColor[
             0.9234054233610658, 0.9412303989647379, 0.9741103804892353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 318}], {
             RGBColor[
             0.934393210631723, 0.9494250727203436, 0.9555109227139035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 168}], {
             RGBColor[
             0.5807697854853608, 0.6661608931990817, 0.9622532043836047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 238}], {
             RGBColor[
             0.6964281606051279, 0.7622084016938948, 0.9707639748211372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 379}], {
             RGBColor[
             0.8749388495689495, 0.9026899397100572, 0.9639533204439129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 236}], {
             RGBColor[
             0.5797736308912229, 0.6687346319793197, 0.9607352161483841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 262}], {
             RGBColor[
             0.7206338633691329, 0.781683918174962, 0.9727897068604483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 265}], {
             RGBColor[
             0.5335689135940422, 0.6287144281731176, 0.957791092419435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 297}], {
             RGBColor[
             0.8472111629942799, 0.8799616318348065, 0.9107655860895106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 325}], {
             RGBColor[
             0.5993064834430176, 0.684600167555607, 0.9622707349465689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 376}], {
             RGBColor[
             0.5663915776335179, 0.6571437700490492, 0.9598825235480882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 397}], {
             RGBColor[
             0.848733553534806, 0.8805911794469663, 0.8855356350125692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 176}], {
             RGBColor[
             0.8581507238662502, 0.889875681812901, 0.9775041297183713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 205}], {
             RGBColor[
             0.7032886346140874, 0.7661199182442695, 0.9639671107517416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 232}], {
             RGBColor[
             0.9271576481627205, 0.9445027659301757, 0.9841914669209899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 277}], {
             RGBColor[
             0.8783936723466259, 0.9056896270178771, 0.9795217576417862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 373}], {
             RGBColor[
             0.6646115109274963, 0.7328316296828256, 0.9614440922383694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 390}], {
             RGBColor[
             0.7653653520256785, 0.8165165939632495, 0.9688540173408904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 89}], {
             RGBColor[
             0.686160240120874, 0.7541970991523965, 0.969733676147666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 120}], {
             RGBColor[
             0.7948194256982024, 0.8391704048232498, 0.9374225301694509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 140}], {
             RGBColor[
             0.7570022354682182, 0.8102502020872336, 0.9766059203198791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 189}], {
             RGBColor[
             0.651600966169198, 0.727199131681137, 0.9662891306949399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 195}], {
             RGBColor[
             0.7923756574800634, 0.8153999900681927, 0.6668890539279788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 233}], {
             RGBColor[
             0.5862572849486483, 0.6749891003678512, 0.960571467483804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 255}], {
             RGBColor[
             0.7423271603640602, 0.79854869554348, 0.9752061985558504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 257}], {
             RGBColor[
             0.6390569480124463, 0.7173996493590136, 0.9650388601955895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 263}], {
             RGBColor[
             0.6186037449361733, 0.7012494137771403, 0.963117899303009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 336}], {
             RGBColor[
             0.4849949982888585, 0.5903522030711321, 0.9532704855419383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 356}], {
             RGBColor[
             0.5696723836490676, 0.6615247303515623, 0.9592658433010057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 359}], {
             RGBColor[
             0.787576492502879, 0.8337686371053922, 0.9496829268096119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 360}], {
             RGBColor[
             0.4784454685776634, 0.5846793296242299, 0.9528531553002626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 389}], {
             RGBColor[
             0.49114413683561886`, 0.5956782778156462, 0.9536623032126681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 162}], {
             RGBColor[
             0.5766216625343301, 0.6634681095303729, 0.9616079196231705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 183}], {
             RGBColor[
             0.8799754283995127, 0.9031331615994389, 0.7670118737625318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 189}], {
             RGBColor[
             0.731682154275548, 0.7903149270011742, 0.9738908972458511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 263}], {
             RGBColor[
             0.6986849330425232, 0.7643652090971775, 0.9707196658539201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 270}], {
             RGBColor[
             0.5900769097875761, 0.675122368420744, 0.9624652760801393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.8089634866625048, 0.8509439230089451, 0.9815255821851536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 291}], {
             RGBColor[
             0.5509631076314168, 0.6412439589099368, 0.9599729791937262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 336}], {
             RGBColor[
             0.5650761863952084, 0.6534679983911693, 0.9608722520928494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 359}], {
             RGBColor[
             0.8676576806092289, 0.8968844324254294, 0.957284693360523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 95}], {
             RGBColor[
             0.49118679617534045`, 0.5942849743599955, 0.9541256193785633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 97}], {
             RGBColor[
             0.351934715309541, 0.47924989447317623`, 0.9436459467492425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.3087621137680994, 0.4399370424026885, 0.9409652876161552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 228}], {
             RGBColor[
             0.5113157380157459, 0.6100098567113443, 0.9561318841855586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 246}], {
             RGBColor[
             0.616186236118349, 0.6926051773347044, 0.966406680108833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 260}], {
             RGBColor[
             0.3710075402270666, 0.49576981678868326`, 0.9448612502875504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 326}], {
             RGBColor[
             0.42344113414988405`, 0.5394465596393737, 0.948682653112785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 172}], {
             RGBColor[
             0.5247218656975803, 0.6224652173345864, 0.9566290395456332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 192}], {
             RGBColor[
             0.5784213725720107, 0.6681545802660198, 0.9602779702753002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 208}], {
             RGBColor[
             0.829567501519264, 0.8665463443780492, 0.925697113420707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 221}], {
             RGBColor[
             0.7144735580470611, 0.776871440837305, 0.9721757051972705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 256}], {
             RGBColor[
             0.8054572433555985, 0.8488487961264825, 0.9792205524846804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 316}], {
             RGBColor[
             0.5944515481051178, 0.6811685989149745, 0.9615399244137341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 351}], {
             RGBColor[
             0.7237759347899277, 0.7841385282495141, 0.9731028791753462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 395}], {
             RGBColor[
             0.8083985750372316, 0.8510424364786557, 0.9742416451698406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 399}], {
             RGBColor[
             0.8294066075319622, 0.8538354555156852, 0.6832709024977472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 98}], {
             RGBColor[
             0.9513580147015763, 0.962936131485254, 0.9565668392005964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 119}], {
             RGBColor[
             0.6084268999802704, 0.6837152095464586, 0.9662968397731847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 130}], {
             RGBColor[
             0.7187142944254707, 0.7790515951960446, 0.9737238072005638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 143}], {
             RGBColor[
             0.6582792933106257, 0.7283439283915731, 0.9694203322250277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 146}], {
             RGBColor[
             0.6855325990105312, 0.7519493719978583, 0.9711568887650737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 151}], {
             RGBColor[
             0.7942989143987637, 0.8400705672844216, 0.9799093188098367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 158}], {
             RGBColor[
             0.9569692232956604, 0.9602615855300034, 0.7044283763552663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 186}], {
             RGBColor[
             0.8968427751688905, 0.9205821010437989, 0.9900228585882473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 267}], {
             RGBColor[
             0.7102493822011839, 0.7721793981124185, 0.9730574183022729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 306}], {
             RGBColor[
             0.9370386349327038, 0.9522567614994615, 0.9808058140569191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 308}], {
             RGBColor[
             0.6223735759289075, 0.6972442006693577, 0.9671324516636439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 346}], {
             RGBColor[
             0.6581770864208201, 0.728255401920691, 0.9694138196923874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 348}], {
             RGBColor[
             0.8425020815601656, 0.877727247828548, 0.984713760028277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 354}], {
             RGBColor[
             0.9312916406769792, 0.9479706625933815, 0.9905339762757015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 374}], {
             RGBColor[
             0.942498341461521, 0.9563286016892043, 0.9715639550231516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 131}], {
             RGBColor[
             0.3871046284578096, 0.5074550782377787, 0.9461535085097524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 142}], {
             RGBColor[
             0.490862556428174, 0.590974522073104, 0.9548111885838353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 188}], {
             RGBColor[
             0.5383271664082752, 0.6280542361339557, 0.9595420173246528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 201}], {
             RGBColor[
             0.2990692747415101, 0.4316711482135094, 0.9403429248119612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 264}], {
             RGBColor[
             0.2801254754326875, 0.411760014033688, 0.9392641034661633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 273}], {
             RGBColor[
             0.5922559321931715, 0.670764910267163, 0.9647629233342354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 281}], {
             RGBColor[
             0.6415763333964606, 0.7076264212282513, 0.8733634092556395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 293}], {
             RGBColor[
             0.30088830442129044`, 0.433546153329456, 0.9404478673321552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 394}], {
             RGBColor[
             0.3444199894617326, 0.47125111094537886`, 0.9432216678093746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 204}], {
             RGBColor[
             0.6203326623757468, 0.6947076665856398, 0.9671494583567627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.8301950889527709, 0.8682081602778, 0.9834058041123793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 307}], {
             RGBColor[
             0.7145779419709264, 0.775605222948646, 0.9734423445594234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 324}], {
             RGBColor[
             0.6830126676554551, 0.7493531446932592, 0.9711303669653432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 97}], {
             RGBColor[
             0.5135885762632695, 0.6136882703259541, 0.9555530409966498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 148}], {
             RGBColor[
             0.7895716845609425, 0.8363980026056441, 0.97943274364384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 166}], {
             RGBColor[
             0.47041597472182795`, 0.5743754182554663, 0.9528723818635625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 169}], {
             RGBColor[
             0.484846722608621, 0.5887935212978661, 0.9537216354971989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 228}], {
             RGBColor[
             0.6729695989694744, 0.7444482325641222, 0.9680389784329659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 246}], {
             RGBColor[
             0.7778400970720775, 0.8270435531874822, 0.9783137743562403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 276}], {
             RGBColor[
             0.5498628250423561, 0.6451072014216435, 0.9578644040527945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 282}], {
             RGBColor[
             0.5763000076010076, 0.6667447684278651, 0.9598973737268865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 305}], {
             RGBColor[
             0.4760919409954071, 0.5803412186860453, 0.9531956197460032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 326}], {
             RGBColor[
             0.5850949951036126, 0.6738849354921517, 0.9605897473601923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 361}], {
             RGBColor[
             0.7022988059540081, 0.767360431970669, 0.9709622396881619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 382}], {
             RGBColor[
             0.6042712096243612, 0.6894530503187148, 0.962099369212054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 104}], {
             RGBColor[
             0.7133467337561543, 0.7744774861967592, 0.9699072825428046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 182}], {
             RGBColor[
             0.9099517299192211, 0.9309331235201187, 0.9877471229822767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 187}], {
             RGBColor[
             0.7369280039672341, 0.7936218236782306, 0.9717636865148598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 208}], {
             RGBColor[
             0.9627716944567364, 0.971471928388395, 0.9351909290189865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 225}], {
             RGBColor[
             0.7364613901182111, 0.7932430055348794, 0.9717269529634018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 261}], {
             RGBColor[
             0.8034249847021215, 0.8472264274943498, 0.9772588186181321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 377}], {
             RGBColor[
             0.9371484985147296, 0.8665693343875762, 0.6266661867372381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 388}], {
             RGBColor[
             0.9171906900671852, 0.9367052738457666, 0.9884375814634856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 166}], {
             RGBColor[
             0.3311638938560285, 0.4593403383686471, 0.9423927092342417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 169}], {
             RGBColor[
             0.3455946417428216, 0.47375844141104684`, 0.9432419628678781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 224}], {
             RGBColor[
             0.3024873769110219, 0.42919950086325687`, 0.9407596240173286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 246}], {
             RGBColor[
             0.638588016206278, 0.7120084733006631, 0.9678341017269195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 276}], {
             RGBColor[
             0.41061074417655674`, 0.5300721215348242, 0.9473847314234737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 326}], {
             RGBColor[
             0.4458429142378132, 0.5588498556053324, 0.9501100747308715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 363}], {
             RGBColor[
             0.34105341489203544`, 0.46973485200933973`, 0.9429559028270069]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 382}], {
             RGBColor[
             0.4650191287585618, 0.5744179704318956, 0.9516196965827332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 383}], {
             RGBColor[
             0.4141038976106902, 0.5330826920810291, 0.9476114630781356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 393}], {
             RGBColor[
             0.517623173379571, 0.6168401282572825, 0.9559551719317491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 134}], {
             RGBColor[
             0.7473498798550435, 0.8007852097404649, 0.9377817327943244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 143}], {
             RGBColor[
             0.685856448999618, 0.7492182619908736, 0.9333949343524538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 151}], {
             RGBColor[
             0.8218760700877559, 0.8609449008837221, 0.9438839209372628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 158}], {
             RGBColor[
             0.9845463789846525, 0.9811359191293039, 0.6684029784826924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 163}], {
             RGBColor[
             0.9614348766108775, 0.9707587746377621, 0.9501648738894173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.9322761349345796, 0.9477207585228787, 0.954746792473825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 186}], {
             RGBColor[
             0.9244199308578828, 0.9414564346430994, 0.9539974607156735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 240}], {
             RGBColor[
             0.7438762336198688, 0.7979651472407703, 0.937508274638306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 272}], {
             RGBColor[
             0.8075978381420608, 0.8496972164174561, 0.9425246727662214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 306}], {
             RGBColor[
             0.9646157906216961, 0.973131095098762, 0.9447804161843452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 308}], {
             RGBColor[
             0.6499507316178997, 0.7181185342686581, 0.93110705379107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 342}], {
             RGBColor[
             0.9800418172697295, 0.9846358005150648, 0.9186681768213347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 348}], {
             RGBColor[
             0.8700792372491578, 0.8986015814278485, 0.9486883621557032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 354}], {
             RGBColor[
             0.9588687963659714, 0.9688449961926819, 0.9545085784031275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 374}], {
             RGBColor[
             0.9700754971505132, 0.9772029352885048, 0.9355385571505778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 378}], {
             RGBColor[
             0.9737070528933056, 0.9799113436153526, 0.9293912805394616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 144}], {
             RGBColor[
             0.9081263327686551, 0.8715401121178532, 0.6336964269577603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 169}], {
             RGBColor[
             0.5903819869927152, 0.6715935190228673, 0.9641461857867847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[
             0.6113080384412676, 0.689718613013676, 0.9654795752809058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 222}], {
             RGBColor[
             0.8689230441923501, 0.8983196654240139, 0.9873598497234668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 223}], {
             RGBColor[
             0.5804660775334237, 0.6619207974250617, 0.9635540455224896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 276}], {
             RGBColor[
             0.6553980894264502, 0.7279071991466448, 0.9682889543423803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 361}], {
             RGBColor[
             0.8078340703381022, 0.8501604296956703, 0.9813867899777478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 382}], {
             RGBColor[
             0.7098064740084553, 0.7722530480437162, 0.9725239195016397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 384}], {
             RGBColor[
             0.8376215406418079, 0.8734306278900844, 0.9843557266378845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 393}], {
             RGBColor[
             0.7624105186294645, 0.8146752058691031, 0.9768593948506556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 157}], {
             RGBColor[
             0.9468816090505348, 0.9599049715200472, 0.9747997597689934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 167}], {
             RGBColor[
             0.8111620009941363, 0.8530749138919882, 0.9681221751650356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 174}], {
             RGBColor[
             0.939768362451127, 0.9544230116975612, 0.9807069753407236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 198}], {
             RGBColor[
             0.9506261241460607, 0.9626976247472097, 0.9684612724382169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 203}], {
             RGBColor[
             0.8603064645578418, 0.8914669423397117, 0.9730204360119425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 206}], {
             RGBColor[
             0.8418990687146684, 0.8770869448056349, 0.9711857588211894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 211}], {
             RGBColor[
             0.6457674478632786, 0.7161943646739588, 0.9556390494650968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 266}], {
             RGBColor[
             0.7154937715568536, 0.7758554658705287, 0.9602842957288382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 341}], {
             RGBColor[
             0.9714048173039658, 0.9768786303539947, 0.874368195083032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 358}], {
             RGBColor[
             0.9387795010059583, 0.9536345204231125, 0.9806126568533164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 115}], {
             RGBColor[
             0.7187708886340389, 0.7763744396644772, 0.8927852344195906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 123}], {
             RGBColor[
             0.862830623750937, 0.8920039994798865, 0.9050820994384222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 161}], {
             RGBColor[
             0.9915552552270295, 0.989962671471704, 0.7305020205645725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 193}], {
             RGBColor[
             0.6567693248468018, 0.7226718014011784, 0.8888345496008979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 253}], {
             RGBColor[
             0.9575369433378219, 0.9668486307046429, 0.9142934993215264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 283}], {
             RGBColor[
             0.9435935714237007, 0.9557305644230707, 0.9129635680609625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 332}], {
             RGBColor[
             0.7763156081681702, 0.8232153078436594, 0.8972812497145743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 334}], {
             RGBColor[
             0.795931731298184, 0.8391405602968811, 0.8988255027835956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 356}], {
             RGBColor[
             0.7610184449832194, 0.8107963816407681, 0.8960770009932999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 364}], {
             RGBColor[
             0.6383812334987073, 0.7048260463544651, 0.8877331375412487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 366}], {
             RGBColor[
             0.9857595732755033, 0.9881393262972189, 0.8749207939728304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 380}], {
             RGBColor[
             0.6461923280040573, 0.713036001931584, 0.8881779678178496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 389}], {
             RGBColor[
             0.6824901981697706, 0.7449499291048518, 0.8904734609049623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 108}], {
             RGBColor[
             0.5926352749040491, 0.6776185434608324, 0.962509678707317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 139}], {
             RGBColor[
             0.8136105599506473, 0.854702706785835, 0.9819546710654892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 213}], {
             RGBColor[
             0.5638458035792657, 0.6526825504002073, 0.9606752390520317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 297}], {
             RGBColor[
             0.8737727514316256, 0.9007117465976098, 0.9134129969927887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 333}], {
             RGBColor[
             0.7212040379283833, 0.7821293428741355, 0.9728465365319301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 337}], {
             RGBColor[
             0.8489188859719753, 0.8827922451334784, 0.9830909258131724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 345}], {
             RGBColor[
             0.5334125535950609, 0.6261782181982505, 0.9587413530812378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 350}], {
             RGBColor[
             0.5781403956350868, 0.6650638075718724, 0.9615860778176172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 378}], {
             RGBColor[
             0.864060903395532, 0.894085136935189, 0.9574594399857318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 122}], {
             RGBColor[
             0.46473650579804576`, 0.5552227578553043, 0.9546360351253969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 295}], {
             RGBColor[
             0.3533831400745795, 0.46647836618525007`, 0.9447367940768928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 145}], {
             RGBColor[
             0.5698556334963925, 0.6615156920028497, 0.9593881641592539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 170}], {
             RGBColor[
             0.7123407648237059, 0.7737272362140621, 0.9716101255467218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 182}], {
             RGBColor[
             0.6836555680619837, 0.7509042588259466, 0.9706013920658373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 187}], {
             RGBColor[
             0.5106318421099966, 0.6135929589840585, 0.9546179555984202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 192}], {
             RGBColor[
             0.4853294036522456, 0.5930512995821935, 0.9526260549571401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 208}], {
             RGBColor[
             0.7364755325994989, 0.7914430636942229, 0.918045198102547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 225}], {
             RGBColor[
             0.5101652282609737, 0.6132141408407072, 0.9545812220469624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 235}], {
             RGBColor[
             0.45017961754900115`, 0.5634287724466864, 0.9501590960321391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 261}], {
             RGBColor[
             0.5771288228448841, 0.6671975628001777, 0.9601130877016927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 327}], {
             RGBColor[
             0.5204689484989004, 0.6215791651071632, 0.9553923686478628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 335}], {
             RGBColor[
             0.6696013037077023, 0.7396977699226857, 0.969260883785336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 349}], {
             RGBColor[
             0.6094616375679165, 0.692456203400304, 0.9633357205059521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 351}], {
             RGBColor[
             0.6306839658701626, 0.7090352475656876, 0.9654509638571862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 355}], {
             RGBColor[
             0.5928972333356586, 0.6795159649199292, 0.961684735495239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 199}], {
             RGBColor[
             0.4161574068875941, 0.5337112031987561, 0.948060096712797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 215}], {
             RGBColor[
             0.7327830736010817, 0.7550634535764431, 0.6444308540031332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 259}], {
             RGBColor[
             0.5554069784882798, 0.649943431792856, 0.9581428183508476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 271}], {
             RGBColor[
             0.7384368832841317, 0.7934928108591435, 0.9355666264388083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 287}], {
             RGBColor[
             0.49895131417107563`, 0.6041101802014553, 0.9536984216518848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 303}], {
             RGBColor[
             0.48861996208926073`, 0.5957227231593307, 0.9528850997710147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 333}], {
             RGBColor[
             0.589497554071054, 0.6770007252954962, 0.9612497475462491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 337}], {
             RGBColor[
             0.717212402114646, 0.7776636275548392, 0.9714941368274913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 345}], {
             RGBColor[
             0.4017060697377315, 0.5210496006196113, 0.9471445640955567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 350}], {
             RGBColor[
             0.4464339117777574, 0.5599351899932331, 0.9499892888319361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 353}], {
             RGBColor[
             0.38054082104524767`, 0.49880358228953603`, 0.9459392344936993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 400}], {
             RGBColor[
             0.4791976997009968, 0.5880733060844545, 0.9521433447609261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 197}], {
             RGBColor[
             0.531588012829544, 0.6207990618507261, 0.9591854462500282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 217}], {
             RGBColor[
             0.3317602176118625, 0.458921902345084, 0.9424649392518056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 231}], {
             RGBColor[
             0.6357414872407372, 0.6990632975667288, 0.7421680299892524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 254}], {
             RGBColor[
             0.3146315875989949, 0.4440859439379146, 0.9413735180936386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 314}], {
             RGBColor[
             0.31911487895082946`, 0.4479691455700985, 0.9416591894541586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 369}], {
             RGBColor[
             0.33034163073421163`, 0.45769319369191247`, 0.9423745481503689]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 124}], {
             RGBColor[
             0.7952515073905293, 0.8385412673536001, 0.896804805440668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 150}], {
             RGBColor[
             0.6267530141816182, 0.707717509557142, 0.9638605241926765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 152}], {
             RGBColor[
             0.46691464834682783`, 0.574816365122811, 0.9520840350551667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.5435041338038368, 0.6402801662609827, 0.9572057828157314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.7722803031741876, 0.8222094020736734, 0.9715156467743624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 160}], {
             RGBColor[
             0.5700539766002326, 0.6618345246998847, 0.9592958836959424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 167}], {
             RGBColor[
             0.6365606951177891, 0.7153793444456146, 0.9648380621704047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.44844033488536605`, 0.5575795373230009, 0.9509520987424855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 181}], {
             RGBColor[
             0.6340322738111888, 0.7134041225041847, 0.9645860527640033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 211}], {
             RGBColor[
             0.4711661419869314, 0.5784987952275851, 0.952354936470466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 238}], {
             RGBColor[
             0.6034584631000393, 0.6889537916953953, 0.9619256072378731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 245}], {
             RGBColor[
             0.4931407111952894, 0.5975320626019024, 0.953755136589074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 386}], {
             RGBColor[
             0.5534069202434648, 0.648319694408118, 0.9579853664393609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 297}], {
             RGBColor[
             0.7067651549406535, 0.7661722383342147, 0.899244915479543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 325}], {
             RGBColor[
             0.45886047538939123`, 0.5708107740550152, 0.9507500643366011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 376}], {
             RGBColor[
             0.4259455695798915, 0.5433543765484574, 0.9483618529381206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 378}], {
             RGBColor[
             0.6970533069045598, 0.7595456286717939, 0.943291358472486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 397}], {
             RGBColor[
             0.7082875454811794, 0.7668017859463745, 0.8740149644026014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 114}], {
             RGBColor[
             0.5248242834655048, 0.6199591889604457, 0.957733781401299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 132}], {
             RGBColor[
             0.665656303866786, 0.7380399416123627, 0.9677852938295736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 180}], {
             RGBColor[
             0.7365750753976903, 0.7941373141693697, 0.9743785778963587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 232}], {
             RGBColor[
             0.8215942961022931, 0.8612733259386376, 0.9826618711615225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 249}], {
             RGBColor[
             0.745204837378062, 0.8008789498170563, 0.9752387119208513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 370}], {
             RGBColor[
             0.8530600963867476, 0.8854325761250258, 0.9533942926731969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 111}], {
             RGBColor[
             0.41390324254193067`, 0.5258886990205041, 0.9485656465244949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 117}], {
             RGBColor[
             0.37124494891801196`, 0.49125677452237904`, 0.9452074293879418]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 202}], {
             RGBColor[
             0.3589396528361244, 0.4812588948860709, 0.9442408903104798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 212}], {
             RGBColor[
             0.31064942356040526`, 0.4394323254249385, 0.941163879602404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 239}], {
             RGBColor[
             0.28260533421469036`, 0.4143665028457011, 0.9394053277551762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 247}], {
             RGBColor[
             0.26671418019762405`, 0.3976638924164059, 0.9385003500427598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 269}], {
             RGBColor[
             0.299772685704087, 0.43001144177453576`, 0.940470823484121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 287}], {
             RGBColor[
             0.38326223153596084`, 0.5010129459240424, 0.9461534738963834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 289}], {
             RGBColor[
             0.5468149284517685, 0.6310077696943881, 0.9609625388053505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 292}], {
             RGBColor[
             0.26270222244097713`, 0.3934470704413564, 0.9382718749836785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 303}], {
             RGBColor[
             0.37293087945414594`, 0.49262548888191776`, 0.9453401520155132]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 309}], {
             RGBColor[
             0.5171821149106288, 0.6077873109524106, 0.9580278792225614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 362}], {
             RGBColor[
             0.43715472954619305`, 0.5447653036381169, 0.9503960887544738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 385}], {
             RGBColor[
             0.4528238332985528, 0.5574861879493624, 0.9516296179996778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 400}], {
             RGBColor[
             0.363508617065882, 0.48497607180704166`, 0.9445983970054247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 199}], {
             RGBColor[
             0.44951982838427706`, 0.5607963199297241, 0.9506865087435926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 222}], {
             RGBColor[
             0.7184448245805858, 0.7791935176070683, 0.9732874457762917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 223}], {
             RGBColor[
             0.42998785792165933`, 0.5427946496081162, 0.9494816415753145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 247}], {
             RGBColor[
             0.41576568432942174`, 0.5278462434247868, 0.9486717098290569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 271}], {
             RGBColor[
             0.7717993047808146, 0.8205779275901115, 0.9381930384696038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 287}], {
             RGBColor[
             0.5323137356677585, 0.6311952969324234, 0.9563248336826804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 292}], {
             RGBColor[
             0.41175372657277487`, 0.5236294214497373, 0.9484432347699754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 309}], {
             RGBColor[
             0.6662336190424265, 0.7379696619607914, 0.9681992390088585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 319}], {
             RGBColor[
             0.46828712356551205`, 0.5770516077440272, 0.9518823441972735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 362}], {
             RGBColor[
             0.5862062336779907, 0.6749476546464979, 0.9605674485407708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 385}], {
             RGBColor[
             0.6018753374303505, 0.6876685389577433, 0.9618009777859748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[
             0.5125601211976797, 0.6151584228154225, 0.9547697567917217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 177}], {
             RGBColor[
             0.44021279051758344`, 0.548511950046195, 0.9505217756730031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 219}], {
             RGBColor[
             0.4963047415033323, 0.6001772618567105, 0.9539830843202193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 248}], {
             RGBColor[
             0.6184316481783092, 0.7011096978762357, 0.9631043512158188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 251}], {
             RGBColor[
             0.4488188469142208, 0.5575574609745519, 0.9510118778532721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 260}], {
             RGBColor[
             0.5087442239948883, 0.610951716364327, 0.9547757171447788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 162}], {
             RGBColor[
             0.3615584591705993, 0.48758549770219417`, 0.9442591631981265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 183}], {
             RGBColor[
             0.664912225035782, 0.72725054977126, 0.7496631173374878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 270}], {
             RGBColor[
             0.37501370642384535`, 0.49923975659256514`, 0.9451165196550955]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 357}], {
             RGBColor[
             0.3097770661849383, 0.4403952628955604, 0.9410453699753649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 368}], {
             RGBColor[
             0.3485528038017599, 0.47632065270495094`, 0.9434304543384736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 132}], {
             RGBColor[
             0.4561518421462525, 0.5656166666375232, 0.9513643905368618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 155}], {
             RGBColor[
             0.36739377424733477`, 0.49263975433019885`, 0.9446309843148497]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 180}], {
             RGBColor[
             0.5270706136771568, 0.6217140391945302, 0.957957674603647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 249}], {
             RGBColor[
             0.5357003756575285, 0.6284556748422168, 0.9588178086281396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 268}], {
             RGBColor[
             0.27314542151332405`, 0.403815740067092, 0.9388888540641744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 279}], {
             RGBColor[
             0.5424832114878463, 0.6337544777443227, 0.959493858314501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 299}], {
             RGBColor[
             0.5771031084006756, 0.6609525853558591, 0.962903902711716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 300}], {
             RGBColor[
             0.31623286901274883`, 0.448326749637865, 0.941371056673114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 370}], {
             RGBColor[
             0.6435556346662141, 0.7130093011501862, 0.9369733893804851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 123}], {
             RGBColor[
             0.5928303377021482, 0.6787538327335928, 0.9621131088766695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 161}], {
             RGBColor[
             0.7215549691782408, 0.7767125047254104, 0.7875330300028197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 193}], {
             RGBColor[
             0.38676903879801316`, 0.5094216346548848, 0.9458655590391452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 195}], {
             RGBColor[
             0.7137214327654265, 0.7514214746111048, 0.6607312210585203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 214}], {
             RGBColor[
             0.4015516271239046, 0.5222255696682792, 0.9468074924955414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 253}], {
             RGBColor[
             0.6875366572890331, 0.7535984639583493, 0.9713245087597736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 257}], {
             RGBColor[
             0.5604027232978094, 0.6534211339019257, 0.9588810273261309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 283}], {
             RGBColor[
             0.673593285374912, 0.742480397676777, 0.9699945774992097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 312}], {
             RGBColor[
             0.45137931078329707`, 0.5653656122556248, 0.9499874951032048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 332}], {
             RGBColor[
             0.5063153221193815, 0.6099651410973657, 0.9543122591528216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 334}], {
             RGBColor[
             0.5259314452493953, 0.6258903935505874, 0.955856512221843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 356}], {
             RGBColor[
             0.4910181589344306, 0.5975462148944743, 0.9531080104315471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 360}], {
             RGBColor[
             0.3997912438630265, 0.5207008141671419, 0.9466953224308041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 364}], {
             RGBColor[
             0.36838094744991856`, 0.4915758796081714, 0.9447641469794961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 366}], {
             RGBColor[
             0.7157592872267147, 0.7748891595509253, 0.9319518034110776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 380}], {
             RGBColor[
             0.3761920419552687, 0.4997858351852904, 0.945208977256097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 389}], {
             RGBColor[
             0.41248991212098196`, 0.5316997623585582, 0.9475044703432095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 141}], {
             RGBColor[
             0.8711050512917506, 0.8997058365513595, 0.9641224124477642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 179}], {
             RGBColor[
             0.5378837581980581, 0.6280793951217237, 0.9594390002691573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 209}], {
             RGBColor[
             0.6784227099461496, 0.7476988017590807, 0.9692726549541246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 286}], {
             RGBColor[
             0.88218053919436, 0.9079659172946785, 0.9453745003785256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 290}], {
             RGBColor[
             0.8290436307886966, 0.8668409885721778, 0.9834711749819278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 304}], {
             RGBColor[
             0.5360484695606471, 0.6261503903997843, 0.9593344832963231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 338}], {
             RGBColor[
             0.6399591901219962, 0.7164723836040112, 0.9662446657770517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 239}], {
             RGBColor[
             0.38899854472256945`, 0.509916929355957, 0.9462184704049199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 269}], {
             RGBColor[
             0.4061658962119661, 0.5255618682847917, 0.9472839661338649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 309}], {
             RGBColor[
             0.6235753254185079, 0.7033377374626664, 0.9648410218723052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 323}], {
             RGBColor[
             0.5692277360528875, 0.6608809875932662, 0.9594241620714385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 362}], {
             RGBColor[
             0.5435479400540721, 0.6403157301483728, 0.9572092314042175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 365}], {
             RGBColor[
             0.590727389135987, 0.677676679985199, 0.9615670465650807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 377}], {
             RGBColor[
             0.7061461304209792, 0.682719759458428, 0.6091499660264588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 385}], {
             RGBColor[
             0.5592170438064319, 0.6530366144596182, 0.9584427606494217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 388}], {
             RGBColor[
             0.6861883219734348, 0.7528556989166184, 0.9709213607527063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 395}], {
             RGBColor[
             0.7106003998809537, 0.7721184455598533, 0.9662192400573406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 124}], {
             RGBColor[
             0.6610049618976606, 0.7262870253630389, 0.8871390656258705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[
             0.6474150824861897, 0.7169517367620755, 0.9459697711062949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 150}], {
             RGBColor[
             0.4925064686887494, 0.5954632675665807, 0.9541947843778791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 179}], {
             RGBColor[
             0.3141937893924973, 0.4453252953324397, 0.9412863589276881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 196}], {
             RGBColor[
             0.31186282334059945`, 0.4428753022201114, 0.9411536138593877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 206}], {
             RGBColor[
             0.5330512173454525, 0.6271371333686999, 0.958235906011761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 209}], {
             RGBColor[
             0.45473274114058876`, 0.5649447019697965, 0.9511200136126554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 286}], {
             RGBColor[
             0.6584905703887991, 0.7252118175053943, 0.9272218590370562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 386}], {
             RGBColor[
             0.4191603747505961, 0.5360654524175568, 0.9483196266245635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 128}], {
             RGBColor[
             0.5769203648203656, 0.6585927536320646, 0.963291718323417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 130}], {
             RGBColor[
             0.4033603353931571, 0.5207050068565495, 0.9474284099005783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 135}], {
             RGBColor[
             0.4728146038219686, 0.5769349017259804, 0.9530029053592897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 146}], {
             RGBColor[
             0.37017863997821754`, 0.49360278365836324`, 0.9448614914650881]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 151}], {
             RGBColor[
             0.47894495536645, 0.5817239789449267, 0.9536139215098511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 213}], {
             RGBColor[
             0.3305608383557335, 0.45928783514157534`, 0.9423370801783499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 227}], {
             RGBColor[
             0.41962658582318346`, 0.5339106817418762, 0.9487089487196687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 243}], {
             RGBColor[
             0.3929403500474366, 0.5122455933379033, 0.9466081104844992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 267}], {
             RGBColor[
             0.3948954231688703, 0.5138328097729237, 0.9467620210022873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 306}], {
             RGBColor[
             0.6216846759003902, 0.6939101731599664, 0.9545104167569336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 311}], {
             RGBColor[
             0.3372424505673074, 0.46507511181164624`, 0.9427628266001538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 344}], {
             RGBColor[
             0.31457892552139133`, 0.4454451055187634, 0.9413187268247962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 346}], {
             RGBColor[
             0.34282312738850645`, 0.4699088135811961, 0.9431184223924018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 350}], {
             RGBColor[
             0.34485543041155453`, 0.47166909231324045`, 0.9432479189439353]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 354}], {
             RGBColor[
             0.6159376816446656, 0.6896240742538864, 0.964238578975716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 140}], {
             RGBColor[
             0.9457426091518967, 0.9583393030781241, 0.9518965408925752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 147}], {
             RGBColor[
             0.6302687675480038, 0.6978555229126978, 0.9258989975440008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 193}], {
             RGBColor[
             0.6541636371963284, 0.7214892511028632, 0.9273140124812997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 195}], {
             RGBColor[
             0.9811160311637419, 0.9634890910590832, 0.6421796745006748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 241}], {
             RGBColor[
             0.6920607347867271, 0.7543138122721581, 0.9297287820286724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 242}], {
             RGBColor[
             0.7584198420024557, 0.8096195829964838, 0.9345570216048533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 255}], {
             RGBColor[
             0.9310675340477386, 0.9466377965343704, 0.9504968191285463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 263}], {
             RGBColor[
             0.8073441186198518, 0.8493385147680308, 0.9384085198757051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 312}], {
             RGBColor[
             0.7187739091816123, 0.7774332287036032, 0.9314359485453594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 331}], {
             RGBColor[
             0.6984342312904832, 0.759834214602463, 0.9301348955900299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 356}], {
             RGBColor[
             0.7584127573327459, 0.8096138313424528, 0.9345564638737016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 359}], {
             RGBColor[
             0.9763168661865573, 0.9818577380962826, 0.9249735473823079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 360}], {
             RGBColor[
             0.6671858422613418, 0.7327684306151203, 0.9281437758729586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 380}], {
             RGBColor[
             0.6435866403535839, 0.7118534516332689, 0.9266574306982515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 389}], {
             RGBColor[
             0.6798845105192972, 0.7437673788065366, 0.928952923785364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[
             0.8364572863201943, 0.872284132213091, 0.9427188982512358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 202}], {
             RGBColor[
             0.5720426904485977, 0.6626951625482174, 0.9599646682548092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 234}], {
             RGBColor[
             0.5356761728992517, 0.6311963128812926, 0.9576474259142137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 289}], {
             RGBColor[
             0.7599179660642419, 0.8124440373565346, 0.97668631674968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 298}], {
             RGBColor[
             0.8322938999280391, 0.8691790854587411, 0.9497664254280749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 173}], {
             RGBColor[
             0.5489832050329719, 0.640195667916704, 0.9595646843614324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 338}], {
             RGBColor[
             0.6250409902566195, 0.7048181724866606, 0.964757759032975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 161}], {
             RGBColor[
             0.8656147042951388, 0.8923420645408198, 0.7998298950216514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 196}], {
             RGBColor[
             0.513806622892261, 0.6086411293112416, 0.9571388002791341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 214}], {
             RGBColor[
             0.5456113622408025, 0.6378551294836885, 0.9591043575143732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 253}], {
             RGBColor[
             0.8315963924059312, 0.8692280237737586, 0.9836213737786053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 283}], {
             RGBColor[
             0.81765302049181, 0.8581099574921863, 0.9822914425180413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 332}], {
             RGBColor[
             0.6503750572362795, 0.725594700912775, 0.9666091241716532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 334}], {
             RGBColor[
             0.6699911803662932, 0.7415199533659967, 0.9681533772406746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 356}], {
             RGBColor[
             0.6350778940513286, 0.7131757747098837, 0.9654048754503788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 364}], {
             RGBColor[
             0.5124406825668166, 0.6072054394235807, 0.9570610119983277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 366}], {
             RGBColor[
             0.8598190223436126, 0.8905187193663346, 0.9442486684299094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 389}], {
             RGBColor[
             0.5565496472378799, 0.6473293221739675, 0.9598013353620412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 150}], {
             RGBColor[
             0.8205089568706868, 0.8588985545628779, 0.8988942489477413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 152}], {
             RGBColor[
             0.6606705910358965, 0.7259974101285469, 0.8871177598102316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 156}], {
             RGBColor[
             0.7372600764929055, 0.7914612112667188, 0.8922395075707963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 157}], {
             RGBColor[
             0.9660362458632563, 0.9733904470794095, 0.9065493715294273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 160}], {
             RGBColor[
             0.7638099192893013, 0.8130155697056207, 0.8943296084510072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 167}], {
             RGBColor[
             0.8303166378068577, 0.8665603894513505, 0.8998717869254695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 179}], {
             RGBColor[
             0.6421962775744346, 0.7087605823287368, 0.8859858234975502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 181}], {
             RGBColor[
             0.8277882165002574, 0.8645851675099208, 0.8996197775190681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 238}], {
             RGBColor[
             0.797214405789108, 0.8401348367011312, 0.8969593319929379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 245}], {
             RGBColor[
             0.686896653884358, 0.7487131076076383, 0.8887888613441386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 386}], {
             RGBColor[
             0.7471628629325335, 0.799500739413854, 0.8930190911944257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 184}], {
             RGBColor[
             0.5123296347631612, 0.614971303544585, 0.9547516120552968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 185}], {
             RGBColor[
             0.6513645867264968, 0.7263684599755984, 0.9667072513635133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 190}], {
             RGBColor[
             0.524710235374932, 0.6250224328609221, 0.9557262582870898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 226}], {
             RGBColor[
             0.45237224355802663`, 0.5632410618275243, 0.9508754119418242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 252}], {
             RGBColor[
             0.5766230738975053, 0.6671676138202716, 0.9598130270985801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 274}], {
             RGBColor[
             0.5506790854124697, 0.6461051152047574, 0.9577706212890769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 288}], {
             RGBColor[
             0.7601192724924197, 0.8118984505791033, 0.9588084072787879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 318}], {
             RGBColor[
             0.7711070597630769, 0.8200931243347089, 0.940208949503456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 176}], {
             RGBColor[
             0.539014117110354, 0.630554202189857, 0.9592996645828549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 205}], {
             RGBColor[
             0.3841520278581912, 0.5067984386212256, 0.9457626456162251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 298}], {
             RGBColor[
             0.6403561110080496, 0.7099888361266699, 0.9352479770856028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 320}], {
             RGBColor[
             0.3947062005645532, 0.5153667914843125, 0.9465935087528785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 347}], {
             RGBColor[
             0.2722111984400043, 0.40344160712023436`, 0.9388133970995536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 373}], {
             RGBColor[
             0.3454749041716, 0.47351015005978164`, 0.9432396271028529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 137}], {
             RGBColor[
             0.9344481246424827, 0.9324677565982467, 0.687810078808645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 138}], {
             RGBColor[
             0.6710113808886973, 0.7192520306597081, 0.6653618977942797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 193}], {
             RGBColor[
             0.6536439585782071, 0.7042092423663879, 0.6642552610020638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 210}], {
             RGBColor[
             0.9228262008132562, 0.9232007500055397, 0.6867015693387994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 242}], {
             RGBColor[
             0.7579001633843343, 0.7923395742600086, 0.6714982701256174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 255}], {
             RGBColor[
             0.9305478554296174, 0.9293577877978951, 0.6874380676493105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 258}], {
             RGBColor[
             0.7413574029190844, 0.7789094160714525, 0.6701959634236646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 264}], {
             RGBColor[
             0.6250700009699135, 0.6756574960589836, 0.662573778927535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 312}], {
             RGBColor[
             0.718254230563491, 0.7601532199671279, 0.6683771970661234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 328}], {
             RGBColor[
             0.7947653107355617, 0.8222683616356973, 0.6744004295665902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 331}], {
             RGBColor[
             0.6979145526723618, 0.7425542058659877, 0.6670761441107941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 380}], {
             RGBColor[
             0.6430669617354627, 0.6945734428967936, 0.6635986792190156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 394}], {
             RGBColor[
             0.6893645149989586, 0.7351485929706745, 0.6665313432707463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 130}], {
             RGBColor[
             0.6872077592655659, 0.7539291392816505, 0.9707186857507961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 135}], {
             RGBColor[
             0.7566620276943774, 0.8101590341510814, 0.9762931812095075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 139}], {
             RGBColor[
             0.8641730185995239, 0.8945321239523041, 0.9869067880420253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 151}], {
             RGBColor[
             0.7627923792388588, 0.8149481113700277, 0.976904197360069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 213}], {
             RGBColor[
             0.6144082622281423, 0.6925119675666762, 0.9656273560285678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 215}], {
             RGBColor[
             0.9150520161072877, 0.9000214883215514, 0.6609797599653502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 224}], {
             RGBColor[
             0.5457030235586741, 0.6257813486722721, 0.9615139369204815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 227}], {
             RGBColor[
             0.7034740096955923, 0.7671348141669772, 0.9719992245698865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 243}], {
             RGBColor[
             0.6767877739198453, 0.7454697257630043, 0.969898386334717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 259}], {
             RGBColor[
             0.7376759209944859, 0.7949014665379642, 0.9746917243130646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 306}], {
             RGBColor[
             0.9055320997727989, 0.9271343055850674, 0.9778006926071514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 350}], {
             RGBColor[
             0.6287028542839633, 0.7048932247383414, 0.9665381947941531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 383}], {
             RGBColor[
             0.6573195442583424, 0.7296645398900444, 0.9683657759812885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 131}], {
             RGBColor[
             0.47960801263516195`, 0.5884064166087969, 0.9521756460981294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 253}], {
             RGBColor[
             0.7019704357093536, 0.765439928015575, 0.9724266728496975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 271}], {
             RGBColor[
             0.7291410111568959, 0.7859460030919865, 0.9348348213330506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 287}], {
             RGBColor[
             0.48965544204383993`, 0.5965633724342984, 0.9529666165461272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 303}], {
             RGBColor[
             0.479324089962025, 0.5881759153921737, 0.9521532946652571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 333}], {
             RGBColor[
             0.5802016819438183, 0.6694539175283392, 0.9605179424404915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 337}], {
             RGBColor[
             0.7079165299874102, 0.7701168197876822, 0.9707623317217338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 353}], {
             RGBColor[
             0.37124494891801196`, 0.49125677452237904`, 0.9452074293879418]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 364}], {
             RGBColor[
             0.382814725870239, 0.5034173436653971, 0.9458663110694199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 391}], {
             RGBColor[
             0.7293940854723096, 0.767441952538422, 0.6666461778099618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 135}], {
             RGBColor[
             0.5831019982671688, 0.6722712873755664, 0.9604298727866688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 146}], {
             RGBColor[
             0.48046603442341773`, 0.5889391693079492, 0.9522884588924674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 151}], {
             RGBColor[
             0.5892323498116503, 0.6770603645945126, 0.9610408889372304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 158}], {
             RGBColor[
             0.7519026587085469, 0.7972513828400943, 0.6855599464826599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 227}], {
             RGBColor[
             0.5299139802683837, 0.6292470673914621, 0.956135916147048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 243}], {
             RGBColor[
             0.5032277444926369, 0.6075819789874892, 0.9540350779118785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 267}], {
             RGBColor[
             0.5051828176140705, 0.6091691954225096, 0.9541889884296666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 275}], {
             RGBColor[
             0.6686422679025787, 0.7391255204156427, 0.9689478926109847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 306}], {
             RGBColor[
             0.7319720703455904, 0.7892465588095524, 0.9619373841843128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 311}], {
             RGBColor[
             0.4475298450125076, 0.5604114974612322, 0.9501897940275329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 317}], {
             RGBColor[
             0.38924973412424513`, 0.5058738702591293, 0.9466248320330777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 344}], {
             RGBColor[
             0.4248663199665915, 0.5407814911683493, 0.9487456942521755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 346}], {
             RGBColor[
             0.4531105218337067, 0.5652451992307821, 0.950545389819781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 354}], {
             RGBColor[
             0.7262250760898659, 0.7849604599034724, 0.9716655464030952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 142}], {
             RGBColor[
             0.5853357938147974, 0.6735250760202841, 0.9609884002326561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 201}], {
             RGBColor[
             0.3935425121281335, 0.5142217021606895, 0.946520136460782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 273}], {
             RGBColor[
             0.6867291695797949, 0.7533154642143431, 0.9709401349830562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 281}], {
             RGBColor[
             0.7360495707830839, 0.7901769751754315, 0.8795406209044603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 293}], {
             RGBColor[
             0.3953615418079138, 0.5160967072766361, 0.946625078980976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 303}], {
             RGBColor[
             0.4812939431712959, 0.5897751309683357, 0.9523083687257009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 391}], {
             RGBColor[
             0.7313639386815806, 0.7690411681145839, 0.6668012518704056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 394}], {
             RGBColor[
             0.43889322684835586`, 0.553801664892559, 0.9493988794581953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 149}], {
             RGBColor[
             0.5032004914615118, 0.6063678419405285, 0.9543622888677432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 155}], {
             RGBColor[
             0.508225794648616, 0.610720506982116, 0.9546824967431243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 180}], {
             RGBColor[
             0.667902634078438, 0.7397947918464473, 0.9680091870319216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 249}], {
             RGBColor[
             0.6765323960588097, 0.746536427494134, 0.9688693210564143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 268}], {
             RGBColor[
             0.4139774419146052, 0.5218964927190091, 0.9489403664924492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 279}], {
             RGBColor[
             0.6833152318891275, 0.7518352303962397, 0.9695453707427757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 299}], {
             RGBColor[
             0.7179351288019568, 0.7790333380077761, 0.9729554151399906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 300}], {
             RGBColor[
             0.45706488941403, 0.5664075022897821, 0.9514225691013887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 370}], {
             RGBColor[
             0.7843876550674953, 0.8310900538021033, 0.9470249018087598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 178}], {
             RGBColor[
             0.7218401557463772, 0.7813392378333943, 0.9696749601856067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 200}], {
             RGBColor[
             0.7424384932805845, 0.796701444239724, 0.9348073476470352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 278}], {
             RGBColor[
             0.748446846219601, 0.7995740209606215, 0.8526074067367547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 296}], {
             RGBColor[
             0.737725816407133, 0.7931867375438041, 0.9427846803308069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 320}], {
             RGBColor[
             0.49262519644493286`, 0.5989743528430168, 0.95320040649115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 330}], {
             RGBColor[
             0.42522031301285607`, 0.5413766637562409, 0.9486885199452635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 347}], {
             RGBColor[
             0.37013019432038397`, 0.48704916847893875`, 0.9454202948378252]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 367}], {
             RGBColor[
             0.7437223742684123, 0.7976203303954139, 0.9309041335094295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 398}], {
             RGBColor[
             0.5491813994334678, 0.6448892262570193, 0.9576527179626053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 163}], {
             RGBColor[
             0.7298495860753524, 0.7877335192936724, 0.9674051653557192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 171}], {
             RGBColor[
             0.7006908443990546, 0.7646955031787891, 0.971987083940127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 240}], {
             RGBColor[
             0.5122909430843439, 0.6149398918966806, 0.954748566104608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 272}], {
             RGBColor[
             0.5760125476065359, 0.6666719610733665, 0.9597649642325234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 342}], {
             RGBColor[
             0.7484565267342045, 0.8016105451709752, 0.9359084682876366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 374}], {
             RGBColor[
             0.7384902066149883, 0.7941776799444151, 0.9527788486168798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 213}], {
             RGBColor[
             0.5103025012297453, 0.6108541156605922, 0.9553385430644403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 215}], {
             RGBColor[
             0.8109462551088907, 0.8183636364154673, 0.6506909470012228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 224}], {
             RGBColor[
             0.4415972625602771, 0.5441234967661881, 0.9512251239563541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 227}], {
             RGBColor[
             0.5993682486971953, 0.6854769622608929, 0.9617104116057591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 243}], {
             RGBColor[
             0.5726820129214484, 0.6638118738569201, 0.9596095733705897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 259}], {
             RGBColor[
             0.6335701599960888, 0.7132436146318801, 0.9644029113489372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 350}], {
             RGBColor[
             0.5245970932855664, 0.6232353728322573, 0.9562493818300258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 363}], {
             RGBColor[
             0.48016330054129064`, 0.584658847912271, 0.9534214027660324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 383}], {
             RGBColor[
             0.5532137832599453, 0.6480066879839603, 0.9580769630171612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 393}], {
             RGBColor[
             0.6567330590288261, 0.7317641241602137, 0.9664206718707746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 149}], {
             RGBColor[
             0.33931274116248045`, 0.4646618500847354, 0.942975532387033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 155}], {
             RGBColor[
             0.3443380443495847, 0.4690145151263228, 0.9432957402624143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 268}], {
             RGBColor[
             0.25008969161557393`, 0.38019050086321593`, 0.937553610011739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 279}], {
             RGBColor[
             0.5194274815900961, 0.6101292385404467, 0.9581586142620655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 299}], {
             RGBColor[
             0.5540473785029254, 0.637327346151983, 0.9615686586592805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 300}], {
             RGBColor[
             0.29317713911499876`, 0.42470151043398896`, 0.9400358126206786]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 371}], {
             RGBColor[
             0.3332466388812918, 0.45940769717993546`, 0.9425890057137194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 138}], {
             RGBColor[
             0.6229390633855416, 0.6990202989167649, 0.9665763288192496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 164}], {
             RGBColor[
             0.8280112041850242, 0.8661045331791712, 0.9833496741770149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 210}], {
             RGBColor[
             0.8747538833101005, 0.9029690182625965, 0.9879160003637695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 230}], {
             RGBColor[
             0.5817676149556407, 0.6604392647419802, 0.9640598504943156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 242}], {
             RGBColor[
             0.7098278458811788, 0.7721078425170654, 0.9727127011505873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 258}], {
             RGBColor[
             0.6932850854159288, 0.7586776843285093, 0.9714103944486345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 264}], {
             RGBColor[
             0.576997683466758, 0.6554257643160404, 0.963788209952505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 328}], {
             RGBColor[
             0.746692993232406, 0.8020366298927541, 0.9756148605915602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 394}], {
             RGBColor[
             0.641292197495803, 0.7149168612277312, 0.9677457742957163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 149}], {
             RGBColor[
             0.38445972000362305`, 0.5074214187849215, 0.9457184112876171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 164}], {
             RGBColor[
             0.5645744604312387, 0.6528888072406327, 0.9609014931626496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 210}], {
             RGBColor[
             0.6113171395563151, 0.6897532923240579, 0.9654678193494042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 230}], {
             RGBColor[
             0.3183308712018552, 0.4472235388034417, 0.9416116694799503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 242}], {
             RGBColor[
             0.4463911021273933, 0.5588921165785269, 0.950264520136222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 258}], {
             RGBColor[
             0.42984834166214336`, 0.5454619583899708, 0.9489622134342692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 264}], {
             RGBColor[
             0.3135609397129725, 0.4422100383775019, 0.9413400289381397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 281}], {
             RGBColor[
             0.6750117976767456, 0.7380764455720652, 0.8754393347276159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 328}], {
             RGBColor[
             0.48325624947862056`, 0.5888209039542156, 0.9531666795771949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 394}], {
             RGBColor[
             0.3778554537420175, 0.5017011352891927, 0.945297593281351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 186}], {
             RGBColor[
             0.8687414699157352, 0.8981748830245435, 0.9873425310068701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 213}], {
             RGBColor[
             0.6178134921348918, 0.6952272054618149, 0.9659521498969581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 215}], {
             RGBColor[
             0.9184572460140372, 0.90273672621669, 0.6613045538337405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 306}], {
             RGBColor[
             0.9089373296795484, 0.929849543480206, 0.9781254864755418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 308}], {
             RGBColor[
             0.5942722706757522, 0.6748369826501022, 0.9644521240822665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 345}], {
             RGBColor[
             0.587380242150687, 0.6687228732598581, 0.9640182639261642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 350}], {
             RGBColor[
             0.6321080841907128, 0.70760846263348, 0.9668629886625436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 378}], {
             RGBColor[
             0.918028591951158, 0.9366297919967966, 0.9627363508306582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 147}], {
             RGBColor[
             0.5924515773180196, 0.6689353201766817, 0.9650823876944292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 193}], {
             RGBColor[
             0.6163464469663442, 0.692569048366847, 0.9664974026317281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 195}], {
             RGBColor[
             0.9432988409337577, 0.9345688883230671, 0.6813630646511031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 241}], {
             RGBColor[
             0.6542435445567429, 0.725393609536142, 0.9689121721791006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 242}], {
             RGBColor[
             0.7206026517724715, 0.7806993802604677, 0.9737404117552816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 255}], {
             RGBColor[
             0.8932503438177544, 0.9177175937983543, 0.9896802092789747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 263}], {
             RGBColor[
             0.7695269283898676, 0.8204183120320148, 0.9775919100261333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 312}], {
             RGBColor[
             0.6809567189516281, 0.748513025967587, 0.9706193386957876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 331}], {
             RGBColor[
             0.660617041060499, 0.7309140118664468, 0.9693182857404583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 356}], {
             RGBColor[
             0.7205955671027617, 0.7806936286064367, 0.97373985402413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 359}], {
             RGBColor[
             0.9384996759565731, 0.9529375353602665, 0.9641569375327361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 360}], {
             RGBColor[
             0.6293686520313576, 0.7038482278791042, 0.9673271660233869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 380}], {
             RGBColor[
             0.6057694501235997, 0.6829332488972526, 0.9658408208486797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 389}], {
             RGBColor[
             0.642067320289313, 0.7148471760705204, 0.9681363139357924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 179}], {
             RGBColor[
             0.6286063981629638, 0.6994252937277734, 0.9448165289779746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 196}], {
             RGBColor[
             0.6262754321110661, 0.6969753006154451, 0.9446837839096742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 209}], {
             RGBColor[
             0.7691453499110553, 0.8190447003651302, 0.954650183662942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 286}], {
             RGBColor[
             0.9729031791592657, 0.9793118159007281, 0.9307520290873428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 290}], {
             RGBColor[
             0.9197662707536023, 0.9381868871782275, 0.9688487036907449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 304}], {
             RGBColor[
             0.6267711095255528, 0.6974962890058339, 0.9447120120051402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 386}], {
             RGBColor[
             0.7335729835210627, 0.7901654508128905, 0.95184979667485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.736558331765263, 0.7941242339164611, 0.9743769090475565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 201}], {
             RGBColor[
             0.49730044009849794`, 0.5977411459960148, 0.9551778165348648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 273}], {
             RGBColor[
             0.7904870975501594, 0.8368349080496684, 0.9795978150571389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 281}], {
             RGBColor[
             0.8398074987534483, 0.8736964190107568, 0.8881983009785432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 293}], {
             RGBColor[
             0.49911946977827826`, 0.5996161511119614, 0.9552827590550589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 394}], {
             RGBColor[
             0.5426511548187203, 0.6373211087278843, 0.9580565595322783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 151}], {
             RGBColor[
             0.5287973486968053, 0.6263526977900412, 0.9567374139616942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 158}], {
             RGBColor[
             0.691467657593702, 0.746543716035623, 0.6812564715071238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 171}], {
             RGBColor[
             0.639197413543629, 0.7131285554291978, 0.9676002854982564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 186}], {
             RGBColor[
             0.6313412094669322, 0.7068642315494185, 0.9668509537401049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 272}], {
             RGBColor[
             0.5145191167511102, 0.6151050133237752, 0.9553781657906528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 306}], {
             RGBColor[
             0.6715370692307454, 0.738538892005081, 0.9576339092087767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 308}], {
             RGBColor[
             0.35687201022694914`, 0.48352633117497723`, 0.9439605468155013]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 342}], {
             RGBColor[
             0.6869630958787789, 0.7500435974213839, 0.931521669845766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 348}], {
             RGBColor[
             0.5770005158582072, 0.6640093783341676, 0.9615418551801345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 354}], {
             RGBColor[
             0.665790074975021, 0.734252793099001, 0.967362071427559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 374}], {
             RGBColor[
             0.6769967757595627, 0.7426107321948239, 0.9483920501750092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 378}], {
             RGBColor[
             0.6806283315023551, 0.7453191405216717, 0.942244773563893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 148}], {
             RGBColor[
             0.9393220958164346, 0.8964147667857227, 0.6366719066860438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 169}], {
             RGBColor[
             0.6345971338641131, 0.6488102854779446, 0.6109607985394028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 218}], {
             RGBColor[
             0.6555231853126655, 0.6669353794687533, 0.6122941880335238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 222}], {
             RGBColor[
             0.9131381910637482, 0.8755364318790911, 0.6341744624760849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 276}], {
             RGBColor[
             0.6996132362978482, 0.7051239656017221, 0.6151035670949982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 282}], {
             RGBColor[
             0.7260504188564998, 0.7267615326079437, 0.6171365367690903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 305}], {
             RGBColor[
             0.6258423522508991, 0.6403579828661239, 0.610434782788207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 339}], {
             RGBColor[
             0.774397076986315, 0.7660115276698563, 0.6209425627967134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 361}], {
             RGBColor[
             0.8520492172095002, 0.8273771961507476, 0.6282014027303657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 382}], {
             RGBColor[
             0.7540216208798534, 0.7494698144987935, 0.6193385322542577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 384}], {
             RGBColor[
             0.881836687513206, 0.8506473943451617, 0.6311703393905026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 165}], {
             RGBColor[
             0.6760124760165123, 0.7468253512399903, 0.9683422639797119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 170}], {
             RGBColor[
             0.7951458264211815, 0.8407943067143246, 0.9782367380796104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 182}], {
             RGBColor[
             0.7664606296594593, 0.8179713293262092, 0.977228004598726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 192}], {
             RGBColor[
             0.5681344652497212, 0.660118370082456, 0.9592526674900288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 208}], {
             RGBColor[
             0.8192805941969745, 0.8585101341944854, 0.9246718106354358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 221}], {
             RGBColor[
             0.7041866507247716, 0.7688352306537412, 0.9711504024119992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 225}], {
             RGBColor[
             0.5929702898584492, 0.6802812113409699, 0.9612078345798512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 235}], {
             RGBColor[
             0.5329846791464767, 0.6304958429469489, 0.9567857085650279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 335}], {
             RGBColor[
             0.752406365305178, 0.8067648404229484, 0.9758874963182248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 349}], {
             RGBColor[
             0.6922666991653921, 0.7595232739005666, 0.9699623330388408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 351}], {
             RGBColor[
             0.7134890274676382, 0.7761023180659503, 0.972077576390075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 355}], {
             RGBColor[
             0.6757022949331342, 0.7465830354201918, 0.9683113480281278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 395}], {
             RGBColor[
             0.7981116677149422, 0.8430062262950919, 0.9732163423845692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 151}], {
             RGBColor[
             0.5560506543967108, 0.6499581413963262, 0.9584739705017402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 158}], {
             RGBColor[
             0.7187209632936074, 0.770149159641908, 0.6829930280471698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 227}], {
             RGBColor[
             0.4967322848534442, 0.6021448441932757, 0.9535689977115578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 243}], {
             RGBColor[
             0.4700460490776973, 0.5804797557893029, 0.9514681594763883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 267}], {
             RGBColor[
             0.472001122199131, 0.5820669722243232, 0.9516220699941764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 275}], {
             RGBColor[
             0.6354605724876392, 0.7120232972174564, 0.9663809741754945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 306}], {
             RGBColor[
             0.6987903749306509, 0.7621443356113661, 0.9593704657488227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 311}], {
             RGBColor[
             0.41434814959756805`, 0.5333092742630459, 0.9476228755920427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 317}], {
             RGBColor[
             0.3560680387093056, 0.478771647060943, 0.9440579135975875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 344}], {
             RGBColor[
             0.391684624551652, 0.513679267970163, 0.9461787758166853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 346}], {
             RGBColor[
             0.41992882641876716`, 0.5381429760325958, 0.9479784713842908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 354}], {
             RGBColor[
             0.6930433806749263, 0.7578582367052861, 0.969098627967605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 195}], {
             RGBColor[
             0.6278249993298648, 0.6740851081576408, 0.6553655213025289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 217}], {
             RGBColor[
             0.33130953772458055`, 0.4584482092087955, 0.9424392736989462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 231}], {
             RGBColor[
             0.6352908073534553, 0.6985896044304403, 0.7421423644363927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 241}], {
             RGBColor[
             0.33876970295285, 0.4649098293707157, 0.9429146288305263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 242}], {
             RGBColor[
             0.4051288101685786, 0.5202156000950414, 0.9477428684067073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 255}], {
             RGBColor[
             0.5777765022138615, 0.657233813632928, 0.9636826659304004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 312}], {
             RGBColor[
             0.36548287734773527`, 0.4880292458021607, 0.9446217953472134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 331}], {
             RGBColor[
             0.3451431994566061, 0.47043023170102055`, 0.943320742391884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 359}], {
             RGBColor[
             0.6230258343526802, 0.6924537551948402, 0.9381593941841619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 392}], {
             RGBColor[
             0.35718917936805916`, 0.4808638540517666, 0.94408830158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 218}], {
             RGBColor[
             0.6425038014890471, 0.7145932676815455, 0.9684550550091893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 228}], {
             RGBColor[
             0.809700626401348, 0.8521228849569931, 0.9814390084508353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 276}], {
             RGBColor[
             0.6865938524742297, 0.7527818538145143, 0.9712644340706639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.7130310350328812, 0.774419420820736, 0.9732974037447559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 301}], {
             RGBColor[
             0.8351642189935705, 0.8720152370205088, 0.9839769813896261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 305}], {
             RGBColor[
             0.6128229684272807, 0.6880158710789162, 0.9665956497638726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 313}], {
             RGBColor[
             0.9208831836852236, 0.9397512702352177, 0.9923158542136612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 339}], {
             RGBColor[
             0.7613776931626965, 0.8136694158826485, 0.9771034297723791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 340}], {
             RGBColor[
             0.7035380422715775, 0.7667125816426592, 0.9725500805806078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 361}], {
             RGBColor[
             0.8390298333858817, 0.8750350843635398, 0.9843622697060312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 382}], {
             RGBColor[
             0.7410022370562348, 0.7971277027115857, 0.9754993992299233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 155}], {
             RGBColor[
             0.4144424235625941, 0.5333909296332042, 0.947628882645731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 164}], {
             RGBColor[
             0.5895318608031056, 0.6745056530473279, 0.9624917566453823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 210}], {
             RGBColor[
             0.636274539928182, 0.7113701381307531, 0.9670580828321369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 230}], {
             RGBColor[
             0.3432882715737221, 0.4688403846101369, 0.9432019329626831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 258}], {
             RGBColor[
             0.45480574203401025`, 0.567078804196666, 0.950552476917002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 264}], {
             RGBColor[
             0.33851834008483933`, 0.4638268841841971, 0.9429302924208725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 268}], {
             RGBColor[
             0.3201940708285833, 0.4445669153700973, 0.9418867523950558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 279}], {
             RGBColor[
             0.5895318608031056, 0.6745056530473279, 0.9624917566453823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 299}], {
             RGBColor[
             0.6241517577159349, 0.7017037606588643, 0.9659018010425973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 300}], {
             RGBColor[
             0.36328151832800815`, 0.4890779249408703, 0.9443689550039953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 328}], {
             RGBColor[
             0.5082136498504874, 0.6104377497609108, 0.9547569430599276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 152}], {
             RGBColor[
             0.4921720978269853, 0.5951736523320887, 0.95417347856224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 156}], {
             RGBColor[
             0.5687615832839943, 0.6606374534702606, 0.9592952263228047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 157}], {
             RGBColor[
             0.7975377526543451, 0.8425666892829513, 0.9736050902814357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 160}], {
             RGBColor[
             0.59531142608039, 0.6821918119091626, 0.9613853272030157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 167}], {
             RGBColor[
             0.6618181445979465, 0.7357366316548923, 0.966927505677478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 179}], {
             RGBColor[
             0.47369778436552346`, 0.5779368245322787, 0.9530415422495588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 181}], {
             RGBColor[
             0.6592897232913462, 0.7337614097134626, 0.9666754962710766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 206}], {
             RGBColor[
             0.6925552123184786, 0.759748662568539, 0.9699910893336318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 211}], {
             RGBColor[
             0.4964235914670888, 0.598856082436863, 0.9544443799775393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 238}], {
             RGBColor[
             0.6287159125801967, 0.709311078904673, 0.9640150507449464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 386}], {
             RGBColor[
             0.5786643697236222, 0.6686769816173959, 0.9600748099464342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 158}], {
             RGBColor[
             0.8274872786818399, 0.8582703549284714, 0.6917454580919328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 186}], {
             RGBColor[
             0.7673608305550701, 0.8185908704422671, 0.9773399403249139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 227}], {
             RGBColor[
             0.6054986002416767, 0.6902660394798392, 0.9623214277563208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 267}], {
             RGBColor[
             0.5807674375873635, 0.6701881675108867, 0.9603745000389394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 306}], {
             RGBColor[
             0.8075566903188833, 0.8502655308979294, 0.9681228957935857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 308}], {
             RGBColor[
             0.49289163131508706`, 0.5952529700678257, 0.9544495334003104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 311}], {
             RGBColor[
             0.5231144649858006, 0.6214304695496093, 0.9563753056368057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 317}], {
             RGBColor[
             0.46483435409753804`, 0.5668928423475064, 0.9528103436423505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 344}], {
             RGBColor[
             0.5004509399398844, 0.6018004632567264, 0.9549312058614483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 346}], {
             RGBColor[
             0.5286951418069996, 0.6262641713191592, 0.9567309014290538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 348}], {
             RGBColor[
             0.7130201369463451, 0.7757360172270161, 0.9720308417649435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 354}], {
             RGBColor[
             0.8018096960631588, 0.8459794319918494, 0.977851058012368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 156}], {
             RGBColor[
             0.4089232174492039, 0.5277363090359296, 0.947518737185295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 157}], {
             RGBColor[
             0.6376993868195548, 0.7096655448486203, 0.961828601143926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 160}], {
             RGBColor[
             0.43547306024559973`, 0.5492906674748316, 0.9496088380655059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 179}], {
             RGBColor[
             0.3138594185307332, 0.44503568009794775`, 0.941265053112049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 181}], {
             RGBColor[
             0.49945135745655583`, 0.6008602652791316, 0.9548990071335668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 238}], {
             RGBColor[
             0.4688775467454064, 0.5764099344703422, 0.9522385616074367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 245}], {
             RGBColor[
             0.35855979484065653`, 0.4849882053768493, 0.9440680909586374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 168}], {
             RGBColor[
             0.6608051772292005, 0.6640185695261782, 0.6108393427879588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 175}], {
             RGBColor[
             0.7470767965195706, 0.7362085857804233, 0.6170366801593674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 211}], {
             RGBColor[
             0.6441712312358597, 0.649611081553181, 0.609779442458084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 216}], {
             RGBColor[
             0.6665207181821675, 0.6689690838281972, 0.6112035320034273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 229}], {
             RGBColor[
             0.6474630708345848, 0.6524623075609278, 0.6099891955664551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 294}], {
             RGBColor[
             0.643942700663092, 0.6494131398573303, 0.6097648806920688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 329}], {
             RGBColor[
             0.6385824263374879, 0.6447703396517132, 0.6094233287519457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 341}], {
             RGBColor[
             0.969808600676547, 0.9102953472332169, 0.5285085880760192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 343}], {
             RGBColor[
             0.6745922283300736, 0.6759602202324175, 0.6117178414926958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 358}], {
             RGBColor[
             0.9371832843785395, 0.8870512373023347, 0.6347530498463034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 379}], {
             RGBColor[
             0.9549742413127892, 0.9005476160371537, 0.6125394588482669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 207}], {
             RGBColor[
             0.6421265437698651, 0.7097662977094956, 0.914126754886294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 231}], {
             RGBColor[
             0.646117222880012, 0.7099688535832424, 0.7427589127843837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 369}], {
             RGBColor[
             0.34071736637348643`, 0.46859874970842597`, 0.9429654309455002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 372}], {
             RGBColor[
             0.33883121872835975`, 0.4669650634187544, 0.9428452472854076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 387}], {
             RGBColor[
             0.6465276883531763, 0.7115862840989513, 0.8411883993437559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 392}], {
             RGBColor[
             0.3680155948946158, 0.49224310320456865`, 0.9447048499279909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 249}], {
             RGBColor[
             0.5877743281598921, 0.6735595151868096, 0.9621359148344021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 268}], {
             RGBColor[
             0.3252193740156875, 0.4489195804116847, 0.9422069602704368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 279}], {
             RGBColor[
             0.5945571639902097, 0.6788583180889154, 0.9628119645207635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.629177060903039, 0.7060564257004518, 0.9662220089179785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 300}], {
             RGBColor[
             0.36830682151511235`, 0.4934305899824578, 0.9446891628793765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 370}], {
             RGBColor[
             0.6956295871685776, 0.758113141494779, 0.9402914955867476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 371}], {
             RGBColor[
             0.4083763212814054, 0.5281367767284042, 0.9472423559724172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 160}], {
             RGBColor[
             0.5120625457026087, 0.6147544686130033, 0.9547305858260706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.3904489039877421, 0.5104994812361195, 0.9463868008726137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 181}], {
             RGBColor[
             0.5760408429135648, 0.6663240664173034, 0.9600207548941315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 245}], {
             RGBColor[
             0.43514928029766553`, 0.5504520065150211, 0.9491898387192022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 352}], {
             RGBColor[
             0.5993313577207418, 0.6845187935991386, 0.9623421357478754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 396}], {
             RGBColor[
             0.48614041538084074`, 0.5937097154391291, 0.952689900771249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 160}], {
             RGBColor[
             0.7408387150729596, 0.796683704425694, 0.9690404497847016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 167}], {
             RGBColor[
             0.807345433590516, 0.8502285241714239, 0.974582628259164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 168}], {
             RGBColor[
             0.6585848264529991, 0.7277554629263915, 0.9631594028891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 203}], {
             RGBColor[
             0.8564898971542215, 0.8886205526191474, 0.9794808891060709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 206}], {
             RGBColor[
             0.8380825013110481, 0.8742405550850705, 0.9776462119153178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 211}], {
             RGBColor[
             0.6419508804596583, 0.7133479749533944, 0.9620995025592252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 238}], {
             RGBColor[
             0.7742432015727663, 0.8238029714212046, 0.9716701733266324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 341}], {
             RGBColor[
             0.9675882499003456, 0.9740322406334303, 0.8808286481771603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 358}], {
             RGBColor[
             0.9349629336023382, 0.9507881307025481, 0.9870731099474448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 386}], {
             RGBColor[
             0.7241916587161918, 0.7831688741339273, 0.9677299325281201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 267}], {
             RGBColor[
             0.7434377464842601, 0.7903791857564684, 0.6848935575843689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 306}], {
             RGBColor[
             0.97022699921578, 0.9704565491435112, 0.6926419533390151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 308}], {
             RGBColor[
             0.6555619402119837, 0.7154439883134074, 0.6789685909457399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 311}], {
             RGBColor[
             0.6857847738826972, 0.741621487795191, 0.6808943631822353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 317}], {
             RGBColor[
             0.6275046629944347, 0.6870838605930881, 0.6773294011877802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 344}], {
             RGBColor[
             0.6631212488367811, 0.7219914815023081, 0.6794502634068778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 346}], {
             RGBColor[
             0.6913654507038963, 0.7464551895647409, 0.6812499589744834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 348}], {
             RGBColor[
             0.8756904458432417, 0.8959270354725979, 0.6965498993103731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 354}], {
             RGBColor[
             0.9644800049600555, 0.9661704502374312, 0.7023701155577975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 374}], {
             RGBColor[
             0.9756867057445973, 0.9745283893332541, 0.6834000943052477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 250}], {
             RGBColor[
             0.6036238500293067, 0.6824601528110509, 0.9652674486545705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 265}], {
             RGBColor[
             0.34321271539442383`, 0.47169533652716394`, 0.9430901886272129]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 321}], {
             RGBColor[
             0.4180743901106471, 0.5349884352771254, 0.9482881141121939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 375}], {
             RGBColor[
             0.5373215030577154, 0.6301675262224217, 0.9587908670005145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 381}], {
             RGBColor[
             0.4705839900036675, 0.5776180940007971, 0.9524218621647748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[
             0.6025906857099605, 0.6878784248562053, 0.9621108557743425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 238}], {
             RGBColor[
             0.5720168749988112, 0.6634280940474159, 0.9594504102482123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 245}], {
             RGBColor[
             0.4616991230940613, 0.572006364953923, 0.9512799395994131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 196}], {
             RGBColor[
             0.6425312543683536, 0.7065998013030592, 0.7825587214052844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 214}], {
             RGBColor[
             0.6743359937168951, 0.735813801475506, 0.7845242786405233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 253}], {
             RGBColor[
             0.9603210238820237, 0.9671866957655761, 0.8090412949047555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 283}], {
             RGBColor[
             0.9463776519679026, 0.956068629484004, 0.8077113636441916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 332}], {
             RGBColor[
             0.779099688712372, 0.8235533729045926, 0.7920290452978035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 334}], {
             RGBColor[
             0.7987158118423858, 0.8394786253578144, 0.7935732983668249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.7638025255274212, 0.8111344467017013, 0.790824796576529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 364}], {
             RGBColor[
             0.6411653140429091, 0.7051641114153984, 0.782480933124478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 366}], {
             RGBColor[
             0.9885436538197052, 0.9884773913581522, 0.7696685895560595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 389}], {
             RGBColor[
             0.6852742787139725, 0.7452879941657851, 0.7852212564881914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 183}], {
             RGBColor[
             0.690355662706619, 0.7492883766573781, 0.751284350687125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 270}], {
             RGBColor[
             0.40045714409468225`, 0.5212775834786834, 0.9467377530047327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 280}], {
             RGBColor[
             0.619343720969611, 0.6970991380668843, 0.965798059109747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 291}], {
             RGBColor[
             0.361343341938523, 0.48739917396787613`, 0.9442454561183193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 336}], {
             RGBColor[
             0.37545642070231466`, 0.49962321344910865`, 0.9451447290174426]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 357}], {
             RGBColor[
             0.3352205038557752, 0.4624330897816785, 0.9426666033250022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 368}], {
             RGBColor[
             0.3739962414725968, 0.4983584795910691, 0.9450516876881108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 171}], {
             RGBColor[
             0.9147758411548885, 0.9346690680760863, 0.9843702250352198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 240}], {
             RGBColor[
             0.7263759398401777, 0.784913456793978, 0.9671317071997008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 272}], {
             RGBColor[
             0.7900975443623697, 0.8366455259706637, 0.9721481053276162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 342}], {
             RGBColor[
             0.9625415234900384, 0.9715841100682724, 0.9482916093827295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 374}], {
             RGBColor[
             0.9525752033708221, 0.9641512448417123, 0.9651619897119725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 210}], {
             RGBColor[
             0.8163892803557976, 0.8568375265864644, 0.9822411647071694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 230}], {
             RGBColor[
             0.5234030120013378, 0.614307773065848, 0.9583850148377155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 258}], {
             RGBColor[
             0.6349204824616259, 0.7125461926523773, 0.9657355587920344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 264}], {
             RGBColor[
             0.518633080512455, 0.6092942726399083, 0.9581133742959049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 279}], {
             RGBColor[
             0.7696466012307213, 0.8199730415030392, 0.9776748385204148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 328}], {
             RGBColor[
             0.6883283902781031, 0.755905138216622, 0.9699400249349601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 170}], {
             RGBColor[
             0.8184976073438258, 0.8590368954512028, 0.9805642253671798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 172}], {
             RGBColor[
             0.5377867392979351, 0.6326715958879007, 0.9579312240479312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 184}], {
             RGBColor[
             0.5800578793109139, 0.6690828957591477, 0.9606804718747775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 190}], {
             RGBColor[
             0.5924384799226847, 0.6791340250754849, 0.9616551181065705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 192}], {
             RGBColor[
             0.5914862461723654, 0.6783609588193341, 0.9615801547775982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 221}], {
             RGBColor[
             0.7275384316474159, 0.7870778193906192, 0.9734778896995684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 226}], {
             RGBColor[
             0.5201004881057794, 0.6173526540420873, 0.9568042717613049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 252}], {
             RGBColor[
             0.6443513184452581, 0.7212792060348343, 0.9657418869180607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 274}], {
             RGBColor[
             0.6184073299602224, 0.7002167074193202, 0.9636994811085575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 288}], {
             RGBColor[
             0.8278475170401725, 0.8660100427936661, 0.9647372670982686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 318}], {
             RGBColor[
             0.8388353043108296, 0.8742047165492718, 0.9461378093229367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 322}], {
             RGBColor[
             0.5560402801941435, 0.6484818955625549, 0.9590943235328652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 351}], {
             RGBColor[
             0.7368408083902825, 0.7943449068028283, 0.9744050636776442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 355}], {
             RGBColor[
             0.6990540758557784, 0.7648256241570699, 0.9706388353156971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 399}], {
             RGBColor[
             0.8424714811323171, 0.8640418340689995, 0.6845730870000453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 169}], {
             RGBColor[
             0.30242204020137997`, 0.4344455893405591, 0.9405613037347906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 246}], {
             RGBColor[
             0.5954154146648365, 0.6726956212301753, 0.9651534425938322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 326}], {
             RGBColor[
             0.40267031269637155`, 0.5195370035348447, 0.947429415597784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 363}], {
             RGBColor[
             0.2978808133505939, 0.430421999938852, 0.9402752436939195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 383}], {
             RGBColor[
             0.3709312960692486, 0.49376984001054136`, 0.9449308039450482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 168}], {
             RGBColor[
             0.5228652183966005, 0.6209254052983326, 0.9564818182851422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.7207702890978229, 0.7817904949910885, 0.9728033045021132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 211}], {
             RGBColor[
             0.5062312724032597, 0.6065179173253356, 0.9554219179552674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 216}], {
             RGBColor[
             0.5285807593495676, 0.6258759196003516, 0.9568460075006109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 238}], {
             RGBColor[
             0.6385235935163676, 0.7169729137931458, 0.9649925887226747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 341}], {
             RGBColor[
             0.8318686418439469, 0.8672021830053714, 0.8741510635732026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 358}], {
             RGBColor[
             0.7992433255459395, 0.8439580730744892, 0.9803955253434871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 211}], {
             RGBColor[
             0.35747066526574284`, 0.4840448560803031, 0.9439986925852034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 216}], {
             RGBColor[
             0.3798201522120507, 0.5034028583553192, 0.9454227821305468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 238}], {
             RGBColor[
             0.48976298637885074`, 0.5944998525481133, 0.9535693633526106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 341}], {
             RGBColor[
             0.68310803470643, 0.744729121760339, 0.8627278382031386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 379}], {
             RGBColor[
             0.6682736753426723, 0.7349813905642757, 0.9467587089753864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 218}], {
             RGBColor[
             0.3377788395367255, 0.4669887863737674, 0.9427439468625483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 222}], {
             RGBColor[
             0.5953938452878081, 0.6755898387841053, 0.9646242213051093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 224}], {
             RGBColor[
             0.2737455232563734, 0.4043047518351688, 0.9389282185178777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 276}], {
             RGBColor[
             0.3818688905219082, 0.5051773725067362, 0.9455533259240227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 326}], {
             RGBColor[
             0.41710106058316465`, 0.5339551065772443, 0.9482786692314206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 361}], {
             RGBColor[
             0.5343048714335602, 0.6274306030557617, 0.9586511615593902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 363}], {
             RGBColor[
             0.31231156123738696`, 0.44484010298125176`, 0.941124497327556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 382}], {
             RGBColor[
             0.4362772751039133, 0.5495232214038076, 0.9497882910832822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 383}], {
             RGBColor[
             0.3853620439560417, 0.5081879430529411, 0.9457800575786848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 393}], {
             RGBColor[
             0.48888131972492244`, 0.5919453792291945, 0.9541237664322981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[
             0.7106195965770347, 0.7723299142936685, 0.9714746288774967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 208}], {
             RGBColor[
             0.961765725524288, 0.9707216784056979, 0.9368937720229036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 221}], {
             RGBColor[
             0.8466717820520852, 0.8810467748649535, 0.983372363799467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 225}], {
             RGBColor[
             0.7354554211857627, 0.7924927555521823, 0.973429795967319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 235}], {
             RGBColor[
             0.6754698104737902, 0.7427073871581614, 0.9690076699524957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 322}], {
             RGBColor[
             0.6751736305988127, 0.7424508510368892, 0.9689887976327638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 335}], {
             RGBColor[
             0.8948914966324915, 0.9189763846341608, 0.9881094577056926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 349}], {
             RGBColor[
             0.8347518304927056, 0.871734818111779, 0.9821842944263086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 351}], {
             RGBColor[
             0.8559741587949518, 0.8883138622771627, 0.9842995377775428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 355}], {
             RGBColor[
             0.8181874262604476, 0.8587945796314043, 0.9805333094155957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 186}], {
             RGBColor[
             0.8777608954018938, 0.9053667280814237, 0.9882028118614761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 240}], {
             RGBColor[
             0.6972171981638797, 0.7618754406790946, 0.9717136257841086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 272}], {
             RGBColor[
             0.7609388026860717, 0.8136075098557803, 0.976730023912024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 308}], {
             RGBColor[
             0.6032916961619108, 0.6820288277069824, 0.9653124049368725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 342}], {
             RGBColor[
             0.9333827818137406, 0.9485460939533891, 0.9528735279671372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 348}], {
             RGBColor[
             0.8234202017931689, 0.8625118748661728, 0.9828937133015057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 374}], {
             RGBColor[
             0.9234164616945242, 0.941113228726829, 0.9697439082963804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 192}], {
             RGBColor[
             0.429908728531144, 0.5459646147303664, 0.9488416275582481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 194}], {
             RGBColor[
             0.5254841944122468, 0.6230607543203968, 0.9567050213475443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 221}], {
             RGBColor[
             0.5659609140061944, 0.6546814753016514, 0.9607393624802185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 256}], {
             RGBColor[
             0.6569445993147318, 0.726658830590829, 0.9677842097676284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 316}], {
             RGBColor[
             0.4459389040642512, 0.558978633379321, 0.9501035816966821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 351}], {
             RGBColor[
             0.575263290749061, 0.6619485627138606, 0.9616665364582943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 399}], {
             RGBColor[
             0.6808939634910955, 0.7316454899800318, 0.6718345597806953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 198}], {
             RGBColor[
             0.9396963101430329, 0.9543692752041593, 0.9808289411040756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 203}], {
             RGBColor[
             0.8493766505548138, 0.8831385927966614, 0.9853881046778012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 266}], {
             RGBColor[
             0.7045639575538257, 0.7675271163274784, 0.9726519643946969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 313}], {
             RGBColor[
             0.9221511019128651, 0.9407622738132155, 0.9924367893860977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 329}], {
             RGBColor[
             0.6292488289618787, 0.7030252732294405, 0.9676506044248173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 340}], {
             RGBColor[
             0.704805960499219, 0.767723585220657, 0.9726710157530443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 341}], {
             RGBColor[
             0.9604750033009379, 0.9685502808109443, 0.8867358637488907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 358}], {
             RGBColor[
             0.9278496870029305, 0.9453061708800621, 0.992980325519175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 204}], {
             RGBColor[
             0.4257759856385128, 0.5403181593015598, 0.9490642391786471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 216}], {
             RGBColor[
             0.46609177150242076`, 0.5755928746095643, 0.9516201195019556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 229}], {
             RGBColor[
             0.44703412415483806`, 0.559086098342295, 0.9504057830649835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 294}], {
             RGBColor[
             0.44351375398334525`, 0.5560369306386974, 0.950181468190597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 307}], {
             RGBColor[
             0.5200212652336925, 0.6212157156645661, 0.9553571253813078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 343}], {
             RGBColor[
             0.47416328165032684`, 0.5825840110137847, 0.9521344289912239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 379}], {
             RGBColor[
             0.7545452946330424, 0.8071714068185208, 0.952956046346795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 205}], {
             RGBColor[
             0.6159839091734446, 0.6971542561388091, 0.9642573642571673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 232}], {
             RGBColor[
             0.8398529227220777, 0.8755371038247153, 0.9844817204264158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 277}], {
             RGBColor[
             0.791088946905983, 0.8367239649124167, 0.979812011147212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 298}], {
             RGBColor[
             0.872187992323303, 0.9003446536442533, 0.9537426957265449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 320}], {
             RGBColor[
             0.6265380818798065, 0.705722609001896, 0.9650882273938206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 347}], {
             RGBColor[
             0.5040430797552576, 0.5937974246378178, 0.9573081157404958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 373}], {
             RGBColor[
             0.5773067854868534, 0.663865967577365, 0.961734345743795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 390}], {
             RGBColor[
             0.6780606265850355, 0.7475509318577891, 0.9691442708463163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 219}], {
             RGBColor[
             0.3315112292636605, 0.4584788142444003, 0.9424574011476097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 248}], {
             RGBColor[
             0.45363813593863733`, 0.5594112502639255, 0.9515786680432092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 260}], {
             RGBColor[
             0.3439507117552165, 0.4692532687520168, 0.9432500339721692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 285}], {
             RGBColor[
             0.3376784085164814, 0.4638205149417517, 0.942850368356177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 200}], {
             RGBColor[
             0.9612584214711017, 0.9706271746834362, 0.9504635664141862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 278}], {
             RGBColor[
             0.9672667744101182, 0.9734997514043335, 0.8682636255039057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 296}], {
             RGBColor[
             0.9565457445976503, 0.9671124679875163, 0.9584408990979578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 330}], {
             RGBColor[
             0.6440402412033733, 0.715302394199953, 0.9643447387124144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 367}], {
             RGBColor[
             0.9625423024589296, 0.9715460608391261, 0.9465603522765804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 398}], {
             RGBColor[
             0.7680013276239851, 0.8188149567007315, 0.9733089367297563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 209}], {
             RGBColor[
             0.4359240568173628, 0.5474182589354946, 0.9499667714843351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 245}], {
             RGBColor[
             0.3400854813791947, 0.4677513775770392, 0.9429361546459561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 286}], {
             RGBColor[
             0.6396818860655731, 0.7076853744710925, 0.926068616908736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 290}], {
             RGBColor[
             0.5865449776599099, 0.6665604457485917, 0.9641652915121381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 352}], {
             RGBColor[
             0.504267558802271, 0.6018181646611568, 0.9560884516746295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 386}], {
             RGBColor[
             0.4003516904273702, 0.5185390093832548, 0.9471663844962432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 232}], {
             RGBColor[
             0.8238406263139452, 0.8630281761727221, 0.9828857643638707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 249}], {
             RGBColor[
             0.7474511675897141, 0.8026338000511408, 0.9754626051231994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 268}], {
             RGBColor[
             0.4848962134455096, 0.577993865276016, 0.9555336505592342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 370}], {
             RGBColor[
             0.8553064265983996, 0.8871874263591103, 0.9536181858755449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 238}], {
             RGBColor[
             0.6359951722097672, 0.7149976918517159, 0.9647405793162732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 245}], {
             RGBColor[
             0.5256774203050174, 0.623575962758223, 0.956570108667474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 187}], {
             RGBColor[
             0.7072368382730634, 0.770048596307418, 0.9724577960378924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 208}], {
             RGBColor[
             0.9330805287625658, 0.9478987010175823, 0.9358850385420192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 323}], {
             RGBColor[
             0.7705389384524672, 0.8211573351516018, 0.9776344923052505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 377}], {
             RGBColor[
             0.9074573328205588, 0.8429961070167635, 0.6273602962602708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 388}], {
             RGBColor[
             0.8874995243730146, 0.913132046474954, 0.9891316909865182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 395}], {
             RGBColor[
             0.9119116022805334, 0.9323947931181888, 0.9844295702911526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 270}], {
             RGBColor[
             0.703810909959865, 0.7609426355477492, 0.7521417071440939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 291}], {
             RGBColor[
             0.6646971078037056, 0.727064226036942, 0.7496494102576806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 357}], {
             RGBColor[
             0.6385742697209579, 0.7020981418507444, 0.7480705574643634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 368}], {
             RGBColor[
             0.6773500073377795, 0.738023531660135, 0.750455641827472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 185}], {
             RGBColor[
             0.5997864536460068, 0.6844950079724407, 0.9626468317904903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 190}], {
             RGBColor[
             0.4731321022944421, 0.5831489808577643, 0.9516658387140667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 226}], {
             RGBColor[
             0.40079411047753666`, 0.5213676098243666, 0.9468149923688012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 252}], {
             RGBColor[
             0.5250449408170155, 0.6252941618171137, 0.9557526075255569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 274}], {
             RGBColor[
             0.4991009523319797, 0.6042316632015996, 0.9537102017160537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 288}], {
             RGBColor[
             0.7085411394119299, 0.7700249985759455, 0.9547479877057647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 318}], {
             RGBColor[
             0.7195289266825871, 0.7782196723315511, 0.9361485299304331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 190}], {
             RGBColor[
             0.6121670542577776, 0.6945461372887778, 0.9636214780222833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 226}], {
             RGBColor[
             0.5398290624408723, 0.6327647662553801, 0.9587706316770177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 252}], {
             RGBColor[
             0.6640798927803511, 0.7366913182481273, 0.9677082468337734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 274}], {
             RGBColor[
             0.6381359042953153, 0.7156288196326132, 0.9656658410242702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 288}], {
             RGBColor[
             0.8475760913752655, 0.881422155006959, 0.9667036270139813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 318}], {
             RGBColor[
             0.8585638786459225, 0.8896168287625648, 0.9481041692386496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 357}], {
             RGBColor[
             0.5111302582397282, 0.6055675096892494, 0.9570276406004736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 272}], {
             RGBColor[
             0.753082598609375, 0.807343185976001, 0.9759806921538725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 306}], {
             RGBColor[
             0.9101005510890103, 0.9307770646573068, 0.9782364355719964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 308}], {
             RGBColor[
             0.595435492085214, 0.675764503827203, 0.964563073178721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 342}], {
             RGBColor[
             0.9255265777370437, 0.9422817700736097, 0.9521241962089857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 348}], {
             RGBColor[
             0.815563997716472, 0.8562475509863934, 0.9821443815433542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 374}], {
             RGBColor[
             0.9155602576178274, 0.9348489048470496, 0.9689945765382288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 378}], {
             RGBColor[
             0.9191918133606198, 0.9375573131738975, 0.9628472999271127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 208}], {
             RGBColor[
             0.7600568028105787, 0.8105874011756943, 0.9199016020746023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 302}], {
             RGBColor[
             0.7623671940214056, 0.8115428073157169, 0.8816124406104114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 377}], {
             RGBColor[
             0.7344336068685718, 0.7056848071748755, 0.6113768597928537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 388}], {
             RGBColor[
             0.7144757984210275, 0.775820746633066, 0.9731482545191013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 201}], {
             RGBColor[
             0.5447650500785991, 0.6348208600568666, 0.9599086452756824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 264}], {
             RGBColor[
             0.5258212507697765, 0.6149097258770452, 0.9588298239298845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 273}], {
             RGBColor[
             0.8379517075302605, 0.8739146221105201, 0.9843286437979566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 281}], {
             RGBColor[
             0.8872721087335496, 0.9107761330716084, 0.8929291297193607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 293}], {
             RGBColor[
             0.5465840797583794, 0.6366958651728132, 0.9600135877958764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 394}], {
             RGBColor[
             0.5901157647988216, 0.674400822788736, 0.9627873882730957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 207}], {
             RGBColor[
             0.841372700548181, 0.8758197583160232, 0.9291909602619381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 241}], {
             RGBColor[
             0.5488422752577227, 0.6423425391300455, 0.9585953825541613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 263}], {
             RGBColor[
             0.6641256590908473, 0.7373672416259182, 0.967275120401194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 280}], {
             RGBColor[
             0.7744042127108288, 0.8239459555376856, 0.9780810367324275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 291}], {
             RGBColor[0.516403833679741, 0.6142459914386774, 0.956528433741]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 336}], {
             RGBColor[
             0.5305169124435325, 0.6264700309199099, 0.9574277066401233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 359}], {
             RGBColor[
             0.8330984066575529, 0.86988646495417, 0.9538401479077969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 226}], {
             RGBColor[
             0.4131747110893075, 0.5314187391407037, 0.9477896386005942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 252}], {
             RGBColor[
             0.5374255414287863, 0.635345291133451, 0.9567272537573499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 274}], {
             RGBColor[
             0.5114815529437505, 0.6142827925179368, 0.9546848479478467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 288}], {
             RGBColor[
             0.7209217400237007, 0.7800761278922826, 0.9557226339375577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 318}], {
             RGBColor[
             0.7319095272943578, 0.7882708016478883, 0.9371231761622261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 225}], {
             RGBColor[
             0.47482916050018575`, 0.583523733402666, 0.9520765680689487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 235}], {
             RGBColor[
             0.41484354978821325`, 0.5337383650086451, 0.9476544420541254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 261}], {
             RGBColor[
             0.5417927550840962, 0.6375071553621365, 0.957608433723679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 322}], {
             RGBColor[
             0.4145473699132358, 0.533481828887373, 0.9476355697343934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 327}], {
             RGBColor[
             0.48513288073811245`, 0.5918887576691219, 0.9528877146698491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 335}], {
             RGBColor[
             0.6342652359469145, 0.7100073624846445, 0.9667562298073223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 349}], {
             RGBColor[
             0.5741255698071286, 0.6627657959622628, 0.9608310665279384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 355}], {
             RGBColor[
             0.5575611655748707, 0.6498255574818879, 0.9591800815172253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 208}], {
             RGBColor[
             0.7347543643528276, 0.7900457417738292, 0.917909701433322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 221}], {
             RGBColor[
             0.6196604208806248, 0.7003708382330849, 0.9643882932098854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[
             0.5084440600143024, 0.6118168189203137, 0.9544457253777374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 322}], {
             RGBColor[
             0.44816226942735243`, 0.5617749144050206, 0.9500047270431822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 335}], {
             RGBColor[
             0.6678801354610311, 0.7383004480022921, 0.969125387116111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 349}], {
             RGBColor[
             0.6077404693212453, 0.6910588814799103, 0.963200223836727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 351}], {
             RGBColor[
             0.6289627976234914, 0.707637925645294, 0.9653154671879611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 355}], {
             RGBColor[
             0.5911760650889873, 0.6781186429995356, 0.9615492388260141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 399}], {
             RGBColor[
             0.7345934703655259, 0.7773348529114652, 0.6754834905103622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 195}], {
             RGBColor[
             0.6517198689781893, 0.6977188363478062, 0.6567805362398277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 242}], {
             RGBColor[
             0.42902367981690326`, 0.5438493282852068, 0.9491578833440062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 253}], {
             RGBColor[
             0.625535093501796, 0.6998958256950505, 0.967373823941081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 255}], {
             RGBColor[
             0.6016713718621862, 0.6808675418230934, 0.9650976808676992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 283}], {
             RGBColor[
             0.6115917215876749, 0.6887777594134783, 0.966043892680517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 312}], {
             RGBColor[
             0.3893777469960599, 0.5116629739923261, 0.9460368102845123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 332}], {
             RGBColor[
             0.44431375833214437`, 0.5562625028340671, 0.9503615743341289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 356}], {
             RGBColor[
             0.4290165951471935, 0.5438435766311758, 0.9491573256128545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 360}], {
             RGBColor[
             0.33778968007578936`, 0.4669981759038432, 0.9427446376121115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 364}], {
             RGBColor[
             0.30637938366268147`, 0.4378732413448727, 0.9408134621608034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 380}], {
             RGBColor[
             0.3141904781680316, 0.4460831969219917, 0.9412582924374043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 389}], {
             RGBColor[
             0.3504883483337448, 0.4779971240952595, 0.9435537855245169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 221}], {
             RGBColor[
             0.7152358867617277, 0.7774669778231154, 0.9722516869991815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 233}], {
             RGBColor[
             0.6205973425252762, 0.7023715768726018, 0.9636141856186802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 256}], {
             RGBColor[
             0.8062195720702652, 0.8494443331122928, 0.9792965342865915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 316}], {
             RGBColor[
             0.5952138768197843, 0.6817641359007849, 0.9616159062156452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 399}], {
             RGBColor[
             0.8301689362466288, 0.8544309925014956, 0.6833468842996584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 241}], {
             RGBColor[
             0.6896169665685881, 0.7305433975171011, 0.6591953057872002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 242}], {
             RGBColor[
             0.7559760737843166, 0.7858491682414268, 0.6640235453633812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.9286237658295996, 0.9228673817793134, 0.6799633428870744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 263}], {
             RGBColor[
             0.8049003504017127, 0.8255681000129738, 0.6678750436342329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 312}], {
             RGBColor[
             0.7163301409634734, 0.7536628139485462, 0.6609024723038872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 356}], {
             RGBColor[
             0.7559689891146069, 0.7858434165873958, 0.6640229876322297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 359}], {
             RGBColor[
             0.9738730979684183, 0.9580873233412256, 0.6544400711408358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 360}], {
             RGBColor[
             0.6647420740432028, 0.7089980158600633, 0.6576102996314865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 380}], {
             RGBColor[
             0.641142872135445, 0.6880830368782118, 0.6561239544567794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 389}], {
             RGBColor[
             0.6774407423011582, 0.7199969640514796, 0.658419447543892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 206}], {
             RGBColor[
             0.5119115669703287, 0.6071606972220696, 0.9569499188151405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 214}], {
             RGBColor[
             0.32252791231401734`, 0.45211286624592795`, 0.9418331838980061]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 286}], {
             RGBColor[
             0.6373509200136753, 0.7052353813587641, 0.9259358718404356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 332}], {
             RGBColor[
             0.4272916073094942, 0.5398524376750145, 0.9493379505552862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 334}], {
             RGBColor[
             0.44690773043950804`, 0.5557776901282362, 0.9508822036243076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 366}], {
             RGBColor[
             0.6367355724168273, 0.7047764561285741, 0.9269774948135423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 386}], {
             RGBColor[
             0.3980207243754723, 0.5160890162709264, 0.9470336394279428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 217}], {
             RGBColor[
             0.585469134952716, 0.6703220379119776, 0.9625142100502599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 231}], {
             RGBColor[
             0.8894504045815907, 0.9104634331336225, 0.7622173007877066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 254}], {
             RGBColor[
             0.5683405049398484, 0.6554860795048083, 0.9614227888920928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 314}], {
             RGBColor[
             0.572823796291683, 0.6593692811369921, 0.9617084602526128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 369}], {
             RGBColor[
             0.5840505480750652, 0.6690933292588062, 0.9624238189488231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 392}], {
             RGBColor[
             0.6113487765961946, 0.6927376827549487, 0.9641632379313139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 203}], {
             RGBColor[
             0.8602344122497474, 0.8914132058463099, 0.9731424017752945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 206}], {
             RGBColor[
             0.841827016406574, 0.877033208312233, 0.9713077245845413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 214}], {
             RGBColor[
             0.6524433617502627, 0.7219853773360914, 0.956190989667407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 266}], {
             RGBColor[
             0.7154217192487593, 0.7758017293771269, 0.9604062614921902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 310}], {
             RGBColor[
             0.9446070843208222, 0.9582086347008199, 0.9786499368453382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 384}], {
             RGBColor[
             0.8809429836121626, 0.9075908991856003, 0.9752064386360979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 215}], {
             RGBColor[
             0.6527105768083135, 0.6868738402082502, 0.6390067684667294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 222}], {
             RGBColor[
             0.6050099062911345, 0.6839187875079075, 0.9652369482090923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 223}], {
             RGBColor[
             0.31655293963220804`, 0.4475199195089553, 0.9414311440081151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 224}], {
             RGBColor[
             0.28336158425969976`, 0.412633700558971, 0.9395409454218607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 247}], {
             RGBColor[
             0.30233076603997044`, 0.43257151332562593`, 0.9406212122618576]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 259}], {
             RGBColor[
             0.4753344816955115, 0.5817538184246631, 0.9527187328144439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 271}], {
             RGBColor[
             0.6583643864913633, 0.7253031974909505, 0.9301425409024044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 287}], {
             RGBColor[
             0.4188788173783073, 0.5359205668332625, 0.9482743361154811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 292}], {
             RGBColor[
             0.2983188082833236, 0.42835469135057636`, 0.940392737202776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 345}], {
             RGBColor[
             0.3216335729449632, 0.45285998725141835`, 0.9417204785591531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 350}], {
             RGBColor[
             0.36636141498498903`, 0.4917455766250402, 0.9445652032955325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 353}], {
             RGBColor[
             0.3004683242524794, 0.4306139689213431, 0.9405151489572956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 393}], {
             RGBColor[
             0.4984973807282488, 0.6002743279529967, 0.9547364933362812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 400}], {
             RGBColor[
             0.3991252029082284, 0.5198836927162617, 0.9467192592245224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 234}], {
             RGBColor[
             0.6810756455843666, 0.7449015617579675, 0.9305244815385927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 296}], {
             RGBColor[
             0.9771440821318578, 0.982474674393846, 0.9235732865593863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 298}], {
             RGBColor[
             0.977693372613154, 0.982884334335416, 0.9226434810524538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 320}], {
             RGBColor[
             0.7320434621696575, 0.7882622896930587, 0.9339890127197295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 330}], {
             RGBColor[
             0.6646385787375808, 0.7306646006062827, 0.9294771261738429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 347}], {
             RGBColor[
             0.6095484600451087, 0.6763371053289805, 0.9262089010664045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 367}], {
             RGBColor[
             0.983140639993137, 0.9869082672454558, 0.9116927397380089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 398}], {
             RGBColor[
             0.7885996651581926, 0.8341771631070611, 0.9384413241911846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 273}], {
             RGBColor[
             0.5986938158634956, 0.6775315341900738, 0.9651295512852649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 281}], {
             RGBColor[
             0.6480142170667844, 0.7143930451511622, 0.8737300372066691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 293}], {
             RGBColor[
             0.3073261880916144, 0.44031277725236684`, 0.9408144952831847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 303}], {
             RGBColor[
             0.39325858945499653`, 0.5139912009440664, 0.9464977850279097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 394}], {
             RGBColor[
             0.35085787313205646`, 0.4780177348682897, 0.9435882957604041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 212}], {
             RGBColor[
             0.4047373379863967, 0.5249848722988862, 0.947010483174686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 234}], {
             RGBColor[
             0.41666104971276996`, 0.5353125920930939, 0.9477702515421661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 239}], {
             RGBColor[
             0.3766932486406819, 0.49991904971964884`, 0.9452519313274579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 269}], {
             RGBColor[
             0.3938606001300785, 0.5155639886484835, 0.946317427056403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 289}], {
             RGBColor[
             0.6409028428777601, 0.7165603165683359, 0.9668091423776324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 309}], {
             RGBColor[
             0.6112700293366202, 0.6933398578263583, 0.9638744827948433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 362}], {
             RGBColor[
             0.5312426439721845, 0.6303178505120647, 0.9562426923267556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 365}], {
             RGBColor[
             0.5784220930540995, 0.6676788003488909, 0.9606005074876187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 206}], {
             RGBColor[
             0.751507356818355, 0.8058025259047351, 0.9758668881582668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 211}], {
             RGBColor[
             0.5553757359669652, 0.644909945773059, 0.9603201788021744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 216}], {
             RGBColor[
             0.5777252229132731, 0.6642679480480751, 0.9617442683475177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 266}], {
             RGBColor[
             0.6251020596605403, 0.7045710469696289, 0.9649654250659158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 329}], {
             RGBColor[
             0.5497869310685934, 0.6400692038715912, 0.9599640650960362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 341}], {
             RGBColor[
             0.8810131054076524, 0.9055942114530949, 0.8790493244201095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 358}], {
             RGBColor[
             0.848387789109645, 0.8823501015222127, 0.9852937861903939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 229}], {
             RGBColor[
             0.3261622599535271, 0.45657188108206437`, 0.942016754585735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 237}], {
             RGBColor[
             0.514766548014226, 0.6113044357334896, 0.9569315564550153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 307}], {
             RGBColor[
             0.3991494010323815, 0.5187014984043354, 0.9469680969020593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 343}], {
             RGBColor[
             0.3532914174490158, 0.480069793753554, 0.9437454005119754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 232}], {
             RGBColor[
             0.6849908334699149, 0.7517813402560839, 0.9709447014597861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 277}], {
             RGBColor[
             0.6362268576538203, 0.7129682013437852, 0.9662749921805822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 373}], {
             RGBColor[
             0.4224446962346906, 0.5401102040087338, 0.9481973267771653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 390}], {
             RGBColor[
             0.5231985373328728, 0.6237951682891576, 0.9556072518796865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 266}], {
             RGBColor[
             0.6066946638173669, 0.6901910494355521, 0.9631307478751625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 286}], {
             RGBColor[
             0.8585393140185282, 0.8894972125073526, 0.9430181639928089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 386}], {
             RGBColor[
             0.6192091183803252, 0.700350847419515, 0.9641159315803162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 231}], {
             RGBColor[
             0.9896131998826371, 0.9885251129758785, 0.7165677266288409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 280}], {
             RGBColor[
             0.9186540329351379, 0.936448754323794, 0.9368256452012407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 291}], {
             RGBColor[
             0.66065365390405, 0.7267487902247858, 0.9152730422098132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 368}], {
             RGBColor[
             0.6733065534381237, 0.7377080958479788, 0.9160792737796046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 372}], {
             RGBColor[
             0.6823271957309848, 0.7455213228113905, 0.9166540611298649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 387}], {
             RGBColor[
             0.9900236653558012, 0.9901425434915875, 0.8149972131882132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 392}], {
             RGBColor[
             0.7115115718972409, 0.7707993625972047, 0.9185136637724483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 221}], {
             RGBColor[
             0.8708065498278781, 0.8987626023451143, 0.9298074363552924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 225}], {
             RGBColor[
             0.7595901889615557, 0.8102085830323431, 0.9198648685231443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 323}], {
             RGBColor[
             0.8233589029899824, 0.8616961400198782, 0.9250782983419603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 351}], {
             RGBColor[
             0.8801089265707447, 0.9060296897573235, 0.9307346103333681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 388}], {
             RGBColor[
             0.9403194889105299, 0.9536708513432304, 0.9365754970232281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 395}], {
             RGBColor[
             0.9647315668180487, 0.9729335979864652, 0.9318733763278624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 286}], {
             RGBColor[
             0.7802208378136646, 0.8273047811084493, 0.9359022715937033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 290}], {
             RGBColor[
             0.7270839294080013, 0.7861798523859487, 0.9739989461971055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 304}], {
             RGBColor[
             0.4340887681799518, 0.5454892542135551, 0.9498622545115007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 338}], {
             RGBColor[
             0.5379994887413009, 0.6358112474177819, 0.9567724369922295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 386}], {
             RGBColor[
             0.5408906421754616, 0.6381584160206116, 0.9570000391812106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 230}], {
             RGBColor[
             0.5701456911264141, 0.6511722581492733, 0.9629513410244701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 258}], {
             RGBColor[
             0.6816631615867023, 0.7494106777358025, 0.970301884978789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 264}], {
             RGBColor[
             0.5653757596375314, 0.6461587577233335, 0.9626797004826595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 279}], {
             RGBColor[
             0.8163892803557976, 0.8568375265864644, 0.9822411647071694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 328}], {
             RGBColor[
             0.7350710694031795, 0.7927696233000472, 0.9745063511217147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 394}], {
             RGBColor[
             0.6296702736665765, 0.7056498546350244, 0.9666372648258708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 216}], {
             RGBColor[
             0.3631862062187099, 0.4889953703823221, 0.944362881800672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 238}], {
             RGBColor[
             0.47312904038550996`, 0.5800923645751163, 0.9525094630227358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 341}], {
             RGBColor[
             0.6664740887130893, 0.7303216337873419, 0.8616679378732638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 358}], {
             RGBColor[
             0.6338487724150819, 0.7070775238564597, 0.9679123996435481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 239}], {
             RGBColor[
             0.3284030193649627, 0.45809248025851645`, 0.9421749206193822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 289}], {
             RGBColor[
             0.5926126136020409, 0.6747337471072035, 0.9637321316695566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 309}], {
             RGBColor[
             0.5629798000609011, 0.6515132883652259, 0.9607974720867676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 362}], {
             RGBColor[
             0.4829524146964653, 0.5884912810509323, 0.95316568161868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 385}], {
             RGBColor[
             0.4986215184488251, 0.6012121653621778, 0.9543992108638839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 215}], {
             RGBColor[
             0.6686924896426556, 0.7007165698310622, 0.6400251218202831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 227}], {
             RGBColor[
             0.45711448323096016`, 0.5678298956764879, 0.9510445864248195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 259}], {
             RGBColor[
             0.49131639452985376`, 0.595596548047475, 0.9537370861679976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 306}], {
             RGBColor[
             0.6591725733081668, 0.7278293870945782, 0.9568460544620844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 308}], {
             RGBColor[
             0.34450751430437054`, 0.4728168262644744, 0.943172692068809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 345}], {
             RGBColor[
             0.3376154857793054, 0.4667027168742303, 0.9427388319127068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 350}], {
             RGBColor[
             0.3823433278193312, 0.5055883062478521, 0.9455835566490862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 378}], {
             RGBColor[
             0.6682638355797765, 0.7346096356111689, 0.9414569188172008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 257}], {
             RGBColor[
             0.5131837478364637, 0.6125224306520214, 0.9558722759638345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 310}], {
             RGBColor[
             0.6464963742331185, 0.7175501237831035, 0.9662576883111762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 332}], {
             RGBColor[
             0.45909634665803584`, 0.5690664378474615, 0.9513035077905252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 389}], {
             RGBColor[
             0.3652709366596363, 0.4908010591086539, 0.9444957189809131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 224}], {
             RGBColor[
             0.5999872509731874, 0.6339859509366581, 0.6359117027121968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 227}], {
             RGBColor[
             0.7577582371101056, 0.775339416431363, 0.6463969903616018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 259}], {
             RGBColor[
             0.7919601484089991, 0.8031060688023501, 0.6490894901047799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 345}], {
             RGBColor[
             0.6382592396584508, 0.6742122376291054, 0.6380912358494892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 350}], {
             RGBColor[
             0.6829870816984767, 0.7130978270027273, 0.6409359605858687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 353}], {
             RGBColor[
             0.617093990965967, 0.6519662192990302, 0.6368859062476318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 393}], {
             RGBColor[
             0.8151230474417364, 0.8216265783306838, 0.6511072506266173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 400}], {
             RGBColor[
             0.7157508696217161, 0.7412359430939488, 0.6430900165148585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 229}], {
             RGBColor[
             0.36647804581743504`, 0.49184659639006884`, 0.9445726349090433]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 294}], {
             RGBColor[
             0.36295767564594217`, 0.4887974286864713, 0.944348320034657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 329}], {
             RGBColor[
             0.357597401320338, 0.4841546284808542, 0.9440067680945339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 340}], {
             RGBColor[
             0.43315453285767824`, 0.5488529404720708, 0.9490271794227607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 341}], {
             RGBColor[
             0.6888235756593972, 0.749679636062358, 0.8630920274186071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 343}], {
             RGBColor[
             0.39360720331292376`, 0.5153445090615585, 0.9463012808352838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 358}], {
             RGBColor[
             0.6561982593613898, 0.7264355261314758, 0.9693364891888916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 231}], {
             RGBColor[
             0.6896226093639093, 0.7485862736279805, 0.745496793789484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 254}], {
             RGBColor[
             0.3685127097221668, 0.4936089199991662, 0.9447022818938702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 314}], {
             RGBColor[
             0.37299600107400144`, 0.49749212163135004`, 0.9449879532543902]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 331}], {
             RGBColor[
             0.39947500146705994`, 0.5204269008985607, 0.9466751717449753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 392}], {
             RGBColor[
             0.411520981378513, 0.5308605232493067, 0.9474427309330913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 222}], {
             RGBColor[
             0.6163198967363606, 0.6937149327749139, 0.9659576107992304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 276}], {
             RGBColor[
             0.4027949419704606, 0.5233024664975447, 0.9468867154181437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 282}], {
             RGBColor[
             0.4292321245291122, 0.5449400335037665, 0.9489196850922358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 305}], {
             RGBColor[
             0.32902405792351164`, 0.45853648376194667`, 0.9422179311113524]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 339}], {
             RGBColor[
             0.4775787826589274, 0.584190028565679, 0.9527257111198589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 361}], {
             RGBColor[
             0.5552309228821126, 0.6455556970465703, 0.9599845510535112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 382}], {
             RGBColor[
             0.45720332655246576`, 0.5676483153946161, 0.9511216805774032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 384}], {
             RGBColor[
             0.5850183931858184, 0.6688258952409845, 0.9629534877136481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 248}], {
             RGBColor[
             0.5097300869243861, 0.6110765620744409, 0.9550399766904254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 251}], {
             RGBColor[
             0.34011728566029775`, 0.4675243251727572, 0.9429475033278787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 260}], {
             RGBColor[
             0.40004266274096534`, 0.5209185805625323, 0.9467113426193854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 352}], {
             RGBColor[
             0.5267648353310687, 0.6225394808698901, 0.9574767276365947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 396}], {
             RGBColor[
             0.41357389299116765`, 0.5317304027098806, 0.9478244926599684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 256}], {
             RGBColor[
             0.8466962916642127, 0.8810650540935474, 0.9833308754192657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 316}], {
             RGBColor[
             0.635690596413732, 0.7133848568820396, 0.9656502473483194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 351}], {
             RGBColor[
             0.7650149830985419, 0.8163547862165791, 0.9772132021099316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 399}], {
             RGBColor[
             0.8706456558405764, 0.8860517134827501, 0.6873812254323326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 223}], {
             RGBColor[
             0.5854779358285167, 0.6659171171862996, 0.9640320810408142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 224}], {
             RGBColor[
             0.5522865804560084, 0.6310308982363153, 0.9621418824545598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 247}], {
             RGBColor[
             0.5712557622362792, 0.6509687110029703, 0.9632221492945566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 259}], {
             RGBColor[
             0.7442594778918202, 0.8001510161020073, 0.9753196698471429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 292}], {
             RGBColor[
             0.5672438044796323, 0.6467518890279207, 0.9629936742354752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 363}], {
             RGBColor[
             0.590852618437022, 0.6715662493823982, 0.9643381612642381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 383}], {
             RGBColor[
             0.6639031011556767, 0.7349140894540875, 0.9689937215153669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 393}], {
             RGBColor[
             0.7674223769245575, 0.818671525630341, 0.9773374303689804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 247}], {
             RGBColor[
             0.2827987955773527, 0.4145698430040181, 0.9394163450935793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 292}], {
             RGBColor[
             0.2787868378207058, 0.41035302102896853`, 0.9391878700344979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 319}], {
             RGBColor[
             0.33532023481344303`, 0.4637752073232584, 0.9426269794617959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 385}], {
             RGBColor[
             0.46890844867828146`, 0.5743921385369746, 0.9525456130504972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 393}], {
             RGBColor[
             0.47896541026563105`, 0.5822726576313888, 0.9535316261680029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 400}], {
             RGBColor[
             0.3795932324456107, 0.5018820223946538, 0.9455143920562441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 227}], {
             RGBColor[
             0.38840924456149195`, 0.5010992767820838, 0.9469311673167332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 259}], {
             RGBColor[
             0.42261115586038545`, 0.5288659291530708, 0.9496236670599113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 363}], {
             RGBColor[
             0.2692042964055873, 0.40028116243346173`, 0.9386421584770065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 383}], {
             RGBColor[
             0.342254779124242, 0.4636290025051511, 0.9432977187281353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 393}], {
             RGBColor[
             0.4457740548931227, 0.5473864386814045, 0.9516414275817486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 235}], {
             RGBColor[
             0.47329427391105794`, 0.5821942917848066, 0.9519787664527364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 261}], {
             RGBColor[
             0.6002434792069409, 0.6859630821382979, 0.96193275812229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 322}], {
             RGBColor[
             0.4729980940360805, 0.5819377556635345, 0.9519598941330044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 327}], {
             RGBColor[
             0.5435836048609571, 0.6403446844452834, 0.9572120390684601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 335}], {
             RGBColor[
             0.6927159600697592, 0.7584632892608059, 0.9710805542059333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 349}], {
             RGBColor[
             0.6325762939299733, 0.7112217227384242, 0.9651553909265493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 355}], {
             RGBColor[
             0.6160118896977154, 0.6982814842580494, 0.9635044059158363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 252}], {
             RGBColor[
             0.4650875496118808, 0.5735639201000532, 0.9518764074120845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 274}], {
             RGBColor[
             0.43914356112684516`, 0.5525014214845391, 0.9498340016025812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 288}], {
             RGBColor[
             0.6485837482067953, 0.7182947568588849, 0.9508717875922923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 315}], {
             RGBColor[
             0.39647428668915063`, 0.5178278325782457, 0.9464839688527547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 318}], {
             RGBColor[
             0.6595715354774523, 0.7264894306144907, 0.9322723298169604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 322}], {
             RGBColor[
             0.3767765113607663, 0.5007666096277738, 0.9452288440268889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 243}], {
             RGBColor[
             0.5194939949226632, 0.6207876538728159, 0.9553156167309689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 306}], {
             RGBColor[
             0.7482383207756169, 0.802452233694879, 0.9632179230034031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 311}], {
             RGBColor[
             0.46379609544253403`, 0.5736171723465588, 0.9514703328466232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 346}], {
             RGBColor[
             0.4693767722637331, 0.5784508741161087, 0.9518259286388713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 350}], {
             RGBColor[
             0.4714090752867812, 0.5802111528481531, 0.951955425190405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 363}], {
             RGBColor[
             0.4269752825425055, 0.5416346279281667, 0.9491274461264115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 383}], {
             RGBColor[
             0.5000257652611602, 0.6049824679998561, 0.9537830063775403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 276}], {
             RGBColor[
             0.5699917668827617, 0.6608320837729924, 0.9598706688597898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 282}], {
             RGBColor[
             0.5964289494414131, 0.6824696507792141, 0.9619036385338817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 301}], {
             RGBColor[
             0.7185621334021024, 0.7800654669789868, 0.972583216178752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 305}], {
             RGBColor[
             0.49622088283581256`, 0.5960661010373942, 0.9552018845529984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 382}], {
             RGBColor[
             0.6244001514647667, 0.7051779326700638, 0.9641056340190493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 294}], {
             RGBColor[
             0.3439000282983595, 0.472290652419202, 0.9431339835976849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 307}], {
             RGBColor[
             0.4204075395487067, 0.5374694374450706, 0.9483096407883955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[
             0.3385397539727553, 0.46764785221358485`, 0.9427924316575618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 340}], {
             RGBColor[
             0.4140968855100955, 0.5323461642048014, 0.9478128429857886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 343}], {
             RGBColor[
             0.37454955596534106`, 0.49883773279428917`, 0.9450869443983116]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 258}], {
             RGBColor[
             0.3886768932322424, 0.5068809242151862, 0.9464457351093352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 264}], {
             RGBColor[
             0.27238949128307155`, 0.4036290042027172, 0.9388235506132057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 279}], {
             RGBColor[
             0.5234030120013378, 0.614307773065848, 0.9583850148377155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 299}], {
             RGBColor[
             0.5580229089141671, 0.6415058806773845, 0.9617950592349305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 300}], {
             RGBColor[
             0.2971526695262403, 0.42888004495939047`, 0.9402622131963285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 328}], {
             RGBColor[
             0.4420848010487196, 0.5502398697794308, 0.9506502012522609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 331}], {
             RGBColor[
             0.7034562710959347, 0.7605682961202055, 0.7463782624824218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 369}], {
             RGBColor[
             0.6882040224862584, 0.7473575649748089, 0.7454064026880471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 372}], {
             RGBColor[
             0.6863178748411317, 0.7457238786851372, 0.7452862190279546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 392}], {
             RGBColor[
             0.7155022510073878, 0.7710019184709516, 0.7471458216705378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 277}], {
             RGBColor[
             0.8600958712024533, 0.8913510490296914, 0.9864993483498306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 373}], {
             RGBColor[
             0.6463137097833237, 0.71849305169464, 0.9684216829464137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 390}], {
             RGBColor[
             0.7470675508815059, 0.8021780159750638, 0.9758316080489349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 256}], {
             RGBColor[
             0.7520577474277613, 0.805969653143034, 0.9746933740387642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 257}], {
             RGBColor[
             0.6192351809465705, 0.7013074458945054, 0.9634784180826385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 310}], {
             RGBColor[
             0.7525478073432252, 0.8063351390255875, 0.9738638304299803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 316}], {
             RGBColor[
             0.5410520521772806, 0.638289455931526, 0.9570127459678179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 389}], {
             RGBColor[
             0.47132236976974307`, 0.579586074351138, 0.9521018610997171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 298}], {
             RGBColor[
             0.6769122591922114, 0.7417965150036177, 0.9375720087154318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 365}], {
             RGBColor[
             0.5420555755047536, 0.6361799506819661, 0.9582832651470232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 261}], {
             RGBColor[
             0.5402578684949684, 0.636177713744277, 0.9575106321074667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 322}], {
             RGBColor[
             0.413012483324108, 0.5321523872695135, 0.9475377681181811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 327}], {
             RGBColor[
             0.48359799414898463`, 0.5905593160512626, 0.9527899130536368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 335}], {
             RGBColor[
             0.6327303493577867, 0.708677920866785, 0.96665842819111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 349}], {
             RGBColor[
             0.5725906832180008, 0.6614363543444033, 0.9607332649117261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 355}], {
             RGBColor[
             0.5560262789857429, 0.6484961158640286, 0.959082279901013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 262}], {
             RGBColor[
             0.5938877997400259, 0.6797607279556609, 0.9621419845948258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 284}], {
             RGBColor[
             0.6065163021181827, 0.6896262099936499, 0.9634006756918161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 334}], {
             RGBColor[
             0.5280599275878282, 0.627733977971505, 0.9559921372343048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 366}], {
             RGBColor[
             0.7178877695651474, 0.7767327439718428, 0.9320874284235396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 376}], {
             RGBColor[
             0.439645514004411, 0.555220579829748, 0.9492348012824657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 397}], {
             RGBColor[
             0.721987489905699, 0.7786679892276652, 0.8748879127469467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 307}], {
             RGBColor[
             0.6090118276094058, 0.6922019920964959, 0.9632244426576759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 324}], {
             RGBColor[
             0.5774465532939345, 0.6659499138411091, 0.9609124650635957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 269}], {
             RGBColor[
             0.3175262815086445, 0.44867159660811373`, 0.9414818645010993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 309}], {
             RGBColor[
             0.5349357107151862, 0.6264474657859884, 0.9590389202395396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 323}], {
             RGBColor[
             0.48058812134956586`, 0.5839907159165882, 0.9536220604386729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 362}], {
             RGBColor[
             0.4549083253507505, 0.5634254584716949, 0.9514071297714519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 365}], {
             RGBColor[
             0.5020877744326655, 0.600786408308521, 0.9557649449323151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 377}], {
             RGBColor[
             0.6175065157176576, 0.60582948778175, 0.6033478643936931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 385}], {
             RGBColor[
             0.47057742910311023`, 0.5761463427829403, 0.9526406590166561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 388}], {
             RGBColor[
             0.5975487072701133, 0.6759654272399405, 0.9651192591199407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 272}], {
             RGBColor[
             0.572538901371361, 0.6638518985736719, 0.959491506076505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 342}], {
             RGBColor[
             0.7449828804990297, 0.7987904826712806, 0.9356350101316182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 374}], {
             RGBColor[
             0.7350165603798134, 0.7913576174447206, 0.9525053904608614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 242}], {
             RGBColor[
             0.46692077740730187`, 0.5766738894545017, 0.9515726528913787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 255}], {
             RGBColor[
             0.6395684694525848, 0.7136921029923883, 0.9675124504150718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 312}], {
             RGBColor[
             0.4272748445864586, 0.544487535161621, 0.9484515798318848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 331}], {
             RGBColor[
             0.40693516669532936`, 0.5268885210604808, 0.9471505268765554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 359}], {
             RGBColor[
             0.6848178015914035, 0.7489120445543005, 0.9419891786688332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 360}], {
             RGBColor[
             0.3756867776661881, 0.4998227370731382, 0.945159407159484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 380}], {
             RGBColor[
             0.3520875757584302, 0.47890775809128666`, 0.9436730619847769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 392}], {
             RGBColor[
             0.41898114660678243`, 0.537322143411227, 0.9479180860646714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 255}], {
             RGBColor[
             0.7059275766683134, 0.768997873716714, 0.9723406899912528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 312}], {
             RGBColor[
             0.49363395180218717`, 0.5997933058859468, 0.9532798194080657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 331}], {
             RGBColor[
             0.47329427391105794`, 0.5821942917848066, 0.9519787664527364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 380}], {
             RGBColor[
             0.41844668297415877`, 0.5342135288156125, 0.9485013015609578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 267}], {
             RGBColor[
             0.49476283226835005`, 0.6007097819038634, 0.9533686890135875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 275}], {
             RGBColor[
             0.6582222825568583, 0.7306661068969964, 0.9681275931949056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 311}], {
             RGBColor[
             0.43710985966678717`, 0.551952083942586, 0.9493694946114538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 326}], {
             RGBColor[
             0.5050785461125363, 0.6090845431201865, 0.9541807797951067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 344}], {
             RGBColor[
             0.4144463346208711, 0.5323220776497031, 0.9479253948360964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 346}], {
             RGBColor[
             0.44269053648798623`, 0.5567857857121359, 0.9497250904037019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 363}], {
             RGBColor[
             0.4002890467667586, 0.5199695395241939, 0.9470266078912422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 383}], {
             RGBColor[
             0.47333952948541336`, 0.5833173795958833, 0.9516821681423708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 302}], {
             RGBColor[
             0.7194684653290362, 0.7765825766353935, 0.8782720742789323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 352}], {
             RGBColor[
             0.5489679351121943, 0.6417706899400583, 0.9588914895212179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 396}], {
             RGBColor[
             0.43577699277229337`, 0.5509616117800487, 0.9492392545445913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 248}], {
             RGBColor[
             0.7673482653072246, 0.8186863771280787, 0.9773780393362674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 251}], {
             RGBColor[
             0.5977354640431362, 0.675134140226395, 0.9652855659737208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 260}], {
             RGBColor[
             0.6576608411238036, 0.7285283956161701, 0.9690494052652274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 326}], {
             RGBColor[
             0.7100944350466212, 0.7722051384668606, 0.972870808090462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 271}], {
             RGBColor[
             0.624610242436508, 0.6923531209860132, 0.9281277419878687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 287}], {
             RGBColor[
             0.38512467332345196`, 0.5029704903283252, 0.9462595372009452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 292}], {
             RGBColor[
             0.26456466422846825`, 0.39540461484563916`, 0.9383779382882403]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 319}], {
             RGBColor[
             0.32109806122120543`, 0.448826801139929, 0.9418170477155383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 362}], {
             RGBColor[
             0.4390171713336841, 0.5467228480423997, 0.9505021520590358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 385}], {
             RGBColor[
             0.45468627508604387`, 0.5594437323536452, 0.9517356813042397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 393}], {
             RGBColor[
             0.46474323667339346`, 0.5673242514480594, 0.9527216944217454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 400}], {
             RGBColor[
             0.36537105885337307`, 0.48693361621132447`, 0.9447044603099866]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 251}], {
             RGBColor[
             0.4622441923352746, 0.5684567611922824, 0.9520687702234782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 260}], {
             RGBColor[
             0.5221695694159422, 0.6218510165820574, 0.9558326095149848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 275}], {
             RGBColor[
             0.7277468997830816, 0.7871093232095581, 0.9736008257400184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 268}], {
             RGBColor[
             0.4935259754258813, 0.5847355009237027, 0.9563937845837269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 279}], {
             RGBColor[
             0.7628637654004036, 0.8146742386009334, 0.9769987888340534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 299}], {
             RGBColor[
             0.7974836623132329, 0.8418723462124698, 0.9804088332312684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 300}], {
             RGBColor[
             0.5366134229253061, 0.6292465104944758, 0.9588759871926664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 370}], {
             RGBColor[
             0.8639361885787713, 0.893929062006797, 0.9544783199000375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 265}], {
             RGBColor[
             0.6210292673026377, 0.6975358504315015, 0.966376506452221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 321}], {
             RGBColor[
             0.695890942018861, 0.7608289491814628, 0.9715744319372019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 325}], {
             RGBColor[
             0.6867668371516131, 0.7534215898139909, 0.9708561489793548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 375}], {
             RGBColor[
             0.8151380549659293, 0.8560080401267591, 0.9820771848255225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 381}], {
             RGBColor[
             0.7484005419118814, 0.8034586079051346, 0.9757081799897827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 260}], {
             RGBColor[
             0.35255676815185377`, 0.4782987796803737, 0.9437401361524382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 275}], {
             RGBColor[
             0.5581340985189933, 0.6435570863078742, 0.9615083523774717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 274}], {
             RGBColor[
             0.563394391466324, 0.6564279734772862, 0.958771616759337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 288}], {
             RGBColor[
             0.772834578546274, 0.8222213088516321, 0.959809402749048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 318}], {
             RGBColor[
             0.7838223658169312, 0.8304159826072377, 0.9412099449737162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 283}], {
             RGBColor[
             0.9123593400786949, 0.9329545887169428, 0.9915028424011455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 332}], {
             RGBColor[
             0.7450813768231644, 0.8004393321375315, 0.9758205240547574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 334}], {
             RGBColor[
             0.7646974999531782, 0.8163645845907532, 0.9773647771237788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 364}], {
             RGBColor[
             0.6071470021537015, 0.6820500706483372, 0.9662724118814319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 366}], {
             RGBColor[
             0.9545253419304975, 0.965363350591091, 0.9534600683130134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 391}], {
             RGBColor[
             0.9537263617557721, 0.946074679521362, 0.6870522786219737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 314}], {
             RGBColor[
             0.35586737106113386`, 0.48265616322418065`, 0.9438965320962232]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 369}], {
             RGBColor[
             0.36709412284451604`, 0.49238021134599463`, 0.9446118907924335]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 312}], {
             RGBColor[
             0.6662816438474701, 0.7368115194238334, 0.9692196169317588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 331}], {
             RGBColor[
             0.6459419659563409, 0.7192125053226932, 0.9679185639764295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 356}], {
             RGBColor[
             0.7059204919986037, 0.768992122062683, 0.9723401322601012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 359}], {
             RGBColor[
             0.9238246008524151, 0.9412360288165128, 0.9627572157687074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 360}], {
             RGBColor[
             0.6146935769271995, 0.6921467213353505, 0.9659274442593582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 380}], {
             RGBColor[
             0.5910943750194417, 0.671231742353499, 0.964441099084651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 310}], {
             RGBColor[
             0.938170036888214, 0.9534078952652785, 0.9895461790978916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 316}], {
             RGBColor[
             0.7266742817222694, 0.785362212171217, 0.9726950946357293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 319}], {
             RGBColor[
             0.655649738715023, 0.7255372874209471, 0.9677017023952152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 384}], {
             RGBColor[
             0.8745059361795544, 0.9027901597500589, 0.9861026808886513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 310}], {
             RGBColor[
             0.8053474704070231, 0.84874568801675, 0.9783312231417658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 356}], {
             RGBColor[
             0.6026502796469897, 0.6878430758782166, 0.9621727938998402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 360}], {
             RGBColor[
             0.5114233645755857, 0.6109976751508841, 0.9557601058990972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 389}], {
             RGBColor[
             0.5241220328335411, 0.6219966233423004, 0.9565692538115026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 264}], {
             RGBColor[
             0.3839069617433597, 0.5018674237892464, 0.9461740945675245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 279}], {
             RGBColor[
             0.6349204824616259, 0.7125461926523773, 0.9657355587920344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 281}], {
             RGBColor[
             0.7453578197071327, 0.7977338309838097, 0.8802734003570007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 300}], {
             RGBColor[
             0.40867013998652846`, 0.5271184645459196, 0.9476127571506475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 328}], {
             RGBColor[
             0.5536022715090078, 0.64847828936596, 0.9580007452065797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 394}], {
             RGBColor[
             0.4482014757724047, 0.5613585207009373, 0.9501316589107358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 271}], {
             RGBColor[
             0.797613958092049, 0.8415354260850505, 0.940225262540455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 287}], {
             RGBColor[
             0.558128388978993, 0.6521527954273624, 0.9583570577535316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 292}], {
             RGBColor[
             0.4375683798840093, 0.5445869199446763, 0.9504754588408266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 345}], {
             RGBColor[
             0.46088314454564894`, 0.5690922158455183, 0.9518032001972037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 350}], {
             RGBColor[
             0.5056109865856748, 0.6079778052191401, 0.9546479249335831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 353}], {
             RGBColor[
             0.4397178958531651, 0.546846197515443, 0.9505978705953462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 393}], {
             RGBColor[
             0.6377469523289345, 0.7165065565470966, 0.9648192149743318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 400}], {
             RGBColor[
             0.5383747745089141, 0.6361159213103615, 0.956801980862573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 327}], {
             RGBColor[
             0.6105471994448676, 0.6943281064047538, 0.9627439047231904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 335}], {
             RGBColor[
             0.7596795546536697, 0.8124467112202765, 0.9766124198606636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 349}], {
             RGBColor[
             0.6995398885138837, 0.7652051446978947, 0.9706872565812796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 355}], {
             RGBColor[
             0.6829754842816258, 0.7522649062175198, 0.9690362715705666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 284}], {
             RGBColor[
             0.7473765345960928, 0.8025754961892921, 0.9754551664038802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 325}], {
             RGBColor[
             0.6134206522918207, 0.6956262635319482, 0.9636775033930105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 376}], {
             RGBColor[
             0.580505746482321, 0.6681698660253903, 0.96128929199453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 397}], {
             RGBColor[
             0.8628477223836091, 0.8916172754233075, 0.8869424034590108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 336}], {
             RGBColor[
             0.49751969121050776`, 0.6005203130159132, 0.9542564752481923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 359}], {
             RGBColor[
             0.8001011854245281, 0.8439367470501733, 0.9506689165158659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 360}], {
             RGBColor[
             0.49097016149931266`, 0.5948474395690109, 0.9538391450065167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 279}], {
             RGBColor[
             0.518633080512455, 0.6092942726399083, 0.9581133742959049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 281}], {
             RGBColor[
             0.6290704177579618, 0.6944819109713407, 0.8726512158608712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 328}], {
             RGBColor[
             0.4373148695598369, 0.5452263693534911, 0.9503785607104502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 394}], {
             RGBColor[
             0.3319140738232338, 0.4581066006884683, 0.9425094744146063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 321}], {
             RGBColor[
             0.43547980738397807`, 0.5500641328975759, 0.9493971719098444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 325}], {
             RGBColor[
             0.42635570251673016`, 0.5426567735301039, 0.9486788889519973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 375}], {
             RGBColor[
             0.5547269203310463, 0.6452432238428722, 0.959899924798165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 381}], {
             RGBColor[
             0.48798940727699847`, 0.5926937916212476, 0.9535309199624252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 358}], {
             RGBColor[
             0.7035750961086569, 0.7667386250530297, 0.9725576459072895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 384}], {
             RGBColor[
             0.6458106310229554, 0.7207487403089194, 0.9670294619267191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 275}], {
             RGBColor[
             0.6601773556782919, 0.7322533233320168, 0.9682815037126937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 306}], {
             RGBColor[
             0.7235071581213037, 0.7823743617259264, 0.9612709952860218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 311}], {
             RGBColor[
             0.43906493278822084`, 0.5535393003776062, 0.9495234051292418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 317}], {
             RGBColor[
             0.3807848218999583, 0.49900167317550337`, 0.9459584431347867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 344}], {
             RGBColor[
             0.4164014077423048, 0.5339092940847234, 0.9480793053538844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 346}], {
             RGBColor[
             0.4446456096094199, 0.5583730021471561, 0.9498790009214899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 354}], {
             RGBColor[
             0.7177601638655791, 0.7780882628198464, 0.9709991575048041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 279}], {
             RGBColor[
             0.500308811256199, 0.5900343038258085, 0.9570698342700883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 299}], {
             RGBColor[
             0.5349287081690283, 0.6172324114373449, 0.9604798786673032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 300}], {
             RGBColor[
             0.27405846878110157`, 0.4046065757193509, 0.9389470326287013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 370}], {
             RGBColor[
             0.6013812344345668, 0.6692891272316721, 0.9345493653360724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 371}], {
             RGBColor[
             0.3141279685473946, 0.4393127624652974, 0.941500225721742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 309}], {
             RGBColor[
             0.5521030622045828, 0.6420924047148231, 0.9601044159684846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 323}], {
             RGBColor[
             0.4977554728389625, 0.5996356548454229, 0.9546875561676179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 362}], {
             RGBColor[
             0.4720756768401471, 0.5790703974005296, 0.952472625500397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 365}], {
             RGBColor[
             0.5192551259220621, 0.6164313472373557, 0.9568304406612601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 377}], {
             RGBColor[
             0.6346738672070542, 0.6214744267105847, 0.6044133601226382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 388}], {
             RGBColor[
             0.61471605875951, 0.6916103661687751, 0.9661847548488857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 336}], {
             RGBColor[
             0.38891166795556065`, 0.5112774723394797, 0.9460020854744116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 357}], {
             RGBColor[
             0.3486757511090212, 0.47408734867204955`, 0.943523959781971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 287}], {
             RGBColor[
             0.7411582937748449, 0.7957021744936499, 0.9357808658414923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 292}], {
             RGBColor[
             0.6205982846798611, 0.6881362990109637, 0.9278992669287873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 303}], {
             RGBColor[
             0.73082694169303, 0.7873147174515251, 0.9349675439606222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 333}], {
             RGBColor[
             0.8317045336748232, 0.8685927195876907, 0.9433321917358566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 337}], {
             RGBColor[
             0.9594193817184151, 0.9692556218470336, 0.9535765810170989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 345}], {
             RGBColor[
             0.6439130493415007, 0.7126415949118057, 0.9292270082851642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 353}], {
             RGBColor[
             0.6227478006490169, 0.6903955765817305, 0.9280216786833069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 385}], {
             RGBColor[
             0.8107198955374367, 0.8521754165189698, 0.9412570099447868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 391}], {
             RGBColor[
             0.9808969372033145, 0.9665807545977735, 0.6494604271053269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 400}], {
             RGBColor[
             0.7214046793047659, 0.779665300376649, 0.9342257889505337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 308}], {
             RGBColor[
             0.47861339936939196`, 0.5840052856015597, 0.953090285229269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 342}], {
             RGBColor[
             0.8087044850212217, 0.8505225518479664, 0.9406514082595336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 348}], {
             RGBColor[
             0.69874190500065, 0.7644883327607501, 0.9706715935939021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 374}], {
             RGBColor[
             0.7987381649020054, 0.8430896866214064, 0.9575217885887768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 375}], {
             RGBColor[
             0.6925481069439454, 0.7596496906442438, 0.9700542536879435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 378}], {
             RGBColor[
             0.8023697206447978, 0.8457980949482542, 0.9513745119776607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 281}], {
             RGBColor[
             0.9412008745184459, 0.9534868072048157, 0.8981500357289433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 293}], {
             RGBColor[
             0.6005128455432758, 0.6794065393060205, 0.9652344938054589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 394}], {
             RGBColor[
             0.6440445305837179, 0.7171114969219432, 0.9680082942826783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 288}], {
             RGBColor[
             0.7468905900612384, 0.801158810236118, 0.9577669969395448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 318}], {
             RGBColor[
             0.7578783773318954, 0.8093534839917236, 0.939167539164213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 311}], {
             RGBColor[
             0.6025243830767291, 0.6834956253707394, 0.96428230931056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 317}], {
             RGBColor[
             0.5442442721884666, 0.6289579981686365, 0.9607173473161048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 344}], {
             RGBColor[
             0.579860858030813, 0.6638656190778565, 0.9628382095352026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 346}], {
             RGBColor[
             0.6081050598979282, 0.6883293271402893, 0.9646379051028081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 282}], {
             RGBColor[
             0.4733221755142949, 0.5831286196367353, 0.9517290641537104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 301}], {
             RGBColor[
             0.5954553594749841, 0.6807244358365081, 0.9624086417985805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 305}], {
             RGBColor[
             0.3731141089086943, 0.49672506989491544`, 0.945027310172827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 339}], {
             RGBColor[
             0.5216688336441101, 0.6223786146986479, 0.9555350901813335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 361}], {
             RGBColor[
             0.5993209738672953, 0.6837442831795391, 0.9627939301149857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 382}], {
             RGBColor[
             0.5012933775376485, 0.605836901527585, 0.9539310596388778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 373}], {
             RGBColor[
             0.5975497339672291, 0.6796799127823413, 0.96375197366721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 390}], {
             RGBColor[
             0.6983035750654112, 0.7633648770627652, 0.971161898769731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 296}], {
             RGBColor[
             0.9831524350708742, 0.9853472511147432, 0.8413733456491058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 302}], {
             RGBColor[
             0.9921973703025385, 0.9910414263487324, 0.7789732968527006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 330}], {
             RGBColor[
             0.6706469316765973, 0.73353717732718, 0.8472771852635624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 367}], {
             RGBColor[
             0.9891489929321535, 0.9897808439663531, 0.8294927988277284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 299}], {
             RGBColor[
             0.8042664981435506, 0.8471711491145756, 0.9810848829176297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 300}], {
             RGBColor[
             0.5433962587556238, 0.6345453133965816, 0.9595520368790278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 328}], {
             RGBColor[
             0.6883283902781031, 0.755905138216622, 0.9699400249349601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 370}], {
             RGBColor[
             0.870719024409089, 0.8992278649089027, 0.9551543695863989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 371}], {
             RGBColor[
             0.5834657585219168, 0.6692515001425281, 0.9621052299720686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 291}], {
             RGBColor[
             0.5936851660666977, 0.6748749874464481, 0.9641631186803026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 336}], {
             RGBColor[
             0.6077982448304894, 0.6870990269276807, 0.9650623915794259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 368}], {
             RGBColor[
             0.6063380656007715, 0.6858342930696412, 0.964969350250094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 387}], {
             RGBColor[
             0.923055177518449, 0.9382687407132498, 0.8638872896587027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 392}], {
             RGBColor[
             0.6445430840598887, 0.7189255598188671, 0.9674037402429376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 293}], {
             RGBColor[
             0.6498332467465647, 0.7162680502671088, 0.8738349797268632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 394}], {
             RGBColor[
             0.6933649317870069, 0.7539730078830316, 0.8766087802040825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 301}], {
             RGBColor[
             0.6218925420336356, 0.7023620028427298, 0.9644416114726726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 305}], {
             RGBColor[
             0.3995512914673458, 0.5183626369011372, 0.947060279846919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 313}], {
             RGBColor[
             0.7076115067252887, 0.7700980360574387, 0.9727804842967076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 339}], {
             RGBColor[
             0.5481060162027617, 0.6440161817048695, 0.9575680598554255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 340}], {
             RGBColor[
             0.4902663653116426, 0.5970593474648802, 0.9530147106636542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 361}], {
             RGBColor[
             0.6257581564259469, 0.7053818501857608, 0.9648268997890778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 382}], {
             RGBColor[
             0.5277305600962999, 0.6274744685338067, 0.9559640293129699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 312}], {
             RGBColor[
             0.6762019935729588, 0.7447217370142183, 0.9701658287445767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 332}], {
             RGBColor[
             0.7311380049090432, 0.7893212658559592, 0.9744905927941935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 334}], {
             RGBColor[
             0.7507541280390571, 0.8052465183091809, 0.9760348458632149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 356}], {
             RGBColor[
             0.7158408417240925, 0.7769023396530679, 0.973286344072919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 360}], {
             RGBColor[
             0.6246139266526882, 0.7000569389257354, 0.966873656072176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 364}], {
             RGBColor[
             0.5932036302395803, 0.6709320043667649, 0.964942480620868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 366}], {
             RGBColor[
             0.9405819700163764, 0.9542452843095188, 0.9521301370524495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 380}], {
             RGBColor[
             0.6010147247449305, 0.6791419599438839, 0.9653873108974689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 389}], {
             RGBColor[
             0.6373125949106437, 0.7110558871171517, 0.9676828039845814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 334}], {
             RGBColor[
             0.681548662443895, 0.7505487462051363, 0.9693053190433593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 366}], {
             RGBColor[
             0.8713765044212143, 0.8995475122054741, 0.945400610232594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 397}], {
             RGBColor[
             0.8754762247617659, 0.9014827574612965, 0.888201094556001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 324}], {
             RGBColor[
             0.41510083537583486`, 0.5339612128530934, 0.94767083606426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 290}], {
             RGBColor[
             0.9308417586562117, 0.9464469679215465, 0.9501007916215063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 304}], {
             RGBColor[
             0.6378465974281622, 0.7057563697491529, 0.9259640999359016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 386}], {
             RGBColor[
             0.744648471423672, 0.7984255315562094, 0.9331018846056114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 292}], {
             RGBColor[
             0.38111271556680504`, 0.4987536683532757, 0.9460310621418639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 303}], {
             RGBColor[
             0.4913413725799739, 0.5979320867938371, 0.9530993391736987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 353}], {
             RGBColor[
             0.38326223153596084`, 0.5010129459240424, 0.9461534738963834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 385}], {
             RGBColor[
             0.5712343264243807, 0.6627927858612817, 0.9593888051578633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 391}], {
             RGBColor[
             0.7414113680902585, 0.7771981239400854, 0.6675922223184034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 400}], {
             RGBColor[
             0.48191911019170997`, 0.5902826697189609, 0.9523575841636102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 318}], {
             RGBColor[
             0.9673185644118456, 0.9751468193660695, 0.9402053251539241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 304}], {
             RGBColor[
             0.5847096890224988, 0.6646314410266523, 0.9640607745393038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 338}], {
             RGBColor[
             0.6886204095838478, 0.7549534342308792, 0.9709709570200324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 336}], {
             RGBColor[
             0.3497978657994014, 0.4773990628286725, 0.9435097885879983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 368}], {
             RGBColor[
             0.34833768656968356`, 0.4761343289706329, 0.9434167472586664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 387}], {
             RGBColor[
             0.6650547984873612, 0.7285687766142417, 0.842334686667275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 303}], {
             RGBColor[
             0.37078136348499013`, 0.490366211311151, 0.9452177402609938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 309}], {
             RGBColor[
             0.515032598941473, 0.6055280333816437, 0.957905467468042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 362}], {
             RGBColor[
             0.43500521357703725`, 0.5425060260673502, 0.9502736769999542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 385}], {
             RGBColor[
             0.450674317329397, 0.5552269103785956, 0.9515072062451584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 400}], {
             RGBColor[
             0.3613591010967262, 0.4827167942362749, 0.9444759852509053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 394}], {
             RGBColor[
             0.3526769028118367, 0.4798927399842363, 0.9436932382805983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 301}], {
             RGBColor[
             0.5422026920605958, 0.6345996518790535, 0.9590154289204206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 313}], {
             RGBColor[
             0.6279216567522488, 0.7023356850937623, 0.9673543017444557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 329}], {
             RGBColor[
             0.3350193838012625, 0.4645986845099873, 0.9425681167831754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 340}], {
             RGBColor[
             0.41057651533860273`, 0.5292969965012039, 0.9475885281114023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 343}], {
             RGBColor[
             0.37102918579384825`, 0.49578856509069164`, 0.9448626295239253]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 330}], {
             RGBColor[
             0.6599259018641292, 0.7271498939103627, 0.9374544588576146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 367}], {
             RGBColor[
             0.9784279631196855, 0.9833935605495359, 0.9196700724217806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 398}], {
             RGBColor[
             0.783886988284741, 0.8306624564111411, 0.9464186568749564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 325}], {
             RGBColor[
             0.7399979519169677, 0.7939039771917927, 0.901653382622073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 375}], {
             RGBColor[
             0.868369169731284, 0.8964904275045611, 0.9128744184682407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 376}], {
             RGBColor[
             0.707083046107468, 0.7664475796852348, 0.8992651712235923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 378}], {
             RGBColor[
             0.9781907834321364, 0.9826388318085714, 0.8941946767579578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 397}], {
             RGBColor[
             0.989425022008756, 0.989894989083152, 0.8249182826880732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 320}], {
             RGBColor[
             0.7278800757775024, 0.7851572429387088, 0.9410365398965685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 347}], {
             RGBColor[
             0.6053850736529534, 0.6732320585746306, 0.9332564282432436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 373}], {
             RGBColor[
             0.678648779384549, 0.7433006015141779, 0.937682658246543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 390}], {
             RGBColor[
             0.7794026204827312, 0.8269855657946019, 0.9450925833490641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 300}], {
             RGBColor[
             0.5780161556684531, 0.661743421008118, 0.9629620812762428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 370}], {
             RGBColor[
             0.9053389213219183, 0.9264259725204391, 0.9585644139836139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 371}], {
             RGBColor[
             0.6180856554347461, 0.6964496077540645, 0.9655152743692836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 370}], {
             RGBColor[
             0.6444686819339915, 0.7138001368024451, 0.937031567945012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 371}], {
             RGBColor[
             0.35721541604681945`, 0.4838237720360704, 0.9439824283306817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 305}], {
             RGBColor[
             0.5216844754280351, 0.6159584531009099, 0.9577398574917892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 313}], {
             RGBColor[
             0.829744690685978, 0.8676938522572114, 0.9834600619415779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 329}], {
             RGBColor[
             0.5368424177349916, 0.6299568516734364, 0.9586738769802976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 339}], {
             RGBColor[
             0.670239200163451, 0.7416119979046423, 0.9682476375002957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 340}], {
             RGBColor[
             0.6123995492723319, 0.694655163664653, 0.9636942883085244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 361}], {
             RGBColor[
             0.7478913403866361, 0.8029776663855336, 0.9755064774339479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 382}], {
             RGBColor[
             0.6498637440569892, 0.7250702847335795, 0.96664360695784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 367}], {
             RGBColor[
             0.9874728983513499, 0.9890877357835248, 0.8572700236253753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 377}], {
             RGBColor[
             0.9625876885689011, 0.8844903180250625, 0.5365149408327898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 353}], {
             RGBColor[
             0.37293087945414594`, 0.49262548888191776`, 0.9453401520155132]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 385}], {
             RGBColor[
             0.5609029743425658, 0.654405328819157, 0.9585754832769932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 391}], {
             RGBColor[
             0.7310800160084436, 0.7688106668979607, 0.6667789004375333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 400}], {
             RGBColor[
             0.47158775810989506`, 0.5818952126768363, 0.95154426228274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 338}], {
             RGBColor[
             0.3956252483557984, 0.5142628360584857, 0.9468342653344277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 313}], {
             RGBColor[
             0.6074034401196882, 0.6836944863156188, 0.9660787303158243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 329}], {
             RGBColor[
             0.3145011671687018, 0.4459574857318438, 0.941292545354544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 339}], {
             RGBColor[
             0.44789794959716106`, 0.5576126319630497, 0.9508663058745421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 340}], {
             RGBColor[
             0.39005829870604203`, 0.5106557977230604, 0.9463129566827708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 361}], {
             RGBColor[
             0.5255500898203462, 0.618978300443941, 0.9581251458081944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 382}], {
             RGBColor[
             0.4275224934906994, 0.5410709187919869, 0.9492622753320865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 308}], {
             RGBColor[
             0.6356313518490273, 0.7074391642828655, 0.9553460286473927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 311}], {
             RGBColor[
             0.6658541855197407, 0.7336166637646491, 0.9572718008838881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 346}], {
             RGBColor[
             0.6714348623409399, 0.738450365534199, 0.9576273966761362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 348}], {
             RGBColor[
             0.8557598574802854, 0.887922211442056, 0.9729273370120259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 350}], {
             RGBColor[
             0.6734671653639879, 0.7402106442662433, 0.9577568932276699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 354}], {
             RGBColor[
             0.9445494165970989, 0.9581656262068893, 0.9787475532594504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 378}], {
             RGBColor[
             0.9593876731244331, 0.9692319736295599, 0.9536302553957845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 343}], {
             RGBColor[
             0.4475366970441955, 0.5609673501165603, 0.9500382867146361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 348}], {
             RGBColor[
             0.541094798476489, 0.6329096506119521, 0.9592539746187507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 354}], {
             RGBColor[
             0.6298843575933026, 0.7031530653767855, 0.9650741908661751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 374}], {
             RGBColor[
             0.6410910583778444, 0.7115110044726083, 0.9461041696136253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 378}], {
             RGBColor[
             0.6447226141206368, 0.7142194127994561, 0.9399568930025092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 323}], {
             RGBColor[
             0.7151649020455042, 0.7774115240232977, 0.9722446119060583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 362}], {
             RGBColor[
             0.6894851060466889, 0.7568462665784044, 0.9700296812388374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 365}], {
             RGBColor[
             0.7366645551286038, 0.7942072164152305, 0.9743874963997005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 385}], {
             RGBColor[
             0.7051542097990486, 0.7695671508896498, 0.9712632104840413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 316}], {
             RGBColor[
             0.7271643416377334, 0.7857276980537706, 0.9718655510269453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 319}], {
             RGBColor[
             0.6561397986304869, 0.7259027733035007, 0.9668721587864312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 384}], {
             RGBColor[
             0.8749959960950183, 0.9031556456326124, 0.9852731372798671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 317}], {
             RGBColor[
             0.32313184929839545`, 0.450243975214226, 0.9419592487326531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 344}], {
             RGBColor[
             0.35874843514074184`, 0.485151596123446, 0.9440801109517507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 346}], {
             RGBColor[
             0.386992637007857, 0.5096153041858787, 0.9458798065193563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 354}], {
             RGBColor[
             0.6601071912640162, 0.7293305648585691, 0.9669999631026704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 356}], {
             RGBColor[
             0.4936268671324774, 0.5997875542319158, 0.9532792616769141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 359}], {
             RGBColor[
             0.7115309759862889, 0.7720314609857455, 0.9436963451855203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 360}], {
             RGBColor[
             0.40239995206107326`, 0.5229421535045832, 0.946866573676171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 380}], {
             RGBColor[
             0.3788007501533155, 0.5020271745227317, 0.9453802285014639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 389}], {
             RGBColor[
             0.4150986203190287, 0.5339411016959995, 0.9476757215885765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 329}], {
             RGBColor[
             0.6225613824266447, 0.6976928848881453, 0.9670127498043326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 339}], {
             RGBColor[
             0.7559581648551039, 0.8093480311193512, 0.9765865103243307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 340}], {
             RGBColor[
             0.6981185139639848, 0.7623911968793617, 0.9720331611325596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 358}], {
             RGBColor[
             0.9211622404676962, 0.9399737825387668, 0.9923424708986903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 361}], {
             RGBColor[
             0.8336103050782891, 0.8707136996002425, 0.9838453502579831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 369}], {
             RGBColor[
             0.3715774141963506, 0.4962634129781785, 0.9448975621529534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 322}], {
             RGBColor[
             0.4324140787775149, 0.5489570740987133, 0.9487740206243149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 351}], {
             RGBColor[
             0.6449929731565986, 0.7206519442942487, 0.9665774213263951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 399}], {
             RGBColor[
             0.7506236458986331, 0.7903488715604198, 0.6767454446487962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 344}], {
             RGBColor[
             0.3004683242524794, 0.4306139689213431, 0.9405151489572956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 346}], {
             RGBColor[
             0.3287125261195945, 0.4550776769837759, 0.9423148445249012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 354}], {
             RGBColor[
             0.6018270803757537, 0.6747929376564662, 0.9634350011082153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 322}], {
             RGBColor[
             0.6955113275658166, 0.7576186721349583, 0.9345623815885207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 384}], {
             RGBColor[
             0.5924756979218273, 0.6752850377882811, 0.9634286605771909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 347}], {
             RGBColor[
             0.359735163209457, 0.4786100139322733, 0.9446019599105193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 398}], {
             RGBColor[
             0.5387863683225409, 0.6364500717103538, 0.9568343830352994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 375}], {
             RGBColor[
             0.6295885950472697, 0.7085363225928336, 0.965097850283146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 381}], {
             RGBColor[
             0.5628510819932218, 0.655986890371209, 0.9587288454474062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 327}], {
             RGBColor[
             0.4833018142740072, 0.5903027799299904, 0.9527710407339048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 335}], {
             RGBColor[
             0.6324341694828092, 0.708421384745513, 0.9666395558713781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 349}], {
             RGBColor[
             0.5722945033430233, 0.6611798182231312, 0.9607143925919941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 355}], {
             RGBColor[
             0.5557300991107654, 0.6482395797427564, 0.9590634075812811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 362}], {
             RGBColor[
             0.6351375166810684, 0.7143895167090042, 0.9646128214379706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 365}], {
             RGBColor[
             0.6823169657629835, 0.7517504665458303, 0.9689706365988338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 377}], {
             RGBColor[
             0.7977357070479756, 0.7567935460190593, 0.6165535560602118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 388}], {
             RGBColor[
             0.7777778986004313, 0.8269294854772498, 0.9783249507864593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 395}], {
             RGBColor[
             0.8021899765079501, 0.8461922321204847, 0.9736228300910936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 376}], {
             RGBColor[
             0.45917836655620575`, 0.5710861154060354, 0.9507703200806505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 397}], {
             RGBColor[
             0.7415203424574938, 0.7945335248039526, 0.8764234315451314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 363}], {
             RGBColor[
             0.41255983373237853`, 0.5299315171755372, 0.9479926091905494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 383}], {
             RGBColor[
             0.48561031645103325`, 0.5932793572472266, 0.9526481694416782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 335}], {
             RGBColor[
             0.7030196803076858, 0.7668283135272618, 0.9718917008068337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 349}], {
             RGBColor[
             0.6428800141679001, 0.7195867470048801, 0.9659665375274498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 355}], {
             RGBColor[
             0.6263156099356421, 0.7066465085245053, 0.9643155525167367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 339}], {
             RGBColor[
             0.4630558919041176, 0.5716110305355762, 0.9518003253630505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 340}], {
             RGBColor[
             0.4052162410129986, 0.5246541962955867, 0.9472469761712792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 341}], {
             RGBColor[
             0.6608852838147175, 0.725480891885874, 0.8613118241671256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 343}], {
             RGBColor[
             0.3656689114682441, 0.49114576488507455`, 0.9445210775838022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 358}], {
             RGBColor[
             0.62825996751671, 0.7022367819549918, 0.96755628593741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 367}], {
             RGBColor[
             0.6659224597254085, 0.7315834867619726, 0.9255739120362372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 398}], {
             RGBColor[
             0.47138148489046405`, 0.5788523826235779, 0.952322496489413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 392}], {
             RGBColor[
             0.4253546431105385, 0.5428425457415318, 0.9483241996260291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 334}], {
             RGBColor[
             0.5834761647835265, 0.6727312617297696, 0.9603525275168268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 356}], {
             RGBColor[
             0.5485628784685619, 0.6443870830736567, 0.9576040257265309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 364}], {
             RGBColor[
             0.4259256669840499, 0.5384167477873537, 0.9492601622744798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 366}], {
             RGBColor[
             0.7733040067608459, 0.8217300277301075, 0.9364478187060614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 380}], {
             RGBColor[
             0.43373676148939994`, 0.5466267033644727, 0.9497049925510808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 389}], {
             RGBColor[
             0.47003463165511317`, 0.5785406305377405, 0.9520004856381933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 337}], {
             RGBColor[
             0.8104800525053375, 0.8527635362833865, 0.9792597021245397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 345}], {
             RGBColor[
             0.494973720128423, 0.5961495093481586, 0.9549101293926052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 353}], {
             RGBColor[
             0.4738084714359392, 0.5739034910180834, 0.9537047997907477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 391}], {
             RGBColor[
             0.8319576079902369, 0.8500886690341263, 0.6751435482127679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 364}], {
             RGBColor[
             0.4455417901140636, 0.5543420002405753, 0.9508044153435011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 366}], {
             RGBColor[
             0.7929201298908597, 0.8376552801833292, 0.9379920717750828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 391}], {
             RGBColor[
             0.7921211497161342, 0.8183666091136002, 0.6715842820840431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 349}], {
             RGBColor[
             0.792012369376702, 0.8377053518204027, 0.979835052664923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 355}], {
             RGBColor[
             0.7754479651444441, 0.8247651133400278, 0.97818406765421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 359}], {
             RGBColor[
             0.6664924387772133, 0.7330395363441651, 0.9408215027547953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 345}], {
             RGBColor[
             0.622688568172015, 0.6968124116075015, 0.9651545186738473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 353}], {
             RGBColor[
             0.6015233194795312, 0.6745663932774263, 0.9639491890719899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 391}], {
             RGBColor[
             0.9596724560338288, 0.9507515712934693, 0.68538793749401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 340}], {
             RGBColor[
             0.5386130234414578, 0.6363093425267927, 0.9568207366912773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 361}], {
             RGBColor[
             0.6741048145557621, 0.7446318452476733, 0.9686329258167009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 382}], {
             RGBColor[
             0.5760772182261151, 0.6667244635957192, 0.959770055340593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 343}], {
             RGBColor[
             0.4412260430055843, 0.5558440768762911, 0.9495414889120292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 358}], {
             RGBColor[
             0.7038170990540502, 0.7669350939462083, 0.9725766972656369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 361}], {
             RGBColor[
             0.616265163664643, 0.6976750110076839, 0.9640795766249297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 358}], {
             RGBColor[
             0.9594861418557691, 0.9677617895364956, 0.8866415452614833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 348}], {
             RGBColor[
             0.8711858841283188, 0.8994269168583588, 0.9468150976490154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 374}], {
             RGBColor[
             0.9711821440296742, 0.9780282707190151, 0.93366529264389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 346}], {
             RGBColor[
             0.36432911196194095`, 0.4899852978929959, 0.9444357067439988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 354}], {
             RGBColor[
             0.6374436662181, 0.7097005585656861, 0.965555863327313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 350}], {
             RGBColor[
             0.3519100778351264, 0.4790839740458954, 0.9436496706782922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 353}], {
             RGBColor[
             0.28601698710261675`, 0.41795236634219834`, 0.9395996163400553]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 354}], {
             RGBColor[
             0.6656878680852152, 0.734164266628119, 0.9673555588949185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 398}], {
             RGBColor[
             0.4162913661979919, 0.5245248873462758, 0.9490542713819746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 354}], {
             RGBColor[
             0.8500128632245607, 0.883636112535976, 0.9826554992308083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 374}], {
             RGBColor[
             0.8612195640091025, 0.8919940516317988, 0.9636854779782584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 378}], {
             RGBColor[
             0.8648511197518949, 0.8947024599586466, 0.9575382013671423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 355}], {
             RGBColor[
             0.7153082990046582, 0.7775235468176461, 0.972258904374826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 355}], {
             RGBColor[
             0.7365306273069043, 0.7941025909830297, 0.9743741477260601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 395}], {
             RGBColor[
             0.8589400000887124, 0.89052578185793, 0.9792791420825016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 399}], {
             RGBColor[
             0.879948032583443, 0.8933188008949593, 0.6883083994104083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 396}], {
             RGBColor[
             0.5999590701953696, 0.6850283988641662, 0.9623915515732647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 391}], {
             RGBColor[
             0.6230008749644305, 0.6718915260281662, 0.659833035160218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 400}], {
             RGBColor[
             0.363508617065882, 0.48497607180704166`, 0.9445983970054247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 374}], {
             RGBColor[
             0.9500091231259161, 0.9622374663966322, 0.969505694225683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 359}], {
             RGBColor[
             0.7511698241374224, 0.8042120636245952, 0.9468168605138627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 360}], {
             RGBColor[
             0.4420388002122069, 0.5551227561434329, 0.9499870890045135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 364}], {
             RGBColor[
             0.410628503799099, 0.5259978215844624, 0.9480559135532054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 380}], {
             RGBColor[
             0.41843959830444905`, 0.5342077771615814, 0.9485007438298063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 389}], {
             RGBColor[
             0.4547374684701623, 0.5661217043348492, 0.9507962369169188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 360}], {
             RGBColor[
             0.6599429090660183, 0.7273666628972627, 0.9404041725131196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 380}], {
             RGBColor[
             0.3272126832330449, 0.4573623764342488, 0.9420880558290632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 389}], {
             RGBColor[
             0.36351055339875815`, 0.4892763036075166, 0.9443835489161758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 382}], {
             RGBColor[
             0.6537293584493005, 0.7280901320766104, 0.9670288952742452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 365}], {
             RGBColor[
             0.6566371697641681, 0.731185209100937, 0.9667557059316128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 385}], {
             RGBColor[
             0.6251268244346129, 0.7065451435753562, 0.9636314200159537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 383}], {
             RGBColor[
             0.38082081710525556`, 0.504164353651234, 0.9454939975378136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 393}], {
             RGBColor[
             0.4843400928741363, 0.5879217898274874, 0.953837706391427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 366}], {
             RGBColor[
             0.6353696320913829, 0.7033407662409132, 0.9268997065327359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 380}], {
             RGBColor[
             0.295802386819937, 0.42823744187527835`, 0.9401568803777551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 391}], {
             RGBColor[
             0.6345706519166576, 0.6840520951711841, 0.6604919168416962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 377}], {
             RGBColor[
             0.8192353601310751, 0.7735892384109921, 0.618696440553854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 388}], {
             RGBColor[
             0.7992775516835309, 0.8437251778691826, 0.9804678352801015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 372}], {
             RGBColor[
             0.37001122839661843`, 0.4949068615572376, 0.9447977661787181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 387}], {
             RGBColor[
             0.6777076980214349, 0.7395280822374346, 0.8431409182370664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 387}], {
             RGBColor[
             0.6867283403142959, 0.7473413092008463, 0.8437157055873268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 392}], {
             RGBColor[
             0.40821624685573554`, 0.5279981283064636, 0.9472321561715618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 390}], {
             RGBColor[
             0.4845214136462816, 0.5905068797277137, 0.9530842333663142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 381}], {
             RGBColor[
             0.68209819494029, 0.7511659813165054, 0.9692315983357268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 397}], {
             RGBColor[
             0.7086054366479941, 0.7670771272973946, 0.8740352201466508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 388}], {
             RGBColor[
             0.914696292968523, 0.8487682573424116, 0.6280507547414795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 389}], {
             RGBColor[
             0.3399113514910004, 0.46836132462566515`, 0.9428972037414687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 393}], {
             RGBColor[
             0.557390575592791, 0.6512696298991768, 0.9584932666425556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 400}], {
             RGBColor[
             0.5514807119543018, 0.6467559117442809, 0.9578337282669046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 395}], {
             RGBColor[
             0.9191505624284975, 0.9381669434438369, 0.9851200287723614]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.08365695714524007], {
             RGBColor[
             0.9875211468791724, 0.9891076877897101, 0.8564704206561676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.08365695714524007], {
             RGBColor[
             0.4738256386217726, 0.5837120248917467, 0.9517204364342614]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.08365695714524007], {
             RGBColor[
             0.3961153530003351, 0.5175169422575254, 0.946461097915496]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.08365695714524007], {
             RGBColor[
             0.5832183341571399, 0.6725219432121317, 0.9603322301454529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.08365695714524007], {
             RGBColor[
             0.9596883683717806, 0.9694562316526885, 0.953121256775906]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.08365695714524007], {
             RGBColor[
             0.3536225610982504, 0.48071182166176035`, 0.9437534947903957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.08365695714524007], {
             RGBColor[
             0.9555290081751514, 0.9663541876283696, 0.9601619686539196]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.08365695714524007], {
             RGBColor[
             0.8596869323415093, 0.8909550405417308, 0.9864789011299593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.08365695714524007], {
             RGBColor[
             0.4640593019063342, 0.5757832727776986, 0.950951594632752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.08365695714524007], {
             RGBColor[
             0.3680487357635102, 0.49320704907618707`, 0.9446727178835007]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.08365695714524007], {
             RGBColor[
             0.7156570479234086, 0.7777959921235638, 0.9722936644078031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.08365695714524007], {
             RGBColor[
             0.3879742443169099, 0.5104655230999625, 0.9459423536690879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.08365695714524007], {
             RGBColor[
             0.3826443276072511, 0.505849017135459, 0.9456027360894087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.08365695714524007], {
             RGBColor[
             0.29118494809259216`, 0.4233842210103145, 0.9398939240731213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.08365695714524007], {
             RGBColor[
             0.48360823540557435`, 0.5916539776617998, 0.9524905582879151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.08365695714524007], {
             RGBColor[
             0.8517709116695357, 0.884643020532556, 0.9857238640115513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.08365695714524007], {
             RGBColor[
             0.28343911087011414`, 0.41524285497504476`, 0.9394528101022405]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.08365695714524007], {
             RGBColor[
             0.9596883683717806, 0.9694562316526885, 0.953121256775906]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.08365695714524007], {
             RGBColor[
             0.6593721513679541, 0.7338258031533853, 0.9666837119314188]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.08365695714524007], {
             RGBColor[
             0.9867199317930659, 0.9887763647613166, 0.8697486281111274]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.08365695714524007], {
             RGBColor[
             0.5164538475084326, 0.6183195252448631, 0.9550762851900937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.08365695714524007], {
             RGBColor[
             0.6459069579259126, 0.7233066916972019, 0.965341627288503]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.08365695714524007], {
             RGBColor[
             0.9097323367611593, 0.9308598875796452, 0.9912522764795654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.08365695714524007], {
             RGBColor[
             0.7662414282272239, 0.8173128944724337, 0.9773354426985772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.08365695714524007], {
             RGBColor[
             0.4985592297929444, 0.6037918684400885, 0.9536675553333859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.08365695714524007], {
             RGBColor[
             0.7840229417453641, 0.8312039479773129, 0.979107737788374]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.08365695714524007], {
             RGBColor[
             0.9367140013861074, 0.9523219863718467, 0.9920108674080792]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.08365695714524007], {
             RGBColor[
             0.9940813256441231, 0.9918204902979214, 0.7477512813225085]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.08365695714524007], {
             RGBColor[
             0.9894312556267729, 0.9898975668443987, 0.8248149755054465]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.08365695714524007], {
             RGBColor[
             0.4247645606232697, 0.5423314459494678, 0.9482866000917298]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.08365695714524007], {
             RGBColor[
             0.6193839288875143, 0.7018828022557254, 0.9631793182415666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.08365695714524007], {
             RGBColor[
             0.594536952507267, 0.6817109074867108, 0.96122327324344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.08365695714524007], {
             RGBColor[
             0.8625532100532968, 0.8932405325860743, 0.9867522892568659]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.08365695714524007], {
             RGBColor[
             0.3015030825420183, 0.4342292345241706, 0.9404815265657042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.08365695714524007], {
             RGBColor[
             0.47028702627849983`, 0.5808392199788084, 0.9514418639082349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.08365695714524007], {
             RGBColor[
             0.5804936979337181, 0.6703099607824947, 0.9601177368012738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.08365695714524007], {
             RGBColor[
             0.5278761379154946, 0.6275926551656349, 0.955975489732166]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.08365695714524007], {
             RGBColor[
             0.9702228947873803, 0.9112169735003536, 0.33882199849379907`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.08365695714524007], {
             RGBColor[
             0.7024296373327353, 0.767462638438086, 0.9709752797373047]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.08365695714524007], {
             RGBColor[
             0.8050558680964723, 0.8476350298989596, 0.9812041033231805]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.08365695714524007], {
             RGBColor[
             0.8803903843553195, 0.907463411197309, 0.9884536148652263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.08365695714524007], {
             RGBColor[
             0.4620360942826929, 0.5741407416843618, 0.9507923203173652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.08365695714524007], {
             RGBColor[
             0.26106361051161164`, 0.3917247854095963, 0.9381785584584101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.08365695714524007], {
             RGBColor[
             0.386522459411199, 0.5092080599834667, 0.945849847218659]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.08365695714524007], {
             RGBColor[
             0.3748454153643658, 0.49909399133539856`, 0.9451057962975994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.08365695714524007], {
             RGBColor[
             0.9856225207724901, 0.9883225571021317, 0.8879355687307513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.08365695714524007], {
             RGBColor[
             0.7034566457290167, 0.7682649452028139, 0.9710776423363069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.08365695714524007], {
             RGBColor[
             0.3762092216567136, 0.500275251798933, 0.9451926968285812]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.08365695714524007], {
             RGBColor[
             0.32308250020973, 0.454259555908216, 0.9418075091160947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.08365695714524007], {
             RGBColor[
             0.44371478019138677`, 0.5587451736736411, 0.949494091325589]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.08365695714524007], {
             RGBColor[
             0.4946791202818076, 0.6006418207420061, 0.9533620988993597]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.08365695714524007], {
             RGBColor[
             0.35048952935961397`, 0.4779981470405073, 0.943553860778441]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.08365695714524007], {
             RGBColor[
             0.40351242761744266`, 0.5239239165030835, 0.9469324329691219]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.08365695714524007], {
             RGBColor[
             0.34577756808125604`, 0.4739168830112537, 0.9432536187724078]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.08365695714524007], {
             RGBColor[
             0.2856856413407256, 0.4176041009379161, 0.9395807466890977]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.08365695714524007], {
             RGBColor[
             0.9376209775797752, 0.9529984077320469, 0.9904755932894761]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.08365695714524007], {
             RGBColor[
             0.36369990487564036`, 0.48944031033971, 0.9443956142248457]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.08365695714524007], {
             RGBColor[
             0.845163501590651, 0.879374451089022, 0.9850936433397227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.08365695714524007], {
             RGBColor[
             0.6369524985693538, 0.7161457585784875, 0.9645623804027121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.08365695714524007], {
             RGBColor[
             0.31583189026958275`, 0.44797944200431217`, 0.9413455066621711]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.08365695714524007], {
             RGBColor[
             0.8040727654692553, 0.8468670226547209, 0.981106116840916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.08365695714524007], {
             RGBColor[
             0.7269503984968376, 0.7866184434241699, 0.9734192800506011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.08365695714524007], {
             RGBColor[
             0.40930857625902967`, 0.5289442491335248, 0.9473017584352308]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.08365695714524007], {
             RGBColor[
             0.6501443555940314, 0.7266169789609513, 0.9657639714873285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.08365695714524007], {
             RGBColor[
             0.5922571533696417, 0.6798600638430058, 0.9610437991041467]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.08365695714524007], {
             RGBColor[
             0.4531506933761011, 0.5669180874114541, 0.9500953393698686]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.08365695714524007], {
             RGBColor[
             0.9660783745246253, 0.9742218877788053, 0.9423046431396614]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.08365695714524007], {
             RGBColor[
             0.5467645782935266, 0.6429271419790634, 0.9574624569493616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.08365695714524007], {
             RGBColor[
             0.9859750987818858, 0.9884683571698584, 0.8820924386724255]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.08365695714524007], {
             RGBColor[
             0.46071143381387764`, 0.5730653226405035, 0.9506880381928688]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.08365695714524007], {
             RGBColor[
             0.3816385079331451, 0.5049778266877152, 0.9455386461491861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.08365695714524007], {
             RGBColor[
             0.46075150168267126`, 0.5730978515414271, 0.9506911924822737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.08365695714524007], {
             RGBColor[
             0.930922033381813, 0.9477559764859623, 0.9932733686595089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.08365695714524007], {
             RGBColor[
             0.28274290218072046`, 0.41451109550031157`, 0.9394131620473279]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.08365695714524007], {
             RGBColor[
             0.3356847870356098, 0.46517502334743993`, 0.942610515688875]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.08365695714524007], {
             RGBColor[
             0.9546007487898153, 0.9656618932986712, 0.9617332696644715]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.08365695714524007], {
             RGBColor[
             0.6217329003751657, 0.7037898031293606, 0.9633642378816405]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.08365695714524007], {
             RGBColor[
             0.8485856520582441, 0.8821031809800809, 0.9854200511063116]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.08365695714524007], {
             RGBColor[
             0.8359187331698229, 0.8720029236928074, 0.9842118690748419]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.08365695714524007], {
             RGBColor[
             0.26881617373621797`, 0.39987322089955607`, 0.9386200554651619]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.08365695714524007], {
             RGBColor[
             0.44637045343284343`, 0.5610453843573727, 0.949663308476215]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.08365695714524007], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.08365695714524007], {
             RGBColor[
             0.4300367346757148, 0.546897938126523, 0.9486225383603512]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.08365695714524007], {
             RGBColor[
             0.8904800695809433, 0.915508652319012, 0.9894159780492147]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.08365695714524007], {
             RGBColor[
             0.787434959711638, 0.8338694423448632, 0.9794478158521314]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.08365695714524007], {
             RGBColor[
             0.7065196945203298, 0.7706578221986208, 0.9713829384140066]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.08365695714524007], {
             RGBColor[
             0.9454554493068931, 0.9588413439183614, 0.9772138762129455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.08365695714524007], {
             RGBColor[
             0.6060790520145241, 0.6910813038323593, 0.9621319095967549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.08365695714524007], {
             RGBColor[
             0.7662414282272239, 0.8173128944724337, 0.9773354426985772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.08365695714524007], {
             RGBColor[
             0.3295329352216119, 0.4598465985072176, 0.942218525131156]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.08365695714524007], {
             RGBColor[
             0.6732345097384469, 0.7446551828702399, 0.9680653822626852]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.08365695714524007], {
             RGBColor[
             0.9237808590125841, 0.9420617978859536, 0.9925922370731702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.08365695714524007], {
             RGBColor[
             0.29263139107118624`, 0.4249045242905986, 0.9399762968609316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.08365695714524007], {
             RGBColor[
             0.9357612033142917, 0.9516113911299502, 0.9936237060141268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.08365695714524007], {
             RGBColor[
             0.6528406571290689, 0.7287233502127733, 0.9660327136259707]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.08365695714524007], {
             RGBColor[
             0.9396428956133918, 0.9545063508909313, 0.987053013459244]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.08365695714524007], {
             RGBColor[
             0.3743364953974701, 0.49865319043913486`, 0.945073368367329]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.08365695714524007], {
             RGBColor[
             0.9789351703905685, 0.9838104650845545, 0.9205414413280224]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.08365695714524007], {
             RGBColor[
             0.8639111858972571, 0.8943233456627759, 0.9868818142051422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.08365695714524007], {
             RGBColor[
             0.950698176454155, 0.9627513612406114, 0.968339306674865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.08365695714524007], {
             RGBColor[
             0.9887711746828277, 0.9896246064107708, 0.8357542249813432]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.08365695714524007], {
             RGBColor[
             0.7596428713950212, 0.8121580517242275, 0.9766777602205627]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.08365695714524007], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.08365695714524007], {
             RGBColor[
             0.4870505718989168, 0.594448621502587, 0.9527615516263651]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.08365695714524007], {
             RGBColor[
             0.49622990368036246`, 0.6019008165669489, 0.9534841822492007]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.08365695714524007], {
             RGBColor[
             0.2778790954886905, 0.40939892628383245`, 0.939136175451574]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.08365695714524007], {
             RGBColor[
             0.6014955647014607, 0.6873602223478641, 0.9617710806856032]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.08365695714524007], {
             RGBColor[
             0.4256276784130769, 0.5430790351974373, 0.9483415971940712]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.08365695714524007], {
             RGBColor[
             0.7343287451860383, 0.7923824639352852, 0.9741546846940106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.08365695714524007], {
             RGBColor[
             0.26485173841013293`, 0.3957063480121231, 0.9383942867381979]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.08365695714524007], {
             RGBColor[
             0.5629547466737284, 0.656071050028885, 0.958737006310792]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.08365695714524007], {
             RGBColor[
             0.6050063027572553, 0.6902103976585052, 0.9620474588456127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.08365695714524007], {
             RGBColor[
             0.33611502149976236`, 0.465547670816076, 0.9426379298484894]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.08365695714524007], {
             RGBColor[
             0.3153198217449713, 0.4475359139856061, 0.9413128781085872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.08365695714524007], {
             RGBColor[
             0.44877060258525026`, 0.5631242729181835, 0.9498162438578378]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.08365695714524007], {
             RGBColor[
             0.7803824113268449, 0.8283599379453098, 0.978744883738947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.08365695714524007], {
             RGBColor[
             0.47763815942589105`, 0.586807201032635, 0.9520205720376855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.08365695714524007], {
             RGBColor[
             0.3330024737157232, 0.4628517383667417, 0.9424396010560083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.08365695714524007], {
             RGBColor[
             0.29307294094795683`, 0.4253686212069636, 0.9400014424731992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.08365695714524007], {
             RGBColor[
             0.9835597993818809, 0.9872595058141402, 0.9127131507421469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.08365695714524007], {
             RGBColor[
             0.6910578136350795, 0.7585788833364161, 0.9698418426268568]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.08365695714524007], {
             RGBColor[
             0.7505460115960915, 0.8050515157106085, 0.9757710702507936]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.08365695714524007], {
             RGBColor[
             0.7368900728190463, 0.7943833925490021, 0.9744099738955012]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.08365695714524007], {
             RGBColor[
             0.989007450079598, 0.989722312359336, 0.8318385301957327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.08365695714524007], {
             RGBColor[
             0.5639077678436512, 0.6568447555477427, 0.9588120316283198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.08365695714524007], {
             RGBColor[
             0.30718223579510057`, 0.44019838467227357`, 0.9408049459419128]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.08365695714524007], {
             RGBColor[
             0.9825204421456383, 0.9526994883411898, 0.38659564778367506`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.08365695714524007], {
             RGBColor[
             0.8607677886927744, 0.8918168860571655, 0.9865819941736348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.08365695714524007], {
             RGBColor[
             0.47763815942589105`, 0.586807201032635, 0.9520205720376855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.08365695714524007], {
             RGBColor[
             0.5136477298383573, 0.6160413925061355, 0.9548553773279576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.08365695714524007], {
             RGBColor[
             0.4815778658444329, 0.5900056321849588, 0.9523307201585732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.08365695714524007], {
             RGBColor[
             0.5969838625475337, 0.6836974192894403, 0.9614159029651366]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.08365695714524007], {
             RGBColor[
             0.5030202275558598, 0.6074135073896823, 0.9540187414184558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.08365695714524007], {
             RGBColor[
             0.5157645893195186, 0.6177599543963752, 0.9550220242606264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.08365695714524007], {
             RGBColor[
             0.6525562666959804, 0.7285011822449973, 0.96600436824538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.08365695714524007], {
             RGBColor[
             0.26920836194947106`, 0.400285435577854, 0.9386423900037163]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.08365695714524007], {
             RGBColor[
             0.8863758071393271, 0.9122360248553034, 0.9890245098336149]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.08365695714524007], {
             RGBColor[
             0.35950231963175616`, 0.4858045729782263, 0.9441281478048843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.08365695714524007], {
             RGBColor[
             0.8675782485062734, 0.8972473618474427, 0.9872315819104156]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.08365695714524007], {
             RGBColor[
             0.9079254189219125, 0.929419100342108, 0.9910799310430035]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.08365695714524007], {
             RGBColor[
             0.9618276912566563, 0.9710517351574091, 0.9494999411565814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.08365695714524007], {
             RGBColor[
             0.6890937217851618, 0.7570445198556094, 0.9696460803067389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.08365695714524007], {
             RGBColor[
             0.3927777276086674, 0.5146260588971927, 0.9462484273768852]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.08365695714524007], {
             RGBColor[
             0.9523414796400531, 0.8487568785729305, 0.2805110397103783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.08365695714524007], {
             RGBColor[
             0.652660695093868, 0.7285827625031123, 0.9660147766921426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.08365695714524007], {
             RGBColor[
             0.4472843390084782, 0.5618369461097629, 0.9497215404569772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.08365695714524007], {
             RGBColor[
             0.2769777357141267, 0.4084515400112554, 0.9390848443458549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.08365695714524007], {
             RGBColor[
             0.9263027119928161, 0.944072654998515, 0.9928327736617094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.08365695714524007], {
             RGBColor[
             0.4094171203754899, 0.5290382645916167, 0.9473086747703499]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.08365695714524007], {
             RGBColor[
             0.6520104636617756, 0.7280747967664197, 0.9659499676997498]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.08365695714524007], {
             RGBColor[
             0.6648169697849432, 0.7380793366828897, 0.9672264005465032]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.08365695714524007], {
             RGBColor[
             0.33233373199219496`, 0.4622725078977578, 0.9423969894247303]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.08365695714524007], {
             RGBColor[
             0.9475057431993174, 0.8295847949990561, 0.27662009266083926`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.08365695714524007], {
             RGBColor[
             0.2986305667672401, 0.43121003831685945`, 0.9403179410418367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.08365695714524007], {
             RGBColor[
             0.4194677267496983, 0.5377435946747916, 0.9479490905211121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.08365695714524007], {
             RGBColor[
             0.4855127029062129, 0.5932001101741015, 0.9526404849458597]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.08365695714524007], {
             RGBColor[
             0.9430650416469146, 0.9570585817994828, 0.9812602128631217]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.08365695714524007], {
             RGBColor[
             0.9901575875787365, 0.9784613731740531, 0.41626451563736233`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.08365695714524007], {
             RGBColor[
             0.3258072981210929, 0.4566196389067134, 0.9419811308295625]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.08365695714524007], {
             RGBColor[
             0.5386123884990045, 0.6363088270519053, 0.9568206867062816]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.08365695714524007], {
             RGBColor[
             0.9943393357712313, 0.9903007365326373, 0.6252498161478016]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.08365695714524007], {
             RGBColor[
             0.38700189684143627`, 0.5096233245883123, 0.9458803965477638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.08365695714524007], {
             RGBColor[
             0.9439345828311864, 0.9577070841909696, 0.979788306450812]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.08365695714524007], {
             RGBColor[
             0.7696466012307213, 0.8199730415030392, 0.9776748385204148]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.08365695714524007], {
             RGBColor[
             0.6993642569391566, 0.7650679399768684, 0.9706697512672812]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.08365695714524007], {
             RGBColor[
             0.2879912923145869, 0.4200274862981594, 0.9397120501011542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.08365695714524007], {
             RGBColor[
             0.6716258255341174, 0.743398466543365, 0.9679050436552062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.08365695714524007], {
             RGBColor[
             0.3741046112590836, 0.4984523440533002, 0.9450585929150782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.08365695714524007], {
             RGBColor[
             0.3168527880881731, 0.4488636923829588, 0.9414105573684272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.08365695714524007], {
             RGBColor[
             0.937630957748495, 0.9530058509255371, 0.9904586994670783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.08365695714524007], {
             RGBColor[
             0.8856170994785906, 0.911631051961203, 0.9889521436196276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.08365695714524007], {
             RGBColor[
             0.3762092216567136, 0.500275251798933, 0.9451926968285812]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.08365695714524007], {
             RGBColor[
             0.3474203984698523, 0.4753398201227995, 0.9433582984720712]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.08365695714524007], {
             RGBColor[
             0.9288385484480992, 0.9460946621545108, 0.9930746440065823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.08365695714524007], {
             RGBColor[
             0.5466478498398238, 0.6428323765617905, 0.9574532676578956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.08365695714524007], {
             RGBColor[
             0.7708459984256073, 0.8209100197074405, 0.9777943832237971]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.08365695714524007], {
             RGBColor[
             0.2754192782779116, 0.40681350243388475`, 0.9389960925003936]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.08365695714524007], {
             RGBColor[
             0.9406600839368944, 0.9552649682771065, 0.9853311789527577]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.08365695714524007], {
             RGBColor[
             0.29538510506927135`, 0.4277988522981377, 0.9401331167993677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.08365695714524007], {
             RGBColor[
             0.7388214056093424, 0.7958921644034542, 0.9746024710987068]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.08365695714524007], {
             RGBColor[
             0.6665689829209167, 0.7394480226605054, 0.9674010248424034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.08365695714524007], {
             RGBColor[
             0.8802605642250505, 0.9073598961493061, 0.9884412325053095]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.08365695714524007], {
             RGBColor[
             0.9937094285718016, 0.9889534287264441, 0.5566883048264862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.08365695714524007], {
             RGBColor[
             0.46075150168267126`, 0.5730978515414271, 0.9506911924822737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.08365695714524007], {
             RGBColor[
             0.7388214056093424, 0.7958921644034542, 0.9746024710987068]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.08365695714524007], {
             RGBColor[
             0.869904691325197, 0.8991024042016443, 0.9874534801033246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.08365695714524007], {
             RGBColor[
             0.5342131123210764, 0.6327372964655299, 0.9564743595704754]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.08365695714524007], {
             RGBColor[
             0.7840229417453641, 0.8312039479773129, 0.979107737788374]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.08365695714524007], {
             RGBColor[
             0.697122880323872, 0.7633169595299149, 0.970446351793125]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.08365695714524007], {
             RGBColor[
             0.4855127029062129, 0.5932001101741015, 0.9526404849458597]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.08365695714524007], {
             RGBColor[
             0.41637843637734107`, 0.5350678066265045, 0.9477522436703377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.08365695714524007], {
             RGBColor[
             0.48360823540557435`, 0.5916539776617998, 0.9524905582879151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.08365695714524007], {
             RGBColor[
             0.324767475010776, 0.4557189963915861, 0.9419148742204526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.08365695714524007], {
             RGBColor[
             0.6747591671677801, 0.7458462568418607, 0.9682173458665073]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.08365695714524007], {
             RGBColor[
             0.9786722629456028, 0.9397186763040262, 0.37164619825920275`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.08365695714524007], {
             RGBColor[
             0.29072317296547573`, 0.42289886607348104`, 0.9398676266627671]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.08365695714524007], {
             RGBColor[
             0.7852969301703976, 0.8321991974176197, 0.9792347170484825]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.08365695714524007], {
             RGBColor[
             0.9505540718379665, 0.9626438882538078, 0.9685832382015689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.08365695714524007], {
             RGBColor[
             0.3360849100948258, 0.46552158983056313`, 0.9426360111763933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.08365695714524007], {
             RGBColor[
             0.9818567590053092, 0.9859893810897659, 0.9155959538756147]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.08365695714524007], {
             RGBColor[
             0.30550715841183407`, 0.4384377721364202, 0.9407095527629907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.08365695714524007], {
             RGBColor[
             0.4530275672621159, 0.5668114417600186, 0.9500874938827616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.08365695714524007], {
             RGBColor[
             0.7699147526615284, 0.820182523438812, 0.9777015653490201]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.08365695714524007], {
             RGBColor[
             0.30490412143720186`, 0.4378039420413292, 0.9406752106993986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.08365695714524007], {
             RGBColor[
             0.4611218199212818, 0.5733984925701777, 0.9507203452905376]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.08365695714524007], {
             RGBColor[
             0.7330999609751816, 0.7914225283706582, 0.9740322109675137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.08365695714524007], {
             RGBColor[
             0.9856225207724901, 0.9883225571021317, 0.8879355687307513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.08365695714524007], {
             RGBColor[
             0.985900493300081, 0.9884375058858587, 0.883328844578729]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.08365695714524007], {
             RGBColor[
             0.5764630085654543, 0.6670376655728514, 0.9598004261693024]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.08365695714524007], {
             RGBColor[
             0.863131959480874, 0.8937020116698896, 0.9868074908939239]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.08365695714524007], {
             RGBColor[
             0.34083671927240206`, 0.46963736810730605`, 0.9429387922553286]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.08365695714524007], {
             RGBColor[
             0.35644710871067753`, 0.48315830283775385`, 0.9439334724666102]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.08365695714524007], {
             RGBColor[
             0.3680487357635102, 0.49320704907618707`, 0.9446727178835007]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.08365695714524007], {
             RGBColor[
             0.3543326516625589, 0.48132686641837485`, 0.943798741133245]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.08365695714524007], {
             RGBColor[
             0.969336243521801, 0.9082260905859373, 0.33537752575706553`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.08365695714524007], {
             RGBColor[
             0.38553569316501773`, 0.5083533726573382, 0.9457869713460154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.08365695714524007], {
             RGBColor[
             0.3856413397350344, 0.5084448784063356, 0.9457937030520374]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.08365695714524007], {
             RGBColor[
             0.35870489098527797`, 0.48511388036457603`, 0.9440773363566692]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.08365695714524007], {
             RGBColor[
             0.3876031802494093, 0.5101441260549158, 0.9459187097948258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.08365695714524007], {
             RGBColor[
             0.34037965812686666`, 0.46924148471560445`, 0.9429096687232984]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.08365695714524007], {
             RGBColor[
             0.7557126063556753, 0.8090876988043699, 0.9762860281318557]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.08365695714524007], {
             RGBColor[
             0.8739349024874432, 0.9023159851852518, 0.9878378852417915]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.08365695714524007], {
             RGBColor[
             0.2970209691695903, 0.4295182491873475, 0.9402262768398368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.08365695714524007], {
             RGBColor[
             0.23063825842457372`, 0.3597458112873788, 0.9364458796673282]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.08365695714524007], {
             RGBColor[
             0.5332798846230304, 0.6319796601788275, 0.9564008924675597]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.08365695714524007], {
             RGBColor[
             0.34083671927240206`, 0.46963736810730605`, 0.9429387922553286]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.08365695714524007], {
             RGBColor[
             0.5461802306984102, 0.6424527422767887, 0.9574164549661383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.08365695714524007], {
             RGBColor[
             0.6930985408098799, 0.7601731149154711, 0.9700452432399612]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.08365695714524007], {
             RGBColor[
             0.3474203984698523, 0.4753398201227995, 0.9433582984720712]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.08365695714524007], {
             RGBColor[
             0.27715942277195427`, 0.408642504628657, 0.9390951911550163]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.08365695714524007], {
             RGBColor[
             0.993603878992784, 0.9887276688496253, 0.5451998845269306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.08365695714524007], {
             RGBColor[
             0.9088598470185479, 0.9301641879419901, 0.9911690576290344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.08365695714524007], {
             RGBColor[
             0.5664355178827725, 0.658896896903343, 0.9590110253708529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.08365695714524007], {
             RGBColor[
             0.38029453216342407`, 0.5038137424261692, 0.9454530092015706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.08365695714524007], {
             RGBColor[
             0.41330866319908544`, 0.5324089233907857, 0.9475566404379131]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.08365695714524007], {
             RGBColor[
             0.4530275672621159, 0.5668114417600186, 0.9500874938827616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.08365695714524007], {
             RGBColor[
             0.7246289745912503, 0.7848049294256499, 0.9731879022106319]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.08365695714524007], {
             RGBColor[
             0.6054213614986178, 0.6905473610429265, 0.962080133790143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.08365695714524007], {
             RGBColor[
             0.30035893001924785`, 0.43302665767927906`, 0.9404163687721543]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.08365695714524007], {
             RGBColor[
             0.508817296849169, 0.6121198293969862, 0.9544751079485896]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.08365695714524007], {
             RGBColor[
             0.40056167019157335`, 0.521368118730176, 0.9467444133151978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.08365695714524007], {
             RGBColor[
             0.5332798846230304, 0.6319796601788275, 0.9564008924675597]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.08365695714524007], {
             RGBColor[
             0.4928077591469164, 0.599122565468843, 0.9532147784957994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.08365695714524007], {
             RGBColor[
             0.4484156549363376, 0.5628168351048829, 0.949793626907517]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.08365695714524007], {
             RGBColor[
             0.3847858576891181, 0.5077039028559407, 0.9457391924925446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.08365695714524007], {
             RGBColor[
             0.902839537015086, 0.9253637561621912, 0.99059483508651]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.08365695714524007], {
             RGBColor[
             0.2685766219851151, 0.3996214368206887, 0.9386064133473218]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.08365695714524007], {
             RGBColor[
             0.631856993599363, 0.7120089980939661, 0.9641612435860248]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.08365695714524007], {
             RGBColor[
             0.7560809295700858, 0.8093754356988275, 0.9763227391476921]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.08365695714524007], {
             RGBColor[
             0.8814404019375207, 0.9083006667153883, 0.9885537664795784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.08365695714524007], {
             RGBColor[
             0.29263139107118624`, 0.4249045242905986, 0.9399762968609316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.08365695714524007], {
             RGBColor[
             0.5893383799513596, 0.6774904720928003, 0.9608140225688402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.08365695714524007], {
             RGBColor[
             0.9263027119928161, 0.944072654998515, 0.9928327736617094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.08365695714524007], {
             RGBColor[
             0.35138407970929925`, 0.4787729615919968, 0.9436108607357031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.08365695714524007], {
             RGBColor[
             0.8785752687135964, 0.9060160872546006, 0.9882804875149459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.08365695714524007], {
             RGBColor[
             0.9376799769727502, 0.953042409382725, 0.9903757227066756]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.08365695714524007], {
             RGBColor[
             0.6720348440103685, 0.7437179948856679, 0.967945810794424]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.08365695714524007], {
             RGBColor[
             0.5001943636925306, 0.6051193438017153, 0.9537962790636542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.08365695714524007], {
             RGBColor[
             0.6145840532961973, 0.697986047018763, 0.9628014544524944]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.08365695714524007], {
             RGBColor[
             0.41248214523252136`, 0.5316930350701489, 0.9475039754439448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.08365695714524007], {
             RGBColor[
             0.6672070737908513, 0.7399465040977684, 0.9674646237770202]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.08365695714524007], {
             RGBColor[
             0.7347480322179359, 0.7927100141513032, 0.97419647530689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.08365695714524007], {
             RGBColor[
             0.6311284378578226, 0.7114175237219215, 0.9641038890092631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.08365695714524007], {
             RGBColor[
             0.2676195597941888, 0.39861550377677746`, 0.938551910071395]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.08365695714524007], {
             RGBColor[
             0.3606181326677548, 0.48677103414761447`, 0.9441992464248634]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.08365695714524007], {
             RGBColor[
             0.4802893666595522, 0.5889595705004459, 0.9522292847828114]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.08365695714524007], {
             RGBColor[
             0.4967179053897838, 0.6022969983388836, 0.9535225995313755]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.08365695714524007], {
             RGBColor[
             0.23097102128167676`, 0.36009556614857785`, 0.9364648300197617]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.08365695714524007], {
             RGBColor[
             0.3346936329980411, 0.4643165355369484, 0.9425473602300443]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.08365695714524007], {
             RGBColor[
             0.4139123913479283, 0.5329318423690543, 0.9475951094617016]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.08365695714524007], {
             RGBColor[
             0.9806438628879008, 0.9850848051513379, 0.9176490706284157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.08365695714524007], {
             RGBColor[
             0.636260505893553, 0.7155839677503577, 0.9645079042044205]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.08365695714524007], {
             RGBColor[
             0.891880473315157, 0.9166252962437273, 0.9895495498075391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.08365695714524007], {
             RGBColor[
             0.5374504029812882, 0.6353654748617721, 0.9567292109498338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.08365695714524007], {
             RGBColor[
             0.8236368059668002, 0.8622096483251499, 0.9830404078940118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.08365695714524007], {
             RGBColor[
             0.4468849929556433, 0.5614910526305136, 0.9496960944796183]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.08365695714524007], {
             RGBColor[
             0.8113318953863587, 0.8525379101173929, 0.9818296390706268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.08365695714524007], {
             RGBColor[
             0.9938734648833422, 0.9917345345315606, 0.7511960720550537]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.08365695714524007], {
             RGBColor[
             0.7696466012307213, 0.8199730415030392, 0.9776748385204148]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.08365695714524007], {
             RGBColor[
             0.8516855450977857, 0.8845749515454564, 0.9857157216717302]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.08365695714524007], {
             RGBColor[
             0.9905212757217349, 0.9903483181659041, 0.8067505216503474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.08365695714524007], {
             RGBColor[
             0.4997593580729464, 0.604766186642957, 0.9537620338278023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.08365695714524007], {
             RGBColor[
             0.8984159681645738, 0.9218365224353705, 0.9901729111405816]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.08365695714524007], {
             RGBColor[
             0.7600050369742497, 0.8124409782272812, 0.9767138575008705]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.08365695714524007], {
             RGBColor[
             0.39993753875505117`, 0.5208275274496186, 0.9467046442119603]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.08365695714524007], {
             RGBColor[
             0.983978667061875, 0.9875718966440471, 0.9120041170181041]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.08365695714524007], {
             RGBColor[
             0.5016727246617888, 0.6063195438359618, 0.9539126610545688]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.08365695714524007], {
             RGBColor[
             0.9563307771411884, 0.9669521456104638, 0.9588047829292559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.08365695714524007], {
             RGBColor[
             0.8287781184934042, 0.8663091913766531, 0.9835307908725032]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.08365695714524007], {
             RGBColor[
             0.8777048502505482, 0.9053220391990459, 0.9881974662249086]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.08365695714524007], {
             RGBColor[
             0.3356847870356098, 0.46517502334743993`, 0.942610515688875]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.08365695714524007], {
             RGBColor[
             0.2605527064718213, 0.39118779287058963`, 0.9381494632291589]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.08365695714524007], {
             RGBColor[
             0.30914521777139464`, 0.44218778236831346`, 0.9409194378033788]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.08365695714524007], {
             RGBColor[
             0.34037965812686666`, 0.46924148471560445`, 0.9429096687232984]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.08365695714524007], {
             RGBColor[
             0.527839280149159, 0.6275627323705002, 0.9559725881537856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.08365695714524007], {
             RGBColor[
             0.9724314052584062, 0.9789599676979259, 0.931550619243158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.08365695714524007], {
             RGBColor[
             0.98790263146823, 0.9892654414709922, 0.8501482337650147]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.08365695714524007], {
             RGBColor[
             0.9735299862209987, 0.9797792875810661, 0.9296910082292928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.08365695714524007], {
             RGBColor[
             0.8388863950563799, 0.874369256726112, 0.9844949273148448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.08365695714524007], {
             RGBColor[
             0.3171459162805264, 0.44911758529012397`, 0.9414292352376409]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.08365695714524007], {
             RGBColor[
             0.7440257259943249, 0.7999578190425025, 0.9751211891175428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.08365695714524007], {
             RGBColor[
             0.9905212757217349, 0.9903483181659041, 0.8067505216503474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.08365695714524007], {
             RGBColor[
             0.481010020498159, 0.5895446297517124, 0.9522860172928286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.08365695714524007], {
             RGBColor[
             0.2917145277944493, 0.42394084285425876`, 0.9399240828536991]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.08365695714524007], {
             RGBColor[
             0.29934322486174525`, 0.4319590871593173, 0.9403585258660356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.08365695714524007], {
             RGBColor[
             0.9502964108528236, 0.9624517251129693, 0.969019391040668]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.08365695714524007], {
             RGBColor[
             0.49339468062756114`, 0.5995990547673418, 0.95326098310472]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.08365695714524007], {
             RGBColor[
             0.3209662928452309, 0.4524266034527617, 0.9416726662541175]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.08365695714524007], {
             RGBColor[
             0.7695124914111247, 0.8198682738926979, 0.977661471706925]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.08365695714524007], {
             RGBColor[
             0.9386600968036779, 0.9537733811478321, 0.9887166354891075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.08365695714524007], {
             RGBColor[
             0.3814119601866579, 0.5047816024163289, 0.9455242107271082]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.08365695714524007], {
             RGBColor[
             0.45398801898134383`, 0.5676069515930661, 0.9501587463485718]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.08365695714524007], {
             RGBColor[
             0.915463655377631, 0.9354298854719203, 0.991798934765613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.08365695714524007], {
             RGBColor[
             0.3603506624129685, 0.4865393648563645, 0.9441822034567431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.08365695714524007], {
             RGBColor[
             0.45211185410589927`, 0.5660182970491853, 0.9500291454501808]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.08365695714524007], {
             RGBColor[
             0.5156685864717887, 0.6176820149597091, 0.9550144665647831]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.08365695714524007], {
             RGBColor[
             0.26485173841013293`, 0.3957063480121231, 0.9383942867381979]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.08365695714524007], {
             RGBColor[
             0.9783063516825027, 0.9833414931216752, 0.9216058673785923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.08365695714524007], {
             RGBColor[
             0.37361950045729575`, 0.49803216545916934`, 0.9450276820837549]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.08365695714524007], {
             RGBColor[
             0.48223016533400587`, 0.5905351982963514, 0.9523820715638442]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.08365695714524007], {
             RGBColor[
             0.5103414821002014, 0.6133572316475373, 0.9545950973948254]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.08365695714524007], {
             RGBColor[
             0.4127163034491305, 0.5318958511482414, 0.9475188957984492]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.08365695714524007], {
             RGBColor[
             0.6608173126798839, 0.7349547741538975, 0.9668277521051916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.08365695714524007], {
             RGBColor[
             0.43026413199661856`, 0.5470948982565682, 0.9486370279165596]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.08365695714524007], {
             RGBColor[
             0.4920932723657055, 0.5985425129125933, 0.9531585314791311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.08365695714524007], {
             RGBColor[
             0.5173493330781562, 0.6190465207715299, 0.955146781094414]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.08365695714524007], {
             RGBColor[
             0.5538873250988838, 0.6487097087117393, 0.9580231856693605]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.08365695714524007], {
             RGBColor[
             0.607010179325485, 0.6918372349302048, 0.9622052113495054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.08365695714524007], {
             RGBColor[
             0.32965910947565835`, 0.45995588430437023`, 0.9422265648430523]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.08365695714524007], {
             RGBColor[
             0.3474203984698523, 0.4753398201227995, 0.9433582984720712]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.08365695714524007], {
             RGBColor[
             0.41330866319908544`, 0.5324089233907857, 0.9475566404379131]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.08365695714524007], {
             RGBColor[
             0.5638600416535128, 0.656806009276548, 0.9588082744478054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.08365695714524007], {
             RGBColor[
             0.6827652044617455, 0.7521006340240435, 0.9690153128432976]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.08365695714524007], {
             RGBColor[
             0.6030922879135403, 0.6886565141829913, 0.961896780585848]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.08365695714524007], {
             RGBColor[
             0.8521520355164879, 0.8849469183427844, 0.985760215944307]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.08365695714524007], {
             RGBColor[
             0.363910944563193, 0.489623102309905, 0.9444090614871216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.08365695714524007], {
             RGBColor[
             0.9381949005489294, 0.9534264385427295, 0.9895040914057819]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.08365695714524007], {
             RGBColor[
             0.4995359689171475, 0.6045848292627126, 0.9537444478151564]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.08365695714524007], {
             RGBColor[
             0.5964526743325769, 0.683266176766782, 0.9613740858830486]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.08365695714524007], {
             RGBColor[
             0.48077337255033875`, 0.5893525082868033, 0.9522673874995061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.08365695714524007], {
             RGBColor[
             0.9921114581537765, 0.9910058994673778, 0.780397083491199]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.08365695714524007], {
             RGBColor[
             0.9811484641488905, 0.9854611359455752, 0.9167949123146469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.08365695714524007], {
             RGBColor[
             0.40167871346082984`, 0.5223356454657788, 0.9468155903245522]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.08365695714524007], {
             RGBColor[
             0.3360849100948258, 0.46552158983056313`, 0.9426360111763933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.08365695714524007], {
             RGBColor[
             0.30718223579510057`, 0.44019838467227357`, 0.9408049459419128]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.08365695714524007], {
             RGBColor[
             0.3925733138290561, 0.5144490059554286, 0.9462354023116044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.08365695714524007], {
             RGBColor[
             0.23724016108490803`, 0.3666848295681952, 0.9368218482571945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.08365695714524007], {
             RGBColor[
             0.7612233041077471, 0.8133926977711425, 0.9768352829833838]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.08365695714524007], {
             RGBColor[
             0.7318727032369162, 0.790463785298021, 0.973909889385539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.08365695714524007], {
             RGBColor[
             0.3966379198751523, 0.5179695634195173, 0.9464943954146716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.08365695714524007], {
             RGBColor[
             0.7743173598414085, 0.8236218736287882, 0.9781403760880073]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.08365695714524007], {
             RGBColor[
             0.7131500125352707, 0.7758374770241758, 0.9720437865498912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.08365695714524007], {
             RGBColor[
             0.26485173841013293`, 0.3957063480121231, 0.9383942867381979]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.08365695714524007], {
             RGBColor[
             0.9388024223413743, 0.9538795273008093, 0.9884757154782328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.08365695714524007], {
             RGBColor[
             0.6987438947724003, 0.7645833083372713, 0.970607919364113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.08365695714524007], {
             RGBColor[
             0.533265715283611, 0.6319681568707654, 0.9563997770052565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.08365695714524007], {
             RGBColor[
             0.28343911087011414`, 0.41524285497504476`, 0.9394528101022405]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.08365695714524007], {
             RGBColor[
             0.9268608255577616, 0.9445176796056134, 0.9928860070317678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.08365695714524007], {
             RGBColor[
             0.9690739329912338, 0.976455970378425, 0.9372339440224688]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.08365695714524007], {
             RGBColor[
             0.35081188514080275`, 0.47827735541610034`, 0.9435744010037703]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.08365695714524007], {
             RGBColor[
             0.7517569547789473, 0.8059975137285647, 0.9758917657503532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.08365695714524007], {
             RGBColor[
             0.6094577206822531, 0.6938242592641107, 0.9623978907707497]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.08365695714524007], {
             RGBColor[
             0.30777033438660084`, 0.44081651357954466`, 0.9408384372866848]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.08365695714524007], {
             RGBColor[
             0.2879912923145869, 0.4200274862981594, 0.9397120501011542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.08365695714524007], {
             RGBColor[
             0.703816618846083, 0.7685461589377631, 0.971113521092476]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.08365695714524007], {
             RGBColor[
             0.982747971868179, 0.986654046183667, 0.9140873629643176]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.08365695714524007], {
             RGBColor[
             0.9844245209809648, 0.9878271534011457, 0.9077895256004032]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.08365695714524007], {
             RGBColor[
             0.3609905861037574, 0.48709363459382593`, 0.9442229788284578]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.08365695714524007], {
             RGBColor[
             0.38280416597973277`, 0.5059874610999925, 0.9456129208491637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.08365695714524007], {
             RGBColor[
             0.9717914475874568, 0.9784826883147664, 0.932633900652383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.08365695714524007], {
             RGBColor[
             0.3972849158131125, 0.5185299587820169, 0.9465356214237224]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.08365695714524007], {
             RGBColor[
             0.37903187068947947`, 0.5027200885206493, 0.9453725535289785]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.08365695714524007], {
             RGBColor[
             0.38376757254809946`, 0.5068219154472897, 0.9456743082637931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.08365695714524007], {
             RGBColor[
             0.9612158239104579, 0.970595405492455, 0.9505356729731331]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.08365695714524007], {
             RGBColor[
             0.748835707994338, 0.8037154135381299, 0.9756006031714666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.08365695714524007], {
             RGBColor[
             0.426263460746706, 0.5436297178994776, 0.9483821086821699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.08365695714524007], {
             RGBColor[
             0.9346541014160673, 0.778632317884221, 0.2662793600152321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.08365695714524007], {
             RGBColor[
             0.9684789353960427, 0.9760122221461506, 0.9382411197509009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.08365695714524007], {
             RGBColor[
             0.962442739426261, 0.9715104370752512, 0.9484588250356945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.08365695714524007], {
             RGBColor[
             0.3036134813252871, 0.43644739745239736`, 0.940601710654356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.08365695714524007], {
             RGBColor[
             0.6153606818862422, 0.6986165490948808, 0.962862593499987]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.08365695714524007], {
             RGBColor[
             0.5557017621196535, 0.6501827504246563, 0.9581660247981373]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.08365695714524007], {
             RGBColor[
             0.4538712998239103, 0.5675121937229234, 0.9501495577889423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.08365695714524007], {
             RGBColor[
             0.8113318953863587, 0.8525379101173929, 0.9818296390706268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.08365695714524007], {
             RGBColor[
             0.6407959281869726, 0.7192660278866017, 0.9648649492611577]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.08365695714524007], {
             RGBColor[
             0.505318275785469, 0.6092791664683719, 0.9541996521931186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.08365695714524007], {
             RGBColor[
             0.9944248099391124, 0.9919625298810433, 0.742058857645675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.08365695714524007], {
             RGBColor[
             0.8947384845209787, 0.918904196800602, 0.9898221494677271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.08365695714524007], {
             RGBColor[
             0.3762092216567136, 0.500275251798933, 0.9451926968285812]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.08365695714524007], {
             RGBColor[
             0.5852752547444637, 0.6741918440081376, 0.9604941584688353]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.08365695714524007], {
             RGBColor[
             0.9811500115187282, 0.9480767040442091, 0.3812717835822381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.08365695714524007], {
             RGBColor[
             0.43740062302199156`, 0.5532761680922779, 0.9490917588141451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.08365695714524007], {
             RGBColor[
             0.6609098513616718, 0.7350270660754302, 0.9668369754961691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.08365695714524007], {
             RGBColor[
             0.39620858785227886`, 0.5175976976001592, 0.9464670387578176]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.08365695714524007], {
             RGBColor[
             0.9435626403360163, 0.9574296900870717, 0.9804179080769958]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.08365695714524007], {
             RGBColor[
             0.48676812785546864`, 0.5942193207041566, 0.9527393165966382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.08365695714524007], {
             RGBColor[
             0.9909474125492821, 0.9905245366953118, 0.7996883316111316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.08365695714524007], {
             RGBColor[
             0.5953425713110758, 0.6823649451243563, 0.9612866945067547]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.08365695714524007], {
             RGBColor[
             0.9855787053254775, 0.9630157281611305, 0.39847642273280937`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.08365695714524007], {
             RGBColor[
             0.46216549572163107`, 0.5742457956019602, 0.9508025072726515]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN3AuYzmXewPH7z7a1WxZbu0o1DqFsy5TT0CKyGGKYrMNM4zSN46CIkAnD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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[37, 104] -> 
             RGBColor[
              0.2541903466574486, 0.3845005493087726, 0.9377871362499982], 
             UndirectedEdge[119, 243] -> 
             RGBColor[
              0.23559188807996673`, 0.3649523901334573, 0.9367279815479644], 
             UndirectedEdge[165, 226] -> 
             RGBColor[
              0.20872258864357046`, 0.33671105281382463`, 0.935197814694628], 
             UndirectedEdge[235, 261] -> 
             RGBColor[
              0.19122633777104836`, 0.31832138382042696`, 0.9342014290908216],
              UndirectedEdge[56, 198] -> 
             RGBColor[
              0.6735978276393025, 0.7431113232752183, 0.969380994432274], 
             UndirectedEdge[50, 254] -> 
             RGBColor[
              0.20910270252497706`, 0.33711057660379506`, 0.9352194616178461],
              UndirectedEdge[249, 268] -> 
             RGBColor[
              0.18564105657677243`, 0.3124508991579618, 0.9338833555894905], 
             UndirectedEdge[38, 224] -> 
             RGBColor[
              0.37823665311305865`, 0.49620023139778335`, 0.9458245390097163],
              UndirectedEdge[79, 87] -> 
             RGBColor[
              0.19294989757058154`, 0.3201329544497393, 0.9342995832716268], 
             UndirectedEdge[38, 311] -> 
             RGBColor[
              0.23066096804752526`, 0.35976968054097413`, 0.9364471729467594],
              UndirectedEdge[37, 145] -> 
             RGBColor[
              0.2671022972631469, 0.3980718280603137, 0.9385224527354736], 
             UndirectedEdge[147, 359] -> 
             RGBColor[
              0.28645237167494564`, 0.4168434263248926, 0.9396817701660576], 
             UndirectedEdge[192, 349] -> 
             RGBColor[
              0.22834058438598487`, 0.3573308101918738, 0.9363150305299347], 
             UndirectedEdge[213, 308] -> 
             RGBColor[
              0.2691305631056292, 0.398662652595457, 0.9386943834532097], 
             UndirectedEdge[262, 397] -> 
             RGBColor[
              0.364256395049981, 0.48992231415871446`, 0.9444310732866698], 
             UndirectedEdge[129, 364] -> 
             RGBColor[
              0.8533368890895888, 0.341701118375767, 0.1959548205416618], 
             UndirectedEdge[54, 83] -> 
             RGBColor[
              0.9496193654049732, 0.8977579075232218, 0.6225379522867944], 
             UndirectedEdge[13, 277] -> 
             RGBColor[
              0.19923872667069553`, 0.3267429125687539, 0.9346577227853893], 
             UndirectedEdge[191, 235] -> 
             RGBColor[
              0.18862912627732129`, 0.3155915498678, 0.9340535217384839], 
             UndirectedEdge[54, 214] -> 
             RGBColor[
              0.913587591361185, 0.6878213464055395, 0.24895168467498954`], 
             UndirectedEdge[87, 176] -> 
             RGBColor[
              0.18652655830038561`, 0.3133816176135313, 0.933933783602668], 
             UndirectedEdge[16, 377] -> 
             RGBColor[
              0.24182389785616784`, 0.37150262754048624`, 0.9370828852852868],
              UndirectedEdge[158, 344] -> 
             RGBColor[
              0.19135142545084088`, 0.31845285890290587`, 0.934208552649135], 
             UndirectedEdge[95, 228] -> 
             RGBColor[
              0.2356195787974104, 0.36498149483318354`, 0.9367295584933581], 
             UndirectedEdge[193, 283] -> 
             RGBColor[
              0.884925338733304, 0.8207038820590313, 0.6242425057097936], 
             UndirectedEdge[11, 366] -> 
             RGBColor[
              0.9332464444239088, 0.9449010522417576, 0.749948999978632], 
             UndirectedEdge[106, 231] -> 
             RGBColor[
              0.1888628748467801, 0.31583723443481654`, 0.9340668333737145], 
             UndirectedEdge[76, 388] -> 
             RGBColor[
              0.276858244918402, 0.40832594760879465`, 0.9390780395218092], 
             UndirectedEdge[208, 351] -> 
             RGBColor[
              0.301986411916915, 0.43466246314501933`, 0.9405117895645303], 
             UndirectedEdge[208, 225] -> 
             RGBColor[
              0.2514500268910438, 0.38162029948797277`, 0.9376310790932412], 
             UndirectedEdge[163, 374] -> 
             RGBColor[
              0.1813453905655848, 0.3079358818192477, 0.9336387237650219], 
             UndirectedEdge[165, 288] -> 
             RGBColor[
              0.2196372553710177, 0.3481830595742119, 0.9358193888179538], 
             UndirectedEdge[110, 239] -> 
             RGBColor[
              0.6800499902731076, 0.7481746185632971, 0.9700901941191247], 
             UndirectedEdge[14, 273] -> 
             RGBColor[
              0.4313475935937616, 0.5461129107315478, 0.9492366849727629], 
             UndirectedEdge[231, 372] -> 
             RGBColor[
              0.18557674124721385`, 0.3123832996687683, 0.9338796929266182], 
             UndirectedEdge[5, 162] -> 
             RGBColor[
              0.19105730741779076`, 0.3181437222020098, 0.9341918030622616], 
             UndirectedEdge[36, 90] -> 
             RGBColor[
              0.2306114538784999, 0.35971763800994894`, 0.9364443531880831], 
             UndirectedEdge[258, 328] -> 
             RGBColor[
              0.23450213577855084`, 0.36380699137038264`, 0.936665921766543], 
             UndirectedEdge[91, 208] -> 
             RGBColor[
              0.4434969579662055, 0.5534506067219376, 0.9505734674176423], 
             UndirectedEdge[155, 370] -> 
             RGBColor[
              0.18572317816153708`, 0.3125372141503586, 0.9338880322922549], 
             UndirectedEdge[66, 243] -> 
             RGBColor[
              0.21376058132167255`, 0.342006302545695, 0.9354847209246038], 
             UndirectedEdge[253, 334] -> 
             RGBColor[
              0.8701987937776897, 0.4222457469371983, 0.21448170260215638`], 
             UndirectedEdge[50, 210] -> 
             RGBColor[
              0.23840421569943582`, 0.3679083247733892, 0.9368881394454274], 
             UndirectedEdge[239, 365] -> 
             RGBColor[
              0.4065771465503478, 0.524864785093759, 0.9475407198960643], 
             UndirectedEdge[13, 51] -> 
             RGBColor[
              0.20728585719020337`, 0.33520095696230034`, 0.9351159949638125],
              UndirectedEdge[258, 300] -> 
             RGBColor[
              0.21690681128224154`, 0.345313189716754, 0.9356638940664279], 
             UndirectedEdge[30, 294] -> 
             RGBColor[
              0.2052159577699056, 0.3330253614323641, 0.9349981172539683], 
             UndirectedEdge[31, 292] -> 
             RGBColor[
              0.8744140526456051, 0.4298053132859735, 0.4143800934465462], 
             UndirectedEdge[203, 216] -> 
             RGBColor[
              0.26291297700315486`, 0.3935517624584167, 0.938288154657422], 
             UndirectedEdge[64, 233] -> 
             RGBColor[
              0.9814581324353071, 0.9819712119725741, 0.6847171998056071], 
             UndirectedEdge[50, 242] -> 
             RGBColor[
              0.2857631387189643, 0.41475906038865373`, 0.9396923133754758], 
             UndirectedEdge[133, 398] -> 
             RGBColor[
              0.18210607446438823`, 0.30873540882703493`, 0.9336820435877278],
              UndirectedEdge[7, 390] -> 
             RGBColor[
              0.23396569650741295`, 0.36324315968420245`, 0.9366353723436424],
              UndirectedEdge[186, 342] -> 
             RGBColor[
              0.19648760861210862`, 0.32385131305821946`, 0.9345010506818672],
              UndirectedEdge[347, 398] -> 
             RGBColor[
              0.182565782601332, 0.30921859122614215`, 0.9337082232860494], 
             UndirectedEdge[321, 375] -> 
             RGBColor[
              0.19367454863692518`, 0.3208946086659977, 0.9343408510778299], 
             UndirectedEdge[149, 279] -> 
             RGBColor[
              0.20468155953700706`, 0.33246367500678287`, 0.9349676840651762],
              UndirectedEdge[38, 306] -> 
             RGBColor[
              0.24051285588611682`, 0.3701246393051007, 0.9370082233846052], 
             UndirectedEdge[12, 358] -> 
             RGBColor[
              0.26019129073322267`, 0.39080792201424114`, 0.9381288811375124],
              UndirectedEdge[139, 378] -> 
             RGBColor[
              0.27359029407982893`, 0.40489112407740385`, 0.9388919345560525],
              UndirectedEdge[272, 374] -> 
             RGBColor[
              0.19014395523747457`, 0.3171837311506246, 0.934139789006776], 
             UndirectedEdge[21, 114] -> 
             RGBColor[
              0.19167285067202883`, 0.3187906971899105, 0.9342268573399758], 
             UndirectedEdge[250, 321] -> 
             RGBColor[
              0.18913677562513462`, 0.3161251215191795, 0.934082431617842], 
             UndirectedEdge[19, 152] -> 
             RGBColor[
              0.2001783639532218, 0.3277305309291337, 0.9347112337385604], 
             UndirectedEdge[270, 336] -> 
             RGBColor[
              0.2213730230293102, 0.3500074614371033, 0.9359182382182554], 
             UndirectedEdge[87, 277] -> 
             RGBColor[
              0.18598156789951187`, 0.3128087981478258, 0.9339027472055792], 
             UndirectedEdge[37, 377] -> 
             RGBColor[
              0.2695128080367538, 0.400605427718585, 0.9386597277579993], 
             UndirectedEdge[312, 356] -> 
             RGBColor[
              0.746600049419986, 0.8012844499471021, 0.9674404180913663], 
             UndirectedEdge[294, 343] -> 
             RGBColor[
              0.20522639813651683`, 0.33303633491963003`, 0.9349987118174017],
              UndirectedEdge[170, 349] -> 
             RGBColor[
              0.21695935367547547`, 0.34536841510342303`, 0.9356668862779931],
              UndirectedEdge[176, 390] -> 
             RGBColor[
              0.199593709897452, 0.3271160224473115, 0.9346779385550025], 
             UndirectedEdge[235, 327] -> 
             RGBColor[
              0.1895062149755763, 0.31651342570030144`, 0.934103470642313], 
             UndirectedEdge[271, 400] -> 
             RGBColor[
              0.8207069079646563, 0.1601679452070842, 0.16746226449304957`], 
             UndirectedEdge[45, 103] -> 
             RGBColor[
              0.21725551419299843`, 0.345679698585001, 0.9356837521813359], 
             UndirectedEdge[30, 343] -> 
             RGBColor[
              0.2007094287814945, 0.32828871373510315`, 0.9347414770948905], 
             UndirectedEdge[200, 234] -> 
             RGBColor[
              0.22049169370930496`, 0.34908112844227146`, 0.9358680478172909],
              UndirectedEdge[282, 382] -> 
             RGBColor[
              0.3185597546508585, 0.45034218102492296`, 0.9415193237683902], 
             UndirectedEdge[305, 382] -> 
             RGBColor[
              0.31007770460075973`, 0.44200741025601153`, 0.9410150322193817],
              UndirectedEdge[50, 164] -> 
             RGBColor[
              0.22306024288786463`, 0.3517808364843617, 0.9360143228931819], 
             UndirectedEdge[259, 287] -> 
             RGBColor[
              0.8433542070105785, 0.39590176780986674`, 0.4394411979268815], 
             UndirectedEdge[90, 95] -> 
             RGBColor[
              0.23140010342565426`, 0.3605465586872775, 0.936489265613091], 
             UndirectedEdge[44, 243] -> 
             RGBColor[
              0.2298536898894718, 0.3589211800124685, 0.9364011996499193], 
             UndirectedEdge[82, 194] -> 
             RGBColor[
              0.6075992658363466, 0.6905170696190597, 0.963481170694517], 
             UndirectedEdge[124, 150] -> 
             RGBColor[
              0.2325126629936997, 0.36171592933364405`, 0.9365526242346068], 
             UndirectedEdge[233, 316] -> 
             RGBColor[
              0.8412361363066468, 0.8762214650435611, 0.9535246374949702], 
             UndirectedEdge[87, 390] -> 
             RGBColor[
              0.19991574882843044`, 0.32745450578221735`, 0.9346962781957078],
              UndirectedEdge[72, 376] -> 
             RGBColor[
              0.3758578545249899, 0.4975526740121381, 0.9453383722532241], 
             UndirectedEdge[99, 169] -> 
             RGBColor[
              0.6797124063510102, 0.7475445119943138, 0.9704734146298177], 
             UndirectedEdge[127, 137] -> 
             RGBColor[
              0.31600670483300364`, 0.4466421785419929, 0.9414111535240912], 
             UndirectedEdge[68, 391] -> 
             RGBColor[
              0.8206909281236954, 0.3912194139027702, 0.4389552580327404], 
             UndirectedEdge[292, 309] -> 
             RGBColor[
              0.778783487932468, 0.35505497183403256`, 0.43435605547208284`], 
             UndirectedEdge[88, 140] -> 
             RGBColor[
              0.41837127081473313`, 0.5367938996534025, 0.947879225318494], 
             UndirectedEdge[153, 216] -> 
             RGBColor[
              0.21073387590110806`, 0.33882504324447416`, 0.935312354528512], 
             UndirectedEdge[145, 165] -> 
             RGBColor[
              0.23770682741222313`, 0.3671753254665574, 0.9368484242141641], 
             UndirectedEdge[37, 76] -> 
             RGBColor[
              0.28363325287465024`, 0.4154469105311262, 0.9394638662021915], 
             UndirectedEdge[6, 391] -> 
             RGBColor[
              0.8555439090552986, 0.41901023483866595`, 0.44227956646762], 
             UndirectedEdge[203, 206] -> 
             RGBColor[
              0.36944897924090714`, 0.4944198695980247, 0.9447619401596937], 
             UndirectedEdge[298, 320] -> 
             RGBColor[
              0.19458686072830475`, 0.3218535065179652, 0.9343928059017892], 
             UndirectedEdge[39, 164] -> 
             RGBColor[
              0.20658345954088297`, 0.3344626924982814, 0.9350759944567879], 
             UndirectedEdge[107, 156] -> 
             RGBColor[
              0.2124764155335251, 0.34065656288153834`, 0.9354115895827217], 
             UndirectedEdge[31, 222] -> 
             RGBColor[
              0.967672940132394, 0.9754000826172251, 0.9391115323234271], 
             UndirectedEdge[301, 329] -> 
             RGBColor[
              0.25610352101831557`, 0.38651141686430435`, 0.9378960886995618],
              UndirectedEdge[126, 320] -> 
             RGBColor[
              0.18313368370358218`, 0.3098154912916167, 0.9337405644136882], 
             UndirectedEdge[49, 191] -> 
             RGBColor[
              0.18385357890938503`, 0.3105721467969078, 0.933781561380669], 
             UndirectedEdge[122, 173] -> 
             RGBColor[
              0.18447873947082444`, 0.3112292301844495, 0.9338171633498009], 
             UndirectedEdge[60, 102] -> 
             RGBColor[
              0.5280292771941157, 0.6238948638185677, 0.9574471733011694], 
             UndirectedEdge[120, 380] -> 
             RGBColor[
              0.5664649447415552, 0.6566185624069654, 0.9601363872621158], 
             UndirectedEdge[110, 247] -> 
             RGBColor[
              0.8292133862002847, 0.38471694368869236`, 0.43810378344252143`],
              UndirectedEdge[59, 149] -> 
             RGBColor[
              0.21329928840113216`, 0.34152145443854653`, 0.9354584509752006],
              UndirectedEdge[92, 346] -> 
             RGBColor[
              0.2038983093069455, 0.33164042935405524`, 0.934923079123289], 
             UndirectedEdge[6, 142] -> 
             RGBColor[
              0.7001614603741532, 0.763972329138221, 0.9722831025823769], 
             UndirectedEdge[176, 232] -> 
             RGBColor[
              0.18828223277850703`, 0.3152269428062281, 0.9340337666669094], 
             UndirectedEdge[60, 345] -> 
             RGBColor[
              0.7675537628448912, 0.8184035673483785, 0.9774488709937861], 
             UndirectedEdge[79, 126] -> 
             RGBColor[
              0.19080527822884924`, 0.31787882354485875`, 0.9341774503727951],
              UndirectedEdge[14, 212] -> 
             RGBColor[
              0.45821441723172895`, 0.5679246084974616, 0.9513517397459614], 
             UndirectedEdge[22, 338] -> 
             RGBColor[
              0.2260845393342366, 0.35495956380096844`, 0.9361865521017572], 
             UndirectedEdge[195, 389] -> 
             RGBColor[
              0.7088707754207897, 0.764952224756877, 0.7205833028362763], 
             UndirectedEdge[14, 293] -> 
             RGBColor[
              0.32638953387049785`, 0.45712394224882835`, 0.9420182303766638],
              UndirectedEdge[201, 394] -> 
             RGBColor[
              0.5116695891716139, 0.6114793927942537, 0.9556621742335425], 
             UndirectedEdge[20, 189] -> 
             RGBColor[
              0.30889970680782364`, 0.4349879582915822, 0.9411596287595527], 
             UndirectedEdge[195, 359] -> 
             RGBColor[
              0.375153965132881, 0.49936124163672424`, 0.9451254568160093], 
             UndirectedEdge[222, 224] -> 
             RGBColor[
              0.724417520241849, 0.7830873105778803, 0.9606419773233753], 
             UndirectedEdge[54, 389] -> 
             RGBColor[
              0.9706885388162402, 0.9101251515870772, 0.3850556620267193], 
             UndirectedEdge[123, 366] -> 
             RGBColor[
              0.8932052278936042, 0.5511829000640883, 0.29668448216333426`], 
             UndirectedEdge[120, 263] -> 
             RGBColor[
              0.3571898835204337, 0.4831624157488532, 0.9440042071759314], 
             UndirectedEdge[332, 364] -> 
             RGBColor[
              0.8523160600837335, 0.33385457930663953`, 0.1949772735327932], 
             UndirectedEdge[70, 228] -> 
             RGBColor[
              0.21048617188066365`, 0.3385646906136451, 0.9352982481509928], 
             UndirectedEdge[74, 141] -> 
             RGBColor[
              0.3021503369999872, 0.43056214369424695`, 0.9406775662244785], 
             UndirectedEdge[212, 385] -> 
             RGBColor[
              0.7860985506073723, 0.8292872838004639, 0.7968353358505167], 
             UndirectedEdge[256, 384] -> 
             RGBColor[
              0.9629443447193516, 0.8827390749129462, 0.5213129511813582], 
             UndirectedEdge[158, 317] -> 
             RGBColor[
              0.18982224071375664`, 0.31684558878831803`, 0.9341214678405843],
              UndirectedEdge[76, 208] -> 
             RGBColor[
              0.28867650153937047`, 0.420747684638181, 0.9397510717528295], 
             UndirectedEdge[101, 253] -> 
             RGBColor[
              0.8443799630600709, 0.34212942026933035`, 0.1901316087873103], 
             UndirectedEdge[111, 309] -> 
             RGBColor[
              0.7835302879454197, 0.39154095679460776`, 0.43890159652522914`],
              UndirectedEdge[145, 170] -> 
             RGBColor[
              0.24268853638713495`, 0.37241141745778183`, 0.9371321251705074],
              UndirectedEdge[59, 279] -> 
             RGBColor[
              0.2076546436516325, 0.3355885749156745, 0.9351369968072203], 
             UndirectedEdge[83, 334] -> 
             RGBColor[
              0.9555982588691752, 0.9202058525384339, 0.6338919338224923], 
             UndirectedEdge[242, 312] -> 
             RGBColor[
              0.4441075478761082, 0.5565195124327971, 0.9502280720328274], 
             UndirectedEdge[140, 356] -> 
             RGBColor[
              0.6758651089866358, 0.7425832566534856, 0.9622242963377263], 
             UndirectedEdge[172, 316] -> 
             RGBColor[
              0.5458822960971526, 0.6391409074229324, 0.9586767421820886], 
             UndirectedEdge[217, 331] -> 
             RGBColor[
              0.22460790707912992`, 0.3534075296769589, 0.9361024600793104], 
             UndirectedEdge[263, 336] -> 
             RGBColor[
              0.2683165494931898, 0.3993480841421268, 0.9385916026036494], 
             UndirectedEdge[122, 338] -> 
             RGBColor[
              0.19975108063826336`, 0.32728142907378543`, 0.9346869005858826],
              UndirectedEdge[303, 400] -> 
             RGBColor[
              0.8460534982430635, 0.31774288769115266`, 0.1902755691417824], 
             UndirectedEdge[133, 367] -> 
             RGBColor[
              0.18474901765317286`, 0.31151330969072427`, 0.9338325552924449],
              UndirectedEdge[136, 279] -> 
             RGBColor[
              0.19083656061449622`, 0.3179117033155916, 0.9341792318583795], 
             UndirectedEdge[117, 365] -> 
             RGBColor[
              0.4322742926857367, 0.5457268859697086, 0.94956369337159], 
             UndirectedEdge[33, 245] -> 
             RGBColor[
              0.22074175679161856`, 0.34934396059669826`, 0.9358822885398935],
              UndirectedEdge[162, 368] -> 
             RGBColor[
              0.18956500601498782`, 0.31657521881029016`, 0.934106818705034], 
             UndirectedEdge[46, 128] -> 
             RGBColor[
              0.5547192055800235, 0.6423805327309791, 0.9609350717272003], 
             UndirectedEdge[117, 269] -> 
             RGBColor[
              0.45596747114210545`, 0.5665010427125681, 0.9510641632117192], 
             UndirectedEdge[98, 134] -> 
             RGBColor[
              0.1861818864522268, 0.313019345647659, 0.9339141550508117], 
             UndirectedEdge[90, 326] -> 
             RGBColor[
              0.22857029923452804`, 0.35757225506245527`, 0.9363281124507266],
              UndirectedEdge[119, 306] -> 
             RGBColor[
              0.2310448890646134, 0.36017320587193224`, 0.9364690366807222], 
             UndirectedEdge[150, 211] -> 
             RGBColor[
              0.23544785722092995`, 0.3648010045685258, 0.9367197792036168], 
             UndirectedEdge[388, 395] -> 
             RGBColor[
              0.35473118198517756`, 0.4781619748017699, 0.9439526563033052], 
             UndirectedEdge[102, 108] -> 
             RGBColor[
              0.3276991764172302, 0.45803801914073383`, 0.9421097447928497], 
             UndirectedEdge[15, 392] -> 
             RGBColor[
              0.19259602959164984`, 0.3197610167673564, 0.9342794310137273], 
             UndirectedEdge[32, 292] -> 
             RGBColor[
              0.820843205790226, 0.16121559002050154`, 0.16759278344474157`], 
             UndirectedEdge[115, 332] -> 
             RGBColor[
              0.8635725695202401, 0.3784828882129811, 0.20403452524964213`], 
             UndirectedEdge[93, 293] -> 
             RGBColor[
              0.3283292569566383, 0.4588040328927261, 0.9421418278164828], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.1906510637312114, 0.3177167343300775, 0.9341686680852945], 
             UndirectedEdge[276, 305] -> 
             RGBColor[
              0.33855234976798615`, 0.46667071672258365`, 0.9428294114302973],
              UndirectedEdge[75, 347] -> 
             RGBColor[
              0.18311704522785527`, 0.30979800319868733`, 0.9337396168771099],
              UndirectedEdge[64, 193] -> 
             RGBColor[
              0.9152566921622731, 0.9300770448033753, 0.7093659477350615], 
             UndirectedEdge[18, 99] -> 
             RGBColor[
              0.947350971343756, 0.9556350172112698, 0.7097411277967336], 
             UndirectedEdge[74, 290] -> 
             RGBColor[
              0.2530317916874394, 0.3832828345786652, 0.9377211582583846], 
             UndirectedEdge[39, 230] -> 
             RGBColor[
              0.20964976351428055`, 0.33768557238922303`, 0.9352506159318827],
              UndirectedEdge[259, 345] -> 
             RGBColor[
              0.8617541752858404, 0.8926034039517254, 0.9866760766074392], 
             UndirectedEdge[30, 168] -> 
             RGBColor[
              0.19933167973369648`, 0.3268406121315325, 0.9346630163248155], 
             UndirectedEdge[231, 331] -> 
             RGBColor[
              0.21608777115484973`, 0.34445232661272185`, 0.9356172509428343],
              UndirectedEdge[137, 242] -> 
             RGBColor[
              0.31652160790723577`, 0.4470881617051118, 0.9414439626926704], 
             UndirectedEdge[172, 221] -> 
             RGBColor[
              0.3747675504331488, 0.4990265486455837, 0.9451008348130354], 
             UndirectedEdge[157, 211] -> 
             RGBColor[
              0.23967520555955008`, 0.36924421570178084`, 0.9369605204376998],
              UndirectedEdge[46, 213] -> 
             RGBColor[
              0.5654749182769274, 0.6521444572622102, 0.9616040176321952], 
             UndirectedEdge[184, 318] -> 
             RGBColor[
              0.2135047362690546, 0.34173739317388024`, 0.935470150927346], 
             UndirectedEdge[201, 293] -> 
             RGBColor[
              0.4899219075938762, 0.5926426440818758, 0.9542764311941287], 
             UndirectedEdge[64, 115] -> 
             RGBColor[
              0.973846560757742, 0.9231368127839409, 0.35853265585475147`], 
             UndirectedEdge[174, 266] -> 
             RGBColor[
              0.5380286912692482, 0.6346285303347542, 0.9572070721400225], 
             UndirectedEdge[80, 104] -> 
             RGBColor[
              0.2135778861880246, 0.34181427837669043`, 0.9354743167070156], 
             UndirectedEdge[265, 321] -> 
             RGBColor[
              0.19177497299708612`, 0.31889803422847507`, 0.9342326730553113],
              UndirectedEdge[178, 296] -> 
             RGBColor[
              0.18104204814496305`, 0.30761704970215387`, 0.9336214488629224],
              UndirectedEdge[114, 249] -> 
             RGBColor[
              0.18514988407402466`, 0.3119346457154385, 0.9338553840420838], 
             UndirectedEdge[255, 380] -> 
             RGBColor[
              0.5472854839726642, 0.6400062774766795, 0.9589142889816533], 
             UndirectedEdge[253, 391] -> 
             RGBColor[
              0.8235396690014747, 0.18194178785987172`, 0.17017491966105283`],
              UndirectedEdge[40, 63] -> 
             RGBColor[
              0.19138658757193353`, 0.3184898165215815, 0.9342105550799136], 
             UndirectedEdge[23, 311] -> 
             RGBColor[
              0.2072579319428704, 0.33517160575679045`, 0.9351144046622886], 
             UndirectedEdge[156, 396] -> 
             RGBColor[
              0.19313485512094197`, 0.32032735656215416`, 0.9343101163304997],
              UndirectedEdge[93, 281] -> 
             RGBColor[
              0.3706399848182322, 0.4954514587674228, 0.944837829981916], 
             UndirectedEdge[27, 325] -> 
             RGBColor[
              0.22165235452841858`, 0.35030105655330623`, 0.9359341457338957],
              UndirectedEdge[12, 107] -> 
             RGBColor[
              0.23293330946253646`, 0.362158055442918, 0.9365765794287164], 
             UndirectedEdge[255, 312] -> 
             RGBColor[
              0.46100266352577723`, 0.571153212435337, 0.9513046138622602], 
             UndirectedEdge[257, 310] -> 
             RGBColor[
              0.8741512138365515, 0.46212106330300473`, 0.4275663759812295], 
             UndirectedEdge[50, 197] -> 
             RGBColor[
              0.21121964795225362`, 0.33933562046995513`, 0.9353400185281894],
              UndirectedEdge[215, 350] -> 
             RGBColor[
              0.5273081197953102, 0.6233107010129518, 0.9573840940310441], 
             UndirectedEdge[49, 235] -> 
             RGBColor[
              0.1884735679979762, 0.31542804825324383`, 0.9340446629246031], 
             UndirectedEdge[239, 323] -> 
             RGBColor[
              0.4638795886223883, 0.5747495967298069, 0.9511827422942791], 
             UndirectedEdge[211, 216] -> 
             RGBColor[
              0.22415272438939332`, 0.35292910380979625`, 0.9360765380985124],
              UndirectedEdge[98, 151] -> 
             RGBColor[
              0.20043054064394245`, 0.3279955846200067, 0.934725594828035], 
             UndirectedEdge[10, 32] -> 
             RGBColor[
              0.8358176878937263, 0.2763160213279036, 0.18193236441831204`], 
             UndirectedEdge[330, 367] -> 
             RGBColor[
              0.1873967228823739, 0.314296215760822, 0.9339833381883191], 
             UndirectedEdge[99, 384] -> 
             RGBColor[
              0.9178754148881313, 0.8496097092612407, 0.6279747633092586], 
             UndirectedEdge[127, 138] -> 
             RGBColor[
              0.31413697275722113`, 0.44467697158248487`, 0.9413046750483962],
              UndirectedEdge[292, 385] -> 
             RGBColor[
              0.8778004509205923, 0.4307085290171253, 0.32212137286959003`], 
             UndirectedEdge[177, 219] -> 
             RGBColor[
              0.18016175523476746`, 0.3066918060397442, 0.9335713174839634], 
             UndirectedEdge[170, 322] -> 
             RGBColor[
              0.2153075934140704, 0.3436323103410369, 0.9355728209746665], 
             UndirectedEdge[261, 335] -> 
             RGBColor[
              0.19373393161436922`, 0.3209570239403897, 0.934344232850546], 
             UndirectedEdge[6, 253] -> 
             RGBColor[
              0.858849364854881, 0.44441741657422273`, 0.4454448746742784], 
             UndirectedEdge[95, 246] -> 
             RGBColor[
              0.23196638865379215`, 0.3611417603666076, 0.9365215147190895], 
             UndirectedEdge[50, 331] -> 
             RGBColor[
              0.2360482874744978, 0.36543209483450245`, 0.9367539728183005], 
             UndirectedEdge[9, 358] -> 
             RGBColor[
              0.48197798109692647`, 0.5820052784935108, 0.954246805716025], 
             UndirectedEdge[99, 144] -> 
             RGBColor[
              0.7417116613175341, 0.797878300210745, 0.9753542230915366], 
             UndirectedEdge[2, 28] -> 
             RGBColor[
              0.1967107027357332, 0.32408579912713337`, 0.9345137555621694], 
             UndirectedEdge[138, 258] -> 
             RGBColor[
              0.26327890753170885`, 0.39405320303566205`, 0.9383047163464664],
              UndirectedEdge[144, 384] -> 
             RGBColor[
              0.757420984754537, 0.7226612405223014, 0.6127983851533676], 
             UndirectedEdge[79, 277] -> 
             RGBColor[
              0.19208286823872933`, 0.31922165164912797`, 0.9342502072338328],
              UndirectedEdge[346, 354] -> 
             RGBColor[
              0.1997636988090205, 0.3272946915712895, 0.9346876191720402], 
             UndirectedEdge[144, 148] -> 
             RGBColor[
              0.41890511783186646`, 0.5289568419765102, 0.9490497655266936], 
             UndirectedEdge[38, 346] -> 
             RGBColor[
              0.23107597310122763`, 0.36020587716525554`, 0.9364708068706228],
              UndirectedEdge[38, 363] -> 
             RGBColor[
              0.3166257823122153, 0.444042358182842, 0.9415654261663287], 
             UndirectedEdge[78, 104] -> 
             RGBColor[
              0.22225745398096258`, 0.35093705444345114`, 0.9359686052525535],
              UndirectedEdge[95, 282] -> 
             RGBColor[
              0.2811273621289757, 0.41223265884799526`, 0.9393424107780823], 
             UndirectedEdge[92, 306] -> 
             RGBColor[
              0.21333519209183469`, 0.34155919149390046`, 0.9354604956372714],
              UndirectedEdge[9, 339] -> 
             RGBColor[
              0.5341582021850244, 0.6300810922914106, 0.9574662349562233], 
             UndirectedEdge[36, 148] -> 
             RGBColor[
              0.2511034439451054, 0.38125601883716365`, 0.9376113417071936], 
             UndirectedEdge[62, 395] -> 
             RGBColor[
              0.7152423649203183, 0.772631878073945, 0.8673341109470382], 
             UndirectedEdge[32, 247] -> 
             RGBColor[
              0.820125492552776, 0.15569893157351436`, 0.16690550043801822`], 
             UndirectedEdge[168, 379] -> 
             RGBColor[
              0.190216267574, 0.31725973600117974`, 0.9341439070873645], 
             UndirectedEdge[137, 230] -> 
             RGBColor[
              0.2568850160495337, 0.38733281769176137`, 0.9379405936854713], 
             UndirectedEdge[268, 279] -> 
             RGBColor[
              0.19334852815726622`, 0.3205519404709839, 0.9343222846938173], 
             UndirectedEdge[185, 288] -> 
             RGBColor[
              0.2031417930336449, 0.3308452827849142, 0.93487999664069], 
             UndirectedEdge[233, 310] -> 
             RGBColor[
              0.8744547972846617, 0.4623474753415331, 0.4270524883908231], 
             UndirectedEdge[150, 386] -> 
             RGBColor[
              0.29016677848912364`, 0.4192462598996066, 0.9399482680174902], 
             UndirectedEdge[138, 281] -> 
             RGBColor[
              0.3438282004171828, 0.4703940206570502, 0.9431965738199672], 
             UndirectedEdge[88, 257] -> 
             RGBColor[
              0.6999080745469857, 0.7619616397704058, 0.9426465587738788], 
             UndirectedEdge[27, 40] -> 
             RGBColor[
              0.19924073649984758`, 0.3267450250266232, 0.9346578372421862], 
             UndirectedEdge[159, 250] -> 
             RGBColor[
              0.18793077615893167`, 0.3148575396154177, 0.934013751732358], 
             UndirectedEdge[169, 363] -> 
             RGBColor[
              0.4158922643017966, 0.5345397089893019, 0.947750829584961], 
             UndirectedEdge[144, 382] -> 
             RGBColor[
              0.451676599366216, 0.5621674511867154, 0.9509612465314614], 
             UndirectedEdge[35, 207] -> 
             RGBColor[
              0.19080850531779897`, 0.3178822154199542, 0.9341776341507367], 
             UndirectedEdge[71, 287] -> 
             RGBColor[
              0.8681139584839492, 0.4150599268113716, 0.4215345385839855], 
             UndirectedEdge[148, 361] -> 
             RGBColor[
              0.33306353105933184`, 0.4580790241212378, 0.94262018039587], 
             UndirectedEdge[215, 393] -> 
             RGBColor[
              0.7140213652809209, 0.7765181844116039, 0.9721306348483233], 
             UndirectedEdge[33, 124] -> 
             RGBColor[
              0.23660403432322674`, 0.366016220008902, 0.9367856217791819], 
             UndirectedEdge[31, 111] -> 
             RGBColor[
              0.8791608526585568, 0.4662912982465486, 0.4189256344996925], 
             UndirectedEdge[113, 357] -> 
             RGBColor[
              0.18582607626581804`, 0.31264536658207454`, 0.9338938921870696],
              UndirectedEdge[30, 329] -> 
             RGBColor[
              0.23151896311630302`, 0.36067148775828894`, 0.9364960344966363],
              UndirectedEdge[117, 239] -> 
             RGBColor[
              0.5328344578573876, 0.6316180426642315, 0.9563658268409162], 
             UndirectedEdge[209, 338] -> 
             RGBColor[
              0.23759083072429804`, 0.3670534055929334, 0.9368418183743885], 
             UndirectedEdge[208, 323] -> 
             RGBColor[
              0.3575199332630081, 0.48276280813906464`, 0.9440503364383386], 
             UndirectedEdge[71, 212] -> 
             RGBColor[
              0.7737416965530766, 0.822516123696677, 0.9480358411696325], 
             UndirectedEdge[199, 292] -> 
             RGBColor[
              0.8759065071929455, 0.430422481595631, 0.3896462592485583], 
             UndirectedEdge[11, 386] -> 
             RGBColor[
              0.6075598618760001, 0.6861529495738531, 0.9653876814635047], 
             UndirectedEdge[130, 267] -> 
             RGBColor[
              0.20661372269188627`, 0.33449450098878053`, 0.9350777178984673],
              UndirectedEdge[67, 347] -> 
             RGBColor[
              0.18186543483400505`, 0.3084824813180684, 0.9336683395167719], 
             UndirectedEdge[211, 358] -> 
             RGBColor[
              0.2550430737157216, 0.3853968195130357, 0.9378356977944702], 
             UndirectedEdge[2, 164] -> 
             RGBColor[
              0.20840908696131982`, 0.3363815426686245, 0.935179961237608], 
             UndirectedEdge[266, 358] -> 
             RGBColor[
              0.4679094050103473, 0.5710147999295367, 0.9528445815300333], 
             UndirectedEdge[57, 397] -> 
             RGBColor[
              0.3562392675894767, 0.4829782813049682, 0.943920229014154], 
             UndirectedEdge[209, 386] -> 
             RGBColor[
              0.30348621877337745`, 0.4332458361396474, 0.9407067904373323], 
             UndirectedEdge[74, 386] -> 
             RGBColor[
              0.29523037248077955`, 0.42456841823523894`, 0.9402366322043989],
              UndirectedEdge[47, 268] -> 
             RGBColor[
              0.18433220446865944`, 0.3110752126063183, 0.9338088183982067], 
             UndirectedEdge[108, 397] -> 
             RGBColor[
              0.3352715846751584, 0.4645968585734458, 0.9425922519510271], 
             UndirectedEdge[157, 358] -> 
             RGBColor[
              0.2622292284500658, 0.3929499237673575, 0.938244938675628], 
             UndirectedEdge[10, 129] -> 
             RGBColor[
              0.8350901197191642, 0.27072361351581226`, 0.18123564431268066`],
              UndirectedEdge[171, 308] -> 
             RGBColor[
              0.20045056014029836`, 0.3280166263799862, 0.9347267349087363], 
             UndirectedEdge[225, 335] -> 
             RGBColor[
              0.20337317791570175`, 0.3310884829666048, 0.93489317366742], 
             UndirectedEdge[45, 116] -> 
             RGBColor[
              0.23987123039501432`, 0.3694502502325462, 0.9369716837620867], 
             UndirectedEdge[261, 349] -> 
             RGBColor[
              0.19380914280268063`, 0.32103607566796977`, 0.9343485160164554],
              UndirectedEdge[118, 209] -> 
             RGBColor[
              0.3112464668184692, 0.43996737295489813`, 0.9412012665806477], 
             UndirectedEdge[329, 343] -> 
             RGBColor[
              0.23152940348291426`, 0.3606824612455548, 0.9364966290600697], 
             UndirectedEdge[163, 171] -> 
             RGBColor[
              0.18355378954190335`, 0.31025704916394076`, 0.9337644888196897],
              UndirectedEdge[106, 217] -> 
             RGBColor[
              0.1973830107710603, 0.32479243749905357`, 0.9345520425101908], 
             UndirectedEdge[55, 123] -> 
             RGBColor[
              0.830017651930728, 0.5040252837026356, 0.45299841203343794`], 
             UndirectedEdge[129, 353] -> 
             RGBColor[
              0.8773107079453166, 0.4290850996340871, 0.28001609828605356`], 
             UndirectedEdge[38, 66] -> 
             RGBColor[
              0.22742648369193186`, 0.3563700324050926, 0.9362629738476992], 
             UndirectedEdge[23, 119] -> 
             RGBColor[
              0.22585475434557115`, 0.35471804520867123`, 0.936173466186589], 
             UndirectedEdge[306, 354] -> 
             RGBColor[
              0.2092005815939097, 0.33721345371113465`, 0.9352250356860227], 
             UndirectedEdge[28, 39] -> 
             RGBColor[
              0.19488507531529636`, 0.3221669489567903, 0.9344097887813494], 
             UndirectedEdge[158, 267] -> 
             RGBColor[
              0.19435218965099377`, 0.3216068523367057, 0.934379441731101], 
             UndirectedEdge[194, 399] -> 
             RGBColor[
              0.40740786703989107`, 0.5272403351648417, 0.9471965661691704], 
             UndirectedEdge[102, 333] -> 
             RGBColor[
              0.6514056454646207, 0.7208926458479099, 0.9532948082895194], 
             UndirectedEdge[16, 80] -> 
             RGBColor[
              0.21603013302378776`, 0.34439174528250716`, 0.9356139685365383],
              UndirectedEdge[72, 333] -> 
             RGBColor[
              0.7096566263019076, 0.7710149507769987, 0.9570981774601166], 
             UndirectedEdge[167, 211] -> 
             RGBColor[
              0.23414776627805434`, 0.3634345265570368, 0.9366457409477322], 
             UndirectedEdge[193, 255] -> 
             RGBColor[
              0.606058461723811, 0.6860652101473173, 0.9647337421078497], 
             UndirectedEdge[168, 211] -> 
             RGBColor[
              0.2152267109388578, 0.3435472977313434, 0.935568214837358], 
             UndirectedEdge[70, 246] -> 
             RGBColor[
              0.2068329817370454, 0.33472495614706915`, 0.9350902043767244], 
             UndirectedEdge[322, 349] -> 
             RGBColor[
              0.19676296516777197`, 0.32414073025683565`, 0.9345167318303588],
              UndirectedEdge[193, 312] -> 
             RGBColor[
              0.6928723364666782, 0.7586931681891012, 0.9709743993376487], 
             UndirectedEdge[194, 221] -> 
             RGBColor[
              0.41267584437400284`, 0.5318031923554098, 0.9475322370266106], 
             UndirectedEdge[208, 221] -> 
             RGBColor[
              0.3321648835388723, 0.4608015384498717, 0.9424347350905069], 
             UndirectedEdge[112, 251] -> 
             RGBColor[
              0.18268323345773074`, 0.30934203952303163`, 0.9337149119385684],
              UndirectedEdge[297, 325] -> 
             RGBColor[
              0.267416015836295, 0.3984015661715987, 0.9385403185441094], 
             UndirectedEdge[170, 225] -> 
             RGBColor[
              0.22199301735031157`, 0.3506591147783862, 0.9359535459776369], 
             UndirectedEdge[27, 250] -> 
             RGBColor[
              0.19937642447535237`, 0.3268876416919933, 0.9346655644716588], 
             UndirectedEdge[67, 126] -> 
             RGBColor[
              0.18098291600078534`, 0.3075548980694286, 0.9336180813747896], 
             UndirectedEdge[12, 157] -> 
             RGBColor[
              0.24482342257705114`, 0.37465531820298625`, 0.937253703780742], 
             UndirectedEdge[316, 399] -> 
             RGBColor[
              0.5357585344043984, 0.6303722138797264, 0.9580316650391174], 
             UndirectedEdge[76, 377] -> 
             RGBColor[
              0.2688145572376063, 0.39987152185702324`, 0.9386199634079575], 
             UndirectedEdge[3, 51] -> 
             RGBColor[
              0.2187121116641707, 0.34721067488081686`, 0.9357667032524762], 
             UndirectedEdge[23, 186] -> 
             RGBColor[
              0.209250396089514, 0.3372658119044362, 0.9352278725478533], 
             UndirectedEdge[17, 319] -> 
             RGBColor[
              0.8292559200449149, 0.22587939825693307`, 0.17564880811583344`],
              UndirectedEdge[115, 360] -> 
             RGBColor[
              0.8089316906478522, 0.7980968050279984, 0.6248789386336926], 
             UndirectedEdge[131, 142] -> 
             RGBColor[
              0.6441352636384634, 0.7193460306737178, 0.9669266768382974], 
             UndirectedEdge[23, 130] -> 
             RGBColor[
              0.21379154943709947`, 0.3420388519985006, 0.935486484512964], 
             UndirectedEdge[348, 354] -> 
             RGBColor[
              0.19860265347109932`, 0.3260743593066081, 0.9346214993576583], 
             UndirectedEdge[76, 80] -> 
             RGBColor[
              0.24302079240522623`, 0.37276063959904404`, 0.9371510466592089],
              UndirectedEdge[38, 81] -> 
             RGBColor[
              0.2439408678768847, 0.37372769725591143`, 0.9372034435961902], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.22057742375863354`, 0.3491712361597149, 0.935872930016774], 
             UndirectedEdge[131, 281] -> 
             RGBColor[
              0.6064310569728814, 0.687254440774864, 0.9643678385927457], 
             UndirectedEdge[157, 167] -> 
             RGBColor[
              0.24133392101239853`, 0.37098763081135855`, 0.93705498182889], 
             UndirectedEdge[165, 172] -> 
             RGBColor[
              0.3025819493818708, 0.42881009810169846`, 0.9407829073040905], 
             UndirectedEdge[255, 331] -> 
             RGBColor[
              0.30757882188877433`, 0.4345645888368619, 0.9410490742458533], 
             UndirectedEdge[59, 268] -> 
             RGBColor[
              0.2019662570213913, 0.3296097199027477, 0.9348130516038419], 
             UndirectedEdge[161, 364] -> 
             RGBColor[
              0.9004423422818535, 0.6358848335091806, 0.23838402091941335`], 
             UndirectedEdge[149, 164] -> 
             RGBColor[
              0.21265948505393958`, 0.340848980554772, 0.9354220151210823], 
             UndirectedEdge[10, 52] -> 
             RGBColor[
              0.8916429525013146, 0.5507520246580102, 0.4032025959775474], 
             UndirectedEdge[132, 155] -> 
             RGBColor[
              0.18938684794258642`, 0.3163879633803221, 0.934096672866372], 
             UndirectedEdge[353, 400] -> 
             RGBColor[
              0.8791634122437909, 0.44332579673236017`, 0.28179025001460273`],
              UndirectedEdge[250, 265] -> 
             RGBColor[
              0.19635832810443649`, 0.32371543104779843`, 0.9344936883482087],
              UndirectedEdge[82, 233] -> 
             RGBColor[
              0.865044812104987, 0.8948209835298624, 0.9558976637938235], 
             UndirectedEdge[66, 81] -> 
             RGBColor[
              0.21264159429708712`, 0.3408301762349806, 0.9354209962689466], 
             UndirectedEdge[69, 201] -> 
             RGBColor[
              0.6192660008437627, 0.7014292931597987, 0.9634146436784279], 
             UndirectedEdge[84, 184] -> 
             RGBColor[
              0.21392003441563898`, 0.34217389785736374`, 0.9354938015424155],
              UndirectedEdge[180, 268] -> 
             RGBColor[
              0.1880422345433147, 0.314974689444274, 0.9340200991224608], 
             UndirectedEdge[17, 247] -> 
             RGBColor[
              0.8242207072500726, 0.18717654627145935`, 0.17082708265703297`],
              UndirectedEdge[188, 394] -> 
             RGBColor[
              0.3167171676025393, 0.44570099448454903`, 0.9415134165478973], 
             UndirectedEdge[241, 312] -> 
             RGBColor[
              0.41436397282412324`, 0.5281836244089898, 0.9484270661099586], 
             UndirectedEdge[81, 128] -> 
             RGBColor[
              0.2665289573662383, 0.3974692114768138, 0.9384898018765251], 
             UndirectedEdge[65, 198] -> 
             RGBColor[
              0.6026458427872066, 0.6834233570756016, 0.9643717480774334], 
             UndirectedEdge[356, 380] -> 
             RGBColor[
              0.8328828698668729, 0.8701375149884446, 0.9750500932107594], 
             UndirectedEdge[40, 265] -> 
             RGBColor[
              0.1962226401289317, 0.32357281438242835`, 0.9344859611187359], 
             UndirectedEdge[19, 168] -> 
             RGBColor[
              0.19873861175960342`, 0.3262172600880793, 0.9346292419810562], 
             UndirectedEdge[195, 241] -> 
             RGBColor[
              0.35276484059541724`, 0.47739540900316435`, 0.9437930699766406],
              UndirectedEdge[33, 141] -> 
             RGBColor[
              0.3011781143378584, 0.42954027603387246`, 0.9406221995821449], 
             UndirectedEdge[65, 100] -> 
             RGBColor[
              0.38210315454201915`, 0.5053802802265043, 0.9455682530202327], 
             UndirectedEdge[15, 207] -> 
             RGBColor[
              0.18682358813972555`, 0.3136938148074571, 0.9339506990126021], 
             UndirectedEdge[81, 135] -> 
             RGBColor[
              0.2822556151095555, 0.41153871876028536`, 0.9394754920042432], 
             UndirectedEdge[259, 271] -> 
             RGBColor[
              0.8451433755388915, 0.40965410113712897`, 0.44115450773017084`],
              UndirectedEdge[194, 233] -> 
             RGBColor[
              0.7128854689421396, 0.7730895863286765, 0.9426895386250231], 
             UndirectedEdge[101, 283] -> 
             RGBColor[
              0.8799566783602811, 0.5331818267657741, 0.22090624547796586`], 
             UndirectedEdge[145, 192] -> 
             RGBColor[
              0.25406976709764434`, 0.3843738125462326, 0.9377802694224489], 
             UndirectedEdge[68, 397] -> 
             RGBColor[
              0.5928919663607762, 0.6752224028696671, 0.9636363647773936], 
             UndirectedEdge[142, 201] -> 
             RGBColor[
              0.5699368421210522, 0.6613816598554264, 0.9595312716051138], 
             UndirectedEdge[146, 354] -> 
             RGBColor[
              0.197615256434939, 0.32503654241701563`, 0.9345652685571719], 
             UndirectedEdge[153, 329] -> 
             RGBColor[
              0.23399514583317907`, 0.36327411279277777`, 0.9366370494391784],
              UndirectedEdge[132, 279] -> 
             RGBColor[
              0.1959554713815859, 0.323292003089491, 0.9344707462538155], 
             UndirectedEdge[257, 389] -> 
             RGBColor[
              0.981271770948398, 0.982206986986089, 0.7147685106713391], 
             UndirectedEdge[107, 386] -> 
             RGBColor[
              0.2825040137132291, 0.4111922082727934, 0.9395118848995476], 
             UndirectedEdge[157, 203] -> 
             RGBColor[
              0.2784354581733116, 0.40986687435040126`, 0.9391721369966093], 
             UndirectedEdge[264, 281] -> 
             RGBColor[
              0.3293650670543722, 0.4551923504771167, 0.9423729197712435], 
             UndirectedEdge[244, 302] -> 
             RGBColor[
              0.18853043849765405`, 0.3154878227542032, 0.9340479016154273], 
             UndirectedEdge[46, 105] -> 
             RGBColor[
              0.8954193827902208, 0.9181003086598438, 0.937247307981482], 
             UndirectedEdge[126, 347] -> 
             RGBColor[
              0.18344187738111917`, 0.31013942238731573`, 0.9337581155876922],
              UndirectedEdge[129, 253] -> 
             RGBColor[
              0.8212882402079674, 0.16463631957058764`, 0.16801894890576527`],
              UndirectedEdge[14, 69] -> 
             RGBColor[
              0.45573362712038445`, 0.5659105913267511, 0.9511564428609628], 
             UndirectedEdge[118, 124] -> 
             RGBColor[
              0.29203302591126107`, 0.41977282835890883`, 0.9401070895447208],
              UndirectedEdge[181, 245] -> 
             RGBColor[
              0.1935081925729178, 0.3207197578951424, 0.9343313773460864], 
             UndirectedEdge[33, 152] -> 
             RGBColor[
              0.2237166408577273, 0.3524707523687224, 0.9360517037865118], 
             UndirectedEdge[47, 371] -> 
             RGBColor[
              0.18051873474236652`, 0.3070670141360388, 0.9335916469388172], 
             UndirectedEdge[131, 273] -> 
             RGBColor[
              0.6690783888345512, 0.7395959833828867, 0.9688902910234116], 
             UndirectedEdge[230, 299] -> 
             RGBColor[
              0.20475753633962784`, 0.33254353144354476`, 0.9349720108316877],
              UndirectedEdge[107, 181] -> 
             RGBColor[
              0.20760170595158578`, 0.3355329340364814, 0.935133982083517], 
             UndirectedEdge[4, 318] -> 
             RGBColor[
              0.20715075077545358`, 0.3350589515541568, 0.9351083008533645], 
             UndirectedEdge[10, 333] -> 
             RGBColor[
              0.8799035766623403, 0.5425287482789902, 0.44689524966387445`], 
             UndirectedEdge[152, 238] -> 
             RGBColor[
              0.20086303760420032`, 0.32845016634712887`, 0.9347502248900996],
              UndirectedEdge[50, 147] -> 
             RGBColor[
              0.23917140342485926`, 0.3687146877153205, 0.9369318296514377], 
             UndirectedEdge[39, 217] -> 
             RGBColor[
              0.2032105562120073, 0.33091755724521044`, 0.9348839126019717], 
             UndirectedEdge[98, 308] -> 
             RGBColor[
              0.20304826815792704`, 0.3307469822107151, 0.9348746705373756], 
             UndirectedEdge[31, 363] -> 
             RGBColor[
              0.6793920980440895, 0.7432878081939467, 0.9278140990011539], 
             UndirectedEdge[286, 386] -> 
             RGBColor[
              0.331585149915525, 0.4616241237277755, 0.94234929043675], 
             UndirectedEdge[137, 138] -> 
             RGBColor[
              0.29077492625511725`, 0.4229532620622423, 0.93987057393605], 
             UndirectedEdge[35, 372] -> 
             RGBColor[
              0.18502327958345532`, 0.31180157636866185`, 0.9338481741036404],
              UndirectedEdge[130, 158] -> 
             RGBColor[
              0.20340188077088672`, 0.3311186514872704, 0.9348948082525605], 
             UndirectedEdge[277, 373] -> 
             RGBColor[
              0.19154984531155025`, 0.31866141075705723`, 0.9342198523666666],
              UndirectedEdge[234, 365] -> 
             RGBColor[
              0.27647661087306347`, 0.4079248260301478, 0.9390563060275041], 
             UndirectedEdge[310, 316] -> 
             RGBColor[
              0.7883915446819063, 0.3948994518775877, 0.4393315589045834], 
             UndirectedEdge[218, 305] -> 
             RGBColor[
              0.42916789405553485`, 0.5422531768418173, 0.9494057845729981], 
             UndirectedEdge[155, 279] -> 
             RGBColor[
              0.19246829134850796`, 0.31962675577474187`, 0.9342721565097523],
              UndirectedEdge[32, 129] -> 
             RGBColor[
              0.8207912982104425, 0.1608166056162391, 0.16754307668771967`], 
             UndirectedEdge[92, 158] -> 
             RGBColor[
              0.19775538870657966`, 0.32518383031940923`, 0.9345732488827347],
              UndirectedEdge[332, 334] -> 
             RGBColor[
              0.865273808078536, 0.38439014871100835`, 0.20976553073467102`], 
             UndirectedEdge[268, 300] -> 
             RGBColor[
              0.1919105716037125, 0.31904055696148764`, 0.9342403951953585], 
             UndirectedEdge[224, 227] -> 
             RGBColor[
              0.3858696957004528, 0.504223043119987, 0.9462592294929938], 
             UndirectedEdge[25, 91] -> 
             RGBColor[
              0.47826887557608655`, 0.5848930154724093, 0.9527405987202289], 
             UndirectedEdge[74, 304] -> 
             RGBColor[
              0.2654021800822186, 0.39628489710950293`, 0.9384256335771177], 
             UndirectedEdge[86, 397] -> 
             RGBColor[
              0.3161394186740798, 0.4444877390569253, 0.9415027034007689], 
             UndirectedEdge[32, 111] -> 
             RGBColor[
              0.8232166057967019, 0.1794585825007891, 0.16986555397131473`], 
             UndirectedEdge[59, 394] -> 
             RGBColor[
              0.286948743301538, 0.41441249311708334`, 0.9398181488223927], 
             UndirectedEdge[170, 355] -> 
             RGBColor[
              0.2218222289646276, 0.3504796053564232, 0.9359438198317311], 
             UndirectedEdge[9, 56] -> 
             RGBColor[
              0.6023784760141789, 0.6874029877027437, 0.9623014191002394], 
             UndirectedEdge[44, 317] -> 
             RGBColor[
              0.2084087804726259, 0.3363812205295747, 0.9351799437835304], 
             UndirectedEdge[236, 262] -> 
             RGBColor[
              0.4369845815472029, 0.5513866495573997, 0.9494877616771007], 
             UndirectedEdge[119, 346] -> 
             RGBColor[
              0.2216080062797242, 0.35025444373208703`, 0.9359316201667398], 
             UndirectedEdge[80, 244] -> 
             RGBColor[
              0.1927330122426994, 0.31990499421881113`, 0.9342872319730569], 
             UndirectedEdge[20, 360] -> 
             RGBColor[
              0.523690607917635, 0.622017048024192, 0.9563749606192402], 
             UndirectedEdge[196, 206] -> 
             RGBColor[
              0.6365065028818196, 0.7122246861355508, 0.9667719599708235], 
             UndirectedEdge[187, 302] -> 
             RGBColor[
              0.20552429842574232`, 0.33334944701157526`, 0.9350156767981692],
              UndirectedEdge[147, 312] -> 
             RGBColor[
              0.3975158125820031, 0.5104751397594638, 0.9474675883087893], 
             UndirectedEdge[259, 400] -> 
             RGBColor[
              0.8465516858832649, 0.4204789915695107, 0.44250310730640185`], 
             UndirectedEdge[120, 312] -> 
             RGBColor[
              0.4801821242946682, 0.587765497365623, 0.9525267121427227], 
             UndirectedEdge[52, 60] -> 
             RGBColor[
              0.8480092281788032, 0.880384326820778, 0.9017418370121976], 
             UndirectedEdge[266, 384] -> 
             RGBColor[
              0.7959032258697958, 0.7536598609266292, 0.6159939861993788], 
             UndirectedEdge[135, 393] -> 
             RGBColor[
              0.5286635054610748, 0.6238093444947674, 0.9577562869015417], 
             UndirectedEdge[77, 244] -> 
             RGBColor[
              0.18965577385650711`, 0.31667062156674053`, 0.9341119877993296],
              UndirectedEdge[239, 385] -> 
             RGBColor[
              0.750777447641219, 0.8006120212149852, 0.7940547292395577], 
             UndirectedEdge[278, 296] -> 
             RGBColor[
              0.1835851599868279, 0.3102900214905575, 0.9337662753201197], 
             UndirectedEdge[267, 275] -> 
             RGBColor[
              0.19585412945824818`, 0.323185486302614, 0.9344649749812033], 
             UndirectedEdge[148, 340] -> 
             RGBColor[
              0.263972502592159, 0.39478221542066183`, 0.9383442155590771], 
             UndirectedEdge[202, 212] -> 
             RGBColor[
              0.45268550871471924`, 0.56313574583105, 0.9509994425842794], 
             UndirectedEdge[81, 346] -> 
             RGBColor[
              0.21629108370638292`, 0.34466602099514354`, 0.9356288292918702],
              UndirectedEdge[50, 217] -> 
             RGBColor[
              0.21968733955898895`, 0.34823570123129066`, 0.9358222410383658],
              UndirectedEdge[5, 183] -> 
             RGBColor[
              0.1877508166785864, 0.3146683907914848, 0.9340035033061785], 
             UndirectedEdge[313, 339] -> 
             RGBColor[
              0.3332875570200404, 0.460867825469856, 0.9425394482092617], 
             UndirectedEdge[4, 184] -> 
             RGBColor[
              0.20719899217930893`, 0.3351096563282905, 0.9351110481299474], 
             UndirectedEdge[104, 349] -> 
             RGBColor[
              0.21123195753513827`, 0.3393485586220395, 0.9353407195407242], 
             UndirectedEdge[119, 135] -> 
             RGBColor[
              0.2875725376828968, 0.4171271414972289, 0.9397782828791128], 
             UndirectedEdge[53, 273] -> 
             RGBColor[
              0.4633253395942303, 0.573810427068907, 0.9512742786711021], 
             UndirectedEdge[224, 259] -> 
             RGBColor[
              0.6965860849930616, 0.7612921063995717, 0.9717456253125671], 
             UndirectedEdge[110, 289] -> 
             RGBColor[
              0.6635885313279589, 0.7348104646113509, 0.9687942877706517], 
             UndirectedEdge[59, 155] -> 
             RGBColor[
              0.20108602021263303`, 0.3286845352065056, 0.9347629234197767], 
             UndirectedEdge[5, 29] -> 
             RGBColor[
              0.18632940584411195`, 0.31317439788179996`, 0.9339225560619441],
              UndirectedEdge[119, 311] -> 
             RGBColor[
              0.22119300122602184`, 0.3498182471078057, 0.9359079862428765], 
             UndirectedEdge[68, 72] -> 
             RGBColor[
              0.6435705389401349, 0.7187858683660439, 0.9669572267898132], 
             UndirectedEdge[121, 234] -> 
             RGBColor[
              0.2453302072944222, 0.37518798107295015`, 0.9372825644206755], 
             UndirectedEdge[20, 336] -> 
             RGBColor[
              0.3097133743307097, 0.43584317444763615`, 0.9412059659212678], 
             UndirectedEdge[17, 256] -> 
             RGBColor[
              0.8825424426584894, 0.4727787904011971, 0.3751504390784578], 
             UndirectedEdge[186, 272] -> 
             RGBColor[
              0.20161622991530592`, 0.3292418192212516, 0.9347931180779689], 
             UndirectedEdge[45, 304] -> 
             RGBColor[
              0.2609958832174149, 0.3916535997292371, 0.9381747014891992], 
             UndirectedEdge[165, 252] -> 
             RGBColor[
              0.21574093049341658`, 0.3440877750865875, 0.9355974988802704], 
             UndirectedEdge[106, 254] -> 
             RGBColor[
              0.18679837373704838`, 0.3136673128715579, 0.9339492630896711], 
             UndirectedEdge[144, 169] -> 
             RGBColor[
              0.5192579762174159, 0.6205960432553745, 0.9552970364739267], 
             UndirectedEdge[191, 355] -> 
             RGBColor[
              0.19607480659810572`, 0.32341743196834305`, 0.9344775422178556],
              UndirectedEdge[96, 377] -> 
             RGBColor[
              0.23316169487877575`, 0.36239810299585723`, 0.9365895856403053],
              UndirectedEdge[110, 303] -> 
             RGBColor[
              0.873446363467674, 0.7484181435664192, 0.6095212570798225], 
             UndirectedEdge[177, 260] -> 
             RGBColor[
              0.18516377148342406`, 0.31194924226322995`, 0.9338561749095045],
              UndirectedEdge[20, 88] -> 
             RGBColor[
              0.40751079531136875`, 0.5273871016357587, 0.9471872054229611], 
             UndirectedEdge[57, 68] -> 
             RGBColor[
              0.584951659196002, 0.6683449078949819, 0.9631304154261922], 
             UndirectedEdge[127, 264] -> 
             RGBColor[
              0.2996738393944105, 0.42947530140255136`, 0.9404810209996725], 
             UndirectedEdge[171, 186] -> 
             RGBColor[
              0.1973172314150955, 0.32472329922528254`, 0.9345482964731804], 
             UndirectedEdge[362, 385] -> 
             RGBColor[
              0.892844244734438, 0.9136671066548807, 0.806798376116899], 
             UndirectedEdge[109, 370] -> 
             RGBColor[
              0.18414849826566793`, 0.3108821257393283, 0.9337983566017154], 
             UndirectedEdge[123, 161] -> 
             RGBColor[
              0.8552873220803263, 0.4038002548740027, 0.1997084684807382], 
             UndirectedEdge[119, 213] -> 
             RGBColor[
              0.2826015926364835, 0.4128215587449884, 0.9394615386563896], 
             UndirectedEdge[140, 360] -> 
             RGBColor[
              0.5345510834209994, 0.6314238460418358, 0.9570669805147731], 
             UndirectedEdge[320, 347] -> 
             RGBColor[
              0.1840162025368019, 0.3107430745402564, 0.9337908225556705], 
             UndirectedEdge[10, 345] -> 
             RGBColor[
              0.8380059756120399, 0.5094315183430771, 0.453673951965273], 
             UndirectedEdge[169, 383] -> 
             RGBColor[
              0.4077881387207459, 0.527520322736191, 0.9472344418691334], 
             UndirectedEdge[154, 372] -> 
             RGBColor[
              0.18315975702077553`, 0.3098428960011307, 0.9337420492505304], 
             UndirectedEdge[167, 341] -> 
             RGBColor[
              0.2425749937598598, 0.37229207695749733`, 0.9371256590858552], 
             UndirectedEdge[186, 308] -> 
             RGBColor[
              0.20971443584181115`, 0.3377535471059201, 0.9352542989252615], 
             UndirectedEdge[145, 225] -> 
             RGBColor[
              0.22917757181567264`, 0.3582105370485437, 0.9363626957258434], 
             UndirectedEdge[12, 65] -> 
             RGBColor[
              0.30963980079837916`, 0.4365176650238572, 0.941174248166886], 
             UndirectedEdge[274, 288] -> 
             RGBColor[
              0.20843688657003606`, 0.3364107618199823, 0.9351815443841986], 
             UndirectedEdge[143, 171] -> 
             RGBColor[
              0.19347840745274208`, 0.320688451845352, 0.9343296811275554], 
             UndirectedEdge[167, 168] -> 
             RGBColor[
              0.21688542639170627`, 0.3452907128409211, 0.935662676228548], 
             UndirectedEdge[203, 341] -> 
             RGBColor[
              0.2796765309207728, 0.4111713204965401, 0.9392428142535747], 
             UndirectedEdge[114, 299] -> 
             RGBColor[
              0.1875337477163088, 0.31444023754916384`, 0.9339911415499016], 
             UndirectedEdge[154, 231] -> 
             RGBColor[
              0.18878970308862236`, 0.3157603262776354, 0.9340626663503354], 
             UndirectedEdge[218, 384] -> 
             RGBColor[
              0.7469305423915883, 0.7141446268230167, 0.6119725391027997], 
             UndirectedEdge[360, 380] -> 
             RGBColor[
              0.6915688443012366, 0.7589781043767949, 0.9698927773878063], 
             UndirectedEdge[98, 306] -> 
             RGBColor[
              0.20777436312467215`, 0.33571440767249217`, 0.9351438146541007],
              UndirectedEdge[57, 262] -> 
             RGBColor[
              0.35631608788520674`, 0.4830448191840292, 0.9439251239354682], 
             UndirectedEdge[152, 160] -> 
             RGBColor[
              0.19806967394342445`, 0.325514164030168, 0.9345911469620297], 
             UndirectedEdge[311, 354] -> 
             RGBColor[
              0.19934869375531813`, 0.32685849494700814`, 0.9346639852481768],
              UndirectedEdge[287, 303] -> 
             RGBColor[
              0.8428560193703771, 0.29316566393150867`, 0.187213659762262], 
             UndirectedEdge[222, 247] -> 
             RGBColor[
              0.8619216604353159, 0.4105330825046606, 0.4320513710856554], 
             UndirectedEdge[24, 206] -> 
             RGBColor[
              0.3445350824096081, 0.46835060878643464`, 0.9433388530787478], 
             UndirectedEdge[92, 308] -> 
             RGBColor[
              0.20860909712508957`, 0.3365917660321234, 0.9351913515205462], 
             UndirectedEdge[18, 266] -> 
             RGBColor[
              0.8253787823254205, 0.8596851688766582, 0.6977603506868537], 
             UndirectedEdge[28, 314] -> 
             RGBColor[
              0.18717488313259786`, 0.3140630481183549, 0.9339707047427519], 
             UndirectedEdge[128, 139] -> 
             RGBColor[
              0.3054227451460619, 0.43834904844198347`, 0.9407047455523833], 
             UndirectedEdge[160, 181] -> 
             RGBColor[
              0.19370887514270452`, 0.320930687999998, 0.9343428059215524], 
             UndirectedEdge[42, 296] -> 
             RGBColor[
              0.18148102360409654`, 0.30807844074235485`, 0.933646447865914], 
             UndirectedEdge[121, 289] -> 
             RGBColor[
              0.3589692840265578, 0.4787637861846151, 0.9444710719407625], 
             UndirectedEdge[22, 286] -> 
             RGBColor[
              0.2816381839372477, 0.41219449596583724`, 0.9393925574171622], 
             UndirectedEdge[128, 213] -> 
             RGBColor[
              0.3146576489473405, 0.4465145063990592, 0.9412870836406073], 
             UndirectedEdge[178, 398] -> 
             RGBColor[
              0.18190742429108608`, 0.30852661489974587`, 0.9336707307542348],
              UndirectedEdge[6, 129] -> 
             RGBColor[
              0.8549452081615826, 0.4144083574171603, 0.44170624981566164`], 
             UndirectedEdge[265, 375] -> 
             RGBColor[
              0.20089610111622702`, 0.32848491819461667`, 0.9347521078081966],
              UndirectedEdge[162, 270] -> 
             RGBColor[
              0.20162095796864934`, 0.3292467887050914, 0.9347933873336124], 
             UndirectedEdge[199, 271] -> 
             RGBColor[
              0.8762470859874794, 0.4330403194529975, 0.3899723978868326], 
             UndirectedEdge[60, 72] -> 
             RGBColor[
              0.5862802580314027, 0.6740171687476564, 0.9612505424717664], 
             UndirectedEdge[230, 258] -> 
             RGBColor[
              0.22938899732612533`, 0.3584327586651811, 0.9363747360958877], 
             UndirectedEdge[38, 135] -> 
             RGBColor[
              0.2970405045044002, 0.42707857493039736`, 0.9403174695829958], 
             UndirectedEdge[42, 67] -> 
             RGBColor[
              0.18164605198289263`, 0.3082518960318731, 0.9336558459879488], 
             UndirectedEdge[220, 352] -> 
             RGBColor[
              0.1830449444132805, 0.30972222067111355`, 0.9337355108423835], 
             UndirectedEdge[4, 226] -> 
             RGBColor[
              0.1963748100004493, 0.3237327545655205, 0.9344946269678038], 
             UndirectedEdge[134, 163] -> 
             RGBColor[
              0.17908461226291875`, 0.3055596604815222, 0.9335099757852068], 
             UndirectedEdge[25, 76] -> 
             RGBColor[
              0.32344841914925154`, 0.45219009338865274`, 0.9419182030554161],
              UndirectedEdge[250, 375] -> 
             RGBColor[
              0.19825790374427554`, 0.32571200548532114`, 0.9346018663707272],
              UndirectedEdge[50, 138] -> 
             RGBColor[
              0.26001645706684573`, 0.3906241607457843, 0.9381189246188555], 
             UndirectedEdge[24, 157] -> 
             RGBColor[
              0.2535215613420126, 0.38379761353881126`, 0.9377490499156633], 
             UndirectedEdge[127, 328] -> 
             RGBColor[
              0.2853602010040631, 0.41443075991720546`, 0.9396658804684725], 
             UndirectedEdge[107, 245] -> 
             RGBColor[
              0.20898762068619692`, 0.33698961829462715`, 0.9352129078773759],
              UndirectedEdge[16, 96] -> 
             RGBColor[
              0.22029148033523374`, 0.34887069149186156`, 0.9358566459618267],
              UndirectedEdge[42, 278] -> 
             RGBColor[
              0.18598976689484537`, 0.3128174158117676, 0.9339032141262342], 
             UndirectedEdge[51, 176] -> 
             RGBColor[
              0.19370665948804128`, 0.32092835920646634`, 0.9343426797432972],
              UndirectedEdge[33, 386] -> 
             RGBColor[
              0.2942581498186507, 0.4235465505748645, 0.9401812655620653], 
             UndirectedEdge[78, 187] -> 
             RGBColor[
              0.21840643996372563`, 0.3468893945429439, 0.9357492957013367], 
             UndirectedEdge[107, 150] -> 
             RGBColor[
              0.23074389884075946`, 0.35985684606277935`, 0.936451895732749], 
             UndirectedEdge[312, 360] -> 
             RGBColor[
              0.6052860238543496, 0.6901250393354524, 0.9622831022684131], 
             UndirectedEdge[78, 208] -> 
             RGBColor[
              0.257441859662032, 0.38791809563442126`, 0.9379723051054267], 
             UndirectedEdge[28, 197] -> 
             RGBColor[
              0.19145378666017485`, 0.3185604470239914, 0.9342143819685769], 
             UndirectedEdge[221, 316] -> 
             RGBColor[
              0.5410265117385101, 0.6349350710702945, 0.9583673358965574], 
             UndirectedEdge[243, 383] -> 
             RGBColor[
              0.29485575436090533`, 0.42265924207033345`, 0.9402707855274055],
              UndirectedEdge[83, 332] -> 
             RGBColor[
              0.8621982556376276, 0.41289639483243457`, 0.43240684643119587`],
              UndirectedEdge[98, 354] -> 
             RGBColor[
              0.19467499021807763`, 0.3219461361994489, 0.9343978247458558], 
             UndirectedEdge[46, 215] -> 
             RGBColor[
              0.7558037231431869, 0.8091588799312872, 0.9762951098017001], 
             UndirectedEdge[375, 381] -> 
             RGBColor[
              0.196072227977034, 0.3234147216741027, 0.9344773953692003], 
             UndirectedEdge[286, 304] -> 
             RGBColor[
              0.3017569575169641, 0.43334060260203944`, 0.9405382918094687], 
             UndirectedEdge[225, 235] -> 
             RGBColor[
              0.20086558407238086`, 0.32845284284664206`, 0.9347503699076954],
              UndirectedEdge[96, 225] -> 
             RGBColor[
              0.21005566506834547`, 0.33811220065819025`, 0.9352737314249091],
              UndirectedEdge[20, 389] -> 
             RGBColor[
              0.688874491712781, 0.747632448851442, 0.7193091573204213], 
             UndirectedEdge[259, 393] -> 
             RGBColor[
              0.808698190108407, 0.8510901979921818, 0.9814053247963395], 
             UndirectedEdge[97, 166] -> 
             RGBColor[
              0.27189959411517783`, 0.40311409121798647`, 0.9387956516942321],
              UndirectedEdge[115, 334] -> 
             RGBColor[
              0.9576597296930937, 0.8685855926092536, 0.2913334520501617], 
             UndirectedEdge[251, 260] -> 
             RGBColor[
              0.1869284496057658, 0.31380403085686637`, 0.9339566707179645], 
             UndirectedEdge[119, 344] -> 
             RGBColor[
              0.2156761634002051, 0.3440197007651513, 0.9355938104901265], 
             UndirectedEdge[329, 341] -> 
             RGBColor[
              0.2558412218032698, 0.3862357237585604, 0.9378811511473018], 
             UndirectedEdge[283, 334] -> 
             RGBColor[
              0.9460670651662169, 0.8226245407866379, 0.2820057220570269], 
             UndirectedEdge[1, 5] -> 
             RGBColor[
              0.18431548798727523`, 0.3110576425244974, 0.9338078664193217], 
             UndirectedEdge[364, 391] -> 
             RGBColor[
              0.8539355899833049, 0.3463029957972727, 0.1965281371936202], 
             UndirectedEdge[48, 295] -> 
             RGBColor[
              0.19691998178395526`, 0.3243057646758728, 0.9345256736943651], 
             UndirectedEdge[105, 199] -> 
             RGBColor[
              0.9870190215241651, 0.9889000460513815, 0.8647919372474027], 
             UndirectedEdge[281, 293] -> 
             RGBColor[
              0.356440478793437, 0.4831525603366694, 0.9439330500141462], 
             UndirectedEdge[216, 358] -> 
             RGBColor[
              0.24670674727990904`, 0.37663481187537284`, 0.9373609563364405],
              UndirectedEdge[100, 206] -> 
             RGBColor[
              0.40830029738828666`, 0.5280709286532568, 0.947237511797173], 
             UndirectedEdge[168, 341] -> 
             RGBColor[
              0.22365393842066325`, 0.35240484813180395`, 0.936048132975481], 
             UndirectedEdge[199, 259] -> 
             RGBColor[
              0.9420801867046171, 0.9545306309034027, 0.913114429015637], 
             UndirectedEdge[19, 24] -> 
             RGBColor[
              0.22984730742841403`, 0.35891447164122536`, 0.936400836178204], 
             UndirectedEdge[136, 299] -> 
             RGBColor[
              0.1855129526762866, 0.3123162538362948, 0.9338760602618706], 
             UndirectedEdge[64, 123] -> 
             RGBColor[
              0.8929669582944121, 0.5506732654841682, 0.2707503067207814], 
             UndirectedEdge[101, 334] -> 
             RGBColor[
              0.8893863599364948, 0.5697297884788785, 0.23285573762508466`], 
             UndirectedEdge[2, 328] -> 
             RGBColor[
              0.2165885293871429, 0.3449786552647677, 0.935645768383358], 
             UndirectedEdge[235, 349] -> 
             RGBColor[
              0.19583192039754477`, 0.3231621431716789, 0.9344637102080516], 
             UndirectedEdge[45, 290] -> 
             RGBColor[
              0.24862549482263574`, 0.3786515371983993, 0.9374702261704662], 
             UndirectedEdge[225, 327] -> 
             RGBColor[
              0.19712268368204472`, 0.3245188172228074, 0.9345372172675908], 
             UndirectedEdge[24, 386] -> 
             RGBColor[
              0.3010543278758621, 0.4306897646155703, 0.940568297848379], 
             UndirectedEdge[363, 393] -> 
             RGBColor[
              0.5482487832688899, 0.640773127747212, 0.9590042434848745], 
             UndirectedEdge[2, 258] -> 
             RGBColor[
              0.2197390144926751, 0.34829001486297484`, 0.935825183849393], 
             UndirectedEdge[8, 234] -> 
             RGBColor[
              0.2512674523014992, 0.38142840201846384`, 0.9376206817404615], 
             UndirectedEdge[44, 151] -> 
             RGBColor[
              0.21796286839338874`, 0.3464231726984579, 0.9357240349566114], 
             UndirectedEdge[253, 283] -> 
             RGBColor[
              0.8607691122014759, 0.3856977852240938, 0.20253221045503758`], 
             UndirectedEdge[257, 360] -> 
             RGBColor[
              0.816087887153252, 0.8565915861588391, 0.9518343139701578], 
             UndirectedEdge[65, 358] -> 
             RGBColor[
              0.3270456066713938, 0.4548122705882284, 0.942165483061772], 
             UndirectedEdge[282, 340] -> 
             RGBColor[
              0.29320777122887487`, 0.42492993475416496`, 0.9400303722049579],
              UndirectedEdge[256, 316] -> 
             RGBColor[
              0.8522226042580414, 0.8830674650503693, 0.8745751101286188], 
             UndirectedEdge[96, 182] -> 
             RGBColor[
              0.2267284521296566, 0.35563635697538404`, 0.9362232219828728], 
             UndirectedEdge[2, 106] -> 
             RGBColor[
              0.19417223523988333`, 0.32141770884085996`, 0.9343691935936069],
              UndirectedEdge[210, 279] -> 
             RGBColor[
              0.2223588131160111, 0.3510435893209275, 0.9359743775053473], 
             UndirectedEdge[279, 371] -> 
             RGBColor[
              0.1895350584309733, 0.3165437420007044, 0.9341051132344278], 
             UndirectedEdge[271, 353] -> 
             RGBColor[
              0.8777551018994175, 0.4325009062999784, 0.2804416504383717], 
             UndirectedEdge[306, 311] -> 
             RGBColor[
              0.21244806666191265`, 0.3406267664200514, 0.9354099751564218], 
             UndirectedEdge[64, 312] -> 
             RGBColor[
              0.7702008939642393, 0.8151650470913949, 0.695936819489472], 
             UndirectedEdge[137, 210] -> 
             RGBColor[
              0.2691626848877073, 0.40023742608984725`, 0.9386397887626219], 
             UndirectedEdge[264, 394] -> 
             RGBColor[
              0.30880202077051594`, 0.4373816733147978, 0.941062660645224], 
             UndirectedEdge[199, 224] -> 
             RGBColor[
              0.7432416506659434, 0.7963714338733744, 0.8949724605475597], 
             UndirectedEdge[61, 301] -> 
             RGBColor[
              0.23356716082772205`, 0.3628242734162258, 0.9366126763262647], 
             UndirectedEdge[48, 103] -> 
             RGBColor[
              0.2013643551866071, 0.328977082911609, 0.9347787741847848], 
             UndirectedEdge[7, 14] -> 
             RGBColor[
              0.29679890469924086`, 0.4265200793940456, 0.9403148622219284], 
             UndirectedEdge[88, 195] -> 
             RGBColor[
              0.42750707901937735`, 0.5447068775411936, 0.948461350938816], 
             UndirectedEdge[211, 341] -> 
             RGBColor[
              0.24091627830701134`, 0.3705486618479197, 0.9370311976946651], 
             UndirectedEdge[84, 185] -> 
             RGBColor[
              0.20341836522778634`, 0.3311359776966468, 0.9348957470179945], 
             UndirectedEdge[368, 387] -> 
             RGBColor[
              0.18468757746568928`, 0.3114487321581461, 0.9338290563646603], 
             UndirectedEdge[134, 171] -> 
             RGBColor[
              0.18358417843459812`, 0.31028898981693004`, 0.9337662194221723],
              UndirectedEdge[41, 295] -> 
             RGBColor[
              0.19034802985855803`, 0.31739822651646155`, 0.9341514107545453],
              UndirectedEdge[77, 388] -> 
             RGBColor[
              0.23386679686193323`, 0.36313920988620363`, 0.9366297401551412],
              UndirectedEdge[142, 273] -> 
             RGBColor[
              0.4991027451822828, 0.6042331187182427, 0.9537103428557971], 
             UndirectedEdge[64, 140] -> 
             RGBColor[
              0.6994659535308891, 0.7564638537977784, 0.690720697735832], 
             UndirectedEdge[150, 157] -> 
             RGBColor[
              0.24263401195527415`, 0.3723541088228476, 0.9371290200847746], 
             UndirectedEdge[210, 264] -> 
             RGBColor[
              0.2528298194491141, 0.3830705489504057, 0.9377096562382032], 
             UndirectedEdge[202, 309] -> 
             RGBColor[
              0.5124790971855998, 0.6108362268976354, 0.9562827357512269], 
             UndirectedEdge[105, 287] -> 
             RGBColor[
              0.8733134302236104, 0.41881471124185254`, 0.40722620341472526`],
              UndirectedEdge[157, 160] -> 
             RGBColor[
              0.22107841637049833`, 0.349697811159551, 0.9359014608048675], 
             UndirectedEdge[153, 379] -> 
             RGBColor[
              0.19405975897206282`, 0.32129948915197337`, 0.9343627882365483],
              UndirectedEdge[207, 387] -> 
             RGBColor[
              0.18852965084716983`, 0.3154869948836043, 0.9340478567598975], 
             UndirectedEdge[93, 264] -> 
             RGBColor[
              0.3012538452175734, 0.43084382303317337`, 0.9405816975735801], 
             UndirectedEdge[202, 365] -> 
             RGBColor[
              0.31680424057691503`, 0.4485693265510483, 0.9414167025039941], 
             UndirectedEdge[138, 230] -> 
             RGBColor[
              0.2550152839737512, 0.38536761073225334`, 0.9378341152097762], 
             UndirectedEdge[5, 291] -> 
             RGBColor[
              0.19113912643877223`, 0.3182297191806869, 0.9341964625344661], 
             UndirectedEdge[241, 360] -> 
             RGBColor[
              0.4718334584098283, 0.5745274932673213, 0.9531648972863125], 
             UndirectedEdge[299, 300] -> 
             RGBColor[
              0.19227535029574405`, 0.31942396249511773`, 0.934261168802228], 
             UndirectedEdge[9, 266] -> 
             RGBColor[
              0.6722902895010364, 0.7439175508444353, 0.9679712712136599], 
             UndirectedEdge[226, 322] -> 
             RGBColor[
              0.1935079091107788, 0.32071945995846174`, 0.9343313612033369], 
             UndirectedEdge[175, 216] -> 
             RGBColor[
              0.20297653411671235`, 0.3306715851851976, 0.9348705853898494], 
             UndirectedEdge[115, 257] -> 
             RGBColor[
              0.9622640683610495, 0.9182194829930534, 0.6096923191590835], 
             UndirectedEdge[146, 275] -> 
             RGBColor[
              0.1966367657635329, 0.324008086681476, 0.9345095449609826], 
             UndirectedEdge[64, 101] -> 
             RGBColor[
              0.9001775806462604, 0.6060972685953367, 0.2776552068281445], 
             UndirectedEdge[79, 390] -> 
             RGBColor[
              0.2060170491676479, 0.3338673592835195, 0.9350437382239613], 
             UndirectedEdge[98, 378] -> 
             RGBColor[
              0.21674290293340537`, 0.34514091164973765`, 0.9356545597284425],
              UndirectedEdge[37, 80] -> 
             RGBColor[
              0.24371904320437376`, 0.3734945454606058, 0.9371908110092508], 
             UndirectedEdge[344, 354] -> 
             RGBColor[
              0.1938318559295014, 0.32105994860435383`, 0.9343498094954268], 
             UndirectedEdge[119, 227] -> 
             RGBColor[
              0.25689083303762017`, 0.3873389317150586, 0.9379409249543373], 
             UndirectedEdge[81, 166] -> 
             RGBColor[
              0.2371652059079643, 0.3666060469247946, 0.9368175796707537], 
             UndirectedEdge[192, 221] -> 
             RGBColor[
              0.3140891047086496, 0.4418027488287358, 0.9414053462268441], 
             UndirectedEdge[242, 331] -> 
             RGBColor[
              0.2906837062391053, 0.4199308888343219, 0.9399725324164205], 
             UndirectedEdge[225, 322] -> 
             RGBColor[
              0.2017966288426081, 0.3294314299317988, 0.9348033915300026], 
             UndirectedEdge[165, 170] -> 
             RGBColor[
              0.23052227294686206`, 0.35962390319639986`, 0.9364392744659576],
              UndirectedEdge[41, 250] -> 
             RGBColor[
              0.1942575833696331, 0.32150741513661096`, 0.934374054043335], 
             UndirectedEdge[31, 393] -> 
             RGBColor[
              0.8531150739602782, 0.8852437730014981, 0.9417329113283139], 
             UndirectedEdge[140, 312] -> 
             RGBColor[
              0.4770815978352943, 0.5850799771835042, 0.9523291493384193], 
             UndirectedEdge[56, 100] -> 
             RGBColor[
              0.4530551393941151, 0.565068246426121, 0.9505774993750733], 
             UndirectedEdge[89, 183] -> 
             RGBColor[
              0.21045489979042858`, 0.338531821664043, 0.935296467251717], 
             UndirectedEdge[39, 210] -> 
             RGBColor[
              0.22192743235245416`, 0.35059018078730897`, 0.9359498110090333],
              UndirectedEdge[34, 321] -> 
             RGBColor[
              0.18374554341254123`, 0.3104585946398788, 0.9337754089189481], 
             UndirectedEdge[148, 301] -> 
             RGBColor[
              0.25321055434935075`, 0.3834707254705414, 0.9377313385275249], 
             UndirectedEdge[136, 155] -> 
             RGBColor[
              0.18426793717549678`, 0.3110076636064226, 0.933805158470936], 
             UndirectedEdge[51, 205] -> 
             RGBColor[
              0.19318129293550862`, 0.32037616564959115`, 0.9343127608953405],
              UndirectedEdge[11, 123] -> 
             RGBColor[
              0.853169485204603, 0.5223983832616403, 0.45522988600606007`], 
             UndirectedEdge[223, 400] -> 
             RGBColor[
              0.8468492899928622, 0.3594083059636659, 0.19242961479906362`], 
             UndirectedEdge[6, 201] -> 
             RGBColor[
              0.7959386825090102, 0.8413708229845736, 0.9800676455168078], 
             UndirectedEdge[201, 273] -> 
             RGBColor[
              0.5948799673171399, 0.6816316125645953, 0.9614948857902279], 
             UndirectedEdge[54, 196] -> 
             RGBColor[
              0.8961892019683437, 0.8555483275728113, 0.6311082747514651], 
             UndirectedEdge[84, 288] -> 
             RGBColor[
              0.21401051896422651`, 0.342269002854981, 0.9354989545035975], 
             UndirectedEdge[177, 248] -> 
             RGBColor[
              0.18215464872777276`, 0.30878646345763827`, 0.9336848098201683],
              UndirectedEdge[76, 117] -> 
             RGBColor[
              0.4207333030341396, 0.5335965741048728, 0.9489064510842957], 
             UndirectedEdge[342, 348] -> 
             RGBColor[
              0.1937491041812462, 0.3209729712701737, 0.9343450969057838], 
             UndirectedEdge[332, 389] -> 
             RGBColor[
              0.8762443712451391, 0.4211412242083381, 0.2740853195911458], 
             UndirectedEdge[68, 236] -> 
             RGBColor[
              0.6656201528579981, 0.7366867382683524, 0.9686930531678246], 
             UndirectedEdge[84, 318] -> 
             RGBColor[
              0.2138717930117836, 0.3421231930832301, 0.9354910542658326], 
             UndirectedEdge[15, 372] -> 
             RGBColor[
              0.1810383624053819, 0.30761317575616476`, 0.9336212389655058], 
             UndirectedEdge[88, 189] -> 
             RGBColor[
              0.331784795723977, 0.4548098720727408, 0.9426178463888004], 
             UndirectedEdge[364, 380] -> 
             RGBColor[
              0.8208602613542741, 0.753663537851497, 0.6141649050014586], 
             UndirectedEdge[103, 295] -> 
             RGBColor[
              0.1903453971129866, 0.3173954593339403, 0.9341512608235798], 
             UndirectedEdge[20, 257] -> 
             RGBColor[
              0.6770229856308323, 0.7421397259892473, 0.9411883411446311], 
             UndirectedEdge[12, 24] -> 
             RGBColor[
              0.25148362362516946`, 0.3816556117856949, 0.9376329923775478], 
             UndirectedEdge[152, 157] -> 
             RGBColor[
              0.22385261786682037`, 0.3526136728267195, 0.9360594474760198], 
             UndirectedEdge[26, 70] -> 
             RGBColor[
              0.1896105861046007, 0.3166231263744179, 0.9341094144237078], 
             UndirectedEdge[33, 74] -> 
             RGBColor[
              0.24756162893783695`, 0.3775333467004828, 0.9374096405821755], 
             UndirectedEdge[124, 238] -> 
             RGBColor[
              0.21375043106969976`, 0.3419956339873084, 0.9354841428827698], 
             UndirectedEdge[148, 339] -> 
             RGBColor[
              0.3192552716311131, 0.4461190038278132, 0.9417403303152683], 
             UndirectedEdge[175, 229] -> 
             RGBColor[
              0.1940292110138258, 0.32126738131101384`, 0.9343610485755184], 
             UndirectedEdge[105, 337] -> 
             RGBColor[
              0.9711407562018461, 0.97781294412538, 0.9254748728105828], 
             UndirectedEdge[158, 306] -> 
             RGBColor[
              0.20672015111524922`, 0.33460636400968674`, 0.935083778839731], 
             UndirectedEdge[136, 268] -> 
             RGBColor[
              0.18514817398425504`, 0.3119328483026647, 0.9338552866550012], 
             UndirectedEdge[133, 278] -> 
             RGBColor[
              0.18574944160901402`, 0.31256481869885566`, 0.9338895279567354],
              UndirectedEdge[197, 254] -> 
             RGBColor[
              0.18919463052287389`, 0.31618593068491585`, 0.9340857263686796],
              UndirectedEdge[296, 398] -> 
             RGBColor[
              0.17994179284220208`, 0.3064606116187368, 0.933558790951112], 
             UndirectedEdge[10, 271] -> 
             RGBColor[
              0.8353123166962146, 0.27243151684875794`, 0.18144842038883974`],
              UndirectedEdge[221, 399] -> 
             RGBColor[
              0.36464378874039466`, 0.49025785510237774`, 0.9444557576700642],
              UndirectedEdge[187, 388] -> 
             RGBColor[
              0.2435643246839634, 0.37333192648593383`, 0.937182000018399], 
             UndirectedEdge[143, 186] -> 
             RGBColor[
              0.20274228315425485`, 0.3304253725712859, 0.9348572451440806], 
             UndirectedEdge[372, 387] -> 
             RGBColor[
              0.18274442511282618`, 0.30940635583231196`, 0.9337183967128011],
              UndirectedEdge[147, 255] -> 
             RGBColor[
              0.3107019378391358, 0.4378471817176799, 0.9412269310789902], 
             UndirectedEdge[27, 86] -> 
             RGBColor[
              0.23656599040606416`, 0.3659762334398404, 0.9367834552343804], 
             UndirectedEdge[19, 157] -> 
             RGBColor[
              0.2231871063802957, 0.35191417805851677`, 0.9360215475813982], 
             UndirectedEdge[192, 208] -> 
             RGBColor[
              0.27634222217301546`, 0.40778357498566165`, 0.9390486527898467],
              UndirectedEdge[88, 89] -> 
             RGBColor[
              0.33131087657095276`, 0.4543117529947025, 0.9425908573941362], 
             UndirectedEdge[54, 332] -> 
             RGBColor[
              0.8612878791024013, 0.3694248520342004, 0.20219620971087243`], 
             UndirectedEdge[282, 301] -> 
             RGBColor[
              0.2824458229860667, 0.41361844480404447`, 0.9394174951734057], 
             UndirectedEdge[264, 328] -> 
             RGBColor[
              0.24566528906336602`, 0.3755401732575213, 0.9373016468317077], 
             UndirectedEdge[124, 156] -> 
             RGBColor[
              0.21424517968646528`, 0.3425156461524031, 0.9355123180845796], 
             UndirectedEdge[64, 120] -> 
             RGBColor[
              0.7025664799902631, 0.759149373979897, 0.6909182605401354], 
             UndirectedEdge[55, 236] -> 
             RGBColor[
              0.6566866391587384, 0.7296947127190476, 0.9678061194855357], 
             UndirectedEdge[11, 196] -> 
             RGBColor[
              0.8586587168624804, 0.8901351694289188, 0.9863808290196707], 
             UndirectedEdge[223, 319] -> 
             RGBColor[
              0.8502923449808009, 0.3858731353572784, 0.1957266881438881], 
             UndirectedEdge[61, 70] -> 
             RGBColor[
              0.20711529305388426`, 0.33502168324063814`, 0.9351062815885762],
              UndirectedEdge[307, 343] -> 
             RGBColor[
              0.1898749181249935, 0.3169009560874688, 0.9341244677412249], 
             UndirectedEdge[13, 87] -> 
             RGBColor[
              0.2001057560025477, 0.3276542153693653, 0.9347070988231834], 
             UndirectedEdge[119, 128] -> 
             RGBColor[
              0.2718458799395796, 0.4030576342137573, 0.9387925927513947], 
             UndirectedEdge[92, 130] -> 
             RGBColor[
              0.2100169217474722, 0.33807147897148404`, 0.935271525050101], 
             UndirectedEdge[263, 359] -> 
             RGBColor[
              0.31376085658735253`, 0.4455463754257799, 0.941236947982536], 
             UndirectedEdge[22, 304] -> 
             RGBColor[
              0.2621517349847551, 0.3928684732219464, 0.9382405255374198], 
             UndirectedEdge[139, 306] -> 
             RGBColor[
              0.2646217542710957, 0.39546462010015837`, 0.9383811894817108], 
             UndirectedEdge[1, 73] -> 
             RGBColor[
              0.19016251964762415`, 0.3172032435227433, 0.9341408462224705], 
             UndirectedEdge[7, 13] -> 
             RGBColor[
              0.23415570368153021`, 0.3634428692713504, 0.9366461929711178], 
             UndirectedEdge[170, 335] -> 
             RGBColor[
              0.21688414248716403`, 0.34528936337584293`, 0.9356626031120838],
              UndirectedEdge[276, 361] -> 
             RGBColor[
              0.3943096577609078, 0.5159529397980152, 0.9463460406115533], 
             UndirectedEdge[46, 345] -> 
             RGBColor[
              0.8168101022247779, 0.8568829940339906, 0.982358282576511], 
             UndirectedEdge[36, 301] -> 
             RGBColor[
              0.2477609938146631, 0.37774289182649035`, 0.9374209941169768], 
             UndirectedEdge[50, 328] -> 
             RGBColor[
              0.23123968531368772`, 0.36037794908050486`, 0.9364801300389318],
              UndirectedEdge[55, 83] -> 
             RGBColor[
              0.8773611303882973, 0.9047851000408222, 0.9744632955960668], 
             UndirectedEdge[143, 306] -> 
             RGBColor[
              0.21060170684620283`, 0.33868612518776664`, 0.9353048276963617],
              UndirectedEdge[32, 400] -> 
             RGBColor[
              0.8217176503596796, 0.1679369541653756, 0.16843015255199423`], 
             UndirectedEdge[20, 195] -> 
             RGBColor[
              0.40462199010322386`, 0.5248849637600351, 0.9470031333095683], 
             UndirectedEdge[203, 266] -> 
             RGBColor[
              0.4841156347335931, 0.5879317505125805, 0.9537717798510146], 
             UndirectedEdge[255, 359] -> 
             RGBColor[
              0.3499392226187198, 0.4775214990007658, 0.9435187957195283], 
             UndirectedEdge[128, 215] -> 
             RGBColor[
              0.5049864538136, 0.6035289290681363, 0.9559781758101122], 
             UndirectedEdge[230, 328] -> 
             RGBColor[
              0.2262385122205931, 0.35512139906697393`, 0.9361953206298528], 
             UndirectedEdge[44, 146] -> 
             RGBColor[
              0.21372136571514777`, 0.3419650844568244, 0.9354824876538264], 
             UndirectedEdge[56, 206] -> 
             RGBColor[
              0.4736432444349138, 0.5829006282242136, 0.9518893552229266], 
             UndirectedEdge[55, 196] -> 
             RGBColor[
              0.8239309669516679, 0.8625755200904117, 0.9830336180607375], 
             UndirectedEdge[93, 188] -> 
             RGBColor[
              0.3091689920495968, 0.43916314420292457`, 0.9410324534762535], 
             UndirectedEdge[52, 271] -> 
             RGBColor[
              0.8763333885975696, 0.43307600780014566`, 0.3885421402936417], 
             UndirectedEdge[193, 253] -> 
             RGBColor[
              0.8294376428224145, 0.4209653077854606, 0.4426395583706675], 
             UndirectedEdge[120, 193] -> 
             RGBColor[
              0.6252379224927019, 0.7026774950776031, 0.9659558403883122], 
             UndirectedEdge[28, 217] -> 
             RGBColor[
              0.19992147826691017`, 0.32746052778532697`, 0.9346966044787532],
              UndirectedEdge[124, 245] -> 
             RGBColor[
              0.21075638483913717`, 0.33884870156549185`, 0.9353136363792337],
              UndirectedEdge[36, 282] -> 
             RGBColor[
              0.28033871258182136`, 0.4114037381706667, 0.9392974983530744], 
             UndirectedEdge[276, 339] -> 
             RGBColor[
              0.38050139833268903`, 0.5039929195045905, 0.9454661905309516], 
             UndirectedEdge[377, 388] -> 
             RGBColor[
              0.26273780008050557`, 0.39348446479625343`, 0.9382739010776171],
              UndirectedEdge[129, 131] -> 
             RGBColor[
              0.8175944103377895, 0.3846574917741582, 0.4381352993196086], 
             UndirectedEdge[69, 142] -> 
             RGBColor[
              0.5234887787089056, 0.6240307993134462, 0.955630100743997], 
             UndirectedEdge[11, 118] -> 
             RGBColor[
              0.6153201099210919, 0.6928744863891039, 0.9658821576068201], 
             UndirectedEdge[53, 293] -> 
             RGBColor[
              0.35836727987096656`, 0.4848214585861875, 0.944055824075003], 
             UndirectedEdge[2, 137] -> 
             RGBColor[
              0.24723503321608348`, 0.3771900738895551, 0.9373910414389766], 
             UndirectedEdge[102, 213] -> 
             RGBColor[
              0.33722405994131943`, 0.4665082641722599, 0.9427085967973012], 
             UndirectedEdge[269, 362] -> 
             RGBColor[
              0.5723371220999356, 0.658694027276514, 0.9617848366135348], 
             UndirectedEdge[147, 242] -> 
             RGBColor[
              0.29380682218946674`, 0.42321348171513995`, 0.9401503892495575],
              UndirectedEdge[58, 220] -> 
             RGBColor[
              0.186453938859043, 0.31330528997634166`, 0.9339296480329143], 
             UndirectedEdge[177, 285] -> 
             RGBColor[
              0.18283630546897034`, 0.3095029279121705, 0.9337236291631588], 
             UndirectedEdge[213, 215] -> 
             RGBColor[
              0.5157421665105038, 0.6132928535993672, 0.9566471217151071], 
             UndirectedEdge[61, 382] -> 
             RGBColor[
              0.2696810924925139, 0.39954800963710424`, 0.9387145049212492], 
             UndirectedEdge[83, 123] -> 
             RGBColor[
              0.8791001851437382, 0.542812031489136, 0.4485921532142464], 
             UndirectedEdge[207, 368] -> 
             RGBColor[
              0.18767517326657374`, 0.3145888847693901, 0.9339991955257688], 
             UndirectedEdge[117, 377] -> 
             RGBColor[
              0.40661285819624315`, 0.5187550912923315, 0.9481023126401036], 
             UndirectedEdge[207, 392] -> 
             RGBColor[
              0.1972896880999786, 0.3246943494547476, 0.9345467279221311], 
             UndirectedEdge[43, 325] -> 
             RGBColor[
              0.21648460691960775`, 0.3448694261623232, 0.9356398501525713], 
             UndirectedEdge[83, 196] -> 
             RGBColor[
              0.8975547667711833, 0.9207556417701627, 0.9764242298319501], 
             UndirectedEdge[81, 130] -> 
             RGBColor[
              0.2224096961469096, 0.35109707061257234`, 0.9359772752186821], 
             UndirectedEdge[204, 229] -> 
             RGBColor[
              0.18893129430891603`, 0.3159091476275659, 0.9340707297608657], 
             UndirectedEdge[44, 267] -> 
             RGBColor[
              0.21293872940986303`, 0.3411424840779623, 0.935437917674047], 
             UndirectedEdge[38, 130] -> 
             RGBColor[
              0.23719458554175432`, 0.36663692678268434`, 0.9368192527974348],
              UndirectedEdge[226, 318] -> 
             RGBColor[
              0.20268055409019498`, 0.33036049141111024`, 0.9348537297652024],
              UndirectedEdge[202, 362] -> 
             RGBColor[
              0.5594312028417849, 0.6475155686854668, 0.9609624828506617], 
             UndirectedEdge[59, 230] -> 
             RGBColor[
              0.21869887314196257`, 0.34719676035460534`, 0.9357659493382211],
              UndirectedEdge[131, 394] -> 
             RGBColor[
              0.585868010689025, 0.6694437636125451, 0.9630575794667262], 
             UndirectedEdge[93, 142] -> 
             RGBColor[
              0.4083441914838143, 0.5275430486662767, 0.9473966682274677], 
             UndirectedEdge[301, 340] -> 
             RGBColor[
              0.26063005246171667`, 0.3912690884099886, 0.9381538679688604], 
             UndirectedEdge[16, 76] -> 
             RGBColor[
              0.2559443426940643, 0.3863441103530275, 0.937887023729479], 
             UndirectedEdge[25, 239] -> 
             RGBColor[
              0.43554957397249955`, 0.5502115619480115, 0.9493775788120367], 
             UndirectedEdge[46, 60] -> 
             RGBColor[
              0.7562801355297237, 0.809531056908518, 0.9763425941360632], 
             UndirectedEdge[57, 297] -> 
             RGBColor[
              0.3224295006293375, 0.45256728530617585`, 0.9418071536579791], 
             UndirectedEdge[221, 351] -> 
             RGBColor[
              0.33973329445254913`, 0.4686816369880935, 0.9428684830015278], 
             UndirectedEdge[365, 377] -> 
             RGBColor[
              0.2803555468892034, 0.41200183372185906`, 0.9392772056952516], 
             UndirectedEdge[334, 366] -> 
             RGBColor[
              0.9767558229939741, 0.9327621554008622, 0.40603042724612426`], 
             UndirectedEdge[209, 290] -> 
             RGBColor[
              0.2612876379800373, 0.3919602524830736, 0.938191316491318], 
             UndirectedEdge[174, 313] -> 
             RGBColor[
              0.35122662219084355`, 0.47640574207717373`, 0.9436825095790529],
              UndirectedEdge[56, 358] -> 
             RGBColor[
              0.3979975915234898, 0.5145002367878451, 0.9471747294166126], 
             UndirectedEdge[304, 338] -> 
             RGBColor[
              0.24620331291395298`, 0.37610567043717064`, 0.9373322864940637],
              UndirectedEdge[130, 306] -> 
             RGBColor[
              0.21898168415614172`, 0.3474940126617616, 0.9357820550070972], 
             UndirectedEdge[11, 206] -> 
             RGBColor[
              0.6510406164097462, 0.7238137937447175, 0.9681582366938735], 
             UndirectedEdge[120, 140] -> 
             RGBColor[
              0.409447183861318, 0.5290643040720063, 0.9473105903890827], 
             UndirectedEdge[193, 356] -> 
             RGBColor[
              0.8916558476180196, 0.9161964476590825, 0.9808695463369558], 
             UndirectedEdge[166, 246] -> 
             RGBColor[
              0.23093801406837325`, 0.3600608734746177, 0.9364629503077938], 
             UndirectedEdge[76, 182] -> 
             RGBColor[
              0.2623813144884871, 0.39310977583655005`, 0.9382535997505249], 
             UndirectedEdge[6, 364] -> 
             RGBColor[
              0.9237508221541206, 0.8349006337052781, 0.6241923325830713], 
             UndirectedEdge[288, 318] -> 
             RGBColor[
              0.21359522081764215`, 0.3418324981714975, 0.9354753038885282], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.285788273116509, 0.4171315718147177, 0.9396078427636225], 
             UndirectedEdge[128, 151] -> 
             RGBColor[
              0.2557571228947407, 0.38614733047351757`, 0.9378763618388744], 
             UndirectedEdge[30, 379] -> 
             RGBColor[
              0.19158357625518677`, 0.31869686411748455`, 0.9342217732940062],
              UndirectedEdge[70, 90] -> 
             RGBColor[
              0.2062666965089075, 0.33412975446773896`, 0.9350579552707259], 
             UndirectedEdge[137, 394] -> 
             RGBColor[
              0.32513488620910913`, 0.45454855045423936`, 0.9419927931696428],
              UndirectedEdge[25, 269] -> 
             RGBColor[
              0.35868258725721747`, 0.48509456199634804`, 0.9440759151828396],
              UndirectedEdge[38, 227] -> 
             RGBColor[
              0.2663587998591236, 0.39729036514822713`, 0.9384801116582203], 
             UndirectedEdge[128, 135] -> 
             RGBColor[
              0.31962859399375376`, 0.45082008915129973`, 0.9416038278633306],
              UndirectedEdge[129, 303] -> 
             RGBColor[
              0.8442007939445894, 0.3035021905928796, 0.18850141741323326`], 
             UndirectedEdge[132, 299] -> 
             RGBColor[
              0.19063186344337624`, 0.3176965536101942, 0.9341675746573066], 
             UndirectedEdge[352, 396] -> 
             RGBColor[
              0.18539177638104404`, 0.312188889866974, 0.9338691594511209], 
             UndirectedEdge[155, 268] -> 
             RGBColor[
              0.18677990471826675`, 0.31364790076181503`, 0.9339482113063738],
              UndirectedEdge[8, 16] -> 
             RGBColor[
              0.24227617377409713`, 0.3719779982061794, 0.9371086417297306], 
             UndirectedEdge[213, 378] -> 
             RGBColor[
              0.2828251978811075, 0.4130565820344796, 0.9394742726442766], 
             UndirectedEdge[164, 230] -> 
             RGBColor[
              0.21805906979477002`, 0.3465242864708308, 0.9357295134841028], 
             UndirectedEdge[218, 339] -> 
             RGBColor[
              0.47111694262023773`, 0.5795753796238241, 0.9520425636736524], 
             UndirectedEdge[101, 366] -> 
             RGBColor[
              0.9004158502454526, 0.6066069031752569, 0.3035893822706974], 
             UndirectedEdge[169, 361] -> 
             RGBColor[
              0.4334163894448813, 0.5497182254001022, 0.948867451343103], 
             UndirectedEdge[65, 341] -> 
             RGBColor[
              0.31291881126268356`, 0.4399641129231123, 0.9413609829619669], 
             UndirectedEdge[46, 353] -> 
             RGBColor[
              0.8993981375114619, 0.9180011012561393, 0.7445005138120175], 
             UndirectedEdge[279, 300] -> 
             RGBColor[
              0.1975989582339537, 0.32501941197441453`, 0.9345643403987369], 
             UndirectedEdge[203, 358] -> 
             RGBColor[
              0.29380332632948314`, 0.42601947816165614`, 0.9400473143533797],
              UndirectedEdge[81, 243] -> 
             RGBColor[
              0.2302749655066254, 0.3593639673965138, 0.9364251906730947], 
             UndirectedEdge[176, 320] -> 
             RGBColor[
              0.18495626411433608`, 0.3117311388615913, 0.9338443576718145], 
             UndirectedEdge[112, 248] -> 
             RGBColor[
              0.18167669359362687`, 0.3082841023075451, 0.9336575909823499], 
             UndirectedEdge[58, 179] -> 
             RGBColor[
              0.21000836012355356`, 0.3380624801619072, 0.9352710374782847], 
             UndirectedEdge[23, 213] -> 
             RGBColor[
              0.2686665233533321, 0.39817491739397315`, 0.9386679570758016], 
             UndirectedEdge[243, 326] -> 
             RGBColor[
              0.23648276332684243`, 0.36588875650267677`, 0.9367787155753422],
              UndirectedEdge[269, 377] -> 
             RGBColor[
              0.30404872534557215`, 0.4327759904647185, 0.9407776755353809], 
             UndirectedEdge[222, 363] -> 
             RGBColor[
              0.6628066494410058, 0.7309294373629389, 0.9563828644799877], 
             UndirectedEdge[30, 341] -> 
             RGBColor[
              0.22502124710185, 0.35384197624810876`, 0.9361259991821227], 
             UndirectedEdge[23, 348] -> 
             RGBColor[
              0.20651189165865158`, 0.3343874701163905, 0.93507191877177], 
             UndirectedEdge[16, 25] -> 
             RGBColor[
              0.2964577597678131, 0.4238211990721158, 0.9403811249327455], 
             UndirectedEdge[25, 62] -> 
             RGBColor[
              0.6778828449272916, 0.740272939600058, 0.8649535953688089], 
             UndirectedEdge[16, 388] -> 
             RGBColor[
              0.24986758553696356`, 0.3799570532922577, 0.9375409613991386], 
             UndirectedEdge[207, 372] -> 
             RGBColor[
              0.18573202091371066`, 0.31254650844355597`, 0.9338885358739095],
              UndirectedEdge[249, 279] -> 
             RGBColor[
              0.19132944320701362`, 0.3184297541708887, 0.934207300792869], 
             UndirectedEdge[151, 267] -> 
             RGBColor[
              0.20258817055551906`, 0.33026339045871145`, 0.9348484686595718],
              UndirectedEdge[185, 252] -> 
             RGBColor[
              0.1992454681560438, 0.3267499982972898, 0.9346581067030068], 
             UndirectedEdge[218, 382] -> 
             RGBColor[
              0.44118615700326724`, 0.5536508374874307, 0.9501354004808935], 
             UndirectedEdge[284, 334] -> 
             RGBColor[
              0.8500382234662116, 0.8370769008965131, 0.6373182165494112], 
             UndirectedEdge[145, 235] -> 
             RGBColor[
              0.22156110310920424`, 0.35020514552603776`, 0.9359289491005658],
              UndirectedEdge[78, 302] -> 
             RGBColor[
              0.2075835767828424, 0.33551387913067643`, 0.9351329496541767], 
             UndirectedEdge[235, 335] -> 
             RGBColor[
              0.19575670920923333`, 0.32308309144409886`, 0.9344594270421422],
              UndirectedEdge[21, 109] -> 
             RGBColor[
              0.1897091064701492, 0.31672667752516137`, 0.9341150250127779], 
             UndirectedEdge[283, 389] -> 
             RGBColor[
              0.9625229099161214, 0.8777511540326326, 0.378485405341739], 
             UndirectedEdge[91, 395] -> 
             RGBColor[
              0.5156283955691132, 0.6172519539462964, 0.9551211142984581], 
             UndirectedEdge[240, 374] -> 
             RGBColor[
              0.18148468566837106`, 0.3080822898040957, 0.933646656415057], 
             UndirectedEdge[301, 339] -> 
             RGBColor[
              0.3159128215006708, 0.4426058768171399, 0.9415499827250514], 
             UndirectedEdge[303, 353] -> 
             RGBColor[
              0.9435949291122223, 0.7996173553563373, 0.3704770005960165], 
             UndirectedEdge[92, 143] -> 
             RGBColor[
              0.20163694443753327`, 0.3292635914974891, 0.9347942977393655], 
             UndirectedEdge[53, 394] -> 
             RGBColor[
              0.38011496144870427`, 0.5036582072985654, 0.9454415671144167], 
             UndirectedEdge[139, 345] -> 
             RGBColor[
              0.5675136417908162, 0.652851509744995, 0.962127956401694], 
             UndirectedEdge[224, 393] -> 
             RGBColor[
              0.6098596540697332, 0.6929310009621534, 0.9632633563282622], 
             UndirectedEdge[175, 204] -> 
             RGBColor[
              0.1850387535749342, 0.31181784051481387`, 0.9338490553245634], 
             UndirectedEdge[131, 293] -> 
             RGBColor[
              0.5641203291112874, 0.6506070149001673, 0.9616718364273125], 
             UndirectedEdge[166, 383] -> 
             RGBColor[
              0.3017459947622442, 0.42990132159861427`, 0.9406631745250644], 
             UndirectedEdge[92, 348] -> 
             RGBColor[
              0.2027372639690243, 0.3304200970893739, 0.9348569593089071], 
             UndirectedEdge[212, 289] -> 
             RGBColor[
              0.5259969557430033, 0.6260670504218144, 0.9558275536278764], 
             UndirectedEdge[161, 214] -> 
             RGBColor[
              0.8792338615689066, 0.5445109956801907, 0.22094211265521246`], 
             UndirectedEdge[124, 386] -> 
             RGBColor[
              0.28427277786616933`, 0.41305129154365816`, 0.9396126134014054],
              UndirectedEdge[227, 350] -> 
             RGBColor[
              0.3112685553301875, 0.44081365131394507`, 0.9411723881594869], 
             UndirectedEdge[258, 279] -> 
             RGBColor[
              0.2183447678357952, 0.34682457322625027`, 0.9357457835648868], 
             UndirectedEdge[63, 103] -> 
             RGBColor[
              0.19205709543901506`, 0.31919456280253833`, 0.9342487395110164],
              UndirectedEdge[291, 336] -> 
             RGBColor[
              0.21513079622652476`, 0.34344648528733734`, 0.9355627526363838],
              UndirectedEdge[292, 400] -> 
             RGBColor[
              0.8203663291701224, 0.1575501073497178, 0.16713612585477525`], 
             UndirectedEdge[149, 300] -> 
             RGBColor[
              0.20324360298345337`, 0.33095229149728655`, 0.9348857945667173],
              UndirectedEdge[356, 364] -> 
             RGBColor[
              0.9333609520587287, 0.8423137522801358, 0.6164503768813724], 
             UndirectedEdge[100, 167] -> 
             RGBColor[
              0.3117593370391954, 0.4377082442608893, 0.941332929144121], 
             UndirectedEdge[334, 391] -> 
             RGBColor[
              0.8668933379781074, 0.3968385652016415, 0.21131639439549801`], 
             UndirectedEdge[309, 323] -> 
             RGBColor[
              0.5589942800594222, 0.6511253403818711, 0.9592466420721857], 
             UndirectedEdge[8, 202] -> 
             RGBColor[
              0.2915950820053508, 0.42207290253936436`, 0.9399810782169516], 
             UndirectedEdge[127, 380] -> 
             RGBColor[
              0.529875465248763, 0.6249265943110206, 0.9578049379836415], 
             UndirectedEdge[130, 151] -> 
             RGBColor[
              0.211637861675412, 0.3397751896092761, 0.9353638351810314], 
             UndirectedEdge[335, 355] -> 
             RGBColor[
              0.20320238953001776`, 0.3309089735446419, 0.934883447521514], 
             UndirectedEdge[117, 395] -> 
             RGBColor[
              0.49860624010091514`, 0.6034326012978481, 0.9537810678657916], 
             UndirectedEdge[256, 310] -> 
             RGBColor[
              0.8817791092522581, 0.4669114753460718, 0.37441947014658894`], 
             UndirectedEdge[362, 365] -> 
             RGBColor[
              0.5486439436435668, 0.6379198705336546, 0.9602843667734056], 
             UndirectedEdge[163, 342] -> 
             RGBColor[
              0.18272416673891645`, 0.30938506299687774`, 0.9337172430283764],
              UndirectedEdge[125, 288] -> 
             RGBColor[
              0.2031660717843796, 0.3308708012912981, 0.9348813792796271], 
             UndirectedEdge[161, 253] -> 
             RGBColor[
              0.8433103782733695, 0.3117402164434911, 0.18823933356517306`], 
             UndirectedEdge[12, 211] -> 
             RGBColor[
              0.23763726784270695`, 0.3671022139486645, 0.9368444628995842], 
             UndirectedEdge[107, 152] -> 
             RGBColor[
              0.2119625047523057, 0.3401164100666513, 0.9353823231239942], 
             UndirectedEdge[183, 291] -> 
             RGBColor[
              0.1920722404266596, 0.31921048114480044`, 0.9342496019956579], 
             UndirectedEdge[149, 299] -> 
             RGBColor[
              0.19935795159879743`, 0.32686822552748607`, 0.9346645124686672],
              UndirectedEdge[57, 284] -> 
             RGBColor[
              0.544081909913294, 0.6364040523835073, 0.9590603762420349], 
             UndirectedEdge[230, 279] -> 
             RGBColor[
              0.2100811442778375, 0.33813898092284156`, 0.9352751824281966], 
             UndirectedEdge[186, 374] -> 
             RGBColor[
              0.19510883243877694`, 0.3224021318805894, 0.9344225314185126], 
             UndirectedEdge[30, 175] -> 
             RGBColor[
              0.19541782934736363`, 0.32272690722304953`, 0.9344401283353366],
              UndirectedEdge[261, 327] -> 
             RGBColor[
              0.1874834373807122, 0.31438735819659225`, 0.9339882764507168], 
             UndirectedEdge[271, 333] -> 
             RGBColor[
              0.8645940127585953, 0.4248527314211257, 0.4322347939799689], 
             UndirectedEdge[199, 247] -> 
             RGBColor[
              0.8744710807180455, 0.41938916470165666`, 0.38827169323511157`],
              UndirectedEdge[99, 223] -> 
             RGBColor[
              0.8735329143735617, 0.6106862837337387, 0.46633619385844605`], 
             UndirectedEdge[200, 367] -> 
             RGBColor[
              0.19007010120853718`, 0.31710610588359545`, 0.9341355831290852],
              UndirectedEdge[111, 400] -> 
             RGBColor[
              0.8251131291830741, 0.19403609231029295`, 0.17168166690792155`],
              UndirectedEdge[277, 390] -> 
             RGBColor[
              0.19904871949657826`, 0.326543202981606, 0.9346469021579138], 
             UndirectedEdge[79, 298] -> 
             RGBColor[
              0.20225845525357178`, 0.3299168387712073, 0.934829691860896], 
             UndirectedEdge[96, 388] -> 
             RGBColor[
              0.24120538255957147`, 0.37085252874762864`, 0.937047661754157], 
             UndirectedEdge[153, 175] -> 
             RGBColor[
              0.19789401206423968`, 0.32532953225753836`, 0.9345811432778787],
              UndirectedEdge[127, 331] -> 
             RGBColor[
              0.29016880316487315`, 0.419484905671203, 0.9399397232478413], 
             UndirectedEdge[6, 93] -> 
             RGBColor[
              0.6343460318717724, 0.7075322117954237, 0.9679330421391619], 
             UndirectedEdge[76, 239] -> 
             RGBColor[
              0.3950361568987507, 0.5127344732289232, 0.94688347760877], 
             UndirectedEdge[333, 337] -> 
             RGBColor[
              0.9553778772118539, 0.9662414744033965, 0.9604177939535141], 
             UndirectedEdge[253, 332] -> 
             RGBColor[
              0.8227299040516889, 0.17571757961455517`, 0.16939948783063935`],
              UndirectedEdge[31, 400] -> 
             RGBColor[
              0.8761629417845124, 0.4432480415757216, 0.4160548316610515], 
             UndirectedEdge[39, 149] -> 
             RGBColor[
              0.2042501787734501, 0.33201026647316434`, 0.9349431175688622], 
             UndirectedEdge[49, 335] -> 
             RGBColor[
              0.1909811618412971, 0.3180636883732066, 0.9341874666843275], 
             UndirectedEdge[57, 236] -> 
             RGBColor[
              0.4289674540866987, 0.5444426167036535, 0.9489769174045849], 
             UndirectedEdge[76, 323] -> 
             RGBColor[
              0.3517784337991403, 0.4767281281704481, 0.9437233665376588], 
             UndirectedEdge[2, 210] -> 
             RGBColor[
              0.223753059772891, 0.352509030957652, 0.9360537777898534], 
             UndirectedEdge[25, 395] -> 
             RGBColor[
              0.4013213562160271, 0.522026120581628, 0.946792819836912], 
             UndirectedEdge[62, 91] -> 
             RGBColor[
              0.7921898842803778, 0.8354987729647263, 0.873281889830355], 
             UndirectedEdge[148, 313] -> 
             RGBColor[
              0.27058528986872044`, 0.4017326741232574, 0.9387208040117352], 
             UndirectedEdge[98, 163] -> 
             RGBColor[
              0.18615149755953203`, 0.3129874049946697, 0.933912424448329], 
             UndirectedEdge[271, 292] -> 
             RGBColor[
              0.8198324633952027, 0.15344658106221012`, 0.16662489538579692`],
              UndirectedEdge[148, 228] -> 
             RGBColor[
              0.2402804897849437, 0.36988040779990605`, 0.9369949904788982], 
             UndirectedEdge[105, 333] -> 
             RGBColor[
              0.969539411680839, 0.9766186640035739, 0.9281855313871071], 
             UndirectedEdge[9, 65] -> 
             RGBColor[
              0.531426491162083, 0.6277150215031269, 0.9572921727453987], 
             UndirectedEdge[129, 337] -> 
             RGBColor[
              0.8652171818184992, 0.4222331115031051, 0.43000213610996785`], 
             UndirectedEdge[62, 323] -> 
             RGBColor[
              0.7062128595771804, 0.7648109743818534, 0.8667587588510515], 
             UndirectedEdge[286, 290] -> 
             RGBColor[
              0.28938656912218486`, 0.4203385400712017, 0.9398338164907357], 
             UndirectedEdge[96, 261] -> 
             RGBColor[
              0.20041641876701294`, 0.3279807416319751, 0.9347247906080353], 
             UndirectedEdge[48, 86] -> 
             RGBColor[
              0.23801910122574216`, 0.3675035450438693, 0.9368662077458763], 
             UndirectedEdge[137, 328] -> 
             RGBColor[
              0.2619981545019592, 0.39270705039696285`, 0.9382317793561266], 
             UndirectedEdge[110, 212] -> 
             RGBColor[
              0.715371093239261, 0.7768498811487758, 0.9728708007300837], 
             UndirectedEdge[163, 272] -> 
             RGBColor[
              0.18785278804211375`, 0.3147755691599099, 0.9340093104244782], 
             UndirectedEdge[245, 396] -> 
             RGBColor[
              0.1896460602736138, 0.31666041197524286`, 0.9341114346251538], 
             UndirectedEdge[25, 37] -> 
             RGBColor[
              0.3241466699483991, 0.4529239992502145, 0.9419579674054581], 
             UndirectedEdge[79, 373] -> 
             RGBColor[
              0.19851817498261992`, 0.32598556705897075`, 0.9346166884327141],
              UndirectedEdge[34, 43] -> 
             RGBColor[
              0.18881744465394812`, 0.3157894844217095, 0.9340642461914408], 
             UndirectedEdge[100, 358] -> 
             RGBColor[
              0.33265464447686266`, 0.4596705372168882, 0.942522885990859], 
             UndirectedEdge[273, 394] -> 
             RGBColor[
              0.4408354922328445, 0.55433085165707, 0.9498412454842259], 
             UndirectedEdge[89, 189] -> 
             RGBColor[
              0.23269978806740765`, 0.361912609650526, 0.9365632807307278], 
             UndirectedEdge[268, 299] -> 
             RGBColor[
              0.18802492021905656`, 0.3149564909916871, 0.9340191130973085], 
             UndirectedEdge[143, 272] -> 
             RGBColor[
              0.19777740595295248`, 0.3252069718413211, 0.9345745027323441], 
             UndirectedEdge[339, 382] -> 
             RGBColor[
              0.3520267531654626, 0.47932961303801835`, 0.943651811320036], 
             UndirectedEdge[111, 223] -> 
             RGBColor[
              0.8374801650249903, 0.28824382747239297`, 0.1834910422728131], 
             UndirectedEdge[71, 131] -> 
             RGBColor[
              0.8919073913712897, 0.9158173378862382, 0.9591371203789343], 
             UndirectedEdge[114, 370] -> 
             RGBColor[
              0.18611224246754757`, 0.3129461454040774, 0.9339101889289132], 
             UndirectedEdge[4, 125] -> 
             RGBColor[
              0.196721601742191, 0.3240972546739574, 0.9345143762444637], 
             UndirectedEdge[246, 251] -> 
             RGBColor[
              0.20081373075853814`, 0.3283983417261034, 0.9347474169381822], 
             UndirectedEdge[30, 229] -> 
             RGBColor[
              0.19931037008134544`, 0.32681821433580155`, 0.9346618027716389],
              UndirectedEdge[115, 366] -> 
             RGBColor[
              0.9742039651565302, 0.9239012646538212, 0.3974339190185809], 
             UndirectedEdge[89, 270] -> 
             RGBColor[
              0.22008543635339983`, 0.34865412620301106`, 0.935844912061876], 
             UndirectedEdge[197, 369] -> 
             RGBColor[
              0.18585850163943218`, 0.31267944770563044`, 0.933895738764128], 
             UndirectedEdge[276, 301] -> 
             RGBColor[
              0.3144566810509267, 0.44134464114731864`, 0.9414571987432081], 
             UndirectedEdge[69, 188] -> 
             RGBColor[
              0.42431357927468827`, 0.535650894850094, 0.9492658859927827], 
             UndirectedEdge[191, 225] -> 
             RGBColor[
              0.19624559498378968`, 0.32359694139030604`, 0.9344872683637615],
              UndirectedEdge[223, 247] -> 
             RGBColor[
              0.8452571321859585, 0.34717028337180467`, 0.19090496268508764`],
              UndirectedEdge[72, 86] -> 
             RGBColor[
              0.3668179912534385, 0.4880512045533021, 0.9448235654131886], 
             UndirectedEdge[19, 85] -> 
             RGBColor[
              0.19070082938217475`, 0.3177690411845645, 0.9341715021654952], 
             UndirectedEdge[320, 398] -> 
             RGBColor[
              0.182257588923795, 0.30889466013044303`, 0.9336906721120455], 
             UndirectedEdge[249, 300] -> 
             RGBColor[
              0.18989148665345995`, 0.3169183706613924, 0.9341254112944102], 
             UndirectedEdge[18, 319] -> 
             RGBColor[
              0.8858082059273583, 0.49573930437115404`, 0.26211860751784904`],
              UndirectedEdge[6, 273] -> 
             RGBColor[
              0.7251045855702409, 0.7842222818473898, 0.9742467167674911], 
             UndirectedEdge[158, 348] -> 
             RGBColor[
              0.1961222229924388, 0.3234672696051602, 0.9344802425113666], 
             UndirectedEdge[61, 228] -> 
             RGBColor[
              0.220637096263315, 0.34923395574559046`, 0.935876328277638], 
             UndirectedEdge[70, 260] -> 
             RGBColor[
              0.19294770058427305`, 0.3201306452778321, 0.9342994581565066], 
             UndirectedEdge[144, 305] -> 
             RGBColor[
              0.4396583364184836, 0.550769790541102, 0.9502316306235659], 
             UndirectedEdge[165, 351] -> 
             RGBColor[
              0.26754769340127105`, 0.39846518644420825`, 0.9385505554925828],
              UndirectedEdge[132, 370] -> 
             RGBColor[
              0.189210358194615, 0.3162024614651078, 0.9340866220363182], 
             UndirectedEdge[104, 145] -> 
             RGBColor[
              0.2369611402467977, 0.36639156097639836`, 0.9368059584332384], 
             UndirectedEdge[207, 231] -> 
             RGBColor[
              0.1913619669815575, 0.3184639387200607, 0.9342091529737147], 
             UndirectedEdge[21, 249] -> 
             RGBColor[
              0.19014493822452405`, 0.31718476433233855`, 0.9341398449864342],
              UndirectedEdge[7, 93] -> 
             RGBColor[
              0.29873862778538124`, 0.4282001700379434, 0.9404384596617476], 
             UndirectedEdge[140, 255] -> 
             RGBColor[
              0.390267723092427, 0.5124520191417203, 0.9460884921086202], 
             UndirectedEdge[100, 157] -> 
             RGBColor[
              0.31728677632069113`, 0.4435179334056334, 0.9416477086340886], 
             UndirectedEdge[42, 178] -> 
             RGBColor[
              0.18344665505298052`, 0.31014444402336394`, 0.9337583876690367],
              UndirectedEdge[115, 195] -> 
             RGBColor[
              0.6898630728334411, 0.7009647207638414, 0.6155071113240207], 
             UndirectedEdge[281, 394] -> 
             RGBColor[
              0.3781881603711747, 0.5019893090490473, 0.9453187930535599], 
             UndirectedEdge[215, 224] -> 
             RGBColor[
              0.6019092601655756, 0.6867200928189938, 0.9624709353645509], 
             UndirectedEdge[99, 222] -> 
             RGBColor[
              0.9266267914902193, 0.9439342403679507, 0.9791054495248444], 
             UndirectedEdge[55, 284] -> 
             RGBColor[
              0.7718010949853338, 0.8216561483989014, 0.9778895783229857], 
             UndirectedEdge[32, 337] -> 
             RGBColor[
              0.8666723181676234, 0.43341792712728777`, 0.43139557632123066`],
              UndirectedEdge[172, 399] -> 
             RGBColor[
              0.369499573099037, 0.49446369145501556`, 0.9447651639555954], 
             UndirectedEdge[267, 346] -> 
             RGBColor[
              0.20049511025135958`, 0.32806345137135173`, 0.9347292719716551],
              UndirectedEdge[222, 393] -> 
             RGBColor[
              0.8365296253571944, 0.8728854021704904, 0.9703016768071477], 
             UndirectedEdge[116, 179] -> 
             RGBColor[
              0.23341719737643146`, 0.3626666523206874, 0.9366041361295647], 
             UndirectedEdge[120, 360] -> 
             RGBColor[
              0.5376516098803733, 0.6341093662239545, 0.9572645433190765], 
             UndirectedEdge[144, 222] -> 
             RGBColor[
              0.7661723613566251, 0.8169857716290115, 0.9639290713689532], 
             UndirectedEdge[237, 307] -> 
             RGBColor[
              0.1806275543927051, 0.307181390488109, 0.9335978440569198], 
             UndirectedEdge[18, 144] -> 
             RGBColor[
              0.7868965412101618, 0.8286865484723305, 0.6945647496408425], 
             UndirectedEdge[309, 365] -> 
             RGBColor[
              0.5016918379873817, 0.6012405287458232, 0.9556046196739707], 
             UndirectedEdge[189, 241] -> 
             RGBColor[
              0.2570425573000169, 0.3874984035347115, 0.937949565426625], 
             UndirectedEdge[268, 370] -> 
             RGBColor[
              0.18660341497029534`, 0.3134623988466007, 0.9339381604763201], 
             UndirectedEdge[336, 359] -> 
             RGBColor[
              0.2802453493603669, 0.4103194523243253, 0.9393282894277089], 
             UndirectedEdge[115, 123] -> 
             RGBColor[
              0.8804744990263506, 0.5083985248696827, 0.22021983203269263`], 
             UndirectedEdge[6, 394] -> 
             RGBColor[
              0.6418942074247149, 0.7140700620770483, 0.9684140052108057], 
             UndirectedEdge[259, 353] -> 
             RGBColor[
              0.9443422105725244, 0.9537215111738743, 0.7488183078429457], 
             UndirectedEdge[98, 348] -> 
             RGBColor[
              0.19717643500186177`, 0.3245753132679656, 0.9345402783257364], 
             UndirectedEdge[145, 349] -> 
             RGBColor[
              0.2241439081408365, 0.35291983737358057`, 0.9360760360261996], 
             UndirectedEdge[287, 292] -> 
             RGBColor[
              0.8180432948668896, 0.1396942477349479, 0.16491158558250754`], 
             UndirectedEdge[53, 69] -> 
             RGBColor[
              0.4877113731208531, 0.5936081076641104, 0.9531940365593021], 
             UndirectedEdge[236, 284] -> 
             RGBColor[
              0.6247504035752902, 0.7047458827568778, 0.9646230139836673], 
             UndirectedEdge[119, 146] -> 
             RGBColor[
              0.2194595639056427, 0.3479962945778132, 0.9358092695518716], 
             UndirectedEdge[198, 310] -> 
             RGBColor[
              0.8272769818270227, 0.4253245421128263, 0.4431946931706203], 
             UndirectedEdge[198, 384] -> 
             RGBColor[
              0.8811911535814985, 0.820358675063078, 0.6244757857174054], 
             UndirectedEdge[111, 292] -> 
             RGBColor[
              0.8242386846136205, 0.1873147281654189, 0.1708442978006689], 
             UndirectedEdge[40, 295] -> 
             RGBColor[
              0.1896748892459051, 0.31669071305298346`, 0.934113076392477], 
             UndirectedEdge[5, 270] -> 
             RGBColor[
              0.19738135324155764`, 0.32479069533045285`, 0.9345519481163376],
              UndirectedEdge[104, 355] -> 
             RGBColor[
              0.21609483282429037`, 0.34445974887503966`, 0.9356176530944622],
              UndirectedEdge[356, 360] -> 
             RGBColor[
              0.804069535005691, 0.8476283188054337, 0.97217824926772], 
             UndirectedEdge[42, 398] -> 
             RGBColor[
              0.18234639975021955`, 0.30898800593994685`, 0.9336957297572264],
              UndirectedEdge[153, 211] -> 
             RGBColor[
              0.21907020233692062`, 0.34758705088213704`, 0.9357870959865418],
              UndirectedEdge[223, 385] -> 
             RGBColor[
              0.9042834117433322, 0.6325667276310734, 0.3474148618138784], 
             UndirectedEdge[144, 361] -> 
             RGBColor[
              0.4954156444114053, 0.6000520136165334, 0.9537482598048219], 
             UndirectedEdge[216, 229] -> 
             RGBColor[
              0.2068690748506942, 0.33476289229794964`, 0.9350922598261517], 
             UndirectedEdge[161, 389] -> 
             RGBColor[
              0.9363348090239618, 0.7668148008617284, 0.3570460900069422], 
             UndirectedEdge[313, 340] -> 
             RGBColor[
              0.2780047879810863, 0.40953103706270466`, 0.9391433334530706], 
             UndirectedEdge[241, 380] -> 
             RGBColor[
              0.5006467932710101, 0.5970366894503322, 0.9560367412293518], 
             UndirectedEdge[258, 281] -> 
             RGBColor[
              0.318201913769557, 0.44345916858997797`, 0.9417371947060786], 
             UndirectedEdge[344, 346] -> 
             RGBColor[
              0.19749434605120672`, 0.3249094579375519, 0.9345583828896893], 
             UndirectedEdge[79, 205] -> 
             RGBColor[
              0.19210249208707042`, 0.3192422775579583, 0.9342513247829649], 
             UndirectedEdge[227, 306] -> 
             RGBColor[
              0.248145898473511, 0.3781474510273044, 0.9374429138678827], 
             UndirectedEdge[43, 381] -> 
             RGBColor[
              0.19202300109929993`, 0.3191587274897918, 0.9342467978888077], 
             UndirectedEdge[98, 143] -> 
             RGBColor[
              0.19607611547037074`, 0.3234188076760809, 0.9344776167561948], 
             UndirectedEdge[243, 267] -> 
             RGBColor[
              0.2144789920516021, 0.342761397772722, 0.9355256333528797], 
             UndirectedEdge[58, 152] -> 
             RGBColor[
              0.19702370192683044`, 0.32441478112227146`, 0.9345315804030616],
              UndirectedEdge[376, 397] -> 
             RGBColor[
              0.32517928194563106`, 0.4539892085157613, 0.9420175102408045], 
             UndirectedEdge[114, 279] -> 
             RGBColor[
              0.19285735565451845`, 0.32003568702846064`, 0.9342943131464105],
              UndirectedEdge[148, 218] -> 
             RGBColor[
              0.40841467546891774`, 0.5204402282772255, 0.9482239194761258], 
             UndirectedEdge[55, 366] -> 
             RGBColor[
              0.8985186945130963, 0.9173414029032505, 0.7466017890196988], 
             UndirectedEdge[99, 361] -> 
             RGBColor[
              0.6558700745449995, 0.7270004823554725, 0.968924637960713], 
             UndirectedEdge[97, 169] -> 
             RGBColor[
              0.37794173807367953`, 0.5007330923555633, 0.945366919038301], 
             UndirectedEdge[43, 250] -> 
             RGBColor[
              0.19420867686654147`, 0.32145601130101026`, 0.9343712688903346],
              UndirectedEdge[112, 177] -> 
             RGBColor[
              0.18091855533538903`, 0.3074872509293952, 0.9336144161301083], 
             UndirectedEdge[255, 356] -> 
             RGBColor[
              0.6597861746771188, 0.7286564919053182, 0.9611997608615672], 
             UndirectedEdge[210, 328] -> 
             RGBColor[
              0.2385161810587667, 0.36802600746505976`, 0.9368945157070033], 
             UndirectedEdge[91, 221] -> 
             RGBColor[
              0.48124384050183955`, 0.5874697805650118, 0.9529301608546397], 
             UndirectedEdge[32, 345] -> 
             RGBColor[
              0.8237071541033182, 0.3995245104435039, 0.439981384340312], 
             UndirectedEdge[210, 258] -> 
             RGBColor[
              0.24166666616429894`, 0.371337367063267, 0.9370739311730383], 
             UndirectedEdge[189, 359] -> 
             RGBColor[
              0.2794316818374808, 0.4094642361682714, 0.9392819522659938], 
             UndirectedEdge[164, 258] -> 
             RGBColor[
              0.22632269335272776`, 0.3552098787742395, 0.936200114620793], 
             UndirectedEdge[354, 374] -> 
             RGBColor[
              0.18986888322413037`, 0.3168946130240269, 0.9341241240625486], 
             UndirectedEdge[235, 322] -> 
             RGBColor[
              0.1941801601361397, 0.32142603840929285`, 0.934369644904725], 
             UndirectedEdge[147, 392] -> 
             RGBColor[
              0.2251386082236323, 0.35396533022822685`, 0.9361326827243879], 
             UndirectedEdge[123, 283] -> 
             RGBColor[
              0.8727460560084327, 0.47775782365460545`, 0.2140013453706027], 
             UndirectedEdge[202, 239] -> 
             RGBColor[
              0.4173644057485659, 0.5344604832455712, 0.9482188359733204], 
             UndirectedEdge[180, 249] -> 
             RGBColor[
              0.18602314959306215`, 0.3128525031441788, 0.9339051152215123], 
             UndirectedEdge[2, 197] -> 
             RGBColor[
              0.1965684920257088, 0.3239363266542179, 0.9345056568726156], 
             UndirectedEdge[174, 329] -> 
             RGBColor[
              0.34008730347088106`, 0.4646976118288939, 0.9430481418570962], 
             UndirectedEdge[193, 242] -> 
             RGBColor[
              0.5891633460741419, 0.6714315101447773, 0.963657200278417], 
             UndirectedEdge[58, 160] -> 
             RGBColor[
              0.1942495004305084, 0.32149891945510295`, 0.9343735937319094], 
             UndirectedEdge[50, 137] -> 
             RGBColor[
              0.2618861891426283, 0.3925893677052923, 0.9382254030945505], 
             UndirectedEdge[326, 383] -> 
             RGBColor[
              0.2999445651565369, 0.428007904865782, 0.9405605857739958], 
             UndirectedEdge[157, 238] -> 
             RGBColor[
              0.22387178003127423`, 0.3526338134765119, 0.9360605387329375], 
             UndirectedEdge[243, 346] -> 
             RGBColor[
              0.21741007073096835`, 0.3458421473058579, 0.9356925539475274], 
             UndirectedEdge[235, 355] -> 
             RGBColor[
              0.2006947956866969, 0.3282733334246791, 0.9347406437617896], 
             UndirectedEdge[44, 135] -> 
             RGBColor[
              0.2818343394924019, 0.41109593137624006`, 0.9394515009810677], 
             UndirectedEdge[33, 206] -> 
             RGBColor[
              0.33773890435239673`, 0.4612073947457289, 0.942951820792434], 
             UndirectedEdge[88, 263] -> 
             RGBColor[
              0.3661139704738488, 0.49089201133024934`, 0.9445728421053426], 
             UndirectedEdge[82, 399] -> 
             RGBColor[
              0.5595672102027384, 0.6489717323660277, 0.9604046913379707], 
             UndirectedEdge[271, 287] -> 
             RGBColor[
              0.819108168528313, 0.14787933332726222`, 0.1659313098032894], 
             UndirectedEdge[31, 223] -> 
             RGBColor[
              0.9008970134683449, 0.6316635118999215, 0.4396735823908346], 
             UndirectedEdge[108, 376] -> 
             RGBColor[
              0.29627129186653856`, 0.4287302908095537, 0.9401835838264763], 
             UndirectedEdge[301, 361] -> 
             RGBColor[
              0.3297210809288895, 0.45456589711056455`, 0.9424298328056531], 
             UndirectedEdge[80, 388] -> 
             RGBColor[
              0.23694403524812552`, 0.36637358253827423`, 0.9368049843288686],
              UndirectedEdge[47, 136] -> 
             RGBColor[
              0.18182023692588944`, 0.308434975450926, 0.9336657655627689], 
             UndirectedEdge[39, 50] -> 
             RGBColor[
              0.21465093660737516`, 0.342942122402754, 0.9355354253409618], 
             UndirectedEdge[120, 389] -> 
             RGBColor[
              0.7028354936755193, 0.7597247670512044, 0.7201987400202577], 
             UndirectedEdge[28, 106] -> 
             RGBColor[
              0.18905752987434937`, 0.31604182921063345`, 0.9340779186895682],
              UndirectedEdge[97, 326] -> 
             RGBColor[
              0.27009816450947055`, 0.40122067448515425`, 0.9386930629431633],
              UndirectedEdge[195, 242] -> 
             RGBColor[
              0.3825084156474021, 0.5057312970269716, 0.9455940758995094], 
             UndirectedEdge[90, 260] -> 
             RGBColor[
              0.20225002842194761`, 0.32990798163687834`, 0.9348292119653014],
              UndirectedEdge[73, 368] -> 
             RGBColor[
              0.19117243294824504`, 0.31826472643389747`, 0.934198359290908], 
             UndirectedEdge[52, 287] -> 
             RGBColor[
              0.8745442200692566, 0.41932367447288343`, 0.3868288304903523], 
             UndirectedEdge[135, 243] -> 
             RGBColor[
              0.2833746021341409, 0.41271484507099976`, 0.9395392166599004], 
             UndirectedEdge[311, 317] -> 
             RGBColor[
              0.19555015626042008`, 0.32286599119868276`, 0.934447664157275], 
             UndirectedEdge[6, 10] -> 
             RGBColor[
              0.8706991660194285, 0.5355001809409162, 0.45679225765188536`], 
             UndirectedEdge[363, 383] -> 
             RGBColor[
              0.36642168177165046`, 0.49179777668654956`, 0.9445690434418867],
              UndirectedEdge[227, 346] -> 
             RGBColor[
              0.23870901568862182`, 0.3682286888874592, 0.9369054973539003], 
             UndirectedEdge[157, 341] -> 
             RGBColor[
              0.24810243304135554`, 0.37810176610224144`, 0.9374404385758228],
              UndirectedEdge[18, 310] -> 
             RGBColor[
              0.8818564092931963, 0.4653640637526585, 0.25833436259805964`], 
             UndirectedEdge[37, 96] -> 
             RGBColor[
              0.24798039051581972`, 0.3779734916699602, 0.9374334884345392], 
             UndirectedEdge[218, 222] -> 
             RGBColor[
              0.7556819189936763, 0.8084691579297268, 0.9631032253183853], 
             UndirectedEdge[65, 203] -> 
             RGBColor[
              0.34325183639463963`, 0.4717292211712722, 0.9430926813827534], 
             UndirectedEdge[105, 303] -> 
             RGBColor[
              0.9396161743909813, 0.7997165627600418, 0.5632237947654809], 
             UndirectedEdge[119, 267] -> 
             RGBColor[
              0.21867692760035795`, 0.34717369419895117`, 0.9357646995720923],
              UndirectedEdge[20, 312] -> 
             RGBColor[
              0.4662211223319299, 0.5756731791658605, 0.9516371294428863], 
             UndirectedEdge[285, 324] -> 
             RGBColor[
              0.1849819453905557, 0.31175813151118514`, 0.9338458201825032], 
             UndirectedEdge[16, 302] -> 
             RGBColor[
              0.21182755927874247`, 0.3399745738178992, 0.9353746381789088], 
             UndirectedEdge[65, 313] -> 
             RGBColor[
              0.33055584599709903`, 0.45850175468157234`, 0.9423653859984371],
              UndirectedEdge[280, 392] -> 
             RGBColor[
              0.20599555407739328`, 0.33384476658079454`, 0.9350425141103704],
              UndirectedEdge[1, 357] -> 
             RGBColor[
              0.18390843895748787`, 0.3106298081857918, 0.9337846855792504], 
             UndirectedEdge[26, 177] -> 
             RGBColor[
              0.18182665700375172`, 0.3084417233598157, 0.9336661311767056], 
             UndirectedEdge[69, 293] -> 
             RGBColor[
              0.44347384418172964`, 0.5552917835398956, 0.950375260333012], 
             UndirectedEdge[165, 399] -> 
             RGBColor[
              0.2924581876891166, 0.42004140455849254`, 0.9401378301611192], 
             UndirectedEdge[108, 297] -> 
             RGBColor[
              0.30146181771501923`, 0.43418586257465347`, 0.9404791765948524],
              UndirectedEdge[192, 335] -> 
             RGBColor[
              0.22826537319767345`, 0.3572517584642937, 0.9363107473640253], 
             UndirectedEdge[134, 272] -> 
             RGBColor[
              0.18788317693480855`, 0.3148075098128992, 0.9340110410269609], 
             UndirectedEdge[86, 236] -> 
             RGBColor[
              0.3888676051713017, 0.5059520744556105, 0.9465593917911999], 
             UndirectedEdge[312, 389] -> 
             RGBColor[
              0.7704699076494956, 0.8157404401627024, 0.7252172989695943], 
             UndirectedEdge[156, 245] -> 
             RGBColor[
              0.1983829021548571, 0.32584338674019936`, 0.9346089848452912], 
             UndirectedEdge[153, 168] -> 
             RGBColor[
              0.20180786245057253`, 0.3294432371660213, 0.9348040312673576], 
             UndirectedEdge[118, 150] -> 
             RGBColor[
              0.29792702653421543`, 0.4259677967148573, 0.9404427441608055], 
             UndirectedEdge[195, 255] -> 
             RGBColor[
              0.3994035312970712, 0.5203649970295117, 0.9466706177289421], 
             UndirectedEdge[109, 180] -> 
             RGBColor[
              0.18558731783868732`, 0.3123944163370016, 0.933880295247856], 
             UndirectedEdge[143, 378] -> 
             RGBColor[
              0.21957024665493602`, 0.3481126291650121, 0.9358155727707034], 
             UndirectedEdge[135, 383] -> 
             RGBColor[
              0.3468364039638354, 0.47483399343410504`, 0.9433210868585539], 
             UndirectedEdge[20, 120] -> 
             RGBColor[
              0.3985867083579536, 0.5196575060543626, 0.9466185704935497], 
             UndirectedEdge[149, 230] -> 
             RGBColor[
              0.21572578902733716`, 0.34407186044571364`, 0.935596636596177], 
             UndirectedEdge[16, 77] -> 
             RGBColor[
              0.21295289463759554`, 0.3411573726304365, 0.9354387243628108], 
             UndirectedEdge[168, 238] -> 
             RGBColor[
              0.19942328541058194`, 0.3269368955060745, 0.9346682331325956], 
             UndirectedEdge[104, 335] -> 
             RGBColor[
              0.21115674634682685`, 0.33926950689445945`, 0.9353364363748149],
              UndirectedEdge[79, 232] -> 
             RGBColor[
              0.19470557204870292`, 0.32197827964243614`, 0.9343995663358682],
              UndirectedEdge[47, 299] -> 
             RGBColor[
              0.184696983160691, 0.3114586181399484, 0.9338295920050762], 
             UndirectedEdge[236, 397] -> 
             RGBColor[
              0.4369077612514729, 0.5513201116783387, 0.9494828667557864], 
             UndirectedEdge[33, 118] -> 
             RGBColor[
              0.30201839786374246`, 0.43026808739011524`, 0.9406757417053806],
              UndirectedEdge[51, 79] -> 
             RGBColor[
              0.20012999875823717`, 0.3276796960426744, 0.934708479412256], 
             UndirectedEdge[24, 168] -> 
             RGBColor[
              0.22907306672132033`, 0.35810069556837376`, 0.9363567443153216],
              UndirectedEdge[269, 365] -> 
             RGBColor[
              0.3297101598350657, 0.4597477851420956, 0.9422390562668672], 
             UndirectedEdge[98, 240] -> 
             RGBColor[
              0.18629079266231832`, 0.3131338129795177, 0.9339203570983641], 
             UndirectedEdge[29, 113] -> 
             RGBColor[
              0.1857448284490183, 0.3125599699752089, 0.9338892652440982], 
             UndirectedEdge[330, 398] -> 
             RGBColor[
              0.18475377969358928`, 0.31151831489713266`, 0.9338328264836019],
              UndirectedEdge[43, 265] -> 
             RGBColor[
              0.19684687423849298`, 0.3242289240103058, 0.934521510327804], 
             UndirectedEdge[209, 304] -> 
             RGBColor[
              0.2736580263748165, 0.40496231501391133`, 0.9388957918100511], 
             UndirectedEdge[107, 238] -> 
             RGBColor[
              0.21198166691675951`, 0.34013655071644366`, 0.9353834143809119],
              UndirectedEdge[298, 347] -> 
             RGBColor[
              0.1948950544058417, 0.32217743761366435`, 0.9344103570757931], 
             UndirectedEdge[153, 343] -> 
             RGBColor[
              0.20318561149837056`, 0.330891338769592, 0.9348824920374326], 
             UndirectedEdge[110, 292] -> 
             RGBColor[
              0.8306488126751848, 0.39575026058266666`, 0.4394783494559681], 
             UndirectedEdge[332, 366] -> 
             RGBColor[
              0.8763032983874938, 0.42126726340738674`, 0.2804991753802838], 
             UndirectedEdge[39, 136] -> 
             RGBColor[
              0.19040517985093924`, 0.31745829478197307`, 0.9341546653620656],
              UndirectedEdge[115, 380] -> 
             RGBColor[
              0.8377450255090341, 0.8206060012110092, 0.627750782576732], 
             UndirectedEdge[167, 238] -> 
             RGBColor[
              0.2183443407497785, 0.3468241243317679, 0.9357457592429699], 
             UndirectedEdge[1, 162] -> 
             RGBColor[
              0.18855509271436693`, 0.315513735899136, 0.9340493056365965], 
             UndirectedEdge[128, 243] -> 
             RGBColor[
              0.26764794439082373`, 0.39864533778752814`, 0.9385535265321823],
              UndirectedEdge[196, 366] -> 
             RGBColor[
              0.9187123308959824, 0.9333119446325909, 0.748562723255582], 
             UndirectedEdge[136, 149] -> 
             RGBColor[
              0.19648120536399588`, 0.3238445828384636, 0.9345006860263599], 
             UndirectedEdge[263, 360] -> 
             RGBColor[
              0.48229378308011506`, 0.5855219577186828, 0.9537605973016217], 
             UndirectedEdge[267, 354] -> 
             RGBColor[
              0.19683262012965425`, 0.3242139420381536, 0.9345206985773926], 
             UndirectedEdge[192, 355] -> 
             RGBColor[
              0.233203459675137, 0.36244200044487396`, 0.9365919640836726], 
             UndirectedEdge[24, 100] -> 
             RGBColor[
              0.32394697736880945`, 0.450518226988342, 0.9420269972308946], 
             UndirectedEdge[11, 286] -> 
             RGBColor[
              0.5972181184299319, 0.677195451192008, 0.9647287147159659], 
             UndirectedEdge[71, 110] -> 
             RGBColor[
              0.9113332721380322, 0.9312595378862136, 0.9610025753124077], 
             UndirectedEdge[186, 306] -> 
             RGBColor[
              0.21444053080855624`, 0.3427209725676972, 0.9355234430419865], 
             UndirectedEdge[6, 131] -> 
             RGBColor[
              0.8701371040264215, 0.8993351938028649, 0.9874630507499915], 
             UndirectedEdge[53, 264] -> 
             RGBColor[
              0.3312918681319017, 0.4568612487266348, 0.9424956938321003], 
             UndirectedEdge[83, 118] -> 
             RGBColor[
              0.6542161598297946, 0.7234949587303476, 0.9559255584190995], 
             UndirectedEdge[98, 272] -> 
             RGBColor[
              0.1949500622314218, 0.3222352543260466, 0.9344134896900831], 
             UndirectedEdge[200, 330] -> 
             RGBColor[
              0.1913737687250167, 0.31847634310071005`, 0.9342098250655455], 
             UndirectedEdge[101, 389] -> 
             RGBColor[
              0.9003569231030979, 0.6064808639762083, 0.2971755264815594], 
             UndirectedEdge[10, 353] -> 
             RGBColor[
              0.8930646658031626, 0.5501769231578431, 0.29510210612227733`], 
             UndirectedEdge[174, 340] -> 
             RGBColor[
              0.3446138349142821, 0.46945528337457815`, 0.9433059211263948], 
             UndirectedEdge[77, 187] -> 
             RGBColor[
              0.2066496337845954, 0.33453224582411256`, 0.9350797629820713], 
             UndirectedEdge[137, 264] -> 
             RGBColor[
              0.27631179289230656`, 0.4077515918823088, 0.9390469198873264], 
             UndirectedEdge[20, 356] -> 
             RGBColor[
              0.6650046334832713, 0.7331764586358418, 0.9615322764421933], 
             UndirectedEdge[130, 227] -> 
             RGBColor[
              0.24482762812914852`, 0.374659738504888, 0.9372539432807123], 
             UndirectedEdge[24, 150] -> 
             RGBColor[
              0.24929421300339247`, 0.3793544024055562, 0.9375083086815804], 
             UndirectedEdge[282, 339] -> 
             RGBColor[
              0.34849054026782905`, 0.4762667231613163, 0.9434264869611491], 
             UndirectedEdge[69, 93] -> 
             RGBColor[
              0.45767335020652483`, 0.5675906819706489, 0.951280040300782], 
             UndirectedEdge[65, 266] -> 
             RGBColor[
              0.5173579150755038, 0.6167245429391528, 0.9558899485594068], 
             UndirectedEdge[189, 336] -> 
             RGBColor[
              0.23398737474331802`, 0.3632659448846183, 0.936636606887107], 
             UndirectedEdge[191, 322] -> 
             RGBColor[
              0.18956017104754852`, 0.31657013695295677`, 0.934106543360791], 
             UndirectedEdge[297, 376] -> 
             RGBColor[
              0.2913695149854919, 0.423578212516969, 0.9399044348846297], 
             UndirectedEdge[33, 286] -> 
             RGBColor[
              0.2839164063725824, 0.41458905219301934`, 0.9395222988145264], 
             UndirectedEdge[145, 351] -> 
             RGBColor[
              0.2797139568415439, 0.4112527007055903, 0.9392434061971325], 
             UndirectedEdge[83, 141] -> 
             RGBColor[
              0.6533758763039106, 0.7227671473741049, 0.9558720162958637], 
             UndirectedEdge[148, 276] -> 
             RGBColor[
              0.31779913118136904`, 0.44485776815799194`, 0.9416475463334251],
              UndirectedEdge[124, 160] -> 
             RGBColor[
              0.21095706740892387`, 0.3390596316703475, 0.9353250649546998], 
             UndirectedEdge[25, 362] -> 
             RGBColor[
              0.5776163710657185, 0.6632666473879071, 0.9621212256893779], 
             UndirectedEdge[96, 208] -> 
             RGBColor[
              0.25302363918053994`, 0.383274265777015, 0.9377206939851772], 
             UndirectedEdge[240, 272] -> 
             RGBColor[
              0.18799208314490007`, 0.3149219771447579, 0.9340172430745133], 
             UndirectedEdge[25, 182] -> 
             RGBColor[
              0.30289473156223595`, 0.4305868645556383, 0.9407477009537915], 
             UndirectedEdge[101, 380] -> 
             RGBColor[
              0.8094432238137885, 0.5377433942133822, 0.4571339579761315], 
             UndirectedEdge[24, 358] -> 
             RGBColor[
              0.2688894294981841, 0.3999502173500661, 0.9386242272724338], 
             UndirectedEdge[202, 234] -> 
             RGBColor[
              0.28726387007128157`, 0.41752052418196, 0.9397344221047603], 
             UndirectedEdge[17, 62] -> 
             RGBColor[
              0.8823757434978273, 0.4727098560142903, 0.37791307557422715`], 
             UndirectedEdge[24, 211] -> 
             RGBColor[
              0.2463354066076684, 0.3762445092844895, 0.9373398090345058], 
             UndirectedEdge[2, 39] -> 
             RGBColor[
              0.19999978068083032`, 0.3275428285870168, 0.934701063685388], 
             UndirectedEdge[164, 328] -> 
             RGBColor[
              0.22317220824719552`, 0.35189851917603227`, 0.9360206991547579],
              UndirectedEdge[228, 301] -> 
             RGBColor[
              0.2369380396545014, 0.36636728078923275`, 0.9368046428886814], 
             UndirectedEdge[118, 286] -> 
             RGBColor[
              0.33934539796061675`, 0.46834566054302623`, 0.9428437665800653],
              UndirectedEdge[139, 215] -> 
             RGBColor[
              0.5065072627092252, 0.6051273956422916, 0.956064783626883], 
             UndirectedEdge[239, 377] -> 
             RGBColor[
              0.3809157120608543, 0.4978929904163819, 0.9460793391645779], 
             UndirectedEdge[348, 374] -> 
             RGBColor[
              0.19237032800791454`, 0.3195237900925436, 0.9342665776424293], 
             UndirectedEdge[8, 388] -> 
             RGBColor[
              0.26319007599843486`, 0.3939598354619466, 0.938299657522061], 
             UndirectedEdge[249, 370] -> 
             RGBColor[
              0.18458433002004276`, 0.31134021254650546`, 0.9338231765753717],
              UndirectedEdge[61, 285] -> 
             RGBColor[
              0.2007711589524707, 0.32835359605871806`, 0.934744992536806], 
             UndirectedEdge[162, 280] -> 
             RGBColor[
              0.20211294537388308`, 0.32976389866179523`, 0.9348214052885103],
              UndirectedEdge[126, 205] -> 
             RGBColor[
              0.18385657240612066`, 0.31057529315177557`, 0.9337817318558796],
              UndirectedEdge[161, 334] -> 
             RGBColor[
              0.9198789642740572, 0.7116881876157337, 0.2605664067222301], 
             UndirectedEdge[192, 399] -> 
             RGBColor[
              0.3088211273745378, 0.43723989163816773`, 0.941069675369404], 
             UndirectedEdge[69, 281] -> 
             RGBColor[
              0.4857845720433236, 0.5919392094145923, 0.9530712624984452], 
             UndirectedEdge[38, 128] -> 
             RGBColor[
              0.281313846761083, 0.4130090676469258, 0.9393317794552777], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.22265042245962569`, 0.35135008923016664`, 0.9359909842260687],
              UndirectedEdge[145, 355] -> 
             RGBColor[
              0.22900678342998865`, 0.3580310276265808, 0.9363529695799375], 
             UndirectedEdge[23, 139] -> 
             RGBColor[
              0.2594316195520534, 0.3900094594368974, 0.9380856189875776], 
             UndirectedEdge[120, 359] -> 
             RGBColor[
              0.3691186833876108, 0.4941337839310517, 0.9447408939999908], 
             UndirectedEdge[117, 309] -> 
             RGBColor[
              0.6279491492944215, 0.7079937863162957, 0.9644297266188226], 
             UndirectedEdge[19, 167] -> 
             RGBColor[
              0.21765966709879997`, 0.34610448891377266`, 0.9357067680914306],
              UndirectedEdge[26, 285] -> 
             RGBColor[
              0.1832664520031871, 0.30995503919249784`, 0.9337481253719375], 
             UndirectedEdge[166, 169] -> 
             RGBColor[
              0.3512165772923903, 0.4726432539013666, 0.9438449606681389], 
             UndirectedEdge[31, 383] -> 
             RGBColor[
              0.6712879724630387, 0.7362684219408357, 0.9272977112853262], 
             UndirectedEdge[146, 346] -> 
             RGBColor[
              0.20127774655664432`, 0.3288860517502138, 0.9347738419514344], 
             UndirectedEdge[191, 349] -> 
             RGBColor[
              0.1912119313089536, 0.3183062417153429, 0.9342006086641177], 
             UndirectedEdge[212, 362] -> 
             RGBColor[
              0.6845252117813709, 0.7524862898136562, 0.9698671068536907], 
             UndirectedEdge[242, 380] -> 
             RGBColor[
              0.5303903683229951, 0.6253725774741394, 0.9578377471522206], 
             UndirectedEdge[175, 307] -> 
             RGBColor[
              0.18458331869086259`, 0.3113391495754152, 0.933823118981671], 
             UndirectedEdge[140, 193] -> 
             RGBColor[
              0.6221373960333281, 0.6999919748954846, 0.9657582775840088], 
             UndirectedEdge[8, 25] -> 
             RGBColor[
              0.3097802502292844, 0.43782398124180466`, 0.9411398210556678], 
             UndirectedEdge[8, 269] -> 
             RGBColor[
              0.30450100126350144`, 0.4332513611304116, 0.9408034319798247], 
             UndirectedEdge[155, 371] -> 
             RGBColor[
              0.18296643499197385`, 0.3096397022915355, 0.9337310398469844], 
             UndirectedEdge[55, 161] -> 
             RGBColor[
              0.8416418357931794, 0.6962674351181222, 0.6011377684958046], 
             UndirectedEdge[110, 202] -> 
             RGBColor[
              0.590277084299675, 0.6718791600205865, 0.9639661767270546], 
             UndirectedEdge[332, 380] -> 
             RGBColor[
              0.7853306719558296, 0.3524037544455121, 0.43404375108571785`], 
             UndirectedEdge[359, 360] -> 
             RGBColor[
              0.49422258294729215`, 0.5964933259008812, 0.9544972841256812], 
             UndirectedEdge[128, 350] -> 
             RGBColor[
              0.32622360223214686`, 0.4565323538126437, 0.9420240559565443], 
             UndirectedEdge[272, 378] -> 
             RGBColor[
              0.2184441934159871, 0.34692907581497784`, 0.9357514457045917], 
             UndirectedEdge[52, 345] -> 
             RGBColor[
              0.9085391948738575, 0.9277362639462506, 0.9077575254526454], 
             UndirectedEdge[32, 333] -> 
             RGBColor[
              0.8656047551536187, 0.43262174037941703`, 0.4332026820389135], 
             UndirectedEdge[85, 168] -> 
             RGBColor[
              0.18992658867508105`, 0.3169552651117129, 0.9341274103026127], 
             UndirectedEdge[23, 354] -> 
             RGBColor[
              0.20401044687486744`, 0.3317582930478737, 0.9349294651918895], 
             UndirectedEdge[51, 373] -> 
             RGBColor[
              0.1995969758310581, 0.32711945515060364`, 0.9346781245450898], 
             UndirectedEdge[55, 334] -> 
             RGBColor[
              0.8819744590496598, 0.862025730858683, 0.6405013220512796], 
             UndirectedEdge[66, 267] -> 
             RGBColor[
              0.1968456208420638, 0.3242276066111888, 0.9345214389487315], 
             UndirectedEdge[30, 153] -> 
             RGBColor[
              0.2031751711317593, 0.3308803652823261, 0.9348818974739992], 
             UndirectedEdge[179, 290] -> 
             RGBColor[
              0.24217146180405288`, 0.37186793928654055`, 0.9371026785379442],
              UndirectedEdge[178, 200] -> 
             RGBColor[
              0.1885274133225135, 0.31548464310332325`, 0.9340477293361784], 
             UndirectedEdge[340, 358] -> 
             RGBColor[
              0.2744945486553811, 0.4058415529693607, 0.9389434305164055], 
             UndirectedEdge[31, 259] -> 
             RGBColor[
              0.9398415048836066, 0.9536048784389164, 0.9502151803126189], 
             UndirectedEdge[92, 146] -> 
             RGBColor[
              0.20174986693286398`, 0.32938228019978144`, 0.9348007285084208],
              UndirectedEdge[3, 373] -> 
             RGBColor[
              0.21710028788855346`, 0.3455165458971132, 0.9356749122729344], 
             UndirectedEdge[174, 341] -> 
             RGBColor[
              0.3335895874564281, 0.4578681003187137, 0.9426781065425826], 
             UndirectedEdge[248, 260] -> 
             RGBColor[
              0.1859219097416619, 0.3127460936413798, 0.933899349761746], 
             UndirectedEdge[41, 325] -> 
             RGBColor[
              0.2165335134226994, 0.3449208299979239, 0.9356426353055718], 
             UndirectedEdge[66, 346] -> 
             RGBColor[
              0.19977669952143007`, 0.3273083561443247, 0.9346883595433791], 
             UndirectedEdge[53, 142] -> 
             RGBColor[
              0.43838221439814257`, 0.5535604743597381, 0.949310664485988], 
             UndirectedEdge[38, 44] -> 
             RGBColor[
              0.24351959225973108`, 0.37328490987186613`, 0.9371794525730147],
              UndirectedEdge[76, 187] -> 
             RGBColor[
              0.24964108184106412`, 0.37971898354670364`, 0.9375280623487394],
              UndirectedEdge[156, 160] -> 
             RGBColor[
              0.19858358472464382`, 0.32605431684505504`, 0.9346204134207573],
              UndirectedEdge[141, 290] -> 
             RGBColor[
              0.3066482770874609, 0.4352897639120549, 0.9409337172583541], 
             UndirectedEdge[3, 79] -> 
             RGBColor[
              0.21763331081573253`, 0.34607678678918397`, 0.9357052671401005],
              UndirectedEdge[301, 382] -> 
             RGBColor[
              0.2859820358837003, 0.41668133468074653`, 0.9396428195322926], 
             UndirectedEdge[193, 389] -> 
             RGBColor[
              0.9155257058475293, 0.9306524378746825, 0.7386464272151838], 
             UndirectedEdge[189, 291] -> 
             RGBColor[
              0.21431712870363867`, 0.34259126913128346`, 0.9355164154746687],
              UndirectedEdge[161, 196] -> 
             RGBColor[
              0.8618354721760655, 0.7122379768474625, 0.603098702731688], 
             UndirectedEdge[83, 161] -> 
             RGBColor[
              0.9152656356126947, 0.754447556797873, 0.5945283802670174], 
             UndirectedEdge[100, 211] -> 
             RGBColor[
              0.31010062158634694`, 0.43596482915131163`, 0.941238467752931], 
             UndirectedEdge[32, 287] -> 
             RGBColor[
              0.8201189109233364, 0.1556483422855536, 0.16689919786223403`], 
             UndirectedEdge[156, 181] -> 
             RGBColor[
              0.19699698742024596`, 0.3243867024820536, 0.9345300590514323], 
             UndirectedEdge[126, 176] -> 
             RGBColor[
              0.18438193895865332`, 0.3111274867086507, 0.9338116507038363], 
             UndirectedEdge[46, 350] -> 
             RGBColor[
              0.5770408715617338, 0.6621623046757947, 0.9623409899481321], 
             UndirectedEdge[47, 149] -> 
             RGBColor[
              0.1956652358484003, 0.3229869471421173, 0.9344542177695655], 
             UndirectedEdge[57, 108] -> 
             RGBColor[
              0.32733127751038416`, 0.4577193635987606, 0.9420863025998256], 
             UndirectedEdge[105, 400] -> 
             RGBColor[
              0.8765109090962969, 0.44339193500149654`, 0.4102881127942457], 
             UndirectedEdge[62, 256] -> 
             RGBColor[
              0.992053902372576, 0.9909820986727351, 0.781350931735281], 
             UndirectedEdge[193, 332] -> 
             RGBColor[
              0.8245126571232608, 0.38310970955927065`, 0.4379233865031822], 
             UndirectedEdge[1, 387] -> 
             RGBColor[
              0.1836776641650684, 0.31038724924699196`, 0.9337715432962228], 
             UndirectedEdge[72, 284] -> 
             RGBColor[
              0.602700789657427, 0.6868450128545692, 0.9628871876056561], 
             UndirectedEdge[127, 394] -> 
             RGBColor[
              0.348496932711213, 0.47627225997448197`, 0.9434268942819889], 
             UndirectedEdge[110, 385] -> 
             RGBColor[
              0.923690126192328, 0.9380306979900004, 0.809802069993292], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.18382719114068813`, 0.31054441157892615`, 0.933780058636279], 
             UndirectedEdge[97, 393] -> 
             RGBColor[
              0.5102982570407728, 0.6069665111134733, 0.9566203329382144], 
             UndirectedEdge[19, 150] -> 
             RGBColor[
              0.21895975804167556`, 0.3474709669252617, 0.9357808063473152], 
             UndirectedEdge[272, 342] -> 
             RGBColor[
              0.19152273141080622`, 0.31863291232825464`, 0.9342183082701306],
              UndirectedEdge[96, 187] -> 
             RGBColor[
              0.2139882194822336, 0.34224556468553763`, 0.9354976845810872], 
             UndirectedEdge[129, 333] -> 
             RGBColor[
              0.8641496188044945, 0.42143692475523437`, 0.4318092418276507], 
             UndirectedEdge[19, 160] -> 
             RGBColor[
              0.19740416245689973`, 0.32481466926196517`, 0.9345532470674082],
              UndirectedEdge[183, 357] -> 
             RGBColor[
              0.18734376764879906`, 0.31424055645277915`, 0.9339803224661072],
              UndirectedEdge[197, 217] -> 
             RGBColor[
              0.19977926755688577`, 0.3273110553124115, 0.9346885057891993], 
             UndirectedEdge[199, 345] -> 
             RGBColor[
              0.9084097409587222, 0.9276827314255283, 0.9099029118424318], 
             UndirectedEdge[44, 346] -> 
             RGBColor[
              0.2158698080892293, 0.3442232336110982, 0.9356048382686947], 
             UndirectedEdge[78, 80] -> 
             RGBColor[
              0.21178615052788774`, 0.3399310505952844, 0.9353722800118063], 
             UndirectedEdge[42, 320] -> 
             RGBColor[
              0.18379681968568948`, 0.3105124892540611, 0.9337783290268474], 
             UndirectedEdge[161, 332] -> 
             RGBColor[
              0.8383853925742157, 0.27388461821730115`, 0.1835231616976877], 
             UndirectedEdge[239, 309] -> 
             RGBColor[
              0.6022520031590326, 0.6871316854403461, 0.9624067531432969], 
             UndirectedEdge[8, 377] -> 
             RGBColor[
              0.25514638831763914`, 0.3855054097101751, 0.9378415814082092], 
             UndirectedEdge[75, 126] -> 
             RGBColor[
              0.18223452639463555`, 0.3088704199500476, 0.9336893587351277], 
             UndirectedEdge[54, 310] -> 
             RGBColor[
              0.8670957257484463, 0.41406650637033016`, 0.20775781021814968`],
              UndirectedEdge[65, 211] -> 
             RGBColor[
              0.3044915837808781, 0.4311065625226518, 0.9408810648238439], 
             UndirectedEdge[88, 356] -> 
             RGBColor[
              0.6878897223994248, 0.7529983724170004, 0.962990494071441], 
             UndirectedEdge[98, 158] -> 
             RGBColor[
              0.19219455973941713`, 0.31933904649800093`, 0.9342565678995641],
              UndirectedEdge[13, 390] -> 
             RGBColor[
              0.2131729075996141, 0.34138862020314553`, 0.9354512537755177], 
             UndirectedEdge[241, 242] -> 
             RGBColor[
              0.31065498243158685`, 0.4409219663646659, 0.9411098670507269], 
             UndirectedEdge[12, 238] -> 
             RGBColor[
              0.2218338423144311, 0.3504918117233956, 0.9359444811948219], 
             UndirectedEdge[175, 343] -> 
             RGBColor[
              0.19542826971397487`, 0.32273788071031545`, 0.93444072289877], 
             UndirectedEdge[59, 258] -> 
             RGBColor[
              0.2269624966999203, 0.35588235265801405`, 0.9362365504749113], 
             UndirectedEdge[152, 156] -> 
             RGBColor[
              0.20135778622096587`, 0.32897017851222354`, 0.9347784000919095],
              UndirectedEdge[39, 258] -> 
             RGBColor[
              0.21791338707223826`, 0.34637116469263174`, 0.9357212170685729],
              UndirectedEdge[183, 368] -> 
             RGBColor[
              0.18625851527578347`, 0.31309988739976513`, 0.933918518948951], 
             UndirectedEdge[44, 119] -> 
             RGBColor[
              0.23405162543822766`, 0.3633334764386976, 0.9366402658691317], 
             UndirectedEdge[149, 264] -> 
             RGBColor[
              0.23515256587011008`, 0.3644906346362611, 0.9367029627980321], 
             UndirectedEdge[120, 241] -> 
             RGBColor[
              0.34672955885014695`, 0.4721679512974918, 0.9434085071606221], 
             UndirectedEdge[116, 304] -> 
             RGBColor[
              0.26114585574207083`, 0.3918112303614577, 0.938183242202614], 
             UndirectedEdge[82, 256] -> 
             RGBColor[
              0.8760312800563814, 0.9016669835366705, 0.876948136427472], 
             UndirectedEdge[98, 186] -> 
             RGBColor[
              0.1999149394327242, 0.32745365505601143`, 0.9346962321018197], 
             UndirectedEdge[72, 262] -> 
             RGBColor[
              0.4149349676293397, 0.5334857796550911, 0.9477519352990894], 
             UndirectedEdge[147, 241] -> 
             RGBColor[
              0.2640632471374818, 0.3948775936913327, 0.9383493833266887], 
             UndirectedEdge[13, 205] -> 
             RGBColor[
              0.19925835051903662`, 0.3267635384775842, 0.9346588403345214], 
             UndirectedEdge[142, 394] -> 
             RGBColor[
              0.4158923670367568, 0.5340808989479011, 0.9478776312991117], 
             UndirectedEdge[42, 75] -> 
             RGBColor[
              0.18289766237674282`, 0.30956741791249204`, 0.9337271233482869],
              UndirectedEdge[56, 341] -> 
             RGBColor[
              0.38387079611477953`, 0.499652079122729, 0.9463702293168075], 
             UndirectedEdge[306, 378] -> 
             RGBColor[
              0.23126849430923743`, 0.36040822916142345`, 0.9364817706686093],
              UndirectedEdge[27, 295] -> 
             RGBColor[
              0.19546687096427723`, 0.32277845307184394`, 0.9344429211828693],
              UndirectedEdge[111, 247] -> 
             RGBColor[
              0.8235209713761704, 0.1817980697184317, 0.17015701479394557`], 
             UndirectedEdge[128, 259] -> 
             RGBColor[
              0.599663278641086, 0.6781009426487141, 0.9652528657581285], 
             UndirectedEdge[52, 68] -> 
             RGBColor[
              0.9052995090875355, 0.9251530264391655, 0.9074485213302443], 
             UndirectedEdge[241, 359] -> 
             RGBColor[
              0.3033005319170658, 0.43455191097441853`, 0.9406412479672268], 
             UndirectedEdge[361, 382] -> 
             RGBColor[
              0.3658350125936814, 0.49128963333144304`, 0.9445316614006376], 
             UndirectedEdge[14, 390] -> 
             RGBColor[
              0.27581610861732475`, 0.40446583032584077`, 0.9391199230263283],
              UndirectedEdge[11, 332] -> 
             RGBColor[
              0.8362675556984924, 0.39248274660493876`, 0.43904457922300955`],
              UndirectedEdge[22, 209] -> 
             RGBColor[
              0.25353925279510015`, 0.38381620837770913`, 0.9377500574177445],
              UndirectedEdge[33, 156] -> 
             RGBColor[
              0.22423055163894667`, 0.35301090518360945`, 0.9360809702452394],
              UndirectedEdge[283, 332] -> 
             RGBColor[
              0.8558441265023222, 0.3478421869979039, 0.19781603858755223`], 
             UndirectedEdge[150, 181] -> 
             RGBColor[
              0.21526447072748034`, 0.3435869856632946, 0.9355703652014595], 
             UndirectedEdge[117, 323] -> 
             RGBColor[
              0.4895767347577772, 0.5956116976057565, 0.9532057157698048], 
             UndirectedEdge[199, 223] -> 
             RGBColor[
              0.9023894680156853, 0.6322806802095792, 0.4149397481928467], 
             UndirectedEdge[128, 306] -> 
             RGBColor[
              0.2631009453754704, 0.39386615352600307`, 0.9382945816649401], 
             UndirectedEdge[184, 288] -> 
             RGBColor[
              0.21364346222149755`, 0.3418832029456312, 0.9354780511651108], 
             UndirectedEdge[145, 182] -> 
             RGBColor[
              0.24585035887698375`, 0.3757346933657375, 0.937312186283807], 
             UndirectedEdge[284, 397] -> 
             RGBColor[
              0.5520222170780682, 0.6432815473581924, 0.9595663255932364], 
             UndirectedEdge[61, 148] -> 
             RGBColor[
              0.23690961095816437`, 0.3663374004268991, 0.9368030239164815], 
             UndirectedEdge[34, 159] -> 
             RGBColor[
              0.1825395439463383, 0.30919101273611693`, 0.9337067290334642], 
             UndirectedEdge[276, 382] -> 
             RGBColor[
              0.35057061271571854`, 0.4780683773681971, 0.9435590273381926], 
             UndirectedEdge[59, 164] -> 
             RGBColor[
              0.215632569168565, 0.3439738804636637, 0.9355913278631264], 
             UndirectedEdge[80, 377] -> 
             RGBColor[
              0.2289003475673298, 0.3579191567865028, 0.9363469082150169], 
             UndirectedEdge[180, 370] -> 
             RGBColor[
              0.18698550798658503`, 0.3138640028328177, 0.9339599201083417], 
             UndirectedEdge[98, 374] -> 
             RGBColor[
              0.18844266475489285`, 0.3153955669853844, 0.9340429030306268], 
             UndirectedEdge[139, 350] -> 
             RGBColor[
              0.3277444111277722, 0.4581308203867991, 0.942110663773315], 
             UndirectedEdge[36, 276] -> 
             RGBColor[
              0.31234957064668134`, 0.4391299345139409, 0.941337201922877], 
             UndirectedEdge[53, 281] -> 
             RGBColor[
              0.40067800773256046`, 0.5214688844608842, 0.9467518262404362], 
             UndirectedEdge[73, 183] -> 
             RGBColor[
              0.19359784833893534`, 0.3208139917897307, 0.9343364831093273], 
             UndirectedEdge[101, 115] -> 
             RGBColor[
              0.8876851213781989, 0.5638225279808512, 0.22712473214005577`], 
             UndirectedEdge[283, 366] -> 
             RGBColor[
              0.9626113006296535, 0.8779402128312055, 0.388106189025446], 
             UndirectedEdge[22, 141] -> 
             RGBColor[
              0.2988998919025237, 0.4271457198066904, 0.9404924581847806], 
             UndirectedEdge[197, 314] -> 
             RGBColor[
              0.18703267242257346`, 0.3139135756454394, 0.9339626060531978], 
             UndirectedEdge[13, 14] -> 
             RGBColor[
              0.27600611579144196`, 0.4046655399129887, 0.9391307436538039], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.18066543438157506`, 0.30722120475814135`, 0.9336000012662475],
              UndirectedEdge[323, 395] -> 
             RGBColor[
              0.42965137086591587`, 0.5465641553634234, 0.9485979833191546], 
             UndirectedEdge[93, 131] -> 
             RGBColor[
              0.5783198351360825, 0.6629059133309206, 0.9625766163950823], 
             UndirectedEdge[52, 105] -> 
             RGBColor[
              0.9871484754393005, 0.988953578572104, 0.8626465508576164], 
             UndirectedEdge[178, 330] -> 
             RGBColor[
              0.18585403499635023`, 0.3126747529805498, 0.9338954843954123], 
             UndirectedEdge[92, 98] -> 
             RGBColor[
              0.19880960071600262`, 0.32629187398221465`, 0.9346332846971046],
              UndirectedEdge[37, 323] -> 
             RGBColor[
              0.35247668459828785`, 0.4774620340320098, 0.9437631308877006], 
             UndirectedEdge[279, 370] -> 
             RGBColor[
              0.19229180160053655`, 0.3194412538595276, 0.9342621056796985], 
             UndirectedEdge[150, 160] -> 
             RGBColor[
              0.2168510680318782, 0.345254600026296, 0.9356607195707846], 
             UndirectedEdge[188, 273] -> 
             RGBColor[
              0.39992754574806544`, 0.5158532142548906, 0.9473461281045827], 
             UndirectedEdge[179, 386] -> 
             RGBColor[
              0.284370042597393, 0.41315352294311436`, 0.9396181524839584], 
             UndirectedEdge[141, 179] -> 
             RGBColor[
              0.2912900071166007, 0.41914724840212236`, 0.9400590865040379], 
             UndirectedEdge[117, 388] -> 
             RGBColor[
              0.4146565458770389, 0.527209517044103, 0.9485603887539554], 
             UndirectedEdge[198, 214] -> 
             RGBColor[
              0.8538594754790496, 0.7047084000192836, 0.6021070091036955], 
             UndirectedEdge[150, 238] -> 
             RGBColor[
              0.21964443169265407`, 0.3481906023432569, 0.9358197974988545], 
             UndirectedEdge[331, 392] -> 
             RGBColor[
              0.22201549227327083`, 0.35068273734740874`, 0.9359548258912509],
              UndirectedEdge[323, 365] -> 
             RGBColor[
              0.3633194234507374, 0.48885844003528395`, 0.9443806088249529], 
             UndirectedEdge[6, 71] -> 
             RGBColor[
              0.9479335881069795, 0.9604436363507414, 0.9644935461230137], 
             UndirectedEdge[132, 249] -> 
             RGBColor[
              0.18824799980109214`, 0.3151909617764689, 0.9340318171494888], 
             UndirectedEdge[348, 378] -> 
             RGBColor[
              0.22067056618642705`, 0.3492691347568969, 0.935878234340245], 
             UndirectedEdge[174, 198] -> 
             RGBColor[
              0.6233166189809511, 0.701327344471203, 0.9656888716580491], 
             UndirectedEdge[72, 236] -> 
             RGBColor[
              0.4875863338308316, 0.5948835771747154, 0.9528037287682061], 
             UndirectedEdge[9, 100] -> 
             RGBColor[
              0.5370355289675518, 0.6325732881317867, 0.9576495756744858], 
             UndirectedEdge[51, 298] -> 
             RGBColor[
              0.20333725610200998`, 0.3310507268628402, 0.9348911279732717], 
             UndirectedEdge[23, 128] -> 
             RGBColor[
              0.2579108106564282, 0.38841099286274205`, 0.9379990111708069], 
             UndirectedEdge[215, 353] -> 
             RGBColor[
              0.8496653857450382, 0.8791494975932964, 0.7395436178949295], 
             UndirectedEdge[80, 96] -> 
             RGBColor[
              0.2073679300463957, 0.3352872207378781, 0.9351206688915568], 
             UndirectedEdge[78, 388] -> 
             RGBColor[
              0.2456236030410635, 0.37549635860503494`, 0.9372992728744065], 
             UndirectedEdge[312, 380] -> 
             RGBColor[
              0.6340993587155315, 0.7126342355184634, 0.9651549462114524], 
             UndirectedEdge[57, 325] -> 
             RGBColor[
              0.29328547563165996`, 0.42193506719570584`, 0.9401474445490827],
              UndirectedEdge[308, 374] -> 
             RGBColor[
              0.1982421611639798, 0.32569545903529307`, 0.9346009698540684], 
             UndirectedEdge[76, 365] -> 
             RGBColor[
              0.2944759917270998, 0.42684331653440033`, 0.9400813441394438], 
             UndirectedEdge[182, 187] -> 
             RGBColor[
              0.22908739425404853`, 0.35811575471368917`, 0.9363575602471148],
              UndirectedEdge[74, 286] -> 
             RGBColor[
              0.28488862903471124`, 0.4156109198533938, 0.9395776654568602], 
             UndirectedEdge[137, 164] -> 
             RGBColor[
              0.2538187120761361, 0.3841099378008197, 0.9377659722103766], 
             UndirectedEdge[149, 258] -> 
             RGBColor[
              0.22398941258529487`, 0.35275745274912235`, 0.9360672377328672],
              UndirectedEdge[147, 331] -> 
             RGBColor[
              0.2440919709450002, 0.37388651616098867`, 0.9372120486923824], 
             UndirectedEdge[42, 367] -> 
             RGBColor[
              0.1849893429390042, 0.3117659068036362, 0.9338462414619436], 
             UndirectedEdge[16, 365] -> 
             RGBColor[
              0.2674853323456614, 0.39847442221786333`, 0.9385442660167731], 
             UndirectedEdge[113, 183] -> 
             RGBColor[
              0.18716623928349274`, 0.31405396288489373`, 0.9339702124883327],
              UndirectedEdge[16, 323] -> 
             RGBColor[
              0.3247877744177019, 0.4483592338539112, 0.9421862884149881], 
             UndirectedEdge[340, 343] -> 
             RGBColor[
              0.2360559349263153, 0.3654401327912391, 0.9367544083293682], 
             UndirectedEdge[323, 362] -> 
             RGBColor[
              0.6059463857156073, 0.6878046821697024, 0.9639263891716204], 
             UndirectedEdge[334, 364] -> 
             RGBColor[
              0.9407749655383337, 0.8016431292497415, 0.27774757447488835`], 
             UndirectedEdge[94, 324] -> 
             RGBColor[
              0.18239675869616345`, 0.30904093638507546`, 0.9336985976246985],
              UndirectedEdge[135, 350] -> 
             RGBColor[
              0.3419502599754641, 0.47060186109611535`, 0.9430097460842624], 
             UndirectedEdge[31, 215] -> 
             RGBColor[
              0.8451646800561206, 0.8790328648583385, 0.9409404903646027], 
             UndirectedEdge[3, 21] -> 
             RGBColor[
              0.21644166427209716`, 0.34482429071706844`, 0.9356374046323236],
              UndirectedEdge[127, 193] -> 
             RGBColor[
              0.5886484429999097, 0.6709855269816585, 0.9636243911098379], 
             UndirectedEdge[50, 230] -> 
             RGBColor[
              0.2261265468612622, 0.35500371637530337`, 0.9361889443682767], 
             UndirectedEdge[169, 382] -> 
             RGBColor[
              0.38967734439969204`, 0.5118336629702842, 0.9460804380697425], 
             UndirectedEdge[12, 19] -> 
             RGBColor[
              0.22114916866345258`, 0.3497721763054004, 0.9359054900432826], 
             UndirectedEdge[133, 296] -> 
             RGBColor[
              0.18124069831826523`, 0.30782584362944293`, 0.9336327616964153],
              UndirectedEdge[214, 332] -> 
             RGBColor[
              0.8381770729417689, 0.2729386874206463, 0.1833493346899926], 
             UndirectedEdge[76, 395] -> 
             RGBColor[
              0.36080793914227827`, 0.4845490318625397, 0.9442987186336453], 
             UndirectedEdge[299, 370] -> 
             RGBColor[
              0.1869681936623269, 0.3138458043802308, 0.9339589340831895], 
             UndirectedEdge[170, 235] -> 
             RGBColor[
              0.21437654864384317`, 0.34265372325588017`, 0.9355197993523594],
              UndirectedEdge[46, 400] -> 
             RGBColor[
              0.8165889705092233, 0.3966653849576874, 0.4396245779524498], 
             UndirectedEdge[65, 329] -> 
             RGBColor[
              0.31941652727713654`, 0.4467936244332925, 0.9417310182764805], 
             UndirectedEdge[81, 267] -> 
             RGBColor[
              0.21336000502701669`, 0.3415852714620077, 0.9354619086972226], 
             UndirectedEdge[104, 182] -> 
             RGBColor[
              0.23293840827128548`, 0.36216341461419643`, 0.9365768697983317],
              UndirectedEdge[23, 306] -> 
             RGBColor[
              0.21710981978146196`, 0.345526564520917, 0.9356754551001344], 
             UndirectedEdge[209, 286] -> 
             RGBColor[
              0.29314447532730914`, 0.4242883377578022, 0.9400478236897936], 
             UndirectedEdge[150, 167] -> 
             RGBColor[
              0.2371065726737784, 0.3665444196781035, 0.936814240594807], 
             UndirectedEdge[4, 288] -> 
             RGBColor[
              0.2072894767278965, 0.33520476132590776`, 0.9351162010911295], 
             UndirectedEdge[171, 272] -> 
             RGBColor[
              0.19235235421379315`, 0.3195048984953177, 0.9342655540614437], 
             UndirectedEdge[78, 182] -> 
             RGBColor[
              0.23114667261114863`, 0.3602801868327903, 0.9364748331031223], 
             UndirectedEdge[143, 374] -> 
             RGBColor[
              0.1912700084764235, 0.3183672845006589, 0.9342039160728877], 
             UndirectedEdge[55, 262] -> 
             RGBColor[
              0.5840352729572464, 0.6682969151994234, 0.9627543260164191], 
             UndirectedEdge[165, 190] -> 
             RGBColor[
              0.21884661716031273`, 0.34735204868540315`, 0.9357743631414985],
              UndirectedEdge[2, 149] -> 
             RGBColor[
              0.20607580619388693`, 0.3339291166435074, 0.9350470843496823], 
             UndirectedEdge[39, 47] -> 
             RGBColor[
              0.18958921033534365`, 0.3166006590856267, 0.9341081971052712], 
             UndirectedEdge[230, 300] -> 
             RGBColor[
              0.2086431877242838, 0.3366275974133453, 0.9351932929297377], 
             UndirectedEdge[40, 48] -> 
             RGBColor[
              0.20069384731952558`, 0.3282723366306521, 0.934740589753682], 
             UndirectedEdge[25, 208] -> 
             RGBColor[
              0.3291899186131193, 0.4582247733572693, 0.9422451729560961], 
             UndirectedEdge[32, 52] -> 
             RGBColor[
              0.8773441309925929, 0.440845016758437, 0.3895100283525863], 
             UndirectedEdge[161, 366] -> 
             RGBColor[
              0.9364231997374939, 0.7670038596603013, 0.3666668736906492], 
             UndirectedEdge[190, 318] -> 
             RGBColor[
              0.21280458260693721`, 0.34100148728268875`, 0.9354302782120729],
              UndirectedEdge[179, 245] -> 
             RGBColor[
              0.21085364957036085`, 0.33895093296494805`, 0.9353191754617867],
              UndirectedEdge[37, 182] -> 
             RGBColor[
              0.26307956528763465`, 0.3938436816981118, 0.9382933641005669], 
             UndirectedEdge[12, 206] -> 
             RGBColor[
              0.33583694364464667`, 0.4592083134506097, 0.9428435069438263], 
             UndirectedEdge[18, 218] -> 
             RGBColor[
              0.776406098847213, 0.8201699347730458, 0.6937389035902746], 
             UndirectedEdge[92, 119] -> 
             RGBColor[
              0.22208012665594387`, 0.3507506721816547, 0.9359585067237262], 
             UndirectedEdge[215, 400] -> 
             RGBColor[
              0.7834338026649409, 0.37076431584912545`, 0.43631998067439115`],
              UndirectedEdge[71, 292] -> 
             RGBColor[
              0.8695625482177284, 0.42619442228126747`, 0.42292170974900056`],
              UndirectedEdge[158, 346] -> 
             RGBColor[
              0.19728326833036003`, 0.3246876018698416, 0.9345463623257486], 
             UndirectedEdge[92, 151] -> 
             RGBColor[
              0.20599136961110498`, 0.33384036844141496`, 0.9350422758112056],
              UndirectedEdge[104, 170] -> 
             RGBColor[
              0.22977658578143667`, 0.35884013870624076`, 0.936396808685032], 
             UndirectedEdge[82, 316] -> 
             RGBColor[
              0.7359499332008539, 0.7936489483339444, 0.9743162695644639], 
             UndirectedEdge[287, 353] -> 
             RGBColor[
              0.8759659333711045, 0.41874857297271617`, 0.27872834063508234`],
              UndirectedEdge[368, 372] -> 
             RGBColor[
              0.1818899475322301, 0.30850824571809776`, 0.9336697354786725], 
             UndirectedEdge[9, 203] -> 
             RGBColor[
              0.4981842108201723, 0.5989222290765547, 0.9551740040370065], 
             UndirectedEdge[17, 384] -> 
             RGBColor[
              0.8629693717290111, 0.400547840174431, 0.20455442187161196`], 
             UndirectedEdge[82, 310] -> 
             RGBColor[
              0.804263995214133, 0.4072991308684552, 0.44091357643715234`], 
             UndirectedEdge[129, 287] -> 
             RGBColor[
              0.8186637745742122, 0.14446352666137094`, 0.16550575765097125`],
              UndirectedEdge[81, 363] -> 
             RGBColor[
              0.3018408929173706, 0.42850250201273, 0.940723448587576], 
             UndirectedEdge[64, 356] -> 
             RGBColor[
              0.9689844051155808, 0.9726683265613763, 0.7058319664887789], 
             UndirectedEdge[245, 352] -> 
             RGBColor[
              0.1906398234149592, 0.3177049200450192, 0.9341680279659126], 
             UndirectedEdge[87, 232] -> 
             RGBColor[
              0.18860427170948546`, 0.315565426141134, 0.9340521063076146], 
             UndirectedEdge[88, 255] -> 
             RGBColor[
              0.40229233650521606`, 0.5228671349052352, 0.9468546898423349], 
             UndirectedEdge[154, 392] -> 
             RGBColor[
              0.19471742420704347`, 0.3219907370123223, 0.934400241298752], 
             UndirectedEdge[22, 45] -> 
             RGBColor[
              0.24087710963769857`, 0.3705074930930349, 0.9370289670968927], 
             UndirectedEdge[116, 141] -> 
             RGBColor[
              0.29789401265983945`, 0.4260884769462017, 0.9404351748499746], 
             UndirectedEdge[97, 224] -> 
             RGBColor[
              0.3981861519254275, 0.5171684195208632, 0.946960633454442], 
             UndirectedEdge[66, 151] -> 
             RGBColor[
              0.20186975982558952`, 0.3295082952316844, 0.9348075562312959], 
             UndirectedEdge[165, 221] -> 
             RGBColor[
              0.29772616502322835`, 0.42460426174906063`, 0.9404735010185594],
              UndirectedEdge[101, 332] -> 
             RGBColor[
              0.8419174702104941, 0.3232016211562354, 0.18777352285356763`], 
             UndirectedEdge[58, 396] -> 
             RGBColor[
              0.18880077082680655`, 0.315771959172202, 0.9340632966416518], 
             UndirectedEdge[35, 387] -> 
             RGBColor[
              0.1878209095169145, 0.3147420628087102, 0.9340074949896282], 
             UndirectedEdge[198, 266] -> 
             RGBColor[0.74350964112616, 0.79962588641691, 0.9750508465456946],
              UndirectedEdge[188, 264] -> 
             RGBColor[
              0.26789407428573686`, 0.39890403591261847`, 0.9385675432655809],
              UndirectedEdge[119, 151] -> 
             RGBColor[
              0.22370106658388367`, 0.35245438281944674`, 0.9360508168546565],
              UndirectedEdge[247, 400] -> 
             RGBColor[
              0.8189309026952224, 0.14651679045574345`, 0.16576155984132857`],
              UndirectedEdge[305, 361] -> 
             RGBColor[
              0.353816749645949, 0.47989197268582956`, 0.9438020454927423], 
             UndirectedEdge[138, 210] -> 
             RGBColor[
              0.2672929528119248, 0.3982722191303392, 0.9385333102869269], 
             UndirectedEdge[197, 231] -> 
             RGBColor[
              0.19125913163260555`, 0.3183558522481745, 0.9342032966527232], 
             UndirectedEdge[225, 261] -> 
             RGBColor[
              0.19884280647751676`, 0.32632677534293286`, 0.9346351757160992],
              UndirectedEdge[83, 286] -> 
             RGBColor[
              0.6361141683386347, 0.7078159235332517, 0.9547721155282454], 
             UndirectedEdge[19, 238] -> 
             RGBColor[
              0.20019752611767563`, 0.32775067157892607`, 0.9347123249954781],
              UndirectedEdge[62, 117] -> 
             RGBColor[
              0.7751677288121797, 0.821679420316278, 0.8719418433976884], 
             UndirectedEdge[65, 167] -> 
             RGBColor[
              0.30615029923372655`, 0.43284997763222943`, 0.940975526215034], 
             UndirectedEdge[268, 371] -> 
             RGBColor[
              0.1838466718007321, 0.3105648869877775, 0.9337811680310495], 
             UndirectedEdge[172, 192] -> 
             RGBColor[
              0.31894488906729196`, 0.44600858518137365`, 0.9417147525123752],
              UndirectedEdge[52, 353] -> 
             RGBColor[
              0.9911272301605415, 0.9888543711683995, 0.6698997566881519], 
             UndirectedEdge[126, 298] -> 
             RGBColor[
              0.194012535572622, 0.32124985436502457`, 0.9343600989338109], 
             UndirectedEdge[146, 306] -> 
             RGBColor[
              0.2107146293415335, 0.33880481389005895`, 0.9353112584654169], 
             UndirectedEdge[21, 132] -> 
             RGBColor[
              0.1947709663990963, 0.3220470132509409, 0.9344032904473808], 
             UndirectedEdge[89, 162] -> 
             RGBColor[
              0.2137613905296329, 0.342007153074568, 0.9354847670077999], 
             UndirectedEdge[9, 18] -> 
             RGBColor[
              0.8394473584119997, 0.8706756474406323, 0.6991625748728455], 
             UndirectedEdge[255, 360] -> 
             RGBColor[
              0.5184721491114823, 0.6174970812936685, 0.956042445038614], 
             UndirectedEdge[124, 152] -> 
             RGBColor[
              0.2137312689052459, 0.34197549333751603`, 0.935483051625852], 
             UndirectedEdge[88, 389] -> 
             RGBColor[
              0.7117595806289345, 0.7674543626326005, 0.720767374949669], 
             UndirectedEdge[12, 167] -> 
             RGBColor[
              0.2392959832955554, 0.36884562905824225`, 0.9369389242907744], 
             UndirectedEdge[32, 303] -> 
             RGBColor[
              0.8456559302937136, 0.31468700621706225`, 0.18989485762449604`],
              UndirectedEdge[49, 261] -> 
             RGBColor[
              0.1864507904031121, 0.31330198074953464`, 0.9339294687330069], 
             UndirectedEdge[283, 360] -> 
             RGBColor[
              0.7973390261209754, 0.7521357532053826, 0.6155512086405578], 
             UndirectedEdge[282, 305] -> 
             RGBColor[
              0.30654149170312617`, 0.4389445203793095, 0.9407897078604948], 
             UndirectedEdge[32, 385] -> 
             RGBColor[
              0.8791517721101495, 0.4410953758327831, 0.323415399566809], 
             UndirectedEdge[167, 216] -> 
             RGBColor[
              0.22581143984224178`, 0.35467251891937396`, 0.9361709994897025],
              UndirectedEdge[252, 318] -> 
             RGBColor[
              0.20969889594004104`, 0.3377372136838731, 0.9352534139508448], 
             UndirectedEdge[2, 217] -> 
             RGBColor[
              0.20503618363244414`, 0.3328364074155535, 0.9349878793827919], 
             UndirectedEdge[305, 329] -> 
             RGBColor[
              0.28019918973537505`, 0.41183749243956935`, 0.9392683013866509],
              UndirectedEdge[87, 373] -> 
             RGBColor[
              0.19241687464340246`, 0.3195727135576686, 0.9342692284044607], 
             UndirectedEdge[20, 241] -> 
             RGBColor[
              0.33276855688740864`, 0.46007563309772936`, 0.9425189244607857],
              UndirectedEdge[59, 210] -> 
             RGBColor[
              0.23097654198013617`, 0.36010136875269116`, 0.9364651444153718],
              UndirectedEdge[290, 304] -> 
             RGBColor[
              0.2699001201696922, 0.4010125173273108, 0.9386817846109934], 
             UndirectedEdge[115, 312] -> 
             RGBColor[
              0.7514622050621471, 0.7517529361696669, 0.6201411074573389], 
             UndirectedEdge[214, 389] -> 
             RGBColor[
              0.9360223295752915, 0.7653959046667461, 0.35678534949539953`], 
             UndirectedEdge[144, 276] -> 
             RGBColor[
              0.48015124453344243`, 0.5868307576532874, 0.952775625742377], 
             UndirectedEdge[196, 286] -> 
             RGBColor[
              0.5826840049020053, 0.6656063435828412, 0.963342437992916], 
             UndirectedEdge[124, 181] -> 
             RGBColor[
              0.209370470104526, 0.33739201730734614`, 0.9352347105853747], 
             UndirectedEdge[216, 341] -> 
             RGBColor[
              0.2325799518711988, 0.3617866542102568, 0.9365564562366354], 
             UndirectedEdge[294, 340] -> 
             RGBColor[
              0.24056246391472638`, 0.3701767804885, 0.937011048488446], 
             UndirectedEdge[104, 235] -> 
             RGBColor[
              0.20864915250350596`, 0.3366338667744967, 0.9351936326150905], 
             UndirectedEdge[125, 318] -> 
             RGBColor[
              0.20302734583193666`, 0.33072499151954715`, 0.9348734790418622],
              UndirectedEdge[109, 232] -> 
             RGBColor[
              0.18655512715268852`, 0.3134116452886715, 0.9339354105565427], 
             UndirectedEdge[182, 388] -> 
             RGBColor[
              0.2563045573313864, 0.38672271877578024`, 0.9379075374201846], 
             UndirectedEdge[97, 382] -> 
             RGBColor[
              0.3103603612224796, 0.44230450028690405`, 0.9410311290958356], 
             UndirectedEdge[140, 147] -> 
             RGBColor[
              0.32678087214865287`, 0.45177394646584723`, 0.9422514665551494],
              UndirectedEdge[59, 300] -> 
             RGBColor[
              0.20621668709807878`, 0.3340771914061782, 0.9350551073087614], 
             UndirectedEdge[205, 373] -> 
             RGBColor[
              0.19156946915989134`, 0.31868203666588757`, 0.9342209699157987],
              UndirectedEdge[215, 259] -> 
             RGBColor[
              0.8007477962042493, 0.8448792898490222, 0.9806129038326282], 
             UndirectedEdge[136, 300] -> 
             RGBColor[
              0.18939860406094253`, 0.3164003198060953, 0.9340973423599207], 
             UndirectedEdge[152, 245] -> 
             RGBColor[
              0.19786899137363773`, 0.3253032339253123, 0.9345797183865636], 
             UndirectedEdge[44, 128] -> 
             RGBColor[
              0.26610768174908467`, 0.39702642409276845`, 0.9384658108533496],
              UndirectedEdge[241, 392] -> 
             RGBColor[
              0.24198676846575243`, 0.37167381487775275`, 0.9370921605255572],
              UndirectedEdge[240, 342] -> 
             RGBColor[
              0.18286346184170274`, 0.30953147098172573`, 0.9337251756784115],
              UndirectedEdge[123, 214] -> 
             RGBColor[
              0.8550790024478794, 0.40285432407734784`, 0.1995346414730431], 
             UndirectedEdge[125, 274] -> 
             RGBColor[
              0.19786901158433057`, 0.32530325516803194`, 0.9345797195375327],
              UndirectedEdge[298, 373] -> 
             RGBColor[
              0.20172543232639267`, 0.32935659787913657`, 0.93479933699373], 
             UndirectedEdge[119, 350] -> 
             RGBColor[
              0.2941675459212899, 0.42283940615857285`, 0.9401985109723265], 
             UndirectedEdge[22, 179] -> 
             RGBColor[
              0.2344230766191157, 0.3637238951811761, 0.9366614194643705], 
             UndirectedEdge[1, 183] -> 
             RGBColor[
              0.18524860197516257`, 0.312038404488611, 0.9338610058805135], 
             UndirectedEdge[112, 260] -> 
             RGBColor[
              0.18468581634927816`, 0.3114468811131368, 0.9338289560716861], 
             UndirectedEdge[183, 270] -> 
             RGBColor[
              0.198314467229445, 0.32577145729456636`, 0.9346050875775294], 
             UndirectedEdge[152, 181] -> 
             RGBColor[
              0.1964830766390266, 0.32384654966716653`, 0.9345007925927047], 
             UndirectedEdge[169, 276] -> 
             RGBColor[
              0.41815198956691846`, 0.5364969694368562, 0.947894817280658], 
             UndirectedEdge[349, 355] -> 
             RGBColor[
              0.20327760071832918`, 0.33098802527222193`, 0.9348877306874234],
              UndirectedEdge[171, 240] -> 
             RGBColor[
              0.18369308464468964`, 0.3104034571487888, 0.9337724214697247], 
             UndirectedEdge[114, 132] -> 
             RGBColor[
              0.1897759122485969, 0.31679689463404087`, 0.9341188295030303], 
             UndirectedEdge[17, 222] -> 
             RGBColor[
              0.8688036227970698, 0.46343086091223773`, 0.43864154601533567`],
              UndirectedEdge[46, 259] -> 
             RGBColor[
              0.850480547970673, 0.8837308935118651, 0.9855697997497163], 
             UndirectedEdge[13, 79] -> 
             RGBColor[
              0.20620705634176517`, 0.33406706887066745`, 0.9350545588514367],
              UndirectedEdge[146, 311] -> 
             RGBColor[
              0.20086274150294195`, 0.3284498551259324, 0.9347502080275711], 
             UndirectedEdge[44, 275] -> 
             RGBColor[
              0.21122882729611786`, 0.33934526854236047`, 0.9353405412782427],
              UndirectedEdge[193, 195] -> 
             RGBColor[
              0.6312732042379722, 0.7079049527832757, 0.9663404032043308], 
             UndirectedEdge[86, 297] -> 
             RGBColor[
              0.28232965171394053`, 0.4140767430581329, 0.9393896280445941], 
             UndirectedEdge[197, 392] -> 
             RGBColor[
              0.19718685275102665`, 0.3245862629828614, 0.9345408716011396], 
             UndirectedEdge[217, 392] -> 
             RGBColor[
              0.20565454435776198`, 0.333486343744197, 0.935023094111316], 
             UndirectedEdge[101, 193] -> 
             RGBColor[
              0.8486252089812196, 0.5684493493271408, 0.4610135933935957], 
             UndirectedEdge[216, 340] -> 
             RGBColor[
              0.2436041993290528, 0.3733738372661213, 0.9371842708204476], 
             UndirectedEdge[125, 190] -> 
             RGBColor[
              0.20237543357367466`, 0.3300397904024893, 0.934836353603172], 
             UndirectedEdge[99, 276] -> 
             RGBColor[
              0.6406056746670367, 0.7137792263922267, 0.9679520038982681], 
             UndirectedEdge[27, 63] -> 
             RGBColor[
              0.1971785692903057, 0.32457755654044196`, 0.9345403998703059], 
             UndirectedEdge[184, 226] -> 
             RGBColor[
              0.20272879549405032`, 0.3304111961852439, 0.9348564770417853], 
             UndirectedEdge[107, 211] -> 
             RGBColor[
              0.2277850924450354, 0.3567469529417126, 0.9362833960856742], 
             UndirectedEdge[216, 294] -> 
             RGBColor[
              0.21277466253925434`, 0.3409700393945122, 0.9354285743084811], 
             UndirectedEdge[68, 284] -> 
             RGBColor[
              0.7807346086845934, 0.8286481739482061, 0.9787765120052747], 
             UndirectedEdge[89, 359] -> 
             RGBColor[
              0.2789577626844565, 0.40896611709023306`, 0.9392549632713296], 
             UndirectedEdge[23, 267] -> 
             RGBColor[
              0.20474185831720654`, 0.33252705284793593`, 0.9349711179915043],
              UndirectedEdge[140, 242] -> 
             RGBColor[
              0.3733726074427579, 0.4978183191391804, 0.9450119502791875], 
             UndirectedEdge[64, 214] -> 
             RGBColor[
              0.9357533158900353, 0.7648205115954387, 0.32750487001527717`], 
             UndirectedEdge[296, 367] -> 
             RGBColor[
              0.18258473603098674`, 0.3092385124824261, 0.9337093026558292], 
             UndirectedEdge[275, 346] -> 
             RGBColor[
              0.1987852081376144, 0.3262662358357499, 0.9346318955758508], 
             UndirectedEdge[301, 305] -> 
             RGBColor[
              0.27396377293596785`, 0.4052836740351331, 0.9389132036243971], 
             UndirectedEdge[81, 119] -> 
             RGBColor[
              0.2344729010553813, 0.363776263822743, 0.9366642568923073], 
             UndirectedEdge[327, 355] -> 
             RGBColor[
              0.19695189529636073`, 0.3243393078008444, 0.9345274911216848], 
             UndirectedEdge[317, 344] -> 
             RGBColor[
              0.19003331843460333`, 0.31706744485602845`, 0.9341334884045249],
              UndirectedEdge[184, 190] -> 
             RGBColor[
              0.21285282401079259`, 0.34105219205682236`, 0.9354330254886557],
              UndirectedEdge[10, 303] -> 
             RGBColor[
              0.8599547518024352, 0.42459401411663544`, 0.20358742524945703`],
              UndirectedEdge[149, 268] -> 
             RGBColor[
              0.19899317290676588`, 0.326484819993856, 0.9346437388617977], 
             UndirectedEdge[38, 267] -> 
             RGBColor[
              0.22814489442186137`, 0.3571251276321197, 0.9363038862759752], 
             UndirectedEdge[253, 366] -> 
             RGBColor[
              0.8812282840866474, 0.45912286163357663`, 0.28521534724776915`],
              UndirectedEdge[165, 355] -> 
             RGBColor[
              0.2168405199897158, 0.34524351336519876`, 0.9356601188753879], 
             UndirectedEdge[339, 340] -> 
             RGBColor[
              0.326674769743479, 0.4539173667672604, 0.9421628597566036], 
             UndirectedEdge[185, 318] -> 
             RGBColor[
              0.20300306708120197`, 0.33069947301316327`, 0.9348720964029251],
              UndirectedEdge[36, 70] -> 
             RGBColor[
              0.22130912604082534`, 0.3499403016509027, 0.9359145993792883], 
             UndirectedEdge[69, 131] -> 
             RGBColor[
              0.693464422361174, 0.75939366397809, 0.9708100489116116], 
             UndirectedEdge[283, 312] -> 
             RGBColor[
              0.7398695405352704, 0.7057918843470511, 0.6108133774642039], 
             UndirectedEdge[75, 330] -> 
             RGBColor[
              0.18530504232011252`, 0.31209772686967785`, 0.9338642200746624],
              UndirectedEdge[169, 222] -> 
             RGBColor[
              0.7041731063901011, 0.7666519834125803, 0.9590482629072343], 
             UndirectedEdge[90, 246] -> 
             RGBColor[
              0.21613530957472, 0.3445022925061154, 0.9356199581855191], 
             UndirectedEdge[62, 362] -> 
             RGBColor[
              0.8915373797700097, 0.913872404880224, 0.882662516799504], 
             UndirectedEdge[158, 374] -> 
             RGBColor[
              0.1873884527454699, 0.3142875233225789, 0.9339828672162569], 
             UndirectedEdge[82, 172] -> 
             RGBColor[
              0.5696909718954926, 0.6577404259092337, 0.9610497684809419], 
             UndirectedEdge[306, 346] -> 
             RGBColor[
              0.21286307171561503`, 0.3410629630443328, 0.9354336090802852], 
             UndirectedEdge[53, 188] -> 
             RGBColor[
              0.33920701496392514`, 0.465180569896386, 0.9429464497347737], 
             UndirectedEdge[84, 190] -> 
             RGBColor[
              0.21321988075352158`, 0.3414379919661722, 0.9354539288271424], 
             UndirectedEdge[78, 96] -> 
             RGBColor[
              0.2160474978393337, 0.3444099968046388, 0.9356149574370947], 
             UndirectedEdge[46, 199] -> 
             RGBColor[
              0.8971361136435547, 0.9188102209856679, 0.9087966349847089], 
             UndirectedEdge[159, 265] -> 
             RGBColor[
              0.19056897353088317`, 0.3176304523247132, 0.9341639931698273], 
             UndirectedEdge[332, 356] -> 
             RGBColor[
              0.860331132425466, 0.41150389739793797`, 0.4355673990056604], 
             UndirectedEdge[199, 222] -> 
             RGBColor[
              0.9699116219534045, 0.9763258350817114, 0.9020107810264453], 
             UndirectedEdge[114, 300] -> 
             RGBColor[
              0.19141939910096473`, 0.3185243035189643, 0.9342124236479517], 
             UndirectedEdge[139, 213] -> 
             RGBColor[
              0.3161784578429658, 0.4481129729732145, 0.941373691457378], 
             UndirectedEdge[106, 369] -> 
             RGBColor[
              0.18346224485360668`, 0.3101608298922725, 0.9337592754851194], 
             UndirectedEdge[109, 114] -> 
             RGBColor[
              0.18471405231964982`, 0.3114765589082613, 0.9338305640684275], 
             UndirectedEdge[58, 245] -> 
             RGBColor[
              0.1940488178607217, 0.32128798935024727`, 0.9343621651564433], 
             UndirectedEdge[151, 317] -> 
             RGBColor[
              0.1980582216182819, 0.3255021269103238, 0.9345904947690551], 
             UndirectedEdge[99, 218] -> 
             RGBColor[
              0.7312212189545854, 0.7893616865114603, 0.9745283770409688], 
             UndirectedEdge[55, 57] -> 
             RGBColor[
              0.5760181454967422, 0.6613528823456771, 0.9622434817439033], 
             UndirectedEdge[247, 287] -> 
             RGBColor[
              0.8173321632588791, 0.13422817857592148`, 0.1642306051515684], 
             UndirectedEdge[44, 66] -> 
             RGBColor[
              0.21222031867993352`, 0.3403873888509353, 0.9353970052457711], 
             UndirectedEdge[116, 290] -> 
             RGBColor[
              0.24877546734729164`, 0.3788091678306199, 0.9374787668838809], 
             UndirectedEdge[278, 367] -> 
             RGBColor[
              0.18709347932173553`, 0.31397748755183885`, 0.9339660689161493],
              UndirectedEdge[102, 297] -> 
             RGBColor[
              0.32279739953618347`, 0.45288594084814915`, 0.9418305958510031],
              UndirectedEdge[104, 187] -> 
             RGBColor[
              0.2201981756238625, 0.34877262232435, 0.935851332396546], 
             UndirectedEdge[136, 371] -> 
             RGBColor[
              0.1813347042579621, 0.3079246498323852, 0.9336381151956117], 
             UndirectedEdge[80, 302] -> 
             RGBColor[
              0.1989040089899044, 0.3263911030639157, 0.9346386611086387], 
             UndirectedEdge[176, 373] -> 
             RGBColor[
              0.192094835712424, 0.3192342302227627, 0.9342508887637553], 
             UndirectedEdge[112, 219] -> 
             RGBColor[
              0.17968380010062157`, 0.30618944488965105`, 0.933544098646145], 
             UndirectedEdge[33, 179] -> 
             RGBColor[
              0.23670129905445042`, 0.3661184514083582, 0.9367911608617348], 
             UndirectedEdge[123, 334] -> 
             RGBColor[
              0.8821757375846465, 0.51430578536771, 0.2259508375177215], 
             UndirectedEdge[94, 307] -> 
             RGBColor[
              0.17906784709075121`, 0.30554203922260087`, 0.9335090210334537],
              UndirectedEdge[73, 89] -> 
             RGBColor[
              0.21536881746289013`, 0.3436966606981754, 0.9355763075936738], 
             UndirectedEdge[267, 311] -> 
             RGBColor[
              0.20008010519765723`, 0.3276272547470704, 0.9347056380477918], 
             UndirectedEdge[52, 391] -> 
             RGBColor[
              0.8764876955371848, 0.43426207855576004`, 0.3886899047932819], 
             UndirectedEdge[105, 271] -> 
             RGBColor[
              0.8751025987519235, 0.43256704456911477`, 0.4089395132180147], 
             UndirectedEdge[187, 377] -> 
             RGBColor[
              0.2355206370031677, 0.36487750073416236`, 0.9367239239045473], 
             UndirectedEdge[58, 124] -> 
             RGBColor[
              0.20991109539232988`, 0.337960248762451, 0.9352654983957317], 
             UndirectedEdge[11, 54] -> 
             RGBColor[
              0.9107233154962703, 0.8671374351819781, 0.6324945514745149], 
             UndirectedEdge[115, 283] -> 
             RGBColor[
              0.9435152073287729, 0.813763650039597, 0.2734092138294835], 
             UndirectedEdge[292, 362] -> 
             RGBColor[
              0.810084891703258, 0.3795078663592535, 0.437475886871706], 
             UndirectedEdge[15, 154] -> 
             RGBColor[
              0.18425132424679044`, 0.31099020236503183`, 0.933804212389223], 
             UndirectedEdge[158, 311] -> 
             RGBColor[
              0.19686826327665763`, 0.3242514052455602, 0.9345227284018851], 
             UndirectedEdge[123, 253] -> 
             RGBColor[
              0.8371693407082226, 0.2867054171581618, 0.18322670867994717`], 
             UndirectedEdge[236, 376] -> 
             RGBColor[
              0.397907468442853, 0.5154535439144465, 0.9470741986312354], 
             UndirectedEdge[206, 386] -> 
             RGBColor[
              0.3854076478953393, 0.5082424662804851, 0.9457788124146576], 
             UndirectedEdge[74, 338] -> 
             RGBColor[
              0.22933498443170014`, 0.35837598768852497`, 0.9363716601414551],
              UndirectedEdge[293, 394] -> 
             RGBColor[
              0.3358774325095808, 0.4653418831743506, 0.9426227908881267], 
             UndirectedEdge[41, 381] -> 
             RGBColor[
              0.19207190760239157`, 0.31921013132539244`, 0.934249583041808], 
             UndirectedEdge[59, 328] -> 
             RGBColor[
              0.22381201159438807`, 0.3525709930598068, 0.9360571350088763], 
             UndirectedEdge[123, 196] -> 
             RGBColor[
              0.8434800761859853, 0.5146723115221958, 0.4543057015240267], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.9124649507944522, 0.7523588106461282, 0.5992692091287142], 
             UndirectedEdge[23, 38] -> 
             RGBColor[
              0.23532272116707456`, 0.36466947864183974`, 0.936712652890472], 
             UndirectedEdge[61, 282] -> 
             RGBColor[
              0.2661448795948803, 0.3964851197604022, 0.9384891805623623], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.2249471629490288, 0.3537641091062871, 0.9361217801992172], 
             UndirectedEdge[3, 232] -> 
             RGBColor[
              0.21328768495463646`, 0.3415092584805786, 0.9354577901760884], 
             UndirectedEdge[110, 362] -> 
             RGBColor[
              0.8221167873663267, 0.8612297040031928, 0.982833840996466], 
             UndirectedEdge[125, 252] -> 
             RGBColor[
              0.19926974690677848`, 0.32677551680367367`, 0.934659489341944], 
             UndirectedEdge[49, 327] -> 
             RGBColor[
              0.18473066760764006`, 0.3114940226294092, 0.9338315102844983], 
             UndirectedEdge[89, 291] -> 
             RGBColor[
              0.2138432095506144, 0.34209315005324514`, 0.9354894264800044], 
             UndirectedEdge[34, 250] -> 
             RGBColor[
              0.1883288985198916, 0.31527599145920215`, 0.9340364242118455], 
             UndirectedEdge[125, 226] -> 
             RGBColor[
              0.1922514050569324, 0.3193987945309108, 0.9342598051563016], 
             UndirectedEdge[3, 14] -> 
             RGBColor[
              0.28743237026540935`, 0.41667525783150516`, 0.9397814519424676],
              UndirectedEdge[105, 345] -> 
             RGBColor[
              0.9066930101053883, 0.9269728190997042, 0.9383535848392048], 
             UndirectedEdge[88, 336] -> 
             RGBColor[
              0.33259846324686315`, 0.4556650882287947, 0.9426641835505155], 
             UndirectedEdge[162, 357] -> 
             RGBColor[
              0.1906502583880034, 0.3177158878633042, 0.9341686222221902], 
             UndirectedEdge[279, 328] -> 
             RGBColor[
              0.215194282730263, 0.3435132136280431, 0.9355663680988517], 
             UndirectedEdge[312, 359] -> 
             RGBColor[
              0.4367530973615871, 0.5501494570425497, 0.9497594529493274], 
             UndirectedEdge[202, 289] -> 
             RGBColor[
              0.4009029468034172, 0.5210963292936249, 0.9469229296248474], 
             UndirectedEdge[27, 48] -> 
             RGBColor[
              0.20648582903789775`, 0.33436007664951256`, 0.9350704345440743],
              UndirectedEdge[115, 193] -> 
             RGBColor[
              0.8965180032601808, 0.866664933881647, 0.6335702357029284], 
             UndirectedEdge[117, 385] -> 
             RGBColor[
              0.776474593776608, 0.8214741220909348, 0.7960777027150834], 
             UndirectedEdge[179, 352] -> 
             RGBColor[
              0.20659936567779108`, 0.3344794108566792, 0.9350769002877538], 
             UndirectedEdge[8, 365] -> 
             RGBColor[
              0.2808078228071327, 0.4124772043875522, 0.9393029621396956], 
             UndirectedEdge[105, 353] -> 
             RGBColor[
              0.9892810453920724, 0.988090926321853, 0.7004958160747115], 
             UndirectedEdge[231, 392] -> 
             RGBColor[
              0.1971344084334818, 0.32453114067996, 0.9345378849748398], 
             UndirectedEdge[109, 132] -> 
             RGBColor[
              0.1878121680467173, 0.3147328749692917, 0.9340069971758325], 
             UndirectedEdge[23, 158] -> 
             RGBColor[
              0.20153001639620693`, 0.3291512033464258, 0.9347882083455978], 
             UndirectedEdge[105, 350] -> 
             RGBColor[
              0.6669237794423443, 0.7322521297415084, 0.9183362922108259], 
             UndirectedEdge[172, 351] -> 
             RGBColor[
              0.3445890788111915, 0.47288747334073133`, 0.943177889287059], 
             UndirectedEdge[34, 375] -> 
             RGBColor[
              0.19286667153168213`, 0.3200454786060204, 0.9342948436718334], 
             UndirectedEdge[32, 391] -> 
             RGBColor[
              0.8210906486573005, 0.1631175443269919, 0.16782973501369886`], 
             UndirectedEdge[140, 241] -> 
             RGBColor[
              0.343629032390773, 0.46948243111537313`, 0.9432109443563187], 
             UndirectedEdge[89, 336] -> 
             RGBColor[
              0.23351345559029374`, 0.36276782580657996`, 0.9366096178924429],
              UndirectedEdge[74, 118] -> 
             RGBColor[
              0.3029906205258713, 0.4312899550504897, 0.9407311083477143], 
             UndirectedEdge[138, 328] -> 
             RGBColor[
              0.2601284224261766, 0.3907418434374549, 0.9381253008804314], 
             UndirectedEdge[189, 207] -> 
             RGBColor[
              0.2123454769342431, 0.3405189381117063, 0.935404132823199], 
             UndirectedEdge[273, 281] -> 
             RGBColor[
              0.46139853851670076`, 0.5721415288193888, 0.9511515046102453], 
             UndirectedEdge[49, 225] -> 
             RGBColor[
              0.19609003670444464`, 0.3234334397757498, 0.9344784095498806], 
             UndirectedEdge[43, 159] -> 
             RGBColor[
              0.1884193222929882, 0.31537103257792504`, 0.9340415737119533], 
             UndirectedEdge[113, 368] -> 
             RGBColor[
              0.18474082389280244`, 0.3115046975290605, 0.9338320886699134], 
             UndirectedEdge[11, 83] -> 
             RGBColor[0.9120888802991098, 0.9323447493793293, 0.977810506555],
              UndirectedEdge[151, 344] -> 
             RGBColor[
              0.1995874063553662, 0.3271093970249116, 0.9346775795776059], 
             UndirectedEdge[182, 377] -> 
             RGBColor[
              0.2482608696505907, 0.3782682930240088, 0.9374494613063329], 
             UndirectedEdge[198, 203] -> 
             RGBColor[
              0.5694035624452959, 0.6546305646490294, 0.9622535793690412], 
             UndirectedEdge[208, 395] -> 
             RGBColor[
              0.366549438606146, 0.4905837118311563, 0.9446256885343254], 
             UndirectedEdge[305, 339] -> 
             RGBColor[
              0.3400084902177303, 0.4679319523924049, 0.9429221954121405], 
             UndirectedEdge[9, 313] -> 
             RGBColor[
              0.4854882204226317, 0.5856947625868548, 0.9544467086526902], 
             UndirectedEdge[267, 317] -> 
             RGBColor[
              0.1930340826347562, 0.32022143828982824`, 0.9343043774864909], 
             UndirectedEdge[306, 350] -> 
             RGBColor[
              0.2854226113571807, 0.41364792547081863`, 0.9397004998858718], 
             UndirectedEdge[111, 362] -> 
             RGBColor[
              0.8148316917162097, 0.4159938513198287, 0.44202142792485233`], 
             UndirectedEdge[104, 261] -> 
             RGBColor[
              0.20662637490864183`, 0.3345077992707875, 0.9350784384234943], 
             UndirectedEdge[243, 363] -> 
             RGBColor[
              0.302959879941956, 0.42967862832344433`, 0.9407871732432331], 
             UndirectedEdge[154, 369] -> 
             RGBColor[
              0.183389073095449, 0.31008392173509136`, 0.9337551084617403], 
             UndirectedEdge[218, 282] -> 
             RGBColor[
              0.4376499441056336, 0.5505879476107286, 0.9499100761220066], 
             UndirectedEdge[7, 293] -> 
             RGBColor[
              0.28453912176058604`, 0.41590127160719004`, 0.9395336796939777],
              UndirectedEdge[24, 167] -> 
             RGBColor[
              0.24799412206051685`, 0.37798792439406714`, 0.9374342704256958],
              UndirectedEdge[326, 363] -> 
             RGBColor[
              0.3080486907375876, 0.43502729111889293`, 0.9410769734898234], 
             UndirectedEdge[276, 282] -> 
             RGBColor[
              0.3470343998180849, 0.475005487491495, 0.9433337029793059], 
             UndirectedEdge[337, 345] -> 
             RGBColor[
              0.8925314756364031, 0.9165956294995268, 0.9705858474056119], 
             UndirectedEdge[107, 124] -> 
             RGBColor[
              0.22484989821780513`, 0.3536618777068309, 0.9361162411166642], 
             UndirectedEdge[128, 227] -> 
             RGBColor[
              0.28894688934847723`, 0.42103187936912945`, 0.9397664699385552],
              UndirectedEdge[25, 365] -> 
             RGBColor[
              0.33498940880084865`, 0.4643204052534886, 0.9425754453427104], 
             UndirectedEdge[97, 363] -> 
             RGBColor[
              0.3365752811245841, 0.4650105463059218, 0.9427015206110543], 
             UndirectedEdge[13, 373] -> 
             RGBColor[
              0.2056740334145861, 0.3335068279785967, 0.9350242039842707], 
             UndirectedEdge[64, 195] -> 
             RGBColor[
              0.7086017617355334, 0.7643768316855696, 0.6913028233561538], 
             UndirectedEdge[77, 96] -> 
             RGBColor[
              0.20429069166020342`, 0.3320528480858075, 0.9349454247178293], 
             UndirectedEdge[6, 53] -> 
             RGBColor[
              0.6643840547861006, 0.7335496374888852, 0.969847038397682], 
             UndirectedEdge[216, 343] -> 
             RGBColor[
              0.20826813355084325`, 0.33623339169725125`, 0.9351719341494034],
              UndirectedEdge[26, 324] -> 
             RGBColor[
              0.1839722969253371, 0.31069692695883033`, 0.9337883221960501], 
             UndirectedEdge[142, 281] -> 
             RGBColor[
              0.436455413320613, 0.55189157611022, 0.9491878904251312], 
             UndirectedEdge[100, 341] -> 
             RGBColor[
              0.3185278490681524, 0.4448223795517722, 0.9417183858910539], 
             UndirectedEdge[115, 364] -> 
             RGBColor[
              0.9382231077008898, 0.7927822385027005, 0.26915106624734497`], 
             UndirectedEdge[150, 152] -> 
             RGBColor[
              0.21962526952820027`, 0.3481704616934645, 0.9358187062419367], 
             UndirectedEdge[10, 68] -> 
             RGBColor[
              0.8358461850878253, 0.5077093600050204, 0.4534679492170056], 
             UndirectedEdge[190, 288] -> 
             RGBColor[
              0.21294330855938015`, 0.3411472970544397, 0.9354381784498378], 
             UndirectedEdge[23, 146] -> 
             RGBColor[
              0.20552449462249126`, 0.333349653226798, 0.9350156879712836], 
             UndirectedEdge[188, 201] -> 
             RGBColor[
              0.47076164268683474`, 0.5730017553920743, 0.9531670568538995], 
             UndirectedEdge[148, 382] -> 
             RGBColor[
              0.2893244860141426, 0.42019446169141983`, 0.9398331671225094], 
             UndirectedEdge[14, 71] -> 
             RGBColor[
              0.6541765961305002, 0.7223342652348994, 0.9394835143282855], 
             UndirectedEdge[228, 276] -> 
             RGBColor[
              0.3015266164865197, 0.4277543234766833, 0.9407208506945814], 
             UndirectedEdge[56, 174] -> 
             RGBColor[
              0.4681168777823908, 0.5781139671930625, 0.9515372200266019], 
             UndirectedEdge[16, 182] -> 
             RGBColor[
              0.23539065510704868`, 0.36474088152001305`, 0.9367165216278543],
              UndirectedEdge[104, 192] -> 
             RGBColor[
              0.24115781649194606`, 0.3708025337946915, 0.9370449529369735], 
             UndirectedEdge[145, 395] -> 
             RGBColor[
              0.3442769835307749, 0.46717394939172724`, 0.9433573051669275], 
             UndirectedEdge[219, 251] -> 
             RGBColor[
              0.1819264333571092, 0.30854659463338063`, 0.9336718132924233], 
             UndirectedEdge[150, 179] -> 
             RGBColor[
              0.23260992772492337`, 0.36181816073310025`, 0.9365581633171598],
              UndirectedEdge[73, 207] -> 
             RGBColor[
              0.1950145063297256, 0.32230298915935574`, 0.934417159686145], 
             UndirectedEdge[265, 325] -> 
             RGBColor[
              0.2186342581575027, 0.34712884590911136`, 0.9357622696104455], 
             UndirectedEdge[39, 314] -> 
             RGBColor[
              0.19046396107769498`, 0.3175200775782383, 0.9341580128659703], 
             UndirectedEdge[20, 263] -> 
             RGBColor[
              0.3432288815576954, 0.4710700975490908, 0.943114624476095], 
             UndirectedEdge[66, 146] -> 
             RGBColor[
              0.19762825714734855`, 0.3250502069900508, 0.9345660089285108], 
             UndirectedEdge[7, 21] -> 
             RGBColor[
              0.22580819870592864`, 0.3546691122796089, 0.9361708149117844], 
             UndirectedEdge[107, 167] -> 
             RGBColor[
              0.22944380789788385`, 0.3584903680512903, 0.9363778574768644], 
             UndirectedEdge[120, 195] -> 
             RGBColor[
              0.41858299206596217`, 0.5369772819597975, 0.9478927160094046], 
             UndirectedEdge[365, 388] -> 
             RGBColor[
              0.2883992345699991, 0.4204562594736305, 0.9397352818091035], 
             UndirectedEdge[134, 342] -> 
             RGBColor[
              0.18275455563161122`, 0.309417003649867, 0.9337189736308591], 
             UndirectedEdge[227, 311] -> 
             RGBColor[
              0.23829401063491945`, 0.3677924922631779, 0.9368818634300369], 
             UndirectedEdge[78, 377] -> 
             RGBColor[
              0.2375799153602678, 0.3670419328532635, 0.9368411967605548], 
             UndirectedEdge[21, 370] -> 
             RGBColor[
              0.19110729661804693`, 0.31819626402097745`, 0.9341946498732637],
              UndirectedEdge[2, 230] -> 
             RGBColor[
              0.2114753909347174, 0.33960442255956613`, 0.9353545827127028], 
             UndirectedEdge[24, 203] -> 
             RGBColor[
              0.2850956592214299, 0.4168671679331099, 0.9395514255934152], 
             UndirectedEdge[54, 206] -> 
             RGBColor[
              0.6885711015156095, 0.68922695188861, 0.6128856824256679], 
             UndirectedEdge[66, 130] -> 
             RGBColor[
              0.20589531196195676`, 0.3337394057617535, 0.9350368054701912], 
             UndirectedEdge[101, 356] -> 
             RGBColor[
              0.8844436842834248, 0.5968435371658081, 0.458657605896074], 
             UndirectedEdge[222, 383] -> 
             RGBColor[
              0.6547025238599551, 0.723910051109828, 0.9558664767641599], 
             UndirectedEdge[31, 247] -> 
             RGBColor[
              0.8729786261707051, 0.41877199639199914`, 0.4130055274330995], 
             UndirectedEdge[46, 333] -> 
             RGBColor[
              0.8796565038002286, 0.9065288389378603, 0.9721902291244133], 
             UndirectedEdge[287, 385] -> 
             RGBColor[
              0.8763518611868132, 0.41957403354722944`, 0.320734201704575], 
             UndirectedEdge[42, 330] -> 
             RGBColor[
              0.18629301045548374`, 0.31313614402075074`, 0.9339204833984038],
              UndirectedEdge[151, 227] -> 
             RGBColor[
              0.2408020759927813, 0.3704286279748189, 0.937024694041817], 
             UndirectedEdge[36, 382] -> 
             RGBColor[
              0.2838749254794549, 0.4144666280473688, 0.9395228227119613], 
             UndirectedEdge[218, 361] -> 
             RGBColor[
              0.4849252020484565, 0.5915353999172487, 0.952922413754254], 
             UndirectedEdge[196, 334] -> 
             RGBColor[
              0.9021680954325457, 0.8779962725880234, 0.6424622562871629], 
             UndirectedEdge[34, 265] -> 
             RGBColor[
              0.19096709589184307`, 0.31804890416849774`, 0.9341866656493147],
              UndirectedEdge[372, 392] -> 
             RGBColor[
              0.19150446236563495`, 0.31861371040345526`, 0.9342172678750348],
              UndirectedEdge[127, 210] -> 
             RGBColor[
              0.29252473138981117`, 0.4219611356100898, 0.9400738898749681], 
             UndirectedEdge[33, 157] -> 
             RGBColor[
              0.2467253832848012, 0.3766543994981055, 0.9373620176293496], 
             UndirectedEdge[139, 308] -> 
             RGBColor[
              0.25989565930435055`, 0.3904971946383813, 0.9381120453649856], 
             UndirectedEdge[38, 146] -> 
             RGBColor[
              0.2289275307271461, 0.3579477280109817, 0.9363484562557545], 
             UndirectedEdge[55, 68] -> 
             RGBColor[
              0.8126708442680417, 0.8535970039103761, 0.981959617507143], 
             UndirectedEdge[35, 392] -> 
             RGBColor[
              0.19658094676972326`, 0.3239494173798535, 0.934506366151862], 
             UndirectedEdge[51, 126] -> 
             RGBColor[
              0.1918840790772874, 0.31901271163649164`, 0.9342388864851707], 
             UndirectedEdge[130, 243] -> 
             RGBColor[
              0.22352868317149505`, 0.3522731969232867, 0.9360409998743393], 
             UndirectedEdge[12, 203] -> 
             RGBColor[
              0.2763975204564685, 0.40772487259728496`, 0.9390560794584938], 
             UndirectedEdge[182, 395] -> 
             RGBColor[
              0.3402542515552627, 0.4629458030295253, 0.9431282165320207], 
             UndirectedEdge[99, 382] -> 
             RGBColor[
              0.6121310294998102, 0.6891159199256546, 0.9661376246873524], 
             UndirectedEdge[17, 31] -> 
             RGBColor[
              0.879860588532459, 0.47166977479957617`, 0.4195957023627799], 
             UndirectedEdge[77, 78] -> 
             RGBColor[
              0.20870891214169546`, 0.33669667794321373`, 0.9351970358380788],
              UndirectedEdge[243, 344] -> 
             RGBColor[
              0.2114782278514492, 0.3396074043389222, 0.9353547442709138], 
             UndirectedEdge[305, 313] -> 
             RGBColor[
              0.29133850845533754`, 0.4235456226878492, 0.9399026691086074], 
             UndirectedEdge[189, 280] -> 
             RGBColor[
              0.2210513429116578, 0.3496693552377532, 0.9358999190114381], 
             UndirectedEdge[104, 208] -> 
             RGBColor[
              0.25923359532216883`, 0.3898013234158274, 0.9380743418006362], 
             UndirectedEdge[191, 335] -> 
             RGBColor[
              0.19113672012064215`, 0.3182271899877628, 0.9341963254982084], 
             UndirectedEdge[225, 355] -> 
             RGBColor[
              0.2083112643931653, 0.336278724947185, 0.9351743903870672], 
             UndirectedEdge[308, 348] -> 
             RGBColor[
              0.20697593141094872`, 0.33487520531787435`, 0.9350983451491781],
              UndirectedEdge[132, 149] -> 
             RGBColor[
              0.20160011613108555`, 0.32922488261236305`, 0.9347922004217959],
              UndirectedEdge[128, 224] -> 
             RGBColor[
              0.40082474260241224`, 0.5199417456186857, 0.9471108972900512], 
             UndirectedEdge[192, 225] -> 
             RGBColor[
              0.233374248060821, 0.36262150986683694`, 0.9366016902295785], 
             UndirectedEdge[84, 252] -> 
             RGBColor[
              0.2101141940866254, 0.33817371836735655`, 0.9352770645659143], 
             UndirectedEdge[30, 211] -> 
             RGBColor[
              0.21659401962004457`, 0.3449844258476482, 0.9356460810439997], 
             UndirectedEdge[138, 242] -> 
             RGBColor[
              0.31465187583145326`, 0.4451229547456037, 0.9413374842169753], 
             UndirectedEdge[27, 41] -> 
             RGBColor[
              0.1999138771125005, 0.32745253849010136`, 0.9346961716042546], 
             UndirectedEdge[102, 139] -> 
             RGBColor[
              0.3279891561400408, 0.4583428062151842, 0.9421262587090772], 
             UndirectedEdge[203, 329] -> 
             RGBColor[
              0.28617424693522586`, 0.4180008320067203, 0.9396128495680883], 
             UndirectedEdge[195, 312] -> 
             RGBColor[
              0.48621740603993846`, 0.5929929550712956, 0.9529112749587412], 
             UndirectedEdge[51, 87] -> 
             RGBColor[
              0.1940286984190197, 0.3212668425413722, 0.9343610193840024], 
             UndirectedEdge[83, 366] -> 
             RGBColor[
              0.9721424943326117, 0.9755215245830015, 0.7399924007909114], 
             UndirectedEdge[8, 302] -> 
             RGBColor[
              0.22515004974021374`, 0.353977355987588, 0.936133334301831], 
             UndirectedEdge[146, 344] -> 
             RGBColor[
              0.1953459036771252, 0.3226513087832781, 0.9344360322748211], 
             UndirectedEdge[67, 320] -> 
             RGBColor[
              0.1815572411564681, 0.30815855022236927`, 0.9336507883427678], 
             UndirectedEdge[90, 166] -> 
             RGBColor[
              0.23037172884023532`, 0.35946567179528754`, 0.9364307012017953],
              UndirectedEdge[12, 341] -> 
             RGBColor[
              0.2460644953245124, 0.3759597643491251, 0.9373243810377072], 
             UndirectedEdge[3, 13] -> 
             RGBColor[
              0.2247891692476987, 0.3535980477088099, 0.9361127826916571], 
             UndirectedEdge[153, 341] -> 
             RGBColor[
              0.22749742981872606`, 0.3564446012825976, 0.9362670141246647], 
             UndirectedEdge[192, 351] -> 
             RGBColor[
              0.2839106330866923, 0.41566367352388345`, 0.9394824007008676], 
             UndirectedEdge[12, 150] -> 
             RGBColor[
              0.24059607423843102`, 0.37021210706973123`, 0.937012962546659], 
             UndirectedEdge[99, 393] -> 
             RGBColor[
              0.8120689253181035, 0.8537779307522239, 0.9817268285297311], 
             UndirectedEdge[4, 190] -> 
             RGBColor[
              0.20649883851719153`, 0.33437375043709894`, 0.9350711754146743],
              UndirectedEdge[373, 390] -> 
             RGBColor[
              0.20548402624046883`, 0.3333071183914488, 0.9350133833567951], 
             UndirectedEdge[23, 308] -> 
             RGBColor[
              0.21238372481471685`, 0.3405591390591399, 0.9354063109834092], 
             UndirectedEdge[37, 187] -> 
             RGBColor[
              0.2503393326402117, 0.3804528894082654, 0.9375678266987812], 
             UndirectedEdge[17, 292] -> 
             RGBColor[
              0.8249384204875226, 0.19269320471844653`, 0.1715143656637563], 
             UndirectedEdge[309, 385] -> 
             RGBColor[
              0.845892139078253, 0.8769877648670494, 0.8021186290174642], 
             UndirectedEdge[140, 380] -> 
             RGBColor[
              0.5633644182821813, 0.6539330422248467, 0.9599388244578124], 
             UndirectedEdge[119, 354] -> 
             RGBColor[
              0.21794551615801888`, 0.3464049343988889, 0.9357230467724773], 
             UndirectedEdge[36, 305] -> 
             RGBColor[
              0.2718566625317226, 0.40306896740175535`, 0.9387932068040659], 
             UndirectedEdge[91, 351] -> 
             RGBColor[
              0.45106536887988224`, 0.5613307052601594, 0.9510072153286632], 
             UndirectedEdge[130, 275] -> 
             RGBColor[
              0.2049038205781411, 0.33269728545317867`, 0.934980341502663], 
             UndirectedEdge[46, 102] -> 
             RGBColor[
              0.5772856165740025, 0.6623742905041798, 0.9623565848838942], 
             UndirectedEdge[111, 271] -> 
             RGBColor[
              0.8244089740108874, 0.1886236470941021, 0.17100736711980608`], 
             UndirectedEdge[104, 351] -> 
             RGBColor[
              0.26680200623584566`, 0.3976814219540492, 0.9385080897116571], 
             UndirectedEdge[174, 203] -> 
             RGBColor[
              0.3639226125883841, 0.4896332085668736, 0.9444098049633691], 
             UndirectedEdge[294, 313] -> 
             RGBColor[
              0.24717525119128783`, 0.3771272391910956, 0.937387636941104], 
             UndirectedEdge[206, 266] -> 
             RGBColor[
              0.5435550579217713, 0.6394151913659053, 0.9575592073363473], 
             UndirectedEdge[167, 358] -> 
             RGBColor[
              0.25670178916857006`, 0.3871402346226134, 0.9379301591856604], 
             UndirectedEdge[315, 322] -> 
             RGBColor[
              0.18811052101816012`, 0.31504646285894905`, 0.9340239879361825],
              UndirectedEdge[176, 347] -> 
             RGBColor[
              0.18526445779187303`, 0.3120550699572905, 0.9338619088458187], 
             UndirectedEdge[92, 186] -> 
             RGBColor[
              0.20547576839988674`, 0.33329843887741967`, 0.9350129130849905],
              UndirectedEdge[149, 210] -> 
             RGBColor[
              0.22800345786551077`, 0.3569764688437995, 0.9362958316733276], 
             UndirectedEdge[171, 374] -> 
             RGBColor[
              0.18584495673726414`, 0.3126652111546555, 0.9338949674019874], 
             UndirectedEdge[228, 282] -> 
             RGBColor[
              0.26951575842165965`, 0.40002812713340913`, 0.938681147124779], 
             UndirectedEdge[164, 210] -> 
             RGBColor[
              0.23033673863294363`, 0.3594288948689166, 0.9364287085612534], 
             UndirectedEdge[196, 214] -> 
             RGBColor[
              0.8615229927273951, 0.7108190806524803, 0.6028379622201453], 
             UndirectedEdge[204, 307] -> 
             RGBColor[
              0.17948540198595286`, 0.30598091589196724`, 0.9335328001670183],
              UndirectedEdge[127, 255] -> 
             RGBColor[
              0.35677877005900877`, 0.4834455712278943, 0.9439546056344492], 
             UndirectedEdge[68, 334] -> 
             RGBColor[
              0.8909079727489195, 0.8690177564079877, 0.6413882557335685], 
             UndirectedEdge[16, 269] -> 
             RGBColor[
              0.29117851080203017`, 0.41924857896072276`, 0.9400447358569024],
              UndirectedEdge[68, 337] -> 
             RGBColor[
              0.8892917898500812, 0.9140123919924417, 0.970276843283211], 
             UndirectedEdge[23, 374] -> 
             RGBColor[
              0.19777812141168266`, 0.3252077238338092, 0.9345745434766604], 
             UndirectedEdge[22, 116] -> 
             RGBColor[
              0.24102708216235447`, 0.3706651237252555, 0.9370375078103073], 
             UndirectedEdge[192, 322] -> 
             RGBColor[
              0.2266888241245798, 0.3555947054294877, 0.936220965226608], 
             UndirectedEdge[70, 95] -> 
             RGBColor[
              0.22209777558797966`, 0.3507692223282312, 0.9359595118042963], 
             UndirectedEdge[71, 273] -> 
             RGBColor[
              0.7468748729151091, 0.8007044259307632, 0.9459207863964338], 
             UndirectedEdge[135, 215] -> 
             RGBColor[
              0.5207131115569171, 0.6175984363516078, 0.9569638659378303], 
             UndirectedEdge[161, 283] -> 
             RGBColor[
              0.9057344419097366, 0.6568662450460772, 0.2426421685015519], 
             UndirectedEdge[18, 384] -> 
             RGBColor[
              0.9630602947807589, 0.8804179575228263, 0.3471852898585644], 
             UndirectedEdge[71, 303] -> 
             RGBColor[
              0.9318169667814895, 0.7940843861143203, 0.5846862975193713], 
             UndirectedEdge[32, 353] -> 
             RGBColor[
              0.8787658442944408, 0.4402699152582698, 0.2814095384973163], 
             UndirectedEdge[188, 281] -> 
             RGBColor[
              0.3372802138863956, 0.4635116716468679, 0.9428236756739168], 
             UndirectedEdge[54, 198] -> 
             RGBColor[
              0.8885256847199983, 0.8494376469396148, 0.6303773216350153], 
             UndirectedEdge[271, 385] -> 
             RGBColor[
              0.8781410297151262, 0.43332636687449166`, 0.3224475115078644], 
             UndirectedEdge[150, 206] -> 
             RGBColor[
              0.33364753302286965`, 0.45690710407047097`, 0.9427188232478589],
              UndirectedEdge[317, 346] -> 
             RGBColor[
              0.19596516131412245`, 0.3233021878229641, 0.9344712980811385], 
             UndirectedEdge[146, 243] -> 
             RGBColor[
              0.21526162835688684`, 0.343583998151584, 0.9355702033326591], 
             UndirectedEdge[91, 316] -> 
             RGBColor[
              0.6523585861658432, 0.7275841393423603, 0.9665060682236928], 
             UndirectedEdge[196, 386] -> 
             RGBColor[
              0.5930257483480736, 0.6745638419646864, 0.9640014047404548], 
             UndirectedEdge[151, 306] -> 
             RGBColor[
              0.21495613201977448`, 0.3432629021316925, 0.9355528057682019], 
             UndirectedEdge[27, 376] -> 
             RGBColor[
              0.24560585367761548`, 0.37547770289867644`, 0.937298262074416], 
             UndirectedEdge[280, 387] -> 
             RGBColor[
              0.19723551682458454`, 0.32463741200965124`, 0.9345436429481366],
              UndirectedEdge[308, 354] -> 
             RGBColor[
              0.20447448662716458`, 0.33224602824935756`, 0.9349558915692975],
              UndirectedEdge[327, 349] -> 
             RGBColor[
              0.19208902000720862`, 0.3192281175478443, 0.934250557567947], 
             UndirectedEdge[60, 108] -> 
             RGBColor[
              0.5066936953729514, 0.6051947855450721, 0.9560957540450186], 
             UndirectedEdge[353, 391] -> 
             RGBColor[
              0.8779094088390327, 0.4336869770555928, 0.280589414938012], 
             UndirectedEdge[140, 195] -> 
             RGBColor[
              0.4154824656065883, 0.5342917617776789, 0.9476951532051012], 
             UndirectedEdge[17, 18] -> 
             RGBColor[
              0.8826197426994277, 0.4712313788077837, 0.2590653315299285], 
             UndirectedEdge[87, 205] -> 
             RGBColor[
              0.18600119174785296`, 0.31282942405665615`, 0.9339038647547113],
              UndirectedEdge[221, 256] -> 
             RGBColor[
              0.6811078585940378, 0.7429531062730206, 0.8609992027595657], 
             UndirectedEdge[194, 316] -> 
             RGBColor[
              0.5837905900380065, 0.6719175511327584, 0.9611081443956637], 
             UndirectedEdge[16, 37] -> 
             RGBColor[
              0.25664259349321183`, 0.38707801621458926`, 0.9379267880795208],
              UndirectedEdge[252, 288] -> 
             RGBColor[
              0.20983762189248398`, 0.33788302345562404`, 0.9352613141886098],
              UndirectedEdge[60, 353] -> 
             RGBColor[
              0.8501417981315751, 0.8795216745705272, 0.7395911022292926], 
             UndirectedEdge[206, 286] -> 
             RGBColor[
              0.375065904449271, 0.49928496789863985`, 0.9451198456671187], 
             UndirectedEdge[220, 396] -> 
             RGBColor[
              0.18205118127193512`, 0.30867771260133725`, 0.9336789175016247],
              UndirectedEdge[133, 320] -> 
             RGBColor[
              0.18355649439985816`, 0.3102598921411492, 0.9337646428573487], 
             UndirectedEdge[28, 231] -> 
             RGBColor[
              0.19140134234262995`, 0.31850532472108994`, 0.934211395342277], 
             UndirectedEdge[239, 269] -> 
             RGBColor[
              0.4302703250067166, 0.5456389418366184, 0.9490411897361934], 
             UndirectedEdge[212, 239] -> 
             RGBColor[
              0.542458414688152, 0.6394312043737607, 0.9571234599763494], 
             UndirectedEdge[77, 182] -> 
             RGBColor[
              0.21938986643201835`, 0.34792303811395897`, 0.9358053003838569],
              UndirectedEdge[280, 336] -> 
             RGBColor[
              0.22186501043454393`, 0.3505245713938071, 0.9359462561731533], 
             UndirectedEdge[199, 400] -> 
             RGBColor[
              0.8776553963318527, 0.44386520988537914`, 0.3913209974630636], 
             UndirectedEdge[73, 336] -> 
             RGBColor[
              0.2166564041388005, 0.3450499959322676, 0.9356496337500533], 
             UndirectedEdge[305, 340] -> 
             RGBColor[
              0.2847257211787761, 0.4165951639852536, 0.9395260806559493], 
             UndirectedEdge[259, 350] -> 
             RGBColor[
              0.6219849446227963, 0.6978827145935297, 0.9666587839790601], 
             UndirectedEdge[247, 393] -> 
             RGBColor[
              0.7855497496539053, 0.35042887609417595`, 0.43379895708891325`],
              UndirectedEdge[30, 216] -> 
             RGBColor[
              0.208257693184232, 0.33622241820998533`, 0.93517133958597], 
             UndirectedEdge[291, 387] -> 
             RGBColor[
              0.1905013026165654, 0.3175593259031815, 0.9341601394113672], 
             UndirectedEdge[45, 338] -> 
             RGBColor[
              0.2249286875668965, 0.3537446903082591, 0.9361207280535366], 
             UndirectedEdge[219, 248] -> 
             RGBColor[
              0.1809198934930053, 0.30748865741789405`, 0.933614492336205], 
             UndirectedEdge[158, 354] -> 
             RGBColor[
              0.1936207782086547, 0.3208380925366434, 0.9343377889314861], 
             UndirectedEdge[191, 327] -> 
             RGBColor[
              0.1848862258869851, 0.3116575242439654, 0.9338403690983792], 
             UndirectedEdge[165, 192] -> 
             RGBColor[
              0.24190350365737148`, 0.3715862982848506, 0.9370874187178992], 
             UndirectedEdge[143, 354] -> 
             RGBColor[
              0.1975023339396083, 0.32491785371472337`, 0.9345588377881168], 
             UndirectedEdge[115, 161] -> 
             RGBColor[
              0.9173271064366133, 0.7028272968686928, 0.25196989849468676`], 
             UndirectedEdge[296, 330] -> 
             RGBColor[
              0.18388840354746627`, 0.31060874969954066`, 0.9337835445922895],
              UndirectedEdge[45, 262] -> 
             RGBColor[
              0.30202723660803465`, 0.4296407358190505, 0.9406995556283282], 
             UndirectedEdge[37, 208] -> 
             RGBColor[
              0.289374752338518, 0.42148159049974276`, 0.9397908361028714], 
             UndirectedEdge[306, 348] -> 
             RGBColor[
              0.21170202637769384`, 0.33984263077965143`, 0.9353674892659032],
              UndirectedEdge[189, 263] -> 
             RGBColor[
              0.2675028819703037, 0.39849286798607286`, 0.9385452654419342], 
             UndirectedEdge[2, 50] -> 
             RGBColor[
              0.216476564027812, 0.3448609725730971, 0.935639392121782], 
             UndirectedEdge[241, 331] -> 
             RGBColor[
              0.26094013118712034`, 0.3915950008105146, 0.9381715264935517], 
             UndirectedEdge[135, 213] -> 
             RGBColor[
              0.33038430669065766`, 0.46058401368253077`, 0.9422727737683254],
              UndirectedEdge[49, 349] -> 
             RGBColor[
              0.19105637302960854`, 0.3181427401007867, 0.9341917498502368], 
             UndirectedEdge[256, 319] -> 
             RGBColor[
              0.88573090588642, 0.4972867159645674, 0.37820371506637834`], 
             UndirectedEdge[64, 332] -> 
             RGBColor[
              0.8760650287883015, 0.4207576288274666, 0.25456499993773085`], 
             UndirectedEdge[213, 350] -> 
             RGBColor[
              0.33697931492905076`, 0.46629627834387477`, 0.942693001861539], 
             UndirectedEdge[333, 345] -> 
             RGBColor[
              0.8909301311153961, 0.9154013493777207, 0.9732965059821361], 
             UndirectedEdge[53, 201] -> 
             RGBColor[
              0.5341594365329997, 0.6309589682060907, 0.9570952074204189], 
             UndirectedEdge[9, 384] -> 
             RGBColor[
              0.8099718019563749, 0.7646503394906032, 0.6173962103853706], 
             UndirectedEdge[24, 33] -> 
             RGBColor[
              0.2533855843329195, 0.3836546930808141, 0.9377413062261555], 
             UndirectedEdge[20, 359] -> 
             RGBColor[
              0.3551576814248725, 0.48204146573128925`, 0.9438513113001545], 
             UndirectedEdge[35, 291] -> 
             RGBColor[
              0.19278015708719454`, 0.31995454643953136`, 0.9342899168022064],
              UndirectedEdge[316, 351] -> 
             RGBColor[
              0.5108480401165528, 0.6087959957654421, 0.956444390370581], 
             UndirectedEdge[195, 263] -> 
             RGBColor[
              0.3632251652657039, 0.4883898734545258, 0.9443887699919498], 
             UndirectedEdge[67, 200] -> 
             RGBColor[
              0.1867268102524256, 0.3135920951118324, 0.9339451876550904], 
             UndirectedEdge[232, 277] -> 
             RGBColor[
              0.18773724237763328`, 0.31465412334052256`, 0.9340027302698206],
              UndirectedEdge[88, 120] -> 
             RGBColor[
              0.42147179727410705`, 0.5394794198355211, 0.9480767881227974], 
             UndirectedEdge[247, 271] -> 
             RGBColor[
              0.8182267475230357, 0.1411043452395526, 0.1650872600532131], 
             UndirectedEdge[202, 269] -> 
             RGBColor[
              0.34049741903328384`, 0.46934348329390774`, 0.9429171723441234],
              UndirectedEdge[207, 291] -> 
             RGBColor[
              0.19348889841744987`, 0.3206994785144255, 0.9343302785724756], 
             UndirectedEdge[72, 397] -> 
             RGBColor[
              0.4148581473336097, 0.5334192417760302, 0.947747040377775], 
             UndirectedEdge[200, 298] -> 
             RGBColor[
              0.19975642982426225`, 0.3272870514074283, 0.9346872052141117], 
             UndirectedEdge[233, 389] -> 
             RGBColor[
              0.9817271461205633, 0.9825466050438816, 0.7139976792857294], 
             UndirectedEdge[44, 311] -> 
             RGBColor[
              0.21545480303552692`, 0.34378703698681684`, 0.9355812043448313],
              UndirectedEdge[137, 258] -> 
             RGBColor[
              0.2651486396074914, 0.3960184099951701, 0.9384111948221615], 
             UndirectedEdge[46, 287] -> 
             RGBColor[
              0.8133914916365368, 0.3720881611980434, 0.43656266857292936`], 
             UndirectedEdge[84, 274] -> 
             RGBColor[
              0.20871345876417752`, 0.33670145673171487`, 0.935197294761503], 
             UndirectedEdge[270, 357] -> 
             RGBColor[
              0.1969743042117703, 0.32436286099174727`, 0.9345287672762663], 
             UndirectedEdge[44, 344] -> 
             RGBColor[
              0.20993796520971017`, 0.3379884906441625, 0.9352670285920812], 
             UndirectedEdge[44, 383] -> 
             RGBColor[
              0.29331549171916627`, 0.4210403283755737, 0.9401830698485728], 
             UndirectedEdge[193, 364] -> 
             RGBColor[
              0.8796332391054209, 0.7997224705221349, 0.619984358127655], 
             UndirectedEdge[43, 375] -> 
             RGBColor[
              0.19874644987833204`, 0.3262254984478285, 0.9346296883503225], 
             UndirectedEdge[184, 252] -> 
             RGBColor[
              0.20974713734389644`, 0.3377879184580067, 0.9352561612274277], 
             UndirectedEdge[16, 78] -> 
             RGBColor[
              0.22470970081672578`, 0.3535145213492678, 0.9361082570820762], 
             UndirectedEdge[345, 353] -> 
             RGBColor[
              0.9106717648266294, 0.9268736116959997, 0.7456067906697404], 
             UndirectedEdge[167, 203] -> 
             RGBColor[
              0.2729080188918158, 0.40405718520565725`, 0.9388573575066418], 
             UndirectedEdge[329, 340] -> 
             RGBColor[
              0.2668654692611238, 0.39782290681442484`, 0.9385089657311141], 
             UndirectedEdge[193, 380] -> 
             RGBColor[
              0.7791551569135652, 0.8275462332304435, 0.978584074457042], 
             UndirectedEdge[115, 253] -> 
             RGBColor[
              0.8684975552193938, 0.416338486439171, 0.2087506971171275], 
             UndirectedEdge[113, 270] -> 
             RGBColor[
              0.196796775846464, 0.3241762674238618, 0.9345186572984918], 
             UndirectedEdge[121, 202] -> 
             RGBColor[
              0.2856578369982738, 0.41583248159385067`, 0.9396429608971655], 
             UndirectedEdge[17, 111] -> 
             RGBColor[
              0.8273118204939984, 0.2109361971987341, 0.17378713619032946`], 
             UndirectedEdge[73, 280] -> 
             RGBColor[
              0.2037203723071403, 0.3314534062854026, 0.9349129458743843], 
             UndirectedEdge[127, 242] -> 
             RGBColor[
              0.33988365440933965`, 0.4688118712253543, 0.9428780638050165], 
             UndirectedEdge[19, 211] -> 
             RGBColor[
              0.2160009516459515, 0.344361073804195, 0.9356123067002404], 
             UndirectedEdge[213, 345] -> 
             RGBColor[
              0.5767485455920949, 0.6610169677020706, 0.962710294489918], 
             UndirectedEdge[102, 350] -> 
             RGBColor[
              0.3487900132261258, 0.4765261115858444, 0.9434455691132382], 
             UndirectedEdge[81, 227] -> 
             RGBColor[
              0.2515739104642789, 0.38175050897811513`, 0.9376381340794677], 
             UndirectedEdge[144, 218] -> 
             RGBColor[
              0.5707667888209911, 0.662413217772521, 0.9593519988850778], 
             UndirectedEdge[130, 354] -> 
             RGBColor[
              0.2058823112495472, 0.3337257411887183, 0.9350360650988523], 
             UndirectedEdge[104, 327] -> 
             RGBColor[
              0.20490625211316982`, 0.332699841150662, 0.9349804799749857], 
             UndirectedEdge[10, 253] -> 
             RGBColor[
              0.8370421980658134, 0.2857281430943435, 0.18310495674198904`], 
             UndirectedEdge[40, 41] -> 
             RGBColor[
              0.19412189539412833`, 0.3213647984712409, 0.9343663268138622], 
             UndirectedEdge[5, 113] -> 
             RGBColor[
              0.18623312529560537`, 0.31307320092078017`, 0.9339170730271409],
              UndirectedEdge[271, 337] -> 
             RGBColor[
              0.8656615757726001, 0.4256489181689964, 0.43042768826228606`], 
             UndirectedEdge[325, 376] -> 
             RGBColor[
              0.26222548998781436`, 0.392945994406499, 0.9382447257757333], 
             UndirectedEdge[52, 337] -> 
             RGBColor[
              0.9729869409703154, 0.9785763889719264, 0.8948788134240234], 
             UndirectedEdge[246, 260] -> 
             RGBColor[
              0.20281631365008554`, 0.33050318331620854`, 0.9348614610713], 
             UndirectedEdge[22, 290] -> 
             RGBColor[
              0.2497813465899759, 0.3798664106911086, 0.9375360502186867], 
             UndirectedEdge[24, 107] -> 
             RGBColor[
              0.2416314482274979, 0.371300350778743, 0.9370719255636378], 
             UndirectedEdge[314, 369] -> 
             RGBColor[
              0.1815795981118552, 0.30818204879999395`, 0.9336520615383029], 
             UndirectedEdge[187, 208] -> 
             RGBColor[
              0.25538258130493185`, 0.38575366351532014`, 0.9378550322494192],
              UndirectedEdge[9, 174] -> 
             RGBColor[
              0.5520972673558275, 0.6456190088987284, 0.9586092963260144], 
             UndirectedEdge[6, 303] -> 
             RGBColor[
              0.9100466794366213, 0.777602242030947, 0.6130122278904285], 
             UndirectedEdge[100, 198] -> 
             RGBColor[
              0.6082548805926754, 0.6882816237042615, 0.9647291510065205], 
             UndirectedEdge[101, 123] -> 
             RGBColor[
              0.8503684349635493, 0.38815943948458614`, 0.19586617624509287`],
              UndirectedEdge[210, 394] -> 
             RGBColor[
              0.30165291276591666`, 0.42986750752233627`, 0.9406555295205197],
              UndirectedEdge[213, 227] -> 
             RGBColor[
              0.29970260204538113`, 0.43079580390036054`, 0.94043541584355], 
             UndirectedEdge[32, 46] -> 
             RGBColor[
              0.8161914025598732, 0.393609503483597, 0.4392438664351634], 
             UndirectedEdge[303, 391] -> 
             RGBColor[
              0.8447994948383054, 0.3081040680143853, 0.18907473406519165`], 
             UndirectedEdge[248, 251] -> 
             RGBColor[
              0.1839193268501145, 0.3106412520512747, 0.9337853056286283], 
             UndirectedEdge[239, 388] -> 
             RGBColor[
              0.38895939974165, 0.5063474161681534, 0.9465374152784297], 
             UndirectedEdge[205, 277] -> 
             RGBColor[
              0.18513416241600078`, 0.31191812125604473`, 0.9338544887169173],
              UndirectedEdge[308, 378] -> 
             RGBColor[
              0.22654239934249232`, 0.35544080369964637`, 0.9362126265518842],
              UndirectedEdge[119, 130] -> 
             RGBColor[
              0.2277266187202509, 0.3566854933495158, 0.936280066093552], 
             UndirectedEdge[28, 254] -> 
             RGBColor[
              0.1893368412328983, 0.3163354031578313, 0.9340938250582336], 
             UndirectedEdge[217, 314] -> 
             RGBColor[
              0.1955003640293088, 0.322813656406775, 0.9344448285633742], 
             UndirectedEdge[229, 307] -> 
             RGBColor[
              0.18847585942484443`, 0.31543045668816716`, 0.9340447934179733],
              UndirectedEdge[114, 155] -> 
             RGBColor[
              0.18628873221551898`, 0.3131316473192917, 0.933920239758967], 
             UndirectedEdge[226, 288] -> 
             RGBColor[
              0.20281928004263788`, 0.3305063011828612, 0.9348616300029674], 
             UndirectedEdge[217, 231] -> 
             RGBColor[
              0.19972682323934088`, 0.32725593300951006`, 0.9346855191628995],
              UndirectedEdge[151, 346] -> 
             RGBColor[
              0.2055192492348853, 0.3333441399918473, 0.9350153892542195], 
             UndirectedEdge[114, 180] -> 
             RGBColor[
              0.18755106204056693`, 0.3144584360017507, 0.9339921275750538], 
             UndirectedEdge[215, 345] -> 
             RGBColor[
              0.7670773504583543, 0.8180313903711476, 0.977401386659423], 
             UndirectedEdge[190, 252] -> 
             RGBColor[
              0.20904698368177904`, 0.3370520125668152, 0.9352162885121547], 
             UndirectedEdge[275, 311] -> 
             RGBColor[
              0.19837020308391207`, 0.32583003921146847`, 0.9346082616519875],
              UndirectedEdge[75, 320] -> 
             RGBColor[
              0.18280885155031829`, 0.3094740721029882, 0.933722065703106], 
             UndirectedEdge[169, 393] -> 
             RGBColor[
              0.5896152402179853, 0.6764956737968535, 0.9616696419121211], 
             UndirectedEdge[80, 182] -> 
             RGBColor[
              0.22246710481821064`, 0.35115741076602963`, 0.9359805445575843],
              UndirectedEdge[239, 362] -> 
             RGBColor[
              0.6492041088152176, 0.7238110272281775, 0.9670865002427318], 
             UndirectedEdge[171, 342] -> 
             RGBColor[
              0.18722373291059582`, 0.31411439233228555`, 0.933973486665342], 
             UndirectedEdge[107, 157] -> 
             RGBColor[
              0.2349712471793796, 0.36430005719603437`, 0.936692636966832], 
             UndirectedEdge[116, 286] -> 
             RGBColor[
              0.28063230469456346`, 0.41113725310534854`, 0.9393352740823563],
              UndirectedEdge[37, 117] -> 
             RGBColor[
              0.4214315538332871, 0.5343304799664346, 0.9489462154343377], 
             UndirectedEdge[111, 222] -> 
             RGBColor[
              0.8681038869231676, 0.45805238435921003`, 0.4379714781522483], 
             UndirectedEdge[57, 72] -> 
             RGBColor[
              0.4069178401688355, 0.5265417468013449, 0.9472410910265736], 
             UndirectedEdge[8, 323] -> 
             RGBColor[
              0.3381102648791732, 0.4623620160236, 0.9429449845379104], 
             UndirectedEdge[115, 356] -> 
             RGBColor[
              0.9502457162134885, 0.9092562156396481, 0.6300362544566458], 
             UndirectedEdge[129, 391] -> 
             RGBColor[
              0.8196355123081763, 0.15193272870280924`, 0.16643629480243607`],
              UndirectedEdge[271, 303] -> 
             RGBColor[
              0.8446451878986901, 0.3069179972587709, 0.1889269695655514], 
             UndirectedEdge[141, 196] -> 
             RGBColor[
              0.5999457128672814, 0.6805575674236943, 0.9644423387605343], 
             UndirectedEdge[8, 117] -> 
             RGBColor[
              0.40706513411417244`, 0.5192304619580248, 0.9481280690845475], 
             UndirectedEdge[278, 330] -> 
             RGBColor[
              0.18839714683821507`, 0.31534772476895345`, 0.9340403108526096],
              UndirectedEdge[95, 276] -> 
             RGBColor[
              0.3131382201938357, 0.4399588551912694, 0.9413821143478849], 
             UndirectedEdge[114, 268] -> 
             RGBColor[
              0.18716896902427724`, 0.3140568320155338, 0.9339703679430321], 
             UndirectedEdge[95, 148] -> 
             RGBColor[
              0.2518920934922597, 0.3820849395144922, 0.9376562541322015], 
             UndirectedEdge[236, 366] -> 
             RGBColor[
              0.7514680031030527, 0.8004311372612268, 0.7333352246803804], 
             UndirectedEdge[108, 378] -> 
             RGBColor[
              0.2733003143570183, 0.40458633700295354`, 0.938875420639825], 
             UndirectedEdge[33, 107] -> 
             RGBColor[
              0.23483527017028652`, 0.36415713673803723`, 0.9366848932773241],
              UndirectedEdge[309, 362] -> 
             RGBColor[
              0.7443188002522516, 0.8001867708802417, 0.9751504000206381], 
             UndirectedEdge[178, 278] -> 
             RGBColor[
              0.18555079143571185`, 0.31235602477156665`, 0.9338782151232425],
              UndirectedEdge[21, 232] -> 
             RGBColor[
              0.19351392550506752`, 0.32072578357032067`, 0.9343317038280912],
              UndirectedEdge[20, 140] -> 
             RGBColor[
              0.3954861818985797, 0.5169719858722439, 0.9464210076892463], 
             UndirectedEdge[33, 150] -> 
             RGBColor[
              0.24249803494618108`, 0.37221118836485045`, 0.9371212763952667],
              UndirectedEdge[38, 213] -> 
             RGBColor[
              0.2920695594579869, 0.42277299217815684`, 0.9400007253602725], 
             UndirectedEdge[86, 262] -> 
             RGBColor[
              0.31621623896980977`, 0.44455427693598626`, 0.9415075983220833],
              UndirectedEdge[17, 310] -> 
             RGBColor[
              0.8272800217278339, 0.2106917779476853, 0.17375668565593874`], 
             UndirectedEdge[222, 223] -> 
             RGBColor[
              0.8898400477329558, 0.6234245980125831, 0.45871942604339044`], 
             UndirectedEdge[19, 124] -> 
             RGBColor[
              0.21306575741872125`, 0.34127599856931323`, 0.9354451517312304],
              UndirectedEdge[184, 274] -> 
             RGBColor[
              0.20834640202144852`, 0.33631565682236503`, 0.9351763914230165],
              UndirectedEdge[195, 360] -> 
             RGBColor[
              0.5436868916256435, 0.6393368239296271, 0.957649106135095], 
             UndirectedEdge[186, 378] -> 
             RGBColor[
              0.22340907061728948`, 0.35214747654494266`, 0.9360341881163283],
              UndirectedEdge[31, 169] -> 
             RGBColor[
              0.7207585549931849, 0.779010354243588, 0.9304794974284005], 
             UndirectedEdge[4, 84] -> 
             RGBColor[
              0.20756604892203795`, 0.3354954562376403, 0.935131951468434], 
             UndirectedEdge[81, 383] -> 
             RGBColor[
              0.2937367673363199, 0.42148311575961905`, 0.9402070608717483], 
             UndirectedEdge[327, 335] -> 
             RGBColor[
              0.19201380881889718`, 0.3191490658202642, 0.9342462744020376], 
             UndirectedEdge[11, 214] -> 
             RGBColor[
              0.8760571062553216, 0.722408188261647, 0.6042242389431952], 
             UndirectedEdge[15, 35] -> 
             RGBColor[
              0.1861148468094702, 0.312948882732563, 0.933910337242333], 
             UndirectedEdge[151, 354] -> 
             RGBColor[
              0.20185675911317996`, 0.3294946306586492, 0.934806815859957], 
             UndirectedEdge[91, 192] -> 
             RGBColor[
              0.4254211791359827, 0.5344518171008017, 0.9495440785539795], 
             UndirectedEdge[44, 130] -> 
             RGBColor[
              0.22198842052975598`, 0.350654283228527, 0.9359532841955067], 
             UndirectedEdge[195, 356] -> 
             RGBColor[
              0.6850009171912799, 0.7504962345412768, 0.9628064219580481], 
             UndirectedEdge[226, 315] -> 
             RGBColor[
              0.186507225222572, 0.3133612973229612, 0.9339326826124872], 
             UndirectedEdge[65, 206] -> 
             RGBColor[
              0.4026912595828178, 0.5232126620245969, 0.9468801088680859], 
             UndirectedEdge[287, 400] -> 
             RGBColor[
              0.8189177394363433, 0.14641561187982197`, 0.1657489546897602], 
             UndirectedEdge[247, 319] -> 
             RGBColor[
              0.822373957683161, 0.17298161984935592`, 0.16905863318615305`], 
             UndirectedEdge[55, 72] -> 
             RGBColor[
              0.6346370252408752, 0.7117938428167392, 0.9660702931075245], 
             UndirectedEdge[313, 329] -> 
             RGBColor[
              0.27347825653768526`, 0.4047733655170204, 0.9388855541837721], 
             UndirectedEdge[5, 357] -> 
             RGBColor[
              0.1864106536609117, 0.3132597944886656, 0.9339271830049154], 
             UndirectedEdge[39, 328] -> 
             RGBColor[
              0.21476290196670605`, 0.3430598050944246, 0.9355418016025379], 
             UndirectedEdge[310, 384] -> 
             RGBColor[
              0.8622060383227799, 0.39468052511930574`, 0.20382345293974308`],
              UndirectedEdge[66, 344] -> 
             RGBColor[
              0.19384485664191092`, 0.32107361317738903`, 0.9343505498667657],
              UndirectedEdge[271, 391] -> 
             RGBColor[
              0.8200799062622772, 0.15534853536870052`, 0.16686184695475423`],
              UndirectedEdge[203, 211] -> 
             RGBColor[
              0.27124930343896736`, 0.4023137700960795, 0.9387628961154517], 
             UndirectedEdge[100, 203] -> 
             RGBColor[
              0.3488608742001085, 0.47658748779993204`, 0.9434500843118405], 
             UndirectedEdge[323, 377] -> 
             RGBColor[
              0.3376579889612439, 0.46188664535790686`, 0.9429192280934666], 
             UndirectedEdge[351, 395] -> 
             RGBColor[
              0.37411784951982285`, 0.4984638103693781, 0.9450594364453463], 
             UndirectedEdge[179, 209] -> 
             RGBColor[
              0.24592936800917714`, 0.3758177369731411, 0.9373166857370019], 
             UndirectedEdge[283, 356] -> 
             RGBColor[
              0.9386530516866118, 0.8632951638170323, 0.6207085244635109], 
             UndirectedEdge[77, 80] -> 
             RGBColor[
              0.20002934434875747`, 0.3275739018764531, 0.9347027472925409], 
             UndirectedEdge[200, 398] -> 
             RGBColor[
              0.18742715801975252`, 0.3143282050199061, 0.933985071424368], 
             UndirectedEdge[280, 368] -> 
             RGBColor[
              0.19638103924398845`, 0.323739301895437, 0.934494981714008], 
             UndirectedEdge[3, 390] -> 
             RGBColor[
              0.22459916207358144`, 0.353398338121662, 0.9361019620641815], 
             UndirectedEdge[64, 380] -> 
             RGBColor[
              0.8564837144111264, 0.8840181121327374, 0.7035464946088651], 
             UndirectedEdge[139, 186] -> 
             RGBColor[
              0.2567623305791477, 0.38720386748367763`, 0.9379336069294297], 
             UndirectedEdge[160, 245] -> 
             RGBColor[
              0.19509478987731566`, 0.3223873722581438, 0.9344217317154114], 
             UndirectedEdge[64, 360] -> 
             RGBColor[
              0.8276703795499445, 0.8615089159497265, 0.7006746506658257], 
             UndirectedEdge[72, 337] -> 
             RGBColor[
              0.7112579708229148, 0.7722092308988048, 0.9543875188835923], 
             UndirectedEdge[11, 141] -> 
             RGBColor[
              0.6144798263952078, 0.6921466750328611, 0.9658286154835842], 
             UndirectedEdge[62, 223] -> 
             RGBColor[
              0.9034121684337133, 0.6327035931146356, 0.3979909556022818], 
             UndirectedEdge[351, 399] -> 
             RGBColor[
              0.33446531711843736`, 0.46411877979752536`, 0.9425328121440877],
              UndirectedEdge[205, 232] -> 
             RGBColor[
              0.18775686622597437`, 0.3146747492493529, 0.9340038478189527], 
             UndirectedEdge[175, 379] -> 
             RGBColor[
              0.1863024171876671, 0.3131460310926968, 0.9339210190978857], 
             UndirectedEdge[144, 339] -> 
             RGBColor[
              0.48160738498318656`, 0.5880919933231088, 0.9528684097242202], 
             UndirectedEdge[66, 275] -> 
             RGBColor[
              0.19513571872831864`, 0.3224303910755869, 0.9344240625529272], 
             UndirectedEdge[311, 346] -> 
             RGBColor[
              0.20301118387702347`, 0.33070800428020625`, 0.9348725586424393],
              UndirectedEdge[81, 326] -> 
             RGBColor[
              0.23536377630225702`, 0.36471263019196243`, 0.936714990919685], 
             UndirectedEdge[145, 335] -> 
             RGBColor[
              0.2240686969525251, 0.3528407856460005, 0.9360717528602902], 
             UndirectedEdge[24, 56] -> 
             RGBColor[
              0.3892899244154366, 0.5053479265592988, 0.9466788406566481], 
             UndirectedEdge[310, 319] -> 
             RGBColor[
              0.8284925866386836, 0.2200120832018078, 0.17491783918396456`], 
             UndirectedEdge[131, 303] -> 
             RGBColor[
              0.8540204827009316, 0.7329759435664439, 0.607655802146349], 
             UndirectedEdge[146, 317] -> 
             RGBColor[
              0.19381671894004093`, 0.32104403866869025`, 0.9343489474662702],
              UndirectedEdge[159, 321] -> 
             RGBColor[
              0.1833474210515813, 0.31004014279609426`, 0.9337527364394607], 
             UndirectedEdge[339, 361] -> 
             RGBColor[
              0.39576579821065194`, 0.5172141754678363, 0.9464388245933966], 
             UndirectedEdge[60, 297] -> 
             RGBColor[
              0.5017919184919047, 0.6000427072524873, 0.955816605103172], 
             UndirectedEdge[1, 368] -> 
             RGBColor[
              0.1828231865844723, 0.30948913913277776`, 0.9337228820620942], 
             UndirectedEdge[15, 106] -> 
             RGBColor[
              0.18432449600494816`, 0.311067110522213, 0.933808379412602], 
             UndirectedEdge[144, 282] -> 
             RGBColor[
              0.44814038646858245`, 0.5591045613100133, 0.9507359221725744], 
             UndirectedEdge[333, 391] -> 
             RGBColor[
              0.8647483196982105, 0.42603880217674006`, 0.43238255847960916`],
              UndirectedEdge[85, 238] -> 
             RGBColor[
              0.19138550303315327`, 0.3184886766025597, 0.9342104933170345], 
             UndirectedEdge[130, 135] -> 
             RGBColor[
              0.27550933277442513`, 0.40444794828705827`, 0.9390913012054878],
              UndirectedEdge[194, 256] -> 
             RGBColor[
              0.7238719368935342, 0.7799355863354847, 0.863740011258672], 
             UndirectedEdge[129, 271] -> 
             RGBColor[
              0.8195583588383687, 0.15133969332500205`, 0.16636241255261597`],
              UndirectedEdge[12, 168] -> 
             RGBColor[
              0.22037492795635888`, 0.34895840023254887`, 0.9358613981804], 
             UndirectedEdge[32, 271] -> 
             RGBColor[
              0.8210134951874929, 0.16252450894918472`, 0.16775585276387872`],
              UndirectedEdge[227, 363] -> 
             RGBColor[
              0.3242588248996095, 0.45206516990504564`, 0.9420001166496061], 
             UndirectedEdge[351, 355] -> 
             RGBColor[
              0.2588476494190366, 0.38932088860423164`, 0.9380551008583563], 
             UndirectedEdge[70, 285] -> 
             RGBColor[
              0.1906202345698193, 0.31768433092677273`, 0.9341669124101608], 
             UndirectedEdge[19, 107] -> 
             RGBColor[
              0.211296993265781, 0.33941691529844853`, 0.9353444232293726], 
             UndirectedEdge[88, 359] -> 
             RGBColor[
              0.3780427703410259, 0.5018633795124479, 0.9453095289294022], 
             UndirectedEdge[128, 130] -> 
             RGBColor[
              0.2597826750311079, 0.39037844100358665`, 0.9381056110777697], 
             UndirectedEdge[72, 297] -> 
             RGBColor[
              0.3810483803734705, 0.5030082457772378, 0.9456339650216002], 
             UndirectedEdge[125, 184] -> 
             RGBColor[
              0.20307558723579205`, 0.3307756962936808, 0.934876226318445], 
             UndirectedEdge[41, 63] -> 
             RGBColor[
              0.19205972818458644`, 0.31919732998505956`, 0.9342488894419819],
              UndirectedEdge[67, 133] -> 
             RGBColor[
              0.1814057266970613, 0.30799929891896116`, 0.9336421598184501], 
             UndirectedEdge[272, 308] -> 
             RGBColor[
              0.20474955864050876`, 0.33253514637595527`, 0.9349715565135248],
              UndirectedEdge[199, 287] -> 
             RGBColor[
              0.8744579174591663, 0.41928798612573526`, 0.3882590880835432], 
             UndirectedEdge[60, 333] -> 
             RGBColor[
              0.8304001644203418, 0.8680494122522482, 0.9672808175416883], 
             UndirectedEdge[86, 325] -> 
             RGBColor[
              0.25318562671626305`, 0.38344452494766296`, 0.9377299189356977],
              UndirectedEdge[77, 377] -> 
             RGBColor[
              0.22582310918113752`, 0.35468478413443216`, 0.9361716640412894],
              UndirectedEdge[62, 319] -> 
             RGBColor[
              0.885564206725758, 0.4972177815776606, 0.3809663515621477], 
             UndirectedEdge[52, 199] -> 
             RGBColor[
              0.9888652062926342, 0.9896634908979279, 0.8341958778608433], 
             UndirectedEdge[57, 376] -> 
             RGBColor[
              0.31723897478085683`, 0.4471117135410761, 0.941511560889603], 
             UndirectedEdge[11, 161] -> 
             RGBColor[
              0.8763695857039919, 0.7238270844566292, 0.6044849794547379], 
             UndirectedEdge[155, 300] -> 
             RGBColor[
              0.19103033479495424`, 0.31811537226524556`, 0.9341902670112934],
              UndirectedEdge[81, 275] -> 
             RGBColor[
              0.21165010291327152`, 0.33978805592640576`, 0.9353645323014182],
              UndirectedEdge[100, 266] -> 
             RGBColor[
              0.5229669528809726, 0.6215828095678126, 0.9562473514884939], 
             UndirectedEdge[56, 266] -> 
             RGBColor[
              0.5883098999275997, 0.6764125091387695, 0.9608991949142476], 
             UndirectedEdge[82, 257] -> 
             RGBColor[
              0.8645894369328215, 0.89448136547207, 0.956668495179433], 
             UndirectedEdge[32, 259] -> 
             RGBColor[
              0.8461541179339149, 0.41742311009542027`, 0.44212239578911544`],
              UndirectedEdge[261, 355] -> 
             RGBColor[
              0.19867201809183277`, 0.32614726592096993`, 0.9346254495701933],
              UndirectedEdge[74, 179] -> 
             RGBColor[
              0.23767352171657924`, 0.3671403190687327, 0.9368465275040685], 
             UndirectedEdge[100, 174] -> 
             RGBColor[
              0.4027739307357637, 0.5232842676221057, 0.9468853766008484], 
             UndirectedEdge[208, 388] -> 
             RGBColor[
              0.28259974438226976`, 0.4143606275774112, 0.9394050094224892], 
             UndirectedEdge[249, 299] -> 
             RGBColor[
              0.186005835268804, 0.3128343046915919, 0.9339041291963601], 
             UndirectedEdge[58, 181] -> 
             RGBColor[
              0.19266290312611054`, 0.31983130509210156`, 0.9342832393625844],
              UndirectedEdge[271, 345] -> 
             RGBColor[
              0.8226964117082949, 0.39175550148521254`, 0.4390134962813673], 
             UndirectedEdge[20, 89] -> 
             RGBColor[
              0.30842578765479933`, 0.4344898392135439, 0.9411326397648885], 
             UndirectedEdge[174, 358] -> 
             RGBColor[
              0.34771638286513834`, 0.47271625798382977`, 0.9434826066423876],
              UndirectedEdge[185, 274] -> 
             RGBColor[
              0.19784473283359588`, 0.32527773666164805`, 0.9345783368985956],
              UndirectedEdge[106, 314] -> 
             RGBColor[
              0.18463641563674799`, 0.3113949578320815, 0.9338261427741893], 
             UndirectedEdge[73, 387] -> 
             RGBColor[
              0.19202691052884113`, 0.31916283654811173`, 0.9342470205250366],
              UndirectedEdge[191, 261] -> 
             RGBColor[
              0.18660634868245718`, 0.3134654823640909, 0.9339383275468877], 
             UndirectedEdge[135, 227] -> 
             RGBColor[
              0.3046735470917944, 0.4351013866526011, 0.9407521600662733], 
             UndirectedEdge[102, 345] -> 
             RGBColor[
              0.5885592438891699, 0.6712468009440402, 0.9634628617416172], 
             UndirectedEdge[72, 108] -> 
             RGBColor[
              0.3859501572545172, 0.5081603240698226, 0.9459131139634468], 
             UndirectedEdge[7, 273] -> 
             RGBColor[
              0.3894971814838498, 0.5048902400899095, 0.9467521342900769], 
             UndirectedEdge[111, 385] -> 
             RGBColor[
              0.882547250933544, 0.4671945139777004, 0.32666691392273633`], 
             UndirectedEdge[25, 187] -> 
             RGBColor[
              0.29015449891481293`, 0.4171960722657919, 0.940022163552006], 
             UndirectedEdge[290, 338] -> 
             RGBColor[
              0.2338329245191738, 0.3631036079063329, 0.9366278111753308], 
             UndirectedEdge[133, 200] -> 
             RGBColor[
              0.18872606349581567`, 0.31569343703061226`, 0.9340590421696713],
              UndirectedEdge[64, 88] -> 
             RGBColor[
              0.7114905669436782, 0.7668789695612932, 0.6914868954695467], 
             UndirectedEdge[23, 92] -> 
             RGBColor[
              0.20814505737279243`, 0.33610403083063944`, 0.9351649251431382],
              UndirectedEdge[38, 350] -> 
             RGBColor[
              0.3036355127427933, 0.43279083959174136`, 0.9407376976762094], 
             UndirectedEdge[135, 224] -> 
             RGBColor[
              0.41655140034572946`, 0.5340112529021572, 0.9480965874177693], 
             UndirectedEdge[329, 358] -> 
             RGBColor[
              0.26996801721198005`, 0.40108388142367646`, 0.9386856512471069],
              UndirectedEdge[4, 185] -> 
             RGBColor[
              0.1966973229914563, 0.32407173616757357`, 0.9345129936055264], 
             UndirectedEdge[111, 199] -> 
             RGBColor[
              0.8806533072058972, 0.4669084665562061, 0.39419180030170453`], 
             UndirectedEdge[138, 264] -> 
             RGBColor[
              0.27444206081652406`, 0.4057863849228008, 0.9389404414116314], 
             UndirectedEdge[275, 344] -> 
             RGBColor[
              0.19285336525809532`, 0.32003149286881416`, 0.9342940858992375],
              UndirectedEdge[300, 371] -> 
             RGBColor[
              0.1880971018774196, 0.31503235849120814`, 0.934023223735969], 
             UndirectedEdge[69, 273] -> 
             RGBColor[
              0.5484319039049934, 0.644280752022615, 0.9575937149291112], 
             UndirectedEdge[65, 174] -> 
             RGBColor[
              0.39716489293029483`, 0.5184260009934458, 0.9465279736717613], 
             UndirectedEdge[217, 254] -> 
             RGBColor[
              0.1976623221296092, 0.32508601144625143`, 0.934567948878856], 
             UndirectedEdge[102, 378] -> 
             RGBColor[
              0.29463589617818253`, 0.42328641527644917`, 0.9402268398959757],
              UndirectedEdge[246, 326] -> 
             RGBColor[
              0.22913658446266597`, 0.35816745674178546`, 0.9363603615567251],
              UndirectedEdge[120, 242] -> 
             RGBColor[
              0.3764731339021319, 0.500503839321299, 0.9452095130834909], 
             UndirectedEdge[25, 117] -> 
             RGBColor[
              0.4612467201078884, 0.5710736628239611, 0.9514005522875624], 
             UndirectedEdge[44, 227] -> 
             RGBColor[
              0.25115263484712524`, 0.3813077215940698, 0.9376141430562922], 
             UndirectedEdge[118, 206] -> 
             RGBColor[
              0.39316789594043106`, 0.5149640030957358, 0.9462732885579729], 
             UndirectedEdge[151, 158] -> 
             RGBColor[
              0.19937632863451948`, 0.3268875409572013, 0.9346655590136652], 
             UndirectedEdge[151, 308] -> 
             RGBColor[
              0.2102300370530294, 0.33829547666991544`, 0.9352836616514766], 
             UndirectedEdge[298, 390] -> 
             RGBColor[
              0.2092243065114207, 0.3372383901036854, 0.935226386784977], 
             UndirectedEdge[62, 111] -> 
             RGBColor[
              0.8816760076239252, 0.4673313794612627, 0.3772430077111397], 
             UndirectedEdge[131, 201] -> 
             RGBColor[
              0.7399124857733206, 0.7967445245200704, 0.9747112197727283], 
             UndirectedEdge[291, 368] -> 
             RGBColor[
              0.1896468250359693, 0.3166612157889672, 0.9341114781772385], 
             UndirectedEdge[35, 73] -> 
             RGBColor[
              0.19430576499947028`, 0.3215580570844616, 0.9343767979158759], 
             UndirectedEdge[273, 293] -> 
             RGBColor[
              0.4190878106551068, 0.5354941029446921, 0.9484555024448121], 
             UndirectedEdge[4, 274] -> 
             RGBColor[
              0.2019924165278475, 0.3296372152026416, 0.934814541349035], 
             UndirectedEdge[10, 337] -> 
             RGBColor[
              0.8809711396763451, 0.543324935026861, 0.44508814394619167`], 
             UndirectedEdge[27, 265] -> 
             RGBColor[
              0.20201462184730384`, 0.32966055440128883`, 0.9348158059091283],
              UndirectedEdge[262, 325] -> 
             RGBColor[
              0.3013026030921642, 0.42887910004945207`, 0.9406582888215985], 
             UndirectedEdge[46, 337] -> 
             RGBColor[
              0.8812578483212357, 0.9077231190596664, 0.969479570547889], 
             UndirectedEdge[322, 327] -> 
             RGBColor[
              0.19043725974580353`, 0.3174920127854582, 0.9341564922646202], 
             UndirectedEdge[59, 299] -> 
             RGBColor[
              0.20233103571342284`, 0.3299931254363777, 0.9348338252107113], 
             UndirectedEdge[254, 369] -> 
             RGBColor[
              0.1837415562121556, 0.31045440383947037`, 0.9337751818537847], 
             UndirectedEdge[262, 376] -> 
             RGBColor[
              0.3252561022413611, 0.4540557463948223, 0.9420224051621189], 
             UndirectedEdge[360, 389] -> 
             RGBColor[
              0.8279393932352007, 0.862084309021034, 0.7299551301459482], 
             UndirectedEdge[159, 381] -> 
             RGBColor[
              0.18574510039169012`, 0.3125602558041992, 0.9338892807308311], 
             UndirectedEdge[77, 302] -> 
             RGBColor[
              0.19582677060371215`, 0.3231567304118451, 0.9344634169349113], 
             UndirectedEdge[67, 398] -> 
             RGBColor[
              0.18010682122099816`, 0.306634066908255, 0.9335681890731469], 
             UndirectedEdge[12, 100] -> 
             RGBColor[
              0.315248838603848, 0.44137593165251704`, 0.941531651095973], 
             UndirectedEdge[329, 339] -> 
             RGBColor[
              0.322148238300078, 0.44915969522157617`, 0.9419050804873051], 
             UndirectedEdge[1, 113] -> 
             RGBColor[
              0.18373091059218155`, 0.31044321461790636`, 0.9337745756014759],
              UndirectedEdge[232, 390] -> 
             RGBColor[
              0.20167142330655186`, 0.3292998309749142, 0.9347962612599492], 
             UndirectedEdge[319, 384] -> 
             RGBColor[
              0.8661578349569418, 0.4250557657378013, 0.20760769785953248`], 
             UndirectedEdge[342, 374] -> 
             RGBColor[
              0.18501533393427727`, 0.31179322498759243`, 0.9338477216106742],
              UndirectedEdge[200, 320] -> 
             RGBColor[
              0.18887757795522245`, 0.31585268833402036`, 0.934067670693989], 
             UndirectedEdge[35, 231] -> 
             RGBColor[
              0.19065322565130216`, 0.31771900664516656`, 0.9341687912034454],
              UndirectedEdge[96, 104] -> 
             RGBColor[
              0.21783923349947054`, 0.34629322458604483`, 0.935716994132304], 
             UndirectedEdge[106, 197] -> 
             RGBColor[
              0.18891531916432497`, 0.315892356737718, 0.9340698200000144], 
             UndirectedEdge[41, 265] -> 
             RGBColor[
              0.19689578074158462`, 0.3242803278459065, 0.9345242954808043], 
             UndirectedEdge[52, 303] -> 
             RGBColor[
              0.9414623591594504, 0.8004800076065881, 0.5326277353789215], 
             UndirectedEdge[170, 208] -> 
             RGBColor[
              0.26496099146250607`, 0.3958211798972109, 0.9384005085379051], 
             UndirectedEdge[49, 355] -> 
             RGBColor[
              0.19591924831876065`, 0.3232539303537868, 0.9344686834039748], 
             UndirectedEdge[140, 359] -> 
             RGBColor[
              0.36601815692823686`, 0.491448263748933, 0.9445433311956875], 
             UndirectedEdge[20, 255] -> 
             RGBColor[
              0.37940724758906264`, 0.5030452211240766, 0.9453964722130872], 
             UndirectedEdge[117, 362] -> 
             RGBColor[
              0.6749012549506066, 0.7446731281041272, 0.9691094737182575], 
             UndirectedEdge[188, 293] -> 
             RGBColor[
              0.29496948602480166`, 0.4268642457721712, 0.9401276735084836], 
             UndirectedEdge[149, 155] -> 
             RGBColor[
              0.19811293609800762`, 0.3255596352976139, 0.9345936106777326], 
             UndirectedEdge[7, 188] -> 
             RGBColor[
              0.2653788568535447, 0.3962603829173885, 0.9384243053537484], 
             UndirectedEdge[120, 331] -> 
             RGBColor[
              0.3267582826576653, 0.45117687376714777`, 0.9422711725263158], 
             UndirectedEdge[169, 218] -> 
             RGBColor[
              0.5087675338544672, 0.6120794295560898, 0.9544711904233589], 
             UndirectedEdge[345, 350] -> 
             RGBColor[
              0.5883144988769012, 0.6710348151156551, 0.9634472668058549], 
             UndirectedEdge[147, 217] -> 
             RGBColor[
              0.2277310230294914, 0.3566901225577769, 0.9362803169124476], 
             UndirectedEdge[141, 386] -> 
             RGBColor[
              0.348846857880801, 0.4765753475686286, 0.9434491912043683], 
             UndirectedEdge[128, 383] -> 
             RGBColor[
              0.3311097462205182, 0.46076448615063337`, 0.9423353967308358], 
             UndirectedEdge[138, 394] -> 
             RGBColor[
              0.32326515413332657`, 0.4525833434947314, 0.9418863146939478], 
             UndirectedEdge[132, 300] -> 
             RGBColor[
              0.1945175148280322, 0.3217806195799947, 0.9343888567553567], 
             UndirectedEdge[103, 122] -> 
             RGBColor[
              0.1920779072643653, 0.3192164373505274, 0.9342499247136817], 
             UndirectedEdge[147, 195] -> 
             RGBColor[
              0.3359166803532971, 0.45968692435363845`, 0.9428335921754714], 
             UndirectedEdge[123, 389] -> 
             RGBColor[
              0.8931463007512496, 0.5510568608650397, 0.29027062637419626`], 
             UndirectedEdge[93, 394] -> 
             RGBColor[
              0.35007693853437594`, 0.4776407816051039, 0.9435275708558966], 
             UndirectedEdge[199, 350] -> 
             RGBColor[
              0.6686405102956781, 0.7329620420673324, 0.8898856192140527], 
             UndirectedEdge[66, 158] -> 
             RGBColor[
              0.19363377892106423`, 0.3208517571096786, 0.934338529302825], 
             UndirectedEdge[105, 215] -> 
             RGBColor[
              0.8456866310237973, 0.8792487049970009, 0.932290412064394], 
             UndirectedEdge[253, 364] -> 
             RGBColor[
              0.8572410457828872, 0.37171017753282953`, 0.19969344540027856`],
              UndirectedEdge[76, 78] -> 
             RGBColor[
              0.2517003601981642, 0.38188341566580475`, 0.9376453352047469], 
             UndirectedEdge[153, 358] -> 
             RGBColor[
              0.24162422522743635`, 0.37129275894771363`, 0.9370715142244698],
              UndirectedEdge[54, 64] -> 
             RGBColor[
              0.970419525130984, 0.9095497585157698, 0.3557751825465969], 
             UndirectedEdge[84, 125] -> 
             RGBColor[
              0.20344264397852102`, 0.33116149620303065`, 0.9348971296569317],
              UndirectedEdge[195, 380] -> 
             RGBColor[
              0.5725002264868254, 0.6618460201126379, 0.9605209500781344], 
             UndirectedEdge[81, 146] -> 
             RGBColor[
              0.2141426413323014, 0.3424078718408697, 0.9355064786770019], 
             UndirectedEdge[275, 317] -> 
             RGBColor[
              0.19132418052101102`, 0.3184242227542263, 0.9342070010906866], 
             UndirectedEdge[25, 377] -> 
             RGBColor[
              0.3093279743113551, 0.4373486105761115, 0.941114064611224], 
             UndirectedEdge[180, 232] -> 
             RGBColor[
              0.18939213687360562`, 0.3163935223821609, 0.9340969740631693], 
             UndirectedEdge[52, 333] -> 
             RGBColor[
              0.9713855964493081, 0.9773821088501203, 0.8975894720005477], 
             UndirectedEdge[97, 276] -> 
             RGBColor[
              0.33883500638970604`, 0.46696780675347616`, 0.9428455083067513],
              UndirectedEdge[51, 390] -> 
             RGBColor[
              0.2070958500160861, 0.33500124737515247`, 0.935105174336337], 
             UndirectedEdge[199, 393] -> 
             RGBColor[
              0.8553537557812887, 0.8861695254659845, 0.9046321600313321], 
             UndirectedEdge[169, 224] -> 
             RGBColor[
              0.4775031351026399, 0.5866975822042433, 0.9520099424283488], 
             UndirectedEdge[132, 268] -> 
             RGBColor[
              0.19026708475134468`, 0.3173131480765642, 0.9341468010504371], 
             UndirectedEdge[162, 183] -> 
             RGBColor[
              0.1919904214056781, 0.3191244841661233, 0.9342449425234534], 
             UndirectedEdge[15, 231] -> 
             RGBColor[
              0.18666830847322874`, 0.31353060603266947`, 0.9339418560653108],
              UndirectedEdge[246, 248] -> 
             RGBColor[
              0.19980719089443424`, 0.32734040451061686`, 0.9346900959819637],
              UndirectedEdge[44, 81] -> 
             RGBColor[
              0.22873470286488637`, 0.35774505370175413`, 0.9363374749942621],
              UndirectedEdge[39, 197] -> 
             RGBColor[
              0.19474286460527196`, 0.3220174764838748, 0.9344016900917953], 
             UndirectedEdge[57, 86] -> 
             RGBColor[
              0.30819911150930557`, 0.43761024408224003`, 0.9409967540495674],
              UndirectedEdge[74, 209] -> 
             RGBColor[
              0.2567896978925637, 0.3872326322652657, 0.9379351654574425], 
             UndirectedEdge[115, 389] -> 
             RGBColor[
              0.9741155744429982, 0.9237122058552483, 0.3878131353348738], 
             UndirectedEdge[157, 168] -> 
             RGBColor[
              0.222412865673202, 0.35110040198566517`, 0.9359774557185156], 
             UndirectedEdge[224, 363] -> 
             RGBColor[
              0.4361366781535445, 0.5509750361546019, 0.9493445440011021], 
             UndirectedEdge[47, 279] -> 
             RGBColor[
              0.19002059109890063`, 0.3170540676192452, 0.934132763601585], 
             UndirectedEdge[58, 352] -> 
             RGBColor[
              0.18979453396815193`, 0.3168164672419784, 0.9341198899824106], 
             UndirectedEdge[101, 161] -> 
             RGBColor[
              0.8624979444321746, 0.45922425798517125`, 0.20661336858810134`],
              UndirectedEdge[23, 98] -> 
             RGBColor[
              0.2025842284056299, 0.3302592470092312, 0.9348482441599675], 
             UndirectedEdge[37, 388] -> 
             RGBColor[
              0.27755649571754953`, 0.4090598534703564, 0.9391178038718512], 
             UndirectedEdge[13, 21] -> 
             RGBColor[
              0.2050154097981298, 0.332814572798552, 0.9349866963436598], 
             UndirectedEdge[159, 375] -> 
             RGBColor[
              0.19246854917072223`, 0.3196270267622359, 0.9342721711923458], 
             UndirectedEdge[130, 346] -> 
             RGBColor[
              0.20954480137125253`, 0.3375752505219164, 0.9352446384931148], 
             UndirectedEdge[104, 225] -> 
             RGBColor[
              0.2162656212099744, 0.3446392582970026, 0.935627379240368], 
             UndirectedEdge[226, 252] -> 
             RGBColor[
              0.19892295516503677`, 0.32641101669523676`, 0.9346397400652842],
              UndirectedEdge[64, 283] -> 
             RGBColor[
              0.9622538962308652, 0.8771757609613251, 0.3492049258616166], 
             UndirectedEdge[262, 284] -> 
             RGBColor[
              0.5520990373737982, 0.6433480852372535, 0.9595712205145508], 
             UndirectedEdge[282, 313] -> 
             RGBColor[
              0.2998205585054363, 0.43188039345676055`, 0.940406960657616], 
             UndirectedEdge[88, 360] -> 
             RGBColor[
              0.5465756968337885, 0.6418389618053506, 0.9578331782484879], 
             UndirectedEdge[210, 230] -> 
             RGBColor[
              0.2334030426063412, 0.36265177475985827`, 0.9366033300363481], 
             UndirectedEdge[2, 138] -> 
             RGBColor[
              0.24536530114030092`, 0.3752248669300471, 0.9372845629632816], 
             UndirectedEdge[178, 367] -> 
             RGBColor[
              0.18455036747987072`, 0.3113045157634352, 0.933821242458952], 
             UndirectedEdge[54, 123] -> 
             RGBColor[
              0.8781898086085118, 0.4993404886909019, 0.21838151649392293`], 
             UndirectedEdge[36, 95] -> 
             RGBColor[
              0.2464425329575721, 0.37635710587044113`, 0.9373459097216534], 
             UndirectedEdge[294, 301] -> 
             RGBColor[
              0.22980051567191817`, 0.3588652905383795, 0.9363981714568937], 
             UndirectedEdge[60, 337] -> 
             RGBColor[
              0.8320015089413489, 0.8692436923740543, 0.9645701589651641], 
             UndirectedEdge[251, 275] -> 
             RGBColor[
              0.1895350470293607, 0.3165437300168866, 0.9341051125851229], 
             UndirectedEdge[66, 311] -> 
             RGBColor[
              0.19936169446772767`, 0.32687215952004334`, 0.9346647256195157],
              UndirectedEdge[110, 400] -> 
             RGBColor[
              0.832397701814092, 0.40919298887241484`, 0.44115308767047345`], 
             UndirectedEdge[143, 151] -> 
             RGBColor[
              0.2032578843654731, 0.3309673021352812, 0.934886607870296], 
             UndirectedEdge[157, 206] -> 
             RGBColor[
              0.3378748813614898, 0.46135031520372605`, 0.942959564481942], 
             UndirectedEdge[226, 274] -> 
             RGBColor[
              0.1975222198425889, 0.324938755059595, 0.9345599702608729], 
             UndirectedEdge[86, 265] -> 
             RGBColor[
              0.23354789403514828`, 0.36280402279564555`, 0.9366115791109302],
              UndirectedEdge[64, 389] -> 
             RGBColor[
              0.9928542633450905, 0.9871243167769764, 0.4636088473670069], 
             UndirectedEdge[120, 356] -> 
             RGBColor[
              0.6789656354460096, 0.7452687768356042, 0.9624218591420297], 
             UndirectedEdge[164, 279] -> 
             RGBColor[
              0.20701484030443992`, 0.33491610103189995`, 0.9351005609531018],
              UndirectedEdge[24, 238] -> 
             RGBColor[
              0.23053198107939255`, 0.35963410705922055`, 0.9364398273297434],
              UndirectedEdge[213, 259] -> 
             RGBColor[
              0.6104189913379899, 0.6878648671799451, 0.9659218116631232], 
             UndirectedEdge[73, 162] -> 
             RGBColor[
              0.19690433907813965`, 0.3242893232002557, 0.9345247828654102], 
             UndirectedEdge[257, 356] -> 
             RGBColor[
              0.9574019127188883, 0.9677509967704889, 0.9569916297931109], 
             UndirectedEdge[6, 281] -> 
             RGBColor[
              0.6624572537085711, 0.7318807392393671, 0.9697242643368251], 
             UndirectedEdge[176, 277] -> 
             RGBColor[
              0.18565952896853344`, 0.31247031481291987`, 0.933884407564874], 
             UndirectedEdge[140, 263] -> 
             RGBColor[
              0.35408935706105976`, 0.48047689556673456`, 0.943806644371628], 
             UndirectedEdge[54, 161] -> 
             RGBColor[
              0.9139000708098552, 0.6892402426005217, 0.2492124251865322], 
             UndirectedEdge[7, 142] -> 
             RGBColor[
              0.36455405628776205`, 0.4846402873807406, 0.9447885201049626], 
             UndirectedEdge[81, 311] -> 
             RGBColor[
              0.21587607865268055`, 0.34422982437086214`, 0.9356051953680067],
              UndirectedEdge[204, 237] -> 
             RGBColor[
              0.18108298927677668`, 0.3076600814275077, 0.9336237803998122], 
             UndirectedEdge[134, 374] -> 
             RGBColor[
              0.18137577945827954`, 0.307967822472237, 0.9336404543675045], 
             UndirectedEdge[264, 279] -> 
             RGBColor[
              0.22950792112061041`, 0.35855775511338905`, 0.9363815086300517],
              UndirectedEdge[81, 344] -> 
             RGBColor[
              0.2103592408268638, 0.3384312780282078, 0.9352910196152566], 
             UndirectedEdge[287, 391] -> 
             RGBColor[
              0.8182907377339641, 0.1415962020414383, 0.16514853715146482`], 
             UndirectedEdge[90, 228] -> 
             RGBColor[
              0.21978849971833822`, 0.34834202697269134`, 0.9358280019597877],
              UndirectedEdge[222, 259] -> 
             RGBColor[
              0.9232560562805229, 0.9412465076079086, 0.9787839457914527], 
             UndirectedEdge[143, 342] -> 
             RGBColor[
              0.19264878464975516`, 0.3198164656782889, 0.9342824353362423], 
             UndirectedEdge[68, 262] -> 
             RGBColor[
              0.5929687866565062, 0.6752889407487281, 0.9636412596987081], 
             UndirectedEdge[73, 189] -> 
             RGBColor[
              0.2158427366159144, 0.3441947797762137, 0.9356032965883381], 
             UndirectedEdge[79, 176] -> 
             RGBColor[
              0.19262785863960308`, 0.31979447111483345`, 0.9342812436309215],
              UndirectedEdge[14, 289] -> 
             RGBColor[
              0.4064318553204269, 0.5258851919600367, 0.9472752267865294], 
             UndirectedEdge[126, 373] -> 
             RGBColor[
              0.19027225530167013`, 0.317318582652788, 0.934147095505629], 
             UndirectedEdge[313, 361] -> 
             RGBColor[
              0.3470958164482592, 0.47282784576328063`, 0.9434192982898635], 
             UndirectedEdge[56, 203] -> 
             RGBColor[
              0.4142038212467356, 0.5314171873708888, 0.948101927737594], 
             UndirectedEdge[163, 240] -> 
             RGBColor[
              0.17919351847301027`, 0.305674127813381, 0.9335161778327592], 
             UndirectedEdge[283, 380] -> 
             RGBColor[
              0.8261523609821573, 0.7746449493883936, 0.6184230525835972], 
             UndirectedEdge[165, 318] -> 
             RGBColor[
              0.21949852941857476`, 0.348037249802461, 0.9358114885801888], 
             UndirectedEdge[184, 185] -> 
             RGBColor[
              0.20305130848505737`, 0.330750177787297, 0.9348748436795078], 
             UndirectedEdge[123, 364] -> 
             RGBColor[
              0.869217989589844, 0.4637702159633411, 0.2111625803158437], 
             UndirectedEdge[24, 341] -> 
             RGBColor[
              0.25476263408947386`, 0.38510205968495004`, 0.9378197271726287],
              UndirectedEdge[10, 364] -> 
             RGBColor[
              0.8690908469474348, 0.46279294189952286`, 0.21104082837788557`],
              UndirectedEdge[59, 132] -> 
             RGBColor[
              0.20457320024571096`, 0.33234978252125474`, 0.93496151316384], 
             UndirectedEdge[110, 309] -> 
             RGBColor[
              0.7751646817101416, 0.8245503622153614, 0.9781540938970312], 
             UndirectedEdge[28, 50] -> 
             RGBColor[
              0.21136185866227802`, 0.33948509294287055`, 0.9353481172177434],
              UndirectedEdge[120, 147] -> 
             RGBColor[
              0.3298813986080268, 0.4544594666479659, 0.9424490293594527], 
             UndirectedEdge[322, 335] -> 
             RGBColor[
              0.19668775397946056`, 0.3240616785292556, 0.9345124486644494], 
             UndirectedEdge[9, 198] -> 
             RGBColor[
              0.7575782172127392, 0.8106163649808842, 0.9764530707316865], 
             UndirectedEdge[214, 257] -> 
             RGBColor[
              0.9241708234933428, 0.7599031818045514, 0.5786645333196092], 
             UndirectedEdge[190, 274] -> 
             RGBColor[
              0.20764624835933113`, 0.33557975093117354`, 0.9351365187077434],
              UndirectedEdge[18, 198] -> 
             RGBColor[
              0.9106667100371233, 0.9263839830131071, 0.7062421502048801], 
             UndirectedEdge[280, 291] -> 
             RGBColor[
              0.20219476439486456`, 0.32984989564047235`, 0.9348260647607148],
              UndirectedEdge[156, 179] -> 
             RGBColor[
              0.21434244441768896`, 0.34261787755185935`, 0.9355178571671325],
              UndirectedEdge[76, 96] -> 
             RGBColor[
              0.24728213971667218`, 0.37723958580839845`, 0.9373937240844974],
              UndirectedEdge[143, 158] -> 
             RGBColor[
              0.1950219034609478, 0.3223107640132754, 0.9344175809418251], 
             UndirectedEdge[252, 274] -> 
             RGBColor[
              0.20454056169243495`, 0.3323154773323579, 0.9349596544465153], 
             UndirectedEdge[272, 348] -> 
             RGBColor[
              0.1988777254844435, 0.3263634774332058, 0.9346371643018856], 
             UndirectedEdge[51, 232] -> 
             RGBColor[
              0.19578437289714112`, 0.32311216773406903`, 0.9344610024482438],
              UndirectedEdge[66, 317] -> 
             RGBColor[
              0.19231567190482668`, 0.3194663430628012, 0.9342634650582149], 
             UndirectedEdge[258, 264] -> 
             RGBColor[
              0.24881577416889822`, 0.37885153285572853`, 0.9374810622977428],
              UndirectedEdge[17, 223] -> 
             RGBColor[
              0.8381799008988925, 0.29362230402542056`, 0.1841611101359005], 
             UndirectedEdge[46, 271] -> 
             RGBColor[
              0.8151806601648499, 0.3858404945253056, 0.4382759783762188], 
             UndirectedEdge[93, 201] -> 
             RGBColor[
              0.5041214136186714, 0.6049415425126292, 0.9551812111618987], 
             UndirectedEdge[232, 373] -> 
             RGBColor[
              0.19417254912152382`, 0.3214180387503654, 0.934369211468702], 
             UndirectedEdge[182, 208] -> 
             RGBColor[
              0.2681228139523549, 0.39914445580516655`, 0.9385805696512048], 
             UndirectedEdge[10, 391] -> 
             RGBColor[
              0.8353894701660223, 0.27302455222656513`, 0.18152230263865984`],
              UndirectedEdge[284, 366] -> 
             RGBColor[
              0.8665824589296481, 0.8923925729410807, 0.7434186835178305], 
             UndirectedEdge[154, 387] -> 
             RGBColor[
              0.18595738695423472`, 0.312783382441179, 0.9339013701365182], 
             UndirectedEdge[135, 363] -> 
             RGBColor[
              0.3549405295448861, 0.4818533796872159, 0.9438374745743816], 
             UndirectedEdge[37, 269] -> 
             RGBColor[
              0.3188674209826161, 0.4483513791388215, 0.9416215783296149], 
             UndirectedEdge[201, 281] -> 
             RGBColor[
              0.5322326354554701, 0.6292900699565726, 0.956972433359562], 
             UndirectedEdge[302, 377] -> 
             RGBColor[
              0.22469777382228445`, 0.35350198532189486`, 0.9361075778573873],
              UndirectedEdge[179, 286] -> 
             RGBColor[
              0.2740282991513247, 0.4041960245612692, 0.9389591857364195], 
             UndirectedEdge[108, 325] -> 
             RGBColor[
              0.2723177927173417, 0.4035536444641835, 0.9388194674859559], 
             UndirectedEdge[279, 299] -> 
             RGBColor[
              0.19371330684929777`, 0.320935346004614, 0.9343430583006869], 
             UndirectedEdge[196, 332] -> 
             RGBColor[
              0.8265781466798748, 0.38475667486549425`, 0.4381203947409763], 
             UndirectedEdge[31, 224] -> 
             RGBColor[
              0.7410029688449329, 0.7954456814088879, 0.9320732118445416], 
             UndirectedEdge[200, 296] -> 
             RGBColor[
              0.1865617818736295, 0.3134186398223141, 0.9339357895330556], 
             UndirectedEdge[170, 221] -> 
             RGBColor[
              0.30270787399814014`, 0.42984035374028506`, 0.9407572019749026],
              UndirectedEdge[198, 206] -> 
             RGBColor[
              0.6288429856334741, 0.7061140055023541, 0.9660410068543737], 
             UndirectedEdge[36, 361] -> 
             RGBColor[
              0.32761397052464425`, 0.4523511904771868, 0.9423098359853219], 
             UndirectedEdge[132, 180] -> 
             RGBColor[
              0.1906491777676344, 0.3177147520627811, 0.9341685606824588], 
             UndirectedEdge[127, 312] -> 
             RGBColor[
              0.44359264480187605`, 0.5560735292696781, 0.9501952628642483], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.37498442055197767`, 0.49560326154572176`, 0.9453825139194686],
              UndirectedEdge[67, 75] -> 
             RGBColor[
              0.1806580838475214, 0.3072134788808002, 0.9335995826642074], 
             UndirectedEdge[110, 287] -> 
             RGBColor[
              0.8292002229414056, 0.38461576511277085`, 0.438091178290953], 
             UndirectedEdge[88, 233] -> 
             RGBColor[
              0.7003634497191511, 0.7623012578281982, 0.9418757273882692], 
             UndirectedEdge[168, 216] -> 
             RGBColor[
              0.20689038450304525`, 0.3347852900936806, 0.9350934733793282], 
             UndirectedEdge[1, 291] -> 
             RGBColor[
              0.1886369117353484, 0.31559973287781307`, 0.934053965108801], 
             UndirectedEdge[115, 214] -> 
             RGBColor[
              0.917014626987943, 0.7014084006737106, 0.2517091579831441], 
             UndirectedEdge[233, 256] -> 
             RGBColor[
              0.9813174831621745, 0.9842395002462874, 0.8561565043579783], 
             UndirectedEdge[4, 252] -> 
             RGBColor[
              0.20339315185029538`, 0.3311094768382833, 0.9348943111534462], 
             UndirectedEdge[91, 399] -> 
             RGBColor[
              0.4759758631677278, 0.5829069233744436, 0.9525944899971995], 
             UndirectedEdge[76, 269] -> 
             RGBColor[
              0.3181691701834686, 0.44761747327725976`, 0.9415818139795731], 
             UndirectedEdge[91, 172] -> 
             RGBColor[
              0.48609962486048197`, 0.5916756169176496, 0.9532395671401708], 
             UndirectedEdge[165, 184] -> 
             RGBColor[
              0.21954677082243013`, 0.3480879545765947, 0.9358142358567716], 
             UndirectedEdge[60, 139] -> 
             RGBColor[
              0.506983675095762, 0.6054995726195224, 0.9561122679612462], 
             UndirectedEdge[356, 359] -> 
             RGBColor[
              0.6355366085129286, 0.7076527365125309, 0.9596545999486343], 
             UndirectedEdge[228, 305] -> 
             RGBColor[
              0.26103370837156087`, 0.39169335636449776`, 0.9381768555757705],
              UndirectedEdge[141, 209] -> 
             RGBColor[
              0.3104061832925851, 0.4392395615986554, 0.9411477244574119], 
             UndirectedEdge[171, 348] -> 
             RGBColor[
              0.1945787269842331, 0.32184495743723673`, 0.934392342697097], 
             UndirectedEdge[10, 60] -> 
             RGBColor[
              0.7976526644820038, 0.4778635602594288, 0.44966349300497443`], 
             UndirectedEdge[234, 298] -> 
             RGBColor[
              0.22620097648238727`, 0.3550819466262163, 0.936193183025091], 
             UndirectedEdge[323, 388] -> 
             RGBColor[
              0.34570167664203966`, 0.47034107110967827`, 0.9433773042073184],
              UndirectedEdge[294, 329] -> 
             RGBColor[
              0.23603593247132534`, 0.36541910894281576`, 0.9367532692191475],
              UndirectedEdge[211, 238] -> 
             RGBColor[
              0.21668562529693003`, 0.34508070922219014`, 0.9356512978517798],
              UndirectedEdge[31, 99] -> 
             RGBColor[
              0.9432122400933031, 0.9562926111989585, 0.9505366840460105], 
             UndirectedEdge[111, 319] -> 
             RGBColor[
              0.8285561841710127, 0.22050092170390542`, 0.174978740252746], 
             UndirectedEdge[258, 394] -> 
             RGBColor[
              0.29763886748570073`, 0.42564849142765915`, 0.9404269355800592],
              UndirectedEdge[101, 364] -> 
             RGBColor[
              0.8764286119416923, 0.5191942190745097, 0.21806748042320684`], 
             UndirectedEdge[225, 349] -> 
             RGBColor[
              0.2034483891040132, 0.3311675346941849, 0.9348974568333293], 
             UndirectedEdge[118, 386] -> 
             RGBColor[
              0.34968714140668505`, 0.4773031589248714, 0.9435027333276041], 
             UndirectedEdge[95, 326] -> 
             RGBColor[
              0.24440137831360023`, 0.3742117229229475, 0.9372296689842969], 
             UndirectedEdge[228, 382] -> 
             RGBColor[
              0.27305197131929326`, 0.4030910170101112, 0.9389064714836659], 
             UndirectedEdge[120, 255] -> 
             RGBColor[
              0.39336824955180094`, 0.5151375393238391, 0.9462860549129236], 
             UndirectedEdge[222, 292] -> 
             RGBColor[
              0.863357086910216, 0.42156639939863494`, 0.43342593709910204`], 
             UndirectedEdge[325, 397] -> 
             RGBColor[
              0.3012257827964342, 0.4288125621703911, 0.9406533939002841], 
             UndirectedEdge[155, 299] -> 
             RGBColor[
              0.1871446834102983, 0.31403130629544507`, 0.9339689849132433], 
             UndirectedEdge[17, 99] -> 
             RGBColor[
              0.8524964894376759, 0.4506925466333933, 0.4462583138303914], 
             UndirectedEdge[60, 105] -> 
             RGBColor[
              0.8461630434103341, 0.8796208819742317, 0.932337896398757], 
             UndirectedEdge[229, 340] -> 
             RGBColor[
              0.23465687622616624`, 0.36396963339193744`, 0.9366747340061166],
              UndirectedEdge[297, 375] -> 
             RGBColor[
              0.2496778587950193, 0.3797576384571041, 0.9375301567418605], 
             UndirectedEdge[155, 249] -> 
             RGBColor[
              0.18476081976801417`, 0.3115257144617197, 0.9338332274054255], 
             UndirectedEdge[143, 348] -> 
             RGBColor[
              0.20000377872339242`, 0.3275470307832401, 0.9347012913679973], 
             UndirectedEdge[175, 294] -> 
             RGBColor[
              0.19993479870238595`, 0.3274745284075764, 0.9346973630578478], 
             UndirectedEdge[19, 181] -> 
             RGBColor[
              0.19581756515250187`, 0.3231470548989638, 0.9344628926980831], 
             UndirectedEdge[153, 294] -> 
             RGBColor[
              0.20769214048678164`, 0.33562798646685293`, 0.9351391321965103],
              UndirectedEdge[68, 376] -> 
             RGBColor[
              0.5538916735521564, 0.639355835105775, 0.9612276966528428], 
             UndirectedEdge[317, 354] -> 
             RGBColor[
              0.19230267119241712`, 0.319452678489766, 0.934262724686876], 
             UndirectedEdge[2, 254] -> 
             RGBColor[
              0.19445154659843222`, 0.32171128278805783`, 0.9343850999622723],
              UndirectedEdge[243, 311] -> 
             RGBColor[
              0.21699506567726595`, 0.34540595068157653`, 0.9356689200236639],
              UndirectedEdge[23, 143] -> 
             RGBColor[
              0.20541157212716055`, 0.3332309645245057, 0.9350092572022285], 
             UndirectedEdge[20, 64] -> 
             RGBColor[
              0.6886054780275248, 0.7470570557801346, 0.690028677840299], 
             UndirectedEdge[75, 296] -> 
             RGBColor[
              0.18049305546872535`, 0.30704002359128196`, 0.9335901845421726],
              UndirectedEdge[146, 227] -> 
             RGBColor[
              0.2365605733145403, 0.3659705397331854, 0.936783146739032], 
             UndirectedEdge[160, 238] -> 
             RGBColor[
              0.19808883610787825`, 0.32553430467996036`, 0.9345922382189475],
              UndirectedEdge[75, 178] -> 
             RGBColor[
              0.18245868691760933`, 0.30910602687229105`, 0.9337021243452953],
              UndirectedEdge[95, 166] -> 
             RGBColor[
              0.24620280791930751`, 0.37610513965577974`, 0.9373322577353658],
              UndirectedEdge[25, 309] -> 
             RGBColor[
              0.5306642654095335, 0.6265873056000757, 0.957441478589943], 
             UndirectedEdge[166, 326] -> 
             RGBColor[
              0.24337300372818133`, 0.3731308360309576, 0.9371711045730012], 
             UndirectedEdge[158, 308] -> 
             RGBColor[
              0.20199405614850408`, 0.32963893854790965`, 0.9348146347230057],
              UndirectedEdge[229, 343] -> 
             RGBColor[
              0.1993208104479567, 0.32682918782306747`, 0.9346623973350723], 
             UndirectedEdge[229, 294] -> 
             RGBColor[
              0.20382733943636777`, 0.33156583552032837`, 0.9349190374941501],
              UndirectedEdge[64, 257] -> 
             RGBColor[
              0.9810027572631417, 0.9816315939147817, 0.6854880311912166], 
             UndirectedEdge[56, 65] -> 
             RGBColor[
              0.4474461015886463, 0.5602099797974611, 0.9502200964459863], 
             UndirectedEdge[170, 192] -> 
             RGBColor[
              0.2468852126322833, 0.37682239027607506`, 0.9373711196742425], 
             UndirectedEdge[133, 347] -> 
             RGBColor[
              0.18386468807739512`, 0.3105838232368483, 0.9337821940313528], 
             UndirectedEdge[223, 393] -> 
             RGBColor[
              0.8134681369515452, 0.5633203916020985, 0.4604670120466483], 
             UndirectedEdge[116, 338] -> 
             RGBColor[
              0.22507866009155236`, 0.35390232094047974`, 0.9361292687669514],
              UndirectedEdge[32, 71] -> 
             RGBColor[
              0.8709138694072857, 0.43658126909692513`, 0.4242157364462195], 
             UndirectedEdge[95, 361] -> 
             RGBColor[
              0.32840262007179855`, 0.45318011115451534`, 0.9423547484103298],
              UndirectedEdge[247, 292] -> 
             RGBColor[
              0.8180564581257688, 0.1397954263108694, 0.1649241907340759], 
             UndirectedEdge[337, 391] -> 
             RGBColor[
              0.8658158827122152, 0.4268349889246108, 0.4305754527619263], 
             UndirectedEdge[181, 238] -> 
             RGBColor[
              0.1965022388034804, 0.3238666903169589, 0.9345018838496224], 
             UndirectedEdge[97, 246] -> 
             RGBColor[
              0.2576631748496625, 0.38815071192881434`, 0.9379849086779559], 
             UndirectedEdge[62, 247] -> 
             RGBColor[
              0.8754937811360735, 0.41981207760671324`, 0.37132290064454676`],
              UndirectedEdge[207, 280] -> 
             RGBColor[
              0.200223112625469, 0.32777756462089525`, 0.9347137821092452], 
             UndirectedEdge[145, 221] -> 
             RGBColor[
              0.3098924284635012, 0.43739177601044266`, 0.941166351723109], 
             UndirectedEdge[10, 334] -> 
             RGBColor[
              0.8820485949422373, 0.5133285113038917, 0.2258290855797634], 
             UndirectedEdge[25, 78] -> 
             RGBColor[
              0.29221377727191306`, 0.41936050438489303`, 0.9401394364080135],
              UndirectedEdge[46, 139] -> 
             RGBColor[
              0.5562400144756487, 0.6439789993051345, 0.961021679543971], 
             UndirectedEdge[224, 383] -> 
             RGBColor[
              0.42803255257249384`, 0.5439556499014909, 0.9488281562852744], 
             UndirectedEdge[138, 164] -> 
             RGBColor[
              0.2519489800003536, 0.38214473084131173`, 0.9376594937346815], 
             UndirectedEdge[53, 93] -> 
             RGBColor[
              0.37256678589576175`, 0.4971203570169409, 0.9449606040427729], 
             UndirectedEdge[31, 199] -> 
             RGBColor[
              0.9864970705564884, 0.9886842059127192, 0.8734420155476115], 
             UndirectedEdge[98, 342] -> 
             RGBColor[
              0.1898214409282245, 0.31684474816301444`, 0.9341214222939813], 
             UndirectedEdge[141, 304] -> 
             RGBColor[
              0.31901866548224, 0.4482918264428926, 0.9416381925770871], 
             UndirectedEdge[32, 105] -> 
             RGBColor[
              0.8761133411469468, 0.4403360535274061, 0.40990740127695935`], 
             UndirectedEdge[216, 329] -> 
             RGBColor[
              0.23907766788565177`, 0.368616165720437, 0.936926491551149], 
             UndirectedEdge[164, 264] -> 
             RGBColor[
              0.23748584663754294`, 0.36694306066137816`, 0.9368358396859577],
              UndirectedEdge[118, 196] -> 
             RGBColor[
              0.6007859963931654, 0.6812853787799371, 0.9644958808837701], 
             UndirectedEdge[75, 398] -> 
             RGBColor[
              0.18135843161484838`, 0.30794958878887396`, 0.9336394664334849],
              UndirectedEdge[45, 48] -> 
             RGBColor[
              0.2238300988639671, 0.3525900039269335, 0.9360581650521211], 
             UndirectedEdge[248, 275] -> 
             RGBColor[
              0.18852850716525682`, 0.3154857928014001, 0.9340477916289045], 
             UndirectedEdge[200, 347] -> 
             RGBColor[
              0.1891857716327594, 0.31617661942971953`, 0.9340852218679931], 
             UndirectedEdge[33, 58] -> 
             RGBColor[
              0.21989646734481127`, 0.3484555077936574, 0.9358341505563915], 
             UndirectedEdge[134, 240] -> 
             RGBColor[
              0.17922390736570504`, 0.3057060684663703, 0.9335179084352418], 
             UndirectedEdge[267, 344] -> 
             RGBColor[
              0.1945632673718405, 0.321828708404416, 0.9343914622950418], 
             UndirectedEdge[141, 286] -> 
             RGBColor[
              0.3385051144347327, 0.4676178491867835, 0.9427902244568296], 
             UndirectedEdge[33, 209] -> 
             RGBColor[
              0.25581747523043485`, 0.38621076460489123`, 0.9378797988151089],
              UndirectedEdge[47, 155] -> 
             RGBColor[
              0.18345196765990118`, 0.3101500279100763, 0.9337586902141416], 
             UndirectedEdge[153, 229] -> 
             RGBColor[
              0.2017865527982215, 0.3294208393702904, 0.934802817714181], 
             UndirectedEdge[64, 161] -> 
             RGBColor[
              0.9360657953387055, 0.766239407790421, 0.32776561052681985`], 
             UndirectedEdge[3, 293] -> 
             RGBColor[
              0.2751725873267546, 0.40605645004464963`, 0.939000269414517], 
             UndirectedEdge[133, 178] -> 
             RGBColor[
              0.18320632976714918`, 0.309891846910452, 0.9337447014995381], 
             UndirectedEdge[113, 162] -> 
             RGBColor[
              0.19047273002269705`, 0.31752929429541876`, 0.9341585122444157],
              UndirectedEdge[313, 358] -> 
             RGBColor[
              0.28110733593194254`, 0.4127920116719563, 0.9393200189690635], 
             UndirectedEdge[259, 292] -> 
             RGBColor[
              0.8448027967443577, 0.4070362632797625, 0.4408283690918966], 
             UndirectedEdge[4, 165] -> 
             RGBColor[
              0.21319278532882907`, 0.3414095129568713, 0.9354523857827901], 
             UndirectedEdge[247, 385] -> 
             RGBColor[
              0.8763650244456923, 0.41967521212315095`, 0.3207468068561434], 
             UndirectedEdge[38, 243] -> 
             RGBColor[
              0.24505985490147014`, 0.37490382356662577`, 0.9372671682518474],
              UndirectedEdge[265, 381] -> 
             RGBColor[
              0.19417265233719494`, 0.3214181472365799, 0.9343692173466818], 
             UndirectedEdge[15, 369] -> 
             RGBColor[
              0.18126767848005537`, 0.30785420149012543`, 0.9336342981767156],
              UndirectedEdge[30, 358] -> 
             RGBColor[
              0.2391480425105603, 0.3686901339132248, 0.9369304992819277], 
             UndirectedEdge[133, 330] -> 
             RGBColor[
              0.1860526851696524, 0.3128835469078388, 0.9339067972289052], 
             UndirectedEdge[223, 292] -> 
             RGBColor[
              0.8459748454234086, 0.3526869418187919, 0.19159224569181096`], 
             UndirectedEdge[44, 326] -> 
             RGBColor[
              0.2349425006851034, 0.3642698428079171, 0.9366909998965096], 
             UndirectedEdge[123, 356] -> 
             RGBColor[
              0.8772330619315765, 0.5414195340546395, 0.45175270578871085`], 
             UndirectedEdge[35, 154] -> 
             RGBColor[
              0.18823624142486384`, 0.31517860297752887`, 0.9340311475273575],
              UndirectedEdge[146, 151] -> 
             RGBColor[
              0.20337080686080378`, 0.3310859908375735, 0.9348930386393511], 
             UndirectedEdge[111, 287] -> 
             RGBColor[
              0.8235143897467309, 0.18174748043047098`, 0.17015071221816136`],
              UndirectedEdge[42, 133] -> 
             RGBColor[
              0.1836453052262827, 0.310353237950653, 0.9337697005025297], 
             UndirectedEdge[40, 103] -> 
             RGBColor[
              0.19411926264855695`, 0.32136203128871965`, 0.9343661768828968],
              UndirectedEdge[219, 260] -> 
             RGBColor[
              0.1839290162486566, 0.31065143622348573`, 0.9337858574255411], 
             UndirectedEdge[151, 186] -> 
             RGBColor[
              0.20709670832782653`, 0.33500214951521173`, 0.9351052232159208],
              UndirectedEdge[8, 76] -> 
             RGBColor[
              0.26926683315553557`, 0.4003468925227164, 0.9386457198524012], 
             UndirectedEdge[124, 167] -> 
             RGBColor[
              0.23121257205082407`, 0.360349451322155, 0.9364785859787222], 
             UndirectedEdge[162, 291] -> 
             RGBColor[
              0.1953787311658639, 0.32268581255532547`, 0.9344379017517408], 
             UndirectedEdge[242, 255] -> 
             RGBColor[
              0.3572936731332409, 0.48389155439101317`, 0.9439874148030284], 
             UndirectedEdge[182, 323] -> 
             RGBColor[
              0.3312247462121247, 0.45512489933743366`, 0.9425528644360341], 
             UndirectedEdge[138, 149] -> 
             RGBColor[
              0.2496156992329207, 0.3796923048161946, 0.9375266168467558], 
             UndirectedEdge[199, 353] -> 
             RGBColor[
              0.9909977762454061, 0.988800838647677, 0.6720451430779383], 
             UndirectedEdge[34, 381] -> 
             RGBColor[
              0.18614322275265005`, 0.3129787076479837, 0.9339119532103186], 
             UndirectedEdge[148, 305] -> 
             RGBColor[
              0.2773062230664102, 0.4087968010458064, 0.939103551214614], 
             UndirectedEdge[97, 383] -> 
             RGBColor[
              0.32847115554353346`, 0.45799116005281093`, 0.9421851328952267],
              UndirectedEdge[154, 207] -> 
             RGBColor[
              0.18894498275511917`, 0.315923535052423, 0.9340715092976267], 
             UndirectedEdge[272, 375] -> 
             RGBColor[
              0.1997235147350348, 0.3272524555617131, 0.9346853307484737], 
             UndirectedEdge[25, 323] -> 
             RGBColor[
              0.3922918508728892, 0.5142052168895364, 0.9462174677409253], 
             UndirectedEdge[236, 334] -> 
             RGBColor[
              0.7349237676396162, 0.7451154652166593, 0.6272347577119612], 
             UndirectedEdge[23, 346] -> 
             RGBColor[
              0.20767293699657277`, 0.3356078023810718, 0.935138038586152], 
             UndirectedEdge[23, 151] -> 
             RGBColor[
              0.20976599730073225`, 0.3378077414684315, 0.9352572352740687], 
             UndirectedEdge[250, 381] -> 
             RGBColor[
              0.19153445496524343`, 0.31864523452728444`, 0.9342189759092124],
              UndirectedEdge[230, 264] -> 
             RGBColor[
              0.2405521506109405, 0.3701659405523198, 0.9370104611610526], 
             UndirectedEdge[60, 68] -> 
             RGBColor[
              0.7643140770585692, 0.8158203298412934, 0.9771398668713851], 
             UndirectedEdge[50, 258] -> 
             RGBColor[
              0.23439017041921995`, 0.3636893086787121, 0.9366595455049669], 
             UndirectedEdge[121, 298] -> 
             RGBColor[
              0.2245949434093795, 0.353393904038107, 0.9361017218174963], 
             UndirectedEdge[95, 382] -> 
             RGBColor[
              0.2846635750266093, 0.4152955487246973, 0.9395677351369693], 
             UndirectedEdge[42, 200] -> 
             RGBColor[
              0.18896638878164698`, 0.3159460341435242, 0.9340727283391701], 
             UndirectedEdge[254, 314] -> 
             RGBColor[
              0.1849157269952969, 0.31168853177927935`, 0.9338420491428545], 
             UndirectedEdge[95, 305] -> 
             RGBColor[
              0.2726453120788769, 0.4038978880790839, 0.9388381192290738], 
             UndirectedEdge[321, 381] -> 
             RGBColor[
              0.18695109985789307`, 0.313827837707961, 0.9339579606163151], 
             UndirectedEdge[116, 209] -> 
             RGBColor[
              0.2525333735524159, 0.38275896551722044`, 0.9376927740829386], 
             UndirectedEdge[364, 366] -> 
             RGBColor[
              0.9573192010017704, 0.856958801294309, 0.38384804144330753`], 
             UndirectedEdge[58, 156] -> 
             RGBColor[
              0.19753761270804981`, 0.3249549339371585, 0.9345608468617892], 
             UndirectedEdge[118, 179] -> 
             RGBColor[
              0.29213029064248475`, 0.4198750597583651, 0.9401126286272736], 
             UndirectedEdge[149, 328] -> 
             RGBColor[
              0.22083892747976266`, 0.3494460931509151, 0.9358878222668322], 
             UndirectedEdge[215, 227] -> 
             RGBColor[
              0.4900314069116405, 0.5878102265694376, 0.9551265080130549], 
             UndirectedEdge[70, 177] -> 
             RGBColor[
              0.1891804395703839, 0.31617101509409057`, 0.9340849182149289], 
             UndirectedEdge[383, 393] -> 
             RGBColor[
              0.5401446576878393, 0.6337537414941011, 0.9584878557690468], 
             UndirectedEdge[14, 201] -> 
             RGBColor[
              0.5021816905325309, 0.6032614518687315, 0.9550576137220795], 
             UndirectedEdge[5, 368] -> 
             RGBColor[
              0.18532540128789612`, 0.31211912543565157`, 0.9338653794877592],
              UndirectedEdge[214, 310] -> 
             RGBColor[
              0.8439849195878139, 0.31758034175677613`, 0.18891093519726984`],
              UndirectedEdge[35, 280] -> 
             RGBColor[
              0.19951437129521365`, 0.3270326325460011, 0.9346734203389759], 
             UndirectedEdge[243, 275] -> 
             RGBColor[
              0.21276908993785693`, 0.3409641822371201, 0.9354282569570754], 
             UndirectedEdge[131, 391] -> 
             RGBColor[
              0.8181931112315055, 0.3892593691956639, 0.4387086159715671], 
             UndirectedEdge[2, 314] -> 
             RGBColor[
              0.19228958849813182`, 0.3194389277485814, 0.9342619796467905], 
             UndirectedEdge[282, 361] -> 
             RGBColor[
              0.36229879969604784`, 0.48822674345474093`, 0.9443063370417508],
              UndirectedEdge[110, 269] -> 
             RGBColor[
              0.6031830035578256, 0.6830576186116337, 0.9647885304899277], 
             UndirectedEdge[193, 360] -> 
             RGBColor[
              0.7503418220523833, 0.8050370370474327, 0.9757122305140027], 
             UndirectedEdge[71, 400] -> 
             RGBColor[
              0.8713114373566356, 0.4396371505710155, 0.42459644796350593`], 
             UndirectedEdge[110, 117] -> 
             RGBColor[
              0.7057471364084966, 0.7690367194392469, 0.9721131675946504], 
             UndirectedEdge[170, 351] -> 
             RGBColor[
              0.27252940237618284`, 0.4037012784354327, 0.938834256448926], 
             UndirectedEdge[121, 200] -> 
             RGBColor[
              0.2188856606362972, 0.3473930858541622, 0.9357765866096961], 
             UndirectedEdge[38, 383] -> 
             RGBColor[
              0.3085216567311646, 0.43702297192973105`, 0.9410490384505009], 
             UndirectedEdge[172, 256] -> 
             RGBColor[
              0.6859636429526801, 0.7471589426256584, 0.8613086090450968], 
             UndirectedEdge[127, 258] -> 
             RGBColor[
              0.2885106861095953, 0.4177421195154126, 0.9398452959345076], 
             UndirectedEdge[25, 388] -> 
             RGBColor[
              0.31737166199215083`, 0.44580303632788293`, 0.9415721407250759],
              UndirectedEdge[51, 277] -> 
             RGBColor[
              0.19316166908716753`, 0.3203555397407608, 0.9343116433462084], 
             UndirectedEdge[85, 379] -> 
             RGBColor[
              0.18217848519657132`, 0.30881151709766497`, 0.9336861672718034],
              UndirectedEdge[267, 306] -> 
             RGBColor[
              0.20993199303624877`, 0.33798221351119695`, 0.9352666884856375],
              UndirectedEdge[176, 298] -> 
             RGBColor[
              0.19583511598337588`, 0.32316550193499927`, 0.9344638921919373],
              UndirectedEdge[269, 323] -> 
             RGBColor[
              0.38701260190710624`, 0.5096325967781434, 0.9458810786650822], 
             UndirectedEdge[21, 180] -> 
             RGBColor[
              0.19254611619106632`, 0.3197085546186507, 0.9342765885194044], 
             UndirectedEdge[36, 228] -> 
             RGBColor[
              0.23483092925025606`, 0.364152574155855, 0.9366846460683501], 
             UndirectedEdge[74, 116] -> 
             RGBColor[
              0.244277527259818, 0.37408154761281204`, 0.9372226158500052], 
             UndirectedEdge[3, 188] -> 
             RGBColor[
              0.25601232241971317`, 0.38641556135484806`, 0.9378908950742876],
              UndirectedEdge[69, 394] -> 
             RGBColor[
              0.46522152575946735`, 0.5741285322522734, 0.9517610033724258], 
             UndirectedEdge[37, 395] -> 
             RGBColor[
              0.3615061899414258, 0.48528293772410147`, 0.9443384829836874], 
             UndirectedEdge[172, 194] -> 
             RGBColor[
              0.41753162873264527`, 0.5360090287080477, 0.9478416433121417], 
             UndirectedEdge[59, 264] -> 
             RGBColor[
              0.2381256499847355, 0.3676155345451527, 0.9368722755400762], 
             UndirectedEdge[28, 369] -> 
             RGBColor[
              0.1860007123494566, 0.3128289201785459, 0.9339038374536819], 
             UndirectedEdge[130, 344] -> 
             RGBColor[
              0.20361295849173341`, 0.3313405075549807, 0.9349068288165013], 
             UndirectedEdge[29, 270] -> 
             RGBColor[
              0.19689305639497057`, 0.3242774643848816, 0.9345241403332949], 
             UndirectedEdge[41, 48] -> 
             RGBColor[
              0.2013669879321785, 0.3289798500941302, 0.9347789241157504], 
             UndirectedEdge[12, 124] -> 
             RGBColor[
              0.23470207361547668`, 0.3640171387137828, 0.9366773079305742], 
             UndirectedEdge[61, 95] -> 
             RGBColor[
              0.23224869997063102`, 0.3614384874601766, 0.9365375919309413], 
             UndirectedEdge[213, 306] -> 
             RGBColor[
              0.2738566580723743, 0.4036300780572341, 0.9389635275699348], 
             UndirectedEdge[63, 295] -> 
             RGBColor[
              0.1876127220363632, 0.31452324456680214`, 0.9339956390205967], 
             UndirectedEdge[302, 367] -> 
             RGBColor[
              0.19039724530537674`, 0.31744995507150764`, 0.934154213501434], 
             UndirectedEdge[140, 331] -> 
             RGBColor[
              0.3236577561982914, 0.4484913535850291, 0.9420736097220124], 
             UndirectedEdge[92, 354] -> 
             RGBColor[
              0.20023581918524017`, 0.32779092002085713`, 0.9347145057290265],
              UndirectedEdge[151, 311] -> 
             RGBColor[
              0.20510424418118295`, 0.33290794336756596`, 0.934991755330356], 
             UndirectedEdge[299, 371] -> 
             RGBColor[
              0.18421145049276366`, 0.3109482925214076, 0.933801941637919], 
             UndirectedEdge[140, 389] -> 
             RGBColor[
              0.6997349672161455, 0.7570392468690857, 0.7200011772159544], 
             UndirectedEdge[176, 205] -> 
             RGBColor[
              0.18567915281687453`, 0.3124909407217502, 0.9338855251140061], 
             UndirectedEdge[152, 179] -> 
             RGBColor[
              0.2138285336364696, 0.3420777247369723, 0.935488590708405], 
             UndirectedEdge[142, 293] -> 
             RGBColor[
              0.3941446854590191, 0.5152441502355233, 0.946491888259698], 
             UndirectedEdge[105, 259] -> 
             RGBColor[
              0.9403634558512834, 0.9538207185775788, 0.9415651020124101], 
             UndirectedEdge[274, 318] -> 
             RGBColor[
              0.20829816061759315`, 0.33626495204823137`, 0.9351736441464337],
              UndirectedEdge[231, 369] -> 
             RGBColor[
              0.1858060573218873, 0.312624325402729, 0.9338927521378282], 
             UndirectedEdge[151, 348] -> 
             RGBColor[
              0.20435820389696413`, 0.332123807727166, 0.9349492694398375], 
             UndirectedEdge[147, 231] -> 
             RGBColor[
              0.2192108871052112, 0.34773491949353985`, 0.9357951077759714], 
             UndirectedEdge[66, 354] -> 
             RGBColor[
              0.19611420939972474`, 0.3234588468111266, 0.9344797861491166], 
             UndirectedEdge[24, 65] -> 
             RGBColor[
              0.3183379395633406, 0.44565996035968214`, 0.9416695943018074], 
             UndirectedEdge[42, 347] -> 
             RGBColor[
              0.18410501336322643`, 0.3108364203497602, 0.9337958802008515], 
             UndirectedEdge[52, 129] -> 
             RGBColor[
              0.8758889946434687, 0.4296602011342544, 0.38811658814132355`], 
             UndirectedEdge[3, 7] -> 
             RGBColor[
              0.24558195815549755`, 0.37545258718986685`, 0.9372969012597816],
              UndirectedEdge[156, 352] -> 
             RGBColor[
              0.19412861826228733`, 0.32137186463193046`, 0.9343667096712585],
              UndirectedEdge[229, 329] -> 
             RGBColor[
              0.2301303447827652, 0.3592119618462532, 0.9364169547368181], 
             UndirectedEdge[80, 187] -> 
             RGBColor[
              0.20972687217078761`, 0.3377666184761832, 0.9352550071557988], 
             UndirectedEdge[247, 362] -> 
             RGBColor[
              0.808649465228358, 0.36847454946527913`, 0.43610132085825937`], 
             UndirectedEdge[43, 321] -> 
             RGBColor[
              0.1896253217591911, 0.31663861448168684`, 0.9341102535974373], 
             UndirectedEdge[84, 270] -> 
             RGBColor[
              0.21111604747539212`, 0.339226729800124, 0.9353341186342953], 
             UndirectedEdge[318, 322] -> 
             RGBColor[
              0.20428384988578308`, 0.3320456569470981, 0.9349450350888977], 
             UndirectedEdge[218, 276] -> 
             RGBColor[
              0.46966080217049366`, 0.5783141439540027, 0.951949779691809], 
             UndirectedEdge[201, 303] -> 
             RGBColor[
              0.7798220611835203, 0.6750115727481525, 0.6002603969131654], 
             UndirectedEdge[283, 364] -> 
             RGBColor[
              0.9266304431740131, 0.7468211866800847, 0.25982333625421017`], 
             UndirectedEdge[65, 340] -> 
             RGBColor[
              0.3239430587205376, 0.45155129597897675`, 0.941988797545779], 
             UndirectedEdge[83, 214] -> 
             RGBColor[
              0.9149531561640245, 0.7530286606028909, 0.5942676397554747], 
             UndirectedEdge[124, 157] -> 
             RGBColor[
              0.2367400113323198, 0.3661591404668991, 0.9367933654686897], 
             UndirectedEdge[311, 344] -> 
             RGBColor[
              0.19707934099750435`, 0.3244732613132706, 0.9345347489658259], 
             UndirectedEdge[190, 226] -> 
             RGBColor[
              0.20202864183193292`, 0.3296752902940524, 0.9348166043265123], 
             UndirectedEdge[380, 389] -> 
             RGBColor[
              0.8567527280963826, 0.8845935052040448, 0.7328269740889874], 
             UndirectedEdge[124, 179] -> 
             RGBColor[
              0.22671592710196903`, 0.3556231923771518, 0.9362225087010749], 
             UndirectedEdge[199, 215] -> 
             RGBColor[
              0.8474033618771311, 0.8799586173228249, 0.9038397390676208], 
             UndirectedEdge[146, 267] -> 
             RGBColor[
              0.19834666787727806`, 0.32580530221707793`, 0.9346069213567869],
              UndirectedEdge[109, 249] -> 
             RGBColor[
              0.18318613987214505`, 0.3098706260506894, 0.9337435517148859], 
             UndirectedEdge[36, 61] -> 
             RGBColor[
              0.23146005042347673`, 0.36060956678284806`, 0.9364926795059334],
              UndirectedEdge[13, 232] -> 
             RGBColor[
              0.20186143048066912`, 0.3294995405620621, 0.9348070818874247], 
             UndirectedEdge[38, 119] -> 
             RGBColor[
              0.249257790450226, 0.37931611999285497`, 0.9375062344710599], 
             UndirectedEdge[91, 256] -> 
             RGBColor[
              0.792439933021371, 0.8356021745450866, 0.869137935086701], 
             UndirectedEdge[6, 69] -> 
             RGBColor[
              0.7494906190968638, 0.8040199624425932, 0.9761664746556911], 
             UndirectedEdge[90, 97] -> 
             RGBColor[
              0.2570968896215246, 0.3875555102494842, 0.9379526595719574], 
             UndirectedEdge[233, 257] -> 
             RGBColor[
              0.9698756400386146, 0.9770538821816868, 0.9358768631099392], 
             UndirectedEdge[66, 119] -> 
             RGBColor[
              0.21795851687042844`, 0.3464185989719241, 0.9357237871438162], 
             UndirectedEdge[33, 116] -> 
             RGBColor[
              0.24330530459768918`, 0.3730596799524376, 0.9371672492076716], 
             UndirectedEdge[335, 349] -> 
             RGBColor[
              0.19833951424086566`, 0.32579778329164166`, 0.9346065139677762],
              UndirectedEdge[165, 274] -> 
             RGBColor[
              0.21434019517096867`, 0.34261551345094576`, 0.9355177290758593],
              UndirectedEdge[95, 169] -> 
             RGBColor[
              0.3522449518778092, 0.4737241407933565, 0.9439035250794346], 
             UndirectedEdge[135, 259] -> 
             RGBColor[
              0.6153899363844033, 0.6921704499321857, 0.9662385558858466], 
             UndirectedEdge[93, 273] -> 
             RGBColor[
              0.433287316679902, 0.5477930013754455, 0.949360282412582], 
             UndirectedEdge[89, 263] -> 
             RGBColor[
              0.2670289628172794, 0.39799474890803455`, 0.93851827644727], 
             UndirectedEdge[71, 289] -> 
             RGBColor[
              0.7219591346417744, 0.780476707159252, 0.9439593282102003], 
             UndirectedEdge[32, 215] -> 
             RGBColor[
              0.7830362347155908, 0.3677084343750351, 0.4359392691571047], 
             UndirectedEdge[8, 239] -> 
             RGBColor[
              0.3813679879787836, 0.49836836108207505`, 0.9461050956090218], 
             UndirectedEdge[110, 111] -> 
             RGBColor[
              0.8353956126881364, 0.4322362455432418, 0.4440238905091144], 
             UndirectedEdge[29, 162] -> 
             RGBColor[
              0.19056901057120365`, 0.3176304912564385, 0.9341639952792189], 
             UndirectedEdge[337, 353] -> 
             RGBColor[
              0.9751195109230872, 0.9777137367216755, 0.7327280786411184], 
             UndirectedEdge[306, 308] -> 
             RGBColor[
              0.2175738595337591, 0.3460142997224009, 0.9357018814775424], 
             UndirectedEdge[185, 190] -> 
             RGBColor[
              0.20235115482293997`, 0.33001427189610544`, 0.9348349709642347],
              UndirectedEdge[71, 385] -> 
             RGBColor[
              0.9820607295061435, 0.9836969405379016, 0.7849671104328407], 
             UndirectedEdge[146, 158] -> 
             RGBColor[
              0.1951348259562785, 0.3224294527155677, 0.9344240117108803], 
             UndirectedEdge[157, 386] -> 
             RGBColor[
              0.2943941268277438, 0.42368947103286164`, 0.9401890092515732], 
             UndirectedEdge[24, 124] -> 
             RGBColor[
              0.24340021238043813`, 0.3731594340496077, 0.9371726540654957], 
             UndirectedEdge[22, 74] -> 
             RGBColor[
              0.24528340650250224`, 0.37513879047330073`, 0.9372798991848111],
              UndirectedEdge[303, 385] -> 
             RGBColor[
              0.9441738208357854, 0.8008555462181073, 0.4334857922002555], 
             UndirectedEdge[130, 317] -> 
             RGBColor[
              0.20208377375464914`, 0.3297332374403929, 0.9348197440079504], 
             UndirectedEdge[73, 291] -> 
             RGBColor[
              0.19698615809912115`, 0.32437532017893284`, 0.9345294423376147],
              UndirectedEdge[241, 255] -> 
             RGBColor[
              0.32755009808125596`, 0.4555556663672059, 0.9421864088801596], 
             UndirectedEdge[385, 400] -> 
             RGBColor[
              0.8795493400594996, 0.44415125730687344`, 0.3237961110840954], 
             UndirectedEdge[130, 311] -> 
             RGBColor[
              0.20912979631755016`, 0.33713905389763504`, 0.9352210045692514],
              UndirectedEdge[143, 308] -> 
             RGBColor[
              0.2058756118794577, 0.33371869972598955`, 0.9350356835796365], 
             UndirectedEdge[297, 397] -> 
             RGBColor[
              0.33036980779411174`, 0.4594447802808611, 0.9423131030091806], 
             UndirectedEdge[237, 324] -> 
             RGBColor[
              0.18395646599811732`, 0.31068028765058353`, 0.9337874206481647],
              UndirectedEdge[107, 160] -> 
             RGBColor[
              0.20918830325598364`, 0.33720054839948277`, 0.935224336452842], 
             UndirectedEdge[125, 185] -> 
             RGBColor[
              0.1925739180479394, 0.31973777613296384`, 0.9342781717940241], 
             UndirectedEdge[269, 388] -> 
             RGBColor[
              0.3120924130263679, 0.44123041621648995`, 0.9412357516492327], 
             UndirectedEdge[47, 300] -> 
             RGBColor[
              0.18858263454534693`, 0.31554268410974895`, 0.9340508741031263],
              UndirectedEdge[37, 365] -> 
             RGBColor[
              0.29517424252624735`, 0.4275772223959621, 0.9401211084894857], 
             UndirectedEdge[356, 389] -> 
             RGBColor[
              0.969253418800837, 0.9732437196326836, 0.7351124459689012], 
             UndirectedEdge[227, 243] -> 
             RGBColor[
              0.2526928974888643, 0.38292663528882953`, 0.9377018587351249], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.1986316801099837, 0.3261048681444708, 0.9346231523818017], 
             UndirectedEdge[186, 348] -> 
             RGBColor[
              0.2038426026857459, 0.33158187816317064`, 0.9349199067136222], 
             UndirectedEdge[61, 90] -> 
             RGBColor[
              0.21641762089155886`, 0.3447990195996844, 0.935636035397371], 
             UndirectedEdge[72, 325] -> 
             RGBColor[
              0.35190435537579295`, 0.4723760276667679, 0.9439742559127038], 
             UndirectedEdge[341, 358] -> 
             RGBColor[
              0.26347030119752707`, 0.39425436991349627`, 0.9383156159325932],
              UndirectedEdge[102, 337] -> 
             RGBColor[
              0.6530069899856277, 0.722086925969716, 0.9505841497129952], 
             UndirectedEdge[297, 378] -> 
             RGBColor[
              0.2683985374759716, 0.3994342587103688, 0.9385962716979784], 
             UndirectedEdge[300, 370] -> 
             RGBColor[
              0.19085384504698283`, 0.3179298703500313, 0.9341802161812396], 
             UndirectedEdge[46, 52] -> 
             RGBColor[
              0.89726556755869, 0.9188637535063902, 0.9066512485949225], 
             UndirectedEdge[75, 200] -> 
             RGBColor[
              0.1879784206462758, 0.3149076169924513, 0.9340164650154286], 
             UndirectedEdge[204, 343] -> 
             RGBColor[
              0.1903303530090651, 0.3173796470268675, 0.9341504040841173], 
             UndirectedEdge[32, 199] -> 
             RGBColor[
              0.8772578283825027, 0.4408093284112888, 0.39094028594577723`], 
             UndirectedEdge[301, 313] -> 
             RGBColor[
              0.2672428397382781, 0.39821954711258417`, 0.9385304564215183], 
             UndirectedEdge[166, 363] -> 
             RGBColor[
              0.3098501203432949, 0.43692070785172515`, 0.9411795622408922], 
             UndirectedEdge[333, 353] -> 
             RGBColor[
              0.97351816640208, 0.9765194565998694, 0.7354387372176427], 
             UndirectedEdge[130, 146] -> 
             RGBColor[
              0.20739635899717102`, 0.3353171013676426, 0.9351222878782466], 
             UndirectedEdge[71, 271] -> 
             RGBColor[
              0.8699031270122622, 0.4288122601386338, 0.4232478483872749], 
             UndirectedEdge[123, 332] -> 
             RGBColor[
              0.8347068478586457, 0.26777761804506683`, 0.1808686227462045], 
             UndirectedEdge[340, 361] -> 
             RGBColor[
              0.34048302917169776`, 0.46587738706068504`, 0.9430427098372054],
              UndirectedEdge[165, 322] -> 
             RGBColor[
              0.2103258844391586, 0.3383962183498125, 0.9352891200183233], 
             UndirectedEdge[278, 302] -> 
             RGBColor[
              0.19139766926121787`, 0.31850146407963903`, 0.9342111861657245],
              UndirectedEdge[322, 355] -> 
             RGBColor[
              0.2016258404569241, 0.32925192050983587`, 0.9347936653840967], 
             UndirectedEdge[68, 333] -> 
             RGBColor[
              0.8876904453290742, 0.9128181118706356, 0.9729875018597351], 
             UndirectedEdge[150, 156] -> 
             RGBColor[
              0.22013918030941965`, 0.34871061450835156`, 0.9358479727006643],
              UndirectedEdge[29, 357] -> 
             RGBColor[
              0.18592235681432462`, 0.3127465635430944, 0.9338993752218727], 
             UndirectedEdge[250, 325] -> 
             RGBColor[
              0.21599606078555122`, 0.34435593319981583`, 0.9356120281729761],
              UndirectedEdge[53, 131] -> 
             RGBColor[
              0.6083578580504109, 0.6889233390243821, 0.9644906126536026], 
             UndirectedEdge[92, 267] -> 
             RGBColor[
              0.20096723062757926`, 0.3285596798209194, 0.9347561585286415], 
             UndirectedEdge[269, 309] -> 
             RGBColor[
              0.5253850164437505, 0.6220146854886827, 0.9571050895141], 
             UndirectedEdge[162, 336] -> 
             RGBColor[
              0.21504897720554328`, 0.3433604883086603, 0.9355580931641793], 
             UndirectedEdge[94, 204] -> 
             RGBColor[
              0.1795232819748228, 0.3060207301619996, 0.9335349573763461], 
             UndirectedEdge[29, 183] -> 
             RGBColor[
              0.18726251983199932`, 0.31415515984591347`, 0.9339756955231359],
              UndirectedEdge[145, 208] -> 
             RGBColor[
              0.2721455459278671, 0.4033726021673685, 0.9388096582861116], 
             UndirectedEdge[75, 133] -> 
             RGBColor[
              0.18265733709091148`, 0.3093148207995801, 0.9337134371787883], 
             UndirectedEdge[169, 326] -> 
             RGBColor[
              0.349415147686683, 0.47074983716853436`, 0.9437423719170701], 
             UndirectedEdge[95, 97] -> 
             RGBColor[
              0.27292796870059677`, 0.4041949781099764, 0.9388542161055278], 
             UndirectedEdge[37, 78] -> 
             RGBColor[
              0.25239861099731176`, 0.3826173215273665, 0.9376850995547887], 
             UndirectedEdge[55, 397] -> 
             RGBColor[
              0.5839584526615165, 0.6682303773203624, 0.9627494310951048], 
             UndirectedEdge[185, 226] -> 
             RGBColor[
              0.1922271263061977, 0.3193732760245269, 0.9342584225173644], 
             UndirectedEdge[39, 254] -> 
             RGBColor[
              0.19262591917799537`, 0.31979243261771473`, 0.934281133181452], 
             UndirectedEdge[71, 201] -> 
             RGBColor[
              0.8177089698538784, 0.8578529670679469, 0.9517417151457506], 
             UndirectedEdge[227, 383] -> 
             RGBColor[
              0.3161546993185588, 0.44504578365193476`, 0.9414837289337784], 
             UndirectedEdge[38, 151] -> 
             RGBColor[
              0.23316903340538708`, 0.36240581625261525`, 0.9365900035585395],
              UndirectedEdge[45, 74] -> 
             RGBColor[
              0.2441275547351621, 0.3739239169805914, 0.9372140751365906], 
             UndirectedEdge[292, 303] -> 
             RGBColor[
              0.8443046091041563, 0.3043001594014045, 0.18860083092727706`], 
             UndirectedEdge[185, 357] -> 
             RGBColor[
              0.18927662196416456`, 0.31627210888827, 0.9340903956599655], 
             UndirectedEdge[86, 376] -> 
             RGBColor[
              0.2771391258654599, 0.4086211712930332, 0.939094035276218], 
             UndirectedEdge[212, 309] -> 
             RGBColor[
              0.6375731061251859, 0.7158069480258249, 0.965187359754256], 
             UndirectedEdge[50, 127] -> 
             RGBColor[
              0.28524823564473223`, 0.4143130772255349, 0.9396595042068966], 
             UndirectedEdge[92, 374] -> 
             RGBColor[
              0.1940034937220554, 0.32124035080679264`, 0.9343595840137974], 
             UndirectedEdge[118, 141] -> 
             RGBColor[
              0.35660710592589273`, 0.4832968843838794, 0.9439436673476838], 
             UndirectedEdge[205, 390] -> 
             RGBColor[
              0.19906834334491935`, 0.32656382889043634`, 
               0.9346480197070459]}, GraphLayout -> {"Dimension" -> 2}, 
           ImageSize -> 500, VertexSize -> {3}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.24987309085249598`, 0.3799628397279394, 0.9375412749187138], 
             316 -> RGBColor[
              0.7121412574025138, 0.7750494298476431, 0.9719432432656107], 
             308 -> RGBColor[
              0.212847764567014, 0.3410468742606238, 0.9354327373608172], 160 -> 
             RGBColor[
              0.19529547244710238`, 0.32259830236299947`, 0.9344331602908775],
              245 -> RGBColor[
              0.19489410730752896`, 0.3221764421532881, 0.9344103031399453], 
             155 -> RGBColor[
              0.1858996679095085, 0.31272271606557295`, 0.9338980831223087], 
             213 -> RGBColor[
              0.3254133616442444, 0.45627843093029025`, 0.9419560295456021], 
             352 -> RGBColor[
              0.18638553952238943`, 0.3132333979367503, 0.9339257527918797], 
             27 -> RGBColor[
              0.20503271821821972`, 0.3328327650454837, 0.9349876820325784], 
             367 -> RGBColor[
              0.1860930553658944, 0.31292597854370746`, 0.9339090962518588], 
             19 -> RGBColor[
              0.19951285246669712`, 0.3270310361609309, 0.9346733338439388], 
             164 -> RGBColor[
              0.21499276582137244`, 0.3433014065798891, 0.935554892009008], 
             190 -> RGBColor[
              0.2121526703486752, 0.34031628616563087`, 0.9353931527733826], 
             103 -> RGBColor[
              0.19478977051563845`, 0.3220667775696765, 0.9344043613139996], 
             138 -> RGBColor[
              0.2889051941793347, 0.4209880551027343, 0.939764095460355], 291 -> 
             RGBColor[
              0.1954605501868454, 0.3227718095340026, 0.9344425612239453], 28 -> 
             RGBColor[
              0.19159599737019925`, 0.31870991949690686`, 0.9342224806581308],
              337 -> RGBColor[
              0.956979221732861, 0.9674357545252026, 0.9577071353769899], 195 -> 
             RGBColor[
              0.42461827381123246`, 0.5422047396654701, 0.9482772788254231], 
             114 -> RGBColor[
              0.18667779652152947`, 0.3135405785730105, 0.9339423963956253], 
             93 -> RGBColor[
              0.3425287629814334, 0.47110293132347947`, 0.9430466077842526], 
             34 -> 
             RGBColor[
              0.1829376663072982, 0.30960946457990146`, 0.9337294015129516], 
             161 -> RGBColor[
              0.8795463410175769, 0.5459298918751729, 0.22120285316675511`], 
             22 -> RGBColor[
              0.24203296140503872`, 0.3717223665857442, 0.9370947911451132], 
             124 -> RGBColor[
              0.22661866237074535`, 0.3555209609776956, 0.9362169696185221], 
             84 -> RGBColor[
              0.21428709115836797`, 0.3425596977667136, 0.935514704880902], 
             46 -> RGBColor[
              0.8055364749096104, 0.8480104835941301, 0.9812520057187881], 
             241 -> RGBColor[
              0.28091140737960196`, 0.41258607834085864`, 0.939308861127858], 
             185 -> RGBColor[
              0.19254963929720473`, 0.31971225762658, 0.9342767891550869], 
             390 -> RGBColor[
              0.21298290042549683`, 0.3411889106159976, 0.9354404331480423], 
             121 -> RGBColor[
              0.24372417422141443`, 0.37349993848484087`, 0.9371911032130806],
              322 -> RGBColor[
              0.1951112049063669, 0.3224046254944496, 0.9344226665270321], 
             126 -> RGBColor[
              0.18255935854789945`, 0.309211839138676, 0.9337078574457099], 
             236 -> RGBColor[
              0.5096359477486948, 0.612784447077024, 0.9545395551462174], 78 -> 
             RGBColor[
              0.22046571832082573`, 0.34905382666204504`, 0.9358665685573442],
              376 -> RGBColor[
              0.28617898913701123`, 0.4181226407518692, 0.9396088421162536], 
             254 -> RGBColor[
              0.1870776850955973, 0.3139608868187558, 0.9339651694583363], 
             290 -> RGBColor[
              0.25752973177491306`, 0.38801045479647306`, 0.9379773092922603],
              251 -> RGBColor[
              0.1849258667142184, 0.3116991892667612, 0.9338426265848467], 
             165 -> RGBColor[
              0.22554056397195027`, 0.35438781120517543`, 0.9361555735096144],
              100 -> RGBColor[
              0.387712192347488, 0.5102385468551641, 0.9459256559493198], 235 -> 
             RGBColor[
              0.19324911536591247`, 0.3204474513241361, 0.9343166232824178], 
             70 -> RGBColor[
              0.1969643686712329, 0.32435241810869275`, 0.934528201461931], 
             234 -> RGBColor[
              0.24693624036742998`, 0.3768760236610595, 0.9373740256282702], 
             257 -> RGBColor[
              0.9694202648664492, 0.9767142641238943, 0.9366476944955487], 
             135 -> 
             RGBColor[
              0.335355251737071, 0.46488959643477135`, 0.9425895179910487], 
             265 -> RGBColor[
              0.19899652547638796`, 0.32648834375709396`, 0.934643929785678], 
             111 -> RGBColor[
              0.8266120846200963, 0.20555772064570646`, 0.17311706832724205`],
              381 -> RGBColor[
              0.1893487791980019, 0.3163479507160659, 0.9340945049076855], 
             182 -> RGBColor[
              0.24182762690147153`, 0.3715065470035356, 0.9370830976489003], 
             188 -> RGBColor[
              0.27580922111776024`, 0.4072233570823697, 0.9390182991682543], 
             154 -> RGBColor[
              0.18637271886218407`, 0.3132199226099977, 0.9339250226742475], 
             336 -> RGBColor[
              0.23480104226620413`, 0.36412116104067216`, 0.9366829440488222],
              315 -> RGBColor[
              0.1811098371299533, 0.3076883002234485, 0.9336253093453327], 
             368 -> RGBColor[
              0.1838330998850932, 0.3105506220439319, 0.9337803951305317], 
             269 -> RGBColor[
              0.3534033382914345, 0.480521941884955, 0.9437395261069965], 208 -> 
             RGBColor[
              0.2944180010032382, 0.4267823646067975, 0.9400780416535094], 86 -> 
             RGBColor[
              0.2680992625939086, 0.39911970183419715`, 0.9385792284361825], 
             119 -> RGBColor[
              0.2397898236287226, 0.36936468655968646`, 0.936967047767177], 
             377 -> RGBColor[
              0.25469411239970985`, 0.38503003904448196`, 0.9378158249637654],
              140 -> RGBColor[
              0.4063466574019441, 0.5263787838898877, 0.9471130275847793], 85 -> 
             RGBColor[
              0.1818888062976524, 0.30850704620819813`, 0.9336696704870515], 
             351 -> RGBColor[
              0.3095548228305918, 0.44254256168324113`, 0.9409455374755513], 
             242 -> RGBColor[
              0.3403985574835718, 0.4692578543884732, 0.9429108729735957], 
             117 -> RGBColor[
              0.5585316039927765, 0.6524801435401812, 0.9583888003164419], 47 -> 
             RGBColor[
              0.18100426741029385`, 0.3075773397545796, 0.9336192973059745], 
             81 -> RGBColor[
              0.22915597848204, 0.35818784108579943`, 0.9363614660174375], 
             275 -> RGBColor[
              0.194144227344503, 0.3213882707670121, 0.934367598585399], 23 -> 
             RGBColor[
              0.2119196850624197, 0.340071403857656, 0.9353798846060012], 328 -> 
             RGBColor[
              0.2313516506730186, 0.3604956317721754, 0.9364865063005079], 
             110 -> RGBColor[
              0.8529626688242167, 0.8855932953383124, 0.985837534872859], 6 -> 
             RGBColor[
              0.9261633007621113, 0.943961492267368, 0.992819476494071], 218 -> 
             RGBColor[
              0.5602763464580424, 0.6538966040732364, 0.9585261528345099], 
             108 -> RGBColor[
              0.3063635945960659, 0.4393379408672382, 0.9407583255366989], 
             297 -> RGBColor[
              0.2965600408339725, 0.42903378428206873`, 0.9402000276530058], 
             157 -> RGBColor[
              0.24686136029389427`, 0.3767973199561026, 0.9373697613188575], 
             354 -> RGBColor[
              0.19610120868731518`, 0.3234451822380914, 0.9344790457777777], 
             385 -> RGBColor[
              0.9944175835604394, 0.9904681006416884, 0.633766605113725], 270 -> 
             RGBColor[
              0.20794500379241626`, 0.3358937618335345, 0.9351535323876885], 
             392 -> RGBColor[
              0.2030621295519029, 0.3307615514146469, 0.9348754599232564], 33 -> 
             RGBColor[
              0.24658940627570813`, 0.37651147904010834`, 0.9373542739398417],
              252 -> RGBColor[
              0.20594129701488287`, 0.33378773896799957`, 0.9350394242509266],
              394 -> RGBColor[
              0.35762511408731845`, 0.48417863188672844`, 0.9440085339275405],
              260 -> RGBColor[
              0.1889310324973132, 0.31590887244697147`, 0.9340707148510822], 
             159 -> RGBColor[
              0.18214142158537838`, 0.30877256089233246`, 0.9336840565539767],
              183 -> RGBColor[
              0.18868393066647376`, 0.3156491527555983, 0.9340566427673703], 
             99 -> RGBColor[
              0.9021660914511284, 0.9248267689496842, 0.9905306012474278], 
             329 -> RGBColor[
              0.2623389378177228, 0.3930652352687406, 0.9382511864618155], 
             309 -> RGBColor[
              0.6973666945960665, 0.7635074290924103, 0.9704706529212034], 17 -> 
             RGBColor[
              0.8276616884309496, 0.21362543547524793`, 0.17412217012187317`],
              349 -> RGBColor[
              0.19841472542917707`, 0.32587683501922177`, 0.9346107971336854],
              347 -> RGBColor[
              0.18432439621433888`, 0.3110670056359555, 0.9338083737296745], 
             340 -> RGBColor[
              0.27139200070452485`, 0.4025805783601091, 0.9387667450004126], 
             277 -> 
             RGBColor[
              0.1851145385676597, 0.3118974953472144, 0.9338533711677852], 
             104 -> RGBColor[
              0.22404918964109946`, 0.35282028222485723`, 0.936070641947763], 
             79 -> RGBColor[
              0.199051197909799, 0.3265458079510415, 0.9346470432998802], 327 -> 
             RGBColor[
              0.18576331458524015`, 0.3125794000764668, 0.9338903180022083], 
             191 -> RGBColor[
              0.1840091371887301, 0.310735648411464, 0.9337904201945499], 50 -> 
             RGBColor[
              0.23112771995435683`, 0.3602602663888343, 0.9364737537773559], 
             225 -> RGBColor[
              0.2084820527788493, 0.336458234369148, 0.9351841165329731], 61 -> 
             RGBColor[
              0.21726621743653565`, 0.3456909483725835, 0.9356843617152213], 
             196 -> RGBColor[
              0.844124603334554, 0.8785460618197521, 0.9849945522966208], 1 -> 
             RGBColor[
              0.1818132732838514, 0.3084276562216236, 0.9336653689936567], 
             263 -> RGBColor[
              0.30183205672017543`, 0.43457500724358145`, 0.9405002611584765],
              201 -> RGBColor[
              0.6657140642559093, 0.738780153701779, 0.9673158145395446], 371 -> 
             RGBColor[
              0.18003320207443918`, 0.306556688517498, 0.93356399657166], 293 -> 
             RGBColor[
              0.3141297509318431, 0.44650513446197276`, 0.941237047848713], 
             362 -> RGBColor[
              0.7912709059084366, 0.8368661126680731, 0.979830147120073], 184 -> 
             RGBColor[
              0.21355297767290998`, 0.3417880979480139, 0.9354728982039288], 
             106 -> RGBColor[
              0.1865190623784995, 0.31337373892436005`, 0.9339333567210057], 
             206 -> RGBColor[
              0.4288884024290853, 0.5459033104513494, 0.9485493676450263], 
             358 -> RGBColor[
              0.2775970966062373, 0.4091025275786123, 0.9391201160323983], 
             247 -> RGBColor[
              0.8173387448883187, 0.1342787678638822, 0.16423690772735258`], 
             220 -> RGBColor[
              0.17970434930417156`, 0.30621104340547683`, 0.9335452688928874],
              107 -> RGBColor[
              0.2230811340648649, 0.3518027944359661, 0.9360155126148064], 
             375 -> RGBColor[
              0.20279567675606608`, 0.3304814926321394, 0.9348602858307151], 
             131 -> RGBColor[
              0.8141109072907318, 0.8547088953383618, 0.982106625005912], 127 -> 
             RGBColor[
              0.3393687513351076, 0.46836588806223545`, 0.9428452546364373], 
             210 -> RGBColor[
              0.2456807114445148, 0.37555638315794415`, 0.9373025251134988], 
             357 -> RGBColor[
              0.18600360463112436`, 0.31283196014996, 0.9339040021648441], 
             181 -> RGBColor[
              0.19212227783830665`, 0.31926307363699663`, 0.9342524515522274],
              194 -> RGBColor[
              0.4554399226734993, 0.5687856724178738, 0.9502730455257168], 
             118 -> RGBColor[
              0.3574473894517768, 0.48402469574012214`, 0.9439972094709195], 
             348 -> RGBColor[
              0.20110409825488346`, 0.3287035363751249, 0.9347639529375389], 
             276 -> RGBColor[
              0.37904525788294496`, 0.5027316838347692, 0.9453734065491083], 
             305 -> RGBColor[
              0.29805944165302733`, 0.4306097496103981, 0.9402854163114862], 
             343 -> RGBColor[
              0.20071986914810575`, 0.3282996872223691, 0.9347420716583239], 
             280 -> RGBColor[
              0.2089289786028837, 0.3369279817469421, 0.9352095682974844], 
             189 -> RGBColor[
              0.2331737072204319, 0.36241072872856434`, 0.9365902697253919], 
             168 -> RGBColor[
              0.19796437105250972`, 0.32540348401522773`, 0.9345851501181738],
              363 -> RGBColor[
              0.3745258073527012, 0.4988171629396605, 0.9450854311577144], 41 -> 
             RGBColor[
              0.19479503600678127`, 0.322072311934719, 0.9344046611759306], 
             14 -> RGBColor[
              0.3386493168091526, 0.46774275003568394`, 0.9427994129046144], 
             77 -> RGBColor[
              0.1969521059625652, 0.3243395292243824, 0.9345275031188135], 51 -> 
             RGBColor[
              0.20120879960667537`, 0.3288135841343073, 0.9347699155246316], 
             179 -> RGBColor[
              0.2268131918331927, 0.35572542377660804`, 0.9362280477836279], 
             223 -> RGBColor[
              0.8592163258347785, 0.4536160411257659, 0.20423899016395516`], 
             323 -> RGBColor[
              0.42062186552277797`, 0.5387432516713317, 0.9480226312231679], 
             292 -> RGBColor[
              0.8194918846006688, 0.15082874320484374`, 0.1662987567475226], 
             396 -> RGBColor[
              0.18439801323969868`, 0.31114438179719767`, 0.9338125661103621],
              321 -> RGBColor[
              0.18455342051778426`, 0.3113077246998561, 0.9338214163249446], 
             143 -> 
             RGBColor[
              0.19890345919190142`, 0.32639052519135536`, 0.9346386297984558],
              112 -> RGBColor[
              0.1804406002012431, 0.3069848897793021, 0.93358719729229], 197 -> 
             RGBColor[
              0.19131157595015044`, 0.3184109745510759, 0.9342062832790229], 
             54 -> RGBColor[
              0.9482538006021336, 0.8325505933258706, 0.2772219972063093], 71 -> 
             RGBColor[
              0.9697038754518477, 0.9769257804341147, 0.9361676157519565], 
             177 -> RGBColor[
              0.18139651046953492`, 0.3079896120794884, 0.9336416349679267], 
             158 -> RGBColor[
              0.1911403477299942, 0.3182310028351955, 0.9341965320851944], 
             226 -> RGBColor[
              0.19190461331519068`, 0.3190342944224739, 0.9342400558796418], 
             350 -> RGBColor[
              0.3485452682138572, 0.4763141257574593, 0.943429974177476], 203 -> 
             RGBColor[
              0.3100095560527289, 0.44293642874469996`, 0.9409745126743612], 
             115 -> RGBColor[
              0.9551078718556497, 0.8597247018622127, 0.2827369438226184], 
             173 -> RGBColor[
              0.17959143492855675`, 0.30609236323752076`, 0.933538838586238], 
             212 -> RGBColor[
              0.5777795176543054, 0.6681064669592394, 0.9599040665873084], 
             129 -> RGBColor[
              0.8193361618613183, 0.1496317899920564, 0.1661496364764569], 
             279 -> RGBColor[
              0.1990369147875074, 0.3265307954839108, 0.9346462298971957], 26 -> 
             RGBColor[
              0.1822568035379685, 0.30889383464014303`, 0.9336906273854845], 
             40 -> RGBColor[
              0.1934487547814754, 0.32065728500776275`, 0.934327992451794], 
             146 -> RGBColor[
              0.1991293041825628, 0.32662790259593993`, 0.9346514913365662], 
             386 -> RGBColor[
              0.3419268933615933, 0.4705816221096207, 0.9430082571842888], 
             192 -> RGBColor[
              0.2582664433427927, 0.3887847853645258, 0.938019263926184], 300 -> 
             RGBColor[
              0.19616100168040002`, 0.3235080284649182, 0.934482450900278], 
             221 -> RGBColor[
              0.36991176607450643`, 0.49482071229294583`, 0.9447914285275043],
              62 -> RGBColor[
              0.9918038536315829, 0.990878697092375, 0.7854948864789351], 286 -> 
             RGBColor[
              0.3212434064694567, 0.45266662534593033`, 0.9416903236892111], 
             152 -> 
             RGBColor[
              0.2008438754397465, 0.3284300256973365, 0.9347491336331819], 64 -> 
             RGBColor[
              0.9925852496598342, 0.986548923705669, 0.43432836788688456`], 
             307 -> RGBColor[
              0.17902996710188124`, 0.3055022249525685, 0.933506863824126], 
             37 -> RGBColor[
              0.2843315036737978, 0.41618081639268795`, 0.9395036305522334], 
             148 -> RGBColor[
              0.25655300447979307`, 0.38698385248121464`, 0.9379216861177417],
              261 -> RGBColor[
              0.18920356017618423`, 0.31619531631671777`, 0.9340862348992254],
              387 -> RGBColor[
              0.18554205504628538`, 0.3123468422723603, 0.933877717598789], 
             15 -> RGBColor[
              0.18212992963139682`, 0.3087604821200659, 0.9336834021041983], 
             136 -> RGBColor[
              0.18263620644148504`, 0.30929261114727236`, 0.9337122338195634],
              198 -> RGBColor[
              0.8287975688378628, 0.8663247005533589, 0.9835326460637211], 63 -> 
             RGBColor[
              0.18932442036239164`, 0.31632234803540016`, 0.9340931177080333],
              310 -> RGBColor[
              0.8265166883216026, 0.20482446289255998`, 0.17302571672406986`],
              171 -> RGBColor[
              0.18805335571358273`, 0.3149863784993486, 0.9340207324566552], 
             395 -> RGBColor[
              0.4386808762090538, 0.554385059055515, 0.9491733354151413], 311 -> 
             RGBColor[
              0.2025961788233211, 0.3302718076559249, 0.934848924718576], 353 -> 
             RGBColor[
              0.9932598001133134, 0.9879917189181485, 0.507749021905247], 59 -> 
             RGBColor[
              0.21627237251575757`, 0.34464635434743823`, 0.9356277637172448],
              397 -> RGBColor[
              0.36417957475425095`, 0.48985577627965343`, 0.9444261783653554],
              229 -> RGBColor[
              0.19792175174780763`, 0.3253586884237658, 0.9345827230118207], 
             102 -> RGBColor[
              0.34903475823839447`, 0.4767380974142295, 0.9434611640490004], 
             299 -> RGBColor[
              0.18838969891108812`, 0.3153398965253172, 0.9340398867041779], 
             128 -> RGBColor[
              0.3039019362504366, 0.4367505818678281, 0.9406181377356125], 12 -> 
             RGBColor[
              0.242785484860208, 0.37251331644986996`, 0.9371376462426264], 
             222 -> RGBColor[
              0.9510874915293103, 0.9630417117862173, 0.9676802978022608], 92 -> 
             RGBColor[
              0.20437042968316516`, 0.3321366578036229, 0.9349499656802752], 
             271 -> RGBColor[
              0.8200027527924696, 0.15475549999089333`, 0.1667879647049341], 
             361 -> RGBColor[
              0.40957405763887067`, 0.529174195761261, 0.9473186746739982], 
             344 -> RGBColor[
              0.1915625031716876, 0.3186747149706162, 0.9342205732130758], 
             132 -> RGBColor[
              0.19287402797566439`, 0.32005321069507126`, 0.9342952626104353],
              80 -> RGBColor[
              0.20310658273494972`, 0.3308082745285237, 0.9348779914662683], 
             324 -> RGBColor[
              0.1856877903127057, 0.31250001927751764`, 0.9338860170066157], 
             244 -> RGBColor[
              0.18235944175044905`, 0.3090017139090986, 0.9336964724798456], 
             150 -> RGBColor[
              0.23840666361665402`, 0.3679108976895925, 0.9368882788506916], 
             125 -> RGBColor[
              0.1925981967986741, 0.3197632946393477, 0.9342795544329613], 
             258 -> RGBColor[
              0.23765262088408304`, 0.3671183509685898, 0.9368453372325779], 
             133 -> RGBColor[
              0.18340497994045135`, 0.3101006408377411, 0.933756014333031], 
             255 -> RGBColor[
              0.37418878878290995`, 0.4985252543935531, 0.9450639566324611], 
             326 -> RGBColor[
              0.24157157412247404`, 0.37123741929812537`, 0.9370685158219325],
              176 -> RGBColor[
              0.18620451936940718`, 0.3130431342786254, 0.9339154439619627], 
             230 -> RGBColor[
              0.2211253737681676, 0.3497471663617724, 0.9359041349591976], 
             274 -> RGBColor[
              0.20313982636998706`, 0.33084321569671615`, 0.9348798846421041],
              87 -> RGBColor[
              0.18684859723136407`, 0.31372010094843716`, 0.9339521232433733],
              130 -> RGBColor[
              0.21566341381177923`, 0.3440063001393452, 0.9355930844199268], 
             35 -> RGBColor[
              0.19009976398754364`, 0.3171372833450601, 0.9341372723804675], 
             379 -> RGBColor[
              0.18246816409549027`, 0.30911598798713175`, 0.9337026640565553],
              31 -> RGBColor[
              0.9842583887354778, 0.9877584534482328, 0.9105427668445933], 18 -> 
             RGBColor[
              0.9925358512363838, 0.9864432654728553, 0.42895165434603927`], 
             24 -> RGBColor[
              0.2601817623901309, 0.39079790712151985`, 0.9381283385124692], 
             151 -> 
             RGBColor[
              0.20761230953904478`, 0.335544079079207, 0.935134585942136], 
             137 -> RGBColor[
              0.29264465833089975`, 0.42491846902175034`, 0.9399770524117451],
              330 -> RGBColor[
              0.18870039039885345`, 0.3156664529779366, 0.9340575801247794], 
             296 -> RGBColor[
              0.17907641669607907`, 0.3055510464211448, 0.9335095090597996], 
             266 -> RGBColor[
              0.6582217134144572, 0.7329270722804612, 0.9665690470276681], 
             302 -> RGBColor[
              0.19470143524485908`, 0.32197393159930776`, 0.9343993307510091],
              283 -> RGBColor[
              0.9319225428018962, 0.7678025982169813, 0.26408148383634866`], 
             388 -> RGBColor[
              0.2707814877613013, 0.40193889054802484`, 0.938731977191469], 
             284 -> RGBColor[
              0.7398648594018855, 0.7967073184367315, 0.9747064728211174], 
             318 -> RGBColor[
              0.21345649486519924`, 0.3416866883997466, 0.9354674036507632], 
             238 -> RGBColor[
              0.20088219976865415`, 0.32847030699692126`, 0.9347513161470175],
              72 -> RGBColor[
              0.46553671991296847`, 0.576982707272407, 0.9510679023901947], 
             288 -> RGBColor[
              0.2137339467700851, 0.34197830794324846`, 0.935483204126293], 
             382 -> RGBColor[
              0.3220959675484921, 0.453405070901625, 0.9417446481272771], 389 -> 
             RGBColor[
              0.9931232770303468, 0.9876997098482838, 0.4928893268471293], 
             172 -> RGBColor[
              0.3796233347917912, 0.5032323849982215, 0.9454102410985666], 
             243 -> RGBColor[
              0.23139395253121084`, 0.36054009370722817`, 0.9364889153287519],
              88 -> RGBColor[
              0.4303958842275222, 0.5472090154169172, 0.9486454230522088], 
             273 -> RGBColor[
              0.5240458703783706, 0.6244830714274116, 0.9556739570409113], 
             202 -> RGBColor[
              0.3275914997751332, 0.4581650247028605, 0.9420948185812503], 
             393 -> RGBColor[
              0.7219717591850786, 0.7827290925547635, 0.9729230558120345], 98 -> 
             RGBColor[
              0.1932487717488401, 0.3204470901608064, 0.9343166037139339], 30 -> 
             RGBColor[
              0.20069898841488326`, 0.3282777402478373, 0.9347408825314572], 
             116 -> RGBColor[
              0.24002120291967022`, 0.3696078808647668, 0.9369802244755014], 
             373 -> 
             RGBColor[
              0.19798515205544082`, 0.3254253261669, 0.934586333565548], 240 -> 
             RGBColor[
              0.17933281357579656`, 0.305820535798229, 0.9335241104827943], 
             317 -> RGBColor[
              0.18850413369751906`, 0.3154601747414406, 0.9340464035959741], 
             391 -> RGBColor[
              0.8202342132018924, 0.1565346061243149, 0.16700961145439447`], 
             73 -> RGBColor[
              0.1985117660113969, 0.3259788308238631, 0.9346163234512842], 
             303 -> RGBColor[
              0.8939300581111314, 0.611242991794526, 0.23320497928678602`], 
             29 -> RGBColor[
              0.18584110899752487`, 0.3126611669362287, 0.9338947482789014], 
             360 -> RGBColor[
              0.6627555094400547, 0.736468908193784, 0.9670209334447669], 320 -> 
             RGBColor[
              0.18370800885926494`, 0.3104191434445573, 0.9337732713816664], 
             75 -> RGBColor[
              0.18190969424137163`, 0.30852900076141915`, 0.9336708600245455],
              200 -> RGBColor[
              0.19404714705117995`, 0.3212862332234835, 0.9343620700063117], 
             301 -> RGBColor[
              0.24986810421890843`, 0.3799575984598681, 0.937540990937308], 
             156 -> RGBColor[
              0.20187169700218524`, 0.3295103313271106, 0.9348076665506371], 
             25 -> RGBColor[
              0.3639618362230004, 0.489667182107741, 0.9444123042586827], 38 -> 
             RGBColor[
              0.2587257572717294, 0.3892675534260234, 0.9380454211749428], 
             365 -> RGBColor[
              0.30601698137869693`, 0.43897362839923615`, 0.940738586426738], 
             380 -> RGBColor[
              0.7203821791624184, 0.7814873005598058, 0.9727646213308456], 
             370 -> RGBColor[
              0.18554668841356567`, 0.31235171223514435`, 0.9338779814622011],
              3 -> RGBColor[
              0.23621542372166607`, 0.36560776562732644`, 0.9367634909803209],
              57 -> RGBColor[
              0.3482989604247025, 0.47610078633028297`, 0.9434142796629524], 
             227 -> RGBColor[
              0.2739918424465178, 0.40531317687043084`, 0.9389148021414978], 
             39 -> RGBColor[
              0.19817415326039348`, 0.32562397841667373`, 0.9345970969045678],
              109 -> RGBColor[
              0.1827503081177702, 0.3094125392435122, 0.9337187317412295], 
             256 -> RGBColor[
              0.9923039511135691, 0.9910855002530954, 0.777206976991627], 339 -> 
             RGBColor[
              0.38195753878243316`, 0.5052541551744117, 0.9455589745127948], 
             287 -> RGBColor[0.817319, 0.134127, 0.164218], 239 -> 
             RGBColor[
              0.5071373117219987, 0.6107559417882819, 0.9543428533653905], 
             285 -> RGBColor[
              0.18427610046840573`, 0.31101624374485265`, 0.9338056233583907],
              345 -> RGBColor[
              0.8280837295399454, 0.865755504473851, 0.9834645594342339], 366 -> 
             RGBColor[
              0.9933000584574108, 0.9880778274454297, 0.5121308942145434], 
             216 -> RGBColor[
              0.21581639795358076`, 0.3441670961721334, 0.9356017966404827], 
             21 -> RGBColor[
              0.19666790482252822`, 0.3240408158068105, 0.9345113182843263], 
             355 -> RGBColor[
              0.2081404760074813, 0.3360992155252221, 0.9351646642411613], 
             175 -> RGBColor[
              0.19013667027984396`, 0.3171760741982618, 0.9341393741392161], 
             7 -> RGBColor[
              0.25494849258932906`, 0.3852974087524073, 0.9378303115392425], 
             13 -> RGBColor[
              0.21336291477373137`, 0.3415883297902934, 0.9354620744029933], 
             294 -> RGBColor[
              0.20973292712492791`, 0.3377729826168909, 0.9352553519764795], 
             193 -> RGBColor[
              0.8379281346647119, 0.8736051659010814, 0.9844035275832383], 60 -> 
             RGBColor[
              0.7070237961498369, 0.7710516302229059, 0.9714331825533382], 65 -> 
             RGBColor[
              0.3764941167365503, 0.5005220135978444, 0.9452108500911456], 69 -> 
             RGBColor[
              0.5728179374316162, 0.6640784326178184, 0.9595134728173111], 
             217 -> RGBColor[
              0.2082469591636211, 0.3362111360737471, 0.9351707282993756], 
             214 -> RGBColor[
              0.8789213821202363, 0.5430920994852084, 0.22068137214366979`], 
             170 -> RGBColor[
              0.23550398192177388`, 0.3648599951876243, 0.9367229754223009], 
             359 -> RGBColor[
              0.32568965645452963`, 0.4565177436079784, 0.9419736348065956], 
             74 -> RGBColor[
              0.24853385159996577`, 0.37855521436085726`, 0.9374650072245091],
              246 -> RGBColor[
              0.2167015948028579, 0.34509749418544555`, 0.9356522072915177], 
             264 -> RGBColor[
              0.2599789274537134, 0.39058471474286727`, 0.9381167873629076], 
             278 -> RGBColor[
              0.1880939032775767, 0.3150289965599703, 0.9340230415804399], 45 -> 
             RGBColor[
              0.23972125787035842`, 0.36929261960032556`, 0.9369631430486721],
              306 -> RGBColor[
              0.22229995450050422`, 0.350981725184178, 0.9359710255942676], 
             237 -> RGBColor[
              0.18222514168352894`, 0.3088605560236495, 0.9336888242897137], 
             228 -> RGBColor[
              0.22400797509009437`, 0.3527769631185974, 0.9360682948400547], 
             180 -> RGBColor[
              0.18842432755960442`, 0.31537629343049095`, 0.9340418587544824],
              383 -> RGBColor[
              0.3583175561905998, 0.4847783904334387, 0.944052655726059], 53 -> 
             RGBColor[
              0.40260480881009003`, 0.5231377827104023, 0.9468746003012931], 
             304 -> RGBColor[
              0.2822705085644714, 0.4140145798581486, 0.9393862599297264], 48 -> 
             RGBColor[
              0.20793893985757575`, 0.3358873882535414, 0.9351531870555702], 
             5 -> RGBColor[
              0.18681770269069906`, 0.3136876288273712, 0.9339503638449868], 
             101 -> RGBColor[
              0.8539737461394735, 0.41587144104017043`, 0.19931862629877445`],
              333 -> RGBColor[
              0.9537765326908467, 0.9650471942815904, 0.9631284525300384], 
             267 -> RGBColor[
              0.19756403157199334`, 0.32498270183821587`, 0.9345623513770076],
              120 -> RGBColor[
              0.41254771032069193`, 0.531749824254125, 0.9475081531933861], 
             147 -> RGBColor[
              0.24721508689536167`, 0.3771691090418067, 0.9373899055255195], 
             89 -> RGBColor[
              0.23222586891438338`, 0.3614144905724877, 0.9365362917360636], 
             43 -> RGBColor[
              0.194697223000598, 0.3219695042635176, 0.9343990908699299], 199 -> 
             RGBColor[
              0.9887357523774989, 0.9896099583772056, 0.8363412642506296], 
             268 -> RGBColor[
              0.187660141527025, 0.31457308545805707`, 0.933998339490439], 
             169 -> RGBColor[
              0.45725872125089195`, 0.5702622550389433, 0.9504162280122078], 
             20 -> RGBColor[
              0.3846257063952153, 0.5075651878546001, 0.9457289877937134], 4 -> 
             RGBColor[
              0.2008450066857079, 0.32843121470856707`, 0.9347491980559659], 
             167 -> RGBColor[
              0.2358064817309028, 0.3651779416666145, 0.9367402023389224], 
             142 -> 
             RGBColor[
              0.4741596199861951, 0.5839831660090739, 0.9517467286706829], 16 -> 
             RGBColor[
              0.22895368331262583`, 0.3579752160364906, 0.9363499456068083], 
             281 -> RGBColor[
              0.39875120665503094`, 0.5197999862113661, 0.9466290521795794], 
             289 -> RGBColor[
              0.4742143938317012, 0.5840276338843894, 0.9517510406684443], 
             398 -> RGBColor[
              0.1808071689883251, 0.3073701768163288, 0.9336080728424244], 
             178 -> RGBColor[
              0.18300767959384703`, 0.309683052983163, 0.9337333886660452], 
             58 -> RGBColor[
              0.19320352841391442`, 0.32039953654720643`, 0.9343140271729413],
              186 -> RGBColor[
              0.2065811071166083, 0.33446021995121644`, 0.9350758604897056], 
             122 -> RGBColor[
              0.18936604401309215`, 0.31636609713137825`, 0.934095488113364], 
             249 -> RGBColor[
              0.18362197162651986`, 0.31032871285786656`, 0.9337683716885422],
              113 -> RGBColor[
              0.1856485479005117, 0.3124587730141891, 0.9338837822092951], 52 -> 
             RGBColor[
              0.9889946602077696, 0.9897170234186503, 0.8320504914710569], 
             187 -> RGBColor[
              0.21634716160662554`, 0.34472496242384276`, 0.9356320228453292],
              259 -> RGBColor[
              0.8954246210317355, 0.9194513034296, 0.9898875937806444], 42 -> 
             RGBColor[
              0.183885630512114, 0.31060583506356493`, 0.9337833866720284], 
             134 -> RGBColor[
              0.17911500115561352`, 0.3055916011345115, 0.9335117063876894], 
             313 -> RGBColor[
              0.28461757525764775`, 0.41648149576530025`, 0.9395199219057286],
              248 -> RGBColor[
              0.1829127869860106, 0.3095833148357881, 0.9337279846724099], 
             174 -> RGBColor[
              0.41783566912403936`, 0.5363299883890472, 0.947845097252377], 
             215 -> RGBColor[
              0.7060709713767632, 0.7703072762684443, 0.9713382138846121], 
             399 -> RGBColor[
              0.3593758114062829, 0.48569499791180964`, 0.944120086812624], 
             83 -> RGBColor[
              0.9509849302078126, 0.9629652217205732, 0.9678539073672795], 95 -> 
             RGBColor[
              0.24723118250472642`, 0.37718602654776967`, 0.9373908221466615],
              166 -> RGBColor[
              0.2451744333338886, 0.3750242527637898, 0.93727369332407], 384 -> 
             RGBColor[
              0.9335847383251342, 0.7743926495727972, 0.2654189253710895], 
             233 -> RGBColor[
              0.9703310152107799, 0.9773935002394792, 0.9351060317243296], 
             295 -> RGBColor[
              0.18590102371033476`, 0.3127241410982041, 0.9338981603331601], 
             141 -> RGBColor[
              0.3557668224000087, 0.48256907302763663`, 0.9438901252244479], 
             319 -> RGBColor[
              0.8324443832728455, 0.2503873238203034, 0.17870208410375396`], 
             205 -> RGBColor[
              0.18515378626434187`, 0.3119387471648751, 0.9338556062660495], 
             224 -> RGBColor[
              0.4977475489543879, 0.6031329093695432, 0.9536036568444898], 
             231 -> RGBColor[
              0.19120668731506069`, 0.31830072994527303`, 0.9342003100264233],
              332 -> RGBColor[
              0.8178049183525352, 0.13786198138836525`, 0.164683315963154], 
             68 -> RGBColor[
              0.8216043579673015, 0.8605890294596807, 0.9828465511894319], 10 -> 
             RGBColor[
              0.8429670986480872, 0.3312695252776902, 0.18877864823079255`], 
             250 -> RGBColor[
              0.19372013073248498`, 0.3209425183385029, 0.9343434469107393], 
             282 -> RGBColor[
              0.31502354175322494`, 0.44727929114822085`, 0.9412939994095033],
              374 -> RGBColor[
              0.1836365577609456, 0.3103440438099624, 0.9337692023473195], 
             232 -> RGBColor[
              0.19035994618760685`, 0.3174107513338308, 0.934152089371856], 
             253 -> RGBColor[
              0.8251923969012658, 0.19464537872765014`, 0.17175757376438203`],
              55 -> RGBColor[
              0.8037373305687819, 0.8466049783610714, 0.9810726838248541], 
             325 -> RGBColor[
              0.23827199083861747`, 0.36776934806112876`, 0.9368806094352129],
              91 -> RGBColor[
              0.5925759149291727, 0.6801188488370776, 0.961068893181775], 105 -> 
             RGBColor[
              0.9853022906708313, 0.9881901337255575, 0.8932426102441758], 36 -> 
             RGBColor[
              0.24565388341041777`, 0.3755281851931126, 0.9373009972966455], 
             123 -> RGBColor[
              0.843157812611701, 0.33273543637341757`, 0.18896127613772973`], 
             94 -> RGBColor[
              0.1791057270796212, 0.3055818534926332, 0.9335111782427814], 
             312 -> RGBColor[
              0.5478165382686445, 0.6437811704771209, 0.9575452710920592], 96 -> 
             RGBColor[
              0.21162927735784165`, 0.3397661669472325, 0.9353633463168451], 
             2 -> RGBColor[
              0.20182540810126717`, 0.3294616787573599, 0.9348050304662081], 
             262 -> RGBColor[
              0.36433321534571095`, 0.4899888520377754, 0.9444359682079841], 
             272 -> RGBColor[
              0.19665135271400355`, 0.3240234184912868, 0.9345103756662324], 
             97 -> RGBColor[
              0.2986247548964671, 0.43120392967218313`, 0.9403176100643942], 
             372 -> RGBColor[
              0.179946795179367, 0.3064658693922636, 0.9335590758268132], 356 -> 
             RGBColor[
              0.9453835605713274, 0.9587877294170835, 0.9773355650906732], 
             346 -> RGBColor[
              0.20342618893072584`, 0.3311442009044876, 0.9348961925663027], 
             341 -> RGBColor[
              0.24934350578881678`, 0.3794062122483802, 0.9375111158327881], 
             209 -> RGBColor[
              0.2650455441851616, 0.3959100501696741, 0.9384053236903759], 
             378 -> RGBColor[
              0.24023703411797065`, 0.3698347331386689, 0.9369925157429511], 
             66 -> RGBColor[
              0.19612721011213427`, 0.3234725113841618, 0.9344805265204555], 
             139 -> RGBColor[
              0.30694355404168716`, 0.4399475150161388, 0.940791353369154], 
             56 -> RGBColor[
              0.5183980864407423, 0.6198979459970778, 0.9552293428008269], 
             335 -> RGBColor[
              0.1982643030525542, 0.3257187315640616, 0.9346022308018668], 
             314 -> RGBColor[
              0.18275376889499648`, 0.30941617673980293`, 0.9337189288273728],
              144 -> RGBColor[
              0.5812572311839399, 0.6709298314718057, 0.9601778449356456], 
             298 -> RGBColor[
              0.20546571259734456`, 0.33328786959137313`, 0.9350123404219118],
              204 -> RGBColor[
              0.17994083687002446`, 0.30645960683136597`, 0.9335587365099107],
              207 -> RGBColor[
              0.1915172466480543, 0.31862714749484833`, 0.934217995921006], 
             334 -> RGBColor[
              0.9602115875305376, 0.8774464833562946, 0.2999299602777051], 
             149 -> RGBColor[
              0.21032620428650672`, 0.3383965545296549, 0.9352891382331565], 
             219 -> RGBColor[0.178927, 0.305394, 0.933501], 400 -> 
             RGBColor[
              0.8221152183090297, 0.17099283563946593`, 0.16881086406928056`],
              9 -> RGBColor[
              0.6863588655876156, 0.7549080294084094, 0.9693734953996518], 11 -> 
             RGBColor[
              0.873192830390407, 0.9017242770380856, 0.9877671057427206], 44 -> 
             RGBColor[
              0.22831342724773274`, 0.3573022663177088, 0.9363134839710866], 
             153 -> RGBColor[
              0.20565135384863537`, 0.33348299031681494`, 0.9350229124165412],
              32 -> RGBColor[
              0.8215188663850046, 0.16640901342833042`, 0.16823979679335105`],
              162 -> RGBColor[
              0.19529691214488243`, 0.32259981557664835`, 0.9344332422795363],
              90 -> RGBColor[
              0.21556902434658207`, 0.3439070908267852, 0.9355877090795206], 
             331 -> RGBColor[
              0.24096885499463874`, 0.3706039232801706, 0.9370341918592453], 
             8 -> RGBColor[
              0.25559866423556843`, 0.38598078037586825`, 0.937867337852653], 
             364 -> RGBColor[
              0.92133834354613, 0.7258397751431882, 0.2555651886720716], 342 -> 
             RGBColor[
              0.18639411010760892`, 0.31324240616522253`, 0.9339262408740289],
              163 -> RGBColor[
              0.17905422337022397`, 0.30552771982853294`, 0.9335082451827241],
              49 -> RGBColor[
              0.18369802063003998`, 0.31040864518235156`, 0.9337727025667882],
              338 -> RGBColor[
              0.21013611726343454`, 0.33819676101619267`, 0.9352783130584011],
              76 -> RGBColor[
              0.2829350020755027, 0.41471300466956446`, 0.9394241018521495], 
             369 -> RGBColor[
              0.1804054273287139, 0.30694792086018496`, 0.933585194249233], 
             82 -> RGBColor[
              0.7597586089991939, 0.8122484668202457, 0.9766892958633172], 67 -> 
             RGBColor[
              0.17940647345367122`, 0.30589795700018124`, 0.9335283053038692],
              211 -> RGBColor[
              0.23248905082520588`, 0.3616911114474591, 
               0.9365512795565422]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9mGk41G3YxiVbGGbGGGMMZp+JsVWihTktLbQQJSTFQyShTSoPqYhQlpJK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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 5}], {
             RGBColor[
             0.18431548798727523`, 0.3110576425244974, 0.9338078664193217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.18382719114068813`, 0.31054441157892615`, 0.933780058636279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 73}], {
             RGBColor[
             0.19016251964762415`, 0.3172032435227433, 0.9341408462224705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[
             0.18373091059218155`, 0.31044321461790636`, 0.9337745756014759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 162}], {
             RGBColor[
             0.18855509271436693`, 0.315513735899136, 0.9340493056365965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 183}], {
             RGBColor[
             0.18524860197516257`, 0.312038404488611, 0.9338610058805135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 291}], {
             RGBColor[
             0.1886369117353484, 0.31559973287781307`, 0.934053965108801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 357}], {
             RGBColor[
             0.18390843895748787`, 0.3106298081857918, 0.9337846855792504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 368}], {
             RGBColor[
             0.1828231865844723, 0.30948913913277776`, 0.9337228820620942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 387}], {
             RGBColor[
             0.1836776641650684, 0.31038724924699196`, 0.9337715432962228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 28}], {
             RGBColor[
             0.1967107027357332, 0.32408579912713337`, 0.9345137555621694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 39}], {
             RGBColor[
             0.19999978068083032`, 0.3275428285870168, 0.934701063685388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 50}], {
             RGBColor[
             0.216476564027812, 0.3448609725730971, 0.935639392121782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 106}], {
             RGBColor[
             0.19417223523988333`, 0.32141770884085996`, 0.9343691935936069]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 137}], {
             RGBColor[
             0.24723503321608348`, 0.3771900738895551, 0.9373910414389766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 138}], {
             RGBColor[
             0.24536530114030092`, 0.3752248669300471, 0.9372845629632816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 149}], {
             RGBColor[
             0.20607580619388693`, 0.3339291166435074, 0.9350470843496823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 164}], {
             RGBColor[
             0.20840908696131982`, 0.3363815426686245, 0.935179961237608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 197}], {
             RGBColor[
             0.1965684920257088, 0.3239363266542179, 0.9345056568726156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 210}], {
             RGBColor[
             0.223753059772891, 0.352509030957652, 0.9360537777898534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 217}], {
             RGBColor[
             0.20503618363244414`, 0.3328364074155535, 0.9349878793827919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 230}], {
             RGBColor[
             0.2114753909347174, 0.33960442255956613`, 0.9353545827127028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 254}], {
             RGBColor[
             0.19445154659843222`, 0.32171128278805783`, 0.9343850999622723]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 258}], {
             RGBColor[
             0.2197390144926751, 0.34829001486297484`, 0.935825183849393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 314}], {
             RGBColor[
             0.19228958849813182`, 0.3194389277485814, 0.9342619796467905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 328}], {
             RGBColor[
             0.2165885293871429, 0.3449786552647677, 0.935645768383358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 7}], {
             RGBColor[
             0.24558195815549755`, 0.37545258718986685`, 0.9372969012597816]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 13}], {
             RGBColor[
             0.2247891692476987, 0.3535980477088099, 0.9361127826916571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 14}], {
             RGBColor[
             0.28743237026540935`, 0.41667525783150516`, 0.9397814519424676]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 21}], {
             RGBColor[
             0.21644166427209716`, 0.34482429071706844`, 0.9356374046323236]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 51}], {
             RGBColor[
             0.2187121116641707, 0.34721067488081686`, 0.9357667032524762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 79}], {
             RGBColor[
             0.21763331081573253`, 0.34607678678918397`, 0.9357052671401005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 188}], {
             RGBColor[
             0.25601232241971317`, 0.38641556135484806`, 0.9378908950742876]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 232}], {
             RGBColor[
             0.21328768495463646`, 0.3415092584805786, 0.9354577901760884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 293}], {
             RGBColor[
             0.2751725873267546, 0.40605645004464963`, 0.939000269414517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 373}], {
             RGBColor[
             0.21710028788855346`, 0.3455165458971132, 0.9356749122729344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 390}], {
             RGBColor[
             0.22459916207358144`, 0.353398338121662, 0.9361019620641815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 84}], {
             RGBColor[
             0.20756604892203795`, 0.3354954562376403, 0.935131951468434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 125}], {
             RGBColor[
             0.196721601742191, 0.3240972546739574, 0.9345143762444637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 165}], {
             RGBColor[
             0.21319278532882907`, 0.3414095129568713, 0.9354523857827901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 184}], {
             RGBColor[
             0.20719899217930893`, 0.3351096563282905, 0.9351110481299474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 185}], {
             RGBColor[
             0.1966973229914563, 0.32407173616757357`, 0.9345129936055264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 190}], {
             RGBColor[
             0.20649883851719153`, 0.33437375043709894`, 0.9350711754146743]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.1963748100004493, 0.3237327545655205, 0.9344946269678038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 252}], {
             RGBColor[
             0.20339315185029538`, 0.3311094768382833, 0.9348943111534462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 274}], {
             RGBColor[
             0.2019924165278475, 0.3296372152026416, 0.934814541349035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 288}], {
             RGBColor[
             0.2072894767278965, 0.33520476132590776`, 0.9351162010911295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 318}], {
             RGBColor[
             0.20715075077545358`, 0.3350589515541568, 0.9351083008533645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.18632940584411195`, 0.31317439788179996`, 0.9339225560619441]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 113}], {
             RGBColor[
             0.18623312529560537`, 0.31307320092078017`, 0.9339170730271409]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 162}], {
             RGBColor[
             0.19105730741779076`, 0.3181437222020098, 0.9341918030622616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 183}], {
             RGBColor[
             0.1877508166785864, 0.3146683907914848, 0.9340035033061785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 270}], {
             RGBColor[
             0.19738135324155764`, 0.32479069533045285`, 0.9345519481163376]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 291}], {
             RGBColor[
             0.19113912643877223`, 0.3182297191806869, 0.9341964625344661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 357}], {
             RGBColor[
             0.1864106536609117, 0.3132597944886656, 0.9339271830049154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 368}], {
             RGBColor[
             0.18532540128789612`, 0.31211912543565157`, 0.9338653794877592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 10}], {
             RGBColor[
             0.8706991660194285, 0.5355001809409162, 0.45679225765188536`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.6643840547861006, 0.7335496374888852, 0.969847038397682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 69}], {
             RGBColor[
             0.7494906190968638, 0.8040199624425932, 0.9761664746556911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 71}], {
             RGBColor[
             0.9479335881069795, 0.9604436363507414, 0.9644935461230137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 93}], {
             RGBColor[
             0.6343460318717724, 0.7075322117954237, 0.9679330421391619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 129}], {
             RGBColor[
             0.8549452081615826, 0.4144083574171603, 0.44170624981566164`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 131}], {
             RGBColor[
             0.8701371040264215, 0.8993351938028649, 0.9874630507499915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 142}], {
             RGBColor[
             0.7001614603741532, 0.763972329138221, 0.9722831025823769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 201}], {
             RGBColor[
             0.7959386825090102, 0.8413708229845736, 0.9800676455168078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 253}], {
             RGBColor[
             0.858849364854881, 0.44441741657422273`, 0.4454448746742784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 273}], {
             RGBColor[
             0.7251045855702409, 0.7842222818473898, 0.9742467167674911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 281}], {
             RGBColor[
             0.6624572537085711, 0.7318807392393671, 0.9697242643368251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 303}], {
             RGBColor[
             0.9100466794366213, 0.777602242030947, 0.6130122278904285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 364}], {
             RGBColor[
             0.9237508221541206, 0.8349006337052781, 0.6241923325830713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 391}], {
             RGBColor[
             0.8555439090552986, 0.41901023483866595`, 0.44227956646762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 394}], {
             RGBColor[
             0.6418942074247149, 0.7140700620770483, 0.9684140052108057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 13}], {
             RGBColor[
             0.23415570368153021`, 0.3634428692713504, 0.9366461929711178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 14}], {
             RGBColor[
             0.29679890469924086`, 0.4265200793940456, 0.9403148622219284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 21}], {
             RGBColor[
             0.22580819870592864`, 0.3546691122796089, 0.9361708149117844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 93}], {
             RGBColor[
             0.29873862778538124`, 0.4282001700379434, 0.9404384596617476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 142}], {
             RGBColor[
             0.36455405628776205`, 0.4846402873807406, 0.9447885201049626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 188}], {
             RGBColor[
             0.2653788568535447, 0.3962603829173885, 0.9384243053537484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 273}], {
             RGBColor[
             0.3894971814838498, 0.5048902400899095, 0.9467521342900769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 293}], {
             RGBColor[
             0.28453912176058604`, 0.41590127160719004`, 0.9395336796939777]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 390}], {
             RGBColor[
             0.23396569650741295`, 0.36324315968420245`, 0.9366353723436424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 16}], {
             RGBColor[
             0.24227617377409713`, 0.3719779982061794, 0.9371086417297306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 25}], {
             RGBColor[
             0.3097802502292844, 0.43782398124180466`, 0.9411398210556678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 76}], {
             RGBColor[
             0.26926683315553557`, 0.4003468925227164, 0.9386457198524012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 117}], {
             RGBColor[
             0.40706513411417244`, 0.5192304619580248, 0.9481280690845475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 202}], {
             RGBColor[
             0.2915950820053508, 0.42207290253936436`, 0.9399810782169516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 234}], {
             RGBColor[
             0.2512674523014992, 0.38142840201846384`, 0.9376206817404615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 239}], {
             RGBColor[
             0.3813679879787836, 0.49836836108207505`, 0.9461050956090218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 269}], {
             RGBColor[
             0.30450100126350144`, 0.4332513611304116, 0.9408034319798247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 302}], {
             RGBColor[
             0.22515004974021374`, 0.353977355987588, 0.936133334301831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 323}], {
             RGBColor[
             0.3381102648791732, 0.4623620160236, 0.9429449845379104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 365}], {
             RGBColor[
             0.2808078228071327, 0.4124772043875522, 0.9393029621396956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 377}], {
             RGBColor[
             0.25514638831763914`, 0.3855054097101751, 0.9378415814082092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 388}], {
             RGBColor[
             0.26319007599843486`, 0.3939598354619466, 0.938299657522061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 18}], {
             RGBColor[
             0.8394473584119997, 0.8706756474406323, 0.6991625748728455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 56}], {
             RGBColor[
             0.6023784760141789, 0.6874029877027437, 0.9623014191002394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 65}], {
             RGBColor[
             0.531426491162083, 0.6277150215031269, 0.9572921727453987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 100}], {
             RGBColor[
             0.5370355289675518, 0.6325732881317867, 0.9576495756744858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 174}], {
             RGBColor[
             0.5520972673558275, 0.6456190088987284, 0.9586092963260144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 198}], {
             RGBColor[
             0.7575782172127392, 0.8106163649808842, 0.9764530707316865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 203}], {
             RGBColor[
             0.4981842108201723, 0.5989222290765547, 0.9551740040370065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 266}], {
             RGBColor[
             0.6722902895010364, 0.7439175508444353, 0.9679712712136599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 313}], {
             RGBColor[
             0.4854882204226317, 0.5856947625868548, 0.9544467086526902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 339}], {
             RGBColor[
             0.5341582021850244, 0.6300810922914106, 0.9574662349562233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 358}], {
             RGBColor[
             0.48197798109692647`, 0.5820052784935108, 0.954246805716025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 384}], {
             RGBColor[
             0.8099718019563749, 0.7646503394906032, 0.6173962103853706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 32}], {
             RGBColor[
             0.8358176878937263, 0.2763160213279036, 0.18193236441831204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 52}], {
             RGBColor[
             0.8916429525013146, 0.5507520246580102, 0.4032025959775474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 60}], {
             RGBColor[
             0.7976526644820038, 0.4778635602594288, 0.44966349300497443`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 68}], {
             RGBColor[
             0.8358461850878253, 0.5077093600050204, 0.4534679492170056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.8350901197191642, 0.27072361351581226`, 0.18123564431268066`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 253}], {
             RGBColor[
             0.8370421980658134, 0.2857281430943435, 0.18310495674198904`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 271}], {
             RGBColor[
             0.8353123166962146, 0.27243151684875794`, 0.18144842038883974`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 303}], {
             RGBColor[
             0.8599547518024352, 0.42459401411663544`, 0.20358742524945703`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 333}], {
             RGBColor[
             0.8799035766623403, 0.5425287482789902, 0.44689524966387445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 334}], {
             RGBColor[
             0.8820485949422373, 0.5133285113038917, 0.2258290855797634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 337}], {
             RGBColor[
             0.8809711396763451, 0.543324935026861, 0.44508814394619167`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 345}], {
             RGBColor[
             0.8380059756120399, 0.5094315183430771, 0.453673951965273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 353}], {
             RGBColor[
             0.8930646658031626, 0.5501769231578431, 0.29510210612227733`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 364}], {
             RGBColor[
             0.8690908469474348, 0.46279294189952286`, 0.21104082837788557`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 391}], {
             RGBColor[
             0.8353894701660223, 0.27302455222656513`, 0.18152230263865984`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 54}], {
             RGBColor[
             0.9107233154962703, 0.8671374351819781, 0.6324945514745149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 83}], {
             RGBColor[
             0.9120888802991098, 0.9323447493793293, 0.977810506555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 118}], {
             RGBColor[
             0.6153201099210919, 0.6928744863891039, 0.9658821576068201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 123}], {
             RGBColor[
             0.853169485204603, 0.5223983832616403, 0.45522988600606007`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 141}], {
             RGBColor[
             0.6144798263952078, 0.6921466750328611, 0.9658286154835842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 161}], {
             RGBColor[
             0.8763695857039919, 0.7238270844566292, 0.6044849794547379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 196}], {
             RGBColor[
             0.8586587168624804, 0.8901351694289188, 0.9863808290196707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 206}], {
             RGBColor[
             0.6510406164097462, 0.7238137937447175, 0.9681582366938735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 214}], {
             RGBColor[
             0.8760571062553216, 0.722408188261647, 0.6042242389431952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 286}], {
             RGBColor[
             0.5972181184299319, 0.677195451192008, 0.9647287147159659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 332}], {
             RGBColor[
             0.8362675556984924, 0.39248274660493876`, 0.43904457922300955`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 366}], {
             RGBColor[
             0.9332464444239088, 0.9449010522417576, 0.749948999978632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 386}], {
             RGBColor[
             0.6075598618760001, 0.6861529495738531, 0.9653876814635047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 19}], {
             RGBColor[
             0.22114916866345258`, 0.3497721763054004, 0.9359054900432826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 24}], {
             RGBColor[
             0.25148362362516946`, 0.3816556117856949, 0.9376329923775478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 65}], {
             RGBColor[
             0.30963980079837916`, 0.4365176650238572, 0.941174248166886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 100}], {
             RGBColor[
             0.315248838603848, 0.44137593165251704`, 0.941531651095973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 107}], {
             RGBColor[
             0.23293330946253646`, 0.362158055442918, 0.9365765794287164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 124}], {
             RGBColor[
             0.23470207361547668`, 0.3640171387137828, 0.9366773079305742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 150}], {
             RGBColor[
             0.24059607423843102`, 0.37021210706973123`, 0.937012962546659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 157}], {
             RGBColor[
             0.24482342257705114`, 0.37465531820298625`, 0.937253703780742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 167}], {
             RGBColor[
             0.2392959832955554, 0.36884562905824225`, 0.9369389242907744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 168}], {
             RGBColor[
             0.22037492795635888`, 0.34895840023254887`, 0.9358613981804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 203}], {
             RGBColor[
             0.2763975204564685, 0.40772487259728496`, 0.9390560794584938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 206}], {
             RGBColor[
             0.33583694364464667`, 0.4592083134506097, 0.9428435069438263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 211}], {
             RGBColor[
             0.23763726784270695`, 0.3671022139486645, 0.9368444628995842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 238}], {
             RGBColor[
             0.2218338423144311, 0.3504918117233956, 0.9359444811948219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 341}], {
             RGBColor[
             0.2460644953245124, 0.3759597643491251, 0.9373243810377072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 358}], {
             RGBColor[
             0.26019129073322267`, 0.39080792201424114`, 0.9381288811375124]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 14}], {
             RGBColor[
             0.27600611579144196`, 0.4046655399129887, 0.9391307436538039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 21}], {
             RGBColor[
             0.2050154097981298, 0.332814572798552, 0.9349866963436598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 51}], {
             RGBColor[
             0.20728585719020337`, 0.33520095696230034`, 0.9351159949638125]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 79}], {
             RGBColor[
             0.20620705634176517`, 0.33406706887066745`, 0.9350545588514367]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 87}], {
             RGBColor[
             0.2001057560025477, 0.3276542153693653, 0.9347070988231834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 205}], {
             RGBColor[
             0.19925835051903662`, 0.3267635384775842, 0.9346588403345214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 232}], {
             RGBColor[
             0.20186143048066912`, 0.3294995405620621, 0.9348070818874247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 277}], {
             RGBColor[
             0.19923872667069553`, 0.3267429125687539, 0.9346577227853893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 373}], {
             RGBColor[
             0.2056740334145861, 0.3335068279785967, 0.9350242039842707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 390}], {
             RGBColor[
             0.2131729075996141, 0.34138862020314553`, 0.9354512537755177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 69}], {
             RGBColor[
             0.45573362712038445`, 0.5659105913267511, 0.9511564428609628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 71}], {
             RGBColor[
             0.6541765961305002, 0.7223342652348994, 0.9394835143282855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 201}], {
             RGBColor[
             0.5021816905325309, 0.6032614518687315, 0.9550576137220795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 212}], {
             RGBColor[
             0.45821441723172895`, 0.5679246084974616, 0.9513517397459614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 273}], {
             RGBColor[
             0.4313475935937616, 0.5461129107315478, 0.9492366849727629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 289}], {
             RGBColor[
             0.4064318553204269, 0.5258851919600367, 0.9472752267865294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 293}], {
             RGBColor[
             0.32638953387049785`, 0.45712394224882835`, 0.9420182303766638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 390}], {
             RGBColor[
             0.27581610861732475`, 0.40446583032584077`, 0.9391199230263283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 35}], {
             RGBColor[
             0.1861148468094702, 0.312948882732563, 0.933910337242333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 106}], {
             RGBColor[
             0.18432449600494816`, 0.311067110522213, 0.933808379412602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 154}], {
             RGBColor[
             0.18425132424679044`, 0.31099020236503183`, 0.933804212389223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 207}], {
             RGBColor[
             0.18682358813972555`, 0.3136938148074571, 0.9339506990126021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 231}], {
             RGBColor[
             0.18666830847322874`, 0.31353060603266947`, 0.9339418560653108]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 369}], {
             RGBColor[
             0.18126767848005537`, 0.30785420149012543`, 0.9336342981767156]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 372}], {
             RGBColor[
             0.1810383624053819, 0.30761317575616476`, 0.9336212389655058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 392}], {
             RGBColor[
             0.19259602959164984`, 0.3197610167673564, 0.9342794310137273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 25}], {
             RGBColor[
             0.2964577597678131, 0.4238211990721158, 0.9403811249327455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 37}], {
             RGBColor[
             0.25664259349321183`, 0.38707801621458926`, 0.9379267880795208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 76}], {
             RGBColor[
             0.2559443426940643, 0.3863441103530275, 0.937887023729479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 77}], {
             RGBColor[
             0.21295289463759554`, 0.3411573726304365, 0.9354387243628108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 78}], {
             RGBColor[
             0.22470970081672578`, 0.3535145213492678, 0.9361082570820762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 80}], {
             RGBColor[
             0.21603013302378776`, 0.34439174528250716`, 0.9356139685365383]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 96}], {
             RGBColor[
             0.22029148033523374`, 0.34887069149186156`, 0.9358566459618267]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 182}], {
             RGBColor[
             0.23539065510704868`, 0.36474088152001305`, 0.9367165216278543]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.22265042245962569`, 0.35135008923016664`, 0.9359909842260687]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 269}], {
             RGBColor[
             0.29117851080203017`, 0.41924857896072276`, 0.9400447358569024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 302}], {
             RGBColor[
             0.21182755927874247`, 0.3399745738178992, 0.9353746381789088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 323}], {
             RGBColor[
             0.3247877744177019, 0.4483592338539112, 0.9421862884149881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 365}], {
             RGBColor[
             0.2674853323456614, 0.39847442221786333`, 0.9385442660167731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 377}], {
             RGBColor[
             0.24182389785616784`, 0.37150262754048624`, 0.9370828852852868]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 388}], {
             RGBColor[
             0.24986758553696356`, 0.3799570532922577, 0.9375409613991386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 18}], {
             RGBColor[
             0.8826197426994277, 0.4712313788077837, 0.2590653315299285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 31}], {
             RGBColor[
             0.879860588532459, 0.47166977479957617`, 0.4195957023627799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 62}], {
             RGBColor[
             0.8823757434978273, 0.4727098560142903, 0.37791307557422715`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.8524964894376759, 0.4506925466333933, 0.4462583138303914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 111}], {
             RGBColor[
             0.8273118204939984, 0.2109361971987341, 0.17378713619032946`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 222}], {
             RGBColor[
             0.8688036227970698, 0.46343086091223773`, 0.43864154601533567`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 223}], {
             RGBColor[
             0.8381799008988925, 0.29362230402542056`, 0.1841611101359005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 247}], {
             RGBColor[
             0.8242207072500726, 0.18717654627145935`, 0.17082708265703297`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 256}], {
             RGBColor[
             0.8825424426584894, 0.4727787904011971, 0.3751504390784578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 292}], {
             RGBColor[
             0.8249384204875226, 0.19269320471844653`, 0.1715143656637563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 310}], {
             RGBColor[
             0.8272800217278339, 0.2106917779476853, 0.17375668565593874`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 319}], {
             RGBColor[
             0.8292559200449149, 0.22587939825693307`, 0.17564880811583344`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 384}], {
             RGBColor[
             0.8629693717290111, 0.400547840174431, 0.20455442187161196`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 99}], {
             RGBColor[
             0.947350971343756, 0.9556350172112698, 0.7097411277967336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 144}], {
             RGBColor[
             0.7868965412101618, 0.8286865484723305, 0.6945647496408425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.9106667100371233, 0.9263839830131071, 0.7062421502048801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 218}], {
             RGBColor[
             0.776406098847213, 0.8201699347730458, 0.6937389035902746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 266}], {
             RGBColor[
             0.8253787823254205, 0.8596851688766582, 0.6977603506868537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 310}], {
             RGBColor[
             0.8818564092931963, 0.4653640637526585, 0.25833436259805964`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 319}], {
             RGBColor[
             0.8858082059273583, 0.49573930437115404`, 0.26211860751784904`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 384}], {
             RGBColor[
             0.9630602947807589, 0.8804179575228263, 0.3471852898585644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 24}], {
             RGBColor[
             0.22984730742841403`, 0.35891447164122536`, 0.936400836178204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 85}], {
             RGBColor[
             0.19070082938217475`, 0.3177690411845645, 0.9341715021654952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 107}], {
             RGBColor[
             0.211296993265781, 0.33941691529844853`, 0.9353444232293726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 124}], {
             RGBColor[
             0.21306575741872125`, 0.34127599856931323`, 0.9354451517312304]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 150}], {
             RGBColor[
             0.21895975804167556`, 0.3474709669252617, 0.9357808063473152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 152}], {
             RGBColor[
             0.2001783639532218, 0.3277305309291337, 0.9347112337385604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 157}], {
             RGBColor[
             0.2231871063802957, 0.35191417805851677`, 0.9360215475813982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 160}], {
             RGBColor[
             0.19740416245689973`, 0.32481466926196517`, 0.9345532470674082]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 167}], {
             RGBColor[
             0.21765966709879997`, 0.34610448891377266`, 0.9357067680914306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 168}], {
             RGBColor[
             0.19873861175960342`, 0.3262172600880793, 0.9346292419810562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 181}], {
             RGBColor[
             0.19581756515250187`, 0.3231470548989638, 0.9344628926980831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 211}], {
             RGBColor[
             0.2160009516459515, 0.344361073804195, 0.9356123067002404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 238}], {
             RGBColor[
             0.20019752611767563`, 0.32775067157892607`, 0.9347123249954781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 64}], {
             RGBColor[
             0.6886054780275248, 0.7470570557801346, 0.690028677840299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 88}], {
             RGBColor[
             0.40751079531136875`, 0.5273871016357587, 0.9471872054229611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 89}], {
             RGBColor[
             0.30842578765479933`, 0.4344898392135439, 0.9411326397648885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 120}], {
             RGBColor[
             0.3985867083579536, 0.5196575060543626, 0.9466185704935497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 140}], {
             RGBColor[
             0.3954861818985797, 0.5169719858722439, 0.9464210076892463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 189}], {
             RGBColor[
             0.30889970680782364`, 0.4349879582915822, 0.9411596287595527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 195}], {
             RGBColor[
             0.40462199010322386`, 0.5248849637600351, 0.9470031333095683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 241}], {
             RGBColor[
             0.33276855688740864`, 0.46007563309772936`, 0.9425189244607857]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 255}], {
             RGBColor[
             0.37940724758906264`, 0.5030452211240766, 0.9453964722130872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 257}], {
             RGBColor[
             0.6770229856308323, 0.7421397259892473, 0.9411883411446311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 263}], {
             RGBColor[
             0.3432288815576954, 0.4710700975490908, 0.943114624476095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 312}], {
             RGBColor[
             0.4662211223319299, 0.5756731791658605, 0.9516371294428863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 336}], {
             RGBColor[
             0.3097133743307097, 0.43584317444763615`, 0.9412059659212678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 356}], {
             RGBColor[
             0.6650046334832713, 0.7331764586358418, 0.9615322764421933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 359}], {
             RGBColor[
             0.3551576814248725, 0.48204146573128925`, 0.9438513113001545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 360}], {
             RGBColor[
             0.523690607917635, 0.622017048024192, 0.9563749606192402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 389}], {
             RGBColor[
             0.688874491712781, 0.747632448851442, 0.7193091573204213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 109}], {
             RGBColor[
             0.1897091064701492, 0.31672667752516137`, 0.9341150250127779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[
             0.19167285067202883`, 0.3187906971899105, 0.9342268573399758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 132}], {
             RGBColor[
             0.1947709663990963, 0.3220470132509409, 0.9344032904473808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 180}], {
             RGBColor[
             0.19254611619106632`, 0.3197085546186507, 0.9342765885194044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 232}], {
             RGBColor[
             0.19351392550506752`, 0.32072578357032067`, 0.9343317038280912]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 249}], {
             RGBColor[
             0.19014493822452405`, 0.31718476433233855`, 0.9341398449864342]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 370}], {
             RGBColor[
             0.19110729661804693`, 0.31819626402097745`, 0.9341946498732637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 45}], {
             RGBColor[
             0.24087710963769857`, 0.3705074930930349, 0.9370289670968927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 74}], {
             RGBColor[
             0.24528340650250224`, 0.37513879047330073`, 0.9372798991848111]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 116}], {
             RGBColor[
             0.24102708216235447`, 0.3706651237252555, 0.9370375078103073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 141}], {
             RGBColor[
             0.2988998919025237, 0.4271457198066904, 0.9404924581847806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 179}], {
             RGBColor[
             0.2344230766191157, 0.3637238951811761, 0.9366614194643705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 209}], {
             RGBColor[
             0.25353925279510015`, 0.38381620837770913`, 0.9377500574177445]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 286}], {
             RGBColor[
             0.2816381839372477, 0.41219449596583724`, 0.9393925574171622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 290}], {
             RGBColor[
             0.2497813465899759, 0.3798664106911086, 0.9375360502186867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 304}], {
             RGBColor[
             0.2621517349847551, 0.3928684732219464, 0.9382405255374198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 338}], {
             RGBColor[
             0.2260845393342366, 0.35495956380096844`, 0.9361865521017572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 38}], {
             RGBColor[
             0.23532272116707456`, 0.36466947864183974`, 0.936712652890472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 92}], {
             RGBColor[
             0.20814505737279243`, 0.33610403083063944`, 0.9351649251431382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 98}], {
             RGBColor[
             0.2025842284056299, 0.3302592470092312, 0.9348482441599675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 119}], {
             RGBColor[
             0.22585475434557115`, 0.35471804520867123`, 0.936173466186589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 128}], {
             RGBColor[
             0.2579108106564282, 0.38841099286274205`, 0.9379990111708069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 130}], {
             RGBColor[
             0.21379154943709947`, 0.3420388519985006, 0.935486484512964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 139}], {
             RGBColor[
             0.2594316195520534, 0.3900094594368974, 0.9380856189875776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 143}], {
             RGBColor[
             0.20541157212716055`, 0.3332309645245057, 0.9350092572022285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 146}], {
             RGBColor[
             0.20552449462249126`, 0.333349653226798, 0.9350156879712836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 151}], {
             RGBColor[
             0.20976599730073225`, 0.3378077414684315, 0.9352572352740687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 158}], {
             RGBColor[
             0.20153001639620693`, 0.3291512033464258, 0.9347882083455978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 186}], {
             RGBColor[
             0.209250396089514, 0.3372658119044362, 0.9352278725478533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 213}], {
             RGBColor[
             0.2686665233533321, 0.39817491739397315`, 0.9386679570758016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 267}], {
             RGBColor[
             0.20474185831720654`, 0.33252705284793593`, 0.9349711179915043]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 306}], {
             RGBColor[
             0.21710981978146196`, 0.345526564520917, 0.9356754551001344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 308}], {
             RGBColor[
             0.21238372481471685`, 0.3405591390591399, 0.9354063109834092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 311}], {
             RGBColor[
             0.2072579319428704, 0.33517160575679045`, 0.9351144046622886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 346}], {
             RGBColor[
             0.20767293699657277`, 0.3356078023810718, 0.935138038586152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 348}], {
             RGBColor[
             0.20651189165865158`, 0.3343874701163905, 0.93507191877177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 354}], {
             RGBColor[
             0.20401044687486744`, 0.3317582930478737, 0.9349294651918895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 374}], {
             RGBColor[
             0.19777812141168266`, 0.3252077238338092, 0.9345745434766604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 33}], {
             RGBColor[
             0.2533855843329195, 0.3836546930808141, 0.9377413062261555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 56}], {
             RGBColor[
             0.3892899244154366, 0.5053479265592988, 0.9466788406566481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 65}], {
             RGBColor[
             0.3183379395633406, 0.44565996035968214`, 0.9416695943018074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 100}], {
             RGBColor[
             0.32394697736880945`, 0.450518226988342, 0.9420269972308946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 107}], {
             RGBColor[
             0.2416314482274979, 0.371300350778743, 0.9370719255636378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 124}], {
             RGBColor[
             0.24340021238043813`, 0.3731594340496077, 0.9371726540654957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 150}], {
             RGBColor[
             0.24929421300339247`, 0.3793544024055562, 0.9375083086815804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 157}], {
             RGBColor[
             0.2535215613420126, 0.38379761353881126`, 0.9377490499156633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 167}], {
             RGBColor[
             0.24799412206051685`, 0.37798792439406714`, 0.9374342704256958]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 168}], {
             RGBColor[
             0.22907306672132033`, 0.35810069556837376`, 0.9363567443153216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 203}], {
             RGBColor[
             0.2850956592214299, 0.4168671679331099, 0.9395514255934152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 206}], {
             RGBColor[
             0.3445350824096081, 0.46835060878643464`, 0.9433388530787478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 211}], {
             RGBColor[
             0.2463354066076684, 0.3762445092844895, 0.9373398090345058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 238}], {
             RGBColor[
             0.23053198107939255`, 0.35963410705922055`, 0.9364398273297434]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 341}], {
             RGBColor[
             0.25476263408947386`, 0.38510205968495004`, 0.9378197271726287]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 358}], {
             RGBColor[
             0.2688894294981841, 0.3999502173500661, 0.9386242272724338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 386}], {
             RGBColor[
             0.3010543278758621, 0.4306897646155703, 0.940568297848379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 37}], {
             RGBColor[
             0.3241466699483991, 0.4529239992502145, 0.9419579674054581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 62}], {
             RGBColor[
             0.6778828449272916, 0.740272939600058, 0.8649535953688089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[
             0.32344841914925154`, 0.45219009338865274`, 0.9419182030554161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 78}], {
             RGBColor[
             0.29221377727191306`, 0.41936050438489303`, 0.9401394364080135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 91}], {
             RGBColor[
             0.47826887557608655`, 0.5848930154724093, 0.9527405987202289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 117}], {
             RGBColor[
             0.4612467201078884, 0.5710736628239611, 0.9514005522875624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 182}], {
             RGBColor[
             0.30289473156223595`, 0.4305868645556383, 0.9407477009537915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 187}], {
             RGBColor[
             0.29015449891481293`, 0.4171960722657919, 0.940022163552006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 208}], {
             RGBColor[
             0.3291899186131193, 0.4582247733572693, 0.9422451729560961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 239}], {
             RGBColor[
             0.43554957397249955`, 0.5502115619480115, 0.9493775788120367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 269}], {
             RGBColor[
             0.35868258725721747`, 0.48509456199634804`, 0.9440759151828396]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 309}], {
             RGBColor[
             0.5306642654095335, 0.6265873056000757, 0.957441478589943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 323}], {
             RGBColor[
             0.3922918508728892, 0.5142052168895364, 0.9462174677409253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 362}], {
             RGBColor[
             0.5776163710657185, 0.6632666473879071, 0.9621212256893779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 365}], {
             RGBColor[
             0.33498940880084865`, 0.4643204052534886, 0.9425754453427104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 377}], {
             RGBColor[
             0.3093279743113551, 0.4373486105761115, 0.941114064611224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 388}], {
             RGBColor[
             0.31737166199215083`, 0.44580303632788293`, 0.9415721407250759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 395}], {
             RGBColor[
             0.4013213562160271, 0.522026120581628, 0.946792819836912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 70}], {
             RGBColor[
             0.1896105861046007, 0.3166231263744179, 0.9341094144237078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 177}], {
             RGBColor[
             0.18182665700375172`, 0.3084417233598157, 0.9336661311767056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 285}], {
             RGBColor[
             0.1832664520031871, 0.30995503919249784`, 0.9337481253719375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 324}], {
             RGBColor[
             0.1839722969253371, 0.31069692695883033`, 0.9337883221960501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 40}], {
             RGBColor[
             0.19924073649984758`, 0.3267450250266232, 0.9346578372421862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 41}], {
             RGBColor[
             0.1999138771125005, 0.32745253849010136`, 0.9346961716042546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 48}], {
             RGBColor[
             0.20648582903789775`, 0.33436007664951256`, 0.9350704345440743]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 63}], {
             RGBColor[
             0.1971785692903057, 0.32457755654044196`, 0.9345403998703059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 86}], {
             RGBColor[
             0.23656599040606416`, 0.3659762334398404, 0.9367834552343804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 250}], {
             RGBColor[
             0.19937642447535237`, 0.3268876416919933, 0.9346655644716588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 265}], {
             RGBColor[
             0.20201462184730384`, 0.32966055440128883`, 0.9348158059091283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 295}], {
             RGBColor[
             0.19546687096427723`, 0.32277845307184394`, 0.9344429211828693]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 325}], {
             RGBColor[
             0.22165235452841858`, 0.35030105655330623`, 0.9359341457338957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 376}], {
             RGBColor[
             0.24560585367761548`, 0.37547770289867644`, 0.937298262074416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 39}], {
             RGBColor[
             0.19488507531529636`, 0.3221669489567903, 0.9344097887813494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 50}], {
             RGBColor[
             0.21136185866227802`, 0.33948509294287055`, 0.9353481172177434]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 106}], {
             RGBColor[
             0.18905752987434937`, 0.31604182921063345`, 0.9340779186895682]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 197}], {
             RGBColor[
             0.19145378666017485`, 0.3185604470239914, 0.9342143819685769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 217}], {
             RGBColor[
             0.19992147826691017`, 0.32746052778532697`, 0.9346966044787532]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 231}], {
             RGBColor[
             0.19140134234262995`, 0.31850532472108994`, 0.934211395342277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 254}], {
             RGBColor[
             0.1893368412328983, 0.3163354031578313, 0.9340938250582336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 314}], {
             RGBColor[
             0.18717488313259786`, 0.3140630481183549, 0.9339707047427519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 369}], {
             RGBColor[
             0.1860007123494566, 0.3128289201785459, 0.9339038374536819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 113}], {
             RGBColor[
             0.1857448284490183, 0.3125599699752089, 0.9338892652440982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 162}], {
             RGBColor[
             0.19056901057120365`, 0.3176304912564385, 0.9341639952792189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 183}], {
             RGBColor[
             0.18726251983199932`, 0.31415515984591347`, 0.9339756955231359]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 270}], {
             RGBColor[
             0.19689305639497057`, 0.3242774643848816, 0.9345241403332949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 357}], {
             RGBColor[
             0.18592235681432462`, 0.3127465635430944, 0.9338993752218727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 153}], {
             RGBColor[
             0.2031751711317593, 0.3308803652823261, 0.9348818974739992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 168}], {
             RGBColor[
             0.19933167973369648`, 0.3268406121315325, 0.9346630163248155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 175}], {
             RGBColor[
             0.19541782934736363`, 0.32272690722304953`, 0.9344401283353366]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 211}], {
             RGBColor[
             0.21659401962004457`, 0.3449844258476482, 0.9356460810439997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 216}], {
             RGBColor[
             0.208257693184232, 0.33622241820998533`, 0.93517133958597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 229}], {
             RGBColor[
             0.19931037008134544`, 0.32681821433580155`, 0.9346618027716389]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 294}], {
             RGBColor[
             0.2052159577699056, 0.3330253614323641, 0.9349981172539683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 329}], {
             RGBColor[
             0.23151896311630302`, 0.36067148775828894`, 0.9364960344966363]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 341}], {
             RGBColor[
             0.22502124710185, 0.35384197624810876`, 0.9361259991821227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 343}], {
             RGBColor[
             0.2007094287814945, 0.32828871373510315`, 0.9347414770948905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 358}], {
             RGBColor[
             0.2391480425105603, 0.3686901339132248, 0.9369304992819277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 379}], {
             RGBColor[
             0.19158357625518677`, 0.31869686411748455`, 0.9342217732940062]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 99}], {
             RGBColor[
             0.9432122400933031, 0.9562926111989585, 0.9505366840460105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 111}], {
             RGBColor[
             0.8791608526585568, 0.4662912982465486, 0.4189256344996925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 169}], {
             RGBColor[
             0.7207585549931849, 0.779010354243588, 0.9304794974284005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 199}], {
             RGBColor[
             0.9864970705564884, 0.9886842059127192, 0.8734420155476115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 215}], {
             RGBColor[
             0.8451646800561206, 0.8790328648583385, 0.9409404903646027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 222}], {
             RGBColor[
             0.967672940132394, 0.9754000826172251, 0.9391115323234271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 223}], {
             RGBColor[
             0.9008970134683449, 0.6316635118999215, 0.4396735823908346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 224}], {
             RGBColor[
             0.7410029688449329, 0.7954456814088879, 0.9320732118445416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 247}], {
             RGBColor[
             0.8729786261707051, 0.41877199639199914`, 0.4130055274330995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 259}], {
             RGBColor[
             0.9398415048836066, 0.9536048784389164, 0.9502151803126189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 292}], {
             RGBColor[
             0.8744140526456051, 0.4298053132859735, 0.4143800934465462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 363}], {
             RGBColor[
             0.6793920980440895, 0.7432878081939467, 0.9278140990011539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 383}], {
             RGBColor[
             0.6712879724630387, 0.7362684219408357, 0.9272977112853262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 393}], {
             RGBColor[
             0.8531150739602782, 0.8852437730014981, 0.9417329113283139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 400}], {
             RGBColor[
             0.8761629417845124, 0.4432480415757216, 0.4160548316610515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 46}], {
             RGBColor[
             0.8161914025598732, 0.393609503483597, 0.4392438664351634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 52}], {
             RGBColor[
             0.8773441309925929, 0.440845016758437, 0.3895100283525863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 71}], {
             RGBColor[
             0.8709138694072857, 0.43658126909692513`, 0.4242157364462195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 105}], {
             RGBColor[
             0.8761133411469468, 0.4403360535274061, 0.40990740127695935`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 111}], {
             RGBColor[
             0.8232166057967019, 0.1794585825007891, 0.16986555397131473`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 129}], {
             RGBColor[
             0.8207912982104425, 0.1608166056162391, 0.16754307668771967`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 199}], {
             RGBColor[
             0.8772578283825027, 0.4408093284112888, 0.39094028594577723`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 215}], {
             RGBColor[
             0.7830362347155908, 0.3677084343750351, 0.4359392691571047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 247}], {
             RGBColor[
             0.820125492552776, 0.15569893157351436`, 0.16690550043801822`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 259}], {
             RGBColor[
             0.8461541179339149, 0.41742311009542027`, 0.44212239578911544`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 271}], {
             RGBColor[
             0.8210134951874929, 0.16252450894918472`, 0.16775585276387872`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 287}], {
             RGBColor[
             0.8201189109233364, 0.1556483422855536, 0.16689919786223403`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 292}], {
             RGBColor[
             0.820843205790226, 0.16121559002050154`, 0.16759278344474157`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 303}], {
             RGBColor[
             0.8456559302937136, 0.31468700621706225`, 0.18989485762449604`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 333}], {
             RGBColor[
             0.8656047551536187, 0.43262174037941703`, 0.4332026820389135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 337}], {
             RGBColor[
             0.8666723181676234, 0.43341792712728777`, 0.43139557632123066`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 345}], {
             RGBColor[
             0.8237071541033182, 0.3995245104435039, 0.439981384340312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 353}], {
             RGBColor[
             0.8787658442944408, 0.4402699152582698, 0.2814095384973163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 385}], {
             RGBColor[
             0.8791517721101495, 0.4410953758327831, 0.323415399566809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 391}], {
             RGBColor[
             0.8210906486573005, 0.1631175443269919, 0.16782973501369886`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 400}], {
             RGBColor[
             0.8217176503596796, 0.1679369541653756, 0.16843015255199423`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 58}], {
             RGBColor[
             0.21989646734481127`, 0.3484555077936574, 0.9358341505563915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 74}], {
             RGBColor[
             0.24756162893783695`, 0.3775333467004828, 0.9374096405821755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 107}], {
             RGBColor[
             0.23483527017028652`, 0.36415713673803723`, 0.9366848932773241]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 116}], {
             RGBColor[
             0.24330530459768918`, 0.3730596799524376, 0.9371672492076716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 118}], {
             RGBColor[
             0.30201839786374246`, 0.43026808739011524`, 0.9406757417053806]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 124}], {
             RGBColor[
             0.23660403432322674`, 0.366016220008902, 0.9367856217791819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 141}], {
             RGBColor[
             0.3011781143378584, 0.42954027603387246`, 0.9406221995821449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 150}], {
             RGBColor[
             0.24249803494618108`, 0.37221118836485045`, 0.9371212763952667]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 152}], {
             RGBColor[
             0.2237166408577273, 0.3524707523687224, 0.9360517037865118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 156}], {
             RGBColor[
             0.22423055163894667`, 0.35301090518360945`, 0.9360809702452394]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 157}], {
             RGBColor[
             0.2467253832848012, 0.3766543994981055, 0.9373620176293496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 179}], {
             RGBColor[
             0.23670129905445042`, 0.3661184514083582, 0.9367911608617348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 206}], {
             RGBColor[
             0.33773890435239673`, 0.4612073947457289, 0.942951820792434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 209}], {
             RGBColor[
             0.25581747523043485`, 0.38621076460489123`, 0.9378797988151089]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 245}], {
             RGBColor[
             0.22074175679161856`, 0.34934396059669826`, 0.9358822885398935]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 286}], {
             RGBColor[
             0.2839164063725824, 0.41458905219301934`, 0.9395222988145264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 386}], {
             RGBColor[
             0.2942581498186507, 0.4235465505748645, 0.9401812655620653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 43}], {
             RGBColor[
             0.18881744465394812`, 0.3157894844217095, 0.9340642461914408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 159}], {
             RGBColor[
             0.1825395439463383, 0.30919101273611693`, 0.9337067290334642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 250}], {
             RGBColor[
             0.1883288985198916, 0.31527599145920215`, 0.9340364242118455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 265}], {
             RGBColor[
             0.19096709589184307`, 0.31804890416849774`, 0.9341866656493147]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 321}], {
             RGBColor[
             0.18374554341254123`, 0.3104585946398788, 0.9337754089189481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 375}], {
             RGBColor[
             0.19286667153168213`, 0.3200454786060204, 0.9342948436718334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 381}], {
             RGBColor[
             0.18614322275265005`, 0.3129787076479837, 0.9339119532103186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 73}], {
             RGBColor[
             0.19430576499947028`, 0.3215580570844616, 0.9343767979158759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 154}], {
             RGBColor[
             0.18823624142486384`, 0.31517860297752887`, 0.9340311475273575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 207}], {
             RGBColor[
             0.19080850531779897`, 0.3178822154199542, 0.9341776341507367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 231}], {
             RGBColor[
             0.19065322565130216`, 0.31771900664516656`, 0.9341687912034454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 280}], {
             RGBColor[
             0.19951437129521365`, 0.3270326325460011, 0.9346734203389759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 291}], {
             RGBColor[
             0.19278015708719454`, 0.31995454643953136`, 0.9342899168022064]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 372}], {
             RGBColor[
             0.18502327958345532`, 0.31180157636866185`, 0.9338481741036404]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 387}], {
             RGBColor[
             0.1878209095169145, 0.3147420628087102, 0.9340074949896282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 392}], {
             RGBColor[
             0.19658094676972326`, 0.3239494173798535, 0.934506366151862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 61}], {
             RGBColor[
             0.23146005042347673`, 0.36060956678284806`, 0.9364926795059334]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 70}], {
             RGBColor[
             0.22130912604082534`, 0.3499403016509027, 0.9359145993792883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 90}], {
             RGBColor[
             0.2306114538784999, 0.35971763800994894`, 0.9364443531880831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 95}], {
             RGBColor[
             0.2464425329575721, 0.37635710587044113`, 0.9373459097216534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 148}], {
             RGBColor[
             0.2511034439451054, 0.38125601883716365`, 0.9376113417071936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 228}], {
             RGBColor[
             0.23483092925025606`, 0.364152574155855, 0.9366846460683501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 276}], {
             RGBColor[
             0.31234957064668134`, 0.4391299345139409, 0.941337201922877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 282}], {
             RGBColor[
             0.28033871258182136`, 0.4114037381706667, 0.9392974983530744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 301}], {
             RGBColor[
             0.2477609938146631, 0.37774289182649035`, 0.9374209941169768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 305}], {
             RGBColor[
             0.2718566625317226, 0.40306896740175535`, 0.9387932068040659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 361}], {
             RGBColor[
             0.32761397052464425`, 0.4523511904771868, 0.9423098359853219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 382}], {
             RGBColor[
             0.2838749254794549, 0.4144666280473688, 0.9395228227119613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 76}], {
             RGBColor[
             0.28363325287465024`, 0.4154469105311262, 0.9394638662021915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 78}], {
             RGBColor[
             0.25239861099731176`, 0.3826173215273665, 0.9376850995547887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 80}], {
             RGBColor[
             0.24371904320437376`, 0.3734945454606058, 0.9371908110092508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 96}], {
             RGBColor[
             0.24798039051581972`, 0.3779734916699602, 0.9374334884345392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 104}], {
             RGBColor[
             0.2541903466574486, 0.3845005493087726, 0.9377871362499982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 117}], {
             RGBColor[
             0.4214315538332871, 0.5343304799664346, 0.9489462154343377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 145}], {
             RGBColor[
             0.2671022972631469, 0.3980718280603137, 0.9385224527354736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 182}], {
             RGBColor[
             0.26307956528763465`, 0.3938436816981118, 0.9382933641005669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 187}], {
             RGBColor[
             0.2503393326402117, 0.3804528894082654, 0.9375678266987812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 208}], {
             RGBColor[
             0.289374752338518, 0.42148159049974276`, 0.9397908361028714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 269}], {
             RGBColor[
             0.3188674209826161, 0.4483513791388215, 0.9416215783296149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 323}], {
             RGBColor[
             0.35247668459828785`, 0.4774620340320098, 0.9437631308877006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 365}], {
             RGBColor[
             0.29517424252624735`, 0.4275772223959621, 0.9401211084894857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 377}], {
             RGBColor[
             0.2695128080367538, 0.400605427718585, 0.9386597277579993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 388}], {
             RGBColor[
             0.27755649571754953`, 0.4090598534703564, 0.9391178038718512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 395}], {
             RGBColor[
             0.3615061899414258, 0.48528293772410147`, 0.9443384829836874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 44}], {
             RGBColor[
             0.24351959225973108`, 0.37328490987186613`, 0.9371794525730147]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 66}], {
             RGBColor[
             0.22742648369193186`, 0.3563700324050926, 0.9362629738476992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 81}], {
             RGBColor[
             0.2439408678768847, 0.37372769725591143`, 0.9372034435961902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 119}], {
             RGBColor[
             0.249257790450226, 0.37931611999285497`, 0.9375062344710599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 128}], {
             RGBColor[
             0.281313846761083, 0.4130090676469258, 0.9393317794552777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 130}], {
             RGBColor[
             0.23719458554175432`, 0.36663692678268434`, 0.9368192527974348]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 135}], {
             RGBColor[
             0.2970405045044002, 0.42707857493039736`, 0.9403174695829958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 146}], {
             RGBColor[
             0.2289275307271461, 0.3579477280109817, 0.9363484562557545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 151}], {
             RGBColor[
             0.23316903340538708`, 0.36240581625261525`, 0.9365900035585395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 213}], {
             RGBColor[
             0.2920695594579869, 0.42277299217815684`, 0.9400007253602725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 224}], {
             RGBColor[
             0.37823665311305865`, 0.49620023139778335`, 0.9458245390097163]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 227}], {
             RGBColor[
             0.2663587998591236, 0.39729036514822713`, 0.9384801116582203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 243}], {
             RGBColor[
             0.24505985490147014`, 0.37490382356662577`, 0.9372671682518474]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 267}], {
             RGBColor[
             0.22814489442186137`, 0.3571251276321197, 0.9363038862759752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 306}], {
             RGBColor[
             0.24051285588611682`, 0.3701246393051007, 0.9370082233846052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 311}], {
             RGBColor[
             0.23066096804752526`, 0.35976968054097413`, 0.9364471729467594]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 346}], {
             RGBColor[
             0.23107597310122763`, 0.36020587716525554`, 0.9364708068706228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 350}], {
             RGBColor[
             0.3036355127427933, 0.43279083959174136`, 0.9407376976762094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 363}], {
             RGBColor[
             0.3166257823122153, 0.444042358182842, 0.9415654261663287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 383}], {
             RGBColor[
             0.3085216567311646, 0.43702297192973105`, 0.9410490384505009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 47}], {
             RGBColor[
             0.18958921033534365`, 0.3166006590856267, 0.9341081971052712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 50}], {
             RGBColor[
             0.21465093660737516`, 0.342942122402754, 0.9355354253409618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 136}], {
             RGBColor[
             0.19040517985093924`, 0.31745829478197307`, 0.9341546653620656]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 149}], {
             RGBColor[
             0.2042501787734501, 0.33201026647316434`, 0.9349431175688622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 164}], {
             RGBColor[
             0.20658345954088297`, 0.3344626924982814, 0.9350759944567879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 197}], {
             RGBColor[
             0.19474286460527196`, 0.3220174764838748, 0.9344016900917953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 210}], {
             RGBColor[
             0.22192743235245416`, 0.35059018078730897`, 0.9359498110090333]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 217}], {
             RGBColor[
             0.2032105562120073, 0.33091755724521044`, 0.9348839126019717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 230}], {
             RGBColor[
             0.20964976351428055`, 0.33768557238922303`, 0.9352506159318827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 254}], {
             RGBColor[
             0.19262591917799537`, 0.31979243261771473`, 0.934281133181452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 258}], {
             RGBColor[
             0.21791338707223826`, 0.34637116469263174`, 0.9357212170685729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 314}], {
             RGBColor[
             0.19046396107769498`, 0.3175200775782383, 0.9341580128659703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 328}], {
             RGBColor[
             0.21476290196670605`, 0.3430598050944246, 0.9355418016025379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 41}], {
             RGBColor[
             0.19412189539412833`, 0.3213647984712409, 0.9343663268138622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 48}], {
             RGBColor[
             0.20069384731952558`, 0.3282723366306521, 0.934740589753682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 63}], {
             RGBColor[
             0.19138658757193353`, 0.3184898165215815, 0.9342105550799136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 103}], {
             RGBColor[
             0.19411926264855695`, 0.32136203128871965`, 0.9343661768828968]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 265}], {
             RGBColor[
             0.1962226401289317, 0.32357281438242835`, 0.9344859611187359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 295}], {
             RGBColor[
             0.1896748892459051, 0.31669071305298346`, 0.934113076392477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 48}], {
             RGBColor[
             0.2013669879321785, 0.3289798500941302, 0.9347789241157504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 63}], {
             RGBColor[
             0.19205972818458644`, 0.31919732998505956`, 0.9342488894419819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.1942575833696331, 0.32150741513661096`, 0.934374054043335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 265}], {
             RGBColor[
             0.19689578074158462`, 0.3242803278459065, 0.9345242954808043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 295}], {
             RGBColor[
             0.19034802985855803`, 0.31739822651646155`, 0.9341514107545453]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 325}], {
             RGBColor[
             0.2165335134226994, 0.3449208299979239, 0.9356426353055718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 381}], {
             RGBColor[
             0.19207190760239157`, 0.31921013132539244`, 0.934249583041808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 67}], {
             RGBColor[
             0.18164605198289263`, 0.3082518960318731, 0.9336558459879488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 75}], {
             RGBColor[
             0.18289766237674282`, 0.30956741791249204`, 0.9337271233482869]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 133}], {
             RGBColor[
             0.1836453052262827, 0.310353237950653, 0.9337697005025297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 178}], {
             RGBColor[
             0.18344665505298052`, 0.31014444402336394`, 0.9337583876690367]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 200}], {
             RGBColor[
             0.18896638878164698`, 0.3159460341435242, 0.9340727283391701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 278}], {
             RGBColor[
             0.18598976689484537`, 0.3128174158117676, 0.9339032141262342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 296}], {
             RGBColor[
             0.18148102360409654`, 0.30807844074235485`, 0.933646447865914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 320}], {
             RGBColor[
             0.18379681968568948`, 0.3105124892540611, 0.9337783290268474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 330}], {
             RGBColor[
             0.18629301045548374`, 0.31313614402075074`, 0.9339204833984038]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 347}], {
             RGBColor[
             0.18410501336322643`, 0.3108364203497602, 0.9337958802008515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 367}], {
             RGBColor[
             0.1849893429390042, 0.3117659068036362, 0.9338462414619436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 398}], {
             RGBColor[
             0.18234639975021955`, 0.30898800593994685`, 0.9336957297572264]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 159}], {
             RGBColor[
             0.1884193222929882, 0.31537103257792504`, 0.9340415737119533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 250}], {
             RGBColor[
             0.19420867686654147`, 0.32145601130101026`, 0.9343712688903346]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 265}], {
             RGBColor[
             0.19684687423849298`, 0.3242289240103058, 0.934521510327804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 321}], {
             RGBColor[
             0.1896253217591911, 0.31663861448168684`, 0.9341102535974373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 325}], {
             RGBColor[
             0.21648460691960775`, 0.3448694261623232, 0.9356398501525713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 375}], {
             RGBColor[
             0.19874644987833204`, 0.3262254984478285, 0.9346296883503225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 381}], {
             RGBColor[
             0.19202300109929993`, 0.3191587274897918, 0.9342467978888077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 66}], {
             RGBColor[
             0.21222031867993352`, 0.3403873888509353, 0.9353970052457711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 81}], {
             RGBColor[
             0.22873470286488637`, 0.35774505370175413`, 0.9363374749942621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 119}], {
             RGBColor[
             0.23405162543822766`, 0.3633334764386976, 0.9366402658691317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[
             0.26610768174908467`, 0.39702642409276845`, 0.9384658108533496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 130}], {
             RGBColor[
             0.22198842052975598`, 0.350654283228527, 0.9359532841955067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 135}], {
             RGBColor[
             0.2818343394924019, 0.41109593137624006`, 0.9394515009810677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 146}], {
             RGBColor[
             0.21372136571514777`, 0.3419650844568244, 0.9354824876538264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 151}], {
             RGBColor[
             0.21796286839338874`, 0.3464231726984579, 0.9357240349566114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 227}], {
             RGBColor[
             0.25115263484712524`, 0.3813077215940698, 0.9376141430562922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 243}], {
             RGBColor[
             0.2298536898894718, 0.3589211800124685, 0.9364011996499193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 267}], {
             RGBColor[
             0.21293872940986303`, 0.3411424840779623, 0.935437917674047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 275}], {
             RGBColor[
             0.21122882729611786`, 0.33934526854236047`, 0.9353405412782427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 311}], {
             RGBColor[
             0.21545480303552692`, 0.34378703698681684`, 0.9355812043448313]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 317}], {
             RGBColor[
             0.2084087804726259, 0.3363812205295747, 0.9351799437835304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 326}], {
             RGBColor[
             0.2349425006851034, 0.3642698428079171, 0.9366909998965096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 344}], {
             RGBColor[
             0.20993796520971017`, 0.3379884906441625, 0.9352670285920812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 346}], {
             RGBColor[
             0.2158698080892293, 0.3442232336110982, 0.9356048382686947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 383}], {
             RGBColor[
             0.29331549171916627`, 0.4210403283755737, 0.9401830698485728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 48}], {
             RGBColor[
             0.2238300988639671, 0.3525900039269335, 0.9360581650521211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 74}], {
             RGBColor[
             0.2441275547351621, 0.3739239169805914, 0.9372140751365906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 103}], {
             RGBColor[
             0.21725551419299843`, 0.345679698585001, 0.9356837521813359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 116}], {
             RGBColor[
             0.23987123039501432`, 0.3694502502325462, 0.9369716837620867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 262}], {
             RGBColor[
             0.30202723660803465`, 0.4296407358190505, 0.9406995556283282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 290}], {
             RGBColor[
             0.24862549482263574`, 0.3786515371983993, 0.9374702261704662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 304}], {
             RGBColor[
             0.2609958832174149, 0.3916535997292371, 0.9381747014891992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 338}], {
             RGBColor[
             0.2249286875668965, 0.3537446903082591, 0.9361207280535366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 52}], {
             RGBColor[
             0.89726556755869, 0.9188637535063902, 0.9066512485949225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 60}], {
             RGBColor[
             0.7562801355297237, 0.809531056908518, 0.9763425941360632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 102}], {
             RGBColor[
             0.5772856165740025, 0.6623742905041798, 0.9623565848838942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 105}], {
             RGBColor[
             0.8954193827902208, 0.9181003086598438, 0.937247307981482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 128}], {
             RGBColor[
             0.5547192055800235, 0.6423805327309791, 0.9609350717272003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 139}], {
             RGBColor[
             0.5562400144756487, 0.6439789993051345, 0.961021679543971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 199}], {
             RGBColor[
             0.8971361136435547, 0.9188102209856679, 0.9087966349847089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 213}], {
             RGBColor[
             0.5654749182769274, 0.6521444572622102, 0.9616040176321952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 215}], {
             RGBColor[
             0.7558037231431869, 0.8091588799312872, 0.9762951098017001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 259}], {
             RGBColor[
             0.850480547970673, 0.8837308935118651, 0.9855697997497163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 271}], {
             RGBColor[
             0.8151806601648499, 0.3858404945253056, 0.4382759783762188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 287}], {
             RGBColor[
             0.8133914916365368, 0.3720881611980434, 0.43656266857292936`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 333}], {
             RGBColor[
             0.8796565038002286, 0.9065288389378603, 0.9721902291244133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 337}], {
             RGBColor[
             0.8812578483212357, 0.9077231190596664, 0.969479570547889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 345}], {
             RGBColor[
             0.8168101022247779, 0.8568829940339906, 0.982358282576511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 350}], {
             RGBColor[
             0.5770408715617338, 0.6621623046757947, 0.9623409899481321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 353}], {
             RGBColor[
             0.8993981375114619, 0.9180011012561393, 0.7445005138120175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 400}], {
             RGBColor[
             0.8165889705092233, 0.3966653849576874, 0.4396245779524498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 136}], {
             RGBColor[
             0.18182023692588944`, 0.308434975450926, 0.9336657655627689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 149}], {
             RGBColor[
             0.1956652358484003, 0.3229869471421173, 0.9344542177695655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 155}], {
             RGBColor[
             0.18345196765990118`, 0.3101500279100763, 0.9337586902141416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 268}], {
             RGBColor[
             0.18433220446865944`, 0.3110752126063183, 0.9338088183982067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 279}], {
             RGBColor[
             0.19002059109890063`, 0.3170540676192452, 0.934132763601585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 299}], {
             RGBColor[
             0.184696983160691, 0.3114586181399484, 0.9338295920050762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 300}], {
             RGBColor[
             0.18858263454534693`, 0.31554268410974895`, 0.9340508741031263]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 371}], {
             RGBColor[
             0.18051873474236652`, 0.3070670141360388, 0.9335916469388172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.1986316801099837, 0.3261048681444708, 0.9346231523818017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 86}], {
             RGBColor[
             0.23801910122574216`, 0.3675035450438693, 0.9368662077458763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 103}], {
             RGBColor[
             0.2013643551866071, 0.328977082911609, 0.9347787741847848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 295}], {
             RGBColor[
             0.19691998178395526`, 0.3243057646758728, 0.9345256736943651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 191}], {
             RGBColor[
             0.18385357890938503`, 0.3105721467969078, 0.933781561380669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 225}], {
             RGBColor[
             0.19609003670444464`, 0.3234334397757498, 0.9344784095498806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 235}], {
             RGBColor[
             0.1884735679979762, 0.31542804825324383`, 0.9340446629246031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 261}], {
             RGBColor[
             0.1864507904031121, 0.31330198074953464`, 0.9339294687330069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 327}], {
             RGBColor[
             0.18473066760764006`, 0.3114940226294092, 0.9338315102844983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 335}], {
             RGBColor[
             0.1909811618412971, 0.3180636883732066, 0.9341874666843275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 349}], {
             RGBColor[
             0.19105637302960854`, 0.3181427401007867, 0.9341917498502368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 355}], {
             RGBColor[
             0.19591924831876065`, 0.3232539303537868, 0.9344686834039748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 127}], {
             RGBColor[
             0.28524823564473223`, 0.4143130772255349, 0.9396595042068966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 137}], {
             RGBColor[
             0.2618861891426283, 0.3925893677052923, 0.9382254030945505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 138}], {
             RGBColor[
             0.26001645706684573`, 0.3906241607457843, 0.9381189246188555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 147}], {
             RGBColor[
             0.23917140342485926`, 0.3687146877153205, 0.9369318296514377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 164}], {
             RGBColor[
             0.22306024288786463`, 0.3517808364843617, 0.9360143228931819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 197}], {
             RGBColor[
             0.21121964795225362`, 0.33933562046995513`, 0.9353400185281894]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 210}], {
             RGBColor[
             0.23840421569943582`, 0.3679083247733892, 0.9368881394454274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 217}], {
             RGBColor[
             0.21968733955898895`, 0.34823570123129066`, 0.9358222410383658]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 230}], {
             RGBColor[
             0.2261265468612622, 0.35500371637530337`, 0.9361889443682767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 242}], {
             RGBColor[
             0.2857631387189643, 0.41475906038865373`, 0.9396923133754758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 254}], {
             RGBColor[
             0.20910270252497706`, 0.33711057660379506`, 0.9352194616178461]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 258}], {
             RGBColor[
             0.23439017041921995`, 0.3636893086787121, 0.9366595455049669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 328}], {
             RGBColor[
             0.23123968531368772`, 0.36037794908050486`, 0.9364801300389318]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 331}], {
             RGBColor[
             0.2360482874744978, 0.36543209483450245`, 0.9367539728183005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 79}], {
             RGBColor[
             0.20012999875823717`, 0.3276796960426744, 0.934708479412256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 87}], {
             RGBColor[
             0.1940286984190197, 0.3212668425413722, 0.9343610193840024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 126}], {
             RGBColor[
             0.1918840790772874, 0.31901271163649164`, 0.9342388864851707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 176}], {
             RGBColor[
             0.19370665948804128`, 0.32092835920646634`, 0.9343426797432972]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 205}], {
             RGBColor[
             0.19318129293550862`, 0.32037616564959115`, 0.9343127608953405]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 232}], {
             RGBColor[
             0.19578437289714112`, 0.32311216773406903`, 0.9344610024482438]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 277}], {
             RGBColor[
             0.19316166908716753`, 0.3203555397407608, 0.9343116433462084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 298}], {
             RGBColor[
             0.20333725610200998`, 0.3310507268628402, 0.9348911279732717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 373}], {
             RGBColor[
             0.1995969758310581, 0.32711945515060364`, 0.9346781245450898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 390}], {
             RGBColor[
             0.2070958500160861, 0.33500124737515247`, 0.935105174336337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 60}], {
             RGBColor[
             0.8480092281788032, 0.880384326820778, 0.9017418370121976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 68}], {
             RGBColor[
             0.9052995090875355, 0.9251530264391655, 0.9074485213302443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 105}], {
             RGBColor[
             0.9871484754393005, 0.988953578572104, 0.8626465508576164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 129}], {
             RGBColor[
             0.8758889946434687, 0.4296602011342544, 0.38811658814132355`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 199}], {
             RGBColor[
             0.9888652062926342, 0.9896634908979279, 0.8341958778608433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 271}], {
             RGBColor[
             0.8763333885975696, 0.43307600780014566`, 0.3885421402936417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 287}], {
             RGBColor[
             0.8745442200692566, 0.41932367447288343`, 0.3868288304903523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 303}], {
             RGBColor[
             0.9414623591594504, 0.8004800076065881, 0.5326277353789215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 333}], {
             RGBColor[
             0.9713855964493081, 0.9773821088501203, 0.8975894720005477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 337}], {
             RGBColor[
             0.9729869409703154, 0.9785763889719264, 0.8948788134240234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 345}], {
             RGBColor[
             0.9085391948738575, 0.9277362639462506, 0.9077575254526454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 353}], {
             RGBColor[
             0.9911272301605415, 0.9888543711683995, 0.6698997566881519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 391}], {
             RGBColor[
             0.8764876955371848, 0.43426207855576004`, 0.3886899047932819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 69}], {
             RGBColor[
             0.4877113731208531, 0.5936081076641104, 0.9531940365593021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 93}], {
             RGBColor[
             0.37256678589576175`, 0.4971203570169409, 0.9449606040427729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 131}], {
             RGBColor[
             0.6083578580504109, 0.6889233390243821, 0.9644906126536026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 142}], {
             RGBColor[
             0.43838221439814257`, 0.5535604743597381, 0.949310664485988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 188}], {
             RGBColor[
             0.33920701496392514`, 0.465180569896386, 0.9429464497347737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 201}], {
             RGBColor[
             0.5341594365329997, 0.6309589682060907, 0.9570952074204189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 264}], {
             RGBColor[
             0.3312918681319017, 0.4568612487266348, 0.9424956938321003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 273}], {
             RGBColor[
             0.4633253395942303, 0.573810427068907, 0.9512742786711021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 281}], {
             RGBColor[
             0.40067800773256046`, 0.5214688844608842, 0.9467518262404362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[
             0.35836727987096656`, 0.4848214585861875, 0.944055824075003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 394}], {
             RGBColor[
             0.38011496144870427`, 0.5036582072985654, 0.9454415671144167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 64}], {
             RGBColor[
             0.970419525130984, 0.9095497585157698, 0.3557751825465969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 83}], {
             RGBColor[
             0.9496193654049732, 0.8977579075232218, 0.6225379522867944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 123}], {
             RGBColor[
             0.8781898086085118, 0.4993404886909019, 0.21838151649392293`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 161}], {
             RGBColor[
             0.9139000708098552, 0.6892402426005217, 0.2492124251865322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 196}], {
             RGBColor[
             0.8961892019683437, 0.8555483275728113, 0.6311082747514651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 198}], {
             RGBColor[
             0.8885256847199983, 0.8494376469396148, 0.6303773216350153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 206}], {
             RGBColor[
             0.6885711015156095, 0.68922695188861, 0.6128856824256679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 214}], {
             RGBColor[
             0.913587591361185, 0.6878213464055395, 0.24895168467498954`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 310}], {
             RGBColor[
             0.8670957257484463, 0.41406650637033016`, 0.20775781021814968`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 332}], {
             RGBColor[
             0.8612878791024013, 0.3694248520342004, 0.20219620971087243`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 389}], {
             RGBColor[
             0.9706885388162402, 0.9101251515870772, 0.3850556620267193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 57}], {
             RGBColor[
             0.5760181454967422, 0.6613528823456771, 0.9622434817439033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 68}], {
             RGBColor[
             0.8126708442680417, 0.8535970039103761, 0.981959617507143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 72}], {
             RGBColor[
             0.6346370252408752, 0.7117938428167392, 0.9660702931075245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 83}], {
             RGBColor[
             0.8773611303882973, 0.9047851000408222, 0.9744632955960668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 123}], {
             RGBColor[
             0.830017651930728, 0.5040252837026356, 0.45299841203343794`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 161}], {
             RGBColor[
             0.8416418357931794, 0.6962674351181222, 0.6011377684958046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 196}], {
             RGBColor[
             0.8239309669516679, 0.8625755200904117, 0.9830336180607375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 236}], {
             RGBColor[
             0.6566866391587384, 0.7296947127190476, 0.9678061194855357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 262}], {
             RGBColor[
             0.5840352729572464, 0.6682969151994234, 0.9627543260164191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 284}], {
             RGBColor[
             0.7718010949853338, 0.8216561483989014, 0.9778895783229857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 334}], {
             RGBColor[
             0.8819744590496598, 0.862025730858683, 0.6405013220512796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 366}], {
             RGBColor[
             0.8985186945130963, 0.9173414029032505, 0.7466017890196988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 397}], {
             RGBColor[
             0.5839584526615165, 0.6682303773203624, 0.9627494310951048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 65}], {
             RGBColor[
             0.4474461015886463, 0.5602099797974611, 0.9502200964459863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 100}], {
             RGBColor[
             0.4530551393941151, 0.565068246426121, 0.9505774993750733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 174}], {
             RGBColor[
             0.4681168777823908, 0.5781139671930625, 0.9515372200266019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 198}], {
             RGBColor[
             0.6735978276393025, 0.7431113232752183, 0.969380994432274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 203}], {
             RGBColor[
             0.4142038212467356, 0.5314171873708888, 0.948101927737594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 206}], {
             RGBColor[
             0.4736432444349138, 0.5829006282242136, 0.9518893552229266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 266}], {
             RGBColor[
             0.5883098999275997, 0.6764125091387695, 0.9608991949142476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 341}], {
             RGBColor[
             0.38387079611477953`, 0.499652079122729, 0.9463702293168075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 358}], {
             RGBColor[
             0.3979975915234898, 0.5145002367878451, 0.9471747294166126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 68}], {
             RGBColor[
             0.584951659196002, 0.6683449078949819, 0.9631304154261922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 72}], {
             RGBColor[
             0.4069178401688355, 0.5265417468013449, 0.9472410910265736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 86}], {
             RGBColor[
             0.30819911150930557`, 0.43761024408224003`, 0.9409967540495674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 108}], {
             RGBColor[
             0.32733127751038416`, 0.4577193635987606, 0.9420863025998256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 236}], {
             RGBColor[
             0.4289674540866987, 0.5444426167036535, 0.9489769174045849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 262}], {
             RGBColor[
             0.35631608788520674`, 0.4830448191840292, 0.9439251239354682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 284}], {
             RGBColor[
             0.544081909913294, 0.6364040523835073, 0.9590603762420349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 297}], {
             RGBColor[
             0.3224295006293375, 0.45256728530617585`, 0.9418071536579791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 325}], {
             RGBColor[
             0.29328547563165996`, 0.42193506719570584`, 0.9401474445490827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 376}], {
             RGBColor[
             0.31723897478085683`, 0.4471117135410761, 0.941511560889603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 397}], {
             RGBColor[
             0.3562392675894767, 0.4829782813049682, 0.943920229014154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 124}], {
             RGBColor[
             0.20991109539232988`, 0.337960248762451, 0.9352654983957317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 152}], {
             RGBColor[
             0.19702370192683044`, 0.32441478112227146`, 0.9345315804030616]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 156}], {
             RGBColor[
             0.19753761270804981`, 0.3249549339371585, 0.9345608468617892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 160}], {
             RGBColor[
             0.1942495004305084, 0.32149891945510295`, 0.9343735937319094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 179}], {
             RGBColor[
             0.21000836012355356`, 0.3380624801619072, 0.9352710374782847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 181}], {
             RGBColor[
             0.19266290312611054`, 0.31983130509210156`, 0.9342832393625844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 220}], {
             RGBColor[
             0.186453938859043, 0.31330528997634166`, 0.9339296480329143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[
             0.1940488178607217, 0.32128798935024727`, 0.9343621651564433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 352}], {
             RGBColor[
             0.18979453396815193`, 0.3168164672419784, 0.9341198899824106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 396}], {
             RGBColor[
             0.18880077082680655`, 0.315771959172202, 0.9340632966416518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 132}], {
             RGBColor[
             0.20457320024571096`, 0.33234978252125474`, 0.93496151316384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 149}], {
             RGBColor[
             0.21329928840113216`, 0.34152145443854653`, 0.9354584509752006]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 155}], {
             RGBColor[
             0.20108602021263303`, 0.3286845352065056, 0.9347629234197767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 164}], {
             RGBColor[
             0.215632569168565, 0.3439738804636637, 0.9355913278631264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 210}], {
             RGBColor[
             0.23097654198013617`, 0.36010136875269116`, 0.9364651444153718]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 230}], {
             RGBColor[
             0.21869887314196257`, 0.34719676035460534`, 0.9357659493382211]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 258}], {
             RGBColor[
             0.2269624966999203, 0.35588235265801405`, 0.9362365504749113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 264}], {
             RGBColor[
             0.2381256499847355, 0.3676155345451527, 0.9368722755400762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 268}], {
             RGBColor[
             0.2019662570213913, 0.3296097199027477, 0.9348130516038419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 279}], {
             RGBColor[
             0.2076546436516325, 0.3355885749156745, 0.9351369968072203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 299}], {
             RGBColor[
             0.20233103571342284`, 0.3299931254363777, 0.9348338252107113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 300}], {
             RGBColor[
             0.20621668709807878`, 0.3340771914061782, 0.9350551073087614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 328}], {
             RGBColor[
             0.22381201159438807`, 0.3525709930598068, 0.9360571350088763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 394}], {
             RGBColor[
             0.286948743301538, 0.41441249311708334`, 0.9398181488223927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 68}], {
             RGBColor[
             0.7643140770585692, 0.8158203298412934, 0.9771398668713851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 72}], {
             RGBColor[
             0.5862802580314027, 0.6740171687476564, 0.9612505424717664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 102}], {
             RGBColor[
             0.5280292771941157, 0.6238948638185677, 0.9574471733011694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 105}], {
             RGBColor[
             0.8461630434103341, 0.8796208819742317, 0.932337896398757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 108}], {
             RGBColor[
             0.5066936953729514, 0.6051947855450721, 0.9560957540450186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 139}], {
             RGBColor[
             0.506983675095762, 0.6054995726195224, 0.9561122679612462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 297}], {
             RGBColor[
             0.5017919184919047, 0.6000427072524873, 0.955816605103172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 333}], {
             RGBColor[
             0.8304001644203418, 0.8680494122522482, 0.9672808175416883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 337}], {
             RGBColor[
             0.8320015089413489, 0.8692436923740543, 0.9645701589651641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 345}], {
             RGBColor[
             0.7675537628448912, 0.8184035673483785, 0.9774488709937861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 353}], {
             RGBColor[
             0.8501417981315751, 0.8795216745705272, 0.7395911022292926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 70}], {
             RGBColor[
             0.20711529305388426`, 0.33502168324063814`, 0.9351062815885762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 90}], {
             RGBColor[
             0.21641762089155886`, 0.3447990195996844, 0.935636035397371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 95}], {
             RGBColor[
             0.23224869997063102`, 0.3614384874601766, 0.9365375919309413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 148}], {
             RGBColor[
             0.23690961095816437`, 0.3663374004268991, 0.9368030239164815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 228}], {
             RGBColor[
             0.220637096263315, 0.34923395574559046`, 0.935876328277638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 282}], {
             RGBColor[
             0.2661448795948803, 0.3964851197604022, 0.9384891805623623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 285}], {
             RGBColor[
             0.2007711589524707, 0.32835359605871806`, 0.934744992536806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 301}], {
             RGBColor[
             0.23356716082772205`, 0.3628242734162258, 0.9366126763262647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 382}], {
             RGBColor[
             0.2696810924925139, 0.39954800963710424`, 0.9387145049212492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 91}], {
             RGBColor[
             0.7921898842803778, 0.8354987729647263, 0.873281889830355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 111}], {
             RGBColor[
             0.8816760076239252, 0.4673313794612627, 0.3772430077111397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 117}], {
             RGBColor[
             0.7751677288121797, 0.821679420316278, 0.8719418433976884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 223}], {
             RGBColor[
             0.9034121684337133, 0.6327035931146356, 0.3979909556022818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 247}], {
             RGBColor[
             0.8754937811360735, 0.41981207760671324`, 0.37132290064454676`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 256}], {
             RGBColor[
             0.992053902372576, 0.9909820986727351, 0.781350931735281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 319}], {
             RGBColor[
             0.885564206725758, 0.4972177815776606, 0.3809663515621477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 323}], {
             RGBColor[
             0.7062128595771804, 0.7648109743818534, 0.8667587588510515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 362}], {
             RGBColor[
             0.8915373797700097, 0.913872404880224, 0.882662516799504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 395}], {
             RGBColor[
             0.7152423649203183, 0.772631878073945, 0.8673341109470382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 103}], {
             RGBColor[
             0.19205709543901506`, 0.31919456280253833`, 0.9342487395110164]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 295}], {
             RGBColor[
             0.1876127220363632, 0.31452324456680214`, 0.9339956390205967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 88}], {
             RGBColor[
             0.7114905669436782, 0.7668789695612932, 0.6914868954695467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 101}], {
             RGBColor[
             0.9001775806462604, 0.6060972685953367, 0.2776552068281445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 115}], {
             RGBColor[
             0.973846560757742, 0.9231368127839409, 0.35853265585475147`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 120}], {
             RGBColor[
             0.7025664799902631, 0.759149373979897, 0.6909182605401354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 123}], {
             RGBColor[
             0.8929669582944121, 0.5506732654841682, 0.2707503067207814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 140}], {
             RGBColor[
             0.6994659535308891, 0.7564638537977784, 0.690720697735832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 161}], {
             RGBColor[
             0.9360657953387055, 0.766239407790421, 0.32776561052681985`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 193}], {
             RGBColor[
             0.9152566921622731, 0.9300770448033753, 0.7093659477350615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 195}], {
             RGBColor[
             0.7086017617355334, 0.7643768316855696, 0.6913028233561538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 214}], {
             RGBColor[
             0.9357533158900353, 0.7648205115954387, 0.32750487001527717`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 233}], {
             RGBColor[
             0.9814581324353071, 0.9819712119725741, 0.6847171998056071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 257}], {
             RGBColor[
             0.9810027572631417, 0.9816315939147817, 0.6854880311912166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 283}], {
             RGBColor[
             0.9622538962308652, 0.8771757609613251, 0.3492049258616166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 312}], {
             RGBColor[
             0.7702008939642393, 0.8151650470913949, 0.695936819489472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 332}], {
             RGBColor[
             0.8760650287883015, 0.4207576288274666, 0.25456499993773085`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 356}], {
             RGBColor[
             0.9689844051155808, 0.9726683265613763, 0.7058319664887789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 360}], {
             RGBColor[
             0.8276703795499445, 0.8615089159497265, 0.7006746506658257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 380}], {
             RGBColor[
             0.8564837144111264, 0.8840181121327374, 0.7035464946088651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 389}], {
             RGBColor[
             0.9928542633450905, 0.9871243167769764, 0.4636088473670069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 100}], {
             RGBColor[
             0.38210315454201915`, 0.5053802802265043, 0.9455682530202327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 167}], {
             RGBColor[
             0.30615029923372655`, 0.43284997763222943`, 0.940975526215034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 174}], {
             RGBColor[
             0.39716489293029483`, 0.5184260009934458, 0.9465279736717613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 198}], {
             RGBColor[
             0.6026458427872066, 0.6834233570756016, 0.9643717480774334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 203}], {
             RGBColor[
             0.34325183639463963`, 0.4717292211712722, 0.9430926813827534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 206}], {
             RGBColor[
             0.4026912595828178, 0.5232126620245969, 0.9468801088680859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 211}], {
             RGBColor[
             0.3044915837808781, 0.4311065625226518, 0.9408810648238439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 266}], {
             RGBColor[
             0.5173579150755038, 0.6167245429391528, 0.9558899485594068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 313}], {
             RGBColor[
             0.33055584599709903`, 0.45850175468157234`, 0.9423653859984371]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 329}], {
             RGBColor[
             0.31941652727713654`, 0.4467936244332925, 0.9417310182764805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 340}], {
             RGBColor[
             0.3239430587205376, 0.45155129597897675`, 0.941988797545779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 341}], {
             RGBColor[
             0.31291881126268356`, 0.4399641129231123, 0.9413609829619669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 358}], {
             RGBColor[
             0.3270456066713938, 0.4548122705882284, 0.942165483061772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 81}], {
             RGBColor[
             0.21264159429708712`, 0.3408301762349806, 0.9354209962689466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 119}], {
             RGBColor[
             0.21795851687042844`, 0.3464185989719241, 0.9357237871438162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 130}], {
             RGBColor[
             0.20589531196195676`, 0.3337394057617535, 0.9350368054701912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 146}], {
             RGBColor[
             0.19762825714734855`, 0.3250502069900508, 0.9345660089285108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 151}], {
             RGBColor[
             0.20186975982558952`, 0.3295082952316844, 0.9348075562312959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 158}], {
             RGBColor[
             0.19363377892106423`, 0.3208517571096786, 0.934338529302825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 243}], {
             RGBColor[
             0.21376058132167255`, 0.342006302545695, 0.9354847209246038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 267}], {
             RGBColor[
             0.1968456208420638, 0.3242276066111888, 0.9345214389487315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 275}], {
             RGBColor[
             0.19513571872831864`, 0.3224303910755869, 0.9344240625529272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 311}], {
             RGBColor[
             0.19936169446772767`, 0.32687215952004334`, 0.9346647256195157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 317}], {
             RGBColor[
             0.19231567190482668`, 0.3194663430628012, 0.9342634650582149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 344}], {
             RGBColor[
             0.19384485664191092`, 0.32107361317738903`, 0.9343505498667657]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 346}], {
             RGBColor[
             0.19977669952143007`, 0.3273083561443247, 0.9346883595433791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 354}], {
             RGBColor[
             0.19611420939972474`, 0.3234588468111266, 0.9344797861491166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 75}], {
             RGBColor[
             0.1806580838475214, 0.3072134788808002, 0.9335995826642074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 126}], {
             RGBColor[
             0.18098291600078534`, 0.3075548980694286, 0.9336180813747896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 133}], {
             RGBColor[
             0.1814057266970613, 0.30799929891896116`, 0.9336421598184501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 200}], {
             RGBColor[
             0.1867268102524256, 0.3135920951118324, 0.9339451876550904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 320}], {
             RGBColor[
             0.1815572411564681, 0.30815855022236927`, 0.9336507883427678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 347}], {
             RGBColor[
             0.18186543483400505`, 0.3084824813180684, 0.9336683395167719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 398}], {
             RGBColor[
             0.18010682122099816`, 0.306634066908255, 0.9335681890731469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 72}], {
             RGBColor[
             0.6435705389401349, 0.7187858683660439, 0.9669572267898132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 236}], {
             RGBColor[
             0.6656201528579981, 0.7366867382683524, 0.9686930531678246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 262}], {
             RGBColor[
             0.5929687866565062, 0.6752889407487281, 0.9636412596987081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 284}], {
             RGBColor[
             0.7807346086845934, 0.8286481739482061, 0.9787765120052747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 333}], {
             RGBColor[
             0.8876904453290742, 0.9128181118706356, 0.9729875018597351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 334}], {
             RGBColor[
             0.8909079727489195, 0.8690177564079877, 0.6413882557335685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 337}], {
             RGBColor[
             0.8892917898500812, 0.9140123919924417, 0.970276843283211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 376}], {
             RGBColor[
             0.5538916735521564, 0.639355835105775, 0.9612276966528428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 391}], {
             RGBColor[
             0.8206909281236954, 0.3912194139027702, 0.4389552580327404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 397}], {
             RGBColor[
             0.5928919663607762, 0.6752224028696671, 0.9636363647773936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 93}], {
             RGBColor[
             0.45767335020652483`, 0.5675906819706489, 0.951280040300782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 131}], {
             RGBColor[
             0.693464422361174, 0.75939366397809, 0.9708100489116116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 142}], {
             RGBColor[
             0.5234887787089056, 0.6240307993134462, 0.955630100743997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 188}], {
             RGBColor[
             0.42431357927468827`, 0.535650894850094, 0.9492658859927827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 201}], {
             RGBColor[
             0.6192660008437627, 0.7014292931597987, 0.9634146436784279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 273}], {
             RGBColor[
             0.5484319039049934, 0.644280752022615, 0.9575937149291112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 281}], {
             RGBColor[
             0.4857845720433236, 0.5919392094145923, 0.9530712624984452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 293}], {
             RGBColor[
             0.44347384418172964`, 0.5552917835398956, 0.950375260333012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 394}], {
             RGBColor[
             0.46522152575946735`, 0.5741285322522734, 0.9517610033724258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 90}], {
             RGBColor[
             0.2062666965089075, 0.33412975446773896`, 0.9350579552707259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 95}], {
             RGBColor[
             0.22209777558797966`, 0.3507692223282312, 0.9359595118042963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 177}], {
             RGBColor[
             0.1891804395703839, 0.31617101509409057`, 0.9340849182149289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 228}], {
             RGBColor[
             0.21048617188066365`, 0.3385646906136451, 0.9352982481509928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 246}], {
             RGBColor[
             0.2068329817370454, 0.33472495614706915`, 0.9350902043767244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 260}], {
             RGBColor[
             0.19294770058427305`, 0.3201306452778321, 0.9342994581565066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 285}], {
             RGBColor[
             0.1906202345698193, 0.31768433092677273`, 0.9341669124101608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 110}], {
             RGBColor[
             0.9113332721380322, 0.9312595378862136, 0.9610025753124077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 131}], {
             RGBColor[
             0.8919073913712897, 0.9158173378862382, 0.9591371203789343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 201}], {
             RGBColor[
             0.8177089698538784, 0.8578529670679469, 0.9517417151457506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 212}], {
             RGBColor[
             0.7737416965530766, 0.822516123696677, 0.9480358411696325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 271}], {
             RGBColor[
             0.8699031270122622, 0.4288122601386338, 0.4232478483872749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 273}], {
             RGBColor[
             0.7468748729151091, 0.8007044259307632, 0.9459207863964338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 287}], {
             RGBColor[
             0.8681139584839492, 0.4150599268113716, 0.4215345385839855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 289}], {
             RGBColor[
             0.7219591346417744, 0.780476707159252, 0.9439593282102003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 292}], {
             RGBColor[
             0.8695625482177284, 0.42619442228126747`, 0.42292170974900056`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 303}], {
             RGBColor[
             0.9318169667814895, 0.7940843861143203, 0.5846862975193713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 385}], {
             RGBColor[
             0.9820607295061435, 0.9836969405379016, 0.7849671104328407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 400}], {
             RGBColor[
             0.8713114373566356, 0.4396371505710155, 0.42459644796350593`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 86}], {
             RGBColor[
             0.3668179912534385, 0.4880512045533021, 0.9448235654131886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 108}], {
             RGBColor[
             0.3859501572545172, 0.5081603240698226, 0.9459131139634468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 236}], {
             RGBColor[
             0.4875863338308316, 0.5948835771747154, 0.9528037287682061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 262}], {
             RGBColor[
             0.4149349676293397, 0.5334857796550911, 0.9477519352990894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 284}], {
             RGBColor[
             0.602700789657427, 0.6868450128545692, 0.9628871876056561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 297}], {
             RGBColor[
             0.3810483803734705, 0.5030082457772378, 0.9456339650216002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 325}], {
             RGBColor[
             0.35190435537579295`, 0.4723760276667679, 0.9439742559127038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 333}], {
             RGBColor[
             0.7096566263019076, 0.7710149507769987, 0.9570981774601166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 337}], {
             RGBColor[
             0.7112579708229148, 0.7722092308988048, 0.9543875188835923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 376}], {
             RGBColor[
             0.3758578545249899, 0.4975526740121381, 0.9453383722532241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 397}], {
             RGBColor[
             0.4148581473336097, 0.5334192417760302, 0.947747040377775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.21536881746289013`, 0.3436966606981754, 0.9355763075936738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 162}], {
             RGBColor[
             0.19690433907813965`, 0.3242893232002557, 0.9345247828654102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 183}], {
             RGBColor[
             0.19359784833893534`, 0.3208139917897307, 0.9343364831093273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 189}], {
             RGBColor[
             0.2158427366159144, 0.3441947797762137, 0.9356032965883381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 207}], {
             RGBColor[
             0.1950145063297256, 0.32230298915935574`, 0.934417159686145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 280}], {
             RGBColor[
             0.2037203723071403, 0.3314534062854026, 0.9349129458743843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 291}], {
             RGBColor[
             0.19698615809912115`, 0.32437532017893284`, 0.9345294423376147]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 336}], {
             RGBColor[
             0.2166564041388005, 0.3450499959322676, 0.9356496337500533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 368}], {
             RGBColor[
             0.19117243294824504`, 0.31826472643389747`, 0.934198359290908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 387}], {
             RGBColor[
             0.19202691052884113`, 0.31916283654811173`, 0.9342470205250366]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 116}], {
             RGBColor[
             0.244277527259818, 0.37408154761281204`, 0.9372226158500052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 118}], {
             RGBColor[
             0.3029906205258713, 0.4312899550504897, 0.9407311083477143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 141}], {
             RGBColor[
             0.3021503369999872, 0.43056214369424695`, 0.9406775662244785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 179}], {
             RGBColor[
             0.23767352171657924`, 0.3671403190687327, 0.9368465275040685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 209}], {
             RGBColor[
             0.2567896978925637, 0.3872326322652657, 0.9379351654574425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 286}], {
             RGBColor[
             0.28488862903471124`, 0.4156109198533938, 0.9395776654568602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 290}], {
             RGBColor[
             0.2530317916874394, 0.3832828345786652, 0.9377211582583846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 304}], {
             RGBColor[
             0.2654021800822186, 0.39628489710950293`, 0.9384256335771177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 338}], {
             RGBColor[
             0.22933498443170014`, 0.35837598768852497`, 0.9363716601414551]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 386}], {
             RGBColor[
             0.29523037248077955`, 0.42456841823523894`, 0.9402366322043989]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 126}], {
             RGBColor[
             0.18223452639463555`, 0.3088704199500476, 0.9336893587351277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 133}], {
             RGBColor[
             0.18265733709091148`, 0.3093148207995801, 0.9337134371787883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 178}], {
             RGBColor[
             0.18245868691760933`, 0.30910602687229105`, 0.9337021243452953]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 200}], {
             RGBColor[
             0.1879784206462758, 0.3149076169924513, 0.9340164650154286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 296}], {
             RGBColor[
             0.18049305546872535`, 0.30704002359128196`, 0.9335901845421726]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 320}], {
             RGBColor[
             0.18280885155031829`, 0.3094740721029882, 0.933722065703106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 330}], {
             RGBColor[
             0.18530504232011252`, 0.31209772686967785`, 0.9338642200746624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 347}], {
             RGBColor[
             0.18311704522785527`, 0.30979800319868733`, 0.9337396168771099]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 398}], {
             RGBColor[
             0.18135843161484838`, 0.30794958878887396`, 0.9336394664334849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 78}], {
             RGBColor[
             0.2517003601981642, 0.38188341566580475`, 0.9376453352047469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 80}], {
             RGBColor[
             0.24302079240522623`, 0.37276063959904404`, 0.9371510466592089]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.24728213971667218`, 0.37723958580839845`, 0.9373937240844974]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 117}], {
             RGBColor[
             0.4207333030341396, 0.5335965741048728, 0.9489064510842957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.2623813144884871, 0.39310977583655005`, 0.9382535997505249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 187}], {
             RGBColor[
             0.24964108184106412`, 0.37971898354670364`, 0.9375280623487394]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 208}], {
             RGBColor[
             0.28867650153937047`, 0.420747684638181, 0.9397510717528295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 239}], {
             RGBColor[
             0.3950361568987507, 0.5127344732289232, 0.94688347760877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 269}], {
             RGBColor[
             0.3181691701834686, 0.44761747327725976`, 0.9415818139795731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 323}], {
             RGBColor[
             0.3517784337991403, 0.4767281281704481, 0.9437233665376588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 365}], {
             RGBColor[
             0.2944759917270998, 0.42684331653440033`, 0.9400813441394438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 377}], {
             RGBColor[
             0.2688145572376063, 0.39987152185702324`, 0.9386199634079575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 388}], {
             RGBColor[
             0.276858244918402, 0.40832594760879465`, 0.9390780395218092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 395}], {
             RGBColor[
             0.36080793914227827`, 0.4845490318625397, 0.9442987186336453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 78}], {
             RGBColor[
             0.20870891214169546`, 0.33669667794321373`, 0.9351970358380788]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 80}], {
             RGBColor[
             0.20002934434875747`, 0.3275739018764531, 0.9347027472925409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 96}], {
             RGBColor[
             0.20429069166020342`, 0.3320528480858075, 0.9349454247178293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 182}], {
             RGBColor[
             0.21938986643201835`, 0.34792303811395897`, 0.9358053003838569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 187}], {
             RGBColor[
             0.2066496337845954, 0.33453224582411256`, 0.9350797629820713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 244}], {
             RGBColor[
             0.18965577385650711`, 0.31667062156674053`, 0.9341119877993296]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 302}], {
             RGBColor[
             0.19582677060371215`, 0.3231567304118451, 0.9344634169349113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 377}], {
             RGBColor[
             0.22582310918113752`, 0.35468478413443216`, 0.9361716640412894]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 388}], {
             RGBColor[
             0.23386679686193323`, 0.36313920988620363`, 0.9366297401551412]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 80}], {
             RGBColor[
             0.21178615052788774`, 0.3399310505952844, 0.9353722800118063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 96}], {
             RGBColor[
             0.2160474978393337, 0.3444099968046388, 0.9356149574370947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 104}], {
             RGBColor[
             0.22225745398096258`, 0.35093705444345114`, 0.9359686052525535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 182}], {
             RGBColor[
             0.23114667261114863`, 0.3602801868327903, 0.9364748331031223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 187}], {
             RGBColor[
             0.21840643996372563`, 0.3468893945429439, 0.9357492957013367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 208}], {
             RGBColor[
             0.257441859662032, 0.38791809563442126`, 0.9379723051054267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 302}], {
             RGBColor[
             0.2075835767828424, 0.33551387913067643`, 0.9351329496541767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 377}], {
             RGBColor[
             0.2375799153602678, 0.3670419328532635, 0.9368411967605548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 388}], {
             RGBColor[
             0.2456236030410635, 0.37549635860503494`, 0.9372992728744065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 87}], {
             RGBColor[
             0.19294989757058154`, 0.3201329544497393, 0.9342995832716268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 126}], {
             RGBColor[
             0.19080527822884924`, 0.31787882354485875`, 0.9341774503727951]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 176}], {
             RGBColor[
             0.19262785863960308`, 0.31979447111483345`, 0.9342812436309215]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 205}], {
             RGBColor[
             0.19210249208707042`, 0.3192422775579583, 0.9342513247829649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 232}], {
             RGBColor[
             0.19470557204870292`, 0.32197827964243614`, 0.9343995663358682]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[
             0.19208286823872933`, 0.31922165164912797`, 0.9342502072338328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 298}], {
             RGBColor[
             0.20225845525357178`, 0.3299168387712073, 0.934829691860896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 373}], {
             RGBColor[
             0.19851817498261992`, 0.32598556705897075`, 0.9346166884327141]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 390}], {
             RGBColor[
             0.2060170491676479, 0.3338673592835195, 0.9350437382239613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 96}], {
             RGBColor[
             0.2073679300463957, 0.3352872207378781, 0.9351206688915568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 104}], {
             RGBColor[
             0.2135778861880246, 0.34181427837669043`, 0.9354743167070156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 182}], {
             RGBColor[
             0.22246710481821064`, 0.35115741076602963`, 0.9359805445575843]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 187}], {
             RGBColor[
             0.20972687217078761`, 0.3377666184761832, 0.9352550071557988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 244}], {
             RGBColor[
             0.1927330122426994, 0.31990499421881113`, 0.9342872319730569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 302}], {
             RGBColor[
             0.1989040089899044, 0.3263911030639157, 0.9346386611086387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 377}], {
             RGBColor[
             0.2289003475673298, 0.3579191567865028, 0.9363469082150169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 388}], {
             RGBColor[
             0.23694403524812552`, 0.36637358253827423`, 0.9368049843288686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 119}], {
             RGBColor[
             0.2344729010553813, 0.363776263822743, 0.9366642568923073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 128}], {
             RGBColor[
             0.2665289573662383, 0.3974692114768138, 0.9384898018765251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.2224096961469096, 0.35109707061257234`, 0.9359772752186821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 135}], {
             RGBColor[
             0.2822556151095555, 0.41153871876028536`, 0.9394754920042432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 146}], {
             RGBColor[
             0.2141426413323014, 0.3424078718408697, 0.9355064786770019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 166}], {
             RGBColor[
             0.2371652059079643, 0.3666060469247946, 0.9368175796707537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 227}], {
             RGBColor[
             0.2515739104642789, 0.38175050897811513`, 0.9376381340794677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 243}], {
             RGBColor[
             0.2302749655066254, 0.3593639673965138, 0.9364251906730947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[
             0.21336000502701669`, 0.3415852714620077, 0.9354619086972226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 275}], {
             RGBColor[
             0.21165010291327152`, 0.33978805592640576`, 0.9353645323014182]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 311}], {
             RGBColor[
             0.21587607865268055`, 0.34422982437086214`, 0.9356051953680067]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 326}], {
             RGBColor[
             0.23536377630225702`, 0.36471263019196243`, 0.936714990919685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 344}], {
             RGBColor[
             0.2103592408268638, 0.3384312780282078, 0.9352910196152566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 346}], {
             RGBColor[
             0.21629108370638292`, 0.34466602099514354`, 0.9356288292918702]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 363}], {
             RGBColor[
             0.3018408929173706, 0.42850250201273, 0.940723448587576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 383}], {
             RGBColor[
             0.2937367673363199, 0.42148311575961905`, 0.9402070608717483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 172}], {
             RGBColor[
             0.5696909718954926, 0.6577404259092337, 0.9610497684809419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 194}], {
             RGBColor[
             0.6075992658363466, 0.6905170696190597, 0.963481170694517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 233}], {
             RGBColor[
             0.865044812104987, 0.8948209835298624, 0.9558976637938235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 256}], {
             RGBColor[
             0.8760312800563814, 0.9016669835366705, 0.876948136427472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 257}], {
             RGBColor[
             0.8645894369328215, 0.89448136547207, 0.956668495179433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 310}], {
             RGBColor[
             0.804263995214133, 0.4072991308684552, 0.44091357643715234`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 316}], {
             RGBColor[
             0.7359499332008539, 0.7936489483339444, 0.9743162695644639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 399}], {
             RGBColor[
             0.5595672102027384, 0.6489717323660277, 0.9604046913379707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 118}], {
             RGBColor[
             0.6542161598297946, 0.7234949587303476, 0.9559255584190995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 123}], {
             RGBColor[
             0.8791001851437382, 0.542812031489136, 0.4485921532142464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 141}], {
             RGBColor[
             0.6533758763039106, 0.7227671473741049, 0.9558720162958637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 161}], {
             RGBColor[
             0.9152656356126947, 0.754447556797873, 0.5945283802670174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 196}], {
             RGBColor[
             0.8975547667711833, 0.9207556417701627, 0.9764242298319501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 214}], {
             RGBColor[
             0.9149531561640245, 0.7530286606028909, 0.5942676397554747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 286}], {
             RGBColor[
             0.6361141683386347, 0.7078159235332517, 0.9547721155282454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 332}], {
             RGBColor[
             0.8621982556376276, 0.41289639483243457`, 0.43240684643119587`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 334}], {
             RGBColor[
             0.9555982588691752, 0.9202058525384339, 0.6338919338224923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 366}], {
             RGBColor[
             0.9721424943326117, 0.9755215245830015, 0.7399924007909114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 125}], {
             RGBColor[
             0.20344264397852102`, 0.33116149620303065`, 0.9348971296569317]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 184}], {
             RGBColor[
             0.21392003441563898`, 0.34217389785736374`, 0.9354938015424155]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 185}], {
             RGBColor[
             0.20341836522778634`, 0.3311359776966468, 0.9348957470179945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 190}], {
             RGBColor[
             0.21321988075352158`, 0.3414379919661722, 0.9354539288271424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 252}], {
             RGBColor[
             0.2101141940866254, 0.33817371836735655`, 0.9352770645659143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 270}], {
             RGBColor[
             0.21111604747539212`, 0.339226729800124, 0.9353341186342953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 274}], {
             RGBColor[
             0.20871345876417752`, 0.33670145673171487`, 0.935197294761503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 288}], {
             RGBColor[
             0.21401051896422651`, 0.342269002854981, 0.9354989545035975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 318}], {
             RGBColor[
             0.2138717930117836, 0.3421231930832301, 0.9354910542658326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 168}], {
             RGBColor[
             0.18992658867508105`, 0.3169552651117129, 0.9341274103026127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 238}], {
             RGBColor[
             0.19138550303315327`, 0.3184886766025597, 0.9342104933170345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 379}], {
             RGBColor[
             0.18217848519657132`, 0.30881151709766497`, 0.9336861672718034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 236}], {
             RGBColor[
             0.3888676051713017, 0.5059520744556105, 0.9465593917911999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 262}], {
             RGBColor[
             0.31621623896980977`, 0.44455427693598626`, 0.9415075983220833]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 265}], {
             RGBColor[
             0.23354789403514828`, 0.36280402279564555`, 0.9366115791109302]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 297}], {
             RGBColor[
             0.28232965171394053`, 0.4140767430581329, 0.9393896280445941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 325}], {
             RGBColor[
             0.25318562671626305`, 0.38344452494766296`, 0.9377299189356977]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 376}], {
             RGBColor[
             0.2771391258654599, 0.4086211712930332, 0.939094035276218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 397}], {
             RGBColor[
             0.3161394186740798, 0.4444877390569253, 0.9415027034007689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 176}], {
             RGBColor[
             0.18652655830038561`, 0.3133816176135313, 0.933933783602668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 205}], {
             RGBColor[
             0.18600119174785296`, 0.31282942405665615`, 0.9339038647547113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 232}], {
             RGBColor[
             0.18860427170948546`, 0.315565426141134, 0.9340521063076146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 277}], {
             RGBColor[
             0.18598156789951187`, 0.3128087981478258, 0.9339027472055792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 373}], {
             RGBColor[
             0.19241687464340246`, 0.3195727135576686, 0.9342692284044607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 390}], {
             RGBColor[
             0.19991574882843044`, 0.32745450578221735`, 0.9346962781957078]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 89}], {
             RGBColor[
             0.33131087657095276`, 0.4543117529947025, 0.9425908573941362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 120}], {
             RGBColor[
             0.42147179727410705`, 0.5394794198355211, 0.9480767881227974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 140}], {
             RGBColor[
             0.41837127081473313`, 0.5367938996534025, 0.947879225318494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 189}], {
             RGBColor[
             0.331784795723977, 0.4548098720727408, 0.9426178463888004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 195}], {
             RGBColor[
             0.42750707901937735`, 0.5447068775411936, 0.948461350938816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 233}], {
             RGBColor[
             0.7003634497191511, 0.7623012578281982, 0.9418757273882692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 255}], {
             RGBColor[
             0.40229233650521606`, 0.5228671349052352, 0.9468546898423349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 257}], {
             RGBColor[
             0.6999080745469857, 0.7619616397704058, 0.9426465587738788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 263}], {
             RGBColor[
             0.3661139704738488, 0.49089201133024934`, 0.9445728421053426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 336}], {
             RGBColor[
             0.33259846324686315`, 0.4556650882287947, 0.9426641835505155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 356}], {
             RGBColor[
             0.6878897223994248, 0.7529983724170004, 0.962990494071441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 359}], {
             RGBColor[
             0.3780427703410259, 0.5018633795124479, 0.9453095289294022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 360}], {
             RGBColor[
             0.5465756968337885, 0.6418389618053506, 0.9578331782484879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 389}], {
             RGBColor[
             0.7117595806289345, 0.7674543626326005, 0.720767374949669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 162}], {
             RGBColor[
             0.2137613905296329, 0.342007153074568, 0.9354847670077999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 183}], {
             RGBColor[
             0.21045489979042858`, 0.338531821664043, 0.935296467251717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 189}], {
             RGBColor[
             0.23269978806740765`, 0.361912609650526, 0.9365632807307278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 263}], {
             RGBColor[
             0.2670289628172794, 0.39799474890803455`, 0.93851827644727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 270}], {
             RGBColor[
             0.22008543635339983`, 0.34865412620301106`, 0.935844912061876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.22057742375863354`, 0.3491712361597149, 0.935872930016774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 291}], {
             RGBColor[
             0.2138432095506144, 0.34209315005324514`, 0.9354894264800044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 336}], {
             RGBColor[
             0.23351345559029374`, 0.36276782580657996`, 0.9366096178924429]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 359}], {
             RGBColor[
             0.2789577626844565, 0.40896611709023306`, 0.9392549632713296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 95}], {
             RGBColor[
             0.23140010342565426`, 0.3605465586872775, 0.936489265613091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 97}], {
             RGBColor[
             0.2570968896215246, 0.3875555102494842, 0.9379526595719574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.23037172884023532`, 0.35946567179528754`, 0.9364307012017953]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 228}], {
             RGBColor[
             0.21978849971833822`, 0.34834202697269134`, 0.9358280019597877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 246}], {
             RGBColor[
             0.21613530957472, 0.3445022925061154, 0.9356199581855191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 260}], {
             RGBColor[
             0.20225002842194761`, 0.32990798163687834`, 0.9348292119653014]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 326}], {
             RGBColor[
             0.22857029923452804`, 0.35757225506245527`, 0.9363281124507266]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 172}], {
             RGBColor[
             0.48609962486048197`, 0.5916756169176496, 0.9532395671401708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 192}], {
             RGBColor[
             0.4254211791359827, 0.5344518171008017, 0.9495440785539795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 208}], {
             RGBColor[
             0.4434969579662055, 0.5534506067219376, 0.9505734674176423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 221}], {
             RGBColor[
             0.48124384050183955`, 0.5874697805650118, 0.9529301608546397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 256}], {
             RGBColor[
             0.792439933021371, 0.8356021745450866, 0.869137935086701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 316}], {
             RGBColor[
             0.6523585861658432, 0.7275841393423603, 0.9665060682236928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 351}], {
             RGBColor[
             0.45106536887988224`, 0.5613307052601594, 0.9510072153286632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 395}], {
             RGBColor[
             0.5156283955691132, 0.6172519539462964, 0.9551211142984581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 399}], {
             RGBColor[
             0.4759758631677278, 0.5829069233744436, 0.9525944899971995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 98}], {
             RGBColor[
             0.19880960071600262`, 0.32629187398221465`, 0.9346332846971046]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 119}], {
             RGBColor[
             0.22208012665594387`, 0.3507506721816547, 0.9359585067237262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 130}], {
             RGBColor[
             0.2100169217474722, 0.33807147897148404`, 0.935271525050101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 143}], {
             RGBColor[
             0.20163694443753327`, 0.3292635914974891, 0.9347942977393655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 146}], {
             RGBColor[
             0.20174986693286398`, 0.32938228019978144`, 0.9348007285084208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 151}], {
             RGBColor[
             0.20599136961110498`, 0.33384036844141496`, 0.9350422758112056]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 158}], {
             RGBColor[
             0.19775538870657966`, 0.32518383031940923`, 0.9345732488827347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 186}], {
             RGBColor[
             0.20547576839988674`, 0.33329843887741967`, 0.9350129130849905]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 267}], {
             RGBColor[
             0.20096723062757926`, 0.3285596798209194, 0.9347561585286415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 306}], {
             RGBColor[
             0.21333519209183469`, 0.34155919149390046`, 0.9354604956372714]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 308}], {
             RGBColor[
             0.20860909712508957`, 0.3365917660321234, 0.9351913515205462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 346}], {
             RGBColor[
             0.2038983093069455, 0.33164042935405524`, 0.934923079123289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 348}], {
             RGBColor[
             0.2027372639690243, 0.3304200970893739, 0.9348569593089071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 354}], {
             RGBColor[
             0.20023581918524017`, 0.32779092002085713`, 0.9347145057290265]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 374}], {
             RGBColor[
             0.1940034937220554, 0.32124035080679264`, 0.9343595840137974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 131}], {
             RGBColor[
             0.5783198351360825, 0.6629059133309206, 0.9625766163950823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 142}], {
             RGBColor[
             0.4083441914838143, 0.5275430486662767, 0.9473966682274677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 188}], {
             RGBColor[
             0.3091689920495968, 0.43916314420292457`, 0.9410324534762535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 201}], {
             RGBColor[
             0.5041214136186714, 0.6049415425126292, 0.9551812111618987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 264}], {
             RGBColor[
             0.3012538452175734, 0.43084382303317337`, 0.9405816975735801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 273}], {
             RGBColor[
             0.433287316679902, 0.5477930013754455, 0.949360282412582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 281}], {
             RGBColor[
             0.3706399848182322, 0.4954514587674228, 0.944837829981916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 293}], {
             RGBColor[
             0.3283292569566383, 0.4588040328927261, 0.9421418278164828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 394}], {
             RGBColor[
             0.35007693853437594`, 0.4776407816051039, 0.9435275708558966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 204}], {
             RGBColor[
             0.1795232819748228, 0.3060207301619996, 0.9335349573763461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.18066543438157506`, 0.30722120475814135`, 0.9336000012662475]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 307}], {
             RGBColor[
             0.17906784709075121`, 0.30554203922260087`, 0.9335090210334537]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 324}], {
             RGBColor[
             0.18239675869616345`, 0.30904093638507546`, 0.9336985976246985]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 97}], {
             RGBColor[
             0.27292796870059677`, 0.4041949781099764, 0.9388542161055278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 148}], {
             RGBColor[
             0.2518920934922597, 0.3820849395144922, 0.9376562541322015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 166}], {
             RGBColor[
             0.24620280791930751`, 0.37610513965577974`, 0.9373322577353658]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 169}], {
             RGBColor[
             0.3522449518778092, 0.4737241407933565, 0.9439035250794346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 228}], {
             RGBColor[
             0.2356195787974104, 0.36498149483318354`, 0.9367295584933581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 246}], {
             RGBColor[
             0.23196638865379215`, 0.3611417603666076, 0.9365215147190895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 276}], {
             RGBColor[
             0.3131382201938357, 0.4399588551912694, 0.9413821143478849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 282}], {
             RGBColor[
             0.2811273621289757, 0.41223265884799526`, 0.9393424107780823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 305}], {
             RGBColor[
             0.2726453120788769, 0.4038978880790839, 0.9388381192290738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 326}], {
             RGBColor[
             0.24440137831360023`, 0.3742117229229475, 0.9372296689842969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 361}], {
             RGBColor[
             0.32840262007179855`, 0.45318011115451534`, 0.9423547484103298]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 382}], {
             RGBColor[
             0.2846635750266093, 0.4152955487246973, 0.9395677351369693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 104}], {
             RGBColor[
             0.21783923349947054`, 0.34629322458604483`, 0.935716994132304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 182}], {
             RGBColor[
             0.2267284521296566, 0.35563635697538404`, 0.9362232219828728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 187}], {
             RGBColor[
             0.2139882194822336, 0.34224556468553763`, 0.9354976845810872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 208}], {
             RGBColor[
             0.25302363918053994`, 0.383274265777015, 0.9377206939851772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 225}], {
             RGBColor[
             0.21005566506834547`, 0.33811220065819025`, 0.9352737314249091]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 261}], {
             RGBColor[
             0.20041641876701294`, 0.3279807416319751, 0.9347247906080353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 377}], {
             RGBColor[
             0.23316169487877575`, 0.36239810299585723`, 0.9365895856403053]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 388}], {
             RGBColor[
             0.24120538255957147`, 0.37085252874762864`, 0.937047661754157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 166}], {
             RGBColor[
             0.27189959411517783`, 0.40311409121798647`, 0.9387956516942321]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 169}], {
             RGBColor[
             0.37794173807367953`, 0.5007330923555633, 0.945366919038301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 224}], {
             RGBColor[
             0.3981861519254275, 0.5171684195208632, 0.946960633454442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 246}], {
             RGBColor[
             0.2576631748496625, 0.38815071192881434`, 0.9379849086779559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 276}], {
             RGBColor[
             0.33883500638970604`, 0.46696780675347616`, 0.9428455083067513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 326}], {
             RGBColor[
             0.27009816450947055`, 0.40122067448515425`, 0.9386930629431633]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 363}], {
             RGBColor[
             0.3365752811245841, 0.4650105463059218, 0.9427015206110543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 382}], {
             RGBColor[
             0.3103603612224796, 0.44230450028690405`, 0.9410311290958356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 383}], {
             RGBColor[
             0.32847115554353346`, 0.45799116005281093`, 0.9421851328952267]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 393}], {
             RGBColor[
             0.5102982570407728, 0.6069665111134733, 0.9566203329382144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 134}], {
             RGBColor[
             0.1861818864522268, 0.313019345647659, 0.9339141550508117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 143}], {
             RGBColor[
             0.19607611547037074`, 0.3234188076760809, 0.9344776167561948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 151}], {
             RGBColor[
             0.20043054064394245`, 0.3279955846200067, 0.934725594828035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 158}], {
             RGBColor[
             0.19219455973941713`, 0.31933904649800093`, 0.9342565678995641]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 163}], {
             RGBColor[
             0.18615149755953203`, 0.3129874049946697, 0.933912424448329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.1906510637312114, 0.3177167343300775, 0.9341686680852945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 186}], {
             RGBColor[
             0.1999149394327242, 0.32745365505601143`, 0.9346962321018197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 240}], {
             RGBColor[
             0.18629079266231832`, 0.3131338129795177, 0.9339203570983641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 272}], {
             RGBColor[
             0.1949500622314218, 0.3222352543260466, 0.9344134896900831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 306}], {
             RGBColor[
             0.20777436312467215`, 0.33571440767249217`, 0.9351438146541007]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 308}], {
             RGBColor[
             0.20304826815792704`, 0.3307469822107151, 0.9348746705373756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 342}], {
             RGBColor[
             0.1898214409282245, 0.31684474816301444`, 0.9341214222939813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 348}], {
             RGBColor[
             0.19717643500186177`, 0.3245753132679656, 0.9345402783257364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 354}], {
             RGBColor[
             0.19467499021807763`, 0.3219461361994489, 0.9343978247458558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 374}], {
             RGBColor[
             0.18844266475489285`, 0.3153955669853844, 0.9340429030306268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 378}], {
             RGBColor[
             0.21674290293340537`, 0.34514091164973765`, 0.9356545597284425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 144}], {
             RGBColor[
             0.7417116613175341, 0.797878300210745, 0.9753542230915366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 169}], {
             RGBColor[
             0.6797124063510102, 0.7475445119943138, 0.9704734146298177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[
             0.7312212189545854, 0.7893616865114603, 0.9745283770409688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 222}], {
             RGBColor[
             0.9266267914902193, 0.9439342403679507, 0.9791054495248444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 223}], {
             RGBColor[
             0.8735329143735617, 0.6106862837337387, 0.46633619385844605`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 276}], {
             RGBColor[
             0.6406056746670367, 0.7137792263922267, 0.9679520038982681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 361}], {
             RGBColor[
             0.6558700745449995, 0.7270004823554725, 0.968924637960713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 382}], {
             RGBColor[
             0.6121310294998102, 0.6891159199256546, 0.9661376246873524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 384}], {
             RGBColor[
             0.9178754148881313, 0.8496097092612407, 0.6279747633092586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 393}], {
             RGBColor[
             0.8120689253181035, 0.8537779307522239, 0.9817268285297311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 157}], {
             RGBColor[
             0.31728677632069113`, 0.4435179334056334, 0.9416477086340886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 167}], {
             RGBColor[
             0.3117593370391954, 0.4377082442608893, 0.941332929144121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 174}], {
             RGBColor[
             0.4027739307357637, 0.5232842676221057, 0.9468853766008484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 198}], {
             RGBColor[
             0.6082548805926754, 0.6882816237042615, 0.9647291510065205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 203}], {
             RGBColor[
             0.3488608742001085, 0.47658748779993204`, 0.9434500843118405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 206}], {
             RGBColor[
             0.40830029738828666`, 0.5280709286532568, 0.947237511797173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 211}], {
             RGBColor[
             0.31010062158634694`, 0.43596482915131163`, 0.941238467752931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 266}], {
             RGBColor[
             0.5229669528809726, 0.6215828095678126, 0.9562473514884939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 341}], {
             RGBColor[
             0.3185278490681524, 0.4448223795517722, 0.9417183858910539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 358}], {
             RGBColor[
             0.33265464447686266`, 0.4596705372168882, 0.942522885990859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 115}], {
             RGBColor[
             0.8876851213781989, 0.5638225279808512, 0.22712473214005577`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 123}], {
             RGBColor[
             0.8503684349635493, 0.38815943948458614`, 0.19586617624509287`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 161}], {
             RGBColor[
             0.8624979444321746, 0.45922425798517125`, 0.20661336858810134`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 193}], {
             RGBColor[
             0.8486252089812196, 0.5684493493271408, 0.4610135933935957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 253}], {
             RGBColor[
             0.8443799630600709, 0.34212942026933035`, 0.1901316087873103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 283}], {
             RGBColor[
             0.8799566783602811, 0.5331818267657741, 0.22090624547796586`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 332}], {
             RGBColor[
             0.8419174702104941, 0.3232016211562354, 0.18777352285356763`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 334}], {
             RGBColor[
             0.8893863599364948, 0.5697297884788785, 0.23285573762508466`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 356}], {
             RGBColor[
             0.8844436842834248, 0.5968435371658081, 0.458657605896074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 364}], {
             RGBColor[
             0.8764286119416923, 0.5191942190745097, 0.21806748042320684`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 366}], {
             RGBColor[
             0.9004158502454526, 0.6066069031752569, 0.3035893822706974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 380}], {
             RGBColor[
             0.8094432238137885, 0.5377433942133822, 0.4571339579761315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 389}], {
             RGBColor[
             0.9003569231030979, 0.6064808639762083, 0.2971755264815594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 108}], {
             RGBColor[
             0.3276991764172302, 0.45803801914073383`, 0.9421097447928497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 139}], {
             RGBColor[
             0.3279891561400408, 0.4583428062151842, 0.9421262587090772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 213}], {
             RGBColor[
             0.33722405994131943`, 0.4665082641722599, 0.9427085967973012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 297}], {
             RGBColor[
             0.32279739953618347`, 0.45288594084814915`, 0.9418305958510031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 333}], {
             RGBColor[
             0.6514056454646207, 0.7208926458479099, 0.9532948082895194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 337}], {
             RGBColor[
             0.6530069899856277, 0.722086925969716, 0.9505841497129952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 345}], {
             RGBColor[
             0.5885592438891699, 0.6712468009440402, 0.9634628617416172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 350}], {
             RGBColor[
             0.3487900132261258, 0.4765261115858444, 0.9434455691132382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 378}], {
             RGBColor[
             0.29463589617818253`, 0.42328641527644917`, 0.9402268398959757]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 122}], {
             RGBColor[
             0.1920779072643653, 0.3192164373505274, 0.9342499247136817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 295}], {
             RGBColor[
             0.1903453971129866, 0.3173954593339403, 0.9341512608235798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 145}], {
             RGBColor[
             0.2369611402467977, 0.36639156097639836`, 0.9368059584332384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 170}], {
             RGBColor[
             0.22977658578143667`, 0.35884013870624076`, 0.936396808685032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 182}], {
             RGBColor[
             0.23293840827128548`, 0.36216341461419643`, 0.9365768697983317]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 187}], {
             RGBColor[
             0.2201981756238625, 0.34877262232435, 0.935851332396546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 192}], {
             RGBColor[
             0.24115781649194606`, 0.3708025337946915, 0.9370449529369735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 208}], {
             RGBColor[
             0.25923359532216883`, 0.3898013234158274, 0.9380743418006362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 225}], {
             RGBColor[
             0.2162656212099744, 0.3446392582970026, 0.935627379240368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 235}], {
             RGBColor[
             0.20864915250350596`, 0.3366338667744967, 0.9351936326150905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 261}], {
             RGBColor[
             0.20662637490864183`, 0.3345077992707875, 0.9350784384234943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 327}], {
             RGBColor[
             0.20490625211316982`, 0.332699841150662, 0.9349804799749857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 335}], {
             RGBColor[
             0.21115674634682685`, 0.33926950689445945`, 0.9353364363748149]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 349}], {
             RGBColor[
             0.21123195753513827`, 0.3393485586220395, 0.9353407195407242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 351}], {
             RGBColor[
             0.26680200623584566`, 0.3976814219540492, 0.9385080897116571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 355}], {
             RGBColor[
             0.21609483282429037`, 0.34445974887503966`, 0.9356176530944622]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 199}], {
             RGBColor[
             0.9870190215241651, 0.9889000460513815, 0.8647919372474027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 215}], {
             RGBColor[
             0.8456866310237973, 0.8792487049970009, 0.932290412064394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 259}], {
             RGBColor[
             0.9403634558512834, 0.9538207185775788, 0.9415651020124101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 271}], {
             RGBColor[
             0.8751025987519235, 0.43256704456911477`, 0.4089395132180147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 287}], {
             RGBColor[
             0.8733134302236104, 0.41881471124185254`, 0.40722620341472526`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 303}], {
             RGBColor[
             0.9396161743909813, 0.7997165627600418, 0.5632237947654809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 333}], {
             RGBColor[
             0.969539411680839, 0.9766186640035739, 0.9281855313871071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 337}], {
             RGBColor[
             0.9711407562018461, 0.97781294412538, 0.9254748728105828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 345}], {
             RGBColor[
             0.9066930101053883, 0.9269728190997042, 0.9383535848392048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 350}], {
             RGBColor[
             0.6669237794423443, 0.7322521297415084, 0.9183362922108259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 353}], {
             RGBColor[
             0.9892810453920724, 0.988090926321853, 0.7004958160747115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 400}], {
             RGBColor[
             0.8765109090962969, 0.44339193500149654`, 0.4102881127942457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 197}], {
             RGBColor[
             0.18891531916432497`, 0.315892356737718, 0.9340698200000144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 217}], {
             RGBColor[
             0.1973830107710603, 0.32479243749905357`, 0.9345520425101908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 231}], {
             RGBColor[
             0.1888628748467801, 0.31583723443481654`, 0.9340668333737145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 254}], {
             RGBColor[
             0.18679837373704838`, 0.3136673128715579, 0.9339492630896711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 314}], {
             RGBColor[
             0.18463641563674799`, 0.3113949578320815, 0.9338261427741893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 369}], {
             RGBColor[
             0.18346224485360668`, 0.3101608298922725, 0.9337592754851194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 124}], {
             RGBColor[
             0.22484989821780513`, 0.3536618777068309, 0.9361162411166642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 150}], {
             RGBColor[
             0.23074389884075946`, 0.35985684606277935`, 0.936451895732749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 152}], {
             RGBColor[
             0.2119625047523057, 0.3401164100666513, 0.9353823231239942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.2124764155335251, 0.34065656288153834`, 0.9354115895827217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.2349712471793796, 0.36430005719603437`, 0.936692636966832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 160}], {
             RGBColor[
             0.20918830325598364`, 0.33720054839948277`, 0.935224336452842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 167}], {
             RGBColor[
             0.22944380789788385`, 0.3584903680512903, 0.9363778574768644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.2249471629490288, 0.3537641091062871, 0.9361217801992172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 181}], {
             RGBColor[
             0.20760170595158578`, 0.3355329340364814, 0.935133982083517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 211}], {
             RGBColor[
             0.2277850924450354, 0.3567469529417126, 0.9362833960856742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 238}], {
             RGBColor[
             0.21198166691675951`, 0.34013655071644366`, 0.9353834143809119]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 245}], {
             RGBColor[
             0.20898762068619692`, 0.33698961829462715`, 0.9352129078773759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 386}], {
             RGBColor[
             0.2825040137132291, 0.4111922082727934, 0.9395118848995476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 297}], {
             RGBColor[
             0.30146181771501923`, 0.43418586257465347`, 0.9404791765948524]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 325}], {
             RGBColor[
             0.2723177927173417, 0.4035536444641835, 0.9388194674859559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 376}], {
             RGBColor[
             0.29627129186653856`, 0.4287302908095537, 0.9401835838264763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 378}], {
             RGBColor[
             0.2733003143570183, 0.40458633700295354`, 0.938875420639825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 397}], {
             RGBColor[
             0.3352715846751584, 0.4645968585734458, 0.9425922519510271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 114}], {
             RGBColor[
             0.18471405231964982`, 0.3114765589082613, 0.9338305640684275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 132}], {
             RGBColor[
             0.1878121680467173, 0.3147328749692917, 0.9340069971758325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 180}], {
             RGBColor[
             0.18558731783868732`, 0.3123944163370016, 0.933880295247856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 232}], {
             RGBColor[
             0.18655512715268852`, 0.3134116452886715, 0.9339354105565427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 249}], {
             RGBColor[
             0.18318613987214505`, 0.3098706260506894, 0.9337435517148859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 370}], {
             RGBColor[
             0.18414849826566793`, 0.3108821257393283, 0.9337983566017154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 111}], {
             RGBColor[
             0.8353956126881364, 0.4322362455432418, 0.4440238905091144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 117}], {
             RGBColor[
             0.7057471364084966, 0.7690367194392469, 0.9721131675946504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 202}], {
             RGBColor[
             0.590277084299675, 0.6718791600205865, 0.9639661767270546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 212}], {
             RGBColor[
             0.715371093239261, 0.7768498811487758, 0.9728708007300837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 239}], {
             RGBColor[
             0.6800499902731076, 0.7481746185632971, 0.9700901941191247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 247}], {
             RGBColor[
             0.8292133862002847, 0.38471694368869236`, 0.43810378344252143`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 269}], {
             RGBColor[
             0.6031830035578256, 0.6830576186116337, 0.9647885304899277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 287}], {
             RGBColor[
             0.8292002229414056, 0.38461576511277085`, 0.438091178290953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 289}], {
             RGBColor[
             0.6635885313279589, 0.7348104646113509, 0.9687942877706517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 292}], {
             RGBColor[
             0.8306488126751848, 0.39575026058266666`, 0.4394783494559681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 303}], {
             RGBColor[
             0.873446363467674, 0.7484181435664192, 0.6095212570798225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 309}], {
             RGBColor[
             0.7751646817101416, 0.8245503622153614, 0.9781540938970312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 362}], {
             RGBColor[
             0.8221167873663267, 0.8612297040031928, 0.982833840996466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 385}], {
             RGBColor[
             0.923690126192328, 0.9380306979900004, 0.809802069993292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 400}], {
             RGBColor[
             0.832397701814092, 0.40919298887241484`, 0.44115308767047345`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 199}], {
             RGBColor[
             0.8806533072058972, 0.4669084665562061, 0.39419180030170453`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 222}], {
             RGBColor[
             0.8681038869231676, 0.45805238435921003`, 0.4379714781522483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 223}], {
             RGBColor[
             0.8374801650249903, 0.28824382747239297`, 0.1834910422728131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 247}], {
             RGBColor[
             0.8235209713761704, 0.1817980697184317, 0.17015701479394557`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 271}], {
             RGBColor[
             0.8244089740108874, 0.1886236470941021, 0.17100736711980608`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 287}], {
             RGBColor[
             0.8235143897467309, 0.18174748043047098`, 0.17015071221816136`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 292}], {
             RGBColor[
             0.8242386846136205, 0.1873147281654189, 0.1708442978006689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 309}], {
             RGBColor[
             0.7835302879454197, 0.39154095679460776`, 0.43890159652522914`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 319}], {
             RGBColor[
             0.8285561841710127, 0.22050092170390542`, 0.174978740252746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 362}], {
             RGBColor[
             0.8148316917162097, 0.4159938513198287, 0.44202142792485233`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 385}], {
             RGBColor[
             0.882547250933544, 0.4671945139777004, 0.32666691392273633`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[
             0.8251131291830741, 0.19403609231029295`, 0.17168166690792155`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 177}], {
             RGBColor[
             0.18091855533538903`, 0.3074872509293952, 0.9336144161301083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 219}], {
             RGBColor[
             0.17968380010062157`, 0.30618944488965105`, 0.933544098646145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 248}], {
             RGBColor[
             0.18167669359362687`, 0.3082841023075451, 0.9336575909823499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 251}], {
             RGBColor[
             0.18268323345773074`, 0.30934203952303163`, 0.9337149119385684]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 260}], {
             RGBColor[
             0.18468581634927816`, 0.3114468811131368, 0.9338289560716861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 162}], {
             RGBColor[
             0.19047273002269705`, 0.31752929429541876`, 0.9341585122444157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 183}], {
             RGBColor[
             0.18716623928349274`, 0.31405396288489373`, 0.9339702124883327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 270}], {
             RGBColor[
             0.196796775846464, 0.3241762674238618, 0.9345186572984918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 357}], {
             RGBColor[
             0.18582607626581804`, 0.31264536658207454`, 0.9338938921870696]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 368}], {
             RGBColor[
             0.18474082389280244`, 0.3115046975290605, 0.9338320886699134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 132}], {
             RGBColor[
             0.1897759122485969, 0.31679689463404087`, 0.9341188295030303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 155}], {
             RGBColor[
             0.18628873221551898`, 0.3131316473192917, 0.933920239758967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 180}], {
             RGBColor[
             0.18755106204056693`, 0.3144584360017507, 0.9339921275750538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 249}], {
             RGBColor[
             0.18514988407402466`, 0.3119346457154385, 0.9338553840420838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 268}], {
             RGBColor[
             0.18716896902427724`, 0.3140568320155338, 0.9339703679430321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 279}], {
             RGBColor[
             0.19285735565451845`, 0.32003568702846064`, 0.9342943131464105]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 299}], {
             RGBColor[
             0.1875337477163088, 0.31444023754916384`, 0.9339911415499016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 300}], {
             RGBColor[
             0.19141939910096473`, 0.3185243035189643, 0.9342124236479517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 370}], {
             RGBColor[
             0.18611224246754757`, 0.3129461454040774, 0.9339101889289132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 123}], {
             RGBColor[
             0.8804744990263506, 0.5083985248696827, 0.22021983203269263`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 161}], {
             RGBColor[
             0.9173271064366133, 0.7028272968686928, 0.25196989849468676`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 193}], {
             RGBColor[
             0.8965180032601808, 0.866664933881647, 0.6335702357029284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 195}], {
             RGBColor[
             0.6898630728334411, 0.7009647207638414, 0.6155071113240207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 214}], {
             RGBColor[
             0.917014626987943, 0.7014084006737106, 0.2517091579831441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 253}], {
             RGBColor[
             0.8684975552193938, 0.416338486439171, 0.2087506971171275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 257}], {
             RGBColor[
             0.9622640683610495, 0.9182194829930534, 0.6096923191590835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 283}], {
             RGBColor[
             0.9435152073287729, 0.813763650039597, 0.2734092138294835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 312}], {
             RGBColor[
             0.7514622050621471, 0.7517529361696669, 0.6201411074573389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 332}], {
             RGBColor[
             0.8635725695202401, 0.3784828882129811, 0.20403452524964213`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 334}], {
             RGBColor[
             0.9576597296930937, 0.8685855926092536, 0.2913334520501617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 356}], {
             RGBColor[
             0.9502457162134885, 0.9092562156396481, 0.6300362544566458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 360}], {
             RGBColor[
             0.8089316906478522, 0.7980968050279984, 0.6248789386336926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 364}], {
             RGBColor[
             0.9382231077008898, 0.7927822385027005, 0.26915106624734497`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 366}], {
             RGBColor[
             0.9742039651565302, 0.9239012646538212, 0.3974339190185809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 380}], {
             RGBColor[
             0.8377450255090341, 0.8206060012110092, 0.627750782576732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 389}], {
             RGBColor[
             0.9741155744429982, 0.9237122058552483, 0.3878131353348738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 141}], {
             RGBColor[
             0.29789401265983945`, 0.4260884769462017, 0.9404351748499746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 179}], {
             RGBColor[
             0.23341719737643146`, 0.3626666523206874, 0.9366041361295647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 209}], {
             RGBColor[
             0.2525333735524159, 0.38275896551722044`, 0.9376927740829386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 286}], {
             RGBColor[
             0.28063230469456346`, 0.41113725310534854`, 0.9393352740823563]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 290}], {
             RGBColor[
             0.24877546734729164`, 0.3788091678306199, 0.9374787668838809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 304}], {
             RGBColor[
             0.26114585574207083`, 0.3918112303614577, 0.938183242202614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 338}], {
             RGBColor[
             0.22507866009155236`, 0.35390232094047974`, 0.9361292687669514]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 239}], {
             RGBColor[
             0.5328344578573876, 0.6316180426642315, 0.9563658268409162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 269}], {
             RGBColor[
             0.45596747114210545`, 0.5665010427125681, 0.9510641632117192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 309}], {
             RGBColor[
             0.6279491492944215, 0.7079937863162957, 0.9644297266188226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 323}], {
             RGBColor[
             0.4895767347577772, 0.5956116976057565, 0.9532057157698048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 362}], {
             RGBColor[
             0.6749012549506066, 0.7446731281041272, 0.9691094737182575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 365}], {
             RGBColor[
             0.4322742926857367, 0.5457268859697086, 0.94956369337159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 377}], {
             RGBColor[
             0.40661285819624315`, 0.5187550912923315, 0.9481023126401036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 385}], {
             RGBColor[
             0.776474593776608, 0.8214741220909348, 0.7960777027150834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 388}], {
             RGBColor[
             0.4146565458770389, 0.527209517044103, 0.9485603887539554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 395}], {
             RGBColor[
             0.49860624010091514`, 0.6034326012978481, 0.9537810678657916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 124}], {
             RGBColor[
             0.29203302591126107`, 0.41977282835890883`, 0.9401070895447208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[
             0.35660710592589273`, 0.4832968843838794, 0.9439436673476838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 150}], {
             RGBColor[
             0.29792702653421543`, 0.4259677967148573, 0.9404427441608055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 179}], {
             RGBColor[
             0.29213029064248475`, 0.4198750597583651, 0.9401126286272736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 196}], {
             RGBColor[
             0.6007859963931654, 0.6812853787799371, 0.9644958808837701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 206}], {
             RGBColor[
             0.39316789594043106`, 0.5149640030957358, 0.9462732885579729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 209}], {
             RGBColor[
             0.3112464668184692, 0.43996737295489813`, 0.9412012665806477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 286}], {
             RGBColor[
             0.33934539796061675`, 0.46834566054302623`, 0.9428437665800653]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 386}], {
             RGBColor[
             0.34968714140668505`, 0.4773031589248714, 0.9435027333276041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 128}], {
             RGBColor[
             0.2718458799395796, 0.4030576342137573, 0.9387925927513947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 130}], {
             RGBColor[
             0.2277266187202509, 0.3566854933495158, 0.936280066093552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 135}], {
             RGBColor[
             0.2875725376828968, 0.4171271414972289, 0.9397782828791128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 146}], {
             RGBColor[
             0.2194595639056427, 0.3479962945778132, 0.9358092695518716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 151}], {
             RGBColor[
             0.22370106658388367`, 0.35245438281944674`, 0.9360508168546565]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 213}], {
             RGBColor[
             0.2826015926364835, 0.4128215587449884, 0.9394615386563896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 227}], {
             RGBColor[
             0.25689083303762017`, 0.3873389317150586, 0.9379409249543373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 243}], {
             RGBColor[
             0.23559188807996673`, 0.3649523901334573, 0.9367279815479644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 267}], {
             RGBColor[
             0.21867692760035795`, 0.34717369419895117`, 0.9357646995720923]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 306}], {
             RGBColor[
             0.2310448890646134, 0.36017320587193224`, 0.9364690366807222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 311}], {
             RGBColor[
             0.22119300122602184`, 0.3498182471078057, 0.9359079862428765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 344}], {
             RGBColor[
             0.2156761634002051, 0.3440197007651513, 0.9355938104901265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 346}], {
             RGBColor[
             0.2216080062797242, 0.35025444373208703`, 0.9359316201667398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 350}], {
             RGBColor[
             0.2941675459212899, 0.42283940615857285`, 0.9401985109723265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 354}], {
             RGBColor[
             0.21794551615801888`, 0.3464049343988889, 0.9357230467724773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 140}], {
             RGBColor[
             0.409447183861318, 0.5290643040720063, 0.9473105903890827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 147}], {
             RGBColor[
             0.3298813986080268, 0.4544594666479659, 0.9424490293594527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 193}], {
             RGBColor[
             0.6252379224927019, 0.7026774950776031, 0.9659558403883122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 195}], {
             RGBColor[
             0.41858299206596217`, 0.5369772819597975, 0.9478927160094046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 241}], {
             RGBColor[
             0.34672955885014695`, 0.4721679512974918, 0.9434085071606221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 242}], {
             RGBColor[
             0.3764731339021319, 0.500503839321299, 0.9452095130834909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 255}], {
             RGBColor[
             0.39336824955180094`, 0.5151375393238391, 0.9462860549129236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 263}], {
             RGBColor[
             0.3571898835204337, 0.4831624157488532, 0.9440042071759314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 312}], {
             RGBColor[
             0.4801821242946682, 0.587765497365623, 0.9525267121427227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 331}], {
             RGBColor[
             0.3267582826576653, 0.45117687376714777`, 0.9422711725263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 356}], {
             RGBColor[
             0.6789656354460096, 0.7452687768356042, 0.9624218591420297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 359}], {
             RGBColor[
             0.3691186833876108, 0.4941337839310517, 0.9447408939999908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 360}], {
             RGBColor[
             0.5376516098803733, 0.6341093662239545, 0.9572645433190765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 380}], {
             RGBColor[
             0.5664649447415552, 0.6566185624069654, 0.9601363872621158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 389}], {
             RGBColor[
             0.7028354936755193, 0.7597247670512044, 0.7201987400202577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[
             0.2188856606362972, 0.3473930858541622, 0.9357765866096961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 202}], {
             RGBColor[
             0.2856578369982738, 0.41583248159385067`, 0.9396429608971655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 234}], {
             RGBColor[
             0.2453302072944222, 0.37518798107295015`, 0.9372825644206755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 289}], {
             RGBColor[
             0.3589692840265578, 0.4787637861846151, 0.9444710719407625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 298}], {
             RGBColor[
             0.2245949434093795, 0.353393904038107, 0.9361017218174963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 173}], {
             RGBColor[
             0.18447873947082444`, 0.3112292301844495, 0.9338171633498009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 338}], {
             RGBColor[
             0.19975108063826336`, 0.32728142907378543`, 0.9346869005858826]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 161}], {
             RGBColor[
             0.8552873220803263, 0.4038002548740027, 0.1997084684807382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 196}], {
             RGBColor[
             0.8434800761859853, 0.5146723115221958, 0.4543057015240267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 214}], {
             RGBColor[
             0.8550790024478794, 0.40285432407734784`, 0.1995346414730431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 253}], {
             RGBColor[
             0.8371693407082226, 0.2867054171581618, 0.18322670867994717`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 283}], {
             RGBColor[
             0.8727460560084327, 0.47775782365460545`, 0.2140013453706027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 332}], {
             RGBColor[
             0.8347068478586457, 0.26777761804506683`, 0.1808686227462045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 334}], {
             RGBColor[
             0.8821757375846465, 0.51430578536771, 0.2259508375177215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 356}], {
             RGBColor[
             0.8772330619315765, 0.5414195340546395, 0.45175270578871085`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 364}], {
             RGBColor[
             0.869217989589844, 0.4637702159633411, 0.2111625803158437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 366}], {
             RGBColor[
             0.8932052278936042, 0.5511829000640883, 0.29668448216333426`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 389}], {
             RGBColor[
             0.8931463007512496, 0.5510568608650397, 0.29027062637419626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 150}], {
             RGBColor[
             0.2325126629936997, 0.36171592933364405`, 0.9365526242346068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 152}], {
             RGBColor[
             0.2137312689052459, 0.34197549333751603`, 0.935483051625852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 156}], {
             RGBColor[
             0.21424517968646528`, 0.3425156461524031, 0.9355123180845796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 157}], {
             RGBColor[
             0.2367400113323198, 0.3661591404668991, 0.9367933654686897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 160}], {
             RGBColor[
             0.21095706740892387`, 0.3390596316703475, 0.9353250649546998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 167}], {
             RGBColor[
             0.23121257205082407`, 0.360349451322155, 0.9364785859787222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 179}], {
             RGBColor[
             0.22671592710196903`, 0.3556231923771518, 0.9362225087010749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 181}], {
             RGBColor[
             0.209370470104526, 0.33739201730734614`, 0.9352347105853747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 238}], {
             RGBColor[
             0.21375043106969976`, 0.3419956339873084, 0.9354841428827698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 245}], {
             RGBColor[
             0.21075638483913717`, 0.33884870156549185`, 0.9353136363792337]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 386}], {
             RGBColor[
             0.28427277786616933`, 0.41305129154365816`, 0.9396126134014054]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 184}], {
             RGBColor[
             0.20307558723579205`, 0.3307756962936808, 0.934876226318445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 185}], {
             RGBColor[
             0.1925739180479394, 0.31973777613296384`, 0.9342781717940241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 190}], {
             RGBColor[
             0.20237543357367466`, 0.3300397904024893, 0.934836353603172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 226}], {
             RGBColor[
             0.1922514050569324, 0.3193987945309108, 0.9342598051563016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 252}], {
             RGBColor[
             0.19926974690677848`, 0.32677551680367367`, 0.934659489341944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 274}], {
             RGBColor[
             0.19786901158433057`, 0.32530325516803194`, 0.9345797195375327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 288}], {
             RGBColor[
             0.2031660717843796, 0.3308708012912981, 0.9348813792796271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 318}], {
             RGBColor[
             0.20302734583193666`, 0.33072499151954715`, 0.9348734790418622]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 176}], {
             RGBColor[
             0.18438193895865332`, 0.3111274867086507, 0.9338116507038363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 205}], {
             RGBColor[
             0.18385657240612066`, 0.31057529315177557`, 0.9337817318558796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 298}], {
             RGBColor[
             0.194012535572622, 0.32124985436502457`, 0.9343600989338109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 320}], {
             RGBColor[
             0.18313368370358218`, 0.3098154912916167, 0.9337405644136882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 347}], {
             RGBColor[
             0.18344187738111917`, 0.31013942238731573`, 0.9337581155876922]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 373}], {
             RGBColor[
             0.19027225530167013`, 0.317318582652788, 0.934147095505629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 137}], {
             RGBColor[
             0.31600670483300364`, 0.4466421785419929, 0.9414111535240912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 138}], {
             RGBColor[
             0.31413697275722113`, 0.44467697158248487`, 0.9413046750483962]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 193}], {
             RGBColor[
             0.5886484429999097, 0.6709855269816585, 0.9636243911098379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 210}], {
             RGBColor[
             0.29252473138981117`, 0.4219611356100898, 0.9400738898749681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 242}], {
             RGBColor[
             0.33988365440933965`, 0.4688118712253543, 0.9428780638050165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 255}], {
             RGBColor[
             0.35677877005900877`, 0.4834455712278943, 0.9439546056344492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 258}], {
             RGBColor[
             0.2885106861095953, 0.4177421195154126, 0.9398452959345076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 264}], {
             RGBColor[
             0.2996738393944105, 0.42947530140255136`, 0.9404810209996725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 312}], {
             RGBColor[
             0.44359264480187605`, 0.5560735292696781, 0.9501952628642483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 328}], {
             RGBColor[
             0.2853602010040631, 0.41443075991720546`, 0.9396658804684725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 331}], {
             RGBColor[
             0.29016880316487315`, 0.419484905671203, 0.9399397232478413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 380}], {
             RGBColor[
             0.529875465248763, 0.6249265943110206, 0.9578049379836415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 394}], {
             RGBColor[
             0.348496932711213, 0.47627225997448197`, 0.9434268942819889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 130}], {
             RGBColor[
             0.2597826750311079, 0.39037844100358665`, 0.9381056110777697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 135}], {
             RGBColor[
             0.31962859399375376`, 0.45082008915129973`, 0.9416038278633306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 139}], {
             RGBColor[
             0.3054227451460619, 0.43834904844198347`, 0.9407047455523833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 151}], {
             RGBColor[
             0.2557571228947407, 0.38614733047351757`, 0.9378763618388744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 213}], {
             RGBColor[
             0.3146576489473405, 0.4465145063990592, 0.9412870836406073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 215}], {
             RGBColor[
             0.5049864538136, 0.6035289290681363, 0.9559781758101122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 224}], {
             RGBColor[
             0.40082474260241224`, 0.5199417456186857, 0.9471108972900512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 227}], {
             RGBColor[
             0.28894688934847723`, 0.42103187936912945`, 0.9397664699385552]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 243}], {
             RGBColor[
             0.26764794439082373`, 0.39864533778752814`, 0.9385535265321823]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 259}], {
             RGBColor[
             0.599663278641086, 0.6781009426487141, 0.9652528657581285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 306}], {
             RGBColor[
             0.2631009453754704, 0.39386615352600307`, 0.9382945816649401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 350}], {
             RGBColor[
             0.32622360223214686`, 0.4565323538126437, 0.9420240559565443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 383}], {
             RGBColor[
             0.3311097462205182, 0.46076448615063337`, 0.9423353967308358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 131}], {
             RGBColor[
             0.8175944103377895, 0.3846574917741582, 0.4381352993196086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 253}], {
             RGBColor[
             0.8212882402079674, 0.16463631957058764`, 0.16801894890576527`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 271}], {
             RGBColor[
             0.8195583588383687, 0.15133969332500205`, 0.16636241255261597`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 287}], {
             RGBColor[
             0.8186637745742122, 0.14446352666137094`, 0.16550575765097125`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 303}], {
             RGBColor[
             0.8442007939445894, 0.3035021905928796, 0.18850141741323326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 333}], {
             RGBColor[
             0.8641496188044945, 0.42143692475523437`, 0.4318092418276507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 337}], {
             RGBColor[
             0.8652171818184992, 0.4222331115031051, 0.43000213610996785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 353}], {
             RGBColor[
             0.8773107079453166, 0.4290850996340871, 0.28001609828605356`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 364}], {
             RGBColor[
             0.8533368890895888, 0.341701118375767, 0.1959548205416618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 391}], {
             RGBColor[
             0.8196355123081763, 0.15193272870280924`, 0.16643629480243607`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 135}], {
             RGBColor[
             0.27550933277442513`, 0.40444794828705827`, 0.9390913012054878]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 146}], {
             RGBColor[
             0.20739635899717102`, 0.3353171013676426, 0.9351222878782466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 151}], {
             RGBColor[
             0.211637861675412, 0.3397751896092761, 0.9353638351810314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 158}], {
             RGBColor[
             0.20340188077088672`, 0.3311186514872704, 0.9348948082525605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 227}], {
             RGBColor[
             0.24482762812914852`, 0.374659738504888, 0.9372539432807123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 243}], {
             RGBColor[
             0.22352868317149505`, 0.3522731969232867, 0.9360409998743393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 267}], {
             RGBColor[
             0.20661372269188627`, 0.33449450098878053`, 0.9350777178984673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 275}], {
             RGBColor[
             0.2049038205781411, 0.33269728545317867`, 0.934980341502663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 306}], {
             RGBColor[
             0.21898168415614172`, 0.3474940126617616, 0.9357820550070972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 311}], {
             RGBColor[
             0.20912979631755016`, 0.33713905389763504`, 0.9352210045692514]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 317}], {
             RGBColor[
             0.20208377375464914`, 0.3297332374403929, 0.9348197440079504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 344}], {
             RGBColor[
             0.20361295849173341`, 0.3313405075549807, 0.9349068288165013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 346}], {
             RGBColor[
             0.20954480137125253`, 0.3375752505219164, 0.9352446384931148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 354}], {
             RGBColor[
             0.2058823112495472, 0.3337257411887183, 0.9350360650988523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 142}], {
             RGBColor[
             0.6441352636384634, 0.7193460306737178, 0.9669266768382974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 201}], {
             RGBColor[
             0.7399124857733206, 0.7967445245200704, 0.9747112197727283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 273}], {
             RGBColor[
             0.6690783888345512, 0.7395959833828867, 0.9688902910234116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 281}], {
             RGBColor[
             0.6064310569728814, 0.687254440774864, 0.9643678385927457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 293}], {
             RGBColor[
             0.5641203291112874, 0.6506070149001673, 0.9616718364273125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 303}], {
             RGBColor[
             0.8540204827009316, 0.7329759435664439, 0.607655802146349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 391}], {
             RGBColor[
             0.8181931112315055, 0.3892593691956639, 0.4387086159715671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 394}], {
             RGBColor[
             0.585868010689025, 0.6694437636125451, 0.9630575794667262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 149}], {
             RGBColor[
             0.20160011613108555`, 0.32922488261236305`, 0.9347922004217959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 155}], {
             RGBColor[
             0.18938684794258642`, 0.3163879633803221, 0.934096672866372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 180}], {
             RGBColor[
             0.1906491777676344, 0.3177147520627811, 0.9341685606824588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 249}], {
             RGBColor[
             0.18824799980109214`, 0.3151909617764689, 0.9340318171494888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 268}], {
             RGBColor[
             0.19026708475134468`, 0.3173131480765642, 0.9341468010504371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 279}], {
             RGBColor[
             0.1959554713815859, 0.323292003089491, 0.9344707462538155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 299}], {
             RGBColor[
             0.19063186344337624`, 0.3176965536101942, 0.9341675746573066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 300}], {
             RGBColor[
             0.1945175148280322, 0.3217806195799947, 0.9343888567553567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 370}], {
             RGBColor[
             0.189210358194615, 0.3162024614651078, 0.9340866220363182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 178}], {
             RGBColor[
             0.18320632976714918`, 0.309891846910452, 0.9337447014995381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 200}], {
             RGBColor[
             0.18872606349581567`, 0.31569343703061226`, 0.9340590421696713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 278}], {
             RGBColor[
             0.18574944160901402`, 0.31256481869885566`, 0.9338895279567354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 296}], {
             RGBColor[
             0.18124069831826523`, 0.30782584362944293`, 0.9336327616964153]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 320}], {
             RGBColor[
             0.18355649439985816`, 0.3102598921411492, 0.9337646428573487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 330}], {
             RGBColor[
             0.1860526851696524, 0.3128835469078388, 0.9339067972289052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 347}], {
             RGBColor[
             0.18386468807739512`, 0.3105838232368483, 0.9337821940313528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 367}], {
             RGBColor[
             0.18474901765317286`, 0.31151330969072427`, 0.9338325552924449]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 398}], {
             RGBColor[
             0.18210607446438823`, 0.30873540882703493`, 0.9336820435877278]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 163}], {
             RGBColor[
             0.17908461226291875`, 0.3055596604815222, 0.9335099757852068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 171}], {
             RGBColor[
             0.18358417843459812`, 0.31028898981693004`, 0.9337662194221723]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 240}], {
             RGBColor[
             0.17922390736570504`, 0.3057060684663703, 0.9335179084352418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 272}], {
             RGBColor[
             0.18788317693480855`, 0.3148075098128992, 0.9340110410269609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 342}], {
             RGBColor[
             0.18275455563161122`, 0.309417003649867, 0.9337189736308591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 374}], {
             RGBColor[
             0.18137577945827954`, 0.307967822472237, 0.9336404543675045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 213}], {
             RGBColor[
             0.33038430669065766`, 0.46058401368253077`, 0.9422727737683254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 215}], {
             RGBColor[
             0.5207131115569171, 0.6175984363516078, 0.9569638659378303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 224}], {
             RGBColor[
             0.41655140034572946`, 0.5340112529021572, 0.9480965874177693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 227}], {
             RGBColor[
             0.3046735470917944, 0.4351013866526011, 0.9407521600662733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 243}], {
             RGBColor[
             0.2833746021341409, 0.41271484507099976`, 0.9395392166599004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 259}], {
             RGBColor[
             0.6153899363844033, 0.6921704499321857, 0.9662385558858466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 350}], {
             RGBColor[
             0.3419502599754641, 0.47060186109611535`, 0.9430097460842624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 363}], {
             RGBColor[
             0.3549405295448861, 0.4818533796872159, 0.9438374745743816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 383}], {
             RGBColor[
             0.3468364039638354, 0.47483399343410504`, 0.9433210868585539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 393}], {
             RGBColor[
             0.5286635054610748, 0.6238093444947674, 0.9577562869015417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 149}], {
             RGBColor[
             0.19648120536399588`, 0.3238445828384636, 0.9345006860263599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 155}], {
             RGBColor[
             0.18426793717549678`, 0.3110076636064226, 0.933805158470936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 268}], {
             RGBColor[
             0.18514817398425504`, 0.3119328483026647, 0.9338552866550012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 279}], {
             RGBColor[
             0.19083656061449622`, 0.3179117033155916, 0.9341792318583795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 299}], {
             RGBColor[
             0.1855129526762866, 0.3123162538362948, 0.9338760602618706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 300}], {
             RGBColor[
             0.18939860406094253`, 0.3164003198060953, 0.9340973423599207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 371}], {
             RGBColor[
             0.1813347042579621, 0.3079246498323852, 0.9336381151956117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 138}], {
             RGBColor[
             0.29077492625511725`, 0.4229532620622423, 0.93987057393605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 164}], {
             RGBColor[
             0.2538187120761361, 0.3841099378008197, 0.9377659722103766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 210}], {
             RGBColor[
             0.2691626848877073, 0.40023742608984725`, 0.9386397887626219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 230}], {
             RGBColor[
             0.2568850160495337, 0.38733281769176137`, 0.9379405936854713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 242}], {
             RGBColor[
             0.31652160790723577`, 0.4470881617051118, 0.9414439626926704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 258}], {
             RGBColor[
             0.2651486396074914, 0.3960184099951701, 0.9384111948221615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 264}], {
             RGBColor[
             0.27631179289230656`, 0.4077515918823088, 0.9390469198873264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 328}], {
             RGBColor[
             0.2619981545019592, 0.39270705039696285`, 0.9382317793561266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 394}], {
             RGBColor[
             0.32513488620910913`, 0.45454855045423936`, 0.9419927931696428]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 149}], {
             RGBColor[
             0.2496156992329207, 0.3796923048161946, 0.9375266168467558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 164}], {
             RGBColor[
             0.2519489800003536, 0.38214473084131173`, 0.9376594937346815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 210}], {
             RGBColor[
             0.2672929528119248, 0.3982722191303392, 0.9385333102869269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 230}], {
             RGBColor[
             0.2550152839737512, 0.38536761073225334`, 0.9378341152097762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 242}], {
             RGBColor[
             0.31465187583145326`, 0.4451229547456037, 0.9413374842169753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 258}], {
             RGBColor[
             0.26327890753170885`, 0.39405320303566205`, 0.9383047163464664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 264}], {
             RGBColor[
             0.27444206081652406`, 0.4057863849228008, 0.9389404414116314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 281}], {
             RGBColor[
             0.3438282004171828, 0.4703940206570502, 0.9431965738199672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 328}], {
             RGBColor[
             0.2601284224261766, 0.3907418434374549, 0.9381253008804314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 394}], {
             RGBColor[
             0.32326515413332657`, 0.4525833434947314, 0.9418863146939478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 186}], {
             RGBColor[
             0.2567623305791477, 0.38720386748367763`, 0.9379336069294297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 213}], {
             RGBColor[
             0.3161784578429658, 0.4481129729732145, 0.941373691457378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 215}], {
             RGBColor[
             0.5065072627092252, 0.6051273956422916, 0.956064783626883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 306}], {
             RGBColor[
             0.2646217542710957, 0.39546462010015837`, 0.9383811894817108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 308}], {
             RGBColor[
             0.25989565930435055`, 0.3904971946383813, 0.9381120453649856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 345}], {
             RGBColor[
             0.5675136417908162, 0.652851509744995, 0.962127956401694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 350}], {
             RGBColor[
             0.3277444111277722, 0.4581308203867991, 0.942110663773315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 378}], {
             RGBColor[
             0.27359029407982893`, 0.40489112407740385`, 0.9388919345560525]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 147}], {
             RGBColor[
             0.32678087214865287`, 0.45177394646584723`, 0.9422514665551494]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 193}], {
             RGBColor[
             0.6221373960333281, 0.6999919748954846, 0.9657582775840088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 195}], {
             RGBColor[
             0.4154824656065883, 0.5342917617776789, 0.9476951532051012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 241}], {
             RGBColor[
             0.343629032390773, 0.46948243111537313`, 0.9432109443563187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 242}], {
             RGBColor[
             0.3733726074427579, 0.4978183191391804, 0.9450119502791875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 255}], {
             RGBColor[
             0.390267723092427, 0.5124520191417203, 0.9460884921086202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 263}], {
             RGBColor[
             0.35408935706105976`, 0.48047689556673456`, 0.943806644371628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 312}], {
             RGBColor[
             0.4770815978352943, 0.5850799771835042, 0.9523291493384193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 331}], {
             RGBColor[
             0.3236577561982914, 0.4484913535850291, 0.9420736097220124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 356}], {
             RGBColor[
             0.6758651089866358, 0.7425832566534856, 0.9622242963377263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 359}], {
             RGBColor[
             0.36601815692823686`, 0.491448263748933, 0.9445433311956875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 360}], {
             RGBColor[
             0.5345510834209994, 0.6314238460418358, 0.9570669805147731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 380}], {
             RGBColor[
             0.5633644182821813, 0.6539330422248467, 0.9599388244578124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 389}], {
             RGBColor[
             0.6997349672161455, 0.7570392468690857, 0.7200011772159544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 179}], {
             RGBColor[
             0.2912900071166007, 0.41914724840212236`, 0.9400590865040379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 196}], {
             RGBColor[
             0.5999457128672814, 0.6805575674236943, 0.9644423387605343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 209}], {
             RGBColor[
             0.3104061832925851, 0.4392395615986554, 0.9411477244574119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 286}], {
             RGBColor[
             0.3385051144347327, 0.4676178491867835, 0.9427902244568296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 290}], {
             RGBColor[
             0.3066482770874609, 0.4352897639120549, 0.9409337172583541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 304}], {
             RGBColor[
             0.31901866548224, 0.4482918264428926, 0.9416381925770871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 386}], {
             RGBColor[
             0.348846857880801, 0.4765753475686286, 0.9434491912043683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.37498442055197767`, 0.49560326154572176`, 0.9453825139194686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 201}], {
             RGBColor[
             0.5699368421210522, 0.6613816598554264, 0.9595312716051138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 273}], {
             RGBColor[
             0.4991027451822828, 0.6042331187182427, 0.9537103428557971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 281}], {
             RGBColor[
             0.436455413320613, 0.55189157611022, 0.9491878904251312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 293}], {
             RGBColor[
             0.3941446854590191, 0.5152441502355233, 0.946491888259698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 394}], {
             RGBColor[
             0.4158923670367568, 0.5340808989479011, 0.9478776312991117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 151}], {
             RGBColor[
             0.2032578843654731, 0.3309673021352812, 0.934886607870296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 158}], {
             RGBColor[
             0.1950219034609478, 0.3223107640132754, 0.9344175809418251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 171}], {
             RGBColor[
             0.19347840745274208`, 0.320688451845352, 0.9343296811275554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 186}], {
             RGBColor[
             0.20274228315425485`, 0.3304253725712859, 0.9348572451440806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 272}], {
             RGBColor[
             0.19777740595295248`, 0.3252069718413211, 0.9345745027323441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 306}], {
             RGBColor[
             0.21060170684620283`, 0.33868612518776664`, 0.9353048276963617]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 308}], {
             RGBColor[
             0.2058756118794577, 0.33371869972598955`, 0.9350356835796365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 342}], {
             RGBColor[
             0.19264878464975516`, 0.3198164656782889, 0.9342824353362423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 348}], {
             RGBColor[
             0.20000377872339242`, 0.3275470307832401, 0.9347012913679973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 354}], {
             RGBColor[
             0.1975023339396083, 0.32491785371472337`, 0.9345588377881168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 374}], {
             RGBColor[
             0.1912700084764235, 0.3183672845006589, 0.9342039160728877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 378}], {
             RGBColor[
             0.21957024665493602`, 0.3481126291650121, 0.9358155727707034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 148}], {
             RGBColor[
             0.41890511783186646`, 0.5289568419765102, 0.9490497655266936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 169}], {
             RGBColor[
             0.5192579762174159, 0.6205960432553745, 0.9552970364739267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 218}], {
             RGBColor[
             0.5707667888209911, 0.662413217772521, 0.9593519988850778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 222}], {
             RGBColor[
             0.7661723613566251, 0.8169857716290115, 0.9639290713689532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 276}], {
             RGBColor[
             0.48015124453344243`, 0.5868307576532874, 0.952775625742377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 282}], {
             RGBColor[
             0.44814038646858245`, 0.5591045613100133, 0.9507359221725744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 305}], {
             RGBColor[
             0.4396583364184836, 0.550769790541102, 0.9502316306235659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 339}], {
             RGBColor[
             0.48160738498318656`, 0.5880919933231088, 0.9528684097242202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 361}], {
             RGBColor[
             0.4954156444114053, 0.6000520136165334, 0.9537482598048219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 382}], {
             RGBColor[
             0.451676599366216, 0.5621674511867154, 0.9509612465314614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 384}], {
             RGBColor[
             0.757420984754537, 0.7226612405223014, 0.6127983851533676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 165}], {
             RGBColor[
             0.23770682741222313`, 0.3671753254665574, 0.9368484242141641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 170}], {
             RGBColor[
             0.24268853638713495`, 0.37241141745778183`, 0.9371321251705074]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 182}], {
             RGBColor[
             0.24585035887698375`, 0.3757346933657375, 0.937312186283807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 192}], {
             RGBColor[
             0.25406976709764434`, 0.3843738125462326, 0.9377802694224489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 208}], {
             RGBColor[
             0.2721455459278671, 0.4033726021673685, 0.9388096582861116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 221}], {
             RGBColor[
             0.3098924284635012, 0.43739177601044266`, 0.941166351723109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 225}], {
             RGBColor[
             0.22917757181567264`, 0.3582105370485437, 0.9363626957258434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 235}], {
             RGBColor[
             0.22156110310920424`, 0.35020514552603776`, 0.9359289491005658]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 335}], {
             RGBColor[
             0.2240686969525251, 0.3528407856460005, 0.9360717528602902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 349}], {
             RGBColor[
             0.2241439081408365, 0.35291983737358057`, 0.9360760360261996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 351}], {
             RGBColor[
             0.2797139568415439, 0.4112527007055903, 0.9392434061971325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 355}], {
             RGBColor[
             0.22900678342998865`, 0.3580310276265808, 0.9363529695799375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 395}], {
             RGBColor[
             0.3442769835307749, 0.46717394939172724`, 0.9433573051669275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 151}], {
             RGBColor[
             0.20337080686080378`, 0.3310859908375735, 0.9348930386393511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 158}], {
             RGBColor[
             0.1951348259562785, 0.3224294527155677, 0.9344240117108803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 227}], {
             RGBColor[
             0.2365605733145403, 0.3659705397331854, 0.936783146739032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 243}], {
             RGBColor[
             0.21526162835688684`, 0.343583998151584, 0.9355702033326591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 267}], {
             RGBColor[
             0.19834666787727806`, 0.32580530221707793`, 0.9346069213567869]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 275}], {
             RGBColor[
             0.1966367657635329, 0.324008086681476, 0.9345095449609826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 306}], {
             RGBColor[
             0.2107146293415335, 0.33880481389005895`, 0.9353112584654169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 311}], {
             RGBColor[
             0.20086274150294195`, 0.3284498551259324, 0.9347502080275711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 317}], {
             RGBColor[
             0.19381671894004093`, 0.32104403866869025`, 0.9343489474662702]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 344}], {
             RGBColor[
             0.1953459036771252, 0.3226513087832781, 0.9344360322748211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 346}], {
             RGBColor[
             0.20127774655664432`, 0.3288860517502138, 0.9347738419514344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 354}], {
             RGBColor[
             0.197615256434939, 0.32503654241701563`, 0.9345652685571719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 195}], {
             RGBColor[
             0.3359166803532971, 0.45968692435363845`, 0.9428335921754714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 217}], {
             RGBColor[
             0.2277310230294914, 0.3566901225577769, 0.9362803169124476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 231}], {
             RGBColor[
             0.2192108871052112, 0.34773491949353985`, 0.9357951077759714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 241}], {
             RGBColor[
             0.2640632471374818, 0.3948775936913327, 0.9383493833266887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 242}], {
             RGBColor[
             0.29380682218946674`, 0.42321348171513995`, 0.9401503892495575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 255}], {
             RGBColor[
             0.3107019378391358, 0.4378471817176799, 0.9412269310789902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 312}], {
             RGBColor[
             0.3975158125820031, 0.5104751397594638, 0.9474675883087893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 331}], {
             RGBColor[
             0.2440919709450002, 0.37388651616098867`, 0.9372120486923824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 359}], {
             RGBColor[
             0.28645237167494564`, 0.4168434263248926, 0.9396817701660576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 392}], {
             RGBColor[
             0.2251386082236323, 0.35396533022822685`, 0.9361326827243879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 218}], {
             RGBColor[
             0.40841467546891774`, 0.5204402282772255, 0.9482239194761258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 228}], {
             RGBColor[
             0.2402804897849437, 0.36988040779990605`, 0.9369949904788982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 276}], {
             RGBColor[
             0.31779913118136904`, 0.44485776815799194`, 0.9416475463334251]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.285788273116509, 0.4171315718147177, 0.9396078427636225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 301}], {
             RGBColor[
             0.25321055434935075`, 0.3834707254705414, 0.9377313385275249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 305}], {
             RGBColor[
             0.2773062230664102, 0.4087968010458064, 0.939103551214614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 313}], {
             RGBColor[
             0.27058528986872044`, 0.4017326741232574, 0.9387208040117352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 339}], {
             RGBColor[
             0.3192552716311131, 0.4461190038278132, 0.9417403303152683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 340}], {
             RGBColor[
             0.263972502592159, 0.39478221542066183`, 0.9383442155590771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 361}], {
             RGBColor[
             0.33306353105933184`, 0.4580790241212378, 0.94262018039587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 382}], {
             RGBColor[
             0.2893244860141426, 0.42019446169141983`, 0.9398331671225094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 155}], {
             RGBColor[
             0.19811293609800762`, 0.3255596352976139, 0.9345936106777326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 164}], {
             RGBColor[
             0.21265948505393958`, 0.340848980554772, 0.9354220151210823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 210}], {
             RGBColor[
             0.22800345786551077`, 0.3569764688437995, 0.9362958316733276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 230}], {
             RGBColor[
             0.21572578902733716`, 0.34407186044571364`, 0.935596636596177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 258}], {
             RGBColor[
             0.22398941258529487`, 0.35275745274912235`, 0.9360672377328672]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 264}], {
             RGBColor[
             0.23515256587011008`, 0.3644906346362611, 0.9367029627980321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 268}], {
             RGBColor[
             0.19899317290676588`, 0.326484819993856, 0.9346437388617977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 279}], {
             RGBColor[
             0.20468155953700706`, 0.33246367500678287`, 0.9349676840651762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 299}], {
             RGBColor[
             0.19935795159879743`, 0.32686822552748607`, 0.9346645124686672]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 300}], {
             RGBColor[
             0.20324360298345337`, 0.33095229149728655`, 0.9348857945667173]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 328}], {
             RGBColor[
             0.22083892747976266`, 0.3494460931509151, 0.9358878222668322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 152}], {
             RGBColor[
             0.21962526952820027`, 0.3481704616934645, 0.9358187062419367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 156}], {
             RGBColor[
             0.22013918030941965`, 0.34871061450835156`, 0.9358479727006643]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 157}], {
             RGBColor[
             0.24263401195527415`, 0.3723541088228476, 0.9371290200847746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 160}], {
             RGBColor[
             0.2168510680318782, 0.345254600026296, 0.9356607195707846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 167}], {
             RGBColor[
             0.2371065726737784, 0.3665444196781035, 0.936814240594807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 179}], {
             RGBColor[
             0.23260992772492337`, 0.36181816073310025`, 0.9365581633171598]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 181}], {
             RGBColor[
             0.21526447072748034`, 0.3435869856632946, 0.9355703652014595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 206}], {
             RGBColor[
             0.33364753302286965`, 0.45690710407047097`, 0.9427188232478589]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 211}], {
             RGBColor[
             0.23544785722092995`, 0.3648010045685258, 0.9367197792036168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 238}], {
             RGBColor[
             0.21964443169265407`, 0.3481906023432569, 0.9358197974988545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 386}], {
             RGBColor[
             0.29016677848912364`, 0.4192462598996066, 0.9399482680174902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 158}], {
             RGBColor[
             0.19937632863451948`, 0.3268875409572013, 0.9346655590136652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 186}], {
             RGBColor[
             0.20709670832782653`, 0.33500214951521173`, 0.9351052232159208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 227}], {
             RGBColor[
             0.2408020759927813, 0.3704286279748189, 0.937024694041817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 267}], {
             RGBColor[
             0.20258817055551906`, 0.33026339045871145`, 0.9348484686595718]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 306}], {
             RGBColor[
             0.21495613201977448`, 0.3432629021316925, 0.9355528057682019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 308}], {
             RGBColor[
             0.2102300370530294, 0.33829547666991544`, 0.9352836616514766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 311}], {
             RGBColor[
             0.20510424418118295`, 0.33290794336756596`, 0.934991755330356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 317}], {
             RGBColor[
             0.1980582216182819, 0.3255021269103238, 0.9345904947690551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 344}], {
             RGBColor[
             0.1995874063553662, 0.3271093970249116, 0.9346775795776059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 346}], {
             RGBColor[
             0.2055192492348853, 0.3333441399918473, 0.9350153892542195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 348}], {
             RGBColor[
             0.20435820389696413`, 0.332123807727166, 0.9349492694398375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 354}], {
             RGBColor[
             0.20185675911317996`, 0.3294946306586492, 0.934806815859957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 156}], {
             RGBColor[
             0.20135778622096587`, 0.32897017851222354`, 0.9347784000919095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 157}], {
             RGBColor[
             0.22385261786682037`, 0.3526136728267195, 0.9360594474760198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 160}], {
             RGBColor[
             0.19806967394342445`, 0.325514164030168, 0.9345911469620297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 179}], {
             RGBColor[
             0.2138285336364696, 0.3420777247369723, 0.935488590708405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 181}], {
             RGBColor[
             0.1964830766390266, 0.32384654966716653`, 0.9345007925927047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 238}], {
             RGBColor[
             0.20086303760420032`, 0.32845016634712887`, 0.9347502248900996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 245}], {
             RGBColor[
             0.19786899137363773`, 0.3253032339253123, 0.9345797183865636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 168}], {
             RGBColor[
             0.20180786245057253`, 0.3294432371660213, 0.9348040312673576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 175}], {
             RGBColor[
             0.19789401206423968`, 0.32532953225753836`, 0.9345811432778787]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 211}], {
             RGBColor[
             0.21907020233692062`, 0.34758705088213704`, 0.9357870959865418]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 216}], {
             RGBColor[
             0.21073387590110806`, 0.33882504324447416`, 0.935312354528512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 229}], {
             RGBColor[
             0.2017865527982215, 0.3294208393702904, 0.934802817714181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 294}], {
             RGBColor[
             0.20769214048678164`, 0.33562798646685293`, 0.9351391321965103]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 329}], {
             RGBColor[
             0.23399514583317907`, 0.36327411279277777`, 0.9366370494391784]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 341}], {
             RGBColor[
             0.22749742981872606`, 0.3564446012825976, 0.9362670141246647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 343}], {
             RGBColor[
             0.20318561149837056`, 0.330891338769592, 0.9348824920374326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 358}], {
             RGBColor[
             0.24162422522743635`, 0.37129275894771363`, 0.9370715142244698]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 379}], {
             RGBColor[
             0.19405975897206282`, 0.32129948915197337`, 0.9343627882365483]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 207}], {
             RGBColor[
             0.18894498275511917`, 0.315923535052423, 0.9340715092976267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 231}], {
             RGBColor[
             0.18878970308862236`, 0.3157603262776354, 0.9340626663503354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 369}], {
             RGBColor[
             0.183389073095449, 0.31008392173509136`, 0.9337551084617403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 372}], {
             RGBColor[
             0.18315975702077553`, 0.3098428960011307, 0.9337420492505304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 387}], {
             RGBColor[
             0.18595738695423472`, 0.312783382441179, 0.9339013701365182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 392}], {
             RGBColor[
             0.19471742420704347`, 0.3219907370123223, 0.934400241298752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 249}], {
             RGBColor[
             0.18476081976801417`, 0.3115257144617197, 0.9338332274054255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 268}], {
             RGBColor[
             0.18677990471826675`, 0.31364790076181503`, 0.9339482113063738]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 279}], {
             RGBColor[
             0.19246829134850796`, 0.31962675577474187`, 0.9342721565097523]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.1871446834102983, 0.31403130629544507`, 0.9339689849132433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 300}], {
             RGBColor[
             0.19103033479495424`, 0.31811537226524556`, 0.9341902670112934]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 370}], {
             RGBColor[
             0.18572317816153708`, 0.3125372141503586, 0.9338880322922549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 371}], {
             RGBColor[
             0.18296643499197385`, 0.3096397022915355, 0.9337310398469844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 160}], {
             RGBColor[
             0.19858358472464382`, 0.32605431684505504`, 0.9346204134207573]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.21434244441768896`, 0.34261787755185935`, 0.9355178571671325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 181}], {
             RGBColor[
             0.19699698742024596`, 0.3243867024820536, 0.9345300590514323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 245}], {
             RGBColor[
             0.1983829021548571, 0.32584338674019936`, 0.9346089848452912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 352}], {
             RGBColor[
             0.19412861826228733`, 0.32137186463193046`, 0.9343667096712585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 396}], {
             RGBColor[
             0.19313485512094197`, 0.32032735656215416`, 0.9343101163304997]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 160}], {
             RGBColor[
             0.22107841637049833`, 0.349697811159551, 0.9359014608048675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 167}], {
             RGBColor[
             0.24133392101239853`, 0.37098763081135855`, 0.93705498182889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 168}], {
             RGBColor[
             0.222412865673202, 0.35110040198566517`, 0.9359774557185156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 203}], {
             RGBColor[
             0.2784354581733116, 0.40986687435040126`, 0.9391721369966093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 206}], {
             RGBColor[
             0.3378748813614898, 0.46135031520372605`, 0.942959564481942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 211}], {
             RGBColor[
             0.23967520555955008`, 0.36924421570178084`, 0.9369605204376998]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 238}], {
             RGBColor[
             0.22387178003127423`, 0.3526338134765119, 0.9360605387329375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 341}], {
             RGBColor[
             0.24810243304135554`, 0.37810176610224144`, 0.9374404385758228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 358}], {
             RGBColor[
             0.2622292284500658, 0.3929499237673575, 0.938244938675628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 386}], {
             RGBColor[
             0.2943941268277438, 0.42368947103286164`, 0.9401890092515732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 267}], {
             RGBColor[
             0.19435218965099377`, 0.3216068523367057, 0.934379441731101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 306}], {
             RGBColor[
             0.20672015111524922`, 0.33460636400968674`, 0.935083778839731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 308}], {
             RGBColor[
             0.20199405614850408`, 0.32963893854790965`, 0.9348146347230057]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 311}], {
             RGBColor[
             0.19686826327665763`, 0.3242514052455602, 0.9345227284018851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 317}], {
             RGBColor[
             0.18982224071375664`, 0.31684558878831803`, 0.9341214678405843]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 344}], {
             RGBColor[
             0.19135142545084088`, 0.31845285890290587`, 0.934208552649135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 346}], {
             RGBColor[
             0.19728326833036003`, 0.3246876018698416, 0.9345463623257486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 348}], {
             RGBColor[
             0.1961222229924388, 0.3234672696051602, 0.9344802425113666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 354}], {
             RGBColor[
             0.1936207782086547, 0.3208380925366434, 0.9343377889314861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 374}], {
             RGBColor[
             0.1873884527454699, 0.3142875233225789, 0.9339828672162569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 250}], {
             RGBColor[
             0.18793077615893167`, 0.3148575396154177, 0.934013751732358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 265}], {
             RGBColor[
             0.19056897353088317`, 0.3176304523247132, 0.9341639931698273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 321}], {
             RGBColor[
             0.1833474210515813, 0.31004014279609426`, 0.9337527364394607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 375}], {
             RGBColor[
             0.19246854917072223`, 0.3196270267622359, 0.9342721711923458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 381}], {
             RGBColor[
             0.18574510039169012`, 0.3125602558041992, 0.9338892807308311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[
             0.19370887514270452`, 0.320930687999998, 0.9343428059215524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 238}], {
             RGBColor[
             0.19808883610787825`, 0.32553430467996036`, 0.9345922382189475]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 245}], {
             RGBColor[
             0.19509478987731566`, 0.3223873722581438, 0.9344217317154114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 196}], {
             RGBColor[
             0.8618354721760655, 0.7122379768474625, 0.603098702731688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 214}], {
             RGBColor[
             0.8792338615689066, 0.5445109956801907, 0.22094211265521246`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 253}], {
             RGBColor[
             0.8433103782733695, 0.3117402164434911, 0.18823933356517306`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 283}], {
             RGBColor[
             0.9057344419097366, 0.6568662450460772, 0.2426421685015519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 332}], {
             RGBColor[
             0.8383853925742157, 0.27388461821730115`, 0.1835231616976877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 334}], {
             RGBColor[
             0.9198789642740572, 0.7116881876157337, 0.2605664067222301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.9124649507944522, 0.7523588106461282, 0.5992692091287142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 364}], {
             RGBColor[
             0.9004423422818535, 0.6358848335091806, 0.23838402091941335`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 366}], {
             RGBColor[
             0.9364231997374939, 0.7670038596603013, 0.3666668736906492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 389}], {
             RGBColor[
             0.9363348090239618, 0.7668148008617284, 0.3570460900069422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 183}], {
             RGBColor[
             0.1919904214056781, 0.3191244841661233, 0.9342449425234534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 270}], {
             RGBColor[
             0.20162095796864934`, 0.3292467887050914, 0.9347933873336124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 280}], {
             RGBColor[
             0.20211294537388308`, 0.32976389866179523`, 0.9348214052885103]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 291}], {
             RGBColor[
             0.1953787311658639, 0.32268581255532547`, 0.9344379017517408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 336}], {
             RGBColor[
             0.21504897720554328`, 0.3433604883086603, 0.9355580931641793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 357}], {
             RGBColor[
             0.1906502583880034, 0.3177158878633042, 0.9341686222221902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 368}], {
             RGBColor[
             0.18956500601498782`, 0.31657521881029016`, 0.934106818705034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 171}], {
             RGBColor[
             0.18355378954190335`, 0.31025704916394076`, 0.9337644888196897]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 240}], {
             RGBColor[
             0.17919351847301027`, 0.305674127813381, 0.9335161778327592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 272}], {
             RGBColor[
             0.18785278804211375`, 0.3147755691599099, 0.9340093104244782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 342}], {
             RGBColor[
             0.18272416673891645`, 0.30938506299687774`, 0.9337172430283764]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 374}], {
             RGBColor[
             0.1813453905655848, 0.3079358818192477, 0.9336387237650219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 210}], {
             RGBColor[
             0.23033673863294363`, 0.3594288948689166, 0.9364287085612534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 230}], {
             RGBColor[
             0.21805906979477002`, 0.3465242864708308, 0.9357295134841028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 258}], {
             RGBColor[
             0.22632269335272776`, 0.3552098787742395, 0.936200114620793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 264}], {
             RGBColor[
             0.23748584663754294`, 0.36694306066137816`, 0.9368358396859577]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 279}], {
             RGBColor[
             0.20701484030443992`, 0.33491610103189995`, 0.9351005609531018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 328}], {
             RGBColor[
             0.22317220824719552`, 0.35189851917603227`, 0.9360206991547579]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 170}], {
             RGBColor[
             0.23052227294686206`, 0.35962390319639986`, 0.9364392744659576]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 172}], {
             RGBColor[
             0.3025819493818708, 0.42881009810169846`, 0.9407829073040905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 184}], {
             RGBColor[
             0.21954677082243013`, 0.3480879545765947, 0.9358142358567716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 190}], {
             RGBColor[
             0.21884661716031273`, 0.34735204868540315`, 0.9357743631414985]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 192}], {
             RGBColor[
             0.24190350365737148`, 0.3715862982848506, 0.9370874187178992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 221}], {
             RGBColor[
             0.29772616502322835`, 0.42460426174906063`, 0.9404735010185594]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 226}], {
             RGBColor[
             0.20872258864357046`, 0.33671105281382463`, 0.935197814694628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 252}], {
             RGBColor[
             0.21574093049341658`, 0.3440877750865875, 0.9355974988802704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 274}], {
             RGBColor[
             0.21434019517096867`, 0.34261551345094576`, 0.9355177290758593]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 288}], {
             RGBColor[
             0.2196372553710177, 0.3481830595742119, 0.9358193888179538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 318}], {
             RGBColor[
             0.21949852941857476`, 0.348037249802461, 0.9358114885801888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 322}], {
             RGBColor[
             0.2103258844391586, 0.3383962183498125, 0.9352891200183233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 351}], {
             RGBColor[
             0.26754769340127105`, 0.39846518644420825`, 0.9385505554925828]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 355}], {
             RGBColor[
             0.2168405199897158, 0.34524351336519876`, 0.9356601188753879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 399}], {
             RGBColor[
             0.2924581876891166, 0.42004140455849254`, 0.9401378301611192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 169}], {
             RGBColor[
             0.3512165772923903, 0.4726432539013666, 0.9438449606681389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 246}], {
             RGBColor[
             0.23093801406837325`, 0.3600608734746177, 0.9364629503077938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 326}], {
             RGBColor[
             0.24337300372818133`, 0.3731308360309576, 0.9371711045730012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 363}], {
             RGBColor[
             0.3098501203432949, 0.43692070785172515`, 0.9411795622408922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 383}], {
             RGBColor[
             0.3017459947622442, 0.42990132159861427`, 0.9406631745250644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 168}], {
             RGBColor[
             0.21688542639170627`, 0.3452907128409211, 0.935662676228548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.2729080188918158, 0.40405718520565725`, 0.9388573575066418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 211}], {
             RGBColor[
             0.23414776627805434`, 0.3634345265570368, 0.9366457409477322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 216}], {
             RGBColor[
             0.22581143984224178`, 0.35467251891937396`, 0.9361709994897025]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 238}], {
             RGBColor[
             0.2183443407497785, 0.3468241243317679, 0.9357457592429699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 341}], {
             RGBColor[
             0.2425749937598598, 0.37229207695749733`, 0.9371256590858552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 358}], {
             RGBColor[
             0.25670178916857006`, 0.3871402346226134, 0.9379301591856604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 211}], {
             RGBColor[
             0.2152267109388578, 0.3435472977313434, 0.935568214837358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 216}], {
             RGBColor[
             0.20689038450304525`, 0.3347852900936806, 0.9350934733793282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 238}], {
             RGBColor[
             0.19942328541058194`, 0.3269368955060745, 0.9346682331325956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 341}], {
             RGBColor[
             0.22365393842066325`, 0.35240484813180395`, 0.936048132975481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 379}], {
             RGBColor[
             0.190216267574, 0.31725973600117974`, 0.9341439070873645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 218}], {
             RGBColor[
             0.5087675338544672, 0.6120794295560898, 0.9544711904233589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 222}], {
             RGBColor[
             0.7041731063901011, 0.7666519834125803, 0.9590482629072343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 224}], {
             RGBColor[
             0.4775031351026399, 0.5866975822042433, 0.9520099424283488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 276}], {
             RGBColor[
             0.41815198956691846`, 0.5364969694368562, 0.947894817280658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 326}], {
             RGBColor[
             0.349415147686683, 0.47074983716853436`, 0.9437423719170701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 361}], {
             RGBColor[
             0.4334163894448813, 0.5497182254001022, 0.948867451343103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 363}], {
             RGBColor[
             0.4158922643017966, 0.5345397089893019, 0.947750829584961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 382}], {
             RGBColor[
             0.38967734439969204`, 0.5118336629702842, 0.9460804380697425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 383}], {
             RGBColor[
             0.4077881387207459, 0.527520322736191, 0.9472344418691334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 393}], {
             RGBColor[
             0.5896152402179853, 0.6764956737968535, 0.9616696419121211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[
             0.2468852126322833, 0.37682239027607506`, 0.9373711196742425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 208}], {
             RGBColor[
             0.26496099146250607`, 0.3958211798972109, 0.9384005085379051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 221}], {
             RGBColor[
             0.30270787399814014`, 0.42984035374028506`, 0.9407572019749026]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 225}], {
             RGBColor[
             0.22199301735031157`, 0.3506591147783862, 0.9359535459776369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 235}], {
             RGBColor[
             0.21437654864384317`, 0.34265372325588017`, 0.9355197993523594]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 322}], {
             RGBColor[
             0.2153075934140704, 0.3436323103410369, 0.9355728209746665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 335}], {
             RGBColor[
             0.21688414248716403`, 0.34528936337584293`, 0.9356626031120838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 349}], {
             RGBColor[
             0.21695935367547547`, 0.34536841510342303`, 0.9356668862779931]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 351}], {
             RGBColor[
             0.27252940237618284`, 0.4037012784354327, 0.938834256448926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 355}], {
             RGBColor[
             0.2218222289646276, 0.3504796053564232, 0.9359438198317311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 186}], {
             RGBColor[
             0.1973172314150955, 0.32472329922528254`, 0.9345482964731804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 240}], {
             RGBColor[
             0.18369308464468964`, 0.3104034571487888, 0.9337724214697247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 272}], {
             RGBColor[
             0.19235235421379315`, 0.3195048984953177, 0.9342655540614437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 308}], {
             RGBColor[
             0.20045056014029836`, 0.3280166263799862, 0.9347267349087363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 342}], {
             RGBColor[
             0.18722373291059582`, 0.31411439233228555`, 0.933973486665342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 348}], {
             RGBColor[
             0.1945787269842331, 0.32184495743723673`, 0.934392342697097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 374}], {
             RGBColor[
             0.18584495673726414`, 0.3126652111546555, 0.9338949674019874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 192}], {
             RGBColor[
             0.31894488906729196`, 0.44600858518137365`, 0.9417147525123752]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 194}], {
             RGBColor[
             0.41753162873264527`, 0.5360090287080477, 0.9478416433121417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 221}], {
             RGBColor[
             0.3747675504331488, 0.4990265486455837, 0.9451008348130354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 256}], {
             RGBColor[
             0.6859636429526801, 0.7471589426256584, 0.8613086090450968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 316}], {
             RGBColor[
             0.5458822960971526, 0.6391409074229324, 0.9586767421820886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 351}], {
             RGBColor[
             0.3445890788111915, 0.47288747334073133`, 0.943177889287059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 399}], {
             RGBColor[
             0.369499573099037, 0.49446369145501556`, 0.9447651639555954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 198}], {
             RGBColor[
             0.6233166189809511, 0.701327344471203, 0.9656888716580491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 203}], {
             RGBColor[
             0.3639226125883841, 0.4896332085668736, 0.9444098049633691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 266}], {
             RGBColor[
             0.5380286912692482, 0.6346285303347542, 0.9572070721400225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 313}], {
             RGBColor[
             0.35122662219084355`, 0.47640574207717373`, 0.9436825095790529]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 329}], {
             RGBColor[
             0.34008730347088106`, 0.4646976118288939, 0.9430481418570962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 340}], {
             RGBColor[
             0.3446138349142821, 0.46945528337457815`, 0.9433059211263948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 341}], {
             RGBColor[
             0.3335895874564281, 0.4578681003187137, 0.9426781065425826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 358}], {
             RGBColor[
             0.34771638286513834`, 0.47271625798382977`, 0.9434826066423876]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 204}], {
             RGBColor[
             0.1850387535749342, 0.31181784051481387`, 0.9338490553245634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 216}], {
             RGBColor[
             0.20297653411671235`, 0.3306715851851976, 0.9348705853898494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 229}], {
             RGBColor[
             0.1940292110138258, 0.32126738131101384`, 0.9343610485755184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 294}], {
             RGBColor[
             0.19993479870238595`, 0.3274745284075764, 0.9346973630578478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 307}], {
             RGBColor[
             0.18458331869086259`, 0.3113391495754152, 0.933823118981671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 343}], {
             RGBColor[
             0.19542826971397487`, 0.32273788071031545`, 0.93444072289877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 379}], {
             RGBColor[
             0.1863024171876671, 0.3131460310926968, 0.9339210190978857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 205}], {
             RGBColor[
             0.18567915281687453`, 0.3124909407217502, 0.9338855251140061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 232}], {
             RGBColor[
             0.18828223277850703`, 0.3152269428062281, 0.9340337666669094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 277}], {
             RGBColor[
             0.18565952896853344`, 0.31247031481291987`, 0.933884407564874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 298}], {
             RGBColor[
             0.19583511598337588`, 0.32316550193499927`, 0.9344638921919373]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 320}], {
             RGBColor[
             0.18495626411433608`, 0.3117311388615913, 0.9338443576718145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 347}], {
             RGBColor[
             0.18526445779187303`, 0.3120550699572905, 0.9338619088458187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 373}], {
             RGBColor[
             0.192094835712424, 0.3192342302227627, 0.9342508887637553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 390}], {
             RGBColor[
             0.199593709897452, 0.3271160224473115, 0.9346779385550025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 219}], {
             RGBColor[
             0.18016175523476746`, 0.3066918060397442, 0.9335713174839634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 248}], {
             RGBColor[
             0.18215464872777276`, 0.30878646345763827`, 0.9336848098201683]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 260}], {
             RGBColor[
             0.18516377148342406`, 0.31194924226322995`, 0.9338561749095045]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 285}], {
             RGBColor[
             0.18283630546897034`, 0.3095029279121705, 0.9337236291631588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 200}], {
             RGBColor[
             0.1885274133225135, 0.31548464310332325`, 0.9340477293361784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 278}], {
             RGBColor[
             0.18555079143571185`, 0.31235602477156665`, 0.9338782151232425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 296}], {
             RGBColor[
             0.18104204814496305`, 0.30761704970215387`, 0.9336214488629224]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 330}], {
             RGBColor[
             0.18585403499635023`, 0.3126747529805498, 0.9338954843954123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 367}], {
             RGBColor[
             0.18455036747987072`, 0.3113045157634352, 0.933821242458952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 398}], {
             RGBColor[
             0.18190742429108608`, 0.30852661489974587`, 0.9336707307542348]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 209}], {
             RGBColor[
             0.24592936800917714`, 0.3758177369731411, 0.9373166857370019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 245}], {
             RGBColor[
             0.21085364957036085`, 0.33895093296494805`, 0.9353191754617867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 286}], {
             RGBColor[
             0.2740282991513247, 0.4041960245612692, 0.9389591857364195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 290}], {
             RGBColor[
             0.24217146180405288`, 0.37186793928654055`, 0.9371026785379442]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 352}], {
             RGBColor[
             0.20659936567779108`, 0.3344794108566792, 0.9350769002877538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 386}], {
             RGBColor[
             0.284370042597393, 0.41315352294311436`, 0.9396181524839584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 232}], {
             RGBColor[
             0.18939213687360562`, 0.3163935223821609, 0.9340969740631693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 249}], {
             RGBColor[
             0.18602314959306215`, 0.3128525031441788, 0.9339051152215123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 268}], {
             RGBColor[
             0.1880422345433147, 0.314974689444274, 0.9340200991224608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 370}], {
             RGBColor[
             0.18698550798658503`, 0.3138640028328177, 0.9339599201083417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 238}], {
             RGBColor[
             0.1965022388034804, 0.3238666903169589, 0.9345018838496224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 245}], {
             RGBColor[
             0.1935081925729178, 0.3207197578951424, 0.9343313773460864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 187}], {
             RGBColor[
             0.22908739425404853`, 0.35811575471368917`, 0.9363575602471148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 208}], {
             RGBColor[
             0.2681228139523549, 0.39914445580516655`, 0.9385805696512048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 323}], {
             RGBColor[
             0.3312247462121247, 0.45512489933743366`, 0.9425528644360341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 377}], {
             RGBColor[
             0.2482608696505907, 0.3782682930240088, 0.9374494613063329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 388}], {
             RGBColor[
             0.2563045573313864, 0.38672271877578024`, 0.9379075374201846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 395}], {
             RGBColor[
             0.3402542515552627, 0.4629458030295253, 0.9431282165320207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 270}], {
             RGBColor[
             0.198314467229445, 0.32577145729456636`, 0.9346050875775294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 291}], {
             RGBColor[
             0.1920722404266596, 0.31921048114480044`, 0.9342496019956579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 357}], {
             RGBColor[
             0.18734376764879906`, 0.31424055645277915`, 0.9339803224661072]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 368}], {
             RGBColor[
             0.18625851527578347`, 0.31309988739976513`, 0.933918518948951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 185}], {
             RGBColor[
             0.20305130848505737`, 0.330750177787297, 0.9348748436795078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 190}], {
             RGBColor[
             0.21285282401079259`, 0.34105219205682236`, 0.9354330254886557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 226}], {
             RGBColor[
             0.20272879549405032`, 0.3304111961852439, 0.9348564770417853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 252}], {
             RGBColor[
             0.20974713734389644`, 0.3377879184580067, 0.9352561612274277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 274}], {
             RGBColor[
             0.20834640202144852`, 0.33631565682236503`, 0.9351763914230165]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 288}], {
             RGBColor[
             0.21364346222149755`, 0.3418832029456312, 0.9354780511651108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 318}], {
             RGBColor[
             0.2135047362690546, 0.34173739317388024`, 0.935470150927346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 190}], {
             RGBColor[
             0.20235115482293997`, 0.33001427189610544`, 0.9348349709642347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 226}], {
             RGBColor[
             0.1922271263061977, 0.3193732760245269, 0.9342584225173644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 252}], {
             RGBColor[
             0.1992454681560438, 0.3267499982972898, 0.9346581067030068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 274}], {
             RGBColor[
             0.19784473283359588`, 0.32527773666164805`, 0.9345783368985956]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 288}], {
             RGBColor[
             0.2031417930336449, 0.3308452827849142, 0.93487999664069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 318}], {
             RGBColor[
             0.20300306708120197`, 0.33069947301316327`, 0.9348720964029251]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 357}], {
             RGBColor[
             0.18927662196416456`, 0.31627210888827, 0.9340903956599655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 272}], {
             RGBColor[
             0.20161622991530592`, 0.3292418192212516, 0.9347931180779689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 306}], {
             RGBColor[
             0.21444053080855624`, 0.3427209725676972, 0.9355234430419865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 308}], {
             RGBColor[
             0.20971443584181115`, 0.3377535471059201, 0.9352542989252615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 342}], {
             RGBColor[
             0.19648760861210862`, 0.32385131305821946`, 0.9345010506818672]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 348}], {
             RGBColor[
             0.2038426026857459, 0.33158187816317064`, 0.9349199067136222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 374}], {
             RGBColor[
             0.19510883243877694`, 0.3224021318805894, 0.9344225314185126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 378}], {
             RGBColor[
             0.22340907061728948`, 0.35214747654494266`, 0.9360341881163283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 208}], {
             RGBColor[
             0.25538258130493185`, 0.38575366351532014`, 0.9378550322494192]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 302}], {
             RGBColor[
             0.20552429842574232`, 0.33334944701157526`, 0.9350156767981692]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 377}], {
             RGBColor[
             0.2355206370031677, 0.36487750073416236`, 0.9367239239045473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 388}], {
             RGBColor[
             0.2435643246839634, 0.37333192648593383`, 0.937182000018399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 201}], {
             RGBColor[
             0.47076164268683474`, 0.5730017553920743, 0.9531670568538995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 264}], {
             RGBColor[
             0.26789407428573686`, 0.39890403591261847`, 0.9385675432655809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 273}], {
             RGBColor[
             0.39992754574806544`, 0.5158532142548906, 0.9473461281045827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 281}], {
             RGBColor[
             0.3372802138863956, 0.4635116716468679, 0.9428236756739168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 293}], {
             RGBColor[
             0.29496948602480166`, 0.4268642457721712, 0.9401276735084836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 394}], {
             RGBColor[
             0.3167171676025393, 0.44570099448454903`, 0.9415134165478973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 207}], {
             RGBColor[
             0.2123454769342431, 0.3405189381117063, 0.935404132823199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 241}], {
             RGBColor[
             0.2570425573000169, 0.3874984035347115, 0.937949565426625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 263}], {
             RGBColor[
             0.2675028819703037, 0.39849286798607286`, 0.9385452654419342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 280}], {
             RGBColor[
             0.2210513429116578, 0.3496693552377532, 0.9358999190114381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 291}], {
             RGBColor[
             0.21431712870363867`, 0.34259126913128346`, 0.9355164154746687]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 336}], {
             RGBColor[
             0.23398737474331802`, 0.3632659448846183, 0.936636606887107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 359}], {
             RGBColor[
             0.2794316818374808, 0.4094642361682714, 0.9392819522659938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 226}], {
             RGBColor[
             0.20202864183193292`, 0.3296752902940524, 0.9348166043265123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 252}], {
             RGBColor[
             0.20904698368177904`, 0.3370520125668152, 0.9352162885121547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 274}], {
             RGBColor[
             0.20764624835933113`, 0.33557975093117354`, 0.9351365187077434]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 288}], {
             RGBColor[
             0.21294330855938015`, 0.3411472970544397, 0.9354381784498378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 318}], {
             RGBColor[
             0.21280458260693721`, 0.34100148728268875`, 0.9354302782120729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 225}], {
             RGBColor[
             0.19624559498378968`, 0.32359694139030604`, 0.9344872683637615]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 235}], {
             RGBColor[
             0.18862912627732129`, 0.3155915498678, 0.9340535217384839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 261}], {
             RGBColor[
             0.18660634868245718`, 0.3134654823640909, 0.9339383275468877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 322}], {
             RGBColor[
             0.18956017104754852`, 0.31657013695295677`, 0.934106543360791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 327}], {
             RGBColor[
             0.1848862258869851, 0.3116575242439654, 0.9338403690983792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 335}], {
             RGBColor[
             0.19113672012064215`, 0.3182271899877628, 0.9341963254982084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 349}], {
             RGBColor[
             0.1912119313089536, 0.3183062417153429, 0.9342006086641177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 355}], {
             RGBColor[
             0.19607480659810572`, 0.32341743196834305`, 0.9344775422178556]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 208}], {
             RGBColor[
             0.27634222217301546`, 0.40778357498566165`, 0.9390486527898467]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 221}], {
             RGBColor[
             0.3140891047086496, 0.4418027488287358, 0.9414053462268441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[
             0.233374248060821, 0.36262150986683694`, 0.9366016902295785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 322}], {
             RGBColor[
             0.2266888241245798, 0.3555947054294877, 0.936220965226608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 335}], {
             RGBColor[
             0.22826537319767345`, 0.3572517584642937, 0.9363107473640253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 349}], {
             RGBColor[
             0.22834058438598487`, 0.3573308101918738, 0.9363150305299347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 351}], {
             RGBColor[
             0.2839106330866923, 0.41566367352388345`, 0.9394824007008676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 355}], {
             RGBColor[
             0.233203459675137, 0.36244200044487396`, 0.9365919640836726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 399}], {
             RGBColor[
             0.3088211273745378, 0.43723989163816773`, 0.941069675369404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 195}], {
             RGBColor[
             0.6312732042379722, 0.7079049527832757, 0.9663404032043308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 242}], {
             RGBColor[
             0.5891633460741419, 0.6714315101447773, 0.963657200278417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 253}], {
             RGBColor[
             0.8294376428224145, 0.4209653077854606, 0.4426395583706675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 255}], {
             RGBColor[
             0.606058461723811, 0.6860652101473173, 0.9647337421078497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 283}], {
             RGBColor[
             0.884925338733304, 0.8207038820590313, 0.6242425057097936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 312}], {
             RGBColor[
             0.6928723364666782, 0.7586931681891012, 0.9709743993376487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 332}], {
             RGBColor[
             0.8245126571232608, 0.38310970955927065`, 0.4379233865031822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 356}], {
             RGBColor[
             0.8916558476180196, 0.9161964476590825, 0.9808695463369558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 360}], {
             RGBColor[
             0.7503418220523833, 0.8050370370474327, 0.9757122305140027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 364}], {
             RGBColor[
             0.8796332391054209, 0.7997224705221349, 0.619984358127655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 380}], {
             RGBColor[
             0.7791551569135652, 0.8275462332304435, 0.978584074457042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 389}], {
             RGBColor[
             0.9155257058475293, 0.9306524378746825, 0.7386464272151838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 221}], {
             RGBColor[
             0.41267584437400284`, 0.5318031923554098, 0.9475322370266106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 233}], {
             RGBColor[
             0.7128854689421396, 0.7730895863286765, 0.9426895386250231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 256}], {
             RGBColor[
             0.7238719368935342, 0.7799355863354847, 0.863740011258672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 316}], {
             RGBColor[
             0.5837905900380065, 0.6719175511327584, 0.9611081443956637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 399}], {
             RGBColor[
             0.40740786703989107`, 0.5272403351648417, 0.9471965661691704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 241}], {
             RGBColor[
             0.35276484059541724`, 0.47739540900316435`, 0.9437930699766406]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 242}], {
             RGBColor[
             0.3825084156474021, 0.5057312970269716, 0.9455940758995094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.3994035312970712, 0.5203649970295117, 0.9466706177289421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 263}], {
             RGBColor[
             0.3632251652657039, 0.4883898734545258, 0.9443887699919498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 312}], {
             RGBColor[
             0.48621740603993846`, 0.5929929550712956, 0.9529112749587412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 356}], {
             RGBColor[
             0.6850009171912799, 0.7504962345412768, 0.9628064219580481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 359}], {
             RGBColor[
             0.375153965132881, 0.49936124163672424`, 0.9451254568160093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 360}], {
             RGBColor[
             0.5436868916256435, 0.6393368239296271, 0.957649106135095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 380}], {
             RGBColor[
             0.5725002264868254, 0.6618460201126379, 0.9605209500781344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 389}], {
             RGBColor[
             0.7088707754207897, 0.764952224756877, 0.7205833028362763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 206}], {
             RGBColor[
             0.6365065028818196, 0.7122246861355508, 0.9667719599708235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 214}], {
             RGBColor[
             0.8615229927273951, 0.7108190806524803, 0.6028379622201453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 286}], {
             RGBColor[
             0.5826840049020053, 0.6656063435828412, 0.963342437992916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 332}], {
             RGBColor[
             0.8265781466798748, 0.38475667486549425`, 0.4381203947409763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 334}], {
             RGBColor[
             0.9021680954325457, 0.8779962725880234, 0.6424622562871629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 366}], {
             RGBColor[
             0.9187123308959824, 0.9333119446325909, 0.748562723255582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 386}], {
             RGBColor[
             0.5930257483480736, 0.6745638419646864, 0.9640014047404548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 217}], {
             RGBColor[
             0.19977926755688577`, 0.3273110553124115, 0.9346885057891993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 231}], {
             RGBColor[
             0.19125913163260555`, 0.3183558522481745, 0.9342032966527232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 254}], {
             RGBColor[
             0.18919463052287389`, 0.31618593068491585`, 0.9340857263686796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 314}], {
             RGBColor[
             0.18703267242257346`, 0.3139135756454394, 0.9339626060531978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 369}], {
             RGBColor[
             0.18585850163943218`, 0.31267944770563044`, 0.933895738764128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 392}], {
             RGBColor[
             0.19718685275102665`, 0.3245862629828614, 0.9345408716011396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 203}], {
             RGBColor[
             0.5694035624452959, 0.6546305646490294, 0.9622535793690412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 206}], {
             RGBColor[
             0.6288429856334741, 0.7061140055023541, 0.9660410068543737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 214}], {
             RGBColor[
             0.8538594754790496, 0.7047084000192836, 0.6021070091036955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 266}], {
             RGBColor[
             0.74350964112616, 0.79962588641691, 0.9750508465456946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 310}], {
             RGBColor[
             0.8272769818270227, 0.4253245421128263, 0.4431946931706203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 384}], {
             RGBColor[
             0.8811911535814985, 0.820358675063078, 0.6244757857174054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 215}], {
             RGBColor[
             0.8474033618771311, 0.8799586173228249, 0.9038397390676208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 222}], {
             RGBColor[
             0.9699116219534045, 0.9763258350817114, 0.9020107810264453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 223}], {
             RGBColor[
             0.9023894680156853, 0.6322806802095792, 0.4149397481928467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 224}], {
             RGBColor[
             0.7432416506659434, 0.7963714338733744, 0.8949724605475597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 247}], {
             RGBColor[
             0.8744710807180455, 0.41938916470165666`, 0.38827169323511157`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 259}], {
             RGBColor[
             0.9420801867046171, 0.9545306309034027, 0.913114429015637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 271}], {
             RGBColor[
             0.8762470859874794, 0.4330403194529975, 0.3899723978868326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 287}], {
             RGBColor[
             0.8744579174591663, 0.41928798612573526`, 0.3882590880835432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 292}], {
             RGBColor[
             0.8759065071929455, 0.430422481595631, 0.3896462592485583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 345}], {
             RGBColor[
             0.9084097409587222, 0.9276827314255283, 0.9099029118424318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 350}], {
             RGBColor[
             0.6686405102956781, 0.7329620420673324, 0.8898856192140527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 353}], {
             RGBColor[
             0.9909977762454061, 0.988800838647677, 0.6720451430779383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 393}], {
             RGBColor[
             0.8553537557812887, 0.8861695254659845, 0.9046321600313321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 400}], {
             RGBColor[
             0.8776553963318527, 0.44386520988537914`, 0.3913209974630636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 234}], {
             RGBColor[
             0.22049169370930496`, 0.34908112844227146`, 0.9358680478172909]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 296}], {
             RGBColor[
             0.1865617818736295, 0.3134186398223141, 0.9339357895330556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 298}], {
             RGBColor[
             0.19975642982426225`, 0.3272870514074283, 0.9346872052141117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 320}], {
             RGBColor[
             0.18887757795522245`, 0.31585268833402036`, 0.934067670693989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 330}], {
             RGBColor[
             0.1913737687250167, 0.31847634310071005`, 0.9342098250655455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 347}], {
             RGBColor[
             0.1891857716327594, 0.31617661942971953`, 0.9340852218679931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 367}], {
             RGBColor[
             0.19007010120853718`, 0.31710610588359545`, 0.9341355831290852]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 398}], {
             RGBColor[
             0.18742715801975252`, 0.3143282050199061, 0.933985071424368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 273}], {
             RGBColor[
             0.5948799673171399, 0.6816316125645953, 0.9614948857902279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 281}], {
             RGBColor[
             0.5322326354554701, 0.6292900699565726, 0.956972433359562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 293}], {
             RGBColor[
             0.4899219075938762, 0.5926426440818758, 0.9542764311941287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 303}], {
             RGBColor[
             0.7798220611835203, 0.6750115727481525, 0.6002603969131654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 394}], {
             RGBColor[
             0.5116695891716139, 0.6114793927942537, 0.9556621742335425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 212}], {
             RGBColor[
             0.45268550871471924`, 0.56313574583105, 0.9509994425842794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 234}], {
             RGBColor[
             0.28726387007128157`, 0.41752052418196, 0.9397344221047603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 239}], {
             RGBColor[
             0.4173644057485659, 0.5344604832455712, 0.9482188359733204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 269}], {
             RGBColor[
             0.34049741903328384`, 0.46934348329390774`, 0.9429171723441234]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 289}], {
             RGBColor[
             0.4009029468034172, 0.5210963292936249, 0.9469229296248474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 309}], {
             RGBColor[
             0.5124790971855998, 0.6108362268976354, 0.9562827357512269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 362}], {
             RGBColor[
             0.5594312028417849, 0.6475155686854668, 0.9609624828506617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 365}], {
             RGBColor[
             0.31680424057691503`, 0.4485693265510483, 0.9414167025039941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 206}], {
             RGBColor[
             0.36944897924090714`, 0.4944198695980247, 0.9447619401596937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 211}], {
             RGBColor[
             0.27124930343896736`, 0.4023137700960795, 0.9387628961154517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 216}], {
             RGBColor[
             0.26291297700315486`, 0.3935517624584167, 0.938288154657422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 266}], {
             RGBColor[
             0.4841156347335931, 0.5879317505125805, 0.9537717798510146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 329}], {
             RGBColor[
             0.28617424693522586`, 0.4180008320067203, 0.9396128495680883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 341}], {
             RGBColor[
             0.2796765309207728, 0.4111713204965401, 0.9392428142535747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 358}], {
             RGBColor[
             0.29380332632948314`, 0.42601947816165614`, 0.9400473143533797]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 229}], {
             RGBColor[
             0.18893129430891603`, 0.3159091476275659, 0.9340707297608657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 237}], {
             RGBColor[
             0.18108298927677668`, 0.3076600814275077, 0.9336237803998122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 307}], {
             RGBColor[
             0.17948540198595286`, 0.30598091589196724`, 0.9335328001670183]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 343}], {
             RGBColor[
             0.1903303530090651, 0.3173796470268675, 0.9341504040841173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 232}], {
             RGBColor[
             0.18775686622597437`, 0.3146747492493529, 0.9340038478189527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 277}], {
             RGBColor[
             0.18513416241600078`, 0.31191812125604473`, 0.9338544887169173]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 373}], {
             RGBColor[
             0.19156946915989134`, 0.31868203666588757`, 0.9342209699157987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 390}], {
             RGBColor[
             0.19906834334491935`, 0.32656382889043634`, 0.9346480197070459]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 266}], {
             RGBColor[
             0.5435550579217713, 0.6394151913659053, 0.9575592073363473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 286}], {
             RGBColor[
             0.375065904449271, 0.49928496789863985`, 0.9451198456671187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 386}], {
             RGBColor[
             0.3854076478953393, 0.5082424662804851, 0.9457788124146576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 231}], {
             RGBColor[
             0.1913619669815575, 0.3184639387200607, 0.9342091529737147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 280}], {
             RGBColor[
             0.200223112625469, 0.32777756462089525`, 0.9347137821092452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 291}], {
             RGBColor[
             0.19348889841744987`, 0.3206994785144255, 0.9343302785724756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 368}], {
             RGBColor[
             0.18767517326657374`, 0.3145888847693901, 0.9339991955257688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 372}], {
             RGBColor[
             0.18573202091371066`, 0.31254650844355597`, 0.9338885358739095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 387}], {
             RGBColor[
             0.18852965084716983`, 0.3154869948836043, 0.9340478567598975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 392}], {
             RGBColor[
             0.1972896880999786, 0.3246943494547476, 0.9345467279221311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 221}], {
             RGBColor[
             0.3321648835388723, 0.4608015384498717, 0.9424347350905069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 225}], {
             RGBColor[
             0.2514500268910438, 0.38162029948797277`, 0.9376310790932412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 323}], {
             RGBColor[
             0.3575199332630081, 0.48276280813906464`, 0.9440503364383386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 351}], {
             RGBColor[
             0.301986411916915, 0.43466246314501933`, 0.9405117895645303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 388}], {
             RGBColor[
             0.28259974438226976`, 0.4143606275774112, 0.9394050094224892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 395}], {
             RGBColor[
             0.366549438606146, 0.4905837118311563, 0.9446256885343254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 286}], {
             RGBColor[
             0.29314447532730914`, 0.4242883377578022, 0.9400478236897936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 290}], {
             RGBColor[
             0.2612876379800373, 0.3919602524830736, 0.938191316491318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 304}], {
             RGBColor[
             0.2736580263748165, 0.40496231501391133`, 0.9388957918100511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 338}], {
             RGBColor[
             0.23759083072429804`, 0.3670534055929334, 0.9368418183743885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 386}], {
             RGBColor[
             0.30348621877337745`, 0.4332458361396474, 0.9407067904373323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 230}], {
             RGBColor[
             0.2334030426063412, 0.36265177475985827`, 0.9366033300363481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 258}], {
             RGBColor[
             0.24166666616429894`, 0.371337367063267, 0.9370739311730383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 264}], {
             RGBColor[
             0.2528298194491141, 0.3830705489504057, 0.9377096562382032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 279}], {
             RGBColor[
             0.2223588131160111, 0.3510435893209275, 0.9359743775053473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 328}], {
             RGBColor[
             0.2385161810587667, 0.36802600746505976`, 0.9368945157070033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 394}], {
             RGBColor[
             0.30165291276591666`, 0.42986750752233627`, 0.9406555295205197]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 216}], {
             RGBColor[
             0.22415272438939332`, 0.35292910380979625`, 0.9360765380985124]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 238}], {
             RGBColor[
             0.21668562529693003`, 0.34508070922219014`, 0.9356512978517798]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 341}], {
             RGBColor[
             0.24091627830701134`, 0.3705486618479197, 0.9370311976946651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 358}], {
             RGBColor[
             0.2550430737157216, 0.3853968195130357, 0.9378356977944702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 239}], {
             RGBColor[
             0.542458414688152, 0.6394312043737607, 0.9571234599763494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 289}], {
             RGBColor[
             0.5259969557430033, 0.6260670504218144, 0.9558275536278764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 309}], {
             RGBColor[
             0.6375731061251859, 0.7158069480258249, 0.965187359754256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 362}], {
             RGBColor[
             0.6845252117813709, 0.7524862898136562, 0.9698671068536907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 385}], {
             RGBColor[
             0.7860985506073723, 0.8292872838004639, 0.7968353358505167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 215}], {
             RGBColor[
             0.5157421665105038, 0.6132928535993672, 0.9566471217151071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 227}], {
             RGBColor[
             0.29970260204538113`, 0.43079580390036054`, 0.94043541584355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 259}], {
             RGBColor[
             0.6104189913379899, 0.6878648671799451, 0.9659218116631232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 306}], {
             RGBColor[
             0.2738566580723743, 0.4036300780572341, 0.9389635275699348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 308}], {
             RGBColor[
             0.2691305631056292, 0.398662652595457, 0.9386943834532097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 345}], {
             RGBColor[
             0.5767485455920949, 0.6610169677020706, 0.962710294489918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 350}], {
             RGBColor[
             0.33697931492905076`, 0.46629627834387477`, 0.942693001861539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 378}], {
             RGBColor[
             0.2828251978811075, 0.4130565820344796, 0.9394742726442766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 257}], {
             RGBColor[
             0.9241708234933428, 0.7599031818045514, 0.5786645333196092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 310}], {
             RGBColor[
             0.8439849195878139, 0.31758034175677613`, 0.18891093519726984`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 332}], {
             RGBColor[
             0.8381770729417689, 0.2729386874206463, 0.1833493346899926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 389}], {
             RGBColor[
             0.9360223295752915, 0.7653959046667461, 0.35678534949539953`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 224}], {
             RGBColor[
             0.6019092601655756, 0.6867200928189938, 0.9624709353645509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 227}], {
             RGBColor[
             0.4900314069116405, 0.5878102265694376, 0.9551265080130549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 259}], {
             RGBColor[
             0.8007477962042493, 0.8448792898490222, 0.9806129038326282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 345}], {
             RGBColor[
             0.7670773504583543, 0.8180313903711476, 0.977401386659423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 350}], {
             RGBColor[
             0.5273081197953102, 0.6233107010129518, 0.9573840940310441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 353}], {
             RGBColor[
             0.8496653857450382, 0.8791494975932964, 0.7395436178949295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 393}], {
             RGBColor[
             0.7140213652809209, 0.7765181844116039, 0.9721306348483233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 400}], {
             RGBColor[
             0.7834338026649409, 0.37076431584912545`, 0.43631998067439115`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 229}], {
             RGBColor[
             0.2068690748506942, 0.33476289229794964`, 0.9350922598261517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 294}], {
             RGBColor[
             0.21277466253925434`, 0.3409700393945122, 0.9354285743084811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 329}], {
             RGBColor[
             0.23907766788565177`, 0.368616165720437, 0.936926491551149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 340}], {
             RGBColor[
             0.2436041993290528, 0.3733738372661213, 0.9371842708204476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 341}], {
             RGBColor[
             0.2325799518711988, 0.3617866542102568, 0.9365564562366354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 343}], {
             RGBColor[
             0.20826813355084325`, 0.33623339169725125`, 0.9351719341494034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 358}], {
             RGBColor[
             0.24670674727990904`, 0.37663481187537284`, 0.9373609563364405]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 231}], {
             RGBColor[
             0.19972682323934088`, 0.32725593300951006`, 0.9346855191628995]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 254}], {
             RGBColor[
             0.1976623221296092, 0.32508601144625143`, 0.934567948878856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 314}], {
             RGBColor[
             0.1955003640293088, 0.322813656406775, 0.9344448285633742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 331}], {
             RGBColor[
             0.22460790707912992`, 0.3534075296769589, 0.9361024600793104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 392}], {
             RGBColor[
             0.20565454435776198`, 0.333486343744197, 0.935023094111316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 222}], {
             RGBColor[
             0.7556819189936763, 0.8084691579297268, 0.9631032253183853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 276}], {
             RGBColor[
             0.46966080217049366`, 0.5783141439540027, 0.951949779691809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 282}], {
             RGBColor[
             0.4376499441056336, 0.5505879476107286, 0.9499100761220066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 305}], {
             RGBColor[
             0.42916789405553485`, 0.5422531768418173, 0.9494057845729981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 339}], {
             RGBColor[
             0.47111694262023773`, 0.5795753796238241, 0.9520425636736524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 361}], {
             RGBColor[
             0.4849252020484565, 0.5915353999172487, 0.952922413754254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 382}], {
             RGBColor[
             0.44118615700326724`, 0.5536508374874307, 0.9501354004808935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 384}], {
             RGBColor[
             0.7469305423915883, 0.7141446268230167, 0.6119725391027997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 248}], {
             RGBColor[
             0.1809198934930053, 0.30748865741789405`, 0.933614492336205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 251}], {
             RGBColor[
             0.1819264333571092, 0.30854659463338063`, 0.9336718132924233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 260}], {
             RGBColor[
             0.1839290162486566, 0.31065143622348573`, 0.9337858574255411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 352}], {
             RGBColor[
             0.1830449444132805, 0.30972222067111355`, 0.9337355108423835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 396}], {
             RGBColor[
             0.18205118127193512`, 0.30867771260133725`, 0.9336789175016247]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 256}], {
             RGBColor[
             0.6811078585940378, 0.7429531062730206, 0.8609992027595657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 316}], {
             RGBColor[
             0.5410265117385101, 0.6349350710702945, 0.9583673358965574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 351}], {
             RGBColor[
             0.33973329445254913`, 0.4686816369880935, 0.9428684830015278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 399}], {
             RGBColor[
             0.36464378874039466`, 0.49025785510237774`, 0.9444557576700642]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 223}], {
             RGBColor[
             0.8898400477329558, 0.6234245980125831, 0.45871942604339044`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 224}], {
             RGBColor[
             0.724417520241849, 0.7830873105778803, 0.9606419773233753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 247}], {
             RGBColor[
             0.8619216604353159, 0.4105330825046606, 0.4320513710856554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 259}], {
             RGBColor[
             0.9232560562805229, 0.9412465076079086, 0.9787839457914527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 292}], {
             RGBColor[
             0.863357086910216, 0.42156639939863494`, 0.43342593709910204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 363}], {
             RGBColor[
             0.6628066494410058, 0.7309294373629389, 0.9563828644799877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 383}], {
             RGBColor[
             0.6547025238599551, 0.723910051109828, 0.9558664767641599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 393}], {
             RGBColor[
             0.8365296253571944, 0.8728854021704904, 0.9703016768071477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 247}], {
             RGBColor[
             0.8452571321859585, 0.34717028337180467`, 0.19090496268508764`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 292}], {
             RGBColor[
             0.8459748454234086, 0.3526869418187919, 0.19159224569181096`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 319}], {
             RGBColor[
             0.8502923449808009, 0.3858731353572784, 0.1957266881438881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 385}], {
             RGBColor[
             0.9042834117433322, 0.6325667276310734, 0.3474148618138784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 393}], {
             RGBColor[
             0.8134681369515452, 0.5633203916020985, 0.4604670120466483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 400}], {
             RGBColor[
             0.8468492899928622, 0.3594083059636659, 0.19242961479906362`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 227}], {
             RGBColor[
             0.3858696957004528, 0.504223043119987, 0.9462592294929938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 259}], {
             RGBColor[
             0.6965860849930616, 0.7612921063995717, 0.9717456253125671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 363}], {
             RGBColor[
             0.4361366781535445, 0.5509750361546019, 0.9493445440011021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 383}], {
             RGBColor[
             0.42803255257249384`, 0.5439556499014909, 0.9488281562852744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 393}], {
             RGBColor[
             0.6098596540697332, 0.6929310009621534, 0.9632633563282622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 235}], {
             RGBColor[
             0.20086558407238086`, 0.32845284284664206`, 0.9347503699076954]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 261}], {
             RGBColor[
             0.19884280647751676`, 0.32632677534293286`, 0.9346351757160992]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 322}], {
             RGBColor[
             0.2017966288426081, 0.3294314299317988, 0.9348033915300026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 327}], {
             RGBColor[
             0.19712268368204472`, 0.3245188172228074, 0.9345372172675908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 335}], {
             RGBColor[
             0.20337317791570175`, 0.3310884829666048, 0.93489317366742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 349}], {
             RGBColor[
             0.2034483891040132, 0.3311675346941849, 0.9348974568333293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 355}], {
             RGBColor[
             0.2083112643931653, 0.336278724947185, 0.9351743903870672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 252}], {
             RGBColor[
             0.19892295516503677`, 0.32641101669523676`, 0.9346397400652842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 274}], {
             RGBColor[
             0.1975222198425889, 0.324938755059595, 0.9345599702608729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 288}], {
             RGBColor[
             0.20281928004263788`, 0.3305063011828612, 0.9348616300029674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 315}], {
             RGBColor[
             0.186507225222572, 0.3133612973229612, 0.9339326826124872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 318}], {
             RGBColor[
             0.20268055409019498`, 0.33036049141111024`, 0.9348537297652024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 322}], {
             RGBColor[
             0.1935079091107788, 0.32071945995846174`, 0.9343313612033369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 243}], {
             RGBColor[
             0.2526928974888643, 0.38292663528882953`, 0.9377018587351249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 306}], {
             RGBColor[
             0.248145898473511, 0.3781474510273044, 0.9374429138678827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 311}], {
             RGBColor[
             0.23829401063491945`, 0.3677924922631779, 0.9368818634300369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 346}], {
             RGBColor[
             0.23870901568862182`, 0.3682286888874592, 0.9369054973539003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 350}], {
             RGBColor[
             0.3112685553301875, 0.44081365131394507`, 0.9411723881594869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 363}], {
             RGBColor[
             0.3242588248996095, 0.45206516990504564`, 0.9420001166496061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 383}], {
             RGBColor[
             0.3161546993185588, 0.44504578365193476`, 0.9414837289337784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 276}], {
             RGBColor[
             0.3015266164865197, 0.4277543234766833, 0.9407208506945814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 282}], {
             RGBColor[
             0.26951575842165965`, 0.40002812713340913`, 0.938681147124779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 301}], {
             RGBColor[
             0.2369380396545014, 0.36636728078923275`, 0.9368046428886814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 305}], {
             RGBColor[
             0.26103370837156087`, 0.39169335636449776`, 0.9381768555757705]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 382}], {
             RGBColor[
             0.27305197131929326`, 0.4030910170101112, 0.9389064714836659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 294}], {
             RGBColor[
             0.20382733943636777`, 0.33156583552032837`, 0.9349190374941501]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 307}], {
             RGBColor[
             0.18847585942484443`, 0.31543045668816716`, 0.9340447934179733]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[
             0.2301303447827652, 0.3592119618462532, 0.9364169547368181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 340}], {
             RGBColor[
             0.23465687622616624`, 0.36396963339193744`, 0.9366747340061166]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 343}], {
             RGBColor[
             0.1993208104479567, 0.32682918782306747`, 0.9346623973350723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 258}], {
             RGBColor[
             0.22938899732612533`, 0.3584327586651811, 0.9363747360958877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 264}], {
             RGBColor[
             0.2405521506109405, 0.3701659405523198, 0.9370104611610526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 279}], {
             RGBColor[
             0.2100811442778375, 0.33813898092284156`, 0.9352751824281966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 299}], {
             RGBColor[
             0.20475753633962784`, 0.33254353144354476`, 0.9349720108316877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 300}], {
             RGBColor[
             0.2086431877242838, 0.3366275974133453, 0.9351932929297377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 328}], {
             RGBColor[
             0.2262385122205931, 0.35512139906697393`, 0.9361953206298528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 331}], {
             RGBColor[
             0.21608777115484973`, 0.34445232661272185`, 0.9356172509428343]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 369}], {
             RGBColor[
             0.1858060573218873, 0.312624325402729, 0.9338927521378282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 372}], {
             RGBColor[
             0.18557674124721385`, 0.3123832996687683, 0.9338796929266182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 392}], {
             RGBColor[
             0.1971344084334818, 0.32453114067996, 0.9345378849748398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 277}], {
             RGBColor[
             0.18773724237763328`, 0.31465412334052256`, 0.9340027302698206]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 373}], {
             RGBColor[
             0.19417254912152382`, 0.3214180387503654, 0.934369211468702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 390}], {
             RGBColor[
             0.20167142330655186`, 0.3292998309749142, 0.9347962612599492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 256}], {
             RGBColor[
             0.9813174831621745, 0.9842395002462874, 0.8561565043579783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 257}], {
             RGBColor[
             0.9698756400386146, 0.9770538821816868, 0.9358768631099392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 310}], {
             RGBColor[
             0.8744547972846617, 0.4623474753415331, 0.4270524883908231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 316}], {
             RGBColor[
             0.8412361363066468, 0.8762214650435611, 0.9535246374949702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 389}], {
             RGBColor[
             0.9817271461205633, 0.9825466050438816, 0.7139976792857294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 298}], {
             RGBColor[
             0.22620097648238727`, 0.3550819466262163, 0.936193183025091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 365}], {
             RGBColor[
             0.27647661087306347`, 0.4079248260301478, 0.9390563060275041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 261}], {
             RGBColor[
             0.19122633777104836`, 0.31832138382042696`, 0.9342014290908216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 322}], {
             RGBColor[
             0.1941801601361397, 0.32142603840929285`, 0.934369644904725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 327}], {
             RGBColor[
             0.1895062149755763, 0.31651342570030144`, 0.934103470642313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 335}], {
             RGBColor[
             0.19575670920923333`, 0.32308309144409886`, 0.9344594270421422]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 349}], {
             RGBColor[
             0.19583192039754477`, 0.3231621431716789, 0.9344637102080516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 355}], {
             RGBColor[
             0.2006947956866969, 0.3282733334246791, 0.9347406437617896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 262}], {
             RGBColor[
             0.4369845815472029, 0.5513866495573997, 0.9494877616771007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 284}], {
             RGBColor[
             0.6247504035752902, 0.7047458827568778, 0.9646230139836673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 334}], {
             RGBColor[
             0.7349237676396162, 0.7451154652166593, 0.6272347577119612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 366}], {
             RGBColor[
             0.7514680031030527, 0.8004311372612268, 0.7333352246803804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 376}], {
             RGBColor[
             0.397907468442853, 0.5154535439144465, 0.9470741986312354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 397}], {
             RGBColor[
             0.4369077612514729, 0.5513201116783387, 0.9494828667557864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 307}], {
             RGBColor[
             0.1806275543927051, 0.307181390488109, 0.9335978440569198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 324}], {
             RGBColor[
             0.18395646599811732`, 0.31068028765058353`, 0.9337874206481647]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 269}], {
             RGBColor[
             0.4302703250067166, 0.5456389418366184, 0.9490411897361934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 309}], {
             RGBColor[
             0.6022520031590326, 0.6871316854403461, 0.9624067531432969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 323}], {
             RGBColor[
             0.4638795886223883, 0.5747495967298069, 0.9511827422942791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 362}], {
             RGBColor[
             0.6492041088152176, 0.7238110272281775, 0.9670865002427318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 365}], {
             RGBColor[
             0.4065771465503478, 0.524864785093759, 0.9475407198960643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 377}], {
             RGBColor[
             0.3809157120608543, 0.4978929904163819, 0.9460793391645779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 385}], {
             RGBColor[
             0.750777447641219, 0.8006120212149852, 0.7940547292395577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 388}], {
             RGBColor[
             0.38895939974165, 0.5063474161681534, 0.9465374152784297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 272}], {
             RGBColor[
             0.18799208314490007`, 0.3149219771447579, 0.9340172430745133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 342}], {
             RGBColor[
             0.18286346184170274`, 0.30953147098172573`, 0.9337251756784115]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 374}], {
             RGBColor[
             0.18148468566837106`, 0.3080822898040957, 0.933646656415057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 242}], {
             RGBColor[
             0.31065498243158685`, 0.4409219663646659, 0.9411098670507269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 255}], {
             RGBColor[
             0.32755009808125596`, 0.4555556663672059, 0.9421864088801596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 312}], {
             RGBColor[
             0.41436397282412324`, 0.5281836244089898, 0.9484270661099586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 331}], {
             RGBColor[
             0.26094013118712034`, 0.3915950008105146, 0.9381715264935517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 359}], {
             RGBColor[
             0.3033005319170658, 0.43455191097441853`, 0.9406412479672268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 360}], {
             RGBColor[
             0.4718334584098283, 0.5745274932673213, 0.9531648972863125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 380}], {
             RGBColor[
             0.5006467932710101, 0.5970366894503322, 0.9560367412293518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 392}], {
             RGBColor[
             0.24198676846575243`, 0.37167381487775275`, 0.9370921605255572]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 255}], {
             RGBColor[
             0.3572936731332409, 0.48389155439101317`, 0.9439874148030284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 312}], {
             RGBColor[
             0.4441075478761082, 0.5565195124327971, 0.9502280720328274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 331}], {
             RGBColor[
             0.2906837062391053, 0.4199308888343219, 0.9399725324164205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 380}], {
             RGBColor[
             0.5303903683229951, 0.6253725774741394, 0.9578377471522206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 267}], {
             RGBColor[
             0.2144789920516021, 0.342761397772722, 0.9355256333528797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 275}], {
             RGBColor[
             0.21276908993785693`, 0.3409641822371201, 0.9354282569570754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 311}], {
             RGBColor[
             0.21699506567726595`, 0.34540595068157653`, 0.9356689200236639]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 326}], {
             RGBColor[
             0.23648276332684243`, 0.36588875650267677`, 0.9367787155753422]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 344}], {
             RGBColor[
             0.2114782278514492, 0.3396074043389222, 0.9353547442709138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 346}], {
             RGBColor[
             0.21741007073096835`, 0.3458421473058579, 0.9356925539475274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 363}], {
             RGBColor[
             0.302959879941956, 0.42967862832344433`, 0.9407871732432331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 383}], {
             RGBColor[
             0.29485575436090533`, 0.42265924207033345`, 0.9402707855274055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 302}], {
             RGBColor[
             0.18853043849765405`, 0.3154878227542032, 0.9340479016154273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 352}], {
             RGBColor[
             0.1906398234149592, 0.3177049200450192, 0.9341680279659126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 396}], {
             RGBColor[
             0.1896460602736138, 0.31666041197524286`, 0.9341114346251538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 248}], {
             RGBColor[
             0.19980719089443424`, 0.32734040451061686`, 0.9346900959819637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 251}], {
             RGBColor[
             0.20081373075853814`, 0.3283983417261034, 0.9347474169381822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 260}], {
             RGBColor[
             0.20281631365008554`, 0.33050318331620854`, 0.9348614610713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 326}], {
             RGBColor[
             0.22913658446266597`, 0.35816745674178546`, 0.9363603615567251]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 271}], {
             RGBColor[
             0.8182267475230357, 0.1411043452395526, 0.1650872600532131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 287}], {
             RGBColor[
             0.8173321632588791, 0.13422817857592148`, 0.1642306051515684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 292}], {
             RGBColor[
             0.8180564581257688, 0.1397954263108694, 0.1649241907340759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 319}], {
             RGBColor[
             0.822373957683161, 0.17298161984935592`, 0.16905863318615305`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 362}], {
             RGBColor[
             0.808649465228358, 0.36847454946527913`, 0.43610132085825937`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 385}], {
             RGBColor[
             0.8763650244456923, 0.41967521212315095`, 0.3207468068561434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 393}], {
             RGBColor[
             0.7855497496539053, 0.35042887609417595`, 0.43379895708891325`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 400}], {
             RGBColor[
             0.8189309026952224, 0.14651679045574345`, 0.16576155984132857`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 251}], {
             RGBColor[
             0.1839193268501145, 0.3106412520512747, 0.9337853056286283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 260}], {
             RGBColor[
             0.1859219097416619, 0.3127460936413798, 0.933899349761746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 275}], {
             RGBColor[
             0.18852850716525682`, 0.3154857928014001, 0.9340477916289045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 268}], {
             RGBColor[
             0.18564105657677243`, 0.3124508991579618, 0.9338833555894905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 279}], {
             RGBColor[
             0.19132944320701362`, 0.3184297541708887, 0.934207300792869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 299}], {
             RGBColor[
             0.186005835268804, 0.3128343046915919, 0.9339041291963601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 300}], {
             RGBColor[
             0.18989148665345995`, 0.3169183706613924, 0.9341254112944102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 370}], {
             RGBColor[
             0.18458433002004276`, 0.31134021254650546`, 0.9338231765753717]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 265}], {
             RGBColor[
             0.19635832810443649`, 0.32371543104779843`, 0.9344936883482087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 321}], {
             RGBColor[
             0.18913677562513462`, 0.3161251215191795, 0.934082431617842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 325}], {
             RGBColor[
             0.21599606078555122`, 0.34435593319981583`, 0.9356120281729761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 375}], {
             RGBColor[
             0.19825790374427554`, 0.32571200548532114`, 0.9346018663707272]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 381}], {
             RGBColor[
             0.19153445496524343`, 0.31864523452728444`, 0.9342189759092124]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 260}], {
             RGBColor[
             0.1869284496057658, 0.31380403085686637`, 0.9339566707179645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 275}], {
             RGBColor[
             0.1895350470293607, 0.3165437300168866, 0.9341051125851229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 274}], {
             RGBColor[
             0.20454056169243495`, 0.3323154773323579, 0.9349596544465153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 288}], {
             RGBColor[
             0.20983762189248398`, 0.33788302345562404`, 0.9352613141886098]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 318}], {
             RGBColor[
             0.20969889594004104`, 0.3377372136838731, 0.9352534139508448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 283}], {
             RGBColor[
             0.8607691122014759, 0.3856977852240938, 0.20253221045503758`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 332}], {
             RGBColor[
             0.8227299040516889, 0.17571757961455517`, 0.16939948783063935`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 334}], {
             RGBColor[
             0.8701987937776897, 0.4222457469371983, 0.21448170260215638`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 364}], {
             RGBColor[
             0.8572410457828872, 0.37171017753282953`, 0.19969344540027856`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 366}], {
             RGBColor[
             0.8812282840866474, 0.45912286163357663`, 0.28521534724776915`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 391}], {
             RGBColor[
             0.8235396690014747, 0.18194178785987172`, 0.17017491966105283`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 314}], {
             RGBColor[
             0.1849157269952969, 0.31168853177927935`, 0.9338420491428545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 369}], {
             RGBColor[
             0.1837415562121556, 0.31045440383947037`, 0.9337751818537847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 312}], {
             RGBColor[
             0.46100266352577723`, 0.571153212435337, 0.9513046138622602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 331}], {
             RGBColor[
             0.30757882188877433`, 0.4345645888368619, 0.9410490742458533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 356}], {
             RGBColor[
             0.6597861746771188, 0.7286564919053182, 0.9611997608615672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 359}], {
             RGBColor[
             0.3499392226187198, 0.4775214990007658, 0.9435187957195283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 360}], {
             RGBColor[
             0.5184721491114823, 0.6174970812936685, 0.956042445038614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 380}], {
             RGBColor[
             0.5472854839726642, 0.6400062774766795, 0.9589142889816533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 310}], {
             RGBColor[
             0.8817791092522581, 0.4669114753460718, 0.37441947014658894`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 316}], {
             RGBColor[
             0.8522226042580414, 0.8830674650503693, 0.8745751101286188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 319}], {
             RGBColor[
             0.88573090588642, 0.4972867159645674, 0.37820371506637834`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 384}], {
             RGBColor[
             0.9629443447193516, 0.8827390749129462, 0.5213129511813582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 310}], {
             RGBColor[
             0.8741512138365515, 0.46212106330300473`, 0.4275663759812295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 356}], {
             RGBColor[
             0.9574019127188883, 0.9677509967704889, 0.9569916297931109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 360}], {
             RGBColor[
             0.816087887153252, 0.8565915861588391, 0.9518343139701578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 389}], {
             RGBColor[
             0.981271770948398, 0.982206986986089, 0.7147685106713391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 264}], {
             RGBColor[
             0.24881577416889822`, 0.37885153285572853`, 0.9374810622977428]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 279}], {
             RGBColor[
             0.2183447678357952, 0.34682457322625027`, 0.9357457835648868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 281}], {
             RGBColor[
             0.318201913769557, 0.44345916858997797`, 0.9417371947060786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 300}], {
             RGBColor[
             0.21690681128224154`, 0.345313189716754, 0.9356638940664279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 328}], {
             RGBColor[
             0.23450213577855084`, 0.36380699137038264`, 0.936665921766543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 394}], {
             RGBColor[
             0.29763886748570073`, 0.42564849142765915`, 0.9404269355800592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 271}], {
             RGBColor[
             0.8451433755388915, 0.40965410113712897`, 0.44115450773017084`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 287}], {
             RGBColor[
             0.8433542070105785, 0.39590176780986674`, 0.4394411979268815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 292}], {
             RGBColor[
             0.8448027967443577, 0.4070362632797625, 0.4408283690918966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 345}], {
             RGBColor[
             0.8617541752858404, 0.8926034039517254, 0.9866760766074392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 350}], {
             RGBColor[
             0.6219849446227963, 0.6978827145935297, 0.9666587839790601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 353}], {
             RGBColor[
             0.9443422105725244, 0.9537215111738743, 0.7488183078429457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 393}], {
             RGBColor[
             0.808698190108407, 0.8510901979921818, 0.9814053247963395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 400}], {
             RGBColor[
             0.8465516858832649, 0.4204789915695107, 0.44250310730640185`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 327}], {
             RGBColor[
             0.1874834373807122, 0.31438735819659225`, 0.9339882764507168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 335}], {
             RGBColor[
             0.19373393161436922`, 0.3209570239403897, 0.934344232850546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 349}], {
             RGBColor[
             0.19380914280268063`, 0.32103607566796977`, 0.9343485160164554]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 355}], {
             RGBColor[
             0.19867201809183277`, 0.32614726592096993`, 0.9346254495701933]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 284}], {
             RGBColor[
             0.5520990373737982, 0.6433480852372535, 0.9595712205145508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 325}], {
             RGBColor[
             0.3013026030921642, 0.42887910004945207`, 0.9406582888215985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 376}], {
             RGBColor[
             0.3252561022413611, 0.4540557463948223, 0.9420224051621189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 397}], {
             RGBColor[
             0.364256395049981, 0.48992231415871446`, 0.9444310732866698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 336}], {
             RGBColor[
             0.2683165494931898, 0.3993480841421268, 0.9385916026036494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 359}], {
             RGBColor[
             0.31376085658735253`, 0.4455463754257799, 0.941236947982536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 360}], {
             RGBColor[
             0.48229378308011506`, 0.5855219577186828, 0.9537605973016217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 279}], {
             RGBColor[
             0.22950792112061041`, 0.35855775511338905`, 0.9363815086300517]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 281}], {
             RGBColor[
             0.3293650670543722, 0.4551923504771167, 0.9423729197712435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 328}], {
             RGBColor[
             0.24566528906336602`, 0.3755401732575213, 0.9373016468317077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 394}], {
             RGBColor[
             0.30880202077051594`, 0.4373816733147978, 0.941062660645224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 321}], {
             RGBColor[
             0.19177497299708612`, 0.31889803422847507`, 0.9342326730553113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 325}], {
             RGBColor[
             0.2186342581575027, 0.34712884590911136`, 0.9357622696104455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 375}], {
             RGBColor[
             0.20089610111622702`, 0.32848491819461667`, 0.9347521078081966]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 381}], {
             RGBColor[
             0.19417265233719494`, 0.3214181472365799, 0.9343692173466818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 358}], {
             RGBColor[
             0.4679094050103473, 0.5710147999295367, 0.9528445815300333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 384}], {
             RGBColor[
             0.7959032258697958, 0.7536598609266292, 0.6159939861993788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 275}], {
             RGBColor[
             0.19585412945824818`, 0.323185486302614, 0.9344649749812033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 306}], {
             RGBColor[
             0.20993199303624877`, 0.33798221351119695`, 0.9352666884856375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 311}], {
             RGBColor[
             0.20008010519765723`, 0.3276272547470704, 0.9347056380477918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 317}], {
             RGBColor[
             0.1930340826347562, 0.32022143828982824`, 0.9343043774864909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 344}], {
             RGBColor[
             0.1945632673718405, 0.321828708404416, 0.9343914622950418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 346}], {
             RGBColor[
             0.20049511025135958`, 0.32806345137135173`, 0.9347292719716551]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 354}], {
             RGBColor[
             0.19683262012965425`, 0.3242139420381536, 0.9345206985773926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 279}], {
             RGBColor[
             0.19334852815726622`, 0.3205519404709839, 0.9343222846938173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 299}], {
             RGBColor[
             0.18802492021905656`, 0.3149564909916871, 0.9340191130973085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 300}], {
             RGBColor[
             0.1919105716037125, 0.31904055696148764`, 0.9342403951953585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 370}], {
             RGBColor[
             0.18660341497029534`, 0.3134623988466007, 0.9339381604763201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 371}], {
             RGBColor[
             0.1838466718007321, 0.3105648869877775, 0.9337811680310495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 309}], {
             RGBColor[
             0.5253850164437505, 0.6220146854886827, 0.9571050895141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 323}], {
             RGBColor[
             0.38701260190710624`, 0.5096325967781434, 0.9458810786650822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 362}], {
             RGBColor[
             0.5723371220999356, 0.658694027276514, 0.9617848366135348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 365}], {
             RGBColor[
             0.3297101598350657, 0.4597477851420956, 0.9422390562668672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 377}], {
             RGBColor[
             0.30404872534557215`, 0.4327759904647185, 0.9407776755353809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 388}], {
             RGBColor[
             0.3120924130263679, 0.44123041621648995`, 0.9412357516492327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 336}], {
             RGBColor[
             0.2213730230293102, 0.3500074614371033, 0.9359182382182554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 357}], {
             RGBColor[
             0.1969743042117703, 0.32436286099174727`, 0.9345287672762663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 287}], {
             RGBColor[
             0.819108168528313, 0.14787933332726222`, 0.1659313098032894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 292}], {
             RGBColor[
             0.8198324633952027, 0.15344658106221012`, 0.16662489538579692`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 303}], {
             RGBColor[
             0.8446451878986901, 0.3069179972587709, 0.1889269695655514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 333}], {
             RGBColor[
             0.8645940127585953, 0.4248527314211257, 0.4322347939799689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 337}], {
             RGBColor[
             0.8656615757726001, 0.4256489181689964, 0.43042768826228606`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 345}], {
             RGBColor[
             0.8226964117082949, 0.39175550148521254`, 0.4390134962813673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 353}], {
             RGBColor[
             0.8777551018994175, 0.4325009062999784, 0.2804416504383717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 385}], {
             RGBColor[
             0.8781410297151262, 0.43332636687449166`, 0.3224475115078644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 391}], {
             RGBColor[
             0.8200799062622772, 0.15534853536870052`, 0.16686184695475423`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 400}], {
             RGBColor[
             0.8207069079646563, 0.1601679452070842, 0.16746226449304957`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 308}], {
             RGBColor[
             0.20474955864050876`, 0.33253514637595527`, 0.9349715565135248]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 342}], {
             RGBColor[
             0.19152273141080622`, 0.31863291232825464`, 0.9342183082701306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 348}], {
             RGBColor[
             0.1988777254844435, 0.3263634774332058, 0.9346371643018856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 374}], {
             RGBColor[
             0.19014395523747457`, 0.3171837311506246, 0.934139789006776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 375}], {
             RGBColor[
             0.1997235147350348, 0.3272524555617131, 0.9346853307484737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 378}], {
             RGBColor[
             0.2184441934159871, 0.34692907581497784`, 0.9357514457045917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 281}], {
             RGBColor[
             0.46139853851670076`, 0.5721415288193888, 0.9511515046102453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 293}], {
             RGBColor[
             0.4190878106551068, 0.5354941029446921, 0.9484555024448121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 394}], {
             RGBColor[
             0.4408354922328445, 0.55433085165707, 0.9498412454842259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 288}], {
             RGBColor[
             0.20843688657003606`, 0.3364107618199823, 0.9351815443841986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 318}], {
             RGBColor[
             0.20829816061759315`, 0.33626495204823137`, 0.9351736441464337]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 311}], {
             RGBColor[
             0.19837020308391207`, 0.32583003921146847`, 0.9346082616519875]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 317}], {
             RGBColor[
             0.19132418052101102`, 0.3184242227542263, 0.9342070010906866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 344}], {
             RGBColor[
             0.19285336525809532`, 0.32003149286881416`, 0.9342940858992375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 346}], {
             RGBColor[
             0.1987852081376144, 0.3262662358357499, 0.9346318955758508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 282}], {
             RGBColor[
             0.3470343998180849, 0.475005487491495, 0.9433337029793059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 301}], {
             RGBColor[
             0.3144566810509267, 0.44134464114731864`, 0.9414571987432081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 305}], {
             RGBColor[
             0.33855234976798615`, 0.46667071672258365`, 0.9428294114302973]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 339}], {
             RGBColor[
             0.38050139833268903`, 0.5039929195045905, 0.9454661905309516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 361}], {
             RGBColor[
             0.3943096577609078, 0.5159529397980152, 0.9463460406115533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 382}], {
             RGBColor[
             0.35057061271571854`, 0.4780683773681971, 0.9435590273381926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 373}], {
             RGBColor[
             0.19154984531155025`, 0.31866141075705723`, 0.9342198523666666]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 390}], {
             RGBColor[
             0.19904871949657826`, 0.326543202981606, 0.9346469021579138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 296}], {
             RGBColor[
             0.1835851599868279, 0.3102900214905575, 0.9337662753201197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 302}], {
             RGBColor[
             0.19139766926121787`, 0.31850146407963903`, 0.9342111861657245]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 330}], {
             RGBColor[
             0.18839714683821507`, 0.31534772476895345`, 0.9340403108526096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 367}], {
             RGBColor[
             0.18709347932173553`, 0.31397748755183885`, 0.9339660689161493]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 299}], {
             RGBColor[
             0.19371330684929777`, 0.320935346004614, 0.9343430583006869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 300}], {
             RGBColor[
             0.1975989582339537, 0.32501941197441453`, 0.9345643403987369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 328}], {
             RGBColor[
             0.215194282730263, 0.3435132136280431, 0.9355663680988517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 370}], {
             RGBColor[
             0.19229180160053655`, 0.3194412538595276, 0.9342621056796985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 371}], {
             RGBColor[
             0.1895350584309733, 0.3165437420007044, 0.9341051132344278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 291}], {
             RGBColor[
             0.20219476439486456`, 0.32984989564047235`, 0.9348260647607148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 336}], {
             RGBColor[
             0.22186501043454393`, 0.3505245713938071, 0.9359462561731533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 368}], {
             RGBColor[
             0.19638103924398845`, 0.323739301895437, 0.934494981714008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 387}], {
             RGBColor[
             0.19723551682458454`, 0.32463741200965124`, 0.9345436429481366]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 392}], {
             RGBColor[
             0.20599555407739328`, 0.33384476658079454`, 0.9350425141103704]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 293}], {
             RGBColor[
             0.356440478793437, 0.4831525603366694, 0.9439330500141462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 394}], {
             RGBColor[
             0.3781881603711747, 0.5019893090490473, 0.9453187930535599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 301}], {
             RGBColor[
             0.2824458229860667, 0.41361844480404447`, 0.9394174951734057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 305}], {
             RGBColor[
             0.30654149170312617`, 0.4389445203793095, 0.9407897078604948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 313}], {
             RGBColor[
             0.2998205585054363, 0.43188039345676055`, 0.940406960657616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 339}], {
             RGBColor[
             0.34849054026782905`, 0.4762667231613163, 0.9434264869611491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 340}], {
             RGBColor[
             0.29320777122887487`, 0.42492993475416496`, 0.9400303722049579]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 361}], {
             RGBColor[
             0.36229879969604784`, 0.48822674345474093`, 0.9443063370417508]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 382}], {
             RGBColor[
             0.3185597546508585, 0.45034218102492296`, 0.9415193237683902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 312}], {
             RGBColor[
             0.7398695405352704, 0.7057918843470511, 0.6108133774642039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 332}], {
             RGBColor[
             0.8558441265023222, 0.3478421869979039, 0.19781603858755223`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 334}], {
             RGBColor[
             0.9460670651662169, 0.8226245407866379, 0.2820057220570269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 356}], {
             RGBColor[
             0.9386530516866118, 0.8632951638170323, 0.6207085244635109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 360}], {
             RGBColor[
             0.7973390261209754, 0.7521357532053826, 0.6155512086405578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 364}], {
             RGBColor[
             0.9266304431740131, 0.7468211866800847, 0.25982333625421017`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 366}], {
             RGBColor[
             0.9626113006296535, 0.8779402128312055, 0.388106189025446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 380}], {
             RGBColor[
             0.8261523609821573, 0.7746449493883936, 0.6184230525835972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 389}], {
             RGBColor[
             0.9625229099161214, 0.8777511540326326, 0.378485405341739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 334}], {
             RGBColor[
             0.8500382234662116, 0.8370769008965131, 0.6373182165494112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 366}], {
             RGBColor[
             0.8665824589296481, 0.8923925729410807, 0.7434186835178305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 397}], {
             RGBColor[
             0.5520222170780682, 0.6432815473581924, 0.9595663255932364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 324}], {
             RGBColor[
             0.1849819453905557, 0.31175813151118514`, 0.9338458201825032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 290}], {
             RGBColor[
             0.28938656912218486`, 0.4203385400712017, 0.9398338164907357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 304}], {
             RGBColor[
             0.3017569575169641, 0.43334060260203944`, 0.9405382918094687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 386}], {
             RGBColor[
             0.331585149915525, 0.4616241237277755, 0.94234929043675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 292}], {
             RGBColor[
             0.8180432948668896, 0.1396942477349479, 0.16491158558250754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 303}], {
             RGBColor[
             0.8428560193703771, 0.29316566393150867`, 0.187213659762262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 353}], {
             RGBColor[
             0.8759659333711045, 0.41874857297271617`, 0.27872834063508234`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 385}], {
             RGBColor[
             0.8763518611868132, 0.41957403354722944`, 0.320734201704575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 391}], {
             RGBColor[
             0.8182907377339641, 0.1415962020414383, 0.16514853715146482`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 400}], {
             RGBColor[
             0.8189177394363433, 0.14641561187982197`, 0.1657489546897602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 318}], {
             RGBColor[
             0.21359522081764215`, 0.3418324981714975, 0.9354753038885282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 304}], {
             RGBColor[
             0.2699001201696922, 0.4010125173273108, 0.9386817846109934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 338}], {
             RGBColor[
             0.2338329245191738, 0.3631036079063329, 0.9366278111753308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 336}], {
             RGBColor[
             0.21513079622652476`, 0.34344648528733734`, 0.9355627526363838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 368}], {
             RGBColor[
             0.1896468250359693, 0.3166612157889672, 0.9341114781772385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 387}], {
             RGBColor[
             0.1905013026165654, 0.3175593259031815, 0.9341601394113672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 303}], {
             RGBColor[
             0.8443046091041563, 0.3043001594014045, 0.18860083092727706`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 309}], {
             RGBColor[
             0.778783487932468, 0.35505497183403256`, 0.43435605547208284`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 362}], {
             RGBColor[
             0.810084891703258, 0.3795078663592535, 0.437475886871706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 385}], {
             RGBColor[
             0.8778004509205923, 0.4307085290171253, 0.32212137286959003`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 400}], {
             RGBColor[
             0.8203663291701224, 0.1575501073497178, 0.16713612585477525`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 394}], {
             RGBColor[
             0.3358774325095808, 0.4653418831743506, 0.9426227908881267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 301}], {
             RGBColor[
             0.22980051567191817`, 0.3588652905383795, 0.9363981714568937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 313}], {
             RGBColor[
             0.24717525119128783`, 0.3771272391910956, 0.937387636941104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 329}], {
             RGBColor[
             0.23603593247132534`, 0.36541910894281576`, 0.9367532692191475]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 340}], {
             RGBColor[
             0.24056246391472638`, 0.3701767804885, 0.937011048488446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 343}], {
             RGBColor[
             0.20522639813651683`, 0.33303633491963003`, 0.9349987118174017]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 330}], {
             RGBColor[
             0.18388840354746627`, 0.31060874969954066`, 0.9337835445922895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 367}], {
             RGBColor[
             0.18258473603098674`, 0.3092385124824261, 0.9337093026558292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 398}], {
             RGBColor[
             0.17994179284220208`, 0.3064606116187368, 0.933558790951112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 325}], {
             RGBColor[
             0.267416015836295, 0.3984015661715987, 0.9385403185441094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 375}], {
             RGBColor[
             0.2496778587950193, 0.3797576384571041, 0.9375301567418605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 376}], {
             RGBColor[
             0.2913695149854919, 0.423578212516969, 0.9399044348846297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 378}], {
             RGBColor[
             0.2683985374759716, 0.3994342587103688, 0.9385962716979784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 397}], {
             RGBColor[
             0.33036980779411174`, 0.4594447802808611, 0.9423131030091806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 320}], {
             RGBColor[
             0.19458686072830475`, 0.3218535065179652, 0.9343928059017892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 347}], {
             RGBColor[
             0.1948950544058417, 0.32217743761366435`, 0.9344103570757931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 373}], {
             RGBColor[
             0.20172543232639267`, 0.32935659787913657`, 0.93479933699373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 390}], {
             RGBColor[
             0.2092243065114207, 0.3372383901036854, 0.935226386784977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 300}], {
             RGBColor[
             0.19227535029574405`, 0.31942396249511773`, 0.934261168802228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 370}], {
             RGBColor[
             0.1869681936623269, 0.3138458043802308, 0.9339589340831895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 371}], {
             RGBColor[
             0.18421145049276366`, 0.3109482925214076, 0.933801941637919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 370}], {
             RGBColor[
             0.19085384504698283`, 0.3179298703500313, 0.9341802161812396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 371}], {
             RGBColor[
             0.1880971018774196, 0.31503235849120814`, 0.934023223735969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 305}], {
             RGBColor[
             0.27396377293596785`, 0.4052836740351331, 0.9389132036243971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 313}], {
             RGBColor[
             0.2672428397382781, 0.39821954711258417`, 0.9385304564215183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 329}], {
             RGBColor[
             0.25610352101831557`, 0.38651141686430435`, 0.9378960886995618]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 339}], {
             RGBColor[
             0.3159128215006708, 0.4426058768171399, 0.9415499827250514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 340}], {
             RGBColor[
             0.26063005246171667`, 0.3912690884099886, 0.9381538679688604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 361}], {
             RGBColor[
             0.3297210809288895, 0.45456589711056455`, 0.9424298328056531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 382}], {
             RGBColor[
             0.2859820358837003, 0.41668133468074653`, 0.9396428195322926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 367}], {
             RGBColor[
             0.19039724530537674`, 0.31744995507150764`, 0.934154213501434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 377}], {
             RGBColor[
             0.22469777382228445`, 0.35350198532189486`, 0.9361075778573873]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 353}], {
             RGBColor[
             0.9435949291122223, 0.7996173553563373, 0.3704770005960165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 385}], {
             RGBColor[
             0.9441738208357854, 0.8008555462181073, 0.4334857922002555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 391}], {
             RGBColor[
             0.8447994948383054, 0.3081040680143853, 0.18907473406519165`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 400}], {
             RGBColor[
             0.8460534982430635, 0.31774288769115266`, 0.1902755691417824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 338}], {
             RGBColor[
             0.24620331291395298`, 0.37610567043717064`, 0.9373322864940637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 313}], {
             RGBColor[
             0.29133850845533754`, 0.4235456226878492, 0.9399026691086074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 329}], {
             RGBColor[
             0.28019918973537505`, 0.41183749243956935`, 0.9392683013866509]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 339}], {
             RGBColor[
             0.3400084902177303, 0.4679319523924049, 0.9429221954121405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 340}], {
             RGBColor[
             0.2847257211787761, 0.4165951639852536, 0.9395260806559493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 361}], {
             RGBColor[
             0.353816749645949, 0.47989197268582956`, 0.9438020454927423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 382}], {
             RGBColor[
             0.31007770460075973`, 0.44200741025601153`, 0.9410150322193817]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 308}], {
             RGBColor[
             0.2175738595337591, 0.3460142997224009, 0.9357018814775424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 311}], {
             RGBColor[
             0.21244806666191265`, 0.3406267664200514, 0.9354099751564218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 346}], {
             RGBColor[
             0.21286307171561503`, 0.3410629630443328, 0.9354336090802852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 348}], {
             RGBColor[
             0.21170202637769384`, 0.33984263077965143`, 0.9353674892659032]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 350}], {
             RGBColor[
             0.2854226113571807, 0.41364792547081863`, 0.9397004998858718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 354}], {
             RGBColor[
             0.2092005815939097, 0.33721345371113465`, 0.9352250356860227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 378}], {
             RGBColor[
             0.23126849430923743`, 0.36040822916142345`, 0.9364817706686093]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 343}], {
             RGBColor[
             0.1898749181249935, 0.3169009560874688, 0.9341244677412249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 348}], {
             RGBColor[
             0.20697593141094872`, 0.33487520531787435`, 0.9350983451491781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 354}], {
             RGBColor[
             0.20447448662716458`, 0.33224602824935756`, 0.9349558915692975]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 374}], {
             RGBColor[
             0.1982421611639798, 0.32569545903529307`, 0.9346009698540684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 378}], {
             RGBColor[
             0.22654239934249232`, 0.35544080369964637`, 0.9362126265518842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 323}], {
             RGBColor[
             0.5589942800594222, 0.6511253403818711, 0.9592466420721857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 362}], {
             RGBColor[
             0.7443188002522516, 0.8001867708802417, 0.9751504000206381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 365}], {
             RGBColor[
             0.5016918379873817, 0.6012405287458232, 0.9556046196739707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 385}], {
             RGBColor[
             0.845892139078253, 0.8769877648670494, 0.8021186290174642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 316}], {
             RGBColor[
             0.7883915446819063, 0.3948994518775877, 0.4393315589045834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 319}], {
             RGBColor[
             0.8284925866386836, 0.2200120832018078, 0.17491783918396456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 384}], {
             RGBColor[
             0.8622060383227799, 0.39468052511930574`, 0.20382345293974308`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 317}], {
             RGBColor[
             0.19555015626042008`, 0.32286599119868276`, 0.934447664157275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 344}], {
             RGBColor[
             0.19707934099750435`, 0.3244732613132706, 0.9345347489658259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 346}], {
             RGBColor[
             0.20301118387702347`, 0.33070800428020625`, 0.9348725586424393]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 354}], {
             RGBColor[
             0.19934869375531813`, 0.32685849494700814`, 0.9346639852481768]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 356}], {
             RGBColor[
             0.746600049419986, 0.8012844499471021, 0.9674404180913663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 359}], {
             RGBColor[
             0.4367530973615871, 0.5501494570425497, 0.9497594529493274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 360}], {
             RGBColor[
             0.6052860238543496, 0.6901250393354524, 0.9622831022684131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 380}], {
             RGBColor[
             0.6340993587155315, 0.7126342355184634, 0.9651549462114524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 389}], {
             RGBColor[
             0.7704699076494956, 0.8157404401627024, 0.7252172989695943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 329}], {
             RGBColor[
             0.27347825653768526`, 0.4047733655170204, 0.9388855541837721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 339}], {
             RGBColor[
             0.3332875570200404, 0.460867825469856, 0.9425394482092617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 340}], {
             RGBColor[
             0.2780047879810863, 0.40953103706270466`, 0.9391433334530706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 358}], {
             RGBColor[
             0.28110733593194254`, 0.4127920116719563, 0.9393200189690635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 361}], {
             RGBColor[
             0.3470958164482592, 0.47282784576328063`, 0.9434192982898635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 369}], {
             RGBColor[
             0.1815795981118552, 0.30818204879999395`, 0.9336520615383029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 322}], {
             RGBColor[
             0.18811052101816012`, 0.31504646285894905`, 0.9340239879361825]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 351}], {
             RGBColor[
             0.5108480401165528, 0.6087959957654421, 0.956444390370581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 399}], {
             RGBColor[
             0.5357585344043984, 0.6303722138797264, 0.9580316650391174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 344}], {
             RGBColor[
             0.19003331843460333`, 0.31706744485602845`, 0.9341334884045249]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 346}], {
             RGBColor[
             0.19596516131412245`, 0.3233021878229641, 0.9344712980811385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 354}], {
             RGBColor[
             0.19230267119241712`, 0.319452678489766, 0.934262724686876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 322}], {
             RGBColor[
             0.20428384988578308`, 0.3320456569470981, 0.9349450350888977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 384}], {
             RGBColor[
             0.8661578349569418, 0.4250557657378013, 0.20760769785953248`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 347}], {
             RGBColor[
             0.1840162025368019, 0.3107430745402564, 0.9337908225556705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 398}], {
             RGBColor[
             0.182257588923795, 0.30889466013044303`, 0.9336906721120455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 375}], {
             RGBColor[
             0.19367454863692518`, 0.3208946086659977, 0.9343408510778299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 381}], {
             RGBColor[
             0.18695109985789307`, 0.313827837707961, 0.9339579606163151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 327}], {
             RGBColor[
             0.19043725974580353`, 0.3174920127854582, 0.9341564922646202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 335}], {
             RGBColor[
             0.19668775397946056`, 0.3240616785292556, 0.9345124486644494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 349}], {
             RGBColor[
             0.19676296516777197`, 0.32414073025683565`, 0.9345167318303588]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 355}], {
             RGBColor[
             0.2016258404569241, 0.32925192050983587`, 0.9347936653840967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 362}], {
             RGBColor[
             0.6059463857156073, 0.6878046821697024, 0.9639263891716204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 365}], {
             RGBColor[
             0.3633194234507374, 0.48885844003528395`, 0.9443806088249529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 377}], {
             RGBColor[
             0.3376579889612439, 0.46188664535790686`, 0.9429192280934666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 388}], {
             RGBColor[
             0.34570167664203966`, 0.47034107110967827`, 0.9433773042073184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 395}], {
             RGBColor[
             0.42965137086591587`, 0.5465641553634234, 0.9485979833191546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 376}], {
             RGBColor[
             0.26222548998781436`, 0.392945994406499, 0.9382447257757333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 397}], {
             RGBColor[
             0.3012257827964342, 0.4288125621703911, 0.9406533939002841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 363}], {
             RGBColor[
             0.3080486907375876, 0.43502729111889293`, 0.9410769734898234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 383}], {
             RGBColor[
             0.2999445651565369, 0.428007904865782, 0.9405605857739958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 335}], {
             RGBColor[
             0.19201380881889718`, 0.3191490658202642, 0.9342462744020376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 349}], {
             RGBColor[
             0.19208902000720862`, 0.3192281175478443, 0.934250557567947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 355}], {
             RGBColor[
             0.19695189529636073`, 0.3243393078008444, 0.9345274911216848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 339}], {
             RGBColor[
             0.322148238300078, 0.44915969522157617`, 0.9419050804873051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 340}], {
             RGBColor[
             0.2668654692611238, 0.39782290681442484`, 0.9385089657311141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 341}], {
             RGBColor[
             0.2558412218032698, 0.3862357237585604, 0.9378811511473018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 343}], {
             RGBColor[
             0.23152940348291426`, 0.3606824612455548, 0.9364966290600697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 358}], {
             RGBColor[
             0.26996801721198005`, 0.40108388142367646`, 0.9386856512471069]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 367}], {
             RGBColor[
             0.1873967228823739, 0.314296215760822, 0.9339833381883191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 398}], {
             RGBColor[
             0.18475377969358928`, 0.31151831489713266`, 0.9338328264836019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 392}], {
             RGBColor[
             0.22201549227327083`, 0.35068273734740874`, 0.9359548258912509]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 334}], {
             RGBColor[
             0.865273808078536, 0.38439014871100835`, 0.20976553073467102`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 356}], {
             RGBColor[
             0.860331132425466, 0.41150389739793797`, 0.4355673990056604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 364}], {
             RGBColor[
             0.8523160600837335, 0.33385457930663953`, 0.1949772735327932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 366}], {
             RGBColor[
             0.8763032983874938, 0.42126726340738674`, 0.2804991753802838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 380}], {
             RGBColor[
             0.7853306719558296, 0.3524037544455121, 0.43404375108571785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 389}], {
             RGBColor[
             0.8762443712451391, 0.4211412242083381, 0.2740853195911458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 337}], {
             RGBColor[
             0.9553778772118539, 0.9662414744033965, 0.9604177939535141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 345}], {
             RGBColor[
             0.8909301311153961, 0.9154013493777207, 0.9732965059821361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 353}], {
             RGBColor[
             0.97351816640208, 0.9765194565998694, 0.7354387372176427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 391}], {
             RGBColor[
             0.8647483196982105, 0.42603880217674006`, 0.43238255847960916`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 364}], {
             RGBColor[
             0.9407749655383337, 0.8016431292497415, 0.27774757447488835`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 366}], {
             RGBColor[
             0.9767558229939741, 0.9327621554008622, 0.40603042724612426`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 391}], {
             RGBColor[
             0.8668933379781074, 0.3968385652016415, 0.21131639439549801`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 349}], {
             RGBColor[
             0.19833951424086566`, 0.32579778329164166`, 0.9346065139677762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 355}], {
             RGBColor[
             0.20320238953001776`, 0.3309089735446419, 0.934883447521514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 359}], {
             RGBColor[
             0.2802453493603669, 0.4103194523243253, 0.9393282894277089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 345}], {
             RGBColor[
             0.8925314756364031, 0.9165956294995268, 0.9705858474056119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 353}], {
             RGBColor[
             0.9751195109230872, 0.9777137367216755, 0.7327280786411184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 391}], {
             RGBColor[
             0.8658158827122152, 0.4268349889246108, 0.4305754527619263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 340}], {
             RGBColor[
             0.326674769743479, 0.4539173667672604, 0.9421628597566036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 361}], {
             RGBColor[
             0.39576579821065194`, 0.5172141754678363, 0.9464388245933966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 382}], {
             RGBColor[
             0.3520267531654626, 0.47932961303801835`, 0.943651811320036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 343}], {
             RGBColor[
             0.2360559349263153, 0.3654401327912391, 0.9367544083293682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 358}], {
             RGBColor[
             0.2744945486553811, 0.4058415529693607, 0.9389434305164055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 361}], {
             RGBColor[
             0.34048302917169776`, 0.46587738706068504`, 0.9430427098372054]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 358}], {
             RGBColor[
             0.26347030119752707`, 0.39425436991349627`, 0.9383156159325932]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 348}], {
             RGBColor[
             0.1937491041812462, 0.3209729712701737, 0.9343450969057838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 374}], {
             RGBColor[
             0.18501533393427727`, 0.31179322498759243`, 0.9338477216106742]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 346}], {
             RGBColor[
             0.19749434605120672`, 0.3249094579375519, 0.9345583828896893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 354}], {
             RGBColor[
             0.1938318559295014, 0.32105994860435383`, 0.9343498094954268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 350}], {
             RGBColor[
             0.5883144988769012, 0.6710348151156551, 0.9634472668058549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 353}], {
             RGBColor[
             0.9106717648266294, 0.9268736116959997, 0.7456067906697404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 354}], {
             RGBColor[
             0.1997636988090205, 0.3272946915712895, 0.9346876191720402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 398}], {
             RGBColor[
             0.182565782601332, 0.30921859122614215`, 0.9337082232860494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 354}], {
             RGBColor[
             0.19860265347109932`, 0.3260743593066081, 0.9346214993576583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 374}], {
             RGBColor[
             0.19237032800791454`, 0.3195237900925436, 0.9342665776424293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 378}], {
             RGBColor[
             0.22067056618642705`, 0.3492691347568969, 0.935878234340245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 355}], {
             RGBColor[
             0.20327760071832918`, 0.33098802527222193`, 0.9348877306874234]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 355}], {
             RGBColor[
             0.2588476494190366, 0.38932088860423164`, 0.9380551008583563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 395}], {
             RGBColor[
             0.37411784951982285`, 0.4984638103693781, 0.9450594364453463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 399}], {
             RGBColor[
             0.33446531711843736`, 0.46411877979752536`, 0.9425328121440877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 396}], {
             RGBColor[
             0.18539177638104404`, 0.312188889866974, 0.9338691594511209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 391}], {
             RGBColor[
             0.8779094088390327, 0.4336869770555928, 0.280589414938012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 400}], {
             RGBColor[
             0.8791634122437909, 0.44332579673236017`, 0.28179025001460273`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 374}], {
             RGBColor[
             0.18986888322413037`, 0.3168946130240269, 0.9341241240625486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 359}], {
             RGBColor[
             0.6355366085129286, 0.7076527365125309, 0.9596545999486343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 360}], {
             RGBColor[
             0.804069535005691, 0.8476283188054337, 0.97217824926772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 364}], {
             RGBColor[
             0.9333609520587287, 0.8423137522801358, 0.6164503768813724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 380}], {
             RGBColor[
             0.8328828698668729, 0.8701375149884446, 0.9750500932107594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 389}], {
             RGBColor[
             0.969253418800837, 0.9732437196326836, 0.7351124459689012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 360}], {
             RGBColor[
             0.49422258294729215`, 0.5964933259008812, 0.9544972841256812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 380}], {
             RGBColor[
             0.6915688443012366, 0.7589781043767949, 0.9698927773878063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 389}], {
             RGBColor[
             0.8279393932352007, 0.862084309021034, 0.7299551301459482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 382}], {
             RGBColor[
             0.3658350125936814, 0.49128963333144304`, 0.9445316614006376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 365}], {
             RGBColor[
             0.5486439436435668, 0.6379198705336546, 0.9602843667734056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 385}], {
             RGBColor[
             0.892844244734438, 0.9136671066548807, 0.806798376116899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 383}], {
             RGBColor[
             0.36642168177165046`, 0.49179777668654956`, 0.9445690434418867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 393}], {
             RGBColor[
             0.5482487832688899, 0.640773127747212, 0.9590042434848745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 366}], {
             RGBColor[
             0.9573192010017704, 0.856958801294309, 0.38384804144330753`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 380}], {
             RGBColor[
             0.8208602613542741, 0.753663537851497, 0.6141649050014586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 391}], {
             RGBColor[
             0.8539355899833049, 0.3463029957972727, 0.1965281371936202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 377}], {
             RGBColor[
             0.2803555468892034, 0.41200183372185906`, 0.9392772056952516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 388}], {
             RGBColor[
             0.2883992345699991, 0.4204562594736305, 0.9397352818091035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 372}], {
             RGBColor[
             0.1818899475322301, 0.30850824571809776`, 0.9336697354786725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 387}], {
             RGBColor[
             0.18468757746568928`, 0.3114487321581461, 0.9338290563646603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 387}], {
             RGBColor[
             0.18274442511282618`, 0.30940635583231196`, 0.9337183967128011]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 392}], {
             RGBColor[
             0.19150446236563495`, 0.31861371040345526`, 0.9342172678750348]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 390}], {
             RGBColor[
             0.20548402624046883`, 0.3333071183914488, 0.9350133833567951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 381}], {
             RGBColor[
             0.196072227977034, 0.3234147216741027, 0.9344773953692003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 397}], {
             RGBColor[
             0.32517928194563106`, 0.4539892085157613, 0.9420175102408045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 388}], {
             RGBColor[
             0.26273780008050557`, 0.39348446479625343`, 0.9382739010776171]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 389}], {
             RGBColor[
             0.8567527280963826, 0.8845935052040448, 0.7328269740889874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 393}], {
             RGBColor[
             0.5401446576878393, 0.6337537414941011, 0.9584878557690468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 400}], {
             RGBColor[
             0.8795493400594996, 0.44415125730687344`, 0.3237961110840954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 395}], {
             RGBColor[
             0.35473118198517756`, 0.4781619748017699, 0.9439526563033052]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.08365695714524007], {
             RGBColor[
             0.1818132732838514, 0.3084276562216236, 0.9336653689936567]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.08365695714524007], {
             RGBColor[
             0.20182540810126717`, 0.3294616787573599, 0.9348050304662081]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.08365695714524007], {
             RGBColor[
             0.23621542372166607`, 0.36560776562732644`, 0.9367634909803209]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.08365695714524007], {
             RGBColor[
             0.2008450066857079, 0.32843121470856707`, 0.9347491980559659]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.08365695714524007], {
             RGBColor[
             0.18681770269069906`, 0.3136876288273712, 0.9339503638449868]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.08365695714524007], {
             RGBColor[
             0.9261633007621113, 0.943961492267368, 0.992819476494071]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.08365695714524007], {
             RGBColor[
             0.25494849258932906`, 0.3852974087524073, 0.9378303115392425]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.08365695714524007], {
             RGBColor[
             0.25559866423556843`, 0.38598078037586825`, 0.937867337852653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.08365695714524007], {
             RGBColor[
             0.6863588655876156, 0.7549080294084094, 0.9693734953996518]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.08365695714524007], {
             RGBColor[
             0.8429670986480872, 0.3312695252776902, 0.18877864823079255`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.08365695714524007], {
             RGBColor[
             0.873192830390407, 0.9017242770380856, 0.9877671057427206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.08365695714524007], {
             RGBColor[
             0.242785484860208, 0.37251331644986996`, 0.9371376462426264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.08365695714524007], {
             RGBColor[
             0.21336291477373137`, 0.3415883297902934, 0.9354620744029933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.08365695714524007], {
             RGBColor[
             0.3386493168091526, 0.46774275003568394`, 0.9427994129046144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.08365695714524007], {
             RGBColor[
             0.18212992963139682`, 0.3087604821200659, 0.9336834021041983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.08365695714524007], {
             RGBColor[
             0.22895368331262583`, 0.3579752160364906, 0.9363499456068083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.08365695714524007], {
             RGBColor[
             0.8276616884309496, 0.21362543547524793`, 0.17412217012187317`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.08365695714524007], {
             RGBColor[
             0.9925358512363838, 0.9864432654728553, 0.42895165434603927`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.08365695714524007], {
             RGBColor[
             0.19951285246669712`, 0.3270310361609309, 0.9346733338439388]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.08365695714524007], {
             RGBColor[
             0.3846257063952153, 0.5075651878546001, 0.9457289877937134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.08365695714524007], {
             RGBColor[
             0.19666790482252822`, 0.3240408158068105, 0.9345113182843263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.08365695714524007], {
             RGBColor[
             0.24203296140503872`, 0.3717223665857442, 0.9370947911451132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.08365695714524007], {
             RGBColor[
             0.2119196850624197, 0.340071403857656, 0.9353798846060012]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.08365695714524007], {
             RGBColor[
             0.2601817623901309, 0.39079790712151985`, 0.9381283385124692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.08365695714524007], {
             RGBColor[
             0.3639618362230004, 0.489667182107741, 0.9444123042586827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.08365695714524007], {
             RGBColor[
             0.1822568035379685, 0.30889383464014303`, 0.9336906273854845]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.08365695714524007], {
             RGBColor[
             0.20503271821821972`, 0.3328327650454837, 0.9349876820325784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.08365695714524007], {
             RGBColor[
             0.19159599737019925`, 0.31870991949690686`, 0.9342224806581308]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.08365695714524007], {
             RGBColor[
             0.18584110899752487`, 0.3126611669362287, 0.9338947482789014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.08365695714524007], {
             RGBColor[
             0.20069898841488326`, 0.3282777402478373, 0.9347408825314572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.08365695714524007], {
             RGBColor[
             0.9842583887354778, 0.9877584534482328, 0.9105427668445933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.08365695714524007], {
             RGBColor[
             0.8215188663850046, 0.16640901342833042`, 0.16823979679335105`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.08365695714524007], {
             RGBColor[
             0.24658940627570813`, 0.37651147904010834`, 0.9373542739398417]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.08365695714524007], {
             RGBColor[
             0.1829376663072982, 0.30960946457990146`, 0.9337294015129516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.08365695714524007], {
             RGBColor[
             0.19009976398754364`, 0.3171372833450601, 0.9341372723804675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.08365695714524007], {
             RGBColor[
             0.24565388341041777`, 0.3755281851931126, 0.9373009972966455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.08365695714524007], {
             RGBColor[
             0.2843315036737978, 0.41618081639268795`, 0.9395036305522334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.08365695714524007], {
             RGBColor[
             0.2587257572717294, 0.3892675534260234, 0.9380454211749428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.08365695714524007], {
             RGBColor[
             0.19817415326039348`, 0.32562397841667373`, 0.9345970969045678]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.08365695714524007], {
             RGBColor[
             0.1934487547814754, 0.32065728500776275`, 0.934327992451794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.08365695714524007], {
             RGBColor[
             0.19479503600678127`, 0.322072311934719, 0.9344046611759306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.08365695714524007], {
             RGBColor[
             0.183885630512114, 0.31060583506356493`, 0.9337833866720284]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.08365695714524007], {
             RGBColor[
             0.194697223000598, 0.3219695042635176, 0.9343990908699299]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.08365695714524007], {
             RGBColor[
             0.22831342724773274`, 0.3573022663177088, 0.9363134839710866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.08365695714524007], {
             RGBColor[
             0.23972125787035842`, 0.36929261960032556`, 0.9369631430486721]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.08365695714524007], {
             RGBColor[
             0.8055364749096104, 0.8480104835941301, 0.9812520057187881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.08365695714524007], {
             RGBColor[
             0.18100426741029385`, 0.3075773397545796, 0.9336192973059745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.08365695714524007], {
             RGBColor[
             0.20793893985757575`, 0.3358873882535414, 0.9351531870555702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.08365695714524007], {
             RGBColor[
             0.18369802063003998`, 0.31040864518235156`, 0.9337727025667882]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.08365695714524007], {
             RGBColor[
             0.23112771995435683`, 0.3602602663888343, 0.9364737537773559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.08365695714524007], {
             RGBColor[
             0.20120879960667537`, 0.3288135841343073, 0.9347699155246316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.08365695714524007], {
             RGBColor[
             0.9889946602077696, 0.9897170234186503, 0.8320504914710569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.08365695714524007], {
             RGBColor[
             0.40260480881009003`, 0.5231377827104023, 0.9468746003012931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.08365695714524007], {
             RGBColor[
             0.9482538006021336, 0.8325505933258706, 0.2772219972063093]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.08365695714524007], {
             RGBColor[
             0.8037373305687819, 0.8466049783610714, 0.9810726838248541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.08365695714524007], {
             RGBColor[
             0.5183980864407423, 0.6198979459970778, 0.9552293428008269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.08365695714524007], {
             RGBColor[
             0.3482989604247025, 0.47610078633028297`, 0.9434142796629524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.08365695714524007], {
             RGBColor[
             0.19320352841391442`, 0.32039953654720643`, 0.9343140271729413]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.08365695714524007], {
             RGBColor[
             0.21627237251575757`, 0.34464635434743823`, 0.9356277637172448]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.08365695714524007], {
             RGBColor[
             0.7070237961498369, 0.7710516302229059, 0.9714331825533382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.08365695714524007], {
             RGBColor[
             0.21726621743653565`, 0.3456909483725835, 0.9356843617152213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.08365695714524007], {
             RGBColor[
             0.9918038536315829, 0.990878697092375, 0.7854948864789351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.08365695714524007], {
             RGBColor[
             0.18932442036239164`, 0.31632234803540016`, 0.9340931177080333]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.08365695714524007], {
             RGBColor[
             0.9925852496598342, 0.986548923705669, 0.43432836788688456`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.08365695714524007], {
             RGBColor[
             0.3764941167365503, 0.5005220135978444, 0.9452108500911456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.08365695714524007], {
             RGBColor[
             0.19612721011213427`, 0.3234725113841618, 0.9344805265204555]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.08365695714524007], {
             RGBColor[
             0.17940647345367122`, 0.30589795700018124`, 0.9335283053038692]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.08365695714524007], {
             RGBColor[
             0.8216043579673015, 0.8605890294596807, 0.9828465511894319]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.08365695714524007], {
             RGBColor[
             0.5728179374316162, 0.6640784326178184, 0.9595134728173111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.08365695714524007], {
             RGBColor[
             0.1969643686712329, 0.32435241810869275`, 0.934528201461931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.08365695714524007], {
             RGBColor[
             0.9697038754518477, 0.9769257804341147, 0.9361676157519565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.08365695714524007], {
             RGBColor[
             0.46553671991296847`, 0.576982707272407, 0.9510679023901947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.08365695714524007], {
             RGBColor[
             0.1985117660113969, 0.3259788308238631, 0.9346163234512842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.08365695714524007], {
             RGBColor[
             0.24853385159996577`, 0.37855521436085726`, 0.9374650072245091]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.08365695714524007], {
             RGBColor[
             0.18190969424137163`, 0.30852900076141915`, 0.9336708600245455]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.08365695714524007], {
             RGBColor[
             0.2829350020755027, 0.41471300466956446`, 0.9394241018521495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.08365695714524007], {
             RGBColor[
             0.1969521059625652, 0.3243395292243824, 0.9345275031188135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.08365695714524007], {
             RGBColor[
             0.22046571832082573`, 0.34905382666204504`, 0.9358665685573442]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.08365695714524007], {
             RGBColor[
             0.199051197909799, 0.3265458079510415, 0.9346470432998802]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.08365695714524007], {
             RGBColor[
             0.20310658273494972`, 0.3308082745285237, 0.9348779914662683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.08365695714524007], {
             RGBColor[
             0.22915597848204, 0.35818784108579943`, 0.9363614660174375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.08365695714524007], {
             RGBColor[
             0.7597586089991939, 0.8122484668202457, 0.9766892958633172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.08365695714524007], {
             RGBColor[
             0.9509849302078126, 0.9629652217205732, 0.9678539073672795]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.08365695714524007], {
             RGBColor[
             0.21428709115836797`, 0.3425596977667136, 0.935514704880902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.08365695714524007], {
             RGBColor[
             0.1818888062976524, 0.30850704620819813`, 0.9336696704870515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.08365695714524007], {
             RGBColor[
             0.2680992625939086, 0.39911970183419715`, 0.9385792284361825]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.08365695714524007], {
             RGBColor[
             0.18684859723136407`, 0.31372010094843716`, 0.9339521232433733]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.08365695714524007], {
             RGBColor[
             0.4303958842275222, 0.5472090154169172, 0.9486454230522088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.08365695714524007], {
             RGBColor[
             0.23222586891438338`, 0.3614144905724877, 0.9365362917360636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.08365695714524007], {
             RGBColor[
             0.21556902434658207`, 0.3439070908267852, 0.9355877090795206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.08365695714524007], {
             RGBColor[
             0.5925759149291727, 0.6801188488370776, 0.961068893181775]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.08365695714524007], {
             RGBColor[
             0.20437042968316516`, 0.3321366578036229, 0.9349499656802752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.08365695714524007], {
             RGBColor[
             0.3425287629814334, 0.47110293132347947`, 0.9430466077842526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.08365695714524007], {
             RGBColor[
             0.1791057270796212, 0.3055818534926332, 0.9335111782427814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.08365695714524007], {
             RGBColor[
             0.24723118250472642`, 0.37718602654776967`, 0.9373908221466615]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.08365695714524007], {
             RGBColor[
             0.21162927735784165`, 0.3397661669472325, 0.9353633463168451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.08365695714524007], {
             RGBColor[
             0.2986247548964671, 0.43120392967218313`, 0.9403176100643942]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.08365695714524007], {
             RGBColor[
             0.1932487717488401, 0.3204470901608064, 0.9343166037139339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.08365695714524007], {
             RGBColor[
             0.9021660914511284, 0.9248267689496842, 0.9905306012474278]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.08365695714524007], {
             RGBColor[
             0.387712192347488, 0.5102385468551641, 0.9459256559493198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.08365695714524007], {
             RGBColor[
             0.8539737461394735, 0.41587144104017043`, 0.19931862629877445`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.08365695714524007], {
             RGBColor[
             0.34903475823839447`, 0.4767380974142295, 0.9434611640490004]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.08365695714524007], {
             RGBColor[
             0.19478977051563845`, 0.3220667775696765, 0.9344043613139996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.08365695714524007], {
             RGBColor[
             0.22404918964109946`, 0.35282028222485723`, 0.936070641947763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.08365695714524007], {
             RGBColor[
             0.9853022906708313, 0.9881901337255575, 0.8932426102441758]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.08365695714524007], {
             RGBColor[
             0.1865190623784995, 0.31337373892436005`, 0.9339333567210057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.08365695714524007], {
             RGBColor[
             0.2230811340648649, 0.3518027944359661, 0.9360155126148064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.08365695714524007], {
             RGBColor[
             0.3063635945960659, 0.4393379408672382, 0.9407583255366989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.08365695714524007], {
             RGBColor[
             0.1827503081177702, 0.3094125392435122, 0.9337187317412295]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.08365695714524007], {
             RGBColor[
             0.8529626688242167, 0.8855932953383124, 0.985837534872859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.08365695714524007], {
             RGBColor[
             0.8266120846200963, 0.20555772064570646`, 0.17311706832724205`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.08365695714524007], {
             RGBColor[
             0.1804406002012431, 0.3069848897793021, 0.93358719729229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.08365695714524007], {
             RGBColor[
             0.1856485479005117, 0.3124587730141891, 0.9338837822092951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.08365695714524007], {
             RGBColor[
             0.18667779652152947`, 0.3135405785730105, 0.9339423963956253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.08365695714524007], {
             RGBColor[
             0.9551078718556497, 0.8597247018622127, 0.2827369438226184]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.08365695714524007], {
             RGBColor[
             0.24002120291967022`, 0.3696078808647668, 0.9369802244755014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.08365695714524007], {
             RGBColor[
             0.5585316039927765, 0.6524801435401812, 0.9583888003164419]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.08365695714524007], {
             RGBColor[
             0.3574473894517768, 0.48402469574012214`, 0.9439972094709195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.08365695714524007], {
             RGBColor[
             0.2397898236287226, 0.36936468655968646`, 0.936967047767177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.08365695714524007], {
             RGBColor[
             0.41254771032069193`, 0.531749824254125, 0.9475081531933861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.08365695714524007], {
             RGBColor[
             0.24372417422141443`, 0.37349993848484087`, 0.9371911032130806]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.08365695714524007], {
             RGBColor[
             0.18936604401309215`, 0.31636609713137825`, 0.934095488113364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.08365695714524007], {
             RGBColor[
             0.843157812611701, 0.33273543637341757`, 0.18896127613772973`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.08365695714524007], {
             RGBColor[
             0.22661866237074535`, 0.3555209609776956, 0.9362169696185221]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.08365695714524007], {
             RGBColor[
             0.1925981967986741, 0.3197632946393477, 0.9342795544329613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.08365695714524007], {
             RGBColor[
             0.18255935854789945`, 0.309211839138676, 0.9337078574457099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.08365695714524007], {
             RGBColor[
             0.3393687513351076, 0.46836588806223545`, 0.9428452546364373]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.08365695714524007], {
             RGBColor[
             0.3039019362504366, 0.4367505818678281, 0.9406181377356125]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.08365695714524007], {
             RGBColor[
             0.8193361618613183, 0.1496317899920564, 0.1661496364764569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.08365695714524007], {
             RGBColor[
             0.21566341381177923`, 0.3440063001393452, 0.9355930844199268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.08365695714524007], {
             RGBColor[
             0.8141109072907318, 0.8547088953383618, 0.982106625005912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.08365695714524007], {
             RGBColor[
             0.19287402797566439`, 0.32005321069507126`, 0.9342952626104353]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.08365695714524007], {
             RGBColor[
             0.18340497994045135`, 0.3101006408377411, 0.933756014333031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.08365695714524007], {
             RGBColor[
             0.17911500115561352`, 0.3055916011345115, 0.9335117063876894]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.08365695714524007], {
             RGBColor[
             0.335355251737071, 0.46488959643477135`, 0.9425895179910487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.08365695714524007], {
             RGBColor[
             0.18263620644148504`, 0.30929261114727236`, 0.9337122338195634]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.08365695714524007], {
             RGBColor[
             0.29264465833089975`, 0.42491846902175034`, 0.9399770524117451]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.08365695714524007], {
             RGBColor[
             0.2889051941793347, 0.4209880551027343, 0.939764095460355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.08365695714524007], {
             RGBColor[
             0.30694355404168716`, 0.4399475150161388, 0.940791353369154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.08365695714524007], {
             RGBColor[
             0.4063466574019441, 0.5263787838898877, 0.9471130275847793]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.08365695714524007], {
             RGBColor[
             0.3557668224000087, 0.48256907302763663`, 0.9438901252244479]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.08365695714524007], {
             RGBColor[
             0.4741596199861951, 0.5839831660090739, 0.9517467286706829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.08365695714524007], {
             RGBColor[
             0.19890345919190142`, 0.32639052519135536`, 0.9346386297984558]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.08365695714524007], {
             RGBColor[
             0.5812572311839399, 0.6709298314718057, 0.9601778449356456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.08365695714524007], {
             RGBColor[
             0.24987309085249598`, 0.3799628397279394, 0.9375412749187138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.08365695714524007], {
             RGBColor[
             0.1991293041825628, 0.32662790259593993`, 0.9346514913365662]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.08365695714524007], {
             RGBColor[
             0.24721508689536167`, 0.3771691090418067, 0.9373899055255195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.08365695714524007], {
             RGBColor[
             0.25655300447979307`, 0.38698385248121464`, 0.9379216861177417]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.08365695714524007], {
             RGBColor[
             0.21032620428650672`, 0.3383965545296549, 0.9352891382331565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.08365695714524007], {
             RGBColor[
             0.23840666361665402`, 0.3679108976895925, 0.9368882788506916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.08365695714524007], {
             RGBColor[
             0.20761230953904478`, 0.335544079079207, 0.935134585942136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.08365695714524007], {
             RGBColor[
             0.2008438754397465, 0.3284300256973365, 0.9347491336331819]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.08365695714524007], {
             RGBColor[
             0.20565135384863537`, 0.33348299031681494`, 0.9350229124165412]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.08365695714524007], {
             RGBColor[
             0.18637271886218407`, 0.3132199226099977, 0.9339250226742475]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.08365695714524007], {
             RGBColor[
             0.1858996679095085, 0.31272271606557295`, 0.9338980831223087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.08365695714524007], {
             RGBColor[
             0.20187169700218524`, 0.3295103313271106, 0.9348076665506371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.08365695714524007], {
             RGBColor[
             0.24686136029389427`, 0.3767973199561026, 0.9373697613188575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.08365695714524007], {
             RGBColor[
             0.1911403477299942, 0.3182310028351955, 0.9341965320851944]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.08365695714524007], {
             RGBColor[
             0.18214142158537838`, 0.30877256089233246`, 0.9336840565539767]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.08365695714524007], {
             RGBColor[
             0.19529547244710238`, 0.32259830236299947`, 0.9344331602908775]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.08365695714524007], {
             RGBColor[
             0.8795463410175769, 0.5459298918751729, 0.22120285316675511`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.08365695714524007], {
             RGBColor[
             0.19529691214488243`, 0.32259981557664835`, 0.9344332422795363]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.08365695714524007], {
             RGBColor[
             0.17905422337022397`, 0.30552771982853294`, 0.9335082451827241]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.08365695714524007], {
             RGBColor[
             0.21499276582137244`, 0.3433014065798891, 0.935554892009008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.08365695714524007], {
             RGBColor[
             0.22554056397195027`, 0.35438781120517543`, 0.9361555735096144]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.08365695714524007], {
             RGBColor[
             0.2451744333338886, 0.3750242527637898, 0.93727369332407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.08365695714524007], {
             RGBColor[
             0.2358064817309028, 0.3651779416666145, 0.9367402023389224]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.08365695714524007], {
             RGBColor[
             0.19796437105250972`, 0.32540348401522773`, 0.9345851501181738]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.08365695714524007], {
             RGBColor[
             0.45725872125089195`, 0.5702622550389433, 0.9504162280122078]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.08365695714524007], {
             RGBColor[
             0.23550398192177388`, 0.3648599951876243, 0.9367229754223009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.08365695714524007], {
             RGBColor[
             0.18805335571358273`, 0.3149863784993486, 0.9340207324566552]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.08365695714524007], {
             RGBColor[
             0.3796233347917912, 0.5032323849982215, 0.9454102410985666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.08365695714524007], {
             RGBColor[
             0.17959143492855675`, 0.30609236323752076`, 0.933538838586238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.08365695714524007], {
             RGBColor[
             0.41783566912403936`, 0.5363299883890472, 0.947845097252377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.08365695714524007], {
             RGBColor[
             0.19013667027984396`, 0.3171760741982618, 0.9341393741392161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.08365695714524007], {
             RGBColor[
             0.18620451936940718`, 0.3130431342786254, 0.9339154439619627]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.08365695714524007], {
             RGBColor[
             0.18139651046953492`, 0.3079896120794884, 0.9336416349679267]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.08365695714524007], {
             RGBColor[
             0.18300767959384703`, 0.309683052983163, 0.9337333886660452]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.08365695714524007], {
             RGBColor[
             0.2268131918331927, 0.35572542377660804`, 0.9362280477836279]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.08365695714524007], {
             RGBColor[
             0.18842432755960442`, 0.31537629343049095`, 0.9340418587544824]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.08365695714524007], {
             RGBColor[
             0.19212227783830665`, 0.31926307363699663`, 0.9342524515522274]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.08365695714524007], {
             RGBColor[
             0.24182762690147153`, 0.3715065470035356, 0.9370830976489003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.08365695714524007], {
             RGBColor[
             0.18868393066647376`, 0.3156491527555983, 0.9340566427673703]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.08365695714524007], {
             RGBColor[
             0.21355297767290998`, 0.3417880979480139, 0.9354728982039288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.08365695714524007], {
             RGBColor[
             0.19254963929720473`, 0.31971225762658, 0.9342767891550869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.08365695714524007], {
             RGBColor[
             0.2065811071166083, 0.33446021995121644`, 0.9350758604897056]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.08365695714524007], {
             RGBColor[
             0.21634716160662554`, 0.34472496242384276`, 0.9356320228453292]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.08365695714524007], {
             RGBColor[
             0.27580922111776024`, 0.4072233570823697, 0.9390182991682543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.08365695714524007], {
             RGBColor[
             0.2331737072204319, 0.36241072872856434`, 0.9365902697253919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.08365695714524007], {
             RGBColor[
             0.2121526703486752, 0.34031628616563087`, 0.9353931527733826]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.08365695714524007], {
             RGBColor[
             0.1840091371887301, 0.310735648411464, 0.9337904201945499]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.08365695714524007], {
             RGBColor[
             0.2582664433427927, 0.3887847853645258, 0.938019263926184]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.08365695714524007], {
             RGBColor[
             0.8379281346647119, 0.8736051659010814, 0.9844035275832383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.08365695714524007], {
             RGBColor[
             0.4554399226734993, 0.5687856724178738, 0.9502730455257168]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.08365695714524007], {
             RGBColor[
             0.42461827381123246`, 0.5422047396654701, 0.9482772788254231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.08365695714524007], {
             RGBColor[
             0.844124603334554, 0.8785460618197521, 0.9849945522966208]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.08365695714524007], {
             RGBColor[
             0.19131157595015044`, 0.3184109745510759, 0.9342062832790229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.08365695714524007], {
             RGBColor[
             0.8287975688378628, 0.8663247005533589, 0.9835326460637211]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.08365695714524007], {
             RGBColor[
             0.9887357523774989, 0.9896099583772056, 0.8363412642506296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.08365695714524007], {
             RGBColor[
             0.19404714705117995`, 0.3212862332234835, 0.9343620700063117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.08365695714524007], {
             RGBColor[
             0.6657140642559093, 0.738780153701779, 0.9673158145395446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.08365695714524007], {
             RGBColor[
             0.3275914997751332, 0.4581650247028605, 0.9420948185812503]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.08365695714524007], {
             RGBColor[
             0.3100095560527289, 0.44293642874469996`, 0.9409745126743612]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.08365695714524007], {
             RGBColor[
             0.17994083687002446`, 0.30645960683136597`, 0.9335587365099107]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.08365695714524007], {
             RGBColor[
             0.18515378626434187`, 0.3119387471648751, 0.9338556062660495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.08365695714524007], {
             RGBColor[
             0.4288884024290853, 0.5459033104513494, 0.9485493676450263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.08365695714524007], {
             RGBColor[
             0.1915172466480543, 0.31862714749484833`, 0.934217995921006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.08365695714524007], {
             RGBColor[
             0.2944180010032382, 0.4267823646067975, 0.9400780416535094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.08365695714524007], {
             RGBColor[
             0.2650455441851616, 0.3959100501696741, 0.9384053236903759]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.08365695714524007], {
             RGBColor[
             0.2456807114445148, 0.37555638315794415`, 0.9373025251134988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.08365695714524007], {
             RGBColor[
             0.23248905082520588`, 0.3616911114474591, 0.9365512795565422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.08365695714524007], {
             RGBColor[
             0.5777795176543054, 0.6681064669592394, 0.9599040665873084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.08365695714524007], {
             RGBColor[
             0.3254133616442444, 0.45627843093029025`, 0.9419560295456021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.08365695714524007], {
             RGBColor[
             0.8789213821202363, 0.5430920994852084, 0.22068137214366979`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.08365695714524007], {
             RGBColor[
             0.7060709713767632, 0.7703072762684443, 0.9713382138846121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.08365695714524007], {
             RGBColor[
             0.21581639795358076`, 0.3441670961721334, 0.9356017966404827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.08365695714524007], {
             RGBColor[
             0.2082469591636211, 0.3362111360737471, 0.9351707282993756]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.08365695714524007], {
             RGBColor[
             0.5602763464580424, 0.6538966040732364, 0.9585261528345099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.08365695714524007], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.08365695714524007], {
             RGBColor[
             0.17970434930417156`, 0.30621104340547683`, 0.9335452688928874]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.08365695714524007], {
             RGBColor[
             0.36991176607450643`, 0.49482071229294583`, 0.9447914285275043]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.08365695714524007], {
             RGBColor[
             0.9510874915293103, 0.9630417117862173, 0.9676802978022608]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.08365695714524007], {
             RGBColor[
             0.8592163258347785, 0.4536160411257659, 0.20423899016395516`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.08365695714524007], {
             RGBColor[
             0.4977475489543879, 0.6031329093695432, 0.9536036568444898]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.08365695714524007], {
             RGBColor[
             0.2084820527788493, 0.336458234369148, 0.9351841165329731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.08365695714524007], {
             RGBColor[
             0.19190461331519068`, 0.3190342944224739, 0.9342400558796418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.08365695714524007], {
             RGBColor[
             0.2739918424465178, 0.40531317687043084`, 0.9389148021414978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.08365695714524007], {
             RGBColor[
             0.22400797509009437`, 0.3527769631185974, 0.9360682948400547]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.08365695714524007], {
             RGBColor[
             0.19792175174780763`, 0.3253586884237658, 0.9345827230118207]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.08365695714524007], {
             RGBColor[
             0.2211253737681676, 0.3497471663617724, 0.9359041349591976]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.08365695714524007], {
             RGBColor[
             0.19120668731506069`, 0.31830072994527303`, 0.9342003100264233]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.08365695714524007], {
             RGBColor[
             0.19035994618760685`, 0.3174107513338308, 0.934152089371856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.08365695714524007], {
             RGBColor[
             0.9703310152107799, 0.9773935002394792, 0.9351060317243296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.08365695714524007], {
             RGBColor[
             0.24693624036742998`, 0.3768760236610595, 0.9373740256282702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.08365695714524007], {
             RGBColor[
             0.19324911536591247`, 0.3204474513241361, 0.9343166232824178]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.08365695714524007], {
             RGBColor[
             0.5096359477486948, 0.612784447077024, 0.9545395551462174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.08365695714524007], {
             RGBColor[
             0.18222514168352894`, 0.3088605560236495, 0.9336888242897137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.08365695714524007], {
             RGBColor[
             0.20088219976865415`, 0.32847030699692126`, 0.9347513161470175]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.08365695714524007], {
             RGBColor[
             0.5071373117219987, 0.6107559417882819, 0.9543428533653905]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.08365695714524007], {
             RGBColor[
             0.17933281357579656`, 0.305820535798229, 0.9335241104827943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.08365695714524007], {
             RGBColor[
             0.28091140737960196`, 0.41258607834085864`, 0.939308861127858]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.08365695714524007], {
             RGBColor[
             0.3403985574835718, 0.4692578543884732, 0.9429108729735957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.08365695714524007], {
             RGBColor[
             0.23139395253121084`, 0.36054009370722817`, 0.9364889153287519]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.08365695714524007], {
             RGBColor[
             0.18235944175044905`, 0.3090017139090986, 0.9336964724798456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.08365695714524007], {
             RGBColor[
             0.19489410730752896`, 0.3221764421532881, 0.9344103031399453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.08365695714524007], {
             RGBColor[
             0.2167015948028579, 0.34509749418544555`, 0.9356522072915177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.08365695714524007], {
             RGBColor[
             0.8173387448883187, 0.1342787678638822, 0.16423690772735258`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.08365695714524007], {
             RGBColor[
             0.1829127869860106, 0.3095833148357881, 0.9337279846724099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.08365695714524007], {
             RGBColor[
             0.18362197162651986`, 0.31032871285786656`, 0.9337683716885422]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.08365695714524007], {
             RGBColor[
             0.19372013073248498`, 0.3209425183385029, 0.9343434469107393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.08365695714524007], {
             RGBColor[
             0.1849258667142184, 0.3116991892667612, 0.9338426265848467]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.08365695714524007], {
             RGBColor[
             0.20594129701488287`, 0.33378773896799957`, 0.9350394242509266]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.08365695714524007], {
             RGBColor[
             0.8251923969012658, 0.19464537872765014`, 0.17175757376438203`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.08365695714524007], {
             RGBColor[
             0.1870776850955973, 0.3139608868187558, 0.9339651694583363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.08365695714524007], {
             RGBColor[
             0.37418878878290995`, 0.4985252543935531, 0.9450639566324611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.08365695714524007], {
             RGBColor[
             0.9923039511135691, 0.9910855002530954, 0.777206976991627]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.08365695714524007], {
             RGBColor[
             0.9694202648664492, 0.9767142641238943, 0.9366476944955487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.08365695714524007], {
             RGBColor[
             0.23765262088408304`, 0.3671183509685898, 0.9368453372325779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.08365695714524007], {
             RGBColor[
             0.8954246210317355, 0.9194513034296, 0.9898875937806444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.08365695714524007], {
             RGBColor[
             0.1889310324973132, 0.31590887244697147`, 0.9340707148510822]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.08365695714524007], {
             RGBColor[
             0.18920356017618423`, 0.31619531631671777`, 0.9340862348992254]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.08365695714524007], {
             RGBColor[
             0.36433321534571095`, 0.4899888520377754, 0.9444359682079841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.08365695714524007], {
             RGBColor[
             0.30183205672017543`, 0.43457500724358145`, 0.9405002611584765]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.08365695714524007], {
             RGBColor[
             0.2599789274537134, 0.39058471474286727`, 0.9381167873629076]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.08365695714524007], {
             RGBColor[
             0.19899652547638796`, 0.32648834375709396`, 0.934643929785678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.08365695714524007], {
             RGBColor[
             0.6582217134144572, 0.7329270722804612, 0.9665690470276681]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.08365695714524007], {
             RGBColor[
             0.19756403157199334`, 0.32498270183821587`, 0.9345623513770076]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.08365695714524007], {
             RGBColor[
             0.187660141527025, 0.31457308545805707`, 0.933998339490439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.08365695714524007], {
             RGBColor[
             0.3534033382914345, 0.480521941884955, 0.9437395261069965]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.08365695714524007], {
             RGBColor[
             0.20794500379241626`, 0.3358937618335345, 0.9351535323876885]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.08365695714524007], {
             RGBColor[
             0.8200027527924696, 0.15475549999089333`, 0.1667879647049341]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.08365695714524007], {
             RGBColor[
             0.19665135271400355`, 0.3240234184912868, 0.9345103756662324]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.08365695714524007], {
             RGBColor[
             0.5240458703783706, 0.6244830714274116, 0.9556739570409113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.08365695714524007], {
             RGBColor[
             0.20313982636998706`, 0.33084321569671615`, 0.9348798846421041]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.08365695714524007], {
             RGBColor[
             0.194144227344503, 0.3213882707670121, 0.934367598585399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.08365695714524007], {
             RGBColor[
             0.37904525788294496`, 0.5027316838347692, 0.9453734065491083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.08365695714524007], {
             RGBColor[
             0.1851145385676597, 0.3118974953472144, 0.9338533711677852]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.08365695714524007], {
             RGBColor[
             0.1880939032775767, 0.3150289965599703, 0.9340230415804399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.08365695714524007], {
             RGBColor[
             0.1990369147875074, 0.3265307954839108, 0.9346462298971957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.08365695714524007], {
             RGBColor[
             0.2089289786028837, 0.3369279817469421, 0.9352095682974844]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.08365695714524007], {
             RGBColor[
             0.39875120665503094`, 0.5197999862113661, 0.9466290521795794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.08365695714524007], {
             RGBColor[
             0.31502354175322494`, 0.44727929114822085`, 0.9412939994095033]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.08365695714524007], {
             RGBColor[
             0.9319225428018962, 0.7678025982169813, 0.26408148383634866`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.08365695714524007], {
             RGBColor[
             0.7398648594018855, 0.7967073184367315, 0.9747064728211174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.08365695714524007], {
             RGBColor[
             0.18427610046840573`, 0.31101624374485265`, 0.9338056233583907]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.08365695714524007], {
             RGBColor[
             0.3212434064694567, 0.45266662534593033`, 0.9416903236892111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.08365695714524007], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.08365695714524007], {
             RGBColor[
             0.2137339467700851, 0.34197830794324846`, 0.935483204126293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.08365695714524007], {
             RGBColor[
             0.4742143938317012, 0.5840276338843894, 0.9517510406684443]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.08365695714524007], {
             RGBColor[
             0.25752973177491306`, 0.38801045479647306`, 0.9379773092922603]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.08365695714524007], {
             RGBColor[
             0.1954605501868454, 0.3227718095340026, 0.9344425612239453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.08365695714524007], {
             RGBColor[
             0.8194918846006688, 0.15082874320484374`, 0.1662987567475226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.08365695714524007], {
             RGBColor[
             0.3141297509318431, 0.44650513446197276`, 0.941237047848713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.08365695714524007], {
             RGBColor[
             0.20973292712492791`, 0.3377729826168909, 0.9352553519764795]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.08365695714524007], {
             RGBColor[
             0.18590102371033476`, 0.3127241410982041, 0.9338981603331601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.08365695714524007], {
             RGBColor[
             0.17907641669607907`, 0.3055510464211448, 0.9335095090597996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.08365695714524007], {
             RGBColor[
             0.2965600408339725, 0.42903378428206873`, 0.9402000276530058]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.08365695714524007], {
             RGBColor[
             0.20546571259734456`, 0.33328786959137313`, 0.9350123404219118]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.08365695714524007], {
             RGBColor[
             0.18838969891108812`, 0.3153398965253172, 0.9340398867041779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.08365695714524007], {
             RGBColor[
             0.19616100168040002`, 0.3235080284649182, 0.934482450900278]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.08365695714524007], {
             RGBColor[
             0.24986810421890843`, 0.3799575984598681, 0.937540990937308]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.08365695714524007], {
             RGBColor[
             0.19470143524485908`, 0.32197393159930776`, 0.9343993307510091]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.08365695714524007], {
             RGBColor[
             0.8939300581111314, 0.611242991794526, 0.23320497928678602`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.08365695714524007], {
             RGBColor[
             0.2822705085644714, 0.4140145798581486, 0.9393862599297264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.08365695714524007], {
             RGBColor[
             0.29805944165302733`, 0.4306097496103981, 0.9402854163114862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.08365695714524007], {
             RGBColor[
             0.22229995450050422`, 0.350981725184178, 0.9359710255942676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.08365695714524007], {
             RGBColor[
             0.17902996710188124`, 0.3055022249525685, 0.933506863824126]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.08365695714524007], {
             RGBColor[
             0.212847764567014, 0.3410468742606238, 0.9354327373608172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.08365695714524007], {
             RGBColor[
             0.6973666945960665, 0.7635074290924103, 0.9704706529212034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.08365695714524007], {
             RGBColor[
             0.8265166883216026, 0.20482446289255998`, 0.17302571672406986`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.08365695714524007], {
             RGBColor[
             0.2025961788233211, 0.3302718076559249, 0.934848924718576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.08365695714524007], {
             RGBColor[
             0.5478165382686445, 0.6437811704771209, 0.9575452710920592]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.08365695714524007], {
             RGBColor[
             0.28461757525764775`, 0.41648149576530025`, 0.9395199219057286]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.08365695714524007], {
             RGBColor[
             0.18275376889499648`, 0.30941617673980293`, 0.9337189288273728]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.08365695714524007], {
             RGBColor[
             0.1811098371299533, 0.3076883002234485, 0.9336253093453327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.08365695714524007], {
             RGBColor[
             0.7121412574025138, 0.7750494298476431, 0.9719432432656107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.08365695714524007], {
             RGBColor[
             0.18850413369751906`, 0.3154601747414406, 0.9340464035959741]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.08365695714524007], {
             RGBColor[
             0.21345649486519924`, 0.3416866883997466, 0.9354674036507632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.08365695714524007], {
             RGBColor[
             0.8324443832728455, 0.2503873238203034, 0.17870208410375396`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.08365695714524007], {
             RGBColor[
             0.18370800885926494`, 0.3104191434445573, 0.9337732713816664]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.08365695714524007], {
             RGBColor[
             0.18455342051778426`, 0.3113077246998561, 0.9338214163249446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.08365695714524007], {
             RGBColor[
             0.1951112049063669, 0.3224046254944496, 0.9344226665270321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.08365695714524007], {
             RGBColor[
             0.42062186552277797`, 0.5387432516713317, 0.9480226312231679]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.08365695714524007], {
             RGBColor[
             0.1856877903127057, 0.31250001927751764`, 0.9338860170066157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.08365695714524007], {
             RGBColor[
             0.23827199083861747`, 0.36776934806112876`, 0.9368806094352129]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.08365695714524007], {
             RGBColor[
             0.24157157412247404`, 0.37123741929812537`, 0.9370685158219325]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.08365695714524007], {
             RGBColor[
             0.18576331458524015`, 0.3125794000764668, 0.9338903180022083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.08365695714524007], {
             RGBColor[
             0.2313516506730186, 0.3604956317721754, 0.9364865063005079]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.08365695714524007], {
             RGBColor[
             0.2623389378177228, 0.3930652352687406, 0.9382511864618155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.08365695714524007], {
             RGBColor[
             0.18870039039885345`, 0.3156664529779366, 0.9340575801247794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.08365695714524007], {
             RGBColor[
             0.24096885499463874`, 0.3706039232801706, 0.9370341918592453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.08365695714524007], {
             RGBColor[
             0.8178049183525352, 0.13786198138836525`, 0.164683315963154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.08365695714524007], {
             RGBColor[
             0.9537765326908467, 0.9650471942815904, 0.9631284525300384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.08365695714524007], {
             RGBColor[
             0.9602115875305376, 0.8774464833562946, 0.2999299602777051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.08365695714524007], {
             RGBColor[
             0.1982643030525542, 0.3257187315640616, 0.9346022308018668]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.08365695714524007], {
             RGBColor[
             0.23480104226620413`, 0.36412116104067216`, 0.9366829440488222]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.08365695714524007], {
             RGBColor[
             0.956979221732861, 0.9674357545252026, 0.9577071353769899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.08365695714524007], {
             RGBColor[
             0.21013611726343454`, 0.33819676101619267`, 0.9352783130584011]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.08365695714524007], {
             RGBColor[
             0.38195753878243316`, 0.5052541551744117, 0.9455589745127948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.08365695714524007], {
             RGBColor[
             0.27139200070452485`, 0.4025805783601091, 0.9387667450004126]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.08365695714524007], {
             RGBColor[
             0.24934350578881678`, 0.3794062122483802, 0.9375111158327881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.08365695714524007], {
             RGBColor[
             0.18639411010760892`, 0.31324240616522253`, 0.9339262408740289]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.08365695714524007], {
             RGBColor[
             0.20071986914810575`, 0.3282996872223691, 0.9347420716583239]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.08365695714524007], {
             RGBColor[
             0.1915625031716876, 0.3186747149706162, 0.9342205732130758]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.08365695714524007], {
             RGBColor[
             0.8280837295399454, 0.865755504473851, 0.9834645594342339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.08365695714524007], {
             RGBColor[
             0.20342618893072584`, 0.3311442009044876, 0.9348961925663027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.08365695714524007], {
             RGBColor[
             0.18432439621433888`, 0.3110670056359555, 0.9338083737296745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.08365695714524007], {
             RGBColor[
             0.20110409825488346`, 0.3287035363751249, 0.9347639529375389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.08365695714524007], {
             RGBColor[
             0.19841472542917707`, 0.32587683501922177`, 0.9346107971336854]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.08365695714524007], {
             RGBColor[
             0.3485452682138572, 0.4763141257574593, 0.943429974177476]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.08365695714524007], {
             RGBColor[
             0.3095548228305918, 0.44254256168324113`, 0.9409455374755513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.08365695714524007], {
             RGBColor[
             0.18638553952238943`, 0.3132333979367503, 0.9339257527918797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.08365695714524007], {
             RGBColor[
             0.9932598001133134, 0.9879917189181485, 0.507749021905247]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.08365695714524007], {
             RGBColor[
             0.19610120868731518`, 0.3234451822380914, 0.9344790457777777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.08365695714524007], {
             RGBColor[
             0.2081404760074813, 0.3360992155252221, 0.9351646642411613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.08365695714524007], {
             RGBColor[
             0.9453835605713274, 0.9587877294170835, 0.9773355650906732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.08365695714524007], {
             RGBColor[
             0.18600360463112436`, 0.31283196014996, 0.9339040021648441]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.08365695714524007], {
             RGBColor[
             0.2775970966062373, 0.4091025275786123, 0.9391201160323983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.08365695714524007], {
             RGBColor[
             0.32568965645452963`, 0.4565177436079784, 0.9419736348065956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.08365695714524007], {
             RGBColor[
             0.6627555094400547, 0.736468908193784, 0.9670209334447669]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.08365695714524007], {
             RGBColor[
             0.40957405763887067`, 0.529174195761261, 0.9473186746739982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.08365695714524007], {
             RGBColor[
             0.7912709059084366, 0.8368661126680731, 0.979830147120073]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.08365695714524007], {
             RGBColor[
             0.3745258073527012, 0.4988171629396605, 0.9450854311577144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.08365695714524007], {
             RGBColor[
             0.92133834354613, 0.7258397751431882, 0.2555651886720716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.08365695714524007], {
             RGBColor[
             0.30601698137869693`, 0.43897362839923615`, 0.940738586426738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.08365695714524007], {
             RGBColor[
             0.9933000584574108, 0.9880778274454297, 0.5121308942145434]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.08365695714524007], {
             RGBColor[
             0.1860930553658944, 0.31292597854370746`, 0.9339090962518588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.08365695714524007], {
             RGBColor[
             0.1838330998850932, 0.3105506220439319, 0.9337803951305317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.08365695714524007], {
             RGBColor[
             0.1804054273287139, 0.30694792086018496`, 0.933585194249233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.08365695714524007], {
             RGBColor[
             0.18554668841356567`, 0.31235171223514435`, 0.9338779814622011]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.08365695714524007], {
             RGBColor[
             0.18003320207443918`, 0.306556688517498, 0.93356399657166]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.08365695714524007], {
             RGBColor[
             0.179946795179367, 0.3064658693922636, 0.9335590758268132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.08365695714524007], {
             RGBColor[
             0.19798515205544082`, 0.3254253261669, 0.934586333565548]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.08365695714524007], {
             RGBColor[
             0.1836365577609456, 0.3103440438099624, 0.9337692023473195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.08365695714524007], {
             RGBColor[
             0.20279567675606608`, 0.3304814926321394, 0.9348602858307151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.08365695714524007], {
             RGBColor[
             0.28617898913701123`, 0.4181226407518692, 0.9396088421162536]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.08365695714524007], {
             RGBColor[
             0.25469411239970985`, 0.38503003904448196`, 0.9378158249637654]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.08365695714524007], {
             RGBColor[
             0.24023703411797065`, 0.3698347331386689, 0.9369925157429511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.08365695714524007], {
             RGBColor[
             0.18246816409549027`, 0.30911598798713175`, 0.9337026640565553]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.08365695714524007], {
             RGBColor[
             0.7203821791624184, 0.7814873005598058, 0.9727646213308456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.08365695714524007], {
             RGBColor[
             0.1893487791980019, 0.3163479507160659, 0.9340945049076855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.08365695714524007], {
             RGBColor[
             0.3220959675484921, 0.453405070901625, 0.9417446481272771]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.08365695714524007], {
             RGBColor[
             0.3583175561905998, 0.4847783904334387, 0.944052655726059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.08365695714524007], {
             RGBColor[
             0.9335847383251342, 0.7743926495727972, 0.2654189253710895]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.08365695714524007], {
             RGBColor[
             0.9944175835604394, 0.9904681006416884, 0.633766605113725]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.08365695714524007], {
             RGBColor[
             0.3419268933615933, 0.4705816221096207, 0.9430082571842888]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.08365695714524007], {
             RGBColor[
             0.18554205504628538`, 0.3123468422723603, 0.933877717598789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.08365695714524007], {
             RGBColor[
             0.2707814877613013, 0.40193889054802484`, 0.938731977191469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.08365695714524007], {
             RGBColor[
             0.9931232770303468, 0.9876997098482838, 0.4928893268471293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.08365695714524007], {
             RGBColor[
             0.21298290042549683`, 0.3411889106159976, 0.9354404331480423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.08365695714524007], {
             RGBColor[
             0.8202342132018924, 0.1565346061243149, 0.16700961145439447`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.08365695714524007], {
             RGBColor[
             0.2030621295519029, 0.3307615514146469, 0.9348754599232564]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.08365695714524007], {
             RGBColor[
             0.7219717591850786, 0.7827290925547635, 0.9729230558120345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.08365695714524007], {
             RGBColor[
             0.35762511408731845`, 0.48417863188672844`, 0.9440085339275405]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.08365695714524007], {
             RGBColor[
             0.4386808762090538, 0.554385059055515, 0.9491733354151413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.08365695714524007], {
             RGBColor[
             0.18439801323969868`, 0.31114438179719767`, 0.9338125661103621]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.08365695714524007], {
             RGBColor[
             0.36417957475425095`, 0.48985577627965343`, 0.9444261783653554]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.08365695714524007], {
             RGBColor[
             0.1808071689883251, 0.3073701768163288, 0.9336080728424244]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.08365695714524007], {
             RGBColor[
             0.3593758114062829, 0.48569499791180964`, 0.944120086812624]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.08365695714524007], {
             RGBColor[
             0.8221152183090297, 0.17099283563946593`, 0.16881086406928056`]},
             StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{
  3.834950276960332*^9, {3.8349573666066523`*^9, 3.83495737580899*^9}, 
   3.8349587938370156`*^9, 3.8350239089504185`*^9, 3.835051837396469*^9},
 CellLabel->
  "Out[404]=",ExpressionUUID->"96dd3d68-4b0f-4ed2-a68c-287a44dd5c26"]
}, Open  ]],

Cell["Estimated with absolute Mean Deviation v Calculated: (r=3)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 
  3.8349503756793146`*^9}},ExpressionUUID->"f6b900d3-3c5d-4138-9743-\
7913b0e89a0e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphin4", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsi4", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}], 
     "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"AMDi3400", ",", "kri4"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502409842243`*^9}, {3.834957391671958*^9, 3.8349574025038147`*^9}},
 CellLabel->
  "In[178]:=",ExpressionUUID->"3dc07067-1630-478e-bc5d-22712ba37614"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN3AuYzmXewPH7z7a1WxZbu0o1DqFsy5TT0CKyGGKYrMNM4zSN46CIkAnD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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[37, 104] -> 
             RGBColor[
              0.9737301920479837, 0.9332422698962709, 0.5806055465064086], 
             UndirectedEdge[119, 243] -> 
             RGBColor[
              0.965274768984378, 0.9721263253889559, 0.8766604911341491], 
             UndirectedEdge[165, 226] -> 
             RGBColor[
              0.9872262108460642, 0.9668784626343387, 0.5489807480897417], 
             UndirectedEdge[235, 261] -> 
             RGBColor[
              0.9669049089257449, 0.895749874200058, 0.34819524088113996`], 
             UndirectedEdge[56, 198] -> 
             RGBColor[
              0.959970566690975, 0.8681211144389187, 0.3474863961588692], 
             UndirectedEdge[50, 254] -> 
             RGBColor[
              0.9861740324072006, 0.9885506213362869, 0.8787955936772404], 
             UndirectedEdge[249, 268] -> 
             RGBColor[
              0.5837865750764887, 0.6393784699172916, 0.6719469333246479], 
             UndirectedEdge[38, 224] -> 
             RGBColor[
              0.8984905648459856, 0.5519873610582565, 0.2607641380776845], 
             UndirectedEdge[79, 87] -> 
             RGBColor[
              0.9932846003499262, 0.9910768223634556, 0.7308470011254131], 
             UndirectedEdge[38, 311] -> 
             RGBColor[
              0.9584804983227556, 0.939748240703068, 0.6659347166526925], 
             UndirectedEdge[37, 145] -> 
             RGBColor[
              0.9222281084100186, 0.7149137934907575, 0.5318269042985506], 
             UndirectedEdge[147, 359] -> 
             RGBColor[
              0.9610819773235719, 0.8703253903197217, 0.47868901361818356`], 
             UndirectedEdge[192, 349] -> 
             RGBColor[
              0.9913891616385389, 0.9907072112961532, 0.7923674059921495], 
             UndirectedEdge[213, 308] -> 
             RGBColor[
              0.894789557996939, 0.9124901731436983, 0.7008524536638625], 
             UndirectedEdge[262, 397] -> 
             RGBColor[
              0.9565065186429265, 0.8669486341231112, 0.563762475072864], 
             UndirectedEdge[129, 364] -> 
             RGBColor[
              0.7885428503621041, 0.831413315240235, 0.8086364505965582], 
             UndirectedEdge[54, 83] -> 
             RGBColor[
              0.9634793749262922, 0.9722835581338396, 0.9467040715319814], 
             UndirectedEdge[13, 277] -> 
             RGBColor[
              0.991054067919412, 0.9806668216777426, 0.5717844372932495], 
             UndirectedEdge[191, 235] -> 
             RGBColor[
              0.9937708903063889, 0.9889611004152823, 0.5739041368295893], 
             UndirectedEdge[54, 214] -> 
             RGBColor[
              0.980208087097032, 0.9812511335985031, 0.7036706320594172], 
             UndirectedEdge[87, 176] -> 
             RGBColor[
              0.9275880780285954, 0.7250820590354482, 0.44039952676768335`], 
             UndirectedEdge[16, 377] -> 
             RGBColor[
              0.9929335318361241, 0.9872938640640236, 0.47223673342760164`], 
             UndirectedEdge[158, 344] -> 
             RGBColor[
              0.8822621768074312, 0.8712284972082576, 0.6536405820802544], 
             UndirectedEdge[95, 228] -> 
             RGBColor[
              0.9722595154951017, 0.9462268487809673, 0.6345485082075963], 
             UndirectedEdge[193, 283] -> 
             RGBColor[
              0.9945508072201121, 0.9907530525787502, 0.6482671783079796], 
             UndirectedEdge[11, 366] -> 
             RGBColor[
              0.9369712538221734, 0.7746456334643033, 0.3131165417409737], 
             UndirectedEdge[106, 231] -> 
             RGBColor[
              0.9923790197649692, 0.9904875471750937, 0.7302415336522243], 
             UndirectedEdge[76, 388] -> 
             RGBColor[
              0.9903149862827693, 0.9797341084201445, 0.579698551405809], 
             UndirectedEdge[208, 351] -> 
             RGBColor[
              0.9900269231909679, 0.9785753042361277, 0.5772862542951844], 
             UndirectedEdge[208, 225] -> 
             RGBColor[
              0.9834337708021705, 0.9563350530829152, 0.5516731022770626], 
             UndirectedEdge[163, 374] -> 
             RGBColor[
              0.9873273837783487, 0.9759614761130897, 0.6116739498779392], 
             UndirectedEdge[165, 288] -> 
             RGBColor[
              0.9915570397417417, 0.9907480880504538, 0.7875102998901242], 
             UndirectedEdge[110, 239] -> 
             RGBColor[
              0.9445138311093879, 0.8486752493854255, 0.5960536628365682], 
             UndirectedEdge[14, 273] -> 
             RGBColor[
              0.9709878226923725, 0.9188107813960811, 0.5482491726907011], 
             UndirectedEdge[231, 372] -> 
             RGBColor[
              0.9402148107414131, 0.9512977895313964, 0.8187352359386242], 
             UndirectedEdge[5, 162] -> 
             RGBColor[
              0.9854069091988586, 0.9624362194863965, 0.39780902722187167`], 
             UndirectedEdge[36, 90] -> 
             RGBColor[
              0.9898153626101213, 0.9886613893534613, 0.7170464211930409], 
             UndirectedEdge[258, 328] -> 
             RGBColor[
              0.9759917331773666, 0.9398381092698043, 0.5822520485440703], 
             UndirectedEdge[91, 208] -> 
             RGBColor[
              0.966508692191954, 0.8943061610149423, 0.5116324089733336], 
             UndirectedEdge[155, 370] -> 
             RGBColor[
              0.9177287220367651, 0.9128465930932215, 0.6769625924270288], 
             UndirectedEdge[66, 243] -> 
             RGBColor[
              0.9867106722347079, 0.9682029284801699, 0.5700303947648064], 
             UndirectedEdge[253, 334] -> 
             RGBColor[
              0.9433654421691833, 0.8101970439636748, 0.28877129553964087`], 
             UndirectedEdge[50, 210] -> 
             RGBColor[
              0.955726817616714, 0.8642616359882949, 0.5651133052064047], 
             UndirectedEdge[239, 365] -> 
             RGBColor[
              0.9166075404271108, 0.707083717222964, 0.2517586734362875], 
             UndirectedEdge[13, 51] -> 
             RGBColor[
              0.9930793675746508, 0.9914061548870468, 0.7643563195180277], 
             UndirectedEdge[258, 300] -> 
             RGBColor[
              0.9775866190540655, 0.9452180338289218, 0.5884478790061198], 
             UndirectedEdge[30, 294] -> 
             RGBColor[
              0.9776799816323394, 0.979816455058819, 0.7437173912922643], 
             UndirectedEdge[31, 292] -> 
             RGBColor[
              0.9935458981811682, 0.9886036537563383, 0.5388890309986412], 
             UndirectedEdge[203, 216] -> 
             RGBColor[
              0.9416135507462369, 0.9512584539418436, 0.7252687425354927], 
             UndirectedEdge[64, 233] -> 
             RGBColor[
              0.9145961605051055, 0.6300986378421507, 0.3934477444656915], 
             UndirectedEdge[50, 242] -> 
             RGBColor[
              0.9895631726726386, 0.9875796536034459, 0.6501756569148137], 
             UndirectedEdge[133, 398] -> 
             RGBColor[
              0.9888686272458558, 0.9877275377816594, 0.6933129989483787], 
             UndirectedEdge[7, 390] -> 
             RGBColor[
              0.9743601724585907, 0.9251729825643398, 0.3548945409871212], 
             UndirectedEdge[186, 342] -> 
             RGBColor[
              0.9327231359861823, 0.7515727862311283, 0.4864305580821723], 
             UndirectedEdge[347, 398] -> 
             RGBColor[
              0.8685256734637179, 0.8937315500609064, 0.7292692217618907], 
             UndirectedEdge[321, 375] -> 
             RGBColor[
              0.9792139246445968, 0.9829199620144329, 0.8708810972509085], 
             UndirectedEdge[149, 279] -> 
             RGBColor[
              0.9937782651342473, 0.9891006631730717, 0.5641807398386882], 
             UndirectedEdge[38, 306] -> 
             RGBColor[
              0.9810198777007912, 0.947637732119434, 0.38076623827326234`], 
             UndirectedEdge[12, 358] -> 
             RGBColor[
              0.911646272562695, 0.9297170212959847, 0.8864836260181435], 
             UndirectedEdge[139, 378] -> 
             RGBColor[
              0.9557061094235837, 0.8510643000102112, 0.35291133688124254`], 
             UndirectedEdge[272, 374] -> 
             RGBColor[
              0.9895227374203934, 0.9755491856411428, 0.47933206194779077`], 
             UndirectedEdge[21, 114] -> 
             RGBColor[
              0.9718783704330213, 0.9780929235996195, 0.9121292209245851], 
             UndirectedEdge[250, 321] -> 
             RGBColor[
              0.9809953878629325, 0.9828667232184514, 0.7839388240105443], 
             UndirectedEdge[19, 152] -> 
             RGBColor[
              0.9179082886749675, 0.9337563973499081, 0.8364861927184697], 
             UndirectedEdge[270, 336] -> 
             RGBColor[
              0.9058492070086284, 0.9277635853197262, 0.9908819000972582], 
             UndirectedEdge[87, 277] -> 
             RGBColor[
              0.9911169110186178, 0.9802786073638488, 0.5406348843257747], 
             UndirectedEdge[37, 377] -> 
             RGBColor[
              0.9900184376845718, 0.9880014406527544, 0.6596054138000187], 
             UndirectedEdge[312, 356] -> 
             RGBColor[
              0.8379407005711224, 0.8517710621587677, 0.6713711851697106], 
             UndirectedEdge[294, 343] -> 
             RGBColor[
              0.9137020404722679, 0.9333515579571663, 0.9682745702141681], 
             UndirectedEdge[170, 349] -> 
             RGBColor[
              0.9835787647729652, 0.9571914412752862, 0.5547750676900092], 
             UndirectedEdge[176, 390] -> 
             RGBColor[
              0.910455862699002, 0.6687098629260537, 0.2532005270821027], 
             UndirectedEdge[235, 327] -> 
             RGBColor[
              0.9728678634808678, 0.9752438127955215, 0.694153127036605], 
             UndirectedEdge[271, 400] -> 
             RGBColor[
              0.9795997294507015, 0.9836412102067316, 0.8896417446226978], 
             UndirectedEdge[45, 103] -> 
             RGBColor[
              0.9211266823656749, 0.7190291317948956, 0.2572303856030264], 
             UndirectedEdge[30, 343] -> 
             RGBColor[
              0.9295591160090555, 0.9421198466238931, 0.7624839203202709], 
             UndirectedEdge[200, 234] -> 
             RGBColor[
              0.9908455539024009, 0.9817525801410176, 0.5833407664456718], 
             UndirectedEdge[282, 382] -> 
             RGBColor[
              0.9932388689049824, 0.9911093267606256, 0.7353422554075884], 
             UndirectedEdge[305, 382] -> 
             RGBColor[
              0.9890703562565395, 0.9897483256801164, 0.8307960120478446], 
             UndirectedEdge[50, 164] -> 
             RGBColor[
              0.9895492988509551, 0.9875499789017235, 0.6486655770438639], 
             UndirectedEdge[259, 287] -> 
             RGBColor[
              0.9914849561775838, 0.9907468247998557, 0.7907798425718546], 
             UndirectedEdge[90, 95] -> 
             RGBColor[
              0.9821125312231375, 0.9506063966008421, 0.4459890545503938], 
             UndirectedEdge[44, 243] -> 
             RGBColor[
              0.9929268823688746, 0.9913430983357672, 0.7668833939968029], 
             UndirectedEdge[82, 194] -> 
             RGBColor[
              0.9644642037971617, 0.883864851836932, 0.47371413926665284`], 
             UndirectedEdge[124, 150] -> 
             RGBColor[
              0.9502234288948188, 0.8384516717216117, 0.28874287703682766`], 
             UndirectedEdge[233, 316] -> 
             RGBColor[
              0.9039251169668254, 0.6247642694053688, 0.5560385140255051], 
             UndirectedEdge[87, 390] -> 
             RGBColor[
              0.9776696548598227, 0.9349178547743371, 0.48839483345010115`], 
             UndirectedEdge[72, 376] -> 
             RGBColor[
              0.9382470241313086, 0.9487607275896905, 0.7400781418792235], 
             UndirectedEdge[99, 169] -> 
             RGBColor[
              0.9483719576089039, 0.8330190464842263, 0.27731706910745807`], 
             UndirectedEdge[127, 137] -> 
             RGBColor[
              0.9566595654442664, 0.8572694671060966, 0.5135522020524537], 
             UndirectedEdge[68, 391] -> 
             RGBColor[
              0.9452476240527184, 0.8206078923971297, 0.274929256931584], 
             UndirectedEdge[292, 309] -> 
             RGBColor[
              0.9938846999684108, 0.9893283165211346, 0.5757655146977207], 
             UndirectedEdge[88, 140] -> 
             RGBColor[
              0.9494823363038649, 0.8290915010417809, 0.509134452428003], 
             UndirectedEdge[153, 216] -> 
             RGBColor[
              0.9420145372441043, 0.9521161235148281, 0.7689136482265462], 
             UndirectedEdge[145, 165] -> 
             RGBColor[
              0.9262354287506152, 0.7165423782793854, 0.4633403041649083], 
             UndirectedEdge[37, 76] -> 
             RGBColor[
              0.9904280192077324, 0.9903097542007809, 0.808296023427491], 
             UndirectedEdge[6, 391] -> 
             RGBColor[
              0.9676605588408362, 0.9025736126875696, 0.32886780719801717`], 
             UndirectedEdge[203, 206] -> 
             RGBColor[
              0.9939065934196412, 0.9893751443995492, 0.5781484817534375], 
             UndirectedEdge[298, 320] -> 
             RGBColor[
              0.9651507727994824, 0.8941075150442965, 0.319117762360682], 
             UndirectedEdge[39, 164] -> 
             RGBColor[
              0.9768441665650305, 0.9784736435637378, 0.6880459768292748], 
             UndirectedEdge[107, 156] -> 
             RGBColor[
              0.9817852805557068, 0.9620331151316937, 0.6230894815163486], 
             UndirectedEdge[31, 222] -> 
             RGBColor[
              0.9867407510752024, 0.9865350313364301, 0.7252908845671796], 
             UndirectedEdge[301, 329] -> 
             RGBColor[
              0.9522211791841216, 0.95975987095737, 0.7297809833624009], 
             UndirectedEdge[126, 320] -> 
             RGBColor[
              0.9409519434372794, 0.9195550454163502, 0.6618048907271545], 
             UndirectedEdge[49, 191] -> 
             RGBColor[
              0.9891728347046423, 0.9734507791957947, 0.5560415590867451], 
             UndirectedEdge[122, 173] -> 
             RGBColor[
              0.9632426897472306, 0.9686549965703442, 0.739495636722876], 
             UndirectedEdge[60, 102] -> 
             RGBColor[
              0.963370581596088, 0.9722024202463062, 0.9468882302621721], 
             UndirectedEdge[120, 380] -> 
             RGBColor[
              0.9936681912973981, 0.9888652263662233, 0.5521998819946361], 
             UndirectedEdge[110, 247] -> 
             RGBColor[
              0.9800790433822204, 0.9834904340764004, 0.8660700218351011], 
             UndirectedEdge[59, 149] -> 
             RGBColor[
              0.9950623198922295, 0.9920280546636464, 0.7170937462225431], 
             UndirectedEdge[92, 346] -> 
             RGBColor[
              0.9522368151044527, 0.874932145500412, 0.5988833688872873], 
             UndirectedEdge[6, 142] -> 
             RGBColor[
              0.9523637442942925, 0.8419510530310562, 0.31643353121051543`], 
             UndirectedEdge[176, 232] -> 
             RGBColor[
              0.9212563998284152, 0.7051426107502798, 0.29515857431957787`], 
             UndirectedEdge[60, 345] -> 
             RGBColor[
              0.9325178833595366, 0.948618426117533, 0.9792093135469351], 
             UndirectedEdge[79, 126] -> 
             RGBColor[
              0.9526016491431917, 0.9623383281308153, 0.8888528506135853], 
             UndirectedEdge[14, 212] -> 
             RGBColor[
              0.8866299873951771, 0.8539014718910882, 0.6315345622136785], 
             UndirectedEdge[22, 338] -> 
             RGBColor[
              0.9701000850522902, 0.9193268838738593, 0.56728317151879], 
             UndirectedEdge[195, 389] -> 
             RGBColor[
              0.8386819155893942, 0.8359770957694772, 0.647535537170715], 
             UndirectedEdge[14, 293] -> 
             RGBColor[
              0.8938494604660551, 0.8596580837504304, 0.6322231620000787], 
             UndirectedEdge[201, 394] -> 
             RGBColor[
              0.961573828743856, 0.9708624049110242, 0.949929664172805], 
             UndirectedEdge[20, 189] -> 
             RGBColor[
              0.9735861062004022, 0.9792380953112634, 0.9034860000948216], 
             UndirectedEdge[195, 359] -> 
             RGBColor[
              0.9806039974511449, 0.9446939940615402, 0.5101756221843987], 
             UndirectedEdge[222, 224] -> 
             RGBColor[
              0.9017652474709967, 0.5832367774429524, 0.544452103620806], 
             UndirectedEdge[54, 389] -> 
             RGBColor[
              0.8393409002524134, 0.874790549081839, 0.9558493596031505], 
             UndirectedEdge[123, 366] -> 
             RGBColor[
              0.9900095687735998, 0.9766037420378981, 0.5311919797765808], 
             UndirectedEdge[120, 263] -> 
             RGBColor[
              0.9823601772611543, 0.9519021723958774, 0.4078013771511432], 
             UndirectedEdge[332, 364] -> 
             RGBColor[
              0.7846778728679218, 0.8196892010885023, 0.6819428779935603], 
             UndirectedEdge[70, 228] -> 
             RGBColor[
              0.8956389544934542, 0.5571130887387925, 0.5465914769337907], 
             UndirectedEdge[74, 141] -> 
             RGBColor[
              0.9745201190930617, 0.9303671935181684, 0.5453841622179356], 
             UndirectedEdge[212, 385] -> 
             RGBColor[
              0.9063602349249209, 0.9216201702513793, 0.7021210259020728], 
             UndirectedEdge[256, 384] -> 
             RGBColor[
              0.9909494005615731, 0.9799203194341355, 0.5224024048311742], 
             UndirectedEdge[158, 317] -> 
             RGBColor[
              0.9680219116763433, 0.9385720384105074, 0.6321808792351917], 
             UndirectedEdge[76, 208] -> 
             RGBColor[
              0.9936849833531894, 0.9916565925750881, 0.7543196987842483], 
             UndirectedEdge[101, 253] -> 
             RGBColor[
              0.9610161877866215, 0.8801605889491895, 0.3030556803365817], 
             UndirectedEdge[111, 309] -> 
             RGBColor[
              0.989854411280339, 0.9764168001540351, 0.5019807273148575], 
             UndirectedEdge[145, 170] -> 
             RGBColor[
              0.9154397348729673, 0.681820656381036, 0.2772969945312054], 
             UndirectedEdge[59, 279] -> 
             RGBColor[
              0.9937882187867734, 0.9893028812304576, 0.5784157037342125], 
             UndirectedEdge[83, 334] -> 
             RGBColor[
              0.9400736719521883, 0.8463166473490042, 0.6043089726814825], 
             UndirectedEdge[242, 312] -> 
             RGBColor[
              0.8447858222785098, 0.874843421630972, 0.6994804607628595], 
             UndirectedEdge[140, 356] -> 
             RGBColor[
              0.9856503049036716, 0.9657198564902676, 0.5734713451320959], 
             UndirectedEdge[172, 316] -> 
             RGBColor[
              0.841986649320905, 0.8767637444051035, 0.9513707965520668], 
             UndirectedEdge[217, 331] -> 
             RGBColor[
              0.9883417030576331, 0.9884092964152182, 0.7765580172056157], 
             UndirectedEdge[263, 336] -> 
             RGBColor[
              0.9457520406736226, 0.927675824645799, 0.6685787524766613], 
             UndirectedEdge[122, 338] -> 
             RGBColor[
              0.9903654750008399, 0.9883628530253621, 0.6696933932450915], 
             UndirectedEdge[303, 400] -> 
             RGBColor[
              0.9821679045433704, 0.9830195769952407, 0.7246976107676735], 
             UndirectedEdge[133, 367] -> 
             RGBColor[
              0.9809761627612681, 0.9614335142700619, 0.6346669190221741], 
             UndirectedEdge[136, 279] -> 
             RGBColor[
              0.9059542635629951, 0.9226098364930057, 0.7040684622804506], 
             UndirectedEdge[117, 365] -> 
             RGBColor[
              0.9540633129458442, 0.8424670675894572, 0.47491494189887445`], 
             UndirectedEdge[33, 245] -> 
             RGBColor[0.982723006039268, 0.9554219019794, 0.5591722079998359],
              UndirectedEdge[162, 368] -> 
             RGBColor[
              0.9873564555189458, 0.9690124969992941, 0.4053826465344789], 
             UndirectedEdge[46, 128] -> 
             RGBColor[
              0.9250475061037664, 0.7166353267716902, 0.31298891498423304`], 
             UndirectedEdge[117, 269] -> 
             RGBColor[
              0.7439502408155105, 0.7954786396412745, 0.8270595304673021], 
             UndirectedEdge[98, 134] -> 
             RGBColor[
              0.9624184243542266, 0.8823023620564492, 0.5289560228127252], 
             UndirectedEdge[90, 326] -> 
             RGBColor[
              0.9942908531503991, 0.9905121197067267, 0.6428759607423937], 
             UndirectedEdge[119, 306] -> 
             RGBColor[
              0.9629701286598153, 0.962983422283189, 0.7005509043243789], 
             UndirectedEdge[150, 211] -> 
             RGBColor[
              0.9708090555771809, 0.9131942314814493, 0.3410991224749973], 
             UndirectedEdge[388, 395] -> 
             RGBColor[
              0.991106468032679, 0.979994747767091, 0.5617362669487199], 
             UndirectedEdge[102, 108] -> 
             RGBColor[
              0.9184919417003076, 0.9368274488141107, 0.9568239342333588], 
             UndirectedEdge[15, 392] -> 
             RGBColor[
              0.9497590276438446, 0.8358359127026305, 0.5369922747329134], 
             UndirectedEdge[32, 292] -> 
             RGBColor[
              0.9901046103251342, 0.9887341478026214, 0.7088471257392779], 
             UndirectedEdge[115, 332] -> 
             RGBColor[
              0.9648356019370823, 0.962157536398773, 0.6926865488723519], 
             UndirectedEdge[93, 293] -> 
             RGBColor[
              0.5814801326133381, 0.6648542842015985, 0.9631319149746781], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.9922668256345404, 0.9892378619767515, 0.6446343972535117], 
             UndirectedEdge[276, 305] -> 
             RGBColor[
              0.9903306711051392, 0.989281634123266, 0.7381020391995217], 
             UndirectedEdge[75, 347] -> 
             RGBColor[
              0.8673028948278196, 0.8899359430336484, 0.6965336118933576], 
             UndirectedEdge[64, 193] -> 
             RGBColor[
              0.9944896911508591, 0.9906223314864002, 0.6416150713344321], 
             UndirectedEdge[18, 99] -> 
             RGBColor[
              0.9682218671148466, 0.9021360908797305, 0.3431879924096779], 
             UndirectedEdge[74, 290] -> 
             RGBColor[
              0.9920917356650626, 0.9892066354252573, 0.6505292716634623], 
             UndirectedEdge[39, 230] -> 
             RGBColor[
              0.9777481285189598, 0.9804071267786193, 0.786436656907966], 
             UndirectedEdge[259, 345] -> 
             RGBColor[
              0.9525223305103679, 0.9623055278377469, 0.8901673656295152], 
             UndirectedEdge[30, 168] -> 
             RGBColor[
              0.9934404348660999, 0.9883780783893839, 0.5274099999975894], 
             UndirectedEdge[231, 331] -> 
             RGBColor[
              0.9945053459465811, 0.9906558155115072, 0.6433189992385832], 
             UndirectedEdge[137, 242] -> 
             RGBColor[
              0.9925735299029322, 0.9888245136808242, 0.6002862470540686], 
             UndirectedEdge[172, 221] -> 
             RGBColor[
              0.8524984147199464, 0.881757433007544, 0.7714435844868504], 
             UndirectedEdge[157, 211] -> 
             RGBColor[
              0.9719776868141579, 0.917136299051436, 0.3456390341531616], 
             UndirectedEdge[46, 213] -> 
             RGBColor[
              0.8949558372405043, 0.9130510720764671, 0.7014984171259133], 
             UndirectedEdge[184, 318] -> 
             RGBColor[
              0.9871053776029617, 0.9671368490999155, 0.49188074530083353`], 
             UndirectedEdge[201, 293] -> 
             RGBColor[
              0.9051291788811432, 0.9261866547298051, 0.9560455278630849], 
             UndirectedEdge[64, 115] -> 
             RGBColor[
              0.9684649862328649, 0.9733777405212551, 0.7937372557422362], 
             UndirectedEdge[174, 266] -> 
             RGBColor[
              0.9943926611786791, 0.9916094742658955, 0.7178945877035245], 
             UndirectedEdge[80, 104] -> 
             RGBColor[
              0.9757096876783894, 0.934060842210161, 0.5478001811401091], 
             UndirectedEdge[265, 321] -> 
             RGBColor[
              0.9805891009116237, 0.9819977165115139, 0.7397169966730005], 
             UndirectedEdge[178, 296] -> 
             RGBColor[
              0.939429459424004, 0.7911175339201093, 0.3012950168100556], 
             UndirectedEdge[114, 249] -> 
             RGBColor[
              0.9727373172204836, 0.9703431373101055, 0.6841775806009153], 
             UndirectedEdge[255, 380] -> 
             RGBColor[
              0.9588133489378268, 0.8618625579513388, 0.44541091368299585`], 
             UndirectedEdge[253, 391] -> 
             RGBColor[
              0.9610304464579902, 0.8802086867958117, 0.30311107258232534`], 
             UndirectedEdge[40, 63] -> 
             RGBColor[
              0.9811158276028896, 0.9504962860169329, 0.5563553966592216], 
             UndirectedEdge[23, 311] -> 
             RGBColor[
              0.9369817359154303, 0.8596842841214394, 0.6217031920086483], 
             UndirectedEdge[156, 396] -> 
             RGBColor[
              0.9905841331460865, 0.9901552897527857, 0.7897882551784903], 
             UndirectedEdge[93, 281] -> 
             RGBColor[
              0.6462287138591238, 0.6760358743223834, 0.6306322146592808], 
             UndirectedEdge[27, 325] -> 
             RGBColor[
              0.9915264382678071, 0.9885992616486698, 0.6327402985261373], 
             UndirectedEdge[12, 107] -> 
             RGBColor[
              0.9045700340934413, 0.9020881703096919, 0.6753161221059519], 
             UndirectedEdge[255, 312] -> 
             RGBColor[
              0.8101244940952492, 0.7482546604719319, 0.6137543163115878], 
             UndirectedEdge[257, 310] -> 
             RGBColor[
              0.9648451211536605, 0.9723378781101057, 0.9012110750475035], 
             UndirectedEdge[50, 197] -> 
             RGBColor[
              0.987820122145344, 0.9817177782449771, 0.6418869644110292], 
             UndirectedEdge[215, 350] -> 
             RGBColor[
              0.9714662302877863, 0.9683676499581548, 0.6841479840158242], 
             UndirectedEdge[49, 235] -> 
             RGBColor[
              0.9877043689405771, 0.9701860906644132, 0.4067342244795803], 
             UndirectedEdge[239, 323] -> 
             RGBColor[
              0.957476310304676, 0.856185212174833, 0.46661040630402556`], 
             UndirectedEdge[211, 216] -> 
             RGBColor[
              0.9347995634424934, 0.9284760051683172, 0.6815589585059849], 
             UndirectedEdge[98, 151] -> 
             RGBColor[
              0.992610154048676, 0.98997220673876, 0.6820035763548024], 
             UndirectedEdge[10, 32] -> 
             RGBColor[
              0.8923762829827988, 0.9154847029362551, 0.9261378757850591], 
             UndirectedEdge[330, 367] -> 
             RGBColor[
              0.9132998056915538, 0.9088184127094596, 0.6758094731202201], 
             UndirectedEdge[99, 384] -> 
             RGBColor[
              0.9677562847459931, 0.9005655722256489, 0.34137929282453516`], 
             UndirectedEdge[127, 138] -> 
             RGBColor[
              0.8927934206125143, 0.8092114384954827, 0.6210146301457997], 
             UndirectedEdge[292, 385] -> 
             RGBColor[
              0.9925490583474699, 0.9858447718864781, 0.48368280486839177`], 
             UndirectedEdge[177, 219] -> 
             RGBColor[
              0.8998722997861142, 0.922911437207437, 0.9873188916398212], 
             UndirectedEdge[170, 322] -> 
             RGBColor[
              0.9780800716249023, 0.9377210759261687, 0.36934564680422827`], 
             UndirectedEdge[261, 335] -> 
             RGBColor[
              0.9683367166335487, 0.8989361548557944, 0.493512572291551], 
             UndirectedEdge[6, 253] -> 
             RGBColor[
              0.9726461272098642, 0.9193911054634221, 0.34823579886610373`], 
             UndirectedEdge[95, 246] -> 
             RGBColor[
              0.9808537583474916, 0.9470773725340753, 0.3801208959547009], 
             UndirectedEdge[50, 331] -> 
             RGBColor[
              0.9905261192163568, 0.989639298891629, 0.7549864455813293], 
             UndirectedEdge[9, 358] -> 
             RGBColor[
              0.9926667591037985, 0.9899144379517254, 0.6751648144369939], 
             UndirectedEdge[99, 144] -> 
             RGBColor[
              0.9522861199114998, 0.8483810736714623, 0.2812806237380229], 
             UndirectedEdge[2, 28] -> 
             RGBColor[
              0.9745332524677659, 0.9254047857123409, 0.3855015554787809], 
             UndirectedEdge[138, 258] -> 
             RGBColor[
              0.926407541383071, 0.9421879049314221, 0.918316148614325], 
             UndirectedEdge[144, 384] -> 
             RGBColor[
              0.9719617870133261, 0.9170826652897794, 0.3455772664293554], 
             UndirectedEdge[79, 277] -> 
             RGBColor[
              0.9895996411791277, 0.9800653788435727, 0.595888052315506], 
             UndirectedEdge[346, 354] -> 
             RGBColor[
              0.9585279028928366, 0.8796231337383528, 0.5881941302268134], 
             UndirectedEdge[144, 148] -> 
             RGBColor[
              0.9612538185029255, 0.8809621731536285, 0.30397883079662746`], 
             UndirectedEdge[38, 346] -> 
             RGBColor[
              0.9531546953781531, 0.8468095356608836, 0.30809848795217837`], 
             UndirectedEdge[38, 363] -> 
             RGBColor[
              0.9759496668464199, 0.9527767179848787, 0.6363639710309841], 
             UndirectedEdge[78, 104] -> 
             RGBColor[
              0.9773085123199365, 0.9347219972873598, 0.521303519204135], 
             UndirectedEdge[95, 282] -> 
             RGBColor[
              0.9827107957509034, 0.951886023931911, 0.5111064563370261], 
             UndirectedEdge[92, 306] -> 
             RGBColor[
              0.9801019974270906, 0.9757603419589624, 0.6715511192083713], 
             UndirectedEdge[9, 339] -> 
             RGBColor[
              0.9927836114379367, 0.9899627593948596, 0.6732282688561767], 
             UndirectedEdge[36, 148] -> 
             RGBColor[
              0.9759908998021403, 0.9427453425806258, 0.6023629300416586], 
             UndirectedEdge[62, 395] -> 
             RGBColor[
              0.9849148902537449, 0.9591091020671494, 0.5376831564589148], 
             UndirectedEdge[32, 247] -> 
             RGBColor[
              0.9889259186493711, 0.989688597017675, 0.8331897169911702], 
             UndirectedEdge[168, 379] -> 
             RGBColor[
              0.9922345541234718, 0.9893847544980372, 0.656816803160504], 
             UndirectedEdge[137, 230] -> 
             RGBColor[
              0.993463618035178, 0.9907283221939833, 0.69716684726181], 
             UndirectedEdge[268, 279] -> 
             RGBColor[
              0.5857155820143956, 0.6458847448699414, 0.6795018486751788], 
             UndirectedEdge[185, 288] -> 
             RGBColor[
              0.9821686419024643, 0.960773506138352, 0.6069340696199338], 
             UndirectedEdge[233, 310] -> 
             RGBColor[
              0.912514218291226, 0.6302057557858431, 0.49831826151448727`], 
             UndirectedEdge[150, 386] -> 
             RGBColor[
              0.9779224571734415, 0.9366170971512411, 0.4173983044741636], 
             UndirectedEdge[138, 281] -> 
             RGBColor[
              0.9150259751157028, 0.8946337201003858, 0.6530817106351473], 
             UndirectedEdge[88, 257] -> 
             RGBColor[
              0.9230999985598749, 0.8107890360946616, 0.6152982885935583], 
             UndirectedEdge[27, 40] -> 
             RGBColor[
              0.9925914103446634, 0.9890396549709839, 0.6150909551532406], 
             UndirectedEdge[159, 250] -> 
             RGBColor[
              0.99054450736075, 0.989568005427383, 0.7489466958367945], 
             UndirectedEdge[169, 363] -> 
             RGBColor[
              0.9635558303777305, 0.9088107587132321, 0.5994584835172463], 
             UndirectedEdge[144, 382] -> 
             RGBColor[
              0.9740539452451429, 0.9278496462386857, 0.5370411290157894], 
             UndirectedEdge[35, 207] -> 
             RGBColor[
              0.993934594411289, 0.9894350356893491, 0.5811962168922021], 
             UndirectedEdge[71, 287] -> 
             RGBColor[
              0.9924035180323312, 0.9895426232372323, 0.660413146539333], 
             UndirectedEdge[148, 361] -> 
             RGBColor[
              0.9752325675332972, 0.9281157759994293, 0.35828363111436967`], 
             UndirectedEdge[215, 393] -> 
             RGBColor[
              0.9546906593792819, 0.8486369552395301, 0.33153179286365825`], 
             UndirectedEdge[33, 124] -> 
             RGBColor[
              0.9553665794069193, 0.8558007260680947, 0.30872304557386054`], 
             UndirectedEdge[31, 111] -> 
             RGBColor[
              0.9895156094930966, 0.9756921373892387, 0.465104243615778], 
             UndirectedEdge[113, 357] -> 
             RGBColor[
              0.9115485005304631, 0.7468696956547196, 0.5976203331965282], 
             UndirectedEdge[30, 329] -> 
             RGBColor[
              0.9525417765395067, 0.9604455962831738, 0.7646760269985287], 
             UndirectedEdge[117, 239] -> 
             RGBColor[
              0.9575785945945161, 0.8564039879282731, 0.47774342002766124`], 
             UndirectedEdge[209, 338] -> 
             RGBColor[
              0.971373426275627, 0.9243752575085806, 0.5683077317562468], 
             UndirectedEdge[208, 323] -> 
             RGBColor[
              0.9942889987345234, 0.9915162603154084, 0.7159528570160136], 
             UndirectedEdge[71, 212] -> 
             RGBColor[
              0.9073394000410797, 0.9243412476876101, 0.7554034681038391], 
             UndirectedEdge[199, 292] -> 
             RGBColor[
              0.8954980001890713, 0.9151924436590968, 0.7631871334282714], 
             UndirectedEdge[11, 386] -> 
             RGBColor[
              0.9410287950519811, 0.7877603645679145, 0.3775442832672792], 
             UndirectedEdge[130, 267] -> 
             RGBColor[
              0.9433774785424571, 0.9360012229265826, 0.6833854719054582], 
             UndirectedEdge[67, 347] -> 
             RGBColor[
              0.8619717537577803, 0.8719527523929558, 0.6758231355377704], 
             UndirectedEdge[211, 358] -> 
             RGBColor[
              0.9853931994964494, 0.9661490104906743, 0.5814334213115202], 
             UndirectedEdge[2, 164] -> 
             RGBColor[
              0.9742486314377894, 0.9247960101088213, 0.3545223128432185], 
             UndirectedEdge[266, 358] -> 
             RGBColor[
              0.9927400259491205, 0.991265828404208, 0.7699800884410404], 
             UndirectedEdge[57, 397] -> 
             RGBColor[
              0.9904773044048021, 0.9893384750301619, 0.7353960363885478], 
             UndirectedEdge[209, 386] -> 
             RGBColor[
              0.9742507039776434, 0.9239676607141574, 0.40450785499259406`], 
             UndirectedEdge[74, 386] -> 
             RGBColor[
              0.992203991506831, 0.9894467393199934, 0.6627476272772055], 
             UndirectedEdge[47, 268] -> 
             RGBColor[
              0.5823859362964677, 0.6469042526470334, 0.9088758118189535], 
             UndirectedEdge[108, 397] -> 
             RGBColor[
              0.9243323149239859, 0.940746232657975, 0.9273698810882289], 
             UndirectedEdge[157, 358] -> 
             RGBColor[
              0.9781673759442356, 0.9417746109450047, 0.5533624612934497], 
             UndirectedEdge[10, 129] -> 
             RGBColor[
              0.8963925111791009, 0.9165839481424201, 0.8187584889621089], 
             UndirectedEdge[171, 308] -> 
             RGBColor[
              0.9922916053518767, 0.9852556279974369, 0.4589325234280428], 
             UndirectedEdge[225, 335] -> 
             RGBColor[
              0.9841426913133973, 0.9565281727591368, 0.5326528083041605], 
             UndirectedEdge[45, 116] -> 
             RGBColor[
              0.9762830417409113, 0.929979715649458, 0.5051818877731278], 
             UndirectedEdge[261, 349] -> 
             RGBColor[
              0.9675036996423179, 0.8986917180959572, 0.5145894660895143], 
             UndirectedEdge[118, 209] -> 
             RGBColor[
              0.9728682934027065, 0.9249934234819608, 0.5435339148684248], 
             UndirectedEdge[329, 343] -> 
             RGBColor[
              0.8885638353794352, 0.9139806991815211, 0.9892332059204323], 
             UndirectedEdge[163, 171] -> 
             RGBColor[
              0.9912595566687061, 0.9888213303737473, 0.6613274507459085], 
             UndirectedEdge[106, 217] -> 
             RGBColor[
              0.9862153768760212, 0.9882410280788048, 0.8634805516192569], 
             UndirectedEdge[55, 123] -> 
             RGBColor[
              0.9817715062697198, 0.98368067660372, 0.8012812645736163], 
             UndirectedEdge[129, 353] -> 
             RGBColor[
              0.9817679436064459, 0.9836272693565109, 0.7972604824411813], 
             UndirectedEdge[38, 66] -> 
             RGBColor[
              0.9768371247203739, 0.9335283241593827, 0.36451703279096304`], 
             UndirectedEdge[23, 119] -> 
             RGBColor[
              0.9339024590627187, 0.8573877644865402, 0.6269156045162615], 
             UndirectedEdge[306, 354] -> 
             RGBColor[
              0.9863930852154746, 0.9804513301969031, 0.6608618805478974], 
             UndirectedEdge[28, 39] -> 
             RGBColor[
              0.977128787595007, 0.9790824191672572, 0.7190252194648372], 
             UndirectedEdge[158, 267] -> 
             RGBColor[
              0.9734373406667859, 0.9220600542393733, 0.3513095137381206], 
             UndirectedEdge[194, 399] -> 
             RGBColor[
              0.9402790464235902, 0.8009333504372418, 0.2708053228027141], 
             UndirectedEdge[102, 333] -> 
             RGBColor[
              0.983018715801409, 0.9809667447672642, 0.6730483678278277], 
             UndirectedEdge[16, 80] -> 
             RGBColor[
              0.9921288604265215, 0.9891000528194756, 0.6410506565368193], 
             UndirectedEdge[72, 333] -> 
             RGBColor[
              0.9920029091993695, 0.9843116089958917, 0.4552752384624349], 
             UndirectedEdge[167, 211] -> 
             RGBColor[
              0.9863871940217361, 0.9650838904847143, 0.45765894457326045`], 
             UndirectedEdge[193, 255] -> 
             RGBColor[
              0.9590143884671277, 0.8622925611762994, 0.46729282577525266`], 
             UndirectedEdge[168, 211] -> 
             RGBColor[
              0.9862736614647222, 0.9648410558251639, 0.4453016263840218], 
             UndirectedEdge[70, 246] -> 
             RGBColor[
              0.9042331973458442, 0.5579636124919007, 0.2921638646808953], 
             UndirectedEdge[322, 349] -> 
             RGBColor[
              0.9880013128274067, 0.9721097343265817, 0.5719558317533922], 
             UndirectedEdge[193, 312] -> 
             RGBColor[
              0.84592962725674, 0.8772899048229835, 0.8239765738971263], 
             UndirectedEdge[194, 221] -> 
             RGBColor[
              0.9639562477242916, 0.8827783851592996, 0.4184262554762421], 
             UndirectedEdge[208, 221] -> 
             RGBColor[
              0.9937947516650498, 0.9904591158098485, 0.662157113643159], 
             UndirectedEdge[112, 251] -> 
             RGBColor[
              0.6093600674927977, 0.5289007101124257, 0.5865979359605932], 
             UndirectedEdge[297, 325] -> 
             RGBColor[
              0.9832040336341459, 0.9859827132992613, 0.8680199895521581], 
             UndirectedEdge[170, 225] -> 
             RGBColor[
              0.973388433119662, 0.9218950775988866, 0.35111951715295997`], 
             UndirectedEdge[27, 250] -> 
             RGBColor[
              0.9935695376154183, 0.9886542161158857, 0.5414620375310799], 
             UndirectedEdge[67, 126] -> 
             RGBColor[
              0.9466821953531713, 0.9388845306557867, 0.6840658373531199], 
             UndirectedEdge[12, 157] -> 
             RGBColor[
              0.8982307598804034, 0.8807043098567464, 0.6506892388597849], 
             UndirectedEdge[316, 399] -> 
             RGBColor[
              0.9596523376948793, 0.9023967744522681, 0.603348453688956], 
             UndirectedEdge[76, 377] -> 
             RGBColor[
              0.9932121862477407, 0.989322137759219, 0.6066767349519738], 
             UndirectedEdge[3, 51] -> 
             RGBColor[
              0.9630671951050869, 0.8846845893133337, 0.5285486198146621], 
             UndirectedEdge[23, 186] -> 
             RGBColor[
              0.9619590691802166, 0.8767718072275394, 0.5104349497090939], 
             UndirectedEdge[17, 319] -> 
             RGBColor[
              0.9532743782762073, 0.9188062296447437, 0.6385336646593234], 
             UndirectedEdge[115, 360] -> 
             RGBColor[
              0.9304833280169478, 0.8351111057195078, 0.6173983376901344], 
             UndirectedEdge[131, 142] -> 
             RGBColor[
              0.9569297486547139, 0.8658103008686129, 0.5503216915413974], 
             UndirectedEdge[23, 130] -> 
             RGBColor[
              0.9187363523287027, 0.8453373353637593, 0.6269464572590486], 
             UndirectedEdge[348, 354] -> 
             RGBColor[
              0.986515844636316, 0.9886919694771998, 0.8731308804591049], 
             UndirectedEdge[76, 80] -> 
             RGBColor[
              0.9924075148381379, 0.991128326514671, 0.7754906580611916], 
             UndirectedEdge[38, 81] -> 
             RGBColor[
              0.9840130750955306, 0.9564556068552594, 0.5011412166355375], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.9869226456019213, 0.9713640046731138, 0.5877608103294862], 
             UndirectedEdge[131, 281] -> 
             RGBColor[
              0.9767886700373782, 0.941821918116986, 0.5804788911056411], 
             UndirectedEdge[157, 167] -> 
             RGBColor[
              0.9791613704695223, 0.9407094909390448, 0.4295879845551899], 
             UndirectedEdge[165, 172] -> 
             RGBColor[
              0.8532022181855137, 0.8832627974549467, 0.8480482483423423], 
             UndirectedEdge[255, 331] -> 
             RGBColor[
              0.9588335300326157, 0.861905723272471, 0.44760750130750143`], 
             UndirectedEdge[59, 268] -> 
             RGBColor[
              0.5869996367723778, 0.6488121363605162, 0.8324148550590337], 
             UndirectedEdge[161, 364] -> 
             RGBColor[
              0.7702491516129382, 0.7710177362705826, 0.625890020553325], 
             UndirectedEdge[149, 164] -> 
             RGBColor[
              0.9937782651342473, 0.9891006631730717, 0.5641807398386882], 
             UndirectedEdge[10, 52] -> 
             RGBColor[
              0.891237965065512, 0.9150139792240208, 0.9450027495468387], 
             UndirectedEdge[132, 155] -> 
             RGBColor[
              0.9257609627134311, 0.9392015766931563, 0.7710608500705], 
             UndirectedEdge[353, 400] -> 
             RGBColor[
              0.9699551364713331, 0.9771131704910447, 0.9357422963853369], 
             UndirectedEdge[250, 265] -> 
             RGBColor[
              0.9939600623073404, 0.9894895089438038, 0.5839682402077622], 
             UndirectedEdge[82, 233] -> 
             RGBColor[
              0.9149448384387369, 0.6308444246854414, 0.4313991857506995], 
             UndirectedEdge[66, 81] -> 
             RGBColor[
              0.9873992293048847, 0.9678779001102283, 0.5142957863173113], 
             UndirectedEdge[69, 201] -> 
             RGBColor[
              0.9790732519275773, 0.983913446068768, 0.9203077053032989], 
             UndirectedEdge[84, 184] -> 
             RGBColor[
              0.972369336859005, 0.9158335905198081, 0.4429414892662965], 
             UndirectedEdge[180, 268] -> 
             RGBColor[
              0.577699557823601, 0.6188455314236841, 0.6483000207339353], 
             UndirectedEdge[17, 247] -> 
             RGBColor[
              0.9686682690910497, 0.9749802972934734, 0.8853854863034787], 
             UndirectedEdge[188, 394] -> 
             RGBColor[
              0.9712380363709108, 0.9752752101697878, 0.7755015401317958], 
             UndirectedEdge[241, 312] -> 
             RGBColor[
              0.84595318657658, 0.8773402958259086, 0.8265408604704374], 
             UndirectedEdge[81, 128] -> 
             RGBColor[
              0.9264562463474343, 0.7201084554887204, 0.4272085765142214], 
             UndirectedEdge[65, 198] -> 
             RGBColor[
              0.9937791304861591, 0.9891025140733105, 0.5642749280539563], 
             UndirectedEdge[356, 380] -> 
             RGBColor[
              0.9866295554136997, 0.9653789596381747, 0.5030277825411187], 
             UndirectedEdge[40, 265] -> 
             RGBColor[
              0.9929819350365854, 0.9898749477989021, 0.6575971578299229], 
             UndirectedEdge[19, 168] -> 
             RGBColor[
              0.994131143931048, 0.989855435237909, 0.6025894191549477], 
             UndirectedEdge[195, 241] -> 
             RGBColor[
              0.9805374732009081, 0.944551705416917, 0.502934868086205], 
             UndirectedEdge[33, 141] -> 
             RGBColor[
              0.9653817352717726, 0.8948866056958991, 0.3200150079519265], 
             UndirectedEdge[65, 100] -> 
             RGBColor[
              0.9944061135582725, 0.9904435674668486, 0.632518166162507], 
             UndirectedEdge[15, 207] -> 
             RGBColor[
              0.9911914243965245, 0.9887469689763184, 0.6590992749832162], 
             UndirectedEdge[81, 135] -> 
             RGBColor[
              0.9908271486654647, 0.9898650400751433, 0.7573579795328484], 
             UndirectedEdge[259, 271] -> 
             RGBColor[
              0.9899013596732593, 0.9900919669487437, 0.8170241348648941], 
             UndirectedEdge[194, 233] -> 
             RGBColor[
              0.8845518256955363, 0.5233008453903425, 0.2234953831392633], 
             UndirectedEdge[101, 283] -> 
             RGBColor[
              0.9751492267789152, 0.9267366489784321, 0.45132578483895974`], 
             UndirectedEdge[145, 192] -> 
             RGBColor[
              0.9232501317385409, 0.7153364264019031, 0.5148893328333457], 
             UndirectedEdge[68, 397] -> 
             RGBColor[
              0.9606362403564408, 0.8833216045690132, 0.5670853461005849], 
             UndirectedEdge[142, 201] -> 
             RGBColor[
              0.9500188387442646, 0.861356627602217, 0.5933886279834439], 
             UndirectedEdge[146, 354] -> 
             RGBColor[
              0.9885634630886997, 0.9875092771760242, 0.6916780318468024], 
             UndirectedEdge[153, 329] -> 
             RGBColor[
              0.9525899769397399, 0.9605486920654647, 0.7699223431055223], 
             UndirectedEdge[132, 279] -> 
             RGBColor[
              0.9931028113216471, 0.987655935766776, 0.49066176075489104`], 
             UndirectedEdge[257, 389] -> 
             RGBColor[
              0.8254248955536254, 0.8644120155628493, 0.9794055256828879], 
             UndirectedEdge[107, 386] -> 
             RGBColor[
              0.9854303626234564, 0.9619430251741732, 0.446565099398495], 
             UndirectedEdge[157, 203] -> 
             RGBColor[
              0.9787916741179015, 0.9399187478249624, 0.3893488181826693], 
             UndirectedEdge[264, 281] -> 
             RGBColor[
              0.9772414162814804, 0.9420091403239699, 0.5729757141711486], 
             UndirectedEdge[244, 302] -> 
             RGBColor[
              0.9661891023256428, 0.8976100443474021, 0.3231514764977371], 
             UndirectedEdge[46, 105] -> 
             RGBColor[
              0.9918047330540689, 0.9873787179193033, 0.6035907432359284], 
             UndirectedEdge[126, 347] -> 
             RGBColor[
              0.8287255261805562, 0.8668812841556203, 0.9833628302966768], 
             UndirectedEdge[129, 253] -> 
             RGBColor[
              0.9803235309484585, 0.9439754285378072, 0.48973992751235607`], 
             UndirectedEdge[14, 69] -> 
             RGBColor[
              0.9677935335124892, 0.9173848750893934, 0.5964853394402925], 
             UndirectedEdge[118, 124] -> 
             RGBColor[
              0.9643488747053333, 0.8912167672748631, 0.5366789906080596], 
             UndirectedEdge[181, 245] -> 
             RGBColor[
              0.9725381300564014, 0.9199919276417836, 0.5251992781314121], 
             UndirectedEdge[33, 152] -> 
             RGBColor[
              0.9067995019315516, 0.8977746051679896, 0.6665676967883416], 
             UndirectedEdge[47, 371] -> 
             RGBColor[
              0.9718916141968583, 0.9782827902183433, 0.9201670976100682], 
             UndirectedEdge[131, 273] -> 
             RGBColor[
              0.98917845101791, 0.9897930256418517, 0.829004602111661], 
             UndirectedEdge[230, 299] -> 
             RGBColor[
              0.9862193077517672, 0.9640601194482479, 0.49590508843705083`], 
             UndirectedEdge[107, 181] -> 
             RGBColor[
              0.964880780767239, 0.8921227723975917, 0.32366228437170275`], 
             UndirectedEdge[4, 318] -> 
             RGBColor[
              0.9396259263060123, 0.9334029712578804, 0.6836059974731388], 
             UndirectedEdge[10, 333] -> 
             RGBColor[
              0.8945250213210354, 0.9115978288197102, 0.6998247786315365], 
             UndirectedEdge[152, 238] -> 
             RGBColor[
              0.8804364561339015, 0.7982035785702619, 0.6195774317364904], 
             UndirectedEdge[50, 147] -> 
             RGBColor[
              0.9568793497757454, 0.86883104194028, 0.5660406596349683], 
             UndirectedEdge[39, 217] -> 
             RGBColor[
              0.9717048852284708, 0.9784181302491675, 0.9327804281470675], 
             UndirectedEdge[98, 308] -> 
             RGBColor[
              0.9914003609882389, 0.9867193614858216, 0.6068905940032762], 
             UndirectedEdge[31, 363] -> 
             RGBColor[
              0.9859647647855914, 0.9859563020321991, 0.7266044269458531], 
             UndirectedEdge[286, 386] -> 
             RGBColor[
              0.9941056261419363, 0.9898008552672435, 0.5998119652876891], 
             UndirectedEdge[137, 138] -> 
             RGBColor[
              0.9287490033019543, 0.9431561596077069, 0.879512065109226], 
             UndirectedEdge[35, 372] -> 
             RGBColor[
              0.9403206958401976, 0.9515242670510708, 0.8302601754942343], 
             UndirectedEdge[130, 158] -> 
             RGBColor[
              0.9370791210853648, 0.9147553842991528, 0.658917542529659], 
             UndirectedEdge[277, 373] -> 
             RGBColor[
              0.9900149683112751, 0.9779216633363408, 0.42069522103362306`], 
             UndirectedEdge[234, 365] -> 
             RGBColor[
              0.950658084891997, 0.8325427124640048, 0.32884137130111674`], 
             UndirectedEdge[310, 316] -> 
             RGBColor[
              0.98140687492094, 0.9846896069523599, 0.8731763459166825], 
             UndirectedEdge[218, 305] -> 
             RGBColor[
              0.9868438635082588, 0.9888276137104486, 0.8676947588653848], 
             UndirectedEdge[155, 279] -> 
             RGBColor[
              0.925162315420575, 0.9379211306662631, 0.7059017866659665], 
             UndirectedEdge[32, 129] -> 
             RGBColor[
              0.9906148188735967, 0.9898254322977855, 0.7643801775972503], 
             UndirectedEdge[92, 158] -> 
             RGBColor[
              0.9693770965866562, 0.9395827330977071, 0.6298869046708642], 
             UndirectedEdge[332, 334] -> 
             RGBColor[
              0.9538079807964412, 0.8454221787780853, 0.32933858619858714`], 
             UndirectedEdge[268, 300] -> 
             RGBColor[
              0.5730840069060956, 0.6032761943960463, 0.6303694769930809], 
             UndirectedEdge[224, 227] -> 
             RGBColor[
              0.8538759365145162, 0.3745141795747622, 0.1976349559532914], 
             UndirectedEdge[25, 91] -> 
             RGBColor[
              0.9671985160621952, 0.8944584349070621, 0.49053356347994936`], 
             UndirectedEdge[74, 304] -> 
             RGBColor[
              0.7928228816731733, 0.8361772113368218, 0.880210246779223], 
             UndirectedEdge[86, 397] -> 
             RGBColor[
              0.9904061721333295, 0.9891863302940576, 0.7276537276162358], 
             UndirectedEdge[32, 111] -> 
             RGBColor[
              0.9860743216370624, 0.9758226314355218, 0.6350623383564147], 
             UndirectedEdge[59, 394] -> 
             RGBColor[
              0.9718167512699065, 0.9766939510227897, 0.8516426557180123], 
             UndirectedEdge[170, 355] -> 
             RGBColor[
              0.9837516299895138, 0.9560238801406609, 0.46184472720238334`], 
             UndirectedEdge[9, 56] -> 
             RGBColor[
              0.960552158061119, 0.8693650795717491, 0.4107890276331532], 
             UndirectedEdge[44, 317] -> 
             RGBColor[
              0.9807802696705271, 0.9837804091673088, 0.8544488875223961], 
             UndirectedEdge[236, 262] -> 
             RGBColor[
              0.9429791526712149, 0.8572969036740591, 0.6062286018516121], 
             UndirectedEdge[119, 346] -> 
             RGBColor[
              0.9351049463371773, 0.8621552258246385, 0.627883154003295], 
             UndirectedEdge[80, 244] -> 
             RGBColor[
              0.9760597164530762, 0.9352415714578441, 0.5491599768323795], 
             UndirectedEdge[20, 360] -> 
             RGBColor[
              0.9529489950395945, 0.8512829169422901, 0.5532598117573901], 
             UndirectedEdge[196, 206] -> 
             RGBColor[
              0.9919581400087181, 0.9906834352997482, 0.7641068039494779], 
             UndirectedEdge[187, 302] -> 
             RGBColor[
              0.9309670192483919, 0.9154366714741347, 0.6665065667551009], 
             UndirectedEdge[147, 312] -> 
             RGBColor[
              0.8121019993816168, 0.756094809967806, 0.615345463483014], 
             UndirectedEdge[259, 400] -> 
             RGBColor[
              0.9813070630222309, 0.9843472365150305, 0.8613468089048077], 
             UndirectedEdge[120, 312] -> 
             RGBColor[
              0.8449793364548207, 0.8752573288868164, 0.720543284623228], 
             UndirectedEdge[52, 60] -> 
             RGBColor[
              0.9679608768929235, 0.9756042647418834, 0.9381512034628019], 
             UndirectedEdge[266, 384] -> 
             RGBColor[
              0.9906645575597666, 0.9805057491340695, 0.57823963197307], 
             UndirectedEdge[135, 393] -> 
             RGBColor[
              0.9542982135951709, 0.8577371065070081, 0.5597525889074914], 
             UndirectedEdge[77, 244] -> 
             RGBColor[
              0.9768966932765175, 0.9355876828836603, 0.5352891048413698], 
             UndirectedEdge[239, 385] -> 
             RGBColor[
              0.9558051543988743, 0.8519840364105571, 0.33800903712175134`], 
             UndirectedEdge[278, 296] -> 
             RGBColor[
              0.9487857466732386, 0.8211793260685871, 0.4651203160728186], 
             UndirectedEdge[267, 275] -> 
             RGBColor[
              0.9868949436971944, 0.9664983649335663, 0.48499541118925016`], 
             UndirectedEdge[148, 340] -> 
             RGBColor[
              0.980557644387926, 0.9444761735123286, 0.5152217306177246], 
             UndirectedEdge[202, 212] -> 
             RGBColor[
              0.8905001809404298, 0.9149040313545233, 0.9678993209677271], 
             UndirectedEdge[81, 346] -> 
             RGBColor[
              0.9637167999626639, 0.8811591116117292, 0.45787724147852665`], 
             UndirectedEdge[50, 217] -> 
             RGBColor[
              0.9844100175143954, 0.9874944655871531, 0.8934000283616563], 
             UndirectedEdge[5, 183] -> 
             RGBColor[
              0.9879869254272963, 0.9807764678149256, 0.6321395302235231], 
             UndirectedEdge[313, 339] -> 
             RGBColor[
              0.9928702533289315, 0.9901480776388585, 0.6826587039991909], 
             UndirectedEdge[4, 184] -> 
             RGBColor[
              0.9466903609713075, 0.9562042650591953, 0.7985234811991322], 
             UndirectedEdge[104, 349] -> 
             RGBColor[
              0.9768630597134369, 0.9345377911869623, 0.5286858216882272], 
             UndirectedEdge[119, 135] -> 
             RGBColor[
              0.9622152950399782, 0.9708611542880526, 0.9273638920576167], 
             UndirectedEdge[53, 273] -> 
             RGBColor[
              0.9917881909262736, 0.9894451019983109, 0.6820180330216686], 
             UndirectedEdge[224, 259] -> 
             RGBColor[
              0.90756942621287, 0.5863333422345709, 0.4794475060965919], 
             UndirectedEdge[110, 289] -> 
             RGBColor[
              0.9778137528029218, 0.9825536782065479, 0.9036117491181728], 
             UndirectedEdge[59, 155] -> 
             RGBColor[
              0.9264463701785572, 0.9408485221568379, 0.8588147930498213], 
             UndirectedEdge[5, 29] -> 
             RGBColor[
              0.987965402499442, 0.9710666181520586, 0.407748290563719], 
             UndirectedEdge[119, 311] -> 
             RGBColor[
              0.9404307492817798, 0.9550939308668229, 0.9857193827038092], 
             UndirectedEdge[68, 72] -> 
             RGBColor[
              0.963780060530723, 0.8827476849537764, 0.3787662698803219], 
             UndirectedEdge[121, 234] -> 
             RGBColor[
              0.9908211762606028, 0.9817424993596573, 0.5837447670575808], 
             UndirectedEdge[20, 336] -> 
             RGBColor[
              0.95370205634382, 0.9639961020987428, 0.9228428278874707], 
             UndirectedEdge[17, 256] -> 
             RGBColor[
              0.9702750704179893, 0.974941531333761, 0.8076399885956491], 
             UndirectedEdge[186, 272] -> 
             RGBColor[
              0.9936082216436938, 0.9903047240145781, 0.6596326422751644], 
             UndirectedEdge[45, 304] -> 
             RGBColor[
              0.7760048922352474, 0.7747915105124883, 0.6250072748644121], 
             UndirectedEdge[165, 252] -> 
             RGBColor[
              0.994586357059796, 0.9908290900911938, 0.652136558969383], 
             UndirectedEdge[106, 254] -> 
             RGBColor[
              0.9879793917688264, 0.9892971838279385, 0.8488761169348409], 
             UndirectedEdge[144, 169] -> 
             RGBColor[
              0.9525774598762369, 0.8495361395483569, 0.28151504271227823`], 
             UndirectedEdge[191, 355] -> 
             RGBColor[
              0.9945425462395104, 0.9907353831765562, 0.6473680215503377], 
             UndirectedEdge[96, 377] -> 
             RGBColor[
              0.9469409187969678, 0.815359774425314, 0.3485782756359296], 
             UndirectedEdge[110, 303] -> 
             RGBColor[
              0.9811176082150304, 0.982236267713267, 0.7264754884903989], 
             UndirectedEdge[177, 260] -> 
             RGBColor[
              0.8545521192711363, 0.6324190755163106, 0.5902812420978004], 
             UndirectedEdge[20, 88] -> 
             RGBColor[
              0.9471035884478467, 0.8281078276722857, 0.5485564604043424], 
             UndirectedEdge[57, 68] -> 
             RGBColor[
              0.9642914340648359, 0.8838414612354488, 0.4344261232368921], 
             UndirectedEdge[127, 264] -> 
             RGBColor[
              0.9550088617782919, 0.856586858719067, 0.540908633681801], 
             UndirectedEdge[171, 186] -> 
             RGBColor[
              0.993311381331121, 0.9896698126011445, 0.6273234061376827], 
             UndirectedEdge[362, 385] -> 
             RGBColor[
              0.9930488826227246, 0.9869138454712622, 0.5380855926720123], 
             UndirectedEdge[109, 370] -> 
             RGBColor[
              0.9838094596910911, 0.9631758522277815, 0.5916564920187192], 
             UndirectedEdge[123, 161] -> 
             RGBColor[
              0.9763737780097446, 0.9306070179554877, 0.4782195075620208], 
             UndirectedEdge[119, 213] -> 
             RGBColor[
              0.8677527238586855, 0.8975203150064066, 0.98572399118067], 
             UndirectedEdge[140, 360] -> 
             RGBColor[
              0.9553277428956128, 0.8522665903117852, 0.5138378037810507], 
             UndirectedEdge[320, 347] -> 
             RGBColor[
              0.8562415018418884, 0.8526232671535192, 0.6535621889118051], 
             UndirectedEdge[10, 345] -> 
             RGBColor[
              0.8557949715321251, 0.8880281405996704, 0.9860608596309719], 
             UndirectedEdge[169, 383] -> 
             RGBColor[
              0.9698242246197896, 0.9123571275755105, 0.538307192432075], 
             UndirectedEdge[154, 372] -> 
             RGBColor[
              0.8541188583129866, 0.88651520945273, 0.9859478132584404], 
             UndirectedEdge[167, 341] -> 
             RGBColor[
              0.9941070961609136, 0.9898039994891942, 0.5999719677814557], 
             UndirectedEdge[186, 308] -> 
             RGBColor[
              0.9924449166848195, 0.9871513121102147, 0.5895796028874472], 
             UndirectedEdge[145, 225] -> 
             RGBColor[
              0.9151706444221686, 0.6809129511050493, 0.27625162894331995`], 
             UndirectedEdge[12, 65] -> 
             RGBColor[
              0.9133402353151996, 0.9301490625504001, 0.8388963711093899], 
             UndirectedEdge[274, 288] -> 
             RGBColor[
              0.99085299818733, 0.9892422143550874, 0.7108797215332393], 
             UndirectedEdge[143, 171] -> 
             RGBColor[
              0.993130653041774, 0.9877154863908977, 0.4936921601715229], 
             UndirectedEdge[167, 168] -> 
             RGBColor[
              0.9934573451200865, 0.9884142477127725, 0.52925057678605], 
             UndirectedEdge[203, 341] -> 
             RGBColor[
              0.9937373998092928, 0.989013256375112, 0.5597328014089351], 
             UndirectedEdge[114, 299] -> 
             RGBColor[
              0.9674775059274373, 0.9526005587562387, 0.6637442069594481], 
             UndirectedEdge[154, 231] -> 
             RGBColor[
              0.9084569347051412, 0.9259749212246537, 0.815706141371694], 
             UndirectedEdge[218, 384] -> 
             RGBColor[
              0.9872976173313553, 0.9791134328232044, 0.6340385449198419], 
             UndirectedEdge[360, 380] -> 
             RGBColor[
              0.956306993405641, 0.8519256934596923, 0.4433942411900735], 
             UndirectedEdge[98, 306] -> 
             RGBColor[
              0.9899821830807327, 0.9819355143997952, 0.6013812406330403], 
             UndirectedEdge[57, 262] -> 
             RGBColor[
              0.9601617123513216, 0.8674684907895468, 0.4311032522091711], 
             UndirectedEdge[152, 160] -> 
             RGBColor[
              0.8910294703540391, 0.8402013500403742, 0.6281008196280143], 
             UndirectedEdge[311, 354] -> 
             RGBColor[
              0.963853705837439, 0.9725618387805371, 0.9460303589273276], 
             UndirectedEdge[287, 303] -> 
             RGBColor[
              0.9923457976987232, 0.9894191652800659, 0.6541306444347204], 
             UndirectedEdge[222, 247] -> 
             RGBColor[
              0.9856267911912449, 0.9876279353087676, 0.856679131878786], 
             UndirectedEdge[24, 206] -> 
             RGBColor[
              0.9932634375354568, 0.991223209371671, 0.7424746459297026], 
             UndirectedEdge[92, 308] -> 
             RGBColor[
              0.9815201753345969, 0.9805441890449889, 0.6770604725786071], 
             UndirectedEdge[18, 266] -> 
             RGBColor[
              0.99113013992862, 0.9820762677881512, 0.5800483315582128], 
             UndirectedEdge[28, 314] -> 
             RGBColor[
              0.9816448577498911, 0.9824504968943835, 0.7113806906723558], 
             UndirectedEdge[128, 139] -> 
             RGBColor[
              0.8884990702013921, 0.5823180219883679, 0.22845398959419036`], 
             UndirectedEdge[160, 181] -> 
             RGBColor[
              0.9467459942518123, 0.8265726435935271, 0.27600878082407687`], 
             UndirectedEdge[42, 296] -> 
             RGBColor[
              0.9487698752033134, 0.8211453785992688, 0.4633928045188163], 
             UndirectedEdge[121, 289] -> 
             RGBColor[
              0.9900705534892507, 0.9901619329397389, 0.814220155474356], 
             UndirectedEdge[22, 286] -> 
             RGBColor[
              0.9736526753373502, 0.9203637124099906, 0.47698690187326165`], 
             UndirectedEdge[128, 213] -> 
             RGBColor[
              0.8282456441515651, 0.6458274734761126, 0.5920066850082373], 
             UndirectedEdge[178, 398] -> 
             RGBColor[
              0.9846278931151221, 0.9594793028805744, 0.42276804261183665`], 
             UndirectedEdge[6, 129] -> 
             RGBColor[
              0.9869536433313045, 0.9663403544295652, 0.5154966621280479], 
             UndirectedEdge[265, 375] -> 
             RGBColor[
              0.9921785990890046, 0.9895427477397852, 0.6709105134481264], 
             UndirectedEdge[162, 270] -> 
             RGBColor[
              0.937223224489866, 0.9345907251526282, 0.6879426322440378], 
             UndirectedEdge[199, 271] -> 
             RGBColor[
              0.8927896982534493, 0.9155143597225082, 0.9128793251904861], 
             UndirectedEdge[60, 72] -> 
             RGBColor[
              0.9723547749940487, 0.9755472844749337, 0.7291151008967793], 
             UndirectedEdge[230, 258] -> 
             RGBColor[
              0.9911221561162948, 0.9897600675176985, 0.735970930766909], 
             UndirectedEdge[38, 135] -> 
             RGBColor[
              0.9802650440809539, 0.9555154641242977, 0.6075792260065], 
             UndirectedEdge[42, 67] -> 
             RGBColor[
              0.9874143891884939, 0.9677283498917832, 0.5314197440964771], 
             UndirectedEdge[220, 352] -> 
             RGBColor[
              0.9772148644849536, 0.9788216165111179, 0.6930922601696189], 
             UndirectedEdge[4, 226] -> 
             RGBColor[
              0.939207210020365, 0.9319905429071329, 0.6819793637713348], 
             UndirectedEdge[134, 163] -> 
             RGBColor[
              0.9614111553883924, 0.881885830453445, 0.545649076305122], 
             UndirectedEdge[25, 76] -> 
             RGBColor[
              0.9943748072234306, 0.9918088664672079, 0.7332208532908641], 
             UndirectedEdge[250, 375] -> 
             RGBColor[
              0.9925848860403134, 0.9904117544467228, 0.71513234078567], 
             UndirectedEdge[50, 138] -> 
             RGBColor[
              0.9257386460716606, 0.9419112995303285, 0.929401474969971], 
             UndirectedEdge[24, 157] -> 
             RGBColor[
              0.9781485182337171, 0.9417668127970842, 0.5536749823589344], 
             UndirectedEdge[127, 328] -> 
             RGBColor[
              0.94237761240681, 0.8068616428338649, 0.28495053007554494`], 
             UndirectedEdge[107, 245] -> 
             RGBColor[
              0.9850877609771823, 0.9633987756558493, 0.5683588343871344], 
             UndirectedEdge[16, 96] -> 
             RGBColor[
              0.9470718459085119, 0.8156398142781454, 0.3628288837390296], 
             UndirectedEdge[42, 278] -> 
             RGBColor[
              0.9949162269165175, 0.9915346483597626, 0.6880408571527429], 
             UndirectedEdge[51, 176] -> 
             RGBColor[
              0.9259284185130359, 0.7248099487248696, 0.4980124601825546], 
             UndirectedEdge[33, 386] -> 
             RGBColor[
              0.983065607685542, 0.953966151497724, 0.4373784730111964], 
             UndirectedEdge[78, 187] -> 
             RGBColor[
              0.9424364580173725, 0.9537293536617755, 0.8660184051537692], 
             UndirectedEdge[107, 150] -> 
             RGBColor[
              0.969922506238005, 0.9102036923887252, 0.3376550457030938], 
             UndirectedEdge[312, 360] -> 
             RGBColor[
              0.8076181385630634, 0.7383177959802854, 0.6117376438186655], 
             UndirectedEdge[78, 208] -> 
             RGBColor[
              0.9940695550619734, 0.9918156228597124, 0.7479463503300197], 
             UndirectedEdge[28, 197] -> 
             RGBColor[
              0.9910596083531567, 0.9811520646866561, 0.4497033273530854], 
             UndirectedEdge[221, 316] -> 
             RGBColor[
              0.9833295389955807, 0.9842418091743259, 0.750969386362484], 
             UndirectedEdge[243, 383] -> 
             RGBColor[
              0.9920916086028131, 0.9909976911679441, 0.7807260419196562], 
             UndirectedEdge[83, 332] -> 
             RGBColor[
              0.9731667832372811, 0.9683709177714039, 0.6785840320511999], 
             UndirectedEdge[98, 354] -> 
             RGBColor[
              0.9877864834056447, 0.989217411262244, 0.8520731077436021], 
             UndirectedEdge[46, 215] -> 
             RGBColor[
              0.989810854205908, 0.9772917600906352, 0.414917521959027], 
             UndirectedEdge[375, 381] -> 
             RGBColor[
              0.9927139052433611, 0.991255026821105, 0.7704129761336926], 
             UndirectedEdge[286, 304] -> 
             RGBColor[
              0.7947245163082786, 0.836531327284072, 0.8172745847897065], 
             UndirectedEdge[225, 235] -> 
             RGBColor[
              0.9827108836055936, 0.9533418921034003, 0.3873354768937495], 
             UndirectedEdge[96, 225] -> 
             RGBColor[
              0.9370992877691096, 0.7823465484811678, 0.294622288756216], 
             UndirectedEdge[20, 389] -> 
             RGBColor[
              0.8494284854415972, 0.8817308071404735, 0.9126636974936719], 
             UndirectedEdge[259, 393] -> 
             RGBColor[
              0.9565630013921211, 0.8586736544634386, 0.5222191940290878], 
             UndirectedEdge[97, 166] -> 
             RGBColor[
              0.7881558739308486, 0.8305856117830982, 0.7665164541960925], 
             UndirectedEdge[115, 334] -> 
             RGBColor[
              0.9317424906519894, 0.8401032659763732, 0.6184114895026347], 
             UndirectedEdge[251, 260] -> 
             RGBColor[
              0.5878472708928686, 0.4154896629704392, 0.5680313223301863], 
             UndirectedEdge[119, 344] -> 
             RGBColor[
              0.8673684214171185, 0.8972200950182476, 0.985685687504805], 
             UndirectedEdge[329, 341] -> 
             RGBColor[
              0.9530949052773066, 0.9616286827234337, 0.8248806765931562], 
             UndirectedEdge[283, 334] -> 
             RGBColor[
              0.9574984811614772, 0.8567731039929176, 0.43704140004201897`], 
             UndirectedEdge[1, 5] -> 
             RGBColor[
              0.9907246303182609, 0.9800142436561505, 0.4490704829445508], 
             UndirectedEdge[364, 391] -> 
             RGBColor[
              0.769249765871636, 0.7676465734982394, 0.6220075956665275], 
             UndirectedEdge[48, 295] -> 
             RGBColor[
              0.8505442704749122, 0.8821922129261168, 0.894172251932537], 
             UndirectedEdge[105, 199] -> 
             RGBColor[
              0.8946185686603005, 0.9162706446355667, 0.8825702095840677], 
             UndirectedEdge[281, 293] -> 
             RGBColor[
              0.9004205105154177, 0.8829877190828935, 0.65168862838312], 
             UndirectedEdge[216, 358] -> 
             RGBColor[
              0.9409892525725712, 0.9531143170618859, 0.889282385646273], 
             UndirectedEdge[100, 206] -> 
             RGBColor[
              0.9944115574252161, 0.9904552113477816, 0.6331106974836702], 
             UndirectedEdge[168, 341] -> 
             RGBColor[
              0.9939935636038997, 0.9895611648296437, 0.587614649592217], 
             UndirectedEdge[199, 259] -> 
             RGBColor[
              0.8944970318249787, 0.916220386030807, 0.8845843894725959], 
             UndirectedEdge[19, 24] -> 
             RGBColor[
              0.9932318242522566, 0.9911555917554989, 0.7390337351479309], 
             UndirectedEdge[136, 299] -> 
             RGBColor[
              0.898765445332042, 0.898360982986489, 0.6760801732884527], 
             UndirectedEdge[64, 123] -> 
             RGBColor[
              0.994431883560511, 0.9904986868958896, 0.6353230718721404], 
             UndirectedEdge[101, 334] -> 
             RGBColor[
              0.9383656151287866, 0.7933314533412003, 0.2693479116258107], 
             UndirectedEdge[2, 328] -> 
             RGBColor[
              0.9600221704527905, 0.8768075350758084, 0.299194110699071], 
             UndirectedEdge[235, 349] -> 
             RGBColor[
              0.9929012152588967, 0.9886382557797999, 0.5909910274307988], 
             UndirectedEdge[45, 290] -> 
             RGBColor[
              0.9752737462271366, 0.9278209346009239, 0.3953262997486514], 
             UndirectedEdge[225, 327] -> 
             RGBColor[
              0.9632763225441376, 0.942889293015021, 0.6568918017079302], 
             UndirectedEdge[24, 386] -> 
             RGBColor[
              0.9924877433821914, 0.9895640780125454, 0.6580451243761714], 
             UndirectedEdge[363, 393] -> 
             RGBColor[
              0.9499828363606369, 0.854998360367589, 0.5885373339319754], 
             UndirectedEdge[2, 258] -> 
             RGBColor[
              0.9719626615713637, 0.9262471046717554, 0.5665998661810787], 
             UndirectedEdge[8, 234] -> 
             RGBColor[
              0.9786634317795485, 0.9396888867072686, 0.37161189084670754`], 
             UndirectedEdge[44, 151] -> 
             RGBColor[
              0.9932502130122552, 0.9902368875689651, 0.6713961429087949], 
             UndirectedEdge[253, 283] -> 
             RGBColor[
              0.980149053819312, 0.9436022396009067, 0.47074916875278994`], 
             UndirectedEdge[257, 360] -> 
             RGBColor[
              0.9289454051516228, 0.8339641253646659, 0.620001639946606], 
             UndirectedEdge[65, 358] -> 
             RGBColor[
              0.9932768513790318, 0.9912193636386584, 0.7415695935430546], 
             UndirectedEdge[282, 340] -> 
             RGBColor[
              0.9949803717236729, 0.991671847616233, 0.6950226235557391], 
             UndirectedEdge[256, 316] -> 
             RGBColor[
              0.9836423114359332, 0.9849107977980952, 0.7850127362870905], 
             UndirectedEdge[96, 182] -> 
             RGBColor[
              0.947770575448459, 0.8171343261116989, 0.4388812821033966], 
             UndirectedEdge[2, 106] -> 
             RGBColor[
              0.9730991256215791, 0.9267170617623135, 0.5477657157943252], 
             UndirectedEdge[210, 279] -> 
             RGBColor[
              0.95868168279455, 0.8630871468264543, 0.34195042551289856`], 
             UndirectedEdge[279, 371] -> 
             RGBColor[
              0.9752212599147863, 0.9772632824412513, 0.6907931344662936], 
             UndirectedEdge[271, 353] -> 
             RGBColor[
              0.9785494331223614, 0.982857900924758, 0.8914196223454234], 
             UndirectedEdge[306, 311] -> 
             RGBColor[
              0.966049405512527, 0.9652799419180882, 0.6953384918167658], 
             UndirectedEdge[64, 312] -> 
             RGBColor[
              0.8455997967789806, 0.8765844307820327, 0.7880765618707672], 
             UndirectedEdge[137, 210] -> 
             RGBColor[
              0.9587371748470076, 0.8655064960656733, 0.5152238953456597], 
             UndirectedEdge[264, 394] -> 
             RGBColor[
              0.9689374848984074, 0.9755033003844041, 0.899359550796266], 
             UndirectedEdge[199, 224] -> 
             RGBColor[
              0.81045776479306, 0.5117557350083354, 0.5753026964221838], 
             UndirectedEdge[61, 301] -> 
             RGBColor[
              0.9588792107827798, 0.8635127042707808, 0.36326875468129693`], 
             UndirectedEdge[48, 103] -> 
             RGBColor[
              0.7980335995988515, 0.672285992386741, 0.5987624066636308], 
             UndirectedEdge[7, 14] -> 
             RGBColor[
              0.9701049485247152, 0.9096551725012445, 0.3444256217556809], 
             UndirectedEdge[88, 195] -> 
             RGBColor[
              0.9363570185956438, 0.7823541163012895, 0.28342830008138536`], 
             UndirectedEdge[211, 341] -> 
             RGBColor[
              0.9869234125055493, 0.9662308076015855, 0.5160230173794274], 
             UndirectedEdge[84, 185] -> 
             RGBColor[
              0.9635204885484776, 0.887013050492877, 0.3210918954868183], 
             UndirectedEdge[368, 387] -> 
             RGBColor[
              0.9937555430129766, 0.9889034545014674, 0.5743441587158], 
             UndirectedEdge[134, 171] -> 
             RGBColor[
              0.9633096687178644, 0.8808386285680645, 0.3809979522374919], 
             UndirectedEdge[41, 295] -> 
             RGBColor[
              0.989607399073952, 0.9899704066864874, 0.8218958227410602], 
             UndirectedEdge[77, 388] -> 
             RGBColor[
              0.9899377101734474, 0.9795780950533861, 0.5859509928965446], 
             UndirectedEdge[142, 273] -> 
             RGBColor[
              0.9576999513590709, 0.8661287994801712, 0.5375574395094989], 
             UndirectedEdge[64, 140] -> 
             RGBColor[
              0.99330940111153, 0.9905332251135326, 0.6901767218331525], 
             UndirectedEdge[150, 157] -> 
             RGBColor[
              0.9635832320249671, 0.8888198319357797, 0.31302816245692666`], 
             UndirectedEdge[210, 264] -> 
             RGBColor[
              0.9570864711810331, 0.8648238876786436, 0.5425803269750069], 
             UndirectedEdge[202, 309] -> 
             RGBColor[
              0.9769630743584157, 0.9797148409971347, 0.7792919275734116], 
             UndirectedEdge[105, 287] -> 
             RGBColor[
              0.9916064930129056, 0.9907970834046154, 0.7887656626833266], 
             UndirectedEdge[157, 160] -> 
             RGBColor[
              0.9529563509595552, 0.8485956311546473, 0.29454145383363217`], 
             UndirectedEdge[153, 379] -> 
             RGBColor[
              0.9923793768267324, 0.9896945156164898, 0.6725798606682756], 
             UndirectedEdge[207, 387] -> 
             RGBColor[
              0.994176704145847, 0.9899528839305198, 0.6075483673707694], 
             UndirectedEdge[93, 264] -> 
             RGBColor[
              0.6583010383794008, 0.723875705442675, 0.8844190007627067], 
             UndirectedEdge[202, 365] -> 
             RGBColor[
              0.9364298187657114, 0.8313309771748851, 0.6009588540586188], 
             UndirectedEdge[138, 230] -> 
             RGBColor[
              0.929597473203426, 0.9426702935833695, 0.804629275355156], 
             UndirectedEdge[5, 291] -> 
             RGBColor[
              0.9894769108280002, 0.9761652906633183, 0.4136202149957705], 
             UndirectedEdge[241, 360] -> 
             RGBColor[
              0.9565315922547819, 0.8524060876875779, 0.4678404398556414], 
             UndirectedEdge[299, 300] -> 
             RGBColor[
              0.9726837706895379, 0.919518085759471, 0.3483820366762617], 
             UndirectedEdge[9, 266] -> 
             RGBColor[
              0.9938238964263917, 0.9903929439716905, 0.655988054426226], 
             UndirectedEdge[226, 322] -> 
             RGBColor[
              0.9808530650228577, 0.9470750337872849, 0.3801182025194217], 
             UndirectedEdge[175, 216] -> 
             RGBColor[
              0.9420065482705946, 0.9520990359082999, 0.7680440977622398], 
             UndirectedEdge[115, 257] -> 
             RGBColor[
              0.9412321889273053, 0.955691643242219, 0.9843627544328709], 
             UndirectedEdge[146, 275] -> 
             RGBColor[
              0.9934918649537616, 0.988488082146513, 0.5330078476498631], 
             UndirectedEdge[64, 101] -> 
             RGBColor[
              0.9750881107096621, 0.9266059278860821, 0.44467367786541223`], 
             UndirectedEdge[79, 390] -> 
             RGBColor[
              0.9761523850203326, 0.934704626254061, 0.5436480014398324], 
             UndirectedEdge[98, 378] -> 
             RGBColor[
              0.9920634863650566, 0.9888029398400793, 0.6225021726347032], 
             UndirectedEdge[37, 80] -> 
             RGBColor[
              0.989213766274969, 0.9898076294082063, 0.8284193369092363], 
             UndirectedEdge[344, 354] -> 
             RGBColor[
              0.8907913779727777, 0.9146880029319617, 0.9459966637283235], 
             UndirectedEdge[119, 227] -> 
             RGBColor[
              0.9107865931385746, 0.7599785395846744, 0.6080179470359126], 
             UndirectedEdge[81, 166] -> 
             RGBColor[
              0.7885149166671754, 0.8313535678913122, 0.805596040290351], 
             UndirectedEdge[192, 221] -> 
             RGBColor[
              0.9915598108481152, 0.9895349103466868, 0.6991958668211967], 
             UndirectedEdge[242, 331] -> 
             RGBColor[
              0.9934948582158764, 0.988494484431511, 0.5333336457587731], 
             UndirectedEdge[225, 322] -> 
             RGBColor[
              0.9778109811741036, 0.936813370650182, 0.36830028121634284`], 
             UndirectedEdge[165, 170] -> 
             RGBColor[
              0.9844532174481089, 0.9575245047732226, 0.5382081923745483], 
             UndirectedEdge[41, 250] -> 
             RGBColor[
              0.9918240657509996, 0.990097135704902, 0.7277411019193928], 
             UndirectedEdge[31, 393] -> 
             RGBColor[
              0.9574992379644082, 0.8575072573344444, 0.3937762819250493], 
             UndirectedEdge[140, 312] -> 
             RGBColor[
              0.844749337217411, 0.8772007984501159, 0.8725382243958468], 
             UndirectedEdge[56, 100] -> 
             RGBColor[
              0.9605975497630885, 0.8694621678324568, 0.41572963426742], 
             UndirectedEdge[89, 183] -> 
             RGBColor[
              0.9895779537372782, 0.9899582302830621, 0.8223838081718354], 
             UndirectedEdge[39, 210] -> 
             RGBColor[
              0.9430216853307893, 0.8551853006503092, 0.6044937049918158], 
             UndirectedEdge[34, 321] -> 
             RGBColor[
              0.9774453444801756, 0.9821886086660077, 0.9001910475141133], 
             UndirectedEdge[148, 301] -> 
             RGBColor[
              0.9794559386426875, 0.9421197363228011, 0.39530785918826195`], 
             UndirectedEdge[136, 155] -> 
             RGBColor[
              0.8386124149547791, 0.8741554774193859, 0.9844675515960595], 
             UndirectedEdge[51, 205] -> 
             RGBColor[
              0.9143388686887668, 0.9318832814842946, 0.8875766591358112], 
             UndirectedEdge[11, 123] -> 
             RGBColor[
              0.941665591496496, 0.789122407772735, 0.4468556464006007], 
             UndirectedEdge[223, 400] -> 
             RGBColor[
              0.9796632468775961, 0.9836674762950759, 0.8885890964812235], 
             UndirectedEdge[6, 201] -> 
             RGBColor[
              0.9769313340426824, 0.9611616059263408, 0.6509476302547241], 
             UndirectedEdge[201, 273] -> 
             RGBColor[
              0.9822675411074606, 0.9853393523754558, 0.8720715385537074], 
             UndirectedEdge[54, 196] -> 
             RGBColor[
              0.9782304268057843, 0.9824969539349564, 0.8864499655760981], 
             UndirectedEdge[84, 288] -> 
             RGBColor[
              0.9692170148037398, 0.9154894937838608, 0.5649269236388816], 
             UndirectedEdge[177, 248] -> 
             RGBColor[
              0.8986990914926021, 0.8392527421619869, 0.6272504998687101], 
             UndirectedEdge[76, 117] -> 
             RGBColor[
              0.9943280674420754, 0.991708894801006, 0.7281335165348471], 
             UndirectedEdge[342, 348] -> 
             RGBColor[
              0.9304079415202728, 0.7506153938216911, 0.5247993219135041], 
             UndirectedEdge[332, 389] -> 
             RGBColor[
              0.8490283085634023, 0.8708779087194033, 0.6877293201223689], 
             UndirectedEdge[68, 236] -> 
             RGBColor[
              0.9471088743847291, 0.8736698741199611, 0.6095514728793331], 
             UndirectedEdge[84, 318] -> 
             RGBColor[
              0.9653049021937097, 0.8930322967184932, 0.32802400554030314`], 
             UndirectedEdge[15, 372] -> 
             RGBColor[
              0.9375775258254333, 0.95083620033804, 0.9081632335852483], 
             UndirectedEdge[88, 189] -> 
             RGBColor[
              0.9329882488103252, 0.8181636769409235, 0.5985600601882533], 
             UndirectedEdge[364, 380] -> 
             RGBColor[
              0.7884360481121631, 0.8311848760269747, 0.7970116847975468], 
             UndirectedEdge[103, 295] -> 
             RGBColor[
              0.9374223450284931, 0.7801988370745363, 0.5210896639197344], 
             UndirectedEdge[20, 257] -> 
             RGBColor[
              0.963697855949952, 0.9718634544650013, 0.9202242285001265], 
             UndirectedEdge[12, 24] -> 
             RGBColor[
              0.9116274148521764, 0.9297092231480641, 0.8867961470836283], 
             UndirectedEdge[152, 157] -> 
             RGBColor[
              0.902824982656428, 0.8843676183914932, 0.6511274399294731], 
             UndirectedEdge[26, 70] -> 
             RGBColor[
              0.905616921873382, 0.5617598955075144, 0.37163223947281715`], 
             UndirectedEdge[33, 74] -> 
             RGBColor[
              0.9818392856334802, 0.9550564608810284, 0.5738177421188372], 
             UndirectedEdge[124, 238] -> 
             RGBColor[
              0.9290035336092695, 0.756229699470367, 0.2617327805220092], 
             UndirectedEdge[148, 339] -> 
             RGBColor[
              0.9789163040609109, 0.9439550724210877, 0.553881410770293], 
             UndirectedEdge[175, 229] -> 
             RGBColor[
              0.9635238338351075, 0.9692563353462853, 0.7700964356680907], 
             UndirectedEdge[105, 337] -> 
             RGBColor[
              0.9929181440044603, 0.9902201671403872, 0.6856656337539069], 
             UndirectedEdge[158, 306] -> 
             RGBColor[
              0.9778638840501281, 0.9369918244731988, 0.3685057988998284], 
             UndirectedEdge[136, 268] -> 
             RGBColor[
              0.49916568154859964`, 0.5821190916230642, 0.9580676136052718], 
             UndirectedEdge[133, 278] -> 
             RGBColor[
              0.9898165452679419, 0.9897550385816882, 0.7964880257805242], 
             UndirectedEdge[197, 254] -> 
             RGBColor[
              0.9873997208794255, 0.9815439315177001, 0.6488541013508996], 
             UndirectedEdge[296, 398] -> 
             RGBColor[
              0.9478378286511524, 0.8191518252685586, 0.3619452892406731], 
             UndirectedEdge[10, 271] -> 
             RGBColor[
              0.8931740006950164, 0.9158145797106672, 0.912917628866351], 
             UndirectedEdge[221, 399] -> 
             RGBColor[
              0.9701641030939208, 0.9073904630547085, 0.4234212416237395], 
             UndirectedEdge[187, 388] -> 
             RGBColor[
              0.9387451048204566, 0.9416739804900501, 0.6967229604343607], 
             UndirectedEdge[143, 186] -> 
             RGBColor[
              0.9932839643747169, 0.9896111705036754, 0.6243392396309273], 
             UndirectedEdge[372, 387] -> 
             RGBColor[
              0.9405628055747557, 0.9520421152922416, 0.8566123259728016], 
             UndirectedEdge[147, 255] -> 
             RGBColor[
              0.9251867605920043, 0.7410974663211218, 0.25866171536114035`], 
             UndirectedEdge[27, 86] -> 
             RGBColor[
              0.9933814797712197, 0.9882519794027094, 0.5209931017485425], 
             UndirectedEdge[19, 157] -> 
             RGBColor[
              0.9798351692804836, 0.9421506784641812, 0.5029268269240875], 
             UndirectedEdge[192, 208] -> 
             RGBColor[
              0.9915132581185429, 0.990758528379769, 0.7903108061670883], 
             UndirectedEdge[88, 89] -> 
             RGBColor[
              0.9490254521316298, 0.828902567695174, 0.5167062055402759], 
             UndirectedEdge[54, 332] -> 
             RGBColor[
              0.9772136837705452, 0.9713890895629208, 0.671733685049086], 
             UndirectedEdge[282, 301] -> 
             RGBColor[
              0.9938786659784344, 0.9893154104267055, 0.5751087521262764], 
             UndirectedEdge[264, 328] -> 
             RGBColor[
              0.9766824914302753, 0.9401237555590594, 0.5708043966683185], 
             UndirectedEdge[124, 156] -> 
             RGBColor[
              0.9620862032125206, 0.89028109446458, 0.5741773128500824], 
             UndirectedEdge[64, 120] -> 
             RGBColor[
              0.9935394003489397, 0.988589755550233, 0.5381817820605338], 
             UndirectedEdge[55, 236] -> 
             RGBColor[
              0.9643032424222504, 0.9728979971633661, 0.9453094787603807], 
             UndirectedEdge[11, 196] -> 
             RGBColor[
              0.938780927348541, 0.7884282385718482, 0.5309132074936611], 
             UndirectedEdge[223, 319] -> 
             RGBColor[
              0.9743932629736409, 0.9338706722317017, 0.5720650002868325], 
             UndirectedEdge[61, 70] -> 
             RGBColor[
              0.8710907795536014, 0.43696955773381163`, 0.21130942761824095`],
              UndirectedEdge[307, 343] -> 
             RGBColor[
              0.9299613735001575, 0.9437915292194613, 0.8652397112219375], 
             UndirectedEdge[13, 87] -> 
             RGBColor[
              0.9947390270902103, 0.9916782651976254, 0.7067433861031565], 
             UndirectedEdge[119, 128] -> 
             RGBColor[
              0.8978443927219477, 0.7011045697016297, 0.5972144890389897], 
             UndirectedEdge[92, 130] -> 
             RGBColor[
              0.9393172344623275, 0.9535239017849164, 0.9619628628382018], 
             UndirectedEdge[263, 359] -> 
             RGBColor[
              0.9834005516331505, 0.9541274279795928, 0.5210397070965462], 
             UndirectedEdge[22, 304] -> 
             RGBColor[
              0.7735962529206488, 0.7656497590962644, 0.6209459142571547], 
             UndirectedEdge[139, 306] -> 
             RGBColor[
              0.9536248061392598, 0.8441968745699271, 0.3317904048795796], 
             UndirectedEdge[1, 73] -> 
             RGBColor[
              0.9928400728448135, 0.9870939647317637, 0.4620642989854783], 
             UndirectedEdge[7, 13] -> 
             RGBColor[
              0.9914295446889783, 0.9819333929876279, 0.5732430936401766], 
             UndirectedEdge[170, 335] -> 
             RGBColor[
              0.9844117817641961, 0.9574358780351234, 0.5336981738920459], 
             UndirectedEdge[276, 361] -> 
             RGBColor[
              0.9892930091241141, 0.9745365575276361, 0.4986519564852087], 
             UndirectedEdge[46, 345] -> 
             RGBColor[
              0.9525968334843264, 0.958835993895248, 0.7070430896069677], 
             UndirectedEdge[36, 301] -> 
             RGBColor[
              0.9894308236178098, 0.9878388993317628, 0.6751917249795087], 
             UndirectedEdge[50, 328] -> 
             RGBColor[
              0.9753228378659562, 0.9395615038687106, 0.5933373748997163], 
             UndirectedEdge[55, 83] -> 
             RGBColor[
              0.9641357902422727, 0.9727731116017164, 0.94559293162256], 
             UndirectedEdge[143, 306] -> 
             RGBColor[
              0.9908460104879662, 0.9804131388139414, 0.4504390035510515], 
             UndirectedEdge[32, 400] -> 
             RGBColor[
              0.9788020117384839, 0.9833113334323196, 0.902861991541406], 
             UndirectedEdge[20, 195] -> 
             RGBColor[
              0.9769548759857207, 0.9434285346716293, 0.5883542399879538], 
             UndirectedEdge[203, 266] -> 
             RGBColor[
              0.9933643241227863, 0.9894099652841657, 0.6059664453302601], 
             UndirectedEdge[255, 359] -> 
             RGBColor[
              0.9591044720372045, 0.8624852408238475, 0.4770978664467574], 
             UndirectedEdge[128, 215] -> 
             RGBColor[
              0.9231006611169688, 0.7100681614902806, 0.30542578984135094`], 
             UndirectedEdge[230, 328] -> 
             RGBColor[
              0.9791816649977215, 0.9403204979217517, 0.46856517528490127`], 
             UndirectedEdge[44, 146] -> 
             RGBColor[
              0.992792619917537, 0.9892581422091213, 0.6215899584859379], 
             UndirectedEdge[56, 206] -> 
             RGBColor[
              0.9611676942032961, 0.8706816491396152, 0.4777863380603772], 
             UndirectedEdge[55, 196] -> 
             RGBColor[
              0.9788868421217648, 0.9829865074028332, 0.8853388256666765], 
             UndirectedEdge[93, 188] -> 
             RGBColor[
              0.6606015898519041, 0.7236476152280586, 0.7605609900982366], 
             UndirectedEdge[52, 271] -> 
             RGBColor[
              0.9862579904722254, 0.9885853401537985, 0.8774041912632722], 
             UndirectedEdge[193, 253] -> 
             RGBColor[
              0.9804177682278183, 0.9441769925495075, 0.49999707380560154`], 
             UndirectedEdge[120, 193] -> 
             RGBColor[
              0.9938692308266992, 0.9892952295911839, 0.5740817940868929], 
             UndirectedEdge[28, 217] -> 
             RGBColor[
              0.9876495037222079, 0.9869287520288321, 0.7012163913037126], 
             UndirectedEdge[124, 245] -> 
             RGBColor[
              0.9653886836339961, 0.8916467549887357, 0.5194466657208683], 
             UndirectedEdge[36, 282] -> 
             RGBColor[
              0.9904136271378872, 0.9899410166845302, 0.7821638229796732], 
             UndirectedEdge[276, 339] -> 
             RGBColor[
              0.9929767456517278, 0.9903758539492944, 0.694249736141132], 
             UndirectedEdge[377, 388] -> 
             RGBColor[
              0.9899054047596086, 0.9774257948721179, 0.4310079417783367], 
             UndirectedEdge[129, 131] -> 
             RGBColor[
              0.991519647691726, 0.990199602267122, 0.7493848224589299], 
             UndirectedEdge[69, 142] -> 
             RGBColor[
              0.9545056621791876, 0.8647028931734835, 0.5857936062590903], 
             UndirectedEdge[11, 118] -> 
             RGBColor[
              0.9396463844770443, 0.788786127335718, 0.5165703431431099], 
             UndirectedEdge[53, 293] -> 
             RGBColor[
              0.914649828699956, 0.9302924043526603, 0.7659920223310461], 
             UndirectedEdge[2, 137] -> 
             RGBColor[
              0.974304123490247, 0.9272153593480402, 0.5277957826759796], 
             UndirectedEdge[102, 213] -> 
             RGBColor[
              0.8866476697686766, 0.9116121347284436, 0.9537397763462089], 
             UndirectedEdge[269, 362] -> 
             RGBColor[
              0.7437381965206276, 0.7950250983354865, 0.8039798175549759], 
             UndirectedEdge[147, 242] -> 
             RGBColor[
              0.959848088775265, 0.867686227480162, 0.344387859812412], 
             UndirectedEdge[58, 220] -> 
             RGBColor[
              0.9760207428703915, 0.9806356559757139, 0.8806375100882531], 
             UndirectedEdge[177, 285] -> 
             RGBColor[
              0.9031916176747468, 0.9253869790538949, 0.9817001522711226], 
             UndirectedEdge[213, 215] -> 
             RGBColor[
              0.8930089922537067, 0.9064839067950576, 0.6939352919830313], 
             UndirectedEdge[61, 382] -> 
             RGBColor[
              0.9582394137093277, 0.8653066206047009, 0.5235022579626087], 
             UndirectedEdge[83, 123] -> 
             RGBColor[
              0.9770681904204752, 0.9801729513443264, 0.8092427514851516], 
             UndirectedEdge[207, 368] -> 
             RGBColor[
              0.9926833703585707, 0.9866101856069769, 0.45764478196633707`], 
             UndirectedEdge[117, 377] -> 
             RGBColor[
              0.9939184859189147, 0.9894005812529794, 0.5794429069073749], 
             UndirectedEdge[207, 392] -> 
             RGBColor[
              0.951672134738761, 0.8347485587623416, 0.3687419903710037], 
             UndirectedEdge[43, 325] -> 
             RGBColor[
              0.9914213031909032, 0.9907205026540561, 0.7918347372898027], 
             UndirectedEdge[83, 196] -> 
             RGBColor[
              0.9741835262725203, 0.9794787821434396, 0.893300312578212], 
             UndirectedEdge[81, 130] -> 
             RGBColor[
              0.9507972193205387, 0.9597508678962337, 0.8209567354294411], 
             UndirectedEdge[204, 229] -> 
             RGBColor[
              0.9535481796117142, 0.9362939326214935, 0.6728555386304695], 
             UndirectedEdge[44, 267] -> 
             RGBColor[
              0.9861956986609697, 0.9672684249961747, 0.573577522025325], 
             UndirectedEdge[38, 130] -> 
             RGBColor[
              0.9402351147360279, 0.925401291945388, 0.6711779819030929], 
             UndirectedEdge[226, 318] -> 
             RGBColor[
              0.9796222266520189, 0.9429231269478531, 0.3753366278730362], 
             UndirectedEdge[202, 362] -> 
             RGBColor[
              0.9771888286382335, 0.9801977065744061, 0.8038638877376665], 
             UndirectedEdge[59, 230] -> 
             RGBColor[
              0.9946921807407026, 0.9912363644453392, 0.6768063838129037], 
             UndirectedEdge[131, 394] -> 
             RGBColor[
              0.9684847386543053, 0.9753160781774202, 0.9068627277307585], 
             UndirectedEdge[93, 142] -> 
             RGBColor[
              0.6263697924764595, 0.6000242570740104, 0.6004750150950371], 
             UndirectedEdge[301, 340] -> 
             RGBColor[
              0.9939975682035955, 0.9895697302634658, 0.5880505255555746], 
             UndirectedEdge[16, 76] -> 
             RGBColor[
              0.9933431133592847, 0.9896021776120503, 0.6209273430550739], 
             UndirectedEdge[25, 239] -> 
             RGBColor[
              0.9576253343758714, 0.856503959594475, 0.48283075678367815`], 
             UndirectedEdge[46, 60] -> 
             RGBColor[
              0.9716787490679157, 0.9736413575943297, 0.6946468710418765], 
             UndirectedEdge[57, 297] -> 
             RGBColor[
              0.9851302074090311, 0.9857875757894052, 0.7640151015468752], 
             UndirectedEdge[221, 351] -> 
             RGBColor[
              0.9900734759205401, 0.9773516862030456, 0.4861713149492929], 
             UndirectedEdge[365, 377] -> 
             RGBColor[
              0.9529474317515094, 0.8400803105476702, 0.3534581603160012], 
             UndirectedEdge[334, 366] -> 
             RGBColor[
              0.9530150503053129, 0.8427474380425761, 0.32625820097291186`], 
             UndirectedEdge[209, 290] -> 
             RGBColor[
              0.974138448135875, 0.9237275568194214, 0.39228949937885077`], 
             UndirectedEdge[174, 313] -> 
             RGBColor[
              0.9944060362243519, 0.9904434020574119, 0.6325097488424922], 
             UndirectedEdge[56, 358] -> 
             RGBColor[
              0.9594682875838478, 0.8702379640042666, 0.5247810616479677], 
             UndirectedEdge[304, 338] -> 
             RGBColor[
              0.7911719260232186, 0.8354944987479407, 0.9075708544352349], 
             UndirectedEdge[130, 306] -> 
             RGBColor[
              0.9478040219257994, 0.9509329931604081, 0.700581757067166], 
             UndirectedEdge[11, 206] -> 
             RGBColor[
              0.9418044892052466, 0.78941949592704, 0.46197380482081046`], 
             UndirectedEdge[120, 140] -> 
             RGBColor[
              0.99268894078737, 0.9892061232183162, 0.6226434445856134], 
             UndirectedEdge[193, 356] -> 
             RGBColor[
              0.9868305949430007, 0.9658089628631352, 0.5249096946333754], 
             UndirectedEdge[166, 246] -> 
             RGBColor[
              0.7868010241729989, 0.8268510889801604, 0.6901909198903033], 
             UndirectedEdge[76, 182] -> 
             RGBColor[
              0.9940418428992318, 0.9910966894456038, 0.696979741419441], 
             UndirectedEdge[6, 364] -> 
             RGBColor[
              0.7808654466235099, 0.8068289921658498, 0.6671323219503058], 
             UndirectedEdge[288, 318] -> 
             RGBColor[
              0.9839530555476964, 0.9667927523639681, 0.6138661796734186], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.9804387421627649, 0.9442218536755683, 0.5022799571884264], 
             UndirectedEdge[128, 151] -> 
             RGBColor[
              0.9260910199206382, 0.7193272730918598, 0.38745593387370836`], 
             UndirectedEdge[30, 379] -> 
             RGBColor[
              0.992331176426499, 0.9895914198341991, 0.6673335445612819], 
             UndirectedEdge[70, 90] -> 
             RGBColor[
              0.9054919702214901, 0.5614926365586674, 0.3580320232765881], 
             UndirectedEdge[137, 394] -> 
             RGBColor[
              0.9705881885643819, 0.9761859087714337, 0.8720031191669186], 
             UndirectedEdge[25, 269] -> 
             RGBColor[
              0.7439969805968658, 0.7955786113074765, 0.832146867223319], 
             UndirectedEdge[38, 227] -> 
             RGBColor[
              0.9288363421795505, 0.7446328494209195, 0.28823328098479606`], 
             UndirectedEdge[128, 135] -> 
             RGBColor[
              0.9227082153328576, 0.7191683127577586, 0.533646585885184], 
             UndirectedEdge[129, 303] -> 
             RGBColor[
              0.9939807116784831, 0.9895336758607067, 0.5862157968235178], 
             UndirectedEdge[132, 299] -> 
             RGBColor[
              0.9859139930906939, 0.9634070822602594, 0.4626734717628931], 
             UndirectedEdge[352, 396] -> 
             RGBColor[
              0.9938174698715674, 0.9891845181419924, 0.5684479335523924], 
             UndirectedEdge[155, 268] -> 
             RGBColor[
              0.5183737334061795, 0.5974303857963217, 0.9599009379907877], 
             UndirectedEdge[8, 16] -> 
             RGBColor[
              0.9810837057506051, 0.9475065246437653, 0.410479287964692], 
             UndirectedEdge[213, 378] -> 
             RGBColor[
              0.8954526833737567, 0.914573751497956, 0.7164640322952895], 
             UndirectedEdge[164, 230] -> 
             RGBColor[
              0.9934081259827204, 0.9883089729547645, 0.5238933774290488], 
             UndirectedEdge[218, 339] -> 
             RGBColor[
              0.9894899380548474, 0.989921833536477, 0.8238424558069951], 
             UndirectedEdge[101, 366] -> 
             RGBColor[
              0.9706657959227509, 0.9127109830280906, 0.34054258576985263`], 
             UndirectedEdge[169, 361] -> 
             RGBColor[
              0.9665562089066086, 0.8966897423941578, 0.33581984303002044`], 
             UndirectedEdge[65, 341] -> 
             RGBColor[
              0.9948070643881315, 0.9913011607495696, 0.6761591896109618], 
             UndirectedEdge[46, 353] -> 
             RGBColor[
              0.9803312696678493, 0.9800943932905579, 0.6800004106049857], 
             UndirectedEdge[279, 300] -> 
             RGBColor[
              0.9798725889204911, 0.9437669392659876, 0.3763703256682597], 
             UndirectedEdge[203, 358] -> 
             RGBColor[
              0.9922071868001929, 0.9889314592642007, 0.625143205341028], 
             UndirectedEdge[81, 243] -> 
             RGBColor[
              0.9938866226098646, 0.9911302111760466, 0.7066545786093809], 
             UndirectedEdge[176, 320] -> 
             RGBColor[
              0.9144211024831932, 0.682085547800707, 0.26860473487098385`], 
             UndirectedEdge[112, 248] -> 
             RGBColor[
              0.9140659746500879, 0.6933216002874527, 0.2495230148108501], 
             UndirectedEdge[58, 179] -> 
             RGBColor[
              0.8434636742448408, 0.8766082990270812, 0.8910860280106463], 
             UndirectedEdge[23, 213] -> 
             RGBColor[
              0.8643037104923361, 0.8021106682610231, 0.6217078004855091], 
             UndirectedEdge[243, 326] -> 
             RGBColor[
              0.9940574156987532, 0.9918106029210534, 0.7481475309942436], 
             UndirectedEdge[269, 377] -> 
             RGBColor[
              0.7428343596211758, 0.7930918825994876, 0.7056027488844288], 
             UndirectedEdge[222, 363] -> 
             RGBColor[
              0.9792243494714311, 0.9840261343695746, 0.9200519365741056], 
             UndirectedEdge[30, 341] -> 
             RGBColor[
              0.9940901859069269, 0.9897678301658055, 0.5981313909929948], 
             UndirectedEdge[23, 348] -> 
             RGBColor[
              0.9596438747143072, 0.875814414818102, 0.5488037135404257], 
             UndirectedEdge[16, 25] -> 
             RGBColor[
              0.9940961528118141, 0.9897805927720125, 0.5987808517664919], 
             UndirectedEdge[25, 62] -> 
             RGBColor[
              0.9848764479563645, 0.9590268778801653, 0.5334989496274218], 
             UndirectedEdge[16, 388] -> 
             RGBColor[
              0.9900363318711527, 0.9777058347249491, 0.44525854988143676`], 
             UndirectedEdge[207, 372] -> 
             RGBColor[
              0.9394906329203498, 0.949748846397751, 0.7399129492233385], 
             UndirectedEdge[249, 279] -> 
             RGBColor[
              0.9905751570908843, 0.979869214787233, 0.41794778199982674`], 
             UndirectedEdge[151, 267] -> 
             RGBColor[
              0.9867902124751637, 0.9662743554395934, 0.4735960639973898], 
             UndirectedEdge[185, 252] -> 
             RGBColor[
              0.9851979592205187, 0.960854508179092, 0.47156032869919273`], 
             UndirectedEdge[218, 382] -> 
             RGBColor[
              0.9893897755631721, 0.9898804137721107, 0.825502407506276], 
             UndirectedEdge[284, 334] -> 
             RGBColor[
              0.9524484468500912, 0.855545734206026, 0.5833617066375328], 
             UndirectedEdge[145, 235] -> 
             RGBColor[
              0.9247621853588988, 0.7132674708855498, 0.3135129542719949], 
             UndirectedEdge[78, 302] -> 
             RGBColor[
              0.9829214724194886, 0.9536558296888533, 0.5431088092723204], 
             UndirectedEdge[235, 335] -> 
             RGBColor[
              0.9937342322501275, 0.9888826925396372, 0.5699141336328354], 
             UndirectedEdge[21, 109] -> 
             RGBColor[
              0.9884550993495319, 0.9894939011376874, 0.8409924112307959], 
             UndirectedEdge[283, 389] -> 
             RGBColor[
              0.8527188089284382, 0.8822288339342355, 0.7954321339658006], 
             UndirectedEdge[91, 395] -> 
             RGBColor[
              0.9672369583595756, 0.8945406590940461, 0.4947177703114425], 
             UndirectedEdge[240, 374] -> 
             RGBColor[
              0.9858527264137034, 0.9753516673958431, 0.6361128387010377], 
             UndirectedEdge[301, 339] -> 
             RGBColor[
              0.9923562278765803, 0.9890486291722247, 0.626710205708143], 
             UndirectedEdge[303, 353] -> 
             RGBColor[
              0.9811176082150304, 0.982236267713267, 0.7264754884903989], 
             UndirectedEdge[92, 143] -> 
             RGBColor[
              0.9823592230244942, 0.9830040474384496, 0.7118201093220873], 
             UndirectedEdge[53, 394] -> 
             RGBColor[
              0.9710944785626688, 0.9749681545338793, 0.7598761586407661], 
             UndirectedEdge[139, 345] -> 
             RGBColor[
              0.916048397581952, 0.8245186891119257, 0.622508164216925], 
             UndirectedEdge[224, 393] -> 
             RGBColor[
              0.8725237343602024, 0.4542090034409669, 0.21293750097867575`], 
             UndirectedEdge[175, 204] -> 
             RGBColor[
              0.9836418257991806, 0.9557943573522791, 0.44943937564612085`], 
             UndirectedEdge[131, 293] -> 
             RGBColor[
              0.9120400887915925, 0.930640327996201, 0.9129785914210384], 
             UndirectedEdge[166, 383] -> 
             RGBColor[
              0.7867199026601239, 0.8312210478832098, 0.8796675036006263], 
             UndirectedEdge[92, 348] -> 
             RGBColor[
              0.980224756847932, 0.984000981239259, 0.8838201191195789], 
             UndirectedEdge[212, 289] -> 
             RGBColor[
              0.9039778242953633, 0.9245352002237246, 0.9262572266270003], 
             UndirectedEdge[161, 214] -> 
             RGBColor[
              0.9754667741530373, 0.9286670284181477, 0.37949773513840024`], 
             UndirectedEdge[124, 386] -> 
             RGBColor[
              0.9657312852802702, 0.8901910045070597, 0.39765293073222885`], 
             UndirectedEdge[227, 350] -> 
             RGBColor[
              0.9196450826022717, 0.7665851865222546, 0.5930228350379532], 
             UndirectedEdge[258, 279] -> 
             RGBColor[
              0.9902181941623656, 0.987826584302817, 0.6375802506882178], 
             UndirectedEdge[63, 103] -> 
             RGBColor[
              0.9273666173205362, 0.7400778976040443, 0.2814713545898221], 
             UndirectedEdge[291, 336] -> 
             RGBColor[
              0.9551466859600952, 0.9593661691646838, 0.7050751753847093], 
             UndirectedEdge[292, 400] -> 
             RGBColor[
              0.9823080313863235, 0.9833192941433202, 0.7399495528604834], 
             UndirectedEdge[149, 300] -> 
             RGBColor[
              0.9811466900259473, 0.9464921126991763, 0.5150483681565902], 
             UndirectedEdge[356, 364] -> 
             RGBColor[
              0.7806481609558462, 0.8060960365877194, 0.666288208162388], 
             UndirectedEdge[100, 167] -> 
             RGBColor[
              0.9937061453310546, 0.9889464062064731, 0.5563309443330009], 
             UndirectedEdge[334, 391] -> 
             RGBColor[
              0.9383798738001554, 0.7933795511878224, 0.2694033038715543], 
             UndirectedEdge[309, 323] -> 
             RGBColor[
              0.9944942842487084, 0.9906321556582667, 0.6421150016900316], 
             UndirectedEdge[8, 202] -> 
             RGBColor[
              0.9644351656532629, 0.9384771514181489, 0.6437293736042096], 
             UndirectedEdge[127, 380] -> 
             RGBColor[
              0.9575607126624215, 0.8568962725356513, 0.4444030131326524], 
             UndirectedEdge[130, 151] -> 
             RGBColor[
              0.9504319928937428, 0.958969685499373, 0.7812040927889281], 
             UndirectedEdge[335, 355] -> 
             RGBColor[
              0.994505888183249, 0.9906569753009111, 0.6433780183535839], 
             UndirectedEdge[117, 395] -> 
             RGBColor[
              0.9951195491919851, 0.9919695341479524, 0.7101712320777582], 
             UndirectedEdge[256, 310] -> 
             RGBColor[
              0.9922314127603338, 0.9903522841785697, 0.7272924837760726], 
             UndirectedEdge[362, 365] -> 
             RGBColor[
              0.9538512686509611, 0.8420135262836691, 0.4518352289865484], 
             UndirectedEdge[163, 342] -> 
             RGBColor[
              0.9306713113237675, 0.7507243040037312, 0.5204346026903981], 
             UndirectedEdge[125, 288] -> 
             RGBColor[
              0.9905640791365239, 0.9886242457196102, 0.6794326658546973], 
             UndirectedEdge[161, 253] -> 
             RGBColor[
              0.9620298321992924, 0.8835798495681548, 0.30699349746912286`], 
             UndirectedEdge[12, 211] -> 
             RGBColor[
              0.9054565834326171, 0.905078709402416, 0.6787601988778554], 
             UndirectedEdge[107, 152] -> 
             RGBColor[
              0.9091642568694659, 0.9057514788444387, 0.6757543231756402], 
             UndirectedEdge[183, 291] -> 
             RGBColor[
              0.9891007196697703, 0.9845335573261148, 0.6364664105331405], 
             UndirectedEdge[149, 299] -> 
             RGBColor[
              0.9865894469032941, 0.964851809666555, 0.5361924508466902], 
             UndirectedEdge[57, 284] -> 
             RGBColor[
              0.9891572611510155, 0.9887909458764819, 0.7571983499855254], 
             UndirectedEdge[230, 279] -> 
             RGBColor[
              0.9934081259827204, 0.9883089729547645, 0.5238933774290488], 
             UndirectedEdge[186, 374] -> 
             RGBColor[
              0.9893792084407635, 0.9768099583404868, 0.5776699052697134], 
             UndirectedEdge[30, 175] -> 
             RGBColor[
              0.9935772685958506, 0.9886707519013083, 0.5423035070410547], 
             UndirectedEdge[261, 327] -> 
             RGBColor[
              0.947470347864289, 0.8852972751116788, 0.6177515656953205], 
             UndirectedEdge[271, 333] -> 
             RGBColor[
              0.9895450467277488, 0.9851691897494879, 0.6322262203479698], 
             UndirectedEdge[199, 247] -> 
             RGBColor[
              0.8943193085133082, 0.9161468928741505, 0.8875297246801638], 
             UndirectedEdge[99, 223] -> 
             RGBColor[
              0.9682008392998429, 0.9106512267122326, 0.5601482122165191], 
             UndirectedEdge[200, 367] -> 
             RGBColor[
              0.9853592650861711, 0.9632460397220011, 0.5620275703933278], 
             UndirectedEdge[111, 400] -> 
             RGBColor[
              0.9782777426982519, 0.9704077777762207, 0.6661647654776202], 
             UndirectedEdge[277, 390] -> 
             RGBColor[
              0.9739846956890243, 0.9239064112544543, 0.35343588464019404`], 
             UndirectedEdge[79, 298] -> 
             RGBColor[
              0.9768004785053946, 0.9368907977587617, 0.5461657222471128], 
             UndirectedEdge[96, 388] -> 
             RGBColor[
              0.9440437188319964, 0.8057717450862396, 0.3216000920897646], 
             UndirectedEdge[153, 175] -> 
             RGBColor[
              0.9936254689960837, 0.9887738476835991, 0.5475498231480483], 
             UndirectedEdge[127, 331] -> 
             RGBColor[
              0.9575808937572106, 0.8569394378567834, 0.446599600757158], 
             UndirectedEdge[6, 93] -> 
             RGBColor[
              0.6532822877748772, 0.6998292353981342, 0.6580340173663173], 
             UndirectedEdge[76, 239] -> 
             RGBColor[
              0.9568722949233419, 0.8563255444345128, 0.5049772480722602], 
             UndirectedEdge[333, 337] -> 
             RGBColor[
              0.9924402942236281, 0.9852471313363715, 0.5028818991255106], 
             UndirectedEdge[253, 332] -> 
             RGBColor[
              0.9764585534542761, 0.9322513143860746, 0.36304635490935816`], 
             UndirectedEdge[31, 400] -> 
             RGBColor[
              0.9822432995945181, 0.9831808393860364, 0.7329038968007693], 
             UndirectedEdge[39, 149] -> 
             RGBColor[
              0.9781182676704867, 0.9811988169969265, 0.8267240193176054], 
             UndirectedEdge[49, 335] -> 
             RGBColor[
              0.9891361766483809, 0.9733723713201496, 0.5520515558899913], 
             UndirectedEdge[57, 236] -> 
             RGBColor[
              0.9769499384330905, 0.9796867445811098, 0.777862163167296], 
             UndirectedEdge[76, 323] -> 
             RGBColor[
              0.9942257831522352, 0.9914901190475659, 0.7170005028112114], 
             UndirectedEdge[2, 210] -> 
             RGBColor[
              0.9404261502035483, 0.8015076671953927, 0.2709700410057594], 
             UndirectedEdge[25, 395] -> 
             RGBColor[
              0.9951662889733404, 0.9920695058141543, 0.7152585688337751], 
             UndirectedEdge[62, 91] -> 
             RGBColor[
              0.9569471173425997, 0.8614980311600571, 0.3129581511050892], 
             UndirectedEdge[148, 313] -> 
             RGBColor[
              0.9799699640950388, 0.9432191847894349, 0.4512563574793098], 
             UndirectedEdge[98, 163] -> 
             RGBColor[
              0.9903683123050685, 0.990285063862132, 0.8092855213211418], 
             UndirectedEdge[271, 292] -> 
             RGBColor[
              0.9909023280373518, 0.9890640245770335, 0.6956268788205697], 
             UndirectedEdge[148, 228] -> 
             RGBColor[
              0.9699874619069633, 0.9385626785246246, 0.6257220090589966], 
             UndirectedEdge[105, 333] -> 
             RGBColor[
              0.9913739171346, 0.9859254746625463, 0.6019171047415515], 
             UndirectedEdge[9, 65] -> 
             RGBColor[
              0.9943607218563031, 0.9903464792061408, 0.6275775595282402], 
             UndirectedEdge[129, 337] -> 
             RGBColor[
              0.9943077840816936, 0.9902332506590814, 0.6218156094560832], 
             UndirectedEdge[62, 323] -> 
             RGBColor[
              0.9847274238851691, 0.9587081304605233, 0.5172785991477692], 
             UndirectedEdge[286, 290] -> 
             RGBColor[
              0.993993370300168, 0.9895607513725075, 0.5875936096739458], 
             UndirectedEdge[96, 261] -> 
             RGBColor[
              0.9212933130892609, 0.7247545305778255, 0.25548205274360647`], 
             UndirectedEdge[48, 86] -> 
             RGBColor[
              0.8525728793077612, 0.8819167052313552, 0.7795485953283321], 
             UndirectedEdge[137, 328] -> 
             RGBColor[
              0.9783331950962498, 0.9408063639460891, 0.5434479650389712], 
             UndirectedEdge[110, 212] -> 
             RGBColor[
              0.8950689116354344, 0.9183113832262477, 0.9601656516168897], 
             UndirectedEdge[163, 272] -> 
             RGBColor[
              0.991556396981279, 0.9894562417871811, 0.6936366868833902], 
             UndirectedEdge[245, 396] -> 
             RGBColor[
              0.9938866135675621, 0.9915209502769413, 0.7350576080492761], 
             UndirectedEdge[25, 37] -> 
             RGBColor[
              0.9911810586602616, 0.9904881693607432, 0.7861495321389089], 
             UndirectedEdge[79, 373] -> 
             RGBColor[
              0.9921826576425835, 0.9887198783359475, 0.6109073378332615], 
             UndirectedEdge[34, 43] -> 
             RGBColor[
              0.9899143591557575, 0.9900973425688282, 0.8168086997983144], 
             UndirectedEdge[100, 358] -> 
             RGBColor[
              0.9927121508057679, 0.9900115262124332, 0.6801054210712607], 
             UndirectedEdge[273, 394] -> 
             RGBColor[
              0.9692549413586622, 0.9756345767889785, 0.8940984756988599], 
             UndirectedEdge[89, 189] -> 
             RGBColor[
              0.9755079698841853, 0.9800328353341515, 0.8716357452307552], 
             UndirectedEdge[268, 299] -> 
             RGBColor[
              0.5785267637834424, 0.6216358913634248, 0.6515135596831809], 
             UndirectedEdge[143, 272] -> 
             RGBColor[
              0.9934274933543468, 0.9883503978043313, 0.5260013963090047], 
             UndirectedEdge[339, 382] -> 
             RGBColor[
              0.9917164308031283, 0.9908425455061449, 0.7869437089894549], 
             UndirectedEdge[111, 223] -> 
             RGBColor[
              0.9869355567761746, 0.9761787742982782, 0.6207894432962322], 
             UndirectedEdge[71, 131] -> 
             RGBColor[
              0.9909270326339182, 0.9889320585810446, 0.6848823306127603], 
             UndirectedEdge[114, 370] -> 
             RGBColor[
              0.9672327307745805, 0.9517748746897136, 0.6627933017125084], 
             UndirectedEdge[4, 125] -> 
             RGBColor[
              0.9462369498948398, 0.9552344646135225, 0.7491724836544176], 
             UndirectedEdge[246, 251] -> 
             RGBColor[
              0.6592178653243662, 0.7198513322124449, 0.6810926153063147], 
             UndirectedEdge[30, 229] -> 
             RGBColor[
              0.9634836224083841, 0.9691703271705228, 0.7657196700254033], 
             UndirectedEdge[115, 366] -> 
             RGBColor[
              0.9640426714459538, 0.9594827956632637, 0.6896061636466766], 
             UndirectedEdge[89, 270] -> 
             RGBColor[
              0.9417704601865153, 0.9537444692864973, 0.8896712176566317], 
             UndirectedEdge[197, 369] -> 
             RGBColor[
              0.9648905789850407, 0.9650160940178161, 0.6985746248533236], 
             UndirectedEdge[276, 301] -> 
             RGBColor[
              0.9935163802335045, 0.9885405178510078, 0.5356761845591009], 
             UndirectedEdge[69, 188] -> 
             RGBColor[
              0.9887374595546321, 0.9883262513275316, 0.7458795812622898], 
             UndirectedEdge[191, 225] -> 
             RGBColor[
              0.9841793493696587, 0.9566065806347819, 0.5366428115009143], 
             UndirectedEdge[223, 247] -> 
             RGBColor[
              0.9897871537884833, 0.9900447398804315, 0.8189168219309877], 
             UndirectedEdge[72, 86] -> 
             RGBColor[
              0.9935499923076115, 0.9886124106788208, 0.5393346513959727], 
             UndirectedEdge[19, 85] -> 
             RGBColor[
              0.9765138470033465, 0.9309470785398416, 0.4900241170564933], 
             UndirectedEdge[320, 398] -> 
             RGBColor[
              0.9807520907204411, 0.9464053113216364, 0.4077112821923684], 
             UndirectedEdge[249, 300] -> 
             RGBColor[
              0.9779435819825842, 0.9372606643133379, 0.3688154103177288], 
             UndirectedEdge[18, 319] -> 
             RGBColor[
              0.9744142907886446, 0.9253555363991995, 0.3551047804799913], 
             UndirectedEdge[6, 273] -> 
             RGBColor[
              0.9846124466574886, 0.965933777804295, 0.5951164417807789], 
             UndirectedEdge[158, 348] -> 
             RGBColor[
              0.9779866434709694, 0.9452324637534955, 0.580774798811036], 
             UndirectedEdge[61, 228] -> 
             RGBColor[
              0.9494107340470556, 0.8599556464726041, 0.5936829045520317], 
             UndirectedEdge[70, 260] -> 
             RGBColor[
              0.8328626029143464, 0.253601943249895, 0.17910257170476676`], 
             UndirectedEdge[144, 305] -> 
             RGBColor[
              0.9715080331902295, 0.9267968461770236, 0.5792334803748982], 
             UndirectedEdge[165, 351] -> 
             RGBColor[
              0.9907772793861074, 0.9788570506504484, 0.5627759788047848], 
             UndirectedEdge[132, 370] -> 
             RGBColor[
              0.9856692179378371, 0.9625813981937342, 0.46172256651595334`], 
             UndirectedEdge[104, 145] -> 
             RGBColor[
              0.9087240298134389, 0.6591670062927122, 0.2512077485294233], 
             UndirectedEdge[207, 231] -> 
             RGBColor[
              0.9938287093125044, 0.9892085581696748, 0.5696712773365921], 
             UndirectedEdge[21, 249] -> 
             RGBColor[
              0.9877872033655151, 0.9811127261240973, 0.6383445069729659], 
             UndirectedEdge[7, 93] -> 
             RGBColor[
              0.6577356206719982, 0.7148513729524126, 0.6753343747302805], 
             UndirectedEdge[140, 255] -> 
             RGBColor[
              0.9578340984277987, 0.8622034548034317, 0.5158544762739732], 
             UndirectedEdge[100, 157] -> 
             RGBColor[
              0.9792966381234764, 0.9409988147731949, 0.444311033912902], 
             UndirectedEdge[42, 178] -> 
             RGBColor[
              0.985559939667283, 0.9614728562112848, 0.5242155578899799], 
             UndirectedEdge[115, 195] -> 
             RGBColor[
              0.9544892089630741, 0.9272567234488469, 0.652492765920698], 
             UndirectedEdge[281, 394] -> 
             RGBColor[
              0.9568651603781304, 0.9276634692641126, 0.64557276469284], 
             UndirectedEdge[215, 224] -> 
             RGBColor[
              0.9056970842000308, 0.5762966430106624, 0.2887601049311624], 
             UndirectedEdge[99, 222] -> 
             RGBColor[
              0.9640404767026045, 0.9082344221405687, 0.5979105221643175], 
             UndirectedEdge[55, 284] -> 
             RGBColor[
              0.9765105651401755, 0.9820021984587382, 0.9246456655786102], 
             UndirectedEdge[32, 337] -> 
             RGBColor[
              0.9902915558853915, 0.9891340054529165, 0.7291949962790333], 
             UndirectedEdge[172, 399] -> 
             RGBColor[
              0.828821213419245, 0.7999123982854861, 0.6238226518133224], 
             UndirectedEdge[267, 346] -> 
             RGBColor[
              0.9562970591845823, 0.8574094666420782, 0.32030597795454374`], 
             UndirectedEdge[222, 393] -> 
             RGBColor[
              0.9507588226502479, 0.85557708967182, 0.5872237915533018], 
             UndirectedEdge[116, 179] -> 
             RGBColor[
              0.8459665808736777, 0.8775936183695561, 0.8459939500109895], 
             UndirectedEdge[120, 360] -> 
             RGBColor[
              0.9555577421330226, 0.8503231207484856, 0.361842864008432], 
             UndirectedEdge[144, 222] -> 
             RGBColor[
              0.9682459789699375, 0.9247515152046992, 0.6021084957691376], 
             UndirectedEdge[237, 307] -> 
             RGBColor[
              0.9947805040997595, 0.9921096185573938, 0.736164084896773], 
             UndirectedEdge[18, 144] -> 
             RGBColor[
              0.9724273693821794, 0.918653183943861, 0.3473859660144981], 
             UndirectedEdge[309, 365] -> 
             RGBColor[
              0.9536255143711433, 0.8415306607063977, 0.4272632688222935], 
             UndirectedEdge[189, 241] -> 
             RGBColor[
              0.9771687034155896, 0.980361266056551, 0.8180666281930729], 
             UndirectedEdge[268, 370] -> 
             RGBColor[
              0.5782819886305857, 0.6208102072968997, 0.6505626544362412], 
             UndirectedEdge[336, 359] -> 
             RGBColor[
              0.9573511778092442, 0.9652615614886536, 0.8446642100839157], 
             UndirectedEdge[115, 123] -> 
             RGBColor[
              0.9687370091202764, 0.9739595699716954, 0.8233452683063036], 
             UndirectedEdge[6, 394] -> 
             RGBColor[
              0.9639187342938839, 0.9514568303398634, 0.6729745673998764], 
             UndirectedEdge[259, 353] -> 
             RGBColor[
              0.9802567666938908, 0.9835639272330569, 0.8631246866275332], 
             UndirectedEdge[98, 348] -> 
             RGBColor[
              0.990104942501574, 0.9901761536800918, 0.8136502405442478], 
             UndirectedEdge[145, 349] -> 
             RGBColor[
              0.9253609760754716, 0.716209314781449, 0.47990717948036926`], 
             UndirectedEdge[287, 292] -> 
             RGBColor[
              0.9924859245416764, 0.9897188824281455, 0.6693825865275302], 
             UndirectedEdge[53, 69] -> 
             RGBColor[
              0.9885939017463903, 0.9880191956916231, 0.73025419977126], 
             UndirectedEdge[236, 284] -> 
             RGBColor[
              0.9719747014709088, 0.9786193587609942, 0.9323236996279664], 
             UndirectedEdge[119, 146] -> 
             RGBColor[
              0.9651405065330404, 0.97004136926231, 0.7313670556232841], 
             UndirectedEdge[198, 310] -> 
             RGBColor[
              0.9912917115430613, 0.9883423582931907, 0.6250118054396381], 
             UndirectedEdge[198, 384] -> 
             RGBColor[
              0.9900096993443006, 0.9779103935487565, 0.42012172649473956`], 
             UndirectedEdge[111, 292] -> 
             RGBColor[
              0.989580341284902, 0.9758305921465225, 0.47214989967549204`], 
             UndirectedEdge[40, 295] -> 
             RGBColor[
              0.9911715553108467, 0.990617225487425, 0.7959737059891341], 
             UndirectedEdge[5, 270] -> 
             RGBColor[
              0.9401794318765334, 0.9445627068183609, 0.6994269397083194], 
             UndirectedEdge[104, 355] -> 
             RGBColor[
              0.9770359249299854, 0.933370230052337, 0.4357554812006013], 
             UndirectedEdge[356, 360] -> 
             RGBColor[
              0.9485191062493241, 0.8268368540204369, 0.3126707645549146], 
             UndirectedEdge[42, 398] -> 
             RGBColor[
              0.9939683088944314, 0.9895071475597339, 0.5848658303205974], 
             UndirectedEdge[153, 211] -> 
             RGBColor[
              0.9864184841679826, 0.9651508169436165, 0.4610646838917934], 
             UndirectedEdge[223, 385] -> 
             RGBColor[
              0.9899042738387424, 0.9861929540382338, 0.632322348489132], 
             UndirectedEdge[144, 361] -> 
             RGBColor[
              0.9704703712092045, 0.9120517695813938, 0.3397833976605853], 
             UndirectedEdge[216, 229] -> 
             RGBColor[
              0.9119129020831281, 0.9325986111775143, 0.9914602607465886], 
             UndirectedEdge[161, 389] -> 
             RGBColor[
              0.8345995873084187, 0.8222064439014836, 0.6316764626821335], 
             UndirectedEdge[313, 340] -> 
             RGBColor[
              0.9945115936559467, 0.9906691787300996, 0.6439990238466224], 
             UndirectedEdge[241, 380] -> 
             RGBColor[
              0.9946420414191575, 0.9909481933053155, 0.6581974578418455], 
             UndirectedEdge[258, 281] -> 
             RGBColor[
              0.9765506580285717, 0.9417234940347148, 0.5844233660469004], 
             UndirectedEdge[344, 346] -> 
             RGBColor[
              0.8651218953252277, 0.8065779096109624, 0.6226370462966777], 
             UndirectedEdge[79, 205] -> 
             RGBColor[
              0.9144812583648363, 0.9319421632745971, 0.8852168937106712], 
             UndirectedEdge[227, 306] -> 
             RGBColor[
              0.9364052493693218, 0.7701645506359396, 0.31763705614886917`], 
             UndirectedEdge[43, 381] -> 
             RGBColor[
              0.9935934217415621, 0.9916187294956541, 0.7558371116427679], 
             UndirectedEdge[98, 143] -> 
             RGBColor[
              0.9922394086781363, 0.9891792198792824, 0.6416502307467562], 
             UndirectedEdge[243, 267] -> 
             RGBColor[
              0.986466881831783, 0.9673805662063956, 0.569083315085398], 
             UndirectedEdge[58, 152] -> 
             RGBColor[
              0.9155583408480716, 0.9330982414182778, 0.8982268923571], 
             UndirectedEdge[376, 397] -> 
             RGBColor[
              0.9351032039570264, 0.9493346472049273, 0.9283972180994866], 
             UndirectedEdge[114, 279] -> 
             RGBColor[
              0.9746663241583905, 0.9768494122627553, 0.6917324959514461], 
             UndirectedEdge[148, 218] -> 
             RGBColor[
              0.9765896488209547, 0.9429929406870534, 0.5924401092871141], 
             UndirectedEdge[55, 366] -> 
             RGBColor[
              0.9770771685953972, 0.9692039022952883, 0.6675421599139892], 
             UndirectedEdge[99, 361] -> 
             RGBColor[
              0.9662648689418716, 0.8955346765172632, 0.3355854240557651], 
             UndirectedEdge[97, 169] -> 
             RGBColor[
              0.9712601958905143, 0.9117216914753989, 0.4251561430275411], 
             UndirectedEdge[43, 250] -> 
             RGBColor[
              0.9934644025385144, 0.9907754571212719, 0.7005564762947453], 
             UndirectedEdge[112, 177] -> 
             RGBColor[
              0.8760649158710654, 0.7458301226582971, 0.6088478557282074], 
             UndirectedEdge[255, 356] -> 
             RGBColor[
              0.9510254617815099, 0.8367737185120836, 0.31468743704783697`], 
             UndirectedEdge[210, 328] -> 
             RGBColor[
              0.9444552218095511, 0.8150986717934415, 0.286622223368751], 
             UndirectedEdge[91, 221] -> 
             RGBColor[
              0.9665552449215262, 0.8930825429818601, 0.4205174696274422], 
             UndirectedEdge[32, 345] -> 
             RGBColor[
              0.9500172792266208, 0.961269624755036, 0.9316825482661134], 
             UndirectedEdge[210, 258] -> 
             RGBColor[
              0.9563957129281244, 0.8645382413893885, 0.5540279788507587], 
             UndirectedEdge[189, 359] -> 
             RGBColor[
              0.9772352276658264, 0.9805035547011742, 0.8253073822912665], 
             UndirectedEdge[164, 258] -> 
             RGBColor[
              0.9902181941623656, 0.987826584302817, 0.6375802506882178], 
             UndirectedEdge[354, 374] -> 
             RGBColor[
              0.9847455548789249, 0.9748938235132018, 0.6544615363003995], 
             UndirectedEdge[235, 322] -> 
             RGBColor[
              0.9874025221108338, 0.9691678904306825, 0.4055616065450178], 
             UndirectedEdge[147, 392] -> 
             RGBColor[
              0.9187020019322263, 0.7153875591528248, 0.2534439263266337], 
             UndirectedEdge[123, 283] -> 
             RGBColor[
              0.9944929996297641, 0.9906294079882396, 0.641975178845688], 
             UndirectedEdge[202, 239] -> 
             RGBColor[
              0.9399451004143833, 0.845267897513701, 0.6037873321874057], 
             UndirectedEdge[180, 249] -> 
             RGBColor[
              0.9825591329000898, 0.9528300013409758, 0.38674595405858325`], 
             UndirectedEdge[2, 197] -> 
             RGBColor[
              0.9725194547321783, 0.918963809452075, 0.3477437002103839], 
             UndirectedEdge[174, 329] -> 
             RGBColor[
              0.9532173274977653, 0.9618905314742099, 0.8382055797877334], 
             UndirectedEdge[193, 242] -> 
             RGBColor[
              0.9936757166503883, 0.9888813223353394, 0.5530189702265242], 
             UndirectedEdge[58, 160] -> 
             RGBColor[
              0.9656897091511989, 0.8973262541814319, 0.541640906261259], 
             UndirectedEdge[50, 137] -> 
             RGBColor[
              0.9896047909034127, 0.9899693281409423, 0.821939046876625], 
             UndirectedEdge[326, 383] -> 
             RGBColor[
              0.9929509587618782, 0.9913530545430094, 0.7664843858570238], 
             UndirectedEdge[157, 238] -> 
             RGBColor[
              0.9423633367394177, 0.806597859684535, 0.2860180659421082], 
             UndirectedEdge[243, 346] -> 
             RGBColor[
              0.9630282428924872, 0.8814841399816709, 0.5136118499260218], 
             UndirectedEdge[235, 355] -> 
             RGBColor[
              0.9930740804754452, 0.9874706946451747, 0.49806068694317285`], 
             UndirectedEdge[44, 135] -> 
             RGBColor[
              0.9898674084244747, 0.9900779272348639, 0.8175867949202705], 
             UndirectedEdge[33, 206] -> 
             RGBColor[
              0.9838413018388075, 0.9556252828568494, 0.5218079945647277], 
             UndirectedEdge[88, 263] -> 
             RGBColor[
              0.9391535727776492, 0.7917875502193421, 0.2942923849935329], 
             UndirectedEdge[82, 399] -> 
             RGBColor[
              0.970672059166791, 0.9084769297323408, 0.47870912541415034`], 
             UndirectedEdge[271, 287] -> 
             RGBColor[
              0.9897776226060544, 0.9900407984915569, 0.8190747782897448], 
             UndirectedEdge[31, 223] -> 
             RGBColor[
              0.9909011136724408, 0.988951835908094, 0.6875285746193813], 
             UndirectedEdge[108, 376] -> 
             RGBColor[
              0.8726134081846053, 0.9012622614991761, 0.987711839935475], 
             UndirectedEdge[301, 361] -> 
             RGBColor[
              0.9886724913489666, 0.9732093327505664, 0.4311124260522198], 
             UndirectedEdge[80, 388] -> 
             RGBColor[
              0.9891007333500059, 0.9792319836275698, 0.5998218648875543], 
             UndirectedEdge[47, 136] -> 
             RGBColor[
              0.9026246178450673, 0.9236293442700977, 0.9334424254242253], 
             UndirectedEdge[39, 50] -> 
             RGBColor[
              0.9738893013871944, 0.9796481327255783, 0.911208856522781], 
             UndirectedEdge[120, 389] -> 
             RGBColor[
              0.8520372325350252, 0.8807710109466691, 0.7212467497447139], 
             UndirectedEdge[28, 106] -> 
             RGBColor[
              0.9916392792425575, 0.9889053169968945, 0.6497253429370267], 
             UndirectedEdge[97, 326] -> 
             RGBColor[
              0.9943869300326029, 0.9907176184428977, 0.65333333645249], 
             UndirectedEdge[195, 242] -> 
             RGBColor[
              0.9793701089028379, 0.9420548312219805, 0.3758744683786271], 
             UndirectedEdge[90, 260] -> 
             RGBColor[
              0.9210355731358365, 0.6809675798085624, 0.3729165949813549], 
             UndirectedEdge[73, 368] -> 
             RGBColor[
              0.9924281054321658, 0.98606419974064, 0.4298607700396879], 
             UndirectedEdge[52, 287] -> 
             RGBColor[
              0.98784158697655, 0.9892401980049106, 0.8511598989702327], 
             UndirectedEdge[135, 243] -> 
             RGBColor[
              0.990138591595288, 0.9901900684450848, 0.8130925879803435], 
             UndirectedEdge[311, 317] -> 
             RGBColor[
              0.9562074331387422, 0.9668601558553966, 0.9590135721521291], 
             UndirectedEdge[6, 10] -> 
             RGBColor[
              0.8887151074405066, 0.8919996250680348, 0.6772543603158565], 
             UndirectedEdge[363, 383] -> 
             RGBColor[
              0.9847167574238791, 0.9869937739276218, 0.8602141878676077], 
             UndirectedEdge[227, 346] -> 
             RGBColor[
              0.9085400670466839, 0.6693363541773893, 0.24496930582778523`], 
             UndirectedEdge[157, 341] -> 
             RGBColor[
              0.9796975889533355, 0.941856408055916, 0.4879520573613568], 
             UndirectedEdge[18, 310] -> 
             RGBColor[
              0.9891795464154335, 0.9812696472424818, 0.6123747140459088], 
             UndirectedEdge[37, 96] -> 
             RGBColor[
              0.9441567517569596, 0.816347390866876, 0.5501975641114467], 
             UndirectedEdge[218, 222] -> 
             RGBColor[
              0.9835818092879667, 0.9867822827381243, 0.8905697742596241], 
             UndirectedEdge[65, 203] -> 
             RGBColor[
              0.9939011495526975, 0.9893635005186161, 0.5775559504322744], 
             UndirectedEdge[105, 303] -> 
             RGBColor[
              0.9925910716012498, 0.9895205923420125, 0.6500658211213416], 
             UndirectedEdge[119, 267] -> 
             RGBColor[
              0.9585435852764732, 0.9480516520493634, 0.6833546191626712], 
             UndirectedEdge[20, 312] -> 
             RGBColor[
              0.8423705893613926, 0.8762171250806208, 0.911960232372186], 
             UndirectedEdge[285, 324] -> 
             RGBColor[
              0.9672150997315272, 0.9743132373848313, 0.9065065117761915], 
             UndirectedEdge[16, 302] -> 
             RGBColor[
              0.9822582462990881, 0.9514685257090336, 0.4150421562021769], 
             UndirectedEdge[65, 313] -> 
             RGBColor[
              0.9944473637472979, 0.9905317974501398, 0.6370079946712544], 
             UndirectedEdge[280, 392] -> 
             RGBColor[
              0.9462699279922168, 0.8168968928732396, 0.3161873600984477], 
             UndirectedEdge[1, 357] -> 
             RGBColor[
              0.9695847178058237, 0.9734649369016946, 0.732499367123883], 
             UndirectedEdge[26, 177] -> 
             RGBColor[
              0.9273064382301717, 0.9405770277739299, 0.7828109098658509], 
             UndirectedEdge[69, 293] -> 
             RGBColor[
              0.9096160023160662, 0.9295329203010716, 0.9484505061387312], 
             UndirectedEdge[165, 399] -> 
             RGBColor[
              0.9708679065594881, 0.9088958275021113, 0.5000259054792314], 
             UndirectedEdge[108, 297] -> 
             RGBColor[
              0.918985217928215, 0.9371953334172183, 0.9559889462465565], 
             UndirectedEdge[192, 335] -> 
             RGBColor[
              0.9922221786297697, 0.9909516480559906, 0.7712905121941862], 
             UndirectedEdge[134, 272] -> 
             RGBColor[
              0.9636065090304371, 0.8814735399814981, 0.4133071883749736], 
             UndirectedEdge[86, 236] -> 
             RGBColor[
              0.9768788061616178, 0.9795345998450056, 0.7701198543949839], 
             UndirectedEdge[312, 389] -> 
             RGBColor[
              0.7040976289650661, 0.7687656861784687, 0.9711415295549474], 
             UndirectedEdge[156, 245] -> 
             RGBColor[
              0.9894426298448692, 0.9899022703758855, 0.8246264752760579], 
             UndirectedEdge[153, 168] -> 
             RGBColor[
              0.9934886352663331, 0.9884811741716747, 0.532656316104583], 
             UndirectedEdge[118, 150] -> 
             RGBColor[
              0.9765400465985046, 0.9376428599190445, 0.5564243643499943], 
             UndirectedEdge[195, 255] -> 
             RGBColor[
              0.9447087807195773, 0.8154660700629404, 0.29014832392735546`], 
             UndirectedEdge[109, 180] -> 
             RGBColor[
              0.9832270288841066, 0.9612111763545659, 0.5893938583164133], 
             UndirectedEdge[143, 378] -> 
             RGBColor[
              0.99292731377229, 0.9872805642542255, 0.4715599355527144], 
             UndirectedEdge[135, 383] -> 
             RGBColor[
              0.9890321346584132, 0.9897325200670408, 0.8314294428431237], 
             UndirectedEdge[20, 120] -> 
             RGBColor[
              0.9903101929313518, 0.9882224498488211, 0.6620654525619527], 
             UndirectedEdge[149, 230] -> 
             RGBColor[
              0.9946822270881766, 0.9910341463879532, 0.6625714199173793], 
             UndirectedEdge[16, 77] -> 
             RGBColor[
              0.9929658372499628, 0.9894461642452919, 0.6271797845458096], 
             UndirectedEdge[168, 238] -> 
             RGBColor[
              0.956659311389982, 0.8543026164582628, 0.3856806581729684], 
             UndirectedEdge[104, 335] -> 
             RGBColor[
              0.9776960767046676, 0.9347822279467997, 0.5076089278902638], 
             UndirectedEdge[79, 232] -> 
             RGBColor[
              0.986952922149746, 0.9711373740782872, 0.5856060486773076], 
             UndirectedEdge[47, 299] -> 
             RGBColor[
              0.9819857000799102, 0.9631461440104583, 0.6268883715021343], 
             UndirectedEdge[236, 397] -> 
             RGBColor[
              0.9732947447246953, 0.9791668879146742, 0.9105213860309888], 
             UndirectedEdge[33, 118] -> 
             RGBColor[
              0.981683197110605, 0.9549919142655274, 0.5764045328870271], 
             UndirectedEdge[51, 79] -> 
             RGBColor[
              0.9916249408343667, 0.9908047120528769, 0.7884599345402843], 
             UndirectedEdge[24, 168] -> 
             RGBColor[
              0.9924444928842813, 0.9894715695708121, 0.6533375745897947], 
             UndirectedEdge[269, 365] -> 
             RGBColor[
              0.7029791866481052, 0.6461583689359653, 0.6010747838759283], 
             UndirectedEdge[98, 240] -> 
             RGBColor[
              0.9888936549404231, 0.9896752551448855, 0.8337244101442404], 
             UndirectedEdge[29, 113] -> 
             RGBColor[
              0.9322906989568162, 0.7520774194091051, 0.3126464048947618], 
             UndirectedEdge[330, 398] -> 
             RGBColor[
              0.9211922701761415, 0.9351124362210572, 0.7344555530464247], 
             UndirectedEdge[43, 265] -> 
             RGBColor[
              0.9930581155872056, 0.9899064504143343, 0.6563346489572015], 
             UndirectedEdge[209, 304] -> 
             RGBColor[
              0.7748695941439856, 0.7706981327309859, 0.6219704744946115], 
             UndirectedEdge[107, 238] -> 
             RGBColor[
              0.9487026109524557, 0.8279817201374805, 0.3106449491882753], 
             UndirectedEdge[298, 347] -> 
             RGBColor[
              0.8529243555427592, 0.8414337537835666, 0.6406757019302043], 
             UndirectedEdge[153, 343] -> 
             RGBColor[
              0.9296073164092888, 0.9422229424061839, 0.7677302364272647], 
             UndirectedEdge[110, 292] -> 
             RGBColor[
              0.9812577350579834, 0.9825359848613466, 0.7417274305832087], 
             UndirectedEdge[332, 366] -> 
             RGBColor[
              0.9861081615904057, 0.9648017084649758, 0.40053326034262915`], 
             UndirectedEdge[39, 136] -> 
             RGBColor[
              0.8902942660992346, 0.9147079903168605, 0.9666117417593678], 
             UndirectedEdge[115, 380] -> 
             RGBColor[
              0.9685937771813234, 0.9736532113372454, 0.8077553556763384], 
             UndirectedEdge[167, 238] -> 
             RGBColor[
              0.9567728439469959, 0.8545454511178132, 0.39803797636220706`], 
             UndirectedEdge[1, 162] -> 
             RGBColor[
              0.9877684229315934, 0.9700422619904179, 0.43758617548026935`], 
             UndirectedEdge[128, 243] -> 
             RGBColor[
              0.9257676892772575, 0.7204334838586619, 0.48294318496171645`], 
             UndirectedEdge[196, 366] -> 
             RGBColor[
              0.9871249046256448, 0.9759095728370114, 0.6152495408696412], 
             UndirectedEdge[136, 149] -> 
             RGBColor[
              0.9072283646684514, 0.9253350099261943, 0.8427465047687812], 
             UndirectedEdge[263, 360] -> 
             RGBColor[
              0.9449989793693971, 0.8149626394893463, 0.2989957363465806], 
             UndirectedEdge[267, 354] -> 
             RGBColor[
              0.9819665418321324, 0.9655195599630775, 0.6436655953861896], 
             UndirectedEdge[192, 355] -> 
             RGBColor[
              0.9915620268550874, 0.9895396501615279, 0.6994370655045237], 
             UndirectedEdge[24, 100] -> 
             RGBColor[
              0.9926932930952493, 0.9900037280645126, 0.6804179421367453], 
             UndirectedEdge[11, 286] -> 
             RGBColor[
              0.9417041076350248, 0.7892047898984691, 0.4510478903854035], 
             UndirectedEdge[71, 110] -> 
             RGBColor[
              0.9811753285486382, 0.9823597256704335, 0.7327579905950116], 
             UndirectedEdge[186, 306] -> 
             RGBColor[
              0.9910267387773133, 0.9823674650241883, 0.5840702495172112], 
             UndirectedEdge[6, 131] -> 
             RGBColor[
              0.9838422439531317, 0.9656152791927368, 0.6078806938126776], 
             UndirectedEdge[53, 264] -> 
             RGBColor[
              0.9914707344660187, 0.9893138255937366, 0.6872791081190748], 
             UndirectedEdge[83, 118] -> 
             RGBColor[
              0.9750489834010236, 0.9798366709073094, 0.8789574482276608], 
             UndirectedEdge[98, 272] -> 
             RGBColor[
              0.9925636659471132, 0.9898727733901851, 0.6769436333909934], 
             UndirectedEdge[200, 330] -> 
             RGBColor[
              0.9214077374046297, 0.9371389052256323, 0.8717108883235032], 
             UndirectedEdge[101, 389] -> 
             RGBColor[
              0.8335859428957476, 0.8187871832825182, 0.6277386455495924], 
             UndirectedEdge[10, 353] -> 
             RGBColor[
              0.883529407715648, 0.9092865399949803, 0.9590181806289899], 
             UndirectedEdge[174, 340] -> 
             RGBColor[
              0.9949937165172391, 0.9917003907803057, 0.6964751219809069], 
             UndirectedEdge[77, 187] -> 
             RGBColor[
              0.9416746101992668, 0.9534143100103929, 0.8786441950987336], 
             UndirectedEdge[137, 264] -> 
             RGBColor[
              0.9909644444677318, 0.990531579831291, 0.7994060686452272], 
             UndirectedEdge[20, 356] -> 
             RGBColor[
              0.9832715570476533, 0.9647361831207725, 0.6128933531084353], 
             UndirectedEdge[130, 227] -> 
             RGBColor[
              0.8956204864045587, 0.7479281104618936, 0.6080487997786997], 
             UndirectedEdge[24, 150] -> 
             RGBColor[
              0.9769798869967401, 0.9378247452270975, 0.54913507068077], 
             UndirectedEdge[282, 339] -> 
             RGBColor[
              0.9933390313966577, 0.991150746524992, 0.7336823037083074], 
             UndirectedEdge[69, 93] -> 
             RGBColor[
              0.6554242056597723, 0.7225810755405615, 0.927394092414892], 
             UndirectedEdge[65, 266] -> 
             RGBColor[
              0.994433988701625, 0.9916978696586234, 0.7223928335322868], 
             UndirectedEdge[189, 336] -> 
             RGBColor[
              0.9395867167062985, 0.9540519513673805, 0.9728464276713816], 
             UndirectedEdge[191, 322] -> 
             RGBColor[
              0.9888709878748989, 0.972432578962064, 0.5548689411521827], 
             UndirectedEdge[297, 376] -> 
             RGBColor[
              0.9297561069612554, 0.9457837479641706, 0.957016283257814], 
             UndirectedEdge[33, 286] -> 
             RGBColor[
              0.9837409202685856, 0.9554105768282785, 0.5108820801293208], 
             UndirectedEdge[145, 351] -> 
             RGBColor[
              0.9217637968109659, 0.7031532022582618, 0.30186478096144176`], 
             UndirectedEdge[83, 141] -> 
             RGBColor[
              0.9587475215621912, 0.919731362337681, 0.62256792329256], 
             UndirectedEdge[148, 276] -> 
             RGBColor[
              0.980076456417835, 0.9434469610998708, 0.46284738962125094`], 
             UndirectedEdge[124, 160] -> 
             RGBColor[
              0.9395965478294069, 0.7982274709404793, 0.27025616841353317`], 
             UndirectedEdge[25, 362] -> 
             RGBColor[
              0.9948690625997216, 0.9914337686551802, 0.6829073123339391], 
             UndirectedEdge[96, 208] -> 
             RGBColor[
              0.9474137159024166, 0.8176942292411832, 0.496221239468204], 
             UndirectedEdge[240, 272] -> 
             RGBColor[
              0.9900817396166336, 0.9888464330699345, 0.7180755757064887], 
             UndirectedEdge[25, 182] -> 
             RGBColor[
              0.9947948823517612, 0.9912751046055661, 0.6748332501308589], 
             UndirectedEdge[101, 380] -> 
             RGBColor[
              0.9752169016581206, 0.9268813987020724, 0.4586917777995145], 
             UndirectedEdge[24, 358] -> 
             RGBColor[
              0.9915640309160085, 0.9907795242363224, 0.7894693695172931], 
             UndirectedEdge[202, 234] -> 
             RGBColor[
              0.9739956448792694, 0.9707268927547418, 0.6808700300522348], 
             UndirectedEdge[17, 62] -> 
             RGBColor[
              0.9603541703987104, 0.9426880308881889, 0.6660373201486895], 
             UndirectedEdge[24, 211] -> 
             RGBColor[
              0.9853743417859309, 0.9661412123427537, 0.581745942377005], 
             UndirectedEdge[2, 39] -> 
             RGBColor[
              0.9585886339740286, 0.9168941639326762, 0.6170655923221358], 
             UndirectedEdge[164, 328] -> 
             RGBColor[
              0.9782777030437922, 0.93838701470687, 0.3701744952062101], 
             UndirectedEdge[228, 301] -> 
             RGBColor[
              0.9834273857226328, 0.9836562352757616, 0.6985508039968467], 
             UndirectedEdge[118, 286] -> 
             RGBColor[
              0.9927232155669995, 0.9908266180350469, 0.7388380251635198], 
             UndirectedEdge[139, 215] -> 
             RGBColor[
              0.9532624183035336, 0.8429744553073129, 0.3303825965689843], 
             UndirectedEdge[239, 377] -> 
             RGBColor[
              0.9564627134001813, 0.8540172308864862, 0.3562866384447879], 
             UndirectedEdge[348, 374] -> 
             RGBColor[
              0.9870640139748541, 0.9758525659310495, 0.6160386691010452], 
             UndirectedEdge[8, 388] -> 
             RGBColor[
              0.9780555786740897, 0.9376384554518595, 0.36925049631542706`], 
             UndirectedEdge[249, 370] -> 
             RGBColor[
              0.9831415637070742, 0.9547946772141913, 0.3890085877608891], 
             UndirectedEdge[61, 285] -> 
             RGBColor[
              0.9352738808715584, 0.849412404521291, 0.61761290949633], 
             UndirectedEdge[162, 280] -> 
             RGBColor[
              0.982375409905272, 0.9522102605392448, 0.3860322249168924], 
             UndirectedEdge[126, 205] -> 
             RGBColor[
              0.8753155769975918, 0.903416897562233, 0.9879695752091122], 
             UndirectedEdge[161, 334] -> 
             RGBColor[
              0.9393792595414576, 0.7967507139601657, 0.27328572875835183`], 
             UndirectedEdge[192, 399] -> 
             RGBColor[
              0.9678826095474138, 0.907689875624629, 0.5515749341476687], 
             UndirectedEdge[69, 281] -> 
             RGBColor[
              0.974364583561852, 0.9407145104218564, 0.615950805823334], 
             UndirectedEdge[38, 128] -> 
             RGBColor[
              0.9158941417629235, 0.6857588795378747, 0.2774298229878731], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.941773231896972, 0.9515420496819559, 0.7379517520836256], 
             UndirectedEdge[145, 355] -> 
             RGBColor[
              0.9255338412920202, 0.7150417536468237, 0.3869768389927434], 
             UndirectedEdge[23, 139] -> 
             RGBColor[
              0.9245571365421631, 0.7386012167732783, 0.25815510507146217`], 
             UndirectedEdge[120, 359] -> 
             RGBColor[
              0.993959314396776, 0.989487909238732, 0.5838868347583976], 
             UndirectedEdge[117, 309] -> 
             RGBColor[
              0.9945965685385486, 0.9908509314117068, 0.6532480154136673], 
             UndirectedEdge[19, 167] -> 
             RGBColor[
              0.9942446764880619, 0.9900982698974594, 0.6149467373441864], 
             UndirectedEdge[26, 285] -> 
             RGBColor[
              0.9698000231913391, 0.9742027422949937, 0.7779357213509062], 
             UndirectedEdge[166, 169] -> 
             RGBColor[
              0.7655589756139753, 0.7530380326688202, 0.6189117992502648], 
             UndirectedEdge[31, 383] -> 
             RGBColor[
              0.9922331590276505, 0.9895026708944773, 0.6654531358606818], 
             UndirectedEdge[146, 346] -> 
             RGBColor[
              0.9628939804411496, 0.8793991838550249, 0.36831841441515667`], 
             UndirectedEdge[191, 349] -> 
             RGBColor[
              0.9943696810229619, 0.9919029443111815, 0.7402983620379636], 
             UndirectedEdge[212, 362] -> 
             RGBColor[
              0.9079216308256797, 0.9255865804633072, 0.8187756958956567], 
             UndirectedEdge[242, 380] -> 
             RGBColor[
              0.9934746771210874, 0.988451319110379, 0.5311370581342675], 
             UndirectedEdge[175, 307] -> 
             RGBColor[
              0.9939795260869526, 0.9903424344968765, 0.6450592979427212], 
             UndirectedEdge[140, 193] -> 
             RGBColor[
              0.9936392315892895, 0.9912386991544834, 0.7260767338595115], 
             UndirectedEdge[8, 25] -> 
             RGBColor[
              0.982115399614751, 0.949713213498923, 0.5227727982004822], 
             UndirectedEdge[8, 269] -> 
             RGBColor[
              0.7309845335356568, 0.7533045431792292, 0.643845303421519], 
             UndirectedEdge[155, 371] -> 
             RGBColor[
              0.9078794113065702, 0.9288089233676315, 0.9711922237819025], 
             UndirectedEdge[55, 161] -> 
             RGBColor[
              0.9634413778315418, 0.9232071782128779, 0.6145696876994291], 
             UndirectedEdge[110, 202] -> 
             RGBColor[
              0.9643361094479884, 0.9729225093373466, 0.9452538434588996], 
             UndirectedEdge[332, 380] -> 
             RGBColor[
              0.9906592673257753, 0.9789721241389575, 0.5186824523722909], 
             UndirectedEdge[359, 360] -> 
             RGBColor[
              0.9565981165050187, 0.8525483763322009, 0.475081193953835], 
             UndirectedEdge[128, 350] -> 
             RGBColor[
              0.9067028821856449, 0.7077112166392099, 0.5822193770410302], 
             UndirectedEdge[272, 378] -> 
             RGBColor[
              0.993251571041267, 0.9879741177651282, 0.5068533381969516], 
             UndirectedEdge[52, 345] -> 
             RGBColor[
              0.948878961309334, 0.9607989010428017, 0.9505474220278931], 
             UndirectedEdge[32, 333] -> 
             RGBColor[
              0.9887473290155312, 0.9848393129750757, 0.6454464672666779], 
             UndirectedEdge[85, 168] -> 
             RGBColor[
              0.9757265156353713, 0.9292630563551547, 0.40432795649835707`], 
             UndirectedEdge[23, 354] -> 
             RGBColor[
              0.9573254156183779, 0.8748556724002543, 0.5872265807397798], 
             UndirectedEdge[51, 373] -> 
             RGBColor[
              0.9920402679665141, 0.988660996545645, 0.6132671032584014], 
             UndirectedEdge[55, 334] -> 
             RGBColor[
              0.9447769878014328, 0.8498243726083978, 0.5963474857699472], 
             UndirectedEdge[66, 267] -> 
             RGBColor[
              0.979979488526803, 0.9441282551405773, 0.37672452279332846`], 
             UndirectedEdge[30, 153] -> 
             RGBColor[
              0.9935852575693603, 0.9886878395078365, 0.5431730575053609], 
             UndirectedEdge[179, 290] -> 
             RGBColor[
              0.844957285359903, 0.8754348373210219, 0.7361383619865132], 
             UndirectedEdge[178, 200] -> 
             RGBColor[
              0.9848433603436102, 0.9615057718851494, 0.560023377888915], 
             UndirectedEdge[340, 358] -> 
             RGBColor[
              0.9933410812876806, 0.9913567449186181, 0.7485606227184227], 
             UndirectedEdge[31, 259] -> 
             RGBColor[
              0.9925449298170758, 0.9896315961280485, 0.6602862870429655], 
             UndirectedEdge[92, 146] -> 
             RGBColor[
              0.9822723753003157, 0.9828182889380834, 0.7023672705072764], 
             UndirectedEdge[3, 373] -> 
             RGBColor[
              0.9636249119133038, 0.8825997555964044, 0.3509960231076391], 
             UndirectedEdge[174, 341] -> 
             RGBColor[
              0.9947657368651857, 0.9912127653568417, 0.6716609437821996], 
             UndirectedEdge[248, 260] -> 
             RGBColor[
              0.8925531780501588, 0.5799105531454662, 0.23095640118044314`], 
             UndirectedEdge[41, 325] -> 
             RGBColor[
              0.9897809664033883, 0.9900421812376862, 0.8190193629144502], 
             UndirectedEdge[66, 346] -> 
             RGBColor[
              0.9565408495875072, 0.8582318289158526, 0.3212530576339523], 
             UndirectedEdge[53, 142] -> 
             RGBColor[
              0.9595394885630775, 0.8654623772250721, 0.4033351224514051], 
             UndirectedEdge[38, 44] -> 
             RGBColor[
              0.9830533348545405, 0.9566684940149801, 0.5613700320229595], 
             UndirectedEdge[76, 187] -> 
             RGBColor[
              0.9420518863085886, 0.9535703233771513, 0.8723917536079979], 
             UndirectedEdge[156, 160] -> 
             RGBColor[
              0.96365049404028, 0.896482986327629, 0.5754359779687227], 
             UndirectedEdge[141, 290] -> 
             RGBColor[
              0.975634185303355, 0.929036780240128, 0.39672653749655157`], 
             UndirectedEdge[3, 79] -> 
             RGBColor[
              0.9632095847811564, 0.8847434711036363, 0.5261888543895221], 
             UndirectedEdge[301, 382] -> 
             RGBColor[
              0.992256065384905, 0.9890072094078584, 0.6283701574074239], 
             UndirectedEdge[193, 389] -> 
             RGBColor[
              0.8529875233369446, 0.8828035868828362, 0.8246800390186122], 
             UndirectedEdge[189, 291] -> 
             RGBColor[
              0.9750307358166774, 0.9746081623772043, 0.6857183475920602], 
             UndirectedEdge[161, 196] -> 
             RGBColor[
              0.9734891138617896, 0.929912848754601, 0.5622770686550811], 
             UndirectedEdge[83, 161] -> 
             RGBColor[
              0.9587380619822974, 0.9196994529534843, 0.6225311746109645], 
             UndirectedEdge[100, 211] -> 
             RGBColor[
              0.9865224616756902, 0.9653732143188645, 0.4723819939309726], 
             UndirectedEdge[32, 287] -> 
             RGBColor[
              0.9889799048938368, 0.9897109217171447, 0.8322950252084529], 
             UndirectedEdge[156, 181] -> 
             RGBColor[
              0.9692356496349259, 0.918626267117628, 0.5799299252606263], 
             UndirectedEdge[126, 176] -> 
             RGBColor[
              0.8869051268218608, 0.696343564802808, 0.5984053762558557], 
             UndirectedEdge[46, 350] -> 
             RGBColor[
              0.973413075274584, 0.9749348152395643, 0.6917111091587063], 
             UndirectedEdge[47, 149] -> 
             RGBColor[
              0.9904486194163195, 0.9901201709501637, 0.7935547029824628], 
             UndirectedEdge[57, 108] -> 
             RGBColor[
              0.9279875086323811, 0.9412660893244107, 0.7947106582245362], 
             UndirectedEdge[105, 400] -> 
             RGBColor[
              0.9814285998575527, 0.9843974951197902, 0.8593326290162796], 
             UndirectedEdge[62, 256] -> 
             RGBColor[
              0.984545949256048, 0.9583199745787326, 0.4975262056995211], 
             UndirectedEdge[193, 332] -> 
             RGBColor[
              0.9908603068550763, 0.9794021273639181, 0.5405643644645478], 
             UndirectedEdge[1, 387] -> 
             RGBColor[
              0.9941675104256242, 0.9899332194925912, 0.6065476876615905], 
             UndirectedEdge[72, 284] -> 
             RGBColor[
              0.9886458876169026, 0.9876971695948095, 0.7015384966289552], 
             UndirectedEdge[127, 394] -> 
             RGBColor[
              0.9346326058749419, 0.8422411876592097, 0.6135056842034923], 
             UndirectedEdge[110, 385] -> 
             RGBColor[
              0.9801961634324794, 0.9796386482342027, 0.6794755483932454], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.9903269162321766, 0.97867266065608, 0.44752543882211665`], 
             UndirectedEdge[97, 393] -> 
             RGBColor[
              0.9576872018734206, 0.8579092931297557, 0.4142349934422702], 
             UndirectedEdge[19, 150] -> 
             RGBColor[
              0.9786665380435067, 0.9382086108941945, 0.49838691524592316`], 
             UndirectedEdge[272, 342] -> 
             RGBColor[
              0.9328666649658122, 0.7503120135317843, 0.38809271476024965`], 
             UndirectedEdge[96, 187] -> 
             RGBColor[
              0.8957806188578158, 0.7796079600432464, 0.6142932942919536], 
             UndirectedEdge[129, 333] -> 
             RGBColor[
              0.9927635572118333, 0.9859385581812407, 0.5380670804437278], 
             UndirectedEdge[19, 160] -> 
             RGBColor[
              0.9680396569780948, 0.8979844101130621, 0.47990020662262867`], 
             UndirectedEdge[183, 357] -> 
             RGBColor[
              0.966847012914859, 0.9742271610604697, 0.9155684144028553], 
             UndirectedEdge[197, 217] -> 
             RGBColor[
              0.9856357059866203, 0.9804877757685664, 0.6634585360353156], 
             UndirectedEdge[199, 345] -> 
             RGBColor[
              0.855410669090558, 0.8877279206115114, 0.986022555955107], 
             UndirectedEdge[44, 346] -> 
             RGBColor[
              0.9627570597216739, 0.8813719987714499, 0.5181060568659488], 
             UndirectedEdge[78, 80] -> 
             RGBColor[
              0.992792086546922, 0.9912873567992952, 0.7691173096069628], 
             UndirectedEdge[42, 320] -> 
             RGBColor[
              0.981684137272602, 0.9483988646523467, 0.5091587974705116], 
             UndirectedEdge[161, 332] -> 
             RGBColor[
              0.9724723708265504, 0.9188049843825654, 0.3475607881280691], 
             UndirectedEdge[239, 309] -> 
             RGBColor[
              0.9571407960198152, 0.8554675810452136, 0.43009174695108027`], 
             UndirectedEdge[8, 377] -> 
             RGBColor[
              0.980952778639061, 0.9472264847909341, 0.396228679861592], 
             UndirectedEdge[75, 126] -> 
             RGBColor[
              0.9520133364232106, 0.9568677212964793, 0.7047763137087071], 
             UndirectedEdge[54, 310] -> 
             RGBColor[
              0.9787611258524485, 0.9827164116290954, 0.8776549089677661], 
             UndirectedEdge[65, 211] -> 
             RGBColor[
              0.987087162248954, 0.9665810517450897, 0.5338461664027666], 
             UndirectedEdge[88, 356] -> 
             RGBColor[
              0.9426736996575763, 0.8036617647504327, 0.3079674132018669], 
             UndirectedEdge[98, 158] -> 
             RGBColor[
              0.9792572822402982, 0.9457579055385399, 0.5597170260955331], 
             UndirectedEdge[13, 390] -> 
             RGBColor[
              0.9776068117606169, 0.9353060690882309, 0.5195443864175758], 
             UndirectedEdge[241, 242] -> 
             RGBColor[
              0.9936992759702283, 0.9889317133382645, 0.5555832567998353], 
             UndirectedEdge[12, 238] -> 
             RGBColor[
              0.875842233357877, 0.794540270035515, 0.619139230666802], 
             UndirectedEdge[175, 343] -> 
             RGBColor[
              0.929599327435779, 0.9422058547996557, 0.7668606859629583], 
             UndirectedEdge[59, 258] -> 
             RGBColor[
              0.9915022489203478, 0.9907539757933918, 0.7904932570720726], 
             UndirectedEdge[152, 156] -> 
             RGBColor[
              0.9135191257371528, 0.932254973564475, 0.9320219640645637], 
             UndirectedEdge[39, 258] -> 
             RGBColor[
              0.9745581966986048, 0.9799247381266718, 0.9001235301671351], 
             UndirectedEdge[183, 368] -> 
             RGBColor[
              0.9899364717473833, 0.9873527453278232, 0.6397131495361303], 
             UndirectedEdge[44, 119] -> 
             RGBColor[
              0.9650035858135646, 0.9720141841787351, 0.8811546980740762], 
             UndirectedEdge[149, 264] -> 
             RGBColor[
              0.9921830535207303, 0.9908374040252609, 0.7648106413007967], 
             UndirectedEdge[120, 241] -> 
             RGBColor[
              0.9938927901465391, 0.9893456205941089, 0.576646080660204], 
             UndirectedEdge[116, 304] -> 
             RGBColor[
              0.7949462433972412, 0.8370055791073155, 0.8414082100823153], 
             UndirectedEdge[82, 256] -> 
             RGBColor[
              0.9946620329078446, 0.990990953078168, 0.660373408012285], 
             UndirectedEdge[98, 186] -> 
             RGBColor[
              0.9924201369674833, 0.9911335460895292, 0.775281476712916], 
             UndirectedEdge[72, 262] -> 
             RGBColor[
              0.9596503388172086, 0.8663747145078744, 0.3754433988526009], 
             UndirectedEdge[147, 241] -> 
             RGBColor[
              0.961015453073335, 0.8701831016750985, 0.4714482595199899], 
             UndirectedEdge[13, 205] -> 
             RGBColor[
              0.9159356851051204, 0.9325436061087669, 0.8611132786884147], 
             UndirectedEdge[142, 394] -> 
             RGBColor[
              0.9370062389954661, 0.8516518520157397, 0.6154155651285964], 
             UndirectedEdge[42, 75] -> 
             RGBColor[
              0.9927455302585333, 0.9857115405324759, 0.5521302204520642], 
             UndirectedEdge[56, 341] -> 
             RGBColor[
              0.9609985005929476, 0.8703197611151778, 0.45937065771587476`], 
             UndirectedEdge[306, 378] -> 
             RGBColor[
              0.9906700881748864, 0.9800368587747382, 0.43129094543899843`], 
             UndirectedEdge[27, 295] -> 
             RGBColor[
              0.9913528709383708, 0.988527487097471, 0.6356167583527474], 
             UndirectedEdge[111, 247] -> 
             RGBColor[
              0.988401649609139, 0.9767850413615762, 0.5964924909273843], 
             UndirectedEdge[128, 259] -> 
             RGBColor[
              0.924973003129808, 0.7201048607141891, 0.4961131910067805], 
             UndirectedEdge[52, 68] -> 
             RGBColor[
              0.9593861624295978, 0.8828046652207262, 0.5878023724463446], 
             UndirectedEdge[241, 359] -> 
             RGBColor[
              0.9949331645185353, 0.9915708761778241, 0.689884410605607], 
             UndirectedEdge[361, 382] -> 
             RGBColor[
              0.9880326942755147, 0.9750032490844865, 0.5913459293335316], 
             UndirectedEdge[14, 390] -> 
             RGBColor[
              0.9562822155963537, 0.8630278486018474, 0.2907269145330802], 
             UndirectedEdge[11, 332] -> 
             RGBColor[
              0.9377641843133018, 0.7773203741998126, 0.31619692696664903`], 
             UndirectedEdge[22, 209] -> 
             RGBColor[
              0.9537977531730573, 0.8545305178569045, 0.28168279157816656`], 
             UndirectedEdge[33, 156] -> 
             RGBColor[
              0.9794205256177924, 0.9540562414552444, 0.6139028551290501], 
             UndirectedEdge[283, 332] -> 
             RGBColor[
              0.99059159244657, 0.9788273744153173, 0.5113164594117362], 
             UndirectedEdge[150, 181] -> 
             RGBColor[
              0.9573728753172241, 0.8667968443746595, 0.29449548944737136`], 
             UndirectedEdge[117, 323] -> 
             RGBColor[
              0.9949320828234094, 0.9915685625413262, 0.6897666747666125], 
             UndirectedEdge[199, 223] -> 
             RGBColor[
              0.8928532156803438, 0.9155406258108525, 0.9118266770490117], 
             UndirectedEdge[128, 306] -> 
             RGBColor[
              0.9234630489526949, 0.7112905807528949, 0.3068335981519462], 
             UndirectedEdge[184, 288] -> 
             RGBColor[
              0.9910174902129918, 0.989594046165283, 0.728783663399412], 
             UndirectedEdge[145, 182] -> 
             RGBColor[
              0.925841932101518, 0.7157007287355803, 0.4205106222905005], 
             UndirectedEdge[284, 397] -> 
             RGBColor[
              0.9855020674426205, 0.9882710892100462, 0.8898575728492182], 
             UndirectedEdge[61, 148] -> 
             RGBColor[
              0.9454392869671104, 0.8184191475196436, 0.29043995974344694`], 
             UndirectedEdge[34, 159] -> 
             RGBColor[
              0.9869944639779931, 0.9888898908749393, 0.8651989193403636], 
             UndirectedEdge[276, 382] -> 
             RGBColor[
              0.9928765831600525, 0.9903344341849281, 0.6959096878404127], 
             UndirectedEdge[59, 164] -> 
             RGBColor[
              0.9937882187867734, 0.9893028812304576, 0.5784157037342125], 
             UndirectedEdge[80, 377] -> 
             RGBColor[
              0.9919979333149773, 0.9888200129666445, 0.6268000484337193], 
             UndirectedEdge[180, 370] -> 
             RGBColor[
              0.9770545464541867, 0.9342617387205838, 0.36536167517017637`], 
             UndirectedEdge[98, 374] -> 
             RGBColor[
              0.988334652744183, 0.9763780077160937, 0.5949808963855424], 
             UndirectedEdge[139, 350] -> 
             RGBColor[
              0.9368646393722098, 0.8406175104562421, 0.6071761837686637], 
             UndirectedEdge[36, 276] -> 
             RGBColor[
              0.9900513413929573, 0.9891661241088325, 0.7427312554124976], 
             UndirectedEdge[53, 281] -> 
             RGBColor[
              0.9793984099457418, 0.9414739944734452, 0.4334923220156488], 
             UndirectedEdge[73, 183] -> 
             RGBColor[
              0.9901023679538488, 0.9878561888905388, 0.6451333462644506], 
             UndirectedEdge[101, 115] -> 
             RGBColor[
              0.9493932362694275, 0.9100668109618879, 0.6326958742995754], 
             UndirectedEdge[283, 366] -> 
             RGBColor[
              0.9897986619554415, 0.976152633679808, 0.508236074186061], 
             UndirectedEdge[22, 141] -> 
             RGBColor[
              0.9552934903405373, 0.8598397412776111, 0.28611982969586736`], 
             UndirectedEdge[197, 314] -> 
             RGBColor[
              0.9796310600143033, 0.9760095206341177, 0.6736228354039588], 
             UndirectedEdge[13, 14] -> 
             RGBColor[
              0.9733515878267414, 0.9197882590251356, 0.5090754671861356], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.9942489320175041, 0.9901613451270593, 0.6193331987852146], 
             UndirectedEdge[323, 395] -> 
             RGBColor[
              0.9950172649021449, 0.9917507583945123, 0.6990382183541225], 
             UndirectedEdge[93, 131] -> 
             RGBColor[
              0.6578482921352986, 0.7236884832356909, 0.8919221776971993], 
             UndirectedEdge[52, 105] -> 
             RGBColor[
              0.9880868608790766, 0.9893416250668572, 0.8470950756568538], 
             UndirectedEdge[178, 330] -> 
             RGBColor[
              0.912783900948993, 0.9070781448726081, 0.6738052806158072], 
             UndirectedEdge[92, 98] -> 
             RGBColor[
              0.9814953956172607, 0.9845264230243034, 0.8627623464040761], 
             UndirectedEdge[37, 323] -> 
             RGBColor[
              0.9910320345890663, 0.9901694219411012, 0.7699291816592564], 
             UndirectedEdge[279, 370] -> 
             RGBColor[
              0.9850705706449812, 0.9613009521668412, 0.39656350311141997`], 
             UndirectedEdge[150, 160] -> 
             RGBColor[
              0.9517877197225783, 0.8446535635846606, 0.29000154215546786`], 
             UndirectedEdge[188, 273] -> 
             RGBColor[
              0.9919317487345154, 0.9897521576342194, 0.6976434145126984], 
             UndirectedEdge[179, 386] -> 
             RGBColor[
              0.8450695412016715, 0.8756749412157578, 0.7483567176002563], 
             UndirectedEdge[141, 179] -> 
             RGBColor[
              0.8273856687879022, 0.8165953954139329, 0.6309932525409865], 
             UndirectedEdge[117, 388] -> 
             RGBColor[
              0.9910212859539433, 0.9798125519139048, 0.55246472336121], 
             UndirectedEdge[198, 214] -> 
             RGBColor[
              0.9927386727876448, 0.9868770802625985, 0.4510275285312891], 
             UndirectedEdge[150, 238] -> 
             RGBColor[
              0.9411947055024408, 0.8026557921145483, 0.28147815426394385`], 
             UndirectedEdge[331, 392] -> 
             RGBColor[
              0.9523487713728378, 0.8361958161041738, 0.4423897122729948], 
             UndirectedEdge[323, 365] -> 
             RGBColor[
              0.9539610286560041, 0.8422482918360171, 0.4637819281752388], 
             UndirectedEdge[6, 71] -> 
             RGBColor[
              0.9863610282734968, 0.9650728107434878, 0.45099417028187816`], 
             UndirectedEdge[132, 249] -> 
             RGBColor[
              0.9911738043837401, 0.9811496608141261, 0.4831068454043602], 
             UndirectedEdge[348, 378] -> 
             RGBColor[
              0.9907928475957278, 0.9882774980550348, 0.6435599453502061], 
             UndirectedEdge[174, 198] -> 
             RGBColor[
              0.9937378029632131, 0.9890141186805825, 0.559776682225194], 
             UndirectedEdge[72, 236] -> 
             RGBColor[
              0.9764385648989775, 0.9785929682994374, 0.7222023098107258], 
             UndirectedEdge[9, 100] -> 
             RGBColor[
              0.9937960212830392, 0.9891386417799155, 0.5661133870564462], 
             UndirectedEdge[51, 298] -> 
             RGBColor[
              0.9766580888293253, 0.9368319159684593, 0.5485254876722527], 
             UndirectedEdge[23, 128] -> 
             RGBColor[
              0.8943953793555982, 0.605694922956246, 0.2331982983438288], 
             UndirectedEdge[215, 353] -> 
             RGBColor[
              0.9783844246810517, 0.9735272280091485, 0.6724372854621037], 
             UndirectedEdge[80, 96] -> 
             RGBColor[
              0.9461362473873651, 0.8171659631807661, 0.5173921987451472], 
             UndirectedEdge[78, 388] -> 
             RGBColor[
              0.9906995579915532, 0.9798931387047687, 0.5733252029515802], 
             UndirectedEdge[312, 380] -> 
             RGBColor[
              0.8457285877274391, 0.876859901598023, 0.8020946618048694], 
             UndirectedEdge[57, 325] -> 
             RGBColor[
              0.9922063243383119, 0.9900534692064537, 0.7067417015301378], 
             UndirectedEdge[308, 374] -> 
             RGBColor[
              0.988359432461519, 0.9723957737367792, 0.40927902256007354`], 
             UndirectedEdge[76, 365] -> 
             RGBColor[
              0.95335701327467, 0.8423886240956968, 0.5021487699434735], 
             UndirectedEdge[182, 187] -> 
             RGBColor[
              0.9424719614369191, 0.9530365615155094, 0.8140041504479927], 
             UndirectedEdge[74, 286] -> 
             RGBColor[
              0.9928793040898747, 0.9908911646505478, 0.7362512343953298], 
             UndirectedEdge[137, 164] -> 
             RGBColor[
              0.9925596560812487, 0.9887948389791018, 0.5987761671831188], 
             UndirectedEdge[149, 258] -> 
             RGBColor[
              0.9914922952678217, 0.9905517577360057, 0.7762582931765484], 
             UndirectedEdge[147, 331] -> 
             RGBColor[
              0.9608110353189832, 0.8697458727683451, 0.4491986484789276], 
             UndirectedEdge[42, 367] -> 
             RGBColor[
              0.9860758444098437, 0.9632131240481363, 0.5262197503943926], 
             UndirectedEdge[16, 365] -> 
             RGBColor[
              0.9530783588630536, 0.8403603504005015, 0.3677087684191012], 
             UndirectedEdge[113, 183] -> 
             RGBColor[
              0.9323122218846704, 0.761787269071972, 0.5370376445545659], 
             UndirectedEdge[16, 323] -> 
             RGBColor[
              0.9939471287406187, 0.9894618453523705, 0.5825605012868393], 
             UndirectedEdge[340, 343] -> 
             RGBColor[
              0.930340224398909, 0.943790558487617, 0.8475027481136059], 
             UndirectedEdge[323, 362] -> 
             RGBColor[
              0.9947200385285263, 0.9911150212355382, 0.6666869618542864], 
             UndirectedEdge[334, 364] -> 
             RGBColor[
              0.751584761582829, 0.6976349306661025, 0.6076678186238431], 
             UndirectedEdge[94, 324] -> 
             RGBColor[
              0.9910117124069803, 0.9888226716253585, 0.6729823053873942], 
             UndirectedEdge[135, 350] -> 
             RGBColor[
              0.9710737845036753, 0.9774678012256328, 0.9123687800596574], 
             UndirectedEdge[31, 215] -> 
             RGBColor[
              0.9906725878042366, 0.9795948969041401, 0.46959888587753595`], 
             UndirectedEdge[3, 21] -> 
             RGBColor[
              0.9607900478149647, 0.8837429303888522, 0.5662868434802677], 
             UndirectedEdge[127, 193] -> 
             RGBColor[
              0.9577617521917225, 0.8573262757606117, 0.4662849252249092], 
             UndirectedEdge[50, 230] -> 
             RGBColor[
              0.9904532608048844, 0.989483462116605, 0.747056257122555], 
             UndirectedEdge[169, 382] -> 
             RGBColor[
              0.9701397829425469, 0.9124876190514497, 0.5330775743852245], 
             UndirectedEdge[12, 19] -> 
             RGBColor[
              0.9133140658989429, 0.9300930888151612, 0.8360479916487813], 
             UndirectedEdge[133, 296] -> 
             RGBColor[
              0.9436701935547377, 0.8193657688211945, 0.5718399731465977], 
             UndirectedEdge[214, 332] -> 
             RGBColor[
              0.989895495408021, 0.9773384932360675, 0.43555059257863554`], 
             UndirectedEdge[76, 395] -> 
             RGBColor[
              0.994413249520811, 0.991891090654192, 0.7374050601223572], 
             UndirectedEdge[299, 370] -> 
             RGBColor[
              0.977881752414028, 0.9370520986603246, 0.368575214119422], 
             UndirectedEdge[170, 235] -> 
             RGBColor[
              0.9829799740563923, 0.954249597379387, 0.38838084248163485`], 
             UndirectedEdge[46, 400] -> 
             RGBColor[
              0.9813815659961894, 0.9808777025725315, 0.6782225328822602], 
             UndirectedEdge[65, 329] -> 
             RGBColor[
              0.9532586550207113, 0.9619789268669379, 0.8427038256164956], 
             UndirectedEdge[81, 267] -> 
             RGBColor[
              0.9871554389019598, 0.967055537836454, 0.5133487066379028], 
             UndirectedEdge[104, 182] -> 
             RGBColor[
              0.9773440157394833, 0.9340292051410938, 0.4692892644983585], 
             UndirectedEdge[23, 306] -> 
             RGBColor[
              0.959521115293466, 0.8675737755378053, 0.33653471362921805`], 
             UndirectedEdge[209, 286] -> 
             RGBColor[
              0.974926016560687, 0.9254120860447119, 0.4780114621107184], 
             UndirectedEdge[150, 167] -> 
             RGBColor[
              0.9779927392325454, 0.9367674233690579, 0.4250480728770255], 
             UndirectedEdge[4, 288] -> 
             RGBColor[
              0.9435380389160424, 0.9558601683232479, 0.9205089155717172], 
             UndirectedEdge[171, 272] -> 
             RGBColor[
              0.9934549103107508, 0.9884090399018004, 0.52898556281576], 
             UndirectedEdge[78, 182] -> 
             RGBColor[
              0.9944264146080157, 0.9912557197302281, 0.6906063929652122], 
             UndirectedEdge[143, 374] -> 
             RGBColor[
              0.9891984801514164, 0.97485563213024, 0.4440386593035536], 
             UndirectedEdge[55, 262] -> 
             RGBColor[
              0.9475150163404815, 0.8606797433718031, 0.5985505678022559], 
             UndirectedEdge[165, 190] -> 
             RGBColor[
              0.9906945303745752, 0.9903914182616509, 0.8018043122067617], 
             UndirectedEdge[2, 149] -> 
             RGBColor[
              0.9755227325432455, 0.9275211835420101, 0.49320035533154905`], 
             UndirectedEdge[39, 47] -> 
             RGBColor[
              0.9735145208471025, 0.9794931513408298, 0.9174199399730495], 
             UndirectedEdge[230, 300] -> 
             RGBColor[
              0.9807765508744204, 0.9457004224808692, 0.4747610057469508], 
             UndirectedEdge[40, 48] -> 
             RGBColor[
              0.8517828098812049, 0.8827043807996297, 0.8736464487330302], 
             UndirectedEdge[25, 208] -> 
             RGBColor[
              0.9944380228057188, 0.9918350077350504, 0.7321732074956663], 
             UndirectedEdge[32, 52] -> 
             RGBColor[
              0.9854602727600078, 0.9882554633793865, 0.8906244381819802], 
             UndirectedEdge[161, 366] -> 
             RGBColor[
              0.9716794403354219, 0.9161302436470561, 0.3444804029023938], 
             UndirectedEdge[190, 318] -> 
             RGBColor[
              0.9830905461805299, 0.9664360825751652, 0.6281601919900561], 
             UndirectedEdge[179, 245] -> 
             RGBColor[
              0.8447269395553975, 0.877130691697434, 0.8701504525888959], 
             UndirectedEdge[37, 182] -> 
             RGBColor[
              0.9908480943360629, 0.9897759923391392, 0.7499084202674857], 
             UndirectedEdge[12, 206] -> 
             RGBColor[
              0.9133456791821433, 0.9301607064313332, 0.839488902430553], 
             UndirectedEdge[18, 218] -> 
             RGBColor[
              0.9877631997002088, 0.980683951477286, 0.6358472445049848], 
             UndirectedEdge[92, 119] -> 
             RGBColor[
              0.9544833411963434, 0.9655743309076972, 0.9619320100954147], 
             UndirectedEdge[215, 400] -> 
             RGBColor[
              0.9794347210093918, 0.974310537291122, 0.6706594077393782], 
             UndirectedEdge[71, 292] -> 
             RGBColor[
              0.9935282234636286, 0.988565849322709, 0.536965247070158], 
             UndirectedEdge[158, 346] -> 
             RGBColor[
              0.94999870172749, 0.8361636280146485, 0.2958380485787444], 
             UndirectedEdge[92, 151] -> 
             RGBColor[
              0.982729968395034, 0.9837970342979272, 0.7521734549301333], 
             UndirectedEdge[104, 170] -> 
             RGBColor[
              0.9669418185109324, 0.9001491327865494, 0.3260756367390633], 
             UndirectedEdge[82, 316] -> 
             RGBColor[
              0.9838374950684509, 0.9853282758519583, 0.8062572701528947], 
             UndirectedEdge[287, 353] -> 
             RGBColor[
              0.9801330296266859, 0.9835127587758701, 0.8651753300523839], 
             UndirectedEdge[368, 372] -> 
             RGBColor[
              0.9390694717874795, 0.9486994169686986, 0.7067087405683692], 
             UndirectedEdge[9, 203] -> 
             RGBColor[
              0.9932910572774643, 0.9880585748316831, 0.5111511713262136], 
             UndirectedEdge[17, 384] -> 
             RGBColor[
              0.9667576217042355, 0.9642883757435916, 0.6909135192803425], 
             UndirectedEdge[82, 310] -> 
             RGBColor[
              0.9924265963928516, 0.9907697622324327, 0.7485370176418769], 
             UndirectedEdge[129, 287] -> 
             RGBColor[
              0.9929961330901389, 0.9908101669233097, 0.7249156383855028], 
             UndirectedEdge[81, 363] -> 
             RGBColor[
              0.9865117714309307, 0.9871262939357244, 0.7861427245573325], 
             UndirectedEdge[64, 356] -> 
             RGBColor[
              0.9865007644652413, 0.9651034888221843, 0.4890096826070164], 
             UndirectedEdge[245, 352] -> 
             RGBColor[
              0.9926759665703501, 0.9889314987650923, 0.6032861536499601], 
             UndirectedEdge[87, 232] -> 
             RGBColor[
              0.988470191989236, 0.9713506025985632, 0.5303528806875764], 
             UndirectedEdge[88, 255] -> 
             RGBColor[
              0.9148574931817033, 0.7001453630635969, 0.2503505443437441], 
             UndirectedEdge[154, 392] -> 
             RGBColor[
              0.8663003601313979, 0.7715149218173205, 0.6147768544061055], 
             UndirectedEdge[22, 45] -> 
             RGBColor[
              0.9549330512643189, 0.8586238956384069, 0.28471959194796725`], 
             UndirectedEdge[116, 141] -> 
             RGBColor[
              0.9766434808171297, 0.9311955612886622, 0.506582125521028], 
             UndirectedEdge[97, 224] -> 
             RGBColor[
              0.9086936266941694, 0.585568980900888, 0.37146330550977436`], 
             UndirectedEdge[66, 151] -> 
             RGBColor[
              0.9870340028780886, 0.9670967177133678, 0.4745431436767983], 
             UndirectedEdge[165, 221] -> 
             RGBColor[
              0.9945451078601895, 0.9907408622241691, 0.6476468381527594], 
             UndirectedEdge[101, 332] -> 
             RGBColor[
              0.9714587264138794, 0.9153857237636001, 0.34362297099552797`], 
             UndirectedEdge[58, 396] -> 
             RGBColor[
              0.9926233482570055, 0.9909985576065885, 0.7559931834710265], 
             UndirectedEdge[35, 387] -> 
             RGBColor[
              0.9950067670656948, 0.9917283045838396, 0.6978955936416651], 
             UndirectedEdge[198, 266] -> 
             RGBColor[
              0.9932423050562478, 0.9891489788388601, 0.592685422951942], 
             UndirectedEdge[188, 264] -> 
             RGBColor[
              0.9916142922742606, 0.9896208812296451, 0.7029044896101044], 
             UndirectedEdge[119, 151] -> 
             RGBColor[
              0.9655980996277587, 0.9710201146221538, 0.7811732400461411], 
             UndirectedEdge[247, 400] -> 
             RGBColor[
              0.9811293397105605, 0.9842737433583739, 0.8642921441123756], 
             UndirectedEdge[305, 361] -> 
             RGBColor[
              0.9854867822206013, 0.9739504490228245, 0.6335382806926404], 
             UndirectedEdge[138, 210] -> 
             RGBColor[
              0.8948710300152556, 0.8174484674550594, 0.6226863234390058], 
             UndirectedEdge[197, 231] -> 
             RGBColor[
              0.9917993488755683, 0.9827342948648552, 0.530219518068283], 
             UndirectedEdge[225, 261] -> 
             RGBColor[
              0.9573133679890147, 0.8633953544195575, 0.310933915552465], 
             UndirectedEdge[83, 286] -> 
             RGBColor[
              0.977106706559004, 0.9802553334700604, 0.8134349954699543], 
             UndirectedEdge[19, 238] -> 
             RGBColor[
              0.9574466427579573, 0.8559866386429498, 0.4713768187311047], 
             UndirectedEdge[62, 117] -> 
             RGBColor[
              0.9848297081750093, 0.9589269062139634, 0.5284116128714049], 
             UndirectedEdge[65, 167] -> 
             RGBColor[
              0.9942708459043184, 0.9901542436326984, 0.6177951168047948], 
             UndirectedEdge[268, 371] -> 
             RGBColor[
              0.5684326779003908, 0.6367725375713098, 0.9447922857911148], 
             UndirectedEdge[172, 192] -> 
             RGBColor[
              0.8502169211734394, 0.8820568455774644, 0.8995972770107796], 
             UndirectedEdge[52, 353] -> 
             RGBColor[
              0.976613397492857, 0.9820573004381117, 0.9235047430259111], 
             UndirectedEdge[126, 298] -> 
             RGBColor[
              0.9376347971381502, 0.9083655320463977, 0.6489184037455538], 
             UndirectedEdge[146, 306] -> 
             RGBColor[
              0.9907591627637876, 0.9802273803135753, 0.44098616473624064`], 
             UndirectedEdge[21, 132] -> 
             RGBColor[
              0.9903148575962779, 0.9888994471036402, 0.7110584857280301], 
             UndirectedEdge[89, 162] -> 
             RGBColor[
              0.9869979375088406, 0.971617981954533, 0.588053305170184], 
             UndirectedEdge[9, 18] -> 
             RGBColor[
              0.991056873083298, 0.9807248773356685, 0.4852330575541663], 
             UndirectedEdge[255, 360] -> 
             RGBColor[
              0.9207028997734511, 0.7233204523336012, 0.2550538956967918], 
             UndirectedEdge[124, 152] -> 
             RGBColor[
              0.8894651795262797, 0.8339994581773252, 0.6268421545093741], 
             UndirectedEdge[88, 389] -> 
             RGBColor[
              0.8088306280515201, 0.7206563887701337, 0.6077377575871037], 
             UndirectedEdge[12, 167] -> 
             RGBColor[
              0.9126402670879816, 0.9286519012900247, 0.7627091492798836], 
             UndirectedEdge[32, 303] -> 
             RGBColor[
              0.989964483482181, 0.9884344306545418, 0.693595183646468], 
             UndirectedEdge[49, 261] -> 
             RGBColor[
              0.9623068533239983, 0.8802395529805704, 0.33033266313829585`], 
             UndirectedEdge[283, 360] -> 
             RGBColor[
              0.9562393185264355, 0.851780943736052, 0.43602824822951874`], 
             UndirectedEdge[282, 305] -> 
             RGBColor[
              0.9906929568500691, 0.9900565266989635, 0.7775346067666972], 
             UndirectedEdge[32, 385] -> 
             RGBColor[
              0.9890430386996303, 0.9858368111754774, 0.6465952435493145], 
             UndirectedEdge[167, 216] -> 
             RGBColor[
              0.9419832470978577, 0.9520491970559259, 0.7655079089080132], 
             UndirectedEdge[252, 318] -> 
             RGBColor[
              0.9869823728657507, 0.9668737544047081, 0.47849243875267755`], 
             UndirectedEdge[2, 217] -> 
             RGBColor[
              0.9691093501012296, 0.924740496794251, 0.5992567641610111], 
             UndirectedEdge[305, 329] -> 
             RGBColor[
              0.9490354700557562, 0.9605009872296282, 0.9322068380028217], 
             UndirectedEdge[87, 373] -> 
             RGBColor[
              0.9936999274820736, 0.9889331068562237, 0.5556541698435301], 
             UndirectedEdge[20, 241] -> 
             RGBColor[
              0.9912840430531111, 0.9903054167879133, 0.7680630284091621], 
             UndirectedEdge[59, 210] -> 
             RGBColor[
              0.9599657375525322, 0.866014538317029, 0.4948634318967534], 
             UndirectedEdge[290, 304] -> 
             RGBColor[
              0.7939369478834666, 0.8348467980587814, 0.7315526220578389], 
             UndirectedEdge[115, 312] -> 
             RGBColor[
              0.819904922338746, 0.8600453138578384, 0.9760987583049304], 
             UndirectedEdge[214, 389] -> 
             RGBColor[
              0.8520227118898893, 0.8807399527549856, 0.7196662671326999], 
             UndirectedEdge[144, 276] -> 
             RGBColor[
              0.9753142600937423, 0.9273829546818353, 0.4443471561674665], 
             UndirectedEdge[196, 286] -> 
             RGBColor[
              0.9918577584384962, 0.9904687292711771, 0.753180889514071], 
             UndirectedEdge[124, 181] -> 
             RGBColor[
              0.9451817034240528, 0.8203707517304781, 0.2747501157054366], 
             UndirectedEdge[216, 341] -> 
             RGBColor[
              0.9425194655816709, 0.9531961141727971, 0.8238719817141801], 
             UndirectedEdge[294, 340] -> 
             RGBColor[
              0.9784610900221928, 0.9814871669225428, 0.8287362190855994], 
             UndirectedEdge[104, 235] -> 
             RGBColor[
              0.9762642689968639, 0.9315959472910631, 0.3622915964798529], 
             UndirectedEdge[125, 318] -> 
             RGBColor[
              0.9866519665264938, 0.9661670486542426, 0.44252974775611886`], 
             UndirectedEdge[109, 232] -> 
             RGBColor[
              0.9860602279550335, 0.9707682220875792, 0.6004003017022135], 
             UndirectedEdge[182, 388] -> 
             RGBColor[
              0.9907350614110998, 0.9792003465585026, 0.5213109482458037], 
             UndirectedEdge[97, 382] -> 
             RGBColor[
              0.9927366812594203, 0.9900351981657277, 0.6806822293310523], 
             UndirectedEdge[140, 147] -> 
             RGBColor[
              0.959811603714166, 0.8700436042993058, 0.5174456234453992], 
             UndirectedEdge[59, 300] -> 
             RGBColor[
              0.9811566436784733, 0.9466943307565624, 0.5292833320521145], 
             UndirectedEdge[205, 373] -> 
             RGBColor[
              0.9148965854969837, 0.9297984477673652, 0.7100240624287883], 
             UndirectedEdge[215, 259] -> 
             RGBColor[
              0.9897363512319495, 0.9807612940331341, 0.5980417979815744], 
             UndirectedEdge[136, 300] -> 
             RGBColor[
              0.8933226884546952, 0.8800012860191104, 0.6549360905983527], 
             UndirectedEdge[152, 245] -> 
             RGBColor[
              0.9168216061586283, 0.9336206340886306, 0.8772913169353496], 
             UndirectedEdge[44, 128] -> 
             RGBColor[
              0.9254965061064442, 0.7203213426484409, 0.4874373919016435], 
             UndirectedEdge[241, 392] -> 
             RGBColor[
              0.9525531891271897, 0.8366330450109274, 0.4646393233140571], 
             UndirectedEdge[240, 342] -> 
             RGBColor[
              0.9291966539591221, 0.7501144952864847, 0.5448734915134966], 
             UndirectedEdge[123, 214] -> 
             RGBColor[
              0.9937969025912152, 0.9891405268089899, 0.5662093120125873], 
             UndirectedEdge[125, 274] -> 
             RGBColor[
              0.9935519091661273, 0.9886165106453619, 0.5395432896159396], 
             UndirectedEdge[298, 373] -> 
             RGBColor[
              0.9772158056375421, 0.9347470822515298, 0.3709728909652299], 
             UndirectedEdge[119, 350] -> 
             RGBColor[
              0.9462099618927653, 0.9594040581695038, 0.975936683213463], 
             UndirectedEdge[22, 179] -> 
             RGBColor[
              0.8246165903970853, 0.806237798358505, 0.6255316541858289], 
             UndirectedEdge[1, 183] -> 
             RGBColor[
              0.990348439160031, 0.988382510318947, 0.6719166784819208], 
             UndirectedEdge[112, 260] -> 
             RGBColor[
              0.8699190024286221, 0.48648793364177645`, 0.21255375703994048`],
              UndirectedEdge[183, 270] -> 
             RGBColor[
              0.9398032407183035, 0.9529309734811573, 0.9222731352456893], 
             UndirectedEdge[152, 181] -> 
             RGBColor[
              0.896614625948685, 0.862344630830373, 0.6325947669199178], 
             UndirectedEdge[169, 276] -> 
             RGBColor[
              0.9714000977911466, 0.9120209274945992, 0.4403836015369017], 
             UndirectedEdge[349, 355] -> 
             RGBColor[
              0.9936728711920182, 0.9904125385410738, 0.6644549121515473], 
             UndirectedEdge[171, 240] -> 
             RGBColor[
              0.9897848993040608, 0.9882115216565008, 0.685766339569007], 
             UndirectedEdge[114, 132] -> 
             RGBColor[
              0.9752649714512465, 0.9781298582896484, 0.7568915593559795], 
             UndirectedEdge[17, 222] -> 
             RGBColor[
              0.963041813660847, 0.9719572256585114, 0.9474447486201247], 
             UndirectedEdge[46, 259] -> 
             RGBColor[
              0.9916831962187471, 0.9873284593145436, 0.6056049231244566], 
             UndirectedEdge[13, 79] -> 
             RGBColor[
              0.9932217572507203, 0.9914650366773492, 0.7619965540928878], 
             UndirectedEdge[146, 311] -> 
             RGBColor[
              0.968219783385752, 0.9723378888972093, 0.7261546431156709], 
             UndirectedEdge[44, 275] -> 
             RGBColor[
              0.9933549442342859, 0.9904608970629379, 0.6827954901006552], 
             UndirectedEdge[193, 195] -> 
             RGBColor[
              0.9805139138810681, 0.944501314413992, 0.5003705815128939], 
             UndirectedEdge[86, 297] -> 
             RGBColor[
              0.9850590751375584, 0.9856354310533009, 0.7562727927745632], 
             UndirectedEdge[197, 392] -> 
             RGBColor[
              0.949642774301825, 0.828274295457522, 0.3292902311026946], 
             UndirectedEdge[217, 392] -> 
             RGBColor[
              0.9462326696708763, 0.834050982799698, 0.5808032950533218], 
             UndirectedEdge[101, 193] -> 
             RGBColor[
              0.9754179411874215, 0.927311401927033, 0.4805736898917713], 
             UndirectedEdge[216, 340] -> 
             RGBColor[
              0.9427474452337246, 0.9536837395962611, 0.8486861599128874], 
             UndirectedEdge[125, 190] -> 
             RGBColor[
              0.9897015697693574, 0.9882675759308073, 0.6937266781713348], 
             UndirectedEdge[99, 276] -> 
             RGBColor[
              0.9711087578264095, 0.9108658616177047, 0.44014918256264635`], 
             UndirectedEdge[27, 63] -> 
             RGBColor[
              0.9812971432304137, 0.948406547626979, 0.39599844902283504`], 
             UndirectedEdge[184, 226] -> 
             RGBColor[
              0.9866866613173143, 0.965724420749168, 0.49025411159902954`], 
             UndirectedEdge[107, 211] -> 
             RGBColor[
              0.9783169610271958, 0.9385201595043815, 0.3702659173993287], 
             UndirectedEdge[216, 294] -> 
             RGBColor[
              0.9261092613070834, 0.9432447390658105, 0.9694579820134496], 
             UndirectedEdge[68, 284] -> 
             RGBColor[
              0.9593161971026543, 0.8827740754153333, 0.5888876596975625], 
             UndirectedEdge[89, 359] -> 
             RGBColor[
              0.993272430987131, 0.9912424454554246, 0.7434535276432892], 
             UndirectedEdge[23, 267] -> 
             RGBColor[
              0.9550945719101237, 0.8526420053039798, 0.31933842846751026`], 
             UndirectedEdge[140, 242] -> 
             RGBColor[
              0.9924954266110593, 0.9887922159624718, 0.6015806207252448], 
             UndirectedEdge[64, 214] -> 
             RGBColor[
              0.9935248797038038, 0.9885586973585496, 0.5366012994485199], 
             UndirectedEdge[296, 367] -> 
             RGBColor[
              0.9399453641665647, 0.792857801756961, 0.3032992093144684], 
             UndirectedEdge[275, 346] -> 
             RGBColor[
              0.9634563047578986, 0.8806019387088415, 0.429523946029874], 
             UndirectedEdge[301, 305] -> 
             RGBColor[
              0.9897101533299917, 0.9879544093461963, 0.6705625087665327], 
             UndirectedEdge[81, 119] -> 
             RGBColor[
              0.9659633260545548, 0.9718012970190144, 0.8209258826866541], 
             UndirectedEdge[327, 355] -> 
             RGBColor[
              0.9736395194139893, 0.9770180955567954, 0.7676170117573535], 
             UndirectedEdge[317, 344] -> 
             RGBColor[
              0.8831451052740809, 0.9089863200068213, 0.958979876953125], 
             UndirectedEdge[184, 190] -> 
             RGBColor[
              0.9901549808458253, 0.9892373763764801, 0.7430776757160495], 
             UndirectedEdge[10, 303] -> 
             RGBColor[
              0.8957421757876853, 0.9151929464991762, 0.7479734950113266], 
             UndirectedEdge[149, 268] -> 
             RGBColor[
              0.5869896831198518, 0.6486099183031302, 0.8181798911635094], 
             UndirectedEdge[38, 267] -> 
             RGBColor[
              0.976593334317449, 0.9327059618856084, 0.36356995311155454`], 
             UndirectedEdge[253, 366] -> 
             RGBColor[
              0.9756656229631477, 0.9295765736505652, 0.3599659696836829], 
             UndirectedEdge[165, 355] -> 
             RGBColor[
              0.9945473238671618, 0.9907456020390102, 0.6478880368360863], 
             UndirectedEdge[339, 340] -> 
             RGBColor[
              0.9934579336218188, 0.9914050663617523, 0.7466240771376056], 
             UndirectedEdge[185, 318] -> 
             RGBColor[
              0.9782565292924342, 0.9383163090729845, 0.37003115152135535`], 
             UndirectedEdge[36, 70] -> 
             RGBColor[
              0.9016423923886312, 0.5612957527947937, 0.5232323979164527], 
             UndirectedEdge[69, 131] -> 
             RGBColor[
              0.9859841618380267, 0.988367119335164, 0.8772407688612525], 
             UndirectedEdge[283, 312] -> 
             RGBColor[
              0.8456609128482337, 0.8767151518743828, 0.7947286688443147], 
             UndirectedEdge[75, 330] -> 
             RGBColor[
              0.9199694915402432, 0.9313168291937992, 0.7017199431778917], 
             UndirectedEdge[169, 222] -> 
             RGBColor[
              0.9643318166673416, 0.9093894880174632, 0.5981449411385729], 
             UndirectedEdge[90, 246] -> 
             RGBColor[
              0.9924061675673341, 0.9853292490505681, 0.48597788795748337`], 
             UndirectedEdge[62, 362] -> 
             RGBColor[
              0.9846176638801263, 0.9584733649081753, 0.5053318999590788], 
             UndirectedEdge[158, 374] -> 
             RGBColor[
              0.9762163537135784, 0.9314343177894975, 0.36210545465233046`], 
             UndirectedEdge[82, 172] -> 
             RGBColor[
              0.8530063707928165, 0.8828438996851762, 0.8267314682772612], 
             UndirectedEdge[306, 346] -> 
             RGBColor[
              0.9607236025679246, 0.8723412368759038, 0.33750226311625153`], 
             UndirectedEdge[53, 188] -> 
             RGBColor[
              0.9937712859385222, 0.9890857353791203, 0.5634210974546046], 
             UndirectedEdge[84, 190] -> 
             RGBColor[
              0.9683545054365733, 0.9151328239950578, 0.5792209359555192], 
             UndirectedEdge[78, 96] -> 
             RGBColor[
              0.9477350720289124, 0.817827118257965, 0.4908955368091731], 
             UndirectedEdge[46, 199] -> 
             RGBColor[
              0.8945715347989371, 0.9127508520883081, 0.7014601134500484], 
             UndirectedEdge[159, 265] -> 
             RGBColor[
              0.9901382204094411, 0.9886989987204455, 0.7047248684992509], 
             UndirectedEdge[332, 356] -> 
             RGBColor[
              0.9828713801694585, 0.9538832846997023, 0.3879589757371321], 
             UndirectedEdge[199, 222] -> 
             RGBColor[
              0.8886928530831055, 0.9131238212391886, 0.9495889869968099], 
             UndirectedEdge[114, 300] -> 
             RGBColor[
              0.9620347490500905, 0.93424086178886, 0.6426001242693481], 
             UndirectedEdge[139, 213] -> 
             RGBColor[
              0.85840740133813, 0.7787337672931448, 0.6169634917358706], 
             UndirectedEdge[106, 369] -> 
             RGBColor[
              0.9654702498744416, 0.9727693463280546, 0.8985966404372648], 
             UndirectedEdge[109, 114] -> 
             RGBColor[
              0.9734052132045005, 0.9787243123236956, 0.8868254848587453], 
             UndirectedEdge[58, 245] -> 
             RGBColor[
              0.9914818449557881, 0.9907455382296884, 0.7908314035685942], 
             UndirectedEdge[151, 317] -> 
             RGBColor[
              0.9813747834847212, 0.9827863396107275, 0.754467429494461], 
             UndirectedEdge[99, 218] -> 
             RGBColor[
              0.9676219502295291, 0.9104118412048874, 0.5697419022285095], 
             UndirectedEdge[55, 57] -> 
             RGBColor[
              0.9814858021023571, 0.9830695842788538, 0.7701841291179398], 
             UndirectedEdge[247, 287] -> 
             RGBColor[
              0.9913072328659133, 0.9906733316431992, 0.7937251777794225], 
             UndirectedEdge[44, 66] -> 
             RGBColor[
              0.9864394890638946, 0.9680907872699489, 0.5745246017047335], 
             UndirectedEdge[116, 290] -> 
             RGBColor[
              0.9942150973891306, 0.9900350031957511, 0.6117272349665546], 
             UndirectedEdge[278, 367] -> 
             RGBColor[
              0.9860917158797691, 0.9632470715174546, 0.5279472619483949], 
             UndirectedEdge[102, 297] -> 
             RGBColor[
              0.9756346404769576, 0.9813489352791052, 0.9261283775556979], 
             UndirectedEdge[104, 187] -> 
             RGBColor[
              0.9253540591488401, 0.8965028390726413, 0.6447012766869155], 
             UndirectedEdge[136, 371] -> 
             RGBColor[
              0.8886713594489903, 0.9134976291943742, 0.9693588993963866], 
             UndirectedEdge[80, 302] -> 
             RGBColor[
              0.9813226477779413, 0.9529946746116544, 0.5696054712082945], 
             UndirectedEdge[176, 373] -> 
             RGBColor[
              0.9264861353212528, 0.7227251150079401, 0.3204598634755317], 
             UndirectedEdge[112, 219] -> 
             RGBColor[
              0.9152391829436002, 0.7769802953329028, 0.6095914065819612], 
             UndirectedEdge[33, 179] -> 
             RGBColor[
              0.8347048353283206, 0.8412846627767928, 0.659426832441888], 
             UndirectedEdge[123, 334] -> 
             RGBColor[
              0.9577093879796355, 0.8572242123510078, 0.4599973056325389], 
             UndirectedEdge[94, 307] -> 
             RGBColor[
              0.9938100000690757, 0.9899798354863477, 0.626607437090142], 
             UndirectedEdge[73, 89] -> 
             RGBColor[
              0.9920695874220606, 0.9886696846958787, 0.612531428675393], 
             UndirectedEdge[267, 311] -> 
             RGBColor[
              0.9616228621291848, 0.9503481716842626, 0.678142206655058], 
             UndirectedEdge[52, 391] -> 
             RGBColor[
              0.9701834164658416, 0.9255879668435558, 0.5966161964289993], 
             UndirectedEdge[105, 271] -> 
             RGBColor[
              0.990022896508581, 0.9901422255535034, 0.8150099549763661], 
             UndirectedEdge[187, 377] -> 
             RGBColor[
              0.941642304785428, 0.9512620098291247, 0.7237011439805257], 
             UndirectedEdge[58, 124] -> 
             RGBColor[
              0.9641254183234395, 0.8911243623183829, 0.5403822411426188], 
             UndirectedEdge[11, 54] -> 
             RGBColor[
              0.9280767760023129, 0.7812330145622483, 0.5843169664474306], 
             UndirectedEdge[115, 283] -> 
             RGBColor[
              0.9685261023021181, 0.9735084616136052, 0.8003893627157836], 
             UndirectedEdge[292, 362] -> 
             RGBColor[
              0.9941104542482286, 0.9898111820984061, 0.6003374748619756], 
             UndirectedEdge[15, 154] -> 
             RGBColor[
              0.9058196497891615, 0.9255133320312974, 0.9051341390183181], 
             UndirectedEdge[158, 311] -> 
             RGBColor[
              0.9553245046720925, 0.9291023330568329, 0.6536742772792586], 
             UndirectedEdge[123, 253] -> 
             RGBColor[
              0.9803599606374702, 0.944053347958997, 0.4937050743433099], 
             UndirectedEdge[236, 376] -> 
             RGBColor[
              0.9215758379853147, 0.9396829167558752, 0.9708633448782347], 
             UndirectedEdge[206, 386] -> 
             RGBColor[
              0.9942060077121582, 0.9900155612958146, 0.610737879723096], 
             UndirectedEdge[74, 338] -> 
             RGBColor[
              0.9893267138048145, 0.9898543361144165, 0.8265475040408583], 
             UndirectedEdge[293, 394] -> 
             RGBColor[
              0.8921165791323447, 0.9164818791433278, 0.9780724650082373], 
             UndirectedEdge[41, 381] -> 
             RGBColor[
              0.9919530849540473, 0.9909404080792842, 0.7830217372674154], 
             UndirectedEdge[59, 328] -> 
             RGBColor[
              0.9795617578017745, 0.9413144061974448, 0.5230875015900649], 
             UndirectedEdge[123, 196] -> 
             RGBColor[
              0.9918192422999674, 0.990386347145443, 0.7489886455292682], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.9684426589144748, 0.9052118198817825, 0.33190611829689676`], 
             UndirectedEdge[23, 38] -> 
             RGBColor[
              0.9519522081036945, 0.8420420743227852, 0.3071309384651449], 
             UndirectedEdge[61, 282] -> 
             RGBColor[
              0.9598620143028572, 0.865614821623548, 0.47024085268146143`], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.8370695902662351, 0.8492615364532421, 0.6686134588291865], 
             UndirectedEdge[3, 232] -> 
             RGBColor[
              0.9583951764204661, 0.865017251338744, 0.3256947339516853], 
             UndirectedEdge[110, 362] -> 
             RGBColor[
              0.9817575593332382, 0.9836050584461307, 0.7961302183868292], 
             UndirectedEdge[125, 252] -> 
             RGBColor[
              0.9935933964545782, 0.9887052477603502, 0.5440589249339562], 
             UndirectedEdge[49, 327] -> 
             RGBColor[
              0.9682698078791212, 0.9597334915760339, 0.676290549293761], 
             UndirectedEdge[89, 291] -> 
             RGBColor[
              0.9910679391379821, 0.9853470531314548, 0.6038644929440828], 
             UndirectedEdge[34, 250] -> 
             RGBColor[
              0.9908163058758923, 0.9896804010982977, 0.7444422910488748], 
             UndirectedEdge[125, 226] -> 
             RGBColor[
              0.9862332502408464, 0.9647546203034951, 0.44090311405431487`], 
             UndirectedEdge[3, 14] -> 
             RGBColor[
              0.9433394153571774, 0.8130666934514226, 0.2732677674827698], 
             UndirectedEdge[105, 345] -> 
             RGBColor[
              0.9526438673456896, 0.9623557864425066, 0.888153185740987], 
             UndirectedEdge[88, 336] -> 
             RGBColor[
              0.913104198953743, 0.802921683728403, 0.6179168879809024], 
             UndirectedEdge[162, 357] -> 
             RGBColor[
              0.9642669966864215, 0.9558869127319406, 0.6812379114012038], 
             UndirectedEdge[279, 328] -> 
             RGBColor[
              0.9782777030437922, 0.93838701470687, 0.3701744952062101], 
             UndirectedEdge[312, 359] -> 
             RGBColor[
              0.8460197108268168, 0.8774825844705316, 0.833781614568631], 
             UndirectedEdge[202, 289] -> 
             RGBColor[
              0.9732450221079172, 0.9791463263348235, 0.9113454184690102], 
             UndirectedEdge[27, 48] -> 
             RGBColor[
              0.851964125508729, 0.8806146424096757, 0.7132895010966437], 
             UndirectedEdge[115, 193] -> 
             RGBColor[
              0.9687948167106244, 0.9740832145622059, 0.8296372677685953], 
             UndirectedEdge[117, 385] -> 
             RGBColor[
              0.9932609269176077, 0.9873673867770503, 0.5611653055843383], 
             UndirectedEdge[179, 352] -> 
             RGBColor[
              0.8446577958594028, 0.8747942595624851, 0.7035407780920122], 
             UndirectedEdge[8, 365] -> 
             RGBColor[
              0.9410976056659905, 0.8002929711274118, 0.29170071485309157`], 
             UndirectedEdge[105, 353] -> 
             RGBColor[
              0.9803783035292126, 0.9836141858378166, 0.861110506739005], 
             UndirectedEdge[231, 392] -> 
             RGBColor[
              0.9523963125598243, 0.8362975018959868, 0.44756427708628926`], 
             UndirectedEdge[109, 132] -> 
             RGBColor[
              0.9918417003677571, 0.9895308358277163, 0.6857547496621903], 
             UndirectedEdge[23, 158] -> 
             RGBColor[
              0.9487962144530314, 0.83139616667655, 0.2948704990917109], 
             UndirectedEdge[105, 350] -> 
             RGBColor[
              0.9734601091359474, 0.978454607786823, 0.8728212052927257], 
             UndirectedEdge[172, 351] -> 
             RGBColor[
              0.8487305862458643, 0.8698736214338232, 0.6865727251388758], 
             UndirectedEdge[34, 375] -> 
             RGBColor[
              0.9890348426575566, 0.9897336398942791, 0.831384564289239], 
             UndirectedEdge[32, 391] -> 
             RGBColor[
              0.9713217343831284, 0.9260586905557899, 0.5777513226672196], 
             UndirectedEdge[140, 241] -> 
             RGBColor[
              0.9936627909091293, 0.9912890901574084, 0.7286410204328226], 
             UndirectedEdge[89, 336] -> 
             RGBColor[
              0.9556239200276031, 0.9647908421216309, 0.8909925730234043], 
             UndirectedEdge[74, 118] -> 
             RGBColor[
              0.9908215809318941, 0.9904725020877968, 0.8017736871530363], 
             UndirectedEdge[138, 328] -> 
             RGBColor[
              0.9144670502644978, 0.8927483353354752, 0.6509103931323172], 
             UndirectedEdge[189, 207] -> 
             RGBColor[
              0.9762876490271608, 0.9784767798079652, 0.7221692952500195], 
             UndirectedEdge[273, 281] -> 
             RGBColor[
              0.9775588727417353, 0.9421404167285442, 0.5677146390737425], 
             UndirectedEdge[49, 225] -> 
             RGBColor[
              0.9781128280038469, 0.9378315708839127, 0.36947289915090537`], 
             UndirectedEdge[43, 159] -> 
             RGBColor[
              0.9896425606406152, 0.9899849468979136, 0.8213131045862341], 
             UndirectedEdge[113, 368] -> 
             RGBColor[
              0.9346379593629874, 0.7599952799220733, 0.3217650683298032], 
             UndirectedEdge[11, 83] -> 
             RGBColor[
              0.9240298754690488, 0.7782148427707314, 0.5911673134495444], 
             UndirectedEdge[151, 344] -> 
             RGBColor[
              0.895615048615809, 0.9154427984084776, 0.7759271323395237], 
             UndirectedEdge[182, 377] -> 
             RGBColor[
              0.9936322613760712, 0.9887883758975773, 0.5482891317919687], 
             UndirectedEdge[198, 203] -> 
             RGBColor[
              0.9927094659073203, 0.9868146096988528, 0.4478485398519296], 
             UndirectedEdge[208, 395] -> 
             RGBColor[
              0.9944764651030992, 0.9919172319220345, 0.7363574143271594], 
             UndirectedEdge[305, 339] -> 
             RGBColor[
              0.9891705187482149, 0.9897897454444828, 0.8291360603485637], 
             UndirectedEdge[9, 313] -> 
             RGBColor[
              0.9938372714720646, 0.9892268717632069, 0.5706032155651937], 
             UndirectedEdge[267, 317] -> 
             RGBColor[
              0.9743202691334356, 0.9598178770379371, 0.6566488086109912], 
             UndirectedEdge[306, 350] -> 
             RGBColor[
              0.9718286181235125, 0.9695900692207691, 0.6855557923264195], 
             UndirectedEdge[111, 362] -> 
             RGBColor[
              0.9900801655601569, 0.9768996657313065, 0.5265526874791124], 
             UndirectedEdge[104, 261] -> 
             RGBColor[
              0.950866753380285, 0.8416494096072203, 0.28589003513856837`], 
             UndirectedEdge[243, 363] -> 
             RGBColor[
              0.9858232143607539, 0.9874513223056658, 0.8418773330048275], 
             UndirectedEdge[154, 369] -> 
             RGBColor[
              0.8815481648146137, 0.9082567203776146, 0.9840612481567345], 
             UndirectedEdge[218, 282] -> 
             RGBColor[
              0.9910123761567016, 0.9901886147909578, 0.7722410022251286], 
             UndirectedEdge[7, 293] -> 
             RGBColor[
              0.9119274173282921, 0.9218032177129227, 0.6963907884541196], 
             UndirectedEdge[24, 167] -> 
             RGBColor[
              0.9925580254412952, 0.9897144042303625, 0.6656948927790333], 
             UndirectedEdge[326, 363] -> 
             RGBColor[
              0.9866825645198192, 0.987806685680731, 0.8276356769421952], 
             UndirectedEdge[276, 282] -> 
             RGBColor[
              0.9944991837535819, 0.9906426352037752, 0.6426482825592654], 
             UndirectedEdge[337, 345] -> 
             RGBColor[
              0.9537102444347179, 0.9616774431163317, 0.7891179801249462], 
             UndirectedEdge[107, 124] -> 
             RGBColor[
              0.9577313343448337, 0.8637775997445438, 0.31790967196115905`], 
             UndirectedEdge[128, 227] -> 
             RGBColor[
              0.8712795134314542, 0.5082856980543804, 0.21430064086347994`], 
             UndirectedEdge[25, 365] -> 
             RGBColor[
              0.9541100527271995, 0.8425670392556591, 0.48000227865489137`], 
             UndirectedEdge[97, 363] -> 
             RGBColor[
              0.9861527286946039, 0.9863583378275103, 0.7470631384630739], 
             UndirectedEdge[13, 373] -> 
             RGBColor[
              0.9936370843828677, 0.9893213211701173, 0.5868037228110049], 
             UndirectedEdge[64, 195] -> 
             RGBColor[
              0.9801840834033086, 0.9437958403730413, 0.46447056948653487`], 
             UndirectedEdge[77, 96] -> 
             RGBColor[
              0.9469732242108067, 0.8175120746065823, 0.5035213267541374], 
             UndirectedEdge[6, 53] -> 
             RGBColor[
              0.9864519838614952, 0.965267355549196, 0.4608941247226852], 
             UndirectedEdge[216, 343] -> 
             RGBColor[
              0.8779883956837995, 0.9055481306308846, 0.9882245110414561], 
             UndirectedEdge[26, 324] -> 
             RGBColor[
              0.9913299202869521, 0.9895032861048663, 0.7076172693709196], 
             UndirectedEdge[142, 281] -> 
             RGBColor[
              0.9453101703785391, 0.8181576919553054, 0.28903172850347897`], 
             UndirectedEdge[100, 341] -> 
             RGBColor[
              0.9942423638148677, 0.9900933233233443, 0.6146950171391677], 
             UndirectedEdge[115, 364] -> 
             RGBColor[
              0.76261238272347, 0.8143702882867901, 0.9710157812976078], 
             UndirectedEdge[150, 152] -> 
             RGBColor[
              0.901656351419451, 0.8804255508215066, 0.6465875282513087], 
             UndirectedEdge[10, 68] -> 
             RGBColor[
              0.8663021726523887, 0.8100339047775948, 0.6233158100494234], 
             UndirectedEdge[190, 288] -> 
             RGBColor[
              0.98700265879056, 0.9888932796405328, 0.8650631100886346], 
             UndirectedEdge[23, 146] -> 
             RGBColor[
              0.9616914931666909, 0.8746317225169264, 0.3673508649281232], 
             UndirectedEdge[188, 201] -> 
             RGBColor[
              0.9842506361197092, 0.9849799857562651, 0.7534746029866435], 
             UndirectedEdge[148, 382] -> 
             RGBColor[
              0.9788161415692356, 0.9439136526567212, 0.5555413624695738], 
             UndirectedEdge[14, 71] -> 
             RGBColor[
              0.9727364043083808, 0.917949814335274, 0.4041269011918004], 
             UndirectedEdge[228, 276] -> 
             RGBColor[
              0.9840479034977803, 0.9849834600528313, 0.7660903344298357], 
             UndirectedEdge[56, 174] -> 
             RGBColor[
              0.9611209228134063, 0.8705816098659541, 0.47269556091045184`], 
             UndirectedEdge[16, 182] -> 
             RGBColor[
              0.9937631884876152, 0.9890684157504084, 0.5625397398950687], 
             UndirectedEdge[104, 192] -> 
             RGBColor[
              0.974752215376506, 0.9336649028074164, 0.5636679750412036], 
             UndirectedEdge[145, 395] -> 
             RGBColor[
              0.9262133387230972, 0.7164951299441686, 0.4609359409934168], 
             UndirectedEdge[219, 251] -> 
             RGBColor[
              0.6331674514078466, 0.7059820246615656, 0.965068971872207], 
             UndirectedEdge[150, 179] -> 
             RGBColor[
              0.8295616848162202, 0.8239356084303099, 0.6394466639048553], 
             UndirectedEdge[73, 207] -> 
             RGBColor[
              0.9928492665650361, 0.9871136291696925, 0.46306497869465735`], 
             UndirectedEdge[265, 325] -> 
             RGBColor[
              0.9919169629597291, 0.989434554476588, 0.6752465012028195], 
             UndirectedEdge[39, 314] -> 
             RGBColor[
              0.9657002392561538, 0.9739398751147188, 0.9429447275157106], 
             UndirectedEdge[20, 263] -> 
             RGBColor[
              0.9797514301677264, 0.952861968589682, 0.5992183249001013], 
             UndirectedEdge[66, 146] -> 
             RGBColor[
              0.9865764097833702, 0.966117972353524, 0.42473695925394134`], 
             UndirectedEdge[7, 21] -> 
             RGBColor[
              0.9875555809825025, 0.9803314094386741, 0.6374446977531788], 
             UndirectedEdge[107, 167] -> 
             RGBColor[
              0.9855006446825603, 0.9620933513919903, 0.45421486780135695`], 
             UndirectedEdge[120, 195] -> 
             RGBColor[
              0.9795636230791488, 0.9424687384778249, 0.39693729223899565`], 
             UndirectedEdge[365, 388] -> 
             RGBColor[
              0.950050231786538, 0.8304922812085958, 0.3264799767698362], 
             UndirectedEdge[134, 342] -> 
             RGBColor[
              0.9027214233729256, 0.6427416021980483, 0.2401051041819815], 
             UndirectedEdge[227, 311] -> 
             RGBColor[
              0.9138658699912863, 0.7622750592195737, 0.6028055345282994], 
             UndirectedEdge[78, 377] -> 
             RGBColor[
              0.9935967579565246, 0.9894811680438433, 0.6003033864977452], 
             UndirectedEdge[21, 370] -> 
             RGBColor[
              0.9822826169196119, 0.9625444635037054, 0.616960228084559], 
             UndirectedEdge[2, 230] -> 
             RGBColor[
              0.9751525933917187, 0.9267294933237029, 0.4529129929219097], 
             UndirectedEdge[24, 203] -> 
             RGBColor[
              0.9921883290896744, 0.9889236611162802, 0.6254557264065127], 
             UndirectedEdge[54, 206] -> 
             RGBColor[
              0.9812539886624899, 0.9834882112901482, 0.8175105629032475], 
             UndirectedEdge[66, 130] -> 
             RGBColor[
              0.943621268945382, 0.9368235852003568, 0.6843325515848668], 
             UndirectedEdge[101, 356] -> 
             RGBColor[
              0.9674290145018039, 0.9017925592628171, 0.3279683011643556], 
             UndirectedEdge[222, 383] -> 
             RGBColor[
              0.9854927437134902, 0.9875725032318529, 0.8589006454889343], 
             UndirectedEdge[31, 247] -> 
             RGBColor[
              0.9923672065054052, 0.989558102971392, 0.6632316222505334], 
             UndirectedEdge[46, 333] -> 
             RGBColor[
              0.9913268832732367, 0.9824056821152878, 0.4208070086075322], 
             UndirectedEdge[287, 385] -> 
             RGBColor[
              0.9914243529161724, 0.9868215458010015, 0.6071307043375669], 
             UndirectedEdge[42, 330] -> 
             RGBColor[
              0.9221243167283023, 0.9371059895517676, 0.8359030683245681], 
             UndirectedEdge[151, 227] -> 
             RGBColor[
              0.9390332203372652, 0.7782012429749046, 0.3982593918706313], 
             UndirectedEdge[36, 382] -> 
             RGBColor[
              0.9887910265443577, 0.9896328156656831, 0.8354252282608206], 
             UndirectedEdge[218, 361] -> 
             RGBColor[
              0.9858062015272337, 0.9740825371148187, 0.6282446761510718], 
             UndirectedEdge[196, 334] -> 
             RGBColor[
              0.9548247238316805, 0.856530043150121, 0.5440548667255992], 
             UndirectedEdge[34, 265] -> 
             RGBColor[
              0.9904100189245835, 0.9888113943913601, 0.7002204637113312], 
             UndirectedEdge[372, 392] -> 
             RGBColor[
              0.8980582361676697, 0.7968377901240631, 0.6178059489730358], 
             UndirectedEdge[127, 210] -> 
             RGBColor[
              0.9227815921575677, 0.7315617749534491, 0.25672646038223335`], 
             UndirectedEdge[33, 157] -> 
             RGBColor[
              0.9687263825370676, 0.9061688862822627, 0.33300833099395954`], 
             UndirectedEdge[139, 308] -> 
             RGBColor[
              0.955042984046766, 0.8489807216559535, 0.3372997582498155], 
             UndirectedEdge[38, 146] -> 
             RGBColor[
              0.9831902555740162, 0.954695679098555, 0.4115823895721674], 
             UndirectedEdge[55, 68] -> 
             RGBColor[
              0.9516447380539959, 0.8770527138177051, 0.6018734388299769], 
             UndirectedEdge[35, 392] -> 
             RGBColor[
              0.9525021976586088, 0.8365239794156613, 0.45908921664189933`], 
             UndirectedEdge[51, 126] -> 
             RGBColor[
              0.9524592594671222, 0.9622794463405129, 0.8912126160387253], 
             UndirectedEdge[130, 243] -> 
             RGBColor[
              0.9501086622503621, 0.9600758962661751, 0.8766913438769363], 
             UndirectedEdge[12, 203] -> 
             RGBColor[
              0.9122705707363608, 0.9278611581759424, 0.7224699829073632], 
             UndirectedEdge[182, 395] -> 
             RGBColor[
              0.9948333246491415, 0.9913573287925502, 0.6790174569623519], 
             UndirectedEdge[99, 382] -> 
             RGBColor[
              0.9698484429778098, 0.9113325531745551, 0.5328431554109692], 
             UndirectedEdge[17, 31] -> 
             RGBColor[
              0.9697822289750073, 0.9738873933211358, 0.7539972389918723], 
             UndirectedEdge[77, 78] -> 
             RGBColor[
              0.9936290633703633, 0.9916334682251116, 0.7552464376159531], 
             UndirectedEdge[243, 344] -> 
             RGBColor[
              0.8952917179724283, 0.9165490091752798, 0.8714143834275319], 
             UndirectedEdge[305, 313] -> 
             RGBColor[
              0.9902241787823428, 0.9890538578128301, 0.7265110070575806], 
             UndirectedEdge[189, 280] -> 
             RGBColor[
              0.9708854422806166, 0.9606251139188634, 0.6696146649774636], 
             UndirectedEdge[104, 208] -> 
             RGBColor[
              0.9769871561934409, 0.9345891082705781, 0.5266292218631659], 
             UndirectedEdge[191, 335] -> 
             RGBColor[
              0.9952026980141927, 0.9921473810710189, 0.7192214682400002], 
             UndirectedEdge[225, 355] -> 
             RGBColor[
              0.983482539538715, 0.9551161748646742, 0.46079936161449797`], 
             UndirectedEdge[308, 348] -> 
             RGBColor[
              0.9901297222189102, 0.9861939197007772, 0.6279483667187791], 
             UndirectedEdge[132, 149] -> 
             RGBColor[
              0.9943769124271034, 0.9903811091999647, 0.6293398032432216], 
             UndirectedEdge[128, 224] -> 
             RGBColor[
              0.8409337360978892, 0.3156402096917174, 0.18683149795636844`], 
             UndirectedEdge[192, 225] -> 
             RGBColor[
              0.9811988299852357, 0.9554108476197536, 0.5887118554551002], 
             UndirectedEdge[84, 252] -> 
             RGBColor[
              0.9722463321217941, 0.9155704958246007, 0.4295531827181405], 
             UndirectedEdge[30, 211] -> 
             RGBColor[
              0.9863702837677494, 0.9650477211613256, 0.4558183677847997], 
             UndirectedEdge[138, 242] -> 
             RGBColor[
              0.9287073850711802, 0.9407664850702104, 0.7077486751474147], 
             UndirectedEdge[27, 41] -> 
             RGBColor[
              0.9910272541077687, 0.9883928361700463, 0.641013071905167], 
             UndirectedEdge[102, 139] -> 
             RGBColor[
              0.9469010958185036, 0.8481026832406988, 0.5901870809321619], 
             UndirectedEdge[203, 329] -> 
             RGBColor[
              0.9521889904418726, 0.9596910224924802, 0.7262774374144689], 
             UndirectedEdge[195, 312] -> 
             RGBColor[
              0.8316240195091897, 0.8304634137096245, 0.6468320720492291], 
             UndirectedEdge[51, 87] -> 
             RGBColor[
              0.9931422106738568, 0.9910179405731531, 0.7332067665505531], 
             UndirectedEdge[83, 366] -> 
             RGBColor[
              0.9723738527461527, 0.9656961770358947, 0.6755036468255246], 
             UndirectedEdge[8, 302] -> 
             RGBColor[
              0.970277493102025, 0.911401146435944, 0.3390341026361672], 
             UndirectedEdge[146, 344] -> 
             RGBColor[
              0.8951574555210907, 0.9144640530486339, 0.7261209479166668], 
             UndirectedEdge[67, 320] -> 
             RGBColor[
              0.9741981710145036, 0.9246265136536858, 0.35426519596824824`], 
             UndirectedEdge[90, 166] -> 
             RGBColor[
              0.7880597970486448, 0.8303801130469272, 0.7560590784859962], 
             UndirectedEdge[12, 341] -> 
             RGBColor[
              0.9131764855717948, 0.9297988184068959, 0.8210732220860506], 
             UndirectedEdge[3, 13] -> 
             RGBColor[
              0.9646640115214404, 0.885344913937806, 0.5020852393672655], 
             UndirectedEdge[153, 341] -> 
             RGBColor[
              0.9941383863071602, 0.9898709259480963, 0.6033777070999886], 
             UndirectedEdge[192, 351] -> 
             RGBColor[
              0.9877919823740331, 0.9776510987729661, 0.614325007473222], 
             UndirectedEdge[12, 150] -> 
             RGBColor[
              0.8970621286434264, 0.8767622422867597, 0.6461493271816205], 
             UndirectedEdge[99, 393] -> 
             RGBColor[
              0.9347989635918101, 0.7792066481385831, 0.26639591952218716`], 
             UndirectedEdge[4, 190] -> 
             RGBColor[
              0.942675529548876, 0.955503498534445, 0.9348029278883547], 
             UndirectedEdge[373, 390] -> 
             RGBColor[
              0.9765677121524801, 0.9325609107468291, 0.3684551701579495], 
             UndirectedEdge[23, 308] -> 
             RGBColor[
              0.9609392932009722, 0.8723576226238318, 0.34204406699945394`], 
             UndirectedEdge[37, 187] -> 
             RGBColor[
              0.9388581377454197, 0.9522496262706865, 0.9253204324560427], 
             UndirectedEdge[17, 292] -> 
             RGBColor[
              0.9698469607668128, 0.9740258480784196, 0.7610428950515863], 
             UndirectedEdge[309, 385] -> 
             RGBColor[
              0.9928231283429068, 0.9864309798939908, 0.5135136325077574], 
             UndirectedEdge[140, 380] -> 
             RGBColor[
              0.9934381920599884, 0.9908086959295228, 0.7041948217672548], 
             UndirectedEdge[119, 354] -> 
             RGBColor[
              0.9607744289847274, 0.9702653191456379, 0.9512427714349407], 
             UndirectedEdge[36, 305] -> 
             RGBColor[
              0.9862451144894444, 0.988580015604021, 0.8776175796199295], 
             UndirectedEdge[91, 351] -> 
             RGBColor[
              0.9627874164474443, 0.8811987314081393, 0.3356466102794675], 
             UndirectedEdge[130, 275] -> 
             RGBColor[
              0.9505367241157734, 0.9591936949933458, 0.7926034399807884], 
             UndirectedEdge[46, 102] -> 
             RGBColor[
              0.9834495317208779, 0.9824199880240212, 0.6747220063222046], 
             UndirectedEdge[111, 271] -> 
             RGBColor[
              0.98687203934928, 0.9761525082099338, 0.6218420914377066], 
             UndirectedEdge[104, 351] -> 
             RGBColor[
              0.9732658804489311, 0.9214816786637752, 0.35064342316929975`], 
             UndirectedEdge[174, 203] -> 
             RGBColor[
              0.9938598220297516, 0.9892751051258881, 0.5730577046035121], 
             UndirectedEdge[294, 313] -> 
             RGBColor[
              0.9778734097293056, 0.980230178199649, 0.7647708459471847], 
             UndirectedEdge[206, 266] -> 
             RGBColor[
              0.9944394325685687, 0.9917095135395566, 0.7229853648534499], 
             UndirectedEdge[167, 358] -> 
             RGBColor[
              0.9925768831518138, 0.989722202378283, 0.6653823717135485], 
             UndirectedEdge[315, 322] -> 
             RGBColor[
              0.9879193021832267, 0.9703970194977604, 0.4512838267369381], 
             UndirectedEdge[176, 347] -> 
             RGBColor[
              0.8021946852264699, 0.629411786539977, 0.5901626744405062], 
             UndirectedEdge[92, 186] -> 
             RGBColor[
              0.9825399513138413, 0.9849583736486964, 0.845451355288247], 
             UndirectedEdge[149, 210] -> 
             RGBColor[
              0.9599557839000061, 0.865812320259643, 0.48062846800122905`], 
             UndirectedEdge[171, 374] -> 
             RGBColor[
              0.9892258971078206, 0.974914274227709, 0.44702282581030905`], 
             UndirectedEdge[228, 282] -> 
             RGBColor[
              0.9844101892427102, 0.985758352628529, 0.8055229019970112], 
             UndirectedEdge[164, 210] -> 
             RGBColor[
              0.95868168279455, 0.8630871468264543, 0.34195042551289856`], 
             UndirectedEdge[196, 214] -> 
             RGBColor[
              0.9909122384432603, 0.9884463576081031, 0.6502668731056476], 
             UndirectedEdge[204, 307] -> 
             RGBColor[
              0.9840038718635592, 0.9573800317720846, 0.5478184009051], 
             UndirectedEdge[127, 255] -> 
             RGBColor[
              0.9219566190302317, 0.7282910314095601, 0.25606266763937074`], 
             UndirectedEdge[68, 334] -> 
             RGBColor[
              0.9275826197639115, 0.7505962495649929, 0.2605894798888996], 
             UndirectedEdge[16, 269] -> 
             RGBColor[
              0.7429652867327199, 0.7933719224523188, 0.7198533569875287], 
             UndirectedEdge[68, 337] -> 
             RGBColor[
              0.9642174455549816, 0.8836832072942562, 0.42637293054339764`], 
             UndirectedEdge[23, 374] -> 
             RGBColor[
              0.9578735849569162, 0.862016268854104, 0.33013436938172014`], 
             UndirectedEdge[22, 116] -> 
             RGBColor[
              0.9738744024263128, 0.9208379642332342, 0.5011205271658704], 
             UndirectedEdge[192, 322] -> 
             RGBColor[
              0.9858904684904759, 0.9712368459470357, 0.6069379851063685], 
             UndirectedEdge[70, 95] -> 
             RGBColor[
              0.8939395610016474, 0.5232407600421747, 0.25217503127380564`], 
             UndirectedEdge[71, 273] -> 
             RGBColor[
              0.9916972353382751, 0.9892505571926029, 0.6721180785808616], 
             UndirectedEdge[135, 215] -> 
             RGBColor[
              0.9874715634349993, 0.9798247460767036, 0.635575192859978], 
             UndirectedEdge[161, 283] -> 
             RGBColor[
              0.9761628711915862, 0.9301559095973976, 0.4552636019715009], 
             UndirectedEdge[18, 384] -> 
             RGBColor[
              0.9878975342166728, 0.9708376824980476, 0.4074846351010104], 
             UndirectedEdge[71, 303] -> 
             RGBColor[
              0.9933880966206754, 0.9882661321746293, 0.5217133049773481], 
             UndirectedEdge[32, 353] -> 
             RGBColor[
              0.9777517154101438, 0.9825280241503459, 0.9046398692641314], 
             UndirectedEdge[188, 281] -> 
             RGBColor[
              0.9795419677539837, 0.9417810501093535, 0.44911770350667846`], 
             UndirectedEdge[54, 198] -> 
             RGBColor[
              0.980056861150169, 0.9809276765894518, 0.6872106210017396], 
             UndirectedEdge[271, 385] -> 
             RGBColor[
              0.9898407564118479, 0.9861666879498895, 0.6333749966306064], 
             UndirectedEdge[150, 206] -> 
             RGBColor[
              0.9786981513267069, 0.9382762285103665, 0.5018278260276948], 
             UndirectedEdge[317, 346] -> 
             RGBColor[
              0.9508816301941398, 0.8739214508132123, 0.601177343451615], 
             UndirectedEdge[146, 243] -> 
             RGBColor[
              0.9930638030883503, 0.9893702834193423, 0.6170957515460108], 
             UndirectedEdge[91, 316] -> 
             RGBColor[
              0.9560434795224848, 0.8880888543794196, 0.6004446816926585], 
             UndirectedEdge[196, 386] -> 
             RGBColor[
              0.9911824458554526, 0.9890243039406227, 0.6796772823959467], 
             UndirectedEdge[151, 306] -> 
             RGBColor[
              0.9912167558585059, 0.981206125673419, 0.4907923491590976], 
             UndirectedEdge[27, 376] -> 
             RGBColor[
              0.9380785115949166, 0.9484002963135791, 0.7217365922317933], 
             UndirectedEdge[280, 387] -> 
             RGBColor[
              0.9887744973993028, 0.972101218041418, 0.5549937370982135], 
             UndirectedEdge[308, 354] -> 
             RGBColor[
              0.987811263122981, 0.9852351772829295, 0.6663712339181332], 
             UndirectedEdge[327, 349] -> 
             RGBColor[
              0.9734666541974407, 0.9781856566914207, 0.8605473522449794], 
             UndirectedEdge[60, 108] -> 
             RGBColor[
              0.9067211590473454, 0.9280488183844193, 0.9767487989530307], 
             UndirectedEdge[353, 391] -> 
             RGBColor[
              0.9624748591159777, 0.9198605276145152, 0.6106316275111505], 
             UndirectedEdge[140, 195] -> 
             RGBColor[
              0.979333623841739, 0.9444122080411244, 0.5489322320116143], 
             UndirectedEdge[17, 18] -> 
             RGBColor[
              0.967223204073089, 0.9658588943976731, 0.6927222188654854], 
             UndirectedEdge[87, 205] -> 
             RGBColor[
              0.9159985282043264, 0.9321553917948733, 0.82996372572094], 
             UndirectedEdge[221, 256] -> 
             RGBColor[
              0.9941540768349746, 0.9899044864005356, 0.6050855242218741], 
             UndirectedEdge[194, 316] -> 
             RGBColor[
              0.9534444823252501, 0.8777846965568592, 0.5983534675414586], 
             UndirectedEdge[16, 37] -> 
             RGBColor[
              0.9901493647961157, 0.9882814805055855, 0.6738560219031188], 
             UndirectedEdge[252, 288] -> 
             RGBColor[
              0.9908944854757809, 0.9893309514700757, 0.715395356851256], 
             UndirectedEdge[60, 353] -> 
             RGBColor[
              0.9602523195430595, 0.9698768255128429, 0.9521666345449531], 
             UndirectedEdge[206, 286] -> 
             RGBColor[
              0.9948813202952018, 0.991459986626369, 0.6842414868412203], 
             UndirectedEdge[220, 396] -> 
             RGBColor[
              0.9784255114821656, 0.9814110680229668, 0.824863714568935], 
             UndirectedEdge[133, 320] -> 
             RGBColor[
              0.9765844556240264, 0.9466192548742723, 0.6176059660982931], 
             UndirectedEdge[28, 231] -> 
             RGBColor[
              0.9938131466111559, 0.989175271125121, 0.56797737333668], 
             UndirectedEdge[239, 269] -> 
             RGBColor[
              0.7064944682967771, 0.6600952892747813, 0.6039032620047151], 
             UndirectedEdge[212, 239] -> 
             RGBColor[
              0.8706779026018293, 0.7906567714026022, 0.6186991403453957], 
             UndirectedEdge[77, 182] -> 
             RGBColor[
              0.99366456678991, 0.9909406760788455, 0.7032321829101766], 
             UndirectedEdge[280, 336] -> 
             RGBColor[
              0.9510013924240344, 0.9453831207063428, 0.6889714927701127], 
             UndirectedEdge[199, 400] -> 
             RGBColor[
              0.8841954016024209, 0.9097696292887949, 0.9572019992303996], 
             UndirectedEdge[73, 336] -> 
             RGBColor[
              0.9561483342441738, 0.9626888007291077, 0.7137421111160194], 
             UndirectedEdge[305, 340] -> 
             RGBColor[
              0.9908118590752301, 0.9903108465357238, 0.7904763801959953], 
             UndirectedEdge[259, 350] -> 
             RGBColor[
              0.9733385723006256, 0.9784043491820633, 0.8748353851812538], 
             UndirectedEdge[247, 393] -> 
             RGBColor[
              0.9563852780804506, 0.858600161306782, 0.5251645292366557], 
             UndirectedEdge[30, 216] -> 
             RGBColor[
              0.9419663368438711, 0.9520130277325373, 0.7636673321195524], 
             UndirectedEdge[291, 387] -> 
             RGBColor[
              0.9929197909353635, 0.9860842664997589, 0.5710974197128101], 
             UndirectedEdge[45, 338] -> 
             RGBColor[
              0.9725087243668886, 0.928468635290083, 0.5713445321260474], 
             UndirectedEdge[219, 248] -> 
             RGBColor[
              0.9378733585651368, 0.8704029148365926, 0.627994050722464], 
             UndirectedEdge[158, 354] -> 
             RGBColor[
              0.9756681843750401, 0.9442737213356478, 0.6191976660103902], 
             UndirectedEdge[191, 327] -> 
             RGBColor[0.974336329244933, 0.978508501326903, 0.84346046164377],
              UndirectedEdge[165, 192] -> 
             RGBColor[
              0.9922636143136825, 0.9910402747940896, 0.7758005306766886], 
             UndirectedEdge[143, 354] -> 
             RGBColor[
              0.9886503108128782, 0.9876950356763903, 0.7011308706616133], 
             UndirectedEdge[115, 161] -> 
             RGBColor[
              0.9504068806820984, 0.9134860715808533, 0.6366336914321166], 
             UndirectedEdge[296, 330] -> 
             RGBColor[
              0.8759938364850233, 0.7667506672605922, 0.6129825272446437], 
             UndirectedEdge[45, 262] -> 
             RGBColor[
              0.9417663085841816, 0.8064221484685634, 0.274125321724356], 
             UndirectedEdge[37, 208] -> 
             RGBColor[
              0.9904912347900205, 0.9903358954686234, 0.8072483776322932], 
             UndirectedEdge[306, 348] -> 
             RGBColor[
              0.9887115443114038, 0.9814100726147508, 0.6224390133485431], 
             UndirectedEdge[189, 263] -> 
             RGBColor[
              0.9656360905302048, 0.9429178178583197, 0.6492219246840121], 
             UndirectedEdge[2, 50] -> 
             RGBColor[
              0.9712937662599532, 0.9259704992706619, 0.5776851925367247], 
             UndirectedEdge[241, 331] -> 
             RGBColor[
              0.9946622225139465, 0.9909913586264476, 0.660394045466351], 
             UndirectedEdge[135, 213] -> 
             RGBColor[
              0.8926165464695957, 0.9155840580625355, 0.9221560880268643], 
             UndirectedEdge[49, 349] -> 
             RGBColor[
              0.9883031596571501, 0.9731279345603123, 0.5731284496879546], 
             UndirectedEdge[256, 319] -> 
             RGBColor[
              0.9774661571335449, 0.9344381733352874, 0.47002255021015504`], 
             UndirectedEdge[64, 332] -> 
             RGBColor[
              0.9905304763773168, 0.9786966533229673, 0.5046643524381887], 
             UndirectedEdge[213, 350] -> 
             RGBColor[
              0.8766112133223827, 0.9041269619439867, 0.9707288791827107], 
             UndirectedEdge[333, 345] -> 
             RGBColor[
              0.9521660175648574, 0.9573827506384911, 0.7053694511125908], 
             UndirectedEdge[53, 201] -> 
             RGBColor[
              0.9841070783114674, 0.9846729301203567, 0.7378492214956138], 
             UndirectedEdge[9, 384] -> 
             RGBColor[
              0.9905912907144445, 0.979154358681587, 0.4834243579690235], 
             UndirectedEdge[24, 33] -> 
             RGBColor[
              0.9821230375088406, 0.9551737995735804, 0.5691152392178029], 
             UndirectedEdge[20, 359] -> 
             RGBColor[
              0.9913505673033479, 0.9904477054325365, 0.7753037825073557], 
             UndirectedEdge[35, 291] -> 
             RGBColor[
              0.9926776812008055, 0.9855664182585882, 0.5447452692342428], 
             UndirectedEdge[316, 351] -> 
             RGBColor[
              0.9795617105214987, 0.9723579976006052, 0.6660985270145092], 
             UndirectedEdge[195, 263] -> 
             RGBColor[
              0.9690048603155234, 0.9071082572186857, 0.33409016457714424`], 
             UndirectedEdge[67, 200] -> 
             RGBColor[
              0.9866978098648211, 0.967761265565648, 0.5672275640954123], 
             UndirectedEdge[232, 277] -> 
             RGBColor[
              0.9847852328184377, 0.9603391590786804, 0.39539393187766925`], 
             UndirectedEdge[88, 120] -> 
             RGBColor[
              0.9497123355412747, 0.8271480314784814, 0.35713951265538435`], 
             UndirectedEdge[247, 271] -> 
             RGBColor[
              0.9897236363615887, 0.9900184737920872, 0.819969470072462], 
             UndirectedEdge[202, 269] -> 
             RGBColor[
              0.7263167466353777, 0.7843425492267024, 0.9531034426270464], 
             UndirectedEdge[207, 291] -> 
             RGBColor[
              0.9918476182809577, 0.9837909976052684, 0.4543980429633472], 
             UndirectedEdge[72, 397] -> 
             RGBColor[
              0.9899659308706892, 0.9882446987484894, 0.6797361830319776], 
             UndirectedEdge[200, 298] -> 
             RGBColor[
              0.9776504116498, 0.9372422669562588, 0.5320801304878461], 
             UndirectedEdge[233, 389] -> 
             RGBColor[
              0.7730939926911911, 0.5222798932385867, 0.5765127121498717], 
             UndirectedEdge[44, 311] -> 
             RGBColor[
              0.9680828626662763, 0.9743107038136343, 0.875942285566463], 
             UndirectedEdge[137, 258] -> 
             RGBColor[
              0.9902736862148231, 0.9902459335420359, 0.8108537205209789], 
             UndirectedEdge[46, 287] -> 
             RGBColor[
              0.9915594591515422, 0.9872772908573568, 0.6076555665493072], 
             UndirectedEdge[84, 274] -> 
             RGBColor[
              0.9722048448333431, 0.9154817587096125, 0.42503754740012384`], 
             UndirectedEdge[270, 357] -> 
             RGBColor[
              0.9190395193640961, 0.9380134000639049, 0.9828558238876515], 
             UndirectedEdge[44, 344] -> 
             RGBColor[
              0.8950205348016149, 0.916436867965059, 0.8759085903674588], 
             UndirectedEdge[44, 383] -> 
             RGBColor[
              0.9918204254319997, 0.9908855499577232, 0.7852202488595832], 
             UndirectedEdge[193, 364] -> 
             RGBColor[
              0.7886370876414641, 0.8316148792519352, 0.8188935968898037], 
             UndirectedEdge[43, 375] -> 
             RGBColor[
              0.9916829393201787, 0.9908286959172533, 0.7874987495351095], 
             UndirectedEdge[184, 252] -> 
             RGBColor[
              0.9940468075310461, 0.989675048206023, 0.5934099224786709], 
             UndirectedEdge[16, 78] -> 
             RGBColor[
              0.9937276850680686, 0.9897612078966744, 0.6145539946008451], 
             UndirectedEdge[345, 353] -> 
             RGBColor[
              0.9411704039594702, 0.9550714618137612, 0.9645628531100443], 
             UndirectedEdge[167, 203] -> 
             RGBColor[
              0.9932011813254796, 0.9878663392582407, 0.5013687286027682], 
             UndirectedEdge[329, 340] -> 
             RGBColor[
              0.95332288492936, 0.9621163081468976, 0.8496948547918637], 
             UndirectedEdge[193, 380] -> 
             RGBColor[
              0.9946184820993176, 0.9908978023023904, 0.6556331712685344], 
             UndirectedEdge[115, 253] -> 
             RGBColor[
              0.9543930633098243, 0.9269324015843624, 0.6521192582134057], 
             UndirectedEdge[113, 270] -> 
             RGBColor[
              0.8845047283339076, 0.7255735080754073, 0.6043250540393622], 
             UndirectedEdge[121, 202] -> 
             RGBColor[
              0.9765929101343173, 0.9805307640705376, 0.8558622498150829], 
             UndirectedEdge[17, 111] -> 
             RGBColor[
              0.9658166720787411, 0.9611143317113201, 0.6872581076687232], 
             UndirectedEdge[73, 280] -> 
             RGBColor[
              0.9874470598184919, 0.9692619632805906, 0.4105103484221014], 
             UndirectedEdge[127, 242] -> 
             RGBColor[
              0.9566179472134924, 0.8548797925686002, 0.3417888120906424], 
             UndirectedEdge[19, 211] -> 
             RGBColor[
              0.9870609928326974, 0.9665250780098508, 0.530997786942158], 
             UndirectedEdge[213, 345] -> 
             RGBColor[
              0.8557949715321251, 0.8880281405996704, 0.9860608596309719], 
             UndirectedEdge[102, 350] -> 
             RGBColor[
              0.9651049078027563, 0.9734958778915408, 0.9439524683790019], 
             UndirectedEdge[81, 227] -> 
             RGBColor[
              0.9393984467640613, 0.7789824253717651, 0.43801203451114434`], 
             UndirectedEdge[144, 218] -> 
             RGBColor[
              0.971827452496862, 0.9269289342690179, 0.5739398758333296], 
             UndirectedEdge[130, 354] -> 
             RGBColor[
              0.9456083222507115, 0.9582148900228571, 0.9512736241777279], 
             UndirectedEdge[104, 327] -> 
             RGBColor[
              0.956829707935408, 0.9211433482026838, 0.6318479212940336], 
             UndirectedEdge[10, 253] -> 
             RGBColor[
              0.8820849950576606, 0.8696346991762767, 0.6514976257001648], 
             UndirectedEdge[40, 41] -> 
             RGBColor[
              0.9908459384802446, 0.9904825745600002, 0.8013700195415535], 
             UndirectedEdge[5, 113] -> 
             RGBColor[
              0.9326884130429004, 0.7534190024091756, 0.314191449017196], 
             UndirectedEdge[271, 337] -> 
             RGBColor[
              0.9910892735976091, 0.9894638822273285, 0.7159747493603252], 
             UndirectedEdge[325, 376] -> 
             RGBColor[
              0.9368322238905362, 0.9500496413812191, 0.8997428832410765], 
             UndirectedEdge[52, 337] -> 
             RGBColor[
              0.9891532379681047, 0.9886632817406823, 0.748059870040813], 
             UndirectedEdge[246, 260] -> 
             RGBColor[
              0.9197768002601906, 0.6774385557417957, 0.307048436385662], 
             UndirectedEdge[22, 290] -> 
             RGBColor[
              0.9728651069125382, 0.9186791831847, 0.39126493914139404`], 
             UndirectedEdge[24, 107] -> 
             RGBColor[
              0.984487792446755, 0.9631506732500297, 0.5783018656051016], 
             UndirectedEdge[314, 369] -> 
             RGBColor[
              0.9554758283817751, 0.9663145262255435, 0.9602519881725939], 
             UndirectedEdge[187, 208] -> 
             RGBColor[
              0.9421151018908768, 0.9535964646449937, 0.8713441078128001], 
             UndirectedEdge[9, 174] -> 
             RGBColor[
              0.994319394333357, 0.990258083813413, 0.6230793136994781], 
             UndirectedEdge[6, 303] -> 
             RGBColor[
              0.9863033079398889, 0.9649493527863215, 0.4447116681772655], 
             UndirectedEdge[100, 198] -> 
             RGBColor[
              0.9932144299128953, 0.9878946766470852, 0.5028107555821623], 
             UndirectedEdge[101, 123] -> 
             RGBColor[
              0.9753601335970735, 0.9271877573365224, 0.47428169042947965`], 
             UndirectedEdge[210, 394] -> 
             RGBColor[
              0.9367102152776832, 0.8504782166187863, 0.6151773774966984], 
             UndirectedEdge[213, 227] -> 
             RGBColor[
              0.8411878445681921, 0.7047014433591573, 0.6028101430051602], 
             UndirectedEdge[32, 46] -> 
             RGBColor[
              0.9891781449350001, 0.9862925562318327, 0.6471201057610548], 
             UndirectedEdge[303, 391] -> 
             RGBColor[
              0.9746876271880149, 0.9257669341187111, 0.3995869418934871], 
             UndirectedEdge[248, 251] -> 
             RGBColor[
              0.6319942431143344, 0.6223233296161155, 0.6050005801010958], 
             UndirectedEdge[239, 388] -> 
             RGBColor[
              0.9535655134352099, 0.8444292015474116, 0.32930845489862304`], 
             UndirectedEdge[205, 277] -> 
             RGBColor[
              0.9123135690335279, 0.9211439482749904, 0.6950047769110329], 
             UndirectedEdge[308, 378] -> 
             RGBColor[
              0.9920882660823928, 0.9848207058607646, 0.4368002988092343], 
             UndirectedEdge[119, 130] -> 
             RGBColor[
              0.9221853656950522, 0.940746982109143, 0.9909626479542095], 
             UndirectedEdge[28, 254] -> 
             RGBColor[
              0.9894135186150133, 0.9879849077779659, 0.6866119566192965], 
             UndirectedEdge[217, 314] -> 
             RGBColor[
              0.9762209553833547, 0.9817862079762938, 0.925135899354586], 
             UndirectedEdge[229, 307] -> 
             RGBColor[
              0.9638858798994862, 0.970842009766091, 0.86847546092707], 
             UndirectedEdge[114, 155] -> 
             RGBColor[
              0.9073244755501744, 0.9283950531891356, 0.972131585267055], 
             UndirectedEdge[226, 288] -> 
             RGBColor[
              0.983534339262049, 0.9653803240132206, 0.6122395459716146], 
             UndirectedEdge[217, 231] -> 
             RGBColor[
              0.9883892442446197, 0.9885109822070313, 0.7817325820189103], 
             UndirectedEdge[151, 346] -> 
             RGBColor[
              0.963351573535868, 0.8803779292148687, 0.4181245988380136], 
             UndirectedEdge[114, 180] -> 
             RGBColor[
              0.966650299967596, 0.949810198816498, 0.6605306680102025], 
             UndirectedEdge[215, 345] -> 
             RGBColor[
              0.9506499884975288, 0.9522688286138385, 0.6994799644640857], 
             UndirectedEdge[190, 252] -> 
             RGBColor[
              0.9900319761086145, 0.9889742816812728, 0.7296893691678935], 
             UndirectedEdge[275, 311] -> 
             RGBColor[
              0.9687821077025011, 0.9735406437510259, 0.7873601747303882], 
             UndirectedEdge[75, 320] -> 
             RGBColor[
              0.979529312084543, 0.9426097042943784, 0.37497567232383533`], 
             UndirectedEdge[169, 393] -> 
             RGBColor[
              0.9350903035565472, 0.7803617140154777, 0.2666303384964425], 
             UndirectedEdge[80, 182] -> 
             RGBColor[
              0.9928275899664685, 0.9905945646530292, 0.7171030549011863], 
             UndirectedEdge[239, 362] -> 
             RGBColor[
              0.957366550299633, 0.855950446622485, 0.45466370711533516`], 
             UndirectedEdge[171, 342] -> 
             RGBColor[
              0.9325698246532393, 0.7496771021183506, 0.35578347862276793`], 
             UndirectedEdge[107, 157] -> 
             RGBColor[
              0.971091137474982, 0.914145759958712, 0.3421949573812581], 
             UndirectedEdge[116, 286] -> 
             RGBColor[
              0.9950026658139426, 0.9917195324210417, 0.6974491976984223], 
             UndirectedEdge[37, 117] -> 
             RGBColor[
              0.9911343188789065, 0.9903881976945412, 0.781062195382892], 
             UndirectedEdge[111, 222] -> 
             RGBColor[
              0.9827751941789362, 0.9737619697266142, 0.6585517532440306], 
             UndirectedEdge[57, 72] -> 
             RGBColor[
              0.9936211245790842, 0.9887645554149251, 0.5470769601682848], 
             UndirectedEdge[8, 323] -> 
             RGBColor[
              0.9819663755435557, 0.949394466079281, 0.5065524477208296], 
             UndirectedEdge[115, 356] -> 
             RGBColor[
              0.9608058900250067, 0.9485643718979901, 0.6770318790411796], 
             UndirectedEdge[129, 391] -> 
             RGBColor[
              0.9753379625794305, 0.9271579357619548, 0.4703719358442695], 
             UndirectedEdge[271, 303] -> 
             RGBColor[
              0.9907622011943986, 0.9887643074289538, 0.6803749367277598], 
             UndirectedEdge[141, 196] -> 
             RGBColor[
              0.9734985734416833, 0.9299447581387977, 0.5623138173366767], 
             UndirectedEdge[8, 117] -> 
             RGBColor[
              0.9820686598333959, 0.949613241832721, 0.5176854614444653], 
             UndirectedEdge[278, 330] -> 
             RGBColor[
              0.9221401881982276, 0.9371399370210859, 0.8376305798785704], 
             UndirectedEdge[95, 276] -> 
             RGBColor[
              0.9823485100059735, 0.9511111313562135, 0.4716738887698506], 
             UndirectedEdge[114, 268] -> 
             RGBColor[
              0.5678777421439949, 0.6363586673928139, 0.9457316472762674], 
             UndirectedEdge[95, 148] -> 
             RGBColor[
              0.9682880684151565, 0.9046903498280067, 0.3313055633990116], 
             UndirectedEdge[236, 366] -> 
             RGBColor[
              0.9725413049261304, 0.9658210625975443, 0.6752201939633453], 
             UndirectedEdge[108, 378] -> 
             RGBColor[
              0.9272969553053877, 0.9397890655836231, 0.7195481901824394], 
             UndirectedEdge[33, 107] -> 
             RGBColor[
              0.9750656567501055, 0.9275527467352082, 0.3576352142401266], 
             UndirectedEdge[309, 362] -> 
             RGBColor[
              0.9943845242436655, 0.9903973901059187, 0.6301683025013411], 
             UndirectedEdge[178, 278] -> 
             RGBColor[
              0.9855758111372082, 0.961506803680603, 0.5259430694439822], 
             UndirectedEdge[21, 232] -> 
             RGBColor[
              0.9845333851835543, 0.9701368333635031, 0.6257040377680533], 
             UndirectedEdge[20, 140] -> 
             RGBColor[
              0.9900801936939421, 0.9901659194121206, 0.8140603923345714], 
             UndirectedEdge[33, 150] -> 
             RGBColor[
              0.9675577513000906, 0.902226818712276, 0.3284684193157952], 
             UndirectedEdge[38, 213] -> 
             RGBColor[
              0.8858024728996614, 0.8821746248426516, 0.6659393251295533], 
             UndirectedEdge[86, 262] -> 
             RGBColor[
              0.9600905800798489, 0.8673163460534425, 0.42336094343685915`], 
             UndirectedEdge[17, 310] -> 
             RGBColor[
              0.9680396339029962, 0.9747203404880258, 0.895803598225241], 
             UndirectedEdge[222, 223] -> 
             RGBColor[
              0.9841606983582805, 0.9870216682454696, 0.8809760842476339], 
             UndirectedEdge[19, 124] -> 
             RGBColor[
              0.9664753661503354, 0.8917825182500132, 0.4786415415039885], 
             UndirectedEdge[184, 274] -> 
             RGBColor[
              0.9940053202425951, 0.9895863110910348, 0.5888942871606542], 
             UndirectedEdge[195, 360] -> 
             RGBColor[
              0.9422024251873915, 0.8055292055712938, 0.2881316514344331], 
             UndirectedEdge[186, 378] -> 
             RGBColor[
              0.9931080420616372, 0.9892348904644723, 0.6051911815188742], 
             UndirectedEdge[31, 169] -> 
             RGBColor[
              0.9710722319815019, 0.9113196556800877, 0.4046974315103202], 
             UndirectedEdge[4, 84] -> 
             RGBColor[
              0.9248898855620555, 0.882099712677773, 0.6346667414386018], 
             UndirectedEdge[81, 383] -> 
             RGBColor[
              0.9927801656729898, 0.9906726627980026, 0.7249914334721611], 
             UndirectedEdge[327, 335] -> 
             RGBColor[
              0.9742996711886716, 0.978430093451258, 0.8394704584470161], 
             UndirectedEdge[11, 214] -> 
             RGBColor[
              0.9407585876397888, 0.7871824182353949, 0.34813387397698015`], 
             UndirectedEdge[15, 35] -> 
             RGBColor[
              0.9920214873163724, 0.9905223896296381, 0.7494465012541118], 
             UndirectedEdge[151, 354] -> 
             RGBColor[
              0.9890210561834181, 0.988488022535868, 0.7414842162696594], 
             UndirectedEdge[91, 192] -> 
             RGBColor[
              0.9642737513750193, 0.8933819555517806, 0.5486711621513713], 
             UndirectedEdge[44, 130] -> 
             RGBColor[
              0.9498374790795487, 0.9599637550559542, 0.8811855508168633], 
             UndirectedEdge[195, 356] -> 
             RGBColor[
              0.9725249871954504, 0.9189824717497762, 0.34776519278547824`], 
             UndirectedEdge[226, 315] -> 
             RGBColor[
              0.9862697475267406, 0.964832684307581, 0.4448756183887486], 
             UndirectedEdge[65, 206] -> 
             RGBColor[
              0.99497625799848, 0.9916630487740069, 0.6945748699554641], 
             UndirectedEdge[287, 400] -> 
             RGBColor[
              0.981183325955026, 0.9842960680578436, 0.8633974523296584], 
             UndirectedEdge[247, 319] -> 
             RGBColor[
              0.9758593558066053, 0.9344769392949996, 0.5477680479179846], 
             UndirectedEdge[55, 72] -> 
             RGBColor[
              0.9809744285682442, 0.9819758079971814, 0.7145242757613696], 
             UndirectedEdge[313, 329] -> 
             RGBColor[
              0.9527352046364728, 0.9608593194240038, 0.7857294816534489], 
             UndirectedEdge[5, 357] -> 
             RGBColor[
              0.967223204073089, 0.9658588943976731, 0.6927222188654854], 
             UndirectedEdge[39, 328] -> 
             RGBColor[
              0.9626177055800316, 0.9304851685307249, 0.6327177746851274], 
             UndirectedEdge[310, 384] -> 
             RGBColor[
              0.9887139640465801, 0.9796991285884001, 0.6105660144607661], 
             UndirectedEdge[66, 344] -> 
             RGBColor[
              0.8888043246674484, 0.8932966981094616, 0.6790555911354623], 
             UndirectedEdge[271, 391] -> 
             RGBColor[
              0.972119452095346, 0.926388567330202, 0.5645310757485116], 
             UndirectedEdge[203, 211] -> 
             RGBColor[
              0.9860174976701153, 0.964293147370632, 0.41741977820073994`], 
             UndirectedEdge[100, 203] -> 
             RGBColor[
              0.9933364489794337, 0.9881556630923909, 0.5160917779604803], 
             UndirectedEdge[323, 377] -> 
             RGBColor[
              0.9938162016290746, 0.9891818054995394, 0.5683098931837393], 
             UndirectedEdge[351, 395] -> 
             RGBColor[
              0.9907551893585894, 0.9788098023152316, 0.5603716156332932], 
             UndirectedEdge[179, 209] -> 
             RGBColor[
              0.8258899316204221, 0.8112861719932263, 0.6265562144232857], 
             UndirectedEdge[283, 356] -> 
             RGBColor[
              0.9865618805344945, 0.9652342099145343, 0.4956617895805639], 
             UndirectedEdge[77, 80] -> 
             RGBColor[
              0.9920302387288161, 0.9909723131479127, 0.7817430995519272], 
             UndirectedEdge[200, 398] -> 
             RGBColor[
              0.9932517295707588, 0.9895400632335987, 0.6206736503195325], 
             UndirectedEdge[280, 368] -> 
             RGBColor[
              0.9872811636120264, 0.9687585197178751, 0.40509015169378115`], 
             UndirectedEdge[3, 390] -> 
             RGBColor[
              0.9475946392910529, 0.8285845035145178, 0.28373668671421015`], 
             UndirectedEdge[64, 380] -> 
             RGBColor[
              0.9942886516215581, 0.9901923282614398, 0.6197331592421753], 
             UndirectedEdge[139, 186] -> 
             RGBColor[
              0.9560627600260104, 0.8533949062596612, 0.5056906409594554], 
             UndirectedEdge[160, 245] -> 
             RGBColor[
              0.9669529744617555, 0.8978486468517847, 0.5207053308395085], 
             UndirectedEdge[64, 360] -> 
             RGBColor[
              0.9561782024571824, 0.8516502226437019, 0.42937614125597123`], 
             UndirectedEdge[72, 337] -> 
             RGBColor[
              0.9935471360692298, 0.9886063014737325, 0.5390237674747903], 
             UndirectedEdge[11, 141] -> 
             RGBColor[
              0.9233449226382119, 0.7286808187660896, 0.26018081820800926`], 
             UndirectedEdge[62, 223] -> 
             RGBColor[
              0.9814730550961439, 0.9577524734751469, 0.5995686557761986], 
             UndirectedEdge[351, 399] -> 
             RGBColor[
              0.9663962746198388, 0.8955066514809877, 0.33855038227576484`], 
             UndirectedEdge[205, 232] -> 
             RGBColor[
              0.909666850004146, 0.9122159435097048, 0.6847227732728345], 
             UndirectedEdge[175, 379] -> 
             RGBColor[
              0.9923713878532225, 0.9896774280099616, 0.6717103102039693], 
             UndirectedEdge[144, 339] -> 
             RGBColor[
              0.9741541077368182, 0.9278910660030522, 0.5353811773165085], 
             UndirectedEdge[66, 275] -> 
             RGBColor[
              0.9871387341001193, 0.9673207272073405, 0.4859424908686587], 
             UndirectedEdge[311, 346] -> 
             RGBColor[
              0.9381842231898889, 0.8644517454595378, 0.6226707414956818], 
             UndirectedEdge[81, 326] -> 
             RGBColor[
              0.9947459727689298, 0.9914855745511117, 0.6924129225467486], 
             UndirectedEdge[145, 335] -> 
             RGBColor[
              0.9261939930667025, 0.7164537515412862, 0.45883028568240586`], 
             UndirectedEdge[24, 56] -> 
             RGBColor[
              0.9594494298733292, 0.870230165856346, 0.5250935827134524], 
             UndirectedEdge[310, 319] -> 
             RGBColor[
              0.9752307206185518, 0.9342169824895521, 0.5581861598397471], 
             UndirectedEdge[131, 303] -> 
             RGBColor[
              0.9908693123003103, 0.9888086006238782, 0.6785998285081476], 
             UndirectedEdge[146, 317] -> 
             RGBColor[
              0.9809171903900029, 0.9818075942508837, 0.704661245071604], 
             UndirectedEdge[159, 321] -> 
             RGBColor[
              0.9771735459650333, 0.9820762129950931, 0.904695452302033], 
             UndirectedEdge[339, 361] -> 
             RGBColor[
              0.98813285676719, 0.975044668848853, 0.5896859776342507], 
             UndirectedEdge[60, 297] -> 
             RGBColor[
              0.9638638578239955, 0.9725703048494138, 0.9460532422753698], 
             UndirectedEdge[1, 368] -> 
             RGBColor[
              0.992674176638348, 0.9865905211690482, 0.45664410225715807`], 
             UndirectedEdge[15, 106] -> 
             RGBColor[
              0.9897417348489894, 0.9900259579817372, 0.8196695312988485], 
             UndirectedEdge[144, 282] -> 
             RGBColor[
              0.9756765458386722, 0.9281578472575328, 0.483779723734642], 
             UndirectedEdge[333, 391] -> 
             RGBColor[
              0.973470472721365, 0.922171816439245, 0.351438225513697], 
             UndirectedEdge[85, 238] -> 
             RGBColor[
              0.9390420144622806, 0.7953942597601954, 0.273115356074514], 
             UndirectedEdge[130, 135] -> 
             RGBColor[
              0.9470491883059622, 0.9588107251652718, 0.9273947448004038], 
             UndirectedEdge[194, 256] -> 
             RGBColor[
              0.964269020164644, 0.8834473737830689, 0.4524696054008487], 
             UndirectedEdge[129, 271] -> 
             RGBColor[
              0.9914125365858143, 0.9901553090721977, 0.7511599306785423], 
             UndirectedEdge[12, 168] -> 
             RGBColor[
              0.9125267345309678, 0.9284090666304743, 0.7503518310906451], 
             UndirectedEdge[32, 271] -> 
             RGBColor[
              0.9873963083895122, 0.9890560638660327, 0.8585393175014924], 
             UndirectedEdge[227, 363] -> 
             RGBColor[
              0.9313350385149506, 0.7753035365013843, 0.573234788906591], 
             UndirectedEdge[351, 355] -> 
             RGBColor[
              0.9900756919275124, 0.9773564260178866, 0.4864125136326198], 
             UndirectedEdge[70, 285] -> 
             RGBColor[
              0.8815021013179571, 0.5465698467874793, 0.570521481878089], 
             UndirectedEdge[19, 107] -> 
             RGBColor[
              0.9861744434935216, 0.9635345389171267, 0.5275537101702545], 
             UndirectedEdge[88, 359] -> 
             RGBColor[
              0.9507527099132709, 0.8293732870621966, 0.4703778426007873], 
             UndirectedEdge[128, 130] -> 
             RGBColor[
              0.8826782859879316, 0.6890541405788488, 0.5972453417817767], 
             UndirectedEdge[72, 297] -> 
             RGBColor[
              0.9846188338749181, 0.9846937995077327, 0.708355248190305], 
             UndirectedEdge[125, 184] -> 
             RGBColor[
              0.9937164011917892, 0.9889683424555575, 0.5574472314821122], 
             UndirectedEdge[41, 63] -> 
             RGBColor[
              0.9795516713659951, 0.9498494672159953, 0.5822775134111479], 
             UndirectedEdge[67, 133] -> 
             RGBColor[
              0.9823147075399183, 0.9659487401137088, 0.6398669127242584], 
             UndirectedEdge[272, 308] -> 
             RGBColor[
              0.9925884456644494, 0.9858905394108706, 0.4912417595655245], 
             UndirectedEdge[199, 287] -> 
             RGBColor[
              0.8943732947577738, 0.9161692175736202, 0.8866350328974466], 
             UndirectedEdge[60, 333] -> 
             RGBColor[
              0.9712479331484469, 0.9721881143375728, 0.6929732325474997], 
             UndirectedEdge[86, 325] -> 
             RGBColor[
              0.9921351920668393, 0.9899013244703494, 0.6989993927578257], 
             UndirectedEdge[77, 377] -> 
             RGBColor[
              0.9928349101384188, 0.9891661243924607, 0.6129291764427095], 
             UndirectedEdge[62, 319] -> 
             RGBColor[
              0.967545257114266, 0.9021846728897152, 0.3284198817631955], 
             UndirectedEdge[52, 199] -> 
             RGBColor[
              0.8908536626239449, 0.9147137592358618, 0.9449644458709738], 
             UndirectedEdge[57, 376] -> 
             RGBColor[
              0.9387583976654215, 0.9498545038713629, 0.7957379952357937], 
             UndirectedEdge[11, 161] -> 
             RGBColor[
              0.9233354630583182, 0.7286489093818929, 0.26014406952641367`], 
             UndirectedEdge[155, 300] -> 
             RGBColor[
              0.9125307403122751, 0.8953125801923679, 0.6567694149838685], 
             UndirectedEdge[81, 275] -> 
             RGBColor[
              0.994314684475276, 0.9902480099032174, 0.622566674713233], 
             UndirectedEdge[100, 266] -> 
             RGBColor[
              0.9938692881283613, 0.9904900322323982, 0.6609286610604928], 
             UndirectedEdge[56, 266] -> 
             RGBColor[
              0.960625424906441, 0.8707164700242317, 0.5056043016371998], 
             UndirectedEdge[82, 257] -> 
             RGBColor[
              0.9672757413011713, 0.972976547009704, 0.8342919992837158], 
             UndirectedEdge[32, 259] -> 
             RGBColor[
              0.9891036419610417, 0.9897620901743316, 0.8302443817836023], 
             UndirectedEdge[261, 355] -> 
             RGBColor[
              0.9676765648588664, 0.8975241569613319, 0.42165912560188845`], 
             UndirectedEdge[74, 179] -> 
             RGBColor[
              0.8438432191496097, 0.8767652505990622, 0.8847959867078972], 
             UndirectedEdge[100, 174] -> 
             RGBColor[
              0.9943647860353266, 0.9903551720741206, 0.6280199203337449], 
             UndirectedEdge[208, 388] -> 
             RGBColor[
              0.9903782018650574, 0.9797602496879869, 0.5786509056106112], 
             UndirectedEdge[249, 299] -> 
             RGBColor[
              0.9833863388599311, 0.9556203612807164, 0.38995949300782884`], 
             UndirectedEdge[58, 181] -> 
             RGBColor[
              0.9712748647458448, 0.9194695349714308, 0.5461348535531625], 
             UndirectedEdge[271, 345] -> 
             RGBColor[
              0.9508149969388384, 0.9615995015294481, 0.9184623013474054], 
             UndirectedEdge[20, 89] -> 
             RGBColor[
              0.9896233095217069, 0.9899769860655138, 0.8216321454468443], 
             UndirectedEdge[174, 358] -> 
             RGBColor[
              0.9932355238560858, 0.9911309682459304, 0.7370713477142925], 
             UndirectedEdge[185, 274] -> 
             RGBColor[
              0.9851564719320678, 0.9607657710641038, 0.46704469338117605`], 
             UndirectedEdge[106, 314] -> 
             RGBColor[
              0.9802107309037043, 0.9837627729443561, 0.8736448509879], 
             UndirectedEdge[73, 387] -> 
             RGBColor[
              0.9939214392194422, 0.9894068980641829, 0.5797643554441203], 
             UndirectedEdge[191, 261] -> 
             RGBColor[
              0.9683733746898101, 0.8990145627314395, 0.4975025754883048], 
             UndirectedEdge[135, 227] -> 
             RGBColor[
              0.9356504157494847, 0.7780422826408033, 0.5444500438821069], 
             UndirectedEdge[102, 345] -> 
             RGBColor[
              0.9442886660124987, 0.9573970565472245, 0.9592844488272632], 
             UndirectedEdge[72, 108] -> 
             RGBColor[
              0.9274761350982681, 0.9401723130427382, 0.739050804867966], 
             UndirectedEdge[7, 273] -> 
             RGBColor[
              0.9890657795546096, 0.9809559153585734, 0.6124167991447421], 
             UndirectedEdge[111, 385] -> 
             RGBColor[
              0.9885187696593981, 0.9729332555193786, 0.4098980174855287], 
             UndirectedEdge[25, 187] -> 
             RGBColor[
              0.942804925761118, 0.9537487385371135, 0.8502452623194159], 
             UndirectedEdge[290, 338] -> 
             RGBColor[
              0.9904407800151078, 0.9885239228363762, 0.6778898793194742], 
             UndirectedEdge[133, 200] -> 
             RGBColor[
              0.989084094474344, 0.9897540067862346, 0.8305683342254571], 
             UndirectedEdge[64, 88] -> 
             RGBColor[
              0.9503327958654346, 0.8284751333736977, 0.4246727899029235], 
             UndirectedEdge[23, 92] -> 
             RGBColor[
              0.951034327829994, 0.8701646841623136, 0.5979158194002538], 
             UndirectedEdge[38, 350] -> 
             RGBColor[
              0.9642597109337412, 0.9440583680057488, 0.6561520171623464], 
             UndirectedEdge[135, 224] -> 
             RGBColor[
              0.9053046384159198, 0.5853967942781404, 0.5169809009749955], 
             UndirectedEdge[329, 358] -> 
             RGBColor[
              0.9515646922682067, 0.9615468856125224, 0.8902910805252492], 
             UndirectedEdge[4, 185] -> 
             RGBColor[
              0.9378415126607802, 0.9273837250322643, 0.6766738874196541], 
             UndirectedEdge[111, 199] -> 
             RGBColor[
              0.8914677115009996, 0.9022809272919972, 0.6894023460454084], 
             UndirectedEdge[138, 264] -> 
             RGBColor[
              0.9270982996359798, 0.9424735512206772, 0.9068684967385733], 
             UndirectedEdge[275, 344] -> 
             RGBColor[
              0.8957197798378398, 0.9156668079024506, 0.7873264795313841], 
             UndirectedEdge[300, 371] -> 
             RGBColor[
              0.9625896848064863, 0.9346547319673562, 0.6416607627841957], 
             UndirectedEdge[69, 273] -> 
             RGBColor[
              0.9867543645423836, 0.9886856179467223, 0.8644765168293538], 
             UndirectedEdge[65, 174] -> 
             RGBColor[
              0.9949294866085904, 0.9915630095003458, 0.6894840928055388], 
             UndirectedEdge[217, 254] -> 
             RGBColor[
              0.9839896162484769, 0.9873206188598762, 0.9003671653015268], 
             UndirectedEdge[102, 378] -> 
             RGBColor[
              0.9839463778541303, 0.98394266744551, 0.6896876214915808], 
             UndirectedEdge[246, 326] -> 
             RGBColor[
              0.9930320802747532, 0.9869830956399599, 0.5770078021467009], 
             UndirectedEdge[120, 242] -> 
             RGBColor[
              0.992725425848469, 0.9868487463991722, 0.4495856809526261], 
             UndirectedEdge[25, 117] -> 
             RGBColor[
              0.9950811068946048, 0.9918873099609682, 0.7059870252462651], 
             UndirectedEdge[44, 227] -> 
             RGBColor[
              0.9384387065230712, 0.7791953125314857, 0.49824084989856643`], 
             UndirectedEdge[118, 206] -> 
             RGBColor[
              0.9928235971372213, 0.991041324063618, 0.7497639395989268], 
             UndirectedEdge[151, 158] -> 
             RGBColor[
              0.9804918550180715, 0.9450285168121637, 0.44912813462159046`], 
             UndirectedEdge[151, 308] -> 
             RGBColor[
              0.9926349337660122, 0.9859899727594454, 0.4963017025293335], 
             UndirectedEdge[298, 390] -> 
             RGBColor[
              0.9611855330152912, 0.8807318301696433, 0.3037135545718009], 
             UndirectedEdge[62, 111] -> 
             RGBColor[
              0.9800875509167997, 0.9444927749562917, 0.3771443247725953], 
             UndirectedEdge[131, 201] -> 
             RGBColor[
              0.9814973384031038, 0.9850208537638976, 0.8848357905856061], 
             UndirectedEdge[291, 368] -> 
             RGBColor[
              0.9914264571480873, 0.9827415681762159, 0.42119383430837776`], 
             UndirectedEdge[35, 73] -> 
             RGBColor[
              0.993679329484884, 0.9888890498230122, 0.553412204965553], 
             UndirectedEdge[273, 293] -> 
             RGBColor[
              0.9128102914959495, 0.9309588266077593, 0.9002143393891398], 
             UndirectedEdge[4, 274] -> 
             RGBColor[
              0.9465258689456458, 0.9558524332489997, 0.7806195393329596], 
             UndirectedEdge[10, 337] -> 
             RGBColor[
              0.8960692481908958, 0.9158925212975508, 0.7835733076438918], 
             UndirectedEdge[27, 265] -> 
             RGBColor[
              0.9931632506641095, 0.9877852094089481, 0.49724021019353626`], 
             UndirectedEdge[262, 325] -> 
             RGBColor[
              0.9582355385764363, 0.8676636282994029, 0.535108140214454], 
             UndirectedEdge[46, 337] -> 
             RGBColor[
              0.9928711101430971, 0.9867003745931284, 0.5045555376198876], 
             UndirectedEdge[322, 327] -> 
             RGBColor[
              0.9679679610493778, 0.9587152913423033, 0.6751179313591984], 
             UndirectedEdge[59, 299] -> 
             RGBColor[
              0.9865994005558202, 0.965054027723941, 0.5504274147422146], 
             UndirectedEdge[254, 369] -> 
             RGBColor[
              0.9632444892468973, 0.9718489371091259, 0.9354832541195348], 
             UndirectedEdge[262, 376] -> 
             RGBColor[
              0.9047876119035458, 0.8274646629643122, 0.6241044339201098], 
             UndirectedEdge[360, 389] -> 
             RGBColor[
              0.814676034643268, 0.743831478040138, 0.6124411089401514], 
             UndirectedEdge[159, 381] -> 
             RGBColor[
              0.9906735265637976, 0.9904112778017653, 0.8042273311848172], 
             UndirectedEdge[77, 302] -> 
             RGBColor[
              0.9821596246013827, 0.9533407860374706, 0.5557345992172847], 
             UndirectedEdge[67, 398] -> 
             RGBColor[
              0.986482342636333, 0.9657347965610729, 0.42997222881833386`], 
             UndirectedEdge[12, 100] -> 
             RGBColor[
              0.9127755347419357, 0.9289412251241749, 0.7774321986375958], 
             UndirectedEdge[329, 339] -> 
             RGBColor[
              0.951681544602345, 0.9615952070556566, 0.888354534944432], 
             UndirectedEdge[1, 113] -> 
             RGBColor[
              0.9350499267756351, 0.761025044913197, 0.35396859727559365`], 
             UndirectedEdge[232, 390] -> 
             RGBColor[
              0.9713379766596426, 0.9149784064891687, 0.3431538810019956], 
             UndirectedEdge[319, 384] -> 
             RGBColor[
              0.9739487084197911, 0.9237850177451179, 0.35329608089484854`], 
             UndirectedEdge[342, 374] -> 
             RGBColor[
              0.9286376517628818, 0.736817247857693, 0.3061299777547986], 
             UndirectedEdge[200, 320] -> 
             RGBColor[
              0.9809675579489292, 0.9484317803262114, 0.5449666174694469], 
             UndirectedEdge[35, 231] -> 
             RGBColor[
              0.9946587722323522, 0.9909839788229946, 0.6600185036074877], 
             UndirectedEdge[96, 104] -> 
             RGBColor[
              0.9306526731603799, 0.7606006036688306, 0.2695784083423194], 
             UndirectedEdge[106, 197] -> 
             RGBColor[
              0.9896254815069698, 0.9824643407366287, 0.6119674876686296], 
             UndirectedEdge[41, 265] -> 
             RGBColor[
              0.9914177787996907, 0.9892281289979644, 0.683519274581849], 
             UndirectedEdge[52, 303] -> 
             RGBColor[
              0.9888261655648942, 0.9879637069423076, 0.7124600574082477], 
             UndirectedEdge[170, 208] -> 
             RGBColor[
              0.9837028612529692, 0.9572427583589018, 0.5527184678649479], 
             UndirectedEdge[49, 355] -> 
             RGBColor[
              0.9884760248736987, 0.9719603734256871, 0.4801981092003288], 
             UndirectedEdge[140, 359] -> 
             RGBColor[
              0.9937293151593662, 0.9914313788020315, 0.7358817745310163], 
             UndirectedEdge[20, 255] -> 
             RGBColor[
              0.9554553505717803, 0.8612197814339366, 0.5552764842503124], 
             UndirectedEdge[117, 362] -> 
             RGBColor[
              0.9948223228183665, 0.9913337969889782, 0.6778199755779222], 
             UndirectedEdge[188, 293] -> 
             RGBColor[
              0.914793386508198, 0.9305994599885687, 0.7816174038220758], 
             UndirectedEdge[149, 155] -> 
             RGBColor[
              0.9264364165260313, 0.9406463040994519, 0.8445798291542971], 
             UndirectedEdge[7, 188] -> 
             RGBColor[
              0.9910488745668581, 0.9805965487393828, 0.49381986357767815`], 
             UndirectedEdge[120, 331] -> 
             RGBColor[
              0.9936883723921872, 0.9889083916873553, 0.5543964696191417], 
             UndirectedEdge[169, 218] -> 
             RGBColor[
              0.9679132901942662, 0.9115669070817818, 0.5699763212027649], 
             UndirectedEdge[345, 350] -> 
             RGBColor[
              0.9342522095662048, 0.9499118837627676, 0.976273551663765], 
             UndirectedEdge[147, 217] -> 
             RGBColor[
              0.9546949336170217, 0.8676010394638691, 0.5876122312592547], 
             UndirectedEdge[141, 386] -> 
             RGBColor[
              0.9757464411451235, 0.9292768841348641, 0.40894489311029486`], 
             UndirectedEdge[128, 383] -> 
             RGBColor[
              0.9246612323403827, 0.7199759354806179, 0.5012800398244968], 
             UndirectedEdge[138, 394] -> 
             RGBColor[
              0.9067220437326298, 0.9281278801608199, 0.9794655472602647], 
             UndirectedEdge[132, 300] -> 
             RGBColor[
              0.9804712362133472, 0.9450473852928807, 0.44152938907279304`], 
             UndirectedEdge[103, 122] -> 
             RGBColor[
              0.9389834329996263, 0.7789233495301746, 0.3555792467220704], 
             UndirectedEdge[147, 195] -> 
             RGBColor[
              0.9466862860059448, 0.8233062195588146, 0.2917394710987816], 
             UndirectedEdge[123, 389] -> 
             RGBColor[
              0.8529297157465965, 0.8826799422923257, 0.8183880395563206], 
             UndirectedEdge[93, 394] -> 
             RGBColor[
              0.6379247824760508, 0.7095300343828177, 0.9570160512843982], 
             UndirectedEdge[199, 350] -> 
             RGBColor[
              0.8762269108808156, 0.9038267419558277, 0.9706905755068457], 
             UndirectedEdge[66, 158] -> 
             RGBColor[
              0.9736811310697108, 0.9228824165131475, 0.35225659341752913`], 
             UndirectedEdge[105, 215] -> 
             RGBColor[
              0.9898578880672713, 0.9808115526378938, 0.5960276180930463], 
             UndirectedEdge[253, 364] -> 
             RGBColor[
              0.7742353342406638, 0.7844640662740917, 0.6413755873346141], 
             UndirectedEdge[76, 78] -> 
             RGBColor[
              0.9940063394796852, 0.9917894815918699, 0.7489939961252174], 
             UndirectedEdge[153, 358] -> 
             RGBColor[
              0.9926081732980604, 0.9897891288371852, 0.6687881110320815], 
             UndirectedEdge[54, 64] -> 
             RGBColor[
              0.9808430680663278, 0.982609293685403, 0.7727843919189703], 
             UndirectedEdge[84, 125] -> 
             RGBColor[
              0.9719159257825372, 0.9148637900741352, 0.39359049172158184`], 
             UndirectedEdge[195, 380] -> 
             RGBColor[
              0.9803128743517672, 0.9440713111890315, 0.4784886694206371], 
             UndirectedEdge[81, 146] -> 
             RGBColor[
              0.993752360158527, 0.9890452550494007, 0.5613611430985157], 
             UndirectedEdge[275, 317] -> 
             RGBColor[
              0.9814795147067519, 0.9830103491047004, 0.7658667766863214], 
             UndirectedEdge[25, 377] -> 
             RGBColor[
              0.99396522570027, 0.9895005529191814, 0.5845302436633918], 
             UndirectedEdge[180, 232] -> 
             RGBColor[
              0.979305314718129, 0.9418541085803815, 0.3741054848536707], 
             UndirectedEdge[52, 333] -> 
             RGBColor[
              0.9876090110982444, 0.9843685892628415, 0.6643113410284576], 
             UndirectedEdge[97, 276] -> 
             RGBColor[
              0.9939969961080198, 0.9895685066088773, 0.5879882564827295], 
             UndirectedEdge[51, 390] -> 
             RGBColor[
              0.9760099953442632, 0.9346457444637586, 0.5460077668649723], 
             UndirectedEdge[199, 393] -> 
             RGBColor[
              0.8594513399723112, 0.7840960472372029, 0.6180743843546797], 
             UndirectedEdge[169, 224] -> 
             RGBColor[
              0.8860967283772961, 0.50802140178661, 0.22385865056394666`], 
             UndirectedEdge[132, 268] -> 
             RGBColor[
              0.5863142293072515, 0.6471651908968346, 0.7446609120797123], 
             UndirectedEdge[162, 183] -> 
             RGBColor[
              0.9850307180406288, 0.970804486149193, 0.6206552227592417], 
             UndirectedEdge[15, 231] -> 
             RGBColor[
              0.9919156022175879, 0.9902959121099637, 0.7379215616985018], 
             UndirectedEdge[246, 248] -> 
             RGBColor[
              0.9639237724816564, 0.8842722223874719, 0.34401769415657163`], 
             UndirectedEdge[44, 81] -> 
             RGBColor[
              0.9936154394390513, 0.9910180699658258, 0.7111487855493079], 
             UndirectedEdge[39, 197] -> 
             RGBColor[
              0.9751149898594194, 0.9726414429069914, 0.6812673641964403], 
             UndirectedEdge[57, 86] -> 
             RGBColor[
              0.9940613658417246, 0.9897061869604933, 0.5949945047525429], 
             UndirectedEdge[74, 209] -> 
             RGBColor[
              0.9730243819255817, 0.9250579700974617, 0.5409471241002348], 
             UndirectedEdge[115, 389] -> 
             RGBColor[
              0.8269628184189505, 0.8655589959176911, 0.9768022234264163], 
             UndirectedEdge[157, 168] -> 
             RGBColor[
              0.9790478379125084, 0.9404666562794943, 0.41723066636595124`], 
             UndirectedEdge[224, 363] -> 
             RGBColor[
              0.9009892611813857, 0.5826580481387214, 0.5457656459994795], 
             UndirectedEdge[47, 279] -> 
             RGBColor[
              0.9891745183108633, 0.9873949975169749, 0.6548766604941323], 
             UndirectedEdge[58, 352] -> 
             RGBColor[
              0.9914127012597934, 0.9884091060947395, 0.6242217290717105], 
             UndirectedEdge[101, 161] -> 
             RGBColor[
              0.9570300051588956, 0.8667142589456802, 0.2875701135552926], 
             UndirectedEdge[23, 98] -> 
             RGBColor[
              0.960914513483636, 0.8763398566031464, 0.5277459408249228], 
             UndirectedEdge[37, 388] -> 
             RGBColor[
              0.9871212377196004, 0.9784134113136798, 0.6326272302538538], 
             UndirectedEdge[13, 21] -> 
             RGBColor[
              0.9908022202845286, 0.9904644959625653, 0.8020945431836335], 
             UndirectedEdge[159, 375] -> 
             RGBColor[
              0.9887630441424142, 0.9896212442233645, 0.8358889690771587], 
             UndirectedEdge[130, 346] -> 
             RGBColor[
              0.9199388396031614, 0.8501047967018578, 0.627914006746082], 
             UndirectedEdge[104, 225] -> 
             RGBColor[
              0.9666727280601337, 0.8992414275105627, 0.3250302711511779], 
             UndirectedEdge[226, 252] -> 
             RGBColor[
              0.9865636565801035, 0.9654613260539606, 0.47686580505087356`], 
             UndirectedEdge[64, 283] -> 
             RGBColor[
              0.9942209767423527, 0.9900475785377995, 0.6123671662816206], 
             UndirectedEdge[262, 284] -> 
             RGBColor[
              0.9551864753891399, 0.8664011049694311, 0.5855647886698416], 
             UndirectedEdge[282, 313] -> 
             RGBColor[
              0.9943926914307857, 0.9904148588933392, 0.6310572504173244], 
             UndirectedEdge[88, 360] -> 
             RGBColor[
              0.9123511376495175, 0.6902084985719503, 0.24833387185082173`], 
             UndirectedEdge[210, 230] -> 
             RGBColor[
              0.9595856447484793, 0.8650206300413359, 0.4403411055915897], 
             UndirectedEdge[2, 138] -> 
             RGBColor[
              0.9104379786584949, 0.8791573307374263, 0.6352582107693256], 
             UndirectedEdge[178, 367] -> 
             RGBColor[
              0.9767354286305344, 0.9331852793689768, 0.36412196268563196`], 
             UndirectedEdge[54, 123] -> 
             RGBColor[
              0.9811150909537393, 0.9831911231358432, 0.8023924044830377], 
             UndirectedEdge[36, 95] -> 
             RGBColor[
              0.9782629533902787, 0.9504095128369685, 0.6111894291902584], 
             UndirectedEdge[294, 301] -> 
             RGBColor[
              0.9773593842769543, 0.9791307297330152, 0.7088223476561367], 
             UndirectedEdge[60, 337] -> 
             RGBColor[
              0.9727921600183073, 0.9764828068154134, 0.776721761559855], 
             UndirectedEdge[251, 275] -> 
             RGBColor[
              0.6606712626137774, 0.723796638220709, 0.7681444402577097], 
             UndirectedEdge[66, 311] -> 
             RGBColor[
              0.9618666525321097, 0.951170533958037, 0.6790892863344664], 
             UndirectedEdge[110, 400] -> 
             RGBColor[
              0.9699551364713331, 0.9771131704910447, 0.9357422963853369], 
             UndirectedEdge[143, 151] -> 
             RGBColor[
              0.9934739814559095, 0.9884498311529062, 0.5310613392728136], 
             UndirectedEdge[157, 206] -> 
             RGBColor[
              0.9798667825636839, 0.9422182960803532, 0.5063677377058592], 
             UndirectedEdge[226, 274] -> 
             RGBColor[
              0.9865221692916526, 0.9653725889389724, 0.4723501697328569], 
             UndirectedEdge[86, 265] -> 
             RGBColor[
              0.9937720044631417, 0.9890872722306276, 0.5634993044252247], 
             UndirectedEdge[64, 389] -> 
             RGBColor[
              0.8526576928591851, 0.8820981128418854, 0.7887800269922531], 
             UndirectedEdge[120, 356] -> 
             RGBColor[
              0.9858803041410813, 0.963776386926968, 0.42147640535947717`], 
             UndirectedEdge[164, 279] -> 
             RGBColor[
              0.9925041640287912, 0.9863754897398829, 0.4255026973503576], 
             UndirectedEdge[24, 238] -> 
             RGBColor[
              0.9557599917111906, 0.8556027729758527, 0.5221249741659516], 
             UndirectedEdge[213, 259] -> 
             RGBColor[
              0.8948813342665458, 0.916520606018966, 0.8846226931484609], 
             UndirectedEdge[73, 162] -> 
             RGBColor[
              0.9875223517254113, 0.9695159405620097, 0.41080284326279914`], 
             UndirectedEdge[257, 356] -> 
             RGBColor[
              0.9592679671596815, 0.9474173915431483, 0.6796351812976511], 
             UndirectedEdge[6, 281] -> 
             RGBColor[
              0.9722226656769568, 0.9179626702794292, 0.3465907307747591], 
             UndirectedEdge[176, 277] -> 
             RGBColor[
              0.9239031188577971, 0.7140706155155654, 0.30544057795777624`], 
             UndirectedEdge[140, 263] -> 
             RGBColor[
              0.9821301780237446, 0.953845641959177, 0.5597963169237619], 
             UndirectedEdge[54, 161] -> 
             RGBColor[
              0.9627849625155613, 0.9227176247450011, 0.6156808276088508], 
             UndirectedEdge[7, 142] -> 
             RGBColor[
              0.9568170771914135, 0.8569731905853346, 0.3337338885744786], 
             UndirectedEdge[81, 311] -> 
             RGBColor[
              0.9690426029072664, 0.9740978166539136, 0.815713470179041], 
             UndirectedEdge[204, 237] -> 
             RGBColor[
              0.9844428038119875, 0.9575615414127963, 0.5405441626001726], 
             UndirectedEdge[134, 374] -> 
             RGBColor[
              0.9593774958275069, 0.8679787743074068, 0.3313444513695226], 
             UndirectedEdge[264, 279] -> 
             RGBColor[
              0.9909089524152742, 0.9881122305920722, 0.6261325988124661], 
             UndirectedEdge[81, 344] -> 
             RGBColor[
              0.8959802750426051, 0.9162239808053383, 0.8156797749800367], 
             UndirectedEdge[287, 391] -> 
             RGBColor[
              0.9737030485996706, 0.927043425181314, 0.5382867834554721], 
             UndirectedEdge[90, 228] -> 
             RGBColor[
              0.9838119247149443, 0.9844787252974601, 0.7404055002103789], 
             UndirectedEdge[222, 259] -> 
             RGBColor[
              0.9858045145029155, 0.9877014284654241, 0.8537337966712181], 
             UndirectedEdge[143, 342] -> 
             RGBColor[
              0.9325424076968352, 0.7496184600208815, 0.3527993121160125], 
             UndirectedEdge[68, 262] -> 
             RGBColor[
              0.9303206483029602, 0.7614516203283981, 0.26279256192120826`], 
             UndirectedEdge[73, 189] -> 
             RGBColor[
              0.976032384100756, 0.9779307939416283, 0.6943852833233704], 
             UndirectedEdge[79, 176] -> 
             RGBColor[
              0.9260708081891054, 0.724868830515172, 0.49565269475741464`], 
             UndirectedEdge[14, 289] -> 
             RGBColor[
              0.9693748285626644, 0.9181437668713884, 0.5749806597149616], 
             UndirectedEdge[126, 373] -> 
             RGBColor[
              0.9530169762753391, 0.9601946126235834, 0.7136600193317024], 
             UndirectedEdge[313, 361] -> 
             RGBColor[
              0.9891865168013179, 0.9743087812172002, 0.48706092434326764`], 
             UndirectedEdge[56, 203] -> 
             RGBColor[
              0.9600925857575136, 0.8683821008842243, 0.3607674185371873], 
             UndirectedEdge[163, 240] -> 
             RGBColor[
              0.9878863859745889, 0.9892587235418814, 0.8504174636366372], 
             UndirectedEdge[283, 380] -> 
             RGBColor[
              0.9943497676908112, 0.9903230493537898, 0.6263852662157228], 
             UndirectedEdge[165, 318] -> 
             RGBColor[
              0.9876449271317116, 0.9682908909850862, 0.5506073817915458], 
             UndirectedEdge[184, 185] -> 
             RGBColor[
              0.9853209639577296, 0.9611176028742994, 0.4849486352473487], 
             UndirectedEdge[123, 364] -> 
             RGBColor[
              0.788579280051116, 0.8314912346614247, 0.812601597427512], 
             UndirectedEdge[24, 341] -> 
             RGBColor[
              0.9930942439251084, 0.9908613213472337, 0.7240589655852001], 
             UndirectedEdge[10, 364] -> 
             RGBColor[
              0.6903043144713064, 0.7570725858787044, 0.9703941487843669], 
             UndirectedEdge[59, 132] -> 
             RGBColor[
              0.9943868660796293, 0.9905833272573508, 0.643574767138746], 
             UndirectedEdge[110, 309] -> 
             RGBColor[
              0.9815318050534203, 0.9831221928688592, 0.7715582582225743], 
             UndirectedEdge[28, 50] -> 
             RGBColor[
              0.9898339198809316, 0.9881587545052429, 0.6796448196794262], 
             UndirectedEdge[120, 147] -> 
             RGBColor[
              0.9600416029515757, 0.8681001347360063, 0.36545068367278055`], 
             UndirectedEdge[322, 335] -> 
             RGBColor[
              0.9888343298186375, 0.972354171086419, 0.5508789379554289], 
             UndirectedEdge[9, 198] -> 
             RGBColor[
              0.9931690382109257, 0.9877975883863774, 0.4978701489478955], 
             UndirectedEdge[214, 257] -> 
             RGBColor[
              0.9662920823982442, 0.9708726000795135, 0.7272267981391545], 
             UndirectedEdge[190, 274] -> 
             RGBColor[
              0.9899904888201636, 0.9888855445662845, 0.7251737338498768], 
             UndirectedEdge[18, 198] -> 
             RGBColor[
              0.990475281713154, 0.9794809122028381, 0.4219304260798823], 
             UndirectedEdge[280, 291] -> 
             RGBColor[
              0.9864454115344135, 0.9659393317161666, 0.40184341269079127`], 
             UndirectedEdge[156, 179] -> 
             RGBColor[
              0.8414244591339219, 0.8757650311732783, 0.9248810997181101], 
             UndirectedEdge[76, 96] -> 
             RGBColor[
              0.9473505003201285, 0.8176680879733407, 0.4972688852634018], 
             UndirectedEdge[143, 158] -> 
             RGBColor[
              0.9801211096475317, 0.9442355299526861, 0.40877478901354436`], 
             UndirectedEdge[252, 274] -> 
             RGBColor[
              0.9938823155053844, 0.9893232163958274, 0.5755059806124982], 
             UndirectedEdge[272, 348] -> 
             RGBColor[
              0.9912930271777844, 0.9893473316051409, 0.6980014061064963], 
             UndirectedEdge[51, 232] -> 
             RGBColor[
              0.9868105324736764, 0.9710784922879847, 0.5879658141024475], 
             UndirectedEdge[66, 317] -> 
             RGBColor[
              0.9745640595363605, 0.9606402393117114, 0.6575958882903996], 
             UndirectedEdge[258, 264] -> 
             RGBColor[
              0.9886229825488486, 0.9895633251550062, 0.8382101521503262], 
             UndirectedEdge[17, 223] -> 
             RGBColor[
              0.9672021762580854, 0.9743740302301753, 0.9096824386723266], 
             UndirectedEdge[46, 271] -> 
             RGBColor[
              0.9899758626472177, 0.9866224330062447, 0.6338998588423467], 
             UndirectedEdge[93, 201] -> 
             RGBColor[
              0.6509373822248493, 0.719234809969295, 0.9349891141392458], 
             UndirectedEdge[232, 373] -> 
             RGBColor[
              0.9873682492818934, 0.9689936585710552, 0.4104132173954247], 
             UndirectedEdge[182, 208] -> 
             RGBColor[
              0.99410505848152, 0.9911228307134463, 0.6959320956242432], 
             UndirectedEdge[10, 391] -> 
             RGBColor[
              0.8770994266886327, 0.8528172064004244, 0.6321296340320782], 
             UndirectedEdge[284, 366] -> 
             RGBColor[
              0.9847486276440556, 0.9749252638929164, 0.6545563807815749], 
             UndirectedEdge[154, 387] -> 
             RGBColor[
              0.9088049295384839, 0.9267192469854988, 0.8535832314058713], 
             UndirectedEdge[135, 363] -> 
             RGBColor[
              0.9827637404163541, 0.9861861512047625, 0.8925807339282951], 
             UndirectedEdge[37, 269] -> 
             RGBColor[
              0.7400501925811674, 0.7940794990410496, 0.9072220373599458], 
             UndirectedEdge[201, 281] -> 
             RGBColor[
              0.969877760126929, 0.93736824485059, 0.6235458275476876], 
             UndirectedEdge[302, 377] -> 
             RGBColor[
              0.9821273191875439, 0.9511884858562024, 0.4007915480990768], 
             UndirectedEdge[179, 286] -> 
             RGBColor[
              0.8457448537847151, 0.8771193665463124, 0.8218603247183807], 
             UndirectedEdge[108, 325] -> 
             RGBColor[
              0.9260613348574958, 0.9414612268342668, 0.898715546229819], 
             UndirectedEdge[279, 299] -> 
             RGBColor[
              0.985315345797838, 0.9621266362333663, 0.3975144083583597], 
             UndirectedEdge[196, 332] -> 
             RGBColor[
              0.9879178351167732, 0.9785843135725207, 0.6183299260953165], 
             UndirectedEdge[31, 224] -> 
             RGBColor[
              0.9085056627851571, 0.5851669451055769, 0.35100459399255346`], 
             UndirectedEdge[200, 296] -> 
             RGBColor[
              0.9480532958796406, 0.8211782942731336, 0.4992006245177515], 
             UndirectedEdge[170, 221] -> 
             RGBColor[
              0.9837494139825416, 0.9560191403258198, 0.46160352851905645`], 
             UndirectedEdge[198, 206] -> 
             RGBColor[
              0.9937845743531027, 0.9891141579542435, 0.5648674593751194], 
             UndirectedEdge[36, 361] -> 
             RGBColor[
              0.9852074525084193, 0.9738349390083911, 0.6381674969056165], 
             UndirectedEdge[132, 180] -> 
             RGBColor[
              0.9850867871308526, 0.9606167223205186, 0.4594599328136475], 
             UndirectedEdge[127, 312] -> 
             RGBColor[
              0.808871857819844, 0.7432883750562442, 0.6127464157612443], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.9596830463713194, 0.8657694328609806, 0.4189605039424348], 
             UndirectedEdge[67, 75] -> 
             RGBColor[
              0.9852595640004349, 0.9619391895338149, 0.3972366189498008], 
             UndirectedEdge[110, 287] -> 
             RGBColor[
              0.9801330296266859, 0.9835127587758701, 0.8651753300523839], 
             UndirectedEdge[88, 233] -> 
             RGBColor[
              0.8707690956974405, 0.468656913770399, 0.21240547506054197`], 
             UndirectedEdge[168, 216] -> 
             RGBColor[
              0.9418697145408439, 0.9518063623963755, 0.7531505907187745], 
             UndirectedEdge[1, 291] -> 
             RGBColor[
              0.9918384245607349, 0.9837713331673397, 0.4533973632541682], 
             UndirectedEdge[115, 214] -> 
             RGBColor[
              0.9678300052635691, 0.9720195804343553, 0.724623495882683], 
             UndirectedEdge[233, 256] -> 
             RGBColor[
              0.9147496548062192, 0.6304269466315784, 0.4101546518848953], 
             UndirectedEdge[4, 252] -> 
             RGBColor[
              0.9465673562340968, 0.955941170363988, 0.7851351746509763], 
             UndirectedEdge[91, 399] -> 
             RGBColor[
              0.942878043620825, 0.8112375082598022, 0.27289653695391414`], 
             UndirectedEdge[76, 269] -> 
             RGBColor[
              0.7432439411443365, 0.7954001961475141, 0.854293358511901], 
             UndirectedEdge[91, 172] -> 
             RGBColor[
              0.8252123552468504, 0.7856044782126377, 0.6209188798170251], 
             UndirectedEdge[165, 184] -> 
             RGBColor[
              0.9947093617970069, 0.9910921847864012, 0.6655248655175391], 
             UndirectedEdge[60, 139] -> 
             RGBColor[
              0.9351303131655415, 0.8393240528110074, 0.6101119456518338], 
             UndirectedEdge[356, 359] -> 
             RGBColor[
              0.9869206785130775, 0.9660016425106833, 0.5347147353048802], 
             UndirectedEdge[228, 305] -> 
             RGBColor[
              0.9802416765942674, 0.9843973515480198, 0.9009766586372674], 
             UndirectedEdge[141, 209] -> 
             RGBColor[
              0.9565668315638741, 0.8648881149123324, 0.28714438993332414`], 
             UndirectedEdge[171, 348] -> 
             RGBColor[
              0.9909961868652117, 0.9887124201917071, 0.6656921699690146], 
             UndirectedEdge[10, 60] -> 
             RGBColor[
              0.8748768871157144, 0.9028335042987521, 0.9736646410658808], 
             UndirectedEdge[234, 298] -> 
             RGBColor[
              0.9750287687529541, 0.9274283148591027, 0.35749191133690705`], 
             UndirectedEdge[323, 388] -> 
             RGBColor[
              0.9909190016641032, 0.9795937761604647, 0.5413317096375743], 
             UndirectedEdge[294, 329] -> 
             RGBColor[
              0.9366847010027191, 0.9516773076164471, 0.9704666768924257], 
             UndirectedEdge[211, 238] -> 
             RGBColor[
              0.9495891602916315, 0.8309722592302046, 0.3140890259601788], 
             UndirectedEdge[31, 99] -> 
             RGBColor[
              0.9707808920167649, 0.9101645898031931, 0.40446301253606487`], 
             UndirectedEdge[111, 319] -> 
             RGBColor[
              0.9730077587942967, 0.9206109737128465, 0.3496406692832292], 
             UndirectedEdge[258, 394] -> 
             RGBColor[
              0.9682467266454986, 0.9752176540951489, 0.9108072026720178], 
             UndirectedEdge[101, 364] -> 
             RGBColor[
              0.7692355072002671, 0.7675984756516172, 0.6219522034207838], 
             UndirectedEdge[225, 349] -> 
             RGBColor[
              0.9833096743221665, 0.9562837359992995, 0.5537297021021238], 
             UndirectedEdge[118, 386] -> 
             RGBColor[
              0.992047902983956, 0.9893821927044925, 0.6653344180453955], 
             UndirectedEdge[95, 326] -> 
             RGBColor[
              0.9827384439305566, 0.952260243190234, 0.5370189687396113], 
             UndirectedEdge[228, 382] -> 
             RGBColor[
              0.9827875886491807, 0.9854501516096819, 0.8587843072781585], 
             UndirectedEdge[120, 255] -> 
             RGBColor[
              0.9580640976652084, 0.8602599852401323, 0.3638595365013544], 
             UndirectedEdge[222, 292] -> 
             RGBColor[
              0.986805482867008, 0.9866734860937139, 0.7323365406268936], 
             UndirectedEdge[325, 397] -> 
             RGBColor[
              0.9885511306299168, 0.989533612540018, 0.8394009243938305], 
             UndirectedEdge[155, 299] -> 
             RGBColor[
              0.9179734971896218, 0.9136722771597465, 0.6779134976739686], 
             UndirectedEdge[17, 99] -> 
             RGBColor[
              0.9470819546024093, 0.8955867841252745, 0.6266168765890101], 
             UndirectedEdge[60, 105] -> 
             RGBColor[
              0.9717257829292791, 0.9771611501415883, 0.8757569671758958], 
             UndirectedEdge[229, 340] -> 
             RGBColor[
              0.9642647307982375, 0.9708410390342466, 0.8507384978187382], 
             UndirectedEdge[297, 375] -> 
             RGBColor[
              0.9834656697634213, 0.9860909065624586, 0.8636840017974649], 
             UndirectedEdge[155, 249] -> 
             RGBColor[
              0.9232333084826682, 0.9314148557136133, 0.6983468713154357], 
             UndirectedEdge[143, 348] -> 
             RGBColor[
              0.9909687699088074, 0.988653778094238, 0.6627080034622591], 
             UndirectedEdge[175, 294] -> 
             RGBColor[
              0.9777201930590629, 0.9799024632345816, 0.7480941569349517], 
             UndirectedEdge[19, 181] -> 
             RGBColor[
              0.9736248125727407, 0.920127690903061, 0.48439415391453217`], 
             UndirectedEdge[153, 294] -> 
             RGBColor[
              0.9777281820325727, 0.9799195508411098, 0.7489637073992581], 
             UndirectedEdge[68, 376] -> 
             RGBColor[
              0.9089173336170602, 0.8438376334102142, 0.6274273049478309], 
             UndirectedEdge[317, 354] -> 
             RGBColor[
              0.9765511128416899, 0.9820315441342116, 0.9245369608832608], 
             UndirectedEdge[2, 254] -> 
             RGBColor[
              0.9708733649940349, 0.9257966525433848, 0.5846523294765951], 
             UndirectedEdge[243, 311] -> 
             RGBColor[
              0.9683540458370896, 0.9744228450238552, 0.871448078626536], 
             UndirectedEdge[23, 143] -> 
             RGBColor[
              0.9617783408908696, 0.8748174810172926, 0.37680370374293404`], 
             UndirectedEdge[20, 64] -> 
             RGBColor[
              0.9909306532555117, 0.9895495517440376, 0.7295987298094919], 
             UndirectedEdge[75, 296] -> 
             RGBColor[
              0.9466150500152543, 0.8153562182413006, 0.32920967937213996`], 
             UndirectedEdge[146, 227] -> 
             RGBColor[
              0.938575627242547, 0.7772224976150608, 0.3484532074477743], 
             UndirectedEdge[160, 238] -> 
             RGBColor[
              0.9305678244370288, 0.7624315913334159, 0.26299144564064936`], 
             UndirectedEdge[75, 178] -> 
             RGBColor[
              0.983405114479224, 0.9556836958533164, 0.3900324327433035], 
             UndirectedEdge[95, 166] -> 
             RGBColor[
              0.7765073878288022, 0.7921282365304344, 0.6502020864832138], 
             UndirectedEdge[25, 309] -> 
             RGBColor[
              0.9946433083199038, 0.9909509030779087, 0.6583353521696842], 
             UndirectedEdge[166, 326] -> 
             RGBColor[
              0.788685709756064, 0.832033959636319, 0.8470889926752138], 
             UndirectedEdge[158, 308] -> 
             RGBColor[
              0.9792820619576343, 0.9417756715592253, 0.37401515227006427`], 
             UndirectedEdge[229, 343] -> 
             RGBColor[
              0.8995056812483126, 0.9227054300688702, 0.990276848947307], 
             UndirectedEdge[229, 294] -> 
             RGBColor[
              0.9476265468715965, 0.960402038503796, 0.9715103199193005], 
             UndirectedEdge[64, 257] -> 
             RGBColor[
              0.96692706336754, 0.9722307601664133, 0.7963405579987077], 
             UndirectedEdge[56, 65] -> 
             RGBColor[
              0.9611622503363524, 0.870670005258682, 0.477193806739214], 
             UndirectedEdge[170, 192] -> 
             RGBColor[
              0.9814679204360345, 0.9563185528957403, 0.5897572210429856], 
             UndirectedEdge[133, 347] -> 
             RGBColor[
              0.8643580383673031, 0.8939454936135424, 0.9391639056678154], 
             UndirectedEdge[223, 393] -> 
             RGBColor[
              0.9549191852474862, 0.8579938942434839, 0.5494614816055036], 
             UndirectedEdge[116, 338] -> 
             RGBColor[
              0.9914500755288825, 0.9906827038849104, 0.7877454673439506], 
             UndirectedEdge[32, 71] -> 
             RGBColor[
              0.990022203815789, 0.9885578886117081, 0.6998776857510807], 
             UndirectedEdge[95, 361] -> 
             RGBColor[
              0.9775046211214355, 0.935779946255772, 0.3671101302629694], 
             UndirectedEdge[247, 292] -> 
             RGBColor[
              0.9924319382972107, 0.9896965577286758, 0.6702772783102475], 
             UndirectedEdge[337, 391] -> 
             RGBColor[
              0.9750146995912254, 0.9264665089170858, 0.4351867545260524], 
             UndirectedEdge[181, 238] -> 
             RGBColor[
              0.9361529800316748, 0.7845748721234148, 0.26748539293255286`], 
             UndirectedEdge[97, 246] -> 
             RGBColor[
              0.9925022444495379, 0.9855347477867391, 0.4964352636675797], 
             UndirectedEdge[62, 247] -> 
             RGBColor[
              0.9829391479291083, 0.9583587405384448, 0.5752717034073507], 
             UndirectedEdge[207, 280] -> 
             RGBColor[
              0.9877023247448968, 0.9698079491469276, 0.4382943603487506], 
             UndirectedEdge[145, 221] -> 
             RGBColor[
              0.9255316252850478, 0.7150370138319826, 0.38673564030941643`], 
             UndirectedEdge[10, 334] -> 
             RGBColor[
              0.8594344223998258, 0.7828055635682876, 0.6177898569893938], 
             UndirectedEdge[25, 78] -> 
             RGBColor[
              0.9947593789322146, 0.9919678967518322, 0.7268475048366354], 
             UndirectedEdge[46, 139] -> 
             RGBColor[
              0.9552092632903313, 0.8495416205887224, 0.33794572171186643`], 
             UndirectedEdge[224, 383] -> 
             RGBColor[
              0.9072576554234447, 0.5862044170009997, 0.48461435491430815`], 
             UndirectedEdge[138, 164] -> 
             RGBColor[
              0.9286935112494967, 0.9407368103684879, 0.7062385952764648], 
             UndirectedEdge[53, 93] -> 
             RGBColor[
              0.6604580320436622, 0.7233405595921502, 0.744935608607207], 
             UndirectedEdge[31, 199] -> 
             RGBColor[
              0.8954332683972658, 0.915053988901813, 0.7561414773685574], 
             UndirectedEdge[98, 342] -> 
             RGBColor[
              0.9316785802896017, 0.7511408356067353, 0.5037415491980013], 
             UndirectedEdge[141, 304] -> 
             RGBColor[
              0.7763653313114658, 0.7760073561516925, 0.6264075126123123], 
             UndirectedEdge[32, 105] -> 
             RGBColor[
              0.9892251787963634, 0.9898123487790913, 0.8282302018950741], 
             UndirectedEdge[216, 329] -> 
             RGBColor[
              0.9009710562142507, 0.9238738802901654, 0.9904166177197138], 
             UndirectedEdge[164, 264] -> 
             RGBColor[
              0.9909089524152742, 0.9881122305920722, 0.6261325988124661], 
             UndirectedEdge[118, 196] -> 
             RGBColor[
              0.9898000352805157, 0.9900500667084261, 0.8187033422717773], 
             UndirectedEdge[75, 398] -> 
             RGBColor[
              0.9918134837063723, 0.9837179872017655, 0.45068270517392095`], 
             UndirectedEdge[45, 48] -> 
             RGBColor[
              0.834248607812094, 0.8210225076464761, 0.6303129736158289], 
             UndirectedEdge[248, 275] -> 
             RGBColor[
              0.9653771697710676, 0.8882175283957361, 0.4310695191079666], 
             UndirectedEdge[200, 347] -> 
             RGBColor[
              0.8687411406922061, 0.8957580190654815, 0.8665245570389691], 
             UndirectedEdge[33, 58] -> 
             RGBColor[
              0.9814597407287113, 0.9548995093090472, 0.5801077834215864], 
             UndirectedEdge[134, 240] -> 
             RGBColor[
              0.959936498023747, 0.8812760217361986, 0.5700879651282207], 
             UndirectedEdge[267, 344] -> 
             RGBColor[
              0.8885605342645235, 0.8924743358356872, 0.6781085114560539], 
             UndirectedEdge[141, 286] -> 
             RGBColor[
              0.9764217537281671, 0.9307213094654185, 0.4824485002284192], 
             UndirectedEdge[33, 209] -> 
             RGBColor[
              0.9638859981042927, 0.8895773822751923, 0.3155779698342257], 
             UndirectedEdge[47, 155] -> 
             RGBColor[
              0.9218326697026472, 0.9389406384433552, 0.9352757498097412], 
             UndirectedEdge[153, 229] -> 
             RGBColor[
              0.9635318228086174, 0.9692734229528135, 0.770965986132397], 
             UndirectedEdge[64, 161] -> 
             RGBColor[
              0.9761017551223331, 0.9300251885050476, 0.4486114949979534], 
             UndirectedEdge[3, 293] -> 
             RGBColor[
              0.8851618841607543, 0.8252147386631008, 0.6252329341812085], 
             UndirectedEdge[133, 178] -> 
             RGBColor[
              0.9804602580187074, 0.9596932464332104, 0.6326627265177612], 
             UndirectedEdge[113, 162] -> 
             RGBColor[
              0.9297322056562329, 0.7434470207434429, 0.3027071415529145], 
             UndirectedEdge[313, 358] -> 
             RGBColor[
              0.9927534009947934, 0.9900997561957243, 0.6845952495800081], 
             UndirectedEdge[259, 292] -> 
             RGBColor[
              0.9926096616088813, 0.9897700508853323, 0.6673319431026796], 
             UndirectedEdge[4, 165] -> 
             RGBColor[
              0.9472299105000574, 0.9573583069443661, 0.8572501176898444], 
             UndirectedEdge[247, 385] -> 
             RGBColor[
              0.9913703666717067, 0.9867992211015317, 0.6080253961202842], 
             UndirectedEdge[38, 243] -> 
             RGBColor[
              0.9833245180253538, 0.956780635225201, 0.5568758250830326], 
             UndirectedEdge[265, 381] -> 
             RGBColor[
              0.994089081510388, 0.990332781318186, 0.6392488755557848], 
             UndirectedEdge[15, 369] -> 
             RGBColor[
              0.9650068323270603, 0.9725777112629246, 0.9062766684835424], 
             UndirectedEdge[30, 358] -> 
             RGBColor[
              0.9925599728978272, 0.9896860330548943, 0.6635417949250878], 
             UndirectedEdge[133, 330] -> 
             RGBColor[
              0.9170246350797266, 0.9353263797736933, 0.9443502369523493], 
             UndirectedEdge[223, 292] -> 
             RGBColor[
              0.9909658454642463, 0.9890902906653778, 0.6945742306790954], 
             UndirectedEdge[44, 326] -> 
             RGBColor[
              0.9937862325279397, 0.9916984617108324, 0.7526417379341707], 
             UndirectedEdge[123, 356] -> 
             RGBColor[
              0.9867727873526526, 0.9656853182726246, 0.5186176951710838], 
             UndirectedEdge[35, 154] -> 
             RGBColor[
              0.9085628198039257, 0.926201398744328, 0.827231080927304], 
             UndirectedEdge[146, 151] -> 
             RGBColor[
              0.993387133731731, 0.9882640726525401, 0.5216085004580027], 
             UndirectedEdge[111, 287] -> 
             RGBColor[
              0.9884556358536046, 0.9768073660610459, 0.5955977991446672], 
             UndirectedEdge[42, 133] -> 
             RGBColor[
              0.9898006737980167, 0.9897210911123699, 0.7947605142265219], 
             UndirectedEdge[40, 103] -> 
             RGBColor[
              0.9386608844347858, 0.7807110049480492, 0.5005638607202277], 
             UndirectedEdge[219, 260] -> 
             RGBColor[
              0.893726386343671, 0.6635692481909163, 0.5910247929515542], 
             UndirectedEdge[151, 186] -> 
             RGBColor[
              0.9936547097452566, 0.990404157363153, 0.6646925852389733], 
             UndirectedEdge[8, 76] -> 
             RGBColor[
              0.9813623601622217, 0.9495347983389606, 0.5449192894890642], 
             UndirectedEdge[124, 167] -> 
             RGBColor[
              0.9658015673393741, 0.8903413307248766, 0.40530269913509087`], 
             UndirectedEdge[162, 291] -> 
             RGBColor[
              0.9865207034413327, 0.9661933089975857, 0.40213590753148903`], 
             UndirectedEdge[242, 255] -> 
             RGBColor[
              0.9578705834888975, 0.8598460779842878, 0.3427967126409858], 
             UndirectedEdge[182, 323] -> 
             RGBColor[
              0.9946458582805657, 0.9909563571859241, 0.6586128996512063], 
             UndirectedEdge[138, 149] -> 
             RGBColor[
              0.9299676123549528, 0.9434619838016767, 0.8449166377647954], 
             UndirectedEdge[199, 353] -> 
             RGBColor[
              0.8831451052740809, 0.9089863200068213, 0.958979876953125], 
             UndirectedEdge[34, 381] -> 
             RGBColor[
              0.9909453250789401, 0.9905236734726799, 0.7997229263968975], 
             UndirectedEdge[148, 305] -> 
             RGBColor[
              0.9762702295143222, 0.9428608525950591, 0.5977337138286827], 
             UndirectedEdge[97, 383] -> 
             RGBColor[
              0.9924211229366628, 0.9899047066897886, 0.6859118473779027], 
             UndirectedEdge[154, 207] -> 
             RGBColor[
              0.907732756884078, 0.9244259780910083, 0.7368838546564083], 
             UndirectedEdge[272, 375] -> 
             RGBColor[
              0.9922775867226507, 0.9897544722789692, 0.681684706489638], 
             UndirectedEdge[25, 323] -> 
             RGBColor[
              0.9949788226047647, 0.9916685342075282, 0.6948540115226294], 
             UndirectedEdge[236, 334] -> 
             RGBColor[
              0.9402411241321662, 0.8464415329106538, 0.6040255198193034], 
             UndirectedEdge[23, 346] -> 
             RGBColor[
              0.9316559329708278, 0.766745579079255, 0.2638669633081341], 
             UndirectedEdge[23, 151] -> 
             RGBColor[
              0.9621490862614093, 0.8756104678767702, 0.41715704935098014`], 
             UndirectedEdge[250, 381] -> 
             RGBColor[
              0.9944953684616968, 0.9912017880251236, 0.6834707028933285], 
             UndirectedEdge[230, 264] -> 
             RGBColor[
              0.9918129143692035, 0.9900457138069537, 0.7245232788911573], 
             UndirectedEdge[60, 68] -> 
             RGBColor[
              0.9430250844798003, 0.8706241902954575, 0.6164642639653866], 
             UndirectedEdge[50, 258] -> 
             RGBColor[
              0.9872633289845294, 0.9890010734646575, 0.860743130381724], 
             UndirectedEdge[121, 298] -> 
             RGBColor[
              0.977626034008002, 0.9372321861748985, 0.532484131099755], 
             UndirectedEdge[95, 382] -> 
             RGBColor[
              0.9810881951573739, 0.9515778229130639, 0.5643678616181735], 
             UndirectedEdge[42, 200] -> 
             RGBColor[
              0.9941837761229195, 0.9915336165643089, 0.7221211655976758], 
             UndirectedEdge[254, 314] -> 
             RGBColor[
              0.9779849702761599, 0.9828423637254275, 0.9105314646701699], 
             UndirectedEdge[95, 305] -> 
             RGBColor[
              0.9785422831024606, 0.9505250228514018, 0.6065602129772824], 
             UndirectedEdge[321, 381] -> 
             RGBColor[
              0.9811244070659801, 0.9837099955928337, 0.8392194593585669], 
             UndirectedEdge[116, 209] -> 
             RGBColor[
              0.9751477436496496, 0.9258863378679556, 0.5021450874033272], 
             UndirectedEdge[364, 366] -> 
             RGBColor[
              0.7838849423767934, 0.817014460352993, 0.678862492767885], 
             UndirectedEdge[58, 156] -> 
             RGBColor[
              0.9881793645343125, 0.9893798777055327, 0.8455620506978083], 
             UndirectedEdge[118, 179] -> 
             RGBColor[
              0.8436871306267346, 0.8767007039835613, 0.8873827774760872], 
             UndirectedEdge[149, 328] -> 
             RGBColor[
              0.9795518041492484, 0.9411121881400588, 0.5088525376945406], 
             UndirectedEdge[215, 227] -> 
             RGBColor[
              0.9360428615335957, 0.7689421313733253, 0.3162292478382739], 
             UndirectedEdge[70, 177] -> 
             RGBColor[
              0.8390085163567897, 0.5129441322664156, 0.5753966703930337], 
             UndirectedEdge[383, 393] -> 
             RGBColor[
              0.9562512306026958, 0.8585447292298674, 0.527386042846804], 
             UndirectedEdge[14, 201] -> 
             RGBColor[
              0.9633067100775663, 0.9140386095181269, 0.6040803611646464], 
             UndirectedEdge[5, 368] -> 
             RGBColor[
              0.9903126629056133, 0.9789844786650268, 0.4168669539987604], 
             UndirectedEdge[214, 310] -> 
             RGBColor[
              0.9914429374899243, 0.9886658153022421, 0.6414718164973157], 
             UndirectedEdge[35, 280] -> 
             RGBColor[
              0.9885323876647447, 0.9715833698002473, 0.5286415866196462], 
             UndirectedEdge[243, 275] -> 
             RGBColor[
              0.9936261274050993, 0.9905730382731588, 0.6783012831607282], 
             UndirectedEdge[131, 391] -> 
             RGBColor[
              0.9722265632012577, 0.9264328605251264, 0.5627559675288992], 
             UndirectedEdge[2, 314] -> 
             RGBColor[
              0.9631047041289127, 0.9202622416598024, 0.6094210635296542], 
             UndirectedEdge[282, 361] -> 
             RGBColor[
              0.989655294869044, 0.9753114501033336, 0.5380845240523842], 
             UndirectedEdge[110, 269] -> 
             RGBColor[
              0.7308854773303823, 0.787749901098427, 0.9453697732762091], 
             UndirectedEdge[193, 360] -> 
             RGBColor[
              0.9565080329349419, 0.8523556966846528, 0.4652761532823303], 
             UndirectedEdge[71, 400] -> 
             RGBColor[
              0.9822256248769783, 0.9831430349524071, 0.7309801128722861], 
             UndirectedEdge[110, 117] -> 
             RGBColor[
              0.9819696036281214, 0.9840585997519187, 0.8192099312991552], 
             UndirectedEdge[170, 351] -> 
             RGBColor[
              0.9799815855084595, 0.944135328752099, 0.3767326691710818], 
             UndirectedEdge[121, 200] -> 
             RGBColor[
              0.9934428191574488, 0.9915564514568134, 0.7583329862085199], 
             UndirectedEdge[38, 383] -> 
             RGBColor[
              0.982218061088479, 0.956323086847157, 0.5752126799458128], 
             UndirectedEdge[172, 256] -> 
             RGBColor[
              0.8528111871602988, 0.8824264216313131, 0.805486934411457], 
             UndirectedEdge[127, 258] -> 
             RGBColor[
              0.9543181035253832, 0.8563012124298118, 0.5523562855575527], 
             UndirectedEdge[25, 388] -> 
             RGBColor[
              0.9910680257352986, 0.9799125235801067, 0.5575520601172269], 
             UndirectedEdge[51, 277] -> 
             RGBColor[
              0.9894572515030583, 0.9800064970532703, 0.598247817740646], 
             UndirectedEdge[85, 379] -> 
             RGBColor[
              0.9746172571957705, 0.9304763977999698, 0.5442515010620497], 
             UndirectedEdge[267, 306] -> 
             RGBColor[
              0.9841622415072204, 0.9582376631006286, 0.3929737282756277], 
             UndirectedEdge[176, 298] -> 
             RGBColor[
              0.9111039561840639, 0.6708960344307544, 0.25571824788938313`], 
             UndirectedEdge[269, 323] -> 
             RGBColor[
              0.7438479565256704, 0.7952598638878345, 0.8159265167436663], 
             UndirectedEdge[21, 180] -> 
             RGBColor[
              0.9817001861126274, 0.9605797876304898, 0.6146975943822531], 
             UndirectedEdge[36, 228] -> 
             RGBColor[
              0.9799623468820855, 0.9842818415335863, 0.9056058748502434], 
             UndirectedEdge[74, 116] -> 
             RGBColor[
              0.9931010311788373, 0.9913654164737915, 0.7603848596879387], 
             UndirectedEdge[3, 188] -> 
             RGBColor[
              0.9642833413993203, 0.8840080696895609, 0.42266200930476705`], 
             UndirectedEdge[69, 394] -> 
             RGBColor[
              0.9660606521787789, 0.9742086704822907, 0.9423346424484513], 
             UndirectedEdge[37, 395] -> 
             RGBColor[
              0.9912195009576421, 0.9905703935477274, 0.7903337389704019], 
             UndirectedEdge[172, 194] -> 
             RGBColor[
              0.8226133580496158, 0.7753003203900772, 0.6188276656658249], 
             UndirectedEdge[59, 264] -> 
             RGBColor[
              0.9921930071732564, 0.991039622082647, 0.7790456051963209], 
             UndirectedEdge[28, 369] -> 
             RGBColor[
              0.9669043767206285, 0.9714570702780819, 0.7363324801217206], 
             UndirectedEdge[130, 344] -> 
             RGBColor[
              0.8522023146831025, 0.8851696658954669, 0.9857165402475921], 
             UndirectedEdge[29, 270] -> 
             RGBColor[
              0.9397817177904492, 0.9432211238182904, 0.6978818955858852], 
             UndirectedEdge[41, 48] -> 
             RGBColor[
              0.8502186536443104, 0.882057561998692, 0.8995685654849566], 
             UndirectedEdge[12, 124] -> 
             RGBColor[
              0.8848709567502551, 0.8303361496425783, 0.6264039534396858], 
             UndirectedEdge[61, 95] -> 
             RGBColor[
              0.9477113405552487, 0.8260833177759863, 0.2992664588920466], 
             UndirectedEdge[213, 306] -> 
             RGBColor[
              0.8933713800894327, 0.9077063260576719, 0.6953431002936266], 
             UndirectedEdge[63, 295] -> 
             RGBColor[
              0.9798772881965969, 0.9499841181434201, 0.5768811998587284], 
             UndirectedEdge[302, 367] -> 
             RGBColor[
              0.9743516835118016, 0.9251443473535204, 0.3548615630318484], 
             UndirectedEdge[140, 331] -> 
             RGBColor[
              0.9934583731547775, 0.9908518612506549, 0.7063914093917604], 
             UndirectedEdge[92, 354] -> 
             RGBColor[
              0.9779062977520028, 0.9830422388214113, 0.9222429863189332], 
             UndirectedEdge[151, 311] -> 
             RGBColor[
              0.9686773764804704, 0.9733166342570531, 0.7759608275385279], 
             UndirectedEdge[299, 371] -> 
             RGBColor[
              0.9680324416838331, 0.9530144289347346, 0.6628048454742956], 
             UndirectedEdge[140, 389] -> 
             RGBColor[
              0.8518072332976154, 0.8827144805099686, 0.8732416895173327], 
             UndirectedEdge[176, 205] -> 
             RGBColor[
              0.8487847360435055, 0.6659473999465897, 0.5947694193529416], 
             UndirectedEdge[152, 179] -> 
             RGBColor[
              0.768803435447681, 0.8194833948860234, 0.9775459413774017], 
             UndirectedEdge[142, 293] -> 
             RGBColor[
              0.8805615891327534, 0.8069761018345205, 0.6215314288188762], 
             UndirectedEdge[105, 259] -> 
             RGBColor[
              0.9917302300801105, 0.9908482518618023, 0.7867150192584759], 
             UndirectedEdge[274, 318] -> 
             RGBColor[
              0.9869408855772999, 0.9667850172897199, 0.47397680343466086`], 
             UndirectedEdge[231, 369] -> 
             RGBColor[
              0.9676441172430401, 0.9730393004562811, 0.8168486708369183], 
             UndirectedEdge[151, 348] -> 
             RGBColor[
              0.9913395152793473, 0.9894467649537158, 0.7030613490703053], 
             UndirectedEdge[147, 231] -> 
             RGBColor[
              0.9608585765059697, 0.8698475585601582, 0.4543732132922221], 
             UndirectedEdge[66, 354] -> 
             RGBColor[
              0.9822103322350573, 0.9663419222368519, 0.644612675065598], 
             UndirectedEdge[24, 65] -> 
             RGBColor[
              0.9932579936685131, 0.9912115654907379, 0.7418821146085395], 
             UndirectedEdge[42, 347] -> 
             RGBColor[
              0.8694577200158787, 0.8957251033916167, 0.8307167370400339], 
             UndirectedEdge[52, 129] -> 
             RGBColor[
              0.9894765009563099, 0.9893547085855514, 0.7832450513590301], 
             UndirectedEdge[3, 7] -> 
             RGBColor[
              0.9614173722194144, 0.875211827413915, 0.3374353939368109], 
             UndirectedEdge[156, 352] -> 
             RGBColor[
              0.9893734861488745, 0.9875658382409367, 0.6580168007791742], 
             UndirectedEdge[229, 329] -> 
             RGBColor[
              0.9224883417787637, 0.9410311797281509, 0.9924689556255647], 
             UndirectedEdge[80, 187] -> 
             RGBColor[
              0.9408376333758253, 0.9530681985845766, 0.8925150670897433], 
             UndirectedEdge[247, 362] -> 
             RGBColor[
              0.9929317625724655, 0.9907656313134598, 0.7246800661138679], 
             UndirectedEdge[43, 321] -> 
             RGBColor[
              0.9800934411427977, 0.983283664688982, 0.8563052327599836], 
             UndirectedEdge[84, 270] -> 
             RGBColor[
              0.9212823043086468, 0.8792231253114893, 0.6343226471181258], 
             UndirectedEdge[318, 322] -> 
             RGBColor[
              0.981271781308505, 0.9484874621380324, 0.3817448362212257], 
             UndirectedEdge[218, 276] -> 
             RGBColor[
              0.9906500904117717, 0.9894137222152601, 0.7328084346579531], 
             UndirectedEdge[201, 303] -> 
             RGBColor[
              0.983958402389861, 0.9843549273574823, 0.721666764950194], 
             UndirectedEdge[283, 364] -> 
             RGBColor[
              0.7883683732329577, 0.8310401263033345, 0.7896456918369921], 
             UndirectedEdge[65, 340] -> 
             RGBColor[
              0.9950350440401852, 0.9917887861730336, 0.7009733678096691], 
             UndirectedEdge[83, 214] -> 
             RGBColor[
              0.976161186563768, 0.9782329618069863, 0.710520979061531], 
             UndirectedEdge[124, 157] -> 
             RGBColor[
              0.9513920601317958, 0.8423937392915983, 0.293282788714992], 
             UndirectedEdge[311, 344] -> 
             RGBColor[
              0.8704476982698302, 0.8995166146531468, 0.9804732749971918], 
             UndirectedEdge[190, 226] -> 
             RGBColor[
              0.9826718298948827, 0.9650236542244177, 0.6265335582882521], 
             UndirectedEdge[380, 389] -> 
             RGBColor[
              0.8527864838076435, 0.8823735836578757, 0.8027981269263553], 
             UndirectedEdge[124, 179] -> 
             RGBColor[
              0.8173705129230489, 0.7775095157861285, 0.6197012901629204], 
             UndirectedEdge[199, 215] -> 
             RGBColor[
              0.8926246898121395, 0.9061836868068986, 0.6938969883071663], 
             UndirectedEdge[146, 267] -> 
             RGBColor[
              0.9863326193804454, 0.9652956100797496, 0.42378987957453285`], 
             UndirectedEdge[109, 249] -> 
             RGBColor[
              0.9893140461369943, 0.9817441148481734, 0.613040770907126], 
             UndirectedEdge[36, 61] -> 
             RGBColor[
              0.9554141719422325, 0.8641383105286053, 0.5703238255346936], 
             UndirectedEdge[13, 232] -> 
             RGBColor[
              0.9884073488900301, 0.971738816912457, 0.561502433655051], 
             UndirectedEdge[38, 119] -> 
             RGBColor[
              0.955401221470044, 0.9374517210681688, 0.6711471291603057], 
             UndirectedEdge[91, 256] -> 
             RGBColor[
              0.9668680173618787, 0.8937515316056295, 0.45456081955204874`], 
             UndirectedEdge[6, 69] -> 
             RGBColor[
              0.9814181574776053, 0.9645078714976072, 0.6433526085303705], 
             UndirectedEdge[90, 97] -> 
             RGBColor[
              0.9937610173251838, 0.9890637718535059, 0.5623034222632726], 
             UndirectedEdge[233, 257] -> 
             RGBColor[
              0.8873633631995459, 0.6124125405631146, 0.5840732431563262], 
             UndirectedEdge[66, 119] -> 
             RGBColor[
              0.9587873756793981, 0.9488740143231377, 0.6843016988420796], 
             UndirectedEdge[33, 116] -> 
             RGBColor[
              0.9839626473575482, 0.955884828651522, 0.5350157054219296], 
             UndirectedEdge[335, 349] -> 
             RGBColor[
              0.9943330229667005, 0.9918245364355365, 0.7363083588412098], 
             UndirectedEdge[165, 274] -> 
             RGBColor[
              0.994544869771345, 0.9907403529762056, 0.6476209236513664], 
             UndirectedEdge[95, 169] -> 
             RGBColor[
              0.959611709788468, 0.8732643162227351, 0.3088417753146624], 
             UndirectedEdge[135, 259] -> 
             RGBColor[
              0.9893439054478385, 0.989861445300612, 0.8262625940254076], 
             UndirectedEdge[93, 273] -> 
             RGBColor[
              0.6586184948396556, 0.7240069818472492, 0.8791579256653006], 
             UndirectedEdge[89, 263] -> 
             RGBColor[
              0.9816732938515094, 0.95365670861257, 0.5673680700360348], 
             UndirectedEdge[71, 289] -> 
             RGBColor[
              0.9900842412085671, 0.9885835426679102, 0.6988495656051221], 
             UndirectedEdge[32, 215] -> 
             RGBColor[
              0.9872312999482025, 0.9797253909504231, 0.6395569806181727], 
             UndirectedEdge[8, 239] -> 
             RGBColor[
              0.9446128873146624, 0.8142298914662278, 0.2945291929818783], 
             UndirectedEdge[110, 111] -> 
             RGBColor[
              0.9772274463699118, 0.969624468494247, 0.6679426432003457], 
             UndirectedEdge[29, 162] -> 
             RGBColor[
              0.9850091951127744, 0.9610946364863261, 0.3962639830994375], 
             UndirectedEdge[337, 353] -> 
             RGBColor[
              0.9814446806182409, 0.9829358425116417, 0.7620753011229642], 
             UndirectedEdge[306, 308] -> 
             RGBColor[
              0.9900069627980688, 0.9779532804204806, 0.4156793668075714], 
             UndirectedEdge[185, 190] -> 
             RGBColor[
              0.9813061325352979, 0.9604168363495491, 0.6212280819365713], 
             UndirectedEdge[71, 385] -> 
             RGBColor[
              0.9924666518381247, 0.9856685126955649, 0.47471336488019467`], 
             UndirectedEdge[146, 158] -> 
             RGBColor[
              0.9800342619233531, 0.9440497714523199, 0.3993219501987335], 
             UndirectedEdge[157, 386] -> 
             RGBColor[
              0.9790910884104185, 0.9405591647212277, 0.4219382161523279], 
             UndirectedEdge[24, 124] -> 
             RGBColor[
              0.9647887151035688, 0.8913986525829161, 0.5293896969388354], 
             UndirectedEdge[22, 74] -> 
             RGBColor[
              0.9717510407022449, 0.9200095964627404, 0.539922563862778], 
             UndirectedEdge[303, 385] -> 
             RGBColor[
              0.9924089315045167, 0.9855450547383986, 0.468430862775582], 
             UndirectedEdge[130, 317] -> 
             RGBColor[
              0.9379620495520147, 0.9525132070977167, 0.9642568374025294], 
             UndirectedEdge[73, 291] -> 
             RGBColor[
              0.9915923533545528, 0.9832450117389315, 0.42661403103669804`], 
             UndirectedEdge[241, 255] -> 
             RGBColor[
              0.9590379477869677, 0.8623429521792244, 0.46985711234856375`], 
             UndirectedEdge[385, 400] -> 
             RGBColor[
              0.9812464597608195, 0.9804219575161763, 0.67769767067052], 
             UndirectedEdge[130, 311] -> 
             RGBColor[
              0.9252646425477637, 0.9430435017440422, 0.9857502354465963], 
             UndirectedEdge[143, 308] -> 
             RGBColor[
              0.9922641883954724, 0.9851969858999678, 0.4559483569212874], 
             UndirectedEdge[297, 397] -> 
             RGBColor[
              0.9814750137006361, 0.9852677191229695, 0.896674324410568], 
             UndirectedEdge[237, 324] -> 
             RGBColor[
              0.9919822164376639, 0.9909524546964046, 0.7825389531940252], 
             UndirectedEdge[107, 160] -> 
             RGBColor[
              0.9592956251725931, 0.8699794916075928, 0.3191683370797993], 
             UndirectedEdge[125, 185] -> 
             RGBColor[
              0.9848675528812617, 0.9601478024286265, 0.43559763770263404`], 
             UndirectedEdge[269, 388] -> 
             RGBColor[
              0.7399371596562044, 0.783503853260413, 0.6786245653382638], 
             UndirectedEdge[47, 300] -> 
             RGBColor[
              0.9765429432025633, 0.9447864470430797, 0.6057442888120342], 
             UndirectedEdge[37, 365] -> 
             RGBColor[
              0.9501632647115011, 0.8410679269892322, 0.5550774487915182], 
             UndirectedEdge[356, 389] -> 
             RGBColor[
              0.8449985966513267, 0.8572847442186204, 0.6720746502911965], 
             UndirectedEdge[227, 243] -> 
             RGBColor[
              0.9387098896938846, 0.7793074537417066, 0.4937466429586394], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.8404885427669553, 0.8420712734556247, 0.6545539426026246], 
             UndirectedEdge[186, 348] -> 
             RGBColor[
              0.9911494981981546, 0.9906081043044849, 0.7963392494284189], 
             UndirectedEdge[61, 90] -> 
             RGBColor[
              0.9592637497750913, 0.8643351942924791, 0.4051234508948291], 
             UndirectedEdge[72, 325] -> 
             RGBColor[
              0.991694950804199, 0.9889596929247813, 0.6510818481735676], 
             UndirectedEdge[341, 358] -> 
             RGBColor[
              0.9931131016356269, 0.9908691194951542, 0.7237464445197155], 
             UndirectedEdge[102, 337] -> 
             RGBColor[
              0.9845629426712694, 0.985261437245105, 0.756796896840183], 
             UndirectedEdge[297, 378] -> 
             RGBColor[
              0.9844396540820377, 0.9843105520486175, 0.6888526335047784], 
             UndirectedEdge[300, 370] -> 
             RGBColor[
              0.9724389955366812, 0.9186924016929459, 0.34743113142932197`], 
             UndirectedEdge[46, 52] -> 
             RGBColor[
              0.9880398270177133, 0.9858218325195984, 0.6659849795228345], 
             UndirectedEdge[75, 200] -> 
             RGBColor[
              0.9920289509348605, 0.9857444562063407, 0.5879380404509994], 
             UndirectedEdge[204, 343] -> 
             RGBColor[
              0.9196236732123857, 0.9092434520748638, 0.6696197889253371], 
             UndirectedEdge[32, 199] -> 
             RGBColor[
              0.8919919805412317, 0.9151844829480961, 0.9260995721091941], 
             UndirectedEdge[301, 313] -> 
             RGBColor[
              0.9934098879107083, 0.988312741540572, 0.5240851524171599], 
             UndirectedEdge[166, 363] -> 
             RGBColor[
              0.7804515084180648, 0.8276746790209315, 0.9408187946857977], 
             UndirectedEdge[333, 353] -> 
             RGBColor[
              0.9799004537483804, 0.978641150033801, 0.6783267721106088], 
             UndirectedEdge[130, 146] -> 
             RGBColor[
              0.9499743997990244, 0.9579909401395292, 0.7313979083660711], 
             UndirectedEdge[71, 271] -> 
             RGBColor[
              0.9908199215280066, 0.9888877653861203, 0.6866574388323725], 
             UndirectedEdge[123, 332] -> 
             RGBColor[
              0.9908024992647282, 0.9792784827734076, 0.5342723650022562], 
             UndirectedEdge[340, 361] -> 
             RGBColor[
              0.9897741970942051, 0.9755657699400939, 0.5510262974816824], 
             UndirectedEdge[165, 322] -> 
             RGBColor[
              0.9888757655025502, 0.972442797824518, 0.5553889564379313], 
             UndirectedEdge[278, 302] -> 
             RGBColor[
              0.9831920660184754, 0.9534658716651466, 0.5166826697901986], 
             UndirectedEdge[322, 355] -> 
             RGBColor[
              0.9881741780439552, 0.9709421731919564, 0.47902549126576627`], 
             UndirectedEdge[68, 333] -> 
             RGBColor[
              0.9626732186851212, 0.8793885148164156, 0.34262440153104223`], 
             UndirectedEdge[150, 156] -> 
             RGBColor[
              0.9742773751056919, 0.9367071871087614, 0.5939226865920173], 
             UndirectedEdge[29, 357] -> 
             RGBColor[
              0.9668254899870048, 0.9645173113976028, 0.6911771747430511], 
             UndirectedEdge[250, 325] -> 
             RGBColor[
              0.9923232499110379, 0.9903035611835256, 0.7194683285403631], 
             UndirectedEdge[53, 131] -> 
             RGBColor[
              0.9910179882219167, 0.9891266033867527, 0.6947822850535672], 
             UndirectedEdge[92, 267] -> 
             RGBColor[
              0.9756754540437484, 0.9608285717251368, 0.6543548340466635], 
             UndirectedEdge[269, 309] -> 
             RGBColor[
              0.7435124422408097, 0.794542232758215, 0.779407857390721], 
             UndirectedEdge[162, 336] -> 
             RGBColor[
              0.9510766843309537, 0.945637097987762, 0.6892639876108104], 
             UndirectedEdge[94, 204] -> 
             RGBColor[
              0.9834722997813039, 0.9554317583417502, 0.43098751479354164`], 
             UndirectedEdge[29, 183] -> 
             RGBColor[
              0.987589211341212, 0.9794348848148552, 0.6305944861010889], 
             UndirectedEdge[145, 208] -> 
             RGBColor[
              0.9254850725554756, 0.7162606318650646, 0.4778505796553079], 
             UndirectedEdge[75, 133] -> 
             RGBColor[
              0.9876458486099576, 0.9839319307544014, 0.6605773890798456], 
             UndirectedEdge[169, 326] -> 
             RGBColor[
              0.9717900317157296, 0.9131700393286197, 0.5057286815066624], 
             UndirectedEdge[95, 97] -> 
             RGBColor[
              0.9822086081053413, 0.9508118953370132, 0.4564464302604901], 
             UndirectedEdge[37, 78] -> 
             RGBColor[
              0.9908125909165162, 0.9904687844854052, 0.8019226749732622], 
             UndirectedEdge[55, 397] -> 
             RGBColor[
              0.9778306083939621, 0.9825497276124182, 0.9028433519816326], 
             UndirectedEdge[185, 226] -> 
             RGBColor[
              0.9778378130067868, 0.936903880722237, 0.36840451781955136`], 
             UndirectedEdge[39, 254] -> 
             RGBColor[
              0.973468900121276, 0.9794742859983012, 0.9181759934626514], 
             UndirectedEdge[71, 201] -> 
             RGBColor[
              0.984016122723469, 0.9844783853146486, 0.7279492670548067], 
             UndirectedEdge[227, 383] -> 
             RGBColor[
              0.9376034327570096, 0.7788499053636626, 0.5120834978214197], 
             UndirectedEdge[38, 151] -> 
             RGBColor[
              0.9836478486687346, 0.9556744244583988, 0.4613885739950244], 
             UndirectedEdge[45, 74] -> 
             RGBColor[
              0.9741596800168433, 0.9291513478789641, 0.5439839244700355], 
             UndirectedEdge[292, 303] -> 
             RGBColor[
              0.9934705031300206, 0.9884423913655425, 0.5306827449655453], 
             UndirectedEdge[185, 357] -> 
             RGBColor[
              0.961277703603927, 0.9458033252452929, 0.6696250722563439], 
             UndirectedEdge[86, 376] -> 
             RGBColor[
              0.9386872653939489, 0.9497023591352587, 0.7879956864634817], 
             UndirectedEdge[212, 309] -> 
             RGBColor[
              0.9076958765458618, 0.9251037148860358, 0.7942037357314018], 
             UndirectedEdge[50, 127] -> 
             RGBColor[
              0.9536492082139727, 0.8560246070287183, 0.5634416119131986], 
             UndirectedEdge[92, 374] -> 
             RGBColor[
              0.9784544670905408, 0.970202835275261, 0.6651507749608734], 
             UndirectedEdge[118, 141] -> 
             RGBColor[
              0.9743640305701866, 0.9303026469026675, 0.5479709529861256], 
             UndirectedEdge[205, 390] -> 
             RGBColor[
              0.8988663128747328, 0.8757831956854787, 0.6427647260353593]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.8572219461754736, 0.44083852988719874`, 0.20242910632156536`],
              316 -> 
             RGBColor[
              0.9728177735965393, 0.9792481205718855, 0.9308965984277003], 
             308 -> RGBColor[
              0.9914251407055751, 0.982737127506507, 0.4211887201778073], 160 -> 
             RGBColor[
              0.9411608386571664, 0.8044293628035282, 0.27151483353217337`], 
             245 -> RGBColor[
              0.9927451102663447, 0.9912679309000412, 0.7698958281468438], 
             155 -> RGBColor[
              0.857820466812359, 0.8894667715926434, 0.9863008759815755], 213 -> 
             RGBColor[
              0.798153975288303, 0.8422432187808895, 0.9805161871499176], 352 -> 
             RGBColor[
              0.9926068228743554, 0.9865950666301434, 0.4366764791530763], 27 -> 
             RGBColor[
              0.9927727259721875, 0.9869499165810299, 0.4547340075168541], 
             367 -> RGBColor[
              0.9772513333730952, 0.9349255472058283, 0.36612615519004477`], 
             19 -> RGBColor[
              0.9949184752990232, 0.991539457422596, 0.688285579713084], 164 -> 
             RGBColor[
              0.9925041640287912, 0.9863754897398829, 0.4255026973503576], 
             190 -> RGBColor[
              0.9861401494233937, 0.9885366098517299, 0.8793571224052721], 
             103 -> RGBColor[
              0.8849116741524323, 0.5702926165351606, 0.22567981865082817`], 
             138 -> RGBColor[
              0.8648828584702022, 0.895098130997093, 0.986974493202572], 291 -> 
             RGBColor[
              0.9905907050704742, 0.9799223801745075, 0.4179470953053879], 28 -> 
             RGBColor[
              0.9930734060887443, 0.9875930409469219, 0.4874611826214824], 
             337 -> RGBColor[
              0.9939845210934886, 0.9895418238142123, 0.586630428137866], 195 -> 
             RGBColor[
              0.9662083061335178, 0.8976748233006331, 0.3232260796649967], 
             114 -> RGBColor[
              0.9568284842879898, 0.9673233347856277, 0.9579622945525346], 93 -> 
             RGBColor[
              0.3272883359570442, 0.45790243944108844`, 0.9420755012508389], 
             34 -> RGBColor[
              0.9872662624931355, 0.989002286545854, 0.860694514552444], 161 -> 
             RGBColor[
              0.9580436495715666, 0.8701335195646457, 0.29150793068783376`], 
             22 -> RGBColor[
              0.9525244119497205, 0.849482144222183, 0.28065823134070983`], 
             124 -> RGBColor[
              0.9380322570016475, 0.7920255790774303, 0.26899750329489297`], 
             84 -> RGBColor[
              0.9505688614497529, 0.8417290381383858, 0.2790847495057661], 46 -> 
             RGBColor[
              0.9917576991927056, 0.9838589253720447, 0.4224806471019091], 
             241 -> RGBColor[
              0.9948666402682984, 0.9914285875332011, 0.6826436565074133], 
             185 -> RGBColor[
              0.9764721156472022, 0.9322970628473684, 0.36309904146787053`], 
             390 -> RGBColor[
              0.9605374395302293, 0.8785456586649426, 0.30119583376452047`], 
             121 -> RGBColor[
              0.9934184415156507, 0.991546370675453, 0.7587369868204288], 322 -> 
             RGBColor[
              0.9825026196793437, 0.9526393689774643, 0.3865264108676112], 
             126 -> RGBColor[
              0.9134359677759472, 0.9338130624184513, 0.9916055321120263], 
             236 -> RGBColor[
              0.9597673787529838, 0.9695151574656221, 0.9529875128097369], 78 -> 
             RGBColor[
              0.9943909111884691, 0.9919485118764941, 0.7426206476709887], 
             376 -> RGBColor[
              0.8833842972176458, 0.9098506760461283, 0.9887391769467325], 
             254 -> RGBColor[
              0.9857536311412821, 0.98837677460901, 0.8857627306171107], 290 -> 
             RGBColor[
              0.9932058018753559, 0.9878762221472169, 0.5018716469420782], 
             251 -> RGBColor[
              0.3272883359570442, 0.45790243944108844`, 0.9420755012508389], 
             165 -> RGBColor[
              0.9952489113257568, 0.9922462266715719, 0.7242515020082513], 
             100 -> RGBColor[
              0.9938414129850087, 0.9892357300406233, 0.571053993690713], 235 -> 
             RGBColor[
              0.9923024245423238, 0.9856964118839008, 0.4245968022224244], 70 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 234 -> 
             RGBColor[
              0.988223911005555, 0.9719386280438614, 0.40875254729473276`], 
             257 -> RGBColor[
              0.9396942660619803, 0.9545446628873772, 0.9869660566893425], 
             135 -> RGBColor[
              0.9870791176508882, 0.9889248973441815, 0.863795988903811], 265 -> 
             RGBColor[
              0.9935537753560315, 0.9886205022368663, 0.5397464128702184], 
             111 -> RGBColor[
              0.9855500525968304, 0.9629190757794229, 0.39836511229262894`], 
             381 -> RGBColor[
              0.9946243876647446, 0.9920450603995058, 0.7387513382413511], 
             182 -> RGBColor[
              0.9944619180275623, 0.990562927583962, 0.6385921382594357], 188 -> 
             RGBColor[
              0.993914843746764, 0.9893927910150287, 0.5790464789456343], 154 -> 
             RGBColor[
              0.8223609822767148, 0.8611923411459873, 0.9829187186915102], 
             336 -> RGBColor[
              0.9197026668497162, 0.9388099581548599, 0.9922032554640308], 
             315 -> RGBColor[
              0.9933359846871095, 0.9881546700180565, 0.516041242606265], 368 -> 
             RGBColor[
              0.9922622092257003, 0.9855607561779245, 0.42444057331136764`], 
             269 -> RGBColor[
              0.49286611451777157`, 0.5991699409877828, 0.9532193724443558], 
             208 -> RGBColor[
              0.9937481989354776, 0.9916827338429306, 0.7532720529890505], 86 -> 
             RGBColor[
              0.9939902335702518, 0.9895540422243889, 0.5872521959802309], 
             119 -> RGBColor[
              0.9373514724290681, 0.9527974112319237, 0.9909317952114224], 
             377 -> RGBColor[
              0.99280260472458, 0.9870138242111924, 0.4579861253245016], 140 -> 
             RGBColor[
              0.9924589415499603, 0.9911495927816157, 0.7746383843582321], 85 -> 
             RGBColor[
              0.9581092187076699, 0.8703546996570872, 0.2917626543999026], 
             351 -> RGBColor[
              0.9863056474464581, 0.9654678746293248, 0.4013004556013182], 
             242 -> RGBColor[
              0.9925319116721582, 0.9864348391433279, 0.42852285709225746`], 
             117 -> RGBColor[
              0.9950343671132496, 0.9917873382947663, 0.7008996884902482], 47 -> 
             RGBColor[
              0.9858448725929354, 0.9884145052940669, 0.8842506236379069], 81 -> 
             RGBColor[
              0.9945751796800414, 0.9908051828061051, 0.6509199701618857], 
             275 -> RGBColor[
              0.9940541892705107, 0.9896908370003296, 0.5942133792645804], 23 -> 
             RGBColor[
              0.9304534456963692, 0.7619781177411565, 0.2628994138211006], 
             328 -> RGBColor[
              0.9640512420587933, 0.8903985396738573, 0.3148462930620626], 
             110 -> RGBColor[
              0.968904840142993, 0.9763298612090712, 0.9375201741080623], 6 -> 
             RGBColor[
              0.9792762395927103, 0.94175603135518, 0.37399253348179556`], 
             218 -> RGBColor[
              0.9871632828148913, 0.9889597018024429, 0.8624011543238163], 
             108 -> RGBColor[
              0.861842519151565, 0.8926738469522238, 0.9866845029242174], 297 -> 
             RGBColor[
              0.976127916704865, 0.9817168198822128, 0.9252933895688955], 157 -> 
             RGBColor[
              0.9647518632619441, 0.8927618995057665, 0.317568074135091], 354 -> 
             RGBColor[
              0.9841973855403867, 0.9877332270593521, 0.9115537476584592], 
             385 -> RGBColor[
              0.9914874867219658, 0.9829474352593341, 0.42143092267842847`], 
             270 -> RGBColor[
              0.8919957471675406, 0.9167172124845926, 0.9895605447304856], 
             392 -> RGBColor[
              0.9102397379860809, 0.6818375024886536, 0.24663499012070086`], 
             33 -> RGBColor[
              0.9727009018121912, 0.9195758730587589, 0.34844858785282806`], 
             252 -> RGBColor[
              0.9939238027938353, 0.9894119535108157, 0.5800216159305149], 
             394 -> RGBColor[
              0.9485612289950575, 0.9611576293245468, 0.9719566013179574], 
             260 -> RGBColor[
              0.848406205828693, 0.37307688649979, 0.19398714340953352`], 159 -> 
             RGBColor[
              0.9867226654628507, 0.9887774952040247, 0.8697033241282833], 
             183 -> RGBColor[
              0.9876107342690663, 0.9891447344777221, 0.854985725760893], 99 -> 
             RGBColor[
              0.9480806176441668, 0.8318639806073318, 0.2770826501332027], 
             329 -> RGBColor[
              0.9115464959098862, 0.9323064488408019, 0.99142531259869], 309 -> 
             RGBColor[
              0.9941587699638477, 0.9899145245286473, 0.6055963423370863], 17 -> 
             RGBColor[
              0.9460832915606517, 0.9593095876432173, 0.9761511030448174], 
             349 -> RGBColor[
              0.9935000059754696, 0.9915800996756992, 0.7573852526391731], 
             347 -> RGBColor[
              0.7440150845851652, 0.7999495058927892, 0.9751201284813273], 
             340 -> RGBColor[
              0.9950992739488339, 0.9919261674529933, 0.7079643969850372], 
             277 -> RGBColor[
              0.9874319518478194, 0.9692671638439659, 0.4056759355158676], 
             104 -> RGBColor[
              0.9602261134514041, 0.8774954826982255, 0.2999863907372813], 79 -> 
             RGBColor[
              0.9917673305104361, 0.9908635938431795, 0.7861001691151444], 
             327 -> RGBColor[
              0.9534333024194118, 0.9647912137071423, 0.9637094518507857], 
             191 -> RGBColor[
              0.9952393560704541, 0.9922257889466639, 0.7232114714367541], 50 -> 
             RGBColor[0.986594433673119, 0.988724468063564, 0.87182845673737],
              225 -> 
             RGBColor[
              0.9731193426688634, 0.9209873723228998, 0.35007415156507454`], 
             61 -> RGBColor[
              0.9248625591072026, 0.7398121154676233, 0.25840085523648193`], 
             196 -> RGBColor[
              0.9889345781520125, 0.9896921779445563, 0.8330462066223285], 1 -> 
             RGBColor[
              0.9930861440509956, 0.987620286160172, 0.4888476312029485], 263 -> 
             RGBColor[
              0.9718014144975289, 0.9165416911367382, 0.34495424948929176`], 
             201 -> RGBColor[
              0.9745864284926544, 0.9805671804975016, 0.9279027270276526], 
             371 -> RGBColor[
              0.9579383558007813, 0.9681510751426198, 0.9560835715822296], 
             293 -> RGBColor[
              0.835671929269632, 0.8718061289621086, 0.9841883286985172], 362 -> 
             RGBColor[
              0.9946102785234834, 0.9908802556831902, 0.654740262665596], 184 -> 
             RGBColor[
              0.994169812268257, 0.9899381429012304, 0.6067982290268269], 106 -> 
             RGBColor[
              0.9902051523963707, 0.9902175930468672, 0.8119895032525709], 
             206 -> RGBColor[
              0.9949817018654237, 0.99167469265494, 0.6951674012766274], 358 -> 
             RGBColor[
              0.9915828886265272, 0.9907873223842429, 0.7891568484518083], 
             247 -> RGBColor[
              0.9912532466214476, 0.9906510069437294, 0.7946198695621398], 
             220 -> RGBColor[
              0.9618229060955518, 0.9710481663920922, 0.9495080411861615], 
             107 -> RGBColor[
              0.9774304116880199, 0.9355296204116574, 0.3668218406274252], 
             375 -> RGBColor[
              0.9908034228219776, 0.9904649932427042, 0.8020746140260342], 
             131 -> RGBColor[
              0.9884082483135531, 0.9894745270302935, 0.8417688541435596], 
             127 -> RGBColor[
              0.9207039827548265, 0.7233247459938725, 0.2550547670890273], 
             210 -> RGBColor[
              0.9248592015603089, 0.7397988039130258, 0.25839815367543945`], 
             357 -> RGBColor[
              0.9460832915606517, 0.9593095876432173, 0.9761511030448174], 
             181 -> RGBColor[
              0.9523311498464582, 0.848715924383526, 0.2805027281159803], 194 -> 
             RGBColor[
              0.934071191053961, 0.7763212725418329, 0.26581033665521664`], 
             118 -> RGBColor[
              0.990665492409019, 0.9904079554722959, 0.8043604779212262], 348 -> 
             RGBColor[
              0.9888343037322452, 0.9896507118950475, 0.8347080132597507], 
             276 -> RGBColor[
              0.994136898008652, 0.9898677426280775, 0.6032157149920899], 305 -> 
             RGBColor[
              0.9865244442016262, 0.9886955256184543, 0.8729883634069534], 
             343 -> RGBColor[
              0.865581174848984, 0.8956549495222405, 0.9870410992421746], 280 -> 
             RGBColor[
              0.9823001179983526, 0.9519562832578257, 0.3857397300761946], 
             189 -> RGBColor[
              0.9594707665628807, 0.9692939445799011, 0.9534895998787325], 
             168 -> RGBColor[
              0.9933438125630727, 0.9881714130532221, 0.5168932585968115], 
             363 -> RGBColor[
              0.97844836318182, 0.9834474050653436, 0.9213654789527791], 41 -> 
             RGBColor[
              0.9892817822433501, 0.9898357557590626, 0.8272921362934798], 14 -> 
             RGBColor[
              0.9520269916624782, 0.8475100385387522, 0.2802579953016399], 77 -> 
             RGBColor[
              0.9928672155522575, 0.9913184245737289, 0.7678722275609174], 51 -> 
             RGBColor[
              0.9914825511582972, 0.9907458302625745, 0.7908196999654242], 
             179 -> RGBColor[
              0.6967087688444502, 0.7629934524948268, 0.970405077030948], 223 -> 
             RGBColor[
              0.9883210609555189, 0.9894384728171335, 0.8432137742998356], 
             323 -> RGBColor[
              0.9948297985335692, 0.9913497867878862, 0.6786336610429768], 
             292 -> RGBColor[
              0.9936106299729738, 0.9887421085136221, 0.5459346870583551], 
             396 -> RGBColor[
              0.9950281168687795, 0.9917739696538413, 0.7002193879517085], 
             321 -> RGBColor[
              0.9676244264672158, 0.9753749307861614, 0.9396875804757826], 
             143 -> RGBColor[
              0.9931032360853698, 0.9876568442934286, 0.4907079936647675], 
             112 -> RGBColor[
              0.8914317990285513, 0.5998989807837629, 0.23112037067034744`], 
             197 -> RGBColor[
              0.9890458106175689, 0.9747110884263903, 0.4119454720846884], 54 -> 
             RGBColor[
              0.9675262754595562, 0.9753017299253565, 0.9398537245298677], 71 -> 
             RGBColor[
              0.9934458169542834, 0.9883895901317957, 0.5279958070819608], 
             177 -> RGBColor[
              0.8606980327135795, 0.8917612645328311, 0.9865753407860673], 
             158 -> RGBColor[
              0.9671389832096936, 0.9008142156119435, 0.32684158436232125`], 
             226 -> 
             RGBColor[
              0.9792035103663717, 0.9415106985971056, 0.3737099941712322], 
             350 -> RGBColor[
              0.9550684513564625, 0.966010705107084, 0.9609415712155036], 203 -> 
             RGBColor[
              0.9928314849738588, 0.9870755961441584, 0.46112956223024765`], 
             115 -> RGBColor[
              0.9427701117926304, 0.9568386235970608, 0.9817594521763994], 
             173 -> RGBColor[
              0.9334301876476412, 0.9497559106154998, 0.9935125986524393], 
             212 -> RGBColor[
              0.821232983127876, 0.8602929052434244, 0.9828111291257172], 129 -> 
             RGBColor[
              0.9946310470698988, 0.9909246775039505, 0.6570007907743002], 
             279 -> RGBColor[
              0.9925041640287912, 0.9863754897398829, 0.4255026973503576], 26 -> 
             RGBColor[
              0.993914843746764, 0.9893927910150287, 0.5790464789456343], 40 -> 
             RGBColor[
              0.9924100947171393, 0.9911293933609379, 0.7754479027896273], 
             146 -> RGBColor[
              0.9929295406370127, 0.9872853272926964, 0.4718023160351457], 
             386 -> RGBColor[
              0.9934303135588928, 0.988356429936689, 0.5263083581695648], 192 -> 
             RGBColor[
              0.9892783173016081, 0.9898343229166073, 0.8273495593451259], 
             300 -> RGBColor[
              0.9672410138121912, 0.9011583887920924, 0.3272379539861617], 
             221 -> RGBColor[
              0.9938413043946221, 0.9892354977767663, 0.5710421742972676], 62 -> 
             RGBColor[
              0.9746250492367691, 0.9260664741331603, 0.3559235372525616], 
             286 -> RGBColor[
              0.99478093872498, 0.991245280597798, 0.6733155724058134], 152 -> 
             RGBColor[
              0.8408981020509119, 0.8759733372772202, 0.9846868057238553], 64 -> 
             RGBColor[
              0.9941598606730996, 0.9899168574454494, 0.605715059308073], 307 -> 
             RGBColor[
              0.9943415721513311, 0.9919281089166821, 0.7434383232017004], 37 -> 
             RGBColor[
              0.9872342706445634, 0.9889890570943163, 0.8612247022755358], 
             148 -> RGBColor[
              0.9660160148270182, 0.897026179571664, 0.3224790642504119], 261 -> 
             RGBColor[
              0.9415073933091661, 0.8058033365162152, 0.2717936795398555], 
             387 -> RGBColor[
              0.995248876800253, 0.9922461528250104, 0.7242477441202324], 15 -> 
             RGBColor[
              0.9892783173016081, 0.9898343229166073, 0.8273495593451259], 
             136 -> RGBColor[
              0.8194043630971992, 0.8588441832461284, 0.9826342272105436], 
             198 -> RGBColor[
              0.9925874468407818, 0.9865536232535471, 0.4345675174736115], 63 -> 
             RGBColor[0.96982156048864, 0.909863178672928, 0.337262890528816],
              310 -> RGBColor[
              0.9899959762453407, 0.9901310933328343, 0.8154560934056646], 
             171 -> RGBColor[
              0.9931580699981781, 0.9877741284883668, 0.4966763266782783], 
             395 -> RGBColor[
              0.9952047312707207, 0.9921517300011384, 0.7194427756652682], 
             311 -> RGBColor[
              0.9435100261344914, 0.9573904505017222, 0.980506970196196], 353 -> 
             RGBColor[
              0.968904840142993, 0.9763298612090712, 0.9375201741080623], 59 -> 
             RGBColor[
              0.9950722735447556, 0.9922302727210324, 0.7313287101180673], 
             397 -> RGBColor[
              0.986822110696407, 0.9888186183637262, 0.8680552592522406], 229 -> 
             RGBColor[
              0.9334301876476412, 0.9497559106154998, 0.9935125986524393], 
             102 -> RGBColor[
              0.9751413642490502, 0.9809810506759976, 0.9269633655425001], 
             299 -> RGBColor[
              0.9781265275668848, 0.9378777827268496, 0.36952611936636176`], 
             128 -> RGBColor[
              0.8583373130148272, 0.4494117281713356, 0.203497182866557], 12 -> 
             RGBColor[
              0.8317096564988627, 0.8686467202077264, 0.9838104035844787], 
             222 -> RGBColor[
              0.9800003357610422, 0.9846048636738056, 0.9187383941954321], 92 -> 
             RGBColor[
              0.9716152099636187, 0.9783512505834706, 0.9329322249794071], 
             271 -> RGBColor[
              0.9881940261017298, 0.9893859406404448, 0.8453190705827843], 
             361 -> RGBColor[
              0.9844491202395763, 0.9592053724271946, 0.3940881979783275], 
             344 -> RGBColor[
              0.7973853704051688, 0.8416427788045715, 0.9804395797981877], 
             132 -> RGBColor[
              0.9937014586145031, 0.988936381793669, 0.5558208241594245], 80 -> 
             RGBColor[
              0.9911932619053747, 0.9906262017220964, 0.7956139715429369], 
             324 -> RGBColor[
              0.9887449968271401, 0.9896137811947038, 0.8361880597962049], 
             244 -> RGBColor[
              0.9609261710007776, 0.8798569411935918, 0.30270598212182215`], 
             150 -> 
             RGBColor[
              0.9624146007879901, 0.884877764365793, 0.30848825077876235`], 
             125 -> RGBColor[
              0.9932629901153213, 0.9879985420098847, 0.5080962339373976], 
             258 -> RGBColor[
              0.9879322242959399, 0.9892776788657511, 0.849657804026078], 133 -> 
             RGBColor[
              0.9847009921494411, 0.9879414813342955, 0.9032076828543033], 
             255 -> RGBColor[
              0.9232092553056369, 0.7332573168252478, 0.2570705681897142], 
             326 -> RGBColor[
              0.9949167658578183, 0.9921659662961185, 0.7339058749316113], 
             176 -> RGBColor[
              0.8603742858677746, 0.4588740671871647, 0.20520522039968492`], 
             230 -> RGBColor[
              0.9943120879366497, 0.990242456169646, 0.62228405750774], 274 -> 
             RGBColor[
              0.9938408282169334, 0.9892344792808392, 0.5709903452944816], 87 -> 
             RGBColor[
              0.9948018701894162, 0.9912900508837317, 0.6755938331356818], 
             130 -> RGBColor[
              0.9070192589610362, 0.9286965529863621, 0.9909935006969965], 35 -> 
             RGBColor[
              0.9947646573311367, 0.9912104563426689, 0.6715434431630978], 
             379 -> RGBColor[
              0.9911252956838711, 0.9905980959428524, 0.7967403477241966], 31 -> 
             RGBColor[
              0.9934811663893628, 0.9884651989990545, 0.5318433749389271], 18 -> 
             RGBColor[
              0.9883631165855262, 0.9724082011521291, 0.40929333468615314`], 
             24 -> RGBColor[
              0.99154517320549, 0.9907717260884019, 0.7897818905827778], 151 -> 
             RGBColor[
              0.9938447268264493, 0.9892428180123839, 0.5714146848808597], 
             137 -> RGBColor[
              0.9926151481337063, 0.9912141882183207, 0.7720496370158799], 
             330 -> RGBColor[
              0.8493482780100123, 0.8827112782130909, 0.9854927910503954], 
             296 -> RGBColor[
              0.9026393949600343, 0.6507900563080935, 0.24047226343889208`], 
             266 -> RGBColor[
              0.9938971632717137, 0.9917443344241731, 0.7508033284302725], 
             302 -> RGBColor[
              0.9714520336505079, 0.9153631475012124, 0.34359697087365204`], 
             283 -> RGBColor[
              0.9942820928116058, 0.9901782996301495, 0.619019273255168], 388 -> 
             RGBColor[
              0.9870082047946372, 0.9678377655330433, 0.40402975823217174`], 
             284 -> RGBColor[
              0.9841820241888339, 0.9877235600563663, 0.9116598864461958], 
             318 -> RGBColor[
              0.9800409429376663, 0.9443355552986006, 0.37696326157484017`], 
             238 -> RGBColor[
              0.9199748102168913, 0.7204338198633036, 0.2544680577491254], 72 -> 
             RGBColor[
              0.9931097510449712, 0.9876707791332526, 0.4914171068117146], 
             288 -> RGBColor[
              0.9878651681577265, 0.9892499494293358, 0.850769097771997], 382 -> 
             RGBColor[
              0.9916162683114529, 0.9908011257417785, 0.7886036606887357], 
             389 -> RGBColor[
              0.7111555250452706, 0.7742793682383214, 0.9718449946764333], 
             172 -> RGBColor[
              0.7111555250452706, 0.7742793682383214, 0.9718449946764333], 
             243 -> RGBColor[
              0.9931980655396879, 0.9914552395459881, 0.762389187056876], 88 -> 
             RGBColor[
              0.9065057310577697, 0.667033409301946, 0.243630520497774], 273 -> 
             RGBColor[
              0.9899486537222669, 0.99011152425341, 0.8162403500797624], 202 -> 
             RGBColor[
              0.9597673787529838, 0.9695151574656221, 0.9529875128097369], 
             393 -> RGBColor[
              0.9215173095394535, 0.7265493156698345, 0.2557091889111716], 98 -> 
             RGBColor[
              0.9913755812709028, 0.9907015954651361, 0.792592467828745], 30 -> 
             RGBColor[
              0.9935370571691271, 0.9885847437255457, 0.5379267413983673], 
             116 -> RGBColor[
              0.9952243929029052, 0.9921937842442853, 0.721582822991031], 373 -> 
             RGBColor[
              0.9925979847747309, 0.9865761628287156, 0.4357145065513785], 
             240 -> RGBColor[
              0.9864117286099435, 0.9886489148246349, 0.8748563524597357], 
             317 -> RGBColor[
              0.968904840142993, 0.9763298612090712, 0.9375201741080623], 391 -> 
             RGBColor[
              0.9560448780889623, 0.8633911940199592, 0.2837430809142388], 73 -> 
             RGBColor[
              0.9925940016386313, 0.9865676433033554, 0.43528096676800815`], 
             303 -> RGBColor[
              0.9933303762870676, 0.9881426742174629, 0.5154308028727355], 29 -> 
             RGBColor[
              0.9875676884133577, 0.9697250351519883, 0.4062032464412848], 
             360 -> RGBColor[
              0.9181965442412653, 0.7133835878419545, 0.25303722320386945`], 
             320 -> RGBColor[
              0.9684679190986116, 0.9052970284142492, 0.3320042493422828], 75 -> 
             RGBColor[
              0.9905907050704742, 0.9799223801745075, 0.4179470953053879], 
             200 -> RGBColor[
              0.9934671967992469, 0.9915665322381737, 0.7579289855966109], 
             301 -> RGBColor[
              0.992895862458357, 0.9872132930739382, 0.468136654126112], 156 -> 
             RGBColor[
              0.9861401494233937, 0.9885366098517299, 0.8793571224052721], 25 -> 
             RGBColor[
              0.99512784667596, 0.9919872816271702, 0.711074362002282], 38 -> 
             RGBColor[
              0.9734509705110198, 0.9221060309044138, 0.35136246310918917`], 
             365 -> RGBColor[
              0.9130922587784389, 0.693146796884148, 0.2489301953075007], 380 -> 
             RGBColor[
              0.9944174425700165, 0.99046779907743, 0.6337512591762775], 370 -> 
             RGBColor[
              0.9776369772611712, 0.9362264145937994, 0.36762430887248226`], 
             3 -> RGBColor[
              0.9346518390518765, 0.7786233483640931, 0.2662775396638998], 57 -> 
             RGBColor[
              0.9941324981131973, 0.9898583316965975, 0.602736813524855], 227 -> 
             RGBColor[
              0.8842217138480811, 0.5671596679374251, 0.2251040988604029], 39 -> 
             RGBColor[
              0.9611841691012698, 0.9705717973875926, 0.9505892563081921], 
             109 -> RGBColor[
              0.9899819421210111, 0.9901252898617635, 0.8156886751649561], 
             256 -> RGBColor[
              0.9944668492753269, 0.9905734750243049, 0.6391288741464807], 
             339 -> RGBColor[
              0.9918165932948037, 0.9908839652705113, 0.785283757290174], 287 -> 
             RGBColor[
              0.9913612191103789, 0.9906956563426689, 0.7928304859967054], 
             239 -> RGBColor[
              0.9201228220757827, 0.7210206375617799, 0.2545871515650743], 
             285 -> RGBColor[
              0.9456852026359142, 0.9590126935749588, 0.976824963756178], 345 -> 
             RGBColor[
              0.9134359677759472, 0.9338130624184513, 0.9916055321120263], 
             366 -> RGBColor[
              0.9853152310992772, 0.9621269677294665, 0.3974528751169538], 
             216 -> RGBColor[
              0.8903956165186151, 0.9154413117395288, 0.9894079228407376], 21 -> 
             RGBColor[
              0.9869282565780527, 0.9888625124136113, 0.8662961472966357], 
             355 -> RGBColor[
              0.9938457364085668, 0.9892449774064486, 0.5715245716639213], 
             175 -> RGBColor[
              0.993617480022574, 0.9887567600770709, 0.5466802726837421], 7 -> 
             RGBColor[
              0.9881829053869522, 0.9718003064637369, 0.4085932482097219], 13 -> 
             RGBColor[
              0.9946761839910044, 0.992066479511519, 0.7378929390706312], 294 -> 
             RGBColor[
              0.9618229060955518, 0.9710481663920922, 0.9495080411861615], 
             193 -> RGBColor[
              0.9948195216286185, 0.991327805527351, 0.6775150833607911], 60 -> 
             RGBColor[
              0.951599798943126, 0.9634237898166147, 0.966813094981844], 65 -> 
             RGBColor[
              0.9949708141315363, 0.9916514048930738, 0.693982338634301], 69 -> 
             RGBColor[
              0.9835600753625003, 0.9872597116400345, 0.9127126835789452], 
             217 -> RGBColor[
              0.9822256013556717, 0.9862644631107423, 0.9149715999859428], 
             214 -> RGBColor[
              0.992889898734508, 0.9872005372716498, 0.46748753958896666`], 
             170 -> RGBColor[
              0.9736575235704609, 0.9228027828748732, 0.35216488274084534`], 
             359 -> RGBColor[
              0.9949996887687721, 0.9917131648224473, 0.6971251647038006], 74 -> 
             RGBColor[
              0.9909776694547693, 0.9905370487032977, 0.7991868963848463], 
             246 -> RGBColor[
              0.9911473946916882, 0.9818002249838014, 0.4201097293617905], 
             264 -> RGBColor[
              0.9893137408017573, 0.9898489714442614, 0.8267625002745745], 
             278 -> RGBColor[
              0.9949320983864428, 0.9915685958290809, 0.6897683687067452], 45 -> 
             RGBColor[
              0.9573416905789174, 0.8677656470546307, 0.2887809525552246], 
             306 -> RGBColor[
              0.9885887848905626, 0.9731694333344542, 0.4101700134373355], 
             237 -> RGBColor[
              0.9952194360481877, 0.9922911281981054, 0.7288898465918455], 
             228 -> RGBColor[
              0.9739589089869085, 0.9800991774775851, 0.9289649538675814], 
             180 -> RGBColor[
              0.9764721156472022, 0.9322970628473684, 0.36309904146787053`], 
             383 -> RGBColor[
              0.9909851516659381, 0.9905401427899001, 0.7990628967824365], 53 -> 
             RGBColor[
              0.9936277281302802, 0.9887786797432119, 0.5477957159635749], 
             304 -> RGBColor[
              0.5946680938915773, 0.6818173739703458, 0.9612335971735996], 48 -> 
             RGBColor[
              0.7111555250452706, 0.7742793682383214, 0.9718449946764333], 5 -> 
             RGBColor[
              0.9883631165855262, 0.9724082011521291, 0.40929333468615314`], 
             101 -> 
             RGBColor[
              0.9560163607462246, 0.8632949983267149, 0.28363229642275145`], 
             333 -> RGBColor[
              0.9908960673537678, 0.9809524388585308, 0.41913337011315527`], 
             267 -> RGBColor[
              0.9797356981238782, 0.943305892866803, 0.3757774431139199], 120 -> 
             RGBColor[
              0.9929189400247798, 0.9872626536550166, 0.47064850481299464`], 
             147 -> RGBColor[
              0.9271642658783718, 0.748937615816996, 0.2602528625325665], 89 -> 
             RGBColor[
              0.99154517320549, 0.9907717260884019, 0.7897818905827778], 43 -> 
             RGBColor[
              0.9925624558183797, 0.9911923985918024, 0.7729228850441847], 
             199 -> RGBColor[
              0.7973853704051688, 0.8416427788045715, 0.9804395797981877], 
             268 -> RGBColor[0.178927, 0.305394, 0.933501], 169 -> 
             RGBColor[
              0.948663297573641, 0.8341741123611208, 0.2775514880817134], 20 -> 
             RGBColor[
              0.9877014458379237, 0.9891822460426256, 0.8534824003109107], 4 -> 
             RGBColor[
              0.8992109096743582, 0.9224703872171601, 0.9902487333714375], 
             167 -> RGBColor[
              0.9935708776771005, 0.988657082372323, 0.5416078949752887], 142 -> 
             RGBColor[
              0.9254512489958748, 0.7421460747069324, 0.2588745289392353], 16 -> 
             RGBColor[
              0.9930644589476681, 0.9875739039168548, 0.4864873415307017], 
             281 -> RGBColor[
              0.9651690917612035, 0.8941693092036784, 0.31918892806772264`], 
             289 -> RGBColor[
              0.9867226654628507, 0.9887774952040247, 0.8697033241282833], 
             398 -> RGBColor[
              0.9930362623422706, 0.9875135942290235, 0.4834183150424541], 
             178 -> RGBColor[
              0.9762195238879736, 0.9314450115321252, 0.36211777018121916`], 
             58 -> RGBColor[
              0.9902185796452314, 0.9902231455593355, 0.8117669789903447], 
             186 -> RGBColor[
              0.9934646926640639, 0.9915654967139222, 0.757970485597087], 122 -> 
             RGBColor[
              0.9930551918468201, 0.9875540825251886, 0.4854786747933127], 
             249 -> RGBColor[
              0.9886461501529773, 0.9733629398345832, 0.4103928666492959], 
             113 -> RGBColor[
              0.8770137095002746, 0.5344298036662221, 0.2190895633482388], 52 -> 
             RGBColor[
              0.984321954842721, 0.9877847396671523, 0.9094893119437599], 187 -> 
             RGBColor[
              0.8904820048462759, 0.9155101954470569, 0.9894161626365496], 
             259 -> RGBColor[
              0.9916086932447887, 0.9907979932570425, 0.788729199147004], 42 -> 
             RGBColor[
              0.9949003554465923, 0.9915007008904443, 0.6863133455987406], 
             134 -> RGBColor[
              0.9334612674375506, 0.7739031286477622, 0.2653195777967055], 
             313 -> RGBColor[
              0.9939239133630594, 0.9894121900072058, 0.5800336507082078], 
             248 -> RGBColor[
              0.9367001502716246, 0.7867442197911425, 0.2679256589513528], 
             174 -> RGBColor[
              0.9948881590856444, 0.991474614107618, 0.6849858469767767], 215 -> 
             RGBColor[
              0.9878640092191103, 0.9707245948092257, 0.4073543968161449], 
             399 -> RGBColor[
              0.9464869017932195, 0.8255454283326507, 0.2758003089502115], 83 -> 
             RGBColor[
              0.9594324743930281, 0.9692653863423228, 0.9535544185340953], 95 -> 
             RGBColor[
              0.9705601220032949, 0.9123545200843494, 0.3401320625476113], 
             166 -> RGBColor[
              0.5824546536543096, 0.6719019529765194, 0.9602721104188162], 
             384 -> RGBColor[
              0.9874319518478194, 0.9692671638439659, 0.4056759355158676], 
             233 -> RGBColor[
              0.8350324603371114, 0.27028041823885196`, 0.18118042962330994`],
              295 -> RGBColor[
              0.989933015904554, 0.9901050576139121, 0.8164995091886408], 141 -> 
             RGBColor[
              0.9580625687313542, 0.8701973383330391, 0.29158142805102494`], 
             319 -> RGBColor[
              0.9604654649917629, 0.87830287164627, 0.3009162262738294], 205 -> 
             RGBColor[
              0.8371951862192364, 0.8730207327060148, 0.9843336183061981], 
             224 -> RGBColor[
              0.8235301591809513, 0.1818686912120992, 0.17016581304617986`], 
             231 -> RGBColor[
              0.9945528871335677, 0.9907575013033202, 0.6484935640518776], 
             332 -> RGBColor[
              0.9869010920815341, 0.9674764492004851, 0.4036136455683044], 68 -> 
             RGBColor[
              0.9344503700164746, 0.7778245907743002, 0.26611543294892925`], 
             10 -> RGBColor[
              0.798153975288303, 0.8422432187808895, 0.9805161871499176], 250 -> 
             RGBColor[
              0.9943663492586491, 0.9903585156507414, 0.6281900675453058], 
             282 -> RGBColor[
              0.9948614694985118, 0.9914175277794727, 0.6820808501264409], 
             374 -> RGBColor[
              0.9852937242174631, 0.9620544199670514, 0.39736932494233973`], 
             232 -> RGBColor[
              0.9821385137890558, 0.9514111543133948, 0.3851119282394708], 
             253 -> RGBColor[
              0.9660160148270182, 0.897026179571664, 0.3224790642504119], 55 -> 
             RGBColor[
              0.9688391060915171, 0.9762808368611101, 0.9376314447110246], 
             325 -> RGBColor[
              0.9902801505634267, 0.9902486067163098, 0.8107465895354206], 91 -> 
             RGBColor[
              0.9392691854484304, 0.7969295881869539, 0.26999276495761676`], 
             105 -> RGBColor[
              0.9918517669154322, 0.990898510466562, 0.7847008393699477], 36 -> 
             RGBColor[
              0.9859657847772625, 0.9884645055895875, 0.8822467958329054], 
             123 -> RGBColor[
              0.9947039064479224, 0.9910805163463299, 0.6649310844362079], 94 -> 
             RGBColor[
              0.9932784279868204, 0.9880315620560133, 0.5097765509785837], 
             312 -> RGBColor[
              0.6970397328848617, 0.763252004118616, 0.9704380644334615], 96 -> 
             RGBColor[
              0.9010792328693557, 0.6437057246394358, 0.2391704259473575], 2 -> 
             RGBColor[
              0.9559930988467875, 0.8632165304777597, 0.2835419283360794], 
             262 -> RGBColor[
              0.926190926589446, 0.7450786498824961, 0.2594696908934873], 272 -> 
             RGBColor[
              0.9937517506233237, 0.9890439513152341, 0.5612947989532417], 97 -> 
             RGBColor[
              0.9938570942073877, 0.989269270589677, 0.5727607979733689], 372 -> 
             RGBColor[
              0.8858767343492585, 0.9118380777594727, 0.9889769078253706], 
             356 -> RGBColor[
              0.978841668257383, 0.9402901201989193, 0.37230430590595975`], 
             346 -> RGBColor[
              0.9328584202452865, 0.7715130404173535, 0.26483451279516756`], 
             341 -> RGBColor[
              0.9946433146447268, 0.9909509166060654, 0.6583360405876225], 
             209 -> RGBColor[
              0.955071094396394, 0.8595788914916258, 0.28270735181562334`], 
             378 -> RGBColor[
              0.9927513914592104, 0.9869042842150223, 0.45241187744066136`], 
             66 -> RGBColor[
              0.9802232789297279, 0.9449506174143516, 0.37767160247273696`], 
             139 -> RGBColor[
              0.918660827387957, 0.7152243158054001, 0.25341079632182373`], 
             56 -> 
             RGBColor[
              0.9273536865411683, 0.7496886056242903, 0.260405274844127], 335 -> 
             RGBColor[
              0.9951660399579313, 0.9920689731953737, 0.7152314650432464], 
             314 -> RGBColor[
              0.9702163094110378, 0.9773079528418451, 0.9353001987232291], 
             144 -> RGBColor[
              0.9564916221788328, 0.8648981667355929, 0.2854785973428431], 
             298 -> RGBColor[
              0.9618336265003532, 0.882918001674344, 0.3062312753790813], 204 -> 
             RGBColor[
              0.9736661715757873, 0.9228319546274872, 0.3521984786084996], 
             207 -> RGBColor[
              0.9931045314914411, 0.9876596150360294, 0.4908489906213065], 
             334 -> RGBColor[
              0.9207148695113485, 0.7233679083556857, 0.2550635268288699], 
             149 -> RGBColor[
              0.9950523662397035, 0.9918258366062603, 0.7028587823270187], 
             219 -> RGBColor[
              0.939046566858649, 0.9540616098820428, 0.988062442493575], 400 -> 
             RGBColor[
              0.9710054327996732, 0.9778964797730184, 0.9339644186626115], 9 -> 
             RGBColor[
              0.9937506295810697, 0.9890415535192079, 0.5611727804221794], 11 -> 
             RGBColor[
              0.8886272765450696, 0.58716429919914, 0.22878020836499358`], 44 -> 
             RGBColor[
              0.9926556991980612, 0.9912309571255463, 0.77137760093673], 153 -> 
             RGBColor[
              0.9936334579695936, 0.9887909352901273, 0.5484193736123546], 32 -> 
             RGBColor[
              0.9865985906772946, 0.9887261870916206, 0.8717595644202005], 
             162 -> RGBColor[
              0.9824507018121912, 0.9524642378206639, 0.3863247197575902], 90 -> 
             RGBColor[
              0.99366494044298, 0.9888582731173349, 0.5518460465531763], 331 -> 
             RGBColor[
              0.9944578047595946, 0.9905541297196941, 0.6381444344252887], 8 -> 
             RGBColor[
              0.9691029525535421, 0.9074391453706757, 0.33447123439868237`], 
             364 -> RGBColor[
              0.5824546536543096, 0.6719019529765194, 0.9602721104188162], 
             342 -> RGBColor[
              0.8719815793083006, 0.5115800757483345, 0.21489063056725752`], 
             163 -> RGBColor[
              0.9893610433392342, 0.9898685322591279, 0.8259785748135386], 49 -> 
             RGBColor[
              0.9831063133388306, 0.9546757694449256, 0.3888716467367362], 
             338 -> RGBColor[
              0.9876757581548599, 0.9891716235255354, 0.8539081116968702], 76 -> 
             RGBColor[
              0.9936217677709013, 0.9916304513072456, 0.7553673445794461], 
             369 -> RGBColor[
              0.9407353473525125, 0.9553210996092419, 0.9852037776219588], 82 -> 
             RGBColor[
              0.9948572165403624, 0.991408431132031, 0.6816179418780891], 67 -> 
             RGBColor[
              0.9799284229303955, 0.9439559988931222, 0.37652614259421363`], 
             211 -> RGBColor[
              0.9792035103663717, 0.9415106985971056, 
               0.3737099941712322]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9mGk41G3YxiVbGGbGGGMMZp+JsVWihTktLbQQJSTFQyShTSoPqYhQlpJK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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 5}], {
             RGBColor[
             0.9907246303182609, 0.9800142436561505, 0.4490704829445508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.9903269162321766, 0.97867266065608, 0.44752543882211665`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 73}], {
             RGBColor[
             0.9928400728448135, 0.9870939647317637, 0.4620642989854783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[
             0.9350499267756351, 0.761025044913197, 0.35396859727559365`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 162}], {
             RGBColor[
             0.9877684229315934, 0.9700422619904179, 0.43758617548026935`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 183}], {
             RGBColor[
             0.990348439160031, 0.988382510318947, 0.6719166784819208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 291}], {
             RGBColor[
             0.9918384245607349, 0.9837713331673397, 0.4533973632541682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 357}], {
             RGBColor[
             0.9695847178058237, 0.9734649369016946, 0.732499367123883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 368}], {
             RGBColor[
             0.992674176638348, 0.9865905211690482, 0.45664410225715807`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 387}], {
             RGBColor[
             0.9941675104256242, 0.9899332194925912, 0.6065476876615905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 28}], {
             RGBColor[
             0.9745332524677659, 0.9254047857123409, 0.3855015554787809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 39}], {
             RGBColor[
             0.9585886339740286, 0.9168941639326762, 0.6170655923221358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 50}], {
             RGBColor[
             0.9712937662599532, 0.9259704992706619, 0.5776851925367247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 106}], {
             RGBColor[
             0.9730991256215791, 0.9267170617623135, 0.5477657157943252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 137}], {
             RGBColor[
             0.974304123490247, 0.9272153593480402, 0.5277957826759796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 138}], {
             RGBColor[
             0.9104379786584949, 0.8791573307374263, 0.6352582107693256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 149}], {
             RGBColor[
             0.9755227325432455, 0.9275211835420101, 0.49320035533154905`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 164}], {
             RGBColor[
             0.9742486314377894, 0.9247960101088213, 0.3545223128432185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 197}], {
             RGBColor[
             0.9725194547321783, 0.918963809452075, 0.3477437002103839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 210}], {
             RGBColor[
             0.9404261502035483, 0.8015076671953927, 0.2709700410057594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 217}], {
             RGBColor[
             0.9691093501012296, 0.924740496794251, 0.5992567641610111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 230}], {
             RGBColor[
             0.9751525933917187, 0.9267294933237029, 0.4529129929219097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 254}], {
             RGBColor[
             0.9708733649940349, 0.9257966525433848, 0.5846523294765951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 258}], {
             RGBColor[
             0.9719626615713637, 0.9262471046717554, 0.5665998661810787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 314}], {
             RGBColor[
             0.9631047041289127, 0.9202622416598024, 0.6094210635296542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 328}], {
             RGBColor[
             0.9600221704527905, 0.8768075350758084, 0.299194110699071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 7}], {
             RGBColor[
             0.9614173722194144, 0.875211827413915, 0.3374353939368109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 13}], {
             RGBColor[
             0.9646640115214404, 0.885344913937806, 0.5020852393672655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 14}], {
             RGBColor[
             0.9433394153571774, 0.8130666934514226, 0.2732677674827698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 21}], {
             RGBColor[
             0.9607900478149647, 0.8837429303888522, 0.5662868434802677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 51}], {
             RGBColor[
             0.9630671951050869, 0.8846845893133337, 0.5285486198146621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 79}], {
             RGBColor[
             0.9632095847811564, 0.8847434711036363, 0.5261888543895221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 188}], {
             RGBColor[
             0.9642833413993203, 0.8840080696895609, 0.42266200930476705`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 232}], {
             RGBColor[
             0.9583951764204661, 0.865017251338744, 0.3256947339516853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 293}], {
             RGBColor[
             0.8851618841607543, 0.8252147386631008, 0.6252329341812085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 373}], {
             RGBColor[
             0.9636249119133038, 0.8825997555964044, 0.3509960231076391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 390}], {
             RGBColor[
             0.9475946392910529, 0.8285845035145178, 0.28373668671421015`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 84}], {
             RGBColor[
             0.9248898855620555, 0.882099712677773, 0.6346667414386018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 125}], {
             RGBColor[
             0.9462369498948398, 0.9552344646135225, 0.7491724836544176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 165}], {
             RGBColor[
             0.9472299105000574, 0.9573583069443661, 0.8572501176898444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 184}], {
             RGBColor[
             0.9466903609713075, 0.9562042650591953, 0.7985234811991322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 185}], {
             RGBColor[
             0.9378415126607802, 0.9273837250322643, 0.6766738874196541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 190}], {
             RGBColor[
             0.942675529548876, 0.955503498534445, 0.9348029278883547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.939207210020365, 0.9319905429071329, 0.6819793637713348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 252}], {
             RGBColor[
             0.9465673562340968, 0.955941170363988, 0.7851351746509763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 274}], {
             RGBColor[
             0.9465258689456458, 0.9558524332489997, 0.7806195393329596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 288}], {
             RGBColor[
             0.9435380389160424, 0.9558601683232479, 0.9205089155717172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 318}], {
             RGBColor[
             0.9396259263060123, 0.9334029712578804, 0.6836059974731388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.987965402499442, 0.9710666181520586, 0.407748290563719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 113}], {
             RGBColor[
             0.9326884130429004, 0.7534190024091756, 0.314191449017196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 162}], {
             RGBColor[
             0.9854069091988586, 0.9624362194863965, 0.39780902722187167`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 183}], {
             RGBColor[
             0.9879869254272963, 0.9807764678149256, 0.6321395302235231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 270}], {
             RGBColor[
             0.9401794318765334, 0.9445627068183609, 0.6994269397083194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 291}], {
             RGBColor[
             0.9894769108280002, 0.9761652906633183, 0.4136202149957705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 357}], {
             RGBColor[
             0.967223204073089, 0.9658588943976731, 0.6927222188654854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 368}], {
             RGBColor[
             0.9903126629056133, 0.9789844786650268, 0.4168669539987604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 10}], {
             RGBColor[
             0.8887151074405066, 0.8919996250680348, 0.6772543603158565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.9864519838614952, 0.965267355549196, 0.4608941247226852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 69}], {
             RGBColor[
             0.9814181574776053, 0.9645078714976072, 0.6433526085303705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 71}], {
             RGBColor[
             0.9863610282734968, 0.9650728107434878, 0.45099417028187816`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 93}], {
             RGBColor[
             0.6532822877748772, 0.6998292353981342, 0.6580340173663173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 129}], {
             RGBColor[
             0.9869536433313045, 0.9663403544295652, 0.5154966621280479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 131}], {
             RGBColor[
             0.9838422439531317, 0.9656152791927368, 0.6078806938126776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 142}], {
             RGBColor[
             0.9523637442942925, 0.8419510530310562, 0.31643353121051543`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 201}], {
             RGBColor[
             0.9769313340426824, 0.9611616059263408, 0.6509476302547241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 253}], {
             RGBColor[
             0.9726461272098642, 0.9193911054634221, 0.34823579886610373`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 273}], {
             RGBColor[
             0.9846124466574886, 0.965933777804295, 0.5951164417807789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 281}], {
             RGBColor[
             0.9722226656769568, 0.9179626702794292, 0.3465907307747591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 303}], {
             RGBColor[
             0.9863033079398889, 0.9649493527863215, 0.4447116681772655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 364}], {
             RGBColor[
             0.7808654466235099, 0.8068289921658498, 0.6671323219503058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 391}], {
             RGBColor[
             0.9676605588408362, 0.9025736126875696, 0.32886780719801717`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 394}], {
             RGBColor[
             0.9639187342938839, 0.9514568303398634, 0.6729745673998764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 13}], {
             RGBColor[
             0.9914295446889783, 0.9819333929876279, 0.5732430936401766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 14}], {
             RGBColor[
             0.9701049485247152, 0.9096551725012445, 0.3444256217556809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 21}], {
             RGBColor[
             0.9875555809825025, 0.9803314094386741, 0.6374446977531788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 93}], {
             RGBColor[
             0.6577356206719982, 0.7148513729524126, 0.6753343747302805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 142}], {
             RGBColor[
             0.9568170771914135, 0.8569731905853346, 0.3337338885744786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 188}], {
             RGBColor[
             0.9910488745668581, 0.9805965487393828, 0.49381986357767815`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 273}], {
             RGBColor[
             0.9890657795546096, 0.9809559153585734, 0.6124167991447421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 293}], {
             RGBColor[
             0.9119274173282921, 0.9218032177129227, 0.6963907884541196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 390}], {
             RGBColor[
             0.9743601724585907, 0.9251729825643398, 0.3548945409871212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 16}], {
             RGBColor[
             0.9810837057506051, 0.9475065246437653, 0.410479287964692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 25}], {
             RGBColor[
             0.982115399614751, 0.949713213498923, 0.5227727982004822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 76}], {
             RGBColor[
             0.9813623601622217, 0.9495347983389606, 0.5449192894890642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 117}], {
             RGBColor[
             0.9820686598333959, 0.949613241832721, 0.5176854614444653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 202}], {
             RGBColor[
             0.9644351656532629, 0.9384771514181489, 0.6437293736042096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 234}], {
             RGBColor[
             0.9786634317795485, 0.9396888867072686, 0.37161189084670754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 239}], {
             RGBColor[
             0.9446128873146624, 0.8142298914662278, 0.2945291929818783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 269}], {
             RGBColor[
             0.7309845335356568, 0.7533045431792292, 0.643845303421519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 302}], {
             RGBColor[
             0.970277493102025, 0.911401146435944, 0.3390341026361672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 323}], {
             RGBColor[
             0.9819663755435557, 0.949394466079281, 0.5065524477208296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 365}], {
             RGBColor[
             0.9410976056659905, 0.8002929711274118, 0.29170071485309157`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 377}], {
             RGBColor[
             0.980952778639061, 0.9472264847909341, 0.396228679861592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 388}], {
             RGBColor[
             0.9780555786740897, 0.9376384554518595, 0.36925049631542706`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 18}], {
             RGBColor[
             0.991056873083298, 0.9807248773356685, 0.4852330575541663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 56}], {
             RGBColor[
             0.960552158061119, 0.8693650795717491, 0.4107890276331532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 65}], {
             RGBColor[
             0.9943607218563031, 0.9903464792061408, 0.6275775595282402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 100}], {
             RGBColor[
             0.9937960212830392, 0.9891386417799155, 0.5661133870564462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 174}], {
             RGBColor[
             0.994319394333357, 0.990258083813413, 0.6230793136994781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 198}], {
             RGBColor[
             0.9931690382109257, 0.9877975883863774, 0.4978701489478955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 203}], {
             RGBColor[
             0.9932910572774643, 0.9880585748316831, 0.5111511713262136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 266}], {
             RGBColor[
             0.9938238964263917, 0.9903929439716905, 0.655988054426226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 313}], {
             RGBColor[
             0.9938372714720646, 0.9892268717632069, 0.5706032155651937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 339}], {
             RGBColor[
             0.9927836114379367, 0.9899627593948596, 0.6732282688561767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 358}], {
             RGBColor[
             0.9926667591037985, 0.9899144379517254, 0.6751648144369939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 384}], {
             RGBColor[
             0.9905912907144445, 0.979154358681587, 0.4834243579690235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 32}], {
             RGBColor[
             0.8923762829827988, 0.9154847029362551, 0.9261378757850591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 52}], {
             RGBColor[
             0.891237965065512, 0.9150139792240208, 0.9450027495468387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 60}], {
             RGBColor[
             0.8748768871157144, 0.9028335042987521, 0.9736646410658808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 68}], {
             RGBColor[
             0.8663021726523887, 0.8100339047775948, 0.6233158100494234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.8963925111791009, 0.9165839481424201, 0.8187584889621089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 253}], {
             RGBColor[
             0.8820849950576606, 0.8696346991762767, 0.6514976257001648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 271}], {
             RGBColor[
             0.8931740006950164, 0.9158145797106672, 0.912917628866351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 303}], {
             RGBColor[
             0.8957421757876853, 0.9151929464991762, 0.7479734950113266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 333}], {
             RGBColor[
             0.8945250213210354, 0.9115978288197102, 0.6998247786315365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 334}], {
             RGBColor[
             0.8594344223998258, 0.7828055635682876, 0.6177898569893938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 337}], {
             RGBColor[
             0.8960692481908958, 0.9158925212975508, 0.7835733076438918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 345}], {
             RGBColor[
             0.8557949715321251, 0.8880281405996704, 0.9860608596309719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 353}], {
             RGBColor[
             0.883529407715648, 0.9092865399949803, 0.9590181806289899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 364}], {
             RGBColor[
             0.6903043144713064, 0.7570725858787044, 0.9703941487843669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 391}], {
             RGBColor[
             0.8770994266886327, 0.8528172064004244, 0.6321296340320782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 54}], {
             RGBColor[
             0.9280767760023129, 0.7812330145622483, 0.5843169664474306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 83}], {
             RGBColor[
             0.9240298754690488, 0.7782148427707314, 0.5911673134495444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 118}], {
             RGBColor[
             0.9396463844770443, 0.788786127335718, 0.5165703431431099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 123}], {
             RGBColor[
             0.941665591496496, 0.789122407772735, 0.4468556464006007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 141}], {
             RGBColor[
             0.9233449226382119, 0.7286808187660896, 0.26018081820800926`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 161}], {
             RGBColor[
             0.9233354630583182, 0.7286489093818929, 0.26014406952641367`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 196}], {
             RGBColor[
             0.938780927348541, 0.7884282385718482, 0.5309132074936611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 206}], {
             RGBColor[
             0.9418044892052466, 0.78941949592704, 0.46197380482081046`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 214}], {
             RGBColor[
             0.9407585876397888, 0.7871824182353949, 0.34813387397698015`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 286}], {
             RGBColor[
             0.9417041076350248, 0.7892047898984691, 0.4510478903854035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 332}], {
             RGBColor[
             0.9377641843133018, 0.7773203741998126, 0.31619692696664903`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 366}], {
             RGBColor[
             0.9369712538221734, 0.7746456334643033, 0.3131165417409737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 386}], {
             RGBColor[
             0.9410287950519811, 0.7877603645679145, 0.3775442832672792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 19}], {
             RGBColor[
             0.9133140658989429, 0.9300930888151612, 0.8360479916487813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 24}], {
             RGBColor[
             0.9116274148521764, 0.9297092231480641, 0.8867961470836283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 65}], {
             RGBColor[
             0.9133402353151996, 0.9301490625504001, 0.8388963711093899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 100}], {
             RGBColor[
             0.9127755347419357, 0.9289412251241749, 0.7774321986375958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 107}], {
             RGBColor[
             0.9045700340934413, 0.9020881703096919, 0.6753161221059519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 124}], {
             RGBColor[
             0.8848709567502551, 0.8303361496425783, 0.6264039534396858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 150}], {
             RGBColor[
             0.8970621286434264, 0.8767622422867597, 0.6461493271816205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 157}], {
             RGBColor[
             0.8982307598804034, 0.8807043098567464, 0.6506892388597849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 167}], {
             RGBColor[
             0.9126402670879816, 0.9286519012900247, 0.7627091492798836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 168}], {
             RGBColor[
             0.9125267345309678, 0.9284090666304743, 0.7503518310906451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 203}], {
             RGBColor[
             0.9122705707363608, 0.9278611581759424, 0.7224699829073632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 206}], {
             RGBColor[
             0.9133456791821433, 0.9301607064313332, 0.839488902430553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 211}], {
             RGBColor[
             0.9054565834326171, 0.905078709402416, 0.6787601988778554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 238}], {
             RGBColor[
             0.875842233357877, 0.794540270035515, 0.619139230666802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 341}], {
             RGBColor[
             0.9131764855717948, 0.9297988184068959, 0.8210732220860506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 358}], {
             RGBColor[
             0.911646272562695, 0.9297170212959847, 0.8864836260181435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 14}], {
             RGBColor[
             0.9733515878267414, 0.9197882590251356, 0.5090754671861356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 21}], {
             RGBColor[
             0.9908022202845286, 0.9904644959625653, 0.8020945431836335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 51}], {
             RGBColor[
             0.9930793675746508, 0.9914061548870468, 0.7643563195180277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 79}], {
             RGBColor[
             0.9932217572507203, 0.9914650366773492, 0.7619965540928878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 87}], {
             RGBColor[
             0.9947390270902103, 0.9916782651976254, 0.7067433861031565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 205}], {
             RGBColor[
             0.9159356851051204, 0.9325436061087669, 0.8611132786884147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 232}], {
             RGBColor[
             0.9884073488900301, 0.971738816912457, 0.561502433655051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 277}], {
             RGBColor[
             0.991054067919412, 0.9806668216777426, 0.5717844372932495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 373}], {
             RGBColor[
             0.9936370843828677, 0.9893213211701173, 0.5868037228110049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 390}], {
             RGBColor[
             0.9776068117606169, 0.9353060690882309, 0.5195443864175758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 69}], {
             RGBColor[
             0.9677935335124892, 0.9173848750893934, 0.5964853394402925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 71}], {
             RGBColor[
             0.9727364043083808, 0.917949814335274, 0.4041269011918004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 201}], {
             RGBColor[
             0.9633067100775663, 0.9140386095181269, 0.6040803611646464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 212}], {
             RGBColor[
             0.8866299873951771, 0.8539014718910882, 0.6315345622136785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 273}], {
             RGBColor[
             0.9709878226923725, 0.9188107813960811, 0.5482491726907011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 289}], {
             RGBColor[
             0.9693748285626644, 0.9181437668713884, 0.5749806597149616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 293}], {
             RGBColor[
             0.8938494604660551, 0.8596580837504304, 0.6322231620000787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 390}], {
             RGBColor[
             0.9562822155963537, 0.8630278486018474, 0.2907269145330802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 35}], {
             RGBColor[
             0.9920214873163724, 0.9905223896296381, 0.7494465012541118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 106}], {
             RGBColor[
             0.9897417348489894, 0.9900259579817372, 0.8196695312988485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 154}], {
             RGBColor[
             0.9058196497891615, 0.9255133320312974, 0.9051341390183181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 207}], {
             RGBColor[
             0.9911914243965245, 0.9887469689763184, 0.6590992749832162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 231}], {
             RGBColor[
             0.9919156022175879, 0.9902959121099637, 0.7379215616985018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 369}], {
             RGBColor[
             0.9650068323270603, 0.9725777112629246, 0.9062766684835424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 372}], {
             RGBColor[
             0.9375775258254333, 0.95083620033804, 0.9081632335852483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 392}], {
             RGBColor[
             0.9497590276438446, 0.8358359127026305, 0.5369922747329134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 25}], {
             RGBColor[
             0.9940961528118141, 0.9897805927720125, 0.5987808517664919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 37}], {
             RGBColor[
             0.9901493647961157, 0.9882814805055855, 0.6738560219031188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 76}], {
             RGBColor[
             0.9933431133592847, 0.9896021776120503, 0.6209273430550739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 77}], {
             RGBColor[
             0.9929658372499628, 0.9894461642452919, 0.6271797845458096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 78}], {
             RGBColor[
             0.9937276850680686, 0.9897612078966744, 0.6145539946008451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 80}], {
             RGBColor[
             0.9921288604265215, 0.9891000528194756, 0.6410506565368193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 96}], {
             RGBColor[
             0.9470718459085119, 0.8156398142781454, 0.3628288837390296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 182}], {
             RGBColor[
             0.9937631884876152, 0.9890684157504084, 0.5625397398950687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.941773231896972, 0.9515420496819559, 0.7379517520836256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 269}], {
             RGBColor[
             0.7429652867327199, 0.7933719224523188, 0.7198533569875287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 302}], {
             RGBColor[
             0.9822582462990881, 0.9514685257090336, 0.4150421562021769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 323}], {
             RGBColor[
             0.9939471287406187, 0.9894618453523705, 0.5825605012868393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 365}], {
             RGBColor[
             0.9530783588630536, 0.8403603504005015, 0.3677087684191012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 377}], {
             RGBColor[
             0.9929335318361241, 0.9872938640640236, 0.47223673342760164`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 388}], {
             RGBColor[
             0.9900363318711527, 0.9777058347249491, 0.44525854988143676`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 18}], {
             RGBColor[
             0.967223204073089, 0.9658588943976731, 0.6927222188654854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 31}], {
             RGBColor[
             0.9697822289750073, 0.9738873933211358, 0.7539972389918723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 62}], {
             RGBColor[
             0.9603541703987104, 0.9426880308881889, 0.6660373201486895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.9470819546024093, 0.8955867841252745, 0.6266168765890101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 111}], {
             RGBColor[
             0.9658166720787411, 0.9611143317113201, 0.6872581076687232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 222}], {
             RGBColor[
             0.963041813660847, 0.9719572256585114, 0.9474447486201247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 223}], {
             RGBColor[
             0.9672021762580854, 0.9743740302301753, 0.9096824386723266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 247}], {
             RGBColor[
             0.9686682690910497, 0.9749802972934734, 0.8853854863034787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 256}], {
             RGBColor[
             0.9702750704179893, 0.974941531333761, 0.8076399885956491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 292}], {
             RGBColor[
             0.9698469607668128, 0.9740258480784196, 0.7610428950515863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 310}], {
             RGBColor[
             0.9680396339029962, 0.9747203404880258, 0.895803598225241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 319}], {
             RGBColor[
             0.9532743782762073, 0.9188062296447437, 0.6385336646593234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 384}], {
             RGBColor[
             0.9667576217042355, 0.9642883757435916, 0.6909135192803425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 99}], {
             RGBColor[
             0.9682218671148466, 0.9021360908797305, 0.3431879924096779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 144}], {
             RGBColor[
             0.9724273693821794, 0.918653183943861, 0.3473859660144981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.990475281713154, 0.9794809122028381, 0.4219304260798823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 218}], {
             RGBColor[
             0.9877631997002088, 0.980683951477286, 0.6358472445049848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 266}], {
             RGBColor[
             0.99113013992862, 0.9820762677881512, 0.5800483315582128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 310}], {
             RGBColor[
             0.9891795464154335, 0.9812696472424818, 0.6123747140459088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 319}], {
             RGBColor[
             0.9744142907886446, 0.9253555363991995, 0.3551047804799913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 384}], {
             RGBColor[
             0.9878975342166728, 0.9708376824980476, 0.4074846351010104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 24}], {
             RGBColor[
             0.9932318242522566, 0.9911555917554989, 0.7390337351479309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 85}], {
             RGBColor[
             0.9765138470033465, 0.9309470785398416, 0.4900241170564933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 107}], {
             RGBColor[
             0.9861744434935216, 0.9635345389171267, 0.5275537101702545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 124}], {
             RGBColor[
             0.9664753661503354, 0.8917825182500132, 0.4786415415039885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 150}], {
             RGBColor[
             0.9786665380435067, 0.9382086108941945, 0.49838691524592316`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 152}], {
             RGBColor[
             0.9179082886749675, 0.9337563973499081, 0.8364861927184697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 157}], {
             RGBColor[
             0.9798351692804836, 0.9421506784641812, 0.5029268269240875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 160}], {
             RGBColor[
             0.9680396569780948, 0.8979844101130621, 0.47990020662262867`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 167}], {
             RGBColor[
             0.9942446764880619, 0.9900982698974594, 0.6149467373441864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 168}], {
             RGBColor[
             0.994131143931048, 0.989855435237909, 0.6025894191549477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 181}], {
             RGBColor[
             0.9736248125727407, 0.920127690903061, 0.48439415391453217`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 211}], {
             RGBColor[
             0.9870609928326974, 0.9665250780098508, 0.530997786942158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 238}], {
             RGBColor[
             0.9574466427579573, 0.8559866386429498, 0.4713768187311047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 64}], {
             RGBColor[
             0.9909306532555117, 0.9895495517440376, 0.7295987298094919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 88}], {
             RGBColor[
             0.9471035884478467, 0.8281078276722857, 0.5485564604043424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 89}], {
             RGBColor[
             0.9896233095217069, 0.9899769860655138, 0.8216321454468443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 120}], {
             RGBColor[
             0.9903101929313518, 0.9882224498488211, 0.6620654525619527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 140}], {
             RGBColor[
             0.9900801936939421, 0.9901659194121206, 0.8140603923345714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 189}], {
             RGBColor[
             0.9735861062004022, 0.9792380953112634, 0.9034860000948216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 195}], {
             RGBColor[
             0.9769548759857207, 0.9434285346716293, 0.5883542399879538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 241}], {
             RGBColor[
             0.9912840430531111, 0.9903054167879133, 0.7680630284091621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 255}], {
             RGBColor[
             0.9554553505717803, 0.8612197814339366, 0.5552764842503124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 257}], {
             RGBColor[
             0.963697855949952, 0.9718634544650013, 0.9202242285001265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 263}], {
             RGBColor[
             0.9797514301677264, 0.952861968589682, 0.5992183249001013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 312}], {
             RGBColor[
             0.8423705893613926, 0.8762171250806208, 0.911960232372186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 336}], {
             RGBColor[
             0.95370205634382, 0.9639961020987428, 0.9228428278874707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 356}], {
             RGBColor[
             0.9832715570476533, 0.9647361831207725, 0.6128933531084353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 359}], {
             RGBColor[
             0.9913505673033479, 0.9904477054325365, 0.7753037825073557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 360}], {
             RGBColor[
             0.9529489950395945, 0.8512829169422901, 0.5532598117573901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 389}], {
             RGBColor[
             0.8494284854415972, 0.8817308071404735, 0.9126636974936719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 109}], {
             RGBColor[
             0.9884550993495319, 0.9894939011376874, 0.8409924112307959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[
             0.9718783704330213, 0.9780929235996195, 0.9121292209245851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 132}], {
             RGBColor[
             0.9903148575962779, 0.9888994471036402, 0.7110584857280301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 180}], {
             RGBColor[
             0.9817001861126274, 0.9605797876304898, 0.6146975943822531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 232}], {
             RGBColor[
             0.9845333851835543, 0.9701368333635031, 0.6257040377680533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 249}], {
             RGBColor[
             0.9877872033655151, 0.9811127261240973, 0.6383445069729659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 370}], {
             RGBColor[
             0.9822826169196119, 0.9625444635037054, 0.616960228084559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 45}], {
             RGBColor[
             0.9549330512643189, 0.8586238956384069, 0.28471959194796725`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 74}], {
             RGBColor[
             0.9717510407022449, 0.9200095964627404, 0.539922563862778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 116}], {
             RGBColor[
             0.9738744024263128, 0.9208379642332342, 0.5011205271658704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 141}], {
             RGBColor[
             0.9552934903405373, 0.8598397412776111, 0.28611982969586736`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 179}], {
             RGBColor[
             0.8246165903970853, 0.806237798358505, 0.6255316541858289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 209}], {
             RGBColor[
             0.9537977531730573, 0.8545305178569045, 0.28168279157816656`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 286}], {
             RGBColor[
             0.9736526753373502, 0.9203637124099906, 0.47698690187326165`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 290}], {
             RGBColor[
             0.9728651069125382, 0.9186791831847, 0.39126493914139404`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 304}], {
             RGBColor[
             0.7735962529206488, 0.7656497590962644, 0.6209459142571547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 338}], {
             RGBColor[
             0.9701000850522902, 0.9193268838738593, 0.56728317151879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 38}], {
             RGBColor[
             0.9519522081036945, 0.8420420743227852, 0.3071309384651449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 92}], {
             RGBColor[
             0.951034327829994, 0.8701646841623136, 0.5979158194002538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 98}], {
             RGBColor[
             0.960914513483636, 0.8763398566031464, 0.5277459408249228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 119}], {
             RGBColor[
             0.9339024590627187, 0.8573877644865402, 0.6269156045162615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 128}], {
             RGBColor[
             0.8943953793555982, 0.605694922956246, 0.2331982983438288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 130}], {
             RGBColor[
             0.9187363523287027, 0.8453373353637593, 0.6269464572590486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 139}], {
             RGBColor[
             0.9245571365421631, 0.7386012167732783, 0.25815510507146217`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 143}], {
             RGBColor[
             0.9617783408908696, 0.8748174810172926, 0.37680370374293404`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 146}], {
             RGBColor[
             0.9616914931666909, 0.8746317225169264, 0.3673508649281232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 151}], {
             RGBColor[
             0.9621490862614093, 0.8756104678767702, 0.41715704935098014`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 158}], {
             RGBColor[
             0.9487962144530314, 0.83139616667655, 0.2948704990917109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 186}], {
             RGBColor[
             0.9619590691802166, 0.8767718072275394, 0.5104349497090939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 213}], {
             RGBColor[
             0.8643037104923361, 0.8021106682610231, 0.6217078004855091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 267}], {
             RGBColor[
             0.9550945719101237, 0.8526420053039798, 0.31933842846751026`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 306}], {
             RGBColor[
             0.959521115293466, 0.8675737755378053, 0.33653471362921805`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 308}], {
             RGBColor[
             0.9609392932009722, 0.8723576226238318, 0.34204406699945394`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 311}], {
             RGBColor[
             0.9369817359154303, 0.8596842841214394, 0.6217031920086483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 346}], {
             RGBColor[
             0.9316559329708278, 0.766745579079255, 0.2638669633081341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 348}], {
             RGBColor[
             0.9596438747143072, 0.875814414818102, 0.5488037135404257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 354}], {
             RGBColor[
             0.9573254156183779, 0.8748556724002543, 0.5872265807397798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 374}], {
             RGBColor[
             0.9578735849569162, 0.862016268854104, 0.33013436938172014`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 33}], {
             RGBColor[
             0.9821230375088406, 0.9551737995735804, 0.5691152392178029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 56}], {
             RGBColor[
             0.9594494298733292, 0.870230165856346, 0.5250935827134524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 65}], {
             RGBColor[
             0.9932579936685131, 0.9912115654907379, 0.7418821146085395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 100}], {
             RGBColor[
             0.9926932930952493, 0.9900037280645126, 0.6804179421367453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 107}], {
             RGBColor[
             0.984487792446755, 0.9631506732500297, 0.5783018656051016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 124}], {
             RGBColor[
             0.9647887151035688, 0.8913986525829161, 0.5293896969388354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 150}], {
             RGBColor[
             0.9769798869967401, 0.9378247452270975, 0.54913507068077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 157}], {
             RGBColor[
             0.9781485182337171, 0.9417668127970842, 0.5536749823589344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 167}], {
             RGBColor[
             0.9925580254412952, 0.9897144042303625, 0.6656948927790333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 168}], {
             RGBColor[
             0.9924444928842813, 0.9894715695708121, 0.6533375745897947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 203}], {
             RGBColor[
             0.9921883290896744, 0.9889236611162802, 0.6254557264065127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 206}], {
             RGBColor[
             0.9932634375354568, 0.991223209371671, 0.7424746459297026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 211}], {
             RGBColor[
             0.9853743417859309, 0.9661412123427537, 0.581745942377005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 238}], {
             RGBColor[
             0.9557599917111906, 0.8556027729758527, 0.5221249741659516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 341}], {
             RGBColor[
             0.9930942439251084, 0.9908613213472337, 0.7240589655852001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 358}], {
             RGBColor[
             0.9915640309160085, 0.9907795242363224, 0.7894693695172931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 386}], {
             RGBColor[
             0.9924877433821914, 0.9895640780125454, 0.6580451243761714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 37}], {
             RGBColor[
             0.9911810586602616, 0.9904881693607432, 0.7861495321389089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 62}], {
             RGBColor[
             0.9848764479563645, 0.9590268778801653, 0.5334989496274218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[
             0.9943748072234306, 0.9918088664672079, 0.7332208532908641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 78}], {
             RGBColor[
             0.9947593789322146, 0.9919678967518322, 0.7268475048366354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 91}], {
             RGBColor[
             0.9671985160621952, 0.8944584349070621, 0.49053356347994936`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 117}], {
             RGBColor[
             0.9950811068946048, 0.9918873099609682, 0.7059870252462651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 182}], {
             RGBColor[
             0.9947948823517612, 0.9912751046055661, 0.6748332501308589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 187}], {
             RGBColor[
             0.942804925761118, 0.9537487385371135, 0.8502452623194159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 208}], {
             RGBColor[
             0.9944380228057188, 0.9918350077350504, 0.7321732074956663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 239}], {
             RGBColor[
             0.9576253343758714, 0.856503959594475, 0.48283075678367815`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 269}], {
             RGBColor[
             0.7439969805968658, 0.7955786113074765, 0.832146867223319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 309}], {
             RGBColor[
             0.9946433083199038, 0.9909509030779087, 0.6583353521696842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 323}], {
             RGBColor[
             0.9949788226047647, 0.9916685342075282, 0.6948540115226294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 362}], {
             RGBColor[
             0.9948690625997216, 0.9914337686551802, 0.6829073123339391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 365}], {
             RGBColor[
             0.9541100527271995, 0.8425670392556591, 0.48000227865489137`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 377}], {
             RGBColor[
             0.99396522570027, 0.9895005529191814, 0.5845302436633918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 388}], {
             RGBColor[
             0.9910680257352986, 0.9799125235801067, 0.5575520601172269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 395}], {
             RGBColor[
             0.9951662889733404, 0.9920695058141543, 0.7152585688337751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 70}], {
             RGBColor[
             0.905616921873382, 0.5617598955075144, 0.37163223947281715`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 177}], {
             RGBColor[
             0.9273064382301717, 0.9405770277739299, 0.7828109098658509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 285}], {
             RGBColor[
             0.9698000231913391, 0.9742027422949937, 0.7779357213509062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 324}], {
             RGBColor[
             0.9913299202869521, 0.9895032861048663, 0.7076172693709196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 40}], {
             RGBColor[
             0.9925914103446634, 0.9890396549709839, 0.6150909551532406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 41}], {
             RGBColor[
             0.9910272541077687, 0.9883928361700463, 0.641013071905167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 48}], {
             RGBColor[
             0.851964125508729, 0.8806146424096757, 0.7132895010966437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 63}], {
             RGBColor[
             0.9812971432304137, 0.948406547626979, 0.39599844902283504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 86}], {
             RGBColor[
             0.9933814797712197, 0.9882519794027094, 0.5209931017485425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 250}], {
             RGBColor[
             0.9935695376154183, 0.9886542161158857, 0.5414620375310799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 265}], {
             RGBColor[
             0.9931632506641095, 0.9877852094089481, 0.49724021019353626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 295}], {
             RGBColor[
             0.9913528709383708, 0.988527487097471, 0.6356167583527474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 325}], {
             RGBColor[
             0.9915264382678071, 0.9885992616486698, 0.6327402985261373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 376}], {
             RGBColor[
             0.9380785115949166, 0.9484002963135791, 0.7217365922317933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 39}], {
             RGBColor[
             0.977128787595007, 0.9790824191672572, 0.7190252194648372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 50}], {
             RGBColor[
             0.9898339198809316, 0.9881587545052429, 0.6796448196794262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 106}], {
             RGBColor[
             0.9916392792425575, 0.9889053169968945, 0.6497253429370267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 197}], {
             RGBColor[
             0.9910596083531567, 0.9811520646866561, 0.4497033273530854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 217}], {
             RGBColor[
             0.9876495037222079, 0.9869287520288321, 0.7012163913037126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 231}], {
             RGBColor[
             0.9938131466111559, 0.989175271125121, 0.56797737333668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 254}], {
             RGBColor[
             0.9894135186150133, 0.9879849077779659, 0.6866119566192965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 314}], {
             RGBColor[
             0.9816448577498911, 0.9824504968943835, 0.7113806906723558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 369}], {
             RGBColor[
             0.9669043767206285, 0.9714570702780819, 0.7363324801217206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 113}], {
             RGBColor[
             0.9322906989568162, 0.7520774194091051, 0.3126464048947618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 162}], {
             RGBColor[
             0.9850091951127744, 0.9610946364863261, 0.3962639830994375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 183}], {
             RGBColor[
             0.987589211341212, 0.9794348848148552, 0.6305944861010889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 270}], {
             RGBColor[
             0.9397817177904492, 0.9432211238182904, 0.6978818955858852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 357}], {
             RGBColor[
             0.9668254899870048, 0.9645173113976028, 0.6911771747430511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 153}], {
             RGBColor[
             0.9935852575693603, 0.9886878395078365, 0.5431730575053609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 168}], {
             RGBColor[
             0.9934404348660999, 0.9883780783893839, 0.5274099999975894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 175}], {
             RGBColor[
             0.9935772685958506, 0.9886707519013083, 0.5423035070410547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 211}], {
             RGBColor[
             0.9863702837677494, 0.9650477211613256, 0.4558183677847997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 216}], {
             RGBColor[
             0.9419663368438711, 0.9520130277325373, 0.7636673321195524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 229}], {
             RGBColor[
             0.9634836224083841, 0.9691703271705228, 0.7657196700254033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 294}], {
             RGBColor[
             0.9776799816323394, 0.979816455058819, 0.7437173912922643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 329}], {
             RGBColor[
             0.9525417765395067, 0.9604455962831738, 0.7646760269985287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 341}], {
             RGBColor[
             0.9940901859069269, 0.9897678301658055, 0.5981313909929948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 343}], {
             RGBColor[
             0.9295591160090555, 0.9421198466238931, 0.7624839203202709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 358}], {
             RGBColor[
             0.9925599728978272, 0.9896860330548943, 0.6635417949250878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 379}], {
             RGBColor[
             0.992331176426499, 0.9895914198341991, 0.6673335445612819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 99}], {
             RGBColor[
             0.9707808920167649, 0.9101645898031931, 0.40446301253606487`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 111}], {
             RGBColor[
             0.9895156094930966, 0.9756921373892387, 0.465104243615778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 169}], {
             RGBColor[
             0.9710722319815019, 0.9113196556800877, 0.4046974315103202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 199}], {
             RGBColor[
             0.8954332683972658, 0.915053988901813, 0.7561414773685574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 215}], {
             RGBColor[
             0.9906725878042366, 0.9795948969041401, 0.46959888587753595`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 222}], {
             RGBColor[
             0.9867407510752024, 0.9865350313364301, 0.7252908845671796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 223}], {
             RGBColor[
             0.9909011136724408, 0.988951835908094, 0.6875285746193813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 224}], {
             RGBColor[
             0.9085056627851571, 0.5851669451055769, 0.35100459399255346`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 247}], {
             RGBColor[
             0.9923672065054052, 0.989558102971392, 0.6632316222505334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 259}], {
             RGBColor[
             0.9925449298170758, 0.9896315961280485, 0.6602862870429655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 292}], {
             RGBColor[
             0.9935458981811682, 0.9886036537563383, 0.5388890309986412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 363}], {
             RGBColor[
             0.9859647647855914, 0.9859563020321991, 0.7266044269458531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 383}], {
             RGBColor[
             0.9922331590276505, 0.9895026708944773, 0.6654531358606818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 393}], {
             RGBColor[
             0.9574992379644082, 0.8575072573344444, 0.3937762819250493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 400}], {
             RGBColor[
             0.9822432995945181, 0.9831808393860364, 0.7329038968007693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 46}], {
             RGBColor[
             0.9891781449350001, 0.9862925562318327, 0.6471201057610548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 52}], {
             RGBColor[
             0.9854602727600078, 0.9882554633793865, 0.8906244381819802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 71}], {
             RGBColor[
             0.990022203815789, 0.9885578886117081, 0.6998776857510807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 105}], {
             RGBColor[
             0.9892251787963634, 0.9898123487790913, 0.8282302018950741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 111}], {
             RGBColor[
             0.9860743216370624, 0.9758226314355218, 0.6350623383564147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 129}], {
             RGBColor[
             0.9906148188735967, 0.9898254322977855, 0.7643801775972503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 199}], {
             RGBColor[
             0.8919919805412317, 0.9151844829480961, 0.9260995721091941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 215}], {
             RGBColor[
             0.9872312999482025, 0.9797253909504231, 0.6395569806181727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 247}], {
             RGBColor[
             0.9889259186493711, 0.989688597017675, 0.8331897169911702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 259}], {
             RGBColor[
             0.9891036419610417, 0.9897620901743316, 0.8302443817836023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 271}], {
             RGBColor[
             0.9873963083895122, 0.9890560638660327, 0.8585393175014924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 287}], {
             RGBColor[
             0.9889799048938368, 0.9897109217171447, 0.8322950252084529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 292}], {
             RGBColor[
             0.9901046103251342, 0.9887341478026214, 0.7088471257392779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 303}], {
             RGBColor[
             0.989964483482181, 0.9884344306545418, 0.693595183646468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 333}], {
             RGBColor[
             0.9887473290155312, 0.9848393129750757, 0.6454464672666779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 337}], {
             RGBColor[
             0.9902915558853915, 0.9891340054529165, 0.7291949962790333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 345}], {
             RGBColor[
             0.9500172792266208, 0.961269624755036, 0.9316825482661134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 353}], {
             RGBColor[
             0.9777517154101438, 0.9825280241503459, 0.9046398692641314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 385}], {
             RGBColor[
             0.9890430386996303, 0.9858368111754774, 0.6465952435493145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 391}], {
             RGBColor[
             0.9713217343831284, 0.9260586905557899, 0.5777513226672196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 400}], {
             RGBColor[
             0.9788020117384839, 0.9833113334323196, 0.902861991541406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 58}], {
             RGBColor[
             0.9814597407287113, 0.9548995093090472, 0.5801077834215864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 74}], {
             RGBColor[
             0.9818392856334802, 0.9550564608810284, 0.5738177421188372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 107}], {
             RGBColor[
             0.9750656567501055, 0.9275527467352082, 0.3576352142401266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 116}], {
             RGBColor[
             0.9839626473575482, 0.955884828651522, 0.5350157054219296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 118}], {
             RGBColor[
             0.981683197110605, 0.9549919142655274, 0.5764045328870271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 124}], {
             RGBColor[
             0.9553665794069193, 0.8558007260680947, 0.30872304557386054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 141}], {
             RGBColor[
             0.9653817352717726, 0.8948866056958991, 0.3200150079519265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 150}], {
             RGBColor[
             0.9675577513000906, 0.902226818712276, 0.3284684193157952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 152}], {
             RGBColor[
             0.9067995019315516, 0.8977746051679896, 0.6665676967883416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 156}], {
             RGBColor[
             0.9794205256177924, 0.9540562414552444, 0.6139028551290501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 157}], {
             RGBColor[
             0.9687263825370676, 0.9061688862822627, 0.33300833099395954`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 179}], {
             RGBColor[
             0.8347048353283206, 0.8412846627767928, 0.659426832441888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 206}], {
             RGBColor[
             0.9838413018388075, 0.9556252828568494, 0.5218079945647277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 209}], {
             RGBColor[
             0.9638859981042927, 0.8895773822751923, 0.3155779698342257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 245}], {
             RGBColor[
             0.982723006039268, 0.9554219019794, 0.5591722079998359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 286}], {
             RGBColor[
             0.9837409202685856, 0.9554105768282785, 0.5108820801293208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 386}], {
             RGBColor[
             0.983065607685542, 0.953966151497724, 0.4373784730111964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 43}], {
             RGBColor[
             0.9899143591557575, 0.9900973425688282, 0.8168086997983144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 159}], {
             RGBColor[
             0.9869944639779931, 0.9888898908749393, 0.8651989193403636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 250}], {
             RGBColor[
             0.9908163058758923, 0.9896804010982977, 0.7444422910488748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 265}], {
             RGBColor[
             0.9904100189245835, 0.9888113943913601, 0.7002204637113312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 321}], {
             RGBColor[
             0.9774453444801756, 0.9821886086660077, 0.9001910475141133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 375}], {
             RGBColor[
             0.9890348426575566, 0.9897336398942791, 0.831384564289239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 381}], {
             RGBColor[
             0.9909453250789401, 0.9905236734726799, 0.7997229263968975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 73}], {
             RGBColor[
             0.993679329484884, 0.9888890498230122, 0.553412204965553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 154}], {
             RGBColor[
             0.9085628198039257, 0.926201398744328, 0.827231080927304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 207}], {
             RGBColor[
             0.993934594411289, 0.9894350356893491, 0.5811962168922021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 231}], {
             RGBColor[
             0.9946587722323522, 0.9909839788229946, 0.6600185036074877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 280}], {
             RGBColor[
             0.9885323876647447, 0.9715833698002473, 0.5286415866196462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 291}], {
             RGBColor[
             0.9926776812008055, 0.9855664182585882, 0.5447452692342428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 372}], {
             RGBColor[
             0.9403206958401976, 0.9515242670510708, 0.8302601754942343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 387}], {
             RGBColor[
             0.9950067670656948, 0.9917283045838396, 0.6978955936416651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 392}], {
             RGBColor[
             0.9525021976586088, 0.8365239794156613, 0.45908921664189933`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 61}], {
             RGBColor[
             0.9554141719422325, 0.8641383105286053, 0.5703238255346936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 70}], {
             RGBColor[
             0.9016423923886312, 0.5612957527947937, 0.5232323979164527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 90}], {
             RGBColor[
             0.9898153626101213, 0.9886613893534613, 0.7170464211930409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 95}], {
             RGBColor[
             0.9782629533902787, 0.9504095128369685, 0.6111894291902584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 148}], {
             RGBColor[
             0.9759908998021403, 0.9427453425806258, 0.6023629300416586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 228}], {
             RGBColor[
             0.9799623468820855, 0.9842818415335863, 0.9056058748502434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 276}], {
             RGBColor[
             0.9900513413929573, 0.9891661241088325, 0.7427312554124976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 282}], {
             RGBColor[
             0.9904136271378872, 0.9899410166845302, 0.7821638229796732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 301}], {
             RGBColor[
             0.9894308236178098, 0.9878388993317628, 0.6751917249795087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 305}], {
             RGBColor[
             0.9862451144894444, 0.988580015604021, 0.8776175796199295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 361}], {
             RGBColor[
             0.9852074525084193, 0.9738349390083911, 0.6381674969056165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 382}], {
             RGBColor[
             0.9887910265443577, 0.9896328156656831, 0.8354252282608206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 76}], {
             RGBColor[
             0.9904280192077324, 0.9903097542007809, 0.808296023427491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 78}], {
             RGBColor[
             0.9908125909165162, 0.9904687844854052, 0.8019226749732622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 80}], {
             RGBColor[
             0.989213766274969, 0.9898076294082063, 0.8284193369092363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 96}], {
             RGBColor[
             0.9441567517569596, 0.816347390866876, 0.5501975641114467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 104}], {
             RGBColor[
             0.9737301920479837, 0.9332422698962709, 0.5806055465064086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 117}], {
             RGBColor[
             0.9911343188789065, 0.9903881976945412, 0.781062195382892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 145}], {
             RGBColor[
             0.9222281084100186, 0.7149137934907575, 0.5318269042985506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 182}], {
             RGBColor[
             0.9908480943360629, 0.9897759923391392, 0.7499084202674857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 187}], {
             RGBColor[
             0.9388581377454197, 0.9522496262706865, 0.9253204324560427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 208}], {
             RGBColor[
             0.9904912347900205, 0.9903358954686234, 0.8072483776322932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 269}], {
             RGBColor[
             0.7400501925811674, 0.7940794990410496, 0.9072220373599458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 323}], {
             RGBColor[
             0.9910320345890663, 0.9901694219411012, 0.7699291816592564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 365}], {
             RGBColor[
             0.9501632647115011, 0.8410679269892322, 0.5550774487915182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 377}], {
             RGBColor[
             0.9900184376845718, 0.9880014406527544, 0.6596054138000187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 388}], {
             RGBColor[
             0.9871212377196004, 0.9784134113136798, 0.6326272302538538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 395}], {
             RGBColor[
             0.9912195009576421, 0.9905703935477274, 0.7903337389704019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 44}], {
             RGBColor[
             0.9830533348545405, 0.9566684940149801, 0.5613700320229595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 66}], {
             RGBColor[
             0.9768371247203739, 0.9335283241593827, 0.36451703279096304`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 81}], {
             RGBColor[
             0.9840130750955306, 0.9564556068552594, 0.5011412166355375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 119}], {
             RGBColor[
             0.955401221470044, 0.9374517210681688, 0.6711471291603057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 128}], {
             RGBColor[
             0.9158941417629235, 0.6857588795378747, 0.2774298229878731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 130}], {
             RGBColor[
             0.9402351147360279, 0.925401291945388, 0.6711779819030929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 135}], {
             RGBColor[
             0.9802650440809539, 0.9555154641242977, 0.6075792260065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 146}], {
             RGBColor[
             0.9831902555740162, 0.954695679098555, 0.4115823895721674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 151}], {
             RGBColor[
             0.9836478486687346, 0.9556744244583988, 0.4613885739950244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 213}], {
             RGBColor[
             0.8858024728996614, 0.8821746248426516, 0.6659393251295533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 224}], {
             RGBColor[
             0.8984905648459856, 0.5519873610582565, 0.2607641380776845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 227}], {
             RGBColor[
             0.9288363421795505, 0.7446328494209195, 0.28823328098479606`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 243}], {
             RGBColor[
             0.9833245180253538, 0.956780635225201, 0.5568758250830326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 267}], {
             RGBColor[
             0.976593334317449, 0.9327059618856084, 0.36356995311155454`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 306}], {
             RGBColor[
             0.9810198777007912, 0.947637732119434, 0.38076623827326234`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 311}], {
             RGBColor[
             0.9584804983227556, 0.939748240703068, 0.6659347166526925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 346}], {
             RGBColor[
             0.9531546953781531, 0.8468095356608836, 0.30809848795217837`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 350}], {
             RGBColor[
             0.9642597109337412, 0.9440583680057488, 0.6561520171623464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 363}], {
             RGBColor[
             0.9759496668464199, 0.9527767179848787, 0.6363639710309841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 383}], {
             RGBColor[
             0.982218061088479, 0.956323086847157, 0.5752126799458128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 47}], {
             RGBColor[
             0.9735145208471025, 0.9794931513408298, 0.9174199399730495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 50}], {
             RGBColor[
             0.9738893013871944, 0.9796481327255783, 0.911208856522781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 136}], {
             RGBColor[
             0.8902942660992346, 0.9147079903168605, 0.9666117417593678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 149}], {
             RGBColor[
             0.9781182676704867, 0.9811988169969265, 0.8267240193176054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 164}], {
             RGBColor[
             0.9768441665650305, 0.9784736435637378, 0.6880459768292748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 197}], {
             RGBColor[
             0.9751149898594194, 0.9726414429069914, 0.6812673641964403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 210}], {
             RGBColor[
             0.9430216853307893, 0.8551853006503092, 0.6044937049918158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 217}], {
             RGBColor[
             0.9717048852284708, 0.9784181302491675, 0.9327804281470675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 230}], {
             RGBColor[
             0.9777481285189598, 0.9804071267786193, 0.786436656907966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 254}], {
             RGBColor[
             0.973468900121276, 0.9794742859983012, 0.9181759934626514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 258}], {
             RGBColor[
             0.9745581966986048, 0.9799247381266718, 0.9001235301671351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 314}], {
             RGBColor[
             0.9657002392561538, 0.9739398751147188, 0.9429447275157106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 328}], {
             RGBColor[
             0.9626177055800316, 0.9304851685307249, 0.6327177746851274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 41}], {
             RGBColor[
             0.9908459384802446, 0.9904825745600002, 0.8013700195415535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 48}], {
             RGBColor[
             0.8517828098812049, 0.8827043807996297, 0.8736464487330302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 63}], {
             RGBColor[
             0.9811158276028896, 0.9504962860169329, 0.5563553966592216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 103}], {
             RGBColor[
             0.9386608844347858, 0.7807110049480492, 0.5005638607202277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 265}], {
             RGBColor[
             0.9929819350365854, 0.9898749477989021, 0.6575971578299229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 295}], {
             RGBColor[
             0.9911715553108467, 0.990617225487425, 0.7959737059891341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 48}], {
             RGBColor[
             0.8502186536443104, 0.882057561998692, 0.8995685654849566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 63}], {
             RGBColor[
             0.9795516713659951, 0.9498494672159953, 0.5822775134111479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.9918240657509996, 0.990097135704902, 0.7277411019193928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 265}], {
             RGBColor[
             0.9914177787996907, 0.9892281289979644, 0.683519274581849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 295}], {
             RGBColor[
             0.989607399073952, 0.9899704066864874, 0.8218958227410602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 325}], {
             RGBColor[
             0.9897809664033883, 0.9900421812376862, 0.8190193629144502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 381}], {
             RGBColor[
             0.9919530849540473, 0.9909404080792842, 0.7830217372674154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 67}], {
             RGBColor[
             0.9874143891884939, 0.9677283498917832, 0.5314197440964771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 75}], {
             RGBColor[
             0.9927455302585333, 0.9857115405324759, 0.5521302204520642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 133}], {
             RGBColor[
             0.9898006737980167, 0.9897210911123699, 0.7947605142265219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 178}], {
             RGBColor[
             0.985559939667283, 0.9614728562112848, 0.5242155578899799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 200}], {
             RGBColor[
             0.9941837761229195, 0.9915336165643089, 0.7221211655976758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 278}], {
             RGBColor[
             0.9949162269165175, 0.9915346483597626, 0.6880408571527429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 296}], {
             RGBColor[
             0.9487698752033134, 0.8211453785992688, 0.4633928045188163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 320}], {
             RGBColor[
             0.981684137272602, 0.9483988646523467, 0.5091587974705116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 330}], {
             RGBColor[
             0.9221243167283023, 0.9371059895517676, 0.8359030683245681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 347}], {
             RGBColor[
             0.8694577200158787, 0.8957251033916167, 0.8307167370400339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 367}], {
             RGBColor[
             0.9860758444098437, 0.9632131240481363, 0.5262197503943926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 398}], {
             RGBColor[
             0.9939683088944314, 0.9895071475597339, 0.5848658303205974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 159}], {
             RGBColor[
             0.9896425606406152, 0.9899849468979136, 0.8213131045862341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 250}], {
             RGBColor[
             0.9934644025385144, 0.9907754571212719, 0.7005564762947453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 265}], {
             RGBColor[
             0.9930581155872056, 0.9899064504143343, 0.6563346489572015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 321}], {
             RGBColor[
             0.9800934411427977, 0.983283664688982, 0.8563052327599836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 325}], {
             RGBColor[
             0.9914213031909032, 0.9907205026540561, 0.7918347372898027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 375}], {
             RGBColor[
             0.9916829393201787, 0.9908286959172533, 0.7874987495351095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 381}], {
             RGBColor[
             0.9935934217415621, 0.9916187294956541, 0.7558371116427679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 66}], {
             RGBColor[
             0.9864394890638946, 0.9680907872699489, 0.5745246017047335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 81}], {
             RGBColor[
             0.9936154394390513, 0.9910180699658258, 0.7111487855493079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 119}], {
             RGBColor[
             0.9650035858135646, 0.9720141841787351, 0.8811546980740762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[
             0.9254965061064442, 0.7203213426484409, 0.4874373919016435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 130}], {
             RGBColor[
             0.9498374790795487, 0.9599637550559542, 0.8811855508168633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 135}], {
             RGBColor[
             0.9898674084244747, 0.9900779272348639, 0.8175867949202705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 146}], {
             RGBColor[
             0.992792619917537, 0.9892581422091213, 0.6215899584859379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 151}], {
             RGBColor[
             0.9932502130122552, 0.9902368875689651, 0.6713961429087949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 227}], {
             RGBColor[
             0.9384387065230712, 0.7791953125314857, 0.49824084989856643`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 243}], {
             RGBColor[
             0.9929268823688746, 0.9913430983357672, 0.7668833939968029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 267}], {
             RGBColor[
             0.9861956986609697, 0.9672684249961747, 0.573577522025325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 275}], {
             RGBColor[
             0.9933549442342859, 0.9904608970629379, 0.6827954901006552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 311}], {
             RGBColor[
             0.9680828626662763, 0.9743107038136343, 0.875942285566463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 317}], {
             RGBColor[
             0.9807802696705271, 0.9837804091673088, 0.8544488875223961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 326}], {
             RGBColor[
             0.9937862325279397, 0.9916984617108324, 0.7526417379341707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 344}], {
             RGBColor[
             0.8950205348016149, 0.916436867965059, 0.8759085903674588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 346}], {
             RGBColor[
             0.9627570597216739, 0.8813719987714499, 0.5181060568659488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 383}], {
             RGBColor[
             0.9918204254319997, 0.9908855499577232, 0.7852202488595832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 48}], {
             RGBColor[
             0.834248607812094, 0.8210225076464761, 0.6303129736158289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 74}], {
             RGBColor[
             0.9741596800168433, 0.9291513478789641, 0.5439839244700355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 103}], {
             RGBColor[
             0.9211266823656749, 0.7190291317948956, 0.2572303856030264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 116}], {
             RGBColor[
             0.9762830417409113, 0.929979715649458, 0.5051818877731278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 262}], {
             RGBColor[
             0.9417663085841816, 0.8064221484685634, 0.274125321724356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 290}], {
             RGBColor[
             0.9752737462271366, 0.9278209346009239, 0.3953262997486514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 304}], {
             RGBColor[
             0.7760048922352474, 0.7747915105124883, 0.6250072748644121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 338}], {
             RGBColor[
             0.9725087243668886, 0.928468635290083, 0.5713445321260474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 52}], {
             RGBColor[
             0.9880398270177133, 0.9858218325195984, 0.6659849795228345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 60}], {
             RGBColor[
             0.9716787490679157, 0.9736413575943297, 0.6946468710418765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 102}], {
             RGBColor[
             0.9834495317208779, 0.9824199880240212, 0.6747220063222046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 105}], {
             RGBColor[
             0.9918047330540689, 0.9873787179193033, 0.6035907432359284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 128}], {
             RGBColor[
             0.9250475061037664, 0.7166353267716902, 0.31298891498423304`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 139}], {
             RGBColor[
             0.9552092632903313, 0.8495416205887224, 0.33794572171186643`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 199}], {
             RGBColor[
             0.8945715347989371, 0.9127508520883081, 0.7014601134500484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 213}], {
             RGBColor[
             0.8949558372405043, 0.9130510720764671, 0.7014984171259133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 215}], {
             RGBColor[
             0.989810854205908, 0.9772917600906352, 0.414917521959027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 259}], {
             RGBColor[
             0.9916831962187471, 0.9873284593145436, 0.6056049231244566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 271}], {
             RGBColor[
             0.9899758626472177, 0.9866224330062447, 0.6338998588423467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 287}], {
             RGBColor[
             0.9915594591515422, 0.9872772908573568, 0.6076555665493072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 333}], {
             RGBColor[
             0.9913268832732367, 0.9824056821152878, 0.4208070086075322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 337}], {
             RGBColor[
             0.9928711101430971, 0.9867003745931284, 0.5045555376198876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 345}], {
             RGBColor[
             0.9525968334843264, 0.958835993895248, 0.7070430896069677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 350}], {
             RGBColor[
             0.973413075274584, 0.9749348152395643, 0.6917111091587063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 353}], {
             RGBColor[
             0.9803312696678493, 0.9800943932905579, 0.6800004106049857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 400}], {
             RGBColor[
             0.9813815659961894, 0.9808777025725315, 0.6782225328822602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 136}], {
             RGBColor[
             0.9026246178450673, 0.9236293442700977, 0.9334424254242253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 149}], {
             RGBColor[
             0.9904486194163195, 0.9901201709501637, 0.7935547029824628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 155}], {
             RGBColor[
             0.9218326697026472, 0.9389406384433552, 0.9352757498097412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 268}], {
             RGBColor[
             0.5823859362964677, 0.6469042526470334, 0.9088758118189535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 279}], {
             RGBColor[
             0.9891745183108633, 0.9873949975169749, 0.6548766604941323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 299}], {
             RGBColor[
             0.9819857000799102, 0.9631461440104583, 0.6268883715021343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 300}], {
             RGBColor[
             0.9765429432025633, 0.9447864470430797, 0.6057442888120342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 371}], {
             RGBColor[
             0.9718916141968583, 0.9782827902183433, 0.9201670976100682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.8404885427669553, 0.8420712734556247, 0.6545539426026246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 86}], {
             RGBColor[
             0.8525728793077612, 0.8819167052313552, 0.7795485953283321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 103}], {
             RGBColor[
             0.7980335995988515, 0.672285992386741, 0.5987624066636308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 295}], {
             RGBColor[
             0.8505442704749122, 0.8821922129261168, 0.894172251932537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 191}], {
             RGBColor[
             0.9891728347046423, 0.9734507791957947, 0.5560415590867451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 225}], {
             RGBColor[
             0.9781128280038469, 0.9378315708839127, 0.36947289915090537`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 235}], {
             RGBColor[
             0.9877043689405771, 0.9701860906644132, 0.4067342244795803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 261}], {
             RGBColor[
             0.9623068533239983, 0.8802395529805704, 0.33033266313829585`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 327}], {
             RGBColor[
             0.9682698078791212, 0.9597334915760339, 0.676290549293761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 335}], {
             RGBColor[
             0.9891361766483809, 0.9733723713201496, 0.5520515558899913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 349}], {
             RGBColor[
             0.9883031596571501, 0.9731279345603123, 0.5731284496879546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 355}], {
             RGBColor[
             0.9884760248736987, 0.9719603734256871, 0.4801981092003288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 127}], {
             RGBColor[
             0.9536492082139727, 0.8560246070287183, 0.5634416119131986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 137}], {
             RGBColor[
             0.9896047909034127, 0.9899693281409423, 0.821939046876625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 138}], {
             RGBColor[
             0.9257386460716606, 0.9419112995303285, 0.929401474969971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 147}], {
             RGBColor[
             0.9568793497757454, 0.86883104194028, 0.5660406596349683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 164}], {
             RGBColor[
             0.9895492988509551, 0.9875499789017235, 0.6486655770438639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 197}], {
             RGBColor[
             0.987820122145344, 0.9817177782449771, 0.6418869644110292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 210}], {
             RGBColor[
             0.955726817616714, 0.8642616359882949, 0.5651133052064047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 217}], {
             RGBColor[
             0.9844100175143954, 0.9874944655871531, 0.8934000283616563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 230}], {
             RGBColor[
             0.9904532608048844, 0.989483462116605, 0.747056257122555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 242}], {
             RGBColor[
             0.9895631726726386, 0.9875796536034459, 0.6501756569148137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 254}], {
             RGBColor[
             0.9861740324072006, 0.9885506213362869, 0.8787955936772404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 258}], {
             RGBColor[
             0.9872633289845294, 0.9890010734646575, 0.860743130381724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 328}], {
             RGBColor[
             0.9753228378659562, 0.9395615038687106, 0.5933373748997163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 331}], {
             RGBColor[
             0.9905261192163568, 0.989639298891629, 0.7549864455813293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 79}], {
             RGBColor[
             0.9916249408343667, 0.9908047120528769, 0.7884599345402843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 87}], {
             RGBColor[
             0.9931422106738568, 0.9910179405731531, 0.7332067665505531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 126}], {
             RGBColor[
             0.9524592594671222, 0.9622794463405129, 0.8912126160387253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 176}], {
             RGBColor[
             0.9259284185130359, 0.7248099487248696, 0.4980124601825546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 205}], {
             RGBColor[
             0.9143388686887668, 0.9318832814842946, 0.8875766591358112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 232}], {
             RGBColor[
             0.9868105324736764, 0.9710784922879847, 0.5879658141024475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 277}], {
             RGBColor[
             0.9894572515030583, 0.9800064970532703, 0.598247817740646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 298}], {
             RGBColor[
             0.9766580888293253, 0.9368319159684593, 0.5485254876722527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 373}], {
             RGBColor[
             0.9920402679665141, 0.988660996545645, 0.6132671032584014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 390}], {
             RGBColor[
             0.9760099953442632, 0.9346457444637586, 0.5460077668649723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 60}], {
             RGBColor[
             0.9679608768929235, 0.9756042647418834, 0.9381512034628019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 68}], {
             RGBColor[
             0.9593861624295978, 0.8828046652207262, 0.5878023724463446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 105}], {
             RGBColor[
             0.9880868608790766, 0.9893416250668572, 0.8470950756568538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 129}], {
             RGBColor[
             0.9894765009563099, 0.9893547085855514, 0.7832450513590301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 199}], {
             RGBColor[
             0.8908536626239449, 0.9147137592358618, 0.9449644458709738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 271}], {
             RGBColor[
             0.9862579904722254, 0.9885853401537985, 0.8774041912632722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 287}], {
             RGBColor[
             0.98784158697655, 0.9892401980049106, 0.8511598989702327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 303}], {
             RGBColor[
             0.9888261655648942, 0.9879637069423076, 0.7124600574082477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 333}], {
             RGBColor[
             0.9876090110982444, 0.9843685892628415, 0.6643113410284576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 337}], {
             RGBColor[
             0.9891532379681047, 0.9886632817406823, 0.748059870040813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 345}], {
             RGBColor[
             0.948878961309334, 0.9607989010428017, 0.9505474220278931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 353}], {
             RGBColor[
             0.976613397492857, 0.9820573004381117, 0.9235047430259111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 391}], {
             RGBColor[
             0.9701834164658416, 0.9255879668435558, 0.5966161964289993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 69}], {
             RGBColor[
             0.9885939017463903, 0.9880191956916231, 0.73025419977126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 93}], {
             RGBColor[
             0.6604580320436622, 0.7233405595921502, 0.744935608607207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 131}], {
             RGBColor[
             0.9910179882219167, 0.9891266033867527, 0.6947822850535672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 142}], {
             RGBColor[
             0.9595394885630775, 0.8654623772250721, 0.4033351224514051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 188}], {
             RGBColor[
             0.9937712859385222, 0.9890857353791203, 0.5634210974546046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 201}], {
             RGBColor[
             0.9841070783114674, 0.9846729301203567, 0.7378492214956138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 264}], {
             RGBColor[
             0.9914707344660187, 0.9893138255937366, 0.6872791081190748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 273}], {
             RGBColor[
             0.9917881909262736, 0.9894451019983109, 0.6820180330216686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 281}], {
             RGBColor[
             0.9793984099457418, 0.9414739944734452, 0.4334923220156488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[
             0.914649828699956, 0.9302924043526603, 0.7659920223310461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 394}], {
             RGBColor[
             0.9710944785626688, 0.9749681545338793, 0.7598761586407661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 64}], {
             RGBColor[
             0.9808430680663278, 0.982609293685403, 0.7727843919189703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 83}], {
             RGBColor[
             0.9634793749262922, 0.9722835581338396, 0.9467040715319814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 123}], {
             RGBColor[
             0.9811150909537393, 0.9831911231358432, 0.8023924044830377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 161}], {
             RGBColor[
             0.9627849625155613, 0.9227176247450011, 0.6156808276088508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 196}], {
             RGBColor[
             0.9782304268057843, 0.9824969539349564, 0.8864499655760981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 198}], {
             RGBColor[
             0.980056861150169, 0.9809276765894518, 0.6872106210017396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 206}], {
             RGBColor[
             0.9812539886624899, 0.9834882112901482, 0.8175105629032475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 214}], {
             RGBColor[
             0.980208087097032, 0.9812511335985031, 0.7036706320594172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 310}], {
             RGBColor[
             0.9787611258524485, 0.9827164116290954, 0.8776549089677661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 332}], {
             RGBColor[
             0.9772136837705452, 0.9713890895629208, 0.671733685049086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 389}], {
             RGBColor[
             0.8393409002524134, 0.874790549081839, 0.9558493596031505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 57}], {
             RGBColor[
             0.9814858021023571, 0.9830695842788538, 0.7701841291179398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 68}], {
             RGBColor[
             0.9516447380539959, 0.8770527138177051, 0.6018734388299769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 72}], {
             RGBColor[
             0.9809744285682442, 0.9819758079971814, 0.7145242757613696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 83}], {
             RGBColor[
             0.9641357902422727, 0.9727731116017164, 0.94559293162256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 123}], {
             RGBColor[
             0.9817715062697198, 0.98368067660372, 0.8012812645736163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 161}], {
             RGBColor[
             0.9634413778315418, 0.9232071782128779, 0.6145696876994291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 196}], {
             RGBColor[
             0.9788868421217648, 0.9829865074028332, 0.8853388256666765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 236}], {
             RGBColor[
             0.9643032424222504, 0.9728979971633661, 0.9453094787603807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 262}], {
             RGBColor[
             0.9475150163404815, 0.8606797433718031, 0.5985505678022559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 284}], {
             RGBColor[
             0.9765105651401755, 0.9820021984587382, 0.9246456655786102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 334}], {
             RGBColor[
             0.9447769878014328, 0.8498243726083978, 0.5963474857699472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 366}], {
             RGBColor[
             0.9770771685953972, 0.9692039022952883, 0.6675421599139892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 397}], {
             RGBColor[
             0.9778306083939621, 0.9825497276124182, 0.9028433519816326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 65}], {
             RGBColor[
             0.9611622503363524, 0.870670005258682, 0.477193806739214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 100}], {
             RGBColor[
             0.9605975497630885, 0.8694621678324568, 0.41572963426742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 174}], {
             RGBColor[
             0.9611209228134063, 0.8705816098659541, 0.47269556091045184`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 198}], {
             RGBColor[
             0.959970566690975, 0.8681211144389187, 0.3474863961588692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 203}], {
             RGBColor[
             0.9600925857575136, 0.8683821008842243, 0.3607674185371873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 206}], {
             RGBColor[
             0.9611676942032961, 0.8706816491396152, 0.4777863380603772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 266}], {
             RGBColor[
             0.960625424906441, 0.8707164700242317, 0.5056043016371998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 341}], {
             RGBColor[
             0.9609985005929476, 0.8703197611151778, 0.45937065771587476`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 358}], {
             RGBColor[
             0.9594682875838478, 0.8702379640042666, 0.5247810616479677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 68}], {
             RGBColor[
             0.9642914340648359, 0.8838414612354488, 0.4344261232368921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 72}], {
             RGBColor[
             0.9936211245790842, 0.9887645554149251, 0.5470769601682848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 86}], {
             RGBColor[
             0.9940613658417246, 0.9897061869604933, 0.5949945047525429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 108}], {
             RGBColor[
             0.9279875086323811, 0.9412660893244107, 0.7947106582245362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 236}], {
             RGBColor[
             0.9769499384330905, 0.9796867445811098, 0.777862163167296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 262}], {
             RGBColor[
             0.9601617123513216, 0.8674684907895468, 0.4311032522091711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 284}], {
             RGBColor[
             0.9891572611510155, 0.9887909458764819, 0.7571983499855254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 297}], {
             RGBColor[
             0.9851302074090311, 0.9857875757894052, 0.7640151015468752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 325}], {
             RGBColor[
             0.9922063243383119, 0.9900534692064537, 0.7067417015301378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 376}], {
             RGBColor[
             0.9387583976654215, 0.9498545038713629, 0.7957379952357937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 397}], {
             RGBColor[
             0.9904773044048021, 0.9893384750301619, 0.7353960363885478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 124}], {
             RGBColor[
             0.9641254183234395, 0.8911243623183829, 0.5403822411426188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 152}], {
             RGBColor[
             0.9155583408480716, 0.9330982414182778, 0.8982268923571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 156}], {
             RGBColor[
             0.9881793645343125, 0.9893798777055327, 0.8455620506978083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 160}], {
             RGBColor[
             0.9656897091511989, 0.8973262541814319, 0.541640906261259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 179}], {
             RGBColor[
             0.8434636742448408, 0.8766082990270812, 0.8910860280106463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 181}], {
             RGBColor[
             0.9712748647458448, 0.9194695349714308, 0.5461348535531625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 220}], {
             RGBColor[
             0.9760207428703915, 0.9806356559757139, 0.8806375100882531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[
             0.9914818449557881, 0.9907455382296884, 0.7908314035685942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 352}], {
             RGBColor[
             0.9914127012597934, 0.9884091060947395, 0.6242217290717105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 396}], {
             RGBColor[
             0.9926233482570055, 0.9909985576065885, 0.7559931834710265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 132}], {
             RGBColor[
             0.9943868660796293, 0.9905833272573508, 0.643574767138746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 149}], {
             RGBColor[
             0.9950623198922295, 0.9920280546636464, 0.7170937462225431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 155}], {
             RGBColor[
             0.9264463701785572, 0.9408485221568379, 0.8588147930498213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 164}], {
             RGBColor[
             0.9937882187867734, 0.9893028812304576, 0.5784157037342125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 210}], {
             RGBColor[
             0.9599657375525322, 0.866014538317029, 0.4948634318967534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 230}], {
             RGBColor[
             0.9946921807407026, 0.9912363644453392, 0.6768063838129037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 258}], {
             RGBColor[
             0.9915022489203478, 0.9907539757933918, 0.7904932570720726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 264}], {
             RGBColor[
             0.9921930071732564, 0.991039622082647, 0.7790456051963209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 268}], {
             RGBColor[
             0.5869996367723778, 0.6488121363605162, 0.8324148550590337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 279}], {
             RGBColor[
             0.9937882187867734, 0.9893028812304576, 0.5784157037342125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 299}], {
             RGBColor[
             0.9865994005558202, 0.965054027723941, 0.5504274147422146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 300}], {
             RGBColor[
             0.9811566436784733, 0.9466943307565624, 0.5292833320521145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 328}], {
             RGBColor[
             0.9795617578017745, 0.9413144061974448, 0.5230875015900649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 394}], {
             RGBColor[
             0.9718167512699065, 0.9766939510227897, 0.8516426557180123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 68}], {
             RGBColor[
             0.9430250844798003, 0.8706241902954575, 0.6164642639653866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 72}], {
             RGBColor[
             0.9723547749940487, 0.9755472844749337, 0.7291151008967793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 102}], {
             RGBColor[
             0.963370581596088, 0.9722024202463062, 0.9468882302621721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 105}], {
             RGBColor[
             0.9717257829292791, 0.9771611501415883, 0.8757569671758958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 108}], {
             RGBColor[
             0.9067211590473454, 0.9280488183844193, 0.9767487989530307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 139}], {
             RGBColor[
             0.9351303131655415, 0.8393240528110074, 0.6101119456518338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 297}], {
             RGBColor[
             0.9638638578239955, 0.9725703048494138, 0.9460532422753698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 333}], {
             RGBColor[
             0.9712479331484469, 0.9721881143375728, 0.6929732325474997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 337}], {
             RGBColor[
             0.9727921600183073, 0.9764828068154134, 0.776721761559855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 345}], {
             RGBColor[
             0.9325178833595366, 0.948618426117533, 0.9792093135469351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 353}], {
             RGBColor[
             0.9602523195430595, 0.9698768255128429, 0.9521666345449531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 70}], {
             RGBColor[
             0.8710907795536014, 0.43696955773381163`, 0.21130942761824095`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 90}], {
             RGBColor[
             0.9592637497750913, 0.8643351942924791, 0.4051234508948291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 95}], {
             RGBColor[
             0.9477113405552487, 0.8260833177759863, 0.2992664588920466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 148}], {
             RGBColor[
             0.9454392869671104, 0.8184191475196436, 0.29043995974344694`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 228}], {
             RGBColor[
             0.9494107340470556, 0.8599556464726041, 0.5936829045520317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 282}], {
             RGBColor[
             0.9598620143028572, 0.865614821623548, 0.47024085268146143`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 285}], {
             RGBColor[
             0.9352738808715584, 0.849412404521291, 0.61761290949633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 301}], {
             RGBColor[
             0.9588792107827798, 0.8635127042707808, 0.36326875468129693`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 382}], {
             RGBColor[
             0.9582394137093277, 0.8653066206047009, 0.5235022579626087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 91}], {
             RGBColor[
             0.9569471173425997, 0.8614980311600571, 0.3129581511050892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 111}], {
             RGBColor[
             0.9800875509167997, 0.9444927749562917, 0.3771443247725953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 117}], {
             RGBColor[
             0.9848297081750093, 0.9589269062139634, 0.5284116128714049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 223}], {
             RGBColor[
             0.9814730550961439, 0.9577524734751469, 0.5995686557761986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 247}], {
             RGBColor[
             0.9829391479291083, 0.9583587405384448, 0.5752717034073507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 256}], {
             RGBColor[
             0.984545949256048, 0.9583199745787326, 0.4975262056995211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 319}], {
             RGBColor[
             0.967545257114266, 0.9021846728897152, 0.3284198817631955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 323}], {
             RGBColor[
             0.9847274238851691, 0.9587081304605233, 0.5172785991477692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 362}], {
             RGBColor[
             0.9846176638801263, 0.9584733649081753, 0.5053318999590788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 395}], {
             RGBColor[
             0.9849148902537449, 0.9591091020671494, 0.5376831564589148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 103}], {
             RGBColor[
             0.9273666173205362, 0.7400778976040443, 0.2814713545898221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 295}], {
             RGBColor[
             0.9798772881965969, 0.9499841181434201, 0.5768811998587284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 88}], {
             RGBColor[
             0.9503327958654346, 0.8284751333736977, 0.4246727899029235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 101}], {
             RGBColor[
             0.9750881107096621, 0.9266059278860821, 0.44467367786541223`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 115}], {
             RGBColor[
             0.9684649862328649, 0.9733777405212551, 0.7937372557422362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 120}], {
             RGBColor[
             0.9935394003489397, 0.988589755550233, 0.5381817820605338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 123}], {
             RGBColor[
             0.994431883560511, 0.9904986868958896, 0.6353230718721404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 140}], {
             RGBColor[
             0.99330940111153, 0.9905332251135326, 0.6901767218331525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 161}], {
             RGBColor[
             0.9761017551223331, 0.9300251885050476, 0.4486114949979534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 193}], {
             RGBColor[
             0.9944896911508591, 0.9906223314864002, 0.6416150713344321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 195}], {
             RGBColor[
             0.9801840834033086, 0.9437958403730413, 0.46447056948653487`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 214}], {
             RGBColor[
             0.9935248797038038, 0.9885586973585496, 0.5366012994485199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 233}], {
             RGBColor[
             0.9145961605051055, 0.6300986378421507, 0.3934477444656915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 257}], {
             RGBColor[
             0.96692706336754, 0.9722307601664133, 0.7963405579987077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 283}], {
             RGBColor[
             0.9942209767423527, 0.9900475785377995, 0.6123671662816206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 312}], {
             RGBColor[
             0.8455997967789806, 0.8765844307820327, 0.7880765618707672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 332}], {
             RGBColor[
             0.9905304763773168, 0.9786966533229673, 0.5046643524381887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 356}], {
             RGBColor[
             0.9865007644652413, 0.9651034888221843, 0.4890096826070164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 360}], {
             RGBColor[
             0.9561782024571824, 0.8516502226437019, 0.42937614125597123`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 380}], {
             RGBColor[
             0.9942886516215581, 0.9901923282614398, 0.6197331592421753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 389}], {
             RGBColor[
             0.8526576928591851, 0.8820981128418854, 0.7887800269922531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 100}], {
             RGBColor[
             0.9944061135582725, 0.9904435674668486, 0.632518166162507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 167}], {
             RGBColor[
             0.9942708459043184, 0.9901542436326984, 0.6177951168047948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 174}], {
             RGBColor[
             0.9949294866085904, 0.9915630095003458, 0.6894840928055388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 198}], {
             RGBColor[
             0.9937791304861591, 0.9891025140733105, 0.5642749280539563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 203}], {
             RGBColor[
             0.9939011495526975, 0.9893635005186161, 0.5775559504322744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 206}], {
             RGBColor[
             0.99497625799848, 0.9916630487740069, 0.6945748699554641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 211}], {
             RGBColor[
             0.987087162248954, 0.9665810517450897, 0.5338461664027666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 266}], {
             RGBColor[
             0.994433988701625, 0.9916978696586234, 0.7223928335322868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 313}], {
             RGBColor[
             0.9944473637472979, 0.9905317974501398, 0.6370079946712544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 329}], {
             RGBColor[
             0.9532586550207113, 0.9619789268669379, 0.8427038256164956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 340}], {
             RGBColor[
             0.9950350440401852, 0.9917887861730336, 0.7009733678096691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 341}], {
             RGBColor[
             0.9948070643881315, 0.9913011607495696, 0.6761591896109618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 358}], {
             RGBColor[
             0.9932768513790318, 0.9912193636386584, 0.7415695935430546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 81}], {
             RGBColor[
             0.9873992293048847, 0.9678779001102283, 0.5142957863173113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 119}], {
             RGBColor[
             0.9587873756793981, 0.9488740143231377, 0.6843016988420796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 130}], {
             RGBColor[
             0.943621268945382, 0.9368235852003568, 0.6843325515848668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 146}], {
             RGBColor[
             0.9865764097833702, 0.966117972353524, 0.42473695925394134`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 151}], {
             RGBColor[
             0.9870340028780886, 0.9670967177133678, 0.4745431436767983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 158}], {
             RGBColor[
             0.9736811310697108, 0.9228824165131475, 0.35225659341752913`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 243}], {
             RGBColor[
             0.9867106722347079, 0.9682029284801699, 0.5700303947648064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 267}], {
             RGBColor[
             0.979979488526803, 0.9441282551405773, 0.37672452279332846`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 275}], {
             RGBColor[
             0.9871387341001193, 0.9673207272073405, 0.4859424908686587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 311}], {
             RGBColor[
             0.9618666525321097, 0.951170533958037, 0.6790892863344664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 317}], {
             RGBColor[
             0.9745640595363605, 0.9606402393117114, 0.6575958882903996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 344}], {
             RGBColor[
             0.8888043246674484, 0.8932966981094616, 0.6790555911354623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 346}], {
             RGBColor[
             0.9565408495875072, 0.8582318289158526, 0.3212530576339523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 354}], {
             RGBColor[
             0.9822103322350573, 0.9663419222368519, 0.644612675065598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 75}], {
             RGBColor[
             0.9852595640004349, 0.9619391895338149, 0.3972366189498008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 126}], {
             RGBColor[
             0.9466821953531713, 0.9388845306557867, 0.6840658373531199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 133}], {
             RGBColor[
             0.9823147075399183, 0.9659487401137088, 0.6398669127242584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 200}], {
             RGBColor[
             0.9866978098648211, 0.967761265565648, 0.5672275640954123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 320}], {
             RGBColor[
             0.9741981710145036, 0.9246265136536858, 0.35426519596824824`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 347}], {
             RGBColor[
             0.8619717537577803, 0.8719527523929558, 0.6758231355377704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 398}], {
             RGBColor[
             0.986482342636333, 0.9657347965610729, 0.42997222881833386`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 72}], {
             RGBColor[
             0.963780060530723, 0.8827476849537764, 0.3787662698803219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 236}], {
             RGBColor[
             0.9471088743847291, 0.8736698741199611, 0.6095514728793331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 262}], {
             RGBColor[
             0.9303206483029602, 0.7614516203283981, 0.26279256192120826`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 284}], {
             RGBColor[
             0.9593161971026543, 0.8827740754153333, 0.5888876596975625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 333}], {
             RGBColor[
             0.9626732186851212, 0.8793885148164156, 0.34262440153104223`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 334}], {
             RGBColor[
             0.9275826197639115, 0.7505962495649929, 0.2605894798888996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 337}], {
             RGBColor[
             0.9642174455549816, 0.8836832072942562, 0.42637293054339764`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 376}], {
             RGBColor[
             0.9089173336170602, 0.8438376334102142, 0.6274273049478309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 391}], {
             RGBColor[
             0.9452476240527184, 0.8206078923971297, 0.274929256931584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 397}], {
             RGBColor[
             0.9606362403564408, 0.8833216045690132, 0.5670853461005849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 93}], {
             RGBColor[
             0.6554242056597723, 0.7225810755405615, 0.927394092414892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 131}], {
             RGBColor[
             0.9859841618380267, 0.988367119335164, 0.8772407688612525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 142}], {
             RGBColor[
             0.9545056621791876, 0.8647028931734835, 0.5857936062590903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 188}], {
             RGBColor[
             0.9887374595546321, 0.9883262513275316, 0.7458795812622898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 201}], {
             RGBColor[
             0.9790732519275773, 0.983913446068768, 0.9203077053032989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 273}], {
             RGBColor[
             0.9867543645423836, 0.9886856179467223, 0.8644765168293538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 281}], {
             RGBColor[
             0.974364583561852, 0.9407145104218564, 0.615950805823334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 293}], {
             RGBColor[
             0.9096160023160662, 0.9295329203010716, 0.9484505061387312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 394}], {
             RGBColor[
             0.9660606521787789, 0.9742086704822907, 0.9423346424484513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 90}], {
             RGBColor[
             0.9054919702214901, 0.5614926365586674, 0.3580320232765881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 95}], {
             RGBColor[
             0.8939395610016474, 0.5232407600421747, 0.25217503127380564`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 177}], {
             RGBColor[
             0.8390085163567897, 0.5129441322664156, 0.5753966703930337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 228}], {
             RGBColor[
             0.8956389544934542, 0.5571130887387925, 0.5465914769337907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 246}], {
             RGBColor[
             0.9042331973458442, 0.5579636124919007, 0.2921638646808953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 260}], {
             RGBColor[
             0.8328626029143464, 0.253601943249895, 0.17910257170476676`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 285}], {
             RGBColor[
             0.8815021013179571, 0.5465698467874793, 0.570521481878089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 110}], {
             RGBColor[
             0.9811753285486382, 0.9823597256704335, 0.7327579905950116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 131}], {
             RGBColor[
             0.9909270326339182, 0.9889320585810446, 0.6848823306127603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 201}], {
             RGBColor[
             0.984016122723469, 0.9844783853146486, 0.7279492670548067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 212}], {
             RGBColor[
             0.9073394000410797, 0.9243412476876101, 0.7554034681038391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 271}], {
             RGBColor[
             0.9908199215280066, 0.9888877653861203, 0.6866574388323725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 273}], {
             RGBColor[
             0.9916972353382751, 0.9892505571926029, 0.6721180785808616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 287}], {
             RGBColor[
             0.9924035180323312, 0.9895426232372323, 0.660413146539333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 289}], {
             RGBColor[
             0.9900842412085671, 0.9885835426679102, 0.6988495656051221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 292}], {
             RGBColor[
             0.9935282234636286, 0.988565849322709, 0.536965247070158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 303}], {
             RGBColor[
             0.9933880966206754, 0.9882661321746293, 0.5217133049773481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 385}], {
             RGBColor[
             0.9924666518381247, 0.9856685126955649, 0.47471336488019467`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 400}], {
             RGBColor[
             0.9822256248769783, 0.9831430349524071, 0.7309801128722861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 86}], {
             RGBColor[
             0.9935499923076115, 0.9886124106788208, 0.5393346513959727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 108}], {
             RGBColor[
             0.9274761350982681, 0.9401723130427382, 0.739050804867966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 236}], {
             RGBColor[
             0.9764385648989775, 0.9785929682994374, 0.7222023098107258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 262}], {
             RGBColor[
             0.9596503388172086, 0.8663747145078744, 0.3754433988526009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 284}], {
             RGBColor[
             0.9886458876169026, 0.9876971695948095, 0.7015384966289552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 297}], {
             RGBColor[
             0.9846188338749181, 0.9846937995077327, 0.708355248190305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 325}], {
             RGBColor[
             0.991694950804199, 0.9889596929247813, 0.6510818481735676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 333}], {
             RGBColor[
             0.9920029091993695, 0.9843116089958917, 0.4552752384624349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 337}], {
             RGBColor[
             0.9935471360692298, 0.9886063014737325, 0.5390237674747903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 376}], {
             RGBColor[
             0.9382470241313086, 0.9487607275896905, 0.7400781418792235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 397}], {
             RGBColor[
             0.9899659308706892, 0.9882446987484894, 0.6797361830319776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.9920695874220606, 0.9886696846958787, 0.612531428675393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 162}], {
             RGBColor[
             0.9875223517254113, 0.9695159405620097, 0.41080284326279914`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 183}], {
             RGBColor[
             0.9901023679538488, 0.9878561888905388, 0.6451333462644506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 189}], {
             RGBColor[
             0.976032384100756, 0.9779307939416283, 0.6943852833233704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 207}], {
             RGBColor[
             0.9928492665650361, 0.9871136291696925, 0.46306497869465735`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 280}], {
             RGBColor[
             0.9874470598184919, 0.9692619632805906, 0.4105103484221014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 291}], {
             RGBColor[
             0.9915923533545528, 0.9832450117389315, 0.42661403103669804`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 336}], {
             RGBColor[
             0.9561483342441738, 0.9626888007291077, 0.7137421111160194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 368}], {
             RGBColor[
             0.9924281054321658, 0.98606419974064, 0.4298607700396879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 387}], {
             RGBColor[
             0.9939214392194422, 0.9894068980641829, 0.5797643554441203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 116}], {
             RGBColor[
             0.9931010311788373, 0.9913654164737915, 0.7603848596879387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 118}], {
             RGBColor[
             0.9908215809318941, 0.9904725020877968, 0.8017736871530363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 141}], {
             RGBColor[
             0.9745201190930617, 0.9303671935181684, 0.5453841622179356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 179}], {
             RGBColor[
             0.8438432191496097, 0.8767652505990622, 0.8847959867078972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 209}], {
             RGBColor[
             0.9730243819255817, 0.9250579700974617, 0.5409471241002348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 286}], {
             RGBColor[
             0.9928793040898747, 0.9908911646505478, 0.7362512343953298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 290}], {
             RGBColor[
             0.9920917356650626, 0.9892066354252573, 0.6505292716634623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 304}], {
             RGBColor[
             0.7928228816731733, 0.8361772113368218, 0.880210246779223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 338}], {
             RGBColor[
             0.9893267138048145, 0.9898543361144165, 0.8265475040408583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 386}], {
             RGBColor[
             0.992203991506831, 0.9894467393199934, 0.6627476272772055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 126}], {
             RGBColor[
             0.9520133364232106, 0.9568677212964793, 0.7047763137087071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 133}], {
             RGBColor[
             0.9876458486099576, 0.9839319307544014, 0.6605773890798456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 178}], {
             RGBColor[
             0.983405114479224, 0.9556836958533164, 0.3900324327433035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 200}], {
             RGBColor[
             0.9920289509348605, 0.9857444562063407, 0.5879380404509994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 296}], {
             RGBColor[
             0.9466150500152543, 0.8153562182413006, 0.32920967937213996`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 320}], {
             RGBColor[
             0.979529312084543, 0.9426097042943784, 0.37497567232383533`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 330}], {
             RGBColor[
             0.9199694915402432, 0.9313168291937992, 0.7017199431778917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 347}], {
             RGBColor[
             0.8673028948278196, 0.8899359430336484, 0.6965336118933576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 398}], {
             RGBColor[
             0.9918134837063723, 0.9837179872017655, 0.45068270517392095`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 78}], {
             RGBColor[
             0.9940063394796852, 0.9917894815918699, 0.7489939961252174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 80}], {
             RGBColor[
             0.9924075148381379, 0.991128326514671, 0.7754906580611916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.9473505003201285, 0.8176680879733407, 0.4972688852634018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 117}], {
             RGBColor[
             0.9943280674420754, 0.991708894801006, 0.7281335165348471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.9940418428992318, 0.9910966894456038, 0.696979741419441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 187}], {
             RGBColor[
             0.9420518863085886, 0.9535703233771513, 0.8723917536079979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 208}], {
             RGBColor[
             0.9936849833531894, 0.9916565925750881, 0.7543196987842483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 239}], {
             RGBColor[
             0.9568722949233419, 0.8563255444345128, 0.5049772480722602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 269}], {
             RGBColor[
             0.7432439411443365, 0.7954001961475141, 0.854293358511901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 323}], {
             RGBColor[
             0.9942257831522352, 0.9914901190475659, 0.7170005028112114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 365}], {
             RGBColor[
             0.95335701327467, 0.8423886240956968, 0.5021487699434735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 377}], {
             RGBColor[
             0.9932121862477407, 0.989322137759219, 0.6066767349519738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 388}], {
             RGBColor[
             0.9903149862827693, 0.9797341084201445, 0.579698551405809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 395}], {
             RGBColor[
             0.994413249520811, 0.991891090654192, 0.7374050601223572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 78}], {
             RGBColor[
             0.9936290633703633, 0.9916334682251116, 0.7552464376159531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 80}], {
             RGBColor[
             0.9920302387288161, 0.9909723131479127, 0.7817430995519272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 96}], {
             RGBColor[
             0.9469732242108067, 0.8175120746065823, 0.5035213267541374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 182}], {
             RGBColor[
             0.99366456678991, 0.9909406760788455, 0.7032321829101766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 187}], {
             RGBColor[
             0.9416746101992668, 0.9534143100103929, 0.8786441950987336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 244}], {
             RGBColor[
             0.9768966932765175, 0.9355876828836603, 0.5352891048413698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 302}], {
             RGBColor[
             0.9821596246013827, 0.9533407860374706, 0.5557345992172847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 377}], {
             RGBColor[
             0.9928349101384188, 0.9891661243924607, 0.6129291764427095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 388}], {
             RGBColor[
             0.9899377101734474, 0.9795780950533861, 0.5859509928965446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 80}], {
             RGBColor[
             0.992792086546922, 0.9912873567992952, 0.7691173096069628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 96}], {
             RGBColor[
             0.9477350720289124, 0.817827118257965, 0.4908955368091731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 104}], {
             RGBColor[
             0.9773085123199365, 0.9347219972873598, 0.521303519204135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 182}], {
             RGBColor[
             0.9944264146080157, 0.9912557197302281, 0.6906063929652122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 187}], {
             RGBColor[
             0.9424364580173725, 0.9537293536617755, 0.8660184051537692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 208}], {
             RGBColor[
             0.9940695550619734, 0.9918156228597124, 0.7479463503300197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 302}], {
             RGBColor[
             0.9829214724194886, 0.9536558296888533, 0.5431088092723204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 377}], {
             RGBColor[
             0.9935967579565246, 0.9894811680438433, 0.6003033864977452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 388}], {
             RGBColor[
             0.9906995579915532, 0.9798931387047687, 0.5733252029515802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 87}], {
             RGBColor[
             0.9932846003499262, 0.9910768223634556, 0.7308470011254131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 126}], {
             RGBColor[
             0.9526016491431917, 0.9623383281308153, 0.8888528506135853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 176}], {
             RGBColor[
             0.9260708081891054, 0.724868830515172, 0.49565269475741464`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 205}], {
             RGBColor[
             0.9144812583648363, 0.9319421632745971, 0.8852168937106712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 232}], {
             RGBColor[
             0.986952922149746, 0.9711373740782872, 0.5856060486773076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[
             0.9895996411791277, 0.9800653788435727, 0.595888052315506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 298}], {
             RGBColor[
             0.9768004785053946, 0.9368907977587617, 0.5461657222471128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 373}], {
             RGBColor[
             0.9921826576425835, 0.9887198783359475, 0.6109073378332615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 390}], {
             RGBColor[
             0.9761523850203326, 0.934704626254061, 0.5436480014398324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 96}], {
             RGBColor[
             0.9461362473873651, 0.8171659631807661, 0.5173921987451472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 104}], {
             RGBColor[
             0.9757096876783894, 0.934060842210161, 0.5478001811401091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 182}], {
             RGBColor[
             0.9928275899664685, 0.9905945646530292, 0.7171030549011863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 187}], {
             RGBColor[
             0.9408376333758253, 0.9530681985845766, 0.8925150670897433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 244}], {
             RGBColor[
             0.9760597164530762, 0.9352415714578441, 0.5491599768323795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 302}], {
             RGBColor[
             0.9813226477779413, 0.9529946746116544, 0.5696054712082945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 377}], {
             RGBColor[
             0.9919979333149773, 0.9888200129666445, 0.6268000484337193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 388}], {
             RGBColor[
             0.9891007333500059, 0.9792319836275698, 0.5998218648875543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 119}], {
             RGBColor[
             0.9659633260545548, 0.9718012970190144, 0.8209258826866541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 128}], {
             RGBColor[
             0.9264562463474343, 0.7201084554887204, 0.4272085765142214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.9507972193205387, 0.9597508678962337, 0.8209567354294411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 135}], {
             RGBColor[
             0.9908271486654647, 0.9898650400751433, 0.7573579795328484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 146}], {
             RGBColor[
             0.993752360158527, 0.9890452550494007, 0.5613611430985157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 166}], {
             RGBColor[
             0.7885149166671754, 0.8313535678913122, 0.805596040290351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 227}], {
             RGBColor[
             0.9393984467640613, 0.7789824253717651, 0.43801203451114434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 243}], {
             RGBColor[
             0.9938866226098646, 0.9911302111760466, 0.7066545786093809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[
             0.9871554389019598, 0.967055537836454, 0.5133487066379028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 275}], {
             RGBColor[
             0.994314684475276, 0.9902480099032174, 0.622566674713233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 311}], {
             RGBColor[
             0.9690426029072664, 0.9740978166539136, 0.815713470179041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 326}], {
             RGBColor[
             0.9947459727689298, 0.9914855745511117, 0.6924129225467486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 344}], {
             RGBColor[
             0.8959802750426051, 0.9162239808053383, 0.8156797749800367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 346}], {
             RGBColor[
             0.9637167999626639, 0.8811591116117292, 0.45787724147852665`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 363}], {
             RGBColor[
             0.9865117714309307, 0.9871262939357244, 0.7861427245573325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 383}], {
             RGBColor[
             0.9927801656729898, 0.9906726627980026, 0.7249914334721611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 172}], {
             RGBColor[
             0.8530063707928165, 0.8828438996851762, 0.8267314682772612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 194}], {
             RGBColor[
             0.9644642037971617, 0.883864851836932, 0.47371413926665284`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 233}], {
             RGBColor[
             0.9149448384387369, 0.6308444246854414, 0.4313991857506995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 256}], {
             RGBColor[
             0.9946620329078446, 0.990990953078168, 0.660373408012285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 257}], {
             RGBColor[
             0.9672757413011713, 0.972976547009704, 0.8342919992837158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 310}], {
             RGBColor[
             0.9924265963928516, 0.9907697622324327, 0.7485370176418769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 316}], {
             RGBColor[
             0.9838374950684509, 0.9853282758519583, 0.8062572701528947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 399}], {
             RGBColor[
             0.970672059166791, 0.9084769297323408, 0.47870912541415034`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 118}], {
             RGBColor[
             0.9750489834010236, 0.9798366709073094, 0.8789574482276608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 123}], {
             RGBColor[
             0.9770681904204752, 0.9801729513443264, 0.8092427514851516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 141}], {
             RGBColor[
             0.9587475215621912, 0.919731362337681, 0.62256792329256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 161}], {
             RGBColor[
             0.9587380619822974, 0.9196994529534843, 0.6225311746109645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 196}], {
             RGBColor[
             0.9741835262725203, 0.9794787821434396, 0.893300312578212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 214}], {
             RGBColor[
             0.976161186563768, 0.9782329618069863, 0.710520979061531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 286}], {
             RGBColor[
             0.977106706559004, 0.9802553334700604, 0.8134349954699543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 332}], {
             RGBColor[
             0.9731667832372811, 0.9683709177714039, 0.6785840320511999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 334}], {
             RGBColor[
             0.9400736719521883, 0.8463166473490042, 0.6043089726814825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 366}], {
             RGBColor[
             0.9723738527461527, 0.9656961770358947, 0.6755036468255246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 125}], {
             RGBColor[
             0.9719159257825372, 0.9148637900741352, 0.39359049172158184`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 184}], {
             RGBColor[
             0.972369336859005, 0.9158335905198081, 0.4429414892662965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 185}], {
             RGBColor[
             0.9635204885484776, 0.887013050492877, 0.3210918954868183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 190}], {
             RGBColor[
             0.9683545054365733, 0.9151328239950578, 0.5792209359555192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 252}], {
             RGBColor[
             0.9722463321217941, 0.9155704958246007, 0.4295531827181405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 270}], {
             RGBColor[
             0.9212823043086468, 0.8792231253114893, 0.6343226471181258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 274}], {
             RGBColor[
             0.9722048448333431, 0.9154817587096125, 0.42503754740012384`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 288}], {
             RGBColor[
             0.9692170148037398, 0.9154894937838608, 0.5649269236388816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 318}], {
             RGBColor[
             0.9653049021937097, 0.8930322967184932, 0.32802400554030314`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 168}], {
             RGBColor[
             0.9757265156353713, 0.9292630563551547, 0.40432795649835707`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 238}], {
             RGBColor[
             0.9390420144622806, 0.7953942597601954, 0.273115356074514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 379}], {
             RGBColor[
             0.9746172571957705, 0.9304763977999698, 0.5442515010620497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 236}], {
             RGBColor[
             0.9768788061616178, 0.9795345998450056, 0.7701198543949839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 262}], {
             RGBColor[
             0.9600905800798489, 0.8673163460534425, 0.42336094343685915`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 265}], {
             RGBColor[
             0.9937720044631417, 0.9890872722306276, 0.5634993044252247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 297}], {
             RGBColor[
             0.9850590751375584, 0.9856354310533009, 0.7562727927745632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 325}], {
             RGBColor[
             0.9921351920668393, 0.9899013244703494, 0.6989993927578257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 376}], {
             RGBColor[
             0.9386872653939489, 0.9497023591352587, 0.7879956864634817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 397}], {
             RGBColor[
             0.9904061721333295, 0.9891863302940576, 0.7276537276162358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 176}], {
             RGBColor[
             0.9275880780285954, 0.7250820590354482, 0.44039952676768335`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 205}], {
             RGBColor[
             0.9159985282043264, 0.9321553917948733, 0.82996372572094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 232}], {
             RGBColor[
             0.988470191989236, 0.9713506025985632, 0.5303528806875764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 277}], {
             RGBColor[
             0.9911169110186178, 0.9802786073638488, 0.5406348843257747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 373}], {
             RGBColor[
             0.9936999274820736, 0.9889331068562237, 0.5556541698435301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 390}], {
             RGBColor[
             0.9776696548598227, 0.9349178547743371, 0.48839483345010115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 89}], {
             RGBColor[
             0.9490254521316298, 0.828902567695174, 0.5167062055402759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 120}], {
             RGBColor[
             0.9497123355412747, 0.8271480314784814, 0.35713951265538435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 140}], {
             RGBColor[
             0.9494823363038649, 0.8290915010417809, 0.509134452428003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 189}], {
             RGBColor[
             0.9329882488103252, 0.8181636769409235, 0.5985600601882533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 195}], {
             RGBColor[
             0.9363570185956438, 0.7823541163012895, 0.28342830008138536`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 233}], {
             RGBColor[
             0.8707690956974405, 0.468656913770399, 0.21240547506054197`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 255}], {
             RGBColor[
             0.9148574931817033, 0.7001453630635969, 0.2503505443437441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 257}], {
             RGBColor[
             0.9230999985598749, 0.8107890360946616, 0.6152982885935583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 263}], {
             RGBColor[
             0.9391535727776492, 0.7917875502193421, 0.2942923849935329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 336}], {
             RGBColor[
             0.913104198953743, 0.802921683728403, 0.6179168879809024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 356}], {
             RGBColor[
             0.9426736996575763, 0.8036617647504327, 0.3079674132018669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 359}], {
             RGBColor[
             0.9507527099132709, 0.8293732870621966, 0.4703778426007873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 360}], {
             RGBColor[
             0.9123511376495175, 0.6902084985719503, 0.24833387185082173`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 389}], {
             RGBColor[
             0.8088306280515201, 0.7206563887701337, 0.6077377575871037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 162}], {
             RGBColor[
             0.9869979375088406, 0.971617981954533, 0.588053305170184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 183}], {
             RGBColor[
             0.9895779537372782, 0.9899582302830621, 0.8223838081718354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 189}], {
             RGBColor[
             0.9755079698841853, 0.9800328353341515, 0.8716357452307552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 263}], {
             RGBColor[
             0.9816732938515094, 0.95365670861257, 0.5673680700360348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 270}], {
             RGBColor[
             0.9417704601865153, 0.9537444692864973, 0.8896712176566317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.9869226456019213, 0.9713640046731138, 0.5877608103294862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 291}], {
             RGBColor[
             0.9910679391379821, 0.9853470531314548, 0.6038644929440828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 336}], {
             RGBColor[
             0.9556239200276031, 0.9647908421216309, 0.8909925730234043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 359}], {
             RGBColor[
             0.993272430987131, 0.9912424454554246, 0.7434535276432892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 95}], {
             RGBColor[
             0.9821125312231375, 0.9506063966008421, 0.4459890545503938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 97}], {
             RGBColor[
             0.9937610173251838, 0.9890637718535059, 0.5623034222632726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.7880597970486448, 0.8303801130469272, 0.7560590784859962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 228}], {
             RGBColor[
             0.9838119247149443, 0.9844787252974601, 0.7404055002103789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 246}], {
             RGBColor[
             0.9924061675673341, 0.9853292490505681, 0.48597788795748337`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 260}], {
             RGBColor[
             0.9210355731358365, 0.6809675798085624, 0.3729165949813549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 326}], {
             RGBColor[
             0.9942908531503991, 0.9905121197067267, 0.6428759607423937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 172}], {
             RGBColor[
             0.8252123552468504, 0.7856044782126377, 0.6209188798170251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 192}], {
             RGBColor[
             0.9642737513750193, 0.8933819555517806, 0.5486711621513713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 208}], {
             RGBColor[
             0.966508692191954, 0.8943061610149423, 0.5116324089733336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 221}], {
             RGBColor[
             0.9665552449215262, 0.8930825429818601, 0.4205174696274422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 256}], {
             RGBColor[
             0.9668680173618787, 0.8937515316056295, 0.45456081955204874`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 316}], {
             RGBColor[
             0.9560434795224848, 0.8880888543794196, 0.6004446816926585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 351}], {
             RGBColor[
             0.9627874164474443, 0.8811987314081393, 0.3356466102794675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 395}], {
             RGBColor[
             0.9672369583595756, 0.8945406590940461, 0.4947177703114425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 399}], {
             RGBColor[
             0.942878043620825, 0.8112375082598022, 0.27289653695391414`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 98}], {
             RGBColor[
             0.9814953956172607, 0.9845264230243034, 0.8627623464040761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 119}], {
             RGBColor[
             0.9544833411963434, 0.9655743309076972, 0.9619320100954147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 130}], {
             RGBColor[
             0.9393172344623275, 0.9535239017849164, 0.9619628628382018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 143}], {
             RGBColor[
             0.9823592230244942, 0.9830040474384496, 0.7118201093220873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 146}], {
             RGBColor[
             0.9822723753003157, 0.9828182889380834, 0.7023672705072764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 151}], {
             RGBColor[
             0.982729968395034, 0.9837970342979272, 0.7521734549301333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 158}], {
             RGBColor[
             0.9693770965866562, 0.9395827330977071, 0.6298869046708642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 186}], {
             RGBColor[
             0.9825399513138413, 0.9849583736486964, 0.845451355288247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 267}], {
             RGBColor[
             0.9756754540437484, 0.9608285717251368, 0.6543548340466635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 306}], {
             RGBColor[
             0.9801019974270906, 0.9757603419589624, 0.6715511192083713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 308}], {
             RGBColor[
             0.9815201753345969, 0.9805441890449889, 0.6770604725786071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 346}], {
             RGBColor[
             0.9522368151044527, 0.874932145500412, 0.5988833688872873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 348}], {
             RGBColor[
             0.980224756847932, 0.984000981239259, 0.8838201191195789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 354}], {
             RGBColor[
             0.9779062977520028, 0.9830422388214113, 0.9222429863189332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 374}], {
             RGBColor[
             0.9784544670905408, 0.970202835275261, 0.6651507749608734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 131}], {
             RGBColor[
             0.6578482921352986, 0.7236884832356909, 0.8919221776971993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 142}], {
             RGBColor[
             0.6263697924764595, 0.6000242570740104, 0.6004750150950371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 188}], {
             RGBColor[
             0.6606015898519041, 0.7236476152280586, 0.7605609900982366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 201}], {
             RGBColor[
             0.6509373822248493, 0.719234809969295, 0.9349891141392458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 264}], {
             RGBColor[
             0.6583010383794008, 0.723875705442675, 0.8844190007627067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 273}], {
             RGBColor[
             0.6586184948396556, 0.7240069818472492, 0.8791579256653006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 281}], {
             RGBColor[
             0.6462287138591238, 0.6760358743223834, 0.6306322146592808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 293}], {
             RGBColor[
             0.5814801326133381, 0.6648542842015985, 0.9631319149746781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 394}], {
             RGBColor[
             0.6379247824760508, 0.7095300343828177, 0.9570160512843982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 204}], {
             RGBColor[
             0.9834722997813039, 0.9554317583417502, 0.43098751479354164`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.9942489320175041, 0.9901613451270593, 0.6193331987852146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 307}], {
             RGBColor[
             0.9938100000690757, 0.9899798354863477, 0.626607437090142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 324}], {
             RGBColor[
             0.9910117124069803, 0.9888226716253585, 0.6729823053873942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 97}], {
             RGBColor[
             0.9822086081053413, 0.9508118953370132, 0.4564464302604901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 148}], {
             RGBColor[
             0.9682880684151565, 0.9046903498280067, 0.3313055633990116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 166}], {
             RGBColor[
             0.7765073878288022, 0.7921282365304344, 0.6502020864832138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 169}], {
             RGBColor[
             0.959611709788468, 0.8732643162227351, 0.3088417753146624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 228}], {
             RGBColor[
             0.9722595154951017, 0.9462268487809673, 0.6345485082075963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 246}], {
             RGBColor[
             0.9808537583474916, 0.9470773725340753, 0.3801208959547009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 276}], {
             RGBColor[
             0.9823485100059735, 0.9511111313562135, 0.4716738887698506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 282}], {
             RGBColor[
             0.9827107957509034, 0.951886023931911, 0.5111064563370261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 305}], {
             RGBColor[
             0.9785422831024606, 0.9505250228514018, 0.6065602129772824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 326}], {
             RGBColor[
             0.9827384439305566, 0.952260243190234, 0.5370189687396113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 361}], {
             RGBColor[
             0.9775046211214355, 0.935779946255772, 0.3671101302629694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 382}], {
             RGBColor[
             0.9810881951573739, 0.9515778229130639, 0.5643678616181735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 104}], {
             RGBColor[
             0.9306526731603799, 0.7606006036688306, 0.2695784083423194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 182}], {
             RGBColor[
             0.947770575448459, 0.8171343261116989, 0.4388812821033966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 187}], {
             RGBColor[
             0.8957806188578158, 0.7796079600432464, 0.6142932942919536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 208}], {
             RGBColor[
             0.9474137159024166, 0.8176942292411832, 0.496221239468204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 225}], {
             RGBColor[
             0.9370992877691096, 0.7823465484811678, 0.294622288756216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 261}], {
             RGBColor[
             0.9212933130892609, 0.7247545305778255, 0.25548205274360647`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 377}], {
             RGBColor[
             0.9469409187969678, 0.815359774425314, 0.3485782756359296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 388}], {
             RGBColor[
             0.9440437188319964, 0.8057717450862396, 0.3216000920897646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 166}], {
             RGBColor[
             0.7881558739308486, 0.8305856117830982, 0.7665164541960925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 169}], {
             RGBColor[
             0.9712601958905143, 0.9117216914753989, 0.4251561430275411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 224}], {
             RGBColor[
             0.9086936266941694, 0.585568980900888, 0.37146330550977436`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 246}], {
             RGBColor[
             0.9925022444495379, 0.9855347477867391, 0.4964352636675797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 276}], {
             RGBColor[
             0.9939969961080198, 0.9895685066088773, 0.5879882564827295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 326}], {
             RGBColor[
             0.9943869300326029, 0.9907176184428977, 0.65333333645249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 363}], {
             RGBColor[
             0.9861527286946039, 0.9863583378275103, 0.7470631384630739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 382}], {
             RGBColor[
             0.9927366812594203, 0.9900351981657277, 0.6806822293310523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 383}], {
             RGBColor[
             0.9924211229366628, 0.9899047066897886, 0.6859118473779027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 393}], {
             RGBColor[
             0.9576872018734206, 0.8579092931297557, 0.4142349934422702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 134}], {
             RGBColor[
             0.9624184243542266, 0.8823023620564492, 0.5289560228127252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 143}], {
             RGBColor[
             0.9922394086781363, 0.9891792198792824, 0.6416502307467562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 151}], {
             RGBColor[
             0.992610154048676, 0.98997220673876, 0.6820035763548024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 158}], {
             RGBColor[
             0.9792572822402982, 0.9457579055385399, 0.5597170260955331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 163}], {
             RGBColor[
             0.9903683123050685, 0.990285063862132, 0.8092855213211418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.9922668256345404, 0.9892378619767515, 0.6446343972535117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 186}], {
             RGBColor[
             0.9924201369674833, 0.9911335460895292, 0.775281476712916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 240}], {
             RGBColor[
             0.9888936549404231, 0.9896752551448855, 0.8337244101442404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 272}], {
             RGBColor[
             0.9925636659471132, 0.9898727733901851, 0.6769436333909934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 306}], {
             RGBColor[
             0.9899821830807327, 0.9819355143997952, 0.6013812406330403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 308}], {
             RGBColor[
             0.9914003609882389, 0.9867193614858216, 0.6068905940032762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 342}], {
             RGBColor[
             0.9316785802896017, 0.7511408356067353, 0.5037415491980013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 348}], {
             RGBColor[
             0.990104942501574, 0.9901761536800918, 0.8136502405442478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 354}], {
             RGBColor[
             0.9877864834056447, 0.989217411262244, 0.8520731077436021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 374}], {
             RGBColor[
             0.988334652744183, 0.9763780077160937, 0.5949808963855424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 378}], {
             RGBColor[
             0.9920634863650566, 0.9888029398400793, 0.6225021726347032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 144}], {
             RGBColor[
             0.9522861199114998, 0.8483810736714623, 0.2812806237380229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 169}], {
             RGBColor[
             0.9483719576089039, 0.8330190464842263, 0.27731706910745807`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[
             0.9676219502295291, 0.9104118412048874, 0.5697419022285095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 222}], {
             RGBColor[
             0.9640404767026045, 0.9082344221405687, 0.5979105221643175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 223}], {
             RGBColor[
             0.9682008392998429, 0.9106512267122326, 0.5601482122165191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 276}], {
             RGBColor[
             0.9711087578264095, 0.9108658616177047, 0.44014918256264635`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 361}], {
             RGBColor[
             0.9662648689418716, 0.8955346765172632, 0.3355854240557651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 382}], {
             RGBColor[
             0.9698484429778098, 0.9113325531745551, 0.5328431554109692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 384}], {
             RGBColor[
             0.9677562847459931, 0.9005655722256489, 0.34137929282453516`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 393}], {
             RGBColor[
             0.9347989635918101, 0.7792066481385831, 0.26639591952218716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 157}], {
             RGBColor[
             0.9792966381234764, 0.9409988147731949, 0.444311033912902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 167}], {
             RGBColor[
             0.9937061453310546, 0.9889464062064731, 0.5563309443330009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 174}], {
             RGBColor[
             0.9943647860353266, 0.9903551720741206, 0.6280199203337449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 198}], {
             RGBColor[
             0.9932144299128953, 0.9878946766470852, 0.5028107555821623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 203}], {
             RGBColor[
             0.9933364489794337, 0.9881556630923909, 0.5160917779604803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 206}], {
             RGBColor[
             0.9944115574252161, 0.9904552113477816, 0.6331106974836702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 211}], {
             RGBColor[
             0.9865224616756902, 0.9653732143188645, 0.4723819939309726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 266}], {
             RGBColor[
             0.9938692881283613, 0.9904900322323982, 0.6609286610604928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 341}], {
             RGBColor[
             0.9942423638148677, 0.9900933233233443, 0.6146950171391677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 358}], {
             RGBColor[
             0.9927121508057679, 0.9900115262124332, 0.6801054210712607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 115}], {
             RGBColor[
             0.9493932362694275, 0.9100668109618879, 0.6326958742995754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 123}], {
             RGBColor[
             0.9753601335970735, 0.9271877573365224, 0.47428169042947965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 161}], {
             RGBColor[
             0.9570300051588956, 0.8667142589456802, 0.2875701135552926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 193}], {
             RGBColor[
             0.9754179411874215, 0.927311401927033, 0.4805736898917713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 253}], {
             RGBColor[
             0.9610161877866215, 0.8801605889491895, 0.3030556803365817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 283}], {
             RGBColor[
             0.9751492267789152, 0.9267366489784321, 0.45132578483895974`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 332}], {
             RGBColor[
             0.9714587264138794, 0.9153857237636001, 0.34362297099552797`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 334}], {
             RGBColor[
             0.9383656151287866, 0.7933314533412003, 0.2693479116258107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 356}], {
             RGBColor[
             0.9674290145018039, 0.9017925592628171, 0.3279683011643556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 364}], {
             RGBColor[
             0.7692355072002671, 0.7675984756516172, 0.6219522034207838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 366}], {
             RGBColor[
             0.9706657959227509, 0.9127109830280906, 0.34054258576985263`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 380}], {
             RGBColor[
             0.9752169016581206, 0.9268813987020724, 0.4586917777995145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 389}], {
             RGBColor[
             0.8335859428957476, 0.8187871832825182, 0.6277386455495924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 108}], {
             RGBColor[
             0.9184919417003076, 0.9368274488141107, 0.9568239342333588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 139}], {
             RGBColor[
             0.9469010958185036, 0.8481026832406988, 0.5901870809321619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 213}], {
             RGBColor[
             0.8866476697686766, 0.9116121347284436, 0.9537397763462089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 297}], {
             RGBColor[
             0.9756346404769576, 0.9813489352791052, 0.9261283775556979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 333}], {
             RGBColor[
             0.983018715801409, 0.9809667447672642, 0.6730483678278277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 337}], {
             RGBColor[
             0.9845629426712694, 0.985261437245105, 0.756796896840183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 345}], {
             RGBColor[
             0.9442886660124987, 0.9573970565472245, 0.9592844488272632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 350}], {
             RGBColor[
             0.9651049078027563, 0.9734958778915408, 0.9439524683790019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 378}], {
             RGBColor[
             0.9839463778541303, 0.98394266744551, 0.6896876214915808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 122}], {
             RGBColor[
             0.9389834329996263, 0.7789233495301746, 0.3555792467220704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 295}], {
             RGBColor[
             0.9374223450284931, 0.7801988370745363, 0.5210896639197344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 145}], {
             RGBColor[
             0.9087240298134389, 0.6591670062927122, 0.2512077485294233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 170}], {
             RGBColor[
             0.9669418185109324, 0.9001491327865494, 0.3260756367390633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 182}], {
             RGBColor[
             0.9773440157394833, 0.9340292051410938, 0.4692892644983585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 187}], {
             RGBColor[
             0.9253540591488401, 0.8965028390726413, 0.6447012766869155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 192}], {
             RGBColor[
             0.974752215376506, 0.9336649028074164, 0.5636679750412036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 208}], {
             RGBColor[
             0.9769871561934409, 0.9345891082705781, 0.5266292218631659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 225}], {
             RGBColor[
             0.9666727280601337, 0.8992414275105627, 0.3250302711511779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 235}], {
             RGBColor[
             0.9762642689968639, 0.9315959472910631, 0.3622915964798529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 261}], {
             RGBColor[
             0.950866753380285, 0.8416494096072203, 0.28589003513856837`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 327}], {
             RGBColor[
             0.956829707935408, 0.9211433482026838, 0.6318479212940336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 335}], {
             RGBColor[
             0.9776960767046676, 0.9347822279467997, 0.5076089278902638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 349}], {
             RGBColor[
             0.9768630597134369, 0.9345377911869623, 0.5286858216882272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 351}], {
             RGBColor[
             0.9732658804489311, 0.9214816786637752, 0.35064342316929975`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 355}], {
             RGBColor[
             0.9770359249299854, 0.933370230052337, 0.4357554812006013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 199}], {
             RGBColor[
             0.8946185686603005, 0.9162706446355667, 0.8825702095840677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 215}], {
             RGBColor[
             0.9898578880672713, 0.9808115526378938, 0.5960276180930463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 259}], {
             RGBColor[
             0.9917302300801105, 0.9908482518618023, 0.7867150192584759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 271}], {
             RGBColor[
             0.990022896508581, 0.9901422255535034, 0.8150099549763661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 287}], {
             RGBColor[
             0.9916064930129056, 0.9907970834046154, 0.7887656626833266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 303}], {
             RGBColor[
             0.9925910716012498, 0.9895205923420125, 0.6500658211213416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 333}], {
             RGBColor[
             0.9913739171346, 0.9859254746625463, 0.6019171047415515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 337}], {
             RGBColor[
             0.9929181440044603, 0.9902201671403872, 0.6856656337539069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 345}], {
             RGBColor[
             0.9526438673456896, 0.9623557864425066, 0.888153185740987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 350}], {
             RGBColor[
             0.9734601091359474, 0.978454607786823, 0.8728212052927257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 353}], {
             RGBColor[
             0.9803783035292126, 0.9836141858378166, 0.861110506739005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 400}], {
             RGBColor[
             0.9814285998575527, 0.9843974951197902, 0.8593326290162796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 197}], {
             RGBColor[
             0.9896254815069698, 0.9824643407366287, 0.6119674876686296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 217}], {
             RGBColor[
             0.9862153768760212, 0.9882410280788048, 0.8634805516192569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 231}], {
             RGBColor[
             0.9923790197649692, 0.9904875471750937, 0.7302415336522243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 254}], {
             RGBColor[
             0.9879793917688264, 0.9892971838279385, 0.8488761169348409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 314}], {
             RGBColor[
             0.9802107309037043, 0.9837627729443561, 0.8736448509879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 369}], {
             RGBColor[
             0.9654702498744416, 0.9727693463280546, 0.8985966404372648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 124}], {
             RGBColor[
             0.9577313343448337, 0.8637775997445438, 0.31790967196115905`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 150}], {
             RGBColor[
             0.969922506238005, 0.9102036923887252, 0.3376550457030938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 152}], {
             RGBColor[
             0.9091642568694659, 0.9057514788444387, 0.6757543231756402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.9817852805557068, 0.9620331151316937, 0.6230894815163486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.971091137474982, 0.914145759958712, 0.3421949573812581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 160}], {
             RGBColor[
             0.9592956251725931, 0.8699794916075928, 0.3191683370797993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 167}], {
             RGBColor[
             0.9855006446825603, 0.9620933513919903, 0.45421486780135695`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.8370695902662351, 0.8492615364532421, 0.6686134588291865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 181}], {
             RGBColor[
             0.964880780767239, 0.8921227723975917, 0.32366228437170275`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 211}], {
             RGBColor[
             0.9783169610271958, 0.9385201595043815, 0.3702659173993287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 238}], {
             RGBColor[
             0.9487026109524557, 0.8279817201374805, 0.3106449491882753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 245}], {
             RGBColor[
             0.9850877609771823, 0.9633987756558493, 0.5683588343871344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 386}], {
             RGBColor[
             0.9854303626234564, 0.9619430251741732, 0.446565099398495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 297}], {
             RGBColor[
             0.918985217928215, 0.9371953334172183, 0.9559889462465565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 325}], {
             RGBColor[
             0.9260613348574958, 0.9414612268342668, 0.898715546229819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 376}], {
             RGBColor[
             0.8726134081846053, 0.9012622614991761, 0.987711839935475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 378}], {
             RGBColor[
             0.9272969553053877, 0.9397890655836231, 0.7195481901824394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 397}], {
             RGBColor[
             0.9243323149239859, 0.940746232657975, 0.9273698810882289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 114}], {
             RGBColor[
             0.9734052132045005, 0.9787243123236956, 0.8868254848587453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 132}], {
             RGBColor[
             0.9918417003677571, 0.9895308358277163, 0.6857547496621903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 180}], {
             RGBColor[
             0.9832270288841066, 0.9612111763545659, 0.5893938583164133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 232}], {
             RGBColor[
             0.9860602279550335, 0.9707682220875792, 0.6004003017022135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 249}], {
             RGBColor[
             0.9893140461369943, 0.9817441148481734, 0.613040770907126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 370}], {
             RGBColor[
             0.9838094596910911, 0.9631758522277815, 0.5916564920187192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 111}], {
             RGBColor[
             0.9772274463699118, 0.969624468494247, 0.6679426432003457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 117}], {
             RGBColor[
             0.9819696036281214, 0.9840585997519187, 0.8192099312991552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 202}], {
             RGBColor[
             0.9643361094479884, 0.9729225093373466, 0.9452538434588996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 212}], {
             RGBColor[
             0.8950689116354344, 0.9183113832262477, 0.9601656516168897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 239}], {
             RGBColor[
             0.9445138311093879, 0.8486752493854255, 0.5960536628365682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 247}], {
             RGBColor[
             0.9800790433822204, 0.9834904340764004, 0.8660700218351011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 269}], {
             RGBColor[
             0.7308854773303823, 0.787749901098427, 0.9453697732762091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 287}], {
             RGBColor[
             0.9801330296266859, 0.9835127587758701, 0.8651753300523839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 289}], {
             RGBColor[
             0.9778137528029218, 0.9825536782065479, 0.9036117491181728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 292}], {
             RGBColor[
             0.9812577350579834, 0.9825359848613466, 0.7417274305832087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 303}], {
             RGBColor[
             0.9811176082150304, 0.982236267713267, 0.7264754884903989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 309}], {
             RGBColor[
             0.9815318050534203, 0.9831221928688592, 0.7715582582225743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 362}], {
             RGBColor[
             0.9817575593332382, 0.9836050584461307, 0.7961302183868292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 385}], {
             RGBColor[
             0.9801961634324794, 0.9796386482342027, 0.6794755483932454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 400}], {
             RGBColor[
             0.9699551364713331, 0.9771131704910447, 0.9357422963853369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 199}], {
             RGBColor[
             0.8914677115009996, 0.9022809272919972, 0.6894023460454084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 222}], {
             RGBColor[
             0.9827751941789362, 0.9737619697266142, 0.6585517532440306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 223}], {
             RGBColor[
             0.9869355567761746, 0.9761787742982782, 0.6207894432962322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 247}], {
             RGBColor[
             0.988401649609139, 0.9767850413615762, 0.5964924909273843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 271}], {
             RGBColor[
             0.98687203934928, 0.9761525082099338, 0.6218420914377066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 287}], {
             RGBColor[
             0.9884556358536046, 0.9768073660610459, 0.5955977991446672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 292}], {
             RGBColor[
             0.989580341284902, 0.9758305921465225, 0.47214989967549204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 309}], {
             RGBColor[
             0.989854411280339, 0.9764168001540351, 0.5019807273148575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 319}], {
             RGBColor[
             0.9730077587942967, 0.9206109737128465, 0.3496406692832292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 362}], {
             RGBColor[
             0.9900801655601569, 0.9768996657313065, 0.5265526874791124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 385}], {
             RGBColor[
             0.9885187696593981, 0.9729332555193786, 0.4098980174855287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[
             0.9782777426982519, 0.9704077777762207, 0.6661647654776202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 177}], {
             RGBColor[
             0.8760649158710654, 0.7458301226582971, 0.6088478557282074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 219}], {
             RGBColor[
             0.9152391829436002, 0.7769802953329028, 0.6095914065819612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 248}], {
             RGBColor[
             0.9140659746500879, 0.6933216002874527, 0.2495230148108501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 251}], {
             RGBColor[
             0.6093600674927977, 0.5289007101124257, 0.5865979359605932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 260}], {
             RGBColor[
             0.8699190024286221, 0.48648793364177645`, 0.21255375703994048`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 162}], {
             RGBColor[
             0.9297322056562329, 0.7434470207434429, 0.3027071415529145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 183}], {
             RGBColor[
             0.9323122218846704, 0.761787269071972, 0.5370376445545659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 270}], {
             RGBColor[
             0.8845047283339076, 0.7255735080754073, 0.6043250540393622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 357}], {
             RGBColor[
             0.9115485005304631, 0.7468696956547196, 0.5976203331965282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 368}], {
             RGBColor[
             0.9346379593629874, 0.7599952799220733, 0.3217650683298032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 132}], {
             RGBColor[
             0.9752649714512465, 0.9781298582896484, 0.7568915593559795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 155}], {
             RGBColor[
             0.9073244755501744, 0.9283950531891356, 0.972131585267055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 180}], {
             RGBColor[
             0.966650299967596, 0.949810198816498, 0.6605306680102025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 249}], {
             RGBColor[
             0.9727373172204836, 0.9703431373101055, 0.6841775806009153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 268}], {
             RGBColor[
             0.5678777421439949, 0.6363586673928139, 0.9457316472762674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 279}], {
             RGBColor[
             0.9746663241583905, 0.9768494122627553, 0.6917324959514461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 299}], {
             RGBColor[
             0.9674775059274373, 0.9526005587562387, 0.6637442069594481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 300}], {
             RGBColor[
             0.9620347490500905, 0.93424086178886, 0.6426001242693481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 370}], {
             RGBColor[
             0.9672327307745805, 0.9517748746897136, 0.6627933017125084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 123}], {
             RGBColor[
             0.9687370091202764, 0.9739595699716954, 0.8233452683063036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 161}], {
             RGBColor[
             0.9504068806820984, 0.9134860715808533, 0.6366336914321166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 193}], {
             RGBColor[
             0.9687948167106244, 0.9740832145622059, 0.8296372677685953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 195}], {
             RGBColor[
             0.9544892089630741, 0.9272567234488469, 0.652492765920698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 214}], {
             RGBColor[
             0.9678300052635691, 0.9720195804343553, 0.724623495882683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 253}], {
             RGBColor[
             0.9543930633098243, 0.9269324015843624, 0.6521192582134057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 257}], {
             RGBColor[
             0.9412321889273053, 0.955691643242219, 0.9843627544328709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 283}], {
             RGBColor[
             0.9685261023021181, 0.9735084616136052, 0.8003893627157836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 312}], {
             RGBColor[
             0.819904922338746, 0.8600453138578384, 0.9760987583049304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 332}], {
             RGBColor[
             0.9648356019370823, 0.962157536398773, 0.6926865488723519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 334}], {
             RGBColor[
             0.9317424906519894, 0.8401032659763732, 0.6184114895026347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 356}], {
             RGBColor[
             0.9608058900250067, 0.9485643718979901, 0.6770318790411796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 360}], {
             RGBColor[
             0.9304833280169478, 0.8351111057195078, 0.6173983376901344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 364}], {
             RGBColor[
             0.76261238272347, 0.8143702882867901, 0.9710157812976078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 366}], {
             RGBColor[
             0.9640426714459538, 0.9594827956632637, 0.6896061636466766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 380}], {
             RGBColor[
             0.9685937771813234, 0.9736532113372454, 0.8077553556763384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 389}], {
             RGBColor[
             0.8269628184189505, 0.8655589959176911, 0.9768022234264163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 141}], {
             RGBColor[
             0.9766434808171297, 0.9311955612886622, 0.506582125521028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 179}], {
             RGBColor[
             0.8459665808736777, 0.8775936183695561, 0.8459939500109895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 209}], {
             RGBColor[
             0.9751477436496496, 0.9258863378679556, 0.5021450874033272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 286}], {
             RGBColor[
             0.9950026658139426, 0.9917195324210417, 0.6974491976984223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 290}], {
             RGBColor[
             0.9942150973891306, 0.9900350031957511, 0.6117272349665546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 304}], {
             RGBColor[
             0.7949462433972412, 0.8370055791073155, 0.8414082100823153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 338}], {
             RGBColor[
             0.9914500755288825, 0.9906827038849104, 0.7877454673439506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 239}], {
             RGBColor[
             0.9575785945945161, 0.8564039879282731, 0.47774342002766124`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 269}], {
             RGBColor[
             0.7439502408155105, 0.7954786396412745, 0.8270595304673021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 309}], {
             RGBColor[
             0.9945965685385486, 0.9908509314117068, 0.6532480154136673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 323}], {
             RGBColor[
             0.9949320828234094, 0.9915685625413262, 0.6897666747666125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 362}], {
             RGBColor[
             0.9948223228183665, 0.9913337969889782, 0.6778199755779222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 365}], {
             RGBColor[
             0.9540633129458442, 0.8424670675894572, 0.47491494189887445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 377}], {
             RGBColor[
             0.9939184859189147, 0.9894005812529794, 0.5794429069073749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 385}], {
             RGBColor[
             0.9932609269176077, 0.9873673867770503, 0.5611653055843383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 388}], {
             RGBColor[
             0.9910212859539433, 0.9798125519139048, 0.55246472336121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 395}], {
             RGBColor[
             0.9951195491919851, 0.9919695341479524, 0.7101712320777582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 124}], {
             RGBColor[
             0.9643488747053333, 0.8912167672748631, 0.5366789906080596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[
             0.9743640305701866, 0.9303026469026675, 0.5479709529861256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 150}], {
             RGBColor[
             0.9765400465985046, 0.9376428599190445, 0.5564243643499943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 179}], {
             RGBColor[
             0.8436871306267346, 0.8767007039835613, 0.8873827774760872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 196}], {
             RGBColor[
             0.9898000352805157, 0.9900500667084261, 0.8187033422717773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 206}], {
             RGBColor[
             0.9928235971372213, 0.991041324063618, 0.7497639395989268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 209}], {
             RGBColor[
             0.9728682934027065, 0.9249934234819608, 0.5435339148684248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 286}], {
             RGBColor[
             0.9927232155669995, 0.9908266180350469, 0.7388380251635198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 386}], {
             RGBColor[
             0.992047902983956, 0.9893821927044925, 0.6653344180453955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 128}], {
             RGBColor[
             0.8978443927219477, 0.7011045697016297, 0.5972144890389897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 130}], {
             RGBColor[
             0.9221853656950522, 0.940746982109143, 0.9909626479542095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 135}], {
             RGBColor[
             0.9622152950399782, 0.9708611542880526, 0.9273638920576167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 146}], {
             RGBColor[
             0.9651405065330404, 0.97004136926231, 0.7313670556232841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 151}], {
             RGBColor[
             0.9655980996277587, 0.9710201146221538, 0.7811732400461411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 213}], {
             RGBColor[
             0.8677527238586855, 0.8975203150064066, 0.98572399118067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 227}], {
             RGBColor[
             0.9107865931385746, 0.7599785395846744, 0.6080179470359126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 243}], {
             RGBColor[
             0.965274768984378, 0.9721263253889559, 0.8766604911341491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 267}], {
             RGBColor[
             0.9585435852764732, 0.9480516520493634, 0.6833546191626712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 306}], {
             RGBColor[
             0.9629701286598153, 0.962983422283189, 0.7005509043243789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 311}], {
             RGBColor[
             0.9404307492817798, 0.9550939308668229, 0.9857193827038092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 344}], {
             RGBColor[
             0.8673684214171185, 0.8972200950182476, 0.985685687504805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 346}], {
             RGBColor[
             0.9351049463371773, 0.8621552258246385, 0.627883154003295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 350}], {
             RGBColor[
             0.9462099618927653, 0.9594040581695038, 0.975936683213463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 354}], {
             RGBColor[
             0.9607744289847274, 0.9702653191456379, 0.9512427714349407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 140}], {
             RGBColor[
             0.99268894078737, 0.9892061232183162, 0.6226434445856134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 147}], {
             RGBColor[
             0.9600416029515757, 0.8681001347360063, 0.36545068367278055`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 193}], {
             RGBColor[
             0.9938692308266992, 0.9892952295911839, 0.5740817940868929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 195}], {
             RGBColor[
             0.9795636230791488, 0.9424687384778249, 0.39693729223899565`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 241}], {
             RGBColor[
             0.9938927901465391, 0.9893456205941089, 0.576646080660204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 242}], {
             RGBColor[
             0.992725425848469, 0.9868487463991722, 0.4495856809526261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 255}], {
             RGBColor[
             0.9580640976652084, 0.8602599852401323, 0.3638595365013544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 263}], {
             RGBColor[
             0.9823601772611543, 0.9519021723958774, 0.4078013771511432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 312}], {
             RGBColor[
             0.8449793364548207, 0.8752573288868164, 0.720543284623228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 331}], {
             RGBColor[
             0.9936883723921872, 0.9889083916873553, 0.5543964696191417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 356}], {
             RGBColor[
             0.9858803041410813, 0.963776386926968, 0.42147640535947717`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 359}], {
             RGBColor[
             0.993959314396776, 0.989487909238732, 0.5838868347583976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 360}], {
             RGBColor[
             0.9555577421330226, 0.8503231207484856, 0.361842864008432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 380}], {
             RGBColor[
             0.9936681912973981, 0.9888652263662233, 0.5521998819946361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 389}], {
             RGBColor[
             0.8520372325350252, 0.8807710109466691, 0.7212467497447139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[
             0.9934428191574488, 0.9915564514568134, 0.7583329862085199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 202}], {
             RGBColor[
             0.9765929101343173, 0.9805307640705376, 0.8558622498150829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 234}], {
             RGBColor[
             0.9908211762606028, 0.9817424993596573, 0.5837447670575808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 289}], {
             RGBColor[
             0.9900705534892507, 0.9901619329397389, 0.814220155474356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 298}], {
             RGBColor[
             0.977626034008002, 0.9372321861748985, 0.532484131099755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 173}], {
             RGBColor[
             0.9632426897472306, 0.9686549965703442, 0.739495636722876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 338}], {
             RGBColor[
             0.9903654750008399, 0.9883628530253621, 0.6696933932450915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 161}], {
             RGBColor[
             0.9763737780097446, 0.9306070179554877, 0.4782195075620208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 196}], {
             RGBColor[
             0.9918192422999674, 0.990386347145443, 0.7489886455292682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 214}], {
             RGBColor[
             0.9937969025912152, 0.9891405268089899, 0.5662093120125873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 253}], {
             RGBColor[
             0.9803599606374702, 0.944053347958997, 0.4937050743433099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 283}], {
             RGBColor[
             0.9944929996297641, 0.9906294079882396, 0.641975178845688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 332}], {
             RGBColor[
             0.9908024992647282, 0.9792784827734076, 0.5342723650022562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 334}], {
             RGBColor[
             0.9577093879796355, 0.8572242123510078, 0.4599973056325389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 356}], {
             RGBColor[
             0.9867727873526526, 0.9656853182726246, 0.5186176951710838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 364}], {
             RGBColor[
             0.788579280051116, 0.8314912346614247, 0.812601597427512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 366}], {
             RGBColor[
             0.9900095687735998, 0.9766037420378981, 0.5311919797765808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 389}], {
             RGBColor[
             0.8529297157465965, 0.8826799422923257, 0.8183880395563206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 150}], {
             RGBColor[
             0.9502234288948188, 0.8384516717216117, 0.28874287703682766`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 152}], {
             RGBColor[
             0.8894651795262797, 0.8339994581773252, 0.6268421545093741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 156}], {
             RGBColor[
             0.9620862032125206, 0.89028109446458, 0.5741773128500824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 157}], {
             RGBColor[
             0.9513920601317958, 0.8423937392915983, 0.293282788714992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 160}], {
             RGBColor[
             0.9395965478294069, 0.7982274709404793, 0.27025616841353317`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 167}], {
             RGBColor[
             0.9658015673393741, 0.8903413307248766, 0.40530269913509087`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 179}], {
             RGBColor[
             0.8173705129230489, 0.7775095157861285, 0.6197012901629204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 181}], {
             RGBColor[
             0.9451817034240528, 0.8203707517304781, 0.2747501157054366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 238}], {
             RGBColor[
             0.9290035336092695, 0.756229699470367, 0.2617327805220092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 245}], {
             RGBColor[
             0.9653886836339961, 0.8916467549887357, 0.5194466657208683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 386}], {
             RGBColor[
             0.9657312852802702, 0.8901910045070597, 0.39765293073222885`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 184}], {
             RGBColor[
             0.9937164011917892, 0.9889683424555575, 0.5574472314821122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 185}], {
             RGBColor[
             0.9848675528812617, 0.9601478024286265, 0.43559763770263404`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 190}], {
             RGBColor[
             0.9897015697693574, 0.9882675759308073, 0.6937266781713348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 226}], {
             RGBColor[
             0.9862332502408464, 0.9647546203034951, 0.44090311405431487`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 252}], {
             RGBColor[
             0.9935933964545782, 0.9887052477603502, 0.5440589249339562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 274}], {
             RGBColor[
             0.9935519091661273, 0.9886165106453619, 0.5395432896159396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 288}], {
             RGBColor[
             0.9905640791365239, 0.9886242457196102, 0.6794326658546973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 318}], {
             RGBColor[
             0.9866519665264938, 0.9661670486542426, 0.44252974775611886`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 176}], {
             RGBColor[
             0.8869051268218608, 0.696343564802808, 0.5984053762558557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 205}], {
             RGBColor[
             0.8753155769975918, 0.903416897562233, 0.9879695752091122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 298}], {
             RGBColor[
             0.9376347971381502, 0.9083655320463977, 0.6489184037455538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 320}], {
             RGBColor[
             0.9409519434372794, 0.9195550454163502, 0.6618048907271545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 347}], {
             RGBColor[
             0.8287255261805562, 0.8668812841556203, 0.9833628302966768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 373}], {
             RGBColor[
             0.9530169762753391, 0.9601946126235834, 0.7136600193317024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 137}], {
             RGBColor[
             0.9566595654442664, 0.8572694671060966, 0.5135522020524537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 138}], {
             RGBColor[
             0.8927934206125143, 0.8092114384954827, 0.6210146301457997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 193}], {
             RGBColor[
             0.9577617521917225, 0.8573262757606117, 0.4662849252249092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 210}], {
             RGBColor[
             0.9227815921575677, 0.7315617749534491, 0.25672646038223335`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 242}], {
             RGBColor[
             0.9566179472134924, 0.8548797925686002, 0.3417888120906424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 255}], {
             RGBColor[
             0.9219566190302317, 0.7282910314095601, 0.25606266763937074`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 258}], {
             RGBColor[
             0.9543181035253832, 0.8563012124298118, 0.5523562855575527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 264}], {
             RGBColor[
             0.9550088617782919, 0.856586858719067, 0.540908633681801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 312}], {
             RGBColor[
             0.808871857819844, 0.7432883750562442, 0.6127464157612443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 328}], {
             RGBColor[
             0.94237761240681, 0.8068616428338649, 0.28495053007554494`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 331}], {
             RGBColor[
             0.9575808937572106, 0.8569394378567834, 0.446599600757158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 380}], {
             RGBColor[
             0.9575607126624215, 0.8568962725356513, 0.4444030131326524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 394}], {
             RGBColor[
             0.9346326058749419, 0.8422411876592097, 0.6135056842034923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 130}], {
             RGBColor[
             0.8826782859879316, 0.6890541405788488, 0.5972453417817767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 135}], {
             RGBColor[
             0.9227082153328576, 0.7191683127577586, 0.533646585885184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 139}], {
             RGBColor[
             0.8884990702013921, 0.5823180219883679, 0.22845398959419036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 151}], {
             RGBColor[
             0.9260910199206382, 0.7193272730918598, 0.38745593387370836`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 213}], {
             RGBColor[
             0.8282456441515651, 0.6458274734761126, 0.5920066850082373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 215}], {
             RGBColor[
             0.9231006611169688, 0.7100681614902806, 0.30542578984135094`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 224}], {
             RGBColor[
             0.8409337360978892, 0.3156402096917174, 0.18683149795636844`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 227}], {
             RGBColor[
             0.8712795134314542, 0.5082856980543804, 0.21430064086347994`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 243}], {
             RGBColor[
             0.9257676892772575, 0.7204334838586619, 0.48294318496171645`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 259}], {
             RGBColor[
             0.924973003129808, 0.7201048607141891, 0.4961131910067805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 306}], {
             RGBColor[
             0.9234630489526949, 0.7112905807528949, 0.3068335981519462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 350}], {
             RGBColor[
             0.9067028821856449, 0.7077112166392099, 0.5822193770410302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 383}], {
             RGBColor[
             0.9246612323403827, 0.7199759354806179, 0.5012800398244968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 131}], {
             RGBColor[
             0.991519647691726, 0.990199602267122, 0.7493848224589299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 253}], {
             RGBColor[
             0.9803235309484585, 0.9439754285378072, 0.48973992751235607`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 271}], {
             RGBColor[
             0.9914125365858143, 0.9901553090721977, 0.7511599306785423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 287}], {
             RGBColor[
             0.9929961330901389, 0.9908101669233097, 0.7249156383855028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 303}], {
             RGBColor[
             0.9939807116784831, 0.9895336758607067, 0.5862157968235178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 333}], {
             RGBColor[
             0.9927635572118333, 0.9859385581812407, 0.5380670804437278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 337}], {
             RGBColor[
             0.9943077840816936, 0.9902332506590814, 0.6218156094560832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 353}], {
             RGBColor[
             0.9817679436064459, 0.9836272693565109, 0.7972604824411813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 364}], {
             RGBColor[
             0.7885428503621041, 0.831413315240235, 0.8086364505965582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 391}], {
             RGBColor[
             0.9753379625794305, 0.9271579357619548, 0.4703719358442695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 135}], {
             RGBColor[
             0.9470491883059622, 0.9588107251652718, 0.9273947448004038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 146}], {
             RGBColor[
             0.9499743997990244, 0.9579909401395292, 0.7313979083660711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 151}], {
             RGBColor[
             0.9504319928937428, 0.958969685499373, 0.7812040927889281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 158}], {
             RGBColor[
             0.9370791210853648, 0.9147553842991528, 0.658917542529659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 227}], {
             RGBColor[
             0.8956204864045587, 0.7479281104618936, 0.6080487997786997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 243}], {
             RGBColor[
             0.9501086622503621, 0.9600758962661751, 0.8766913438769363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 267}], {
             RGBColor[
             0.9433774785424571, 0.9360012229265826, 0.6833854719054582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 275}], {
             RGBColor[
             0.9505367241157734, 0.9591936949933458, 0.7926034399807884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 306}], {
             RGBColor[
             0.9478040219257994, 0.9509329931604081, 0.700581757067166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 311}], {
             RGBColor[
             0.9252646425477637, 0.9430435017440422, 0.9857502354465963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 317}], {
             RGBColor[
             0.9379620495520147, 0.9525132070977167, 0.9642568374025294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 344}], {
             RGBColor[
             0.8522023146831025, 0.8851696658954669, 0.9857165402475921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 346}], {
             RGBColor[
             0.9199388396031614, 0.8501047967018578, 0.627914006746082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 354}], {
             RGBColor[
             0.9456083222507115, 0.9582148900228571, 0.9512736241777279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 142}], {
             RGBColor[
             0.9569297486547139, 0.8658103008686129, 0.5503216915413974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 201}], {
             RGBColor[
             0.9814973384031038, 0.9850208537638976, 0.8848357905856061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 273}], {
             RGBColor[
             0.98917845101791, 0.9897930256418517, 0.829004602111661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 281}], {
             RGBColor[
             0.9767886700373782, 0.941821918116986, 0.5804788911056411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 293}], {
             RGBColor[
             0.9120400887915925, 0.930640327996201, 0.9129785914210384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 303}], {
             RGBColor[
             0.9908693123003103, 0.9888086006238782, 0.6785998285081476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 391}], {
             RGBColor[
             0.9722265632012577, 0.9264328605251264, 0.5627559675288992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 394}], {
             RGBColor[
             0.9684847386543053, 0.9753160781774202, 0.9068627277307585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 149}], {
             RGBColor[
             0.9943769124271034, 0.9903811091999647, 0.6293398032432216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 155}], {
             RGBColor[
             0.9257609627134311, 0.9392015766931563, 0.7710608500705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 180}], {
             RGBColor[
             0.9850867871308526, 0.9606167223205186, 0.4594599328136475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 249}], {
             RGBColor[
             0.9911738043837401, 0.9811496608141261, 0.4831068454043602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 268}], {
             RGBColor[
             0.5863142293072515, 0.6471651908968346, 0.7446609120797123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 279}], {
             RGBColor[
             0.9931028113216471, 0.987655935766776, 0.49066176075489104`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 299}], {
             RGBColor[
             0.9859139930906939, 0.9634070822602594, 0.4626734717628931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 300}], {
             RGBColor[
             0.9804712362133472, 0.9450473852928807, 0.44152938907279304`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 370}], {
             RGBColor[
             0.9856692179378371, 0.9625813981937342, 0.46172256651595334`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 178}], {
             RGBColor[
             0.9804602580187074, 0.9596932464332104, 0.6326627265177612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 200}], {
             RGBColor[
             0.989084094474344, 0.9897540067862346, 0.8305683342254571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 278}], {
             RGBColor[
             0.9898165452679419, 0.9897550385816882, 0.7964880257805242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 296}], {
             RGBColor[
             0.9436701935547377, 0.8193657688211945, 0.5718399731465977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 320}], {
             RGBColor[
             0.9765844556240264, 0.9466192548742723, 0.6176059660982931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 330}], {
             RGBColor[
             0.9170246350797266, 0.9353263797736933, 0.9443502369523493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 347}], {
             RGBColor[
             0.8643580383673031, 0.8939454936135424, 0.9391639056678154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 367}], {
             RGBColor[
             0.9809761627612681, 0.9614335142700619, 0.6346669190221741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 398}], {
             RGBColor[
             0.9888686272458558, 0.9877275377816594, 0.6933129989483787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 163}], {
             RGBColor[
             0.9614111553883924, 0.881885830453445, 0.545649076305122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 171}], {
             RGBColor[
             0.9633096687178644, 0.8808386285680645, 0.3809979522374919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 240}], {
             RGBColor[
             0.959936498023747, 0.8812760217361986, 0.5700879651282207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 272}], {
             RGBColor[
             0.9636065090304371, 0.8814735399814981, 0.4133071883749736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 342}], {
             RGBColor[
             0.9027214233729256, 0.6427416021980483, 0.2401051041819815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 374}], {
             RGBColor[
             0.9593774958275069, 0.8679787743074068, 0.3313444513695226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 213}], {
             RGBColor[
             0.8926165464695957, 0.9155840580625355, 0.9221560880268643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 215}], {
             RGBColor[
             0.9874715634349993, 0.9798247460767036, 0.635575192859978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 224}], {
             RGBColor[
             0.9053046384159198, 0.5853967942781404, 0.5169809009749955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 227}], {
             RGBColor[
             0.9356504157494847, 0.7780422826408033, 0.5444500438821069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 243}], {
             RGBColor[
             0.990138591595288, 0.9901900684450848, 0.8130925879803435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 259}], {
             RGBColor[
             0.9893439054478385, 0.989861445300612, 0.8262625940254076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 350}], {
             RGBColor[
             0.9710737845036753, 0.9774678012256328, 0.9123687800596574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 363}], {
             RGBColor[
             0.9827637404163541, 0.9861861512047625, 0.8925807339282951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 383}], {
             RGBColor[
             0.9890321346584132, 0.9897325200670408, 0.8314294428431237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 393}], {
             RGBColor[
             0.9542982135951709, 0.8577371065070081, 0.5597525889074914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 149}], {
             RGBColor[
             0.9072283646684514, 0.9253350099261943, 0.8427465047687812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 155}], {
             RGBColor[
             0.8386124149547791, 0.8741554774193859, 0.9844675515960595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 268}], {
             RGBColor[
             0.49916568154859964`, 0.5821190916230642, 0.9580676136052718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 279}], {
             RGBColor[
             0.9059542635629951, 0.9226098364930057, 0.7040684622804506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 299}], {
             RGBColor[
             0.898765445332042, 0.898360982986489, 0.6760801732884527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 300}], {
             RGBColor[
             0.8933226884546952, 0.8800012860191104, 0.6549360905983527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 371}], {
             RGBColor[
             0.8886713594489903, 0.9134976291943742, 0.9693588993963866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 138}], {
             RGBColor[
             0.9287490033019543, 0.9431561596077069, 0.879512065109226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 164}], {
             RGBColor[
             0.9925596560812487, 0.9887948389791018, 0.5987761671831188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 210}], {
             RGBColor[
             0.9587371748470076, 0.8655064960656733, 0.5152238953456597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 230}], {
             RGBColor[
             0.993463618035178, 0.9907283221939833, 0.69716684726181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 242}], {
             RGBColor[
             0.9925735299029322, 0.9888245136808242, 0.6002862470540686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 258}], {
             RGBColor[
             0.9902736862148231, 0.9902459335420359, 0.8108537205209789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 264}], {
             RGBColor[
             0.9909644444677318, 0.990531579831291, 0.7994060686452272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 328}], {
             RGBColor[
             0.9783331950962498, 0.9408063639460891, 0.5434479650389712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 394}], {
             RGBColor[
             0.9705881885643819, 0.9761859087714337, 0.8720031191669186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 149}], {
             RGBColor[
             0.9299676123549528, 0.9434619838016767, 0.8449166377647954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 164}], {
             RGBColor[
             0.9286935112494967, 0.9407368103684879, 0.7062385952764648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 210}], {
             RGBColor[
             0.8948710300152556, 0.8174484674550594, 0.6226863234390058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 230}], {
             RGBColor[
             0.929597473203426, 0.9426702935833695, 0.804629275355156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 242}], {
             RGBColor[
             0.9287073850711802, 0.9407664850702104, 0.7077486751474147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 258}], {
             RGBColor[
             0.926407541383071, 0.9421879049314221, 0.918316148614325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 264}], {
             RGBColor[
             0.9270982996359798, 0.9424735512206772, 0.9068684967385733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 281}], {
             RGBColor[
             0.9150259751157028, 0.8946337201003858, 0.6530817106351473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 328}], {
             RGBColor[
             0.9144670502644978, 0.8927483353354752, 0.6509103931323172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 394}], {
             RGBColor[
             0.9067220437326298, 0.9281278801608199, 0.9794655472602647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 186}], {
             RGBColor[
             0.9560627600260104, 0.8533949062596612, 0.5056906409594554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 213}], {
             RGBColor[
             0.85840740133813, 0.7787337672931448, 0.6169634917358706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 215}], {
             RGBColor[
             0.9532624183035336, 0.8429744553073129, 0.3303825965689843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 306}], {
             RGBColor[
             0.9536248061392598, 0.8441968745699271, 0.3317904048795796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 308}], {
             RGBColor[
             0.955042984046766, 0.8489807216559535, 0.3372997582498155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 345}], {
             RGBColor[
             0.916048397581952, 0.8245186891119257, 0.622508164216925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 350}], {
             RGBColor[
             0.9368646393722098, 0.8406175104562421, 0.6071761837686637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 378}], {
             RGBColor[
             0.9557061094235837, 0.8510643000102112, 0.35291133688124254`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 147}], {
             RGBColor[
             0.959811603714166, 0.8700436042993058, 0.5174456234453992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 193}], {
             RGBColor[
             0.9936392315892895, 0.9912386991544834, 0.7260767338595115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 195}], {
             RGBColor[
             0.979333623841739, 0.9444122080411244, 0.5489322320116143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 241}], {
             RGBColor[
             0.9936627909091293, 0.9912890901574084, 0.7286410204328226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 242}], {
             RGBColor[
             0.9924954266110593, 0.9887922159624718, 0.6015806207252448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 255}], {
             RGBColor[
             0.9578340984277987, 0.8622034548034317, 0.5158544762739732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 263}], {
             RGBColor[
             0.9821301780237446, 0.953845641959177, 0.5597963169237619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 312}], {
             RGBColor[
             0.844749337217411, 0.8772007984501159, 0.8725382243958468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 331}], {
             RGBColor[
             0.9934583731547775, 0.9908518612506549, 0.7063914093917604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 356}], {
             RGBColor[
             0.9856503049036716, 0.9657198564902676, 0.5734713451320959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 359}], {
             RGBColor[
             0.9937293151593662, 0.9914313788020315, 0.7358817745310163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 360}], {
             RGBColor[
             0.9553277428956128, 0.8522665903117852, 0.5138378037810507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 380}], {
             RGBColor[
             0.9934381920599884, 0.9908086959295228, 0.7041948217672548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 389}], {
             RGBColor[
             0.8518072332976154, 0.8827144805099686, 0.8732416895173327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 179}], {
             RGBColor[
             0.8273856687879022, 0.8165953954139329, 0.6309932525409865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 196}], {
             RGBColor[
             0.9734985734416833, 0.9299447581387977, 0.5623138173366767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 209}], {
             RGBColor[
             0.9565668315638741, 0.8648881149123324, 0.28714438993332414`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 286}], {
             RGBColor[
             0.9764217537281671, 0.9307213094654185, 0.4824485002284192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 290}], {
             RGBColor[
             0.975634185303355, 0.929036780240128, 0.39672653749655157`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 304}], {
             RGBColor[
             0.7763653313114658, 0.7760073561516925, 0.6264075126123123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 386}], {
             RGBColor[
             0.9757464411451235, 0.9292768841348641, 0.40894489311029486`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.9596830463713194, 0.8657694328609806, 0.4189605039424348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 201}], {
             RGBColor[
             0.9500188387442646, 0.861356627602217, 0.5933886279834439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 273}], {
             RGBColor[
             0.9576999513590709, 0.8661287994801712, 0.5375574395094989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 281}], {
             RGBColor[
             0.9453101703785391, 0.8181576919553054, 0.28903172850347897`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 293}], {
             RGBColor[
             0.8805615891327534, 0.8069761018345205, 0.6215314288188762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 394}], {
             RGBColor[
             0.9370062389954661, 0.8516518520157397, 0.6154155651285964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 151}], {
             RGBColor[
             0.9934739814559095, 0.9884498311529062, 0.5310613392728136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 158}], {
             RGBColor[
             0.9801211096475317, 0.9442355299526861, 0.40877478901354436`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 171}], {
             RGBColor[
             0.993130653041774, 0.9877154863908977, 0.4936921601715229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 186}], {
             RGBColor[
             0.9932839643747169, 0.9896111705036754, 0.6243392396309273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 272}], {
             RGBColor[
             0.9934274933543468, 0.9883503978043313, 0.5260013963090047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 306}], {
             RGBColor[
             0.9908460104879662, 0.9804131388139414, 0.4504390035510515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 308}], {
             RGBColor[
             0.9922641883954724, 0.9851969858999678, 0.4559483569212874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 342}], {
             RGBColor[
             0.9325424076968352, 0.7496184600208815, 0.3527993121160125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 348}], {
             RGBColor[
             0.9909687699088074, 0.988653778094238, 0.6627080034622591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 354}], {
             RGBColor[
             0.9886503108128782, 0.9876950356763903, 0.7011308706616133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 374}], {
             RGBColor[
             0.9891984801514164, 0.97485563213024, 0.4440386593035536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 378}], {
             RGBColor[
             0.99292731377229, 0.9872805642542255, 0.4715599355527144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 148}], {
             RGBColor[
             0.9612538185029255, 0.8809621731536285, 0.30397883079662746`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 169}], {
             RGBColor[
             0.9525774598762369, 0.8495361395483569, 0.28151504271227823`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 218}], {
             RGBColor[
             0.971827452496862, 0.9269289342690179, 0.5739398758333296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 222}], {
             RGBColor[
             0.9682459789699375, 0.9247515152046992, 0.6021084957691376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 276}], {
             RGBColor[
             0.9753142600937423, 0.9273829546818353, 0.4443471561674665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 282}], {
             RGBColor[
             0.9756765458386722, 0.9281578472575328, 0.483779723734642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 305}], {
             RGBColor[
             0.9715080331902295, 0.9267968461770236, 0.5792334803748982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 339}], {
             RGBColor[
             0.9741541077368182, 0.9278910660030522, 0.5353811773165085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 361}], {
             RGBColor[
             0.9704703712092045, 0.9120517695813938, 0.3397833976605853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 382}], {
             RGBColor[
             0.9740539452451429, 0.9278496462386857, 0.5370411290157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 384}], {
             RGBColor[
             0.9719617870133261, 0.9170826652897794, 0.3455772664293554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 165}], {
             RGBColor[
             0.9262354287506152, 0.7165423782793854, 0.4633403041649083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 170}], {
             RGBColor[
             0.9154397348729673, 0.681820656381036, 0.2772969945312054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 182}], {
             RGBColor[
             0.925841932101518, 0.7157007287355803, 0.4205106222905005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 192}], {
             RGBColor[
             0.9232501317385409, 0.7153364264019031, 0.5148893328333457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 208}], {
             RGBColor[
             0.9254850725554756, 0.7162606318650646, 0.4778505796553079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 221}], {
             RGBColor[
             0.9255316252850478, 0.7150370138319826, 0.38673564030941643`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 225}], {
             RGBColor[
             0.9151706444221686, 0.6809129511050493, 0.27625162894331995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 235}], {
             RGBColor[
             0.9247621853588988, 0.7132674708855498, 0.3135129542719949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 335}], {
             RGBColor[
             0.9261939930667025, 0.7164537515412862, 0.45883028568240586`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 349}], {
             RGBColor[
             0.9253609760754716, 0.716209314781449, 0.47990717948036926`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 351}], {
             RGBColor[
             0.9217637968109659, 0.7031532022582618, 0.30186478096144176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 355}], {
             RGBColor[
             0.9255338412920202, 0.7150417536468237, 0.3869768389927434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 395}], {
             RGBColor[
             0.9262133387230972, 0.7164951299441686, 0.4609359409934168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 151}], {
             RGBColor[
             0.993387133731731, 0.9882640726525401, 0.5216085004580027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 158}], {
             RGBColor[
             0.9800342619233531, 0.9440497714523199, 0.3993219501987335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 227}], {
             RGBColor[
             0.938575627242547, 0.7772224976150608, 0.3484532074477743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 243}], {
             RGBColor[
             0.9930638030883503, 0.9893702834193423, 0.6170957515460108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 267}], {
             RGBColor[
             0.9863326193804454, 0.9652956100797496, 0.42378987957453285`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 275}], {
             RGBColor[
             0.9934918649537616, 0.988488082146513, 0.5330078476498631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 306}], {
             RGBColor[
             0.9907591627637876, 0.9802273803135753, 0.44098616473624064`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 311}], {
             RGBColor[
             0.968219783385752, 0.9723378888972093, 0.7261546431156709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 317}], {
             RGBColor[
             0.9809171903900029, 0.9818075942508837, 0.704661245071604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 344}], {
             RGBColor[
             0.8951574555210907, 0.9144640530486339, 0.7261209479166668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 346}], {
             RGBColor[
             0.9628939804411496, 0.8793991838550249, 0.36831841441515667`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 354}], {
             RGBColor[
             0.9885634630886997, 0.9875092771760242, 0.6916780318468024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 195}], {
             RGBColor[
             0.9466862860059448, 0.8233062195588146, 0.2917394710987816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 217}], {
             RGBColor[
             0.9546949336170217, 0.8676010394638691, 0.5876122312592547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 231}], {
             RGBColor[
             0.9608585765059697, 0.8698475585601582, 0.4543732132922221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 241}], {
             RGBColor[
             0.961015453073335, 0.8701831016750985, 0.4714482595199899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 242}], {
             RGBColor[
             0.959848088775265, 0.867686227480162, 0.344387859812412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 255}], {
             RGBColor[
             0.9251867605920043, 0.7410974663211218, 0.25866171536114035`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 312}], {
             RGBColor[
             0.8121019993816168, 0.756094809967806, 0.615345463483014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 331}], {
             RGBColor[
             0.9608110353189832, 0.8697458727683451, 0.4491986484789276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 359}], {
             RGBColor[
             0.9610819773235719, 0.8703253903197217, 0.47868901361818356`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 392}], {
             RGBColor[
             0.9187020019322263, 0.7153875591528248, 0.2534439263266337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 218}], {
             RGBColor[
             0.9765896488209547, 0.9429929406870534, 0.5924401092871141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 228}], {
             RGBColor[
             0.9699874619069633, 0.9385626785246246, 0.6257220090589966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 276}], {
             RGBColor[
             0.980076456417835, 0.9434469610998708, 0.46284738962125094`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.9804387421627649, 0.9442218536755683, 0.5022799571884264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 301}], {
             RGBColor[
             0.9794559386426875, 0.9421197363228011, 0.39530785918826195`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 305}], {
             RGBColor[
             0.9762702295143222, 0.9428608525950591, 0.5977337138286827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 313}], {
             RGBColor[
             0.9799699640950388, 0.9432191847894349, 0.4512563574793098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 339}], {
             RGBColor[
             0.9789163040609109, 0.9439550724210877, 0.553881410770293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 340}], {
             RGBColor[
             0.980557644387926, 0.9444761735123286, 0.5152217306177246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 361}], {
             RGBColor[
             0.9752325675332972, 0.9281157759994293, 0.35828363111436967`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 382}], {
             RGBColor[
             0.9788161415692356, 0.9439136526567212, 0.5555413624695738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 155}], {
             RGBColor[
             0.9264364165260313, 0.9406463040994519, 0.8445798291542971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 164}], {
             RGBColor[
             0.9937782651342473, 0.9891006631730717, 0.5641807398386882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 210}], {
             RGBColor[
             0.9599557839000061, 0.865812320259643, 0.48062846800122905`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 230}], {
             RGBColor[
             0.9946822270881766, 0.9910341463879532, 0.6625714199173793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 258}], {
             RGBColor[
             0.9914922952678217, 0.9905517577360057, 0.7762582931765484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 264}], {
             RGBColor[
             0.9921830535207303, 0.9908374040252609, 0.7648106413007967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 268}], {
             RGBColor[
             0.5869896831198518, 0.6486099183031302, 0.8181798911635094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 279}], {
             RGBColor[
             0.9937782651342473, 0.9891006631730717, 0.5641807398386882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 299}], {
             RGBColor[
             0.9865894469032941, 0.964851809666555, 0.5361924508466902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 300}], {
             RGBColor[
             0.9811466900259473, 0.9464921126991763, 0.5150483681565902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 328}], {
             RGBColor[
             0.9795518041492484, 0.9411121881400588, 0.5088525376945406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 152}], {
             RGBColor[
             0.901656351419451, 0.8804255508215066, 0.6465875282513087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 156}], {
             RGBColor[
             0.9742773751056919, 0.9367071871087614, 0.5939226865920173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 157}], {
             RGBColor[
             0.9635832320249671, 0.8888198319357797, 0.31302816245692666`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 160}], {
             RGBColor[
             0.9517877197225783, 0.8446535635846606, 0.29000154215546786`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 167}], {
             RGBColor[
             0.9779927392325454, 0.9367674233690579, 0.4250480728770255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 179}], {
             RGBColor[
             0.8295616848162202, 0.8239356084303099, 0.6394466639048553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 181}], {
             RGBColor[
             0.9573728753172241, 0.8667968443746595, 0.29449548944737136`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 206}], {
             RGBColor[
             0.9786981513267069, 0.9382762285103665, 0.5018278260276948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 211}], {
             RGBColor[
             0.9708090555771809, 0.9131942314814493, 0.3410991224749973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 238}], {
             RGBColor[
             0.9411947055024408, 0.8026557921145483, 0.28147815426394385`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 386}], {
             RGBColor[
             0.9779224571734415, 0.9366170971512411, 0.4173983044741636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 158}], {
             RGBColor[
             0.9804918550180715, 0.9450285168121637, 0.44912813462159046`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 186}], {
             RGBColor[
             0.9936547097452566, 0.990404157363153, 0.6646925852389733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 227}], {
             RGBColor[
             0.9390332203372652, 0.7782012429749046, 0.3982593918706313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 267}], {
             RGBColor[
             0.9867902124751637, 0.9662743554395934, 0.4735960639973898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 306}], {
             RGBColor[
             0.9912167558585059, 0.981206125673419, 0.4907923491590976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 308}], {
             RGBColor[
             0.9926349337660122, 0.9859899727594454, 0.4963017025293335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 311}], {
             RGBColor[
             0.9686773764804704, 0.9733166342570531, 0.7759608275385279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 317}], {
             RGBColor[
             0.9813747834847212, 0.9827863396107275, 0.754467429494461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 344}], {
             RGBColor[
             0.895615048615809, 0.9154427984084776, 0.7759271323395237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 346}], {
             RGBColor[
             0.963351573535868, 0.8803779292148687, 0.4181245988380136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 348}], {
             RGBColor[
             0.9913395152793473, 0.9894467649537158, 0.7030613490703053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 354}], {
             RGBColor[
             0.9890210561834181, 0.988488022535868, 0.7414842162696594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 156}], {
             RGBColor[
             0.9135191257371528, 0.932254973564475, 0.9320219640645637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 157}], {
             RGBColor[
             0.902824982656428, 0.8843676183914932, 0.6511274399294731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 160}], {
             RGBColor[
             0.8910294703540391, 0.8402013500403742, 0.6281008196280143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 179}], {
             RGBColor[
             0.768803435447681, 0.8194833948860234, 0.9775459413774017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 181}], {
             RGBColor[
             0.896614625948685, 0.862344630830373, 0.6325947669199178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 238}], {
             RGBColor[
             0.8804364561339015, 0.7982035785702619, 0.6195774317364904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 245}], {
             RGBColor[
             0.9168216061586283, 0.9336206340886306, 0.8772913169353496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 168}], {
             RGBColor[
             0.9934886352663331, 0.9884811741716747, 0.532656316104583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 175}], {
             RGBColor[
             0.9936254689960837, 0.9887738476835991, 0.5475498231480483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 211}], {
             RGBColor[
             0.9864184841679826, 0.9651508169436165, 0.4610646838917934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 216}], {
             RGBColor[
             0.9420145372441043, 0.9521161235148281, 0.7689136482265462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 229}], {
             RGBColor[
             0.9635318228086174, 0.9692734229528135, 0.770965986132397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 294}], {
             RGBColor[
             0.9777281820325727, 0.9799195508411098, 0.7489637073992581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 329}], {
             RGBColor[
             0.9525899769397399, 0.9605486920654647, 0.7699223431055223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 341}], {
             RGBColor[
             0.9941383863071602, 0.9898709259480963, 0.6033777070999886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 343}], {
             RGBColor[
             0.9296073164092888, 0.9422229424061839, 0.7677302364272647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 358}], {
             RGBColor[
             0.9926081732980604, 0.9897891288371852, 0.6687881110320815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 379}], {
             RGBColor[
             0.9923793768267324, 0.9896945156164898, 0.6725798606682756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 207}], {
             RGBColor[
             0.907732756884078, 0.9244259780910083, 0.7368838546564083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 231}], {
             RGBColor[
             0.9084569347051412, 0.9259749212246537, 0.815706141371694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 369}], {
             RGBColor[
             0.8815481648146137, 0.9082567203776146, 0.9840612481567345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 372}], {
             RGBColor[
             0.8541188583129866, 0.88651520945273, 0.9859478132584404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 387}], {
             RGBColor[
             0.9088049295384839, 0.9267192469854988, 0.8535832314058713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 392}], {
             RGBColor[
             0.8663003601313979, 0.7715149218173205, 0.6147768544061055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 249}], {
             RGBColor[
             0.9232333084826682, 0.9314148557136133, 0.6983468713154357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 268}], {
             RGBColor[
             0.5183737334061795, 0.5974303857963217, 0.9599009379907877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 279}], {
             RGBColor[
             0.925162315420575, 0.9379211306662631, 0.7059017866659665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.9179734971896218, 0.9136722771597465, 0.6779134976739686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 300}], {
             RGBColor[
             0.9125307403122751, 0.8953125801923679, 0.6567694149838685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 370}], {
             RGBColor[
             0.9177287220367651, 0.9128465930932215, 0.6769625924270288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 371}], {
             RGBColor[
             0.9078794113065702, 0.9288089233676315, 0.9711922237819025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 160}], {
             RGBColor[
             0.96365049404028, 0.896482986327629, 0.5754359779687227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.8414244591339219, 0.8757650311732783, 0.9248810997181101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 181}], {
             RGBColor[
             0.9692356496349259, 0.918626267117628, 0.5799299252606263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 245}], {
             RGBColor[
             0.9894426298448692, 0.9899022703758855, 0.8246264752760579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 352}], {
             RGBColor[
             0.9893734861488745, 0.9875658382409367, 0.6580168007791742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 396}], {
             RGBColor[
             0.9905841331460865, 0.9901552897527857, 0.7897882551784903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 160}], {
             RGBColor[
             0.9529563509595552, 0.8485956311546473, 0.29454145383363217`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 167}], {
             RGBColor[
             0.9791613704695223, 0.9407094909390448, 0.4295879845551899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 168}], {
             RGBColor[
             0.9790478379125084, 0.9404666562794943, 0.41723066636595124`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 203}], {
             RGBColor[
             0.9787916741179015, 0.9399187478249624, 0.3893488181826693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 206}], {
             RGBColor[
             0.9798667825636839, 0.9422182960803532, 0.5063677377058592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 211}], {
             RGBColor[
             0.9719776868141579, 0.917136299051436, 0.3456390341531616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 238}], {
             RGBColor[
             0.9423633367394177, 0.806597859684535, 0.2860180659421082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 341}], {
             RGBColor[
             0.9796975889533355, 0.941856408055916, 0.4879520573613568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 358}], {
             RGBColor[
             0.9781673759442356, 0.9417746109450047, 0.5533624612934497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 386}], {
             RGBColor[
             0.9790910884104185, 0.9405591647212277, 0.4219382161523279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 267}], {
             RGBColor[
             0.9734373406667859, 0.9220600542393733, 0.3513095137381206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 306}], {
             RGBColor[
             0.9778638840501281, 0.9369918244731988, 0.3685057988998284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 308}], {
             RGBColor[
             0.9792820619576343, 0.9417756715592253, 0.37401515227006427`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 311}], {
             RGBColor[
             0.9553245046720925, 0.9291023330568329, 0.6536742772792586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 317}], {
             RGBColor[
             0.9680219116763433, 0.9385720384105074, 0.6321808792351917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 344}], {
             RGBColor[
             0.8822621768074312, 0.8712284972082576, 0.6536405820802544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 346}], {
             RGBColor[
             0.94999870172749, 0.8361636280146485, 0.2958380485787444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 348}], {
             RGBColor[
             0.9779866434709694, 0.9452324637534955, 0.580774798811036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 354}], {
             RGBColor[
             0.9756681843750401, 0.9442737213356478, 0.6191976660103902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 374}], {
             RGBColor[
             0.9762163537135784, 0.9314343177894975, 0.36210545465233046`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 250}], {
             RGBColor[
             0.99054450736075, 0.989568005427383, 0.7489466958367945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 265}], {
             RGBColor[
             0.9901382204094411, 0.9886989987204455, 0.7047248684992509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 321}], {
             RGBColor[
             0.9771735459650333, 0.9820762129950931, 0.904695452302033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 375}], {
             RGBColor[
             0.9887630441424142, 0.9896212442233645, 0.8358889690771587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 381}], {
             RGBColor[
             0.9906735265637976, 0.9904112778017653, 0.8042273311848172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[
             0.9467459942518123, 0.8265726435935271, 0.27600878082407687`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 238}], {
             RGBColor[
             0.9305678244370288, 0.7624315913334159, 0.26299144564064936`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 245}], {
             RGBColor[
             0.9669529744617555, 0.8978486468517847, 0.5207053308395085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 196}], {
             RGBColor[
             0.9734891138617896, 0.929912848754601, 0.5622770686550811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 214}], {
             RGBColor[
             0.9754667741530373, 0.9286670284181477, 0.37949773513840024`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 253}], {
             RGBColor[
             0.9620298321992924, 0.8835798495681548, 0.30699349746912286`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 283}], {
             RGBColor[
             0.9761628711915862, 0.9301559095973976, 0.4552636019715009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 332}], {
             RGBColor[
             0.9724723708265504, 0.9188049843825654, 0.3475607881280691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 334}], {
             RGBColor[
             0.9393792595414576, 0.7967507139601657, 0.27328572875835183`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.9684426589144748, 0.9052118198817825, 0.33190611829689676`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 364}], {
             RGBColor[
             0.7702491516129382, 0.7710177362705826, 0.625890020553325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 366}], {
             RGBColor[
             0.9716794403354219, 0.9161302436470561, 0.3444804029023938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 389}], {
             RGBColor[
             0.8345995873084187, 0.8222064439014836, 0.6316764626821335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 183}], {
             RGBColor[
             0.9850307180406288, 0.970804486149193, 0.6206552227592417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 270}], {
             RGBColor[
             0.937223224489866, 0.9345907251526282, 0.6879426322440378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 280}], {
             RGBColor[
             0.982375409905272, 0.9522102605392448, 0.3860322249168924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 291}], {
             RGBColor[
             0.9865207034413327, 0.9661933089975857, 0.40213590753148903`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 336}], {
             RGBColor[
             0.9510766843309537, 0.945637097987762, 0.6892639876108104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 357}], {
             RGBColor[
             0.9642669966864215, 0.9558869127319406, 0.6812379114012038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 368}], {
             RGBColor[
             0.9873564555189458, 0.9690124969992941, 0.4053826465344789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 171}], {
             RGBColor[
             0.9912595566687061, 0.9888213303737473, 0.6613274507459085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 240}], {
             RGBColor[
             0.9878863859745889, 0.9892587235418814, 0.8504174636366372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 272}], {
             RGBColor[
             0.991556396981279, 0.9894562417871811, 0.6936366868833902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 342}], {
             RGBColor[
             0.9306713113237675, 0.7507243040037312, 0.5204346026903981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 374}], {
             RGBColor[
             0.9873273837783487, 0.9759614761130897, 0.6116739498779392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 210}], {
             RGBColor[
             0.95868168279455, 0.8630871468264543, 0.34195042551289856`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 230}], {
             RGBColor[
             0.9934081259827204, 0.9883089729547645, 0.5238933774290488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 258}], {
             RGBColor[
             0.9902181941623656, 0.987826584302817, 0.6375802506882178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 264}], {
             RGBColor[
             0.9909089524152742, 0.9881122305920722, 0.6261325988124661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 279}], {
             RGBColor[
             0.9925041640287912, 0.9863754897398829, 0.4255026973503576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 328}], {
             RGBColor[
             0.9782777030437922, 0.93838701470687, 0.3701744952062101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 170}], {
             RGBColor[
             0.9844532174481089, 0.9575245047732226, 0.5382081923745483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 172}], {
             RGBColor[
             0.8532022181855137, 0.8832627974549467, 0.8480482483423423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 184}], {
             RGBColor[
             0.9947093617970069, 0.9910921847864012, 0.6655248655175391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 190}], {
             RGBColor[
             0.9906945303745752, 0.9903914182616509, 0.8018043122067617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 192}], {
             RGBColor[
             0.9922636143136825, 0.9910402747940896, 0.7758005306766886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 221}], {
             RGBColor[
             0.9945451078601895, 0.9907408622241691, 0.6476468381527594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 226}], {
             RGBColor[
             0.9872262108460642, 0.9668784626343387, 0.5489807480897417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 252}], {
             RGBColor[
             0.994586357059796, 0.9908290900911938, 0.652136558969383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 274}], {
             RGBColor[
             0.994544869771345, 0.9907403529762056, 0.6476209236513664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 288}], {
             RGBColor[
             0.9915570397417417, 0.9907480880504538, 0.7875102998901242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 318}], {
             RGBColor[
             0.9876449271317116, 0.9682908909850862, 0.5506073817915458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 322}], {
             RGBColor[
             0.9888757655025502, 0.972442797824518, 0.5553889564379313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 351}], {
             RGBColor[
             0.9907772793861074, 0.9788570506504484, 0.5627759788047848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 355}], {
             RGBColor[
             0.9945473238671618, 0.9907456020390102, 0.6478880368360863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 399}], {
             RGBColor[
             0.9708679065594881, 0.9088958275021113, 0.5000259054792314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 169}], {
             RGBColor[
             0.7655589756139753, 0.7530380326688202, 0.6189117992502648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 246}], {
             RGBColor[
             0.7868010241729989, 0.8268510889801604, 0.6901909198903033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 326}], {
             RGBColor[
             0.788685709756064, 0.832033959636319, 0.8470889926752138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 363}], {
             RGBColor[
             0.7804515084180648, 0.8276746790209315, 0.9408187946857977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 383}], {
             RGBColor[
             0.7867199026601239, 0.8312210478832098, 0.8796675036006263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 168}], {
             RGBColor[
             0.9934573451200865, 0.9884142477127725, 0.52925057678605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.9932011813254796, 0.9878663392582407, 0.5013687286027682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 211}], {
             RGBColor[
             0.9863871940217361, 0.9650838904847143, 0.45765894457326045`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 216}], {
             RGBColor[
             0.9419832470978577, 0.9520491970559259, 0.7655079089080132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 238}], {
             RGBColor[
             0.9567728439469959, 0.8545454511178132, 0.39803797636220706`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 341}], {
             RGBColor[
             0.9941070961609136, 0.9898039994891942, 0.5999719677814557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 358}], {
             RGBColor[
             0.9925768831518138, 0.989722202378283, 0.6653823717135485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 211}], {
             RGBColor[
             0.9862736614647222, 0.9648410558251639, 0.4453016263840218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 216}], {
             RGBColor[
             0.9418697145408439, 0.9518063623963755, 0.7531505907187745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 238}], {
             RGBColor[
             0.956659311389982, 0.8543026164582628, 0.3856806581729684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 341}], {
             RGBColor[
             0.9939935636038997, 0.9895611648296437, 0.587614649592217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 379}], {
             RGBColor[
             0.9922345541234718, 0.9893847544980372, 0.656816803160504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 218}], {
             RGBColor[
             0.9679132901942662, 0.9115669070817818, 0.5699763212027649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 222}], {
             RGBColor[
             0.9643318166673416, 0.9093894880174632, 0.5981449411385729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 224}], {
             RGBColor[
             0.8860967283772961, 0.50802140178661, 0.22385865056394666`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 276}], {
             RGBColor[
             0.9714000977911466, 0.9120209274945992, 0.4403836015369017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 326}], {
             RGBColor[
             0.9717900317157296, 0.9131700393286197, 0.5057286815066624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 361}], {
             RGBColor[
             0.9665562089066086, 0.8966897423941578, 0.33581984303002044`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 363}], {
             RGBColor[
             0.9635558303777305, 0.9088107587132321, 0.5994584835172463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 382}], {
             RGBColor[
             0.9701397829425469, 0.9124876190514497, 0.5330775743852245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 383}], {
             RGBColor[
             0.9698242246197896, 0.9123571275755105, 0.538307192432075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 393}], {
             RGBColor[
             0.9350903035565472, 0.7803617140154777, 0.2666303384964425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[
             0.9814679204360345, 0.9563185528957403, 0.5897572210429856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 208}], {
             RGBColor[
             0.9837028612529692, 0.9572427583589018, 0.5527184678649479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 221}], {
             RGBColor[
             0.9837494139825416, 0.9560191403258198, 0.46160352851905645`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 225}], {
             RGBColor[
             0.973388433119662, 0.9218950775988866, 0.35111951715295997`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 235}], {
             RGBColor[
             0.9829799740563923, 0.954249597379387, 0.38838084248163485`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 322}], {
             RGBColor[
             0.9780800716249023, 0.9377210759261687, 0.36934564680422827`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 335}], {
             RGBColor[
             0.9844117817641961, 0.9574358780351234, 0.5336981738920459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 349}], {
             RGBColor[
             0.9835787647729652, 0.9571914412752862, 0.5547750676900092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 351}], {
             RGBColor[
             0.9799815855084595, 0.944135328752099, 0.3767326691710818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 355}], {
             RGBColor[
             0.9837516299895138, 0.9560238801406609, 0.46184472720238334`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 186}], {
             RGBColor[
             0.993311381331121, 0.9896698126011445, 0.6273234061376827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 240}], {
             RGBColor[
             0.9897848993040608, 0.9882115216565008, 0.685766339569007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 272}], {
             RGBColor[
             0.9934549103107508, 0.9884090399018004, 0.52898556281576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 308}], {
             RGBColor[
             0.9922916053518767, 0.9852556279974369, 0.4589325234280428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 342}], {
             RGBColor[
             0.9325698246532393, 0.7496771021183506, 0.35578347862276793`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 348}], {
             RGBColor[
             0.9909961868652117, 0.9887124201917071, 0.6656921699690146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 374}], {
             RGBColor[
             0.9892258971078206, 0.974914274227709, 0.44702282581030905`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 192}], {
             RGBColor[
             0.8502169211734394, 0.8820568455774644, 0.8995972770107796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 194}], {
             RGBColor[
             0.8226133580496158, 0.7753003203900772, 0.6188276656658249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 221}], {
             RGBColor[
             0.8524984147199464, 0.881757433007544, 0.7714435844868504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 256}], {
             RGBColor[
             0.8528111871602988, 0.8824264216313131, 0.805486934411457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 316}], {
             RGBColor[
             0.841986649320905, 0.8767637444051035, 0.9513707965520668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 351}], {
             RGBColor[
             0.8487305862458643, 0.8698736214338232, 0.6865727251388758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 399}], {
             RGBColor[
             0.828821213419245, 0.7999123982854861, 0.6238226518133224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 198}], {
             RGBColor[
             0.9937378029632131, 0.9890141186805825, 0.559776682225194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 203}], {
             RGBColor[
             0.9938598220297516, 0.9892751051258881, 0.5730577046035121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 266}], {
             RGBColor[
             0.9943926611786791, 0.9916094742658955, 0.7178945877035245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 313}], {
             RGBColor[
             0.9944060362243519, 0.9904434020574119, 0.6325097488424922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 329}], {
             RGBColor[
             0.9532173274977653, 0.9618905314742099, 0.8382055797877334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 340}], {
             RGBColor[
             0.9949937165172391, 0.9917003907803057, 0.6964751219809069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 341}], {
             RGBColor[
             0.9947657368651857, 0.9912127653568417, 0.6716609437821996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 358}], {
             RGBColor[
             0.9932355238560858, 0.9911309682459304, 0.7370713477142925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 204}], {
             RGBColor[
             0.9836418257991806, 0.9557943573522791, 0.44943937564612085`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 216}], {
             RGBColor[
             0.9420065482705946, 0.9520990359082999, 0.7680440977622398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 229}], {
             RGBColor[
             0.9635238338351075, 0.9692563353462853, 0.7700964356680907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 294}], {
             RGBColor[
             0.9777201930590629, 0.9799024632345816, 0.7480941569349517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 307}], {
             RGBColor[
             0.9939795260869526, 0.9903424344968765, 0.6450592979427212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 343}], {
             RGBColor[
             0.929599327435779, 0.9422058547996557, 0.7668606859629583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 379}], {
             RGBColor[
             0.9923713878532225, 0.9896774280099616, 0.6717103102039693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 205}], {
             RGBColor[
             0.8487847360435055, 0.6659473999465897, 0.5947694193529416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 232}], {
             RGBColor[
             0.9212563998284152, 0.7051426107502798, 0.29515857431957787`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 277}], {
             RGBColor[
             0.9239031188577971, 0.7140706155155654, 0.30544057795777624`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 298}], {
             RGBColor[
             0.9111039561840639, 0.6708960344307544, 0.25571824788938313`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 320}], {
             RGBColor[
             0.9144211024831932, 0.682085547800707, 0.26860473487098385`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 347}], {
             RGBColor[
             0.8021946852264699, 0.629411786539977, 0.5901626744405062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 373}], {
             RGBColor[
             0.9264861353212528, 0.7227251150079401, 0.3204598634755317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 390}], {
             RGBColor[
             0.910455862699002, 0.6687098629260537, 0.2532005270821027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 219}], {
             RGBColor[
             0.8998722997861142, 0.922911437207437, 0.9873188916398212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 248}], {
             RGBColor[
             0.8986990914926021, 0.8392527421619869, 0.6272504998687101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 260}], {
             RGBColor[
             0.8545521192711363, 0.6324190755163106, 0.5902812420978004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 285}], {
             RGBColor[
             0.9031916176747468, 0.9253869790538949, 0.9817001522711226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 200}], {
             RGBColor[
             0.9848433603436102, 0.9615057718851494, 0.560023377888915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 278}], {
             RGBColor[
             0.9855758111372082, 0.961506803680603, 0.5259430694439822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 296}], {
             RGBColor[
             0.939429459424004, 0.7911175339201093, 0.3012950168100556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 330}], {
             RGBColor[
             0.912783900948993, 0.9070781448726081, 0.6738052806158072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 367}], {
             RGBColor[
             0.9767354286305344, 0.9331852793689768, 0.36412196268563196`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 398}], {
             RGBColor[
             0.9846278931151221, 0.9594793028805744, 0.42276804261183665`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 209}], {
             RGBColor[
             0.8258899316204221, 0.8112861719932263, 0.6265562144232857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 245}], {
             RGBColor[
             0.8447269395553975, 0.877130691697434, 0.8701504525888959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 286}], {
             RGBColor[
             0.8457448537847151, 0.8771193665463124, 0.8218603247183807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 290}], {
             RGBColor[
             0.844957285359903, 0.8754348373210219, 0.7361383619865132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 352}], {
             RGBColor[
             0.8446577958594028, 0.8747942595624851, 0.7035407780920122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 386}], {
             RGBColor[
             0.8450695412016715, 0.8756749412157578, 0.7483567176002563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 232}], {
             RGBColor[
             0.979305314718129, 0.9418541085803815, 0.3741054848536707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 249}], {
             RGBColor[
             0.9825591329000898, 0.9528300013409758, 0.38674595405858325`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 268}], {
             RGBColor[
             0.577699557823601, 0.6188455314236841, 0.6483000207339353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 370}], {
             RGBColor[
             0.9770545464541867, 0.9342617387205838, 0.36536167517017637`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 238}], {
             RGBColor[
             0.9361529800316748, 0.7845748721234148, 0.26748539293255286`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 245}], {
             RGBColor[
             0.9725381300564014, 0.9199919276417836, 0.5251992781314121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 187}], {
             RGBColor[
             0.9424719614369191, 0.9530365615155094, 0.8140041504479927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 208}], {
             RGBColor[
             0.99410505848152, 0.9911228307134463, 0.6959320956242432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 323}], {
             RGBColor[
             0.9946458582805657, 0.9909563571859241, 0.6586128996512063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 377}], {
             RGBColor[
             0.9936322613760712, 0.9887883758975773, 0.5482891317919687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 388}], {
             RGBColor[
             0.9907350614110998, 0.9792003465585026, 0.5213109482458037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 395}], {
             RGBColor[
             0.9948333246491415, 0.9913573287925502, 0.6790174569623519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 270}], {
             RGBColor[
             0.9398032407183035, 0.9529309734811573, 0.9222731352456893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 291}], {
             RGBColor[
             0.9891007196697703, 0.9845335573261148, 0.6364664105331405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 357}], {
             RGBColor[
             0.966847012914859, 0.9742271610604697, 0.9155684144028553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 368}], {
             RGBColor[
             0.9899364717473833, 0.9873527453278232, 0.6397131495361303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 185}], {
             RGBColor[
             0.9853209639577296, 0.9611176028742994, 0.4849486352473487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 190}], {
             RGBColor[
             0.9901549808458253, 0.9892373763764801, 0.7430776757160495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 226}], {
             RGBColor[
             0.9866866613173143, 0.965724420749168, 0.49025411159902954`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 252}], {
             RGBColor[
             0.9940468075310461, 0.989675048206023, 0.5934099224786709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 274}], {
             RGBColor[
             0.9940053202425951, 0.9895863110910348, 0.5888942871606542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 288}], {
             RGBColor[
             0.9910174902129918, 0.989594046165283, 0.728783663399412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 318}], {
             RGBColor[
             0.9871053776029617, 0.9671368490999155, 0.49188074530083353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 190}], {
             RGBColor[
             0.9813061325352979, 0.9604168363495491, 0.6212280819365713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 226}], {
             RGBColor[
             0.9778378130067868, 0.936903880722237, 0.36840451781955136`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 252}], {
             RGBColor[
             0.9851979592205187, 0.960854508179092, 0.47156032869919273`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 274}], {
             RGBColor[
             0.9851564719320678, 0.9607657710641038, 0.46704469338117605`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 288}], {
             RGBColor[
             0.9821686419024643, 0.960773506138352, 0.6069340696199338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 318}], {
             RGBColor[
             0.9782565292924342, 0.9383163090729845, 0.37003115152135535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 357}], {
             RGBColor[
             0.961277703603927, 0.9458033252452929, 0.6696250722563439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 272}], {
             RGBColor[
             0.9936082216436938, 0.9903047240145781, 0.6596326422751644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 306}], {
             RGBColor[
             0.9910267387773133, 0.9823674650241883, 0.5840702495172112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 308}], {
             RGBColor[
             0.9924449166848195, 0.9871513121102147, 0.5895796028874472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 342}], {
             RGBColor[
             0.9327231359861823, 0.7515727862311283, 0.4864305580821723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 348}], {
             RGBColor[
             0.9911494981981546, 0.9906081043044849, 0.7963392494284189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 374}], {
             RGBColor[
             0.9893792084407635, 0.9768099583404868, 0.5776699052697134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 378}], {
             RGBColor[
             0.9931080420616372, 0.9892348904644723, 0.6051911815188742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 208}], {
             RGBColor[
             0.9421151018908768, 0.9535964646449937, 0.8713441078128001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 302}], {
             RGBColor[
             0.9309670192483919, 0.9154366714741347, 0.6665065667551009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 377}], {
             RGBColor[
             0.941642304785428, 0.9512620098291247, 0.7237011439805257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 388}], {
             RGBColor[
             0.9387451048204566, 0.9416739804900501, 0.6967229604343607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 201}], {
             RGBColor[
             0.9842506361197092, 0.9849799857562651, 0.7534746029866435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 264}], {
             RGBColor[
             0.9916142922742606, 0.9896208812296451, 0.7029044896101044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 273}], {
             RGBColor[
             0.9919317487345154, 0.9897521576342194, 0.6976434145126984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 281}], {
             RGBColor[
             0.9795419677539837, 0.9417810501093535, 0.44911770350667846`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 293}], {
             RGBColor[
             0.914793386508198, 0.9305994599885687, 0.7816174038220758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 394}], {
             RGBColor[
             0.9712380363709108, 0.9752752101697878, 0.7755015401317958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 207}], {
             RGBColor[
             0.9762876490271608, 0.9784767798079652, 0.7221692952500195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 241}], {
             RGBColor[
             0.9771687034155896, 0.980361266056551, 0.8180666281930729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 263}], {
             RGBColor[
             0.9656360905302048, 0.9429178178583197, 0.6492219246840121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 280}], {
             RGBColor[
             0.9708854422806166, 0.9606251139188634, 0.6696146649774636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 291}], {
             RGBColor[
             0.9750307358166774, 0.9746081623772043, 0.6857183475920602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 336}], {
             RGBColor[
             0.9395867167062985, 0.9540519513673805, 0.9728464276713816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 359}], {
             RGBColor[
             0.9772352276658264, 0.9805035547011742, 0.8253073822912665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 226}], {
             RGBColor[
             0.9826718298948827, 0.9650236542244177, 0.6265335582882521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 252}], {
             RGBColor[
             0.9900319761086145, 0.9889742816812728, 0.7296893691678935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 274}], {
             RGBColor[
             0.9899904888201636, 0.9888855445662845, 0.7251737338498768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 288}], {
             RGBColor[
             0.98700265879056, 0.9888932796405328, 0.8650631100886346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 318}], {
             RGBColor[
             0.9830905461805299, 0.9664360825751652, 0.6281601919900561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 225}], {
             RGBColor[
             0.9841793493696587, 0.9566065806347819, 0.5366428115009143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 235}], {
             RGBColor[
             0.9937708903063889, 0.9889611004152823, 0.5739041368295893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 261}], {
             RGBColor[
             0.9683733746898101, 0.8990145627314395, 0.4975025754883048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 322}], {
             RGBColor[
             0.9888709878748989, 0.972432578962064, 0.5548689411521827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 327}], {
             RGBColor[
             0.974336329244933, 0.978508501326903, 0.84346046164377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 335}], {
             RGBColor[
             0.9952026980141927, 0.9921473810710189, 0.7192214682400002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 349}], {
             RGBColor[
             0.9943696810229619, 0.9919029443111815, 0.7402983620379636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 355}], {
             RGBColor[
             0.9945425462395104, 0.9907353831765562, 0.6473680215503377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 208}], {
             RGBColor[
             0.9915132581185429, 0.990758528379769, 0.7903108061670883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 221}], {
             RGBColor[
             0.9915598108481152, 0.9895349103466868, 0.6991958668211967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[
             0.9811988299852357, 0.9554108476197536, 0.5887118554551002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 322}], {
             RGBColor[
             0.9858904684904759, 0.9712368459470357, 0.6069379851063685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 335}], {
             RGBColor[
             0.9922221786297697, 0.9909516480559906, 0.7712905121941862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 349}], {
             RGBColor[
             0.9913891616385389, 0.9907072112961532, 0.7923674059921495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 351}], {
             RGBColor[
             0.9877919823740331, 0.9776510987729661, 0.614325007473222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 355}], {
             RGBColor[
             0.9915620268550874, 0.9895396501615279, 0.6994370655045237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 399}], {
             RGBColor[
             0.9678826095474138, 0.907689875624629, 0.5515749341476687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 195}], {
             RGBColor[
             0.9805139138810681, 0.944501314413992, 0.5003705815128939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 242}], {
             RGBColor[
             0.9936757166503883, 0.9888813223353394, 0.5530189702265242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 253}], {
             RGBColor[
             0.9804177682278183, 0.9441769925495075, 0.49999707380560154`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 255}], {
             RGBColor[
             0.9590143884671277, 0.8622925611762994, 0.46729282577525266`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 283}], {
             RGBColor[
             0.9945508072201121, 0.9907530525787502, 0.6482671783079796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 312}], {
             RGBColor[
             0.84592962725674, 0.8772899048229835, 0.8239765738971263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 332}], {
             RGBColor[
             0.9908603068550763, 0.9794021273639181, 0.5405643644645478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 356}], {
             RGBColor[
             0.9868305949430007, 0.9658089628631352, 0.5249096946333754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 360}], {
             RGBColor[
             0.9565080329349419, 0.8523556966846528, 0.4652761532823303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 364}], {
             RGBColor[
             0.7886370876414641, 0.8316148792519352, 0.8188935968898037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 380}], {
             RGBColor[
             0.9946184820993176, 0.9908978023023904, 0.6556331712685344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 389}], {
             RGBColor[
             0.8529875233369446, 0.8828035868828362, 0.8246800390186122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 221}], {
             RGBColor[
             0.9639562477242916, 0.8827783851592996, 0.4184262554762421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 233}], {
             RGBColor[
             0.8845518256955363, 0.5233008453903425, 0.2234953831392633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 256}], {
             RGBColor[
             0.964269020164644, 0.8834473737830689, 0.4524696054008487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 316}], {
             RGBColor[
             0.9534444823252501, 0.8777846965568592, 0.5983534675414586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 399}], {
             RGBColor[
             0.9402790464235902, 0.8009333504372418, 0.2708053228027141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 241}], {
             RGBColor[
             0.9805374732009081, 0.944551705416917, 0.502934868086205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 242}], {
             RGBColor[
             0.9793701089028379, 0.9420548312219805, 0.3758744683786271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.9447087807195773, 0.8154660700629404, 0.29014832392735546`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 263}], {
             RGBColor[
             0.9690048603155234, 0.9071082572186857, 0.33409016457714424`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 312}], {
             RGBColor[
             0.8316240195091897, 0.8304634137096245, 0.6468320720492291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 356}], {
             RGBColor[
             0.9725249871954504, 0.9189824717497762, 0.34776519278547824`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 359}], {
             RGBColor[
             0.9806039974511449, 0.9446939940615402, 0.5101756221843987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 360}], {
             RGBColor[
             0.9422024251873915, 0.8055292055712938, 0.2881316514344331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 380}], {
             RGBColor[
             0.9803128743517672, 0.9440713111890315, 0.4784886694206371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 389}], {
             RGBColor[
             0.8386819155893942, 0.8359770957694772, 0.647535537170715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 206}], {
             RGBColor[
             0.9919581400087181, 0.9906834352997482, 0.7641068039494779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 214}], {
             RGBColor[
             0.9909122384432603, 0.9884463576081031, 0.6502668731056476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 286}], {
             RGBColor[
             0.9918577584384962, 0.9904687292711771, 0.753180889514071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 332}], {
             RGBColor[
             0.9879178351167732, 0.9785843135725207, 0.6183299260953165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 334}], {
             RGBColor[
             0.9548247238316805, 0.856530043150121, 0.5440548667255992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 366}], {
             RGBColor[
             0.9871249046256448, 0.9759095728370114, 0.6152495408696412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 386}], {
             RGBColor[
             0.9911824458554526, 0.9890243039406227, 0.6796772823959467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 217}], {
             RGBColor[
             0.9856357059866203, 0.9804877757685664, 0.6634585360353156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 231}], {
             RGBColor[
             0.9917993488755683, 0.9827342948648552, 0.530219518068283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 254}], {
             RGBColor[
             0.9873997208794255, 0.9815439315177001, 0.6488541013508996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 314}], {
             RGBColor[
             0.9796310600143033, 0.9760095206341177, 0.6736228354039588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 369}], {
             RGBColor[
             0.9648905789850407, 0.9650160940178161, 0.6985746248533236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 392}], {
             RGBColor[
             0.949642774301825, 0.828274295457522, 0.3292902311026946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 203}], {
             RGBColor[
             0.9927094659073203, 0.9868146096988528, 0.4478485398519296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 206}], {
             RGBColor[
             0.9937845743531027, 0.9891141579542435, 0.5648674593751194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 214}], {
             RGBColor[
             0.9927386727876448, 0.9868770802625985, 0.4510275285312891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 266}], {
             RGBColor[
             0.9932423050562478, 0.9891489788388601, 0.592685422951942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 310}], {
             RGBColor[
             0.9912917115430613, 0.9883423582931907, 0.6250118054396381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 384}], {
             RGBColor[
             0.9900096993443006, 0.9779103935487565, 0.42012172649473956`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 215}], {
             RGBColor[
             0.8926246898121395, 0.9061836868068986, 0.6938969883071663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 222}], {
             RGBColor[
             0.8886928530831055, 0.9131238212391886, 0.9495889869968099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 223}], {
             RGBColor[
             0.8928532156803438, 0.9155406258108525, 0.9118266770490117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 224}], {
             RGBColor[
             0.81045776479306, 0.5117557350083354, 0.5753026964221838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 247}], {
             RGBColor[
             0.8943193085133082, 0.9161468928741505, 0.8875297246801638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 259}], {
             RGBColor[
             0.8944970318249787, 0.916220386030807, 0.8845843894725959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 271}], {
             RGBColor[
             0.8927896982534493, 0.9155143597225082, 0.9128793251904861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 287}], {
             RGBColor[
             0.8943732947577738, 0.9161692175736202, 0.8866350328974466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 292}], {
             RGBColor[
             0.8954980001890713, 0.9151924436590968, 0.7631871334282714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 345}], {
             RGBColor[
             0.855410669090558, 0.8877279206115114, 0.986022555955107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 350}], {
             RGBColor[
             0.8762269108808156, 0.9038267419558277, 0.9706905755068457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 353}], {
             RGBColor[
             0.8831451052740809, 0.9089863200068213, 0.958979876953125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 393}], {
             RGBColor[
             0.8594513399723112, 0.7840960472372029, 0.6180743843546797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 400}], {
             RGBColor[
             0.8841954016024209, 0.9097696292887949, 0.9572019992303996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 234}], {
             RGBColor[
             0.9908455539024009, 0.9817525801410176, 0.5833407664456718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 296}], {
             RGBColor[
             0.9480532958796406, 0.8211782942731336, 0.4992006245177515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 298}], {
             RGBColor[
             0.9776504116498, 0.9372422669562588, 0.5320801304878461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 320}], {
             RGBColor[
             0.9809675579489292, 0.9484317803262114, 0.5449666174694469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 330}], {
             RGBColor[
             0.9214077374046297, 0.9371389052256323, 0.8717108883235032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 347}], {
             RGBColor[
             0.8687411406922061, 0.8957580190654815, 0.8665245570389691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 367}], {
             RGBColor[
             0.9853592650861711, 0.9632460397220011, 0.5620275703933278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 398}], {
             RGBColor[
             0.9932517295707588, 0.9895400632335987, 0.6206736503195325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 273}], {
             RGBColor[
             0.9822675411074606, 0.9853393523754558, 0.8720715385537074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 281}], {
             RGBColor[
             0.969877760126929, 0.93736824485059, 0.6235458275476876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 293}], {
             RGBColor[
             0.9051291788811432, 0.9261866547298051, 0.9560455278630849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 303}], {
             RGBColor[
             0.983958402389861, 0.9843549273574823, 0.721666764950194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 394}], {
             RGBColor[
             0.961573828743856, 0.9708624049110242, 0.949929664172805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 212}], {
             RGBColor[
             0.8905001809404298, 0.9149040313545233, 0.9678993209677271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 234}], {
             RGBColor[
             0.9739956448792694, 0.9707268927547418, 0.6808700300522348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 239}], {
             RGBColor[
             0.9399451004143833, 0.845267897513701, 0.6037873321874057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 269}], {
             RGBColor[
             0.7263167466353777, 0.7843425492267024, 0.9531034426270464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 289}], {
             RGBColor[
             0.9732450221079172, 0.9791463263348235, 0.9113454184690102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 309}], {
             RGBColor[
             0.9769630743584157, 0.9797148409971347, 0.7792919275734116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 362}], {
             RGBColor[
             0.9771888286382335, 0.9801977065744061, 0.8038638877376665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 365}], {
             RGBColor[
             0.9364298187657114, 0.8313309771748851, 0.6009588540586188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 206}], {
             RGBColor[
             0.9939065934196412, 0.9893751443995492, 0.5781484817534375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 211}], {
             RGBColor[
             0.9860174976701153, 0.964293147370632, 0.41741977820073994`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 216}], {
             RGBColor[
             0.9416135507462369, 0.9512584539418436, 0.7252687425354927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 266}], {
             RGBColor[
             0.9933643241227863, 0.9894099652841657, 0.6059664453302601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 329}], {
             RGBColor[
             0.9521889904418726, 0.9596910224924802, 0.7262774374144689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 341}], {
             RGBColor[
             0.9937373998092928, 0.989013256375112, 0.5597328014089351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 358}], {
             RGBColor[
             0.9922071868001929, 0.9889314592642007, 0.625143205341028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 229}], {
             RGBColor[
             0.9535481796117142, 0.9362939326214935, 0.6728555386304695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 237}], {
             RGBColor[
             0.9844428038119875, 0.9575615414127963, 0.5405441626001726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 307}], {
             RGBColor[
             0.9840038718635592, 0.9573800317720846, 0.5478184009051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 343}], {
             RGBColor[
             0.9196236732123857, 0.9092434520748638, 0.6696197889253371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 232}], {
             RGBColor[
             0.909666850004146, 0.9122159435097048, 0.6847227732728345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 277}], {
             RGBColor[
             0.9123135690335279, 0.9211439482749904, 0.6950047769110329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 373}], {
             RGBColor[
             0.9148965854969837, 0.9297984477673652, 0.7100240624287883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 390}], {
             RGBColor[
             0.8988663128747328, 0.8757831956854787, 0.6427647260353593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 266}], {
             RGBColor[
             0.9944394325685687, 0.9917095135395566, 0.7229853648534499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 286}], {
             RGBColor[
             0.9948813202952018, 0.991459986626369, 0.6842414868412203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 386}], {
             RGBColor[
             0.9942060077121582, 0.9900155612958146, 0.610737879723096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 231}], {
             RGBColor[
             0.9938287093125044, 0.9892085581696748, 0.5696712773365921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 280}], {
             RGBColor[
             0.9877023247448968, 0.9698079491469276, 0.4382943603487506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 291}], {
             RGBColor[
             0.9918476182809577, 0.9837909976052684, 0.4543980429633472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 368}], {
             RGBColor[
             0.9926833703585707, 0.9866101856069769, 0.45764478196633707`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 372}], {
             RGBColor[
             0.9394906329203498, 0.949748846397751, 0.7399129492233385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 387}], {
             RGBColor[
             0.994176704145847, 0.9899528839305198, 0.6075483673707694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 392}], {
             RGBColor[
             0.951672134738761, 0.8347485587623416, 0.3687419903710037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 221}], {
             RGBColor[
             0.9937947516650498, 0.9904591158098485, 0.662157113643159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 225}], {
             RGBColor[
             0.9834337708021705, 0.9563350530829152, 0.5516731022770626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 323}], {
             RGBColor[
             0.9942889987345234, 0.9915162603154084, 0.7159528570160136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 351}], {
             RGBColor[
             0.9900269231909679, 0.9785753042361277, 0.5772862542951844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 388}], {
             RGBColor[
             0.9903782018650574, 0.9797602496879869, 0.5786509056106112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 395}], {
             RGBColor[
             0.9944764651030992, 0.9919172319220345, 0.7363574143271594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 286}], {
             RGBColor[
             0.974926016560687, 0.9254120860447119, 0.4780114621107184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 290}], {
             RGBColor[
             0.974138448135875, 0.9237275568194214, 0.39228949937885077`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 304}], {
             RGBColor[
             0.7748695941439856, 0.7706981327309859, 0.6219704744946115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 338}], {
             RGBColor[
             0.971373426275627, 0.9243752575085806, 0.5683077317562468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 386}], {
             RGBColor[
             0.9742507039776434, 0.9239676607141574, 0.40450785499259406`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 230}], {
             RGBColor[
             0.9595856447484793, 0.8650206300413359, 0.4403411055915897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 258}], {
             RGBColor[
             0.9563957129281244, 0.8645382413893885, 0.5540279788507587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 264}], {
             RGBColor[
             0.9570864711810331, 0.8648238876786436, 0.5425803269750069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 279}], {
             RGBColor[
             0.95868168279455, 0.8630871468264543, 0.34195042551289856`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 328}], {
             RGBColor[
             0.9444552218095511, 0.8150986717934415, 0.286622223368751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 394}], {
             RGBColor[
             0.9367102152776832, 0.8504782166187863, 0.6151773774966984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 216}], {
             RGBColor[
             0.9347995634424934, 0.9284760051683172, 0.6815589585059849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 238}], {
             RGBColor[
             0.9495891602916315, 0.8309722592302046, 0.3140890259601788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 341}], {
             RGBColor[
             0.9869234125055493, 0.9662308076015855, 0.5160230173794274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 358}], {
             RGBColor[
             0.9853931994964494, 0.9661490104906743, 0.5814334213115202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 239}], {
             RGBColor[
             0.8706779026018293, 0.7906567714026022, 0.6186991403453957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 289}], {
             RGBColor[
             0.9039778242953633, 0.9245352002237246, 0.9262572266270003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 309}], {
             RGBColor[
             0.9076958765458618, 0.9251037148860358, 0.7942037357314018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 362}], {
             RGBColor[
             0.9079216308256797, 0.9255865804633072, 0.8187756958956567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 385}], {
             RGBColor[
             0.9063602349249209, 0.9216201702513793, 0.7021210259020728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 215}], {
             RGBColor[
             0.8930089922537067, 0.9064839067950576, 0.6939352919830313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 227}], {
             RGBColor[
             0.8411878445681921, 0.7047014433591573, 0.6028101430051602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 259}], {
             RGBColor[
             0.8948813342665458, 0.916520606018966, 0.8846226931484609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 306}], {
             RGBColor[
             0.8933713800894327, 0.9077063260576719, 0.6953431002936266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 308}], {
             RGBColor[
             0.894789557996939, 0.9124901731436983, 0.7008524536638625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 345}], {
             RGBColor[
             0.8557949715321251, 0.8880281405996704, 0.9860608596309719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 350}], {
             RGBColor[
             0.8766112133223827, 0.9041269619439867, 0.9707288791827107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 378}], {
             RGBColor[
             0.8954526833737567, 0.914573751497956, 0.7164640322952895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 257}], {
             RGBColor[
             0.9662920823982442, 0.9708726000795135, 0.7272267981391545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 310}], {
             RGBColor[
             0.9914429374899243, 0.9886658153022421, 0.6414718164973157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 332}], {
             RGBColor[
             0.989895495408021, 0.9773384932360675, 0.43555059257863554`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 389}], {
             RGBColor[
             0.8520227118898893, 0.8807399527549856, 0.7196662671326999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 224}], {
             RGBColor[
             0.9056970842000308, 0.5762966430106624, 0.2887601049311624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 227}], {
             RGBColor[
             0.9360428615335957, 0.7689421313733253, 0.3162292478382739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 259}], {
             RGBColor[
             0.9897363512319495, 0.9807612940331341, 0.5980417979815744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 345}], {
             RGBColor[
             0.9506499884975288, 0.9522688286138385, 0.6994799644640857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 350}], {
             RGBColor[
             0.9714662302877863, 0.9683676499581548, 0.6841479840158242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 353}], {
             RGBColor[
             0.9783844246810517, 0.9735272280091485, 0.6724372854621037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 393}], {
             RGBColor[
             0.9546906593792819, 0.8486369552395301, 0.33153179286365825`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 400}], {
             RGBColor[
             0.9794347210093918, 0.974310537291122, 0.6706594077393782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 229}], {
             RGBColor[
             0.9119129020831281, 0.9325986111775143, 0.9914602607465886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 294}], {
             RGBColor[
             0.9261092613070834, 0.9432447390658105, 0.9694579820134496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 329}], {
             RGBColor[
             0.9009710562142507, 0.9238738802901654, 0.9904166177197138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 340}], {
             RGBColor[
             0.9427474452337246, 0.9536837395962611, 0.8486861599128874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 341}], {
             RGBColor[
             0.9425194655816709, 0.9531961141727971, 0.8238719817141801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 343}], {
             RGBColor[
             0.8779883956837995, 0.9055481306308846, 0.9882245110414561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 358}], {
             RGBColor[
             0.9409892525725712, 0.9531143170618859, 0.889282385646273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 231}], {
             RGBColor[
             0.9883892442446197, 0.9885109822070313, 0.7817325820189103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 254}], {
             RGBColor[
             0.9839896162484769, 0.9873206188598762, 0.9003671653015268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 314}], {
             RGBColor[
             0.9762209553833547, 0.9817862079762938, 0.925135899354586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 331}], {
             RGBColor[
             0.9883417030576331, 0.9884092964152182, 0.7765580172056157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 392}], {
             RGBColor[
             0.9462326696708763, 0.834050982799698, 0.5808032950533218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 222}], {
             RGBColor[
             0.9835818092879667, 0.9867822827381243, 0.8905697742596241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 276}], {
             RGBColor[
             0.9906500904117717, 0.9894137222152601, 0.7328084346579531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 282}], {
             RGBColor[
             0.9910123761567016, 0.9901886147909578, 0.7722410022251286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 305}], {
             RGBColor[
             0.9868438635082588, 0.9888276137104486, 0.8676947588653848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 339}], {
             RGBColor[
             0.9894899380548474, 0.989921833536477, 0.8238424558069951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 361}], {
             RGBColor[
             0.9858062015272337, 0.9740825371148187, 0.6282446761510718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 382}], {
             RGBColor[
             0.9893897755631721, 0.9898804137721107, 0.825502407506276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 384}], {
             RGBColor[
             0.9872976173313553, 0.9791134328232044, 0.6340385449198419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 248}], {
             RGBColor[
             0.9378733585651368, 0.8704029148365926, 0.627994050722464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 251}], {
             RGBColor[
             0.6331674514078466, 0.7059820246615656, 0.965068971872207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 260}], {
             RGBColor[
             0.893726386343671, 0.6635692481909163, 0.5910247929515542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 352}], {
             RGBColor[
             0.9772148644849536, 0.9788216165111179, 0.6930922601696189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 396}], {
             RGBColor[
             0.9784255114821656, 0.9814110680229668, 0.824863714568935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 256}], {
             RGBColor[
             0.9941540768349746, 0.9899044864005356, 0.6050855242218741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 316}], {
             RGBColor[
             0.9833295389955807, 0.9842418091743259, 0.750969386362484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 351}], {
             RGBColor[
             0.9900734759205401, 0.9773516862030456, 0.4861713149492929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 399}], {
             RGBColor[
             0.9701641030939208, 0.9073904630547085, 0.4234212416237395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 223}], {
             RGBColor[
             0.9841606983582805, 0.9870216682454696, 0.8809760842476339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 224}], {
             RGBColor[
             0.9017652474709967, 0.5832367774429524, 0.544452103620806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 247}], {
             RGBColor[
             0.9856267911912449, 0.9876279353087676, 0.856679131878786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 259}], {
             RGBColor[
             0.9858045145029155, 0.9877014284654241, 0.8537337966712181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 292}], {
             RGBColor[
             0.986805482867008, 0.9866734860937139, 0.7323365406268936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 363}], {
             RGBColor[
             0.9792243494714311, 0.9840261343695746, 0.9200519365741056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 383}], {
             RGBColor[
             0.9854927437134902, 0.9875725032318529, 0.8589006454889343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 393}], {
             RGBColor[
             0.9507588226502479, 0.85557708967182, 0.5872237915533018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 247}], {
             RGBColor[
             0.9897871537884833, 0.9900447398804315, 0.8189168219309877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 292}], {
             RGBColor[
             0.9909658454642463, 0.9890902906653778, 0.6945742306790954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 319}], {
             RGBColor[
             0.9743932629736409, 0.9338706722317017, 0.5720650002868325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 385}], {
             RGBColor[
             0.9899042738387424, 0.9861929540382338, 0.632322348489132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 393}], {
             RGBColor[
             0.9549191852474862, 0.8579938942434839, 0.5494614816055036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 400}], {
             RGBColor[
             0.9796632468775961, 0.9836674762950759, 0.8885890964812235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 227}], {
             RGBColor[
             0.8538759365145162, 0.3745141795747622, 0.1976349559532914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 259}], {
             RGBColor[
             0.90756942621287, 0.5863333422345709, 0.4794475060965919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 363}], {
             RGBColor[
             0.9009892611813857, 0.5826580481387214, 0.5457656459994795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 383}], {
             RGBColor[
             0.9072576554234447, 0.5862044170009997, 0.48461435491430815`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 393}], {
             RGBColor[
             0.8725237343602024, 0.4542090034409669, 0.21293750097867575`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 235}], {
             RGBColor[
             0.9827108836055936, 0.9533418921034003, 0.3873354768937495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 261}], {
             RGBColor[
             0.9573133679890147, 0.8633953544195575, 0.310933915552465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 322}], {
             RGBColor[
             0.9778109811741036, 0.936813370650182, 0.36830028121634284`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 327}], {
             RGBColor[
             0.9632763225441376, 0.942889293015021, 0.6568918017079302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 335}], {
             RGBColor[
             0.9841426913133973, 0.9565281727591368, 0.5326528083041605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 349}], {
             RGBColor[
             0.9833096743221665, 0.9562837359992995, 0.5537297021021238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 355}], {
             RGBColor[
             0.983482539538715, 0.9551161748646742, 0.46079936161449797`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 252}], {
             RGBColor[
             0.9865636565801035, 0.9654613260539606, 0.47686580505087356`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 274}], {
             RGBColor[
             0.9865221692916526, 0.9653725889389724, 0.4723501697328569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 288}], {
             RGBColor[
             0.983534339262049, 0.9653803240132206, 0.6122395459716146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 315}], {
             RGBColor[
             0.9862697475267406, 0.964832684307581, 0.4448756183887486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 318}], {
             RGBColor[
             0.9796222266520189, 0.9429231269478531, 0.3753366278730362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 322}], {
             RGBColor[
             0.9808530650228577, 0.9470750337872849, 0.3801182025194217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 243}], {
             RGBColor[
             0.9387098896938846, 0.7793074537417066, 0.4937466429586394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 306}], {
             RGBColor[
             0.9364052493693218, 0.7701645506359396, 0.31763705614886917`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 311}], {
             RGBColor[
             0.9138658699912863, 0.7622750592195737, 0.6028055345282994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 346}], {
             RGBColor[
             0.9085400670466839, 0.6693363541773893, 0.24496930582778523`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 350}], {
             RGBColor[
             0.9196450826022717, 0.7665851865222546, 0.5930228350379532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 363}], {
             RGBColor[
             0.9313350385149506, 0.7753035365013843, 0.573234788906591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 383}], {
             RGBColor[
             0.9376034327570096, 0.7788499053636626, 0.5120834978214197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 276}], {
             RGBColor[
             0.9840479034977803, 0.9849834600528313, 0.7660903344298357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 282}], {
             RGBColor[
             0.9844101892427102, 0.985758352628529, 0.8055229019970112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 301}], {
             RGBColor[
             0.9834273857226328, 0.9836562352757616, 0.6985508039968467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 305}], {
             RGBColor[
             0.9802416765942674, 0.9843973515480198, 0.9009766586372674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 382}], {
             RGBColor[
             0.9827875886491807, 0.9854501516096819, 0.8587843072781585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 294}], {
             RGBColor[
             0.9476265468715965, 0.960402038503796, 0.9715103199193005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 307}], {
             RGBColor[
             0.9638858798994862, 0.970842009766091, 0.86847546092707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[
             0.9224883417787637, 0.9410311797281509, 0.9924689556255647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 340}], {
             RGBColor[
             0.9642647307982375, 0.9708410390342466, 0.8507384978187382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 343}], {
             RGBColor[
             0.8995056812483126, 0.9227054300688702, 0.990276848947307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 258}], {
             RGBColor[
             0.9911221561162948, 0.9897600675176985, 0.735970930766909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 264}], {
             RGBColor[
             0.9918129143692035, 0.9900457138069537, 0.7245232788911573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 279}], {
             RGBColor[
             0.9934081259827204, 0.9883089729547645, 0.5238933774290488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 299}], {
             RGBColor[
             0.9862193077517672, 0.9640601194482479, 0.49590508843705083`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 300}], {
             RGBColor[
             0.9807765508744204, 0.9457004224808692, 0.4747610057469508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 328}], {
             RGBColor[
             0.9791816649977215, 0.9403204979217517, 0.46856517528490127`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 331}], {
             RGBColor[
             0.9945053459465811, 0.9906558155115072, 0.6433189992385832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 369}], {
             RGBColor[
             0.9676441172430401, 0.9730393004562811, 0.8168486708369183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 372}], {
             RGBColor[
             0.9402148107414131, 0.9512977895313964, 0.8187352359386242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 392}], {
             RGBColor[
             0.9523963125598243, 0.8362975018959868, 0.44756427708628926`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 277}], {
             RGBColor[
             0.9847852328184377, 0.9603391590786804, 0.39539393187766925`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 373}], {
             RGBColor[
             0.9873682492818934, 0.9689936585710552, 0.4104132173954247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 390}], {
             RGBColor[
             0.9713379766596426, 0.9149784064891687, 0.3431538810019956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 256}], {
             RGBColor[
             0.9147496548062192, 0.6304269466315784, 0.4101546518848953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 257}], {
             RGBColor[
             0.8873633631995459, 0.6124125405631146, 0.5840732431563262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 310}], {
             RGBColor[
             0.912514218291226, 0.6302057557858431, 0.49831826151448727`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 316}], {
             RGBColor[
             0.9039251169668254, 0.6247642694053688, 0.5560385140255051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 389}], {
             RGBColor[
             0.7730939926911911, 0.5222798932385867, 0.5765127121498717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 298}], {
             RGBColor[
             0.9750287687529541, 0.9274283148591027, 0.35749191133690705`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 365}], {
             RGBColor[
             0.950658084891997, 0.8325427124640048, 0.32884137130111674`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 261}], {
             RGBColor[
             0.9669049089257449, 0.895749874200058, 0.34819524088113996`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 322}], {
             RGBColor[
             0.9874025221108338, 0.9691678904306825, 0.4055616065450178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 327}], {
             RGBColor[
             0.9728678634808678, 0.9752438127955215, 0.694153127036605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 335}], {
             RGBColor[
             0.9937342322501275, 0.9888826925396372, 0.5699141336328354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 349}], {
             RGBColor[
             0.9929012152588967, 0.9886382557797999, 0.5909910274307988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 355}], {
             RGBColor[
             0.9930740804754452, 0.9874706946451747, 0.49806068694317285`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 262}], {
             RGBColor[
             0.9429791526712149, 0.8572969036740591, 0.6062286018516121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 284}], {
             RGBColor[
             0.9719747014709088, 0.9786193587609942, 0.9323236996279664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 334}], {
             RGBColor[
             0.9402411241321662, 0.8464415329106538, 0.6040255198193034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 366}], {
             RGBColor[
             0.9725413049261304, 0.9658210625975443, 0.6752201939633453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 376}], {
             RGBColor[
             0.9215758379853147, 0.9396829167558752, 0.9708633448782347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 397}], {
             RGBColor[
             0.9732947447246953, 0.9791668879146742, 0.9105213860309888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 307}], {
             RGBColor[
             0.9947805040997595, 0.9921096185573938, 0.736164084896773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 324}], {
             RGBColor[
             0.9919822164376639, 0.9909524546964046, 0.7825389531940252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 269}], {
             RGBColor[
             0.7064944682967771, 0.6600952892747813, 0.6039032620047151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 309}], {
             RGBColor[
             0.9571407960198152, 0.8554675810452136, 0.43009174695108027`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 323}], {
             RGBColor[
             0.957476310304676, 0.856185212174833, 0.46661040630402556`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 362}], {
             RGBColor[
             0.957366550299633, 0.855950446622485, 0.45466370711533516`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 365}], {
             RGBColor[
             0.9166075404271108, 0.707083717222964, 0.2517586734362875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 377}], {
             RGBColor[
             0.9564627134001813, 0.8540172308864862, 0.3562866384447879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 385}], {
             RGBColor[
             0.9558051543988743, 0.8519840364105571, 0.33800903712175134`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 388}], {
             RGBColor[
             0.9535655134352099, 0.8444292015474116, 0.32930845489862304`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 272}], {
             RGBColor[
             0.9900817396166336, 0.9888464330699345, 0.7180755757064887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 342}], {
             RGBColor[
             0.9291966539591221, 0.7501144952864847, 0.5448734915134966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 374}], {
             RGBColor[
             0.9858527264137034, 0.9753516673958431, 0.6361128387010377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 242}], {
             RGBColor[
             0.9936992759702283, 0.9889317133382645, 0.5555832567998353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 255}], {
             RGBColor[
             0.9590379477869677, 0.8623429521792244, 0.46985711234856375`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 312}], {
             RGBColor[
             0.84595318657658, 0.8773402958259086, 0.8265408604704374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 331}], {
             RGBColor[
             0.9946622225139465, 0.9909913586264476, 0.660394045466351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 359}], {
             RGBColor[
             0.9949331645185353, 0.9915708761778241, 0.689884410605607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 360}], {
             RGBColor[
             0.9565315922547819, 0.8524060876875779, 0.4678404398556414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 380}], {
             RGBColor[
             0.9946420414191575, 0.9909481933053155, 0.6581974578418455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 392}], {
             RGBColor[
             0.9525531891271897, 0.8366330450109274, 0.4646393233140571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 255}], {
             RGBColor[
             0.9578705834888975, 0.8598460779842878, 0.3427967126409858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 312}], {
             RGBColor[
             0.8447858222785098, 0.874843421630972, 0.6994804607628595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 331}], {
             RGBColor[
             0.9934948582158764, 0.988494484431511, 0.5333336457587731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 380}], {
             RGBColor[
             0.9934746771210874, 0.988451319110379, 0.5311370581342675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 267}], {
             RGBColor[
             0.986466881831783, 0.9673805662063956, 0.569083315085398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 275}], {
             RGBColor[
             0.9936261274050993, 0.9905730382731588, 0.6783012831607282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 311}], {
             RGBColor[
             0.9683540458370896, 0.9744228450238552, 0.871448078626536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 326}], {
             RGBColor[
             0.9940574156987532, 0.9918106029210534, 0.7481475309942436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 344}], {
             RGBColor[
             0.8952917179724283, 0.9165490091752798, 0.8714143834275319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 346}], {
             RGBColor[
             0.9630282428924872, 0.8814841399816709, 0.5136118499260218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 363}], {
             RGBColor[
             0.9858232143607539, 0.9874513223056658, 0.8418773330048275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 383}], {
             RGBColor[
             0.9920916086028131, 0.9909976911679441, 0.7807260419196562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 302}], {
             RGBColor[
             0.9661891023256428, 0.8976100443474021, 0.3231514764977371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 352}], {
             RGBColor[
             0.9926759665703501, 0.9889314987650923, 0.6032861536499601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 396}], {
             RGBColor[
             0.9938866135675621, 0.9915209502769413, 0.7350576080492761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 248}], {
             RGBColor[
             0.9639237724816564, 0.8842722223874719, 0.34401769415657163`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 251}], {
             RGBColor[
             0.6592178653243662, 0.7198513322124449, 0.6810926153063147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 260}], {
             RGBColor[
             0.9197768002601906, 0.6774385557417957, 0.307048436385662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 326}], {
             RGBColor[
             0.9930320802747532, 0.9869830956399599, 0.5770078021467009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 271}], {
             RGBColor[
             0.9897236363615887, 0.9900184737920872, 0.819969470072462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 287}], {
             RGBColor[
             0.9913072328659133, 0.9906733316431992, 0.7937251777794225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 292}], {
             RGBColor[
             0.9924319382972107, 0.9896965577286758, 0.6702772783102475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 319}], {
             RGBColor[
             0.9758593558066053, 0.9344769392949996, 0.5477680479179846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 362}], {
             RGBColor[
             0.9929317625724655, 0.9907656313134598, 0.7246800661138679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 385}], {
             RGBColor[
             0.9913703666717067, 0.9867992211015317, 0.6080253961202842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 393}], {
             RGBColor[
             0.9563852780804506, 0.858600161306782, 0.5251645292366557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 400}], {
             RGBColor[
             0.9811293397105605, 0.9842737433583739, 0.8642921441123756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 251}], {
             RGBColor[
             0.6319942431143344, 0.6223233296161155, 0.6050005801010958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 260}], {
             RGBColor[
             0.8925531780501588, 0.5799105531454662, 0.23095640118044314`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 275}], {
             RGBColor[
             0.9653771697710676, 0.8882175283957361, 0.4310695191079666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 268}], {
             RGBColor[
             0.5837865750764887, 0.6393784699172916, 0.6719469333246479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 279}], {
             RGBColor[
             0.9905751570908843, 0.979869214787233, 0.41794778199982674`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 299}], {
             RGBColor[
             0.9833863388599311, 0.9556203612807164, 0.38995949300782884`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 300}], {
             RGBColor[
             0.9779435819825842, 0.9372606643133379, 0.3688154103177288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 370}], {
             RGBColor[
             0.9831415637070742, 0.9547946772141913, 0.3890085877608891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 265}], {
             RGBColor[
             0.9939600623073404, 0.9894895089438038, 0.5839682402077622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 321}], {
             RGBColor[
             0.9809953878629325, 0.9828667232184514, 0.7839388240105443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 325}], {
             RGBColor[
             0.9923232499110379, 0.9903035611835256, 0.7194683285403631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 375}], {
             RGBColor[
             0.9925848860403134, 0.9904117544467228, 0.71513234078567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 381}], {
             RGBColor[
             0.9944953684616968, 0.9912017880251236, 0.6834707028933285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 260}], {
             RGBColor[
             0.5878472708928686, 0.4154896629704392, 0.5680313223301863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 275}], {
             RGBColor[
             0.6606712626137774, 0.723796638220709, 0.7681444402577097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 274}], {
             RGBColor[
             0.9938823155053844, 0.9893232163958274, 0.5755059806124982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 288}], {
             RGBColor[
             0.9908944854757809, 0.9893309514700757, 0.715395356851256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 318}], {
             RGBColor[
             0.9869823728657507, 0.9668737544047081, 0.47849243875267755`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 283}], {
             RGBColor[
             0.980149053819312, 0.9436022396009067, 0.47074916875278994`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 332}], {
             RGBColor[
             0.9764585534542761, 0.9322513143860746, 0.36304635490935816`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 334}], {
             RGBColor[
             0.9433654421691833, 0.8101970439636748, 0.28877129553964087`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 364}], {
             RGBColor[
             0.7742353342406638, 0.7844640662740917, 0.6413755873346141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 366}], {
             RGBColor[
             0.9756656229631477, 0.9295765736505652, 0.3599659696836829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 391}], {
             RGBColor[
             0.9610304464579902, 0.8802086867958117, 0.30311107258232534`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 314}], {
             RGBColor[
             0.9779849702761599, 0.9828423637254275, 0.9105314646701699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 369}], {
             RGBColor[
             0.9632444892468973, 0.9718489371091259, 0.9354832541195348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 312}], {
             RGBColor[
             0.8101244940952492, 0.7482546604719319, 0.6137543163115878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 331}], {
             RGBColor[
             0.9588335300326157, 0.861905723272471, 0.44760750130750143`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 356}], {
             RGBColor[
             0.9510254617815099, 0.8367737185120836, 0.31468743704783697`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 359}], {
             RGBColor[
             0.9591044720372045, 0.8624852408238475, 0.4770978664467574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 360}], {
             RGBColor[
             0.9207028997734511, 0.7233204523336012, 0.2550538956967918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 380}], {
             RGBColor[
             0.9588133489378268, 0.8618625579513388, 0.44541091368299585`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 310}], {
             RGBColor[
             0.9922314127603338, 0.9903522841785697, 0.7272924837760726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 316}], {
             RGBColor[
             0.9836423114359332, 0.9849107977980952, 0.7850127362870905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 319}], {
             RGBColor[
             0.9774661571335449, 0.9344381733352874, 0.47002255021015504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 384}], {
             RGBColor[
             0.9909494005615731, 0.9799203194341355, 0.5224024048311742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 310}], {
             RGBColor[
             0.9648451211536605, 0.9723378781101057, 0.9012110750475035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 356}], {
             RGBColor[
             0.9592679671596815, 0.9474173915431483, 0.6796351812976511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 360}], {
             RGBColor[
             0.9289454051516228, 0.8339641253646659, 0.620001639946606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 389}], {
             RGBColor[
             0.8254248955536254, 0.8644120155628493, 0.9794055256828879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 264}], {
             RGBColor[
             0.9886229825488486, 0.9895633251550062, 0.8382101521503262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 279}], {
             RGBColor[
             0.9902181941623656, 0.987826584302817, 0.6375802506882178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 281}], {
             RGBColor[
             0.9765506580285717, 0.9417234940347148, 0.5844233660469004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 300}], {
             RGBColor[
             0.9775866190540655, 0.9452180338289218, 0.5884478790061198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 328}], {
             RGBColor[
             0.9759917331773666, 0.9398381092698043, 0.5822520485440703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 394}], {
             RGBColor[
             0.9682467266454986, 0.9752176540951489, 0.9108072026720178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 271}], {
             RGBColor[
             0.9899013596732593, 0.9900919669487437, 0.8170241348648941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 287}], {
             RGBColor[
             0.9914849561775838, 0.9907468247998557, 0.7907798425718546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 292}], {
             RGBColor[
             0.9926096616088813, 0.9897700508853323, 0.6673319431026796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 345}], {
             RGBColor[
             0.9525223305103679, 0.9623055278377469, 0.8901673656295152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 350}], {
             RGBColor[
             0.9733385723006256, 0.9784043491820633, 0.8748353851812538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 353}], {
             RGBColor[
             0.9802567666938908, 0.9835639272330569, 0.8631246866275332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 393}], {
             RGBColor[
             0.9565630013921211, 0.8586736544634386, 0.5222191940290878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 400}], {
             RGBColor[
             0.9813070630222309, 0.9843472365150305, 0.8613468089048077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 327}], {
             RGBColor[
             0.947470347864289, 0.8852972751116788, 0.6177515656953205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 335}], {
             RGBColor[
             0.9683367166335487, 0.8989361548557944, 0.493512572291551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 349}], {
             RGBColor[
             0.9675036996423179, 0.8986917180959572, 0.5145894660895143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 355}], {
             RGBColor[
             0.9676765648588664, 0.8975241569613319, 0.42165912560188845`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 284}], {
             RGBColor[
             0.9551864753891399, 0.8664011049694311, 0.5855647886698416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 325}], {
             RGBColor[
             0.9582355385764363, 0.8676636282994029, 0.535108140214454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 376}], {
             RGBColor[
             0.9047876119035458, 0.8274646629643122, 0.6241044339201098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 397}], {
             RGBColor[
             0.9565065186429265, 0.8669486341231112, 0.563762475072864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 336}], {
             RGBColor[
             0.9457520406736226, 0.927675824645799, 0.6685787524766613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 359}], {
             RGBColor[
             0.9834005516331505, 0.9541274279795928, 0.5210397070965462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 360}], {
             RGBColor[
             0.9449989793693971, 0.8149626394893463, 0.2989957363465806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 279}], {
             RGBColor[
             0.9909089524152742, 0.9881122305920722, 0.6261325988124661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 281}], {
             RGBColor[
             0.9772414162814804, 0.9420091403239699, 0.5729757141711486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 328}], {
             RGBColor[
             0.9766824914302753, 0.9401237555590594, 0.5708043966683185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 394}], {
             RGBColor[
             0.9689374848984074, 0.9755033003844041, 0.899359550796266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 321}], {
             RGBColor[
             0.9805891009116237, 0.9819977165115139, 0.7397169966730005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 325}], {
             RGBColor[
             0.9919169629597291, 0.989434554476588, 0.6752465012028195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 375}], {
             RGBColor[
             0.9921785990890046, 0.9895427477397852, 0.6709105134481264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 381}], {
             RGBColor[
             0.994089081510388, 0.990332781318186, 0.6392488755557848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 358}], {
             RGBColor[
             0.9927400259491205, 0.991265828404208, 0.7699800884410404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 384}], {
             RGBColor[
             0.9906645575597666, 0.9805057491340695, 0.57823963197307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 275}], {
             RGBColor[
             0.9868949436971944, 0.9664983649335663, 0.48499541118925016`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 306}], {
             RGBColor[
             0.9841622415072204, 0.9582376631006286, 0.3929737282756277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 311}], {
             RGBColor[
             0.9616228621291848, 0.9503481716842626, 0.678142206655058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 317}], {
             RGBColor[
             0.9743202691334356, 0.9598178770379371, 0.6566488086109912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 344}], {
             RGBColor[
             0.8885605342645235, 0.8924743358356872, 0.6781085114560539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 346}], {
             RGBColor[
             0.9562970591845823, 0.8574094666420782, 0.32030597795454374`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 354}], {
             RGBColor[
             0.9819665418321324, 0.9655195599630775, 0.6436655953861896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 279}], {
             RGBColor[
             0.5857155820143956, 0.6458847448699414, 0.6795018486751788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 299}], {
             RGBColor[
             0.5785267637834424, 0.6216358913634248, 0.6515135596831809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 300}], {
             RGBColor[
             0.5730840069060956, 0.6032761943960463, 0.6303694769930809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 370}], {
             RGBColor[
             0.5782819886305857, 0.6208102072968997, 0.6505626544362412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 371}], {
             RGBColor[
             0.5684326779003908, 0.6367725375713098, 0.9447922857911148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 309}], {
             RGBColor[
             0.7435124422408097, 0.794542232758215, 0.779407857390721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 323}], {
             RGBColor[
             0.7438479565256704, 0.7952598638878345, 0.8159265167436663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 362}], {
             RGBColor[
             0.7437381965206276, 0.7950250983354865, 0.8039798175549759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 365}], {
             RGBColor[
             0.7029791866481052, 0.6461583689359653, 0.6010747838759283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 377}], {
             RGBColor[
             0.7428343596211758, 0.7930918825994876, 0.7056027488844288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 388}], {
             RGBColor[
             0.7399371596562044, 0.783503853260413, 0.6786245653382638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 336}], {
             RGBColor[
             0.9058492070086284, 0.9277635853197262, 0.9908819000972582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 357}], {
             RGBColor[
             0.9190395193640961, 0.9380134000639049, 0.9828558238876515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 287}], {
             RGBColor[
             0.9897776226060544, 0.9900407984915569, 0.8190747782897448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 292}], {
             RGBColor[
             0.9909023280373518, 0.9890640245770335, 0.6956268788205697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 303}], {
             RGBColor[
             0.9907622011943986, 0.9887643074289538, 0.6803749367277598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 333}], {
             RGBColor[
             0.9895450467277488, 0.9851691897494879, 0.6322262203479698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 337}], {
             RGBColor[
             0.9910892735976091, 0.9894638822273285, 0.7159747493603252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 345}], {
             RGBColor[
             0.9508149969388384, 0.9615995015294481, 0.9184623013474054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 353}], {
             RGBColor[
             0.9785494331223614, 0.982857900924758, 0.8914196223454234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 385}], {
             RGBColor[
             0.9898407564118479, 0.9861666879498895, 0.6333749966306064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 391}], {
             RGBColor[
             0.972119452095346, 0.926388567330202, 0.5645310757485116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 400}], {
             RGBColor[
             0.9795997294507015, 0.9836412102067316, 0.8896417446226978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 308}], {
             RGBColor[
             0.9925884456644494, 0.9858905394108706, 0.4912417595655245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 342}], {
             RGBColor[
             0.9328666649658122, 0.7503120135317843, 0.38809271476024965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 348}], {
             RGBColor[
             0.9912930271777844, 0.9893473316051409, 0.6980014061064963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 374}], {
             RGBColor[
             0.9895227374203934, 0.9755491856411428, 0.47933206194779077`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 375}], {
             RGBColor[
             0.9922775867226507, 0.9897544722789692, 0.681684706489638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 378}], {
             RGBColor[
             0.993251571041267, 0.9879741177651282, 0.5068533381969516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 281}], {
             RGBColor[
             0.9775588727417353, 0.9421404167285442, 0.5677146390737425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 293}], {
             RGBColor[
             0.9128102914959495, 0.9309588266077593, 0.9002143393891398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 394}], {
             RGBColor[
             0.9692549413586622, 0.9756345767889785, 0.8940984756988599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 288}], {
             RGBColor[
             0.99085299818733, 0.9892422143550874, 0.7108797215332393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 318}], {
             RGBColor[
             0.9869408855772999, 0.9667850172897199, 0.47397680343466086`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 311}], {
             RGBColor[
             0.9687821077025011, 0.9735406437510259, 0.7873601747303882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 317}], {
             RGBColor[
             0.9814795147067519, 0.9830103491047004, 0.7658667766863214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 344}], {
             RGBColor[
             0.8957197798378398, 0.9156668079024506, 0.7873264795313841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 346}], {
             RGBColor[
             0.9634563047578986, 0.8806019387088415, 0.429523946029874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 282}], {
             RGBColor[
             0.9944991837535819, 0.9906426352037752, 0.6426482825592654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 301}], {
             RGBColor[
             0.9935163802335045, 0.9885405178510078, 0.5356761845591009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 305}], {
             RGBColor[
             0.9903306711051392, 0.989281634123266, 0.7381020391995217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 339}], {
             RGBColor[
             0.9929767456517278, 0.9903758539492944, 0.694249736141132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 361}], {
             RGBColor[
             0.9892930091241141, 0.9745365575276361, 0.4986519564852087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 382}], {
             RGBColor[
             0.9928765831600525, 0.9903344341849281, 0.6959096878404127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 373}], {
             RGBColor[
             0.9900149683112751, 0.9779216633363408, 0.42069522103362306`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 390}], {
             RGBColor[
             0.9739846956890243, 0.9239064112544543, 0.35343588464019404`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 296}], {
             RGBColor[
             0.9487857466732386, 0.8211793260685871, 0.4651203160728186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 302}], {
             RGBColor[
             0.9831920660184754, 0.9534658716651466, 0.5166826697901986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 330}], {
             RGBColor[
             0.9221401881982276, 0.9371399370210859, 0.8376305798785704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 367}], {
             RGBColor[
             0.9860917158797691, 0.9632470715174546, 0.5279472619483949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 299}], {
             RGBColor[
             0.985315345797838, 0.9621266362333663, 0.3975144083583597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 300}], {
             RGBColor[
             0.9798725889204911, 0.9437669392659876, 0.3763703256682597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 328}], {
             RGBColor[
             0.9782777030437922, 0.93838701470687, 0.3701744952062101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 370}], {
             RGBColor[
             0.9850705706449812, 0.9613009521668412, 0.39656350311141997`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 371}], {
             RGBColor[
             0.9752212599147863, 0.9772632824412513, 0.6907931344662936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 291}], {
             RGBColor[
             0.9864454115344135, 0.9659393317161666, 0.40184341269079127`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 336}], {
             RGBColor[
             0.9510013924240344, 0.9453831207063428, 0.6889714927701127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 368}], {
             RGBColor[
             0.9872811636120264, 0.9687585197178751, 0.40509015169378115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 387}], {
             RGBColor[
             0.9887744973993028, 0.972101218041418, 0.5549937370982135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 392}], {
             RGBColor[
             0.9462699279922168, 0.8168968928732396, 0.3161873600984477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 293}], {
             RGBColor[
             0.9004205105154177, 0.8829877190828935, 0.65168862838312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 394}], {
             RGBColor[
             0.9568651603781304, 0.9276634692641126, 0.64557276469284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 301}], {
             RGBColor[
             0.9938786659784344, 0.9893154104267055, 0.5751087521262764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 305}], {
             RGBColor[
             0.9906929568500691, 0.9900565266989635, 0.7775346067666972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 313}], {
             RGBColor[
             0.9943926914307857, 0.9904148588933392, 0.6310572504173244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 339}], {
             RGBColor[
             0.9933390313966577, 0.991150746524992, 0.7336823037083074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 340}], {
             RGBColor[
             0.9949803717236729, 0.991671847616233, 0.6950226235557391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 361}], {
             RGBColor[
             0.989655294869044, 0.9753114501033336, 0.5380845240523842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 382}], {
             RGBColor[
             0.9932388689049824, 0.9911093267606256, 0.7353422554075884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 312}], {
             RGBColor[
             0.8456609128482337, 0.8767151518743828, 0.7947286688443147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 332}], {
             RGBColor[
             0.99059159244657, 0.9788273744153173, 0.5113164594117362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 334}], {
             RGBColor[
             0.9574984811614772, 0.8567731039929176, 0.43704140004201897`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 356}], {
             RGBColor[
             0.9865618805344945, 0.9652342099145343, 0.4956617895805639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 360}], {
             RGBColor[
             0.9562393185264355, 0.851780943736052, 0.43602824822951874`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 364}], {
             RGBColor[
             0.7883683732329577, 0.8310401263033345, 0.7896456918369921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 366}], {
             RGBColor[
             0.9897986619554415, 0.976152633679808, 0.508236074186061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 380}], {
             RGBColor[
             0.9943497676908112, 0.9903230493537898, 0.6263852662157228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 389}], {
             RGBColor[
             0.8527188089284382, 0.8822288339342355, 0.7954321339658006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 334}], {
             RGBColor[
             0.9524484468500912, 0.855545734206026, 0.5833617066375328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 366}], {
             RGBColor[
             0.9847486276440556, 0.9749252638929164, 0.6545563807815749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 397}], {
             RGBColor[
             0.9855020674426205, 0.9882710892100462, 0.8898575728492182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 324}], {
             RGBColor[
             0.9672150997315272, 0.9743132373848313, 0.9065065117761915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 290}], {
             RGBColor[
             0.993993370300168, 0.9895607513725075, 0.5875936096739458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 304}], {
             RGBColor[
             0.7947245163082786, 0.836531327284072, 0.8172745847897065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 386}], {
             RGBColor[
             0.9941056261419363, 0.9898008552672435, 0.5998119652876891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 292}], {
             RGBColor[
             0.9924859245416764, 0.9897188824281455, 0.6693825865275302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 303}], {
             RGBColor[
             0.9923457976987232, 0.9894191652800659, 0.6541306444347204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 353}], {
             RGBColor[
             0.9801330296266859, 0.9835127587758701, 0.8651753300523839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 385}], {
             RGBColor[
             0.9914243529161724, 0.9868215458010015, 0.6071307043375669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 391}], {
             RGBColor[
             0.9737030485996706, 0.927043425181314, 0.5382867834554721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 400}], {
             RGBColor[
             0.981183325955026, 0.9842960680578436, 0.8633974523296584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 318}], {
             RGBColor[
             0.9839530555476964, 0.9667927523639681, 0.6138661796734186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 304}], {
             RGBColor[
             0.7939369478834666, 0.8348467980587814, 0.7315526220578389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 338}], {
             RGBColor[
             0.9904407800151078, 0.9885239228363762, 0.6778898793194742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 336}], {
             RGBColor[
             0.9551466859600952, 0.9593661691646838, 0.7050751753847093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 368}], {
             RGBColor[
             0.9914264571480873, 0.9827415681762159, 0.42119383430837776`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 387}], {
             RGBColor[
             0.9929197909353635, 0.9860842664997589, 0.5710974197128101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 303}], {
             RGBColor[
             0.9934705031300206, 0.9884423913655425, 0.5306827449655453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 309}], {
             RGBColor[
             0.9938846999684108, 0.9893283165211346, 0.5757655146977207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 362}], {
             RGBColor[
             0.9941104542482286, 0.9898111820984061, 0.6003374748619756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 385}], {
             RGBColor[
             0.9925490583474699, 0.9858447718864781, 0.48368280486839177`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 400}], {
             RGBColor[
             0.9823080313863235, 0.9833192941433202, 0.7399495528604834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 394}], {
             RGBColor[
             0.8921165791323447, 0.9164818791433278, 0.9780724650082373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 301}], {
             RGBColor[
             0.9773593842769543, 0.9791307297330152, 0.7088223476561367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 313}], {
             RGBColor[
             0.9778734097293056, 0.980230178199649, 0.7647708459471847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 329}], {
             RGBColor[
             0.9366847010027191, 0.9516773076164471, 0.9704666768924257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 340}], {
             RGBColor[
             0.9784610900221928, 0.9814871669225428, 0.8287362190855994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 343}], {
             RGBColor[
             0.9137020404722679, 0.9333515579571663, 0.9682745702141681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 330}], {
             RGBColor[
             0.8759938364850233, 0.7667506672605922, 0.6129825272446437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 367}], {
             RGBColor[
             0.9399453641665647, 0.792857801756961, 0.3032992093144684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 398}], {
             RGBColor[
             0.9478378286511524, 0.8191518252685586, 0.3619452892406731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 325}], {
             RGBColor[
             0.9832040336341459, 0.9859827132992613, 0.8680199895521581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 375}], {
             RGBColor[
             0.9834656697634213, 0.9860909065624586, 0.8636840017974649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 376}], {
             RGBColor[
             0.9297561069612554, 0.9457837479641706, 0.957016283257814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 378}], {
             RGBColor[
             0.9844396540820377, 0.9843105520486175, 0.6888526335047784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 397}], {
             RGBColor[
             0.9814750137006361, 0.9852677191229695, 0.896674324410568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 320}], {
             RGBColor[
             0.9651507727994824, 0.8941075150442965, 0.319117762360682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 347}], {
             RGBColor[
             0.8529243555427592, 0.8414337537835666, 0.6406757019302043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 373}], {
             RGBColor[
             0.9772158056375421, 0.9347470822515298, 0.3709728909652299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 390}], {
             RGBColor[
             0.9611855330152912, 0.8807318301696433, 0.3037135545718009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 300}], {
             RGBColor[
             0.9726837706895379, 0.919518085759471, 0.3483820366762617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 370}], {
             RGBColor[
             0.977881752414028, 0.9370520986603246, 0.368575214119422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 371}], {
             RGBColor[
             0.9680324416838331, 0.9530144289347346, 0.6628048454742956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 370}], {
             RGBColor[
             0.9724389955366812, 0.9186924016929459, 0.34743113142932197`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 371}], {
             RGBColor[
             0.9625896848064863, 0.9346547319673562, 0.6416607627841957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 305}], {
             RGBColor[
             0.9897101533299917, 0.9879544093461963, 0.6705625087665327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 313}], {
             RGBColor[
             0.9934098879107083, 0.988312741540572, 0.5240851524171599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 329}], {
             RGBColor[
             0.9522211791841216, 0.95975987095737, 0.7297809833624009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 339}], {
             RGBColor[
             0.9923562278765803, 0.9890486291722247, 0.626710205708143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 340}], {
             RGBColor[
             0.9939975682035955, 0.9895697302634658, 0.5880505255555746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 361}], {
             RGBColor[
             0.9886724913489666, 0.9732093327505664, 0.4311124260522198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 382}], {
             RGBColor[
             0.992256065384905, 0.9890072094078584, 0.6283701574074239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 367}], {
             RGBColor[
             0.9743516835118016, 0.9251443473535204, 0.3548615630318484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 377}], {
             RGBColor[
             0.9821273191875439, 0.9511884858562024, 0.4007915480990768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 353}], {
             RGBColor[
             0.9811176082150304, 0.982236267713267, 0.7264754884903989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 385}], {
             RGBColor[
             0.9924089315045167, 0.9855450547383986, 0.468430862775582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 391}], {
             RGBColor[
             0.9746876271880149, 0.9257669341187111, 0.3995869418934871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 400}], {
             RGBColor[
             0.9821679045433704, 0.9830195769952407, 0.7246976107676735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 338}], {
             RGBColor[
             0.7911719260232186, 0.8354944987479407, 0.9075708544352349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 313}], {
             RGBColor[
             0.9902241787823428, 0.9890538578128301, 0.7265110070575806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 329}], {
             RGBColor[
             0.9490354700557562, 0.9605009872296282, 0.9322068380028217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 339}], {
             RGBColor[
             0.9891705187482149, 0.9897897454444828, 0.8291360603485637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 340}], {
             RGBColor[
             0.9908118590752301, 0.9903108465357238, 0.7904763801959953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 361}], {
             RGBColor[
             0.9854867822206013, 0.9739504490228245, 0.6335382806926404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 382}], {
             RGBColor[
             0.9890703562565395, 0.9897483256801164, 0.8307960120478446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 308}], {
             RGBColor[
             0.9900069627980688, 0.9779532804204806, 0.4156793668075714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 311}], {
             RGBColor[
             0.966049405512527, 0.9652799419180882, 0.6953384918167658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 346}], {
             RGBColor[
             0.9607236025679246, 0.8723412368759038, 0.33750226311625153`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 348}], {
             RGBColor[
             0.9887115443114038, 0.9814100726147508, 0.6224390133485431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 350}], {
             RGBColor[
             0.9718286181235125, 0.9695900692207691, 0.6855557923264195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 354}], {
             RGBColor[
             0.9863930852154746, 0.9804513301969031, 0.6608618805478974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 378}], {
             RGBColor[
             0.9906700881748864, 0.9800368587747382, 0.43129094543899843`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 343}], {
             RGBColor[
             0.9299613735001575, 0.9437915292194613, 0.8652397112219375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 348}], {
             RGBColor[
             0.9901297222189102, 0.9861939197007772, 0.6279483667187791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 354}], {
             RGBColor[
             0.987811263122981, 0.9852351772829295, 0.6663712339181332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 374}], {
             RGBColor[
             0.988359432461519, 0.9723957737367792, 0.40927902256007354`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 378}], {
             RGBColor[
             0.9920882660823928, 0.9848207058607646, 0.4368002988092343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 323}], {
             RGBColor[
             0.9944942842487084, 0.9906321556582667, 0.6421150016900316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 362}], {
             RGBColor[
             0.9943845242436655, 0.9903973901059187, 0.6301683025013411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 365}], {
             RGBColor[
             0.9536255143711433, 0.8415306607063977, 0.4272632688222935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 385}], {
             RGBColor[
             0.9928231283429068, 0.9864309798939908, 0.5135136325077574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 316}], {
             RGBColor[
             0.98140687492094, 0.9846896069523599, 0.8731763459166825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 319}], {
             RGBColor[
             0.9752307206185518, 0.9342169824895521, 0.5581861598397471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 384}], {
             RGBColor[
             0.9887139640465801, 0.9796991285884001, 0.6105660144607661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 317}], {
             RGBColor[
             0.9562074331387422, 0.9668601558553966, 0.9590135721521291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 344}], {
             RGBColor[
             0.8704476982698302, 0.8995166146531468, 0.9804732749971918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 346}], {
             RGBColor[
             0.9381842231898889, 0.8644517454595378, 0.6226707414956818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 354}], {
             RGBColor[
             0.963853705837439, 0.9725618387805371, 0.9460303589273276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 356}], {
             RGBColor[
             0.8379407005711224, 0.8517710621587677, 0.6713711851697106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 359}], {
             RGBColor[
             0.8460197108268168, 0.8774825844705316, 0.833781614568631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 360}], {
             RGBColor[
             0.8076181385630634, 0.7383177959802854, 0.6117376438186655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 380}], {
             RGBColor[
             0.8457285877274391, 0.876859901598023, 0.8020946618048694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 389}], {
             RGBColor[
             0.7040976289650661, 0.7687656861784687, 0.9711415295549474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 329}], {
             RGBColor[
             0.9527352046364728, 0.9608593194240038, 0.7857294816534489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 339}], {
             RGBColor[
             0.9928702533289315, 0.9901480776388585, 0.6826587039991909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 340}], {
             RGBColor[
             0.9945115936559467, 0.9906691787300996, 0.6439990238466224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 358}], {
             RGBColor[
             0.9927534009947934, 0.9900997561957243, 0.6845952495800081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 361}], {
             RGBColor[
             0.9891865168013179, 0.9743087812172002, 0.48706092434326764`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 369}], {
             RGBColor[
             0.9554758283817751, 0.9663145262255435, 0.9602519881725939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 322}], {
             RGBColor[
             0.9879193021832267, 0.9703970194977604, 0.4512838267369381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 351}], {
             RGBColor[
             0.9795617105214987, 0.9723579976006052, 0.6660985270145092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 399}], {
             RGBColor[
             0.9596523376948793, 0.9023967744522681, 0.603348453688956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 344}], {
             RGBColor[
             0.8831451052740809, 0.9089863200068213, 0.958979876953125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 346}], {
             RGBColor[
             0.9508816301941398, 0.8739214508132123, 0.601177343451615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 354}], {
             RGBColor[
             0.9765511128416899, 0.9820315441342116, 0.9245369608832608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 322}], {
             RGBColor[
             0.981271781308505, 0.9484874621380324, 0.3817448362212257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 384}], {
             RGBColor[
             0.9739487084197911, 0.9237850177451179, 0.35329608089484854`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 347}], {
             RGBColor[
             0.8562415018418884, 0.8526232671535192, 0.6535621889118051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 398}], {
             RGBColor[
             0.9807520907204411, 0.9464053113216364, 0.4077112821923684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 375}], {
             RGBColor[
             0.9792139246445968, 0.9829199620144329, 0.8708810972509085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 381}], {
             RGBColor[
             0.9811244070659801, 0.9837099955928337, 0.8392194593585669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 327}], {
             RGBColor[
             0.9679679610493778, 0.9587152913423033, 0.6751179313591984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 335}], {
             RGBColor[
             0.9888343298186375, 0.972354171086419, 0.5508789379554289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 349}], {
             RGBColor[
             0.9880013128274067, 0.9721097343265817, 0.5719558317533922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 355}], {
             RGBColor[
             0.9881741780439552, 0.9709421731919564, 0.47902549126576627`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 362}], {
             RGBColor[
             0.9947200385285263, 0.9911150212355382, 0.6666869618542864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 365}], {
             RGBColor[
             0.9539610286560041, 0.8422482918360171, 0.4637819281752388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 377}], {
             RGBColor[
             0.9938162016290746, 0.9891818054995394, 0.5683098931837393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 388}], {
             RGBColor[
             0.9909190016641032, 0.9795937761604647, 0.5413317096375743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 395}], {
             RGBColor[
             0.9950172649021449, 0.9917507583945123, 0.6990382183541225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 376}], {
             RGBColor[
             0.9368322238905362, 0.9500496413812191, 0.8997428832410765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 397}], {
             RGBColor[
             0.9885511306299168, 0.989533612540018, 0.8394009243938305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 363}], {
             RGBColor[
             0.9866825645198192, 0.987806685680731, 0.8276356769421952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 383}], {
             RGBColor[
             0.9929509587618782, 0.9913530545430094, 0.7664843858570238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 335}], {
             RGBColor[
             0.9742996711886716, 0.978430093451258, 0.8394704584470161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 349}], {
             RGBColor[
             0.9734666541974407, 0.9781856566914207, 0.8605473522449794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 355}], {
             RGBColor[
             0.9736395194139893, 0.9770180955567954, 0.7676170117573535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 339}], {
             RGBColor[
             0.951681544602345, 0.9615952070556566, 0.888354534944432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 340}], {
             RGBColor[
             0.95332288492936, 0.9621163081468976, 0.8496948547918637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 341}], {
             RGBColor[
             0.9530949052773066, 0.9616286827234337, 0.8248806765931562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 343}], {
             RGBColor[
             0.8885638353794352, 0.9139806991815211, 0.9892332059204323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 358}], {
             RGBColor[
             0.9515646922682067, 0.9615468856125224, 0.8902910805252492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 367}], {
             RGBColor[
             0.9132998056915538, 0.9088184127094596, 0.6758094731202201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 398}], {
             RGBColor[
             0.9211922701761415, 0.9351124362210572, 0.7344555530464247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 392}], {
             RGBColor[
             0.9523487713728378, 0.8361958161041738, 0.4423897122729948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 334}], {
             RGBColor[
             0.9538079807964412, 0.8454221787780853, 0.32933858619858714`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 356}], {
             RGBColor[
             0.9828713801694585, 0.9538832846997023, 0.3879589757371321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 364}], {
             RGBColor[
             0.7846778728679218, 0.8196892010885023, 0.6819428779935603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 366}], {
             RGBColor[
             0.9861081615904057, 0.9648017084649758, 0.40053326034262915`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 380}], {
             RGBColor[
             0.9906592673257753, 0.9789721241389575, 0.5186824523722909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 389}], {
             RGBColor[
             0.8490283085634023, 0.8708779087194033, 0.6877293201223689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 337}], {
             RGBColor[
             0.9924402942236281, 0.9852471313363715, 0.5028818991255106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 345}], {
             RGBColor[
             0.9521660175648574, 0.9573827506384911, 0.7053694511125908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 353}], {
             RGBColor[
             0.9799004537483804, 0.978641150033801, 0.6783267721106088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 391}], {
             RGBColor[
             0.973470472721365, 0.922171816439245, 0.351438225513697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 364}], {
             RGBColor[
             0.751584761582829, 0.6976349306661025, 0.6076678186238431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 366}], {
             RGBColor[
             0.9530150503053129, 0.8427474380425761, 0.32625820097291186`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 391}], {
             RGBColor[
             0.9383798738001554, 0.7933795511878224, 0.2694033038715543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 349}], {
             RGBColor[
             0.9943330229667005, 0.9918245364355365, 0.7363083588412098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 355}], {
             RGBColor[
             0.994505888183249, 0.9906569753009111, 0.6433780183535839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 359}], {
             RGBColor[
             0.9573511778092442, 0.9652615614886536, 0.8446642100839157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 345}], {
             RGBColor[
             0.9537102444347179, 0.9616774431163317, 0.7891179801249462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 353}], {
             RGBColor[
             0.9814446806182409, 0.9829358425116417, 0.7620753011229642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 391}], {
             RGBColor[
             0.9750146995912254, 0.9264665089170858, 0.4351867545260524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 340}], {
             RGBColor[
             0.9934579336218188, 0.9914050663617523, 0.7466240771376056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 361}], {
             RGBColor[
             0.98813285676719, 0.975044668848853, 0.5896859776342507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 382}], {
             RGBColor[
             0.9917164308031283, 0.9908425455061449, 0.7869437089894549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 343}], {
             RGBColor[
             0.930340224398909, 0.943790558487617, 0.8475027481136059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 358}], {
             RGBColor[
             0.9933410812876806, 0.9913567449186181, 0.7485606227184227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 361}], {
             RGBColor[
             0.9897741970942051, 0.9755657699400939, 0.5510262974816824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 358}], {
             RGBColor[
             0.9931131016356269, 0.9908691194951542, 0.7237464445197155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 348}], {
             RGBColor[
             0.9304079415202728, 0.7506153938216911, 0.5247993219135041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 374}], {
             RGBColor[
             0.9286376517628818, 0.736817247857693, 0.3061299777547986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 346}], {
             RGBColor[
             0.8651218953252277, 0.8065779096109624, 0.6226370462966777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 354}], {
             RGBColor[
             0.8907913779727777, 0.9146880029319617, 0.9459966637283235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 350}], {
             RGBColor[
             0.9342522095662048, 0.9499118837627676, 0.976273551663765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 353}], {
             RGBColor[
             0.9411704039594702, 0.9550714618137612, 0.9645628531100443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 354}], {
             RGBColor[
             0.9585279028928366, 0.8796231337383528, 0.5881941302268134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 398}], {
             RGBColor[
             0.8685256734637179, 0.8937315500609064, 0.7292692217618907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 354}], {
             RGBColor[
             0.986515844636316, 0.9886919694771998, 0.8731308804591049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 374}], {
             RGBColor[
             0.9870640139748541, 0.9758525659310495, 0.6160386691010452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 378}], {
             RGBColor[
             0.9907928475957278, 0.9882774980550348, 0.6435599453502061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 355}], {
             RGBColor[
             0.9936728711920182, 0.9904125385410738, 0.6644549121515473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 355}], {
             RGBColor[
             0.9900756919275124, 0.9773564260178866, 0.4864125136326198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 395}], {
             RGBColor[
             0.9907551893585894, 0.9788098023152316, 0.5603716156332932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 399}], {
             RGBColor[
             0.9663962746198388, 0.8955066514809877, 0.33855038227576484`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 396}], {
             RGBColor[
             0.9938174698715674, 0.9891845181419924, 0.5684479335523924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 391}], {
             RGBColor[
             0.9624748591159777, 0.9198605276145152, 0.6106316275111505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 400}], {
             RGBColor[
             0.9699551364713331, 0.9771131704910447, 0.9357422963853369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 374}], {
             RGBColor[
             0.9847455548789249, 0.9748938235132018, 0.6544615363003995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 359}], {
             RGBColor[
             0.9869206785130775, 0.9660016425106833, 0.5347147353048802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 360}], {
             RGBColor[
             0.9485191062493241, 0.8268368540204369, 0.3126707645549146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 364}], {
             RGBColor[
             0.7806481609558462, 0.8060960365877194, 0.666288208162388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 380}], {
             RGBColor[
             0.9866295554136997, 0.9653789596381747, 0.5030277825411187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 389}], {
             RGBColor[
             0.8449985966513267, 0.8572847442186204, 0.6720746502911965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 360}], {
             RGBColor[
             0.9565981165050187, 0.8525483763322009, 0.475081193953835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 380}], {
             RGBColor[
             0.956306993405641, 0.8519256934596923, 0.4433942411900735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 389}], {
             RGBColor[
             0.814676034643268, 0.743831478040138, 0.6124411089401514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 382}], {
             RGBColor[
             0.9880326942755147, 0.9750032490844865, 0.5913459293335316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 365}], {
             RGBColor[
             0.9538512686509611, 0.8420135262836691, 0.4518352289865484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 385}], {
             RGBColor[
             0.9930488826227246, 0.9869138454712622, 0.5380855926720123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 383}], {
             RGBColor[
             0.9847167574238791, 0.9869937739276218, 0.8602141878676077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 393}], {
             RGBColor[
             0.9499828363606369, 0.854998360367589, 0.5885373339319754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 366}], {
             RGBColor[
             0.7838849423767934, 0.817014460352993, 0.678862492767885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 380}], {
             RGBColor[
             0.7884360481121631, 0.8311848760269747, 0.7970116847975468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 391}], {
             RGBColor[
             0.769249765871636, 0.7676465734982394, 0.6220075956665275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 377}], {
             RGBColor[
             0.9529474317515094, 0.8400803105476702, 0.3534581603160012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 388}], {
             RGBColor[
             0.950050231786538, 0.8304922812085958, 0.3264799767698362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 372}], {
             RGBColor[
             0.9390694717874795, 0.9486994169686986, 0.7067087405683692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 387}], {
             RGBColor[
             0.9937555430129766, 0.9889034545014674, 0.5743441587158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 387}], {
             RGBColor[
             0.9405628055747557, 0.9520421152922416, 0.8566123259728016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 392}], {
             RGBColor[
             0.8980582361676697, 0.7968377901240631, 0.6178059489730358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 390}], {
             RGBColor[
             0.9765677121524801, 0.9325609107468291, 0.3684551701579495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 381}], {
             RGBColor[
             0.9927139052433611, 0.991255026821105, 0.7704129761336926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 397}], {
             RGBColor[
             0.9351032039570264, 0.9493346472049273, 0.9283972180994866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 388}], {
             RGBColor[
             0.9899054047596086, 0.9774257948721179, 0.4310079417783367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 389}], {
             RGBColor[
             0.8527864838076435, 0.8823735836578757, 0.8027981269263553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 393}], {
             RGBColor[
             0.9562512306026958, 0.8585447292298674, 0.527386042846804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 400}], {
             RGBColor[
             0.9812464597608195, 0.9804219575161763, 0.67769767067052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 395}], {
             RGBColor[
             0.991106468032679, 0.979994747767091, 0.5617362669487199]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.027885652381746694`], {
             RGBColor[
             0.9930861440509956, 0.987620286160172, 0.4888476312029485]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.027885652381746694`], {
             RGBColor[
             0.9559930988467875, 0.8632165304777597, 0.2835419283360794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.027885652381746694`], {
             RGBColor[
             0.9346518390518765, 0.7786233483640931, 0.2662775396638998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.027885652381746694`], {
             RGBColor[
             0.8992109096743582, 0.9224703872171601, 0.9902487333714375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.027885652381746694`], {
             RGBColor[
             0.9883631165855262, 0.9724082011521291, 0.40929333468615314`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.027885652381746694`], {
             RGBColor[
             0.9792762395927103, 0.94175603135518, 0.37399253348179556`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.027885652381746694`], {
             RGBColor[
             0.9881829053869522, 0.9718003064637369, 0.4085932482097219]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.027885652381746694`], {
             RGBColor[
             0.9691029525535421, 0.9074391453706757, 0.33447123439868237`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.027885652381746694`], {
             RGBColor[
             0.9937506295810697, 0.9890415535192079, 0.5611727804221794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.027885652381746694`], {
             RGBColor[
             0.798153975288303, 0.8422432187808895, 0.9805161871499176]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.027885652381746694`], {
             RGBColor[
             0.8886272765450696, 0.58716429919914, 0.22878020836499358`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.027885652381746694`], {
             RGBColor[
             0.8317096564988627, 0.8686467202077264, 0.9838104035844787]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.027885652381746694`], {
             RGBColor[
             0.9946761839910044, 0.992066479511519, 0.7378929390706312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.027885652381746694`], {
             RGBColor[
             0.9520269916624782, 0.8475100385387522, 0.2802579953016399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.027885652381746694`], {
             RGBColor[
             0.9892783173016081, 0.9898343229166073, 0.8273495593451259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.027885652381746694`], {
             RGBColor[
             0.9930644589476681, 0.9875739039168548, 0.4864873415307017]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.027885652381746694`], {
             RGBColor[
             0.9460832915606517, 0.9593095876432173, 0.9761511030448174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.027885652381746694`], {
             RGBColor[
             0.9883631165855262, 0.9724082011521291, 0.40929333468615314`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.027885652381746694`], {
             RGBColor[
             0.9949184752990232, 0.991539457422596, 0.688285579713084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.027885652381746694`], {
             RGBColor[
             0.9877014458379237, 0.9891822460426256, 0.8534824003109107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.027885652381746694`], {
             RGBColor[
             0.9869282565780527, 0.9888625124136113, 0.8662961472966357]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.027885652381746694`], {
             RGBColor[
             0.9525244119497205, 0.849482144222183, 0.28065823134070983`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.027885652381746694`], {
             RGBColor[
             0.9304534456963692, 0.7619781177411565, 0.2628994138211006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.027885652381746694`], {
             RGBColor[
             0.99154517320549, 0.9907717260884019, 0.7897818905827778]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.027885652381746694`], {
             RGBColor[
             0.99512784667596, 0.9919872816271702, 0.711074362002282]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.027885652381746694`], {
             RGBColor[
             0.993914843746764, 0.9893927910150287, 0.5790464789456343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.027885652381746694`], {
             RGBColor[
             0.9927727259721875, 0.9869499165810299, 0.4547340075168541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.027885652381746694`], {
             RGBColor[
             0.9930734060887443, 0.9875930409469219, 0.4874611826214824]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.027885652381746694`], {
             RGBColor[
             0.9875676884133577, 0.9697250351519883, 0.4062032464412848]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.027885652381746694`], {
             RGBColor[
             0.9935370571691271, 0.9885847437255457, 0.5379267413983673]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.027885652381746694`], {
             RGBColor[
             0.9934811663893628, 0.9884651989990545, 0.5318433749389271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.027885652381746694`], {
             RGBColor[
             0.9865985906772946, 0.9887261870916206, 0.8717595644202005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.027885652381746694`], {
             RGBColor[
             0.9727009018121912, 0.9195758730587589, 0.34844858785282806`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.027885652381746694`], {
             RGBColor[
             0.9872662624931355, 0.989002286545854, 0.860694514552444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.027885652381746694`], {
             RGBColor[
             0.9947646573311367, 0.9912104563426689, 0.6715434431630978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.027885652381746694`], {
             RGBColor[
             0.9859657847772625, 0.9884645055895875, 0.8822467958329054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.027885652381746694`], {
             RGBColor[
             0.9872342706445634, 0.9889890570943163, 0.8612247022755358]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.027885652381746694`], {
             RGBColor[
             0.9734509705110198, 0.9221060309044138, 0.35136246310918917`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.027885652381746694`], {
             RGBColor[
             0.9611841691012698, 0.9705717973875926, 0.9505892563081921]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.027885652381746694`], {
             RGBColor[
             0.9924100947171393, 0.9911293933609379, 0.7754479027896273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.027885652381746694`], {
             RGBColor[
             0.9892817822433501, 0.9898357557590626, 0.8272921362934798]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.027885652381746694`], {
             RGBColor[
             0.9949003554465923, 0.9915007008904443, 0.6863133455987406]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.027885652381746694`], {
             RGBColor[
             0.9925624558183797, 0.9911923985918024, 0.7729228850441847]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.027885652381746694`], {
             RGBColor[
             0.9926556991980612, 0.9912309571255463, 0.77137760093673]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.027885652381746694`], {
             RGBColor[
             0.9573416905789174, 0.8677656470546307, 0.2887809525552246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.027885652381746694`], {
             RGBColor[
             0.9917576991927056, 0.9838589253720447, 0.4224806471019091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.027885652381746694`], {
             RGBColor[
             0.9858448725929354, 0.9884145052940669, 0.8842506236379069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.027885652381746694`], {
             RGBColor[
             0.7111555250452706, 0.7742793682383214, 0.9718449946764333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.027885652381746694`], {
             RGBColor[
             0.9831063133388306, 0.9546757694449256, 0.3888716467367362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.027885652381746694`], {
             RGBColor[
             0.986594433673119, 0.988724468063564, 0.87182845673737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.027885652381746694`], {
             RGBColor[
             0.9914825511582972, 0.9907458302625745, 0.7908196999654242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.027885652381746694`], {
             RGBColor[
             0.984321954842721, 0.9877847396671523, 0.9094893119437599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.027885652381746694`], {
             RGBColor[
             0.9936277281302802, 0.9887786797432119, 0.5477957159635749]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.027885652381746694`], {
             RGBColor[
             0.9675262754595562, 0.9753017299253565, 0.9398537245298677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.027885652381746694`], {
             RGBColor[
             0.9688391060915171, 0.9762808368611101, 0.9376314447110246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.027885652381746694`], {
             RGBColor[
             0.9273536865411683, 0.7496886056242903, 0.260405274844127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.027885652381746694`], {
             RGBColor[
             0.9941324981131973, 0.9898583316965975, 0.602736813524855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.027885652381746694`], {
             RGBColor[
             0.9902185796452314, 0.9902231455593355, 0.8117669789903447]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.027885652381746694`], {
             RGBColor[
             0.9950722735447556, 0.9922302727210324, 0.7313287101180673]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.027885652381746694`], {
             RGBColor[
             0.951599798943126, 0.9634237898166147, 0.966813094981844]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.027885652381746694`], {
             RGBColor[
             0.9248625591072026, 0.7398121154676233, 0.25840085523648193`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.027885652381746694`], {
             RGBColor[
             0.9746250492367691, 0.9260664741331603, 0.3559235372525616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.027885652381746694`], {
             RGBColor[
             0.96982156048864, 0.909863178672928, 0.337262890528816]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.027885652381746694`], {
             RGBColor[
             0.9941598606730996, 0.9899168574454494, 0.605715059308073]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.027885652381746694`], {
             RGBColor[
             0.9949708141315363, 0.9916514048930738, 0.693982338634301]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.027885652381746694`], {
             RGBColor[
             0.9802232789297279, 0.9449506174143516, 0.37767160247273696`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.027885652381746694`], {
             RGBColor[
             0.9799284229303955, 0.9439559988931222, 0.37652614259421363`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.027885652381746694`], {
             RGBColor[
             0.9344503700164746, 0.7778245907743002, 0.26611543294892925`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.027885652381746694`], {
             RGBColor[
             0.9835600753625003, 0.9872597116400345, 0.9127126835789452]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.027885652381746694`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.027885652381746694`], {
             RGBColor[
             0.9934458169542834, 0.9883895901317957, 0.5279958070819608]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.027885652381746694`], {
             RGBColor[
             0.9931097510449712, 0.9876707791332526, 0.4914171068117146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.027885652381746694`], {
             RGBColor[
             0.9925940016386313, 0.9865676433033554, 0.43528096676800815`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.027885652381746694`], {
             RGBColor[
             0.9909776694547693, 0.9905370487032977, 0.7991868963848463]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.027885652381746694`], {
             RGBColor[
             0.9905907050704742, 0.9799223801745075, 0.4179470953053879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.027885652381746694`], {
             RGBColor[
             0.9936217677709013, 0.9916304513072456, 0.7553673445794461]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.027885652381746694`], {
             RGBColor[
             0.9928672155522575, 0.9913184245737289, 0.7678722275609174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.027885652381746694`], {
             RGBColor[
             0.9943909111884691, 0.9919485118764941, 0.7426206476709887]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.027885652381746694`], {
             RGBColor[
             0.9917673305104361, 0.9908635938431795, 0.7861001691151444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.027885652381746694`], {
             RGBColor[
             0.9911932619053747, 0.9906262017220964, 0.7956139715429369]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.027885652381746694`], {
             RGBColor[
             0.9945751796800414, 0.9908051828061051, 0.6509199701618857]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.027885652381746694`], {
             RGBColor[
             0.9948572165403624, 0.991408431132031, 0.6816179418780891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.027885652381746694`], {
             RGBColor[
             0.9594324743930281, 0.9692653863423228, 0.9535544185340953]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.027885652381746694`], {
             RGBColor[
             0.9505688614497529, 0.8417290381383858, 0.2790847495057661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.027885652381746694`], {
             RGBColor[
             0.9581092187076699, 0.8703546996570872, 0.2917626543999026]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.027885652381746694`], {
             RGBColor[
             0.9939902335702518, 0.9895540422243889, 0.5872521959802309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.027885652381746694`], {
             RGBColor[
             0.9948018701894162, 0.9912900508837317, 0.6755938331356818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.027885652381746694`], {
             RGBColor[
             0.9065057310577697, 0.667033409301946, 0.243630520497774]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.027885652381746694`], {
             RGBColor[
             0.99154517320549, 0.9907717260884019, 0.7897818905827778]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.027885652381746694`], {
             RGBColor[
             0.99366494044298, 0.9888582731173349, 0.5518460465531763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.027885652381746694`], {
             RGBColor[
             0.9392691854484304, 0.7969295881869539, 0.26999276495761676`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.027885652381746694`], {
             RGBColor[
             0.9716152099636187, 0.9783512505834706, 0.9329322249794071]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.027885652381746694`], {
             RGBColor[
             0.3272883359570442, 0.45790243944108844`, 0.9420755012508389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.027885652381746694`], {
             RGBColor[
             0.9932784279868204, 0.9880315620560133, 0.5097765509785837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.027885652381746694`], {
             RGBColor[
             0.9705601220032949, 0.9123545200843494, 0.3401320625476113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.027885652381746694`], {
             RGBColor[
             0.9010792328693557, 0.6437057246394358, 0.2391704259473575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.027885652381746694`], {
             RGBColor[
             0.9938570942073877, 0.989269270589677, 0.5727607979733689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.027885652381746694`], {
             RGBColor[
             0.9913755812709028, 0.9907015954651361, 0.792592467828745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.027885652381746694`], {
             RGBColor[
             0.9480806176441668, 0.8318639806073318, 0.2770826501332027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.027885652381746694`], {
             RGBColor[
             0.9938414129850087, 0.9892357300406233, 0.571053993690713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.027885652381746694`], {
             RGBColor[
             0.9560163607462246, 0.8632949983267149, 0.28363229642275145`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.027885652381746694`], {
             RGBColor[
             0.9751413642490502, 0.9809810506759976, 0.9269633655425001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.027885652381746694`], {
             RGBColor[
             0.8849116741524323, 0.5702926165351606, 0.22567981865082817`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.027885652381746694`], {
             RGBColor[
             0.9602261134514041, 0.8774954826982255, 0.2999863907372813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.027885652381746694`], {
             RGBColor[
             0.9918517669154322, 0.990898510466562, 0.7847008393699477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.027885652381746694`], {
             RGBColor[
             0.9902051523963707, 0.9902175930468672, 0.8119895032525709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.027885652381746694`], {
             RGBColor[
             0.9774304116880199, 0.9355296204116574, 0.3668218406274252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.027885652381746694`], {
             RGBColor[
             0.861842519151565, 0.8926738469522238, 0.9866845029242174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.027885652381746694`], {
             RGBColor[
             0.9899819421210111, 0.9901252898617635, 0.8156886751649561]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.027885652381746694`], {
             RGBColor[
             0.968904840142993, 0.9763298612090712, 0.9375201741080623]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.027885652381746694`], {
             RGBColor[
             0.9855500525968304, 0.9629190757794229, 0.39836511229262894`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.027885652381746694`], {
             RGBColor[
             0.8914317990285513, 0.5998989807837629, 0.23112037067034744`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.027885652381746694`], {
             RGBColor[
             0.8770137095002746, 0.5344298036662221, 0.2190895633482388]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.027885652381746694`], {
             RGBColor[
             0.9568284842879898, 0.9673233347856277, 0.9579622945525346]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.027885652381746694`], {
             RGBColor[
             0.9427701117926304, 0.9568386235970608, 0.9817594521763994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.027885652381746694`], {
             RGBColor[
             0.9952243929029052, 0.9921937842442853, 0.721582822991031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.027885652381746694`], {
             RGBColor[
             0.9950343671132496, 0.9917873382947663, 0.7008996884902482]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.027885652381746694`], {
             RGBColor[
             0.990665492409019, 0.9904079554722959, 0.8043604779212262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.027885652381746694`], {
             RGBColor[
             0.9373514724290681, 0.9527974112319237, 0.9909317952114224]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.027885652381746694`], {
             RGBColor[
             0.9929189400247798, 0.9872626536550166, 0.47064850481299464`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.027885652381746694`], {
             RGBColor[
             0.9934184415156507, 0.991546370675453, 0.7587369868204288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.027885652381746694`], {
             RGBColor[
             0.9930551918468201, 0.9875540825251886, 0.4854786747933127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.027885652381746694`], {
             RGBColor[
             0.9947039064479224, 0.9910805163463299, 0.6649310844362079]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.027885652381746694`], {
             RGBColor[
             0.9380322570016475, 0.7920255790774303, 0.26899750329489297`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.027885652381746694`], {
             RGBColor[
             0.9932629901153213, 0.9879985420098847, 0.5080962339373976]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.027885652381746694`], {
             RGBColor[
             0.9134359677759472, 0.9338130624184513, 0.9916055321120263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.027885652381746694`], {
             RGBColor[
             0.9207039827548265, 0.7233247459938725, 0.2550547670890273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.027885652381746694`], {
             RGBColor[
             0.8583373130148272, 0.4494117281713356, 0.203497182866557]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.027885652381746694`], {
             RGBColor[
             0.9946310470698988, 0.9909246775039505, 0.6570007907743002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.027885652381746694`], {
             RGBColor[
             0.9070192589610362, 0.9286965529863621, 0.9909935006969965]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.027885652381746694`], {
             RGBColor[
             0.9884082483135531, 0.9894745270302935, 0.8417688541435596]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.027885652381746694`], {
             RGBColor[
             0.9937014586145031, 0.988936381793669, 0.5558208241594245]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.027885652381746694`], {
             RGBColor[
             0.9847009921494411, 0.9879414813342955, 0.9032076828543033]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.027885652381746694`], {
             RGBColor[
             0.9334612674375506, 0.7739031286477622, 0.2653195777967055]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.027885652381746694`], {
             RGBColor[
             0.9870791176508882, 0.9889248973441815, 0.863795988903811]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.027885652381746694`], {
             RGBColor[
             0.8194043630971992, 0.8588441832461284, 0.9826342272105436]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.027885652381746694`], {
             RGBColor[
             0.9926151481337063, 0.9912141882183207, 0.7720496370158799]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.027885652381746694`], {
             RGBColor[
             0.8648828584702022, 0.895098130997093, 0.986974493202572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.027885652381746694`], {
             RGBColor[
             0.918660827387957, 0.7152243158054001, 0.25341079632182373`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.027885652381746694`], {
             RGBColor[
             0.9924589415499603, 0.9911495927816157, 0.7746383843582321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.027885652381746694`], {
             RGBColor[
             0.9580625687313542, 0.8701973383330391, 0.29158142805102494`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.027885652381746694`], {
             RGBColor[
             0.9254512489958748, 0.7421460747069324, 0.2588745289392353]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.027885652381746694`], {
             RGBColor[
             0.9931032360853698, 0.9876568442934286, 0.4907079936647675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.027885652381746694`], {
             RGBColor[
             0.9564916221788328, 0.8648981667355929, 0.2854785973428431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.027885652381746694`], {
             RGBColor[
             0.8572219461754736, 0.44083852988719874`, 0.20242910632156536`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.027885652381746694`], {
             RGBColor[
             0.9929295406370127, 0.9872853272926964, 0.4718023160351457]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.027885652381746694`], {
             RGBColor[
             0.9271642658783718, 0.748937615816996, 0.2602528625325665]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.027885652381746694`], {
             RGBColor[
             0.9660160148270182, 0.897026179571664, 0.3224790642504119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.027885652381746694`], {
             RGBColor[
             0.9950523662397035, 0.9918258366062603, 0.7028587823270187]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.027885652381746694`], {
             RGBColor[
             0.9624146007879901, 0.884877764365793, 0.30848825077876235`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.027885652381746694`], {
             RGBColor[
             0.9938447268264493, 0.9892428180123839, 0.5714146848808597]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.027885652381746694`], {
             RGBColor[
             0.8408981020509119, 0.8759733372772202, 0.9846868057238553]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.027885652381746694`], {
             RGBColor[
             0.9936334579695936, 0.9887909352901273, 0.5484193736123546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.027885652381746694`], {
             RGBColor[
             0.8223609822767148, 0.8611923411459873, 0.9829187186915102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.027885652381746694`], {
             RGBColor[
             0.857820466812359, 0.8894667715926434, 0.9863008759815755]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.027885652381746694`], {
             RGBColor[
             0.9861401494233937, 0.9885366098517299, 0.8793571224052721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.027885652381746694`], {
             RGBColor[
             0.9647518632619441, 0.8927618995057665, 0.317568074135091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.027885652381746694`], {
             RGBColor[
             0.9671389832096936, 0.9008142156119435, 0.32684158436232125`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.027885652381746694`], {
             RGBColor[
             0.9867226654628507, 0.9887774952040247, 0.8697033241282833]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.027885652381746694`], {
             RGBColor[
             0.9411608386571664, 0.8044293628035282, 0.27151483353217337`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.027885652381746694`], {
             RGBColor[
             0.9580436495715666, 0.8701335195646457, 0.29150793068783376`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.027885652381746694`], {
             RGBColor[
             0.9824507018121912, 0.9524642378206639, 0.3863247197575902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.027885652381746694`], {
             RGBColor[
             0.9893610433392342, 0.9898685322591279, 0.8259785748135386]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.027885652381746694`], {
             RGBColor[
             0.9925041640287912, 0.9863754897398829, 0.4255026973503576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.027885652381746694`], {
             RGBColor[
             0.9952489113257568, 0.9922462266715719, 0.7242515020082513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.027885652381746694`], {
             RGBColor[
             0.5824546536543096, 0.6719019529765194, 0.9602721104188162]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.027885652381746694`], {
             RGBColor[
             0.9935708776771005, 0.988657082372323, 0.5416078949752887]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.027885652381746694`], {
             RGBColor[
             0.9933438125630727, 0.9881714130532221, 0.5168932585968115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.027885652381746694`], {
             RGBColor[
             0.948663297573641, 0.8341741123611208, 0.2775514880817134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.027885652381746694`], {
             RGBColor[
             0.9736575235704609, 0.9228027828748732, 0.35216488274084534`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.027885652381746694`], {
             RGBColor[
             0.9931580699981781, 0.9877741284883668, 0.4966763266782783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.027885652381746694`], {
             RGBColor[
             0.7111555250452706, 0.7742793682383214, 0.9718449946764333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.027885652381746694`], {
             RGBColor[
             0.9334301876476412, 0.9497559106154998, 0.9935125986524393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.027885652381746694`], {
             RGBColor[
             0.9948881590856444, 0.991474614107618, 0.6849858469767767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.027885652381746694`], {
             RGBColor[
             0.993617480022574, 0.9887567600770709, 0.5466802726837421]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.027885652381746694`], {
             RGBColor[
             0.8603742858677746, 0.4588740671871647, 0.20520522039968492`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.027885652381746694`], {
             RGBColor[
             0.8606980327135795, 0.8917612645328311, 0.9865753407860673]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.027885652381746694`], {
             RGBColor[
             0.9762195238879736, 0.9314450115321252, 0.36211777018121916`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.027885652381746694`], {
             RGBColor[
             0.6967087688444502, 0.7629934524948268, 0.970405077030948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.027885652381746694`], {
             RGBColor[
             0.9764721156472022, 0.9322970628473684, 0.36309904146787053`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.027885652381746694`], {
             RGBColor[
             0.9523311498464582, 0.848715924383526, 0.2805027281159803]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.027885652381746694`], {
             RGBColor[
             0.9944619180275623, 0.990562927583962, 0.6385921382594357]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.027885652381746694`], {
             RGBColor[
             0.9876107342690663, 0.9891447344777221, 0.854985725760893]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.027885652381746694`], {
             RGBColor[
             0.994169812268257, 0.9899381429012304, 0.6067982290268269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.027885652381746694`], {
             RGBColor[
             0.9764721156472022, 0.9322970628473684, 0.36309904146787053`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.027885652381746694`], {
             RGBColor[
             0.9934646926640639, 0.9915654967139222, 0.757970485597087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.027885652381746694`], {
             RGBColor[
             0.8904820048462759, 0.9155101954470569, 0.9894161626365496]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.027885652381746694`], {
             RGBColor[
             0.993914843746764, 0.9893927910150287, 0.5790464789456343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.027885652381746694`], {
             RGBColor[
             0.9594707665628807, 0.9692939445799011, 0.9534895998787325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.027885652381746694`], {
             RGBColor[
             0.9861401494233937, 0.9885366098517299, 0.8793571224052721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.027885652381746694`], {
             RGBColor[
             0.9952393560704541, 0.9922257889466639, 0.7232114714367541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.027885652381746694`], {
             RGBColor[
             0.9892783173016081, 0.9898343229166073, 0.8273495593451259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.027885652381746694`], {
             RGBColor[
             0.9948195216286185, 0.991327805527351, 0.6775150833607911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.027885652381746694`], {
             RGBColor[
             0.934071191053961, 0.7763212725418329, 0.26581033665521664`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.027885652381746694`], {
             RGBColor[
             0.9662083061335178, 0.8976748233006331, 0.3232260796649967]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.027885652381746694`], {
             RGBColor[
             0.9889345781520125, 0.9896921779445563, 0.8330462066223285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.027885652381746694`], {
             RGBColor[
             0.9890458106175689, 0.9747110884263903, 0.4119454720846884]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.027885652381746694`], {
             RGBColor[
             0.9925874468407818, 0.9865536232535471, 0.4345675174736115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.027885652381746694`], {
             RGBColor[
             0.7973853704051688, 0.8416427788045715, 0.9804395797981877]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.027885652381746694`], {
             RGBColor[
             0.9934671967992469, 0.9915665322381737, 0.7579289855966109]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.027885652381746694`], {
             RGBColor[
             0.9745864284926544, 0.9805671804975016, 0.9279027270276526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.027885652381746694`], {
             RGBColor[
             0.9597673787529838, 0.9695151574656221, 0.9529875128097369]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.027885652381746694`], {
             RGBColor[
             0.9928314849738588, 0.9870755961441584, 0.46112956223024765`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.027885652381746694`], {
             RGBColor[
             0.9736661715757873, 0.9228319546274872, 0.3521984786084996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.027885652381746694`], {
             RGBColor[
             0.8371951862192364, 0.8730207327060148, 0.9843336183061981]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.027885652381746694`], {
             RGBColor[
             0.9949817018654237, 0.99167469265494, 0.6951674012766274]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.027885652381746694`], {
             RGBColor[
             0.9931045314914411, 0.9876596150360294, 0.4908489906213065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.027885652381746694`], {
             RGBColor[
             0.9937481989354776, 0.9916827338429306, 0.7532720529890505]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.027885652381746694`], {
             RGBColor[
             0.955071094396394, 0.8595788914916258, 0.28270735181562334`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.027885652381746694`], {
             RGBColor[
             0.9248592015603089, 0.7397988039130258, 0.25839815367543945`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.027885652381746694`], {
             RGBColor[
             0.9792035103663717, 0.9415106985971056, 0.3737099941712322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.027885652381746694`], {
             RGBColor[
             0.821232983127876, 0.8602929052434244, 0.9828111291257172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.027885652381746694`], {
             RGBColor[
             0.798153975288303, 0.8422432187808895, 0.9805161871499176]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.027885652381746694`], {
             RGBColor[
             0.992889898734508, 0.9872005372716498, 0.46748753958896666`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.027885652381746694`], {
             RGBColor[
             0.9878640092191103, 0.9707245948092257, 0.4073543968161449]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.027885652381746694`], {
             RGBColor[
             0.8903956165186151, 0.9154413117395288, 0.9894079228407376]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.027885652381746694`], {
             RGBColor[
             0.9822256013556717, 0.9862644631107423, 0.9149715999859428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.027885652381746694`], {
             RGBColor[
             0.9871632828148913, 0.9889597018024429, 0.8624011543238163]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.027885652381746694`], {
             RGBColor[
             0.939046566858649, 0.9540616098820428, 0.988062442493575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.027885652381746694`], {
             RGBColor[
             0.9618229060955518, 0.9710481663920922, 0.9495080411861615]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.027885652381746694`], {
             RGBColor[
             0.9938413043946221, 0.9892354977767663, 0.5710421742972676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.027885652381746694`], {
             RGBColor[
             0.9800003357610422, 0.9846048636738056, 0.9187383941954321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.027885652381746694`], {
             RGBColor[
             0.9883210609555189, 0.9894384728171335, 0.8432137742998356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.027885652381746694`], {
             RGBColor[
             0.8235301591809513, 0.1818686912120992, 0.17016581304617986`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.027885652381746694`], {
             RGBColor[
             0.9731193426688634, 0.9209873723228998, 0.35007415156507454`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.027885652381746694`], {
             RGBColor[
             0.9792035103663717, 0.9415106985971056, 0.3737099941712322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.027885652381746694`], {
             RGBColor[
             0.8842217138480811, 0.5671596679374251, 0.2251040988604029]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.027885652381746694`], {
             RGBColor[
             0.9739589089869085, 0.9800991774775851, 0.9289649538675814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.027885652381746694`], {
             RGBColor[
             0.9334301876476412, 0.9497559106154998, 0.9935125986524393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.027885652381746694`], {
             RGBColor[
             0.9943120879366497, 0.990242456169646, 0.62228405750774]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.027885652381746694`], {
             RGBColor[
             0.9945528871335677, 0.9907575013033202, 0.6484935640518776]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.027885652381746694`], {
             RGBColor[
             0.9821385137890558, 0.9514111543133948, 0.3851119282394708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.027885652381746694`], {
             RGBColor[
             0.8350324603371114, 0.27028041823885196`, 0.18118042962330994`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.027885652381746694`], {
             RGBColor[
             0.988223911005555, 0.9719386280438614, 0.40875254729473276`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.027885652381746694`], {
             RGBColor[
             0.9923024245423238, 0.9856964118839008, 0.4245968022224244]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.027885652381746694`], {
             RGBColor[
             0.9597673787529838, 0.9695151574656221, 0.9529875128097369]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.027885652381746694`], {
             RGBColor[
             0.9952194360481877, 0.9922911281981054, 0.7288898465918455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.027885652381746694`], {
             RGBColor[
             0.9199748102168913, 0.7204338198633036, 0.2544680577491254]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.027885652381746694`], {
             RGBColor[
             0.9201228220757827, 0.7210206375617799, 0.2545871515650743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.027885652381746694`], {
             RGBColor[
             0.9864117286099435, 0.9886489148246349, 0.8748563524597357]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.027885652381746694`], {
             RGBColor[
             0.9948666402682984, 0.9914285875332011, 0.6826436565074133]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.027885652381746694`], {
             RGBColor[
             0.9925319116721582, 0.9864348391433279, 0.42852285709225746`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.027885652381746694`], {
             RGBColor[
             0.9931980655396879, 0.9914552395459881, 0.762389187056876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.027885652381746694`], {
             RGBColor[
             0.9609261710007776, 0.8798569411935918, 0.30270598212182215`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.027885652381746694`], {
             RGBColor[
             0.9927451102663447, 0.9912679309000412, 0.7698958281468438]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.027885652381746694`], {
             RGBColor[
             0.9911473946916882, 0.9818002249838014, 0.4201097293617905]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.027885652381746694`], {
             RGBColor[
             0.9912532466214476, 0.9906510069437294, 0.7946198695621398]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.027885652381746694`], {
             RGBColor[
             0.9367001502716246, 0.7867442197911425, 0.2679256589513528]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.027885652381746694`], {
             RGBColor[
             0.9886461501529773, 0.9733629398345832, 0.4103928666492959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.027885652381746694`], {
             RGBColor[
             0.9943663492586491, 0.9903585156507414, 0.6281900675453058]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.027885652381746694`], {
             RGBColor[
             0.3272883359570442, 0.45790243944108844`, 0.9420755012508389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.027885652381746694`], {
             RGBColor[
             0.9939238027938353, 0.9894119535108157, 0.5800216159305149]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.027885652381746694`], {
             RGBColor[
             0.9660160148270182, 0.897026179571664, 0.3224790642504119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.027885652381746694`], {
             RGBColor[
             0.9857536311412821, 0.98837677460901, 0.8857627306171107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.027885652381746694`], {
             RGBColor[
             0.9232092553056369, 0.7332573168252478, 0.2570705681897142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.027885652381746694`], {
             RGBColor[
             0.9944668492753269, 0.9905734750243049, 0.6391288741464807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.027885652381746694`], {
             RGBColor[
             0.9396942660619803, 0.9545446628873772, 0.9869660566893425]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.027885652381746694`], {
             RGBColor[
             0.9879322242959399, 0.9892776788657511, 0.849657804026078]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.027885652381746694`], {
             RGBColor[
             0.9916086932447887, 0.9907979932570425, 0.788729199147004]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.027885652381746694`], {
             RGBColor[
             0.848406205828693, 0.37307688649979, 0.19398714340953352`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.027885652381746694`], {
             RGBColor[
             0.9415073933091661, 0.8058033365162152, 0.2717936795398555]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.027885652381746694`], {
             RGBColor[
             0.926190926589446, 0.7450786498824961, 0.2594696908934873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.027885652381746694`], {
             RGBColor[
             0.9718014144975289, 0.9165416911367382, 0.34495424948929176`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.027885652381746694`], {
             RGBColor[
             0.9893137408017573, 0.9898489714442614, 0.8267625002745745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.027885652381746694`], {
             RGBColor[
             0.9935537753560315, 0.9886205022368663, 0.5397464128702184]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.027885652381746694`], {
             RGBColor[
             0.9938971632717137, 0.9917443344241731, 0.7508033284302725]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.027885652381746694`], {
             RGBColor[
             0.9797356981238782, 0.943305892866803, 0.3757774431139199]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.027885652381746694`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.027885652381746694`], {
             RGBColor[
             0.49286611451777157`, 0.5991699409877828, 0.9532193724443558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.027885652381746694`], {
             RGBColor[
             0.8919957471675406, 0.9167172124845926, 0.9895605447304856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.027885652381746694`], {
             RGBColor[
             0.9881940261017298, 0.9893859406404448, 0.8453190705827843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.027885652381746694`], {
             RGBColor[
             0.9937517506233237, 0.9890439513152341, 0.5612947989532417]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.027885652381746694`], {
             RGBColor[
             0.9899486537222669, 0.99011152425341, 0.8162403500797624]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.027885652381746694`], {
             RGBColor[
             0.9938408282169334, 0.9892344792808392, 0.5709903452944816]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.027885652381746694`], {
             RGBColor[
             0.9940541892705107, 0.9896908370003296, 0.5942133792645804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.027885652381746694`], {
             RGBColor[
             0.994136898008652, 0.9898677426280775, 0.6032157149920899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.027885652381746694`], {
             RGBColor[
             0.9874319518478194, 0.9692671638439659, 0.4056759355158676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.027885652381746694`], {
             RGBColor[
             0.9949320983864428, 0.9915685958290809, 0.6897683687067452]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.027885652381746694`], {
             RGBColor[
             0.9925041640287912, 0.9863754897398829, 0.4255026973503576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.027885652381746694`], {
             RGBColor[
             0.9823001179983526, 0.9519562832578257, 0.3857397300761946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.027885652381746694`], {
             RGBColor[
             0.9651690917612035, 0.8941693092036784, 0.31918892806772264`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.027885652381746694`], {
             RGBColor[
             0.9948614694985118, 0.9914175277794727, 0.6820808501264409]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.027885652381746694`], {
             RGBColor[
             0.9942820928116058, 0.9901782996301495, 0.619019273255168]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.027885652381746694`], {
             RGBColor[
             0.9841820241888339, 0.9877235600563663, 0.9116598864461958]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.027885652381746694`], {
             RGBColor[
             0.9456852026359142, 0.9590126935749588, 0.976824963756178]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.027885652381746694`], {
             RGBColor[
             0.99478093872498, 0.991245280597798, 0.6733155724058134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.027885652381746694`], {
             RGBColor[
             0.9913612191103789, 0.9906956563426689, 0.7928304859967054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.027885652381746694`], {
             RGBColor[
             0.9878651681577265, 0.9892499494293358, 0.850769097771997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.027885652381746694`], {
             RGBColor[
             0.9867226654628507, 0.9887774952040247, 0.8697033241282833]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.027885652381746694`], {
             RGBColor[
             0.9932058018753559, 0.9878762221472169, 0.5018716469420782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.027885652381746694`], {
             RGBColor[
             0.9905907050704742, 0.9799223801745075, 0.4179470953053879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.027885652381746694`], {
             RGBColor[
             0.9936106299729738, 0.9887421085136221, 0.5459346870583551]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.027885652381746694`], {
             RGBColor[
             0.835671929269632, 0.8718061289621086, 0.9841883286985172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.027885652381746694`], {
             RGBColor[
             0.9618229060955518, 0.9710481663920922, 0.9495080411861615]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.027885652381746694`], {
             RGBColor[
             0.989933015904554, 0.9901050576139121, 0.8164995091886408]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.027885652381746694`], {
             RGBColor[
             0.9026393949600343, 0.6507900563080935, 0.24047226343889208`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.027885652381746694`], {
             RGBColor[
             0.976127916704865, 0.9817168198822128, 0.9252933895688955]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.027885652381746694`], {
             RGBColor[
             0.9618336265003532, 0.882918001674344, 0.3062312753790813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.027885652381746694`], {
             RGBColor[
             0.9781265275668848, 0.9378777827268496, 0.36952611936636176`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.027885652381746694`], {
             RGBColor[
             0.9672410138121912, 0.9011583887920924, 0.3272379539861617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.027885652381746694`], {
             RGBColor[
             0.992895862458357, 0.9872132930739382, 0.468136654126112]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.027885652381746694`], {
             RGBColor[
             0.9714520336505079, 0.9153631475012124, 0.34359697087365204`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.027885652381746694`], {
             RGBColor[
             0.9933303762870676, 0.9881426742174629, 0.5154308028727355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.027885652381746694`], {
             RGBColor[
             0.5946680938915773, 0.6818173739703458, 0.9612335971735996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.027885652381746694`], {
             RGBColor[
             0.9865244442016262, 0.9886955256184543, 0.8729883634069534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.027885652381746694`], {
             RGBColor[
             0.9885887848905626, 0.9731694333344542, 0.4101700134373355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.027885652381746694`], {
             RGBColor[
             0.9943415721513311, 0.9919281089166821, 0.7434383232017004]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.027885652381746694`], {
             RGBColor[
             0.9914251407055751, 0.982737127506507, 0.4211887201778073]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.027885652381746694`], {
             RGBColor[
             0.9941587699638477, 0.9899145245286473, 0.6055963423370863]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.027885652381746694`], {
             RGBColor[
             0.9899959762453407, 0.9901310933328343, 0.8154560934056646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.027885652381746694`], {
             RGBColor[
             0.9435100261344914, 0.9573904505017222, 0.980506970196196]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.027885652381746694`], {
             RGBColor[
             0.6970397328848617, 0.763252004118616, 0.9704380644334615]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.027885652381746694`], {
             RGBColor[
             0.9939239133630594, 0.9894121900072058, 0.5800336507082078]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.027885652381746694`], {
             RGBColor[
             0.9702163094110378, 0.9773079528418451, 0.9353001987232291]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.027885652381746694`], {
             RGBColor[
             0.9933359846871095, 0.9881546700180565, 0.516041242606265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.027885652381746694`], {
             RGBColor[
             0.9728177735965393, 0.9792481205718855, 0.9308965984277003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.027885652381746694`], {
             RGBColor[
             0.968904840142993, 0.9763298612090712, 0.9375201741080623]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.027885652381746694`], {
             RGBColor[
             0.9800409429376663, 0.9443355552986006, 0.37696326157484017`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.027885652381746694`], {
             RGBColor[
             0.9604654649917629, 0.87830287164627, 0.3009162262738294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.027885652381746694`], {
             RGBColor[
             0.9684679190986116, 0.9052970284142492, 0.3320042493422828]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.027885652381746694`], {
             RGBColor[
             0.9676244264672158, 0.9753749307861614, 0.9396875804757826]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.027885652381746694`], {
             RGBColor[
             0.9825026196793437, 0.9526393689774643, 0.3865264108676112]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.027885652381746694`], {
             RGBColor[
             0.9948297985335692, 0.9913497867878862, 0.6786336610429768]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.027885652381746694`], {
             RGBColor[
             0.9887449968271401, 0.9896137811947038, 0.8361880597962049]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.027885652381746694`], {
             RGBColor[
             0.9902801505634267, 0.9902486067163098, 0.8107465895354206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.027885652381746694`], {
             RGBColor[
             0.9949167658578183, 0.9921659662961185, 0.7339058749316113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.027885652381746694`], {
             RGBColor[
             0.9534333024194118, 0.9647912137071423, 0.9637094518507857]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.027885652381746694`], {
             RGBColor[
             0.9640512420587933, 0.8903985396738573, 0.3148462930620626]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.027885652381746694`], {
             RGBColor[
             0.9115464959098862, 0.9323064488408019, 0.99142531259869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.027885652381746694`], {
             RGBColor[
             0.8493482780100123, 0.8827112782130909, 0.9854927910503954]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.027885652381746694`], {
             RGBColor[
             0.9944578047595946, 0.9905541297196941, 0.6381444344252887]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.027885652381746694`], {
             RGBColor[
             0.9869010920815341, 0.9674764492004851, 0.4036136455683044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.027885652381746694`], {
             RGBColor[
             0.9908960673537678, 0.9809524388585308, 0.41913337011315527`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.027885652381746694`], {
             RGBColor[
             0.9207148695113485, 0.7233679083556857, 0.2550635268288699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.027885652381746694`], {
             RGBColor[
             0.9951660399579313, 0.9920689731953737, 0.7152314650432464]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.027885652381746694`], {
             RGBColor[
             0.9197026668497162, 0.9388099581548599, 0.9922032554640308]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.027885652381746694`], {
             RGBColor[
             0.9939845210934886, 0.9895418238142123, 0.586630428137866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.027885652381746694`], {
             RGBColor[
             0.9876757581548599, 0.9891716235255354, 0.8539081116968702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.027885652381746694`], {
             RGBColor[
             0.9918165932948037, 0.9908839652705113, 0.785283757290174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.027885652381746694`], {
             RGBColor[
             0.9950992739488339, 0.9919261674529933, 0.7079643969850372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.027885652381746694`], {
             RGBColor[
             0.9946433146447268, 0.9909509166060654, 0.6583360405876225]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.027885652381746694`], {
             RGBColor[
             0.8719815793083006, 0.5115800757483345, 0.21489063056725752`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.027885652381746694`], {
             RGBColor[
             0.865581174848984, 0.8956549495222405, 0.9870410992421746]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.027885652381746694`], {
             RGBColor[
             0.7973853704051688, 0.8416427788045715, 0.9804395797981877]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.027885652381746694`], {
             RGBColor[
             0.9134359677759472, 0.9338130624184513, 0.9916055321120263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.027885652381746694`], {
             RGBColor[
             0.9328584202452865, 0.7715130404173535, 0.26483451279516756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.027885652381746694`], {
             RGBColor[
             0.7440150845851652, 0.7999495058927892, 0.9751201284813273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.027885652381746694`], {
             RGBColor[
             0.9888343037322452, 0.9896507118950475, 0.8347080132597507]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.027885652381746694`], {
             RGBColor[
             0.9935000059754696, 0.9915800996756992, 0.7573852526391731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.027885652381746694`], {
             RGBColor[
             0.9550684513564625, 0.966010705107084, 0.9609415712155036]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.027885652381746694`], {
             RGBColor[
             0.9863056474464581, 0.9654678746293248, 0.4013004556013182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.027885652381746694`], {
             RGBColor[
             0.9926068228743554, 0.9865950666301434, 0.4366764791530763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.027885652381746694`], {
             RGBColor[
             0.968904840142993, 0.9763298612090712, 0.9375201741080623]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.027885652381746694`], {
             RGBColor[
             0.9841973855403867, 0.9877332270593521, 0.9115537476584592]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.027885652381746694`], {
             RGBColor[
             0.9938457364085668, 0.9892449774064486, 0.5715245716639213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.027885652381746694`], {
             RGBColor[
             0.978841668257383, 0.9402901201989193, 0.37230430590595975`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.027885652381746694`], {
             RGBColor[
             0.9460832915606517, 0.9593095876432173, 0.9761511030448174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.027885652381746694`], {
             RGBColor[
             0.9915828886265272, 0.9907873223842429, 0.7891568484518083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.027885652381746694`], {
             RGBColor[
             0.9949996887687721, 0.9917131648224473, 0.6971251647038006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.027885652381746694`], {
             RGBColor[
             0.9181965442412653, 0.7133835878419545, 0.25303722320386945`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.027885652381746694`], {
             RGBColor[
             0.9844491202395763, 0.9592053724271946, 0.3940881979783275]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.027885652381746694`], {
             RGBColor[
             0.9946102785234834, 0.9908802556831902, 0.654740262665596]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.027885652381746694`], {
             RGBColor[
             0.97844836318182, 0.9834474050653436, 0.9213654789527791]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.027885652381746694`], {
             RGBColor[
             0.5824546536543096, 0.6719019529765194, 0.9602721104188162]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.027885652381746694`], {
             RGBColor[
             0.9130922587784389, 0.693146796884148, 0.2489301953075007]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.027885652381746694`], {
             RGBColor[
             0.9853152310992772, 0.9621269677294665, 0.3974528751169538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.027885652381746694`], {
             RGBColor[
             0.9772513333730952, 0.9349255472058283, 0.36612615519004477`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.027885652381746694`], {
             RGBColor[
             0.9922622092257003, 0.9855607561779245, 0.42444057331136764`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.027885652381746694`], {
             RGBColor[
             0.9407353473525125, 0.9553210996092419, 0.9852037776219588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.027885652381746694`], {
             RGBColor[
             0.9776369772611712, 0.9362264145937994, 0.36762430887248226`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.027885652381746694`], {
             RGBColor[
             0.9579383558007813, 0.9681510751426198, 0.9560835715822296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.027885652381746694`], {
             RGBColor[
             0.8858767343492585, 0.9118380777594727, 0.9889769078253706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.027885652381746694`], {
             RGBColor[
             0.9925979847747309, 0.9865761628287156, 0.4357145065513785]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.027885652381746694`], {
             RGBColor[
             0.9852937242174631, 0.9620544199670514, 0.39736932494233973`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.027885652381746694`], {
             RGBColor[
             0.9908034228219776, 0.9904649932427042, 0.8020746140260342]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.027885652381746694`], {
             RGBColor[
             0.8833842972176458, 0.9098506760461283, 0.9887391769467325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.027885652381746694`], {
             RGBColor[
             0.99280260472458, 0.9870138242111924, 0.4579861253245016]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.027885652381746694`], {
             RGBColor[
             0.9927513914592104, 0.9869042842150223, 0.45241187744066136`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.027885652381746694`], {
             RGBColor[
             0.9911252956838711, 0.9905980959428524, 0.7967403477241966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.027885652381746694`], {
             RGBColor[
             0.9944174425700165, 0.99046779907743, 0.6337512591762775]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.027885652381746694`], {
             RGBColor[
             0.9946243876647446, 0.9920450603995058, 0.7387513382413511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.027885652381746694`], {
             RGBColor[
             0.9916162683114529, 0.9908011257417785, 0.7886036606887357]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.027885652381746694`], {
             RGBColor[
             0.9909851516659381, 0.9905401427899001, 0.7990628967824365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.027885652381746694`], {
             RGBColor[
             0.9874319518478194, 0.9692671638439659, 0.4056759355158676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.027885652381746694`], {
             RGBColor[
             0.9914874867219658, 0.9829474352593341, 0.42143092267842847`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.027885652381746694`], {
             RGBColor[
             0.9934303135588928, 0.988356429936689, 0.5263083581695648]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.027885652381746694`], {
             RGBColor[
             0.995248876800253, 0.9922461528250104, 0.7242477441202324]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.027885652381746694`], {
             RGBColor[
             0.9870082047946372, 0.9678377655330433, 0.40402975823217174`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.027885652381746694`], {
             RGBColor[
             0.7111555250452706, 0.7742793682383214, 0.9718449946764333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.027885652381746694`], {
             RGBColor[
             0.9605374395302293, 0.8785456586649426, 0.30119583376452047`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.027885652381746694`], {
             RGBColor[
             0.9560448780889623, 0.8633911940199592, 0.2837430809142388]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.027885652381746694`], {
             RGBColor[
             0.9102397379860809, 0.6818375024886536, 0.24663499012070086`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.027885652381746694`], {
             RGBColor[
             0.9215173095394535, 0.7265493156698345, 0.2557091889111716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.027885652381746694`], {
             RGBColor[
             0.9485612289950575, 0.9611576293245468, 0.9719566013179574]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.027885652381746694`], {
             RGBColor[
             0.9952047312707207, 0.9921517300011384, 0.7194427756652682]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.027885652381746694`], {
             RGBColor[
             0.9950281168687795, 0.9917739696538413, 0.7002193879517085]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.027885652381746694`], {
             RGBColor[
             0.986822110696407, 0.9888186183637262, 0.8680552592522406]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.027885652381746694`], {
             RGBColor[
             0.9930362623422706, 0.9875135942290235, 0.4834183150424541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.027885652381746694`], {
             RGBColor[
             0.9464869017932195, 0.8255454283326507, 0.2758003089502115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.027885652381746694`], {
             RGBColor[
             0.9710054327996732, 0.9778964797730184, 0.9339644186626115]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN3AuYzmXewPH7z7a1WxZbu0o1DqFsy5TT0CKyGGKYrMNM4zSN46CIkAnD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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[37, 104] -> 
             RGBColor[
              0.2541903466574486, 0.3845005493087726, 0.9377871362499982], 
             UndirectedEdge[119, 243] -> 
             RGBColor[
              0.23559188807996673`, 0.3649523901334573, 0.9367279815479644], 
             UndirectedEdge[165, 226] -> 
             RGBColor[
              0.20872258864357046`, 0.33671105281382463`, 0.935197814694628], 
             UndirectedEdge[235, 261] -> 
             RGBColor[
              0.19122633777104836`, 0.31832138382042696`, 0.9342014290908216],
              UndirectedEdge[56, 198] -> 
             RGBColor[
              0.6735978276393025, 0.7431113232752183, 0.969380994432274], 
             UndirectedEdge[50, 254] -> 
             RGBColor[
              0.20910270252497706`, 0.33711057660379506`, 0.9352194616178461],
              UndirectedEdge[249, 268] -> 
             RGBColor[
              0.18564105657677243`, 0.3124508991579618, 0.9338833555894905], 
             UndirectedEdge[38, 224] -> 
             RGBColor[
              0.37823665311305865`, 0.49620023139778335`, 0.9458245390097163],
              UndirectedEdge[79, 87] -> 
             RGBColor[
              0.19294989757058154`, 0.3201329544497393, 0.9342995832716268], 
             UndirectedEdge[38, 311] -> 
             RGBColor[
              0.23066096804752526`, 0.35976968054097413`, 0.9364471729467594],
              UndirectedEdge[37, 145] -> 
             RGBColor[
              0.2671022972631469, 0.3980718280603137, 0.9385224527354736], 
             UndirectedEdge[147, 359] -> 
             RGBColor[
              0.28645237167494564`, 0.4168434263248926, 0.9396817701660576], 
             UndirectedEdge[192, 349] -> 
             RGBColor[
              0.22834058438598487`, 0.3573308101918738, 0.9363150305299347], 
             UndirectedEdge[213, 308] -> 
             RGBColor[
              0.2691305631056292, 0.398662652595457, 0.9386943834532097], 
             UndirectedEdge[262, 397] -> 
             RGBColor[
              0.364256395049981, 0.48992231415871446`, 0.9444310732866698], 
             UndirectedEdge[129, 364] -> 
             RGBColor[
              0.8703372527037241, 0.4377357825676223, 0.21085741257426427`], 
             UndirectedEdge[54, 83] -> 
             RGBColor[
              0.9496193654049732, 0.8977579075232218, 0.6225379522867944], 
             UndirectedEdge[13, 277] -> 
             RGBColor[
              0.19923872667069553`, 0.3267429125687539, 0.9346577227853893], 
             UndirectedEdge[191, 235] -> 
             RGBColor[
              0.18862912627732129`, 0.3155915498678, 0.9340535217384839], 
             UndirectedEdge[54, 214] -> 
             RGBColor[
              0.913587591361185, 0.6878213464055395, 0.24895168467498954`], 
             UndirectedEdge[87, 176] -> 
             RGBColor[
              0.18652655830038561`, 0.3133816176135313, 0.933933783602668], 
             UndirectedEdge[16, 377] -> 
             RGBColor[
              0.24182389785616784`, 0.37150262754048624`, 0.9370828852852868],
              UndirectedEdge[158, 344] -> 
             RGBColor[
              0.19135142545084088`, 0.31845285890290587`, 0.934208552649135], 
             UndirectedEdge[95, 228] -> 
             RGBColor[
              0.2356195787974104, 0.36498149483318354`, 0.9367295584933581], 
             UndirectedEdge[193, 283] -> 
             RGBColor[
              0.884925338733304, 0.8207038820590313, 0.6242425057097936], 
             UndirectedEdge[11, 366] -> 
             RGBColor[
              0.9332464444239088, 0.9449010522417576, 0.749948999978632], 
             UndirectedEdge[106, 231] -> 
             RGBColor[
              0.1888628748467801, 0.31583723443481654`, 0.9340668333737145], 
             UndirectedEdge[76, 388] -> 
             RGBColor[
              0.276858244918402, 0.40832594760879465`, 0.9390780395218092], 
             UndirectedEdge[208, 351] -> 
             RGBColor[
              0.301986411916915, 0.43466246314501933`, 0.9405117895645303], 
             UndirectedEdge[208, 225] -> 
             RGBColor[
              0.2514500268910438, 0.38162029948797277`, 0.9376310790932412], 
             UndirectedEdge[163, 374] -> 
             RGBColor[
              0.1813453905655848, 0.3079358818192477, 0.9336387237650219], 
             UndirectedEdge[165, 288] -> 
             RGBColor[
              0.2196372553710177, 0.3481830595742119, 0.9358193888179538], 
             UndirectedEdge[110, 239] -> 
             RGBColor[
              0.6800499902731076, 0.7481746185632971, 0.9700901941191247], 
             UndirectedEdge[14, 273] -> 
             RGBColor[
              0.4313475935937616, 0.5461129107315478, 0.9492366849727629], 
             UndirectedEdge[231, 372] -> 
             RGBColor[
              0.18557674124721385`, 0.3123832996687683, 0.9338796929266182], 
             UndirectedEdge[5, 162] -> 
             RGBColor[
              0.19105730741779076`, 0.3181437222020098, 0.9341918030622616], 
             UndirectedEdge[36, 90] -> 
             RGBColor[
              0.2306114538784999, 0.35971763800994894`, 0.9364443531880831], 
             UndirectedEdge[258, 328] -> 
             RGBColor[
              0.23450213577855084`, 0.36380699137038264`, 0.936665921766543], 
             UndirectedEdge[91, 208] -> 
             RGBColor[
              0.4434969579662055, 0.5534506067219376, 0.9505734674176423], 
             UndirectedEdge[155, 370] -> 
             RGBColor[
              0.18572317816153708`, 0.3125372141503586, 0.9338880322922549], 
             UndirectedEdge[66, 243] -> 
             RGBColor[
              0.21376058132167255`, 0.342006302545695, 0.9354847209246038], 
             UndirectedEdge[253, 334] -> 
             RGBColor[
              0.8927019922159016, 0.5360459310419723, 0.23584376702104354`], 
             UndirectedEdge[50, 210] -> 
             RGBColor[
              0.23840421569943582`, 0.3679083247733892, 0.9368881394454274], 
             UndirectedEdge[239, 365] -> 
             RGBColor[
              0.4065771465503478, 0.524864785093759, 0.9475407198960643], 
             UndirectedEdge[13, 51] -> 
             RGBColor[
              0.20728585719020337`, 0.33520095696230034`, 0.9351159949638125],
              UndirectedEdge[258, 300] -> 
             RGBColor[
              0.21690681128224154`, 0.345313189716754, 0.9356638940664279], 
             UndirectedEdge[30, 294] -> 
             RGBColor[
              0.2052159577699056, 0.3330253614323641, 0.9349981172539683], 
             UndirectedEdge[31, 292] -> 
             RGBColor[
              0.9018751366680733, 0.5692935983265383, 0.5384207617960579], 
             UndirectedEdge[203, 216] -> 
             RGBColor[
              0.26291297700315486`, 0.3935517624584167, 0.938288154657422], 
             UndirectedEdge[64, 233] -> 
             RGBColor[
              0.9814581324353071, 0.9819712119725741, 0.6847171998056071], 
             UndirectedEdge[50, 242] -> 
             RGBColor[
              0.2857631387189643, 0.41475906038865373`, 0.9396923133754758], 
             UndirectedEdge[133, 398] -> 
             RGBColor[
              0.18210607446438823`, 0.30873540882703493`, 0.9336820435877278],
              UndirectedEdge[7, 390] -> 
             RGBColor[
              0.23396569650741295`, 0.36324315968420245`, 0.9366353723436424],
              UndirectedEdge[186, 342] -> 
             RGBColor[
              0.19648760861210862`, 0.32385131305821946`, 0.9345010506818672],
              UndirectedEdge[347, 398] -> 
             RGBColor[
              0.182565782601332, 0.30921859122614215`, 0.9337082232860494], 
             UndirectedEdge[321, 375] -> 
             RGBColor[
              0.19367454863692518`, 0.3208946086659977, 0.9343408510778299], 
             UndirectedEdge[149, 279] -> 
             RGBColor[
              0.20468155953700706`, 0.33246367500678287`, 0.9349676840651762],
              UndirectedEdge[38, 306] -> 
             RGBColor[
              0.24051285588611682`, 0.3701246393051007, 0.9370082233846052], 
             UndirectedEdge[12, 358] -> 
             RGBColor[
              0.26019129073322267`, 0.39080792201424114`, 0.9381288811375124],
              UndirectedEdge[139, 378] -> 
             RGBColor[
              0.27359029407982893`, 0.40489112407740385`, 0.9388919345560525],
              UndirectedEdge[272, 374] -> 
             RGBColor[
              0.19014395523747457`, 0.3171837311506246, 0.934139789006776], 
             UndirectedEdge[21, 114] -> 
             RGBColor[
              0.19167285067202883`, 0.3187906971899105, 0.9342268573399758], 
             UndirectedEdge[250, 321] -> 
             RGBColor[
              0.18913677562513462`, 0.3161251215191795, 0.934082431617842], 
             UndirectedEdge[19, 152] -> 
             RGBColor[
              0.2001783639532218, 0.3277305309291337, 0.9347112337385604], 
             UndirectedEdge[270, 336] -> 
             RGBColor[
              0.2213730230293102, 0.3500074614371033, 0.9359182382182554], 
             UndirectedEdge[87, 277] -> 
             RGBColor[
              0.18598156789951187`, 0.3128087981478258, 0.9339027472055792], 
             UndirectedEdge[37, 377] -> 
             RGBColor[
              0.2695128080367538, 0.400605427718585, 0.9386597277579993], 
             UndirectedEdge[312, 356] -> 
             RGBColor[
              0.746600049419986, 0.8012844499471021, 0.9674404180913663], 
             UndirectedEdge[294, 343] -> 
             RGBColor[
              0.20522639813651683`, 0.33303633491963003`, 0.9349987118174017],
              UndirectedEdge[170, 349] -> 
             RGBColor[
              0.21695935367547547`, 0.34536841510342303`, 0.9356668862779931],
              UndirectedEdge[176, 390] -> 
             RGBColor[
              0.199593709897452, 0.3271160224473115, 0.9346779385550025], 
             UndirectedEdge[235, 327] -> 
             RGBColor[
              0.1895062149755763, 0.31651342570030144`, 0.934103470642313], 
             UndirectedEdge[271, 400] -> 
             RGBColor[
              0.8210589855507496, 0.16287416781517963`, 0.16779941438710733`],
              UndirectedEdge[45, 103] -> 
             RGBColor[
              0.21725551419299843`, 0.345679698585001, 0.9356837521813359], 
             UndirectedEdge[30, 343] -> 
             RGBColor[
              0.2007094287814945, 0.32828871373510315`, 0.9347414770948905], 
             UndirectedEdge[200, 234] -> 
             RGBColor[
              0.22049169370930496`, 0.34908112844227146`, 0.9358680478172909],
              UndirectedEdge[282, 382] -> 
             RGBColor[
              0.3185597546508585, 0.45034218102492296`, 0.9415193237683902], 
             UndirectedEdge[305, 382] -> 
             RGBColor[
              0.31007770460075973`, 0.44200741025601153`, 0.9410150322193817],
              UndirectedEdge[50, 164] -> 
             RGBColor[
              0.22306024288786463`, 0.3517808364843617, 0.9360143228931819], 
             UndirectedEdge[259, 287] -> 
             RGBColor[
              0.8563718105158677, 0.5267891517148, 0.5770527968903222], 
             UndirectedEdge[90, 95] -> 
             RGBColor[
              0.23140010342565426`, 0.3605465586872775, 0.936489265613091], 
             UndirectedEdge[44, 243] -> 
             RGBColor[
              0.2298536898894718, 0.3589211800124685, 0.9364011996499193], 
             UndirectedEdge[82, 194] -> 
             RGBColor[
              0.6075992658363466, 0.6905170696190597, 0.963481170694517], 
             UndirectedEdge[124, 150] -> 
             RGBColor[
              0.2325126629936997, 0.36171592933364405`, 0.9365526242346068], 
             UndirectedEdge[233, 316] -> 
             RGBColor[
              0.8412361363066468, 0.8762214650435611, 0.9535246374949702], 
             UndirectedEdge[87, 390] -> 
             RGBColor[
              0.19991574882843044`, 0.32745450578221735`, 0.9346962781957078],
              UndirectedEdge[72, 376] -> 
             RGBColor[
              0.3758578545249899, 0.4975526740121381, 0.9453383722532241], 
             UndirectedEdge[99, 169] -> 
             RGBColor[
              0.6797124063510102, 0.7475445119943138, 0.9704734146298177], 
             UndirectedEdge[127, 137] -> 
             RGBColor[
              0.31600670483300364`, 0.4466421785419929, 0.9414111535240912], 
             UndirectedEdge[68, 391] -> 
             RGBColor[
              0.8209192855845969, 0.5085618177919978, 0.5749280813219132], 
             UndirectedEdge[292, 309] -> 
             RGBColor[
              0.7584292895983676, 0.45716808614862703`, 0.568384704834363], 
             UndirectedEdge[88, 140] -> 
             RGBColor[
              0.41837127081473313`, 0.5367938996534025, 0.947879225318494], 
             UndirectedEdge[153, 216] -> 
             RGBColor[
              0.21073387590110806`, 0.33882504324447416`, 0.935312354528512], 
             UndirectedEdge[145, 165] -> 
             RGBColor[
              0.23770682741222313`, 0.3671753254665574, 0.9368484242141641], 
             UndirectedEdge[37, 76] -> 
             RGBColor[
              0.28363325287465024`, 0.4154469105311262, 0.9394638662021915], 
             UndirectedEdge[6, 391] -> 
             RGBColor[
              0.8731987569820019, 0.5502480491958415, 0.5799145439742327], 
             UndirectedEdge[203, 206] -> 
             RGBColor[
              0.36944897924090714`, 0.4944198695980247, 0.9447619401596937], 
             UndirectedEdge[298, 320] -> 
             RGBColor[
              0.19458686072830475`, 0.3218535065179652, 0.9343928059017892], 
             UndirectedEdge[39, 164] -> 
             RGBColor[
              0.20658345954088297`, 0.3344626924982814, 0.9350759944567879], 
             UndirectedEdge[107, 156] -> 
             RGBColor[
              0.2124764155335251, 0.34065656288153834`, 0.9354115895827217], 
             UndirectedEdge[31, 222] -> 
             RGBColor[
              0.967672940132394, 0.9754000826172251, 0.9391115323234271], 
             UndirectedEdge[301, 329] -> 
             RGBColor[
              0.25610352101831557`, 0.38651141686430435`, 0.9378960886995618],
              UndirectedEdge[126, 320] -> 
             RGBColor[
              0.18313368370358218`, 0.3098154912916167, 0.9337405644136882], 
             UndirectedEdge[49, 191] -> 
             RGBColor[
              0.18385357890938503`, 0.3105721467969078, 0.933781561380669], 
             UndirectedEdge[122, 173] -> 
             RGBColor[
              0.18447873947082444`, 0.3112292301844495, 0.9338171633498009], 
             UndirectedEdge[60, 102] -> 
             RGBColor[
              0.5280292771941157, 0.6238948638185677, 0.9574471733011694], 
             UndirectedEdge[120, 380] -> 
             RGBColor[
              0.5664649447415552, 0.6566185624069654, 0.9601363872621158], 
             UndirectedEdge[110, 247] -> 
             RGBColor[
              0.8351507068562677, 0.5099360316010974, 0.5750372213001058], 
             UndirectedEdge[59, 149] -> 
             RGBColor[
              0.21329928840113216`, 0.34152145443854653`, 0.9354584509752006],
              UndirectedEdge[92, 346] -> 
             RGBColor[
              0.2038983093069455, 0.33164042935405524`, 0.934923079123289], 
             UndirectedEdge[6, 142] -> 
             RGBColor[
              0.7001614603741532, 0.763972329138221, 0.9722831025823769], 
             UndirectedEdge[176, 232] -> 
             RGBColor[
              0.18828223277850703`, 0.3152269428062281, 0.9340337666669094], 
             UndirectedEdge[60, 345] -> 
             RGBColor[
              0.7675537628448912, 0.8184035673483785, 0.9774488709937861], 
             UndirectedEdge[79, 126] -> 
             RGBColor[
              0.19080527822884924`, 0.31787882354485875`, 0.9341774503727951],
              UndirectedEdge[14, 212] -> 
             RGBColor[
              0.45821441723172895`, 0.5679246084974616, 0.9513517397459614], 
             UndirectedEdge[22, 338] -> 
             RGBColor[
              0.2260845393342366, 0.35495956380096844`, 0.9361865521017572], 
             UndirectedEdge[195, 389] -> 
             RGBColor[
              0.7088707754207897, 0.764952224756877, 0.7205833028362763], 
             UndirectedEdge[14, 293] -> 
             RGBColor[
              0.32638953387049785`, 0.45712394224882835`, 0.9420182303766638],
              UndirectedEdge[201, 394] -> 
             RGBColor[
              0.5116695891716139, 0.6114793927942537, 0.9556621742335425], 
             UndirectedEdge[20, 189] -> 
             RGBColor[
              0.30889970680782364`, 0.4349879582915822, 0.9411596287595527], 
             UndirectedEdge[195, 359] -> 
             RGBColor[
              0.375153965132881, 0.49936124163672424`, 0.9451254568160093], 
             UndirectedEdge[222, 224] -> 
             RGBColor[
              0.724417520241849, 0.7830873105778803, 0.9606419773233753], 
             UndirectedEdge[54, 389] -> 
             RGBColor[
              0.9706885388162402, 0.9101251515870772, 0.3850556620267193], 
             UndirectedEdge[123, 366] -> 
             RGBColor[
              0.9182289355345559, 0.6604066319094237, 0.35054608517613656`], 
             UndirectedEdge[120, 263] -> 
             RGBColor[
              0.3571898835204337, 0.4831624157488532, 0.9440042071759314], 
             UndirectedEdge[332, 364] -> 
             RGBColor[
              0.8695716309493327, 0.4318508782657767, 0.2101242523176128], 
             UndirectedEdge[70, 228] -> 
             RGBColor[
              0.21048617188066365`, 0.3385646906136451, 0.9352982481509928], 
             UndirectedEdge[74, 141] -> 
             RGBColor[
              0.3021503369999872, 0.43056214369424695`, 0.9406775662244785], 
             UndirectedEdge[212, 385] -> 
             RGBColor[
              0.7860985506073723, 0.8292872838004639, 0.7968353358505167], 
             UndirectedEdge[256, 384] -> 
             RGBColor[
              0.9629443447193516, 0.8827390749129462, 0.5213129511813582], 
             UndirectedEdge[158, 317] -> 
             RGBColor[
              0.18982224071375664`, 0.31684558878831803`, 0.9341214678405843],
              UndirectedEdge[76, 208] -> 
             RGBColor[
              0.28867650153937047`, 0.420747684638181, 0.9397510717528295], 
             UndirectedEdge[101, 253] -> 
             RGBColor[
              0.8395830715203696, 0.3052584098839103, 0.18553810003157822`], 
             UndirectedEdge[111, 309] -> 
             RGBColor[
              0.7619893896080814, 0.48453257486905843`, 0.5717938606242228], 
             UndirectedEdge[145, 170] -> 
             RGBColor[
              0.24268853638713495`, 0.37241141745778183`, 0.9371321251705074],
              UndirectedEdge[59, 279] -> 
             RGBColor[
              0.2076546436516325, 0.3355885749156745, 0.9351369968072203], 
             UndirectedEdge[83, 334] -> 
             RGBColor[
              0.9555982588691752, 0.9202058525384339, 0.6338919338224923], 
             UndirectedEdge[242, 312] -> 
             RGBColor[
              0.4441075478761082, 0.5565195124327971, 0.9502280720328274], 
             UndirectedEdge[140, 356] -> 
             RGBColor[
              0.6758651089866358, 0.7425832566534856, 0.9622242963377263], 
             UndirectedEdge[172, 316] -> 
             RGBColor[
              0.5458822960971526, 0.6391409074229324, 0.9586767421820886], 
             UndirectedEdge[217, 331] -> 
             RGBColor[
              0.22460790707912992`, 0.3534075296769589, 0.9361024600793104], 
             UndirectedEdge[263, 336] -> 
             RGBColor[
              0.2683165494931898, 0.3993480841421268, 0.9385916026036494], 
             UndirectedEdge[122, 338] -> 
             RGBColor[
              0.19975108063826336`, 0.32728142907378543`, 0.9346869005858826],
              UndirectedEdge[303, 400] -> 
             RGBColor[
              0.8580226382100805, 0.391117913716996, 0.20100792167803327`], 
             UndirectedEdge[133, 367] -> 
             RGBColor[
              0.18474901765317286`, 0.31151330969072427`, 0.9338325552924449],
              UndirectedEdge[136, 279] -> 
             RGBColor[
              0.19083656061449622`, 0.3179117033155916, 0.9341792318583795], 
             UndirectedEdge[117, 365] -> 
             RGBColor[
              0.4322742926857367, 0.5457268859697086, 0.94956369337159], 
             UndirectedEdge[33, 245] -> 
             RGBColor[
              0.22074175679161856`, 0.34934396059669826`, 0.9358822885398935],
              UndirectedEdge[162, 368] -> 
             RGBColor[
              0.18956500601498782`, 0.31657521881029016`, 0.934106818705034], 
             UndirectedEdge[46, 128] -> 
             RGBColor[
              0.5547192055800235, 0.6423805327309791, 0.9609350717272003], 
             UndirectedEdge[117, 269] -> 
             RGBColor[
              0.45596747114210545`, 0.5665010427125681, 0.9510641632117192], 
             UndirectedEdge[98, 134] -> 
             RGBColor[
              0.1861818864522268, 0.313019345647659, 0.9339141550508117], 
             UndirectedEdge[90, 326] -> 
             RGBColor[
              0.22857029923452804`, 0.35757225506245527`, 0.9363281124507266],
              UndirectedEdge[119, 306] -> 
             RGBColor[
              0.2310448890646134, 0.36017320587193224`, 0.9364690366807222], 
             UndirectedEdge[150, 211] -> 
             RGBColor[
              0.23544785722092995`, 0.3648010045685258, 0.9367197792036168], 
             UndirectedEdge[388, 395] -> 
             RGBColor[
              0.35473118198517756`, 0.4781619748017699, 0.9439526563033052], 
             UndirectedEdge[102, 108] -> 
             RGBColor[
              0.3276991764172302, 0.45803801914073383`, 0.9421097447928497], 
             UndirectedEdge[15, 392] -> 
             RGBColor[
              0.19259602959164984`, 0.3197610167673564, 0.9342794310137273], 
             UndirectedEdge[32, 292] -> 
             RGBColor[
              0.8205053754928366, 0.15861887831658708`, 0.16726927677043682`],
              UndirectedEdge[115, 332] -> 
             RGBColor[
              0.8864563951040925, 0.498793341625289, 0.2237101298928862], 
             UndirectedEdge[93, 293] -> 
             RGBColor[
              0.3283292569566383, 0.4588040328927261, 0.9421418278164828], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.1906510637312114, 0.3177167343300775, 0.9341686680852945], 
             UndirectedEdge[276, 305] -> 
             RGBColor[
              0.33855234976798615`, 0.46667071672258365`, 0.9428294114302973],
              UndirectedEdge[75, 347] -> 
             RGBColor[
              0.18311704522785527`, 0.30979800319868733`, 0.9337396168771099],
              UndirectedEdge[64, 193] -> 
             RGBColor[
              0.9152566921622731, 0.9300770448033753, 0.7093659477350615], 
             UndirectedEdge[18, 99] -> 
             RGBColor[
              0.947350971343756, 0.9556350172112698, 0.7097411277967336], 
             UndirectedEdge[74, 290] -> 
             RGBColor[
              0.2530317916874394, 0.3832828345786652, 0.9377211582583846], 
             UndirectedEdge[39, 230] -> 
             RGBColor[
              0.20964976351428055`, 0.33768557238922303`, 0.9352506159318827],
              UndirectedEdge[259, 345] -> 
             RGBColor[
              0.8617541752858404, 0.8926034039517254, 0.9866760766074392], 
             UndirectedEdge[30, 168] -> 
             RGBColor[
              0.19933167973369648`, 0.3268406121315325, 0.9346630163248155], 
             UndirectedEdge[231, 331] -> 
             RGBColor[
              0.21608777115484973`, 0.34445232661272185`, 0.9356172509428343],
              UndirectedEdge[137, 242] -> 
             RGBColor[
              0.31652160790723577`, 0.4470881617051118, 0.9414439626926704], 
             UndirectedEdge[172, 221] -> 
             RGBColor[
              0.3747675504331488, 0.4990265486455837, 0.9451008348130354], 
             UndirectedEdge[157, 211] -> 
             RGBColor[
              0.23967520555955008`, 0.36924421570178084`, 0.9369605204376998],
              UndirectedEdge[46, 213] -> 
             RGBColor[
              0.5654749182769274, 0.6521444572622102, 0.9616040176321952], 
             UndirectedEdge[184, 318] -> 
             RGBColor[
              0.2135047362690546, 0.34173739317388024`, 0.935470150927346], 
             UndirectedEdge[201, 293] -> 
             RGBColor[
              0.4899219075938762, 0.5926426440818758, 0.9542764311941287], 
             UndirectedEdge[64, 115] -> 
             RGBColor[
              0.973846560757742, 0.9231368127839409, 0.35853265585475147`], 
             UndirectedEdge[174, 266] -> 
             RGBColor[
              0.5380286912692482, 0.6346285303347542, 0.9572070721400225], 
             UndirectedEdge[80, 104] -> 
             RGBColor[
              0.2135778861880246, 0.34181427837669043`, 0.9354743167070156], 
             UndirectedEdge[265, 321] -> 
             RGBColor[
              0.19177497299708612`, 0.31889803422847507`, 0.9342326730553113],
              UndirectedEdge[178, 296] -> 
             RGBColor[
              0.18104204814496305`, 0.30761704970215387`, 0.9336214488629224],
              UndirectedEdge[114, 249] -> 
             RGBColor[
              0.18514988407402466`, 0.3119346457154385, 0.9338553840420838], 
             UndirectedEdge[255, 380] -> 
             RGBColor[
              0.5472854839726642, 0.6400062774766795, 0.9589142889816533], 
             UndirectedEdge[253, 391] -> 
             RGBColor[
              0.8227133050515791, 0.17558999242598253`, 0.16938359260938823`],
              UndirectedEdge[40, 63] -> 
             RGBColor[
              0.19138658757193353`, 0.3184898165215815, 0.9342105550799136], 
             UndirectedEdge[23, 311] -> 
             RGBColor[
              0.2072579319428704, 0.33517160575679045`, 0.9351144046622886], 
             UndirectedEdge[156, 396] -> 
             RGBColor[
              0.19313485512094197`, 0.32032735656215416`, 0.9343101163304997],
              UndirectedEdge[93, 281] -> 
             RGBColor[
              0.3706399848182322, 0.4954514587674228, 0.944837829981916], 
             UndirectedEdge[27, 325] -> 
             RGBColor[
              0.22165235452841858`, 0.35030105655330623`, 0.9359341457338957],
              UndirectedEdge[12, 107] -> 
             RGBColor[
              0.23293330946253646`, 0.362158055442918, 0.9365765794287164], 
             UndirectedEdge[255, 312] -> 
             RGBColor[
              0.46100266352577723`, 0.571153212435337, 0.9513046138622602], 
             UndirectedEdge[257, 310] -> 
             RGBColor[
              0.8979684765940259, 0.5907693635082272, 0.5548367056098094], 
             UndirectedEdge[50, 197] -> 
             RGBColor[
              0.21121964795225362`, 0.33933562046995513`, 0.9353400185281894],
              UndirectedEdge[215, 350] -> 
             RGBColor[
              0.5273081197953102, 0.6233107010129518, 0.9573840940310441], 
             UndirectedEdge[49, 235] -> 
             RGBColor[
              0.1884735679979762, 0.31542804825324383`, 0.9340446629246031], 
             UndirectedEdge[239, 323] -> 
             RGBColor[
              0.4638795886223883, 0.5747495967298069, 0.9511827422942791], 
             UndirectedEdge[211, 216] -> 
             RGBColor[
              0.22415272438939332`, 0.35292910380979625`, 0.9360765380985124],
              UndirectedEdge[98, 151] -> 
             RGBColor[
              0.20043054064394245`, 0.3279955846200067, 0.934725594828035], 
             UndirectedEdge[10, 32] -> 
             RGBColor[
              0.8322429825165458, 0.24883926935301032`, 0.1785092225120718], 
             UndirectedEdge[330, 367] -> 
             RGBColor[
              0.1873967228823739, 0.314296215760822, 0.9339833381883191], 
             UndirectedEdge[99, 384] -> 
             RGBColor[
              0.9178754148881313, 0.8496097092612407, 0.6279747633092586], 
             UndirectedEdge[127, 138] -> 
             RGBColor[
              0.31413697275722113`, 0.44467697158248487`, 0.9413046750483962],
              UndirectedEdge[292, 385] -> 
             RGBColor[
              0.9069547340805542, 0.5706484219232661, 0.4000326809306238], 
             UndirectedEdge[177, 219] -> 
             RGBColor[
              0.18016175523476746`, 0.3066918060397442, 0.9335713174839634], 
             UndirectedEdge[170, 322] -> 
             RGBColor[
              0.2153075934140704, 0.3436323103410369, 0.9355728209746665], 
             UndirectedEdge[261, 335] -> 
             RGBColor[
              0.19373393161436922`, 0.3209570239403897, 0.934344232850546], 
             UndirectedEdge[6, 253] -> 
             RGBColor[
              0.8756778488316885, 0.5693034354975091, 0.5822885251292265], 
             UndirectedEdge[95, 246] -> 
             RGBColor[
              0.23196638865379215`, 0.3611417603666076, 0.9365215147190895], 
             UndirectedEdge[50, 331] -> 
             RGBColor[
              0.2360482874744978, 0.36543209483450245`, 0.9367539728183005], 
             UndirectedEdge[9, 358] -> 
             RGBColor[
              0.48197798109692647`, 0.5820052784935108, 0.954246805716025], 
             UndirectedEdge[99, 144] -> 
             RGBColor[
              0.7417116613175341, 0.797878300210745, 0.9753542230915366], 
             UndirectedEdge[2, 28] -> 
             RGBColor[
              0.1967107027357332, 0.32408579912713337`, 0.9345137555621694], 
             UndirectedEdge[138, 258] -> 
             RGBColor[
              0.26327890753170885`, 0.39405320303566205`, 0.9383047163464664],
              UndirectedEdge[144, 384] -> 
             RGBColor[
              0.757420984754537, 0.7226612405223014, 0.6127983851533676], 
             UndirectedEdge[79, 277] -> 
             RGBColor[
              0.19208286823872933`, 0.31922165164912797`, 0.9342502072338328],
              UndirectedEdge[346, 354] -> 
             RGBColor[
              0.1997636988090205, 0.3272946915712895, 0.9346876191720402], 
             UndirectedEdge[144, 148] -> 
             RGBColor[
              0.41890511783186646`, 0.5289568419765102, 0.9490497655266936], 
             UndirectedEdge[38, 346] -> 
             RGBColor[
              0.23107597310122763`, 0.36020587716525554`, 0.9364708068706228],
              UndirectedEdge[38, 363] -> 
             RGBColor[
              0.3166257823122153, 0.444042358182842, 0.9415654261663287], 
             UndirectedEdge[78, 104] -> 
             RGBColor[
              0.22225745398096258`, 0.35093705444345114`, 0.9359686052525535],
              UndirectedEdge[95, 282] -> 
             RGBColor[
              0.2811273621289757, 0.41223265884799526`, 0.9393424107780823], 
             UndirectedEdge[92, 306] -> 
             RGBColor[
              0.21333519209183469`, 0.34155919149390046`, 0.9354604956372714],
              UndirectedEdge[9, 339] -> 
             RGBColor[
              0.5341582021850244, 0.6300810922914106, 0.9574662349562233], 
             UndirectedEdge[36, 148] -> 
             RGBColor[
              0.2511034439451054, 0.38125601883716365`, 0.9376113417071936], 
             UndirectedEdge[62, 395] -> 
             RGBColor[
              0.7152423649203183, 0.772631878073945, 0.8673341109470382], 
             UndirectedEdge[32, 247] -> 
             RGBColor[
              0.8194288056366617, 0.15034389064610632`, 0.16623835226035183`],
              UndirectedEdge[168, 379] -> 
             RGBColor[
              0.190216267574, 0.31725973600117974`, 0.9341439070873645], 
             UndirectedEdge[137, 230] -> 
             RGBColor[
              0.2568850160495337, 0.38733281769176137`, 0.9379405936854713], 
             UndirectedEdge[268, 279] -> 
             RGBColor[
              0.19334852815726622`, 0.3205519404709839, 0.9343222846938173], 
             UndirectedEdge[185, 288] -> 
             RGBColor[
              0.2031417930336449, 0.3308452827849142, 0.93487999664069], 
             UndirectedEdge[233, 310] -> 
             RGBColor[
              0.8984238517661913, 0.5911089815660195, 0.5540658742241997], 
             UndirectedEdge[150, 386] -> 
             RGBColor[
              0.29016677848912364`, 0.4192462598996066, 0.9399482680174902], 
             UndirectedEdge[138, 281] -> 
             RGBColor[
              0.3438282004171828, 0.4703940206570502, 0.9431965738199672], 
             UndirectedEdge[88, 257] -> 
             RGBColor[
              0.6999080745469857, 0.7619616397704058, 0.9426465587738788], 
             UndirectedEdge[27, 40] -> 
             RGBColor[
              0.19924073649984758`, 0.3267450250266232, 0.9346578372421862], 
             UndirectedEdge[159, 250] -> 
             RGBColor[
              0.18793077615893167`, 0.3148575396154177, 0.934013751732358], 
             UndirectedEdge[169, 363] -> 
             RGBColor[
              0.4158922643017966, 0.5345397089893019, 0.947750829584961], 
             UndirectedEdge[144, 382] -> 
             RGBColor[
              0.451676599366216, 0.5621674511867154, 0.9509612465314614], 
             UndirectedEdge[35, 207] -> 
             RGBColor[
              0.19080850531779897`, 0.3178822154199542, 0.9341776341507367], 
             UndirectedEdge[71, 287] -> 
             RGBColor[
              0.8935114377259239, 0.5555263902170573, 0.5501928078759782], 
             UndirectedEdge[148, 361] -> 
             RGBColor[
              0.33306353105933184`, 0.4580790241212378, 0.94262018039587], 
             UndirectedEdge[215, 393] -> 
             RGBColor[
              0.7140213652809209, 0.7765181844116039, 0.9721306348483233], 
             UndirectedEdge[33, 124] -> 
             RGBColor[
              0.23660403432322674`, 0.366016220008902, 0.9367856217791819], 
             UndirectedEdge[31, 111] -> 
             RGBColor[
              0.905435236677787, 0.5966580870469695, 0.5418299175859177], 
             UndirectedEdge[113, 357] -> 
             RGBColor[
              0.18582607626581804`, 0.31264536658207454`, 0.9338938921870696],
              UndirectedEdge[30, 329] -> 
             RGBColor[
              0.23151896311630302`, 0.36067148775828894`, 0.9364960344966363],
              UndirectedEdge[117, 239] -> 
             RGBColor[
              0.5328344578573876, 0.6316180426642315, 0.9563658268409162], 
             UndirectedEdge[209, 338] -> 
             RGBColor[
              0.23759083072429804`, 0.3670534055929334, 0.9368418183743885], 
             UndirectedEdge[208, 323] -> 
             RGBColor[
              0.3575199332630081, 0.48276280813906464`, 0.9440503364383386], 
             UndirectedEdge[71, 212] -> 
             RGBColor[
              0.7737416965530766, 0.822516123696677, 0.9480358411696325], 
             UndirectedEdge[199, 292] -> 
             RGBColor[
              0.9041138184890838, 0.5702193507910247, 0.501320010499076], 
             UndirectedEdge[11, 386] -> 
             RGBColor[
              0.6075598618760001, 0.6861529495738531, 0.9653876814635047], 
             UndirectedEdge[130, 267] -> 
             RGBColor[
              0.20661372269188627`, 0.33449450098878053`, 0.9350777178984673],
              UndirectedEdge[67, 347] -> 
             RGBColor[
              0.18186543483400505`, 0.3084824813180684, 0.9336683395167719], 
             UndirectedEdge[211, 358] -> 
             RGBColor[
              0.2550430737157216, 0.3853968195130357, 0.9378356977944702], 
             UndirectedEdge[2, 164] -> 
             RGBColor[
              0.20840908696131982`, 0.3363815426686245, 0.935179961237608], 
             UndirectedEdge[266, 358] -> 
             RGBColor[
              0.4679094050103473, 0.5710147999295367, 0.9528445815300333], 
             UndirectedEdge[57, 397] -> 
             RGBColor[
              0.3562392675894767, 0.4829782813049682, 0.943920229014154], 
             UndirectedEdge[209, 386] -> 
             RGBColor[
              0.30348621877337745`, 0.4332458361396474, 0.9407067904373323], 
             UndirectedEdge[74, 386] -> 
             RGBColor[
              0.29523037248077955`, 0.42456841823523894`, 0.9402366322043989],
              UndirectedEdge[47, 268] -> 
             RGBColor[
              0.18433220446865944`, 0.3110752126063183, 0.9338088183982067], 
             UndirectedEdge[108, 397] -> 
             RGBColor[
              0.3352715846751584, 0.4645968585734458, 0.9425922519510271], 
             UndirectedEdge[157, 358] -> 
             RGBColor[
              0.2622292284500658, 0.3929499237673575, 0.938244938675628], 
             UndirectedEdge[10, 129] -> 
             RGBColor[
              0.8311516302547027, 0.2404506576348733, 0.17746414235362473`], 
             UndirectedEdge[171, 308] -> 
             RGBColor[
              0.20045056014029836`, 0.3280166263799862, 0.9347267349087363], 
             UndirectedEdge[225, 335] -> 
             RGBColor[
              0.20337317791570175`, 0.3310884829666048, 0.93489317366742], 
             UndirectedEdge[45, 116] -> 
             RGBColor[
              0.23987123039501432`, 0.3694502502325462, 0.9369716837620867], 
             UndirectedEdge[261, 349] -> 
             RGBColor[
              0.19380914280268063`, 0.32103607566796977`, 0.9343485160164554],
              UndirectedEdge[118, 209] -> 
             RGBColor[
              0.3112464668184692, 0.43996737295489813`, 0.9412012665806477], 
             UndirectedEdge[329, 343] -> 
             RGBColor[
              0.23152940348291426`, 0.3606824612455548, 0.9364966290600697], 
             UndirectedEdge[163, 171] -> 
             RGBColor[
              0.18355378954190335`, 0.31025704916394076`, 0.9337644888196897],
              UndirectedEdge[106, 217] -> 
             RGBColor[
              0.1973830107710603, 0.32479243749905357`, 0.9345520425101908], 
             UndirectedEdge[55, 123] -> 
             RGBColor[
              0.8234475715902414, 0.5896702073672445, 0.5850169799812919], 
             UndirectedEdge[129, 353] -> 
             RGBColor[
              0.9062979809873158, 0.5688117544551025, 0.33694932919085196`], 
             UndirectedEdge[38, 66] -> 
             RGBColor[
              0.22742648369193186`, 0.3563700324050926, 0.9362629738476992], 
             UndirectedEdge[23, 119] -> 
             RGBColor[
              0.22585475434557115`, 0.35471804520867123`, 0.936173466186589], 
             UndirectedEdge[306, 354] -> 
             RGBColor[
              0.2092005815939097, 0.33721345371113465`, 0.9352250356860227], 
             UndirectedEdge[28, 39] -> 
             RGBColor[
              0.19488507531529636`, 0.3221669489567903, 0.9344097887813494], 
             UndirectedEdge[158, 267] -> 
             RGBColor[
              0.19435218965099377`, 0.3216068523367057, 0.934379441731101], 
             UndirectedEdge[194, 399] -> 
             RGBColor[
              0.40740786703989107`, 0.5272403351648417, 0.9471965661691704], 
             UndirectedEdge[102, 333] -> 
             RGBColor[
              0.6514056454646207, 0.7208926458479099, 0.9532948082895194], 
             UndirectedEdge[16, 80] -> 
             RGBColor[
              0.21603013302378776`, 0.34439174528250716`, 0.9356139685365383],
              UndirectedEdge[72, 333] -> 
             RGBColor[
              0.7096566263019076, 0.7710149507769987, 0.9570981774601166], 
             UndirectedEdge[167, 211] -> 
             RGBColor[
              0.23414776627805434`, 0.3634345265570368, 0.9366457409477322], 
             UndirectedEdge[193, 255] -> 
             RGBColor[
              0.606058461723811, 0.6860652101473173, 0.9647337421078497], 
             UndirectedEdge[168, 211] -> 
             RGBColor[
              0.2152267109388578, 0.3435472977313434, 0.935568214837358], 
             UndirectedEdge[70, 246] -> 
             RGBColor[
              0.2068329817370454, 0.33472495614706915`, 0.9350902043767244], 
             UndirectedEdge[322, 349] -> 
             RGBColor[
              0.19676296516777197`, 0.32414073025683565`, 0.9345167318303588],
              UndirectedEdge[193, 312] -> 
             RGBColor[
              0.6928723364666782, 0.7586931681891012, 0.9709743993376487], 
             UndirectedEdge[194, 221] -> 
             RGBColor[
              0.41267584437400284`, 0.5318031923554098, 0.9475322370266106], 
             UndirectedEdge[208, 221] -> 
             RGBColor[
              0.3321648835388723, 0.4608015384498717, 0.9424347350905069], 
             UndirectedEdge[112, 251] -> 
             RGBColor[
              0.18268323345773074`, 0.30934203952303163`, 0.9337149119385684],
              UndirectedEdge[297, 325] -> 
             RGBColor[
              0.267416015836295, 0.3984015661715987, 0.9385403185441094], 
             UndirectedEdge[170, 225] -> 
             RGBColor[
              0.22199301735031157`, 0.3506591147783862, 0.9359535459776369], 
             UndirectedEdge[27, 250] -> 
             RGBColor[
              0.19937642447535237`, 0.3268876416919933, 0.9346655644716588], 
             UndirectedEdge[67, 126] -> 
             RGBColor[
              0.18098291600078534`, 0.3075548980694286, 0.9336180813747896], 
             UndirectedEdge[12, 157] -> 
             RGBColor[
              0.24482342257705114`, 0.37465531820298625`, 0.937253703780742], 
             UndirectedEdge[316, 399] -> 
             RGBColor[
              0.5357585344043984, 0.6303722138797264, 0.9580316650391174], 
             UndirectedEdge[76, 377] -> 
             RGBColor[
              0.2688145572376063, 0.39987152185702324`, 0.9386199634079575], 
             UndirectedEdge[3, 51] -> 
             RGBColor[
              0.2187121116641707, 0.34721067488081686`, 0.9357667032524762], 
             UndirectedEdge[23, 186] -> 
             RGBColor[
              0.209250396089514, 0.3372658119044362, 0.9352278725478533], 
             UndirectedEdge[17, 319] -> 
             RGBColor[
              0.8300530358518976, 0.23200637964777565`, 0.17641212711281357`],
              UndirectedEdge[115, 360] -> 
             RGBColor[
              0.8089316906478522, 0.7980968050279984, 0.6248789386336926], 
             UndirectedEdge[131, 142] -> 
             RGBColor[
              0.6441352636384634, 0.7193460306737178, 0.9669266768382974], 
             UndirectedEdge[23, 130] -> 
             RGBColor[
              0.21379154943709947`, 0.3420388519985006, 0.935486484512964], 
             UndirectedEdge[348, 354] -> 
             RGBColor[
              0.19860265347109932`, 0.3260743593066081, 0.9346214993576583], 
             UndirectedEdge[76, 80] -> 
             RGBColor[
              0.24302079240522623`, 0.37276063959904404`, 0.9371510466592089],
              UndirectedEdge[38, 81] -> 
             RGBColor[
              0.2439408678768847, 0.37372769725591143`, 0.9372034435961902], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.22057742375863354`, 0.3491712361597149, 0.935872930016774], 
             UndirectedEdge[131, 281] -> 
             RGBColor[
              0.6064310569728814, 0.687254440774864, 0.9643678385927457], 
             UndirectedEdge[157, 167] -> 
             RGBColor[
              0.24133392101239853`, 0.37098763081135855`, 0.93705498182889], 
             UndirectedEdge[165, 172] -> 
             RGBColor[
              0.3025819493818708, 0.42881009810169846`, 0.9407829073040905], 
             UndirectedEdge[255, 331] -> 
             RGBColor[
              0.30757882188877433`, 0.4345645888368619, 0.9410490742458533], 
             UndirectedEdge[59, 268] -> 
             RGBColor[
              0.2019662570213913, 0.3296097199027477, 0.9348130516038419], 
             UndirectedEdge[161, 364] -> 
             RGBColor[
              0.9004423422818535, 0.6358848335091806, 0.23838402091941335`], 
             UndirectedEdge[149, 164] -> 
             RGBColor[
              0.21265948505393958`, 0.340848980554772, 0.9354220151210823], 
             UndirectedEdge[10, 52] -> 
             RGBColor[
              0.9159808794279284, 0.6604932743481702, 0.5104145698509248], 
             UndirectedEdge[132, 155] -> 
             RGBColor[
              0.18938684794258642`, 0.3163879633803221, 0.934096672866372], 
             UndirectedEdge[353, 400] -> 
             RGBColor[
              0.9076875092111716, 0.5794922772788073, 0.33827994298726377`], 
             UndirectedEdge[250, 265] -> 
             RGBColor[
              0.19635832810443649`, 0.32371543104779843`, 0.9344936883482087],
              UndirectedEdge[82, 233] -> 
             RGBColor[
              0.865044812104987, 0.8948209835298624, 0.9558976637938235], 
             UndirectedEdge[66, 81] -> 
             RGBColor[
              0.21264159429708712`, 0.3408301762349806, 0.9354209962689466], 
             UndirectedEdge[69, 201] -> 
             RGBColor[
              0.6192660008437627, 0.7014292931597987, 0.9634146436784279], 
             UndirectedEdge[84, 184] -> 
             RGBColor[
              0.21392003441563898`, 0.34217389785736374`, 0.9354938015424155],
              UndirectedEdge[180, 268] -> 
             RGBColor[
              0.1880422345433147, 0.314974689444274, 0.9340200991224608], 
             UndirectedEdge[17, 247] -> 
             RGBColor[
              0.8225002166596341, 0.17395210166956507`, 0.16917953892461288`],
              UndirectedEdge[188, 394] -> 
             RGBColor[
              0.3167171676025393, 0.44570099448454903`, 0.9415134165478973], 
             UndirectedEdge[241, 312] -> 
             RGBColor[
              0.41436397282412324`, 0.5281836244089898, 0.9484270661099586], 
             UndirectedEdge[81, 128] -> 
             RGBColor[
              0.2665289573662383, 0.3974692114768138, 0.9384898018765251], 
             UndirectedEdge[65, 198] -> 
             RGBColor[
              0.6026458427872066, 0.6834233570756016, 0.9643717480774334], 
             UndirectedEdge[356, 380] -> 
             RGBColor[
              0.8328828698668729, 0.8701375149884446, 0.9750500932107594], 
             UndirectedEdge[40, 265] -> 
             RGBColor[
              0.1962226401289317, 0.32357281438242835`, 0.9344859611187359], 
             UndirectedEdge[19, 168] -> 
             RGBColor[
              0.19873861175960342`, 0.3262172600880793, 0.9346292419810562], 
             UndirectedEdge[195, 241] -> 
             RGBColor[
              0.35276484059541724`, 0.47739540900316435`, 0.9437930699766406],
              UndirectedEdge[33, 141] -> 
             RGBColor[
              0.3011781143378584, 0.42954027603387246`, 0.9406221995821449], 
             UndirectedEdge[65, 100] -> 
             RGBColor[
              0.38210315454201915`, 0.5053802802265043, 0.9455682530202327], 
             UndirectedEdge[15, 207] -> 
             RGBColor[
              0.18682358813972555`, 0.3136938148074571, 0.9339506990126021], 
             UndirectedEdge[81, 135] -> 
             RGBColor[
              0.2822556151095555, 0.41153871876028536`, 0.9394754920042432], 
             UndirectedEdge[259, 271] -> 
             RGBColor[
              0.8577136869121025, 0.5371034017102467, 0.5783377792427893], 
             UndirectedEdge[194, 233] -> 
             RGBColor[
              0.7128854689421396, 0.7730895863286765, 0.9426895386250231], 
             UndirectedEdge[101, 283] -> 
             RGBColor[
              0.8929481444706848, 0.5918370196285758, 0.23170005506756156`], 
             UndirectedEdge[145, 192] -> 
             RGBColor[
              0.25406976709764434`, 0.3843738125462326, 0.9377802694224489], 
             UndirectedEdge[68, 397] -> 
             RGBColor[
              0.5928919663607762, 0.6752224028696671, 0.9636363647773936], 
             UndirectedEdge[142, 201] -> 
             RGBColor[
              0.5699368421210522, 0.6613816598554264, 0.9595312716051138], 
             UndirectedEdge[146, 354] -> 
             RGBColor[
              0.197615256434939, 0.32503654241701563`, 0.9345652685571719], 
             UndirectedEdge[153, 329] -> 
             RGBColor[
              0.23399514583317907`, 0.36327411279277777`, 0.9366370494391784],
              UndirectedEdge[132, 279] -> 
             RGBColor[
              0.1959554713815859, 0.323292003089491, 0.9344707462538155], 
             UndirectedEdge[257, 389] -> 
             RGBColor[
              0.981271770948398, 0.982206986986089, 0.7147685106713391], 
             UndirectedEdge[107, 386] -> 
             RGBColor[
              0.2825040137132291, 0.4111922082727934, 0.9395118848995476], 
             UndirectedEdge[157, 203] -> 
             RGBColor[
              0.2784354581733116, 0.40986687435040126`, 0.9391721369966093], 
             UndirectedEdge[264, 281] -> 
             RGBColor[
              0.3293650670543722, 0.4551923504771167, 0.9423729197712435], 
             UndirectedEdge[244, 302] -> 
             RGBColor[
              0.18853043849765405`, 0.3154878227542032, 0.9340479016154273], 
             UndirectedEdge[46, 105] -> 
             RGBColor[
              0.8954193827902208, 0.9181003086598438, 0.937247307981482], 
             UndirectedEdge[126, 347] -> 
             RGBColor[
              0.18344187738111917`, 0.31013942238731573`, 0.9337581155876922],
              UndirectedEdge[129, 253] -> 
             RGBColor[
              0.822264279381292, 0.17213858435985327`, 0.16895360512041946`], 
             UndirectedEdge[14, 69] -> 
             RGBColor[
              0.45573362712038445`, 0.5659105913267511, 0.9511564428609628], 
             UndirectedEdge[118, 124] -> 
             RGBColor[
              0.29203302591126107`, 0.41977282835890883`, 0.9401070895447208],
              UndirectedEdge[181, 245] -> 
             RGBColor[
              0.1935081925729178, 0.3207197578951424, 0.9343313773460864], 
             UndirectedEdge[33, 152] -> 
             RGBColor[
              0.2237166408577273, 0.3524707523687224, 0.9360517037865118], 
             UndirectedEdge[47, 371] -> 
             RGBColor[
              0.18051873474236652`, 0.3070670141360388, 0.9335916469388172], 
             UndirectedEdge[131, 273] -> 
             RGBColor[
              0.6690783888345512, 0.7395959833828867, 0.9688902910234116], 
             UndirectedEdge[230, 299] -> 
             RGBColor[
              0.20475753633962784`, 0.33254353144354476`, 0.9349720108316877],
              UndirectedEdge[107, 181] -> 
             RGBColor[
              0.20760170595158578`, 0.3355329340364814, 0.935133982083517], 
             UndirectedEdge[4, 318] -> 
             RGBColor[
              0.20715075077545358`, 0.3350589515541568, 0.9351083008533645], 
             UndirectedEdge[10, 333] -> 
             RGBColor[
              0.8983718156694669, 0.6481583597796403, 0.5759535503804154], 
             UndirectedEdge[152, 238] -> 
             RGBColor[
              0.20086303760420032`, 0.32845016634712887`, 0.9347502248900996],
              UndirectedEdge[50, 147] -> 
             RGBColor[
              0.23917140342485926`, 0.3687146877153205, 0.9369318296514377], 
             UndirectedEdge[39, 217] -> 
             RGBColor[
              0.2032105562120073, 0.33091755724521044`, 0.9348839126019717], 
             UndirectedEdge[98, 308] -> 
             RGBColor[
              0.20304826815792704`, 0.3307469822107151, 0.9348746705373756], 
             UndirectedEdge[31, 363] -> 
             RGBColor[
              0.6793920980440895, 0.7432878081939467, 0.9278140990011539], 
             UndirectedEdge[286, 386] -> 
             RGBColor[
              0.331585149915525, 0.4616241237277755, 0.94234929043675], 
             UndirectedEdge[137, 138] -> 
             RGBColor[
              0.29077492625511725`, 0.4229532620622423, 0.93987057393605], 
             UndirectedEdge[35, 372] -> 
             RGBColor[
              0.18502327958345532`, 0.31180157636866185`, 0.9338481741036404],
              UndirectedEdge[130, 158] -> 
             RGBColor[
              0.20340188077088672`, 0.3311186514872704, 0.9348948082525605], 
             UndirectedEdge[277, 373] -> 
             RGBColor[
              0.19154984531155025`, 0.31866141075705723`, 0.9342198523666666],
              UndirectedEdge[234, 365] -> 
             RGBColor[
              0.27647661087306347`, 0.4079248260301478, 0.9390563060275041], 
             UndirectedEdge[310, 316] -> 
             RGBColor[
              0.7693289728620583, 0.48993694637010154`, 0.5724844799948403], 
             UndirectedEdge[218, 305] -> 
             RGBColor[
              0.42916789405553485`, 0.5422531768418173, 0.9494057845729981], 
             UndirectedEdge[155, 279] -> 
             RGBColor[
              0.19246829134850796`, 0.31962675577474187`, 0.9342721565097523],
              UndirectedEdge[32, 129] -> 
             RGBColor[
              0.8204275141231614, 0.1580204017101934, 0.16719471663490398`], 
             UndirectedEdge[92, 158] -> 
             RGBColor[
              0.19775538870657966`, 0.32518383031940923`, 0.9345732488827347],
              UndirectedEdge[332, 334] -> 
             RGBColor[
              0.8890082529415364, 0.5076542323723299, 0.23230663812042954`], 
             UndirectedEdge[268, 300] -> 
             RGBColor[
              0.1919105716037125, 0.31904055696148764`, 0.9342403951953585], 
             UndirectedEdge[224, 227] -> 
             RGBColor[
              0.3858696957004528, 0.504223043119987, 0.9462592294929938], 
             UndirectedEdge[25, 91] -> 
             RGBColor[
              0.47826887557608655`, 0.5848930154724093, 0.9527405987202289], 
             UndirectedEdge[74, 304] -> 
             RGBColor[
              0.2654021800822186, 0.39628489710950293`, 0.9384256335771177], 
             UndirectedEdge[86, 397] -> 
             RGBColor[
              0.3161394186740798, 0.4444877390569253, 0.9415027034007689], 
             UndirectedEdge[32, 111] -> 
             RGBColor[
              0.8240654755025505, 0.18598336703701845`, 0.17067843256029655`],
              UndirectedEdge[59, 394] -> 
             RGBColor[
              0.286948743301538, 0.41441249311708334`, 0.9398181488223927], 
             UndirectedEdge[170, 355] -> 
             RGBColor[
              0.2218222289646276, 0.3504796053564232, 0.9359438198317311], 
             UndirectedEdge[9, 56] -> 
             RGBColor[
              0.6023784760141789, 0.6874029877027437, 0.9623014191002394], 
             UndirectedEdge[44, 317] -> 
             RGBColor[
              0.2084087804726259, 0.3363812205295747, 0.9351799437835304], 
             UndirectedEdge[236, 262] -> 
             RGBColor[
              0.4369845815472029, 0.5513866495573997, 0.9494877616771007], 
             UndirectedEdge[119, 346] -> 
             RGBColor[
              0.2216080062797242, 0.35025444373208703`, 0.9359316201667398], 
             UndirectedEdge[80, 244] -> 
             RGBColor[
              0.1927330122426994, 0.31990499421881113`, 0.9342872319730569], 
             UndirectedEdge[20, 360] -> 
             RGBColor[
              0.523690607917635, 0.622017048024192, 0.9563749606192402], 
             UndirectedEdge[196, 206] -> 
             RGBColor[
              0.6365065028818196, 0.7122246861355508, 0.9667719599708235], 
             UndirectedEdge[187, 302] -> 
             RGBColor[
              0.20552429842574232`, 0.33334944701157526`, 0.9350156767981692],
              UndirectedEdge[147, 312] -> 
             RGBColor[
              0.3975158125820031, 0.5104751397594638, 0.9474675883087893], 
             UndirectedEdge[259, 400] -> 
             RGBColor[
              0.8587699196703826, 0.545222069534533, 0.5793492289249624], 
             UndirectedEdge[120, 312] -> 
             RGBColor[
              0.4801821242946682, 0.587765497365623, 0.9525267121427227], 
             UndirectedEdge[52, 60] -> 
             RGBColor[
              0.8480092281788032, 0.880384326820778, 0.9017418370121976], 
             UndirectedEdge[266, 384] -> 
             RGBColor[
              0.7959032258697958, 0.7536598609266292, 0.6159939861993788], 
             UndirectedEdge[135, 393] -> 
             RGBColor[
              0.5286635054610748, 0.6238093444947674, 0.9577562869015417], 
             UndirectedEdge[77, 244] -> 
             RGBColor[
              0.18965577385650711`, 0.31667062156674053`, 0.9341119877993296],
              UndirectedEdge[239, 385] -> 
             RGBColor[
              0.750777447641219, 0.8006120212149852, 0.7940547292395577], 
             UndirectedEdge[278, 296] -> 
             RGBColor[
              0.1835851599868279, 0.3102900214905575, 0.9337662753201197], 
             UndirectedEdge[267, 275] -> 
             RGBColor[
              0.19585412945824818`, 0.323185486302614, 0.9344649749812033], 
             UndirectedEdge[148, 340] -> 
             RGBColor[
              0.263972502592159, 0.39478221542066183`, 0.9383442155590771], 
             UndirectedEdge[202, 212] -> 
             RGBColor[
              0.45268550871471924`, 0.56313574583105, 0.9509994425842794], 
             UndirectedEdge[81, 346] -> 
             RGBColor[
              0.21629108370638292`, 0.34466602099514354`, 0.9356288292918702],
              UndirectedEdge[50, 217] -> 
             RGBColor[
              0.21968733955898895`, 0.34823570123129066`, 0.9358222410383658],
              UndirectedEdge[5, 183] -> 
             RGBColor[
              0.1877508166785864, 0.3146683907914848, 0.9340035033061785], 
             UndirectedEdge[313, 339] -> 
             RGBColor[
              0.3332875570200404, 0.460867825469856, 0.9425394482092617], 
             UndirectedEdge[4, 184] -> 
             RGBColor[
              0.20719899217930893`, 0.3351096563282905, 0.9351110481299474], 
             UndirectedEdge[104, 349] -> 
             RGBColor[
              0.21123195753513827`, 0.3393485586220395, 0.9353407195407242], 
             UndirectedEdge[119, 135] -> 
             RGBColor[
              0.2875725376828968, 0.4171271414972289, 0.9397782828791128], 
             UndirectedEdge[53, 273] -> 
             RGBColor[
              0.4633253395942303, 0.573810427068907, 0.9512742786711021], 
             UndirectedEdge[224, 259] -> 
             RGBColor[
              0.6965860849930616, 0.7612921063995717, 0.9717456253125671], 
             UndirectedEdge[110, 289] -> 
             RGBColor[
              0.6635885313279589, 0.7348104646113509, 0.9687942877706517], 
             UndirectedEdge[59, 155] -> 
             RGBColor[
              0.20108602021263303`, 0.3286845352065056, 0.9347629234197767], 
             UndirectedEdge[5, 29] -> 
             RGBColor[
              0.18632940584411195`, 0.31317439788179996`, 0.9339225560619441],
              UndirectedEdge[119, 311] -> 
             RGBColor[
              0.22119300122602184`, 0.3498182471078057, 0.9359079862428765], 
             UndirectedEdge[68, 72] -> 
             RGBColor[
              0.6435705389401349, 0.7187858683660439, 0.9669572267898132], 
             UndirectedEdge[121, 234] -> 
             RGBColor[
              0.2453302072944222, 0.37518798107295015`, 0.9372825644206755], 
             UndirectedEdge[20, 336] -> 
             RGBColor[
              0.3097133743307097, 0.43584317444763615`, 0.9412059659212678], 
             UndirectedEdge[17, 256] -> 
             RGBColor[
              0.9099828197722593, 0.6023554678641716, 0.47566457355675007`], 
             UndirectedEdge[186, 272] -> 
             RGBColor[
              0.20161622991530592`, 0.3292418192212516, 0.9347931180779689], 
             UndirectedEdge[45, 304] -> 
             RGBColor[
              0.2609958832174149, 0.3916535997292371, 0.9381747014891992], 
             UndirectedEdge[165, 252] -> 
             RGBColor[
              0.21574093049341658`, 0.3440877750865875, 0.9355974988802704], 
             UndirectedEdge[106, 254] -> 
             RGBColor[
              0.18679837373704838`, 0.3136673128715579, 0.9339492630896711], 
             UndirectedEdge[144, 169] -> 
             RGBColor[
              0.5192579762174159, 0.6205960432553745, 0.9552970364739267], 
             UndirectedEdge[191, 355] -> 
             RGBColor[
              0.19607480659810572`, 0.32341743196834305`, 0.9344775422178556],
              UndirectedEdge[96, 377] -> 
             RGBColor[
              0.23316169487877575`, 0.36239810299585723`, 0.9365895856403053],
              UndirectedEdge[110, 303] -> 
             RGBColor[
              0.873446363467674, 0.7484181435664192, 0.6095212570798225], 
             UndirectedEdge[177, 260] -> 
             RGBColor[
              0.18516377148342406`, 0.31194924226322995`, 0.9338561749095045],
              UndirectedEdge[20, 88] -> 
             RGBColor[
              0.40751079531136875`, 0.5273871016357587, 0.9471872054229611], 
             UndirectedEdge[57, 68] -> 
             RGBColor[
              0.584951659196002, 0.6683449078949819, 0.9631304154261922], 
             UndirectedEdge[127, 264] -> 
             RGBColor[
              0.2996738393944105, 0.42947530140255136`, 0.9404810209996725], 
             UndirectedEdge[171, 186] -> 
             RGBColor[
              0.1973172314150955, 0.32472329922528254`, 0.9345482964731804], 
             UndirectedEdge[362, 385] -> 
             RGBColor[
              0.892844244734438, 0.9136671066548807, 0.806798376116899], 
             UndirectedEdge[109, 370] -> 
             RGBColor[
              0.18414849826566793`, 0.3108821257393283, 0.9337983566017154], 
             UndirectedEdge[123, 161] -> 
             RGBColor[
              0.861352076814639, 0.4393326641242953, 0.20508206465224244`], 
             UndirectedEdge[119, 213] -> 
             RGBColor[
              0.2826015926364835, 0.4128215587449884, 0.9394615386563896], 
             UndirectedEdge[140, 360] -> 
             RGBColor[
              0.5345510834209994, 0.6314238460418358, 0.9570669805147731], 
             UndirectedEdge[320, 347] -> 
             RGBColor[
              0.1840162025368019, 0.3107430745402564, 0.9337908225556705], 
             UndirectedEdge[10, 345] -> 
             RGBColor[
              0.8355254140940163, 0.5985125148757706, 0.5861216038325132], 
             UndirectedEdge[169, 383] -> 
             RGBColor[
              0.4077881387207459, 0.527520322736191, 0.9472344418691334], 
             UndirectedEdge[154, 372] -> 
             RGBColor[
              0.18315975702077553`, 0.3098428960011307, 0.9337420492505304], 
             UndirectedEdge[167, 341] -> 
             RGBColor[
              0.2425749937598598, 0.37229207695749733`, 0.9371256590858552], 
             UndirectedEdge[186, 308] -> 
             RGBColor[
              0.20971443584181115`, 0.3377535471059201, 0.9352542989252615], 
             UndirectedEdge[145, 225] -> 
             RGBColor[
              0.22917757181567264`, 0.3582105370485437, 0.9363626957258434], 
             UndirectedEdge[12, 65] -> 
             RGBColor[
              0.30963980079837916`, 0.4365176650238572, 0.941174248166886], 
             UndirectedEdge[274, 288] -> 
             RGBColor[
              0.20843688657003606`, 0.3364107618199823, 0.9351815443841986], 
             UndirectedEdge[143, 171] -> 
             RGBColor[
              0.19347840745274208`, 0.320688451845352, 0.9343296811275554], 
             UndirectedEdge[167, 168] -> 
             RGBColor[
              0.21688542639170627`, 0.3452907128409211, 0.935662676228548], 
             UndirectedEdge[203, 341] -> 
             RGBColor[
              0.2796765309207728, 0.4111713204965401, 0.9392428142535747], 
             UndirectedEdge[114, 299] -> 
             RGBColor[
              0.1875337477163088, 0.31444023754916384`, 0.9339911415499016], 
             UndirectedEdge[154, 231] -> 
             RGBColor[
              0.18878970308862236`, 0.3157603262776354, 0.9340626663503354], 
             UndirectedEdge[218, 384] -> 
             RGBColor[
              0.7469305423915883, 0.7141446268230167, 0.6119725391027997], 
             UndirectedEdge[360, 380] -> 
             RGBColor[
              0.6915688443012366, 0.7589781043767949, 0.9698927773878063], 
             UndirectedEdge[98, 306] -> 
             RGBColor[
              0.20777436312467215`, 0.33571440767249217`, 0.9351438146541007],
              UndirectedEdge[57, 262] -> 
             RGBColor[
              0.35631608788520674`, 0.4830448191840292, 0.9439251239354682], 
             UndirectedEdge[152, 160] -> 
             RGBColor[
              0.19806967394342445`, 0.325514164030168, 0.9345911469620297], 
             UndirectedEdge[311, 354] -> 
             RGBColor[
              0.19934869375531813`, 0.32685849494700814`, 0.9346639852481768],
              UndirectedEdge[287, 303] -> 
             RGBColor[
              0.8556245290555657, 0.372684995897263, 0.19871148964339302`], 
             UndirectedEdge[222, 247] -> 
             RGBColor[
              0.8842131182088144, 0.5486602398250497, 0.5659586027648067], 
             UndirectedEdge[24, 206] -> 
             RGBColor[
              0.3445350824096081, 0.46835060878643464`, 0.9433388530787478], 
             UndirectedEdge[92, 308] -> 
             RGBColor[
              0.20860909712508957`, 0.3365917660321234, 0.9351913515205462], 
             UndirectedEdge[18, 266] -> 
             RGBColor[
              0.8253787823254205, 0.8596851688766582, 0.6977603506868537], 
             UndirectedEdge[28, 314] -> 
             RGBColor[
              0.18717488313259786`, 0.3140630481183549, 0.9339707047427519], 
             UndirectedEdge[128, 139] -> 
             RGBColor[
              0.3054227451460619, 0.43834904844198347`, 0.9407047455523833], 
             UndirectedEdge[160, 181] -> 
             RGBColor[
              0.19370887514270452`, 0.320930687999998, 0.9343428059215524], 
             UndirectedEdge[42, 296] -> 
             RGBColor[
              0.18148102360409654`, 0.30807844074235485`, 0.933646447865914], 
             UndirectedEdge[121, 289] -> 
             RGBColor[
              0.3589692840265578, 0.4787637861846151, 0.9444710719407625], 
             UndirectedEdge[22, 286] -> 
             RGBColor[
              0.2816381839372477, 0.41219449596583724`, 0.9393925574171622], 
             UndirectedEdge[128, 213] -> 
             RGBColor[
              0.3146576489473405, 0.4465145063990592, 0.9412870836406073], 
             UndirectedEdge[178, 398] -> 
             RGBColor[
              0.18190742429108608`, 0.30852661489974587`, 0.9336707307542348],
              UndirectedEdge[6, 129] -> 
             RGBColor[
              0.8727497313117147, 0.5467966411297123, 0.579484556485264], 
             UndirectedEdge[265, 375] -> 
             RGBColor[
              0.20089610111622702`, 0.32848491819461667`, 0.9347521078081966],
              UndirectedEdge[162, 270] -> 
             RGBColor[
              0.20162095796864934`, 0.3292467887050914, 0.9347933873336124], 
             UndirectedEdge[199, 271] -> 
             RGBColor[
              0.9043692525849842, 0.5721827291840494, 0.5015646144777819], 
             UndirectedEdge[60, 72] -> 
             RGBColor[
              0.5862802580314027, 0.6740171687476564, 0.9612505424717664], 
             UndirectedEdge[230, 258] -> 
             RGBColor[
              0.22938899732612533`, 0.3584327586651811, 0.9363747360958877], 
             UndirectedEdge[38, 135] -> 
             RGBColor[
              0.2970405045044002, 0.42707857493039736`, 0.9403174695829958], 
             UndirectedEdge[42, 67] -> 
             RGBColor[
              0.18164605198289263`, 0.3082518960318731, 0.9336558459879488], 
             UndirectedEdge[220, 352] -> 
             RGBColor[
              0.1830449444132805, 0.30972222067111355`, 0.9337355108423835], 
             UndirectedEdge[4, 226] -> 
             RGBColor[
              0.1963748100004493, 0.3237327545655205, 0.9344946269678038], 
             UndirectedEdge[134, 163] -> 
             RGBColor[
              0.17908461226291875`, 0.3055596604815222, 0.9335099757852068], 
             UndirectedEdge[25, 76] -> 
             RGBColor[
              0.32344841914925154`, 0.45219009338865274`, 0.9419182030554161],
              UndirectedEdge[250, 375] -> 
             RGBColor[
              0.19825790374427554`, 0.32571200548532114`, 0.9346018663707272],
              UndirectedEdge[50, 138] -> 
             RGBColor[
              0.26001645706684573`, 0.3906241607457843, 0.9381189246188555], 
             UndirectedEdge[24, 157] -> 
             RGBColor[
              0.2535215613420126, 0.38379761353881126`, 0.9377490499156633], 
             UndirectedEdge[127, 328] -> 
             RGBColor[
              0.2853602010040631, 0.41443075991720546`, 0.9396658804684725], 
             UndirectedEdge[107, 245] -> 
             RGBColor[
              0.20898762068619692`, 0.33698961829462715`, 0.9352129078773759],
              UndirectedEdge[16, 96] -> 
             RGBColor[
              0.22029148033523374`, 0.34887069149186156`, 0.9358566459618267],
              UndirectedEdge[42, 278] -> 
             RGBColor[
              0.18598976689484537`, 0.3128174158117676, 0.9339032141262342], 
             UndirectedEdge[51, 176] -> 
             RGBColor[
              0.19370665948804128`, 0.32092835920646634`, 0.9343426797432972],
              UndirectedEdge[33, 386] -> 
             RGBColor[
              0.2942581498186507, 0.4235465505748645, 0.9401812655620653], 
             UndirectedEdge[78, 187] -> 
             RGBColor[
              0.21840643996372563`, 0.3468893945429439, 0.9357492957013367], 
             UndirectedEdge[107, 150] -> 
             RGBColor[
              0.23074389884075946`, 0.35985684606277935`, 0.936451895732749], 
             UndirectedEdge[312, 360] -> 
             RGBColor[
              0.6052860238543496, 0.6901250393354524, 0.9622831022684131], 
             UndirectedEdge[78, 208] -> 
             RGBColor[
              0.257441859662032, 0.38791809563442126`, 0.9379723051054267], 
             UndirectedEdge[28, 197] -> 
             RGBColor[
              0.19145378666017485`, 0.3185604470239914, 0.9342143819685769], 
             UndirectedEdge[221, 316] -> 
             RGBColor[
              0.5410265117385101, 0.6349350710702945, 0.9583673358965574], 
             UndirectedEdge[243, 383] -> 
             RGBColor[
              0.29485575436090533`, 0.42265924207033345`, 0.9402707855274055],
              UndirectedEdge[83, 332] -> 
             RGBColor[
              0.8843949242801739, 0.5504136015544692, 0.5662686116652167], 
             UndirectedEdge[98, 354] -> 
             RGBColor[
              0.19467499021807763`, 0.3219461361994489, 0.9343978247458558], 
             UndirectedEdge[46, 215] -> 
             RGBColor[
              0.7558037231431869, 0.8091588799312872, 0.9762951098017001], 
             UndirectedEdge[375, 381] -> 
             RGBColor[
              0.196072227977034, 0.3234147216741027, 0.9344773953692003], 
             UndirectedEdge[286, 304] -> 
             RGBColor[
              0.3017569575169641, 0.43334060260203944`, 0.9405382918094687], 
             UndirectedEdge[225, 235] -> 
             RGBColor[
              0.20086558407238086`, 0.32845284284664206`, 0.9347503699076954],
              UndirectedEdge[96, 225] -> 
             RGBColor[
              0.21005566506834547`, 0.33811220065819025`, 0.9352737314249091],
              UndirectedEdge[20, 389] -> 
             RGBColor[
              0.688874491712781, 0.747632448851442, 0.7193091573204213], 
             UndirectedEdge[259, 393] -> 
             RGBColor[
              0.808698190108407, 0.8510901979921818, 0.9814053247963395], 
             UndirectedEdge[97, 166] -> 
             RGBColor[
              0.27189959411517783`, 0.40311409121798647`, 0.9387956516942321],
              UndirectedEdge[115, 334] -> 
             RGBColor[
              0.9576597296930937, 0.8685855926092536, 0.2913334520501617], 
             UndirectedEdge[251, 260] -> 
             RGBColor[
              0.1869284496057658, 0.31380403085686637`, 0.9339566707179645], 
             UndirectedEdge[119, 344] -> 
             RGBColor[
              0.2156761634002051, 0.3440197007651513, 0.9355938104901265], 
             UndirectedEdge[329, 341] -> 
             RGBColor[
              0.2558412218032698, 0.3862357237585604, 0.9378811511473018], 
             UndirectedEdge[283, 334] -> 
             RGBColor[
              0.9460670651662169, 0.8226245407866379, 0.2820057220570269], 
             UndirectedEdge[1, 5] -> 
             RGBColor[
              0.18431548798727523`, 0.3110576425244974, 0.9338078664193217], 
             UndirectedEdge[364, 391] -> 
             RGBColor[
              0.8707862783740112, 0.44118719063375156`, 0.21128740006323304`],
              UndirectedEdge[48, 295] -> 
             RGBColor[
              0.19691998178395526`, 0.3243057646758728, 0.9345256736943651], 
             UndirectedEdge[105, 199] -> 
             RGBColor[
              0.9870190215241651, 0.9889000460513815, 0.8647919372474027], 
             UndirectedEdge[281, 293] -> 
             RGBColor[
              0.356440478793437, 0.4831525603366694, 0.9439330500141462], 
             UndirectedEdge[216, 358] -> 
             RGBColor[
              0.24670674727990904`, 0.37663481187537284`, 0.9373609563364405],
              UndirectedEdge[100, 206] -> 
             RGBColor[
              0.40830029738828666`, 0.5280709286532568, 0.947237511797173], 
             UndirectedEdge[168, 341] -> 
             RGBColor[
              0.22365393842066325`, 0.35240484813180395`, 0.936048132975481], 
             UndirectedEdge[199, 259] -> 
             RGBColor[
              0.9420801867046171, 0.9545306309034027, 0.913114429015637], 
             UndirectedEdge[19, 24] -> 
             RGBColor[
              0.22984730742841403`, 0.35891447164122536`, 0.936400836178204], 
             UndirectedEdge[136, 299] -> 
             RGBColor[
              0.1855129526762866, 0.3123162538362948, 0.9338760602618706], 
             UndirectedEdge[64, 123] -> 
             RGBColor[
              0.9178715311357676, 0.6596421800395433, 0.31164482201230714`], 
             UndirectedEdge[101, 334] -> 
             RGBColor[
              0.9070926668350056, 0.6466589621982325, 0.24962429328823976`], 
             UndirectedEdge[2, 328] -> 
             RGBColor[
              0.2165885293871429, 0.3449786552647677, 0.935645768383358], 
             UndirectedEdge[235, 349] -> 
             RGBColor[
              0.19583192039754477`, 0.3231621431716789, 0.9344637102080516], 
             UndirectedEdge[45, 290] -> 
             RGBColor[
              0.24862549482263574`, 0.3786515371983993, 0.9374702261704662], 
             UndirectedEdge[225, 327] -> 
             RGBColor[
              0.19712268368204472`, 0.3245188172228074, 0.9345372172675908], 
             UndirectedEdge[24, 386] -> 
             RGBColor[
              0.3010543278758621, 0.4306897646155703, 0.940568297848379], 
             UndirectedEdge[363, 393] -> 
             RGBColor[
              0.5482487832688899, 0.640773127747212, 0.9590042434848745], 
             UndirectedEdge[2, 258] -> 
             RGBColor[
              0.2197390144926751, 0.34829001486297484`, 0.935825183849393], 
             UndirectedEdge[8, 234] -> 
             RGBColor[
              0.2512674523014992, 0.38142840201846384`, 0.9376206817404615], 
             UndirectedEdge[44, 151] -> 
             RGBColor[
              0.21796286839338874`, 0.3464231726984579, 0.9357240349566114], 
             UndirectedEdge[253, 283] -> 
             RGBColor[
              0.878557469851581, 0.4812239884723157, 0.21791952880036536`], 
             UndirectedEdge[257, 360] -> 
             RGBColor[
              0.816087887153252, 0.8565915861588391, 0.9518343139701578], 
             UndirectedEdge[65, 358] -> 
             RGBColor[
              0.3270456066713938, 0.4548122705882284, 0.942165483061772], 
             UndirectedEdge[282, 340] -> 
             RGBColor[
              0.29320777122887487`, 0.42492993475416496`, 0.9400303722049579],
              UndirectedEdge[256, 316] -> 
             RGBColor[
              0.8522226042580414, 0.8830674650503693, 0.8745751101286188], 
             UndirectedEdge[96, 182] -> 
             RGBColor[
              0.2267284521296566, 0.35563635697538404`, 0.9362232219828728], 
             UndirectedEdge[2, 106] -> 
             RGBColor[
              0.19417223523988333`, 0.32141770884085996`, 0.9343691935936069],
              UndirectedEdge[210, 279] -> 
             RGBColor[
              0.2223588131160111, 0.3510435893209275, 0.9359743775053473], 
             UndirectedEdge[279, 371] -> 
             RGBColor[
              0.1895350584309733, 0.3165437420007044, 0.9341051132344278], 
             UndirectedEdge[271, 353] -> 
             RGBColor[
              0.9066312764528914, 0.571373609454521, 0.33726849330509057`], 
             UndirectedEdge[306, 311] -> 
             RGBColor[
              0.21244806666191265`, 0.3406267664200514, 0.9354099751564218], 
             UndirectedEdge[64, 312] -> 
             RGBColor[
              0.7702008939642393, 0.8151650470913949, 0.695936819489472], 
             UndirectedEdge[137, 210] -> 
             RGBColor[
              0.2691626848877073, 0.40023742608984725`, 0.9386397887626219], 
             UndirectedEdge[264, 394] -> 
             RGBColor[
              0.30880202077051594`, 0.4373816733147978, 0.941062660645224], 
             UndirectedEdge[199, 224] -> 
             RGBColor[
              0.7432416506659434, 0.7963714338733744, 0.8949724605475597], 
             UndirectedEdge[61, 301] -> 
             RGBColor[
              0.23356716082772205`, 0.3628242734162258, 0.9366126763262647], 
             UndirectedEdge[48, 103] -> 
             RGBColor[
              0.2013643551866071, 0.328977082911609, 0.9347787741847848], 
             UndirectedEdge[7, 14] -> 
             RGBColor[
              0.29679890469924086`, 0.4265200793940456, 0.9403148622219284], 
             UndirectedEdge[88, 195] -> 
             RGBColor[
              0.42750707901937735`, 0.5447068775411936, 0.948461350938816], 
             UndirectedEdge[211, 341] -> 
             RGBColor[
              0.24091627830701134`, 0.3705486618479197, 0.9370311976946651], 
             UndirectedEdge[84, 185] -> 
             RGBColor[
              0.20341836522778634`, 0.3311359776966468, 0.9348957470179945], 
             UndirectedEdge[368, 387] -> 
             RGBColor[
              0.18468757746568928`, 0.3114487321581461, 0.9338290563646603], 
             UndirectedEdge[134, 171] -> 
             RGBColor[
              0.18358417843459812`, 0.31028898981693004`, 0.9337662194221723],
              UndirectedEdge[41, 295] -> 
             RGBColor[
              0.19034802985855803`, 0.31739822651646155`, 0.9341514107545453],
              UndirectedEdge[77, 388] -> 
             RGBColor[
              0.23386679686193323`, 0.36313920988620363`, 0.9366297401551412],
              UndirectedEdge[142, 273] -> 
             RGBColor[
              0.4991027451822828, 0.6042331187182427, 0.9537103428557971], 
             UndirectedEdge[64, 140] -> 
             RGBColor[
              0.6994659535308891, 0.7564638537977784, 0.690720697735832], 
             UndirectedEdge[150, 157] -> 
             RGBColor[
              0.24263401195527415`, 0.3723541088228476, 0.9371290200847746], 
             UndirectedEdge[210, 264] -> 
             RGBColor[
              0.2528298194491141, 0.3830705489504057, 0.9377096562382032], 
             UndirectedEdge[202, 309] -> 
             RGBColor[
              0.5124790971855998, 0.6108362268976354, 0.9562827357512269], 
             UndirectedEdge[105, 287] -> 
             RGBColor[
              0.9013106453354156, 0.5611585668627788, 0.528730305122088], 
             UndirectedEdge[157, 160] -> 
             RGBColor[
              0.22107841637049833`, 0.349697811159551, 0.9359014608048675], 
             UndirectedEdge[153, 379] -> 
             RGBColor[
              0.19405975897206282`, 0.32129948915197337`, 0.9343627882365483],
              UndirectedEdge[207, 387] -> 
             RGBColor[
              0.18852965084716983`, 0.3154869948836043, 0.9340478567598975], 
             UndirectedEdge[93, 264] -> 
             RGBColor[
              0.3012538452175734, 0.43084382303317337`, 0.9405816975735801], 
             UndirectedEdge[202, 365] -> 
             RGBColor[
              0.31680424057691503`, 0.4485693265510483, 0.9414167025039941], 
             UndirectedEdge[138, 230] -> 
             RGBColor[
              0.2550152839737512, 0.38536761073225334`, 0.9378341152097762], 
             UndirectedEdge[5, 291] -> 
             RGBColor[
              0.19113912643877223`, 0.3182297191806869, 0.9341964625344661], 
             UndirectedEdge[241, 360] -> 
             RGBColor[
              0.4718334584098283, 0.5745274932673213, 0.9531648972863125], 
             UndirectedEdge[299, 300] -> 
             RGBColor[
              0.19227535029574405`, 0.31942396249511773`, 0.934261168802228], 
             UndirectedEdge[9, 266] -> 
             RGBColor[
              0.6722902895010364, 0.7439175508444353, 0.9679712712136599], 
             UndirectedEdge[226, 322] -> 
             RGBColor[
              0.1935079091107788, 0.32071945995846174`, 0.9343313612033369], 
             UndirectedEdge[175, 216] -> 
             RGBColor[
              0.20297653411671235`, 0.3306715851851976, 0.9348705853898494], 
             UndirectedEdge[115, 257] -> 
             RGBColor[
              0.9622640683610495, 0.9182194829930534, 0.6096923191590835], 
             UndirectedEdge[146, 275] -> 
             RGBColor[
              0.1966367657635329, 0.324008086681476, 0.9345095449609826], 
             UndirectedEdge[64, 101] -> 
             RGBColor[
              0.9232794978996539, 0.7012101823729198, 0.31682349709282953`], 
             UndirectedEdge[79, 390] -> 
             RGBColor[
              0.2060170491676479, 0.3338673592835195, 0.9350437382239613], 
             UndirectedEdge[98, 378] -> 
             RGBColor[
              0.21674290293340537`, 0.34514091164973765`, 0.9356545597284425],
              UndirectedEdge[37, 80] -> 
             RGBColor[
              0.24371904320437376`, 0.3734945454606058, 0.9371908110092508], 
             UndirectedEdge[344, 354] -> 
             RGBColor[
              0.1938318559295014, 0.32105994860435383`, 0.9343498094954268], 
             UndirectedEdge[119, 227] -> 
             RGBColor[
              0.25689083303762017`, 0.3873389317150586, 0.9379409249543373], 
             UndirectedEdge[81, 166] -> 
             RGBColor[
              0.2371652059079643, 0.3666060469247946, 0.9368175796707537], 
             UndirectedEdge[192, 221] -> 
             RGBColor[
              0.3140891047086496, 0.4418027488287358, 0.9414053462268441], 
             UndirectedEdge[242, 331] -> 
             RGBColor[
              0.2906837062391053, 0.4199308888343219, 0.9399725324164205], 
             UndirectedEdge[225, 322] -> 
             RGBColor[
              0.2017966288426081, 0.3294314299317988, 0.9348033915300026], 
             UndirectedEdge[165, 170] -> 
             RGBColor[
              0.23052227294686206`, 0.35962390319639986`, 0.9364392744659576],
              UndirectedEdge[41, 250] -> 
             RGBColor[
              0.1942575833696331, 0.32150741513661096`, 0.934374054043335], 
             UndirectedEdge[31, 393] -> 
             RGBColor[
              0.8531150739602782, 0.8852437730014981, 0.9417329113283139], 
             UndirectedEdge[140, 312] -> 
             RGBColor[
              0.4770815978352943, 0.5850799771835042, 0.9523291493384193], 
             UndirectedEdge[56, 100] -> 
             RGBColor[
              0.4530551393941151, 0.565068246426121, 0.9505774993750733], 
             UndirectedEdge[89, 183] -> 
             RGBColor[
              0.21045489979042858`, 0.338531821664043, 0.935296467251717], 
             UndirectedEdge[39, 210] -> 
             RGBColor[
              0.22192743235245416`, 0.35059018078730897`, 0.9359498110090333],
              UndirectedEdge[34, 321] -> 
             RGBColor[
              0.18374554341254123`, 0.3104585946398788, 0.9337754089189481], 
             UndirectedEdge[148, 301] -> 
             RGBColor[
              0.25321055434935075`, 0.3834707254705414, 0.9377313385275249], 
             UndirectedEdge[136, 155] -> 
             RGBColor[
              0.18426793717549678`, 0.3110076636064226, 0.933805158470936], 
             UndirectedEdge[51, 205] -> 
             RGBColor[
              0.19318129293550862`, 0.32037616564959115`, 0.9343127608953405],
              UndirectedEdge[11, 123] -> 
             RGBColor[
              0.8581753215010539, 0.6172298567057516, 0.5883641909402252], 
             UndirectedEdge[223, 400] -> 
             RGBColor[
              0.8406657720719041, 0.3123044383826159, 0.18652492711661786`], 
             UndirectedEdge[6, 201] -> 
             RGBColor[
              0.7959386825090102, 0.8413708229845736, 0.9800676455168078], 
             UndirectedEdge[201, 273] -> 
             RGBColor[
              0.5948799673171399, 0.6816316125645953, 0.9614948857902279], 
             UndirectedEdge[54, 196] -> 
             RGBColor[
              0.8961892019683437, 0.8555483275728113, 0.6311082747514651], 
             UndirectedEdge[84, 288] -> 
             RGBColor[
              0.21401051896422651`, 0.342269002854981, 0.9354989545035975], 
             UndirectedEdge[177, 248] -> 
             RGBColor[
              0.18215464872777276`, 0.30878646345763827`, 0.9336848098201683],
              UndirectedEdge[76, 117] -> 
             RGBColor[
              0.4207333030341396, 0.5335965741048728, 0.9489064510842957], 
             UndirectedEdge[342, 348] -> 
             RGBColor[
              0.1937491041812462, 0.3209729712701737, 0.9343450969057838], 
             UndirectedEdge[332, 389] -> 
             RGBColor[
              0.905464097691441, 0.5627808456183245, 0.32878632140514163`], 
             UndirectedEdge[68, 236] -> 
             RGBColor[
              0.6656201528579981, 0.7366867382683524, 0.9686930531678246], 
             UndirectedEdge[84, 318] -> 
             RGBColor[
              0.2138717930117836, 0.3421231930832301, 0.9354910542658326], 
             UndirectedEdge[15, 372] -> 
             RGBColor[
              0.1810383624053819, 0.30761317575616476`, 0.9336212389655058], 
             UndirectedEdge[88, 189] -> 
             RGBColor[
              0.331784795723977, 0.4548098720727408, 0.9426178463888004], 
             UndirectedEdge[364, 380] -> 
             RGBColor[
              0.8208602613542741, 0.753663537851497, 0.6141649050014586], 
             UndirectedEdge[103, 295] -> 
             RGBColor[
              0.1903453971129866, 0.3173954593339403, 0.9341512608235798], 
             UndirectedEdge[20, 257] -> 
             RGBColor[
              0.6770229856308323, 0.7421397259892473, 0.9411883411446311], 
             UndirectedEdge[12, 24] -> 
             RGBColor[
              0.25148362362516946`, 0.3816556117856949, 0.9376329923775478], 
             UndirectedEdge[152, 157] -> 
             RGBColor[
              0.22385261786682037`, 0.3526136728267195, 0.9360594474760198], 
             UndirectedEdge[26, 70] -> 
             RGBColor[
              0.1896105861046007, 0.3166231263744179, 0.9341094144237078], 
             UndirectedEdge[33, 74] -> 
             RGBColor[
              0.24756162893783695`, 0.3775333467004828, 0.9374096405821755], 
             UndirectedEdge[124, 238] -> 
             RGBColor[
              0.21375043106969976`, 0.3419956339873084, 0.9354841428827698], 
             UndirectedEdge[148, 339] -> 
             RGBColor[
              0.3192552716311131, 0.4461190038278132, 0.9417403303152683], 
             UndirectedEdge[175, 229] -> 
             RGBColor[
              0.1940292110138258, 0.32126738131101384`, 0.9343610485755184], 
             UndirectedEdge[105, 337] -> 
             RGBColor[
              0.9711407562018461, 0.97781294412538, 0.9254748728105828], 
             UndirectedEdge[158, 306] -> 
             RGBColor[
              0.20672015111524922`, 0.33460636400968674`, 0.935083778839731], 
             UndirectedEdge[136, 268] -> 
             RGBColor[
              0.18514817398425504`, 0.3119328483026647, 0.9338552866550012], 
             UndirectedEdge[133, 278] -> 
             RGBColor[
              0.18574944160901402`, 0.31256481869885566`, 0.9338895279567354],
              UndirectedEdge[197, 254] -> 
             RGBColor[
              0.18919463052287389`, 0.31618593068491585`, 0.9340857263686796],
              UndirectedEdge[296, 398] -> 
             RGBColor[
              0.17994179284220208`, 0.3064606116187368, 0.933558790951112], 
             UndirectedEdge[10, 271] -> 
             RGBColor[
              0.8314849257202783, 0.24301251263429177`, 0.17778330646786333`],
              UndirectedEdge[221, 399] -> 
             RGBColor[
              0.36464378874039466`, 0.49025785510237774`, 0.9444557576700642],
              UndirectedEdge[187, 388] -> 
             RGBColor[
              0.2435643246839634, 0.37333192648593383`, 0.937182000018399], 
             UndirectedEdge[143, 186] -> 
             RGBColor[
              0.20274228315425485`, 0.3304253725712859, 0.9348572451440806], 
             UndirectedEdge[372, 387] -> 
             RGBColor[
              0.18274442511282618`, 0.30940635583231196`, 0.9337183967128011],
              UndirectedEdge[147, 255] -> 
             RGBColor[
              0.3107019378391358, 0.4378471817176799, 0.9412269310789902], 
             UndirectedEdge[27, 86] -> 
             RGBColor[
              0.23656599040606416`, 0.3659762334398404, 0.9367834552343804], 
             UndirectedEdge[19, 157] -> 
             RGBColor[
              0.2231871063802957, 0.35191417805851677`, 0.9360215475813982], 
             UndirectedEdge[192, 208] -> 
             RGBColor[
              0.27634222217301546`, 0.40778357498566165`, 0.9390486527898467],
              UndirectedEdge[88, 89] -> 
             RGBColor[
              0.33131087657095276`, 0.4543117529947025, 0.9425908573941362], 
             UndirectedEdge[54, 332] -> 
             RGBColor[
              0.8830293594773344, 0.4852062873571179, 0.22095265658473165`], 
             UndirectedEdge[282, 301] -> 
             RGBColor[
              0.2824458229860667, 0.41361844480404447`, 0.9394174951734057], 
             UndirectedEdge[264, 328] -> 
             RGBColor[
              0.24566528906336602`, 0.3755401732575213, 0.9373016468317077], 
             UndirectedEdge[124, 156] -> 
             RGBColor[
              0.21424517968646528`, 0.3425156461524031, 0.9355123180845796], 
             UndirectedEdge[64, 120] -> 
             RGBColor[
              0.7025664799902631, 0.759149373979897, 0.6909182605401354], 
             UndirectedEdge[55, 236] -> 
             RGBColor[
              0.6566866391587384, 0.7296947127190476, 0.9678061194855357], 
             UndirectedEdge[11, 196] -> 
             RGBColor[
              0.8586587168624804, 0.8901351694289188, 0.9863808290196707], 
             UndirectedEdge[223, 319] -> 
             RGBColor[
              0.845830354553812, 0.35200168247303465`, 0.19147053713385456`], 
             UndirectedEdge[61, 70] -> 
             RGBColor[
              0.20711529305388426`, 0.33502168324063814`, 0.9351062815885762],
              UndirectedEdge[307, 343] -> 
             RGBColor[
              0.1898749181249935, 0.3169009560874688, 0.9341244677412249], 
             UndirectedEdge[13, 87] -> 
             RGBColor[
              0.2001057560025477, 0.3276542153693653, 0.9347070988231834], 
             UndirectedEdge[119, 128] -> 
             RGBColor[
              0.2718458799395796, 0.4030576342137573, 0.9387925927513947], 
             UndirectedEdge[92, 130] -> 
             RGBColor[
              0.2100169217474722, 0.33807147897148404`, 0.935271525050101], 
             UndirectedEdge[263, 359] -> 
             RGBColor[
              0.31376085658735253`, 0.4455463754257799, 0.941236947982536], 
             UndirectedEdge[22, 304] -> 
             RGBColor[
              0.2621517349847551, 0.3928684732219464, 0.9382405255374198], 
             UndirectedEdge[139, 306] -> 
             RGBColor[
              0.2646217542710957, 0.39546462010015837`, 0.9383811894817108], 
             UndirectedEdge[1, 73] -> 
             RGBColor[
              0.19016251964762415`, 0.3172032435227433, 0.9341408462224705], 
             UndirectedEdge[7, 13] -> 
             RGBColor[
              0.23415570368153021`, 0.3634428692713504, 0.9366461929711178], 
             UndirectedEdge[170, 335] -> 
             RGBColor[
              0.21688414248716403`, 0.34528936337584293`, 0.9356626031120838],
              UndirectedEdge[276, 361] -> 
             RGBColor[
              0.3943096577609078, 0.5159529397980152, 0.9463460406115533], 
             UndirectedEdge[46, 345] -> 
             RGBColor[
              0.8168101022247779, 0.8568829940339906, 0.982358282576511], 
             UndirectedEdge[36, 301] -> 
             RGBColor[
              0.2477609938146631, 0.37774289182649035`, 0.9374209941169768], 
             UndirectedEdge[50, 328] -> 
             RGBColor[
              0.23123968531368772`, 0.36037794908050486`, 0.9364801300389318],
              UndirectedEdge[55, 83] -> 
             RGBColor[
              0.8773611303882973, 0.9047851000408222, 0.9744632955960668], 
             UndirectedEdge[143, 306] -> 
             RGBColor[
              0.21060170684620283`, 0.33868612518776664`, 0.9353048276963617],
              UndirectedEdge[32, 400] -> 
             RGBColor[
              0.8218170423470171, 0.16870092453389818`, 0.1685253304313158], 
             UndirectedEdge[20, 195] -> 
             RGBColor[
              0.40462199010322386`, 0.5248849637600351, 0.9470031333095683], 
             UndirectedEdge[203, 266] -> 
             RGBColor[
              0.4841156347335931, 0.5879317505125805, 0.9537717798510146], 
             UndirectedEdge[255, 359] -> 
             RGBColor[
              0.3499392226187198, 0.4775214990007658, 0.9435187957195283], 
             UndirectedEdge[128, 215] -> 
             RGBColor[
              0.5049864538136, 0.6035289290681363, 0.9559781758101122], 
             UndirectedEdge[230, 328] -> 
             RGBColor[
              0.2262385122205931, 0.35512139906697393`, 0.9361953206298528], 
             UndirectedEdge[44, 146] -> 
             RGBColor[
              0.21372136571514777`, 0.3419650844568244, 0.9354824876538264], 
             UndirectedEdge[56, 206] -> 
             RGBColor[
              0.4736432444349138, 0.5829006282242136, 0.9518893552229266], 
             UndirectedEdge[55, 196] -> 
             RGBColor[
              0.8239309669516679, 0.8625755200904117, 0.9830336180607375], 
             UndirectedEdge[93, 188] -> 
             RGBColor[
              0.3091689920495968, 0.43916314420292457`, 0.9410324534762535], 
             UndirectedEdge[52, 271] -> 
             RGBColor[
              0.9044987065001195, 0.5722362617047718, 0.4994192280879955], 
             UndirectedEdge[193, 253] -> 
             RGBColor[
              0.8315602657829888, 0.5341252723143658, 0.5780805506738103], 
             UndirectedEdge[120, 193] -> 
             RGBColor[
              0.6252379224927019, 0.7026774950776031, 0.9659558403883122], 
             UndirectedEdge[28, 217] -> 
             RGBColor[
              0.19992147826691017`, 0.32746052778532697`, 0.9346966044787532],
              UndirectedEdge[124, 245] -> 
             RGBColor[
              0.21075638483913717`, 0.33884870156549185`, 0.9353136363792337],
              UndirectedEdge[36, 282] -> 
             RGBColor[
              0.28033871258182136`, 0.4114037381706667, 0.9392974983530744], 
             UndirectedEdge[276, 339] -> 
             RGBColor[
              0.38050139833268903`, 0.5039929195045905, 0.9454661905309516], 
             UndirectedEdge[377, 388] -> 
             RGBColor[
              0.26273780008050557`, 0.39348446479625343`, 0.9382739010776171],
              UndirectedEdge[129, 131] -> 
             RGBColor[
              0.8167235345760251, 0.5021703426652091, 0.5741281307411844], 
             UndirectedEdge[69, 142] -> 
             RGBColor[
              0.5234887787089056, 0.6240307993134462, 0.955630100743997], 
             UndirectedEdge[11, 118] -> 
             RGBColor[
              0.6153201099210919, 0.6928744863891039, 0.9658821576068201], 
             UndirectedEdge[53, 293] -> 
             RGBColor[
              0.35836727987096656`, 0.4848214585861875, 0.944055824075003], 
             UndirectedEdge[2, 137] -> 
             RGBColor[
              0.24723503321608348`, 0.3771900738895551, 0.9373910414389766], 
             UndirectedEdge[102, 213] -> 
             RGBColor[
              0.33722405994131943`, 0.4665082641722599, 0.9427085967973012], 
             UndirectedEdge[269, 362] -> 
             RGBColor[
              0.5723371220999356, 0.658694027276514, 0.9617848366135348], 
             UndirectedEdge[147, 242] -> 
             RGBColor[
              0.29380682218946674`, 0.42321348171513995`, 0.9401503892495575],
              UndirectedEdge[58, 220] -> 
             RGBColor[
              0.186453938859043, 0.31330528997634166`, 0.9339296480329143], 
             UndirectedEdge[177, 285] -> 
             RGBColor[
              0.18283630546897034`, 0.3095029279121705, 0.9337236291631588], 
             UndirectedEdge[213, 215] -> 
             RGBColor[
              0.5157421665105038, 0.6132928535993672, 0.9566471217151071], 
             UndirectedEdge[61, 382] -> 
             RGBColor[
              0.2696810924925139, 0.39954800963710424`, 0.9387145049212492], 
             UndirectedEdge[83, 123] -> 
             RGBColor[
              0.8970713714097568, 0.6478503290469954, 0.5784075917525047], 
             UndirectedEdge[207, 368] -> 
             RGBColor[
              0.18767517326657374`, 0.3145888847693901, 0.9339991955257688], 
             UndirectedEdge[117, 377] -> 
             RGBColor[
              0.40661285819624315`, 0.5187550912923315, 0.9481023126401036], 
             UndirectedEdge[207, 392] -> 
             RGBColor[
              0.1972896880999786, 0.3246943494547476, 0.9345467279221311], 
             UndirectedEdge[43, 325] -> 
             RGBColor[
              0.21648460691960775`, 0.3448694261623232, 0.9356398501525713], 
             UndirectedEdge[83, 196] -> 
             RGBColor[
              0.8975547667711833, 0.9207556417701627, 0.9764242298319501], 
             UndirectedEdge[81, 130] -> 
             RGBColor[
              0.2224096961469096, 0.35109707061257234`, 0.9359772752186821], 
             UndirectedEdge[204, 229] -> 
             RGBColor[
              0.18893129430891603`, 0.3159091476275659, 0.9340707297608657], 
             UndirectedEdge[44, 267] -> 
             RGBColor[
              0.21293872940986303`, 0.3411424840779623, 0.935437917674047], 
             UndirectedEdge[38, 130] -> 
             RGBColor[
              0.23719458554175432`, 0.36663692678268434`, 0.9368192527974348],
              UndirectedEdge[226, 318] -> 
             RGBColor[
              0.20268055409019498`, 0.33036049141111024`, 0.9348537297652024],
              UndirectedEdge[202, 362] -> 
             RGBColor[
              0.5594312028417849, 0.6475155686854668, 0.9609624828506617], 
             UndirectedEdge[59, 230] -> 
             RGBColor[
              0.21869887314196257`, 0.34719676035460534`, 0.9357659493382211],
              UndirectedEdge[131, 394] -> 
             RGBColor[
              0.585868010689025, 0.6694437636125451, 0.9630575794667262], 
             UndirectedEdge[93, 142] -> 
             RGBColor[
              0.4083441914838143, 0.5275430486662767, 0.9473966682274677], 
             UndirectedEdge[301, 340] -> 
             RGBColor[
              0.26063005246171667`, 0.3912690884099886, 0.9381538679688604], 
             UndirectedEdge[16, 76] -> 
             RGBColor[
              0.2559443426940643, 0.3863441103530275, 0.937887023729479], 
             UndirectedEdge[25, 239] -> 
             RGBColor[
              0.43554957397249955`, 0.5502115619480115, 0.9493775788120367], 
             UndirectedEdge[46, 60] -> 
             RGBColor[
              0.7562801355297237, 0.809531056908518, 0.9763425941360632], 
             UndirectedEdge[57, 297] -> 
             RGBColor[
              0.3224295006293375, 0.45256728530617585`, 0.9418071536579791], 
             UndirectedEdge[221, 351] -> 
             RGBColor[
              0.33973329445254913`, 0.4686816369880935, 0.9428684830015278], 
             UndirectedEdge[365, 377] -> 
             RGBColor[
              0.2803555468892034, 0.41200183372185906`, 0.9392772056952516], 
             UndirectedEdge[334, 366] -> 
             RGBColor[
              0.9767558229939741, 0.9327621554008622, 0.40603042724612426`], 
             UndirectedEdge[209, 290] -> 
             RGBColor[
              0.2612876379800373, 0.3919602524830736, 0.938191316491318], 
             UndirectedEdge[174, 313] -> 
             RGBColor[
              0.35122662219084355`, 0.47640574207717373`, 0.9436825095790529],
              UndirectedEdge[56, 358] -> 
             RGBColor[
              0.3979975915234898, 0.5145002367878451, 0.9471747294166126], 
             UndirectedEdge[304, 338] -> 
             RGBColor[
              0.24620331291395298`, 0.37610567043717064`, 0.9373322864940637],
              UndirectedEdge[130, 306] -> 
             RGBColor[
              0.21898168415614172`, 0.3474940126617616, 0.9357820550070972], 
             UndirectedEdge[11, 206] -> 
             RGBColor[
              0.6510406164097462, 0.7238137937447175, 0.9681582366938735], 
             UndirectedEdge[120, 140] -> 
             RGBColor[
              0.409447183861318, 0.5290643040720063, 0.9473105903890827], 
             UndirectedEdge[193, 356] -> 
             RGBColor[
              0.8916558476180196, 0.9161964476590825, 0.9808695463369558], 
             UndirectedEdge[166, 246] -> 
             RGBColor[
              0.23093801406837325`, 0.3600608734746177, 0.9364629503077938], 
             UndirectedEdge[76, 182] -> 
             RGBColor[
              0.2623813144884871, 0.39310977583655005`, 0.9382535997505249], 
             UndirectedEdge[6, 364] -> 
             RGBColor[
              0.9237508221541206, 0.8349006337052781, 0.6241923325830713], 
             UndirectedEdge[288, 318] -> 
             RGBColor[
              0.21359522081764215`, 0.3418324981714975, 0.9354753038885282], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.285788273116509, 0.4171315718147177, 0.9396078427636225], 
             UndirectedEdge[128, 151] -> 
             RGBColor[
              0.2557571228947407, 0.38614733047351757`, 0.9378763618388744], 
             UndirectedEdge[30, 379] -> 
             RGBColor[
              0.19158357625518677`, 0.31869686411748455`, 0.9342217732940062],
              UndirectedEdge[70, 90] -> 
             RGBColor[
              0.2062666965089075, 0.33412975446773896`, 0.9350579552707259], 
             UndirectedEdge[137, 394] -> 
             RGBColor[
              0.32513488620910913`, 0.45454855045423936`, 0.9419927931696428],
              UndirectedEdge[25, 269] -> 
             RGBColor[
              0.35868258725721747`, 0.48509456199634804`, 0.9440759151828396],
              UndirectedEdge[38, 227] -> 
             RGBColor[
              0.2663587998591236, 0.39729036514822713`, 0.9384801116582203], 
             UndirectedEdge[128, 135] -> 
             RGBColor[
              0.31962859399375376`, 0.45082008915129973`, 0.9416038278633306],
              UndirectedEdge[129, 303] -> 
             RGBColor[
              0.8566331099862248, 0.3804373908932912, 0.19967730788162147`], 
             UndirectedEdge[132, 299] -> 
             RGBColor[
              0.19063186344337624`, 0.3176965536101942, 0.9341675746573066], 
             UndirectedEdge[352, 396] -> 
             RGBColor[
              0.18539177638104404`, 0.312188889866974, 0.9338691594511209], 
             UndirectedEdge[155, 268] -> 
             RGBColor[
              0.18677990471826675`, 0.31364790076181503`, 0.9339482113063738],
              UndirectedEdge[8, 16] -> 
             RGBColor[
              0.24227617377409713`, 0.3719779982061794, 0.9371086417297306], 
             UndirectedEdge[213, 378] -> 
             RGBColor[
              0.2828251978811075, 0.4130565820344796, 0.9394742726442766], 
             UndirectedEdge[164, 230] -> 
             RGBColor[
              0.21805906979477002`, 0.3465242864708308, 0.9357295134841028], 
             UndirectedEdge[218, 339] -> 
             RGBColor[
              0.47111694262023773`, 0.5795753796238241, 0.9520425636736524], 
             UndirectedEdge[101, 366] -> 
             RGBColor[
              0.9236369022984421, 0.7019746342428002, 0.3557247602566589], 
             UndirectedEdge[169, 361] -> 
             RGBColor[
              0.4334163894448813, 0.5497182254001022, 0.948867451343103], 
             UndirectedEdge[65, 341] -> 
             RGBColor[
              0.31291881126268356`, 0.4399641129231123, 0.9413609829619669], 
             UndirectedEdge[46, 353] -> 
             RGBColor[
              0.8993981375114619, 0.9180011012561393, 0.7445005138120175], 
             UndirectedEdge[279, 300] -> 
             RGBColor[
              0.1975989582339537, 0.32501941197441453`, 0.9345643403987369], 
             UndirectedEdge[203, 358] -> 
             RGBColor[
              0.29380332632948314`, 0.42601947816165614`, 0.9400473143533797],
              UndirectedEdge[81, 243] -> 
             RGBColor[
              0.2302749655066254, 0.3593639673965138, 0.9364251906730947], 
             UndirectedEdge[176, 320] -> 
             RGBColor[
              0.18495626411433608`, 0.3117311388615913, 0.9338443576718145], 
             UndirectedEdge[112, 248] -> 
             RGBColor[
              0.18167669359362687`, 0.3082841023075451, 0.9336575909823499], 
             UndirectedEdge[58, 179] -> 
             RGBColor[
              0.21000836012355356`, 0.3380624801619072, 0.9352710374782847], 
             UndirectedEdge[23, 213] -> 
             RGBColor[
              0.2686665233533321, 0.39817491739397315`, 0.9386679570758016], 
             UndirectedEdge[243, 326] -> 
             RGBColor[
              0.23648276332684243`, 0.36588875650267677`, 0.9367787155753422],
              UndirectedEdge[269, 377] -> 
             RGBColor[
              0.30404872534557215`, 0.4327759904647185, 0.9407776755353809], 
             UndirectedEdge[222, 363] -> 
             RGBColor[
              0.6628066494410058, 0.7309294373629389, 0.9563828644799877], 
             UndirectedEdge[30, 341] -> 
             RGBColor[
              0.22502124710185, 0.35384197624810876`, 0.9361259991821227], 
             UndirectedEdge[23, 348] -> 
             RGBColor[
              0.20651189165865158`, 0.3343874701163905, 0.93507191877177], 
             UndirectedEdge[16, 25] -> 
             RGBColor[
              0.2964577597678131, 0.4238211990721158, 0.9403811249327455], 
             UndirectedEdge[25, 62] -> 
             RGBColor[
              0.6778828449272916, 0.740272939600058, 0.8649535953688089], 
             UndirectedEdge[16, 388] -> 
             RGBColor[
              0.24986758553696356`, 0.3799570532922577, 0.9375409613991386], 
             UndirectedEdge[207, 372] -> 
             RGBColor[
              0.18573202091371066`, 0.31254650844355597`, 0.9338885358739095],
              UndirectedEdge[249, 279] -> 
             RGBColor[
              0.19132944320701362`, 0.3184297541708887, 0.934207300792869], 
             UndirectedEdge[151, 267] -> 
             RGBColor[
              0.20258817055551906`, 0.33026339045871145`, 0.9348484686595718],
              UndirectedEdge[185, 252] -> 
             RGBColor[
              0.1992454681560438, 0.3267499982972898, 0.9346581067030068], 
             UndirectedEdge[218, 382] -> 
             RGBColor[
              0.44118615700326724`, 0.5536508374874307, 0.9501354004808935], 
             UndirectedEdge[284, 334] -> 
             RGBColor[
              0.8500382234662116, 0.8370769008965131, 0.6373182165494112], 
             UndirectedEdge[145, 235] -> 
             RGBColor[
              0.22156110310920424`, 0.35020514552603776`, 0.9359289491005658],
              UndirectedEdge[78, 302] -> 
             RGBColor[
              0.2075835767828424, 0.33551387913067643`, 0.9351329496541767], 
             UndirectedEdge[235, 335] -> 
             RGBColor[
              0.19575670920923333`, 0.32308309144409886`, 0.9344594270421422],
              UndirectedEdge[21, 109] -> 
             RGBColor[
              0.1897091064701492, 0.31672667752516137`, 0.9341150250127779], 
             UndirectedEdge[283, 389] -> 
             RGBColor[
              0.9625229099161214, 0.8777511540326326, 0.378485405341739], 
             UndirectedEdge[91, 395] -> 
             RGBColor[
              0.5156283955691132, 0.6172519539462964, 0.9551211142984581], 
             UndirectedEdge[240, 374] -> 
             RGBColor[
              0.18148468566837106`, 0.3080822898040957, 0.933646656415057], 
             UndirectedEdge[301, 339] -> 
             RGBColor[
              0.3159128215006708, 0.4426058768171399, 0.9415499827250514], 
             UndirectedEdge[303, 353] -> 
             RGBColor[
              0.9435949291122223, 0.7996173553563373, 0.3704770005960165], 
             UndirectedEdge[92, 143] -> 
             RGBColor[
              0.20163694443753327`, 0.3292635914974891, 0.9347942977393655], 
             UndirectedEdge[53, 394] -> 
             RGBColor[
              0.38011496144870427`, 0.5036582072985654, 0.9454415671144167], 
             UndirectedEdge[139, 345] -> 
             RGBColor[
              0.5675136417908162, 0.652851509744995, 0.962127956401694], 
             UndirectedEdge[224, 393] -> 
             RGBColor[
              0.6098596540697332, 0.6929310009621534, 0.9632633563282622], 
             UndirectedEdge[175, 204] -> 
             RGBColor[
              0.1850387535749342, 0.31181784051481387`, 0.9338490553245634], 
             UndirectedEdge[131, 293] -> 
             RGBColor[
              0.5641203291112874, 0.6506070149001673, 0.9616718364273125], 
             UndirectedEdge[166, 383] -> 
             RGBColor[
              0.3017459947622442, 0.42990132159861427`, 0.9406631745250644], 
             UndirectedEdge[92, 348] -> 
             RGBColor[
              0.2027372639690243, 0.3304200970893739, 0.9348569593089071], 
             UndirectedEdge[212, 289] -> 
             RGBColor[
              0.5259969557430033, 0.6260670504218144, 0.9558275536278764], 
             UndirectedEdge[161, 214] -> 
             RGBColor[
              0.8792338615689066, 0.5445109956801907, 0.22094211265521246`], 
             UndirectedEdge[124, 386] -> 
             RGBColor[
              0.28427277786616933`, 0.41305129154365816`, 0.9396126134014054],
              UndirectedEdge[227, 350] -> 
             RGBColor[
              0.3112685553301875, 0.44081365131394507`, 0.9411723881594869], 
             UndirectedEdge[258, 279] -> 
             RGBColor[
              0.2183447678357952, 0.34682457322625027`, 0.9357457835648868], 
             UndirectedEdge[63, 103] -> 
             RGBColor[
              0.19205709543901506`, 0.31919456280253833`, 0.9342487395110164],
              UndirectedEdge[291, 336] -> 
             RGBColor[
              0.21513079622652476`, 0.34344648528733734`, 0.9355627526363838],
              UndirectedEdge[292, 400] -> 
             RGBColor[
              0.8208035514548493, 0.16091078942215484`, 0.1675548104084016], 
             UndirectedEdge[149, 300] -> 
             RGBColor[
              0.20324360298345337`, 0.33095229149728655`, 0.9348857945667173],
              UndirectedEdge[356, 364] -> 
             RGBColor[
              0.9333609520587287, 0.8423137522801358, 0.6164503768813724], 
             UndirectedEdge[100, 167] -> 
             RGBColor[
              0.3117593370391954, 0.4377082442608893, 0.941332929144121], 
             UndirectedEdge[334, 391] -> 
             RGBColor[
              0.890222900366215, 0.5169905447403047, 0.23346978586604977`], 
             UndirectedEdge[309, 323] -> 
             RGBColor[
              0.5589942800594222, 0.6511253403818711, 0.9592466420721857], 
             UndirectedEdge[8, 202] -> 
             RGBColor[
              0.2915950820053508, 0.42207290253936436`, 0.9399810782169516], 
             UndirectedEdge[127, 380] -> 
             RGBColor[
              0.529875465248763, 0.6249265943110206, 0.9578049379836415], 
             UndirectedEdge[130, 151] -> 
             RGBColor[
              0.211637861675412, 0.3397751896092761, 0.9353638351810314], 
             UndirectedEdge[335, 355] -> 
             RGBColor[
              0.20320238953001776`, 0.3309089735446419, 0.934883447521514], 
             UndirectedEdge[117, 395] -> 
             RGBColor[
              0.49860624010091514`, 0.6034326012978481, 0.9537810678657916], 
             UndirectedEdge[256, 310] -> 
             RGBColor[
              0.9094103197175858, 0.5979549815728277, 0.4751163468578484], 
             UndirectedEdge[362, 365] -> 
             RGBColor[
              0.5486439436435668, 0.6379198705336546, 0.9602843667734056], 
             UndirectedEdge[163, 342] -> 
             RGBColor[
              0.18272416673891645`, 0.30938506299687774`, 0.9337172430283764],
              UndirectedEdge[125, 288] -> 
             RGBColor[
              0.2031660717843796, 0.3308708012912981, 0.9348813792796271], 
             UndirectedEdge[161, 253] -> 
             RGBColor[
              0.8523693689594214, 0.3702876353014115, 0.19648021346556857`], 
             UndirectedEdge[12, 211] -> 
             RGBColor[
              0.23763726784270695`, 0.3671022139486645, 0.9368444628995842], 
             UndirectedEdge[107, 152] -> 
             RGBColor[
              0.2119625047523057, 0.3401164100666513, 0.9353823231239942], 
             UndirectedEdge[183, 291] -> 
             RGBColor[
              0.1920722404266596, 0.31921048114480044`, 0.9342496019956579], 
             UndirectedEdge[149, 299] -> 
             RGBColor[
              0.19935795159879743`, 0.32686822552748607`, 0.9346645124686672],
              UndirectedEdge[57, 284] -> 
             RGBColor[
              0.544081909913294, 0.6364040523835073, 0.9590603762420349], 
             UndirectedEdge[230, 279] -> 
             RGBColor[
              0.2100811442778375, 0.33813898092284156`, 0.9352751824281966], 
             UndirectedEdge[186, 374] -> 
             RGBColor[
              0.19510883243877694`, 0.3224021318805894, 0.9344225314185126], 
             UndirectedEdge[30, 175] -> 
             RGBColor[
              0.19541782934736363`, 0.32272690722304953`, 0.9344401283353366],
              UndirectedEdge[261, 327] -> 
             RGBColor[
              0.1874834373807122, 0.31438735819659225`, 0.9339882764507168], 
             UndirectedEdge[271, 333] -> 
             RGBColor[
              0.8868896427416582, 0.5599013471362418, 0.5649582086174862], 
             UndirectedEdge[199, 247] -> 
             RGBColor[
              0.9030372486329088, 0.5619443631205439, 0.500289085988991], 
             UndirectedEdge[99, 223] -> 
             RGBColor[
              0.8806912086429535, 0.689221405037725, 0.5973847957056915], 
             UndirectedEdge[200, 367] -> 
             RGBColor[
              0.19007010120853718`, 0.31710610588359545`, 0.9341355831290852],
              UndirectedEdge[111, 400] -> 
             RGBColor[
              0.8243636514645629, 0.1882752781425862, 0.17096396619826132`], 
             UndirectedEdge[277, 390] -> 
             RGBColor[
              0.19904871949657826`, 0.326543202981606, 0.9346469021579138], 
             UndirectedEdge[79, 298] -> 
             RGBColor[
              0.20225845525357178`, 0.3299168387712073, 0.934829691860896], 
             UndirectedEdge[96, 388] -> 
             RGBColor[
              0.24120538255957147`, 0.37085252874762864`, 0.937047661754157], 
             UndirectedEdge[153, 175] -> 
             RGBColor[
              0.19789401206423968`, 0.32532953225753836`, 0.9345811432778787],
              UndirectedEdge[127, 331] -> 
             RGBColor[
              0.29016880316487315`, 0.419484905671203, 0.9399397232478413], 
             UndirectedEdge[6, 93] -> 
             RGBColor[
              0.6343460318717724, 0.7075322117954237, 0.9679330421391619], 
             UndirectedEdge[76, 239] -> 
             RGBColor[
              0.3950361568987507, 0.5127344732289232, 0.94688347760877], 
             UndirectedEdge[333, 337] -> 
             RGBColor[
              0.9553778772118539, 0.9662414744033965, 0.9604177939535141], 
             UndirectedEdge[253, 332] -> 
             RGBColor[
              0.8214986576269006, 0.1662536800580077, 0.16822044486376803`], 
             UndirectedEdge[31, 400] -> 
             RGBColor[
              0.9031868035222537, 0.5793756445438494, 0.5396768154569369], 
             UndirectedEdge[39, 149] -> 
             RGBColor[
              0.2042501787734501, 0.33201026647316434`, 0.9349431175688622], 
             UndirectedEdge[49, 335] -> 
             RGBColor[
              0.1909811618412971, 0.3180636883732066, 0.9341874666843275], 
             UndirectedEdge[57, 236] -> 
             RGBColor[
              0.4289674540866987, 0.5444426167036535, 0.9489769174045849], 
             UndirectedEdge[76, 323] -> 
             RGBColor[
              0.3517784337991403, 0.4767281281704481, 0.9437233665376588], 
             UndirectedEdge[2, 210] -> 
             RGBColor[
              0.223753059772891, 0.352509030957652, 0.9360537777898534], 
             UndirectedEdge[25, 395] -> 
             RGBColor[
              0.4013213562160271, 0.522026120581628, 0.946792819836912], 
             UndirectedEdge[62, 91] -> 
             RGBColor[
              0.7921898842803778, 0.8354987729647263, 0.873281889830355], 
             UndirectedEdge[148, 313] -> 
             RGBColor[
              0.27058528986872044`, 0.4017326741232574, 0.9387208040117352], 
             UndirectedEdge[98, 163] -> 
             RGBColor[
              0.18615149755953203`, 0.3129874049946697, 0.933912424448329], 
             UndirectedEdge[271, 292] -> 
             RGBColor[
              0.8197473186965691, 0.15279212159786854`, 0.16654336072622833`],
              UndirectedEdge[148, 228] -> 
             RGBColor[
              0.2402804897849437, 0.36988040779990605`, 0.9369949904788982], 
             UndirectedEdge[105, 333] -> 
             RGBColor[
              0.969539411680839, 0.9766186640035739, 0.9281855313871071], 
             UndirectedEdge[9, 65] -> 
             RGBColor[
              0.531426491162083, 0.6277150215031269, 0.9572921727453987], 
             UndirectedEdge[129, 337] -> 
             RGBColor[
              0.8881576917970897, 0.5585337722586294, 0.5619283859267235], 
             UndirectedEdge[62, 323] -> 
             RGBColor[
              0.7062128595771804, 0.7648109743818534, 0.8667587588510515], 
             UndirectedEdge[286, 290] -> 
             RGBColor[
              0.28938656912218486`, 0.4203385400712017, 0.9398338164907357], 
             UndirectedEdge[96, 261] -> 
             RGBColor[
              0.20041641876701294`, 0.3279807416319751, 0.9347247906080353], 
             UndirectedEdge[48, 86] -> 
             RGBColor[
              0.23801910122574216`, 0.3675035450438693, 0.9368662077458763], 
             UndirectedEdge[137, 328] -> 
             RGBColor[
              0.2619981545019592, 0.39270705039696285`, 0.9382317793561266], 
             UndirectedEdge[110, 212] -> 
             RGBColor[
              0.715371093239261, 0.7768498811487758, 0.9728708007300837], 
             UndirectedEdge[163, 272] -> 
             RGBColor[
              0.18785278804211375`, 0.3147755691599099, 0.9340093104244782], 
             UndirectedEdge[245, 396] -> 
             RGBColor[
              0.1896460602736138, 0.31666041197524286`, 0.9341114346251538], 
             UndirectedEdge[25, 37] -> 
             RGBColor[
              0.3241466699483991, 0.4529239992502145, 0.9419579674054581], 
             UndirectedEdge[79, 373] -> 
             RGBColor[
              0.19851817498261992`, 0.32598556705897075`, 0.9346166884327141],
              UndirectedEdge[34, 43] -> 
             RGBColor[
              0.18881744465394812`, 0.3157894844217095, 0.9340642461914408], 
             UndirectedEdge[100, 358] -> 
             RGBColor[
              0.33265464447686266`, 0.4596705372168882, 0.942522885990859], 
             UndirectedEdge[273, 394] -> 
             RGBColor[
              0.4408354922328445, 0.55433085165707, 0.9498412454842259], 
             UndirectedEdge[89, 189] -> 
             RGBColor[
              0.23269978806740765`, 0.361912609650526, 0.9365632807307278], 
             UndirectedEdge[268, 299] -> 
             RGBColor[
              0.18802492021905656`, 0.3149564909916871, 0.9340191130973085], 
             UndirectedEdge[143, 272] -> 
             RGBColor[
              0.19777740595295248`, 0.3252069718413211, 0.9345745027323441], 
             UndirectedEdge[339, 382] -> 
             RGBColor[
              0.3520267531654626, 0.47932961303801835`, 0.943651811320036], 
             UndirectedEdge[111, 223] -> 
             RGBColor[
              0.8429142052274374, 0.3295868808857362, 0.18867802924559862`], 
             UndirectedEdge[71, 131] -> 
             RGBColor[
              0.8919073913712897, 0.9158173378862382, 0.9591371203789343], 
             UndirectedEdge[114, 370] -> 
             RGBColor[
              0.18611224246754757`, 0.3129461454040774, 0.9339101889289132], 
             UndirectedEdge[4, 125] -> 
             RGBColor[
              0.196721601742191, 0.3240972546739574, 0.9345143762444637], 
             UndirectedEdge[246, 251] -> 
             RGBColor[
              0.20081373075853814`, 0.3283983417261034, 0.9347474169381822], 
             UndirectedEdge[30, 229] -> 
             RGBColor[
              0.19931037008134544`, 0.32681821433580155`, 0.9346618027716389],
              UndirectedEdge[115, 366] -> 
             RGBColor[
              0.9742039651565302, 0.9239012646538212, 0.3974339190185809], 
             UndirectedEdge[89, 270] -> 
             RGBColor[
              0.22008543635339983`, 0.34865412620301106`, 0.935844912061876], 
             UndirectedEdge[197, 369] -> 
             RGBColor[
              0.18585850163943218`, 0.31267944770563044`, 0.933895738764128], 
             UndirectedEdge[276, 301] -> 
             RGBColor[
              0.3144566810509267, 0.44134464114731864`, 0.9414571987432081], 
             UndirectedEdge[69, 188] -> 
             RGBColor[
              0.42431357927468827`, 0.535650894850094, 0.9492658859927827], 
             UndirectedEdge[191, 225] -> 
             RGBColor[
              0.19624559498378968`, 0.32359694139030604`, 0.9344872683637615],
              UndirectedEdge[223, 247] -> 
             RGBColor[
              0.8382775353615486, 0.29394740449482404`, 0.18423794894565387`],
              UndirectedEdge[72, 86] -> 
             RGBColor[
              0.3668179912534385, 0.4880512045533021, 0.9448235654131886], 
             UndirectedEdge[19, 85] -> 
             RGBColor[
              0.19070082938217475`, 0.3177690411845645, 0.9341715021654952], 
             UndirectedEdge[320, 398] -> 
             RGBColor[
              0.182257588923795, 0.30889466013044303`, 0.9336906721120455], 
             UndirectedEdge[249, 300] -> 
             RGBColor[
              0.18989148665345995`, 0.3169183706613924, 0.9341254112944102], 
             UndirectedEdge[18, 319] -> 
             RGBColor[
              0.9124901172546147, 0.6184152946465793, 0.3038268692248966], 
             UndirectedEdge[6, 273] -> 
             RGBColor[
              0.7251045855702409, 0.7842222818473898, 0.9742467167674911], 
             UndirectedEdge[158, 348] -> 
             RGBColor[
              0.1961222229924388, 0.3234672696051602, 0.9344802425113666], 
             UndirectedEdge[61, 228] -> 
             RGBColor[
              0.220637096263315, 0.34923395574559046`, 0.935876328277638], 
             UndirectedEdge[70, 260] -> 
             RGBColor[
              0.19294770058427305`, 0.3201306452778321, 0.9342994581565066], 
             UndirectedEdge[144, 305] -> 
             RGBColor[
              0.4396583364184836, 0.550769790541102, 0.9502316306235659], 
             UndirectedEdge[165, 351] -> 
             RGBColor[
              0.26754769340127105`, 0.39846518644420825`, 0.9385505554925828],
              UndirectedEdge[132, 370] -> 
             RGBColor[
              0.189210358194615, 0.3162024614651078, 0.9340866220363182], 
             UndirectedEdge[104, 145] -> 
             RGBColor[
              0.2369611402467977, 0.36639156097639836`, 0.9368059584332384], 
             UndirectedEdge[207, 231] -> 
             RGBColor[
              0.1913619669815575, 0.3184639387200607, 0.9342091529737147], 
             UndirectedEdge[21, 249] -> 
             RGBColor[
              0.19014493822452405`, 0.31718476433233855`, 0.9341398449864342],
              UndirectedEdge[7, 93] -> 
             RGBColor[
              0.29873862778538124`, 0.4282001700379434, 0.9404384596617476], 
             UndirectedEdge[140, 255] -> 
             RGBColor[
              0.390267723092427, 0.5124520191417203, 0.9460884921086202], 
             UndirectedEdge[100, 157] -> 
             RGBColor[
              0.31728677632069113`, 0.4435179334056334, 0.9416477086340886], 
             UndirectedEdge[42, 178] -> 
             RGBColor[
              0.18344665505298052`, 0.31014444402336394`, 0.9337583876690367],
              UndirectedEdge[115, 195] -> 
             RGBColor[
              0.6898630728334411, 0.7009647207638414, 0.6155071113240207], 
             UndirectedEdge[281, 394] -> 
             RGBColor[
              0.3781881603711747, 0.5019893090490473, 0.9453187930535599], 
             UndirectedEdge[215, 224] -> 
             RGBColor[
              0.6019092601655756, 0.6867200928189938, 0.9624709353645509], 
             UndirectedEdge[99, 222] -> 
             RGBColor[
              0.9266267914902193, 0.9439342403679507, 0.9791054495248444], 
             UndirectedEdge[55, 284] -> 
             RGBColor[
              0.7718010949853338, 0.8216561483989014, 0.9778895783229857], 
             UndirectedEdge[32, 337] -> 
             RGBColor[
              0.8892490440589328, 0.5669223839767665, 0.5629734660851704], 
             UndirectedEdge[172, 399] -> 
             RGBColor[
              0.369499573099037, 0.49446369145501556`, 0.9447651639555954], 
             UndirectedEdge[267, 346] -> 
             RGBColor[
              0.20049511025135958`, 0.32806345137135173`, 0.9347292719716551],
              UndirectedEdge[222, 393] -> 
             RGBColor[
              0.8365296253571944, 0.8728854021704904, 0.9703016768071477], 
             UndirectedEdge[116, 179] -> 
             RGBColor[
              0.23341719737643146`, 0.3626666523206874, 0.9366041361295647], 
             UndirectedEdge[120, 360] -> 
             RGBColor[
              0.5376516098803733, 0.6341093662239545, 0.9572645433190765], 
             UndirectedEdge[144, 222] -> 
             RGBColor[
              0.7661723613566251, 0.8169857716290115, 0.9639290713689532], 
             UndirectedEdge[237, 307] -> 
             RGBColor[
              0.1806275543927051, 0.307181390488109, 0.9335978440569198], 
             UndirectedEdge[18, 144] -> 
             RGBColor[
              0.7868965412101618, 0.8286865484723305, 0.6945647496408425], 
             UndirectedEdge[309, 365] -> 
             RGBColor[
              0.5016918379873817, 0.6012405287458232, 0.9556046196739707], 
             UndirectedEdge[189, 241] -> 
             RGBColor[
              0.2570425573000169, 0.3874984035347115, 0.937949565426625], 
             UndirectedEdge[268, 370] -> 
             RGBColor[
              0.18660341497029534`, 0.3134623988466007, 0.9339381604763201], 
             UndirectedEdge[336, 359] -> 
             RGBColor[
              0.2802453493603669, 0.4103194523243253, 0.9393282894277089], 
             UndirectedEdge[115, 123] -> 
             RGBColor[
              0.8991328422336753, 0.5962300691178152, 0.23584910998017405`], 
             UndirectedEdge[6, 394] -> 
             RGBColor[
              0.6418942074247149, 0.7140700620770483, 0.9684140052108057], 
             UndirectedEdge[259, 353] -> 
             RGBColor[
              0.9443422105725244, 0.9537215111738743, 0.7488183078429457], 
             UndirectedEdge[98, 348] -> 
             RGBColor[
              0.19717643500186177`, 0.3245753132679656, 0.9345402783257364], 
             UndirectedEdge[145, 349] -> 
             RGBColor[
              0.2241439081408365, 0.35291983737358057`, 0.9360760360261996], 
             UndirectedEdge[287, 292] -> 
             RGBColor[
              0.8184054423003344, 0.14247787160242187`, 0.16525837837376128`],
              UndirectedEdge[53, 69] -> 
             RGBColor[
              0.4877113731208531, 0.5936081076641104, 0.9531940365593021], 
             UndirectedEdge[236, 284] -> 
             RGBColor[
              0.6247504035752902, 0.7047458827568778, 0.9646230139836673], 
             UndirectedEdge[119, 146] -> 
             RGBColor[
              0.2194595639056427, 0.3479962945778132, 0.9358092695518716], 
             UndirectedEdge[198, 310] -> 
             RGBColor[
              0.8276571285797327, 0.5355745817229594, 0.5782791813938954], 
             UndirectedEdge[198, 384] -> 
             RGBColor[
              0.8811911535814985, 0.820358675063078, 0.6244757857174054], 
             UndirectedEdge[111, 292] -> 
             RGBColor[
              0.8230519846103825, 0.1781932319252751, 0.16970791253738232`], 
             UndirectedEdge[40, 295] -> 
             RGBColor[
              0.1896748892459051, 0.31669071305298346`, 0.934113076392477], 
             UndirectedEdge[5, 270] -> 
             RGBColor[
              0.19738135324155764`, 0.32479069533045285`, 0.9345519481163376],
              UndirectedEdge[104, 355] -> 
             RGBColor[
              0.21609483282429037`, 0.34445974887503966`, 0.9356176530944622],
              UndirectedEdge[356, 360] -> 
             RGBColor[
              0.804069535005691, 0.8476283188054337, 0.97217824926772], 
             UndirectedEdge[42, 398] -> 
             RGBColor[
              0.18234639975021955`, 0.30898800593994685`, 0.9336957297572264],
              UndirectedEdge[153, 211] -> 
             RGBColor[
              0.21907020233692062`, 0.34758705088213704`, 0.9357870959865418],
              UndirectedEdge[223, 385] -> 
             RGBColor[
              0.9268169546976089, 0.7220420708837272, 0.4190027976388401], 
             UndirectedEdge[144, 361] -> 
             RGBColor[
              0.4954156444114053, 0.6000520136165334, 0.9537482598048219], 
             UndirectedEdge[216, 229] -> 
             RGBColor[
              0.2068690748506942, 0.33476289229794964`, 0.9350922598261517], 
             UndirectedEdge[161, 389] -> 
             RGBColor[
              0.9363348090239618, 0.7668148008617284, 0.3570460900069422], 
             UndirectedEdge[313, 340] -> 
             RGBColor[
              0.2780047879810863, 0.40953103706270466`, 0.9391433334530706], 
             UndirectedEdge[241, 380] -> 
             RGBColor[
              0.5006467932710101, 0.5970366894503322, 0.9560367412293518], 
             UndirectedEdge[258, 281] -> 
             RGBColor[
              0.318201913769557, 0.44345916858997797`, 0.9417371947060786], 
             UndirectedEdge[344, 346] -> 
             RGBColor[
              0.19749434605120672`, 0.3249094579375519, 0.9345583828896893], 
             UndirectedEdge[79, 205] -> 
             RGBColor[
              0.19210249208707042`, 0.3192422775579583, 0.9342513247829649], 
             UndirectedEdge[227, 306] -> 
             RGBColor[
              0.248145898473511, 0.3781474510273044, 0.9374429138678827], 
             UndirectedEdge[43, 381] -> 
             RGBColor[
              0.19202300109929993`, 0.3191587274897918, 0.9342467978888077], 
             UndirectedEdge[98, 143] -> 
             RGBColor[
              0.19607611547037074`, 0.3234188076760809, 0.9344776167561948], 
             UndirectedEdge[243, 267] -> 
             RGBColor[
              0.2144789920516021, 0.342761397772722, 0.9355256333528797], 
             UndirectedEdge[58, 152] -> 
             RGBColor[
              0.19702370192683044`, 0.32441478112227146`, 0.9345315804030616],
              UndirectedEdge[376, 397] -> 
             RGBColor[
              0.32517928194563106`, 0.4539892085157613, 0.9420175102408045], 
             UndirectedEdge[114, 279] -> 
             RGBColor[
              0.19285735565451845`, 0.32003568702846064`, 0.9342943131464105],
              UndirectedEdge[148, 218] -> 
             RGBColor[
              0.40841467546891774`, 0.5204402282772255, 0.9482239194761258], 
             UndirectedEdge[55, 366] -> 
             RGBColor[
              0.8985186945130963, 0.9173414029032505, 0.7466017890196988], 
             UndirectedEdge[99, 361] -> 
             RGBColor[
              0.6558700745449995, 0.7270004823554725, 0.968924637960713], 
             UndirectedEdge[97, 169] -> 
             RGBColor[
              0.37794173807367953`, 0.5007330923555633, 0.945366919038301], 
             UndirectedEdge[43, 250] -> 
             RGBColor[
              0.19420867686654147`, 0.32145601130101026`, 0.9343712688903346],
              UndirectedEdge[112, 177] -> 
             RGBColor[
              0.18091855533538903`, 0.3074872509293952, 0.9336144161301083], 
             UndirectedEdge[255, 356] -> 
             RGBColor[
              0.6597861746771188, 0.7286564919053182, 0.9611997608615672], 
             UndirectedEdge[210, 328] -> 
             RGBColor[
              0.2385161810587667, 0.36802600746505976`, 0.9368945157070033], 
             UndirectedEdge[91, 221] -> 
             RGBColor[
              0.48124384050183955`, 0.5874697805650118, 0.9529301608546397], 
             UndirectedEdge[32, 345] -> 
             RGBColor[
              0.824801297962475, 0.5160822589510907, 0.5758521781137924], 
             UndirectedEdge[210, 258] -> 
             RGBColor[
              0.24166666616429894`, 0.371337367063267, 0.9370739311730383], 
             UndirectedEdge[189, 359] -> 
             RGBColor[
              0.2794316818374808, 0.4094642361682714, 0.9392819522659938], 
             UndirectedEdge[164, 258] -> 
             RGBColor[
              0.22632269335272776`, 0.3552098787742395, 0.936200114620793], 
             UndirectedEdge[354, 374] -> 
             RGBColor[
              0.18986888322413037`, 0.3168946130240269, 0.9341241240625486], 
             UndirectedEdge[235, 322] -> 
             RGBColor[
              0.1941801601361397, 0.32142603840929285`, 0.934369644904725], 
             UndirectedEdge[147, 392] -> 
             RGBColor[
              0.2251386082236323, 0.35396533022822685`, 0.9361326827243879], 
             UndirectedEdge[123, 283] -> 
             RGBColor[
              0.8875401777067986, 0.5502690172951994, 0.2265213799870392], 
             UndirectedEdge[202, 239] -> 
             RGBColor[
              0.4173644057485659, 0.5344604832455712, 0.9482188359733204], 
             UndirectedEdge[180, 249] -> 
             RGBColor[
              0.18602314959306215`, 0.3128525031441788, 0.9339051152215123], 
             UndirectedEdge[2, 197] -> 
             RGBColor[
              0.1965684920257088, 0.3239363266542179, 0.9345056568726156], 
             UndirectedEdge[174, 329] -> 
             RGBColor[
              0.34008730347088106`, 0.4646976118288939, 0.9430481418570962], 
             UndirectedEdge[193, 242] -> 
             RGBColor[
              0.5891633460741419, 0.6714315101447773, 0.963657200278417], 
             UndirectedEdge[58, 160] -> 
             RGBColor[
              0.1942495004305084, 0.32149891945510295`, 0.9343735937319094], 
             UndirectedEdge[50, 137] -> 
             RGBColor[
              0.2618861891426283, 0.3925893677052923, 0.9382254030945505], 
             UndirectedEdge[326, 383] -> 
             RGBColor[
              0.2999445651565369, 0.428007904865782, 0.9405605857739958], 
             UndirectedEdge[157, 238] -> 
             RGBColor[
              0.22387178003127423`, 0.3526338134765119, 0.9360605387329375], 
             UndirectedEdge[243, 346] -> 
             RGBColor[
              0.21741007073096835`, 0.3458421473058579, 0.9356925539475274], 
             UndirectedEdge[235, 355] -> 
             RGBColor[
              0.2006947956866969, 0.3282733334246791, 0.9347406437617896], 
             UndirectedEdge[44, 135] -> 
             RGBColor[
              0.2818343394924019, 0.41109593137624006`, 0.9394515009810677], 
             UndirectedEdge[33, 206] -> 
             RGBColor[
              0.33773890435239673`, 0.4612073947457289, 0.942951820792434], 
             UndirectedEdge[88, 263] -> 
             RGBColor[
              0.3661139704738488, 0.49089201133024934`, 0.9445728421053426], 
             UndirectedEdge[82, 399] -> 
             RGBColor[
              0.5595672102027384, 0.6489717323660277, 0.9604046913379707], 
             UndirectedEdge[271, 287] -> 
             RGBColor[
              0.8186608763962349, 0.14444124999544666`, 0.16550298235246705`],
              UndirectedEdge[31, 223] -> 
             RGBColor[
              0.9217373572851282, 0.7206872472869994, 0.5573908785042743], 
             UndirectedEdge[108, 376] -> 
             RGBColor[
              0.29627129186653856`, 0.4287302908095537, 0.9401835838264763], 
             UndirectedEdge[301, 361] -> 
             RGBColor[
              0.3297210809288895, 0.45456589711056455`, 0.9424298328056531], 
             UndirectedEdge[80, 388] -> 
             RGBColor[
              0.23694403524812552`, 0.36637358253827423`, 0.9368049843288686],
              UndirectedEdge[47, 136] -> 
             RGBColor[
              0.18182023692588944`, 0.308434975450926, 0.9336657655627689], 
             UndirectedEdge[39, 50] -> 
             RGBColor[
              0.21465093660737516`, 0.342942122402754, 0.9355354253409618], 
             UndirectedEdge[120, 389] -> 
             RGBColor[
              0.7028354936755193, 0.7597247670512044, 0.7201987400202577], 
             UndirectedEdge[28, 106] -> 
             RGBColor[
              0.18905752987434937`, 0.31604182921063345`, 0.9340779186895682],
              UndirectedEdge[97, 326] -> 
             RGBColor[
              0.27009816450947055`, 0.40122067448515425`, 0.9386930629431633],
              UndirectedEdge[195, 242] -> 
             RGBColor[
              0.3825084156474021, 0.5057312970269716, 0.9455940758995094], 
             UndirectedEdge[90, 260] -> 
             RGBColor[
              0.20225002842194761`, 0.32990798163687834`, 0.9348292119653014],
              UndirectedEdge[73, 368] -> 
             RGBColor[
              0.19117243294824504`, 0.31826472643389747`, 0.934198359290908], 
             UndirectedEdge[52, 287] -> 
             RGBColor[
              0.9031568301038848, 0.5619220117093251, 0.49813424573552845`], 
             UndirectedEdge[135, 243] -> 
             RGBColor[
              0.2833746021341409, 0.41271484507099976`, 0.9395392166599004], 
             UndirectedEdge[311, 317] -> 
             RGBColor[
              0.19555015626042008`, 0.32286599119868276`, 0.934447664157275], 
             UndirectedEdge[6, 10] -> 
             RGBColor[
              0.8845651997050992, 0.6376155087725291, 0.5907990623624317], 
             UndirectedEdge[363, 383] -> 
             RGBColor[
              0.36642168177165046`, 0.49179777668654956`, 0.9445690434418867],
              UndirectedEdge[227, 346] -> 
             RGBColor[
              0.23870901568862182`, 0.3682286888874592, 0.9369054973539003], 
             UndirectedEdge[157, 341] -> 
             RGBColor[
              0.24810243304135554`, 0.37810176610224144`, 0.9374404385758228],
              UndirectedEdge[18, 310] -> 
             RGBColor[
              0.9095262697789932, 0.5956338641827077, 0.30098868553505453`], 
             UndirectedEdge[37, 96] -> 
             RGBColor[
              0.24798039051581972`, 0.3779734916699602, 0.9374334884345392], 
             UndirectedEdge[218, 222] -> 
             RGBColor[
              0.7556819189936763, 0.8084691579297268, 0.9631032253183853], 
             UndirectedEdge[65, 203] -> 
             RGBColor[
              0.34325183639463963`, 0.4717292211712722, 0.9430926813827534], 
             UndirectedEdge[105, 303] -> 
             RGBColor[
              0.9396161743909813, 0.7997165627600418, 0.5632237947654809], 
             UndirectedEdge[119, 267] -> 
             RGBColor[
              0.21867692760035795`, 0.34717369419895117`, 0.9357646995720923],
              UndirectedEdge[20, 312] -> 
             RGBColor[
              0.4662211223319299, 0.5756731791658605, 0.9516371294428863], 
             UndirectedEdge[285, 324] -> 
             RGBColor[
              0.1849819453905557, 0.31175813151118514`, 0.9338458201825032], 
             UndirectedEdge[16, 302] -> 
             RGBColor[
              0.21182755927874247`, 0.3399745738178992, 0.9353746381789088], 
             UndirectedEdge[65, 313] -> 
             RGBColor[
              0.33055584599709903`, 0.45850175468157234`, 0.9423653859984371],
              UndirectedEdge[280, 392] -> 
             RGBColor[
              0.20599555407739328`, 0.33384476658079454`, 0.9350425141103704],
              UndirectedEdge[1, 357] -> 
             RGBColor[
              0.18390843895748787`, 0.3106298081857918, 0.9337846855792504], 
             UndirectedEdge[26, 177] -> 
             RGBColor[
              0.18182665700375172`, 0.3084417233598157, 0.9336661311767056], 
             UndirectedEdge[69, 293] -> 
             RGBColor[
              0.44347384418172964`, 0.5552917835398956, 0.950375260333012], 
             UndirectedEdge[165, 399] -> 
             RGBColor[
              0.2924581876891166, 0.42004140455849254`, 0.9401378301611192], 
             UndirectedEdge[108, 297] -> 
             RGBColor[
              0.30146181771501923`, 0.43418586257465347`, 0.9404791765948524],
              UndirectedEdge[192, 335] -> 
             RGBColor[
              0.22826537319767345`, 0.3572517584642937, 0.9363107473640253], 
             UndirectedEdge[134, 272] -> 
             RGBColor[
              0.18788317693480855`, 0.3148075098128992, 0.9340110410269609], 
             UndirectedEdge[86, 236] -> 
             RGBColor[
              0.3888676051713017, 0.5059520744556105, 0.9465593917911999], 
             UndirectedEdge[312, 389] -> 
             RGBColor[
              0.7704699076494956, 0.8157404401627024, 0.7252172989695943], 
             UndirectedEdge[156, 245] -> 
             RGBColor[
              0.1983829021548571, 0.32584338674019936`, 0.9346089848452912], 
             UndirectedEdge[153, 168] -> 
             RGBColor[
              0.20180786245057253`, 0.3294432371660213, 0.9348040312673576], 
             UndirectedEdge[118, 150] -> 
             RGBColor[
              0.29792702653421543`, 0.4259677967148573, 0.9404427441608055], 
             UndirectedEdge[195, 255] -> 
             RGBColor[
              0.3994035312970712, 0.5203649970295117, 0.9466706177289421], 
             UndirectedEdge[109, 180] -> 
             RGBColor[
              0.18558731783868732`, 0.3123944163370016, 0.933880295247856], 
             UndirectedEdge[143, 378] -> 
             RGBColor[
              0.21957024665493602`, 0.3481126291650121, 0.9358155727707034], 
             UndirectedEdge[135, 383] -> 
             RGBColor[
              0.3468364039638354, 0.47483399343410504`, 0.9433210868585539], 
             UndirectedEdge[20, 120] -> 
             RGBColor[
              0.3985867083579536, 0.5196575060543626, 0.9466185704935497], 
             UndirectedEdge[149, 230] -> 
             RGBColor[
              0.21572578902733716`, 0.34407186044571364`, 0.935596636596177], 
             UndirectedEdge[16, 77] -> 
             RGBColor[
              0.21295289463759554`, 0.3411573726304365, 0.9354387243628108], 
             UndirectedEdge[168, 238] -> 
             RGBColor[
              0.19942328541058194`, 0.3269368955060745, 0.9346682331325956], 
             UndirectedEdge[104, 335] -> 
             RGBColor[
              0.21115674634682685`, 0.33926950689445945`, 0.9353364363748149],
              UndirectedEdge[79, 232] -> 
             RGBColor[
              0.19470557204870292`, 0.32197827964243614`, 0.9343995663358682],
              UndirectedEdge[47, 299] -> 
             RGBColor[
              0.184696983160691, 0.3114586181399484, 0.9338295920050762], 
             UndirectedEdge[236, 397] -> 
             RGBColor[
              0.4369077612514729, 0.5513201116783387, 0.9494828667557864], 
             UndirectedEdge[33, 118] -> 
             RGBColor[
              0.30201839786374246`, 0.43026808739011524`, 0.9406757417053806],
              UndirectedEdge[51, 79] -> 
             RGBColor[
              0.20012999875823717`, 0.3276796960426744, 0.934708479412256], 
             UndirectedEdge[24, 168] -> 
             RGBColor[
              0.22907306672132033`, 0.35810069556837376`, 0.9363567443153216],
              UndirectedEdge[269, 365] -> 
             RGBColor[
              0.3297101598350657, 0.4597477851420956, 0.9422390562668672], 
             UndirectedEdge[98, 240] -> 
             RGBColor[
              0.18629079266231832`, 0.3131338129795177, 0.9339203570983641], 
             UndirectedEdge[29, 113] -> 
             RGBColor[
              0.1857448284490183, 0.3125599699752089, 0.9338892652440982], 
             UndirectedEdge[330, 398] -> 
             RGBColor[
              0.18475377969358928`, 0.31151831489713266`, 0.9338328264836019],
              UndirectedEdge[43, 265] -> 
             RGBColor[
              0.19684687423849298`, 0.3242289240103058, 0.934521510327804], 
             UndirectedEdge[209, 304] -> 
             RGBColor[
              0.2736580263748165, 0.40496231501391133`, 0.9388957918100511], 
             UndirectedEdge[107, 238] -> 
             RGBColor[
              0.21198166691675951`, 0.34013655071644366`, 0.9353834143809119],
              UndirectedEdge[298, 347] -> 
             RGBColor[
              0.1948950544058417, 0.32217743761366435`, 0.9344103570757931], 
             UndirectedEdge[153, 343] -> 
             RGBColor[
              0.20318561149837056`, 0.330891338769592, 0.9348824920374326], 
             UndirectedEdge[110, 292] -> 
             RGBColor[
              0.8362272767124428, 0.5182110192715781, 0.5760681458101908], 
             UndirectedEdge[332, 366] -> 
             RGBColor[
              0.905552488404973, 0.5629699044168974, 0.3384071050888487], 
             UndirectedEdge[39, 136] -> 
             RGBColor[
              0.19040517985093924`, 0.31745829478197307`, 0.9341546653620656],
              UndirectedEdge[115, 380] -> 
             RGBColor[
              0.8377450255090341, 0.8206060012110092, 0.627750782576732], 
             UndirectedEdge[167, 238] -> 
             RGBColor[
              0.2183443407497785, 0.3468241243317679, 0.9357457592429699], 
             UndirectedEdge[1, 162] -> 
             RGBColor[
              0.18855509271436693`, 0.315513735899136, 0.9340493056365965], 
             UndirectedEdge[128, 243] -> 
             RGBColor[
              0.26764794439082373`, 0.39864533778752814`, 0.9385535265321823],
              UndirectedEdge[196, 366] -> 
             RGBColor[
              0.9187123308959824, 0.9333119446325909, 0.748562723255582], 
             UndirectedEdge[136, 149] -> 
             RGBColor[
              0.19648120536399588`, 0.3238445828384636, 0.9345006860263599], 
             UndirectedEdge[263, 360] -> 
             RGBColor[
              0.48229378308011506`, 0.5855219577186828, 0.9537605973016217], 
             UndirectedEdge[267, 354] -> 
             RGBColor[
              0.19683262012965425`, 0.3242139420381536, 0.9345206985773926], 
             UndirectedEdge[192, 355] -> 
             RGBColor[
              0.233203459675137, 0.36244200044487396`, 0.9365919640836726], 
             UndirectedEdge[24, 100] -> 
             RGBColor[
              0.32394697736880945`, 0.450518226988342, 0.9420269972308946], 
             UndirectedEdge[11, 286] -> 
             RGBColor[
              0.5972181184299319, 0.677195451192008, 0.9647287147159659], 
             UndirectedEdge[71, 110] -> 
             RGBColor[
              0.9113332721380322, 0.9312595378862136, 0.9610025753124077], 
             UndirectedEdge[186, 306] -> 
             RGBColor[
              0.21444053080855624`, 0.3427209725676972, 0.9355234430419865], 
             UndirectedEdge[6, 131] -> 
             RGBColor[
              0.8701371040264215, 0.8993351938028649, 0.9874630507499915], 
             UndirectedEdge[53, 264] -> 
             RGBColor[
              0.3312918681319017, 0.4568612487266348, 0.9424956938321003], 
             UndirectedEdge[83, 118] -> 
             RGBColor[
              0.6542161598297946, 0.7234949587303476, 0.9559255584190995], 
             UndirectedEdge[98, 272] -> 
             RGBColor[
              0.1949500622314218, 0.3222352543260466, 0.9344134896900831], 
             UndirectedEdge[200, 330] -> 
             RGBColor[
              0.1913737687250167, 0.31847634310071005`, 0.9342098250655455], 
             UndirectedEdge[101, 389] -> 
             RGBColor[
              0.9235485115849101, 0.701785575444227, 0.3461039765729519], 
             UndirectedEdge[10, 353] -> 
             RGBColor[
              0.9181134493807003, 0.6596306220979193, 0.3482638350680197], 
             UndirectedEdge[174, 340] -> 
             RGBColor[
              0.3446138349142821, 0.46945528337457815`, 0.9433059211263948], 
             UndirectedEdge[77, 187] -> 
             RGBColor[
              0.2066496337845954, 0.33453224582411256`, 0.9350797629820713], 
             UndirectedEdge[137, 264] -> 
             RGBColor[
              0.27631179289230656`, 0.4077515918823088, 0.9390469198873264], 
             UndirectedEdge[20, 356] -> 
             RGBColor[
              0.6650046334832713, 0.7331764586358418, 0.9615322764421933], 
             UndirectedEdge[130, 227] -> 
             RGBColor[
              0.24482762812914852`, 0.374659738504888, 0.9372539432807123], 
             UndirectedEdge[24, 150] -> 
             RGBColor[
              0.24929421300339247`, 0.3793544024055562, 0.9375083086815804], 
             UndirectedEdge[282, 339] -> 
             RGBColor[
              0.34849054026782905`, 0.4762667231613163, 0.9434264869611491], 
             UndirectedEdge[69, 93] -> 
             RGBColor[
              0.45767335020652483`, 0.5675906819706489, 0.951280040300782], 
             UndirectedEdge[65, 266] -> 
             RGBColor[
              0.5173579150755038, 0.6167245429391528, 0.9558899485594068], 
             UndirectedEdge[189, 336] -> 
             RGBColor[
              0.23398737474331802`, 0.3632659448846183, 0.936636606887107], 
             UndirectedEdge[191, 322] -> 
             RGBColor[
              0.18956017104754852`, 0.31657013695295677`, 0.934106543360791], 
             UndirectedEdge[297, 376] -> 
             RGBColor[
              0.2913695149854919, 0.423578212516969, 0.9399044348846297], 
             UndirectedEdge[33, 286] -> 
             RGBColor[
              0.2839164063725824, 0.41458905219301934`, 0.9395222988145264], 
             UndirectedEdge[145, 351] -> 
             RGBColor[
              0.2797139568415439, 0.4112527007055903, 0.9392434061971325], 
             UndirectedEdge[83, 141] -> 
             RGBColor[
              0.6533758763039106, 0.7227671473741049, 0.9558720162958637], 
             UndirectedEdge[148, 276] -> 
             RGBColor[
              0.31779913118136904`, 0.44485776815799194`, 0.9416475463334251],
              UndirectedEdge[124, 160] -> 
             RGBColor[
              0.21095706740892387`, 0.3390596316703475, 0.9353250649546998], 
             UndirectedEdge[25, 362] -> 
             RGBColor[
              0.5776163710657185, 0.6632666473879071, 0.9621212256893779], 
             UndirectedEdge[96, 208] -> 
             RGBColor[
              0.25302363918053994`, 0.383274265777015, 0.9377206939851772], 
             UndirectedEdge[240, 272] -> 
             RGBColor[
              0.18799208314490007`, 0.3149219771447579, 0.9340172430745133], 
             UndirectedEdge[25, 182] -> 
             RGBColor[
              0.30289473156223595`, 0.4305868645556383, 0.9407477009537915], 
             UndirectedEdge[101, 380] -> 
             RGBColor[
              0.787177962650946, 0.5986793707999881, 0.5860416238148101], 
             UndirectedEdge[24, 358] -> 
             RGBColor[
              0.2688894294981841, 0.3999502173500661, 0.9386242272724338], 
             UndirectedEdge[202, 234] -> 
             RGBColor[
              0.28726387007128157`, 0.41752052418196, 0.9397344221047603], 
             UndirectedEdge[17, 62] -> 
             RGBColor[
              0.9097327710312662, 0.6022520662838114, 0.4798085283004041], 
             UndirectedEdge[24, 211] -> 
             RGBColor[
              0.2463354066076684, 0.3762445092844895, 0.9373398090345058], 
             UndirectedEdge[2, 39] -> 
             RGBColor[
              0.19999978068083032`, 0.3275428285870168, 0.934701063685388], 
             UndirectedEdge[164, 328] -> 
             RGBColor[
              0.22317220824719552`, 0.35189851917603227`, 0.9360206991547579],
              UndirectedEdge[228, 301] -> 
             RGBColor[
              0.2369380396545014, 0.36636728078923275`, 0.9368046428886814], 
             UndirectedEdge[118, 286] -> 
             RGBColor[
              0.33934539796061675`, 0.46834566054302623`, 0.9428437665800653],
              UndirectedEdge[139, 215] -> 
             RGBColor[
              0.5065072627092252, 0.6051273956422916, 0.956064783626883], 
             UndirectedEdge[239, 377] -> 
             RGBColor[
              0.3809157120608543, 0.4978929904163819, 0.9460793391645779], 
             UndirectedEdge[348, 374] -> 
             RGBColor[
              0.19237032800791454`, 0.3195237900925436, 0.9342665776424293], 
             UndirectedEdge[8, 388] -> 
             RGBColor[
              0.26319007599843486`, 0.3939598354619466, 0.938299657522061], 
             UndirectedEdge[249, 370] -> 
             RGBColor[
              0.18458433002004276`, 0.31134021254650546`, 0.9338231765753717],
              UndirectedEdge[61, 285] -> 
             RGBColor[
              0.2007711589524707, 0.32835359605871806`, 0.934744992536806], 
             UndirectedEdge[162, 280] -> 
             RGBColor[
              0.20211294537388308`, 0.32976389866179523`, 0.9348214052885103],
              UndirectedEdge[126, 205] -> 
             RGBColor[
              0.18385657240612066`, 0.31057529315177557`, 0.9337817318558796],
              UndirectedEdge[161, 334] -> 
             RGBColor[
              0.9198789642740572, 0.7116881876157337, 0.2605664067222301], 
             UndirectedEdge[192, 399] -> 
             RGBColor[
              0.3088211273745378, 0.43723989163816773`, 0.941069675369404], 
             UndirectedEdge[69, 281] -> 
             RGBColor[
              0.4857845720433236, 0.5919392094145923, 0.9530712624984452], 
             UndirectedEdge[38, 128] -> 
             RGBColor[
              0.281313846761083, 0.4130090676469258, 0.9393317794552777], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.22265042245962569`, 0.35135008923016664`, 0.9359909842260687],
              UndirectedEdge[145, 355] -> 
             RGBColor[
              0.22900678342998865`, 0.3580310276265808, 0.9363529695799375], 
             UndirectedEdge[23, 139] -> 
             RGBColor[
              0.2594316195520534, 0.3900094594368974, 0.9380856189875776], 
             UndirectedEdge[120, 359] -> 
             RGBColor[
              0.3691186833876108, 0.4941337839310517, 0.9447408939999908], 
             UndirectedEdge[117, 309] -> 
             RGBColor[
              0.6279491492944215, 0.7079937863162957, 0.9644297266188226], 
             UndirectedEdge[19, 167] -> 
             RGBColor[
              0.21765966709879997`, 0.34610448891377266`, 0.9357067680914306],
              UndirectedEdge[26, 285] -> 
             RGBColor[
              0.1832664520031871, 0.30995503919249784`, 0.9337481253719375], 
             UndirectedEdge[166, 169] -> 
             RGBColor[
              0.3512165772923903, 0.4726432539013666, 0.9438449606681389], 
             UndirectedEdge[31, 383] -> 
             RGBColor[
              0.6712879724630387, 0.7362684219408357, 0.9272977112853262], 
             UndirectedEdge[146, 346] -> 
             RGBColor[
              0.20127774655664432`, 0.3288860517502138, 0.9347738419514344], 
             UndirectedEdge[191, 349] -> 
             RGBColor[
              0.1912119313089536, 0.3183062417153429, 0.9342006086641177], 
             UndirectedEdge[212, 362] -> 
             RGBColor[
              0.6845252117813709, 0.7524862898136562, 0.9698671068536907], 
             UndirectedEdge[242, 380] -> 
             RGBColor[
              0.5303903683229951, 0.6253725774741394, 0.9578377471522206], 
             UndirectedEdge[175, 307] -> 
             RGBColor[
              0.18458331869086259`, 0.3113391495754152, 0.933823118981671], 
             UndirectedEdge[140, 193] -> 
             RGBColor[
              0.6221373960333281, 0.6999919748954846, 0.9657582775840088], 
             UndirectedEdge[8, 25] -> 
             RGBColor[
              0.3097802502292844, 0.43782398124180466`, 0.9411398210556678], 
             UndirectedEdge[8, 269] -> 
             RGBColor[
              0.30450100126350144`, 0.4332513611304116, 0.9408034319798247], 
             UndirectedEdge[155, 371] -> 
             RGBColor[
              0.18296643499197385`, 0.3096397022915355, 0.9337310398469844], 
             UndirectedEdge[55, 161] -> 
             RGBColor[
              0.8416418357931794, 0.6962674351181222, 0.6011377684958046], 
             UndirectedEdge[110, 202] -> 
             RGBColor[
              0.590277084299675, 0.6718791600205865, 0.9639661767270546], 
             UndirectedEdge[332, 380] -> 
             RGBColor[
              0.7690935487574768, 0.4596746409740855, 0.5687239686469998], 
             UndirectedEdge[359, 360] -> 
             RGBColor[
              0.49422258294729215`, 0.5964933259008812, 0.9544972841256812], 
             UndirectedEdge[128, 350] -> 
             RGBColor[
              0.32622360223214686`, 0.4565323538126437, 0.9420240559565443], 
             UndirectedEdge[272, 378] -> 
             RGBColor[
              0.2184441934159871, 0.34692907581497784`, 0.9357514457045917], 
             UndirectedEdge[52, 345] -> 
             RGBColor[
              0.9085391948738575, 0.9277362639462506, 0.9077575254526454], 
             UndirectedEdge[32, 333] -> 
             RGBColor[
              0.8876476995379257, 0.5657281038549604, 0.5656841246616948], 
             UndirectedEdge[85, 168] -> 
             RGBColor[
              0.18992658867508105`, 0.3169552651117129, 0.9341274103026127], 
             UndirectedEdge[23, 354] -> 
             RGBColor[
              0.20401044687486744`, 0.3317582930478737, 0.9349294651918895], 
             UndirectedEdge[51, 373] -> 
             RGBColor[
              0.1995969758310581, 0.32711945515060364`, 0.9346781245450898], 
             UndirectedEdge[55, 334] -> 
             RGBColor[
              0.8819744590496598, 0.862025730858683, 0.6405013220512796], 
             UndirectedEdge[66, 267] -> 
             RGBColor[
              0.1968456208420638, 0.3242276066111888, 0.9345214389487315], 
             UndirectedEdge[30, 153] -> 
             RGBColor[
              0.2031751711317593, 0.3308803652823261, 0.9348818974739992], 
             UndirectedEdge[179, 290] -> 
             RGBColor[
              0.24217146180405288`, 0.37186793928654055`, 0.9371026785379442],
              UndirectedEdge[178, 200] -> 
             RGBColor[
              0.1885274133225135, 0.31548464310332325`, 0.9340477293361784], 
             UndirectedEdge[340, 358] -> 
             RGBColor[
              0.2744945486553811, 0.4058415529693607, 0.9389434305164055], 
             UndirectedEdge[31, 259] -> 
             RGBColor[
              0.9398415048836066, 0.9536048784389164, 0.9502151803126189], 
             UndirectedEdge[92, 146] -> 
             RGBColor[
              0.20174986693286398`, 0.32938228019978144`, 0.9348007285084208],
              UndirectedEdge[3, 373] -> 
             RGBColor[
              0.21710028788855346`, 0.3455165458971132, 0.9356749122729344], 
             UndirectedEdge[174, 341] -> 
             RGBColor[
              0.3335895874564281, 0.4578681003187137, 0.9426781065425826], 
             UndirectedEdge[248, 260] -> 
             RGBColor[
              0.1859219097416619, 0.3127460936413798, 0.933899349761746], 
             UndirectedEdge[41, 325] -> 
             RGBColor[
              0.2165335134226994, 0.3449208299979239, 0.9356426353055718], 
             UndirectedEdge[66, 346] -> 
             RGBColor[
              0.19977669952143007`, 0.3273083561443247, 0.9346883595433791], 
             UndirectedEdge[53, 142] -> 
             RGBColor[
              0.43838221439814257`, 0.5535604743597381, 0.949310664485988], 
             UndirectedEdge[38, 44] -> 
             RGBColor[
              0.24351959225973108`, 0.37328490987186613`, 0.9371794525730147],
              UndirectedEdge[76, 187] -> 
             RGBColor[
              0.24964108184106412`, 0.37971898354670364`, 0.9375280623487394],
              UndirectedEdge[156, 160] -> 
             RGBColor[
              0.19858358472464382`, 0.32605431684505504`, 0.9346204134207573],
              UndirectedEdge[141, 290] -> 
             RGBColor[
              0.3066482770874609, 0.4352897639120549, 0.9409337172583541], 
             UndirectedEdge[3, 79] -> 
             RGBColor[
              0.21763331081573253`, 0.34607678678918397`, 0.9357052671401005],
              UndirectedEdge[301, 382] -> 
             RGBColor[
              0.2859820358837003, 0.41668133468074653`, 0.9396428195322926], 
             UndirectedEdge[193, 389] -> 
             RGBColor[
              0.9155257058475293, 0.9306524378746825, 0.7386464272151838], 
             UndirectedEdge[189, 291] -> 
             RGBColor[
              0.21431712870363867`, 0.34259126913128346`, 0.9355164154746687],
              UndirectedEdge[161, 196] -> 
             RGBColor[
              0.8618354721760655, 0.7122379768474625, 0.603098702731688], 
             UndirectedEdge[83, 161] -> 
             RGBColor[
              0.9152656356126947, 0.754447556797873, 0.5945283802670174], 
             UndirectedEdge[100, 211] -> 
             RGBColor[
              0.31010062158634694`, 0.43596482915131163`, 0.941238467752931], 
             UndirectedEdge[32, 287] -> 
             RGBColor[
              0.8194189331925024, 0.1502680067141652, 0.16622889839667554`], 
             UndirectedEdge[156, 181] -> 
             RGBColor[
              0.19699698742024596`, 0.3243867024820536, 0.9345300590514323], 
             UndirectedEdge[126, 176] -> 
             RGBColor[
              0.18438193895865332`, 0.3111274867086507, 0.9338116507038363], 
             UndirectedEdge[46, 350] -> 
             RGBColor[
              0.5770408715617338, 0.6621623046757947, 0.9623409899481321], 
             UndirectedEdge[47, 149] -> 
             RGBColor[
              0.1956652358484003, 0.3229869471421173, 0.9344542177695655], 
             UndirectedEdge[57, 108] -> 
             RGBColor[
              0.32733127751038416`, 0.4577193635987606, 0.9420863025998256], 
             UndirectedEdge[105, 400] -> 
             RGBColor[
              0.9037087544899305, 0.5795914846825118, 0.5310267371567282], 
             UndirectedEdge[62, 256] -> 
             RGBColor[
              0.992053902372576, 0.9909820986727351, 0.781350931735281], 
             UndirectedEdge[193, 332] -> 
             RGBColor[
              0.8278665265086236, 0.5057335736447233, 0.5745434217731962], 
             UndirectedEdge[1, 387] -> 
             RGBColor[
              0.1836776641650684, 0.31038724924699196`, 0.9337715432962228], 
             UndirectedEdge[72, 284] -> 
             RGBColor[
              0.602700789657427, 0.6868450128545692, 0.9628871876056561], 
             UndirectedEdge[127, 394] -> 
             RGBColor[
              0.348496932711213, 0.47627225997448197`, 0.9434268942819889], 
             UndirectedEdge[110, 385] -> 
             RGBColor[
              0.923690126192328, 0.9380306979900004, 0.809802069993292], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.18382719114068813`, 0.31054441157892615`, 0.933780058636279], 
             UndirectedEdge[97, 393] -> 
             RGBColor[
              0.5102982570407728, 0.6069665111134733, 0.9566203329382144], 
             UndirectedEdge[19, 150] -> 
             RGBColor[
              0.21895975804167556`, 0.3474709669252617, 0.9357808063473152], 
             UndirectedEdge[272, 342] -> 
             RGBColor[
              0.19152273141080622`, 0.31863291232825464`, 0.9342183082701306],
              UndirectedEdge[96, 187] -> 
             RGBColor[
              0.2139882194822336, 0.34224556468553763`, 0.9354976845810872], 
             UndirectedEdge[129, 333] -> 
             RGBColor[
              0.8865563472760825, 0.5573394921368233, 0.5646390445032476], 
             UndirectedEdge[19, 160] -> 
             RGBColor[
              0.19740416245689973`, 0.32481466926196517`, 0.9345532470674082],
              UndirectedEdge[183, 357] -> 
             RGBColor[
              0.18734376764879906`, 0.31424055645277915`, 0.9339803224661072],
              UndirectedEdge[197, 217] -> 
             RGBColor[
              0.19977926755688577`, 0.3273110553124115, 0.9346885057891993], 
             UndirectedEdge[199, 345] -> 
             RGBColor[
              0.9084097409587222, 0.9276827314255283, 0.9099029118424318], 
             UndirectedEdge[44, 346] -> 
             RGBColor[
              0.2158698080892293, 0.3442232336110982, 0.9356048382686947], 
             UndirectedEdge[78, 80] -> 
             RGBColor[
              0.21178615052788774`, 0.3399310505952844, 0.9353722800118063], 
             UndirectedEdge[42, 320] -> 
             RGBColor[
              0.18379681968568948`, 0.3105124892540611, 0.9337783290268474], 
             UndirectedEdge[161, 332] -> 
             RGBColor[
              0.848675629685056, 0.3418959366317691, 0.19294308456495457`], 
             UndirectedEdge[239, 309] -> 
             RGBColor[
              0.6022520031590326, 0.6871316854403461, 0.9624067531432969], 
             UndirectedEdge[8, 377] -> 
             RGBColor[
              0.25514638831763914`, 0.3855054097101751, 0.9378415814082092], 
             UndirectedEdge[75, 126] -> 
             RGBColor[
              0.18223452639463555`, 0.3088704199500476, 0.9336893587351277], 
             UndirectedEdge[54, 310] -> 
             RGBColor[
              0.8873852444618682, 0.5186875281092153, 0.22512385696518958`], 
             UndirectedEdge[65, 211] -> 
             RGBColor[
              0.3044915837808781, 0.4311065625226518, 0.9408810648238439], 
             UndirectedEdge[88, 356] -> 
             RGBColor[
              0.6878897223994248, 0.7529983724170004, 0.962990494071441], 
             UndirectedEdge[98, 158] -> 
             RGBColor[
              0.19219455973941713`, 0.31933904649800093`, 0.9342565678995641],
              UndirectedEdge[13, 390] -> 
             RGBColor[
              0.2131729075996141, 0.34138862020314553`, 0.9354512537755177], 
             UndirectedEdge[241, 242] -> 
             RGBColor[
              0.31065498243158685`, 0.4409219663646659, 0.9411098670507269], 
             UndirectedEdge[12, 238] -> 
             RGBColor[
              0.2218338423144311, 0.3504918117233956, 0.9359444811948219], 
             UndirectedEdge[175, 343] -> 
             RGBColor[
              0.19542826971397487`, 0.32273788071031545`, 0.93444072289877], 
             UndirectedEdge[59, 258] -> 
             RGBColor[
              0.2269624966999203, 0.35588235265801405`, 0.9362365504749113], 
             UndirectedEdge[152, 156] -> 
             RGBColor[
              0.20135778622096587`, 0.32897017851222354`, 0.9347784000919095],
              UndirectedEdge[39, 258] -> 
             RGBColor[
              0.21791338707223826`, 0.34637116469263174`, 0.9357212170685729],
              UndirectedEdge[183, 368] -> 
             RGBColor[
              0.18625851527578347`, 0.31309988739976513`, 0.933918518948951], 
             UndirectedEdge[44, 119] -> 
             RGBColor[
              0.23405162543822766`, 0.3633334764386976, 0.9366402658691317], 
             UndirectedEdge[149, 264] -> 
             RGBColor[
              0.23515256587011008`, 0.3644906346362611, 0.9367029627980321], 
             UndirectedEdge[120, 241] -> 
             RGBColor[
              0.34672955885014695`, 0.4721679512974918, 0.9434085071606221], 
             UndirectedEdge[116, 304] -> 
             RGBColor[
              0.26114585574207083`, 0.3918112303614577, 0.938183242202614], 
             UndirectedEdge[82, 256] -> 
             RGBColor[
              0.8760312800563814, 0.9016669835366705, 0.876948136427472], 
             UndirectedEdge[98, 186] -> 
             RGBColor[
              0.1999149394327242, 0.32745365505601143`, 0.9346962321018197], 
             UndirectedEdge[72, 262] -> 
             RGBColor[
              0.4149349676293397, 0.5334857796550911, 0.9477519352990894], 
             UndirectedEdge[147, 241] -> 
             RGBColor[
              0.2640632471374818, 0.3948775936913327, 0.9383493833266887], 
             UndirectedEdge[13, 205] -> 
             RGBColor[
              0.19925835051903662`, 0.3267635384775842, 0.9346588403345214], 
             UndirectedEdge[142, 394] -> 
             RGBColor[
              0.4158923670367568, 0.5340808989479011, 0.9478776312991117], 
             UndirectedEdge[42, 75] -> 
             RGBColor[
              0.18289766237674282`, 0.30956741791249204`, 0.9337271233482869],
              UndirectedEdge[56, 341] -> 
             RGBColor[
              0.38387079611477953`, 0.499652079122729, 0.9463702293168075], 
             UndirectedEdge[306, 378] -> 
             RGBColor[
              0.23126849430923743`, 0.36040822916142345`, 0.9364817706686093],
              UndirectedEdge[27, 295] -> 
             RGBColor[
              0.19546687096427723`, 0.32277845307184394`, 0.9344429211828693],
              UndirectedEdge[111, 247] -> 
             RGBColor[
              0.8219754147542075, 0.16991824425479435`, 0.1686769880272973], 
             UndirectedEdge[128, 259] -> 
             RGBColor[
              0.599663278641086, 0.6781009426487141, 0.9652528657581285], 
             UndirectedEdge[52, 68] -> 
             RGBColor[
              0.9052995090875355, 0.9251530264391655, 0.9074485213302443], 
             UndirectedEdge[241, 359] -> 
             RGBColor[
              0.3033005319170658, 0.43455191097441853`, 0.9406412479672268], 
             UndirectedEdge[361, 382] -> 
             RGBColor[
              0.3658350125936814, 0.49128963333144304`, 0.9445316614006376], 
             UndirectedEdge[14, 390] -> 
             RGBColor[
              0.27581610861732475`, 0.40446583032584077`, 0.9391199230263283],
              UndirectedEdge[11, 332] -> 
             RGBColor[
              0.8454988743714711, 0.5197931292132254, 0.5762252108529373], 
             UndirectedEdge[22, 209] -> 
             RGBColor[
              0.25353925279510015`, 0.38381620837770913`, 0.9377500574177445],
              UndirectedEdge[33, 156] -> 
             RGBColor[
              0.22423055163894667`, 0.35301090518360945`, 0.9360809702452394],
              UndirectedEdge[283, 332] -> 
             RGBColor[
              0.8748637305772158, 0.45283228980267326`, 0.21438239989975133`],
              UndirectedEdge[150, 181] -> 
             RGBColor[
              0.21526447072748034`, 0.3435869856632946, 0.9355703652014595], 
             UndirectedEdge[117, 323] -> 
             RGBColor[
              0.4895767347577772, 0.5956116976057565, 0.9532057157698048], 
             UndirectedEdge[199, 223] -> 
             RGBColor[
              0.9239760391061387, 0.7216129997514857, 0.5202901272072924], 
             UndirectedEdge[128, 306] -> 
             RGBColor[
              0.2631009453754704, 0.39386615352600307`, 0.9382945816649401], 
             UndirectedEdge[184, 288] -> 
             RGBColor[
              0.21364346222149755`, 0.3418832029456312, 0.9354780511651108], 
             UndirectedEdge[145, 182] -> 
             RGBColor[
              0.24585035887698375`, 0.3757346933657375, 0.937312186283807], 
             UndirectedEdge[284, 397] -> 
             RGBColor[
              0.5520222170780682, 0.6432815473581924, 0.9595663255932364], 
             UndirectedEdge[61, 148] -> 
             RGBColor[
              0.23690961095816437`, 0.3663374004268991, 0.9368030239164815], 
             UndirectedEdge[34, 159] -> 
             RGBColor[
              0.1825395439463383, 0.30919101273611693`, 0.9337067290334642], 
             UndirectedEdge[276, 382] -> 
             RGBColor[
              0.35057061271571854`, 0.4780683773681971, 0.9435590273381926], 
             UndirectedEdge[59, 164] -> 
             RGBColor[
              0.215632569168565, 0.3439738804636637, 0.9355913278631264], 
             UndirectedEdge[80, 377] -> 
             RGBColor[
              0.2289003475673298, 0.3579191567865028, 0.9363469082150169], 
             UndirectedEdge[180, 370] -> 
             RGBColor[
              0.18698550798658503`, 0.3138640028328177, 0.9339599201083417], 
             UndirectedEdge[98, 374] -> 
             RGBColor[
              0.18844266475489285`, 0.3153955669853844, 0.9340429030306268], 
             UndirectedEdge[139, 350] -> 
             RGBColor[
              0.3277444111277722, 0.4581308203867991, 0.942110663773315], 
             UndirectedEdge[36, 276] -> 
             RGBColor[
              0.31234957064668134`, 0.4391299345139409, 0.941337201922877], 
             UndirectedEdge[53, 281] -> 
             RGBColor[
              0.40067800773256046`, 0.5214688844608842, 0.9467518262404362], 
             UndirectedEdge[73, 183] -> 
             RGBColor[
              0.19359784833893534`, 0.3208139917897307, 0.9343364831093273], 
             UndirectedEdge[101, 115] -> 
             RGBColor[
              0.9045408089975616, 0.6377980714511916, 0.24102778506069641`], 
             UndirectedEdge[283, 366] -> 
             RGBColor[
              0.9626113006296535, 0.8779402128312055, 0.388106189025446], 
             UndirectedEdge[22, 141] -> 
             RGBColor[
              0.2988998919025237, 0.4271457198066904, 0.9404924581847806], 
             UndirectedEdge[197, 314] -> 
             RGBColor[
              0.18703267242257346`, 0.3139135756454394, 0.9339626060531978], 
             UndirectedEdge[13, 14] -> 
             RGBColor[
              0.27600611579144196`, 0.4046655399129887, 0.9391307436538039], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.18066543438157506`, 0.30722120475814135`, 0.9336000012662475],
              UndirectedEdge[323, 395] -> 
             RGBColor[
              0.42965137086591587`, 0.5465641553634234, 0.9485979833191546], 
             UndirectedEdge[93, 131] -> 
             RGBColor[
              0.5783198351360825, 0.6629059133309206, 0.9625766163950823], 
             UndirectedEdge[52, 105] -> 
             RGBColor[
              0.9871484754393005, 0.988953578572104, 0.8626465508576164], 
             UndirectedEdge[178, 330] -> 
             RGBColor[
              0.18585403499635023`, 0.3126747529805498, 0.9338954843954123], 
             UndirectedEdge[92, 98] -> 
             RGBColor[
              0.19880960071600262`, 0.32629187398221465`, 0.9346332846971046],
              UndirectedEdge[37, 323] -> 
             RGBColor[
              0.35247668459828785`, 0.4774620340320098, 0.9437631308877006], 
             UndirectedEdge[279, 370] -> 
             RGBColor[
              0.19229180160053655`, 0.3194412538595276, 0.9342621056796985], 
             UndirectedEdge[150, 160] -> 
             RGBColor[
              0.2168510680318782, 0.345254600026296, 0.9356607195707846], 
             UndirectedEdge[188, 273] -> 
             RGBColor[
              0.39992754574806544`, 0.5158532142548906, 0.9473461281045827], 
             UndirectedEdge[179, 386] -> 
             RGBColor[
              0.284370042597393, 0.41315352294311436`, 0.9396181524839584], 
             UndirectedEdge[141, 179] -> 
             RGBColor[
              0.2912900071166007, 0.41914724840212236`, 0.9400590865040379], 
             UndirectedEdge[117, 388] -> 
             RGBColor[
              0.4146565458770389, 0.527209517044103, 0.9485603887539554], 
             UndirectedEdge[198, 214] -> 
             RGBColor[
              0.8538594754790496, 0.7047084000192836, 0.6021070091036955], 
             UndirectedEdge[150, 238] -> 
             RGBColor[
              0.21964443169265407`, 0.3481906023432569, 0.9358197974988545], 
             UndirectedEdge[331, 392] -> 
             RGBColor[
              0.22201549227327083`, 0.35068273734740874`, 0.9359548258912509],
              UndirectedEdge[323, 365] -> 
             RGBColor[
              0.3633194234507374, 0.48885844003528395`, 0.9443806088249529], 
             UndirectedEdge[6, 71] -> 
             RGBColor[
              0.9479335881069795, 0.9604436363507414, 0.9644935461230137], 
             UndirectedEdge[132, 249] -> 
             RGBColor[
              0.18824799980109214`, 0.3151909617764689, 0.9340318171494888], 
             UndirectedEdge[348, 378] -> 
             RGBColor[
              0.22067056618642705`, 0.3492691347568969, 0.935878234340245], 
             UndirectedEdge[174, 198] -> 
             RGBColor[
              0.6233166189809511, 0.701327344471203, 0.9656888716580491], 
             UndirectedEdge[72, 236] -> 
             RGBColor[
              0.4875863338308316, 0.5948835771747154, 0.9528037287682061], 
             UndirectedEdge[9, 100] -> 
             RGBColor[
              0.5370355289675518, 0.6325732881317867, 0.9576495756744858], 
             UndirectedEdge[51, 298] -> 
             RGBColor[
              0.20333725610200998`, 0.3310507268628402, 0.9348911279732717], 
             UndirectedEdge[23, 128] -> 
             RGBColor[
              0.2579108106564282, 0.38841099286274205`, 0.9379990111708069], 
             UndirectedEdge[215, 353] -> 
             RGBColor[
              0.8496653857450382, 0.8791494975932964, 0.7395436178949295], 
             UndirectedEdge[80, 96] -> 
             RGBColor[
              0.2073679300463957, 0.3352872207378781, 0.9351206688915568], 
             UndirectedEdge[78, 388] -> 
             RGBColor[
              0.2456236030410635, 0.37549635860503494`, 0.9372992728744065], 
             UndirectedEdge[312, 380] -> 
             RGBColor[
              0.6340993587155315, 0.7126342355184634, 0.9651549462114524], 
             UndirectedEdge[57, 325] -> 
             RGBColor[
              0.29328547563165996`, 0.42193506719570584`, 0.9401474445490827],
              UndirectedEdge[308, 374] -> 
             RGBColor[
              0.1982421611639798, 0.32569545903529307`, 0.9346009698540684], 
             UndirectedEdge[76, 365] -> 
             RGBColor[
              0.2944759917270998, 0.42684331653440033`, 0.9400813441394438], 
             UndirectedEdge[182, 187] -> 
             RGBColor[
              0.22908739425404853`, 0.35811575471368917`, 0.9363575602471148],
              UndirectedEdge[74, 286] -> 
             RGBColor[
              0.28488862903471124`, 0.4156109198533938, 0.9395776654568602], 
             UndirectedEdge[137, 164] -> 
             RGBColor[
              0.2538187120761361, 0.3841099378008197, 0.9377659722103766], 
             UndirectedEdge[149, 258] -> 
             RGBColor[
              0.22398941258529487`, 0.35275745274912235`, 0.9360672377328672],
              UndirectedEdge[147, 331] -> 
             RGBColor[
              0.2440919709450002, 0.37388651616098867`, 0.9372120486923824], 
             UndirectedEdge[42, 367] -> 
             RGBColor[
              0.1849893429390042, 0.3117659068036362, 0.9338462414619436], 
             UndirectedEdge[16, 365] -> 
             RGBColor[
              0.2674853323456614, 0.39847442221786333`, 0.9385442660167731], 
             UndirectedEdge[113, 183] -> 
             RGBColor[
              0.18716623928349274`, 0.31405396288489373`, 0.9339702124883327],
              UndirectedEdge[16, 323] -> 
             RGBColor[
              0.3247877744177019, 0.4483592338539112, 0.9421862884149881], 
             UndirectedEdge[340, 343] -> 
             RGBColor[
              0.2360559349263153, 0.3654401327912391, 0.9367544083293682], 
             UndirectedEdge[323, 362] -> 
             RGBColor[
              0.6059463857156073, 0.6878046821697024, 0.9639263891716204], 
             UndirectedEdge[334, 364] -> 
             RGBColor[
              0.9407749655383337, 0.8016431292497415, 0.27774757447488835`], 
             UndirectedEdge[94, 324] -> 
             RGBColor[
              0.18239675869616345`, 0.30904093638507546`, 0.9336985976246985],
              UndirectedEdge[135, 350] -> 
             RGBColor[
              0.3419502599754641, 0.47060186109611535`, 0.9430097460842624], 
             UndirectedEdge[31, 215] -> 
             RGBColor[
              0.8451646800561206, 0.8790328648583385, 0.9409404903646027], 
             UndirectedEdge[3, 21] -> 
             RGBColor[
              0.21644166427209716`, 0.34482429071706844`, 0.9356374046323236],
              UndirectedEdge[127, 193] -> 
             RGBColor[
              0.5886484429999097, 0.6709855269816585, 0.9636243911098379], 
             UndirectedEdge[50, 230] -> 
             RGBColor[
              0.2261265468612622, 0.35500371637530337`, 0.9361889443682767], 
             UndirectedEdge[169, 382] -> 
             RGBColor[
              0.38967734439969204`, 0.5118336629702842, 0.9460804380697425], 
             UndirectedEdge[12, 19] -> 
             RGBColor[
              0.22114916866345258`, 0.3497721763054004, 0.9359054900432826], 
             UndirectedEdge[133, 296] -> 
             RGBColor[
              0.18124069831826523`, 0.30782584362944293`, 0.9336327616964153],
              UndirectedEdge[214, 332] -> 
             RGBColor[
              0.8483631502363858, 0.34047704043678684`, 0.1926823440534119], 
             UndirectedEdge[76, 395] -> 
             RGBColor[
              0.36080793914227827`, 0.4845490318625397, 0.9442987186336453], 
             UndirectedEdge[299, 370] -> 
             RGBColor[
              0.1869681936623269, 0.3138458043802308, 0.9339589340831895], 
             UndirectedEdge[170, 235] -> 
             RGBColor[
              0.21437654864384317`, 0.34265372325588017`, 0.9355197993523594],
              UndirectedEdge[46, 400] -> 
             RGBColor[
              0.81382584660932, 0.509501659616798, 0.5750314348940344], 
             UndirectedEdge[65, 329] -> 
             RGBColor[
              0.31941652727713654`, 0.4467936244332925, 0.9417310182764805], 
             UndirectedEdge[81, 267] -> 
             RGBColor[
              0.21336000502701669`, 0.3415852714620077, 0.9354619086972226], 
             UndirectedEdge[104, 182] -> 
             RGBColor[
              0.23293840827128548`, 0.36216341461419643`, 0.9365768697983317],
              UndirectedEdge[23, 306] -> 
             RGBColor[
              0.21710981978146196`, 0.345526564520917, 0.9356754551001344], 
             UndirectedEdge[209, 286] -> 
             RGBColor[
              0.29314447532730914`, 0.4242883377578022, 0.9400478236897936], 
             UndirectedEdge[150, 167] -> 
             RGBColor[
              0.2371065726737784, 0.3665444196781035, 0.936814240594807], 
             UndirectedEdge[4, 288] -> 
             RGBColor[
              0.2072894767278965, 0.33520476132590776`, 0.9351162010911295], 
             UndirectedEdge[171, 272] -> 
             RGBColor[
              0.19235235421379315`, 0.3195048984953177, 0.9342655540614437], 
             UndirectedEdge[78, 182] -> 
             RGBColor[
              0.23114667261114863`, 0.3602801868327903, 0.9364748331031223], 
             UndirectedEdge[143, 374] -> 
             RGBColor[
              0.1912700084764235, 0.3183672845006589, 0.9342039160728877], 
             UndirectedEdge[55, 262] -> 
             RGBColor[
              0.5840352729572464, 0.6682969151994234, 0.9627543260164191], 
             UndirectedEdge[165, 190] -> 
             RGBColor[
              0.21884661716031273`, 0.34735204868540315`, 0.9357743631414985],
              UndirectedEdge[2, 149] -> 
             RGBColor[
              0.20607580619388693`, 0.3339291166435074, 0.9350470843496823], 
             UndirectedEdge[39, 47] -> 
             RGBColor[
              0.18958921033534365`, 0.3166006590856267, 0.9341081971052712], 
             UndirectedEdge[230, 300] -> 
             RGBColor[
              0.2086431877242838, 0.3366275974133453, 0.9351932929297377], 
             UndirectedEdge[40, 48] -> 
             RGBColor[
              0.20069384731952558`, 0.3282723366306521, 0.934740589753682], 
             UndirectedEdge[25, 208] -> 
             RGBColor[
              0.3291899186131193, 0.4582247733572693, 0.9422451729560961], 
             UndirectedEdge[32, 52] -> 
             RGBColor[
              0.905256763296387, 0.5780630184234903, 0.500145144132204], 
             UndirectedEdge[161, 366] -> 
             RGBColor[
              0.9364231997374939, 0.7670038596603013, 0.3666668736906492], 
             UndirectedEdge[190, 318] -> 
             RGBColor[
              0.21280458260693721`, 0.34100148728268875`, 0.9354302782120729],
              UndirectedEdge[179, 245] -> 
             RGBColor[
              0.21085364957036085`, 0.33895093296494805`, 0.9353191754617867],
              UndirectedEdge[37, 182] -> 
             RGBColor[
              0.26307956528763465`, 0.3938436816981118, 0.9382933641005669], 
             UndirectedEdge[12, 206] -> 
             RGBColor[
              0.33583694364464667`, 0.4592083134506097, 0.9428435069438263], 
             UndirectedEdge[18, 218] -> 
             RGBColor[
              0.776406098847213, 0.8201699347730458, 0.6937389035902746], 
             UndirectedEdge[92, 119] -> 
             RGBColor[
              0.22208012665594387`, 0.3507506721816547, 0.9359585067237262], 
             UndirectedEdge[215, 400] -> 
             RGBColor[
              0.7640930948428964, 0.47065005595395515`, 0.5700745389769464], 
             UndirectedEdge[71, 292] -> 
             RGBColor[
              0.8945978800262582, 0.5638772618194792, 0.5512331862497395], 
             UndirectedEdge[158, 346] -> 
             RGBColor[
              0.19728326833036003`, 0.3246876018698416, 0.9345463623257486], 
             UndirectedEdge[92, 151] -> 
             RGBColor[
              0.20599136961110498`, 0.33384036844141496`, 0.9350422758112056],
              UndirectedEdge[104, 170] -> 
             RGBColor[
              0.22977658578143667`, 0.35884013870624076`, 0.936396808685032], 
             UndirectedEdge[82, 316] -> 
             RGBColor[
              0.7359499332008539, 0.7936489483339444, 0.9743162695644639], 
             UndirectedEdge[287, 353] -> 
             RGBColor[
              0.9052894000566567, 0.5610593594590743, 0.33598351095262347`], 
             UndirectedEdge[368, 372] -> 
             RGBColor[
              0.1818899475322301, 0.30850824571809776`, 0.9336697354786725], 
             UndirectedEdge[9, 203] -> 
             RGBColor[
              0.4981842108201723, 0.5989222290765547, 0.9551740040370065], 
             UndirectedEdge[17, 384] -> 
             RGBColor[
              0.8806232133780418, 0.49400904252402256`, 0.21977054774648136`],
              UndirectedEdge[82, 310] -> 
             RGBColor[
              0.7931376486603983, 0.5085364648564028, 0.5748575062936936], 
             UndirectedEdge[129, 287] -> 
             RGBColor[
              0.8183275809306592, 0.1418793949960282, 0.16518381823822845`], 
             UndirectedEdge[81, 363] -> 
             RGBColor[
              0.3018408929173706, 0.42850250201273, 0.940723448587576], 
             UndirectedEdge[64, 356] -> 
             RGBColor[
              0.9689844051155808, 0.9726683265613763, 0.7058319664887789], 
             UndirectedEdge[245, 352] -> 
             RGBColor[
              0.1906398234149592, 0.3177049200450192, 0.9341680279659126], 
             UndirectedEdge[87, 232] -> 
             RGBColor[
              0.18860427170948546`, 0.315565426141134, 0.9340521063076146], 
             UndirectedEdge[88, 255] -> 
             RGBColor[
              0.40229233650521606`, 0.5228671349052352, 0.9468546898423349], 
             UndirectedEdge[154, 392] -> 
             RGBColor[
              0.19471742420704347`, 0.3219907370123223, 0.934400241298752], 
             UndirectedEdge[22, 45] -> 
             RGBColor[
              0.24087710963769857`, 0.3705074930930349, 0.9370289670968927], 
             UndirectedEdge[116, 141] -> 
             RGBColor[
              0.29789401265983945`, 0.4260884769462017, 0.9404351748499746], 
             UndirectedEdge[97, 224] -> 
             RGBColor[
              0.3981861519254275, 0.5171684195208632, 0.946960633454442], 
             UndirectedEdge[66, 151] -> 
             RGBColor[
              0.20186975982558952`, 0.3295082952316844, 0.9348075562312959], 
             UndirectedEdge[165, 221] -> 
             RGBColor[
              0.29772616502322835`, 0.42460426174906063`, 0.9404735010185594],
              UndirectedEdge[101, 332] -> 
             RGBColor[
              0.8358893322460044, 0.27686671121426787`, 0.18200097113096422`],
              UndirectedEdge[58, 396] -> 
             RGBColor[
              0.18880077082680655`, 0.315771959172202, 0.9340632966416518], 
             UndirectedEdge[35, 387] -> 
             RGBColor[
              0.1878209095169145, 0.3147420628087102, 0.9340074949896282], 
             UndirectedEdge[198, 266] -> 
             RGBColor[0.74350964112616, 0.79962588641691, 0.9750508465456946],
              UndirectedEdge[188, 264] -> 
             RGBColor[
              0.26789407428573686`, 0.39890403591261847`, 0.9385675432655809],
              UndirectedEdge[119, 151] -> 
             RGBColor[
              0.22370106658388367`, 0.35245438281944674`, 0.9360508168546565],
              UndirectedEdge[247, 400] -> 
             RGBColor[
              0.8197269815986742, 0.15263580175167407`, 0.16652388589831657`],
              UndirectedEdge[305, 361] -> 
             RGBColor[
              0.353816749645949, 0.47989197268582956`, 0.9438020454927423], 
             UndirectedEdge[138, 210] -> 
             RGBColor[
              0.2672929528119248, 0.3982722191303392, 0.9385333102869269], 
             UndirectedEdge[197, 231] -> 
             RGBColor[
              0.19125913163260555`, 0.3183558522481745, 0.9342032966527232], 
             UndirectedEdge[225, 261] -> 
             RGBColor[
              0.19884280647751676`, 0.32632677534293286`, 0.9346351757160992],
              UndirectedEdge[83, 286] -> 
             RGBColor[
              0.6361141683386347, 0.7078159235332517, 0.9547721155282454], 
             UndirectedEdge[19, 238] -> 
             RGBColor[
              0.20019752611767563`, 0.32775067157892607`, 0.9347123249954781],
              UndirectedEdge[62, 117] -> 
             RGBColor[
              0.7751677288121797, 0.821679420316278, 0.8719418433976884], 
             UndirectedEdge[65, 167] -> 
             RGBColor[
              0.30615029923372655`, 0.43284997763222943`, 0.940975526215034], 
             UndirectedEdge[268, 371] -> 
             RGBColor[
              0.1838466718007321, 0.3105648869877775, 0.9337811680310495], 
             UndirectedEdge[172, 192] -> 
             RGBColor[
              0.31894488906729196`, 0.44600858518137365`, 0.9417147525123752],
              UndirectedEdge[52, 353] -> 
             RGBColor[
              0.9911272301605415, 0.9888543711683995, 0.6698997566881519], 
             UndirectedEdge[126, 298] -> 
             RGBColor[
              0.194012535572622, 0.32124985436502457`, 0.9343600989338109], 
             UndirectedEdge[146, 306] -> 
             RGBColor[
              0.2107146293415335, 0.33880481389005895`, 0.9353112584654169], 
             UndirectedEdge[21, 132] -> 
             RGBColor[
              0.1947709663990963, 0.3220470132509409, 0.9344032904473808], 
             UndirectedEdge[89, 162] -> 
             RGBColor[
              0.2137613905296329, 0.342007153074568, 0.9354847670077999], 
             UndirectedEdge[9, 18] -> 
             RGBColor[
              0.8394473584119997, 0.8706756474406323, 0.6991625748728455], 
             UndirectedEdge[255, 360] -> 
             RGBColor[
              0.5184721491114823, 0.6174970812936685, 0.956042445038614], 
             UndirectedEdge[124, 152] -> 
             RGBColor[
              0.2137312689052459, 0.34197549333751603`, 0.935483051625852], 
             UndirectedEdge[88, 389] -> 
             RGBColor[
              0.7117595806289345, 0.7674543626326005, 0.720767374949669], 
             UndirectedEdge[12, 167] -> 
             RGBColor[
              0.2392959832955554, 0.36884562905824225`, 0.9369389242907744], 
             UndirectedEdge[32, 303] -> 
             RGBColor[
              0.857724462248068, 0.3888260026114282, 0.20072238804006853`], 
             UndirectedEdge[49, 261] -> 
             RGBColor[
              0.1864507904031121, 0.31330198074953464`, 0.9339294687330069], 
             UndirectedEdge[283, 360] -> 
             RGBColor[
              0.7973390261209754, 0.7521357532053826, 0.6155512086405578], 
             UndirectedEdge[282, 305] -> 
             RGBColor[
              0.30654149170312617`, 0.4389445203793095, 0.9407897078604948], 
             UndirectedEdge[32, 385] -> 
             RGBColor[
              0.907968224972722, 0.5784385570350095, 0.40100320095353803`], 
             UndirectedEdge[167, 216] -> 
             RGBColor[
              0.22581143984224178`, 0.35467251891937396`, 0.9361709994897025],
              UndirectedEdge[252, 318] -> 
             RGBColor[
              0.20969889594004104`, 0.3377372136838731, 0.9352534139508448], 
             UndirectedEdge[2, 217] -> 
             RGBColor[
              0.20503618363244414`, 0.3328364074155535, 0.9349878793827919], 
             UndirectedEdge[305, 329] -> 
             RGBColor[
              0.28019918973537505`, 0.41183749243956935`, 0.9392683013866509],
              UndirectedEdge[87, 373] -> 
             RGBColor[
              0.19241687464340246`, 0.3195727135576686, 0.9342692284044607], 
             UndirectedEdge[20, 241] -> 
             RGBColor[
              0.33276855688740864`, 0.46007563309772936`, 0.9425189244607857],
              UndirectedEdge[59, 210] -> 
             RGBColor[
              0.23097654198013617`, 0.36010136875269116`, 0.9364651444153718],
              UndirectedEdge[290, 304] -> 
             RGBColor[
              0.2699001201696922, 0.4010125173273108, 0.9386817846109934], 
             UndirectedEdge[115, 312] -> 
             RGBColor[
              0.7514622050621471, 0.7517529361696669, 0.6201411074573389], 
             UndirectedEdge[214, 389] -> 
             RGBColor[
              0.9360223295752915, 0.7653959046667461, 0.35678534949539953`], 
             UndirectedEdge[144, 276] -> 
             RGBColor[
              0.48015124453344243`, 0.5868307576532874, 0.952775625742377], 
             UndirectedEdge[196, 286] -> 
             RGBColor[
              0.5826840049020053, 0.6656063435828412, 0.963342437992916], 
             UndirectedEdge[124, 181] -> 
             RGBColor[
              0.209370470104526, 0.33739201730734614`, 0.9352347105853747], 
             UndirectedEdge[216, 341] -> 
             RGBColor[
              0.2325799518711988, 0.3617866542102568, 0.9365564562366354], 
             UndirectedEdge[294, 340] -> 
             RGBColor[
              0.24056246391472638`, 0.3701767804885, 0.937011048488446], 
             UndirectedEdge[104, 235] -> 
             RGBColor[
              0.20864915250350596`, 0.3366338667744967, 0.9351936326150905], 
             UndirectedEdge[125, 318] -> 
             RGBColor[
              0.20302734583193666`, 0.33072499151954715`, 0.9348734790418622],
              UndirectedEdge[109, 232] -> 
             RGBColor[
              0.18655512715268852`, 0.3134116452886715, 0.9339354105565427], 
             UndirectedEdge[182, 388] -> 
             RGBColor[
              0.2563045573313864, 0.38672271877578024`, 0.9379075374201846], 
             UndirectedEdge[97, 382] -> 
             RGBColor[
              0.3103603612224796, 0.44230450028690405`, 0.9410311290958356], 
             UndirectedEdge[140, 147] -> 
             RGBColor[
              0.32678087214865287`, 0.45177394646584723`, 0.9422514665551494],
              UndirectedEdge[59, 300] -> 
             RGBColor[
              0.20621668709807878`, 0.3340771914061782, 0.9350551073087614], 
             UndirectedEdge[205, 373] -> 
             RGBColor[
              0.19156946915989134`, 0.31868203666588757`, 0.9342209699157987],
              UndirectedEdge[215, 259] -> 
             RGBColor[
              0.8007477962042493, 0.8448792898490222, 0.9806129038326282], 
             UndirectedEdge[136, 300] -> 
             RGBColor[
              0.18939860406094253`, 0.3164003198060953, 0.9340973423599207], 
             UndirectedEdge[152, 245] -> 
             RGBColor[
              0.19786899137363773`, 0.3253032339253123, 0.9345797183865636], 
             UndirectedEdge[44, 128] -> 
             RGBColor[
              0.26610768174908467`, 0.39702642409276845`, 0.9384658108533496],
              UndirectedEdge[241, 392] -> 
             RGBColor[
              0.24198676846575243`, 0.37167381487775275`, 0.9370921605255572],
              UndirectedEdge[240, 342] -> 
             RGBColor[
              0.18286346184170274`, 0.30953147098172573`, 0.9337251756784115],
              UndirectedEdge[123, 214] -> 
             RGBColor[
              0.8610395973659686, 0.437913767929313, 0.20482132414069976`], 
             UndirectedEdge[125, 274] -> 
             RGBColor[
              0.19786901158433057`, 0.32530325516803194`, 0.9345797195375327],
              UndirectedEdge[298, 373] -> 
             RGBColor[
              0.20172543232639267`, 0.32935659787913657`, 0.93479933699373], 
             UndirectedEdge[119, 350] -> 
             RGBColor[
              0.2941675459212899, 0.42283940615857285`, 0.9401985109723265], 
             UndirectedEdge[22, 179] -> 
             RGBColor[
              0.2344230766191157, 0.3637238951811761, 0.9366614194643705], 
             UndirectedEdge[1, 183] -> 
             RGBColor[
              0.18524860197516257`, 0.312038404488611, 0.9338610058805135], 
             UndirectedEdge[112, 260] -> 
             RGBColor[
              0.18468581634927816`, 0.3114468811131368, 0.9338289560716861], 
             UndirectedEdge[183, 270] -> 
             RGBColor[
              0.198314467229445, 0.32577145729456636`, 0.9346050875775294], 
             UndirectedEdge[152, 181] -> 
             RGBColor[
              0.1964830766390266, 0.32384654966716653`, 0.9345007925927047], 
             UndirectedEdge[169, 276] -> 
             RGBColor[
              0.41815198956691846`, 0.5364969694368562, 0.947894817280658], 
             UndirectedEdge[349, 355] -> 
             RGBColor[
              0.20327760071832918`, 0.33098802527222193`, 0.9348877306874234],
              UndirectedEdge[171, 240] -> 
             RGBColor[
              0.18369308464468964`, 0.3104034571487888, 0.9337724214697247], 
             UndirectedEdge[114, 132] -> 
             RGBColor[
              0.1897759122485969, 0.31679689463404087`, 0.9341188295030303], 
             UndirectedEdge[17, 222] -> 
             RGBColor[
              0.88937458998013, 0.5883335736307327, 0.570901233962067], 
             UndirectedEdge[46, 259] -> 
             RGBColor[
              0.850480547970673, 0.8837308935118651, 0.9855697997497163], 
             UndirectedEdge[13, 79] -> 
             RGBColor[
              0.20620705634176517`, 0.33406706887066745`, 0.9350545588514367],
              UndirectedEdge[146, 311] -> 
             RGBColor[
              0.20086274150294195`, 0.3284498551259324, 0.9347502080275711], 
             UndirectedEdge[44, 275] -> 
             RGBColor[
              0.21122882729611786`, 0.33934526854236047`, 0.9353405412782427],
              UndirectedEdge[193, 195] -> 
             RGBColor[
              0.6312732042379722, 0.7079049527832757, 0.9663404032043308], 
             UndirectedEdge[86, 297] -> 
             RGBColor[
              0.28232965171394053`, 0.4140767430581329, 0.9393896280445941], 
             UndirectedEdge[197, 392] -> 
             RGBColor[
              0.19718685275102665`, 0.3245862629828614, 0.9345408716011396], 
             UndirectedEdge[217, 392] -> 
             RGBColor[
              0.20565454435776198`, 0.333486343744197, 0.935023094111316], 
             UndirectedEdge[101, 193] -> 
             RGBColor[
              0.8459509404020927, 0.6447383034706259, 0.5918610769410064], 
             UndirectedEdge[216, 340] -> 
             RGBColor[
              0.2436041993290528, 0.3733738372661213, 0.9371842708204476], 
             UndirectedEdge[125, 190] -> 
             RGBColor[
              0.20237543357367466`, 0.3300397904024893, 0.934836353603172], 
             UndirectedEdge[99, 276] -> 
             RGBColor[
              0.6406056746670367, 0.7137792263922267, 0.9679520038982681], 
             UndirectedEdge[27, 63] -> 
             RGBColor[
              0.1971785692903057, 0.32457755654044196`, 0.9345403998703059], 
             UndirectedEdge[184, 226] -> 
             RGBColor[
              0.20272879549405032`, 0.3304111961852439, 0.9348564770417853], 
             UndirectedEdge[107, 211] -> 
             RGBColor[
              0.2277850924450354, 0.3567469529417126, 0.9362833960856742], 
             UndirectedEdge[216, 294] -> 
             RGBColor[
              0.21277466253925434`, 0.3409700393945122, 0.9354285743084811], 
             UndirectedEdge[68, 284] -> 
             RGBColor[
              0.7807346086845934, 0.8286481739482061, 0.9787765120052747], 
             UndirectedEdge[89, 359] -> 
             RGBColor[
              0.2789577626844565, 0.40896611709023306`, 0.9392549632713296], 
             UndirectedEdge[23, 267] -> 
             RGBColor[
              0.20474185831720654`, 0.33252705284793593`, 0.9349711179915043],
              UndirectedEdge[140, 242] -> 
             RGBColor[
              0.3733726074427579, 0.4978183191391804, 0.9450119502791875], 
             UndirectedEdge[64, 214] -> 
             RGBColor[
              0.9357533158900353, 0.7648205115954387, 0.32750487001527717`], 
             UndirectedEdge[296, 367] -> 
             RGBColor[
              0.18258473603098674`, 0.3092385124824261, 0.9337093026558292], 
             UndirectedEdge[275, 346] -> 
             RGBColor[
              0.1987852081376144, 0.3262662358357499, 0.9346318955758508], 
             UndirectedEdge[301, 305] -> 
             RGBColor[
              0.27396377293596785`, 0.4052836740351331, 0.9389132036243971], 
             UndirectedEdge[81, 119] -> 
             RGBColor[
              0.2344729010553813, 0.363776263822743, 0.9366642568923073], 
             UndirectedEdge[327, 355] -> 
             RGBColor[
              0.19695189529636073`, 0.3243393078008444, 0.9345274911216848], 
             UndirectedEdge[317, 344] -> 
             RGBColor[
              0.19003331843460333`, 0.31706744485602845`, 0.9341334884045249],
              UndirectedEdge[184, 190] -> 
             RGBColor[
              0.21285282401079259`, 0.34105219205682236`, 0.9354330254886557],
              UndirectedEdge[10, 303] -> 
             RGBColor[
              0.8684485783796092, 0.4712562585361081, 0.21099181375878928`], 
             UndirectedEdge[149, 268] -> 
             RGBColor[
              0.19899317290676588`, 0.326484819993856, 0.9346437388617977], 
             UndirectedEdge[38, 267] -> 
             RGBColor[
              0.22814489442186137`, 0.3571251276321197, 0.9363038862759752], 
             UndirectedEdge[253, 366] -> 
             RGBColor[
              0.9092462276793383, 0.5913616030865398, 0.3419442339894627], 
             UndirectedEdge[165, 355] -> 
             RGBColor[
              0.2168405199897158, 0.34524351336519876`, 0.9356601188753879], 
             UndirectedEdge[339, 340] -> 
             RGBColor[
              0.326674769743479, 0.4539173667672604, 0.9421628597566036], 
             UndirectedEdge[185, 318] -> 
             RGBColor[
              0.20300306708120197`, 0.33069947301316327`, 0.9348720964029251],
              UndirectedEdge[36, 70] -> 
             RGBColor[
              0.22130912604082534`, 0.3499403016509027, 0.9359145993792883], 
             UndirectedEdge[69, 131] -> 
             RGBColor[
              0.693464422361174, 0.75939366397809, 0.9708100489116116], 
             UndirectedEdge[283, 312] -> 
             RGBColor[
              0.7398695405352704, 0.7057918843470511, 0.6108133774642039], 
             UndirectedEdge[75, 330] -> 
             RGBColor[
              0.18530504232011252`, 0.31209772686967785`, 0.9338642200746624],
              UndirectedEdge[169, 222] -> 
             RGBColor[
              0.7041731063901011, 0.7666519834125803, 0.9590482629072343], 
             UndirectedEdge[90, 246] -> 
             RGBColor[
              0.21613530957472, 0.3445022925061154, 0.9356199581855191], 
             UndirectedEdge[62, 362] -> 
             RGBColor[
              0.8915373797700097, 0.913872404880224, 0.882662516799504], 
             UndirectedEdge[158, 374] -> 
             RGBColor[
              0.1873884527454699, 0.3142875233225789, 0.9339828672162569], 
             UndirectedEdge[82, 172] -> 
             RGBColor[
              0.5696909718954926, 0.6577404259092337, 0.9610497684809419], 
             UndirectedEdge[306, 346] -> 
             RGBColor[
              0.21286307171561503`, 0.3410629630443328, 0.9354336090802852], 
             UndirectedEdge[53, 188] -> 
             RGBColor[
              0.33920701496392514`, 0.465180569896386, 0.9429464497347737], 
             UndirectedEdge[84, 190] -> 
             RGBColor[
              0.21321988075352158`, 0.3414379919661722, 0.9354539288271424], 
             UndirectedEdge[78, 96] -> 
             RGBColor[
              0.2160474978393337, 0.3444099968046388, 0.9356149574370947], 
             UndirectedEdge[46, 199] -> 
             RGBColor[
              0.8971361136435547, 0.9188102209856679, 0.9087966349847089], 
             UndirectedEdge[159, 265] -> 
             RGBColor[
              0.19056897353088317`, 0.3176304523247132, 0.9341639931698273], 
             UndirectedEdge[332, 356] -> 
             RGBColor[
              0.8815942394619314, 0.5483248554027244, 0.5710094405269136], 
             UndirectedEdge[199, 222] -> 
             RGBColor[
              0.9699116219534045, 0.9763258350817114, 0.9020107810264453], 
             UndirectedEdge[114, 300] -> 
             RGBColor[
              0.19141939910096473`, 0.3185243035189643, 0.9342124236479517], 
             UndirectedEdge[139, 213] -> 
             RGBColor[
              0.3161784578429658, 0.4481129729732145, 0.941373691457378], 
             UndirectedEdge[106, 369] -> 
             RGBColor[
              0.18346224485360668`, 0.3101608298922725, 0.9337592754851194], 
             UndirectedEdge[109, 114] -> 
             RGBColor[
              0.18471405231964982`, 0.3114765589082613, 0.9338305640684275], 
             UndirectedEdge[58, 245] -> 
             RGBColor[
              0.1940488178607217, 0.32128798935024727`, 0.9343621651564433], 
             UndirectedEdge[151, 317] -> 
             RGBColor[
              0.1980582216182819, 0.3255021269103238, 0.9345904947690551], 
             UndirectedEdge[99, 218] -> 
             RGBColor[
              0.7312212189545854, 0.7893616865114603, 0.9745283770409688], 
             UndirectedEdge[55, 57] -> 
             RGBColor[
              0.5760181454967422, 0.6613528823456771, 0.9622434817439033], 
             UndirectedEdge[247, 287] -> 
             RGBColor[
              0.8173288724441594, 0.1342028839319411, 0.1642274538636763], 
             UndirectedEdge[44, 66] -> 
             RGBColor[
              0.21222031867993352`, 0.3403873888509353, 0.9353970052457711], 
             UndirectedEdge[116, 290] -> 
             RGBColor[
              0.24877546734729164`, 0.3788091678306199, 0.9374787668838809], 
             UndirectedEdge[278, 367] -> 
             RGBColor[
              0.18709347932173553`, 0.31397748755183885`, 0.9339660689161493],
              UndirectedEdge[102, 297] -> 
             RGBColor[
              0.32279739953618347`, 0.45288594084814915`, 0.9418305958510031],
              UndirectedEdge[104, 187] -> 
             RGBColor[
              0.2201981756238625, 0.34877262232435, 0.935851332396546], 
             UndirectedEdge[136, 371] -> 
             RGBColor[
              0.1813347042579621, 0.3079246498323852, 0.9336381151956117], 
             UndirectedEdge[80, 302] -> 
             RGBColor[
              0.1989040089899044, 0.3263911030639157, 0.9346386611086387], 
             UndirectedEdge[176, 373] -> 
             RGBColor[
              0.192094835712424, 0.3192342302227627, 0.9342508887637553], 
             UndirectedEdge[112, 219] -> 
             RGBColor[
              0.17968380010062157`, 0.30618944488965105`, 0.933544098646145], 
             UndirectedEdge[33, 179] -> 
             RGBColor[
              0.23670129905445042`, 0.3661184514083582, 0.9367911608617348], 
             UndirectedEdge[123, 334] -> 
             RGBColor[
              0.9016847000711192, 0.6050909598648562, 0.2444456182077174], 
             UndirectedEdge[94, 307] -> 
             RGBColor[
              0.17906784709075121`, 0.30554203922260087`, 0.9335090210334537],
              UndirectedEdge[73, 89] -> 
             RGBColor[
              0.21536881746289013`, 0.3436966606981754, 0.9355763075936738], 
             UndirectedEdge[267, 311] -> 
             RGBColor[
              0.20008010519765723`, 0.3276272547470704, 0.9347056380477918], 
             UndirectedEdge[52, 391] -> 
             RGBColor[
              0.904614436704831, 0.5731258147714826, 0.49953005146272567`], 
             UndirectedEdge[105, 271] -> 
             RGBColor[
              0.9026525217316504, 0.5714728168582255, 0.530015287474555], 
             UndirectedEdge[187, 377] -> 
             RGBColor[
              0.2355206370031677, 0.36487750073416236`, 0.9367239239045473], 
             UndirectedEdge[58, 124] -> 
             RGBColor[
              0.20991109539232988`, 0.337960248762451, 0.9352654983957317], 
             UndirectedEdge[11, 54] -> 
             RGBColor[
              0.9107233154962703, 0.8671374351819781, 0.6324945514745149], 
             UndirectedEdge[115, 283] -> 
             RGBColor[
              0.9435152073287729, 0.813763650039597, 0.2734092138294835], 
             UndirectedEdge[292, 362] -> 
             RGBColor[
              0.8053813952545528, 0.4938474279364584, 0.5730644519337977], 
             UndirectedEdge[15, 154] -> 
             RGBColor[
              0.18425132424679044`, 0.31099020236503183`, 0.933804212389223], 
             UndirectedEdge[158, 311] -> 
             RGBColor[
              0.19686826327665763`, 0.3242514052455602, 0.9345227284018851], 
             UndirectedEdge[123, 253] -> 
             RGBColor[
              0.8341751047564834, 0.26369040755053386`, 0.1803594249510559], 
             UndirectedEdge[236, 376] -> 
             RGBColor[
              0.397907468442853, 0.5154535439144465, 0.9470741986312354], 
             UndirectedEdge[206, 386] -> 
             RGBColor[
              0.3854076478953393, 0.5082424662804851, 0.9457788124146576], 
             UndirectedEdge[74, 338] -> 
             RGBColor[
              0.22933498443170014`, 0.35837598768852497`, 0.9363716601414551],
              UndirectedEdge[293, 394] -> 
             RGBColor[
              0.3358774325095808, 0.4653418831743506, 0.9426227908881267], 
             UndirectedEdge[41, 381] -> 
             RGBColor[
              0.19207190760239157`, 0.31921013132539244`, 0.934249583041808], 
             UndirectedEdge[59, 328] -> 
             RGBColor[
              0.22381201159438807`, 0.3525709930598068, 0.9360571350088763], 
             UndirectedEdge[123, 196] -> 
             RGBColor[
              0.8436412079731275, 0.6056407490965849, 0.5869779142171753], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.9124649507944522, 0.7523588106461282, 0.5992692091287142], 
             UndirectedEdge[23, 38] -> 
             RGBColor[
              0.23532272116707456`, 0.36466947864183974`, 0.936712652890472], 
             UndirectedEdge[61, 282] -> 
             RGBColor[
              0.2661448795948803, 0.3964851197604022, 0.9384891805623623], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.2249471629490288, 0.3537641091062871, 0.9361217801992172], 
             UndirectedEdge[3, 232] -> 
             RGBColor[
              0.21328768495463646`, 0.3415092584805786, 0.9354577901760884], 
             UndirectedEdge[110, 362] -> 
             RGBColor[
              0.8221167873663267, 0.8612297040031928, 0.982833840996466], 
             UndirectedEdge[125, 252] -> 
             RGBColor[
              0.19926974690677848`, 0.32677551680367367`, 0.934659489341944], 
             UndirectedEdge[49, 327] -> 
             RGBColor[
              0.18473066760764006`, 0.3114940226294092, 0.9338315102844983], 
             UndirectedEdge[89, 291] -> 
             RGBColor[
              0.2138432095506144, 0.34209315005324514`, 0.9354894264800044], 
             UndirectedEdge[34, 250] -> 
             RGBColor[
              0.1883288985198916, 0.31527599145920215`, 0.9340364242118455], 
             UndirectedEdge[125, 226] -> 
             RGBColor[
              0.1922514050569324, 0.3193987945309108, 0.9342598051563016], 
             UndirectedEdge[3, 14] -> 
             RGBColor[
              0.28743237026540935`, 0.41667525783150516`, 0.9397814519424676],
              UndirectedEdge[105, 345] -> 
             RGBColor[
              0.9066930101053883, 0.9269728190997042, 0.9383535848392048], 
             UndirectedEdge[88, 336] -> 
             RGBColor[
              0.33259846324686315`, 0.4556650882287947, 0.9426641835505155], 
             UndirectedEdge[162, 357] -> 
             RGBColor[
              0.1906502583880034, 0.3177158878633042, 0.9341686222221902], 
             UndirectedEdge[279, 328] -> 
             RGBColor[
              0.215194282730263, 0.3435132136280431, 0.9355663680988517], 
             UndirectedEdge[312, 359] -> 
             RGBColor[
              0.4367530973615871, 0.5501494570425497, 0.9497594529493274], 
             UndirectedEdge[202, 289] -> 
             RGBColor[
              0.4009029468034172, 0.5210963292936249, 0.9469229296248474], 
             UndirectedEdge[27, 48] -> 
             RGBColor[
              0.20648582903789775`, 0.33436007664951256`, 0.9350704345440743],
              UndirectedEdge[115, 193] -> 
             RGBColor[
              0.8965180032601808, 0.866664933881647, 0.6335702357029284], 
             UndirectedEdge[117, 385] -> 
             RGBColor[
              0.776474593776608, 0.8214741220909348, 0.7960777027150834], 
             UndirectedEdge[179, 352] -> 
             RGBColor[
              0.20659936567779108`, 0.3344794108566792, 0.9350769002877538], 
             UndirectedEdge[8, 365] -> 
             RGBColor[
              0.2808078228071327, 0.4124772043875522, 0.9393029621396956], 
             UndirectedEdge[105, 353] -> 
             RGBColor[
              0.9892810453920724, 0.988090926321853, 0.7004958160747115], 
             UndirectedEdge[231, 392] -> 
             RGBColor[
              0.1971344084334818, 0.32453114067996, 0.9345378849748398], 
             UndirectedEdge[109, 132] -> 
             RGBColor[
              0.1878121680467173, 0.3147328749692917, 0.9340069971758325], 
             UndirectedEdge[23, 158] -> 
             RGBColor[
              0.20153001639620693`, 0.3291512033464258, 0.9347882083455978], 
             UndirectedEdge[105, 350] -> 
             RGBColor[
              0.6669237794423443, 0.7322521297415084, 0.9183362922108259], 
             UndirectedEdge[172, 351] -> 
             RGBColor[
              0.3445890788111915, 0.47288747334073133`, 0.943177889287059], 
             UndirectedEdge[34, 375] -> 
             RGBColor[
              0.19286667153168213`, 0.3200454786060204, 0.9342948436718334], 
             UndirectedEdge[32, 391] -> 
             RGBColor[
              0.8208765397934485, 0.16147180977632267`, 0.16762470412387276`],
              UndirectedEdge[140, 241] -> 
             RGBColor[
              0.343629032390773, 0.46948243111537313`, 0.9432109443563187], 
             UndirectedEdge[89, 336] -> 
             RGBColor[
              0.23351345559029374`, 0.36276782580657996`, 0.9366096178924429],
              UndirectedEdge[74, 118] -> 
             RGBColor[
              0.3029906205258713, 0.4312899550504897, 0.9407311083477143], 
             UndirectedEdge[138, 328] -> 
             RGBColor[
              0.2601284224261766, 0.3907418434374549, 0.9381253008804314], 
             UndirectedEdge[189, 207] -> 
             RGBColor[
              0.2123454769342431, 0.3405189381117063, 0.935404132823199], 
             UndirectedEdge[273, 281] -> 
             RGBColor[
              0.46139853851670076`, 0.5721415288193888, 0.9511515046102453], 
             UndirectedEdge[49, 225] -> 
             RGBColor[
              0.19609003670444464`, 0.3234334397757498, 0.9344784095498806], 
             UndirectedEdge[43, 159] -> 
             RGBColor[
              0.1884193222929882, 0.31537103257792504`, 0.9340415737119533], 
             UndirectedEdge[113, 368] -> 
             RGBColor[
              0.18474082389280244`, 0.3115046975290605, 0.9338320886699134], 
             UndirectedEdge[11, 83] -> 
             RGBColor[0.9120888802991098, 0.9323447493793293, 0.977810506555],
              UndirectedEdge[151, 344] -> 
             RGBColor[
              0.1995874063553662, 0.3271093970249116, 0.9346775795776059], 
             UndirectedEdge[182, 377] -> 
             RGBColor[
              0.2482608696505907, 0.3782682930240088, 0.9374494613063329], 
             UndirectedEdge[198, 203] -> 
             RGBColor[
              0.5694035624452959, 0.6546305646490294, 0.9622535793690412], 
             UndirectedEdge[208, 395] -> 
             RGBColor[
              0.366549438606146, 0.4905837118311563, 0.9446256885343254], 
             UndirectedEdge[305, 339] -> 
             RGBColor[
              0.3400084902177303, 0.4679319523924049, 0.9429221954121405], 
             UndirectedEdge[9, 313] -> 
             RGBColor[
              0.4854882204226317, 0.5856947625868548, 0.9544467086526902], 
             UndirectedEdge[267, 317] -> 
             RGBColor[
              0.1930340826347562, 0.32022143828982824`, 0.9343043774864909], 
             UndirectedEdge[306, 350] -> 
             RGBColor[
              0.2854226113571807, 0.41364792547081863`, 0.9397004998858718], 
             UndirectedEdge[111, 362] -> 
             RGBColor[
              0.8089414952642664, 0.5212119166568898, 0.5764736077236575], 
             UndirectedEdge[104, 261] -> 
             RGBColor[
              0.20662637490864183`, 0.3345077992707875, 0.9350784384234943], 
             UndirectedEdge[243, 363] -> 
             RGBColor[
              0.302959879941956, 0.42967862832344433`, 0.9407871732432331], 
             UndirectedEdge[154, 369] -> 
             RGBColor[
              0.183389073095449, 0.31008392173509136`, 0.9337551084617403], 
             UndirectedEdge[218, 282] -> 
             RGBColor[
              0.4376499441056336, 0.5505879476107286, 0.9499100761220066], 
             UndirectedEdge[7, 293] -> 
             RGBColor[
              0.28453912176058604`, 0.41590127160719004`, 0.9395336796939777],
              UndirectedEdge[24, 167] -> 
             RGBColor[
              0.24799412206051685`, 0.37798792439406714`, 0.9374342704256958],
              UndirectedEdge[326, 363] -> 
             RGBColor[
              0.3080486907375876, 0.43502729111889293`, 0.9410769734898234], 
             UndirectedEdge[276, 282] -> 
             RGBColor[
              0.3470343998180849, 0.475005487491495, 0.9433337029793059], 
             UndirectedEdge[337, 345] -> 
             RGBColor[
              0.8925314756364031, 0.9165956294995268, 0.9705858474056119], 
             UndirectedEdge[107, 124] -> 
             RGBColor[
              0.22484989821780513`, 0.3536618777068309, 0.9361162411166642], 
             UndirectedEdge[128, 227] -> 
             RGBColor[
              0.28894688934847723`, 0.42103187936912945`, 0.9397664699385552],
              UndirectedEdge[25, 365] -> 
             RGBColor[
              0.33498940880084865`, 0.4643204052534886, 0.9425754453427104], 
             UndirectedEdge[97, 363] -> 
             RGBColor[
              0.3365752811245841, 0.4650105463059218, 0.9427015206110543], 
             UndirectedEdge[13, 373] -> 
             RGBColor[
              0.2056740334145861, 0.3335068279785967, 0.9350242039842707], 
             UndirectedEdge[64, 195] -> 
             RGBColor[
              0.7086017617355334, 0.7643768316855696, 0.6913028233561538], 
             UndirectedEdge[77, 96] -> 
             RGBColor[
              0.20429069166020342`, 0.3320528480858075, 0.9349454247178293], 
             UndirectedEdge[6, 53] -> 
             RGBColor[
              0.6643840547861006, 0.7335496374888852, 0.969847038397682], 
             UndirectedEdge[216, 343] -> 
             RGBColor[
              0.20826813355084325`, 0.33623339169725125`, 0.9351719341494034],
              UndirectedEdge[26, 324] -> 
             RGBColor[
              0.1839722969253371, 0.31069692695883033`, 0.9337883221960501], 
             UndirectedEdge[142, 281] -> 
             RGBColor[
              0.436455413320613, 0.55189157611022, 0.9491878904251312], 
             UndirectedEdge[100, 341] -> 
             RGBColor[
              0.3185278490681524, 0.4448223795517722, 0.9417183858910539], 
             UndirectedEdge[115, 364] -> 
             RGBColor[
              0.9382231077008898, 0.7927822385027005, 0.26915106624734497`], 
             UndirectedEdge[150, 152] -> 
             RGBColor[
              0.21962526952820027`, 0.3481704616934645, 0.9358187062419367], 
             UndirectedEdge[10, 68] -> 
             RGBColor[
              0.8322857283076943, 0.5959292773686855, 0.5858125997101122], 
             UndirectedEdge[190, 288] -> 
             RGBColor[
              0.21294330855938015`, 0.3411472970544397, 0.9354381784498378], 
             UndirectedEdge[23, 146] -> 
             RGBColor[
              0.20552449462249126`, 0.333349653226798, 0.9350156879712836], 
             UndirectedEdge[188, 201] -> 
             RGBColor[
              0.47076164268683474`, 0.5730017553920743, 0.9531670568538995], 
             UndirectedEdge[148, 382] -> 
             RGBColor[
              0.2893244860141426, 0.42019446169141983`, 0.9398331671225094], 
             UndirectedEdge[14, 71] -> 
             RGBColor[
              0.6541765961305002, 0.7223342652348994, 0.9394835143282855], 
             UndirectedEdge[228, 276] -> 
             RGBColor[
              0.3015266164865197, 0.4277543234766833, 0.9407208506945814], 
             UndirectedEdge[56, 174] -> 
             RGBColor[
              0.4681168777823908, 0.5781139671930625, 0.9515372200266019], 
             UndirectedEdge[16, 182] -> 
             RGBColor[
              0.23539065510704868`, 0.36474088152001305`, 0.9367165216278543],
              UndirectedEdge[104, 192] -> 
             RGBColor[
              0.24115781649194606`, 0.3708025337946915, 0.9370449529369735], 
             UndirectedEdge[145, 395] -> 
             RGBColor[
              0.3442769835307749, 0.46717394939172724`, 0.9433573051669275], 
             UndirectedEdge[219, 251] -> 
             RGBColor[
              0.1819264333571092, 0.30854659463338063`, 0.9336718132924233], 
             UndirectedEdge[150, 179] -> 
             RGBColor[
              0.23260992772492337`, 0.36181816073310025`, 0.9365581633171598],
              UndirectedEdge[73, 207] -> 
             RGBColor[
              0.1950145063297256, 0.32230298915935574`, 0.934417159686145], 
             UndirectedEdge[265, 325] -> 
             RGBColor[
              0.2186342581575027, 0.34712884590911136`, 0.9357622696104455], 
             UndirectedEdge[39, 314] -> 
             RGBColor[
              0.19046396107769498`, 0.3175200775782383, 0.9341580128659703], 
             UndirectedEdge[20, 263] -> 
             RGBColor[
              0.3432288815576954, 0.4710700975490908, 0.943114624476095], 
             UndirectedEdge[66, 146] -> 
             RGBColor[
              0.19762825714734855`, 0.3250502069900508, 0.9345660089285108], 
             UndirectedEdge[7, 21] -> 
             RGBColor[
              0.22580819870592864`, 0.3546691122796089, 0.9361708149117844], 
             UndirectedEdge[107, 167] -> 
             RGBColor[
              0.22944380789788385`, 0.3584903680512903, 0.9363778574768644], 
             UndirectedEdge[120, 195] -> 
             RGBColor[
              0.41858299206596217`, 0.5369772819597975, 0.9478927160094046], 
             UndirectedEdge[365, 388] -> 
             RGBColor[
              0.2883992345699991, 0.4204562594736305, 0.9397352818091035], 
             UndirectedEdge[134, 342] -> 
             RGBColor[
              0.18275455563161122`, 0.309417003649867, 0.9337189736308591], 
             UndirectedEdge[227, 311] -> 
             RGBColor[
              0.23829401063491945`, 0.3677924922631779, 0.9368818634300369], 
             UndirectedEdge[78, 377] -> 
             RGBColor[
              0.2375799153602678, 0.3670419328532635, 0.9368411967605548], 
             UndirectedEdge[21, 370] -> 
             RGBColor[
              0.19110729661804693`, 0.31819626402097745`, 0.9341946498732637],
              UndirectedEdge[2, 230] -> 
             RGBColor[
              0.2114753909347174, 0.33960442255956613`, 0.9353545827127028], 
             UndirectedEdge[24, 203] -> 
             RGBColor[
              0.2850956592214299, 0.4168671679331099, 0.9395514255934152], 
             UndirectedEdge[54, 206] -> 
             RGBColor[
              0.6885711015156095, 0.68922695188861, 0.6128856824256679], 
             UndirectedEdge[66, 130] -> 
             RGBColor[
              0.20589531196195676`, 0.3337394057617535, 0.9350368054701912], 
             UndirectedEdge[101, 356] -> 
             RGBColor[
              0.8996786533554004, 0.687329585228627, 0.5883270956947237], 
             UndirectedEdge[222, 383] -> 
             RGBColor[
              0.6547025238599551, 0.723910051109828, 0.9558664767641599], 
             UndirectedEdge[31, 247] -> 
             RGBColor[
              0.9007985668118983, 0.5610186106560575, 0.5373898372859729], 
             UndirectedEdge[46, 333] -> 
             RGBColor[
              0.8796565038002286, 0.9065288389378603, 0.9721902291244133], 
             UndirectedEdge[287, 385] -> 
             RGBColor[
              0.9058682917802197, 0.5622975503208443, 0.39899230255686247`], 
             UndirectedEdge[42, 330] -> 
             RGBColor[
              0.18629301045548374`, 0.31313614402075074`, 0.9339204833984038],
              UndirectedEdge[151, 227] -> 
             RGBColor[
              0.2408020759927813, 0.3704286279748189, 0.937024694041817], 
             UndirectedEdge[36, 382] -> 
             RGBColor[
              0.2838749254794549, 0.4144666280473688, 0.9395228227119613], 
             UndirectedEdge[218, 361] -> 
             RGBColor[
              0.4849252020484565, 0.5915353999172487, 0.952922413754254], 
             UndirectedEdge[196, 334] -> 
             RGBColor[
              0.9021680954325457, 0.8779962725880234, 0.6424622562871629], 
             UndirectedEdge[34, 265] -> 
             RGBColor[
              0.19096709589184307`, 0.31804890416849774`, 0.9341866656493147],
              UndirectedEdge[372, 392] -> 
             RGBColor[
              0.19150446236563495`, 0.31861371040345526`, 0.9342172678750348],
              UndirectedEdge[127, 210] -> 
             RGBColor[
              0.29252473138981117`, 0.4219611356100898, 0.9400738898749681], 
             UndirectedEdge[33, 157] -> 
             RGBColor[
              0.2467253832848012, 0.3766543994981055, 0.9373620176293496], 
             UndirectedEdge[139, 308] -> 
             RGBColor[
              0.25989565930435055`, 0.3904971946383813, 0.9381120453649856], 
             UndirectedEdge[38, 146] -> 
             RGBColor[
              0.2289275307271461, 0.3579477280109817, 0.9363484562557545], 
             UndirectedEdge[55, 68] -> 
             RGBColor[
              0.8126708442680417, 0.8535970039103761, 0.981959617507143], 
             UndirectedEdge[35, 392] -> 
             RGBColor[
              0.19658094676972326`, 0.3239494173798535, 0.934506366151862], 
             UndirectedEdge[51, 126] -> 
             RGBColor[
              0.1918840790772874, 0.31901271163649164`, 0.9342388864851707], 
             UndirectedEdge[130, 243] -> 
             RGBColor[
              0.22352868317149505`, 0.3522731969232867, 0.9360409998743393], 
             UndirectedEdge[12, 203] -> 
             RGBColor[
              0.2763975204564685, 0.40772487259728496`, 0.9390560794584938], 
             UndirectedEdge[182, 395] -> 
             RGBColor[
              0.3402542515552627, 0.4629458030295253, 0.9431282165320207], 
             UndirectedEdge[99, 382] -> 
             RGBColor[
              0.6121310294998102, 0.6891159199256546, 0.9661376246873524], 
             UndirectedEdge[17, 31] -> 
             RGBColor[
              0.9059600385832136, 0.6006919444617403, 0.5423324684832332], 
             UndirectedEdge[77, 78] -> 
             RGBColor[
              0.20870891214169546`, 0.33669667794321373`, 0.9351970358380788],
              UndirectedEdge[243, 344] -> 
             RGBColor[
              0.2114782278514492, 0.3396074043389222, 0.9353547442709138], 
             UndirectedEdge[305, 313] -> 
             RGBColor[
              0.29133850845533754`, 0.4235456226878492, 0.9399026691086074], 
             UndirectedEdge[189, 280] -> 
             RGBColor[
              0.2210513429116578, 0.3496693552377532, 0.9358999190114381], 
             UndirectedEdge[104, 208] -> 
             RGBColor[
              0.25923359532216883`, 0.3898013234158274, 0.9380743418006362], 
             UndirectedEdge[191, 335] -> 
             RGBColor[
              0.19113672012064215`, 0.3182271899877628, 0.9341963254982084], 
             UndirectedEdge[225, 355] -> 
             RGBColor[
              0.2083112643931653, 0.336278724947185, 0.9351743903870672], 
             UndirectedEdge[308, 348] -> 
             RGBColor[
              0.20697593141094872`, 0.33487520531787435`, 0.9350983451491781],
              UndirectedEdge[132, 149] -> 
             RGBColor[
              0.20160011613108555`, 0.32922488261236305`, 0.9347922004217959],
              UndirectedEdge[128, 224] -> 
             RGBColor[
              0.40082474260241224`, 0.5199417456186857, 0.9471108972900512], 
             UndirectedEdge[192, 225] -> 
             RGBColor[
              0.233374248060821, 0.36262150986683694`, 0.9366016902295785], 
             UndirectedEdge[84, 252] -> 
             RGBColor[
              0.2101141940866254, 0.33817371836735655`, 0.9352770645659143], 
             UndirectedEdge[30, 211] -> 
             RGBColor[
              0.21659401962004457`, 0.3449844258476482, 0.9356460810439997], 
             UndirectedEdge[138, 242] -> 
             RGBColor[
              0.31465187583145326`, 0.4451229547456037, 0.9413374842169753], 
             UndirectedEdge[27, 41] -> 
             RGBColor[
              0.1999138771125005, 0.32745253849010136`, 0.9346961716042546], 
             UndirectedEdge[102, 139] -> 
             RGBColor[
              0.3279891561400408, 0.4583428062151842, 0.9421262587090772], 
             UndirectedEdge[203, 329] -> 
             RGBColor[
              0.28617424693522586`, 0.4180008320067203, 0.9396128495680883], 
             UndirectedEdge[195, 312] -> 
             RGBColor[
              0.48621740603993846`, 0.5929929550712956, 0.9529112749587412], 
             UndirectedEdge[51, 87] -> 
             RGBColor[
              0.1940286984190197, 0.3212668425413722, 0.9343610193840024], 
             UndirectedEdge[83, 366] -> 
             RGBColor[
              0.9721424943326117, 0.9755215245830015, 0.7399924007909114], 
             UndirectedEdge[8, 302] -> 
             RGBColor[
              0.22515004974021374`, 0.353977355987588, 0.936133334301831], 
             UndirectedEdge[146, 344] -> 
             RGBColor[
              0.1953459036771252, 0.3226513087832781, 0.9344360322748211], 
             UndirectedEdge[67, 320] -> 
             RGBColor[
              0.1815572411564681, 0.30815855022236927`, 0.9336507883427678], 
             UndirectedEdge[90, 166] -> 
             RGBColor[
              0.23037172884023532`, 0.35946567179528754`, 0.9364307012017953],
              UndirectedEdge[12, 341] -> 
             RGBColor[
              0.2460644953245124, 0.3759597643491251, 0.9373243810377072], 
             UndirectedEdge[3, 13] -> 
             RGBColor[
              0.2247891692476987, 0.3535980477088099, 0.9361127826916571], 
             UndirectedEdge[153, 341] -> 
             RGBColor[
              0.22749742981872606`, 0.3564446012825976, 0.9362670141246647], 
             UndirectedEdge[192, 351] -> 
             RGBColor[
              0.2839106330866923, 0.41566367352388345`, 0.9394824007008676], 
             UndirectedEdge[12, 150] -> 
             RGBColor[
              0.24059607423843102`, 0.37021210706973123`, 0.937012962546659], 
             UndirectedEdge[99, 393] -> 
             RGBColor[
              0.8120689253181035, 0.8537779307522239, 0.9817268285297311], 
             UndirectedEdge[4, 190] -> 
             RGBColor[
              0.20649883851719153`, 0.33437375043709894`, 0.9350711754146743],
              UndirectedEdge[373, 390] -> 
             RGBColor[
              0.20548402624046883`, 0.3333071183914488, 0.9350133833567951], 
             UndirectedEdge[23, 308] -> 
             RGBColor[
              0.21238372481471685`, 0.3405591390591399, 0.9354063109834092], 
             UndirectedEdge[37, 187] -> 
             RGBColor[
              0.2503393326402117, 0.3804528894082654, 0.9375678266987812], 
             UndirectedEdge[17, 292] -> 
             RGBColor[
              0.8235767865158092, 0.18222708934004583`, 0.17021046343469787`],
              UndirectedEdge[309, 385] -> 
             RGBColor[
              0.845892139078253, 0.8769877648670494, 0.8021186290174642], 
             UndirectedEdge[140, 380] -> 
             RGBColor[
              0.5633644182821813, 0.6539330422248467, 0.9599388244578124], 
             UndirectedEdge[119, 354] -> 
             RGBColor[
              0.21794551615801888`, 0.3464049343988889, 0.9357230467724773], 
             UndirectedEdge[36, 305] -> 
             RGBColor[
              0.2718566625317226, 0.40306896740175535`, 0.9387932068040659], 
             UndirectedEdge[91, 351] -> 
             RGBColor[
              0.45106536887988224`, 0.5613307052601594, 0.9510072153286632], 
             UndirectedEdge[130, 275] -> 
             RGBColor[
              0.2049038205781411, 0.33269728545317867`, 0.934980341502663], 
             UndirectedEdge[46, 102] -> 
             RGBColor[
              0.5772856165740025, 0.6623742905041798, 0.9623565848838942], 
             UndirectedEdge[111, 271] -> 
             RGBColor[
              0.823307418706283, 0.18015661031829988`, 0.16995251651608806`], 
             UndirectedEdge[104, 351] -> 
             RGBColor[
              0.26680200623584566`, 0.3976814219540492, 0.9385080897116571], 
             UndirectedEdge[174, 203] -> 
             RGBColor[
              0.3639226125883841, 0.4896332085668736, 0.9444098049633691], 
             UndirectedEdge[294, 313] -> 
             RGBColor[
              0.24717525119128783`, 0.3771272391910956, 0.937387636941104], 
             UndirectedEdge[206, 266] -> 
             RGBColor[
              0.5435550579217713, 0.6394151913659053, 0.9575592073363473], 
             UndirectedEdge[167, 358] -> 
             RGBColor[
              0.25670178916857006`, 0.3871402346226134, 0.9379301591856604], 
             UndirectedEdge[315, 322] -> 
             RGBColor[
              0.18811052101816012`, 0.31504646285894905`, 0.9340239879361825],
              UndirectedEdge[176, 347] -> 
             RGBColor[
              0.18526445779187303`, 0.3120550699572905, 0.9338619088458187], 
             UndirectedEdge[92, 186] -> 
             RGBColor[
              0.20547576839988674`, 0.33329843887741967`, 0.9350129130849905],
              UndirectedEdge[149, 210] -> 
             RGBColor[
              0.22800345786551077`, 0.3569764688437995, 0.9362958316733276], 
             UndirectedEdge[171, 374] -> 
             RGBColor[
              0.18584495673726414`, 0.3126652111546555, 0.9338949674019874], 
             UndirectedEdge[228, 282] -> 
             RGBColor[
              0.26951575842165965`, 0.40002812713340913`, 0.938681147124779], 
             UndirectedEdge[164, 210] -> 
             RGBColor[
              0.23033673863294363`, 0.3594288948689166, 0.9364287085612534], 
             UndirectedEdge[196, 214] -> 
             RGBColor[
              0.8615229927273951, 0.7108190806524803, 0.6028379622201453], 
             UndirectedEdge[204, 307] -> 
             RGBColor[
              0.17948540198595286`, 0.30598091589196724`, 0.9335328001670183],
              UndirectedEdge[127, 255] -> 
             RGBColor[
              0.35677877005900877`, 0.4834455712278943, 0.9439546056344492], 
             UndirectedEdge[68, 334] -> 
             RGBColor[
              0.8909079727489195, 0.8690177564079877, 0.6413882557335685], 
             UndirectedEdge[16, 269] -> 
             RGBColor[
              0.29117851080203017`, 0.41924857896072276`, 0.9400447358569024],
              UndirectedEdge[68, 337] -> 
             RGBColor[
              0.8892917898500812, 0.9140123919924417, 0.970276843283211], 
             UndirectedEdge[23, 374] -> 
             RGBColor[
              0.19777812141168266`, 0.3252077238338092, 0.9345745434766604], 
             UndirectedEdge[22, 116] -> 
             RGBColor[
              0.24102708216235447`, 0.3706651237252555, 0.9370375078103073], 
             UndirectedEdge[192, 322] -> 
             RGBColor[
              0.2266888241245798, 0.3555947054294877, 0.936220965226608], 
             UndirectedEdge[70, 95] -> 
             RGBColor[
              0.22209777558797966`, 0.3507692223282312, 0.9359595118042963], 
             UndirectedEdge[71, 273] -> 
             RGBColor[
              0.7468748729151091, 0.8007044259307632, 0.9459207863964338], 
             UndirectedEdge[135, 215] -> 
             RGBColor[
              0.5207131115569171, 0.6175984363516078, 0.9569638659378303], 
             UndirectedEdge[161, 283] -> 
             RGBColor[
              0.9057344419097366, 0.6568662450460772, 0.2426421685015519], 
             UndirectedEdge[18, 384] -> 
             RGBColor[
              0.9630602947807589, 0.8804179575228263, 0.3471852898585644], 
             UndirectedEdge[71, 303] -> 
             RGBColor[
              0.9318169667814895, 0.7940843861143203, 0.5846862975193713], 
             UndirectedEdge[32, 353] -> 
             RGBColor[
              0.9073893332491589, 0.5772003661732394, 0.33799440934929903`], 
             UndirectedEdge[188, 281] -> 
             RGBColor[
              0.3372802138863956, 0.4635116716468679, 0.9428236756739168], 
             UndirectedEdge[54, 198] -> 
             RGBColor[
              0.8885256847199983, 0.8494376469396148, 0.6303773216350153], 
             UndirectedEdge[271, 385] -> 
             RGBColor[
              0.9072101681764545, 0.5726118003162909, 0.40027728490932957`], 
             UndirectedEdge[150, 206] -> 
             RGBColor[
              0.33364753302286965`, 0.45690710407047097`, 0.9427188232478589],
              UndirectedEdge[317, 346] -> 
             RGBColor[
              0.19596516131412245`, 0.3233021878229641, 0.9344712980811385], 
             UndirectedEdge[146, 243] -> 
             RGBColor[
              0.21526162835688684`, 0.343583998151584, 0.9355702033326591], 
             UndirectedEdge[91, 316] -> 
             RGBColor[
              0.6523585861658432, 0.7275841393423603, 0.9665060682236928], 
             UndirectedEdge[196, 386] -> 
             RGBColor[
              0.5930257483480736, 0.6745638419646864, 0.9640014047404548], 
             UndirectedEdge[151, 306] -> 
             RGBColor[
              0.21495613201977448`, 0.3432629021316925, 0.9355528057682019], 
             UndirectedEdge[27, 376] -> 
             RGBColor[
              0.24560585367761548`, 0.37547770289867644`, 0.937298262074416], 
             UndirectedEdge[280, 387] -> 
             RGBColor[
              0.19723551682458454`, 0.32463741200965124`, 0.9345436429481366],
              UndirectedEdge[308, 354] -> 
             RGBColor[
              0.20447448662716458`, 0.33224602824935756`, 0.9349558915692975],
              UndirectedEdge[327, 349] -> 
             RGBColor[
              0.19208902000720862`, 0.3192281175478443, 0.934250557567947], 
             UndirectedEdge[60, 108] -> 
             RGBColor[
              0.5066936953729514, 0.6051947855450721, 0.9560957540450186], 
             UndirectedEdge[353, 391] -> 
             RGBColor[
              0.9067470066576029, 0.5722631625212318, 0.3373793166798207], 
             UndirectedEdge[140, 195] -> 
             RGBColor[
              0.4154824656065883, 0.5342917617776789, 0.9476951532051012], 
             UndirectedEdge[17, 18] -> 
             RGBColor[
              0.9100987698336667, 0.6000343504740516, 0.3015369122339562], 
             UndirectedEdge[87, 205] -> 
             RGBColor[
              0.18600119174785296`, 0.31282942405665615`, 0.9339038647547113],
              UndirectedEdge[221, 256] -> 
             RGBColor[
              0.6811078585940378, 0.7429531062730206, 0.8609992027595657], 
             UndirectedEdge[194, 316] -> 
             RGBColor[
              0.5837905900380065, 0.6719175511327584, 0.9611081443956637], 
             UndirectedEdge[16, 37] -> 
             RGBColor[
              0.25664259349321183`, 0.38707801621458926`, 0.9379267880795208],
              UndirectedEdge[252, 288] -> 
             RGBColor[
              0.20983762189248398`, 0.33788302345562404`, 0.9352613141886098],
              UndirectedEdge[60, 353] -> 
             RGBColor[
              0.8501417981315751, 0.8795216745705272, 0.7395911022292926], 
             UndirectedEdge[206, 286] -> 
             RGBColor[
              0.375065904449271, 0.49928496789863985`, 0.9451198456671187], 
             UndirectedEdge[220, 396] -> 
             RGBColor[
              0.18205118127193512`, 0.30867771260133725`, 0.9336789175016247],
              UndirectedEdge[133, 320] -> 
             RGBColor[
              0.18355649439985816`, 0.3102598921411492, 0.9337646428573487], 
             UndirectedEdge[28, 231] -> 
             RGBColor[
              0.19140134234262995`, 0.31850532472108994`, 0.934211395342277], 
             UndirectedEdge[239, 269] -> 
             RGBColor[
              0.4302703250067166, 0.5456389418366184, 0.9490411897361934], 
             UndirectedEdge[212, 239] -> 
             RGBColor[
              0.542458414688152, 0.6394312043737607, 0.9571234599763494], 
             UndirectedEdge[77, 182] -> 
             RGBColor[
              0.21938986643201835`, 0.34792303811395897`, 0.9358053003838569],
              UndirectedEdge[280, 336] -> 
             RGBColor[
              0.22186501043454393`, 0.3505245713938071, 0.9359462561731533], 
             UndirectedEdge[199, 400] -> 
             RGBColor[
              0.9054254853432643, 0.5803013970083357, 0.502576064159955], 
             UndirectedEdge[73, 336] -> 
             RGBColor[
              0.2166564041388005, 0.3450499959322676, 0.9356496337500533], 
             UndirectedEdge[305, 340] -> 
             RGBColor[
              0.2847257211787761, 0.4165951639852536, 0.9395260806559493], 
             UndirectedEdge[259, 350] -> 
             RGBColor[
              0.6219849446227963, 0.6978827145935297, 0.9666587839790601], 
             UndirectedEdge[247, 393] -> 
             RGBColor[
              0.7696552520366986, 0.45850393020932284`, 0.5685799817696936], 
             UndirectedEdge[30, 216] -> 
             RGBColor[
              0.208257693184232, 0.33622241820998533`, 0.93517133958597], 
             UndirectedEdge[291, 387] -> 
             RGBColor[
              0.1905013026165654, 0.3175593259031815, 0.9341601394113672], 
             UndirectedEdge[45, 338] -> 
             RGBColor[
              0.2249286875668965, 0.3537446903082591, 0.9361207280535366], 
             UndirectedEdge[219, 248] -> 
             RGBColor[
              0.1809198934930053, 0.30748865741789405`, 0.933614492336205], 
             UndirectedEdge[158, 354] -> 
             RGBColor[
              0.1936207782086547, 0.3208380925366434, 0.9343377889314861], 
             UndirectedEdge[191, 327] -> 
             RGBColor[
              0.1848862258869851, 0.3116575242439654, 0.9338403690983792], 
             UndirectedEdge[165, 192] -> 
             RGBColor[
              0.24190350365737148`, 0.3715862982848506, 0.9370874187178992], 
             UndirectedEdge[143, 354] -> 
             RGBColor[
              0.1975023339396083, 0.32491785371472337`, 0.9345588377881168], 
             UndirectedEdge[115, 161] -> 
             RGBColor[
              0.9173271064366133, 0.7028272968686928, 0.25196989849468676`], 
             UndirectedEdge[296, 330] -> 
             RGBColor[
              0.18388840354746627`, 0.31060874969954066`, 0.9337835445922895],
              UndirectedEdge[45, 262] -> 
             RGBColor[
              0.30202723660803465`, 0.4296407358190505, 0.9406995556283282], 
             UndirectedEdge[37, 208] -> 
             RGBColor[
              0.289374752338518, 0.42148159049974276`, 0.9397908361028714], 
             UndirectedEdge[306, 348] -> 
             RGBColor[
              0.21170202637769384`, 0.33984263077965143`, 0.9353674892659032],
              UndirectedEdge[189, 263] -> 
             RGBColor[
              0.2675028819703037, 0.39849286798607286`, 0.9385452654419342], 
             UndirectedEdge[2, 50] -> 
             RGBColor[
              0.216476564027812, 0.3448609725730971, 0.935639392121782], 
             UndirectedEdge[241, 331] -> 
             RGBColor[
              0.26094013118712034`, 0.3915950008105146, 0.9381715264935517], 
             UndirectedEdge[135, 213] -> 
             RGBColor[
              0.33038430669065766`, 0.46058401368253077`, 0.9422727737683254],
              UndirectedEdge[49, 349] -> 
             RGBColor[
              0.19105637302960854`, 0.3181427401007867, 0.9341917498502368], 
             UndirectedEdge[256, 319] -> 
             RGBColor[
              0.9123741671932073, 0.6207364120366994, 0.4779545305476905], 
             UndirectedEdge[64, 332] -> 
             RGBColor[
              0.9051950840061846, 0.5622054525470171, 0.2995058419250193], 
             UndirectedEdge[213, 350] -> 
             RGBColor[
              0.33697931492905076`, 0.46629627834387477`, 0.942693001861539], 
             UndirectedEdge[333, 345] -> 
             RGBColor[
              0.8909301311153961, 0.9154013493777207, 0.9732965059821361], 
             UndirectedEdge[53, 201] -> 
             RGBColor[
              0.5341594365329997, 0.6309589682060907, 0.9570952074204189], 
             UndirectedEdge[9, 384] -> 
             RGBColor[
              0.8099718019563749, 0.7646503394906032, 0.6173962103853706], 
             UndirectedEdge[24, 33] -> 
             RGBColor[
              0.2533855843329195, 0.3836546930808141, 0.9377413062261555], 
             UndirectedEdge[20, 359] -> 
             RGBColor[
              0.3551576814248725, 0.48204146573128925`, 0.9438513113001545], 
             UndirectedEdge[35, 291] -> 
             RGBColor[
              0.19278015708719454`, 0.31995454643953136`, 0.9342899168022064],
              UndirectedEdge[316, 351] -> 
             RGBColor[
              0.5108480401165528, 0.6087959957654421, 0.956444390370581], 
             UndirectedEdge[195, 263] -> 
             RGBColor[
              0.3632251652657039, 0.4883898734545258, 0.9443887699919498], 
             UndirectedEdge[67, 200] -> 
             RGBColor[
              0.1867268102524256, 0.3135920951118324, 0.9339451876550904], 
             UndirectedEdge[232, 277] -> 
             RGBColor[
              0.18773724237763328`, 0.31465412334052256`, 0.9340027302698206],
              UndirectedEdge[88, 120] -> 
             RGBColor[
              0.42147179727410705`, 0.5394794198355211, 0.9480767881227974], 
             UndirectedEdge[247, 271] -> 
             RGBColor[
              0.8186707488403941, 0.14451713392738777`, 0.16551243621614334`],
              UndirectedEdge[202, 269] -> 
             RGBColor[
              0.34049741903328384`, 0.46934348329390774`, 0.9429171723441234],
              UndirectedEdge[207, 291] -> 
             RGBColor[
              0.19348889841744987`, 0.3206994785144255, 0.9343302785724756], 
             UndirectedEdge[72, 397] -> 
             RGBColor[
              0.4148581473336097, 0.5334192417760302, 0.947747040377775], 
             UndirectedEdge[200, 298] -> 
             RGBColor[
              0.19975642982426225`, 0.3272870514074283, 0.9346872052141117], 
             UndirectedEdge[233, 389] -> 
             RGBColor[
              0.9817271461205633, 0.9825466050438816, 0.7139976792857294], 
             UndirectedEdge[44, 311] -> 
             RGBColor[
              0.21545480303552692`, 0.34378703698681684`, 0.9355812043448313],
              UndirectedEdge[137, 258] -> 
             RGBColor[
              0.2651486396074914, 0.3960184099951701, 0.9384111948221615], 
             UndirectedEdge[46, 287] -> 
             RGBColor[
              0.8114277374548052, 0.49106874179706506`, 0.572735002859394], 
             UndirectedEdge[84, 274] -> 
             RGBColor[
              0.20871345876417752`, 0.33670145673171487`, 0.935197294761503], 
             UndirectedEdge[270, 357] -> 
             RGBColor[
              0.1969743042117703, 0.32436286099174727`, 0.9345287672762663], 
             UndirectedEdge[44, 344] -> 
             RGBColor[
              0.20993796520971017`, 0.3379884906441625, 0.9352670285920812], 
             UndirectedEdge[44, 383] -> 
             RGBColor[
              0.29331549171916627`, 0.4210403283755737, 0.9401830698485728], 
             UndirectedEdge[193, 364] -> 
             RGBColor[
              0.8796332391054209, 0.7997224705221349, 0.619984358127655], 
             UndirectedEdge[43, 375] -> 
             RGBColor[
              0.19874644987833204`, 0.3262254984478285, 0.9346296883503225], 
             UndirectedEdge[184, 252] -> 
             RGBColor[
              0.20974713734389644`, 0.3377879184580067, 0.9352561612274277], 
             UndirectedEdge[16, 78] -> 
             RGBColor[
              0.22470970081672578`, 0.3535145213492678, 0.9361082570820762], 
             UndirectedEdge[345, 353] -> 
             RGBColor[
              0.9106717648266294, 0.9268736116959997, 0.7456067906697404], 
             UndirectedEdge[167, 203] -> 
             RGBColor[
              0.2729080188918158, 0.40405718520565725`, 0.9388573575066418], 
             UndirectedEdge[329, 340] -> 
             RGBColor[
              0.2668654692611238, 0.39782290681442484`, 0.9385089657311141], 
             UndirectedEdge[193, 380] -> 
             RGBColor[
              0.7791551569135652, 0.8275462332304435, 0.978584074457042], 
             UndirectedEdge[115, 253] -> 
             RGBColor[
              0.8901501343784577, 0.5271850402949314, 0.22724725879350022`], 
             UndirectedEdge[113, 270] -> 
             RGBColor[
              0.196796775846464, 0.3241762674238618, 0.9345186572984918], 
             UndirectedEdge[121, 202] -> 
             RGBColor[
              0.2856578369982738, 0.41583248159385067`, 0.9396429608971655], 
             UndirectedEdge[17, 111] -> 
             RGBColor[
              0.8271368865255229, 0.20959157806047718`, 0.1736196192245576], 
             UndirectedEdge[73, 280] -> 
             RGBColor[
              0.2037203723071403, 0.3314534062854026, 0.9349129458743843], 
             UndirectedEdge[127, 242] -> 
             RGBColor[
              0.33988365440933965`, 0.4688118712253543, 0.9428780638050165], 
             UndirectedEdge[19, 211] -> 
             RGBColor[
              0.2160009516459515, 0.344361073804195, 0.9356123067002404], 
             UndirectedEdge[213, 345] -> 
             RGBColor[
              0.5767485455920949, 0.6610169677020706, 0.962710294489918], 
             UndirectedEdge[102, 350] -> 
             RGBColor[
              0.3487900132261258, 0.4765261115858444, 0.9434455691132382], 
             UndirectedEdge[81, 227] -> 
             RGBColor[
              0.2515739104642789, 0.38175050897811513`, 0.9376381340794677], 
             UndirectedEdge[144, 218] -> 
             RGBColor[
              0.5707667888209911, 0.662413217772521, 0.9593519988850778], 
             UndirectedEdge[130, 354] -> 
             RGBColor[
              0.2058823112495472, 0.3337257411887183, 0.9350360650988523], 
             UndirectedEdge[104, 327] -> 
             RGBColor[
              0.20490625211316982`, 0.332699841150662, 0.9349804799749857], 
             UndirectedEdge[10, 253] -> 
             RGBColor[
              0.8340797477746764, 0.2629574520026702, 0.18026811099758727`], 
             UndirectedEdge[40, 41] -> 
             RGBColor[
              0.19412189539412833`, 0.3213647984712409, 0.9343663268138622], 
             UndirectedEdge[5, 113] -> 
             RGBColor[
              0.18623312529560537`, 0.31307320092078017`, 0.9339170730271409],
              UndirectedEdge[271, 337] -> 
             RGBColor[
              0.8884909872626653, 0.561095627258048, 0.562247550040962], 
             UndirectedEdge[325, 376] -> 
             RGBColor[
              0.26222548998781436`, 0.392945994406499, 0.9382447257757333], 
             UndirectedEdge[52, 337] -> 
             RGBColor[
              0.9729869409703154, 0.9785763889719264, 0.8948788134240234], 
             UndirectedEdge[246, 260] -> 
             RGBColor[
              0.20281631365008554`, 0.33050318331620854`, 0.9348614610713], 
             UndirectedEdge[22, 290] -> 
             RGBColor[
              0.2497813465899759, 0.3798664106911086, 0.9375360502186867], 
             UndirectedEdge[24, 107] -> 
             RGBColor[
              0.2416314482274979, 0.371300350778743, 0.9370719255636378], 
             UndirectedEdge[314, 369] -> 
             RGBColor[
              0.1815795981118552, 0.30818204879999395`, 0.9336520615383029], 
             UndirectedEdge[187, 208] -> 
             RGBColor[
              0.25538258130493185`, 0.38575366351532014`, 0.9378550322494192],
              UndirectedEdge[9, 174] -> 
             RGBColor[
              0.5520972673558275, 0.6456190088987284, 0.9586092963260144], 
             UndirectedEdge[6, 303] -> 
             RGBColor[
              0.9100466794366213, 0.777602242030947, 0.6130122278904285], 
             UndirectedEdge[100, 198] -> 
             RGBColor[
              0.6082548805926754, 0.6882816237042615, 0.9647291510065205], 
             UndirectedEdge[101, 123] -> 
             RGBColor[
              0.8485657793755872, 0.374303438706794, 0.1941399512182521], 
             UndirectedEdge[210, 394] -> 
             RGBColor[
              0.30165291276591666`, 0.42986750752233627`, 0.9406555295205197],
              UndirectedEdge[213, 227] -> 
             RGBColor[
              0.29970260204538113`, 0.43079580390036054`, 0.94043541584355], 
             UndirectedEdge[32, 46] -> 
             RGBColor[
              0.8135276706473076, 0.5072097485112304, 0.5747459012560696], 
             UndirectedEdge[303, 391] -> 
             RGBColor[
              0.8570821356565119, 0.38388879895942046`, 0.20010729537059024`],
              UndirectedEdge[248, 251] -> 
             RGBColor[
              0.1839193268501145, 0.3106412520512747, 0.9337853056286283], 
             UndirectedEdge[239, 388] -> 
             RGBColor[
              0.38895939974165, 0.5063474161681534, 0.9465374152784297], 
             UndirectedEdge[205, 277] -> 
             RGBColor[
              0.18513416241600078`, 0.31191812125604473`, 0.9338544887169173],
              UndirectedEdge[308, 378] -> 
             RGBColor[
              0.22654239934249232`, 0.35544080369964637`, 0.9362126265518842],
              UndirectedEdge[119, 130] -> 
             RGBColor[
              0.2277266187202509, 0.3566854933495158, 0.936280066093552], 
             UndirectedEdge[28, 254] -> 
             RGBColor[
              0.1893368412328983, 0.3163354031578313, 0.9340938250582336], 
             UndirectedEdge[217, 314] -> 
             RGBColor[
              0.1955003640293088, 0.322813656406775, 0.9344448285633742], 
             UndirectedEdge[229, 307] -> 
             RGBColor[
              0.18847585942484443`, 0.31543045668816716`, 0.9340447934179733],
              UndirectedEdge[114, 155] -> 
             RGBColor[
              0.18628873221551898`, 0.3131316473192917, 0.933920239758967], 
             UndirectedEdge[226, 288] -> 
             RGBColor[
              0.20281928004263788`, 0.3305063011828612, 0.9348616300029674], 
             UndirectedEdge[217, 231] -> 
             RGBColor[
              0.19972682323934088`, 0.32725593300951006`, 0.9346855191628995],
              UndirectedEdge[151, 346] -> 
             RGBColor[
              0.2055192492348853, 0.3333441399918473, 0.9350153892542195], 
             UndirectedEdge[114, 180] -> 
             RGBColor[
              0.18755106204056693`, 0.3144584360017507, 0.9339921275750538], 
             UndirectedEdge[215, 345] -> 
             RGBColor[
              0.7670773504583543, 0.8180313903711476, 0.977401386659423], 
             UndirectedEdge[190, 252] -> 
             RGBColor[
              0.20904698368177904`, 0.3370520125668152, 0.9352162885121547], 
             UndirectedEdge[275, 311] -> 
             RGBColor[
              0.19837020308391207`, 0.32583003921146847`, 0.9346082616519875],
              UndirectedEdge[75, 320] -> 
             RGBColor[
              0.18280885155031829`, 0.3094740721029882, 0.933722065703106], 
             UndirectedEdge[169, 393] -> 
             RGBColor[
              0.5896152402179853, 0.6764956737968535, 0.9616696419121211], 
             UndirectedEdge[80, 182] -> 
             RGBColor[
              0.22246710481821064`, 0.35115741076602963`, 0.9359805445575843],
              UndirectedEdge[239, 362] -> 
             RGBColor[
              0.6492041088152176, 0.7238110272281775, 0.9670865002427318], 
             UndirectedEdge[171, 342] -> 
             RGBColor[
              0.18722373291059582`, 0.31411439233228555`, 0.933973486665342], 
             UndirectedEdge[107, 157] -> 
             RGBColor[
              0.2349712471793796, 0.36430005719603437`, 0.936692636966832], 
             UndirectedEdge[116, 286] -> 
             RGBColor[
              0.28063230469456346`, 0.41113725310534854`, 0.9393352740823563],
              UndirectedEdge[37, 117] -> 
             RGBColor[
              0.4214315538332871, 0.5343304799664346, 0.9489462154343377], 
             UndirectedEdge[111, 222] -> 
             RGBColor[
              0.8888497880747033, 0.5842997162159619, 0.5703986830647514], 
             UndirectedEdge[57, 72] -> 
             RGBColor[
              0.4069178401688355, 0.5265417468013449, 0.9472410910265736], 
             UndirectedEdge[8, 323] -> 
             RGBColor[
              0.3381102648791732, 0.4623620160236, 0.9429449845379104], 
             UndirectedEdge[115, 356] -> 
             RGBColor[
              0.9502457162134885, 0.9092562156396481, 0.6300362544566458], 
             UndirectedEdge[129, 391] -> 
             RGBColor[
              0.8197851875316053, 0.15308319805818565`, 0.1665796239654257], 
             UndirectedEdge[271, 303] -> 
             RGBColor[
              0.8569664054518005, 0.38299924589270967`, 0.19999647199586007`],
              UndirectedEdge[141, 196] -> 
             RGBColor[
              0.5999457128672814, 0.6805575674236943, 0.9644423387605343], 
             UndirectedEdge[8, 117] -> 
             RGBColor[
              0.40706513411417244`, 0.5192304619580248, 0.9481280690845475], 
             UndirectedEdge[278, 330] -> 
             RGBColor[
              0.18839714683821507`, 0.31534772476895345`, 0.9340403108526096],
              UndirectedEdge[95, 276] -> 
             RGBColor[
              0.3131382201938357, 0.4399588551912694, 0.9413821143478849], 
             UndirectedEdge[114, 268] -> 
             RGBColor[
              0.18716896902427724`, 0.3140568320155338, 0.9339703679430321], 
             UndirectedEdge[95, 148] -> 
             RGBColor[
              0.2518920934922597, 0.3820849395144922, 0.9376562541322015], 
             UndirectedEdge[236, 366] -> 
             RGBColor[
              0.7514680031030527, 0.8004311372612268, 0.7333352246803804], 
             UndirectedEdge[108, 378] -> 
             RGBColor[
              0.2733003143570183, 0.40458633700295354`, 0.938875420639825], 
             UndirectedEdge[33, 107] -> 
             RGBColor[
              0.23483527017028652`, 0.36415713673803723`, 0.9366848932773241],
              UndirectedEdge[309, 362] -> 
             RGBColor[
              0.7443188002522516, 0.8001867708802417, 0.9751504000206381], 
             UndirectedEdge[178, 278] -> 
             RGBColor[
              0.18555079143571185`, 0.31235602477156665`, 0.9338782151232425],
              UndirectedEdge[21, 232] -> 
             RGBColor[
              0.19351392550506752`, 0.32072578357032067`, 0.9343317038280912],
              UndirectedEdge[20, 140] -> 
             RGBColor[
              0.3954861818985797, 0.5169719858722439, 0.9464210076892463], 
             UndirectedEdge[33, 150] -> 
             RGBColor[
              0.24249803494618108`, 0.37221118836485045`, 0.9371212763952667],
              UndirectedEdge[38, 213] -> 
             RGBColor[
              0.2920695594579869, 0.42277299217815684`, 0.9400007253602725], 
             UndirectedEdge[86, 262] -> 
             RGBColor[
              0.31621623896980977`, 0.44455427693598626`, 0.9415075983220833],
              UndirectedEdge[17, 310] -> 
             RGBColor[
              0.8270891883762761, 0.20922494918390394`, 0.1735739434229715], 
             UndirectedEdge[222, 223] -> 
             RGBColor[
              0.9051519086820443, 0.7083288764559916, 0.5859596439831081], 
             UndirectedEdge[19, 124] -> 
             RGBColor[
              0.21306575741872125`, 0.34127599856931323`, 0.9354451517312304],
              UndirectedEdge[184, 274] -> 
             RGBColor[
              0.20834640202144852`, 0.33631565682236503`, 0.9351763914230165],
              UndirectedEdge[195, 360] -> 
             RGBColor[
              0.5436868916256435, 0.6393368239296271, 0.957649106135095], 
             UndirectedEdge[186, 378] -> 
             RGBColor[
              0.22340907061728948`, 0.35214747654494266`, 0.9360341881163283],
              UndirectedEdge[31, 169] -> 
             RGBColor[
              0.7207585549931849, 0.779010354243588, 0.9304794974284005], 
             UndirectedEdge[4, 84] -> 
             RGBColor[
              0.20756604892203795`, 0.3354954562376403, 0.935131951468434], 
             UndirectedEdge[81, 383] -> 
             RGBColor[
              0.2937367673363199, 0.42148311575961905`, 0.9402070608717483], 
             UndirectedEdge[327, 335] -> 
             RGBColor[
              0.19201380881889718`, 0.3191490658202642, 0.9342462744020376], 
             UndirectedEdge[11, 214] -> 
             RGBColor[
              0.8760571062553216, 0.722408188261647, 0.6042242389431952], 
             UndirectedEdge[15, 35] -> 
             RGBColor[
              0.1861148468094702, 0.312948882732563, 0.933910337242333], 
             UndirectedEdge[151, 354] -> 
             RGBColor[
              0.20185675911317996`, 0.3294946306586492, 0.934806815859957], 
             UndirectedEdge[91, 192] -> 
             RGBColor[
              0.4254211791359827, 0.5344518171008017, 0.9495440785539795], 
             UndirectedEdge[44, 130] -> 
             RGBColor[
              0.22198842052975598`, 0.350654283228527, 0.9359532841955067], 
             UndirectedEdge[195, 356] -> 
             RGBColor[
              0.6850009171912799, 0.7504962345412768, 0.9628064219580481], 
             UndirectedEdge[226, 315] -> 
             RGBColor[
              0.186507225222572, 0.3133612973229612, 0.9339326826124872], 
             UndirectedEdge[65, 206] -> 
             RGBColor[
              0.4026912595828178, 0.5232126620245969, 0.9468801088680859], 
             UndirectedEdge[287, 400] -> 
             RGBColor[
              0.8197171091545148, 0.15255991781973297`, 0.16651443203464028`],
              UndirectedEdge[247, 319] -> 
             RGBColor[
              0.8248915640805821, 0.1923330458420928, 0.17146949591555327`], 
             UndirectedEdge[55, 72] -> 
             RGBColor[
              0.6346370252408752, 0.7117938428167392, 0.9660702931075245], 
             UndirectedEdge[313, 329] -> 
             RGBColor[
              0.27347825653768526`, 0.4047733655170204, 0.9388855541837721], 
             UndirectedEdge[5, 357] -> 
             RGBColor[
              0.1864106536609117, 0.3132597944886656, 0.9339271830049154], 
             UndirectedEdge[39, 328] -> 
             RGBColor[
              0.21476290196670605`, 0.3430598050944246, 0.9355418016025379], 
             UndirectedEdge[310, 384] -> 
             RGBColor[
              0.8800507133233684, 0.4896085562326786, 0.2192223210475797], 
             UndirectedEdge[66, 344] -> 
             RGBColor[
              0.19384485664191092`, 0.32107361317738903`, 0.9343505498667657],
              UndirectedEdge[271, 391] -> 
             RGBColor[
              0.820118482997181, 0.15564505305760412`, 0.1668987880796643], 
             UndirectedEdge[203, 211] -> 
             RGBColor[
              0.27124930343896736`, 0.4023137700960795, 0.9387628961154517], 
             UndirectedEdge[100, 203] -> 
             RGBColor[
              0.3488608742001085, 0.47658748779993204`, 0.9434500843118405], 
             UndirectedEdge[323, 377] -> 
             RGBColor[
              0.3376579889612439, 0.46188664535790686`, 0.9429192280934666], 
             UndirectedEdge[351, 395] -> 
             RGBColor[
              0.37411784951982285`, 0.4984638103693781, 0.9450594364453463], 
             UndirectedEdge[179, 209] -> 
             RGBColor[
              0.24592936800917714`, 0.3758177369731411, 0.9373166857370019], 
             UndirectedEdge[283, 356] -> 
             RGBColor[
              0.9386530516866118, 0.8632951638170323, 0.6207085244635109], 
             UndirectedEdge[77, 80] -> 
             RGBColor[
              0.20002934434875747`, 0.3275739018764531, 0.9347027472925409], 
             UndirectedEdge[200, 398] -> 
             RGBColor[
              0.18742715801975252`, 0.3143282050199061, 0.933985071424368], 
             UndirectedEdge[280, 368] -> 
             RGBColor[
              0.19638103924398845`, 0.323739301895437, 0.934494981714008], 
             UndirectedEdge[3, 390] -> 
             RGBColor[
              0.22459916207358144`, 0.353398338121662, 0.9361019620641815], 
             UndirectedEdge[64, 380] -> 
             RGBColor[
              0.8564837144111264, 0.8840181121327374, 0.7035464946088651], 
             UndirectedEdge[139, 186] -> 
             RGBColor[
              0.2567623305791477, 0.38720386748367763`, 0.9379336069294297], 
             UndirectedEdge[160, 245] -> 
             RGBColor[
              0.19509478987731566`, 0.3223873722581438, 0.9344217317154114], 
             UndirectedEdge[64, 360] -> 
             RGBColor[
              0.8276703795499445, 0.8615089159497265, 0.7006746506658257], 
             UndirectedEdge[72, 337] -> 
             RGBColor[
              0.7112579708229148, 0.7722092308988048, 0.9543875188835923], 
             UndirectedEdge[11, 141] -> 
             RGBColor[
              0.6144798263952078, 0.6921466750328611, 0.9658286154835842], 
             UndirectedEdge[62, 223] -> 
             RGBColor[
              0.9255100897331807, 0.7222473691090705, 0.4948669383214451], 
             UndirectedEdge[351, 399] -> 
             RGBColor[
              0.33446531711843736`, 0.46411877979752536`, 0.9425328121440877],
              UndirectedEdge[205, 232] -> 
             RGBColor[
              0.18775686622597437`, 0.3146747492493529, 0.9340038478189527], 
             UndirectedEdge[175, 379] -> 
             RGBColor[
              0.1863024171876671, 0.3131460310926968, 0.9339210190978857], 
             UndirectedEdge[144, 339] -> 
             RGBColor[
              0.48160738498318656`, 0.5880919933231088, 0.9528684097242202], 
             UndirectedEdge[66, 275] -> 
             RGBColor[
              0.19513571872831864`, 0.3224303910755869, 0.9344240625529272], 
             UndirectedEdge[311, 346] -> 
             RGBColor[
              0.20301118387702347`, 0.33070800428020625`, 0.9348725586424393],
              UndirectedEdge[81, 326] -> 
             RGBColor[
              0.23536377630225702`, 0.36471263019196243`, 0.936714990919685], 
             UndirectedEdge[145, 335] -> 
             RGBColor[
              0.2240686969525251, 0.3528407856460005, 0.9360717528602902], 
             UndirectedEdge[24, 56] -> 
             RGBColor[
              0.3892899244154366, 0.5053479265592988, 0.9466788406566481], 
             UndirectedEdge[310, 319] -> 
             RGBColor[
              0.8294805357972241, 0.22760589335643167`, 0.17586390041391192`],
              UndirectedEdge[131, 303] -> 
             RGBColor[
              0.8540204827009316, 0.7329759435664439, 0.607655802146349], 
             UndirectedEdge[146, 317] -> 
             RGBColor[
              0.19381671894004093`, 0.32104403866869025`, 0.9343489474662702],
              UndirectedEdge[159, 321] -> 
             RGBColor[
              0.1833474210515813, 0.31004014279609426`, 0.9337527364394607], 
             UndirectedEdge[339, 361] -> 
             RGBColor[
              0.39576579821065194`, 0.5172141754678363, 0.9464388245933966], 
             UndirectedEdge[60, 297] -> 
             RGBColor[
              0.5017919184919047, 0.6000427072524873, 0.955816605103172], 
             UndirectedEdge[1, 368] -> 
             RGBColor[
              0.1828231865844723, 0.30948913913277776`, 0.9337228820620942], 
             UndirectedEdge[15, 106] -> 
             RGBColor[
              0.18432449600494816`, 0.311067110522213, 0.933808379412602], 
             UndirectedEdge[144, 282] -> 
             RGBColor[
              0.44814038646858245`, 0.5591045613100133, 0.9507359221725744], 
             UndirectedEdge[333, 391] -> 
             RGBColor[
              0.8870053729463696, 0.5607909002029526, 0.5650690319922165], 
             UndirectedEdge[85, 238] -> 
             RGBColor[
              0.19138550303315327`, 0.3184886766025597, 0.9342104933170345], 
             UndirectedEdge[130, 135] -> 
             RGBColor[
              0.27550933277442513`, 0.40444794828705827`, 0.9390913012054878],
              UndirectedEdge[194, 256] -> 
             RGBColor[
              0.7238719368935342, 0.7799355863354847, 0.863740011258672], 
             UndirectedEdge[129, 271] -> 
             RGBColor[
              0.8196694573268939, 0.15219364499147486`, 0.1664688005906955], 
             UndirectedEdge[12, 168] -> 
             RGBColor[
              0.22037492795635888`, 0.34895840023254887`, 0.9358613981804], 
             UndirectedEdge[32, 271] -> 
             RGBColor[
              0.8207608095887371, 0.16058225670961188`, 0.16751388074914259`],
              UndirectedEdge[227, 363] -> 
             RGBColor[
              0.3242588248996095, 0.45206516990504564`, 0.9420001166496061], 
             UndirectedEdge[351, 355] -> 
             RGBColor[
              0.2588476494190366, 0.38932088860423164`, 0.9380551008583563], 
             UndirectedEdge[70, 285] -> 
             RGBColor[
              0.1906202345698193, 0.31768433092677273`, 0.9341669124101608], 
             UndirectedEdge[19, 107] -> 
             RGBColor[
              0.211296993265781, 0.33941691529844853`, 0.9353444232293726], 
             UndirectedEdge[88, 359] -> 
             RGBColor[
              0.3780427703410259, 0.5018633795124479, 0.9453095289294022], 
             UndirectedEdge[128, 130] -> 
             RGBColor[
              0.2597826750311079, 0.39037844100358665`, 0.9381056110777697], 
             UndirectedEdge[72, 297] -> 
             RGBColor[
              0.3810483803734705, 0.5030082457772378, 0.9456339650216002], 
             UndirectedEdge[125, 184] -> 
             RGBColor[
              0.20307558723579205`, 0.3307756962936808, 0.934876226318445], 
             UndirectedEdge[41, 63] -> 
             RGBColor[
              0.19205972818458644`, 0.31919732998505956`, 0.9342488894419819],
              UndirectedEdge[67, 133] -> 
             RGBColor[
              0.1814057266970613, 0.30799929891896116`, 0.9336421598184501], 
             UndirectedEdge[272, 308] -> 
             RGBColor[
              0.20474955864050876`, 0.33253514637595527`, 0.9349715565135248],
              UndirectedEdge[199, 287] -> 
             RGBColor[
              0.9030273761887495, 0.5618684791886028, 0.5002796321253148], 
             UndirectedEdge[60, 333] -> 
             RGBColor[
              0.8304001644203418, 0.8680494122522482, 0.9672808175416883], 
             UndirectedEdge[86, 325] -> 
             RGBColor[
              0.25318562671626305`, 0.38344452494766296`, 0.9377299189356977],
              UndirectedEdge[77, 377] -> 
             RGBColor[
              0.22582310918113752`, 0.35468478413443216`, 0.9361716640412894],
              UndirectedEdge[62, 319] -> 
             RGBColor[
              0.9121241184522142, 0.6206330104563391, 0.4820984852913445], 
             UndirectedEdge[52, 199] -> 
             RGBColor[
              0.9888652062926342, 0.9896634908979279, 0.8341958778608433], 
             UndirectedEdge[57, 376] -> 
             RGBColor[
              0.31723897478085683`, 0.4471117135410761, 0.941511560889603], 
             UndirectedEdge[11, 161] -> 
             RGBColor[
              0.8763695857039919, 0.7238270844566292, 0.6044849794547379], 
             UndirectedEdge[155, 300] -> 
             RGBColor[
              0.19103033479495424`, 0.31811537226524556`, 0.9341902670112934],
              UndirectedEdge[81, 275] -> 
             RGBColor[
              0.21165010291327152`, 0.33978805592640576`, 0.9353645323014182],
              UndirectedEdge[100, 266] -> 
             RGBColor[
              0.5229669528809726, 0.6215828095678126, 0.9562473514884939], 
             UndirectedEdge[56, 266] -> 
             RGBColor[
              0.5883098999275997, 0.6764125091387695, 0.9608991949142476], 
             UndirectedEdge[82, 257] -> 
             RGBColor[
              0.8645894369328215, 0.89448136547207, 0.956668495179433], 
             UndirectedEdge[32, 259] -> 
             RGBColor[
              0.85847174370837, 0.5429301584289652, 0.5790636952869976], 
             UndirectedEdge[261, 355] -> 
             RGBColor[
              0.19867201809183277`, 0.32614726592096993`, 0.9346254495701933],
              UndirectedEdge[74, 179] -> 
             RGBColor[
              0.23767352171657924`, 0.3671403190687327, 0.9368465275040685], 
             UndirectedEdge[100, 174] -> 
             RGBColor[
              0.4027739307357637, 0.5232842676221057, 0.9468853766008484], 
             UndirectedEdge[208, 388] -> 
             RGBColor[
              0.28259974438226976`, 0.4143606275774112, 0.9394050094224892], 
             UndirectedEdge[249, 299] -> 
             RGBColor[
              0.186005835268804, 0.3128343046915919, 0.9339041291963601], 
             UndirectedEdge[58, 181] -> 
             RGBColor[
              0.19266290312611054`, 0.31983130509210156`, 0.9342832393625844],
              UndirectedEdge[271, 345] -> 
             RGBColor[
              0.8240432411662075, 0.5102555022323721, 0.5751262620695841], 
             UndirectedEdge[20, 89] -> 
             RGBColor[
              0.30842578765479933`, 0.4344898392135439, 0.9411326397648885], 
             UndirectedEdge[174, 358] -> 
             RGBColor[
              0.34771638286513834`, 0.47271625798382977`, 0.9434826066423876],
              UndirectedEdge[185, 274] -> 
             RGBColor[
              0.19784473283359588`, 0.32527773666164805`, 0.9345783368985956],
              UndirectedEdge[106, 314] -> 
             RGBColor[
              0.18463641563674799`, 0.3113949578320815, 0.9338261427741893], 
             UndirectedEdge[73, 387] -> 
             RGBColor[
              0.19202691052884113`, 0.31916283654811173`, 0.9342470205250366],
              UndirectedEdge[191, 261] -> 
             RGBColor[
              0.18660634868245718`, 0.3134654823640909, 0.9339383275468877], 
             UndirectedEdge[135, 227] -> 
             RGBColor[
              0.3046735470917944, 0.4351013866526011, 0.9407521600662733], 
             UndirectedEdge[102, 345] -> 
             RGBColor[
              0.5885592438891699, 0.6712468009440402, 0.9634628617416172], 
             UndirectedEdge[72, 108] -> 
             RGBColor[
              0.3859501572545172, 0.5081603240698226, 0.9459131139634468], 
             UndirectedEdge[7, 273] -> 
             RGBColor[
              0.3894971814838498, 0.5048902400899095, 0.9467521342900769], 
             UndirectedEdge[111, 385] -> 
             RGBColor[
              0.9105148340902678, 0.5980129106436974, 0.4034418367204835], 
             UndirectedEdge[25, 187] -> 
             RGBColor[
              0.29015449891481293`, 0.4171960722657919, 0.940022163552006], 
             UndirectedEdge[290, 338] -> 
             RGBColor[
              0.2338329245191738, 0.3631036079063329, 0.9366278111753308], 
             UndirectedEdge[133, 200] -> 
             RGBColor[
              0.18872606349581567`, 0.31569343703061226`, 0.9340590421696713],
              UndirectedEdge[64, 88] -> 
             RGBColor[
              0.7114905669436782, 0.7668789695612932, 0.6914868954695467], 
             UndirectedEdge[23, 92] -> 
             RGBColor[
              0.20814505737279243`, 0.33610403083063944`, 0.9351649251431382],
              UndirectedEdge[38, 350] -> 
             RGBColor[
              0.3036355127427933, 0.43279083959174136`, 0.9407376976762094], 
             UndirectedEdge[135, 224] -> 
             RGBColor[
              0.41655140034572946`, 0.5340112529021572, 0.9480965874177693], 
             UndirectedEdge[329, 358] -> 
             RGBColor[
              0.26996801721198005`, 0.40108388142367646`, 0.9386856512471069],
              UndirectedEdge[4, 185] -> 
             RGBColor[
              0.1966973229914563, 0.32407173616757357`, 0.9345129936055264], 
             UndirectedEdge[111, 199] -> 
             RGBColor[
              0.9076739184987976, 0.597583839511456, 0.5047291662889358], 
             UndirectedEdge[138, 264] -> 
             RGBColor[
              0.27444206081652406`, 0.4057863849228008, 0.9389404414116314], 
             UndirectedEdge[275, 344] -> 
             RGBColor[
              0.19285336525809532`, 0.32003149286881416`, 0.9342940858992375],
              UndirectedEdge[300, 371] -> 
             RGBColor[
              0.1880971018774196, 0.31503235849120814`, 0.934023223735969], 
             UndirectedEdge[69, 273] -> 
             RGBColor[
              0.5484319039049934, 0.644280752022615, 0.9575937149291112], 
             UndirectedEdge[65, 174] -> 
             RGBColor[
              0.39716489293029483`, 0.5184260009934458, 0.9465279736717613], 
             UndirectedEdge[217, 254] -> 
             RGBColor[
              0.1976623221296092, 0.32508601144625143`, 0.934567948878856], 
             UndirectedEdge[102, 378] -> 
             RGBColor[
              0.29463589617818253`, 0.42328641527644917`, 0.9402268398959757],
              UndirectedEdge[246, 326] -> 
             RGBColor[
              0.22913658446266597`, 0.35816745674178546`, 0.9363603615567251],
              UndirectedEdge[120, 242] -> 
             RGBColor[
              0.3764731339021319, 0.500503839321299, 0.9452095130834909], 
             UndirectedEdge[25, 117] -> 
             RGBColor[
              0.4612467201078884, 0.5710736628239611, 0.9514005522875624], 
             UndirectedEdge[44, 227] -> 
             RGBColor[
              0.25115263484712524`, 0.3813077215940698, 0.9376141430562922], 
             UndirectedEdge[118, 206] -> 
             RGBColor[
              0.39316789594043106`, 0.5149640030957358, 0.9462732885579729], 
             UndirectedEdge[151, 158] -> 
             RGBColor[
              0.19937632863451948`, 0.3268875409572013, 0.9346655590136652], 
             UndirectedEdge[151, 308] -> 
             RGBColor[
              0.2102300370530294, 0.33829547666991544`, 0.9352836616514766], 
             UndirectedEdge[298, 390] -> 
             RGBColor[
              0.2092243065114207, 0.3372383901036854, 0.935226386784977], 
             UndirectedEdge[62, 111] -> 
             RGBColor[
              0.9092079691258396, 0.5982182088690406, 0.47930597740308856`], 
             UndirectedEdge[131, 201] -> 
             RGBColor[
              0.7399124857733206, 0.7967445245200704, 0.9747112197727283], 
             UndirectedEdge[291, 368] -> 
             RGBColor[
              0.1896468250359693, 0.3166612157889672, 0.9341114781772385], 
             UndirectedEdge[35, 73] -> 
             RGBColor[
              0.19430576499947028`, 0.3215580570844616, 0.9343767979158759], 
             UndirectedEdge[273, 293] -> 
             RGBColor[
              0.4190878106551068, 0.5354941029446921, 0.9484555024448121], 
             UndirectedEdge[4, 274] -> 
             RGBColor[
              0.2019924165278475, 0.3296372152026416, 0.934814541349035], 
             UndirectedEdge[10, 337] -> 
             RGBColor[
              0.8999731601904741, 0.6493526399014464, 0.5732428918038912], 
             UndirectedEdge[27, 265] -> 
             RGBColor[
              0.20201462184730384`, 0.32966055440128883`, 0.9348158059091283],
              UndirectedEdge[262, 325] -> 
             RGBColor[
              0.3013026030921642, 0.42887910004945207`, 0.9406582888215985], 
             UndirectedEdge[46, 337] -> 
             RGBColor[
              0.8812578483212357, 0.9077231190596664, 0.969479570547889], 
             UndirectedEdge[322, 327] -> 
             RGBColor[
              0.19043725974580353`, 0.3174920127854582, 0.9341564922646202], 
             UndirectedEdge[59, 299] -> 
             RGBColor[
              0.20233103571342284`, 0.3299931254363777, 0.9348338252107113], 
             UndirectedEdge[254, 369] -> 
             RGBColor[
              0.1837415562121556, 0.31045440383947037`, 0.9337751818537847], 
             UndirectedEdge[262, 376] -> 
             RGBColor[
              0.3252561022413611, 0.4540557463948223, 0.9420224051621189], 
             UndirectedEdge[360, 389] -> 
             RGBColor[
              0.8279393932352007, 0.862084309021034, 0.7299551301459482], 
             UndirectedEdge[159, 381] -> 
             RGBColor[
              0.18574510039169012`, 0.3125602558041992, 0.9338892807308311], 
             UndirectedEdge[77, 302] -> 
             RGBColor[
              0.19582677060371215`, 0.3231567304118451, 0.9344634169349113], 
             UndirectedEdge[67, 398] -> 
             RGBColor[
              0.18010682122099816`, 0.306634066908255, 0.9335681890731469], 
             UndirectedEdge[12, 100] -> 
             RGBColor[
              0.315248838603848, 0.44137593165251704`, 0.941531651095973], 
             UndirectedEdge[329, 339] -> 
             RGBColor[
              0.322148238300078, 0.44915969522157617`, 0.9419050804873051], 
             UndirectedEdge[1, 113] -> 
             RGBColor[
              0.18373091059218155`, 0.31044321461790636`, 0.9337745756014759],
              UndirectedEdge[232, 390] -> 
             RGBColor[
              0.20167142330655186`, 0.3292998309749142, 0.9347962612599492], 
             UndirectedEdge[319, 384] -> 
             RGBColor[
              0.8830145607989899, 0.5123899866965502, 0.22206050473742173`], 
             UndirectedEdge[342, 374] -> 
             RGBColor[
              0.18501533393427727`, 0.31179322498759243`, 0.9338477216106742],
              UndirectedEdge[200, 320] -> 
             RGBColor[
              0.18887757795522245`, 0.31585268833402036`, 0.934067670693989], 
             UndirectedEdge[35, 231] -> 
             RGBColor[
              0.19065322565130216`, 0.31771900664516656`, 0.9341687912034454],
              UndirectedEdge[96, 104] -> 
             RGBColor[
              0.21783923349947054`, 0.34629322458604483`, 0.935716994132304], 
             UndirectedEdge[106, 197] -> 
             RGBColor[
              0.18891531916432497`, 0.315892356737718, 0.9340698200000144], 
             UndirectedEdge[41, 265] -> 
             RGBColor[
              0.19689578074158462`, 0.3242803278459065, 0.9345242954808043], 
             UndirectedEdge[52, 303] -> 
             RGBColor[
              0.9414623591594504, 0.8004800076065881, 0.5326277353789215], 
             UndirectedEdge[170, 208] -> 
             RGBColor[
              0.26496099146250607`, 0.3958211798972109, 0.9384005085379051], 
             UndirectedEdge[49, 355] -> 
             RGBColor[
              0.19591924831876065`, 0.3232539303537868, 0.9344686834039748], 
             UndirectedEdge[140, 359] -> 
             RGBColor[
              0.36601815692823686`, 0.491448263748933, 0.9445433311956875], 
             UndirectedEdge[20, 255] -> 
             RGBColor[
              0.37940724758906264`, 0.5030452211240766, 0.9453964722130872], 
             UndirectedEdge[117, 362] -> 
             RGBColor[
              0.6749012549506066, 0.7446731281041272, 0.9691094737182575], 
             UndirectedEdge[188, 293] -> 
             RGBColor[
              0.29496948602480166`, 0.4268642457721712, 0.9401276735084836], 
             UndirectedEdge[149, 155] -> 
             RGBColor[
              0.19811293609800762`, 0.3255596352976139, 0.9345936106777326], 
             UndirectedEdge[7, 188] -> 
             RGBColor[
              0.2653788568535447, 0.3962603829173885, 0.9384243053537484], 
             UndirectedEdge[120, 331] -> 
             RGBColor[
              0.3267582826576653, 0.45117687376714777`, 0.9422711725263158], 
             UndirectedEdge[169, 218] -> 
             RGBColor[
              0.5087675338544672, 0.6120794295560898, 0.9544711904233589], 
             UndirectedEdge[345, 350] -> 
             RGBColor[
              0.5883144988769012, 0.6710348151156551, 0.9634472668058549], 
             UndirectedEdge[147, 217] -> 
             RGBColor[
              0.2277310230294914, 0.3566901225577769, 0.9362803169124476], 
             UndirectedEdge[141, 386] -> 
             RGBColor[
              0.348846857880801, 0.4765753475686286, 0.9434491912043683], 
             UndirectedEdge[128, 383] -> 
             RGBColor[
              0.3311097462205182, 0.46076448615063337`, 0.9423353967308358], 
             UndirectedEdge[138, 394] -> 
             RGBColor[
              0.32326515413332657`, 0.4525833434947314, 0.9418863146939478], 
             UndirectedEdge[132, 300] -> 
             RGBColor[
              0.1945175148280322, 0.3217806195799947, 0.9343888567553567], 
             UndirectedEdge[103, 122] -> 
             RGBColor[
              0.1920779072643653, 0.3192164373505274, 0.9342499247136817], 
             UndirectedEdge[147, 195] -> 
             RGBColor[
              0.3359166803532971, 0.45968692435363845`, 0.9428335921754714], 
             UndirectedEdge[123, 389] -> 
             RGBColor[
              0.9181405448210238, 0.6602175731108506, 0.3409253014924295], 
             UndirectedEdge[93, 394] -> 
             RGBColor[
              0.35007693853437594`, 0.4776407816051039, 0.9435275708558966], 
             UndirectedEdge[199, 350] -> 
             RGBColor[
              0.6686405102956781, 0.7329620420673324, 0.8898856192140527], 
             UndirectedEdge[66, 158] -> 
             RGBColor[
              0.19363377892106423`, 0.3208517571096786, 0.934338529302825], 
             UndirectedEdge[105, 215] -> 
             RGBColor[
              0.8456866310237973, 0.8792487049970009, 0.932290412064394], 
             UndirectedEdge[253, 364] -> 
             RGBColor[
              0.8732653702236979, 0.4602425769354192, 0.2136613812182268], 
             UndirectedEdge[76, 78] -> 
             RGBColor[
              0.2517003601981642, 0.38188341566580475`, 0.9376453352047469], 
             UndirectedEdge[153, 358] -> 
             RGBColor[
              0.24162422522743635`, 0.37129275894771363`, 0.9370715142244698],
              UndirectedEdge[54, 64] -> 
             RGBColor[
              0.970419525130984, 0.9095497585157698, 0.3557751825465969], 
             UndirectedEdge[84, 125] -> 
             RGBColor[
              0.20344264397852102`, 0.33116149620303065`, 0.9348971296569317],
              UndirectedEdge[195, 380] -> 
             RGBColor[
              0.5725002264868254, 0.6618460201126379, 0.9605209500781344], 
             UndirectedEdge[81, 146] -> 
             RGBColor[
              0.2141426413323014, 0.3424078718408697, 0.9355064786770019], 
             UndirectedEdge[275, 317] -> 
             RGBColor[
              0.19132418052101102`, 0.3184242227542263, 0.9342070010906866], 
             UndirectedEdge[25, 377] -> 
             RGBColor[
              0.3093279743113551, 0.4373486105761115, 0.941114064611224], 
             UndirectedEdge[180, 232] -> 
             RGBColor[
              0.18939213687360562`, 0.3163935223821609, 0.9340969740631693], 
             UndirectedEdge[52, 333] -> 
             RGBColor[
              0.9713855964493081, 0.9773821088501203, 0.8975894720005477], 
             UndirectedEdge[97, 276] -> 
             RGBColor[
              0.33883500638970604`, 0.46696780675347616`, 0.9428455083067513],
              UndirectedEdge[51, 390] -> 
             RGBColor[
              0.2070958500160861, 0.33500124737515247`, 0.935105174336337], 
             UndirectedEdge[199, 393] -> 
             RGBColor[
              0.8553537557812887, 0.8861695254659845, 0.9046321600313321], 
             UndirectedEdge[169, 224] -> 
             RGBColor[
              0.4775031351026399, 0.5866975822042433, 0.9520099424283488], 
             UndirectedEdge[132, 268] -> 
             RGBColor[
              0.19026708475134468`, 0.3173131480765642, 0.9341468010504371], 
             UndirectedEdge[162, 183] -> 
             RGBColor[
              0.1919904214056781, 0.3191244841661233, 0.9342449425234534], 
             UndirectedEdge[15, 231] -> 
             RGBColor[
              0.18666830847322874`, 0.31353060603266947`, 0.9339418560653108],
              UndirectedEdge[246, 248] -> 
             RGBColor[
              0.19980719089443424`, 0.32734040451061686`, 0.9346900959819637],
              UndirectedEdge[44, 81] -> 
             RGBColor[
              0.22873470286488637`, 0.35774505370175413`, 0.9363374749942621],
              UndirectedEdge[39, 197] -> 
             RGBColor[
              0.19474286460527196`, 0.3220174764838748, 0.9344016900917953], 
             UndirectedEdge[57, 86] -> 
             RGBColor[
              0.30819911150930557`, 0.43761024408224003`, 0.9409967540495674],
              UndirectedEdge[74, 209] -> 
             RGBColor[
              0.2567896978925637, 0.3872326322652657, 0.9379351654574425], 
             UndirectedEdge[115, 389] -> 
             RGBColor[
              0.9741155744429982, 0.9237122058552483, 0.3878131353348738], 
             UndirectedEdge[157, 168] -> 
             RGBColor[
              0.222412865673202, 0.35110040198566517`, 0.9359774557185156], 
             UndirectedEdge[224, 363] -> 
             RGBColor[
              0.4361366781535445, 0.5509750361546019, 0.9493445440011021], 
             UndirectedEdge[47, 279] -> 
             RGBColor[
              0.19002059109890063`, 0.3170540676192452, 0.934132763601585], 
             UndirectedEdge[58, 352] -> 
             RGBColor[
              0.18979453396815193`, 0.3168164672419784, 0.9341198899824106], 
             UndirectedEdge[101, 161] -> 
             RGBColor[
              0.8667600435785252, 0.4809006664576717, 0.21026073973276477`], 
             UndirectedEdge[23, 98] -> 
             RGBColor[
              0.2025842284056299, 0.3302592470092312, 0.9348482441599675], 
             UndirectedEdge[37, 388] -> 
             RGBColor[
              0.27755649571754953`, 0.4090598534703564, 0.9391178038718512], 
             UndirectedEdge[13, 21] -> 
             RGBColor[
              0.2050154097981298, 0.332814572798552, 0.9349866963436598], 
             UndirectedEdge[159, 375] -> 
             RGBColor[
              0.19246854917072223`, 0.3196270267622359, 0.9342721711923458], 
             UndirectedEdge[130, 346] -> 
             RGBColor[
              0.20954480137125253`, 0.3375752505219164, 0.9352446384931148], 
             UndirectedEdge[104, 225] -> 
             RGBColor[
              0.2162656212099744, 0.3446392582970026, 0.935627379240368], 
             UndirectedEdge[226, 252] -> 
             RGBColor[
              0.19892295516503677`, 0.32641101669523676`, 0.9346397400652842],
              UndirectedEdge[64, 283] -> 
             RGBColor[
              0.9622538962308652, 0.8771757609613251, 0.3492049258616166], 
             UndirectedEdge[262, 284] -> 
             RGBColor[
              0.5520990373737982, 0.6433480852372535, 0.9595712205145508], 
             UndirectedEdge[282, 313] -> 
             RGBColor[
              0.2998205585054363, 0.43188039345676055`, 0.940406960657616], 
             UndirectedEdge[88, 360] -> 
             RGBColor[
              0.5465756968337885, 0.6418389618053506, 0.9578331782484879], 
             UndirectedEdge[210, 230] -> 
             RGBColor[
              0.2334030426063412, 0.36265177475985827`, 0.9366033300363481], 
             UndirectedEdge[2, 138] -> 
             RGBColor[
              0.24536530114030092`, 0.3752248669300471, 0.9372845629632816], 
             UndirectedEdge[178, 367] -> 
             RGBColor[
              0.18455036747987072`, 0.3113045157634352, 0.933821242458952], 
             UndirectedEdge[54, 123] -> 
             RGBColor[
              0.8957058066069172, 0.5826430148496441, 0.23309163667201951`], 
             UndirectedEdge[36, 95] -> 
             RGBColor[
              0.2464425329575721, 0.37635710587044113`, 0.9373459097216534], 
             UndirectedEdge[294, 301] -> 
             RGBColor[
              0.22980051567191817`, 0.3588652905383795, 0.9363981714568937], 
             UndirectedEdge[60, 337] -> 
             RGBColor[
              0.8320015089413489, 0.8692436923740543, 0.9645701589651641], 
             UndirectedEdge[251, 275] -> 
             RGBColor[
              0.1895350470293607, 0.3165437300168866, 0.9341051125851229], 
             UndirectedEdge[66, 311] -> 
             RGBColor[
              0.19936169446772767`, 0.32687215952004334`, 0.9346647256195157],
              UndirectedEdge[110, 400] -> 
             RGBColor[
              0.8375389435666232, 0.5282930654888892, 0.5773241994710698], 
             UndirectedEdge[143, 151] -> 
             RGBColor[
              0.2032578843654731, 0.3309673021352812, 0.934886607870296], 
             UndirectedEdge[157, 206] -> 
             RGBColor[
              0.3378748813614898, 0.46135031520372605`, 0.942959564481942], 
             UndirectedEdge[226, 274] -> 
             RGBColor[
              0.1975222198425889, 0.324938755059595, 0.9345599702608729], 
             UndirectedEdge[86, 265] -> 
             RGBColor[
              0.23354789403514828`, 0.36280402279564555`, 0.9366115791109302],
              UndirectedEdge[64, 389] -> 
             RGBColor[
              0.9928542633450905, 0.9871243167769764, 0.4636088473670069], 
             UndirectedEdge[120, 356] -> 
             RGBColor[
              0.6789656354460096, 0.7452687768356042, 0.9624218591420297], 
             UndirectedEdge[164, 279] -> 
             RGBColor[
              0.20701484030443992`, 0.33491610103189995`, 0.9351005609531018],
              UndirectedEdge[24, 238] -> 
             RGBColor[
              0.23053198107939255`, 0.35963410705922055`, 0.9364398273297434],
              UndirectedEdge[213, 259] -> 
             RGBColor[
              0.6104189913379899, 0.6878648671799451, 0.9659218116631232], 
             UndirectedEdge[73, 162] -> 
             RGBColor[
              0.19690433907813965`, 0.3242893232002557, 0.9345247828654102], 
             UndirectedEdge[257, 356] -> 
             RGBColor[
              0.9574019127188883, 0.9677509967704889, 0.9569916297931109], 
             UndirectedEdge[6, 281] -> 
             RGBColor[
              0.6624572537085711, 0.7318807392393671, 0.9697242643368251], 
             UndirectedEdge[176, 277] -> 
             RGBColor[
              0.18565952896853344`, 0.31247031481291987`, 0.933884407564874], 
             UndirectedEdge[140, 263] -> 
             RGBColor[
              0.35408935706105976`, 0.48047689556673456`, 0.943806644371628], 
             UndirectedEdge[54, 161] -> 
             RGBColor[
              0.9139000708098552, 0.6892402426005217, 0.2492124251865322], 
             UndirectedEdge[7, 142] -> 
             RGBColor[
              0.36455405628776205`, 0.4846402873807406, 0.9447885201049626], 
             UndirectedEdge[81, 311] -> 
             RGBColor[
              0.21587607865268055`, 0.34422982437086214`, 0.9356051953680067],
              UndirectedEdge[204, 237] -> 
             RGBColor[
              0.18108298927677668`, 0.3076600814275077, 0.9336237803998122], 
             UndirectedEdge[134, 374] -> 
             RGBColor[
              0.18137577945827954`, 0.307967822472237, 0.9336404543675045], 
             UndirectedEdge[264, 279] -> 
             RGBColor[
              0.22950792112061041`, 0.35855775511338905`, 0.9363815086300517],
              UndirectedEdge[81, 344] -> 
             RGBColor[
              0.2103592408268638, 0.3384312780282078, 0.9352910196152566], 
             UndirectedEdge[287, 391] -> 
             RGBColor[
              0.8187766066009462, 0.14533080306215745`, 0.16561380572719725`],
              UndirectedEdge[90, 228] -> 
             RGBColor[
              0.21978849971833822`, 0.34834202697269134`, 0.9358280019597877],
              UndirectedEdge[222, 259] -> 
             RGBColor[
              0.9232560562805229, 0.9412465076079086, 0.9787839457914527], 
             UndirectedEdge[143, 342] -> 
             RGBColor[
              0.19264878464975516`, 0.3198164656782889, 0.9342824353362423], 
             UndirectedEdge[68, 262] -> 
             RGBColor[
              0.5929687866565062, 0.6752889407487281, 0.9636412596987081], 
             UndirectedEdge[73, 189] -> 
             RGBColor[
              0.2158427366159144, 0.3441947797762137, 0.9356032965883381], 
             UndirectedEdge[79, 176] -> 
             RGBColor[
              0.19262785863960308`, 0.31979447111483345`, 0.9342812436309215],
              UndirectedEdge[14, 289] -> 
             RGBColor[
              0.4064318553204269, 0.5258851919600367, 0.9472752267865294], 
             UndirectedEdge[126, 373] -> 
             RGBColor[
              0.19027225530167013`, 0.317318582652788, 0.934147095505629], 
             UndirectedEdge[313, 361] -> 
             RGBColor[
              0.3470958164482592, 0.47282784576328063`, 0.9434192982898635], 
             UndirectedEdge[56, 203] -> 
             RGBColor[
              0.4142038212467356, 0.5314171873708888, 0.948101927737594], 
             UndirectedEdge[163, 240] -> 
             RGBColor[
              0.17919351847301027`, 0.305674127813381, 0.9335161778327592], 
             UndirectedEdge[283, 380] -> 
             RGBColor[
              0.8261523609821573, 0.7746449493883936, 0.6184230525835972], 
             UndirectedEdge[165, 318] -> 
             RGBColor[
              0.21949852941857476`, 0.348037249802461, 0.9358114885801888], 
             UndirectedEdge[184, 185] -> 
             RGBColor[
              0.20305130848505737`, 0.330750177787297, 0.9348748436795078], 
             UndirectedEdge[123, 364] -> 
             RGBColor[
              0.8822480780789155, 0.5292876057583029, 0.22226323240490067`], 
             UndirectedEdge[24, 341] -> 
             RGBColor[
              0.25476263408947386`, 0.38510205968495004`, 0.9378197271726287],
              UndirectedEdge[10, 364] -> 
             RGBColor[
              0.8821527210971085, 0.5285546502104392, 0.22217191845143208`], 
             UndirectedEdge[59, 132] -> 
             RGBColor[
              0.20457320024571096`, 0.33234978252125474`, 0.93496151316384], 
             UndirectedEdge[110, 309] -> 
             RGBColor[
              0.7751646817101416, 0.8245503622153614, 0.9781540938970312], 
             UndirectedEdge[28, 50] -> 
             RGBColor[
              0.21136185866227802`, 0.33948509294287055`, 0.9353481172177434],
              UndirectedEdge[120, 147] -> 
             RGBColor[
              0.3298813986080268, 0.4544594666479659, 0.9424490293594527], 
             UndirectedEdge[322, 335] -> 
             RGBColor[
              0.19668775397946056`, 0.3240616785292556, 0.9345124486644494], 
             UndirectedEdge[9, 198] -> 
             RGBColor[
              0.7575782172127392, 0.8106163649808842, 0.9764530707316865], 
             UndirectedEdge[214, 257] -> 
             RGBColor[
              0.9241708234933428, 0.7599031818045514, 0.5786645333196092], 
             UndirectedEdge[190, 274] -> 
             RGBColor[
              0.20764624835933113`, 0.33557975093117354`, 0.9351365187077434],
              UndirectedEdge[18, 198] -> 
             RGBColor[
              0.9106667100371233, 0.9263839830131071, 0.7062421502048801], 
             UndirectedEdge[280, 291] -> 
             RGBColor[
              0.20219476439486456`, 0.32984989564047235`, 0.9348260647607148],
              UndirectedEdge[156, 179] -> 
             RGBColor[
              0.21434244441768896`, 0.34261787755185935`, 0.9355178571671325],
              UndirectedEdge[76, 96] -> 
             RGBColor[
              0.24728213971667218`, 0.37723958580839845`, 0.9373937240844974],
              UndirectedEdge[143, 158] -> 
             RGBColor[
              0.1950219034609478, 0.3223107640132754, 0.9344175809418251], 
             UndirectedEdge[252, 274] -> 
             RGBColor[
              0.20454056169243495`, 0.3323154773323579, 0.9349596544465153], 
             UndirectedEdge[272, 348] -> 
             RGBColor[
              0.1988777254844435, 0.3263634774332058, 0.9346371643018856], 
             UndirectedEdge[51, 232] -> 
             RGBColor[
              0.19578437289714112`, 0.32311216773406903`, 0.9344610024482438],
              UndirectedEdge[66, 317] -> 
             RGBColor[
              0.19231567190482668`, 0.3194663430628012, 0.9342634650582149], 
             UndirectedEdge[258, 264] -> 
             RGBColor[
              0.24881577416889822`, 0.37885153285572853`, 0.9374810622977428],
              UndirectedEdge[17, 223] -> 
             RGBColor[
              0.843439007132864, 0.3336207383005069, 0.18918058014291417`], 
             UndirectedEdge[46, 271] -> 
             RGBColor[
              0.8127696138510401, 0.5013829917925117, 0.574019985211861], 
             UndirectedEdge[93, 201] -> 
             RGBColor[
              0.5041214136186714, 0.6049415425126292, 0.9551812111618987], 
             UndirectedEdge[232, 373] -> 
             RGBColor[
              0.19417254912152382`, 0.3214180387503654, 0.934369211468702], 
             UndirectedEdge[182, 208] -> 
             RGBColor[
              0.2681228139523549, 0.39914445580516655`, 0.9385805696512048], 
             UndirectedEdge[10, 391] -> 
             RGBColor[
              0.8316006559249898, 0.24390206570100256`, 0.1778941298425935], 
             UndirectedEdge[284, 366] -> 
             RGBColor[
              0.8665824589296481, 0.8923925729410807, 0.7434186835178305], 
             UndirectedEdge[154, 387] -> 
             RGBColor[
              0.18595738695423472`, 0.312783382441179, 0.9339013701365182], 
             UndirectedEdge[135, 363] -> 
             RGBColor[
              0.3549405295448861, 0.4818533796872159, 0.9438374745743816], 
             UndirectedEdge[37, 269] -> 
             RGBColor[
              0.3188674209826161, 0.4483513791388215, 0.9416215783296149], 
             UndirectedEdge[201, 281] -> 
             RGBColor[
              0.5322326354554701, 0.6292900699565726, 0.956972433359562], 
             UndirectedEdge[302, 377] -> 
             RGBColor[
              0.22469777382228445`, 0.35350198532189486`, 0.9361075778573873],
              UndirectedEdge[179, 286] -> 
             RGBColor[
              0.2740282991513247, 0.4041960245612692, 0.9389591857364195], 
             UndirectedEdge[108, 325] -> 
             RGBColor[
              0.2723177927173417, 0.4035536444641835, 0.9388194674859559], 
             UndirectedEdge[279, 299] -> 
             RGBColor[
              0.19371330684929777`, 0.320935346004614, 0.9343430583006869], 
             UndirectedEdge[196, 332] -> 
             RGBColor[
              0.8309647608435446, 0.5082040216040586, 0.5748389341298874], 
             UndirectedEdge[31, 224] -> 
             RGBColor[
              0.7410029688449329, 0.7954456814088879, 0.9320732118445416], 
             UndirectedEdge[200, 296] -> 
             RGBColor[
              0.1865617818736295, 0.3134186398223141, 0.9339357895330556], 
             UndirectedEdge[170, 221] -> 
             RGBColor[
              0.30270787399814014`, 0.42984035374028506`, 0.9407572019749026],
              UndirectedEdge[198, 206] -> 
             RGBColor[
              0.6288429856334741, 0.7061140055023541, 0.9660410068543737], 
             UndirectedEdge[36, 361] -> 
             RGBColor[
              0.32761397052464425`, 0.4523511904771868, 0.9423098359853219], 
             UndirectedEdge[132, 180] -> 
             RGBColor[
              0.1906491777676344, 0.3177147520627811, 0.9341685606824588], 
             UndirectedEdge[127, 312] -> 
             RGBColor[
              0.44359264480187605`, 0.5560735292696781, 0.9501952628642483], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.37498442055197767`, 0.49560326154572176`, 0.9453825139194686],
              UndirectedEdge[67, 75] -> 
             RGBColor[
              0.1806580838475214, 0.3072134788808002, 0.9335995826642074], 
             UndirectedEdge[110, 287] -> 
             RGBColor[
              0.8351408344121083, 0.5098601476691562, 0.5750277674364295], 
             UndirectedEdge[88, 233] -> 
             RGBColor[
              0.7003634497191511, 0.7623012578281982, 0.9418757273882692], 
             UndirectedEdge[168, 216] -> 
             RGBColor[
              0.20689038450304525`, 0.3347852900936806, 0.9350934733793282], 
             UndirectedEdge[1, 291] -> 
             RGBColor[
              0.1886369117353484, 0.31559973287781307`, 0.934053965108801], 
             UndirectedEdge[115, 214] -> 
             RGBColor[
              0.917014626987943, 0.7014084006737106, 0.2517091579831441], 
             UndirectedEdge[233, 256] -> 
             RGBColor[
              0.9813174831621745, 0.9842395002462874, 0.8561565043579783], 
             UndirectedEdge[4, 252] -> 
             RGBColor[
              0.20339315185029538`, 0.3311094768382833, 0.9348943111534462], 
             UndirectedEdge[91, 399] -> 
             RGBColor[
              0.4759758631677278, 0.5829069233744436, 0.9525944899971995], 
             UndirectedEdge[76, 269] -> 
             RGBColor[
              0.3181691701834686, 0.44761747327725976`, 0.9415818139795731], 
             UndirectedEdge[91, 172] -> 
             RGBColor[
              0.48609962486048197`, 0.5916756169176496, 0.9532395671401708], 
             UndirectedEdge[165, 184] -> 
             RGBColor[
              0.21954677082243013`, 0.3480879545765947, 0.9358142358567716], 
             UndirectedEdge[60, 139] -> 
             RGBColor[
              0.506983675095762, 0.6054995726195224, 0.9561122679612462], 
             UndirectedEdge[356, 359] -> 
             RGBColor[
              0.6355366085129286, 0.7076527365125309, 0.9596545999486343], 
             UndirectedEdge[228, 305] -> 
             RGBColor[
              0.26103370837156087`, 0.39169335636449776`, 0.9381768555757705],
              UndirectedEdge[141, 209] -> 
             RGBColor[
              0.3104061832925851, 0.4392395615986554, 0.9411477244574119], 
             UndirectedEdge[171, 348] -> 
             RGBColor[
              0.1945787269842331, 0.32184495743723673`, 0.934392342697097], 
             UndirectedEdge[10, 60] -> 
             RGBColor[
              0.774995447398962, 0.551160577750298, 0.5801059153920654], 
             UndirectedEdge[234, 298] -> 
             RGBColor[
              0.22620097648238727`, 0.3550819466262163, 0.936193183025091], 
             UndirectedEdge[323, 388] -> 
             RGBColor[
              0.34570167664203966`, 0.47034107110967827`, 0.9433773042073184],
              UndirectedEdge[294, 329] -> 
             RGBColor[
              0.23603593247132534`, 0.36541910894281576`, 0.9367532692191475],
              UndirectedEdge[211, 238] -> 
             RGBColor[
              0.21668562529693003`, 0.34508070922219014`, 0.9356512978517798],
              UndirectedEdge[31, 99] -> 
             RGBColor[
              0.9432122400933031, 0.9562926111989585, 0.9505366840460105], 
             UndirectedEdge[111, 319] -> 
             RGBColor[
              0.8295282339464709, 0.2279725222330049, 0.17590957621549802`], 
             UndirectedEdge[258, 394] -> 
             RGBColor[
              0.29763886748570073`, 0.42564849142765915`, 0.9404269355800592],
              UndirectedEdge[101, 364] -> 
             RGBColor[
              0.8876560448428017, 0.5708556080916793, 0.22744190748542303`], 
             UndirectedEdge[225, 349] -> 
             RGBColor[
              0.2034483891040132, 0.3311675346941849, 0.9348974568333293], 
             UndirectedEdge[118, 386] -> 
             RGBColor[
              0.34968714140668505`, 0.4773031589248714, 0.9435027333276041], 
             UndirectedEdge[95, 326] -> 
             RGBColor[
              0.24440137831360023`, 0.3742117229229475, 0.9372296689842969], 
             UndirectedEdge[228, 382] -> 
             RGBColor[
              0.27305197131929326`, 0.4030910170101112, 0.9389064714836659], 
             UndirectedEdge[120, 255] -> 
             RGBColor[
              0.39336824955180094`, 0.5151375393238391, 0.9462860549129236], 
             UndirectedEdge[222, 292] -> 
             RGBColor[
              0.8852896880649895, 0.5569352274955306, 0.5669895272748917], 
             UndirectedEdge[325, 397] -> 
             RGBColor[
              0.3012257827964342, 0.4288125621703911, 0.9406533939002841], 
             UndirectedEdge[155, 299] -> 
             RGBColor[
              0.1871446834102983, 0.31403130629544507`, 0.9339689849132433], 
             UndirectedEdge[17, 99] -> 
             RGBColor[
              0.8649138899410389, 0.5692261022124661, 0.5823263856846504], 
             UndirectedEdge[60, 105] -> 
             RGBColor[
              0.8461630434103341, 0.8796208819742317, 0.932337896398757], 
             UndirectedEdge[229, 340] -> 
             RGBColor[
              0.23465687622616624`, 0.36396963339193744`, 0.9366747340061166],
              UndirectedEdge[297, 375] -> 
             RGBColor[
              0.2496778587950193, 0.3797576384571041, 0.9375301567418605], 
             UndirectedEdge[155, 249] -> 
             RGBColor[
              0.18476081976801417`, 0.3115257144617197, 0.9338332274054255], 
             UndirectedEdge[143, 348] -> 
             RGBColor[
              0.20000377872339242`, 0.3275470307832401, 0.9347012913679973], 
             UndirectedEdge[175, 294] -> 
             RGBColor[
              0.19993479870238595`, 0.3274745284075764, 0.9346973630578478], 
             UndirectedEdge[19, 181] -> 
             RGBColor[
              0.19581756515250187`, 0.3231470548989638, 0.9344628926980831], 
             UndirectedEdge[153, 294] -> 
             RGBColor[
              0.20769214048678164`, 0.33562798646685293`, 0.9351391321965103],
              UndirectedEdge[68, 376] -> 
             RGBColor[
              0.5538916735521564, 0.639355835105775, 0.9612276966528428], 
             UndirectedEdge[317, 354] -> 
             RGBColor[
              0.19230267119241712`, 0.319452678489766, 0.934262724686876], 
             UndirectedEdge[2, 254] -> 
             RGBColor[
              0.19445154659843222`, 0.32171128278805783`, 0.9343850999622723],
              UndirectedEdge[243, 311] -> 
             RGBColor[
              0.21699506567726595`, 0.34540595068157653`, 0.9356689200236639],
              UndirectedEdge[23, 143] -> 
             RGBColor[
              0.20541157212716055`, 0.3332309645245057, 0.9350092572022285], 
             UndirectedEdge[20, 64] -> 
             RGBColor[
              0.6886054780275248, 0.7470570557801346, 0.690028677840299], 
             UndirectedEdge[75, 296] -> 
             RGBColor[
              0.18049305546872535`, 0.30704002359128196`, 0.9335901845421726],
              UndirectedEdge[146, 227] -> 
             RGBColor[
              0.2365605733145403, 0.3659705397331854, 0.936783146739032], 
             UndirectedEdge[160, 238] -> 
             RGBColor[
              0.19808883610787825`, 0.32553430467996036`, 0.9345922382189475],
              UndirectedEdge[75, 178] -> 
             RGBColor[
              0.18245868691760933`, 0.30910602687229105`, 0.9337021243452953],
              UndirectedEdge[95, 166] -> 
             RGBColor[
              0.24620280791930751`, 0.37610513965577974`, 0.9373322577353658],
              UndirectedEdge[25, 309] -> 
             RGBColor[
              0.5306642654095335, 0.6265873056000757, 0.957441478589943], 
             UndirectedEdge[166, 326] -> 
             RGBColor[
              0.24337300372818133`, 0.3731308360309576, 0.9371711045730012], 
             UndirectedEdge[158, 308] -> 
             RGBColor[
              0.20199405614850408`, 0.32963893854790965`, 0.9348146347230057],
              UndirectedEdge[229, 343] -> 
             RGBColor[
              0.1993208104479567, 0.32682918782306747`, 0.9346623973350723], 
             UndirectedEdge[229, 294] -> 
             RGBColor[
              0.20382733943636777`, 0.33156583552032837`, 0.9349190374941501],
              UndirectedEdge[64, 257] -> 
             RGBColor[
              0.9810027572631417, 0.9816315939147817, 0.6854880311912166], 
             UndirectedEdge[56, 65] -> 
             RGBColor[
              0.4474461015886463, 0.5602099797974611, 0.9502200964459863], 
             UndirectedEdge[170, 192] -> 
             RGBColor[
              0.2468852126322833, 0.37682239027607506`, 0.9373711196742425], 
             UndirectedEdge[133, 347] -> 
             RGBColor[
              0.18386468807739512`, 0.3105838232368483, 0.9337821940313528], 
             UndirectedEdge[223, 393] -> 
             RGBColor[
              0.7905940425099285, 0.6181725668402647, 0.5885810229879949], 
             UndirectedEdge[116, 338] -> 
             RGBColor[
              0.22507866009155236`, 0.35390232094047974`, 0.9361292687669514],
              UndirectedEdge[32, 71] -> 
             RGBColor[
              0.8956113709184261, 0.5716673969312225, 0.5522037062726537], 
             UndirectedEdge[95, 361] -> 
             RGBColor[
              0.32840262007179855`, 0.45318011115451534`, 0.9423547484103298],
              UndirectedEdge[247, 292] -> 
             RGBColor[
              0.8184153147444937, 0.14255375553436297`, 0.16526783223743757`],
              UndirectedEdge[337, 391] -> 
             RGBColor[
              0.8886067174673766, 0.5619851803247587, 0.5623583734156922], 
             UndirectedEdge[181, 238] -> 
             RGBColor[
              0.1965022388034804, 0.3238666903169589, 0.9345018838496224], 
             UndirectedEdge[97, 246] -> 
             RGBColor[
              0.2576631748496625, 0.38815071192881434`, 0.9379849086779559], 
             UndirectedEdge[62, 247] -> 
             RGBColor[
              0.9045712992599508, 0.5625787324781286, 0.4748658971031438], 
             UndirectedEdge[207, 280] -> 
             RGBColor[
              0.200223112625469, 0.32777756462089525`, 0.9347137821092452], 
             UndirectedEdge[145, 221] -> 
             RGBColor[
              0.3098924284635012, 0.43739177601044266`, 0.941166351723109], 
             UndirectedEdge[10, 334] -> 
             RGBColor[
              0.9015893430893124, 0.6043580043169925, 0.2443543042542488], 
             UndirectedEdge[25, 78] -> 
             RGBColor[
              0.29221377727191306`, 0.41936050438489303`, 0.9401394364080135],
              UndirectedEdge[46, 139] -> 
             RGBColor[
              0.5562400144756487, 0.6439789993051345, 0.961021679543971], 
             UndirectedEdge[224, 383] -> 
             RGBColor[
              0.42803255257249384`, 0.5439556499014909, 0.9488281562852744], 
             UndirectedEdge[138, 164] -> 
             RGBColor[
              0.2519489800003536, 0.38214473084131173`, 0.9376594937346815], 
             UndirectedEdge[53, 93] -> 
             RGBColor[
              0.37256678589576175`, 0.4971203570169409, 0.9449606040427729], 
             UndirectedEdge[31, 199] -> 
             RGBColor[
              0.9864970705564884, 0.9886842059127192, 0.8734420155476115], 
             UndirectedEdge[98, 342] -> 
             RGBColor[
              0.1898214409282245, 0.31684474816301444`, 0.9341214222939813], 
             UndirectedEdge[141, 304] -> 
             RGBColor[
              0.31901866548224, 0.4482918264428926, 0.9416381925770871], 
             UndirectedEdge[32, 105] -> 
             RGBColor[
              0.903410578527918, 0.577299573576944, 0.5307412035187635], 
             UndirectedEdge[216, 329] -> 
             RGBColor[
              0.23907766788565177`, 0.368616165720437, 0.936926491551149], 
             UndirectedEdge[164, 264] -> 
             RGBColor[
              0.23748584663754294`, 0.36694306066137816`, 0.9368358396859577],
              UndirectedEdge[118, 196] -> 
             RGBColor[
              0.6007859963931654, 0.6812853787799371, 0.9644958808837701], 
             UndirectedEdge[75, 398] -> 
             RGBColor[
              0.18135843161484838`, 0.30794958878887396`, 0.9336394664334849],
              UndirectedEdge[45, 48] -> 
             RGBColor[
              0.2238300988639671, 0.3525900039269335, 0.9360581650521211], 
             UndirectedEdge[248, 275] -> 
             RGBColor[
              0.18852850716525682`, 0.3154857928014001, 0.9340477916289045], 
             UndirectedEdge[200, 347] -> 
             RGBColor[
              0.1891857716327594, 0.31617661942971953`, 0.9340852218679931], 
             UndirectedEdge[33, 58] -> 
             RGBColor[
              0.21989646734481127`, 0.3484555077936574, 0.9358341505563915], 
             UndirectedEdge[134, 240] -> 
             RGBColor[
              0.17922390736570504`, 0.3057060684663703, 0.9335179084352418], 
             UndirectedEdge[267, 344] -> 
             RGBColor[
              0.1945632673718405, 0.321828708404416, 0.9343914622950418], 
             UndirectedEdge[141, 286] -> 
             RGBColor[
              0.3385051144347327, 0.4676178491867835, 0.9427902244568296], 
             UndirectedEdge[33, 209] -> 
             RGBColor[
              0.25581747523043485`, 0.38621076460489123`, 0.9378797988151089],
              UndirectedEdge[47, 155] -> 
             RGBColor[
              0.18345196765990118`, 0.3101500279100763, 0.9337586902141416], 
             UndirectedEdge[153, 229] -> 
             RGBColor[
              0.2017865527982215, 0.3294208393702904, 0.934802817714181], 
             UndirectedEdge[64, 161] -> 
             RGBColor[
              0.9360657953387055, 0.766239407790421, 0.32776561052681985`], 
             UndirectedEdge[3, 293] -> 
             RGBColor[
              0.2751725873267546, 0.40605645004464963`, 0.939000269414517], 
             UndirectedEdge[133, 178] -> 
             RGBColor[
              0.18320632976714918`, 0.309891846910452, 0.9337447014995381], 
             UndirectedEdge[113, 162] -> 
             RGBColor[
              0.19047273002269705`, 0.31752929429541876`, 0.9341585122444157],
              UndirectedEdge[313, 358] -> 
             RGBColor[
              0.28110733593194254`, 0.4127920116719563, 0.9393200189690635], 
             UndirectedEdge[259, 292] -> 
             RGBColor[
              0.8574582528162021, 0.5351400233172219, 0.5780931752640834], 
             UndirectedEdge[4, 165] -> 
             RGBColor[
              0.21319278532882907`, 0.3414095129568713, 0.9354523857827901], 
             UndirectedEdge[247, 385] -> 
             RGBColor[
              0.9058781642243791, 0.5623734342527853, 0.3990017564205388], 
             UndirectedEdge[38, 243] -> 
             RGBColor[
              0.24505985490147014`, 0.37490382356662577`, 0.9372671682518474],
              UndirectedEdge[265, 381] -> 
             RGBColor[
              0.19417265233719494`, 0.3214181472365799, 0.9343692173466818], 
             UndirectedEdge[15, 369] -> 
             RGBColor[
              0.18126767848005537`, 0.30785420149012543`, 0.9336342981767156],
              UndirectedEdge[30, 358] -> 
             RGBColor[
              0.2391480425105603, 0.3686901339132248, 0.9369304992819277], 
             UndirectedEdge[133, 330] -> 
             RGBColor[
              0.1860526851696524, 0.3128835469078388, 0.9339067972289052], 
             UndirectedEdge[223, 292] -> 
             RGBColor[
              0.8393541052177236, 0.30222239216530483`, 0.1852688734557389], 
             UndirectedEdge[44, 326] -> 
             RGBColor[
              0.2349425006851034, 0.3642698428079171, 0.9366909998965096], 
             UndirectedEdge[123, 356] -> 
             RGBColor[
              0.8942706865915142, 0.6457615828952505, 0.5831484206142015], 
             UndirectedEdge[35, 154] -> 
             RGBColor[
              0.18823624142486384`, 0.31517860297752887`, 0.9340311475273575],
              UndirectedEdge[146, 151] -> 
             RGBColor[
              0.20337080686080378`, 0.3310859908375735, 0.9348930386393511], 
             UndirectedEdge[111, 287] -> 
             RGBColor[
              0.8219655423100481, 0.16984236032285321`, 0.168667534163621], 
             UndirectedEdge[42, 133] -> 
             RGBColor[
              0.1836453052262827, 0.310353237950653, 0.9337697005025297], 
             UndirectedEdge[40, 103] -> 
             RGBColor[
              0.19411926264855695`, 0.32136203128871965`, 0.9343661768828968],
              UndirectedEdge[219, 260] -> 
             RGBColor[
              0.1839290162486566, 0.31065143622348573`, 0.9337858574255411], 
             UndirectedEdge[151, 186] -> 
             RGBColor[
              0.20709670832782653`, 0.33500214951521173`, 0.9351052232159208],
              UndirectedEdge[8, 76] -> 
             RGBColor[
              0.26926683315553557`, 0.4003468925227164, 0.9386457198524012], 
             UndirectedEdge[124, 167] -> 
             RGBColor[
              0.23121257205082407`, 0.360349451322155, 0.9364785859787222], 
             UndirectedEdge[162, 291] -> 
             RGBColor[
              0.1953787311658639, 0.32268581255532547`, 0.9344379017517408], 
             UndirectedEdge[242, 255] -> 
             RGBColor[
              0.3572936731332409, 0.48389155439101317`, 0.9439874148030284], 
             UndirectedEdge[182, 323] -> 
             RGBColor[
              0.3312247462121247, 0.45512489933743366`, 0.9425528644360341], 
             UndirectedEdge[138, 149] -> 
             RGBColor[
              0.2496156992329207, 0.3796923048161946, 0.9375266168467558], 
             UndirectedEdge[199, 353] -> 
             RGBColor[
              0.9909977762454061, 0.988800838647677, 0.6720451430779383], 
             UndirectedEdge[34, 381] -> 
             RGBColor[
              0.18614322275265005`, 0.3129787076479837, 0.9339119532103186], 
             UndirectedEdge[148, 305] -> 
             RGBColor[
              0.2773062230664102, 0.4087968010458064, 0.939103551214614], 
             UndirectedEdge[97, 383] -> 
             RGBColor[
              0.32847115554353346`, 0.45799116005281093`, 0.9421851328952267],
              UndirectedEdge[154, 207] -> 
             RGBColor[
              0.18894498275511917`, 0.315923535052423, 0.9340715092976267], 
             UndirectedEdge[272, 375] -> 
             RGBColor[
              0.1997235147350348, 0.3272524555617131, 0.9346853307484737], 
             UndirectedEdge[25, 323] -> 
             RGBColor[
              0.3922918508728892, 0.5142052168895364, 0.9462174677409253], 
             UndirectedEdge[236, 334] -> 
             RGBColor[
              0.7349237676396162, 0.7451154652166593, 0.6272347577119612], 
             UndirectedEdge[23, 346] -> 
             RGBColor[
              0.20767293699657277`, 0.3356078023810718, 0.935138038586152], 
             UndirectedEdge[23, 151] -> 
             RGBColor[
              0.20976599730073225`, 0.3378077414684315, 0.9352572352740687], 
             UndirectedEdge[250, 381] -> 
             RGBColor[
              0.19153445496524343`, 0.31864523452728444`, 0.9342189759092124],
              UndirectedEdge[230, 264] -> 
             RGBColor[
              0.2405521506109405, 0.3701659405523198, 0.9370104611610526], 
             UndirectedEdge[60, 68] -> 
             RGBColor[
              0.7643140770585692, 0.8158203298412934, 0.9771398668713851], 
             UndirectedEdge[50, 258] -> 
             RGBColor[
              0.23439017041921995`, 0.3636893086787121, 0.9366595455049669], 
             UndirectedEdge[121, 298] -> 
             RGBColor[
              0.2245949434093795, 0.353393904038107, 0.9361017218174963], 
             UndirectedEdge[95, 382] -> 
             RGBColor[
              0.2846635750266093, 0.4152955487246973, 0.9395677351369693], 
             UndirectedEdge[42, 200] -> 
             RGBColor[
              0.18896638878164698`, 0.3159460341435242, 0.9340727283391701], 
             UndirectedEdge[254, 314] -> 
             RGBColor[
              0.1849157269952969, 0.31168853177927935`, 0.9338420491428545], 
             UndirectedEdge[95, 305] -> 
             RGBColor[
              0.2726453120788769, 0.4038978880790839, 0.9388381192290738], 
             UndirectedEdge[321, 381] -> 
             RGBColor[
              0.18695109985789307`, 0.313827837707961, 0.9339579606163151], 
             UndirectedEdge[116, 209] -> 
             RGBColor[
              0.2525333735524159, 0.38275896551722044`, 0.9376927740829386], 
             UndirectedEdge[364, 366] -> 
             RGBColor[
              0.9573192010017704, 0.856958801294309, 0.38384804144330753`], 
             UndirectedEdge[58, 156] -> 
             RGBColor[
              0.19753761270804981`, 0.3249549339371585, 0.9345608468617892], 
             UndirectedEdge[118, 179] -> 
             RGBColor[
              0.29213029064248475`, 0.4198750597583651, 0.9401126286272736], 
             UndirectedEdge[149, 328] -> 
             RGBColor[
              0.22083892747976266`, 0.3494460931509151, 0.9358878222668322], 
             UndirectedEdge[215, 227] -> 
             RGBColor[
              0.4900314069116405, 0.5878102265694376, 0.9551265080130549], 
             UndirectedEdge[70, 177] -> 
             RGBColor[
              0.1891804395703839, 0.31617101509409057`, 0.9340849182149289], 
             UndirectedEdge[383, 393] -> 
             RGBColor[
              0.5401446576878393, 0.6337537414941011, 0.9584878557690468], 
             UndirectedEdge[14, 201] -> 
             RGBColor[
              0.5021816905325309, 0.6032614518687315, 0.9550576137220795], 
             UndirectedEdge[5, 368] -> 
             RGBColor[
              0.18532540128789612`, 0.31211912543565157`, 0.9338653794877592],
              UndirectedEdge[214, 310] -> 
             RGBColor[
              0.8527190352209195, 0.3739582811888842, 0.19685354443386982`], 
             UndirectedEdge[35, 280] -> 
             RGBColor[
              0.19951437129521365`, 0.3270326325460011, 0.9346734203389759], 
             UndirectedEdge[243, 275] -> 
             RGBColor[
              0.21276908993785693`, 0.3409641822371201, 0.9354282569570754], 
             UndirectedEdge[131, 391] -> 
             RGBColor[
              0.817172560246312, 0.5056217507313383, 0.5745581182301532], 
             UndirectedEdge[2, 314] -> 
             RGBColor[
              0.19228958849813182`, 0.3194389277485814, 0.9342619796467905], 
             UndirectedEdge[282, 361] -> 
             RGBColor[
              0.36229879969604784`, 0.48822674345474093`, 0.9443063370417508],
              UndirectedEdge[110, 269] -> 
             RGBColor[
              0.6031830035578256, 0.6830576186116337, 0.9647885304899277], 
             UndirectedEdge[193, 360] -> 
             RGBColor[
              0.7503418220523833, 0.8050370370474327, 0.9757122305140027], 
             UndirectedEdge[71, 400] -> 
             RGBColor[
              0.8959095468804387, 0.5739593080367903, 0.5524892399106185], 
             UndirectedEdge[110, 117] -> 
             RGBColor[
              0.7057471364084966, 0.7690367194392469, 0.9721131675946504], 
             UndirectedEdge[170, 351] -> 
             RGBColor[
              0.27252940237618284`, 0.4037012784354327, 0.938834256448926], 
             UndirectedEdge[121, 200] -> 
             RGBColor[
              0.2188856606362972, 0.3473930858541622, 0.9357765866096961], 
             UndirectedEdge[38, 383] -> 
             RGBColor[
              0.3085216567311646, 0.43702297192973105`, 0.9410490384505009], 
             UndirectedEdge[172, 256] -> 
             RGBColor[
              0.6859636429526801, 0.7471589426256584, 0.8613086090450968], 
             UndirectedEdge[127, 258] -> 
             RGBColor[
              0.2885106861095953, 0.4177421195154126, 0.9398452959345076], 
             UndirectedEdge[25, 388] -> 
             RGBColor[
              0.31737166199215083`, 0.44580303632788293`, 0.9415721407250759],
              UndirectedEdge[51, 277] -> 
             RGBColor[
              0.19316166908716753`, 0.3203555397407608, 0.9343116433462084], 
             UndirectedEdge[85, 379] -> 
             RGBColor[
              0.18217848519657132`, 0.30881151709766497`, 0.9336861672718034],
              UndirectedEdge[267, 306] -> 
             RGBColor[
              0.20993199303624877`, 0.33798221351119695`, 0.9352666884856375],
              UndirectedEdge[176, 298] -> 
             RGBColor[
              0.19583511598337588`, 0.32316550193499927`, 0.9344638921919373],
              UndirectedEdge[269, 323] -> 
             RGBColor[
              0.38701260190710624`, 0.5096325967781434, 0.9458810786650822], 
             UndirectedEdge[21, 180] -> 
             RGBColor[
              0.19254611619106632`, 0.3197085546186507, 0.9342765885194044], 
             UndirectedEdge[36, 228] -> 
             RGBColor[
              0.23483092925025606`, 0.364152574155855, 0.9366846460683501], 
             UndirectedEdge[74, 116] -> 
             RGBColor[
              0.244277527259818, 0.37408154761281204`, 0.9372226158500052], 
             UndirectedEdge[3, 188] -> 
             RGBColor[
              0.25601232241971317`, 0.38641556135484806`, 0.9378908950742876],
              UndirectedEdge[69, 394] -> 
             RGBColor[
              0.46522152575946735`, 0.5741285322522734, 0.9517610033724258], 
             UndirectedEdge[37, 395] -> 
             RGBColor[
              0.3615061899414258, 0.48528293772410147`, 0.9443384829836874], 
             UndirectedEdge[172, 194] -> 
             RGBColor[
              0.41753162873264527`, 0.5360090287080477, 0.9478416433121417], 
             UndirectedEdge[59, 264] -> 
             RGBColor[
              0.2381256499847355, 0.3676155345451527, 0.9368722755400762], 
             UndirectedEdge[28, 369] -> 
             RGBColor[
              0.1860007123494566, 0.3128289201785459, 0.9339038374536819], 
             UndirectedEdge[130, 344] -> 
             RGBColor[
              0.20361295849173341`, 0.3313405075549807, 0.9349068288165013], 
             UndirectedEdge[29, 270] -> 
             RGBColor[
              0.19689305639497057`, 0.3242774643848816, 0.9345241403332949], 
             UndirectedEdge[41, 48] -> 
             RGBColor[
              0.2013669879321785, 0.3289798500941302, 0.9347789241157504], 
             UndirectedEdge[12, 124] -> 
             RGBColor[
              0.23470207361547668`, 0.3640171387137828, 0.9366773079305742], 
             UndirectedEdge[61, 95] -> 
             RGBColor[
              0.23224869997063102`, 0.3614384874601766, 0.9365375919309413], 
             UndirectedEdge[213, 306] -> 
             RGBColor[
              0.2738566580723743, 0.4036300780572341, 0.9389635275699348], 
             UndirectedEdge[63, 295] -> 
             RGBColor[
              0.1876127220363632, 0.31452324456680214`, 0.9339956390205967], 
             UndirectedEdge[302, 367] -> 
             RGBColor[
              0.19039724530537674`, 0.31744995507150764`, 0.934154213501434], 
             UndirectedEdge[140, 331] -> 
             RGBColor[
              0.3236577561982914, 0.4484913535850291, 0.9420736097220124], 
             UndirectedEdge[92, 354] -> 
             RGBColor[
              0.20023581918524017`, 0.32779092002085713`, 0.9347145057290265],
              UndirectedEdge[151, 311] -> 
             RGBColor[
              0.20510424418118295`, 0.33290794336756596`, 0.934991755330356], 
             UndirectedEdge[299, 371] -> 
             RGBColor[
              0.18421145049276366`, 0.3109482925214076, 0.933801941637919], 
             UndirectedEdge[140, 389] -> 
             RGBColor[
              0.6997349672161455, 0.7570392468690857, 0.7200011772159544], 
             UndirectedEdge[176, 205] -> 
             RGBColor[
              0.18567915281687453`, 0.3124909407217502, 0.9338855251140061], 
             UndirectedEdge[152, 179] -> 
             RGBColor[
              0.2138285336364696, 0.3420777247369723, 0.935488590708405], 
             UndirectedEdge[142, 293] -> 
             RGBColor[
              0.3941446854590191, 0.5152441502355233, 0.946491888259698], 
             UndirectedEdge[105, 259] -> 
             RGBColor[
              0.9403634558512834, 0.9538207185775788, 0.9415651020124101], 
             UndirectedEdge[274, 318] -> 
             RGBColor[
              0.20829816061759315`, 0.33626495204823137`, 0.9351736441464337],
              UndirectedEdge[231, 369] -> 
             RGBColor[
              0.1858060573218873, 0.312624325402729, 0.9338927521378282], 
             UndirectedEdge[151, 348] -> 
             RGBColor[
              0.20435820389696413`, 0.332123807727166, 0.9349492694398375], 
             UndirectedEdge[147, 231] -> 
             RGBColor[
              0.2192108871052112, 0.34773491949353985`, 0.9357951077759714], 
             UndirectedEdge[66, 354] -> 
             RGBColor[
              0.19611420939972474`, 0.3234588468111266, 0.9344797861491166], 
             UndirectedEdge[24, 65] -> 
             RGBColor[
              0.3183379395633406, 0.44565996035968214`, 0.9416695943018074], 
             UndirectedEdge[42, 347] -> 
             RGBColor[
              0.18410501336322643`, 0.3108364203497602, 0.9337958802008515], 
             UndirectedEdge[52, 129] -> 
             RGBColor[
              0.904165411034544, 0.5696744067053534, 0.4991000639737569], 
             UndirectedEdge[3, 7] -> 
             RGBColor[
              0.24558195815549755`, 0.37545258718986685`, 0.9372969012597816],
              UndirectedEdge[156, 352] -> 
             RGBColor[
              0.19412861826228733`, 0.32137186463193046`, 0.9343667096712585],
              UndirectedEdge[229, 329] -> 
             RGBColor[
              0.2301303447827652, 0.3592119618462532, 0.9364169547368181], 
             UndirectedEdge[80, 187] -> 
             RGBColor[
              0.20972687217078761`, 0.3377666184761832, 0.9352550071557988], 
             UndirectedEdge[247, 362] -> 
             RGBColor[
              0.8043048253983777, 0.4855724402659776, 0.5720335274237128], 
             UndirectedEdge[43, 321] -> 
             RGBColor[
              0.1896253217591911, 0.31663861448168684`, 0.9341102535974373], 
             UndirectedEdge[84, 270] -> 
             RGBColor[
              0.21111604747539212`, 0.339226729800124, 0.9353341186342953], 
             UndirectedEdge[318, 322] -> 
             RGBColor[
              0.20428384988578308`, 0.3320456569470981, 0.9349450350888977], 
             UndirectedEdge[218, 276] -> 
             RGBColor[
              0.46966080217049366`, 0.5783141439540027, 0.951949779691809], 
             UndirectedEdge[201, 303] -> 
             RGBColor[
              0.7798220611835203, 0.6750115727481525, 0.6002603969131654], 
             UndirectedEdge[283, 364] -> 
             RGBColor[
              0.9266304431740131, 0.7468211866800847, 0.25982333625421017`], 
             UndirectedEdge[65, 340] -> 
             RGBColor[
              0.3239430587205376, 0.45155129597897675`, 0.941988797545779], 
             UndirectedEdge[83, 214] -> 
             RGBColor[
              0.9149531561640245, 0.7530286606028909, 0.5942676397554747], 
             UndirectedEdge[124, 157] -> 
             RGBColor[
              0.2367400113323198, 0.3661591404668991, 0.9367933654686897], 
             UndirectedEdge[311, 344] -> 
             RGBColor[
              0.19707934099750435`, 0.3244732613132706, 0.9345347489658259], 
             UndirectedEdge[190, 226] -> 
             RGBColor[
              0.20202864183193292`, 0.3296752902940524, 0.9348166043265123], 
             UndirectedEdge[380, 389] -> 
             RGBColor[
              0.8567527280963826, 0.8845935052040448, 0.7328269740889874], 
             UndirectedEdge[124, 179] -> 
             RGBColor[
              0.22671592710196903`, 0.3556231923771518, 0.9362225087010749], 
             UndirectedEdge[199, 215] -> 
             RGBColor[
              0.8474033618771311, 0.8799586173228249, 0.9038397390676208], 
             UndirectedEdge[146, 267] -> 
             RGBColor[
              0.19834666787727806`, 0.32580530221707793`, 0.9346069213567869],
              UndirectedEdge[109, 249] -> 
             RGBColor[
              0.18318613987214505`, 0.3098706260506894, 0.9337435517148859], 
             UndirectedEdge[36, 61] -> 
             RGBColor[
              0.23146005042347673`, 0.36060956678284806`, 0.9364926795059334],
              UndirectedEdge[13, 232] -> 
             RGBColor[
              0.20186143048066912`, 0.3294995405620621, 0.9348070818874247], 
             UndirectedEdge[38, 119] -> 
             RGBColor[
              0.249257790450226, 0.37931611999285497`, 0.9375062344710599], 
             UndirectedEdge[91, 256] -> 
             RGBColor[
              0.792439933021371, 0.8356021745450866, 0.869137935086701], 
             UndirectedEdge[6, 69] -> 
             RGBColor[
              0.7494906190968638, 0.8040199624425932, 0.9761664746556911], 
             UndirectedEdge[90, 97] -> 
             RGBColor[
              0.2570968896215246, 0.3875555102494842, 0.9379526595719574], 
             UndirectedEdge[233, 257] -> 
             RGBColor[
              0.9698756400386146, 0.9770538821816868, 0.9358768631099392], 
             UndirectedEdge[66, 119] -> 
             RGBColor[
              0.21795851687042844`, 0.3464185989719241, 0.9357237871438162], 
             UndirectedEdge[33, 116] -> 
             RGBColor[
              0.24330530459768918`, 0.3730596799524376, 0.9371672492076716], 
             UndirectedEdge[335, 349] -> 
             RGBColor[
              0.19833951424086566`, 0.32579778329164166`, 0.9346065139677762],
              UndirectedEdge[165, 274] -> 
             RGBColor[
              0.21434019517096867`, 0.34261551345094576`, 0.9355177290758593],
              UndirectedEdge[95, 169] -> 
             RGBColor[
              0.3522449518778092, 0.4737241407933565, 0.9439035250794346], 
             UndirectedEdge[135, 259] -> 
             RGBColor[
              0.6153899363844033, 0.6921704499321857, 0.9662385558858466], 
             UndirectedEdge[93, 273] -> 
             RGBColor[
              0.433287316679902, 0.5477930013754455, 0.949360282412582], 
             UndirectedEdge[89, 263] -> 
             RGBColor[
              0.2670289628172794, 0.39799474890803455`, 0.93851827644727], 
             UndirectedEdge[71, 289] -> 
             RGBColor[
              0.7219591346417744, 0.780476707159252, 0.9439593282102003], 
             UndirectedEdge[32, 215] -> 
             RGBColor[
              0.7637949188808839, 0.4683581448483874, 0.5697890053389816], 
             UndirectedEdge[8, 239] -> 
             RGBColor[
              0.3813679879787836, 0.49836836108207505`, 0.9461050956090218], 
             UndirectedEdge[110, 111] -> 
             RGBColor[
              0.8397873767221564, 0.5455755079920095, 0.5794773016000505], 
             UndirectedEdge[29, 162] -> 
             RGBColor[
              0.19056901057120365`, 0.3176304912564385, 0.9341639952792189], 
             UndirectedEdge[337, 353] -> 
             RGBColor[
              0.9751195109230872, 0.9777137367216755, 0.7327280786411184], 
             UndirectedEdge[306, 308] -> 
             RGBColor[
              0.2175738595337591, 0.3460142997224009, 0.9357018814775424], 
             UndirectedEdge[185, 190] -> 
             RGBColor[
              0.20235115482293997`, 0.33001427189610544`, 0.9348349709642347],
              UndirectedEdge[71, 385] -> 
             RGBColor[
              0.9820607295061435, 0.9836969405379016, 0.7849671104328407], 
             UndirectedEdge[146, 158] -> 
             RGBColor[
              0.1951348259562785, 0.3224294527155677, 0.9344240117108803], 
             UndirectedEdge[157, 386] -> 
             RGBColor[
              0.2943941268277438, 0.42368947103286164`, 0.9401890092515732], 
             UndirectedEdge[24, 124] -> 
             RGBColor[
              0.24340021238043813`, 0.3731594340496077, 0.9371726540654957], 
             UndirectedEdge[22, 74] -> 
             RGBColor[
              0.24528340650250224`, 0.37513879047330073`, 0.9372798991848111],
              UndirectedEdge[303, 385] -> 
             RGBColor[
              0.9441738208357854, 0.8008555462181073, 0.4334857922002555], 
             UndirectedEdge[130, 317] -> 
             RGBColor[
              0.20208377375464914`, 0.3297332374403929, 0.9348197440079504], 
             UndirectedEdge[73, 291] -> 
             RGBColor[
              0.19698615809912115`, 0.32437532017893284`, 0.9345294423376147],
              UndirectedEdge[241, 255] -> 
             RGBColor[
              0.32755009808125596`, 0.4555556663672059, 0.9421864088801596], 
             UndirectedEdge[385, 400] -> 
             RGBColor[
              0.9082664009347345, 0.5807304681405772, 0.40128873459150277`], 
             UndirectedEdge[130, 311] -> 
             RGBColor[
              0.20912979631755016`, 0.33713905389763504`, 0.9352210045692514],
              UndirectedEdge[143, 308] -> 
             RGBColor[
              0.2058756118794577, 0.33371869972598955`, 0.9350356835796365], 
             UndirectedEdge[297, 397] -> 
             RGBColor[
              0.33036980779411174`, 0.4594447802808611, 0.9423131030091806], 
             UndirectedEdge[237, 324] -> 
             RGBColor[
              0.18395646599811732`, 0.31068028765058353`, 0.9337874206481647],
              UndirectedEdge[107, 160] -> 
             RGBColor[
              0.20918830325598364`, 0.33720054839948277`, 0.935224336452842], 
             UndirectedEdge[125, 185] -> 
             RGBColor[
              0.1925739180479394, 0.31973777613296384`, 0.9342781717940241], 
             UndirectedEdge[269, 388] -> 
             RGBColor[
              0.3120924130263679, 0.44123041621648995`, 0.9412357516492327], 
             UndirectedEdge[47, 300] -> 
             RGBColor[
              0.18858263454534693`, 0.31554268410974895`, 0.9340508741031263],
              UndirectedEdge[37, 365] -> 
             RGBColor[
              0.29517424252624735`, 0.4275772223959621, 0.9401211084894857], 
             UndirectedEdge[356, 389] -> 
             RGBColor[
              0.969253418800837, 0.9732437196326836, 0.7351124459689012], 
             UndirectedEdge[227, 243] -> 
             RGBColor[
              0.2526928974888643, 0.38292663528882953`, 0.9377018587351249], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.1986316801099837, 0.3261048681444708, 0.9346231523818017], 
             UndirectedEdge[186, 348] -> 
             RGBColor[
              0.2038426026857459, 0.33158187816317064`, 0.9349199067136222], 
             UndirectedEdge[61, 90] -> 
             RGBColor[
              0.21641762089155886`, 0.3447990195996844, 0.935636035397371], 
             UndirectedEdge[72, 325] -> 
             RGBColor[
              0.35190435537579295`, 0.4723760276667679, 0.9439742559127038], 
             UndirectedEdge[341, 358] -> 
             RGBColor[
              0.26347030119752707`, 0.39425436991349627`, 0.9383156159325932],
              UndirectedEdge[102, 337] -> 
             RGBColor[
              0.6530069899856277, 0.722086925969716, 0.9505841497129952], 
             UndirectedEdge[297, 378] -> 
             RGBColor[
              0.2683985374759716, 0.3994342587103688, 0.9385962716979784], 
             UndirectedEdge[300, 370] -> 
             RGBColor[
              0.19085384504698283`, 0.3179298703500313, 0.9341802161812396], 
             UndirectedEdge[46, 52] -> 
             RGBColor[
              0.89726556755869, 0.9188637535063902, 0.9066512485949225], 
             UndirectedEdge[75, 200] -> 
             RGBColor[
              0.1879784206462758, 0.3149076169924513, 0.9340164650154286], 
             UndirectedEdge[204, 343] -> 
             RGBColor[
              0.1903303530090651, 0.3173796470268675, 0.9341504040841173], 
             UndirectedEdge[32, 199] -> 
             RGBColor[
              0.9051273093812517, 0.578009485902768, 0.5022905305219902], 
             UndirectedEdge[301, 313] -> 
             RGBColor[
              0.2672428397382781, 0.39821954711258417`, 0.9385304564215183], 
             UndirectedEdge[166, 363] -> 
             RGBColor[
              0.3098501203432949, 0.43692070785172515`, 0.9411795622408922], 
             UndirectedEdge[333, 353] -> 
             RGBColor[
              0.97351816640208, 0.9765194565998694, 0.7354387372176427], 
             UndirectedEdge[130, 146] -> 
             RGBColor[
              0.20739635899717102`, 0.3353171013676426, 0.9351222878782466], 
             UndirectedEdge[71, 271] -> 
             RGBColor[
              0.8948533141221586, 0.565840640212504, 0.5514777902284453], 
             UndirectedEdge[123, 332] -> 
             RGBColor[
              0.8304813654821182, 0.2352987088808914, 0.17682229605044186`], 
             UndirectedEdge[340, 361] -> 
             RGBColor[
              0.34048302917169776`, 0.46587738706068504`, 0.9430427098372054],
              UndirectedEdge[165, 322] -> 
             RGBColor[
              0.2103258844391586, 0.3383962183498125, 0.9352891200183233], 
             UndirectedEdge[278, 302] -> 
             RGBColor[
              0.19139766926121787`, 0.31850146407963903`, 0.9342111861657245],
              UndirectedEdge[322, 355] -> 
             RGBColor[
              0.2016258404569241, 0.32925192050983587`, 0.9347936653840967], 
             UndirectedEdge[68, 333] -> 
             RGBColor[
              0.8876904453290742, 0.9128181118706356, 0.9729875018597351], 
             UndirectedEdge[150, 156] -> 
             RGBColor[
              0.22013918030941965`, 0.34871061450835156`, 0.9358479727006643],
              UndirectedEdge[29, 357] -> 
             RGBColor[
              0.18592235681432462`, 0.3127465635430944, 0.9338993752218727], 
             UndirectedEdge[250, 325] -> 
             RGBColor[
              0.21599606078555122`, 0.34435593319981583`, 0.9356120281729761],
              UndirectedEdge[53, 131] -> 
             RGBColor[
              0.6083578580504109, 0.6889233390243821, 0.9644906126536026], 
             UndirectedEdge[92, 267] -> 
             RGBColor[
              0.20096723062757926`, 0.3285596798209194, 0.9347561585286415], 
             UndirectedEdge[269, 309] -> 
             RGBColor[
              0.5253850164437505, 0.6220146854886827, 0.9571050895141], 
             UndirectedEdge[162, 336] -> 
             RGBColor[
              0.21504897720554328`, 0.3433604883086603, 0.9355580931641793], 
             UndirectedEdge[94, 204] -> 
             RGBColor[
              0.1795232819748228, 0.3060207301619996, 0.9335349573763461], 
             UndirectedEdge[29, 183] -> 
             RGBColor[
              0.18726251983199932`, 0.31415515984591347`, 0.9339756955231359],
              UndirectedEdge[145, 208] -> 
             RGBColor[
              0.2721455459278671, 0.4033726021673685, 0.9388096582861116], 
             UndirectedEdge[75, 133] -> 
             RGBColor[
              0.18265733709091148`, 0.3093148207995801, 0.9337134371787883], 
             UndirectedEdge[169, 326] -> 
             RGBColor[
              0.349415147686683, 0.47074983716853436`, 0.9437423719170701], 
             UndirectedEdge[95, 97] -> 
             RGBColor[
              0.27292796870059677`, 0.4041949781099764, 0.9388542161055278], 
             UndirectedEdge[37, 78] -> 
             RGBColor[
              0.25239861099731176`, 0.3826173215273665, 0.9376850995547887], 
             UndirectedEdge[55, 397] -> 
             RGBColor[
              0.5839584526615165, 0.6682303773203624, 0.9627494310951048], 
             UndirectedEdge[185, 226] -> 
             RGBColor[
              0.1922271263061977, 0.3193732760245269, 0.9342584225173644], 
             UndirectedEdge[39, 254] -> 
             RGBColor[
              0.19262591917799537`, 0.31979243261771473`, 0.934281133181452], 
             UndirectedEdge[71, 201] -> 
             RGBColor[
              0.8177089698538784, 0.8578529670679469, 0.9517417151457506], 
             UndirectedEdge[227, 383] -> 
             RGBColor[
              0.3161546993185588, 0.44504578365193476`, 0.9414837289337784], 
             UndirectedEdge[38, 151] -> 
             RGBColor[
              0.23316903340538708`, 0.36240581625261525`, 0.9365900035585395],
              UndirectedEdge[45, 74] -> 
             RGBColor[
              0.2441275547351621, 0.3739239169805914, 0.9372140751365906], 
             UndirectedEdge[292, 303] -> 
             RGBColor[
              0.8567109713559, 0.3810358674996849, 0.1997518680171543], 
             UndirectedEdge[185, 357] -> 
             RGBColor[
              0.18927662196416456`, 0.31627210888827, 0.9340903956599655], 
             UndirectedEdge[86, 376] -> 
             RGBColor[
              0.2771391258654599, 0.4086211712930332, 0.939094035276218], 
             UndirectedEdge[212, 309] -> 
             RGBColor[
              0.6375731061251859, 0.7158069480258249, 0.965187359754256], 
             UndirectedEdge[50, 127] -> 
             RGBColor[
              0.28524823564473223`, 0.4143130772255349, 0.9396595042068966], 
             UndirectedEdge[92, 374] -> 
             RGBColor[
              0.1940034937220554, 0.32124035080679264`, 0.9343595840137974], 
             UndirectedEdge[118, 141] -> 
             RGBColor[
              0.35660710592589273`, 0.4832968843838794, 0.9439436673476838], 
             UndirectedEdge[205, 390] -> 
             RGBColor[
              0.19906834334491935`, 0.32656382889043634`, 
               0.9346480197070459]}, GraphLayout -> {"Dimension" -> 2}, 
           ImageSize -> 500, VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.24987309085249598`, 0.3799628397279394, 0.9375412749187138], 
             316 -> RGBColor[
              0.7121412574025138, 0.7750494298476431, 0.9719432432656107], 
             308 -> RGBColor[
              0.212847764567014, 0.3410468742606238, 0.9354327373608172], 160 -> 
             RGBColor[
              0.19529547244710238`, 0.32259830236299947`, 0.9344331602908775],
              245 -> RGBColor[
              0.19489410730752896`, 0.3221764421532881, 0.9344103031399453], 
             155 -> RGBColor[
              0.1858996679095085, 0.31272271606557295`, 0.9338980831223087], 
             213 -> 
             RGBColor[
              0.3254133616442444, 0.45627843093029025`, 0.9419560295456021], 
             352 -> RGBColor[
              0.18638553952238943`, 0.3132333979367503, 0.9339257527918797], 
             27 -> RGBColor[
              0.20503271821821972`, 0.3328327650454837, 0.9349876820325784], 
             367 -> RGBColor[
              0.1860930553658944, 0.31292597854370746`, 0.9339090962518588], 
             19 -> RGBColor[
              0.19951285246669712`, 0.3270310361609309, 0.9346733338439388], 
             164 -> RGBColor[
              0.21499276582137244`, 0.3433014065798891, 0.935554892009008], 
             190 -> RGBColor[
              0.2121526703486752, 0.34031628616563087`, 0.9353931527733826], 
             103 -> RGBColor[
              0.19478977051563845`, 0.3220667775696765, 0.9344043613139996], 
             138 -> RGBColor[
              0.2889051941793347, 0.4209880551027343, 0.939764095460355], 291 -> 
             RGBColor[
              0.1954605501868454, 0.3227718095340026, 0.9344425612239453], 28 -> 
             RGBColor[
              0.19159599737019925`, 0.31870991949690686`, 0.9342224806581308],
              337 -> RGBColor[
              0.956979221732861, 0.9674357545252026, 0.9577071353769899], 195 -> 
             RGBColor[
              0.42461827381123246`, 0.5422047396654701, 0.9482772788254231], 
             114 -> RGBColor[
              0.18667779652152947`, 0.3135405785730105, 0.9339423963956253], 
             93 -> RGBColor[
              0.3425287629814334, 0.47110293132347947`, 0.9430466077842526], 
             34 -> RGBColor[
              0.1829376663072982, 0.30960946457990146`, 0.9337294015129516], 
             161 -> RGBColor[
              0.8795463410175769, 0.5459298918751729, 0.22120285316675511`], 
             22 -> RGBColor[
              0.24203296140503872`, 0.3717223665857442, 0.9370947911451132], 
             124 -> RGBColor[
              0.22661866237074535`, 0.3555209609776956, 0.9362169696185221], 
             84 -> RGBColor[
              0.21428709115836797`, 0.3425596977667136, 0.935514704880902], 
             46 -> RGBColor[
              0.8055364749096104, 0.8480104835941301, 0.9812520057187881], 
             241 -> RGBColor[
              0.28091140737960196`, 0.41258607834085864`, 0.939308861127858], 
             185 -> RGBColor[
              0.19254963929720473`, 0.31971225762658, 0.9342767891550869], 
             390 -> RGBColor[
              0.21298290042549683`, 0.3411889106159976, 0.9354404331480423], 
             121 -> 
             RGBColor[
              0.24372417422141443`, 0.37349993848484087`, 0.9371911032130806],
              322 -> RGBColor[
              0.1951112049063669, 0.3224046254944496, 0.9344226665270321], 
             126 -> RGBColor[
              0.18255935854789945`, 0.309211839138676, 0.9337078574457099], 
             236 -> RGBColor[
              0.5096359477486948, 0.612784447077024, 0.9545395551462174], 78 -> 
             RGBColor[
              0.22046571832082573`, 0.34905382666204504`, 0.9358665685573442],
              376 -> RGBColor[
              0.28617898913701123`, 0.4181226407518692, 0.9396088421162536], 
             254 -> RGBColor[
              0.1870776850955973, 0.3139608868187558, 0.9339651694583363], 
             290 -> RGBColor[
              0.25752973177491306`, 0.38801045479647306`, 0.9379773092922603],
              251 -> RGBColor[
              0.1849258667142184, 0.3116991892667612, 0.9338426265848467], 
             165 -> RGBColor[
              0.22554056397195027`, 0.35438781120517543`, 0.9361555735096144],
              100 -> RGBColor[
              0.387712192347488, 0.5102385468551641, 0.9459256559493198], 235 -> 
             RGBColor[
              0.19324911536591247`, 0.3204474513241361, 0.9343166232824178], 
             70 -> RGBColor[
              0.1969643686712329, 0.32435241810869275`, 0.934528201461931], 
             234 -> RGBColor[
              0.24693624036742998`, 0.3768760236610595, 0.9373740256282702], 
             257 -> RGBColor[
              0.9694202648664492, 0.9767142641238943, 0.9366476944955487], 
             135 -> RGBColor[
              0.335355251737071, 0.46488959643477135`, 0.9425895179910487], 
             265 -> RGBColor[
              0.19899652547638796`, 0.32648834375709396`, 0.934643929785678], 
             111 -> RGBColor[
              0.8266120846200963, 0.20555772064570646`, 0.17311706832724205`],
              381 -> RGBColor[
              0.1893487791980019, 0.3163479507160659, 0.9340945049076855], 
             182 -> RGBColor[
              0.24182762690147153`, 0.3715065470035356, 0.9370830976489003], 
             188 -> RGBColor[
              0.27580922111776024`, 0.4072233570823697, 0.9390182991682543], 
             154 -> RGBColor[
              0.18637271886218407`, 0.3132199226099977, 0.9339250226742475], 
             336 -> RGBColor[
              0.23480104226620413`, 0.36412116104067216`, 0.9366829440488222],
              315 -> RGBColor[
              0.1811098371299533, 0.3076883002234485, 0.9336253093453327], 
             368 -> 
             RGBColor[
              0.1838330998850932, 0.3105506220439319, 0.9337803951305317], 
             269 -> RGBColor[
              0.3534033382914345, 0.480521941884955, 0.9437395261069965], 208 -> 
             RGBColor[
              0.2944180010032382, 0.4267823646067975, 0.9400780416535094], 86 -> 
             RGBColor[
              0.2680992625939086, 0.39911970183419715`, 0.9385792284361825], 
             119 -> RGBColor[
              0.2397898236287226, 0.36936468655968646`, 0.936967047767177], 
             377 -> RGBColor[
              0.25469411239970985`, 0.38503003904448196`, 0.9378158249637654],
              140 -> RGBColor[
              0.4063466574019441, 0.5263787838898877, 0.9471130275847793], 85 -> 
             RGBColor[
              0.1818888062976524, 0.30850704620819813`, 0.9336696704870515], 
             351 -> RGBColor[
              0.3095548228305918, 0.44254256168324113`, 0.9409455374755513], 
             242 -> RGBColor[
              0.3403985574835718, 0.4692578543884732, 0.9429108729735957], 
             117 -> RGBColor[
              0.5585316039927765, 0.6524801435401812, 0.9583888003164419], 47 -> 
             RGBColor[
              0.18100426741029385`, 0.3075773397545796, 0.9336192973059745], 
             81 -> RGBColor[
              0.22915597848204, 0.35818784108579943`, 0.9363614660174375], 
             275 -> RGBColor[
              0.194144227344503, 0.3213882707670121, 0.934367598585399], 23 -> 
             RGBColor[
              0.2119196850624197, 0.340071403857656, 0.9353798846060012], 328 -> 
             RGBColor[
              0.2313516506730186, 0.3604956317721754, 0.9364865063005079], 
             110 -> RGBColor[
              0.8529626688242167, 0.8855932953383124, 0.985837534872859], 6 -> 
             RGBColor[
              0.9261633007621113, 0.943961492267368, 0.992819476494071], 218 -> 
             RGBColor[
              0.5602763464580424, 0.6538966040732364, 0.9585261528345099], 
             108 -> RGBColor[
              0.3063635945960659, 0.4393379408672382, 0.9407583255366989], 
             297 -> RGBColor[
              0.2965600408339725, 0.42903378428206873`, 0.9402000276530058], 
             157 -> RGBColor[
              0.24686136029389427`, 0.3767973199561026, 0.9373697613188575], 
             354 -> RGBColor[
              0.19610120868731518`, 0.3234451822380914, 0.9344790457777777], 
             385 -> RGBColor[
              0.9944175835604394, 0.9904681006416884, 0.633766605113725], 270 -> 
             RGBColor[
              0.20794500379241626`, 0.3358937618335345, 0.9351535323876885], 
             392 -> RGBColor[
              0.2030621295519029, 0.3307615514146469, 0.9348754599232564], 33 -> 
             RGBColor[
              0.24658940627570813`, 0.37651147904010834`, 0.9373542739398417],
              252 -> RGBColor[
              0.20594129701488287`, 0.33378773896799957`, 0.9350394242509266],
              394 -> RGBColor[
              0.35762511408731845`, 0.48417863188672844`, 0.9440085339275405],
              260 -> RGBColor[
              0.1889310324973132, 0.31590887244697147`, 0.9340707148510822], 
             159 -> RGBColor[
              0.18214142158537838`, 0.30877256089233246`, 0.9336840565539767],
              183 -> RGBColor[
              0.18868393066647376`, 0.3156491527555983, 0.9340566427673703], 
             99 -> RGBColor[
              0.9021660914511284, 0.9248267689496842, 0.9905306012474278], 
             329 -> RGBColor[
              0.2623389378177228, 0.3930652352687406, 0.9382511864618155], 
             309 -> RGBColor[
              0.6973666945960665, 0.7635074290924103, 0.9704706529212034], 17 -> 
             RGBColor[
              0.8276616884309496, 0.21362543547524793`, 0.17412217012187317`],
              349 -> RGBColor[
              0.19841472542917707`, 0.32587683501922177`, 0.9346107971336854],
              347 -> RGBColor[
              0.18432439621433888`, 0.3110670056359555, 0.9338083737296745], 
             340 -> RGBColor[
              0.27139200070452485`, 0.4025805783601091, 0.9387667450004126], 
             277 -> RGBColor[
              0.1851145385676597, 0.3118974953472144, 0.9338533711677852], 
             104 -> RGBColor[
              0.22404918964109946`, 0.35282028222485723`, 0.936070641947763], 
             79 -> RGBColor[
              0.199051197909799, 0.3265458079510415, 0.9346470432998802], 327 -> 
             RGBColor[
              0.18576331458524015`, 0.3125794000764668, 0.9338903180022083], 
             191 -> RGBColor[
              0.1840091371887301, 0.310735648411464, 0.9337904201945499], 50 -> 
             RGBColor[
              0.23112771995435683`, 0.3602602663888343, 0.9364737537773559], 
             225 -> RGBColor[
              0.2084820527788493, 0.336458234369148, 0.9351841165329731], 61 -> 
             RGBColor[
              0.21726621743653565`, 0.3456909483725835, 0.9356843617152213], 
             196 -> RGBColor[
              0.844124603334554, 0.8785460618197521, 0.9849945522966208], 1 -> 
             RGBColor[
              0.1818132732838514, 0.3084276562216236, 0.9336653689936567], 
             263 -> RGBColor[
              0.30183205672017543`, 0.43457500724358145`, 0.9405002611584765],
              201 -> RGBColor[
              0.6657140642559093, 0.738780153701779, 0.9673158145395446], 371 -> 
             RGBColor[
              0.18003320207443918`, 0.306556688517498, 0.93356399657166], 293 -> 
             RGBColor[
              0.3141297509318431, 0.44650513446197276`, 0.941237047848713], 
             362 -> RGBColor[
              0.7912709059084366, 0.8368661126680731, 0.979830147120073], 184 -> 
             RGBColor[
              0.21355297767290998`, 0.3417880979480139, 0.9354728982039288], 
             106 -> RGBColor[
              0.1865190623784995, 0.31337373892436005`, 0.9339333567210057], 
             206 -> RGBColor[
              0.4288884024290853, 0.5459033104513494, 0.9485493676450263], 
             358 -> RGBColor[
              0.2775970966062373, 0.4091025275786123, 0.9391201160323983], 
             247 -> RGBColor[
              0.8173387448883187, 0.1342787678638822, 0.16423690772735258`], 
             220 -> RGBColor[
              0.17970434930417156`, 0.30621104340547683`, 0.9335452688928874],
              107 -> RGBColor[
              0.2230811340648649, 0.3518027944359661, 0.9360155126148064], 
             375 -> RGBColor[
              0.20279567675606608`, 0.3304814926321394, 0.9348602858307151], 
             131 -> RGBColor[
              0.8141109072907318, 0.8547088953383618, 0.982106625005912], 127 -> 
             RGBColor[
              0.3393687513351076, 0.46836588806223545`, 0.9428452546364373], 
             210 -> RGBColor[
              0.2456807114445148, 0.37555638315794415`, 0.9373025251134988], 
             357 -> RGBColor[
              0.18600360463112436`, 0.31283196014996, 0.9339040021648441], 
             181 -> RGBColor[
              0.19212227783830665`, 0.31926307363699663`, 0.9342524515522274],
              194 -> RGBColor[
              0.4554399226734993, 0.5687856724178738, 0.9502730455257168], 
             118 -> RGBColor[
              0.3574473894517768, 0.48402469574012214`, 0.9439972094709195], 
             348 -> RGBColor[
              0.20110409825488346`, 0.3287035363751249, 0.9347639529375389], 
             276 -> RGBColor[
              0.37904525788294496`, 0.5027316838347692, 0.9453734065491083], 
             305 -> RGBColor[
              0.29805944165302733`, 0.4306097496103981, 0.9402854163114862], 
             343 -> 
             RGBColor[
              0.20071986914810575`, 0.3282996872223691, 0.9347420716583239], 
             280 -> RGBColor[
              0.2089289786028837, 0.3369279817469421, 0.9352095682974844], 
             189 -> RGBColor[
              0.2331737072204319, 0.36241072872856434`, 0.9365902697253919], 
             168 -> RGBColor[
              0.19796437105250972`, 0.32540348401522773`, 0.9345851501181738],
              363 -> RGBColor[
              0.3745258073527012, 0.4988171629396605, 0.9450854311577144], 41 -> 
             RGBColor[
              0.19479503600678127`, 0.322072311934719, 0.9344046611759306], 
             14 -> RGBColor[
              0.3386493168091526, 0.46774275003568394`, 0.9427994129046144], 
             77 -> RGBColor[
              0.1969521059625652, 0.3243395292243824, 0.9345275031188135], 51 -> 
             RGBColor[
              0.20120879960667537`, 0.3288135841343073, 0.9347699155246316], 
             179 -> RGBColor[
              0.2268131918331927, 0.35572542377660804`, 0.9362280477836279], 
             223 -> RGBColor[
              0.8592163258347785, 0.4536160411257659, 0.20423899016395516`], 
             323 -> RGBColor[
              0.42062186552277797`, 0.5387432516713317, 0.9480226312231679], 
             292 -> RGBColor[
              0.8194918846006688, 0.15082874320484374`, 0.1662987567475226], 
             396 -> RGBColor[
              0.18439801323969868`, 0.31114438179719767`, 0.9338125661103621],
              321 -> RGBColor[
              0.18455342051778426`, 0.3113077246998561, 0.9338214163249446], 
             143 -> RGBColor[
              0.19890345919190142`, 0.32639052519135536`, 0.9346386297984558],
              112 -> RGBColor[
              0.1804406002012431, 0.3069848897793021, 0.93358719729229], 197 -> 
             RGBColor[
              0.19131157595015044`, 0.3184109745510759, 0.9342062832790229], 
             54 -> RGBColor[
              0.9482538006021336, 0.8325505933258706, 0.2772219972063093], 71 -> 
             RGBColor[
              0.9697038754518477, 0.9769257804341147, 0.9361676157519565], 
             177 -> RGBColor[
              0.18139651046953492`, 0.3079896120794884, 0.9336416349679267], 
             158 -> RGBColor[
              0.1911403477299942, 0.3182310028351955, 0.9341965320851944], 
             226 -> RGBColor[
              0.19190461331519068`, 0.3190342944224739, 0.9342400558796418], 
             350 -> RGBColor[
              0.3485452682138572, 0.4763141257574593, 0.943429974177476], 203 -> 
             RGBColor[
              0.3100095560527289, 0.44293642874469996`, 0.9409745126743612], 
             115 -> RGBColor[
              0.9551078718556497, 0.8597247018622127, 0.2827369438226184], 
             173 -> RGBColor[
              0.17959143492855675`, 0.30609236323752076`, 0.933538838586238], 
             212 -> RGBColor[
              0.5777795176543054, 0.6681064669592394, 0.9599040665873084], 
             129 -> RGBColor[
              0.8193361618613183, 0.1496317899920564, 0.1661496364764569], 
             279 -> RGBColor[
              0.1990369147875074, 0.3265307954839108, 0.9346462298971957], 26 -> 
             RGBColor[
              0.1822568035379685, 0.30889383464014303`, 0.9336906273854845], 
             40 -> RGBColor[
              0.1934487547814754, 0.32065728500776275`, 0.934327992451794], 
             146 -> RGBColor[
              0.1991293041825628, 0.32662790259593993`, 0.9346514913365662], 
             386 -> RGBColor[
              0.3419268933615933, 0.4705816221096207, 0.9430082571842888], 
             192 -> RGBColor[
              0.2582664433427927, 0.3887847853645258, 0.938019263926184], 300 -> 
             RGBColor[
              0.19616100168040002`, 0.3235080284649182, 0.934482450900278], 
             221 -> RGBColor[
              0.36991176607450643`, 0.49482071229294583`, 0.9447914285275043],
              62 -> RGBColor[
              0.9918038536315829, 0.990878697092375, 0.7854948864789351], 286 -> 
             RGBColor[
              0.3212434064694567, 0.45266662534593033`, 0.9416903236892111], 
             152 -> RGBColor[
              0.2008438754397465, 0.3284300256973365, 0.9347491336331819], 64 -> 
             RGBColor[
              0.9925852496598342, 0.986548923705669, 0.43432836788688456`], 
             307 -> RGBColor[
              0.17902996710188124`, 0.3055022249525685, 0.933506863824126], 
             37 -> RGBColor[
              0.2843315036737978, 0.41618081639268795`, 0.9395036305522334], 
             148 -> RGBColor[
              0.25655300447979307`, 0.38698385248121464`, 0.9379216861177417],
              261 -> RGBColor[
              0.18920356017618423`, 0.31619531631671777`, 0.9340862348992254],
              387 -> RGBColor[
              0.18554205504628538`, 0.3123468422723603, 0.933877717598789], 
             15 -> RGBColor[
              0.18212992963139682`, 0.3087604821200659, 0.9336834021041983], 
             136 -> RGBColor[
              0.18263620644148504`, 0.30929261114727236`, 0.9337122338195634],
              198 -> 
             RGBColor[
              0.8287975688378628, 0.8663247005533589, 0.9835326460637211], 63 -> 
             RGBColor[
              0.18932442036239164`, 0.31632234803540016`, 0.9340931177080333],
              310 -> RGBColor[
              0.8265166883216026, 0.20482446289255998`, 0.17302571672406986`],
              171 -> RGBColor[
              0.18805335571358273`, 0.3149863784993486, 0.9340207324566552], 
             395 -> RGBColor[
              0.4386808762090538, 0.554385059055515, 0.9491733354151413], 311 -> 
             RGBColor[
              0.2025961788233211, 0.3302718076559249, 0.934848924718576], 353 -> 
             RGBColor[
              0.9932598001133134, 0.9879917189181485, 0.507749021905247], 59 -> 
             RGBColor[
              0.21627237251575757`, 0.34464635434743823`, 0.9356277637172448],
              397 -> RGBColor[
              0.36417957475425095`, 0.48985577627965343`, 0.9444261783653554],
              229 -> RGBColor[
              0.19792175174780763`, 0.3253586884237658, 0.9345827230118207], 
             102 -> RGBColor[
              0.34903475823839447`, 0.4767380974142295, 0.9434611640490004], 
             299 -> RGBColor[
              0.18838969891108812`, 0.3153398965253172, 0.9340398867041779], 
             128 -> RGBColor[
              0.3039019362504366, 0.4367505818678281, 0.9406181377356125], 12 -> 
             RGBColor[
              0.242785484860208, 0.37251331644986996`, 0.9371376462426264], 
             222 -> RGBColor[
              0.9510874915293103, 0.9630417117862173, 0.9676802978022608], 92 -> 
             RGBColor[
              0.20437042968316516`, 0.3321366578036229, 0.9349499656802752], 
             271 -> RGBColor[
              0.8200027527924696, 0.15475549999089333`, 0.1667879647049341], 
             361 -> RGBColor[
              0.40957405763887067`, 0.529174195761261, 0.9473186746739982], 
             344 -> RGBColor[
              0.1915625031716876, 0.3186747149706162, 0.9342205732130758], 
             132 -> RGBColor[
              0.19287402797566439`, 0.32005321069507126`, 0.9342952626104353],
              80 -> RGBColor[
              0.20310658273494972`, 0.3308082745285237, 0.9348779914662683], 
             324 -> RGBColor[
              0.1856877903127057, 0.31250001927751764`, 0.9338860170066157], 
             244 -> RGBColor[
              0.18235944175044905`, 0.3090017139090986, 0.9336964724798456], 
             150 -> RGBColor[
              0.23840666361665402`, 0.3679108976895925, 0.9368882788506916], 
             125 -> 
             RGBColor[
              0.1925981967986741, 0.3197632946393477, 0.9342795544329613], 
             258 -> RGBColor[
              0.23765262088408304`, 0.3671183509685898, 0.9368453372325779], 
             133 -> RGBColor[
              0.18340497994045135`, 0.3101006408377411, 0.933756014333031], 
             255 -> RGBColor[
              0.37418878878290995`, 0.4985252543935531, 0.9450639566324611], 
             326 -> RGBColor[
              0.24157157412247404`, 0.37123741929812537`, 0.9370685158219325],
              176 -> RGBColor[
              0.18620451936940718`, 0.3130431342786254, 0.9339154439619627], 
             230 -> RGBColor[
              0.2211253737681676, 0.3497471663617724, 0.9359041349591976], 
             274 -> RGBColor[
              0.20313982636998706`, 0.33084321569671615`, 0.9348798846421041],
              87 -> RGBColor[
              0.18684859723136407`, 0.31372010094843716`, 0.9339521232433733],
              130 -> RGBColor[
              0.21566341381177923`, 0.3440063001393452, 0.9355930844199268], 
             35 -> RGBColor[
              0.19009976398754364`, 0.3171372833450601, 0.9341372723804675], 
             379 -> RGBColor[
              0.18246816409549027`, 0.30911598798713175`, 0.9337026640565553],
              31 -> RGBColor[
              0.9842583887354778, 0.9877584534482328, 0.9105427668445933], 18 -> 
             RGBColor[
              0.9925358512363838, 0.9864432654728553, 0.42895165434603927`], 
             24 -> RGBColor[
              0.2601817623901309, 0.39079790712151985`, 0.9381283385124692], 
             151 -> RGBColor[
              0.20761230953904478`, 0.335544079079207, 0.935134585942136], 
             137 -> RGBColor[
              0.29264465833089975`, 0.42491846902175034`, 0.9399770524117451],
              330 -> RGBColor[
              0.18870039039885345`, 0.3156664529779366, 0.9340575801247794], 
             296 -> RGBColor[
              0.17907641669607907`, 0.3055510464211448, 0.9335095090597996], 
             266 -> RGBColor[
              0.6582217134144572, 0.7329270722804612, 0.9665690470276681], 
             302 -> RGBColor[
              0.19470143524485908`, 0.32197393159930776`, 0.9343993307510091],
              283 -> RGBColor[
              0.9319225428018962, 0.7678025982169813, 0.26408148383634866`], 
             388 -> RGBColor[
              0.2707814877613013, 0.40193889054802484`, 0.938731977191469], 
             284 -> RGBColor[
              0.7398648594018855, 0.7967073184367315, 0.9747064728211174], 
             318 -> 
             RGBColor[
              0.21345649486519924`, 0.3416866883997466, 0.9354674036507632], 
             238 -> RGBColor[
              0.20088219976865415`, 0.32847030699692126`, 0.9347513161470175],
              72 -> RGBColor[
              0.46553671991296847`, 0.576982707272407, 0.9510679023901947], 
             288 -> RGBColor[
              0.2137339467700851, 0.34197830794324846`, 0.935483204126293], 
             382 -> RGBColor[
              0.3220959675484921, 0.453405070901625, 0.9417446481272771], 389 -> 
             RGBColor[
              0.9931232770303468, 0.9876997098482838, 0.4928893268471293], 
             172 -> RGBColor[
              0.3796233347917912, 0.5032323849982215, 0.9454102410985666], 
             243 -> RGBColor[
              0.23139395253121084`, 0.36054009370722817`, 0.9364889153287519],
              88 -> RGBColor[
              0.4303958842275222, 0.5472090154169172, 0.9486454230522088], 
             273 -> RGBColor[
              0.5240458703783706, 0.6244830714274116, 0.9556739570409113], 
             202 -> RGBColor[
              0.3275914997751332, 0.4581650247028605, 0.9420948185812503], 
             393 -> RGBColor[
              0.7219717591850786, 0.7827290925547635, 0.9729230558120345], 98 -> 
             RGBColor[
              0.1932487717488401, 0.3204470901608064, 0.9343166037139339], 30 -> 
             RGBColor[
              0.20069898841488326`, 0.3282777402478373, 0.9347408825314572], 
             116 -> RGBColor[
              0.24002120291967022`, 0.3696078808647668, 0.9369802244755014], 
             373 -> RGBColor[
              0.19798515205544082`, 0.3254253261669, 0.934586333565548], 240 -> 
             RGBColor[
              0.17933281357579656`, 0.305820535798229, 0.9335241104827943], 
             317 -> RGBColor[
              0.18850413369751906`, 0.3154601747414406, 0.9340464035959741], 
             391 -> RGBColor[
              0.8202342132018924, 0.1565346061243149, 0.16700961145439447`], 
             73 -> RGBColor[
              0.1985117660113969, 0.3259788308238631, 0.9346163234512842], 
             303 -> RGBColor[
              0.8939300581111314, 0.611242991794526, 0.23320497928678602`], 
             29 -> RGBColor[
              0.18584110899752487`, 0.3126611669362287, 0.9338947482789014], 
             360 -> RGBColor[
              0.6627555094400547, 0.736468908193784, 0.9670209334447669], 320 -> 
             RGBColor[
              0.18370800885926494`, 0.3104191434445573, 0.9337732713816664], 
             75 -> 
             RGBColor[
              0.18190969424137163`, 0.30852900076141915`, 0.9336708600245455],
              200 -> RGBColor[
              0.19404714705117995`, 0.3212862332234835, 0.9343620700063117], 
             301 -> RGBColor[
              0.24986810421890843`, 0.3799575984598681, 0.937540990937308], 
             156 -> RGBColor[
              0.20187169700218524`, 0.3295103313271106, 0.9348076665506371], 
             25 -> RGBColor[
              0.3639618362230004, 0.489667182107741, 0.9444123042586827], 38 -> 
             RGBColor[
              0.2587257572717294, 0.3892675534260234, 0.9380454211749428], 
             365 -> RGBColor[
              0.30601698137869693`, 0.43897362839923615`, 0.940738586426738], 
             380 -> RGBColor[
              0.7203821791624184, 0.7814873005598058, 0.9727646213308456], 
             370 -> RGBColor[
              0.18554668841356567`, 0.31235171223514435`, 0.9338779814622011],
              3 -> RGBColor[
              0.23621542372166607`, 0.36560776562732644`, 0.9367634909803209],
              57 -> RGBColor[
              0.3482989604247025, 0.47610078633028297`, 0.9434142796629524], 
             227 -> RGBColor[
              0.2739918424465178, 0.40531317687043084`, 0.9389148021414978], 
             39 -> RGBColor[
              0.19817415326039348`, 0.32562397841667373`, 0.9345970969045678],
              109 -> RGBColor[
              0.1827503081177702, 0.3094125392435122, 0.9337187317412295], 
             256 -> RGBColor[
              0.9923039511135691, 0.9910855002530954, 0.777206976991627], 339 -> 
             RGBColor[
              0.38195753878243316`, 0.5052541551744117, 0.9455589745127948], 
             287 -> RGBColor[0.817319, 0.134127, 0.164218], 239 -> 
             RGBColor[
              0.5071373117219987, 0.6107559417882819, 0.9543428533653905], 
             285 -> RGBColor[
              0.18427610046840573`, 0.31101624374485265`, 0.9338056233583907],
              345 -> RGBColor[
              0.8280837295399454, 0.865755504473851, 0.9834645594342339], 366 -> 
             RGBColor[
              0.9933000584574108, 0.9880778274454297, 0.5121308942145434], 
             216 -> RGBColor[
              0.21581639795358076`, 0.3441670961721334, 0.9356017966404827], 
             21 -> RGBColor[
              0.19666790482252822`, 0.3240408158068105, 0.9345113182843263], 
             355 -> RGBColor[
              0.2081404760074813, 0.3360992155252221, 0.9351646642411613], 
             175 -> RGBColor[
              0.19013667027984396`, 0.3171760741982618, 0.9341393741392161], 
             7 -> RGBColor[
              0.25494849258932906`, 0.3852974087524073, 0.9378303115392425], 
             13 -> RGBColor[
              0.21336291477373137`, 0.3415883297902934, 0.9354620744029933], 
             294 -> RGBColor[
              0.20973292712492791`, 0.3377729826168909, 0.9352553519764795], 
             193 -> RGBColor[
              0.8379281346647119, 0.8736051659010814, 0.9844035275832383], 60 -> 
             RGBColor[
              0.7070237961498369, 0.7710516302229059, 0.9714331825533382], 65 -> 
             RGBColor[
              0.3764941167365503, 0.5005220135978444, 0.9452108500911456], 69 -> 
             RGBColor[
              0.5728179374316162, 0.6640784326178184, 0.9595134728173111], 
             217 -> RGBColor[
              0.2082469591636211, 0.3362111360737471, 0.9351707282993756], 
             214 -> RGBColor[
              0.8789213821202363, 0.5430920994852084, 0.22068137214366979`], 
             170 -> RGBColor[
              0.23550398192177388`, 0.3648599951876243, 0.9367229754223009], 
             359 -> RGBColor[
              0.32568965645452963`, 0.4565177436079784, 0.9419736348065956], 
             74 -> RGBColor[
              0.24853385159996577`, 0.37855521436085726`, 0.9374650072245091],
              246 -> RGBColor[
              0.2167015948028579, 0.34509749418544555`, 0.9356522072915177], 
             264 -> RGBColor[
              0.2599789274537134, 0.39058471474286727`, 0.9381167873629076], 
             278 -> RGBColor[
              0.1880939032775767, 0.3150289965599703, 0.9340230415804399], 45 -> 
             RGBColor[
              0.23972125787035842`, 0.36929261960032556`, 0.9369631430486721],
              306 -> RGBColor[
              0.22229995450050422`, 0.350981725184178, 0.9359710255942676], 
             237 -> RGBColor[
              0.18222514168352894`, 0.3088605560236495, 0.9336888242897137], 
             228 -> RGBColor[
              0.22400797509009437`, 0.3527769631185974, 0.9360682948400547], 
             180 -> RGBColor[
              0.18842432755960442`, 0.31537629343049095`, 0.9340418587544824],
              383 -> RGBColor[
              0.3583175561905998, 0.4847783904334387, 0.944052655726059], 53 -> 
             RGBColor[
              0.40260480881009003`, 0.5231377827104023, 0.9468746003012931], 
             304 -> RGBColor[
              0.2822705085644714, 0.4140145798581486, 0.9393862599297264], 48 -> 
             RGBColor[
              0.20793893985757575`, 0.3358873882535414, 0.9351531870555702], 
             5 -> RGBColor[
              0.18681770269069906`, 0.3136876288273712, 0.9339503638449868], 
             101 -> RGBColor[
              0.8539737461394735, 0.41587144104017043`, 0.19931862629877445`],
              333 -> RGBColor[
              0.9537765326908467, 0.9650471942815904, 0.9631284525300384], 
             267 -> RGBColor[
              0.19756403157199334`, 0.32498270183821587`, 0.9345623513770076],
              120 -> RGBColor[
              0.41254771032069193`, 0.531749824254125, 0.9475081531933861], 
             147 -> RGBColor[
              0.24721508689536167`, 0.3771691090418067, 0.9373899055255195], 
             89 -> RGBColor[
              0.23222586891438338`, 0.3614144905724877, 0.9365362917360636], 
             43 -> RGBColor[
              0.194697223000598, 0.3219695042635176, 0.9343990908699299], 199 -> 
             RGBColor[
              0.9887357523774989, 0.9896099583772056, 0.8363412642506296], 
             268 -> RGBColor[
              0.187660141527025, 0.31457308545805707`, 0.933998339490439], 
             169 -> RGBColor[
              0.45725872125089195`, 0.5702622550389433, 0.9504162280122078], 
             20 -> RGBColor[
              0.3846257063952153, 0.5075651878546001, 0.9457289877937134], 4 -> 
             RGBColor[
              0.2008450066857079, 0.32843121470856707`, 0.9347491980559659], 
             167 -> RGBColor[
              0.2358064817309028, 0.3651779416666145, 0.9367402023389224], 
             142 -> RGBColor[
              0.4741596199861951, 0.5839831660090739, 0.9517467286706829], 16 -> 
             RGBColor[
              0.22895368331262583`, 0.3579752160364906, 0.9363499456068083], 
             281 -> RGBColor[
              0.39875120665503094`, 0.5197999862113661, 0.9466290521795794], 
             289 -> RGBColor[
              0.4742143938317012, 0.5840276338843894, 0.9517510406684443], 
             398 -> RGBColor[
              0.1808071689883251, 0.3073701768163288, 0.9336080728424244], 
             178 -> RGBColor[
              0.18300767959384703`, 0.309683052983163, 0.9337333886660452], 
             58 -> RGBColor[
              0.19320352841391442`, 0.32039953654720643`, 0.9343140271729413],
              186 -> RGBColor[
              0.2065811071166083, 0.33446021995121644`, 0.9350758604897056], 
             122 -> RGBColor[
              0.18936604401309215`, 0.31636609713137825`, 0.934095488113364], 
             249 -> 
             RGBColor[
              0.18362197162651986`, 0.31032871285786656`, 0.9337683716885422],
              113 -> RGBColor[
              0.1856485479005117, 0.3124587730141891, 0.9338837822092951], 52 -> 
             RGBColor[
              0.9889946602077696, 0.9897170234186503, 0.8320504914710569], 
             187 -> RGBColor[
              0.21634716160662554`, 0.34472496242384276`, 0.9356320228453292],
              259 -> RGBColor[
              0.8954246210317355, 0.9194513034296, 0.9898875937806444], 42 -> 
             RGBColor[
              0.183885630512114, 0.31060583506356493`, 0.9337833866720284], 
             134 -> RGBColor[
              0.17911500115561352`, 0.3055916011345115, 0.9335117063876894], 
             313 -> RGBColor[
              0.28461757525764775`, 0.41648149576530025`, 0.9395199219057286],
              248 -> RGBColor[
              0.1829127869860106, 0.3095833148357881, 0.9337279846724099], 
             174 -> RGBColor[
              0.41783566912403936`, 0.5363299883890472, 0.947845097252377], 
             215 -> RGBColor[
              0.7060709713767632, 0.7703072762684443, 0.9713382138846121], 
             399 -> RGBColor[
              0.3593758114062829, 0.48569499791180964`, 0.944120086812624], 
             83 -> RGBColor[
              0.9509849302078126, 0.9629652217205732, 0.9678539073672795], 95 -> 
             RGBColor[
              0.24723118250472642`, 0.37718602654776967`, 0.9373908221466615],
              166 -> RGBColor[
              0.2451744333338886, 0.3750242527637898, 0.93727369332407], 384 -> 
             RGBColor[
              0.9335847383251342, 0.7743926495727972, 0.2654189253710895], 
             233 -> RGBColor[
              0.9703310152107799, 0.9773935002394792, 0.9351060317243296], 
             295 -> RGBColor[
              0.18590102371033476`, 0.3127241410982041, 0.9338981603331601], 
             141 -> RGBColor[
              0.3557668224000087, 0.48256907302763663`, 0.9438901252244479], 
             319 -> RGBColor[
              0.8324443832728455, 0.2503873238203034, 0.17870208410375396`], 
             205 -> RGBColor[
              0.18515378626434187`, 0.3119387471648751, 0.9338556062660495], 
             224 -> RGBColor[
              0.4977475489543879, 0.6031329093695432, 0.9536036568444898], 
             231 -> RGBColor[
              0.19120668731506069`, 0.31830072994527303`, 0.9342003100264233],
              332 -> RGBColor[
              0.8178049183525352, 0.13786198138836525`, 0.164683315963154], 
             68 -> 
             RGBColor[
              0.8216043579673015, 0.8605890294596807, 0.9828465511894319], 10 -> 
             RGBColor[
              0.8429670986480872, 0.3312695252776902, 0.18877864823079255`], 
             250 -> RGBColor[
              0.19372013073248498`, 0.3209425183385029, 0.9343434469107393], 
             282 -> RGBColor[
              0.31502354175322494`, 0.44727929114822085`, 0.9412939994095033],
              374 -> RGBColor[
              0.1836365577609456, 0.3103440438099624, 0.9337692023473195], 
             232 -> RGBColor[
              0.19035994618760685`, 0.3174107513338308, 0.934152089371856], 
             253 -> RGBColor[
              0.8251923969012658, 0.19464537872765014`, 0.17175757376438203`],
              55 -> RGBColor[
              0.8037373305687819, 0.8466049783610714, 0.9810726838248541], 
             325 -> RGBColor[
              0.23827199083861747`, 0.36776934806112876`, 0.9368806094352129],
              91 -> RGBColor[
              0.5925759149291727, 0.6801188488370776, 0.961068893181775], 105 -> 
             RGBColor[
              0.9853022906708313, 0.9881901337255575, 0.8932426102441758], 36 -> 
             RGBColor[
              0.24565388341041777`, 0.3755281851931126, 0.9373009972966455], 
             123 -> RGBColor[
              0.843157812611701, 0.33273543637341757`, 0.18896127613772973`], 
             94 -> RGBColor[
              0.1791057270796212, 0.3055818534926332, 0.9335111782427814], 
             312 -> RGBColor[
              0.5478165382686445, 0.6437811704771209, 0.9575452710920592], 96 -> 
             RGBColor[
              0.21162927735784165`, 0.3397661669472325, 0.9353633463168451], 
             2 -> RGBColor[
              0.20182540810126717`, 0.3294616787573599, 0.9348050304662081], 
             262 -> RGBColor[
              0.36433321534571095`, 0.4899888520377754, 0.9444359682079841], 
             272 -> RGBColor[
              0.19665135271400355`, 0.3240234184912868, 0.9345103756662324], 
             97 -> RGBColor[
              0.2986247548964671, 0.43120392967218313`, 0.9403176100643942], 
             372 -> RGBColor[
              0.179946795179367, 0.3064658693922636, 0.9335590758268132], 356 -> 
             RGBColor[
              0.9453835605713274, 0.9587877294170835, 0.9773355650906732], 
             346 -> RGBColor[
              0.20342618893072584`, 0.3311442009044876, 0.9348961925663027], 
             341 -> RGBColor[
              0.24934350578881678`, 0.3794062122483802, 0.9375111158327881], 
             209 -> 
             RGBColor[
              0.2650455441851616, 0.3959100501696741, 0.9384053236903759], 
             378 -> RGBColor[
              0.24023703411797065`, 0.3698347331386689, 0.9369925157429511], 
             66 -> RGBColor[
              0.19612721011213427`, 0.3234725113841618, 0.9344805265204555], 
             139 -> RGBColor[
              0.30694355404168716`, 0.4399475150161388, 0.940791353369154], 
             56 -> RGBColor[
              0.5183980864407423, 0.6198979459970778, 0.9552293428008269], 
             335 -> RGBColor[
              0.1982643030525542, 0.3257187315640616, 0.9346022308018668], 
             314 -> RGBColor[
              0.18275376889499648`, 0.30941617673980293`, 0.9337189288273728],
              144 -> RGBColor[
              0.5812572311839399, 0.6709298314718057, 0.9601778449356456], 
             298 -> RGBColor[
              0.20546571259734456`, 0.33328786959137313`, 0.9350123404219118],
              204 -> RGBColor[
              0.17994083687002446`, 0.30645960683136597`, 0.9335587365099107],
              207 -> RGBColor[
              0.1915172466480543, 0.31862714749484833`, 0.934217995921006], 
             334 -> RGBColor[
              0.9602115875305376, 0.8774464833562946, 0.2999299602777051], 
             149 -> RGBColor[
              0.21032620428650672`, 0.3383965545296549, 0.9352891382331565], 
             219 -> RGBColor[0.178927, 0.305394, 0.933501], 400 -> 
             RGBColor[
              0.8221152183090297, 0.17099283563946593`, 0.16881086406928056`],
              9 -> RGBColor[
              0.6863588655876156, 0.7549080294084094, 0.9693734953996518], 11 -> 
             RGBColor[
              0.873192830390407, 0.9017242770380856, 0.9877671057427206], 44 -> 
             RGBColor[
              0.22831342724773274`, 0.3573022663177088, 0.9363134839710866], 
             153 -> RGBColor[
              0.20565135384863537`, 0.33348299031681494`, 0.9350229124165412],
              32 -> RGBColor[
              0.8215188663850046, 0.16640901342833042`, 0.16823979679335105`],
              162 -> RGBColor[
              0.19529691214488243`, 0.32259981557664835`, 0.9344332422795363],
              90 -> RGBColor[
              0.21556902434658207`, 0.3439070908267852, 0.9355877090795206], 
             331 -> RGBColor[
              0.24096885499463874`, 0.3706039232801706, 0.9370341918592453], 
             8 -> RGBColor[
              0.25559866423556843`, 0.38598078037586825`, 0.937867337852653], 
             364 -> 
             RGBColor[
              0.92133834354613, 0.7258397751431882, 0.2555651886720716], 342 -> 
             RGBColor[
              0.18639411010760892`, 0.31324240616522253`, 0.9339262408740289],
              163 -> RGBColor[
              0.17905422337022397`, 0.30552771982853294`, 0.9335082451827241],
              49 -> RGBColor[
              0.18369802063003998`, 0.31040864518235156`, 0.9337727025667882],
              338 -> RGBColor[
              0.21013611726343454`, 0.33819676101619267`, 0.9352783130584011],
              76 -> RGBColor[
              0.2829350020755027, 0.41471300466956446`, 0.9394241018521495], 
             369 -> RGBColor[
              0.1804054273287139, 0.30694792086018496`, 0.933585194249233], 
             82 -> RGBColor[
              0.7597586089991939, 0.8122484668202457, 0.9766892958633172], 67 -> 
             RGBColor[
              0.17940647345367122`, 0.30589795700018124`, 0.9335283053038692],
              211 -> RGBColor[
              0.23248905082520588`, 0.3616911114474591, 
               0.9365512795565422]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9mGk41G3YxiVbGGbGGGMMZp+JsVWihTktLbQQJSTFQyShTSoPqYhQlpJK
qqfNXmhRyhaSilTaVCKRJUXIFu+8x/Ee7/3l/+H+ch3XfZ3X+Tv/LO9gJ19p
KSmppBlSUv/73TOaQg3xNcCuudfIQVpkmNPakkbt9TEPvi8NZNhgb/ns6fdD
H/sXHfyxyp0ND7fHqS/sJPcGTVUBJb/EIV13v7p5GCChatH2mBYiThm7fD2a
wMXSuP7uQgILxDHp2nhtPXyQ1mc/PcEGUValUrFSgL1qDx/o8inocZNuvLFX
DVyLS7FPPEloSs5kZR9joiF+nLmJz4T996mupTMZcLnp8o7irAb3UmmBWRgR
ZWJeSs2kPKrtmszXKxqgqOfAmPFKNhw7U0JMc4RIyGeqClVYSB2aXjO/RQTr
Ep2PcWVa8Ilq33jlkwDdLesDpQUkpPs90jq5QgeM26p3r2zTwDLDKvklLTRQ
VD5/igyjYLV8z4H4IhXcifTSGGyQxjYefcQ1jY/OjwNjcxI0kLa7/oumpQHC
73cRiM5cuGYx9G6L1DBn86n6kFAi1v1636Z+UQ2/Rn+ujf7Cxe3kS+naQhLa
19W7XjyiAE/j7z5jmnwo3nsku9GAjJI0Ajma0Snum+Oz/l6zJnzeBtttuqUM
pZ5wzHdiwnKv0plpRRGUHmlc7S9hYmWxo8+JmwZ4Y6G0Um9SBQh//02tXxa1
bEXtkKxZCDFeXlenpoVQ1cOHvPdrY9Fmh5wxDhPlPbq/ivt00UdzJ1MKJPXp
ac2zmiWpp/BMVitdBjIHqtwOhnAQuHjVa5dkEdquksQdR2h47SvbqGaqiPJb
Tk29uTQ4PFt9yposwJsT54efnlDFF79nv6NoFNjmf6wKlObgwDVuWG2BPso8
0+tEWWysVdCzaTOQg6s66R+pJF3cse1rM3FUwPjvLq/Ht5mg7ktvPOhhjDVV
Ff53GjUROMwwd3FWgH1kY6p/ORum5c8iMizJmKbLOPuociBNlaf8cCGhzOjV
2f1x6lBwzl+VsIEBzts3ZunuLMx8mmI8ai1C0NC3Ef1AHgYZT1e0+SohvPzn
Smm6NsjbFgWO2whRsq6Dt+TbgLgkibrzh1APXWfFaV0cFgyHijTKDxliKJWU
oLqHhTjusWKDVF20/r73XfUOE04WqW34zQc5d+2/N++yIQw6tL1VWxdlZczj
mzdQEG34/N3dUi04ik3nUjvpaFT1fvrzOBlaRZcuXhcScGgLwfKpQAPvCkoS
wlfrwqvTvOHmRhImeyotO+dNis2qJwj7NPRhO/h4g9ReLrZmBPj4uGvBsz9A
2cOHhQyVjUdNN8jBwl6/hfeRhgcY2J15i42P1sRXggEK1lbumccokkXYrqlz
LZt1sCLvlqXnSQ5WWRQKX6Zp4IQoiT1MIKGkzKH8ppoKLENTkv8jknBtU37A
8jEObi2ZIFxPMsZtm11rDV0Z8Mhk7L59TwtpVgtjrpnr4jhzx79l7XyI3pv/
OWXFRsfXd6tvrZkB2zW5YSkrtRAVUl636wkHMzasnqx5qosItSVDZhE0iNYq
lYTTmHhTfN+t/5c+XOXU73X1URA4RYzOlsxjjYfazElfVZikRt4bDjNGxFBq
rvl2LVQTOqsV/vChdNxDK8uEhOnMr+oL+oWw2Z22MkNZFePXnZZTuUJsnmjV
uvBEBa+tb5RLZxmC88NPXnCBBVHvQUphmhAczdycIiUV1KcvdttjTcbXitXO
+ofY0Ln02uU/Nw78iduE238ScJs3c/ffcgaOiJvTItXV4Vkht/ecpF4uPeNi
/I1RcVq9onmUSB516rlU86ppMSmC87LeXg3eh2u8ZCZ1kVbtIHWRYwThW+ON
STZs1OxVLH7gIenXybW+Q41UCIU2HquHZ6PuFfv8xTsUhGl2BAe2KkCz/nh2
WRUDyz+dVUqc5iLpdNjtwBQlJNlYO0U6kpF7OY9gE86DtP0ypSX/CBBhf8Rz
RQAbUv93XgXERey7qIpjvN7KwlZlJGntCTT6SofHjZLGk5MCzN/Ybbs9VREl
6bvGhBUkdOSHi1seamOvxylW1zQJ3xWfXlsYx4f504OdoWoaKPCa9Tp7ioYE
vteTGDky7lTttnjeo4SeD0rNl9ewoZaaa31vjyY+GJzXK/hPE0ybJBMHPzbu
H43s7ngoh6lnVqoFgXTw5jUxev4IoJy0zWJrlwysDW0ckwN0sMEn6WHMCBO7
NRqj3x4S4eD4DGeGqsQH8tlFtUtIuGjVMX1skQzGNrU9LsyiwmNN8YuHJ1lY
2rt4tY/kfdfbNq0/4MMDVZAbdCWJg7Uezisz3tGxXl+esa+Sie87lBc8GaKD
0Zy55ULpgNiaMkeQ/JAJn/AFO27mGaDfr2+iyJmISf+pSu0sA0TUWg06D/Iw
sLyAVdLARnChS2ZAHw3Ujz/Xhc9Qg+/CyYmiMFXEF1et6PDiwS90VarzJQr+
o9sVhP6lIlX74GauswrI9U5Da6rUMGH82fpcFQdMx+CvFYv5aFBnzuar0iGc
UB2zbteDIO9l9ISXFkb3zmr1WyUNeW/iY5N8Clq2Dnw59ZEJmzrhTu2rGvg7
lDjTz5CMBT/9ZvyOlcEducETNhQRRn/+yvC5/00c6+8ls3rSCM+LvpO0lJn4
e0I2QEtJiLTJ/o0DPkzM1w51cxdQ0fGPllFuIRtXayqnL6SzoOl9nly3i4kT
nZ9aLc6RMdbgbln2kQPPuJ/b2k14yDH5eO3UVRaO0Vnjq7kG2FLwNsphBw+n
+gOmL9gYw0yj9GdOjyYKCi5mhgar4mx+2MEsihCdOTGP5afU0dc9Y9TyLwtk
y4V/bheL4G/8aPKgLg9XMm0tEtJn43qVfFH8HxY8/DVXrToxGzee5pP8JHrx
WFZXbv5cA3Oajm9+c5SDtKyFHm3L+HC9LP2i65km0uWph/9cpCLLQ/1DfhIR
nV+mHOX5AsxptNvuHc7GNSVj8rzLZAS1jkcst+EjpbwxU3RPDZvfysa0n9SA
e/XXDQZ7BOBRpgvENBnIM2p0RTwyng3KrsnmcGE1sno0/V8h1NCk3GTJAJnt
ah70hgCjUXHIwBsqcoq/P82K1keJ344W6jwueu/sVSSYkDHvauKQt5YcfP7T
Z316QEZnTyi+F3LhUjMe2AbJvh32zbHvnoGsBkv612ZZPH1+Wf7nWkWJX9Xu
6h4RYZNro+ydo3Q8ayE8JKeKEC6yWvNigIfhfXbKpPMkVBsu3r5QJIUbmWZn
72uRoC8aUxjQl4cdq3b2kQMkyGZQH9114YGfop2ziCWL8OsR8kfCOPCRtw3b
bEvEy+R5zPhDUnib/qfxZBMTdMXP0wmfNJCXaKdz10miv42PGGLJnA1d9j2u
yyTilsoMKmeJEMzKTddcm/VA3pOyIX4pB++ijq2Q/yJEX2xQ7N7fY+KVwfzm
0zuIiJlfYk331sXOPU0H5g+qoNz7fe9EkDxev+8xXL9KEX7b541cfyiLIwTV
+c9kKDCz/uZdtZCB3X7JmzzPCJDmt54aP0cKBzJGvobmkiBK+9rSsF+ADwk7
bHgiHqz0mwp8t8lh86v97smiPrGirApdVKwG26n9Be3dRAxuJnCdBlUxGUr9
ouM+JXbiLDEZMlCE7aG8RNp2IxRmNp9v72KClvT2Qr/LoHj76R1l0p+1ITXL
RM7H1xiioJzQwSoapnYHZ/x1UIP9apXWe63yYJ3/R97a0xCykR8HN4fxkODv
8iXFiIjXtu5KlXunxPqdLX55fgK87B+VG99DgHDEtnrihggxFcdmeZ0mgVhp
kr0uVh9S78yMPs7rFcunNs+tNRZhiOoTEhc4LF4SlzJiH6aGjC35FnFEPpSL
lFdVKQuRTT1d8tVaBSKv9zknI4WYv6CacvwhG/WfMrrTDs/GqLjv/PQ7Kvx+
aHnlL9DHu4OW4aejfoi3OTjm/k4WIiz46f61boPiKbPWJ4VEAYq8u4q+npmB
ddkLDP4kcjFkp1H+YpoO5X+r5xcpcLHZKKhzvYIiLtz7eyzwDQ+XWd+62lM1
MSMYhtYjWiisKe5dv4qC9pwylsMnfYSsX9q00JkJOW+b5tEyDaR/6Na4pivh
MhfhXpa9NjzrHoasD9AF/o1NylY3Qtlcd7kkyXz7RS17QNCX8PQ3j1eT5Syo
jURHBI7yoVJ6mDR2lYZu9Xap1yIS5qvdD2lMUUbWvvVSV+n94r9eo3zmoBIa
hk8F2ptJ/FXBpXD1JxYmLmyknv6uDmge8lsaqQKZDo+hraYiRC+aVyqvQoPP
nnqd51N8eHX7XTTlKeKwbIuz9ZAaHH98kHg3AbMcu+8E2+gh0WTFb/xgIz0v
2ahkGwGaVt11xjMUkHNpaVyxZO8RtzpYzGzVwj9Svy1nHdLAziK74tdUDs5b
Wy12CZH4zWsL4SquOvqll5OdI+hI4T/z32XOQlDl7OERGQXom2nkhO5Tgv1L
G9PnFH2cmxNrHDeLiZycVTsvVKjhUdqRl8cdNOB/rofZdmtAvN3vx3hqGBOe
AzyLh0xVKJAvXuXu+SY+qnb5bvodHva9rQo6PyKLgsWPtpZ1aWLdiXcK14wY
CPB7qnhlnyTf/I7v98+hY8SAW5hurIFr+cMlDjuZ+KSoHbVVV4iQS4zalB/T
4t2zNR+vqtCD+eJA+wUhneK8TSWqT2so8Ig9drHzERsupTZjj1bMgsyxg8FV
FTSsrLFb+lZmBgbW7//TfIaAl4XxWcOK+vidWmS/7hQH+twPjKJb+vAVqpX/
kfDMudpBSn6wIWpvpW87O5ODyV7ZF2b7OYh/MmWhv4uMqLOP3Dbm6eFS6d7g
nS9oiH1bdsTTX4gXfU4G7P/GxHStjlCHTE0IhtUD7npo42DFCm/Ze3fF2tE5
9NH5RNwv33nk6woVnOzRflHmMhN0kjSRkMOD9sKQ+V9kqdDLHtiSmUfEJbD+
bV4rxFEv6XNPUgXwOV7SfNyNjp2853lpEj8ojTv73m5YGw/dny4Qx5IRW5zt
mSLR237r+4zsfXqooLruDv2ijNcRFyMdGkgYPXbwpUXtlNic7OKkFiWPUpNv
7y+M6MC8IkHcsIgJbu2Ok4sl3B7S05Y7ND4ltj2Q1dTVz0TLfumVWhkGCP0p
fYj7gIfYf8ditmxRwMYTuglhC9mIIZQG91lLwZG1YluNIwsJ+iN96Z4SvY18
T7Tq6hKnrIhZPvM7C2t25tDleAxcq3k8Za4twtx3cnk9TBYCEtXZdTl8WC19
QBBRtHBZ77n4JIUNe7eu4d4oIqTWLKC1HOegvd1018856qiNnp/nqqeHFlrA
Qwd9Dj5v2Flz5KkW9unXz/JJZCIvuG5K7cOkWPh8vsmGpboYKCj+VXtcCNGr
bCmLL3/FBhbsF2Z+VOzbu7XgIkcbIz2t8yfuC3CVsiLGM1gDK3VCV+mHzQZj
jvSZJXM5CC8ourLm2yzMi7kc1PSSBb+586zV/Cig6h1yOOpPxCKP797v4kno
/djaOM9B4sfLTyw+/1nCDwtNi4aqJf3i7ldeoSPhKc7Z54+TKSghKA//oyJC
cD3ft91fBcGMTj2CKxObFo5Rz9XpoiUw++SHOiLMP/vbNiXz0Zh8NJb+i49r
HmYqlBYWKnJV8g8K9GHse+O34rVucYHTTcEnPgENz8r8TQUcpCsOEk0k8/PA
JTTWKJ2GI4NL3Lp/GkLn69ZRLw82wv3XRCouNELpyssvez0kHDgcvfZciz44
j59HfannomTF5x2qJfq4aX+06F8eFc6OdyMNYwWw27Yte+wsG0Fdv6IcxQQJ
h07GNzRTsahyojRfMncmIo1sQpImbhmgZriKjuR8UU/2RwYW3971yPLwoFgQ
f5zh6qCJfy51uLNrqJAa34gzK4jYMvop+3U5EwNl+5be19TF37G//5Hi9VFx
Orgh6upP8a0NvK9iSX6L/hDmcHOJNtwcHlkcf0QGUSHYQHsdEU0ZZxfnkkR4
zKX99oug4AJrhNHcwMQNrQ11rtEMKMQ5W0/OF4L3XNs0Zh0bJy96jPgukcXj
NsYS6qgqOqxXq4R8l0F9hOqF3ps6OBtacGXU3hg+tyqztxygQfuilNcdvjqu
Od2vn32ThS1rW7zcWYbIXqBgHXRZB6FHA0e6Dkp4xHioxymFh2XRG9+dthIh
LPSNHmMuD4FXo02mzyiitstnt/VqdRDUOpZ0XdeD2W/RRLopGU/yy+rvG7Gx
VOeL/2sTJnwfmlifHCDjYJR1XvkySc5ZKpdT1ETAOSPy1ddyVJCMNvxqolFg
ZNZmm3SUC1rJ2PZ51f3i1AVNzEPflOG0iWpCeawG+sPpzcfO8+D01fWpzxYu
8vVC3o4VacCQEB2utFTig98yD692IKNi0a/Jh40kWLreydvax4Gjd4RrVCEP
/XVrHkdk0zGUpUpv+IeAv4LX+TF3yXgX+faEkYT3vDER3KvFgns/PXf3cr3/
z3VWlRHVvpI8veGS/bSblhKuy+2v+CuWvNOFKnm7DC7C3dYwZT/oYZTBCxy9
3i8eX/7ytmakLtpZV/yuPFHHrLnmLaWzJXm+d5rF0NIG5ZLB0pLemfB++MPs
swEH8roz+w/8FYKmIL13kdRv8TPu4NqKCR64fTohhSVk4OXm6TnNleJS6w4j
hx8UFFYuaK9XIYMyddN59lsmdr7mN1RnETH+bfpwrJiJXzOH6OcShVhb3msb
fmpE3PdI46Rsgh4crg7ZhHayITNw7N9MZUUsPOS/zsSBCNl6nsAi2BiNfpa3
o9bRUGLYonK1VYgbd0ccmnW10ccvDagOYCGnYUupXp0GBi8r1TmMaWPnp+Vd
0hVMZMSEuk/+0MUwbaJz9CIdbgopbvMHBTCfPSTroDgmfmdUNDmzcjYcZuw5
skVaHV3LFnmwp7Txftwrc+UPif+2eQxxVIlw916TeO0wCWsZUhuf3FRFr9Cs
cn0vBcfIpFzWVkUo19V1lKmT8eujX3P0IgKe2EXecdmtiCDNTv64OglpnQsf
N18RYOmejOGF/BmIXIZ9fZ+UIfVy5NGFEiKCzqjH1oq4+Lg/brPyJQb0TIvb
so6zkPTC11XpFQkKpTW1D1hcsDV6LyyGMZoSVnTGLtNGivnbyGoLMvR+msU5
S7hJoa1uYzNfsn8J7YkpvHGxk2nNgtMlNNx75JD2fjUbCed+tm6J4kPbwEVA
uyqDhpfmdxs0SPB/7J9loftHHK/XTamco4uaeYHXHYuYeL8lwkepjYSDv0VR
iuY87Fzkl0D5LsCtWJ0ne1MnxHlxaTe75nJBnU07rfyZBh3bjul2YwO82Foq
I1JQwsuExx8bDqqglZ5esfC7MgxG7spkbhWgqvlBo6EnDRbS3w5brOZh7T6m
h/oNGux6i0f69xHBOtYUclRPAz6EP9b28lxMaBmk5TzQgM6W5XO2S/pemJHc
FbyNidO2H5ebL2Bj1s1Ty/75pgW5+gK7nj4+ZC7Hpw5L8jdzWwFLtlgXK6oj
hHPkNJEzg3Ivi2GE3Z7/UbJHqCjqCbrrIjTA0hcfSx6ZUvBJo+vdpu8iXG5r
OXVmTAffj7zy7Y80wLypOYpaGnwkueHN/kYRJo0+XT12mI94z6iVjVIGSJyU
qS5V1sSc8lody1BDVC+onpmbzcKC4pVxXYkk0M4EHjHv5CPhMEl9E18JMWqa
jp/jOAiRMcned0AdOtLJjKMUJrTedjhpJgrQ0rGBOvsuCbYJyfIMia5op7fy
KyVcrlxNsCS4SaNm2vQBBTJ4sNw6M+AtFw7U2mLZajqIFuOcvFIZyHVbu+/+
3/9+lVYBS0yJEH3dw+nOpyE0q/uY8mcKMhb8jZlzU5L/aVIZeQp0nOuKCSnt
VMOnDKnbb2LYmLar+FK9Uwv7LTPtDJLUYW111KnIVBn3yEmjz2cb4K9UQ6nx
EiqepR4wSBMI0Kcke3KLhMu3zrUKHU/kwNM8+uiBBg08K8y79dfMAO/86re3
lrCw+XUGp8+KBSOpgm0kTSaIE9OBimx9KJinXDvnpgWnxD1hbjU0eBx3CL3v
q4Mdhz+MpcoK4Sq7zEovkY0cUc1ilW4eVJpt9VRVVPHKXtpxej0RsWdzH5bw
B8T3lhWrjblpoP02P8YvWRdBXIWlipnGuCIoctAooKPCdsa6t0k8bLvzJDzy
jgwSPl2/K7Bggn/vJfv4Ax38D4p/h4g=
         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 5}], {
             RGBColor[
             0.18431548798727523`, 0.3110576425244974, 0.9338078664193217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.18382719114068813`, 0.31054441157892615`, 0.933780058636279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 73}], {
             RGBColor[
             0.19016251964762415`, 0.3172032435227433, 0.9341408462224705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[
             0.18373091059218155`, 0.31044321461790636`, 0.9337745756014759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 162}], {
             RGBColor[
             0.18855509271436693`, 0.315513735899136, 0.9340493056365965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 183}], {
             RGBColor[
             0.18524860197516257`, 0.312038404488611, 0.9338610058805135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 291}], {
             RGBColor[
             0.1886369117353484, 0.31559973287781307`, 0.934053965108801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 357}], {
             RGBColor[
             0.18390843895748787`, 0.3106298081857918, 0.9337846855792504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 368}], {
             RGBColor[
             0.1828231865844723, 0.30948913913277776`, 0.9337228820620942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 387}], {
             RGBColor[
             0.1836776641650684, 0.31038724924699196`, 0.9337715432962228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 28}], {
             RGBColor[
             0.1967107027357332, 0.32408579912713337`, 0.9345137555621694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 39}], {
             RGBColor[
             0.19999978068083032`, 0.3275428285870168, 0.934701063685388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 50}], {
             RGBColor[
             0.216476564027812, 0.3448609725730971, 0.935639392121782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 106}], {
             RGBColor[
             0.19417223523988333`, 0.32141770884085996`, 0.9343691935936069]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 137}], {
             RGBColor[
             0.24723503321608348`, 0.3771900738895551, 0.9373910414389766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 138}], {
             RGBColor[
             0.24536530114030092`, 0.3752248669300471, 0.9372845629632816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 149}], {
             RGBColor[
             0.20607580619388693`, 0.3339291166435074, 0.9350470843496823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 164}], {
             RGBColor[
             0.20840908696131982`, 0.3363815426686245, 0.935179961237608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 197}], {
             RGBColor[
             0.1965684920257088, 0.3239363266542179, 0.9345056568726156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 210}], {
             RGBColor[
             0.223753059772891, 0.352509030957652, 0.9360537777898534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 217}], {
             RGBColor[
             0.20503618363244414`, 0.3328364074155535, 0.9349878793827919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 230}], {
             RGBColor[
             0.2114753909347174, 0.33960442255956613`, 0.9353545827127028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 254}], {
             RGBColor[
             0.19445154659843222`, 0.32171128278805783`, 0.9343850999622723]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 258}], {
             RGBColor[
             0.2197390144926751, 0.34829001486297484`, 0.935825183849393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 314}], {
             RGBColor[
             0.19228958849813182`, 0.3194389277485814, 0.9342619796467905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 328}], {
             RGBColor[
             0.2165885293871429, 0.3449786552647677, 0.935645768383358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 7}], {
             RGBColor[
             0.24558195815549755`, 0.37545258718986685`, 0.9372969012597816]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 13}], {
             RGBColor[
             0.2247891692476987, 0.3535980477088099, 0.9361127826916571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 14}], {
             RGBColor[
             0.28743237026540935`, 0.41667525783150516`, 0.9397814519424676]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 21}], {
             RGBColor[
             0.21644166427209716`, 0.34482429071706844`, 0.9356374046323236]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 51}], {
             RGBColor[
             0.2187121116641707, 0.34721067488081686`, 0.9357667032524762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 79}], {
             RGBColor[
             0.21763331081573253`, 0.34607678678918397`, 0.9357052671401005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 188}], {
             RGBColor[
             0.25601232241971317`, 0.38641556135484806`, 0.9378908950742876]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 232}], {
             RGBColor[
             0.21328768495463646`, 0.3415092584805786, 0.9354577901760884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 293}], {
             RGBColor[
             0.2751725873267546, 0.40605645004464963`, 0.939000269414517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 373}], {
             RGBColor[
             0.21710028788855346`, 0.3455165458971132, 0.9356749122729344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 390}], {
             RGBColor[
             0.22459916207358144`, 0.353398338121662, 0.9361019620641815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 84}], {
             RGBColor[
             0.20756604892203795`, 0.3354954562376403, 0.935131951468434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 125}], {
             RGBColor[
             0.196721601742191, 0.3240972546739574, 0.9345143762444637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 165}], {
             RGBColor[
             0.21319278532882907`, 0.3414095129568713, 0.9354523857827901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 184}], {
             RGBColor[
             0.20719899217930893`, 0.3351096563282905, 0.9351110481299474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 185}], {
             RGBColor[
             0.1966973229914563, 0.32407173616757357`, 0.9345129936055264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 190}], {
             RGBColor[
             0.20649883851719153`, 0.33437375043709894`, 0.9350711754146743]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.1963748100004493, 0.3237327545655205, 0.9344946269678038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 252}], {
             RGBColor[
             0.20339315185029538`, 0.3311094768382833, 0.9348943111534462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 274}], {
             RGBColor[
             0.2019924165278475, 0.3296372152026416, 0.934814541349035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 288}], {
             RGBColor[
             0.2072894767278965, 0.33520476132590776`, 0.9351162010911295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 318}], {
             RGBColor[
             0.20715075077545358`, 0.3350589515541568, 0.9351083008533645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.18632940584411195`, 0.31317439788179996`, 0.9339225560619441]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 113}], {
             RGBColor[
             0.18623312529560537`, 0.31307320092078017`, 0.9339170730271409]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 162}], {
             RGBColor[
             0.19105730741779076`, 0.3181437222020098, 0.9341918030622616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 183}], {
             RGBColor[
             0.1877508166785864, 0.3146683907914848, 0.9340035033061785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 270}], {
             RGBColor[
             0.19738135324155764`, 0.32479069533045285`, 0.9345519481163376]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 291}], {
             RGBColor[
             0.19113912643877223`, 0.3182297191806869, 0.9341964625344661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 357}], {
             RGBColor[
             0.1864106536609117, 0.3132597944886656, 0.9339271830049154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 368}], {
             RGBColor[
             0.18532540128789612`, 0.31211912543565157`, 0.9338653794877592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 10}], {
             RGBColor[
             0.8845651997050992, 0.6376155087725291, 0.5907990623624317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.6643840547861006, 0.7335496374888852, 0.969847038397682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 69}], {
             RGBColor[
             0.7494906190968638, 0.8040199624425932, 0.9761664746556911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 71}], {
             RGBColor[
             0.9479335881069795, 0.9604436363507414, 0.9644935461230137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 93}], {
             RGBColor[
             0.6343460318717724, 0.7075322117954237, 0.9679330421391619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 129}], {
             RGBColor[
             0.8727497313117147, 0.5467966411297123, 0.579484556485264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 131}], {
             RGBColor[
             0.8701371040264215, 0.8993351938028649, 0.9874630507499915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 142}], {
             RGBColor[
             0.7001614603741532, 0.763972329138221, 0.9722831025823769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 201}], {
             RGBColor[
             0.7959386825090102, 0.8413708229845736, 0.9800676455168078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 253}], {
             RGBColor[
             0.8756778488316885, 0.5693034354975091, 0.5822885251292265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 273}], {
             RGBColor[
             0.7251045855702409, 0.7842222818473898, 0.9742467167674911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 281}], {
             RGBColor[
             0.6624572537085711, 0.7318807392393671, 0.9697242643368251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 303}], {
             RGBColor[
             0.9100466794366213, 0.777602242030947, 0.6130122278904285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 364}], {
             RGBColor[
             0.9237508221541206, 0.8349006337052781, 0.6241923325830713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 391}], {
             RGBColor[
             0.8731987569820019, 0.5502480491958415, 0.5799145439742327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 394}], {
             RGBColor[
             0.6418942074247149, 0.7140700620770483, 0.9684140052108057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 13}], {
             RGBColor[
             0.23415570368153021`, 0.3634428692713504, 0.9366461929711178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 14}], {
             RGBColor[
             0.29679890469924086`, 0.4265200793940456, 0.9403148622219284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 21}], {
             RGBColor[
             0.22580819870592864`, 0.3546691122796089, 0.9361708149117844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 93}], {
             RGBColor[
             0.29873862778538124`, 0.4282001700379434, 0.9404384596617476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 142}], {
             RGBColor[
             0.36455405628776205`, 0.4846402873807406, 0.9447885201049626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 188}], {
             RGBColor[
             0.2653788568535447, 0.3962603829173885, 0.9384243053537484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 273}], {
             RGBColor[
             0.3894971814838498, 0.5048902400899095, 0.9467521342900769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 293}], {
             RGBColor[
             0.28453912176058604`, 0.41590127160719004`, 0.9395336796939777]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 390}], {
             RGBColor[
             0.23396569650741295`, 0.36324315968420245`, 0.9366353723436424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 16}], {
             RGBColor[
             0.24227617377409713`, 0.3719779982061794, 0.9371086417297306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 25}], {
             RGBColor[
             0.3097802502292844, 0.43782398124180466`, 0.9411398210556678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 76}], {
             RGBColor[
             0.26926683315553557`, 0.4003468925227164, 0.9386457198524012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 117}], {
             RGBColor[
             0.40706513411417244`, 0.5192304619580248, 0.9481280690845475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 202}], {
             RGBColor[
             0.2915950820053508, 0.42207290253936436`, 0.9399810782169516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 234}], {
             RGBColor[
             0.2512674523014992, 0.38142840201846384`, 0.9376206817404615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 239}], {
             RGBColor[
             0.3813679879787836, 0.49836836108207505`, 0.9461050956090218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 269}], {
             RGBColor[
             0.30450100126350144`, 0.4332513611304116, 0.9408034319798247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 302}], {
             RGBColor[
             0.22515004974021374`, 0.353977355987588, 0.936133334301831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 323}], {
             RGBColor[
             0.3381102648791732, 0.4623620160236, 0.9429449845379104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 365}], {
             RGBColor[
             0.2808078228071327, 0.4124772043875522, 0.9393029621396956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 377}], {
             RGBColor[
             0.25514638831763914`, 0.3855054097101751, 0.9378415814082092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 388}], {
             RGBColor[
             0.26319007599843486`, 0.3939598354619466, 0.938299657522061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 18}], {
             RGBColor[
             0.8394473584119997, 0.8706756474406323, 0.6991625748728455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 56}], {
             RGBColor[
             0.6023784760141789, 0.6874029877027437, 0.9623014191002394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 65}], {
             RGBColor[
             0.531426491162083, 0.6277150215031269, 0.9572921727453987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 100}], {
             RGBColor[
             0.5370355289675518, 0.6325732881317867, 0.9576495756744858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 174}], {
             RGBColor[
             0.5520972673558275, 0.6456190088987284, 0.9586092963260144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 198}], {
             RGBColor[
             0.7575782172127392, 0.8106163649808842, 0.9764530707316865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 203}], {
             RGBColor[
             0.4981842108201723, 0.5989222290765547, 0.9551740040370065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 266}], {
             RGBColor[
             0.6722902895010364, 0.7439175508444353, 0.9679712712136599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 313}], {
             RGBColor[
             0.4854882204226317, 0.5856947625868548, 0.9544467086526902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 339}], {
             RGBColor[
             0.5341582021850244, 0.6300810922914106, 0.9574662349562233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 358}], {
             RGBColor[
             0.48197798109692647`, 0.5820052784935108, 0.954246805716025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 384}], {
             RGBColor[
             0.8099718019563749, 0.7646503394906032, 0.6173962103853706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 32}], {
             RGBColor[
             0.8322429825165458, 0.24883926935301032`, 0.1785092225120718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 52}], {
             RGBColor[
             0.9159808794279284, 0.6604932743481702, 0.5104145698509248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 60}], {
             RGBColor[
             0.774995447398962, 0.551160577750298, 0.5801059153920654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 68}], {
             RGBColor[
             0.8322857283076943, 0.5959292773686855, 0.5858125997101122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.8311516302547027, 0.2404506576348733, 0.17746414235362473`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 253}], {
             RGBColor[
             0.8340797477746764, 0.2629574520026702, 0.18026811099758727`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 271}], {
             RGBColor[
             0.8314849257202783, 0.24301251263429177`, 0.17778330646786333`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 303}], {
             RGBColor[
             0.8684485783796092, 0.4712562585361081, 0.21099181375878928`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 333}], {
             RGBColor[
             0.8983718156694669, 0.6481583597796403, 0.5759535503804154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 334}], {
             RGBColor[
             0.9015893430893124, 0.6043580043169925, 0.2443543042542488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 337}], {
             RGBColor[
             0.8999731601904741, 0.6493526399014464, 0.5732428918038912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 345}], {
             RGBColor[
             0.8355254140940163, 0.5985125148757706, 0.5861216038325132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 353}], {
             RGBColor[
             0.9181134493807003, 0.6596306220979193, 0.3482638350680197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 364}], {
             RGBColor[
             0.8821527210971085, 0.5285546502104392, 0.22217191845143208`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 391}], {
             RGBColor[
             0.8316006559249898, 0.24390206570100256`, 0.1778941298425935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 54}], {
             RGBColor[
             0.9107233154962703, 0.8671374351819781, 0.6324945514745149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 83}], {
             RGBColor[
             0.9120888802991098, 0.9323447493793293, 0.977810506555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 118}], {
             RGBColor[
             0.6153201099210919, 0.6928744863891039, 0.9658821576068201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 123}], {
             RGBColor[
             0.8581753215010539, 0.6172298567057516, 0.5883641909402252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 141}], {
             RGBColor[
             0.6144798263952078, 0.6921466750328611, 0.9658286154835842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 161}], {
             RGBColor[
             0.8763695857039919, 0.7238270844566292, 0.6044849794547379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 196}], {
             RGBColor[
             0.8586587168624804, 0.8901351694289188, 0.9863808290196707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 206}], {
             RGBColor[
             0.6510406164097462, 0.7238137937447175, 0.9681582366938735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 214}], {
             RGBColor[
             0.8760571062553216, 0.722408188261647, 0.6042242389431952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 286}], {
             RGBColor[
             0.5972181184299319, 0.677195451192008, 0.9647287147159659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 332}], {
             RGBColor[
             0.8454988743714711, 0.5197931292132254, 0.5762252108529373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 366}], {
             RGBColor[
             0.9332464444239088, 0.9449010522417576, 0.749948999978632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 386}], {
             RGBColor[
             0.6075598618760001, 0.6861529495738531, 0.9653876814635047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 19}], {
             RGBColor[
             0.22114916866345258`, 0.3497721763054004, 0.9359054900432826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 24}], {
             RGBColor[
             0.25148362362516946`, 0.3816556117856949, 0.9376329923775478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 65}], {
             RGBColor[
             0.30963980079837916`, 0.4365176650238572, 0.941174248166886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 100}], {
             RGBColor[
             0.315248838603848, 0.44137593165251704`, 0.941531651095973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 107}], {
             RGBColor[
             0.23293330946253646`, 0.362158055442918, 0.9365765794287164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 124}], {
             RGBColor[
             0.23470207361547668`, 0.3640171387137828, 0.9366773079305742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 150}], {
             RGBColor[
             0.24059607423843102`, 0.37021210706973123`, 0.937012962546659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 157}], {
             RGBColor[
             0.24482342257705114`, 0.37465531820298625`, 0.937253703780742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 167}], {
             RGBColor[
             0.2392959832955554, 0.36884562905824225`, 0.9369389242907744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 168}], {
             RGBColor[
             0.22037492795635888`, 0.34895840023254887`, 0.9358613981804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 203}], {
             RGBColor[
             0.2763975204564685, 0.40772487259728496`, 0.9390560794584938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 206}], {
             RGBColor[
             0.33583694364464667`, 0.4592083134506097, 0.9428435069438263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 211}], {
             RGBColor[
             0.23763726784270695`, 0.3671022139486645, 0.9368444628995842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 238}], {
             RGBColor[
             0.2218338423144311, 0.3504918117233956, 0.9359444811948219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 341}], {
             RGBColor[
             0.2460644953245124, 0.3759597643491251, 0.9373243810377072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 358}], {
             RGBColor[
             0.26019129073322267`, 0.39080792201424114`, 0.9381288811375124]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 14}], {
             RGBColor[
             0.27600611579144196`, 0.4046655399129887, 0.9391307436538039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 21}], {
             RGBColor[
             0.2050154097981298, 0.332814572798552, 0.9349866963436598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 51}], {
             RGBColor[
             0.20728585719020337`, 0.33520095696230034`, 0.9351159949638125]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 79}], {
             RGBColor[
             0.20620705634176517`, 0.33406706887066745`, 0.9350545588514367]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 87}], {
             RGBColor[
             0.2001057560025477, 0.3276542153693653, 0.9347070988231834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 205}], {
             RGBColor[
             0.19925835051903662`, 0.3267635384775842, 0.9346588403345214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 232}], {
             RGBColor[
             0.20186143048066912`, 0.3294995405620621, 0.9348070818874247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 277}], {
             RGBColor[
             0.19923872667069553`, 0.3267429125687539, 0.9346577227853893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 373}], {
             RGBColor[
             0.2056740334145861, 0.3335068279785967, 0.9350242039842707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 390}], {
             RGBColor[
             0.2131729075996141, 0.34138862020314553`, 0.9354512537755177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 69}], {
             RGBColor[
             0.45573362712038445`, 0.5659105913267511, 0.9511564428609628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 71}], {
             RGBColor[
             0.6541765961305002, 0.7223342652348994, 0.9394835143282855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 201}], {
             RGBColor[
             0.5021816905325309, 0.6032614518687315, 0.9550576137220795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 212}], {
             RGBColor[
             0.45821441723172895`, 0.5679246084974616, 0.9513517397459614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 273}], {
             RGBColor[
             0.4313475935937616, 0.5461129107315478, 0.9492366849727629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 289}], {
             RGBColor[
             0.4064318553204269, 0.5258851919600367, 0.9472752267865294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 293}], {
             RGBColor[
             0.32638953387049785`, 0.45712394224882835`, 0.9420182303766638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 390}], {
             RGBColor[
             0.27581610861732475`, 0.40446583032584077`, 0.9391199230263283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 35}], {
             RGBColor[
             0.1861148468094702, 0.312948882732563, 0.933910337242333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 106}], {
             RGBColor[
             0.18432449600494816`, 0.311067110522213, 0.933808379412602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 154}], {
             RGBColor[
             0.18425132424679044`, 0.31099020236503183`, 0.933804212389223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 207}], {
             RGBColor[
             0.18682358813972555`, 0.3136938148074571, 0.9339506990126021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 231}], {
             RGBColor[
             0.18666830847322874`, 0.31353060603266947`, 0.9339418560653108]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 369}], {
             RGBColor[
             0.18126767848005537`, 0.30785420149012543`, 0.9336342981767156]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 372}], {
             RGBColor[
             0.1810383624053819, 0.30761317575616476`, 0.9336212389655058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 392}], {
             RGBColor[
             0.19259602959164984`, 0.3197610167673564, 0.9342794310137273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 25}], {
             RGBColor[
             0.2964577597678131, 0.4238211990721158, 0.9403811249327455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 37}], {
             RGBColor[
             0.25664259349321183`, 0.38707801621458926`, 0.9379267880795208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 76}], {
             RGBColor[
             0.2559443426940643, 0.3863441103530275, 0.937887023729479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 77}], {
             RGBColor[
             0.21295289463759554`, 0.3411573726304365, 0.9354387243628108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 78}], {
             RGBColor[
             0.22470970081672578`, 0.3535145213492678, 0.9361082570820762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 80}], {
             RGBColor[
             0.21603013302378776`, 0.34439174528250716`, 0.9356139685365383]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 96}], {
             RGBColor[
             0.22029148033523374`, 0.34887069149186156`, 0.9358566459618267]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 182}], {
             RGBColor[
             0.23539065510704868`, 0.36474088152001305`, 0.9367165216278543]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.22265042245962569`, 0.35135008923016664`, 0.9359909842260687]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 269}], {
             RGBColor[
             0.29117851080203017`, 0.41924857896072276`, 0.9400447358569024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 302}], {
             RGBColor[
             0.21182755927874247`, 0.3399745738178992, 0.9353746381789088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 323}], {
             RGBColor[
             0.3247877744177019, 0.4483592338539112, 0.9421862884149881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 365}], {
             RGBColor[
             0.2674853323456614, 0.39847442221786333`, 0.9385442660167731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 377}], {
             RGBColor[
             0.24182389785616784`, 0.37150262754048624`, 0.9370828852852868]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 388}], {
             RGBColor[
             0.24986758553696356`, 0.3799570532922577, 0.9375409613991386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 18}], {
             RGBColor[
             0.9100987698336667, 0.6000343504740516, 0.3015369122339562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 31}], {
             RGBColor[
             0.9059600385832136, 0.6006919444617403, 0.5423324684832332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 62}], {
             RGBColor[
             0.9097327710312662, 0.6022520662838114, 0.4798085283004041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.8649138899410389, 0.5692261022124661, 0.5823263856846504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 111}], {
             RGBColor[
             0.8271368865255229, 0.20959157806047718`, 0.1736196192245576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 222}], {
             RGBColor[
             0.88937458998013, 0.5883335736307327, 0.570901233962067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 223}], {
             RGBColor[
             0.843439007132864, 0.3336207383005069, 0.18918058014291417`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 247}], {
             RGBColor[
             0.8225002166596341, 0.17395210166956507`, 0.16917953892461288`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 256}], {
             RGBColor[
             0.9099828197722593, 0.6023554678641716, 0.47566457355675007`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 292}], {
             RGBColor[
             0.8235767865158092, 0.18222708934004583`, 0.17021046343469787`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 310}], {
             RGBColor[
             0.8270891883762761, 0.20922494918390394`, 0.1735739434229715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 319}], {
             RGBColor[
             0.8300530358518976, 0.23200637964777565`, 0.17641212711281357`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 384}], {
             RGBColor[
             0.8806232133780418, 0.49400904252402256`, 0.21977054774648136`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 99}], {
             RGBColor[
             0.947350971343756, 0.9556350172112698, 0.7097411277967336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 144}], {
             RGBColor[
             0.7868965412101618, 0.8286865484723305, 0.6945647496408425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.9106667100371233, 0.9263839830131071, 0.7062421502048801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 218}], {
             RGBColor[
             0.776406098847213, 0.8201699347730458, 0.6937389035902746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 266}], {
             RGBColor[
             0.8253787823254205, 0.8596851688766582, 0.6977603506868537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 310}], {
             RGBColor[
             0.9095262697789932, 0.5956338641827077, 0.30098868553505453`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 319}], {
             RGBColor[
             0.9124901172546147, 0.6184152946465793, 0.3038268692248966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 384}], {
             RGBColor[
             0.9630602947807589, 0.8804179575228263, 0.3471852898585644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 24}], {
             RGBColor[
             0.22984730742841403`, 0.35891447164122536`, 0.936400836178204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 85}], {
             RGBColor[
             0.19070082938217475`, 0.3177690411845645, 0.9341715021654952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 107}], {
             RGBColor[
             0.211296993265781, 0.33941691529844853`, 0.9353444232293726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 124}], {
             RGBColor[
             0.21306575741872125`, 0.34127599856931323`, 0.9354451517312304]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 150}], {
             RGBColor[
             0.21895975804167556`, 0.3474709669252617, 0.9357808063473152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 152}], {
             RGBColor[
             0.2001783639532218, 0.3277305309291337, 0.9347112337385604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 157}], {
             RGBColor[
             0.2231871063802957, 0.35191417805851677`, 0.9360215475813982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 160}], {
             RGBColor[
             0.19740416245689973`, 0.32481466926196517`, 0.9345532470674082]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 167}], {
             RGBColor[
             0.21765966709879997`, 0.34610448891377266`, 0.9357067680914306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 168}], {
             RGBColor[
             0.19873861175960342`, 0.3262172600880793, 0.9346292419810562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 181}], {
             RGBColor[
             0.19581756515250187`, 0.3231470548989638, 0.9344628926980831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 211}], {
             RGBColor[
             0.2160009516459515, 0.344361073804195, 0.9356123067002404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 238}], {
             RGBColor[
             0.20019752611767563`, 0.32775067157892607`, 0.9347123249954781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 64}], {
             RGBColor[
             0.6886054780275248, 0.7470570557801346, 0.690028677840299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 88}], {
             RGBColor[
             0.40751079531136875`, 0.5273871016357587, 0.9471872054229611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 89}], {
             RGBColor[
             0.30842578765479933`, 0.4344898392135439, 0.9411326397648885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 120}], {
             RGBColor[
             0.3985867083579536, 0.5196575060543626, 0.9466185704935497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 140}], {
             RGBColor[
             0.3954861818985797, 0.5169719858722439, 0.9464210076892463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 189}], {
             RGBColor[
             0.30889970680782364`, 0.4349879582915822, 0.9411596287595527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 195}], {
             RGBColor[
             0.40462199010322386`, 0.5248849637600351, 0.9470031333095683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 241}], {
             RGBColor[
             0.33276855688740864`, 0.46007563309772936`, 0.9425189244607857]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 255}], {
             RGBColor[
             0.37940724758906264`, 0.5030452211240766, 0.9453964722130872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 257}], {
             RGBColor[
             0.6770229856308323, 0.7421397259892473, 0.9411883411446311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 263}], {
             RGBColor[
             0.3432288815576954, 0.4710700975490908, 0.943114624476095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 312}], {
             RGBColor[
             0.4662211223319299, 0.5756731791658605, 0.9516371294428863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 336}], {
             RGBColor[
             0.3097133743307097, 0.43584317444763615`, 0.9412059659212678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 356}], {
             RGBColor[
             0.6650046334832713, 0.7331764586358418, 0.9615322764421933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 359}], {
             RGBColor[
             0.3551576814248725, 0.48204146573128925`, 0.9438513113001545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 360}], {
             RGBColor[
             0.523690607917635, 0.622017048024192, 0.9563749606192402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 389}], {
             RGBColor[
             0.688874491712781, 0.747632448851442, 0.7193091573204213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 109}], {
             RGBColor[
             0.1897091064701492, 0.31672667752516137`, 0.9341150250127779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[
             0.19167285067202883`, 0.3187906971899105, 0.9342268573399758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 132}], {
             RGBColor[
             0.1947709663990963, 0.3220470132509409, 0.9344032904473808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 180}], {
             RGBColor[
             0.19254611619106632`, 0.3197085546186507, 0.9342765885194044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 232}], {
             RGBColor[
             0.19351392550506752`, 0.32072578357032067`, 0.9343317038280912]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 249}], {
             RGBColor[
             0.19014493822452405`, 0.31718476433233855`, 0.9341398449864342]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 370}], {
             RGBColor[
             0.19110729661804693`, 0.31819626402097745`, 0.9341946498732637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 45}], {
             RGBColor[
             0.24087710963769857`, 0.3705074930930349, 0.9370289670968927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 74}], {
             RGBColor[
             0.24528340650250224`, 0.37513879047330073`, 0.9372798991848111]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 116}], {
             RGBColor[
             0.24102708216235447`, 0.3706651237252555, 0.9370375078103073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 141}], {
             RGBColor[
             0.2988998919025237, 0.4271457198066904, 0.9404924581847806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 179}], {
             RGBColor[
             0.2344230766191157, 0.3637238951811761, 0.9366614194643705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 209}], {
             RGBColor[
             0.25353925279510015`, 0.38381620837770913`, 0.9377500574177445]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 286}], {
             RGBColor[
             0.2816381839372477, 0.41219449596583724`, 0.9393925574171622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 290}], {
             RGBColor[
             0.2497813465899759, 0.3798664106911086, 0.9375360502186867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 304}], {
             RGBColor[
             0.2621517349847551, 0.3928684732219464, 0.9382405255374198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 338}], {
             RGBColor[
             0.2260845393342366, 0.35495956380096844`, 0.9361865521017572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 38}], {
             RGBColor[
             0.23532272116707456`, 0.36466947864183974`, 0.936712652890472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 92}], {
             RGBColor[
             0.20814505737279243`, 0.33610403083063944`, 0.9351649251431382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 98}], {
             RGBColor[
             0.2025842284056299, 0.3302592470092312, 0.9348482441599675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 119}], {
             RGBColor[
             0.22585475434557115`, 0.35471804520867123`, 0.936173466186589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 128}], {
             RGBColor[
             0.2579108106564282, 0.38841099286274205`, 0.9379990111708069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 130}], {
             RGBColor[
             0.21379154943709947`, 0.3420388519985006, 0.935486484512964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 139}], {
             RGBColor[
             0.2594316195520534, 0.3900094594368974, 0.9380856189875776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 143}], {
             RGBColor[
             0.20541157212716055`, 0.3332309645245057, 0.9350092572022285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 146}], {
             RGBColor[
             0.20552449462249126`, 0.333349653226798, 0.9350156879712836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 151}], {
             RGBColor[
             0.20976599730073225`, 0.3378077414684315, 0.9352572352740687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 158}], {
             RGBColor[
             0.20153001639620693`, 0.3291512033464258, 0.9347882083455978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 186}], {
             RGBColor[
             0.209250396089514, 0.3372658119044362, 0.9352278725478533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 213}], {
             RGBColor[
             0.2686665233533321, 0.39817491739397315`, 0.9386679570758016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 267}], {
             RGBColor[
             0.20474185831720654`, 0.33252705284793593`, 0.9349711179915043]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 306}], {
             RGBColor[
             0.21710981978146196`, 0.345526564520917, 0.9356754551001344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 308}], {
             RGBColor[
             0.21238372481471685`, 0.3405591390591399, 0.9354063109834092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 311}], {
             RGBColor[
             0.2072579319428704, 0.33517160575679045`, 0.9351144046622886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 346}], {
             RGBColor[
             0.20767293699657277`, 0.3356078023810718, 0.935138038586152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 348}], {
             RGBColor[
             0.20651189165865158`, 0.3343874701163905, 0.93507191877177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 354}], {
             RGBColor[
             0.20401044687486744`, 0.3317582930478737, 0.9349294651918895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 374}], {
             RGBColor[
             0.19777812141168266`, 0.3252077238338092, 0.9345745434766604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 33}], {
             RGBColor[
             0.2533855843329195, 0.3836546930808141, 0.9377413062261555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 56}], {
             RGBColor[
             0.3892899244154366, 0.5053479265592988, 0.9466788406566481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 65}], {
             RGBColor[
             0.3183379395633406, 0.44565996035968214`, 0.9416695943018074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 100}], {
             RGBColor[
             0.32394697736880945`, 0.450518226988342, 0.9420269972308946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 107}], {
             RGBColor[
             0.2416314482274979, 0.371300350778743, 0.9370719255636378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 124}], {
             RGBColor[
             0.24340021238043813`, 0.3731594340496077, 0.9371726540654957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 150}], {
             RGBColor[
             0.24929421300339247`, 0.3793544024055562, 0.9375083086815804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 157}], {
             RGBColor[
             0.2535215613420126, 0.38379761353881126`, 0.9377490499156633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 167}], {
             RGBColor[
             0.24799412206051685`, 0.37798792439406714`, 0.9374342704256958]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 168}], {
             RGBColor[
             0.22907306672132033`, 0.35810069556837376`, 0.9363567443153216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 203}], {
             RGBColor[
             0.2850956592214299, 0.4168671679331099, 0.9395514255934152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 206}], {
             RGBColor[
             0.3445350824096081, 0.46835060878643464`, 0.9433388530787478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 211}], {
             RGBColor[
             0.2463354066076684, 0.3762445092844895, 0.9373398090345058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 238}], {
             RGBColor[
             0.23053198107939255`, 0.35963410705922055`, 0.9364398273297434]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 341}], {
             RGBColor[
             0.25476263408947386`, 0.38510205968495004`, 0.9378197271726287]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 358}], {
             RGBColor[
             0.2688894294981841, 0.3999502173500661, 0.9386242272724338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 386}], {
             RGBColor[
             0.3010543278758621, 0.4306897646155703, 0.940568297848379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 37}], {
             RGBColor[
             0.3241466699483991, 0.4529239992502145, 0.9419579674054581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 62}], {
             RGBColor[
             0.6778828449272916, 0.740272939600058, 0.8649535953688089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[
             0.32344841914925154`, 0.45219009338865274`, 0.9419182030554161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 78}], {
             RGBColor[
             0.29221377727191306`, 0.41936050438489303`, 0.9401394364080135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 91}], {
             RGBColor[
             0.47826887557608655`, 0.5848930154724093, 0.9527405987202289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 117}], {
             RGBColor[
             0.4612467201078884, 0.5710736628239611, 0.9514005522875624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 182}], {
             RGBColor[
             0.30289473156223595`, 0.4305868645556383, 0.9407477009537915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 187}], {
             RGBColor[
             0.29015449891481293`, 0.4171960722657919, 0.940022163552006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 208}], {
             RGBColor[
             0.3291899186131193, 0.4582247733572693, 0.9422451729560961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 239}], {
             RGBColor[
             0.43554957397249955`, 0.5502115619480115, 0.9493775788120367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 269}], {
             RGBColor[
             0.35868258725721747`, 0.48509456199634804`, 0.9440759151828396]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 309}], {
             RGBColor[
             0.5306642654095335, 0.6265873056000757, 0.957441478589943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 323}], {
             RGBColor[
             0.3922918508728892, 0.5142052168895364, 0.9462174677409253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 362}], {
             RGBColor[
             0.5776163710657185, 0.6632666473879071, 0.9621212256893779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 365}], {
             RGBColor[
             0.33498940880084865`, 0.4643204052534886, 0.9425754453427104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 377}], {
             RGBColor[
             0.3093279743113551, 0.4373486105761115, 0.941114064611224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 388}], {
             RGBColor[
             0.31737166199215083`, 0.44580303632788293`, 0.9415721407250759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 395}], {
             RGBColor[
             0.4013213562160271, 0.522026120581628, 0.946792819836912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 70}], {
             RGBColor[
             0.1896105861046007, 0.3166231263744179, 0.9341094144237078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 177}], {
             RGBColor[
             0.18182665700375172`, 0.3084417233598157, 0.9336661311767056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 285}], {
             RGBColor[
             0.1832664520031871, 0.30995503919249784`, 0.9337481253719375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 324}], {
             RGBColor[
             0.1839722969253371, 0.31069692695883033`, 0.9337883221960501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 40}], {
             RGBColor[
             0.19924073649984758`, 0.3267450250266232, 0.9346578372421862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 41}], {
             RGBColor[
             0.1999138771125005, 0.32745253849010136`, 0.9346961716042546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 48}], {
             RGBColor[
             0.20648582903789775`, 0.33436007664951256`, 0.9350704345440743]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 63}], {
             RGBColor[
             0.1971785692903057, 0.32457755654044196`, 0.9345403998703059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 86}], {
             RGBColor[
             0.23656599040606416`, 0.3659762334398404, 0.9367834552343804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 250}], {
             RGBColor[
             0.19937642447535237`, 0.3268876416919933, 0.9346655644716588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 265}], {
             RGBColor[
             0.20201462184730384`, 0.32966055440128883`, 0.9348158059091283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 295}], {
             RGBColor[
             0.19546687096427723`, 0.32277845307184394`, 0.9344429211828693]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 325}], {
             RGBColor[
             0.22165235452841858`, 0.35030105655330623`, 0.9359341457338957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 376}], {
             RGBColor[
             0.24560585367761548`, 0.37547770289867644`, 0.937298262074416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 39}], {
             RGBColor[
             0.19488507531529636`, 0.3221669489567903, 0.9344097887813494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 50}], {
             RGBColor[
             0.21136185866227802`, 0.33948509294287055`, 0.9353481172177434]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 106}], {
             RGBColor[
             0.18905752987434937`, 0.31604182921063345`, 0.9340779186895682]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 197}], {
             RGBColor[
             0.19145378666017485`, 0.3185604470239914, 0.9342143819685769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 217}], {
             RGBColor[
             0.19992147826691017`, 0.32746052778532697`, 0.9346966044787532]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 231}], {
             RGBColor[
             0.19140134234262995`, 0.31850532472108994`, 0.934211395342277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 254}], {
             RGBColor[
             0.1893368412328983, 0.3163354031578313, 0.9340938250582336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 314}], {
             RGBColor[
             0.18717488313259786`, 0.3140630481183549, 0.9339707047427519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 369}], {
             RGBColor[
             0.1860007123494566, 0.3128289201785459, 0.9339038374536819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 113}], {
             RGBColor[
             0.1857448284490183, 0.3125599699752089, 0.9338892652440982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 162}], {
             RGBColor[
             0.19056901057120365`, 0.3176304912564385, 0.9341639952792189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 183}], {
             RGBColor[
             0.18726251983199932`, 0.31415515984591347`, 0.9339756955231359]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 270}], {
             RGBColor[
             0.19689305639497057`, 0.3242774643848816, 0.9345241403332949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 357}], {
             RGBColor[
             0.18592235681432462`, 0.3127465635430944, 0.9338993752218727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 153}], {
             RGBColor[
             0.2031751711317593, 0.3308803652823261, 0.9348818974739992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 168}], {
             RGBColor[
             0.19933167973369648`, 0.3268406121315325, 0.9346630163248155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 175}], {
             RGBColor[
             0.19541782934736363`, 0.32272690722304953`, 0.9344401283353366]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 211}], {
             RGBColor[
             0.21659401962004457`, 0.3449844258476482, 0.9356460810439997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 216}], {
             RGBColor[
             0.208257693184232, 0.33622241820998533`, 0.93517133958597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 229}], {
             RGBColor[
             0.19931037008134544`, 0.32681821433580155`, 0.9346618027716389]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 294}], {
             RGBColor[
             0.2052159577699056, 0.3330253614323641, 0.9349981172539683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 329}], {
             RGBColor[
             0.23151896311630302`, 0.36067148775828894`, 0.9364960344966363]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 341}], {
             RGBColor[
             0.22502124710185, 0.35384197624810876`, 0.9361259991821227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 343}], {
             RGBColor[
             0.2007094287814945, 0.32828871373510315`, 0.9347414770948905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 358}], {
             RGBColor[
             0.2391480425105603, 0.3686901339132248, 0.9369304992819277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 379}], {
             RGBColor[
             0.19158357625518677`, 0.31869686411748455`, 0.9342217732940062]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 99}], {
             RGBColor[
             0.9432122400933031, 0.9562926111989585, 0.9505366840460105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 111}], {
             RGBColor[
             0.905435236677787, 0.5966580870469695, 0.5418299175859177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 169}], {
             RGBColor[
             0.7207585549931849, 0.779010354243588, 0.9304794974284005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 199}], {
             RGBColor[
             0.9864970705564884, 0.9886842059127192, 0.8734420155476115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 215}], {
             RGBColor[
             0.8451646800561206, 0.8790328648583385, 0.9409404903646027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 222}], {
             RGBColor[
             0.967672940132394, 0.9754000826172251, 0.9391115323234271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 223}], {
             RGBColor[
             0.9217373572851282, 0.7206872472869994, 0.5573908785042743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 224}], {
             RGBColor[
             0.7410029688449329, 0.7954456814088879, 0.9320732118445416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 247}], {
             RGBColor[
             0.9007985668118983, 0.5610186106560575, 0.5373898372859729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 259}], {
             RGBColor[
             0.9398415048836066, 0.9536048784389164, 0.9502151803126189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 292}], {
             RGBColor[
             0.9018751366680733, 0.5692935983265383, 0.5384207617960579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 363}], {
             RGBColor[
             0.6793920980440895, 0.7432878081939467, 0.9278140990011539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 383}], {
             RGBColor[
             0.6712879724630387, 0.7362684219408357, 0.9272977112853262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 393}], {
             RGBColor[
             0.8531150739602782, 0.8852437730014981, 0.9417329113283139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 400}], {
             RGBColor[
             0.9031868035222537, 0.5793756445438494, 0.5396768154569369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 46}], {
             RGBColor[
             0.8135276706473076, 0.5072097485112304, 0.5747459012560696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 52}], {
             RGBColor[
             0.905256763296387, 0.5780630184234903, 0.500145144132204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 71}], {
             RGBColor[
             0.8956113709184261, 0.5716673969312225, 0.5522037062726537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 105}], {
             RGBColor[
             0.903410578527918, 0.577299573576944, 0.5307412035187635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 111}], {
             RGBColor[
             0.8240654755025505, 0.18598336703701845`, 0.17067843256029655`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 129}], {
             RGBColor[
             0.8204275141231614, 0.1580204017101934, 0.16719471663490398`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 199}], {
             RGBColor[
             0.9051273093812517, 0.578009485902768, 0.5022905305219902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 215}], {
             RGBColor[
             0.7637949188808839, 0.4683581448483874, 0.5697890053389816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 247}], {
             RGBColor[
             0.8194288056366617, 0.15034389064610632`, 0.16623835226035183`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 259}], {
             RGBColor[
             0.85847174370837, 0.5429301584289652, 0.5790636952869976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 271}], {
             RGBColor[
             0.8207608095887371, 0.16058225670961188`, 0.16751388074914259`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 287}], {
             RGBColor[
             0.8194189331925024, 0.1502680067141652, 0.16622889839667554`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 292}], {
             RGBColor[
             0.8205053754928366, 0.15861887831658708`, 0.16726927677043682`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 303}], {
             RGBColor[
             0.857724462248068, 0.3888260026114282, 0.20072238804006853`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 333}], {
             RGBColor[
             0.8876476995379257, 0.5657281038549604, 0.5656841246616948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 337}], {
             RGBColor[
             0.8892490440589328, 0.5669223839767665, 0.5629734660851704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 345}], {
             RGBColor[
             0.824801297962475, 0.5160822589510907, 0.5758521781137924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 353}], {
             RGBColor[
             0.9073893332491589, 0.5772003661732394, 0.33799440934929903`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 385}], {
             RGBColor[
             0.907968224972722, 0.5784385570350095, 0.40100320095353803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 391}], {
             RGBColor[
             0.8208765397934485, 0.16147180977632267`, 0.16762470412387276`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 400}], {
             RGBColor[
             0.8218170423470171, 0.16870092453389818`, 0.1685253304313158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 58}], {
             RGBColor[
             0.21989646734481127`, 0.3484555077936574, 0.9358341505563915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 74}], {
             RGBColor[
             0.24756162893783695`, 0.3775333467004828, 0.9374096405821755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 107}], {
             RGBColor[
             0.23483527017028652`, 0.36415713673803723`, 0.9366848932773241]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 116}], {
             RGBColor[
             0.24330530459768918`, 0.3730596799524376, 0.9371672492076716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 118}], {
             RGBColor[
             0.30201839786374246`, 0.43026808739011524`, 0.9406757417053806]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 124}], {
             RGBColor[
             0.23660403432322674`, 0.366016220008902, 0.9367856217791819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 141}], {
             RGBColor[
             0.3011781143378584, 0.42954027603387246`, 0.9406221995821449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 150}], {
             RGBColor[
             0.24249803494618108`, 0.37221118836485045`, 0.9371212763952667]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 152}], {
             RGBColor[
             0.2237166408577273, 0.3524707523687224, 0.9360517037865118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 156}], {
             RGBColor[
             0.22423055163894667`, 0.35301090518360945`, 0.9360809702452394]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 157}], {
             RGBColor[
             0.2467253832848012, 0.3766543994981055, 0.9373620176293496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 179}], {
             RGBColor[
             0.23670129905445042`, 0.3661184514083582, 0.9367911608617348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 206}], {
             RGBColor[
             0.33773890435239673`, 0.4612073947457289, 0.942951820792434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 209}], {
             RGBColor[
             0.25581747523043485`, 0.38621076460489123`, 0.9378797988151089]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 245}], {
             RGBColor[
             0.22074175679161856`, 0.34934396059669826`, 0.9358822885398935]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 286}], {
             RGBColor[
             0.2839164063725824, 0.41458905219301934`, 0.9395222988145264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 386}], {
             RGBColor[
             0.2942581498186507, 0.4235465505748645, 0.9401812655620653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 43}], {
             RGBColor[
             0.18881744465394812`, 0.3157894844217095, 0.9340642461914408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 159}], {
             RGBColor[
             0.1825395439463383, 0.30919101273611693`, 0.9337067290334642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 250}], {
             RGBColor[
             0.1883288985198916, 0.31527599145920215`, 0.9340364242118455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 265}], {
             RGBColor[
             0.19096709589184307`, 0.31804890416849774`, 0.9341866656493147]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 321}], {
             RGBColor[
             0.18374554341254123`, 0.3104585946398788, 0.9337754089189481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 375}], {
             RGBColor[
             0.19286667153168213`, 0.3200454786060204, 0.9342948436718334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 381}], {
             RGBColor[
             0.18614322275265005`, 0.3129787076479837, 0.9339119532103186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 73}], {
             RGBColor[
             0.19430576499947028`, 0.3215580570844616, 0.9343767979158759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 154}], {
             RGBColor[
             0.18823624142486384`, 0.31517860297752887`, 0.9340311475273575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 207}], {
             RGBColor[
             0.19080850531779897`, 0.3178822154199542, 0.9341776341507367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 231}], {
             RGBColor[
             0.19065322565130216`, 0.31771900664516656`, 0.9341687912034454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 280}], {
             RGBColor[
             0.19951437129521365`, 0.3270326325460011, 0.9346734203389759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 291}], {
             RGBColor[
             0.19278015708719454`, 0.31995454643953136`, 0.9342899168022064]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 372}], {
             RGBColor[
             0.18502327958345532`, 0.31180157636866185`, 0.9338481741036404]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 387}], {
             RGBColor[
             0.1878209095169145, 0.3147420628087102, 0.9340074949896282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 392}], {
             RGBColor[
             0.19658094676972326`, 0.3239494173798535, 0.934506366151862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 61}], {
             RGBColor[
             0.23146005042347673`, 0.36060956678284806`, 0.9364926795059334]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 70}], {
             RGBColor[
             0.22130912604082534`, 0.3499403016509027, 0.9359145993792883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 90}], {
             RGBColor[
             0.2306114538784999, 0.35971763800994894`, 0.9364443531880831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 95}], {
             RGBColor[
             0.2464425329575721, 0.37635710587044113`, 0.9373459097216534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 148}], {
             RGBColor[
             0.2511034439451054, 0.38125601883716365`, 0.9376113417071936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 228}], {
             RGBColor[
             0.23483092925025606`, 0.364152574155855, 0.9366846460683501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 276}], {
             RGBColor[
             0.31234957064668134`, 0.4391299345139409, 0.941337201922877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 282}], {
             RGBColor[
             0.28033871258182136`, 0.4114037381706667, 0.9392974983530744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 301}], {
             RGBColor[
             0.2477609938146631, 0.37774289182649035`, 0.9374209941169768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 305}], {
             RGBColor[
             0.2718566625317226, 0.40306896740175535`, 0.9387932068040659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 361}], {
             RGBColor[
             0.32761397052464425`, 0.4523511904771868, 0.9423098359853219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 382}], {
             RGBColor[
             0.2838749254794549, 0.4144666280473688, 0.9395228227119613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 76}], {
             RGBColor[
             0.28363325287465024`, 0.4154469105311262, 0.9394638662021915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 78}], {
             RGBColor[
             0.25239861099731176`, 0.3826173215273665, 0.9376850995547887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 80}], {
             RGBColor[
             0.24371904320437376`, 0.3734945454606058, 0.9371908110092508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 96}], {
             RGBColor[
             0.24798039051581972`, 0.3779734916699602, 0.9374334884345392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 104}], {
             RGBColor[
             0.2541903466574486, 0.3845005493087726, 0.9377871362499982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 117}], {
             RGBColor[
             0.4214315538332871, 0.5343304799664346, 0.9489462154343377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 145}], {
             RGBColor[
             0.2671022972631469, 0.3980718280603137, 0.9385224527354736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 182}], {
             RGBColor[
             0.26307956528763465`, 0.3938436816981118, 0.9382933641005669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 187}], {
             RGBColor[
             0.2503393326402117, 0.3804528894082654, 0.9375678266987812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 208}], {
             RGBColor[
             0.289374752338518, 0.42148159049974276`, 0.9397908361028714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 269}], {
             RGBColor[
             0.3188674209826161, 0.4483513791388215, 0.9416215783296149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 323}], {
             RGBColor[
             0.35247668459828785`, 0.4774620340320098, 0.9437631308877006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 365}], {
             RGBColor[
             0.29517424252624735`, 0.4275772223959621, 0.9401211084894857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 377}], {
             RGBColor[
             0.2695128080367538, 0.400605427718585, 0.9386597277579993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 388}], {
             RGBColor[
             0.27755649571754953`, 0.4090598534703564, 0.9391178038718512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 395}], {
             RGBColor[
             0.3615061899414258, 0.48528293772410147`, 0.9443384829836874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 44}], {
             RGBColor[
             0.24351959225973108`, 0.37328490987186613`, 0.9371794525730147]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 66}], {
             RGBColor[
             0.22742648369193186`, 0.3563700324050926, 0.9362629738476992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 81}], {
             RGBColor[
             0.2439408678768847, 0.37372769725591143`, 0.9372034435961902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 119}], {
             RGBColor[
             0.249257790450226, 0.37931611999285497`, 0.9375062344710599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 128}], {
             RGBColor[
             0.281313846761083, 0.4130090676469258, 0.9393317794552777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 130}], {
             RGBColor[
             0.23719458554175432`, 0.36663692678268434`, 0.9368192527974348]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 135}], {
             RGBColor[
             0.2970405045044002, 0.42707857493039736`, 0.9403174695829958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 146}], {
             RGBColor[
             0.2289275307271461, 0.3579477280109817, 0.9363484562557545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 151}], {
             RGBColor[
             0.23316903340538708`, 0.36240581625261525`, 0.9365900035585395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 213}], {
             RGBColor[
             0.2920695594579869, 0.42277299217815684`, 0.9400007253602725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 224}], {
             RGBColor[
             0.37823665311305865`, 0.49620023139778335`, 0.9458245390097163]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 227}], {
             RGBColor[
             0.2663587998591236, 0.39729036514822713`, 0.9384801116582203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 243}], {
             RGBColor[
             0.24505985490147014`, 0.37490382356662577`, 0.9372671682518474]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 267}], {
             RGBColor[
             0.22814489442186137`, 0.3571251276321197, 0.9363038862759752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 306}], {
             RGBColor[
             0.24051285588611682`, 0.3701246393051007, 0.9370082233846052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 311}], {
             RGBColor[
             0.23066096804752526`, 0.35976968054097413`, 0.9364471729467594]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 346}], {
             RGBColor[
             0.23107597310122763`, 0.36020587716525554`, 0.9364708068706228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 350}], {
             RGBColor[
             0.3036355127427933, 0.43279083959174136`, 0.9407376976762094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 363}], {
             RGBColor[
             0.3166257823122153, 0.444042358182842, 0.9415654261663287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 383}], {
             RGBColor[
             0.3085216567311646, 0.43702297192973105`, 0.9410490384505009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 47}], {
             RGBColor[
             0.18958921033534365`, 0.3166006590856267, 0.9341081971052712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 50}], {
             RGBColor[
             0.21465093660737516`, 0.342942122402754, 0.9355354253409618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 136}], {
             RGBColor[
             0.19040517985093924`, 0.31745829478197307`, 0.9341546653620656]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 149}], {
             RGBColor[
             0.2042501787734501, 0.33201026647316434`, 0.9349431175688622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 164}], {
             RGBColor[
             0.20658345954088297`, 0.3344626924982814, 0.9350759944567879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 197}], {
             RGBColor[
             0.19474286460527196`, 0.3220174764838748, 0.9344016900917953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 210}], {
             RGBColor[
             0.22192743235245416`, 0.35059018078730897`, 0.9359498110090333]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 217}], {
             RGBColor[
             0.2032105562120073, 0.33091755724521044`, 0.9348839126019717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 230}], {
             RGBColor[
             0.20964976351428055`, 0.33768557238922303`, 0.9352506159318827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 254}], {
             RGBColor[
             0.19262591917799537`, 0.31979243261771473`, 0.934281133181452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 258}], {
             RGBColor[
             0.21791338707223826`, 0.34637116469263174`, 0.9357212170685729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 314}], {
             RGBColor[
             0.19046396107769498`, 0.3175200775782383, 0.9341580128659703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 328}], {
             RGBColor[
             0.21476290196670605`, 0.3430598050944246, 0.9355418016025379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 41}], {
             RGBColor[
             0.19412189539412833`, 0.3213647984712409, 0.9343663268138622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 48}], {
             RGBColor[
             0.20069384731952558`, 0.3282723366306521, 0.934740589753682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 63}], {
             RGBColor[
             0.19138658757193353`, 0.3184898165215815, 0.9342105550799136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 103}], {
             RGBColor[
             0.19411926264855695`, 0.32136203128871965`, 0.9343661768828968]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 265}], {
             RGBColor[
             0.1962226401289317, 0.32357281438242835`, 0.9344859611187359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 295}], {
             RGBColor[
             0.1896748892459051, 0.31669071305298346`, 0.934113076392477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 48}], {
             RGBColor[
             0.2013669879321785, 0.3289798500941302, 0.9347789241157504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 63}], {
             RGBColor[
             0.19205972818458644`, 0.31919732998505956`, 0.9342488894419819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.1942575833696331, 0.32150741513661096`, 0.934374054043335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 265}], {
             RGBColor[
             0.19689578074158462`, 0.3242803278459065, 0.9345242954808043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 295}], {
             RGBColor[
             0.19034802985855803`, 0.31739822651646155`, 0.9341514107545453]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 325}], {
             RGBColor[
             0.2165335134226994, 0.3449208299979239, 0.9356426353055718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 381}], {
             RGBColor[
             0.19207190760239157`, 0.31921013132539244`, 0.934249583041808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 67}], {
             RGBColor[
             0.18164605198289263`, 0.3082518960318731, 0.9336558459879488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 75}], {
             RGBColor[
             0.18289766237674282`, 0.30956741791249204`, 0.9337271233482869]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 133}], {
             RGBColor[
             0.1836453052262827, 0.310353237950653, 0.9337697005025297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 178}], {
             RGBColor[
             0.18344665505298052`, 0.31014444402336394`, 0.9337583876690367]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 200}], {
             RGBColor[
             0.18896638878164698`, 0.3159460341435242, 0.9340727283391701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 278}], {
             RGBColor[
             0.18598976689484537`, 0.3128174158117676, 0.9339032141262342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 296}], {
             RGBColor[
             0.18148102360409654`, 0.30807844074235485`, 0.933646447865914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 320}], {
             RGBColor[
             0.18379681968568948`, 0.3105124892540611, 0.9337783290268474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 330}], {
             RGBColor[
             0.18629301045548374`, 0.31313614402075074`, 0.9339204833984038]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 347}], {
             RGBColor[
             0.18410501336322643`, 0.3108364203497602, 0.9337958802008515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 367}], {
             RGBColor[
             0.1849893429390042, 0.3117659068036362, 0.9338462414619436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 398}], {
             RGBColor[
             0.18234639975021955`, 0.30898800593994685`, 0.9336957297572264]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 159}], {
             RGBColor[
             0.1884193222929882, 0.31537103257792504`, 0.9340415737119533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 250}], {
             RGBColor[
             0.19420867686654147`, 0.32145601130101026`, 0.9343712688903346]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 265}], {
             RGBColor[
             0.19684687423849298`, 0.3242289240103058, 0.934521510327804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 321}], {
             RGBColor[
             0.1896253217591911, 0.31663861448168684`, 0.9341102535974373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 325}], {
             RGBColor[
             0.21648460691960775`, 0.3448694261623232, 0.9356398501525713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 375}], {
             RGBColor[
             0.19874644987833204`, 0.3262254984478285, 0.9346296883503225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 381}], {
             RGBColor[
             0.19202300109929993`, 0.3191587274897918, 0.9342467978888077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 66}], {
             RGBColor[
             0.21222031867993352`, 0.3403873888509353, 0.9353970052457711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 81}], {
             RGBColor[
             0.22873470286488637`, 0.35774505370175413`, 0.9363374749942621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 119}], {
             RGBColor[
             0.23405162543822766`, 0.3633334764386976, 0.9366402658691317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[
             0.26610768174908467`, 0.39702642409276845`, 0.9384658108533496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 130}], {
             RGBColor[
             0.22198842052975598`, 0.350654283228527, 0.9359532841955067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 135}], {
             RGBColor[
             0.2818343394924019, 0.41109593137624006`, 0.9394515009810677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 146}], {
             RGBColor[
             0.21372136571514777`, 0.3419650844568244, 0.9354824876538264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 151}], {
             RGBColor[
             0.21796286839338874`, 0.3464231726984579, 0.9357240349566114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 227}], {
             RGBColor[
             0.25115263484712524`, 0.3813077215940698, 0.9376141430562922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 243}], {
             RGBColor[
             0.2298536898894718, 0.3589211800124685, 0.9364011996499193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 267}], {
             RGBColor[
             0.21293872940986303`, 0.3411424840779623, 0.935437917674047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 275}], {
             RGBColor[
             0.21122882729611786`, 0.33934526854236047`, 0.9353405412782427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 311}], {
             RGBColor[
             0.21545480303552692`, 0.34378703698681684`, 0.9355812043448313]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 317}], {
             RGBColor[
             0.2084087804726259, 0.3363812205295747, 0.9351799437835304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 326}], {
             RGBColor[
             0.2349425006851034, 0.3642698428079171, 0.9366909998965096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 344}], {
             RGBColor[
             0.20993796520971017`, 0.3379884906441625, 0.9352670285920812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 346}], {
             RGBColor[
             0.2158698080892293, 0.3442232336110982, 0.9356048382686947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 383}], {
             RGBColor[
             0.29331549171916627`, 0.4210403283755737, 0.9401830698485728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 48}], {
             RGBColor[
             0.2238300988639671, 0.3525900039269335, 0.9360581650521211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 74}], {
             RGBColor[
             0.2441275547351621, 0.3739239169805914, 0.9372140751365906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 103}], {
             RGBColor[
             0.21725551419299843`, 0.345679698585001, 0.9356837521813359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 116}], {
             RGBColor[
             0.23987123039501432`, 0.3694502502325462, 0.9369716837620867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 262}], {
             RGBColor[
             0.30202723660803465`, 0.4296407358190505, 0.9406995556283282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 290}], {
             RGBColor[
             0.24862549482263574`, 0.3786515371983993, 0.9374702261704662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 304}], {
             RGBColor[
             0.2609958832174149, 0.3916535997292371, 0.9381747014891992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 338}], {
             RGBColor[
             0.2249286875668965, 0.3537446903082591, 0.9361207280535366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 52}], {
             RGBColor[
             0.89726556755869, 0.9188637535063902, 0.9066512485949225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 60}], {
             RGBColor[
             0.7562801355297237, 0.809531056908518, 0.9763425941360632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 102}], {
             RGBColor[
             0.5772856165740025, 0.6623742905041798, 0.9623565848838942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 105}], {
             RGBColor[
             0.8954193827902208, 0.9181003086598438, 0.937247307981482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 128}], {
             RGBColor[
             0.5547192055800235, 0.6423805327309791, 0.9609350717272003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 139}], {
             RGBColor[
             0.5562400144756487, 0.6439789993051345, 0.961021679543971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 199}], {
             RGBColor[
             0.8971361136435547, 0.9188102209856679, 0.9087966349847089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 213}], {
             RGBColor[
             0.5654749182769274, 0.6521444572622102, 0.9616040176321952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 215}], {
             RGBColor[
             0.7558037231431869, 0.8091588799312872, 0.9762951098017001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 259}], {
             RGBColor[
             0.850480547970673, 0.8837308935118651, 0.9855697997497163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 271}], {
             RGBColor[
             0.8127696138510401, 0.5013829917925117, 0.574019985211861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 287}], {
             RGBColor[
             0.8114277374548052, 0.49106874179706506`, 0.572735002859394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 333}], {
             RGBColor[
             0.8796565038002286, 0.9065288389378603, 0.9721902291244133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 337}], {
             RGBColor[
             0.8812578483212357, 0.9077231190596664, 0.969479570547889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 345}], {
             RGBColor[
             0.8168101022247779, 0.8568829940339906, 0.982358282576511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 350}], {
             RGBColor[
             0.5770408715617338, 0.6621623046757947, 0.9623409899481321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 353}], {
             RGBColor[
             0.8993981375114619, 0.9180011012561393, 0.7445005138120175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 400}], {
             RGBColor[
             0.81382584660932, 0.509501659616798, 0.5750314348940344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 136}], {
             RGBColor[
             0.18182023692588944`, 0.308434975450926, 0.9336657655627689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 149}], {
             RGBColor[
             0.1956652358484003, 0.3229869471421173, 0.9344542177695655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 155}], {
             RGBColor[
             0.18345196765990118`, 0.3101500279100763, 0.9337586902141416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 268}], {
             RGBColor[
             0.18433220446865944`, 0.3110752126063183, 0.9338088183982067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 279}], {
             RGBColor[
             0.19002059109890063`, 0.3170540676192452, 0.934132763601585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 299}], {
             RGBColor[
             0.184696983160691, 0.3114586181399484, 0.9338295920050762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 300}], {
             RGBColor[
             0.18858263454534693`, 0.31554268410974895`, 0.9340508741031263]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 371}], {
             RGBColor[
             0.18051873474236652`, 0.3070670141360388, 0.9335916469388172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.1986316801099837, 0.3261048681444708, 0.9346231523818017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 86}], {
             RGBColor[
             0.23801910122574216`, 0.3675035450438693, 0.9368662077458763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 103}], {
             RGBColor[
             0.2013643551866071, 0.328977082911609, 0.9347787741847848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 295}], {
             RGBColor[
             0.19691998178395526`, 0.3243057646758728, 0.9345256736943651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 191}], {
             RGBColor[
             0.18385357890938503`, 0.3105721467969078, 0.933781561380669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 225}], {
             RGBColor[
             0.19609003670444464`, 0.3234334397757498, 0.9344784095498806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 235}], {
             RGBColor[
             0.1884735679979762, 0.31542804825324383`, 0.9340446629246031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 261}], {
             RGBColor[
             0.1864507904031121, 0.31330198074953464`, 0.9339294687330069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 327}], {
             RGBColor[
             0.18473066760764006`, 0.3114940226294092, 0.9338315102844983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 335}], {
             RGBColor[
             0.1909811618412971, 0.3180636883732066, 0.9341874666843275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 349}], {
             RGBColor[
             0.19105637302960854`, 0.3181427401007867, 0.9341917498502368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 355}], {
             RGBColor[
             0.19591924831876065`, 0.3232539303537868, 0.9344686834039748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 127}], {
             RGBColor[
             0.28524823564473223`, 0.4143130772255349, 0.9396595042068966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 137}], {
             RGBColor[
             0.2618861891426283, 0.3925893677052923, 0.9382254030945505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 138}], {
             RGBColor[
             0.26001645706684573`, 0.3906241607457843, 0.9381189246188555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 147}], {
             RGBColor[
             0.23917140342485926`, 0.3687146877153205, 0.9369318296514377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 164}], {
             RGBColor[
             0.22306024288786463`, 0.3517808364843617, 0.9360143228931819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 197}], {
             RGBColor[
             0.21121964795225362`, 0.33933562046995513`, 0.9353400185281894]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 210}], {
             RGBColor[
             0.23840421569943582`, 0.3679083247733892, 0.9368881394454274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 217}], {
             RGBColor[
             0.21968733955898895`, 0.34823570123129066`, 0.9358222410383658]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 230}], {
             RGBColor[
             0.2261265468612622, 0.35500371637530337`, 0.9361889443682767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 242}], {
             RGBColor[
             0.2857631387189643, 0.41475906038865373`, 0.9396923133754758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 254}], {
             RGBColor[
             0.20910270252497706`, 0.33711057660379506`, 0.9352194616178461]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 258}], {
             RGBColor[
             0.23439017041921995`, 0.3636893086787121, 0.9366595455049669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 328}], {
             RGBColor[
             0.23123968531368772`, 0.36037794908050486`, 0.9364801300389318]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 331}], {
             RGBColor[
             0.2360482874744978, 0.36543209483450245`, 0.9367539728183005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 79}], {
             RGBColor[
             0.20012999875823717`, 0.3276796960426744, 0.934708479412256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 87}], {
             RGBColor[
             0.1940286984190197, 0.3212668425413722, 0.9343610193840024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 126}], {
             RGBColor[
             0.1918840790772874, 0.31901271163649164`, 0.9342388864851707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 176}], {
             RGBColor[
             0.19370665948804128`, 0.32092835920646634`, 0.9343426797432972]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 205}], {
             RGBColor[
             0.19318129293550862`, 0.32037616564959115`, 0.9343127608953405]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 232}], {
             RGBColor[
             0.19578437289714112`, 0.32311216773406903`, 0.9344610024482438]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 277}], {
             RGBColor[
             0.19316166908716753`, 0.3203555397407608, 0.9343116433462084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 298}], {
             RGBColor[
             0.20333725610200998`, 0.3310507268628402, 0.9348911279732717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 373}], {
             RGBColor[
             0.1995969758310581, 0.32711945515060364`, 0.9346781245450898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 390}], {
             RGBColor[
             0.2070958500160861, 0.33500124737515247`, 0.935105174336337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 60}], {
             RGBColor[
             0.8480092281788032, 0.880384326820778, 0.9017418370121976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 68}], {
             RGBColor[
             0.9052995090875355, 0.9251530264391655, 0.9074485213302443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 105}], {
             RGBColor[
             0.9871484754393005, 0.988953578572104, 0.8626465508576164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 129}], {
             RGBColor[
             0.904165411034544, 0.5696744067053534, 0.4991000639737569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 199}], {
             RGBColor[
             0.9888652062926342, 0.9896634908979279, 0.8341958778608433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 271}], {
             RGBColor[
             0.9044987065001195, 0.5722362617047718, 0.4994192280879955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 287}], {
             RGBColor[
             0.9031568301038848, 0.5619220117093251, 0.49813424573552845`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 303}], {
             RGBColor[
             0.9414623591594504, 0.8004800076065881, 0.5326277353789215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 333}], {
             RGBColor[
             0.9713855964493081, 0.9773821088501203, 0.8975894720005477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 337}], {
             RGBColor[
             0.9729869409703154, 0.9785763889719264, 0.8948788134240234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 345}], {
             RGBColor[
             0.9085391948738575, 0.9277362639462506, 0.9077575254526454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 353}], {
             RGBColor[
             0.9911272301605415, 0.9888543711683995, 0.6698997566881519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 391}], {
             RGBColor[
             0.904614436704831, 0.5731258147714826, 0.49953005146272567`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 69}], {
             RGBColor[
             0.4877113731208531, 0.5936081076641104, 0.9531940365593021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 93}], {
             RGBColor[
             0.37256678589576175`, 0.4971203570169409, 0.9449606040427729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 131}], {
             RGBColor[
             0.6083578580504109, 0.6889233390243821, 0.9644906126536026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 142}], {
             RGBColor[
             0.43838221439814257`, 0.5535604743597381, 0.949310664485988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 188}], {
             RGBColor[
             0.33920701496392514`, 0.465180569896386, 0.9429464497347737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 201}], {
             RGBColor[
             0.5341594365329997, 0.6309589682060907, 0.9570952074204189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 264}], {
             RGBColor[
             0.3312918681319017, 0.4568612487266348, 0.9424956938321003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 273}], {
             RGBColor[
             0.4633253395942303, 0.573810427068907, 0.9512742786711021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 281}], {
             RGBColor[
             0.40067800773256046`, 0.5214688844608842, 0.9467518262404362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[
             0.35836727987096656`, 0.4848214585861875, 0.944055824075003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 394}], {
             RGBColor[
             0.38011496144870427`, 0.5036582072985654, 0.9454415671144167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 64}], {
             RGBColor[
             0.970419525130984, 0.9095497585157698, 0.3557751825465969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 83}], {
             RGBColor[
             0.9496193654049732, 0.8977579075232218, 0.6225379522867944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 123}], {
             RGBColor[
             0.8957058066069172, 0.5826430148496441, 0.23309163667201951`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 161}], {
             RGBColor[
             0.9139000708098552, 0.6892402426005217, 0.2492124251865322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 196}], {
             RGBColor[
             0.8961892019683437, 0.8555483275728113, 0.6311082747514651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 198}], {
             RGBColor[
             0.8885256847199983, 0.8494376469396148, 0.6303773216350153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 206}], {
             RGBColor[
             0.6885711015156095, 0.68922695188861, 0.6128856824256679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 214}], {
             RGBColor[
             0.913587591361185, 0.6878213464055395, 0.24895168467498954`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 310}], {
             RGBColor[
             0.8873852444618682, 0.5186875281092153, 0.22512385696518958`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 332}], {
             RGBColor[
             0.8830293594773344, 0.4852062873571179, 0.22095265658473165`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 389}], {
             RGBColor[
             0.9706885388162402, 0.9101251515870772, 0.3850556620267193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 57}], {
             RGBColor[
             0.5760181454967422, 0.6613528823456771, 0.9622434817439033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 68}], {
             RGBColor[
             0.8126708442680417, 0.8535970039103761, 0.981959617507143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 72}], {
             RGBColor[
             0.6346370252408752, 0.7117938428167392, 0.9660702931075245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 83}], {
             RGBColor[
             0.8773611303882973, 0.9047851000408222, 0.9744632955960668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 123}], {
             RGBColor[
             0.8234475715902414, 0.5896702073672445, 0.5850169799812919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 161}], {
             RGBColor[
             0.8416418357931794, 0.6962674351181222, 0.6011377684958046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 196}], {
             RGBColor[
             0.8239309669516679, 0.8625755200904117, 0.9830336180607375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 236}], {
             RGBColor[
             0.6566866391587384, 0.7296947127190476, 0.9678061194855357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 262}], {
             RGBColor[
             0.5840352729572464, 0.6682969151994234, 0.9627543260164191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 284}], {
             RGBColor[
             0.7718010949853338, 0.8216561483989014, 0.9778895783229857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 334}], {
             RGBColor[
             0.8819744590496598, 0.862025730858683, 0.6405013220512796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 366}], {
             RGBColor[
             0.8985186945130963, 0.9173414029032505, 0.7466017890196988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 397}], {
             RGBColor[
             0.5839584526615165, 0.6682303773203624, 0.9627494310951048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 65}], {
             RGBColor[
             0.4474461015886463, 0.5602099797974611, 0.9502200964459863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 100}], {
             RGBColor[
             0.4530551393941151, 0.565068246426121, 0.9505774993750733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 174}], {
             RGBColor[
             0.4681168777823908, 0.5781139671930625, 0.9515372200266019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 198}], {
             RGBColor[
             0.6735978276393025, 0.7431113232752183, 0.969380994432274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 203}], {
             RGBColor[
             0.4142038212467356, 0.5314171873708888, 0.948101927737594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 206}], {
             RGBColor[
             0.4736432444349138, 0.5829006282242136, 0.9518893552229266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 266}], {
             RGBColor[
             0.5883098999275997, 0.6764125091387695, 0.9608991949142476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 341}], {
             RGBColor[
             0.38387079611477953`, 0.499652079122729, 0.9463702293168075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 358}], {
             RGBColor[
             0.3979975915234898, 0.5145002367878451, 0.9471747294166126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 68}], {
             RGBColor[
             0.584951659196002, 0.6683449078949819, 0.9631304154261922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 72}], {
             RGBColor[
             0.4069178401688355, 0.5265417468013449, 0.9472410910265736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 86}], {
             RGBColor[
             0.30819911150930557`, 0.43761024408224003`, 0.9409967540495674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 108}], {
             RGBColor[
             0.32733127751038416`, 0.4577193635987606, 0.9420863025998256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 236}], {
             RGBColor[
             0.4289674540866987, 0.5444426167036535, 0.9489769174045849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 262}], {
             RGBColor[
             0.35631608788520674`, 0.4830448191840292, 0.9439251239354682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 284}], {
             RGBColor[
             0.544081909913294, 0.6364040523835073, 0.9590603762420349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 297}], {
             RGBColor[
             0.3224295006293375, 0.45256728530617585`, 0.9418071536579791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 325}], {
             RGBColor[
             0.29328547563165996`, 0.42193506719570584`, 0.9401474445490827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 376}], {
             RGBColor[
             0.31723897478085683`, 0.4471117135410761, 0.941511560889603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 397}], {
             RGBColor[
             0.3562392675894767, 0.4829782813049682, 0.943920229014154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 124}], {
             RGBColor[
             0.20991109539232988`, 0.337960248762451, 0.9352654983957317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 152}], {
             RGBColor[
             0.19702370192683044`, 0.32441478112227146`, 0.9345315804030616]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 156}], {
             RGBColor[
             0.19753761270804981`, 0.3249549339371585, 0.9345608468617892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 160}], {
             RGBColor[
             0.1942495004305084, 0.32149891945510295`, 0.9343735937319094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 179}], {
             RGBColor[
             0.21000836012355356`, 0.3380624801619072, 0.9352710374782847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 181}], {
             RGBColor[
             0.19266290312611054`, 0.31983130509210156`, 0.9342832393625844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 220}], {
             RGBColor[
             0.186453938859043, 0.31330528997634166`, 0.9339296480329143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[
             0.1940488178607217, 0.32128798935024727`, 0.9343621651564433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 352}], {
             RGBColor[
             0.18979453396815193`, 0.3168164672419784, 0.9341198899824106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 396}], {
             RGBColor[
             0.18880077082680655`, 0.315771959172202, 0.9340632966416518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 132}], {
             RGBColor[
             0.20457320024571096`, 0.33234978252125474`, 0.93496151316384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 149}], {
             RGBColor[
             0.21329928840113216`, 0.34152145443854653`, 0.9354584509752006]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 155}], {
             RGBColor[
             0.20108602021263303`, 0.3286845352065056, 0.9347629234197767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 164}], {
             RGBColor[
             0.215632569168565, 0.3439738804636637, 0.9355913278631264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 210}], {
             RGBColor[
             0.23097654198013617`, 0.36010136875269116`, 0.9364651444153718]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 230}], {
             RGBColor[
             0.21869887314196257`, 0.34719676035460534`, 0.9357659493382211]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 258}], {
             RGBColor[
             0.2269624966999203, 0.35588235265801405`, 0.9362365504749113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 264}], {
             RGBColor[
             0.2381256499847355, 0.3676155345451527, 0.9368722755400762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 268}], {
             RGBColor[
             0.2019662570213913, 0.3296097199027477, 0.9348130516038419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 279}], {
             RGBColor[
             0.2076546436516325, 0.3355885749156745, 0.9351369968072203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 299}], {
             RGBColor[
             0.20233103571342284`, 0.3299931254363777, 0.9348338252107113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 300}], {
             RGBColor[
             0.20621668709807878`, 0.3340771914061782, 0.9350551073087614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 328}], {
             RGBColor[
             0.22381201159438807`, 0.3525709930598068, 0.9360571350088763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 394}], {
             RGBColor[
             0.286948743301538, 0.41441249311708334`, 0.9398181488223927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 68}], {
             RGBColor[
             0.7643140770585692, 0.8158203298412934, 0.9771398668713851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 72}], {
             RGBColor[
             0.5862802580314027, 0.6740171687476564, 0.9612505424717664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 102}], {
             RGBColor[
             0.5280292771941157, 0.6238948638185677, 0.9574471733011694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 105}], {
             RGBColor[
             0.8461630434103341, 0.8796208819742317, 0.932337896398757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 108}], {
             RGBColor[
             0.5066936953729514, 0.6051947855450721, 0.9560957540450186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 139}], {
             RGBColor[
             0.506983675095762, 0.6054995726195224, 0.9561122679612462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 297}], {
             RGBColor[
             0.5017919184919047, 0.6000427072524873, 0.955816605103172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 333}], {
             RGBColor[
             0.8304001644203418, 0.8680494122522482, 0.9672808175416883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 337}], {
             RGBColor[
             0.8320015089413489, 0.8692436923740543, 0.9645701589651641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 345}], {
             RGBColor[
             0.7675537628448912, 0.8184035673483785, 0.9774488709937861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 353}], {
             RGBColor[
             0.8501417981315751, 0.8795216745705272, 0.7395911022292926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 70}], {
             RGBColor[
             0.20711529305388426`, 0.33502168324063814`, 0.9351062815885762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 90}], {
             RGBColor[
             0.21641762089155886`, 0.3447990195996844, 0.935636035397371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 95}], {
             RGBColor[
             0.23224869997063102`, 0.3614384874601766, 0.9365375919309413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 148}], {
             RGBColor[
             0.23690961095816437`, 0.3663374004268991, 0.9368030239164815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 228}], {
             RGBColor[
             0.220637096263315, 0.34923395574559046`, 0.935876328277638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 282}], {
             RGBColor[
             0.2661448795948803, 0.3964851197604022, 0.9384891805623623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 285}], {
             RGBColor[
             0.2007711589524707, 0.32835359605871806`, 0.934744992536806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 301}], {
             RGBColor[
             0.23356716082772205`, 0.3628242734162258, 0.9366126763262647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 382}], {
             RGBColor[
             0.2696810924925139, 0.39954800963710424`, 0.9387145049212492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 91}], {
             RGBColor[
             0.7921898842803778, 0.8354987729647263, 0.873281889830355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 111}], {
             RGBColor[
             0.9092079691258396, 0.5982182088690406, 0.47930597740308856`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 117}], {
             RGBColor[
             0.7751677288121797, 0.821679420316278, 0.8719418433976884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 223}], {
             RGBColor[
             0.9255100897331807, 0.7222473691090705, 0.4948669383214451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 247}], {
             RGBColor[
             0.9045712992599508, 0.5625787324781286, 0.4748658971031438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 256}], {
             RGBColor[
             0.992053902372576, 0.9909820986727351, 0.781350931735281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 319}], {
             RGBColor[
             0.9121241184522142, 0.6206330104563391, 0.4820984852913445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 323}], {
             RGBColor[
             0.7062128595771804, 0.7648109743818534, 0.8667587588510515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 362}], {
             RGBColor[
             0.8915373797700097, 0.913872404880224, 0.882662516799504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 395}], {
             RGBColor[
             0.7152423649203183, 0.772631878073945, 0.8673341109470382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 103}], {
             RGBColor[
             0.19205709543901506`, 0.31919456280253833`, 0.9342487395110164]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 295}], {
             RGBColor[
             0.1876127220363632, 0.31452324456680214`, 0.9339956390205967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 88}], {
             RGBColor[
             0.7114905669436782, 0.7668789695612932, 0.6914868954695467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 101}], {
             RGBColor[
             0.9232794978996539, 0.7012101823729198, 0.31682349709282953`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 115}], {
             RGBColor[
             0.973846560757742, 0.9231368127839409, 0.35853265585475147`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 120}], {
             RGBColor[
             0.7025664799902631, 0.759149373979897, 0.6909182605401354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 123}], {
             RGBColor[
             0.9178715311357676, 0.6596421800395433, 0.31164482201230714`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 140}], {
             RGBColor[
             0.6994659535308891, 0.7564638537977784, 0.690720697735832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 161}], {
             RGBColor[
             0.9360657953387055, 0.766239407790421, 0.32776561052681985`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 193}], {
             RGBColor[
             0.9152566921622731, 0.9300770448033753, 0.7093659477350615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 195}], {
             RGBColor[
             0.7086017617355334, 0.7643768316855696, 0.6913028233561538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 214}], {
             RGBColor[
             0.9357533158900353, 0.7648205115954387, 0.32750487001527717`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 233}], {
             RGBColor[
             0.9814581324353071, 0.9819712119725741, 0.6847171998056071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 257}], {
             RGBColor[
             0.9810027572631417, 0.9816315939147817, 0.6854880311912166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 283}], {
             RGBColor[
             0.9622538962308652, 0.8771757609613251, 0.3492049258616166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 312}], {
             RGBColor[
             0.7702008939642393, 0.8151650470913949, 0.695936819489472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 332}], {
             RGBColor[
             0.9051950840061846, 0.5622054525470171, 0.2995058419250193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 356}], {
             RGBColor[
             0.9689844051155808, 0.9726683265613763, 0.7058319664887789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 360}], {
             RGBColor[
             0.8276703795499445, 0.8615089159497265, 0.7006746506658257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 380}], {
             RGBColor[
             0.8564837144111264, 0.8840181121327374, 0.7035464946088651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 389}], {
             RGBColor[
             0.9928542633450905, 0.9871243167769764, 0.4636088473670069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 100}], {
             RGBColor[
             0.38210315454201915`, 0.5053802802265043, 0.9455682530202327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 167}], {
             RGBColor[
             0.30615029923372655`, 0.43284997763222943`, 0.940975526215034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 174}], {
             RGBColor[
             0.39716489293029483`, 0.5184260009934458, 0.9465279736717613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 198}], {
             RGBColor[
             0.6026458427872066, 0.6834233570756016, 0.9643717480774334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 203}], {
             RGBColor[
             0.34325183639463963`, 0.4717292211712722, 0.9430926813827534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 206}], {
             RGBColor[
             0.4026912595828178, 0.5232126620245969, 0.9468801088680859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 211}], {
             RGBColor[
             0.3044915837808781, 0.4311065625226518, 0.9408810648238439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 266}], {
             RGBColor[
             0.5173579150755038, 0.6167245429391528, 0.9558899485594068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 313}], {
             RGBColor[
             0.33055584599709903`, 0.45850175468157234`, 0.9423653859984371]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 329}], {
             RGBColor[
             0.31941652727713654`, 0.4467936244332925, 0.9417310182764805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 340}], {
             RGBColor[
             0.3239430587205376, 0.45155129597897675`, 0.941988797545779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 341}], {
             RGBColor[
             0.31291881126268356`, 0.4399641129231123, 0.9413609829619669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 358}], {
             RGBColor[
             0.3270456066713938, 0.4548122705882284, 0.942165483061772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 81}], {
             RGBColor[
             0.21264159429708712`, 0.3408301762349806, 0.9354209962689466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 119}], {
             RGBColor[
             0.21795851687042844`, 0.3464185989719241, 0.9357237871438162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 130}], {
             RGBColor[
             0.20589531196195676`, 0.3337394057617535, 0.9350368054701912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 146}], {
             RGBColor[
             0.19762825714734855`, 0.3250502069900508, 0.9345660089285108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 151}], {
             RGBColor[
             0.20186975982558952`, 0.3295082952316844, 0.9348075562312959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 158}], {
             RGBColor[
             0.19363377892106423`, 0.3208517571096786, 0.934338529302825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 243}], {
             RGBColor[
             0.21376058132167255`, 0.342006302545695, 0.9354847209246038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 267}], {
             RGBColor[
             0.1968456208420638, 0.3242276066111888, 0.9345214389487315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 275}], {
             RGBColor[
             0.19513571872831864`, 0.3224303910755869, 0.9344240625529272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 311}], {
             RGBColor[
             0.19936169446772767`, 0.32687215952004334`, 0.9346647256195157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 317}], {
             RGBColor[
             0.19231567190482668`, 0.3194663430628012, 0.9342634650582149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 344}], {
             RGBColor[
             0.19384485664191092`, 0.32107361317738903`, 0.9343505498667657]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 346}], {
             RGBColor[
             0.19977669952143007`, 0.3273083561443247, 0.9346883595433791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 354}], {
             RGBColor[
             0.19611420939972474`, 0.3234588468111266, 0.9344797861491166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 75}], {
             RGBColor[
             0.1806580838475214, 0.3072134788808002, 0.9335995826642074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 126}], {
             RGBColor[
             0.18098291600078534`, 0.3075548980694286, 0.9336180813747896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 133}], {
             RGBColor[
             0.1814057266970613, 0.30799929891896116`, 0.9336421598184501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 200}], {
             RGBColor[
             0.1867268102524256, 0.3135920951118324, 0.9339451876550904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 320}], {
             RGBColor[
             0.1815572411564681, 0.30815855022236927`, 0.9336507883427678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 347}], {
             RGBColor[
             0.18186543483400505`, 0.3084824813180684, 0.9336683395167719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 398}], {
             RGBColor[
             0.18010682122099816`, 0.306634066908255, 0.9335681890731469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 72}], {
             RGBColor[
             0.6435705389401349, 0.7187858683660439, 0.9669572267898132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 236}], {
             RGBColor[
             0.6656201528579981, 0.7366867382683524, 0.9686930531678246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 262}], {
             RGBColor[
             0.5929687866565062, 0.6752889407487281, 0.9636412596987081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 284}], {
             RGBColor[
             0.7807346086845934, 0.8286481739482061, 0.9787765120052747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 333}], {
             RGBColor[
             0.8876904453290742, 0.9128181118706356, 0.9729875018597351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 334}], {
             RGBColor[
             0.8909079727489195, 0.8690177564079877, 0.6413882557335685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 337}], {
             RGBColor[
             0.8892917898500812, 0.9140123919924417, 0.970276843283211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 376}], {
             RGBColor[
             0.5538916735521564, 0.639355835105775, 0.9612276966528428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 391}], {
             RGBColor[
             0.8209192855845969, 0.5085618177919978, 0.5749280813219132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 397}], {
             RGBColor[
             0.5928919663607762, 0.6752224028696671, 0.9636363647773936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 93}], {
             RGBColor[
             0.45767335020652483`, 0.5675906819706489, 0.951280040300782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 131}], {
             RGBColor[
             0.693464422361174, 0.75939366397809, 0.9708100489116116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 142}], {
             RGBColor[
             0.5234887787089056, 0.6240307993134462, 0.955630100743997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 188}], {
             RGBColor[
             0.42431357927468827`, 0.535650894850094, 0.9492658859927827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 201}], {
             RGBColor[
             0.6192660008437627, 0.7014292931597987, 0.9634146436784279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 273}], {
             RGBColor[
             0.5484319039049934, 0.644280752022615, 0.9575937149291112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 281}], {
             RGBColor[
             0.4857845720433236, 0.5919392094145923, 0.9530712624984452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 293}], {
             RGBColor[
             0.44347384418172964`, 0.5552917835398956, 0.950375260333012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 394}], {
             RGBColor[
             0.46522152575946735`, 0.5741285322522734, 0.9517610033724258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 90}], {
             RGBColor[
             0.2062666965089075, 0.33412975446773896`, 0.9350579552707259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 95}], {
             RGBColor[
             0.22209777558797966`, 0.3507692223282312, 0.9359595118042963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 177}], {
             RGBColor[
             0.1891804395703839, 0.31617101509409057`, 0.9340849182149289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 228}], {
             RGBColor[
             0.21048617188066365`, 0.3385646906136451, 0.9352982481509928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 246}], {
             RGBColor[
             0.2068329817370454, 0.33472495614706915`, 0.9350902043767244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 260}], {
             RGBColor[
             0.19294770058427305`, 0.3201306452778321, 0.9342994581565066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 285}], {
             RGBColor[
             0.1906202345698193, 0.31768433092677273`, 0.9341669124101608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 110}], {
             RGBColor[
             0.9113332721380322, 0.9312595378862136, 0.9610025753124077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 131}], {
             RGBColor[
             0.8919073913712897, 0.9158173378862382, 0.9591371203789343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 201}], {
             RGBColor[
             0.8177089698538784, 0.8578529670679469, 0.9517417151457506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 212}], {
             RGBColor[
             0.7737416965530766, 0.822516123696677, 0.9480358411696325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 271}], {
             RGBColor[
             0.8948533141221586, 0.565840640212504, 0.5514777902284453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 273}], {
             RGBColor[
             0.7468748729151091, 0.8007044259307632, 0.9459207863964338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 287}], {
             RGBColor[
             0.8935114377259239, 0.5555263902170573, 0.5501928078759782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 289}], {
             RGBColor[
             0.7219591346417744, 0.780476707159252, 0.9439593282102003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 292}], {
             RGBColor[
             0.8945978800262582, 0.5638772618194792, 0.5512331862497395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 303}], {
             RGBColor[
             0.9318169667814895, 0.7940843861143203, 0.5846862975193713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 385}], {
             RGBColor[
             0.9820607295061435, 0.9836969405379016, 0.7849671104328407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 400}], {
             RGBColor[
             0.8959095468804387, 0.5739593080367903, 0.5524892399106185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 86}], {
             RGBColor[
             0.3668179912534385, 0.4880512045533021, 0.9448235654131886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 108}], {
             RGBColor[
             0.3859501572545172, 0.5081603240698226, 0.9459131139634468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 236}], {
             RGBColor[
             0.4875863338308316, 0.5948835771747154, 0.9528037287682061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 262}], {
             RGBColor[
             0.4149349676293397, 0.5334857796550911, 0.9477519352990894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 284}], {
             RGBColor[
             0.602700789657427, 0.6868450128545692, 0.9628871876056561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 297}], {
             RGBColor[
             0.3810483803734705, 0.5030082457772378, 0.9456339650216002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 325}], {
             RGBColor[
             0.35190435537579295`, 0.4723760276667679, 0.9439742559127038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 333}], {
             RGBColor[
             0.7096566263019076, 0.7710149507769987, 0.9570981774601166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 337}], {
             RGBColor[
             0.7112579708229148, 0.7722092308988048, 0.9543875188835923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 376}], {
             RGBColor[
             0.3758578545249899, 0.4975526740121381, 0.9453383722532241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 397}], {
             RGBColor[
             0.4148581473336097, 0.5334192417760302, 0.947747040377775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.21536881746289013`, 0.3436966606981754, 0.9355763075936738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 162}], {
             RGBColor[
             0.19690433907813965`, 0.3242893232002557, 0.9345247828654102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 183}], {
             RGBColor[
             0.19359784833893534`, 0.3208139917897307, 0.9343364831093273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 189}], {
             RGBColor[
             0.2158427366159144, 0.3441947797762137, 0.9356032965883381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 207}], {
             RGBColor[
             0.1950145063297256, 0.32230298915935574`, 0.934417159686145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 280}], {
             RGBColor[
             0.2037203723071403, 0.3314534062854026, 0.9349129458743843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 291}], {
             RGBColor[
             0.19698615809912115`, 0.32437532017893284`, 0.9345294423376147]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 336}], {
             RGBColor[
             0.2166564041388005, 0.3450499959322676, 0.9356496337500533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 368}], {
             RGBColor[
             0.19117243294824504`, 0.31826472643389747`, 0.934198359290908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 387}], {
             RGBColor[
             0.19202691052884113`, 0.31916283654811173`, 0.9342470205250366]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 116}], {
             RGBColor[
             0.244277527259818, 0.37408154761281204`, 0.9372226158500052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 118}], {
             RGBColor[
             0.3029906205258713, 0.4312899550504897, 0.9407311083477143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 141}], {
             RGBColor[
             0.3021503369999872, 0.43056214369424695`, 0.9406775662244785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 179}], {
             RGBColor[
             0.23767352171657924`, 0.3671403190687327, 0.9368465275040685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 209}], {
             RGBColor[
             0.2567896978925637, 0.3872326322652657, 0.9379351654574425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 286}], {
             RGBColor[
             0.28488862903471124`, 0.4156109198533938, 0.9395776654568602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 290}], {
             RGBColor[
             0.2530317916874394, 0.3832828345786652, 0.9377211582583846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 304}], {
             RGBColor[
             0.2654021800822186, 0.39628489710950293`, 0.9384256335771177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 338}], {
             RGBColor[
             0.22933498443170014`, 0.35837598768852497`, 0.9363716601414551]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 386}], {
             RGBColor[
             0.29523037248077955`, 0.42456841823523894`, 0.9402366322043989]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 126}], {
             RGBColor[
             0.18223452639463555`, 0.3088704199500476, 0.9336893587351277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 133}], {
             RGBColor[
             0.18265733709091148`, 0.3093148207995801, 0.9337134371787883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 178}], {
             RGBColor[
             0.18245868691760933`, 0.30910602687229105`, 0.9337021243452953]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 200}], {
             RGBColor[
             0.1879784206462758, 0.3149076169924513, 0.9340164650154286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 296}], {
             RGBColor[
             0.18049305546872535`, 0.30704002359128196`, 0.9335901845421726]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 320}], {
             RGBColor[
             0.18280885155031829`, 0.3094740721029882, 0.933722065703106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 330}], {
             RGBColor[
             0.18530504232011252`, 0.31209772686967785`, 0.9338642200746624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 347}], {
             RGBColor[
             0.18311704522785527`, 0.30979800319868733`, 0.9337396168771099]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 398}], {
             RGBColor[
             0.18135843161484838`, 0.30794958878887396`, 0.9336394664334849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 78}], {
             RGBColor[
             0.2517003601981642, 0.38188341566580475`, 0.9376453352047469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 80}], {
             RGBColor[
             0.24302079240522623`, 0.37276063959904404`, 0.9371510466592089]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.24728213971667218`, 0.37723958580839845`, 0.9373937240844974]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 117}], {
             RGBColor[
             0.4207333030341396, 0.5335965741048728, 0.9489064510842957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.2623813144884871, 0.39310977583655005`, 0.9382535997505249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 187}], {
             RGBColor[
             0.24964108184106412`, 0.37971898354670364`, 0.9375280623487394]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 208}], {
             RGBColor[
             0.28867650153937047`, 0.420747684638181, 0.9397510717528295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 239}], {
             RGBColor[
             0.3950361568987507, 0.5127344732289232, 0.94688347760877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 269}], {
             RGBColor[
             0.3181691701834686, 0.44761747327725976`, 0.9415818139795731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 323}], {
             RGBColor[
             0.3517784337991403, 0.4767281281704481, 0.9437233665376588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 365}], {
             RGBColor[
             0.2944759917270998, 0.42684331653440033`, 0.9400813441394438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 377}], {
             RGBColor[
             0.2688145572376063, 0.39987152185702324`, 0.9386199634079575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 388}], {
             RGBColor[
             0.276858244918402, 0.40832594760879465`, 0.9390780395218092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 395}], {
             RGBColor[
             0.36080793914227827`, 0.4845490318625397, 0.9442987186336453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 78}], {
             RGBColor[
             0.20870891214169546`, 0.33669667794321373`, 0.9351970358380788]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 80}], {
             RGBColor[
             0.20002934434875747`, 0.3275739018764531, 0.9347027472925409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 96}], {
             RGBColor[
             0.20429069166020342`, 0.3320528480858075, 0.9349454247178293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 182}], {
             RGBColor[
             0.21938986643201835`, 0.34792303811395897`, 0.9358053003838569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 187}], {
             RGBColor[
             0.2066496337845954, 0.33453224582411256`, 0.9350797629820713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 244}], {
             RGBColor[
             0.18965577385650711`, 0.31667062156674053`, 0.9341119877993296]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 302}], {
             RGBColor[
             0.19582677060371215`, 0.3231567304118451, 0.9344634169349113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 377}], {
             RGBColor[
             0.22582310918113752`, 0.35468478413443216`, 0.9361716640412894]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 388}], {
             RGBColor[
             0.23386679686193323`, 0.36313920988620363`, 0.9366297401551412]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 80}], {
             RGBColor[
             0.21178615052788774`, 0.3399310505952844, 0.9353722800118063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 96}], {
             RGBColor[
             0.2160474978393337, 0.3444099968046388, 0.9356149574370947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 104}], {
             RGBColor[
             0.22225745398096258`, 0.35093705444345114`, 0.9359686052525535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 182}], {
             RGBColor[
             0.23114667261114863`, 0.3602801868327903, 0.9364748331031223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 187}], {
             RGBColor[
             0.21840643996372563`, 0.3468893945429439, 0.9357492957013367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 208}], {
             RGBColor[
             0.257441859662032, 0.38791809563442126`, 0.9379723051054267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 302}], {
             RGBColor[
             0.2075835767828424, 0.33551387913067643`, 0.9351329496541767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 377}], {
             RGBColor[
             0.2375799153602678, 0.3670419328532635, 0.9368411967605548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 388}], {
             RGBColor[
             0.2456236030410635, 0.37549635860503494`, 0.9372992728744065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 87}], {
             RGBColor[
             0.19294989757058154`, 0.3201329544497393, 0.9342995832716268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 126}], {
             RGBColor[
             0.19080527822884924`, 0.31787882354485875`, 0.9341774503727951]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 176}], {
             RGBColor[
             0.19262785863960308`, 0.31979447111483345`, 0.9342812436309215]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 205}], {
             RGBColor[
             0.19210249208707042`, 0.3192422775579583, 0.9342513247829649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 232}], {
             RGBColor[
             0.19470557204870292`, 0.32197827964243614`, 0.9343995663358682]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[
             0.19208286823872933`, 0.31922165164912797`, 0.9342502072338328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 298}], {
             RGBColor[
             0.20225845525357178`, 0.3299168387712073, 0.934829691860896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 373}], {
             RGBColor[
             0.19851817498261992`, 0.32598556705897075`, 0.9346166884327141]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 390}], {
             RGBColor[
             0.2060170491676479, 0.3338673592835195, 0.9350437382239613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 96}], {
             RGBColor[
             0.2073679300463957, 0.3352872207378781, 0.9351206688915568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 104}], {
             RGBColor[
             0.2135778861880246, 0.34181427837669043`, 0.9354743167070156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 182}], {
             RGBColor[
             0.22246710481821064`, 0.35115741076602963`, 0.9359805445575843]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 187}], {
             RGBColor[
             0.20972687217078761`, 0.3377666184761832, 0.9352550071557988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 244}], {
             RGBColor[
             0.1927330122426994, 0.31990499421881113`, 0.9342872319730569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 302}], {
             RGBColor[
             0.1989040089899044, 0.3263911030639157, 0.9346386611086387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 377}], {
             RGBColor[
             0.2289003475673298, 0.3579191567865028, 0.9363469082150169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 388}], {
             RGBColor[
             0.23694403524812552`, 0.36637358253827423`, 0.9368049843288686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 119}], {
             RGBColor[
             0.2344729010553813, 0.363776263822743, 0.9366642568923073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 128}], {
             RGBColor[
             0.2665289573662383, 0.3974692114768138, 0.9384898018765251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.2224096961469096, 0.35109707061257234`, 0.9359772752186821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 135}], {
             RGBColor[
             0.2822556151095555, 0.41153871876028536`, 0.9394754920042432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 146}], {
             RGBColor[
             0.2141426413323014, 0.3424078718408697, 0.9355064786770019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 166}], {
             RGBColor[
             0.2371652059079643, 0.3666060469247946, 0.9368175796707537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 227}], {
             RGBColor[
             0.2515739104642789, 0.38175050897811513`, 0.9376381340794677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 243}], {
             RGBColor[
             0.2302749655066254, 0.3593639673965138, 0.9364251906730947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[
             0.21336000502701669`, 0.3415852714620077, 0.9354619086972226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 275}], {
             RGBColor[
             0.21165010291327152`, 0.33978805592640576`, 0.9353645323014182]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 311}], {
             RGBColor[
             0.21587607865268055`, 0.34422982437086214`, 0.9356051953680067]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 326}], {
             RGBColor[
             0.23536377630225702`, 0.36471263019196243`, 0.936714990919685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 344}], {
             RGBColor[
             0.2103592408268638, 0.3384312780282078, 0.9352910196152566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 346}], {
             RGBColor[
             0.21629108370638292`, 0.34466602099514354`, 0.9356288292918702]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 363}], {
             RGBColor[
             0.3018408929173706, 0.42850250201273, 0.940723448587576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 383}], {
             RGBColor[
             0.2937367673363199, 0.42148311575961905`, 0.9402070608717483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 172}], {
             RGBColor[
             0.5696909718954926, 0.6577404259092337, 0.9610497684809419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 194}], {
             RGBColor[
             0.6075992658363466, 0.6905170696190597, 0.963481170694517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 233}], {
             RGBColor[
             0.865044812104987, 0.8948209835298624, 0.9558976637938235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 256}], {
             RGBColor[
             0.8760312800563814, 0.9016669835366705, 0.876948136427472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 257}], {
             RGBColor[
             0.8645894369328215, 0.89448136547207, 0.956668495179433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 310}], {
             RGBColor[
             0.7931376486603983, 0.5085364648564028, 0.5748575062936936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 316}], {
             RGBColor[
             0.7359499332008539, 0.7936489483339444, 0.9743162695644639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 399}], {
             RGBColor[
             0.5595672102027384, 0.6489717323660277, 0.9604046913379707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 118}], {
             RGBColor[
             0.6542161598297946, 0.7234949587303476, 0.9559255584190995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 123}], {
             RGBColor[
             0.8970713714097568, 0.6478503290469954, 0.5784075917525047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 141}], {
             RGBColor[
             0.6533758763039106, 0.7227671473741049, 0.9558720162958637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 161}], {
             RGBColor[
             0.9152656356126947, 0.754447556797873, 0.5945283802670174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 196}], {
             RGBColor[
             0.8975547667711833, 0.9207556417701627, 0.9764242298319501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 214}], {
             RGBColor[
             0.9149531561640245, 0.7530286606028909, 0.5942676397554747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 286}], {
             RGBColor[
             0.6361141683386347, 0.7078159235332517, 0.9547721155282454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 332}], {
             RGBColor[
             0.8843949242801739, 0.5504136015544692, 0.5662686116652167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 334}], {
             RGBColor[
             0.9555982588691752, 0.9202058525384339, 0.6338919338224923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 366}], {
             RGBColor[
             0.9721424943326117, 0.9755215245830015, 0.7399924007909114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 125}], {
             RGBColor[
             0.20344264397852102`, 0.33116149620303065`, 0.9348971296569317]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 184}], {
             RGBColor[
             0.21392003441563898`, 0.34217389785736374`, 0.9354938015424155]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 185}], {
             RGBColor[
             0.20341836522778634`, 0.3311359776966468, 0.9348957470179945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 190}], {
             RGBColor[
             0.21321988075352158`, 0.3414379919661722, 0.9354539288271424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 252}], {
             RGBColor[
             0.2101141940866254, 0.33817371836735655`, 0.9352770645659143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 270}], {
             RGBColor[
             0.21111604747539212`, 0.339226729800124, 0.9353341186342953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 274}], {
             RGBColor[
             0.20871345876417752`, 0.33670145673171487`, 0.935197294761503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 288}], {
             RGBColor[
             0.21401051896422651`, 0.342269002854981, 0.9354989545035975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 318}], {
             RGBColor[
             0.2138717930117836, 0.3421231930832301, 0.9354910542658326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 168}], {
             RGBColor[
             0.18992658867508105`, 0.3169552651117129, 0.9341274103026127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 238}], {
             RGBColor[
             0.19138550303315327`, 0.3184886766025597, 0.9342104933170345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 379}], {
             RGBColor[
             0.18217848519657132`, 0.30881151709766497`, 0.9336861672718034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 236}], {
             RGBColor[
             0.3888676051713017, 0.5059520744556105, 0.9465593917911999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 262}], {
             RGBColor[
             0.31621623896980977`, 0.44455427693598626`, 0.9415075983220833]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 265}], {
             RGBColor[
             0.23354789403514828`, 0.36280402279564555`, 0.9366115791109302]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 297}], {
             RGBColor[
             0.28232965171394053`, 0.4140767430581329, 0.9393896280445941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 325}], {
             RGBColor[
             0.25318562671626305`, 0.38344452494766296`, 0.9377299189356977]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 376}], {
             RGBColor[
             0.2771391258654599, 0.4086211712930332, 0.939094035276218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 397}], {
             RGBColor[
             0.3161394186740798, 0.4444877390569253, 0.9415027034007689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 176}], {
             RGBColor[
             0.18652655830038561`, 0.3133816176135313, 0.933933783602668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 205}], {
             RGBColor[
             0.18600119174785296`, 0.31282942405665615`, 0.9339038647547113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 232}], {
             RGBColor[
             0.18860427170948546`, 0.315565426141134, 0.9340521063076146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 277}], {
             RGBColor[
             0.18598156789951187`, 0.3128087981478258, 0.9339027472055792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 373}], {
             RGBColor[
             0.19241687464340246`, 0.3195727135576686, 0.9342692284044607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 390}], {
             RGBColor[
             0.19991574882843044`, 0.32745450578221735`, 0.9346962781957078]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 89}], {
             RGBColor[
             0.33131087657095276`, 0.4543117529947025, 0.9425908573941362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 120}], {
             RGBColor[
             0.42147179727410705`, 0.5394794198355211, 0.9480767881227974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 140}], {
             RGBColor[
             0.41837127081473313`, 0.5367938996534025, 0.947879225318494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 189}], {
             RGBColor[
             0.331784795723977, 0.4548098720727408, 0.9426178463888004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 195}], {
             RGBColor[
             0.42750707901937735`, 0.5447068775411936, 0.948461350938816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 233}], {
             RGBColor[
             0.7003634497191511, 0.7623012578281982, 0.9418757273882692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 255}], {
             RGBColor[
             0.40229233650521606`, 0.5228671349052352, 0.9468546898423349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 257}], {
             RGBColor[
             0.6999080745469857, 0.7619616397704058, 0.9426465587738788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 263}], {
             RGBColor[
             0.3661139704738488, 0.49089201133024934`, 0.9445728421053426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 336}], {
             RGBColor[
             0.33259846324686315`, 0.4556650882287947, 0.9426641835505155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 356}], {
             RGBColor[
             0.6878897223994248, 0.7529983724170004, 0.962990494071441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 359}], {
             RGBColor[
             0.3780427703410259, 0.5018633795124479, 0.9453095289294022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 360}], {
             RGBColor[
             0.5465756968337885, 0.6418389618053506, 0.9578331782484879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 389}], {
             RGBColor[
             0.7117595806289345, 0.7674543626326005, 0.720767374949669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 162}], {
             RGBColor[
             0.2137613905296329, 0.342007153074568, 0.9354847670077999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 183}], {
             RGBColor[
             0.21045489979042858`, 0.338531821664043, 0.935296467251717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 189}], {
             RGBColor[
             0.23269978806740765`, 0.361912609650526, 0.9365632807307278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 263}], {
             RGBColor[
             0.2670289628172794, 0.39799474890803455`, 0.93851827644727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 270}], {
             RGBColor[
             0.22008543635339983`, 0.34865412620301106`, 0.935844912061876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.22057742375863354`, 0.3491712361597149, 0.935872930016774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 291}], {
             RGBColor[
             0.2138432095506144, 0.34209315005324514`, 0.9354894264800044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 336}], {
             RGBColor[
             0.23351345559029374`, 0.36276782580657996`, 0.9366096178924429]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 359}], {
             RGBColor[
             0.2789577626844565, 0.40896611709023306`, 0.9392549632713296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 95}], {
             RGBColor[
             0.23140010342565426`, 0.3605465586872775, 0.936489265613091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 97}], {
             RGBColor[
             0.2570968896215246, 0.3875555102494842, 0.9379526595719574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.23037172884023532`, 0.35946567179528754`, 0.9364307012017953]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 228}], {
             RGBColor[
             0.21978849971833822`, 0.34834202697269134`, 0.9358280019597877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 246}], {
             RGBColor[
             0.21613530957472, 0.3445022925061154, 0.9356199581855191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 260}], {
             RGBColor[
             0.20225002842194761`, 0.32990798163687834`, 0.9348292119653014]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 326}], {
             RGBColor[
             0.22857029923452804`, 0.35757225506245527`, 0.9363281124507266]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 172}], {
             RGBColor[
             0.48609962486048197`, 0.5916756169176496, 0.9532395671401708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 192}], {
             RGBColor[
             0.4254211791359827, 0.5344518171008017, 0.9495440785539795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 208}], {
             RGBColor[
             0.4434969579662055, 0.5534506067219376, 0.9505734674176423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 221}], {
             RGBColor[
             0.48124384050183955`, 0.5874697805650118, 0.9529301608546397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 256}], {
             RGBColor[
             0.792439933021371, 0.8356021745450866, 0.869137935086701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 316}], {
             RGBColor[
             0.6523585861658432, 0.7275841393423603, 0.9665060682236928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 351}], {
             RGBColor[
             0.45106536887988224`, 0.5613307052601594, 0.9510072153286632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 395}], {
             RGBColor[
             0.5156283955691132, 0.6172519539462964, 0.9551211142984581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 399}], {
             RGBColor[
             0.4759758631677278, 0.5829069233744436, 0.9525944899971995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 98}], {
             RGBColor[
             0.19880960071600262`, 0.32629187398221465`, 0.9346332846971046]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 119}], {
             RGBColor[
             0.22208012665594387`, 0.3507506721816547, 0.9359585067237262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 130}], {
             RGBColor[
             0.2100169217474722, 0.33807147897148404`, 0.935271525050101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 143}], {
             RGBColor[
             0.20163694443753327`, 0.3292635914974891, 0.9347942977393655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 146}], {
             RGBColor[
             0.20174986693286398`, 0.32938228019978144`, 0.9348007285084208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 151}], {
             RGBColor[
             0.20599136961110498`, 0.33384036844141496`, 0.9350422758112056]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 158}], {
             RGBColor[
             0.19775538870657966`, 0.32518383031940923`, 0.9345732488827347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 186}], {
             RGBColor[
             0.20547576839988674`, 0.33329843887741967`, 0.9350129130849905]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 267}], {
             RGBColor[
             0.20096723062757926`, 0.3285596798209194, 0.9347561585286415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 306}], {
             RGBColor[
             0.21333519209183469`, 0.34155919149390046`, 0.9354604956372714]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 308}], {
             RGBColor[
             0.20860909712508957`, 0.3365917660321234, 0.9351913515205462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 346}], {
             RGBColor[
             0.2038983093069455, 0.33164042935405524`, 0.934923079123289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 348}], {
             RGBColor[
             0.2027372639690243, 0.3304200970893739, 0.9348569593089071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 354}], {
             RGBColor[
             0.20023581918524017`, 0.32779092002085713`, 0.9347145057290265]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 374}], {
             RGBColor[
             0.1940034937220554, 0.32124035080679264`, 0.9343595840137974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 131}], {
             RGBColor[
             0.5783198351360825, 0.6629059133309206, 0.9625766163950823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 142}], {
             RGBColor[
             0.4083441914838143, 0.5275430486662767, 0.9473966682274677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 188}], {
             RGBColor[
             0.3091689920495968, 0.43916314420292457`, 0.9410324534762535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 201}], {
             RGBColor[
             0.5041214136186714, 0.6049415425126292, 0.9551812111618987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 264}], {
             RGBColor[
             0.3012538452175734, 0.43084382303317337`, 0.9405816975735801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 273}], {
             RGBColor[
             0.433287316679902, 0.5477930013754455, 0.949360282412582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 281}], {
             RGBColor[
             0.3706399848182322, 0.4954514587674228, 0.944837829981916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 293}], {
             RGBColor[
             0.3283292569566383, 0.4588040328927261, 0.9421418278164828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 394}], {
             RGBColor[
             0.35007693853437594`, 0.4776407816051039, 0.9435275708558966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 204}], {
             RGBColor[
             0.1795232819748228, 0.3060207301619996, 0.9335349573763461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.18066543438157506`, 0.30722120475814135`, 0.9336000012662475]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 307}], {
             RGBColor[
             0.17906784709075121`, 0.30554203922260087`, 0.9335090210334537]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 324}], {
             RGBColor[
             0.18239675869616345`, 0.30904093638507546`, 0.9336985976246985]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 97}], {
             RGBColor[
             0.27292796870059677`, 0.4041949781099764, 0.9388542161055278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 148}], {
             RGBColor[
             0.2518920934922597, 0.3820849395144922, 0.9376562541322015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 166}], {
             RGBColor[
             0.24620280791930751`, 0.37610513965577974`, 0.9373322577353658]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 169}], {
             RGBColor[
             0.3522449518778092, 0.4737241407933565, 0.9439035250794346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 228}], {
             RGBColor[
             0.2356195787974104, 0.36498149483318354`, 0.9367295584933581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 246}], {
             RGBColor[
             0.23196638865379215`, 0.3611417603666076, 0.9365215147190895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 276}], {
             RGBColor[
             0.3131382201938357, 0.4399588551912694, 0.9413821143478849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 282}], {
             RGBColor[
             0.2811273621289757, 0.41223265884799526`, 0.9393424107780823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 305}], {
             RGBColor[
             0.2726453120788769, 0.4038978880790839, 0.9388381192290738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 326}], {
             RGBColor[
             0.24440137831360023`, 0.3742117229229475, 0.9372296689842969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 361}], {
             RGBColor[
             0.32840262007179855`, 0.45318011115451534`, 0.9423547484103298]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 382}], {
             RGBColor[
             0.2846635750266093, 0.4152955487246973, 0.9395677351369693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 104}], {
             RGBColor[
             0.21783923349947054`, 0.34629322458604483`, 0.935716994132304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 182}], {
             RGBColor[
             0.2267284521296566, 0.35563635697538404`, 0.9362232219828728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 187}], {
             RGBColor[
             0.2139882194822336, 0.34224556468553763`, 0.9354976845810872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 208}], {
             RGBColor[
             0.25302363918053994`, 0.383274265777015, 0.9377206939851772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 225}], {
             RGBColor[
             0.21005566506834547`, 0.33811220065819025`, 0.9352737314249091]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 261}], {
             RGBColor[
             0.20041641876701294`, 0.3279807416319751, 0.9347247906080353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 377}], {
             RGBColor[
             0.23316169487877575`, 0.36239810299585723`, 0.9365895856403053]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 388}], {
             RGBColor[
             0.24120538255957147`, 0.37085252874762864`, 0.937047661754157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 166}], {
             RGBColor[
             0.27189959411517783`, 0.40311409121798647`, 0.9387956516942321]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 169}], {
             RGBColor[
             0.37794173807367953`, 0.5007330923555633, 0.945366919038301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 224}], {
             RGBColor[
             0.3981861519254275, 0.5171684195208632, 0.946960633454442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 246}], {
             RGBColor[
             0.2576631748496625, 0.38815071192881434`, 0.9379849086779559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 276}], {
             RGBColor[
             0.33883500638970604`, 0.46696780675347616`, 0.9428455083067513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 326}], {
             RGBColor[
             0.27009816450947055`, 0.40122067448515425`, 0.9386930629431633]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 363}], {
             RGBColor[
             0.3365752811245841, 0.4650105463059218, 0.9427015206110543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 382}], {
             RGBColor[
             0.3103603612224796, 0.44230450028690405`, 0.9410311290958356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 383}], {
             RGBColor[
             0.32847115554353346`, 0.45799116005281093`, 0.9421851328952267]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 393}], {
             RGBColor[
             0.5102982570407728, 0.6069665111134733, 0.9566203329382144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 134}], {
             RGBColor[
             0.1861818864522268, 0.313019345647659, 0.9339141550508117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 143}], {
             RGBColor[
             0.19607611547037074`, 0.3234188076760809, 0.9344776167561948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 151}], {
             RGBColor[
             0.20043054064394245`, 0.3279955846200067, 0.934725594828035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 158}], {
             RGBColor[
             0.19219455973941713`, 0.31933904649800093`, 0.9342565678995641]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 163}], {
             RGBColor[
             0.18615149755953203`, 0.3129874049946697, 0.933912424448329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.1906510637312114, 0.3177167343300775, 0.9341686680852945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 186}], {
             RGBColor[
             0.1999149394327242, 0.32745365505601143`, 0.9346962321018197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 240}], {
             RGBColor[
             0.18629079266231832`, 0.3131338129795177, 0.9339203570983641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 272}], {
             RGBColor[
             0.1949500622314218, 0.3222352543260466, 0.9344134896900831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 306}], {
             RGBColor[
             0.20777436312467215`, 0.33571440767249217`, 0.9351438146541007]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 308}], {
             RGBColor[
             0.20304826815792704`, 0.3307469822107151, 0.9348746705373756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 342}], {
             RGBColor[
             0.1898214409282245, 0.31684474816301444`, 0.9341214222939813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 348}], {
             RGBColor[
             0.19717643500186177`, 0.3245753132679656, 0.9345402783257364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 354}], {
             RGBColor[
             0.19467499021807763`, 0.3219461361994489, 0.9343978247458558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 374}], {
             RGBColor[
             0.18844266475489285`, 0.3153955669853844, 0.9340429030306268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 378}], {
             RGBColor[
             0.21674290293340537`, 0.34514091164973765`, 0.9356545597284425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 144}], {
             RGBColor[
             0.7417116613175341, 0.797878300210745, 0.9753542230915366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 169}], {
             RGBColor[
             0.6797124063510102, 0.7475445119943138, 0.9704734146298177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[
             0.7312212189545854, 0.7893616865114603, 0.9745283770409688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 222}], {
             RGBColor[
             0.9266267914902193, 0.9439342403679507, 0.9791054495248444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 223}], {
             RGBColor[
             0.8806912086429535, 0.689221405037725, 0.5973847957056915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 276}], {
             RGBColor[
             0.6406056746670367, 0.7137792263922267, 0.9679520038982681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 361}], {
             RGBColor[
             0.6558700745449995, 0.7270004823554725, 0.968924637960713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 382}], {
             RGBColor[
             0.6121310294998102, 0.6891159199256546, 0.9661376246873524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 384}], {
             RGBColor[
             0.9178754148881313, 0.8496097092612407, 0.6279747633092586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 393}], {
             RGBColor[
             0.8120689253181035, 0.8537779307522239, 0.9817268285297311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 157}], {
             RGBColor[
             0.31728677632069113`, 0.4435179334056334, 0.9416477086340886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 167}], {
             RGBColor[
             0.3117593370391954, 0.4377082442608893, 0.941332929144121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 174}], {
             RGBColor[
             0.4027739307357637, 0.5232842676221057, 0.9468853766008484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 198}], {
             RGBColor[
             0.6082548805926754, 0.6882816237042615, 0.9647291510065205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 203}], {
             RGBColor[
             0.3488608742001085, 0.47658748779993204`, 0.9434500843118405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 206}], {
             RGBColor[
             0.40830029738828666`, 0.5280709286532568, 0.947237511797173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 211}], {
             RGBColor[
             0.31010062158634694`, 0.43596482915131163`, 0.941238467752931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 266}], {
             RGBColor[
             0.5229669528809726, 0.6215828095678126, 0.9562473514884939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 341}], {
             RGBColor[
             0.3185278490681524, 0.4448223795517722, 0.9417183858910539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 358}], {
             RGBColor[
             0.33265464447686266`, 0.4596705372168882, 0.942522885990859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 115}], {
             RGBColor[
             0.9045408089975616, 0.6377980714511916, 0.24102778506069641`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 123}], {
             RGBColor[
             0.8485657793755872, 0.374303438706794, 0.1941399512182521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 161}], {
             RGBColor[
             0.8667600435785252, 0.4809006664576717, 0.21026073973276477`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 193}], {
             RGBColor[
             0.8459509404020927, 0.6447383034706259, 0.5918610769410064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 253}], {
             RGBColor[
             0.8395830715203696, 0.3052584098839103, 0.18553810003157822`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 283}], {
             RGBColor[
             0.8929481444706848, 0.5918370196285758, 0.23170005506756156`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 332}], {
             RGBColor[
             0.8358893322460044, 0.27686671121426787`, 0.18200097113096422`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 334}], {
             RGBColor[
             0.9070926668350056, 0.6466589621982325, 0.24962429328823976`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 356}], {
             RGBColor[
             0.8996786533554004, 0.687329585228627, 0.5883270956947237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 364}], {
             RGBColor[
             0.8876560448428017, 0.5708556080916793, 0.22744190748542303`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 366}], {
             RGBColor[
             0.9236369022984421, 0.7019746342428002, 0.3557247602566589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 380}], {
             RGBColor[
             0.787177962650946, 0.5986793707999881, 0.5860416238148101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 389}], {
             RGBColor[
             0.9235485115849101, 0.701785575444227, 0.3461039765729519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 108}], {
             RGBColor[
             0.3276991764172302, 0.45803801914073383`, 0.9421097447928497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 139}], {
             RGBColor[
             0.3279891561400408, 0.4583428062151842, 0.9421262587090772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 213}], {
             RGBColor[
             0.33722405994131943`, 0.4665082641722599, 0.9427085967973012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 297}], {
             RGBColor[
             0.32279739953618347`, 0.45288594084814915`, 0.9418305958510031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 333}], {
             RGBColor[
             0.6514056454646207, 0.7208926458479099, 0.9532948082895194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 337}], {
             RGBColor[
             0.6530069899856277, 0.722086925969716, 0.9505841497129952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 345}], {
             RGBColor[
             0.5885592438891699, 0.6712468009440402, 0.9634628617416172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 350}], {
             RGBColor[
             0.3487900132261258, 0.4765261115858444, 0.9434455691132382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 378}], {
             RGBColor[
             0.29463589617818253`, 0.42328641527644917`, 0.9402268398959757]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 122}], {
             RGBColor[
             0.1920779072643653, 0.3192164373505274, 0.9342499247136817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 295}], {
             RGBColor[
             0.1903453971129866, 0.3173954593339403, 0.9341512608235798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 145}], {
             RGBColor[
             0.2369611402467977, 0.36639156097639836`, 0.9368059584332384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 170}], {
             RGBColor[
             0.22977658578143667`, 0.35884013870624076`, 0.936396808685032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 182}], {
             RGBColor[
             0.23293840827128548`, 0.36216341461419643`, 0.9365768697983317]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 187}], {
             RGBColor[
             0.2201981756238625, 0.34877262232435, 0.935851332396546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 192}], {
             RGBColor[
             0.24115781649194606`, 0.3708025337946915, 0.9370449529369735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 208}], {
             RGBColor[
             0.25923359532216883`, 0.3898013234158274, 0.9380743418006362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 225}], {
             RGBColor[
             0.2162656212099744, 0.3446392582970026, 0.935627379240368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 235}], {
             RGBColor[
             0.20864915250350596`, 0.3366338667744967, 0.9351936326150905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 261}], {
             RGBColor[
             0.20662637490864183`, 0.3345077992707875, 0.9350784384234943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 327}], {
             RGBColor[
             0.20490625211316982`, 0.332699841150662, 0.9349804799749857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 335}], {
             RGBColor[
             0.21115674634682685`, 0.33926950689445945`, 0.9353364363748149]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 349}], {
             RGBColor[
             0.21123195753513827`, 0.3393485586220395, 0.9353407195407242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 351}], {
             RGBColor[
             0.26680200623584566`, 0.3976814219540492, 0.9385080897116571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 355}], {
             RGBColor[
             0.21609483282429037`, 0.34445974887503966`, 0.9356176530944622]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 199}], {
             RGBColor[
             0.9870190215241651, 0.9889000460513815, 0.8647919372474027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 215}], {
             RGBColor[
             0.8456866310237973, 0.8792487049970009, 0.932290412064394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 259}], {
             RGBColor[
             0.9403634558512834, 0.9538207185775788, 0.9415651020124101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 271}], {
             RGBColor[
             0.9026525217316504, 0.5714728168582255, 0.530015287474555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 287}], {
             RGBColor[
             0.9013106453354156, 0.5611585668627788, 0.528730305122088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 303}], {
             RGBColor[
             0.9396161743909813, 0.7997165627600418, 0.5632237947654809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 333}], {
             RGBColor[
             0.969539411680839, 0.9766186640035739, 0.9281855313871071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 337}], {
             RGBColor[
             0.9711407562018461, 0.97781294412538, 0.9254748728105828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 345}], {
             RGBColor[
             0.9066930101053883, 0.9269728190997042, 0.9383535848392048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 350}], {
             RGBColor[
             0.6669237794423443, 0.7322521297415084, 0.9183362922108259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 353}], {
             RGBColor[
             0.9892810453920724, 0.988090926321853, 0.7004958160747115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 400}], {
             RGBColor[
             0.9037087544899305, 0.5795914846825118, 0.5310267371567282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 197}], {
             RGBColor[
             0.18891531916432497`, 0.315892356737718, 0.9340698200000144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 217}], {
             RGBColor[
             0.1973830107710603, 0.32479243749905357`, 0.9345520425101908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 231}], {
             RGBColor[
             0.1888628748467801, 0.31583723443481654`, 0.9340668333737145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 254}], {
             RGBColor[
             0.18679837373704838`, 0.3136673128715579, 0.9339492630896711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 314}], {
             RGBColor[
             0.18463641563674799`, 0.3113949578320815, 0.9338261427741893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 369}], {
             RGBColor[
             0.18346224485360668`, 0.3101608298922725, 0.9337592754851194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 124}], {
             RGBColor[
             0.22484989821780513`, 0.3536618777068309, 0.9361162411166642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 150}], {
             RGBColor[
             0.23074389884075946`, 0.35985684606277935`, 0.936451895732749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 152}], {
             RGBColor[
             0.2119625047523057, 0.3401164100666513, 0.9353823231239942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.2124764155335251, 0.34065656288153834`, 0.9354115895827217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.2349712471793796, 0.36430005719603437`, 0.936692636966832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 160}], {
             RGBColor[
             0.20918830325598364`, 0.33720054839948277`, 0.935224336452842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 167}], {
             RGBColor[
             0.22944380789788385`, 0.3584903680512903, 0.9363778574768644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.2249471629490288, 0.3537641091062871, 0.9361217801992172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 181}], {
             RGBColor[
             0.20760170595158578`, 0.3355329340364814, 0.935133982083517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 211}], {
             RGBColor[
             0.2277850924450354, 0.3567469529417126, 0.9362833960856742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 238}], {
             RGBColor[
             0.21198166691675951`, 0.34013655071644366`, 0.9353834143809119]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 245}], {
             RGBColor[
             0.20898762068619692`, 0.33698961829462715`, 0.9352129078773759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 386}], {
             RGBColor[
             0.2825040137132291, 0.4111922082727934, 0.9395118848995476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 297}], {
             RGBColor[
             0.30146181771501923`, 0.43418586257465347`, 0.9404791765948524]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 325}], {
             RGBColor[
             0.2723177927173417, 0.4035536444641835, 0.9388194674859559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 376}], {
             RGBColor[
             0.29627129186653856`, 0.4287302908095537, 0.9401835838264763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 378}], {
             RGBColor[
             0.2733003143570183, 0.40458633700295354`, 0.938875420639825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 397}], {
             RGBColor[
             0.3352715846751584, 0.4645968585734458, 0.9425922519510271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 114}], {
             RGBColor[
             0.18471405231964982`, 0.3114765589082613, 0.9338305640684275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 132}], {
             RGBColor[
             0.1878121680467173, 0.3147328749692917, 0.9340069971758325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 180}], {
             RGBColor[
             0.18558731783868732`, 0.3123944163370016, 0.933880295247856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 232}], {
             RGBColor[
             0.18655512715268852`, 0.3134116452886715, 0.9339354105565427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 249}], {
             RGBColor[
             0.18318613987214505`, 0.3098706260506894, 0.9337435517148859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 370}], {
             RGBColor[
             0.18414849826566793`, 0.3108821257393283, 0.9337983566017154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 111}], {
             RGBColor[
             0.8397873767221564, 0.5455755079920095, 0.5794773016000505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 117}], {
             RGBColor[
             0.7057471364084966, 0.7690367194392469, 0.9721131675946504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 202}], {
             RGBColor[
             0.590277084299675, 0.6718791600205865, 0.9639661767270546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 212}], {
             RGBColor[
             0.715371093239261, 0.7768498811487758, 0.9728708007300837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 239}], {
             RGBColor[
             0.6800499902731076, 0.7481746185632971, 0.9700901941191247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 247}], {
             RGBColor[
             0.8351507068562677, 0.5099360316010974, 0.5750372213001058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 269}], {
             RGBColor[
             0.6031830035578256, 0.6830576186116337, 0.9647885304899277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 287}], {
             RGBColor[
             0.8351408344121083, 0.5098601476691562, 0.5750277674364295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 289}], {
             RGBColor[
             0.6635885313279589, 0.7348104646113509, 0.9687942877706517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 292}], {
             RGBColor[
             0.8362272767124428, 0.5182110192715781, 0.5760681458101908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 303}], {
             RGBColor[
             0.873446363467674, 0.7484181435664192, 0.6095212570798225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 309}], {
             RGBColor[
             0.7751646817101416, 0.8245503622153614, 0.9781540938970312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 362}], {
             RGBColor[
             0.8221167873663267, 0.8612297040031928, 0.982833840996466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 385}], {
             RGBColor[
             0.923690126192328, 0.9380306979900004, 0.809802069993292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 400}], {
             RGBColor[
             0.8375389435666232, 0.5282930654888892, 0.5773241994710698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 199}], {
             RGBColor[
             0.9076739184987976, 0.597583839511456, 0.5047291662889358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 222}], {
             RGBColor[
             0.8888497880747033, 0.5842997162159619, 0.5703986830647514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 223}], {
             RGBColor[
             0.8429142052274374, 0.3295868808857362, 0.18867802924559862`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 247}], {
             RGBColor[
             0.8219754147542075, 0.16991824425479435`, 0.1686769880272973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 271}], {
             RGBColor[
             0.823307418706283, 0.18015661031829988`, 0.16995251651608806`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 287}], {
             RGBColor[
             0.8219655423100481, 0.16984236032285321`, 0.168667534163621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 292}], {
             RGBColor[
             0.8230519846103825, 0.1781932319252751, 0.16970791253738232`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 309}], {
             RGBColor[
             0.7619893896080814, 0.48453257486905843`, 0.5717938606242228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 319}], {
             RGBColor[
             0.8295282339464709, 0.2279725222330049, 0.17590957621549802`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 362}], {
             RGBColor[
             0.8089414952642664, 0.5212119166568898, 0.5764736077236575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 385}], {
             RGBColor[
             0.9105148340902678, 0.5980129106436974, 0.4034418367204835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[
             0.8243636514645629, 0.1882752781425862, 0.17096396619826132`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 177}], {
             RGBColor[
             0.18091855533538903`, 0.3074872509293952, 0.9336144161301083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 219}], {
             RGBColor[
             0.17968380010062157`, 0.30618944488965105`, 0.933544098646145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 248}], {
             RGBColor[
             0.18167669359362687`, 0.3082841023075451, 0.9336575909823499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 251}], {
             RGBColor[
             0.18268323345773074`, 0.30934203952303163`, 0.9337149119385684]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 260}], {
             RGBColor[
             0.18468581634927816`, 0.3114468811131368, 0.9338289560716861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 162}], {
             RGBColor[
             0.19047273002269705`, 0.31752929429541876`, 0.9341585122444157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 183}], {
             RGBColor[
             0.18716623928349274`, 0.31405396288489373`, 0.9339702124883327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 270}], {
             RGBColor[
             0.196796775846464, 0.3241762674238618, 0.9345186572984918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 357}], {
             RGBColor[
             0.18582607626581804`, 0.31264536658207454`, 0.9338938921870696]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 368}], {
             RGBColor[
             0.18474082389280244`, 0.3115046975290605, 0.9338320886699134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 132}], {
             RGBColor[
             0.1897759122485969, 0.31679689463404087`, 0.9341188295030303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 155}], {
             RGBColor[
             0.18628873221551898`, 0.3131316473192917, 0.933920239758967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 180}], {
             RGBColor[
             0.18755106204056693`, 0.3144584360017507, 0.9339921275750538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 249}], {
             RGBColor[
             0.18514988407402466`, 0.3119346457154385, 0.9338553840420838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 268}], {
             RGBColor[
             0.18716896902427724`, 0.3140568320155338, 0.9339703679430321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 279}], {
             RGBColor[
             0.19285735565451845`, 0.32003568702846064`, 0.9342943131464105]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 299}], {
             RGBColor[
             0.1875337477163088, 0.31444023754916384`, 0.9339911415499016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 300}], {
             RGBColor[
             0.19141939910096473`, 0.3185243035189643, 0.9342124236479517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 370}], {
             RGBColor[
             0.18611224246754757`, 0.3129461454040774, 0.9339101889289132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 123}], {
             RGBColor[
             0.8991328422336753, 0.5962300691178152, 0.23584910998017405`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 161}], {
             RGBColor[
             0.9173271064366133, 0.7028272968686928, 0.25196989849468676`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 193}], {
             RGBColor[
             0.8965180032601808, 0.866664933881647, 0.6335702357029284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 195}], {
             RGBColor[
             0.6898630728334411, 0.7009647207638414, 0.6155071113240207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 214}], {
             RGBColor[
             0.917014626987943, 0.7014084006737106, 0.2517091579831441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 253}], {
             RGBColor[
             0.8901501343784577, 0.5271850402949314, 0.22724725879350022`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 257}], {
             RGBColor[
             0.9622640683610495, 0.9182194829930534, 0.6096923191590835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 283}], {
             RGBColor[
             0.9435152073287729, 0.813763650039597, 0.2734092138294835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 312}], {
             RGBColor[
             0.7514622050621471, 0.7517529361696669, 0.6201411074573389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 332}], {
             RGBColor[
             0.8864563951040925, 0.498793341625289, 0.2237101298928862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 334}], {
             RGBColor[
             0.9576597296930937, 0.8685855926092536, 0.2913334520501617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 356}], {
             RGBColor[
             0.9502457162134885, 0.9092562156396481, 0.6300362544566458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 360}], {
             RGBColor[
             0.8089316906478522, 0.7980968050279984, 0.6248789386336926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 364}], {
             RGBColor[
             0.9382231077008898, 0.7927822385027005, 0.26915106624734497`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 366}], {
             RGBColor[
             0.9742039651565302, 0.9239012646538212, 0.3974339190185809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 380}], {
             RGBColor[
             0.8377450255090341, 0.8206060012110092, 0.627750782576732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 389}], {
             RGBColor[
             0.9741155744429982, 0.9237122058552483, 0.3878131353348738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 141}], {
             RGBColor[
             0.29789401265983945`, 0.4260884769462017, 0.9404351748499746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 179}], {
             RGBColor[
             0.23341719737643146`, 0.3626666523206874, 0.9366041361295647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 209}], {
             RGBColor[
             0.2525333735524159, 0.38275896551722044`, 0.9376927740829386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 286}], {
             RGBColor[
             0.28063230469456346`, 0.41113725310534854`, 0.9393352740823563]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 290}], {
             RGBColor[
             0.24877546734729164`, 0.3788091678306199, 0.9374787668838809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 304}], {
             RGBColor[
             0.26114585574207083`, 0.3918112303614577, 0.938183242202614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 338}], {
             RGBColor[
             0.22507866009155236`, 0.35390232094047974`, 0.9361292687669514]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 239}], {
             RGBColor[
             0.5328344578573876, 0.6316180426642315, 0.9563658268409162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 269}], {
             RGBColor[
             0.45596747114210545`, 0.5665010427125681, 0.9510641632117192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 309}], {
             RGBColor[
             0.6279491492944215, 0.7079937863162957, 0.9644297266188226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 323}], {
             RGBColor[
             0.4895767347577772, 0.5956116976057565, 0.9532057157698048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 362}], {
             RGBColor[
             0.6749012549506066, 0.7446731281041272, 0.9691094737182575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 365}], {
             RGBColor[
             0.4322742926857367, 0.5457268859697086, 0.94956369337159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 377}], {
             RGBColor[
             0.40661285819624315`, 0.5187550912923315, 0.9481023126401036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 385}], {
             RGBColor[
             0.776474593776608, 0.8214741220909348, 0.7960777027150834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 388}], {
             RGBColor[
             0.4146565458770389, 0.527209517044103, 0.9485603887539554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 395}], {
             RGBColor[
             0.49860624010091514`, 0.6034326012978481, 0.9537810678657916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 124}], {
             RGBColor[
             0.29203302591126107`, 0.41977282835890883`, 0.9401070895447208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[
             0.35660710592589273`, 0.4832968843838794, 0.9439436673476838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 150}], {
             RGBColor[
             0.29792702653421543`, 0.4259677967148573, 0.9404427441608055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 179}], {
             RGBColor[
             0.29213029064248475`, 0.4198750597583651, 0.9401126286272736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 196}], {
             RGBColor[
             0.6007859963931654, 0.6812853787799371, 0.9644958808837701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 206}], {
             RGBColor[
             0.39316789594043106`, 0.5149640030957358, 0.9462732885579729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 209}], {
             RGBColor[
             0.3112464668184692, 0.43996737295489813`, 0.9412012665806477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 286}], {
             RGBColor[
             0.33934539796061675`, 0.46834566054302623`, 0.9428437665800653]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 386}], {
             RGBColor[
             0.34968714140668505`, 0.4773031589248714, 0.9435027333276041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 128}], {
             RGBColor[
             0.2718458799395796, 0.4030576342137573, 0.9387925927513947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 130}], {
             RGBColor[
             0.2277266187202509, 0.3566854933495158, 0.936280066093552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 135}], {
             RGBColor[
             0.2875725376828968, 0.4171271414972289, 0.9397782828791128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 146}], {
             RGBColor[
             0.2194595639056427, 0.3479962945778132, 0.9358092695518716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 151}], {
             RGBColor[
             0.22370106658388367`, 0.35245438281944674`, 0.9360508168546565]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 213}], {
             RGBColor[
             0.2826015926364835, 0.4128215587449884, 0.9394615386563896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 227}], {
             RGBColor[
             0.25689083303762017`, 0.3873389317150586, 0.9379409249543373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 243}], {
             RGBColor[
             0.23559188807996673`, 0.3649523901334573, 0.9367279815479644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 267}], {
             RGBColor[
             0.21867692760035795`, 0.34717369419895117`, 0.9357646995720923]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 306}], {
             RGBColor[
             0.2310448890646134, 0.36017320587193224`, 0.9364690366807222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 311}], {
             RGBColor[
             0.22119300122602184`, 0.3498182471078057, 0.9359079862428765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 344}], {
             RGBColor[
             0.2156761634002051, 0.3440197007651513, 0.9355938104901265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 346}], {
             RGBColor[
             0.2216080062797242, 0.35025444373208703`, 0.9359316201667398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 350}], {
             RGBColor[
             0.2941675459212899, 0.42283940615857285`, 0.9401985109723265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 354}], {
             RGBColor[
             0.21794551615801888`, 0.3464049343988889, 0.9357230467724773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 140}], {
             RGBColor[
             0.409447183861318, 0.5290643040720063, 0.9473105903890827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 147}], {
             RGBColor[
             0.3298813986080268, 0.4544594666479659, 0.9424490293594527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 193}], {
             RGBColor[
             0.6252379224927019, 0.7026774950776031, 0.9659558403883122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 195}], {
             RGBColor[
             0.41858299206596217`, 0.5369772819597975, 0.9478927160094046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 241}], {
             RGBColor[
             0.34672955885014695`, 0.4721679512974918, 0.9434085071606221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 242}], {
             RGBColor[
             0.3764731339021319, 0.500503839321299, 0.9452095130834909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 255}], {
             RGBColor[
             0.39336824955180094`, 0.5151375393238391, 0.9462860549129236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 263}], {
             RGBColor[
             0.3571898835204337, 0.4831624157488532, 0.9440042071759314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 312}], {
             RGBColor[
             0.4801821242946682, 0.587765497365623, 0.9525267121427227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 331}], {
             RGBColor[
             0.3267582826576653, 0.45117687376714777`, 0.9422711725263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 356}], {
             RGBColor[
             0.6789656354460096, 0.7452687768356042, 0.9624218591420297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 359}], {
             RGBColor[
             0.3691186833876108, 0.4941337839310517, 0.9447408939999908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 360}], {
             RGBColor[
             0.5376516098803733, 0.6341093662239545, 0.9572645433190765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 380}], {
             RGBColor[
             0.5664649447415552, 0.6566185624069654, 0.9601363872621158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 389}], {
             RGBColor[
             0.7028354936755193, 0.7597247670512044, 0.7201987400202577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[
             0.2188856606362972, 0.3473930858541622, 0.9357765866096961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 202}], {
             RGBColor[
             0.2856578369982738, 0.41583248159385067`, 0.9396429608971655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 234}], {
             RGBColor[
             0.2453302072944222, 0.37518798107295015`, 0.9372825644206755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 289}], {
             RGBColor[
             0.3589692840265578, 0.4787637861846151, 0.9444710719407625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 298}], {
             RGBColor[
             0.2245949434093795, 0.353393904038107, 0.9361017218174963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 173}], {
             RGBColor[
             0.18447873947082444`, 0.3112292301844495, 0.9338171633498009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 338}], {
             RGBColor[
             0.19975108063826336`, 0.32728142907378543`, 0.9346869005858826]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 161}], {
             RGBColor[
             0.861352076814639, 0.4393326641242953, 0.20508206465224244`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 196}], {
             RGBColor[
             0.8436412079731275, 0.6056407490965849, 0.5869779142171753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 214}], {
             RGBColor[
             0.8610395973659686, 0.437913767929313, 0.20482132414069976`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 253}], {
             RGBColor[
             0.8341751047564834, 0.26369040755053386`, 0.1803594249510559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 283}], {
             RGBColor[
             0.8875401777067986, 0.5502690172951994, 0.2265213799870392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 332}], {
             RGBColor[
             0.8304813654821182, 0.2352987088808914, 0.17682229605044186`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 334}], {
             RGBColor[
             0.9016847000711192, 0.6050909598648562, 0.2444456182077174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 356}], {
             RGBColor[
             0.8942706865915142, 0.6457615828952505, 0.5831484206142015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 364}], {
             RGBColor[
             0.8822480780789155, 0.5292876057583029, 0.22226323240490067`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 366}], {
             RGBColor[
             0.9182289355345559, 0.6604066319094237, 0.35054608517613656`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 389}], {
             RGBColor[
             0.9181405448210238, 0.6602175731108506, 0.3409253014924295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 150}], {
             RGBColor[
             0.2325126629936997, 0.36171592933364405`, 0.9365526242346068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 152}], {
             RGBColor[
             0.2137312689052459, 0.34197549333751603`, 0.935483051625852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 156}], {
             RGBColor[
             0.21424517968646528`, 0.3425156461524031, 0.9355123180845796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 157}], {
             RGBColor[
             0.2367400113323198, 0.3661591404668991, 0.9367933654686897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 160}], {
             RGBColor[
             0.21095706740892387`, 0.3390596316703475, 0.9353250649546998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 167}], {
             RGBColor[
             0.23121257205082407`, 0.360349451322155, 0.9364785859787222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 179}], {
             RGBColor[
             0.22671592710196903`, 0.3556231923771518, 0.9362225087010749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 181}], {
             RGBColor[
             0.209370470104526, 0.33739201730734614`, 0.9352347105853747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 238}], {
             RGBColor[
             0.21375043106969976`, 0.3419956339873084, 0.9354841428827698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 245}], {
             RGBColor[
             0.21075638483913717`, 0.33884870156549185`, 0.9353136363792337]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 386}], {
             RGBColor[
             0.28427277786616933`, 0.41305129154365816`, 0.9396126134014054]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 184}], {
             RGBColor[
             0.20307558723579205`, 0.3307756962936808, 0.934876226318445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 185}], {
             RGBColor[
             0.1925739180479394, 0.31973777613296384`, 0.9342781717940241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 190}], {
             RGBColor[
             0.20237543357367466`, 0.3300397904024893, 0.934836353603172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 226}], {
             RGBColor[
             0.1922514050569324, 0.3193987945309108, 0.9342598051563016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 252}], {
             RGBColor[
             0.19926974690677848`, 0.32677551680367367`, 0.934659489341944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 274}], {
             RGBColor[
             0.19786901158433057`, 0.32530325516803194`, 0.9345797195375327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 288}], {
             RGBColor[
             0.2031660717843796, 0.3308708012912981, 0.9348813792796271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 318}], {
             RGBColor[
             0.20302734583193666`, 0.33072499151954715`, 0.9348734790418622]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 176}], {
             RGBColor[
             0.18438193895865332`, 0.3111274867086507, 0.9338116507038363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 205}], {
             RGBColor[
             0.18385657240612066`, 0.31057529315177557`, 0.9337817318558796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 298}], {
             RGBColor[
             0.194012535572622, 0.32124985436502457`, 0.9343600989338109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 320}], {
             RGBColor[
             0.18313368370358218`, 0.3098154912916167, 0.9337405644136882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 347}], {
             RGBColor[
             0.18344187738111917`, 0.31013942238731573`, 0.9337581155876922]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 373}], {
             RGBColor[
             0.19027225530167013`, 0.317318582652788, 0.934147095505629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 137}], {
             RGBColor[
             0.31600670483300364`, 0.4466421785419929, 0.9414111535240912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 138}], {
             RGBColor[
             0.31413697275722113`, 0.44467697158248487`, 0.9413046750483962]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 193}], {
             RGBColor[
             0.5886484429999097, 0.6709855269816585, 0.9636243911098379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 210}], {
             RGBColor[
             0.29252473138981117`, 0.4219611356100898, 0.9400738898749681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 242}], {
             RGBColor[
             0.33988365440933965`, 0.4688118712253543, 0.9428780638050165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 255}], {
             RGBColor[
             0.35677877005900877`, 0.4834455712278943, 0.9439546056344492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 258}], {
             RGBColor[
             0.2885106861095953, 0.4177421195154126, 0.9398452959345076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 264}], {
             RGBColor[
             0.2996738393944105, 0.42947530140255136`, 0.9404810209996725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 312}], {
             RGBColor[
             0.44359264480187605`, 0.5560735292696781, 0.9501952628642483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 328}], {
             RGBColor[
             0.2853602010040631, 0.41443075991720546`, 0.9396658804684725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 331}], {
             RGBColor[
             0.29016880316487315`, 0.419484905671203, 0.9399397232478413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 380}], {
             RGBColor[
             0.529875465248763, 0.6249265943110206, 0.9578049379836415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 394}], {
             RGBColor[
             0.348496932711213, 0.47627225997448197`, 0.9434268942819889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 130}], {
             RGBColor[
             0.2597826750311079, 0.39037844100358665`, 0.9381056110777697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 135}], {
             RGBColor[
             0.31962859399375376`, 0.45082008915129973`, 0.9416038278633306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 139}], {
             RGBColor[
             0.3054227451460619, 0.43834904844198347`, 0.9407047455523833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 151}], {
             RGBColor[
             0.2557571228947407, 0.38614733047351757`, 0.9378763618388744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 213}], {
             RGBColor[
             0.3146576489473405, 0.4465145063990592, 0.9412870836406073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 215}], {
             RGBColor[
             0.5049864538136, 0.6035289290681363, 0.9559781758101122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 224}], {
             RGBColor[
             0.40082474260241224`, 0.5199417456186857, 0.9471108972900512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 227}], {
             RGBColor[
             0.28894688934847723`, 0.42103187936912945`, 0.9397664699385552]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 243}], {
             RGBColor[
             0.26764794439082373`, 0.39864533778752814`, 0.9385535265321823]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 259}], {
             RGBColor[
             0.599663278641086, 0.6781009426487141, 0.9652528657581285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 306}], {
             RGBColor[
             0.2631009453754704, 0.39386615352600307`, 0.9382945816649401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 350}], {
             RGBColor[
             0.32622360223214686`, 0.4565323538126437, 0.9420240559565443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 383}], {
             RGBColor[
             0.3311097462205182, 0.46076448615063337`, 0.9423353967308358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 131}], {
             RGBColor[
             0.8167235345760251, 0.5021703426652091, 0.5741281307411844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 253}], {
             RGBColor[
             0.822264279381292, 0.17213858435985327`, 0.16895360512041946`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 271}], {
             RGBColor[
             0.8196694573268939, 0.15219364499147486`, 0.1664688005906955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 287}], {
             RGBColor[
             0.8183275809306592, 0.1418793949960282, 0.16518381823822845`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 303}], {
             RGBColor[
             0.8566331099862248, 0.3804373908932912, 0.19967730788162147`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 333}], {
             RGBColor[
             0.8865563472760825, 0.5573394921368233, 0.5646390445032476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 337}], {
             RGBColor[
             0.8881576917970897, 0.5585337722586294, 0.5619283859267235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 353}], {
             RGBColor[
             0.9062979809873158, 0.5688117544551025, 0.33694932919085196`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 364}], {
             RGBColor[
             0.8703372527037241, 0.4377357825676223, 0.21085741257426427`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 391}], {
             RGBColor[
             0.8197851875316053, 0.15308319805818565`, 0.1665796239654257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 135}], {
             RGBColor[
             0.27550933277442513`, 0.40444794828705827`, 0.9390913012054878]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 146}], {
             RGBColor[
             0.20739635899717102`, 0.3353171013676426, 0.9351222878782466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 151}], {
             RGBColor[
             0.211637861675412, 0.3397751896092761, 0.9353638351810314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 158}], {
             RGBColor[
             0.20340188077088672`, 0.3311186514872704, 0.9348948082525605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 227}], {
             RGBColor[
             0.24482762812914852`, 0.374659738504888, 0.9372539432807123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 243}], {
             RGBColor[
             0.22352868317149505`, 0.3522731969232867, 0.9360409998743393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 267}], {
             RGBColor[
             0.20661372269188627`, 0.33449450098878053`, 0.9350777178984673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 275}], {
             RGBColor[
             0.2049038205781411, 0.33269728545317867`, 0.934980341502663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 306}], {
             RGBColor[
             0.21898168415614172`, 0.3474940126617616, 0.9357820550070972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 311}], {
             RGBColor[
             0.20912979631755016`, 0.33713905389763504`, 0.9352210045692514]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 317}], {
             RGBColor[
             0.20208377375464914`, 0.3297332374403929, 0.9348197440079504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 344}], {
             RGBColor[
             0.20361295849173341`, 0.3313405075549807, 0.9349068288165013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 346}], {
             RGBColor[
             0.20954480137125253`, 0.3375752505219164, 0.9352446384931148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 354}], {
             RGBColor[
             0.2058823112495472, 0.3337257411887183, 0.9350360650988523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 142}], {
             RGBColor[
             0.6441352636384634, 0.7193460306737178, 0.9669266768382974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 201}], {
             RGBColor[
             0.7399124857733206, 0.7967445245200704, 0.9747112197727283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 273}], {
             RGBColor[
             0.6690783888345512, 0.7395959833828867, 0.9688902910234116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 281}], {
             RGBColor[
             0.6064310569728814, 0.687254440774864, 0.9643678385927457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 293}], {
             RGBColor[
             0.5641203291112874, 0.6506070149001673, 0.9616718364273125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 303}], {
             RGBColor[
             0.8540204827009316, 0.7329759435664439, 0.607655802146349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 391}], {
             RGBColor[
             0.817172560246312, 0.5056217507313383, 0.5745581182301532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 394}], {
             RGBColor[
             0.585868010689025, 0.6694437636125451, 0.9630575794667262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 149}], {
             RGBColor[
             0.20160011613108555`, 0.32922488261236305`, 0.9347922004217959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 155}], {
             RGBColor[
             0.18938684794258642`, 0.3163879633803221, 0.934096672866372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 180}], {
             RGBColor[
             0.1906491777676344, 0.3177147520627811, 0.9341685606824588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 249}], {
             RGBColor[
             0.18824799980109214`, 0.3151909617764689, 0.9340318171494888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 268}], {
             RGBColor[
             0.19026708475134468`, 0.3173131480765642, 0.9341468010504371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 279}], {
             RGBColor[
             0.1959554713815859, 0.323292003089491, 0.9344707462538155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 299}], {
             RGBColor[
             0.19063186344337624`, 0.3176965536101942, 0.9341675746573066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 300}], {
             RGBColor[
             0.1945175148280322, 0.3217806195799947, 0.9343888567553567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 370}], {
             RGBColor[
             0.189210358194615, 0.3162024614651078, 0.9340866220363182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 178}], {
             RGBColor[
             0.18320632976714918`, 0.309891846910452, 0.9337447014995381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 200}], {
             RGBColor[
             0.18872606349581567`, 0.31569343703061226`, 0.9340590421696713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 278}], {
             RGBColor[
             0.18574944160901402`, 0.31256481869885566`, 0.9338895279567354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 296}], {
             RGBColor[
             0.18124069831826523`, 0.30782584362944293`, 0.9336327616964153]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 320}], {
             RGBColor[
             0.18355649439985816`, 0.3102598921411492, 0.9337646428573487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 330}], {
             RGBColor[
             0.1860526851696524, 0.3128835469078388, 0.9339067972289052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 347}], {
             RGBColor[
             0.18386468807739512`, 0.3105838232368483, 0.9337821940313528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 367}], {
             RGBColor[
             0.18474901765317286`, 0.31151330969072427`, 0.9338325552924449]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 398}], {
             RGBColor[
             0.18210607446438823`, 0.30873540882703493`, 0.9336820435877278]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 163}], {
             RGBColor[
             0.17908461226291875`, 0.3055596604815222, 0.9335099757852068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 171}], {
             RGBColor[
             0.18358417843459812`, 0.31028898981693004`, 0.9337662194221723]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 240}], {
             RGBColor[
             0.17922390736570504`, 0.3057060684663703, 0.9335179084352418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 272}], {
             RGBColor[
             0.18788317693480855`, 0.3148075098128992, 0.9340110410269609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 342}], {
             RGBColor[
             0.18275455563161122`, 0.309417003649867, 0.9337189736308591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 374}], {
             RGBColor[
             0.18137577945827954`, 0.307967822472237, 0.9336404543675045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 213}], {
             RGBColor[
             0.33038430669065766`, 0.46058401368253077`, 0.9422727737683254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 215}], {
             RGBColor[
             0.5207131115569171, 0.6175984363516078, 0.9569638659378303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 224}], {
             RGBColor[
             0.41655140034572946`, 0.5340112529021572, 0.9480965874177693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 227}], {
             RGBColor[
             0.3046735470917944, 0.4351013866526011, 0.9407521600662733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 243}], {
             RGBColor[
             0.2833746021341409, 0.41271484507099976`, 0.9395392166599004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 259}], {
             RGBColor[
             0.6153899363844033, 0.6921704499321857, 0.9662385558858466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 350}], {
             RGBColor[
             0.3419502599754641, 0.47060186109611535`, 0.9430097460842624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 363}], {
             RGBColor[
             0.3549405295448861, 0.4818533796872159, 0.9438374745743816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 383}], {
             RGBColor[
             0.3468364039638354, 0.47483399343410504`, 0.9433210868585539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 393}], {
             RGBColor[
             0.5286635054610748, 0.6238093444947674, 0.9577562869015417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 149}], {
             RGBColor[
             0.19648120536399588`, 0.3238445828384636, 0.9345006860263599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 155}], {
             RGBColor[
             0.18426793717549678`, 0.3110076636064226, 0.933805158470936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 268}], {
             RGBColor[
             0.18514817398425504`, 0.3119328483026647, 0.9338552866550012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 279}], {
             RGBColor[
             0.19083656061449622`, 0.3179117033155916, 0.9341792318583795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 299}], {
             RGBColor[
             0.1855129526762866, 0.3123162538362948, 0.9338760602618706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 300}], {
             RGBColor[
             0.18939860406094253`, 0.3164003198060953, 0.9340973423599207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 371}], {
             RGBColor[
             0.1813347042579621, 0.3079246498323852, 0.9336381151956117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 138}], {
             RGBColor[
             0.29077492625511725`, 0.4229532620622423, 0.93987057393605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 164}], {
             RGBColor[
             0.2538187120761361, 0.3841099378008197, 0.9377659722103766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 210}], {
             RGBColor[
             0.2691626848877073, 0.40023742608984725`, 0.9386397887626219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 230}], {
             RGBColor[
             0.2568850160495337, 0.38733281769176137`, 0.9379405936854713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 242}], {
             RGBColor[
             0.31652160790723577`, 0.4470881617051118, 0.9414439626926704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 258}], {
             RGBColor[
             0.2651486396074914, 0.3960184099951701, 0.9384111948221615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 264}], {
             RGBColor[
             0.27631179289230656`, 0.4077515918823088, 0.9390469198873264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 328}], {
             RGBColor[
             0.2619981545019592, 0.39270705039696285`, 0.9382317793561266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 394}], {
             RGBColor[
             0.32513488620910913`, 0.45454855045423936`, 0.9419927931696428]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 149}], {
             RGBColor[
             0.2496156992329207, 0.3796923048161946, 0.9375266168467558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 164}], {
             RGBColor[
             0.2519489800003536, 0.38214473084131173`, 0.9376594937346815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 210}], {
             RGBColor[
             0.2672929528119248, 0.3982722191303392, 0.9385333102869269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 230}], {
             RGBColor[
             0.2550152839737512, 0.38536761073225334`, 0.9378341152097762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 242}], {
             RGBColor[
             0.31465187583145326`, 0.4451229547456037, 0.9413374842169753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 258}], {
             RGBColor[
             0.26327890753170885`, 0.39405320303566205`, 0.9383047163464664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 264}], {
             RGBColor[
             0.27444206081652406`, 0.4057863849228008, 0.9389404414116314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 281}], {
             RGBColor[
             0.3438282004171828, 0.4703940206570502, 0.9431965738199672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 328}], {
             RGBColor[
             0.2601284224261766, 0.3907418434374549, 0.9381253008804314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 394}], {
             RGBColor[
             0.32326515413332657`, 0.4525833434947314, 0.9418863146939478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 186}], {
             RGBColor[
             0.2567623305791477, 0.38720386748367763`, 0.9379336069294297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 213}], {
             RGBColor[
             0.3161784578429658, 0.4481129729732145, 0.941373691457378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 215}], {
             RGBColor[
             0.5065072627092252, 0.6051273956422916, 0.956064783626883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 306}], {
             RGBColor[
             0.2646217542710957, 0.39546462010015837`, 0.9383811894817108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 308}], {
             RGBColor[
             0.25989565930435055`, 0.3904971946383813, 0.9381120453649856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 345}], {
             RGBColor[
             0.5675136417908162, 0.652851509744995, 0.962127956401694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 350}], {
             RGBColor[
             0.3277444111277722, 0.4581308203867991, 0.942110663773315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 378}], {
             RGBColor[
             0.27359029407982893`, 0.40489112407740385`, 0.9388919345560525]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 147}], {
             RGBColor[
             0.32678087214865287`, 0.45177394646584723`, 0.9422514665551494]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 193}], {
             RGBColor[
             0.6221373960333281, 0.6999919748954846, 0.9657582775840088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 195}], {
             RGBColor[
             0.4154824656065883, 0.5342917617776789, 0.9476951532051012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 241}], {
             RGBColor[
             0.343629032390773, 0.46948243111537313`, 0.9432109443563187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 242}], {
             RGBColor[
             0.3733726074427579, 0.4978183191391804, 0.9450119502791875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 255}], {
             RGBColor[
             0.390267723092427, 0.5124520191417203, 0.9460884921086202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 263}], {
             RGBColor[
             0.35408935706105976`, 0.48047689556673456`, 0.943806644371628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 312}], {
             RGBColor[
             0.4770815978352943, 0.5850799771835042, 0.9523291493384193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 331}], {
             RGBColor[
             0.3236577561982914, 0.4484913535850291, 0.9420736097220124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 356}], {
             RGBColor[
             0.6758651089866358, 0.7425832566534856, 0.9622242963377263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 359}], {
             RGBColor[
             0.36601815692823686`, 0.491448263748933, 0.9445433311956875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 360}], {
             RGBColor[
             0.5345510834209994, 0.6314238460418358, 0.9570669805147731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 380}], {
             RGBColor[
             0.5633644182821813, 0.6539330422248467, 0.9599388244578124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 389}], {
             RGBColor[
             0.6997349672161455, 0.7570392468690857, 0.7200011772159544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 179}], {
             RGBColor[
             0.2912900071166007, 0.41914724840212236`, 0.9400590865040379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 196}], {
             RGBColor[
             0.5999457128672814, 0.6805575674236943, 0.9644423387605343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 209}], {
             RGBColor[
             0.3104061832925851, 0.4392395615986554, 0.9411477244574119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 286}], {
             RGBColor[
             0.3385051144347327, 0.4676178491867835, 0.9427902244568296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 290}], {
             RGBColor[
             0.3066482770874609, 0.4352897639120549, 0.9409337172583541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 304}], {
             RGBColor[
             0.31901866548224, 0.4482918264428926, 0.9416381925770871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 386}], {
             RGBColor[
             0.348846857880801, 0.4765753475686286, 0.9434491912043683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.37498442055197767`, 0.49560326154572176`, 0.9453825139194686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 201}], {
             RGBColor[
             0.5699368421210522, 0.6613816598554264, 0.9595312716051138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 273}], {
             RGBColor[
             0.4991027451822828, 0.6042331187182427, 0.9537103428557971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 281}], {
             RGBColor[
             0.436455413320613, 0.55189157611022, 0.9491878904251312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 293}], {
             RGBColor[
             0.3941446854590191, 0.5152441502355233, 0.946491888259698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 394}], {
             RGBColor[
             0.4158923670367568, 0.5340808989479011, 0.9478776312991117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 151}], {
             RGBColor[
             0.2032578843654731, 0.3309673021352812, 0.934886607870296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 158}], {
             RGBColor[
             0.1950219034609478, 0.3223107640132754, 0.9344175809418251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 171}], {
             RGBColor[
             0.19347840745274208`, 0.320688451845352, 0.9343296811275554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 186}], {
             RGBColor[
             0.20274228315425485`, 0.3304253725712859, 0.9348572451440806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 272}], {
             RGBColor[
             0.19777740595295248`, 0.3252069718413211, 0.9345745027323441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 306}], {
             RGBColor[
             0.21060170684620283`, 0.33868612518776664`, 0.9353048276963617]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 308}], {
             RGBColor[
             0.2058756118794577, 0.33371869972598955`, 0.9350356835796365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 342}], {
             RGBColor[
             0.19264878464975516`, 0.3198164656782889, 0.9342824353362423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 348}], {
             RGBColor[
             0.20000377872339242`, 0.3275470307832401, 0.9347012913679973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 354}], {
             RGBColor[
             0.1975023339396083, 0.32491785371472337`, 0.9345588377881168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 374}], {
             RGBColor[
             0.1912700084764235, 0.3183672845006589, 0.9342039160728877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 378}], {
             RGBColor[
             0.21957024665493602`, 0.3481126291650121, 0.9358155727707034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 148}], {
             RGBColor[
             0.41890511783186646`, 0.5289568419765102, 0.9490497655266936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 169}], {
             RGBColor[
             0.5192579762174159, 0.6205960432553745, 0.9552970364739267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 218}], {
             RGBColor[
             0.5707667888209911, 0.662413217772521, 0.9593519988850778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 222}], {
             RGBColor[
             0.7661723613566251, 0.8169857716290115, 0.9639290713689532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 276}], {
             RGBColor[
             0.48015124453344243`, 0.5868307576532874, 0.952775625742377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 282}], {
             RGBColor[
             0.44814038646858245`, 0.5591045613100133, 0.9507359221725744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 305}], {
             RGBColor[
             0.4396583364184836, 0.550769790541102, 0.9502316306235659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 339}], {
             RGBColor[
             0.48160738498318656`, 0.5880919933231088, 0.9528684097242202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 361}], {
             RGBColor[
             0.4954156444114053, 0.6000520136165334, 0.9537482598048219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 382}], {
             RGBColor[
             0.451676599366216, 0.5621674511867154, 0.9509612465314614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 384}], {
             RGBColor[
             0.757420984754537, 0.7226612405223014, 0.6127983851533676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 165}], {
             RGBColor[
             0.23770682741222313`, 0.3671753254665574, 0.9368484242141641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 170}], {
             RGBColor[
             0.24268853638713495`, 0.37241141745778183`, 0.9371321251705074]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 182}], {
             RGBColor[
             0.24585035887698375`, 0.3757346933657375, 0.937312186283807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 192}], {
             RGBColor[
             0.25406976709764434`, 0.3843738125462326, 0.9377802694224489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 208}], {
             RGBColor[
             0.2721455459278671, 0.4033726021673685, 0.9388096582861116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 221}], {
             RGBColor[
             0.3098924284635012, 0.43739177601044266`, 0.941166351723109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 225}], {
             RGBColor[
             0.22917757181567264`, 0.3582105370485437, 0.9363626957258434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 235}], {
             RGBColor[
             0.22156110310920424`, 0.35020514552603776`, 0.9359289491005658]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 335}], {
             RGBColor[
             0.2240686969525251, 0.3528407856460005, 0.9360717528602902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 349}], {
             RGBColor[
             0.2241439081408365, 0.35291983737358057`, 0.9360760360261996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 351}], {
             RGBColor[
             0.2797139568415439, 0.4112527007055903, 0.9392434061971325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 355}], {
             RGBColor[
             0.22900678342998865`, 0.3580310276265808, 0.9363529695799375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 395}], {
             RGBColor[
             0.3442769835307749, 0.46717394939172724`, 0.9433573051669275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 151}], {
             RGBColor[
             0.20337080686080378`, 0.3310859908375735, 0.9348930386393511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 158}], {
             RGBColor[
             0.1951348259562785, 0.3224294527155677, 0.9344240117108803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 227}], {
             RGBColor[
             0.2365605733145403, 0.3659705397331854, 0.936783146739032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 243}], {
             RGBColor[
             0.21526162835688684`, 0.343583998151584, 0.9355702033326591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 267}], {
             RGBColor[
             0.19834666787727806`, 0.32580530221707793`, 0.9346069213567869]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 275}], {
             RGBColor[
             0.1966367657635329, 0.324008086681476, 0.9345095449609826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 306}], {
             RGBColor[
             0.2107146293415335, 0.33880481389005895`, 0.9353112584654169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 311}], {
             RGBColor[
             0.20086274150294195`, 0.3284498551259324, 0.9347502080275711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 317}], {
             RGBColor[
             0.19381671894004093`, 0.32104403866869025`, 0.9343489474662702]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 344}], {
             RGBColor[
             0.1953459036771252, 0.3226513087832781, 0.9344360322748211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 346}], {
             RGBColor[
             0.20127774655664432`, 0.3288860517502138, 0.9347738419514344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 354}], {
             RGBColor[
             0.197615256434939, 0.32503654241701563`, 0.9345652685571719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 195}], {
             RGBColor[
             0.3359166803532971, 0.45968692435363845`, 0.9428335921754714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 217}], {
             RGBColor[
             0.2277310230294914, 0.3566901225577769, 0.9362803169124476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 231}], {
             RGBColor[
             0.2192108871052112, 0.34773491949353985`, 0.9357951077759714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 241}], {
             RGBColor[
             0.2640632471374818, 0.3948775936913327, 0.9383493833266887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 242}], {
             RGBColor[
             0.29380682218946674`, 0.42321348171513995`, 0.9401503892495575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 255}], {
             RGBColor[
             0.3107019378391358, 0.4378471817176799, 0.9412269310789902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 312}], {
             RGBColor[
             0.3975158125820031, 0.5104751397594638, 0.9474675883087893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 331}], {
             RGBColor[
             0.2440919709450002, 0.37388651616098867`, 0.9372120486923824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 359}], {
             RGBColor[
             0.28645237167494564`, 0.4168434263248926, 0.9396817701660576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 392}], {
             RGBColor[
             0.2251386082236323, 0.35396533022822685`, 0.9361326827243879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 218}], {
             RGBColor[
             0.40841467546891774`, 0.5204402282772255, 0.9482239194761258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 228}], {
             RGBColor[
             0.2402804897849437, 0.36988040779990605`, 0.9369949904788982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 276}], {
             RGBColor[
             0.31779913118136904`, 0.44485776815799194`, 0.9416475463334251]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.285788273116509, 0.4171315718147177, 0.9396078427636225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 301}], {
             RGBColor[
             0.25321055434935075`, 0.3834707254705414, 0.9377313385275249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 305}], {
             RGBColor[
             0.2773062230664102, 0.4087968010458064, 0.939103551214614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 313}], {
             RGBColor[
             0.27058528986872044`, 0.4017326741232574, 0.9387208040117352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 339}], {
             RGBColor[
             0.3192552716311131, 0.4461190038278132, 0.9417403303152683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 340}], {
             RGBColor[
             0.263972502592159, 0.39478221542066183`, 0.9383442155590771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 361}], {
             RGBColor[
             0.33306353105933184`, 0.4580790241212378, 0.94262018039587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 382}], {
             RGBColor[
             0.2893244860141426, 0.42019446169141983`, 0.9398331671225094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 155}], {
             RGBColor[
             0.19811293609800762`, 0.3255596352976139, 0.9345936106777326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 164}], {
             RGBColor[
             0.21265948505393958`, 0.340848980554772, 0.9354220151210823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 210}], {
             RGBColor[
             0.22800345786551077`, 0.3569764688437995, 0.9362958316733276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 230}], {
             RGBColor[
             0.21572578902733716`, 0.34407186044571364`, 0.935596636596177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 258}], {
             RGBColor[
             0.22398941258529487`, 0.35275745274912235`, 0.9360672377328672]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 264}], {
             RGBColor[
             0.23515256587011008`, 0.3644906346362611, 0.9367029627980321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 268}], {
             RGBColor[
             0.19899317290676588`, 0.326484819993856, 0.9346437388617977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 279}], {
             RGBColor[
             0.20468155953700706`, 0.33246367500678287`, 0.9349676840651762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 299}], {
             RGBColor[
             0.19935795159879743`, 0.32686822552748607`, 0.9346645124686672]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 300}], {
             RGBColor[
             0.20324360298345337`, 0.33095229149728655`, 0.9348857945667173]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 328}], {
             RGBColor[
             0.22083892747976266`, 0.3494460931509151, 0.9358878222668322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 152}], {
             RGBColor[
             0.21962526952820027`, 0.3481704616934645, 0.9358187062419367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 156}], {
             RGBColor[
             0.22013918030941965`, 0.34871061450835156`, 0.9358479727006643]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 157}], {
             RGBColor[
             0.24263401195527415`, 0.3723541088228476, 0.9371290200847746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 160}], {
             RGBColor[
             0.2168510680318782, 0.345254600026296, 0.9356607195707846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 167}], {
             RGBColor[
             0.2371065726737784, 0.3665444196781035, 0.936814240594807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 179}], {
             RGBColor[
             0.23260992772492337`, 0.36181816073310025`, 0.9365581633171598]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 181}], {
             RGBColor[
             0.21526447072748034`, 0.3435869856632946, 0.9355703652014595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 206}], {
             RGBColor[
             0.33364753302286965`, 0.45690710407047097`, 0.9427188232478589]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 211}], {
             RGBColor[
             0.23544785722092995`, 0.3648010045685258, 0.9367197792036168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 238}], {
             RGBColor[
             0.21964443169265407`, 0.3481906023432569, 0.9358197974988545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 386}], {
             RGBColor[
             0.29016677848912364`, 0.4192462598996066, 0.9399482680174902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 158}], {
             RGBColor[
             0.19937632863451948`, 0.3268875409572013, 0.9346655590136652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 186}], {
             RGBColor[
             0.20709670832782653`, 0.33500214951521173`, 0.9351052232159208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 227}], {
             RGBColor[
             0.2408020759927813, 0.3704286279748189, 0.937024694041817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 267}], {
             RGBColor[
             0.20258817055551906`, 0.33026339045871145`, 0.9348484686595718]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 306}], {
             RGBColor[
             0.21495613201977448`, 0.3432629021316925, 0.9355528057682019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 308}], {
             RGBColor[
             0.2102300370530294, 0.33829547666991544`, 0.9352836616514766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 311}], {
             RGBColor[
             0.20510424418118295`, 0.33290794336756596`, 0.934991755330356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 317}], {
             RGBColor[
             0.1980582216182819, 0.3255021269103238, 0.9345904947690551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 344}], {
             RGBColor[
             0.1995874063553662, 0.3271093970249116, 0.9346775795776059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 346}], {
             RGBColor[
             0.2055192492348853, 0.3333441399918473, 0.9350153892542195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 348}], {
             RGBColor[
             0.20435820389696413`, 0.332123807727166, 0.9349492694398375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 354}], {
             RGBColor[
             0.20185675911317996`, 0.3294946306586492, 0.934806815859957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 156}], {
             RGBColor[
             0.20135778622096587`, 0.32897017851222354`, 0.9347784000919095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 157}], {
             RGBColor[
             0.22385261786682037`, 0.3526136728267195, 0.9360594474760198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 160}], {
             RGBColor[
             0.19806967394342445`, 0.325514164030168, 0.9345911469620297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 179}], {
             RGBColor[
             0.2138285336364696, 0.3420777247369723, 0.935488590708405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 181}], {
             RGBColor[
             0.1964830766390266, 0.32384654966716653`, 0.9345007925927047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 238}], {
             RGBColor[
             0.20086303760420032`, 0.32845016634712887`, 0.9347502248900996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 245}], {
             RGBColor[
             0.19786899137363773`, 0.3253032339253123, 0.9345797183865636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 168}], {
             RGBColor[
             0.20180786245057253`, 0.3294432371660213, 0.9348040312673576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 175}], {
             RGBColor[
             0.19789401206423968`, 0.32532953225753836`, 0.9345811432778787]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 211}], {
             RGBColor[
             0.21907020233692062`, 0.34758705088213704`, 0.9357870959865418]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 216}], {
             RGBColor[
             0.21073387590110806`, 0.33882504324447416`, 0.935312354528512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 229}], {
             RGBColor[
             0.2017865527982215, 0.3294208393702904, 0.934802817714181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 294}], {
             RGBColor[
             0.20769214048678164`, 0.33562798646685293`, 0.9351391321965103]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 329}], {
             RGBColor[
             0.23399514583317907`, 0.36327411279277777`, 0.9366370494391784]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 341}], {
             RGBColor[
             0.22749742981872606`, 0.3564446012825976, 0.9362670141246647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 343}], {
             RGBColor[
             0.20318561149837056`, 0.330891338769592, 0.9348824920374326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 358}], {
             RGBColor[
             0.24162422522743635`, 0.37129275894771363`, 0.9370715142244698]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 379}], {
             RGBColor[
             0.19405975897206282`, 0.32129948915197337`, 0.9343627882365483]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 207}], {
             RGBColor[
             0.18894498275511917`, 0.315923535052423, 0.9340715092976267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 231}], {
             RGBColor[
             0.18878970308862236`, 0.3157603262776354, 0.9340626663503354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 369}], {
             RGBColor[
             0.183389073095449, 0.31008392173509136`, 0.9337551084617403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 372}], {
             RGBColor[
             0.18315975702077553`, 0.3098428960011307, 0.9337420492505304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 387}], {
             RGBColor[
             0.18595738695423472`, 0.312783382441179, 0.9339013701365182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 392}], {
             RGBColor[
             0.19471742420704347`, 0.3219907370123223, 0.934400241298752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 249}], {
             RGBColor[
             0.18476081976801417`, 0.3115257144617197, 0.9338332274054255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 268}], {
             RGBColor[
             0.18677990471826675`, 0.31364790076181503`, 0.9339482113063738]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 279}], {
             RGBColor[
             0.19246829134850796`, 0.31962675577474187`, 0.9342721565097523]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.1871446834102983, 0.31403130629544507`, 0.9339689849132433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 300}], {
             RGBColor[
             0.19103033479495424`, 0.31811537226524556`, 0.9341902670112934]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 370}], {
             RGBColor[
             0.18572317816153708`, 0.3125372141503586, 0.9338880322922549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 371}], {
             RGBColor[
             0.18296643499197385`, 0.3096397022915355, 0.9337310398469844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 160}], {
             RGBColor[
             0.19858358472464382`, 0.32605431684505504`, 0.9346204134207573]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.21434244441768896`, 0.34261787755185935`, 0.9355178571671325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 181}], {
             RGBColor[
             0.19699698742024596`, 0.3243867024820536, 0.9345300590514323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 245}], {
             RGBColor[
             0.1983829021548571, 0.32584338674019936`, 0.9346089848452912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 352}], {
             RGBColor[
             0.19412861826228733`, 0.32137186463193046`, 0.9343667096712585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 396}], {
             RGBColor[
             0.19313485512094197`, 0.32032735656215416`, 0.9343101163304997]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 160}], {
             RGBColor[
             0.22107841637049833`, 0.349697811159551, 0.9359014608048675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 167}], {
             RGBColor[
             0.24133392101239853`, 0.37098763081135855`, 0.93705498182889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 168}], {
             RGBColor[
             0.222412865673202, 0.35110040198566517`, 0.9359774557185156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 203}], {
             RGBColor[
             0.2784354581733116, 0.40986687435040126`, 0.9391721369966093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 206}], {
             RGBColor[
             0.3378748813614898, 0.46135031520372605`, 0.942959564481942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 211}], {
             RGBColor[
             0.23967520555955008`, 0.36924421570178084`, 0.9369605204376998]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 238}], {
             RGBColor[
             0.22387178003127423`, 0.3526338134765119, 0.9360605387329375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 341}], {
             RGBColor[
             0.24810243304135554`, 0.37810176610224144`, 0.9374404385758228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 358}], {
             RGBColor[
             0.2622292284500658, 0.3929499237673575, 0.938244938675628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 386}], {
             RGBColor[
             0.2943941268277438, 0.42368947103286164`, 0.9401890092515732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 267}], {
             RGBColor[
             0.19435218965099377`, 0.3216068523367057, 0.934379441731101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 306}], {
             RGBColor[
             0.20672015111524922`, 0.33460636400968674`, 0.935083778839731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 308}], {
             RGBColor[
             0.20199405614850408`, 0.32963893854790965`, 0.9348146347230057]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 311}], {
             RGBColor[
             0.19686826327665763`, 0.3242514052455602, 0.9345227284018851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 317}], {
             RGBColor[
             0.18982224071375664`, 0.31684558878831803`, 0.9341214678405843]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 344}], {
             RGBColor[
             0.19135142545084088`, 0.31845285890290587`, 0.934208552649135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 346}], {
             RGBColor[
             0.19728326833036003`, 0.3246876018698416, 0.9345463623257486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 348}], {
             RGBColor[
             0.1961222229924388, 0.3234672696051602, 0.9344802425113666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 354}], {
             RGBColor[
             0.1936207782086547, 0.3208380925366434, 0.9343377889314861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 374}], {
             RGBColor[
             0.1873884527454699, 0.3142875233225789, 0.9339828672162569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 250}], {
             RGBColor[
             0.18793077615893167`, 0.3148575396154177, 0.934013751732358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 265}], {
             RGBColor[
             0.19056897353088317`, 0.3176304523247132, 0.9341639931698273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 321}], {
             RGBColor[
             0.1833474210515813, 0.31004014279609426`, 0.9337527364394607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 375}], {
             RGBColor[
             0.19246854917072223`, 0.3196270267622359, 0.9342721711923458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 381}], {
             RGBColor[
             0.18574510039169012`, 0.3125602558041992, 0.9338892807308311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[
             0.19370887514270452`, 0.320930687999998, 0.9343428059215524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 238}], {
             RGBColor[
             0.19808883610787825`, 0.32553430467996036`, 0.9345922382189475]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 245}], {
             RGBColor[
             0.19509478987731566`, 0.3223873722581438, 0.9344217317154114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 196}], {
             RGBColor[
             0.8618354721760655, 0.7122379768474625, 0.603098702731688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 214}], {
             RGBColor[
             0.8792338615689066, 0.5445109956801907, 0.22094211265521246`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 253}], {
             RGBColor[
             0.8523693689594214, 0.3702876353014115, 0.19648021346556857`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 283}], {
             RGBColor[
             0.9057344419097366, 0.6568662450460772, 0.2426421685015519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 332}], {
             RGBColor[
             0.848675629685056, 0.3418959366317691, 0.19294308456495457`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 334}], {
             RGBColor[
             0.9198789642740572, 0.7116881876157337, 0.2605664067222301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.9124649507944522, 0.7523588106461282, 0.5992692091287142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 364}], {
             RGBColor[
             0.9004423422818535, 0.6358848335091806, 0.23838402091941335`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 366}], {
             RGBColor[
             0.9364231997374939, 0.7670038596603013, 0.3666668736906492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 389}], {
             RGBColor[
             0.9363348090239618, 0.7668148008617284, 0.3570460900069422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 183}], {
             RGBColor[
             0.1919904214056781, 0.3191244841661233, 0.9342449425234534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 270}], {
             RGBColor[
             0.20162095796864934`, 0.3292467887050914, 0.9347933873336124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 280}], {
             RGBColor[
             0.20211294537388308`, 0.32976389866179523`, 0.9348214052885103]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 291}], {
             RGBColor[
             0.1953787311658639, 0.32268581255532547`, 0.9344379017517408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 336}], {
             RGBColor[
             0.21504897720554328`, 0.3433604883086603, 0.9355580931641793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 357}], {
             RGBColor[
             0.1906502583880034, 0.3177158878633042, 0.9341686222221902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 368}], {
             RGBColor[
             0.18956500601498782`, 0.31657521881029016`, 0.934106818705034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 171}], {
             RGBColor[
             0.18355378954190335`, 0.31025704916394076`, 0.9337644888196897]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 240}], {
             RGBColor[
             0.17919351847301027`, 0.305674127813381, 0.9335161778327592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 272}], {
             RGBColor[
             0.18785278804211375`, 0.3147755691599099, 0.9340093104244782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 342}], {
             RGBColor[
             0.18272416673891645`, 0.30938506299687774`, 0.9337172430283764]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 374}], {
             RGBColor[
             0.1813453905655848, 0.3079358818192477, 0.9336387237650219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 210}], {
             RGBColor[
             0.23033673863294363`, 0.3594288948689166, 0.9364287085612534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 230}], {
             RGBColor[
             0.21805906979477002`, 0.3465242864708308, 0.9357295134841028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 258}], {
             RGBColor[
             0.22632269335272776`, 0.3552098787742395, 0.936200114620793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 264}], {
             RGBColor[
             0.23748584663754294`, 0.36694306066137816`, 0.9368358396859577]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 279}], {
             RGBColor[
             0.20701484030443992`, 0.33491610103189995`, 0.9351005609531018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 328}], {
             RGBColor[
             0.22317220824719552`, 0.35189851917603227`, 0.9360206991547579]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 170}], {
             RGBColor[
             0.23052227294686206`, 0.35962390319639986`, 0.9364392744659576]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 172}], {
             RGBColor[
             0.3025819493818708, 0.42881009810169846`, 0.9407829073040905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 184}], {
             RGBColor[
             0.21954677082243013`, 0.3480879545765947, 0.9358142358567716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 190}], {
             RGBColor[
             0.21884661716031273`, 0.34735204868540315`, 0.9357743631414985]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 192}], {
             RGBColor[
             0.24190350365737148`, 0.3715862982848506, 0.9370874187178992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 221}], {
             RGBColor[
             0.29772616502322835`, 0.42460426174906063`, 0.9404735010185594]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 226}], {
             RGBColor[
             0.20872258864357046`, 0.33671105281382463`, 0.935197814694628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 252}], {
             RGBColor[
             0.21574093049341658`, 0.3440877750865875, 0.9355974988802704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 274}], {
             RGBColor[
             0.21434019517096867`, 0.34261551345094576`, 0.9355177290758593]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 288}], {
             RGBColor[
             0.2196372553710177, 0.3481830595742119, 0.9358193888179538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 318}], {
             RGBColor[
             0.21949852941857476`, 0.348037249802461, 0.9358114885801888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 322}], {
             RGBColor[
             0.2103258844391586, 0.3383962183498125, 0.9352891200183233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 351}], {
             RGBColor[
             0.26754769340127105`, 0.39846518644420825`, 0.9385505554925828]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 355}], {
             RGBColor[
             0.2168405199897158, 0.34524351336519876`, 0.9356601188753879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 399}], {
             RGBColor[
             0.2924581876891166, 0.42004140455849254`, 0.9401378301611192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 169}], {
             RGBColor[
             0.3512165772923903, 0.4726432539013666, 0.9438449606681389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 246}], {
             RGBColor[
             0.23093801406837325`, 0.3600608734746177, 0.9364629503077938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 326}], {
             RGBColor[
             0.24337300372818133`, 0.3731308360309576, 0.9371711045730012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 363}], {
             RGBColor[
             0.3098501203432949, 0.43692070785172515`, 0.9411795622408922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 383}], {
             RGBColor[
             0.3017459947622442, 0.42990132159861427`, 0.9406631745250644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 168}], {
             RGBColor[
             0.21688542639170627`, 0.3452907128409211, 0.935662676228548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.2729080188918158, 0.40405718520565725`, 0.9388573575066418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 211}], {
             RGBColor[
             0.23414776627805434`, 0.3634345265570368, 0.9366457409477322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 216}], {
             RGBColor[
             0.22581143984224178`, 0.35467251891937396`, 0.9361709994897025]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 238}], {
             RGBColor[
             0.2183443407497785, 0.3468241243317679, 0.9357457592429699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 341}], {
             RGBColor[
             0.2425749937598598, 0.37229207695749733`, 0.9371256590858552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 358}], {
             RGBColor[
             0.25670178916857006`, 0.3871402346226134, 0.9379301591856604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 211}], {
             RGBColor[
             0.2152267109388578, 0.3435472977313434, 0.935568214837358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 216}], {
             RGBColor[
             0.20689038450304525`, 0.3347852900936806, 0.9350934733793282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 238}], {
             RGBColor[
             0.19942328541058194`, 0.3269368955060745, 0.9346682331325956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 341}], {
             RGBColor[
             0.22365393842066325`, 0.35240484813180395`, 0.936048132975481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 379}], {
             RGBColor[
             0.190216267574, 0.31725973600117974`, 0.9341439070873645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 218}], {
             RGBColor[
             0.5087675338544672, 0.6120794295560898, 0.9544711904233589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 222}], {
             RGBColor[
             0.7041731063901011, 0.7666519834125803, 0.9590482629072343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 224}], {
             RGBColor[
             0.4775031351026399, 0.5866975822042433, 0.9520099424283488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 276}], {
             RGBColor[
             0.41815198956691846`, 0.5364969694368562, 0.947894817280658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 326}], {
             RGBColor[
             0.349415147686683, 0.47074983716853436`, 0.9437423719170701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 361}], {
             RGBColor[
             0.4334163894448813, 0.5497182254001022, 0.948867451343103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 363}], {
             RGBColor[
             0.4158922643017966, 0.5345397089893019, 0.947750829584961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 382}], {
             RGBColor[
             0.38967734439969204`, 0.5118336629702842, 0.9460804380697425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 383}], {
             RGBColor[
             0.4077881387207459, 0.527520322736191, 0.9472344418691334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 393}], {
             RGBColor[
             0.5896152402179853, 0.6764956737968535, 0.9616696419121211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[
             0.2468852126322833, 0.37682239027607506`, 0.9373711196742425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 208}], {
             RGBColor[
             0.26496099146250607`, 0.3958211798972109, 0.9384005085379051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 221}], {
             RGBColor[
             0.30270787399814014`, 0.42984035374028506`, 0.9407572019749026]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 225}], {
             RGBColor[
             0.22199301735031157`, 0.3506591147783862, 0.9359535459776369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 235}], {
             RGBColor[
             0.21437654864384317`, 0.34265372325588017`, 0.9355197993523594]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 322}], {
             RGBColor[
             0.2153075934140704, 0.3436323103410369, 0.9355728209746665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 335}], {
             RGBColor[
             0.21688414248716403`, 0.34528936337584293`, 0.9356626031120838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 349}], {
             RGBColor[
             0.21695935367547547`, 0.34536841510342303`, 0.9356668862779931]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 351}], {
             RGBColor[
             0.27252940237618284`, 0.4037012784354327, 0.938834256448926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 355}], {
             RGBColor[
             0.2218222289646276, 0.3504796053564232, 0.9359438198317311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 186}], {
             RGBColor[
             0.1973172314150955, 0.32472329922528254`, 0.9345482964731804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 240}], {
             RGBColor[
             0.18369308464468964`, 0.3104034571487888, 0.9337724214697247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 272}], {
             RGBColor[
             0.19235235421379315`, 0.3195048984953177, 0.9342655540614437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 308}], {
             RGBColor[
             0.20045056014029836`, 0.3280166263799862, 0.9347267349087363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 342}], {
             RGBColor[
             0.18722373291059582`, 0.31411439233228555`, 0.933973486665342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 348}], {
             RGBColor[
             0.1945787269842331, 0.32184495743723673`, 0.934392342697097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 374}], {
             RGBColor[
             0.18584495673726414`, 0.3126652111546555, 0.9338949674019874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 192}], {
             RGBColor[
             0.31894488906729196`, 0.44600858518137365`, 0.9417147525123752]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 194}], {
             RGBColor[
             0.41753162873264527`, 0.5360090287080477, 0.9478416433121417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 221}], {
             RGBColor[
             0.3747675504331488, 0.4990265486455837, 0.9451008348130354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 256}], {
             RGBColor[
             0.6859636429526801, 0.7471589426256584, 0.8613086090450968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 316}], {
             RGBColor[
             0.5458822960971526, 0.6391409074229324, 0.9586767421820886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 351}], {
             RGBColor[
             0.3445890788111915, 0.47288747334073133`, 0.943177889287059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 399}], {
             RGBColor[
             0.369499573099037, 0.49446369145501556`, 0.9447651639555954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 198}], {
             RGBColor[
             0.6233166189809511, 0.701327344471203, 0.9656888716580491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 203}], {
             RGBColor[
             0.3639226125883841, 0.4896332085668736, 0.9444098049633691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 266}], {
             RGBColor[
             0.5380286912692482, 0.6346285303347542, 0.9572070721400225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 313}], {
             RGBColor[
             0.35122662219084355`, 0.47640574207717373`, 0.9436825095790529]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 329}], {
             RGBColor[
             0.34008730347088106`, 0.4646976118288939, 0.9430481418570962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 340}], {
             RGBColor[
             0.3446138349142821, 0.46945528337457815`, 0.9433059211263948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 341}], {
             RGBColor[
             0.3335895874564281, 0.4578681003187137, 0.9426781065425826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 358}], {
             RGBColor[
             0.34771638286513834`, 0.47271625798382977`, 0.9434826066423876]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 204}], {
             RGBColor[
             0.1850387535749342, 0.31181784051481387`, 0.9338490553245634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 216}], {
             RGBColor[
             0.20297653411671235`, 0.3306715851851976, 0.9348705853898494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 229}], {
             RGBColor[
             0.1940292110138258, 0.32126738131101384`, 0.9343610485755184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 294}], {
             RGBColor[
             0.19993479870238595`, 0.3274745284075764, 0.9346973630578478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 307}], {
             RGBColor[
             0.18458331869086259`, 0.3113391495754152, 0.933823118981671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 343}], {
             RGBColor[
             0.19542826971397487`, 0.32273788071031545`, 0.93444072289877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 379}], {
             RGBColor[
             0.1863024171876671, 0.3131460310926968, 0.9339210190978857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 205}], {
             RGBColor[
             0.18567915281687453`, 0.3124909407217502, 0.9338855251140061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 232}], {
             RGBColor[
             0.18828223277850703`, 0.3152269428062281, 0.9340337666669094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 277}], {
             RGBColor[
             0.18565952896853344`, 0.31247031481291987`, 0.933884407564874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 298}], {
             RGBColor[
             0.19583511598337588`, 0.32316550193499927`, 0.9344638921919373]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 320}], {
             RGBColor[
             0.18495626411433608`, 0.3117311388615913, 0.9338443576718145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 347}], {
             RGBColor[
             0.18526445779187303`, 0.3120550699572905, 0.9338619088458187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 373}], {
             RGBColor[
             0.192094835712424, 0.3192342302227627, 0.9342508887637553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 390}], {
             RGBColor[
             0.199593709897452, 0.3271160224473115, 0.9346779385550025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 219}], {
             RGBColor[
             0.18016175523476746`, 0.3066918060397442, 0.9335713174839634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 248}], {
             RGBColor[
             0.18215464872777276`, 0.30878646345763827`, 0.9336848098201683]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 260}], {
             RGBColor[
             0.18516377148342406`, 0.31194924226322995`, 0.9338561749095045]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 285}], {
             RGBColor[
             0.18283630546897034`, 0.3095029279121705, 0.9337236291631588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 200}], {
             RGBColor[
             0.1885274133225135, 0.31548464310332325`, 0.9340477293361784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 278}], {
             RGBColor[
             0.18555079143571185`, 0.31235602477156665`, 0.9338782151232425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 296}], {
             RGBColor[
             0.18104204814496305`, 0.30761704970215387`, 0.9336214488629224]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 330}], {
             RGBColor[
             0.18585403499635023`, 0.3126747529805498, 0.9338954843954123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 367}], {
             RGBColor[
             0.18455036747987072`, 0.3113045157634352, 0.933821242458952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 398}], {
             RGBColor[
             0.18190742429108608`, 0.30852661489974587`, 0.9336707307542348]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 209}], {
             RGBColor[
             0.24592936800917714`, 0.3758177369731411, 0.9373166857370019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 245}], {
             RGBColor[
             0.21085364957036085`, 0.33895093296494805`, 0.9353191754617867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 286}], {
             RGBColor[
             0.2740282991513247, 0.4041960245612692, 0.9389591857364195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 290}], {
             RGBColor[
             0.24217146180405288`, 0.37186793928654055`, 0.9371026785379442]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 352}], {
             RGBColor[
             0.20659936567779108`, 0.3344794108566792, 0.9350769002877538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 386}], {
             RGBColor[
             0.284370042597393, 0.41315352294311436`, 0.9396181524839584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 232}], {
             RGBColor[
             0.18939213687360562`, 0.3163935223821609, 0.9340969740631693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 249}], {
             RGBColor[
             0.18602314959306215`, 0.3128525031441788, 0.9339051152215123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 268}], {
             RGBColor[
             0.1880422345433147, 0.314974689444274, 0.9340200991224608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 370}], {
             RGBColor[
             0.18698550798658503`, 0.3138640028328177, 0.9339599201083417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 238}], {
             RGBColor[
             0.1965022388034804, 0.3238666903169589, 0.9345018838496224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 245}], {
             RGBColor[
             0.1935081925729178, 0.3207197578951424, 0.9343313773460864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 187}], {
             RGBColor[
             0.22908739425404853`, 0.35811575471368917`, 0.9363575602471148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 208}], {
             RGBColor[
             0.2681228139523549, 0.39914445580516655`, 0.9385805696512048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 323}], {
             RGBColor[
             0.3312247462121247, 0.45512489933743366`, 0.9425528644360341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 377}], {
             RGBColor[
             0.2482608696505907, 0.3782682930240088, 0.9374494613063329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 388}], {
             RGBColor[
             0.2563045573313864, 0.38672271877578024`, 0.9379075374201846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 395}], {
             RGBColor[
             0.3402542515552627, 0.4629458030295253, 0.9431282165320207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 270}], {
             RGBColor[
             0.198314467229445, 0.32577145729456636`, 0.9346050875775294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 291}], {
             RGBColor[
             0.1920722404266596, 0.31921048114480044`, 0.9342496019956579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 357}], {
             RGBColor[
             0.18734376764879906`, 0.31424055645277915`, 0.9339803224661072]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 368}], {
             RGBColor[
             0.18625851527578347`, 0.31309988739976513`, 0.933918518948951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 185}], {
             RGBColor[
             0.20305130848505737`, 0.330750177787297, 0.9348748436795078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 190}], {
             RGBColor[
             0.21285282401079259`, 0.34105219205682236`, 0.9354330254886557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 226}], {
             RGBColor[
             0.20272879549405032`, 0.3304111961852439, 0.9348564770417853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 252}], {
             RGBColor[
             0.20974713734389644`, 0.3377879184580067, 0.9352561612274277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 274}], {
             RGBColor[
             0.20834640202144852`, 0.33631565682236503`, 0.9351763914230165]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 288}], {
             RGBColor[
             0.21364346222149755`, 0.3418832029456312, 0.9354780511651108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 318}], {
             RGBColor[
             0.2135047362690546, 0.34173739317388024`, 0.935470150927346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 190}], {
             RGBColor[
             0.20235115482293997`, 0.33001427189610544`, 0.9348349709642347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 226}], {
             RGBColor[
             0.1922271263061977, 0.3193732760245269, 0.9342584225173644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 252}], {
             RGBColor[
             0.1992454681560438, 0.3267499982972898, 0.9346581067030068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 274}], {
             RGBColor[
             0.19784473283359588`, 0.32527773666164805`, 0.9345783368985956]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 288}], {
             RGBColor[
             0.2031417930336449, 0.3308452827849142, 0.93487999664069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 318}], {
             RGBColor[
             0.20300306708120197`, 0.33069947301316327`, 0.9348720964029251]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 357}], {
             RGBColor[
             0.18927662196416456`, 0.31627210888827, 0.9340903956599655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 272}], {
             RGBColor[
             0.20161622991530592`, 0.3292418192212516, 0.9347931180779689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 306}], {
             RGBColor[
             0.21444053080855624`, 0.3427209725676972, 0.9355234430419865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 308}], {
             RGBColor[
             0.20971443584181115`, 0.3377535471059201, 0.9352542989252615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 342}], {
             RGBColor[
             0.19648760861210862`, 0.32385131305821946`, 0.9345010506818672]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 348}], {
             RGBColor[
             0.2038426026857459, 0.33158187816317064`, 0.9349199067136222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 374}], {
             RGBColor[
             0.19510883243877694`, 0.3224021318805894, 0.9344225314185126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 378}], {
             RGBColor[
             0.22340907061728948`, 0.35214747654494266`, 0.9360341881163283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 208}], {
             RGBColor[
             0.25538258130493185`, 0.38575366351532014`, 0.9378550322494192]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 302}], {
             RGBColor[
             0.20552429842574232`, 0.33334944701157526`, 0.9350156767981692]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 377}], {
             RGBColor[
             0.2355206370031677, 0.36487750073416236`, 0.9367239239045473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 388}], {
             RGBColor[
             0.2435643246839634, 0.37333192648593383`, 0.937182000018399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 201}], {
             RGBColor[
             0.47076164268683474`, 0.5730017553920743, 0.9531670568538995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 264}], {
             RGBColor[
             0.26789407428573686`, 0.39890403591261847`, 0.9385675432655809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 273}], {
             RGBColor[
             0.39992754574806544`, 0.5158532142548906, 0.9473461281045827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 281}], {
             RGBColor[
             0.3372802138863956, 0.4635116716468679, 0.9428236756739168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 293}], {
             RGBColor[
             0.29496948602480166`, 0.4268642457721712, 0.9401276735084836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 394}], {
             RGBColor[
             0.3167171676025393, 0.44570099448454903`, 0.9415134165478973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 207}], {
             RGBColor[
             0.2123454769342431, 0.3405189381117063, 0.935404132823199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 241}], {
             RGBColor[
             0.2570425573000169, 0.3874984035347115, 0.937949565426625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 263}], {
             RGBColor[
             0.2675028819703037, 0.39849286798607286`, 0.9385452654419342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 280}], {
             RGBColor[
             0.2210513429116578, 0.3496693552377532, 0.9358999190114381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 291}], {
             RGBColor[
             0.21431712870363867`, 0.34259126913128346`, 0.9355164154746687]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 336}], {
             RGBColor[
             0.23398737474331802`, 0.3632659448846183, 0.936636606887107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 359}], {
             RGBColor[
             0.2794316818374808, 0.4094642361682714, 0.9392819522659938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 226}], {
             RGBColor[
             0.20202864183193292`, 0.3296752902940524, 0.9348166043265123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 252}], {
             RGBColor[
             0.20904698368177904`, 0.3370520125668152, 0.9352162885121547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 274}], {
             RGBColor[
             0.20764624835933113`, 0.33557975093117354`, 0.9351365187077434]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 288}], {
             RGBColor[
             0.21294330855938015`, 0.3411472970544397, 0.9354381784498378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 318}], {
             RGBColor[
             0.21280458260693721`, 0.34100148728268875`, 0.9354302782120729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 225}], {
             RGBColor[
             0.19624559498378968`, 0.32359694139030604`, 0.9344872683637615]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 235}], {
             RGBColor[
             0.18862912627732129`, 0.3155915498678, 0.9340535217384839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 261}], {
             RGBColor[
             0.18660634868245718`, 0.3134654823640909, 0.9339383275468877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 322}], {
             RGBColor[
             0.18956017104754852`, 0.31657013695295677`, 0.934106543360791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 327}], {
             RGBColor[
             0.1848862258869851, 0.3116575242439654, 0.9338403690983792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 335}], {
             RGBColor[
             0.19113672012064215`, 0.3182271899877628, 0.9341963254982084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 349}], {
             RGBColor[
             0.1912119313089536, 0.3183062417153429, 0.9342006086641177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 355}], {
             RGBColor[
             0.19607480659810572`, 0.32341743196834305`, 0.9344775422178556]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 208}], {
             RGBColor[
             0.27634222217301546`, 0.40778357498566165`, 0.9390486527898467]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 221}], {
             RGBColor[
             0.3140891047086496, 0.4418027488287358, 0.9414053462268441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[
             0.233374248060821, 0.36262150986683694`, 0.9366016902295785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 322}], {
             RGBColor[
             0.2266888241245798, 0.3555947054294877, 0.936220965226608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 335}], {
             RGBColor[
             0.22826537319767345`, 0.3572517584642937, 0.9363107473640253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 349}], {
             RGBColor[
             0.22834058438598487`, 0.3573308101918738, 0.9363150305299347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 351}], {
             RGBColor[
             0.2839106330866923, 0.41566367352388345`, 0.9394824007008676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 355}], {
             RGBColor[
             0.233203459675137, 0.36244200044487396`, 0.9365919640836726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 399}], {
             RGBColor[
             0.3088211273745378, 0.43723989163816773`, 0.941069675369404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 195}], {
             RGBColor[
             0.6312732042379722, 0.7079049527832757, 0.9663404032043308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 242}], {
             RGBColor[
             0.5891633460741419, 0.6714315101447773, 0.963657200278417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 253}], {
             RGBColor[
             0.8315602657829888, 0.5341252723143658, 0.5780805506738103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 255}], {
             RGBColor[
             0.606058461723811, 0.6860652101473173, 0.9647337421078497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 283}], {
             RGBColor[
             0.884925338733304, 0.8207038820590313, 0.6242425057097936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 312}], {
             RGBColor[
             0.6928723364666782, 0.7586931681891012, 0.9709743993376487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 332}], {
             RGBColor[
             0.8278665265086236, 0.5057335736447233, 0.5745434217731962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 356}], {
             RGBColor[
             0.8916558476180196, 0.9161964476590825, 0.9808695463369558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 360}], {
             RGBColor[
             0.7503418220523833, 0.8050370370474327, 0.9757122305140027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 364}], {
             RGBColor[
             0.8796332391054209, 0.7997224705221349, 0.619984358127655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 380}], {
             RGBColor[
             0.7791551569135652, 0.8275462332304435, 0.978584074457042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 389}], {
             RGBColor[
             0.9155257058475293, 0.9306524378746825, 0.7386464272151838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 221}], {
             RGBColor[
             0.41267584437400284`, 0.5318031923554098, 0.9475322370266106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 233}], {
             RGBColor[
             0.7128854689421396, 0.7730895863286765, 0.9426895386250231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 256}], {
             RGBColor[
             0.7238719368935342, 0.7799355863354847, 0.863740011258672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 316}], {
             RGBColor[
             0.5837905900380065, 0.6719175511327584, 0.9611081443956637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 399}], {
             RGBColor[
             0.40740786703989107`, 0.5272403351648417, 0.9471965661691704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 241}], {
             RGBColor[
             0.35276484059541724`, 0.47739540900316435`, 0.9437930699766406]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 242}], {
             RGBColor[
             0.3825084156474021, 0.5057312970269716, 0.9455940758995094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.3994035312970712, 0.5203649970295117, 0.9466706177289421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 263}], {
             RGBColor[
             0.3632251652657039, 0.4883898734545258, 0.9443887699919498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 312}], {
             RGBColor[
             0.48621740603993846`, 0.5929929550712956, 0.9529112749587412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 356}], {
             RGBColor[
             0.6850009171912799, 0.7504962345412768, 0.9628064219580481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 359}], {
             RGBColor[
             0.375153965132881, 0.49936124163672424`, 0.9451254568160093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 360}], {
             RGBColor[
             0.5436868916256435, 0.6393368239296271, 0.957649106135095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 380}], {
             RGBColor[
             0.5725002264868254, 0.6618460201126379, 0.9605209500781344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 389}], {
             RGBColor[
             0.7088707754207897, 0.764952224756877, 0.7205833028362763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 206}], {
             RGBColor[
             0.6365065028818196, 0.7122246861355508, 0.9667719599708235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 214}], {
             RGBColor[
             0.8615229927273951, 0.7108190806524803, 0.6028379622201453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 286}], {
             RGBColor[
             0.5826840049020053, 0.6656063435828412, 0.963342437992916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 332}], {
             RGBColor[
             0.8309647608435446, 0.5082040216040586, 0.5748389341298874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 334}], {
             RGBColor[
             0.9021680954325457, 0.8779962725880234, 0.6424622562871629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 366}], {
             RGBColor[
             0.9187123308959824, 0.9333119446325909, 0.748562723255582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 386}], {
             RGBColor[
             0.5930257483480736, 0.6745638419646864, 0.9640014047404548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 217}], {
             RGBColor[
             0.19977926755688577`, 0.3273110553124115, 0.9346885057891993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 231}], {
             RGBColor[
             0.19125913163260555`, 0.3183558522481745, 0.9342032966527232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 254}], {
             RGBColor[
             0.18919463052287389`, 0.31618593068491585`, 0.9340857263686796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 314}], {
             RGBColor[
             0.18703267242257346`, 0.3139135756454394, 0.9339626060531978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 369}], {
             RGBColor[
             0.18585850163943218`, 0.31267944770563044`, 0.933895738764128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 392}], {
             RGBColor[
             0.19718685275102665`, 0.3245862629828614, 0.9345408716011396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 203}], {
             RGBColor[
             0.5694035624452959, 0.6546305646490294, 0.9622535793690412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 206}], {
             RGBColor[
             0.6288429856334741, 0.7061140055023541, 0.9660410068543737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 214}], {
             RGBColor[
             0.8538594754790496, 0.7047084000192836, 0.6021070091036955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 266}], {
             RGBColor[
             0.74350964112616, 0.79962588641691, 0.9750508465456946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 310}], {
             RGBColor[
             0.8276571285797327, 0.5355745817229594, 0.5782791813938954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 384}], {
             RGBColor[
             0.8811911535814985, 0.820358675063078, 0.6244757857174054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 215}], {
             RGBColor[
             0.8474033618771311, 0.8799586173228249, 0.9038397390676208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 222}], {
             RGBColor[
             0.9699116219534045, 0.9763258350817114, 0.9020107810264453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 223}], {
             RGBColor[
             0.9239760391061387, 0.7216129997514857, 0.5202901272072924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 224}], {
             RGBColor[
             0.7432416506659434, 0.7963714338733744, 0.8949724605475597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 247}], {
             RGBColor[
             0.9030372486329088, 0.5619443631205439, 0.500289085988991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 259}], {
             RGBColor[
             0.9420801867046171, 0.9545306309034027, 0.913114429015637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 271}], {
             RGBColor[
             0.9043692525849842, 0.5721827291840494, 0.5015646144777819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 287}], {
             RGBColor[
             0.9030273761887495, 0.5618684791886028, 0.5002796321253148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 292}], {
             RGBColor[
             0.9041138184890838, 0.5702193507910247, 0.501320010499076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 345}], {
             RGBColor[
             0.9084097409587222, 0.9276827314255283, 0.9099029118424318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 350}], {
             RGBColor[
             0.6686405102956781, 0.7329620420673324, 0.8898856192140527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 353}], {
             RGBColor[
             0.9909977762454061, 0.988800838647677, 0.6720451430779383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 393}], {
             RGBColor[
             0.8553537557812887, 0.8861695254659845, 0.9046321600313321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 400}], {
             RGBColor[
             0.9054254853432643, 0.5803013970083357, 0.502576064159955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 234}], {
             RGBColor[
             0.22049169370930496`, 0.34908112844227146`, 0.9358680478172909]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 296}], {
             RGBColor[
             0.1865617818736295, 0.3134186398223141, 0.9339357895330556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 298}], {
             RGBColor[
             0.19975642982426225`, 0.3272870514074283, 0.9346872052141117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 320}], {
             RGBColor[
             0.18887757795522245`, 0.31585268833402036`, 0.934067670693989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 330}], {
             RGBColor[
             0.1913737687250167, 0.31847634310071005`, 0.9342098250655455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 347}], {
             RGBColor[
             0.1891857716327594, 0.31617661942971953`, 0.9340852218679931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 367}], {
             RGBColor[
             0.19007010120853718`, 0.31710610588359545`, 0.9341355831290852]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 398}], {
             RGBColor[
             0.18742715801975252`, 0.3143282050199061, 0.933985071424368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 273}], {
             RGBColor[
             0.5948799673171399, 0.6816316125645953, 0.9614948857902279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 281}], {
             RGBColor[
             0.5322326354554701, 0.6292900699565726, 0.956972433359562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 293}], {
             RGBColor[
             0.4899219075938762, 0.5926426440818758, 0.9542764311941287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 303}], {
             RGBColor[
             0.7798220611835203, 0.6750115727481525, 0.6002603969131654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 394}], {
             RGBColor[
             0.5116695891716139, 0.6114793927942537, 0.9556621742335425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 212}], {
             RGBColor[
             0.45268550871471924`, 0.56313574583105, 0.9509994425842794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 234}], {
             RGBColor[
             0.28726387007128157`, 0.41752052418196, 0.9397344221047603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 239}], {
             RGBColor[
             0.4173644057485659, 0.5344604832455712, 0.9482188359733204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 269}], {
             RGBColor[
             0.34049741903328384`, 0.46934348329390774`, 0.9429171723441234]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 289}], {
             RGBColor[
             0.4009029468034172, 0.5210963292936249, 0.9469229296248474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 309}], {
             RGBColor[
             0.5124790971855998, 0.6108362268976354, 0.9562827357512269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 362}], {
             RGBColor[
             0.5594312028417849, 0.6475155686854668, 0.9609624828506617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 365}], {
             RGBColor[
             0.31680424057691503`, 0.4485693265510483, 0.9414167025039941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 206}], {
             RGBColor[
             0.36944897924090714`, 0.4944198695980247, 0.9447619401596937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 211}], {
             RGBColor[
             0.27124930343896736`, 0.4023137700960795, 0.9387628961154517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 216}], {
             RGBColor[
             0.26291297700315486`, 0.3935517624584167, 0.938288154657422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 266}], {
             RGBColor[
             0.4841156347335931, 0.5879317505125805, 0.9537717798510146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 329}], {
             RGBColor[
             0.28617424693522586`, 0.4180008320067203, 0.9396128495680883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 341}], {
             RGBColor[
             0.2796765309207728, 0.4111713204965401, 0.9392428142535747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 358}], {
             RGBColor[
             0.29380332632948314`, 0.42601947816165614`, 0.9400473143533797]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 229}], {
             RGBColor[
             0.18893129430891603`, 0.3159091476275659, 0.9340707297608657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 237}], {
             RGBColor[
             0.18108298927677668`, 0.3076600814275077, 0.9336237803998122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 307}], {
             RGBColor[
             0.17948540198595286`, 0.30598091589196724`, 0.9335328001670183]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 343}], {
             RGBColor[
             0.1903303530090651, 0.3173796470268675, 0.9341504040841173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 232}], {
             RGBColor[
             0.18775686622597437`, 0.3146747492493529, 0.9340038478189527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 277}], {
             RGBColor[
             0.18513416241600078`, 0.31191812125604473`, 0.9338544887169173]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 373}], {
             RGBColor[
             0.19156946915989134`, 0.31868203666588757`, 0.9342209699157987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 390}], {
             RGBColor[
             0.19906834334491935`, 0.32656382889043634`, 0.9346480197070459]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 266}], {
             RGBColor[
             0.5435550579217713, 0.6394151913659053, 0.9575592073363473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 286}], {
             RGBColor[
             0.375065904449271, 0.49928496789863985`, 0.9451198456671187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 386}], {
             RGBColor[
             0.3854076478953393, 0.5082424662804851, 0.9457788124146576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 231}], {
             RGBColor[
             0.1913619669815575, 0.3184639387200607, 0.9342091529737147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 280}], {
             RGBColor[
             0.200223112625469, 0.32777756462089525`, 0.9347137821092452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 291}], {
             RGBColor[
             0.19348889841744987`, 0.3206994785144255, 0.9343302785724756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 368}], {
             RGBColor[
             0.18767517326657374`, 0.3145888847693901, 0.9339991955257688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 372}], {
             RGBColor[
             0.18573202091371066`, 0.31254650844355597`, 0.9338885358739095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 387}], {
             RGBColor[
             0.18852965084716983`, 0.3154869948836043, 0.9340478567598975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 392}], {
             RGBColor[
             0.1972896880999786, 0.3246943494547476, 0.9345467279221311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 221}], {
             RGBColor[
             0.3321648835388723, 0.4608015384498717, 0.9424347350905069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 225}], {
             RGBColor[
             0.2514500268910438, 0.38162029948797277`, 0.9376310790932412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 323}], {
             RGBColor[
             0.3575199332630081, 0.48276280813906464`, 0.9440503364383386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 351}], {
             RGBColor[
             0.301986411916915, 0.43466246314501933`, 0.9405117895645303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 388}], {
             RGBColor[
             0.28259974438226976`, 0.4143606275774112, 0.9394050094224892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 395}], {
             RGBColor[
             0.366549438606146, 0.4905837118311563, 0.9446256885343254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 286}], {
             RGBColor[
             0.29314447532730914`, 0.4242883377578022, 0.9400478236897936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 290}], {
             RGBColor[
             0.2612876379800373, 0.3919602524830736, 0.938191316491318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 304}], {
             RGBColor[
             0.2736580263748165, 0.40496231501391133`, 0.9388957918100511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 338}], {
             RGBColor[
             0.23759083072429804`, 0.3670534055929334, 0.9368418183743885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 386}], {
             RGBColor[
             0.30348621877337745`, 0.4332458361396474, 0.9407067904373323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 230}], {
             RGBColor[
             0.2334030426063412, 0.36265177475985827`, 0.9366033300363481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 258}], {
             RGBColor[
             0.24166666616429894`, 0.371337367063267, 0.9370739311730383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 264}], {
             RGBColor[
             0.2528298194491141, 0.3830705489504057, 0.9377096562382032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 279}], {
             RGBColor[
             0.2223588131160111, 0.3510435893209275, 0.9359743775053473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 328}], {
             RGBColor[
             0.2385161810587667, 0.36802600746505976`, 0.9368945157070033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 394}], {
             RGBColor[
             0.30165291276591666`, 0.42986750752233627`, 0.9406555295205197]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 216}], {
             RGBColor[
             0.22415272438939332`, 0.35292910380979625`, 0.9360765380985124]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 238}], {
             RGBColor[
             0.21668562529693003`, 0.34508070922219014`, 0.9356512978517798]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 341}], {
             RGBColor[
             0.24091627830701134`, 0.3705486618479197, 0.9370311976946651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 358}], {
             RGBColor[
             0.2550430737157216, 0.3853968195130357, 0.9378356977944702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 239}], {
             RGBColor[
             0.542458414688152, 0.6394312043737607, 0.9571234599763494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 289}], {
             RGBColor[
             0.5259969557430033, 0.6260670504218144, 0.9558275536278764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 309}], {
             RGBColor[
             0.6375731061251859, 0.7158069480258249, 0.965187359754256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 362}], {
             RGBColor[
             0.6845252117813709, 0.7524862898136562, 0.9698671068536907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 385}], {
             RGBColor[
             0.7860985506073723, 0.8292872838004639, 0.7968353358505167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 215}], {
             RGBColor[
             0.5157421665105038, 0.6132928535993672, 0.9566471217151071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 227}], {
             RGBColor[
             0.29970260204538113`, 0.43079580390036054`, 0.94043541584355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 259}], {
             RGBColor[
             0.6104189913379899, 0.6878648671799451, 0.9659218116631232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 306}], {
             RGBColor[
             0.2738566580723743, 0.4036300780572341, 0.9389635275699348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 308}], {
             RGBColor[
             0.2691305631056292, 0.398662652595457, 0.9386943834532097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 345}], {
             RGBColor[
             0.5767485455920949, 0.6610169677020706, 0.962710294489918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 350}], {
             RGBColor[
             0.33697931492905076`, 0.46629627834387477`, 0.942693001861539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 378}], {
             RGBColor[
             0.2828251978811075, 0.4130565820344796, 0.9394742726442766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 257}], {
             RGBColor[
             0.9241708234933428, 0.7599031818045514, 0.5786645333196092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 310}], {
             RGBColor[
             0.8527190352209195, 0.3739582811888842, 0.19685354443386982`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 332}], {
             RGBColor[
             0.8483631502363858, 0.34047704043678684`, 0.1926823440534119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 389}], {
             RGBColor[
             0.9360223295752915, 0.7653959046667461, 0.35678534949539953`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 224}], {
             RGBColor[
             0.6019092601655756, 0.6867200928189938, 0.9624709353645509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 227}], {
             RGBColor[
             0.4900314069116405, 0.5878102265694376, 0.9551265080130549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 259}], {
             RGBColor[
             0.8007477962042493, 0.8448792898490222, 0.9806129038326282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 345}], {
             RGBColor[
             0.7670773504583543, 0.8180313903711476, 0.977401386659423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 350}], {
             RGBColor[
             0.5273081197953102, 0.6233107010129518, 0.9573840940310441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 353}], {
             RGBColor[
             0.8496653857450382, 0.8791494975932964, 0.7395436178949295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 393}], {
             RGBColor[
             0.7140213652809209, 0.7765181844116039, 0.9721306348483233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 400}], {
             RGBColor[
             0.7640930948428964, 0.47065005595395515`, 0.5700745389769464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 229}], {
             RGBColor[
             0.2068690748506942, 0.33476289229794964`, 0.9350922598261517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 294}], {
             RGBColor[
             0.21277466253925434`, 0.3409700393945122, 0.9354285743084811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 329}], {
             RGBColor[
             0.23907766788565177`, 0.368616165720437, 0.936926491551149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 340}], {
             RGBColor[
             0.2436041993290528, 0.3733738372661213, 0.9371842708204476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 341}], {
             RGBColor[
             0.2325799518711988, 0.3617866542102568, 0.9365564562366354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 343}], {
             RGBColor[
             0.20826813355084325`, 0.33623339169725125`, 0.9351719341494034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 358}], {
             RGBColor[
             0.24670674727990904`, 0.37663481187537284`, 0.9373609563364405]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 231}], {
             RGBColor[
             0.19972682323934088`, 0.32725593300951006`, 0.9346855191628995]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 254}], {
             RGBColor[
             0.1976623221296092, 0.32508601144625143`, 0.934567948878856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 314}], {
             RGBColor[
             0.1955003640293088, 0.322813656406775, 0.9344448285633742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 331}], {
             RGBColor[
             0.22460790707912992`, 0.3534075296769589, 0.9361024600793104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 392}], {
             RGBColor[
             0.20565454435776198`, 0.333486343744197, 0.935023094111316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 222}], {
             RGBColor[
             0.7556819189936763, 0.8084691579297268, 0.9631032253183853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 276}], {
             RGBColor[
             0.46966080217049366`, 0.5783141439540027, 0.951949779691809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 282}], {
             RGBColor[
             0.4376499441056336, 0.5505879476107286, 0.9499100761220066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 305}], {
             RGBColor[
             0.42916789405553485`, 0.5422531768418173, 0.9494057845729981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 339}], {
             RGBColor[
             0.47111694262023773`, 0.5795753796238241, 0.9520425636736524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 361}], {
             RGBColor[
             0.4849252020484565, 0.5915353999172487, 0.952922413754254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 382}], {
             RGBColor[
             0.44118615700326724`, 0.5536508374874307, 0.9501354004808935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 384}], {
             RGBColor[
             0.7469305423915883, 0.7141446268230167, 0.6119725391027997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 248}], {
             RGBColor[
             0.1809198934930053, 0.30748865741789405`, 0.933614492336205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 251}], {
             RGBColor[
             0.1819264333571092, 0.30854659463338063`, 0.9336718132924233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 260}], {
             RGBColor[
             0.1839290162486566, 0.31065143622348573`, 0.9337858574255411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 352}], {
             RGBColor[
             0.1830449444132805, 0.30972222067111355`, 0.9337355108423835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 396}], {
             RGBColor[
             0.18205118127193512`, 0.30867771260133725`, 0.9336789175016247]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 256}], {
             RGBColor[
             0.6811078585940378, 0.7429531062730206, 0.8609992027595657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 316}], {
             RGBColor[
             0.5410265117385101, 0.6349350710702945, 0.9583673358965574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 351}], {
             RGBColor[
             0.33973329445254913`, 0.4686816369880935, 0.9428684830015278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 399}], {
             RGBColor[
             0.36464378874039466`, 0.49025785510237774`, 0.9444557576700642]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 223}], {
             RGBColor[
             0.9051519086820443, 0.7083288764559916, 0.5859596439831081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 224}], {
             RGBColor[
             0.724417520241849, 0.7830873105778803, 0.9606419773233753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 247}], {
             RGBColor[
             0.8842131182088144, 0.5486602398250497, 0.5659586027648067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 259}], {
             RGBColor[
             0.9232560562805229, 0.9412465076079086, 0.9787839457914527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 292}], {
             RGBColor[
             0.8852896880649895, 0.5569352274955306, 0.5669895272748917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 363}], {
             RGBColor[
             0.6628066494410058, 0.7309294373629389, 0.9563828644799877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 383}], {
             RGBColor[
             0.6547025238599551, 0.723910051109828, 0.9558664767641599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 393}], {
             RGBColor[
             0.8365296253571944, 0.8728854021704904, 0.9703016768071477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 247}], {
             RGBColor[
             0.8382775353615486, 0.29394740449482404`, 0.18423794894565387`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 292}], {
             RGBColor[
             0.8393541052177236, 0.30222239216530483`, 0.1852688734557389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 319}], {
             RGBColor[
             0.845830354553812, 0.35200168247303465`, 0.19147053713385456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 385}], {
             RGBColor[
             0.9268169546976089, 0.7220420708837272, 0.4190027976388401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 393}], {
             RGBColor[
             0.7905940425099285, 0.6181725668402647, 0.5885810229879949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 400}], {
             RGBColor[
             0.8406657720719041, 0.3123044383826159, 0.18652492711661786`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 227}], {
             RGBColor[
             0.3858696957004528, 0.504223043119987, 0.9462592294929938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 259}], {
             RGBColor[
             0.6965860849930616, 0.7612921063995717, 0.9717456253125671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 363}], {
             RGBColor[
             0.4361366781535445, 0.5509750361546019, 0.9493445440011021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 383}], {
             RGBColor[
             0.42803255257249384`, 0.5439556499014909, 0.9488281562852744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 393}], {
             RGBColor[
             0.6098596540697332, 0.6929310009621534, 0.9632633563282622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 235}], {
             RGBColor[
             0.20086558407238086`, 0.32845284284664206`, 0.9347503699076954]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 261}], {
             RGBColor[
             0.19884280647751676`, 0.32632677534293286`, 0.9346351757160992]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 322}], {
             RGBColor[
             0.2017966288426081, 0.3294314299317988, 0.9348033915300026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 327}], {
             RGBColor[
             0.19712268368204472`, 0.3245188172228074, 0.9345372172675908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 335}], {
             RGBColor[
             0.20337317791570175`, 0.3310884829666048, 0.93489317366742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 349}], {
             RGBColor[
             0.2034483891040132, 0.3311675346941849, 0.9348974568333293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 355}], {
             RGBColor[
             0.2083112643931653, 0.336278724947185, 0.9351743903870672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 252}], {
             RGBColor[
             0.19892295516503677`, 0.32641101669523676`, 0.9346397400652842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 274}], {
             RGBColor[
             0.1975222198425889, 0.324938755059595, 0.9345599702608729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 288}], {
             RGBColor[
             0.20281928004263788`, 0.3305063011828612, 0.9348616300029674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 315}], {
             RGBColor[
             0.186507225222572, 0.3133612973229612, 0.9339326826124872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 318}], {
             RGBColor[
             0.20268055409019498`, 0.33036049141111024`, 0.9348537297652024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 322}], {
             RGBColor[
             0.1935079091107788, 0.32071945995846174`, 0.9343313612033369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 243}], {
             RGBColor[
             0.2526928974888643, 0.38292663528882953`, 0.9377018587351249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 306}], {
             RGBColor[
             0.248145898473511, 0.3781474510273044, 0.9374429138678827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 311}], {
             RGBColor[
             0.23829401063491945`, 0.3677924922631779, 0.9368818634300369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 346}], {
             RGBColor[
             0.23870901568862182`, 0.3682286888874592, 0.9369054973539003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 350}], {
             RGBColor[
             0.3112685553301875, 0.44081365131394507`, 0.9411723881594869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 363}], {
             RGBColor[
             0.3242588248996095, 0.45206516990504564`, 0.9420001166496061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 383}], {
             RGBColor[
             0.3161546993185588, 0.44504578365193476`, 0.9414837289337784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 276}], {
             RGBColor[
             0.3015266164865197, 0.4277543234766833, 0.9407208506945814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 282}], {
             RGBColor[
             0.26951575842165965`, 0.40002812713340913`, 0.938681147124779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 301}], {
             RGBColor[
             0.2369380396545014, 0.36636728078923275`, 0.9368046428886814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 305}], {
             RGBColor[
             0.26103370837156087`, 0.39169335636449776`, 0.9381768555757705]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 382}], {
             RGBColor[
             0.27305197131929326`, 0.4030910170101112, 0.9389064714836659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 294}], {
             RGBColor[
             0.20382733943636777`, 0.33156583552032837`, 0.9349190374941501]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 307}], {
             RGBColor[
             0.18847585942484443`, 0.31543045668816716`, 0.9340447934179733]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[
             0.2301303447827652, 0.3592119618462532, 0.9364169547368181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 340}], {
             RGBColor[
             0.23465687622616624`, 0.36396963339193744`, 0.9366747340061166]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 343}], {
             RGBColor[
             0.1993208104479567, 0.32682918782306747`, 0.9346623973350723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 258}], {
             RGBColor[
             0.22938899732612533`, 0.3584327586651811, 0.9363747360958877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 264}], {
             RGBColor[
             0.2405521506109405, 0.3701659405523198, 0.9370104611610526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 279}], {
             RGBColor[
             0.2100811442778375, 0.33813898092284156`, 0.9352751824281966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 299}], {
             RGBColor[
             0.20475753633962784`, 0.33254353144354476`, 0.9349720108316877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 300}], {
             RGBColor[
             0.2086431877242838, 0.3366275974133453, 0.9351932929297377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 328}], {
             RGBColor[
             0.2262385122205931, 0.35512139906697393`, 0.9361953206298528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 331}], {
             RGBColor[
             0.21608777115484973`, 0.34445232661272185`, 0.9356172509428343]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 369}], {
             RGBColor[
             0.1858060573218873, 0.312624325402729, 0.9338927521378282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 372}], {
             RGBColor[
             0.18557674124721385`, 0.3123832996687683, 0.9338796929266182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 392}], {
             RGBColor[
             0.1971344084334818, 0.32453114067996, 0.9345378849748398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 277}], {
             RGBColor[
             0.18773724237763328`, 0.31465412334052256`, 0.9340027302698206]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 373}], {
             RGBColor[
             0.19417254912152382`, 0.3214180387503654, 0.934369211468702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 390}], {
             RGBColor[
             0.20167142330655186`, 0.3292998309749142, 0.9347962612599492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 256}], {
             RGBColor[
             0.9813174831621745, 0.9842395002462874, 0.8561565043579783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 257}], {
             RGBColor[
             0.9698756400386146, 0.9770538821816868, 0.9358768631099392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 310}], {
             RGBColor[
             0.8984238517661913, 0.5911089815660195, 0.5540658742241997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 316}], {
             RGBColor[
             0.8412361363066468, 0.8762214650435611, 0.9535246374949702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 389}], {
             RGBColor[
             0.9817271461205633, 0.9825466050438816, 0.7139976792857294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 298}], {
             RGBColor[
             0.22620097648238727`, 0.3550819466262163, 0.936193183025091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 365}], {
             RGBColor[
             0.27647661087306347`, 0.4079248260301478, 0.9390563060275041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 261}], {
             RGBColor[
             0.19122633777104836`, 0.31832138382042696`, 0.9342014290908216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 322}], {
             RGBColor[
             0.1941801601361397, 0.32142603840929285`, 0.934369644904725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 327}], {
             RGBColor[
             0.1895062149755763, 0.31651342570030144`, 0.934103470642313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 335}], {
             RGBColor[
             0.19575670920923333`, 0.32308309144409886`, 0.9344594270421422]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 349}], {
             RGBColor[
             0.19583192039754477`, 0.3231621431716789, 0.9344637102080516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 355}], {
             RGBColor[
             0.2006947956866969, 0.3282733334246791, 0.9347406437617896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 262}], {
             RGBColor[
             0.4369845815472029, 0.5513866495573997, 0.9494877616771007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 284}], {
             RGBColor[
             0.6247504035752902, 0.7047458827568778, 0.9646230139836673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 334}], {
             RGBColor[
             0.7349237676396162, 0.7451154652166593, 0.6272347577119612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 366}], {
             RGBColor[
             0.7514680031030527, 0.8004311372612268, 0.7333352246803804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 376}], {
             RGBColor[
             0.397907468442853, 0.5154535439144465, 0.9470741986312354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 397}], {
             RGBColor[
             0.4369077612514729, 0.5513201116783387, 0.9494828667557864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 307}], {
             RGBColor[
             0.1806275543927051, 0.307181390488109, 0.9335978440569198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 324}], {
             RGBColor[
             0.18395646599811732`, 0.31068028765058353`, 0.9337874206481647]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 269}], {
             RGBColor[
             0.4302703250067166, 0.5456389418366184, 0.9490411897361934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 309}], {
             RGBColor[
             0.6022520031590326, 0.6871316854403461, 0.9624067531432969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 323}], {
             RGBColor[
             0.4638795886223883, 0.5747495967298069, 0.9511827422942791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 362}], {
             RGBColor[
             0.6492041088152176, 0.7238110272281775, 0.9670865002427318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 365}], {
             RGBColor[
             0.4065771465503478, 0.524864785093759, 0.9475407198960643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 377}], {
             RGBColor[
             0.3809157120608543, 0.4978929904163819, 0.9460793391645779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 385}], {
             RGBColor[
             0.750777447641219, 0.8006120212149852, 0.7940547292395577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 388}], {
             RGBColor[
             0.38895939974165, 0.5063474161681534, 0.9465374152784297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 272}], {
             RGBColor[
             0.18799208314490007`, 0.3149219771447579, 0.9340172430745133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 342}], {
             RGBColor[
             0.18286346184170274`, 0.30953147098172573`, 0.9337251756784115]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 374}], {
             RGBColor[
             0.18148468566837106`, 0.3080822898040957, 0.933646656415057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 242}], {
             RGBColor[
             0.31065498243158685`, 0.4409219663646659, 0.9411098670507269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 255}], {
             RGBColor[
             0.32755009808125596`, 0.4555556663672059, 0.9421864088801596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 312}], {
             RGBColor[
             0.41436397282412324`, 0.5281836244089898, 0.9484270661099586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 331}], {
             RGBColor[
             0.26094013118712034`, 0.3915950008105146, 0.9381715264935517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 359}], {
             RGBColor[
             0.3033005319170658, 0.43455191097441853`, 0.9406412479672268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 360}], {
             RGBColor[
             0.4718334584098283, 0.5745274932673213, 0.9531648972863125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 380}], {
             RGBColor[
             0.5006467932710101, 0.5970366894503322, 0.9560367412293518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 392}], {
             RGBColor[
             0.24198676846575243`, 0.37167381487775275`, 0.9370921605255572]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 255}], {
             RGBColor[
             0.3572936731332409, 0.48389155439101317`, 0.9439874148030284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 312}], {
             RGBColor[
             0.4441075478761082, 0.5565195124327971, 0.9502280720328274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 331}], {
             RGBColor[
             0.2906837062391053, 0.4199308888343219, 0.9399725324164205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 380}], {
             RGBColor[
             0.5303903683229951, 0.6253725774741394, 0.9578377471522206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 267}], {
             RGBColor[
             0.2144789920516021, 0.342761397772722, 0.9355256333528797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 275}], {
             RGBColor[
             0.21276908993785693`, 0.3409641822371201, 0.9354282569570754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 311}], {
             RGBColor[
             0.21699506567726595`, 0.34540595068157653`, 0.9356689200236639]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 326}], {
             RGBColor[
             0.23648276332684243`, 0.36588875650267677`, 0.9367787155753422]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 344}], {
             RGBColor[
             0.2114782278514492, 0.3396074043389222, 0.9353547442709138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 346}], {
             RGBColor[
             0.21741007073096835`, 0.3458421473058579, 0.9356925539475274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 363}], {
             RGBColor[
             0.302959879941956, 0.42967862832344433`, 0.9407871732432331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 383}], {
             RGBColor[
             0.29485575436090533`, 0.42265924207033345`, 0.9402707855274055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 302}], {
             RGBColor[
             0.18853043849765405`, 0.3154878227542032, 0.9340479016154273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 352}], {
             RGBColor[
             0.1906398234149592, 0.3177049200450192, 0.9341680279659126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 396}], {
             RGBColor[
             0.1896460602736138, 0.31666041197524286`, 0.9341114346251538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 248}], {
             RGBColor[
             0.19980719089443424`, 0.32734040451061686`, 0.9346900959819637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 251}], {
             RGBColor[
             0.20081373075853814`, 0.3283983417261034, 0.9347474169381822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 260}], {
             RGBColor[
             0.20281631365008554`, 0.33050318331620854`, 0.9348614610713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 326}], {
             RGBColor[
             0.22913658446266597`, 0.35816745674178546`, 0.9363603615567251]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 271}], {
             RGBColor[
             0.8186707488403941, 0.14451713392738777`, 0.16551243621614334`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 287}], {
             RGBColor[
             0.8173288724441594, 0.1342028839319411, 0.1642274538636763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 292}], {
             RGBColor[
             0.8184153147444937, 0.14255375553436297`, 0.16526783223743757`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 319}], {
             RGBColor[
             0.8248915640805821, 0.1923330458420928, 0.17146949591555327`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 362}], {
             RGBColor[
             0.8043048253983777, 0.4855724402659776, 0.5720335274237128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 385}], {
             RGBColor[
             0.9058781642243791, 0.5623734342527853, 0.3990017564205388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 393}], {
             RGBColor[
             0.7696552520366986, 0.45850393020932284`, 0.5685799817696936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 400}], {
             RGBColor[
             0.8197269815986742, 0.15263580175167407`, 0.16652388589831657`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 251}], {
             RGBColor[
             0.1839193268501145, 0.3106412520512747, 0.9337853056286283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 260}], {
             RGBColor[
             0.1859219097416619, 0.3127460936413798, 0.933899349761746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 275}], {
             RGBColor[
             0.18852850716525682`, 0.3154857928014001, 0.9340477916289045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 268}], {
             RGBColor[
             0.18564105657677243`, 0.3124508991579618, 0.9338833555894905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 279}], {
             RGBColor[
             0.19132944320701362`, 0.3184297541708887, 0.934207300792869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 299}], {
             RGBColor[
             0.186005835268804, 0.3128343046915919, 0.9339041291963601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 300}], {
             RGBColor[
             0.18989148665345995`, 0.3169183706613924, 0.9341254112944102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 370}], {
             RGBColor[
             0.18458433002004276`, 0.31134021254650546`, 0.9338231765753717]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 265}], {
             RGBColor[
             0.19635832810443649`, 0.32371543104779843`, 0.9344936883482087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 321}], {
             RGBColor[
             0.18913677562513462`, 0.3161251215191795, 0.934082431617842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 325}], {
             RGBColor[
             0.21599606078555122`, 0.34435593319981583`, 0.9356120281729761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 375}], {
             RGBColor[
             0.19825790374427554`, 0.32571200548532114`, 0.9346018663707272]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 381}], {
             RGBColor[
             0.19153445496524343`, 0.31864523452728444`, 0.9342189759092124]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 260}], {
             RGBColor[
             0.1869284496057658, 0.31380403085686637`, 0.9339566707179645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 275}], {
             RGBColor[
             0.1895350470293607, 0.3165437300168866, 0.9341051125851229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 274}], {
             RGBColor[
             0.20454056169243495`, 0.3323154773323579, 0.9349596544465153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 288}], {
             RGBColor[
             0.20983762189248398`, 0.33788302345562404`, 0.9352613141886098]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 318}], {
             RGBColor[
             0.20969889594004104`, 0.3377372136838731, 0.9352534139508448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 283}], {
             RGBColor[
             0.878557469851581, 0.4812239884723157, 0.21791952880036536`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 332}], {
             RGBColor[
             0.8214986576269006, 0.1662536800580077, 0.16822044486376803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 334}], {
             RGBColor[
             0.8927019922159016, 0.5360459310419723, 0.23584376702104354`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 364}], {
             RGBColor[
             0.8732653702236979, 0.4602425769354192, 0.2136613812182268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 366}], {
             RGBColor[
             0.9092462276793383, 0.5913616030865398, 0.3419442339894627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 391}], {
             RGBColor[
             0.8227133050515791, 0.17558999242598253`, 0.16938359260938823`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 314}], {
             RGBColor[
             0.1849157269952969, 0.31168853177927935`, 0.9338420491428545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 369}], {
             RGBColor[
             0.1837415562121556, 0.31045440383947037`, 0.9337751818537847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 312}], {
             RGBColor[
             0.46100266352577723`, 0.571153212435337, 0.9513046138622602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 331}], {
             RGBColor[
             0.30757882188877433`, 0.4345645888368619, 0.9410490742458533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 356}], {
             RGBColor[
             0.6597861746771188, 0.7286564919053182, 0.9611997608615672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 359}], {
             RGBColor[
             0.3499392226187198, 0.4775214990007658, 0.9435187957195283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 360}], {
             RGBColor[
             0.5184721491114823, 0.6174970812936685, 0.956042445038614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 380}], {
             RGBColor[
             0.5472854839726642, 0.6400062774766795, 0.9589142889816533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 310}], {
             RGBColor[
             0.9094103197175858, 0.5979549815728277, 0.4751163468578484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 316}], {
             RGBColor[
             0.8522226042580414, 0.8830674650503693, 0.8745751101286188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 319}], {
             RGBColor[
             0.9123741671932073, 0.6207364120366994, 0.4779545305476905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 384}], {
             RGBColor[
             0.9629443447193516, 0.8827390749129462, 0.5213129511813582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 310}], {
             RGBColor[
             0.8979684765940259, 0.5907693635082272, 0.5548367056098094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 356}], {
             RGBColor[
             0.9574019127188883, 0.9677509967704889, 0.9569916297931109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 360}], {
             RGBColor[
             0.816087887153252, 0.8565915861588391, 0.9518343139701578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 389}], {
             RGBColor[
             0.981271770948398, 0.982206986986089, 0.7147685106713391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 264}], {
             RGBColor[
             0.24881577416889822`, 0.37885153285572853`, 0.9374810622977428]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 279}], {
             RGBColor[
             0.2183447678357952, 0.34682457322625027`, 0.9357457835648868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 281}], {
             RGBColor[
             0.318201913769557, 0.44345916858997797`, 0.9417371947060786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 300}], {
             RGBColor[
             0.21690681128224154`, 0.345313189716754, 0.9356638940664279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 328}], {
             RGBColor[
             0.23450213577855084`, 0.36380699137038264`, 0.936665921766543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 394}], {
             RGBColor[
             0.29763886748570073`, 0.42564849142765915`, 0.9404269355800592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 271}], {
             RGBColor[
             0.8577136869121025, 0.5371034017102467, 0.5783377792427893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 287}], {
             RGBColor[
             0.8563718105158677, 0.5267891517148, 0.5770527968903222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 292}], {
             RGBColor[
             0.8574582528162021, 0.5351400233172219, 0.5780931752640834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 345}], {
             RGBColor[
             0.8617541752858404, 0.8926034039517254, 0.9866760766074392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 350}], {
             RGBColor[
             0.6219849446227963, 0.6978827145935297, 0.9666587839790601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 353}], {
             RGBColor[
             0.9443422105725244, 0.9537215111738743, 0.7488183078429457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 393}], {
             RGBColor[
             0.808698190108407, 0.8510901979921818, 0.9814053247963395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 400}], {
             RGBColor[
             0.8587699196703826, 0.545222069534533, 0.5793492289249624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 327}], {
             RGBColor[
             0.1874834373807122, 0.31438735819659225`, 0.9339882764507168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 335}], {
             RGBColor[
             0.19373393161436922`, 0.3209570239403897, 0.934344232850546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 349}], {
             RGBColor[
             0.19380914280268063`, 0.32103607566796977`, 0.9343485160164554]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 355}], {
             RGBColor[
             0.19867201809183277`, 0.32614726592096993`, 0.9346254495701933]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 284}], {
             RGBColor[
             0.5520990373737982, 0.6433480852372535, 0.9595712205145508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 325}], {
             RGBColor[
             0.3013026030921642, 0.42887910004945207`, 0.9406582888215985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 376}], {
             RGBColor[
             0.3252561022413611, 0.4540557463948223, 0.9420224051621189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 397}], {
             RGBColor[
             0.364256395049981, 0.48992231415871446`, 0.9444310732866698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 336}], {
             RGBColor[
             0.2683165494931898, 0.3993480841421268, 0.9385916026036494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 359}], {
             RGBColor[
             0.31376085658735253`, 0.4455463754257799, 0.941236947982536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 360}], {
             RGBColor[
             0.48229378308011506`, 0.5855219577186828, 0.9537605973016217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 279}], {
             RGBColor[
             0.22950792112061041`, 0.35855775511338905`, 0.9363815086300517]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 281}], {
             RGBColor[
             0.3293650670543722, 0.4551923504771167, 0.9423729197712435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 328}], {
             RGBColor[
             0.24566528906336602`, 0.3755401732575213, 0.9373016468317077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 394}], {
             RGBColor[
             0.30880202077051594`, 0.4373816733147978, 0.941062660645224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 321}], {
             RGBColor[
             0.19177497299708612`, 0.31889803422847507`, 0.9342326730553113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 325}], {
             RGBColor[
             0.2186342581575027, 0.34712884590911136`, 0.9357622696104455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 375}], {
             RGBColor[
             0.20089610111622702`, 0.32848491819461667`, 0.9347521078081966]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 381}], {
             RGBColor[
             0.19417265233719494`, 0.3214181472365799, 0.9343692173466818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 358}], {
             RGBColor[
             0.4679094050103473, 0.5710147999295367, 0.9528445815300333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 384}], {
             RGBColor[
             0.7959032258697958, 0.7536598609266292, 0.6159939861993788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 275}], {
             RGBColor[
             0.19585412945824818`, 0.323185486302614, 0.9344649749812033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 306}], {
             RGBColor[
             0.20993199303624877`, 0.33798221351119695`, 0.9352666884856375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 311}], {
             RGBColor[
             0.20008010519765723`, 0.3276272547470704, 0.9347056380477918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 317}], {
             RGBColor[
             0.1930340826347562, 0.32022143828982824`, 0.9343043774864909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 344}], {
             RGBColor[
             0.1945632673718405, 0.321828708404416, 0.9343914622950418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 346}], {
             RGBColor[
             0.20049511025135958`, 0.32806345137135173`, 0.9347292719716551]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 354}], {
             RGBColor[
             0.19683262012965425`, 0.3242139420381536, 0.9345206985773926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 279}], {
             RGBColor[
             0.19334852815726622`, 0.3205519404709839, 0.9343222846938173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 299}], {
             RGBColor[
             0.18802492021905656`, 0.3149564909916871, 0.9340191130973085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 300}], {
             RGBColor[
             0.1919105716037125, 0.31904055696148764`, 0.9342403951953585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 370}], {
             RGBColor[
             0.18660341497029534`, 0.3134623988466007, 0.9339381604763201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 371}], {
             RGBColor[
             0.1838466718007321, 0.3105648869877775, 0.9337811680310495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 309}], {
             RGBColor[
             0.5253850164437505, 0.6220146854886827, 0.9571050895141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 323}], {
             RGBColor[
             0.38701260190710624`, 0.5096325967781434, 0.9458810786650822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 362}], {
             RGBColor[
             0.5723371220999356, 0.658694027276514, 0.9617848366135348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 365}], {
             RGBColor[
             0.3297101598350657, 0.4597477851420956, 0.9422390562668672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 377}], {
             RGBColor[
             0.30404872534557215`, 0.4327759904647185, 0.9407776755353809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 388}], {
             RGBColor[
             0.3120924130263679, 0.44123041621648995`, 0.9412357516492327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 336}], {
             RGBColor[
             0.2213730230293102, 0.3500074614371033, 0.9359182382182554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 357}], {
             RGBColor[
             0.1969743042117703, 0.32436286099174727`, 0.9345287672762663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 287}], {
             RGBColor[
             0.8186608763962349, 0.14444124999544666`, 0.16550298235246705`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 292}], {
             RGBColor[
             0.8197473186965691, 0.15279212159786854`, 0.16654336072622833`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 303}], {
             RGBColor[
             0.8569664054518005, 0.38299924589270967`, 0.19999647199586007`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 333}], {
             RGBColor[
             0.8868896427416582, 0.5599013471362418, 0.5649582086174862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 337}], {
             RGBColor[
             0.8884909872626653, 0.561095627258048, 0.562247550040962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 345}], {
             RGBColor[
             0.8240432411662075, 0.5102555022323721, 0.5751262620695841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 353}], {
             RGBColor[
             0.9066312764528914, 0.571373609454521, 0.33726849330509057`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 385}], {
             RGBColor[
             0.9072101681764545, 0.5726118003162909, 0.40027728490932957`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 391}], {
             RGBColor[
             0.820118482997181, 0.15564505305760412`, 0.1668987880796643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 400}], {
             RGBColor[
             0.8210589855507496, 0.16287416781517963`, 0.16779941438710733`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 308}], {
             RGBColor[
             0.20474955864050876`, 0.33253514637595527`, 0.9349715565135248]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 342}], {
             RGBColor[
             0.19152273141080622`, 0.31863291232825464`, 0.9342183082701306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 348}], {
             RGBColor[
             0.1988777254844435, 0.3263634774332058, 0.9346371643018856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 374}], {
             RGBColor[
             0.19014395523747457`, 0.3171837311506246, 0.934139789006776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 375}], {
             RGBColor[
             0.1997235147350348, 0.3272524555617131, 0.9346853307484737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 378}], {
             RGBColor[
             0.2184441934159871, 0.34692907581497784`, 0.9357514457045917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 281}], {
             RGBColor[
             0.46139853851670076`, 0.5721415288193888, 0.9511515046102453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 293}], {
             RGBColor[
             0.4190878106551068, 0.5354941029446921, 0.9484555024448121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 394}], {
             RGBColor[
             0.4408354922328445, 0.55433085165707, 0.9498412454842259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 288}], {
             RGBColor[
             0.20843688657003606`, 0.3364107618199823, 0.9351815443841986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 318}], {
             RGBColor[
             0.20829816061759315`, 0.33626495204823137`, 0.9351736441464337]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 311}], {
             RGBColor[
             0.19837020308391207`, 0.32583003921146847`, 0.9346082616519875]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 317}], {
             RGBColor[
             0.19132418052101102`, 0.3184242227542263, 0.9342070010906866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 344}], {
             RGBColor[
             0.19285336525809532`, 0.32003149286881416`, 0.9342940858992375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 346}], {
             RGBColor[
             0.1987852081376144, 0.3262662358357499, 0.9346318955758508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 282}], {
             RGBColor[
             0.3470343998180849, 0.475005487491495, 0.9433337029793059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 301}], {
             RGBColor[
             0.3144566810509267, 0.44134464114731864`, 0.9414571987432081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 305}], {
             RGBColor[
             0.33855234976798615`, 0.46667071672258365`, 0.9428294114302973]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 339}], {
             RGBColor[
             0.38050139833268903`, 0.5039929195045905, 0.9454661905309516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 361}], {
             RGBColor[
             0.3943096577609078, 0.5159529397980152, 0.9463460406115533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 382}], {
             RGBColor[
             0.35057061271571854`, 0.4780683773681971, 0.9435590273381926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 373}], {
             RGBColor[
             0.19154984531155025`, 0.31866141075705723`, 0.9342198523666666]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 390}], {
             RGBColor[
             0.19904871949657826`, 0.326543202981606, 0.9346469021579138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 296}], {
             RGBColor[
             0.1835851599868279, 0.3102900214905575, 0.9337662753201197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 302}], {
             RGBColor[
             0.19139766926121787`, 0.31850146407963903`, 0.9342111861657245]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 330}], {
             RGBColor[
             0.18839714683821507`, 0.31534772476895345`, 0.9340403108526096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 367}], {
             RGBColor[
             0.18709347932173553`, 0.31397748755183885`, 0.9339660689161493]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 299}], {
             RGBColor[
             0.19371330684929777`, 0.320935346004614, 0.9343430583006869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 300}], {
             RGBColor[
             0.1975989582339537, 0.32501941197441453`, 0.9345643403987369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 328}], {
             RGBColor[
             0.215194282730263, 0.3435132136280431, 0.9355663680988517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 370}], {
             RGBColor[
             0.19229180160053655`, 0.3194412538595276, 0.9342621056796985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 371}], {
             RGBColor[
             0.1895350584309733, 0.3165437420007044, 0.9341051132344278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 291}], {
             RGBColor[
             0.20219476439486456`, 0.32984989564047235`, 0.9348260647607148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 336}], {
             RGBColor[
             0.22186501043454393`, 0.3505245713938071, 0.9359462561731533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 368}], {
             RGBColor[
             0.19638103924398845`, 0.323739301895437, 0.934494981714008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 387}], {
             RGBColor[
             0.19723551682458454`, 0.32463741200965124`, 0.9345436429481366]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 392}], {
             RGBColor[
             0.20599555407739328`, 0.33384476658079454`, 0.9350425141103704]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 293}], {
             RGBColor[
             0.356440478793437, 0.4831525603366694, 0.9439330500141462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 394}], {
             RGBColor[
             0.3781881603711747, 0.5019893090490473, 0.9453187930535599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 301}], {
             RGBColor[
             0.2824458229860667, 0.41361844480404447`, 0.9394174951734057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 305}], {
             RGBColor[
             0.30654149170312617`, 0.4389445203793095, 0.9407897078604948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 313}], {
             RGBColor[
             0.2998205585054363, 0.43188039345676055`, 0.940406960657616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 339}], {
             RGBColor[
             0.34849054026782905`, 0.4762667231613163, 0.9434264869611491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 340}], {
             RGBColor[
             0.29320777122887487`, 0.42492993475416496`, 0.9400303722049579]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 361}], {
             RGBColor[
             0.36229879969604784`, 0.48822674345474093`, 0.9443063370417508]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 382}], {
             RGBColor[
             0.3185597546508585, 0.45034218102492296`, 0.9415193237683902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 312}], {
             RGBColor[
             0.7398695405352704, 0.7057918843470511, 0.6108133774642039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 332}], {
             RGBColor[
             0.8748637305772158, 0.45283228980267326`, 0.21438239989975133`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 334}], {
             RGBColor[
             0.9460670651662169, 0.8226245407866379, 0.2820057220570269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 356}], {
             RGBColor[
             0.9386530516866118, 0.8632951638170323, 0.6207085244635109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 360}], {
             RGBColor[
             0.7973390261209754, 0.7521357532053826, 0.6155512086405578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 364}], {
             RGBColor[
             0.9266304431740131, 0.7468211866800847, 0.25982333625421017`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 366}], {
             RGBColor[
             0.9626113006296535, 0.8779402128312055, 0.388106189025446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 380}], {
             RGBColor[
             0.8261523609821573, 0.7746449493883936, 0.6184230525835972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 389}], {
             RGBColor[
             0.9625229099161214, 0.8777511540326326, 0.378485405341739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 334}], {
             RGBColor[
             0.8500382234662116, 0.8370769008965131, 0.6373182165494112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 366}], {
             RGBColor[
             0.8665824589296481, 0.8923925729410807, 0.7434186835178305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 397}], {
             RGBColor[
             0.5520222170780682, 0.6432815473581924, 0.9595663255932364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 324}], {
             RGBColor[
             0.1849819453905557, 0.31175813151118514`, 0.9338458201825032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 290}], {
             RGBColor[
             0.28938656912218486`, 0.4203385400712017, 0.9398338164907357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 304}], {
             RGBColor[
             0.3017569575169641, 0.43334060260203944`, 0.9405382918094687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 386}], {
             RGBColor[
             0.331585149915525, 0.4616241237277755, 0.94234929043675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 292}], {
             RGBColor[
             0.8184054423003344, 0.14247787160242187`, 0.16525837837376128`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 303}], {
             RGBColor[
             0.8556245290555657, 0.372684995897263, 0.19871148964339302`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 353}], {
             RGBColor[
             0.9052894000566567, 0.5610593594590743, 0.33598351095262347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 385}], {
             RGBColor[
             0.9058682917802197, 0.5622975503208443, 0.39899230255686247`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 391}], {
             RGBColor[
             0.8187766066009462, 0.14533080306215745`, 0.16561380572719725`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 400}], {
             RGBColor[
             0.8197171091545148, 0.15255991781973297`, 0.16651443203464028`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 318}], {
             RGBColor[
             0.21359522081764215`, 0.3418324981714975, 0.9354753038885282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 304}], {
             RGBColor[
             0.2699001201696922, 0.4010125173273108, 0.9386817846109934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 338}], {
             RGBColor[
             0.2338329245191738, 0.3631036079063329, 0.9366278111753308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 336}], {
             RGBColor[
             0.21513079622652476`, 0.34344648528733734`, 0.9355627526363838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 368}], {
             RGBColor[
             0.1896468250359693, 0.3166612157889672, 0.9341114781772385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 387}], {
             RGBColor[
             0.1905013026165654, 0.3175593259031815, 0.9341601394113672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 303}], {
             RGBColor[
             0.8567109713559, 0.3810358674996849, 0.1997518680171543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 309}], {
             RGBColor[
             0.7584292895983676, 0.45716808614862703`, 0.568384704834363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 362}], {
             RGBColor[
             0.8053813952545528, 0.4938474279364584, 0.5730644519337977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 385}], {
             RGBColor[
             0.9069547340805542, 0.5706484219232661, 0.4000326809306238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 400}], {
             RGBColor[
             0.8208035514548493, 0.16091078942215484`, 0.1675548104084016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 394}], {
             RGBColor[
             0.3358774325095808, 0.4653418831743506, 0.9426227908881267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 301}], {
             RGBColor[
             0.22980051567191817`, 0.3588652905383795, 0.9363981714568937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 313}], {
             RGBColor[
             0.24717525119128783`, 0.3771272391910956, 0.937387636941104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 329}], {
             RGBColor[
             0.23603593247132534`, 0.36541910894281576`, 0.9367532692191475]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 340}], {
             RGBColor[
             0.24056246391472638`, 0.3701767804885, 0.937011048488446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 343}], {
             RGBColor[
             0.20522639813651683`, 0.33303633491963003`, 0.9349987118174017]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 330}], {
             RGBColor[
             0.18388840354746627`, 0.31060874969954066`, 0.9337835445922895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 367}], {
             RGBColor[
             0.18258473603098674`, 0.3092385124824261, 0.9337093026558292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 398}], {
             RGBColor[
             0.17994179284220208`, 0.3064606116187368, 0.933558790951112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 325}], {
             RGBColor[
             0.267416015836295, 0.3984015661715987, 0.9385403185441094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 375}], {
             RGBColor[
             0.2496778587950193, 0.3797576384571041, 0.9375301567418605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 376}], {
             RGBColor[
             0.2913695149854919, 0.423578212516969, 0.9399044348846297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 378}], {
             RGBColor[
             0.2683985374759716, 0.3994342587103688, 0.9385962716979784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 397}], {
             RGBColor[
             0.33036980779411174`, 0.4594447802808611, 0.9423131030091806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 320}], {
             RGBColor[
             0.19458686072830475`, 0.3218535065179652, 0.9343928059017892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 347}], {
             RGBColor[
             0.1948950544058417, 0.32217743761366435`, 0.9344103570757931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 373}], {
             RGBColor[
             0.20172543232639267`, 0.32935659787913657`, 0.93479933699373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 390}], {
             RGBColor[
             0.2092243065114207, 0.3372383901036854, 0.935226386784977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 300}], {
             RGBColor[
             0.19227535029574405`, 0.31942396249511773`, 0.934261168802228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 370}], {
             RGBColor[
             0.1869681936623269, 0.3138458043802308, 0.9339589340831895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 371}], {
             RGBColor[
             0.18421145049276366`, 0.3109482925214076, 0.933801941637919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 370}], {
             RGBColor[
             0.19085384504698283`, 0.3179298703500313, 0.9341802161812396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 371}], {
             RGBColor[
             0.1880971018774196, 0.31503235849120814`, 0.934023223735969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 305}], {
             RGBColor[
             0.27396377293596785`, 0.4052836740351331, 0.9389132036243971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 313}], {
             RGBColor[
             0.2672428397382781, 0.39821954711258417`, 0.9385304564215183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 329}], {
             RGBColor[
             0.25610352101831557`, 0.38651141686430435`, 0.9378960886995618]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 339}], {
             RGBColor[
             0.3159128215006708, 0.4426058768171399, 0.9415499827250514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 340}], {
             RGBColor[
             0.26063005246171667`, 0.3912690884099886, 0.9381538679688604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 361}], {
             RGBColor[
             0.3297210809288895, 0.45456589711056455`, 0.9424298328056531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 382}], {
             RGBColor[
             0.2859820358837003, 0.41668133468074653`, 0.9396428195322926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 367}], {
             RGBColor[
             0.19039724530537674`, 0.31744995507150764`, 0.934154213501434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 377}], {
             RGBColor[
             0.22469777382228445`, 0.35350198532189486`, 0.9361075778573873]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 353}], {
             RGBColor[
             0.9435949291122223, 0.7996173553563373, 0.3704770005960165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 385}], {
             RGBColor[
             0.9441738208357854, 0.8008555462181073, 0.4334857922002555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 391}], {
             RGBColor[
             0.8570821356565119, 0.38388879895942046`, 0.20010729537059024`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 400}], {
             RGBColor[
             0.8580226382100805, 0.391117913716996, 0.20100792167803327`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 338}], {
             RGBColor[
             0.24620331291395298`, 0.37610567043717064`, 0.9373322864940637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 313}], {
             RGBColor[
             0.29133850845533754`, 0.4235456226878492, 0.9399026691086074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 329}], {
             RGBColor[
             0.28019918973537505`, 0.41183749243956935`, 0.9392683013866509]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 339}], {
             RGBColor[
             0.3400084902177303, 0.4679319523924049, 0.9429221954121405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 340}], {
             RGBColor[
             0.2847257211787761, 0.4165951639852536, 0.9395260806559493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 361}], {
             RGBColor[
             0.353816749645949, 0.47989197268582956`, 0.9438020454927423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 382}], {
             RGBColor[
             0.31007770460075973`, 0.44200741025601153`, 0.9410150322193817]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 308}], {
             RGBColor[
             0.2175738595337591, 0.3460142997224009, 0.9357018814775424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 311}], {
             RGBColor[
             0.21244806666191265`, 0.3406267664200514, 0.9354099751564218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 346}], {
             RGBColor[
             0.21286307171561503`, 0.3410629630443328, 0.9354336090802852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 348}], {
             RGBColor[
             0.21170202637769384`, 0.33984263077965143`, 0.9353674892659032]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 350}], {
             RGBColor[
             0.2854226113571807, 0.41364792547081863`, 0.9397004998858718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 354}], {
             RGBColor[
             0.2092005815939097, 0.33721345371113465`, 0.9352250356860227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 378}], {
             RGBColor[
             0.23126849430923743`, 0.36040822916142345`, 0.9364817706686093]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 343}], {
             RGBColor[
             0.1898749181249935, 0.3169009560874688, 0.9341244677412249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 348}], {
             RGBColor[
             0.20697593141094872`, 0.33487520531787435`, 0.9350983451491781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 354}], {
             RGBColor[
             0.20447448662716458`, 0.33224602824935756`, 0.9349558915692975]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 374}], {
             RGBColor[
             0.1982421611639798, 0.32569545903529307`, 0.9346009698540684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 378}], {
             RGBColor[
             0.22654239934249232`, 0.35544080369964637`, 0.9362126265518842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 323}], {
             RGBColor[
             0.5589942800594222, 0.6511253403818711, 0.9592466420721857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 362}], {
             RGBColor[
             0.7443188002522516, 0.8001867708802417, 0.9751504000206381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 365}], {
             RGBColor[
             0.5016918379873817, 0.6012405287458232, 0.9556046196739707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 385}], {
             RGBColor[
             0.845892139078253, 0.8769877648670494, 0.8021186290174642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 316}], {
             RGBColor[
             0.7693289728620583, 0.48993694637010154`, 0.5724844799948403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 319}], {
             RGBColor[
             0.8294805357972241, 0.22760589335643167`, 0.17586390041391192`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 384}], {
             RGBColor[
             0.8800507133233684, 0.4896085562326786, 0.2192223210475797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 317}], {
             RGBColor[
             0.19555015626042008`, 0.32286599119868276`, 0.934447664157275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 344}], {
             RGBColor[
             0.19707934099750435`, 0.3244732613132706, 0.9345347489658259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 346}], {
             RGBColor[
             0.20301118387702347`, 0.33070800428020625`, 0.9348725586424393]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 354}], {
             RGBColor[
             0.19934869375531813`, 0.32685849494700814`, 0.9346639852481768]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 356}], {
             RGBColor[
             0.746600049419986, 0.8012844499471021, 0.9674404180913663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 359}], {
             RGBColor[
             0.4367530973615871, 0.5501494570425497, 0.9497594529493274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 360}], {
             RGBColor[
             0.6052860238543496, 0.6901250393354524, 0.9622831022684131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 380}], {
             RGBColor[
             0.6340993587155315, 0.7126342355184634, 0.9651549462114524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 389}], {
             RGBColor[
             0.7704699076494956, 0.8157404401627024, 0.7252172989695943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 329}], {
             RGBColor[
             0.27347825653768526`, 0.4047733655170204, 0.9388855541837721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 339}], {
             RGBColor[
             0.3332875570200404, 0.460867825469856, 0.9425394482092617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 340}], {
             RGBColor[
             0.2780047879810863, 0.40953103706270466`, 0.9391433334530706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 358}], {
             RGBColor[
             0.28110733593194254`, 0.4127920116719563, 0.9393200189690635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 361}], {
             RGBColor[
             0.3470958164482592, 0.47282784576328063`, 0.9434192982898635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 369}], {
             RGBColor[
             0.1815795981118552, 0.30818204879999395`, 0.9336520615383029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 322}], {
             RGBColor[
             0.18811052101816012`, 0.31504646285894905`, 0.9340239879361825]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 351}], {
             RGBColor[
             0.5108480401165528, 0.6087959957654421, 0.956444390370581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 399}], {
             RGBColor[
             0.5357585344043984, 0.6303722138797264, 0.9580316650391174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 344}], {
             RGBColor[
             0.19003331843460333`, 0.31706744485602845`, 0.9341334884045249]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 346}], {
             RGBColor[
             0.19596516131412245`, 0.3233021878229641, 0.9344712980811385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 354}], {
             RGBColor[
             0.19230267119241712`, 0.319452678489766, 0.934262724686876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 322}], {
             RGBColor[
             0.20428384988578308`, 0.3320456569470981, 0.9349450350888977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 384}], {
             RGBColor[
             0.8830145607989899, 0.5123899866965502, 0.22206050473742173`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 347}], {
             RGBColor[
             0.1840162025368019, 0.3107430745402564, 0.9337908225556705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 398}], {
             RGBColor[
             0.182257588923795, 0.30889466013044303`, 0.9336906721120455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 375}], {
             RGBColor[
             0.19367454863692518`, 0.3208946086659977, 0.9343408510778299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 381}], {
             RGBColor[
             0.18695109985789307`, 0.313827837707961, 0.9339579606163151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 327}], {
             RGBColor[
             0.19043725974580353`, 0.3174920127854582, 0.9341564922646202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 335}], {
             RGBColor[
             0.19668775397946056`, 0.3240616785292556, 0.9345124486644494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 349}], {
             RGBColor[
             0.19676296516777197`, 0.32414073025683565`, 0.9345167318303588]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 355}], {
             RGBColor[
             0.2016258404569241, 0.32925192050983587`, 0.9347936653840967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 362}], {
             RGBColor[
             0.6059463857156073, 0.6878046821697024, 0.9639263891716204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 365}], {
             RGBColor[
             0.3633194234507374, 0.48885844003528395`, 0.9443806088249529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 377}], {
             RGBColor[
             0.3376579889612439, 0.46188664535790686`, 0.9429192280934666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 388}], {
             RGBColor[
             0.34570167664203966`, 0.47034107110967827`, 0.9433773042073184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 395}], {
             RGBColor[
             0.42965137086591587`, 0.5465641553634234, 0.9485979833191546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 376}], {
             RGBColor[
             0.26222548998781436`, 0.392945994406499, 0.9382447257757333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 397}], {
             RGBColor[
             0.3012257827964342, 0.4288125621703911, 0.9406533939002841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 363}], {
             RGBColor[
             0.3080486907375876, 0.43502729111889293`, 0.9410769734898234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 383}], {
             RGBColor[
             0.2999445651565369, 0.428007904865782, 0.9405605857739958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 335}], {
             RGBColor[
             0.19201380881889718`, 0.3191490658202642, 0.9342462744020376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 349}], {
             RGBColor[
             0.19208902000720862`, 0.3192281175478443, 0.934250557567947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 355}], {
             RGBColor[
             0.19695189529636073`, 0.3243393078008444, 0.9345274911216848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 339}], {
             RGBColor[
             0.322148238300078, 0.44915969522157617`, 0.9419050804873051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 340}], {
             RGBColor[
             0.2668654692611238, 0.39782290681442484`, 0.9385089657311141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 341}], {
             RGBColor[
             0.2558412218032698, 0.3862357237585604, 0.9378811511473018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 343}], {
             RGBColor[
             0.23152940348291426`, 0.3606824612455548, 0.9364966290600697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 358}], {
             RGBColor[
             0.26996801721198005`, 0.40108388142367646`, 0.9386856512471069]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 367}], {
             RGBColor[
             0.1873967228823739, 0.314296215760822, 0.9339833381883191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 398}], {
             RGBColor[
             0.18475377969358928`, 0.31151831489713266`, 0.9338328264836019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 392}], {
             RGBColor[
             0.22201549227327083`, 0.35068273734740874`, 0.9359548258912509]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 334}], {
             RGBColor[
             0.8890082529415364, 0.5076542323723299, 0.23230663812042954`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 356}], {
             RGBColor[
             0.8815942394619314, 0.5483248554027244, 0.5710094405269136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 364}], {
             RGBColor[
             0.8695716309493327, 0.4318508782657767, 0.2101242523176128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 366}], {
             RGBColor[
             0.905552488404973, 0.5629699044168974, 0.3384071050888487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 380}], {
             RGBColor[
             0.7690935487574768, 0.4596746409740855, 0.5687239686469998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 389}], {
             RGBColor[
             0.905464097691441, 0.5627808456183245, 0.32878632140514163`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 337}], {
             RGBColor[
             0.9553778772118539, 0.9662414744033965, 0.9604177939535141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 345}], {
             RGBColor[
             0.8909301311153961, 0.9154013493777207, 0.9732965059821361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 353}], {
             RGBColor[
             0.97351816640208, 0.9765194565998694, 0.7354387372176427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 391}], {
             RGBColor[
             0.8870053729463696, 0.5607909002029526, 0.5650690319922165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 364}], {
             RGBColor[
             0.9407749655383337, 0.8016431292497415, 0.27774757447488835`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 366}], {
             RGBColor[
             0.9767558229939741, 0.9327621554008622, 0.40603042724612426`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 391}], {
             RGBColor[
             0.890222900366215, 0.5169905447403047, 0.23346978586604977`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 349}], {
             RGBColor[
             0.19833951424086566`, 0.32579778329164166`, 0.9346065139677762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 355}], {
             RGBColor[
             0.20320238953001776`, 0.3309089735446419, 0.934883447521514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 359}], {
             RGBColor[
             0.2802453493603669, 0.4103194523243253, 0.9393282894277089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 345}], {
             RGBColor[
             0.8925314756364031, 0.9165956294995268, 0.9705858474056119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 353}], {
             RGBColor[
             0.9751195109230872, 0.9777137367216755, 0.7327280786411184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 391}], {
             RGBColor[
             0.8886067174673766, 0.5619851803247587, 0.5623583734156922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 340}], {
             RGBColor[
             0.326674769743479, 0.4539173667672604, 0.9421628597566036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 361}], {
             RGBColor[
             0.39576579821065194`, 0.5172141754678363, 0.9464388245933966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 382}], {
             RGBColor[
             0.3520267531654626, 0.47932961303801835`, 0.943651811320036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 343}], {
             RGBColor[
             0.2360559349263153, 0.3654401327912391, 0.9367544083293682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 358}], {
             RGBColor[
             0.2744945486553811, 0.4058415529693607, 0.9389434305164055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 361}], {
             RGBColor[
             0.34048302917169776`, 0.46587738706068504`, 0.9430427098372054]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 358}], {
             RGBColor[
             0.26347030119752707`, 0.39425436991349627`, 0.9383156159325932]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 348}], {
             RGBColor[
             0.1937491041812462, 0.3209729712701737, 0.9343450969057838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 374}], {
             RGBColor[
             0.18501533393427727`, 0.31179322498759243`, 0.9338477216106742]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 346}], {
             RGBColor[
             0.19749434605120672`, 0.3249094579375519, 0.9345583828896893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 354}], {
             RGBColor[
             0.1938318559295014, 0.32105994860435383`, 0.9343498094954268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 350}], {
             RGBColor[
             0.5883144988769012, 0.6710348151156551, 0.9634472668058549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 353}], {
             RGBColor[
             0.9106717648266294, 0.9268736116959997, 0.7456067906697404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 354}], {
             RGBColor[
             0.1997636988090205, 0.3272946915712895, 0.9346876191720402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 398}], {
             RGBColor[
             0.182565782601332, 0.30921859122614215`, 0.9337082232860494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 354}], {
             RGBColor[
             0.19860265347109932`, 0.3260743593066081, 0.9346214993576583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 374}], {
             RGBColor[
             0.19237032800791454`, 0.3195237900925436, 0.9342665776424293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 378}], {
             RGBColor[
             0.22067056618642705`, 0.3492691347568969, 0.935878234340245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 355}], {
             RGBColor[
             0.20327760071832918`, 0.33098802527222193`, 0.9348877306874234]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 355}], {
             RGBColor[
             0.2588476494190366, 0.38932088860423164`, 0.9380551008583563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 395}], {
             RGBColor[
             0.37411784951982285`, 0.4984638103693781, 0.9450594364453463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 399}], {
             RGBColor[
             0.33446531711843736`, 0.46411877979752536`, 0.9425328121440877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 396}], {
             RGBColor[
             0.18539177638104404`, 0.312188889866974, 0.9338691594511209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 391}], {
             RGBColor[
             0.9067470066576029, 0.5722631625212318, 0.3373793166798207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 400}], {
             RGBColor[
             0.9076875092111716, 0.5794922772788073, 0.33827994298726377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 374}], {
             RGBColor[
             0.18986888322413037`, 0.3168946130240269, 0.9341241240625486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 359}], {
             RGBColor[
             0.6355366085129286, 0.7076527365125309, 0.9596545999486343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 360}], {
             RGBColor[
             0.804069535005691, 0.8476283188054337, 0.97217824926772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 364}], {
             RGBColor[
             0.9333609520587287, 0.8423137522801358, 0.6164503768813724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 380}], {
             RGBColor[
             0.8328828698668729, 0.8701375149884446, 0.9750500932107594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 389}], {
             RGBColor[
             0.969253418800837, 0.9732437196326836, 0.7351124459689012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 360}], {
             RGBColor[
             0.49422258294729215`, 0.5964933259008812, 0.9544972841256812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 380}], {
             RGBColor[
             0.6915688443012366, 0.7589781043767949, 0.9698927773878063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 389}], {
             RGBColor[
             0.8279393932352007, 0.862084309021034, 0.7299551301459482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 382}], {
             RGBColor[
             0.3658350125936814, 0.49128963333144304`, 0.9445316614006376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 365}], {
             RGBColor[
             0.5486439436435668, 0.6379198705336546, 0.9602843667734056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 385}], {
             RGBColor[
             0.892844244734438, 0.9136671066548807, 0.806798376116899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 383}], {
             RGBColor[
             0.36642168177165046`, 0.49179777668654956`, 0.9445690434418867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 393}], {
             RGBColor[
             0.5482487832688899, 0.640773127747212, 0.9590042434848745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 366}], {
             RGBColor[
             0.9573192010017704, 0.856958801294309, 0.38384804144330753`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 380}], {
             RGBColor[
             0.8208602613542741, 0.753663537851497, 0.6141649050014586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 391}], {
             RGBColor[
             0.8707862783740112, 0.44118719063375156`, 0.21128740006323304`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 377}], {
             RGBColor[
             0.2803555468892034, 0.41200183372185906`, 0.9392772056952516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 388}], {
             RGBColor[
             0.2883992345699991, 0.4204562594736305, 0.9397352818091035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 372}], {
             RGBColor[
             0.1818899475322301, 0.30850824571809776`, 0.9336697354786725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 387}], {
             RGBColor[
             0.18468757746568928`, 0.3114487321581461, 0.9338290563646603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 387}], {
             RGBColor[
             0.18274442511282618`, 0.30940635583231196`, 0.9337183967128011]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 392}], {
             RGBColor[
             0.19150446236563495`, 0.31861371040345526`, 0.9342172678750348]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 390}], {
             RGBColor[
             0.20548402624046883`, 0.3333071183914488, 0.9350133833567951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 381}], {
             RGBColor[
             0.196072227977034, 0.3234147216741027, 0.9344773953692003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 397}], {
             RGBColor[
             0.32517928194563106`, 0.4539892085157613, 0.9420175102408045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 388}], {
             RGBColor[
             0.26273780008050557`, 0.39348446479625343`, 0.9382739010776171]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 389}], {
             RGBColor[
             0.8567527280963826, 0.8845935052040448, 0.7328269740889874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 393}], {
             RGBColor[
             0.5401446576878393, 0.6337537414941011, 0.9584878557690468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 400}], {
             RGBColor[
             0.9082664009347345, 0.5807304681405772, 0.40128873459150277`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 395}], {
             RGBColor[
             0.35473118198517756`, 0.4781619748017699, 0.9439526563033052]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.027885652381746694`], {
             RGBColor[
             0.1818132732838514, 0.3084276562216236, 0.9336653689936567]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.027885652381746694`], {
             RGBColor[
             0.20182540810126717`, 0.3294616787573599, 0.9348050304662081]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.027885652381746694`], {
             RGBColor[
             0.23621542372166607`, 0.36560776562732644`, 0.9367634909803209]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.027885652381746694`], {
             RGBColor[
             0.2008450066857079, 0.32843121470856707`, 0.9347491980559659]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.027885652381746694`], {
             RGBColor[
             0.18681770269069906`, 0.3136876288273712, 0.9339503638449868]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.027885652381746694`], {
             RGBColor[
             0.9261633007621113, 0.943961492267368, 0.992819476494071]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.027885652381746694`], {
             RGBColor[
             0.25494849258932906`, 0.3852974087524073, 0.9378303115392425]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.027885652381746694`], {
             RGBColor[
             0.25559866423556843`, 0.38598078037586825`, 0.937867337852653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.027885652381746694`], {
             RGBColor[
             0.6863588655876156, 0.7549080294084094, 0.9693734953996518]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.027885652381746694`], {
             RGBColor[
             0.8429670986480872, 0.3312695252776902, 0.18877864823079255`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.027885652381746694`], {
             RGBColor[
             0.873192830390407, 0.9017242770380856, 0.9877671057427206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.027885652381746694`], {
             RGBColor[
             0.242785484860208, 0.37251331644986996`, 0.9371376462426264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.027885652381746694`], {
             RGBColor[
             0.21336291477373137`, 0.3415883297902934, 0.9354620744029933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.027885652381746694`], {
             RGBColor[
             0.3386493168091526, 0.46774275003568394`, 0.9427994129046144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.027885652381746694`], {
             RGBColor[
             0.18212992963139682`, 0.3087604821200659, 0.9336834021041983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.027885652381746694`], {
             RGBColor[
             0.22895368331262583`, 0.3579752160364906, 0.9363499456068083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.027885652381746694`], {
             RGBColor[
             0.8276616884309496, 0.21362543547524793`, 0.17412217012187317`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.027885652381746694`], {
             RGBColor[
             0.9925358512363838, 0.9864432654728553, 0.42895165434603927`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.027885652381746694`], {
             RGBColor[
             0.19951285246669712`, 0.3270310361609309, 0.9346733338439388]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.027885652381746694`], {
             RGBColor[
             0.3846257063952153, 0.5075651878546001, 0.9457289877937134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.027885652381746694`], {
             RGBColor[
             0.19666790482252822`, 0.3240408158068105, 0.9345113182843263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.027885652381746694`], {
             RGBColor[
             0.24203296140503872`, 0.3717223665857442, 0.9370947911451132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.027885652381746694`], {
             RGBColor[
             0.2119196850624197, 0.340071403857656, 0.9353798846060012]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.027885652381746694`], {
             RGBColor[
             0.2601817623901309, 0.39079790712151985`, 0.9381283385124692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.027885652381746694`], {
             RGBColor[
             0.3639618362230004, 0.489667182107741, 0.9444123042586827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.027885652381746694`], {
             RGBColor[
             0.1822568035379685, 0.30889383464014303`, 0.9336906273854845]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.027885652381746694`], {
             RGBColor[
             0.20503271821821972`, 0.3328327650454837, 0.9349876820325784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.027885652381746694`], {
             RGBColor[
             0.19159599737019925`, 0.31870991949690686`, 0.9342224806581308]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.027885652381746694`], {
             RGBColor[
             0.18584110899752487`, 0.3126611669362287, 0.9338947482789014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.027885652381746694`], {
             RGBColor[
             0.20069898841488326`, 0.3282777402478373, 0.9347408825314572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.027885652381746694`], {
             RGBColor[
             0.9842583887354778, 0.9877584534482328, 0.9105427668445933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.027885652381746694`], {
             RGBColor[
             0.8215188663850046, 0.16640901342833042`, 0.16823979679335105`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.027885652381746694`], {
             RGBColor[
             0.24658940627570813`, 0.37651147904010834`, 0.9373542739398417]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.027885652381746694`], {
             RGBColor[
             0.1829376663072982, 0.30960946457990146`, 0.9337294015129516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.027885652381746694`], {
             RGBColor[
             0.19009976398754364`, 0.3171372833450601, 0.9341372723804675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.027885652381746694`], {
             RGBColor[
             0.24565388341041777`, 0.3755281851931126, 0.9373009972966455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.027885652381746694`], {
             RGBColor[
             0.2843315036737978, 0.41618081639268795`, 0.9395036305522334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.027885652381746694`], {
             RGBColor[
             0.2587257572717294, 0.3892675534260234, 0.9380454211749428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.027885652381746694`], {
             RGBColor[
             0.19817415326039348`, 0.32562397841667373`, 0.9345970969045678]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.027885652381746694`], {
             RGBColor[
             0.1934487547814754, 0.32065728500776275`, 0.934327992451794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.027885652381746694`], {
             RGBColor[
             0.19479503600678127`, 0.322072311934719, 0.9344046611759306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.027885652381746694`], {
             RGBColor[
             0.183885630512114, 0.31060583506356493`, 0.9337833866720284]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.027885652381746694`], {
             RGBColor[
             0.194697223000598, 0.3219695042635176, 0.9343990908699299]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.027885652381746694`], {
             RGBColor[
             0.22831342724773274`, 0.3573022663177088, 0.9363134839710866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.027885652381746694`], {
             RGBColor[
             0.23972125787035842`, 0.36929261960032556`, 0.9369631430486721]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.027885652381746694`], {
             RGBColor[
             0.8055364749096104, 0.8480104835941301, 0.9812520057187881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.027885652381746694`], {
             RGBColor[
             0.18100426741029385`, 0.3075773397545796, 0.9336192973059745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.027885652381746694`], {
             RGBColor[
             0.20793893985757575`, 0.3358873882535414, 0.9351531870555702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.027885652381746694`], {
             RGBColor[
             0.18369802063003998`, 0.31040864518235156`, 0.9337727025667882]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.027885652381746694`], {
             RGBColor[
             0.23112771995435683`, 0.3602602663888343, 0.9364737537773559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.027885652381746694`], {
             RGBColor[
             0.20120879960667537`, 0.3288135841343073, 0.9347699155246316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.027885652381746694`], {
             RGBColor[
             0.9889946602077696, 0.9897170234186503, 0.8320504914710569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.027885652381746694`], {
             RGBColor[
             0.40260480881009003`, 0.5231377827104023, 0.9468746003012931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.027885652381746694`], {
             RGBColor[
             0.9482538006021336, 0.8325505933258706, 0.2772219972063093]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.027885652381746694`], {
             RGBColor[
             0.8037373305687819, 0.8466049783610714, 0.9810726838248541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.027885652381746694`], {
             RGBColor[
             0.5183980864407423, 0.6198979459970778, 0.9552293428008269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.027885652381746694`], {
             RGBColor[
             0.3482989604247025, 0.47610078633028297`, 0.9434142796629524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.027885652381746694`], {
             RGBColor[
             0.19320352841391442`, 0.32039953654720643`, 0.9343140271729413]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.027885652381746694`], {
             RGBColor[
             0.21627237251575757`, 0.34464635434743823`, 0.9356277637172448]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.027885652381746694`], {
             RGBColor[
             0.7070237961498369, 0.7710516302229059, 0.9714331825533382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.027885652381746694`], {
             RGBColor[
             0.21726621743653565`, 0.3456909483725835, 0.9356843617152213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.027885652381746694`], {
             RGBColor[
             0.9918038536315829, 0.990878697092375, 0.7854948864789351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.027885652381746694`], {
             RGBColor[
             0.18932442036239164`, 0.31632234803540016`, 0.9340931177080333]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.027885652381746694`], {
             RGBColor[
             0.9925852496598342, 0.986548923705669, 0.43432836788688456`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.027885652381746694`], {
             RGBColor[
             0.3764941167365503, 0.5005220135978444, 0.9452108500911456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.027885652381746694`], {
             RGBColor[
             0.19612721011213427`, 0.3234725113841618, 0.9344805265204555]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.027885652381746694`], {
             RGBColor[
             0.17940647345367122`, 0.30589795700018124`, 0.9335283053038692]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.027885652381746694`], {
             RGBColor[
             0.8216043579673015, 0.8605890294596807, 0.9828465511894319]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.027885652381746694`], {
             RGBColor[
             0.5728179374316162, 0.6640784326178184, 0.9595134728173111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.027885652381746694`], {
             RGBColor[
             0.1969643686712329, 0.32435241810869275`, 0.934528201461931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.027885652381746694`], {
             RGBColor[
             0.9697038754518477, 0.9769257804341147, 0.9361676157519565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.027885652381746694`], {
             RGBColor[
             0.46553671991296847`, 0.576982707272407, 0.9510679023901947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.027885652381746694`], {
             RGBColor[
             0.1985117660113969, 0.3259788308238631, 0.9346163234512842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.027885652381746694`], {
             RGBColor[
             0.24853385159996577`, 0.37855521436085726`, 0.9374650072245091]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.027885652381746694`], {
             RGBColor[
             0.18190969424137163`, 0.30852900076141915`, 0.9336708600245455]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.027885652381746694`], {
             RGBColor[
             0.2829350020755027, 0.41471300466956446`, 0.9394241018521495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.027885652381746694`], {
             RGBColor[
             0.1969521059625652, 0.3243395292243824, 0.9345275031188135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.027885652381746694`], {
             RGBColor[
             0.22046571832082573`, 0.34905382666204504`, 0.9358665685573442]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.027885652381746694`], {
             RGBColor[
             0.199051197909799, 0.3265458079510415, 0.9346470432998802]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.027885652381746694`], {
             RGBColor[
             0.20310658273494972`, 0.3308082745285237, 0.9348779914662683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.027885652381746694`], {
             RGBColor[
             0.22915597848204, 0.35818784108579943`, 0.9363614660174375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.027885652381746694`], {
             RGBColor[
             0.7597586089991939, 0.8122484668202457, 0.9766892958633172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.027885652381746694`], {
             RGBColor[
             0.9509849302078126, 0.9629652217205732, 0.9678539073672795]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.027885652381746694`], {
             RGBColor[
             0.21428709115836797`, 0.3425596977667136, 0.935514704880902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.027885652381746694`], {
             RGBColor[
             0.1818888062976524, 0.30850704620819813`, 0.9336696704870515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.027885652381746694`], {
             RGBColor[
             0.2680992625939086, 0.39911970183419715`, 0.9385792284361825]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.027885652381746694`], {
             RGBColor[
             0.18684859723136407`, 0.31372010094843716`, 0.9339521232433733]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.027885652381746694`], {
             RGBColor[
             0.4303958842275222, 0.5472090154169172, 0.9486454230522088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.027885652381746694`], {
             RGBColor[
             0.23222586891438338`, 0.3614144905724877, 0.9365362917360636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.027885652381746694`], {
             RGBColor[
             0.21556902434658207`, 0.3439070908267852, 0.9355877090795206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.027885652381746694`], {
             RGBColor[
             0.5925759149291727, 0.6801188488370776, 0.961068893181775]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.027885652381746694`], {
             RGBColor[
             0.20437042968316516`, 0.3321366578036229, 0.9349499656802752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.027885652381746694`], {
             RGBColor[
             0.3425287629814334, 0.47110293132347947`, 0.9430466077842526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.027885652381746694`], {
             RGBColor[
             0.1791057270796212, 0.3055818534926332, 0.9335111782427814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.027885652381746694`], {
             RGBColor[
             0.24723118250472642`, 0.37718602654776967`, 0.9373908221466615]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.027885652381746694`], {
             RGBColor[
             0.21162927735784165`, 0.3397661669472325, 0.9353633463168451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.027885652381746694`], {
             RGBColor[
             0.2986247548964671, 0.43120392967218313`, 0.9403176100643942]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.027885652381746694`], {
             RGBColor[
             0.1932487717488401, 0.3204470901608064, 0.9343166037139339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.027885652381746694`], {
             RGBColor[
             0.9021660914511284, 0.9248267689496842, 0.9905306012474278]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.027885652381746694`], {
             RGBColor[
             0.387712192347488, 0.5102385468551641, 0.9459256559493198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.027885652381746694`], {
             RGBColor[
             0.8539737461394735, 0.41587144104017043`, 0.19931862629877445`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.027885652381746694`], {
             RGBColor[
             0.34903475823839447`, 0.4767380974142295, 0.9434611640490004]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.027885652381746694`], {
             RGBColor[
             0.19478977051563845`, 0.3220667775696765, 0.9344043613139996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.027885652381746694`], {
             RGBColor[
             0.22404918964109946`, 0.35282028222485723`, 0.936070641947763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.027885652381746694`], {
             RGBColor[
             0.9853022906708313, 0.9881901337255575, 0.8932426102441758]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.027885652381746694`], {
             RGBColor[
             0.1865190623784995, 0.31337373892436005`, 0.9339333567210057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.027885652381746694`], {
             RGBColor[
             0.2230811340648649, 0.3518027944359661, 0.9360155126148064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.027885652381746694`], {
             RGBColor[
             0.3063635945960659, 0.4393379408672382, 0.9407583255366989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.027885652381746694`], {
             RGBColor[
             0.1827503081177702, 0.3094125392435122, 0.9337187317412295]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.027885652381746694`], {
             RGBColor[
             0.8529626688242167, 0.8855932953383124, 0.985837534872859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.027885652381746694`], {
             RGBColor[
             0.8266120846200963, 0.20555772064570646`, 0.17311706832724205`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.027885652381746694`], {
             RGBColor[
             0.1804406002012431, 0.3069848897793021, 0.93358719729229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.027885652381746694`], {
             RGBColor[
             0.1856485479005117, 0.3124587730141891, 0.9338837822092951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.027885652381746694`], {
             RGBColor[
             0.18667779652152947`, 0.3135405785730105, 0.9339423963956253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.027885652381746694`], {
             RGBColor[
             0.9551078718556497, 0.8597247018622127, 0.2827369438226184]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.027885652381746694`], {
             RGBColor[
             0.24002120291967022`, 0.3696078808647668, 0.9369802244755014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.027885652381746694`], {
             RGBColor[
             0.5585316039927765, 0.6524801435401812, 0.9583888003164419]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.027885652381746694`], {
             RGBColor[
             0.3574473894517768, 0.48402469574012214`, 0.9439972094709195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.027885652381746694`], {
             RGBColor[
             0.2397898236287226, 0.36936468655968646`, 0.936967047767177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.027885652381746694`], {
             RGBColor[
             0.41254771032069193`, 0.531749824254125, 0.9475081531933861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.027885652381746694`], {
             RGBColor[
             0.24372417422141443`, 0.37349993848484087`, 0.9371911032130806]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.027885652381746694`], {
             RGBColor[
             0.18936604401309215`, 0.31636609713137825`, 0.934095488113364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.027885652381746694`], {
             RGBColor[
             0.843157812611701, 0.33273543637341757`, 0.18896127613772973`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.027885652381746694`], {
             RGBColor[
             0.22661866237074535`, 0.3555209609776956, 0.9362169696185221]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.027885652381746694`], {
             RGBColor[
             0.1925981967986741, 0.3197632946393477, 0.9342795544329613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.027885652381746694`], {
             RGBColor[
             0.18255935854789945`, 0.309211839138676, 0.9337078574457099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.027885652381746694`], {
             RGBColor[
             0.3393687513351076, 0.46836588806223545`, 0.9428452546364373]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.027885652381746694`], {
             RGBColor[
             0.3039019362504366, 0.4367505818678281, 0.9406181377356125]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.027885652381746694`], {
             RGBColor[
             0.8193361618613183, 0.1496317899920564, 0.1661496364764569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.027885652381746694`], {
             RGBColor[
             0.21566341381177923`, 0.3440063001393452, 0.9355930844199268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.027885652381746694`], {
             RGBColor[
             0.8141109072907318, 0.8547088953383618, 0.982106625005912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.027885652381746694`], {
             RGBColor[
             0.19287402797566439`, 0.32005321069507126`, 0.9342952626104353]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.027885652381746694`], {
             RGBColor[
             0.18340497994045135`, 0.3101006408377411, 0.933756014333031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.027885652381746694`], {
             RGBColor[
             0.17911500115561352`, 0.3055916011345115, 0.9335117063876894]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.027885652381746694`], {
             RGBColor[
             0.335355251737071, 0.46488959643477135`, 0.9425895179910487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.027885652381746694`], {
             RGBColor[
             0.18263620644148504`, 0.30929261114727236`, 0.9337122338195634]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.027885652381746694`], {
             RGBColor[
             0.29264465833089975`, 0.42491846902175034`, 0.9399770524117451]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.027885652381746694`], {
             RGBColor[
             0.2889051941793347, 0.4209880551027343, 0.939764095460355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.027885652381746694`], {
             RGBColor[
             0.30694355404168716`, 0.4399475150161388, 0.940791353369154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.027885652381746694`], {
             RGBColor[
             0.4063466574019441, 0.5263787838898877, 0.9471130275847793]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.027885652381746694`], {
             RGBColor[
             0.3557668224000087, 0.48256907302763663`, 0.9438901252244479]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.027885652381746694`], {
             RGBColor[
             0.4741596199861951, 0.5839831660090739, 0.9517467286706829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.027885652381746694`], {
             RGBColor[
             0.19890345919190142`, 0.32639052519135536`, 0.9346386297984558]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.027885652381746694`], {
             RGBColor[
             0.5812572311839399, 0.6709298314718057, 0.9601778449356456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.027885652381746694`], {
             RGBColor[
             0.24987309085249598`, 0.3799628397279394, 0.9375412749187138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.027885652381746694`], {
             RGBColor[
             0.1991293041825628, 0.32662790259593993`, 0.9346514913365662]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.027885652381746694`], {
             RGBColor[
             0.24721508689536167`, 0.3771691090418067, 0.9373899055255195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.027885652381746694`], {
             RGBColor[
             0.25655300447979307`, 0.38698385248121464`, 0.9379216861177417]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.027885652381746694`], {
             RGBColor[
             0.21032620428650672`, 0.3383965545296549, 0.9352891382331565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.027885652381746694`], {
             RGBColor[
             0.23840666361665402`, 0.3679108976895925, 0.9368882788506916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.027885652381746694`], {
             RGBColor[
             0.20761230953904478`, 0.335544079079207, 0.935134585942136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.027885652381746694`], {
             RGBColor[
             0.2008438754397465, 0.3284300256973365, 0.9347491336331819]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.027885652381746694`], {
             RGBColor[
             0.20565135384863537`, 0.33348299031681494`, 0.9350229124165412]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.027885652381746694`], {
             RGBColor[
             0.18637271886218407`, 0.3132199226099977, 0.9339250226742475]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.027885652381746694`], {
             RGBColor[
             0.1858996679095085, 0.31272271606557295`, 0.9338980831223087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.027885652381746694`], {
             RGBColor[
             0.20187169700218524`, 0.3295103313271106, 0.9348076665506371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.027885652381746694`], {
             RGBColor[
             0.24686136029389427`, 0.3767973199561026, 0.9373697613188575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.027885652381746694`], {
             RGBColor[
             0.1911403477299942, 0.3182310028351955, 0.9341965320851944]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.027885652381746694`], {
             RGBColor[
             0.18214142158537838`, 0.30877256089233246`, 0.9336840565539767]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.027885652381746694`], {
             RGBColor[
             0.19529547244710238`, 0.32259830236299947`, 0.9344331602908775]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.027885652381746694`], {
             RGBColor[
             0.8795463410175769, 0.5459298918751729, 0.22120285316675511`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.027885652381746694`], {
             RGBColor[
             0.19529691214488243`, 0.32259981557664835`, 0.9344332422795363]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.027885652381746694`], {
             RGBColor[
             0.17905422337022397`, 0.30552771982853294`, 0.9335082451827241]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.027885652381746694`], {
             RGBColor[
             0.21499276582137244`, 0.3433014065798891, 0.935554892009008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.027885652381746694`], {
             RGBColor[
             0.22554056397195027`, 0.35438781120517543`, 0.9361555735096144]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.027885652381746694`], {
             RGBColor[
             0.2451744333338886, 0.3750242527637898, 0.93727369332407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.027885652381746694`], {
             RGBColor[
             0.2358064817309028, 0.3651779416666145, 0.9367402023389224]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.027885652381746694`], {
             RGBColor[
             0.19796437105250972`, 0.32540348401522773`, 0.9345851501181738]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.027885652381746694`], {
             RGBColor[
             0.45725872125089195`, 0.5702622550389433, 0.9504162280122078]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.027885652381746694`], {
             RGBColor[
             0.23550398192177388`, 0.3648599951876243, 0.9367229754223009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.027885652381746694`], {
             RGBColor[
             0.18805335571358273`, 0.3149863784993486, 0.9340207324566552]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.027885652381746694`], {
             RGBColor[
             0.3796233347917912, 0.5032323849982215, 0.9454102410985666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.027885652381746694`], {
             RGBColor[
             0.17959143492855675`, 0.30609236323752076`, 0.933538838586238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.027885652381746694`], {
             RGBColor[
             0.41783566912403936`, 0.5363299883890472, 0.947845097252377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.027885652381746694`], {
             RGBColor[
             0.19013667027984396`, 0.3171760741982618, 0.9341393741392161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.027885652381746694`], {
             RGBColor[
             0.18620451936940718`, 0.3130431342786254, 0.9339154439619627]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.027885652381746694`], {
             RGBColor[
             0.18139651046953492`, 0.3079896120794884, 0.9336416349679267]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.027885652381746694`], {
             RGBColor[
             0.18300767959384703`, 0.309683052983163, 0.9337333886660452]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.027885652381746694`], {
             RGBColor[
             0.2268131918331927, 0.35572542377660804`, 0.9362280477836279]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.027885652381746694`], {
             RGBColor[
             0.18842432755960442`, 0.31537629343049095`, 0.9340418587544824]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.027885652381746694`], {
             RGBColor[
             0.19212227783830665`, 0.31926307363699663`, 0.9342524515522274]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.027885652381746694`], {
             RGBColor[
             0.24182762690147153`, 0.3715065470035356, 0.9370830976489003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.027885652381746694`], {
             RGBColor[
             0.18868393066647376`, 0.3156491527555983, 0.9340566427673703]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.027885652381746694`], {
             RGBColor[
             0.21355297767290998`, 0.3417880979480139, 0.9354728982039288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.027885652381746694`], {
             RGBColor[
             0.19254963929720473`, 0.31971225762658, 0.9342767891550869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.027885652381746694`], {
             RGBColor[
             0.2065811071166083, 0.33446021995121644`, 0.9350758604897056]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.027885652381746694`], {
             RGBColor[
             0.21634716160662554`, 0.34472496242384276`, 0.9356320228453292]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.027885652381746694`], {
             RGBColor[
             0.27580922111776024`, 0.4072233570823697, 0.9390182991682543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.027885652381746694`], {
             RGBColor[
             0.2331737072204319, 0.36241072872856434`, 0.9365902697253919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.027885652381746694`], {
             RGBColor[
             0.2121526703486752, 0.34031628616563087`, 0.9353931527733826]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.027885652381746694`], {
             RGBColor[
             0.1840091371887301, 0.310735648411464, 0.9337904201945499]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.027885652381746694`], {
             RGBColor[
             0.2582664433427927, 0.3887847853645258, 0.938019263926184]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.027885652381746694`], {
             RGBColor[
             0.8379281346647119, 0.8736051659010814, 0.9844035275832383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.027885652381746694`], {
             RGBColor[
             0.4554399226734993, 0.5687856724178738, 0.9502730455257168]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.027885652381746694`], {
             RGBColor[
             0.42461827381123246`, 0.5422047396654701, 0.9482772788254231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.027885652381746694`], {
             RGBColor[
             0.844124603334554, 0.8785460618197521, 0.9849945522966208]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.027885652381746694`], {
             RGBColor[
             0.19131157595015044`, 0.3184109745510759, 0.9342062832790229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.027885652381746694`], {
             RGBColor[
             0.8287975688378628, 0.8663247005533589, 0.9835326460637211]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.027885652381746694`], {
             RGBColor[
             0.9887357523774989, 0.9896099583772056, 0.8363412642506296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.027885652381746694`], {
             RGBColor[
             0.19404714705117995`, 0.3212862332234835, 0.9343620700063117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.027885652381746694`], {
             RGBColor[
             0.6657140642559093, 0.738780153701779, 0.9673158145395446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.027885652381746694`], {
             RGBColor[
             0.3275914997751332, 0.4581650247028605, 0.9420948185812503]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.027885652381746694`], {
             RGBColor[
             0.3100095560527289, 0.44293642874469996`, 0.9409745126743612]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.027885652381746694`], {
             RGBColor[
             0.17994083687002446`, 0.30645960683136597`, 0.9335587365099107]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.027885652381746694`], {
             RGBColor[
             0.18515378626434187`, 0.3119387471648751, 0.9338556062660495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.027885652381746694`], {
             RGBColor[
             0.4288884024290853, 0.5459033104513494, 0.9485493676450263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.027885652381746694`], {
             RGBColor[
             0.1915172466480543, 0.31862714749484833`, 0.934217995921006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.027885652381746694`], {
             RGBColor[
             0.2944180010032382, 0.4267823646067975, 0.9400780416535094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.027885652381746694`], {
             RGBColor[
             0.2650455441851616, 0.3959100501696741, 0.9384053236903759]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.027885652381746694`], {
             RGBColor[
             0.2456807114445148, 0.37555638315794415`, 0.9373025251134988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.027885652381746694`], {
             RGBColor[
             0.23248905082520588`, 0.3616911114474591, 0.9365512795565422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.027885652381746694`], {
             RGBColor[
             0.5777795176543054, 0.6681064669592394, 0.9599040665873084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.027885652381746694`], {
             RGBColor[
             0.3254133616442444, 0.45627843093029025`, 0.9419560295456021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.027885652381746694`], {
             RGBColor[
             0.8789213821202363, 0.5430920994852084, 0.22068137214366979`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.027885652381746694`], {
             RGBColor[
             0.7060709713767632, 0.7703072762684443, 0.9713382138846121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.027885652381746694`], {
             RGBColor[
             0.21581639795358076`, 0.3441670961721334, 0.9356017966404827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.027885652381746694`], {
             RGBColor[
             0.2082469591636211, 0.3362111360737471, 0.9351707282993756]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.027885652381746694`], {
             RGBColor[
             0.5602763464580424, 0.6538966040732364, 0.9585261528345099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.027885652381746694`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.027885652381746694`], {
             RGBColor[
             0.17970434930417156`, 0.30621104340547683`, 0.9335452688928874]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.027885652381746694`], {
             RGBColor[
             0.36991176607450643`, 0.49482071229294583`, 0.9447914285275043]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.027885652381746694`], {
             RGBColor[
             0.9510874915293103, 0.9630417117862173, 0.9676802978022608]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.027885652381746694`], {
             RGBColor[
             0.8592163258347785, 0.4536160411257659, 0.20423899016395516`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.027885652381746694`], {
             RGBColor[
             0.4977475489543879, 0.6031329093695432, 0.9536036568444898]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.027885652381746694`], {
             RGBColor[
             0.2084820527788493, 0.336458234369148, 0.9351841165329731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.027885652381746694`], {
             RGBColor[
             0.19190461331519068`, 0.3190342944224739, 0.9342400558796418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.027885652381746694`], {
             RGBColor[
             0.2739918424465178, 0.40531317687043084`, 0.9389148021414978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.027885652381746694`], {
             RGBColor[
             0.22400797509009437`, 0.3527769631185974, 0.9360682948400547]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.027885652381746694`], {
             RGBColor[
             0.19792175174780763`, 0.3253586884237658, 0.9345827230118207]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.027885652381746694`], {
             RGBColor[
             0.2211253737681676, 0.3497471663617724, 0.9359041349591976]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.027885652381746694`], {
             RGBColor[
             0.19120668731506069`, 0.31830072994527303`, 0.9342003100264233]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.027885652381746694`], {
             RGBColor[
             0.19035994618760685`, 0.3174107513338308, 0.934152089371856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.027885652381746694`], {
             RGBColor[
             0.9703310152107799, 0.9773935002394792, 0.9351060317243296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.027885652381746694`], {
             RGBColor[
             0.24693624036742998`, 0.3768760236610595, 0.9373740256282702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.027885652381746694`], {
             RGBColor[
             0.19324911536591247`, 0.3204474513241361, 0.9343166232824178]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.027885652381746694`], {
             RGBColor[
             0.5096359477486948, 0.612784447077024, 0.9545395551462174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.027885652381746694`], {
             RGBColor[
             0.18222514168352894`, 0.3088605560236495, 0.9336888242897137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.027885652381746694`], {
             RGBColor[
             0.20088219976865415`, 0.32847030699692126`, 0.9347513161470175]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.027885652381746694`], {
             RGBColor[
             0.5071373117219987, 0.6107559417882819, 0.9543428533653905]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.027885652381746694`], {
             RGBColor[
             0.17933281357579656`, 0.305820535798229, 0.9335241104827943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.027885652381746694`], {
             RGBColor[
             0.28091140737960196`, 0.41258607834085864`, 0.939308861127858]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.027885652381746694`], {
             RGBColor[
             0.3403985574835718, 0.4692578543884732, 0.9429108729735957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.027885652381746694`], {
             RGBColor[
             0.23139395253121084`, 0.36054009370722817`, 0.9364889153287519]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.027885652381746694`], {
             RGBColor[
             0.18235944175044905`, 0.3090017139090986, 0.9336964724798456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.027885652381746694`], {
             RGBColor[
             0.19489410730752896`, 0.3221764421532881, 0.9344103031399453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.027885652381746694`], {
             RGBColor[
             0.2167015948028579, 0.34509749418544555`, 0.9356522072915177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.027885652381746694`], {
             RGBColor[
             0.8173387448883187, 0.1342787678638822, 0.16423690772735258`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.027885652381746694`], {
             RGBColor[
             0.1829127869860106, 0.3095833148357881, 0.9337279846724099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.027885652381746694`], {
             RGBColor[
             0.18362197162651986`, 0.31032871285786656`, 0.9337683716885422]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.027885652381746694`], {
             RGBColor[
             0.19372013073248498`, 0.3209425183385029, 0.9343434469107393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.027885652381746694`], {
             RGBColor[
             0.1849258667142184, 0.3116991892667612, 0.9338426265848467]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.027885652381746694`], {
             RGBColor[
             0.20594129701488287`, 0.33378773896799957`, 0.9350394242509266]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.027885652381746694`], {
             RGBColor[
             0.8251923969012658, 0.19464537872765014`, 0.17175757376438203`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.027885652381746694`], {
             RGBColor[
             0.1870776850955973, 0.3139608868187558, 0.9339651694583363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.027885652381746694`], {
             RGBColor[
             0.37418878878290995`, 0.4985252543935531, 0.9450639566324611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.027885652381746694`], {
             RGBColor[
             0.9923039511135691, 0.9910855002530954, 0.777206976991627]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.027885652381746694`], {
             RGBColor[
             0.9694202648664492, 0.9767142641238943, 0.9366476944955487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.027885652381746694`], {
             RGBColor[
             0.23765262088408304`, 0.3671183509685898, 0.9368453372325779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.027885652381746694`], {
             RGBColor[
             0.8954246210317355, 0.9194513034296, 0.9898875937806444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.027885652381746694`], {
             RGBColor[
             0.1889310324973132, 0.31590887244697147`, 0.9340707148510822]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.027885652381746694`], {
             RGBColor[
             0.18920356017618423`, 0.31619531631671777`, 0.9340862348992254]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.027885652381746694`], {
             RGBColor[
             0.36433321534571095`, 0.4899888520377754, 0.9444359682079841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.027885652381746694`], {
             RGBColor[
             0.30183205672017543`, 0.43457500724358145`, 0.9405002611584765]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.027885652381746694`], {
             RGBColor[
             0.2599789274537134, 0.39058471474286727`, 0.9381167873629076]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.027885652381746694`], {
             RGBColor[
             0.19899652547638796`, 0.32648834375709396`, 0.934643929785678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.027885652381746694`], {
             RGBColor[
             0.6582217134144572, 0.7329270722804612, 0.9665690470276681]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.027885652381746694`], {
             RGBColor[
             0.19756403157199334`, 0.32498270183821587`, 0.9345623513770076]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.027885652381746694`], {
             RGBColor[
             0.187660141527025, 0.31457308545805707`, 0.933998339490439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.027885652381746694`], {
             RGBColor[
             0.3534033382914345, 0.480521941884955, 0.9437395261069965]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.027885652381746694`], {
             RGBColor[
             0.20794500379241626`, 0.3358937618335345, 0.9351535323876885]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.027885652381746694`], {
             RGBColor[
             0.8200027527924696, 0.15475549999089333`, 0.1667879647049341]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.027885652381746694`], {
             RGBColor[
             0.19665135271400355`, 0.3240234184912868, 0.9345103756662324]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.027885652381746694`], {
             RGBColor[
             0.5240458703783706, 0.6244830714274116, 0.9556739570409113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.027885652381746694`], {
             RGBColor[
             0.20313982636998706`, 0.33084321569671615`, 0.9348798846421041]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.027885652381746694`], {
             RGBColor[
             0.194144227344503, 0.3213882707670121, 0.934367598585399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.027885652381746694`], {
             RGBColor[
             0.37904525788294496`, 0.5027316838347692, 0.9453734065491083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.027885652381746694`], {
             RGBColor[
             0.1851145385676597, 0.3118974953472144, 0.9338533711677852]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.027885652381746694`], {
             RGBColor[
             0.1880939032775767, 0.3150289965599703, 0.9340230415804399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.027885652381746694`], {
             RGBColor[
             0.1990369147875074, 0.3265307954839108, 0.9346462298971957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.027885652381746694`], {
             RGBColor[
             0.2089289786028837, 0.3369279817469421, 0.9352095682974844]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.027885652381746694`], {
             RGBColor[
             0.39875120665503094`, 0.5197999862113661, 0.9466290521795794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.027885652381746694`], {
             RGBColor[
             0.31502354175322494`, 0.44727929114822085`, 0.9412939994095033]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.027885652381746694`], {
             RGBColor[
             0.9319225428018962, 0.7678025982169813, 0.26408148383634866`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.027885652381746694`], {
             RGBColor[
             0.7398648594018855, 0.7967073184367315, 0.9747064728211174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.027885652381746694`], {
             RGBColor[
             0.18427610046840573`, 0.31101624374485265`, 0.9338056233583907]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.027885652381746694`], {
             RGBColor[
             0.3212434064694567, 0.45266662534593033`, 0.9416903236892111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.027885652381746694`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.027885652381746694`], {
             RGBColor[
             0.2137339467700851, 0.34197830794324846`, 0.935483204126293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.027885652381746694`], {
             RGBColor[
             0.4742143938317012, 0.5840276338843894, 0.9517510406684443]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.027885652381746694`], {
             RGBColor[
             0.25752973177491306`, 0.38801045479647306`, 0.9379773092922603]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.027885652381746694`], {
             RGBColor[
             0.1954605501868454, 0.3227718095340026, 0.9344425612239453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.027885652381746694`], {
             RGBColor[
             0.8194918846006688, 0.15082874320484374`, 0.1662987567475226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.027885652381746694`], {
             RGBColor[
             0.3141297509318431, 0.44650513446197276`, 0.941237047848713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.027885652381746694`], {
             RGBColor[
             0.20973292712492791`, 0.3377729826168909, 0.9352553519764795]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.027885652381746694`], {
             RGBColor[
             0.18590102371033476`, 0.3127241410982041, 0.9338981603331601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.027885652381746694`], {
             RGBColor[
             0.17907641669607907`, 0.3055510464211448, 0.9335095090597996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.027885652381746694`], {
             RGBColor[
             0.2965600408339725, 0.42903378428206873`, 0.9402000276530058]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.027885652381746694`], {
             RGBColor[
             0.20546571259734456`, 0.33328786959137313`, 0.9350123404219118]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.027885652381746694`], {
             RGBColor[
             0.18838969891108812`, 0.3153398965253172, 0.9340398867041779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.027885652381746694`], {
             RGBColor[
             0.19616100168040002`, 0.3235080284649182, 0.934482450900278]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.027885652381746694`], {
             RGBColor[
             0.24986810421890843`, 0.3799575984598681, 0.937540990937308]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.027885652381746694`], {
             RGBColor[
             0.19470143524485908`, 0.32197393159930776`, 0.9343993307510091]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.027885652381746694`], {
             RGBColor[
             0.8939300581111314, 0.611242991794526, 0.23320497928678602`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.027885652381746694`], {
             RGBColor[
             0.2822705085644714, 0.4140145798581486, 0.9393862599297264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.027885652381746694`], {
             RGBColor[
             0.29805944165302733`, 0.4306097496103981, 0.9402854163114862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.027885652381746694`], {
             RGBColor[
             0.22229995450050422`, 0.350981725184178, 0.9359710255942676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.027885652381746694`], {
             RGBColor[
             0.17902996710188124`, 0.3055022249525685, 0.933506863824126]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.027885652381746694`], {
             RGBColor[
             0.212847764567014, 0.3410468742606238, 0.9354327373608172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.027885652381746694`], {
             RGBColor[
             0.6973666945960665, 0.7635074290924103, 0.9704706529212034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.027885652381746694`], {
             RGBColor[
             0.8265166883216026, 0.20482446289255998`, 0.17302571672406986`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.027885652381746694`], {
             RGBColor[
             0.2025961788233211, 0.3302718076559249, 0.934848924718576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.027885652381746694`], {
             RGBColor[
             0.5478165382686445, 0.6437811704771209, 0.9575452710920592]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.027885652381746694`], {
             RGBColor[
             0.28461757525764775`, 0.41648149576530025`, 0.9395199219057286]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.027885652381746694`], {
             RGBColor[
             0.18275376889499648`, 0.30941617673980293`, 0.9337189288273728]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.027885652381746694`], {
             RGBColor[
             0.1811098371299533, 0.3076883002234485, 0.9336253093453327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.027885652381746694`], {
             RGBColor[
             0.7121412574025138, 0.7750494298476431, 0.9719432432656107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.027885652381746694`], {
             RGBColor[
             0.18850413369751906`, 0.3154601747414406, 0.9340464035959741]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.027885652381746694`], {
             RGBColor[
             0.21345649486519924`, 0.3416866883997466, 0.9354674036507632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.027885652381746694`], {
             RGBColor[
             0.8324443832728455, 0.2503873238203034, 0.17870208410375396`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.027885652381746694`], {
             RGBColor[
             0.18370800885926494`, 0.3104191434445573, 0.9337732713816664]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.027885652381746694`], {
             RGBColor[
             0.18455342051778426`, 0.3113077246998561, 0.9338214163249446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.027885652381746694`], {
             RGBColor[
             0.1951112049063669, 0.3224046254944496, 0.9344226665270321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.027885652381746694`], {
             RGBColor[
             0.42062186552277797`, 0.5387432516713317, 0.9480226312231679]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.027885652381746694`], {
             RGBColor[
             0.1856877903127057, 0.31250001927751764`, 0.9338860170066157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.027885652381746694`], {
             RGBColor[
             0.23827199083861747`, 0.36776934806112876`, 0.9368806094352129]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.027885652381746694`], {
             RGBColor[
             0.24157157412247404`, 0.37123741929812537`, 0.9370685158219325]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.027885652381746694`], {
             RGBColor[
             0.18576331458524015`, 0.3125794000764668, 0.9338903180022083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.027885652381746694`], {
             RGBColor[
             0.2313516506730186, 0.3604956317721754, 0.9364865063005079]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.027885652381746694`], {
             RGBColor[
             0.2623389378177228, 0.3930652352687406, 0.9382511864618155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.027885652381746694`], {
             RGBColor[
             0.18870039039885345`, 0.3156664529779366, 0.9340575801247794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.027885652381746694`], {
             RGBColor[
             0.24096885499463874`, 0.3706039232801706, 0.9370341918592453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.027885652381746694`], {
             RGBColor[
             0.8178049183525352, 0.13786198138836525`, 0.164683315963154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.027885652381746694`], {
             RGBColor[
             0.9537765326908467, 0.9650471942815904, 0.9631284525300384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.027885652381746694`], {
             RGBColor[
             0.9602115875305376, 0.8774464833562946, 0.2999299602777051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.027885652381746694`], {
             RGBColor[
             0.1982643030525542, 0.3257187315640616, 0.9346022308018668]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.027885652381746694`], {
             RGBColor[
             0.23480104226620413`, 0.36412116104067216`, 0.9366829440488222]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.027885652381746694`], {
             RGBColor[
             0.956979221732861, 0.9674357545252026, 0.9577071353769899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.027885652381746694`], {
             RGBColor[
             0.21013611726343454`, 0.33819676101619267`, 0.9352783130584011]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.027885652381746694`], {
             RGBColor[
             0.38195753878243316`, 0.5052541551744117, 0.9455589745127948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.027885652381746694`], {
             RGBColor[
             0.27139200070452485`, 0.4025805783601091, 0.9387667450004126]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.027885652381746694`], {
             RGBColor[
             0.24934350578881678`, 0.3794062122483802, 0.9375111158327881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.027885652381746694`], {
             RGBColor[
             0.18639411010760892`, 0.31324240616522253`, 0.9339262408740289]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.027885652381746694`], {
             RGBColor[
             0.20071986914810575`, 0.3282996872223691, 0.9347420716583239]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.027885652381746694`], {
             RGBColor[
             0.1915625031716876, 0.3186747149706162, 0.9342205732130758]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.027885652381746694`], {
             RGBColor[
             0.8280837295399454, 0.865755504473851, 0.9834645594342339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.027885652381746694`], {
             RGBColor[
             0.20342618893072584`, 0.3311442009044876, 0.9348961925663027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.027885652381746694`], {
             RGBColor[
             0.18432439621433888`, 0.3110670056359555, 0.9338083737296745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.027885652381746694`], {
             RGBColor[
             0.20110409825488346`, 0.3287035363751249, 0.9347639529375389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.027885652381746694`], {
             RGBColor[
             0.19841472542917707`, 0.32587683501922177`, 0.9346107971336854]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.027885652381746694`], {
             RGBColor[
             0.3485452682138572, 0.4763141257574593, 0.943429974177476]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.027885652381746694`], {
             RGBColor[
             0.3095548228305918, 0.44254256168324113`, 0.9409455374755513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.027885652381746694`], {
             RGBColor[
             0.18638553952238943`, 0.3132333979367503, 0.9339257527918797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.027885652381746694`], {
             RGBColor[
             0.9932598001133134, 0.9879917189181485, 0.507749021905247]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.027885652381746694`], {
             RGBColor[
             0.19610120868731518`, 0.3234451822380914, 0.9344790457777777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.027885652381746694`], {
             RGBColor[
             0.2081404760074813, 0.3360992155252221, 0.9351646642411613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.027885652381746694`], {
             RGBColor[
             0.9453835605713274, 0.9587877294170835, 0.9773355650906732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.027885652381746694`], {
             RGBColor[
             0.18600360463112436`, 0.31283196014996, 0.9339040021648441]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.027885652381746694`], {
             RGBColor[
             0.2775970966062373, 0.4091025275786123, 0.9391201160323983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.027885652381746694`], {
             RGBColor[
             0.32568965645452963`, 0.4565177436079784, 0.9419736348065956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.027885652381746694`], {
             RGBColor[
             0.6627555094400547, 0.736468908193784, 0.9670209334447669]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.027885652381746694`], {
             RGBColor[
             0.40957405763887067`, 0.529174195761261, 0.9473186746739982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.027885652381746694`], {
             RGBColor[
             0.7912709059084366, 0.8368661126680731, 0.979830147120073]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.027885652381746694`], {
             RGBColor[
             0.3745258073527012, 0.4988171629396605, 0.9450854311577144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.027885652381746694`], {
             RGBColor[
             0.92133834354613, 0.7258397751431882, 0.2555651886720716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.027885652381746694`], {
             RGBColor[
             0.30601698137869693`, 0.43897362839923615`, 0.940738586426738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.027885652381746694`], {
             RGBColor[
             0.9933000584574108, 0.9880778274454297, 0.5121308942145434]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.027885652381746694`], {
             RGBColor[
             0.1860930553658944, 0.31292597854370746`, 0.9339090962518588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.027885652381746694`], {
             RGBColor[
             0.1838330998850932, 0.3105506220439319, 0.9337803951305317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.027885652381746694`], {
             RGBColor[
             0.1804054273287139, 0.30694792086018496`, 0.933585194249233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.027885652381746694`], {
             RGBColor[
             0.18554668841356567`, 0.31235171223514435`, 0.9338779814622011]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.027885652381746694`], {
             RGBColor[
             0.18003320207443918`, 0.306556688517498, 0.93356399657166]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.027885652381746694`], {
             RGBColor[
             0.179946795179367, 0.3064658693922636, 0.9335590758268132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.027885652381746694`], {
             RGBColor[
             0.19798515205544082`, 0.3254253261669, 0.934586333565548]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.027885652381746694`], {
             RGBColor[
             0.1836365577609456, 0.3103440438099624, 0.9337692023473195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.027885652381746694`], {
             RGBColor[
             0.20279567675606608`, 0.3304814926321394, 0.9348602858307151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.027885652381746694`], {
             RGBColor[
             0.28617898913701123`, 0.4181226407518692, 0.9396088421162536]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.027885652381746694`], {
             RGBColor[
             0.25469411239970985`, 0.38503003904448196`, 0.9378158249637654]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.027885652381746694`], {
             RGBColor[
             0.24023703411797065`, 0.3698347331386689, 0.9369925157429511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.027885652381746694`], {
             RGBColor[
             0.18246816409549027`, 0.30911598798713175`, 0.9337026640565553]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.027885652381746694`], {
             RGBColor[
             0.7203821791624184, 0.7814873005598058, 0.9727646213308456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.027885652381746694`], {
             RGBColor[
             0.1893487791980019, 0.3163479507160659, 0.9340945049076855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.027885652381746694`], {
             RGBColor[
             0.3220959675484921, 0.453405070901625, 0.9417446481272771]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.027885652381746694`], {
             RGBColor[
             0.3583175561905998, 0.4847783904334387, 0.944052655726059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.027885652381746694`], {
             RGBColor[
             0.9335847383251342, 0.7743926495727972, 0.2654189253710895]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.027885652381746694`], {
             RGBColor[
             0.9944175835604394, 0.9904681006416884, 0.633766605113725]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.027885652381746694`], {
             RGBColor[
             0.3419268933615933, 0.4705816221096207, 0.9430082571842888]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.027885652381746694`], {
             RGBColor[
             0.18554205504628538`, 0.3123468422723603, 0.933877717598789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.027885652381746694`], {
             RGBColor[
             0.2707814877613013, 0.40193889054802484`, 0.938731977191469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.027885652381746694`], {
             RGBColor[
             0.9931232770303468, 0.9876997098482838, 0.4928893268471293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.027885652381746694`], {
             RGBColor[
             0.21298290042549683`, 0.3411889106159976, 0.9354404331480423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.027885652381746694`], {
             RGBColor[
             0.8202342132018924, 0.1565346061243149, 0.16700961145439447`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.027885652381746694`], {
             RGBColor[
             0.2030621295519029, 0.3307615514146469, 0.9348754599232564]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.027885652381746694`], {
             RGBColor[
             0.7219717591850786, 0.7827290925547635, 0.9729230558120345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.027885652381746694`], {
             RGBColor[
             0.35762511408731845`, 0.48417863188672844`, 0.9440085339275405]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.027885652381746694`], {
             RGBColor[
             0.4386808762090538, 0.554385059055515, 0.9491733354151413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.027885652381746694`], {
             RGBColor[
             0.18439801323969868`, 0.31114438179719767`, 0.9338125661103621]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.027885652381746694`], {
             RGBColor[
             0.36417957475425095`, 0.48985577627965343`, 0.9444261783653554]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.027885652381746694`], {
             RGBColor[
             0.1808071689883251, 0.3073701768163288, 0.9336080728424244]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.027885652381746694`], {
             RGBColor[
             0.3593758114062829, 0.48569499791180964`, 0.944120086812624]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.027885652381746694`], {
             RGBColor[
             0.8221152183090297, 0.17099283563946593`, 0.16881086406928056`]},
             StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{3.8349502435193233`*^9, 3.834957407142641*^9, 
  3.835023913107746*^9},
 CellLabel->
  "Out[178]=",ExpressionUUID->"588c2948-04e8-43cf-ac50-c3fd10b68aa2"]
}, Open  ]],

Cell["Estimated with absolute Mean Deviation v Calculated: (r=6)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 
  3.8349503922098827`*^9}},ExpressionUUID->"bf68603a-3d49-4f35-853b-\
650bd5ab7349"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphin4", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsi4", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}], 
     "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"AMDi6400", ",", "kri4"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502409842243`*^9}, {3.8349504019691753`*^9, 3.834950402221115*^9}, {
   3.8349577477528667`*^9, 3.8349577551942053`*^9}},
 CellLabel->
  "In[179]:=",ExpressionUUID->"1f2fcd74-2a50-47d3-9fab-590bd8d01e87"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN3AuYzmXewPH7z7a1WxZbu0o1DqFsy5TT0CKyGGKYrMNM4zSN46CIkAnD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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[37, 104] -> 
             RGBColor[
              0.9902685056381975, 0.9883637515712489, 0.6742805388381534], 
             UndirectedEdge[119, 243] -> 
             RGBColor[
              0.9819046799503658, 0.9844146173201452, 0.8433932155145794], 
             UndirectedEdge[165, 226] -> 
             RGBColor[
              0.9938283113632569, 0.9892077069964731, 0.569627963016853], 
             UndirectedEdge[235, 261] -> 
             RGBColor[
              0.9378395220940055, 0.7848394808499499, 0.5330207055496983], 
             UndirectedEdge[56, 198] -> 
             RGBColor[
              0.9157428576089452, 0.6922765617218424, 0.2587625151369652], 
             UndirectedEdge[50, 254] -> 
             RGBColor[
              0.9895173537198412, 0.9876011403103664, 0.6538741220505444], 
             UndirectedEdge[249, 268] -> 
             RGBColor[
              0.5729142449518891, 0.6027035474625054, 0.6297099838578437], 
             UndirectedEdge[38, 224] -> 
             RGBColor[
              0.946925163318732, 0.8245647774363036, 0.2903094377321579], 
             UndirectedEdge[79, 87] -> 
             RGBColor[
              0.9575226183629502, 0.8669120423537706, 0.2971079253670562], 
             UndirectedEdge[38, 311] -> 
             RGBColor[0.960957129380066, 0.87323587188551, 0.511764360365143],
              UndirectedEdge[37, 145] -> 
             RGBColor[
              0.9551916660969193, 0.8606487038296735, 0.5573854775767064], 
             UndirectedEdge[147, 359] -> 
             RGBColor[
              0.9307598047418317, 0.7631927292683152, 0.26314591750025074`], 
             UndirectedEdge[192, 349] -> 
             RGBColor[
              0.9713679788578575, 0.9181998360600995, 0.5381901250965812], 
             UndirectedEdge[213, 308] -> 
             RGBColor[
              0.9651466591470663, 0.9678715443484828, 0.7037973053397767], 
             UndirectedEdge[262, 397] -> 
             RGBColor[
              0.9742434893515388, 0.9247793830457571, 0.35444124914998026`], 
             UndirectedEdge[129, 364] -> 
             RGBColor[
              0.9739994710911974, 0.9774118047152123, 0.7769463771010705], 
             UndirectedEdge[54, 83] -> 
             RGBColor[
              0.9912104906044805, 0.990633326231934, 0.795328447412309], 
             UndirectedEdge[13, 277] -> 
             RGBColor[
              0.9474926418009052, 0.8216068462353592, 0.31788832537507034`], 
             UndirectedEdge[191, 235] -> 
             RGBColor[
              0.9846958865758912, 0.9682078255644411, 0.60921326559921], 
             UndirectedEdge[54, 214] -> 
             RGBColor[
              0.990954029288587, 0.9905272728870569, 0.7995786751172748], 
             UndirectedEdge[87, 176] -> 
             RGBColor[
              0.9566935632914256, 0.8636251152614012, 0.29644084819608385`], 
             UndirectedEdge[16, 377] -> 
             RGBColor[
              0.9315370888105792, 0.7474444562152399, 0.315181518028128], 
             UndirectedEdge[158, 344] -> 
             RGBColor[
              0.9554376712898365, 0.8660438862466879, 0.5792116035135377], 
             UndirectedEdge[95, 228] -> 
             RGBColor[
              0.9564943448053369, 0.8541564029151123, 0.35549760688559573`], 
             UndirectedEdge[193, 283] -> 
             RGBColor[
              0.9772126196519004, 0.9347949567338245, 0.365975759693676], 
             UndirectedEdge[11, 366] -> 
             RGBColor[
              0.8952185435487368, 0.6112003507689274, 0.23397526610301192`], 
             UndirectedEdge[106, 231] -> 
             RGBColor[
              0.9191138164640009, 0.7865581640601825, 0.6074864837726264], 
             UndirectedEdge[76, 388] -> 
             RGBColor[
              0.9432644187263832, 0.8127693568014697, 0.27320742343323573`], 
             UndirectedEdge[208, 351] -> 
             RGBColor[
              0.9191502336772752, 0.7171646486575687, 0.25380458411005125`], 
             UndirectedEdge[208, 225] -> 
             RGBColor[
              0.943146856943273, 0.8058827689499933, 0.30655087524212155`], 
             UndirectedEdge[163, 374] -> 
             RGBColor[
              0.9419347989886953, 0.8074978576110484, 0.2721375801821053], 
             UndirectedEdge[165, 288] -> 
             RGBColor[
              0.9933755802729062, 0.9882393609723477, 0.5203509777646033], 
             UndirectedEdge[110, 239] -> 
             RGBColor[
              0.9702914696686762, 0.9080759373001683, 0.5086685914634259], 
             UndirectedEdge[14, 273] -> 
             RGBColor[
              0.9673409519418061, 0.9005409494560934, 0.3325975287969896], 
             UndirectedEdge[231, 372] -> 
             RGBColor[
              0.9015967104410338, 0.7727857621764518, 0.6125855763028066], 
             UndirectedEdge[5, 162] -> 
             RGBColor[
              0.9850698437908946, 0.9617122426481606, 0.5570497274678465], 
             UndirectedEdge[36, 90] -> 
             RGBColor[
              0.9884609942749132, 0.9716469551114258, 0.5598251122318971], 
             UndirectedEdge[258, 328] -> 
             RGBColor[
              0.9725917006749829, 0.917058604764277, 0.4227988923279595], 
             UndirectedEdge[91, 208] -> 
             RGBColor[
              0.9092658256943311, 0.677976264788898, 0.24585135743009934`], 
             UndirectedEdge[155, 370] -> 
             RGBColor[
              0.9491390845768416, 0.8228656642175997, 0.46173159888371507`], 
             UndirectedEdge[66, 243] -> 
             RGBColor[
              0.9917562176267514, 0.9842048950395078, 0.582596094351592], 
             UndirectedEdge[253, 334] -> 
             RGBColor[
              0.9135808512620107, 0.6858213415319705, 0.2488441855673404], 
             UndirectedEdge[50, 210] -> 
             RGBColor[
              0.9817079459860085, 0.9499119780622995, 0.38741623252429447`], 
             UndirectedEdge[239, 365] -> 
             RGBColor[
              0.9517330180396164, 0.8459424396174731, 0.2821155564214594], 
             UndirectedEdge[13, 51] -> 
             RGBColor[
              0.9876504491134, 0.9699843752143475, 0.40821105925787116`], 
             UndirectedEdge[258, 300] -> 
             RGBColor[
              0.9726183645239288, 0.9171156360410438, 0.4257010877355299], 
             UndirectedEdge[30, 294] -> 
             RGBColor[
              0.9909976269066483, 0.9903912734646582, 0.7876599286853888], 
             UndirectedEdge[31, 292] -> 
             RGBColor[
              0.9845546365257472, 0.9753171715621851, 0.6560238275166316], 
             UndirectedEdge[203, 216] -> 
             RGBColor[
              0.9595780274038479, 0.8650780912538735, 0.43514763970756604`], 
             UndirectedEdge[64, 233] -> 
             RGBColor[
              0.9871077688190752, 0.9675877985920733, 0.4542304307085189], 
             UndirectedEdge[50, 242] -> 
             RGBColor[
              0.9851267372768145, 0.9614443638565571, 0.40069759110451353`], 
             UndirectedEdge[133, 398] -> 
             RGBColor[
              0.9897055922820643, 0.981137310548664, 0.6012384830383145], 
             UndirectedEdge[7, 390] -> 
             RGBColor[
              0.993185501569203, 0.9878328018450317, 0.4996620838963037], 
             UndirectedEdge[186, 342] -> 
             RGBColor[
              0.9394055840191446, 0.7947139148095919, 0.2844581438285942], 
             UndirectedEdge[347, 398] -> 
             RGBColor[
              0.9813859772200482, 0.9761108755272054, 0.6680890103605738], 
             UndirectedEdge[321, 375] -> 
             RGBColor[
              0.977574392429466, 0.9370094063607648, 0.5319477257199828], 
             UndirectedEdge[149, 279] -> 
             RGBColor[
              0.9407666567235966, 0.7974099027228446, 0.29961604387314195`], 
             UndirectedEdge[38, 306] -> 
             RGBColor[
              0.9356328478656593, 0.7825127214089329, 0.2670668823827057], 
             UndirectedEdge[12, 358] -> 
             RGBColor[
              0.9913947875780815, 0.9889824520079608, 0.6667332669957657], 
             UndirectedEdge[139, 378] -> 
             RGBColor[
              0.8843051865137714, 0.5015829311782898, 0.22244444289252685`], 
             UndirectedEdge[272, 374] -> 
             RGBColor[
              0.9660118078084885, 0.8907572782917272, 0.4301823659467916], 
             UndirectedEdge[21, 114] -> 
             RGBColor[
              0.9916049394477163, 0.9893915491830398, 0.6866706074868703], 
             UndirectedEdge[250, 321] -> 
             RGBColor[
              0.9480756685098667, 0.8213127510588394, 0.4993579161279491], 
             UndirectedEdge[19, 152] -> 
             RGBColor[
              0.954833044967677, 0.8571172697769944, 0.546773670017942], 
             UndirectedEdge[270, 336] -> 
             RGBColor[
              0.9651050829144916, 0.9734960084895863, 0.9439521719605104], 
             UndirectedEdge[87, 277] -> 
             RGBColor[
              0.9381260844801245, 0.7900112490201212, 0.28150101890976786`], 
             UndirectedEdge[37, 377] -> 
             RGBColor[
              0.9304331654098461, 0.7536190141959109, 0.5370053457852864], 
             UndirectedEdge[312, 356] -> 
             RGBColor[
              0.9863364331862932, 0.9793776802431507, 0.6545416498487993], 
             UndirectedEdge[294, 343] -> 
             RGBColor[
              0.9887273160460206, 0.9896064697373355, 0.8364810760957513], 
             UndirectedEdge[170, 349] -> 
             RGBColor[
              0.9369246967380247, 0.7876344717047448, 0.2681063343090013], 
             UndirectedEdge[176, 390] -> 
             RGBColor[
              0.9709569742891182, 0.9117040964510694, 0.35481518072382795`], 
             UndirectedEdge[235, 327] -> 
             RGBColor[
              0.9917939908645529, 0.9906190923368268, 0.7670842773010795], 
             UndirectedEdge[271, 400] -> 
             RGBColor[
              0.9285514055320285, 0.7544371623068574, 0.26136898765825123`], 
             UndirectedEdge[45, 103] -> 
             RGBColor[
              0.9668854465328987, 0.8937009920323058, 0.46165452589692946`], 
             UndirectedEdge[30, 343] -> 
             RGBColor[
              0.9928331443942069, 0.9911503071164114, 0.7572406537495546], 
             UndirectedEdge[200, 234] -> 
             RGBColor[
              0.9420384412509906, 0.8002753155158691, 0.5212125222969675], 
             UndirectedEdge[282, 382] -> 
             RGBColor[
              0.9857211357177602, 0.9634961793185461, 0.3990297379111045], 
             UndirectedEdge[305, 382] -> 
             RGBColor[
              0.9883814929054098, 0.9751097033222842, 0.5853042789670988], 
             UndirectedEdge[50, 164] -> 
             RGBColor[
              0.9498483635123092, 0.8279978622580425, 0.3388737387046245], 
             UndirectedEdge[259, 287] -> 
             RGBColor[
              0.9737021047954505, 0.9233091706328957, 0.5197864901563322], 
             UndirectedEdge[90, 95] -> 
             RGBColor[
              0.9575308512828804, 0.8567369732379925, 0.4947439333532755], 
             UndirectedEdge[44, 243] -> 
             RGBColor[
              0.9935675621222271, 0.9916080358784972, 0.7562656724576984], 
             UndirectedEdge[82, 194] -> 
             RGBColor[
              0.9334187412961065, 0.772480778047591, 0.27181490438964495`], 
             UndirectedEdge[124, 150] -> 
             RGBColor[
              0.9554658828783282, 0.8509834887014524, 0.3359416247952805], 
             UndirectedEdge[233, 316] -> 
             RGBColor[
              0.9936275467636815, 0.988778291818396, 0.5477759753285616], 
             UndirectedEdge[87, 390] -> 
             RGBColor[
              0.9782960619817628, 0.9384148088030926, 0.3731484027751373], 
             UndirectedEdge[72, 376] -> 
             RGBColor[
              0.9921871058655579, 0.9891966851321317, 0.6453587309961978], 
             UndirectedEdge[99, 169] -> 
             RGBColor[
              0.9825942219444925, 0.9521938059852464, 0.45104451424087666`], 
             UndirectedEdge[127, 137] -> 
             RGBColor[
              0.9175352572919986, 0.7098543753449913, 0.2524581957830475], 
             UndirectedEdge[68, 391] -> 
             RGBColor[
              0.9360196390008226, 0.7840462193693511, 0.2673781036092131], 
             UndirectedEdge[292, 309] -> 
             RGBColor[
              0.9548743903740136, 0.866445594368562, 0.5863081656260157], 
             UndirectedEdge[88, 140] -> 
             RGBColor[
              0.92646959315915, 0.7271429417137274, 0.3038758483717767], 
             UndirectedEdge[153, 216] -> 
             RGBColor[
              0.9391056240404427, 0.7780840635243552, 0.4183735988870449], 
             UndirectedEdge[145, 165] -> 
             RGBColor[
              0.9582608453694219, 0.8604432588828219, 0.3993312401900699], 
             UndirectedEdge[37, 76] -> 
             RGBColor[
              0.9654945982912477, 0.9014963967315572, 0.565675458661164], 
             UndirectedEdge[6, 391] -> 
             RGBColor[
              0.9722478323257483, 0.914597717902351, 0.4874701582908636], 
             UndirectedEdge[203, 206] -> 
             RGBColor[
              0.9292493315982886, 0.7572042065895037, 0.26193055535359433`], 
             UndirectedEdge[298, 320] -> 
             RGBColor[
              0.9426459078335077, 0.7951133413497935, 0.37844191423481605`], 
             UndirectedEdge[39, 164] -> 
             RGBColor[
              0.9453853904392965, 0.8129899760761488, 0.3175589521839606], 
             UndirectedEdge[107, 156] -> 
             RGBColor[
              0.9921880164089147, 0.9901907258982314, 0.7175725410241496], 
             UndirectedEdge[31, 222] -> 
             RGBColor[
              0.9584647667761454, 0.8642329631607808, 0.3312722194241132], 
             UndirectedEdge[301, 329] -> 
             RGBColor[
              0.9620308751210942, 0.8941264110444196, 0.5915293500903058], 
             UndirectedEdge[126, 320] -> 
             RGBColor[
              0.9899301669557581, 0.9884992384076972, 0.6999062556582221], 
             UndirectedEdge[49, 191] -> 
             RGBColor[
              0.979761454918019, 0.9433927765814227, 0.3758775033953946], 
             UndirectedEdge[122, 173] -> 
             RGBColor[
              0.9692936912426715, 0.9219250957788063, 0.5949931170688514], 
             UndirectedEdge[60, 102] -> 
             RGBColor[
              0.9679080970067966, 0.9380093533778746, 0.631359254057487], 
             UndirectedEdge[120, 380] -> 
             RGBColor[
              0.9521245182157617, 0.8416101207030966, 0.31307707316012534`], 
             UndirectedEdge[110, 247] -> 
             RGBColor[
              0.9806925694743738, 0.9834186276036418, 0.8413250674836916], 
             UndirectedEdge[59, 149] -> 
             RGBColor[
              0.970565912168869, 0.9123740516724265, 0.3401545562474858], 
             UndirectedEdge[92, 346] -> 
             RGBColor[
              0.9805424284789578, 0.9460271837837815, 0.37891143820515966`], 
             UndirectedEdge[6, 142] -> 
             RGBColor[
              0.9759236464789361, 0.9289083923638531, 0.4917959703060728], 
             UndirectedEdge[176, 232] -> 
             RGBColor[
              0.9524398620769008, 0.8491469321510281, 0.28059020052839856`], 
             UndirectedEdge[60, 345] -> 
             RGBColor[
              0.9777396489882831, 0.9825456410246034, 0.905852213066939], 
             UndirectedEdge[79, 126] -> 
             RGBColor[
              0.9687254853457938, 0.9160740975001508, 0.5769281842056715], 
             UndirectedEdge[14, 212] -> 
             RGBColor[
              0.9735609112689525, 0.9203597334835822, 0.4556199487714685], 
             UndirectedEdge[22, 338] -> 
             RGBColor[
              0.9821309449283953, 0.9516166392525893, 0.5443746316671265], 
             UndirectedEdge[195, 389] -> 
             RGBColor[
              0.9305694245802564, 0.8768246144194645, 0.6330131236495031], 
             UndirectedEdge[14, 293] -> 
             RGBColor[
              0.9684622282478159, 0.91902317225215, 0.5962375625274845], 
             UndirectedEdge[201, 394] -> 
             RGBColor[
              0.9875336673189652, 0.9773334599199005, 0.6171487837812312], 
             UndirectedEdge[20, 189] -> 
             RGBColor[
              0.9648382279366128, 0.8930532278328138, 0.3179035845875785], 
             UndirectedEdge[195, 359] -> 
             RGBColor[
              0.9365013231924477, 0.7859559366774026, 0.2677656780163757], 
             UndirectedEdge[222, 224] -> 
             RGBColor[
              0.948180411068029, 0.8295414164757501, 0.2913194395356939], 
             UndirectedEdge[54, 389] -> 
             RGBColor[
              0.952123079126967, 0.9627785102231872, 0.9244917651934812], 
             UndirectedEdge[123, 366] -> 
             RGBColor[
              0.9254202769064283, 0.7223268531785867, 0.30313453489484765`], 
             UndirectedEdge[120, 263] -> 
             RGBColor[
              0.956561838285644, 0.8684563697225474, 0.5701117210501105], 
             UndirectedEdge[332, 364] -> 
             RGBColor[
              0.9342906521427878, 0.8321749543430872, 0.6064724885410357], 
             UndirectedEdge[70, 228] -> 
             RGBColor[
              0.9752167214615091, 0.9278867224178421, 0.3731539187926316], 
             UndirectedEdge[74, 141] -> 
             RGBColor[
              0.9438088528665185, 0.8020749685480847, 0.49637467682278125`], 
             UndirectedEdge[212, 385] -> 
             RGBColor[
              0.9937674634470528, 0.9890775594563805, 0.5630050428478518], 
             UndirectedEdge[256, 384] -> 
             RGBColor[
              0.9343779572124982, 0.7773679356442844, 0.2669402522494828], 
             UndirectedEdge[158, 317] -> 
             RGBColor[
              0.960184965032052, 0.8680070142089783, 0.5005366606026445], 
             UndirectedEdge[76, 208] -> 
             RGBColor[
              0.9260869607616697, 0.7446664600199212, 0.2593860375480669], 
             UndirectedEdge[101, 253] -> 
             RGBColor[
              0.9659342342753032, 0.8964923942671695, 0.3235046155591867], 
             UndirectedEdge[111, 309] -> 
             RGBColor[
              0.9556385161628249, 0.8532673021541558, 0.3277509313308915], 
             UndirectedEdge[145, 170] -> 
             RGBColor[
              0.9226020296922364, 0.7308498696140553, 0.25658198020775513`], 
             UndirectedEdge[59, 279] -> 
             RGBColor[
              0.9369172009127344, 0.7844247843776, 0.2846616349566755], 
             UndirectedEdge[83, 334] -> 
             RGBColor[
              0.9335031776352251, 0.7520796605395592, 0.47428058094493597`], 
             UndirectedEdge[242, 312] -> 
             RGBColor[
              0.9812342271386888, 0.9621667411896305, 0.6347205428246203], 
             UndirectedEdge[140, 356] -> 
             RGBColor[
              0.9864405157274435, 0.965922817009667, 0.4018243934052088], 
             UndirectedEdge[172, 316] -> 
             RGBColor[
              0.9552817638356501, 0.9628086966893428, 0.779391667679716], 
             UndirectedEdge[217, 331] -> 
             RGBColor[
              0.9918656865580009, 0.9909042665964827, 0.7844701548697046], 
             UndirectedEdge[263, 336] -> 
             RGBColor[
              0.9665336038593211, 0.9742449940460958, 0.9273648847031015], 
             UndirectedEdge[122, 338] -> 
             RGBColor[
              0.9740712252701071, 0.9239007288761751, 0.515817014372514], 
             UndirectedEdge[303, 400] -> 
             RGBColor[
              0.9603373732965526, 0.8709425923648484, 0.33650077631490916`], 
             UndirectedEdge[133, 367] -> 
             RGBColor[
              0.9868680451827274, 0.9715655978948577, 0.590215148383197], 
             UndirectedEdge[136, 279] -> 
             RGBColor[
              0.9422539775829661, 0.8260593610991871, 0.5836400589598126], 
             UndirectedEdge[117, 365] -> 
             RGBColor[
              0.9756741420675599, 0.9286656339028057, 0.4399023875331186], 
             UndirectedEdge[33, 245] -> 
             RGBColor[
              0.9885066770291968, 0.9721125201005456, 0.47617185959426783`], 
             UndirectedEdge[162, 368] -> 
             RGBColor[
              0.993930764996025, 0.9906674482333573, 0.6709581703675935], 
             UndirectedEdge[46, 128] -> 
             RGBColor[
              0.9370458391292553, 0.788114760917665, 0.2682038083205628], 
             UndirectedEdge[117, 269] -> 
             RGBColor[
              0.9815438673006819, 0.9830384030554309, 0.7641756822120813], 
             UndirectedEdge[98, 134] -> 
             RGBColor[
              0.9311637074606443, 0.7647940689558043, 0.26347090710862253`], 
             UndirectedEdge[90, 326] -> 
             RGBColor[
              0.9944888115716911, 0.9909840379297938, 0.667948327533696], 
             UndirectedEdge[119, 306] -> 
             RGBColor[
              0.9562469160945402, 0.8935535633252862, 0.6042224029540878], 
             UndirectedEdge[150, 211] -> 
             RGBColor[
              0.9573466941377081, 0.8563521837708082, 0.4262166575950905], 
             UndirectedEdge[388, 395] -> 
             RGBColor[
              0.9579770301812327, 0.8660677231795378, 0.3112535032113781], 
             UndirectedEdge[102, 108] -> 
             RGBColor[
              0.9805804997862724, 0.9449936536478103, 0.4778634845867417], 
             UndirectedEdge[15, 392] -> 
             RGBColor[
              0.9920695200147376, 0.9890177085995439, 0.6378322358520884], 
             UndirectedEdge[32, 292] -> 
             RGBColor[
              0.9885004913260917, 0.9879409355033768, 0.7297303546828191], 
             UndirectedEdge[115, 332] -> 
             RGBColor[
              0.953514209098481, 0.8451447998725592, 0.5127126495032157], 
             UndirectedEdge[93, 293] -> 
             RGBColor[
              0.9448328342271283, 0.9575976376133932, 0.9512468660940101], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.961121748419362, 0.8739800210819613, 0.33750874082838134`], 
             UndirectedEdge[276, 305] -> 
             RGBColor[
              0.9867106187613394, 0.9694734524944287, 0.5788132484354911], 
             UndirectedEdge[75, 347] -> 
             RGBColor[
              0.9848054267268311, 0.9861256477643285, 0.8106086282163281], 
             UndirectedEdge[64, 193] -> 
             RGBColor[
              0.9755817259681674, 0.9292935693865456, 0.35964004570080266`], 
             UndirectedEdge[18, 99] -> 
             RGBColor[
              0.9738792928775255, 0.9235508628215119, 0.353026414621172], 
             UndirectedEdge[74, 290] -> 
             RGBColor[
              0.9791048305416624, 0.9422700569809539, 0.5385714147882601], 
             UndirectedEdge[39, 230] -> 
             RGBColor[
              0.9810417224847401, 0.9699767405831536, 0.6561951564960091], 
             UndirectedEdge[259, 345] -> 
             RGBColor[
              0.9701833584613992, 0.9218540785961096, 0.5781012231351679], 
             UndirectedEdge[30, 168] -> 
             RGBColor[
              0.9901565640265126, 0.9768530028186837, 0.5527311536947184], 
             UndirectedEdge[231, 331] -> 
             RGBColor[
              0.9417793688503286, 0.8027294047958251, 0.5363082102576555], 
             UndirectedEdge[137, 242] -> 
             RGBColor[
              0.9558342307073215, 0.8561839781077674, 0.3167594339836132], 
             UndirectedEdge[172, 221] -> 
             RGBColor[
              0.9229099940740124, 0.8464575248161181, 0.626850166074238], 
             UndirectedEdge[157, 211] -> 
             RGBColor[
              0.9679020677695398, 0.8982007228512705, 0.43470975898572545`], 
             UndirectedEdge[46, 213] -> 
             RGBColor[
              0.9337722333415792, 0.8538652839685485, 0.6244784745811134], 
             UndirectedEdge[184, 318] -> 
             RGBColor[
              0.9602701374383079, 0.8687965883361102, 0.37803813921183493`], 
             UndirectedEdge[201, 293] -> 
             RGBColor[
              0.9865467726004241, 0.9887043268280508, 0.8725989711760385], 
             UndirectedEdge[64, 115] -> 
             RGBColor[
              0.9865919125102571, 0.9689530171669729, 0.5775225836470326], 
             UndirectedEdge[174, 266] -> 
             RGBColor[
              0.9933297948934006, 0.9881414306751972, 0.5153675217600272], 
             UndirectedEdge[80, 104] -> 
             RGBColor[
              0.9940475871845954, 0.9896767158061299, 0.5934947829560482], 
             UndirectedEdge[265, 321] -> 
             RGBColor[
              0.9934784440543454, 0.9900387228562837, 0.6463488950736979], 
             UndirectedEdge[178, 296] -> 
             RGBColor[
              0.9592459906012656, 0.8741892981809192, 0.2961787985451627], 
             UndirectedEdge[114, 249] -> 
             RGBColor[
              0.9782289382631284, 0.9449812033259268, 0.5743300993968283], 
             UndirectedEdge[255, 380] -> 
             RGBColor[
              0.9684040906120452, 0.9050817199414192, 0.33175628772497034`], 
             UndirectedEdge[253, 391] -> 
             RGBColor[
              0.9522952737811736, 0.8485736877396631, 0.2804738613917329], 
             UndirectedEdge[40, 63] -> 
             RGBColor[
              0.9629443485363851, 0.8875458780506698, 0.544834568740022], 
             UndirectedEdge[23, 311] -> 
             RGBColor[
              0.9605392036272384, 0.8715789355410499, 0.5114280874944397], 
             UndirectedEdge[156, 396] -> 
             RGBColor[
              0.9812344908846278, 0.9472523888316535, 0.4759254701033331], 
             UndirectedEdge[93, 281] -> 
             RGBColor[
              0.9339257149674327, 0.9061054687093621, 0.649590680389825], 
             UndirectedEdge[27, 325] -> 
             RGBColor[
              0.9789017395679354, 0.9424390088376181, 0.5436854364366686], 
             UndirectedEdge[12, 107] -> 
             RGBColor[
              0.989792607705325, 0.9900469952152048, 0.818826436414636], 
             UndirectedEdge[255, 312] -> 
             RGBColor[
              0.9721900522139446, 0.93165861549521, 0.5995856310911127], 
             UndirectedEdge[257, 310] -> 
             RGBColor[
              0.9653735559577076, 0.8938518245800824, 0.3252286974215489], 
             UndirectedEdge[50, 197] -> 
             RGBColor[
              0.982996674849179, 0.9542591631257005, 0.39242270080168673`], 
             UndirectedEdge[215, 350] -> 
             RGBColor[
              0.9422579523321573, 0.7940317017717566, 0.490858802610669], 
             UndirectedEdge[49, 235] -> 
             RGBColor[
              0.9836677483082794, 0.9647396737694408, 0.6052191425771579], 
             UndirectedEdge[239, 323] -> 
             RGBColor[
              0.9137712315652969, 0.6892631389275634, 0.24913636590577692`], 
             UndirectedEdge[211, 216] -> 
             RGBColor[
              0.9941500146177041, 0.9898957977285474, 0.604643376941088], 
             UndirectedEdge[98, 151] -> 
             RGBColor[
              0.9639293487553467, 0.8836325137574863, 0.5073676451111275], 
             UndirectedEdge[10, 32] -> 
             RGBColor[
              0.9664173548425572, 0.971471368471774, 0.7671113445450142], 
             UndirectedEdge[330, 367] -> 
             RGBColor[
              0.9834317264604799, 0.9701445917938454, 0.6471638425186217], 
             UndirectedEdge[99, 384] -> 
             RGBColor[
              0.9418411733253957, 0.8025431160395644, 0.2959334375379865], 
             UndirectedEdge[127, 138] -> 
             RGBColor[
              0.9438026139832416, 0.8161958141844552, 0.5560449004615138], 
             UndirectedEdge[292, 385] -> 
             RGBColor[
              0.9882668778800936, 0.987441259964329, 0.7043029727809738], 
             UndirectedEdge[177, 219] -> 
             RGBColor[
              0.9877898138569492, 0.9881862139373054, 0.7924501269684339], 
             UndirectedEdge[170, 322] -> 
             RGBColor[
              0.9519298480879385, 0.8576377400267965, 0.5861627201287534], 
             UndirectedEdge[261, 335] -> 
             RGBColor[
              0.9353376097680933, 0.7682298907563332, 0.3091348216078169], 
             UndirectedEdge[6, 253] -> 
             RGBColor[
              0.9750433692865281, 0.9256810903943742, 0.4897195129491932], 
             UndirectedEdge[95, 246] -> 
             RGBColor[
              0.9181586790269998, 0.7132334648852265, 0.2530067559636606], 
             UndirectedEdge[50, 331] -> 
             RGBColor[
              0.990590480761654, 0.988044905920263, 0.6360896298039453], 
             UndirectedEdge[9, 358] -> 
             RGBColor[
              0.9665778964985652, 0.893684741160532, 0.3902150567845551], 
             UndirectedEdge[99, 144] -> 
             RGBColor[
              0.9673881164569915, 0.9016546005543475, 0.32780941998320745`], 
             UndirectedEdge[2, 28] -> 
             RGBColor[
              0.9494179598245689, 0.8258218396586351, 0.3663167604125671], 
             UndirectedEdge[138, 258] -> 
             RGBColor[
              0.9689591293468962, 0.9168404447934795, 0.5763333636414616], 
             UndirectedEdge[144, 384] -> 
             RGBColor[
              0.9377664611077744, 0.7887981549416012, 0.2801039500173635], 
             UndirectedEdge[79, 277] -> 
             RGBColor[
              0.9316160518590044, 0.7665874637604675, 0.26383487402943084`], 
             UndirectedEdge[346, 354] -> 
             RGBColor[
              0.9730720924419559, 0.9208279862126603, 0.3498905933559958], 
             UndirectedEdge[144, 148] -> 
             RGBColor[
              0.9592021074906618, 0.8737833498440354, 0.2973515742563235], 
             UndirectedEdge[38, 346] -> 
             RGBColor[
              0.9532955026233518, 0.8460534277375853, 0.31505700299297057`], 
             UndirectedEdge[38, 363] -> 
             RGBColor[
              0.9596124036511633, 0.8726797932387338, 0.5340499457316912], 
             UndirectedEdge[78, 104] -> 
             RGBColor[
              0.991538849447289, 0.9827505687053415, 0.4531032229416111], 
             UndirectedEdge[95, 282] -> 
             RGBColor[
              0.953609922580804, 0.8446021705178287, 0.32936032454583786`], 
             UndirectedEdge[92, 306] -> 
             RGBColor[
              0.9628797737212652, 0.8824864774551291, 0.33092131759489474`], 
             UndirectedEdge[9, 339] -> 
             RGBColor[
              0.9665190086150143, 0.8935587859320948, 0.3838054740739302], 
             UndirectedEdge[36, 148] -> 
             RGBColor[
              0.968576129578009, 0.9054041274697124, 0.3337678799301335], 
             UndirectedEdge[62, 395] -> 
             RGBColor[
              0.9833069050102293, 0.9546545887832296, 0.4489887784186893], 
             UndirectedEdge[32, 247] -> 
             RGBColor[
              0.9802804514205805, 0.9818104432009265, 0.7436447381130833], 
             UndirectedEdge[168, 379] -> 
             RGBColor[
              0.9483672938410339, 0.8243518477111176, 0.3223559373349455], 
             UndirectedEdge[137, 230] -> 
             RGBColor[
              0.9562121889882599, 0.8797242410162576, 0.5935717858957728], 
             UndirectedEdge[268, 279] -> 
             RGBColor[
              0.5430224727337309, 0.48742731771400905`, 0.5888120612911658], 
             UndirectedEdge[185, 288] -> 
             RGBColor[
              0.9930199646823371, 0.987478735182372, 0.4816444153361898], 
             UndirectedEdge[233, 310] -> 
             RGBColor[
              0.9730046340631706, 0.9190074231180119, 0.4046878798955861], 
             UndirectedEdge[150, 386] -> 
             RGBColor[
              0.947922005311089, 0.8255362182804684, 0.3066350849882977], 
             UndirectedEdge[138, 281] -> 
             RGBColor[
              0.9744518210307204, 0.9367209587379333, 0.5906282408601676], 
             UndirectedEdge[88, 257] -> 
             RGBColor[
              0.923063655066793, 0.715653912775913, 0.29064442204040936`], 
             UndirectedEdge[27, 40] -> 
             RGBColor[
              0.9506437710461724, 0.8393549406278129, 0.2930561009491899], 
             UndirectedEdge[159, 250] -> 
             RGBColor[
              0.9445886569700723, 0.8198707821750255, 0.5571467214389327], 
             UndirectedEdge[169, 363] -> 
             RGBColor[
              0.992127531912983, 0.9896698740920383, 0.6825325983462727], 
             UndirectedEdge[144, 382] -> 
             RGBColor[
              0.9738684964716406, 0.9235144440093455, 0.35298447262303945`], 
             UndirectedEdge[35, 207] -> 
             RGBColor[
              0.9418904950895756, 0.8073222074144382, 0.2721019322249275], 
             UndirectedEdge[71, 287] -> 
             RGBColor[
              0.991876683777655, 0.9852179769820817, 0.5872577178131281], 
             UndirectedEdge[148, 361] -> 
             RGBColor[
              0.9725469366012012, 0.9187985919487663, 0.3491937153912491], 
             UndirectedEdge[215, 393] -> 
             RGBColor[
              0.9125116535841988, 0.6869328503547749, 0.2482606609427429], 
             UndirectedEdge[33, 124] -> 
             RGBColor[
              0.9867844764057929, 0.9670830771435474, 0.40316061568907235`], 
             UndirectedEdge[31, 111] -> 
             RGBColor[
              0.9853187623145585, 0.9621388793477789, 0.39746659322150735`], 
             UndirectedEdge[113, 357] -> 
             RGBColor[
              0.9052163764084544, 0.6660196612023416, 0.5692387217856651], 
             UndirectedEdge[30, 329] -> 
             RGBColor[
              0.9894595878112143, 0.9896927410549936, 0.8103497248037049], 
             UndirectedEdge[117, 239] -> 
             RGBColor[
              0.970084438294056, 0.9069064125667599, 0.43331068147252455`], 
             UndirectedEdge[209, 338] -> 
             RGBColor[
              0.9678089312316671, 0.8990728197995427, 0.5107782255942517], 
             UndirectedEdge[208, 323] -> 
             RGBColor[
              0.8950090848772774, 0.6148774794243195, 0.23403990227641092`], 
             UndirectedEdge[71, 212] -> 
             RGBColor[
              0.9923321273799492, 0.9846340072308923, 0.523571244666964], 
             UndirectedEdge[199, 292] -> 
             RGBColor[
              0.9841653156376695, 0.9875859919438019, 0.9060856269643206], 
             UndirectedEdge[11, 386] -> 
             RGBColor[
              0.9499605397714683, 0.8336183281145326, 0.3082753376656726], 
             UndirectedEdge[130, 267] -> 
             RGBColor[
              0.984748357712148, 0.9740602625275132, 0.6486455323662841], 
             UndirectedEdge[67, 347] -> 
             RGBColor[
              0.9662576860133449, 0.9250795969952998, 0.6093184557606086], 
             UndirectedEdge[211, 358] -> 
             RGBColor[
              0.9936819915348682, 0.9888947436787537, 0.5537019526780589], 
             UndirectedEdge[2, 164] -> 
             RGBColor[
              0.9501055787940733, 0.8285480197372816, 0.366870034775922], 
             UndirectedEdge[266, 358] -> 
             RGBColor[
              0.9935435267624793, 0.9885985815315498, 0.5386309167090458], 
             UndirectedEdge[57, 397] -> 
             RGBColor[
              0.9489835921783765, 0.834206566031555, 0.28425364500124284`], 
             UndirectedEdge[209, 386] -> 
             RGBColor[
              0.9584427662251601, 0.8672475294690138, 0.3151003361737575], 
             UndirectedEdge[74, 386] -> 
             RGBColor[
              0.9843097769496172, 0.9598275633945195, 0.558791648711511], 
             UndirectedEdge[47, 268] -> 
             RGBColor[
              0.5858969401843492, 0.6462726516573487, 0.6992415662617538], 
             UndirectedEdge[108, 397] -> 
             RGBColor[
              0.9772665825613787, 0.9338150327034765, 0.46498954194878617`], 
             UndirectedEdge[157, 358] -> 
             RGBColor[
              0.9675000910721286, 0.8973409353415864, 0.390957076185133], 
             UndirectedEdge[10, 129] -> 
             RGBColor[
              0.9666224415217302, 0.9719100281410809, 0.7894337639247211], 
             UndirectedEdge[171, 308] -> 
             RGBColor[
              0.9897294884201906, 0.9770172941898152, 0.4146014312461539], 
             UndirectedEdge[225, 335] -> 
             RGBColor[
              0.9806365241554, 0.9463445905951365, 0.37927698213966005`], 
             UndirectedEdge[45, 116] -> 
             RGBColor[
              0.993573124741386, 0.9886618886156167, 0.5418524740554931], 
             UndirectedEdge[261, 349] -> 
             RGBColor[
              0.9193356172790227, 0.7129595390449777, 0.25369820217300043`], 
             UndirectedEdge[118, 209] -> 
             RGBColor[
              0.9653343334316922, 0.8980495100149903, 0.5517887151936556], 
             UndirectedEdge[329, 343] -> 
             RGBColor[
              0.9871892769505866, 0.9889079373276709, 0.8591708722140674], 
             UndirectedEdge[163, 171] -> 
             RGBColor[
              0.9671296375734797, 0.8977992995676576, 0.3423428294650678], 
             UndirectedEdge[106, 217] -> 
             RGBColor[
              0.969200134171673, 0.9747330258608401, 0.8556484283846753], 
             UndirectedEdge[55, 123] -> 
             RGBColor[
              0.9667895270782307, 0.9612354476715224, 0.6843282110600086], 
             UndirectedEdge[129, 353] -> 
             RGBColor[
              0.9942325936966199, 0.990799131585501, 0.6664554225750852], 
             UndirectedEdge[38, 66] -> 
             RGBColor[
              0.9591609645959993, 0.865839008247289, 0.3378432151571542], 
             UndirectedEdge[23, 119] -> 
             RGBColor[
              0.9488915011667861, 0.8643917941834665, 0.5983040634494383], 
             UndirectedEdge[306, 354] -> 
             RGBColor[
              0.9554094376842633, 0.8572872798840079, 0.3019004727457309], 
             UndirectedEdge[28, 39] -> 
             RGBColor[
              0.9446977714697922, 0.8102637959975023, 0.31700567782060574`], 
             UndirectedEdge[158, 267] -> 
             RGBColor[
              0.955329986879609, 0.8520985502914946, 0.3272190323335086], 
             UndirectedEdge[194, 399] -> 
             RGBColor[
              0.9289841382089452, 0.7530378409983585, 0.26815044000362787`], 
             UndirectedEdge[102, 333] -> 
             RGBColor[
              0.9453143037207465, 0.8176991034600289, 0.29150873643013514`], 
             UndirectedEdge[16, 80] -> 
             RGBColor[
              0.9923173008963604, 0.9842101789524216, 0.555300181689064], 
             UndirectedEdge[72, 333] -> 
             RGBColor[
              0.9585009394464247, 0.8617823078485749, 0.37661460097915134`], 
             UndirectedEdge[167, 211] -> 
             RGBColor[
              0.9893612305897852, 0.9747993511127905, 0.496139255333208], 
             UndirectedEdge[193, 255] -> 
             RGBColor[
              0.9649932319172931, 0.8935760926563139, 0.3185057457824758], 
             UndirectedEdge[168, 211] -> 
             RGBColor[
              0.9896468205152349, 0.9757627129910356, 0.49724871826444783`], 
             UndirectedEdge[70, 246] -> 
             RGBColor[
              0.9368810556831719, 0.7869637843879564, 0.2706630678706965], 
             UndirectedEdge[322, 349] -> 
             RGBColor[
              0.9665995216860997, 0.9157981074645662, 0.5979662838473296], 
             UndirectedEdge[193, 312] -> 
             RGBColor[
              0.9775969409842534, 0.9498973209153176, 0.6205903729584942], 
             UndirectedEdge[194, 221] -> 
             RGBColor[
              0.9446310264837691, 0.8169337525441234, 0.28083657223779745`], 
             UndirectedEdge[208, 221] -> 
             RGBColor[
              0.9188391842523718, 0.7159314413389026, 0.2535543064415055], 
             UndirectedEdge[112, 251] -> 
             RGBColor[
              0.9362230395724289, 0.9138548840394831, 0.6585153526668861], 
             UndirectedEdge[297, 325] -> 
             RGBColor[
              0.9931788866879872, 0.9899530586035538, 0.6540908297761041], 
             UndirectedEdge[170, 225] -> 
             RGBColor[
              0.9499648580681681, 0.8329138714460111, 0.3120367989862674], 
             UndirectedEdge[27, 250] -> 
             RGBColor[
              0.933847842118157, 0.772324846687176, 0.27951895019520057`], 
             UndirectedEdge[67, 126] -> 
             RGBColor[
              0.9721542485594004, 0.9291040375317996, 0.5826241792867214], 
             UndirectedEdge[12, 157] -> 
             RGBColor[
              0.9656148638127533, 0.8982884311804775, 0.5477410733034324], 
             UndirectedEdge[316, 399] -> 
             RGBColor[
              0.945784229101484, 0.8089062437303258, 0.4016330591521861], 
             UndirectedEdge[76, 377] -> 
             RGBColor[
              0.9084934677518646, 0.6660436382292566, 0.24477103911812267`], 
             UndirectedEdge[3, 51] -> 
             RGBColor[
              0.9889855935903332, 0.9873435884620809, 0.6599496157227057], 
             UndirectedEdge[23, 186] -> 
             RGBColor[
              0.9206932029975274, 0.7232820078483232, 0.2550460934432711], 
             UndirectedEdge[17, 319] -> 
             RGBColor[
              0.9721368393936516, 0.9591724716545766, 0.6624314936090709], 
             UndirectedEdge[115, 360] -> 
             RGBColor[
              0.9833816813252794, 0.9581241535819158, 0.5650514416946852], 
             UndirectedEdge[131, 142] -> 
             RGBColor[
              0.9752159009830618, 0.9288625120377694, 0.5214642179200133], 
             UndirectedEdge[23, 130] -> 
             RGBColor[
              0.9563132769215098, 0.8698314062468686, 0.5814626293561032], 
             UndirectedEdge[348, 354] -> 
             RGBColor[
              0.9678865484021024, 0.9033359285425928, 0.32974573396898865`], 
             UndirectedEdge[76, 80] -> 
             RGBColor[
              0.9692736798376458, 0.9028093609664383, 0.48488970277905874`], 
             UndirectedEdge[38, 81] -> 
             RGBColor[
              0.9344347543879661, 0.7777626800108639, 0.2661028682476854], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.9079476102377695, 0.6609345394721352, 0.24417948984707286`], 
             UndirectedEdge[131, 281] -> 
             RGBColor[
              0.977977798550069, 0.938179041055673, 0.5321936684272455], 
             UndirectedEdge[157, 167] -> 
             RGBColor[
              0.9631793301270457, 0.8832455427756232, 0.33339437884028217`], 
             UndirectedEdge[165, 172] -> 
             RGBColor[
              0.9551666475137945, 0.9625624745169392, 0.7668619664613265], 
             UndirectedEdge[255, 331] -> 
             RGBColor[
              0.974094261556568, 0.9324460549943326, 0.5680279543480338], 
             UndirectedEdge[59, 268] -> 
             RGBColor[
              0.5728217281790035, 0.6023914666635909, 0.6293505736655096], 
             UndirectedEdge[161, 364] -> 
             RGBColor[
              0.9594277579581635, 0.9291976714038626, 0.6404347004788686], 
             UndirectedEdge[149, 164] -> 
             RGBColor[
              0.9407666567235966, 0.7974099027228446, 0.29961604387314195`], 
             UndirectedEdge[10, 52] -> 
             RGBColor[
              0.9621765129419587, 0.971155434357732, 0.941903261834256], 
             UndirectedEdge[132, 155] -> 
             RGBColor[
              0.9933393172624205, 0.9911529532329311, 0.7338293777193092], 
             UndirectedEdge[353, 400] -> 
             RGBColor[
              0.9634870387032524, 0.8810986359644666, 0.5031935865881232], 
             UndirectedEdge[250, 265] -> 
             RGBColor[
              0.9481028430631959, 0.8197915280240808, 0.38751386905482643`], 
             UndirectedEdge[82, 233] -> 
             RGBColor[
              0.9500434918143812, 0.827974145448639, 0.3862128058749311], 
             UndirectedEdge[66, 81] -> 
             RGBColor[
              0.9649003602932326, 0.8885937996465798, 0.3424612676560801], 
             UndirectedEdge[69, 201] -> 
             RGBColor[
              0.9730005762895817, 0.9283099313457419, 0.5606904694760309], 
             UndirectedEdge[84, 184] -> 
             RGBColor[
              0.9499431273509785, 0.8278534346119595, 0.36972878448948776`], 
             UndirectedEdge[180, 268] -> 
             RGBColor[
              0.5858942116565481, 0.6462668156122784, 0.6989445828491139], 
             UndirectedEdge[17, 247] -> 
             RGBColor[
              0.9653676210220128, 0.9736918089803088, 0.943507763425382], 
             UndirectedEdge[188, 394] -> 
             RGBColor[
              0.9714440877595207, 0.9153363441451288, 0.3435661025876225], 
             UndirectedEdge[241, 312] -> 
             RGBColor[
              0.9817707768318341, 0.9639766492924686, 0.6368049370635824], 
             UndirectedEdge[81, 128] -> 
             RGBColor[
              0.9429703411910061, 0.8116034373692285, 0.27297080174538424`], 
             UndirectedEdge[65, 198] -> 
             RGBColor[
              0.9772123724057009, 0.9344052779750203, 0.39903934907035493`], 
             UndirectedEdge[356, 380] -> 
             RGBColor[
              0.9825504715843938, 0.95280078468936, 0.386712306482657], 
             UndirectedEdge[40, 265] -> 
             RGBColor[
              0.9648987719912114, 0.8868216219647177, 0.40105101980881563`], 
             UndirectedEdge[19, 168] -> 
             RGBColor[
              0.9531266649683735, 0.8432211682646084, 0.32618543906080166`], 
             UndirectedEdge[195, 241] -> 
             RGBColor[
              0.9615630005049607, 0.8785793087201411, 0.3230216103957209], 
             UndirectedEdge[33, 141] -> 
             RGBColor[
              0.9387396747554551, 0.7838832118761285, 0.3114371039933598], 
             UndirectedEdge[65, 100] -> 
             RGBColor[
              0.9607680721273404, 0.8707848882416851, 0.3776011841494943], 
             UndirectedEdge[15, 207] -> 
             RGBColor[
              0.9597333666706135, 0.8720724757423561, 0.5288286430312765], 
             UndirectedEdge[81, 135] -> 
             RGBColor[
              0.9466926189192469, 0.8263610281861808, 0.2759658337786147], 
             UndirectedEdge[259, 271] -> 
             RGBColor[
              0.9392483453509166, 0.7968469641448628, 0.26997599652597726`], 
             UndirectedEdge[194, 233] -> 
             RGBColor[
              0.9768274558711427, 0.9329098890864287, 0.4142933561800034], 
             UndirectedEdge[101, 283] -> 
             RGBColor[
              0.980401388212426, 0.9455514218469402, 0.3783635234029028], 
             UndirectedEdge[145, 192] -> 
             RGBColor[
              0.9570453118120693, 0.86141523396941, 0.526665770995335], 
             UndirectedEdge[68, 397] -> 
             RGBColor[
              0.9413434938591241, 0.8039161221075609, 0.2781062425574158], 
             UndirectedEdge[142, 201] -> 
             RGBColor[
              0.9728777557737212, 0.927895628906116, 0.5602133349646211], 
             UndirectedEdge[146, 354] -> 
             RGBColor[
              0.9797748797375067, 0.9476139256023436, 0.5624884019966284], 
             UndirectedEdge[153, 329] -> 
             RGBColor[
              0.9339054537226754, 0.7767907170231532, 0.5685975113193913], 
             UndirectedEdge[132, 279] -> 
             RGBColor[
              0.9494663447869689, 0.8301719180058169, 0.5147187628543242], 
             UndirectedEdge[257, 389] -> 
             RGBColor[
              0.9474753453559231, 0.937278062820494, 0.6808477675424067], 
             UndirectedEdge[107, 386] -> 
             RGBColor[
              0.9826551228354926, 0.9591433213956579, 0.5862135494901363], 
             UndirectedEdge[157, 203] -> 
             RGBColor[
              0.9333300805556837, 0.7733830163765966, 0.26521402175220343`], 
             UndirectedEdge[264, 281] -> 
             RGBColor[
              0.9779219636412768, 0.9381559518859955, 0.5331189973620472], 
             UndirectedEdge[244, 302] -> 
             RGBColor[
              0.9780535500277083, 0.9368731500811487, 0.43373677214338197`], 
             UndirectedEdge[46, 105] -> 
             RGBColor[
              0.9610392895245516, 0.8712938342214049, 0.41133242934127745`], 
             UndirectedEdge[126, 347] -> 
             RGBColor[
              0.9805418224037021, 0.984635497369685, 0.901108864398511], 
             UndirectedEdge[129, 253] -> 
             RGBColor[
              0.9745581865319766, 0.9246433335418894, 0.43691036431712316`], 
             UndirectedEdge[14, 69] -> 
             RGBColor[
              0.9549160319369734, 0.8586287767698412, 0.2843290608274769], 
             UndirectedEdge[118, 124] -> 
             RGBColor[
              0.9896700353528125, 0.9843718511747186, 0.6242864090919467], 
             UndirectedEdge[181, 245] -> 
             RGBColor[
              0.9108132114046413, 0.6021116402462015, 0.36861941039318635`], 
             UndirectedEdge[33, 152] -> 
             RGBColor[
              0.9859345199474319, 0.972356055527887, 0.6138179622318192], 
             UndirectedEdge[47, 371] -> 
             RGBColor[
              0.9940245404729847, 0.9896274212203746, 0.5909862906250436], 
             UndirectedEdge[131, 273] -> 
             RGBColor[
              0.9877636415037548, 0.9711889871636475, 0.5702098204009357], 
             UndirectedEdge[230, 299] -> 
             RGBColor[
              0.9699908871289215, 0.932699678068444, 0.613264747913803], 
             UndirectedEdge[107, 181] -> 
             RGBColor[
              0.9089676654704496, 0.6026556480561189, 0.49422368590607857`], 
             UndirectedEdge[4, 318] -> 
             RGBColor[
              0.9435924346404769, 0.8596868902734885, 0.606689886787767], 
             UndirectedEdge[10, 333] -> 
             RGBColor[
              0.9315363235880848, 0.8450006468687, 0.6226794091099044], 
             UndirectedEdge[152, 238] -> 
             RGBColor[
              0.978598854868223, 0.9476111347196454, 0.585320288623204], 
             UndirectedEdge[50, 147] -> 
             RGBColor[
              0.9627369766415412, 0.8790969184397253, 0.34924421936303773`], 
             UndirectedEdge[39, 217] -> 
             RGBColor[
              0.9893910142804905, 0.9743865635823927, 0.5606900933720127], 
             UndirectedEdge[98, 308] -> 
             RGBColor[
              0.9624662575718435, 0.8785153661590424, 0.3427319049965225], 
             UndirectedEdge[31, 363] -> 
             RGBColor[
              0.9881265639872789, 0.9769282287484949, 0.6028273476035089], 
             UndirectedEdge[286, 386] -> 
             RGBColor[
              0.9719014307672059, 0.9168790694992959, 0.34534279381049937`], 
             UndirectedEdge[137, 138] -> 
             RGBColor[
              0.9602611251094135, 0.8823557564299511, 0.5693347452635829], 
             UndirectedEdge[35, 372] -> 
             RGBColor[
              0.9318463536825077, 0.8953858669177804, 0.6370632837120811], 
             UndirectedEdge[130, 158] -> 
             RGBColor[
              0.9553486758254031, 0.8660070843350656, 0.5806864886720778], 
             UndirectedEdge[277, 373] -> 
             RGBColor[
              0.9468638737201538, 0.8377080593777182, 0.5822069455249564], 
             UndirectedEdge[234, 365] -> 
             RGBColor[
              0.9738420885864807, 0.928991944646292, 0.5490532105654077], 
             UndirectedEdge[310, 316] -> 
             RGBColor[
              0.9731799744374345, 0.9193824584489312, 0.4237725975588581], 
             UndirectedEdge[218, 305] -> 
             RGBColor[
              0.9909033271873187, 0.9905063062651978, 0.8004189401481256], 
             UndirectedEdge[155, 279] -> 
             RGBColor[
              0.9509909179429137, 0.8304416706551324, 0.4632337374473169], 
             UndirectedEdge[32, 129] -> 
             RGBColor[
              0.9938204756428266, 0.9891909471827856, 0.5687750932044768], 
             UndirectedEdge[92, 158] -> 
             RGBColor[
              0.9545597576974043, 0.8495003864015063, 0.32422683740622005`], 
             UndirectedEdge[332, 334] -> 
             RGBColor[
              0.8933394081036243, 0.6055707644700485, 0.23255744527436628`], 
             UndirectedEdge[268, 300] -> 
             RGBColor[
              0.586386976077361, 0.6473207888822718, 0.7525789490650929], 
             UndirectedEdge[224, 227] -> 
             RGBColor[
              0.9763333660775062, 0.9318290279688355, 0.3625600255902591], 
             UndirectedEdge[25, 91] -> 
             RGBColor[
              0.9522807757301197, 0.835751769126968, 0.45265902267232133`], 
             UndirectedEdge[74, 304] -> 
             RGBColor[
              0.989409697492299, 0.9898886520017749, 0.8251722495843439], 
             UndirectedEdge[86, 397] -> 
             RGBColor[
              0.9182309951786534, 0.7042425881659282, 0.2590934734982831], 
             UndirectedEdge[32, 111] -> 
             RGBColor[
              0.9892646171149031, 0.9747626432889704, 0.4711731203876948], 
             UndirectedEdge[59, 394] -> 
             RGBColor[
              0.9764398222876323, 0.9321881297626976, 0.3629735878640306], 
             UndirectedEdge[170, 355] -> 
             RGBColor[
              0.9364523990540297, 0.785761968771578, 0.2677263125062075], 
             UndirectedEdge[9, 56] -> 
             RGBColor[
              0.9050348977146396, 0.6513988500891685, 0.24193994433832966`], 
             UndirectedEdge[44, 317] -> 
             RGBColor[
              0.9938444422817287, 0.9917225329399466, 0.7516770516718742], 
             UndirectedEdge[236, 262] -> 
             RGBColor[
              0.9903176242013378, 0.9817053701436473, 0.5932725819422116], 
             UndirectedEdge[119, 346] -> 
             RGBColor[
              0.9739095708522327, 0.9570942696539386, 0.6522125235643527], 
             UndirectedEdge[80, 244] -> 
             RGBColor[
              0.9943621994183289, 0.9903496395619097, 0.6277383830362975], 
             UndirectedEdge[20, 360] -> 
             RGBColor[
              0.9673730654104481, 0.9016038298402029, 0.327750949509538], 
             UndirectedEdge[196, 206] -> 
             RGBColor[
              0.9529813843237767, 0.8766144489328087, 0.5984973954395203], 
             UndirectedEdge[187, 302] -> 
             RGBColor[
              0.9781044979045339, 0.936982122438058, 0.43928213412199085`], 
             UndirectedEdge[147, 312] -> 
             RGBColor[
              0.9588444665034155, 0.8798192957727987, 0.5832671710831446], 
             UndirectedEdge[259, 400] -> 
             RGBColor[
              0.9432313921541529, 0.812638417448029, 0.2731808494779858], 
             UndirectedEdge[120, 312] -> 
             RGBColor[
              0.9559104798176611, 0.8681870162568874, 0.5809064165262677], 
             UndirectedEdge[52, 60] -> 
             RGBColor[
              0.9770873090946328, 0.9822758817142083, 0.9166631733062538], 
             UndirectedEdge[266, 384] -> 
             RGBColor[
              0.9530132783318401, 0.8394244386604239, 0.4077702655563839], 
             UndirectedEdge[135, 393] -> 
             RGBColor[
              0.9437942592053812, 0.8148699977418234, 0.27363374551959196`], 
             UndirectedEdge[77, 244] -> 
             RGBColor[
              0.9934583990285889, 0.9884165019164924, 0.5293652882225575], 
             UndirectedEdge[239, 385] -> 
             RGBColor[
              0.9696457381688848, 0.9059680773584051, 0.38556088019097234`], 
             UndirectedEdge[278, 296] -> 
             RGBColor[
              0.9746037996431088, 0.9259947942641027, 0.35584098659384084`], 
             UndirectedEdge[267, 275] -> 
             RGBColor[
              0.9521656172375168, 0.8395528791242732, 0.3246729062421793], 
             UndirectedEdge[148, 340] -> 
             RGBColor[
              0.9742047937759162, 0.9238874621701649, 0.3984457437072443], 
             UndirectedEdge[202, 212] -> 
             RGBColor[
              0.9933412405295217, 0.990742138698609, 0.7038778129444477], 
             UndirectedEdge[81, 346] -> 
             RGBColor[
              0.9590348983205852, 0.8688082191368762, 0.31967505549189645`], 
             UndirectedEdge[50, 217] -> 
             RGBColor[
              0.9938539873535033, 0.9893944497642865, 0.5820048798926766], 
             UndirectedEdge[5, 183] -> 
             RGBColor[
              0.9527933819944254, 0.8445357996486924, 0.3121890050124395], 
             UndirectedEdge[313, 339] -> 
             RGBColor[
              0.970284321153819, 0.9084869954324328, 0.3868351329258972], 
             UndirectedEdge[4, 184] -> 
             RGBColor[
              0.9764708496403094, 0.9786440733271975, 0.7242921465796844], 
             UndirectedEdge[104, 349] -> 
             RGBColor[
              0.9723485428316758, 0.9167252847934004, 0.3852806051877784], 
             UndirectedEdge[119, 135] -> 
             RGBColor[
              0.9615672914508946, 0.9146470787032432, 0.6085033018510709], 
             UndirectedEdge[53, 273] -> 
             RGBColor[
              0.9880460361569188, 0.9713057646099423, 0.5655298101840748], 
             UndirectedEdge[224, 259] -> 
             RGBColor[
              0.9595416499598861, 0.8745849427735342, 0.3004609590306341], 
             UndirectedEdge[110, 289] -> 
             RGBColor[
              0.9693362006527719, 0.9042886139766366, 0.5078999595901836], 
             UndirectedEdge[59, 155] -> 
             RGBColor[
              0.9807901733881861, 0.9454058196047143, 0.5037722498216607], 
             UndirectedEdge[5, 29] -> 
             RGBColor[
              0.977371016832695, 0.9353292676180711, 0.3665911028302651], 
             UndirectedEdge[119, 311] -> 
             RGBColor[
              0.981571197608947, 0.9842767138018633, 0.8489198809365252], 
             UndirectedEdge[68, 72] -> 
             RGBColor[
              0.957844046809696, 0.8591779474404407, 0.37608604974438753`], 
             UndirectedEdge[121, 234] -> 
             RGBColor[
              0.9921836792013735, 0.9899348929905171, 0.6991784400132988], 
             UndirectedEdge[20, 336] -> 
             RGBColor[
              0.953686995721945, 0.9190322417802539, 0.6376617406317042], 
             UndirectedEdge[17, 256] -> 
             RGBColor[
              0.960163062307668, 0.918782109966997, 0.6159156306880953], 
             UndirectedEdge[186, 272] -> 
             RGBColor[
              0.953777606164407, 0.842252745578966, 0.4203384401303423], 
             UndirectedEdge[45, 304] -> 
             RGBColor[
              0.9900161692971919, 0.9895492857589564, 0.7722231915359947], 
             UndirectedEdge[165, 252] -> 
             RGBColor[
              0.9910122758581719, 0.9806842809452584, 0.4757197606247583], 
             UndirectedEdge[106, 254] -> 
             RGBColor[
              0.9648635005380108, 0.97293971640692, 0.9275176705425431], 
             UndirectedEdge[144, 169] -> 
             RGBColor[
              0.9785195097268712, 0.9384488448872833, 0.4352150267202536], 
             UndirectedEdge[191, 355] -> 
             RGBColor[
              0.9657196840769136, 0.894455380826302, 0.3295107404197182], 
             UndirectedEdge[96, 377] -> 
             RGBColor[
              0.915510124492633, 0.693381742260631, 0.252919788091161], 
             UndirectedEdge[110, 303] -> 
             RGBColor[
              0.9912899596645401, 0.9818126127192914, 0.5751205222927726], 
             UndirectedEdge[177, 260] -> 
             RGBColor[
              0.9003895931605936, 0.569710189720645, 0.5420072605264188], 
             UndirectedEdge[20, 88] -> 
             RGBColor[
              0.9141702609486066, 0.6856544061470291, 0.2560952652678129], 
             UndirectedEdge[57, 68] -> 
             RGBColor[
              0.930179639500504, 0.7608925674150564, 0.2626791029288499], 
             UndirectedEdge[127, 264] -> 
             RGBColor[
              0.9472727565937981, 0.8176308073325175, 0.49853565696339325`], 
             UndirectedEdge[171, 186] -> 
             RGBColor[
              0.9509559390388433, 0.8336759744433637, 0.32932909197860105`], 
             UndirectedEdge[362, 385] -> 
             RGBColor[
              0.9711777724290295, 0.9120420826797258, 0.3867935909181508], 
             UndirectedEdge[109, 370] -> 
             RGBColor[
              0.9259354233999599, 0.7438315606496295, 0.2592519970606518], 
             UndirectedEdge[123, 161] -> 
             RGBColor[
              0.974986045867605, 0.9272842005350095, 0.3573259409948654], 
             UndirectedEdge[119, 213] -> 
             RGBColor[
              0.9545714079349776, 0.9656400109371746, 0.961782936078391], 
             UndirectedEdge[140, 360] -> 
             RGBColor[
              0.9796723976209915, 0.943092365406901, 0.3755315326135018], 
             UndirectedEdge[320, 347] -> 
             RGBColor[
              0.9840336044097027, 0.9844747978711975, 0.7266005321321092], 
             UndirectedEdge[10, 345] -> 
             RGBColor[
              0.962828852835609, 0.971425193668127, 0.931092301594941], 
             UndirectedEdge[169, 383] -> 
             RGBColor[
              0.9932213569708802, 0.9879094929236819, 0.5035647230949739], 
             UndirectedEdge[154, 372] -> 
             RGBColor[
              0.9471739647206752, 0.9590960103719741, 0.935474370999416], 
             UndirectedEdge[167, 341] -> 
             RGBColor[
              0.9700783618807208, 0.9105979047128976, 0.33894550173037785`], 
             UndirectedEdge[186, 308] -> 
             RGBColor[
              0.9523004481913246, 0.8382113195204448, 0.33455225614674217`], 
             UndirectedEdge[145, 225] -> 
             RGBColor[
              0.9503118646205411, 0.8342896367930914, 0.31231600860359743`], 
             UndirectedEdge[12, 65] -> 
             RGBColor[
              0.9913213035909118, 0.9888252771897752, 0.6587349884829301], 
             UndirectedEdge[274, 288] -> 
             RGBColor[
              0.9632745761619526, 0.8806808425327758, 0.38207366342708327`], 
             UndirectedEdge[143, 171] -> 
             RGBColor[
              0.991243393340227, 0.9811373182521849, 0.5043872936298366], 
             UndirectedEdge[167, 168] -> 
             RGBColor[
              0.9849240828727408, 0.9608075329153882, 0.39593333811900455`], 
             UndirectedEdge[203, 341] -> 
             RGBColor[
              0.9402291123093587, 0.800735378313871, 0.27076514464229906`], 
             UndirectedEdge[114, 299] -> 
             RGBColor[
              0.975553775660986, 0.9359572517108514, 0.5639375978495733], 
             UndirectedEdge[154, 231] -> 
             RGBColor[
              0.9405338120141471, 0.8022143350347133, 0.5569503104309472], 
             UndirectedEdge[218, 384] -> 
             RGBColor[
              0.9508433876219538, 0.8397995624374759, 0.5362231513588454], 
             UndirectedEdge[360, 380] -> 
             RGBColor[
              0.9757823534779417, 0.929970333086594, 0.36041944569094997`], 
             UndirectedEdge[98, 306] -> 
             RGBColor[
              0.9382144273058003, 0.7927478236287406, 0.2691440817977009], 
             UndirectedEdge[57, 262] -> 
             RGBColor[
              0.9630796349929186, 0.8817558283532527, 0.3390141095214143], 
             UndirectedEdge[152, 160] -> 
             RGBColor[
              0.9875594150612239, 0.9778372082902235, 0.6201303729132064], 
             UndirectedEdge[311, 354] -> 
             RGBColor[
              0.98073371919867, 0.9480104303605849, 0.5465979507281682], 
             UndirectedEdge[287, 303] -> 
             RGBColor[
              0.9908080859378501, 0.9816133455497152, 0.5831064169932555], 
             UndirectedEdge[222, 247] -> 
             RGBColor[
              0.9490756840334171, 0.8699148827894202, 0.6021708108786141], 
             UndirectedEdge[24, 206] -> 
             RGBColor[
              0.9431228130650205, 0.8122079375414555, 0.27309348419419116`], 
             UndirectedEdge[92, 308] -> 
             RGBColor[
              0.9871316039873084, 0.9682540199854309, 0.40450914079371636`], 
             UndirectedEdge[18, 266] -> 
             RGBColor[
              0.9850513978839699, 0.9604321854423714, 0.46486324263956946`], 
             UndirectedEdge[28, 314] -> 
             RGBColor[
              0.9497298560313581, 0.8264889541074134, 0.40026473772130683`], 
             UndirectedEdge[128, 139] -> 
             RGBColor[
              0.8848268617752838, 0.503651199752211, 0.22286419505323196`], 
             UndirectedEdge[160, 181] -> 
             RGBColor[
              0.9071780365873028, 0.590629286145361, 0.2881766229794191], 
             UndirectedEdge[42, 296] -> 
             RGBColor[
              0.9757226778697435, 0.9293575206279693, 0.5150385870287187], 
             UndirectedEdge[121, 289] -> 
             RGBColor[
              0.9691193396386047, 0.9030980646381663, 0.4314721539961081], 
             UndirectedEdge[22, 286] -> 
             RGBColor[
              0.9694316201100528, 0.9085478182135982, 0.335748045792066], 
             UndirectedEdge[128, 213] -> 
             RGBColor[
              0.9424929265091367, 0.8884399263791856, 0.6314953490047077], 
             UndirectedEdge[178, 398] -> 
             RGBColor[
              0.9747872122959726, 0.9266134882095513, 0.3565535101156436], 
             UndirectedEdge[6, 129] -> 
             RGBColor[
              0.9945107450765511, 0.9906673637045773, 0.6439066612162538], 
             UndirectedEdge[265, 375] -> 
             RGBColor[
              0.9776015669827953, 0.935488183326006, 0.42010367864686016`], 
             UndirectedEdge[162, 270] -> 
             RGBColor[
              0.9885416834142815, 0.9893714504390614, 0.832470487513407], 
             UndirectedEdge[199, 271] -> 
             RGBColor[
              0.9547566981578006, 0.8633440546990101, 0.5786636765470078], 
             UndirectedEdge[60, 72] -> 
             RGBColor[
              0.9810947327324746, 0.9820925577664206, 0.7164651186065032], 
             UndirectedEdge[230, 258] -> 
             RGBColor[
              0.9649101932257426, 0.914208929379786, 0.6005704042736513], 
             UndirectedEdge[38, 135] -> 
             RGBColor[
              0.9409532232220137, 0.8036062367868899, 0.27134778127968884`], 
             UndirectedEdge[42, 67] -> 
             RGBColor[
              0.9761356083577475, 0.9307504321246958, 0.5166427439992345], 
             UndirectedEdge[220, 352] -> 
             RGBColor[
              0.9904059629620279, 0.9891257641135163, 0.7232609596400756], 
             UndirectedEdge[4, 226] -> 
             RGBColor[
              0.9769385575373789, 0.9796444532265068, 0.775199264817134], 
             UndirectedEdge[134, 163] -> 
             RGBColor[
              0.9371715966147618, 0.7886133474415006, 0.26830499574530897`], 
             UndirectedEdge[25, 76] -> 
             RGBColor[
              0.9691019107974583, 0.9024419643579912, 0.4661937027902888], 
             UndirectedEdge[250, 375] -> 
             RGBColor[
              0.9321987914383165, 0.7667622115285618, 0.2731126997011114], 
             UndirectedEdge[50, 138] -> 
             RGBColor[
              0.9895536316789064, 0.9876161421787408, 0.6532729023844832], 
             UndirectedEdge[24, 157] -> 
             RGBColor[
              0.9472035620224155, 0.8283867473285484, 0.2763769505928002], 
             UndirectedEdge[127, 328] -> 
             RGBColor[
              0.9474351853113283, 0.8164139741552526, 0.4025104291480116], 
             UndirectedEdge[107, 245] -> 
             RGBColor[
              0.9919212010261356, 0.9896200347736401, 0.6885313332023146], 
             UndirectedEdge[16, 96] -> 
             RGBColor[
              0.9736151784327493, 0.9226599427822608, 0.352000379877044], 
             UndirectedEdge[42, 278] -> 
             RGBColor[
              0.9932822263198171, 0.9885900007281107, 0.583254116914772], 
             UndirectedEdge[51, 176] -> 
             RGBColor[
              0.9709448040999746, 0.9116780656470864, 0.35349053074125936`], 
             UndirectedEdge[33, 386] -> 
             RGBColor[
              0.9792405988385537, 0.9416358067225634, 0.3738540758820895], 
             UndirectedEdge[78, 187] -> 
             RGBColor[
              0.991904409557848, 0.9835324648180306, 0.4928921850004693], 
             UndirectedEdge[107, 150] -> 
             RGBColor[
              0.9553425375675404, 0.8565569394683682, 0.5345571442133683], 
             UndirectedEdge[312, 360] -> 
             RGBColor[
              0.9795683150798411, 0.9565472286403849, 0.6282487890570924], 
             UndirectedEdge[78, 208] -> 
             RGBColor[
              0.9492970022287429, 0.8266286531206681, 0.3304430283186881], 
             UndirectedEdge[28, 197] -> 
             RGBColor[
              0.9395786378348274, 0.7929957562170296, 0.29711881031603904`], 
             UndirectedEdge[221, 316] -> 
             RGBColor[
              0.9614311173763077, 0.8728021552760907, 0.4143191913863557], 
             UndirectedEdge[243, 383] -> 
             RGBColor[
              0.9933014817398126, 0.9892852988625962, 0.59983494967483], 
             UndirectedEdge[83, 332] -> 
             RGBColor[
              0.9547716939567813, 0.8456648021773532, 0.49187287113468403`], 
             UndirectedEdge[98, 354] -> 
             RGBColor[
              0.951053527949478, 0.8400175493064557, 0.29839560552677996`], 
             UndirectedEdge[46, 215] -> 
             RGBColor[
              0.9094855112363136, 0.6749352043475689, 0.24582575577694418`], 
             UndirectedEdge[375, 381] -> 
             RGBColor[
              0.9740989048451805, 0.9355722029287058, 0.5895455492651454], 
             UndirectedEdge[286, 304] -> 
             RGBColor[
              0.9770013513098876, 0.9469401581065511, 0.6117233946833323], 
             UndirectedEdge[225, 235] -> 
             RGBColor[
              0.9831384364813122, 0.9629541806887532, 0.6031628660815415], 
             UndirectedEdge[96, 225] -> 
             RGBColor[
              0.9676314535556378, 0.9024754337263496, 0.3287547386610934], 
             UndirectedEdge[20, 389] -> 
             RGBColor[
              0.9385819512377368, 0.9072785561916101, 0.6462986107698103], 
             UndirectedEdge[259, 393] -> 
             RGBColor[
              0.9441528813152544, 0.8162918149037373, 0.2739223012871388], 
             UndirectedEdge[97, 166] -> 
             RGBColor[
              0.9717605657170385, 0.9775698717452934, 0.892839788900639], 
             UndirectedEdge[115, 334] -> 
             RGBColor[
              0.9322456927769247, 0.7515596582347652, 0.4951203593134676], 
             UndirectedEdge[251, 260] -> 
             RGBColor[
              0.8627021373974515, 0.5408235859221207, 0.5787813576257563], 
             UndirectedEdge[119, 344] -> 
             RGBColor[
              0.9774342663676517, 0.9825659864193043, 0.9174795376396484], 
             UndirectedEdge[329, 341] -> 
             RGBColor[
              0.9696669755908722, 0.9244010048274525, 0.5976735357706042], 
             UndirectedEdge[283, 334] -> 
             RGBColor[
              0.9280480051991336, 0.7348803691117411, 0.3037030934110565], 
             UndirectedEdge[1, 5] -> 
             RGBColor[
              0.9658588494941208, 0.8963360244760372, 0.32270178684863327`], 
             UndirectedEdge[364, 391] -> 
             RGBColor[
              0.9517365583403945, 0.901342158912986, 0.6205098741756803], 
             UndirectedEdge[48, 295] -> 
             RGBColor[
              0.9504059318247642, 0.94716361911432, 0.6922325425790365], 
             UndirectedEdge[105, 199] -> 
             RGBColor[
              0.9893492353371072, 0.9885449751650555, 0.7303205715866798], 
             UndirectedEdge[281, 293] -> 
             RGBColor[
              0.9732822795204797, 0.9362368911104827, 0.6099912174824713], 
             UndirectedEdge[216, 358] -> 
             RGBColor[
              0.993748037920293, 0.9890360102188633, 0.5608906941404956], 
             UndirectedEdge[100, 206] -> 
             RGBColor[
              0.930980883391787, 0.7640692324452945, 0.26332380257138754`], 
             UndirectedEdge[168, 341] -> 
             RGBColor[
              0.9703639518061705, 0.9115612665911426, 0.34005496466161766`], 
             UndirectedEdge[199, 259] -> 
             RGBColor[
              0.969436684779925, 0.9215453098401816, 0.5904755383667424], 
             UndirectedEdge[19, 24] -> 
             RGBColor[
              0.9368653069382937, 0.7873990109392885, 0.26805854788207994`], 
             UndirectedEdge[136, 299] -> 
             RGBColor[
              0.9694705871989819, 0.9323116392326081, 0.6141454799792355], 
             UndirectedEdge[64, 123] -> 
             RGBColor[
              0.9829266434640055, 0.9540697007686477, 0.38817366320084945`], 
             UndirectedEdge[101, 334] -> 
             RGBColor[
              0.9244242747953605, 0.7226566755674537, 0.2896255850764645], 
             UndirectedEdge[2, 328] -> 
             RGBColor[
              0.9934434182887572, 0.9883844596287774, 0.5277347271422785], 
             UndirectedEdge[235, 349] -> 
             RGBColor[
              0.9700982751511689, 0.9176747809474868, 0.5592324014042754], 
             UndirectedEdge[45, 290] -> 
             RGBColor[
              0.9797113023465553, 0.9419306907381354, 0.4856223567399109], 
             UndirectedEdge[225, 327] -> 
             RGBColor[
              0.9863302473797134, 0.9640185502731209, 0.5316922386016478], 
             UndirectedEdge[24, 386] -> 
             RGBColor[
              0.963960773658536, 0.8891245901753759, 0.3195402544789333], 
             UndirectedEdge[363, 393] -> 
             RGBColor[
              0.962453439634531, 0.8839435541936673, 0.5363359099715942], 
             UndirectedEdge[2, 258] -> 
             RGBColor[
              0.9722414945069102, 0.9163095491820445, 0.3846811121551932], 
             UndirectedEdge[8, 234] -> 
             RGBColor[
              0.9528591684345149, 0.8462037498549231, 0.5300757612814757], 
             UndirectedEdge[44, 151] -> 
             RGBColor[
              0.993624719715948, 0.9916316720123839, 0.7553184232106334], 
             UndirectedEdge[253, 283] -> 
             RGBColor[
              0.9695579646790762, 0.908716087811457, 0.33758212389377873`], 
             UndirectedEdge[257, 360] -> 
             RGBColor[
              0.9762664595286344, 0.9316033364690868, 0.36230010628213444`], 
             UndirectedEdge[65, 358] -> 
             RGBColor[
              0.9932065308502871, 0.9878777813508841, 0.5019509913646307], 
             UndirectedEdge[282, 340] -> 
             RGBColor[
              0.990168729770744, 0.9779954870917146, 0.4591193672015703], 
             UndirectedEdge[256, 316] -> 
             RGBColor[
              0.9751696417933815, 0.9271012640055329, 0.42625661495932843`], 
             UndirectedEdge[96, 182] -> 
             RGBColor[
              0.9753742038009325, 0.9281879496220116, 0.393323052639348], 
             UndirectedEdge[2, 106] -> 
             RGBColor[
              0.9681821436570902, 0.9724238226638595, 0.7352641993902136], 
             UndirectedEdge[210, 279] -> 
             RGBColor[
              0.9389775279411614, 0.7913747512322753, 0.2926656164020016], 
             UndirectedEdge[279, 371] -> 
             RGBColor[
              0.9511500730223665, 0.8307820872770351, 0.4805567856544557], 
             UndirectedEdge[271, 353] -> 
             RGBColor[
              0.9595039919000162, 0.8653071826613004, 0.4999887336361146], 
             UndirectedEdge[306, 311] -> 
             RGBColor[
              0.9678946185549924, 0.9007407046828697, 0.5173464269990892], 
             UndirectedEdge[64, 312] -> 
             RGBColor[
              0.9827785462648189, 0.9673760922254417, 0.6407199310094396], 
             UndirectedEdge[137, 210] -> 
             RGBColor[
              0.9524154394165156, 0.8446515923135098, 0.30347807540339417`], 
             UndirectedEdge[264, 394] -> 
             RGBColor[
              0.9898159776195135, 0.9782772538818765, 0.579324995671425], 
             UndirectedEdge[199, 224] -> 
             RGBColor[
              0.97505000276677, 0.9410820333276815, 0.6091486390516647], 
             UndirectedEdge[61, 301] -> 
             RGBColor[
              0.8787825149372972, 0.4674647254112931, 0.21749837845619702`], 
             UndirectedEdge[48, 103] -> 
             RGBColor[
              0.9279668133345866, 0.866506128099169, 0.6309190015500996], 
             UndirectedEdge[7, 14] -> 
             RGBColor[
              0.9732732939372036, 0.9197445490935443, 0.4243145771790193], 
             UndirectedEdge[88, 195] -> 
             RGBColor[
              0.9061577342911262, 0.6552004643748836, 0.24280977814750576`], 
             UndirectedEdge[211, 341] -> 
             RGBColor[
              0.974801099523215, 0.9255530847885449, 0.44026088187582113`], 
             UndirectedEdge[84, 185] -> 
             RGBColor[
              0.9497995627884563, 0.8275463645293283, 0.3541026678367255], 
             UndirectedEdge[368, 387] -> 
             RGBColor[
              0.9418585633942069, 0.7908228572987417, 0.4099528641071397], 
             UndirectedEdge[134, 171] -> 
             RGBColor[
              0.9584269383089914, 0.863295996986577, 0.335340433358254], 
             UndirectedEdge[41, 295] -> 
             RGBColor[
              0.9885444150699545, 0.9726898211829893, 0.4380535590559834], 
             UndirectedEdge[77, 388] -> 
             RGBColor[
              0.9680793975410229, 0.8997245593575877, 0.3862828794045541], 
             UndirectedEdge[142, 273] -> 
             RGBColor[
              0.9693991056474626, 0.9084381392965226, 0.3356217332447442], 
             UndirectedEdge[64, 140] -> 
             RGBColor[
              0.9828826288059691, 0.9539212289919581, 0.38800267456584914`], 
             UndirectedEdge[150, 157] -> 
             RGBColor[
              0.9311647936749685, 0.7647983754336409, 0.2634717811021646], 
             UndirectedEdge[210, 264] -> 
             RGBColor[
              0.982152938718315, 0.9524280243010359, 0.5495555365837399], 
             UndirectedEdge[202, 309] -> 
             RGBColor[
              0.9593294516480458, 0.8684218500818446, 0.5184758729627172], 
             UndirectedEdge[105, 287] -> 
             RGBColor[
              0.9936146553526328, 0.9903088359577696, 0.6596315233762695], 
             UndirectedEdge[157, 160] -> 
             RGBColor[
              0.9641082823162253, 0.8863791166380725, 0.33700318267734375`], 
             UndirectedEdge[153, 379] -> 
             RGBColor[
              0.897760050980817, 0.6265319317043277, 0.23629207649510583`], 
             UndirectedEdge[207, 387] -> 
             RGBColor[
              0.9090123366297065, 0.6727866289717026, 0.24543092728662017`], 
             UndirectedEdge[93, 264] -> 
             RGBColor[
              0.9494725183479253, 0.9595166983889061, 0.8743746459735862], 
             UndirectedEdge[202, 365] -> 
             RGBColor[
              0.9748092190248574, 0.9293918779366792, 0.5330253563481624], 
             UndirectedEdge[138, 230] -> 
             RGBColor[
              0.9824795456795029, 0.9860656798557215, 0.8971584905742389], 
             UndirectedEdge[5, 291] -> 
             RGBColor[
              0.9856306753382269, 0.9616712013430924, 0.5279140186493858], 
             UndirectedEdge[241, 360] -> 
             RGBColor[
              0.9765453306307703, 0.9325440341786397, 0.36338346785354364`], 
             UndirectedEdge[299, 300] -> 
             RGBColor[
              0.9776990584271077, 0.9356063847297018, 0.4383954313756816], 
             UndirectedEdge[9, 266] -> 
             RGBColor[
              0.9668414084235875, 0.8942483665230121, 0.41889670361613457`], 
             UndirectedEdge[226, 322] -> 
             RGBColor[
              0.9878443206341465, 0.987777953487528, 0.7567386525728665], 
             UndirectedEdge[175, 216] -> 
             RGBColor[
              0.9920608072627403, 0.9838241336950567, 0.5135587646622349], 
             UndirectedEdge[115, 257] -> 
             RGBColor[
              0.9853052719751365, 0.9646128765244467, 0.5725242281297661], 
             UndirectedEdge[146, 275] -> 
             RGBColor[
              0.9554513934278761, 0.8548124377037842, 0.5239962719875453], 
             UndirectedEdge[64, 101] -> 
             RGBColor[
              0.9787704945286928, 0.9400500344996613, 0.37202780941002944`], 
             UndirectedEdge[79, 390] -> 
             RGBColor[
              0.9717860293606427, 0.9149910235434389, 0.35548225789480026`], 
             UndirectedEdge[98, 378] -> 
             RGBColor[
              0.9392908496724014, 0.7970154796158241, 0.2700101965007485], 
             UndirectedEdge[37, 80] -> 
             RGBColor[
              0.9912133774956273, 0.9903847369330925, 0.7771240094462224], 
             UndirectedEdge[344, 354] -> 
             RGBColor[
              0.9765967879573749, 0.9462997029780258, 0.6151576074312914], 
             UndirectedEdge[119, 227] -> 
             RGBColor[
              0.9787176296783879, 0.9733129810604584, 0.6708909241782428], 
             UndirectedEdge[81, 166] -> 
             RGBColor[
              0.9470737649727974, 0.8828557369942434, 0.6167580811822841], 
             UndirectedEdge[192, 221] -> 
             RGBColor[
              0.9601004674970997, 0.8735279081902751, 0.5291240209732313], 
             UndirectedEdge[242, 331] -> 
             RGBColor[
              0.9831384364813122, 0.9629541806887532, 0.6031628660815415], 
             UndirectedEdge[225, 322] -> 
             RGBColor[
              0.979639683016243, 0.9610775072058326, 0.6418967485245957], 
             UndirectedEdge[165, 170] -> 
             RGBColor[
              0.9579138388170488, 0.8590674935357416, 0.39905203057273986`], 
             UndirectedEdge[41, 250] -> 
             RGBColor[
              0.9478688372712263, 0.8192910132966726, 0.36204378271528487`], 
             UndirectedEdge[31, 393] -> 
             RGBColor[
              0.9600505550102161, 0.8705200850762678, 0.3325481818604804], 
             UndirectedEdge[140, 312] -> 
             RGBColor[
              0.9848978438220553, 0.97452498052073, 0.6489530018235405], 
             UndirectedEdge[56, 100] -> 
             RGBColor[
              0.8992985573305847, 0.6286561719885073, 0.23732435021610454`], 
             UndirectedEdge[89, 183] -> 
             RGBColor[
              0.9409889818232218, 0.8037480077248327, 0.2713765534895831], 
             UndirectedEdge[39, 210] -> 
             RGBColor[
              0.9772449729129957, 0.9349040918804059, 0.36610144600363054`], 
             UndirectedEdge[34, 321] -> 
             RGBColor[
              0.991457663393556, 0.9907355385322676, 0.7912321546346563], 
             UndirectedEdge[148, 301] -> 
             RGBColor[
              0.9476684203082739, 0.8302297555271363, 0.2767509864812283], 
             UndirectedEdge[136, 155] -> 
             RGBColor[
              0.9861269500584178, 0.9870403963263013, 0.8027506738247978], 
             UndirectedEdge[51, 205] -> 
             RGBColor[
              0.9928584301511094, 0.9871332291537225, 0.46406237848763], 
             UndirectedEdge[11, 123] -> 
             RGBColor[
              0.9548882223215867, 0.8502405584309664, 0.32741845385811513`], 
             UndirectedEdge[223, 400] -> 
             RGBColor[
              0.9604080342165169, 0.8798253884823954, 0.5542206591415156], 
             UndirectedEdge[6, 201] -> 
             RGBColor[
              0.9919500371258878, 0.9906923570993248, 0.7651331745068721], 
             UndirectedEdge[201, 273] -> 
             RGBColor[
              0.9854254962944142, 0.9702221040319943, 0.6089589374455435], 
             UndirectedEdge[54, 196] -> 
             RGBColor[
              0.9799448084880611, 0.9840162785713521, 0.8943288646014117], 
             UndirectedEdge[84, 288] -> 
             RGBColor[
              0.9499581041576973, 0.8278854684871434, 0.37135891747468763`], 
             UndirectedEdge[177, 248] -> 
             RGBColor[
              0.9300839725256138, 0.7650634291947758, 0.5691547115770429], 
             UndirectedEdge[76, 117] -> 
             RGBColor[
              0.9687902314776329, 0.9017753138084978, 0.43226933228909203`], 
             UndirectedEdge[342, 348] -> 
             RGBColor[
              0.9664044138522878, 0.8983363406843266, 0.32398792112058317`], 
             UndirectedEdge[332, 389] -> 
             RGBColor[
              0.9156842824792677, 0.8178099861686063, 0.6210361889158563], 
             UndirectedEdge[68, 236] -> 
             RGBColor[
              0.9574176287089231, 0.860842109205451, 0.516937575349647], 
             UndirectedEdge[84, 318] -> 
             RGBColor[
              0.917064712351146, 0.7088962515582504, 0.2521265246975704], 
             UndirectedEdge[15, 372] -> 
             RGBColor[
              0.9496892252635456, 0.9601361352456985, 0.8937899945184301], 
             UndirectedEdge[88, 189] -> 
             RGBColor[
              0.9186052269431007, 0.7006145878259931, 0.273324270683369], 
             UndirectedEdge[364, 380] -> 
             RGBColor[
              0.9655976089687507, 0.9500100276124821, 0.6644034065764017], 
             UndirectedEdge[103, 295] -> 
             RGBColor[
              0.961612104625996, 0.8772056809841187, 0.33122890176153785`], 
             UndirectedEdge[20, 257] -> 
             RGBColor[
              0.9692966560603051, 0.9080925527827337, 0.33522373594461885`], 
             UndirectedEdge[12, 24] -> 
             RGBColor[
              0.9710982585283685, 0.9200282639949228, 0.552153141403433], 
             UndirectedEdge[152, 157] -> 
             RGBColor[
              0.965171300051799, 0.8981050061662542, 0.5550920727286622], 
             UndirectedEdge[26, 70] -> 
             RGBColor[
              0.9571854515220637, 0.8672386160291878, 0.28817399332261795`], 
             UndirectedEdge[33, 74] -> 
             RGBColor[
              0.9883157852091295, 0.9733407699093248, 0.5743542343285348], 
             UndirectedEdge[124, 238] -> 
             RGBColor[
              0.9794488113265839, 0.9423381563353059, 0.37466294208045725`], 
             UndirectedEdge[148, 339] -> 
             RGBColor[
              0.9741265249061544, 0.9237200529719409, 0.38992666025313955`], 
             UndirectedEdge[175, 229] -> 
             RGBColor[
              0.9871587030297679, 0.9827165588977673, 0.661642442709837], 
             UndirectedEdge[105, 337] -> 
             RGBColor[
              0.9731271345495363, 0.9192181117098995, 0.42105859318657013`], 
             UndirectedEdge[158, 306] -> 
             RGBColor[
              0.9342503210167248, 0.7770314631526699, 0.2659544688279771], 
             UndirectedEdge[136, 268] -> 
             RGBColor[
              0.578158504849235, 0.644026043385178, 0.9283289976686468], 
             UndirectedEdge[133, 278] -> 
             RGBColor[
              0.9917239190374307, 0.9879456006201734, 0.6090793013538869], 
             UndirectedEdge[197, 254] -> 
             RGBColor[0.9799352470118637, 0.955325214348, 0.6126724680253137],
              UndirectedEdge[296, 398] -> 
             RGBColor[
              0.9725854728877424, 0.9191865041925933, 0.3480001682782684], 
             UndirectedEdge[10, 271] -> 
             RGBColor[
              0.9318938397251266, 0.8464180792168803, 0.6229670749857504], 
             UndirectedEdge[221, 399] -> 
             RGBColor[
              0.9134124593398463, 0.6925550718571011, 0.2490915575467081], 
             UndirectedEdge[187, 388] -> 
             RGBColor[
              0.968403886183892, 0.9004186077538504, 0.4216014656690833], 
             UndirectedEdge[143, 186] -> 
             RGBColor[
              0.9538143531113612, 0.8423313435828146, 0.4243381185304248], 
             UndirectedEdge[372, 387] -> 
             RGBColor[
              0.8989681952226385, 0.7608502884750449, 0.6103922787737737], 
             UndirectedEdge[147, 255] -> 
             RGBColor[
              0.9462407574364551, 0.8234980675137948, 0.28118254390712627`], 
             UndirectedEdge[27, 86] -> 
             RGBColor[
              0.9206550802689535, 0.7124195963777562, 0.2685105863240405], 
             UndirectedEdge[19, 157] -> 
             RGBColor[
              0.9313819122226784, 0.7656591781248434, 0.26364647978207933`], 
             UndirectedEdge[192, 208] -> 
             RGBColor[
              0.9498803041348012, 0.8330083661263119, 0.5209006376338591], 
             UndirectedEdge[88, 89] -> 
             RGBColor[
              0.9103121083465626, 0.6716711731416011, 0.24615248502820214`], 
             UndirectedEdge[54, 332] -> 
             RGBColor[
              0.9510467210728799, 0.8441244301624233, 0.5536053117417392], 
             UndirectedEdge[282, 301] -> 
             RGBColor[
              0.9636323563031017, 0.8843377804486858, 0.33742460997555435`], 
             UndirectedEdge[264, 328] -> 
             RGBColor[
              0.9936311957392996, 0.9903503483882747, 0.6618777351304266], 
             UndirectedEdge[124, 156] -> 
             RGBColor[
              0.9923113617197026, 0.9846172751313156, 0.5189570216060617], 
             UndirectedEdge[64, 120] -> 
             RGBColor[
              0.953895264801575, 0.8475832647281154, 0.3199560892685762], 
             UndirectedEdge[55, 236] -> 
             RGBColor[
              0.9703924073568889, 0.9760929647111294, 0.8747110748421689], 
             UndirectedEdge[11, 196] -> 
             RGBColor[
              0.9485452941097192, 0.8590268294735035, 0.5949280131248693], 
             UndirectedEdge[223, 319] -> 
             RGBColor[
              0.9843827833592769, 0.9676260427958385, 0.611275870220773], 
             UndirectedEdge[61, 70] -> 
             RGBColor[
              0.8874824578711717, 0.5014594349831658, 0.2270904049335164], 
             UndirectedEdge[307, 343] -> 
             RGBColor[
              0.9919280064894508, 0.9909300374896863, 0.7834373523267661], 
             UndirectedEdge[13, 87] -> 
             RGBColor[
              0.973399208304851, 0.9219314248286623, 0.35116137671269565`], 
             UndirectedEdge[119, 128] -> 
             RGBColor[
              0.9578450137226537, 0.8998894878862909, 0.6055082698178404], 
             UndirectedEdge[92, 130] -> 
             RGBColor[
              0.9839781285299434, 0.9714620986375249, 0.6456533374389954], 
             UndirectedEdge[263, 359] -> 
             RGBColor[
              0.9573604579873041, 0.8716226307153901, 0.57075430920808], 
             UndirectedEdge[22, 304] -> 
             RGBColor[
              0.97786470046457, 0.9498524375293158, 0.6150773431194652], 
             UndirectedEdge[139, 306] -> 
             RGBColor[
              0.8832287641471703, 0.4973152751912063, 0.22157832818947926`], 
             UndirectedEdge[1, 73] -> 
             RGBColor[
              0.9474216379515801, 0.8292513457181903, 0.276552419604306], 
             UndirectedEdge[7, 13] -> 
             RGBColor[
              0.9882886478922912, 0.9713494178706015, 0.4776750578338621], 
             UndirectedEdge[170, 335] -> 
             RGBColor[
              0.9529266892270953, 0.8429048234161004, 0.32354295374381775`], 
             UndirectedEdge[276, 361] -> 
             RGBColor[
              0.9855424514381097, 0.9628934352862211, 0.3983355832263574], 
             UndirectedEdge[46, 345] -> 
             RGBColor[
              0.9573817654557276, 0.8711000282066064, 0.567800760910796], 
             UndirectedEdge[36, 301] -> 
             RGBColor[
              0.9611537391443294, 0.8759768227651623, 0.32779565036129926`], 
             UndirectedEdge[50, 328] -> 
             RGBColor[
              0.9931862030069931, 0.9878343021495384, 0.4997384310709811], 
             UndirectedEdge[55, 83] -> 
             RGBColor[
              0.9717122809827826, 0.9766387663746414, 0.8528373531376601], 
             UndirectedEdge[143, 306] -> 
             RGBColor[
              0.9683360722266653, 0.8999051207989642, 0.4360226345991561], 
             UndirectedEdge[32, 400] -> 
             RGBColor[
              0.9630749206494591, 0.879490451561751, 0.40551325721751486`], 
             UndirectedEdge[20, 195] -> 
             RGBColor[
              0.9523907352846384, 0.8476391043817042, 0.28738909205171526`], 
             UndirectedEdge[203, 266] -> 
             RGBColor[
              0.9593735162460342, 0.8646406625665599, 0.4128878622761163], 
             UndirectedEdge[255, 359] -> 
             RGBColor[
              0.9441053904523609, 0.8150320489907263, 0.27946437750821884`], 
             UndirectedEdge[128, 215] -> 
             RGBColor[
              0.9182062044038711, 0.7095098467582059, 0.25284263020053865`], 
             UndirectedEdge[230, 328] -> 
             RGBColor[
              0.9861121170075895, 0.9862838398265189, 0.7436240192607367], 
             UndirectedEdge[44, 146] -> 
             RGBColor[
              0.9922752403196449, 0.991073627601974, 0.7776827891481043], 
             UndirectedEdge[56, 206] -> 
             RGBColor[
              0.9018763433308081, 0.6388762344831302, 0.2393984973402985], 
             UndirectedEdge[55, 196] -> 
             RGBColor[
              0.9604465988663631, 0.9700217187140596, 0.9518377703267629], 
             UndirectedEdge[93, 188] -> 
             RGBColor[
              0.9311006284879326, 0.8965757886521584, 0.6386157528897836], 
             UndirectedEdge[52, 271] -> 
             RGBColor[
              0.9548510319456245, 0.863383064144543, 0.5771003215547481], 
             UndirectedEdge[193, 253] -> 
             RGBColor[
              0.9627454657147777, 0.8857359291540539, 0.3111168518499599], 
             UndirectedEdge[120, 193] -> 
             RGBColor[
              0.9487136595210096, 0.8301044934179913, 0.2998265312176308], 
             UndirectedEdge[28, 217] -> 
             RGBColor[
              0.9504359503391517, 0.8281310428556157, 0.4867009894070289], 
             UndirectedEdge[124, 245] -> 
             RGBColor[
              0.9920445463369234, 0.9840465840067243, 0.48991581378422683`], 
             UndirectedEdge[36, 282] -> 
             RGBColor[
              0.9845400655728368, 0.9595121523912621, 0.3944415034244595], 
             UndirectedEdge[276, 339] -> 
             RGBColor[
              0.9871220397430627, 0.9678148963093957, 0.4390685280882478], 
             UndirectedEdge[377, 388] -> 
             RGBColor[
              0.9082029858449816, 0.6648919742658232, 0.24453731055735803`], 
             UndirectedEdge[129, 131] -> 
             RGBColor[
              0.9938029995806767, 0.9906214833784934, 0.6735749088301943], 
             UndirectedEdge[69, 142] -> 
             RGBColor[
              0.9569741856426299, 0.8665259666102703, 0.2873532652752315], 
             UndirectedEdge[11, 118] -> 
             RGBColor[
              0.9568521069780004, 0.8644203086605091, 0.5449637166855708], 
             UndirectedEdge[53, 293] -> 
             RGBColor[
              0.9891673124629285, 0.9897879874059989, 0.8291698439145697], 
             UndirectedEdge[2, 137] -> 
             RGBColor[
              0.9635434902694275, 0.8818248608185162, 0.37768249377731455`], 
             UndirectedEdge[102, 213] -> 
             RGBColor[
              0.9529973008541225, 0.9268889060213982, 0.656599342585489], 
             UndirectedEdge[269, 362] -> 
             RGBColor[
              0.9591347775328831, 0.9063892140914189, 0.6076215618276006], 
             UndirectedEdge[147, 242] -> 
             RGBColor[
              0.9552849323611994, 0.8540061932082155, 0.31631745564063396`], 
             UndirectedEdge[58, 220] -> 
             RGBColor[
              0.9396828606951402, 0.7967392288328914, 0.5494451476740854], 
             UndirectedEdge[177, 285] -> 
             RGBColor[
              0.9860391057753369, 0.9879397943256036, 0.8561762379115707], 
             UndirectedEdge[213, 215] -> 
             RGBColor[
              0.9149325986161951, 0.7752603698090895, 0.6091172964610891], 
             UndirectedEdge[61, 382] -> 
             RGBColor[
              0.9008712943519557, 0.5466231242811532, 0.27910350639174725`], 
             UndirectedEdge[83, 123] -> 
             RGBColor[
              0.99001270958383, 0.9767703795437448, 0.5650868647276023], 
             UndirectedEdge[207, 368] -> 
             RGBColor[
              0.9611713727261983, 0.8715763468340672, 0.4257088707174879], 
             UndirectedEdge[117, 377] -> 
             RGBColor[
              0.9337287985962313, 0.7538979312728513, 0.40359921941321436`], 
             UndirectedEdge[207, 392] -> 
             RGBColor[
              0.9606612993058219, 0.8704853513642157, 0.37019052671778013`], 
             UndirectedEdge[43, 325] -> 
             RGBColor[
              0.9939488724440761, 0.991599980278326, 0.7378990275251104], 
             UndirectedEdge[83, 196] -> 
             RGBColor[
              0.9836697813719626, 0.985556650586282, 0.8325964239943564], 
             UndirectedEdge[81, 130] -> 
             RGBColor[
              0.9624705983715707, 0.8942431339906194, 0.5864169547257323], 
             UndirectedEdge[204, 229] -> 
             RGBColor[
              0.9793077378985567, 0.9562334100159164, 0.6311429257054428], 
             UndirectedEdge[44, 267] -> 
             RGBColor[
              0.9889894641292856, 0.975814069022463, 0.5783594234027383], 
             UndirectedEdge[38, 130] -> 
             RGBColor[
              0.9567312026743374, 0.8714883425913286, 0.5817989022268064], 
             UndirectedEdge[226, 318] -> 
             RGBColor[
              0.9607378453353774, 0.8697969682354195, 0.4289452574492844], 
             UndirectedEdge[202, 362] -> 
             RGBColor[
              0.9707515495114982, 0.9137066619219543, 0.5276663610147467], 
             UndirectedEdge[59, 230] -> 
             RGBColor[
              0.9725735329581782, 0.9414115488846049, 0.6232978392687241], 
             UndirectedEdge[131, 394] -> 
             RGBColor[
              0.9898718125283057, 0.9783003430515538, 0.5783996667366234], 
             UndirectedEdge[93, 142] -> 
             RGBColor[
              0.9311638174004253, 0.8967889396914586, 0.6388612298825929], 
             UndirectedEdge[301, 340] -> 
             RGBColor[
              0.9667824033422368, 0.8944601574656148, 0.39247351413841003`], 
             UndirectedEdge[16, 76] -> 
             RGBColor[
              0.9665985216919808, 0.8953218387508863, 0.34385163090400567`], 
             UndirectedEdge[25, 239] -> 
             RGBColor[
              0.9703961176138813, 0.9075730631162533, 0.46723505197372134`], 
             UndirectedEdge[46, 60] -> 
             RGBColor[
              0.9486830294942533, 0.8649857313250251, 0.5992383860531112], 
             UndirectedEdge[57, 297] -> 
             RGBColor[
              0.9656848243887284, 0.8898976240093187, 0.4040761511664357], 
             UndirectedEdge[221, 351] -> 
             RGBColor[
              0.9293703970395737, 0.757684190721532, 0.2620279674494234], 
             UndirectedEdge[365, 377] -> 
             RGBColor[
              0.9153773783417916, 0.6929339583235645, 0.2524040943621492], 
             UndirectedEdge[334, 366] -> 
             RGBColor[
              0.8689107449578233, 0.4976361341744011, 0.2123282511121813], 
             UndirectedEdge[209, 290] -> 
             RGBColor[
              0.9532378198172053, 0.8496900230554483, 0.29488010225050654`], 
             UndirectedEdge[174, 313] -> 
             RGBColor[
              0.9701294771682913, 0.9081557998045173, 0.36998132068750345`], 
             UndirectedEdge[56, 358] -> 
             RGBColor[
              0.9317370160535314, 0.7457490650977063, 0.361674157431241], 
             UndirectedEdge[304, 338] -> 
             RGBColor[
              0.9897006761282301, 0.9900089791455422, 0.8203499805583927], 
             UndirectedEdge[130, 306] -> 
             RGBColor[
              0.9636686918492638, 0.8989931753886884, 0.5873809688607525], 
             UndirectedEdge[11, 206] -> 
             RGBColor[
              0.9291225791779527, 0.7567016754806122, 0.2618285673809304], 
             UndirectedEdge[120, 140] -> 
             RGBColor[
              0.9560145623588114, 0.8547321530234036, 0.32818916008267723`], 
             UndirectedEdge[193, 356] -> 
             RGBColor[
              0.9791396128896417, 0.9412951574042546, 0.3734617645401624], 
             UndirectedEdge[166, 246] -> 
             RGBColor[
              0.9350447877421979, 0.8351648506939566, 0.6070792837461586], 
             UndirectedEdge[76, 182] -> 
             RGBColor[
              0.9683575470601641, 0.9008498455906372, 0.38517430366630967`], 
             UndirectedEdge[6, 364] -> 
             RGBColor[
              0.974484653845749, 0.9784495615676969, 0.8297555257331405], 
             UndirectedEdge[288, 318] -> 
             RGBColor[
              0.9602851142450267, 0.8688286222112942, 0.3796682721970347], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.9710547467367813, 0.913765085153236, 0.3433968395443886], 
             UndirectedEdge[128, 151] -> 
             RGBColor[
              0.9698833561182456, 0.9072381688960431, 0.5121583791938311], 
             UndirectedEdge[30, 379] -> 
             RGBColor[
              0.953314185069356, 0.8394339557361681, 0.4780442899794195], 
             UndirectedEdge[70, 90] -> 
             RGBColor[
              0.9762532279390527, 0.9304672927407223, 0.5124002452603114], 
             UndirectedEdge[137, 394] -> 
             RGBColor[
              0.960078478317714, 0.8705008218943504, 0.3332475344910793], 
             UndirectedEdge[25, 269] -> 
             RGBColor[
              0.9818555466205072, 0.9837050536049242, 0.7981000527132782], 
             UndirectedEdge[38, 227] -> 
             RGBColor[
              0.958103561449507, 0.862272139144105, 0.3337354036068607], 
             UndirectedEdge[128, 135] -> 
             RGBColor[
              0.9494888100250536, 0.8374469941452544, 0.27821571477738766`], 
             UndirectedEdge[129, 303] -> 
             RGBColor[
              0.9910829282899198, 0.980643087985883, 0.49976261230187113`], 
             UndirectedEdge[132, 299] -> 
             RGBColor[
              0.9766829544029847, 0.9364241961392379, 0.545224183873747], 
             UndirectedEdge[352, 396] -> 
             RGBColor[
              0.981044365704482, 0.9468457302959261, 0.4552315175610699], 
             UndirectedEdge[155, 268] -> 
             RGBColor[
              0.5868954452091827, 0.6484083529411233, 0.8079226761561511], 
             UndirectedEdge[8, 16] -> 
             RGBColor[
              0.952499512129942, 0.8394239640538252, 0.3325072368641002], 
             UndirectedEdge[213, 378] -> 
             RGBColor[
              0.9419712512476244, 0.8863716578052645, 0.6310755968440027], 
             UndirectedEdge[164, 230] -> 
             RGBColor[
              0.9427742775129057, 0.826447399935023, 0.5827593268943801], 
             UndirectedEdge[218, 339] -> 
             RGBColor[
              0.991314748169042, 0.9888477500801647, 0.6606742198008824], 
             UndirectedEdge[101, 366] -> 
             RGBColor[
              0.9212641279711156, 0.7083071869096003, 0.28698868110402764`], 
             UndirectedEdge[169, 361] -> 
             RGBColor[
              0.9918643388374107, 0.9834640869920143, 0.4870571678551792], 
             UndirectedEdge[65, 341] -> 
             RGBColor[
              0.9743256388386339, 0.9245361224606754, 0.388509920562393], 
             UndirectedEdge[46, 353] -> 
             RGBColor[
              0.9613823855164689, 0.8727543874129687, 0.5015001332314775], 
             UndirectedEdge[279, 300] -> 
             RGBColor[
              0.9504824488110919, 0.8293541065962808, 0.4078900103562587], 
             UndirectedEdge[203, 358] -> 
             RGBColor[
              0.9591100043210119, 0.8640770372040798, 0.3842062154445368], 
             UndirectedEdge[81, 243] -> 
             RGBColor[
              0.9670300074187181, 0.8961285668030827, 0.5108557474421231], 
             UndirectedEdge[176, 320] -> 
             RGBColor[
              0.9713882122802698, 0.9126264709092938, 0.4017527747682974], 
             UndirectedEdge[112, 248] -> 
             RGBColor[
              0.9231432866608194, 0.7225654942234618, 0.2735978323419026], 
             UndirectedEdge[58, 179] -> 
             RGBColor[
              0.9379930931167453, 0.7959275375690672, 0.5723917805369281], 
             UndirectedEdge[23, 213] -> 
             RGBColor[
              0.9335394139532691, 0.8529422326763612, 0.6242911426363056], 
             UndirectedEdge[243, 326] -> 
             RGBColor[
              0.9940014738799285, 0.9907825112702426, 0.6760247742757186], 
             UndirectedEdge[269, 377] -> 
             RGBColor[
              0.9212471035749136, 0.7473067274761896, 0.576677389041112], 
             UndirectedEdge[222, 363] -> 
             RGBColor[
              0.9608676514004604, 0.8776564322781804, 0.5350599475352271], 
             UndirectedEdge[30, 341] -> 
             RGBColor[
              0.9753108430344926, 0.9266433746161931, 0.49574331730609156`], 
             UndirectedEdge[23, 348] -> 
             RGBColor[
              0.9476920328306708, 0.826904433723058, 0.29457587073526015`], 
             UndirectedEdge[16, 25] -> 
             RGBColor[
              0.9921455318561729, 0.9838427823439745, 0.5366041817002941], 
             UndirectedEdge[25, 62] -> 
             RGBColor[
              0.994141303719572, 0.9898771659982497, 0.6036952494368353], 
             UndirectedEdge[16, 388] -> 
             RGBColor[
              0.9663080397850978, 0.894170174787453, 0.343617902343241], 
             UndirectedEdge[207, 372] -> 
             RGBColor[
              0.9182810045546299, 0.8416037780103702, 0.6261482853841218], 
             UndirectedEdge[249, 279] -> 
             RGBColor[
              0.9370097176856201, 0.7847368651765145, 0.28502104514900956`], 
             UndirectedEdge[151, 267] -> 
             RGBColor[
              0.9893649243530163, 0.9759693314738632, 0.5721370758356099], 
             UndirectedEdge[185, 252] -> 
             RGBColor[
              0.9906566602676028, 0.9799236551552827, 0.4370131981963448], 
             UndirectedEdge[218, 382] -> 
             RGBColor[
              0.98694542298582, 0.9745158515052201, 0.6091036739645214], 
             UndirectedEdge[284, 334] -> 
             RGBColor[
              0.9327041066103025, 0.7500715760132238, 0.36557594741713545`], 
             UndirectedEdge[145, 235] -> 
             RGBColor[
              0.9557756081053805, 0.8608901788567973, 0.5477080473030291], 
             UndirectedEdge[78, 302] -> 
             RGBColor[
              0.9761750719140984, 0.9312950645864242, 0.3619450826567645], 
             UndirectedEdge[235, 335] -> 
             RGBColor[
              0.9861002676402395, 0.9729451326588425, 0.6146690208390918], 
             UndirectedEdge[21, 109] -> 
             RGBColor[
              0.9710550301687781, 0.9110941426927717, 0.4139925662809735], 
             UndirectedEdge[283, 389] -> 
             RGBColor[
              0.9503928795747769, 0.947119590810299, 0.6921818370525465], 
             UndirectedEdge[91, 395] -> 
             RGBColor[
              0.941446377020777, 0.800529191911948, 0.2979525516541753], 
             UndirectedEdge[240, 374] -> 
             RGBColor[
              0.9658208538764079, 0.8903488471394109, 0.40939820887088474`], 
             UndirectedEdge[301, 339] -> 
             RGBColor[
              0.9667041344724748, 0.8942927482673908, 0.3839544306843053], 
             UndirectedEdge[303, 353] -> 
             RGBColor[
              0.9912899596645401, 0.9818126127192914, 0.5751205222927726], 
             UndirectedEdge[92, 143] -> 
             RGBColor[
              0.9886455089073448, 0.9723740440478006, 0.49429500317739905`], 
             UndirectedEdge[53, 394] -> 
             RGBColor[
              0.9901542071814696, 0.9784171204978487, 0.5737196565197624], 
             UndirectedEdge[139, 345] -> 
             RGBColor[
              0.9051627881017561, 0.5866364670411524, 0.5224611476434653], 
             UndirectedEdge[224, 393] -> 
             RGBColor[
              0.9497661993020996, 0.835828538391237, 0.292595401972061], 
             UndirectedEdge[175, 204] -> 
             RGBColor[
              0.9820545883911405, 0.9511280542396057, 0.38478589391655105`], 
             UndirectedEdge[131, 293] -> 
             RGBColor[
              0.9888849178097647, 0.989671209959704, 0.8338498541314306], 
             UndirectedEdge[166, 383] -> 
             RGBColor[
              0.9733452392938917, 0.9760124690537568, 0.7057372834149911], 
             UndirectedEdge[92, 348] -> 
             RGBColor[
              0.9753568844391043, 0.9285351261137142, 0.35876657881815255`], 
             UndirectedEdge[212, 289] -> 
             RGBColor[
              0.9693097705283762, 0.903505377055871, 0.4521993811445024], 
             UndirectedEdge[161, 214] -> 
             RGBColor[
              0.9796523384562634, 0.9425814658932514, 0.5300853107774827], 
             UndirectedEdge[124, 386] -> 
             RGBColor[
              0.9827784681462804, 0.9535698706287421, 0.3875980300720485], 
             UndirectedEdge[227, 350] -> 
             RGBColor[
              0.990690896180833, 0.9806347515160201, 0.57861950951469], 
             UndirectedEdge[258, 279] -> 
             RGBColor[
              0.929253861180299, 0.7572221648727812, 0.2619341999616029], 
             UndirectedEdge[63, 103] -> 
             RGBColor[
              0.9643848789169202, 0.8932571009811985, 0.5459936532977944], 
             UndirectedEdge[291, 336] -> 
             RGBColor[
              0.9709681615488934, 0.9758058380510648, 0.8340315088258221], 
             UndirectedEdge[292, 400] -> 
             RGBColor[
              0.9579600230118974, 0.8786790995516492, 0.588790938075564], 
             UndirectedEdge[149, 300] -> 
             RGBColor[
              0.9841311600672265, 0.9573033738911073, 0.46338293164706895`], 
             UndirectedEdge[356, 364] -> 
             RGBColor[
              0.9709262424760383, 0.9679847596552098, 0.6851041415242123], 
             UndirectedEdge[100, 167] -> 
             RGBColor[
              0.9565207951694273, 0.8568466704939073, 0.32803676531747916`], 
             UndirectedEdge[334, 391] -> 
             RGBColor[
              0.910785314301231, 0.6747379690399473, 0.24659483090901074`], 
             UndirectedEdge[309, 323] -> 
             RGBColor[
              0.9038811679619893, 0.6500523324087744, 0.24117858858092586`], 
             UndirectedEdge[8, 202] -> 
             RGBColor[
              0.9538262988728916, 0.8466036831453103, 0.5140479070642303], 
             UndirectedEdge[127, 380] -> 
             RGBColor[
              0.9391492921214665, 0.7892602428730638, 0.3025899612579123], 
             UndirectedEdge[130, 151] -> 
             RGBColor[
              0.9893836132988103, 0.9898778655174341, 0.8256045321741792], 
             UndirectedEdge[335, 355] -> 
             RGBColor[
              0.9671240651412616, 0.8991926879207033, 0.3349664956596001], 
             UndirectedEdge[117, 395] -> 
             RGBColor[
              0.9835028429324824, 0.955073680186566, 0.4703154120672345], 
             UndirectedEdge[256, 310] -> 
             RGBColor[
              0.9545467290928706, 0.8573303953051489, 0.2831685195263528], 
             UndirectedEdge[362, 365] -> 
             RGBColor[
              0.9532650522997611, 0.8520164449387937, 0.28334826714863787`], 
             UndirectedEdge[163, 342] -> 
             RGBColor[
              0.955579282553781, 0.8588372399338857, 0.29747188131506086`], 
             UndirectedEdge[125, 288] -> 
             RGBColor[
              0.9909454321627511, 0.9887090617271816, 0.6678148150315074], 
             UndirectedEdge[161, 253] -> 
             RGBColor[
              0.9599864733989426, 0.8764292002305398, 0.3003986876949213], 
             UndirectedEdge[12, 211] -> 
             RGBColor[
              0.9917967642754928, 0.9898422395176448, 0.7104859497963583], 
             UndirectedEdge[107, 152] -> 
             RGBColor[
              0.9893490439443706, 0.9898635702009815, 0.8261774358398659], 
             UndirectedEdge[183, 291] -> 
             RGBColor[
              0.9621283002522141, 0.8745048370010717, 0.4776891019233117], 
             UndirectedEdge[149, 299] -> 
             RGBColor[
              0.9679832663396124, 0.9036621808562657, 0.3301214648925649], 
             UndirectedEdge[57, 284] -> 
             RGBColor[
              0.9655785296291466, 0.8896702702666218, 0.39250662256116475`], 
             UndirectedEdge[230, 279] -> 
             RGBColor[
              0.9427742775129057, 0.826447399935023, 0.5827593268943801], 
             UndirectedEdge[186, 374] -> 
             RGBColor[
              0.9257611004540589, 0.7433745324867546, 0.25912384269563865`], 
             UndirectedEdge[30, 175] -> 
             RGBColor[
              0.9925045043885932, 0.9847731569825953, 0.5618524586300687], 
             UndirectedEdge[261, 327] -> 
             RGBColor[
              0.9410313329924067, 0.7859038504343177, 0.46155007806980464`], 
             UndirectedEdge[271, 333] -> 
             RGBColor[
              0.9242108425917506, 0.737228276655511, 0.2578764688303965], 
             UndirectedEdge[199, 247] -> 
             RGBColor[
              0.9759452757321581, 0.9814554996413516, 0.9200000103945849], 
             UndirectedEdge[99, 223] -> 
             RGBColor[
              0.9798722223861909, 0.9524108615035389, 0.5937531925883011], 
             UndirectedEdge[200, 367] -> 
             RGBColor[
              0.9380835137629577, 0.7813678358031428, 0.30967704824184383`], 
             UndirectedEdge[111, 400] -> 
             RGBColor[
              0.9587241488007088, 0.865500807337243, 0.3302337037804398], 
             UndirectedEdge[277, 390] -> 
             RGBColor[
              0.9523894954778169, 0.8380902302097895, 0.3398753514375119], 
             UndirectedEdge[79, 298] -> 
             RGBColor[
              0.9214412262235434, 0.7226882004422471, 0.2554638427822655], 
             UndirectedEdge[96, 388] -> 
             RGBColor[
              0.9502810754671518, 0.840107460832844, 0.2813561724062741], 
             UndirectedEdge[153, 175] -> 
             RGBColor[
              0.9369503703000541, 0.7718711329507549, 0.3201002451457551], 
             UndirectedEdge[127, 331] -> 
             RGBColor[
              0.9448394630659892, 0.8166245779259773, 0.5388616278809757], 
             UndirectedEdge[6, 93] -> 
             RGBColor[
              0.950236098752592, 0.9595856678846673, 0.8437810694248439], 
             UndirectedEdge[76, 239] -> 
             RGBColor[
              0.9448491074496893, 0.8190521195231651, 0.2744825011774329], 
             UndirectedEdge[333, 337] -> 
             RGBColor[
              0.938177081233188, 0.7925997588956739, 0.269114032271052], 
             UndirectedEdge[253, 332] -> 
             RGBColor[
              0.934849367583567, 0.7794064831697645, 0.26643647575708845`], 
             UndirectedEdge[31, 400] -> 
             RGBColor[
              0.9591290658491145, 0.8668666876205595, 0.33180673005132744`], 
             UndirectedEdge[39, 149] -> 
             RGBColor[
              0.979034101695431, 0.9409392433709753, 0.37305187347477087`], 
             UndirectedEdge[49, 335] -> 
             RGBColor[
              0.9811658359823672, 0.9481300836758242, 0.38133325863527645`], 
             UndirectedEdge[57, 236] -> 
             RGBColor[
              0.9650577270281755, 0.8911325531294452, 0.5230849777934741], 
             UndirectedEdge[76, 323] -> 
             RGBColor[
              0.9124770247488738, 0.6841320401693013, 0.24809501672234444`], 
             UndirectedEdge[2, 210] -> 
             RGBColor[
              0.9819651612677726, 0.9504621355415387, 0.41541252859559197`], 
             UndirectedEdge[25, 395] -> 
             RGBColor[
              0.9838145222523077, 0.9557403307360594, 0.5042397825684313], 
             UndirectedEdge[62, 91] -> 
             RGBColor[
              0.9517731584880413, 0.8346660271741384, 0.39740801852257934`], 
             UndirectedEdge[148, 313] -> 
             RGBColor[
              0.9512486069896182, 0.8444240026921782, 0.2796316887228202], 
             UndirectedEdge[98, 163] -> 
             RGBColor[
              0.9398664067251326, 0.7992973715368847, 0.27047330321543633`], 
             UndirectedEdge[271, 292] -> 
             RGBColor[
              0.9539769762086612, 0.8628876462484831, 0.5855860851235555], 
             UndirectedEdge[148, 228] -> 
             RGBColor[
              0.9739391689613142, 0.9233193175505194, 0.36953412188414647`], 
             UndirectedEdge[105, 333] -> 
             RGBColor[
              0.9588033797710571, 0.8624291971215564, 0.4095333638700685], 
             UndirectedEdge[9, 65] -> 
             RGBColor[
              0.9665044125113953, 0.8935275663423464, 0.3822167782717194], 
             UndirectedEdge[129, 337] -> 
             RGBColor[
              0.9732631991668333, 0.9195091401680549, 0.4358683870858687], 
             UndirectedEdge[62, 323] -> 
             RGBColor[
              0.9375164176709876, 0.7715672418095598, 0.3855965633688909], 
             UndirectedEdge[286, 290] -> 
             RGBColor[
              0.9666964843592512, 0.8993215630857301, 0.3251225598872485], 
             UndirectedEdge[96, 261] -> 
             RGBColor[
              0.9223325391683312, 0.7243607338875463, 0.2586125781292502], 
             UndirectedEdge[48, 86] -> 
             RGBColor[
              0.8965375921768325, 0.7338595609185836, 0.6052144023671779], 
             UndirectedEdge[137, 328] -> 
             RGBColor[
              0.9638936964375002, 0.8825739164007487, 0.4158002739500808], 
             UndirectedEdge[110, 212] -> 
             RGBColor[
              0.9944131949468443, 0.991185419398144, 0.6861127541203054], 
             UndirectedEdge[163, 272] -> 
             RGBColor[
              0.9699513046990433, 0.9063760707032599, 0.433352177616809], 
             UndirectedEdge[245, 396] -> 
             RGBColor[
              0.9809676755018486, 0.9466816977070622, 0.44688426228149813`], 
             UndirectedEdge[25, 37] -> 
             RGBColor[
              0.9910416084554399, 0.9900173403246455, 0.7584280094574525], 
             UndirectedEdge[79, 373] -> 
             RGBColor[
              0.9662604076029795, 0.9146088527113676, 0.5978138519822447], 
             UndirectedEdge[34, 43] -> 
             RGBColor[
              0.9922769698779871, 0.9909086056013121, 0.7656067797903496], 
             UndirectedEdge[100, 358] -> 
             RGBColor[
              0.9608415561145103, 0.8709420630598705, 0.38559946266233], 
             UndirectedEdge[273, 394] -> 
             RGBColor[
              0.9840550171927065, 0.957875970310307, 0.3925571820613542], 
             UndirectedEdge[89, 189] -> 
             RGBColor[
              0.9609800753345688, 0.8790699948273857, 0.30796080434796774`], 
             UndirectedEdge[268, 299] -> 
             RGBColor[
              0.5702390823497467, 0.5936795958474301, 0.6193174823105888], 
             UndirectedEdge[143, 272] -> 
             RGBColor[
              0.9940650604657908, 0.9897140893877872, 0.5953966417815778], 
             UndirectedEdge[339, 382] -> 
             RGBColor[
              0.9887929138871332, 0.9734511471372511, 0.4455595586198555], 
             UndirectedEdge[111, 223] -> 
             RGBColor[
              0.9865977306819609, 0.9750975802096148, 0.6198805223116957], 
             UndirectedEdge[71, 131] -> 
             RGBColor[
              0.9919289633884021, 0.9852395959446503, 0.5863913093677543], 
             UndirectedEdge[114, 370] -> 
             RGBColor[
              0.9464853326788982, 0.8221289671398977, 0.5319300382665486], 
             UndirectedEdge[4, 125] -> 
             RGBColor[
              0.9742527525582012, 0.9795673297893761, 0.8948364296222397], 
             UndirectedEdge[246, 251] -> 
             RGBColor[
              0.9107962326490409, 0.816300957010927, 0.6211048274378621], 
             UndirectedEdge[30, 229] -> 
             RGBColor[
              0.9897576538960094, 0.9898785127589061, 0.8082094904189605], 
             UndirectedEdge[115, 366] -> 
             RGBColor[
              0.9290855459526799, 0.7372101695769118, 0.49248345534103066`], 
             UndirectedEdge[89, 270] -> 
             RGBColor[
              0.9679631965326214, 0.9185735798577541, 0.5970222302612178], 
             UndirectedEdge[197, 369] -> 
             RGBColor[
              0.9821847081354178, 0.9562554243311036, 0.5753930757892445], 
             UndirectedEdge[276, 301] -> 
             RGBColor[
              0.9606639351451824, 0.8743245988645909, 0.32589285431633663`], 
             UndirectedEdge[69, 188] -> 
             RGBColor[
              0.9569109967301372, 0.8663128155709702, 0.2871077882824221], 
             UndirectedEdge[191, 225] -> 
             RGBColor[
              0.9792321430910518, 0.9416072835007352, 0.37382122689977815`], 
             UndirectedEdge[223, 247] -> 
             RGBColor[
              0.9776135649876382, 0.9821453801215707, 0.8923521400370841], 
             UndirectedEdge[72, 86] -> 
             RGBColor[
              0.9347315481292253, 0.759504413498808, 0.35707328068525485`], 
             UndirectedEdge[19, 85] -> 
             RGBColor[
              0.943698199212031, 0.811416739359429, 0.2895576300137694], 
             UndirectedEdge[320, 398] -> 
             RGBColor[
              0.9907743217721041, 0.9799746165652174, 0.46688640162028483`], 
             UndirectedEdge[249, 300] -> 
             RGBColor[
              0.9803742210292501, 0.9446303363447772, 0.4487879329229366], 
             UndirectedEdge[18, 319] -> 
             RGBColor[
              0.9783898538506115, 0.9387660441138115, 0.370549092253644], 
             UndirectedEdge[6, 273] -> 
             RGBColor[
              0.9884713869996292, 0.9712348674897313, 0.5405415727869952], 
             UndirectedEdge[158, 348] -> 
             RGBColor[
              0.946727431734564, 0.823080111811255, 0.29379973005123483`], 
             UndirectedEdge[61, 228] -> 
             RGBColor[
              0.9050532635903374, 0.5605542874346763, 0.3102815138591152], 
             UndirectedEdge[70, 260] -> 
             RGBColor[
              0.8887869604315826, 0.5114864132991501, 0.22833959805859072`], 
             UndirectedEdge[144, 305] -> 
             RGBColor[
              0.9778264006731393, 0.9395048987693231, 0.5442997388066437], 
             UndirectedEdge[165, 351] -> 
             RGBColor[
              0.9616270504793557, 0.8737891404223532, 0.4020397678365119], 
             UndirectedEdge[132, 370] -> 
             RGBColor[
              0.9476145114208967, 0.8225959115682842, 0.5132166242907223], 
             UndirectedEdge[104, 145] -> 
             RGBColor[
              0.9580258757858875, 0.859940682702711, 0.37375625108653215`], 
             UndirectedEdge[207, 231] -> 
             RGBColor[
              0.9116408518481018, 0.6847221026731094, 0.2476242248156531], 
             UndirectedEdge[21, 249] -> 
             RGBColor[
              0.9802774910883663, 0.9444234407821239, 0.43825947580572944`], 
             UndirectedEdge[7, 93] -> 
             RGBColor[
              0.949643899916516, 0.9583190144547875, 0.7793238807455449], 
             UndirectedEdge[140, 255] -> 
             RGBColor[
              0.9722941347550949, 0.9182037522617261, 0.34686837464752224`], 
             UndirectedEdge[100, 157] -> 
             RGBColor[
              0.9350616323491819, 0.7802480422323874, 0.2666072689699966], 
             UndirectedEdge[42, 178] -> 
             RGBColor[
              0.9779244172779737, 0.9367845046449272, 0.523591928866094], 
             UndirectedEdge[115, 195] -> 
             RGBColor[
              0.9683993511994697, 0.9041594281234173, 0.5246895842368625], 
             UndirectedEdge[281, 394] -> 
             RGBColor[
              0.9742691742390208, 0.9248660242023324, 0.354541030087664], 
             UndirectedEdge[215, 224] -> 
             RGBColor[
              0.9279004222288303, 0.7452259782245719, 0.2747993186862382], 
             UndirectedEdge[99, 222] -> 
             RGBColor[
              0.9513343414319698, 0.8401803641713883, 0.303571863429831], 
             UndirectedEdge[55, 284] -> 
             RGBColor[
              0.97091320995786, 0.9746306818483061, 0.7441327196098596], 
             UndirectedEdge[32, 337] -> 
             RGBColor[
              0.9730581124876603, 0.9190704804987477, 0.4135459677061618], 
             UndirectedEdge[172, 399] -> 
             RGBColor[
              0.9072631057991887, 0.7825616132703532, 0.6141640338400685], 
             UndirectedEdge[267, 346] -> 
             RGBColor[
              0.9813126576611624, 0.9486253476737698, 0.38190363313244824`], 
             UndirectedEdge[222, 393] -> 
             RGBColor[
              0.9327916424233974, 0.7712482886059531, 0.26478078179219866`], 
             UndirectedEdge[116, 179] -> 
             RGBColor[
              0.9880303029772326, 0.9868470183467615, 0.6715524369034994], 
             UndirectedEdge[120, 360] -> 
             RGBColor[
              0.9506850336165973, 0.8367544011430584, 0.307484947316229], 
             UndirectedEdge[144, 222] -> 
             RGBColor[
              0.9472596292143485, 0.8264354030734253, 0.2877423759092079], 
             UndirectedEdge[237, 307] -> 
             RGBColor[
              0.9931986571628921, 0.9895766691577661, 0.6258093627287123], 
             UndirectedEdge[18, 144] -> 
             RGBColor[
              0.9698045806599043, 0.9098059017235487, 0.33719692710054905`], 
             UndirectedEdge[309, 365] -> 
             RGBColor[
              0.9418429544363087, 0.806731633098684, 0.2741577790966083], 
             UndirectedEdge[189, 241] -> 
             RGBColor[
              0.9740104931569351, 0.9239934321712506, 0.35353610293158416`], 
             UndirectedEdge[268, 370] -> 
             RGBColor[
              0.541170639367659, 0.4798513112764763, 0.5873099227275641], 
             UndirectedEdge[336, 359] -> 
             RGBColor[
              0.9377975836297544, 0.8573490740759522, 0.6180383265963647], 
             UndirectedEdge[115, 123] -> 
             RGBColor[
              0.9887552247255298, 0.9762503772389508, 0.5859266430961338], 
             UndirectedEdge[6, 394] -> 
             RGBColor[
              0.9905795580241801, 0.9783462233776377, 0.5487314191226829], 
             UndirectedEdge[259, 353] -> 
             RGBColor[
              0.9741839785221404, 0.9235084378024719, 0.5118005954558492], 
             UndirectedEdge[98, 348] -> 
             RGBColor[
              0.9506915380236394, 0.8387964722873256, 0.29698934302095864`], 
             UndirectedEdge[145, 349] -> 
             RGBColor[
              0.9372717032903977, 0.789010237051825, 0.2683855439263313], 
             UndirectedEdge[287, 292] -> 
             RGBColor[
              0.9884307356531951, 0.9893498527365161, 0.8353965787539104], 
             UndirectedEdge[53, 69] -> 
             RGBColor[
              0.975621116152086, 0.9293935919236901, 0.5172613422145621], 
             UndirectedEdge[236, 284] -> 
             RGBColor[
              0.9928165188375657, 0.9896198120570164, 0.6467650949819619], 
             UndirectedEdge[119, 146] -> 
             RGBColor[
              0.9806123581477835, 0.9838802090436221, 0.8648103322049854], 
             UndirectedEdge[198, 310] -> 
             RGBColor[
              0.9569243798426041, 0.8653507695829444, 0.29240524370739873`], 
             UndirectedEdge[198, 384] -> 
             RGBColor[
              0.9367556079622317, 0.78538830992208, 0.2761769764305287], 
             UndirectedEdge[111, 292] -> 
             RGBColor[
              0.9841497194773414, 0.9739512912788686, 0.654450801245744], 
             UndirectedEdge[40, 295] -> 
             RGBColor[
              0.9601715742454608, 0.87149445805359, 0.33006981720376544`], 
             UndirectedEdge[5, 270] -> 
             RGBColor[
              0.9797675967038251, 0.9593613717816138, 0.6378346817840741], 
             UndirectedEdge[104, 355] -> 
             RGBColor[
              0.9718762451476808, 0.9148527818602337, 0.3849005833849845], 
             UndirectedEdge[356, 360] -> 
             RGBColor[
              0.9811109869852295, 0.9479450651293218, 0.3811201806387605], 
             UndirectedEdge[42, 398] -> 
             RGBColor[
              0.9912638995644507, 0.9817817106566014, 0.5754132985991997], 
             UndirectedEdge[153, 211] -> 
             RGBColor[
              0.939039577655018, 0.7779427969842456, 0.41118485742460814`], 
             UndirectedEdge[223, 385] -> 
             RGBColor[
              0.9907148890847131, 0.988587548895075, 0.6697326938469255], 
             UndirectedEdge[144, 361] -> 
             RGBColor[
              0.9766582333499096, 0.9329248815611154, 0.36382207359751007`], 
             UndirectedEdge[216, 229] -> 
             RGBColor[
              0.9893139567701565, 0.9889294894713676, 0.7599157964511268], 
             UndirectedEdge[161, 389] -> 
             RGBColor[
              0.9408213882946432, 0.9148327032293817, 0.6549984008536891], 
             UndirectedEdge[313, 340] -> 
             RGBColor[
              0.9703625900235809, 0.9086544046306568, 0.3953542163800019], 
             UndirectedEdge[241, 380] -> 
             RGBColor[
              0.9779848152299347, 0.937399753738678, 0.36897559369744004`], 
             UndirectedEdge[258, 281] -> 
             RGBColor[
              0.95688246857696, 0.8648642082619978, 0.2940401545595801], 
             UndirectedEdge[344, 346] -> 
             RGBColor[
              0.9814203420713898, 0.9625706836289631, 0.6338962043124773], 
             UndirectedEdge[79, 205] -> 
             RGBColor[
              0.9720971567214403, 0.9156564935083835, 0.38934655106211746`], 
             UndirectedEdge[227, 306] -> 
             RGBColor[
              0.9650410506244333, 0.8897769719414648, 0.33931747024080683`], 
             UndirectedEdge[43, 381] -> 
             RGBColor[
              0.9907950884011616, 0.9902958095280279, 0.7901653908476762], 
             UndirectedEdge[98, 143] -> 
             RGBColor[
              0.9639801624918799, 0.8826353902214121, 0.43251776738020514`], 
             UndirectedEdge[243, 267] -> 
             RGBColor[
              0.9893077667592954, 0.9759456953399765, 0.5730843250826749], 
             UndirectedEdge[58, 152] -> 
             RGBColor[
              0.9405481778143079, 0.797097059699303, 0.5351046036405551], 
             UndirectedEdge[376, 397] -> 
             RGBColor[
              0.9756865529149861, 0.9339348597992518, 0.547378923809226], 
             UndirectedEdge[114, 279] -> 
             RGBColor[
              0.9483371660449702, 0.8297049735774304, 0.5334321768301504], 
             UndirectedEdge[148, 218] -> 
             RGBColor[
              0.9722790340048411, 0.9247847573399101, 0.5534707755978054], 
             UndirectedEdge[55, 366] -> 
             RGBColor[
              0.9071198483053808, 0.7221952400094833, 0.5908850233049054], 
             UndirectedEdge[99, 361] -> 
             RGBColor[
              0.9807329455675309, 0.9466698426590785, 0.37965156111813303`], 
             UndirectedEdge[97, 169] -> 
             RGBColor[
              0.991636683394027, 0.9894668956152184, 0.6906672285806217], 
             UndirectedEdge[43, 250] -> 
             RGBColor[
              0.9488949749942978, 0.8214858181278839, 0.47373254128364234`], 
             UndirectedEdge[112, 177] -> 
             RGBColor[
              0.9739104953355711, 0.9427414878380074, 0.6217412555675487], 
             UndirectedEdge[255, 356] -> 
             RGBColor[
              0.9737327241193329, 0.9230564519841469, 0.35245702267278095`], 
             UndirectedEdge[210, 328] -> 
             RGBColor[
              0.9823153674358452, 0.9512111911237711, 0.4535303087683582], 
             UndirectedEdge[91, 221] -> 
             RGBColor[
              0.9194859890566296, 0.7184958068528613, 0.2540747407694715], 
             UndirectedEdge[32, 345] -> 
             RGBColor[
              0.9900268869567055, 0.9887061127098316, 0.7104336308746968], 
             UndirectedEdge[210, 258] -> 
             RGBColor[
              0.9611134436539983, 0.8791362806770382, 0.31047669378127285`], 
             UndirectedEdge[189, 359] -> 
             RGBColor[
              0.9489488158444221, 0.8313700601285121, 0.29828017055223893`], 
             UndirectedEdge[164, 258] -> 
             RGBColor[
              0.929253861180299, 0.7572221648727812, 0.2619341999616029], 
             UndirectedEdge[354, 374] -> 
             RGBColor[
              0.9531219202130407, 0.8482180353806194, 0.30005988249344895`], 
             UndirectedEdge[235, 322] -> 
             RGBColor[
              0.9851034265010825, 0.9876780492695385, 0.8772887872240275], 
             UndirectedEdge[147, 392] -> 
             RGBColor[
              0.962946312187936, 0.8795446660063935, 0.37202910171887504`], 
             UndirectedEdge[123, 283] -> 
             RGBColor[
              0.9845575371477386, 0.9595710881159266, 0.3945093771937228], 
             UndirectedEdge[202, 239] -> 
             RGBColor[
              0.9692195152513535, 0.9076326566006335, 0.5264336502875683], 
             UndirectedEdge[180, 249] -> 
             RGBColor[
              0.9798814566084372, 0.9435763630747838, 0.39515356670695756`], 
             UndirectedEdge[2, 197] -> 
             RGBColor[
              0.9832538901309431, 0.9548093206049395, 0.42041899687298423`], 
             UndirectedEdge[174, 329] -> 
             RGBColor[
              0.9883341357334468, 0.9872855128613087, 0.6878512116238233], 
             UndirectedEdge[193, 242] -> 
             RGBColor[
              0.9740374068420373, 0.9240842183507344, 0.3536406575159835], 
             UndirectedEdge[58, 160] -> 
             RGBColor[
              0.9394851600787344, 0.7853711701711212, 0.31701571358923664`], 
             UndirectedEdge[50, 137] -> 
             RGBColor[
              0.9632862749876634, 0.8812747033392772, 0.34968619770601705`], 
             UndirectedEdge[326, 383] -> 
             RGBColor[
              0.9934170908675042, 0.9883281479368282, 0.5248691498129137], 
             UndirectedEdge[157, 238] -> 
             RGBColor[
              0.9551477221232243, 0.8561530430674944, 0.3021930983873413], 
             UndirectedEdge[243, 346] -> 
             RGBColor[
              0.9858907556541039, 0.9644193145298041, 0.5598098821874083], 
             UndirectedEdge[235, 355] -> 
             RGBColor[
              0.9696259774671738, 0.91580227801432, 0.5588523796014815], 
             UndirectedEdge[44, 135] -> 
             RGBColor[
              0.9732301736227559, 0.9218404972615952, 0.5213757587941898], 
             UndirectedEdge[33, 206] -> 
             RGBColor[
              0.9584026382450382, 0.864719154088643, 0.32740730559734743`], 
             UndirectedEdge[88, 263] -> 
             RGBColor[
              0.9270168690859826, 0.7408671584128711, 0.5457984093392101], 
             UndirectedEdge[82, 399] -> 
             RGBColor[
              0.9022001741521837, 0.6481020973605687, 0.24006988969855558`], 
             UndirectedEdge[271, 287] -> 
             RGBColor[
              0.9590221181733263, 0.8651079154917243, 0.5079746283365976], 
             UndirectedEdge[31, 223] -> 
             RGBColor[
              0.9870026477303666, 0.9764634604929313, 0.6214535485825832], 
             UndirectedEdge[108, 376] -> 
             RGBColor[
              0.9928056889393679, 0.9905197717786689, 0.7126876811282035], 
             UndirectedEdge[301, 361] -> 
             RGBColor[
              0.9651245461675217, 0.8893712872442163, 0.34322148582241485`], 
             UndirectedEdge[80, 388] -> 
             RGBColor[
              0.9689831979307628, 0.9016576970030049, 0.4846559742182941], 
             UndirectedEdge[47, 136] -> 
             RGBColor[
              0.9851284450335843, 0.9849046950425266, 0.6940695639304006], 
             UndirectedEdge[39, 50] -> 
             RGBColor[
              0.9881158084841437, 0.9715272029061732, 0.4123095683062534], 
             UndirectedEdge[120, 389] -> 
             RGBColor[
              0.921893919443886, 0.8424291274944656, 0.6260326085765013], 
             UndirectedEdge[28, 106] -> 
             RGBColor[
              0.9245068913609746, 0.8106102582759496, 0.6119640128332684], 
             UndirectedEdge[97, 326] -> 
             RGBColor[
              0.991832417290651, 0.9898855506283647, 0.7119716552985615], 
             UndirectedEdge[195, 242] -> 
             RGBColor[
              0.9610264508118154, 0.876769400617303, 0.3209372161567589], 
             UndirectedEdge[90, 260] -> 
             RGBColor[
              0.9073942726282918, 0.5731618360735409, 0.4507770334518692], 
             UndirectedEdge[73, 368] -> 
             RGBColor[
              0.9667194667430278, 0.8935726908180626, 0.4301729973939333], 
             UndirectedEdge[52, 287] -> 
             RGBColor[
              0.9893047913901584, 0.9898452706325759, 0.826910815185103], 
             UndirectedEdge[135, 243] -> 
             RGBColor[
              0.9735484762527657, 0.9219721235791087, 0.5161006604741265], 
             UndirectedEdge[311, 317] -> 
             RGBColor[
              0.9938292625703196, 0.9917162557391781, 0.7519286187737566], 
             UndirectedEdge[6, 10] -> 
             RGBColor[
              0.9671076242762817, 0.9729477849935656, 0.8422429125567911], 
             UndirectedEdge[363, 383] -> 
             RGBColor[
              0.991623273669491, 0.9885913166975381, 0.6276472004633238], 
             UndirectedEdge[227, 346] -> 
             RGBColor[
              0.9827037053821259, 0.9533176782701172, 0.38730759085107175`], 
             UndirectedEdge[157, 341] -> 
             RGBColor[
              0.9486191990604754, 0.8339992764513776, 0.2775160053828952], 
             UndirectedEdge[18, 310] -> 
             RGBColor[
              0.964426409408681, 0.8906568768696301, 0.3215492119321981], 
             UndirectedEdge[37, 96] -> 
             RGBColor[
              0.9725112550320162, 0.9288345007629317, 0.5738242076342024], 
             UndirectedEdge[218, 222] -> 
             RGBColor[
              0.9603365557285277, 0.8774368105693, 0.5438615772506898], 
             UndirectedEdge[65, 203] -> 
             RGBColor[
              0.9590365203338421, 0.8639198623858944, 0.3762079369317011], 
             UndirectedEdge[105, 303] -> 
             RGBColor[
              0.9909468636726229, 0.9803520595277277, 0.48495281840257254`], 
             UndirectedEdge[119, 267] -> 
             RGBColor[
              0.9773265819574243, 0.968620650464111, 0.6654869664596194], 
             UndirectedEdge[20, 312] -> 
             RGBColor[
              0.9725985116115119, 0.9330364449540318, 0.6011724187195768], 
             UndirectedEdge[285, 324] -> 
             RGBColor[
              0.9921624051994069, 0.989142670112076, 0.642584239371656], 
             UndirectedEdge[16, 302] -> 
             RGBColor[
              0.9760086515057398, 0.9307336894716606, 0.3612985707961486], 
             UndirectedEdge[65, 313] -> 
             RGBColor[
              0.9702697250502001, 0.9084557758426843, 0.38524643712368645`], 
             UndirectedEdge[280, 392] -> 
             RGBColor[
              0.9281028581937272, 0.7295865415113401, 0.3433820402699684], 
             UndirectedEdge[1, 357] -> 
             RGBColor[
              0.9596058350371608, 0.9167424520168025, 0.6145841882040601], 
             UndirectedEdge[26, 177] -> 
             RGBColor[
              0.9687880842510748, 0.9254623924506827, 0.601841655790446], 
             UndirectedEdge[69, 293] -> 
             RGBColor[
              0.9706432024693328, 0.927334664532205, 0.5997389014866488], 
             UndirectedEdge[165, 399] -> 
             RGBColor[
              0.9456691127796284, 0.8086600215579223, 0.3891033579337966], 
             UndirectedEdge[108, 297] -> 
             RGBColor[
              0.9939678147717306, 0.9895060906812403, 0.5848120481139791], 
             UndirectedEdge[192, 335] -> 
             RGBColor[
              0.9873699713469282, 0.9734701877714551, 0.5936267445313976], 
             UndirectedEdge[134, 272] -> 
             RGBColor[
              0.961248605434555, 0.8718727681221794, 0.42634978150999525`], 
             UndirectedEdge[86, 236] -> 
             RGBColor[
              0.9343051300284524, 0.7611685752638184, 0.4979248062905143], 
             UndirectedEdge[312, 389] -> 
             RGBColor[
              0.9507772009071298, 0.9622219549917921, 0.9467964503173647], 
             UndirectedEdge[156, 245] -> 
             RGBColor[
              0.9940335623431065, 0.989646718088314, 0.5919682655112573], 
             UndirectedEdge[153, 168] -> 
             RGBColor[
              0.9346024299379736, 0.7639509787868433, 0.3109789402104047], 
             UndirectedEdge[118, 150] -> 
             RGBColor[
              0.9548135725176212, 0.8563381988264449, 0.5433234640081959], 
             UndirectedEdge[195, 255] -> 
             RGBColor[
              0.9519822758870711, 0.8462612749228824, 0.2858023044232513], 
             UndirectedEdge[109, 180] -> 
             RGBColor[
              0.9706589956888491, 0.9102470649854315, 0.3708866571822016], 
             UndirectedEdge[143, 378] -> 
             RGBColor[
              0.9694124945932664, 0.9041727767860477, 0.43688874930220367`], 
             UndirectedEdge[135, 383] -> 
             RGBColor[
              0.9729640932403414, 0.9195177602456942, 0.36494503601132156`], 
             UndirectedEdge[20, 120] -> 
             RGBColor[
              0.9437152301482681, 0.8132436174567055, 0.28040857697871335`], 
             UndirectedEdge[149, 230] -> 
             RGBColor[
              0.9764229887690402, 0.9543966672298495, 0.6382522481851904], 
             UndirectedEdge[16, 77] -> 
             RGBColor[
              0.9914135005066204, 0.9822770413070043, 0.456927086875324], 
             UndirectedEdge[168, 238] -> 
             RGBColor[
              0.9768924748689194, 0.9337150332072595, 0.36473205766606376`], 
             UndirectedEdge[104, 335] -> 
             RGBColor[
              0.9883505353207465, 0.9719956365047561, 0.44071722462259477`], 
             UndirectedEdge[79, 232] -> 
             RGBColor[
              0.9532689171484253, 0.8524338592433975, 0.2812572776993708], 
             UndirectedEdge[47, 299] -> 
             RGBColor[
              0.9772090225340961, 0.9345582475047789, 0.3850580485723426], 
             UndirectedEdge[236, 397] -> 
             RGBColor[
              0.9762215813867956, 0.9341561078219496, 0.53851211742204], 
             UndirectedEdge[33, 118] -> 
             RGBColor[
              0.9861321660450859, 0.9724377872685399, 0.6105424549019877], 
             UndirectedEdge[51, 79] -> 
             RGBColor[
              0.9717738591714993, 0.9149649927394559, 0.3541576079122317], 
             UndirectedEdge[24, 168] -> 
             RGBColor[
              0.9689483147681106, 0.9059487374683135, 0.33891590987152265`], 
             UndirectedEdge[269, 365] -> 
             RGBColor[
              0.9631924470462423, 0.9220744301061439, 0.6129805571610163], 
             UndirectedEdge[98, 240] -> 
             RGBColor[
              0.9637524616128452, 0.8821483610652472, 0.40773393190421575`], 
             UndirectedEdge[29, 113] -> 
             RGBColor[
              0.9125446506176712, 0.6492403372889344, 0.28153350152198975`], 
             UndirectedEdge[330, 398] -> 
             RGBColor[
              0.9862692735598169, 0.9797163044476518, 0.6581871771737391], 
             UndirectedEdge[43, 265] -> 
             RGBColor[
              0.9942977505387764, 0.9902117899253282, 0.6207235202293911], 
             UndirectedEdge[209, 304] -> 
             RGBColor[
              0.9635426867678418, 0.8973086180762693, 0.5814809370465903], 
             UndirectedEdge[107, 238] -> 
             RGBColor[
              0.9793254660157961, 0.9479116071022218, 0.573278461498545], 
             UndirectedEdge[298, 347] -> 
             RGBColor[
              0.9332575632814518, 0.7912496003117814, 0.579644522975105], 
             UndirectedEdge[153, 343] -> 
             RGBColor[
              0.937279010305668, 0.7782482830845712, 0.5154884402652411], 
             UndirectedEdge[110, 292] -> 
             RGBColor[
              0.988912609379885, 0.9895491199060922, 0.8274106840534274], 
             UndirectedEdge[332, 366] -> 
             RGBColor[
              0.8901792612793795, 0.5912212758121951, 0.22992054130192938`], 
             UndirectedEdge[39, 136] -> 
             RGBColor[
              0.9805214225548005, 0.9695887017473177, 0.6570758885614416], 
             UndirectedEdge[115, 380] -> 
             RGBColor[
              0.9848211659244438, 0.9629798731419541, 0.5706435675385817], 
             UndirectedEdge[167, 238] -> 
             RGBColor[
              0.9766068849434697, 0.9327516713290145, 0.36362259473482395`], 
             UndirectedEdge[1, 162] -> 
             RGBColor[
              0.9746329362045771, 0.9263461031334849, 0.5173375925779662], 
             UndirectedEdge[128, 243] -> 
             RGBColor[
              0.9698261985245249, 0.9072145327621564, 0.5131056284408961], 
             UndirectedEdge[196, 366] -> 
             RGBColor[
              0.9190773486945607, 0.7311131242211238, 0.5706440941616018], 
             UndirectedEdge[136, 149] -> 
             RGBColor[
              0.9759026888391007, 0.9540086283940135, 0.6391329802506229], 
             UndirectedEdge[263, 360] -> 
             RGBColor[
              0.9802196735478241, 0.9568165821060448, 0.6174540935809352], 
             UndirectedEdge[267, 354] -> 
             RGBColor[
              0.9764891035471475, 0.9323543670228326, 0.3631650362512624], 
             UndirectedEdge[192, 355] -> 
             RGBColor[
              0.9708956811738626, 0.9163273331269326, 0.5378101032937873], 
             UndirectedEdge[24, 100] -> 
             RGBColor[
              0.9405450270647973, 0.8019878750468326, 0.27101933706999726`], 
             UndirectedEdge[11, 286] -> 
             RGBColor[
              0.9466273799596329, 0.8223747974060702, 0.29532664121110624`], 
             UndirectedEdge[71, 110] -> 
             RGBColor[
              0.992358557504345, 0.985417244151658, 0.5792718231126451], 
             UndirectedEdge[186, 306] -> 
             RGBColor[
              0.9280486179252816, 0.7524437769901431, 0.2609644329479206], 
             UndirectedEdge[6, 131] -> 
             RGBColor[
              0.9942881823352284, 0.9916592402309781, 0.7263840574622644], 
             UndirectedEdge[53, 264] -> 
             RGBColor[
              0.9938069965837255, 0.9917070481815118, 0.7522976237941457], 
             UndirectedEdge[83, 118] -> 
             RGBColor[
              0.9919765942402438, 0.9909501297732874, 0.7826321275550578], 
             UndirectedEdge[98, 272] -> 
             RGBColor[
              0.9639434155449258, 0.8825567922175636, 0.4285180889801226], 
             UndirectedEdge[200, 330] -> 
             RGBColor[
              0.9390636398396621, 0.7990451586833756, 0.5705126802219511], 
             UndirectedEdge[101, 389] -> 
             RGBColor[
              0.9467691491710039, 0.9348958972660115, 0.6781043287179546], 
             UndirectedEdge[10, 353] -> 
             RGBColor[
              0.9668294728963505, 0.9730795528744893, 0.8647916739156225], 
             UndirectedEdge[174, 340] -> 
             RGBColor[
              0.9930856639545893, 0.9876192592825039, 0.48879537567192755`], 
             UndirectedEdge[77, 187] -> 
             RGBColor[
              0.9935093469054144, 0.9885254742734018, 0.5349106502011663], 
             UndirectedEdge[137, 264] -> 
             RGBColor[
              0.9637312677199699, 0.8837907495780135, 0.5118255017654625], 
             UndirectedEdge[20, 356] -> 
             RGBColor[
              0.9741411835169002, 0.9244342814429688, 0.354043810301245], 
             UndirectedEdge[130, 227] -> 
             RGBColor[
              0.9861394054331116, 0.9787525931238605, 0.6540494900849076], 
             UndirectedEdge[24, 150] -> 
             RGBColor[
              0.9366481883905838, 0.7865382082480862, 0.26788384920216524`], 
             UndirectedEdge[282, 339] -> 
             RGBColor[
              0.9900904609009822, 0.9778280778934906, 0.4506002837474655], 
             UndirectedEdge[69, 93] -> 
             RGBColor[
              0.9312866379162859, 0.8972032421310845, 0.6393383643940025], 
             UndirectedEdge[65, 266] -> 
             RGBColor[
              0.9934700427753094, 0.9884414067133642, 0.5306326381962101], 
             UndirectedEdge[189, 336] -> 
             RGBColor[
              0.958121961716439, 0.9339924234592178, 0.6548907460472604], 
             UndirectedEdge[191, 322] -> 
             RGBColor[
              0.9811971331108222, 0.9663311520815205, 0.647947148042264], 
             UndirectedEdge[297, 376] -> 
             RGBColor[
              0.992387785125338, 0.9896259177770155, 0.6672014299744189], 
             UndirectedEdge[33, 286] -> 
             RGBColor[
              0.9759074390267184, 0.930392276014101, 0.3609053794275232], 
             UndirectedEdge[145, 351] -> 
             RGBColor[
              0.9263152413545432, 0.7455715165006669, 0.25956971747152713`], 
             UndirectedEdge[83, 141] -> 
             RGBColor[
              0.944584102950613, 0.8023955543808762, 0.48352677664642996`], 
             UndirectedEdge[148, 276] -> 
             RGBColor[
              0.9680863255788619, 0.903751903569141, 0.3318650838851709], 
             UndirectedEdge[124, 160] -> 
             RGBColor[
              0.988409371519585, 0.9725642299058839, 0.40947302637045957`], 
             UndirectedEdge[25, 362] -> 
             RGBColor[
              0.9719281518740261, 0.913647068437574, 0.4684677627008998], 
             UndirectedEdge[96, 208] -> 
             RGBColor[
              0.9331036175024382, 0.7720045640512956, 0.2675347865211052], 
             UndirectedEdge[240, 272] -> 
             RGBColor[
              0.9938373595867561, 0.9892270602316223, 0.5706128063055884], 
             UndirectedEdge[25, 182] -> 
             RGBColor[
              0.9939045572243561, 0.9893707891837253, 0.5779268544625982], 
             UndirectedEdge[101, 380] -> 
             RGBColor[
              0.9769997479428796, 0.9340768904746426, 0.36514879330157857`], 
             UndirectedEdge[24, 358] -> 
             RGBColor[
              0.972983485787744, 0.9190807681560317, 0.3953691442851336], 
             UndirectedEdge[202, 234] -> 
             RGBColor[
              0.9913285857982179, 0.9906821616294524, 0.7933713044315165], 
             UndirectedEdge[17, 62] -> 
             RGBColor[
              0.978711707322006, 0.9806532215588317, 0.7473114848682303], 
             UndirectedEdge[24, 211] -> 
             RGBColor[
              0.9733854624851551, 0.9199405556657158, 0.4391218270857261], 
             UndirectedEdge[2, 39] -> 
             RGBColor[
              0.9883730237659076, 0.9720773603854123, 0.4403058643775509], 
             UndirectedEdge[164, 328] -> 
             RGBColor[
              0.950455784962146, 0.829297075319514, 0.4049878149486883], 
             UndirectedEdge[228, 301] -> 
             RGBColor[
              0.9665167785276346, 0.8938920128459694, 0.3635618923153122], 
             UndirectedEdge[118, 286] -> 
             RGBColor[
              0.978792997973738, 0.9476810500452724, 0.5820311728303975], 
             UndirectedEdge[139, 215] -> 
             RGBColor[
              0.8572665338823422, 0.3904716431821148, 0.20048614250961336`], 
             UndirectedEdge[239, 377] -> 
             RGBColor[
              0.9097876745682877, 0.6711747369875187, 0.24581238830155516`], 
             UndirectedEdge[348, 374] -> 
             RGBColor[
              0.9527599302872021, 0.8469969583614894, 0.2986536199876276], 
             UndirectedEdge[8, 388] -> 
             RGBColor[
              0.9291654091643444, 0.7568714821044087, 0.2618630293933303], 
             UndirectedEdge[249, 370] -> 
             RGBColor[
              0.935157884319548, 0.7771608587389818, 0.2835189065854078], 
             UndirectedEdge[61, 285] -> 
             RGBColor[
              0.9042730151751541, 0.5623835829209429, 0.47963617051022633`], 
             UndirectedEdge[162, 280] -> 
             RGBColor[
              0.9285260971194296, 0.7317324100534425, 0.47962774709926215`], 
             UndirectedEdge[126, 205] -> 
             RGBColor[
              0.989810056325404, 0.9882423339144173, 0.6868329547810698], 
             UndirectedEdge[161, 334] -> 
             RGBColor[
              0.9184765139189999, 0.7025934815308239, 0.2665196572121991], 
             UndirectedEdge[192, 399] -> 
             RGBColor[
              0.9444535792222759, 0.8096319966445102, 0.5164378887390617], 
             UndirectedEdge[69, 281] -> 
             RGBColor[
              0.9597360832096373, 0.8758424956281738, 0.29808271578246365`], 
             UndirectedEdge[38, 128] -> 
             RGBColor[
              0.9372309454937728, 0.7888486459699375, 0.26835274924645836`], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.9917379891494895, 0.9829710897032671, 0.49224567313985323`], 
             UndirectedEdge[145, 355] -> 
             RGBColor[
              0.9367994056064027, 0.7871377341186583, 0.26800552212353745`], 
             UndirectedEdge[23, 139] -> 
             RGBColor[
              0.8758733492194162, 0.46815350604938644`, 0.2156599886848298], 
             UndirectedEdge[120, 359] -> 
             RGBColor[
              0.9278258180560774, 0.7515604497524038, 0.26078516294337384`], 
             UndirectedEdge[117, 309] -> 
             RGBColor[
              0.9601943746907483, 0.8676956060479709, 0.42535290414767346`], 
             UndirectedEdge[19, 167] -> 
             RGBColor[
              0.9528410750429238, 0.8422578063863633, 0.32507597612956185`], 
             UndirectedEdge[26, 285] -> 
             RGBColor[
              0.9739760088260462, 0.928162763966965, 0.5407197588993278], 
             UndirectedEdge[166, 169] -> 
             RGBColor[
              0.9738494975373837, 0.9770910264482571, 0.76062268129794], 
             UndirectedEdge[31, 383] -> 
             RGBColor[
              0.9892203890451762, 0.9751678475801385, 0.42385947235221], 
             UndirectedEdge[146, 346] -> 
             RGBColor[
              0.9845984338515216, 0.9638849062532808, 0.5812269988778143], 
             UndirectedEdge[191, 349] -> 
             RGBColor[
              0.9661919817609085, 0.8963278837594688, 0.32989076222251207`], 
             UndirectedEdge[212, 362] -> 
             RGBColor[
              0.9717970738044253, 0.9133667057007235, 0.45420072374492326`], 
             UndirectedEdge[242, 380] -> 
             RGBColor[
              0.9774482655367894, 0.9355898456358398, 0.36689119945847803`], 
             UndirectedEdge[175, 307] -> 
             RGBColor[
              0.991599366483837, 0.9845528873558702, 0.5880491572072802], 
             UndirectedEdge[140, 193] -> 
             RGBColor[
              0.9777010235254038, 0.9364424576818339, 0.3678731165149037], 
             UndirectedEdge[8, 25] -> 
             RGBColor[
              0.9550029012354195, 0.8465440896609302, 0.4548493087503834], 
             UndirectedEdge[8, 269] -> 
             RGBColor[
              0.9422095268942764, 0.839286235314775, 0.5940031078770842], 
             UndirectedEdge[155, 371] -> 
             RGBColor[
              0.9950230454978182, 0.9917631225041492, 0.6996674005194409], 
             UndirectedEdge[55, 161] -> 
             RGBColor[
              0.9566856172665574, 0.9271525873659061, 0.6450764294049233], 
             UndirectedEdge[110, 202] -> 
             RGBColor[
              0.9933676706539174, 0.9915253756193747, 0.7595783913901288], 
             UndirectedEdge[332, 380] -> 
             RGBColor[
              0.9459148812511433, 0.8169909793772374, 0.30808065349948033`], 
             UndirectedEdge[359, 360] -> 
             RGBColor[
              0.9514836533182575, 0.8399206621359012, 0.3081275354741984], 
             UndirectedEdge[128, 350] -> 
             RGBColor[
              0.9698182802250987, 0.9072112583418527, 0.5132368551542876], 
             UndirectedEdge[272, 378] -> 
             RGBColor[
              0.9693757476463123, 0.9040941787821992, 0.43288907090212114`], 
             UndirectedEdge[52, 345] -> 
             RGBColor[
              0.9857860450561071, 0.9883901785957896, 0.8852255481639386], 
             UndirectedEdge[32, 333] -> 
             RGBColor[
              0.9587343577091811, 0.8622815659104046, 0.4020207383896602], 
             UndirectedEdge[85, 168] -> 
             RGBColor[
              0.9757812070418481, 0.9299664658884539, 0.36041499200321203`], 
             UndirectedEdge[23, 354] -> 
             RGBColor[
              0.9480540227565093, 0.828125510742188, 0.29598213324108147`], 
             UndirectedEdge[51, 373] -> 
             RGBColor[
              0.9870216810326486, 0.9860855883567066, 0.6725296794077572], 
             UndirectedEdge[55, 334] -> 
             RGBColor[
              0.9102799951296257, 0.7365447286673368, 0.5935219272773424], 
             UndirectedEdge[66, 267] -> 
             RGBColor[
              0.9871781196338099, 0.9684109281834736, 0.4046898452966319], 
             UndirectedEdge[30, 153] -> 
             RGBColor[
              0.9395493211662957, 0.7790330868118938, 0.4666672928548786], 
             UndirectedEdge[179, 290] -> 
             RGBColor[
              0.974168480582402, 0.9401158204692803, 0.6153223195879173], 
             UndirectedEdge[178, 200] -> 
             RGBColor[
              0.9275815785758179, 0.745942342445275, 0.26887901316385554`], 
             UndirectedEdge[340, 358] -> 
             RGBColor[
              0.993299395823668, 0.9880764101388566, 0.5120587706209462], 
             UndirectedEdge[31, 259] -> 
             RGBColor[
              0.9698260056680026, 0.9092764894585649, 0.3404137389190534], 
             UndirectedEdge[92, 146] -> 
             RGBColor[
              0.9872452157745085, 0.9728131231734649, 0.5915092468457923], 
             UndirectedEdge[3, 373] -> 
             RGBColor[
              0.9834721420218135, 0.9869874484339927, 0.9036058597927188], 
             UndirectedEdge[174, 341] -> 
             RGBColor[
              0.9741853909567251, 0.9242361464225082, 0.37324480412621], 
             UndirectedEdge[248, 260] -> 
             RGBColor[
              0.8496223844858418, 0.34953419610609937`, 0.19386383730077272`],
              UndirectedEdge[41, 325] -> 
             RGBColor[
              0.9929227347210047, 0.9894051754471147, 0.6262102689567529], 
             UndirectedEdge[66, 346] -> 
             RGBColor[
              0.9837611085286182, 0.9568845473733012, 0.3914154024013652], 
             UndirectedEdge[53, 142] -> 
             RGBColor[
              0.9754982956362257, 0.9289792894840642, 0.5167842077031524], 
             UndirectedEdge[38, 44] -> 
             RGBColor[
              0.960972309091475, 0.8732421490862784, 0.5115127932632606], 
             UndirectedEdge[76, 187] -> 
             RGBColor[
              0.9686943680907749, 0.9015702717172838, 0.42183519422984794`], 
             UndirectedEdge[156, 160] -> 
             RGBColor[
              0.9903983875257679, 0.9781643639874734, 0.51152547809749], 
             UndirectedEdge[141, 290] -> 
             RGBColor[
              0.9295287200879879, 0.7528124989477576, 0.27565428445308504`], 
             UndirectedEdge[3, 79] -> 
             RGBColor[
              0.9682243201606642, 0.915866852816742, 0.5852337882971932], 
             UndirectedEdge[301, 382] -> 
             RGBColor[
              0.9623348092892529, 0.8799608496924464, 0.3323838848479443], 
             UndirectedEdge[193, 389] -> 
             RGBColor[
              0.9435803806104783, 0.924139432152896, 0.6657165650087278], 
             UndirectedEdge[189, 291] -> 
             RGBColor[
              0.982119393763561, 0.9498268241036247, 0.5142733527816963], 
             UndirectedEdge[161, 196] -> 
             RGBColor[
              0.9686431176557374, 0.9360704715775466, 0.6248355002616196], 
             UndirectedEdge[83, 161] -> 
             RGBColor[
              0.979908799772157, 0.9426875192381285, 0.5258350830725169], 
             UndirectedEdge[100, 211] -> 
             RGBColor[
              0.9612435328119215, 0.8718018505695546, 0.42935214546292244`], 
             UndirectedEdge[32, 287] -> 
             RGBColor[
              0.9935456332907568, 0.9901612047466178, 0.6521188978958612], 
             UndirectedEdge[156, 181] -> 
             RGBColor[
              0.9110800267874204, 0.6026823313707927, 0.39766061821502124`], 
             UndirectedEdge[126, 176] -> 
             RGBColor[
              0.9678964302742692, 0.9127871704077813, 0.5762611070346992], 
             UndirectedEdge[46, 350] -> 
             RGBColor[
              0.9610975870575413, 0.8726366159312157, 0.5062199807306932], 
             UndirectedEdge[47, 149] -> 
             RGBColor[
              0.9836411241742149, 0.9562552366661843, 0.4100455488437299], 
             UndirectedEdge[57, 108] -> 
             RGBColor[
              0.9661027282027584, 0.890791478010972, 0.44956240232022027`], 
             UndirectedEdge[105, 400] -> 
             RGBColor[
              0.9631439427113351, 0.8796380827729028, 0.4130258826979232], 
             UndirectedEdge[62, 256] -> 
             RGBColor[
              0.9750850414631557, 0.9269203124535853, 0.41704839110695824`], 
             UndirectedEdge[193, 332] -> 
             RGBColor[
              0.9425040225563912, 0.805485352092132, 0.2948301115569858], 
             UndirectedEdge[1, 387] -> 
             RGBColor[
              0.9225607346027592, 0.7265015121988694, 0.2563322863175124], 
             UndirectedEdge[72, 284] -> 
             RGBColor[
              0.9932429369383386, 0.9879556502920062, 0.5059135693767025], 
             UndirectedEdge[127, 394] -> 
             RGBColor[
              0.9436199671915422, 0.8043408796488544, 0.31995768968901006`], 
             UndirectedEdge[110, 385] -> 
             RGBColor[
              0.9937938935714485, 0.9898607963771462, 0.6187056212935329], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.9669341092463776, 0.8999631281033953, 0.32687896794038473`], 
             UndirectedEdge[97, 393] -> 
             RGBColor[
              0.9619625911155749, 0.8837405757168474, 0.5444705402059432], 
             UndirectedEdge[19, 150] -> 
             RGBColor[
              0.9208265385908467, 0.723810639044381, 0.25515337839144436`], 
             UndirectedEdge[272, 342] -> 
             RGBColor[
              0.9796562913735742, 0.9420966606145644, 0.45551666707974714`], 
             UndirectedEdge[96, 187] -> 
             RGBColor[
              0.9757110248315433, 0.9289083757486583, 0.4299839432028863], 
             UndirectedEdge[129, 333] -> 
             RGBColor[
              0.9589394443883542, 0.8627202255797117, 0.4243431577693671], 
             UndirectedEdge[19, 160] -> 
             RGBColor[
              0.9537700272321035, 0.8453913802488127, 0.32868477996662343`], 
             UndirectedEdge[183, 357] -> 
             RGBColor[
              0.9465403675374655, 0.8649422271894576, 0.6040714063678664], 
             UndirectedEdge[197, 217] -> 
             RGBColor[
              0.9842718806455258, 0.9571185238019201, 0.540803225867446], 
             UndirectedEdge[199, 345] -> 
             RGBColor[
              0.9856917112682831, 0.9883511691502567, 0.8867889031561984], 
             UndirectedEdge[44, 346] -> 
             RGBColor[
              0.9855724530240941, 0.9642876882122906, 0.5650849805074717], 
             UndirectedEdge[78, 80] -> 
             RGBColor[
              0.9924837213047188, 0.9847715540671851, 0.5559466935496801], 
             UndirectedEdge[42, 320] -> 
             RGBColor[
              0.9939115267541052, 0.9901456330005934, 0.633924820370735], 
             UndirectedEdge[161, 332] -> 
             RGBColor[
              0.9397450302405561, 0.7961786231686179, 0.2841119474019472], 
             UndirectedEdge[239, 309] -> 
             RGBColor[
              0.9362532506628047, 0.7849724117626382, 0.2675660730360143], 
             UndirectedEdge[8, 377] -> 
             RGBColor[
              0.8943944581898258, 0.6101457635321956, 0.2334266450782172], 
             UndirectedEdge[75, 126] -> 
             RGBColor[
              0.9907019892728864, 0.9901500883008282, 0.783914351742441], 
             UndirectedEdge[54, 310] -> 
             RGBColor[
              0.9700212897287515, 0.9193522719827756, 0.5688726950726234], 
             UndirectedEdge[65, 211] -> 
             RGBColor[
              0.9936085075476984, 0.9887375688605682, 0.5457036741652231], 
             UndirectedEdge[88, 356] -> 
             RGBColor[
              0.9279081825233879, 0.7319956414361481, 0.30946449639703544`], 
             UndirectedEdge[98, 158] -> 
             RGBColor[
              0.9298944112819394, 0.7597617325751178, 0.26244960160902614`], 
             UndirectedEdge[13, 390] -> 
             RGBColor[
              0.9876626193025435, 0.9700104060183307, 0.4095357092404397], 
             UndirectedEdge[241, 242] -> 
             RGBColor[
              0.978211242689618, 0.9381635467278855, 0.3698552216210717], 
             UndirectedEdge[12, 238] -> 
             RGBColor[
              0.9790424186291773, 0.9477945597338688, 0.5779692891979741], 
             UndirectedEdge[175, 343] -> 
             RGBColor[
              0.9902341935279655, 0.9839883532552727, 0.6106736060404311], 
             UndirectedEdge[59, 258] -> 
             RGBColor[
              0.9590531166255714, 0.872186313822363, 0.30247271233594675`], 
             UndirectedEdge[152, 156] -> 
             RGBColor[
              0.9914614052613415, 0.9898902535156552, 0.7296143681488085], 
             UndirectedEdge[39, 258] -> 
             RGBColor[
              0.9675213061521334, 0.9007515055209119, 0.3353700295632318], 
             UndirectedEdge[183, 368] -> 
             RGBColor[
              0.9616543031995557, 0.8734910052338889, 0.42609744791218646`], 
             UndirectedEdge[44, 119] -> 
             RGBColor[
              0.9815863773203559, 0.9842829910026317, 0.8486683138346427], 
             UndirectedEdge[149, 264] -> 
             RGBColor[
              0.9839420675007502, 0.9584631757916053, 0.5565059640548802], 
             UndirectedEdge[120, 241] -> 
             RGBColor[
              0.9528874953685903, 0.8441838217951423, 0.31604109532271907`], 
             UndirectedEdge[116, 304] -> 
             RGBColor[
              0.988991387108599, 0.987357380278929, 0.6606819745302298], 
             UndirectedEdge[82, 256] -> 
             RGBColor[
              0.9315855868440813, 0.766297117635776, 0.2646934455056979], 
             UndirectedEdge[98, 186] -> 
             RGBColor[
              0.9236927081904962, 0.7351740464125909, 0.25745956572896966`], 
             UndirectedEdge[72, 262] -> 
             RGBColor[
              0.9907440423021108, 0.980041208378637, 0.45242105633695207`], 
             UndirectedEdge[147, 241] -> 
             RGBColor[
              0.9558214820543447, 0.8558161013110537, 0.31840184987959597`], 
             UndirectedEdge[13, 205] -> 
             RGBColor[
              0.9879737466633411, 0.9706758759832752, 0.4434000024077569], 
             UndirectedEdge[142, 394] -> 
             RGBColor[
              0.9715072766720134, 0.9155494951844289, 0.34381157958043185`], 
             UndirectedEdge[42, 75] -> 
             RGBColor[
              0.9946833490712337, 0.9917964828937245, 0.7179329164549539], 
             UndirectedEdge[56, 341] -> 
             RGBColor[
              0.9128561240418782, 0.6824074062074975, 0.24823308662900323`], 
             UndirectedEdge[306, 378] -> 
             RGBColor[
              0.9436467594071868, 0.8142852101933762, 0.2735150637196994], 
             UndirectedEdge[27, 295] -> 
             RGBColor[
              0.9745234199168851, 0.9257236545734926, 0.3555287265358992], 
             UndirectedEdge[111, 247] -> 
             RGBColor[
              0.9759296795718301, 0.9678207989764183, 0.6683651846760081], 
             UndirectedEdge[128, 259] -> 
             RGBColor[
              0.9498474321349268, 0.8388688113071682, 0.27850427054493454`], 
             UndirectedEdge[52, 68] -> 
             RGBColor[
              0.9538366231718541, 0.8593612713882285, 0.5762841044441382], 
             UndirectedEdge[241, 359] -> 
             RGBColor[
              0.9536861150702505, 0.8473500827879851, 0.3166836834806885], 
             UndirectedEdge[361, 382] -> 
             RGBColor[
              0.9872133255821801, 0.9685296861140764, 0.4048266137579651], 
             UndirectedEdge[14, 390] -> 
             RGBColor[
              0.9726472653474559, 0.9184055372412736, 0.356175228585597], 
             UndirectedEdge[11, 332] -> 
             RGBColor[
              0.9196472066945379, 0.7191349810645749, 0.2542044602651969], 
             UndirectedEdge[22, 209] -> 
             RGBColor[
              0.955972955568007, 0.8589162781833163, 0.30550558815532414`], 
             UndirectedEdge[33, 156] -> 
             RGBColor[
              0.9887734924119759, 0.9726832112251369, 0.5052130674161028], 
             UndirectedEdge[283, 332] -> 
             RGBColor[
              0.9493165215206898, 0.8284655107495351, 0.32129538360080456`], 
             UndirectedEdge[150, 181] -> 
             RGBColor[
              0.874234547946046, 0.46904854494092946`, 0.21464522140423997`], 
             UndirectedEdge[117, 323] -> 
             RGBColor[
              0.9377123555932405, 0.771986333212896, 0.4069231970174361], 
             UndirectedEdge[199, 223] -> 
             RGBColor[
              0.986613326842289, 0.988732280874548, 0.8715153480302722], 
             UndirectedEdge[128, 306] -> 
             RGBColor[
              0.9441684346686992, 0.8163534787672974, 0.2739348158804045], 
             UndirectedEdge[184, 288] -> 
             RGBColor[
              0.9931635292448593, 0.987785805265003, 0.4972705319889521], 
             UndirectedEdge[145, 182] -> 
             RGBColor[
              0.9580546148658358, 0.8600021526887535, 0.37688432258185206`], 
             UndirectedEdge[284, 397] -> 
             RGBColor[
              0.9767423839877667, 0.9326938249591263, 0.4079337621897307], 
             UndirectedEdge[61, 148] -> 
             RGBColor[
              0.8862049053709767, 0.49689203011584315`, 0.22347060802503127`],
              UndirectedEdge[34, 159] -> 
             RGBColor[
              0.9879706518537616, 0.9892935696484537, 0.8490209599456401], 
             UndirectedEdge[276, 382] -> 
             RGBColor[
              0.9827527145598407, 0.9534829977344512, 0.3874979822518868], 
             UndirectedEdge[59, 164] -> 
             RGBColor[
              0.9369172009127344, 0.7844247843776, 0.2846616349566755], 
             UndirectedEdge[80, 377] -> 
             RGBColor[
              0.9342122469562442, 0.7549319784307919, 0.45621958990318107`], 
             UndirectedEdge[180, 370] -> 
             RGBColor[
              0.948137851024207, 0.8207241268887547, 0.35275350557667795`], 
             UndirectedEdge[98, 374] -> 
             RGBColor[
              0.9359269098345776, 0.7836785791253521, 0.267303491545419], 
             UndirectedEdge[139, 350] -> 
             RGBColor[
              0.9088786097035699, 0.5881730547657615, 0.46088036746336236`], 
             UndirectedEdge[36, 276] -> 
             RGBColor[
              0.9815716444149174, 0.9494989708071672, 0.3829097477652418], 
             UndirectedEdge[53, 281] -> 
             RGBColor[
              0.978260193203233, 0.9382958185019677, 0.5275136582103845], 
             UndirectedEdge[73, 183] -> 
             RGBColor[
              0.9343561704518846, 0.7774511208908452, 0.26603963776811224`], 
             UndirectedEdge[101, 115] -> 
             RGBColor[
              0.9845990757902172, 0.9622307109699644, 0.569780789305314], 
             UndirectedEdge[283, 366] -> 
             RGBColor[
              0.9248878583748887, 0.7205308804538877, 0.3010661894386196], 
             UndirectedEdge[22, 141] -> 
             RGBColor[
              0.9322638558387895, 0.7620387540756257, 0.2862797703579026], 
             UndirectedEdge[197, 314] -> 
             RGBColor[
              0.9835657863377323, 0.9554764350537179, 0.45436697418172395`], 
             UndirectedEdge[13, 14] -> 
             RGBColor[
              0.9677504116705442, 0.9019221532668433, 0.3341882025231554], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.9514888527401648, 0.8340222687728078, 0.368573092605255], 
             UndirectedEdge[323, 395] -> 
             RGBColor[
              0.9271896362037233, 0.7374304065473695, 0.28614109650048686`], 
             UndirectedEdge[93, 131] -> 
             RGBColor[
              0.9495283532567176, 0.9595397875585835, 0.8734493170387845], 
             UndirectedEdge[52, 105] -> 
             RGBColor[
              0.989443569124931, 0.9885839846105884, 0.72875721659442], 
             UndirectedEdge[178, 330] -> 
             RGBColor[
              0.97292979127334, 0.9347190984359777, 0.6063658074406334], 
             UndirectedEdge[92, 98] -> 
             RGBColor[
              0.9585238639864798, 0.865216746877577, 0.3274164503759438], 
             UndirectedEdge[37, 323] -> 
             RGBColor[
              0.9344167224068554, 0.7717074161359556, 0.5403293233895081], 
             UndirectedEdge[279, 370] -> 
             RGBColor[
              0.90526611210139, 0.6618846289904854, 0.2426209840187299], 
             UndirectedEdge[150, 160] -> 
             RGBColor[
              0.9535529086843936, 0.8445305775576102, 0.3285100812867088], 
             UndirectedEdge[188, 273] -> 
             RGBColor[
              0.9693359167349698, 0.9082249882572224, 0.33537625625193485`], 
             UndirectedEdge[179, 386] -> 
             RGBColor[
              0.9793734269903568, 0.9576733268828459, 0.6355425535111682], 
             UndirectedEdge[141, 179] -> 
             RGBColor[
              0.9388725029072581, 0.7999207320364111, 0.5731255816224384], 
             UndirectedEdge[117, 388] -> 
             RGBColor[
              0.9684997495707499, 0.9006236498450644, 0.4320356037283274], 
             UndirectedEdge[198, 214] -> 
             RGBColor[
              0.9778571194024398, 0.9365257704872256, 0.5231112237520501], 
             UndirectedEdge[150, 238] -> 
             RGBColor[
              0.9445923484913925, 0.8143045039870322, 0.29369999699670635`], 
             UndirectedEdge[331, 392] -> 
             RGBColor[
              0.9907998163080489, 0.9884926534869312, 0.6588745121597825], 
             UndirectedEdge[323, 365] -> 
             RGBColor[
              0.9193609353388008, 0.7110223602636092, 0.255728071966371], 
             UndirectedEdge[6, 71] -> 
             RGBColor[
              0.9926367088842765, 0.9852854762707342, 0.5567230617538138], 
             UndirectedEdge[132, 249] -> 
             RGBColor[
              0.9793581170051269, 0.9454481477543132, 0.555616685421002], 
             UndirectedEdge[348, 378] -> 
             RGBColor[
              0.9561238701250259, 0.8603338588519613, 0.30136032494295717`], 
             UndirectedEdge[174, 198] -> 
             RGBColor[
              0.9770721245237921, 0.934105301936853, 0.383774232634172], 
             UndirectedEdge[72, 236] -> 
             RGBColor[
              0.9927221343373676, 0.9894179331548294, 0.6364919246090117], 
             UndirectedEdge[9, 100] -> 
             RGBColor[
              0.9341394377756185, 0.7765918480513329, 0.2658652495694187], 
             UndirectedEdge[51, 298] -> 
             RGBColor[
              0.9422024996532126, 0.7941649360875861, 0.33017967020777805`], 
             UndirectedEdge[23, 128] -> 
             RGBColor[
              0.9368130197409452, 0.7871917096254775, 0.2680164763757551], 
             UndirectedEdge[215, 353] -> 
             RGBColor[
              0.9425427507910848, 0.7941494732535097, 0.4861389551114533], 
             UndirectedEdge[80, 96] -> 
             RGBColor[
              0.9762903365784141, 0.9301474649978128, 0.4930384517520971], 
             UndirectedEdge[78, 388] -> 
             RGBColor[
              0.9664744601934565, 0.8947315499022166, 0.344264414203857], 
             UndirectedEdge[312, 380] -> 
             RGBColor[
              0.9810077996790055, 0.961402948200423, 0.6338409149009887], 
             UndirectedEdge[57, 325] -> 
             RGBColor[
              0.9653138001190151, 0.8912384459332856, 0.5188411839823452], 
             UndirectedEdge[308, 374] -> 
             RGBColor[
              0.9645346498354062, 0.886715852233206, 0.3443961819631915], 
             UndirectedEdge[76, 365] -> 
             RGBColor[
              0.9504388112231932, 0.8408113408592108, 0.2810742072380269], 
             UndirectedEdge[182, 187] -> 
             RGBColor[
              0.9934970145176727, 0.9884990965430179, 0.5335683459021573], 
             UndirectedEdge[74, 286] -> 
             RGBColor[
              0.9809766171377817, 0.9485840326860572, 0.5458429522569447], 
             UndirectedEdge[137, 164] -> 
             RGBColor[
              0.9205558569428163, 0.7227374765092527, 0.2549355815837242], 
             UndirectedEdge[149, 258] -> 
             RGBColor[
              0.9629025724364335, 0.8851714321676076, 0.3174271212524131], 
             UndirectedEdge[147, 331] -> 
             RGBColor[
              0.9607486758460388, 0.8806067352719213, 0.5517094943400658], 
             UndirectedEdge[42, 367] -> 
             RGBColor[
              0.9884263524651137, 0.972209998002795, 0.5643899639440823], 
             UndirectedEdge[16, 365] -> 
             RGBColor[
              0.9734824322819078, 0.9222121588451941, 0.3514846861480322], 
             UndirectedEdge[113, 183] -> 
             RGBColor[
              0.8879670157794016, 0.5584468693195557, 0.22713140370416418`], 
             UndirectedEdge[16, 323] -> 
             RGBColor[
              0.9355206458075884, 0.7655328581552846, 0.31850549563234976`], 
             UndirectedEdge[340, 343] -> 
             RGBColor[
              0.9919408051717291, 0.9892416837488662, 0.6601150362621715], 
             UndirectedEdge[323, 362] -> 
             RGBColor[
              0.9153032658254416, 0.6953371442488842, 0.2503690766329554], 
             UndirectedEdge[334, 364] -> 
             RGBColor[
              0.9130221358212316, 0.7385898127052932, 0.5888801983512877], 
             UndirectedEdge[94, 324] -> 
             RGBColor[
              0.9514856753241867, 0.8340154726013167, 0.36822725048478], 
             UndirectedEdge[135, 350] -> 
             RGBColor[
              0.9735405579533396, 0.9219688491588051, 0.516231887187518], 
             UndirectedEdge[31, 215] -> 
             RGBColor[
              0.9381847779369468, 0.7799175249096026, 0.31475209857465747`], 
             UndirectedEdge[3, 21] -> 
             RGBColor[
              0.9895447734262262, 0.988539617589302, 0.7208128900017194], 
             UndirectedEdge[127, 193] -> 
             RGBColor[
              0.9357384334267144, 0.7777546155879584, 0.28933941931541773`], 
             UndirectedEdge[50, 230] -> 
             RGBColor[
              0.9855046955577529, 0.9849846267650474, 0.6775099430166729], 
             UndirectedEdge[169, 382] -> 
             RGBColor[
              0.9890746019591417, 0.9740536494402443, 0.47621956688070866`], 
             UndirectedEdge[12, 19] -> 
             RGBColor[
              0.9552766087286313, 0.8573006947912176, 0.5394226705927121], 
             UndirectedEdge[133, 296] -> 
             RGBColor[
              0.9741643705873573, 0.9287131205200321, 0.5408637714678335], 
             UndirectedEdge[214, 332] -> 
             RGBColor[
              0.9545152326408878, 0.8455587488324761, 0.49612309883964983`], 
             UndirectedEdge[76, 395] -> 
             RGBColor[
              0.9582675120881157, 0.8672193871429712, 0.31148723177214277`], 
             UndirectedEdge[299, 370] -> 
             RGBColor[
              0.9324827217174058, 0.7681369071239064, 0.27312640503815283`], 
             UndirectedEdge[170, 235] -> 
             RGBColor[
              0.9554286015530076, 0.859514413509717, 0.5474288376856993], 
             UndirectedEdge[46, 400] -> 
             RGBColor[
              0.9304297991484813, 0.7618843670585258, 0.26288038725361407`], 
             UndirectedEdge[65, 329] -> 
             RGBColor[
              0.9884743836153557, 0.9875854888994758, 0.7031163280600063], 
             UndirectedEdge[81, 267] -> 
             RGBColor[
              0.9624519094257766, 0.8803345999470485, 0.3329494983871631], 
             UndirectedEdge[104, 182] -> 
             RGBColor[
              0.9931314544071137, 0.9877172004303288, 0.4937793838432991], 
             UndirectedEdge[23, 306] -> 
             RGBColor[
              0.9352149221128316, 0.7808557850644728, 0.26673060951200234`], 
             UndirectedEdge[209, 286] -> 
             RGBColor[
              0.9551096064133247, 0.8560039987605516, 0.3021516397191911], 
             UndirectedEdge[150, 167] -> 
             RGBColor[
              0.9526239564952139, 0.8413970036951609, 0.3249012774496472], 
             UndirectedEdge[4, 288] -> 
             RGBColor[
              0.9764858264470282, 0.9786761072023815, 0.7259222795648842], 
             UndirectedEdge[171, 272] -> 
             RGBColor[
              0.9912066463932729, 0.9810587202483363, 0.5003876152297541], 
             UndirectedEdge[78, 182] -> 
             RGBColor[
              0.9915675885272373, 0.9828120386913841, 0.456231294436931], 
             UndirectedEdge[143, 374] -> 
             RGBColor[
              0.9660485547554426, 0.8908358762955757, 0.43418204434687413`], 
             UndirectedEdge[55, 262] -> 
             RGBColor[
              0.968414315321632, 0.9667162399349369, 0.6906402065701092], 
             UndirectedEdge[165, 190] -> 
             RGBColor[
              0.99393651611006, 0.9894391460087066, 0.5814053819440734], 
             UndirectedEdge[2, 149] -> 
             RGBColor[
              0.9837542900502079, 0.956497287032108, 0.42236295606673224`], 
             UndirectedEdge[39, 47] -> 
             RGBColor[
              0.9882598578899147, 0.9718353100194885, 0.4279884571545486], 
             UndirectedEdge[230, 300] -> 
             RGBColor[
              0.9861387808565356, 0.9863408711032857, 0.7465262146683072], 
             UndirectedEdge[40, 48] -> 
             RGBColor[
              0.9265262829540515, 0.8607949051686403, 0.6297599169923271], 
             UndirectedEdge[25, 208] -> 
             RGBColor[
              0.9516339709258619, 0.8331874036130094, 0.45213858834435533`], 
             UndirectedEdge[32, 52] -> 
             RGBColor[
              0.989374547063055, 0.9884363533994366, 0.7212445911140117], 
             UndirectedEdge[161, 366] -> 
             RGBColor[
              0.9153163670947551, 0.6882439928729704, 0.2638827532397622], 
             UndirectedEdge[190, 318] -> 
             RGBColor[
              0.9608460500821805, 0.8700284072476532, 0.44072267637650486`], 
             UndirectedEdge[179, 245] -> 
             RGBColor[
              0.9886395051809997, 0.9881500402608282, 0.7378603372233465], 
             UndirectedEdge[37, 182] -> 
             RGBColor[
              0.9902972447181456, 0.9884252215572915, 0.6774086103334733], 
             UndirectedEdge[12, 206] -> 
             RGBColor[
              0.9615341148553582, 0.8821096213933846, 0.5444576069048233], 
             UndirectedEdge[18, 218] -> 
             RGBColor[
              0.9828815071740835, 0.9608073092194234, 0.593316128442031], 
             UndirectedEdge[92, 119] -> 
             RGBColor[
              0.9765563527752197, 0.9660224865741227, 0.6624947715323308], 
             UndirectedEdge[215, 400] -> 
             RGBColor[
              0.9115901644230971, 0.6832794528990667, 0.24751920913358993`], 
             UndirectedEdge[71, 292] -> 
             RGBColor[
              0.98683154181299, 0.9829977077388407, 0.664869174600086], 
             UndirectedEdge[158, 346] -> 
             RGBColor[
              0.9519129757744174, 0.8405721694813223, 0.313944589438242], 
             UndirectedEdge[92, 151] -> 
             RGBColor[
              0.9885946951708117, 0.9733711675838749, 0.5691448809083214], 
             UndirectedEdge[104, 170] -> 
             RGBColor[
              0.9576788692335145, 0.8585649173556307, 0.37347704146920213`], 
             UndirectedEdge[82, 316] -> 
             RGBColor[
              0.9502188321886451, 0.8283491807795583, 0.4052975235382032], 
             UndirectedEdge[287, 353] -> 
             RGBColor[
              0.9939577513445501, 0.9917693891493333, 0.7497992272664695], 
             UndirectedEdge[368, 372] -> 
             RGBColor[
              0.9511272313191304, 0.9596400063374093, 0.7906702222046414], 
             UndirectedEdge[9, 203] -> 
             RGBColor[
              0.9324078859821201, 0.769726822195542, 0.26447200235162555`], 
             UndirectedEdge[17, 384] -> 
             RGBColor[
              0.9380046230713485, 0.8311008447495307, 0.5972033460107549], 
             UndirectedEdge[82, 310] -> 
             RGBColor[
              0.9295959194881342, 0.7585783120791743, 0.2622094281052276], 
             UndirectedEdge[129, 287] -> 
             RGBColor[
              0.9937507199699298, 0.9905998644159248, 0.6744413172755681], 
             UndirectedEdge[81, 363] -> 
             RGBColor[
              0.9653517993483967, 0.8954345846380247, 0.5386679982306171], 
             UndirectedEdge[64, 356] -> 
             RGBColor[
              0.9843212181702072, 0.9587739287143788, 0.39359132259110785`], 
             UndirectedEdge[245, 352] -> 
             RGBColor[
              0.9938434371629606, 0.9892400595525865, 0.5712743129689941], 
             UndirectedEdge[87, 232] -> 
             RGBColor[
              0.9597789497695454, 0.8758576445030513, 0.29892342257970783`], 
             UndirectedEdge[88, 255] -> 
             RGBColor[
              0.9137618015510394, 0.6842765766882073, 0.2545084776393489], 
             UndirectedEdge[154, 392] -> 
             RGBColor[
              0.9895542594718674, 0.9879775837258196, 0.6795166123330743], 
             UndirectedEdge[22, 45] -> 
             RGBColor[
              0.982446438097357, 0.9511569458660034, 0.49624784264472843`], 
             UndirectedEdge[116, 141] -> 
             RGBColor[
              0.9433905424828186, 0.7995436968252388, 0.3318844017686672], 
             UndirectedEdge[97, 224] -> 
             RGBColor[
              0.9773513597602065, 0.9420337035866444, 0.5710091979494385], 
             UndirectedEdge[66, 151] -> 
             RGBColor[
              0.9918133752204721, 0.9842285311733945, 0.581648845104527], 
             UndirectedEdge[165, 221] -> 
             RGBColor[
              0.9613160010544521, 0.8725559331036872, 0.40178949016796617`], 
             UndirectedEdge[101, 332] -> 
             RGBColor[
              0.9456927911169167, 0.8162418172052477, 0.3072178752662126], 
             UndirectedEdge[58, 396] -> 
             RGBColor[
              0.9303212634375941, 0.7544591950153012, 0.28141570559507967`], 
             UndirectedEdge[35, 387] -> 
             RGBColor[
              0.9225776857575843, 0.7265687178791128, 0.25634592561457936`], 
             UndirectedEdge[198, 266] -> 
             RGBColor[
              0.9775493683178931, 0.9351260781556858, 0.4357192744147701], 
             UndirectedEdge[188, 264] -> 
             RGBColor[
              0.9750968771617767, 0.9286262718287919, 0.5221440698620057], 
             UndirectedEdge[119, 151] -> 
             RGBColor[
              0.9819618375440866, 0.9844382534540319, 0.8424459662675143], 
             UndirectedEdge[247, 400] -> 
             RGBColor[
              0.9497399831063861, 0.8725486072491989, 0.6027053215058282], 
             UndirectedEdge[305, 361] -> 
             RGBColor[
              0.9911712297836788, 0.984520140874054, 0.5961418799415693], 
             UndirectedEdge[138, 210] -> 
             RGBColor[
              0.9786827961077587, 0.9509930311529736, 0.6070647800818604], 
             UndirectedEdge[197, 231] -> 
             RGBColor[
              0.9341855629378537, 0.7689436620012625, 0.292641281255397], 
             UndirectedEdge[225, 261] -> 
             RGBColor[
              0.932375778609166, 0.758238938786244, 0.29762866685026657`], 
             UndirectedEdge[83, 286] -> 
             RGBColor[
              0.9817518672218762, 0.9489046185188487, 0.5329950520805934], 
             UndirectedEdge[19, 238] -> 
             RGBColor[
              0.9448094670391024, 0.8151653066782346, 0.29387469567662106`], 
             UndirectedEdge[62, 117] -> 
             RGBColor[
              0.9938296243997466, 0.9892105154487563, 0.5697708789356386], 
             UndirectedEdge[65, 167] -> 
             RGBColor[
              0.9888857699052043, 0.9737823887849208, 0.44438829401977986`], 
             UndirectedEdge[268, 371] -> 
             RGBColor[
              0.5870546002886354, 0.6487487695630259, 0.8252457243632898], 
             UndirectedEdge[172, 192] -> 
             RGBColor[
              0.953951113956442, 0.9635344496035274, 0.8941964972665916], 
             UndirectedEdge[52, 353] -> 
             RGBColor[
              0.9897866651168483, 0.9900445378021521, 0.8189249204846201], 
             UndirectedEdge[126, 298] -> 
             RGBColor[
              0.9391541258275071, 0.795274040848281, 0.5529502465012178], 
             UndirectedEdge[146, 306] -> 
             RGBColor[
              0.966935779093829, 0.9003441999246284, 0.5332368782675494], 
             UndirectedEdge[21, 132] -> 
             RGBColor[
              0.9927341181897149, 0.9898584936114263, 0.667957193511044], 
             UndirectedEdge[89, 162] -> 
             RGBColor[
              0.9732654436196908, 0.920924450724301, 0.5162372759449901], 
             UndirectedEdge[9, 18] -> 
             RGBColor[
              0.9580857676200558, 0.8655183450713536, 0.3164473827150787], 
             UndirectedEdge[255, 360] -> 
             RGBColor[
              0.9669646060128808, 0.900226000381381, 0.326164161881074], 
             UndirectedEdge[124, 152] -> 
             RGBColor[
              0.9894723892551585, 0.9842901194340656, 0.627561916421778], 
             UndirectedEdge[88, 389] -> 
             RGBColor[
              0.8923489502442246, 0.7148399161847894, 0.6017192968656009], 
             UndirectedEdge[12, 167] -> 
             RGBColor[
              0.9870740266329987, 0.9748870594419975, 0.6091705696509149], 
             UndirectedEdge[32, 303] -> 
             RGBColor[
              0.9908778416107469, 0.980204428316576, 0.4774401929221642], 
             UndirectedEdge[49, 261] -> 
             RGBColor[
              0.9329050904361332, 0.7600244318669316, 0.29968494334588297`], 
             UndirectedEdge[283, 360] -> 
             RGBColor[
              0.9791839937474882, 0.9414448644588918, 0.3736341757922742], 
             UndirectedEdge[282, 305] -> 
             RGBColor[
              0.9896790399192588, 0.9794866340785237, 0.5903450040947088], 
             UndirectedEdge[32, 385] -> 
             RGBColor[
              0.9933817755176553, 0.9882526119744307, 0.5210252919229246], 
             UndirectedEdge[167, 216] -> 
             RGBColor[
              0.9894272769752099, 0.9749406176529001, 0.5033279967956448], 
             UndirectedEdge[252, 318] -> 
             RGBColor[
              0.9579218098302924, 0.8612735421842048, 0.3350370550571897], 
             UndirectedEdge[2, 217] -> 
             RGBColor[
              0.9941112026352672, 0.9899446072435256, 0.6100011759639741], 
             UndirectedEdge[305, 329] -> 
             RGBColor[
              0.9880775587372512, 0.9892752646742573, 0.8444497442094603], 
             UndirectedEdge[87, 373] -> 
             RGBColor[
              0.9727704402240995, 0.9380326379710213, 0.6154799968625817], 
             UndirectedEdge[20, 241] -> 
             RGBColor[
              0.9695755271624411, 0.9090332504922867, 0.33630709751602805`], 
             UndirectedEdge[59, 210] -> 
             RGBColor[
              0.9687767833864338, 0.9063389001818571, 0.3332041287763455], 
             UndirectedEdge[290, 304] -> 
             RGBColor[
              0.9751295647137683, 0.9406261824014478, 0.6044518572146477], 
             UndirectedEdge[115, 312] -> 
             RGBColor[
              0.9886071275263432, 0.9895567686957448, 0.838472910904724], 
             UndirectedEdge[214, 389] -> 
             RGBColor[
              0.9555915906949749, 0.9642128288932399, 0.8670095522913919], 
             UndirectedEdge[144, 276] -> 
             RGBColor[
              0.9721976223275702, 0.9178781931814901, 0.3464934420914318], 
             UndirectedEdge[196, 286] -> 
             RGBColor[
              0.9704861851054567, 0.9422875708582668, 0.6319954692696961], 
             UndirectedEdge[124, 181] -> 
             RGBColor[
              0.9090910107812374, 0.5970821972892031, 0.2956081664879908], 
             UndirectedEdge[216, 341] -> 
             RGBColor[
              0.9748671459086398, 0.9256943513286545, 0.4474496233382579], 
             UndirectedEdge[294, 340] -> 
             RGBColor[
              0.9901052876841704, 0.9884826500971129, 0.6905343111980057], 
             UndirectedEdge[104, 235] -> 
             RGBColor[
              0.9908524476466586, 0.9886052265983727, 0.6646031085644762], 
             UndirectedEdge[125, 318] -> 
             RGBColor[
              0.9580520403561997, 0.8697198447982888, 0.5485824222543902], 
             UndirectedEdge[109, 232] -> 
             RGBColor[
              0.9519909083098113, 0.8473669800694922, 0.28022896178909895`], 
             UndirectedEdge[182, 388] -> 
             RGBColor[
              0.9680670651532812, 0.8996981816272038, 0.384940575105545], 
             UndirectedEdge[97, 382] -> 
             RGBColor[
              0.9869856701387965, 0.9745324947372807, 0.6084366744834075], 
             UndirectedEdge[140, 147] -> 
             RGBColor[
              0.9589485490445657, 0.8663644325393149, 0.33054991463955413`], 
             UndirectedEdge[59, 300] -> 
             RGBColor[
              0.9802817042563644, 0.9443182555458627, 0.4484285227306025], 
             UndirectedEdge[205, 373] -> 
             RGBColor[
              0.9873449785825896, 0.9867770891256342, 0.7077186225576431], 
             UndirectedEdge[215, 259] -> 
             RGBColor[
              0.9222871042419852, 0.7256892547370721, 0.25612621800131596`], 
             UndirectedEdge[136, 300] -> 
             RGBColor[
              0.985618480926596, 0.9859528322674498, 0.7474069467337396], 
             UndirectedEdge[152, 245] -> 
             RGBColor[
              0.9911945898785623, 0.989319562391064, 0.7005731603269736], 
             UndirectedEdge[44, 128] -> 
             RGBColor[
              0.969507895894515, 0.9070829064446428, 0.5183807267609595], 
             UndirectedEdge[241, 392] -> 
             RGBColor[
              0.9858726225163548, 0.9637020195260635, 0.42556686769931285`], 
             UndirectedEdge[240, 342] -> 
             RGBColor[
              0.9794653374414937, 0.9416882294622482, 0.4347325100038403], 
             UndirectedEdge[123, 214] -> 
             RGBColor[
              0.9897562482679365, 0.9766643261988676, 0.569337092432568], 
             UndirectedEdge[125, 274] -> 
             RGBColor[
              0.9610415022731256, 0.8815720651197705, 0.5509878134844388], 
             UndirectedEdge[298, 373] -> 
             RGBColor[
              0.9366890480846928, 0.7938087960594978, 0.5738359142777911], 
             UndirectedEdge[119, 350] -> 
             RGBColor[
              0.9818967616509398, 0.9844113428998416, 0.8435244422279708], 
             UndirectedEdge[22, 179] -> 
             RGBColor[
              0.9769036163332037, 0.9493420755971483, 0.6259478054927348], 
             UndirectedEdge[1, 183] -> 
             RGBColor[
              0.942356474408108, 0.8091696601340166, 0.27247687012255917`], 
             UndirectedEdge[112, 260] -> 
             RGBColor[
              0.8934489072957992, 0.5272122547493311, 0.2464503812912785], 
             UndirectedEdge[183, 270] -> 
             RGBColor[
              0.9562652216178122, 0.8721950074395932, 0.5876097650580001], 
             UndirectedEdge[152, 181] -> 
             RGBColor[
              0.9082410543228765, 0.6023551756735428, 0.5062655130307376], 
             UndirectedEdge[169, 276] -> 
             RGBColor[
              0.9874037278150712, 0.968417398612389, 0.46972853634910094`], 
             UndirectedEdge[349, 355] -> 
             RGBColor[
              0.951122072652191, 0.8439223362093478, 0.27952987622478365`], 
             UndirectedEdge[171, 240] -> 
             RGBColor[
              0.9910156924611924, 0.98065028909602, 0.4796034581538472], 
             UndirectedEdge[114, 132] -> 
             RGBColor[
              0.990685565364477, 0.9904162561552292, 0.8040278171021429], 
             UndirectedEdge[17, 222] -> 
             RGBColor[
              0.9474977911779225, 0.8687380928813548, 0.6048417719025994], 
             UndirectedEdge[46, 259] -> 
             RGBColor[
              0.9411267389673694, 0.8042941688965312, 0.2714873961213401], 
             UndirectedEdge[13, 79] -> 
             RGBColor[
              0.966889175683731, 0.8985076395690086, 0.33349523183235863`], 
             UndirectedEdge[146, 311] -> 
             RGBColor[
              0.9922600606082357, 0.9910673504012055, 0.7779343562499867], 
             UndirectedEdge[44, 275] -> 
             RGBColor[
              0.9564254126004486, 0.8552152196627939, 0.5078542536172027], 
             UndirectedEdge[193, 195] -> 
             RGBColor[0.95738916465738, 0.86449998034299, 0.3068070462906327],
              UndirectedEdge[86, 297] -> 
             RGBColor[
              0.9349322273890053, 0.7599336461436919, 0.378915979663476], 
             UndirectedEdge[197, 392] -> 
             RGBColor[
              0.9832060103955739, 0.9547069106923687, 0.41520758315752404`], 
             UndirectedEdge[217, 392] -> 
             RGBColor[
              0.9940633228998981, 0.9898421973309547, 0.6047897622485139], 
             UndirectedEdge[101, 193] -> 
             RGBColor[
              0.9735888892481275, 0.9225712631895371, 0.35189825135908404`], 
             UndirectedEdge[216, 340] -> 
             RGBColor[
              0.9937674189065039, 0.9890774641886503, 0.5630001948839753], 
             UndirectedEdge[125, 190] -> 
             RGBColor[
              0.9915063679999048, 0.9899088467635407, 0.7288692192109776], 
             UndirectedEdge[99, 276] -> 
             RGBColor[
              0.9762723345451916, 0.9316231542794532, 0.3623229296120548], 
             UndirectedEdge[27, 63] -> 
             RGBColor[
              0.9772961942078093, 0.9417750745705724, 0.5702934780721556], 
             UndirectedEdge[184, 226] -> 
             RGBColor[
              0.9936162603352099, 0.9887541512891285, 0.5465475172412018], 
             UndirectedEdge[107, 211] -> 
             RGBColor[
              0.9920798116621117, 0.9899592868859978, 0.7057951220969291], 
             UndirectedEdge[216, 294] -> 
             RGBColor[
              0.9905539297807954, 0.9894422501771196, 0.7393662347175551], 
             UndirectedEdge[68, 284] -> 
             RGBColor[
              0.9579384313098942, 0.8593798263426278, 0.38635922011733775`], 
             UndirectedEdge[89, 359] -> 
             RGBColor[
              0.9406556972478841, 0.8024266454441201, 0.27110838489707206`], 
             UndirectedEdge[23, 267] -> 
             RGBColor[
              0.9562945879757158, 0.8559228722032977, 0.3279951730175339], 
             UndirectedEdge[140, 242] -> 
             RGBColor[
              0.9813383096798391, 0.9487118779561468, 0.38200328638102987`], 
             UndirectedEdge[64, 214] -> 
             RGBColor[
              0.9875929360526639, 0.9693669661268897, 0.5609330329834668], 
             UndirectedEdge[296, 367] -> 
             RGBColor[
              0.9697479257884054, 0.909614791538787, 0.336976833623151], 
             UndirectedEdge[275, 346] -> 
             RGBColor[
              0.9487486061323254, 0.8280264983141008, 0.3113984633469127], 
             UndirectedEdge[301, 305] -> 
             RGBColor[
              0.9662927134907515, 0.8959513044524239, 0.5236991510315485], 
             UndirectedEdge[81, 119] -> 
             RGBColor[
              0.955048822616847, 0.8888035219272172, 0.6032583888190675], 
             UndirectedEdge[327, 355] -> 
             RGBColor[
              0.9728177883655751, 0.9168666475986877, 0.48738175212158785`], 
             UndirectedEdge[317, 344] -> 
             RGBColor[
              0.9896923313290245, 0.9900055283566191, 0.8204882754768799], 
             UndirectedEdge[184, 190] -> 
             RGBColor[
              0.993724465082013, 0.9889855903013621, 0.5583249361684223], 
             UndirectedEdge[10, 303] -> 
             RGBColor[
              0.9636798074896504, 0.9629235092748714, 0.6980988636424084], 
             UndirectedEdge[149, 268] -> 
             RGBColor[
              0.5766711839898656, 0.6153765850088355, 0.6443049825819761], 
             UndirectedEdge[38, 267] -> 
             RGBColor[
              0.9567125137285434, 0.8575798085477577, 0.3283314458882372], 
             UndirectedEdge[253, 366] -> 
             RGBColor[
              0.9104207044377659, 0.671471852874117, 0.2462072815949035], 
             UndirectedEdge[165, 355] -> 
             RGBColor[
              0.9721112147312152, 0.9153553580403446, 0.41047557248852223`], 
             UndirectedEdge[339, 340] -> 
             RGBColor[
              0.993240507940117, 0.9879504549104196, 0.5056491879103213], 
             UndirectedEdge[185, 318] -> 
             RGBColor[
              0.9601265728757857, 0.8684895182534791, 0.3624120225590726], 
             UndirectedEdge[36, 70] -> 
             RGBColor[
              0.969853682078204, 0.909971532337035, 0.33738767683861864`], 
             UndirectedEdge[69, 131] -> 
             RGBColor[
              0.9753387214989222, 0.9292768144773953, 0.521941352431423], 
             UndirectedEdge[283, 312] -> 
             RGBColor[
              0.9844094399485519, 0.9728774795727206, 0.647055645002313], 
             UndirectedEdge[75, 330] -> 
             RGBColor[
              0.9896887230665998, 0.9897310766847749, 0.8007067950294935], 
             UndirectedEdge[169, 222] -> 
             RGBColor[
              0.9624657347018495, 0.8769746085043242, 0.41097747016687713`], 
             UndirectedEdge[90, 246] -> 
             RGBColor[
              0.9554883678798813, 0.8486392071623472, 0.4931005032639749], 
             UndirectedEdge[62, 362] -> 
             RGBColor[
              0.9714205346319478, 0.9125613264847443, 0.4132167585511578], 
             UndirectedEdge[158, 374] -> 
             RGBColor[
              0.9319628035455021, 0.7679622186492814, 0.2641138785756951], 
             UndirectedEdge[82, 172] -> 
             RGBColor[
              0.9116977088863498, 0.8020045503195858, 0.6178284982260855], 
             UndirectedEdge[306, 346] -> 
             RGBColor[
              0.9602329917982783, 0.8735582605349451, 0.3206390696269167], 
             UndirectedEdge[53, 188] -> 
             RGBColor[
              0.9754351067237329, 0.9287661384447641, 0.5165387307103431], 
             UndirectedEdge[84, 190] -> 
             RGBColor[
              0.9505190399948511, 0.8290852535235025, 0.4324133216541578], 
             UndirectedEdge[78, 96] -> 
             RGBColor[
              0.9737815988411078, 0.9232213178970243, 0.35264689173765995`], 
             UndirectedEdge[46, 199] -> 
             RGBColor[
              0.9566350917742533, 0.8707912594506784, 0.5801750761423707], 
             UndirectedEdge[159, 265] -> 
             RGBColor[
              0.9899914325145509, 0.9885967539724698, 0.7041377003846816], 
             UndirectedEdge[332, 356] -> 
             RGBColor[
              0.951243514758431, 0.8349657114199651, 0.32878138844729093`], 
             UndirectedEdge[199, 222] -> 
             RGBColor[
              0.9580754458880678, 0.8765017835423974, 0.5813340188718022], 
             UndirectedEdge[114, 300] -> 
             RGBColor[
              0.9917016693886002, 0.9895984447456931, 0.6971990646040774], 
             UndirectedEdge[139, 213] -> 
             RGBColor[
              0.8815532559876078, 0.5694017228030945, 0.5791388613137824], 
             UndirectedEdge[106, 369] -> 
             RGBColor[
              0.967112961661565, 0.9738699263900236, 0.8902382783064737], 
             UndirectedEdge[109, 114] -> 
             RGBColor[
              0.9690064773435403, 0.9116519052365746, 0.5500631898720723], 
             UndirectedEdge[58, 245] -> 
             RGBColor[
              0.9431203348960728, 0.7968535242719617, 0.39745850100300384`], 
             UndirectedEdge[151, 317] -> 
             RGBColor[
              0.9942199025054593, 0.9918777953913469, 0.7454547041047458], 
             UndirectedEdge[99, 218] -> 
             RGBColor[
              0.9804650429711708, 0.9526560080502222, 0.5839286213246894], 
             UndirectedEdge[55, 57] -> 
             RGBColor[
              0.9431544181484697, 0.8761434229207348, 0.6204526024213717], 
             UndirectedEdge[247, 287] -> 
             RGBColor[
              0.9802106957476837, 0.9832193604340658, 0.8493109621841746], 
             UndirectedEdge[44, 66] -> 
             RGBColor[
              0.9914379149967415, 0.9840732687219943, 0.5878711926716553], 
             UndirectedEdge[116, 290] -> 
             RGBColor[
              0.9786865201579624, 0.9397387852581081, 0.37408113973414603`], 
             UndirectedEdge[278, 367] -> 
             RGBColor[
              0.987307474238479, 0.9688472716389284, 0.40519236350920435`], 
             UndirectedEdge[102, 297] -> 
             RGBColor[
              0.9801625959722424, 0.944099799646157, 0.4323772334329572], 
             UndirectedEdge[104, 187] -> 
             RGBColor[
              0.9934682754377245, 0.9884376265569754, 0.5304402744068374], 
             UndirectedEdge[136, 371] -> 
             RGBColor[
              0.9862861051378705, 0.9873808129482039, 0.8200737220319366], 
             UndirectedEdge[80, 302] -> 
             RGBColor[
              0.9786838096514048, 0.9382212116872125, 0.5023366426712017], 
             UndirectedEdge[176, 373] -> 
             RGBColor[
              0.965431352531455, 0.9113219256189982, 0.5971467748112724], 
             UndirectedEdge[112, 219] -> 
             RGBColor[
              0.9808491279921547, 0.9456882789659915, 0.4968932477332935], 
             UndirectedEdge[33, 179] -> 
             RGBColor[
              0.9833794352498693, 0.9711865333976513, 0.651105139128192], 
             UndirectedEdge[123, 334] -> 
             RGBColor[
              0.9285804237306732, 0.7366763418364402, 0.30577143886728453`], 
             UndirectedEdge[94, 307] -> 
             RGBColor[
              0.9515833750225952, 0.8359401712053256, 0.5035766333701579], 
             UndirectedEdge[73, 89] -> 
             RGBColor[
              0.9460541453666937, 0.8238296933090064, 0.27545210297132994`], 
             UndirectedEdge[267, 311] -> 
             RGBColor[
              0.9889742844178766, 0.9758077918216945, 0.5786109905046207], 
             UndirectedEdge[52, 391] -> 
             RGBColor[
              0.9673167209914253, 0.9128053672665173, 0.5871305075683284], 
             UndirectedEdge[105, 271] -> 
             RGBColor[
              0.9591608959080989, 0.8638466294697367, 0.4098210297459146], 
             UndirectedEdge[187, 377] -> 
             RGBColor[
              0.9336329352093733, 0.7536928891816373, 0.39316508135397027`], 
             UndirectedEdge[58, 124] -> 
             RGBColor[
              0.9413981342726689, 0.7918240813149633, 0.32444725709780836`], 
             UndirectedEdge[11, 54] -> 
             RGBColor[
              0.9560860033422371, 0.8641035051191557, 0.5576600365428218], 
             UndirectedEdge[115, 283] -> 
             RGBColor[
              0.9882228061939902, 0.9744544045142518, 0.5838582976399059], 
             UndirectedEdge[292, 362] -> 
             RGBColor[
              0.9662964882374661, 0.9117304062086719, 0.5954986536780452], 
             UndirectedEdge[15, 154] -> 
             RGBColor[
              0.9886263268366589, 0.98956470810396, 0.8381547286465707], 
             UndirectedEdge[158, 311] -> 
             RGBColor[
              0.9595746025311316, 0.8677546136292469, 0.5106519468104145], 
             UndirectedEdge[123, 253] -> 
             RGBColor[
              0.9700903832106158, 0.910512060536156, 0.3396504693500067], 
             UndirectedEdge[236, 376] -> 
             RGBColor[
              0.991760687764785, 0.9908608468971419, 0.7862102566014573], 
             UndirectedEdge[206, 386] -> 
             RGBColor[
              0.9543966299855258, 0.8512059475738378, 0.3118447199803236], 
             UndirectedEdge[74, 338] -> 
             RGBColor[
              0.9936759419561242, 0.9916528537250483, 0.7544695381320052], 
             UndirectedEdge[293, 394] -> 
             RGBColor[
              0.9851762934987164, 0.9763581931063636, 0.6561972157918491], 
             UndirectedEdge[41, 381] -> 
             RGBColor[
              0.9897689506780902, 0.9881010046968166, 0.6784766322793188], 
             UndirectedEdge[59, 328] -> 
             RGBColor[
              0.9802550404074184, 0.9442612242690959, 0.4455263273230321], 
             UndirectedEdge[123, 196] -> 
             RGBColor[
              0.9787470274674106, 0.9701533318831628, 0.664087281916705], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.9763806205738066, 0.9319884284807405, 0.36274360038512377`], 
             UndirectedEdge[23, 38] -> 
             RGBColor[
              0.9282774329379052, 0.7533509522671131, 0.2611485428780562], 
             UndirectedEdge[61, 282] -> 
             RGBColor[
              0.9021688413658046, 0.5510000550373928, 0.2841442315193573], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.986793959246808, 0.9886940480707458, 0.8634646127362388], 
             UndirectedEdge[3, 232] -> 
             RGBColor[
              0.9704806515672593, 0.9248124549660225, 0.5870492855098449], 
             UndirectedEdge[110, 362] -> 
             RGBColor[
              0.971823503928821, 0.9141499426214892, 0.5099013021906045], 
             UndirectedEdge[125, 252] -> 
             RGBColor[
              0.9885821277480167, 0.9811539817000925, 0.6231835978916624], 
             UndirectedEdge[49, 327] -> 
             RGBColor[
              0.9868595592066807, 0.9658040433538084, 0.5337485150972643], 
             UndirectedEdge[89, 291] -> 
             RGBColor[
              0.9738262751670231, 0.9208834094192326, 0.4871015671265294], 
             UndirectedEdge[34, 250] -> 
             RGBColor[
              0.9460820624024066, 0.8204883437000647, 0.5323971286157849], 
             UndirectedEdge[125, 226] -> 
             RGBColor[
              0.9913981632531017, 0.9896774077513071, 0.7170918002837572], 
             UndirectedEdge[3, 14] -> 
             RGBColor[
              0.9690855561474774, 0.9192813665145765, 0.58592675898799], 
             UndirectedEdge[105, 345] -> 
             RGBColor[
              0.9900959090185815, 0.9888537439209834, 0.7179462563551051], 
             UndirectedEdge[88, 336] -> 
             RGBColor[
              0.9074539947284328, 0.7265936017734331, 0.5930824267274948], 
             UndirectedEdge[162, 357] -> 
             RGBColor[
              0.9788168293339345, 0.9821186701889258, 0.8489321288232734], 
             UndirectedEdge[279, 328] -> 
             RGBColor[
              0.950455784962146, 0.829297075319514, 0.4049878149486883], 
             UndirectedEdge[312, 359] -> 
             RGBColor[
              0.9567090995193213, 0.8713532772497301, 0.5815490046842372], 
             UndirectedEdge[202, 289] -> 
             RGBColor[
              0.9682642462354492, 0.9038453332771017, 0.5256650184143259], 
             UndirectedEdge[27, 48] -> 
             RGBColor[
              0.9408781286254757, 0.915024101688543, 0.6552188263244609], 
             UndirectedEdge[115, 193] -> 
             RGBColor[
              0.9814103072296917, 0.9514742458568487, 0.557393025596087], 
             UndirectedEdge[117, 385] -> 
             RGBColor[
              0.9935868621968282, 0.9886912716437377, 0.5433477113026315], 
             UndirectedEdge[179, 352] -> 
             RGBColor[
              0.9887161953836331, 0.9883140728496921, 0.7462075925029182], 
             UndirectedEdge[8, 365] -> 
             RGBColor[
              0.9363398016611544, 0.7849134661621499, 0.26972981319812145`], 
             UndirectedEdge[105, 353] -> 
             RGBColor[
              0.9940965290793228, 0.9905081031273457, 0.6516456286757866], 
             UndirectedEdge[231, 392] -> 
             RGBColor[
              0.9439770051922259, 0.8016673355302971, 0.3566278176364649], 
             UndirectedEdge[109, 132] -> 
             RGBColor[
              0.9701356560855388, 0.9121188496649609, 0.531349775896246], 
             UndirectedEdge[23, 158] -> 
             RGBColor[
              0.9268949060889708, 0.74786969401085, 0.26003612932332765`], 
             UndirectedEdge[105, 350] -> 
             RGBColor[
              0.9938117306203952, 0.9903903316455926, 0.6563654761750023], 
             UndirectedEdge[172, 351] -> 
             RGBColor[
              0.923221043498916, 0.8476907321347842, 0.6271004437427837], 
             UndirectedEdge[34, 375] -> 
             RGBColor[
              0.9755807863220058, 0.9361849990019899, 0.5649869382078186], 
             UndirectedEdge[32, 391] -> 
             RGBColor[
              0.9715575628920237, 0.9131213013805592, 0.4123385902790866], 
             UndirectedEdge[140, 241] -> 
             RGBColor[
              0.9818748593729845, 0.950521786058985, 0.3840876806199919], 
             UndirectedEdge[89, 336] -> 
             RGBColor[
              0.9498288431199011, 0.9050490087748257, 0.6277189603920936], 
             UndirectedEdge[74, 118] -> 
             RGBColor[
              0.9912013441561492, 0.990629543940496, 0.7954800277314091], 
             UndirectedEdge[138, 328] -> 
             RGBColor[
              0.9901610531287433, 0.9889153552402123, 0.719386978628547], 
             UndirectedEdge[189, 207] -> 
             RGBColor[
              0.9487991699464022, 0.8307767640094028, 0.29815976195005145`], 
             UndirectedEdge[273, 281] -> 
             RGBColor[
              0.9721610032144699, 0.9177546683144262, 0.3463511837519764], 
             UndirectedEdge[49, 225] -> 
             RGBColor[
              0.9782040048234399, 0.9381391317057348, 0.3698271038777261], 
             UndirectedEdge[43, 159] -> 
             RGBColor[
              0.9907835644456529, 0.9902910440762729, 0.7903563726134976], 
             UndirectedEdge[113, 368] -> 
             RGBColor[
              0.9203303120705448, 0.674568439246773, 0.3912647633299852], 
             UndirectedEdge[11, 83] -> 
             RGBColor[
              0.9598109762261386, 0.8656438771340855, 0.4959275959357666], 
             UndirectedEdge[151, 344] -> 
             RGBColor[
              0.9894726087632437, 0.9899146674290564, 0.824129647015639], 
             UndirectedEdge[182, 377] -> 
             RGBColor[
              0.9332961141787625, 0.7529724630549908, 0.356504190790432], 
             UndirectedEdge[198, 203] -> 
             RGBColor[
              0.9431158458764257, 0.8106045338282158, 0.2812945731502611], 
             UndirectedEdge[208, 395] -> 
             RGBColor[
              0.9407995722165192, 0.7979648263979894, 0.2974321173262093], 
             UndirectedEdge[305, 339] -> 
             RGBColor[
              0.9927508180886317, 0.9894416018972286, 0.6368748248034597], 
             UndirectedEdge[9, 313] -> 
             RGBColor[
              0.9436410906984782, 0.8142627356523322, 0.27351050254361087`], 
             UndirectedEdge[267, 317] -> 
             RGBColor[
              0.989584646918797, 0.9760601924014258, 0.5684957042968507], 
             UndirectedEdge[306, 350] -> 
             RGBColor[
              0.9682201825969853, 0.900875333780848, 0.5119509882905349], 
             UndirectedEdge[111, 362] -> 
             RGBColor[
              0.9670606140262774, 0.8985521139942656, 0.336941419382921], 
             UndirectedEdge[104, 261] -> 
             RGBColor[
              0.9400897897745124, 0.7838899846958636, 0.3590689093332013], 
             UndirectedEdge[243, 363] -> 
             RGBColor[
              0.9922076566819154, 0.9910456800309526, 0.7788028249261288], 
             UndirectedEdge[154, 369] -> 
             RGBColor[
              0.9885329572117113, 0.9895260973645543, 0.8397021049647947], 
             UndirectedEdge[218, 282] -> 
             RGBColor[
              0.9882429699996689, 0.9788927822614597, 0.6141443990921314], 
             UndirectedEdge[7, 293] -> 
             RGBColor[
              0.989000464469563, 0.9884504368559082, 0.7397244178381912], 
             UndirectedEdge[24, 167] -> 
             RGBColor[
              0.9686627248426609, 0.9049853755900684, 0.33780644694028283`], 
             UndirectedEdge[326, 363] -> 
             RGBColor[
              0.9923232658096071, 0.9900885291051846, 0.7038370250642125], 
             UndirectedEdge[276, 282] -> 
             RGBColor[
              0.9840502615736897, 0.9578599284906907, 0.39253870737949687`], 
             UndirectedEdge[337, 345] -> 
             RGBColor[
              0.9694696104807123, 0.9190243056951009, 0.5775269247560888], 
             UndirectedEdge[107, 124] -> 
             RGBColor[
              0.9901990004027317, 0.9845905918166419, 0.6155200892971191], 
             UndirectedEdge[128, 227] -> 
             RGBColor[
              0.9666391482525469, 0.8961128965024694, 0.3406033371045596], 
             UndirectedEdge[25, 365] -> 
             RGBColor[
              0.9759858213873853, 0.9293322844522991, 0.4738267580343154], 
             UndirectedEdge[97, 363] -> 
             RGBColor[
              0.9900386000926378, 0.9901487193890746, 0.8147497059489717], 
             UndirectedEdge[13, 373] -> 
             RGBColor[
              0.9821369975448804, 0.9696282351862593, 0.6518673033278841], 
             UndirectedEdge[64, 195] -> 
             RGBColor[
              0.9625707699379453, 0.8819787516531142, 0.3269366043415781], 
             UndirectedEdge[77, 96] -> 
             RGBColor[
              0.9753865361886742, 0.9282143273523955, 0.3946653569383571], 
             UndirectedEdge[6, 53] -> 
             RGBColor[
              0.9945705769883924, 0.991776017677273, 0.7217040472454035], 
             UndirectedEdge[216, 343] -> 
             RGBColor[
              0.9923894472683541, 0.990201283828873, 0.708946959781721], 
             UndirectedEdge[26, 324] -> 
             RGBColor[
              0.9749113836751448, 0.9266652682371551, 0.3882496572505313], 
             UndirectedEdge[142, 281] -> 
             RGBColor[
              0.9596132626937768, 0.8754281931885479, 0.29760558127105396`], 
             UndirectedEdge[100, 341] -> 
             RGBColor[
              0.9419606641028571, 0.8076004041696618, 0.2721583918600923], 
             UndirectedEdge[115, 364] -> 
             RGBColor[
              0.9731969368160883, 0.9781638481078039, 0.869035402580137], 
             UndirectedEdge[150, 152] -> 
             RGBColor[
              0.9546159264199672, 0.856256467085792, 0.5465989713380273], 
             UndirectedEdge[10, 68] -> 
             RGBColor[
              0.9308794309513562, 0.8423962864605659, 0.6221508578751406], 
             UndirectedEdge[190, 288] -> 
             RGBColor[
              0.9937394418887318, 0.989017624176546, 0.559955069153622], 
             UndirectedEdge[23, 146] -> 
             RGBColor[
              0.959580364166075, 0.8711824307828087, 0.5273185387628998], 
             UndirectedEdge[188, 201] -> 
             RGBColor[
              0.9728145668612285, 0.9276824778668159, 0.5599678579718117], 
             UndirectedEdge[148, 382] -> 
             RGBColor[
              0.9697571997229324, 0.9093881543969964, 0.33835611441677854`], 
             UndirectedEdge[14, 71] -> 
             RGBColor[
              0.9715062738264533, 0.9145915582370963, 0.3487790177638082], 
             UndirectedEdge[228, 276] -> 
             RGBColor[
              0.9869346837982225, 0.9674141608879743, 0.41867598971925474`], 
             UndirectedEdge[56, 174] -> 
             RGBColor[
              0.9315232841844527, 0.7452919142413537, 0.33841076248222235`], 
             UndirectedEdge[16, 182] -> 
             RGBColor[
              0.9914011681188787, 0.9822506635766205, 0.45558478257631496`], 
             UndirectedEdge[104, 192] -> 
             RGBColor[
              0.9921221513533474, 0.9891302817109854, 0.6435608322567821], 
             UndirectedEdge[145, 395] -> 
             RGBColor[
              0.9479645798937872, 0.8263716942410875, 0.30319725068768516`], 
             UndirectedEdge[219, 251] -> 
             RGBColor[
              0.950102358093807, 0.9592996101387811, 0.8292242240677713], 
             UndirectedEdge[150, 179] -> 
             RGBColor[
              0.9520608417224046, 0.8550869449555563, 0.5838861482344002], 
             UndirectedEdge[73, 207] -> 
             RGBColor[
              0.9338732399785272, 0.7755364624910235, 0.2656510605734137], 
             UndirectedEdge[265, 325] -> 
             RGBColor[
              0.9931567405129742, 0.9899056901745229, 0.6516803552962944], 
             UndirectedEdge[39, 314] -> 
             RGBColor[
              0.9886849199726969, 0.9727444748341907, 0.4742538416862906], 
             UndirectedEdge[20, 263] -> 
             RGBColor[
              0.9732498700794947, 0.9333057984196917, 0.5903777232434195], 
             UndirectedEdge[66, 146] -> 
             RGBColor[
              0.9904638958241689, 0.9836704867629846, 0.6040132110419978], 
             UndirectedEdge[7, 21] -> 
             RGBColor[
              0.9937325112159525, 0.9890028001682697, 0.5592007081927488], 
             UndirectedEdge[107, 167] -> 
             RGBColor[
              0.9873570740196175, 0.9750041068103504, 0.6044797419514858], 
             UndirectedEdge[120, 195] -> 
             RGBColor[
              0.9357027034907877, 0.7827896756845598, 0.26712308985840627`], 
             UndirectedEdge[365, 388] -> 
             RGBColor[
              0.9501483293163103, 0.8396596768957776, 0.28084047867726225`], 
             UndirectedEdge[134, 342] -> 
             RGBColor[
              0.9468765832892927, 0.8243339373528051, 0.2904694852082471], 
             UndirectedEdge[227, 311] -> 
             RGBColor[
              0.9903653321388401, 0.9805001224180419, 0.5840149482232442], 
             UndirectedEdge[78, 377] -> 
             RGBColor[
              0.9317035092189377, 0.7480058313300035, 0.3158280298887439], 
             UndirectedEdge[21, 370] -> 
             RGBColor[
              0.9485338855041361, 0.8215712045960948, 0.3958594146754498], 
             UndirectedEdge[2, 230] -> 
             RGBColor[
              0.9857619108395168, 0.9855347842442865, 0.7055062390879705], 
             UndirectedEdge[24, 203] -> 
             RGBColor[
              0.9388134752712989, 0.7951228491910418, 0.26962608985220404`], 
             UndirectedEdge[54, 206] -> 
             RGBColor[
              0.9605220935562947, 0.8816911245784608, 0.5612294188574728], 
             UndirectedEdge[66, 130] -> 
             RGBColor[
              0.9871968085796039, 0.9823194622270445, 0.6581573016352011], 
             UndirectedEdge[101, 356] -> 
             RGBColor[
              0.9823283814501672, 0.9520516225173703, 0.3858495282493892], 
             UndirectedEdge[222, 383] -> 
             RGBColor[
              0.9619614764583575, 0.8758960511098239, 0.35609207228392825`], 
             UndirectedEdge[31, 247] -> 
             RGBColor[
              0.9763345966202357, 0.9691866792597348, 0.6699382109468959], 
             UndirectedEdge[46, 333] -> 
             RGBColor[
              0.9260892362082034, 0.7446754814071794, 0.2593878684257594], 
             UndirectedEdge[287, 385] -> 
             RGBColor[
              0.9933120198447585, 0.98966152920757, 0.6266915159940158], 
             UndirectedEdge[42, 330] -> 
             RGBColor[
              0.989406478541818, 0.9898873208830277, 0.8252255959241894], 
             UndirectedEdge[151, 227] -> 
             RGBColor[
              0.9907559720739798, 0.9806616620702105, 0.5775410335542335], 
             UndirectedEdge[36, 382] -> 
             RGBColor[
              0.9832425185589879, 0.9551352216350226, 0.3894007782968495], 
             UndirectedEdge[218, 361] -> 
             RGBColor[
              0.9897351598640889, 0.9839262890569901, 0.6199412749389919], 
             UndirectedEdge[196, 334] -> 
             RGBColor[
              0.9222374955188055, 0.7454626128789773, 0.5732809981340388], 
             UndirectedEdge[34, 265] -> 
             RGBColor[
              0.9914848379468852, 0.9892143154975089, 0.6793881075615337], 
             UndirectedEdge[372, 392] -> 
             RGBColor[
              0.950617157898754, 0.9585490108675578, 0.7351518782049337], 
             UndirectedEdge[127, 210] -> 
             RGBColor[
              0.9359569282903437, 0.7784916500680139, 0.2901882306013249], 
             UndirectedEdge[33, 157] -> 
             RGBColor[
              0.9624833872024332, 0.8808979638757359, 0.3306907719959565], 
             UndirectedEdge[139, 308] -> 
             RGBColor[
              0.9074805944132134, 0.5830828177215082, 0.2951661513883008], 
             UndirectedEdge[38, 146] -> 
             RGBColor[
              0.9599982899189026, 0.8728393671272687, 0.5276548116336033], 
             UndirectedEdge[55, 68] -> 
             RGBColor[
              0.9355143198292174, 0.8458529789967407, 0.6143051999775446], 
             UndirectedEdge[35, 392] -> 
             RGBColor[
              0.9742266484336997, 0.9242674402716258, 0.3811055250457393], 
             UndirectedEdge[51, 126] -> 
             RGBColor[
              0.9894867587754629, 0.9875508331454897, 0.651644011631184], 
             UndirectedEdge[130, 243] -> 
             RGBColor[
              0.9893264557050895, 0.9898542293835474, 0.8265517814212442], 
             UndirectedEdge[12, 203] -> 
             RGBColor[
              0.9572247770616366, 0.8650245330429709, 0.5409902125628362], 
             UndirectedEdge[182, 395] -> 
             RGBColor[
              0.9830701585150134, 0.9541482119687054, 0.4232203834444521], 
             UndirectedEdge[99, 382] -> 
             RGBColor[
              0.9779432086892621, 0.9372594051073087, 0.3688139601436625], 
             UndirectedEdge[17, 31] -> 
             RGBColor[
              0.9747567037647412, 0.9680098893516694, 0.6726091719708811], 
             UndirectedEdge[77, 78] -> 
             RGBColor[
              0.9915799209149789, 0.9828384164217678, 0.45757359873594006`], 
             UndirectedEdge[243, 344] -> 
             RGBColor[
              0.9894154511695229, 0.9898910312951698, 0.825076896262704], 
             UndirectedEdge[305, 313] -> 
             RGBColor[
              0.9698729001720957, 0.9101455516174659, 0.5265798532731404], 
             UndirectedEdge[189, 280] -> 
             RGBColor[
              0.9162407288343075, 0.6898779541565272, 0.2713512755022397], 
             UndirectedEdge[104, 208] -> 
             RGBColor[
              0.9508608681086195, 0.8315338148596129, 0.36799111772505627`], 
             UndirectedEdge[191, 335] -> 
             RGBColor[
              0.9821939742499791, 0.9515982354708244, 0.3853273816573285], 
             UndirectedEdge[225, 355] -> 
             RGBColor[
              0.9641622339823344, 0.8892017359506141, 0.3234603409020498], 
             UndirectedEdge[308, 348] -> 
             RGBColor[
              0.9792992780244679, 0.9418337453951795, 0.37408203343873114`], 
             UndirectedEdge[132, 149] -> 
             RGBColor[
              0.9831150560431035, 0.9581211853006433, 0.5702116841451343], 
             UndirectedEdge[128, 224] -> 
             RGBColor[
              0.955460750121772, 0.858405534794668, 0.29717737122985677`], 
             UndirectedEdge[192, 225] -> 
             RGBColor[
              0.9844081401880009, 0.9634792358013659, 0.5821205897738473], 
             UndirectedEdge[84, 252] -> 
             RGBColor[
              0.947594799742963, 0.8203303884600541, 0.3267277003348426], 
             UndirectedEdge[30, 211] -> 
             RGBColor[
              0.994593711743557, 0.990844821016086, 0.6529370709089217], 
             UndirectedEdge[138, 242] -> 
             RGBColor[
              0.9821015873985646, 0.962525416947231, 0.6203461386620794], 
             UndirectedEdge[27, 41] -> 
             RGBColor[
              0.979016611870666, 0.9405503037572122, 0.40103984280140786`], 
             UndirectedEdge[102, 139] -> 
             RGBColor[
              0.8953312361202695, 0.5421001793944235, 0.24796818863401326`], 
             UndirectedEdge[203, 329] -> 
             RGBColor[
              0.9543778570860805, 0.8637847447526714, 0.5853715521399124], 
             UndirectedEdge[195, 312] -> 
             RGBColor[
              0.9645859849540315, 0.9025825031818862, 0.5878869315992696], 
             UndirectedEdge[51, 87] -> 
             RGBColor[
              0.9782838917926193, 0.9383887779991096, 0.3718237527925687], 
             UndirectedEdge[83, 366] -> 
             RGBColor[
              0.9303430308109801, 0.7377301718817058, 0.4716436769724991], 
             UndirectedEdge[8, 302] -> 
             RGBColor[
              0.9388660208849864, 0.7934349967886163, 0.2795436978462378], 
             UndirectedEdge[146, 344] -> 
             RGBColor[
              0.9881231293669406, 0.9893566230186466, 0.84649401295311], 
             UndirectedEdge[67, 320] -> 
             RGBColor[
              0.9756460305654009, 0.9289433380333121, 0.4081158470203196], 
             UndirectedEdge[90, 166] -> 
             RGBColor[
              0.9744169599980785, 0.9786683590467226, 0.8488164611357735], 
             UndirectedEdge[12, 341] -> 
             RGBColor[
              0.9725138955664283, 0.9256407931177519, 0.553292196193528], 
             UndirectedEdge[3, 13] -> 
             RGBColor[
              0.984100910102565, 0.9708862352916336, 0.6392872396428327], 
             UndirectedEdge[153, 341] -> 
             RGBColor[
              0.9197567089459536, 0.7137413505843527, 0.2539911038217779], 
             UndirectedEdge[192, 351] -> 
             RGBColor[
              0.9604115169220031, 0.8747611155089412, 0.529374298641777], 
             UndirectedEdge[12, 150] -> 
             RGBColor[
              0.9550594901809215, 0.8564398921000153, 0.5392479719127974], 
             UndirectedEdge[99, 393] -> 
             RGBColor[
              0.9529201296660404, 0.8464674860868753, 0.30484782586619813`], 
             UndirectedEdge[4, 190] -> 
             RGBColor[
              0.977046762284182, 0.9798758922387405, 0.7869766837443544], 
             UndirectedEdge[373, 390] -> 
             RGBColor[
              0.9870338512217921, 0.9861116191606896, 0.6738543293903259], 
             UndirectedEdge[23, 308] -> 
             RGBColor[
              0.9594667523788747, 0.8666233275947747, 0.34031843271082396`], 
             UndirectedEdge[37, 187] -> 
             RGBColor[
              0.9906340657487565, 0.989145647683938, 0.7140695008970116], 
             UndirectedEdge[17, 292] -> 
             RGBColor[
              0.9735876609275242, 0.9798223012827592, 0.9295933799951177], 
             UndirectedEdge[309, 385] -> 
             RGBColor[
              0.9597556745655771, 0.8667572708396161, 0.3776031028661213], 
             UndirectedEdge[140, 380] -> 
             RGBColor[
              0.9811118822201559, 0.9479480849669393, 0.38112365845739826`], 
             UndirectedEdge[119, 354] -> 
             RGBColor[
              0.9690860167382178, 0.9408232890030013, 0.6334739266831668], 
             UndirectedEdge[36, 305] -> 
             RGBColor[
              0.9872004227604865, 0.9711256763950001, 0.5807160444804538], 
             UndirectedEdge[91, 351] -> 
             RGBColor[
              0.919797038481533, 0.7197290141715273, 0.25432501843801725`], 
             UndirectedEdge[130, 275] -> 
             RGBColor[
              0.9521843061833108, 0.8534614131678441, 0.5781403625807485], 
             UndirectedEdge[46, 102] -> 
             RGBColor[
              0.9475502134742411, 0.8265637405598776, 0.2933078019013441], 
             UndirectedEdge[111, 271] -> 
             RGBColor[
              0.9547411019974725, 0.8497093540340768, 0.32702885082843114`], 
             UndirectedEdge[104, 351] -> 
             RGBColor[
              0.9613920808958214, 0.8732865642422423, 0.3764647787329742], 
             UndirectedEdge[174, 203] -> 
             RGBColor[
              0.9588962724519332, 0.8636198863477271, 0.3609428204955182], 
             UndirectedEdge[294, 313] -> 
             RGBColor[
              0.9671491008978724, 0.9090191906191262, 0.5717202562135816], 
             UndirectedEdge[206, 266] -> 
             RGBColor[
              0.963682854039756, 0.8817257509169736, 0.41635525661810335`], 
             UndirectedEdge[167, 358] -> 
             RGBColor[
              0.988959253892374, 0.9739395636031064, 0.45238657253261555`], 
             UndirectedEdge[315, 322] -> 
             RGBColor[
              0.9873585653082546, 0.9867389719628423, 0.703867183083914], 
             UndirectedEdge[176, 347] -> 
             RGBColor[
              0.961999867728214, 0.9087627298712817, 0.6029553835085864], 
             UndirectedEdge[92, 186] -> 
             RGBColor[
              0.9483580546059611, 0.8249127002389794, 0.3192368015261635], 
             UndirectedEdge[149, 210] -> 
             RGBColor[
              0.972626239197296, 0.9193240185271017, 0.3481585376928119], 
             UndirectedEdge[171, 374] -> 
             RGBColor[
              0.9631901406829247, 0.8821805071561248, 0.3391730177950504], 
             UndirectedEdge[228, 282] -> 
             RGBColor[
              0.989903104956142, 0.9774273424720692, 0.43020774537847245`], 
             UndirectedEdge[164, 210] -> 
             RGBColor[
              0.9389775279411614, 0.7913747512322753, 0.2926656164020016], 
             UndirectedEdge[196, 214] -> 
             RGBColor[
              0.9834133200560691, 0.9854505972414047, 0.8368466516993223], 
             UndirectedEdge[204, 307] -> 
             RGBColor[
              0.9837484013526259, 0.9580697384740193, 0.5575496402028861], 
             UndirectedEdge[127, 255] -> 
             RGBColor[
              0.9303315446564056, 0.7595159101678508, 0.2683346774480363], 
             UndirectedEdge[68, 334] -> 
             RGBColor[
              0.8973052164816598, 0.6212938731616584, 0.23574842778482052`], 
             UndirectedEdge[16, 269] -> 
             RGBColor[
              0.9793521575150298, 0.9765849279978194, 0.6757579808269949], 
             UndirectedEdge[68, 337] -> 
             RGBColor[
              0.9375201885964594, 0.7899953984875396, 0.2685854810362882], 
             UndirectedEdge[23, 374] -> 
             RGBColor[
              0.932927404641609, 0.7717865405610844, 0.26489001925972044`], 
             UndirectedEdge[22, 116] -> 
             RGBColor[
              0.9814216559087641, 0.9489650403859761, 0.3847066256389636], 
             UndirectedEdge[192, 322] -> 
             RGBColor[
              0.9863731302077714, 0.9882031043821512, 0.8562465109163333], 
             UndirectedEdge[70, 95] -> 
             RGBColor[
              0.9389235390861712, 0.7950615504636016, 0.27230649795999695`], 
             UndirectedEdge[71, 273] -> 
             RGBColor[
              0.9861121680528029, 0.9648152232034035, 0.40054882469248515`], 
             UndirectedEdge[135, 215] -> 
             RGBColor[
              0.921928482132112, 0.7242674375751583, 0.255837662233769], 
             UndirectedEdge[161, 283] -> 
             RGBColor[
              0.9744536273360653, 0.9254882278103105, 0.35525759553863745`], 
             UndirectedEdge[18, 384] -> 
             RGBColor[
              0.9442576375283085, 0.8106944172087656, 0.30532094465532805`], 
             UndirectedEdge[71, 303] -> 
             RGBColor[
              0.9892088920976452, 0.9752612005520398, 0.4125790128394311], 
             UndirectedEdge[32, 353] -> 
             RGBColor[
              0.9940275070174468, 0.990360471916194, 0.6441330031953783], 
             UndirectedEdge[188, 281] -> 
             RGBColor[
              0.9595500737812841, 0.8752150421492478, 0.29736010427824466`], 
             UndirectedEdge[54, 198] -> 
             RGBColor[
              0.9743886078344319, 0.9350914518171729, 0.5805934366541395], 
             UndirectedEdge[271, 385] -> 
             RGBColor[
              0.9588582604002247, 0.8631993227195371, 0.37688102236366094`], 
             UndirectedEdge[150, 206] -> 
             RGBColor[
              0.9270840447175736, 0.748619565646548, 0.2601883147035555], 
             UndirectedEdge[317, 346] -> 
             RGBColor[
              0.9861676358136054, 0.9645338115912535, 0.5552212614015841], 
             UndirectedEdge[146, 243] -> 
             RGBColor[
              0.9925935429496546, 0.9912052539194876, 0.772407690828041], 
             UndirectedEdge[91, 316] -> 
             RGBColor[
              0.9518577588182673, 0.834846978726086, 0.40661624237494953`], 
             UndirectedEdge[196, 386] -> 
             RGBColor[
              0.9738193449172923, 0.9535311015667292, 0.6449441657242625], 
             UndirectedEdge[151, 306] -> 
             RGBColor[
              0.9682852584901321, 0.9009022443350385, 0.5108725123300784], 
             UndirectedEdge[27, 376] -> 
             RGBColor[
              0.978110638005286, 0.9421118680110798, 0.5567960366349834], 
             UndirectedEdge[280, 387] -> 
             RGBColor[
              0.8764538955176115, 0.531887819118827, 0.2186224408388084], 
             UndirectedEdge[308, 354] -> 
             RGBColor[
              0.9796612679503065, 0.9430548224143096, 0.37548829594455246`], 
             UndirectedEdge[327, 349] -> 
             RGBColor[
              0.9732900860495701, 0.9187391505318545, 0.4877617739243817], 
             UndirectedEdge[60, 108] -> 
             RGBColor[
              0.9817133158062847, 0.9834156444129578, 0.7837940687385089], 
             UndirectedEdge[353, 391] -> 
             RGBColor[
              0.9719696809458169, 0.9147294857832747, 0.5100189196496949], 
             UndirectedEdge[140, 195] -> 
             RGBColor[
              0.9646900674951817, 0.8891276399484025, 0.3351696751556791], 
             UndirectedEdge[17, 18] -> 
             RGBColor[
              0.9700427426234783, 0.9521085915314782, 0.6542963230939405], 
             UndirectedEdge[87, 205] -> 
             RGBColor[
              0.9786071893425603, 0.9390802787680372, 0.4070126959424545], 
             UndirectedEdge[221, 256] -> 
             RGBColor[
              0.9427978720317439, 0.8107500921323083, 0.2737151133538504], 
             UndirectedEdge[194, 316] -> 
             RGBColor[
              0.9770027962454066, 0.933284924417348, 0.43337807384327554`], 
             UndirectedEdge[16, 37] -> 
             RGBColor[
              0.9885382193499623, 0.9828972147175405, 0.6360859375711693], 
             UndirectedEdge[252, 288] -> 
             RGBColor[
              0.9908152016368437, 0.9802627591130978, 0.4542694478343069], 
             UndirectedEdge[60, 353] -> 
             RGBColor[
              0.9817402690490244, 0.9842000002309659, 0.8395515853876203], 
             UndirectedEdge[206, 286] -> 
             RGBColor[
              0.9510634701736904, 0.8399624168653754, 0.2988960235257573], 
             UndirectedEdge[220, 396] -> 
             RGBColor[
              0.977530201300916, 0.946567402267992, 0.5988709089525797], 
             UndirectedEdge[133, 320] -> 
             RGBColor[
              0.9923532194717188, 0.9895012328926562, 0.6597500048098499], 
             UndirectedEdge[28, 231] -> 
             RGBColor[
              0.9003496326314795, 0.6399561810549581, 0.2385390447949799], 
             UndirectedEdge[239, 269] -> 
             RGBColor[
              0.9576027432727383, 0.9003152087700982, 0.6063888511004222], 
             UndirectedEdge[212, 239] -> 
             RGBColor[
              0.9702650395442804, 0.9072927003794028, 0.4529680130177448], 
             UndirectedEdge[77, 182] -> 
             RGBColor[
              0.9931725258748036, 0.9878050481467552, 0.4982497596376281], 
             UndirectedEdge[280, 336] -> 
             RGBColor[
              0.9050894966196397, 0.7158569681039673, 0.5911094315463655], 
             UndirectedEdge[199, 400] -> 
             RGBColor[
              0.9587397449610369, 0.8791355080021761, 0.5818685294990165], 
             UndirectedEdge[73, 336] -> 
             RGBColor[
              0.9431960317485639, 0.8787521219408384, 0.6223820446706226], 
             UndirectedEdge[305, 340] -> 
             RGBColor[
              0.9928290869583937, 0.9896090110954526, 0.6453939082575645], 
             UndirectedEdge[259, 350] -> 
             RGBColor[
              0.9738991800632129, 0.9233906663207189, 0.5165204429550649], 
             UndirectedEdge[247, 393] -> 
             RGBColor[
              0.9506614722674878, 0.8762020047049072, 0.6034467733149812], 
             UndirectedEdge[30, 216] -> 
             RGBColor[
              0.9946597581289818, 0.9909860875561955, 0.6601258123713585], 
             UndirectedEdge[291, 387] -> 
             RGBColor[
              0.9423325604468653, 0.7918366890659245, 0.461544518118265], 
             UndirectedEdge[45, 338] -> 
             RGBColor[
              0.9942824137610171, 0.9913134874822298, 0.701520480083656], 
             UndirectedEdge[219, 248] -> 
             RGBColor[
              0.9370226051821975, 0.7680102203227598, 0.4443067037427878], 
             UndirectedEdge[158, 354] -> 
             RGBColor[
              0.9470894216604024, 0.8243011888303851, 0.29520599255705615`], 
             UndirectedEdge[191, 327] -> 
             RGBColor[
              0.9878876974742925, 0.9692721951488088, 0.5377426381193162], 
             UndirectedEdge[165, 192] -> 
             RGBColor[
              0.9923571209368818, 0.9896328578910963, 0.6691358213603198], 
             UndirectedEdge[143, 354] -> 
             RGBColor[
              0.981175172870343, 0.9471748464766794, 0.46527415832823515`], 
             UndirectedEdge[115, 161] -> 
             RGBColor[
              0.9786513149138566, 0.9421675169333346, 0.5466748614410485], 
             UndirectedEdge[296, 330] -> 
             RGBColor[
              0.9707280518651098, 0.9272921144190198, 0.5978124656032582], 
             UndirectedEdge[45, 262] -> 
             RGBColor[
              0.99146871954803, 0.9815912197315494, 0.5312977023657048], 
             UndirectedEdge[37, 208] -> 
             RGBColor[
              0.9480266584196513, 0.8322418359865755, 0.5516203442152305], 
             UndirectedEdge[306, 348] -> 
             RGBColor[
              0.9550474477584248, 0.8560662028648778, 0.3004942102399096], 
             UndirectedEdge[189, 263] -> 
             RGBColor[
              0.9776848360739887, 0.9482659800986557, 0.6076067286589757], 
             UndirectedEdge[2, 50] -> 
             RGBColor[
              0.9928359968389204, 0.9870852465673059, 0.4616206508982148], 
             UndirectedEdge[241, 331] -> 
             RGBColor[
              0.9836749861744575, 0.9647640887915914, 0.6052472603205035], 
             UndirectedEdge[135, 213] -> 
             RGBColor[
              0.9462152042373776, 0.903197517196138, 0.6344903810379382], 
             UndirectedEdge[49, 349] -> 
             RGBColor[
              0.9651638434932965, 0.8928597319644684, 0.3258966392004601], 
             UndirectedEdge[256, 319] -> 
             RGBColor[
              0.9685101735348012, 0.9054395625493303, 0.3321683998477988], 
             UndirectedEdge[64, 332] -> 
             RGBColor[
              0.9476856278369568, 0.8229641234022562, 0.3149596696079312], 
             UndirectedEdge[213, 350] -> 
             RGBColor[
              0.9665446744374229, 0.9729617813927363, 0.8695115214148381], 
             UndirectedEdge[333, 345] -> 
             RGBColor[
              0.9551458557022332, 0.8622353911067577, 0.5660016954395871], 
             UndirectedEdge[53, 201] -> 
             RGBColor[
              0.9915246862831774, 0.9907632542195358, 0.7901214119039517], 
             UndirectedEdge[9, 384] -> 
             RGBColor[
              0.926047648067926, 0.7445105982894061, 0.25935440563189316`], 
             UndirectedEdge[24, 33] -> 
             RGBColor[
              0.9679667819180485, 0.9026377966901812, 0.33510284009595714`], 
             UndirectedEdge[20, 359] -> 
             RGBColor[
              0.9445138498499281, 0.8164098784495482, 0.2810511651366828], 
             UndirectedEdge[35, 291] -> 
             RGBColor[
              0.9752107189067344, 0.9263722675086601, 0.48821552305657234`], 
             UndirectedEdge[316, 351] -> 
             RGBColor[
              0.9617421668012113, 0.8740353625947568, 0.41456946905490144`], 
             UndirectedEdge[195, 263] -> 
             RGBColor[
              0.9652373434220143, 0.9028518566475462, 0.5770922361231126], 
             UndirectedEdge[67, 200] -> 
             RGBColor[
              0.9257927696555917, 0.7399082699250437, 0.26192982829699607`], 
             UndirectedEdge[232, 277] -> 
             RGBColor[
              0.9338723832655995, 0.7755330659097481, 0.2656503712420825], 
             UndirectedEdge[88, 120] -> 
             RGBColor[
              0.8974822291547558, 0.6208049774498847, 0.2358292630745039], 
             UndirectedEdge[247, 271] -> 
             RGBColor[
              0.9457569363031499, 0.8567571539460328, 0.5995004685538197], 
             UndirectedEdge[202, 269] -> 
             RGBColor[
              0.9806789442579794, 0.9837646470893044, 0.8572986510271251], 
             UndirectedEdge[207, 291] -> 
             RGBColor[
              0.9616453697788566, 0.8725901786012498, 0.4773005247286132], 
             UndirectedEdge[72, 397] -> 
             RGBColor[
              0.9766479994875685, 0.9324919460569393, 0.3976605918167805], 
             UndirectedEdge[200, 298] -> 
             RGBColor[
              0.8927926469236984, 0.6060782732415251, 0.23225589551149253`], 
             UndirectedEdge[233, 389] -> 
             RGBColor[
              0.9551064234613862, 0.9624336613584235, 0.7603069500164439], 
             UndirectedEdge[44, 311] -> 
             RGBColor[
              0.9932340797808082, 0.9914701323602153, 0.7617923378796441], 
             UndirectedEdge[137, 258] -> 
             RGBColor[
              0.9426917726556532, 0.8104990059540158, 0.27274665896299544`], 
             UndirectedEdge[46, 287] -> 
             RGBColor[
              0.9609005117897789, 0.8725551202433925, 0.5094860279319604], 
             UndirectedEdge[84, 274] -> 
             RGBColor[
              0.9200541742680719, 0.7207484718797321, 0.254531915927619], 
             UndirectedEdge[270, 357] -> 
             RGBColor[
              0.9735145822468652, 0.979767799322379, 0.929717083139501], 
             UndirectedEdge[44, 344] -> 
             RGBColor[
              0.989097148539513, 0.9897594049776562, 0.8303519945827673], 
             UndirectedEdge[44, 383] -> 
             RGBColor[
              0.9929831791098027, 0.9891536725450827, 0.6051100479948933], 
             UndirectedEdge[193, 364] -> 
             RGBColor[
              0.9621867502739986, 0.9385044003273768, 0.6511528646339072], 
             UndirectedEdge[43, 375] -> 
             RGBColor[
              0.978393698913897, 0.9371824734298093, 0.5063223508756761], 
             UndirectedEdge[184, 252] -> 
             RGBColor[
              0.9908002248301249, 0.9802307252379139, 0.45263931484910713`], 
             UndirectedEdge[16, 78] -> 
             RGBColor[
              0.989808563159054, 0.9772840318516332, 0.41490862167462694`], 
             UndirectedEdge[345, 353] -> 
             RGBColor[
              0.9904390050104988, 0.9903142971125471, 0.8081139602453051], 
             UndirectedEdge[167, 203] -> 
             RGBColor[
              0.9547892433759291, 0.8499816446381165, 0.326643518099686], 
             UndirectedEdge[329, 340] -> 
             RGBColor[
              0.9885672485887365, 0.9877841176874482, 0.7132241073163218], 
             UndirectedEdge[193, 380] -> 
             RGBColor[
              0.9738109793823541, 0.9233204253615269, 0.3527610295923518], 
             UndirectedEdge[115, 253] -> 
             RGBColor[
              0.9737556522568674, 0.9253953769344812, 0.5289993897961898], 
             UndirectedEdge[113, 270] -> 
             RGBColor[
              0.9149412304888014, 0.6732724414524771, 0.5527770804757988], 
             UndirectedEdge[121, 202] -> 
             RGBColor[
              0.9931508096397502, 0.9903348262809044, 0.6831505857960534], 
             UndirectedEdge[17, 111] -> 
             RGBColor[
              0.9743517867163356, 0.9666440090683529, 0.6710361456999936], 
             UndirectedEdge[73, 280] -> 
             RGBColor[
              0.9013147988664324, 0.6346376526381479, 0.23884257412560195`], 
             UndirectedEdge[127, 242] -> 
             RGBColor[
              0.9393757195811497, 0.7900240358622713, 0.303469589181544], 
             UndirectedEdge[19, 211] -> 
             RGBColor[
              0.957563812685418, 0.8572129864620106, 0.42639135627500513`], 
             UndirectedEdge[213, 345] -> 
             RGBColor[
              0.962828852835609, 0.971425193668127, 0.931092301594941], 
             UndirectedEdge[102, 350] -> 
             RGBColor[
              0.9803226545700845, 0.9456602379840653, 0.5383408487350689], 
             UndirectedEdge[81, 227] -> 
             RGBColor[
              0.9638429571467403, 0.8850269305433959, 0.3383534561057866], 
             UndirectedEdge[144, 218] -> 
             RGBColor[
              0.9763903307535495, 0.9389110469522591, 0.5680991338040664], 
             UndirectedEdge[130, 354] -> 
             RGBColor[
              0.9765077924929415, 0.9462629010664034, 0.6166324925898317], 
             UndirectedEdge[104, 327] -> 
             RGBColor[
              0.9940442585450598, 0.9896695961827404, 0.5931324810845826], 
             UndirectedEdge[10, 253] -> 
             RGBColor[
              0.9471550657317072, 0.9069237548308777, 0.6352466156576604], 
             UndirectedEdge[40, 41] -> 
             RGBColor[
              0.9646647661992418, 0.8863211072373096, 0.3755809334692741], 
             UndirectedEdge[5, 113] -> 
             RGBColor[
              0.9114693908654145, 0.6456132336615763, 0.2773563204302383], 
             UndirectedEdge[271, 337] -> 
             RGBColor[
              0.9385345973702297, 0.7940171912438542, 0.2694016981468981], 
             UndirectedEdge[325, 376] -> 
             RGBColor[
              0.9920167608556246, 0.9909667397009824, 0.7819664627903284], 
             UndirectedEdge[52, 337] -> 
             RGBColor[
              0.9688172705870619, 0.9187545463847058, 0.5883378849954036], 
             UndirectedEdge[246, 260] -> 
             RGBColor[
              0.8680221003724111, 0.42965832772077495`, 0.20903985606225434`],
              UndirectedEdge[22, 290] -> 
             RGBColor[
              0.9675598335139335, 0.9022338425084948, 0.32847650832338143`], 
             UndirectedEdge[24, 107] -> 
             RGBColor[
              0.9713813059149874, 0.9201453113632757, 0.5474623137040038], 
             UndirectedEdge[314, 369] -> 
             RGBColor[
              0.9923359263319484, 0.9897486222214874, 0.6785390031945122], 
             UndirectedEdge[187, 208] -> 
             RGBColor[
              0.9512264282191785, 0.832315710972302, 0.40778007978391445`], 
             UndirectedEdge[9, 174] -> 
             RGBColor[
              0.9663641646294865, 0.8932275903041793, 0.36695166183553646`], 
             UndirectedEdge[6, 303] -> 
             RGBColor[
              0.9915681110444715, 0.9816808448383676, 0.5525717609339411], 
             UndirectedEdge[100, 198] -> 
             RGBColor[
              0.9448473976699241, 0.8174695596840067, 0.28268782036805423`], 
             UndirectedEdge[101, 123] -> 
             RGBColor[
              0.9809338067439655, 0.9473473945716392, 0.38043186885913083`], 
             UndirectedEdge[210, 394] -> 
             RGBColor[
              0.978500149316059, 0.9391380966173728, 0.3709775693093567], 
             UndirectedEdge[213, 227] -> 
             RGBColor[
              0.9633655424648709, 0.9618634195533531, 0.6968780033651101], 
             UndirectedEdge[32, 46] -> 
             RGBColor[
              0.9609702674626757, 0.8711462030102533, 0.40381980386086913`], 
             UndirectedEdge[303, 391] -> 
             RGBColor[
              0.968820015539117, 0.9045734421836567, 0.3433261093764809], 
             UndirectedEdge[248, 251] -> 
             RGBColor[
              0.8923965167624717, 0.7361768253962514, 0.6059288086763803], 
             UndirectedEdge[239, 388] -> 
             RGBColor[
              0.9445586255428065, 0.8179004555597318, 0.27424877261666825`], 
             UndirectedEdge[205, 277] -> 
             RGBColor[
              0.9527006228386146, 0.8387557001747341, 0.3737396446048291], 
             UndirectedEdge[308, 378] -> 
             RGBColor[0.96789858967323, 0.900052752723678, 0.347102886918521],
              UndirectedEdge[119, 130] -> 
             RGBColor[
              0.9773452709032183, 0.9825291845076819, 0.9189544227981885], 
             UndirectedEdge[28, 254] -> 
             RGBColor[
              0.9460993167054896, 0.8263377334016955, 0.5585702315648966], 
             UndirectedEdge[217, 314] -> 
             RGBColor[
              0.9944230988420565, 0.9906117216923039, 0.6439491532727137], 
             UndirectedEdge[229, 307] -> 
             RGBColor[
              0.9888525159912533, 0.989658243132181, 0.834406188996172], 
             UndirectedEdge[114, 155] -> 
             RGBColor[
              0.9922101385204218, 0.9906860088045447, 0.7525427916951356], 
             UndirectedEdge[226, 288] -> 
             RGBColor[
              0.9936312371419287, 0.9887861851643125, 0.5481776502264015], 
             UndirectedEdge[217, 231] -> 
             RGBColor[
              0.9450428754421779, 0.8040789486398485, 0.48222346034638686`], 
             UndirectedEdge[151, 346] -> 
             RGBColor[
              0.9859479132478247, 0.9644429506636909, 0.5588626329403433], 
             UndirectedEdge[114, 180] -> 
             RGBColor[
              0.9912089049677872, 0.9885444714756998, 0.6435646983880985], 
             UndirectedEdge[215, 345] -> 
             RGBColor[
              0.9385421307303434, 0.7924951140471472, 0.552439582790772], 
             UndirectedEdge[190, 252] -> 
             RGBColor[
              0.9913761374739974, 0.9814625441494569, 0.5153238520137771], 
             UndirectedEdge[275, 311] -> 
             RGBColor[
              0.9564102328890395, 0.8552089424620255, 0.5081058207190852], 
             UndirectedEdge[75, 320] -> 
             RGBColor[
              0.9941937712788871, 0.9899893888023407, 0.6094060194760391], 
             UndirectedEdge[169, 393] -> 
             RGBColor[
              0.9640515229359201, 0.8832617304198112, 0.4122534326032443], 
             UndirectedEdge[80, 182] -> 
             RGBColor[
              0.9940763262645436, 0.9897381857921724, 0.5966228544513681], 
             UndirectedEdge[239, 362] -> 
             RGBColor[
              0.9476753485262572, 0.830257223602748, 0.2767565610880438], 
             UndirectedEdge[171, 342] -> 
             RGBColor[
              0.9768346242480105, 0.9335198894789621, 0.3645073189280059], 
             UndirectedEdge[107, 157] -> 
             RGBColor[
              0.9658979111993721, 0.8984054785488305, 0.5430502456040032], 
             UndirectedEdge[116, 286] -> 
             RGBColor[
              0.9805583067540817, 0.9460527609632113, 0.3813526772028306], 
             UndirectedEdge[37, 117] -> 
             RGBColor[
              0.9907299291356144, 0.9893506897751521, 0.7245036389562557], 
             UndirectedEdge[111, 222] -> 
             RGBColor[
              0.9580598497277397, 0.8628670828774643, 0.3296991931532256], 
             UndirectedEdge[57, 72] -> 
             RGBColor[
              0.9654841451289484, 0.8894683913644348, 0.3822334521882146], 
             UndirectedEdge[8, 323] -> 
             RGBColor[
              0.898378015186835, 0.6282341654722403, 0.23675062268243896`], 
             UndirectedEdge[115, 356] -> 
             RGBColor[
              0.9901497994317314, 0.9809546051846818, 0.5913443024863922], 
             UndirectedEdge[129, 391] -> 
             RGBColor[
              0.9717626495711966, 0.9135599610498663, 0.4346610096587935], 
             UndirectedEdge[271, 303] -> 
             RGBColor[
              0.9563543264933163, 0.8551511390616824, 0.3332959233629006], 
             UndirectedEdge[141, 196] -> 
             RGBColor[
              0.9333184208341936, 0.7957785067202943, 0.5825271938355328], 
             UndirectedEdge[8, 117] -> 
             RGBColor[
              0.9546912219155941, 0.8458774391114368, 0.4209249382491866], 
             UndirectedEdge[278, 330] -> 
             RGBColor[
              0.9882876003151833, 0.9865245945191612, 0.6660279954893116], 
             UndirectedEdge[95, 276] -> 
             RGBColor[
              0.9506415014228846, 0.8345889889337338, 0.31782856888662014`], 
             UndirectedEdge[114, 268] -> 
             RGBColor[
              0.5842416933112392, 0.6476716558634213, 0.8781211155389845], 
             UndirectedEdge[95, 148] -> 
             RGBColor[
              0.9376459865859762, 0.7904941455962791, 0.2686867010515118], 
             UndirectedEdge[236, 366] -> 
             RGBColor[
              0.9290231571850864, 0.7371843702181937, 0.49351739867700783`], 
             UndirectedEdge[108, 378] -> 
             RGBColor[
              0.9695544501797743, 0.9044764054316767, 0.4523397388452553], 
             UndirectedEdge[33, 107] -> 
             RGBColor[
              0.9866611310950051, 0.9726565279104632, 0.6017761351071601], 
             UndirectedEdge[309, 362] -> 
             RGBColor[
              0.9377852849229495, 0.7910464170839591, 0.2687987837631928], 
             UndirectedEdge[178, 278] -> 
             RGBColor[
              0.976805539051339, 0.9334217782810605, 0.36439432843121605`], 
             UndirectedEdge[21, 232] -> 
             RGBColor[
              0.9745893704139874, 0.9251066240159576, 0.41683637940389695`], 
             UndirectedEdge[20, 140] -> 
             RGBColor[
              0.9727025941526621, 0.919581581720548, 0.3484551622759863], 
             UndirectedEdge[33, 150] -> 
             RGBColor[
              0.9519280135706015, 0.8390494247952737, 0.3221976706053215], 
             UndirectedEdge[38, 213] -> 
             RGBColor[
              0.9339573397060967, 0.8545991690208212, 0.6246274155070088], 
             UndirectedEdge[86, 262] -> 
             RGBColor[
              0.9323270379931956, 0.7517918504876259, 0.3138539380184546], 
             UndirectedEdge[17, 310] -> 
             RGBColor[
              0.958173394951721, 0.9110633044103953, 0.613431613287625], 
             UndirectedEdge[222, 223] -> 
             RGBColor[
              0.9597437351435478, 0.8771916640226167, 0.5536861485143014], 
             UndirectedEdge[19, 124] -> 
             RGBColor[
              0.955683001426038, 0.8518442913926547, 0.33611632347519516`], 
             UndirectedEdge[184, 274] -> 
             RGBColor[
              0.9632595993552338, 0.8806488086575919, 0.38044353044188345`], 
             UndirectedEdge[195, 360] -> 
             RGBColor[
              0.9593605387529677, 0.8711498880680573, 0.31446546238923084`], 
             UndirectedEdge[186, 378] -> 
             RGBColor[
              0.9291250402918827, 0.7567114329772265, 0.26183054765096814`], 
             UndirectedEdge[31, 169] -> 
             RGBColor[
              0.9897246472886682, 0.9762464049746388, 0.4787448702351589], 
             UndirectedEdge[4, 84] -> 
             RGBColor[
              0.9332654245531475, 0.8187437365493377, 0.5983805320654199], 
             UndirectedEdge[81, 383] -> 
             RGBColor[
              0.9664456244062938, 0.8936742034696683, 0.35970012297931814`], 
             UndirectedEdge[327, 335] -> 
             RGBColor[
              0.9892920785386408, 0.9740095022432101, 0.5431983933591982], 
             UndirectedEdge[11, 214] -> 
             RGBColor[
              0.9595545149102451, 0.8655378237892083, 0.5001778236407324], 
             UndirectedEdge[15, 35] -> 
             RGBColor[
              0.9732987157984913, 0.9258545646497665, 0.5397436413592358], 
             UndirectedEdge[151, 354] -> 
             RGBColor[
              0.9811243591338098, 0.9481719700127536, 0.5401240360591575], 
             UndirectedEdge[91, 192] -> 
             RGBColor[
              0.9505271089390591, 0.8355727316402706, 0.5214210719618251], 
             UndirectedEdge[44, 130] -> 
             RGBColor[
              0.9890081530750796, 0.9897226030660339, 0.8318268797413075], 
             UndirectedEdge[195, 356] -> 
             RGBColor[
              0.9661286568594197, 0.8939803396708232, 0.3407583231809378], 
             UndirectedEdge[226, 315] -> 
             RGBColor[
              0.9935982129063875, 0.9887155496637522, 0.5445831659896988], 
             UndirectedEdge[65, 206] -> 
             RGBColor[
              0.9633458581275638, 0.881004950736308, 0.37967533127368824`], 
             UndirectedEdge[287, 400] -> 
             RGBColor[
              0.9630051649765624, 0.8808993687948903, 0.5111794812886061], 
             UndirectedEdge[247, 319] -> 
             RGBColor[
              0.9737147322491461, 0.9603492615626421, 0.6597605325850855], 
             UndirectedEdge[55, 72] -> 
             RGBColor[
              0.9708188254576618, 0.9744288029461191, 0.7338595492369094], 
             UndirectedEdge[313, 329] -> 
             RGBColor[
              0.9656110618024385, 0.9083206582094616, 0.5944100523318978], 
             UndirectedEdge[5, 357] -> 
             RGBColor[
              0.9700427426234783, 0.9521085915314782, 0.6542963230939405], 
             UndirectedEdge[39, 328] -> 
             RGBColor[
              0.9887232299339803, 0.9728264159676447, 0.47842364455031716`], 
             UndirectedEdge[310, 384] -> 
             RGBColor[
              0.9323882898565512, 0.7696491300876827, 0.26445623484901254`], 
             UndirectedEdge[66, 344] -> 
             RGBColor[
              0.9872858040440373, 0.9823562641386668, 0.6566824164766609], 
             UndirectedEdge[271, 391] -> 
             RGBColor[
              0.9370340477745931, 0.7880680121256656, 0.26819432071982297`], 
             UndirectedEdge[203, 211] -> 
             RGBColor[
              0.9595119810184232, 0.8649368247137639, 0.4279588982451293], 
             UndirectedEdge[100, 203] -> 
             RGBColor[
              0.9266715455980652, 0.7469841440948808, 0.2598564082294004], 
             UndirectedEdge[323, 377] -> 
             RGBColor[
              0.8774155918674722, 0.5362546576336549, 0.21942490384646673`], 
             UndirectedEdge[351, 395] -> 
             RGBColor[
              0.9513307850037211, 0.8397175757806188, 0.3059057783341272], 
             UndirectedEdge[179, 209] -> 
             RGBColor[
              0.9625816026364755, 0.8967982561441017, 0.5923513994198599], 
             UndirectedEdge[283, 356] -> 
             RGBColor[
              0.9859521118539403, 0.9642753160616577, 0.3999270365839812], 
             UndirectedEdge[77, 80] -> 
             RGBColor[
              0.9940886586522852, 0.9897645635225563, 0.5979651587503771], 
             UndirectedEdge[200, 398] -> 
             RGBColor[
              0.9409210608622949, 0.7909395484569491, 0.3207003828969613], 
             UndirectedEdge[280, 368] -> 
             RGBColor[
              0.9286129316141035, 0.7306775369811915, 0.39890038426967617`], 
             UndirectedEdge[3, 390] -> 
             RGBColor[
              0.9889977637794767, 0.9873696192660639, 0.6612742657052744], 
             UndirectedEdge[64, 380] -> 
             RGBColor[
              0.9789925846629195, 0.9407991966716511, 0.37289058764329724`], 
             UndirectedEdge[139, 186] -> 
             RGBColor[
              0.8687070450318661, 0.4397414979750566, 0.209893812120748], 
             UndirectedEdge[160, 245] -> 
             RGBColor[
              0.9901315721429889, 0.9775936728628822, 0.4824842702756551], 
             UndirectedEdge[64, 360] -> 
             RGBColor[
              0.9775531000637552, 0.9359434771116129, 0.36729846179940084`], 
             UndirectedEdge[72, 337] -> 
             RGBColor[
              0.9728246942249038, 0.918571222436918, 0.38813983029565297`], 
             UndirectedEdge[11, 141] -> 
             RGBColor[
              0.9094596156883696, 0.6758657332680977, 0.2458583657769428], 
             UndirectedEdge[62, 223] -> 
             RGBColor[
              0.9909576512876312, 0.9891067927000936, 0.6961558614799324], 
             UndirectedEdge[351, 399] -> 
             RGBColor[
              0.9137235087647498, 0.6937882791757671, 0.24934183521525383`], 
             UndirectedEdge[205, 232] -> 
             RGBColor[
              0.9743534881280356, 0.924602095657664, 0.3911620482747691], 
             UndirectedEdge[175, 379] -> 
             RGBColor[
              0.9507152342031144, 0.8322720018750293, 0.3314772422702959], 
             UndirectedEdge[144, 339] -> 
             RGBColor[
              0.9782378216548626, 0.93784634258429, 0.40455501845940045`], 
             UndirectedEdge[66, 275] -> 
             RGBColor[
              0.9546140681049727, 0.8478120788238045, 0.3341846755110963], 
             UndirectedEdge[311, 346] -> 
             RGBColor[
              0.985557273312685, 0.9642814110115221, 0.565336547609354], 
             UndirectedEdge[81, 326] -> 
             RGBColor[
              0.9671456165464098, 0.8951714158773147, 0.4358899475802068], 
             UndirectedEdge[145, 335] -> 
             RGBColor[
              0.9532736957794683, 0.8442805887631807, 0.3238221633611478], 
             UndirectedEdge[24, 56] -> 
             RGBColor[
              0.9114404870038184, 0.6767948770846683, 0.2470940318389082], 
             UndirectedEdge[310, 319] -> 
             RGBColor[
              0.9665205061788542, 0.8977207569927286, 0.32968438244732845`], 
             UndirectedEdge[131, 303] -> 
             RGBColor[
              0.9908603655485971, 0.9816349645122838, 0.5822400085478817], 
             UndirectedEdge[146, 317] -> 
             RGBColor[
              0.9928704231091562, 0.9913197509809368, 0.7678190700422167], 
             UndirectedEdge[159, 321] -> 
             RGBColor[
              0.9899642579612218, 0.9901179770072284, 0.8159817474578043], 
             UndirectedEdge[339, 361] -> 
             RGBColor[
              0.9915826507654021, 0.982861584689021, 0.4563971595943261], 
             UndirectedEdge[60, 297] -> 
             RGBColor[
              0.9812954119922547, 0.9825217904113045, 0.7383078175847244], 
             UndirectedEdge[1, 368] -> 
             RGBColor[
              0.9747197706992512, 0.9252912300612339, 0.43661022974838015`], 
             UndirectedEdge[15, 106] -> 
             RGBColor[
              0.9672063312865126, 0.9739085371294293, 0.8886909019882498], 
             UndirectedEdge[144, 282] -> 
             RGBColor[
              0.9751660434854896, 0.927891374765585, 0.3580251977506495], 
             UndirectedEdge[333, 391] -> 
             RGBColor[
              0.9366765316375514, 0.7866505797774854, 0.2679066548439769], 
             UndirectedEdge[85, 238] -> 
             RGBColor[
              0.967464009112577, 0.9019106043020801, 0.3281042486190314], 
             UndirectedEdge[130, 135] -> 
             RGBColor[
              0.9689890672056183, 0.9200866907666454, 0.5916618677577357], 
             UndirectedEdge[194, 256] -> 
             RGBColor[
              0.9583695509008429, 0.8712328612735656, 0.29277399581077024`], 
             UndirectedEdge[129, 271] -> 
             RGBColor[
              0.959296960525396, 0.8641376579278919, 0.4246308236452132], 
             UndirectedEdge[12, 168] -> 
             RGBColor[
              0.9873596165584484, 0.9758504213202426, 0.6102800325821547], 
             UndirectedEdge[32, 271] -> 
             RGBColor[
              0.959091873846223, 0.863698998258585, 0.4023084042655063], 
             UndirectedEdge[227, 363] -> 
             RGBColor[
              0.9890206064099375, 0.9799440437712656, 0.6063005335897923], 
             UndirectedEdge[351, 355] -> 
             RGBColor[
              0.9401656107163365, 0.8004836156581895, 0.2707140497699795], 
             UndirectedEdge[70, 285] -> 
             RGBColor[
              0.9744364730463259, 0.9297160179041086, 0.5425085754437426], 
             UndirectedEdge[19, 107] -> 
             RGBColor[
              0.9555596561152502, 0.8574177421595706, 0.534731842893283], 
             UndirectedEdge[88, 359] -> 
             RGBColor[
              0.898280848856416, 0.6239712384427275, 0.23647185123247333`], 
             UndirectedEdge[128, 130] -> 
             RGBColor[
              0.9652667894773774, 0.905329099949693, 0.5886668357245053], 
             UndirectedEdge[72, 297] -> 
             RGBColor[
              0.9933492316979204, 0.988183004034703, 0.5174830979819734], 
             UndirectedEdge[125, 184] -> 
             RGBColor[
              0.9909304553560323, 0.9886770278519977, 0.6661846820463077], 
             UndirectedEdge[41, 63] -> 
             RGBColor[
              0.9913171893608788, 0.9887412411800689, 0.6528183105922399], 
             UndirectedEdge[67, 133] -> 
             RGBColor[
              0.9745773010753611, 0.9301060320167587, 0.5424679284383493], 
             UndirectedEdge[272, 308] -> 
             RGBColor[
              0.9925511555457542, 0.9855940653254175, 0.5056107793978951], 
             UndirectedEdge[199, 287] -> 
             RGBColor[
              0.9892104576023344, 0.989806261187043, 0.8284741701773628], 
             UndirectedEdge[60, 333] -> 
             RGBColor[
              0.9464471197407589, 0.8561210942251765, 0.5974393205819023], 
             UndirectedEdge[86, 325] -> 
             RGBColor[
              0.934561203119292, 0.7612744680676589, 0.49368101247938556`], 
             UndirectedEdge[77, 377] -> 
             RGBColor[
              0.9333084465665041, 0.7529988407853746, 0.35784649508944105`], 
             UndirectedEdge[62, 319] -> 
             RGBColor[
              0.9870588185491391, 0.967310674141165, 0.4635642540279339], 
             UndirectedEdge[52, 199] -> 
             RGBColor[
              0.9850393713746328, 0.9880814098398617, 0.8975998633955133], 
             UndirectedEdge[57, 376] -> 
             RGBColor[
              0.9645226985563657, 0.8909113051067473, 0.53195178418066], 
             UndirectedEdge[11, 161] -> 
             RGBColor[
              0.9447843125099136, 0.8161576981253502, 0.2881666722030297], 
             UndirectedEdge[155, 300] -> 
             RGBColor[
              0.9943554212865435, 0.9903351418233951, 0.6270006252212439], 
             UndirectedEdge[81, 275] -> 
             RGBColor[
              0.9298878578969396, 0.7597357505873794, 0.26244432860162753`], 
             UndirectedEdge[100, 266] -> 
             RGBColor[
              0.9611050680395326, 0.8715056884223507, 0.41428110949390945`], 
             UndirectedEdge[56, 266] -> 
             RGBColor[
              0.9320005279785537, 0.7463126904601864, 0.39035580426282046`], 
             UndirectedEdge[82, 257] -> 
             RGBColor[
              0.9424124137089183, 0.8028185469107094, 0.30675362340089396`], 
             UndirectedEdge[32, 259] -> 
             RGBColor[
              0.9737718604683472, 0.9219002533997565, 0.4141202660852409], 
             UndirectedEdge[261, 355] -> 
             RGBColor[
              0.9188633195950278, 0.7110870361118108, 0.2533181803702066], 
             UndirectedEdge[74, 179] -> 
             RGBColor[
              0.9884486133609326, 0.9893782900696073, 0.8360427119576135], 
             UndirectedEdge[100, 174] -> 
             RGBColor[
              0.9606278242454316, 0.870484912203518, 0.36233606771331134`], 
             UndirectedEdge[208, 388] -> 
             RGBColor[
              0.9257964788547868, 0.7435147960564878, 0.25915230898730224`], 
             UndirectedEdge[249, 299] -> 
             RGBColor[
              0.9642263273016359, 0.8909891433099355, 0.3155264661684325], 
             UndirectedEdge[58, 181] -> 
             RGBColor[
              0.8601667993403869, 0.40988913755444045`, 0.20315085370676786`],
              UndirectedEdge[271, 345] -> 
             RGBColor[
              0.9555033718392749, 0.863652823454938, 0.5662893613154332], 
             UndirectedEdge[20, 89] -> 
             RGBColor[
              0.9565451093400748, 0.8641098131484217, 0.29073179893241163`], 
             UndirectedEdge[174, 358] -> 
             RGBColor[
              0.9930662829683783, 0.9875778053127171, 0.4866858749284477], 
             UndirectedEdge[185, 274] -> 
             RGBColor[
              0.9631160347927117, 0.8803417385749607, 0.36481741378912114`], 
             UndirectedEdge[106, 314] -> 
             RGBColor[
              0.9684940398638795, 0.9730909371126379, 0.7692121766989533], 
             UndirectedEdge[73, 387] -> 
             RGBColor[
              0.9145604306465358, 0.694782972955698, 0.24989505396306552`], 
             UndirectedEdge[191, 261] -> 
             RGBColor[
              0.9339332287037452, 0.763492583661932, 0.30367906636793496`], 
             UndirectedEdge[135, 227] -> 
             RGBColor[
              0.9703614259807878, 0.9108704873194218, 0.34359836913778996`], 
             UndirectedEdge[102, 345] -> 
             RGBColor[
              0.9766068329682709, 0.9441236502594559, 0.5999216289151719], 
             UndirectedEdge[72, 108] -> 
             RGBColor[
              0.9937671355119506, 0.9890768580363564, 0.5629693491357579], 
             UndirectedEdge[7, 273] -> 
             RGBColor[
              0.9878791881635531, 0.9699682140598516, 0.47608438410769627`], 
             UndirectedEdge[111, 385] -> 
             RGBColor[
              0.989031003668905, 0.9742629677499226, 0.44574573848584953`], 
             UndirectedEdge[25, 187] -> 
             RGBColor[
              0.994241378254967, 0.9900912153103719, 0.6145877450261364], 
             UndirectedEdge[290, 338] -> 
             RGBColor[
              0.9793958091775936, 0.9423903841247212, 0.5337491457623089], 
             UndirectedEdge[133, 200] -> 
             RGBColor[
              0.9424999585619096, 0.8004661647843878, 0.5135639860865264], 
             UndirectedEdge[64, 88] -> 
             RGBColor[
              0.9243502956019136, 0.7199940534184391, 0.29564277755767576`], 
             UndirectedEdge[23, 92] -> 
             RGBColor[
              0.9555243587935112, 0.8533247083133093, 0.3250029780902453], 
             UndirectedEdge[38, 350] -> 
             RGBColor[
              0.9612826934220589, 0.8733705009834882, 0.5063689216565888], 
             UndirectedEdge[135, 224] -> 
             RGBColor[
              0.9591830278500129, 0.8731631256116203, 0.3001724032630872], 
             UndirectedEdge[329, 358] -> 
             RGBColor[
              0.9885478676025254, 0.9877426637176614, 0.711114606572842], 
             UndirectedEdge[4, 185] -> 
             RGBColor[
              0.9763272850777873, 0.9783370032445664, 0.7086660299269221], 
             UndirectedEdge[111, 199] -> 
             RGBColor[
              0.9849294414264809, 0.9744076997293956, 0.6475283926691964], 
             UndirectedEdge[138, 264] -> 
             RGBColor[
              0.9899986244112129, 0.9901321884174772, 0.8154122064439286], 
             UndirectedEdge[275, 344] -> 
             RGBColor[
              0.9522733016477443, 0.8534982150794664, 0.5766654774222084], 
             UndirectedEdge[300, 371] -> 
             RGBColor[
              0.9945145763659964, 0.9906755584452978, 0.6443236734283827], 
             UndirectedEdge[69, 273] -> 
             RGBColor[
              0.969521926163323, 0.9088524417361485, 0.33609886775615383`], 
             UndirectedEdge[65, 174] -> 
             RGBColor[
              0.9929927989812084, 0.9874206304945315, 0.47868759641561204`], 
             UndirectedEdge[217, 254] -> 
             RGBColor[
              0.9907925595161879, 0.9904605009865859, 0.8022546471163037], 
             UndirectedEdge[102, 378] -> 
             RGBColor[
              0.955749231380286, 0.8590701143965934, 0.2999049241642334], 
             UndirectedEdge[246, 326] -> 
             RGBColor[
              0.9551166393158104, 0.847480529577028, 0.4262111501440812], 
             UndirectedEdge[120, 242] -> 
             RGBColor[
              0.952350945675445, 0.8423739136923041, 0.31395670108375706`], 
             UndirectedEdge[25, 117] -> 
             RGBColor[
              0.994337241641825, 0.9902962574015859, 0.6250218830853805], 
             UndirectedEdge[44, 227] -> 
             RGBColor[
              0.9903805118502492, 0.9805063996188104, 0.5837633811213618], 
             UndirectedEdge[118, 206] -> 
             RGBColor[
              0.9612881971920579, 0.8820079281198143, 0.5485330990002217], 
             UndirectedEdge[151, 158] -> 
             RGBColor[
              0.9599652424662712, 0.8679161532814157, 0.5041780321414037], 
             UndirectedEdge[151, 308] -> 
             RGBColor[
              0.9925370887561753, 0.9866697868653402, 0.5844603355289], 
             UndirectedEdge[298, 390] -> 
             RGBColor[
              0.9422146698423561, 0.7941909668915692, 0.3315043201903466], 
             UndirectedEdge[62, 111] -> 
             RGBColor[
              0.9892737658718231, 0.9747822115549412, 0.47216890611885654`], 
             UndirectedEdge[131, 201] -> 
             RGBColor[
              0.9912422916300134, 0.990646476773241, 0.7948014221208126], 
             UndirectedEdge[291, 368] -> 
             RGBColor[
              0.9944915965433572, 0.990626406928289, 0.6418224615491328], 
             UndirectedEdge[35, 73] -> 
             RGBColor[
              0.947438589106405, 0.8293185513984336, 0.27656605890137287`], 
             UndirectedEdge[273, 293] -> 
             RGBColor[
              0.9830681224741655, 0.9692468372184573, 0.6480073694561614], 
             UndirectedEdge[4, 274] -> 
             RGBColor[
              0.9465818965574028, 0.8715391105949701, 0.6090952780178156], 
             UndirectedEdge[10, 337] -> 
             RGBColor[
              0.9458600783665639, 0.9017895614570431, 0.634204638426406], 
             UndirectedEdge[27, 265] -> 
             RGBColor[
              0.9792506176626357, 0.9410508184846202, 0.4265099291409494], 
             UndirectedEdge[262, 325] -> 
             RGBColor[
              0.9905736972921775, 0.9818112629474878, 0.5890287881310827], 
             UndirectedEdge[46, 337] -> 
             RGBColor[
              0.9404129909866825, 0.8014643959955225, 0.270913097742261], 
             UndirectedEdge[322, 327] -> 
             RGBColor[
              0.9882952373994838, 0.9887424188539062, 0.8058181597441338], 
             UndirectedEdge[59, 299] -> 
             RGBColor[
              0.9641338105287502, 0.890677062511021, 0.31516705597609845`], 
             UndirectedEdge[254, 369] -> 
             RGBColor[
              0.98870538700608, 0.9895974015157694, 0.836844497038102], 
             UndirectedEdge[262, 376] -> 
             RGBColor[
              0.9897825957295281, 0.9814841221209494, 0.6021393883293975], 
             UndirectedEdge[360, 389] -> 
             RGBColor[
              0.9455517547060661, 0.9307893398779631, 0.673374981107326], 
             UndirectedEdge[159, 381] -> 
             RGBColor[
              0.986488770376936, 0.9886807735751695, 0.8735795710029667], 
             UndirectedEdge[77, 302] -> 
             RGBColor[
              0.9777800092616648, 0.9362880740417953, 0.40396354785746164`], 
             UndirectedEdge[67, 398] -> 
             RGBColor[
              0.9729984033757464, 0.9205794156893199, 0.34960432524878415`], 
             UndirectedEdge[12, 100] -> 
             RGBColor[
              0.9589563288551348, 0.8718895588987616, 0.5423834597806294], 
             UndirectedEdge[329, 339] -> 
             RGBColor[
              0.9884889797189746, 0.9876167084892242, 0.704705023862217], 
             UndirectedEdge[1, 113] -> 
             RGBColor[
              0.901032483279097, 0.6102470941469006, 0.2376441855403579], 
             UndirectedEdge[232, 390] -> 
             RGBColor[
              0.9740423607672379, 0.9239366256927195, 0.3572977551074519], 
             UndirectedEdge[319, 384] -> 
             RGBColor[
              0.9463517342984817, 0.817758297331864, 0.31345611517045846`], 
             UndirectedEdge[342, 374] -> 
             RGBColor[
              0.951639785663226, 0.843218447522353, 0.2943020696450435], 
             UndirectedEdge[200, 320] -> 
             RGBColor[
              0.9435686880519494, 0.7993034708009412, 0.37921190466849675`], 
             UndirectedEdge[35, 231] -> 
             RGBColor[
              0.9252062009759796, 0.7385041915805197, 0.2585392231436123], 
             UndirectedEdge[96, 104] -> 
             RGBColor[
              0.9753454647209843, 0.9281264796359692, 0.3901949811440281], 
             UndirectedEdge[106, 197] -> 
             RGBColor[
              0.9583428216673489, 0.9395977392222541, 0.6660662492936855], 
             UndirectedEdge[41, 265] -> 
             RGBColor[
              0.9932716128157051, 0.988016985094117, 0.5090347616610337], 
             UndirectedEdge[52, 303] -> 
             RGBColor[
              0.9866369997101485, 0.979888494202534, 0.652232110211406], 
             UndirectedEdge[170, 208] -> 
             RGBColor[
              0.9154370220149683, 0.7024430017709572, 0.25081684684627925`], 
             UndirectedEdge[49, 355] -> 
             RGBColor[
              0.9646915458093015, 0.8909872290313017, 0.3255166173976662], 
             UndirectedEdge[140, 359] -> 
             RGBColor[
              0.9568131820604715, 0.8578984140162464, 0.32883174824064665`], 
             UndirectedEdge[20, 255] -> 
             RGBColor[
              0.9599948025445515, 0.876715216695028, 0.29908779154355836`], 
             UndirectedEdge[117, 362] -> 
             RGBColor[
              0.9716164725542007, 0.9129804178880807, 0.434543392199703], 
             UndirectedEdge[188, 293] -> 
             RGBColor[
              0.9704571930409797, 0.926707211053279, 0.5990162899824298], 
             UndirectedEdge[149, 155] -> 
             RGBColor[
              0.9846396291990482, 0.9583909379499589, 0.5187266587381272], 
             UndirectedEdge[7, 188] -> 
             RGBColor[
              0.9752682587303674, 0.9274285878946733, 0.42709330463396455`], 
             UndirectedEdge[120, 331] -> 
             RGBColor[
              0.9578146891602844, 0.8689744557560101, 0.5493487397831889], 
             UndirectedEdge[169, 218] -> 
             RGBColor[
              0.9915964362410505, 0.989450252383158, 0.6913342280617355], 
             UndirectedEdge[345, 350] -> 
             RGBColor[
              0.9901542065515712, 0.9901965256307941, 0.812833807744521], 
             UndirectedEdge[147, 217] -> 
             RGBColor[
              0.964012182437888, 0.8819562791159449, 0.497624744428797], 
             UndirectedEdge[141, 386] -> 
             RGBColor[
              0.9347336664959427, 0.7703700053613234, 0.295874518376336], 
             UndirectedEdge[128, 383] -> 
             RGBColor[
              0.9692418155121005, 0.9047601694287418, 0.3619500039780911], 
             UndirectedEdge[138, 394] -> 
             RGBColor[
              0.986345835008957, 0.9768422607338141, 0.6368342391695455], 
             UndirectedEdge[132, 300] -> 
             RGBColor[
              0.9928308481305987, 0.9900653891740796, 0.6784856506282511], 
             UndirectedEdge[103, 122] -> 
             RGBColor[
              0.9466742580419886, 0.8262882334262511, 0.27595106018578747`], 
             UndirectedEdge[147, 195] -> 
             RGBColor[
              0.9386366901765419, 0.7944219552004712, 0.26948384441528317`], 
             UndirectedEdge[123, 389] -> 
             RGBColor[
              0.9509252981063165, 0.948915563534998, 0.6942501825087746], 
             UndirectedEdge[93, 394] -> 
             RGBColor[
              0.9458197289456693, 0.946226770705243, 0.6957966786992029], 
             UndirectedEdge[199, 350] -> 
             RGBColor[
              0.9894075328700969, 0.9898877568748661, 0.8252081229760955], 
             UndirectedEdge[66, 158] -> 
             RGBColor[
              0.9577784377470648, 0.860357749991026, 0.3367308016024256], 
             UndirectedEdge[105, 215] -> 
             RGBColor[
              0.9421996547991676, 0.7926889200619459, 0.3959712512212533], 
             UndirectedEdge[253, 364] -> 
             RGBColor[
              0.9545320953011743, 0.9124255314050091, 0.6227592288340098], 
             UndirectedEdge[76, 78] -> 
             RGBColor[
              0.9667649421003394, 0.8958832138656498, 0.34449814276462165`], 
             UndirectedEdge[153, 358] -> 
             RGBColor[
              0.9386376009576068, 0.7770830094745615, 0.3674321746240157], 
             UndirectedEdge[54, 64] -> 
             RGBColor[
              0.984124424484656, 0.967932647456837, 0.6184152458855562], 
             UndirectedEdge[84, 125] -> 
             RGBColor[
              0.9477250302688703, 0.8287766910741381, 0.5402730675320432], 
             UndirectedEdge[195, 380] -> 
             RGBColor[
              0.9608000233521321, 0.8760056076280955, 0.32005758823312724`], 
             UndirectedEdge[81, 146] -> 
             RGBColor[
              0.9657376856161359, 0.8955941585265595, 0.5322728641325292], 
             UndirectedEdge[275, 317] -> 
             RGBColor[
              0.95702059538996, 0.8554613430417568, 0.49799053451131514`], 
             UndirectedEdge[25, 377] -> 
             RGBColor[
              0.9340404779160567, 0.7545645818223448, 0.43752358991441115`], 
             UndirectedEdge[180, 232] -> 
             RGBColor[
              0.9741933359340583, 0.9242595463086174, 0.3737304703051251], 
             UndirectedEdge[52, 333] -> 
             RGBColor[
              0.9544935158085828, 0.8619656317963627, 0.5768126556789019], 
             UndirectedEdge[97, 276] -> 
             RGBColor[0.985314795994726, 0.9688962439094253, 0.6019456439518],
              UndirectedEdge[51, 390] -> 
             RGBColor[
              0.9925473027903118, 0.9864677591887778, 0.4301980853203128], 
             UndirectedEdge[199, 393] -> 
             RGBColor[
              0.9596612341221384, 0.8827889054578844, 0.5826099813081694], 
             UndirectedEdge[169, 224] -> 
             RGBColor[
              0.9794402915805517, 0.941554858289608, 0.43879209034673955`], 
             UndirectedEdge[132, 268] -> 
             RGBColor[
              0.5853708720532378, 0.6481386002918078, 0.8594077015631583], 
             UndirectedEdge[162, 183] -> 
             RGBColor[
              0.9615674687048817, 0.87454587830614, 0.5068248107417724], 
             UndirectedEdge[15, 231] -> 
             RGBColor[
              0.9430490725570175, 0.8032544599084377, 0.5152659339499613], 
             UndirectedEdge[246, 248] -> 
             RGBColor[
              0.8977164797374313, 0.6250115671949057, 0.2361873071128785], 
             UndirectedEdge[44, 81] -> 
             RGBColor[
              0.9667117047887084, 0.8959969404855692, 0.5161308457621865], 
             UndirectedEdge[39, 197] -> 
             RGBColor[
              0.9785337017761663, 0.9392512769438068, 0.37110791428102285`], 
             UndirectedEdge[57, 86] -> 
             RGBColor[
              0.9070671408200333, 0.6612190334734238, 0.24366633386971714`], 
             UndirectedEdge[74, 209] -> 
             RGBColor[
              0.9675179525957359, 0.8989524926557753, 0.5156004946202027], 
             UndirectedEdge[115, 389] -> 
             RGBColor[
              0.9545905671525681, 0.963798879933323, 0.8835991029549577], 
             UndirectedEdge[157, 168] -> 
             RGBColor[
              0.9634649200524954, 0.8842089046538681, 0.334503841771522], 
             UndirectedEdge[224, 363] -> 
             RGBColor[
              0.9778422082791625, 0.9422366820634642, 0.5628745677150895], 
             UndirectedEdge[47, 279] -> 
             RGBColor[
              0.9499924129180803, 0.8283059693713578, 0.35455262755291966`], 
             UndirectedEdge[58, 352] -> 
             RGBColor[
              0.9431970250987062, 0.7970175568608255, 0.40580575628257565`], 
             UndirectedEdge[101, 161] -> 
             RGBColor[
              0.9708298969322924, 0.913264534266023, 0.3411800872040454], 
             UndirectedEdge[23, 98] -> 
             RGBColor[
              0.9308590123780462, 0.7635860544869207, 0.2632257422930514], 
             UndirectedEdge[37, 388] -> 
             RGBColor[
              0.9652041163843648, 0.900344732768124, 0.5654417301003993], 
             UndirectedEdge[13, 21] -> 
             RGBColor[
              0.988209628949293, 0.9711804043415686, 0.46907433353688477`], 
             UndirectedEdge[159, 375] -> 
             RGBColor[
              0.9740873808896716, 0.9355674374769508, 0.5897365310309666], 
             UndirectedEdge[130, 346] -> 
             RGBColor[
              0.9813313466069564, 0.9625338817173408, 0.6353710894710175], 
             UndirectedEdge[104, 225] -> 
             RGBColor[
              0.9853887041618191, 0.9620046845346668, 0.4292110698650444], 
             UndirectedEdge[226, 252] -> 
             RGBColor[
              0.9912679327271944, 0.9812311051372231, 0.5035464330865567], 
             UndirectedEdge[64, 283] -> 
             RGBColor[
              0.982394224932466, 0.9522737280439487, 0.3861053177446215], 
             UndirectedEdge[262, 284] -> 
             RGBColor[
              0.9908384268023089, 0.9802430872808239, 0.46269422670990223`], 
             UndirectedEdge[282, 313] -> 
             RGBColor[
              0.967212542984446, 0.8985320276137279, 0.3403053122171462], 
             UndirectedEdge[88, 360] -> 
             RGBColor[
              0.9211400644169359, 0.7091651898333822, 0.2831716356053285], 
             UndirectedEdge[210, 230] -> 
             RGBColor[
              0.9746338599866049, 0.9483615157392802, 0.6313018207140502], 
             UndirectedEdge[2, 138] -> 
             RGBColor[
              0.9898108469606706, 0.98816629965798, 0.6812691984557807], 
             UndirectedEdge[178, 367] -> 
             RGBColor[
              0.9719496651966357, 0.917041775555745, 0.3455301754605262], 
             UndirectedEdge[54, 123] -> 
             RGBColor[
              0.9862877366999286, 0.975230007528815, 0.6268193053346576], 
             UndirectedEdge[36, 95] -> 
             RGBColor[
              0.9511313054220317, 0.8362412128343052, 0.31973136493158283`], 
             UndirectedEdge[294, 301] -> 
             RGBColor[
              0.9635689142165282, 0.8948249434540843, 0.5688395539719897], 
             UndirectedEdge[60, 337] -> 
             RGBColor[
              0.960770874519238, 0.9129100088135196, 0.6089645498984039], 
             UndirectedEdge[251, 275] -> 
             RGBColor[
              0.9125389176913805, 0.8232101224884384, 0.6225070327290039], 
             UndirectedEdge[66, 311] -> 
             RGBColor[
              0.9914227352853324, 0.9840669915212259, 0.5881227597735377], 
             UndirectedEdge[110, 400] -> 
             RGBColor[
              0.9634870387032524, 0.8810986359644666, 0.5031935865881232], 
             UndirectedEdge[143, 151] -> 
             RGBColor[
              0.9940509936762117, 0.99078981092771, 0.6742461979125827], 
             UndirectedEdge[157, 206] -> 
             RGBColor[
              0.9376394183494052, 0.7904681047270103, 0.2686814160941905], 
             UndirectedEdge[226, 274] -> 
             RGBColor[
              0.9637273072523033, 0.8816491885569011, 0.4313506486793329], 
             UndirectedEdge[86, 265] -> 
             RGBColor[
              0.9349100812139923, 0.759886277714661, 0.3765055051836663], 
             UndirectedEdge[64, 389] -> 
             RGBColor[
              0.9487619858910439, 0.94161820346302, 0.6858461230596733], 
             UndirectedEdge[120, 356] -> 
             RGBColor[
              0.9574531517230493, 0.8595848527458243, 0.33377780810793595`], 
             UndirectedEdge[164, 279] -> 
             RGBColor[
              0.907117945467462, 0.6694606354280181, 0.24412312258233168`], 
             UndirectedEdge[24, 238] -> 
             RGBColor[
              0.9606311168388395, 0.8778928758819398, 0.306605166487342], 
             UndirectedEdge[213, 259] -> 
             RGBColor[
              0.9465738263472508, 0.9046193343580518, 0.634778936805485], 
             UndirectedEdge[73, 162] -> 
             RGBColor[
              0.9666326322483538, 0.8946275638903136, 0.5109003602235193], 
             UndirectedEdge[257, 356] -> 
             RGBColor[
              0.9830345776350865, 0.9544337880718526, 0.3885929670738414], 
             UndirectedEdge[6, 281] -> 
             RGBColor[
              0.9786855440459434, 0.9382249213817567, 0.502525420813305], 
             UndirectedEdge[176, 277] -> 
             RGBColor[
              0.9307869967874798, 0.763300536668098, 0.26316779685845854`], 
             UndirectedEdge[140, 263] -> 
             RGBColor[
              0.9855492022900381, 0.97479433398639, 0.6381583063473835], 
             UndirectedEdge[54, 161] -> 
             RGBColor[
              0.9761838268882554, 0.9411471472231987, 0.5875675236795721], 
             UndirectedEdge[7, 142] -> 
             RGBColor[
              0.9753314476428601, 0.9276417389339734, 0.4273387816267739], 
             UndirectedEdge[81, 311] -> 
             RGBColor[
              0.9666965250772993, 0.8959906632848008, 0.5163824128640689], 
             UndirectedEdge[204, 237] -> 
             RGBColor[
              0.9836538790701955, 0.9561518360415016, 0.42254609943798316`], 
             UndirectedEdge[134, 374] -> 
             RGBColor[
              0.933232099724207, 0.772994555029968, 0.2651351840752916], 
             UndirectedEdge[264, 279] -> 
             RGBColor[
              0.9502933562446156, 0.8305139084967789, 0.50101304276407], 
             UndirectedEdge[81, 344] -> 
             RGBColor[
              0.9625595938360041, 0.8942799359022418, 0.5849420695671921], 
             UndirectedEdge[287, 391] -> 
             RGBColor[
              0.9714878072191269, 0.9145302186136985, 0.5180048143501779], 
             UndirectedEdge[90, 228] -> 
             RGBColor[
              0.9938240336582184, 0.989562145192233, 0.59559135418591], 
             UndirectedEdge[222, 259] -> 
             RGBColor[
              0.9425670930811838, 0.8100046929882503, 0.27264633885077166`], 
             UndirectedEdge[143, 342] -> 
             RGBColor[
              0.9796930383205283, 0.942175258618413, 0.45951634547982967`], 
             UndirectedEdge[68, 262] -> 
             RGBColor[
              0.9554395366736663, 0.8514653844292586, 0.3328667070775873], 
             UndirectedEdge[73, 189] -> 
             RGBColor[
              0.9543472639632318, 0.8527731079933983, 0.3026238886264968], 
             UndirectedEdge[79, 176] -> 
             RGBColor[
              0.9501835306703056, 0.8402013300017475, 0.2787747033157469], 
             UndirectedEdge[14, 289] -> 
             RGBColor[
              0.9484839169748801, 0.8334629280620749, 0.27740715424134665`], 
             UndirectedEdge[126, 373] -> 
             RGBColor[
              0.9839733072069432, 0.9871946931174015, 0.8953002557011971], 
             UndirectedEdge[313, 361] -> 
             RGBColor[
              0.968704732848866, 0.9035655344092582, 0.3461021880640067], 
             UndirectedEdge[56, 203] -> 
             RGBColor[
              0.8975670055370863, 0.6217911461327165, 0.23593110299831138`], 
             UndirectedEdge[163, 240] -> 
             RGBColor[
              0.9697603507669628, 0.9059676395509435, 0.41256802054090214`], 
             UndirectedEdge[283, 380] -> 
             RGBColor[
              0.9806234783466525, 0.94630058401893, 0.3792263016361706], 
             UndirectedEdge[165, 318] -> 
             RGBColor[
              0.9604821884663548, 0.8692501440434548, 0.4011185849874861], 
             UndirectedEdge[184, 185] -> 
             RGBColor[
              0.9930049878756183, 0.9874467013071879, 0.48001428235099], 
             UndirectedEdge[123, 364] -> 
             RGBColor[
              0.9695316677698367, 0.9632805317094788, 0.679686482133954], 
             UndirectedEdge[24, 341] -> 
             RGBColor[
              0.9541025937760907, 0.8557391092658229, 0.2819280734828959], 
             UndirectedEdge[10, 364] -> 
             RGBColor[
              0.946596350290928, 0.9596922260042007, 0.9752826284416077], 
             UndirectedEdge[59, 132] -> 
             RGBColor[
              0.9792656002322413, 0.9451360669553988, 0.555257275228668], 
             UndirectedEdge[110, 309] -> 
             RGBColor[
              0.9604014060653685, 0.8688651307813794, 0.5007108141385749], 
             UndirectedEdge[28, 50] -> 
             RGBColor[
              0.9491607445428049, 0.825271682179396, 0.3383204643412696], 
             UndirectedEdge[120, 147] -> 
             RGBColor[
              0.9299611850401717, 0.7600264682754723, 0.26250332934228127`], 
             UndirectedEdge[322, 335] -> 
             RGBColor[
              0.9826015141751704, 0.9710684591759219, 0.653402903282146], 
             UndirectedEdge[9, 198] -> 
             RGBColor[
              0.950583738053979, 0.8402122377846679, 0.28730341449027935`], 
             UndirectedEdge[214, 257] -> 
             RGBColor[
              0.9863062955175432, 0.9650268254843635, 0.5559346774662003], 
             UndirectedEdge[190, 274] -> 
             RGBColor[
              0.9638355119991063, 0.8818806275691349, 0.44312806760655343`], 
             UndirectedEdge[18, 198] -> 
             RGBColor[
              0.9687937275143614, 0.9063960567040275, 0.33326995351371425`], 
             UndirectedEdge[280, 291] -> 
             RGBColor[
              0.9290869286667618, 0.7316913687483741, 0.4504920382808014], 
             UndirectedEdge[156, 179] -> 
             RGBColor[
              0.9889063205637789, 0.9887207313854194, 0.7669015450451815], 
             UndirectedEdge[76, 96] -> 
             RGBColor[
              0.9505715573740346, 0.8412591247962775, 0.28158990096703873`], 
             UndirectedEdge[143, 158] -> 
             RGBColor[
              0.9600160562028044, 0.8669190297453414, 0.42932815441048133`], 
             UndirectedEdge[252, 274] -> 
             RGBColor[
              0.9609112717472182, 0.8731257625056865, 0.3374424462872383], 
             UndirectedEdge[272, 348] -> 
             RGBColor[
              0.9807764359975504, 0.9458751714537008, 0.4598682174223313], 
             UndirectedEdge[51, 232] -> 
             RGBColor[
              0.9740301905780944, 0.9239105948887365, 0.35597310512488334`], 
             UndirectedEdge[66, 317] -> 
             RGBColor[
              0.9920330977862528, 0.9843193921009572, 0.5780074735657676], 
             UndirectedEdge[258, 264] -> 
             RGBColor[
              0.9724292719574525, 0.9182754379415419, 0.5188241201433412], 
             UndirectedEdge[17, 223] -> 
             RGBColor[
              0.9760356721321437, 0.9809685902135054, 0.8950231010610694], 
             UndirectedEdge[46, 271] -> 
             RGBColor[
              0.9264467523452451, 0.7460929137553596, 0.2596755343016055], 
             UndirectedEdge[93, 201] -> 
             RGBColor[
              0.9471902080473771, 0.9585729044269302, 0.9121984340833922], 
             UndirectedEdge[232, 373] -> 
             RGBColor[
              0.9685167390095747, 0.9235544548606482, 0.5996293491948963], 
             UndirectedEdge[182, 208] -> 
             RGBColor[
              0.9508896071885676, 0.8315952848456554, 0.3711191892203762], 
             UndirectedEdge[10, 391] -> 
             RGBColor[
              0.9443595287709272, 0.8958403823388545, 0.6329972609993308], 
             UndirectedEdge[284, 366] -> 
             RGBColor[
              0.9295439597860575, 0.7357220873553704, 0.3629390434446985], 
             UndirectedEdge[154, 387] -> 
             RGBColor[
              0.9379052967957517, 0.7902788613333065, 0.5547570129019144], 
             UndirectedEdge[135, 363] -> 
             RGBColor[
              0.9718702681824442, 0.9212781414140506, 0.5439129112626204], 
             UndirectedEdge[37, 269] -> 
             RGBColor[
              0.9782482341142967, 0.9827594859784903, 0.8975818085841534], 
             UndirectedEdge[201, 281] -> 
             RGBColor[
              0.9756396533407286, 0.9372121579240196, 0.5709427854718533], 
             UndirectedEdge[302, 377] -> 
             RGBColor[
              0.9179035975656236, 0.7014554889500308, 0.26221797901026556`], 
             UndirectedEdge[179, 286] -> 
             RGBColor[
              0.9760402671785213, 0.9464297961743836, 0.6225938570566019], 
             UndirectedEdge[108, 325] -> 
             RGBColor[
              0.9935967905020173, 0.9908469126052071, 0.6995770809298887], 
             UndirectedEdge[279, 299] -> 
             RGBColor[
              0.9343345550834778, 0.7757129135614391, 0.2746285436017546], 
             UndirectedEdge[196, 332] -> 
             RGBColor[
              0.9435060118403618, 0.8390477545167713, 0.5908732883237868], 
             UndirectedEdge[31, 224] -> 
             RGBColor[
              0.9754393236548476, 0.9288132129460647, 0.35908683960397564`], 
             UndirectedEdge[200, 296] -> 
             RGBColor[
              0.9253798391675876, 0.7385153584283171, 0.2603256713264803], 
             UndirectedEdge[170, 221] -> 
             RGBColor[
              0.9256571853772668, 0.7429625438349206, 0.25904023018565137`], 
             UndirectedEdge[198, 206] -> 
             RGBColor[
              0.9474251836701475, 0.8276896221786296, 0.28476196749224814`], 
             UndirectedEdge[36, 361] -> 
             RGBColor[
              0.9860322554372567, 0.9645456591867925, 0.40023837927132005`], 
             UndirectedEdge[132, 180] -> 
             RGBColor[
              0.9923380837097859, 0.9890114159040861, 0.6248512844122721], 
             UndirectedEdge[127, 312] -> 
             RGBColor[
              0.9429352537233658, 0.8158371384268546, 0.5704193046240547], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.9567881762142767, 0.8658985131313442, 0.2866306537710125], 
             UndirectedEdge[67, 75] -> 
             RGBColor[
              0.9764178528825294, 0.930594187926443, 0.4921239431045385], 
             UndirectedEdge[110, 287] -> 
             RGBColor[
              0.9939577513445501, 0.9917693891493333, 0.7497992272664695], 
             UndirectedEdge[88, 233] -> 
             RGBColor[
              0.9306947331722559, 0.7408095113138427, 0.37010360451444646`], 
             UndirectedEdge[168, 216] -> 
             RGBColor[
              0.9897128669006596, 0.975903979531145, 0.5044374597268846], 
             UndirectedEdge[1, 291] -> 
             RGBColor[
              0.9751937677519094, 0.9263050618284165, 0.48820188375950546`], 
             UndirectedEdge[115, 214] -> 
             RGBColor[
              0.9934215173141883, 0.9915476425971927, 0.7586860128787511], 
             UndirectedEdge[233, 256] -> 
             RGBColor[
              0.9749943014191176, 0.9267262286746136, 0.40717189729605635`], 
             UndirectedEdge[4, 252] -> 
             RGBColor[
              0.9741225220322939, 0.9711210271752921, 0.6812910624250392], 
             UndirectedEdge[91, 399] -> 
             RGBColor[
              0.9038391007818058, 0.6545998953070964, 0.2413886085353019], 
             UndirectedEdge[76, 269] -> 
             RGBColor[
              0.9563085364563152, 0.8951841100118361, 0.6053475019169896], 
             UndirectedEdge[91, 172] -> 
             RGBColor[
              0.913336635515972, 0.8085023482661136, 0.6191472170628318], 
             UndirectedEdge[165, 184] -> 
             RGBColor[
              0.9933606034661874, 0.9882073270971636, 0.5187208447794035], 
             UndirectedEdge[60, 139] -> 
             RGBColor[
              0.8964640521402818, 0.580522170159571, 0.5538987727857805], 
             UndirectedEdge[356, 359] -> 
             RGBColor[
              0.9582517714247095, 0.8627511137386672, 0.33442039626590536`], 
             UndirectedEdge[228, 305] -> 
             RGBColor[
              0.9925634621437915, 0.9890408664758072, 0.6164822864344667], 
             UndirectedEdge[141, 209] -> 
             RGBColor[
              0.9179418421420614, 0.7094949346225791, 0.25268336428502775`], 
             UndirectedEdge[171, 348] -> 
             RGBColor[
              0.9779547688719865, 0.9372984003180984, 0.3688588692705901], 
             UndirectedEdge[10, 60] -> 
             RGBColor[
              0.9541301168741347, 0.9653108967865457, 0.9625299267372562], 
             UndirectedEdge[234, 298] -> 
             RGBColor[
              0.9411156610325491, 0.7960851860647212, 0.5204425318632868], 
             UndirectedEdge[323, 388] -> 
             RGBColor[
              0.9121865428419909, 0.6829803762058679, 0.2478612881615798], 
             UndirectedEdge[294, 329] -> 
             RGBColor[
              0.985353759463028, 0.9881489036759177, 0.8895901471499015], 
             UndirectedEdge[211, 238] -> 
             RGBColor[
              0.9813296225859638, 0.9477068514046618, 0.4649379748802672], 
             UndirectedEdge[31, 99] -> 
             RGBColor[
              0.9785932540187885, 0.939452160641703, 0.37133926349811275`], 
             UndirectedEdge[111, 319] -> 
             RGBColor[
              0.9826988979434688, 0.9533014616506861, 0.3872889148596971], 
             UndirectedEdge[258, 394] -> 
             RGBColor[
              0.9687764825551967, 0.9049855102578788, 0.340246152868958], 
             UndirectedEdge[101, 364] -> 
             RGBColor[
              0.9653755188345241, 0.9492608654404924, 0.663540628343134], 
             UndirectedEdge[225, 349] -> 
             RGBColor[
              0.9646345316663294, 0.8910742388837809, 0.3238403627048436], 
             UndirectedEdge[118, 386] -> 
             RGBColor[
              0.9821261577855734, 0.9589245807537347, 0.5949798692849638], 
             UndirectedEdge[95, 326] -> 
             RGBColor[
              0.9571591227188097, 0.8555782956526732, 0.42785458023338174`], 
             UndirectedEdge[228, 382] -> 
             RGBColor[
              0.988605557942293, 0.9730504117158296, 0.4251670202508624], 
             UndirectedEdge[120, 255] -> 
             RGBColor[
              0.9433067707507008, 0.8118657879978836, 0.27882178935024937`], 
             UndirectedEdge[222, 292] -> 
             RGBColor[
              0.9572957239389284, 0.8760453750918705, 0.5882564274483498], 
             UndirectedEdge[325, 397] -> 
             RGBColor[
              0.9764776544776352, 0.93426200062579, 0.5342683236109111], 
             UndirectedEdge[155, 299] -> 
             RGBColor[
              0.9782075275589295, 0.9366939487885535, 0.49373915846673977`], 
             UndirectedEdge[17, 99] -> 
             RGBColor[
              0.9676262784205656, 0.943957290362277, 0.6449088159765989], 
             UndirectedEdge[60, 105] -> 
             RGBColor[
              0.9813971730571072, 0.9827394470394021, 0.7493838814974203], 
             UndirectedEdge[229, 340] -> 
             RGBColor[
              0.9888653146735316, 0.9879698893913609, 0.7110838729315774], 
             UndirectedEdge[297, 375] -> 
             RGBColor[
              0.9776237131578083, 0.935535551755037, 0.42251415312666984`], 
             UndirectedEdge[155, 249] -> 
             RGBColor[
              0.9808826901610718, 0.9457179004036287, 0.5041316600139948], 
             UndirectedEdge[143, 348] -> 
             RGBColor[
              0.9808131829445044, 0.9459537694575493, 0.46386789582241383`], 
             UndirectedEdge[175, 294] -> 
             RGBColor[
              0.9883986760404068, 0.9832293196035193, 0.6410928809762653], 
             UndirectedEdge[19, 181] -> 
             RGBColor[
              0.8744516664937559, 0.4699093476321319, 0.21481992008415468`], 
             UndirectedEdge[153, 294] -> 
             RGBColor[
              0.9354434928181092, 0.7774892494328178, 0.5459077152010752], 
             UndirectedEdge[68, 376] -> 
             RGBColor[
              0.9568826002371135, 0.8606208611827533, 0.5258043817368331], 
             UndirectedEdge[317, 354] -> 
             RGBColor[
              0.9813440816995905, 0.9482628309403163, 0.5364826645203983], 
             UndirectedEdge[2, 254] -> 
             RGBColor[
              0.9897745690016051, 0.9881512977896054, 0.6818704181218418], 
             UndirectedEdge[243, 311] -> 
             RGBColor[
              0.9935523824108181, 0.9916017586777288, 0.7565172395595807], 
             UndirectedEdge[23, 143] -> 
             RGBColor[
              0.9609806572989112, 0.8707433516571443, 0.43010429509450665`], 
             UndirectedEdge[20, 64] -> 
             RGBColor[
              0.9705832965954257, 0.9124326934252598, 0.34022209146188526`], 
             UndirectedEdge[75, 296] -> 
             RGBColor[
              0.9760049223945253, 0.9292012764297165, 0.49051978613402275`], 
             UndirectedEdge[146, 227] -> 
             RGBColor[
              0.9894064926776767, 0.9801036176598006, 0.5999053994917044], 
             UndirectedEdge[160, 238] -> 
             RGBColor[
              0.9775358371326492, 0.9358852451914637, 0.36723139857188547`], 
             UndirectedEdge[75, 178] -> 
             RGBColor[
              0.9782066618027556, 0.9366282604466745, 0.49907312797139797`], 
             UndirectedEdge[95, 166] -> 
             RGBColor[
              0.9370872711451971, 0.8432626167696019, 0.6087227138354592], 
             UndirectedEdge[25, 309] -> 
             RGBColor[
              0.9605060540105737, 0.8683622565974642, 0.45927727464887025`], 
             UndirectedEdge[166, 326] -> 
             RGBColor[
              0.9740452314340078, 0.9775096814614033, 0.7819271080158797], 
             UndirectedEdge[158, 308] -> 
             RGBColor[
              0.958502151282768, 0.8627990056829717, 0.33954229202679864`], 
             UndirectedEdge[229, 343] -> 
             RGBColor[
              0.9874873430353817, 0.9890937090315834, 0.857030637829323], 
             UndirectedEdge[229, 294] -> 
             RGBColor[
              0.985651825547823, 0.9883346753798302, 0.8874499127651572], 
             UndirectedEdge[64, 257] -> 
             RGBColor[
              0.9794766907136121, 0.9424322000541436, 0.3747712482344817], 
             UndirectedEdge[56, 65] -> 
             RGBColor[
              0.9316635320663615, 0.7455918902795209, 0.35367587891840524`], 
             UndirectedEdge[170, 192] -> 
             RGBColor[
              0.9566983052596962, 0.8600394686223297, 0.526386561378005], 
             UndirectedEdge[133, 347] -> 
             RGBColor[
              0.982964874919663, 0.9856374918546441, 0.8609526135501389], 
             UndirectedEdge[223, 393] -> 
             RGBColor[
              0.9613295233776185, 0.8834787859381037, 0.5549621109506686], 
             UndirectedEdge[116, 338] -> 
             RGBColor[
              0.9932576315724242, 0.9891215820022025, 0.5899792630778911], 
             UndirectedEdge[32, 71] -> 
             RGBColor[
              0.9919464394505517, 0.9838090597489424, 0.4815914937420368], 
             UndirectedEdge[95, 361] -> 
             RGBColor[
              0.9551021124452239, 0.8496356773133591, 0.33515720039269836`], 
             UndirectedEdge[247, 292] -> 
             RGBColor[
              0.9751655537830187, 0.9809990911908246, 0.9269224189711325], 
             UndirectedEdge[337, 391] -> 
             RGBColor[
              0.9510002864160305, 0.8434394943658285, 0.2794318841604785], 
             UndirectedEdge[181, 238] -> 
             RGBColor[
              0.8982174763943018, 0.560403212574783, 0.2533665386894167], 
             UndirectedEdge[97, 246] -> 
             RGBColor[
              0.9528319735988412, 0.847540719860918, 0.5371238310288404], 
             UndirectedEdge[62, 247] -> 
             RGBColor[
              0.9802896001775006, 0.9818300114668972, 0.7446405238442451], 
             UndirectedEdge[207, 280] -> 
             RGBColor[
              0.895766704849603, 0.6126413086541523, 0.2343784474491566], 
             UndirectedEdge[145, 221] -> 
             RGBColor[
              0.9260041919296398, 0.7443383091820008, 0.2593194398029814], 
             UndirectedEdge[10, 334] -> 
             RGBColor[
              0.9056451062517644, 0.7330880361311619, 0.6013675851749383], 
             UndirectedEdge[25, 78] -> 
             RGBColor[
              0.9923119522645314, 0.9844041574587381, 0.5372506935609102], 
             UndirectedEdge[46, 139] -> 
             RGBColor[
              0.8761061686077263, 0.46907655734157394`, 0.21584732062963752`],
              UndirectedEdge[224, 383] -> 
             RGBColor[
              0.9789360333370597, 0.9404763008951078, 0.3839066924637906], 
             UndirectedEdge[138, 164] -> 
             RGBColor[
              0.9468232136340593, 0.8290789153487166, 0.5585222862621904], 
             UndirectedEdge[53, 93] -> 
             RGBColor[
              0.9498107479098815, 0.9596565650048783, 0.8687693068219235], 
             UndirectedEdge[31, 199] -> 
             RGBColor[
              0.9853343584748865, 0.9757735800127121, 0.649101418940084], 
             UndirectedEdge[98, 342] -> 
             RGBColor[
              0.9495713933996633, 0.8350179614481894, 0.29263779267837453`], 
             UndirectedEdge[141, 304] -> 
             RGBColor[
              0.9398335870386245, 0.8004310939685786, 0.5622551192491688], 
             UndirectedEdge[32, 105] -> 
             RGBColor[
              0.9936844110255295, 0.9888999187246303, 0.5539652993051782], 
             UndirectedEdge[216, 329] -> 
             RGBColor[
              0.9890158906853614, 0.988743717767455, 0.7620560308358713], 
             UndirectedEdge[164, 264] -> 
             RGBColor[
              0.9502933562446156, 0.8305139084967789, 0.50101304276407], 
             UndirectedEdge[118, 196] -> 
             RGBColor[
              0.9807109121238242, 0.9843330821127056, 0.8816325447441606], 
             UndirectedEdge[75, 398] -> 
             RGBColor[
              0.9915461440892326, 0.9816254664583486, 0.5508944977045037], 
             UndirectedEdge[45, 48] -> 
             RGBColor[
              0.9556792737316668, 0.9636589301625071, 0.8226581667144282], 
             UndirectedEdge[248, 275] -> 
             RGBColor[
              0.899459164779771, 0.6319207326724171, 0.23758951240402032`], 
             UndirectedEdge[200, 347] -> 
             RGBColor[
              0.9341803434998934, 0.7954397297629292, 0.5804145134087857], 
             UndirectedEdge[33, 58] -> 
             RGBColor[
              0.9378602649649423, 0.7798900174087846, 0.31070330290784937`], 
             UndirectedEdge[134, 240] -> 
             RGBColor[
              0.9610576515024745, 0.871464336969863, 0.4055656244340884], 
             UndirectedEdge[267, 344] -> 
             RGBColor[
              0.9848373531765814, 0.9740970644391356, 0.6471706472077439], 
             UndirectedEdge[141, 286] -> 
             RGBColor[
              0.9314005066841072, 0.759126474652861, 0.2829258219217696], 
             UndirectedEdge[33, 209] -> 
             RGBColor[
              0.9624487744846726, 0.8807607359838192, 0.3306629217907813], 
             UndirectedEdge[47, 155] -> 
             RGBColor[
              0.993865385393532, 0.9892870045984721, 0.5736632424179049], 
             UndirectedEdge[153, 229] -> 
             RGBColor[
              0.9342035198074705, 0.7769764887270658, 0.566457276934647], 
             UndirectedEdge[64, 161] -> 
             RGBColor[
              0.9728227336523323, 0.9199868404630316, 0.3489218815457641], 
             UndirectedEdge[3, 293] -> 
             RGBColor[
              0.9848127266798368, 0.9879872542769403, 0.9013365996471618], 
             UndirectedEdge[133, 178] -> 
             RGBColor[
              0.9763661099955875, 0.9361401045369899, 0.5494171133052088], 
             UndirectedEdge[113, 162] -> 
             RGBColor[
              0.9202434775758708, 0.675623312319024, 0.4719921261595712], 
             UndirectedEdge[313, 358] -> 
             RGBColor[
              0.97034320903737, 0.9086129506608699, 0.3932447156365221], 
             UndirectedEdge[259, 292] -> 
             RGBColor[
              0.9686569628307855, 0.9210889013896546, 0.59739794694329], 
             UndirectedEdge[4, 165] -> 
             RGBColor[
              0.9766829006683564, 0.9790976290345421, 0.7473725923553356], 
             UndirectedEdge[247, 385] -> 
             RGBColor[
              0.9800468379745821, 0.9813107676618786, 0.718217356211238], 
             UndirectedEdge[38, 243] -> 
             RGBColor[
              0.9612906117214849, 0.8733737754037919, 0.5062376949431973], 
             UndirectedEdge[265, 381] -> 
             RGBColor[
              0.9900029564700598, 0.9886015194242248, 0.7039467186188603], 
             UndirectedEdge[15, 369] -> 
             RGBColor[
              0.9910482177545816, 0.9905662222382787, 0.7980177284838088], 
             UndirectedEdge[30, 358] -> 
             RGBColor[
              0.9941917350461458, 0.9899850335064019, 0.6091843881083293], 
             UndirectedEdge[133, 330] -> 
             RGBColor[
              0.9878481712594317, 0.9892429207750906, 0.8510507803633043], 
             UndirectedEdge[223, 292] -> 
             RGBColor[
              0.9858336048931495, 0.988275872424021, 0.8784377566068198], 
             UndirectedEdge[44, 326] -> 
             RGBColor[
              0.9936831712499188, 0.9906508849527291, 0.681299872595782], 
             UndirectedEdge[123, 356] -> 
             RGBColor[
              0.9864845303854799, 0.9660712887863567, 0.4019953820402092], 
             UndirectedEdge[35, 154] -> 
             RGBColor[
              0.9707834552556209, 0.924814439776042, 0.5814280178402217], 
             UndirectedEdge[146, 151] -> 
             RGBColor[
              0.9926507005433755, 0.9912288900533742, 0.7714604415809759], 
             UndirectedEdge[111, 287] -> 
             RGBColor[
              0.9891948614420064, 0.9761715605221097, 0.576839344458786], 
             UndirectedEdge[42, 133] -> 
             RGBColor[
              0.9928427972640654, 0.99130832698404, 0.7682769017887647], 
             UndirectedEdge[40, 103] -> 
             RGBColor[
              0.9377324557552833, 0.790836967038439, 0.26875627617482856`], 
             UndirectedEdge[219, 260] -> 
             RGBColor[
              0.9073282258171773, 0.572656980848629, 0.41715925269216364`], 
             UndirectedEdge[151, 186] -> 
             RGBColor[
              0.953763539374828, 0.8433284671188888, 0.49918799626134713`], 
             UndirectedEdge[8, 76] -> 
             RGBColor[
              0.9294558910712274, 0.7580231460678419, 0.2620967579540949], 
             UndirectedEdge[124, 167] -> 
             RGBColor[
              0.9874804193304053, 0.9694306560434346, 0.40586422253339804`], 
             UndirectedEdge[162, 291] -> 
             RGBColor[
              0.9944047620486831, 0.9916812800005399, 0.7225498243787187], 
             UndirectedEdge[242, 255] -> 
             RGBColor[
              0.9686305180717285, 0.9058455129306267, 0.33263591564860207`], 
             UndirectedEdge[182, 323] -> 
             RGBColor[
              0.9372796711757717, 0.7710608649950355, 0.35982816839465376`], 
             UndirectedEdge[138, 149] -> 
             RGBColor[
              0.9804719248901939, 0.957028182643543, 0.6140152075530007], 
             UndirectedEdge[199, 353] -> 
             RGBColor[
              0.9896923313290245, 0.9900055283566191, 0.8204882754768799], 
             UndirectedEdge[34, 381] -> 
             RGBColor[
              0.9879821758092704, 0.9892983351002087, 0.8488299781798188], 
             UndirectedEdge[148, 305] -> 
             RGBColor[
              0.973715103924431, 0.925378609156974, 0.5296713806003828], 
             UndirectedEdge[97, 383] -> 
             RGBColor[
              0.991132425150535, 0.9883883382207181, 0.6357818306976728], 
             UndirectedEdge[154, 207] -> 
             RGBColor[
              0.9572181061277432, 0.8710323508686318, 0.5705130195122625], 
             UndirectedEdge[272, 375] -> 
             RGBColor[
              0.9778629144383764, 0.9360471791072129, 0.4485497363373202], 
             UndirectedEdge[25, 323] -> 
             RGBColor[
              0.938024034913066, 0.7726529837623894, 0.4408475675186329], 
             UndirectedEdge[236, 334] -> 
             RGBColor[
              0.9321833040093314, 0.7515338588760472, 0.4961543026494447], 
             UndirectedEdge[23, 346] -> 
             RGBColor[
              0.9528775768705242, 0.8443964913931252, 0.31472073012226726`], 
             UndirectedEdge[23, 151] -> 
             RGBColor[
              0.9609298435623781, 0.8717404751932186, 0.504954172825429], 
             UndirectedEdge[250, 381] -> 
             RGBColor[
              0.9446001809255811, 0.8198755476267805, 0.5569557396731115], 
             UndirectedEdge[230, 264] -> 
             RGBColor[
              0.9859496882900594, 0.9875006730037837, 0.8396492470761184], 
             UndirectedEdge[60, 68] -> 
             RGBColor[
              0.9457902271040302, 0.8535167338170422, 0.5969107693471385], 
             UndirectedEdge[50, 258] -> 
             RGBColor[
              0.9719842792251461, 0.9157593917028055, 0.3566848160838957], 
             UndirectedEdge[121, 298] -> 
             RGBColor[
              0.9429378848740813, 0.7957378507161732, 0.41022181322782375`], 
             UndirectedEdge[95, 382] -> 
             RGBColor[
              0.9523123755669551, 0.8402252397615892, 0.32431959941822786`], 
             UndirectedEdge[42, 200] -> 
             RGBColor[
              0.944058265844296, 0.8011105648923251, 0.48773880164741157`], 
             UndirectedEdge[254, 314] -> 
             RGBColor[
              0.9900864652083944, 0.9888184122383838, 0.7158183954305816], 
             UndirectedEdge[95, 305] -> 
             RGBColor[
              0.9562702797684537, 0.8562156945215668, 0.5156348656018321], 
             UndirectedEdge[321, 381] -> 
             RGBColor[
              0.9899757819167305, 0.9901227424589834, 0.8157907656919829], 
             UndirectedEdge[116, 209] -> 
             RGBColor[
              0.9670996422120359, 0.8964212209329294, 0.3511102195660887], 
             UndirectedEdge[364, 366] -> 
             RGBColor[
              0.9098619889969868, 0.7242403240474398, 0.5862432943788508], 
             UndirectedEdge[58, 156] -> 
             RGBColor[
              0.943387150278852, 0.797424215396553, 0.4264997088248388], 
             UndirectedEdge[118, 179] -> 
             RGBColor[
              0.9862649941968888, 0.9884753074288224, 0.8722309325310663], 
             UndirectedEdge[149, 328] -> 
             RGBColor[
              0.9841044962182806, 0.9572463426143405, 0.46048073623949853`], 
             UndirectedEdge[215, 227] -> 
             RGBColor[
              0.9390788203596053, 0.7829333399323734, 0.31822528456094096`], 
             UndirectedEdge[70, 177] -> 
             RGBColor[
              0.9692485484713544, 0.9270156463878264, 0.6036304723348609], 
             UndirectedEdge[383, 393] -> 
             RGBColor[
              0.9635472646924281, 0.8821831730253109, 0.3573680347202954], 
             UndirectedEdge[14, 201] -> 
             RGBColor[
              0.9708196020680647, 0.9199984390656869, 0.5571891305168666], 
             UndirectedEdge[5, 368] -> 
             RGBColor[
              0.9851566782855685, 0.9606573695759096, 0.47632236463826055`], 
             UndirectedEdge[214, 310] -> 
             RGBColor[
              0.9734898012967593, 0.9207865906528283, 0.511390482170534], 
             UndirectedEdge[35, 280] -> 
             RGBColor[
              0.9093320539774807, 0.6664233975615625, 0.24529344577711576`], 
             UndirectedEdge[243, 275] -> 
             RGBColor[
              0.9567437152304583, 0.8553468459803074, 0.5025791552971394], 
             UndirectedEdge[131, 391] -> 
             RGBColor[
              0.9715400868298739, 0.9145518375762671, 0.5171384059048041], 
             UndirectedEdge[2, 314] -> 
             RGBColor[
              0.9934051083274738, 0.9883025184953234, 0.5235649242782521], 
             UndirectedEdge[282, 361] -> 
             RGBColor[
              0.988510872596029, 0.972906616870316, 0.40986733888557514`], 
             UndirectedEdge[110, 269] -> 
             RGBColor[
              0.9817508986753021, 0.9842079277888394, 0.8395335922029827], 
             UndirectedEdge[193, 360] -> 
             RGBColor[
              0.9723714947831896, 0.9184647058014888, 0.34716890374845544`], 
             UndirectedEdge[71, 400] -> 
             RGBColor[
              0.9614059711363574, 0.874547223797215, 0.3406520771347818], 
             UndirectedEdge[110, 117] -> 
             RGBColor[
              0.9942325936966199, 0.990799131585501, 0.6664554225750852], 
             UndirectedEdge[170, 351] -> 
             RGBColor[
              0.9259682348021703, 0.7441957511535866, 0.25929050785419716`], 
             UndirectedEdge[121, 200] -> 
             RGBColor[
              0.943860665092523, 0.7999279801673209, 0.41099180366150445`], 
             UndirectedEdge[38, 383] -> 
             RGBColor[
              0.9607062287090605, 0.8709194120703774, 0.35508207048039225`], 
             UndirectedEdge[172, 256] -> 
             RGBColor[
              0.9366485184910862, 0.9007566335455605, 0.6387875896472107], 
             UndirectedEdge[127, 258] -> 
             RGBColor[
              0.9262332615294813, 0.7443390637085198, 0.25945681416092614`], 
             UndirectedEdge[25, 388] -> 
             RGBColor[
              0.9688114288905754, 0.9012903003945578, 0.4659599742295242], 
             UndirectedEdge[51, 277] -> 
             RGBColor[
              0.9523773252886735, 0.8380641994058065, 0.33855070145494337`], 
             UndirectedEdge[85, 379] -> 
             RGBColor[
              0.9389388280846914, 0.7925474188059383, 0.2857281282879132], 
             UndirectedEdge[267, 306] -> 
             RGBColor[
              0.9636500029034698, 0.8850846413451174, 0.3339135125221834], 
             UndirectedEdge[176, 298] -> 
             RGBColor[
              0.920612171152019, 0.7194012733498777, 0.2547967656112932], 
             UndirectedEdge[269, 323] -> 
             RGBColor[
              0.9252306605719228, 0.7653951294162343, 0.5800013666453337], 
             UndirectedEdge[21, 180] -> 
             RGBColor[
              0.9932574577930251, 0.9879867089318969, 0.5074940747969996], 
             UndirectedEdge[36, 228] -> 
             RGBColor[
              0.9874244877973697, 0.9690663847885457, 0.42057878576421737`], 
             UndirectedEdge[74, 116] -> 
             RGBColor[
              0.9929666529364931, 0.989001254858435, 0.5948015321038422], 
             UndirectedEdge[3, 188] -> 
             RGBColor[
              0.971080520940641, 0.9269654053157055, 0.5887054864429352], 
             UndirectedEdge[69, 394] -> 
             RGBColor[
              0.971630097187874, 0.9159637976240548, 0.3442887140918415], 
             UndirectedEdge[37, 395] -> 
             RGBColor[
              0.9802072097460972, 0.9547947631096254, 0.6037215384393064], 
             UndirectedEdge[172, 194] -> 
             RGBColor[
              0.9384816729431114, 0.9069402939573754, 0.6459090485311578], 
             UndirectedEdge[59, 264] -> 
             RGBColor[
              0.9800926116898881, 0.9454780574463607, 0.5415515551384138], 
             UndirectedEdge[28, 369] -> 
             RGBColor[
              0.9483487778290437, 0.8272679433847991, 0.5212908393288274], 
             UndirectedEdge[130, 344] -> 
             RGBColor[
              0.9848560421223754, 0.9880055984827064, 0.9006381035463131], 
             UndirectedEdge[29, 270] -> 
             RGBColor[
              0.9808428564560818, 0.9629884754089719, 0.6420118628758256], 
             UndirectedEdge[41, 48] -> 
             RGBColor[
              0.9548991237785451, 0.9619902682980395, 0.7377436588445452], 
             UndirectedEdge[12, 124] -> 
             RGBColor[
              0.9899159530161128, 0.9844735444482889, 0.6202109169965482], 
             UndirectedEdge[61, 95] -> 
             RGBColor[
              0.8687600812149995, 0.4277291154804359, 0.20943409302648058`], 
             UndirectedEdge[213, 306] -> 
             RGBColor[
              0.9408948288810233, 0.8821040018181809, 0.6302094821409551], 
             UndirectedEdge[63, 295] -> 
             RGBColor[
              0.9868239974070978, 0.9739145919963494, 0.6073071943267312], 
             UndirectedEdge[302, 367] -> 
             RGBColor[
              0.9724133803222799, 0.9186059955600321, 0.3473316211584003], 
             UndirectedEdge[140, 331] -> 
             RGBColor[
              0.9868020531646786, 0.9753124200198526, 0.6173953250804617], 
             UndirectedEdge[92, 354] -> 
             RGBColor[
              0.9757188743649429, 0.9297562031328442, 0.36017284132397387`], 
             UndirectedEdge[151, 311] -> 
             RGBColor[
              0.9936095400045388, 0.9916253948116155, 0.7555699903125157], 
             UndirectedEdge[299, 371] -> 
             RGBColor[
              0.9783666826383823, 0.937034365410456, 0.5110622066738786], 
             UndirectedEdge[140, 389] -> 
             RGBColor[
              0.9508812834482802, 0.9487670917583082, 0.6940791938737743], 
             UndirectedEdge[176, 205] -> 
             RGBColor[
              0.9712681016499158, 0.9123695664160141, 0.38867947389114516`], 
             UndirectedEdge[152, 179] -> 
             RGBColor[
              0.9860673480992348, 0.9883935756881694, 0.8755064398608978], 
             UndirectedEdge[142, 293] -> 
             RGBColor[
              0.9705203819534725, 0.9269203620925791, 0.5992617669752391], 
             UndirectedEdge[105, 259] -> 
             RGBColor[
              0.9738408825302232, 0.9220478846109081, 0.4216328915656492], 
             UndirectedEdge[274, 318] -> 
             RGBColor[
              0.9303811843554013, 0.7616916256038828, 0.2628412706499661], 
             UndirectedEdge[231, 369] -> 
             RGBColor[
              0.9429557029320699, 0.803215849169032, 0.5168133102681852], 
             UndirectedEdge[151, 348] -> 
             RGBColor[
              0.9807623692079712, 0.9469508929936234, 0.5387177735533362], 
             UndirectedEdge[147, 231] -> 
             RGBColor[
              0.9139258647302159, 0.6937814173152873, 0.24946279981674802`], 
             UndirectedEdge[66, 354] -> 
             RGBColor[
              0.9789375544146033, 0.9406135667223638, 0.3726768055201794], 
             UndirectedEdge[24, 65] -> 
             RGBColor[
              0.9729100018005741, 0.9189235933378461, 0.38737086577229796`], 
             UndirectedEdge[42, 347] -> 
             RGBColor[
              0.9845231822020493, 0.9862818919625813, 0.835127429111024], 
             UndirectedEdge[52, 129] -> 
             RGBColor[
              0.9895796337422281, 0.9888750130687436, 0.7435670104937186], 
             UndirectedEdge[3, 7] -> 
             RGBColor[
              0.9896237923692244, 0.9887086311183346, 0.7294136142986967], 
             UndirectedEdge[156, 352] -> 
             RGBColor[
              0.9941102525457397, 0.9898107506771778, 0.6003155207908291], 
             UndirectedEdge[229, 329] -> 
             RGBColor[
              0.9841137864523891, 0.9876361429701657, 0.9101397088834733], 
             UndirectedEdge[80, 187] -> 
             RGBColor[
              0.9944131472951544, 0.990458611918819, 0.6332837450149064], 
             UndirectedEdge[247, 362] -> 
             RGBColor[
              0.9580764483319546, 0.9055999139062215, 0.6094130371083095], 
             UndirectedEdge[43, 321] -> 
             RGBColor[
              0.9942705759854472, 0.9917330129600869, 0.7325675673025138], 
             UndirectedEdge[84, 270] -> 
             RGBColor[
              0.9449885692955142, 0.8274868387033072, 0.578536305902429], 
             UndirectedEdge[318, 322] -> 
             RGBColor[
              0.9544981977372444, 0.8678203905345097, 0.5882292745434996], 
             UndirectedEdge[218, 276] -> 
             RGBColor[
              0.9852745488417496, 0.9688796006773648, 0.6026126434329137], 
             UndirectedEdge[201, 303] -> 
             RGBColor[
              0.9885222203392565, 0.9806680813806306, 0.6209891255924895], 
             UndirectedEdge[283, 364] -> 
             RGBColor[
              0.9689992492382971, 0.9614845589847798, 0.6776181366777261], 
             UndirectedEdge[65, 340] -> 
             RGBColor[
              0.9932259118364981, 0.9879192353206712, 0.5040604921081104], 
             UndirectedEdge[83, 214] -> 
             RGBColor[
              0.9946790021724885, 0.9920676449019867, 0.7378462345102195], 
             UndirectedEdge[124, 157] -> 
             RGBColor[
              0.9660212565101599, 0.8928320277819146, 0.3444347261859155], 
             UndirectedEdge[311, 344] -> 
             RGBColor[
              0.9890819688281041, 0.9897531277768878, 0.8306035616846498], 
             UndirectedEdge[190, 226] -> 
             RGBColor[
              0.9941921729790825, 0.9899859702006715, 0.6092320544058718], 
             UndirectedEdge[380, 389] -> 
             RGBColor[
              0.9469912393052304, 0.9356450594380012, 0.6789671069512224], 
             UndirectedEdge[124, 179] -> 
             RGBColor[
              0.9869173045575959, 0.98312059730383, 0.664849093318151], 
             UndirectedEdge[199, 215] -> 
             RGBColor[
              0.9377954570488691, 0.7921863452912192, 0.5648138980223465], 
             UndirectedEdge[146, 267] -> 
             RGBColor[
              0.9880154449567131, 0.9754112870634533, 0.5945014417730808], 
             UndirectedEdge[109, 249] -> 
             RGBColor[
              0.9576790289841901, 0.8666837968356585, 0.30165205819093144`], 
             UndirectedEdge[36, 61] -> 
             RGBColor[
              0.8996902242070323, 0.5426390973538693, 0.2745152719051022], 
             UndirectedEdge[13, 232] -> 
             RGBColor[
              0.9691455070903261, 0.9074532417182892, 0.3353107290450103], 
             UndirectedEdge[38, 119] -> 
             RGBColor[
              0.9493094269196137, 0.8660487305279264, 0.5986403363201416], 
             UndirectedEdge[91, 256] -> 
             RGBColor[
              0.9332245134737034, 0.7727949155823037, 0.26601216434244424`], 
             UndirectedEdge[6, 69] -> 
             RGBColor[
              0.9760464669947966, 0.9293226948034791, 0.4922731048174825], 
             UndirectedEdge[90, 97] -> 
             RGBColor[
              0.9922041458547219, 0.991044228213684, 0.7788610084184553], 
             UndirectedEdge[233, 257] -> 
             RGBColor[
              0.9858211282839545, 0.9632476579495471, 0.4492320751912524], 
             UndirectedEdge[66, 119] -> 
             RGBColor[
              0.9797750328248802, 0.9768798501636423, 0.6749987357285363], 
             UndirectedEdge[33, 116] -> 
             RGBColor[
              0.9878974748254297, 0.970809498186479, 0.40986395927442076`], 
             UndirectedEdge[335, 349] -> 
             RGBColor[
              0.9675963628252566, 0.9010651908538702, 0.33534651746239397`], 
             UndirectedEdge[165, 274] -> 
             RGBColor[
              0.9634716503832808, 0.8811023643649364, 0.40352397621753466`], 
             UndirectedEdge[95, 169] -> 
             RGBColor[
              0.9569633888221856, 0.855159640639527, 0.406550153515442], 
             UndirectedEdge[135, 259] -> 
             RGBColor[
              0.9535697098631677, 0.8536264021241206, 0.28149930257816497`], 
             UndirectedEdge[93, 273] -> 
             RGBColor[
              0.9437115579211184, 0.9391154148173367, 0.6876068323635153], 
             UndirectedEdge[89, 263] -> 
             RGBColor[
              0.9693917174774508, 0.9193225654142637, 0.5804349430038089], 
             UndirectedEdge[71, 289] -> 
             RGBColor[
              0.9672551330858769, 0.897737201809385, 0.3453584501368422], 
             UndirectedEdge[32, 215] -> 
             RGBColor[
              0.9421306327372916, 0.7925412888507941, 0.388458625740845], 
             UndirectedEdge[8, 239] -> 
             RGBColor[
              0.9307500978876505, 0.7631542448261042, 0.2631381071375274], 
             UndirectedEdge[110, 111] -> 
             RGBColor[
              0.9896767351686964, 0.9763708276916859, 0.5688534497583031], 
             UndirectedEdge[29, 162] -> 
             RGBColor[
              0.9861451035431513, 0.9653393462755187, 0.561226908559598], 
             UndirectedEdge[337, 353] -> 
             RGBColor[
              0.9734702305414535, 0.9206786649014633, 0.5112262970767701], 
             UndirectedEdge[306, 308] -> 
             RGBColor[
              0.9668221673066288, 0.8957850967365946, 0.34623677221547344`], 
             UndirectedEdge[185, 190] -> 
             RGBColor[
              0.9935809005194909, 0.9886785202187309, 0.5426988195156599], 
             UndirectedEdge[71, 385] -> 
             RGBColor[
              0.9917128260045536, 0.9833093842098946, 0.45616411184019157`], 
             UndirectedEdge[146, 158] -> 
             RGBColor[
              0.9586157630699681, 0.8673581088710056, 0.5265423980788746], 
             UndirectedEdge[157, 386] -> 
             RGBColor[
              0.9584773789429208, 0.8673847573609307, 0.3151281863789327], 
             UndirectedEdge[24, 124] -> 
             RGBColor[
              0.9715046512257752, 0.9145718605963599, 0.34884679428591614`], 
             UndirectedEdge[22, 74] -> 
             RGBColor[
              0.981839966292464, 0.9514963121088219, 0.5491969006930777], 
             UndirectedEdge[303, 385] -> 
             RGBColor[
              0.9906442281647486, 0.9797047527775281, 0.4520128110203189], 
             UndirectedEdge[130, 317] -> 
             RGBColor[
              0.989603335864591, 0.9899687264449968, 0.82196316063542], 
             UndirectedEdge[73, 291] -> 
             RGBColor[
              0.967193463795686, 0.8945865225852453, 0.48176465140505853`], 
             UndirectedEdge[241, 255] -> 
             RGBColor[
              0.9691670677648738, 0.9076554210334649, 0.33472030988756407`], 
             UndirectedEdge[385, 400] -> 
             RGBColor[
              0.962841307203461, 0.8789907760227031, 0.3800858753156696], 
             UndirectedEdge[130, 311] -> 
             RGBColor[
              0.9889929733636706, 0.9897163258652655, 0.8320784468431899], 
             UndirectedEdge[143, 308] -> 
             RGBColor[
              0.9925879024927085, 0.9856726633292661, 0.5096104577979776], 
             UndirectedEdge[297, 397] -> 
             RGBColor[
              0.9768486787473486, 0.9329211787018232, 0.41950329079500165`], 
             UndirectedEdge[237, 324] -> 
             RGBColor[
              0.9931009574644837, 0.9876519705537572, 0.49045997984333434`], 
             UndirectedEdge[107, 160] -> 
             RGBColor[
              0.9882860262087971, 0.9781376806727997, 0.6080885457885473], 
             UndirectedEdge[125, 185] -> 
             RGBColor[
              0.9907868907935101, 0.9883699577693665, 0.6505585653935453], 
             UndirectedEdge[269, 388] -> 
             RGBColor[
              0.9560180545494323, 0.8940324460484027, 0.6051137733562251], 
             UndirectedEdge[47, 300] -> 
             RGBColor[
              0.9933569162617102, 0.9881994405396205, 0.5183195153268467], 
             UndirectedEdge[37, 365] -> 
             RGBColor[
              0.9723785088811747, 0.9283867168258652, 0.5733085139051906], 
             UndirectedEdge[356, 389] -> 
             RGBColor[
              0.9523198728125182, 0.953619791480729, 0.699667841899033], 
             UndirectedEdge[227, 243] -> 
             RGBColor[
              0.9906988144802591, 0.9806380259363239, 0.5784882828012985], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.9531787061156884, 0.9632150391113997, 0.9069972941152931], 
             UndirectedEdge[186, 348] -> 
             RGBColor[
              0.9405257286431207, 0.798492425648728, 0.2888096941711783], 
             UndirectedEdge[61, 90] -> 
             RGBColor[
              0.9060897700678809, 0.5631348577575566, 0.44952784032679494`], 
             UndirectedEdge[72, 325] -> 
             RGBColor[
              0.9929782074282072, 0.9895238259586698, 0.632248130797883], 
             UndirectedEdge[341, 358] -> 
             RGBColor[
              0.9743991228258038, 0.9246932972788608, 0.3965081990752286], 
             UndirectedEdge[102, 337] -> 
             RGBColor[
              0.9596380584992257, 0.8744880180483721, 0.30303396574663677`], 
             UndirectedEdge[297, 378] -> 
             RGBColor[
              0.9691365463657442, 0.9035825514300233, 0.4068534876914708], 
             UndirectedEdge[300, 370] -> 
             RGBColor[
              0.9486306154450199, 0.8217781001587481, 0.4063878717926569], 
             UndirectedEdge[46, 52] -> 
             RGBColor[
              0.9567294255620773, 0.8708302688962113, 0.578611721150111], 
             UndirectedEdge[75, 200] -> 
             RGBColor[
              0.9443405103690777, 0.8009543206940724, 0.46322000075271563`], 
             UndirectedEdge[204, 343] -> 
             RGBColor[
              0.9823832283967542, 0.9575052043734218, 0.580174089036037], 
             UndirectedEdge[32, 199] -> 
             RGBColor[
              0.9892802132752312, 0.9883973439539037, 0.7228079461062715], 
             UndirectedEdge[301, 313] -> 
             RGBColor[
              0.9438262165559388, 0.8149966979876282, 0.27365945915398593`], 
             UndirectedEdge[166, 363] -> 
             RGBColor[
              0.9722514142359946, 0.9777728502221132, 0.88470515866629], 
             UndirectedEdge[333, 353] -> 
             RGBColor[
              0.9591464757629744, 0.8638897503131202, 0.4997010677602685], 
             UndirectedEdge[130, 146] -> 
             RGBColor[
              0.9880341339025072, 0.9893198211070242, 0.8479688981116501], 
             UndirectedEdge[71, 271] -> 
             RGBColor[
              0.9574229243331212, 0.8587557704940488, 0.3374472241827732], 
             UndirectedEdge[123, 332] -> 
             RGBColor[
              0.9498489400522294, 0.8302614834742341, 0.3233637290570326], 
             UndirectedEdge[340, 361] -> 
             RGBColor[
              0.991660919635164, 0.983028993887245, 0.4649162430484308], 
             UndirectedEdge[165, 322] -> 
             RGBColor[
              0.9875886637651239, 0.9872311292955631, 0.7289119801110682], 
             UndirectedEdge[278, 302] -> 
             RGBColor[
              0.9772692541769833, 0.9349859982853478, 0.36619577412909016`], 
             UndirectedEdge[322, 355] -> 
             RGBColor[
              0.9661272240021048, 0.9139256045313995, 0.5975862620445358], 
             UndirectedEdge[68, 333] -> 
             RGBColor[
              0.9231964338179802, 0.7332064838991965, 0.25706025171978664`], 
             UndirectedEdge[150, 156] -> 
             RGBColor[
              0.9574548988845112, 0.8565836227830419, 0.4379940765223109], 
             UndirectedEdge[29, 357] -> 
             RGBColor[
              0.9711180023757351, 0.9557356951588363, 0.658473504185692], 
             UndirectedEdge[250, 325] -> 
             RGBColor[
              0.9477539649684956, 0.8211797183770786, 0.5046893763505457], 
             UndirectedEdge[53, 131] -> 
             RGBColor[
              0.993862831492518, 0.9917301373511891, 0.751372294859344], 
             UndirectedEdge[92, 267] -> 
             RGBColor[
              0.9839594395841493, 0.9575535645939539, 0.3921858811004263], 
             UndirectedEdge[269, 309] -> 
             RGBColor[
              0.9477126796694306, 0.8611044022513092, 0.5984310737755711], 
             UndirectedEdge[162, 336] -> 
             RGBColor[
              0.9704073300015611, 0.975846879356133, 0.8631672176442828], 
             UndirectedEdge[94, 204] -> 
             RGBColor[
              0.9420385969298986, 0.8025153380890611, 0.3003133700794288], 
             UndirectedEdge[29, 183] -> 
             RGBColor[
              0.9538686417466822, 0.8481629032760505, 0.316366186104191], 
             UndirectedEdge[145, 208] -> 
             RGBColor[
              0.9157840285673413, 0.7038187671180375, 0.2510960564636092], 
             UndirectedEdge[75, 133] -> 
             RGBColor[
              0.9931250417888473, 0.9911520827857873, 0.7437581008940688], 
             UndirectedEdge[169, 326] -> 
             RGBColor[
              0.9939213491109962, 0.9894067053313285, 0.5797545476958625], 
             UndirectedEdge[95, 97] -> 
             RGBColor[
              0.9548744570018404, 0.8556384859365633, 0.5387672611181409], 
             UndirectedEdge[37, 78] -> 
             RGBColor[
              0.9887046397583209, 0.9834585898323042, 0.6367324494317853], 
             UndirectedEdge[55, 397] -> 
             RGBColor[
              0.95431827250709, 0.9191669776132393, 0.6358797420499376], 
             UndirectedEdge[185, 226] -> 
             RGBColor[
              0.9934726957726878, 0.9884470812064974, 0.5309214005884395], 
             UndirectedEdge[39, 254] -> 
             RGBColor[
              0.9850543806468284, 0.9725932541284726, 0.6325593355298804], 
             UndirectedEdge[71, 201] -> 
             RGBColor[
              0.9895908181790615, 0.984272712812997, 0.6251404264123621], 
             UndirectedEdge[227, 383] -> 
             RGBColor[
              0.9901144314678347, 0.9781836626029092, 0.42733265833849343`], 
             UndirectedEdge[38, 151] -> 
             RGBColor[
              0.9613477693152057, 0.8733974115376786, 0.5052904456961322], 
             UndirectedEdge[45, 74] -> 
             RGBColor[
              0.993991435125086, 0.9911931603384625, 0.706342749109607], 
             UndirectedEdge[292, 303] -> 
             RGBColor[
              0.9857629439731852, 0.9793930763064742, 0.6607178737802133], 
             UndirectedEdge[185, 357] -> 
             RGBColor[
              0.9783255757398073, 0.9798273251484002, 0.7052834450737975], 
             UndirectedEdge[86, 376] -> 
             RGBColor[
              0.9337701015566428, 0.7609473272411205, 0.5067916126777003], 
             UndirectedEdge[212, 309] -> 
             RGBColor[
              0.9603749759409728, 0.8680818938606139, 0.4450102356928938], 
             UndirectedEdge[50, 127] -> 
             RGBColor[
              0.9468277638614916, 0.8151147610937811, 0.33639635290394776`], 
             UndirectedEdge[92, 374] -> 
             RGBColor[
              0.9605922562500425, 0.8734172329517407, 0.32908072734261284`], 
             UndirectedEdge[118, 141] -> 
             RGBColor[
              0.9416252337024748, 0.8011719859072999, 0.5325628973962341], 
             UndirectedEdge[205, 390] -> 
             RGBColor[
              0.992870600340253, 0.9871592599577055, 0.4653870284701985]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.9229490362446094, 0.7322256349611356, 0.2568611898250851], 
             316 -> RGBColor[
              0.9938028871379454, 0.9891533271493154, 0.5668606929918337], 
             308 -> RGBColor[
              0.9910739975726719, 0.9815526392668963, 0.419824595414295], 160 -> 
             RGBColor[
              0.9864963973256503, 0.9661113187620417, 0.40204148286188784`], 
             245 -> RGBColor[
              0.9937667469603273, 0.9890760269637227, 0.5629270576894223], 
             155 -> RGBColor[
              0.9948638904183653, 0.9914227058822467, 0.6823443523123021], 
             213 -> RGBColor[
              0.9392193207214607, 0.9541904494300693, 0.9877700152652583], 
             352 -> RGBColor[
              0.993920127365594, 0.9894040921414504, 0.5796215682485658], 27 -> 
             RGBColor[
              0.9649956167175967, 0.8935841371477156, 0.31851501028132356`], 
             367 -> RGBColor[
              0.9824516003837755, 0.9524672689136127, 0.3863282105385145], 19 -> 
             RGBColor[
              0.9210436571385565, 0.7246714417355835, 0.255328077071359], 164 -> 
             RGBColor[
              0.907117945467462, 0.6694606354280181, 0.24412312258233168`], 
             190 -> RGBColor[
              0.9943003777258855, 0.9902174092129051, 0.6210094733330922], 
             103 -> RGBColor[
              0.9391729861358183, 0.7965481899689677, 0.26991536073260103`], 
             138 -> 
             RGBColor[
              0.9865284818006566, 0.9886971952694149, 0.8729214499420491], 
             291 -> RGBColor[
              0.9949655935960154, 0.9916402386954717, 0.693414115560258], 28 -> 
             RGBColor[
              0.9057427075284533, 0.6640082752707251, 0.24301657385562192`], 
             337 -> RGBColor[
              0.9525008360116671, 0.849388673484017, 0.28063926158755365`], 
             195 -> RGBColor[
              0.9443782086271579, 0.8171851626095586, 0.2741036049314081], 
             114 -> RGBColor[
              0.9895563866224785, 0.9899493117268428, 0.8227412310779691], 93 -> 
             RGBColor[
              0.9054762696740812, 0.9274662152122727, 0.9908463290013639], 34 -> 
             RGBColor[
              0.9894640572860959, 0.9899111311734928, 0.8242713671224922], 
             161 -> RGBColor[
              0.9648821360559318, 0.8932013402293932, 0.31807415933978], 22 -> 
             RGBColor[
              0.970294969264735, 0.9114600976363629, 0.339101994228199], 124 -> 
             RGBColor[
              0.9903223457135195, 0.979017141049726, 0.41690456987903135`], 
             84 -> RGBColor[
              0.9067377022638166, 0.6679530978340997, 0.24381716997522332`], 
             46 -> RGBColor[
              0.9283251459616978, 0.753540118507028, 0.26118693389696834`], 
             241 -> RGBColor[
              0.9787477923827633, 0.9399734548307236, 0.3719396158600337], 
             185 -> RGBColor[
              0.9928614233130961, 0.9871396312245568, 0.4643881656982277], 
             390 -> RGBColor[
              0.9925594729794553, 0.9864937899927609, 0.4315227353028813], 
             121 -> RGBColor[
              0.9940059030429058, 0.989587557641969, 0.5889577213778356], 322 -> 
             RGBColor[
              0.9816046730360135, 0.985801375786618, 0.9160226696670817], 126 -> 
             RGBColor[
              0.9864383849497574, 0.9886599379061847, 0.8744145879246238], 
             236 -> RGBColor[
              0.9922957162365946, 0.9910820949198398, 0.7773434502142712], 78 -> 
             RGBColor[
              0.9899749835674125, 0.9778454069663968, 0.4155551335352429], 
             376 -> RGBColor[
              0.9912256592929753, 0.9906395988744441, 0.7950770629886433], 
             254 -> RGBColor[
              0.9864559258825258, 0.9886671915326658, 0.8741238892741714], 
             290 -> RGBColor[
              0.9648246977631318, 0.8930075873806268, 0.3178510224185639], 
             251 -> RGBColor[
              0.9054762696740812, 0.9274662152122727, 0.9908463290013639], 
             165 -> RGBColor[
              0.9935726544942343, 0.9886608828045083, 0.5418012905550547], 
             100 -> RGBColor[
              0.9284030973915636, 0.7538491699506715, 0.2612496554471936], 
             235 -> RGBColor[
              0.9886021799661516, 0.9895547227524591, 0.8385549047809733], 70 -> 
             RGBColor[
              0.9576459157423434, 0.8687918699663315, 0.2899628098670328], 
             234 -> RGBColor[
              0.9903614553598412, 0.9902822283390651, 0.8093991586487619], 
             257 -> RGBColor[
              0.9781900501784915, 0.9380920594116176, 0.3697728927172153], 
             135 -> RGBColor[
              0.9532110877532944, 0.8522045849622067, 0.2812107468106181], 
             265 -> RGBColor[
              0.9935056186076746, 0.988517499821525, 0.5345048480005752], 111 -> 
             RGBColor[
              0.9849138452661528, 0.9607729990644623, 0.3958935669506197], 
             381 -> RGBColor[
              0.9865002943324449, 0.9886855390269245, 0.8733885892371454], 
             182 -> RGBColor[
              0.993160193487062, 0.9877786704163714, 0.496907455338619], 188 -> 
             RGBColor[
              0.956724987301784, 0.8656853620920442, 0.28638517677820313`], 
             154 -> RGBColor[
              0.9861110662937885, 0.9885245832302357, 0.8798391051275567], 
             336 -> RGBColor[
              0.9469707295017713, 0.9599714374066579, 0.9746489020913862], 
             315 -> RGBColor[
              0.9931124575804956, 0.9876765681390666, 0.4917116965007463], 
             368 -> RGBColor[
              0.9940175994906989, 0.9896125751611062, 0.5902308075380075], 
             269 -> RGBColor[
              0.9690621722793642, 0.9764471992587691, 0.937253851839979], 208 -> 
             RGBColor[
              0.9086190208900733, 0.6754118992749394, 0.24533092310213334`], 
             86 -> RGBColor[
              0.8763145438203102, 0.531255055607797, 0.21850616236675743`], 
             119 -> RGBColor[
              0.9699234951484946, 0.9770895724442797, 0.9357958568915238], 
             377 -> RGBColor[
              0.873432034870463, 0.5181662556936102, 0.21610092624224497`], 
             140 -> RGBColor[
              0.9850019263632055, 0.9610701172872462, 0.3962357453799501], 85 -> 
             RGBColor[
              0.9663527412855056, 0.8981620369832746, 0.32378718295617975`], 
             351 -> RGBColor[
              0.9296814464644771, 0.7589173980401981, 0.26227824511796916`], 
             242 -> RGBColor[
              0.9776746929964727, 0.9363536386250473, 0.3677708273821097], 
             117 -> RGBColor[
              0.9940255623219996, 0.9896296068520926, 0.5910975125841837], 47 -> 
             RGBColor[
              0.9928668803686985, 0.9871513033146975, 0.4649821325235076], 81 -> 
             RGBColor[
              0.9401741500851994, 0.8005174714101548, 0.2707209207466113], 
             275 -> RGBColor[
              0.9196015657086798, 0.7189540297646041, 0.25416773645664376`], 
             23 -> RGBColor[
              0.9278595071850776, 0.7516940159226531, 0.2608122700073529], 
             328 -> RGBColor[
              0.9937936244568298, 0.9891335152110099, 0.5658525073150449], 
             110 -> RGBColor[
              0.9944396250712401, 0.9919686563189095, 0.7418133325659866], 6 -> 
             RGBColor[
              0.9949959278311028, 0.991705120557062, 0.6967158098483238], 218 -> 
             RGBColor[
              0.9894672572677288, 0.9899124544481338, 0.8242183351455482], 
             108 -> RGBColor[
              0.9943857185857606, 0.9903999446828936, 0.6302982992677636], 
             297 -> RGBColor[
              0.9935499109577005, 0.9886122366795869, 0.5393257969601946], 
             157 -> RGBColor[
              0.9417201673068003, 0.8066469145141032, 0.2719648824927996], 
             354 -> RGBColor[
              0.968248538327941, 0.9045570055617229, 0.33115199647481], 385 -> 
             RGBColor[
              0.993148162071657, 0.9877529364353829, 0.49559791002107934`], 
             270 -> RGBColor[
              0.983239436327212, 0.9870205795725147, 0.9132554418296347], 392 -> 
             RGBColor[
              0.9929974526499461, 0.9874305842214033, 0.4791941195385919], 33 -> 
             RGBColor[
              0.9832466070980662, 0.9551490132373687, 0.38941666149911336`], 
             252 -> RGBColor[
              0.9884518972221094, 0.9727076790860085, 0.4096382306944619], 
             394 -> RGBColor[
              0.9861631882172575, 0.9649873261982134, 0.40074702839704185`], 
             260 -> RGBColor[
              0.8199280051208216, 0.15418095663196868`, 0.1667163862501486], 
             159 -> RGBColor[
              0.9864772464214273, 0.9886760081234145, 0.873770552768788], 183 -> 
             RGBColor[
              0.9292910069084126, 0.7573694353066717, 0.2619640882863654], 99 -> 
             RGBColor[
              0.9714628286746129, 0.9153995616523106, 0.34363890750383047`], 
             329 -> 
             RGBColor[
              0.983815720367594, 0.987450371266253, 0.9122799432682176], 309 -> 
             RGBColor[
              0.926363187059497, 0.7457616052438493, 0.25960829571116323`], 
             17 -> RGBColor[
              0.9637897281665183, 0.9725150190722435, 0.9461787244493673], 
             349 -> RGBColor[
              0.951594370336186, 0.8457948391425145, 0.27990989802757754`], 
             347 -> RGBColor[
              0.9746452598576468, 0.9806110568331854, 0.9278031408723981], 
             340 -> RGBColor[
              0.9933187768098789, 0.9881178641086436, 0.514168271364426], 277 -> 
             RGBColor[
              0.9122195179761786, 0.6896866704268181, 0.24822796757214252`], 
             104 -> RGBColor[
              0.9931027153271655, 0.9876557304442863, 0.4906513123479792], 79 -> 
             RGBColor[
              0.9510125857418301, 0.8434882570941169, 0.2794417804867192], 
             327 -> RGBColor[
              0.9949858017629541, 0.9916834619211945, 0.6956136498211859], 
             191 -> RGBColor[
              0.980789593185631, 0.9468609283764231, 0.3798716264174466], 50 -> 
             RGBColor[
              0.9925787815571564, 0.9865350890880669, 0.4336243548269173], 
             225 -> RGBColor[
              0.9776746929964727, 0.9363536386250473, 0.3677708273821097], 61 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 196 -> 
             RGBColor[0.972404099255543, 0.9789396029257, 0.9315968411834592],
              1 -> RGBColor[
              0.9554219419078034, 0.8609698849613615, 0.28298965195875286`], 
             263 -> RGBColor[
              0.9860964782168707, 0.9885185506855337, 0.8800808673148168], 
             201 -> RGBColor[
              0.9889041464206729, 0.9896795936415876, 0.8335505391654204], 
             371 -> RGBColor[
              0.9951822005772709, 0.9921035391260519, 0.7169904487265797], 
             293 -> RGBColor[
              0.9841893987801753, 0.9877290600145139, 0.9116474031866564], 
             362 -> RGBColor[
              0.9492073827864019, 0.8363312289240687, 0.27798927181522226`], 
             184 -> RGBColor[
              0.9931485524381405, 0.9877537713898191, 0.4956403990037523], 
             106 -> RGBColor[
              0.943271075193496, 0.9572122412811741, 0.9809114518109148], 206 -> 
             RGBColor[
              0.9335586693920103, 0.7742892949399174, 0.26539794969558145`], 
             358 -> RGBColor[
              0.993280014837457, 0.9880349561690697, 0.5099492698774664], 247 -> 
             RGBColor[
              0.9669455138775074, 0.9748685988883743, 0.9408368024013967], 
             220 -> RGBColor[
              0.9868917985584619, 0.9888474360855822, 0.8669003510315854], 
             107 -> RGBColor[
              0.9900756550919438, 0.9901640425835577, 0.8141356087152068], 
             375 -> RGBColor[
              0.9616975153579159, 0.8824588668304871, 0.3057025092931452], 
             131 -> RGBColor[
              0.993580436839354, 0.9916133599048943, 0.7560523050762049], 127 -> 
             RGBColor[
              0.9010767461658268, 0.6436944330994954, 0.23916835098097827`], 
             210 -> RGBColor[
              0.9708371104148606, 0.9132888670365323, 0.3412081102216716], 
             357 -> RGBColor[
              0.9637897281665183, 0.9725150190722435, 0.9461787244493673], 
             181 -> RGBColor[
              0.8278596758489554, 0.21514725352868025`, 0.17431176309695032`],
              194 -> RGBColor[
              0.960202705352868, 0.8774165216853806, 0.2998954546947173], 118 -> 
             RGBColor[
              0.9890177249921055, 0.9897265612997111, 0.831668248304862], 348 -> 
             RGBColor[
              0.967524558476264, 0.9021148515234628, 0.32833947146316733`], 
             276 -> RGBColor[
              0.9810818404157703, 0.9478467469065958, 0.38100695172027915`], 
             305 -> RGBColor[
              0.9923393971069084, 0.9911001580822617, 0.776619545150703], 343 -> 
             RGBColor[
              0.9905628335335792, 0.9903655033890888, 0.8060618011599171], 
             280 -> RGBColor[
              0.8632082637375081, 0.4717424988012767, 0.20756996100134484`], 
             189 -> RGBColor[
              0.9692731939311068, 0.9080134095117778, 0.3351325900031346], 
             168 -> RGBColor[
              0.9852096727981905, 0.9617708947936332, 0.39704280105024436`], 
             363 -> RGBColor[
              0.9905294486115939, 0.9903516978658945, 0.8066150757146227], 41 -> 
             RGBColor[
              0.9930376070237354, 0.9875164703667088, 0.48356467532149217`], 
             14 -> RGBColor[
              0.9527350577154565, 0.8503172844897862, 0.2808277218683127], 77 -> 
             RGBColor[
              0.9931848582625453, 0.987831425877139, 0.49959206393663713`], 
             51 -> RGBColor[
              0.9925351326011683, 0.9864417283847948, 0.4288734353377442], 
             179 -> RGBColor[
              0.9835122634016722, 0.9872240535579337, 0.9127936167572707], 
             223 -> 
             RGBColor[
              0.988281616097769, 0.9894221613547672, 0.8438674776727715], 323 -> 
             RGBColor[
              0.8813991488644815, 0.5543430595736996, 0.2227488814506885], 
             292 -> RGBColor[
              0.9833855936885301, 0.987129583493275, 0.9130080355408682], 396 -> 
             RGBColor[
              0.9681686040433699, 0.9042873684504018, 0.33084146687357396`], 
             321 -> RGBColor[
              0.9934512695010161, 0.9915599458910423, 0.7581929421468205], 
             143 -> RGBColor[
              0.9941018074127449, 0.9897926873916357, 0.5993963201816603], 
             112 -> RGBColor[
              0.9669698094707766, 0.9002435528666934, 0.3261843763324084], 
             197 -> RGBColor[
              0.9734145681412016, 0.9219832371633341, 0.35122104677645616`], 
             54 -> RGBColor[
              0.9874855177205791, 0.9890929542170042, 0.8570608880193642], 71 -> 
             RGBColor[
              0.99027748993745, 0.9788658319844064, 0.41673031365930374`], 
             177 -> RGBColor[
              0.9808511812003655, 0.9852394228093213, 0.917298134802689], 158 -> 
             RGBColor[
              0.925930304992864, 0.7440453720990471, 0.25925998863930233`], 
             226 -> RGBColor[
              0.9940839682322794, 0.9897545311884378, 0.5974546354786513], 
             350 -> RGBColor[
              0.9938700281533849, 0.9917331133554034, 0.751253027564418], 203 -> 
             RGBColor[
              0.9249399938045669, 0.7401191182390899, 0.25846316101160727`], 
             115 -> RGBColor[
              0.9924204937717814, 0.9911336936372759, 0.775275563542317], 173 -> 
             RGBColor[
              0.9844118525371842, 0.9878219146740782, 0.9079994744987289], 
             212 -> RGBColor[
              0.9943867648224486, 0.9904021824773783, 0.6304121756746243], 
             129 -> RGBColor[
              0.9940255623219996, 0.9896296068520926, 0.5910975125841837], 
             279 -> RGBColor[
              0.907117945467462, 0.6694606354280181, 0.24412312258233168`], 
             26 -> RGBColor[
              0.956724987301784, 0.8656853620920442, 0.28638517677820313`], 
             40 -> RGBColor[
              0.9362919253747481, 0.7851257441079104, 0.26759719161705614`], 
             146 -> RGBColor[
              0.9913012211470723, 0.9906708456429643, 0.7938248075184469], 
             386 -> RGBColor[
              0.9752345905790414, 0.9281226002077582, 0.35829149026506574`], 
             192 -> 
             RGBColor[
              0.9911415873795292, 0.9906048329776844, 0.7964703521655848], 
             300 -> RGBColor[
              0.9938469521547219, 0.9892475777645435, 0.5716568981301857], 
             221 -> RGBColor[
              0.9290593476146701, 0.756450983402866, 0.2617776897808777], 62 -> 
             RGBColor[
              0.9936336864774936, 0.98879142404542, 0.5484442452870933], 286 -> 
             RGBColor[
              0.9685682709553705, 0.9056355387908335, 0.33239409735593306`], 
             152 -> RGBColor[
              0.9886224327967975, 0.9895630978184052, 0.8382192629645249], 64 -> 
             RGBColor[
              0.9807633312487328, 0.9467723406966698, 0.3797696037517481], 
             307 -> RGBColor[
              0.9932931794453224, 0.9914945715902839, 0.7608129034936153], 37 -> 
             RGBColor[
              0.9874342959492293, 0.9890717726982116, 0.8579097653283276], 
             148 -> RGBColor[
              0.9550908107419535, 0.8596570602316863, 0.28272321605006256`], 
             261 -> RGBColor[
              0.8870768642218594, 0.5801242389474407, 0.22748650631842338`], 
             387 -> RGBColor[
              0.8896995272977151, 0.5920331394363773, 0.229674920676272], 15 -> 
             RGBColor[
              0.9911415873795292, 0.9906048329776844, 0.7964703521655848], 
             136 -> RGBColor[
              0.9773900096984701, 0.9826580867703559, 0.9231569953372936], 
             198 -> RGBColor[
              0.9612916979482846, 0.8810899494173418, 0.3041259852889149], 63 -> 
             RGBColor[
              0.989596771698022, 0.9899660119934292, 0.8220719458629877], 310 -> 
             RGBColor[
              0.9525570617369237, 0.8496115897485471, 0.28068450212588253`], 
             171 -> RGBColor[
              0.9883849792677092, 0.972481949112734, 0.4093782670780128], 395 -> 
             RGBColor[
              0.972980123542965, 0.9205177535210394, 0.3495333115502852], 311 -> 
             RGBColor[
              0.9932189000693992, 0.9914638551594468, 0.7620439049815265], 
             353 -> RGBColor[
              0.9944396250712401, 0.9919686563189095, 0.7418133325659866], 59 -> 
             RGBColor[
              0.966716456358007, 0.8993889333271818, 0.3252001473310194], 397 -> 
             RGBColor[
              0.9601474465369967, 0.8772301207240595, 0.29968078462980874`], 
             229 -> RGBColor[
              0.9844118525371842, 0.9878219146740782, 0.9079994744987289], 
             102 -> RGBColor[
              0.9667752809867842, 0.8995873626127271, 0.32542866990571984`], 
             299 -> RGBColor[
              0.9615511646994936, 0.8819651916948602, 0.30513396462117753`], 
             128 -> RGBColor[
              0.9457665322968127, 0.822689403328302, 0.27522068274415723`], 
             12 -> RGBColor[
              0.9895095603187062, 0.9899299478468518, 0.8235172641140651], 
             222 -> RGBColor[
              0.9312058541893268, 0.7649611666904661, 0.2635048193558315], 92 -> 
             RGBColor[
              0.9831892104019447, 0.9549554007039656, 0.3891936861731377], 
             271 -> RGBColor[
              0.9245683587287924, 0.7386457090036913, 0.2581641347062426], 
             361 -> RGBColor[
              0.990003062460449, 0.9779401236658464, 0.41566421473243564`], 
             344 -> RGBColor[
              0.9849450375868088, 0.9880424003943288, 0.899163218387773], 132 -> 
             RGBColor[
              0.9918147441064756, 0.9908832005836156, 0.7853144031263165], 80 -> 
             RGBColor[
              0.9949924590420253, 0.9916977011679735, 0.6963382535641172], 
             324 -> RGBColor[
              0.9930977800485056, 0.9876451743822661, 0.4901141377228594], 
             244 -> RGBColor[
              0.9937319397946325, 0.9890015779558459, 0.5591385125084778], 
             150 -> RGBColor[
              0.9206094200431368, 0.7229498363531787, 0.25497867971152965`], 
             125 -> RGBColor[
              0.9887123582739241, 0.9896002843141763, 0.836728965088863], 258 -> 
             RGBColor[
              0.9513897768931359, 0.8449836943175442, 0.27974527734087407`], 
             133 -> RGBColor[
              0.9912844899816792, 0.9906639268761028, 0.7941020862278796], 
             255 -> RGBColor[
              0.9595863431469842, 0.8753373872362061, 0.2975010039150944], 
             326 -> RGBColor[
              0.9941170830076203, 0.9898253603444747, 0.6010589744138023], 
             176 -> RGBColor[
              0.9493544755987811, 0.836914402909378, 0.2781076261447746], 230 -> 
             RGBColor[
              0.9784306095583493, 0.9834341644420279, 0.9213955312064286], 
             274 -> RGBColor[
              0.9333706462723271, 0.7735438459253645, 0.2652466618800146], 87 -> 
             RGBColor[
              0.9640326509840702, 0.8903358276134243, 0.3147740702473932], 
             130 -> RGBColor[
              0.984767046657942, 0.987968796571084, 0.9021129887048533], 35 -> 
             RGBColor[
              0.9554558442174533, 0.8611042963218484, 0.2830169305528867], 
             379 -> RGBColor[
              0.9115249148838772, 0.6869328006286021, 0.24766907361964668`], 
             31 -> RGBColor[
              0.9857236793629641, 0.9635047596310954, 0.39903961949239497`], 
             18 -> RGBColor[
              0.9762957570804383, 0.931702163990713, 0.3624139217385136], 24 -> 
             RGBColor[
              0.9526869567380308, 0.8501265801429937, 0.2807890186928009], 
             151 -> RGBColor[
              0.9940001799396786, 0.9917869344637842, 0.749096075643505], 137 -> 
             RGBColor[
              0.9339937684181705, 0.7760143175904873, 0.26574804058511675`], 
             330 -> RGBColor[
              0.9844118525371842, 0.9878219146740782, 0.9079994744987289], 
             296 -> RGBColor[
              0.9570442511930353, 0.8667623141639613, 0.2876254567077875], 
             266 -> RGBColor[
              0.9938070386875015, 0.9891622068940299, 0.5673125635406253], 
             302 -> RGBColor[
              0.9623751602607842, 0.8847447222064515, 0.30833503177828614`], 
             283 -> RGBColor[
              0.984025118616199, 0.9577751153912276, 0.39244103173749484`], 
             388 -> RGBColor[
              0.9429739368195004, 0.8116176928380363, 0.2729736948724711], 
             284 -> RGBColor[
              0.9933373214385368, 0.9881575291941931, 0.5161867397496527], 
             318 -> RGBColor[
              0.9273917224384753, 0.7498394052824012, 0.2604358794199175], 
             238 -> RGBColor[
              0.9685752769396483, 0.9056591716208857, 0.3324213142818831], 72 -> 
             RGBColor[
              0.9931485524381405, 0.9877537713898191, 0.4956403990037523], 
             288 -> RGBColor[
              0.9931785060515781, 0.9878178391401871, 0.49890066497415186`], 
             382 -> RGBColor[
              0.9844235887039112, 0.9591192485623066, 0.3939890127834945], 
             389 -> RGBColor[
              0.9167606405333548, 0.9364640662293703, 0.9919226423675983], 
             172 -> RGBColor[
              0.9167606405333548, 0.9364640662293703, 0.9919226423675983], 
             243 -> RGBColor[
              0.993885864752237, 0.9917396621960107, 0.750990574137635], 88 -> 
             RGBColor[
              0.8679372599550944, 0.49321576614020846`, 0.2115159513636034], 
             273 -> RGBColor[
              0.9819468461681556, 0.9507646144224008, 0.38436733572566656`], 
             202 -> RGBColor[
              0.9922957162365946, 0.9910820949198398, 0.7773434502142712], 
             393 -> RGBColor[
              0.934377430657468, 0.77753541052144, 0.2660567442285658], 98 -> 
             RGBColor[
              0.9338585175710149, 0.7754780930511884, 0.26563921457874995`], 
             30 -> RGBColor[
              0.9951034552548347, 0.9919351108437341, 0.7084195063391923], 
             116 -> RGBColor[
              0.9925483425527931, 0.9864699831355892, 0.43031125704972817`], 
             373 -> RGBColor[
              0.9815082294641289, 0.9857294483286183, 0.9161859234777703], 
             240 -> RGBColor[
              0.9936464056546755, 0.988818629079306, 0.5498286492296816], 317 -> 
             RGBColor[
              0.9944396250712401, 0.9919686563189095, 0.7418133325659866], 
             391 -> RGBColor[
              0.9494997368203938, 0.83749031524764, 0.2782245067334033], 73 -> 
             RGBColor[
              0.9394213339953567, 0.7975328064750189, 0.27011518724985906`], 
             303 -> RGBColor[
              0.9881402942578402, 0.9716565691196734, 0.4084277120195585], 29 -> 
             RGBColor[
              0.9784462765849518, 0.9389563712454292, 0.37076828392201655`], 
             360 -> RGBColor[
              0.9743428688787774, 0.9251146135265559, 0.35482731984705357`], 
             320 -> RGBColor[
              0.9934219489617586, 0.9883385389092096, 0.5253979233918202], 75 -> 
             RGBColor[
              0.9949655935960154, 0.9916402386954717, 0.693414115560258], 200 -> 
             RGBColor[
              0.89371542714214, 0.6102684026926729, 0.2330258859451732], 301 -> 
             RGBColor[
              0.9402460298745945, 0.8008024508225862, 0.27077875691239406`], 
             156 -> RGBColor[
              0.9943003777258855, 0.9902174092129051, 0.6210094733330922], 25 -> 
             RGBColor[
              0.9946489209616504, 0.9909629079510793, 0.6589462535865773], 38 -> 
             RGBColor[
              0.9286953586907328, 0.7550078886115731, 0.26148481574875954`], 
             365 -> RGBColor[
              0.9573227218131203, 0.8677016609535187, 0.2887072624820535], 
             380 -> RGBColor[
              0.9772218380771062, 0.9348260526466323, 0.36601157153484637`], 
             370 -> RGBColor[
              0.9034142787353179, 0.6543086225529526, 0.24111884545512813`], 
             3 -> RGBColor[
              0.9854360545794981, 0.9882454485393669, 0.8910257961076673], 57 -> 
             RGBColor[
              0.9378197378197562, 0.7911830113390506, 0.2688265053726769], 
             227 -> 
             RGBColor[
              0.9875117642082811, 0.9695363896766369, 0.4059859914649619], 39 -> 
             RGBColor[
              0.9836528354111309, 0.9565193167242795, 0.3909947817855895], 
             109 -> RGBColor[
              0.948456568064602, 0.8333544987463063, 0.2773851486661754], 256 -> 
             RGBColor[
              0.9565363964488177, 0.8650492008617506, 0.28565253692682313`], 
             339 -> RGBColor[
              0.9931622390703552, 0.9877830457121956, 0.4971301044562165], 
             287 -> RGBColor[
              0.99347587761786, 0.9915701219797571, 0.7577851219669525], 239 -> 
             RGBColor[
              0.9461433142661124, 0.8241832182814273, 0.27552385036086535`], 
             285 -> RGBColor[
              0.9912270303503083, 0.9906401658418859, 0.7950543410204526], 
             345 -> RGBColor[
              0.9864383849497574, 0.9886599379061847, 0.8744145879246238], 
             366 -> RGBColor[
              0.8657505981335784, 0.48328664551654765`, 0.2096913471397444], 
             216 -> RGBColor[
              0.9942160610031289, 0.990037064268657, 0.6118321184035248], 21 -> 
             RGBColor[
              0.9936534922729542, 0.9888337866392369, 0.5505999838957715], 
             355 -> RGBColor[
              0.950649774968196, 0.8420498332761809, 0.2791498544219898], 175 -> 
             RGBColor[
              0.9899055535223517, 0.9776112031214564, 0.4152854109209451], 7 -> 
             RGBColor[
              0.9938115301589507, 0.9891718136973024, 0.567801432489726], 13 -> 
             RGBColor[
              0.9827657656256318, 0.9535270220439004, 0.3875486831779981], 
             294 -> RGBColor[
              0.9868917985584619, 0.9888474360855822, 0.8669003510315854], 
             193 -> RGBColor[
              0.970400120687602, 0.9118147980764215, 0.33951048764985725`], 
             60 -> RGBColor[
              0.9690409130268088, 0.9764313441430221, 0.9372898382092542], 65 -> 
             RGBColor[
              0.9931330468631173, 0.9877206065326987, 0.493952712851795], 69 -> 
             RGBColor[
              0.9570970061584904, 0.8669402690498962, 0.28783039978664116`], 
             217 -> RGBColor[
              0.99512919314985, 0.9922538104405061, 0.7303854049584358], 214 -> 
             RGBColor[
              0.994422540856595, 0.9919615915571095, 0.7420964622151853], 170 -> 
             RGBColor[
              0.9222550231398634, 0.729474104266975, 0.2563027705904251], 359 -> 
             RGBColor[
              0.9286244377577375, 0.7547267107452466, 0.26142775110134325`], 
             74 -> RGBColor[
              0.993384963320193, 0.9915325265812809, 0.7592918071579563], 246 -> 
             RGBColor[
              0.9161161956240006, 0.7051356988095813, 0.2513633258743601], 
             264 -> RGBColor[
              0.9934687670217693, 0.9915671815655396, 0.7579029629458083], 
             278 -> RGBColor[
              0.9921633480931824, 0.9852272743642441, 0.4240565164798942], 45 -> 
             RGBColor[
              0.994597906929979, 0.990853794095644, 0.6533936910612579], 306 -> 
             RGBColor[
              0.9425703370405857, 0.8100175542062927, 0.2726489490166518], 
             237 -> RGBColor[
              0.9931041348804618, 0.9876587667252482, 0.49080582196380934`], 
             228 -> RGBColor[
              0.9927875271806748, 0.9869815748693527, 0.4563450277182303], 
             180 -> RGBColor[
              0.9928614233130961, 0.9871396312245568, 0.4643881656982277], 
             383 -> RGBColor[
              0.9927170987273882, 0.9868309355291817, 0.44867932521202497`], 
             53 -> RGBColor[
              0.9941452261456818, 0.991846914797484, 0.746692284642483], 304 -> 
             RGBColor[
              0.9854344316644049, 0.9882447774222688, 0.8910526920107315], 48 -> 
             RGBColor[
              0.9167606405333548, 0.9364640662293703, 0.9919226423675983], 5 -> 
             RGBColor[
              0.9762957570804383, 0.931702163990713, 0.3624139217385136], 101 -> 
             RGBColor[
              0.9767776578086529, 0.9333277283026528, 0.3642860150683108], 
             333 -> RGBColor[
              0.9238533264547089, 0.7358108443073308, 0.25758880295455044`], 
             267 -> RGBColor[
              0.9847296687663539, 0.9601517284839423, 0.3951780760277149], 
             120 -> RGBColor[
              0.9270271983544173, 0.748394188759561, 0.26014257478540437`], 
             147 -> RGBColor[
              0.932895171725926, 0.7716587477913837, 0.26486408389915816`], 
             89 -> RGBColor[
              0.9526869567380308, 0.8501265801429937, 0.2807890186928009], 43 -> 
             RGBColor[
              0.9950898824698783, 0.9919060800291314, 0.7069421924582071], 
             199 -> RGBColor[
              0.9849450375868088, 0.9880424003943288, 0.899163218387773], 268 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 169 -> 
             RGBColor[
              0.9937256152143722, 0.9889880503181822, 0.5584501209779228], 20 -> 
             RGBColor[
              0.9604032619421188, 0.8780930461538499, 0.3006745791720224], 4 -> 
             RGBColor[
              0.9597931468424784, 0.9695343752645759, 0.9529438941556165], 
             167 -> RGBColor[
              0.9846384929472911, 0.9598441710371431, 0.39482387518776474`], 
             142 -> RGBColor[
              0.9568513651267695, 0.8661116641706443, 0.2868761307638218], 16 -> 
             RGBColor[
              0.9896421427506954, 0.9767226567368696, 0.41426210981401096`], 
             281 -> RGBColor[
              0.9623751602607842, 0.8847447222064515, 0.30833503177828614`], 
             289 -> RGBColor[
              0.9442327762343037, 0.8166085716343637, 0.2739865866143806], 
             398 -> RGBColor[
              0.9881266945824496, 0.9716106942212254, 0.4083748798487494], 
             178 -> RGBColor[
              0.9614477300094958, 0.8816162821978771, 0.30473214038253793`], 
             58 -> RGBColor[
              0.8924739228318184, 0.6046310215802007, 0.2319899443165854], 
             186 -> RGBColor[
              0.9135268988099774, 0.6948699997739933, 0.24927991687918932`], 
             122 -> RGBColor[
              0.9541755299481588, 0.8560282768835346, 0.2819867596389739], 
             249 -> RGBColor[
              0.9669014899037782, 0.9000130949250108, 0.32591896771568746`], 
             113 -> RGBColor[
              0.8466430246503907, 0.3595243033324397, 0.19229871912196295`], 
             52 -> RGBColor[
              0.9851337051624567, 0.9881204192853946, 0.8960365084032536], 
             187 -> RGBColor[
              0.9938338355482835, 0.9892195226696645, 0.5702292364656956], 
             259 -> RGBColor[
              0.9539283319730409, 0.8550482192860344, 0.28178785834571185`], 
             42 -> RGBColor[
              0.9944011045464518, 0.9919527270919772, 0.74245171734965], 134 -> 
             RGBColor[
              0.9284688973502735, 0.7541100448604201, 0.26130259963849517`], 
             313 -> RGBColor[
              0.947406403237283, 0.8291909451526701, 0.27654016139557785`], 
             248 -> RGBColor[
              0.879316763850862, 0.5448874355802301, 0.22101128835139688`], 
             174 -> RGBColor[
              0.9928525510992996, 0.9871206544563644, 0.4634224799794291], 
             215 -> RGBColor[
              0.8906458765109295, 0.5963302901881098, 0.23046457765692002`], 
             399 -> RGBColor[
              0.8977655710650225, 0.6286591603113362, 0.23640542531253847`], 
             83 -> 
             RGBColor[
              0.994935463488382, 0.9921736982468639, 0.7335960068052537], 95 -> 
             RGBColor[
              0.9202011624299989, 0.7213312309608718, 0.25465018605296114`], 
             166 -> RGBColor[
              0.9539733798603952, 0.965194002578332, 0.9627952416179572], 384 -> 
             RGBColor[
              0.9122195179761786, 0.6896866704268181, 0.24822796757214252`], 
             233 -> RGBColor[
              0.9934522063894176, 0.9884032564874767, 0.5286912576652896], 
             295 -> RGBColor[
              0.9840512231161735, 0.9578631719992697, 0.39254244279047473`], 
             141 -> RGBColor[
              0.894232742412844, 0.6126174105148885, 0.23345754648760622`], 
             319 -> RGBColor[
              0.9804839506207847, 0.9458299242369099, 0.3786842627687744], 
             205 -> RGBColor[
              0.9931817277010505, 0.98782472992265, 0.49925132163751573`], 
             224 -> RGBColor[
              0.9651549679467312, 0.8941216662610341, 0.3191340597155563], 
             231 -> RGBColor[
              0.8949565577345058, 0.615904086839191, 0.23406151573433784`], 
             332 -> RGBColor[
              0.9146079244251806, 0.6991559061078425, 0.25014973546411434`], 
             68 -> RGBColor[
              0.9225395411812516, 0.7306021234910623, 0.25653170048502283`], 
             10 -> RGBColor[
              0.9392193207214607, 0.9541904494300693, 0.9877700152652583], 
             250 -> RGBColor[
              0.9027000675187172, 0.6510655562266365, 0.2405228901090776], 
             282 -> RGBColor[
              0.9870186827316091, 0.9678731100747856, 0.4040704630387146], 
             374 -> RGBColor[
              0.9379953020981403, 0.7918790651995158, 0.268967768512088], 232 -> 
             RGBColor[
              0.9555252485550205, 0.8613794613926781, 0.2830727749120225], 
             253 -> RGBColor[
              0.9550908107419535, 0.8596570602316863, 0.28272321605006256`], 
             55 -> RGBColor[
              0.9484890984771832, 0.9611038345024191, 0.9720786994700665], 
             325 -> RGBColor[
              0.9928078624182739, 0.9912938805275207, 0.7688558625920137], 91 -> 
             RGBColor[
              0.9099126304985891, 0.6805406303028567, 0.2463717917580653], 
             105 -> RGBColor[
              0.9937534330874055, 0.989047549935782, 0.5614779247855866], 36 -> 
             RGBColor[
              0.9820614484140645, 0.9511511947077386, 0.38481254381020447`], 
             123 -> 
             RGBColor[
              0.9850899556792782, 0.9613670608406256, 0.39657772264995084`], 
             94 -> RGBColor[
              0.909873570599868, 0.6803857708203673, 0.24634036324670067`], 
             312 -> RGBColor[
              0.9847937612809049, 0.9879798437542138, 0.9016702582671311], 96 -> 
             RGBColor[
              0.9575882141148031, 0.8685972288276519, 0.28973864994007703`], 
             2 -> RGBColor[
              0.9930932121206845, 0.987635404046545, 0.4896169469695123], 262 -> 
             RGBColor[
              0.988339532166081, 0.9723286453674548, 0.4092017136701518], 272 -> 
             RGBColor[
              0.9940283135188367, 0.9896354913839387, 0.5913969633814953], 97 -> 
             RGBColor[
              0.9895477515736818, 0.9899457409122547, 0.8228843361833207], 
             372 -> RGBColor[
              0.9082368631475619, 0.9296674375137125, 0.9911096368712754], 
             356 -> RGBColor[
              0.9878791050916815, 0.9707755167320877, 0.4074130414304675], 
             346 -> RGBColor[
              0.9778956465559708, 0.9370989668635975, 0.3686291902371816], 
             341 -> RGBColor[
              0.9555182308141505, 0.861351638388652, 0.2830671282729909], 209 -> 
             RGBColor[
              0.9416509418712788, 0.8063724587302696, 0.27190918208244924`], 
             378 -> RGBColor[
              0.9447231817737879, 0.8185528661804597, 0.274381178422747], 66 -> 
             RGBColor[
              0.9896265705012657, 0.9766701278830049, 0.4142016145655488], 
             139 -> RGBColor[
              0.8238871912537549, 0.18461299617611987`, 0.1705077073623067], 
             56 -> RGBColor[
              0.8701940172696059, 0.503463174026343, 0.21339904498501552`], 
             335 -> RGBColor[
              0.9835983553143273, 0.9563355425652258, 0.3907831368972104], 
             314 -> RGBColor[
              0.9937170045342629, 0.9889696329441018, 0.5575129015869917], 
             144 -> RGBColor[
              0.9633134042393702, 0.8879096394563845, 0.31197993246258443`], 
             298 -> RGBColor[
              0.8918698667052568, 0.6018881437903774, 0.23148590507781186`], 
             204 -> RGBColor[
              0.9742036232599293, 0.9246449053577548, 0.3542863769121569], 
             207 -> RGBColor[
              0.9283251459616978, 0.753540118507028, 0.26118693389696834`], 
             334 -> RGBColor[
              0.8720708917820681, 0.5119856228322546, 0.2149651550846182], 
             149 -> 
             RGBColor[
              0.9744153679797312, 0.9253591700176711, 0.3551089651639522], 
             219 -> RGBColor[
              0.9947284465135329, 0.9911330050652895, 0.6676021191341787], 
             400 -> RGBColor[
              0.9325344523352648, 0.7702286156100235, 0.26457384061025985`], 
             9 -> RGBColor[
              0.9398757781596734, 0.7993345261519942, 0.2704808436916438], 11 -> 
             RGBColor[
              0.9246864889638953, 0.7391140560213071, 0.25825918506627943`], 
             44 -> RGBColor[
              0.9932492594922173, 0.9914764095609837, 0.7615407707777617], 
             153 -> RGBColor[
              0.8839951870777567, 0.5661310627800534, 0.22491507937056499`], 
             32 -> RGBColor[
              0.9936153889636535, 0.9887522875134785, 0.5464526738247699], 
             162 -> RGBColor[
              0.9938439305013509, 0.9917223213056082, 0.7516855331971795], 90 -> 
             RGBColor[
              0.994860540135762, 0.9921427155151131, 0.7348376806535898], 331 -> 
             RGBColor[
              0.9886021799661516, 0.9895547227524591, 0.8385549047809733], 8 -> 
             RGBColor[
              0.9153568815091886, 0.702125271370781, 0.2507523639141894], 364 -> 
             RGBColor[
              0.9539733798603952, 0.965194002578332, 0.9627952416179572], 342 -> 
             RGBColor[
              0.9652842692283118, 0.8945578298451903, 0.31963637077799906`], 
             163 -> RGBColor[
              0.9458742958792501, 0.823116650022581, 0.2753073918521227], 49 -> 
             RGBColor[
              0.9787333166504071, 0.9399246247864225, 0.37188338037334256`], 
             338 -> RGBColor[
              0.9939669205920554, 0.9917731808688157, 0.7496472691060541], 76 -> 
             RGBColor[
              0.9435549006332662, 0.813921020764903, 0.2734411519940004], 369 -> 
             RGBColor[
              0.9909548481296341, 0.990527611498873, 0.7995651048020327], 82 -> 
             RGBColor[
              0.9066347772393449, 0.6675450344098013, 0.24373435408457267`], 
             67 -> RGBColor[
              0.9578701121690432, 0.8695481371574144, 0.290833770648819], 211 -> 
             RGBColor[
              0.9940839682322794, 0.9897545311884378, 
               0.5974546354786513]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9mGk41G3YxiVbGGbGGGMMZp+JsVWihTktLbQQJSTFQyShTSoPqYhQlpJK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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 5}], {
             RGBColor[
             0.9658588494941208, 0.8963360244760372, 0.32270178684863327`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.9669341092463776, 0.8999631281033953, 0.32687896794038473`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 73}], {
             RGBColor[
             0.9474216379515801, 0.8292513457181903, 0.276552419604306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[
             0.901032483279097, 0.6102470941469006, 0.2376441855403579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 162}], {
             RGBColor[
             0.9746329362045771, 0.9263461031334849, 0.5173375925779662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 183}], {
             RGBColor[
             0.942356474408108, 0.8091696601340166, 0.27247687012255917`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 291}], {
             RGBColor[
             0.9751937677519094, 0.9263050618284165, 0.48820188375950546`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 357}], {
             RGBColor[
             0.9596058350371608, 0.9167424520168025, 0.6145841882040601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 368}], {
             RGBColor[
             0.9747197706992512, 0.9252912300612339, 0.43661022974838015`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 387}], {
             RGBColor[
             0.9225607346027592, 0.7265015121988694, 0.2563322863175124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 28}], {
             RGBColor[
             0.9494179598245689, 0.8258218396586351, 0.3663167604125671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 39}], {
             RGBColor[
             0.9883730237659076, 0.9720773603854123, 0.4403058643775509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 50}], {
             RGBColor[
             0.9928359968389204, 0.9870852465673059, 0.4616206508982148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 106}], {
             RGBColor[
             0.9681821436570902, 0.9724238226638595, 0.7352641993902136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 137}], {
             RGBColor[
             0.9635434902694275, 0.8818248608185162, 0.37768249377731455`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 138}], {
             RGBColor[
             0.9898108469606706, 0.98816629965798, 0.6812691984557807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 149}], {
             RGBColor[
             0.9837542900502079, 0.956497287032108, 0.42236295606673224`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 164}], {
             RGBColor[
             0.9501055787940733, 0.8285480197372816, 0.366870034775922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 197}], {
             RGBColor[
             0.9832538901309431, 0.9548093206049395, 0.42041899687298423`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 210}], {
             RGBColor[
             0.9819651612677726, 0.9504621355415387, 0.41541252859559197`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 217}], {
             RGBColor[
             0.9941112026352672, 0.9899446072435256, 0.6100011759639741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 230}], {
             RGBColor[
             0.9857619108395168, 0.9855347842442865, 0.7055062390879705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 254}], {
             RGBColor[
             0.9897745690016051, 0.9881512977896054, 0.6818704181218418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 258}], {
             RGBColor[
             0.9722414945069102, 0.9163095491820445, 0.3846811121551932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 314}], {
             RGBColor[
             0.9934051083274738, 0.9883025184953234, 0.5235649242782521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 328}], {
             RGBColor[
             0.9934434182887572, 0.9883844596287774, 0.5277347271422785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 7}], {
             RGBColor[
             0.9896237923692244, 0.9887086311183346, 0.7294136142986967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 13}], {
             RGBColor[
             0.984100910102565, 0.9708862352916336, 0.6392872396428327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 14}], {
             RGBColor[
             0.9690855561474774, 0.9192813665145765, 0.58592675898799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 21}], {
             RGBColor[
             0.9895447734262262, 0.988539617589302, 0.7208128900017194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 51}], {
             RGBColor[
             0.9889855935903332, 0.9873435884620809, 0.6599496157227057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 79}], {
             RGBColor[
             0.9682243201606642, 0.915866852816742, 0.5852337882971932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 188}], {
             RGBColor[
             0.971080520940641, 0.9269654053157055, 0.5887054864429352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 232}], {
             RGBColor[
             0.9704806515672593, 0.9248124549660225, 0.5870492855098449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 293}], {
             RGBColor[
             0.9848127266798368, 0.9879872542769403, 0.9013365996471618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 373}], {
             RGBColor[
             0.9834721420218135, 0.9869874484339927, 0.9036058597927188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 390}], {
             RGBColor[
             0.9889977637794767, 0.9873696192660639, 0.6612742657052744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 84}], {
             RGBColor[
             0.9332654245531475, 0.8187437365493377, 0.5983805320654199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 125}], {
             RGBColor[
             0.9742527525582012, 0.9795673297893761, 0.8948364296222397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 165}], {
             RGBColor[
             0.9766829006683564, 0.9790976290345421, 0.7473725923553356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 184}], {
             RGBColor[
             0.9764708496403094, 0.9786440733271975, 0.7242921465796844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 185}], {
             RGBColor[
             0.9763272850777873, 0.9783370032445664, 0.7086660299269221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 190}], {
             RGBColor[
             0.977046762284182, 0.9798758922387405, 0.7869766837443544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.9769385575373789, 0.9796444532265068, 0.775199264817134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 252}], {
             RGBColor[
             0.9741225220322939, 0.9711210271752921, 0.6812910624250392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 274}], {
             RGBColor[
             0.9465818965574028, 0.8715391105949701, 0.6090952780178156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 288}], {
             RGBColor[
             0.9764858264470282, 0.9786761072023815, 0.7259222795648842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 318}], {
             RGBColor[
             0.9435924346404769, 0.8596868902734885, 0.606689886787767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.977371016832695, 0.9353292676180711, 0.3665911028302651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 113}], {
             RGBColor[
             0.9114693908654145, 0.6456132336615763, 0.2773563204302383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 162}], {
             RGBColor[
             0.9850698437908946, 0.9617122426481606, 0.5570497274678465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 183}], {
             RGBColor[
             0.9527933819944254, 0.8445357996486924, 0.3121890050124395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 270}], {
             RGBColor[
             0.9797675967038251, 0.9593613717816138, 0.6378346817840741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 291}], {
             RGBColor[
             0.9856306753382269, 0.9616712013430924, 0.5279140186493858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 357}], {
             RGBColor[
             0.9700427426234783, 0.9521085915314782, 0.6542963230939405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 368}], {
             RGBColor[
             0.9851566782855685, 0.9606573695759096, 0.47632236463826055`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 10}], {
             RGBColor[
             0.9671076242762817, 0.9729477849935656, 0.8422429125567911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.9945705769883924, 0.991776017677273, 0.7217040472454035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 69}], {
             RGBColor[
             0.9760464669947966, 0.9293226948034791, 0.4922731048174825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 71}], {
             RGBColor[
             0.9926367088842765, 0.9852854762707342, 0.5567230617538138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 93}], {
             RGBColor[
             0.950236098752592, 0.9595856678846673, 0.8437810694248439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 129}], {
             RGBColor[
             0.9945107450765511, 0.9906673637045773, 0.6439066612162538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 131}], {
             RGBColor[
             0.9942881823352284, 0.9916592402309781, 0.7263840574622644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 142}], {
             RGBColor[
             0.9759236464789361, 0.9289083923638531, 0.4917959703060728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 201}], {
             RGBColor[
             0.9919500371258878, 0.9906923570993248, 0.7651331745068721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 253}], {
             RGBColor[
             0.9750433692865281, 0.9256810903943742, 0.4897195129491932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 273}], {
             RGBColor[
             0.9884713869996292, 0.9712348674897313, 0.5405415727869952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 281}], {
             RGBColor[
             0.9786855440459434, 0.9382249213817567, 0.502525420813305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 303}], {
             RGBColor[
             0.9915681110444715, 0.9816808448383676, 0.5525717609339411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 364}], {
             RGBColor[
             0.974484653845749, 0.9784495615676969, 0.8297555257331405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 391}], {
             RGBColor[
             0.9722478323257483, 0.914597717902351, 0.4874701582908636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 394}], {
             RGBColor[
             0.9905795580241801, 0.9783462233776377, 0.5487314191226829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 13}], {
             RGBColor[
             0.9882886478922912, 0.9713494178706015, 0.4776750578338621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 14}], {
             RGBColor[
             0.9732732939372036, 0.9197445490935443, 0.4243145771790193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 21}], {
             RGBColor[
             0.9937325112159525, 0.9890028001682697, 0.5592007081927488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 93}], {
             RGBColor[
             0.949643899916516, 0.9583190144547875, 0.7793238807455449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 142}], {
             RGBColor[
             0.9753314476428601, 0.9276417389339734, 0.4273387816267739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 188}], {
             RGBColor[
             0.9752682587303674, 0.9274285878946733, 0.42709330463396455`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 273}], {
             RGBColor[
             0.9878791881635531, 0.9699682140598516, 0.47608438410769627`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 293}], {
             RGBColor[
             0.989000464469563, 0.9884504368559082, 0.7397244178381912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 390}], {
             RGBColor[
             0.993185501569203, 0.9878328018450317, 0.4996620838963037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 16}], {
             RGBColor[
             0.952499512129942, 0.8394239640538252, 0.3325072368641002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 25}], {
             RGBColor[
             0.9550029012354195, 0.8465440896609302, 0.4548493087503834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 76}], {
             RGBColor[
             0.9294558910712274, 0.7580231460678419, 0.2620967579540949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 117}], {
             RGBColor[
             0.9546912219155941, 0.8458774391114368, 0.4209249382491866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 202}], {
             RGBColor[
             0.9538262988728916, 0.8466036831453103, 0.5140479070642303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 234}], {
             RGBColor[
             0.9528591684345149, 0.8462037498549231, 0.5300757612814757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 239}], {
             RGBColor[
             0.9307500978876505, 0.7631542448261042, 0.2631381071375274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 269}], {
             RGBColor[
             0.9422095268942764, 0.839286235314775, 0.5940031078770842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 302}], {
             RGBColor[
             0.9388660208849864, 0.7934349967886163, 0.2795436978462378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 323}], {
             RGBColor[
             0.898378015186835, 0.6282341654722403, 0.23675062268243896`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 365}], {
             RGBColor[
             0.9363398016611544, 0.7849134661621499, 0.26972981319812145`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 377}], {
             RGBColor[
             0.8943944581898258, 0.6101457635321956, 0.2334266450782172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 388}], {
             RGBColor[
             0.9291654091643444, 0.7568714821044087, 0.2618630293933303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 18}], {
             RGBColor[
             0.9580857676200558, 0.8655183450713536, 0.3164473827150787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 56}], {
             RGBColor[
             0.9050348977146396, 0.6513988500891685, 0.24193994433832966`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 65}], {
             RGBColor[
             0.9665044125113953, 0.8935275663423464, 0.3822167782717194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 100}], {
             RGBColor[
             0.9341394377756185, 0.7765918480513329, 0.2658652495694187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 174}], {
             RGBColor[
             0.9663641646294865, 0.8932275903041793, 0.36695166183553646`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 198}], {
             RGBColor[
             0.950583738053979, 0.8402122377846679, 0.28730341449027935`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 203}], {
             RGBColor[
             0.9324078859821201, 0.769726822195542, 0.26447200235162555`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 266}], {
             RGBColor[
             0.9668414084235875, 0.8942483665230121, 0.41889670361613457`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 313}], {
             RGBColor[
             0.9436410906984782, 0.8142627356523322, 0.27351050254361087`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 339}], {
             RGBColor[
             0.9665190086150143, 0.8935587859320948, 0.3838054740739302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 358}], {
             RGBColor[
             0.9665778964985652, 0.893684741160532, 0.3902150567845551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 384}], {
             RGBColor[
             0.926047648067926, 0.7445105982894061, 0.25935440563189316`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 32}], {
             RGBColor[
             0.9664173548425572, 0.971471368471774, 0.7671113445450142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 52}], {
             RGBColor[
             0.9621765129419587, 0.971155434357732, 0.941903261834256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 60}], {
             RGBColor[
             0.9541301168741347, 0.9653108967865457, 0.9625299267372562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 68}], {
             RGBColor[
             0.9308794309513562, 0.8423962864605659, 0.6221508578751406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.9666224415217302, 0.9719100281410809, 0.7894337639247211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 253}], {
             RGBColor[
             0.9471550657317072, 0.9069237548308777, 0.6352466156576604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 271}], {
             RGBColor[
             0.9318938397251266, 0.8464180792168803, 0.6229670749857504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 303}], {
             RGBColor[
             0.9636798074896504, 0.9629235092748714, 0.6980988636424084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 333}], {
             RGBColor[
             0.9315363235880848, 0.8450006468687, 0.6226794091099044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 334}], {
             RGBColor[
             0.9056451062517644, 0.7330880361311619, 0.6013675851749383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 337}], {
             RGBColor[
             0.9458600783665639, 0.9017895614570431, 0.634204638426406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 345}], {
             RGBColor[
             0.962828852835609, 0.971425193668127, 0.931092301594941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 353}], {
             RGBColor[
             0.9668294728963505, 0.9730795528744893, 0.8647916739156225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 364}], {
             RGBColor[
             0.946596350290928, 0.9596922260042007, 0.9752826284416077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 391}], {
             RGBColor[
             0.9443595287709272, 0.8958403823388545, 0.6329972609993308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 54}], {
             RGBColor[
             0.9560860033422371, 0.8641035051191557, 0.5576600365428218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 83}], {
             RGBColor[
             0.9598109762261386, 0.8656438771340855, 0.4959275959357666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 118}], {
             RGBColor[
             0.9568521069780004, 0.8644203086605091, 0.5449637166855708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 123}], {
             RGBColor[
             0.9548882223215867, 0.8502405584309664, 0.32741845385811513`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 141}], {
             RGBColor[
             0.9094596156883696, 0.6758657332680977, 0.2458583657769428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 161}], {
             RGBColor[
             0.9447843125099136, 0.8161576981253502, 0.2881666722030297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 196}], {
             RGBColor[
             0.9485452941097192, 0.8590268294735035, 0.5949280131248693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 206}], {
             RGBColor[
             0.9291225791779527, 0.7567016754806122, 0.2618285673809304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 214}], {
             RGBColor[
             0.9595545149102451, 0.8655378237892083, 0.5001778236407324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 286}], {
             RGBColor[
             0.9466273799596329, 0.8223747974060702, 0.29532664121110624`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 332}], {
             RGBColor[
             0.9196472066945379, 0.7191349810645749, 0.2542044602651969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 366}], {
             RGBColor[
             0.8952185435487368, 0.6112003507689274, 0.23397526610301192`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 386}], {
             RGBColor[
             0.9499605397714683, 0.8336183281145326, 0.3082753376656726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 19}], {
             RGBColor[
             0.9552766087286313, 0.8573006947912176, 0.5394226705927121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 24}], {
             RGBColor[
             0.9710982585283685, 0.9200282639949228, 0.552153141403433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 65}], {
             RGBColor[
             0.9913213035909118, 0.9888252771897752, 0.6587349884829301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 100}], {
             RGBColor[
             0.9589563288551348, 0.8718895588987616, 0.5423834597806294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 107}], {
             RGBColor[
             0.989792607705325, 0.9900469952152048, 0.818826436414636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 124}], {
             RGBColor[
             0.9899159530161128, 0.9844735444482889, 0.6202109169965482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 150}], {
             RGBColor[
             0.9550594901809215, 0.8564398921000153, 0.5392479719127974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 157}], {
             RGBColor[
             0.9656148638127533, 0.8982884311804775, 0.5477410733034324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 167}], {
             RGBColor[
             0.9870740266329987, 0.9748870594419975, 0.6091705696509149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 168}], {
             RGBColor[
             0.9873596165584484, 0.9758504213202426, 0.6102800325821547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 203}], {
             RGBColor[
             0.9572247770616366, 0.8650245330429709, 0.5409902125628362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 206}], {
             RGBColor[
             0.9615341148553582, 0.8821096213933846, 0.5444576069048233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 211}], {
             RGBColor[
             0.9917967642754928, 0.9898422395176448, 0.7104859497963583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 238}], {
             RGBColor[
             0.9790424186291773, 0.9477945597338688, 0.5779692891979741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 341}], {
             RGBColor[
             0.9725138955664283, 0.9256407931177519, 0.553292196193528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 358}], {
             RGBColor[
             0.9913947875780815, 0.9889824520079608, 0.6667332669957657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 14}], {
             RGBColor[
             0.9677504116705442, 0.9019221532668433, 0.3341882025231554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 21}], {
             RGBColor[
             0.988209628949293, 0.9711804043415686, 0.46907433353688477`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 51}], {
             RGBColor[
             0.9876504491134, 0.9699843752143475, 0.40821105925787116`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 79}], {
             RGBColor[
             0.966889175683731, 0.8985076395690086, 0.33349523183235863`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 87}], {
             RGBColor[
             0.973399208304851, 0.9219314248286623, 0.35116137671269565`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 205}], {
             RGBColor[
             0.9879737466633411, 0.9706758759832752, 0.4434000024077569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 232}], {
             RGBColor[
             0.9691455070903261, 0.9074532417182892, 0.3353107290450103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 277}], {
             RGBColor[
             0.9474926418009052, 0.8216068462353592, 0.31788832537507034`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 373}], {
             RGBColor[
             0.9821369975448804, 0.9696282351862593, 0.6518673033278841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 390}], {
             RGBColor[
             0.9876626193025435, 0.9700104060183307, 0.4095357092404397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 69}], {
             RGBColor[
             0.9549160319369734, 0.8586287767698412, 0.2843290608274769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 71}], {
             RGBColor[
             0.9715062738264533, 0.9145915582370963, 0.3487790177638082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 201}], {
             RGBColor[
             0.9708196020680647, 0.9199984390656869, 0.5571891305168666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 212}], {
             RGBColor[
             0.9735609112689525, 0.9203597334835822, 0.4556199487714685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 273}], {
             RGBColor[
             0.9673409519418061, 0.9005409494560934, 0.3325975287969896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 289}], {
             RGBColor[
             0.9484839169748801, 0.8334629280620749, 0.27740715424134665`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 293}], {
             RGBColor[
             0.9684622282478159, 0.91902317225215, 0.5962375625274845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 390}], {
             RGBColor[
             0.9726472653474559, 0.9184055372412736, 0.356175228585597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 35}], {
             RGBColor[
             0.9732987157984913, 0.9258545646497665, 0.5397436413592358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 106}], {
             RGBColor[
             0.9672063312865126, 0.9739085371294293, 0.8886909019882498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 154}], {
             RGBColor[
             0.9886263268366589, 0.98956470810396, 0.8381547286465707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 207}], {
             RGBColor[
             0.9597333666706135, 0.8720724757423561, 0.5288286430312765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 231}], {
             RGBColor[
             0.9430490725570175, 0.8032544599084377, 0.5152659339499613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 369}], {
             RGBColor[
             0.9910482177545816, 0.9905662222382787, 0.7980177284838088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 372}], {
             RGBColor[
             0.9496892252635456, 0.9601361352456985, 0.8937899945184301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 392}], {
             RGBColor[
             0.9920695200147376, 0.9890177085995439, 0.6378322358520884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 25}], {
             RGBColor[
             0.9921455318561729, 0.9838427823439745, 0.5366041817002941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 37}], {
             RGBColor[
             0.9885382193499623, 0.9828972147175405, 0.6360859375711693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 76}], {
             RGBColor[
             0.9665985216919808, 0.8953218387508863, 0.34385163090400567`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 77}], {
             RGBColor[
             0.9914135005066204, 0.9822770413070043, 0.456927086875324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 78}], {
             RGBColor[
             0.989808563159054, 0.9772840318516332, 0.41490862167462694`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 80}], {
             RGBColor[
             0.9923173008963604, 0.9842101789524216, 0.555300181689064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 96}], {
             RGBColor[
             0.9736151784327493, 0.9226599427822608, 0.352000379877044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 182}], {
             RGBColor[
             0.9914011681188787, 0.9822506635766205, 0.45558478257631496`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.9917379891494895, 0.9829710897032671, 0.49224567313985323`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 269}], {
             RGBColor[
             0.9793521575150298, 0.9765849279978194, 0.6757579808269949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 302}], {
             RGBColor[
             0.9760086515057398, 0.9307336894716606, 0.3612985707961486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 323}], {
             RGBColor[
             0.9355206458075884, 0.7655328581552846, 0.31850549563234976`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 365}], {
             RGBColor[
             0.9734824322819078, 0.9222121588451941, 0.3514846861480322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 377}], {
             RGBColor[
             0.9315370888105792, 0.7474444562152399, 0.315181518028128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 388}], {
             RGBColor[
             0.9663080397850978, 0.894170174787453, 0.343617902343241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 18}], {
             RGBColor[
             0.9700427426234783, 0.9521085915314782, 0.6542963230939405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 31}], {
             RGBColor[
             0.9747567037647412, 0.9680098893516694, 0.6726091719708811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 62}], {
             RGBColor[
             0.978711707322006, 0.9806532215588317, 0.7473114848682303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.9676262784205656, 0.943957290362277, 0.6449088159765989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 111}], {
             RGBColor[
             0.9743517867163356, 0.9666440090683529, 0.6710361456999936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 222}], {
             RGBColor[
             0.9474977911779225, 0.8687380928813548, 0.6048417719025994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 223}], {
             RGBColor[
             0.9760356721321437, 0.9809685902135054, 0.8950231010610694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 247}], {
             RGBColor[
             0.9653676210220128, 0.9736918089803088, 0.943507763425382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 256}], {
             RGBColor[
             0.960163062307668, 0.918782109966997, 0.6159156306880953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 292}], {
             RGBColor[
             0.9735876609275242, 0.9798223012827592, 0.9295933799951177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 310}], {
             RGBColor[
             0.958173394951721, 0.9110633044103953, 0.613431613287625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 319}], {
             RGBColor[
             0.9721368393936516, 0.9591724716545766, 0.6624314936090709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 384}], {
             RGBColor[
             0.9380046230713485, 0.8311008447495307, 0.5972033460107549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 99}], {
             RGBColor[
             0.9738792928775255, 0.9235508628215119, 0.353026414621172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 144}], {
             RGBColor[
             0.9698045806599043, 0.9098059017235487, 0.33719692710054905`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.9687937275143614, 0.9063960567040275, 0.33326995351371425`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 218}], {
             RGBColor[
             0.9828815071740835, 0.9608073092194234, 0.593316128442031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 266}], {
             RGBColor[
             0.9850513978839699, 0.9604321854423714, 0.46486324263956946`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 310}], {
             RGBColor[
             0.964426409408681, 0.8906568768696301, 0.3215492119321981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 319}], {
             RGBColor[
             0.9783898538506115, 0.9387660441138115, 0.370549092253644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 384}], {
             RGBColor[
             0.9442576375283085, 0.8106944172087656, 0.30532094465532805`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 24}], {
             RGBColor[
             0.9368653069382937, 0.7873990109392885, 0.26805854788207994`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 85}], {
             RGBColor[
             0.943698199212031, 0.811416739359429, 0.2895576300137694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 107}], {
             RGBColor[
             0.9555596561152502, 0.8574177421595706, 0.534731842893283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 124}], {
             RGBColor[
             0.955683001426038, 0.8518442913926547, 0.33611632347519516`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 150}], {
             RGBColor[
             0.9208265385908467, 0.723810639044381, 0.25515337839144436`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 152}], {
             RGBColor[
             0.954833044967677, 0.8571172697769944, 0.546773670017942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 157}], {
             RGBColor[
             0.9313819122226784, 0.7656591781248434, 0.26364647978207933`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 160}], {
             RGBColor[
             0.9537700272321035, 0.8453913802488127, 0.32868477996662343`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 167}], {
             RGBColor[
             0.9528410750429238, 0.8422578063863633, 0.32507597612956185`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 168}], {
             RGBColor[
             0.9531266649683735, 0.8432211682646084, 0.32618543906080166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 181}], {
             RGBColor[
             0.8744516664937559, 0.4699093476321319, 0.21481992008415468`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 211}], {
             RGBColor[
             0.957563812685418, 0.8572129864620106, 0.42639135627500513`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 238}], {
             RGBColor[
             0.9448094670391024, 0.8151653066782346, 0.29387469567662106`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 64}], {
             RGBColor[
             0.9705832965954257, 0.9124326934252598, 0.34022209146188526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 88}], {
             RGBColor[
             0.9141702609486066, 0.6856544061470291, 0.2560952652678129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 89}], {
             RGBColor[
             0.9565451093400748, 0.8641098131484217, 0.29073179893241163`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 120}], {
             RGBColor[
             0.9437152301482681, 0.8132436174567055, 0.28040857697871335`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 140}], {
             RGBColor[
             0.9727025941526621, 0.919581581720548, 0.3484551622759863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 189}], {
             RGBColor[
             0.9648382279366128, 0.8930532278328138, 0.3179035845875785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 195}], {
             RGBColor[
             0.9523907352846384, 0.8476391043817042, 0.28738909205171526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 241}], {
             RGBColor[
             0.9695755271624411, 0.9090332504922867, 0.33630709751602805`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 255}], {
             RGBColor[
             0.9599948025445515, 0.876715216695028, 0.29908779154355836`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 257}], {
             RGBColor[
             0.9692966560603051, 0.9080925527827337, 0.33522373594461885`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 263}], {
             RGBColor[
             0.9732498700794947, 0.9333057984196917, 0.5903777232434195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 312}], {
             RGBColor[
             0.9725985116115119, 0.9330364449540318, 0.6011724187195768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 336}], {
             RGBColor[
             0.953686995721945, 0.9190322417802539, 0.6376617406317042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 356}], {
             RGBColor[
             0.9741411835169002, 0.9244342814429688, 0.354043810301245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 359}], {
             RGBColor[
             0.9445138498499281, 0.8164098784495482, 0.2810511651366828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 360}], {
             RGBColor[
             0.9673730654104481, 0.9016038298402029, 0.327750949509538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 389}], {
             RGBColor[
             0.9385819512377368, 0.9072785561916101, 0.6462986107698103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 109}], {
             RGBColor[
             0.9710550301687781, 0.9110941426927717, 0.4139925662809735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[
             0.9916049394477163, 0.9893915491830398, 0.6866706074868703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 132}], {
             RGBColor[
             0.9927341181897149, 0.9898584936114263, 0.667957193511044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 180}], {
             RGBColor[
             0.9932574577930251, 0.9879867089318969, 0.5074940747969996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 232}], {
             RGBColor[
             0.9745893704139874, 0.9251066240159576, 0.41683637940389695`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 249}], {
             RGBColor[
             0.9802774910883663, 0.9444234407821239, 0.43825947580572944`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 370}], {
             RGBColor[
             0.9485338855041361, 0.8215712045960948, 0.3958594146754498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 45}], {
             RGBColor[
             0.982446438097357, 0.9511569458660034, 0.49624784264472843`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 74}], {
             RGBColor[
             0.981839966292464, 0.9514963121088219, 0.5491969006930777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 116}], {
             RGBColor[
             0.9814216559087641, 0.9489650403859761, 0.3847066256389636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 141}], {
             RGBColor[
             0.9322638558387895, 0.7620387540756257, 0.2862797703579026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 179}], {
             RGBColor[
             0.9769036163332037, 0.9493420755971483, 0.6259478054927348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 209}], {
             RGBColor[
             0.955972955568007, 0.8589162781833163, 0.30550558815532414`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 286}], {
             RGBColor[
             0.9694316201100528, 0.9085478182135982, 0.335748045792066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 290}], {
             RGBColor[
             0.9675598335139335, 0.9022338425084948, 0.32847650832338143`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 304}], {
             RGBColor[
             0.97786470046457, 0.9498524375293158, 0.6150773431194652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 338}], {
             RGBColor[
             0.9821309449283953, 0.9516166392525893, 0.5443746316671265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 38}], {
             RGBColor[
             0.9282774329379052, 0.7533509522671131, 0.2611485428780562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 92}], {
             RGBColor[
             0.9555243587935112, 0.8533247083133093, 0.3250029780902453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 98}], {
             RGBColor[
             0.9308590123780462, 0.7635860544869207, 0.2632257422930514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 119}], {
             RGBColor[
             0.9488915011667861, 0.8643917941834665, 0.5983040634494383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 128}], {
             RGBColor[
             0.9368130197409452, 0.7871917096254775, 0.2680164763757551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 130}], {
             RGBColor[
             0.9563132769215098, 0.8698314062468686, 0.5814626293561032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 139}], {
             RGBColor[
             0.8758733492194162, 0.46815350604938644`, 0.2156599886848298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 143}], {
             RGBColor[
             0.9609806572989112, 0.8707433516571443, 0.43010429509450665`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 146}], {
             RGBColor[
             0.959580364166075, 0.8711824307828087, 0.5273185387628998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 151}], {
             RGBColor[
             0.9609298435623781, 0.8717404751932186, 0.504954172825429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 158}], {
             RGBColor[
             0.9268949060889708, 0.74786969401085, 0.26003612932332765`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 186}], {
             RGBColor[
             0.9206932029975274, 0.7232820078483232, 0.2550460934432711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 213}], {
             RGBColor[
             0.9335394139532691, 0.8529422326763612, 0.6242911426363056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 267}], {
             RGBColor[
             0.9562945879757158, 0.8559228722032977, 0.3279951730175339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 306}], {
             RGBColor[
             0.9352149221128316, 0.7808557850644728, 0.26673060951200234`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 308}], {
             RGBColor[
             0.9594667523788747, 0.8666233275947747, 0.34031843271082396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 311}], {
             RGBColor[
             0.9605392036272384, 0.8715789355410499, 0.5114280874944397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 346}], {
             RGBColor[
             0.9528775768705242, 0.8443964913931252, 0.31472073012226726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 348}], {
             RGBColor[
             0.9476920328306708, 0.826904433723058, 0.29457587073526015`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 354}], {
             RGBColor[
             0.9480540227565093, 0.828125510742188, 0.29598213324108147`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 374}], {
             RGBColor[
             0.932927404641609, 0.7717865405610844, 0.26489001925972044`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 33}], {
             RGBColor[
             0.9679667819180485, 0.9026377966901812, 0.33510284009595714`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 56}], {
             RGBColor[
             0.9114404870038184, 0.6767948770846683, 0.2470940318389082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 65}], {
             RGBColor[
             0.9729100018005741, 0.9189235933378461, 0.38737086577229796`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 100}], {
             RGBColor[
             0.9405450270647973, 0.8019878750468326, 0.27101933706999726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 107}], {
             RGBColor[
             0.9713813059149874, 0.9201453113632757, 0.5474623137040038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 124}], {
             RGBColor[
             0.9715046512257752, 0.9145718605963599, 0.34884679428591614`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 150}], {
             RGBColor[
             0.9366481883905838, 0.7865382082480862, 0.26788384920216524`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 157}], {
             RGBColor[
             0.9472035620224155, 0.8283867473285484, 0.2763769505928002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 167}], {
             RGBColor[
             0.9686627248426609, 0.9049853755900684, 0.33780644694028283`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 168}], {
             RGBColor[
             0.9689483147681106, 0.9059487374683135, 0.33891590987152265`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 203}], {
             RGBColor[
             0.9388134752712989, 0.7951228491910418, 0.26962608985220404`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 206}], {
             RGBColor[
             0.9431228130650205, 0.8122079375414555, 0.27309348419419116`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 211}], {
             RGBColor[
             0.9733854624851551, 0.9199405556657158, 0.4391218270857261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 238}], {
             RGBColor[
             0.9606311168388395, 0.8778928758819398, 0.306605166487342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 341}], {
             RGBColor[
             0.9541025937760907, 0.8557391092658229, 0.2819280734828959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 358}], {
             RGBColor[
             0.972983485787744, 0.9190807681560317, 0.3953691442851336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 386}], {
             RGBColor[
             0.963960773658536, 0.8891245901753759, 0.3195402544789333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 37}], {
             RGBColor[
             0.9910416084554399, 0.9900173403246455, 0.7584280094574525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 62}], {
             RGBColor[
             0.994141303719572, 0.9898771659982497, 0.6036952494368353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[
             0.9691019107974583, 0.9024419643579912, 0.4661937027902888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 78}], {
             RGBColor[
             0.9923119522645314, 0.9844041574587381, 0.5372506935609102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 91}], {
             RGBColor[
             0.9522807757301197, 0.835751769126968, 0.45265902267232133`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 117}], {
             RGBColor[
             0.994337241641825, 0.9902962574015859, 0.6250218830853805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 182}], {
             RGBColor[
             0.9939045572243561, 0.9893707891837253, 0.5779268544625982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 187}], {
             RGBColor[
             0.994241378254967, 0.9900912153103719, 0.6145877450261364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 208}], {
             RGBColor[
             0.9516339709258619, 0.8331874036130094, 0.45213858834435533`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 239}], {
             RGBColor[
             0.9703961176138813, 0.9075730631162533, 0.46723505197372134`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 269}], {
             RGBColor[
             0.9818555466205072, 0.9837050536049242, 0.7981000527132782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 309}], {
             RGBColor[
             0.9605060540105737, 0.8683622565974642, 0.45927727464887025`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 323}], {
             RGBColor[
             0.938024034913066, 0.7726529837623894, 0.4408475675186329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 362}], {
             RGBColor[
             0.9719281518740261, 0.913647068437574, 0.4684677627008998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 365}], {
             RGBColor[
             0.9759858213873853, 0.9293322844522991, 0.4738267580343154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 377}], {
             RGBColor[
             0.9340404779160567, 0.7545645818223448, 0.43752358991441115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 388}], {
             RGBColor[
             0.9688114288905754, 0.9012903003945578, 0.4659599742295242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 395}], {
             RGBColor[
             0.9838145222523077, 0.9557403307360594, 0.5042397825684313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 70}], {
             RGBColor[
             0.9571854515220637, 0.8672386160291878, 0.28817399332261795`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 177}], {
             RGBColor[
             0.9687880842510748, 0.9254623924506827, 0.601841655790446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 285}], {
             RGBColor[
             0.9739760088260462, 0.928162763966965, 0.5407197588993278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 324}], {
             RGBColor[
             0.9749113836751448, 0.9266652682371551, 0.3882496572505313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 40}], {
             RGBColor[
             0.9506437710461724, 0.8393549406278129, 0.2930561009491899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 41}], {
             RGBColor[
             0.979016611870666, 0.9405503037572122, 0.40103984280140786`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 48}], {
             RGBColor[
             0.9408781286254757, 0.915024101688543, 0.6552188263244609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 63}], {
             RGBColor[
             0.9772961942078093, 0.9417750745705724, 0.5702934780721556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 86}], {
             RGBColor[
             0.9206550802689535, 0.7124195963777562, 0.2685105863240405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 250}], {
             RGBColor[
             0.933847842118157, 0.772324846687176, 0.27951895019520057`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 265}], {
             RGBColor[
             0.9792506176626357, 0.9410508184846202, 0.4265099291409494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 295}], {
             RGBColor[
             0.9745234199168851, 0.9257236545734926, 0.3555287265358992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 325}], {
             RGBColor[
             0.9789017395679354, 0.9424390088376181, 0.5436854364366686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 376}], {
             RGBColor[
             0.978110638005286, 0.9421118680110798, 0.5567960366349834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 39}], {
             RGBColor[
             0.9446977714697922, 0.8102637959975023, 0.31700567782060574`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 50}], {
             RGBColor[
             0.9491607445428049, 0.825271682179396, 0.3383204643412696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 106}], {
             RGBColor[
             0.9245068913609746, 0.8106102582759496, 0.6119640128332684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 197}], {
             RGBColor[
             0.9395786378348274, 0.7929957562170296, 0.29711881031603904`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 217}], {
             RGBColor[
             0.9504359503391517, 0.8281310428556157, 0.4867009894070289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 231}], {
             RGBColor[
             0.9003496326314795, 0.6399561810549581, 0.2385390447949799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 254}], {
             RGBColor[
             0.9460993167054896, 0.8263377334016955, 0.5585702315648966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 314}], {
             RGBColor[
             0.9497298560313581, 0.8264889541074134, 0.40026473772130683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 369}], {
             RGBColor[
             0.9483487778290437, 0.8272679433847991, 0.5212908393288274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 113}], {
             RGBColor[
             0.9125446506176712, 0.6492403372889344, 0.28153350152198975`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 162}], {
             RGBColor[
             0.9861451035431513, 0.9653393462755187, 0.561226908559598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 183}], {
             RGBColor[
             0.9538686417466822, 0.8481629032760505, 0.316366186104191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 270}], {
             RGBColor[
             0.9808428564560818, 0.9629884754089719, 0.6420118628758256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 357}], {
             RGBColor[
             0.9711180023757351, 0.9557356951588363, 0.658473504185692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 153}], {
             RGBColor[
             0.9395493211662957, 0.7790330868118938, 0.4666672928548786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 168}], {
             RGBColor[
             0.9901565640265126, 0.9768530028186837, 0.5527311536947184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 175}], {
             RGBColor[
             0.9925045043885932, 0.9847731569825953, 0.5618524586300687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 211}], {
             RGBColor[
             0.994593711743557, 0.990844821016086, 0.6529370709089217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 216}], {
             RGBColor[
             0.9946597581289818, 0.9909860875561955, 0.6601258123713585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 229}], {
             RGBColor[
             0.9897576538960094, 0.9898785127589061, 0.8082094904189605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 294}], {
             RGBColor[
             0.9909976269066483, 0.9903912734646582, 0.7876599286853888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 329}], {
             RGBColor[
             0.9894595878112143, 0.9896927410549936, 0.8103497248037049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 341}], {
             RGBColor[
             0.9753108430344926, 0.9266433746161931, 0.49574331730609156`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 343}], {
             RGBColor[
             0.9928331443942069, 0.9911503071164114, 0.7572406537495546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 358}], {
             RGBColor[
             0.9941917350461458, 0.9899850335064019, 0.6091843881083293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 379}], {
             RGBColor[
             0.953314185069356, 0.8394339557361681, 0.4780442899794195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 99}], {
             RGBColor[
             0.9785932540187885, 0.939452160641703, 0.37133926349811275`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 111}], {
             RGBColor[
             0.9853187623145585, 0.9621388793477789, 0.39746659322150735`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 169}], {
             RGBColor[
             0.9897246472886682, 0.9762464049746388, 0.4787448702351589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 199}], {
             RGBColor[
             0.9853343584748865, 0.9757735800127121, 0.649101418940084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 215}], {
             RGBColor[
             0.9381847779369468, 0.7799175249096026, 0.31475209857465747`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 222}], {
             RGBColor[
             0.9584647667761454, 0.8642329631607808, 0.3312722194241132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 223}], {
             RGBColor[
             0.9870026477303666, 0.9764634604929313, 0.6214535485825832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 224}], {
             RGBColor[
             0.9754393236548476, 0.9288132129460647, 0.35908683960397564`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 247}], {
             RGBColor[
             0.9763345966202357, 0.9691866792597348, 0.6699382109468959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 259}], {
             RGBColor[
             0.9698260056680026, 0.9092764894585649, 0.3404137389190534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 292}], {
             RGBColor[
             0.9845546365257472, 0.9753171715621851, 0.6560238275166316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 363}], {
             RGBColor[
             0.9881265639872789, 0.9769282287484949, 0.6028273476035089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 383}], {
             RGBColor[
             0.9892203890451762, 0.9751678475801385, 0.42385947235221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 393}], {
             RGBColor[
             0.9600505550102161, 0.8705200850762678, 0.3325481818604804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 400}], {
             RGBColor[
             0.9591290658491145, 0.8668666876205595, 0.33180673005132744`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 46}], {
             RGBColor[
             0.9609702674626757, 0.8711462030102533, 0.40381980386086913`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 52}], {
             RGBColor[
             0.989374547063055, 0.9884363533994366, 0.7212445911140117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 71}], {
             RGBColor[
             0.9919464394505517, 0.9838090597489424, 0.4815914937420368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 105}], {
             RGBColor[
             0.9936844110255295, 0.9888999187246303, 0.5539652993051782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 111}], {
             RGBColor[
             0.9892646171149031, 0.9747626432889704, 0.4711731203876948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 129}], {
             RGBColor[
             0.9938204756428266, 0.9891909471827856, 0.5687750932044768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 199}], {
             RGBColor[
             0.9892802132752312, 0.9883973439539037, 0.7228079461062715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 215}], {
             RGBColor[
             0.9421306327372916, 0.7925412888507941, 0.388458625740845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 247}], {
             RGBColor[
             0.9802804514205805, 0.9818104432009265, 0.7436447381130833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 259}], {
             RGBColor[
             0.9737718604683472, 0.9219002533997565, 0.4141202660852409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 271}], {
             RGBColor[
             0.959091873846223, 0.863698998258585, 0.4023084042655063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 287}], {
             RGBColor[
             0.9935456332907568, 0.9901612047466178, 0.6521188978958612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 292}], {
             RGBColor[
             0.9885004913260917, 0.9879409355033768, 0.7297303546828191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 303}], {
             RGBColor[
             0.9908778416107469, 0.980204428316576, 0.4774401929221642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 333}], {
             RGBColor[
             0.9587343577091811, 0.8622815659104046, 0.4020207383896602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 337}], {
             RGBColor[
             0.9730581124876603, 0.9190704804987477, 0.4135459677061618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 345}], {
             RGBColor[
             0.9900268869567055, 0.9887061127098316, 0.7104336308746968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 353}], {
             RGBColor[
             0.9940275070174468, 0.990360471916194, 0.6441330031953783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 385}], {
             RGBColor[
             0.9933817755176553, 0.9882526119744307, 0.5210252919229246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 391}], {
             RGBColor[
             0.9715575628920237, 0.9131213013805592, 0.4123385902790866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 400}], {
             RGBColor[
             0.9630749206494591, 0.879490451561751, 0.40551325721751486`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 58}], {
             RGBColor[
             0.9378602649649423, 0.7798900174087846, 0.31070330290784937`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 74}], {
             RGBColor[
             0.9883157852091295, 0.9733407699093248, 0.5743542343285348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 107}], {
             RGBColor[
             0.9866611310950051, 0.9726565279104632, 0.6017761351071601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 116}], {
             RGBColor[
             0.9878974748254297, 0.970809498186479, 0.40986395927442076`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 118}], {
             RGBColor[
             0.9861321660450859, 0.9724377872685399, 0.6105424549019877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 124}], {
             RGBColor[
             0.9867844764057929, 0.9670830771435474, 0.40316061568907235`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 141}], {
             RGBColor[
             0.9387396747554551, 0.7838832118761285, 0.3114371039933598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 150}], {
             RGBColor[
             0.9519280135706015, 0.8390494247952737, 0.3221976706053215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 152}], {
             RGBColor[
             0.9859345199474319, 0.972356055527887, 0.6138179622318192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 156}], {
             RGBColor[
             0.9887734924119759, 0.9726832112251369, 0.5052130674161028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 157}], {
             RGBColor[
             0.9624833872024332, 0.8808979638757359, 0.3306907719959565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 179}], {
             RGBColor[
             0.9833794352498693, 0.9711865333976513, 0.651105139128192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 206}], {
             RGBColor[
             0.9584026382450382, 0.864719154088643, 0.32740730559734743`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 209}], {
             RGBColor[
             0.9624487744846726, 0.8807607359838192, 0.3306629217907813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 245}], {
             RGBColor[
             0.9885066770291968, 0.9721125201005456, 0.47617185959426783`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 286}], {
             RGBColor[
             0.9759074390267184, 0.930392276014101, 0.3609053794275232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 386}], {
             RGBColor[
             0.9792405988385537, 0.9416358067225634, 0.3738540758820895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 43}], {
             RGBColor[
             0.9922769698779871, 0.9909086056013121, 0.7656067797903496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 159}], {
             RGBColor[
             0.9879706518537616, 0.9892935696484537, 0.8490209599456401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 250}], {
             RGBColor[
             0.9460820624024066, 0.8204883437000647, 0.5323971286157849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 265}], {
             RGBColor[
             0.9914848379468852, 0.9892143154975089, 0.6793881075615337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 321}], {
             RGBColor[
             0.991457663393556, 0.9907355385322676, 0.7912321546346563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 375}], {
             RGBColor[
             0.9755807863220058, 0.9361849990019899, 0.5649869382078186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 381}], {
             RGBColor[
             0.9879821758092704, 0.9892983351002087, 0.8488299781798188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 73}], {
             RGBColor[
             0.947438589106405, 0.8293185513984336, 0.27656605890137287`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 154}], {
             RGBColor[
             0.9707834552556209, 0.924814439776042, 0.5814280178402217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 207}], {
             RGBColor[
             0.9418904950895756, 0.8073222074144382, 0.2721019322249275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 231}], {
             RGBColor[
             0.9252062009759796, 0.7385041915805197, 0.2585392231436123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 280}], {
             RGBColor[
             0.9093320539774807, 0.6664233975615625, 0.24529344577711576`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 291}], {
             RGBColor[
             0.9752107189067344, 0.9263722675086601, 0.48821552305657234`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 372}], {
             RGBColor[
             0.9318463536825077, 0.8953858669177804, 0.6370632837120811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 387}], {
             RGBColor[
             0.9225776857575843, 0.7265687178791128, 0.25634592561457936`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 392}], {
             RGBColor[
             0.9742266484336997, 0.9242674402716258, 0.3811055250457393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 61}], {
             RGBColor[
             0.8996902242070323, 0.5426390973538693, 0.2745152719051022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 70}], {
             RGBColor[
             0.969853682078204, 0.909971532337035, 0.33738767683861864`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 90}], {
             RGBColor[
             0.9884609942749132, 0.9716469551114258, 0.5598251122318971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 95}], {
             RGBColor[
             0.9511313054220317, 0.8362412128343052, 0.31973136493158283`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 148}], {
             RGBColor[
             0.968576129578009, 0.9054041274697124, 0.3337678799301335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 228}], {
             RGBColor[
             0.9874244877973697, 0.9690663847885457, 0.42057878576421737`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 276}], {
             RGBColor[
             0.9815716444149174, 0.9494989708071672, 0.3829097477652418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 282}], {
             RGBColor[
             0.9845400655728368, 0.9595121523912621, 0.3944415034244595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 301}], {
             RGBColor[
             0.9611537391443294, 0.8759768227651623, 0.32779565036129926`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 305}], {
             RGBColor[
             0.9872004227604865, 0.9711256763950001, 0.5807160444804538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 361}], {
             RGBColor[
             0.9860322554372567, 0.9645456591867925, 0.40023837927132005`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 382}], {
             RGBColor[
             0.9832425185589879, 0.9551352216350226, 0.3894007782968495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 76}], {
             RGBColor[
             0.9654945982912477, 0.9014963967315572, 0.565675458661164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 78}], {
             RGBColor[
             0.9887046397583209, 0.9834585898323042, 0.6367324494317853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 80}], {
             RGBColor[
             0.9912133774956273, 0.9903847369330925, 0.7771240094462224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 96}], {
             RGBColor[
             0.9725112550320162, 0.9288345007629317, 0.5738242076342024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 104}], {
             RGBColor[
             0.9902685056381975, 0.9883637515712489, 0.6742805388381534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 117}], {
             RGBColor[
             0.9907299291356144, 0.9893506897751521, 0.7245036389562557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 145}], {
             RGBColor[
             0.9551916660969193, 0.8606487038296735, 0.5573854775767064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 182}], {
             RGBColor[
             0.9902972447181456, 0.9884252215572915, 0.6774086103334733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 187}], {
             RGBColor[
             0.9906340657487565, 0.989145647683938, 0.7140695008970116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 208}], {
             RGBColor[
             0.9480266584196513, 0.8322418359865755, 0.5516203442152305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 269}], {
             RGBColor[
             0.9782482341142967, 0.9827594859784903, 0.8975818085841534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 323}], {
             RGBColor[
             0.9344167224068554, 0.7717074161359556, 0.5403293233895081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 365}], {
             RGBColor[
             0.9723785088811747, 0.9283867168258652, 0.5733085139051906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 377}], {
             RGBColor[
             0.9304331654098461, 0.7536190141959109, 0.5370053457852864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 388}], {
             RGBColor[
             0.9652041163843648, 0.900344732768124, 0.5654417301003993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 395}], {
             RGBColor[
             0.9802072097460972, 0.9547947631096254, 0.6037215384393064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 44}], {
             RGBColor[
             0.960972309091475, 0.8732421490862784, 0.5115127932632606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 66}], {
             RGBColor[
             0.9591609645959993, 0.865839008247289, 0.3378432151571542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 81}], {
             RGBColor[
             0.9344347543879661, 0.7777626800108639, 0.2661028682476854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 119}], {
             RGBColor[
             0.9493094269196137, 0.8660487305279264, 0.5986403363201416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 128}], {
             RGBColor[
             0.9372309454937728, 0.7888486459699375, 0.26835274924645836`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 130}], {
             RGBColor[
             0.9567312026743374, 0.8714883425913286, 0.5817989022268064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 135}], {
             RGBColor[
             0.9409532232220137, 0.8036062367868899, 0.27134778127968884`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 146}], {
             RGBColor[
             0.9599982899189026, 0.8728393671272687, 0.5276548116336033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 151}], {
             RGBColor[
             0.9613477693152057, 0.8733974115376786, 0.5052904456961322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 213}], {
             RGBColor[
             0.9339573397060967, 0.8545991690208212, 0.6246274155070088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 224}], {
             RGBColor[
             0.946925163318732, 0.8245647774363036, 0.2903094377321579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 227}], {
             RGBColor[
             0.958103561449507, 0.862272139144105, 0.3337354036068607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 243}], {
             RGBColor[
             0.9612906117214849, 0.8733737754037919, 0.5062376949431973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 267}], {
             RGBColor[
             0.9567125137285434, 0.8575798085477577, 0.3283314458882372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 306}], {
             RGBColor[
             0.9356328478656593, 0.7825127214089329, 0.2670668823827057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 311}], {
             RGBColor[
             0.960957129380066, 0.87323587188551, 0.511764360365143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 346}], {
             RGBColor[
             0.9532955026233518, 0.8460534277375853, 0.31505700299297057`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 350}], {
             RGBColor[
             0.9612826934220589, 0.8733705009834882, 0.5063689216565888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 363}], {
             RGBColor[
             0.9596124036511633, 0.8726797932387338, 0.5340499457316912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 383}], {
             RGBColor[
             0.9607062287090605, 0.8709194120703774, 0.35508207048039225`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 47}], {
             RGBColor[
             0.9882598578899147, 0.9718353100194885, 0.4279884571545486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 50}], {
             RGBColor[
             0.9881158084841437, 0.9715272029061732, 0.4123095683062534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 136}], {
             RGBColor[
             0.9805214225548005, 0.9695887017473177, 0.6570758885614416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 149}], {
             RGBColor[
             0.979034101695431, 0.9409392433709753, 0.37305187347477087`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 164}], {
             RGBColor[
             0.9453853904392965, 0.8129899760761488, 0.3175589521839606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 197}], {
             RGBColor[
             0.9785337017761663, 0.9392512769438068, 0.37110791428102285`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 210}], {
             RGBColor[
             0.9772449729129957, 0.9349040918804059, 0.36610144600363054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 217}], {
             RGBColor[
             0.9893910142804905, 0.9743865635823927, 0.5606900933720127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 230}], {
             RGBColor[
             0.9810417224847401, 0.9699767405831536, 0.6561951564960091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 254}], {
             RGBColor[
             0.9850543806468284, 0.9725932541284726, 0.6325593355298804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 258}], {
             RGBColor[
             0.9675213061521334, 0.9007515055209119, 0.3353700295632318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 314}], {
             RGBColor[
             0.9886849199726969, 0.9727444748341907, 0.4742538416862906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 328}], {
             RGBColor[
             0.9887232299339803, 0.9728264159676447, 0.47842364455031716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 41}], {
             RGBColor[
             0.9646647661992418, 0.8863211072373096, 0.3755809334692741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 48}], {
             RGBColor[
             0.9265262829540515, 0.8607949051686403, 0.6297599169923271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 63}], {
             RGBColor[
             0.9629443485363851, 0.8875458780506698, 0.544834568740022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 103}], {
             RGBColor[
             0.9377324557552833, 0.790836967038439, 0.26875627617482856`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 265}], {
             RGBColor[
             0.9648987719912114, 0.8868216219647177, 0.40105101980881563`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 295}], {
             RGBColor[
             0.9601715742454608, 0.87149445805359, 0.33006981720376544`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 48}], {
             RGBColor[
             0.9548991237785451, 0.9619902682980395, 0.7377436588445452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 63}], {
             RGBColor[
             0.9913171893608788, 0.9887412411800689, 0.6528183105922399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.9478688372712263, 0.8192910132966726, 0.36204378271528487`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 265}], {
             RGBColor[
             0.9932716128157051, 0.988016985094117, 0.5090347616610337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 295}], {
             RGBColor[
             0.9885444150699545, 0.9726898211829893, 0.4380535590559834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 325}], {
             RGBColor[
             0.9929227347210047, 0.9894051754471147, 0.6262102689567529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 381}], {
             RGBColor[
             0.9897689506780902, 0.9881010046968166, 0.6784766322793188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 67}], {
             RGBColor[
             0.9761356083577475, 0.9307504321246958, 0.5166427439992345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 75}], {
             RGBColor[
             0.9946833490712337, 0.9917964828937245, 0.7179329164549539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 133}], {
             RGBColor[
             0.9928427972640654, 0.99130832698404, 0.7682769017887647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 178}], {
             RGBColor[
             0.9779244172779737, 0.9367845046449272, 0.523591928866094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 200}], {
             RGBColor[
             0.944058265844296, 0.8011105648923251, 0.48773880164741157`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 278}], {
             RGBColor[
             0.9932822263198171, 0.9885900007281107, 0.583254116914772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 296}], {
             RGBColor[
             0.9757226778697435, 0.9293575206279693, 0.5150385870287187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 320}], {
             RGBColor[
             0.9939115267541052, 0.9901456330005934, 0.633924820370735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 330}], {
             RGBColor[
             0.989406478541818, 0.9898873208830277, 0.8252255959241894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 347}], {
             RGBColor[
             0.9845231822020493, 0.9862818919625813, 0.835127429111024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 367}], {
             RGBColor[
             0.9884263524651137, 0.972209998002795, 0.5643899639440823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 398}], {
             RGBColor[
             0.9912638995644507, 0.9817817106566014, 0.5754132985991997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 159}], {
             RGBColor[
             0.9907835644456529, 0.9902910440762729, 0.7903563726134976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 250}], {
             RGBColor[
             0.9488949749942978, 0.8214858181278839, 0.47373254128364234`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 265}], {
             RGBColor[
             0.9942977505387764, 0.9902117899253282, 0.6207235202293911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 321}], {
             RGBColor[
             0.9942705759854472, 0.9917330129600869, 0.7325675673025138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 325}], {
             RGBColor[
             0.9939488724440761, 0.991599980278326, 0.7378990275251104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 375}], {
             RGBColor[
             0.978393698913897, 0.9371824734298093, 0.5063223508756761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 381}], {
             RGBColor[
             0.9907950884011616, 0.9902958095280279, 0.7901653908476762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 66}], {
             RGBColor[
             0.9914379149967415, 0.9840732687219943, 0.5878711926716553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 81}], {
             RGBColor[
             0.9667117047887084, 0.8959969404855692, 0.5161308457621865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 119}], {
             RGBColor[
             0.9815863773203559, 0.9842829910026317, 0.8486683138346427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[
             0.969507895894515, 0.9070829064446428, 0.5183807267609595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 130}], {
             RGBColor[
             0.9890081530750796, 0.9897226030660339, 0.8318268797413075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 135}], {
             RGBColor[
             0.9732301736227559, 0.9218404972615952, 0.5213757587941898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 146}], {
             RGBColor[
             0.9922752403196449, 0.991073627601974, 0.7776827891481043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 151}], {
             RGBColor[
             0.993624719715948, 0.9916316720123839, 0.7553184232106334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 227}], {
             RGBColor[
             0.9903805118502492, 0.9805063996188104, 0.5837633811213618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 243}], {
             RGBColor[
             0.9935675621222271, 0.9916080358784972, 0.7562656724576984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 267}], {
             RGBColor[
             0.9889894641292856, 0.975814069022463, 0.5783594234027383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 275}], {
             RGBColor[
             0.9564254126004486, 0.8552152196627939, 0.5078542536172027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 311}], {
             RGBColor[
             0.9932340797808082, 0.9914701323602153, 0.7617923378796441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 317}], {
             RGBColor[
             0.9938444422817287, 0.9917225329399466, 0.7516770516718742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 326}], {
             RGBColor[
             0.9936831712499188, 0.9906508849527291, 0.681299872595782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 344}], {
             RGBColor[
             0.989097148539513, 0.9897594049776562, 0.8303519945827673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 346}], {
             RGBColor[
             0.9855724530240941, 0.9642876882122906, 0.5650849805074717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 383}], {
             RGBColor[
             0.9929831791098027, 0.9891536725450827, 0.6051100479948933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 48}], {
             RGBColor[
             0.9556792737316668, 0.9636589301625071, 0.8226581667144282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 74}], {
             RGBColor[
             0.993991435125086, 0.9911931603384625, 0.706342749109607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 103}], {
             RGBColor[
             0.9668854465328987, 0.8937009920323058, 0.46165452589692946`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 116}], {
             RGBColor[
             0.993573124741386, 0.9886618886156167, 0.5418524740554931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 262}], {
             RGBColor[
             0.99146871954803, 0.9815912197315494, 0.5312977023657048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 290}], {
             RGBColor[
             0.9797113023465553, 0.9419306907381354, 0.4856223567399109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 304}], {
             RGBColor[
             0.9900161692971919, 0.9895492857589564, 0.7722231915359947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 338}], {
             RGBColor[
             0.9942824137610171, 0.9913134874822298, 0.701520480083656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 52}], {
             RGBColor[
             0.9567294255620773, 0.8708302688962113, 0.578611721150111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 60}], {
             RGBColor[
             0.9486830294942533, 0.8649857313250251, 0.5992383860531112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 102}], {
             RGBColor[
             0.9475502134742411, 0.8265637405598776, 0.2933078019013441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 105}], {
             RGBColor[
             0.9610392895245516, 0.8712938342214049, 0.41133242934127745`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 128}], {
             RGBColor[
             0.9370458391292553, 0.788114760917665, 0.2682038083205628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 139}], {
             RGBColor[
             0.8761061686077263, 0.46907655734157394`, 0.21584732062963752`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 199}], {
             RGBColor[
             0.9566350917742533, 0.8707912594506784, 0.5801750761423707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 213}], {
             RGBColor[
             0.9337722333415792, 0.8538652839685485, 0.6244784745811134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 215}], {
             RGBColor[
             0.9094855112363136, 0.6749352043475689, 0.24582575577694418`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 259}], {
             RGBColor[
             0.9411267389673694, 0.8042941688965312, 0.2714873961213401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 271}], {
             RGBColor[
             0.9264467523452451, 0.7460929137553596, 0.2596755343016055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 287}], {
             RGBColor[
             0.9609005117897789, 0.8725551202433925, 0.5094860279319604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 333}], {
             RGBColor[
             0.9260892362082034, 0.7446754814071794, 0.2593878684257594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 337}], {
             RGBColor[
             0.9404129909866825, 0.8014643959955225, 0.270913097742261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 345}], {
             RGBColor[
             0.9573817654557276, 0.8711000282066064, 0.567800760910796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 350}], {
             RGBColor[
             0.9610975870575413, 0.8726366159312157, 0.5062199807306932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 353}], {
             RGBColor[
             0.9613823855164689, 0.8727543874129687, 0.5015001332314775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 400}], {
             RGBColor[
             0.9304297991484813, 0.7618843670585258, 0.26288038725361407`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 136}], {
             RGBColor[
             0.9851284450335843, 0.9849046950425266, 0.6940695639304006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 149}], {
             RGBColor[
             0.9836411241742149, 0.9562552366661843, 0.4100455488437299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 155}], {
             RGBColor[
             0.993865385393532, 0.9892870045984721, 0.5736632424179049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 268}], {
             RGBColor[
             0.5858969401843492, 0.6462726516573487, 0.6992415662617538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 279}], {
             RGBColor[
             0.9499924129180803, 0.8283059693713578, 0.35455262755291966`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 299}], {
             RGBColor[
             0.9772090225340961, 0.9345582475047789, 0.3850580485723426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 300}], {
             RGBColor[
             0.9933569162617102, 0.9881994405396205, 0.5183195153268467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 371}], {
             RGBColor[
             0.9940245404729847, 0.9896274212203746, 0.5909862906250436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.9531787061156884, 0.9632150391113997, 0.9069972941152931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 86}], {
             RGBColor[
             0.8965375921768325, 0.7338595609185836, 0.6052144023671779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 103}], {
             RGBColor[
             0.9279668133345866, 0.866506128099169, 0.6309190015500996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 295}], {
             RGBColor[
             0.9504059318247642, 0.94716361911432, 0.6922325425790365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 191}], {
             RGBColor[
             0.979761454918019, 0.9433927765814227, 0.3758775033953946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 225}], {
             RGBColor[
             0.9782040048234399, 0.9381391317057348, 0.3698271038777261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 235}], {
             RGBColor[
             0.9836677483082794, 0.9647396737694408, 0.6052191425771579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 261}], {
             RGBColor[
             0.9329050904361332, 0.7600244318669316, 0.29968494334588297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 327}], {
             RGBColor[
             0.9868595592066807, 0.9658040433538084, 0.5337485150972643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 335}], {
             RGBColor[
             0.9811658359823672, 0.9481300836758242, 0.38133325863527645`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 349}], {
             RGBColor[
             0.9651638434932965, 0.8928597319644684, 0.3258966392004601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 355}], {
             RGBColor[
             0.9646915458093015, 0.8909872290313017, 0.3255166173976662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 127}], {
             RGBColor[
             0.9468277638614916, 0.8151147610937811, 0.33639635290394776`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 137}], {
             RGBColor[
             0.9632862749876634, 0.8812747033392772, 0.34968619770601705`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 138}], {
             RGBColor[
             0.9895536316789064, 0.9876161421787408, 0.6532729023844832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 147}], {
             RGBColor[
             0.9627369766415412, 0.8790969184397253, 0.34924421936303773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 164}], {
             RGBColor[
             0.9498483635123092, 0.8279978622580425, 0.3388737387046245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 197}], {
             RGBColor[
             0.982996674849179, 0.9542591631257005, 0.39242270080168673`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 210}], {
             RGBColor[
             0.9817079459860085, 0.9499119780622995, 0.38741623252429447`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 217}], {
             RGBColor[
             0.9938539873535033, 0.9893944497642865, 0.5820048798926766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 230}], {
             RGBColor[
             0.9855046955577529, 0.9849846267650474, 0.6775099430166729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 242}], {
             RGBColor[
             0.9851267372768145, 0.9614443638565571, 0.40069759110451353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 254}], {
             RGBColor[
             0.9895173537198412, 0.9876011403103664, 0.6538741220505444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 258}], {
             RGBColor[
             0.9719842792251461, 0.9157593917028055, 0.3566848160838957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 328}], {
             RGBColor[
             0.9931862030069931, 0.9878343021495384, 0.4997384310709811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 331}], {
             RGBColor[
             0.990590480761654, 0.988044905920263, 0.6360896298039453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 79}], {
             RGBColor[
             0.9717738591714993, 0.9149649927394559, 0.3541576079122317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 87}], {
             RGBColor[
             0.9782838917926193, 0.9383887779991096, 0.3718237527925687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 126}], {
             RGBColor[
             0.9894867587754629, 0.9875508331454897, 0.651644011631184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 176}], {
             RGBColor[
             0.9709448040999746, 0.9116780656470864, 0.35349053074125936`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 205}], {
             RGBColor[
             0.9928584301511094, 0.9871332291537225, 0.46406237848763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 232}], {
             RGBColor[
             0.9740301905780944, 0.9239105948887365, 0.35597310512488334`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 277}], {
             RGBColor[
             0.9523773252886735, 0.8380641994058065, 0.33855070145494337`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 298}], {
             RGBColor[
             0.9422024996532126, 0.7941649360875861, 0.33017967020777805`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 373}], {
             RGBColor[
             0.9870216810326486, 0.9860855883567066, 0.6725296794077572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 390}], {
             RGBColor[
             0.9925473027903118, 0.9864677591887778, 0.4301980853203128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 60}], {
             RGBColor[
             0.9770873090946328, 0.9822758817142083, 0.9166631733062538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 68}], {
             RGBColor[
             0.9538366231718541, 0.8593612713882285, 0.5762841044441382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 105}], {
             RGBColor[
             0.989443569124931, 0.9885839846105884, 0.72875721659442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 129}], {
             RGBColor[
             0.9895796337422281, 0.9888750130687436, 0.7435670104937186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 199}], {
             RGBColor[
             0.9850393713746328, 0.9880814098398617, 0.8975998633955133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 271}], {
             RGBColor[
             0.9548510319456245, 0.863383064144543, 0.5771003215547481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 287}], {
             RGBColor[
             0.9893047913901584, 0.9898452706325759, 0.826910815185103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 303}], {
             RGBColor[
             0.9866369997101485, 0.979888494202534, 0.652232110211406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 333}], {
             RGBColor[
             0.9544935158085828, 0.8619656317963627, 0.5768126556789019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 337}], {
             RGBColor[
             0.9688172705870619, 0.9187545463847058, 0.5883378849954036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 345}], {
             RGBColor[
             0.9857860450561071, 0.9883901785957896, 0.8852255481639386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 353}], {
             RGBColor[
             0.9897866651168483, 0.9900445378021521, 0.8189249204846201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 391}], {
             RGBColor[
             0.9673167209914253, 0.9128053672665173, 0.5871305075683284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 69}], {
             RGBColor[
             0.975621116152086, 0.9293935919236901, 0.5172613422145621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 93}], {
             RGBColor[
             0.9498107479098815, 0.9596565650048783, 0.8687693068219235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 131}], {
             RGBColor[
             0.993862831492518, 0.9917301373511891, 0.751372294859344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 142}], {
             RGBColor[
             0.9754982956362257, 0.9289792894840642, 0.5167842077031524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 188}], {
             RGBColor[
             0.9754351067237329, 0.9287661384447641, 0.5165387307103431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 201}], {
             RGBColor[
             0.9915246862831774, 0.9907632542195358, 0.7901214119039517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 264}], {
             RGBColor[
             0.9938069965837255, 0.9917070481815118, 0.7522976237941457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 273}], {
             RGBColor[
             0.9880460361569188, 0.9713057646099423, 0.5655298101840748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 281}], {
             RGBColor[
             0.978260193203233, 0.9382958185019677, 0.5275136582103845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[
             0.9891673124629285, 0.9897879874059989, 0.8291698439145697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 394}], {
             RGBColor[
             0.9901542071814696, 0.9784171204978487, 0.5737196565197624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 64}], {
             RGBColor[
             0.984124424484656, 0.967932647456837, 0.6184152458855562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 83}], {
             RGBColor[
             0.9912104906044805, 0.990633326231934, 0.795328447412309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 123}], {
             RGBColor[
             0.9862877366999286, 0.975230007528815, 0.6268193053346576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 161}], {
             RGBColor[
             0.9761838268882554, 0.9411471472231987, 0.5875675236795721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 196}], {
             RGBColor[
             0.9799448084880611, 0.9840162785713521, 0.8943288646014117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 198}], {
             RGBColor[
             0.9743886078344319, 0.9350914518171729, 0.5805934366541395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 206}], {
             RGBColor[
             0.9605220935562947, 0.8816911245784608, 0.5612294188574728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 214}], {
             RGBColor[
             0.990954029288587, 0.9905272728870569, 0.7995786751172748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 310}], {
             RGBColor[
             0.9700212897287515, 0.9193522719827756, 0.5688726950726234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 332}], {
             RGBColor[
             0.9510467210728799, 0.8441244301624233, 0.5536053117417392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 389}], {
             RGBColor[
             0.952123079126967, 0.9627785102231872, 0.9244917651934812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 57}], {
             RGBColor[
             0.9431544181484697, 0.8761434229207348, 0.6204526024213717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 68}], {
             RGBColor[
             0.9355143198292174, 0.8458529789967407, 0.6143051999775446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 72}], {
             RGBColor[
             0.9708188254576618, 0.9744288029461191, 0.7338595492369094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 83}], {
             RGBColor[
             0.9717122809827826, 0.9766387663746414, 0.8528373531376601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 123}], {
             RGBColor[
             0.9667895270782307, 0.9612354476715224, 0.6843282110600086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 161}], {
             RGBColor[
             0.9566856172665574, 0.9271525873659061, 0.6450764294049233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 196}], {
             RGBColor[
             0.9604465988663631, 0.9700217187140596, 0.9518377703267629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 236}], {
             RGBColor[
             0.9703924073568889, 0.9760929647111294, 0.8747110748421689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 262}], {
             RGBColor[
             0.968414315321632, 0.9667162399349369, 0.6906402065701092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 284}], {
             RGBColor[
             0.97091320995786, 0.9746306818483061, 0.7441327196098596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 334}], {
             RGBColor[
             0.9102799951296257, 0.7365447286673368, 0.5935219272773424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 366}], {
             RGBColor[
             0.9071198483053808, 0.7221952400094833, 0.5908850233049054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 397}], {
             RGBColor[
             0.95431827250709, 0.9191669776132393, 0.6358797420499376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 65}], {
             RGBColor[
             0.9316635320663615, 0.7455918902795209, 0.35367587891840524`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 100}], {
             RGBColor[
             0.8992985573305847, 0.6286561719885073, 0.23732435021610454`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 174}], {
             RGBColor[
             0.9315232841844527, 0.7452919142413537, 0.33841076248222235`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 198}], {
             RGBColor[
             0.9157428576089452, 0.6922765617218424, 0.2587625151369652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 203}], {
             RGBColor[
             0.8975670055370863, 0.6217911461327165, 0.23593110299831138`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 206}], {
             RGBColor[
             0.9018763433308081, 0.6388762344831302, 0.2393984973402985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 266}], {
             RGBColor[
             0.9320005279785537, 0.7463126904601864, 0.39035580426282046`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 341}], {
             RGBColor[
             0.9128561240418782, 0.6824074062074975, 0.24823308662900323`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 358}], {
             RGBColor[
             0.9317370160535314, 0.7457490650977063, 0.361674157431241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 68}], {
             RGBColor[
             0.930179639500504, 0.7608925674150564, 0.2626791029288499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 72}], {
             RGBColor[
             0.9654841451289484, 0.8894683913644348, 0.3822334521882146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 86}], {
             RGBColor[
             0.9070671408200333, 0.6612190334734238, 0.24366633386971714`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 108}], {
             RGBColor[
             0.9661027282027584, 0.890791478010972, 0.44956240232022027`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 236}], {
             RGBColor[
             0.9650577270281755, 0.8911325531294452, 0.5230849777934741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 262}], {
             RGBColor[
             0.9630796349929186, 0.8817558283532527, 0.3390141095214143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 284}], {
             RGBColor[
             0.9655785296291466, 0.8896702702666218, 0.39250662256116475`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 297}], {
             RGBColor[
             0.9656848243887284, 0.8898976240093187, 0.4040761511664357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 325}], {
             RGBColor[
             0.9653138001190151, 0.8912384459332856, 0.5188411839823452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 376}], {
             RGBColor[
             0.9645226985563657, 0.8909113051067473, 0.53195178418066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 397}], {
             RGBColor[
             0.9489835921783765, 0.834206566031555, 0.28425364500124284`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 124}], {
             RGBColor[
             0.9413981342726689, 0.7918240813149633, 0.32444725709780836`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 152}], {
             RGBColor[
             0.9405481778143079, 0.797097059699303, 0.5351046036405551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 156}], {
             RGBColor[
             0.943387150278852, 0.797424215396553, 0.4264997088248388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 160}], {
             RGBColor[
             0.9394851600787344, 0.7853711701711212, 0.31701571358923664`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 179}], {
             RGBColor[
             0.9379930931167453, 0.7959275375690672, 0.5723917805369281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 181}], {
             RGBColor[
             0.8601667993403869, 0.40988913755444045`, 0.20315085370676786`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 220}], {
             RGBColor[
             0.9396828606951402, 0.7967392288328914, 0.5494451476740854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[
             0.9431203348960728, 0.7968535242719617, 0.39745850100300384`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 352}], {
             RGBColor[
             0.9431970250987062, 0.7970175568608255, 0.40580575628257565`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 396}], {
             RGBColor[
             0.9303212634375941, 0.7544591950153012, 0.28141570559507967`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 132}], {
             RGBColor[
             0.9792656002322413, 0.9451360669553988, 0.555257275228668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 149}], {
             RGBColor[
             0.970565912168869, 0.9123740516724265, 0.3401545562474858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 155}], {
             RGBColor[
             0.9807901733881861, 0.9454058196047143, 0.5037722498216607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 164}], {
             RGBColor[
             0.9369172009127344, 0.7844247843776, 0.2846616349566755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 210}], {
             RGBColor[
             0.9687767833864338, 0.9063389001818571, 0.3332041287763455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 230}], {
             RGBColor[
             0.9725735329581782, 0.9414115488846049, 0.6232978392687241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 258}], {
             RGBColor[
             0.9590531166255714, 0.872186313822363, 0.30247271233594675`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 264}], {
             RGBColor[
             0.9800926116898881, 0.9454780574463607, 0.5415515551384138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 268}], {
             RGBColor[
             0.5728217281790035, 0.6023914666635909, 0.6293505736655096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 279}], {
             RGBColor[
             0.9369172009127344, 0.7844247843776, 0.2846616349566755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 299}], {
             RGBColor[
             0.9641338105287502, 0.890677062511021, 0.31516705597609845`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 300}], {
             RGBColor[
             0.9802817042563644, 0.9443182555458627, 0.4484285227306025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 328}], {
             RGBColor[
             0.9802550404074184, 0.9442612242690959, 0.4455263273230321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 394}], {
             RGBColor[
             0.9764398222876323, 0.9321881297626976, 0.3629735878640306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 68}], {
             RGBColor[
             0.9457902271040302, 0.8535167338170422, 0.5969107693471385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 72}], {
             RGBColor[
             0.9810947327324746, 0.9820925577664206, 0.7164651186065032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 102}], {
             RGBColor[
             0.9679080970067966, 0.9380093533778746, 0.631359254057487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 105}], {
             RGBColor[
             0.9813971730571072, 0.9827394470394021, 0.7493838814974203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 108}], {
             RGBColor[
             0.9817133158062847, 0.9834156444129578, 0.7837940687385089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 139}], {
             RGBColor[
             0.8964640521402818, 0.580522170159571, 0.5538987727857805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 297}], {
             RGBColor[
             0.9812954119922547, 0.9825217904113045, 0.7383078175847244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 333}], {
             RGBColor[
             0.9464471197407589, 0.8561210942251765, 0.5974393205819023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 337}], {
             RGBColor[
             0.960770874519238, 0.9129100088135196, 0.6089645498984039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 345}], {
             RGBColor[
             0.9777396489882831, 0.9825456410246034, 0.905852213066939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 353}], {
             RGBColor[
             0.9817402690490244, 0.9842000002309659, 0.8395515853876203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 70}], {
             RGBColor[
             0.8874824578711717, 0.5014594349831658, 0.2270904049335164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 90}], {
             RGBColor[
             0.9060897700678809, 0.5631348577575566, 0.44952784032679494`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 95}], {
             RGBColor[
             0.8687600812149995, 0.4277291154804359, 0.20943409302648058`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 148}], {
             RGBColor[
             0.8862049053709767, 0.49689203011584315`, 0.22347060802503127`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 228}], {
             RGBColor[
             0.9050532635903374, 0.5605542874346763, 0.3102815138591152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 282}], {
             RGBColor[
             0.9021688413658046, 0.5510000550373928, 0.2841442315193573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 285}], {
             RGBColor[
             0.9042730151751541, 0.5623835829209429, 0.47963617051022633`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 301}], {
             RGBColor[
             0.8787825149372972, 0.4674647254112931, 0.21749837845619702`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 382}], {
             RGBColor[
             0.9008712943519557, 0.5466231242811532, 0.27910350639174725`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 91}], {
             RGBColor[
             0.9517731584880413, 0.8346660271741384, 0.39740801852257934`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 111}], {
             RGBColor[
             0.9892737658718231, 0.9747822115549412, 0.47216890611885654`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 117}], {
             RGBColor[
             0.9938296243997466, 0.9892105154487563, 0.5697708789356386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 223}], {
             RGBColor[
             0.9909576512876312, 0.9891067927000936, 0.6961558614799324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 247}], {
             RGBColor[
             0.9802896001775006, 0.9818300114668972, 0.7446405238442451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 256}], {
             RGBColor[
             0.9750850414631557, 0.9269203124535853, 0.41704839110695824`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 319}], {
             RGBColor[
             0.9870588185491391, 0.967310674141165, 0.4635642540279339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 323}], {
             RGBColor[
             0.9375164176709876, 0.7715672418095598, 0.3855965633688909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 362}], {
             RGBColor[
             0.9714205346319478, 0.9125613264847443, 0.4132167585511578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 395}], {
             RGBColor[
             0.9833069050102293, 0.9546545887832296, 0.4489887784186893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 103}], {
             RGBColor[
             0.9643848789169202, 0.8932571009811985, 0.5459936532977944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 295}], {
             RGBColor[
             0.9868239974070978, 0.9739145919963494, 0.6073071943267312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 88}], {
             RGBColor[
             0.9243502956019136, 0.7199940534184391, 0.29564277755767576`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 101}], {
             RGBColor[
             0.9787704945286928, 0.9400500344996613, 0.37202780941002944`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 115}], {
             RGBColor[
             0.9865919125102571, 0.9689530171669729, 0.5775225836470326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 120}], {
             RGBColor[
             0.953895264801575, 0.8475832647281154, 0.3199560892685762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 123}], {
             RGBColor[
             0.9829266434640055, 0.9540697007686477, 0.38817366320084945`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 140}], {
             RGBColor[
             0.9828826288059691, 0.9539212289919581, 0.38800267456584914`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 161}], {
             RGBColor[
             0.9728227336523323, 0.9199868404630316, 0.3489218815457641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 193}], {
             RGBColor[
             0.9755817259681674, 0.9292935693865456, 0.35964004570080266`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 195}], {
             RGBColor[
             0.9625707699379453, 0.8819787516531142, 0.3269366043415781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 214}], {
             RGBColor[
             0.9875929360526639, 0.9693669661268897, 0.5609330329834668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 233}], {
             RGBColor[
             0.9871077688190752, 0.9675877985920733, 0.4542304307085189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 257}], {
             RGBColor[
             0.9794766907136121, 0.9424322000541436, 0.3747712482344817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 283}], {
             RGBColor[
             0.982394224932466, 0.9522737280439487, 0.3861053177446215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 312}], {
             RGBColor[
             0.9827785462648189, 0.9673760922254417, 0.6407199310094396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 332}], {
             RGBColor[
             0.9476856278369568, 0.8229641234022562, 0.3149596696079312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 356}], {
             RGBColor[
             0.9843212181702072, 0.9587739287143788, 0.39359132259110785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 360}], {
             RGBColor[
             0.9775531000637552, 0.9359434771116129, 0.36729846179940084`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 380}], {
             RGBColor[
             0.9789925846629195, 0.9407991966716511, 0.37289058764329724`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 389}], {
             RGBColor[
             0.9487619858910439, 0.94161820346302, 0.6858461230596733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 100}], {
             RGBColor[
             0.9607680721273404, 0.8707848882416851, 0.3776011841494943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 167}], {
             RGBColor[
             0.9888857699052043, 0.9737823887849208, 0.44438829401977986`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 174}], {
             RGBColor[
             0.9929927989812084, 0.9874206304945315, 0.47868759641561204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 198}], {
             RGBColor[
             0.9772123724057009, 0.9344052779750203, 0.39903934907035493`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 203}], {
             RGBColor[
             0.9590365203338421, 0.8639198623858944, 0.3762079369317011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 206}], {
             RGBColor[
             0.9633458581275638, 0.881004950736308, 0.37967533127368824`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 211}], {
             RGBColor[
             0.9936085075476984, 0.9887375688605682, 0.5457036741652231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 266}], {
             RGBColor[
             0.9934700427753094, 0.9884414067133642, 0.5306326381962101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 313}], {
             RGBColor[
             0.9702697250502001, 0.9084557758426843, 0.38524643712368645`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 329}], {
             RGBColor[
             0.9884743836153557, 0.9875854888994758, 0.7031163280600063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 340}], {
             RGBColor[
             0.9932259118364981, 0.9879192353206712, 0.5040604921081104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 341}], {
             RGBColor[
             0.9743256388386339, 0.9245361224606754, 0.388509920562393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 358}], {
             RGBColor[
             0.9932065308502871, 0.9878777813508841, 0.5019509913646307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 81}], {
             RGBColor[
             0.9649003602932326, 0.8885937996465798, 0.3424612676560801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 119}], {
             RGBColor[
             0.9797750328248802, 0.9768798501636423, 0.6749987357285363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 130}], {
             RGBColor[
             0.9871968085796039, 0.9823194622270445, 0.6581573016352011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 146}], {
             RGBColor[
             0.9904638958241689, 0.9836704867629846, 0.6040132110419978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 151}], {
             RGBColor[
             0.9918133752204721, 0.9842285311733945, 0.581648845104527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 158}], {
             RGBColor[
             0.9577784377470648, 0.860357749991026, 0.3367308016024256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 243}], {
             RGBColor[
             0.9917562176267514, 0.9842048950395078, 0.582596094351592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 267}], {
             RGBColor[
             0.9871781196338099, 0.9684109281834736, 0.4046898452966319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 275}], {
             RGBColor[
             0.9546140681049727, 0.8478120788238045, 0.3341846755110963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 311}], {
             RGBColor[
             0.9914227352853324, 0.9840669915212259, 0.5881227597735377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 317}], {
             RGBColor[
             0.9920330977862528, 0.9843193921009572, 0.5780074735657676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 344}], {
             RGBColor[
             0.9872858040440373, 0.9823562641386668, 0.6566824164766609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 346}], {
             RGBColor[
             0.9837611085286182, 0.9568845473733012, 0.3914154024013652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 354}], {
             RGBColor[
             0.9789375544146033, 0.9406135667223638, 0.3726768055201794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 75}], {
             RGBColor[
             0.9764178528825294, 0.930594187926443, 0.4921239431045385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 126}], {
             RGBColor[
             0.9721542485594004, 0.9291040375317996, 0.5826241792867214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 133}], {
             RGBColor[
             0.9745773010753611, 0.9301060320167587, 0.5424679284383493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 200}], {
             RGBColor[
             0.9257927696555917, 0.7399082699250437, 0.26192982829699607`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 320}], {
             RGBColor[
             0.9756460305654009, 0.9289433380333121, 0.4081158470203196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 347}], {
             RGBColor[
             0.9662576860133449, 0.9250795969952998, 0.6093184557606086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 398}], {
             RGBColor[
             0.9729984033757464, 0.9205794156893199, 0.34960432524878415`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 72}], {
             RGBColor[
             0.957844046809696, 0.8591779474404407, 0.37608604974438753`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 236}], {
             RGBColor[
             0.9574176287089231, 0.860842109205451, 0.516937575349647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 262}], {
             RGBColor[
             0.9554395366736663, 0.8514653844292586, 0.3328667070775873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 284}], {
             RGBColor[
             0.9579384313098942, 0.8593798263426278, 0.38635922011733775`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 333}], {
             RGBColor[
             0.9231964338179802, 0.7332064838991965, 0.25706025171978664`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 334}], {
             RGBColor[
             0.8973052164816598, 0.6212938731616584, 0.23574842778482052`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 337}], {
             RGBColor[
             0.9375201885964594, 0.7899953984875396, 0.2685854810362882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 376}], {
             RGBColor[
             0.9568826002371135, 0.8606208611827533, 0.5258043817368331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 391}], {
             RGBColor[
             0.9360196390008226, 0.7840462193693511, 0.2673781036092131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 397}], {
             RGBColor[
             0.9413434938591241, 0.8039161221075609, 0.2781062425574158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 93}], {
             RGBColor[
             0.9312866379162859, 0.8972032421310845, 0.6393383643940025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 131}], {
             RGBColor[
             0.9753387214989222, 0.9292768144773953, 0.521941352431423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 142}], {
             RGBColor[
             0.9569741856426299, 0.8665259666102703, 0.2873532652752315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 188}], {
             RGBColor[
             0.9569109967301372, 0.8663128155709702, 0.2871077882824221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 201}], {
             RGBColor[
             0.9730005762895817, 0.9283099313457419, 0.5606904694760309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 273}], {
             RGBColor[
             0.969521926163323, 0.9088524417361485, 0.33609886775615383`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 281}], {
             RGBColor[
             0.9597360832096373, 0.8758424956281738, 0.29808271578246365`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 293}], {
             RGBColor[
             0.9706432024693328, 0.927334664532205, 0.5997389014866488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 394}], {
             RGBColor[
             0.971630097187874, 0.9159637976240548, 0.3442887140918415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 90}], {
             RGBColor[
             0.9762532279390527, 0.9304672927407223, 0.5124002452603114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 95}], {
             RGBColor[
             0.9389235390861712, 0.7950615504636016, 0.27230649795999695`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 177}], {
             RGBColor[
             0.9692485484713544, 0.9270156463878264, 0.6036304723348609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 228}], {
             RGBColor[
             0.9752167214615091, 0.9278867224178421, 0.3731539187926316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 246}], {
             RGBColor[
             0.9368810556831719, 0.7869637843879564, 0.2706630678706965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 260}], {
             RGBColor[
             0.8887869604315826, 0.5114864132991501, 0.22833959805859072`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 285}], {
             RGBColor[
             0.9744364730463259, 0.9297160179041086, 0.5425085754437426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 110}], {
             RGBColor[
             0.992358557504345, 0.985417244151658, 0.5792718231126451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 131}], {
             RGBColor[
             0.9919289633884021, 0.9852395959446503, 0.5863913093677543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 201}], {
             RGBColor[
             0.9895908181790615, 0.984272712812997, 0.6251404264123621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 212}], {
             RGBColor[
             0.9923321273799492, 0.9846340072308923, 0.523571244666964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 271}], {
             RGBColor[
             0.9574229243331212, 0.8587557704940488, 0.3374472241827732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 273}], {
             RGBColor[
             0.9861121680528029, 0.9648152232034035, 0.40054882469248515`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 287}], {
             RGBColor[
             0.991876683777655, 0.9852179769820817, 0.5872577178131281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 289}], {
             RGBColor[
             0.9672551330858769, 0.897737201809385, 0.3453584501368422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 292}], {
             RGBColor[
             0.98683154181299, 0.9829977077388407, 0.664869174600086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 303}], {
             RGBColor[
             0.9892088920976452, 0.9752612005520398, 0.4125790128394311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 385}], {
             RGBColor[
             0.9917128260045536, 0.9833093842098946, 0.45616411184019157`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 400}], {
             RGBColor[
             0.9614059711363574, 0.874547223797215, 0.3406520771347818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 86}], {
             RGBColor[
             0.9347315481292253, 0.759504413498808, 0.35707328068525485`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 108}], {
             RGBColor[
             0.9937671355119506, 0.9890768580363564, 0.5629693491357579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 236}], {
             RGBColor[
             0.9927221343373676, 0.9894179331548294, 0.6364919246090117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 262}], {
             RGBColor[
             0.9907440423021108, 0.980041208378637, 0.45242105633695207`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 284}], {
             RGBColor[
             0.9932429369383386, 0.9879556502920062, 0.5059135693767025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 297}], {
             RGBColor[
             0.9933492316979204, 0.988183004034703, 0.5174830979819734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 325}], {
             RGBColor[
             0.9929782074282072, 0.9895238259586698, 0.632248130797883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 333}], {
             RGBColor[
             0.9585009394464247, 0.8617823078485749, 0.37661460097915134`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 337}], {
             RGBColor[
             0.9728246942249038, 0.918571222436918, 0.38813983029565297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 376}], {
             RGBColor[
             0.9921871058655579, 0.9891966851321317, 0.6453587309961978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 397}], {
             RGBColor[
             0.9766479994875685, 0.9324919460569393, 0.3976605918167805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.9460541453666937, 0.8238296933090064, 0.27545210297132994`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 162}], {
             RGBColor[
             0.9666326322483538, 0.8946275638903136, 0.5109003602235193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 183}], {
             RGBColor[
             0.9343561704518846, 0.7774511208908452, 0.26603963776811224`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 189}], {
             RGBColor[
             0.9543472639632318, 0.8527731079933983, 0.3026238886264968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 207}], {
             RGBColor[
             0.9338732399785272, 0.7755364624910235, 0.2656510605734137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 280}], {
             RGBColor[
             0.9013147988664324, 0.6346376526381479, 0.23884257412560195`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 291}], {
             RGBColor[
             0.967193463795686, 0.8945865225852453, 0.48176465140505853`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 336}], {
             RGBColor[
             0.9431960317485639, 0.8787521219408384, 0.6223820446706226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 368}], {
             RGBColor[
             0.9667194667430278, 0.8935726908180626, 0.4301729973939333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 387}], {
             RGBColor[
             0.9145604306465358, 0.694782972955698, 0.24989505396306552`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 116}], {
             RGBColor[
             0.9929666529364931, 0.989001254858435, 0.5948015321038422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 118}], {
             RGBColor[
             0.9912013441561492, 0.990629543940496, 0.7954800277314091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 141}], {
             RGBColor[
             0.9438088528665185, 0.8020749685480847, 0.49637467682278125`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 179}], {
             RGBColor[
             0.9884486133609326, 0.9893782900696073, 0.8360427119576135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 209}], {
             RGBColor[
             0.9675179525957359, 0.8989524926557753, 0.5156004946202027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 286}], {
             RGBColor[
             0.9809766171377817, 0.9485840326860572, 0.5458429522569447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 290}], {
             RGBColor[
             0.9791048305416624, 0.9422700569809539, 0.5385714147882601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 304}], {
             RGBColor[
             0.989409697492299, 0.9898886520017749, 0.8251722495843439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 338}], {
             RGBColor[
             0.9936759419561242, 0.9916528537250483, 0.7544695381320052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 386}], {
             RGBColor[
             0.9843097769496172, 0.9598275633945195, 0.558791648711511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 126}], {
             RGBColor[
             0.9907019892728864, 0.9901500883008282, 0.783914351742441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 133}], {
             RGBColor[
             0.9931250417888473, 0.9911520827857873, 0.7437581008940688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 178}], {
             RGBColor[
             0.9782066618027556, 0.9366282604466745, 0.49907312797139797`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 200}], {
             RGBColor[
             0.9443405103690777, 0.8009543206940724, 0.46322000075271563`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 296}], {
             RGBColor[
             0.9760049223945253, 0.9292012764297165, 0.49051978613402275`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 320}], {
             RGBColor[
             0.9941937712788871, 0.9899893888023407, 0.6094060194760391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 330}], {
             RGBColor[
             0.9896887230665998, 0.9897310766847749, 0.8007067950294935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 347}], {
             RGBColor[
             0.9848054267268311, 0.9861256477643285, 0.8106086282163281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 398}], {
             RGBColor[
             0.9915461440892326, 0.9816254664583486, 0.5508944977045037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 78}], {
             RGBColor[
             0.9667649421003394, 0.8958832138656498, 0.34449814276462165`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 80}], {
             RGBColor[
             0.9692736798376458, 0.9028093609664383, 0.48488970277905874`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.9505715573740346, 0.8412591247962775, 0.28158990096703873`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 117}], {
             RGBColor[
             0.9687902314776329, 0.9017753138084978, 0.43226933228909203`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.9683575470601641, 0.9008498455906372, 0.38517430366630967`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 187}], {
             RGBColor[
             0.9686943680907749, 0.9015702717172838, 0.42183519422984794`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 208}], {
             RGBColor[
             0.9260869607616697, 0.7446664600199212, 0.2593860375480669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 239}], {
             RGBColor[
             0.9448491074496893, 0.8190521195231651, 0.2744825011774329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 269}], {
             RGBColor[
             0.9563085364563152, 0.8951841100118361, 0.6053475019169896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 323}], {
             RGBColor[
             0.9124770247488738, 0.6841320401693013, 0.24809501672234444`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 365}], {
             RGBColor[
             0.9504388112231932, 0.8408113408592108, 0.2810742072380269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 377}], {
             RGBColor[
             0.9084934677518646, 0.6660436382292566, 0.24477103911812267`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 388}], {
             RGBColor[
             0.9432644187263832, 0.8127693568014697, 0.27320742343323573`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 395}], {
             RGBColor[
             0.9582675120881157, 0.8672193871429712, 0.31148723177214277`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 78}], {
             RGBColor[
             0.9915799209149789, 0.9828384164217678, 0.45757359873594006`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 80}], {
             RGBColor[
             0.9940886586522852, 0.9897645635225563, 0.5979651587503771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 96}], {
             RGBColor[
             0.9753865361886742, 0.9282143273523955, 0.3946653569383571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 182}], {
             RGBColor[
             0.9931725258748036, 0.9878050481467552, 0.4982497596376281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 187}], {
             RGBColor[
             0.9935093469054144, 0.9885254742734018, 0.5349106502011663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 244}], {
             RGBColor[
             0.9934583990285889, 0.9884165019164924, 0.5293652882225575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 302}], {
             RGBColor[
             0.9777800092616648, 0.9362880740417953, 0.40396354785746164`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 377}], {
             RGBColor[
             0.9333084465665041, 0.7529988407853746, 0.35784649508944105`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 388}], {
             RGBColor[
             0.9680793975410229, 0.8997245593575877, 0.3862828794045541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 80}], {
             RGBColor[
             0.9924837213047188, 0.9847715540671851, 0.5559466935496801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 96}], {
             RGBColor[
             0.9737815988411078, 0.9232213178970243, 0.35264689173765995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 104}], {
             RGBColor[
             0.991538849447289, 0.9827505687053415, 0.4531032229416111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 182}], {
             RGBColor[
             0.9915675885272373, 0.9828120386913841, 0.456231294436931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 187}], {
             RGBColor[
             0.991904409557848, 0.9835324648180306, 0.4928921850004693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 208}], {
             RGBColor[
             0.9492970022287429, 0.8266286531206681, 0.3304430283186881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 302}], {
             RGBColor[
             0.9761750719140984, 0.9312950645864242, 0.3619450826567645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 377}], {
             RGBColor[
             0.9317035092189377, 0.7480058313300035, 0.3158280298887439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 388}], {
             RGBColor[
             0.9664744601934565, 0.8947315499022166, 0.344264414203857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 87}], {
             RGBColor[
             0.9575226183629502, 0.8669120423537706, 0.2971079253670562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 126}], {
             RGBColor[
             0.9687254853457938, 0.9160740975001508, 0.5769281842056715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 176}], {
             RGBColor[
             0.9501835306703056, 0.8402013300017475, 0.2787747033157469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 205}], {
             RGBColor[
             0.9720971567214403, 0.9156564935083835, 0.38934655106211746`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 232}], {
             RGBColor[
             0.9532689171484253, 0.8524338592433975, 0.2812572776993708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[
             0.9316160518590044, 0.7665874637604675, 0.26383487402943084`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 298}], {
             RGBColor[
             0.9214412262235434, 0.7226882004422471, 0.2554638427822655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 373}], {
             RGBColor[
             0.9662604076029795, 0.9146088527113676, 0.5978138519822447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 390}], {
             RGBColor[
             0.9717860293606427, 0.9149910235434389, 0.35548225789480026`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 96}], {
             RGBColor[
             0.9762903365784141, 0.9301474649978128, 0.4930384517520971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 104}], {
             RGBColor[
             0.9940475871845954, 0.9896767158061299, 0.5934947829560482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 182}], {
             RGBColor[
             0.9940763262645436, 0.9897381857921724, 0.5966228544513681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 187}], {
             RGBColor[
             0.9944131472951544, 0.990458611918819, 0.6332837450149064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 244}], {
             RGBColor[
             0.9943621994183289, 0.9903496395619097, 0.6277383830362975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 302}], {
             RGBColor[
             0.9786838096514048, 0.9382212116872125, 0.5023366426712017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 377}], {
             RGBColor[
             0.9342122469562442, 0.7549319784307919, 0.45621958990318107`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 388}], {
             RGBColor[
             0.9689831979307628, 0.9016576970030049, 0.4846559742182941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 119}], {
             RGBColor[
             0.955048822616847, 0.8888035219272172, 0.6032583888190675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 128}], {
             RGBColor[
             0.9429703411910061, 0.8116034373692285, 0.27297080174538424`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.9624705983715707, 0.8942431339906194, 0.5864169547257323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 135}], {
             RGBColor[
             0.9466926189192469, 0.8263610281861808, 0.2759658337786147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 146}], {
             RGBColor[
             0.9657376856161359, 0.8955941585265595, 0.5322728641325292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 166}], {
             RGBColor[
             0.9470737649727974, 0.8828557369942434, 0.6167580811822841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 227}], {
             RGBColor[
             0.9638429571467403, 0.8850269305433959, 0.3383534561057866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 243}], {
             RGBColor[
             0.9670300074187181, 0.8961285668030827, 0.5108557474421231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[
             0.9624519094257766, 0.8803345999470485, 0.3329494983871631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 275}], {
             RGBColor[
             0.9298878578969396, 0.7597357505873794, 0.26244432860162753`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 311}], {
             RGBColor[
             0.9666965250772993, 0.8959906632848008, 0.5163824128640689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 326}], {
             RGBColor[
             0.9671456165464098, 0.8951714158773147, 0.4358899475802068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 344}], {
             RGBColor[
             0.9625595938360041, 0.8942799359022418, 0.5849420695671921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 346}], {
             RGBColor[
             0.9590348983205852, 0.8688082191368762, 0.31967505549189645`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 363}], {
             RGBColor[
             0.9653517993483967, 0.8954345846380247, 0.5386679982306171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 383}], {
             RGBColor[
             0.9664456244062938, 0.8936742034696683, 0.35970012297931814`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 172}], {
             RGBColor[
             0.9116977088863498, 0.8020045503195858, 0.6178284982260855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 194}], {
             RGBColor[
             0.9334187412961065, 0.772480778047591, 0.27181490438964495`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 233}], {
             RGBColor[
             0.9500434918143812, 0.827974145448639, 0.3862128058749311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 256}], {
             RGBColor[
             0.9315855868440813, 0.766297117635776, 0.2646934455056979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 257}], {
             RGBColor[
             0.9424124137089183, 0.8028185469107094, 0.30675362340089396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 310}], {
             RGBColor[
             0.9295959194881342, 0.7585783120791743, 0.2622094281052276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 316}], {
             RGBColor[
             0.9502188321886451, 0.8283491807795583, 0.4052975235382032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 399}], {
             RGBColor[
             0.9022001741521837, 0.6481020973605687, 0.24006988969855558`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 118}], {
             RGBColor[
             0.9919765942402438, 0.9909501297732874, 0.7826321275550578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 123}], {
             RGBColor[
             0.99001270958383, 0.9767703795437448, 0.5650868647276023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 141}], {
             RGBColor[
             0.944584102950613, 0.8023955543808762, 0.48352677664642996`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 161}], {
             RGBColor[
             0.979908799772157, 0.9426875192381285, 0.5258350830725169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 196}], {
             RGBColor[
             0.9836697813719626, 0.985556650586282, 0.8325964239943564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 214}], {
             RGBColor[
             0.9946790021724885, 0.9920676449019867, 0.7378462345102195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 286}], {
             RGBColor[
             0.9817518672218762, 0.9489046185188487, 0.5329950520805934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 332}], {
             RGBColor[
             0.9547716939567813, 0.8456648021773532, 0.49187287113468403`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 334}], {
             RGBColor[
             0.9335031776352251, 0.7520796605395592, 0.47428058094493597`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 366}], {
             RGBColor[
             0.9303430308109801, 0.7377301718817058, 0.4716436769724991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 125}], {
             RGBColor[
             0.9477250302688703, 0.8287766910741381, 0.5402730675320432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 184}], {
             RGBColor[
             0.9499431273509785, 0.8278534346119595, 0.36972878448948776`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 185}], {
             RGBColor[
             0.9497995627884563, 0.8275463645293283, 0.3541026678367255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 190}], {
             RGBColor[
             0.9505190399948511, 0.8290852535235025, 0.4324133216541578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 252}], {
             RGBColor[
             0.947594799742963, 0.8203303884600541, 0.3267277003348426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 270}], {
             RGBColor[
             0.9449885692955142, 0.8274868387033072, 0.578536305902429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 274}], {
             RGBColor[
             0.9200541742680719, 0.7207484718797321, 0.254531915927619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 288}], {
             RGBColor[
             0.9499581041576973, 0.8278854684871434, 0.37135891747468763`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 318}], {
             RGBColor[
             0.917064712351146, 0.7088962515582504, 0.2521265246975704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 168}], {
             RGBColor[
             0.9757812070418481, 0.9299664658884539, 0.36041499200321203`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 238}], {
             RGBColor[
             0.967464009112577, 0.9019106043020801, 0.3281042486190314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 379}], {
             RGBColor[
             0.9389388280846914, 0.7925474188059383, 0.2857281282879132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 236}], {
             RGBColor[
             0.9343051300284524, 0.7611685752638184, 0.4979248062905143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 262}], {
             RGBColor[
             0.9323270379931956, 0.7517918504876259, 0.3138539380184546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 265}], {
             RGBColor[
             0.9349100812139923, 0.759886277714661, 0.3765055051836663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 297}], {
             RGBColor[
             0.9349322273890053, 0.7599336461436919, 0.378915979663476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 325}], {
             RGBColor[
             0.934561203119292, 0.7612744680676589, 0.49368101247938556`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 376}], {
             RGBColor[
             0.9337701015566428, 0.7609473272411205, 0.5067916126777003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 397}], {
             RGBColor[
             0.9182309951786534, 0.7042425881659282, 0.2590934734982831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 176}], {
             RGBColor[
             0.9566935632914256, 0.8636251152614012, 0.29644084819608385`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 205}], {
             RGBColor[
             0.9786071893425603, 0.9390802787680372, 0.4070126959424545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 232}], {
             RGBColor[
             0.9597789497695454, 0.8758576445030513, 0.29892342257970783`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 277}], {
             RGBColor[
             0.9381260844801245, 0.7900112490201212, 0.28150101890976786`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 373}], {
             RGBColor[
             0.9727704402240995, 0.9380326379710213, 0.6154799968625817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 390}], {
             RGBColor[
             0.9782960619817628, 0.9384148088030926, 0.3731484027751373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 89}], {
             RGBColor[
             0.9103121083465626, 0.6716711731416011, 0.24615248502820214`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 120}], {
             RGBColor[
             0.8974822291547558, 0.6208049774498847, 0.2358292630745039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 140}], {
             RGBColor[
             0.92646959315915, 0.7271429417137274, 0.3038758483717767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 189}], {
             RGBColor[
             0.9186052269431007, 0.7006145878259931, 0.273324270683369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 195}], {
             RGBColor[
             0.9061577342911262, 0.6552004643748836, 0.24280977814750576`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 233}], {
             RGBColor[
             0.9306947331722559, 0.7408095113138427, 0.37010360451444646`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 255}], {
             RGBColor[
             0.9137618015510394, 0.6842765766882073, 0.2545084776393489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 257}], {
             RGBColor[
             0.923063655066793, 0.715653912775913, 0.29064442204040936`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 263}], {
             RGBColor[
             0.9270168690859826, 0.7408671584128711, 0.5457984093392101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 336}], {
             RGBColor[
             0.9074539947284328, 0.7265936017734331, 0.5930824267274948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 356}], {
             RGBColor[
             0.9279081825233879, 0.7319956414361481, 0.30946449639703544`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 359}], {
             RGBColor[
             0.898280848856416, 0.6239712384427275, 0.23647185123247333`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 360}], {
             RGBColor[
             0.9211400644169359, 0.7091651898333822, 0.2831716356053285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 389}], {
             RGBColor[
             0.8923489502442246, 0.7148399161847894, 0.6017192968656009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 162}], {
             RGBColor[
             0.9732654436196908, 0.920924450724301, 0.5162372759449901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 183}], {
             RGBColor[
             0.9409889818232218, 0.8037480077248327, 0.2713765534895831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 189}], {
             RGBColor[
             0.9609800753345688, 0.8790699948273857, 0.30796080434796774`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 263}], {
             RGBColor[
             0.9693917174774508, 0.9193225654142637, 0.5804349430038089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 270}], {
             RGBColor[
             0.9679631965326214, 0.9185735798577541, 0.5970222302612178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.9079476102377695, 0.6609345394721352, 0.24417948984707286`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 291}], {
             RGBColor[
             0.9738262751670231, 0.9208834094192326, 0.4871015671265294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 336}], {
             RGBColor[
             0.9498288431199011, 0.9050490087748257, 0.6277189603920936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 359}], {
             RGBColor[
             0.9406556972478841, 0.8024266454441201, 0.27110838489707206`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 95}], {
             RGBColor[
             0.9575308512828804, 0.8567369732379925, 0.4947439333532755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 97}], {
             RGBColor[
             0.9922041458547219, 0.991044228213684, 0.7788610084184553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.9744169599980785, 0.9786683590467226, 0.8488164611357735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 228}], {
             RGBColor[
             0.9938240336582184, 0.989562145192233, 0.59559135418591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 246}], {
             RGBColor[
             0.9554883678798813, 0.8486392071623472, 0.4931005032639749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 260}], {
             RGBColor[
             0.9073942726282918, 0.5731618360735409, 0.4507770334518692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 326}], {
             RGBColor[
             0.9944888115716911, 0.9909840379297938, 0.667948327533696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 172}], {
             RGBColor[
             0.913336635515972, 0.8085023482661136, 0.6191472170628318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 192}], {
             RGBColor[
             0.9505271089390591, 0.8355727316402706, 0.5214210719618251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 208}], {
             RGBColor[
             0.9092658256943311, 0.677976264788898, 0.24585135743009934`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 221}], {
             RGBColor[
             0.9194859890566296, 0.7184958068528613, 0.2540747407694715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 256}], {
             RGBColor[
             0.9332245134737034, 0.7727949155823037, 0.26601216434244424`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 316}], {
             RGBColor[
             0.9518577588182673, 0.834846978726086, 0.40661624237494953`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 351}], {
             RGBColor[
             0.919797038481533, 0.7197290141715273, 0.25432501843801725`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 395}], {
             RGBColor[
             0.941446377020777, 0.800529191911948, 0.2979525516541753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 399}], {
             RGBColor[
             0.9038391007818058, 0.6545998953070964, 0.2413886085353019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 98}], {
             RGBColor[
             0.9585238639864798, 0.865216746877577, 0.3274164503759438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 119}], {
             RGBColor[
             0.9765563527752197, 0.9660224865741227, 0.6624947715323308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 130}], {
             RGBColor[
             0.9839781285299434, 0.9714620986375249, 0.6456533374389954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 143}], {
             RGBColor[
             0.9886455089073448, 0.9723740440478006, 0.49429500317739905`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 146}], {
             RGBColor[
             0.9872452157745085, 0.9728131231734649, 0.5915092468457923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 151}], {
             RGBColor[
             0.9885946951708117, 0.9733711675838749, 0.5691448809083214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 158}], {
             RGBColor[
             0.9545597576974043, 0.8495003864015063, 0.32422683740622005`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 186}], {
             RGBColor[
             0.9483580546059611, 0.8249127002389794, 0.3192368015261635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 267}], {
             RGBColor[
             0.9839594395841493, 0.9575535645939539, 0.3921858811004263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 306}], {
             RGBColor[
             0.9628797737212652, 0.8824864774551291, 0.33092131759489474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 308}], {
             RGBColor[
             0.9871316039873084, 0.9682540199854309, 0.40450914079371636`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 346}], {
             RGBColor[
             0.9805424284789578, 0.9460271837837815, 0.37891143820515966`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 348}], {
             RGBColor[
             0.9753568844391043, 0.9285351261137142, 0.35876657881815255`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 354}], {
             RGBColor[
             0.9757188743649429, 0.9297562031328442, 0.36017284132397387`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 374}], {
             RGBColor[
             0.9605922562500425, 0.8734172329517407, 0.32908072734261284`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 131}], {
             RGBColor[
             0.9495283532567176, 0.9595397875585835, 0.8734493170387845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 142}], {
             RGBColor[
             0.9311638174004253, 0.8967889396914586, 0.6388612298825929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 188}], {
             RGBColor[
             0.9311006284879326, 0.8965757886521584, 0.6386157528897836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 201}], {
             RGBColor[
             0.9471902080473771, 0.9585729044269302, 0.9121984340833922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 264}], {
             RGBColor[
             0.9494725183479253, 0.9595166983889061, 0.8743746459735862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 273}], {
             RGBColor[
             0.9437115579211184, 0.9391154148173367, 0.6876068323635153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 281}], {
             RGBColor[
             0.9339257149674327, 0.9061054687093621, 0.649590680389825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 293}], {
             RGBColor[
             0.9448328342271283, 0.9575976376133932, 0.9512468660940101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 394}], {
             RGBColor[
             0.9458197289456693, 0.946226770705243, 0.6957966786992029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 204}], {
             RGBColor[
             0.9420385969298986, 0.8025153380890611, 0.3003133700794288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.9514888527401648, 0.8340222687728078, 0.368573092605255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 307}], {
             RGBColor[
             0.9515833750225952, 0.8359401712053256, 0.5035766333701579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 324}], {
             RGBColor[
             0.9514856753241867, 0.8340154726013167, 0.36822725048478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 97}], {
             RGBColor[
             0.9548744570018404, 0.8556384859365633, 0.5387672611181409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 148}], {
             RGBColor[
             0.9376459865859762, 0.7904941455962791, 0.2686867010515118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 166}], {
             RGBColor[
             0.9370872711451971, 0.8432626167696019, 0.6087227138354592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 169}], {
             RGBColor[
             0.9569633888221856, 0.855159640639527, 0.406550153515442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 228}], {
             RGBColor[
             0.9564943448053369, 0.8541564029151123, 0.35549760688559573`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 246}], {
             RGBColor[
             0.9181586790269998, 0.7132334648852265, 0.2530067559636606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 276}], {
             RGBColor[
             0.9506415014228846, 0.8345889889337338, 0.31782856888662014`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 282}], {
             RGBColor[
             0.953609922580804, 0.8446021705178287, 0.32936032454583786`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 305}], {
             RGBColor[
             0.9562702797684537, 0.8562156945215668, 0.5156348656018321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 326}], {
             RGBColor[
             0.9571591227188097, 0.8555782956526732, 0.42785458023338174`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 361}], {
             RGBColor[
             0.9551021124452239, 0.8496356773133591, 0.33515720039269836`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 382}], {
             RGBColor[
             0.9523123755669551, 0.8402252397615892, 0.32431959941822786`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 104}], {
             RGBColor[
             0.9753454647209843, 0.9281264796359692, 0.3901949811440281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 182}], {
             RGBColor[
             0.9753742038009325, 0.9281879496220116, 0.393323052639348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 187}], {
             RGBColor[
             0.9757110248315433, 0.9289083757486583, 0.4299839432028863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 208}], {
             RGBColor[
             0.9331036175024382, 0.7720045640512956, 0.2675347865211052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 225}], {
             RGBColor[
             0.9676314535556378, 0.9024754337263496, 0.3287547386610934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 261}], {
             RGBColor[
             0.9223325391683312, 0.7243607338875463, 0.2586125781292502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 377}], {
             RGBColor[
             0.915510124492633, 0.693381742260631, 0.252919788091161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 388}], {
             RGBColor[
             0.9502810754671518, 0.840107460832844, 0.2813561724062741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 166}], {
             RGBColor[
             0.9717605657170385, 0.9775698717452934, 0.892839788900639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 169}], {
             RGBColor[
             0.991636683394027, 0.9894668956152184, 0.6906672285806217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 224}], {
             RGBColor[
             0.9773513597602065, 0.9420337035866444, 0.5710091979494385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 246}], {
             RGBColor[
             0.9528319735988412, 0.847540719860918, 0.5371238310288404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 276}], {
             RGBColor[
             0.985314795994726, 0.9688962439094253, 0.6019456439518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 326}], {
             RGBColor[
             0.991832417290651, 0.9898855506283647, 0.7119716552985615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 363}], {
             RGBColor[
             0.9900386000926378, 0.9901487193890746, 0.8147497059489717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 382}], {
             RGBColor[
             0.9869856701387965, 0.9745324947372807, 0.6084366744834075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 383}], {
             RGBColor[
             0.991132425150535, 0.9883883382207181, 0.6357818306976728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 393}], {
             RGBColor[
             0.9619625911155749, 0.8837405757168474, 0.5444705402059432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 134}], {
             RGBColor[
             0.9311637074606443, 0.7647940689558043, 0.26347090710862253`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 143}], {
             RGBColor[
             0.9639801624918799, 0.8826353902214121, 0.43251776738020514`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 151}], {
             RGBColor[
             0.9639293487553467, 0.8836325137574863, 0.5073676451111275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 158}], {
             RGBColor[
             0.9298944112819394, 0.7597617325751178, 0.26244960160902614`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 163}], {
             RGBColor[
             0.9398664067251326, 0.7992973715368847, 0.27047330321543633`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.961121748419362, 0.8739800210819613, 0.33750874082838134`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 186}], {
             RGBColor[
             0.9236927081904962, 0.7351740464125909, 0.25745956572896966`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 240}], {
             RGBColor[
             0.9637524616128452, 0.8821483610652472, 0.40773393190421575`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 272}], {
             RGBColor[
             0.9639434155449258, 0.8825567922175636, 0.4285180889801226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 306}], {
             RGBColor[
             0.9382144273058003, 0.7927478236287406, 0.2691440817977009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 308}], {
             RGBColor[
             0.9624662575718435, 0.8785153661590424, 0.3427319049965225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 342}], {
             RGBColor[
             0.9495713933996633, 0.8350179614481894, 0.29263779267837453`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 348}], {
             RGBColor[
             0.9506915380236394, 0.8387964722873256, 0.29698934302095864`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 354}], {
             RGBColor[
             0.951053527949478, 0.8400175493064557, 0.29839560552677996`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 374}], {
             RGBColor[
             0.9359269098345776, 0.7836785791253521, 0.267303491545419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 378}], {
             RGBColor[
             0.9392908496724014, 0.7970154796158241, 0.2700101965007485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 144}], {
             RGBColor[
             0.9673881164569915, 0.9016546005543475, 0.32780941998320745`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 169}], {
             RGBColor[
             0.9825942219444925, 0.9521938059852464, 0.45104451424087666`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[
             0.9804650429711708, 0.9526560080502222, 0.5839286213246894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 222}], {
             RGBColor[
             0.9513343414319698, 0.8401803641713883, 0.303571863429831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 223}], {
             RGBColor[
             0.9798722223861909, 0.9524108615035389, 0.5937531925883011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 276}], {
             RGBColor[
             0.9762723345451916, 0.9316231542794532, 0.3623229296120548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 361}], {
             RGBColor[
             0.9807329455675309, 0.9466698426590785, 0.37965156111813303`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 382}], {
             RGBColor[
             0.9779432086892621, 0.9372594051073087, 0.3688139601436625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 384}], {
             RGBColor[
             0.9418411733253957, 0.8025431160395644, 0.2959334375379865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 393}], {
             RGBColor[
             0.9529201296660404, 0.8464674860868753, 0.30484782586619813`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 157}], {
             RGBColor[
             0.9350616323491819, 0.7802480422323874, 0.2666072689699966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 167}], {
             RGBColor[
             0.9565207951694273, 0.8568466704939073, 0.32803676531747916`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 174}], {
             RGBColor[
             0.9606278242454316, 0.870484912203518, 0.36233606771331134`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 198}], {
             RGBColor[
             0.9448473976699241, 0.8174695596840067, 0.28268782036805423`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 203}], {
             RGBColor[
             0.9266715455980652, 0.7469841440948808, 0.2598564082294004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 206}], {
             RGBColor[
             0.930980883391787, 0.7640692324452945, 0.26332380257138754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 211}], {
             RGBColor[
             0.9612435328119215, 0.8718018505695546, 0.42935214546292244`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 266}], {
             RGBColor[
             0.9611050680395326, 0.8715056884223507, 0.41428110949390945`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 341}], {
             RGBColor[
             0.9419606641028571, 0.8076004041696618, 0.2721583918600923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 358}], {
             RGBColor[
             0.9608415561145103, 0.8709420630598705, 0.38559946266233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 115}], {
             RGBColor[
             0.9845990757902172, 0.9622307109699644, 0.569780789305314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 123}], {
             RGBColor[
             0.9809338067439655, 0.9473473945716392, 0.38043186885913083`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 161}], {
             RGBColor[
             0.9708298969322924, 0.913264534266023, 0.3411800872040454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 193}], {
             RGBColor[
             0.9735888892481275, 0.9225712631895371, 0.35189825135908404`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 253}], {
             RGBColor[
             0.9659342342753032, 0.8964923942671695, 0.3235046155591867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 283}], {
             RGBColor[
             0.980401388212426, 0.9455514218469402, 0.3783635234029028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 332}], {
             RGBColor[
             0.9456927911169167, 0.8162418172052477, 0.3072178752662126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 334}], {
             RGBColor[
             0.9244242747953605, 0.7226566755674537, 0.2896255850764645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 356}], {
             RGBColor[
             0.9823283814501672, 0.9520516225173703, 0.3858495282493892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 364}], {
             RGBColor[
             0.9653755188345241, 0.9492608654404924, 0.663540628343134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 366}], {
             RGBColor[
             0.9212641279711156, 0.7083071869096003, 0.28698868110402764`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 380}], {
             RGBColor[
             0.9769997479428796, 0.9340768904746426, 0.36514879330157857`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 389}], {
             RGBColor[
             0.9467691491710039, 0.9348958972660115, 0.6781043287179546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 108}], {
             RGBColor[
             0.9805804997862724, 0.9449936536478103, 0.4778634845867417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 139}], {
             RGBColor[
             0.8953312361202695, 0.5421001793944235, 0.24796818863401326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 213}], {
             RGBColor[
             0.9529973008541225, 0.9268889060213982, 0.656599342585489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 297}], {
             RGBColor[
             0.9801625959722424, 0.944099799646157, 0.4323772334329572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 333}], {
             RGBColor[
             0.9453143037207465, 0.8176991034600289, 0.29150873643013514`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 337}], {
             RGBColor[
             0.9596380584992257, 0.8744880180483721, 0.30303396574663677`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 345}], {
             RGBColor[
             0.9766068329682709, 0.9441236502594559, 0.5999216289151719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 350}], {
             RGBColor[
             0.9803226545700845, 0.9456602379840653, 0.5383408487350689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 378}], {
             RGBColor[
             0.955749231380286, 0.8590701143965934, 0.2999049241642334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 122}], {
             RGBColor[
             0.9466742580419886, 0.8262882334262511, 0.27595106018578747`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 295}], {
             RGBColor[
             0.961612104625996, 0.8772056809841187, 0.33122890176153785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 145}], {
             RGBColor[
             0.9580258757858875, 0.859940682702711, 0.37375625108653215`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 170}], {
             RGBColor[
             0.9576788692335145, 0.8585649173556307, 0.37347704146920213`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 182}], {
             RGBColor[
             0.9931314544071137, 0.9877172004303288, 0.4937793838432991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 187}], {
             RGBColor[
             0.9934682754377245, 0.9884376265569754, 0.5304402744068374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 192}], {
             RGBColor[
             0.9921221513533474, 0.9891302817109854, 0.6435608322567821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 208}], {
             RGBColor[
             0.9508608681086195, 0.8315338148596129, 0.36799111772505627`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 225}], {
             RGBColor[
             0.9853887041618191, 0.9620046845346668, 0.4292110698650444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 235}], {
             RGBColor[
             0.9908524476466586, 0.9886052265983727, 0.6646031085644762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 261}], {
             RGBColor[
             0.9400897897745124, 0.7838899846958636, 0.3590689093332013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 327}], {
             RGBColor[
             0.9940442585450598, 0.9896695961827404, 0.5931324810845826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 335}], {
             RGBColor[
             0.9883505353207465, 0.9719956365047561, 0.44071722462259477`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 349}], {
             RGBColor[
             0.9723485428316758, 0.9167252847934004, 0.3852806051877784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 351}], {
             RGBColor[
             0.9613920808958214, 0.8732865642422423, 0.3764647787329742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 355}], {
             RGBColor[
             0.9718762451476808, 0.9148527818602337, 0.3849005833849845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 199}], {
             RGBColor[
             0.9893492353371072, 0.9885449751650555, 0.7303205715866798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 215}], {
             RGBColor[
             0.9421996547991676, 0.7926889200619459, 0.3959712512212533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 259}], {
             RGBColor[
             0.9738408825302232, 0.9220478846109081, 0.4216328915656492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 271}], {
             RGBColor[
             0.9591608959080989, 0.8638466294697367, 0.4098210297459146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 287}], {
             RGBColor[
             0.9936146553526328, 0.9903088359577696, 0.6596315233762695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 303}], {
             RGBColor[
             0.9909468636726229, 0.9803520595277277, 0.48495281840257254`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 333}], {
             RGBColor[
             0.9588033797710571, 0.8624291971215564, 0.4095333638700685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 337}], {
             RGBColor[
             0.9731271345495363, 0.9192181117098995, 0.42105859318657013`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 345}], {
             RGBColor[
             0.9900959090185815, 0.9888537439209834, 0.7179462563551051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 350}], {
             RGBColor[
             0.9938117306203952, 0.9903903316455926, 0.6563654761750023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 353}], {
             RGBColor[
             0.9940965290793228, 0.9905081031273457, 0.6516456286757866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 400}], {
             RGBColor[
             0.9631439427113351, 0.8796380827729028, 0.4130258826979232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 197}], {
             RGBColor[
             0.9583428216673489, 0.9395977392222541, 0.6660662492936855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 217}], {
             RGBColor[
             0.969200134171673, 0.9747330258608401, 0.8556484283846753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 231}], {
             RGBColor[
             0.9191138164640009, 0.7865581640601825, 0.6074864837726264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 254}], {
             RGBColor[
             0.9648635005380108, 0.97293971640692, 0.9275176705425431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 314}], {
             RGBColor[
             0.9684940398638795, 0.9730909371126379, 0.7692121766989533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 369}], {
             RGBColor[
             0.967112961661565, 0.9738699263900236, 0.8902382783064737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 124}], {
             RGBColor[
             0.9901990004027317, 0.9845905918166419, 0.6155200892971191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 150}], {
             RGBColor[
             0.9553425375675404, 0.8565569394683682, 0.5345571442133683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 152}], {
             RGBColor[
             0.9893490439443706, 0.9898635702009815, 0.8261774358398659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.9921880164089147, 0.9901907258982314, 0.7175725410241496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.9658979111993721, 0.8984054785488305, 0.5430502456040032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 160}], {
             RGBColor[
             0.9882860262087971, 0.9781376806727997, 0.6080885457885473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 167}], {
             RGBColor[
             0.9873570740196175, 0.9750041068103504, 0.6044797419514858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.986793959246808, 0.9886940480707458, 0.8634646127362388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 181}], {
             RGBColor[
             0.9089676654704496, 0.6026556480561189, 0.49422368590607857`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 211}], {
             RGBColor[
             0.9920798116621117, 0.9899592868859978, 0.7057951220969291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 238}], {
             RGBColor[
             0.9793254660157961, 0.9479116071022218, 0.573278461498545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 245}], {
             RGBColor[
             0.9919212010261356, 0.9896200347736401, 0.6885313332023146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 386}], {
             RGBColor[
             0.9826551228354926, 0.9591433213956579, 0.5862135494901363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 297}], {
             RGBColor[
             0.9939678147717306, 0.9895060906812403, 0.5848120481139791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 325}], {
             RGBColor[
             0.9935967905020173, 0.9908469126052071, 0.6995770809298887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 376}], {
             RGBColor[
             0.9928056889393679, 0.9905197717786689, 0.7126876811282035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 378}], {
             RGBColor[
             0.9695544501797743, 0.9044764054316767, 0.4523397388452553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 397}], {
             RGBColor[
             0.9772665825613787, 0.9338150327034765, 0.46498954194878617`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 114}], {
             RGBColor[
             0.9690064773435403, 0.9116519052365746, 0.5500631898720723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 132}], {
             RGBColor[
             0.9701356560855388, 0.9121188496649609, 0.531349775896246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 180}], {
             RGBColor[
             0.9706589956888491, 0.9102470649854315, 0.3708866571822016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 232}], {
             RGBColor[
             0.9519909083098113, 0.8473669800694922, 0.28022896178909895`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 249}], {
             RGBColor[
             0.9576790289841901, 0.8666837968356585, 0.30165205819093144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 370}], {
             RGBColor[
             0.9259354233999599, 0.7438315606496295, 0.2592519970606518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 111}], {
             RGBColor[
             0.9896767351686964, 0.9763708276916859, 0.5688534497583031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 117}], {
             RGBColor[
             0.9942325936966199, 0.990799131585501, 0.6664554225750852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 202}], {
             RGBColor[
             0.9933676706539174, 0.9915253756193747, 0.7595783913901288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 212}], {
             RGBColor[
             0.9944131949468443, 0.991185419398144, 0.6861127541203054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 239}], {
             RGBColor[
             0.9702914696686762, 0.9080759373001683, 0.5086685914634259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 247}], {
             RGBColor[
             0.9806925694743738, 0.9834186276036418, 0.8413250674836916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 269}], {
             RGBColor[
             0.9817508986753021, 0.9842079277888394, 0.8395335922029827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 287}], {
             RGBColor[
             0.9939577513445501, 0.9917693891493333, 0.7497992272664695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 289}], {
             RGBColor[
             0.9693362006527719, 0.9042886139766366, 0.5078999595901836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 292}], {
             RGBColor[
             0.988912609379885, 0.9895491199060922, 0.8274106840534274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 303}], {
             RGBColor[
             0.9912899596645401, 0.9818126127192914, 0.5751205222927726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 309}], {
             RGBColor[
             0.9604014060653685, 0.8688651307813794, 0.5007108141385749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 362}], {
             RGBColor[
             0.971823503928821, 0.9141499426214892, 0.5099013021906045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 385}], {
             RGBColor[
             0.9937938935714485, 0.9898607963771462, 0.6187056212935329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 400}], {
             RGBColor[
             0.9634870387032524, 0.8810986359644666, 0.5031935865881232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 199}], {
             RGBColor[
             0.9849294414264809, 0.9744076997293956, 0.6475283926691964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 222}], {
             RGBColor[
             0.9580598497277397, 0.8628670828774643, 0.3296991931532256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 223}], {
             RGBColor[
             0.9865977306819609, 0.9750975802096148, 0.6198805223116957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 247}], {
             RGBColor[
             0.9759296795718301, 0.9678207989764183, 0.6683651846760081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 271}], {
             RGBColor[
             0.9547411019974725, 0.8497093540340768, 0.32702885082843114`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 287}], {
             RGBColor[
             0.9891948614420064, 0.9761715605221097, 0.576839344458786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 292}], {
             RGBColor[
             0.9841497194773414, 0.9739512912788686, 0.654450801245744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 309}], {
             RGBColor[
             0.9556385161628249, 0.8532673021541558, 0.3277509313308915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 319}], {
             RGBColor[
             0.9826988979434688, 0.9533014616506861, 0.3872889148596971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 362}], {
             RGBColor[
             0.9670606140262774, 0.8985521139942656, 0.336941419382921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 385}], {
             RGBColor[
             0.989031003668905, 0.9742629677499226, 0.44574573848584953`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[
             0.9587241488007088, 0.865500807337243, 0.3302337037804398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 177}], {
             RGBColor[
             0.9739104953355711, 0.9427414878380074, 0.6217412555675487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 219}], {
             RGBColor[
             0.9808491279921547, 0.9456882789659915, 0.4968932477332935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 248}], {
             RGBColor[
             0.9231432866608194, 0.7225654942234618, 0.2735978323419026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 251}], {
             RGBColor[
             0.9362230395724289, 0.9138548840394831, 0.6585153526668861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 260}], {
             RGBColor[
             0.8934489072957992, 0.5272122547493311, 0.2464503812912785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 162}], {
             RGBColor[
             0.9202434775758708, 0.675623312319024, 0.4719921261595712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 183}], {
             RGBColor[
             0.8879670157794016, 0.5584468693195557, 0.22713140370416418`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 270}], {
             RGBColor[
             0.9149412304888014, 0.6732724414524771, 0.5527770804757988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 357}], {
             RGBColor[
             0.9052163764084544, 0.6660196612023416, 0.5692387217856651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 368}], {
             RGBColor[
             0.9203303120705448, 0.674568439246773, 0.3912647633299852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 132}], {
             RGBColor[
             0.990685565364477, 0.9904162561552292, 0.8040278171021429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 155}], {
             RGBColor[
             0.9922101385204218, 0.9906860088045447, 0.7525427916951356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 180}], {
             RGBColor[
             0.9912089049677872, 0.9885444714756998, 0.6435646983880985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 249}], {
             RGBColor[
             0.9782289382631284, 0.9449812033259268, 0.5743300993968283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 268}], {
             RGBColor[
             0.5842416933112392, 0.6476716558634213, 0.8781211155389845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 279}], {
             RGBColor[
             0.9483371660449702, 0.8297049735774304, 0.5334321768301504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 299}], {
             RGBColor[
             0.975553775660986, 0.9359572517108514, 0.5639375978495733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 300}], {
             RGBColor[
             0.9917016693886002, 0.9895984447456931, 0.6971990646040774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 370}], {
             RGBColor[
             0.9464853326788982, 0.8221289671398977, 0.5319300382665486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 123}], {
             RGBColor[
             0.9887552247255298, 0.9762503772389508, 0.5859266430961338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 161}], {
             RGBColor[
             0.9786513149138566, 0.9421675169333346, 0.5466748614410485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 193}], {
             RGBColor[
             0.9814103072296917, 0.9514742458568487, 0.557393025596087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 195}], {
             RGBColor[
             0.9683993511994697, 0.9041594281234173, 0.5246895842368625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 214}], {
             RGBColor[
             0.9934215173141883, 0.9915476425971927, 0.7586860128787511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 253}], {
             RGBColor[
             0.9737556522568674, 0.9253953769344812, 0.5289993897961898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 257}], {
             RGBColor[
             0.9853052719751365, 0.9646128765244467, 0.5725242281297661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 283}], {
             RGBColor[
             0.9882228061939902, 0.9744544045142518, 0.5838582976399059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 312}], {
             RGBColor[
             0.9886071275263432, 0.9895567686957448, 0.838472910904724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 332}], {
             RGBColor[
             0.953514209098481, 0.8451447998725592, 0.5127126495032157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 334}], {
             RGBColor[
             0.9322456927769247, 0.7515596582347652, 0.4951203593134676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 356}], {
             RGBColor[
             0.9901497994317314, 0.9809546051846818, 0.5913443024863922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 360}], {
             RGBColor[
             0.9833816813252794, 0.9581241535819158, 0.5650514416946852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 364}], {
             RGBColor[
             0.9731969368160883, 0.9781638481078039, 0.869035402580137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 366}], {
             RGBColor[
             0.9290855459526799, 0.7372101695769118, 0.49248345534103066`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 380}], {
             RGBColor[
             0.9848211659244438, 0.9629798731419541, 0.5706435675385817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 389}], {
             RGBColor[
             0.9545905671525681, 0.963798879933323, 0.8835991029549577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 141}], {
             RGBColor[
             0.9433905424828186, 0.7995436968252388, 0.3318844017686672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 179}], {
             RGBColor[
             0.9880303029772326, 0.9868470183467615, 0.6715524369034994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 209}], {
             RGBColor[
             0.9670996422120359, 0.8964212209329294, 0.3511102195660887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 286}], {
             RGBColor[
             0.9805583067540817, 0.9460527609632113, 0.3813526772028306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 290}], {
             RGBColor[
             0.9786865201579624, 0.9397387852581081, 0.37408113973414603`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 304}], {
             RGBColor[
             0.988991387108599, 0.987357380278929, 0.6606819745302298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 338}], {
             RGBColor[
             0.9932576315724242, 0.9891215820022025, 0.5899792630778911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 239}], {
             RGBColor[
             0.970084438294056, 0.9069064125667599, 0.43331068147252455`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 269}], {
             RGBColor[
             0.9815438673006819, 0.9830384030554309, 0.7641756822120813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 309}], {
             RGBColor[
             0.9601943746907483, 0.8676956060479709, 0.42535290414767346`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 323}], {
             RGBColor[
             0.9377123555932405, 0.771986333212896, 0.4069231970174361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 362}], {
             RGBColor[
             0.9716164725542007, 0.9129804178880807, 0.434543392199703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 365}], {
             RGBColor[
             0.9756741420675599, 0.9286656339028057, 0.4399023875331186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 377}], {
             RGBColor[
             0.9337287985962313, 0.7538979312728513, 0.40359921941321436`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 385}], {
             RGBColor[
             0.9935868621968282, 0.9886912716437377, 0.5433477113026315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 388}], {
             RGBColor[
             0.9684997495707499, 0.9006236498450644, 0.4320356037283274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 395}], {
             RGBColor[
             0.9835028429324824, 0.955073680186566, 0.4703154120672345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 124}], {
             RGBColor[
             0.9896700353528125, 0.9843718511747186, 0.6242864090919467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[
             0.9416252337024748, 0.8011719859072999, 0.5325628973962341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 150}], {
             RGBColor[
             0.9548135725176212, 0.8563381988264449, 0.5433234640081959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 179}], {
             RGBColor[
             0.9862649941968888, 0.9884753074288224, 0.8722309325310663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 196}], {
             RGBColor[
             0.9807109121238242, 0.9843330821127056, 0.8816325447441606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 206}], {
             RGBColor[
             0.9612881971920579, 0.8820079281198143, 0.5485330990002217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 209}], {
             RGBColor[
             0.9653343334316922, 0.8980495100149903, 0.5517887151936556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 286}], {
             RGBColor[
             0.978792997973738, 0.9476810500452724, 0.5820311728303975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 386}], {
             RGBColor[
             0.9821261577855734, 0.9589245807537347, 0.5949798692849638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 128}], {
             RGBColor[
             0.9578450137226537, 0.8998894878862909, 0.6055082698178404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 130}], {
             RGBColor[
             0.9773452709032183, 0.9825291845076819, 0.9189544227981885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 135}], {
             RGBColor[
             0.9615672914508946, 0.9146470787032432, 0.6085033018510709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 146}], {
             RGBColor[
             0.9806123581477835, 0.9838802090436221, 0.8648103322049854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 151}], {
             RGBColor[
             0.9819618375440866, 0.9844382534540319, 0.8424459662675143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 213}], {
             RGBColor[
             0.9545714079349776, 0.9656400109371746, 0.961782936078391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 227}], {
             RGBColor[
             0.9787176296783879, 0.9733129810604584, 0.6708909241782428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 243}], {
             RGBColor[
             0.9819046799503658, 0.9844146173201452, 0.8433932155145794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 267}], {
             RGBColor[
             0.9773265819574243, 0.968620650464111, 0.6654869664596194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 306}], {
             RGBColor[
             0.9562469160945402, 0.8935535633252862, 0.6042224029540878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 311}], {
             RGBColor[
             0.981571197608947, 0.9842767138018633, 0.8489198809365252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 344}], {
             RGBColor[
             0.9774342663676517, 0.9825659864193043, 0.9174795376396484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 346}], {
             RGBColor[
             0.9739095708522327, 0.9570942696539386, 0.6522125235643527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 350}], {
             RGBColor[
             0.9818967616509398, 0.9844113428998416, 0.8435244422279708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 354}], {
             RGBColor[
             0.9690860167382178, 0.9408232890030013, 0.6334739266831668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 140}], {
             RGBColor[
             0.9560145623588114, 0.8547321530234036, 0.32818916008267723`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 147}], {
             RGBColor[
             0.9299611850401717, 0.7600264682754723, 0.26250332934228127`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 193}], {
             RGBColor[
             0.9487136595210096, 0.8301044934179913, 0.2998265312176308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 195}], {
             RGBColor[
             0.9357027034907877, 0.7827896756845598, 0.26712308985840627`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 241}], {
             RGBColor[
             0.9528874953685903, 0.8441838217951423, 0.31604109532271907`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 242}], {
             RGBColor[
             0.952350945675445, 0.8423739136923041, 0.31395670108375706`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 255}], {
             RGBColor[
             0.9433067707507008, 0.8118657879978836, 0.27882178935024937`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 263}], {
             RGBColor[
             0.956561838285644, 0.8684563697225474, 0.5701117210501105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 312}], {
             RGBColor[
             0.9559104798176611, 0.8681870162568874, 0.5809064165262677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 331}], {
             RGBColor[
             0.9578146891602844, 0.8689744557560101, 0.5493487397831889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 356}], {
             RGBColor[
             0.9574531517230493, 0.8595848527458243, 0.33377780810793595`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 359}], {
             RGBColor[
             0.9278258180560774, 0.7515604497524038, 0.26078516294337384`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 360}], {
             RGBColor[
             0.9506850336165973, 0.8367544011430584, 0.307484947316229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 380}], {
             RGBColor[
             0.9521245182157617, 0.8416101207030966, 0.31307707316012534`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 389}], {
             RGBColor[
             0.921893919443886, 0.8424291274944656, 0.6260326085765013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[
             0.943860665092523, 0.7999279801673209, 0.41099180366150445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 202}], {
             RGBColor[
             0.9931508096397502, 0.9903348262809044, 0.6831505857960534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 234}], {
             RGBColor[
             0.9921836792013735, 0.9899348929905171, 0.6991784400132988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 289}], {
             RGBColor[
             0.9691193396386047, 0.9030980646381663, 0.4314721539961081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 298}], {
             RGBColor[
             0.9429378848740813, 0.7957378507161732, 0.41022181322782375`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 173}], {
             RGBColor[
             0.9692936912426715, 0.9219250957788063, 0.5949931170688514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 338}], {
             RGBColor[
             0.9740712252701071, 0.9239007288761751, 0.515817014372514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 161}], {
             RGBColor[
             0.974986045867605, 0.9272842005350095, 0.3573259409948654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 196}], {
             RGBColor[
             0.9787470274674106, 0.9701533318831628, 0.664087281916705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 214}], {
             RGBColor[
             0.9897562482679365, 0.9766643261988676, 0.569337092432568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 253}], {
             RGBColor[
             0.9700903832106158, 0.910512060536156, 0.3396504693500067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 283}], {
             RGBColor[
             0.9845575371477386, 0.9595710881159266, 0.3945093771937228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 332}], {
             RGBColor[
             0.9498489400522294, 0.8302614834742341, 0.3233637290570326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 334}], {
             RGBColor[
             0.9285804237306732, 0.7366763418364402, 0.30577143886728453`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 356}], {
             RGBColor[
             0.9864845303854799, 0.9660712887863567, 0.4019953820402092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 364}], {
             RGBColor[
             0.9695316677698367, 0.9632805317094788, 0.679686482133954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 366}], {
             RGBColor[
             0.9254202769064283, 0.7223268531785867, 0.30313453489484765`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 389}], {
             RGBColor[
             0.9509252981063165, 0.948915563534998, 0.6942501825087746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 150}], {
             RGBColor[
             0.9554658828783282, 0.8509834887014524, 0.3359416247952805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 152}], {
             RGBColor[
             0.9894723892551585, 0.9842901194340656, 0.627561916421778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 156}], {
             RGBColor[
             0.9923113617197026, 0.9846172751313156, 0.5189570216060617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 157}], {
             RGBColor[
             0.9660212565101599, 0.8928320277819146, 0.3444347261859155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 160}], {
             RGBColor[
             0.988409371519585, 0.9725642299058839, 0.40947302637045957`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 167}], {
             RGBColor[
             0.9874804193304053, 0.9694306560434346, 0.40586422253339804`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 179}], {
             RGBColor[
             0.9869173045575959, 0.98312059730383, 0.664849093318151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 181}], {
             RGBColor[
             0.9090910107812374, 0.5970821972892031, 0.2956081664879908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 238}], {
             RGBColor[
             0.9794488113265839, 0.9423381563353059, 0.37466294208045725`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 245}], {
             RGBColor[
             0.9920445463369234, 0.9840465840067243, 0.48991581378422683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 386}], {
             RGBColor[
             0.9827784681462804, 0.9535698706287421, 0.3875980300720485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 184}], {
             RGBColor[
             0.9909304553560323, 0.9886770278519977, 0.6661846820463077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 185}], {
             RGBColor[
             0.9907868907935101, 0.9883699577693665, 0.6505585653935453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 190}], {
             RGBColor[
             0.9915063679999048, 0.9899088467635407, 0.7288692192109776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 226}], {
             RGBColor[
             0.9913981632531017, 0.9896774077513071, 0.7170918002837572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 252}], {
             RGBColor[
             0.9885821277480167, 0.9811539817000925, 0.6231835978916624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 274}], {
             RGBColor[
             0.9610415022731256, 0.8815720651197705, 0.5509878134844388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 288}], {
             RGBColor[
             0.9909454321627511, 0.9887090617271816, 0.6678148150315074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 318}], {
             RGBColor[
             0.9580520403561997, 0.8697198447982888, 0.5485824222543902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 176}], {
             RGBColor[
             0.9678964302742692, 0.9127871704077813, 0.5762611070346992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 205}], {
             RGBColor[
             0.989810056325404, 0.9882423339144173, 0.6868329547810698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 298}], {
             RGBColor[
             0.9391541258275071, 0.795274040848281, 0.5529502465012178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 320}], {
             RGBColor[
             0.9899301669557581, 0.9884992384076972, 0.6999062556582221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 347}], {
             RGBColor[
             0.9805418224037021, 0.984635497369685, 0.901108864398511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 373}], {
             RGBColor[
             0.9839733072069432, 0.9871946931174015, 0.8953002557011971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 137}], {
             RGBColor[
             0.9175352572919986, 0.7098543753449913, 0.2524581957830475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 138}], {
             RGBColor[
             0.9438026139832416, 0.8161958141844552, 0.5560449004615138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 193}], {
             RGBColor[
             0.9357384334267144, 0.7777546155879584, 0.28933941931541773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 210}], {
             RGBColor[
             0.9359569282903437, 0.7784916500680139, 0.2901882306013249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 242}], {
             RGBColor[
             0.9393757195811497, 0.7900240358622713, 0.303469589181544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 255}], {
             RGBColor[
             0.9303315446564056, 0.7595159101678508, 0.2683346774480363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 258}], {
             RGBColor[
             0.9262332615294813, 0.7443390637085198, 0.25945681416092614`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 264}], {
             RGBColor[
             0.9472727565937981, 0.8176308073325175, 0.49853565696339325`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 312}], {
             RGBColor[
             0.9429352537233658, 0.8158371384268546, 0.5704193046240547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 328}], {
             RGBColor[
             0.9474351853113283, 0.8164139741552526, 0.4025104291480116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 331}], {
             RGBColor[
             0.9448394630659892, 0.8166245779259773, 0.5388616278809757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 380}], {
             RGBColor[
             0.9391492921214665, 0.7892602428730638, 0.3025899612579123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 394}], {
             RGBColor[
             0.9436199671915422, 0.8043408796488544, 0.31995768968901006`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 130}], {
             RGBColor[
             0.9652667894773774, 0.905329099949693, 0.5886668357245053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 135}], {
             RGBColor[
             0.9494888100250536, 0.8374469941452544, 0.27821571477738766`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 139}], {
             RGBColor[
             0.8848268617752838, 0.503651199752211, 0.22286419505323196`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 151}], {
             RGBColor[
             0.9698833561182456, 0.9072381688960431, 0.5121583791938311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 213}], {
             RGBColor[
             0.9424929265091367, 0.8884399263791856, 0.6314953490047077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 215}], {
             RGBColor[
             0.9182062044038711, 0.7095098467582059, 0.25284263020053865`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 224}], {
             RGBColor[
             0.955460750121772, 0.858405534794668, 0.29717737122985677`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 227}], {
             RGBColor[
             0.9666391482525469, 0.8961128965024694, 0.3406033371045596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 243}], {
             RGBColor[
             0.9698261985245249, 0.9072145327621564, 0.5131056284408961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 259}], {
             RGBColor[
             0.9498474321349268, 0.8388688113071682, 0.27850427054493454`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 306}], {
             RGBColor[
             0.9441684346686992, 0.8163534787672974, 0.2739348158804045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 350}], {
             RGBColor[
             0.9698182802250987, 0.9072112583418527, 0.5132368551542876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 383}], {
             RGBColor[
             0.9692418155121005, 0.9047601694287418, 0.3619500039780911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 131}], {
             RGBColor[
             0.9938029995806767, 0.9906214833784934, 0.6735749088301943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 253}], {
             RGBColor[
             0.9745581865319766, 0.9246433335418894, 0.43691036431712316`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 271}], {
             RGBColor[
             0.959296960525396, 0.8641376579278919, 0.4246308236452132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 287}], {
             RGBColor[
             0.9937507199699298, 0.9905998644159248, 0.6744413172755681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 303}], {
             RGBColor[
             0.9910829282899198, 0.980643087985883, 0.49976261230187113`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 333}], {
             RGBColor[
             0.9589394443883542, 0.8627202255797117, 0.4243431577693671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 337}], {
             RGBColor[
             0.9732631991668333, 0.9195091401680549, 0.4358683870858687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 353}], {
             RGBColor[
             0.9942325936966199, 0.990799131585501, 0.6664554225750852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 364}], {
             RGBColor[
             0.9739994710911974, 0.9774118047152123, 0.7769463771010705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 391}], {
             RGBColor[
             0.9717626495711966, 0.9135599610498663, 0.4346610096587935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 135}], {
             RGBColor[
             0.9689890672056183, 0.9200866907666454, 0.5916618677577357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 146}], {
             RGBColor[
             0.9880341339025072, 0.9893198211070242, 0.8479688981116501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 151}], {
             RGBColor[
             0.9893836132988103, 0.9898778655174341, 0.8256045321741792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 158}], {
             RGBColor[
             0.9553486758254031, 0.8660070843350656, 0.5806864886720778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 227}], {
             RGBColor[
             0.9861394054331116, 0.9787525931238605, 0.6540494900849076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 243}], {
             RGBColor[
             0.9893264557050895, 0.9898542293835474, 0.8265517814212442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 267}], {
             RGBColor[
             0.984748357712148, 0.9740602625275132, 0.6486455323662841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 275}], {
             RGBColor[
             0.9521843061833108, 0.8534614131678441, 0.5781403625807485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 306}], {
             RGBColor[
             0.9636686918492638, 0.8989931753886884, 0.5873809688607525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 311}], {
             RGBColor[
             0.9889929733636706, 0.9897163258652655, 0.8320784468431899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 317}], {
             RGBColor[
             0.989603335864591, 0.9899687264449968, 0.82196316063542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 344}], {
             RGBColor[
             0.9848560421223754, 0.9880055984827064, 0.9006381035463131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 346}], {
             RGBColor[
             0.9813313466069564, 0.9625338817173408, 0.6353710894710175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 354}], {
             RGBColor[
             0.9765077924929415, 0.9462629010664034, 0.6166324925898317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 142}], {
             RGBColor[
             0.9752159009830618, 0.9288625120377694, 0.5214642179200133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 201}], {
             RGBColor[
             0.9912422916300134, 0.990646476773241, 0.7948014221208126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 273}], {
             RGBColor[
             0.9877636415037548, 0.9711889871636475, 0.5702098204009357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 281}], {
             RGBColor[
             0.977977798550069, 0.938179041055673, 0.5321936684272455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 293}], {
             RGBColor[
             0.9888849178097647, 0.989671209959704, 0.8338498541314306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 303}], {
             RGBColor[
             0.9908603655485971, 0.9816349645122838, 0.5822400085478817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 391}], {
             RGBColor[
             0.9715400868298739, 0.9145518375762671, 0.5171384059048041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 394}], {
             RGBColor[
             0.9898718125283057, 0.9783003430515538, 0.5783996667366234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 149}], {
             RGBColor[
             0.9831150560431035, 0.9581211853006433, 0.5702116841451343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 155}], {
             RGBColor[
             0.9933393172624205, 0.9911529532329311, 0.7338293777193092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 180}], {
             RGBColor[
             0.9923380837097859, 0.9890114159040861, 0.6248512844122721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 249}], {
             RGBColor[
             0.9793581170051269, 0.9454481477543132, 0.555616685421002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 268}], {
             RGBColor[
             0.5853708720532378, 0.6481386002918078, 0.8594077015631583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 279}], {
             RGBColor[
             0.9494663447869689, 0.8301719180058169, 0.5147187628543242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 299}], {
             RGBColor[
             0.9766829544029847, 0.9364241961392379, 0.545224183873747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 300}], {
             RGBColor[
             0.9928308481305987, 0.9900653891740796, 0.6784856506282511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 370}], {
             RGBColor[
             0.9476145114208967, 0.8225959115682842, 0.5132166242907223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 178}], {
             RGBColor[
             0.9763661099955875, 0.9361401045369899, 0.5494171133052088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 200}], {
             RGBColor[
             0.9424999585619096, 0.8004661647843878, 0.5135639860865264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 278}], {
             RGBColor[
             0.9917239190374307, 0.9879456006201734, 0.6090793013538869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 296}], {
             RGBColor[
             0.9741643705873573, 0.9287131205200321, 0.5408637714678335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 320}], {
             RGBColor[
             0.9923532194717188, 0.9895012328926562, 0.6597500048098499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 330}], {
             RGBColor[
             0.9878481712594317, 0.9892429207750906, 0.8510507803633043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 347}], {
             RGBColor[
             0.982964874919663, 0.9856374918546441, 0.8609526135501389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 367}], {
             RGBColor[
             0.9868680451827274, 0.9715655978948577, 0.590215148383197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 398}], {
             RGBColor[
             0.9897055922820643, 0.981137310548664, 0.6012384830383145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 163}], {
             RGBColor[
             0.9371715966147618, 0.7886133474415006, 0.26830499574530897`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 171}], {
             RGBColor[
             0.9584269383089914, 0.863295996986577, 0.335340433358254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 240}], {
             RGBColor[
             0.9610576515024745, 0.871464336969863, 0.4055656244340884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 272}], {
             RGBColor[
             0.961248605434555, 0.8718727681221794, 0.42634978150999525`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 342}], {
             RGBColor[
             0.9468765832892927, 0.8243339373528051, 0.2904694852082471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 374}], {
             RGBColor[
             0.933232099724207, 0.772994555029968, 0.2651351840752916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 213}], {
             RGBColor[
             0.9462152042373776, 0.903197517196138, 0.6344903810379382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 215}], {
             RGBColor[
             0.921928482132112, 0.7242674375751583, 0.255837662233769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 224}], {
             RGBColor[
             0.9591830278500129, 0.8731631256116203, 0.3001724032630872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 227}], {
             RGBColor[
             0.9703614259807878, 0.9108704873194218, 0.34359836913778996`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 243}], {
             RGBColor[
             0.9735484762527657, 0.9219721235791087, 0.5161006604741265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 259}], {
             RGBColor[
             0.9535697098631677, 0.8536264021241206, 0.28149930257816497`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 350}], {
             RGBColor[
             0.9735405579533396, 0.9219688491588051, 0.516231887187518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 363}], {
             RGBColor[
             0.9718702681824442, 0.9212781414140506, 0.5439129112626204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 383}], {
             RGBColor[
             0.9729640932403414, 0.9195177602456942, 0.36494503601132156`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 393}], {
             RGBColor[
             0.9437942592053812, 0.8148699977418234, 0.27363374551959196`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 149}], {
             RGBColor[
             0.9759026888391007, 0.9540086283940135, 0.6391329802506229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 155}], {
             RGBColor[
             0.9861269500584178, 0.9870403963263013, 0.8027506738247978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 268}], {
             RGBColor[
             0.578158504849235, 0.644026043385178, 0.9283289976686468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 279}], {
             RGBColor[
             0.9422539775829661, 0.8260593610991871, 0.5836400589598126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 299}], {
             RGBColor[
             0.9694705871989819, 0.9323116392326081, 0.6141454799792355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 300}], {
             RGBColor[
             0.985618480926596, 0.9859528322674498, 0.7474069467337396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 371}], {
             RGBColor[
             0.9862861051378705, 0.9873808129482039, 0.8200737220319366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 138}], {
             RGBColor[
             0.9602611251094135, 0.8823557564299511, 0.5693347452635829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 164}], {
             RGBColor[
             0.9205558569428163, 0.7227374765092527, 0.2549355815837242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 210}], {
             RGBColor[
             0.9524154394165156, 0.8446515923135098, 0.30347807540339417`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 230}], {
             RGBColor[
             0.9562121889882599, 0.8797242410162576, 0.5935717858957728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 242}], {
             RGBColor[
             0.9558342307073215, 0.8561839781077674, 0.3167594339836132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 258}], {
             RGBColor[
             0.9426917726556532, 0.8104990059540158, 0.27274665896299544`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 264}], {
             RGBColor[
             0.9637312677199699, 0.8837907495780135, 0.5118255017654625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 328}], {
             RGBColor[
             0.9638936964375002, 0.8825739164007487, 0.4158002739500808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 394}], {
             RGBColor[
             0.960078478317714, 0.8705008218943504, 0.3332475344910793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 149}], {
             RGBColor[
             0.9804719248901939, 0.957028182643543, 0.6140152075530007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 164}], {
             RGBColor[
             0.9468232136340593, 0.8290789153487166, 0.5585222862621904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 210}], {
             RGBColor[
             0.9786827961077587, 0.9509930311529736, 0.6070647800818604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 230}], {
             RGBColor[
             0.9824795456795029, 0.9860656798557215, 0.8971584905742389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 242}], {
             RGBColor[
             0.9821015873985646, 0.962525416947231, 0.6203461386620794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 258}], {
             RGBColor[
             0.9689591293468962, 0.9168404447934795, 0.5763333636414616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 264}], {
             RGBColor[
             0.9899986244112129, 0.9901321884174772, 0.8154122064439286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 281}], {
             RGBColor[
             0.9744518210307204, 0.9367209587379333, 0.5906282408601676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 328}], {
             RGBColor[
             0.9901610531287433, 0.9889153552402123, 0.719386978628547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 394}], {
             RGBColor[
             0.986345835008957, 0.9768422607338141, 0.6368342391695455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 186}], {
             RGBColor[
             0.8687070450318661, 0.4397414979750566, 0.209893812120748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 213}], {
             RGBColor[
             0.8815532559876078, 0.5694017228030945, 0.5791388613137824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 215}], {
             RGBColor[
             0.8572665338823422, 0.3904716431821148, 0.20048614250961336`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 306}], {
             RGBColor[
             0.8832287641471703, 0.4973152751912063, 0.22157832818947926`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 308}], {
             RGBColor[
             0.9074805944132134, 0.5830828177215082, 0.2951661513883008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 345}], {
             RGBColor[
             0.9051627881017561, 0.5866364670411524, 0.5224611476434653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 350}], {
             RGBColor[
             0.9088786097035699, 0.5881730547657615, 0.46088036746336236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 378}], {
             RGBColor[
             0.8843051865137714, 0.5015829311782898, 0.22244444289252685`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 147}], {
             RGBColor[
             0.9589485490445657, 0.8663644325393149, 0.33054991463955413`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 193}], {
             RGBColor[
             0.9777010235254038, 0.9364424576818339, 0.3678731165149037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 195}], {
             RGBColor[
             0.9646900674951817, 0.8891276399484025, 0.3351696751556791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 241}], {
             RGBColor[
             0.9818748593729845, 0.950521786058985, 0.3840876806199919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 242}], {
             RGBColor[
             0.9813383096798391, 0.9487118779561468, 0.38200328638102987`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 255}], {
             RGBColor[
             0.9722941347550949, 0.9182037522617261, 0.34686837464752224`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 263}], {
             RGBColor[
             0.9855492022900381, 0.97479433398639, 0.6381583063473835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 312}], {
             RGBColor[
             0.9848978438220553, 0.97452498052073, 0.6489530018235405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 331}], {
             RGBColor[
             0.9868020531646786, 0.9753124200198526, 0.6173953250804617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 356}], {
             RGBColor[
             0.9864405157274435, 0.965922817009667, 0.4018243934052088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 359}], {
             RGBColor[
             0.9568131820604715, 0.8578984140162464, 0.32883174824064665`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 360}], {
             RGBColor[
             0.9796723976209915, 0.943092365406901, 0.3755315326135018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 380}], {
             RGBColor[
             0.9811118822201559, 0.9479480849669393, 0.38112365845739826`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 389}], {
             RGBColor[
             0.9508812834482802, 0.9487670917583082, 0.6940791938737743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 179}], {
             RGBColor[
             0.9388725029072581, 0.7999207320364111, 0.5731255816224384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 196}], {
             RGBColor[
             0.9333184208341936, 0.7957785067202943, 0.5825271938355328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 209}], {
             RGBColor[
             0.9179418421420614, 0.7094949346225791, 0.25268336428502775`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 286}], {
             RGBColor[
             0.9314005066841072, 0.759126474652861, 0.2829258219217696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 290}], {
             RGBColor[
             0.9295287200879879, 0.7528124989477576, 0.27565428445308504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 304}], {
             RGBColor[
             0.9398335870386245, 0.8004310939685786, 0.5622551192491688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 386}], {
             RGBColor[
             0.9347336664959427, 0.7703700053613234, 0.295874518376336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.9567881762142767, 0.8658985131313442, 0.2866306537710125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 201}], {
             RGBColor[
             0.9728777557737212, 0.927895628906116, 0.5602133349646211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 273}], {
             RGBColor[
             0.9693991056474626, 0.9084381392965226, 0.3356217332447442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 281}], {
             RGBColor[
             0.9596132626937768, 0.8754281931885479, 0.29760558127105396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 293}], {
             RGBColor[
             0.9705203819534725, 0.9269203620925791, 0.5992617669752391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 394}], {
             RGBColor[
             0.9715072766720134, 0.9155494951844289, 0.34381157958043185`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 151}], {
             RGBColor[
             0.9940509936762117, 0.99078981092771, 0.6742461979125827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 158}], {
             RGBColor[
             0.9600160562028044, 0.8669190297453414, 0.42932815441048133`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 171}], {
             RGBColor[
             0.991243393340227, 0.9811373182521849, 0.5043872936298366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 186}], {
             RGBColor[
             0.9538143531113612, 0.8423313435828146, 0.4243381185304248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 272}], {
             RGBColor[
             0.9940650604657908, 0.9897140893877872, 0.5953966417815778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 306}], {
             RGBColor[
             0.9683360722266653, 0.8999051207989642, 0.4360226345991561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 308}], {
             RGBColor[
             0.9925879024927085, 0.9856726633292661, 0.5096104577979776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 342}], {
             RGBColor[
             0.9796930383205283, 0.942175258618413, 0.45951634547982967`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 348}], {
             RGBColor[
             0.9808131829445044, 0.9459537694575493, 0.46386789582241383`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 354}], {
             RGBColor[
             0.981175172870343, 0.9471748464766794, 0.46527415832823515`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 374}], {
             RGBColor[
             0.9660485547554426, 0.8908358762955757, 0.43418204434687413`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 378}], {
             RGBColor[
             0.9694124945932664, 0.9041727767860477, 0.43688874930220367`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 148}], {
             RGBColor[
             0.9592021074906618, 0.8737833498440354, 0.2973515742563235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 169}], {
             RGBColor[
             0.9785195097268712, 0.9384488448872833, 0.4352150267202536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 218}], {
             RGBColor[
             0.9763903307535495, 0.9389110469522591, 0.5680991338040664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 222}], {
             RGBColor[
             0.9472596292143485, 0.8264354030734253, 0.2877423759092079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 276}], {
             RGBColor[
             0.9721976223275702, 0.9178781931814901, 0.3464934420914318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 282}], {
             RGBColor[
             0.9751660434854896, 0.927891374765585, 0.3580251977506495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 305}], {
             RGBColor[
             0.9778264006731393, 0.9395048987693231, 0.5442997388066437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 339}], {
             RGBColor[
             0.9782378216548626, 0.93784634258429, 0.40455501845940045`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 361}], {
             RGBColor[
             0.9766582333499096, 0.9329248815611154, 0.36382207359751007`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 382}], {
             RGBColor[
             0.9738684964716406, 0.9235144440093455, 0.35298447262303945`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 384}], {
             RGBColor[
             0.9377664611077744, 0.7887981549416012, 0.2801039500173635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 165}], {
             RGBColor[
             0.9582608453694219, 0.8604432588828219, 0.3993312401900699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 170}], {
             RGBColor[
             0.9226020296922364, 0.7308498696140553, 0.25658198020775513`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 182}], {
             RGBColor[
             0.9580546148658358, 0.8600021526887535, 0.37688432258185206`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 192}], {
             RGBColor[
             0.9570453118120693, 0.86141523396941, 0.526665770995335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 208}], {
             RGBColor[
             0.9157840285673413, 0.7038187671180375, 0.2510960564636092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 221}], {
             RGBColor[
             0.9260041919296398, 0.7443383091820008, 0.2593194398029814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 225}], {
             RGBColor[
             0.9503118646205411, 0.8342896367930914, 0.31231600860359743`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 235}], {
             RGBColor[
             0.9557756081053805, 0.8608901788567973, 0.5477080473030291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 335}], {
             RGBColor[
             0.9532736957794683, 0.8442805887631807, 0.3238221633611478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 349}], {
             RGBColor[
             0.9372717032903977, 0.789010237051825, 0.2683855439263313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 351}], {
             RGBColor[
             0.9263152413545432, 0.7455715165006669, 0.25956971747152713`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 355}], {
             RGBColor[
             0.9367994056064027, 0.7871377341186583, 0.26800552212353745`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 395}], {
             RGBColor[
             0.9479645798937872, 0.8263716942410875, 0.30319725068768516`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 151}], {
             RGBColor[
             0.9926507005433755, 0.9912288900533742, 0.7714604415809759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 158}], {
             RGBColor[
             0.9586157630699681, 0.8673581088710056, 0.5265423980788746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 227}], {
             RGBColor[
             0.9894064926776767, 0.9801036176598006, 0.5999053994917044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 243}], {
             RGBColor[
             0.9925935429496546, 0.9912052539194876, 0.772407690828041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 267}], {
             RGBColor[
             0.9880154449567131, 0.9754112870634533, 0.5945014417730808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 275}], {
             RGBColor[
             0.9554513934278761, 0.8548124377037842, 0.5239962719875453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 306}], {
             RGBColor[
             0.966935779093829, 0.9003441999246284, 0.5332368782675494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 311}], {
             RGBColor[
             0.9922600606082357, 0.9910673504012055, 0.7779343562499867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 317}], {
             RGBColor[
             0.9928704231091562, 0.9913197509809368, 0.7678190700422167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 344}], {
             RGBColor[
             0.9881231293669406, 0.9893566230186466, 0.84649401295311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 346}], {
             RGBColor[
             0.9845984338515216, 0.9638849062532808, 0.5812269988778143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 354}], {
             RGBColor[
             0.9797748797375067, 0.9476139256023436, 0.5624884019966284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 195}], {
             RGBColor[
             0.9386366901765419, 0.7944219552004712, 0.26948384441528317`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 217}], {
             RGBColor[
             0.964012182437888, 0.8819562791159449, 0.497624744428797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 231}], {
             RGBColor[
             0.9139258647302159, 0.6937814173152873, 0.24946279981674802`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 241}], {
             RGBColor[
             0.9558214820543447, 0.8558161013110537, 0.31840184987959597`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 242}], {
             RGBColor[
             0.9552849323611994, 0.8540061932082155, 0.31631745564063396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 255}], {
             RGBColor[
             0.9462407574364551, 0.8234980675137948, 0.28118254390712627`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 312}], {
             RGBColor[
             0.9588444665034155, 0.8798192957727987, 0.5832671710831446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 331}], {
             RGBColor[
             0.9607486758460388, 0.8806067352719213, 0.5517094943400658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 359}], {
             RGBColor[
             0.9307598047418317, 0.7631927292683152, 0.26314591750025074`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 392}], {
             RGBColor[
             0.962946312187936, 0.8795446660063935, 0.37202910171887504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 218}], {
             RGBColor[
             0.9722790340048411, 0.9247847573399101, 0.5534707755978054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 228}], {
             RGBColor[
             0.9739391689613142, 0.9233193175505194, 0.36953412188414647`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 276}], {
             RGBColor[
             0.9680863255788619, 0.903751903569141, 0.3318650838851709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.9710547467367813, 0.913765085153236, 0.3433968395443886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 301}], {
             RGBColor[
             0.9476684203082739, 0.8302297555271363, 0.2767509864812283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 305}], {
             RGBColor[
             0.973715103924431, 0.925378609156974, 0.5296713806003828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 313}], {
             RGBColor[
             0.9512486069896182, 0.8444240026921782, 0.2796316887228202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 339}], {
             RGBColor[
             0.9741265249061544, 0.9237200529719409, 0.38992666025313955`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 340}], {
             RGBColor[
             0.9742047937759162, 0.9238874621701649, 0.3984457437072443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 361}], {
             RGBColor[
             0.9725469366012012, 0.9187985919487663, 0.3491937153912491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 382}], {
             RGBColor[
             0.9697571997229324, 0.9093881543969964, 0.33835611441677854`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 155}], {
             RGBColor[
             0.9846396291990482, 0.9583909379499589, 0.5187266587381272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 164}], {
             RGBColor[
             0.9407666567235966, 0.7974099027228446, 0.29961604387314195`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 210}], {
             RGBColor[
             0.972626239197296, 0.9193240185271017, 0.3481585376928119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 230}], {
             RGBColor[
             0.9764229887690402, 0.9543966672298495, 0.6382522481851904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 258}], {
             RGBColor[
             0.9629025724364335, 0.8851714321676076, 0.3174271212524131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 264}], {
             RGBColor[
             0.9839420675007502, 0.9584631757916053, 0.5565059640548802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 268}], {
             RGBColor[
             0.5766711839898656, 0.6153765850088355, 0.6443049825819761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 279}], {
             RGBColor[
             0.9407666567235966, 0.7974099027228446, 0.29961604387314195`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 299}], {
             RGBColor[
             0.9679832663396124, 0.9036621808562657, 0.3301214648925649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 300}], {
             RGBColor[
             0.9841311600672265, 0.9573033738911073, 0.46338293164706895`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 328}], {
             RGBColor[
             0.9841044962182806, 0.9572463426143405, 0.46048073623949853`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 152}], {
             RGBColor[
             0.9546159264199672, 0.856256467085792, 0.5465989713380273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 156}], {
             RGBColor[
             0.9574548988845112, 0.8565836227830419, 0.4379940765223109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 157}], {
             RGBColor[
             0.9311647936749685, 0.7647983754336409, 0.2634717811021646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 160}], {
             RGBColor[
             0.9535529086843936, 0.8445305775576102, 0.3285100812867088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 167}], {
             RGBColor[
             0.9526239564952139, 0.8413970036951609, 0.3249012774496472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 179}], {
             RGBColor[
             0.9520608417224046, 0.8550869449555563, 0.5838861482344002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 181}], {
             RGBColor[
             0.874234547946046, 0.46904854494092946`, 0.21464522140423997`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 206}], {
             RGBColor[
             0.9270840447175736, 0.748619565646548, 0.2601883147035555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 211}], {
             RGBColor[
             0.9573466941377081, 0.8563521837708082, 0.4262166575950905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 238}], {
             RGBColor[
             0.9445923484913925, 0.8143045039870322, 0.29369999699670635`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 386}], {
             RGBColor[
             0.947922005311089, 0.8255362182804684, 0.3066350849882977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 158}], {
             RGBColor[
             0.9599652424662712, 0.8679161532814157, 0.5041780321414037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 186}], {
             RGBColor[
             0.953763539374828, 0.8433284671188888, 0.49918799626134713`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 227}], {
             RGBColor[
             0.9907559720739798, 0.9806616620702105, 0.5775410335542335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 267}], {
             RGBColor[
             0.9893649243530163, 0.9759693314738632, 0.5721370758356099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 306}], {
             RGBColor[
             0.9682852584901321, 0.9009022443350385, 0.5108725123300784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 308}], {
             RGBColor[
             0.9925370887561753, 0.9866697868653402, 0.5844603355289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 311}], {
             RGBColor[
             0.9936095400045388, 0.9916253948116155, 0.7555699903125157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 317}], {
             RGBColor[
             0.9942199025054593, 0.9918777953913469, 0.7454547041047458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 344}], {
             RGBColor[
             0.9894726087632437, 0.9899146674290564, 0.824129647015639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 346}], {
             RGBColor[
             0.9859479132478247, 0.9644429506636909, 0.5588626329403433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 348}], {
             RGBColor[
             0.9807623692079712, 0.9469508929936234, 0.5387177735533362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 354}], {
             RGBColor[
             0.9811243591338098, 0.9481719700127536, 0.5401240360591575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 156}], {
             RGBColor[
             0.9914614052613415, 0.9898902535156552, 0.7296143681488085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 157}], {
             RGBColor[
             0.965171300051799, 0.8981050061662542, 0.5550920727286622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 160}], {
             RGBColor[
             0.9875594150612239, 0.9778372082902235, 0.6201303729132064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 179}], {
             RGBColor[
             0.9860673480992348, 0.9883935756881694, 0.8755064398608978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 181}], {
             RGBColor[
             0.9082410543228765, 0.6023551756735428, 0.5062655130307376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 238}], {
             RGBColor[
             0.978598854868223, 0.9476111347196454, 0.585320288623204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 245}], {
             RGBColor[
             0.9911945898785623, 0.989319562391064, 0.7005731603269736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 168}], {
             RGBColor[
             0.9346024299379736, 0.7639509787868433, 0.3109789402104047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 175}], {
             RGBColor[
             0.9369503703000541, 0.7718711329507549, 0.3201002451457551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 211}], {
             RGBColor[
             0.939039577655018, 0.7779427969842456, 0.41118485742460814`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 216}], {
             RGBColor[
             0.9391056240404427, 0.7780840635243552, 0.4183735988870449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 229}], {
             RGBColor[
             0.9342035198074705, 0.7769764887270658, 0.566457276934647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 294}], {
             RGBColor[
             0.9354434928181092, 0.7774892494328178, 0.5459077152010752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 329}], {
             RGBColor[
             0.9339054537226754, 0.7767907170231532, 0.5685975113193913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 341}], {
             RGBColor[
             0.9197567089459536, 0.7137413505843527, 0.2539911038217779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 343}], {
             RGBColor[
             0.937279010305668, 0.7782482830845712, 0.5154884402652411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 358}], {
             RGBColor[
             0.9386376009576068, 0.7770830094745615, 0.3674321746240157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 379}], {
             RGBColor[
             0.897760050980817, 0.6265319317043277, 0.23629207649510583`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 207}], {
             RGBColor[
             0.9572181061277432, 0.8710323508686318, 0.5705130195122625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 231}], {
             RGBColor[
             0.9405338120141471, 0.8022143350347133, 0.5569503104309472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 369}], {
             RGBColor[
             0.9885329572117113, 0.9895260973645543, 0.8397021049647947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 372}], {
             RGBColor[
             0.9471739647206752, 0.9590960103719741, 0.935474370999416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 387}], {
             RGBColor[
             0.9379052967957517, 0.7902788613333065, 0.5547570129019144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 392}], {
             RGBColor[
             0.9895542594718674, 0.9879775837258196, 0.6795166123330743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 249}], {
             RGBColor[
             0.9808826901610718, 0.9457179004036287, 0.5041316600139948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 268}], {
             RGBColor[
             0.5868954452091827, 0.6484083529411233, 0.8079226761561511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 279}], {
             RGBColor[
             0.9509909179429137, 0.8304416706551324, 0.4632337374473169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.9782075275589295, 0.9366939487885535, 0.49373915846673977`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 300}], {
             RGBColor[
             0.9943554212865435, 0.9903351418233951, 0.6270006252212439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 370}], {
             RGBColor[
             0.9491390845768416, 0.8228656642175997, 0.46173159888371507`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 371}], {
             RGBColor[
             0.9950230454978182, 0.9917631225041492, 0.6996674005194409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 160}], {
             RGBColor[
             0.9903983875257679, 0.9781643639874734, 0.51152547809749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.9889063205637789, 0.9887207313854194, 0.7669015450451815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 181}], {
             RGBColor[
             0.9110800267874204, 0.6026823313707927, 0.39766061821502124`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 245}], {
             RGBColor[
             0.9940335623431065, 0.989646718088314, 0.5919682655112573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 352}], {
             RGBColor[
             0.9941102525457397, 0.9898107506771778, 0.6003155207908291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 396}], {
             RGBColor[
             0.9812344908846278, 0.9472523888316535, 0.4759254701033331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 160}], {
             RGBColor[
             0.9641082823162253, 0.8863791166380725, 0.33700318267734375`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 167}], {
             RGBColor[
             0.9631793301270457, 0.8832455427756232, 0.33339437884028217`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 168}], {
             RGBColor[
             0.9634649200524954, 0.8842089046538681, 0.334503841771522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 203}], {
             RGBColor[
             0.9333300805556837, 0.7733830163765966, 0.26521402175220343`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 206}], {
             RGBColor[
             0.9376394183494052, 0.7904681047270103, 0.2686814160941905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 211}], {
             RGBColor[
             0.9679020677695398, 0.8982007228512705, 0.43470975898572545`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 238}], {
             RGBColor[
             0.9551477221232243, 0.8561530430674944, 0.3021930983873413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 341}], {
             RGBColor[
             0.9486191990604754, 0.8339992764513776, 0.2775160053828952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 358}], {
             RGBColor[
             0.9675000910721286, 0.8973409353415864, 0.390957076185133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 386}], {
             RGBColor[
             0.9584773789429208, 0.8673847573609307, 0.3151281863789327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 267}], {
             RGBColor[
             0.955329986879609, 0.8520985502914946, 0.3272190323335086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 306}], {
             RGBColor[
             0.9342503210167248, 0.7770314631526699, 0.2659544688279771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 308}], {
             RGBColor[
             0.958502151282768, 0.8627990056829717, 0.33954229202679864`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 311}], {
             RGBColor[
             0.9595746025311316, 0.8677546136292469, 0.5106519468104145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 317}], {
             RGBColor[
             0.960184965032052, 0.8680070142089783, 0.5005366606026445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 344}], {
             RGBColor[
             0.9554376712898365, 0.8660438862466879, 0.5792116035135377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 346}], {
             RGBColor[
             0.9519129757744174, 0.8405721694813223, 0.313944589438242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 348}], {
             RGBColor[
             0.946727431734564, 0.823080111811255, 0.29379973005123483`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 354}], {
             RGBColor[
             0.9470894216604024, 0.8243011888303851, 0.29520599255705615`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 374}], {
             RGBColor[
             0.9319628035455021, 0.7679622186492814, 0.2641138785756951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 250}], {
             RGBColor[
             0.9445886569700723, 0.8198707821750255, 0.5571467214389327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 265}], {
             RGBColor[
             0.9899914325145509, 0.9885967539724698, 0.7041377003846816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 321}], {
             RGBColor[
             0.9899642579612218, 0.9901179770072284, 0.8159817474578043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 375}], {
             RGBColor[
             0.9740873808896716, 0.9355674374769508, 0.5897365310309666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 381}], {
             RGBColor[
             0.986488770376936, 0.9886807735751695, 0.8735795710029667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[
             0.9071780365873028, 0.590629286145361, 0.2881766229794191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 238}], {
             RGBColor[
             0.9775358371326492, 0.9358852451914637, 0.36723139857188547`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 245}], {
             RGBColor[
             0.9901315721429889, 0.9775936728628822, 0.4824842702756551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 196}], {
             RGBColor[
             0.9686431176557374, 0.9360704715775466, 0.6248355002616196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 214}], {
             RGBColor[
             0.9796523384562634, 0.9425814658932514, 0.5300853107774827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 253}], {
             RGBColor[
             0.9599864733989426, 0.8764292002305398, 0.3003986876949213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 283}], {
             RGBColor[
             0.9744536273360653, 0.9254882278103105, 0.35525759553863745`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 332}], {
             RGBColor[
             0.9397450302405561, 0.7961786231686179, 0.2841119474019472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 334}], {
             RGBColor[
             0.9184765139189999, 0.7025934815308239, 0.2665196572121991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.9763806205738066, 0.9319884284807405, 0.36274360038512377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 364}], {
             RGBColor[
             0.9594277579581635, 0.9291976714038626, 0.6404347004788686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 366}], {
             RGBColor[
             0.9153163670947551, 0.6882439928729704, 0.2638827532397622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 389}], {
             RGBColor[
             0.9408213882946432, 0.9148327032293817, 0.6549984008536891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 183}], {
             RGBColor[
             0.9615674687048817, 0.87454587830614, 0.5068248107417724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 270}], {
             RGBColor[
             0.9885416834142815, 0.9893714504390614, 0.832470487513407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 280}], {
             RGBColor[
             0.9285260971194296, 0.7317324100534425, 0.47962774709926215`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 291}], {
             RGBColor[
             0.9944047620486831, 0.9916812800005399, 0.7225498243787187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 336}], {
             RGBColor[
             0.9704073300015611, 0.975846879356133, 0.8631672176442828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 357}], {
             RGBColor[
             0.9788168293339345, 0.9821186701889258, 0.8489321288232734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 368}], {
             RGBColor[
             0.993930764996025, 0.9906674482333573, 0.6709581703675935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 171}], {
             RGBColor[
             0.9671296375734797, 0.8977992995676576, 0.3423428294650678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 240}], {
             RGBColor[
             0.9697603507669628, 0.9059676395509435, 0.41256802054090214`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 272}], {
             RGBColor[
             0.9699513046990433, 0.9063760707032599, 0.433352177616809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 342}], {
             RGBColor[
             0.955579282553781, 0.8588372399338857, 0.29747188131506086`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 374}], {
             RGBColor[
             0.9419347989886953, 0.8074978576110484, 0.2721375801821053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 210}], {
             RGBColor[
             0.9389775279411614, 0.7913747512322753, 0.2926656164020016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 230}], {
             RGBColor[
             0.9427742775129057, 0.826447399935023, 0.5827593268943801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 258}], {
             RGBColor[
             0.929253861180299, 0.7572221648727812, 0.2619341999616029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 264}], {
             RGBColor[
             0.9502933562446156, 0.8305139084967789, 0.50101304276407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 279}], {
             RGBColor[
             0.907117945467462, 0.6694606354280181, 0.24412312258233168`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 328}], {
             RGBColor[
             0.950455784962146, 0.829297075319514, 0.4049878149486883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 170}], {
             RGBColor[
             0.9579138388170488, 0.8590674935357416, 0.39905203057273986`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 172}], {
             RGBColor[
             0.9551666475137945, 0.9625624745169392, 0.7668619664613265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 184}], {
             RGBColor[
             0.9933606034661874, 0.9882073270971636, 0.5187208447794035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 190}], {
             RGBColor[
             0.99393651611006, 0.9894391460087066, 0.5814053819440734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 192}], {
             RGBColor[
             0.9923571209368818, 0.9896328578910963, 0.6691358213603198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 221}], {
             RGBColor[
             0.9613160010544521, 0.8725559331036872, 0.40178949016796617`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 226}], {
             RGBColor[
             0.9938283113632569, 0.9892077069964731, 0.569627963016853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 252}], {
             RGBColor[
             0.9910122758581719, 0.9806842809452584, 0.4757197606247583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 274}], {
             RGBColor[
             0.9634716503832808, 0.8811023643649364, 0.40352397621753466`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 288}], {
             RGBColor[
             0.9933755802729062, 0.9882393609723477, 0.5203509777646033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 318}], {
             RGBColor[
             0.9604821884663548, 0.8692501440434548, 0.4011185849874861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 322}], {
             RGBColor[
             0.9875886637651239, 0.9872311292955631, 0.7289119801110682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 351}], {
             RGBColor[
             0.9616270504793557, 0.8737891404223532, 0.4020397678365119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 355}], {
             RGBColor[
             0.9721112147312152, 0.9153553580403446, 0.41047557248852223`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 399}], {
             RGBColor[
             0.9456691127796284, 0.8086600215579223, 0.3891033579337966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 169}], {
             RGBColor[
             0.9738494975373837, 0.9770910264482571, 0.76062268129794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 246}], {
             RGBColor[
             0.9350447877421979, 0.8351648506939566, 0.6070792837461586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 326}], {
             RGBColor[
             0.9740452314340078, 0.9775096814614033, 0.7819271080158797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 363}], {
             RGBColor[
             0.9722514142359946, 0.9777728502221132, 0.88470515866629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 383}], {
             RGBColor[
             0.9733452392938917, 0.9760124690537568, 0.7057372834149911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 168}], {
             RGBColor[
             0.9849240828727408, 0.9608075329153882, 0.39593333811900455`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.9547892433759291, 0.8499816446381165, 0.326643518099686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 211}], {
             RGBColor[
             0.9893612305897852, 0.9747993511127905, 0.496139255333208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 216}], {
             RGBColor[
             0.9894272769752099, 0.9749406176529001, 0.5033279967956448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 238}], {
             RGBColor[
             0.9766068849434697, 0.9327516713290145, 0.36362259473482395`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 341}], {
             RGBColor[
             0.9700783618807208, 0.9105979047128976, 0.33894550173037785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 358}], {
             RGBColor[
             0.988959253892374, 0.9739395636031064, 0.45238657253261555`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 211}], {
             RGBColor[
             0.9896468205152349, 0.9757627129910356, 0.49724871826444783`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 216}], {
             RGBColor[
             0.9897128669006596, 0.975903979531145, 0.5044374597268846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 238}], {
             RGBColor[
             0.9768924748689194, 0.9337150332072595, 0.36473205766606376`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 341}], {
             RGBColor[
             0.9703639518061705, 0.9115612665911426, 0.34005496466161766`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 379}], {
             RGBColor[
             0.9483672938410339, 0.8243518477111176, 0.3223559373349455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 218}], {
             RGBColor[
             0.9915964362410505, 0.989450252383158, 0.6913342280617355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 222}], {
             RGBColor[
             0.9624657347018495, 0.8769746085043242, 0.41097747016687713`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 224}], {
             RGBColor[
             0.9794402915805517, 0.941554858289608, 0.43879209034673955`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 276}], {
             RGBColor[
             0.9874037278150712, 0.968417398612389, 0.46972853634910094`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 326}], {
             RGBColor[
             0.9939213491109962, 0.9894067053313285, 0.5797545476958625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 361}], {
             RGBColor[
             0.9918643388374107, 0.9834640869920143, 0.4870571678551792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 363}], {
             RGBColor[
             0.992127531912983, 0.9896698740920383, 0.6825325983462727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 382}], {
             RGBColor[
             0.9890746019591417, 0.9740536494402443, 0.47621956688070866`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 383}], {
             RGBColor[
             0.9932213569708802, 0.9879094929236819, 0.5035647230949739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 393}], {
             RGBColor[
             0.9640515229359201, 0.8832617304198112, 0.4122534326032443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[
             0.9566983052596962, 0.8600394686223297, 0.526386561378005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 208}], {
             RGBColor[
             0.9154370220149683, 0.7024430017709572, 0.25081684684627925`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 221}], {
             RGBColor[
             0.9256571853772668, 0.7429625438349206, 0.25904023018565137`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 225}], {
             RGBColor[
             0.9499648580681681, 0.8329138714460111, 0.3120367989862674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 235}], {
             RGBColor[
             0.9554286015530076, 0.859514413509717, 0.5474288376856993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 322}], {
             RGBColor[
             0.9519298480879385, 0.8576377400267965, 0.5861627201287534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 335}], {
             RGBColor[
             0.9529266892270953, 0.8429048234161004, 0.32354295374381775`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 349}], {
             RGBColor[
             0.9369246967380247, 0.7876344717047448, 0.2681063343090013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 351}], {
             RGBColor[
             0.9259682348021703, 0.7441957511535866, 0.25929050785419716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 355}], {
             RGBColor[
             0.9364523990540297, 0.785761968771578, 0.2677263125062075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 186}], {
             RGBColor[
             0.9509559390388433, 0.8336759744433637, 0.32932909197860105`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 240}], {
             RGBColor[
             0.9910156924611924, 0.98065028909602, 0.4796034581538472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 272}], {
             RGBColor[
             0.9912066463932729, 0.9810587202483363, 0.5003876152297541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 308}], {
             RGBColor[
             0.9897294884201906, 0.9770172941898152, 0.4146014312461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 342}], {
             RGBColor[
             0.9768346242480105, 0.9335198894789621, 0.3645073189280059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 348}], {
             RGBColor[
             0.9779547688719865, 0.9372984003180984, 0.3688588692705901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 374}], {
             RGBColor[
             0.9631901406829247, 0.8821805071561248, 0.3391730177950504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 192}], {
             RGBColor[
             0.953951113956442, 0.9635344496035274, 0.8941964972665916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 194}], {
             RGBColor[
             0.9384816729431114, 0.9069402939573754, 0.6459090485311578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 221}], {
             RGBColor[
             0.9229099940740124, 0.8464575248161181, 0.626850166074238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 256}], {
             RGBColor[
             0.9366485184910862, 0.9007566335455605, 0.6387875896472107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 316}], {
             RGBColor[
             0.9552817638356501, 0.9628086966893428, 0.779391667679716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 351}], {
             RGBColor[
             0.923221043498916, 0.8476907321347842, 0.6271004437427837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 399}], {
             RGBColor[
             0.9072631057991887, 0.7825616132703532, 0.6141640338400685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 198}], {
             RGBColor[
             0.9770721245237921, 0.934105301936853, 0.383774232634172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 203}], {
             RGBColor[
             0.9588962724519332, 0.8636198863477271, 0.3609428204955182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 266}], {
             RGBColor[
             0.9933297948934006, 0.9881414306751972, 0.5153675217600272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 313}], {
             RGBColor[
             0.9701294771682913, 0.9081557998045173, 0.36998132068750345`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 329}], {
             RGBColor[
             0.9883341357334468, 0.9872855128613087, 0.6878512116238233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 340}], {
             RGBColor[
             0.9930856639545893, 0.9876192592825039, 0.48879537567192755`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 341}], {
             RGBColor[
             0.9741853909567251, 0.9242361464225082, 0.37324480412621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 358}], {
             RGBColor[
             0.9930662829683783, 0.9875778053127171, 0.4866858749284477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 204}], {
             RGBColor[
             0.9820545883911405, 0.9511280542396057, 0.38478589391655105`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 216}], {
             RGBColor[
             0.9920608072627403, 0.9838241336950567, 0.5135587646622349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 229}], {
             RGBColor[
             0.9871587030297679, 0.9827165588977673, 0.661642442709837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 294}], {
             RGBColor[
             0.9883986760404068, 0.9832293196035193, 0.6410928809762653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 307}], {
             RGBColor[
             0.991599366483837, 0.9845528873558702, 0.5880491572072802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 343}], {
             RGBColor[
             0.9902341935279655, 0.9839883532552727, 0.6106736060404311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 379}], {
             RGBColor[
             0.9507152342031144, 0.8322720018750293, 0.3314772422702959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 205}], {
             RGBColor[
             0.9712681016499158, 0.9123695664160141, 0.38867947389114516`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 232}], {
             RGBColor[
             0.9524398620769008, 0.8491469321510281, 0.28059020052839856`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 277}], {
             RGBColor[
             0.9307869967874798, 0.763300536668098, 0.26316779685845854`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 298}], {
             RGBColor[
             0.920612171152019, 0.7194012733498777, 0.2547967656112932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 320}], {
             RGBColor[
             0.9713882122802698, 0.9126264709092938, 0.4017527747682974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 347}], {
             RGBColor[
             0.961999867728214, 0.9087627298712817, 0.6029553835085864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 373}], {
             RGBColor[
             0.965431352531455, 0.9113219256189982, 0.5971467748112724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 390}], {
             RGBColor[
             0.9709569742891182, 0.9117040964510694, 0.35481518072382795`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 219}], {
             RGBColor[
             0.9877898138569492, 0.9881862139373054, 0.7924501269684339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 248}], {
             RGBColor[
             0.9300839725256138, 0.7650634291947758, 0.5691547115770429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 260}], {
             RGBColor[
             0.9003895931605936, 0.569710189720645, 0.5420072605264188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 285}], {
             RGBColor[
             0.9860391057753369, 0.9879397943256036, 0.8561762379115707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 200}], {
             RGBColor[
             0.9275815785758179, 0.745942342445275, 0.26887901316385554`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 278}], {
             RGBColor[
             0.976805539051339, 0.9334217782810605, 0.36439432843121605`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 296}], {
             RGBColor[
             0.9592459906012656, 0.8741892981809192, 0.2961787985451627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 330}], {
             RGBColor[
             0.97292979127334, 0.9347190984359777, 0.6063658074406334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 367}], {
             RGBColor[
             0.9719496651966357, 0.917041775555745, 0.3455301754605262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 398}], {
             RGBColor[
             0.9747872122959726, 0.9266134882095513, 0.3565535101156436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 209}], {
             RGBColor[
             0.9625816026364755, 0.8967982561441017, 0.5923513994198599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 245}], {
             RGBColor[
             0.9886395051809997, 0.9881500402608282, 0.7378603372233465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 286}], {
             RGBColor[
             0.9760402671785213, 0.9464297961743836, 0.6225938570566019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 290}], {
             RGBColor[
             0.974168480582402, 0.9401158204692803, 0.6153223195879173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 352}], {
             RGBColor[
             0.9887161953836331, 0.9883140728496921, 0.7462075925029182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 386}], {
             RGBColor[
             0.9793734269903568, 0.9576733268828459, 0.6355425535111682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 232}], {
             RGBColor[
             0.9741933359340583, 0.9242595463086174, 0.3737304703051251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 249}], {
             RGBColor[
             0.9798814566084372, 0.9435763630747838, 0.39515356670695756`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 268}], {
             RGBColor[
             0.5858942116565481, 0.6462668156122784, 0.6989445828491139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 370}], {
             RGBColor[
             0.948137851024207, 0.8207241268887547, 0.35275350557667795`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 238}], {
             RGBColor[
             0.8982174763943018, 0.560403212574783, 0.2533665386894167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 245}], {
             RGBColor[
             0.9108132114046413, 0.6021116402462015, 0.36861941039318635`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 187}], {
             RGBColor[
             0.9934970145176727, 0.9884990965430179, 0.5335683459021573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 208}], {
             RGBColor[
             0.9508896071885676, 0.8315952848456554, 0.3711191892203762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 323}], {
             RGBColor[
             0.9372796711757717, 0.7710608649950355, 0.35982816839465376`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 377}], {
             RGBColor[
             0.9332961141787625, 0.7529724630549908, 0.356504190790432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 388}], {
             RGBColor[
             0.9680670651532812, 0.8996981816272038, 0.384940575105545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 395}], {
             RGBColor[
             0.9830701585150134, 0.9541482119687054, 0.4232203834444521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 270}], {
             RGBColor[
             0.9562652216178122, 0.8721950074395932, 0.5876097650580001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 291}], {
             RGBColor[
             0.9621283002522141, 0.8745048370010717, 0.4776891019233117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 357}], {
             RGBColor[
             0.9465403675374655, 0.8649422271894576, 0.6040714063678664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 368}], {
             RGBColor[
             0.9616543031995557, 0.8734910052338889, 0.42609744791218646`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 185}], {
             RGBColor[
             0.9930049878756183, 0.9874467013071879, 0.48001428235099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 190}], {
             RGBColor[
             0.993724465082013, 0.9889855903013621, 0.5583249361684223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 226}], {
             RGBColor[
             0.9936162603352099, 0.9887541512891285, 0.5465475172412018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 252}], {
             RGBColor[
             0.9908002248301249, 0.9802307252379139, 0.45263931484910713`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 274}], {
             RGBColor[
             0.9632595993552338, 0.8806488086575919, 0.38044353044188345`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 288}], {
             RGBColor[
             0.9931635292448593, 0.987785805265003, 0.4972705319889521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 318}], {
             RGBColor[
             0.9602701374383079, 0.8687965883361102, 0.37803813921183493`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 190}], {
             RGBColor[
             0.9935809005194909, 0.9886785202187309, 0.5426988195156599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 226}], {
             RGBColor[
             0.9934726957726878, 0.9884470812064974, 0.5309214005884395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 252}], {
             RGBColor[
             0.9906566602676028, 0.9799236551552827, 0.4370131981963448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 274}], {
             RGBColor[
             0.9631160347927117, 0.8803417385749607, 0.36481741378912114`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 288}], {
             RGBColor[
             0.9930199646823371, 0.987478735182372, 0.4816444153361898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 318}], {
             RGBColor[
             0.9601265728757857, 0.8684895182534791, 0.3624120225590726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 357}], {
             RGBColor[
             0.9783255757398073, 0.9798273251484002, 0.7052834450737975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 272}], {
             RGBColor[
             0.953777606164407, 0.842252745578966, 0.4203384401303423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 306}], {
             RGBColor[
             0.9280486179252816, 0.7524437769901431, 0.2609644329479206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 308}], {
             RGBColor[
             0.9523004481913246, 0.8382113195204448, 0.33455225614674217`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 342}], {
             RGBColor[
             0.9394055840191446, 0.7947139148095919, 0.2844581438285942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 348}], {
             RGBColor[
             0.9405257286431207, 0.798492425648728, 0.2888096941711783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 374}], {
             RGBColor[
             0.9257611004540589, 0.7433745324867546, 0.25912384269563865`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 378}], {
             RGBColor[
             0.9291250402918827, 0.7567114329772265, 0.26183054765096814`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 208}], {
             RGBColor[
             0.9512264282191785, 0.832315710972302, 0.40778007978391445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 302}], {
             RGBColor[
             0.9781044979045339, 0.936982122438058, 0.43928213412199085`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 377}], {
             RGBColor[
             0.9336329352093733, 0.7536928891816373, 0.39316508135397027`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 388}], {
             RGBColor[
             0.968403886183892, 0.9004186077538504, 0.4216014656690833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 201}], {
             RGBColor[
             0.9728145668612285, 0.9276824778668159, 0.5599678579718117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 264}], {
             RGBColor[
             0.9750968771617767, 0.9286262718287919, 0.5221440698620057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 273}], {
             RGBColor[
             0.9693359167349698, 0.9082249882572224, 0.33537625625193485`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 281}], {
             RGBColor[
             0.9595500737812841, 0.8752150421492478, 0.29736010427824466`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 293}], {
             RGBColor[
             0.9704571930409797, 0.926707211053279, 0.5990162899824298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 394}], {
             RGBColor[
             0.9714440877595207, 0.9153363441451288, 0.3435661025876225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 207}], {
             RGBColor[
             0.9487991699464022, 0.8307767640094028, 0.29815976195005145`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 241}], {
             RGBColor[
             0.9740104931569351, 0.9239934321712506, 0.35353610293158416`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 263}], {
             RGBColor[
             0.9776848360739887, 0.9482659800986557, 0.6076067286589757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 280}], {
             RGBColor[
             0.9162407288343075, 0.6898779541565272, 0.2713512755022397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 291}], {
             RGBColor[
             0.982119393763561, 0.9498268241036247, 0.5142733527816963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 336}], {
             RGBColor[
             0.958121961716439, 0.9339924234592178, 0.6548907460472604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 359}], {
             RGBColor[
             0.9489488158444221, 0.8313700601285121, 0.29828017055223893`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 226}], {
             RGBColor[
             0.9941921729790825, 0.9899859702006715, 0.6092320544058718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 252}], {
             RGBColor[
             0.9913761374739974, 0.9814625441494569, 0.5153238520137771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 274}], {
             RGBColor[
             0.9638355119991063, 0.8818806275691349, 0.44312806760655343`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 288}], {
             RGBColor[
             0.9937394418887318, 0.989017624176546, 0.559955069153622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 318}], {
             RGBColor[
             0.9608460500821805, 0.8700284072476532, 0.44072267637650486`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 225}], {
             RGBColor[
             0.9792321430910518, 0.9416072835007352, 0.37382122689977815`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 235}], {
             RGBColor[
             0.9846958865758912, 0.9682078255644411, 0.60921326559921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 261}], {
             RGBColor[
             0.9339332287037452, 0.763492583661932, 0.30367906636793496`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 322}], {
             RGBColor[
             0.9811971331108222, 0.9663311520815205, 0.647947148042264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 327}], {
             RGBColor[
             0.9878876974742925, 0.9692721951488088, 0.5377426381193162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 335}], {
             RGBColor[
             0.9821939742499791, 0.9515982354708244, 0.3853273816573285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 349}], {
             RGBColor[
             0.9661919817609085, 0.8963278837594688, 0.32989076222251207`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 355}], {
             RGBColor[
             0.9657196840769136, 0.894455380826302, 0.3295107404197182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 208}], {
             RGBColor[
             0.9498803041348012, 0.8330083661263119, 0.5209006376338591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 221}], {
             RGBColor[
             0.9601004674970997, 0.8735279081902751, 0.5291240209732313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[
             0.9844081401880009, 0.9634792358013659, 0.5821205897738473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 322}], {
             RGBColor[
             0.9863731302077714, 0.9882031043821512, 0.8562465109163333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 335}], {
             RGBColor[
             0.9873699713469282, 0.9734701877714551, 0.5936267445313976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 349}], {
             RGBColor[
             0.9713679788578575, 0.9181998360600995, 0.5381901250965812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 351}], {
             RGBColor[
             0.9604115169220031, 0.8747611155089412, 0.529374298641777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 355}], {
             RGBColor[
             0.9708956811738626, 0.9163273331269326, 0.5378101032937873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 399}], {
             RGBColor[
             0.9444535792222759, 0.8096319966445102, 0.5164378887390617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 195}], {
             RGBColor[
             0.95738916465738, 0.86449998034299, 0.3068070462906327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 242}], {
             RGBColor[
             0.9740374068420373, 0.9240842183507344, 0.3536406575159835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 253}], {
             RGBColor[
             0.9627454657147777, 0.8857359291540539, 0.3111168518499599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 255}], {
             RGBColor[
             0.9649932319172931, 0.8935760926563139, 0.3185057457824758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 283}], {
             RGBColor[
             0.9772126196519004, 0.9347949567338245, 0.365975759693676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 312}], {
             RGBColor[
             0.9775969409842534, 0.9498973209153176, 0.6205903729584942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 332}], {
             RGBColor[
             0.9425040225563912, 0.805485352092132, 0.2948301115569858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 356}], {
             RGBColor[
             0.9791396128896417, 0.9412951574042546, 0.3734617645401624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 360}], {
             RGBColor[
             0.9723714947831896, 0.9184647058014888, 0.34716890374845544`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 364}], {
             RGBColor[
             0.9621867502739986, 0.9385044003273768, 0.6511528646339072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 380}], {
             RGBColor[
             0.9738109793823541, 0.9233204253615269, 0.3527610295923518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 389}], {
             RGBColor[
             0.9435803806104783, 0.924139432152896, 0.6657165650087278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 221}], {
             RGBColor[
             0.9446310264837691, 0.8169337525441234, 0.28083657223779745`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 233}], {
             RGBColor[
             0.9768274558711427, 0.9329098890864287, 0.4142933561800034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 256}], {
             RGBColor[
             0.9583695509008429, 0.8712328612735656, 0.29277399581077024`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 316}], {
             RGBColor[
             0.9770027962454066, 0.933284924417348, 0.43337807384327554`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 399}], {
             RGBColor[
             0.9289841382089452, 0.7530378409983585, 0.26815044000362787`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 241}], {
             RGBColor[
             0.9615630005049607, 0.8785793087201411, 0.3230216103957209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 242}], {
             RGBColor[
             0.9610264508118154, 0.876769400617303, 0.3209372161567589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.9519822758870711, 0.8462612749228824, 0.2858023044232513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 263}], {
             RGBColor[
             0.9652373434220143, 0.9028518566475462, 0.5770922361231126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 312}], {
             RGBColor[
             0.9645859849540315, 0.9025825031818862, 0.5878869315992696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 356}], {
             RGBColor[
             0.9661286568594197, 0.8939803396708232, 0.3407583231809378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 359}], {
             RGBColor[
             0.9365013231924477, 0.7859559366774026, 0.2677656780163757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 360}], {
             RGBColor[
             0.9593605387529677, 0.8711498880680573, 0.31446546238923084`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 380}], {
             RGBColor[
             0.9608000233521321, 0.8760056076280955, 0.32005758823312724`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 389}], {
             RGBColor[
             0.9305694245802564, 0.8768246144194645, 0.6330131236495031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 206}], {
             RGBColor[
             0.9529813843237767, 0.8766144489328087, 0.5984973954395203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 214}], {
             RGBColor[
             0.9834133200560691, 0.9854505972414047, 0.8368466516993223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 286}], {
             RGBColor[
             0.9704861851054567, 0.9422875708582668, 0.6319954692696961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 332}], {
             RGBColor[
             0.9435060118403618, 0.8390477545167713, 0.5908732883237868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 334}], {
             RGBColor[
             0.9222374955188055, 0.7454626128789773, 0.5732809981340388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 366}], {
             RGBColor[
             0.9190773486945607, 0.7311131242211238, 0.5706440941616018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 386}], {
             RGBColor[
             0.9738193449172923, 0.9535311015667292, 0.6449441657242625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 217}], {
             RGBColor[
             0.9842718806455258, 0.9571185238019201, 0.540803225867446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 231}], {
             RGBColor[
             0.9341855629378537, 0.7689436620012625, 0.292641281255397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 254}], {
             RGBColor[
             0.9799352470118637, 0.955325214348, 0.6126724680253137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 314}], {
             RGBColor[
             0.9835657863377323, 0.9554764350537179, 0.45436697418172395`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 369}], {
             RGBColor[
             0.9821847081354178, 0.9562554243311036, 0.5753930757892445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 392}], {
             RGBColor[
             0.9832060103955739, 0.9547069106923687, 0.41520758315752404`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 203}], {
             RGBColor[
             0.9431158458764257, 0.8106045338282158, 0.2812945731502611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 206}], {
             RGBColor[
             0.9474251836701475, 0.8276896221786296, 0.28476196749224814`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 214}], {
             RGBColor[
             0.9778571194024398, 0.9365257704872256, 0.5231112237520501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 266}], {
             RGBColor[
             0.9775493683178931, 0.9351260781556858, 0.4357192744147701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 310}], {
             RGBColor[
             0.9569243798426041, 0.8653507695829444, 0.29240524370739873`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 384}], {
             RGBColor[
             0.9367556079622317, 0.78538830992208, 0.2761769764305287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 215}], {
             RGBColor[
             0.9377954570488691, 0.7921863452912192, 0.5648138980223465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 222}], {
             RGBColor[
             0.9580754458880678, 0.8765017835423974, 0.5813340188718022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 223}], {
             RGBColor[
             0.986613326842289, 0.988732280874548, 0.8715153480302722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 224}], {
             RGBColor[
             0.97505000276677, 0.9410820333276815, 0.6091486390516647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 247}], {
             RGBColor[
             0.9759452757321581, 0.9814554996413516, 0.9200000103945849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 259}], {
             RGBColor[
             0.969436684779925, 0.9215453098401816, 0.5904755383667424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 271}], {
             RGBColor[
             0.9547566981578006, 0.8633440546990101, 0.5786636765470078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 287}], {
             RGBColor[
             0.9892104576023344, 0.989806261187043, 0.8284741701773628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 292}], {
             RGBColor[
             0.9841653156376695, 0.9875859919438019, 0.9060856269643206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 345}], {
             RGBColor[
             0.9856917112682831, 0.9883511691502567, 0.8867889031561984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 350}], {
             RGBColor[
             0.9894075328700969, 0.9898877568748661, 0.8252081229760955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 353}], {
             RGBColor[
             0.9896923313290245, 0.9900055283566191, 0.8204882754768799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 393}], {
             RGBColor[
             0.9596612341221384, 0.8827889054578844, 0.5826099813081694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 400}], {
             RGBColor[
             0.9587397449610369, 0.8791355080021761, 0.5818685294990165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 234}], {
             RGBColor[
             0.9420384412509906, 0.8002753155158691, 0.5212125222969675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 296}], {
             RGBColor[
             0.9253798391675876, 0.7385153584283171, 0.2603256713264803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 298}], {
             RGBColor[
             0.8927926469236984, 0.6060782732415251, 0.23225589551149253`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 320}], {
             RGBColor[
             0.9435686880519494, 0.7993034708009412, 0.37921190466849675`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 330}], {
             RGBColor[
             0.9390636398396621, 0.7990451586833756, 0.5705126802219511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 347}], {
             RGBColor[
             0.9341803434998934, 0.7954397297629292, 0.5804145134087857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 367}], {
             RGBColor[
             0.9380835137629577, 0.7813678358031428, 0.30967704824184383`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 398}], {
             RGBColor[
             0.9409210608622949, 0.7909395484569491, 0.3207003828969613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 273}], {
             RGBColor[
             0.9854254962944142, 0.9702221040319943, 0.6089589374455435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 281}], {
             RGBColor[
             0.9756396533407286, 0.9372121579240196, 0.5709427854718533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 293}], {
             RGBColor[
             0.9865467726004241, 0.9887043268280508, 0.8725989711760385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 303}], {
             RGBColor[
             0.9885222203392565, 0.9806680813806306, 0.6209891255924895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 394}], {
             RGBColor[
             0.9875336673189652, 0.9773334599199005, 0.6171487837812312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 212}], {
             RGBColor[
             0.9933412405295217, 0.990742138698609, 0.7038778129444477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 234}], {
             RGBColor[
             0.9913285857982179, 0.9906821616294524, 0.7933713044315165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 239}], {
             RGBColor[
             0.9692195152513535, 0.9076326566006335, 0.5264336502875683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 269}], {
             RGBColor[
             0.9806789442579794, 0.9837646470893044, 0.8572986510271251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 289}], {
             RGBColor[
             0.9682642462354492, 0.9038453332771017, 0.5256650184143259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 309}], {
             RGBColor[
             0.9593294516480458, 0.8684218500818446, 0.5184758729627172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 362}], {
             RGBColor[
             0.9707515495114982, 0.9137066619219543, 0.5276663610147467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 365}], {
             RGBColor[
             0.9748092190248574, 0.9293918779366792, 0.5330253563481624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 206}], {
             RGBColor[
             0.9292493315982886, 0.7572042065895037, 0.26193055535359433`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 211}], {
             RGBColor[
             0.9595119810184232, 0.8649368247137639, 0.4279588982451293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 216}], {
             RGBColor[
             0.9595780274038479, 0.8650780912538735, 0.43514763970756604`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 266}], {
             RGBColor[
             0.9593735162460342, 0.8646406625665599, 0.4128878622761163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 329}], {
             RGBColor[
             0.9543778570860805, 0.8637847447526714, 0.5853715521399124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 341}], {
             RGBColor[
             0.9402291123093587, 0.800735378313871, 0.27076514464229906`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 358}], {
             RGBColor[
             0.9591100043210119, 0.8640770372040798, 0.3842062154445368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 229}], {
             RGBColor[
             0.9793077378985567, 0.9562334100159164, 0.6311429257054428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 237}], {
             RGBColor[
             0.9836538790701955, 0.9561518360415016, 0.42254609943798316`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 307}], {
             RGBColor[
             0.9837484013526259, 0.9580697384740193, 0.5575496402028861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 343}], {
             RGBColor[
             0.9823832283967542, 0.9575052043734218, 0.580174089036037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 232}], {
             RGBColor[
             0.9743534881280356, 0.924602095657664, 0.3911620482747691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 277}], {
             RGBColor[
             0.9527006228386146, 0.8387557001747341, 0.3737396446048291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 373}], {
             RGBColor[
             0.9873449785825896, 0.9867770891256342, 0.7077186225576431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 390}], {
             RGBColor[
             0.992870600340253, 0.9871592599577055, 0.4653870284701985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 266}], {
             RGBColor[
             0.963682854039756, 0.8817257509169736, 0.41635525661810335`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 286}], {
             RGBColor[
             0.9510634701736904, 0.8399624168653754, 0.2988960235257573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 386}], {
             RGBColor[
             0.9543966299855258, 0.8512059475738378, 0.3118447199803236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 231}], {
             RGBColor[
             0.9116408518481018, 0.6847221026731094, 0.2476242248156531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 280}], {
             RGBColor[
             0.895766704849603, 0.6126413086541523, 0.2343784474491566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 291}], {
             RGBColor[
             0.9616453697788566, 0.8725901786012498, 0.4773005247286132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 368}], {
             RGBColor[
             0.9611713727261983, 0.8715763468340672, 0.4257088707174879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 372}], {
             RGBColor[
             0.9182810045546299, 0.8416037780103702, 0.6261482853841218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 387}], {
             RGBColor[
             0.9090123366297065, 0.6727866289717026, 0.24543092728662017`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 392}], {
             RGBColor[
             0.9606612993058219, 0.8704853513642157, 0.37019052671778013`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 221}], {
             RGBColor[
             0.9188391842523718, 0.7159314413389026, 0.2535543064415055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 225}], {
             RGBColor[
             0.943146856943273, 0.8058827689499933, 0.30655087524212155`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 323}], {
             RGBColor[
             0.8950090848772774, 0.6148774794243195, 0.23403990227641092`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 351}], {
             RGBColor[
             0.9191502336772752, 0.7171646486575687, 0.25380458411005125`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 388}], {
             RGBColor[
             0.9257964788547868, 0.7435147960564878, 0.25915230898730224`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 395}], {
             RGBColor[
             0.9407995722165192, 0.7979648263979894, 0.2974321173262093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 286}], {
             RGBColor[
             0.9551096064133247, 0.8560039987605516, 0.3021516397191911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 290}], {
             RGBColor[
             0.9532378198172053, 0.8496900230554483, 0.29488010225050654`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 304}], {
             RGBColor[
             0.9635426867678418, 0.8973086180762693, 0.5814809370465903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 338}], {
             RGBColor[
             0.9678089312316671, 0.8990728197995427, 0.5107782255942517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 386}], {
             RGBColor[
             0.9584427662251601, 0.8672475294690138, 0.3151003361737575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 230}], {
             RGBColor[
             0.9746338599866049, 0.9483615157392802, 0.6313018207140502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 258}], {
             RGBColor[
             0.9611134436539983, 0.8791362806770382, 0.31047669378127285`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 264}], {
             RGBColor[
             0.982152938718315, 0.9524280243010359, 0.5495555365837399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 279}], {
             RGBColor[
             0.9389775279411614, 0.7913747512322753, 0.2926656164020016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 328}], {
             RGBColor[
             0.9823153674358452, 0.9512111911237711, 0.4535303087683582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 394}], {
             RGBColor[
             0.978500149316059, 0.9391380966173728, 0.3709775693093567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 216}], {
             RGBColor[
             0.9941500146177041, 0.9898957977285474, 0.604643376941088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 238}], {
             RGBColor[
             0.9813296225859638, 0.9477068514046618, 0.4649379748802672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 341}], {
             RGBColor[
             0.974801099523215, 0.9255530847885449, 0.44026088187582113`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 358}], {
             RGBColor[
             0.9936819915348682, 0.9888947436787537, 0.5537019526780589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 239}], {
             RGBColor[
             0.9702650395442804, 0.9072927003794028, 0.4529680130177448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 289}], {
             RGBColor[
             0.9693097705283762, 0.903505377055871, 0.4521993811445024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 309}], {
             RGBColor[
             0.9603749759409728, 0.8680818938606139, 0.4450102356928938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 362}], {
             RGBColor[
             0.9717970738044253, 0.9133667057007235, 0.45420072374492326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 385}], {
             RGBColor[
             0.9937674634470528, 0.9890775594563805, 0.5630050428478518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 215}], {
             RGBColor[
             0.9149325986161951, 0.7752603698090895, 0.6091172964610891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 227}], {
             RGBColor[
             0.9633655424648709, 0.9618634195533531, 0.6968780033651101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 259}], {
             RGBColor[
             0.9465738263472508, 0.9046193343580518, 0.634778936805485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 306}], {
             RGBColor[
             0.9408948288810233, 0.8821040018181809, 0.6302094821409551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 308}], {
             RGBColor[
             0.9651466591470663, 0.9678715443484828, 0.7037973053397767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 345}], {
             RGBColor[
             0.962828852835609, 0.971425193668127, 0.931092301594941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 350}], {
             RGBColor[
             0.9665446744374229, 0.9729617813927363, 0.8695115214148381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 378}], {
             RGBColor[
             0.9419712512476244, 0.8863716578052645, 0.6310755968440027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 257}], {
             RGBColor[
             0.9863062955175432, 0.9650268254843635, 0.5559346774662003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 310}], {
             RGBColor[
             0.9734898012967593, 0.9207865906528283, 0.511390482170534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 332}], {
             RGBColor[
             0.9545152326408878, 0.8455587488324761, 0.49612309883964983`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 389}], {
             RGBColor[
             0.9555915906949749, 0.9642128288932399, 0.8670095522913919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 224}], {
             RGBColor[
             0.9279004222288303, 0.7452259782245719, 0.2747993186862382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 227}], {
             RGBColor[
             0.9390788203596053, 0.7829333399323734, 0.31822528456094096`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 259}], {
             RGBColor[
             0.9222871042419852, 0.7256892547370721, 0.25612621800131596`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 345}], {
             RGBColor[
             0.9385421307303434, 0.7924951140471472, 0.552439582790772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 350}], {
             RGBColor[
             0.9422579523321573, 0.7940317017717566, 0.490858802610669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 353}], {
             RGBColor[
             0.9425427507910848, 0.7941494732535097, 0.4861389551114533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 393}], {
             RGBColor[
             0.9125116535841988, 0.6869328503547749, 0.2482606609427429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 400}], {
             RGBColor[
             0.9115901644230971, 0.6832794528990667, 0.24751920913358993`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 229}], {
             RGBColor[
             0.9893139567701565, 0.9889294894713676, 0.7599157964511268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 294}], {
             RGBColor[
             0.9905539297807954, 0.9894422501771196, 0.7393662347175551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 329}], {
             RGBColor[
             0.9890158906853614, 0.988743717767455, 0.7620560308358713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 340}], {
             RGBColor[
             0.9937674189065039, 0.9890774641886503, 0.5630001948839753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 341}], {
             RGBColor[
             0.9748671459086398, 0.9256943513286545, 0.4474496233382579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 343}], {
             RGBColor[
             0.9923894472683541, 0.990201283828873, 0.708946959781721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 358}], {
             RGBColor[
             0.993748037920293, 0.9890360102188633, 0.5608906941404956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 231}], {
             RGBColor[
             0.9450428754421779, 0.8040789486398485, 0.48222346034638686`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 254}], {
             RGBColor[
             0.9907925595161879, 0.9904605009865859, 0.8022546471163037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 314}], {
             RGBColor[
             0.9944230988420565, 0.9906117216923039, 0.6439491532727137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 331}], {
             RGBColor[
             0.9918656865580009, 0.9909042665964827, 0.7844701548697046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 392}], {
             RGBColor[
             0.9940633228998981, 0.9898421973309547, 0.6047897622485139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 222}], {
             RGBColor[
             0.9603365557285277, 0.8774368105693, 0.5438615772506898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 276}], {
             RGBColor[
             0.9852745488417496, 0.9688796006773648, 0.6026126434329137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 282}], {
             RGBColor[
             0.9882429699996689, 0.9788927822614597, 0.6141443990921314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 305}], {
             RGBColor[
             0.9909033271873187, 0.9905063062651978, 0.8004189401481256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 339}], {
             RGBColor[
             0.991314748169042, 0.9888477500801647, 0.6606742198008824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 361}], {
             RGBColor[
             0.9897351598640889, 0.9839262890569901, 0.6199412749389919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 382}], {
             RGBColor[
             0.98694542298582, 0.9745158515052201, 0.6091036739645214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 384}], {
             RGBColor[
             0.9508433876219538, 0.8397995624374759, 0.5362231513588454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 248}], {
             RGBColor[
             0.9370226051821975, 0.7680102203227598, 0.4443067037427878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 251}], {
             RGBColor[
             0.950102358093807, 0.9592996101387811, 0.8292242240677713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 260}], {
             RGBColor[
             0.9073282258171773, 0.572656980848629, 0.41715925269216364`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 352}], {
             RGBColor[
             0.9904059629620279, 0.9891257641135163, 0.7232609596400756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 396}], {
             RGBColor[
             0.977530201300916, 0.946567402267992, 0.5988709089525797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 256}], {
             RGBColor[
             0.9427978720317439, 0.8107500921323083, 0.2737151133538504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 316}], {
             RGBColor[
             0.9614311173763077, 0.8728021552760907, 0.4143191913863557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 351}], {
             RGBColor[
             0.9293703970395737, 0.757684190721532, 0.2620279674494234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 399}], {
             RGBColor[
             0.9134124593398463, 0.6925550718571011, 0.2490915575467081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 223}], {
             RGBColor[
             0.9597437351435478, 0.8771916640226167, 0.5536861485143014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 224}], {
             RGBColor[
             0.948180411068029, 0.8295414164757501, 0.2913194395356939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 247}], {
             RGBColor[
             0.9490756840334171, 0.8699148827894202, 0.6021708108786141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 259}], {
             RGBColor[
             0.9425670930811838, 0.8100046929882503, 0.27264633885077166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 292}], {
             RGBColor[
             0.9572957239389284, 0.8760453750918705, 0.5882564274483498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 363}], {
             RGBColor[
             0.9608676514004604, 0.8776564322781804, 0.5350599475352271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 383}], {
             RGBColor[
             0.9619614764583575, 0.8758960511098239, 0.35609207228392825`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 393}], {
             RGBColor[
             0.9327916424233974, 0.7712482886059531, 0.26478078179219866`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 247}], {
             RGBColor[
             0.9776135649876382, 0.9821453801215707, 0.8923521400370841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 292}], {
             RGBColor[
             0.9858336048931495, 0.988275872424021, 0.8784377566068198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 319}], {
             RGBColor[
             0.9843827833592769, 0.9676260427958385, 0.611275870220773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 385}], {
             RGBColor[
             0.9907148890847131, 0.988587548895075, 0.6697326938469255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 393}], {
             RGBColor[
             0.9613295233776185, 0.8834787859381037, 0.5549621109506686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 400}], {
             RGBColor[
             0.9604080342165169, 0.8798253884823954, 0.5542206591415156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 227}], {
             RGBColor[
             0.9763333660775062, 0.9318290279688355, 0.3625600255902591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 259}], {
             RGBColor[
             0.9595416499598861, 0.8745849427735342, 0.3004609590306341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 363}], {
             RGBColor[
             0.9778422082791625, 0.9422366820634642, 0.5628745677150895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 383}], {
             RGBColor[
             0.9789360333370597, 0.9404763008951078, 0.3839066924637906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 393}], {
             RGBColor[
             0.9497661993020996, 0.835828538391237, 0.292595401972061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 235}], {
             RGBColor[
             0.9831384364813122, 0.9629541806887532, 0.6031628660815415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 261}], {
             RGBColor[
             0.932375778609166, 0.758238938786244, 0.29762866685026657`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 322}], {
             RGBColor[
             0.979639683016243, 0.9610775072058326, 0.6418967485245957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 327}], {
             RGBColor[
             0.9863302473797134, 0.9640185502731209, 0.5316922386016478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 335}], {
             RGBColor[
             0.9806365241554, 0.9463445905951365, 0.37927698213966005`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 349}], {
             RGBColor[
             0.9646345316663294, 0.8910742388837809, 0.3238403627048436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 355}], {
             RGBColor[
             0.9641622339823344, 0.8892017359506141, 0.3234603409020498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 252}], {
             RGBColor[
             0.9912679327271944, 0.9812311051372231, 0.5035464330865567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 274}], {
             RGBColor[
             0.9637273072523033, 0.8816491885569011, 0.4313506486793329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 288}], {
             RGBColor[
             0.9936312371419287, 0.9887861851643125, 0.5481776502264015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 315}], {
             RGBColor[
             0.9935982129063875, 0.9887155496637522, 0.5445831659896988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 318}], {
             RGBColor[
             0.9607378453353774, 0.8697969682354195, 0.4289452574492844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 322}], {
             RGBColor[
             0.9878443206341465, 0.987777953487528, 0.7567386525728665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 243}], {
             RGBColor[
             0.9906988144802591, 0.9806380259363239, 0.5784882828012985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 306}], {
             RGBColor[
             0.9650410506244333, 0.8897769719414648, 0.33931747024080683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 311}], {
             RGBColor[
             0.9903653321388401, 0.9805001224180419, 0.5840149482232442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 346}], {
             RGBColor[
             0.9827037053821259, 0.9533176782701172, 0.38730759085107175`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 350}], {
             RGBColor[
             0.990690896180833, 0.9806347515160201, 0.57861950951469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 363}], {
             RGBColor[
             0.9890206064099375, 0.9799440437712656, 0.6063005335897923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 383}], {
             RGBColor[
             0.9901144314678347, 0.9781836626029092, 0.42733265833849343`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 276}], {
             RGBColor[
             0.9869346837982225, 0.9674141608879743, 0.41867598971925474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 282}], {
             RGBColor[
             0.989903104956142, 0.9774273424720692, 0.43020774537847245`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 301}], {
             RGBColor[
             0.9665167785276346, 0.8938920128459694, 0.3635618923153122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 305}], {
             RGBColor[
             0.9925634621437915, 0.9890408664758072, 0.6164822864344667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 382}], {
             RGBColor[
             0.988605557942293, 0.9730504117158296, 0.4251670202508624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 294}], {
             RGBColor[
             0.985651825547823, 0.9883346753798302, 0.8874499127651572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 307}], {
             RGBColor[
             0.9888525159912533, 0.989658243132181, 0.834406188996172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[
             0.9841137864523891, 0.9876361429701657, 0.9101397088834733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 340}], {
             RGBColor[
             0.9888653146735316, 0.9879698893913609, 0.7110838729315774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 343}], {
             RGBColor[
             0.9874873430353817, 0.9890937090315834, 0.857030637829323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 258}], {
             RGBColor[
             0.9649101932257426, 0.914208929379786, 0.6005704042736513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 264}], {
             RGBColor[
             0.9859496882900594, 0.9875006730037837, 0.8396492470761184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 279}], {
             RGBColor[
             0.9427742775129057, 0.826447399935023, 0.5827593268943801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 299}], {
             RGBColor[
             0.9699908871289215, 0.932699678068444, 0.613264747913803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 300}], {
             RGBColor[
             0.9861387808565356, 0.9863408711032857, 0.7465262146683072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 328}], {
             RGBColor[
             0.9861121170075895, 0.9862838398265189, 0.7436240192607367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 331}], {
             RGBColor[
             0.9417793688503286, 0.8027294047958251, 0.5363082102576555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 369}], {
             RGBColor[
             0.9429557029320699, 0.803215849169032, 0.5168133102681852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 372}], {
             RGBColor[
             0.9015967104410338, 0.7727857621764518, 0.6125855763028066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 392}], {
             RGBColor[
             0.9439770051922259, 0.8016673355302971, 0.3566278176364649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 277}], {
             RGBColor[
             0.9338723832655995, 0.7755330659097481, 0.2656503712420825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 373}], {
             RGBColor[
             0.9685167390095747, 0.9235544548606482, 0.5996293491948963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 390}], {
             RGBColor[
             0.9740423607672379, 0.9239366256927195, 0.3572977551074519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 256}], {
             RGBColor[
             0.9749943014191176, 0.9267262286746136, 0.40717189729605635`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 257}], {
             RGBColor[
             0.9858211282839545, 0.9632476579495471, 0.4492320751912524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 310}], {
             RGBColor[
             0.9730046340631706, 0.9190074231180119, 0.4046878798955861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 316}], {
             RGBColor[
             0.9936275467636815, 0.988778291818396, 0.5477759753285616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 389}], {
             RGBColor[
             0.9551064234613862, 0.9624336613584235, 0.7603069500164439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 298}], {
             RGBColor[
             0.9411156610325491, 0.7960851860647212, 0.5204425318632868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 365}], {
             RGBColor[
             0.9738420885864807, 0.928991944646292, 0.5490532105654077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 261}], {
             RGBColor[
             0.9378395220940055, 0.7848394808499499, 0.5330207055496983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 322}], {
             RGBColor[
             0.9851034265010825, 0.9876780492695385, 0.8772887872240275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 327}], {
             RGBColor[
             0.9917939908645529, 0.9906190923368268, 0.7670842773010795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 335}], {
             RGBColor[
             0.9861002676402395, 0.9729451326588425, 0.6146690208390918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 349}], {
             RGBColor[
             0.9700982751511689, 0.9176747809474868, 0.5592324014042754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 355}], {
             RGBColor[
             0.9696259774671738, 0.91580227801432, 0.5588523796014815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 262}], {
             RGBColor[
             0.9903176242013378, 0.9817053701436473, 0.5932725819422116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 284}], {
             RGBColor[
             0.9928165188375657, 0.9896198120570164, 0.6467650949819619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 334}], {
             RGBColor[
             0.9321833040093314, 0.7515338588760472, 0.4961543026494447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 366}], {
             RGBColor[
             0.9290231571850864, 0.7371843702181937, 0.49351739867700783`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 376}], {
             RGBColor[
             0.991760687764785, 0.9908608468971419, 0.7862102566014573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 397}], {
             RGBColor[
             0.9762215813867956, 0.9341561078219496, 0.53851211742204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 307}], {
             RGBColor[
             0.9931986571628921, 0.9895766691577661, 0.6258093627287123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 324}], {
             RGBColor[
             0.9931009574644837, 0.9876519705537572, 0.49045997984333434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 269}], {
             RGBColor[
             0.9576027432727383, 0.9003152087700982, 0.6063888511004222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 309}], {
             RGBColor[
             0.9362532506628047, 0.7849724117626382, 0.2675660730360143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 323}], {
             RGBColor[
             0.9137712315652969, 0.6892631389275634, 0.24913636590577692`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 362}], {
             RGBColor[
             0.9476753485262572, 0.830257223602748, 0.2767565610880438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 365}], {
             RGBColor[
             0.9517330180396164, 0.8459424396174731, 0.2821155564214594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 377}], {
             RGBColor[
             0.9097876745682877, 0.6711747369875187, 0.24581238830155516`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 385}], {
             RGBColor[
             0.9696457381688848, 0.9059680773584051, 0.38556088019097234`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 388}], {
             RGBColor[
             0.9445586255428065, 0.8179004555597318, 0.27424877261666825`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 272}], {
             RGBColor[
             0.9938373595867561, 0.9892270602316223, 0.5706128063055884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 342}], {
             RGBColor[
             0.9794653374414937, 0.9416882294622482, 0.4347325100038403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 374}], {
             RGBColor[
             0.9658208538764079, 0.8903488471394109, 0.40939820887088474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 242}], {
             RGBColor[
             0.978211242689618, 0.9381635467278855, 0.3698552216210717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 255}], {
             RGBColor[
             0.9691670677648738, 0.9076554210334649, 0.33472030988756407`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 312}], {
             RGBColor[
             0.9817707768318341, 0.9639766492924686, 0.6368049370635824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 331}], {
             RGBColor[
             0.9836749861744575, 0.9647640887915914, 0.6052472603205035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 359}], {
             RGBColor[
             0.9536861150702505, 0.8473500827879851, 0.3166836834806885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 360}], {
             RGBColor[
             0.9765453306307703, 0.9325440341786397, 0.36338346785354364`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 380}], {
             RGBColor[
             0.9779848152299347, 0.937399753738678, 0.36897559369744004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 392}], {
             RGBColor[
             0.9858726225163548, 0.9637020195260635, 0.42556686769931285`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 255}], {
             RGBColor[
             0.9686305180717285, 0.9058455129306267, 0.33263591564860207`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 312}], {
             RGBColor[
             0.9812342271386888, 0.9621667411896305, 0.6347205428246203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 331}], {
             RGBColor[
             0.9831384364813122, 0.9629541806887532, 0.6031628660815415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 380}], {
             RGBColor[
             0.9774482655367894, 0.9355898456358398, 0.36689119945847803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 267}], {
             RGBColor[
             0.9893077667592954, 0.9759456953399765, 0.5730843250826749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 275}], {
             RGBColor[
             0.9567437152304583, 0.8553468459803074, 0.5025791552971394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 311}], {
             RGBColor[
             0.9935523824108181, 0.9916017586777288, 0.7565172395595807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 326}], {
             RGBColor[
             0.9940014738799285, 0.9907825112702426, 0.6760247742757186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 344}], {
             RGBColor[
             0.9894154511695229, 0.9898910312951698, 0.825076896262704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 346}], {
             RGBColor[
             0.9858907556541039, 0.9644193145298041, 0.5598098821874083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 363}], {
             RGBColor[
             0.9922076566819154, 0.9910456800309526, 0.7788028249261288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 383}], {
             RGBColor[
             0.9933014817398126, 0.9892852988625962, 0.59983494967483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 302}], {
             RGBColor[
             0.9780535500277083, 0.9368731500811487, 0.43373677214338197`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 352}], {
             RGBColor[
             0.9938434371629606, 0.9892400595525865, 0.5712743129689941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 396}], {
             RGBColor[
             0.9809676755018486, 0.9466816977070622, 0.44688426228149813`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 248}], {
             RGBColor[
             0.8977164797374313, 0.6250115671949057, 0.2361873071128785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 251}], {
             RGBColor[
             0.9107962326490409, 0.816300957010927, 0.6211048274378621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 260}], {
             RGBColor[
             0.8680221003724111, 0.42965832772077495`, 0.20903985606225434`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 326}], {
             RGBColor[
             0.9551166393158104, 0.847480529577028, 0.4262111501440812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 271}], {
             RGBColor[
             0.9457569363031499, 0.8567571539460328, 0.5995004685538197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 287}], {
             RGBColor[
             0.9802106957476837, 0.9832193604340658, 0.8493109621841746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 292}], {
             RGBColor[
             0.9751655537830187, 0.9809990911908246, 0.9269224189711325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 319}], {
             RGBColor[
             0.9737147322491461, 0.9603492615626421, 0.6597605325850855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 362}], {
             RGBColor[
             0.9580764483319546, 0.9055999139062215, 0.6094130371083095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 385}], {
             RGBColor[
             0.9800468379745821, 0.9813107676618786, 0.718217356211238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 393}], {
             RGBColor[
             0.9506614722674878, 0.8762020047049072, 0.6034467733149812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 400}], {
             RGBColor[
             0.9497399831063861, 0.8725486072491989, 0.6027053215058282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 251}], {
             RGBColor[
             0.8923965167624717, 0.7361768253962514, 0.6059288086763803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 260}], {
             RGBColor[
             0.8496223844858418, 0.34953419610609937`, 0.19386383730077272`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 275}], {
             RGBColor[
             0.899459164779771, 0.6319207326724171, 0.23758951240402032`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 268}], {
             RGBColor[
             0.5729142449518891, 0.6027035474625054, 0.6297099838578437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 279}], {
             RGBColor[
             0.9370097176856201, 0.7847368651765145, 0.28502104514900956`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 299}], {
             RGBColor[
             0.9642263273016359, 0.8909891433099355, 0.3155264661684325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 300}], {
             RGBColor[
             0.9803742210292501, 0.9446303363447772, 0.4487879329229366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 370}], {
             RGBColor[
             0.935157884319548, 0.7771608587389818, 0.2835189065854078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 265}], {
             RGBColor[
             0.9481028430631959, 0.8197915280240808, 0.38751386905482643`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 321}], {
             RGBColor[
             0.9480756685098667, 0.8213127510588394, 0.4993579161279491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 325}], {
             RGBColor[
             0.9477539649684956, 0.8211797183770786, 0.5046893763505457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 375}], {
             RGBColor[
             0.9321987914383165, 0.7667622115285618, 0.2731126997011114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 381}], {
             RGBColor[
             0.9446001809255811, 0.8198755476267805, 0.5569557396731115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 260}], {
             RGBColor[
             0.8627021373974515, 0.5408235859221207, 0.5787813576257563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 275}], {
             RGBColor[
             0.9125389176913805, 0.8232101224884384, 0.6225070327290039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 274}], {
             RGBColor[
             0.9609112717472182, 0.8731257625056865, 0.3374424462872383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 288}], {
             RGBColor[
             0.9908152016368437, 0.9802627591130978, 0.4542694478343069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 318}], {
             RGBColor[
             0.9579218098302924, 0.8612735421842048, 0.3350370550571897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 283}], {
             RGBColor[
             0.9695579646790762, 0.908716087811457, 0.33758212389377873`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 332}], {
             RGBColor[
             0.934849367583567, 0.7794064831697645, 0.26643647575708845`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 334}], {
             RGBColor[
             0.9135808512620107, 0.6858213415319705, 0.2488441855673404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 364}], {
             RGBColor[
             0.9545320953011743, 0.9124255314050091, 0.6227592288340098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 366}], {
             RGBColor[
             0.9104207044377659, 0.671471852874117, 0.2462072815949035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 391}], {
             RGBColor[
             0.9522952737811736, 0.8485736877396631, 0.2804738613917329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 314}], {
             RGBColor[
             0.9900864652083944, 0.9888184122383838, 0.7158183954305816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 369}], {
             RGBColor[
             0.98870538700608, 0.9895974015157694, 0.836844497038102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 312}], {
             RGBColor[
             0.9721900522139446, 0.93165861549521, 0.5995856310911127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 331}], {
             RGBColor[
             0.974094261556568, 0.9324460549943326, 0.5680279543480338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 356}], {
             RGBColor[
             0.9737327241193329, 0.9230564519841469, 0.35245702267278095`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 359}], {
             RGBColor[
             0.9441053904523609, 0.8150320489907263, 0.27946437750821884`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 360}], {
             RGBColor[
             0.9669646060128808, 0.900226000381381, 0.326164161881074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 380}], {
             RGBColor[
             0.9684040906120452, 0.9050817199414192, 0.33175628772497034`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 310}], {
             RGBColor[
             0.9545467290928706, 0.8573303953051489, 0.2831685195263528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 316}], {
             RGBColor[
             0.9751696417933815, 0.9271012640055329, 0.42625661495932843`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 319}], {
             RGBColor[
             0.9685101735348012, 0.9054395625493303, 0.3321683998477988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 384}], {
             RGBColor[
             0.9343779572124982, 0.7773679356442844, 0.2669402522494828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 310}], {
             RGBColor[
             0.9653735559577076, 0.8938518245800824, 0.3252286974215489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 356}], {
             RGBColor[
             0.9830345776350865, 0.9544337880718526, 0.3885929670738414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 360}], {
             RGBColor[
             0.9762664595286344, 0.9316033364690868, 0.36230010628213444`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 389}], {
             RGBColor[
             0.9474753453559231, 0.937278062820494, 0.6808477675424067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 264}], {
             RGBColor[
             0.9724292719574525, 0.9182754379415419, 0.5188241201433412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 279}], {
             RGBColor[
             0.929253861180299, 0.7572221648727812, 0.2619341999616029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 281}], {
             RGBColor[
             0.95688246857696, 0.8648642082619978, 0.2940401545595801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 300}], {
             RGBColor[
             0.9726183645239288, 0.9171156360410438, 0.4257010877355299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 328}], {
             RGBColor[
             0.9725917006749829, 0.917058604764277, 0.4227988923279595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 394}], {
             RGBColor[
             0.9687764825551967, 0.9049855102578788, 0.340246152868958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 271}], {
             RGBColor[
             0.9392483453509166, 0.7968469641448628, 0.26997599652597726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 287}], {
             RGBColor[
             0.9737021047954505, 0.9233091706328957, 0.5197864901563322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 292}], {
             RGBColor[
             0.9686569628307855, 0.9210889013896546, 0.59739794694329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 345}], {
             RGBColor[
             0.9701833584613992, 0.9218540785961096, 0.5781012231351679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 350}], {
             RGBColor[
             0.9738991800632129, 0.9233906663207189, 0.5165204429550649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 353}], {
             RGBColor[
             0.9741839785221404, 0.9235084378024719, 0.5118005954558492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 393}], {
             RGBColor[
             0.9441528813152544, 0.8162918149037373, 0.2739223012871388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 400}], {
             RGBColor[
             0.9432313921541529, 0.812638417448029, 0.2731808494779858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 327}], {
             RGBColor[
             0.9410313329924067, 0.7859038504343177, 0.46155007806980464`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 335}], {
             RGBColor[
             0.9353376097680933, 0.7682298907563332, 0.3091348216078169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 349}], {
             RGBColor[
             0.9193356172790227, 0.7129595390449777, 0.25369820217300043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 355}], {
             RGBColor[
             0.9188633195950278, 0.7110870361118108, 0.2533181803702066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 284}], {
             RGBColor[
             0.9908384268023089, 0.9802430872808239, 0.46269422670990223`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 325}], {
             RGBColor[
             0.9905736972921775, 0.9818112629474878, 0.5890287881310827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 376}], {
             RGBColor[
             0.9897825957295281, 0.9814841221209494, 0.6021393883293975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 397}], {
             RGBColor[
             0.9742434893515388, 0.9247793830457571, 0.35444124914998026`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 336}], {
             RGBColor[
             0.9665336038593211, 0.9742449940460958, 0.9273648847031015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 359}], {
             RGBColor[
             0.9573604579873041, 0.8716226307153901, 0.57075430920808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 360}], {
             RGBColor[
             0.9802196735478241, 0.9568165821060448, 0.6174540935809352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 279}], {
             RGBColor[
             0.9502933562446156, 0.8305139084967789, 0.50101304276407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 281}], {
             RGBColor[
             0.9779219636412768, 0.9381559518859955, 0.5331189973620472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 328}], {
             RGBColor[
             0.9936311957392996, 0.9903503483882747, 0.6618777351304266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 394}], {
             RGBColor[
             0.9898159776195135, 0.9782772538818765, 0.579324995671425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 321}], {
             RGBColor[
             0.9934784440543454, 0.9900387228562837, 0.6463488950736979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 325}], {
             RGBColor[
             0.9931567405129742, 0.9899056901745229, 0.6516803552962944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 375}], {
             RGBColor[
             0.9776015669827953, 0.935488183326006, 0.42010367864686016`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 381}], {
             RGBColor[
             0.9900029564700598, 0.9886015194242248, 0.7039467186188603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 358}], {
             RGBColor[
             0.9935435267624793, 0.9885985815315498, 0.5386309167090458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 384}], {
             RGBColor[
             0.9530132783318401, 0.8394244386604239, 0.4077702655563839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 275}], {
             RGBColor[
             0.9521656172375168, 0.8395528791242732, 0.3246729062421793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 306}], {
             RGBColor[
             0.9636500029034698, 0.8850846413451174, 0.3339135125221834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 311}], {
             RGBColor[
             0.9889742844178766, 0.9758077918216945, 0.5786109905046207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 317}], {
             RGBColor[
             0.989584646918797, 0.9760601924014258, 0.5684957042968507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 344}], {
             RGBColor[
             0.9848373531765814, 0.9740970644391356, 0.6471706472077439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 346}], {
             RGBColor[
             0.9813126576611624, 0.9486253476737698, 0.38190363313244824`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 354}], {
             RGBColor[
             0.9764891035471475, 0.9323543670228326, 0.3631650362512624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 279}], {
             RGBColor[
             0.5430224727337309, 0.48742731771400905`, 0.5888120612911658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 299}], {
             RGBColor[
             0.5702390823497467, 0.5936795958474301, 0.6193174823105888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 300}], {
             RGBColor[
             0.586386976077361, 0.6473207888822718, 0.7525789490650929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 370}], {
             RGBColor[
             0.541170639367659, 0.4798513112764763, 0.5873099227275641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 371}], {
             RGBColor[
             0.5870546002886354, 0.6487487695630259, 0.8252457243632898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 309}], {
             RGBColor[
             0.9477126796694306, 0.8611044022513092, 0.5984310737755711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 323}], {
             RGBColor[
             0.9252306605719228, 0.7653951294162343, 0.5800013666453337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 362}], {
             RGBColor[
             0.9591347775328831, 0.9063892140914189, 0.6076215618276006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 365}], {
             RGBColor[
             0.9631924470462423, 0.9220744301061439, 0.6129805571610163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 377}], {
             RGBColor[
             0.9212471035749136, 0.7473067274761896, 0.576677389041112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 388}], {
             RGBColor[
             0.9560180545494323, 0.8940324460484027, 0.6051137733562251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 336}], {
             RGBColor[
             0.9651050829144916, 0.9734960084895863, 0.9439521719605104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 357}], {
             RGBColor[
             0.9735145822468652, 0.979767799322379, 0.929717083139501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 287}], {
             RGBColor[
             0.9590221181733263, 0.8651079154917243, 0.5079746283365976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 292}], {
             RGBColor[
             0.9539769762086612, 0.8628876462484831, 0.5855860851235555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 303}], {
             RGBColor[
             0.9563543264933163, 0.8551511390616824, 0.3332959233629006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 333}], {
             RGBColor[
             0.9242108425917506, 0.737228276655511, 0.2578764688303965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 337}], {
             RGBColor[
             0.9385345973702297, 0.7940171912438542, 0.2694016981468981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 345}], {
             RGBColor[
             0.9555033718392749, 0.863652823454938, 0.5662893613154332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 353}], {
             RGBColor[
             0.9595039919000162, 0.8653071826613004, 0.4999887336361146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 385}], {
             RGBColor[
             0.9588582604002247, 0.8631993227195371, 0.37688102236366094`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 391}], {
             RGBColor[
             0.9370340477745931, 0.7880680121256656, 0.26819432071982297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 400}], {
             RGBColor[
             0.9285514055320285, 0.7544371623068574, 0.26136898765825123`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 308}], {
             RGBColor[
             0.9925511555457542, 0.9855940653254175, 0.5056107793978951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 342}], {
             RGBColor[
             0.9796562913735742, 0.9420966606145644, 0.45551666707974714`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 348}], {
             RGBColor[
             0.9807764359975504, 0.9458751714537008, 0.4598682174223313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 374}], {
             RGBColor[
             0.9660118078084885, 0.8907572782917272, 0.4301823659467916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 375}], {
             RGBColor[
             0.9778629144383764, 0.9360471791072129, 0.4485497363373202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 378}], {
             RGBColor[
             0.9693757476463123, 0.9040941787821992, 0.43288907090212114`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 281}], {
             RGBColor[
             0.9721610032144699, 0.9177546683144262, 0.3463511837519764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 293}], {
             RGBColor[
             0.9830681224741655, 0.9692468372184573, 0.6480073694561614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 394}], {
             RGBColor[
             0.9840550171927065, 0.957875970310307, 0.3925571820613542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 288}], {
             RGBColor[
             0.9632745761619526, 0.8806808425327758, 0.38207366342708327`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 318}], {
             RGBColor[
             0.9303811843554013, 0.7616916256038828, 0.2628412706499661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 311}], {
             RGBColor[
             0.9564102328890395, 0.8552089424620255, 0.5081058207190852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 317}], {
             RGBColor[
             0.95702059538996, 0.8554613430417568, 0.49799053451131514`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 344}], {
             RGBColor[
             0.9522733016477443, 0.8534982150794664, 0.5766654774222084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 346}], {
             RGBColor[
             0.9487486061323254, 0.8280264983141008, 0.3113984633469127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 282}], {
             RGBColor[
             0.9840502615736897, 0.9578599284906907, 0.39253870737949687`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 301}], {
             RGBColor[
             0.9606639351451824, 0.8743245988645909, 0.32589285431633663`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 305}], {
             RGBColor[
             0.9867106187613394, 0.9694734524944287, 0.5788132484354911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 339}], {
             RGBColor[
             0.9871220397430627, 0.9678148963093957, 0.4390685280882478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 361}], {
             RGBColor[
             0.9855424514381097, 0.9628934352862211, 0.3983355832263574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 382}], {
             RGBColor[
             0.9827527145598407, 0.9534829977344512, 0.3874979822518868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 373}], {
             RGBColor[
             0.9468638737201538, 0.8377080593777182, 0.5822069455249564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 390}], {
             RGBColor[
             0.9523894954778169, 0.8380902302097895, 0.3398753514375119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 296}], {
             RGBColor[
             0.9746037996431088, 0.9259947942641027, 0.35584098659384084`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 302}], {
             RGBColor[
             0.9772692541769833, 0.9349859982853478, 0.36619577412909016`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 330}], {
             RGBColor[
             0.9882876003151833, 0.9865245945191612, 0.6660279954893116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 367}], {
             RGBColor[
             0.987307474238479, 0.9688472716389284, 0.40519236350920435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 299}], {
             RGBColor[
             0.9343345550834778, 0.7757129135614391, 0.2746285436017546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 300}], {
             RGBColor[
             0.9504824488110919, 0.8293541065962808, 0.4078900103562587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 328}], {
             RGBColor[
             0.950455784962146, 0.829297075319514, 0.4049878149486883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 370}], {
             RGBColor[
             0.90526611210139, 0.6618846289904854, 0.2426209840187299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 371}], {
             RGBColor[
             0.9511500730223665, 0.8307820872770351, 0.4805567856544557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 291}], {
             RGBColor[
             0.9290869286667618, 0.7316913687483741, 0.4504920382808014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 336}], {
             RGBColor[
             0.9050894966196397, 0.7158569681039673, 0.5911094315463655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 368}], {
             RGBColor[
             0.9286129316141035, 0.7306775369811915, 0.39890038426967617`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 387}], {
             RGBColor[
             0.8764538955176115, 0.531887819118827, 0.2186224408388084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 392}], {
             RGBColor[
             0.9281028581937272, 0.7295865415113401, 0.3433820402699684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 293}], {
             RGBColor[
             0.9732822795204797, 0.9362368911104827, 0.6099912174824713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 394}], {
             RGBColor[
             0.9742691742390208, 0.9248660242023324, 0.354541030087664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 301}], {
             RGBColor[
             0.9636323563031017, 0.8843377804486858, 0.33742460997555435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 305}], {
             RGBColor[
             0.9896790399192588, 0.9794866340785237, 0.5903450040947088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 313}], {
             RGBColor[
             0.967212542984446, 0.8985320276137279, 0.3403053122171462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 339}], {
             RGBColor[
             0.9900904609009822, 0.9778280778934906, 0.4506002837474655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 340}], {
             RGBColor[
             0.990168729770744, 0.9779954870917146, 0.4591193672015703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 361}], {
             RGBColor[
             0.988510872596029, 0.972906616870316, 0.40986733888557514`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 382}], {
             RGBColor[
             0.9857211357177602, 0.9634961793185461, 0.3990297379111045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 312}], {
             RGBColor[
             0.9844094399485519, 0.9728774795727206, 0.647055645002313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 332}], {
             RGBColor[
             0.9493165215206898, 0.8284655107495351, 0.32129538360080456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 334}], {
             RGBColor[
             0.9280480051991336, 0.7348803691117411, 0.3037030934110565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 356}], {
             RGBColor[
             0.9859521118539403, 0.9642753160616577, 0.3999270365839812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 360}], {
             RGBColor[
             0.9791839937474882, 0.9414448644588918, 0.3736341757922742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 364}], {
             RGBColor[
             0.9689992492382971, 0.9614845589847798, 0.6776181366777261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 366}], {
             RGBColor[
             0.9248878583748887, 0.7205308804538877, 0.3010661894386196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 380}], {
             RGBColor[
             0.9806234783466525, 0.94630058401893, 0.3792263016361706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 389}], {
             RGBColor[
             0.9503928795747769, 0.947119590810299, 0.6921818370525465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 334}], {
             RGBColor[
             0.9327041066103025, 0.7500715760132238, 0.36557594741713545`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 366}], {
             RGBColor[
             0.9295439597860575, 0.7357220873553704, 0.3629390434446985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 397}], {
             RGBColor[
             0.9767423839877667, 0.9326938249591263, 0.4079337621897307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 324}], {
             RGBColor[
             0.9921624051994069, 0.989142670112076, 0.642584239371656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 290}], {
             RGBColor[
             0.9666964843592512, 0.8993215630857301, 0.3251225598872485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 304}], {
             RGBColor[
             0.9770013513098876, 0.9469401581065511, 0.6117233946833323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 386}], {
             RGBColor[
             0.9719014307672059, 0.9168790694992959, 0.34534279381049937`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 292}], {
             RGBColor[
             0.9884307356531951, 0.9893498527365161, 0.8353965787539104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 303}], {
             RGBColor[
             0.9908080859378501, 0.9816133455497152, 0.5831064169932555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 353}], {
             RGBColor[
             0.9939577513445501, 0.9917693891493333, 0.7497992272664695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 385}], {
             RGBColor[
             0.9933120198447585, 0.98966152920757, 0.6266915159940158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 391}], {
             RGBColor[
             0.9714878072191269, 0.9145302186136985, 0.5180048143501779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 400}], {
             RGBColor[
             0.9630051649765624, 0.8808993687948903, 0.5111794812886061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 318}], {
             RGBColor[
             0.9602851142450267, 0.8688286222112942, 0.3796682721970347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 304}], {
             RGBColor[
             0.9751295647137683, 0.9406261824014478, 0.6044518572146477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 338}], {
             RGBColor[
             0.9793958091775936, 0.9423903841247212, 0.5337491457623089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 336}], {
             RGBColor[
             0.9709681615488934, 0.9758058380510648, 0.8340315088258221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 368}], {
             RGBColor[
             0.9944915965433572, 0.990626406928289, 0.6418224615491328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 387}], {
             RGBColor[
             0.9423325604468653, 0.7918366890659245, 0.461544518118265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 303}], {
             RGBColor[
             0.9857629439731852, 0.9793930763064742, 0.6607178737802133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 309}], {
             RGBColor[
             0.9548743903740136, 0.866445594368562, 0.5863081656260157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 362}], {
             RGBColor[
             0.9662964882374661, 0.9117304062086719, 0.5954986536780452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 385}], {
             RGBColor[
             0.9882668778800936, 0.987441259964329, 0.7043029727809738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 400}], {
             RGBColor[
             0.9579600230118974, 0.8786790995516492, 0.588790938075564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 394}], {
             RGBColor[
             0.9851762934987164, 0.9763581931063636, 0.6561972157918491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 301}], {
             RGBColor[
             0.9635689142165282, 0.8948249434540843, 0.5688395539719897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 313}], {
             RGBColor[
             0.9671491008978724, 0.9090191906191262, 0.5717202562135816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 329}], {
             RGBColor[
             0.985353759463028, 0.9881489036759177, 0.8895901471499015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 340}], {
             RGBColor[
             0.9901052876841704, 0.9884826500971129, 0.6905343111980057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 343}], {
             RGBColor[
             0.9887273160460206, 0.9896064697373355, 0.8364810760957513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 330}], {
             RGBColor[
             0.9707280518651098, 0.9272921144190198, 0.5978124656032582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 367}], {
             RGBColor[
             0.9697479257884054, 0.909614791538787, 0.336976833623151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 398}], {
             RGBColor[
             0.9725854728877424, 0.9191865041925933, 0.3480001682782684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 325}], {
             RGBColor[
             0.9931788866879872, 0.9899530586035538, 0.6540908297761041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 375}], {
             RGBColor[
             0.9776237131578083, 0.935535551755037, 0.42251415312666984`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 376}], {
             RGBColor[
             0.992387785125338, 0.9896259177770155, 0.6672014299744189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 378}], {
             RGBColor[
             0.9691365463657442, 0.9035825514300233, 0.4068534876914708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 397}], {
             RGBColor[
             0.9768486787473486, 0.9329211787018232, 0.41950329079500165`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 320}], {
             RGBColor[
             0.9426459078335077, 0.7951133413497935, 0.37844191423481605`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 347}], {
             RGBColor[
             0.9332575632814518, 0.7912496003117814, 0.579644522975105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 373}], {
             RGBColor[
             0.9366890480846928, 0.7938087960594978, 0.5738359142777911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 390}], {
             RGBColor[
             0.9422146698423561, 0.7941909668915692, 0.3315043201903466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 300}], {
             RGBColor[
             0.9776990584271077, 0.9356063847297018, 0.4383954313756816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 370}], {
             RGBColor[
             0.9324827217174058, 0.7681369071239064, 0.27312640503815283`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 371}], {
             RGBColor[
             0.9783666826383823, 0.937034365410456, 0.5110622066738786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 370}], {
             RGBColor[
             0.9486306154450199, 0.8217781001587481, 0.4063878717926569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 371}], {
             RGBColor[
             0.9945145763659964, 0.9906755584452978, 0.6443236734283827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 305}], {
             RGBColor[
             0.9662927134907515, 0.8959513044524239, 0.5236991510315485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 313}], {
             RGBColor[
             0.9438262165559388, 0.8149966979876282, 0.27365945915398593`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 329}], {
             RGBColor[
             0.9620308751210942, 0.8941264110444196, 0.5915293500903058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 339}], {
             RGBColor[
             0.9667041344724748, 0.8942927482673908, 0.3839544306843053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 340}], {
             RGBColor[
             0.9667824033422368, 0.8944601574656148, 0.39247351413841003`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 361}], {
             RGBColor[
             0.9651245461675217, 0.8893712872442163, 0.34322148582241485`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 382}], {
             RGBColor[
             0.9623348092892529, 0.8799608496924464, 0.3323838848479443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 367}], {
             RGBColor[
             0.9724133803222799, 0.9186059955600321, 0.3473316211584003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 377}], {
             RGBColor[
             0.9179035975656236, 0.7014554889500308, 0.26221797901026556`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 353}], {
             RGBColor[
             0.9912899596645401, 0.9818126127192914, 0.5751205222927726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 385}], {
             RGBColor[
             0.9906442281647486, 0.9797047527775281, 0.4520128110203189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 391}], {
             RGBColor[
             0.968820015539117, 0.9045734421836567, 0.3433261093764809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 400}], {
             RGBColor[
             0.9603373732965526, 0.8709425923648484, 0.33650077631490916`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 338}], {
             RGBColor[
             0.9897006761282301, 0.9900089791455422, 0.8203499805583927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 313}], {
             RGBColor[
             0.9698729001720957, 0.9101455516174659, 0.5265798532731404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 329}], {
             RGBColor[
             0.9880775587372512, 0.9892752646742573, 0.8444497442094603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 339}], {
             RGBColor[
             0.9927508180886317, 0.9894416018972286, 0.6368748248034597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 340}], {
             RGBColor[
             0.9928290869583937, 0.9896090110954526, 0.6453939082575645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 361}], {
             RGBColor[
             0.9911712297836788, 0.984520140874054, 0.5961418799415693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 382}], {
             RGBColor[
             0.9883814929054098, 0.9751097033222842, 0.5853042789670988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 308}], {
             RGBColor[
             0.9668221673066288, 0.8957850967365946, 0.34623677221547344`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 311}], {
             RGBColor[
             0.9678946185549924, 0.9007407046828697, 0.5173464269990892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 346}], {
             RGBColor[
             0.9602329917982783, 0.8735582605349451, 0.3206390696269167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 348}], {
             RGBColor[
             0.9550474477584248, 0.8560662028648778, 0.3004942102399096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 350}], {
             RGBColor[
             0.9682201825969853, 0.900875333780848, 0.5119509882905349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 354}], {
             RGBColor[
             0.9554094376842633, 0.8572872798840079, 0.3019004727457309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 378}], {
             RGBColor[
             0.9436467594071868, 0.8142852101933762, 0.2735150637196994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 343}], {
             RGBColor[
             0.9919280064894508, 0.9909300374896863, 0.7834373523267661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 348}], {
             RGBColor[
             0.9792992780244679, 0.9418337453951795, 0.37408203343873114`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 354}], {
             RGBColor[
             0.9796612679503065, 0.9430548224143096, 0.37548829594455246`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 374}], {
             RGBColor[
             0.9645346498354062, 0.886715852233206, 0.3443961819631915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 378}], {
             RGBColor[
             0.96789858967323, 0.900052752723678, 0.347102886918521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 323}], {
             RGBColor[
             0.9038811679619893, 0.6500523324087744, 0.24117858858092586`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 362}], {
             RGBColor[
             0.9377852849229495, 0.7910464170839591, 0.2687987837631928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 365}], {
             RGBColor[
             0.9418429544363087, 0.806731633098684, 0.2741577790966083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 385}], {
             RGBColor[
             0.9597556745655771, 0.8667572708396161, 0.3776031028661213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 316}], {
             RGBColor[
             0.9731799744374345, 0.9193824584489312, 0.4237725975588581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 319}], {
             RGBColor[
             0.9665205061788542, 0.8977207569927286, 0.32968438244732845`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 384}], {
             RGBColor[
             0.9323882898565512, 0.7696491300876827, 0.26445623484901254`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 317}], {
             RGBColor[
             0.9938292625703196, 0.9917162557391781, 0.7519286187737566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 344}], {
             RGBColor[
             0.9890819688281041, 0.9897531277768878, 0.8306035616846498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 346}], {
             RGBColor[
             0.985557273312685, 0.9642814110115221, 0.565336547609354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 354}], {
             RGBColor[
             0.98073371919867, 0.9480104303605849, 0.5465979507281682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 356}], {
             RGBColor[
             0.9863364331862932, 0.9793776802431507, 0.6545416498487993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 359}], {
             RGBColor[
             0.9567090995193213, 0.8713532772497301, 0.5815490046842372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 360}], {
             RGBColor[
             0.9795683150798411, 0.9565472286403849, 0.6282487890570924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 380}], {
             RGBColor[
             0.9810077996790055, 0.961402948200423, 0.6338409149009887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 389}], {
             RGBColor[
             0.9507772009071298, 0.9622219549917921, 0.9467964503173647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 329}], {
             RGBColor[
             0.9656110618024385, 0.9083206582094616, 0.5944100523318978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 339}], {
             RGBColor[
             0.970284321153819, 0.9084869954324328, 0.3868351329258972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 340}], {
             RGBColor[
             0.9703625900235809, 0.9086544046306568, 0.3953542163800019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 358}], {
             RGBColor[
             0.97034320903737, 0.9086129506608699, 0.3932447156365221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 361}], {
             RGBColor[
             0.968704732848866, 0.9035655344092582, 0.3461021880640067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 369}], {
             RGBColor[
             0.9923359263319484, 0.9897486222214874, 0.6785390031945122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 322}], {
             RGBColor[
             0.9873585653082546, 0.9867389719628423, 0.703867183083914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 351}], {
             RGBColor[
             0.9617421668012113, 0.8740353625947568, 0.41456946905490144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 399}], {
             RGBColor[
             0.945784229101484, 0.8089062437303258, 0.4016330591521861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 344}], {
             RGBColor[
             0.9896923313290245, 0.9900055283566191, 0.8204882754768799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 346}], {
             RGBColor[
             0.9861676358136054, 0.9645338115912535, 0.5552212614015841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 354}], {
             RGBColor[
             0.9813440816995905, 0.9482628309403163, 0.5364826645203983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 322}], {
             RGBColor[
             0.9544981977372444, 0.8678203905345097, 0.5882292745434996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 384}], {
             RGBColor[
             0.9463517342984817, 0.817758297331864, 0.31345611517045846`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 347}], {
             RGBColor[
             0.9840336044097027, 0.9844747978711975, 0.7266005321321092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 398}], {
             RGBColor[
             0.9907743217721041, 0.9799746165652174, 0.46688640162028483`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 375}], {
             RGBColor[
             0.977574392429466, 0.9370094063607648, 0.5319477257199828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 381}], {
             RGBColor[
             0.9899757819167305, 0.9901227424589834, 0.8157907656919829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 327}], {
             RGBColor[
             0.9882952373994838, 0.9887424188539062, 0.8058181597441338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 335}], {
             RGBColor[
             0.9826015141751704, 0.9710684591759219, 0.653402903282146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 349}], {
             RGBColor[
             0.9665995216860997, 0.9157981074645662, 0.5979662838473296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 355}], {
             RGBColor[
             0.9661272240021048, 0.9139256045313995, 0.5975862620445358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 362}], {
             RGBColor[
             0.9153032658254416, 0.6953371442488842, 0.2503690766329554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 365}], {
             RGBColor[
             0.9193609353388008, 0.7110223602636092, 0.255728071966371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 377}], {
             RGBColor[
             0.8774155918674722, 0.5362546576336549, 0.21942490384646673`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 388}], {
             RGBColor[
             0.9121865428419909, 0.6829803762058679, 0.2478612881615798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 395}], {
             RGBColor[
             0.9271896362037233, 0.7374304065473695, 0.28614109650048686`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 376}], {
             RGBColor[
             0.9920167608556246, 0.9909667397009824, 0.7819664627903284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 397}], {
             RGBColor[
             0.9764776544776352, 0.93426200062579, 0.5342683236109111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 363}], {
             RGBColor[
             0.9923232658096071, 0.9900885291051846, 0.7038370250642125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 383}], {
             RGBColor[
             0.9934170908675042, 0.9883281479368282, 0.5248691498129137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 335}], {
             RGBColor[
             0.9892920785386408, 0.9740095022432101, 0.5431983933591982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 349}], {
             RGBColor[
             0.9732900860495701, 0.9187391505318545, 0.4877617739243817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 355}], {
             RGBColor[
             0.9728177883655751, 0.9168666475986877, 0.48738175212158785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 339}], {
             RGBColor[
             0.9884889797189746, 0.9876167084892242, 0.704705023862217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 340}], {
             RGBColor[
             0.9885672485887365, 0.9877841176874482, 0.7132241073163218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 341}], {
             RGBColor[
             0.9696669755908722, 0.9244010048274525, 0.5976735357706042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 343}], {
             RGBColor[
             0.9871892769505866, 0.9889079373276709, 0.8591708722140674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 358}], {
             RGBColor[
             0.9885478676025254, 0.9877426637176614, 0.711114606572842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 367}], {
             RGBColor[
             0.9834317264604799, 0.9701445917938454, 0.6471638425186217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 398}], {
             RGBColor[
             0.9862692735598169, 0.9797163044476518, 0.6581871771737391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 392}], {
             RGBColor[
             0.9907998163080489, 0.9884926534869312, 0.6588745121597825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 334}], {
             RGBColor[
             0.8933394081036243, 0.6055707644700485, 0.23255744527436628`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 356}], {
             RGBColor[
             0.951243514758431, 0.8349657114199651, 0.32878138844729093`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 364}], {
             RGBColor[
             0.9342906521427878, 0.8321749543430872, 0.6064724885410357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 366}], {
             RGBColor[
             0.8901792612793795, 0.5912212758121951, 0.22992054130192938`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 380}], {
             RGBColor[
             0.9459148812511433, 0.8169909793772374, 0.30808065349948033`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 389}], {
             RGBColor[
             0.9156842824792677, 0.8178099861686063, 0.6210361889158563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 337}], {
             RGBColor[
             0.938177081233188, 0.7925997588956739, 0.269114032271052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 345}], {
             RGBColor[
             0.9551458557022332, 0.8622353911067577, 0.5660016954395871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 353}], {
             RGBColor[
             0.9591464757629744, 0.8638897503131202, 0.4997010677602685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 391}], {
             RGBColor[
             0.9366765316375514, 0.7866505797774854, 0.2679066548439769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 364}], {
             RGBColor[
             0.9130221358212316, 0.7385898127052932, 0.5888801983512877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 366}], {
             RGBColor[
             0.8689107449578233, 0.4976361341744011, 0.2123282511121813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 391}], {
             RGBColor[
             0.910785314301231, 0.6747379690399473, 0.24659483090901074`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 349}], {
             RGBColor[
             0.9675963628252566, 0.9010651908538702, 0.33534651746239397`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 355}], {
             RGBColor[
             0.9671240651412616, 0.8991926879207033, 0.3349664956596001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 359}], {
             RGBColor[
             0.9377975836297544, 0.8573490740759522, 0.6180383265963647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 345}], {
             RGBColor[
             0.9694696104807123, 0.9190243056951009, 0.5775269247560888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 353}], {
             RGBColor[
             0.9734702305414535, 0.9206786649014633, 0.5112262970767701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 391}], {
             RGBColor[
             0.9510002864160305, 0.8434394943658285, 0.2794318841604785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 340}], {
             RGBColor[
             0.993240507940117, 0.9879504549104196, 0.5056491879103213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 361}], {
             RGBColor[
             0.9915826507654021, 0.982861584689021, 0.4563971595943261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 382}], {
             RGBColor[
             0.9887929138871332, 0.9734511471372511, 0.4455595586198555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 343}], {
             RGBColor[
             0.9919408051717291, 0.9892416837488662, 0.6601150362621715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 358}], {
             RGBColor[
             0.993299395823668, 0.9880764101388566, 0.5120587706209462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 361}], {
             RGBColor[
             0.991660919635164, 0.983028993887245, 0.4649162430484308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 358}], {
             RGBColor[
             0.9743991228258038, 0.9246932972788608, 0.3965081990752286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 348}], {
             RGBColor[
             0.9664044138522878, 0.8983363406843266, 0.32398792112058317`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 374}], {
             RGBColor[
             0.951639785663226, 0.843218447522353, 0.2943020696450435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 346}], {
             RGBColor[
             0.9814203420713898, 0.9625706836289631, 0.6338962043124773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 354}], {
             RGBColor[
             0.9765967879573749, 0.9462997029780258, 0.6151576074312914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 350}], {
             RGBColor[
             0.9901542065515712, 0.9901965256307941, 0.812833807744521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 353}], {
             RGBColor[
             0.9904390050104988, 0.9903142971125471, 0.8081139602453051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 354}], {
             RGBColor[
             0.9730720924419559, 0.9208279862126603, 0.3498905933559958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 398}], {
             RGBColor[
             0.9813859772200482, 0.9761108755272054, 0.6680890103605738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 354}], {
             RGBColor[
             0.9678865484021024, 0.9033359285425928, 0.32974573396898865`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 374}], {
             RGBColor[
             0.9527599302872021, 0.8469969583614894, 0.2986536199876276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 378}], {
             RGBColor[
             0.9561238701250259, 0.8603338588519613, 0.30136032494295717`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 355}], {
             RGBColor[
             0.951122072652191, 0.8439223362093478, 0.27952987622478365`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 355}], {
             RGBColor[
             0.9401656107163365, 0.8004836156581895, 0.2707140497699795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 395}], {
             RGBColor[
             0.9513307850037211, 0.8397175757806188, 0.3059057783341272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 399}], {
             RGBColor[
             0.9137235087647498, 0.6937882791757671, 0.24934183521525383`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 396}], {
             RGBColor[
             0.981044365704482, 0.9468457302959261, 0.4552315175610699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 391}], {
             RGBColor[
             0.9719696809458169, 0.9147294857832747, 0.5100189196496949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 400}], {
             RGBColor[
             0.9634870387032524, 0.8810986359644666, 0.5031935865881232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 374}], {
             RGBColor[
             0.9531219202130407, 0.8482180353806194, 0.30005988249344895`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 359}], {
             RGBColor[
             0.9582517714247095, 0.8627511137386672, 0.33442039626590536`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 360}], {
             RGBColor[
             0.9811109869852295, 0.9479450651293218, 0.3811201806387605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 364}], {
             RGBColor[
             0.9709262424760383, 0.9679847596552098, 0.6851041415242123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 380}], {
             RGBColor[
             0.9825504715843938, 0.95280078468936, 0.386712306482657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 389}], {
             RGBColor[
             0.9523198728125182, 0.953619791480729, 0.699667841899033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 360}], {
             RGBColor[
             0.9514836533182575, 0.8399206621359012, 0.3081275354741984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 380}], {
             RGBColor[
             0.9757823534779417, 0.929970333086594, 0.36041944569094997`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 389}], {
             RGBColor[
             0.9455517547060661, 0.9307893398779631, 0.673374981107326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 382}], {
             RGBColor[
             0.9872133255821801, 0.9685296861140764, 0.4048266137579651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 365}], {
             RGBColor[
             0.9532650522997611, 0.8520164449387937, 0.28334826714863787`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 385}], {
             RGBColor[
             0.9711777724290295, 0.9120420826797258, 0.3867935909181508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 383}], {
             RGBColor[
             0.991623273669491, 0.9885913166975381, 0.6276472004633238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 393}], {
             RGBColor[
             0.962453439634531, 0.8839435541936673, 0.5363359099715942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 366}], {
             RGBColor[
             0.9098619889969868, 0.7242403240474398, 0.5862432943788508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 380}], {
             RGBColor[
             0.9655976089687507, 0.9500100276124821, 0.6644034065764017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 391}], {
             RGBColor[
             0.9517365583403945, 0.901342158912986, 0.6205098741756803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 377}], {
             RGBColor[
             0.9153773783417916, 0.6929339583235645, 0.2524040943621492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 388}], {
             RGBColor[
             0.9501483293163103, 0.8396596768957776, 0.28084047867726225`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 372}], {
             RGBColor[
             0.9511272313191304, 0.9596400063374093, 0.7906702222046414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 387}], {
             RGBColor[
             0.9418585633942069, 0.7908228572987417, 0.4099528641071397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 387}], {
             RGBColor[
             0.8989681952226385, 0.7608502884750449, 0.6103922787737737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 392}], {
             RGBColor[
             0.950617157898754, 0.9585490108675578, 0.7351518782049337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 390}], {
             RGBColor[
             0.9870338512217921, 0.9861116191606896, 0.6738543293903259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 381}], {
             RGBColor[
             0.9740989048451805, 0.9355722029287058, 0.5895455492651454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 397}], {
             RGBColor[
             0.9756865529149861, 0.9339348597992518, 0.547378923809226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 388}], {
             RGBColor[
             0.9082029858449816, 0.6648919742658232, 0.24453731055735803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 389}], {
             RGBColor[
             0.9469912393052304, 0.9356450594380012, 0.6789671069512224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 393}], {
             RGBColor[
             0.9635472646924281, 0.8821831730253109, 0.3573680347202954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 400}], {
             RGBColor[
             0.962841307203461, 0.8789907760227031, 0.3800858753156696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 395}], {
             RGBColor[
             0.9579770301812327, 0.8660677231795378, 0.3112535032113781]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.027885652381746694`], {
             RGBColor[
             0.9554219419078034, 0.8609698849613615, 0.28298965195875286`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.027885652381746694`], {
             RGBColor[
             0.9930932121206845, 0.987635404046545, 0.4896169469695123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.027885652381746694`], {
             RGBColor[
             0.9854360545794981, 0.9882454485393669, 0.8910257961076673]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.027885652381746694`], {
             RGBColor[
             0.9597931468424784, 0.9695343752645759, 0.9529438941556165]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.027885652381746694`], {
             RGBColor[
             0.9762957570804383, 0.931702163990713, 0.3624139217385136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.027885652381746694`], {
             RGBColor[
             0.9949959278311028, 0.991705120557062, 0.6967158098483238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.027885652381746694`], {
             RGBColor[
             0.9938115301589507, 0.9891718136973024, 0.567801432489726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.027885652381746694`], {
             RGBColor[
             0.9153568815091886, 0.702125271370781, 0.2507523639141894]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.027885652381746694`], {
             RGBColor[
             0.9398757781596734, 0.7993345261519942, 0.2704808436916438]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.027885652381746694`], {
             RGBColor[
             0.9392193207214607, 0.9541904494300693, 0.9877700152652583]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.027885652381746694`], {
             RGBColor[
             0.9246864889638953, 0.7391140560213071, 0.25825918506627943`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.027885652381746694`], {
             RGBColor[
             0.9895095603187062, 0.9899299478468518, 0.8235172641140651]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.027885652381746694`], {
             RGBColor[
             0.9827657656256318, 0.9535270220439004, 0.3875486831779981]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.027885652381746694`], {
             RGBColor[
             0.9527350577154565, 0.8503172844897862, 0.2808277218683127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.027885652381746694`], {
             RGBColor[
             0.9911415873795292, 0.9906048329776844, 0.7964703521655848]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.027885652381746694`], {
             RGBColor[
             0.9896421427506954, 0.9767226567368696, 0.41426210981401096`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.027885652381746694`], {
             RGBColor[
             0.9637897281665183, 0.9725150190722435, 0.9461787244493673]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.027885652381746694`], {
             RGBColor[
             0.9762957570804383, 0.931702163990713, 0.3624139217385136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.027885652381746694`], {
             RGBColor[
             0.9210436571385565, 0.7246714417355835, 0.255328077071359]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.027885652381746694`], {
             RGBColor[
             0.9604032619421188, 0.8780930461538499, 0.3006745791720224]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.027885652381746694`], {
             RGBColor[
             0.9936534922729542, 0.9888337866392369, 0.5505999838957715]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.027885652381746694`], {
             RGBColor[
             0.970294969264735, 0.9114600976363629, 0.339101994228199]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.027885652381746694`], {
             RGBColor[
             0.9278595071850776, 0.7516940159226531, 0.2608122700073529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.027885652381746694`], {
             RGBColor[
             0.9526869567380308, 0.8501265801429937, 0.2807890186928009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.027885652381746694`], {
             RGBColor[
             0.9946489209616504, 0.9909629079510793, 0.6589462535865773]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.027885652381746694`], {
             RGBColor[
             0.956724987301784, 0.8656853620920442, 0.28638517677820313`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.027885652381746694`], {
             RGBColor[
             0.9649956167175967, 0.8935841371477156, 0.31851501028132356`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.027885652381746694`], {
             RGBColor[
             0.9057427075284533, 0.6640082752707251, 0.24301657385562192`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.027885652381746694`], {
             RGBColor[
             0.9784462765849518, 0.9389563712454292, 0.37076828392201655`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.027885652381746694`], {
             RGBColor[
             0.9951034552548347, 0.9919351108437341, 0.7084195063391923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.027885652381746694`], {
             RGBColor[
             0.9857236793629641, 0.9635047596310954, 0.39903961949239497`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.027885652381746694`], {
             RGBColor[
             0.9936153889636535, 0.9887522875134785, 0.5464526738247699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.027885652381746694`], {
             RGBColor[
             0.9832466070980662, 0.9551490132373687, 0.38941666149911336`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.027885652381746694`], {
             RGBColor[
             0.9894640572860959, 0.9899111311734928, 0.8242713671224922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.027885652381746694`], {
             RGBColor[
             0.9554558442174533, 0.8611042963218484, 0.2830169305528867]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.027885652381746694`], {
             RGBColor[
             0.9820614484140645, 0.9511511947077386, 0.38481254381020447`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.027885652381746694`], {
             RGBColor[
             0.9874342959492293, 0.9890717726982116, 0.8579097653283276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.027885652381746694`], {
             RGBColor[
             0.9286953586907328, 0.7550078886115731, 0.26148481574875954`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.027885652381746694`], {
             RGBColor[
             0.9836528354111309, 0.9565193167242795, 0.3909947817855895]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.027885652381746694`], {
             RGBColor[
             0.9362919253747481, 0.7851257441079104, 0.26759719161705614`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.027885652381746694`], {
             RGBColor[
             0.9930376070237354, 0.9875164703667088, 0.48356467532149217`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.027885652381746694`], {
             RGBColor[
             0.9944011045464518, 0.9919527270919772, 0.74245171734965]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.027885652381746694`], {
             RGBColor[
             0.9950898824698783, 0.9919060800291314, 0.7069421924582071]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.027885652381746694`], {
             RGBColor[
             0.9932492594922173, 0.9914764095609837, 0.7615407707777617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.027885652381746694`], {
             RGBColor[
             0.994597906929979, 0.990853794095644, 0.6533936910612579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.027885652381746694`], {
             RGBColor[
             0.9283251459616978, 0.753540118507028, 0.26118693389696834`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.027885652381746694`], {
             RGBColor[
             0.9928668803686985, 0.9871513033146975, 0.4649821325235076]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.027885652381746694`], {
             RGBColor[
             0.9167606405333548, 0.9364640662293703, 0.9919226423675983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.027885652381746694`], {
             RGBColor[
             0.9787333166504071, 0.9399246247864225, 0.37188338037334256`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.027885652381746694`], {
             RGBColor[
             0.9925787815571564, 0.9865350890880669, 0.4336243548269173]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.027885652381746694`], {
             RGBColor[
             0.9925351326011683, 0.9864417283847948, 0.4288734353377442]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.027885652381746694`], {
             RGBColor[
             0.9851337051624567, 0.9881204192853946, 0.8960365084032536]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.027885652381746694`], {
             RGBColor[
             0.9941452261456818, 0.991846914797484, 0.746692284642483]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.027885652381746694`], {
             RGBColor[
             0.9874855177205791, 0.9890929542170042, 0.8570608880193642]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.027885652381746694`], {
             RGBColor[
             0.9484890984771832, 0.9611038345024191, 0.9720786994700665]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.027885652381746694`], {
             RGBColor[
             0.8701940172696059, 0.503463174026343, 0.21339904498501552`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.027885652381746694`], {
             RGBColor[
             0.9378197378197562, 0.7911830113390506, 0.2688265053726769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.027885652381746694`], {
             RGBColor[
             0.8924739228318184, 0.6046310215802007, 0.2319899443165854]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.027885652381746694`], {
             RGBColor[
             0.966716456358007, 0.8993889333271818, 0.3252001473310194]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.027885652381746694`], {
             RGBColor[
             0.9690409130268088, 0.9764313441430221, 0.9372898382092542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.027885652381746694`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.027885652381746694`], {
             RGBColor[
             0.9936336864774936, 0.98879142404542, 0.5484442452870933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.027885652381746694`], {
             RGBColor[
             0.989596771698022, 0.9899660119934292, 0.8220719458629877]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.027885652381746694`], {
             RGBColor[
             0.9807633312487328, 0.9467723406966698, 0.3797696037517481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.027885652381746694`], {
             RGBColor[
             0.9931330468631173, 0.9877206065326987, 0.493952712851795]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.027885652381746694`], {
             RGBColor[
             0.9896265705012657, 0.9766701278830049, 0.4142016145655488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.027885652381746694`], {
             RGBColor[
             0.9578701121690432, 0.8695481371574144, 0.290833770648819]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.027885652381746694`], {
             RGBColor[
             0.9225395411812516, 0.7306021234910623, 0.25653170048502283`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.027885652381746694`], {
             RGBColor[
             0.9570970061584904, 0.8669402690498962, 0.28783039978664116`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.027885652381746694`], {
             RGBColor[
             0.9576459157423434, 0.8687918699663315, 0.2899628098670328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.027885652381746694`], {
             RGBColor[
             0.99027748993745, 0.9788658319844064, 0.41673031365930374`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.027885652381746694`], {
             RGBColor[
             0.9931485524381405, 0.9877537713898191, 0.4956403990037523]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.027885652381746694`], {
             RGBColor[
             0.9394213339953567, 0.7975328064750189, 0.27011518724985906`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.027885652381746694`], {
             RGBColor[
             0.993384963320193, 0.9915325265812809, 0.7592918071579563]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.027885652381746694`], {
             RGBColor[
             0.9949655935960154, 0.9916402386954717, 0.693414115560258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.027885652381746694`], {
             RGBColor[
             0.9435549006332662, 0.813921020764903, 0.2734411519940004]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.027885652381746694`], {
             RGBColor[
             0.9931848582625453, 0.987831425877139, 0.49959206393663713`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.027885652381746694`], {
             RGBColor[
             0.9899749835674125, 0.9778454069663968, 0.4155551335352429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.027885652381746694`], {
             RGBColor[
             0.9510125857418301, 0.8434882570941169, 0.2794417804867192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.027885652381746694`], {
             RGBColor[
             0.9949924590420253, 0.9916977011679735, 0.6963382535641172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.027885652381746694`], {
             RGBColor[
             0.9401741500851994, 0.8005174714101548, 0.2707209207466113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.027885652381746694`], {
             RGBColor[
             0.9066347772393449, 0.6675450344098013, 0.24373435408457267`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.027885652381746694`], {
             RGBColor[
             0.994935463488382, 0.9921736982468639, 0.7335960068052537]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.027885652381746694`], {
             RGBColor[
             0.9067377022638166, 0.6679530978340997, 0.24381716997522332`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.027885652381746694`], {
             RGBColor[
             0.9663527412855056, 0.8981620369832746, 0.32378718295617975`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.027885652381746694`], {
             RGBColor[
             0.8763145438203102, 0.531255055607797, 0.21850616236675743`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.027885652381746694`], {
             RGBColor[
             0.9640326509840702, 0.8903358276134243, 0.3147740702473932]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.027885652381746694`], {
             RGBColor[
             0.8679372599550944, 0.49321576614020846`, 0.2115159513636034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.027885652381746694`], {
             RGBColor[
             0.9526869567380308, 0.8501265801429937, 0.2807890186928009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.027885652381746694`], {
             RGBColor[
             0.994860540135762, 0.9921427155151131, 0.7348376806535898]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.027885652381746694`], {
             RGBColor[
             0.9099126304985891, 0.6805406303028567, 0.2463717917580653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.027885652381746694`], {
             RGBColor[
             0.9831892104019447, 0.9549554007039656, 0.3891936861731377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.027885652381746694`], {
             RGBColor[
             0.9054762696740812, 0.9274662152122727, 0.9908463290013639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.027885652381746694`], {
             RGBColor[
             0.909873570599868, 0.6803857708203673, 0.24634036324670067`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.027885652381746694`], {
             RGBColor[
             0.9202011624299989, 0.7213312309608718, 0.25465018605296114`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.027885652381746694`], {
             RGBColor[
             0.9575882141148031, 0.8685972288276519, 0.28973864994007703`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.027885652381746694`], {
             RGBColor[
             0.9895477515736818, 0.9899457409122547, 0.8228843361833207]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.027885652381746694`], {
             RGBColor[
             0.9338585175710149, 0.7754780930511884, 0.26563921457874995`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.027885652381746694`], {
             RGBColor[
             0.9714628286746129, 0.9153995616523106, 0.34363890750383047`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.027885652381746694`], {
             RGBColor[
             0.9284030973915636, 0.7538491699506715, 0.2612496554471936]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.027885652381746694`], {
             RGBColor[
             0.9767776578086529, 0.9333277283026528, 0.3642860150683108]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.027885652381746694`], {
             RGBColor[
             0.9667752809867842, 0.8995873626127271, 0.32542866990571984`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.027885652381746694`], {
             RGBColor[
             0.9391729861358183, 0.7965481899689677, 0.26991536073260103`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.027885652381746694`], {
             RGBColor[
             0.9931027153271655, 0.9876557304442863, 0.4906513123479792]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.027885652381746694`], {
             RGBColor[
             0.9937534330874055, 0.989047549935782, 0.5614779247855866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.027885652381746694`], {
             RGBColor[
             0.943271075193496, 0.9572122412811741, 0.9809114518109148]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.027885652381746694`], {
             RGBColor[
             0.9900756550919438, 0.9901640425835577, 0.8141356087152068]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.027885652381746694`], {
             RGBColor[
             0.9943857185857606, 0.9903999446828936, 0.6302982992677636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.027885652381746694`], {
             RGBColor[
             0.948456568064602, 0.8333544987463063, 0.2773851486661754]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.027885652381746694`], {
             RGBColor[
             0.9944396250712401, 0.9919686563189095, 0.7418133325659866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.027885652381746694`], {
             RGBColor[
             0.9849138452661528, 0.9607729990644623, 0.3958935669506197]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.027885652381746694`], {
             RGBColor[
             0.9669698094707766, 0.9002435528666934, 0.3261843763324084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.027885652381746694`], {
             RGBColor[
             0.8466430246503907, 0.3595243033324397, 0.19229871912196295`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.027885652381746694`], {
             RGBColor[
             0.9895563866224785, 0.9899493117268428, 0.8227412310779691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.027885652381746694`], {
             RGBColor[
             0.9924204937717814, 0.9911336936372759, 0.775275563542317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.027885652381746694`], {
             RGBColor[
             0.9925483425527931, 0.9864699831355892, 0.43031125704972817`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.027885652381746694`], {
             RGBColor[
             0.9940255623219996, 0.9896296068520926, 0.5910975125841837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.027885652381746694`], {
             RGBColor[
             0.9890177249921055, 0.9897265612997111, 0.831668248304862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.027885652381746694`], {
             RGBColor[
             0.9699234951484946, 0.9770895724442797, 0.9357958568915238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.027885652381746694`], {
             RGBColor[
             0.9270271983544173, 0.748394188759561, 0.26014257478540437`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.027885652381746694`], {
             RGBColor[
             0.9940059030429058, 0.989587557641969, 0.5889577213778356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.027885652381746694`], {
             RGBColor[
             0.9541755299481588, 0.8560282768835346, 0.2819867596389739]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.027885652381746694`], {
             RGBColor[
             0.9850899556792782, 0.9613670608406256, 0.39657772264995084`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.027885652381746694`], {
             RGBColor[
             0.9903223457135195, 0.979017141049726, 0.41690456987903135`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.027885652381746694`], {
             RGBColor[
             0.9887123582739241, 0.9896002843141763, 0.836728965088863]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.027885652381746694`], {
             RGBColor[
             0.9864383849497574, 0.9886599379061847, 0.8744145879246238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.027885652381746694`], {
             RGBColor[
             0.9010767461658268, 0.6436944330994954, 0.23916835098097827`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.027885652381746694`], {
             RGBColor[
             0.9457665322968127, 0.822689403328302, 0.27522068274415723`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.027885652381746694`], {
             RGBColor[
             0.9940255623219996, 0.9896296068520926, 0.5910975125841837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.027885652381746694`], {
             RGBColor[
             0.984767046657942, 0.987968796571084, 0.9021129887048533]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.027885652381746694`], {
             RGBColor[
             0.993580436839354, 0.9916133599048943, 0.7560523050762049]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.027885652381746694`], {
             RGBColor[
             0.9918147441064756, 0.9908832005836156, 0.7853144031263165]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.027885652381746694`], {
             RGBColor[
             0.9912844899816792, 0.9906639268761028, 0.7941020862278796]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.027885652381746694`], {
             RGBColor[
             0.9284688973502735, 0.7541100448604201, 0.26130259963849517`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.027885652381746694`], {
             RGBColor[
             0.9532110877532944, 0.8522045849622067, 0.2812107468106181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.027885652381746694`], {
             RGBColor[
             0.9773900096984701, 0.9826580867703559, 0.9231569953372936]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.027885652381746694`], {
             RGBColor[
             0.9339937684181705, 0.7760143175904873, 0.26574804058511675`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.027885652381746694`], {
             RGBColor[
             0.9865284818006566, 0.9886971952694149, 0.8729214499420491]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.027885652381746694`], {
             RGBColor[
             0.8238871912537549, 0.18461299617611987`, 0.1705077073623067]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.027885652381746694`], {
             RGBColor[
             0.9850019263632055, 0.9610701172872462, 0.3962357453799501]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.027885652381746694`], {
             RGBColor[
             0.894232742412844, 0.6126174105148885, 0.23345754648760622`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.027885652381746694`], {
             RGBColor[
             0.9568513651267695, 0.8661116641706443, 0.2868761307638218]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.027885652381746694`], {
             RGBColor[
             0.9941018074127449, 0.9897926873916357, 0.5993963201816603]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.027885652381746694`], {
             RGBColor[
             0.9633134042393702, 0.8879096394563845, 0.31197993246258443`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.027885652381746694`], {
             RGBColor[
             0.9229490362446094, 0.7322256349611356, 0.2568611898250851]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.027885652381746694`], {
             RGBColor[
             0.9913012211470723, 0.9906708456429643, 0.7938248075184469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.027885652381746694`], {
             RGBColor[
             0.932895171725926, 0.7716587477913837, 0.26486408389915816`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.027885652381746694`], {
             RGBColor[
             0.9550908107419535, 0.8596570602316863, 0.28272321605006256`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.027885652381746694`], {
             RGBColor[
             0.9744153679797312, 0.9253591700176711, 0.3551089651639522]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.027885652381746694`], {
             RGBColor[
             0.9206094200431368, 0.7229498363531787, 0.25497867971152965`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.027885652381746694`], {
             RGBColor[
             0.9940001799396786, 0.9917869344637842, 0.749096075643505]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.027885652381746694`], {
             RGBColor[
             0.9886224327967975, 0.9895630978184052, 0.8382192629645249]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.027885652381746694`], {
             RGBColor[
             0.8839951870777567, 0.5661310627800534, 0.22491507937056499`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.027885652381746694`], {
             RGBColor[
             0.9861110662937885, 0.9885245832302357, 0.8798391051275567]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.027885652381746694`], {
             RGBColor[
             0.9948638904183653, 0.9914227058822467, 0.6823443523123021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.027885652381746694`], {
             RGBColor[
             0.9943003777258855, 0.9902174092129051, 0.6210094733330922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.027885652381746694`], {
             RGBColor[
             0.9417201673068003, 0.8066469145141032, 0.2719648824927996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.027885652381746694`], {
             RGBColor[
             0.925930304992864, 0.7440453720990471, 0.25925998863930233`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.027885652381746694`], {
             RGBColor[
             0.9864772464214273, 0.9886760081234145, 0.873770552768788]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.027885652381746694`], {
             RGBColor[
             0.9864963973256503, 0.9661113187620417, 0.40204148286188784`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.027885652381746694`], {
             RGBColor[
             0.9648821360559318, 0.8932013402293932, 0.31807415933978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.027885652381746694`], {
             RGBColor[
             0.9938439305013509, 0.9917223213056082, 0.7516855331971795]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.027885652381746694`], {
             RGBColor[
             0.9458742958792501, 0.823116650022581, 0.2753073918521227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.027885652381746694`], {
             RGBColor[
             0.907117945467462, 0.6694606354280181, 0.24412312258233168`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.027885652381746694`], {
             RGBColor[
             0.9935726544942343, 0.9886608828045083, 0.5418012905550547]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.027885652381746694`], {
             RGBColor[
             0.9539733798603952, 0.965194002578332, 0.9627952416179572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.027885652381746694`], {
             RGBColor[
             0.9846384929472911, 0.9598441710371431, 0.39482387518776474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.027885652381746694`], {
             RGBColor[
             0.9852096727981905, 0.9617708947936332, 0.39704280105024436`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.027885652381746694`], {
             RGBColor[
             0.9937256152143722, 0.9889880503181822, 0.5584501209779228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.027885652381746694`], {
             RGBColor[
             0.9222550231398634, 0.729474104266975, 0.2563027705904251]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.027885652381746694`], {
             RGBColor[
             0.9883849792677092, 0.972481949112734, 0.4093782670780128]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.027885652381746694`], {
             RGBColor[
             0.9167606405333548, 0.9364640662293703, 0.9919226423675983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.027885652381746694`], {
             RGBColor[
             0.9844118525371842, 0.9878219146740782, 0.9079994744987289]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.027885652381746694`], {
             RGBColor[
             0.9928525510992996, 0.9871206544563644, 0.4634224799794291]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.027885652381746694`], {
             RGBColor[
             0.9899055535223517, 0.9776112031214564, 0.4152854109209451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.027885652381746694`], {
             RGBColor[
             0.9493544755987811, 0.836914402909378, 0.2781076261447746]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.027885652381746694`], {
             RGBColor[
             0.9808511812003655, 0.9852394228093213, 0.917298134802689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.027885652381746694`], {
             RGBColor[
             0.9614477300094958, 0.8816162821978771, 0.30473214038253793`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.027885652381746694`], {
             RGBColor[
             0.9835122634016722, 0.9872240535579337, 0.9127936167572707]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.027885652381746694`], {
             RGBColor[
             0.9928614233130961, 0.9871396312245568, 0.4643881656982277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.027885652381746694`], {
             RGBColor[
             0.8278596758489554, 0.21514725352868025`, 0.17431176309695032`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.027885652381746694`], {
             RGBColor[
             0.993160193487062, 0.9877786704163714, 0.496907455338619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.027885652381746694`], {
             RGBColor[
             0.9292910069084126, 0.7573694353066717, 0.2619640882863654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.027885652381746694`], {
             RGBColor[
             0.9931485524381405, 0.9877537713898191, 0.4956403990037523]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.027885652381746694`], {
             RGBColor[
             0.9928614233130961, 0.9871396312245568, 0.4643881656982277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.027885652381746694`], {
             RGBColor[
             0.9135268988099774, 0.6948699997739933, 0.24927991687918932`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.027885652381746694`], {
             RGBColor[
             0.9938338355482835, 0.9892195226696645, 0.5702292364656956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.027885652381746694`], {
             RGBColor[
             0.956724987301784, 0.8656853620920442, 0.28638517677820313`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.027885652381746694`], {
             RGBColor[
             0.9692731939311068, 0.9080134095117778, 0.3351325900031346]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.027885652381746694`], {
             RGBColor[
             0.9943003777258855, 0.9902174092129051, 0.6210094733330922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.027885652381746694`], {
             RGBColor[
             0.980789593185631, 0.9468609283764231, 0.3798716264174466]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.027885652381746694`], {
             RGBColor[
             0.9911415873795292, 0.9906048329776844, 0.7964703521655848]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.027885652381746694`], {
             RGBColor[
             0.970400120687602, 0.9118147980764215, 0.33951048764985725`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.027885652381746694`], {
             RGBColor[
             0.960202705352868, 0.8774165216853806, 0.2998954546947173]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.027885652381746694`], {
             RGBColor[
             0.9443782086271579, 0.8171851626095586, 0.2741036049314081]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.027885652381746694`], {
             RGBColor[
             0.972404099255543, 0.9789396029257, 0.9315968411834592]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.027885652381746694`], {
             RGBColor[
             0.9734145681412016, 0.9219832371633341, 0.35122104677645616`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.027885652381746694`], {
             RGBColor[
             0.9612916979482846, 0.8810899494173418, 0.3041259852889149]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.027885652381746694`], {
             RGBColor[
             0.9849450375868088, 0.9880424003943288, 0.899163218387773]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.027885652381746694`], {
             RGBColor[
             0.89371542714214, 0.6102684026926729, 0.2330258859451732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.027885652381746694`], {
             RGBColor[
             0.9889041464206729, 0.9896795936415876, 0.8335505391654204]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.027885652381746694`], {
             RGBColor[
             0.9922957162365946, 0.9910820949198398, 0.7773434502142712]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.027885652381746694`], {
             RGBColor[
             0.9249399938045669, 0.7401191182390899, 0.25846316101160727`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.027885652381746694`], {
             RGBColor[
             0.9742036232599293, 0.9246449053577548, 0.3542863769121569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.027885652381746694`], {
             RGBColor[
             0.9931817277010505, 0.98782472992265, 0.49925132163751573`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.027885652381746694`], {
             RGBColor[
             0.9335586693920103, 0.7742892949399174, 0.26539794969558145`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.027885652381746694`], {
             RGBColor[
             0.9283251459616978, 0.753540118507028, 0.26118693389696834`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.027885652381746694`], {
             RGBColor[
             0.9086190208900733, 0.6754118992749394, 0.24533092310213334`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.027885652381746694`], {
             RGBColor[
             0.9416509418712788, 0.8063724587302696, 0.27190918208244924`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.027885652381746694`], {
             RGBColor[
             0.9708371104148606, 0.9132888670365323, 0.3412081102216716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.027885652381746694`], {
             RGBColor[
             0.9940839682322794, 0.9897545311884378, 0.5974546354786513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.027885652381746694`], {
             RGBColor[
             0.9943867648224486, 0.9904021824773783, 0.6304121756746243]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.027885652381746694`], {
             RGBColor[
             0.9392193207214607, 0.9541904494300693, 0.9877700152652583]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.027885652381746694`], {
             RGBColor[
             0.994422540856595, 0.9919615915571095, 0.7420964622151853]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.027885652381746694`], {
             RGBColor[
             0.8906458765109295, 0.5963302901881098, 0.23046457765692002`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.027885652381746694`], {
             RGBColor[
             0.9942160610031289, 0.990037064268657, 0.6118321184035248]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.027885652381746694`], {
             RGBColor[
             0.99512919314985, 0.9922538104405061, 0.7303854049584358]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.027885652381746694`], {
             RGBColor[
             0.9894672572677288, 0.9899124544481338, 0.8242183351455482]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.027885652381746694`], {
             RGBColor[
             0.9947284465135329, 0.9911330050652895, 0.6676021191341787]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.027885652381746694`], {
             RGBColor[
             0.9868917985584619, 0.9888474360855822, 0.8669003510315854]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.027885652381746694`], {
             RGBColor[
             0.9290593476146701, 0.756450983402866, 0.2617776897808777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.027885652381746694`], {
             RGBColor[
             0.9312058541893268, 0.7649611666904661, 0.2635048193558315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.027885652381746694`], {
             RGBColor[
             0.988281616097769, 0.9894221613547672, 0.8438674776727715]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.027885652381746694`], {
             RGBColor[
             0.9651549679467312, 0.8941216662610341, 0.3191340597155563]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.027885652381746694`], {
             RGBColor[
             0.9776746929964727, 0.9363536386250473, 0.3677708273821097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.027885652381746694`], {
             RGBColor[
             0.9940839682322794, 0.9897545311884378, 0.5974546354786513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.027885652381746694`], {
             RGBColor[
             0.9875117642082811, 0.9695363896766369, 0.4059859914649619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.027885652381746694`], {
             RGBColor[
             0.9927875271806748, 0.9869815748693527, 0.4563450277182303]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.027885652381746694`], {
             RGBColor[
             0.9844118525371842, 0.9878219146740782, 0.9079994744987289]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.027885652381746694`], {
             RGBColor[
             0.9784306095583493, 0.9834341644420279, 0.9213955312064286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.027885652381746694`], {
             RGBColor[
             0.8949565577345058, 0.615904086839191, 0.23406151573433784`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.027885652381746694`], {
             RGBColor[
             0.9555252485550205, 0.8613794613926781, 0.2830727749120225]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.027885652381746694`], {
             RGBColor[
             0.9934522063894176, 0.9884032564874767, 0.5286912576652896]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.027885652381746694`], {
             RGBColor[
             0.9903614553598412, 0.9902822283390651, 0.8093991586487619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.027885652381746694`], {
             RGBColor[
             0.9886021799661516, 0.9895547227524591, 0.8385549047809733]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.027885652381746694`], {
             RGBColor[
             0.9922957162365946, 0.9910820949198398, 0.7773434502142712]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.027885652381746694`], {
             RGBColor[
             0.9931041348804618, 0.9876587667252482, 0.49080582196380934`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.027885652381746694`], {
             RGBColor[
             0.9685752769396483, 0.9056591716208857, 0.3324213142818831]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.027885652381746694`], {
             RGBColor[
             0.9461433142661124, 0.8241832182814273, 0.27552385036086535`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.027885652381746694`], {
             RGBColor[
             0.9936464056546755, 0.988818629079306, 0.5498286492296816]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.027885652381746694`], {
             RGBColor[
             0.9787477923827633, 0.9399734548307236, 0.3719396158600337]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.027885652381746694`], {
             RGBColor[
             0.9776746929964727, 0.9363536386250473, 0.3677708273821097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.027885652381746694`], {
             RGBColor[
             0.993885864752237, 0.9917396621960107, 0.750990574137635]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.027885652381746694`], {
             RGBColor[
             0.9937319397946325, 0.9890015779558459, 0.5591385125084778]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.027885652381746694`], {
             RGBColor[
             0.9937667469603273, 0.9890760269637227, 0.5629270576894223]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.027885652381746694`], {
             RGBColor[
             0.9161161956240006, 0.7051356988095813, 0.2513633258743601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.027885652381746694`], {
             RGBColor[
             0.9669455138775074, 0.9748685988883743, 0.9408368024013967]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.027885652381746694`], {
             RGBColor[
             0.879316763850862, 0.5448874355802301, 0.22101128835139688`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.027885652381746694`], {
             RGBColor[
             0.9669014899037782, 0.9000130949250108, 0.32591896771568746`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.027885652381746694`], {
             RGBColor[
             0.9027000675187172, 0.6510655562266365, 0.2405228901090776]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.027885652381746694`], {
             RGBColor[
             0.9054762696740812, 0.9274662152122727, 0.9908463290013639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.027885652381746694`], {
             RGBColor[
             0.9884518972221094, 0.9727076790860085, 0.4096382306944619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.027885652381746694`], {
             RGBColor[
             0.9550908107419535, 0.8596570602316863, 0.28272321605006256`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.027885652381746694`], {
             RGBColor[
             0.9864559258825258, 0.9886671915326658, 0.8741238892741714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.027885652381746694`], {
             RGBColor[
             0.9595863431469842, 0.8753373872362061, 0.2975010039150944]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.027885652381746694`], {
             RGBColor[
             0.9565363964488177, 0.8650492008617506, 0.28565253692682313`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.027885652381746694`], {
             RGBColor[
             0.9781900501784915, 0.9380920594116176, 0.3697728927172153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.027885652381746694`], {
             RGBColor[
             0.9513897768931359, 0.8449836943175442, 0.27974527734087407`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.027885652381746694`], {
             RGBColor[
             0.9539283319730409, 0.8550482192860344, 0.28178785834571185`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.027885652381746694`], {
             RGBColor[
             0.8199280051208216, 0.15418095663196868`, 0.1667163862501486]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.027885652381746694`], {
             RGBColor[
             0.8870768642218594, 0.5801242389474407, 0.22748650631842338`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.027885652381746694`], {
             RGBColor[
             0.988339532166081, 0.9723286453674548, 0.4092017136701518]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.027885652381746694`], {
             RGBColor[
             0.9860964782168707, 0.9885185506855337, 0.8800808673148168]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.027885652381746694`], {
             RGBColor[
             0.9934687670217693, 0.9915671815655396, 0.7579029629458083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.027885652381746694`], {
             RGBColor[
             0.9935056186076746, 0.988517499821525, 0.5345048480005752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.027885652381746694`], {
             RGBColor[
             0.9938070386875015, 0.9891622068940299, 0.5673125635406253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.027885652381746694`], {
             RGBColor[
             0.9847296687663539, 0.9601517284839423, 0.3951780760277149]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.027885652381746694`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.027885652381746694`], {
             RGBColor[
             0.9690621722793642, 0.9764471992587691, 0.937253851839979]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.027885652381746694`], {
             RGBColor[
             0.983239436327212, 0.9870205795725147, 0.9132554418296347]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.027885652381746694`], {
             RGBColor[
             0.9245683587287924, 0.7386457090036913, 0.2581641347062426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.027885652381746694`], {
             RGBColor[
             0.9940283135188367, 0.9896354913839387, 0.5913969633814953]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.027885652381746694`], {
             RGBColor[
             0.9819468461681556, 0.9507646144224008, 0.38436733572566656`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.027885652381746694`], {
             RGBColor[
             0.9333706462723271, 0.7735438459253645, 0.2652466618800146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.027885652381746694`], {
             RGBColor[
             0.9196015657086798, 0.7189540297646041, 0.25416773645664376`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.027885652381746694`], {
             RGBColor[
             0.9810818404157703, 0.9478467469065958, 0.38100695172027915`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.027885652381746694`], {
             RGBColor[
             0.9122195179761786, 0.6896866704268181, 0.24822796757214252`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.027885652381746694`], {
             RGBColor[
             0.9921633480931824, 0.9852272743642441, 0.4240565164798942]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.027885652381746694`], {
             RGBColor[
             0.907117945467462, 0.6694606354280181, 0.24412312258233168`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.027885652381746694`], {
             RGBColor[
             0.8632082637375081, 0.4717424988012767, 0.20756996100134484`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.027885652381746694`], {
             RGBColor[
             0.9623751602607842, 0.8847447222064515, 0.30833503177828614`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.027885652381746694`], {
             RGBColor[
             0.9870186827316091, 0.9678731100747856, 0.4040704630387146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.027885652381746694`], {
             RGBColor[
             0.984025118616199, 0.9577751153912276, 0.39244103173749484`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.027885652381746694`], {
             RGBColor[
             0.9933373214385368, 0.9881575291941931, 0.5161867397496527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.027885652381746694`], {
             RGBColor[
             0.9912270303503083, 0.9906401658418859, 0.7950543410204526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.027885652381746694`], {
             RGBColor[
             0.9685682709553705, 0.9056355387908335, 0.33239409735593306`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.027885652381746694`], {
             RGBColor[
             0.99347587761786, 0.9915701219797571, 0.7577851219669525]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.027885652381746694`], {
             RGBColor[
             0.9931785060515781, 0.9878178391401871, 0.49890066497415186`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.027885652381746694`], {
             RGBColor[
             0.9442327762343037, 0.8166085716343637, 0.2739865866143806]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.027885652381746694`], {
             RGBColor[
             0.9648246977631318, 0.8930075873806268, 0.3178510224185639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.027885652381746694`], {
             RGBColor[
             0.9949655935960154, 0.9916402386954717, 0.693414115560258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.027885652381746694`], {
             RGBColor[
             0.9833855936885301, 0.987129583493275, 0.9130080355408682]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.027885652381746694`], {
             RGBColor[
             0.9841893987801753, 0.9877290600145139, 0.9116474031866564]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.027885652381746694`], {
             RGBColor[
             0.9868917985584619, 0.9888474360855822, 0.8669003510315854]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.027885652381746694`], {
             RGBColor[
             0.9840512231161735, 0.9578631719992697, 0.39254244279047473`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.027885652381746694`], {
             RGBColor[
             0.9570442511930353, 0.8667623141639613, 0.2876254567077875]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.027885652381746694`], {
             RGBColor[
             0.9935499109577005, 0.9886122366795869, 0.5393257969601946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.027885652381746694`], {
             RGBColor[
             0.8918698667052568, 0.6018881437903774, 0.23148590507781186`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.027885652381746694`], {
             RGBColor[
             0.9615511646994936, 0.8819651916948602, 0.30513396462117753`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.027885652381746694`], {
             RGBColor[
             0.9938469521547219, 0.9892475777645435, 0.5716568981301857]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.027885652381746694`], {
             RGBColor[
             0.9402460298745945, 0.8008024508225862, 0.27077875691239406`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.027885652381746694`], {
             RGBColor[
             0.9623751602607842, 0.8847447222064515, 0.30833503177828614`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.027885652381746694`], {
             RGBColor[
             0.9881402942578402, 0.9716565691196734, 0.4084277120195585]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.027885652381746694`], {
             RGBColor[
             0.9854344316644049, 0.9882447774222688, 0.8910526920107315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.027885652381746694`], {
             RGBColor[
             0.9923393971069084, 0.9911001580822617, 0.776619545150703]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.027885652381746694`], {
             RGBColor[
             0.9425703370405857, 0.8100175542062927, 0.2726489490166518]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.027885652381746694`], {
             RGBColor[
             0.9932931794453224, 0.9914945715902839, 0.7608129034936153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.027885652381746694`], {
             RGBColor[
             0.9910739975726719, 0.9815526392668963, 0.419824595414295]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.027885652381746694`], {
             RGBColor[
             0.926363187059497, 0.7457616052438493, 0.25960829571116323`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.027885652381746694`], {
             RGBColor[
             0.9525570617369237, 0.8496115897485471, 0.28068450212588253`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.027885652381746694`], {
             RGBColor[
             0.9932189000693992, 0.9914638551594468, 0.7620439049815265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.027885652381746694`], {
             RGBColor[
             0.9847937612809049, 0.9879798437542138, 0.9016702582671311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.027885652381746694`], {
             RGBColor[
             0.947406403237283, 0.8291909451526701, 0.27654016139557785`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.027885652381746694`], {
             RGBColor[
             0.9937170045342629, 0.9889696329441018, 0.5575129015869917]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.027885652381746694`], {
             RGBColor[
             0.9931124575804956, 0.9876765681390666, 0.4917116965007463]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.027885652381746694`], {
             RGBColor[
             0.9938028871379454, 0.9891533271493154, 0.5668606929918337]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.027885652381746694`], {
             RGBColor[
             0.9944396250712401, 0.9919686563189095, 0.7418133325659866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.027885652381746694`], {
             RGBColor[
             0.9273917224384753, 0.7498394052824012, 0.2604358794199175]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.027885652381746694`], {
             RGBColor[
             0.9804839506207847, 0.9458299242369099, 0.3786842627687744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.027885652381746694`], {
             RGBColor[
             0.9934219489617586, 0.9883385389092096, 0.5253979233918202]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.027885652381746694`], {
             RGBColor[
             0.9934512695010161, 0.9915599458910423, 0.7581929421468205]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.027885652381746694`], {
             RGBColor[
             0.9816046730360135, 0.985801375786618, 0.9160226696670817]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.027885652381746694`], {
             RGBColor[
             0.8813991488644815, 0.5543430595736996, 0.2227488814506885]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.027885652381746694`], {
             RGBColor[
             0.9930977800485056, 0.9876451743822661, 0.4901141377228594]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.027885652381746694`], {
             RGBColor[
             0.9928078624182739, 0.9912938805275207, 0.7688558625920137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.027885652381746694`], {
             RGBColor[
             0.9941170830076203, 0.9898253603444747, 0.6010589744138023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.027885652381746694`], {
             RGBColor[
             0.9949858017629541, 0.9916834619211945, 0.6956136498211859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.027885652381746694`], {
             RGBColor[
             0.9937936244568298, 0.9891335152110099, 0.5658525073150449]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.027885652381746694`], {
             RGBColor[
             0.983815720367594, 0.987450371266253, 0.9122799432682176]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.027885652381746694`], {
             RGBColor[
             0.9844118525371842, 0.9878219146740782, 0.9079994744987289]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.027885652381746694`], {
             RGBColor[
             0.9886021799661516, 0.9895547227524591, 0.8385549047809733]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.027885652381746694`], {
             RGBColor[
             0.9146079244251806, 0.6991559061078425, 0.25014973546411434`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.027885652381746694`], {
             RGBColor[
             0.9238533264547089, 0.7358108443073308, 0.25758880295455044`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.027885652381746694`], {
             RGBColor[
             0.8720708917820681, 0.5119856228322546, 0.2149651550846182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.027885652381746694`], {
             RGBColor[
             0.9835983553143273, 0.9563355425652258, 0.3907831368972104]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.027885652381746694`], {
             RGBColor[
             0.9469707295017713, 0.9599714374066579, 0.9746489020913862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.027885652381746694`], {
             RGBColor[
             0.9525008360116671, 0.849388673484017, 0.28063926158755365`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.027885652381746694`], {
             RGBColor[
             0.9939669205920554, 0.9917731808688157, 0.7496472691060541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.027885652381746694`], {
             RGBColor[
             0.9931622390703552, 0.9877830457121956, 0.4971301044562165]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.027885652381746694`], {
             RGBColor[
             0.9933187768098789, 0.9881178641086436, 0.514168271364426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.027885652381746694`], {
             RGBColor[
             0.9555182308141505, 0.861351638388652, 0.2830671282729909]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.027885652381746694`], {
             RGBColor[
             0.9652842692283118, 0.8945578298451903, 0.31963637077799906`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.027885652381746694`], {
             RGBColor[
             0.9905628335335792, 0.9903655033890888, 0.8060618011599171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.027885652381746694`], {
             RGBColor[
             0.9849450375868088, 0.9880424003943288, 0.899163218387773]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.027885652381746694`], {
             RGBColor[
             0.9864383849497574, 0.9886599379061847, 0.8744145879246238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.027885652381746694`], {
             RGBColor[
             0.9778956465559708, 0.9370989668635975, 0.3686291902371816]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.027885652381746694`], {
             RGBColor[
             0.9746452598576468, 0.9806110568331854, 0.9278031408723981]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.027885652381746694`], {
             RGBColor[
             0.967524558476264, 0.9021148515234628, 0.32833947146316733`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.027885652381746694`], {
             RGBColor[
             0.951594370336186, 0.8457948391425145, 0.27990989802757754`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.027885652381746694`], {
             RGBColor[
             0.9938700281533849, 0.9917331133554034, 0.751253027564418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.027885652381746694`], {
             RGBColor[
             0.9296814464644771, 0.7589173980401981, 0.26227824511796916`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.027885652381746694`], {
             RGBColor[
             0.993920127365594, 0.9894040921414504, 0.5796215682485658]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.027885652381746694`], {
             RGBColor[
             0.9944396250712401, 0.9919686563189095, 0.7418133325659866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.027885652381746694`], {
             RGBColor[
             0.968248538327941, 0.9045570055617229, 0.33115199647481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.027885652381746694`], {
             RGBColor[
             0.950649774968196, 0.8420498332761809, 0.2791498544219898]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.027885652381746694`], {
             RGBColor[
             0.9878791050916815, 0.9707755167320877, 0.4074130414304675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.027885652381746694`], {
             RGBColor[
             0.9637897281665183, 0.9725150190722435, 0.9461787244493673]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.027885652381746694`], {
             RGBColor[
             0.993280014837457, 0.9880349561690697, 0.5099492698774664]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.027885652381746694`], {
             RGBColor[
             0.9286244377577375, 0.7547267107452466, 0.26142775110134325`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.027885652381746694`], {
             RGBColor[
             0.9743428688787774, 0.9251146135265559, 0.35482731984705357`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.027885652381746694`], {
             RGBColor[
             0.990003062460449, 0.9779401236658464, 0.41566421473243564`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.027885652381746694`], {
             RGBColor[
             0.9492073827864019, 0.8363312289240687, 0.27798927181522226`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.027885652381746694`], {
             RGBColor[
             0.9905294486115939, 0.9903516978658945, 0.8066150757146227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.027885652381746694`], {
             RGBColor[
             0.9539733798603952, 0.965194002578332, 0.9627952416179572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.027885652381746694`], {
             RGBColor[
             0.9573227218131203, 0.8677016609535187, 0.2887072624820535]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.027885652381746694`], {
             RGBColor[
             0.8657505981335784, 0.48328664551654765`, 0.2096913471397444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.027885652381746694`], {
             RGBColor[
             0.9824516003837755, 0.9524672689136127, 0.3863282105385145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.027885652381746694`], {
             RGBColor[
             0.9940175994906989, 0.9896125751611062, 0.5902308075380075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.027885652381746694`], {
             RGBColor[
             0.9909548481296341, 0.990527611498873, 0.7995651048020327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.027885652381746694`], {
             RGBColor[
             0.9034142787353179, 0.6543086225529526, 0.24111884545512813`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.027885652381746694`], {
             RGBColor[
             0.9951822005772709, 0.9921035391260519, 0.7169904487265797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.027885652381746694`], {
             RGBColor[
             0.9082368631475619, 0.9296674375137125, 0.9911096368712754]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.027885652381746694`], {
             RGBColor[
             0.9815082294641289, 0.9857294483286183, 0.9161859234777703]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.027885652381746694`], {
             RGBColor[
             0.9379953020981403, 0.7918790651995158, 0.268967768512088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.027885652381746694`], {
             RGBColor[
             0.9616975153579159, 0.8824588668304871, 0.3057025092931452]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.027885652381746694`], {
             RGBColor[
             0.9912256592929753, 0.9906395988744441, 0.7950770629886433]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.027885652381746694`], {
             RGBColor[
             0.873432034870463, 0.5181662556936102, 0.21610092624224497`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.027885652381746694`], {
             RGBColor[
             0.9447231817737879, 0.8185528661804597, 0.274381178422747]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.027885652381746694`], {
             RGBColor[
             0.9115249148838772, 0.6869328006286021, 0.24766907361964668`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.027885652381746694`], {
             RGBColor[
             0.9772218380771062, 0.9348260526466323, 0.36601157153484637`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.027885652381746694`], {
             RGBColor[
             0.9865002943324449, 0.9886855390269245, 0.8733885892371454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.027885652381746694`], {
             RGBColor[
             0.9844235887039112, 0.9591192485623066, 0.3939890127834945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.027885652381746694`], {
             RGBColor[
             0.9927170987273882, 0.9868309355291817, 0.44867932521202497`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.027885652381746694`], {
             RGBColor[
             0.9122195179761786, 0.6896866704268181, 0.24822796757214252`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.027885652381746694`], {
             RGBColor[
             0.993148162071657, 0.9877529364353829, 0.49559791002107934`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.027885652381746694`], {
             RGBColor[
             0.9752345905790414, 0.9281226002077582, 0.35829149026506574`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.027885652381746694`], {
             RGBColor[
             0.8896995272977151, 0.5920331394363773, 0.229674920676272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.027885652381746694`], {
             RGBColor[
             0.9429739368195004, 0.8116176928380363, 0.2729736948724711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.027885652381746694`], {
             RGBColor[
             0.9167606405333548, 0.9364640662293703, 0.9919226423675983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.027885652381746694`], {
             RGBColor[
             0.9925594729794553, 0.9864937899927609, 0.4315227353028813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.027885652381746694`], {
             RGBColor[
             0.9494997368203938, 0.83749031524764, 0.2782245067334033]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.027885652381746694`], {
             RGBColor[
             0.9929974526499461, 0.9874305842214033, 0.4791941195385919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.027885652381746694`], {
             RGBColor[
             0.934377430657468, 0.77753541052144, 0.2660567442285658]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.027885652381746694`], {
             RGBColor[
             0.9861631882172575, 0.9649873261982134, 0.40074702839704185`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.027885652381746694`], {
             RGBColor[
             0.972980123542965, 0.9205177535210394, 0.3495333115502852]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.027885652381746694`], {
             RGBColor[
             0.9681686040433699, 0.9042873684504018, 0.33084146687357396`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.027885652381746694`], {
             RGBColor[
             0.9601474465369967, 0.8772301207240595, 0.29968078462980874`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.027885652381746694`], {
             RGBColor[
             0.9881266945824496, 0.9716106942212254, 0.4083748798487494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.027885652381746694`], {
             RGBColor[
             0.8977655710650225, 0.6286591603113362, 0.23640542531253847`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.027885652381746694`], {
             RGBColor[
             0.9325344523352648, 0.7702286156100235, 0.26457384061025985`]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN3AuYzmXewPH7z7a1WxZbu0o1DqFsy5TT0CKyGGKYrMNM4zSN46CIkAnD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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[37, 104] -> 
             RGBColor[
              0.2541903466574486, 0.3845005493087726, 0.9377871362499982], 
             UndirectedEdge[119, 243] -> 
             RGBColor[
              0.23559188807996673`, 0.3649523901334573, 0.9367279815479644], 
             UndirectedEdge[165, 226] -> 
             RGBColor[
              0.20872258864357046`, 0.33671105281382463`, 0.935197814694628], 
             UndirectedEdge[235, 261] -> 
             RGBColor[
              0.19122633777104836`, 0.31832138382042696`, 0.9342014290908216],
              UndirectedEdge[56, 198] -> 
             RGBColor[
              0.6735978276393025, 0.7431113232752183, 0.969380994432274], 
             UndirectedEdge[50, 254] -> 
             RGBColor[
              0.20910270252497706`, 0.33711057660379506`, 0.9352194616178461],
              UndirectedEdge[249, 268] -> 
             RGBColor[
              0.18564105657677243`, 0.3124508991579618, 0.9338833555894905], 
             UndirectedEdge[38, 224] -> 
             RGBColor[
              0.37823665311305865`, 0.49620023139778335`, 0.9458245390097163],
              UndirectedEdge[79, 87] -> 
             RGBColor[
              0.19294989757058154`, 0.3201329544497393, 0.9342995832716268], 
             UndirectedEdge[38, 311] -> 
             RGBColor[
              0.23066096804752526`, 0.35976968054097413`, 0.9364471729467594],
              UndirectedEdge[37, 145] -> 
             RGBColor[
              0.2671022972631469, 0.3980718280603137, 0.9385224527354736], 
             UndirectedEdge[147, 359] -> 
             RGBColor[
              0.28645237167494564`, 0.4168434263248926, 0.9396817701660576], 
             UndirectedEdge[192, 349] -> 
             RGBColor[
              0.22834058438598487`, 0.3573308101918738, 0.9363150305299347], 
             UndirectedEdge[213, 308] -> 
             RGBColor[
              0.2691305631056292, 0.398662652595457, 0.9386943834532097], 
             UndirectedEdge[262, 397] -> 
             RGBColor[
              0.364256395049981, 0.48992231415871446`, 0.9444310732866698], 
             UndirectedEdge[129, 364] -> 
             RGBColor[
              0.8703372527037241, 0.4377357825676223, 0.21085741257426427`], 
             UndirectedEdge[54, 83] -> 
             RGBColor[
              0.9496193654049732, 0.8977579075232218, 0.6225379522867944], 
             UndirectedEdge[13, 277] -> 
             RGBColor[
              0.19923872667069553`, 0.3267429125687539, 0.9346577227853893], 
             UndirectedEdge[191, 235] -> 
             RGBColor[
              0.18862912627732129`, 0.3155915498678, 0.9340535217384839], 
             UndirectedEdge[54, 214] -> 
             RGBColor[
              0.913587591361185, 0.6878213464055395, 0.24895168467498954`], 
             UndirectedEdge[87, 176] -> 
             RGBColor[
              0.18652655830038561`, 0.3133816176135313, 0.933933783602668], 
             UndirectedEdge[16, 377] -> 
             RGBColor[
              0.24182389785616784`, 0.37150262754048624`, 0.9370828852852868],
              UndirectedEdge[158, 344] -> 
             RGBColor[
              0.19135142545084088`, 0.31845285890290587`, 0.934208552649135], 
             UndirectedEdge[95, 228] -> 
             RGBColor[
              0.2356195787974104, 0.36498149483318354`, 0.9367295584933581], 
             UndirectedEdge[193, 283] -> 
             RGBColor[
              0.884925338733304, 0.8207038820590313, 0.6242425057097936], 
             UndirectedEdge[11, 366] -> 
             RGBColor[
              0.9332464444239088, 0.9449010522417576, 0.749948999978632], 
             UndirectedEdge[106, 231] -> 
             RGBColor[
              0.1888628748467801, 0.31583723443481654`, 0.9340668333737145], 
             UndirectedEdge[76, 388] -> 
             RGBColor[
              0.276858244918402, 0.40832594760879465`, 0.9390780395218092], 
             UndirectedEdge[208, 351] -> 
             RGBColor[
              0.301986411916915, 0.43466246314501933`, 0.9405117895645303], 
             UndirectedEdge[208, 225] -> 
             RGBColor[
              0.2514500268910438, 0.38162029948797277`, 0.9376310790932412], 
             UndirectedEdge[163, 374] -> 
             RGBColor[
              0.1813453905655848, 0.3079358818192477, 0.9336387237650219], 
             UndirectedEdge[165, 288] -> 
             RGBColor[
              0.2196372553710177, 0.3481830595742119, 0.9358193888179538], 
             UndirectedEdge[110, 239] -> 
             RGBColor[
              0.6800499902731076, 0.7481746185632971, 0.9700901941191247], 
             UndirectedEdge[14, 273] -> 
             RGBColor[
              0.4313475935937616, 0.5461129107315478, 0.9492366849727629], 
             UndirectedEdge[231, 372] -> 
             RGBColor[
              0.18557674124721385`, 0.3123832996687683, 0.9338796929266182], 
             UndirectedEdge[5, 162] -> 
             RGBColor[
              0.19105730741779076`, 0.3181437222020098, 0.9341918030622616], 
             UndirectedEdge[36, 90] -> 
             RGBColor[
              0.2306114538784999, 0.35971763800994894`, 0.9364443531880831], 
             UndirectedEdge[258, 328] -> 
             RGBColor[
              0.23450213577855084`, 0.36380699137038264`, 0.936665921766543], 
             UndirectedEdge[91, 208] -> 
             RGBColor[
              0.4434969579662055, 0.5534506067219376, 0.9505734674176423], 
             UndirectedEdge[155, 370] -> 
             RGBColor[
              0.18572317816153708`, 0.3125372141503586, 0.9338880322922549], 
             UndirectedEdge[66, 243] -> 
             RGBColor[
              0.21376058132167255`, 0.342006302545695, 0.9354847209246038], 
             UndirectedEdge[253, 334] -> 
             RGBColor[
              0.8927019922159016, 0.5360459310419723, 0.23584376702104354`], 
             UndirectedEdge[50, 210] -> 
             RGBColor[
              0.23840421569943582`, 0.3679083247733892, 0.9368881394454274], 
             UndirectedEdge[239, 365] -> 
             RGBColor[
              0.4065771465503478, 0.524864785093759, 0.9475407198960643], 
             UndirectedEdge[13, 51] -> 
             RGBColor[
              0.20728585719020337`, 0.33520095696230034`, 0.9351159949638125],
              UndirectedEdge[258, 300] -> 
             RGBColor[
              0.21690681128224154`, 0.345313189716754, 0.9356638940664279], 
             UndirectedEdge[30, 294] -> 
             RGBColor[
              0.2052159577699056, 0.3330253614323641, 0.9349981172539683], 
             UndirectedEdge[31, 292] -> 
             RGBColor[
              0.9018751366680733, 0.5692935983265383, 0.5384207617960579], 
             UndirectedEdge[203, 216] -> 
             RGBColor[
              0.26291297700315486`, 0.3935517624584167, 0.938288154657422], 
             UndirectedEdge[64, 233] -> 
             RGBColor[
              0.9814581324353071, 0.9819712119725741, 0.6847171998056071], 
             UndirectedEdge[50, 242] -> 
             RGBColor[
              0.2857631387189643, 0.41475906038865373`, 0.9396923133754758], 
             UndirectedEdge[133, 398] -> 
             RGBColor[
              0.18210607446438823`, 0.30873540882703493`, 0.9336820435877278],
              UndirectedEdge[7, 390] -> 
             RGBColor[
              0.23396569650741295`, 0.36324315968420245`, 0.9366353723436424],
              UndirectedEdge[186, 342] -> 
             RGBColor[
              0.19648760861210862`, 0.32385131305821946`, 0.9345010506818672],
              UndirectedEdge[347, 398] -> 
             RGBColor[
              0.182565782601332, 0.30921859122614215`, 0.9337082232860494], 
             UndirectedEdge[321, 375] -> 
             RGBColor[
              0.19367454863692518`, 0.3208946086659977, 0.9343408510778299], 
             UndirectedEdge[149, 279] -> 
             RGBColor[
              0.20468155953700706`, 0.33246367500678287`, 0.9349676840651762],
              UndirectedEdge[38, 306] -> 
             RGBColor[
              0.24051285588611682`, 0.3701246393051007, 0.9370082233846052], 
             UndirectedEdge[12, 358] -> 
             RGBColor[
              0.26019129073322267`, 0.39080792201424114`, 0.9381288811375124],
              UndirectedEdge[139, 378] -> 
             RGBColor[
              0.27359029407982893`, 0.40489112407740385`, 0.9388919345560525],
              UndirectedEdge[272, 374] -> 
             RGBColor[
              0.19014395523747457`, 0.3171837311506246, 0.934139789006776], 
             UndirectedEdge[21, 114] -> 
             RGBColor[
              0.19167285067202883`, 0.3187906971899105, 0.9342268573399758], 
             UndirectedEdge[250, 321] -> 
             RGBColor[
              0.18913677562513462`, 0.3161251215191795, 0.934082431617842], 
             UndirectedEdge[19, 152] -> 
             RGBColor[
              0.2001783639532218, 0.3277305309291337, 0.9347112337385604], 
             UndirectedEdge[270, 336] -> 
             RGBColor[
              0.2213730230293102, 0.3500074614371033, 0.9359182382182554], 
             UndirectedEdge[87, 277] -> 
             RGBColor[
              0.18598156789951187`, 0.3128087981478258, 0.9339027472055792], 
             UndirectedEdge[37, 377] -> 
             RGBColor[
              0.2695128080367538, 0.400605427718585, 0.9386597277579993], 
             UndirectedEdge[312, 356] -> 
             RGBColor[
              0.746600049419986, 0.8012844499471021, 0.9674404180913663], 
             UndirectedEdge[294, 343] -> 
             RGBColor[
              0.20522639813651683`, 0.33303633491963003`, 0.9349987118174017],
              UndirectedEdge[170, 349] -> 
             RGBColor[
              0.21695935367547547`, 0.34536841510342303`, 0.9356668862779931],
              UndirectedEdge[176, 390] -> 
             RGBColor[
              0.199593709897452, 0.3271160224473115, 0.9346779385550025], 
             UndirectedEdge[235, 327] -> 
             RGBColor[
              0.1895062149755763, 0.31651342570030144`, 0.934103470642313], 
             UndirectedEdge[271, 400] -> 
             RGBColor[
              0.8210589855507496, 0.16287416781517963`, 0.16779941438710733`],
              UndirectedEdge[45, 103] -> 
             RGBColor[
              0.21725551419299843`, 0.345679698585001, 0.9356837521813359], 
             UndirectedEdge[30, 343] -> 
             RGBColor[
              0.2007094287814945, 0.32828871373510315`, 0.9347414770948905], 
             UndirectedEdge[200, 234] -> 
             RGBColor[
              0.22049169370930496`, 0.34908112844227146`, 0.9358680478172909],
              UndirectedEdge[282, 382] -> 
             RGBColor[
              0.3185597546508585, 0.45034218102492296`, 0.9415193237683902], 
             UndirectedEdge[305, 382] -> 
             RGBColor[
              0.31007770460075973`, 0.44200741025601153`, 0.9410150322193817],
              UndirectedEdge[50, 164] -> 
             RGBColor[
              0.22306024288786463`, 0.3517808364843617, 0.9360143228931819], 
             UndirectedEdge[259, 287] -> 
             RGBColor[
              0.8563718105158677, 0.5267891517148, 0.5770527968903222], 
             UndirectedEdge[90, 95] -> 
             RGBColor[
              0.23140010342565426`, 0.3605465586872775, 0.936489265613091], 
             UndirectedEdge[44, 243] -> 
             RGBColor[
              0.2298536898894718, 0.3589211800124685, 0.9364011996499193], 
             UndirectedEdge[82, 194] -> 
             RGBColor[
              0.6075992658363466, 0.6905170696190597, 0.963481170694517], 
             UndirectedEdge[124, 150] -> 
             RGBColor[
              0.2325126629936997, 0.36171592933364405`, 0.9365526242346068], 
             UndirectedEdge[233, 316] -> 
             RGBColor[
              0.8412361363066468, 0.8762214650435611, 0.9535246374949702], 
             UndirectedEdge[87, 390] -> 
             RGBColor[
              0.19991574882843044`, 0.32745450578221735`, 0.9346962781957078],
              UndirectedEdge[72, 376] -> 
             RGBColor[
              0.3758578545249899, 0.4975526740121381, 0.9453383722532241], 
             UndirectedEdge[99, 169] -> 
             RGBColor[
              0.6797124063510102, 0.7475445119943138, 0.9704734146298177], 
             UndirectedEdge[127, 137] -> 
             RGBColor[
              0.31600670483300364`, 0.4466421785419929, 0.9414111535240912], 
             UndirectedEdge[68, 391] -> 
             RGBColor[
              0.8209192855845969, 0.5085618177919978, 0.5749280813219132], 
             UndirectedEdge[292, 309] -> 
             RGBColor[
              0.7584292895983676, 0.45716808614862703`, 0.568384704834363], 
             UndirectedEdge[88, 140] -> 
             RGBColor[
              0.41837127081473313`, 0.5367938996534025, 0.947879225318494], 
             UndirectedEdge[153, 216] -> 
             RGBColor[
              0.21073387590110806`, 0.33882504324447416`, 0.935312354528512], 
             UndirectedEdge[145, 165] -> 
             RGBColor[
              0.23770682741222313`, 0.3671753254665574, 0.9368484242141641], 
             UndirectedEdge[37, 76] -> 
             RGBColor[
              0.28363325287465024`, 0.4154469105311262, 0.9394638662021915], 
             UndirectedEdge[6, 391] -> 
             RGBColor[
              0.8731987569820019, 0.5502480491958415, 0.5799145439742327], 
             UndirectedEdge[203, 206] -> 
             RGBColor[
              0.36944897924090714`, 0.4944198695980247, 0.9447619401596937], 
             UndirectedEdge[298, 320] -> 
             RGBColor[
              0.19458686072830475`, 0.3218535065179652, 0.9343928059017892], 
             UndirectedEdge[39, 164] -> 
             RGBColor[
              0.20658345954088297`, 0.3344626924982814, 0.9350759944567879], 
             UndirectedEdge[107, 156] -> 
             RGBColor[
              0.2124764155335251, 0.34065656288153834`, 0.9354115895827217], 
             UndirectedEdge[31, 222] -> 
             RGBColor[
              0.967672940132394, 0.9754000826172251, 0.9391115323234271], 
             UndirectedEdge[301, 329] -> 
             RGBColor[
              0.25610352101831557`, 0.38651141686430435`, 0.9378960886995618],
              UndirectedEdge[126, 320] -> 
             RGBColor[
              0.18313368370358218`, 0.3098154912916167, 0.9337405644136882], 
             UndirectedEdge[49, 191] -> 
             RGBColor[
              0.18385357890938503`, 0.3105721467969078, 0.933781561380669], 
             UndirectedEdge[122, 173] -> 
             RGBColor[
              0.18447873947082444`, 0.3112292301844495, 0.9338171633498009], 
             UndirectedEdge[60, 102] -> 
             RGBColor[
              0.5280292771941157, 0.6238948638185677, 0.9574471733011694], 
             UndirectedEdge[120, 380] -> 
             RGBColor[
              0.5664649447415552, 0.6566185624069654, 0.9601363872621158], 
             UndirectedEdge[110, 247] -> 
             RGBColor[
              0.8351507068562677, 0.5099360316010974, 0.5750372213001058], 
             UndirectedEdge[59, 149] -> 
             RGBColor[
              0.21329928840113216`, 0.34152145443854653`, 0.9354584509752006],
              UndirectedEdge[92, 346] -> 
             RGBColor[
              0.2038983093069455, 0.33164042935405524`, 0.934923079123289], 
             UndirectedEdge[6, 142] -> 
             RGBColor[
              0.7001614603741532, 0.763972329138221, 0.9722831025823769], 
             UndirectedEdge[176, 232] -> 
             RGBColor[
              0.18828223277850703`, 0.3152269428062281, 0.9340337666669094], 
             UndirectedEdge[60, 345] -> 
             RGBColor[
              0.7675537628448912, 0.8184035673483785, 0.9774488709937861], 
             UndirectedEdge[79, 126] -> 
             RGBColor[
              0.19080527822884924`, 0.31787882354485875`, 0.9341774503727951],
              UndirectedEdge[14, 212] -> 
             RGBColor[
              0.45821441723172895`, 0.5679246084974616, 0.9513517397459614], 
             UndirectedEdge[22, 338] -> 
             RGBColor[
              0.2260845393342366, 0.35495956380096844`, 0.9361865521017572], 
             UndirectedEdge[195, 389] -> 
             RGBColor[
              0.7088707754207897, 0.764952224756877, 0.7205833028362763], 
             UndirectedEdge[14, 293] -> 
             RGBColor[
              0.32638953387049785`, 0.45712394224882835`, 0.9420182303766638],
              UndirectedEdge[201, 394] -> 
             RGBColor[
              0.5116695891716139, 0.6114793927942537, 0.9556621742335425], 
             UndirectedEdge[20, 189] -> 
             RGBColor[
              0.30889970680782364`, 0.4349879582915822, 0.9411596287595527], 
             UndirectedEdge[195, 359] -> 
             RGBColor[
              0.375153965132881, 0.49936124163672424`, 0.9451254568160093], 
             UndirectedEdge[222, 224] -> 
             RGBColor[
              0.724417520241849, 0.7830873105778803, 0.9606419773233753], 
             UndirectedEdge[54, 389] -> 
             RGBColor[
              0.9706885388162402, 0.9101251515870772, 0.3850556620267193], 
             UndirectedEdge[123, 366] -> 
             RGBColor[
              0.9182289355345559, 0.6604066319094237, 0.35054608517613656`], 
             UndirectedEdge[120, 263] -> 
             RGBColor[
              0.3571898835204337, 0.4831624157488532, 0.9440042071759314], 
             UndirectedEdge[332, 364] -> 
             RGBColor[
              0.8695716309493327, 0.4318508782657767, 0.2101242523176128], 
             UndirectedEdge[70, 228] -> 
             RGBColor[
              0.21048617188066365`, 0.3385646906136451, 0.9352982481509928], 
             UndirectedEdge[74, 141] -> 
             RGBColor[
              0.3021503369999872, 0.43056214369424695`, 0.9406775662244785], 
             UndirectedEdge[212, 385] -> 
             RGBColor[
              0.7860985506073723, 0.8292872838004639, 0.7968353358505167], 
             UndirectedEdge[256, 384] -> 
             RGBColor[
              0.9629443447193516, 0.8827390749129462, 0.5213129511813582], 
             UndirectedEdge[158, 317] -> 
             RGBColor[
              0.18982224071375664`, 0.31684558878831803`, 0.9341214678405843],
              UndirectedEdge[76, 208] -> 
             RGBColor[
              0.28867650153937047`, 0.420747684638181, 0.9397510717528295], 
             UndirectedEdge[101, 253] -> 
             RGBColor[
              0.8395830715203696, 0.3052584098839103, 0.18553810003157822`], 
             UndirectedEdge[111, 309] -> 
             RGBColor[
              0.7619893896080814, 0.48453257486905843`, 0.5717938606242228], 
             UndirectedEdge[145, 170] -> 
             RGBColor[
              0.24268853638713495`, 0.37241141745778183`, 0.9371321251705074],
              UndirectedEdge[59, 279] -> 
             RGBColor[
              0.2076546436516325, 0.3355885749156745, 0.9351369968072203], 
             UndirectedEdge[83, 334] -> 
             RGBColor[
              0.9555982588691752, 0.9202058525384339, 0.6338919338224923], 
             UndirectedEdge[242, 312] -> 
             RGBColor[
              0.4441075478761082, 0.5565195124327971, 0.9502280720328274], 
             UndirectedEdge[140, 356] -> 
             RGBColor[
              0.6758651089866358, 0.7425832566534856, 0.9622242963377263], 
             UndirectedEdge[172, 316] -> 
             RGBColor[
              0.5458822960971526, 0.6391409074229324, 0.9586767421820886], 
             UndirectedEdge[217, 331] -> 
             RGBColor[
              0.22460790707912992`, 0.3534075296769589, 0.9361024600793104], 
             UndirectedEdge[263, 336] -> 
             RGBColor[
              0.2683165494931898, 0.3993480841421268, 0.9385916026036494], 
             UndirectedEdge[122, 338] -> 
             RGBColor[
              0.19975108063826336`, 0.32728142907378543`, 0.9346869005858826],
              UndirectedEdge[303, 400] -> 
             RGBColor[
              0.8580226382100805, 0.391117913716996, 0.20100792167803327`], 
             UndirectedEdge[133, 367] -> 
             RGBColor[
              0.18474901765317286`, 0.31151330969072427`, 0.9338325552924449],
              UndirectedEdge[136, 279] -> 
             RGBColor[
              0.19083656061449622`, 0.3179117033155916, 0.9341792318583795], 
             UndirectedEdge[117, 365] -> 
             RGBColor[
              0.4322742926857367, 0.5457268859697086, 0.94956369337159], 
             UndirectedEdge[33, 245] -> 
             RGBColor[
              0.22074175679161856`, 0.34934396059669826`, 0.9358822885398935],
              UndirectedEdge[162, 368] -> 
             RGBColor[
              0.18956500601498782`, 0.31657521881029016`, 0.934106818705034], 
             UndirectedEdge[46, 128] -> 
             RGBColor[
              0.5547192055800235, 0.6423805327309791, 0.9609350717272003], 
             UndirectedEdge[117, 269] -> 
             RGBColor[
              0.45596747114210545`, 0.5665010427125681, 0.9510641632117192], 
             UndirectedEdge[98, 134] -> 
             RGBColor[
              0.1861818864522268, 0.313019345647659, 0.9339141550508117], 
             UndirectedEdge[90, 326] -> 
             RGBColor[
              0.22857029923452804`, 0.35757225506245527`, 0.9363281124507266],
              UndirectedEdge[119, 306] -> 
             RGBColor[
              0.2310448890646134, 0.36017320587193224`, 0.9364690366807222], 
             UndirectedEdge[150, 211] -> 
             RGBColor[
              0.23544785722092995`, 0.3648010045685258, 0.9367197792036168], 
             UndirectedEdge[388, 395] -> 
             RGBColor[
              0.35473118198517756`, 0.4781619748017699, 0.9439526563033052], 
             UndirectedEdge[102, 108] -> 
             RGBColor[
              0.3276991764172302, 0.45803801914073383`, 0.9421097447928497], 
             UndirectedEdge[15, 392] -> 
             RGBColor[
              0.19259602959164984`, 0.3197610167673564, 0.9342794310137273], 
             UndirectedEdge[32, 292] -> 
             RGBColor[
              0.8205053754928366, 0.15861887831658708`, 0.16726927677043682`],
              UndirectedEdge[115, 332] -> 
             RGBColor[
              0.8864563951040925, 0.498793341625289, 0.2237101298928862], 
             UndirectedEdge[93, 293] -> 
             RGBColor[
              0.3283292569566383, 0.4588040328927261, 0.9421418278164828], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.1906510637312114, 0.3177167343300775, 0.9341686680852945], 
             UndirectedEdge[276, 305] -> 
             RGBColor[
              0.33855234976798615`, 0.46667071672258365`, 0.9428294114302973],
              UndirectedEdge[75, 347] -> 
             RGBColor[
              0.18311704522785527`, 0.30979800319868733`, 0.9337396168771099],
              UndirectedEdge[64, 193] -> 
             RGBColor[
              0.9152566921622731, 0.9300770448033753, 0.7093659477350615], 
             UndirectedEdge[18, 99] -> 
             RGBColor[
              0.947350971343756, 0.9556350172112698, 0.7097411277967336], 
             UndirectedEdge[74, 290] -> 
             RGBColor[
              0.2530317916874394, 0.3832828345786652, 0.9377211582583846], 
             UndirectedEdge[39, 230] -> 
             RGBColor[
              0.20964976351428055`, 0.33768557238922303`, 0.9352506159318827],
              UndirectedEdge[259, 345] -> 
             RGBColor[
              0.8617541752858404, 0.8926034039517254, 0.9866760766074392], 
             UndirectedEdge[30, 168] -> 
             RGBColor[
              0.19933167973369648`, 0.3268406121315325, 0.9346630163248155], 
             UndirectedEdge[231, 331] -> 
             RGBColor[
              0.21608777115484973`, 0.34445232661272185`, 0.9356172509428343],
              UndirectedEdge[137, 242] -> 
             RGBColor[
              0.31652160790723577`, 0.4470881617051118, 0.9414439626926704], 
             UndirectedEdge[172, 221] -> 
             RGBColor[
              0.3747675504331488, 0.4990265486455837, 0.9451008348130354], 
             UndirectedEdge[157, 211] -> 
             RGBColor[
              0.23967520555955008`, 0.36924421570178084`, 0.9369605204376998],
              UndirectedEdge[46, 213] -> 
             RGBColor[
              0.5654749182769274, 0.6521444572622102, 0.9616040176321952], 
             UndirectedEdge[184, 318] -> 
             RGBColor[
              0.2135047362690546, 0.34173739317388024`, 0.935470150927346], 
             UndirectedEdge[201, 293] -> 
             RGBColor[
              0.4899219075938762, 0.5926426440818758, 0.9542764311941287], 
             UndirectedEdge[64, 115] -> 
             RGBColor[
              0.973846560757742, 0.9231368127839409, 0.35853265585475147`], 
             UndirectedEdge[174, 266] -> 
             RGBColor[
              0.5380286912692482, 0.6346285303347542, 0.9572070721400225], 
             UndirectedEdge[80, 104] -> 
             RGBColor[
              0.2135778861880246, 0.34181427837669043`, 0.9354743167070156], 
             UndirectedEdge[265, 321] -> 
             RGBColor[
              0.19177497299708612`, 0.31889803422847507`, 0.9342326730553113],
              UndirectedEdge[178, 296] -> 
             RGBColor[
              0.18104204814496305`, 0.30761704970215387`, 0.9336214488629224],
              UndirectedEdge[114, 249] -> 
             RGBColor[
              0.18514988407402466`, 0.3119346457154385, 0.9338553840420838], 
             UndirectedEdge[255, 380] -> 
             RGBColor[
              0.5472854839726642, 0.6400062774766795, 0.9589142889816533], 
             UndirectedEdge[253, 391] -> 
             RGBColor[
              0.8227133050515791, 0.17558999242598253`, 0.16938359260938823`],
              UndirectedEdge[40, 63] -> 
             RGBColor[
              0.19138658757193353`, 0.3184898165215815, 0.9342105550799136], 
             UndirectedEdge[23, 311] -> 
             RGBColor[
              0.2072579319428704, 0.33517160575679045`, 0.9351144046622886], 
             UndirectedEdge[156, 396] -> 
             RGBColor[
              0.19313485512094197`, 0.32032735656215416`, 0.9343101163304997],
              UndirectedEdge[93, 281] -> 
             RGBColor[
              0.3706399848182322, 0.4954514587674228, 0.944837829981916], 
             UndirectedEdge[27, 325] -> 
             RGBColor[
              0.22165235452841858`, 0.35030105655330623`, 0.9359341457338957],
              UndirectedEdge[12, 107] -> 
             RGBColor[
              0.23293330946253646`, 0.362158055442918, 0.9365765794287164], 
             UndirectedEdge[255, 312] -> 
             RGBColor[
              0.46100266352577723`, 0.571153212435337, 0.9513046138622602], 
             UndirectedEdge[257, 310] -> 
             RGBColor[
              0.8979684765940259, 0.5907693635082272, 0.5548367056098094], 
             UndirectedEdge[50, 197] -> 
             RGBColor[
              0.21121964795225362`, 0.33933562046995513`, 0.9353400185281894],
              UndirectedEdge[215, 350] -> 
             RGBColor[
              0.5273081197953102, 0.6233107010129518, 0.9573840940310441], 
             UndirectedEdge[49, 235] -> 
             RGBColor[
              0.1884735679979762, 0.31542804825324383`, 0.9340446629246031], 
             UndirectedEdge[239, 323] -> 
             RGBColor[
              0.4638795886223883, 0.5747495967298069, 0.9511827422942791], 
             UndirectedEdge[211, 216] -> 
             RGBColor[
              0.22415272438939332`, 0.35292910380979625`, 0.9360765380985124],
              UndirectedEdge[98, 151] -> 
             RGBColor[
              0.20043054064394245`, 0.3279955846200067, 0.934725594828035], 
             UndirectedEdge[10, 32] -> 
             RGBColor[
              0.8322429825165458, 0.24883926935301032`, 0.1785092225120718], 
             UndirectedEdge[330, 367] -> 
             RGBColor[
              0.1873967228823739, 0.314296215760822, 0.9339833381883191], 
             UndirectedEdge[99, 384] -> 
             RGBColor[
              0.9178754148881313, 0.8496097092612407, 0.6279747633092586], 
             UndirectedEdge[127, 138] -> 
             RGBColor[
              0.31413697275722113`, 0.44467697158248487`, 0.9413046750483962],
              UndirectedEdge[292, 385] -> 
             RGBColor[
              0.9069547340805542, 0.5706484219232661, 0.4000326809306238], 
             UndirectedEdge[177, 219] -> 
             RGBColor[
              0.18016175523476746`, 0.3066918060397442, 0.9335713174839634], 
             UndirectedEdge[170, 322] -> 
             RGBColor[
              0.2153075934140704, 0.3436323103410369, 0.9355728209746665], 
             UndirectedEdge[261, 335] -> 
             RGBColor[
              0.19373393161436922`, 0.3209570239403897, 0.934344232850546], 
             UndirectedEdge[6, 253] -> 
             RGBColor[
              0.8756778488316885, 0.5693034354975091, 0.5822885251292265], 
             UndirectedEdge[95, 246] -> 
             RGBColor[
              0.23196638865379215`, 0.3611417603666076, 0.9365215147190895], 
             UndirectedEdge[50, 331] -> 
             RGBColor[
              0.2360482874744978, 0.36543209483450245`, 0.9367539728183005], 
             UndirectedEdge[9, 358] -> 
             RGBColor[
              0.48197798109692647`, 0.5820052784935108, 0.954246805716025], 
             UndirectedEdge[99, 144] -> 
             RGBColor[
              0.7417116613175341, 0.797878300210745, 0.9753542230915366], 
             UndirectedEdge[2, 28] -> 
             RGBColor[
              0.1967107027357332, 0.32408579912713337`, 0.9345137555621694], 
             UndirectedEdge[138, 258] -> 
             RGBColor[
              0.26327890753170885`, 0.39405320303566205`, 0.9383047163464664],
              UndirectedEdge[144, 384] -> 
             RGBColor[
              0.757420984754537, 0.7226612405223014, 0.6127983851533676], 
             UndirectedEdge[79, 277] -> 
             RGBColor[
              0.19208286823872933`, 0.31922165164912797`, 0.9342502072338328],
              UndirectedEdge[346, 354] -> 
             RGBColor[
              0.1997636988090205, 0.3272946915712895, 0.9346876191720402], 
             UndirectedEdge[144, 148] -> 
             RGBColor[
              0.41890511783186646`, 0.5289568419765102, 0.9490497655266936], 
             UndirectedEdge[38, 346] -> 
             RGBColor[
              0.23107597310122763`, 0.36020587716525554`, 0.9364708068706228],
              UndirectedEdge[38, 363] -> 
             RGBColor[
              0.3166257823122153, 0.444042358182842, 0.9415654261663287], 
             UndirectedEdge[78, 104] -> 
             RGBColor[
              0.22225745398096258`, 0.35093705444345114`, 0.9359686052525535],
              UndirectedEdge[95, 282] -> 
             RGBColor[
              0.2811273621289757, 0.41223265884799526`, 0.9393424107780823], 
             UndirectedEdge[92, 306] -> 
             RGBColor[
              0.21333519209183469`, 0.34155919149390046`, 0.9354604956372714],
              UndirectedEdge[9, 339] -> 
             RGBColor[
              0.5341582021850244, 0.6300810922914106, 0.9574662349562233], 
             UndirectedEdge[36, 148] -> 
             RGBColor[
              0.2511034439451054, 0.38125601883716365`, 0.9376113417071936], 
             UndirectedEdge[62, 395] -> 
             RGBColor[
              0.7152423649203183, 0.772631878073945, 0.8673341109470382], 
             UndirectedEdge[32, 247] -> 
             RGBColor[
              0.8194288056366617, 0.15034389064610632`, 0.16623835226035183`],
              UndirectedEdge[168, 379] -> 
             RGBColor[
              0.190216267574, 0.31725973600117974`, 0.9341439070873645], 
             UndirectedEdge[137, 230] -> 
             RGBColor[
              0.2568850160495337, 0.38733281769176137`, 0.9379405936854713], 
             UndirectedEdge[268, 279] -> 
             RGBColor[
              0.19334852815726622`, 0.3205519404709839, 0.9343222846938173], 
             UndirectedEdge[185, 288] -> 
             RGBColor[
              0.2031417930336449, 0.3308452827849142, 0.93487999664069], 
             UndirectedEdge[233, 310] -> 
             RGBColor[
              0.8984238517661913, 0.5911089815660195, 0.5540658742241997], 
             UndirectedEdge[150, 386] -> 
             RGBColor[
              0.29016677848912364`, 0.4192462598996066, 0.9399482680174902], 
             UndirectedEdge[138, 281] -> 
             RGBColor[
              0.3438282004171828, 0.4703940206570502, 0.9431965738199672], 
             UndirectedEdge[88, 257] -> 
             RGBColor[
              0.6999080745469857, 0.7619616397704058, 0.9426465587738788], 
             UndirectedEdge[27, 40] -> 
             RGBColor[
              0.19924073649984758`, 0.3267450250266232, 0.9346578372421862], 
             UndirectedEdge[159, 250] -> 
             RGBColor[
              0.18793077615893167`, 0.3148575396154177, 0.934013751732358], 
             UndirectedEdge[169, 363] -> 
             RGBColor[
              0.4158922643017966, 0.5345397089893019, 0.947750829584961], 
             UndirectedEdge[144, 382] -> 
             RGBColor[
              0.451676599366216, 0.5621674511867154, 0.9509612465314614], 
             UndirectedEdge[35, 207] -> 
             RGBColor[
              0.19080850531779897`, 0.3178822154199542, 0.9341776341507367], 
             UndirectedEdge[71, 287] -> 
             RGBColor[
              0.8935114377259239, 0.5555263902170573, 0.5501928078759782], 
             UndirectedEdge[148, 361] -> 
             RGBColor[
              0.33306353105933184`, 0.4580790241212378, 0.94262018039587], 
             UndirectedEdge[215, 393] -> 
             RGBColor[
              0.7140213652809209, 0.7765181844116039, 0.9721306348483233], 
             UndirectedEdge[33, 124] -> 
             RGBColor[
              0.23660403432322674`, 0.366016220008902, 0.9367856217791819], 
             UndirectedEdge[31, 111] -> 
             RGBColor[
              0.905435236677787, 0.5966580870469695, 0.5418299175859177], 
             UndirectedEdge[113, 357] -> 
             RGBColor[
              0.18582607626581804`, 0.31264536658207454`, 0.9338938921870696],
              UndirectedEdge[30, 329] -> 
             RGBColor[
              0.23151896311630302`, 0.36067148775828894`, 0.9364960344966363],
              UndirectedEdge[117, 239] -> 
             RGBColor[
              0.5328344578573876, 0.6316180426642315, 0.9563658268409162], 
             UndirectedEdge[209, 338] -> 
             RGBColor[
              0.23759083072429804`, 0.3670534055929334, 0.9368418183743885], 
             UndirectedEdge[208, 323] -> 
             RGBColor[
              0.3575199332630081, 0.48276280813906464`, 0.9440503364383386], 
             UndirectedEdge[71, 212] -> 
             RGBColor[
              0.7737416965530766, 0.822516123696677, 0.9480358411696325], 
             UndirectedEdge[199, 292] -> 
             RGBColor[
              0.9041138184890838, 0.5702193507910247, 0.501320010499076], 
             UndirectedEdge[11, 386] -> 
             RGBColor[
              0.6075598618760001, 0.6861529495738531, 0.9653876814635047], 
             UndirectedEdge[130, 267] -> 
             RGBColor[
              0.20661372269188627`, 0.33449450098878053`, 0.9350777178984673],
              UndirectedEdge[67, 347] -> 
             RGBColor[
              0.18186543483400505`, 0.3084824813180684, 0.9336683395167719], 
             UndirectedEdge[211, 358] -> 
             RGBColor[
              0.2550430737157216, 0.3853968195130357, 0.9378356977944702], 
             UndirectedEdge[2, 164] -> 
             RGBColor[
              0.20840908696131982`, 0.3363815426686245, 0.935179961237608], 
             UndirectedEdge[266, 358] -> 
             RGBColor[
              0.4679094050103473, 0.5710147999295367, 0.9528445815300333], 
             UndirectedEdge[57, 397] -> 
             RGBColor[
              0.3562392675894767, 0.4829782813049682, 0.943920229014154], 
             UndirectedEdge[209, 386] -> 
             RGBColor[
              0.30348621877337745`, 0.4332458361396474, 0.9407067904373323], 
             UndirectedEdge[74, 386] -> 
             RGBColor[
              0.29523037248077955`, 0.42456841823523894`, 0.9402366322043989],
              UndirectedEdge[47, 268] -> 
             RGBColor[
              0.18433220446865944`, 0.3110752126063183, 0.9338088183982067], 
             UndirectedEdge[108, 397] -> 
             RGBColor[
              0.3352715846751584, 0.4645968585734458, 0.9425922519510271], 
             UndirectedEdge[157, 358] -> 
             RGBColor[
              0.2622292284500658, 0.3929499237673575, 0.938244938675628], 
             UndirectedEdge[10, 129] -> 
             RGBColor[
              0.8311516302547027, 0.2404506576348733, 0.17746414235362473`], 
             UndirectedEdge[171, 308] -> 
             RGBColor[
              0.20045056014029836`, 0.3280166263799862, 0.9347267349087363], 
             UndirectedEdge[225, 335] -> 
             RGBColor[
              0.20337317791570175`, 0.3310884829666048, 0.93489317366742], 
             UndirectedEdge[45, 116] -> 
             RGBColor[
              0.23987123039501432`, 0.3694502502325462, 0.9369716837620867], 
             UndirectedEdge[261, 349] -> 
             RGBColor[
              0.19380914280268063`, 0.32103607566796977`, 0.9343485160164554],
              UndirectedEdge[118, 209] -> 
             RGBColor[
              0.3112464668184692, 0.43996737295489813`, 0.9412012665806477], 
             UndirectedEdge[329, 343] -> 
             RGBColor[
              0.23152940348291426`, 0.3606824612455548, 0.9364966290600697], 
             UndirectedEdge[163, 171] -> 
             RGBColor[
              0.18355378954190335`, 0.31025704916394076`, 0.9337644888196897],
              UndirectedEdge[106, 217] -> 
             RGBColor[
              0.1973830107710603, 0.32479243749905357`, 0.9345520425101908], 
             UndirectedEdge[55, 123] -> 
             RGBColor[
              0.8234475715902414, 0.5896702073672445, 0.5850169799812919], 
             UndirectedEdge[129, 353] -> 
             RGBColor[
              0.9062979809873158, 0.5688117544551025, 0.33694932919085196`], 
             UndirectedEdge[38, 66] -> 
             RGBColor[
              0.22742648369193186`, 0.3563700324050926, 0.9362629738476992], 
             UndirectedEdge[23, 119] -> 
             RGBColor[
              0.22585475434557115`, 0.35471804520867123`, 0.936173466186589], 
             UndirectedEdge[306, 354] -> 
             RGBColor[
              0.2092005815939097, 0.33721345371113465`, 0.9352250356860227], 
             UndirectedEdge[28, 39] -> 
             RGBColor[
              0.19488507531529636`, 0.3221669489567903, 0.9344097887813494], 
             UndirectedEdge[158, 267] -> 
             RGBColor[
              0.19435218965099377`, 0.3216068523367057, 0.934379441731101], 
             UndirectedEdge[194, 399] -> 
             RGBColor[
              0.40740786703989107`, 0.5272403351648417, 0.9471965661691704], 
             UndirectedEdge[102, 333] -> 
             RGBColor[
              0.6514056454646207, 0.7208926458479099, 0.9532948082895194], 
             UndirectedEdge[16, 80] -> 
             RGBColor[
              0.21603013302378776`, 0.34439174528250716`, 0.9356139685365383],
              UndirectedEdge[72, 333] -> 
             RGBColor[
              0.7096566263019076, 0.7710149507769987, 0.9570981774601166], 
             UndirectedEdge[167, 211] -> 
             RGBColor[
              0.23414776627805434`, 0.3634345265570368, 0.9366457409477322], 
             UndirectedEdge[193, 255] -> 
             RGBColor[
              0.606058461723811, 0.6860652101473173, 0.9647337421078497], 
             UndirectedEdge[168, 211] -> 
             RGBColor[
              0.2152267109388578, 0.3435472977313434, 0.935568214837358], 
             UndirectedEdge[70, 246] -> 
             RGBColor[
              0.2068329817370454, 0.33472495614706915`, 0.9350902043767244], 
             UndirectedEdge[322, 349] -> 
             RGBColor[
              0.19676296516777197`, 0.32414073025683565`, 0.9345167318303588],
              UndirectedEdge[193, 312] -> 
             RGBColor[
              0.6928723364666782, 0.7586931681891012, 0.9709743993376487], 
             UndirectedEdge[194, 221] -> 
             RGBColor[
              0.41267584437400284`, 0.5318031923554098, 0.9475322370266106], 
             UndirectedEdge[208, 221] -> 
             RGBColor[
              0.3321648835388723, 0.4608015384498717, 0.9424347350905069], 
             UndirectedEdge[112, 251] -> 
             RGBColor[
              0.18268323345773074`, 0.30934203952303163`, 0.9337149119385684],
              UndirectedEdge[297, 325] -> 
             RGBColor[
              0.267416015836295, 0.3984015661715987, 0.9385403185441094], 
             UndirectedEdge[170, 225] -> 
             RGBColor[
              0.22199301735031157`, 0.3506591147783862, 0.9359535459776369], 
             UndirectedEdge[27, 250] -> 
             RGBColor[
              0.19937642447535237`, 0.3268876416919933, 0.9346655644716588], 
             UndirectedEdge[67, 126] -> 
             RGBColor[
              0.18098291600078534`, 0.3075548980694286, 0.9336180813747896], 
             UndirectedEdge[12, 157] -> 
             RGBColor[
              0.24482342257705114`, 0.37465531820298625`, 0.937253703780742], 
             UndirectedEdge[316, 399] -> 
             RGBColor[
              0.5357585344043984, 0.6303722138797264, 0.9580316650391174], 
             UndirectedEdge[76, 377] -> 
             RGBColor[
              0.2688145572376063, 0.39987152185702324`, 0.9386199634079575], 
             UndirectedEdge[3, 51] -> 
             RGBColor[
              0.2187121116641707, 0.34721067488081686`, 0.9357667032524762], 
             UndirectedEdge[23, 186] -> 
             RGBColor[
              0.209250396089514, 0.3372658119044362, 0.9352278725478533], 
             UndirectedEdge[17, 319] -> 
             RGBColor[
              0.8300530358518976, 0.23200637964777565`, 0.17641212711281357`],
              UndirectedEdge[115, 360] -> 
             RGBColor[
              0.8089316906478522, 0.7980968050279984, 0.6248789386336926], 
             UndirectedEdge[131, 142] -> 
             RGBColor[
              0.6441352636384634, 0.7193460306737178, 0.9669266768382974], 
             UndirectedEdge[23, 130] -> 
             RGBColor[
              0.21379154943709947`, 0.3420388519985006, 0.935486484512964], 
             UndirectedEdge[348, 354] -> 
             RGBColor[
              0.19860265347109932`, 0.3260743593066081, 0.9346214993576583], 
             UndirectedEdge[76, 80] -> 
             RGBColor[
              0.24302079240522623`, 0.37276063959904404`, 0.9371510466592089],
              UndirectedEdge[38, 81] -> 
             RGBColor[
              0.2439408678768847, 0.37372769725591143`, 0.9372034435961902], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.22057742375863354`, 0.3491712361597149, 0.935872930016774], 
             UndirectedEdge[131, 281] -> 
             RGBColor[
              0.6064310569728814, 0.687254440774864, 0.9643678385927457], 
             UndirectedEdge[157, 167] -> 
             RGBColor[
              0.24133392101239853`, 0.37098763081135855`, 0.93705498182889], 
             UndirectedEdge[165, 172] -> 
             RGBColor[
              0.3025819493818708, 0.42881009810169846`, 0.9407829073040905], 
             UndirectedEdge[255, 331] -> 
             RGBColor[
              0.30757882188877433`, 0.4345645888368619, 0.9410490742458533], 
             UndirectedEdge[59, 268] -> 
             RGBColor[
              0.2019662570213913, 0.3296097199027477, 0.9348130516038419], 
             UndirectedEdge[161, 364] -> 
             RGBColor[
              0.9004423422818535, 0.6358848335091806, 0.23838402091941335`], 
             UndirectedEdge[149, 164] -> 
             RGBColor[
              0.21265948505393958`, 0.340848980554772, 0.9354220151210823], 
             UndirectedEdge[10, 52] -> 
             RGBColor[
              0.9159808794279284, 0.6604932743481702, 0.5104145698509248], 
             UndirectedEdge[132, 155] -> 
             RGBColor[
              0.18938684794258642`, 0.3163879633803221, 0.934096672866372], 
             UndirectedEdge[353, 400] -> 
             RGBColor[
              0.9076875092111716, 0.5794922772788073, 0.33827994298726377`], 
             UndirectedEdge[250, 265] -> 
             RGBColor[
              0.19635832810443649`, 0.32371543104779843`, 0.9344936883482087],
              UndirectedEdge[82, 233] -> 
             RGBColor[
              0.865044812104987, 0.8948209835298624, 0.9558976637938235], 
             UndirectedEdge[66, 81] -> 
             RGBColor[
              0.21264159429708712`, 0.3408301762349806, 0.9354209962689466], 
             UndirectedEdge[69, 201] -> 
             RGBColor[
              0.6192660008437627, 0.7014292931597987, 0.9634146436784279], 
             UndirectedEdge[84, 184] -> 
             RGBColor[
              0.21392003441563898`, 0.34217389785736374`, 0.9354938015424155],
              UndirectedEdge[180, 268] -> 
             RGBColor[
              0.1880422345433147, 0.314974689444274, 0.9340200991224608], 
             UndirectedEdge[17, 247] -> 
             RGBColor[
              0.8225002166596341, 0.17395210166956507`, 0.16917953892461288`],
              UndirectedEdge[188, 394] -> 
             RGBColor[
              0.3167171676025393, 0.44570099448454903`, 0.9415134165478973], 
             UndirectedEdge[241, 312] -> 
             RGBColor[
              0.41436397282412324`, 0.5281836244089898, 0.9484270661099586], 
             UndirectedEdge[81, 128] -> 
             RGBColor[
              0.2665289573662383, 0.3974692114768138, 0.9384898018765251], 
             UndirectedEdge[65, 198] -> 
             RGBColor[
              0.6026458427872066, 0.6834233570756016, 0.9643717480774334], 
             UndirectedEdge[356, 380] -> 
             RGBColor[
              0.8328828698668729, 0.8701375149884446, 0.9750500932107594], 
             UndirectedEdge[40, 265] -> 
             RGBColor[
              0.1962226401289317, 0.32357281438242835`, 0.9344859611187359], 
             UndirectedEdge[19, 168] -> 
             RGBColor[
              0.19873861175960342`, 0.3262172600880793, 0.9346292419810562], 
             UndirectedEdge[195, 241] -> 
             RGBColor[
              0.35276484059541724`, 0.47739540900316435`, 0.9437930699766406],
              UndirectedEdge[33, 141] -> 
             RGBColor[
              0.3011781143378584, 0.42954027603387246`, 0.9406221995821449], 
             UndirectedEdge[65, 100] -> 
             RGBColor[
              0.38210315454201915`, 0.5053802802265043, 0.9455682530202327], 
             UndirectedEdge[15, 207] -> 
             RGBColor[
              0.18682358813972555`, 0.3136938148074571, 0.9339506990126021], 
             UndirectedEdge[81, 135] -> 
             RGBColor[
              0.2822556151095555, 0.41153871876028536`, 0.9394754920042432], 
             UndirectedEdge[259, 271] -> 
             RGBColor[
              0.8577136869121025, 0.5371034017102467, 0.5783377792427893], 
             UndirectedEdge[194, 233] -> 
             RGBColor[
              0.7128854689421396, 0.7730895863286765, 0.9426895386250231], 
             UndirectedEdge[101, 283] -> 
             RGBColor[
              0.8929481444706848, 0.5918370196285758, 0.23170005506756156`], 
             UndirectedEdge[145, 192] -> 
             RGBColor[
              0.25406976709764434`, 0.3843738125462326, 0.9377802694224489], 
             UndirectedEdge[68, 397] -> 
             RGBColor[
              0.5928919663607762, 0.6752224028696671, 0.9636363647773936], 
             UndirectedEdge[142, 201] -> 
             RGBColor[
              0.5699368421210522, 0.6613816598554264, 0.9595312716051138], 
             UndirectedEdge[146, 354] -> 
             RGBColor[
              0.197615256434939, 0.32503654241701563`, 0.9345652685571719], 
             UndirectedEdge[153, 329] -> 
             RGBColor[
              0.23399514583317907`, 0.36327411279277777`, 0.9366370494391784],
              UndirectedEdge[132, 279] -> 
             RGBColor[
              0.1959554713815859, 0.323292003089491, 0.9344707462538155], 
             UndirectedEdge[257, 389] -> 
             RGBColor[
              0.981271770948398, 0.982206986986089, 0.7147685106713391], 
             UndirectedEdge[107, 386] -> 
             RGBColor[
              0.2825040137132291, 0.4111922082727934, 0.9395118848995476], 
             UndirectedEdge[157, 203] -> 
             RGBColor[
              0.2784354581733116, 0.40986687435040126`, 0.9391721369966093], 
             UndirectedEdge[264, 281] -> 
             RGBColor[
              0.3293650670543722, 0.4551923504771167, 0.9423729197712435], 
             UndirectedEdge[244, 302] -> 
             RGBColor[
              0.18853043849765405`, 0.3154878227542032, 0.9340479016154273], 
             UndirectedEdge[46, 105] -> 
             RGBColor[
              0.8954193827902208, 0.9181003086598438, 0.937247307981482], 
             UndirectedEdge[126, 347] -> 
             RGBColor[
              0.18344187738111917`, 0.31013942238731573`, 0.9337581155876922],
              UndirectedEdge[129, 253] -> 
             RGBColor[
              0.822264279381292, 0.17213858435985327`, 0.16895360512041946`], 
             UndirectedEdge[14, 69] -> 
             RGBColor[
              0.45573362712038445`, 0.5659105913267511, 0.9511564428609628], 
             UndirectedEdge[118, 124] -> 
             RGBColor[
              0.29203302591126107`, 0.41977282835890883`, 0.9401070895447208],
              UndirectedEdge[181, 245] -> 
             RGBColor[
              0.1935081925729178, 0.3207197578951424, 0.9343313773460864], 
             UndirectedEdge[33, 152] -> 
             RGBColor[
              0.2237166408577273, 0.3524707523687224, 0.9360517037865118], 
             UndirectedEdge[47, 371] -> 
             RGBColor[
              0.18051873474236652`, 0.3070670141360388, 0.9335916469388172], 
             UndirectedEdge[131, 273] -> 
             RGBColor[
              0.6690783888345512, 0.7395959833828867, 0.9688902910234116], 
             UndirectedEdge[230, 299] -> 
             RGBColor[
              0.20475753633962784`, 0.33254353144354476`, 0.9349720108316877],
              UndirectedEdge[107, 181] -> 
             RGBColor[
              0.20760170595158578`, 0.3355329340364814, 0.935133982083517], 
             UndirectedEdge[4, 318] -> 
             RGBColor[
              0.20715075077545358`, 0.3350589515541568, 0.9351083008533645], 
             UndirectedEdge[10, 333] -> 
             RGBColor[
              0.8983718156694669, 0.6481583597796403, 0.5759535503804154], 
             UndirectedEdge[152, 238] -> 
             RGBColor[
              0.20086303760420032`, 0.32845016634712887`, 0.9347502248900996],
              UndirectedEdge[50, 147] -> 
             RGBColor[
              0.23917140342485926`, 0.3687146877153205, 0.9369318296514377], 
             UndirectedEdge[39, 217] -> 
             RGBColor[
              0.2032105562120073, 0.33091755724521044`, 0.9348839126019717], 
             UndirectedEdge[98, 308] -> 
             RGBColor[
              0.20304826815792704`, 0.3307469822107151, 0.9348746705373756], 
             UndirectedEdge[31, 363] -> 
             RGBColor[
              0.6793920980440895, 0.7432878081939467, 0.9278140990011539], 
             UndirectedEdge[286, 386] -> 
             RGBColor[
              0.331585149915525, 0.4616241237277755, 0.94234929043675], 
             UndirectedEdge[137, 138] -> 
             RGBColor[
              0.29077492625511725`, 0.4229532620622423, 0.93987057393605], 
             UndirectedEdge[35, 372] -> 
             RGBColor[
              0.18502327958345532`, 0.31180157636866185`, 0.9338481741036404],
              UndirectedEdge[130, 158] -> 
             RGBColor[
              0.20340188077088672`, 0.3311186514872704, 0.9348948082525605], 
             UndirectedEdge[277, 373] -> 
             RGBColor[
              0.19154984531155025`, 0.31866141075705723`, 0.9342198523666666],
              UndirectedEdge[234, 365] -> 
             RGBColor[
              0.27647661087306347`, 0.4079248260301478, 0.9390563060275041], 
             UndirectedEdge[310, 316] -> 
             RGBColor[
              0.7693289728620583, 0.48993694637010154`, 0.5724844799948403], 
             UndirectedEdge[218, 305] -> 
             RGBColor[
              0.42916789405553485`, 0.5422531768418173, 0.9494057845729981], 
             UndirectedEdge[155, 279] -> 
             RGBColor[
              0.19246829134850796`, 0.31962675577474187`, 0.9342721565097523],
              UndirectedEdge[32, 129] -> 
             RGBColor[
              0.8204275141231614, 0.1580204017101934, 0.16719471663490398`], 
             UndirectedEdge[92, 158] -> 
             RGBColor[
              0.19775538870657966`, 0.32518383031940923`, 0.9345732488827347],
              UndirectedEdge[332, 334] -> 
             RGBColor[
              0.8890082529415364, 0.5076542323723299, 0.23230663812042954`], 
             UndirectedEdge[268, 300] -> 
             RGBColor[
              0.1919105716037125, 0.31904055696148764`, 0.9342403951953585], 
             UndirectedEdge[224, 227] -> 
             RGBColor[
              0.3858696957004528, 0.504223043119987, 0.9462592294929938], 
             UndirectedEdge[25, 91] -> 
             RGBColor[
              0.47826887557608655`, 0.5848930154724093, 0.9527405987202289], 
             UndirectedEdge[74, 304] -> 
             RGBColor[
              0.2654021800822186, 0.39628489710950293`, 0.9384256335771177], 
             UndirectedEdge[86, 397] -> 
             RGBColor[
              0.3161394186740798, 0.4444877390569253, 0.9415027034007689], 
             UndirectedEdge[32, 111] -> 
             RGBColor[
              0.8240654755025505, 0.18598336703701845`, 0.17067843256029655`],
              UndirectedEdge[59, 394] -> 
             RGBColor[
              0.286948743301538, 0.41441249311708334`, 0.9398181488223927], 
             UndirectedEdge[170, 355] -> 
             RGBColor[
              0.2218222289646276, 0.3504796053564232, 0.9359438198317311], 
             UndirectedEdge[9, 56] -> 
             RGBColor[
              0.6023784760141789, 0.6874029877027437, 0.9623014191002394], 
             UndirectedEdge[44, 317] -> 
             RGBColor[
              0.2084087804726259, 0.3363812205295747, 0.9351799437835304], 
             UndirectedEdge[236, 262] -> 
             RGBColor[
              0.4369845815472029, 0.5513866495573997, 0.9494877616771007], 
             UndirectedEdge[119, 346] -> 
             RGBColor[
              0.2216080062797242, 0.35025444373208703`, 0.9359316201667398], 
             UndirectedEdge[80, 244] -> 
             RGBColor[
              0.1927330122426994, 0.31990499421881113`, 0.9342872319730569], 
             UndirectedEdge[20, 360] -> 
             RGBColor[
              0.523690607917635, 0.622017048024192, 0.9563749606192402], 
             UndirectedEdge[196, 206] -> 
             RGBColor[
              0.6365065028818196, 0.7122246861355508, 0.9667719599708235], 
             UndirectedEdge[187, 302] -> 
             RGBColor[
              0.20552429842574232`, 0.33334944701157526`, 0.9350156767981692],
              UndirectedEdge[147, 312] -> 
             RGBColor[
              0.3975158125820031, 0.5104751397594638, 0.9474675883087893], 
             UndirectedEdge[259, 400] -> 
             RGBColor[
              0.8587699196703826, 0.545222069534533, 0.5793492289249624], 
             UndirectedEdge[120, 312] -> 
             RGBColor[
              0.4801821242946682, 0.587765497365623, 0.9525267121427227], 
             UndirectedEdge[52, 60] -> 
             RGBColor[
              0.8480092281788032, 0.880384326820778, 0.9017418370121976], 
             UndirectedEdge[266, 384] -> 
             RGBColor[
              0.7959032258697958, 0.7536598609266292, 0.6159939861993788], 
             UndirectedEdge[135, 393] -> 
             RGBColor[
              0.5286635054610748, 0.6238093444947674, 0.9577562869015417], 
             UndirectedEdge[77, 244] -> 
             RGBColor[
              0.18965577385650711`, 0.31667062156674053`, 0.9341119877993296],
              UndirectedEdge[239, 385] -> 
             RGBColor[
              0.750777447641219, 0.8006120212149852, 0.7940547292395577], 
             UndirectedEdge[278, 296] -> 
             RGBColor[
              0.1835851599868279, 0.3102900214905575, 0.9337662753201197], 
             UndirectedEdge[267, 275] -> 
             RGBColor[
              0.19585412945824818`, 0.323185486302614, 0.9344649749812033], 
             UndirectedEdge[148, 340] -> 
             RGBColor[
              0.263972502592159, 0.39478221542066183`, 0.9383442155590771], 
             UndirectedEdge[202, 212] -> 
             RGBColor[
              0.45268550871471924`, 0.56313574583105, 0.9509994425842794], 
             UndirectedEdge[81, 346] -> 
             RGBColor[
              0.21629108370638292`, 0.34466602099514354`, 0.9356288292918702],
              UndirectedEdge[50, 217] -> 
             RGBColor[
              0.21968733955898895`, 0.34823570123129066`, 0.9358222410383658],
              UndirectedEdge[5, 183] -> 
             RGBColor[
              0.1877508166785864, 0.3146683907914848, 0.9340035033061785], 
             UndirectedEdge[313, 339] -> 
             RGBColor[
              0.3332875570200404, 0.460867825469856, 0.9425394482092617], 
             UndirectedEdge[4, 184] -> 
             RGBColor[
              0.20719899217930893`, 0.3351096563282905, 0.9351110481299474], 
             UndirectedEdge[104, 349] -> 
             RGBColor[
              0.21123195753513827`, 0.3393485586220395, 0.9353407195407242], 
             UndirectedEdge[119, 135] -> 
             RGBColor[
              0.2875725376828968, 0.4171271414972289, 0.9397782828791128], 
             UndirectedEdge[53, 273] -> 
             RGBColor[
              0.4633253395942303, 0.573810427068907, 0.9512742786711021], 
             UndirectedEdge[224, 259] -> 
             RGBColor[
              0.6965860849930616, 0.7612921063995717, 0.9717456253125671], 
             UndirectedEdge[110, 289] -> 
             RGBColor[
              0.6635885313279589, 0.7348104646113509, 0.9687942877706517], 
             UndirectedEdge[59, 155] -> 
             RGBColor[
              0.20108602021263303`, 0.3286845352065056, 0.9347629234197767], 
             UndirectedEdge[5, 29] -> 
             RGBColor[
              0.18632940584411195`, 0.31317439788179996`, 0.9339225560619441],
              UndirectedEdge[119, 311] -> 
             RGBColor[
              0.22119300122602184`, 0.3498182471078057, 0.9359079862428765], 
             UndirectedEdge[68, 72] -> 
             RGBColor[
              0.6435705389401349, 0.7187858683660439, 0.9669572267898132], 
             UndirectedEdge[121, 234] -> 
             RGBColor[
              0.2453302072944222, 0.37518798107295015`, 0.9372825644206755], 
             UndirectedEdge[20, 336] -> 
             RGBColor[
              0.3097133743307097, 0.43584317444763615`, 0.9412059659212678], 
             UndirectedEdge[17, 256] -> 
             RGBColor[
              0.9099828197722593, 0.6023554678641716, 0.47566457355675007`], 
             UndirectedEdge[186, 272] -> 
             RGBColor[
              0.20161622991530592`, 0.3292418192212516, 0.9347931180779689], 
             UndirectedEdge[45, 304] -> 
             RGBColor[
              0.2609958832174149, 0.3916535997292371, 0.9381747014891992], 
             UndirectedEdge[165, 252] -> 
             RGBColor[
              0.21574093049341658`, 0.3440877750865875, 0.9355974988802704], 
             UndirectedEdge[106, 254] -> 
             RGBColor[
              0.18679837373704838`, 0.3136673128715579, 0.9339492630896711], 
             UndirectedEdge[144, 169] -> 
             RGBColor[
              0.5192579762174159, 0.6205960432553745, 0.9552970364739267], 
             UndirectedEdge[191, 355] -> 
             RGBColor[
              0.19607480659810572`, 0.32341743196834305`, 0.9344775422178556],
              UndirectedEdge[96, 377] -> 
             RGBColor[
              0.23316169487877575`, 0.36239810299585723`, 0.9365895856403053],
              UndirectedEdge[110, 303] -> 
             RGBColor[
              0.873446363467674, 0.7484181435664192, 0.6095212570798225], 
             UndirectedEdge[177, 260] -> 
             RGBColor[
              0.18516377148342406`, 0.31194924226322995`, 0.9338561749095045],
              UndirectedEdge[20, 88] -> 
             RGBColor[
              0.40751079531136875`, 0.5273871016357587, 0.9471872054229611], 
             UndirectedEdge[57, 68] -> 
             RGBColor[
              0.584951659196002, 0.6683449078949819, 0.9631304154261922], 
             UndirectedEdge[127, 264] -> 
             RGBColor[
              0.2996738393944105, 0.42947530140255136`, 0.9404810209996725], 
             UndirectedEdge[171, 186] -> 
             RGBColor[
              0.1973172314150955, 0.32472329922528254`, 0.9345482964731804], 
             UndirectedEdge[362, 385] -> 
             RGBColor[
              0.892844244734438, 0.9136671066548807, 0.806798376116899], 
             UndirectedEdge[109, 370] -> 
             RGBColor[
              0.18414849826566793`, 0.3108821257393283, 0.9337983566017154], 
             UndirectedEdge[123, 161] -> 
             RGBColor[
              0.861352076814639, 0.4393326641242953, 0.20508206465224244`], 
             UndirectedEdge[119, 213] -> 
             RGBColor[
              0.2826015926364835, 0.4128215587449884, 0.9394615386563896], 
             UndirectedEdge[140, 360] -> 
             RGBColor[
              0.5345510834209994, 0.6314238460418358, 0.9570669805147731], 
             UndirectedEdge[320, 347] -> 
             RGBColor[
              0.1840162025368019, 0.3107430745402564, 0.9337908225556705], 
             UndirectedEdge[10, 345] -> 
             RGBColor[
              0.8355254140940163, 0.5985125148757706, 0.5861216038325132], 
             UndirectedEdge[169, 383] -> 
             RGBColor[
              0.4077881387207459, 0.527520322736191, 0.9472344418691334], 
             UndirectedEdge[154, 372] -> 
             RGBColor[
              0.18315975702077553`, 0.3098428960011307, 0.9337420492505304], 
             UndirectedEdge[167, 341] -> 
             RGBColor[
              0.2425749937598598, 0.37229207695749733`, 0.9371256590858552], 
             UndirectedEdge[186, 308] -> 
             RGBColor[
              0.20971443584181115`, 0.3377535471059201, 0.9352542989252615], 
             UndirectedEdge[145, 225] -> 
             RGBColor[
              0.22917757181567264`, 0.3582105370485437, 0.9363626957258434], 
             UndirectedEdge[12, 65] -> 
             RGBColor[
              0.30963980079837916`, 0.4365176650238572, 0.941174248166886], 
             UndirectedEdge[274, 288] -> 
             RGBColor[
              0.20843688657003606`, 0.3364107618199823, 0.9351815443841986], 
             UndirectedEdge[143, 171] -> 
             RGBColor[
              0.19347840745274208`, 0.320688451845352, 0.9343296811275554], 
             UndirectedEdge[167, 168] -> 
             RGBColor[
              0.21688542639170627`, 0.3452907128409211, 0.935662676228548], 
             UndirectedEdge[203, 341] -> 
             RGBColor[
              0.2796765309207728, 0.4111713204965401, 0.9392428142535747], 
             UndirectedEdge[114, 299] -> 
             RGBColor[
              0.1875337477163088, 0.31444023754916384`, 0.9339911415499016], 
             UndirectedEdge[154, 231] -> 
             RGBColor[
              0.18878970308862236`, 0.3157603262776354, 0.9340626663503354], 
             UndirectedEdge[218, 384] -> 
             RGBColor[
              0.7469305423915883, 0.7141446268230167, 0.6119725391027997], 
             UndirectedEdge[360, 380] -> 
             RGBColor[
              0.6915688443012366, 0.7589781043767949, 0.9698927773878063], 
             UndirectedEdge[98, 306] -> 
             RGBColor[
              0.20777436312467215`, 0.33571440767249217`, 0.9351438146541007],
              UndirectedEdge[57, 262] -> 
             RGBColor[
              0.35631608788520674`, 0.4830448191840292, 0.9439251239354682], 
             UndirectedEdge[152, 160] -> 
             RGBColor[
              0.19806967394342445`, 0.325514164030168, 0.9345911469620297], 
             UndirectedEdge[311, 354] -> 
             RGBColor[
              0.19934869375531813`, 0.32685849494700814`, 0.9346639852481768],
              UndirectedEdge[287, 303] -> 
             RGBColor[
              0.8556245290555657, 0.372684995897263, 0.19871148964339302`], 
             UndirectedEdge[222, 247] -> 
             RGBColor[
              0.8842131182088144, 0.5486602398250497, 0.5659586027648067], 
             UndirectedEdge[24, 206] -> 
             RGBColor[
              0.3445350824096081, 0.46835060878643464`, 0.9433388530787478], 
             UndirectedEdge[92, 308] -> 
             RGBColor[
              0.20860909712508957`, 0.3365917660321234, 0.9351913515205462], 
             UndirectedEdge[18, 266] -> 
             RGBColor[
              0.8253787823254205, 0.8596851688766582, 0.6977603506868537], 
             UndirectedEdge[28, 314] -> 
             RGBColor[
              0.18717488313259786`, 0.3140630481183549, 0.9339707047427519], 
             UndirectedEdge[128, 139] -> 
             RGBColor[
              0.3054227451460619, 0.43834904844198347`, 0.9407047455523833], 
             UndirectedEdge[160, 181] -> 
             RGBColor[
              0.19370887514270452`, 0.320930687999998, 0.9343428059215524], 
             UndirectedEdge[42, 296] -> 
             RGBColor[
              0.18148102360409654`, 0.30807844074235485`, 0.933646447865914], 
             UndirectedEdge[121, 289] -> 
             RGBColor[
              0.3589692840265578, 0.4787637861846151, 0.9444710719407625], 
             UndirectedEdge[22, 286] -> 
             RGBColor[
              0.2816381839372477, 0.41219449596583724`, 0.9393925574171622], 
             UndirectedEdge[128, 213] -> 
             RGBColor[
              0.3146576489473405, 0.4465145063990592, 0.9412870836406073], 
             UndirectedEdge[178, 398] -> 
             RGBColor[
              0.18190742429108608`, 0.30852661489974587`, 0.9336707307542348],
              UndirectedEdge[6, 129] -> 
             RGBColor[
              0.8727497313117147, 0.5467966411297123, 0.579484556485264], 
             UndirectedEdge[265, 375] -> 
             RGBColor[
              0.20089610111622702`, 0.32848491819461667`, 0.9347521078081966],
              UndirectedEdge[162, 270] -> 
             RGBColor[
              0.20162095796864934`, 0.3292467887050914, 0.9347933873336124], 
             UndirectedEdge[199, 271] -> 
             RGBColor[
              0.9043692525849842, 0.5721827291840494, 0.5015646144777819], 
             UndirectedEdge[60, 72] -> 
             RGBColor[
              0.5862802580314027, 0.6740171687476564, 0.9612505424717664], 
             UndirectedEdge[230, 258] -> 
             RGBColor[
              0.22938899732612533`, 0.3584327586651811, 0.9363747360958877], 
             UndirectedEdge[38, 135] -> 
             RGBColor[
              0.2970405045044002, 0.42707857493039736`, 0.9403174695829958], 
             UndirectedEdge[42, 67] -> 
             RGBColor[
              0.18164605198289263`, 0.3082518960318731, 0.9336558459879488], 
             UndirectedEdge[220, 352] -> 
             RGBColor[
              0.1830449444132805, 0.30972222067111355`, 0.9337355108423835], 
             UndirectedEdge[4, 226] -> 
             RGBColor[
              0.1963748100004493, 0.3237327545655205, 0.9344946269678038], 
             UndirectedEdge[134, 163] -> 
             RGBColor[
              0.17908461226291875`, 0.3055596604815222, 0.9335099757852068], 
             UndirectedEdge[25, 76] -> 
             RGBColor[
              0.32344841914925154`, 0.45219009338865274`, 0.9419182030554161],
              UndirectedEdge[250, 375] -> 
             RGBColor[
              0.19825790374427554`, 0.32571200548532114`, 0.9346018663707272],
              UndirectedEdge[50, 138] -> 
             RGBColor[
              0.26001645706684573`, 0.3906241607457843, 0.9381189246188555], 
             UndirectedEdge[24, 157] -> 
             RGBColor[
              0.2535215613420126, 0.38379761353881126`, 0.9377490499156633], 
             UndirectedEdge[127, 328] -> 
             RGBColor[
              0.2853602010040631, 0.41443075991720546`, 0.9396658804684725], 
             UndirectedEdge[107, 245] -> 
             RGBColor[
              0.20898762068619692`, 0.33698961829462715`, 0.9352129078773759],
              UndirectedEdge[16, 96] -> 
             RGBColor[
              0.22029148033523374`, 0.34887069149186156`, 0.9358566459618267],
              UndirectedEdge[42, 278] -> 
             RGBColor[
              0.18598976689484537`, 0.3128174158117676, 0.9339032141262342], 
             UndirectedEdge[51, 176] -> 
             RGBColor[
              0.19370665948804128`, 0.32092835920646634`, 0.9343426797432972],
              UndirectedEdge[33, 386] -> 
             RGBColor[
              0.2942581498186507, 0.4235465505748645, 0.9401812655620653], 
             UndirectedEdge[78, 187] -> 
             RGBColor[
              0.21840643996372563`, 0.3468893945429439, 0.9357492957013367], 
             UndirectedEdge[107, 150] -> 
             RGBColor[
              0.23074389884075946`, 0.35985684606277935`, 0.936451895732749], 
             UndirectedEdge[312, 360] -> 
             RGBColor[
              0.6052860238543496, 0.6901250393354524, 0.9622831022684131], 
             UndirectedEdge[78, 208] -> 
             RGBColor[
              0.257441859662032, 0.38791809563442126`, 0.9379723051054267], 
             UndirectedEdge[28, 197] -> 
             RGBColor[
              0.19145378666017485`, 0.3185604470239914, 0.9342143819685769], 
             UndirectedEdge[221, 316] -> 
             RGBColor[
              0.5410265117385101, 0.6349350710702945, 0.9583673358965574], 
             UndirectedEdge[243, 383] -> 
             RGBColor[
              0.29485575436090533`, 0.42265924207033345`, 0.9402707855274055],
              UndirectedEdge[83, 332] -> 
             RGBColor[
              0.8843949242801739, 0.5504136015544692, 0.5662686116652167], 
             UndirectedEdge[98, 354] -> 
             RGBColor[
              0.19467499021807763`, 0.3219461361994489, 0.9343978247458558], 
             UndirectedEdge[46, 215] -> 
             RGBColor[
              0.7558037231431869, 0.8091588799312872, 0.9762951098017001], 
             UndirectedEdge[375, 381] -> 
             RGBColor[
              0.196072227977034, 0.3234147216741027, 0.9344773953692003], 
             UndirectedEdge[286, 304] -> 
             RGBColor[
              0.3017569575169641, 0.43334060260203944`, 0.9405382918094687], 
             UndirectedEdge[225, 235] -> 
             RGBColor[
              0.20086558407238086`, 0.32845284284664206`, 0.9347503699076954],
              UndirectedEdge[96, 225] -> 
             RGBColor[
              0.21005566506834547`, 0.33811220065819025`, 0.9352737314249091],
              UndirectedEdge[20, 389] -> 
             RGBColor[
              0.688874491712781, 0.747632448851442, 0.7193091573204213], 
             UndirectedEdge[259, 393] -> 
             RGBColor[
              0.808698190108407, 0.8510901979921818, 0.9814053247963395], 
             UndirectedEdge[97, 166] -> 
             RGBColor[
              0.27189959411517783`, 0.40311409121798647`, 0.9387956516942321],
              UndirectedEdge[115, 334] -> 
             RGBColor[
              0.9576597296930937, 0.8685855926092536, 0.2913334520501617], 
             UndirectedEdge[251, 260] -> 
             RGBColor[
              0.1869284496057658, 0.31380403085686637`, 0.9339566707179645], 
             UndirectedEdge[119, 344] -> 
             RGBColor[
              0.2156761634002051, 0.3440197007651513, 0.9355938104901265], 
             UndirectedEdge[329, 341] -> 
             RGBColor[
              0.2558412218032698, 0.3862357237585604, 0.9378811511473018], 
             UndirectedEdge[283, 334] -> 
             RGBColor[
              0.9460670651662169, 0.8226245407866379, 0.2820057220570269], 
             UndirectedEdge[1, 5] -> 
             RGBColor[
              0.18431548798727523`, 0.3110576425244974, 0.9338078664193217], 
             UndirectedEdge[364, 391] -> 
             RGBColor[
              0.8707862783740112, 0.44118719063375156`, 0.21128740006323304`],
              UndirectedEdge[48, 295] -> 
             RGBColor[
              0.19691998178395526`, 0.3243057646758728, 0.9345256736943651], 
             UndirectedEdge[105, 199] -> 
             RGBColor[
              0.9870190215241651, 0.9889000460513815, 0.8647919372474027], 
             UndirectedEdge[281, 293] -> 
             RGBColor[
              0.356440478793437, 0.4831525603366694, 0.9439330500141462], 
             UndirectedEdge[216, 358] -> 
             RGBColor[
              0.24670674727990904`, 0.37663481187537284`, 0.9373609563364405],
              UndirectedEdge[100, 206] -> 
             RGBColor[
              0.40830029738828666`, 0.5280709286532568, 0.947237511797173], 
             UndirectedEdge[168, 341] -> 
             RGBColor[
              0.22365393842066325`, 0.35240484813180395`, 0.936048132975481], 
             UndirectedEdge[199, 259] -> 
             RGBColor[
              0.9420801867046171, 0.9545306309034027, 0.913114429015637], 
             UndirectedEdge[19, 24] -> 
             RGBColor[
              0.22984730742841403`, 0.35891447164122536`, 0.936400836178204], 
             UndirectedEdge[136, 299] -> 
             RGBColor[
              0.1855129526762866, 0.3123162538362948, 0.9338760602618706], 
             UndirectedEdge[64, 123] -> 
             RGBColor[
              0.9178715311357676, 0.6596421800395433, 0.31164482201230714`], 
             UndirectedEdge[101, 334] -> 
             RGBColor[
              0.9070926668350056, 0.6466589621982325, 0.24962429328823976`], 
             UndirectedEdge[2, 328] -> 
             RGBColor[
              0.2165885293871429, 0.3449786552647677, 0.935645768383358], 
             UndirectedEdge[235, 349] -> 
             RGBColor[
              0.19583192039754477`, 0.3231621431716789, 0.9344637102080516], 
             UndirectedEdge[45, 290] -> 
             RGBColor[
              0.24862549482263574`, 0.3786515371983993, 0.9374702261704662], 
             UndirectedEdge[225, 327] -> 
             RGBColor[
              0.19712268368204472`, 0.3245188172228074, 0.9345372172675908], 
             UndirectedEdge[24, 386] -> 
             RGBColor[
              0.3010543278758621, 0.4306897646155703, 0.940568297848379], 
             UndirectedEdge[363, 393] -> 
             RGBColor[
              0.5482487832688899, 0.640773127747212, 0.9590042434848745], 
             UndirectedEdge[2, 258] -> 
             RGBColor[
              0.2197390144926751, 0.34829001486297484`, 0.935825183849393], 
             UndirectedEdge[8, 234] -> 
             RGBColor[
              0.2512674523014992, 0.38142840201846384`, 0.9376206817404615], 
             UndirectedEdge[44, 151] -> 
             RGBColor[
              0.21796286839338874`, 0.3464231726984579, 0.9357240349566114], 
             UndirectedEdge[253, 283] -> 
             RGBColor[
              0.878557469851581, 0.4812239884723157, 0.21791952880036536`], 
             UndirectedEdge[257, 360] -> 
             RGBColor[
              0.816087887153252, 0.8565915861588391, 0.9518343139701578], 
             UndirectedEdge[65, 358] -> 
             RGBColor[
              0.3270456066713938, 0.4548122705882284, 0.942165483061772], 
             UndirectedEdge[282, 340] -> 
             RGBColor[
              0.29320777122887487`, 0.42492993475416496`, 0.9400303722049579],
              UndirectedEdge[256, 316] -> 
             RGBColor[
              0.8522226042580414, 0.8830674650503693, 0.8745751101286188], 
             UndirectedEdge[96, 182] -> 
             RGBColor[
              0.2267284521296566, 0.35563635697538404`, 0.9362232219828728], 
             UndirectedEdge[2, 106] -> 
             RGBColor[
              0.19417223523988333`, 0.32141770884085996`, 0.9343691935936069],
              UndirectedEdge[210, 279] -> 
             RGBColor[
              0.2223588131160111, 0.3510435893209275, 0.9359743775053473], 
             UndirectedEdge[279, 371] -> 
             RGBColor[
              0.1895350584309733, 0.3165437420007044, 0.9341051132344278], 
             UndirectedEdge[271, 353] -> 
             RGBColor[
              0.9066312764528914, 0.571373609454521, 0.33726849330509057`], 
             UndirectedEdge[306, 311] -> 
             RGBColor[
              0.21244806666191265`, 0.3406267664200514, 0.9354099751564218], 
             UndirectedEdge[64, 312] -> 
             RGBColor[
              0.7702008939642393, 0.8151650470913949, 0.695936819489472], 
             UndirectedEdge[137, 210] -> 
             RGBColor[
              0.2691626848877073, 0.40023742608984725`, 0.9386397887626219], 
             UndirectedEdge[264, 394] -> 
             RGBColor[
              0.30880202077051594`, 0.4373816733147978, 0.941062660645224], 
             UndirectedEdge[199, 224] -> 
             RGBColor[
              0.7432416506659434, 0.7963714338733744, 0.8949724605475597], 
             UndirectedEdge[61, 301] -> 
             RGBColor[
              0.23356716082772205`, 0.3628242734162258, 0.9366126763262647], 
             UndirectedEdge[48, 103] -> 
             RGBColor[
              0.2013643551866071, 0.328977082911609, 0.9347787741847848], 
             UndirectedEdge[7, 14] -> 
             RGBColor[
              0.29679890469924086`, 0.4265200793940456, 0.9403148622219284], 
             UndirectedEdge[88, 195] -> 
             RGBColor[
              0.42750707901937735`, 0.5447068775411936, 0.948461350938816], 
             UndirectedEdge[211, 341] -> 
             RGBColor[
              0.24091627830701134`, 0.3705486618479197, 0.9370311976946651], 
             UndirectedEdge[84, 185] -> 
             RGBColor[
              0.20341836522778634`, 0.3311359776966468, 0.9348957470179945], 
             UndirectedEdge[368, 387] -> 
             RGBColor[
              0.18468757746568928`, 0.3114487321581461, 0.9338290563646603], 
             UndirectedEdge[134, 171] -> 
             RGBColor[
              0.18358417843459812`, 0.31028898981693004`, 0.9337662194221723],
              UndirectedEdge[41, 295] -> 
             RGBColor[
              0.19034802985855803`, 0.31739822651646155`, 0.9341514107545453],
              UndirectedEdge[77, 388] -> 
             RGBColor[
              0.23386679686193323`, 0.36313920988620363`, 0.9366297401551412],
              UndirectedEdge[142, 273] -> 
             RGBColor[
              0.4991027451822828, 0.6042331187182427, 0.9537103428557971], 
             UndirectedEdge[64, 140] -> 
             RGBColor[
              0.6994659535308891, 0.7564638537977784, 0.690720697735832], 
             UndirectedEdge[150, 157] -> 
             RGBColor[
              0.24263401195527415`, 0.3723541088228476, 0.9371290200847746], 
             UndirectedEdge[210, 264] -> 
             RGBColor[
              0.2528298194491141, 0.3830705489504057, 0.9377096562382032], 
             UndirectedEdge[202, 309] -> 
             RGBColor[
              0.5124790971855998, 0.6108362268976354, 0.9562827357512269], 
             UndirectedEdge[105, 287] -> 
             RGBColor[
              0.9013106453354156, 0.5611585668627788, 0.528730305122088], 
             UndirectedEdge[157, 160] -> 
             RGBColor[
              0.22107841637049833`, 0.349697811159551, 0.9359014608048675], 
             UndirectedEdge[153, 379] -> 
             RGBColor[
              0.19405975897206282`, 0.32129948915197337`, 0.9343627882365483],
              UndirectedEdge[207, 387] -> 
             RGBColor[
              0.18852965084716983`, 0.3154869948836043, 0.9340478567598975], 
             UndirectedEdge[93, 264] -> 
             RGBColor[
              0.3012538452175734, 0.43084382303317337`, 0.9405816975735801], 
             UndirectedEdge[202, 365] -> 
             RGBColor[
              0.31680424057691503`, 0.4485693265510483, 0.9414167025039941], 
             UndirectedEdge[138, 230] -> 
             RGBColor[
              0.2550152839737512, 0.38536761073225334`, 0.9378341152097762], 
             UndirectedEdge[5, 291] -> 
             RGBColor[
              0.19113912643877223`, 0.3182297191806869, 0.9341964625344661], 
             UndirectedEdge[241, 360] -> 
             RGBColor[
              0.4718334584098283, 0.5745274932673213, 0.9531648972863125], 
             UndirectedEdge[299, 300] -> 
             RGBColor[
              0.19227535029574405`, 0.31942396249511773`, 0.934261168802228], 
             UndirectedEdge[9, 266] -> 
             RGBColor[
              0.6722902895010364, 0.7439175508444353, 0.9679712712136599], 
             UndirectedEdge[226, 322] -> 
             RGBColor[
              0.1935079091107788, 0.32071945995846174`, 0.9343313612033369], 
             UndirectedEdge[175, 216] -> 
             RGBColor[
              0.20297653411671235`, 0.3306715851851976, 0.9348705853898494], 
             UndirectedEdge[115, 257] -> 
             RGBColor[
              0.9622640683610495, 0.9182194829930534, 0.6096923191590835], 
             UndirectedEdge[146, 275] -> 
             RGBColor[
              0.1966367657635329, 0.324008086681476, 0.9345095449609826], 
             UndirectedEdge[64, 101] -> 
             RGBColor[
              0.9232794978996539, 0.7012101823729198, 0.31682349709282953`], 
             UndirectedEdge[79, 390] -> 
             RGBColor[
              0.2060170491676479, 0.3338673592835195, 0.9350437382239613], 
             UndirectedEdge[98, 378] -> 
             RGBColor[
              0.21674290293340537`, 0.34514091164973765`, 0.9356545597284425],
              UndirectedEdge[37, 80] -> 
             RGBColor[
              0.24371904320437376`, 0.3734945454606058, 0.9371908110092508], 
             UndirectedEdge[344, 354] -> 
             RGBColor[
              0.1938318559295014, 0.32105994860435383`, 0.9343498094954268], 
             UndirectedEdge[119, 227] -> 
             RGBColor[
              0.25689083303762017`, 0.3873389317150586, 0.9379409249543373], 
             UndirectedEdge[81, 166] -> 
             RGBColor[
              0.2371652059079643, 0.3666060469247946, 0.9368175796707537], 
             UndirectedEdge[192, 221] -> 
             RGBColor[
              0.3140891047086496, 0.4418027488287358, 0.9414053462268441], 
             UndirectedEdge[242, 331] -> 
             RGBColor[
              0.2906837062391053, 0.4199308888343219, 0.9399725324164205], 
             UndirectedEdge[225, 322] -> 
             RGBColor[
              0.2017966288426081, 0.3294314299317988, 0.9348033915300026], 
             UndirectedEdge[165, 170] -> 
             RGBColor[
              0.23052227294686206`, 0.35962390319639986`, 0.9364392744659576],
              UndirectedEdge[41, 250] -> 
             RGBColor[
              0.1942575833696331, 0.32150741513661096`, 0.934374054043335], 
             UndirectedEdge[31, 393] -> 
             RGBColor[
              0.8531150739602782, 0.8852437730014981, 0.9417329113283139], 
             UndirectedEdge[140, 312] -> 
             RGBColor[
              0.4770815978352943, 0.5850799771835042, 0.9523291493384193], 
             UndirectedEdge[56, 100] -> 
             RGBColor[
              0.4530551393941151, 0.565068246426121, 0.9505774993750733], 
             UndirectedEdge[89, 183] -> 
             RGBColor[
              0.21045489979042858`, 0.338531821664043, 0.935296467251717], 
             UndirectedEdge[39, 210] -> 
             RGBColor[
              0.22192743235245416`, 0.35059018078730897`, 0.9359498110090333],
              UndirectedEdge[34, 321] -> 
             RGBColor[
              0.18374554341254123`, 0.3104585946398788, 0.9337754089189481], 
             UndirectedEdge[148, 301] -> 
             RGBColor[
              0.25321055434935075`, 0.3834707254705414, 0.9377313385275249], 
             UndirectedEdge[136, 155] -> 
             RGBColor[
              0.18426793717549678`, 0.3110076636064226, 0.933805158470936], 
             UndirectedEdge[51, 205] -> 
             RGBColor[
              0.19318129293550862`, 0.32037616564959115`, 0.9343127608953405],
              UndirectedEdge[11, 123] -> 
             RGBColor[
              0.8581753215010539, 0.6172298567057516, 0.5883641909402252], 
             UndirectedEdge[223, 400] -> 
             RGBColor[
              0.8406657720719041, 0.3123044383826159, 0.18652492711661786`], 
             UndirectedEdge[6, 201] -> 
             RGBColor[
              0.7959386825090102, 0.8413708229845736, 0.9800676455168078], 
             UndirectedEdge[201, 273] -> 
             RGBColor[
              0.5948799673171399, 0.6816316125645953, 0.9614948857902279], 
             UndirectedEdge[54, 196] -> 
             RGBColor[
              0.8961892019683437, 0.8555483275728113, 0.6311082747514651], 
             UndirectedEdge[84, 288] -> 
             RGBColor[
              0.21401051896422651`, 0.342269002854981, 0.9354989545035975], 
             UndirectedEdge[177, 248] -> 
             RGBColor[
              0.18215464872777276`, 0.30878646345763827`, 0.9336848098201683],
              UndirectedEdge[76, 117] -> 
             RGBColor[
              0.4207333030341396, 0.5335965741048728, 0.9489064510842957], 
             UndirectedEdge[342, 348] -> 
             RGBColor[
              0.1937491041812462, 0.3209729712701737, 0.9343450969057838], 
             UndirectedEdge[332, 389] -> 
             RGBColor[
              0.905464097691441, 0.5627808456183245, 0.32878632140514163`], 
             UndirectedEdge[68, 236] -> 
             RGBColor[
              0.6656201528579981, 0.7366867382683524, 0.9686930531678246], 
             UndirectedEdge[84, 318] -> 
             RGBColor[
              0.2138717930117836, 0.3421231930832301, 0.9354910542658326], 
             UndirectedEdge[15, 372] -> 
             RGBColor[
              0.1810383624053819, 0.30761317575616476`, 0.9336212389655058], 
             UndirectedEdge[88, 189] -> 
             RGBColor[
              0.331784795723977, 0.4548098720727408, 0.9426178463888004], 
             UndirectedEdge[364, 380] -> 
             RGBColor[
              0.8208602613542741, 0.753663537851497, 0.6141649050014586], 
             UndirectedEdge[103, 295] -> 
             RGBColor[
              0.1903453971129866, 0.3173954593339403, 0.9341512608235798], 
             UndirectedEdge[20, 257] -> 
             RGBColor[
              0.6770229856308323, 0.7421397259892473, 0.9411883411446311], 
             UndirectedEdge[12, 24] -> 
             RGBColor[
              0.25148362362516946`, 0.3816556117856949, 0.9376329923775478], 
             UndirectedEdge[152, 157] -> 
             RGBColor[
              0.22385261786682037`, 0.3526136728267195, 0.9360594474760198], 
             UndirectedEdge[26, 70] -> 
             RGBColor[
              0.1896105861046007, 0.3166231263744179, 0.9341094144237078], 
             UndirectedEdge[33, 74] -> 
             RGBColor[
              0.24756162893783695`, 0.3775333467004828, 0.9374096405821755], 
             UndirectedEdge[124, 238] -> 
             RGBColor[
              0.21375043106969976`, 0.3419956339873084, 0.9354841428827698], 
             UndirectedEdge[148, 339] -> 
             RGBColor[
              0.3192552716311131, 0.4461190038278132, 0.9417403303152683], 
             UndirectedEdge[175, 229] -> 
             RGBColor[
              0.1940292110138258, 0.32126738131101384`, 0.9343610485755184], 
             UndirectedEdge[105, 337] -> 
             RGBColor[
              0.9711407562018461, 0.97781294412538, 0.9254748728105828], 
             UndirectedEdge[158, 306] -> 
             RGBColor[
              0.20672015111524922`, 0.33460636400968674`, 0.935083778839731], 
             UndirectedEdge[136, 268] -> 
             RGBColor[
              0.18514817398425504`, 0.3119328483026647, 0.9338552866550012], 
             UndirectedEdge[133, 278] -> 
             RGBColor[
              0.18574944160901402`, 0.31256481869885566`, 0.9338895279567354],
              UndirectedEdge[197, 254] -> 
             RGBColor[
              0.18919463052287389`, 0.31618593068491585`, 0.9340857263686796],
              UndirectedEdge[296, 398] -> 
             RGBColor[
              0.17994179284220208`, 0.3064606116187368, 0.933558790951112], 
             UndirectedEdge[10, 271] -> 
             RGBColor[
              0.8314849257202783, 0.24301251263429177`, 0.17778330646786333`],
              UndirectedEdge[221, 399] -> 
             RGBColor[
              0.36464378874039466`, 0.49025785510237774`, 0.9444557576700642],
              UndirectedEdge[187, 388] -> 
             RGBColor[
              0.2435643246839634, 0.37333192648593383`, 0.937182000018399], 
             UndirectedEdge[143, 186] -> 
             RGBColor[
              0.20274228315425485`, 0.3304253725712859, 0.9348572451440806], 
             UndirectedEdge[372, 387] -> 
             RGBColor[
              0.18274442511282618`, 0.30940635583231196`, 0.9337183967128011],
              UndirectedEdge[147, 255] -> 
             RGBColor[
              0.3107019378391358, 0.4378471817176799, 0.9412269310789902], 
             UndirectedEdge[27, 86] -> 
             RGBColor[
              0.23656599040606416`, 0.3659762334398404, 0.9367834552343804], 
             UndirectedEdge[19, 157] -> 
             RGBColor[
              0.2231871063802957, 0.35191417805851677`, 0.9360215475813982], 
             UndirectedEdge[192, 208] -> 
             RGBColor[
              0.27634222217301546`, 0.40778357498566165`, 0.9390486527898467],
              UndirectedEdge[88, 89] -> 
             RGBColor[
              0.33131087657095276`, 0.4543117529947025, 0.9425908573941362], 
             UndirectedEdge[54, 332] -> 
             RGBColor[
              0.8830293594773344, 0.4852062873571179, 0.22095265658473165`], 
             UndirectedEdge[282, 301] -> 
             RGBColor[
              0.2824458229860667, 0.41361844480404447`, 0.9394174951734057], 
             UndirectedEdge[264, 328] -> 
             RGBColor[
              0.24566528906336602`, 0.3755401732575213, 0.9373016468317077], 
             UndirectedEdge[124, 156] -> 
             RGBColor[
              0.21424517968646528`, 0.3425156461524031, 0.9355123180845796], 
             UndirectedEdge[64, 120] -> 
             RGBColor[
              0.7025664799902631, 0.759149373979897, 0.6909182605401354], 
             UndirectedEdge[55, 236] -> 
             RGBColor[
              0.6566866391587384, 0.7296947127190476, 0.9678061194855357], 
             UndirectedEdge[11, 196] -> 
             RGBColor[
              0.8586587168624804, 0.8901351694289188, 0.9863808290196707], 
             UndirectedEdge[223, 319] -> 
             RGBColor[
              0.845830354553812, 0.35200168247303465`, 0.19147053713385456`], 
             UndirectedEdge[61, 70] -> 
             RGBColor[
              0.20711529305388426`, 0.33502168324063814`, 0.9351062815885762],
              UndirectedEdge[307, 343] -> 
             RGBColor[
              0.1898749181249935, 0.3169009560874688, 0.9341244677412249], 
             UndirectedEdge[13, 87] -> 
             RGBColor[
              0.2001057560025477, 0.3276542153693653, 0.9347070988231834], 
             UndirectedEdge[119, 128] -> 
             RGBColor[
              0.2718458799395796, 0.4030576342137573, 0.9387925927513947], 
             UndirectedEdge[92, 130] -> 
             RGBColor[
              0.2100169217474722, 0.33807147897148404`, 0.935271525050101], 
             UndirectedEdge[263, 359] -> 
             RGBColor[
              0.31376085658735253`, 0.4455463754257799, 0.941236947982536], 
             UndirectedEdge[22, 304] -> 
             RGBColor[
              0.2621517349847551, 0.3928684732219464, 0.9382405255374198], 
             UndirectedEdge[139, 306] -> 
             RGBColor[
              0.2646217542710957, 0.39546462010015837`, 0.9383811894817108], 
             UndirectedEdge[1, 73] -> 
             RGBColor[
              0.19016251964762415`, 0.3172032435227433, 0.9341408462224705], 
             UndirectedEdge[7, 13] -> 
             RGBColor[
              0.23415570368153021`, 0.3634428692713504, 0.9366461929711178], 
             UndirectedEdge[170, 335] -> 
             RGBColor[
              0.21688414248716403`, 0.34528936337584293`, 0.9356626031120838],
              UndirectedEdge[276, 361] -> 
             RGBColor[
              0.3943096577609078, 0.5159529397980152, 0.9463460406115533], 
             UndirectedEdge[46, 345] -> 
             RGBColor[
              0.8168101022247779, 0.8568829940339906, 0.982358282576511], 
             UndirectedEdge[36, 301] -> 
             RGBColor[
              0.2477609938146631, 0.37774289182649035`, 0.9374209941169768], 
             UndirectedEdge[50, 328] -> 
             RGBColor[
              0.23123968531368772`, 0.36037794908050486`, 0.9364801300389318],
              UndirectedEdge[55, 83] -> 
             RGBColor[
              0.8773611303882973, 0.9047851000408222, 0.9744632955960668], 
             UndirectedEdge[143, 306] -> 
             RGBColor[
              0.21060170684620283`, 0.33868612518776664`, 0.9353048276963617],
              UndirectedEdge[32, 400] -> 
             RGBColor[
              0.8218170423470171, 0.16870092453389818`, 0.1685253304313158], 
             UndirectedEdge[20, 195] -> 
             RGBColor[
              0.40462199010322386`, 0.5248849637600351, 0.9470031333095683], 
             UndirectedEdge[203, 266] -> 
             RGBColor[
              0.4841156347335931, 0.5879317505125805, 0.9537717798510146], 
             UndirectedEdge[255, 359] -> 
             RGBColor[
              0.3499392226187198, 0.4775214990007658, 0.9435187957195283], 
             UndirectedEdge[128, 215] -> 
             RGBColor[
              0.5049864538136, 0.6035289290681363, 0.9559781758101122], 
             UndirectedEdge[230, 328] -> 
             RGBColor[
              0.2262385122205931, 0.35512139906697393`, 0.9361953206298528], 
             UndirectedEdge[44, 146] -> 
             RGBColor[
              0.21372136571514777`, 0.3419650844568244, 0.9354824876538264], 
             UndirectedEdge[56, 206] -> 
             RGBColor[
              0.4736432444349138, 0.5829006282242136, 0.9518893552229266], 
             UndirectedEdge[55, 196] -> 
             RGBColor[
              0.8239309669516679, 0.8625755200904117, 0.9830336180607375], 
             UndirectedEdge[93, 188] -> 
             RGBColor[
              0.3091689920495968, 0.43916314420292457`, 0.9410324534762535], 
             UndirectedEdge[52, 271] -> 
             RGBColor[
              0.9044987065001195, 0.5722362617047718, 0.4994192280879955], 
             UndirectedEdge[193, 253] -> 
             RGBColor[
              0.8315602657829888, 0.5341252723143658, 0.5780805506738103], 
             UndirectedEdge[120, 193] -> 
             RGBColor[
              0.6252379224927019, 0.7026774950776031, 0.9659558403883122], 
             UndirectedEdge[28, 217] -> 
             RGBColor[
              0.19992147826691017`, 0.32746052778532697`, 0.9346966044787532],
              UndirectedEdge[124, 245] -> 
             RGBColor[
              0.21075638483913717`, 0.33884870156549185`, 0.9353136363792337],
              UndirectedEdge[36, 282] -> 
             RGBColor[
              0.28033871258182136`, 0.4114037381706667, 0.9392974983530744], 
             UndirectedEdge[276, 339] -> 
             RGBColor[
              0.38050139833268903`, 0.5039929195045905, 0.9454661905309516], 
             UndirectedEdge[377, 388] -> 
             RGBColor[
              0.26273780008050557`, 0.39348446479625343`, 0.9382739010776171],
              UndirectedEdge[129, 131] -> 
             RGBColor[
              0.8167235345760251, 0.5021703426652091, 0.5741281307411844], 
             UndirectedEdge[69, 142] -> 
             RGBColor[
              0.5234887787089056, 0.6240307993134462, 0.955630100743997], 
             UndirectedEdge[11, 118] -> 
             RGBColor[
              0.6153201099210919, 0.6928744863891039, 0.9658821576068201], 
             UndirectedEdge[53, 293] -> 
             RGBColor[
              0.35836727987096656`, 0.4848214585861875, 0.944055824075003], 
             UndirectedEdge[2, 137] -> 
             RGBColor[
              0.24723503321608348`, 0.3771900738895551, 0.9373910414389766], 
             UndirectedEdge[102, 213] -> 
             RGBColor[
              0.33722405994131943`, 0.4665082641722599, 0.9427085967973012], 
             UndirectedEdge[269, 362] -> 
             RGBColor[
              0.5723371220999356, 0.658694027276514, 0.9617848366135348], 
             UndirectedEdge[147, 242] -> 
             RGBColor[
              0.29380682218946674`, 0.42321348171513995`, 0.9401503892495575],
              UndirectedEdge[58, 220] -> 
             RGBColor[
              0.186453938859043, 0.31330528997634166`, 0.9339296480329143], 
             UndirectedEdge[177, 285] -> 
             RGBColor[
              0.18283630546897034`, 0.3095029279121705, 0.9337236291631588], 
             UndirectedEdge[213, 215] -> 
             RGBColor[
              0.5157421665105038, 0.6132928535993672, 0.9566471217151071], 
             UndirectedEdge[61, 382] -> 
             RGBColor[
              0.2696810924925139, 0.39954800963710424`, 0.9387145049212492], 
             UndirectedEdge[83, 123] -> 
             RGBColor[
              0.8970713714097568, 0.6478503290469954, 0.5784075917525047], 
             UndirectedEdge[207, 368] -> 
             RGBColor[
              0.18767517326657374`, 0.3145888847693901, 0.9339991955257688], 
             UndirectedEdge[117, 377] -> 
             RGBColor[
              0.40661285819624315`, 0.5187550912923315, 0.9481023126401036], 
             UndirectedEdge[207, 392] -> 
             RGBColor[
              0.1972896880999786, 0.3246943494547476, 0.9345467279221311], 
             UndirectedEdge[43, 325] -> 
             RGBColor[
              0.21648460691960775`, 0.3448694261623232, 0.9356398501525713], 
             UndirectedEdge[83, 196] -> 
             RGBColor[
              0.8975547667711833, 0.9207556417701627, 0.9764242298319501], 
             UndirectedEdge[81, 130] -> 
             RGBColor[
              0.2224096961469096, 0.35109707061257234`, 0.9359772752186821], 
             UndirectedEdge[204, 229] -> 
             RGBColor[
              0.18893129430891603`, 0.3159091476275659, 0.9340707297608657], 
             UndirectedEdge[44, 267] -> 
             RGBColor[
              0.21293872940986303`, 0.3411424840779623, 0.935437917674047], 
             UndirectedEdge[38, 130] -> 
             RGBColor[
              0.23719458554175432`, 0.36663692678268434`, 0.9368192527974348],
              UndirectedEdge[226, 318] -> 
             RGBColor[
              0.20268055409019498`, 0.33036049141111024`, 0.9348537297652024],
              UndirectedEdge[202, 362] -> 
             RGBColor[
              0.5594312028417849, 0.6475155686854668, 0.9609624828506617], 
             UndirectedEdge[59, 230] -> 
             RGBColor[
              0.21869887314196257`, 0.34719676035460534`, 0.9357659493382211],
              UndirectedEdge[131, 394] -> 
             RGBColor[
              0.585868010689025, 0.6694437636125451, 0.9630575794667262], 
             UndirectedEdge[93, 142] -> 
             RGBColor[
              0.4083441914838143, 0.5275430486662767, 0.9473966682274677], 
             UndirectedEdge[301, 340] -> 
             RGBColor[
              0.26063005246171667`, 0.3912690884099886, 0.9381538679688604], 
             UndirectedEdge[16, 76] -> 
             RGBColor[
              0.2559443426940643, 0.3863441103530275, 0.937887023729479], 
             UndirectedEdge[25, 239] -> 
             RGBColor[
              0.43554957397249955`, 0.5502115619480115, 0.9493775788120367], 
             UndirectedEdge[46, 60] -> 
             RGBColor[
              0.7562801355297237, 0.809531056908518, 0.9763425941360632], 
             UndirectedEdge[57, 297] -> 
             RGBColor[
              0.3224295006293375, 0.45256728530617585`, 0.9418071536579791], 
             UndirectedEdge[221, 351] -> 
             RGBColor[
              0.33973329445254913`, 0.4686816369880935, 0.9428684830015278], 
             UndirectedEdge[365, 377] -> 
             RGBColor[
              0.2803555468892034, 0.41200183372185906`, 0.9392772056952516], 
             UndirectedEdge[334, 366] -> 
             RGBColor[
              0.9767558229939741, 0.9327621554008622, 0.40603042724612426`], 
             UndirectedEdge[209, 290] -> 
             RGBColor[
              0.2612876379800373, 0.3919602524830736, 0.938191316491318], 
             UndirectedEdge[174, 313] -> 
             RGBColor[
              0.35122662219084355`, 0.47640574207717373`, 0.9436825095790529],
              UndirectedEdge[56, 358] -> 
             RGBColor[
              0.3979975915234898, 0.5145002367878451, 0.9471747294166126], 
             UndirectedEdge[304, 338] -> 
             RGBColor[
              0.24620331291395298`, 0.37610567043717064`, 0.9373322864940637],
              UndirectedEdge[130, 306] -> 
             RGBColor[
              0.21898168415614172`, 0.3474940126617616, 0.9357820550070972], 
             UndirectedEdge[11, 206] -> 
             RGBColor[
              0.6510406164097462, 0.7238137937447175, 0.9681582366938735], 
             UndirectedEdge[120, 140] -> 
             RGBColor[
              0.409447183861318, 0.5290643040720063, 0.9473105903890827], 
             UndirectedEdge[193, 356] -> 
             RGBColor[
              0.8916558476180196, 0.9161964476590825, 0.9808695463369558], 
             UndirectedEdge[166, 246] -> 
             RGBColor[
              0.23093801406837325`, 0.3600608734746177, 0.9364629503077938], 
             UndirectedEdge[76, 182] -> 
             RGBColor[
              0.2623813144884871, 0.39310977583655005`, 0.9382535997505249], 
             UndirectedEdge[6, 364] -> 
             RGBColor[
              0.9237508221541206, 0.8349006337052781, 0.6241923325830713], 
             UndirectedEdge[288, 318] -> 
             RGBColor[
              0.21359522081764215`, 0.3418324981714975, 0.9354753038885282], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.285788273116509, 0.4171315718147177, 0.9396078427636225], 
             UndirectedEdge[128, 151] -> 
             RGBColor[
              0.2557571228947407, 0.38614733047351757`, 0.9378763618388744], 
             UndirectedEdge[30, 379] -> 
             RGBColor[
              0.19158357625518677`, 0.31869686411748455`, 0.9342217732940062],
              UndirectedEdge[70, 90] -> 
             RGBColor[
              0.2062666965089075, 0.33412975446773896`, 0.9350579552707259], 
             UndirectedEdge[137, 394] -> 
             RGBColor[
              0.32513488620910913`, 0.45454855045423936`, 0.9419927931696428],
              UndirectedEdge[25, 269] -> 
             RGBColor[
              0.35868258725721747`, 0.48509456199634804`, 0.9440759151828396],
              UndirectedEdge[38, 227] -> 
             RGBColor[
              0.2663587998591236, 0.39729036514822713`, 0.9384801116582203], 
             UndirectedEdge[128, 135] -> 
             RGBColor[
              0.31962859399375376`, 0.45082008915129973`, 0.9416038278633306],
              UndirectedEdge[129, 303] -> 
             RGBColor[
              0.8566331099862248, 0.3804373908932912, 0.19967730788162147`], 
             UndirectedEdge[132, 299] -> 
             RGBColor[
              0.19063186344337624`, 0.3176965536101942, 0.9341675746573066], 
             UndirectedEdge[352, 396] -> 
             RGBColor[
              0.18539177638104404`, 0.312188889866974, 0.9338691594511209], 
             UndirectedEdge[155, 268] -> 
             RGBColor[
              0.18677990471826675`, 0.31364790076181503`, 0.9339482113063738],
              UndirectedEdge[8, 16] -> 
             RGBColor[
              0.24227617377409713`, 0.3719779982061794, 0.9371086417297306], 
             UndirectedEdge[213, 378] -> 
             RGBColor[
              0.2828251978811075, 0.4130565820344796, 0.9394742726442766], 
             UndirectedEdge[164, 230] -> 
             RGBColor[
              0.21805906979477002`, 0.3465242864708308, 0.9357295134841028], 
             UndirectedEdge[218, 339] -> 
             RGBColor[
              0.47111694262023773`, 0.5795753796238241, 0.9520425636736524], 
             UndirectedEdge[101, 366] -> 
             RGBColor[
              0.9236369022984421, 0.7019746342428002, 0.3557247602566589], 
             UndirectedEdge[169, 361] -> 
             RGBColor[
              0.4334163894448813, 0.5497182254001022, 0.948867451343103], 
             UndirectedEdge[65, 341] -> 
             RGBColor[
              0.31291881126268356`, 0.4399641129231123, 0.9413609829619669], 
             UndirectedEdge[46, 353] -> 
             RGBColor[
              0.8993981375114619, 0.9180011012561393, 0.7445005138120175], 
             UndirectedEdge[279, 300] -> 
             RGBColor[
              0.1975989582339537, 0.32501941197441453`, 0.9345643403987369], 
             UndirectedEdge[203, 358] -> 
             RGBColor[
              0.29380332632948314`, 0.42601947816165614`, 0.9400473143533797],
              UndirectedEdge[81, 243] -> 
             RGBColor[
              0.2302749655066254, 0.3593639673965138, 0.9364251906730947], 
             UndirectedEdge[176, 320] -> 
             RGBColor[
              0.18495626411433608`, 0.3117311388615913, 0.9338443576718145], 
             UndirectedEdge[112, 248] -> 
             RGBColor[
              0.18167669359362687`, 0.3082841023075451, 0.9336575909823499], 
             UndirectedEdge[58, 179] -> 
             RGBColor[
              0.21000836012355356`, 0.3380624801619072, 0.9352710374782847], 
             UndirectedEdge[23, 213] -> 
             RGBColor[
              0.2686665233533321, 0.39817491739397315`, 0.9386679570758016], 
             UndirectedEdge[243, 326] -> 
             RGBColor[
              0.23648276332684243`, 0.36588875650267677`, 0.9367787155753422],
              UndirectedEdge[269, 377] -> 
             RGBColor[
              0.30404872534557215`, 0.4327759904647185, 0.9407776755353809], 
             UndirectedEdge[222, 363] -> 
             RGBColor[
              0.6628066494410058, 0.7309294373629389, 0.9563828644799877], 
             UndirectedEdge[30, 341] -> 
             RGBColor[
              0.22502124710185, 0.35384197624810876`, 0.9361259991821227], 
             UndirectedEdge[23, 348] -> 
             RGBColor[
              0.20651189165865158`, 0.3343874701163905, 0.93507191877177], 
             UndirectedEdge[16, 25] -> 
             RGBColor[
              0.2964577597678131, 0.4238211990721158, 0.9403811249327455], 
             UndirectedEdge[25, 62] -> 
             RGBColor[
              0.6778828449272916, 0.740272939600058, 0.8649535953688089], 
             UndirectedEdge[16, 388] -> 
             RGBColor[
              0.24986758553696356`, 0.3799570532922577, 0.9375409613991386], 
             UndirectedEdge[207, 372] -> 
             RGBColor[
              0.18573202091371066`, 0.31254650844355597`, 0.9338885358739095],
              UndirectedEdge[249, 279] -> 
             RGBColor[
              0.19132944320701362`, 0.3184297541708887, 0.934207300792869], 
             UndirectedEdge[151, 267] -> 
             RGBColor[
              0.20258817055551906`, 0.33026339045871145`, 0.9348484686595718],
              UndirectedEdge[185, 252] -> 
             RGBColor[
              0.1992454681560438, 0.3267499982972898, 0.9346581067030068], 
             UndirectedEdge[218, 382] -> 
             RGBColor[
              0.44118615700326724`, 0.5536508374874307, 0.9501354004808935], 
             UndirectedEdge[284, 334] -> 
             RGBColor[
              0.8500382234662116, 0.8370769008965131, 0.6373182165494112], 
             UndirectedEdge[145, 235] -> 
             RGBColor[
              0.22156110310920424`, 0.35020514552603776`, 0.9359289491005658],
              UndirectedEdge[78, 302] -> 
             RGBColor[
              0.2075835767828424, 0.33551387913067643`, 0.9351329496541767], 
             UndirectedEdge[235, 335] -> 
             RGBColor[
              0.19575670920923333`, 0.32308309144409886`, 0.9344594270421422],
              UndirectedEdge[21, 109] -> 
             RGBColor[
              0.1897091064701492, 0.31672667752516137`, 0.9341150250127779], 
             UndirectedEdge[283, 389] -> 
             RGBColor[
              0.9625229099161214, 0.8777511540326326, 0.378485405341739], 
             UndirectedEdge[91, 395] -> 
             RGBColor[
              0.5156283955691132, 0.6172519539462964, 0.9551211142984581], 
             UndirectedEdge[240, 374] -> 
             RGBColor[
              0.18148468566837106`, 0.3080822898040957, 0.933646656415057], 
             UndirectedEdge[301, 339] -> 
             RGBColor[
              0.3159128215006708, 0.4426058768171399, 0.9415499827250514], 
             UndirectedEdge[303, 353] -> 
             RGBColor[
              0.9435949291122223, 0.7996173553563373, 0.3704770005960165], 
             UndirectedEdge[92, 143] -> 
             RGBColor[
              0.20163694443753327`, 0.3292635914974891, 0.9347942977393655], 
             UndirectedEdge[53, 394] -> 
             RGBColor[
              0.38011496144870427`, 0.5036582072985654, 0.9454415671144167], 
             UndirectedEdge[139, 345] -> 
             RGBColor[
              0.5675136417908162, 0.652851509744995, 0.962127956401694], 
             UndirectedEdge[224, 393] -> 
             RGBColor[
              0.6098596540697332, 0.6929310009621534, 0.9632633563282622], 
             UndirectedEdge[175, 204] -> 
             RGBColor[
              0.1850387535749342, 0.31181784051481387`, 0.9338490553245634], 
             UndirectedEdge[131, 293] -> 
             RGBColor[
              0.5641203291112874, 0.6506070149001673, 0.9616718364273125], 
             UndirectedEdge[166, 383] -> 
             RGBColor[
              0.3017459947622442, 0.42990132159861427`, 0.9406631745250644], 
             UndirectedEdge[92, 348] -> 
             RGBColor[
              0.2027372639690243, 0.3304200970893739, 0.9348569593089071], 
             UndirectedEdge[212, 289] -> 
             RGBColor[
              0.5259969557430033, 0.6260670504218144, 0.9558275536278764], 
             UndirectedEdge[161, 214] -> 
             RGBColor[
              0.8792338615689066, 0.5445109956801907, 0.22094211265521246`], 
             UndirectedEdge[124, 386] -> 
             RGBColor[
              0.28427277786616933`, 0.41305129154365816`, 0.9396126134014054],
              UndirectedEdge[227, 350] -> 
             RGBColor[
              0.3112685553301875, 0.44081365131394507`, 0.9411723881594869], 
             UndirectedEdge[258, 279] -> 
             RGBColor[
              0.2183447678357952, 0.34682457322625027`, 0.9357457835648868], 
             UndirectedEdge[63, 103] -> 
             RGBColor[
              0.19205709543901506`, 0.31919456280253833`, 0.9342487395110164],
              UndirectedEdge[291, 336] -> 
             RGBColor[
              0.21513079622652476`, 0.34344648528733734`, 0.9355627526363838],
              UndirectedEdge[292, 400] -> 
             RGBColor[
              0.8208035514548493, 0.16091078942215484`, 0.1675548104084016], 
             UndirectedEdge[149, 300] -> 
             RGBColor[
              0.20324360298345337`, 0.33095229149728655`, 0.9348857945667173],
              UndirectedEdge[356, 364] -> 
             RGBColor[
              0.9333609520587287, 0.8423137522801358, 0.6164503768813724], 
             UndirectedEdge[100, 167] -> 
             RGBColor[
              0.3117593370391954, 0.4377082442608893, 0.941332929144121], 
             UndirectedEdge[334, 391] -> 
             RGBColor[
              0.890222900366215, 0.5169905447403047, 0.23346978586604977`], 
             UndirectedEdge[309, 323] -> 
             RGBColor[
              0.5589942800594222, 0.6511253403818711, 0.9592466420721857], 
             UndirectedEdge[8, 202] -> 
             RGBColor[
              0.2915950820053508, 0.42207290253936436`, 0.9399810782169516], 
             UndirectedEdge[127, 380] -> 
             RGBColor[
              0.529875465248763, 0.6249265943110206, 0.9578049379836415], 
             UndirectedEdge[130, 151] -> 
             RGBColor[
              0.211637861675412, 0.3397751896092761, 0.9353638351810314], 
             UndirectedEdge[335, 355] -> 
             RGBColor[
              0.20320238953001776`, 0.3309089735446419, 0.934883447521514], 
             UndirectedEdge[117, 395] -> 
             RGBColor[
              0.49860624010091514`, 0.6034326012978481, 0.9537810678657916], 
             UndirectedEdge[256, 310] -> 
             RGBColor[
              0.9094103197175858, 0.5979549815728277, 0.4751163468578484], 
             UndirectedEdge[362, 365] -> 
             RGBColor[
              0.5486439436435668, 0.6379198705336546, 0.9602843667734056], 
             UndirectedEdge[163, 342] -> 
             RGBColor[
              0.18272416673891645`, 0.30938506299687774`, 0.9337172430283764],
              UndirectedEdge[125, 288] -> 
             RGBColor[
              0.2031660717843796, 0.3308708012912981, 0.9348813792796271], 
             UndirectedEdge[161, 253] -> 
             RGBColor[
              0.8523693689594214, 0.3702876353014115, 0.19648021346556857`], 
             UndirectedEdge[12, 211] -> 
             RGBColor[
              0.23763726784270695`, 0.3671022139486645, 0.9368444628995842], 
             UndirectedEdge[107, 152] -> 
             RGBColor[
              0.2119625047523057, 0.3401164100666513, 0.9353823231239942], 
             UndirectedEdge[183, 291] -> 
             RGBColor[
              0.1920722404266596, 0.31921048114480044`, 0.9342496019956579], 
             UndirectedEdge[149, 299] -> 
             RGBColor[
              0.19935795159879743`, 0.32686822552748607`, 0.9346645124686672],
              UndirectedEdge[57, 284] -> 
             RGBColor[
              0.544081909913294, 0.6364040523835073, 0.9590603762420349], 
             UndirectedEdge[230, 279] -> 
             RGBColor[
              0.2100811442778375, 0.33813898092284156`, 0.9352751824281966], 
             UndirectedEdge[186, 374] -> 
             RGBColor[
              0.19510883243877694`, 0.3224021318805894, 0.9344225314185126], 
             UndirectedEdge[30, 175] -> 
             RGBColor[
              0.19541782934736363`, 0.32272690722304953`, 0.9344401283353366],
              UndirectedEdge[261, 327] -> 
             RGBColor[
              0.1874834373807122, 0.31438735819659225`, 0.9339882764507168], 
             UndirectedEdge[271, 333] -> 
             RGBColor[
              0.8868896427416582, 0.5599013471362418, 0.5649582086174862], 
             UndirectedEdge[199, 247] -> 
             RGBColor[
              0.9030372486329088, 0.5619443631205439, 0.500289085988991], 
             UndirectedEdge[99, 223] -> 
             RGBColor[
              0.8806912086429535, 0.689221405037725, 0.5973847957056915], 
             UndirectedEdge[200, 367] -> 
             RGBColor[
              0.19007010120853718`, 0.31710610588359545`, 0.9341355831290852],
              UndirectedEdge[111, 400] -> 
             RGBColor[
              0.8243636514645629, 0.1882752781425862, 0.17096396619826132`], 
             UndirectedEdge[277, 390] -> 
             RGBColor[
              0.19904871949657826`, 0.326543202981606, 0.9346469021579138], 
             UndirectedEdge[79, 298] -> 
             RGBColor[
              0.20225845525357178`, 0.3299168387712073, 0.934829691860896], 
             UndirectedEdge[96, 388] -> 
             RGBColor[
              0.24120538255957147`, 0.37085252874762864`, 0.937047661754157], 
             UndirectedEdge[153, 175] -> 
             RGBColor[
              0.19789401206423968`, 0.32532953225753836`, 0.9345811432778787],
              UndirectedEdge[127, 331] -> 
             RGBColor[
              0.29016880316487315`, 0.419484905671203, 0.9399397232478413], 
             UndirectedEdge[6, 93] -> 
             RGBColor[
              0.6343460318717724, 0.7075322117954237, 0.9679330421391619], 
             UndirectedEdge[76, 239] -> 
             RGBColor[
              0.3950361568987507, 0.5127344732289232, 0.94688347760877], 
             UndirectedEdge[333, 337] -> 
             RGBColor[
              0.9553778772118539, 0.9662414744033965, 0.9604177939535141], 
             UndirectedEdge[253, 332] -> 
             RGBColor[
              0.8214986576269006, 0.1662536800580077, 0.16822044486376803`], 
             UndirectedEdge[31, 400] -> 
             RGBColor[
              0.9031868035222537, 0.5793756445438494, 0.5396768154569369], 
             UndirectedEdge[39, 149] -> 
             RGBColor[
              0.2042501787734501, 0.33201026647316434`, 0.9349431175688622], 
             UndirectedEdge[49, 335] -> 
             RGBColor[
              0.1909811618412971, 0.3180636883732066, 0.9341874666843275], 
             UndirectedEdge[57, 236] -> 
             RGBColor[
              0.4289674540866987, 0.5444426167036535, 0.9489769174045849], 
             UndirectedEdge[76, 323] -> 
             RGBColor[
              0.3517784337991403, 0.4767281281704481, 0.9437233665376588], 
             UndirectedEdge[2, 210] -> 
             RGBColor[
              0.223753059772891, 0.352509030957652, 0.9360537777898534], 
             UndirectedEdge[25, 395] -> 
             RGBColor[
              0.4013213562160271, 0.522026120581628, 0.946792819836912], 
             UndirectedEdge[62, 91] -> 
             RGBColor[
              0.7921898842803778, 0.8354987729647263, 0.873281889830355], 
             UndirectedEdge[148, 313] -> 
             RGBColor[
              0.27058528986872044`, 0.4017326741232574, 0.9387208040117352], 
             UndirectedEdge[98, 163] -> 
             RGBColor[
              0.18615149755953203`, 0.3129874049946697, 0.933912424448329], 
             UndirectedEdge[271, 292] -> 
             RGBColor[
              0.8197473186965691, 0.15279212159786854`, 0.16654336072622833`],
              UndirectedEdge[148, 228] -> 
             RGBColor[
              0.2402804897849437, 0.36988040779990605`, 0.9369949904788982], 
             UndirectedEdge[105, 333] -> 
             RGBColor[
              0.969539411680839, 0.9766186640035739, 0.9281855313871071], 
             UndirectedEdge[9, 65] -> 
             RGBColor[
              0.531426491162083, 0.6277150215031269, 0.9572921727453987], 
             UndirectedEdge[129, 337] -> 
             RGBColor[
              0.8881576917970897, 0.5585337722586294, 0.5619283859267235], 
             UndirectedEdge[62, 323] -> 
             RGBColor[
              0.7062128595771804, 0.7648109743818534, 0.8667587588510515], 
             UndirectedEdge[286, 290] -> 
             RGBColor[
              0.28938656912218486`, 0.4203385400712017, 0.9398338164907357], 
             UndirectedEdge[96, 261] -> 
             RGBColor[
              0.20041641876701294`, 0.3279807416319751, 0.9347247906080353], 
             UndirectedEdge[48, 86] -> 
             RGBColor[
              0.23801910122574216`, 0.3675035450438693, 0.9368662077458763], 
             UndirectedEdge[137, 328] -> 
             RGBColor[
              0.2619981545019592, 0.39270705039696285`, 0.9382317793561266], 
             UndirectedEdge[110, 212] -> 
             RGBColor[
              0.715371093239261, 0.7768498811487758, 0.9728708007300837], 
             UndirectedEdge[163, 272] -> 
             RGBColor[
              0.18785278804211375`, 0.3147755691599099, 0.9340093104244782], 
             UndirectedEdge[245, 396] -> 
             RGBColor[
              0.1896460602736138, 0.31666041197524286`, 0.9341114346251538], 
             UndirectedEdge[25, 37] -> 
             RGBColor[
              0.3241466699483991, 0.4529239992502145, 0.9419579674054581], 
             UndirectedEdge[79, 373] -> 
             RGBColor[
              0.19851817498261992`, 0.32598556705897075`, 0.9346166884327141],
              UndirectedEdge[34, 43] -> 
             RGBColor[
              0.18881744465394812`, 0.3157894844217095, 0.9340642461914408], 
             UndirectedEdge[100, 358] -> 
             RGBColor[
              0.33265464447686266`, 0.4596705372168882, 0.942522885990859], 
             UndirectedEdge[273, 394] -> 
             RGBColor[
              0.4408354922328445, 0.55433085165707, 0.9498412454842259], 
             UndirectedEdge[89, 189] -> 
             RGBColor[
              0.23269978806740765`, 0.361912609650526, 0.9365632807307278], 
             UndirectedEdge[268, 299] -> 
             RGBColor[
              0.18802492021905656`, 0.3149564909916871, 0.9340191130973085], 
             UndirectedEdge[143, 272] -> 
             RGBColor[
              0.19777740595295248`, 0.3252069718413211, 0.9345745027323441], 
             UndirectedEdge[339, 382] -> 
             RGBColor[
              0.3520267531654626, 0.47932961303801835`, 0.943651811320036], 
             UndirectedEdge[111, 223] -> 
             RGBColor[
              0.8429142052274374, 0.3295868808857362, 0.18867802924559862`], 
             UndirectedEdge[71, 131] -> 
             RGBColor[
              0.8919073913712897, 0.9158173378862382, 0.9591371203789343], 
             UndirectedEdge[114, 370] -> 
             RGBColor[
              0.18611224246754757`, 0.3129461454040774, 0.9339101889289132], 
             UndirectedEdge[4, 125] -> 
             RGBColor[
              0.196721601742191, 0.3240972546739574, 0.9345143762444637], 
             UndirectedEdge[246, 251] -> 
             RGBColor[
              0.20081373075853814`, 0.3283983417261034, 0.9347474169381822], 
             UndirectedEdge[30, 229] -> 
             RGBColor[
              0.19931037008134544`, 0.32681821433580155`, 0.9346618027716389],
              UndirectedEdge[115, 366] -> 
             RGBColor[
              0.9742039651565302, 0.9239012646538212, 0.3974339190185809], 
             UndirectedEdge[89, 270] -> 
             RGBColor[
              0.22008543635339983`, 0.34865412620301106`, 0.935844912061876], 
             UndirectedEdge[197, 369] -> 
             RGBColor[
              0.18585850163943218`, 0.31267944770563044`, 0.933895738764128], 
             UndirectedEdge[276, 301] -> 
             RGBColor[
              0.3144566810509267, 0.44134464114731864`, 0.9414571987432081], 
             UndirectedEdge[69, 188] -> 
             RGBColor[
              0.42431357927468827`, 0.535650894850094, 0.9492658859927827], 
             UndirectedEdge[191, 225] -> 
             RGBColor[
              0.19624559498378968`, 0.32359694139030604`, 0.9344872683637615],
              UndirectedEdge[223, 247] -> 
             RGBColor[
              0.8382775353615486, 0.29394740449482404`, 0.18423794894565387`],
              UndirectedEdge[72, 86] -> 
             RGBColor[
              0.3668179912534385, 0.4880512045533021, 0.9448235654131886], 
             UndirectedEdge[19, 85] -> 
             RGBColor[
              0.19070082938217475`, 0.3177690411845645, 0.9341715021654952], 
             UndirectedEdge[320, 398] -> 
             RGBColor[
              0.182257588923795, 0.30889466013044303`, 0.9336906721120455], 
             UndirectedEdge[249, 300] -> 
             RGBColor[
              0.18989148665345995`, 0.3169183706613924, 0.9341254112944102], 
             UndirectedEdge[18, 319] -> 
             RGBColor[
              0.9124901172546147, 0.6184152946465793, 0.3038268692248966], 
             UndirectedEdge[6, 273] -> 
             RGBColor[
              0.7251045855702409, 0.7842222818473898, 0.9742467167674911], 
             UndirectedEdge[158, 348] -> 
             RGBColor[
              0.1961222229924388, 0.3234672696051602, 0.9344802425113666], 
             UndirectedEdge[61, 228] -> 
             RGBColor[
              0.220637096263315, 0.34923395574559046`, 0.935876328277638], 
             UndirectedEdge[70, 260] -> 
             RGBColor[
              0.19294770058427305`, 0.3201306452778321, 0.9342994581565066], 
             UndirectedEdge[144, 305] -> 
             RGBColor[
              0.4396583364184836, 0.550769790541102, 0.9502316306235659], 
             UndirectedEdge[165, 351] -> 
             RGBColor[
              0.26754769340127105`, 0.39846518644420825`, 0.9385505554925828],
              UndirectedEdge[132, 370] -> 
             RGBColor[
              0.189210358194615, 0.3162024614651078, 0.9340866220363182], 
             UndirectedEdge[104, 145] -> 
             RGBColor[
              0.2369611402467977, 0.36639156097639836`, 0.9368059584332384], 
             UndirectedEdge[207, 231] -> 
             RGBColor[
              0.1913619669815575, 0.3184639387200607, 0.9342091529737147], 
             UndirectedEdge[21, 249] -> 
             RGBColor[
              0.19014493822452405`, 0.31718476433233855`, 0.9341398449864342],
              UndirectedEdge[7, 93] -> 
             RGBColor[
              0.29873862778538124`, 0.4282001700379434, 0.9404384596617476], 
             UndirectedEdge[140, 255] -> 
             RGBColor[
              0.390267723092427, 0.5124520191417203, 0.9460884921086202], 
             UndirectedEdge[100, 157] -> 
             RGBColor[
              0.31728677632069113`, 0.4435179334056334, 0.9416477086340886], 
             UndirectedEdge[42, 178] -> 
             RGBColor[
              0.18344665505298052`, 0.31014444402336394`, 0.9337583876690367],
              UndirectedEdge[115, 195] -> 
             RGBColor[
              0.6898630728334411, 0.7009647207638414, 0.6155071113240207], 
             UndirectedEdge[281, 394] -> 
             RGBColor[
              0.3781881603711747, 0.5019893090490473, 0.9453187930535599], 
             UndirectedEdge[215, 224] -> 
             RGBColor[
              0.6019092601655756, 0.6867200928189938, 0.9624709353645509], 
             UndirectedEdge[99, 222] -> 
             RGBColor[
              0.9266267914902193, 0.9439342403679507, 0.9791054495248444], 
             UndirectedEdge[55, 284] -> 
             RGBColor[
              0.7718010949853338, 0.8216561483989014, 0.9778895783229857], 
             UndirectedEdge[32, 337] -> 
             RGBColor[
              0.8892490440589328, 0.5669223839767665, 0.5629734660851704], 
             UndirectedEdge[172, 399] -> 
             RGBColor[
              0.369499573099037, 0.49446369145501556`, 0.9447651639555954], 
             UndirectedEdge[267, 346] -> 
             RGBColor[
              0.20049511025135958`, 0.32806345137135173`, 0.9347292719716551],
              UndirectedEdge[222, 393] -> 
             RGBColor[
              0.8365296253571944, 0.8728854021704904, 0.9703016768071477], 
             UndirectedEdge[116, 179] -> 
             RGBColor[
              0.23341719737643146`, 0.3626666523206874, 0.9366041361295647], 
             UndirectedEdge[120, 360] -> 
             RGBColor[
              0.5376516098803733, 0.6341093662239545, 0.9572645433190765], 
             UndirectedEdge[144, 222] -> 
             RGBColor[
              0.7661723613566251, 0.8169857716290115, 0.9639290713689532], 
             UndirectedEdge[237, 307] -> 
             RGBColor[
              0.1806275543927051, 0.307181390488109, 0.9335978440569198], 
             UndirectedEdge[18, 144] -> 
             RGBColor[
              0.7868965412101618, 0.8286865484723305, 0.6945647496408425], 
             UndirectedEdge[309, 365] -> 
             RGBColor[
              0.5016918379873817, 0.6012405287458232, 0.9556046196739707], 
             UndirectedEdge[189, 241] -> 
             RGBColor[
              0.2570425573000169, 0.3874984035347115, 0.937949565426625], 
             UndirectedEdge[268, 370] -> 
             RGBColor[
              0.18660341497029534`, 0.3134623988466007, 0.9339381604763201], 
             UndirectedEdge[336, 359] -> 
             RGBColor[
              0.2802453493603669, 0.4103194523243253, 0.9393282894277089], 
             UndirectedEdge[115, 123] -> 
             RGBColor[
              0.8991328422336753, 0.5962300691178152, 0.23584910998017405`], 
             UndirectedEdge[6, 394] -> 
             RGBColor[
              0.6418942074247149, 0.7140700620770483, 0.9684140052108057], 
             UndirectedEdge[259, 353] -> 
             RGBColor[
              0.9443422105725244, 0.9537215111738743, 0.7488183078429457], 
             UndirectedEdge[98, 348] -> 
             RGBColor[
              0.19717643500186177`, 0.3245753132679656, 0.9345402783257364], 
             UndirectedEdge[145, 349] -> 
             RGBColor[
              0.2241439081408365, 0.35291983737358057`, 0.9360760360261996], 
             UndirectedEdge[287, 292] -> 
             RGBColor[
              0.8184054423003344, 0.14247787160242187`, 0.16525837837376128`],
              UndirectedEdge[53, 69] -> 
             RGBColor[
              0.4877113731208531, 0.5936081076641104, 0.9531940365593021], 
             UndirectedEdge[236, 284] -> 
             RGBColor[
              0.6247504035752902, 0.7047458827568778, 0.9646230139836673], 
             UndirectedEdge[119, 146] -> 
             RGBColor[
              0.2194595639056427, 0.3479962945778132, 0.9358092695518716], 
             UndirectedEdge[198, 310] -> 
             RGBColor[
              0.8276571285797327, 0.5355745817229594, 0.5782791813938954], 
             UndirectedEdge[198, 384] -> 
             RGBColor[
              0.8811911535814985, 0.820358675063078, 0.6244757857174054], 
             UndirectedEdge[111, 292] -> 
             RGBColor[
              0.8230519846103825, 0.1781932319252751, 0.16970791253738232`], 
             UndirectedEdge[40, 295] -> 
             RGBColor[
              0.1896748892459051, 0.31669071305298346`, 0.934113076392477], 
             UndirectedEdge[5, 270] -> 
             RGBColor[
              0.19738135324155764`, 0.32479069533045285`, 0.9345519481163376],
              UndirectedEdge[104, 355] -> 
             RGBColor[
              0.21609483282429037`, 0.34445974887503966`, 0.9356176530944622],
              UndirectedEdge[356, 360] -> 
             RGBColor[
              0.804069535005691, 0.8476283188054337, 0.97217824926772], 
             UndirectedEdge[42, 398] -> 
             RGBColor[
              0.18234639975021955`, 0.30898800593994685`, 0.9336957297572264],
              UndirectedEdge[153, 211] -> 
             RGBColor[
              0.21907020233692062`, 0.34758705088213704`, 0.9357870959865418],
              UndirectedEdge[223, 385] -> 
             RGBColor[
              0.9268169546976089, 0.7220420708837272, 0.4190027976388401], 
             UndirectedEdge[144, 361] -> 
             RGBColor[
              0.4954156444114053, 0.6000520136165334, 0.9537482598048219], 
             UndirectedEdge[216, 229] -> 
             RGBColor[
              0.2068690748506942, 0.33476289229794964`, 0.9350922598261517], 
             UndirectedEdge[161, 389] -> 
             RGBColor[
              0.9363348090239618, 0.7668148008617284, 0.3570460900069422], 
             UndirectedEdge[313, 340] -> 
             RGBColor[
              0.2780047879810863, 0.40953103706270466`, 0.9391433334530706], 
             UndirectedEdge[241, 380] -> 
             RGBColor[
              0.5006467932710101, 0.5970366894503322, 0.9560367412293518], 
             UndirectedEdge[258, 281] -> 
             RGBColor[
              0.318201913769557, 0.44345916858997797`, 0.9417371947060786], 
             UndirectedEdge[344, 346] -> 
             RGBColor[
              0.19749434605120672`, 0.3249094579375519, 0.9345583828896893], 
             UndirectedEdge[79, 205] -> 
             RGBColor[
              0.19210249208707042`, 0.3192422775579583, 0.9342513247829649], 
             UndirectedEdge[227, 306] -> 
             RGBColor[
              0.248145898473511, 0.3781474510273044, 0.9374429138678827], 
             UndirectedEdge[43, 381] -> 
             RGBColor[
              0.19202300109929993`, 0.3191587274897918, 0.9342467978888077], 
             UndirectedEdge[98, 143] -> 
             RGBColor[
              0.19607611547037074`, 0.3234188076760809, 0.9344776167561948], 
             UndirectedEdge[243, 267] -> 
             RGBColor[
              0.2144789920516021, 0.342761397772722, 0.9355256333528797], 
             UndirectedEdge[58, 152] -> 
             RGBColor[
              0.19702370192683044`, 0.32441478112227146`, 0.9345315804030616],
              UndirectedEdge[376, 397] -> 
             RGBColor[
              0.32517928194563106`, 0.4539892085157613, 0.9420175102408045], 
             UndirectedEdge[114, 279] -> 
             RGBColor[
              0.19285735565451845`, 0.32003568702846064`, 0.9342943131464105],
              UndirectedEdge[148, 218] -> 
             RGBColor[
              0.40841467546891774`, 0.5204402282772255, 0.9482239194761258], 
             UndirectedEdge[55, 366] -> 
             RGBColor[
              0.8985186945130963, 0.9173414029032505, 0.7466017890196988], 
             UndirectedEdge[99, 361] -> 
             RGBColor[
              0.6558700745449995, 0.7270004823554725, 0.968924637960713], 
             UndirectedEdge[97, 169] -> 
             RGBColor[
              0.37794173807367953`, 0.5007330923555633, 0.945366919038301], 
             UndirectedEdge[43, 250] -> 
             RGBColor[
              0.19420867686654147`, 0.32145601130101026`, 0.9343712688903346],
              UndirectedEdge[112, 177] -> 
             RGBColor[
              0.18091855533538903`, 0.3074872509293952, 0.9336144161301083], 
             UndirectedEdge[255, 356] -> 
             RGBColor[
              0.6597861746771188, 0.7286564919053182, 0.9611997608615672], 
             UndirectedEdge[210, 328] -> 
             RGBColor[
              0.2385161810587667, 0.36802600746505976`, 0.9368945157070033], 
             UndirectedEdge[91, 221] -> 
             RGBColor[
              0.48124384050183955`, 0.5874697805650118, 0.9529301608546397], 
             UndirectedEdge[32, 345] -> 
             RGBColor[
              0.824801297962475, 0.5160822589510907, 0.5758521781137924], 
             UndirectedEdge[210, 258] -> 
             RGBColor[
              0.24166666616429894`, 0.371337367063267, 0.9370739311730383], 
             UndirectedEdge[189, 359] -> 
             RGBColor[
              0.2794316818374808, 0.4094642361682714, 0.9392819522659938], 
             UndirectedEdge[164, 258] -> 
             RGBColor[
              0.22632269335272776`, 0.3552098787742395, 0.936200114620793], 
             UndirectedEdge[354, 374] -> 
             RGBColor[
              0.18986888322413037`, 0.3168946130240269, 0.9341241240625486], 
             UndirectedEdge[235, 322] -> 
             RGBColor[
              0.1941801601361397, 0.32142603840929285`, 0.934369644904725], 
             UndirectedEdge[147, 392] -> 
             RGBColor[
              0.2251386082236323, 0.35396533022822685`, 0.9361326827243879], 
             UndirectedEdge[123, 283] -> 
             RGBColor[
              0.8875401777067986, 0.5502690172951994, 0.2265213799870392], 
             UndirectedEdge[202, 239] -> 
             RGBColor[
              0.4173644057485659, 0.5344604832455712, 0.9482188359733204], 
             UndirectedEdge[180, 249] -> 
             RGBColor[
              0.18602314959306215`, 0.3128525031441788, 0.9339051152215123], 
             UndirectedEdge[2, 197] -> 
             RGBColor[
              0.1965684920257088, 0.3239363266542179, 0.9345056568726156], 
             UndirectedEdge[174, 329] -> 
             RGBColor[
              0.34008730347088106`, 0.4646976118288939, 0.9430481418570962], 
             UndirectedEdge[193, 242] -> 
             RGBColor[
              0.5891633460741419, 0.6714315101447773, 0.963657200278417], 
             UndirectedEdge[58, 160] -> 
             RGBColor[
              0.1942495004305084, 0.32149891945510295`, 0.9343735937319094], 
             UndirectedEdge[50, 137] -> 
             RGBColor[
              0.2618861891426283, 0.3925893677052923, 0.9382254030945505], 
             UndirectedEdge[326, 383] -> 
             RGBColor[
              0.2999445651565369, 0.428007904865782, 0.9405605857739958], 
             UndirectedEdge[157, 238] -> 
             RGBColor[
              0.22387178003127423`, 0.3526338134765119, 0.9360605387329375], 
             UndirectedEdge[243, 346] -> 
             RGBColor[
              0.21741007073096835`, 0.3458421473058579, 0.9356925539475274], 
             UndirectedEdge[235, 355] -> 
             RGBColor[
              0.2006947956866969, 0.3282733334246791, 0.9347406437617896], 
             UndirectedEdge[44, 135] -> 
             RGBColor[
              0.2818343394924019, 0.41109593137624006`, 0.9394515009810677], 
             UndirectedEdge[33, 206] -> 
             RGBColor[
              0.33773890435239673`, 0.4612073947457289, 0.942951820792434], 
             UndirectedEdge[88, 263] -> 
             RGBColor[
              0.3661139704738488, 0.49089201133024934`, 0.9445728421053426], 
             UndirectedEdge[82, 399] -> 
             RGBColor[
              0.5595672102027384, 0.6489717323660277, 0.9604046913379707], 
             UndirectedEdge[271, 287] -> 
             RGBColor[
              0.8186608763962349, 0.14444124999544666`, 0.16550298235246705`],
              UndirectedEdge[31, 223] -> 
             RGBColor[
              0.9217373572851282, 0.7206872472869994, 0.5573908785042743], 
             UndirectedEdge[108, 376] -> 
             RGBColor[
              0.29627129186653856`, 0.4287302908095537, 0.9401835838264763], 
             UndirectedEdge[301, 361] -> 
             RGBColor[
              0.3297210809288895, 0.45456589711056455`, 0.9424298328056531], 
             UndirectedEdge[80, 388] -> 
             RGBColor[
              0.23694403524812552`, 0.36637358253827423`, 0.9368049843288686],
              UndirectedEdge[47, 136] -> 
             RGBColor[
              0.18182023692588944`, 0.308434975450926, 0.9336657655627689], 
             UndirectedEdge[39, 50] -> 
             RGBColor[
              0.21465093660737516`, 0.342942122402754, 0.9355354253409618], 
             UndirectedEdge[120, 389] -> 
             RGBColor[
              0.7028354936755193, 0.7597247670512044, 0.7201987400202577], 
             UndirectedEdge[28, 106] -> 
             RGBColor[
              0.18905752987434937`, 0.31604182921063345`, 0.9340779186895682],
              UndirectedEdge[97, 326] -> 
             RGBColor[
              0.27009816450947055`, 0.40122067448515425`, 0.9386930629431633],
              UndirectedEdge[195, 242] -> 
             RGBColor[
              0.3825084156474021, 0.5057312970269716, 0.9455940758995094], 
             UndirectedEdge[90, 260] -> 
             RGBColor[
              0.20225002842194761`, 0.32990798163687834`, 0.9348292119653014],
              UndirectedEdge[73, 368] -> 
             RGBColor[
              0.19117243294824504`, 0.31826472643389747`, 0.934198359290908], 
             UndirectedEdge[52, 287] -> 
             RGBColor[
              0.9031568301038848, 0.5619220117093251, 0.49813424573552845`], 
             UndirectedEdge[135, 243] -> 
             RGBColor[
              0.2833746021341409, 0.41271484507099976`, 0.9395392166599004], 
             UndirectedEdge[311, 317] -> 
             RGBColor[
              0.19555015626042008`, 0.32286599119868276`, 0.934447664157275], 
             UndirectedEdge[6, 10] -> 
             RGBColor[
              0.8845651997050992, 0.6376155087725291, 0.5907990623624317], 
             UndirectedEdge[363, 383] -> 
             RGBColor[
              0.36642168177165046`, 0.49179777668654956`, 0.9445690434418867],
              UndirectedEdge[227, 346] -> 
             RGBColor[
              0.23870901568862182`, 0.3682286888874592, 0.9369054973539003], 
             UndirectedEdge[157, 341] -> 
             RGBColor[
              0.24810243304135554`, 0.37810176610224144`, 0.9374404385758228],
              UndirectedEdge[18, 310] -> 
             RGBColor[
              0.9095262697789932, 0.5956338641827077, 0.30098868553505453`], 
             UndirectedEdge[37, 96] -> 
             RGBColor[
              0.24798039051581972`, 0.3779734916699602, 0.9374334884345392], 
             UndirectedEdge[218, 222] -> 
             RGBColor[
              0.7556819189936763, 0.8084691579297268, 0.9631032253183853], 
             UndirectedEdge[65, 203] -> 
             RGBColor[
              0.34325183639463963`, 0.4717292211712722, 0.9430926813827534], 
             UndirectedEdge[105, 303] -> 
             RGBColor[
              0.9396161743909813, 0.7997165627600418, 0.5632237947654809], 
             UndirectedEdge[119, 267] -> 
             RGBColor[
              0.21867692760035795`, 0.34717369419895117`, 0.9357646995720923],
              UndirectedEdge[20, 312] -> 
             RGBColor[
              0.4662211223319299, 0.5756731791658605, 0.9516371294428863], 
             UndirectedEdge[285, 324] -> 
             RGBColor[
              0.1849819453905557, 0.31175813151118514`, 0.9338458201825032], 
             UndirectedEdge[16, 302] -> 
             RGBColor[
              0.21182755927874247`, 0.3399745738178992, 0.9353746381789088], 
             UndirectedEdge[65, 313] -> 
             RGBColor[
              0.33055584599709903`, 0.45850175468157234`, 0.9423653859984371],
              UndirectedEdge[280, 392] -> 
             RGBColor[
              0.20599555407739328`, 0.33384476658079454`, 0.9350425141103704],
              UndirectedEdge[1, 357] -> 
             RGBColor[
              0.18390843895748787`, 0.3106298081857918, 0.9337846855792504], 
             UndirectedEdge[26, 177] -> 
             RGBColor[
              0.18182665700375172`, 0.3084417233598157, 0.9336661311767056], 
             UndirectedEdge[69, 293] -> 
             RGBColor[
              0.44347384418172964`, 0.5552917835398956, 0.950375260333012], 
             UndirectedEdge[165, 399] -> 
             RGBColor[
              0.2924581876891166, 0.42004140455849254`, 0.9401378301611192], 
             UndirectedEdge[108, 297] -> 
             RGBColor[
              0.30146181771501923`, 0.43418586257465347`, 0.9404791765948524],
              UndirectedEdge[192, 335] -> 
             RGBColor[
              0.22826537319767345`, 0.3572517584642937, 0.9363107473640253], 
             UndirectedEdge[134, 272] -> 
             RGBColor[
              0.18788317693480855`, 0.3148075098128992, 0.9340110410269609], 
             UndirectedEdge[86, 236] -> 
             RGBColor[
              0.3888676051713017, 0.5059520744556105, 0.9465593917911999], 
             UndirectedEdge[312, 389] -> 
             RGBColor[
              0.7704699076494956, 0.8157404401627024, 0.7252172989695943], 
             UndirectedEdge[156, 245] -> 
             RGBColor[
              0.1983829021548571, 0.32584338674019936`, 0.9346089848452912], 
             UndirectedEdge[153, 168] -> 
             RGBColor[
              0.20180786245057253`, 0.3294432371660213, 0.9348040312673576], 
             UndirectedEdge[118, 150] -> 
             RGBColor[
              0.29792702653421543`, 0.4259677967148573, 0.9404427441608055], 
             UndirectedEdge[195, 255] -> 
             RGBColor[
              0.3994035312970712, 0.5203649970295117, 0.9466706177289421], 
             UndirectedEdge[109, 180] -> 
             RGBColor[
              0.18558731783868732`, 0.3123944163370016, 0.933880295247856], 
             UndirectedEdge[143, 378] -> 
             RGBColor[
              0.21957024665493602`, 0.3481126291650121, 0.9358155727707034], 
             UndirectedEdge[135, 383] -> 
             RGBColor[
              0.3468364039638354, 0.47483399343410504`, 0.9433210868585539], 
             UndirectedEdge[20, 120] -> 
             RGBColor[
              0.3985867083579536, 0.5196575060543626, 0.9466185704935497], 
             UndirectedEdge[149, 230] -> 
             RGBColor[
              0.21572578902733716`, 0.34407186044571364`, 0.935596636596177], 
             UndirectedEdge[16, 77] -> 
             RGBColor[
              0.21295289463759554`, 0.3411573726304365, 0.9354387243628108], 
             UndirectedEdge[168, 238] -> 
             RGBColor[
              0.19942328541058194`, 0.3269368955060745, 0.9346682331325956], 
             UndirectedEdge[104, 335] -> 
             RGBColor[
              0.21115674634682685`, 0.33926950689445945`, 0.9353364363748149],
              UndirectedEdge[79, 232] -> 
             RGBColor[
              0.19470557204870292`, 0.32197827964243614`, 0.9343995663358682],
              UndirectedEdge[47, 299] -> 
             RGBColor[
              0.184696983160691, 0.3114586181399484, 0.9338295920050762], 
             UndirectedEdge[236, 397] -> 
             RGBColor[
              0.4369077612514729, 0.5513201116783387, 0.9494828667557864], 
             UndirectedEdge[33, 118] -> 
             RGBColor[
              0.30201839786374246`, 0.43026808739011524`, 0.9406757417053806],
              UndirectedEdge[51, 79] -> 
             RGBColor[
              0.20012999875823717`, 0.3276796960426744, 0.934708479412256], 
             UndirectedEdge[24, 168] -> 
             RGBColor[
              0.22907306672132033`, 0.35810069556837376`, 0.9363567443153216],
              UndirectedEdge[269, 365] -> 
             RGBColor[
              0.3297101598350657, 0.4597477851420956, 0.9422390562668672], 
             UndirectedEdge[98, 240] -> 
             RGBColor[
              0.18629079266231832`, 0.3131338129795177, 0.9339203570983641], 
             UndirectedEdge[29, 113] -> 
             RGBColor[
              0.1857448284490183, 0.3125599699752089, 0.9338892652440982], 
             UndirectedEdge[330, 398] -> 
             RGBColor[
              0.18475377969358928`, 0.31151831489713266`, 0.9338328264836019],
              UndirectedEdge[43, 265] -> 
             RGBColor[
              0.19684687423849298`, 0.3242289240103058, 0.934521510327804], 
             UndirectedEdge[209, 304] -> 
             RGBColor[
              0.2736580263748165, 0.40496231501391133`, 0.9388957918100511], 
             UndirectedEdge[107, 238] -> 
             RGBColor[
              0.21198166691675951`, 0.34013655071644366`, 0.9353834143809119],
              UndirectedEdge[298, 347] -> 
             RGBColor[
              0.1948950544058417, 0.32217743761366435`, 0.9344103570757931], 
             UndirectedEdge[153, 343] -> 
             RGBColor[
              0.20318561149837056`, 0.330891338769592, 0.9348824920374326], 
             UndirectedEdge[110, 292] -> 
             RGBColor[
              0.8362272767124428, 0.5182110192715781, 0.5760681458101908], 
             UndirectedEdge[332, 366] -> 
             RGBColor[
              0.905552488404973, 0.5629699044168974, 0.3384071050888487], 
             UndirectedEdge[39, 136] -> 
             RGBColor[
              0.19040517985093924`, 0.31745829478197307`, 0.9341546653620656],
              UndirectedEdge[115, 380] -> 
             RGBColor[
              0.8377450255090341, 0.8206060012110092, 0.627750782576732], 
             UndirectedEdge[167, 238] -> 
             RGBColor[
              0.2183443407497785, 0.3468241243317679, 0.9357457592429699], 
             UndirectedEdge[1, 162] -> 
             RGBColor[
              0.18855509271436693`, 0.315513735899136, 0.9340493056365965], 
             UndirectedEdge[128, 243] -> 
             RGBColor[
              0.26764794439082373`, 0.39864533778752814`, 0.9385535265321823],
              UndirectedEdge[196, 366] -> 
             RGBColor[
              0.9187123308959824, 0.9333119446325909, 0.748562723255582], 
             UndirectedEdge[136, 149] -> 
             RGBColor[
              0.19648120536399588`, 0.3238445828384636, 0.9345006860263599], 
             UndirectedEdge[263, 360] -> 
             RGBColor[
              0.48229378308011506`, 0.5855219577186828, 0.9537605973016217], 
             UndirectedEdge[267, 354] -> 
             RGBColor[
              0.19683262012965425`, 0.3242139420381536, 0.9345206985773926], 
             UndirectedEdge[192, 355] -> 
             RGBColor[
              0.233203459675137, 0.36244200044487396`, 0.9365919640836726], 
             UndirectedEdge[24, 100] -> 
             RGBColor[
              0.32394697736880945`, 0.450518226988342, 0.9420269972308946], 
             UndirectedEdge[11, 286] -> 
             RGBColor[
              0.5972181184299319, 0.677195451192008, 0.9647287147159659], 
             UndirectedEdge[71, 110] -> 
             RGBColor[
              0.9113332721380322, 0.9312595378862136, 0.9610025753124077], 
             UndirectedEdge[186, 306] -> 
             RGBColor[
              0.21444053080855624`, 0.3427209725676972, 0.9355234430419865], 
             UndirectedEdge[6, 131] -> 
             RGBColor[
              0.8701371040264215, 0.8993351938028649, 0.9874630507499915], 
             UndirectedEdge[53, 264] -> 
             RGBColor[
              0.3312918681319017, 0.4568612487266348, 0.9424956938321003], 
             UndirectedEdge[83, 118] -> 
             RGBColor[
              0.6542161598297946, 0.7234949587303476, 0.9559255584190995], 
             UndirectedEdge[98, 272] -> 
             RGBColor[
              0.1949500622314218, 0.3222352543260466, 0.9344134896900831], 
             UndirectedEdge[200, 330] -> 
             RGBColor[
              0.1913737687250167, 0.31847634310071005`, 0.9342098250655455], 
             UndirectedEdge[101, 389] -> 
             RGBColor[
              0.9235485115849101, 0.701785575444227, 0.3461039765729519], 
             UndirectedEdge[10, 353] -> 
             RGBColor[
              0.9181134493807003, 0.6596306220979193, 0.3482638350680197], 
             UndirectedEdge[174, 340] -> 
             RGBColor[
              0.3446138349142821, 0.46945528337457815`, 0.9433059211263948], 
             UndirectedEdge[77, 187] -> 
             RGBColor[
              0.2066496337845954, 0.33453224582411256`, 0.9350797629820713], 
             UndirectedEdge[137, 264] -> 
             RGBColor[
              0.27631179289230656`, 0.4077515918823088, 0.9390469198873264], 
             UndirectedEdge[20, 356] -> 
             RGBColor[
              0.6650046334832713, 0.7331764586358418, 0.9615322764421933], 
             UndirectedEdge[130, 227] -> 
             RGBColor[
              0.24482762812914852`, 0.374659738504888, 0.9372539432807123], 
             UndirectedEdge[24, 150] -> 
             RGBColor[
              0.24929421300339247`, 0.3793544024055562, 0.9375083086815804], 
             UndirectedEdge[282, 339] -> 
             RGBColor[
              0.34849054026782905`, 0.4762667231613163, 0.9434264869611491], 
             UndirectedEdge[69, 93] -> 
             RGBColor[
              0.45767335020652483`, 0.5675906819706489, 0.951280040300782], 
             UndirectedEdge[65, 266] -> 
             RGBColor[
              0.5173579150755038, 0.6167245429391528, 0.9558899485594068], 
             UndirectedEdge[189, 336] -> 
             RGBColor[
              0.23398737474331802`, 0.3632659448846183, 0.936636606887107], 
             UndirectedEdge[191, 322] -> 
             RGBColor[
              0.18956017104754852`, 0.31657013695295677`, 0.934106543360791], 
             UndirectedEdge[297, 376] -> 
             RGBColor[
              0.2913695149854919, 0.423578212516969, 0.9399044348846297], 
             UndirectedEdge[33, 286] -> 
             RGBColor[
              0.2839164063725824, 0.41458905219301934`, 0.9395222988145264], 
             UndirectedEdge[145, 351] -> 
             RGBColor[
              0.2797139568415439, 0.4112527007055903, 0.9392434061971325], 
             UndirectedEdge[83, 141] -> 
             RGBColor[
              0.6533758763039106, 0.7227671473741049, 0.9558720162958637], 
             UndirectedEdge[148, 276] -> 
             RGBColor[
              0.31779913118136904`, 0.44485776815799194`, 0.9416475463334251],
              UndirectedEdge[124, 160] -> 
             RGBColor[
              0.21095706740892387`, 0.3390596316703475, 0.9353250649546998], 
             UndirectedEdge[25, 362] -> 
             RGBColor[
              0.5776163710657185, 0.6632666473879071, 0.9621212256893779], 
             UndirectedEdge[96, 208] -> 
             RGBColor[
              0.25302363918053994`, 0.383274265777015, 0.9377206939851772], 
             UndirectedEdge[240, 272] -> 
             RGBColor[
              0.18799208314490007`, 0.3149219771447579, 0.9340172430745133], 
             UndirectedEdge[25, 182] -> 
             RGBColor[
              0.30289473156223595`, 0.4305868645556383, 0.9407477009537915], 
             UndirectedEdge[101, 380] -> 
             RGBColor[
              0.787177962650946, 0.5986793707999881, 0.5860416238148101], 
             UndirectedEdge[24, 358] -> 
             RGBColor[
              0.2688894294981841, 0.3999502173500661, 0.9386242272724338], 
             UndirectedEdge[202, 234] -> 
             RGBColor[
              0.28726387007128157`, 0.41752052418196, 0.9397344221047603], 
             UndirectedEdge[17, 62] -> 
             RGBColor[
              0.9097327710312662, 0.6022520662838114, 0.4798085283004041], 
             UndirectedEdge[24, 211] -> 
             RGBColor[
              0.2463354066076684, 0.3762445092844895, 0.9373398090345058], 
             UndirectedEdge[2, 39] -> 
             RGBColor[
              0.19999978068083032`, 0.3275428285870168, 0.934701063685388], 
             UndirectedEdge[164, 328] -> 
             RGBColor[
              0.22317220824719552`, 0.35189851917603227`, 0.9360206991547579],
              UndirectedEdge[228, 301] -> 
             RGBColor[
              0.2369380396545014, 0.36636728078923275`, 0.9368046428886814], 
             UndirectedEdge[118, 286] -> 
             RGBColor[
              0.33934539796061675`, 0.46834566054302623`, 0.9428437665800653],
              UndirectedEdge[139, 215] -> 
             RGBColor[
              0.5065072627092252, 0.6051273956422916, 0.956064783626883], 
             UndirectedEdge[239, 377] -> 
             RGBColor[
              0.3809157120608543, 0.4978929904163819, 0.9460793391645779], 
             UndirectedEdge[348, 374] -> 
             RGBColor[
              0.19237032800791454`, 0.3195237900925436, 0.9342665776424293], 
             UndirectedEdge[8, 388] -> 
             RGBColor[
              0.26319007599843486`, 0.3939598354619466, 0.938299657522061], 
             UndirectedEdge[249, 370] -> 
             RGBColor[
              0.18458433002004276`, 0.31134021254650546`, 0.9338231765753717],
              UndirectedEdge[61, 285] -> 
             RGBColor[
              0.2007711589524707, 0.32835359605871806`, 0.934744992536806], 
             UndirectedEdge[162, 280] -> 
             RGBColor[
              0.20211294537388308`, 0.32976389866179523`, 0.9348214052885103],
              UndirectedEdge[126, 205] -> 
             RGBColor[
              0.18385657240612066`, 0.31057529315177557`, 0.9337817318558796],
              UndirectedEdge[161, 334] -> 
             RGBColor[
              0.9198789642740572, 0.7116881876157337, 0.2605664067222301], 
             UndirectedEdge[192, 399] -> 
             RGBColor[
              0.3088211273745378, 0.43723989163816773`, 0.941069675369404], 
             UndirectedEdge[69, 281] -> 
             RGBColor[
              0.4857845720433236, 0.5919392094145923, 0.9530712624984452], 
             UndirectedEdge[38, 128] -> 
             RGBColor[
              0.281313846761083, 0.4130090676469258, 0.9393317794552777], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.22265042245962569`, 0.35135008923016664`, 0.9359909842260687],
              UndirectedEdge[145, 355] -> 
             RGBColor[
              0.22900678342998865`, 0.3580310276265808, 0.9363529695799375], 
             UndirectedEdge[23, 139] -> 
             RGBColor[
              0.2594316195520534, 0.3900094594368974, 0.9380856189875776], 
             UndirectedEdge[120, 359] -> 
             RGBColor[
              0.3691186833876108, 0.4941337839310517, 0.9447408939999908], 
             UndirectedEdge[117, 309] -> 
             RGBColor[
              0.6279491492944215, 0.7079937863162957, 0.9644297266188226], 
             UndirectedEdge[19, 167] -> 
             RGBColor[
              0.21765966709879997`, 0.34610448891377266`, 0.9357067680914306],
              UndirectedEdge[26, 285] -> 
             RGBColor[
              0.1832664520031871, 0.30995503919249784`, 0.9337481253719375], 
             UndirectedEdge[166, 169] -> 
             RGBColor[
              0.3512165772923903, 0.4726432539013666, 0.9438449606681389], 
             UndirectedEdge[31, 383] -> 
             RGBColor[
              0.6712879724630387, 0.7362684219408357, 0.9272977112853262], 
             UndirectedEdge[146, 346] -> 
             RGBColor[
              0.20127774655664432`, 0.3288860517502138, 0.9347738419514344], 
             UndirectedEdge[191, 349] -> 
             RGBColor[
              0.1912119313089536, 0.3183062417153429, 0.9342006086641177], 
             UndirectedEdge[212, 362] -> 
             RGBColor[
              0.6845252117813709, 0.7524862898136562, 0.9698671068536907], 
             UndirectedEdge[242, 380] -> 
             RGBColor[
              0.5303903683229951, 0.6253725774741394, 0.9578377471522206], 
             UndirectedEdge[175, 307] -> 
             RGBColor[
              0.18458331869086259`, 0.3113391495754152, 0.933823118981671], 
             UndirectedEdge[140, 193] -> 
             RGBColor[
              0.6221373960333281, 0.6999919748954846, 0.9657582775840088], 
             UndirectedEdge[8, 25] -> 
             RGBColor[
              0.3097802502292844, 0.43782398124180466`, 0.9411398210556678], 
             UndirectedEdge[8, 269] -> 
             RGBColor[
              0.30450100126350144`, 0.4332513611304116, 0.9408034319798247], 
             UndirectedEdge[155, 371] -> 
             RGBColor[
              0.18296643499197385`, 0.3096397022915355, 0.9337310398469844], 
             UndirectedEdge[55, 161] -> 
             RGBColor[
              0.8416418357931794, 0.6962674351181222, 0.6011377684958046], 
             UndirectedEdge[110, 202] -> 
             RGBColor[
              0.590277084299675, 0.6718791600205865, 0.9639661767270546], 
             UndirectedEdge[332, 380] -> 
             RGBColor[
              0.7690935487574768, 0.4596746409740855, 0.5687239686469998], 
             UndirectedEdge[359, 360] -> 
             RGBColor[
              0.49422258294729215`, 0.5964933259008812, 0.9544972841256812], 
             UndirectedEdge[128, 350] -> 
             RGBColor[
              0.32622360223214686`, 0.4565323538126437, 0.9420240559565443], 
             UndirectedEdge[272, 378] -> 
             RGBColor[
              0.2184441934159871, 0.34692907581497784`, 0.9357514457045917], 
             UndirectedEdge[52, 345] -> 
             RGBColor[
              0.9085391948738575, 0.9277362639462506, 0.9077575254526454], 
             UndirectedEdge[32, 333] -> 
             RGBColor[
              0.8876476995379257, 0.5657281038549604, 0.5656841246616948], 
             UndirectedEdge[85, 168] -> 
             RGBColor[
              0.18992658867508105`, 0.3169552651117129, 0.9341274103026127], 
             UndirectedEdge[23, 354] -> 
             RGBColor[
              0.20401044687486744`, 0.3317582930478737, 0.9349294651918895], 
             UndirectedEdge[51, 373] -> 
             RGBColor[
              0.1995969758310581, 0.32711945515060364`, 0.9346781245450898], 
             UndirectedEdge[55, 334] -> 
             RGBColor[
              0.8819744590496598, 0.862025730858683, 0.6405013220512796], 
             UndirectedEdge[66, 267] -> 
             RGBColor[
              0.1968456208420638, 0.3242276066111888, 0.9345214389487315], 
             UndirectedEdge[30, 153] -> 
             RGBColor[
              0.2031751711317593, 0.3308803652823261, 0.9348818974739992], 
             UndirectedEdge[179, 290] -> 
             RGBColor[
              0.24217146180405288`, 0.37186793928654055`, 0.9371026785379442],
              UndirectedEdge[178, 200] -> 
             RGBColor[
              0.1885274133225135, 0.31548464310332325`, 0.9340477293361784], 
             UndirectedEdge[340, 358] -> 
             RGBColor[
              0.2744945486553811, 0.4058415529693607, 0.9389434305164055], 
             UndirectedEdge[31, 259] -> 
             RGBColor[
              0.9398415048836066, 0.9536048784389164, 0.9502151803126189], 
             UndirectedEdge[92, 146] -> 
             RGBColor[
              0.20174986693286398`, 0.32938228019978144`, 0.9348007285084208],
              UndirectedEdge[3, 373] -> 
             RGBColor[
              0.21710028788855346`, 0.3455165458971132, 0.9356749122729344], 
             UndirectedEdge[174, 341] -> 
             RGBColor[
              0.3335895874564281, 0.4578681003187137, 0.9426781065425826], 
             UndirectedEdge[248, 260] -> 
             RGBColor[
              0.1859219097416619, 0.3127460936413798, 0.933899349761746], 
             UndirectedEdge[41, 325] -> 
             RGBColor[
              0.2165335134226994, 0.3449208299979239, 0.9356426353055718], 
             UndirectedEdge[66, 346] -> 
             RGBColor[
              0.19977669952143007`, 0.3273083561443247, 0.9346883595433791], 
             UndirectedEdge[53, 142] -> 
             RGBColor[
              0.43838221439814257`, 0.5535604743597381, 0.949310664485988], 
             UndirectedEdge[38, 44] -> 
             RGBColor[
              0.24351959225973108`, 0.37328490987186613`, 0.9371794525730147],
              UndirectedEdge[76, 187] -> 
             RGBColor[
              0.24964108184106412`, 0.37971898354670364`, 0.9375280623487394],
              UndirectedEdge[156, 160] -> 
             RGBColor[
              0.19858358472464382`, 0.32605431684505504`, 0.9346204134207573],
              UndirectedEdge[141, 290] -> 
             RGBColor[
              0.3066482770874609, 0.4352897639120549, 0.9409337172583541], 
             UndirectedEdge[3, 79] -> 
             RGBColor[
              0.21763331081573253`, 0.34607678678918397`, 0.9357052671401005],
              UndirectedEdge[301, 382] -> 
             RGBColor[
              0.2859820358837003, 0.41668133468074653`, 0.9396428195322926], 
             UndirectedEdge[193, 389] -> 
             RGBColor[
              0.9155257058475293, 0.9306524378746825, 0.7386464272151838], 
             UndirectedEdge[189, 291] -> 
             RGBColor[
              0.21431712870363867`, 0.34259126913128346`, 0.9355164154746687],
              UndirectedEdge[161, 196] -> 
             RGBColor[
              0.8618354721760655, 0.7122379768474625, 0.603098702731688], 
             UndirectedEdge[83, 161] -> 
             RGBColor[
              0.9152656356126947, 0.754447556797873, 0.5945283802670174], 
             UndirectedEdge[100, 211] -> 
             RGBColor[
              0.31010062158634694`, 0.43596482915131163`, 0.941238467752931], 
             UndirectedEdge[32, 287] -> 
             RGBColor[
              0.8194189331925024, 0.1502680067141652, 0.16622889839667554`], 
             UndirectedEdge[156, 181] -> 
             RGBColor[
              0.19699698742024596`, 0.3243867024820536, 0.9345300590514323], 
             UndirectedEdge[126, 176] -> 
             RGBColor[
              0.18438193895865332`, 0.3111274867086507, 0.9338116507038363], 
             UndirectedEdge[46, 350] -> 
             RGBColor[
              0.5770408715617338, 0.6621623046757947, 0.9623409899481321], 
             UndirectedEdge[47, 149] -> 
             RGBColor[
              0.1956652358484003, 0.3229869471421173, 0.9344542177695655], 
             UndirectedEdge[57, 108] -> 
             RGBColor[
              0.32733127751038416`, 0.4577193635987606, 0.9420863025998256], 
             UndirectedEdge[105, 400] -> 
             RGBColor[
              0.9037087544899305, 0.5795914846825118, 0.5310267371567282], 
             UndirectedEdge[62, 256] -> 
             RGBColor[
              0.992053902372576, 0.9909820986727351, 0.781350931735281], 
             UndirectedEdge[193, 332] -> 
             RGBColor[
              0.8278665265086236, 0.5057335736447233, 0.5745434217731962], 
             UndirectedEdge[1, 387] -> 
             RGBColor[
              0.1836776641650684, 0.31038724924699196`, 0.9337715432962228], 
             UndirectedEdge[72, 284] -> 
             RGBColor[
              0.602700789657427, 0.6868450128545692, 0.9628871876056561], 
             UndirectedEdge[127, 394] -> 
             RGBColor[
              0.348496932711213, 0.47627225997448197`, 0.9434268942819889], 
             UndirectedEdge[110, 385] -> 
             RGBColor[
              0.923690126192328, 0.9380306979900004, 0.809802069993292], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.18382719114068813`, 0.31054441157892615`, 0.933780058636279], 
             UndirectedEdge[97, 393] -> 
             RGBColor[
              0.5102982570407728, 0.6069665111134733, 0.9566203329382144], 
             UndirectedEdge[19, 150] -> 
             RGBColor[
              0.21895975804167556`, 0.3474709669252617, 0.9357808063473152], 
             UndirectedEdge[272, 342] -> 
             RGBColor[
              0.19152273141080622`, 0.31863291232825464`, 0.9342183082701306],
              UndirectedEdge[96, 187] -> 
             RGBColor[
              0.2139882194822336, 0.34224556468553763`, 0.9354976845810872], 
             UndirectedEdge[129, 333] -> 
             RGBColor[
              0.8865563472760825, 0.5573394921368233, 0.5646390445032476], 
             UndirectedEdge[19, 160] -> 
             RGBColor[
              0.19740416245689973`, 0.32481466926196517`, 0.9345532470674082],
              UndirectedEdge[183, 357] -> 
             RGBColor[
              0.18734376764879906`, 0.31424055645277915`, 0.9339803224661072],
              UndirectedEdge[197, 217] -> 
             RGBColor[
              0.19977926755688577`, 0.3273110553124115, 0.9346885057891993], 
             UndirectedEdge[199, 345] -> 
             RGBColor[
              0.9084097409587222, 0.9276827314255283, 0.9099029118424318], 
             UndirectedEdge[44, 346] -> 
             RGBColor[
              0.2158698080892293, 0.3442232336110982, 0.9356048382686947], 
             UndirectedEdge[78, 80] -> 
             RGBColor[
              0.21178615052788774`, 0.3399310505952844, 0.9353722800118063], 
             UndirectedEdge[42, 320] -> 
             RGBColor[
              0.18379681968568948`, 0.3105124892540611, 0.9337783290268474], 
             UndirectedEdge[161, 332] -> 
             RGBColor[
              0.848675629685056, 0.3418959366317691, 0.19294308456495457`], 
             UndirectedEdge[239, 309] -> 
             RGBColor[
              0.6022520031590326, 0.6871316854403461, 0.9624067531432969], 
             UndirectedEdge[8, 377] -> 
             RGBColor[
              0.25514638831763914`, 0.3855054097101751, 0.9378415814082092], 
             UndirectedEdge[75, 126] -> 
             RGBColor[
              0.18223452639463555`, 0.3088704199500476, 0.9336893587351277], 
             UndirectedEdge[54, 310] -> 
             RGBColor[
              0.8873852444618682, 0.5186875281092153, 0.22512385696518958`], 
             UndirectedEdge[65, 211] -> 
             RGBColor[
              0.3044915837808781, 0.4311065625226518, 0.9408810648238439], 
             UndirectedEdge[88, 356] -> 
             RGBColor[
              0.6878897223994248, 0.7529983724170004, 0.962990494071441], 
             UndirectedEdge[98, 158] -> 
             RGBColor[
              0.19219455973941713`, 0.31933904649800093`, 0.9342565678995641],
              UndirectedEdge[13, 390] -> 
             RGBColor[
              0.2131729075996141, 0.34138862020314553`, 0.9354512537755177], 
             UndirectedEdge[241, 242] -> 
             RGBColor[
              0.31065498243158685`, 0.4409219663646659, 0.9411098670507269], 
             UndirectedEdge[12, 238] -> 
             RGBColor[
              0.2218338423144311, 0.3504918117233956, 0.9359444811948219], 
             UndirectedEdge[175, 343] -> 
             RGBColor[
              0.19542826971397487`, 0.32273788071031545`, 0.93444072289877], 
             UndirectedEdge[59, 258] -> 
             RGBColor[
              0.2269624966999203, 0.35588235265801405`, 0.9362365504749113], 
             UndirectedEdge[152, 156] -> 
             RGBColor[
              0.20135778622096587`, 0.32897017851222354`, 0.9347784000919095],
              UndirectedEdge[39, 258] -> 
             RGBColor[
              0.21791338707223826`, 0.34637116469263174`, 0.9357212170685729],
              UndirectedEdge[183, 368] -> 
             RGBColor[
              0.18625851527578347`, 0.31309988739976513`, 0.933918518948951], 
             UndirectedEdge[44, 119] -> 
             RGBColor[
              0.23405162543822766`, 0.3633334764386976, 0.9366402658691317], 
             UndirectedEdge[149, 264] -> 
             RGBColor[
              0.23515256587011008`, 0.3644906346362611, 0.9367029627980321], 
             UndirectedEdge[120, 241] -> 
             RGBColor[
              0.34672955885014695`, 0.4721679512974918, 0.9434085071606221], 
             UndirectedEdge[116, 304] -> 
             RGBColor[
              0.26114585574207083`, 0.3918112303614577, 0.938183242202614], 
             UndirectedEdge[82, 256] -> 
             RGBColor[
              0.8760312800563814, 0.9016669835366705, 0.876948136427472], 
             UndirectedEdge[98, 186] -> 
             RGBColor[
              0.1999149394327242, 0.32745365505601143`, 0.9346962321018197], 
             UndirectedEdge[72, 262] -> 
             RGBColor[
              0.4149349676293397, 0.5334857796550911, 0.9477519352990894], 
             UndirectedEdge[147, 241] -> 
             RGBColor[
              0.2640632471374818, 0.3948775936913327, 0.9383493833266887], 
             UndirectedEdge[13, 205] -> 
             RGBColor[
              0.19925835051903662`, 0.3267635384775842, 0.9346588403345214], 
             UndirectedEdge[142, 394] -> 
             RGBColor[
              0.4158923670367568, 0.5340808989479011, 0.9478776312991117], 
             UndirectedEdge[42, 75] -> 
             RGBColor[
              0.18289766237674282`, 0.30956741791249204`, 0.9337271233482869],
              UndirectedEdge[56, 341] -> 
             RGBColor[
              0.38387079611477953`, 0.499652079122729, 0.9463702293168075], 
             UndirectedEdge[306, 378] -> 
             RGBColor[
              0.23126849430923743`, 0.36040822916142345`, 0.9364817706686093],
              UndirectedEdge[27, 295] -> 
             RGBColor[
              0.19546687096427723`, 0.32277845307184394`, 0.9344429211828693],
              UndirectedEdge[111, 247] -> 
             RGBColor[
              0.8219754147542075, 0.16991824425479435`, 0.1686769880272973], 
             UndirectedEdge[128, 259] -> 
             RGBColor[
              0.599663278641086, 0.6781009426487141, 0.9652528657581285], 
             UndirectedEdge[52, 68] -> 
             RGBColor[
              0.9052995090875355, 0.9251530264391655, 0.9074485213302443], 
             UndirectedEdge[241, 359] -> 
             RGBColor[
              0.3033005319170658, 0.43455191097441853`, 0.9406412479672268], 
             UndirectedEdge[361, 382] -> 
             RGBColor[
              0.3658350125936814, 0.49128963333144304`, 0.9445316614006376], 
             UndirectedEdge[14, 390] -> 
             RGBColor[
              0.27581610861732475`, 0.40446583032584077`, 0.9391199230263283],
              UndirectedEdge[11, 332] -> 
             RGBColor[
              0.8454988743714711, 0.5197931292132254, 0.5762252108529373], 
             UndirectedEdge[22, 209] -> 
             RGBColor[
              0.25353925279510015`, 0.38381620837770913`, 0.9377500574177445],
              UndirectedEdge[33, 156] -> 
             RGBColor[
              0.22423055163894667`, 0.35301090518360945`, 0.9360809702452394],
              UndirectedEdge[283, 332] -> 
             RGBColor[
              0.8748637305772158, 0.45283228980267326`, 0.21438239989975133`],
              UndirectedEdge[150, 181] -> 
             RGBColor[
              0.21526447072748034`, 0.3435869856632946, 0.9355703652014595], 
             UndirectedEdge[117, 323] -> 
             RGBColor[
              0.4895767347577772, 0.5956116976057565, 0.9532057157698048], 
             UndirectedEdge[199, 223] -> 
             RGBColor[
              0.9239760391061387, 0.7216129997514857, 0.5202901272072924], 
             UndirectedEdge[128, 306] -> 
             RGBColor[
              0.2631009453754704, 0.39386615352600307`, 0.9382945816649401], 
             UndirectedEdge[184, 288] -> 
             RGBColor[
              0.21364346222149755`, 0.3418832029456312, 0.9354780511651108], 
             UndirectedEdge[145, 182] -> 
             RGBColor[
              0.24585035887698375`, 0.3757346933657375, 0.937312186283807], 
             UndirectedEdge[284, 397] -> 
             RGBColor[
              0.5520222170780682, 0.6432815473581924, 0.9595663255932364], 
             UndirectedEdge[61, 148] -> 
             RGBColor[
              0.23690961095816437`, 0.3663374004268991, 0.9368030239164815], 
             UndirectedEdge[34, 159] -> 
             RGBColor[
              0.1825395439463383, 0.30919101273611693`, 0.9337067290334642], 
             UndirectedEdge[276, 382] -> 
             RGBColor[
              0.35057061271571854`, 0.4780683773681971, 0.9435590273381926], 
             UndirectedEdge[59, 164] -> 
             RGBColor[
              0.215632569168565, 0.3439738804636637, 0.9355913278631264], 
             UndirectedEdge[80, 377] -> 
             RGBColor[
              0.2289003475673298, 0.3579191567865028, 0.9363469082150169], 
             UndirectedEdge[180, 370] -> 
             RGBColor[
              0.18698550798658503`, 0.3138640028328177, 0.9339599201083417], 
             UndirectedEdge[98, 374] -> 
             RGBColor[
              0.18844266475489285`, 0.3153955669853844, 0.9340429030306268], 
             UndirectedEdge[139, 350] -> 
             RGBColor[
              0.3277444111277722, 0.4581308203867991, 0.942110663773315], 
             UndirectedEdge[36, 276] -> 
             RGBColor[
              0.31234957064668134`, 0.4391299345139409, 0.941337201922877], 
             UndirectedEdge[53, 281] -> 
             RGBColor[
              0.40067800773256046`, 0.5214688844608842, 0.9467518262404362], 
             UndirectedEdge[73, 183] -> 
             RGBColor[
              0.19359784833893534`, 0.3208139917897307, 0.9343364831093273], 
             UndirectedEdge[101, 115] -> 
             RGBColor[
              0.9045408089975616, 0.6377980714511916, 0.24102778506069641`], 
             UndirectedEdge[283, 366] -> 
             RGBColor[
              0.9626113006296535, 0.8779402128312055, 0.388106189025446], 
             UndirectedEdge[22, 141] -> 
             RGBColor[
              0.2988998919025237, 0.4271457198066904, 0.9404924581847806], 
             UndirectedEdge[197, 314] -> 
             RGBColor[
              0.18703267242257346`, 0.3139135756454394, 0.9339626060531978], 
             UndirectedEdge[13, 14] -> 
             RGBColor[
              0.27600611579144196`, 0.4046655399129887, 0.9391307436538039], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.18066543438157506`, 0.30722120475814135`, 0.9336000012662475],
              UndirectedEdge[323, 395] -> 
             RGBColor[
              0.42965137086591587`, 0.5465641553634234, 0.9485979833191546], 
             UndirectedEdge[93, 131] -> 
             RGBColor[
              0.5783198351360825, 0.6629059133309206, 0.9625766163950823], 
             UndirectedEdge[52, 105] -> 
             RGBColor[
              0.9871484754393005, 0.988953578572104, 0.8626465508576164], 
             UndirectedEdge[178, 330] -> 
             RGBColor[
              0.18585403499635023`, 0.3126747529805498, 0.9338954843954123], 
             UndirectedEdge[92, 98] -> 
             RGBColor[
              0.19880960071600262`, 0.32629187398221465`, 0.9346332846971046],
              UndirectedEdge[37, 323] -> 
             RGBColor[
              0.35247668459828785`, 0.4774620340320098, 0.9437631308877006], 
             UndirectedEdge[279, 370] -> 
             RGBColor[
              0.19229180160053655`, 0.3194412538595276, 0.9342621056796985], 
             UndirectedEdge[150, 160] -> 
             RGBColor[
              0.2168510680318782, 0.345254600026296, 0.9356607195707846], 
             UndirectedEdge[188, 273] -> 
             RGBColor[
              0.39992754574806544`, 0.5158532142548906, 0.9473461281045827], 
             UndirectedEdge[179, 386] -> 
             RGBColor[
              0.284370042597393, 0.41315352294311436`, 0.9396181524839584], 
             UndirectedEdge[141, 179] -> 
             RGBColor[
              0.2912900071166007, 0.41914724840212236`, 0.9400590865040379], 
             UndirectedEdge[117, 388] -> 
             RGBColor[
              0.4146565458770389, 0.527209517044103, 0.9485603887539554], 
             UndirectedEdge[198, 214] -> 
             RGBColor[
              0.8538594754790496, 0.7047084000192836, 0.6021070091036955], 
             UndirectedEdge[150, 238] -> 
             RGBColor[
              0.21964443169265407`, 0.3481906023432569, 0.9358197974988545], 
             UndirectedEdge[331, 392] -> 
             RGBColor[
              0.22201549227327083`, 0.35068273734740874`, 0.9359548258912509],
              UndirectedEdge[323, 365] -> 
             RGBColor[
              0.3633194234507374, 0.48885844003528395`, 0.9443806088249529], 
             UndirectedEdge[6, 71] -> 
             RGBColor[
              0.9479335881069795, 0.9604436363507414, 0.9644935461230137], 
             UndirectedEdge[132, 249] -> 
             RGBColor[
              0.18824799980109214`, 0.3151909617764689, 0.9340318171494888], 
             UndirectedEdge[348, 378] -> 
             RGBColor[
              0.22067056618642705`, 0.3492691347568969, 0.935878234340245], 
             UndirectedEdge[174, 198] -> 
             RGBColor[
              0.6233166189809511, 0.701327344471203, 0.9656888716580491], 
             UndirectedEdge[72, 236] -> 
             RGBColor[
              0.4875863338308316, 0.5948835771747154, 0.9528037287682061], 
             UndirectedEdge[9, 100] -> 
             RGBColor[
              0.5370355289675518, 0.6325732881317867, 0.9576495756744858], 
             UndirectedEdge[51, 298] -> 
             RGBColor[
              0.20333725610200998`, 0.3310507268628402, 0.9348911279732717], 
             UndirectedEdge[23, 128] -> 
             RGBColor[
              0.2579108106564282, 0.38841099286274205`, 0.9379990111708069], 
             UndirectedEdge[215, 353] -> 
             RGBColor[
              0.8496653857450382, 0.8791494975932964, 0.7395436178949295], 
             UndirectedEdge[80, 96] -> 
             RGBColor[
              0.2073679300463957, 0.3352872207378781, 0.9351206688915568], 
             UndirectedEdge[78, 388] -> 
             RGBColor[
              0.2456236030410635, 0.37549635860503494`, 0.9372992728744065], 
             UndirectedEdge[312, 380] -> 
             RGBColor[
              0.6340993587155315, 0.7126342355184634, 0.9651549462114524], 
             UndirectedEdge[57, 325] -> 
             RGBColor[
              0.29328547563165996`, 0.42193506719570584`, 0.9401474445490827],
              UndirectedEdge[308, 374] -> 
             RGBColor[
              0.1982421611639798, 0.32569545903529307`, 0.9346009698540684], 
             UndirectedEdge[76, 365] -> 
             RGBColor[
              0.2944759917270998, 0.42684331653440033`, 0.9400813441394438], 
             UndirectedEdge[182, 187] -> 
             RGBColor[
              0.22908739425404853`, 0.35811575471368917`, 0.9363575602471148],
              UndirectedEdge[74, 286] -> 
             RGBColor[
              0.28488862903471124`, 0.4156109198533938, 0.9395776654568602], 
             UndirectedEdge[137, 164] -> 
             RGBColor[
              0.2538187120761361, 0.3841099378008197, 0.9377659722103766], 
             UndirectedEdge[149, 258] -> 
             RGBColor[
              0.22398941258529487`, 0.35275745274912235`, 0.9360672377328672],
              UndirectedEdge[147, 331] -> 
             RGBColor[
              0.2440919709450002, 0.37388651616098867`, 0.9372120486923824], 
             UndirectedEdge[42, 367] -> 
             RGBColor[
              0.1849893429390042, 0.3117659068036362, 0.9338462414619436], 
             UndirectedEdge[16, 365] -> 
             RGBColor[
              0.2674853323456614, 0.39847442221786333`, 0.9385442660167731], 
             UndirectedEdge[113, 183] -> 
             RGBColor[
              0.18716623928349274`, 0.31405396288489373`, 0.9339702124883327],
              UndirectedEdge[16, 323] -> 
             RGBColor[
              0.3247877744177019, 0.4483592338539112, 0.9421862884149881], 
             UndirectedEdge[340, 343] -> 
             RGBColor[
              0.2360559349263153, 0.3654401327912391, 0.9367544083293682], 
             UndirectedEdge[323, 362] -> 
             RGBColor[
              0.6059463857156073, 0.6878046821697024, 0.9639263891716204], 
             UndirectedEdge[334, 364] -> 
             RGBColor[
              0.9407749655383337, 0.8016431292497415, 0.27774757447488835`], 
             UndirectedEdge[94, 324] -> 
             RGBColor[
              0.18239675869616345`, 0.30904093638507546`, 0.9336985976246985],
              UndirectedEdge[135, 350] -> 
             RGBColor[
              0.3419502599754641, 0.47060186109611535`, 0.9430097460842624], 
             UndirectedEdge[31, 215] -> 
             RGBColor[
              0.8451646800561206, 0.8790328648583385, 0.9409404903646027], 
             UndirectedEdge[3, 21] -> 
             RGBColor[
              0.21644166427209716`, 0.34482429071706844`, 0.9356374046323236],
              UndirectedEdge[127, 193] -> 
             RGBColor[
              0.5886484429999097, 0.6709855269816585, 0.9636243911098379], 
             UndirectedEdge[50, 230] -> 
             RGBColor[
              0.2261265468612622, 0.35500371637530337`, 0.9361889443682767], 
             UndirectedEdge[169, 382] -> 
             RGBColor[
              0.38967734439969204`, 0.5118336629702842, 0.9460804380697425], 
             UndirectedEdge[12, 19] -> 
             RGBColor[
              0.22114916866345258`, 0.3497721763054004, 0.9359054900432826], 
             UndirectedEdge[133, 296] -> 
             RGBColor[
              0.18124069831826523`, 0.30782584362944293`, 0.9336327616964153],
              UndirectedEdge[214, 332] -> 
             RGBColor[
              0.8483631502363858, 0.34047704043678684`, 0.1926823440534119], 
             UndirectedEdge[76, 395] -> 
             RGBColor[
              0.36080793914227827`, 0.4845490318625397, 0.9442987186336453], 
             UndirectedEdge[299, 370] -> 
             RGBColor[
              0.1869681936623269, 0.3138458043802308, 0.9339589340831895], 
             UndirectedEdge[170, 235] -> 
             RGBColor[
              0.21437654864384317`, 0.34265372325588017`, 0.9355197993523594],
              UndirectedEdge[46, 400] -> 
             RGBColor[
              0.81382584660932, 0.509501659616798, 0.5750314348940344], 
             UndirectedEdge[65, 329] -> 
             RGBColor[
              0.31941652727713654`, 0.4467936244332925, 0.9417310182764805], 
             UndirectedEdge[81, 267] -> 
             RGBColor[
              0.21336000502701669`, 0.3415852714620077, 0.9354619086972226], 
             UndirectedEdge[104, 182] -> 
             RGBColor[
              0.23293840827128548`, 0.36216341461419643`, 0.9365768697983317],
              UndirectedEdge[23, 306] -> 
             RGBColor[
              0.21710981978146196`, 0.345526564520917, 0.9356754551001344], 
             UndirectedEdge[209, 286] -> 
             RGBColor[
              0.29314447532730914`, 0.4242883377578022, 0.9400478236897936], 
             UndirectedEdge[150, 167] -> 
             RGBColor[
              0.2371065726737784, 0.3665444196781035, 0.936814240594807], 
             UndirectedEdge[4, 288] -> 
             RGBColor[
              0.2072894767278965, 0.33520476132590776`, 0.9351162010911295], 
             UndirectedEdge[171, 272] -> 
             RGBColor[
              0.19235235421379315`, 0.3195048984953177, 0.9342655540614437], 
             UndirectedEdge[78, 182] -> 
             RGBColor[
              0.23114667261114863`, 0.3602801868327903, 0.9364748331031223], 
             UndirectedEdge[143, 374] -> 
             RGBColor[
              0.1912700084764235, 0.3183672845006589, 0.9342039160728877], 
             UndirectedEdge[55, 262] -> 
             RGBColor[
              0.5840352729572464, 0.6682969151994234, 0.9627543260164191], 
             UndirectedEdge[165, 190] -> 
             RGBColor[
              0.21884661716031273`, 0.34735204868540315`, 0.9357743631414985],
              UndirectedEdge[2, 149] -> 
             RGBColor[
              0.20607580619388693`, 0.3339291166435074, 0.9350470843496823], 
             UndirectedEdge[39, 47] -> 
             RGBColor[
              0.18958921033534365`, 0.3166006590856267, 0.9341081971052712], 
             UndirectedEdge[230, 300] -> 
             RGBColor[
              0.2086431877242838, 0.3366275974133453, 0.9351932929297377], 
             UndirectedEdge[40, 48] -> 
             RGBColor[
              0.20069384731952558`, 0.3282723366306521, 0.934740589753682], 
             UndirectedEdge[25, 208] -> 
             RGBColor[
              0.3291899186131193, 0.4582247733572693, 0.9422451729560961], 
             UndirectedEdge[32, 52] -> 
             RGBColor[
              0.905256763296387, 0.5780630184234903, 0.500145144132204], 
             UndirectedEdge[161, 366] -> 
             RGBColor[
              0.9364231997374939, 0.7670038596603013, 0.3666668736906492], 
             UndirectedEdge[190, 318] -> 
             RGBColor[
              0.21280458260693721`, 0.34100148728268875`, 0.9354302782120729],
              UndirectedEdge[179, 245] -> 
             RGBColor[
              0.21085364957036085`, 0.33895093296494805`, 0.9353191754617867],
              UndirectedEdge[37, 182] -> 
             RGBColor[
              0.26307956528763465`, 0.3938436816981118, 0.9382933641005669], 
             UndirectedEdge[12, 206] -> 
             RGBColor[
              0.33583694364464667`, 0.4592083134506097, 0.9428435069438263], 
             UndirectedEdge[18, 218] -> 
             RGBColor[
              0.776406098847213, 0.8201699347730458, 0.6937389035902746], 
             UndirectedEdge[92, 119] -> 
             RGBColor[
              0.22208012665594387`, 0.3507506721816547, 0.9359585067237262], 
             UndirectedEdge[215, 400] -> 
             RGBColor[
              0.7640930948428964, 0.47065005595395515`, 0.5700745389769464], 
             UndirectedEdge[71, 292] -> 
             RGBColor[
              0.8945978800262582, 0.5638772618194792, 0.5512331862497395], 
             UndirectedEdge[158, 346] -> 
             RGBColor[
              0.19728326833036003`, 0.3246876018698416, 0.9345463623257486], 
             UndirectedEdge[92, 151] -> 
             RGBColor[
              0.20599136961110498`, 0.33384036844141496`, 0.9350422758112056],
              UndirectedEdge[104, 170] -> 
             RGBColor[
              0.22977658578143667`, 0.35884013870624076`, 0.936396808685032], 
             UndirectedEdge[82, 316] -> 
             RGBColor[
              0.7359499332008539, 0.7936489483339444, 0.9743162695644639], 
             UndirectedEdge[287, 353] -> 
             RGBColor[
              0.9052894000566567, 0.5610593594590743, 0.33598351095262347`], 
             UndirectedEdge[368, 372] -> 
             RGBColor[
              0.1818899475322301, 0.30850824571809776`, 0.9336697354786725], 
             UndirectedEdge[9, 203] -> 
             RGBColor[
              0.4981842108201723, 0.5989222290765547, 0.9551740040370065], 
             UndirectedEdge[17, 384] -> 
             RGBColor[
              0.8806232133780418, 0.49400904252402256`, 0.21977054774648136`],
              UndirectedEdge[82, 310] -> 
             RGBColor[
              0.7931376486603983, 0.5085364648564028, 0.5748575062936936], 
             UndirectedEdge[129, 287] -> 
             RGBColor[
              0.8183275809306592, 0.1418793949960282, 0.16518381823822845`], 
             UndirectedEdge[81, 363] -> 
             RGBColor[
              0.3018408929173706, 0.42850250201273, 0.940723448587576], 
             UndirectedEdge[64, 356] -> 
             RGBColor[
              0.9689844051155808, 0.9726683265613763, 0.7058319664887789], 
             UndirectedEdge[245, 352] -> 
             RGBColor[
              0.1906398234149592, 0.3177049200450192, 0.9341680279659126], 
             UndirectedEdge[87, 232] -> 
             RGBColor[
              0.18860427170948546`, 0.315565426141134, 0.9340521063076146], 
             UndirectedEdge[88, 255] -> 
             RGBColor[
              0.40229233650521606`, 0.5228671349052352, 0.9468546898423349], 
             UndirectedEdge[154, 392] -> 
             RGBColor[
              0.19471742420704347`, 0.3219907370123223, 0.934400241298752], 
             UndirectedEdge[22, 45] -> 
             RGBColor[
              0.24087710963769857`, 0.3705074930930349, 0.9370289670968927], 
             UndirectedEdge[116, 141] -> 
             RGBColor[
              0.29789401265983945`, 0.4260884769462017, 0.9404351748499746], 
             UndirectedEdge[97, 224] -> 
             RGBColor[
              0.3981861519254275, 0.5171684195208632, 0.946960633454442], 
             UndirectedEdge[66, 151] -> 
             RGBColor[
              0.20186975982558952`, 0.3295082952316844, 0.9348075562312959], 
             UndirectedEdge[165, 221] -> 
             RGBColor[
              0.29772616502322835`, 0.42460426174906063`, 0.9404735010185594],
              UndirectedEdge[101, 332] -> 
             RGBColor[
              0.8358893322460044, 0.27686671121426787`, 0.18200097113096422`],
              UndirectedEdge[58, 396] -> 
             RGBColor[
              0.18880077082680655`, 0.315771959172202, 0.9340632966416518], 
             UndirectedEdge[35, 387] -> 
             RGBColor[
              0.1878209095169145, 0.3147420628087102, 0.9340074949896282], 
             UndirectedEdge[198, 266] -> 
             RGBColor[0.74350964112616, 0.79962588641691, 0.9750508465456946],
              UndirectedEdge[188, 264] -> 
             RGBColor[
              0.26789407428573686`, 0.39890403591261847`, 0.9385675432655809],
              UndirectedEdge[119, 151] -> 
             RGBColor[
              0.22370106658388367`, 0.35245438281944674`, 0.9360508168546565],
              UndirectedEdge[247, 400] -> 
             RGBColor[
              0.8197269815986742, 0.15263580175167407`, 0.16652388589831657`],
              UndirectedEdge[305, 361] -> 
             RGBColor[
              0.353816749645949, 0.47989197268582956`, 0.9438020454927423], 
             UndirectedEdge[138, 210] -> 
             RGBColor[
              0.2672929528119248, 0.3982722191303392, 0.9385333102869269], 
             UndirectedEdge[197, 231] -> 
             RGBColor[
              0.19125913163260555`, 0.3183558522481745, 0.9342032966527232], 
             UndirectedEdge[225, 261] -> 
             RGBColor[
              0.19884280647751676`, 0.32632677534293286`, 0.9346351757160992],
              UndirectedEdge[83, 286] -> 
             RGBColor[
              0.6361141683386347, 0.7078159235332517, 0.9547721155282454], 
             UndirectedEdge[19, 238] -> 
             RGBColor[
              0.20019752611767563`, 0.32775067157892607`, 0.9347123249954781],
              UndirectedEdge[62, 117] -> 
             RGBColor[
              0.7751677288121797, 0.821679420316278, 0.8719418433976884], 
             UndirectedEdge[65, 167] -> 
             RGBColor[
              0.30615029923372655`, 0.43284997763222943`, 0.940975526215034], 
             UndirectedEdge[268, 371] -> 
             RGBColor[
              0.1838466718007321, 0.3105648869877775, 0.9337811680310495], 
             UndirectedEdge[172, 192] -> 
             RGBColor[
              0.31894488906729196`, 0.44600858518137365`, 0.9417147525123752],
              UndirectedEdge[52, 353] -> 
             RGBColor[
              0.9911272301605415, 0.9888543711683995, 0.6698997566881519], 
             UndirectedEdge[126, 298] -> 
             RGBColor[
              0.194012535572622, 0.32124985436502457`, 0.9343600989338109], 
             UndirectedEdge[146, 306] -> 
             RGBColor[
              0.2107146293415335, 0.33880481389005895`, 0.9353112584654169], 
             UndirectedEdge[21, 132] -> 
             RGBColor[
              0.1947709663990963, 0.3220470132509409, 0.9344032904473808], 
             UndirectedEdge[89, 162] -> 
             RGBColor[
              0.2137613905296329, 0.342007153074568, 0.9354847670077999], 
             UndirectedEdge[9, 18] -> 
             RGBColor[
              0.8394473584119997, 0.8706756474406323, 0.6991625748728455], 
             UndirectedEdge[255, 360] -> 
             RGBColor[
              0.5184721491114823, 0.6174970812936685, 0.956042445038614], 
             UndirectedEdge[124, 152] -> 
             RGBColor[
              0.2137312689052459, 0.34197549333751603`, 0.935483051625852], 
             UndirectedEdge[88, 389] -> 
             RGBColor[
              0.7117595806289345, 0.7674543626326005, 0.720767374949669], 
             UndirectedEdge[12, 167] -> 
             RGBColor[
              0.2392959832955554, 0.36884562905824225`, 0.9369389242907744], 
             UndirectedEdge[32, 303] -> 
             RGBColor[
              0.857724462248068, 0.3888260026114282, 0.20072238804006853`], 
             UndirectedEdge[49, 261] -> 
             RGBColor[
              0.1864507904031121, 0.31330198074953464`, 0.9339294687330069], 
             UndirectedEdge[283, 360] -> 
             RGBColor[
              0.7973390261209754, 0.7521357532053826, 0.6155512086405578], 
             UndirectedEdge[282, 305] -> 
             RGBColor[
              0.30654149170312617`, 0.4389445203793095, 0.9407897078604948], 
             UndirectedEdge[32, 385] -> 
             RGBColor[
              0.907968224972722, 0.5784385570350095, 0.40100320095353803`], 
             UndirectedEdge[167, 216] -> 
             RGBColor[
              0.22581143984224178`, 0.35467251891937396`, 0.9361709994897025],
              UndirectedEdge[252, 318] -> 
             RGBColor[
              0.20969889594004104`, 0.3377372136838731, 0.9352534139508448], 
             UndirectedEdge[2, 217] -> 
             RGBColor[
              0.20503618363244414`, 0.3328364074155535, 0.9349878793827919], 
             UndirectedEdge[305, 329] -> 
             RGBColor[
              0.28019918973537505`, 0.41183749243956935`, 0.9392683013866509],
              UndirectedEdge[87, 373] -> 
             RGBColor[
              0.19241687464340246`, 0.3195727135576686, 0.9342692284044607], 
             UndirectedEdge[20, 241] -> 
             RGBColor[
              0.33276855688740864`, 0.46007563309772936`, 0.9425189244607857],
              UndirectedEdge[59, 210] -> 
             RGBColor[
              0.23097654198013617`, 0.36010136875269116`, 0.9364651444153718],
              UndirectedEdge[290, 304] -> 
             RGBColor[
              0.2699001201696922, 0.4010125173273108, 0.9386817846109934], 
             UndirectedEdge[115, 312] -> 
             RGBColor[
              0.7514622050621471, 0.7517529361696669, 0.6201411074573389], 
             UndirectedEdge[214, 389] -> 
             RGBColor[
              0.9360223295752915, 0.7653959046667461, 0.35678534949539953`], 
             UndirectedEdge[144, 276] -> 
             RGBColor[
              0.48015124453344243`, 0.5868307576532874, 0.952775625742377], 
             UndirectedEdge[196, 286] -> 
             RGBColor[
              0.5826840049020053, 0.6656063435828412, 0.963342437992916], 
             UndirectedEdge[124, 181] -> 
             RGBColor[
              0.209370470104526, 0.33739201730734614`, 0.9352347105853747], 
             UndirectedEdge[216, 341] -> 
             RGBColor[
              0.2325799518711988, 0.3617866542102568, 0.9365564562366354], 
             UndirectedEdge[294, 340] -> 
             RGBColor[
              0.24056246391472638`, 0.3701767804885, 0.937011048488446], 
             UndirectedEdge[104, 235] -> 
             RGBColor[
              0.20864915250350596`, 0.3366338667744967, 0.9351936326150905], 
             UndirectedEdge[125, 318] -> 
             RGBColor[
              0.20302734583193666`, 0.33072499151954715`, 0.9348734790418622],
              UndirectedEdge[109, 232] -> 
             RGBColor[
              0.18655512715268852`, 0.3134116452886715, 0.9339354105565427], 
             UndirectedEdge[182, 388] -> 
             RGBColor[
              0.2563045573313864, 0.38672271877578024`, 0.9379075374201846], 
             UndirectedEdge[97, 382] -> 
             RGBColor[
              0.3103603612224796, 0.44230450028690405`, 0.9410311290958356], 
             UndirectedEdge[140, 147] -> 
             RGBColor[
              0.32678087214865287`, 0.45177394646584723`, 0.9422514665551494],
              UndirectedEdge[59, 300] -> 
             RGBColor[
              0.20621668709807878`, 0.3340771914061782, 0.9350551073087614], 
             UndirectedEdge[205, 373] -> 
             RGBColor[
              0.19156946915989134`, 0.31868203666588757`, 0.9342209699157987],
              UndirectedEdge[215, 259] -> 
             RGBColor[
              0.8007477962042493, 0.8448792898490222, 0.9806129038326282], 
             UndirectedEdge[136, 300] -> 
             RGBColor[
              0.18939860406094253`, 0.3164003198060953, 0.9340973423599207], 
             UndirectedEdge[152, 245] -> 
             RGBColor[
              0.19786899137363773`, 0.3253032339253123, 0.9345797183865636], 
             UndirectedEdge[44, 128] -> 
             RGBColor[
              0.26610768174908467`, 0.39702642409276845`, 0.9384658108533496],
              UndirectedEdge[241, 392] -> 
             RGBColor[
              0.24198676846575243`, 0.37167381487775275`, 0.9370921605255572],
              UndirectedEdge[240, 342] -> 
             RGBColor[
              0.18286346184170274`, 0.30953147098172573`, 0.9337251756784115],
              UndirectedEdge[123, 214] -> 
             RGBColor[
              0.8610395973659686, 0.437913767929313, 0.20482132414069976`], 
             UndirectedEdge[125, 274] -> 
             RGBColor[
              0.19786901158433057`, 0.32530325516803194`, 0.9345797195375327],
              UndirectedEdge[298, 373] -> 
             RGBColor[
              0.20172543232639267`, 0.32935659787913657`, 0.93479933699373], 
             UndirectedEdge[119, 350] -> 
             RGBColor[
              0.2941675459212899, 0.42283940615857285`, 0.9401985109723265], 
             UndirectedEdge[22, 179] -> 
             RGBColor[
              0.2344230766191157, 0.3637238951811761, 0.9366614194643705], 
             UndirectedEdge[1, 183] -> 
             RGBColor[
              0.18524860197516257`, 0.312038404488611, 0.9338610058805135], 
             UndirectedEdge[112, 260] -> 
             RGBColor[
              0.18468581634927816`, 0.3114468811131368, 0.9338289560716861], 
             UndirectedEdge[183, 270] -> 
             RGBColor[
              0.198314467229445, 0.32577145729456636`, 0.9346050875775294], 
             UndirectedEdge[152, 181] -> 
             RGBColor[
              0.1964830766390266, 0.32384654966716653`, 0.9345007925927047], 
             UndirectedEdge[169, 276] -> 
             RGBColor[
              0.41815198956691846`, 0.5364969694368562, 0.947894817280658], 
             UndirectedEdge[349, 355] -> 
             RGBColor[
              0.20327760071832918`, 0.33098802527222193`, 0.9348877306874234],
              UndirectedEdge[171, 240] -> 
             RGBColor[
              0.18369308464468964`, 0.3104034571487888, 0.9337724214697247], 
             UndirectedEdge[114, 132] -> 
             RGBColor[
              0.1897759122485969, 0.31679689463404087`, 0.9341188295030303], 
             UndirectedEdge[17, 222] -> 
             RGBColor[
              0.88937458998013, 0.5883335736307327, 0.570901233962067], 
             UndirectedEdge[46, 259] -> 
             RGBColor[
              0.850480547970673, 0.8837308935118651, 0.9855697997497163], 
             UndirectedEdge[13, 79] -> 
             RGBColor[
              0.20620705634176517`, 0.33406706887066745`, 0.9350545588514367],
              UndirectedEdge[146, 311] -> 
             RGBColor[
              0.20086274150294195`, 0.3284498551259324, 0.9347502080275711], 
             UndirectedEdge[44, 275] -> 
             RGBColor[
              0.21122882729611786`, 0.33934526854236047`, 0.9353405412782427],
              UndirectedEdge[193, 195] -> 
             RGBColor[
              0.6312732042379722, 0.7079049527832757, 0.9663404032043308], 
             UndirectedEdge[86, 297] -> 
             RGBColor[
              0.28232965171394053`, 0.4140767430581329, 0.9393896280445941], 
             UndirectedEdge[197, 392] -> 
             RGBColor[
              0.19718685275102665`, 0.3245862629828614, 0.9345408716011396], 
             UndirectedEdge[217, 392] -> 
             RGBColor[
              0.20565454435776198`, 0.333486343744197, 0.935023094111316], 
             UndirectedEdge[101, 193] -> 
             RGBColor[
              0.8459509404020927, 0.6447383034706259, 0.5918610769410064], 
             UndirectedEdge[216, 340] -> 
             RGBColor[
              0.2436041993290528, 0.3733738372661213, 0.9371842708204476], 
             UndirectedEdge[125, 190] -> 
             RGBColor[
              0.20237543357367466`, 0.3300397904024893, 0.934836353603172], 
             UndirectedEdge[99, 276] -> 
             RGBColor[
              0.6406056746670367, 0.7137792263922267, 0.9679520038982681], 
             UndirectedEdge[27, 63] -> 
             RGBColor[
              0.1971785692903057, 0.32457755654044196`, 0.9345403998703059], 
             UndirectedEdge[184, 226] -> 
             RGBColor[
              0.20272879549405032`, 0.3304111961852439, 0.9348564770417853], 
             UndirectedEdge[107, 211] -> 
             RGBColor[
              0.2277850924450354, 0.3567469529417126, 0.9362833960856742], 
             UndirectedEdge[216, 294] -> 
             RGBColor[
              0.21277466253925434`, 0.3409700393945122, 0.9354285743084811], 
             UndirectedEdge[68, 284] -> 
             RGBColor[
              0.7807346086845934, 0.8286481739482061, 0.9787765120052747], 
             UndirectedEdge[89, 359] -> 
             RGBColor[
              0.2789577626844565, 0.40896611709023306`, 0.9392549632713296], 
             UndirectedEdge[23, 267] -> 
             RGBColor[
              0.20474185831720654`, 0.33252705284793593`, 0.9349711179915043],
              UndirectedEdge[140, 242] -> 
             RGBColor[
              0.3733726074427579, 0.4978183191391804, 0.9450119502791875], 
             UndirectedEdge[64, 214] -> 
             RGBColor[
              0.9357533158900353, 0.7648205115954387, 0.32750487001527717`], 
             UndirectedEdge[296, 367] -> 
             RGBColor[
              0.18258473603098674`, 0.3092385124824261, 0.9337093026558292], 
             UndirectedEdge[275, 346] -> 
             RGBColor[
              0.1987852081376144, 0.3262662358357499, 0.9346318955758508], 
             UndirectedEdge[301, 305] -> 
             RGBColor[
              0.27396377293596785`, 0.4052836740351331, 0.9389132036243971], 
             UndirectedEdge[81, 119] -> 
             RGBColor[
              0.2344729010553813, 0.363776263822743, 0.9366642568923073], 
             UndirectedEdge[327, 355] -> 
             RGBColor[
              0.19695189529636073`, 0.3243393078008444, 0.9345274911216848], 
             UndirectedEdge[317, 344] -> 
             RGBColor[
              0.19003331843460333`, 0.31706744485602845`, 0.9341334884045249],
              UndirectedEdge[184, 190] -> 
             RGBColor[
              0.21285282401079259`, 0.34105219205682236`, 0.9354330254886557],
              UndirectedEdge[10, 303] -> 
             RGBColor[
              0.8684485783796092, 0.4712562585361081, 0.21099181375878928`], 
             UndirectedEdge[149, 268] -> 
             RGBColor[
              0.19899317290676588`, 0.326484819993856, 0.9346437388617977], 
             UndirectedEdge[38, 267] -> 
             RGBColor[
              0.22814489442186137`, 0.3571251276321197, 0.9363038862759752], 
             UndirectedEdge[253, 366] -> 
             RGBColor[
              0.9092462276793383, 0.5913616030865398, 0.3419442339894627], 
             UndirectedEdge[165, 355] -> 
             RGBColor[
              0.2168405199897158, 0.34524351336519876`, 0.9356601188753879], 
             UndirectedEdge[339, 340] -> 
             RGBColor[
              0.326674769743479, 0.4539173667672604, 0.9421628597566036], 
             UndirectedEdge[185, 318] -> 
             RGBColor[
              0.20300306708120197`, 0.33069947301316327`, 0.9348720964029251],
              UndirectedEdge[36, 70] -> 
             RGBColor[
              0.22130912604082534`, 0.3499403016509027, 0.9359145993792883], 
             UndirectedEdge[69, 131] -> 
             RGBColor[
              0.693464422361174, 0.75939366397809, 0.9708100489116116], 
             UndirectedEdge[283, 312] -> 
             RGBColor[
              0.7398695405352704, 0.7057918843470511, 0.6108133774642039], 
             UndirectedEdge[75, 330] -> 
             RGBColor[
              0.18530504232011252`, 0.31209772686967785`, 0.9338642200746624],
              UndirectedEdge[169, 222] -> 
             RGBColor[
              0.7041731063901011, 0.7666519834125803, 0.9590482629072343], 
             UndirectedEdge[90, 246] -> 
             RGBColor[
              0.21613530957472, 0.3445022925061154, 0.9356199581855191], 
             UndirectedEdge[62, 362] -> 
             RGBColor[
              0.8915373797700097, 0.913872404880224, 0.882662516799504], 
             UndirectedEdge[158, 374] -> 
             RGBColor[
              0.1873884527454699, 0.3142875233225789, 0.9339828672162569], 
             UndirectedEdge[82, 172] -> 
             RGBColor[
              0.5696909718954926, 0.6577404259092337, 0.9610497684809419], 
             UndirectedEdge[306, 346] -> 
             RGBColor[
              0.21286307171561503`, 0.3410629630443328, 0.9354336090802852], 
             UndirectedEdge[53, 188] -> 
             RGBColor[
              0.33920701496392514`, 0.465180569896386, 0.9429464497347737], 
             UndirectedEdge[84, 190] -> 
             RGBColor[
              0.21321988075352158`, 0.3414379919661722, 0.9354539288271424], 
             UndirectedEdge[78, 96] -> 
             RGBColor[
              0.2160474978393337, 0.3444099968046388, 0.9356149574370947], 
             UndirectedEdge[46, 199] -> 
             RGBColor[
              0.8971361136435547, 0.9188102209856679, 0.9087966349847089], 
             UndirectedEdge[159, 265] -> 
             RGBColor[
              0.19056897353088317`, 0.3176304523247132, 0.9341639931698273], 
             UndirectedEdge[332, 356] -> 
             RGBColor[
              0.8815942394619314, 0.5483248554027244, 0.5710094405269136], 
             UndirectedEdge[199, 222] -> 
             RGBColor[
              0.9699116219534045, 0.9763258350817114, 0.9020107810264453], 
             UndirectedEdge[114, 300] -> 
             RGBColor[
              0.19141939910096473`, 0.3185243035189643, 0.9342124236479517], 
             UndirectedEdge[139, 213] -> 
             RGBColor[
              0.3161784578429658, 0.4481129729732145, 0.941373691457378], 
             UndirectedEdge[106, 369] -> 
             RGBColor[
              0.18346224485360668`, 0.3101608298922725, 0.9337592754851194], 
             UndirectedEdge[109, 114] -> 
             RGBColor[
              0.18471405231964982`, 0.3114765589082613, 0.9338305640684275], 
             UndirectedEdge[58, 245] -> 
             RGBColor[
              0.1940488178607217, 0.32128798935024727`, 0.9343621651564433], 
             UndirectedEdge[151, 317] -> 
             RGBColor[
              0.1980582216182819, 0.3255021269103238, 0.9345904947690551], 
             UndirectedEdge[99, 218] -> 
             RGBColor[
              0.7312212189545854, 0.7893616865114603, 0.9745283770409688], 
             UndirectedEdge[55, 57] -> 
             RGBColor[
              0.5760181454967422, 0.6613528823456771, 0.9622434817439033], 
             UndirectedEdge[247, 287] -> 
             RGBColor[
              0.8173288724441594, 0.1342028839319411, 0.1642274538636763], 
             UndirectedEdge[44, 66] -> 
             RGBColor[
              0.21222031867993352`, 0.3403873888509353, 0.9353970052457711], 
             UndirectedEdge[116, 290] -> 
             RGBColor[
              0.24877546734729164`, 0.3788091678306199, 0.9374787668838809], 
             UndirectedEdge[278, 367] -> 
             RGBColor[
              0.18709347932173553`, 0.31397748755183885`, 0.9339660689161493],
              UndirectedEdge[102, 297] -> 
             RGBColor[
              0.32279739953618347`, 0.45288594084814915`, 0.9418305958510031],
              UndirectedEdge[104, 187] -> 
             RGBColor[
              0.2201981756238625, 0.34877262232435, 0.935851332396546], 
             UndirectedEdge[136, 371] -> 
             RGBColor[
              0.1813347042579621, 0.3079246498323852, 0.9336381151956117], 
             UndirectedEdge[80, 302] -> 
             RGBColor[
              0.1989040089899044, 0.3263911030639157, 0.9346386611086387], 
             UndirectedEdge[176, 373] -> 
             RGBColor[
              0.192094835712424, 0.3192342302227627, 0.9342508887637553], 
             UndirectedEdge[112, 219] -> 
             RGBColor[
              0.17968380010062157`, 0.30618944488965105`, 0.933544098646145], 
             UndirectedEdge[33, 179] -> 
             RGBColor[
              0.23670129905445042`, 0.3661184514083582, 0.9367911608617348], 
             UndirectedEdge[123, 334] -> 
             RGBColor[
              0.9016847000711192, 0.6050909598648562, 0.2444456182077174], 
             UndirectedEdge[94, 307] -> 
             RGBColor[
              0.17906784709075121`, 0.30554203922260087`, 0.9335090210334537],
              UndirectedEdge[73, 89] -> 
             RGBColor[
              0.21536881746289013`, 0.3436966606981754, 0.9355763075936738], 
             UndirectedEdge[267, 311] -> 
             RGBColor[
              0.20008010519765723`, 0.3276272547470704, 0.9347056380477918], 
             UndirectedEdge[52, 391] -> 
             RGBColor[
              0.904614436704831, 0.5731258147714826, 0.49953005146272567`], 
             UndirectedEdge[105, 271] -> 
             RGBColor[
              0.9026525217316504, 0.5714728168582255, 0.530015287474555], 
             UndirectedEdge[187, 377] -> 
             RGBColor[
              0.2355206370031677, 0.36487750073416236`, 0.9367239239045473], 
             UndirectedEdge[58, 124] -> 
             RGBColor[
              0.20991109539232988`, 0.337960248762451, 0.9352654983957317], 
             UndirectedEdge[11, 54] -> 
             RGBColor[
              0.9107233154962703, 0.8671374351819781, 0.6324945514745149], 
             UndirectedEdge[115, 283] -> 
             RGBColor[
              0.9435152073287729, 0.813763650039597, 0.2734092138294835], 
             UndirectedEdge[292, 362] -> 
             RGBColor[
              0.8053813952545528, 0.4938474279364584, 0.5730644519337977], 
             UndirectedEdge[15, 154] -> 
             RGBColor[
              0.18425132424679044`, 0.31099020236503183`, 0.933804212389223], 
             UndirectedEdge[158, 311] -> 
             RGBColor[
              0.19686826327665763`, 0.3242514052455602, 0.9345227284018851], 
             UndirectedEdge[123, 253] -> 
             RGBColor[
              0.8341751047564834, 0.26369040755053386`, 0.1803594249510559], 
             UndirectedEdge[236, 376] -> 
             RGBColor[
              0.397907468442853, 0.5154535439144465, 0.9470741986312354], 
             UndirectedEdge[206, 386] -> 
             RGBColor[
              0.3854076478953393, 0.5082424662804851, 0.9457788124146576], 
             UndirectedEdge[74, 338] -> 
             RGBColor[
              0.22933498443170014`, 0.35837598768852497`, 0.9363716601414551],
              UndirectedEdge[293, 394] -> 
             RGBColor[
              0.3358774325095808, 0.4653418831743506, 0.9426227908881267], 
             UndirectedEdge[41, 381] -> 
             RGBColor[
              0.19207190760239157`, 0.31921013132539244`, 0.934249583041808], 
             UndirectedEdge[59, 328] -> 
             RGBColor[
              0.22381201159438807`, 0.3525709930598068, 0.9360571350088763], 
             UndirectedEdge[123, 196] -> 
             RGBColor[
              0.8436412079731275, 0.6056407490965849, 0.5869779142171753], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.9124649507944522, 0.7523588106461282, 0.5992692091287142], 
             UndirectedEdge[23, 38] -> 
             RGBColor[
              0.23532272116707456`, 0.36466947864183974`, 0.936712652890472], 
             UndirectedEdge[61, 282] -> 
             RGBColor[
              0.2661448795948803, 0.3964851197604022, 0.9384891805623623], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.2249471629490288, 0.3537641091062871, 0.9361217801992172], 
             UndirectedEdge[3, 232] -> 
             RGBColor[
              0.21328768495463646`, 0.3415092584805786, 0.9354577901760884], 
             UndirectedEdge[110, 362] -> 
             RGBColor[
              0.8221167873663267, 0.8612297040031928, 0.982833840996466], 
             UndirectedEdge[125, 252] -> 
             RGBColor[
              0.19926974690677848`, 0.32677551680367367`, 0.934659489341944], 
             UndirectedEdge[49, 327] -> 
             RGBColor[
              0.18473066760764006`, 0.3114940226294092, 0.9338315102844983], 
             UndirectedEdge[89, 291] -> 
             RGBColor[
              0.2138432095506144, 0.34209315005324514`, 0.9354894264800044], 
             UndirectedEdge[34, 250] -> 
             RGBColor[
              0.1883288985198916, 0.31527599145920215`, 0.9340364242118455], 
             UndirectedEdge[125, 226] -> 
             RGBColor[
              0.1922514050569324, 0.3193987945309108, 0.9342598051563016], 
             UndirectedEdge[3, 14] -> 
             RGBColor[
              0.28743237026540935`, 0.41667525783150516`, 0.9397814519424676],
              UndirectedEdge[105, 345] -> 
             RGBColor[
              0.9066930101053883, 0.9269728190997042, 0.9383535848392048], 
             UndirectedEdge[88, 336] -> 
             RGBColor[
              0.33259846324686315`, 0.4556650882287947, 0.9426641835505155], 
             UndirectedEdge[162, 357] -> 
             RGBColor[
              0.1906502583880034, 0.3177158878633042, 0.9341686222221902], 
             UndirectedEdge[279, 328] -> 
             RGBColor[
              0.215194282730263, 0.3435132136280431, 0.9355663680988517], 
             UndirectedEdge[312, 359] -> 
             RGBColor[
              0.4367530973615871, 0.5501494570425497, 0.9497594529493274], 
             UndirectedEdge[202, 289] -> 
             RGBColor[
              0.4009029468034172, 0.5210963292936249, 0.9469229296248474], 
             UndirectedEdge[27, 48] -> 
             RGBColor[
              0.20648582903789775`, 0.33436007664951256`, 0.9350704345440743],
              UndirectedEdge[115, 193] -> 
             RGBColor[
              0.8965180032601808, 0.866664933881647, 0.6335702357029284], 
             UndirectedEdge[117, 385] -> 
             RGBColor[
              0.776474593776608, 0.8214741220909348, 0.7960777027150834], 
             UndirectedEdge[179, 352] -> 
             RGBColor[
              0.20659936567779108`, 0.3344794108566792, 0.9350769002877538], 
             UndirectedEdge[8, 365] -> 
             RGBColor[
              0.2808078228071327, 0.4124772043875522, 0.9393029621396956], 
             UndirectedEdge[105, 353] -> 
             RGBColor[
              0.9892810453920724, 0.988090926321853, 0.7004958160747115], 
             UndirectedEdge[231, 392] -> 
             RGBColor[
              0.1971344084334818, 0.32453114067996, 0.9345378849748398], 
             UndirectedEdge[109, 132] -> 
             RGBColor[
              0.1878121680467173, 0.3147328749692917, 0.9340069971758325], 
             UndirectedEdge[23, 158] -> 
             RGBColor[
              0.20153001639620693`, 0.3291512033464258, 0.9347882083455978], 
             UndirectedEdge[105, 350] -> 
             RGBColor[
              0.6669237794423443, 0.7322521297415084, 0.9183362922108259], 
             UndirectedEdge[172, 351] -> 
             RGBColor[
              0.3445890788111915, 0.47288747334073133`, 0.943177889287059], 
             UndirectedEdge[34, 375] -> 
             RGBColor[
              0.19286667153168213`, 0.3200454786060204, 0.9342948436718334], 
             UndirectedEdge[32, 391] -> 
             RGBColor[
              0.8208765397934485, 0.16147180977632267`, 0.16762470412387276`],
              UndirectedEdge[140, 241] -> 
             RGBColor[
              0.343629032390773, 0.46948243111537313`, 0.9432109443563187], 
             UndirectedEdge[89, 336] -> 
             RGBColor[
              0.23351345559029374`, 0.36276782580657996`, 0.9366096178924429],
              UndirectedEdge[74, 118] -> 
             RGBColor[
              0.3029906205258713, 0.4312899550504897, 0.9407311083477143], 
             UndirectedEdge[138, 328] -> 
             RGBColor[
              0.2601284224261766, 0.3907418434374549, 0.9381253008804314], 
             UndirectedEdge[189, 207] -> 
             RGBColor[
              0.2123454769342431, 0.3405189381117063, 0.935404132823199], 
             UndirectedEdge[273, 281] -> 
             RGBColor[
              0.46139853851670076`, 0.5721415288193888, 0.9511515046102453], 
             UndirectedEdge[49, 225] -> 
             RGBColor[
              0.19609003670444464`, 0.3234334397757498, 0.9344784095498806], 
             UndirectedEdge[43, 159] -> 
             RGBColor[
              0.1884193222929882, 0.31537103257792504`, 0.9340415737119533], 
             UndirectedEdge[113, 368] -> 
             RGBColor[
              0.18474082389280244`, 0.3115046975290605, 0.9338320886699134], 
             UndirectedEdge[11, 83] -> 
             RGBColor[0.9120888802991098, 0.9323447493793293, 0.977810506555],
              UndirectedEdge[151, 344] -> 
             RGBColor[
              0.1995874063553662, 0.3271093970249116, 0.9346775795776059], 
             UndirectedEdge[182, 377] -> 
             RGBColor[
              0.2482608696505907, 0.3782682930240088, 0.9374494613063329], 
             UndirectedEdge[198, 203] -> 
             RGBColor[
              0.5694035624452959, 0.6546305646490294, 0.9622535793690412], 
             UndirectedEdge[208, 395] -> 
             RGBColor[
              0.366549438606146, 0.4905837118311563, 0.9446256885343254], 
             UndirectedEdge[305, 339] -> 
             RGBColor[
              0.3400084902177303, 0.4679319523924049, 0.9429221954121405], 
             UndirectedEdge[9, 313] -> 
             RGBColor[
              0.4854882204226317, 0.5856947625868548, 0.9544467086526902], 
             UndirectedEdge[267, 317] -> 
             RGBColor[
              0.1930340826347562, 0.32022143828982824`, 0.9343043774864909], 
             UndirectedEdge[306, 350] -> 
             RGBColor[
              0.2854226113571807, 0.41364792547081863`, 0.9397004998858718], 
             UndirectedEdge[111, 362] -> 
             RGBColor[
              0.8089414952642664, 0.5212119166568898, 0.5764736077236575], 
             UndirectedEdge[104, 261] -> 
             RGBColor[
              0.20662637490864183`, 0.3345077992707875, 0.9350784384234943], 
             UndirectedEdge[243, 363] -> 
             RGBColor[
              0.302959879941956, 0.42967862832344433`, 0.9407871732432331], 
             UndirectedEdge[154, 369] -> 
             RGBColor[
              0.183389073095449, 0.31008392173509136`, 0.9337551084617403], 
             UndirectedEdge[218, 282] -> 
             RGBColor[
              0.4376499441056336, 0.5505879476107286, 0.9499100761220066], 
             UndirectedEdge[7, 293] -> 
             RGBColor[
              0.28453912176058604`, 0.41590127160719004`, 0.9395336796939777],
              UndirectedEdge[24, 167] -> 
             RGBColor[
              0.24799412206051685`, 0.37798792439406714`, 0.9374342704256958],
              UndirectedEdge[326, 363] -> 
             RGBColor[
              0.3080486907375876, 0.43502729111889293`, 0.9410769734898234], 
             UndirectedEdge[276, 282] -> 
             RGBColor[
              0.3470343998180849, 0.475005487491495, 0.9433337029793059], 
             UndirectedEdge[337, 345] -> 
             RGBColor[
              0.8925314756364031, 0.9165956294995268, 0.9705858474056119], 
             UndirectedEdge[107, 124] -> 
             RGBColor[
              0.22484989821780513`, 0.3536618777068309, 0.9361162411166642], 
             UndirectedEdge[128, 227] -> 
             RGBColor[
              0.28894688934847723`, 0.42103187936912945`, 0.9397664699385552],
              UndirectedEdge[25, 365] -> 
             RGBColor[
              0.33498940880084865`, 0.4643204052534886, 0.9425754453427104], 
             UndirectedEdge[97, 363] -> 
             RGBColor[
              0.3365752811245841, 0.4650105463059218, 0.9427015206110543], 
             UndirectedEdge[13, 373] -> 
             RGBColor[
              0.2056740334145861, 0.3335068279785967, 0.9350242039842707], 
             UndirectedEdge[64, 195] -> 
             RGBColor[
              0.7086017617355334, 0.7643768316855696, 0.6913028233561538], 
             UndirectedEdge[77, 96] -> 
             RGBColor[
              0.20429069166020342`, 0.3320528480858075, 0.9349454247178293], 
             UndirectedEdge[6, 53] -> 
             RGBColor[
              0.6643840547861006, 0.7335496374888852, 0.969847038397682], 
             UndirectedEdge[216, 343] -> 
             RGBColor[
              0.20826813355084325`, 0.33623339169725125`, 0.9351719341494034],
              UndirectedEdge[26, 324] -> 
             RGBColor[
              0.1839722969253371, 0.31069692695883033`, 0.9337883221960501], 
             UndirectedEdge[142, 281] -> 
             RGBColor[
              0.436455413320613, 0.55189157611022, 0.9491878904251312], 
             UndirectedEdge[100, 341] -> 
             RGBColor[
              0.3185278490681524, 0.4448223795517722, 0.9417183858910539], 
             UndirectedEdge[115, 364] -> 
             RGBColor[
              0.9382231077008898, 0.7927822385027005, 0.26915106624734497`], 
             UndirectedEdge[150, 152] -> 
             RGBColor[
              0.21962526952820027`, 0.3481704616934645, 0.9358187062419367], 
             UndirectedEdge[10, 68] -> 
             RGBColor[
              0.8322857283076943, 0.5959292773686855, 0.5858125997101122], 
             UndirectedEdge[190, 288] -> 
             RGBColor[
              0.21294330855938015`, 0.3411472970544397, 0.9354381784498378], 
             UndirectedEdge[23, 146] -> 
             RGBColor[
              0.20552449462249126`, 0.333349653226798, 0.9350156879712836], 
             UndirectedEdge[188, 201] -> 
             RGBColor[
              0.47076164268683474`, 0.5730017553920743, 0.9531670568538995], 
             UndirectedEdge[148, 382] -> 
             RGBColor[
              0.2893244860141426, 0.42019446169141983`, 0.9398331671225094], 
             UndirectedEdge[14, 71] -> 
             RGBColor[
              0.6541765961305002, 0.7223342652348994, 0.9394835143282855], 
             UndirectedEdge[228, 276] -> 
             RGBColor[
              0.3015266164865197, 0.4277543234766833, 0.9407208506945814], 
             UndirectedEdge[56, 174] -> 
             RGBColor[
              0.4681168777823908, 0.5781139671930625, 0.9515372200266019], 
             UndirectedEdge[16, 182] -> 
             RGBColor[
              0.23539065510704868`, 0.36474088152001305`, 0.9367165216278543],
              UndirectedEdge[104, 192] -> 
             RGBColor[
              0.24115781649194606`, 0.3708025337946915, 0.9370449529369735], 
             UndirectedEdge[145, 395] -> 
             RGBColor[
              0.3442769835307749, 0.46717394939172724`, 0.9433573051669275], 
             UndirectedEdge[219, 251] -> 
             RGBColor[
              0.1819264333571092, 0.30854659463338063`, 0.9336718132924233], 
             UndirectedEdge[150, 179] -> 
             RGBColor[
              0.23260992772492337`, 0.36181816073310025`, 0.9365581633171598],
              UndirectedEdge[73, 207] -> 
             RGBColor[
              0.1950145063297256, 0.32230298915935574`, 0.934417159686145], 
             UndirectedEdge[265, 325] -> 
             RGBColor[
              0.2186342581575027, 0.34712884590911136`, 0.9357622696104455], 
             UndirectedEdge[39, 314] -> 
             RGBColor[
              0.19046396107769498`, 0.3175200775782383, 0.9341580128659703], 
             UndirectedEdge[20, 263] -> 
             RGBColor[
              0.3432288815576954, 0.4710700975490908, 0.943114624476095], 
             UndirectedEdge[66, 146] -> 
             RGBColor[
              0.19762825714734855`, 0.3250502069900508, 0.9345660089285108], 
             UndirectedEdge[7, 21] -> 
             RGBColor[
              0.22580819870592864`, 0.3546691122796089, 0.9361708149117844], 
             UndirectedEdge[107, 167] -> 
             RGBColor[
              0.22944380789788385`, 0.3584903680512903, 0.9363778574768644], 
             UndirectedEdge[120, 195] -> 
             RGBColor[
              0.41858299206596217`, 0.5369772819597975, 0.9478927160094046], 
             UndirectedEdge[365, 388] -> 
             RGBColor[
              0.2883992345699991, 0.4204562594736305, 0.9397352818091035], 
             UndirectedEdge[134, 342] -> 
             RGBColor[
              0.18275455563161122`, 0.309417003649867, 0.9337189736308591], 
             UndirectedEdge[227, 311] -> 
             RGBColor[
              0.23829401063491945`, 0.3677924922631779, 0.9368818634300369], 
             UndirectedEdge[78, 377] -> 
             RGBColor[
              0.2375799153602678, 0.3670419328532635, 0.9368411967605548], 
             UndirectedEdge[21, 370] -> 
             RGBColor[
              0.19110729661804693`, 0.31819626402097745`, 0.9341946498732637],
              UndirectedEdge[2, 230] -> 
             RGBColor[
              0.2114753909347174, 0.33960442255956613`, 0.9353545827127028], 
             UndirectedEdge[24, 203] -> 
             RGBColor[
              0.2850956592214299, 0.4168671679331099, 0.9395514255934152], 
             UndirectedEdge[54, 206] -> 
             RGBColor[
              0.6885711015156095, 0.68922695188861, 0.6128856824256679], 
             UndirectedEdge[66, 130] -> 
             RGBColor[
              0.20589531196195676`, 0.3337394057617535, 0.9350368054701912], 
             UndirectedEdge[101, 356] -> 
             RGBColor[
              0.8996786533554004, 0.687329585228627, 0.5883270956947237], 
             UndirectedEdge[222, 383] -> 
             RGBColor[
              0.6547025238599551, 0.723910051109828, 0.9558664767641599], 
             UndirectedEdge[31, 247] -> 
             RGBColor[
              0.9007985668118983, 0.5610186106560575, 0.5373898372859729], 
             UndirectedEdge[46, 333] -> 
             RGBColor[
              0.8796565038002286, 0.9065288389378603, 0.9721902291244133], 
             UndirectedEdge[287, 385] -> 
             RGBColor[
              0.9058682917802197, 0.5622975503208443, 0.39899230255686247`], 
             UndirectedEdge[42, 330] -> 
             RGBColor[
              0.18629301045548374`, 0.31313614402075074`, 0.9339204833984038],
              UndirectedEdge[151, 227] -> 
             RGBColor[
              0.2408020759927813, 0.3704286279748189, 0.937024694041817], 
             UndirectedEdge[36, 382] -> 
             RGBColor[
              0.2838749254794549, 0.4144666280473688, 0.9395228227119613], 
             UndirectedEdge[218, 361] -> 
             RGBColor[
              0.4849252020484565, 0.5915353999172487, 0.952922413754254], 
             UndirectedEdge[196, 334] -> 
             RGBColor[
              0.9021680954325457, 0.8779962725880234, 0.6424622562871629], 
             UndirectedEdge[34, 265] -> 
             RGBColor[
              0.19096709589184307`, 0.31804890416849774`, 0.9341866656493147],
              UndirectedEdge[372, 392] -> 
             RGBColor[
              0.19150446236563495`, 0.31861371040345526`, 0.9342172678750348],
              UndirectedEdge[127, 210] -> 
             RGBColor[
              0.29252473138981117`, 0.4219611356100898, 0.9400738898749681], 
             UndirectedEdge[33, 157] -> 
             RGBColor[
              0.2467253832848012, 0.3766543994981055, 0.9373620176293496], 
             UndirectedEdge[139, 308] -> 
             RGBColor[
              0.25989565930435055`, 0.3904971946383813, 0.9381120453649856], 
             UndirectedEdge[38, 146] -> 
             RGBColor[
              0.2289275307271461, 0.3579477280109817, 0.9363484562557545], 
             UndirectedEdge[55, 68] -> 
             RGBColor[
              0.8126708442680417, 0.8535970039103761, 0.981959617507143], 
             UndirectedEdge[35, 392] -> 
             RGBColor[
              0.19658094676972326`, 0.3239494173798535, 0.934506366151862], 
             UndirectedEdge[51, 126] -> 
             RGBColor[
              0.1918840790772874, 0.31901271163649164`, 0.9342388864851707], 
             UndirectedEdge[130, 243] -> 
             RGBColor[
              0.22352868317149505`, 0.3522731969232867, 0.9360409998743393], 
             UndirectedEdge[12, 203] -> 
             RGBColor[
              0.2763975204564685, 0.40772487259728496`, 0.9390560794584938], 
             UndirectedEdge[182, 395] -> 
             RGBColor[
              0.3402542515552627, 0.4629458030295253, 0.9431282165320207], 
             UndirectedEdge[99, 382] -> 
             RGBColor[
              0.6121310294998102, 0.6891159199256546, 0.9661376246873524], 
             UndirectedEdge[17, 31] -> 
             RGBColor[
              0.9059600385832136, 0.6006919444617403, 0.5423324684832332], 
             UndirectedEdge[77, 78] -> 
             RGBColor[
              0.20870891214169546`, 0.33669667794321373`, 0.9351970358380788],
              UndirectedEdge[243, 344] -> 
             RGBColor[
              0.2114782278514492, 0.3396074043389222, 0.9353547442709138], 
             UndirectedEdge[305, 313] -> 
             RGBColor[
              0.29133850845533754`, 0.4235456226878492, 0.9399026691086074], 
             UndirectedEdge[189, 280] -> 
             RGBColor[
              0.2210513429116578, 0.3496693552377532, 0.9358999190114381], 
             UndirectedEdge[104, 208] -> 
             RGBColor[
              0.25923359532216883`, 0.3898013234158274, 0.9380743418006362], 
             UndirectedEdge[191, 335] -> 
             RGBColor[
              0.19113672012064215`, 0.3182271899877628, 0.9341963254982084], 
             UndirectedEdge[225, 355] -> 
             RGBColor[
              0.2083112643931653, 0.336278724947185, 0.9351743903870672], 
             UndirectedEdge[308, 348] -> 
             RGBColor[
              0.20697593141094872`, 0.33487520531787435`, 0.9350983451491781],
              UndirectedEdge[132, 149] -> 
             RGBColor[
              0.20160011613108555`, 0.32922488261236305`, 0.9347922004217959],
              UndirectedEdge[128, 224] -> 
             RGBColor[
              0.40082474260241224`, 0.5199417456186857, 0.9471108972900512], 
             UndirectedEdge[192, 225] -> 
             RGBColor[
              0.233374248060821, 0.36262150986683694`, 0.9366016902295785], 
             UndirectedEdge[84, 252] -> 
             RGBColor[
              0.2101141940866254, 0.33817371836735655`, 0.9352770645659143], 
             UndirectedEdge[30, 211] -> 
             RGBColor[
              0.21659401962004457`, 0.3449844258476482, 0.9356460810439997], 
             UndirectedEdge[138, 242] -> 
             RGBColor[
              0.31465187583145326`, 0.4451229547456037, 0.9413374842169753], 
             UndirectedEdge[27, 41] -> 
             RGBColor[
              0.1999138771125005, 0.32745253849010136`, 0.9346961716042546], 
             UndirectedEdge[102, 139] -> 
             RGBColor[
              0.3279891561400408, 0.4583428062151842, 0.9421262587090772], 
             UndirectedEdge[203, 329] -> 
             RGBColor[
              0.28617424693522586`, 0.4180008320067203, 0.9396128495680883], 
             UndirectedEdge[195, 312] -> 
             RGBColor[
              0.48621740603993846`, 0.5929929550712956, 0.9529112749587412], 
             UndirectedEdge[51, 87] -> 
             RGBColor[
              0.1940286984190197, 0.3212668425413722, 0.9343610193840024], 
             UndirectedEdge[83, 366] -> 
             RGBColor[
              0.9721424943326117, 0.9755215245830015, 0.7399924007909114], 
             UndirectedEdge[8, 302] -> 
             RGBColor[
              0.22515004974021374`, 0.353977355987588, 0.936133334301831], 
             UndirectedEdge[146, 344] -> 
             RGBColor[
              0.1953459036771252, 0.3226513087832781, 0.9344360322748211], 
             UndirectedEdge[67, 320] -> 
             RGBColor[
              0.1815572411564681, 0.30815855022236927`, 0.9336507883427678], 
             UndirectedEdge[90, 166] -> 
             RGBColor[
              0.23037172884023532`, 0.35946567179528754`, 0.9364307012017953],
              UndirectedEdge[12, 341] -> 
             RGBColor[
              0.2460644953245124, 0.3759597643491251, 0.9373243810377072], 
             UndirectedEdge[3, 13] -> 
             RGBColor[
              0.2247891692476987, 0.3535980477088099, 0.9361127826916571], 
             UndirectedEdge[153, 341] -> 
             RGBColor[
              0.22749742981872606`, 0.3564446012825976, 0.9362670141246647], 
             UndirectedEdge[192, 351] -> 
             RGBColor[
              0.2839106330866923, 0.41566367352388345`, 0.9394824007008676], 
             UndirectedEdge[12, 150] -> 
             RGBColor[
              0.24059607423843102`, 0.37021210706973123`, 0.937012962546659], 
             UndirectedEdge[99, 393] -> 
             RGBColor[
              0.8120689253181035, 0.8537779307522239, 0.9817268285297311], 
             UndirectedEdge[4, 190] -> 
             RGBColor[
              0.20649883851719153`, 0.33437375043709894`, 0.9350711754146743],
              UndirectedEdge[373, 390] -> 
             RGBColor[
              0.20548402624046883`, 0.3333071183914488, 0.9350133833567951], 
             UndirectedEdge[23, 308] -> 
             RGBColor[
              0.21238372481471685`, 0.3405591390591399, 0.9354063109834092], 
             UndirectedEdge[37, 187] -> 
             RGBColor[
              0.2503393326402117, 0.3804528894082654, 0.9375678266987812], 
             UndirectedEdge[17, 292] -> 
             RGBColor[
              0.8235767865158092, 0.18222708934004583`, 0.17021046343469787`],
              UndirectedEdge[309, 385] -> 
             RGBColor[
              0.845892139078253, 0.8769877648670494, 0.8021186290174642], 
             UndirectedEdge[140, 380] -> 
             RGBColor[
              0.5633644182821813, 0.6539330422248467, 0.9599388244578124], 
             UndirectedEdge[119, 354] -> 
             RGBColor[
              0.21794551615801888`, 0.3464049343988889, 0.9357230467724773], 
             UndirectedEdge[36, 305] -> 
             RGBColor[
              0.2718566625317226, 0.40306896740175535`, 0.9387932068040659], 
             UndirectedEdge[91, 351] -> 
             RGBColor[
              0.45106536887988224`, 0.5613307052601594, 0.9510072153286632], 
             UndirectedEdge[130, 275] -> 
             RGBColor[
              0.2049038205781411, 0.33269728545317867`, 0.934980341502663], 
             UndirectedEdge[46, 102] -> 
             RGBColor[
              0.5772856165740025, 0.6623742905041798, 0.9623565848838942], 
             UndirectedEdge[111, 271] -> 
             RGBColor[
              0.823307418706283, 0.18015661031829988`, 0.16995251651608806`], 
             UndirectedEdge[104, 351] -> 
             RGBColor[
              0.26680200623584566`, 0.3976814219540492, 0.9385080897116571], 
             UndirectedEdge[174, 203] -> 
             RGBColor[
              0.3639226125883841, 0.4896332085668736, 0.9444098049633691], 
             UndirectedEdge[294, 313] -> 
             RGBColor[
              0.24717525119128783`, 0.3771272391910956, 0.937387636941104], 
             UndirectedEdge[206, 266] -> 
             RGBColor[
              0.5435550579217713, 0.6394151913659053, 0.9575592073363473], 
             UndirectedEdge[167, 358] -> 
             RGBColor[
              0.25670178916857006`, 0.3871402346226134, 0.9379301591856604], 
             UndirectedEdge[315, 322] -> 
             RGBColor[
              0.18811052101816012`, 0.31504646285894905`, 0.9340239879361825],
              UndirectedEdge[176, 347] -> 
             RGBColor[
              0.18526445779187303`, 0.3120550699572905, 0.9338619088458187], 
             UndirectedEdge[92, 186] -> 
             RGBColor[
              0.20547576839988674`, 0.33329843887741967`, 0.9350129130849905],
              UndirectedEdge[149, 210] -> 
             RGBColor[
              0.22800345786551077`, 0.3569764688437995, 0.9362958316733276], 
             UndirectedEdge[171, 374] -> 
             RGBColor[
              0.18584495673726414`, 0.3126652111546555, 0.9338949674019874], 
             UndirectedEdge[228, 282] -> 
             RGBColor[
              0.26951575842165965`, 0.40002812713340913`, 0.938681147124779], 
             UndirectedEdge[164, 210] -> 
             RGBColor[
              0.23033673863294363`, 0.3594288948689166, 0.9364287085612534], 
             UndirectedEdge[196, 214] -> 
             RGBColor[
              0.8615229927273951, 0.7108190806524803, 0.6028379622201453], 
             UndirectedEdge[204, 307] -> 
             RGBColor[
              0.17948540198595286`, 0.30598091589196724`, 0.9335328001670183],
              UndirectedEdge[127, 255] -> 
             RGBColor[
              0.35677877005900877`, 0.4834455712278943, 0.9439546056344492], 
             UndirectedEdge[68, 334] -> 
             RGBColor[
              0.8909079727489195, 0.8690177564079877, 0.6413882557335685], 
             UndirectedEdge[16, 269] -> 
             RGBColor[
              0.29117851080203017`, 0.41924857896072276`, 0.9400447358569024],
              UndirectedEdge[68, 337] -> 
             RGBColor[
              0.8892917898500812, 0.9140123919924417, 0.970276843283211], 
             UndirectedEdge[23, 374] -> 
             RGBColor[
              0.19777812141168266`, 0.3252077238338092, 0.9345745434766604], 
             UndirectedEdge[22, 116] -> 
             RGBColor[
              0.24102708216235447`, 0.3706651237252555, 0.9370375078103073], 
             UndirectedEdge[192, 322] -> 
             RGBColor[
              0.2266888241245798, 0.3555947054294877, 0.936220965226608], 
             UndirectedEdge[70, 95] -> 
             RGBColor[
              0.22209777558797966`, 0.3507692223282312, 0.9359595118042963], 
             UndirectedEdge[71, 273] -> 
             RGBColor[
              0.7468748729151091, 0.8007044259307632, 0.9459207863964338], 
             UndirectedEdge[135, 215] -> 
             RGBColor[
              0.5207131115569171, 0.6175984363516078, 0.9569638659378303], 
             UndirectedEdge[161, 283] -> 
             RGBColor[
              0.9057344419097366, 0.6568662450460772, 0.2426421685015519], 
             UndirectedEdge[18, 384] -> 
             RGBColor[
              0.9630602947807589, 0.8804179575228263, 0.3471852898585644], 
             UndirectedEdge[71, 303] -> 
             RGBColor[
              0.9318169667814895, 0.7940843861143203, 0.5846862975193713], 
             UndirectedEdge[32, 353] -> 
             RGBColor[
              0.9073893332491589, 0.5772003661732394, 0.33799440934929903`], 
             UndirectedEdge[188, 281] -> 
             RGBColor[
              0.3372802138863956, 0.4635116716468679, 0.9428236756739168], 
             UndirectedEdge[54, 198] -> 
             RGBColor[
              0.8885256847199983, 0.8494376469396148, 0.6303773216350153], 
             UndirectedEdge[271, 385] -> 
             RGBColor[
              0.9072101681764545, 0.5726118003162909, 0.40027728490932957`], 
             UndirectedEdge[150, 206] -> 
             RGBColor[
              0.33364753302286965`, 0.45690710407047097`, 0.9427188232478589],
              UndirectedEdge[317, 346] -> 
             RGBColor[
              0.19596516131412245`, 0.3233021878229641, 0.9344712980811385], 
             UndirectedEdge[146, 243] -> 
             RGBColor[
              0.21526162835688684`, 0.343583998151584, 0.9355702033326591], 
             UndirectedEdge[91, 316] -> 
             RGBColor[
              0.6523585861658432, 0.7275841393423603, 0.9665060682236928], 
             UndirectedEdge[196, 386] -> 
             RGBColor[
              0.5930257483480736, 0.6745638419646864, 0.9640014047404548], 
             UndirectedEdge[151, 306] -> 
             RGBColor[
              0.21495613201977448`, 0.3432629021316925, 0.9355528057682019], 
             UndirectedEdge[27, 376] -> 
             RGBColor[
              0.24560585367761548`, 0.37547770289867644`, 0.937298262074416], 
             UndirectedEdge[280, 387] -> 
             RGBColor[
              0.19723551682458454`, 0.32463741200965124`, 0.9345436429481366],
              UndirectedEdge[308, 354] -> 
             RGBColor[
              0.20447448662716458`, 0.33224602824935756`, 0.9349558915692975],
              UndirectedEdge[327, 349] -> 
             RGBColor[
              0.19208902000720862`, 0.3192281175478443, 0.934250557567947], 
             UndirectedEdge[60, 108] -> 
             RGBColor[
              0.5066936953729514, 0.6051947855450721, 0.9560957540450186], 
             UndirectedEdge[353, 391] -> 
             RGBColor[
              0.9067470066576029, 0.5722631625212318, 0.3373793166798207], 
             UndirectedEdge[140, 195] -> 
             RGBColor[
              0.4154824656065883, 0.5342917617776789, 0.9476951532051012], 
             UndirectedEdge[17, 18] -> 
             RGBColor[
              0.9100987698336667, 0.6000343504740516, 0.3015369122339562], 
             UndirectedEdge[87, 205] -> 
             RGBColor[
              0.18600119174785296`, 0.31282942405665615`, 0.9339038647547113],
              UndirectedEdge[221, 256] -> 
             RGBColor[
              0.6811078585940378, 0.7429531062730206, 0.8609992027595657], 
             UndirectedEdge[194, 316] -> 
             RGBColor[
              0.5837905900380065, 0.6719175511327584, 0.9611081443956637], 
             UndirectedEdge[16, 37] -> 
             RGBColor[
              0.25664259349321183`, 0.38707801621458926`, 0.9379267880795208],
              UndirectedEdge[252, 288] -> 
             RGBColor[
              0.20983762189248398`, 0.33788302345562404`, 0.9352613141886098],
              UndirectedEdge[60, 353] -> 
             RGBColor[
              0.8501417981315751, 0.8795216745705272, 0.7395911022292926], 
             UndirectedEdge[206, 286] -> 
             RGBColor[
              0.375065904449271, 0.49928496789863985`, 0.9451198456671187], 
             UndirectedEdge[220, 396] -> 
             RGBColor[
              0.18205118127193512`, 0.30867771260133725`, 0.9336789175016247],
              UndirectedEdge[133, 320] -> 
             RGBColor[
              0.18355649439985816`, 0.3102598921411492, 0.9337646428573487], 
             UndirectedEdge[28, 231] -> 
             RGBColor[
              0.19140134234262995`, 0.31850532472108994`, 0.934211395342277], 
             UndirectedEdge[239, 269] -> 
             RGBColor[
              0.4302703250067166, 0.5456389418366184, 0.9490411897361934], 
             UndirectedEdge[212, 239] -> 
             RGBColor[
              0.542458414688152, 0.6394312043737607, 0.9571234599763494], 
             UndirectedEdge[77, 182] -> 
             RGBColor[
              0.21938986643201835`, 0.34792303811395897`, 0.9358053003838569],
              UndirectedEdge[280, 336] -> 
             RGBColor[
              0.22186501043454393`, 0.3505245713938071, 0.9359462561731533], 
             UndirectedEdge[199, 400] -> 
             RGBColor[
              0.9054254853432643, 0.5803013970083357, 0.502576064159955], 
             UndirectedEdge[73, 336] -> 
             RGBColor[
              0.2166564041388005, 0.3450499959322676, 0.9356496337500533], 
             UndirectedEdge[305, 340] -> 
             RGBColor[
              0.2847257211787761, 0.4165951639852536, 0.9395260806559493], 
             UndirectedEdge[259, 350] -> 
             RGBColor[
              0.6219849446227963, 0.6978827145935297, 0.9666587839790601], 
             UndirectedEdge[247, 393] -> 
             RGBColor[
              0.7696552520366986, 0.45850393020932284`, 0.5685799817696936], 
             UndirectedEdge[30, 216] -> 
             RGBColor[
              0.208257693184232, 0.33622241820998533`, 0.93517133958597], 
             UndirectedEdge[291, 387] -> 
             RGBColor[
              0.1905013026165654, 0.3175593259031815, 0.9341601394113672], 
             UndirectedEdge[45, 338] -> 
             RGBColor[
              0.2249286875668965, 0.3537446903082591, 0.9361207280535366], 
             UndirectedEdge[219, 248] -> 
             RGBColor[
              0.1809198934930053, 0.30748865741789405`, 0.933614492336205], 
             UndirectedEdge[158, 354] -> 
             RGBColor[
              0.1936207782086547, 0.3208380925366434, 0.9343377889314861], 
             UndirectedEdge[191, 327] -> 
             RGBColor[
              0.1848862258869851, 0.3116575242439654, 0.9338403690983792], 
             UndirectedEdge[165, 192] -> 
             RGBColor[
              0.24190350365737148`, 0.3715862982848506, 0.9370874187178992], 
             UndirectedEdge[143, 354] -> 
             RGBColor[
              0.1975023339396083, 0.32491785371472337`, 0.9345588377881168], 
             UndirectedEdge[115, 161] -> 
             RGBColor[
              0.9173271064366133, 0.7028272968686928, 0.25196989849468676`], 
             UndirectedEdge[296, 330] -> 
             RGBColor[
              0.18388840354746627`, 0.31060874969954066`, 0.9337835445922895],
              UndirectedEdge[45, 262] -> 
             RGBColor[
              0.30202723660803465`, 0.4296407358190505, 0.9406995556283282], 
             UndirectedEdge[37, 208] -> 
             RGBColor[
              0.289374752338518, 0.42148159049974276`, 0.9397908361028714], 
             UndirectedEdge[306, 348] -> 
             RGBColor[
              0.21170202637769384`, 0.33984263077965143`, 0.9353674892659032],
              UndirectedEdge[189, 263] -> 
             RGBColor[
              0.2675028819703037, 0.39849286798607286`, 0.9385452654419342], 
             UndirectedEdge[2, 50] -> 
             RGBColor[
              0.216476564027812, 0.3448609725730971, 0.935639392121782], 
             UndirectedEdge[241, 331] -> 
             RGBColor[
              0.26094013118712034`, 0.3915950008105146, 0.9381715264935517], 
             UndirectedEdge[135, 213] -> 
             RGBColor[
              0.33038430669065766`, 0.46058401368253077`, 0.9422727737683254],
              UndirectedEdge[49, 349] -> 
             RGBColor[
              0.19105637302960854`, 0.3181427401007867, 0.9341917498502368], 
             UndirectedEdge[256, 319] -> 
             RGBColor[
              0.9123741671932073, 0.6207364120366994, 0.4779545305476905], 
             UndirectedEdge[64, 332] -> 
             RGBColor[
              0.9051950840061846, 0.5622054525470171, 0.2995058419250193], 
             UndirectedEdge[213, 350] -> 
             RGBColor[
              0.33697931492905076`, 0.46629627834387477`, 0.942693001861539], 
             UndirectedEdge[333, 345] -> 
             RGBColor[
              0.8909301311153961, 0.9154013493777207, 0.9732965059821361], 
             UndirectedEdge[53, 201] -> 
             RGBColor[
              0.5341594365329997, 0.6309589682060907, 0.9570952074204189], 
             UndirectedEdge[9, 384] -> 
             RGBColor[
              0.8099718019563749, 0.7646503394906032, 0.6173962103853706], 
             UndirectedEdge[24, 33] -> 
             RGBColor[
              0.2533855843329195, 0.3836546930808141, 0.9377413062261555], 
             UndirectedEdge[20, 359] -> 
             RGBColor[
              0.3551576814248725, 0.48204146573128925`, 0.9438513113001545], 
             UndirectedEdge[35, 291] -> 
             RGBColor[
              0.19278015708719454`, 0.31995454643953136`, 0.9342899168022064],
              UndirectedEdge[316, 351] -> 
             RGBColor[
              0.5108480401165528, 0.6087959957654421, 0.956444390370581], 
             UndirectedEdge[195, 263] -> 
             RGBColor[
              0.3632251652657039, 0.4883898734545258, 0.9443887699919498], 
             UndirectedEdge[67, 200] -> 
             RGBColor[
              0.1867268102524256, 0.3135920951118324, 0.9339451876550904], 
             UndirectedEdge[232, 277] -> 
             RGBColor[
              0.18773724237763328`, 0.31465412334052256`, 0.9340027302698206],
              UndirectedEdge[88, 120] -> 
             RGBColor[
              0.42147179727410705`, 0.5394794198355211, 0.9480767881227974], 
             UndirectedEdge[247, 271] -> 
             RGBColor[
              0.8186707488403941, 0.14451713392738777`, 0.16551243621614334`],
              UndirectedEdge[202, 269] -> 
             RGBColor[
              0.34049741903328384`, 0.46934348329390774`, 0.9429171723441234],
              UndirectedEdge[207, 291] -> 
             RGBColor[
              0.19348889841744987`, 0.3206994785144255, 0.9343302785724756], 
             UndirectedEdge[72, 397] -> 
             RGBColor[
              0.4148581473336097, 0.5334192417760302, 0.947747040377775], 
             UndirectedEdge[200, 298] -> 
             RGBColor[
              0.19975642982426225`, 0.3272870514074283, 0.9346872052141117], 
             UndirectedEdge[233, 389] -> 
             RGBColor[
              0.9817271461205633, 0.9825466050438816, 0.7139976792857294], 
             UndirectedEdge[44, 311] -> 
             RGBColor[
              0.21545480303552692`, 0.34378703698681684`, 0.9355812043448313],
              UndirectedEdge[137, 258] -> 
             RGBColor[
              0.2651486396074914, 0.3960184099951701, 0.9384111948221615], 
             UndirectedEdge[46, 287] -> 
             RGBColor[
              0.8114277374548052, 0.49106874179706506`, 0.572735002859394], 
             UndirectedEdge[84, 274] -> 
             RGBColor[
              0.20871345876417752`, 0.33670145673171487`, 0.935197294761503], 
             UndirectedEdge[270, 357] -> 
             RGBColor[
              0.1969743042117703, 0.32436286099174727`, 0.9345287672762663], 
             UndirectedEdge[44, 344] -> 
             RGBColor[
              0.20993796520971017`, 0.3379884906441625, 0.9352670285920812], 
             UndirectedEdge[44, 383] -> 
             RGBColor[
              0.29331549171916627`, 0.4210403283755737, 0.9401830698485728], 
             UndirectedEdge[193, 364] -> 
             RGBColor[
              0.8796332391054209, 0.7997224705221349, 0.619984358127655], 
             UndirectedEdge[43, 375] -> 
             RGBColor[
              0.19874644987833204`, 0.3262254984478285, 0.9346296883503225], 
             UndirectedEdge[184, 252] -> 
             RGBColor[
              0.20974713734389644`, 0.3377879184580067, 0.9352561612274277], 
             UndirectedEdge[16, 78] -> 
             RGBColor[
              0.22470970081672578`, 0.3535145213492678, 0.9361082570820762], 
             UndirectedEdge[345, 353] -> 
             RGBColor[
              0.9106717648266294, 0.9268736116959997, 0.7456067906697404], 
             UndirectedEdge[167, 203] -> 
             RGBColor[
              0.2729080188918158, 0.40405718520565725`, 0.9388573575066418], 
             UndirectedEdge[329, 340] -> 
             RGBColor[
              0.2668654692611238, 0.39782290681442484`, 0.9385089657311141], 
             UndirectedEdge[193, 380] -> 
             RGBColor[
              0.7791551569135652, 0.8275462332304435, 0.978584074457042], 
             UndirectedEdge[115, 253] -> 
             RGBColor[
              0.8901501343784577, 0.5271850402949314, 0.22724725879350022`], 
             UndirectedEdge[113, 270] -> 
             RGBColor[
              0.196796775846464, 0.3241762674238618, 0.9345186572984918], 
             UndirectedEdge[121, 202] -> 
             RGBColor[
              0.2856578369982738, 0.41583248159385067`, 0.9396429608971655], 
             UndirectedEdge[17, 111] -> 
             RGBColor[
              0.8271368865255229, 0.20959157806047718`, 0.1736196192245576], 
             UndirectedEdge[73, 280] -> 
             RGBColor[
              0.2037203723071403, 0.3314534062854026, 0.9349129458743843], 
             UndirectedEdge[127, 242] -> 
             RGBColor[
              0.33988365440933965`, 0.4688118712253543, 0.9428780638050165], 
             UndirectedEdge[19, 211] -> 
             RGBColor[
              0.2160009516459515, 0.344361073804195, 0.9356123067002404], 
             UndirectedEdge[213, 345] -> 
             RGBColor[
              0.5767485455920949, 0.6610169677020706, 0.962710294489918], 
             UndirectedEdge[102, 350] -> 
             RGBColor[
              0.3487900132261258, 0.4765261115858444, 0.9434455691132382], 
             UndirectedEdge[81, 227] -> 
             RGBColor[
              0.2515739104642789, 0.38175050897811513`, 0.9376381340794677], 
             UndirectedEdge[144, 218] -> 
             RGBColor[
              0.5707667888209911, 0.662413217772521, 0.9593519988850778], 
             UndirectedEdge[130, 354] -> 
             RGBColor[
              0.2058823112495472, 0.3337257411887183, 0.9350360650988523], 
             UndirectedEdge[104, 327] -> 
             RGBColor[
              0.20490625211316982`, 0.332699841150662, 0.9349804799749857], 
             UndirectedEdge[10, 253] -> 
             RGBColor[
              0.8340797477746764, 0.2629574520026702, 0.18026811099758727`], 
             UndirectedEdge[40, 41] -> 
             RGBColor[
              0.19412189539412833`, 0.3213647984712409, 0.9343663268138622], 
             UndirectedEdge[5, 113] -> 
             RGBColor[
              0.18623312529560537`, 0.31307320092078017`, 0.9339170730271409],
              UndirectedEdge[271, 337] -> 
             RGBColor[
              0.8884909872626653, 0.561095627258048, 0.562247550040962], 
             UndirectedEdge[325, 376] -> 
             RGBColor[
              0.26222548998781436`, 0.392945994406499, 0.9382447257757333], 
             UndirectedEdge[52, 337] -> 
             RGBColor[
              0.9729869409703154, 0.9785763889719264, 0.8948788134240234], 
             UndirectedEdge[246, 260] -> 
             RGBColor[
              0.20281631365008554`, 0.33050318331620854`, 0.9348614610713], 
             UndirectedEdge[22, 290] -> 
             RGBColor[
              0.2497813465899759, 0.3798664106911086, 0.9375360502186867], 
             UndirectedEdge[24, 107] -> 
             RGBColor[
              0.2416314482274979, 0.371300350778743, 0.9370719255636378], 
             UndirectedEdge[314, 369] -> 
             RGBColor[
              0.1815795981118552, 0.30818204879999395`, 0.9336520615383029], 
             UndirectedEdge[187, 208] -> 
             RGBColor[
              0.25538258130493185`, 0.38575366351532014`, 0.9378550322494192],
              UndirectedEdge[9, 174] -> 
             RGBColor[
              0.5520972673558275, 0.6456190088987284, 0.9586092963260144], 
             UndirectedEdge[6, 303] -> 
             RGBColor[
              0.9100466794366213, 0.777602242030947, 0.6130122278904285], 
             UndirectedEdge[100, 198] -> 
             RGBColor[
              0.6082548805926754, 0.6882816237042615, 0.9647291510065205], 
             UndirectedEdge[101, 123] -> 
             RGBColor[
              0.8485657793755872, 0.374303438706794, 0.1941399512182521], 
             UndirectedEdge[210, 394] -> 
             RGBColor[
              0.30165291276591666`, 0.42986750752233627`, 0.9406555295205197],
              UndirectedEdge[213, 227] -> 
             RGBColor[
              0.29970260204538113`, 0.43079580390036054`, 0.94043541584355], 
             UndirectedEdge[32, 46] -> 
             RGBColor[
              0.8135276706473076, 0.5072097485112304, 0.5747459012560696], 
             UndirectedEdge[303, 391] -> 
             RGBColor[
              0.8570821356565119, 0.38388879895942046`, 0.20010729537059024`],
              UndirectedEdge[248, 251] -> 
             RGBColor[
              0.1839193268501145, 0.3106412520512747, 0.9337853056286283], 
             UndirectedEdge[239, 388] -> 
             RGBColor[
              0.38895939974165, 0.5063474161681534, 0.9465374152784297], 
             UndirectedEdge[205, 277] -> 
             RGBColor[
              0.18513416241600078`, 0.31191812125604473`, 0.9338544887169173],
              UndirectedEdge[308, 378] -> 
             RGBColor[
              0.22654239934249232`, 0.35544080369964637`, 0.9362126265518842],
              UndirectedEdge[119, 130] -> 
             RGBColor[
              0.2277266187202509, 0.3566854933495158, 0.936280066093552], 
             UndirectedEdge[28, 254] -> 
             RGBColor[
              0.1893368412328983, 0.3163354031578313, 0.9340938250582336], 
             UndirectedEdge[217, 314] -> 
             RGBColor[
              0.1955003640293088, 0.322813656406775, 0.9344448285633742], 
             UndirectedEdge[229, 307] -> 
             RGBColor[
              0.18847585942484443`, 0.31543045668816716`, 0.9340447934179733],
              UndirectedEdge[114, 155] -> 
             RGBColor[
              0.18628873221551898`, 0.3131316473192917, 0.933920239758967], 
             UndirectedEdge[226, 288] -> 
             RGBColor[
              0.20281928004263788`, 0.3305063011828612, 0.9348616300029674], 
             UndirectedEdge[217, 231] -> 
             RGBColor[
              0.19972682323934088`, 0.32725593300951006`, 0.9346855191628995],
              UndirectedEdge[151, 346] -> 
             RGBColor[
              0.2055192492348853, 0.3333441399918473, 0.9350153892542195], 
             UndirectedEdge[114, 180] -> 
             RGBColor[
              0.18755106204056693`, 0.3144584360017507, 0.9339921275750538], 
             UndirectedEdge[215, 345] -> 
             RGBColor[
              0.7670773504583543, 0.8180313903711476, 0.977401386659423], 
             UndirectedEdge[190, 252] -> 
             RGBColor[
              0.20904698368177904`, 0.3370520125668152, 0.9352162885121547], 
             UndirectedEdge[275, 311] -> 
             RGBColor[
              0.19837020308391207`, 0.32583003921146847`, 0.9346082616519875],
              UndirectedEdge[75, 320] -> 
             RGBColor[
              0.18280885155031829`, 0.3094740721029882, 0.933722065703106], 
             UndirectedEdge[169, 393] -> 
             RGBColor[
              0.5896152402179853, 0.6764956737968535, 0.9616696419121211], 
             UndirectedEdge[80, 182] -> 
             RGBColor[
              0.22246710481821064`, 0.35115741076602963`, 0.9359805445575843],
              UndirectedEdge[239, 362] -> 
             RGBColor[
              0.6492041088152176, 0.7238110272281775, 0.9670865002427318], 
             UndirectedEdge[171, 342] -> 
             RGBColor[
              0.18722373291059582`, 0.31411439233228555`, 0.933973486665342], 
             UndirectedEdge[107, 157] -> 
             RGBColor[
              0.2349712471793796, 0.36430005719603437`, 0.936692636966832], 
             UndirectedEdge[116, 286] -> 
             RGBColor[
              0.28063230469456346`, 0.41113725310534854`, 0.9393352740823563],
              UndirectedEdge[37, 117] -> 
             RGBColor[
              0.4214315538332871, 0.5343304799664346, 0.9489462154343377], 
             UndirectedEdge[111, 222] -> 
             RGBColor[
              0.8888497880747033, 0.5842997162159619, 0.5703986830647514], 
             UndirectedEdge[57, 72] -> 
             RGBColor[
              0.4069178401688355, 0.5265417468013449, 0.9472410910265736], 
             UndirectedEdge[8, 323] -> 
             RGBColor[
              0.3381102648791732, 0.4623620160236, 0.9429449845379104], 
             UndirectedEdge[115, 356] -> 
             RGBColor[
              0.9502457162134885, 0.9092562156396481, 0.6300362544566458], 
             UndirectedEdge[129, 391] -> 
             RGBColor[
              0.8197851875316053, 0.15308319805818565`, 0.1665796239654257], 
             UndirectedEdge[271, 303] -> 
             RGBColor[
              0.8569664054518005, 0.38299924589270967`, 0.19999647199586007`],
              UndirectedEdge[141, 196] -> 
             RGBColor[
              0.5999457128672814, 0.6805575674236943, 0.9644423387605343], 
             UndirectedEdge[8, 117] -> 
             RGBColor[
              0.40706513411417244`, 0.5192304619580248, 0.9481280690845475], 
             UndirectedEdge[278, 330] -> 
             RGBColor[
              0.18839714683821507`, 0.31534772476895345`, 0.9340403108526096],
              UndirectedEdge[95, 276] -> 
             RGBColor[
              0.3131382201938357, 0.4399588551912694, 0.9413821143478849], 
             UndirectedEdge[114, 268] -> 
             RGBColor[
              0.18716896902427724`, 0.3140568320155338, 0.9339703679430321], 
             UndirectedEdge[95, 148] -> 
             RGBColor[
              0.2518920934922597, 0.3820849395144922, 0.9376562541322015], 
             UndirectedEdge[236, 366] -> 
             RGBColor[
              0.7514680031030527, 0.8004311372612268, 0.7333352246803804], 
             UndirectedEdge[108, 378] -> 
             RGBColor[
              0.2733003143570183, 0.40458633700295354`, 0.938875420639825], 
             UndirectedEdge[33, 107] -> 
             RGBColor[
              0.23483527017028652`, 0.36415713673803723`, 0.9366848932773241],
              UndirectedEdge[309, 362] -> 
             RGBColor[
              0.7443188002522516, 0.8001867708802417, 0.9751504000206381], 
             UndirectedEdge[178, 278] -> 
             RGBColor[
              0.18555079143571185`, 0.31235602477156665`, 0.9338782151232425],
              UndirectedEdge[21, 232] -> 
             RGBColor[
              0.19351392550506752`, 0.32072578357032067`, 0.9343317038280912],
              UndirectedEdge[20, 140] -> 
             RGBColor[
              0.3954861818985797, 0.5169719858722439, 0.9464210076892463], 
             UndirectedEdge[33, 150] -> 
             RGBColor[
              0.24249803494618108`, 0.37221118836485045`, 0.9371212763952667],
              UndirectedEdge[38, 213] -> 
             RGBColor[
              0.2920695594579869, 0.42277299217815684`, 0.9400007253602725], 
             UndirectedEdge[86, 262] -> 
             RGBColor[
              0.31621623896980977`, 0.44455427693598626`, 0.9415075983220833],
              UndirectedEdge[17, 310] -> 
             RGBColor[
              0.8270891883762761, 0.20922494918390394`, 0.1735739434229715], 
             UndirectedEdge[222, 223] -> 
             RGBColor[
              0.9051519086820443, 0.7083288764559916, 0.5859596439831081], 
             UndirectedEdge[19, 124] -> 
             RGBColor[
              0.21306575741872125`, 0.34127599856931323`, 0.9354451517312304],
              UndirectedEdge[184, 274] -> 
             RGBColor[
              0.20834640202144852`, 0.33631565682236503`, 0.9351763914230165],
              UndirectedEdge[195, 360] -> 
             RGBColor[
              0.5436868916256435, 0.6393368239296271, 0.957649106135095], 
             UndirectedEdge[186, 378] -> 
             RGBColor[
              0.22340907061728948`, 0.35214747654494266`, 0.9360341881163283],
              UndirectedEdge[31, 169] -> 
             RGBColor[
              0.7207585549931849, 0.779010354243588, 0.9304794974284005], 
             UndirectedEdge[4, 84] -> 
             RGBColor[
              0.20756604892203795`, 0.3354954562376403, 0.935131951468434], 
             UndirectedEdge[81, 383] -> 
             RGBColor[
              0.2937367673363199, 0.42148311575961905`, 0.9402070608717483], 
             UndirectedEdge[327, 335] -> 
             RGBColor[
              0.19201380881889718`, 0.3191490658202642, 0.9342462744020376], 
             UndirectedEdge[11, 214] -> 
             RGBColor[
              0.8760571062553216, 0.722408188261647, 0.6042242389431952], 
             UndirectedEdge[15, 35] -> 
             RGBColor[
              0.1861148468094702, 0.312948882732563, 0.933910337242333], 
             UndirectedEdge[151, 354] -> 
             RGBColor[
              0.20185675911317996`, 0.3294946306586492, 0.934806815859957], 
             UndirectedEdge[91, 192] -> 
             RGBColor[
              0.4254211791359827, 0.5344518171008017, 0.9495440785539795], 
             UndirectedEdge[44, 130] -> 
             RGBColor[
              0.22198842052975598`, 0.350654283228527, 0.9359532841955067], 
             UndirectedEdge[195, 356] -> 
             RGBColor[
              0.6850009171912799, 0.7504962345412768, 0.9628064219580481], 
             UndirectedEdge[226, 315] -> 
             RGBColor[
              0.186507225222572, 0.3133612973229612, 0.9339326826124872], 
             UndirectedEdge[65, 206] -> 
             RGBColor[
              0.4026912595828178, 0.5232126620245969, 0.9468801088680859], 
             UndirectedEdge[287, 400] -> 
             RGBColor[
              0.8197171091545148, 0.15255991781973297`, 0.16651443203464028`],
              UndirectedEdge[247, 319] -> 
             RGBColor[
              0.8248915640805821, 0.1923330458420928, 0.17146949591555327`], 
             UndirectedEdge[55, 72] -> 
             RGBColor[
              0.6346370252408752, 0.7117938428167392, 0.9660702931075245], 
             UndirectedEdge[313, 329] -> 
             RGBColor[
              0.27347825653768526`, 0.4047733655170204, 0.9388855541837721], 
             UndirectedEdge[5, 357] -> 
             RGBColor[
              0.1864106536609117, 0.3132597944886656, 0.9339271830049154], 
             UndirectedEdge[39, 328] -> 
             RGBColor[
              0.21476290196670605`, 0.3430598050944246, 0.9355418016025379], 
             UndirectedEdge[310, 384] -> 
             RGBColor[
              0.8800507133233684, 0.4896085562326786, 0.2192223210475797], 
             UndirectedEdge[66, 344] -> 
             RGBColor[
              0.19384485664191092`, 0.32107361317738903`, 0.9343505498667657],
              UndirectedEdge[271, 391] -> 
             RGBColor[
              0.820118482997181, 0.15564505305760412`, 0.1668987880796643], 
             UndirectedEdge[203, 211] -> 
             RGBColor[
              0.27124930343896736`, 0.4023137700960795, 0.9387628961154517], 
             UndirectedEdge[100, 203] -> 
             RGBColor[
              0.3488608742001085, 0.47658748779993204`, 0.9434500843118405], 
             UndirectedEdge[323, 377] -> 
             RGBColor[
              0.3376579889612439, 0.46188664535790686`, 0.9429192280934666], 
             UndirectedEdge[351, 395] -> 
             RGBColor[
              0.37411784951982285`, 0.4984638103693781, 0.9450594364453463], 
             UndirectedEdge[179, 209] -> 
             RGBColor[
              0.24592936800917714`, 0.3758177369731411, 0.9373166857370019], 
             UndirectedEdge[283, 356] -> 
             RGBColor[
              0.9386530516866118, 0.8632951638170323, 0.6207085244635109], 
             UndirectedEdge[77, 80] -> 
             RGBColor[
              0.20002934434875747`, 0.3275739018764531, 0.9347027472925409], 
             UndirectedEdge[200, 398] -> 
             RGBColor[
              0.18742715801975252`, 0.3143282050199061, 0.933985071424368], 
             UndirectedEdge[280, 368] -> 
             RGBColor[
              0.19638103924398845`, 0.323739301895437, 0.934494981714008], 
             UndirectedEdge[3, 390] -> 
             RGBColor[
              0.22459916207358144`, 0.353398338121662, 0.9361019620641815], 
             UndirectedEdge[64, 380] -> 
             RGBColor[
              0.8564837144111264, 0.8840181121327374, 0.7035464946088651], 
             UndirectedEdge[139, 186] -> 
             RGBColor[
              0.2567623305791477, 0.38720386748367763`, 0.9379336069294297], 
             UndirectedEdge[160, 245] -> 
             RGBColor[
              0.19509478987731566`, 0.3223873722581438, 0.9344217317154114], 
             UndirectedEdge[64, 360] -> 
             RGBColor[
              0.8276703795499445, 0.8615089159497265, 0.7006746506658257], 
             UndirectedEdge[72, 337] -> 
             RGBColor[
              0.7112579708229148, 0.7722092308988048, 0.9543875188835923], 
             UndirectedEdge[11, 141] -> 
             RGBColor[
              0.6144798263952078, 0.6921466750328611, 0.9658286154835842], 
             UndirectedEdge[62, 223] -> 
             RGBColor[
              0.9255100897331807, 0.7222473691090705, 0.4948669383214451], 
             UndirectedEdge[351, 399] -> 
             RGBColor[
              0.33446531711843736`, 0.46411877979752536`, 0.9425328121440877],
              UndirectedEdge[205, 232] -> 
             RGBColor[
              0.18775686622597437`, 0.3146747492493529, 0.9340038478189527], 
             UndirectedEdge[175, 379] -> 
             RGBColor[
              0.1863024171876671, 0.3131460310926968, 0.9339210190978857], 
             UndirectedEdge[144, 339] -> 
             RGBColor[
              0.48160738498318656`, 0.5880919933231088, 0.9528684097242202], 
             UndirectedEdge[66, 275] -> 
             RGBColor[
              0.19513571872831864`, 0.3224303910755869, 0.9344240625529272], 
             UndirectedEdge[311, 346] -> 
             RGBColor[
              0.20301118387702347`, 0.33070800428020625`, 0.9348725586424393],
              UndirectedEdge[81, 326] -> 
             RGBColor[
              0.23536377630225702`, 0.36471263019196243`, 0.936714990919685], 
             UndirectedEdge[145, 335] -> 
             RGBColor[
              0.2240686969525251, 0.3528407856460005, 0.9360717528602902], 
             UndirectedEdge[24, 56] -> 
             RGBColor[
              0.3892899244154366, 0.5053479265592988, 0.9466788406566481], 
             UndirectedEdge[310, 319] -> 
             RGBColor[
              0.8294805357972241, 0.22760589335643167`, 0.17586390041391192`],
              UndirectedEdge[131, 303] -> 
             RGBColor[
              0.8540204827009316, 0.7329759435664439, 0.607655802146349], 
             UndirectedEdge[146, 317] -> 
             RGBColor[
              0.19381671894004093`, 0.32104403866869025`, 0.9343489474662702],
              UndirectedEdge[159, 321] -> 
             RGBColor[
              0.1833474210515813, 0.31004014279609426`, 0.9337527364394607], 
             UndirectedEdge[339, 361] -> 
             RGBColor[
              0.39576579821065194`, 0.5172141754678363, 0.9464388245933966], 
             UndirectedEdge[60, 297] -> 
             RGBColor[
              0.5017919184919047, 0.6000427072524873, 0.955816605103172], 
             UndirectedEdge[1, 368] -> 
             RGBColor[
              0.1828231865844723, 0.30948913913277776`, 0.9337228820620942], 
             UndirectedEdge[15, 106] -> 
             RGBColor[
              0.18432449600494816`, 0.311067110522213, 0.933808379412602], 
             UndirectedEdge[144, 282] -> 
             RGBColor[
              0.44814038646858245`, 0.5591045613100133, 0.9507359221725744], 
             UndirectedEdge[333, 391] -> 
             RGBColor[
              0.8870053729463696, 0.5607909002029526, 0.5650690319922165], 
             UndirectedEdge[85, 238] -> 
             RGBColor[
              0.19138550303315327`, 0.3184886766025597, 0.9342104933170345], 
             UndirectedEdge[130, 135] -> 
             RGBColor[
              0.27550933277442513`, 0.40444794828705827`, 0.9390913012054878],
              UndirectedEdge[194, 256] -> 
             RGBColor[
              0.7238719368935342, 0.7799355863354847, 0.863740011258672], 
             UndirectedEdge[129, 271] -> 
             RGBColor[
              0.8196694573268939, 0.15219364499147486`, 0.1664688005906955], 
             UndirectedEdge[12, 168] -> 
             RGBColor[
              0.22037492795635888`, 0.34895840023254887`, 0.9358613981804], 
             UndirectedEdge[32, 271] -> 
             RGBColor[
              0.8207608095887371, 0.16058225670961188`, 0.16751388074914259`],
              UndirectedEdge[227, 363] -> 
             RGBColor[
              0.3242588248996095, 0.45206516990504564`, 0.9420001166496061], 
             UndirectedEdge[351, 355] -> 
             RGBColor[
              0.2588476494190366, 0.38932088860423164`, 0.9380551008583563], 
             UndirectedEdge[70, 285] -> 
             RGBColor[
              0.1906202345698193, 0.31768433092677273`, 0.9341669124101608], 
             UndirectedEdge[19, 107] -> 
             RGBColor[
              0.211296993265781, 0.33941691529844853`, 0.9353444232293726], 
             UndirectedEdge[88, 359] -> 
             RGBColor[
              0.3780427703410259, 0.5018633795124479, 0.9453095289294022], 
             UndirectedEdge[128, 130] -> 
             RGBColor[
              0.2597826750311079, 0.39037844100358665`, 0.9381056110777697], 
             UndirectedEdge[72, 297] -> 
             RGBColor[
              0.3810483803734705, 0.5030082457772378, 0.9456339650216002], 
             UndirectedEdge[125, 184] -> 
             RGBColor[
              0.20307558723579205`, 0.3307756962936808, 0.934876226318445], 
             UndirectedEdge[41, 63] -> 
             RGBColor[
              0.19205972818458644`, 0.31919732998505956`, 0.9342488894419819],
              UndirectedEdge[67, 133] -> 
             RGBColor[
              0.1814057266970613, 0.30799929891896116`, 0.9336421598184501], 
             UndirectedEdge[272, 308] -> 
             RGBColor[
              0.20474955864050876`, 0.33253514637595527`, 0.9349715565135248],
              UndirectedEdge[199, 287] -> 
             RGBColor[
              0.9030273761887495, 0.5618684791886028, 0.5002796321253148], 
             UndirectedEdge[60, 333] -> 
             RGBColor[
              0.8304001644203418, 0.8680494122522482, 0.9672808175416883], 
             UndirectedEdge[86, 325] -> 
             RGBColor[
              0.25318562671626305`, 0.38344452494766296`, 0.9377299189356977],
              UndirectedEdge[77, 377] -> 
             RGBColor[
              0.22582310918113752`, 0.35468478413443216`, 0.9361716640412894],
              UndirectedEdge[62, 319] -> 
             RGBColor[
              0.9121241184522142, 0.6206330104563391, 0.4820984852913445], 
             UndirectedEdge[52, 199] -> 
             RGBColor[
              0.9888652062926342, 0.9896634908979279, 0.8341958778608433], 
             UndirectedEdge[57, 376] -> 
             RGBColor[
              0.31723897478085683`, 0.4471117135410761, 0.941511560889603], 
             UndirectedEdge[11, 161] -> 
             RGBColor[
              0.8763695857039919, 0.7238270844566292, 0.6044849794547379], 
             UndirectedEdge[155, 300] -> 
             RGBColor[
              0.19103033479495424`, 0.31811537226524556`, 0.9341902670112934],
              UndirectedEdge[81, 275] -> 
             RGBColor[
              0.21165010291327152`, 0.33978805592640576`, 0.9353645323014182],
              UndirectedEdge[100, 266] -> 
             RGBColor[
              0.5229669528809726, 0.6215828095678126, 0.9562473514884939], 
             UndirectedEdge[56, 266] -> 
             RGBColor[
              0.5883098999275997, 0.6764125091387695, 0.9608991949142476], 
             UndirectedEdge[82, 257] -> 
             RGBColor[
              0.8645894369328215, 0.89448136547207, 0.956668495179433], 
             UndirectedEdge[32, 259] -> 
             RGBColor[
              0.85847174370837, 0.5429301584289652, 0.5790636952869976], 
             UndirectedEdge[261, 355] -> 
             RGBColor[
              0.19867201809183277`, 0.32614726592096993`, 0.9346254495701933],
              UndirectedEdge[74, 179] -> 
             RGBColor[
              0.23767352171657924`, 0.3671403190687327, 0.9368465275040685], 
             UndirectedEdge[100, 174] -> 
             RGBColor[
              0.4027739307357637, 0.5232842676221057, 0.9468853766008484], 
             UndirectedEdge[208, 388] -> 
             RGBColor[
              0.28259974438226976`, 0.4143606275774112, 0.9394050094224892], 
             UndirectedEdge[249, 299] -> 
             RGBColor[
              0.186005835268804, 0.3128343046915919, 0.9339041291963601], 
             UndirectedEdge[58, 181] -> 
             RGBColor[
              0.19266290312611054`, 0.31983130509210156`, 0.9342832393625844],
              UndirectedEdge[271, 345] -> 
             RGBColor[
              0.8240432411662075, 0.5102555022323721, 0.5751262620695841], 
             UndirectedEdge[20, 89] -> 
             RGBColor[
              0.30842578765479933`, 0.4344898392135439, 0.9411326397648885], 
             UndirectedEdge[174, 358] -> 
             RGBColor[
              0.34771638286513834`, 0.47271625798382977`, 0.9434826066423876],
              UndirectedEdge[185, 274] -> 
             RGBColor[
              0.19784473283359588`, 0.32527773666164805`, 0.9345783368985956],
              UndirectedEdge[106, 314] -> 
             RGBColor[
              0.18463641563674799`, 0.3113949578320815, 0.9338261427741893], 
             UndirectedEdge[73, 387] -> 
             RGBColor[
              0.19202691052884113`, 0.31916283654811173`, 0.9342470205250366],
              UndirectedEdge[191, 261] -> 
             RGBColor[
              0.18660634868245718`, 0.3134654823640909, 0.9339383275468877], 
             UndirectedEdge[135, 227] -> 
             RGBColor[
              0.3046735470917944, 0.4351013866526011, 0.9407521600662733], 
             UndirectedEdge[102, 345] -> 
             RGBColor[
              0.5885592438891699, 0.6712468009440402, 0.9634628617416172], 
             UndirectedEdge[72, 108] -> 
             RGBColor[
              0.3859501572545172, 0.5081603240698226, 0.9459131139634468], 
             UndirectedEdge[7, 273] -> 
             RGBColor[
              0.3894971814838498, 0.5048902400899095, 0.9467521342900769], 
             UndirectedEdge[111, 385] -> 
             RGBColor[
              0.9105148340902678, 0.5980129106436974, 0.4034418367204835], 
             UndirectedEdge[25, 187] -> 
             RGBColor[
              0.29015449891481293`, 0.4171960722657919, 0.940022163552006], 
             UndirectedEdge[290, 338] -> 
             RGBColor[
              0.2338329245191738, 0.3631036079063329, 0.9366278111753308], 
             UndirectedEdge[133, 200] -> 
             RGBColor[
              0.18872606349581567`, 0.31569343703061226`, 0.9340590421696713],
              UndirectedEdge[64, 88] -> 
             RGBColor[
              0.7114905669436782, 0.7668789695612932, 0.6914868954695467], 
             UndirectedEdge[23, 92] -> 
             RGBColor[
              0.20814505737279243`, 0.33610403083063944`, 0.9351649251431382],
              UndirectedEdge[38, 350] -> 
             RGBColor[
              0.3036355127427933, 0.43279083959174136`, 0.9407376976762094], 
             UndirectedEdge[135, 224] -> 
             RGBColor[
              0.41655140034572946`, 0.5340112529021572, 0.9480965874177693], 
             UndirectedEdge[329, 358] -> 
             RGBColor[
              0.26996801721198005`, 0.40108388142367646`, 0.9386856512471069],
              UndirectedEdge[4, 185] -> 
             RGBColor[
              0.1966973229914563, 0.32407173616757357`, 0.9345129936055264], 
             UndirectedEdge[111, 199] -> 
             RGBColor[
              0.9076739184987976, 0.597583839511456, 0.5047291662889358], 
             UndirectedEdge[138, 264] -> 
             RGBColor[
              0.27444206081652406`, 0.4057863849228008, 0.9389404414116314], 
             UndirectedEdge[275, 344] -> 
             RGBColor[
              0.19285336525809532`, 0.32003149286881416`, 0.9342940858992375],
              UndirectedEdge[300, 371] -> 
             RGBColor[
              0.1880971018774196, 0.31503235849120814`, 0.934023223735969], 
             UndirectedEdge[69, 273] -> 
             RGBColor[
              0.5484319039049934, 0.644280752022615, 0.9575937149291112], 
             UndirectedEdge[65, 174] -> 
             RGBColor[
              0.39716489293029483`, 0.5184260009934458, 0.9465279736717613], 
             UndirectedEdge[217, 254] -> 
             RGBColor[
              0.1976623221296092, 0.32508601144625143`, 0.934567948878856], 
             UndirectedEdge[102, 378] -> 
             RGBColor[
              0.29463589617818253`, 0.42328641527644917`, 0.9402268398959757],
              UndirectedEdge[246, 326] -> 
             RGBColor[
              0.22913658446266597`, 0.35816745674178546`, 0.9363603615567251],
              UndirectedEdge[120, 242] -> 
             RGBColor[
              0.3764731339021319, 0.500503839321299, 0.9452095130834909], 
             UndirectedEdge[25, 117] -> 
             RGBColor[
              0.4612467201078884, 0.5710736628239611, 0.9514005522875624], 
             UndirectedEdge[44, 227] -> 
             RGBColor[
              0.25115263484712524`, 0.3813077215940698, 0.9376141430562922], 
             UndirectedEdge[118, 206] -> 
             RGBColor[
              0.39316789594043106`, 0.5149640030957358, 0.9462732885579729], 
             UndirectedEdge[151, 158] -> 
             RGBColor[
              0.19937632863451948`, 0.3268875409572013, 0.9346655590136652], 
             UndirectedEdge[151, 308] -> 
             RGBColor[
              0.2102300370530294, 0.33829547666991544`, 0.9352836616514766], 
             UndirectedEdge[298, 390] -> 
             RGBColor[
              0.2092243065114207, 0.3372383901036854, 0.935226386784977], 
             UndirectedEdge[62, 111] -> 
             RGBColor[
              0.9092079691258396, 0.5982182088690406, 0.47930597740308856`], 
             UndirectedEdge[131, 201] -> 
             RGBColor[
              0.7399124857733206, 0.7967445245200704, 0.9747112197727283], 
             UndirectedEdge[291, 368] -> 
             RGBColor[
              0.1896468250359693, 0.3166612157889672, 0.9341114781772385], 
             UndirectedEdge[35, 73] -> 
             RGBColor[
              0.19430576499947028`, 0.3215580570844616, 0.9343767979158759], 
             UndirectedEdge[273, 293] -> 
             RGBColor[
              0.4190878106551068, 0.5354941029446921, 0.9484555024448121], 
             UndirectedEdge[4, 274] -> 
             RGBColor[
              0.2019924165278475, 0.3296372152026416, 0.934814541349035], 
             UndirectedEdge[10, 337] -> 
             RGBColor[
              0.8999731601904741, 0.6493526399014464, 0.5732428918038912], 
             UndirectedEdge[27, 265] -> 
             RGBColor[
              0.20201462184730384`, 0.32966055440128883`, 0.9348158059091283],
              UndirectedEdge[262, 325] -> 
             RGBColor[
              0.3013026030921642, 0.42887910004945207`, 0.9406582888215985], 
             UndirectedEdge[46, 337] -> 
             RGBColor[
              0.8812578483212357, 0.9077231190596664, 0.969479570547889], 
             UndirectedEdge[322, 327] -> 
             RGBColor[
              0.19043725974580353`, 0.3174920127854582, 0.9341564922646202], 
             UndirectedEdge[59, 299] -> 
             RGBColor[
              0.20233103571342284`, 0.3299931254363777, 0.9348338252107113], 
             UndirectedEdge[254, 369] -> 
             RGBColor[
              0.1837415562121556, 0.31045440383947037`, 0.9337751818537847], 
             UndirectedEdge[262, 376] -> 
             RGBColor[
              0.3252561022413611, 0.4540557463948223, 0.9420224051621189], 
             UndirectedEdge[360, 389] -> 
             RGBColor[
              0.8279393932352007, 0.862084309021034, 0.7299551301459482], 
             UndirectedEdge[159, 381] -> 
             RGBColor[
              0.18574510039169012`, 0.3125602558041992, 0.9338892807308311], 
             UndirectedEdge[77, 302] -> 
             RGBColor[
              0.19582677060371215`, 0.3231567304118451, 0.9344634169349113], 
             UndirectedEdge[67, 398] -> 
             RGBColor[
              0.18010682122099816`, 0.306634066908255, 0.9335681890731469], 
             UndirectedEdge[12, 100] -> 
             RGBColor[
              0.315248838603848, 0.44137593165251704`, 0.941531651095973], 
             UndirectedEdge[329, 339] -> 
             RGBColor[
              0.322148238300078, 0.44915969522157617`, 0.9419050804873051], 
             UndirectedEdge[1, 113] -> 
             RGBColor[
              0.18373091059218155`, 0.31044321461790636`, 0.9337745756014759],
              UndirectedEdge[232, 390] -> 
             RGBColor[
              0.20167142330655186`, 0.3292998309749142, 0.9347962612599492], 
             UndirectedEdge[319, 384] -> 
             RGBColor[
              0.8830145607989899, 0.5123899866965502, 0.22206050473742173`], 
             UndirectedEdge[342, 374] -> 
             RGBColor[
              0.18501533393427727`, 0.31179322498759243`, 0.9338477216106742],
              UndirectedEdge[200, 320] -> 
             RGBColor[
              0.18887757795522245`, 0.31585268833402036`, 0.934067670693989], 
             UndirectedEdge[35, 231] -> 
             RGBColor[
              0.19065322565130216`, 0.31771900664516656`, 0.9341687912034454],
              UndirectedEdge[96, 104] -> 
             RGBColor[
              0.21783923349947054`, 0.34629322458604483`, 0.935716994132304], 
             UndirectedEdge[106, 197] -> 
             RGBColor[
              0.18891531916432497`, 0.315892356737718, 0.9340698200000144], 
             UndirectedEdge[41, 265] -> 
             RGBColor[
              0.19689578074158462`, 0.3242803278459065, 0.9345242954808043], 
             UndirectedEdge[52, 303] -> 
             RGBColor[
              0.9414623591594504, 0.8004800076065881, 0.5326277353789215], 
             UndirectedEdge[170, 208] -> 
             RGBColor[
              0.26496099146250607`, 0.3958211798972109, 0.9384005085379051], 
             UndirectedEdge[49, 355] -> 
             RGBColor[
              0.19591924831876065`, 0.3232539303537868, 0.9344686834039748], 
             UndirectedEdge[140, 359] -> 
             RGBColor[
              0.36601815692823686`, 0.491448263748933, 0.9445433311956875], 
             UndirectedEdge[20, 255] -> 
             RGBColor[
              0.37940724758906264`, 0.5030452211240766, 0.9453964722130872], 
             UndirectedEdge[117, 362] -> 
             RGBColor[
              0.6749012549506066, 0.7446731281041272, 0.9691094737182575], 
             UndirectedEdge[188, 293] -> 
             RGBColor[
              0.29496948602480166`, 0.4268642457721712, 0.9401276735084836], 
             UndirectedEdge[149, 155] -> 
             RGBColor[
              0.19811293609800762`, 0.3255596352976139, 0.9345936106777326], 
             UndirectedEdge[7, 188] -> 
             RGBColor[
              0.2653788568535447, 0.3962603829173885, 0.9384243053537484], 
             UndirectedEdge[120, 331] -> 
             RGBColor[
              0.3267582826576653, 0.45117687376714777`, 0.9422711725263158], 
             UndirectedEdge[169, 218] -> 
             RGBColor[
              0.5087675338544672, 0.6120794295560898, 0.9544711904233589], 
             UndirectedEdge[345, 350] -> 
             RGBColor[
              0.5883144988769012, 0.6710348151156551, 0.9634472668058549], 
             UndirectedEdge[147, 217] -> 
             RGBColor[
              0.2277310230294914, 0.3566901225577769, 0.9362803169124476], 
             UndirectedEdge[141, 386] -> 
             RGBColor[
              0.348846857880801, 0.4765753475686286, 0.9434491912043683], 
             UndirectedEdge[128, 383] -> 
             RGBColor[
              0.3311097462205182, 0.46076448615063337`, 0.9423353967308358], 
             UndirectedEdge[138, 394] -> 
             RGBColor[
              0.32326515413332657`, 0.4525833434947314, 0.9418863146939478], 
             UndirectedEdge[132, 300] -> 
             RGBColor[
              0.1945175148280322, 0.3217806195799947, 0.9343888567553567], 
             UndirectedEdge[103, 122] -> 
             RGBColor[
              0.1920779072643653, 0.3192164373505274, 0.9342499247136817], 
             UndirectedEdge[147, 195] -> 
             RGBColor[
              0.3359166803532971, 0.45968692435363845`, 0.9428335921754714], 
             UndirectedEdge[123, 389] -> 
             RGBColor[
              0.9181405448210238, 0.6602175731108506, 0.3409253014924295], 
             UndirectedEdge[93, 394] -> 
             RGBColor[
              0.35007693853437594`, 0.4776407816051039, 0.9435275708558966], 
             UndirectedEdge[199, 350] -> 
             RGBColor[
              0.6686405102956781, 0.7329620420673324, 0.8898856192140527], 
             UndirectedEdge[66, 158] -> 
             RGBColor[
              0.19363377892106423`, 0.3208517571096786, 0.934338529302825], 
             UndirectedEdge[105, 215] -> 
             RGBColor[
              0.8456866310237973, 0.8792487049970009, 0.932290412064394], 
             UndirectedEdge[253, 364] -> 
             RGBColor[
              0.8732653702236979, 0.4602425769354192, 0.2136613812182268], 
             UndirectedEdge[76, 78] -> 
             RGBColor[
              0.2517003601981642, 0.38188341566580475`, 0.9376453352047469], 
             UndirectedEdge[153, 358] -> 
             RGBColor[
              0.24162422522743635`, 0.37129275894771363`, 0.9370715142244698],
              UndirectedEdge[54, 64] -> 
             RGBColor[
              0.970419525130984, 0.9095497585157698, 0.3557751825465969], 
             UndirectedEdge[84, 125] -> 
             RGBColor[
              0.20344264397852102`, 0.33116149620303065`, 0.9348971296569317],
              UndirectedEdge[195, 380] -> 
             RGBColor[
              0.5725002264868254, 0.6618460201126379, 0.9605209500781344], 
             UndirectedEdge[81, 146] -> 
             RGBColor[
              0.2141426413323014, 0.3424078718408697, 0.9355064786770019], 
             UndirectedEdge[275, 317] -> 
             RGBColor[
              0.19132418052101102`, 0.3184242227542263, 0.9342070010906866], 
             UndirectedEdge[25, 377] -> 
             RGBColor[
              0.3093279743113551, 0.4373486105761115, 0.941114064611224], 
             UndirectedEdge[180, 232] -> 
             RGBColor[
              0.18939213687360562`, 0.3163935223821609, 0.9340969740631693], 
             UndirectedEdge[52, 333] -> 
             RGBColor[
              0.9713855964493081, 0.9773821088501203, 0.8975894720005477], 
             UndirectedEdge[97, 276] -> 
             RGBColor[
              0.33883500638970604`, 0.46696780675347616`, 0.9428455083067513],
              UndirectedEdge[51, 390] -> 
             RGBColor[
              0.2070958500160861, 0.33500124737515247`, 0.935105174336337], 
             UndirectedEdge[199, 393] -> 
             RGBColor[
              0.8553537557812887, 0.8861695254659845, 0.9046321600313321], 
             UndirectedEdge[169, 224] -> 
             RGBColor[
              0.4775031351026399, 0.5866975822042433, 0.9520099424283488], 
             UndirectedEdge[132, 268] -> 
             RGBColor[
              0.19026708475134468`, 0.3173131480765642, 0.9341468010504371], 
             UndirectedEdge[162, 183] -> 
             RGBColor[
              0.1919904214056781, 0.3191244841661233, 0.9342449425234534], 
             UndirectedEdge[15, 231] -> 
             RGBColor[
              0.18666830847322874`, 0.31353060603266947`, 0.9339418560653108],
              UndirectedEdge[246, 248] -> 
             RGBColor[
              0.19980719089443424`, 0.32734040451061686`, 0.9346900959819637],
              UndirectedEdge[44, 81] -> 
             RGBColor[
              0.22873470286488637`, 0.35774505370175413`, 0.9363374749942621],
              UndirectedEdge[39, 197] -> 
             RGBColor[
              0.19474286460527196`, 0.3220174764838748, 0.9344016900917953], 
             UndirectedEdge[57, 86] -> 
             RGBColor[
              0.30819911150930557`, 0.43761024408224003`, 0.9409967540495674],
              UndirectedEdge[74, 209] -> 
             RGBColor[
              0.2567896978925637, 0.3872326322652657, 0.9379351654574425], 
             UndirectedEdge[115, 389] -> 
             RGBColor[
              0.9741155744429982, 0.9237122058552483, 0.3878131353348738], 
             UndirectedEdge[157, 168] -> 
             RGBColor[
              0.222412865673202, 0.35110040198566517`, 0.9359774557185156], 
             UndirectedEdge[224, 363] -> 
             RGBColor[
              0.4361366781535445, 0.5509750361546019, 0.9493445440011021], 
             UndirectedEdge[47, 279] -> 
             RGBColor[
              0.19002059109890063`, 0.3170540676192452, 0.934132763601585], 
             UndirectedEdge[58, 352] -> 
             RGBColor[
              0.18979453396815193`, 0.3168164672419784, 0.9341198899824106], 
             UndirectedEdge[101, 161] -> 
             RGBColor[
              0.8667600435785252, 0.4809006664576717, 0.21026073973276477`], 
             UndirectedEdge[23, 98] -> 
             RGBColor[
              0.2025842284056299, 0.3302592470092312, 0.9348482441599675], 
             UndirectedEdge[37, 388] -> 
             RGBColor[
              0.27755649571754953`, 0.4090598534703564, 0.9391178038718512], 
             UndirectedEdge[13, 21] -> 
             RGBColor[
              0.2050154097981298, 0.332814572798552, 0.9349866963436598], 
             UndirectedEdge[159, 375] -> 
             RGBColor[
              0.19246854917072223`, 0.3196270267622359, 0.9342721711923458], 
             UndirectedEdge[130, 346] -> 
             RGBColor[
              0.20954480137125253`, 0.3375752505219164, 0.9352446384931148], 
             UndirectedEdge[104, 225] -> 
             RGBColor[
              0.2162656212099744, 0.3446392582970026, 0.935627379240368], 
             UndirectedEdge[226, 252] -> 
             RGBColor[
              0.19892295516503677`, 0.32641101669523676`, 0.9346397400652842],
              UndirectedEdge[64, 283] -> 
             RGBColor[
              0.9622538962308652, 0.8771757609613251, 0.3492049258616166], 
             UndirectedEdge[262, 284] -> 
             RGBColor[
              0.5520990373737982, 0.6433480852372535, 0.9595712205145508], 
             UndirectedEdge[282, 313] -> 
             RGBColor[
              0.2998205585054363, 0.43188039345676055`, 0.940406960657616], 
             UndirectedEdge[88, 360] -> 
             RGBColor[
              0.5465756968337885, 0.6418389618053506, 0.9578331782484879], 
             UndirectedEdge[210, 230] -> 
             RGBColor[
              0.2334030426063412, 0.36265177475985827`, 0.9366033300363481], 
             UndirectedEdge[2, 138] -> 
             RGBColor[
              0.24536530114030092`, 0.3752248669300471, 0.9372845629632816], 
             UndirectedEdge[178, 367] -> 
             RGBColor[
              0.18455036747987072`, 0.3113045157634352, 0.933821242458952], 
             UndirectedEdge[54, 123] -> 
             RGBColor[
              0.8957058066069172, 0.5826430148496441, 0.23309163667201951`], 
             UndirectedEdge[36, 95] -> 
             RGBColor[
              0.2464425329575721, 0.37635710587044113`, 0.9373459097216534], 
             UndirectedEdge[294, 301] -> 
             RGBColor[
              0.22980051567191817`, 0.3588652905383795, 0.9363981714568937], 
             UndirectedEdge[60, 337] -> 
             RGBColor[
              0.8320015089413489, 0.8692436923740543, 0.9645701589651641], 
             UndirectedEdge[251, 275] -> 
             RGBColor[
              0.1895350470293607, 0.3165437300168866, 0.9341051125851229], 
             UndirectedEdge[66, 311] -> 
             RGBColor[
              0.19936169446772767`, 0.32687215952004334`, 0.9346647256195157],
              UndirectedEdge[110, 400] -> 
             RGBColor[
              0.8375389435666232, 0.5282930654888892, 0.5773241994710698], 
             UndirectedEdge[143, 151] -> 
             RGBColor[
              0.2032578843654731, 0.3309673021352812, 0.934886607870296], 
             UndirectedEdge[157, 206] -> 
             RGBColor[
              0.3378748813614898, 0.46135031520372605`, 0.942959564481942], 
             UndirectedEdge[226, 274] -> 
             RGBColor[
              0.1975222198425889, 0.324938755059595, 0.9345599702608729], 
             UndirectedEdge[86, 265] -> 
             RGBColor[
              0.23354789403514828`, 0.36280402279564555`, 0.9366115791109302],
              UndirectedEdge[64, 389] -> 
             RGBColor[
              0.9928542633450905, 0.9871243167769764, 0.4636088473670069], 
             UndirectedEdge[120, 356] -> 
             RGBColor[
              0.6789656354460096, 0.7452687768356042, 0.9624218591420297], 
             UndirectedEdge[164, 279] -> 
             RGBColor[
              0.20701484030443992`, 0.33491610103189995`, 0.9351005609531018],
              UndirectedEdge[24, 238] -> 
             RGBColor[
              0.23053198107939255`, 0.35963410705922055`, 0.9364398273297434],
              UndirectedEdge[213, 259] -> 
             RGBColor[
              0.6104189913379899, 0.6878648671799451, 0.9659218116631232], 
             UndirectedEdge[73, 162] -> 
             RGBColor[
              0.19690433907813965`, 0.3242893232002557, 0.9345247828654102], 
             UndirectedEdge[257, 356] -> 
             RGBColor[
              0.9574019127188883, 0.9677509967704889, 0.9569916297931109], 
             UndirectedEdge[6, 281] -> 
             RGBColor[
              0.6624572537085711, 0.7318807392393671, 0.9697242643368251], 
             UndirectedEdge[176, 277] -> 
             RGBColor[
              0.18565952896853344`, 0.31247031481291987`, 0.933884407564874], 
             UndirectedEdge[140, 263] -> 
             RGBColor[
              0.35408935706105976`, 0.48047689556673456`, 0.943806644371628], 
             UndirectedEdge[54, 161] -> 
             RGBColor[
              0.9139000708098552, 0.6892402426005217, 0.2492124251865322], 
             UndirectedEdge[7, 142] -> 
             RGBColor[
              0.36455405628776205`, 0.4846402873807406, 0.9447885201049626], 
             UndirectedEdge[81, 311] -> 
             RGBColor[
              0.21587607865268055`, 0.34422982437086214`, 0.9356051953680067],
              UndirectedEdge[204, 237] -> 
             RGBColor[
              0.18108298927677668`, 0.3076600814275077, 0.9336237803998122], 
             UndirectedEdge[134, 374] -> 
             RGBColor[
              0.18137577945827954`, 0.307967822472237, 0.9336404543675045], 
             UndirectedEdge[264, 279] -> 
             RGBColor[
              0.22950792112061041`, 0.35855775511338905`, 0.9363815086300517],
              UndirectedEdge[81, 344] -> 
             RGBColor[
              0.2103592408268638, 0.3384312780282078, 0.9352910196152566], 
             UndirectedEdge[287, 391] -> 
             RGBColor[
              0.8187766066009462, 0.14533080306215745`, 0.16561380572719725`],
              UndirectedEdge[90, 228] -> 
             RGBColor[
              0.21978849971833822`, 0.34834202697269134`, 0.9358280019597877],
              UndirectedEdge[222, 259] -> 
             RGBColor[
              0.9232560562805229, 0.9412465076079086, 0.9787839457914527], 
             UndirectedEdge[143, 342] -> 
             RGBColor[
              0.19264878464975516`, 0.3198164656782889, 0.9342824353362423], 
             UndirectedEdge[68, 262] -> 
             RGBColor[
              0.5929687866565062, 0.6752889407487281, 0.9636412596987081], 
             UndirectedEdge[73, 189] -> 
             RGBColor[
              0.2158427366159144, 0.3441947797762137, 0.9356032965883381], 
             UndirectedEdge[79, 176] -> 
             RGBColor[
              0.19262785863960308`, 0.31979447111483345`, 0.9342812436309215],
              UndirectedEdge[14, 289] -> 
             RGBColor[
              0.4064318553204269, 0.5258851919600367, 0.9472752267865294], 
             UndirectedEdge[126, 373] -> 
             RGBColor[
              0.19027225530167013`, 0.317318582652788, 0.934147095505629], 
             UndirectedEdge[313, 361] -> 
             RGBColor[
              0.3470958164482592, 0.47282784576328063`, 0.9434192982898635], 
             UndirectedEdge[56, 203] -> 
             RGBColor[
              0.4142038212467356, 0.5314171873708888, 0.948101927737594], 
             UndirectedEdge[163, 240] -> 
             RGBColor[
              0.17919351847301027`, 0.305674127813381, 0.9335161778327592], 
             UndirectedEdge[283, 380] -> 
             RGBColor[
              0.8261523609821573, 0.7746449493883936, 0.6184230525835972], 
             UndirectedEdge[165, 318] -> 
             RGBColor[
              0.21949852941857476`, 0.348037249802461, 0.9358114885801888], 
             UndirectedEdge[184, 185] -> 
             RGBColor[
              0.20305130848505737`, 0.330750177787297, 0.9348748436795078], 
             UndirectedEdge[123, 364] -> 
             RGBColor[
              0.8822480780789155, 0.5292876057583029, 0.22226323240490067`], 
             UndirectedEdge[24, 341] -> 
             RGBColor[
              0.25476263408947386`, 0.38510205968495004`, 0.9378197271726287],
              UndirectedEdge[10, 364] -> 
             RGBColor[
              0.8821527210971085, 0.5285546502104392, 0.22217191845143208`], 
             UndirectedEdge[59, 132] -> 
             RGBColor[
              0.20457320024571096`, 0.33234978252125474`, 0.93496151316384], 
             UndirectedEdge[110, 309] -> 
             RGBColor[
              0.7751646817101416, 0.8245503622153614, 0.9781540938970312], 
             UndirectedEdge[28, 50] -> 
             RGBColor[
              0.21136185866227802`, 0.33948509294287055`, 0.9353481172177434],
              UndirectedEdge[120, 147] -> 
             RGBColor[
              0.3298813986080268, 0.4544594666479659, 0.9424490293594527], 
             UndirectedEdge[322, 335] -> 
             RGBColor[
              0.19668775397946056`, 0.3240616785292556, 0.9345124486644494], 
             UndirectedEdge[9, 198] -> 
             RGBColor[
              0.7575782172127392, 0.8106163649808842, 0.9764530707316865], 
             UndirectedEdge[214, 257] -> 
             RGBColor[
              0.9241708234933428, 0.7599031818045514, 0.5786645333196092], 
             UndirectedEdge[190, 274] -> 
             RGBColor[
              0.20764624835933113`, 0.33557975093117354`, 0.9351365187077434],
              UndirectedEdge[18, 198] -> 
             RGBColor[
              0.9106667100371233, 0.9263839830131071, 0.7062421502048801], 
             UndirectedEdge[280, 291] -> 
             RGBColor[
              0.20219476439486456`, 0.32984989564047235`, 0.9348260647607148],
              UndirectedEdge[156, 179] -> 
             RGBColor[
              0.21434244441768896`, 0.34261787755185935`, 0.9355178571671325],
              UndirectedEdge[76, 96] -> 
             RGBColor[
              0.24728213971667218`, 0.37723958580839845`, 0.9373937240844974],
              UndirectedEdge[143, 158] -> 
             RGBColor[
              0.1950219034609478, 0.3223107640132754, 0.9344175809418251], 
             UndirectedEdge[252, 274] -> 
             RGBColor[
              0.20454056169243495`, 0.3323154773323579, 0.9349596544465153], 
             UndirectedEdge[272, 348] -> 
             RGBColor[
              0.1988777254844435, 0.3263634774332058, 0.9346371643018856], 
             UndirectedEdge[51, 232] -> 
             RGBColor[
              0.19578437289714112`, 0.32311216773406903`, 0.9344610024482438],
              UndirectedEdge[66, 317] -> 
             RGBColor[
              0.19231567190482668`, 0.3194663430628012, 0.9342634650582149], 
             UndirectedEdge[258, 264] -> 
             RGBColor[
              0.24881577416889822`, 0.37885153285572853`, 0.9374810622977428],
              UndirectedEdge[17, 223] -> 
             RGBColor[
              0.843439007132864, 0.3336207383005069, 0.18918058014291417`], 
             UndirectedEdge[46, 271] -> 
             RGBColor[
              0.8127696138510401, 0.5013829917925117, 0.574019985211861], 
             UndirectedEdge[93, 201] -> 
             RGBColor[
              0.5041214136186714, 0.6049415425126292, 0.9551812111618987], 
             UndirectedEdge[232, 373] -> 
             RGBColor[
              0.19417254912152382`, 0.3214180387503654, 0.934369211468702], 
             UndirectedEdge[182, 208] -> 
             RGBColor[
              0.2681228139523549, 0.39914445580516655`, 0.9385805696512048], 
             UndirectedEdge[10, 391] -> 
             RGBColor[
              0.8316006559249898, 0.24390206570100256`, 0.1778941298425935], 
             UndirectedEdge[284, 366] -> 
             RGBColor[
              0.8665824589296481, 0.8923925729410807, 0.7434186835178305], 
             UndirectedEdge[154, 387] -> 
             RGBColor[
              0.18595738695423472`, 0.312783382441179, 0.9339013701365182], 
             UndirectedEdge[135, 363] -> 
             RGBColor[
              0.3549405295448861, 0.4818533796872159, 0.9438374745743816], 
             UndirectedEdge[37, 269] -> 
             RGBColor[
              0.3188674209826161, 0.4483513791388215, 0.9416215783296149], 
             UndirectedEdge[201, 281] -> 
             RGBColor[
              0.5322326354554701, 0.6292900699565726, 0.956972433359562], 
             UndirectedEdge[302, 377] -> 
             RGBColor[
              0.22469777382228445`, 0.35350198532189486`, 0.9361075778573873],
              UndirectedEdge[179, 286] -> 
             RGBColor[
              0.2740282991513247, 0.4041960245612692, 0.9389591857364195], 
             UndirectedEdge[108, 325] -> 
             RGBColor[
              0.2723177927173417, 0.4035536444641835, 0.9388194674859559], 
             UndirectedEdge[279, 299] -> 
             RGBColor[
              0.19371330684929777`, 0.320935346004614, 0.9343430583006869], 
             UndirectedEdge[196, 332] -> 
             RGBColor[
              0.8309647608435446, 0.5082040216040586, 0.5748389341298874], 
             UndirectedEdge[31, 224] -> 
             RGBColor[
              0.7410029688449329, 0.7954456814088879, 0.9320732118445416], 
             UndirectedEdge[200, 296] -> 
             RGBColor[
              0.1865617818736295, 0.3134186398223141, 0.9339357895330556], 
             UndirectedEdge[170, 221] -> 
             RGBColor[
              0.30270787399814014`, 0.42984035374028506`, 0.9407572019749026],
              UndirectedEdge[198, 206] -> 
             RGBColor[
              0.6288429856334741, 0.7061140055023541, 0.9660410068543737], 
             UndirectedEdge[36, 361] -> 
             RGBColor[
              0.32761397052464425`, 0.4523511904771868, 0.9423098359853219], 
             UndirectedEdge[132, 180] -> 
             RGBColor[
              0.1906491777676344, 0.3177147520627811, 0.9341685606824588], 
             UndirectedEdge[127, 312] -> 
             RGBColor[
              0.44359264480187605`, 0.5560735292696781, 0.9501952628642483], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.37498442055197767`, 0.49560326154572176`, 0.9453825139194686],
              UndirectedEdge[67, 75] -> 
             RGBColor[
              0.1806580838475214, 0.3072134788808002, 0.9335995826642074], 
             UndirectedEdge[110, 287] -> 
             RGBColor[
              0.8351408344121083, 0.5098601476691562, 0.5750277674364295], 
             UndirectedEdge[88, 233] -> 
             RGBColor[
              0.7003634497191511, 0.7623012578281982, 0.9418757273882692], 
             UndirectedEdge[168, 216] -> 
             RGBColor[
              0.20689038450304525`, 0.3347852900936806, 0.9350934733793282], 
             UndirectedEdge[1, 291] -> 
             RGBColor[
              0.1886369117353484, 0.31559973287781307`, 0.934053965108801], 
             UndirectedEdge[115, 214] -> 
             RGBColor[
              0.917014626987943, 0.7014084006737106, 0.2517091579831441], 
             UndirectedEdge[233, 256] -> 
             RGBColor[
              0.9813174831621745, 0.9842395002462874, 0.8561565043579783], 
             UndirectedEdge[4, 252] -> 
             RGBColor[
              0.20339315185029538`, 0.3311094768382833, 0.9348943111534462], 
             UndirectedEdge[91, 399] -> 
             RGBColor[
              0.4759758631677278, 0.5829069233744436, 0.9525944899971995], 
             UndirectedEdge[76, 269] -> 
             RGBColor[
              0.3181691701834686, 0.44761747327725976`, 0.9415818139795731], 
             UndirectedEdge[91, 172] -> 
             RGBColor[
              0.48609962486048197`, 0.5916756169176496, 0.9532395671401708], 
             UndirectedEdge[165, 184] -> 
             RGBColor[
              0.21954677082243013`, 0.3480879545765947, 0.9358142358567716], 
             UndirectedEdge[60, 139] -> 
             RGBColor[
              0.506983675095762, 0.6054995726195224, 0.9561122679612462], 
             UndirectedEdge[356, 359] -> 
             RGBColor[
              0.6355366085129286, 0.7076527365125309, 0.9596545999486343], 
             UndirectedEdge[228, 305] -> 
             RGBColor[
              0.26103370837156087`, 0.39169335636449776`, 0.9381768555757705],
              UndirectedEdge[141, 209] -> 
             RGBColor[
              0.3104061832925851, 0.4392395615986554, 0.9411477244574119], 
             UndirectedEdge[171, 348] -> 
             RGBColor[
              0.1945787269842331, 0.32184495743723673`, 0.934392342697097], 
             UndirectedEdge[10, 60] -> 
             RGBColor[
              0.774995447398962, 0.551160577750298, 0.5801059153920654], 
             UndirectedEdge[234, 298] -> 
             RGBColor[
              0.22620097648238727`, 0.3550819466262163, 0.936193183025091], 
             UndirectedEdge[323, 388] -> 
             RGBColor[
              0.34570167664203966`, 0.47034107110967827`, 0.9433773042073184],
              UndirectedEdge[294, 329] -> 
             RGBColor[
              0.23603593247132534`, 0.36541910894281576`, 0.9367532692191475],
              UndirectedEdge[211, 238] -> 
             RGBColor[
              0.21668562529693003`, 0.34508070922219014`, 0.9356512978517798],
              UndirectedEdge[31, 99] -> 
             RGBColor[
              0.9432122400933031, 0.9562926111989585, 0.9505366840460105], 
             UndirectedEdge[111, 319] -> 
             RGBColor[
              0.8295282339464709, 0.2279725222330049, 0.17590957621549802`], 
             UndirectedEdge[258, 394] -> 
             RGBColor[
              0.29763886748570073`, 0.42564849142765915`, 0.9404269355800592],
              UndirectedEdge[101, 364] -> 
             RGBColor[
              0.8876560448428017, 0.5708556080916793, 0.22744190748542303`], 
             UndirectedEdge[225, 349] -> 
             RGBColor[
              0.2034483891040132, 0.3311675346941849, 0.9348974568333293], 
             UndirectedEdge[118, 386] -> 
             RGBColor[
              0.34968714140668505`, 0.4773031589248714, 0.9435027333276041], 
             UndirectedEdge[95, 326] -> 
             RGBColor[
              0.24440137831360023`, 0.3742117229229475, 0.9372296689842969], 
             UndirectedEdge[228, 382] -> 
             RGBColor[
              0.27305197131929326`, 0.4030910170101112, 0.9389064714836659], 
             UndirectedEdge[120, 255] -> 
             RGBColor[
              0.39336824955180094`, 0.5151375393238391, 0.9462860549129236], 
             UndirectedEdge[222, 292] -> 
             RGBColor[
              0.8852896880649895, 0.5569352274955306, 0.5669895272748917], 
             UndirectedEdge[325, 397] -> 
             RGBColor[
              0.3012257827964342, 0.4288125621703911, 0.9406533939002841], 
             UndirectedEdge[155, 299] -> 
             RGBColor[
              0.1871446834102983, 0.31403130629544507`, 0.9339689849132433], 
             UndirectedEdge[17, 99] -> 
             RGBColor[
              0.8649138899410389, 0.5692261022124661, 0.5823263856846504], 
             UndirectedEdge[60, 105] -> 
             RGBColor[
              0.8461630434103341, 0.8796208819742317, 0.932337896398757], 
             UndirectedEdge[229, 340] -> 
             RGBColor[
              0.23465687622616624`, 0.36396963339193744`, 0.9366747340061166],
              UndirectedEdge[297, 375] -> 
             RGBColor[
              0.2496778587950193, 0.3797576384571041, 0.9375301567418605], 
             UndirectedEdge[155, 249] -> 
             RGBColor[
              0.18476081976801417`, 0.3115257144617197, 0.9338332274054255], 
             UndirectedEdge[143, 348] -> 
             RGBColor[
              0.20000377872339242`, 0.3275470307832401, 0.9347012913679973], 
             UndirectedEdge[175, 294] -> 
             RGBColor[
              0.19993479870238595`, 0.3274745284075764, 0.9346973630578478], 
             UndirectedEdge[19, 181] -> 
             RGBColor[
              0.19581756515250187`, 0.3231470548989638, 0.9344628926980831], 
             UndirectedEdge[153, 294] -> 
             RGBColor[
              0.20769214048678164`, 0.33562798646685293`, 0.9351391321965103],
              UndirectedEdge[68, 376] -> 
             RGBColor[
              0.5538916735521564, 0.639355835105775, 0.9612276966528428], 
             UndirectedEdge[317, 354] -> 
             RGBColor[
              0.19230267119241712`, 0.319452678489766, 0.934262724686876], 
             UndirectedEdge[2, 254] -> 
             RGBColor[
              0.19445154659843222`, 0.32171128278805783`, 0.9343850999622723],
              UndirectedEdge[243, 311] -> 
             RGBColor[
              0.21699506567726595`, 0.34540595068157653`, 0.9356689200236639],
              UndirectedEdge[23, 143] -> 
             RGBColor[
              0.20541157212716055`, 0.3332309645245057, 0.9350092572022285], 
             UndirectedEdge[20, 64] -> 
             RGBColor[
              0.6886054780275248, 0.7470570557801346, 0.690028677840299], 
             UndirectedEdge[75, 296] -> 
             RGBColor[
              0.18049305546872535`, 0.30704002359128196`, 0.9335901845421726],
              UndirectedEdge[146, 227] -> 
             RGBColor[
              0.2365605733145403, 0.3659705397331854, 0.936783146739032], 
             UndirectedEdge[160, 238] -> 
             RGBColor[
              0.19808883610787825`, 0.32553430467996036`, 0.9345922382189475],
              UndirectedEdge[75, 178] -> 
             RGBColor[
              0.18245868691760933`, 0.30910602687229105`, 0.9337021243452953],
              UndirectedEdge[95, 166] -> 
             RGBColor[
              0.24620280791930751`, 0.37610513965577974`, 0.9373322577353658],
              UndirectedEdge[25, 309] -> 
             RGBColor[
              0.5306642654095335, 0.6265873056000757, 0.957441478589943], 
             UndirectedEdge[166, 326] -> 
             RGBColor[
              0.24337300372818133`, 0.3731308360309576, 0.9371711045730012], 
             UndirectedEdge[158, 308] -> 
             RGBColor[
              0.20199405614850408`, 0.32963893854790965`, 0.9348146347230057],
              UndirectedEdge[229, 343] -> 
             RGBColor[
              0.1993208104479567, 0.32682918782306747`, 0.9346623973350723], 
             UndirectedEdge[229, 294] -> 
             RGBColor[
              0.20382733943636777`, 0.33156583552032837`, 0.9349190374941501],
              UndirectedEdge[64, 257] -> 
             RGBColor[
              0.9810027572631417, 0.9816315939147817, 0.6854880311912166], 
             UndirectedEdge[56, 65] -> 
             RGBColor[
              0.4474461015886463, 0.5602099797974611, 0.9502200964459863], 
             UndirectedEdge[170, 192] -> 
             RGBColor[
              0.2468852126322833, 0.37682239027607506`, 0.9373711196742425], 
             UndirectedEdge[133, 347] -> 
             RGBColor[
              0.18386468807739512`, 0.3105838232368483, 0.9337821940313528], 
             UndirectedEdge[223, 393] -> 
             RGBColor[
              0.7905940425099285, 0.6181725668402647, 0.5885810229879949], 
             UndirectedEdge[116, 338] -> 
             RGBColor[
              0.22507866009155236`, 0.35390232094047974`, 0.9361292687669514],
              UndirectedEdge[32, 71] -> 
             RGBColor[
              0.8956113709184261, 0.5716673969312225, 0.5522037062726537], 
             UndirectedEdge[95, 361] -> 
             RGBColor[
              0.32840262007179855`, 0.45318011115451534`, 0.9423547484103298],
              UndirectedEdge[247, 292] -> 
             RGBColor[
              0.8184153147444937, 0.14255375553436297`, 0.16526783223743757`],
              UndirectedEdge[337, 391] -> 
             RGBColor[
              0.8886067174673766, 0.5619851803247587, 0.5623583734156922], 
             UndirectedEdge[181, 238] -> 
             RGBColor[
              0.1965022388034804, 0.3238666903169589, 0.9345018838496224], 
             UndirectedEdge[97, 246] -> 
             RGBColor[
              0.2576631748496625, 0.38815071192881434`, 0.9379849086779559], 
             UndirectedEdge[62, 247] -> 
             RGBColor[
              0.9045712992599508, 0.5625787324781286, 0.4748658971031438], 
             UndirectedEdge[207, 280] -> 
             RGBColor[
              0.200223112625469, 0.32777756462089525`, 0.9347137821092452], 
             UndirectedEdge[145, 221] -> 
             RGBColor[
              0.3098924284635012, 0.43739177601044266`, 0.941166351723109], 
             UndirectedEdge[10, 334] -> 
             RGBColor[
              0.9015893430893124, 0.6043580043169925, 0.2443543042542488], 
             UndirectedEdge[25, 78] -> 
             RGBColor[
              0.29221377727191306`, 0.41936050438489303`, 0.9401394364080135],
              UndirectedEdge[46, 139] -> 
             RGBColor[
              0.5562400144756487, 0.6439789993051345, 0.961021679543971], 
             UndirectedEdge[224, 383] -> 
             RGBColor[
              0.42803255257249384`, 0.5439556499014909, 0.9488281562852744], 
             UndirectedEdge[138, 164] -> 
             RGBColor[
              0.2519489800003536, 0.38214473084131173`, 0.9376594937346815], 
             UndirectedEdge[53, 93] -> 
             RGBColor[
              0.37256678589576175`, 0.4971203570169409, 0.9449606040427729], 
             UndirectedEdge[31, 199] -> 
             RGBColor[
              0.9864970705564884, 0.9886842059127192, 0.8734420155476115], 
             UndirectedEdge[98, 342] -> 
             RGBColor[
              0.1898214409282245, 0.31684474816301444`, 0.9341214222939813], 
             UndirectedEdge[141, 304] -> 
             RGBColor[
              0.31901866548224, 0.4482918264428926, 0.9416381925770871], 
             UndirectedEdge[32, 105] -> 
             RGBColor[
              0.903410578527918, 0.577299573576944, 0.5307412035187635], 
             UndirectedEdge[216, 329] -> 
             RGBColor[
              0.23907766788565177`, 0.368616165720437, 0.936926491551149], 
             UndirectedEdge[164, 264] -> 
             RGBColor[
              0.23748584663754294`, 0.36694306066137816`, 0.9368358396859577],
              UndirectedEdge[118, 196] -> 
             RGBColor[
              0.6007859963931654, 0.6812853787799371, 0.9644958808837701], 
             UndirectedEdge[75, 398] -> 
             RGBColor[
              0.18135843161484838`, 0.30794958878887396`, 0.9336394664334849],
              UndirectedEdge[45, 48] -> 
             RGBColor[
              0.2238300988639671, 0.3525900039269335, 0.9360581650521211], 
             UndirectedEdge[248, 275] -> 
             RGBColor[
              0.18852850716525682`, 0.3154857928014001, 0.9340477916289045], 
             UndirectedEdge[200, 347] -> 
             RGBColor[
              0.1891857716327594, 0.31617661942971953`, 0.9340852218679931], 
             UndirectedEdge[33, 58] -> 
             RGBColor[
              0.21989646734481127`, 0.3484555077936574, 0.9358341505563915], 
             UndirectedEdge[134, 240] -> 
             RGBColor[
              0.17922390736570504`, 0.3057060684663703, 0.9335179084352418], 
             UndirectedEdge[267, 344] -> 
             RGBColor[
              0.1945632673718405, 0.321828708404416, 0.9343914622950418], 
             UndirectedEdge[141, 286] -> 
             RGBColor[
              0.3385051144347327, 0.4676178491867835, 0.9427902244568296], 
             UndirectedEdge[33, 209] -> 
             RGBColor[
              0.25581747523043485`, 0.38621076460489123`, 0.9378797988151089],
              UndirectedEdge[47, 155] -> 
             RGBColor[
              0.18345196765990118`, 0.3101500279100763, 0.9337586902141416], 
             UndirectedEdge[153, 229] -> 
             RGBColor[
              0.2017865527982215, 0.3294208393702904, 0.934802817714181], 
             UndirectedEdge[64, 161] -> 
             RGBColor[
              0.9360657953387055, 0.766239407790421, 0.32776561052681985`], 
             UndirectedEdge[3, 293] -> 
             RGBColor[
              0.2751725873267546, 0.40605645004464963`, 0.939000269414517], 
             UndirectedEdge[133, 178] -> 
             RGBColor[
              0.18320632976714918`, 0.309891846910452, 0.9337447014995381], 
             UndirectedEdge[113, 162] -> 
             RGBColor[
              0.19047273002269705`, 0.31752929429541876`, 0.9341585122444157],
              UndirectedEdge[313, 358] -> 
             RGBColor[
              0.28110733593194254`, 0.4127920116719563, 0.9393200189690635], 
             UndirectedEdge[259, 292] -> 
             RGBColor[
              0.8574582528162021, 0.5351400233172219, 0.5780931752640834], 
             UndirectedEdge[4, 165] -> 
             RGBColor[
              0.21319278532882907`, 0.3414095129568713, 0.9354523857827901], 
             UndirectedEdge[247, 385] -> 
             RGBColor[
              0.9058781642243791, 0.5623734342527853, 0.3990017564205388], 
             UndirectedEdge[38, 243] -> 
             RGBColor[
              0.24505985490147014`, 0.37490382356662577`, 0.9372671682518474],
              UndirectedEdge[265, 381] -> 
             RGBColor[
              0.19417265233719494`, 0.3214181472365799, 0.9343692173466818], 
             UndirectedEdge[15, 369] -> 
             RGBColor[
              0.18126767848005537`, 0.30785420149012543`, 0.9336342981767156],
              UndirectedEdge[30, 358] -> 
             RGBColor[
              0.2391480425105603, 0.3686901339132248, 0.9369304992819277], 
             UndirectedEdge[133, 330] -> 
             RGBColor[
              0.1860526851696524, 0.3128835469078388, 0.9339067972289052], 
             UndirectedEdge[223, 292] -> 
             RGBColor[
              0.8393541052177236, 0.30222239216530483`, 0.1852688734557389], 
             UndirectedEdge[44, 326] -> 
             RGBColor[
              0.2349425006851034, 0.3642698428079171, 0.9366909998965096], 
             UndirectedEdge[123, 356] -> 
             RGBColor[
              0.8942706865915142, 0.6457615828952505, 0.5831484206142015], 
             UndirectedEdge[35, 154] -> 
             RGBColor[
              0.18823624142486384`, 0.31517860297752887`, 0.9340311475273575],
              UndirectedEdge[146, 151] -> 
             RGBColor[
              0.20337080686080378`, 0.3310859908375735, 0.9348930386393511], 
             UndirectedEdge[111, 287] -> 
             RGBColor[
              0.8219655423100481, 0.16984236032285321`, 0.168667534163621], 
             UndirectedEdge[42, 133] -> 
             RGBColor[
              0.1836453052262827, 0.310353237950653, 0.9337697005025297], 
             UndirectedEdge[40, 103] -> 
             RGBColor[
              0.19411926264855695`, 0.32136203128871965`, 0.9343661768828968],
              UndirectedEdge[219, 260] -> 
             RGBColor[
              0.1839290162486566, 0.31065143622348573`, 0.9337858574255411], 
             UndirectedEdge[151, 186] -> 
             RGBColor[
              0.20709670832782653`, 0.33500214951521173`, 0.9351052232159208],
              UndirectedEdge[8, 76] -> 
             RGBColor[
              0.26926683315553557`, 0.4003468925227164, 0.9386457198524012], 
             UndirectedEdge[124, 167] -> 
             RGBColor[
              0.23121257205082407`, 0.360349451322155, 0.9364785859787222], 
             UndirectedEdge[162, 291] -> 
             RGBColor[
              0.1953787311658639, 0.32268581255532547`, 0.9344379017517408], 
             UndirectedEdge[242, 255] -> 
             RGBColor[
              0.3572936731332409, 0.48389155439101317`, 0.9439874148030284], 
             UndirectedEdge[182, 323] -> 
             RGBColor[
              0.3312247462121247, 0.45512489933743366`, 0.9425528644360341], 
             UndirectedEdge[138, 149] -> 
             RGBColor[
              0.2496156992329207, 0.3796923048161946, 0.9375266168467558], 
             UndirectedEdge[199, 353] -> 
             RGBColor[
              0.9909977762454061, 0.988800838647677, 0.6720451430779383], 
             UndirectedEdge[34, 381] -> 
             RGBColor[
              0.18614322275265005`, 0.3129787076479837, 0.9339119532103186], 
             UndirectedEdge[148, 305] -> 
             RGBColor[
              0.2773062230664102, 0.4087968010458064, 0.939103551214614], 
             UndirectedEdge[97, 383] -> 
             RGBColor[
              0.32847115554353346`, 0.45799116005281093`, 0.9421851328952267],
              UndirectedEdge[154, 207] -> 
             RGBColor[
              0.18894498275511917`, 0.315923535052423, 0.9340715092976267], 
             UndirectedEdge[272, 375] -> 
             RGBColor[
              0.1997235147350348, 0.3272524555617131, 0.9346853307484737], 
             UndirectedEdge[25, 323] -> 
             RGBColor[
              0.3922918508728892, 0.5142052168895364, 0.9462174677409253], 
             UndirectedEdge[236, 334] -> 
             RGBColor[
              0.7349237676396162, 0.7451154652166593, 0.6272347577119612], 
             UndirectedEdge[23, 346] -> 
             RGBColor[
              0.20767293699657277`, 0.3356078023810718, 0.935138038586152], 
             UndirectedEdge[23, 151] -> 
             RGBColor[
              0.20976599730073225`, 0.3378077414684315, 0.9352572352740687], 
             UndirectedEdge[250, 381] -> 
             RGBColor[
              0.19153445496524343`, 0.31864523452728444`, 0.9342189759092124],
              UndirectedEdge[230, 264] -> 
             RGBColor[
              0.2405521506109405, 0.3701659405523198, 0.9370104611610526], 
             UndirectedEdge[60, 68] -> 
             RGBColor[
              0.7643140770585692, 0.8158203298412934, 0.9771398668713851], 
             UndirectedEdge[50, 258] -> 
             RGBColor[
              0.23439017041921995`, 0.3636893086787121, 0.9366595455049669], 
             UndirectedEdge[121, 298] -> 
             RGBColor[
              0.2245949434093795, 0.353393904038107, 0.9361017218174963], 
             UndirectedEdge[95, 382] -> 
             RGBColor[
              0.2846635750266093, 0.4152955487246973, 0.9395677351369693], 
             UndirectedEdge[42, 200] -> 
             RGBColor[
              0.18896638878164698`, 0.3159460341435242, 0.9340727283391701], 
             UndirectedEdge[254, 314] -> 
             RGBColor[
              0.1849157269952969, 0.31168853177927935`, 0.9338420491428545], 
             UndirectedEdge[95, 305] -> 
             RGBColor[
              0.2726453120788769, 0.4038978880790839, 0.9388381192290738], 
             UndirectedEdge[321, 381] -> 
             RGBColor[
              0.18695109985789307`, 0.313827837707961, 0.9339579606163151], 
             UndirectedEdge[116, 209] -> 
             RGBColor[
              0.2525333735524159, 0.38275896551722044`, 0.9376927740829386], 
             UndirectedEdge[364, 366] -> 
             RGBColor[
              0.9573192010017704, 0.856958801294309, 0.38384804144330753`], 
             UndirectedEdge[58, 156] -> 
             RGBColor[
              0.19753761270804981`, 0.3249549339371585, 0.9345608468617892], 
             UndirectedEdge[118, 179] -> 
             RGBColor[
              0.29213029064248475`, 0.4198750597583651, 0.9401126286272736], 
             UndirectedEdge[149, 328] -> 
             RGBColor[
              0.22083892747976266`, 0.3494460931509151, 0.9358878222668322], 
             UndirectedEdge[215, 227] -> 
             RGBColor[
              0.4900314069116405, 0.5878102265694376, 0.9551265080130549], 
             UndirectedEdge[70, 177] -> 
             RGBColor[
              0.1891804395703839, 0.31617101509409057`, 0.9340849182149289], 
             UndirectedEdge[383, 393] -> 
             RGBColor[
              0.5401446576878393, 0.6337537414941011, 0.9584878557690468], 
             UndirectedEdge[14, 201] -> 
             RGBColor[
              0.5021816905325309, 0.6032614518687315, 0.9550576137220795], 
             UndirectedEdge[5, 368] -> 
             RGBColor[
              0.18532540128789612`, 0.31211912543565157`, 0.9338653794877592],
              UndirectedEdge[214, 310] -> 
             RGBColor[
              0.8527190352209195, 0.3739582811888842, 0.19685354443386982`], 
             UndirectedEdge[35, 280] -> 
             RGBColor[
              0.19951437129521365`, 0.3270326325460011, 0.9346734203389759], 
             UndirectedEdge[243, 275] -> 
             RGBColor[
              0.21276908993785693`, 0.3409641822371201, 0.9354282569570754], 
             UndirectedEdge[131, 391] -> 
             RGBColor[
              0.817172560246312, 0.5056217507313383, 0.5745581182301532], 
             UndirectedEdge[2, 314] -> 
             RGBColor[
              0.19228958849813182`, 0.3194389277485814, 0.9342619796467905], 
             UndirectedEdge[282, 361] -> 
             RGBColor[
              0.36229879969604784`, 0.48822674345474093`, 0.9443063370417508],
              UndirectedEdge[110, 269] -> 
             RGBColor[
              0.6031830035578256, 0.6830576186116337, 0.9647885304899277], 
             UndirectedEdge[193, 360] -> 
             RGBColor[
              0.7503418220523833, 0.8050370370474327, 0.9757122305140027], 
             UndirectedEdge[71, 400] -> 
             RGBColor[
              0.8959095468804387, 0.5739593080367903, 0.5524892399106185], 
             UndirectedEdge[110, 117] -> 
             RGBColor[
              0.7057471364084966, 0.7690367194392469, 0.9721131675946504], 
             UndirectedEdge[170, 351] -> 
             RGBColor[
              0.27252940237618284`, 0.4037012784354327, 0.938834256448926], 
             UndirectedEdge[121, 200] -> 
             RGBColor[
              0.2188856606362972, 0.3473930858541622, 0.9357765866096961], 
             UndirectedEdge[38, 383] -> 
             RGBColor[
              0.3085216567311646, 0.43702297192973105`, 0.9410490384505009], 
             UndirectedEdge[172, 256] -> 
             RGBColor[
              0.6859636429526801, 0.7471589426256584, 0.8613086090450968], 
             UndirectedEdge[127, 258] -> 
             RGBColor[
              0.2885106861095953, 0.4177421195154126, 0.9398452959345076], 
             UndirectedEdge[25, 388] -> 
             RGBColor[
              0.31737166199215083`, 0.44580303632788293`, 0.9415721407250759],
              UndirectedEdge[51, 277] -> 
             RGBColor[
              0.19316166908716753`, 0.3203555397407608, 0.9343116433462084], 
             UndirectedEdge[85, 379] -> 
             RGBColor[
              0.18217848519657132`, 0.30881151709766497`, 0.9336861672718034],
              UndirectedEdge[267, 306] -> 
             RGBColor[
              0.20993199303624877`, 0.33798221351119695`, 0.9352666884856375],
              UndirectedEdge[176, 298] -> 
             RGBColor[
              0.19583511598337588`, 0.32316550193499927`, 0.9344638921919373],
              UndirectedEdge[269, 323] -> 
             RGBColor[
              0.38701260190710624`, 0.5096325967781434, 0.9458810786650822], 
             UndirectedEdge[21, 180] -> 
             RGBColor[
              0.19254611619106632`, 0.3197085546186507, 0.9342765885194044], 
             UndirectedEdge[36, 228] -> 
             RGBColor[
              0.23483092925025606`, 0.364152574155855, 0.9366846460683501], 
             UndirectedEdge[74, 116] -> 
             RGBColor[
              0.244277527259818, 0.37408154761281204`, 0.9372226158500052], 
             UndirectedEdge[3, 188] -> 
             RGBColor[
              0.25601232241971317`, 0.38641556135484806`, 0.9378908950742876],
              UndirectedEdge[69, 394] -> 
             RGBColor[
              0.46522152575946735`, 0.5741285322522734, 0.9517610033724258], 
             UndirectedEdge[37, 395] -> 
             RGBColor[
              0.3615061899414258, 0.48528293772410147`, 0.9443384829836874], 
             UndirectedEdge[172, 194] -> 
             RGBColor[
              0.41753162873264527`, 0.5360090287080477, 0.9478416433121417], 
             UndirectedEdge[59, 264] -> 
             RGBColor[
              0.2381256499847355, 0.3676155345451527, 0.9368722755400762], 
             UndirectedEdge[28, 369] -> 
             RGBColor[
              0.1860007123494566, 0.3128289201785459, 0.9339038374536819], 
             UndirectedEdge[130, 344] -> 
             RGBColor[
              0.20361295849173341`, 0.3313405075549807, 0.9349068288165013], 
             UndirectedEdge[29, 270] -> 
             RGBColor[
              0.19689305639497057`, 0.3242774643848816, 0.9345241403332949], 
             UndirectedEdge[41, 48] -> 
             RGBColor[
              0.2013669879321785, 0.3289798500941302, 0.9347789241157504], 
             UndirectedEdge[12, 124] -> 
             RGBColor[
              0.23470207361547668`, 0.3640171387137828, 0.9366773079305742], 
             UndirectedEdge[61, 95] -> 
             RGBColor[
              0.23224869997063102`, 0.3614384874601766, 0.9365375919309413], 
             UndirectedEdge[213, 306] -> 
             RGBColor[
              0.2738566580723743, 0.4036300780572341, 0.9389635275699348], 
             UndirectedEdge[63, 295] -> 
             RGBColor[
              0.1876127220363632, 0.31452324456680214`, 0.9339956390205967], 
             UndirectedEdge[302, 367] -> 
             RGBColor[
              0.19039724530537674`, 0.31744995507150764`, 0.934154213501434], 
             UndirectedEdge[140, 331] -> 
             RGBColor[
              0.3236577561982914, 0.4484913535850291, 0.9420736097220124], 
             UndirectedEdge[92, 354] -> 
             RGBColor[
              0.20023581918524017`, 0.32779092002085713`, 0.9347145057290265],
              UndirectedEdge[151, 311] -> 
             RGBColor[
              0.20510424418118295`, 0.33290794336756596`, 0.934991755330356], 
             UndirectedEdge[299, 371] -> 
             RGBColor[
              0.18421145049276366`, 0.3109482925214076, 0.933801941637919], 
             UndirectedEdge[140, 389] -> 
             RGBColor[
              0.6997349672161455, 0.7570392468690857, 0.7200011772159544], 
             UndirectedEdge[176, 205] -> 
             RGBColor[
              0.18567915281687453`, 0.3124909407217502, 0.9338855251140061], 
             UndirectedEdge[152, 179] -> 
             RGBColor[
              0.2138285336364696, 0.3420777247369723, 0.935488590708405], 
             UndirectedEdge[142, 293] -> 
             RGBColor[
              0.3941446854590191, 0.5152441502355233, 0.946491888259698], 
             UndirectedEdge[105, 259] -> 
             RGBColor[
              0.9403634558512834, 0.9538207185775788, 0.9415651020124101], 
             UndirectedEdge[274, 318] -> 
             RGBColor[
              0.20829816061759315`, 0.33626495204823137`, 0.9351736441464337],
              UndirectedEdge[231, 369] -> 
             RGBColor[
              0.1858060573218873, 0.312624325402729, 0.9338927521378282], 
             UndirectedEdge[151, 348] -> 
             RGBColor[
              0.20435820389696413`, 0.332123807727166, 0.9349492694398375], 
             UndirectedEdge[147, 231] -> 
             RGBColor[
              0.2192108871052112, 0.34773491949353985`, 0.9357951077759714], 
             UndirectedEdge[66, 354] -> 
             RGBColor[
              0.19611420939972474`, 0.3234588468111266, 0.9344797861491166], 
             UndirectedEdge[24, 65] -> 
             RGBColor[
              0.3183379395633406, 0.44565996035968214`, 0.9416695943018074], 
             UndirectedEdge[42, 347] -> 
             RGBColor[
              0.18410501336322643`, 0.3108364203497602, 0.9337958802008515], 
             UndirectedEdge[52, 129] -> 
             RGBColor[
              0.904165411034544, 0.5696744067053534, 0.4991000639737569], 
             UndirectedEdge[3, 7] -> 
             RGBColor[
              0.24558195815549755`, 0.37545258718986685`, 0.9372969012597816],
              UndirectedEdge[156, 352] -> 
             RGBColor[
              0.19412861826228733`, 0.32137186463193046`, 0.9343667096712585],
              UndirectedEdge[229, 329] -> 
             RGBColor[
              0.2301303447827652, 0.3592119618462532, 0.9364169547368181], 
             UndirectedEdge[80, 187] -> 
             RGBColor[
              0.20972687217078761`, 0.3377666184761832, 0.9352550071557988], 
             UndirectedEdge[247, 362] -> 
             RGBColor[
              0.8043048253983777, 0.4855724402659776, 0.5720335274237128], 
             UndirectedEdge[43, 321] -> 
             RGBColor[
              0.1896253217591911, 0.31663861448168684`, 0.9341102535974373], 
             UndirectedEdge[84, 270] -> 
             RGBColor[
              0.21111604747539212`, 0.339226729800124, 0.9353341186342953], 
             UndirectedEdge[318, 322] -> 
             RGBColor[
              0.20428384988578308`, 0.3320456569470981, 0.9349450350888977], 
             UndirectedEdge[218, 276] -> 
             RGBColor[
              0.46966080217049366`, 0.5783141439540027, 0.951949779691809], 
             UndirectedEdge[201, 303] -> 
             RGBColor[
              0.7798220611835203, 0.6750115727481525, 0.6002603969131654], 
             UndirectedEdge[283, 364] -> 
             RGBColor[
              0.9266304431740131, 0.7468211866800847, 0.25982333625421017`], 
             UndirectedEdge[65, 340] -> 
             RGBColor[
              0.3239430587205376, 0.45155129597897675`, 0.941988797545779], 
             UndirectedEdge[83, 214] -> 
             RGBColor[
              0.9149531561640245, 0.7530286606028909, 0.5942676397554747], 
             UndirectedEdge[124, 157] -> 
             RGBColor[
              0.2367400113323198, 0.3661591404668991, 0.9367933654686897], 
             UndirectedEdge[311, 344] -> 
             RGBColor[
              0.19707934099750435`, 0.3244732613132706, 0.9345347489658259], 
             UndirectedEdge[190, 226] -> 
             RGBColor[
              0.20202864183193292`, 0.3296752902940524, 0.9348166043265123], 
             UndirectedEdge[380, 389] -> 
             RGBColor[
              0.8567527280963826, 0.8845935052040448, 0.7328269740889874], 
             UndirectedEdge[124, 179] -> 
             RGBColor[
              0.22671592710196903`, 0.3556231923771518, 0.9362225087010749], 
             UndirectedEdge[199, 215] -> 
             RGBColor[
              0.8474033618771311, 0.8799586173228249, 0.9038397390676208], 
             UndirectedEdge[146, 267] -> 
             RGBColor[
              0.19834666787727806`, 0.32580530221707793`, 0.9346069213567869],
              UndirectedEdge[109, 249] -> 
             RGBColor[
              0.18318613987214505`, 0.3098706260506894, 0.9337435517148859], 
             UndirectedEdge[36, 61] -> 
             RGBColor[
              0.23146005042347673`, 0.36060956678284806`, 0.9364926795059334],
              UndirectedEdge[13, 232] -> 
             RGBColor[
              0.20186143048066912`, 0.3294995405620621, 0.9348070818874247], 
             UndirectedEdge[38, 119] -> 
             RGBColor[
              0.249257790450226, 0.37931611999285497`, 0.9375062344710599], 
             UndirectedEdge[91, 256] -> 
             RGBColor[
              0.792439933021371, 0.8356021745450866, 0.869137935086701], 
             UndirectedEdge[6, 69] -> 
             RGBColor[
              0.7494906190968638, 0.8040199624425932, 0.9761664746556911], 
             UndirectedEdge[90, 97] -> 
             RGBColor[
              0.2570968896215246, 0.3875555102494842, 0.9379526595719574], 
             UndirectedEdge[233, 257] -> 
             RGBColor[
              0.9698756400386146, 0.9770538821816868, 0.9358768631099392], 
             UndirectedEdge[66, 119] -> 
             RGBColor[
              0.21795851687042844`, 0.3464185989719241, 0.9357237871438162], 
             UndirectedEdge[33, 116] -> 
             RGBColor[
              0.24330530459768918`, 0.3730596799524376, 0.9371672492076716], 
             UndirectedEdge[335, 349] -> 
             RGBColor[
              0.19833951424086566`, 0.32579778329164166`, 0.9346065139677762],
              UndirectedEdge[165, 274] -> 
             RGBColor[
              0.21434019517096867`, 0.34261551345094576`, 0.9355177290758593],
              UndirectedEdge[95, 169] -> 
             RGBColor[
              0.3522449518778092, 0.4737241407933565, 0.9439035250794346], 
             UndirectedEdge[135, 259] -> 
             RGBColor[
              0.6153899363844033, 0.6921704499321857, 0.9662385558858466], 
             UndirectedEdge[93, 273] -> 
             RGBColor[
              0.433287316679902, 0.5477930013754455, 0.949360282412582], 
             UndirectedEdge[89, 263] -> 
             RGBColor[
              0.2670289628172794, 0.39799474890803455`, 0.93851827644727], 
             UndirectedEdge[71, 289] -> 
             RGBColor[
              0.7219591346417744, 0.780476707159252, 0.9439593282102003], 
             UndirectedEdge[32, 215] -> 
             RGBColor[
              0.7637949188808839, 0.4683581448483874, 0.5697890053389816], 
             UndirectedEdge[8, 239] -> 
             RGBColor[
              0.3813679879787836, 0.49836836108207505`, 0.9461050956090218], 
             UndirectedEdge[110, 111] -> 
             RGBColor[
              0.8397873767221564, 0.5455755079920095, 0.5794773016000505], 
             UndirectedEdge[29, 162] -> 
             RGBColor[
              0.19056901057120365`, 0.3176304912564385, 0.9341639952792189], 
             UndirectedEdge[337, 353] -> 
             RGBColor[
              0.9751195109230872, 0.9777137367216755, 0.7327280786411184], 
             UndirectedEdge[306, 308] -> 
             RGBColor[
              0.2175738595337591, 0.3460142997224009, 0.9357018814775424], 
             UndirectedEdge[185, 190] -> 
             RGBColor[
              0.20235115482293997`, 0.33001427189610544`, 0.9348349709642347],
              UndirectedEdge[71, 385] -> 
             RGBColor[
              0.9820607295061435, 0.9836969405379016, 0.7849671104328407], 
             UndirectedEdge[146, 158] -> 
             RGBColor[
              0.1951348259562785, 0.3224294527155677, 0.9344240117108803], 
             UndirectedEdge[157, 386] -> 
             RGBColor[
              0.2943941268277438, 0.42368947103286164`, 0.9401890092515732], 
             UndirectedEdge[24, 124] -> 
             RGBColor[
              0.24340021238043813`, 0.3731594340496077, 0.9371726540654957], 
             UndirectedEdge[22, 74] -> 
             RGBColor[
              0.24528340650250224`, 0.37513879047330073`, 0.9372798991848111],
              UndirectedEdge[303, 385] -> 
             RGBColor[
              0.9441738208357854, 0.8008555462181073, 0.4334857922002555], 
             UndirectedEdge[130, 317] -> 
             RGBColor[
              0.20208377375464914`, 0.3297332374403929, 0.9348197440079504], 
             UndirectedEdge[73, 291] -> 
             RGBColor[
              0.19698615809912115`, 0.32437532017893284`, 0.9345294423376147],
              UndirectedEdge[241, 255] -> 
             RGBColor[
              0.32755009808125596`, 0.4555556663672059, 0.9421864088801596], 
             UndirectedEdge[385, 400] -> 
             RGBColor[
              0.9082664009347345, 0.5807304681405772, 0.40128873459150277`], 
             UndirectedEdge[130, 311] -> 
             RGBColor[
              0.20912979631755016`, 0.33713905389763504`, 0.9352210045692514],
              UndirectedEdge[143, 308] -> 
             RGBColor[
              0.2058756118794577, 0.33371869972598955`, 0.9350356835796365], 
             UndirectedEdge[297, 397] -> 
             RGBColor[
              0.33036980779411174`, 0.4594447802808611, 0.9423131030091806], 
             UndirectedEdge[237, 324] -> 
             RGBColor[
              0.18395646599811732`, 0.31068028765058353`, 0.9337874206481647],
              UndirectedEdge[107, 160] -> 
             RGBColor[
              0.20918830325598364`, 0.33720054839948277`, 0.935224336452842], 
             UndirectedEdge[125, 185] -> 
             RGBColor[
              0.1925739180479394, 0.31973777613296384`, 0.9342781717940241], 
             UndirectedEdge[269, 388] -> 
             RGBColor[
              0.3120924130263679, 0.44123041621648995`, 0.9412357516492327], 
             UndirectedEdge[47, 300] -> 
             RGBColor[
              0.18858263454534693`, 0.31554268410974895`, 0.9340508741031263],
              UndirectedEdge[37, 365] -> 
             RGBColor[
              0.29517424252624735`, 0.4275772223959621, 0.9401211084894857], 
             UndirectedEdge[356, 389] -> 
             RGBColor[
              0.969253418800837, 0.9732437196326836, 0.7351124459689012], 
             UndirectedEdge[227, 243] -> 
             RGBColor[
              0.2526928974888643, 0.38292663528882953`, 0.9377018587351249], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.1986316801099837, 0.3261048681444708, 0.9346231523818017], 
             UndirectedEdge[186, 348] -> 
             RGBColor[
              0.2038426026857459, 0.33158187816317064`, 0.9349199067136222], 
             UndirectedEdge[61, 90] -> 
             RGBColor[
              0.21641762089155886`, 0.3447990195996844, 0.935636035397371], 
             UndirectedEdge[72, 325] -> 
             RGBColor[
              0.35190435537579295`, 0.4723760276667679, 0.9439742559127038], 
             UndirectedEdge[341, 358] -> 
             RGBColor[
              0.26347030119752707`, 0.39425436991349627`, 0.9383156159325932],
              UndirectedEdge[102, 337] -> 
             RGBColor[
              0.6530069899856277, 0.722086925969716, 0.9505841497129952], 
             UndirectedEdge[297, 378] -> 
             RGBColor[
              0.2683985374759716, 0.3994342587103688, 0.9385962716979784], 
             UndirectedEdge[300, 370] -> 
             RGBColor[
              0.19085384504698283`, 0.3179298703500313, 0.9341802161812396], 
             UndirectedEdge[46, 52] -> 
             RGBColor[
              0.89726556755869, 0.9188637535063902, 0.9066512485949225], 
             UndirectedEdge[75, 200] -> 
             RGBColor[
              0.1879784206462758, 0.3149076169924513, 0.9340164650154286], 
             UndirectedEdge[204, 343] -> 
             RGBColor[
              0.1903303530090651, 0.3173796470268675, 0.9341504040841173], 
             UndirectedEdge[32, 199] -> 
             RGBColor[
              0.9051273093812517, 0.578009485902768, 0.5022905305219902], 
             UndirectedEdge[301, 313] -> 
             RGBColor[
              0.2672428397382781, 0.39821954711258417`, 0.9385304564215183], 
             UndirectedEdge[166, 363] -> 
             RGBColor[
              0.3098501203432949, 0.43692070785172515`, 0.9411795622408922], 
             UndirectedEdge[333, 353] -> 
             RGBColor[
              0.97351816640208, 0.9765194565998694, 0.7354387372176427], 
             UndirectedEdge[130, 146] -> 
             RGBColor[
              0.20739635899717102`, 0.3353171013676426, 0.9351222878782466], 
             UndirectedEdge[71, 271] -> 
             RGBColor[
              0.8948533141221586, 0.565840640212504, 0.5514777902284453], 
             UndirectedEdge[123, 332] -> 
             RGBColor[
              0.8304813654821182, 0.2352987088808914, 0.17682229605044186`], 
             UndirectedEdge[340, 361] -> 
             RGBColor[
              0.34048302917169776`, 0.46587738706068504`, 0.9430427098372054],
              UndirectedEdge[165, 322] -> 
             RGBColor[
              0.2103258844391586, 0.3383962183498125, 0.9352891200183233], 
             UndirectedEdge[278, 302] -> 
             RGBColor[
              0.19139766926121787`, 0.31850146407963903`, 0.9342111861657245],
              UndirectedEdge[322, 355] -> 
             RGBColor[
              0.2016258404569241, 0.32925192050983587`, 0.9347936653840967], 
             UndirectedEdge[68, 333] -> 
             RGBColor[
              0.8876904453290742, 0.9128181118706356, 0.9729875018597351], 
             UndirectedEdge[150, 156] -> 
             RGBColor[
              0.22013918030941965`, 0.34871061450835156`, 0.9358479727006643],
              UndirectedEdge[29, 357] -> 
             RGBColor[
              0.18592235681432462`, 0.3127465635430944, 0.9338993752218727], 
             UndirectedEdge[250, 325] -> 
             RGBColor[
              0.21599606078555122`, 0.34435593319981583`, 0.9356120281729761],
              UndirectedEdge[53, 131] -> 
             RGBColor[
              0.6083578580504109, 0.6889233390243821, 0.9644906126536026], 
             UndirectedEdge[92, 267] -> 
             RGBColor[
              0.20096723062757926`, 0.3285596798209194, 0.9347561585286415], 
             UndirectedEdge[269, 309] -> 
             RGBColor[
              0.5253850164437505, 0.6220146854886827, 0.9571050895141], 
             UndirectedEdge[162, 336] -> 
             RGBColor[
              0.21504897720554328`, 0.3433604883086603, 0.9355580931641793], 
             UndirectedEdge[94, 204] -> 
             RGBColor[
              0.1795232819748228, 0.3060207301619996, 0.9335349573763461], 
             UndirectedEdge[29, 183] -> 
             RGBColor[
              0.18726251983199932`, 0.31415515984591347`, 0.9339756955231359],
              UndirectedEdge[145, 208] -> 
             RGBColor[
              0.2721455459278671, 0.4033726021673685, 0.9388096582861116], 
             UndirectedEdge[75, 133] -> 
             RGBColor[
              0.18265733709091148`, 0.3093148207995801, 0.9337134371787883], 
             UndirectedEdge[169, 326] -> 
             RGBColor[
              0.349415147686683, 0.47074983716853436`, 0.9437423719170701], 
             UndirectedEdge[95, 97] -> 
             RGBColor[
              0.27292796870059677`, 0.4041949781099764, 0.9388542161055278], 
             UndirectedEdge[37, 78] -> 
             RGBColor[
              0.25239861099731176`, 0.3826173215273665, 0.9376850995547887], 
             UndirectedEdge[55, 397] -> 
             RGBColor[
              0.5839584526615165, 0.6682303773203624, 0.9627494310951048], 
             UndirectedEdge[185, 226] -> 
             RGBColor[
              0.1922271263061977, 0.3193732760245269, 0.9342584225173644], 
             UndirectedEdge[39, 254] -> 
             RGBColor[
              0.19262591917799537`, 0.31979243261771473`, 0.934281133181452], 
             UndirectedEdge[71, 201] -> 
             RGBColor[
              0.8177089698538784, 0.8578529670679469, 0.9517417151457506], 
             UndirectedEdge[227, 383] -> 
             RGBColor[
              0.3161546993185588, 0.44504578365193476`, 0.9414837289337784], 
             UndirectedEdge[38, 151] -> 
             RGBColor[
              0.23316903340538708`, 0.36240581625261525`, 0.9365900035585395],
              UndirectedEdge[45, 74] -> 
             RGBColor[
              0.2441275547351621, 0.3739239169805914, 0.9372140751365906], 
             UndirectedEdge[292, 303] -> 
             RGBColor[
              0.8567109713559, 0.3810358674996849, 0.1997518680171543], 
             UndirectedEdge[185, 357] -> 
             RGBColor[
              0.18927662196416456`, 0.31627210888827, 0.9340903956599655], 
             UndirectedEdge[86, 376] -> 
             RGBColor[
              0.2771391258654599, 0.4086211712930332, 0.939094035276218], 
             UndirectedEdge[212, 309] -> 
             RGBColor[
              0.6375731061251859, 0.7158069480258249, 0.965187359754256], 
             UndirectedEdge[50, 127] -> 
             RGBColor[
              0.28524823564473223`, 0.4143130772255349, 0.9396595042068966], 
             UndirectedEdge[92, 374] -> 
             RGBColor[
              0.1940034937220554, 0.32124035080679264`, 0.9343595840137974], 
             UndirectedEdge[118, 141] -> 
             RGBColor[
              0.35660710592589273`, 0.4832968843838794, 0.9439436673476838], 
             UndirectedEdge[205, 390] -> 
             RGBColor[
              0.19906834334491935`, 0.32656382889043634`, 
               0.9346480197070459]}, GraphLayout -> {"Dimension" -> 2}, 
           ImageSize -> 500, VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.24987309085249598`, 0.3799628397279394, 0.9375412749187138], 
             316 -> RGBColor[
              0.7121412574025138, 0.7750494298476431, 0.9719432432656107], 
             308 -> RGBColor[
              0.212847764567014, 0.3410468742606238, 0.9354327373608172], 160 -> 
             RGBColor[
              0.19529547244710238`, 0.32259830236299947`, 0.9344331602908775],
              245 -> RGBColor[
              0.19489410730752896`, 0.3221764421532881, 0.9344103031399453], 
             155 -> RGBColor[
              0.1858996679095085, 0.31272271606557295`, 0.9338980831223087], 
             213 -> RGBColor[
              0.3254133616442444, 0.45627843093029025`, 0.9419560295456021], 
             352 -> RGBColor[
              0.18638553952238943`, 0.3132333979367503, 0.9339257527918797], 
             27 -> RGBColor[
              0.20503271821821972`, 0.3328327650454837, 0.9349876820325784], 
             367 -> RGBColor[
              0.1860930553658944, 0.31292597854370746`, 0.9339090962518588], 
             19 -> RGBColor[
              0.19951285246669712`, 0.3270310361609309, 0.9346733338439388], 
             164 -> RGBColor[
              0.21499276582137244`, 0.3433014065798891, 0.935554892009008], 
             190 -> RGBColor[
              0.2121526703486752, 0.34031628616563087`, 0.9353931527733826], 
             103 -> RGBColor[
              0.19478977051563845`, 0.3220667775696765, 0.9344043613139996], 
             138 -> RGBColor[
              0.2889051941793347, 0.4209880551027343, 0.939764095460355], 291 -> 
             RGBColor[
              0.1954605501868454, 0.3227718095340026, 0.9344425612239453], 28 -> 
             RGBColor[
              0.19159599737019925`, 0.31870991949690686`, 0.9342224806581308],
              337 -> RGBColor[
              0.956979221732861, 0.9674357545252026, 0.9577071353769899], 195 -> 
             RGBColor[
              0.42461827381123246`, 0.5422047396654701, 0.9482772788254231], 
             114 -> RGBColor[
              0.18667779652152947`, 0.3135405785730105, 0.9339423963956253], 
             93 -> RGBColor[
              0.3425287629814334, 0.47110293132347947`, 0.9430466077842526], 
             34 -> RGBColor[
              0.1829376663072982, 0.30960946457990146`, 0.9337294015129516], 
             161 -> RGBColor[
              0.8795463410175769, 0.5459298918751729, 0.22120285316675511`], 
             22 -> RGBColor[
              0.24203296140503872`, 0.3717223665857442, 0.9370947911451132], 
             124 -> RGBColor[
              0.22661866237074535`, 0.3555209609776956, 0.9362169696185221], 
             84 -> RGBColor[
              0.21428709115836797`, 0.3425596977667136, 0.935514704880902], 
             46 -> RGBColor[
              0.8055364749096104, 0.8480104835941301, 0.9812520057187881], 
             241 -> RGBColor[
              0.28091140737960196`, 0.41258607834085864`, 0.939308861127858], 
             185 -> RGBColor[
              0.19254963929720473`, 0.31971225762658, 0.9342767891550869], 
             390 -> RGBColor[
              0.21298290042549683`, 0.3411889106159976, 0.9354404331480423], 
             121 -> RGBColor[
              0.24372417422141443`, 0.37349993848484087`, 0.9371911032130806],
              322 -> RGBColor[
              0.1951112049063669, 0.3224046254944496, 0.9344226665270321], 
             126 -> RGBColor[
              0.18255935854789945`, 0.309211839138676, 0.9337078574457099], 
             236 -> RGBColor[
              0.5096359477486948, 0.612784447077024, 0.9545395551462174], 78 -> 
             RGBColor[
              0.22046571832082573`, 0.34905382666204504`, 0.9358665685573442],
              376 -> RGBColor[
              0.28617898913701123`, 0.4181226407518692, 0.9396088421162536], 
             254 -> RGBColor[
              0.1870776850955973, 0.3139608868187558, 0.9339651694583363], 
             290 -> RGBColor[
              0.25752973177491306`, 0.38801045479647306`, 0.9379773092922603],
              251 -> RGBColor[
              0.1849258667142184, 0.3116991892667612, 0.9338426265848467], 
             165 -> RGBColor[
              0.22554056397195027`, 0.35438781120517543`, 0.9361555735096144],
              100 -> 
             RGBColor[
              0.387712192347488, 0.5102385468551641, 0.9459256559493198], 235 -> 
             RGBColor[
              0.19324911536591247`, 0.3204474513241361, 0.9343166232824178], 
             70 -> RGBColor[
              0.1969643686712329, 0.32435241810869275`, 0.934528201461931], 
             234 -> RGBColor[
              0.24693624036742998`, 0.3768760236610595, 0.9373740256282702], 
             257 -> RGBColor[
              0.9694202648664492, 0.9767142641238943, 0.9366476944955487], 
             135 -> RGBColor[
              0.335355251737071, 0.46488959643477135`, 0.9425895179910487], 
             265 -> RGBColor[
              0.19899652547638796`, 0.32648834375709396`, 0.934643929785678], 
             111 -> RGBColor[
              0.8266120846200963, 0.20555772064570646`, 0.17311706832724205`],
              381 -> RGBColor[
              0.1893487791980019, 0.3163479507160659, 0.9340945049076855], 
             182 -> RGBColor[
              0.24182762690147153`, 0.3715065470035356, 0.9370830976489003], 
             188 -> RGBColor[
              0.27580922111776024`, 0.4072233570823697, 0.9390182991682543], 
             154 -> RGBColor[
              0.18637271886218407`, 0.3132199226099977, 0.9339250226742475], 
             336 -> RGBColor[
              0.23480104226620413`, 0.36412116104067216`, 0.9366829440488222],
              315 -> RGBColor[
              0.1811098371299533, 0.3076883002234485, 0.9336253093453327], 
             368 -> RGBColor[
              0.1838330998850932, 0.3105506220439319, 0.9337803951305317], 
             269 -> RGBColor[
              0.3534033382914345, 0.480521941884955, 0.9437395261069965], 208 -> 
             RGBColor[
              0.2944180010032382, 0.4267823646067975, 0.9400780416535094], 86 -> 
             RGBColor[
              0.2680992625939086, 0.39911970183419715`, 0.9385792284361825], 
             119 -> RGBColor[
              0.2397898236287226, 0.36936468655968646`, 0.936967047767177], 
             377 -> RGBColor[
              0.25469411239970985`, 0.38503003904448196`, 0.9378158249637654],
              140 -> RGBColor[
              0.4063466574019441, 0.5263787838898877, 0.9471130275847793], 85 -> 
             RGBColor[
              0.1818888062976524, 0.30850704620819813`, 0.9336696704870515], 
             351 -> RGBColor[
              0.3095548228305918, 0.44254256168324113`, 0.9409455374755513], 
             242 -> RGBColor[
              0.3403985574835718, 0.4692578543884732, 0.9429108729735957], 
             117 -> 
             RGBColor[
              0.5585316039927765, 0.6524801435401812, 0.9583888003164419], 47 -> 
             RGBColor[
              0.18100426741029385`, 0.3075773397545796, 0.9336192973059745], 
             81 -> RGBColor[
              0.22915597848204, 0.35818784108579943`, 0.9363614660174375], 
             275 -> RGBColor[
              0.194144227344503, 0.3213882707670121, 0.934367598585399], 23 -> 
             RGBColor[
              0.2119196850624197, 0.340071403857656, 0.9353798846060012], 328 -> 
             RGBColor[
              0.2313516506730186, 0.3604956317721754, 0.9364865063005079], 
             110 -> RGBColor[
              0.8529626688242167, 0.8855932953383124, 0.985837534872859], 6 -> 
             RGBColor[
              0.9261633007621113, 0.943961492267368, 0.992819476494071], 218 -> 
             RGBColor[
              0.5602763464580424, 0.6538966040732364, 0.9585261528345099], 
             108 -> RGBColor[
              0.3063635945960659, 0.4393379408672382, 0.9407583255366989], 
             297 -> RGBColor[
              0.2965600408339725, 0.42903378428206873`, 0.9402000276530058], 
             157 -> RGBColor[
              0.24686136029389427`, 0.3767973199561026, 0.9373697613188575], 
             354 -> RGBColor[
              0.19610120868731518`, 0.3234451822380914, 0.9344790457777777], 
             385 -> RGBColor[
              0.9944175835604394, 0.9904681006416884, 0.633766605113725], 270 -> 
             RGBColor[
              0.20794500379241626`, 0.3358937618335345, 0.9351535323876885], 
             392 -> RGBColor[
              0.2030621295519029, 0.3307615514146469, 0.9348754599232564], 33 -> 
             RGBColor[
              0.24658940627570813`, 0.37651147904010834`, 0.9373542739398417],
              252 -> RGBColor[
              0.20594129701488287`, 0.33378773896799957`, 0.9350394242509266],
              394 -> RGBColor[
              0.35762511408731845`, 0.48417863188672844`, 0.9440085339275405],
              260 -> RGBColor[
              0.1889310324973132, 0.31590887244697147`, 0.9340707148510822], 
             159 -> RGBColor[
              0.18214142158537838`, 0.30877256089233246`, 0.9336840565539767],
              183 -> RGBColor[
              0.18868393066647376`, 0.3156491527555983, 0.9340566427673703], 
             99 -> RGBColor[
              0.9021660914511284, 0.9248267689496842, 0.9905306012474278], 
             329 -> RGBColor[
              0.2623389378177228, 0.3930652352687406, 0.9382511864618155], 
             309 -> 
             RGBColor[
              0.6973666945960665, 0.7635074290924103, 0.9704706529212034], 17 -> 
             RGBColor[
              0.8276616884309496, 0.21362543547524793`, 0.17412217012187317`],
              349 -> RGBColor[
              0.19841472542917707`, 0.32587683501922177`, 0.9346107971336854],
              347 -> RGBColor[
              0.18432439621433888`, 0.3110670056359555, 0.9338083737296745], 
             340 -> RGBColor[
              0.27139200070452485`, 0.4025805783601091, 0.9387667450004126], 
             277 -> RGBColor[
              0.1851145385676597, 0.3118974953472144, 0.9338533711677852], 
             104 -> RGBColor[
              0.22404918964109946`, 0.35282028222485723`, 0.936070641947763], 
             79 -> RGBColor[
              0.199051197909799, 0.3265458079510415, 0.9346470432998802], 327 -> 
             RGBColor[
              0.18576331458524015`, 0.3125794000764668, 0.9338903180022083], 
             191 -> RGBColor[
              0.1840091371887301, 0.310735648411464, 0.9337904201945499], 50 -> 
             RGBColor[
              0.23112771995435683`, 0.3602602663888343, 0.9364737537773559], 
             225 -> RGBColor[
              0.2084820527788493, 0.336458234369148, 0.9351841165329731], 61 -> 
             RGBColor[
              0.21726621743653565`, 0.3456909483725835, 0.9356843617152213], 
             196 -> RGBColor[
              0.844124603334554, 0.8785460618197521, 0.9849945522966208], 1 -> 
             RGBColor[
              0.1818132732838514, 0.3084276562216236, 0.9336653689936567], 
             263 -> RGBColor[
              0.30183205672017543`, 0.43457500724358145`, 0.9405002611584765],
              201 -> RGBColor[
              0.6657140642559093, 0.738780153701779, 0.9673158145395446], 371 -> 
             RGBColor[
              0.18003320207443918`, 0.306556688517498, 0.93356399657166], 293 -> 
             RGBColor[
              0.3141297509318431, 0.44650513446197276`, 0.941237047848713], 
             362 -> RGBColor[
              0.7912709059084366, 0.8368661126680731, 0.979830147120073], 184 -> 
             RGBColor[
              0.21355297767290998`, 0.3417880979480139, 0.9354728982039288], 
             106 -> RGBColor[
              0.1865190623784995, 0.31337373892436005`, 0.9339333567210057], 
             206 -> RGBColor[
              0.4288884024290853, 0.5459033104513494, 0.9485493676450263], 
             358 -> RGBColor[
              0.2775970966062373, 0.4091025275786123, 0.9391201160323983], 
             247 -> 
             RGBColor[
              0.8173387448883187, 0.1342787678638822, 0.16423690772735258`], 
             220 -> RGBColor[
              0.17970434930417156`, 0.30621104340547683`, 0.9335452688928874],
              107 -> RGBColor[
              0.2230811340648649, 0.3518027944359661, 0.9360155126148064], 
             375 -> RGBColor[
              0.20279567675606608`, 0.3304814926321394, 0.9348602858307151], 
             131 -> RGBColor[
              0.8141109072907318, 0.8547088953383618, 0.982106625005912], 127 -> 
             RGBColor[
              0.3393687513351076, 0.46836588806223545`, 0.9428452546364373], 
             210 -> RGBColor[
              0.2456807114445148, 0.37555638315794415`, 0.9373025251134988], 
             357 -> RGBColor[
              0.18600360463112436`, 0.31283196014996, 0.9339040021648441], 
             181 -> RGBColor[
              0.19212227783830665`, 0.31926307363699663`, 0.9342524515522274],
              194 -> RGBColor[
              0.4554399226734993, 0.5687856724178738, 0.9502730455257168], 
             118 -> RGBColor[
              0.3574473894517768, 0.48402469574012214`, 0.9439972094709195], 
             348 -> RGBColor[
              0.20110409825488346`, 0.3287035363751249, 0.9347639529375389], 
             276 -> RGBColor[
              0.37904525788294496`, 0.5027316838347692, 0.9453734065491083], 
             305 -> RGBColor[
              0.29805944165302733`, 0.4306097496103981, 0.9402854163114862], 
             343 -> RGBColor[
              0.20071986914810575`, 0.3282996872223691, 0.9347420716583239], 
             280 -> RGBColor[
              0.2089289786028837, 0.3369279817469421, 0.9352095682974844], 
             189 -> RGBColor[
              0.2331737072204319, 0.36241072872856434`, 0.9365902697253919], 
             168 -> RGBColor[
              0.19796437105250972`, 0.32540348401522773`, 0.9345851501181738],
              363 -> RGBColor[
              0.3745258073527012, 0.4988171629396605, 0.9450854311577144], 41 -> 
             RGBColor[
              0.19479503600678127`, 0.322072311934719, 0.9344046611759306], 
             14 -> RGBColor[
              0.3386493168091526, 0.46774275003568394`, 0.9427994129046144], 
             77 -> RGBColor[
              0.1969521059625652, 0.3243395292243824, 0.9345275031188135], 51 -> 
             RGBColor[
              0.20120879960667537`, 0.3288135841343073, 0.9347699155246316], 
             179 -> RGBColor[
              0.2268131918331927, 0.35572542377660804`, 0.9362280477836279], 
             223 -> 
             RGBColor[
              0.8592163258347785, 0.4536160411257659, 0.20423899016395516`], 
             323 -> RGBColor[
              0.42062186552277797`, 0.5387432516713317, 0.9480226312231679], 
             292 -> RGBColor[
              0.8194918846006688, 0.15082874320484374`, 0.1662987567475226], 
             396 -> RGBColor[
              0.18439801323969868`, 0.31114438179719767`, 0.9338125661103621],
              321 -> RGBColor[
              0.18455342051778426`, 0.3113077246998561, 0.9338214163249446], 
             143 -> RGBColor[
              0.19890345919190142`, 0.32639052519135536`, 0.9346386297984558],
              112 -> RGBColor[
              0.1804406002012431, 0.3069848897793021, 0.93358719729229], 197 -> 
             RGBColor[
              0.19131157595015044`, 0.3184109745510759, 0.9342062832790229], 
             54 -> RGBColor[
              0.9482538006021336, 0.8325505933258706, 0.2772219972063093], 71 -> 
             RGBColor[
              0.9697038754518477, 0.9769257804341147, 0.9361676157519565], 
             177 -> RGBColor[
              0.18139651046953492`, 0.3079896120794884, 0.9336416349679267], 
             158 -> RGBColor[
              0.1911403477299942, 0.3182310028351955, 0.9341965320851944], 
             226 -> RGBColor[
              0.19190461331519068`, 0.3190342944224739, 0.9342400558796418], 
             350 -> RGBColor[
              0.3485452682138572, 0.4763141257574593, 0.943429974177476], 203 -> 
             RGBColor[
              0.3100095560527289, 0.44293642874469996`, 0.9409745126743612], 
             115 -> RGBColor[
              0.9551078718556497, 0.8597247018622127, 0.2827369438226184], 
             173 -> RGBColor[
              0.17959143492855675`, 0.30609236323752076`, 0.933538838586238], 
             212 -> RGBColor[
              0.5777795176543054, 0.6681064669592394, 0.9599040665873084], 
             129 -> RGBColor[
              0.8193361618613183, 0.1496317899920564, 0.1661496364764569], 
             279 -> RGBColor[
              0.1990369147875074, 0.3265307954839108, 0.9346462298971957], 26 -> 
             RGBColor[
              0.1822568035379685, 0.30889383464014303`, 0.9336906273854845], 
             40 -> RGBColor[
              0.1934487547814754, 0.32065728500776275`, 0.934327992451794], 
             146 -> RGBColor[
              0.1991293041825628, 0.32662790259593993`, 0.9346514913365662], 
             386 -> RGBColor[
              0.3419268933615933, 0.4705816221096207, 0.9430082571842888], 
             192 -> 
             RGBColor[
              0.2582664433427927, 0.3887847853645258, 0.938019263926184], 300 -> 
             RGBColor[
              0.19616100168040002`, 0.3235080284649182, 0.934482450900278], 
             221 -> RGBColor[
              0.36991176607450643`, 0.49482071229294583`, 0.9447914285275043],
              62 -> RGBColor[
              0.9918038536315829, 0.990878697092375, 0.7854948864789351], 286 -> 
             RGBColor[
              0.3212434064694567, 0.45266662534593033`, 0.9416903236892111], 
             152 -> RGBColor[
              0.2008438754397465, 0.3284300256973365, 0.9347491336331819], 64 -> 
             RGBColor[
              0.9925852496598342, 0.986548923705669, 0.43432836788688456`], 
             307 -> RGBColor[
              0.17902996710188124`, 0.3055022249525685, 0.933506863824126], 
             37 -> RGBColor[
              0.2843315036737978, 0.41618081639268795`, 0.9395036305522334], 
             148 -> RGBColor[
              0.25655300447979307`, 0.38698385248121464`, 0.9379216861177417],
              261 -> RGBColor[
              0.18920356017618423`, 0.31619531631671777`, 0.9340862348992254],
              387 -> RGBColor[
              0.18554205504628538`, 0.3123468422723603, 0.933877717598789], 
             15 -> RGBColor[
              0.18212992963139682`, 0.3087604821200659, 0.9336834021041983], 
             136 -> RGBColor[
              0.18263620644148504`, 0.30929261114727236`, 0.9337122338195634],
              198 -> RGBColor[
              0.8287975688378628, 0.8663247005533589, 0.9835326460637211], 63 -> 
             RGBColor[
              0.18932442036239164`, 0.31632234803540016`, 0.9340931177080333],
              310 -> RGBColor[
              0.8265166883216026, 0.20482446289255998`, 0.17302571672406986`],
              171 -> RGBColor[
              0.18805335571358273`, 0.3149863784993486, 0.9340207324566552], 
             395 -> RGBColor[
              0.4386808762090538, 0.554385059055515, 0.9491733354151413], 311 -> 
             RGBColor[
              0.2025961788233211, 0.3302718076559249, 0.934848924718576], 353 -> 
             RGBColor[
              0.9932598001133134, 0.9879917189181485, 0.507749021905247], 59 -> 
             RGBColor[
              0.21627237251575757`, 0.34464635434743823`, 0.9356277637172448],
              397 -> RGBColor[
              0.36417957475425095`, 0.48985577627965343`, 0.9444261783653554],
              229 -> RGBColor[
              0.19792175174780763`, 0.3253586884237658, 0.9345827230118207], 
             102 -> 
             RGBColor[
              0.34903475823839447`, 0.4767380974142295, 0.9434611640490004], 
             299 -> RGBColor[
              0.18838969891108812`, 0.3153398965253172, 0.9340398867041779], 
             128 -> RGBColor[
              0.3039019362504366, 0.4367505818678281, 0.9406181377356125], 12 -> 
             RGBColor[
              0.242785484860208, 0.37251331644986996`, 0.9371376462426264], 
             222 -> RGBColor[
              0.9510874915293103, 0.9630417117862173, 0.9676802978022608], 92 -> 
             RGBColor[
              0.20437042968316516`, 0.3321366578036229, 0.9349499656802752], 
             271 -> RGBColor[
              0.8200027527924696, 0.15475549999089333`, 0.1667879647049341], 
             361 -> RGBColor[
              0.40957405763887067`, 0.529174195761261, 0.9473186746739982], 
             344 -> RGBColor[
              0.1915625031716876, 0.3186747149706162, 0.9342205732130758], 
             132 -> RGBColor[
              0.19287402797566439`, 0.32005321069507126`, 0.9342952626104353],
              80 -> RGBColor[
              0.20310658273494972`, 0.3308082745285237, 0.9348779914662683], 
             324 -> RGBColor[
              0.1856877903127057, 0.31250001927751764`, 0.9338860170066157], 
             244 -> RGBColor[
              0.18235944175044905`, 0.3090017139090986, 0.9336964724798456], 
             150 -> RGBColor[
              0.23840666361665402`, 0.3679108976895925, 0.9368882788506916], 
             125 -> RGBColor[
              0.1925981967986741, 0.3197632946393477, 0.9342795544329613], 
             258 -> RGBColor[
              0.23765262088408304`, 0.3671183509685898, 0.9368453372325779], 
             133 -> RGBColor[
              0.18340497994045135`, 0.3101006408377411, 0.933756014333031], 
             255 -> RGBColor[
              0.37418878878290995`, 0.4985252543935531, 0.9450639566324611], 
             326 -> RGBColor[
              0.24157157412247404`, 0.37123741929812537`, 0.9370685158219325],
              176 -> RGBColor[
              0.18620451936940718`, 0.3130431342786254, 0.9339154439619627], 
             230 -> RGBColor[
              0.2211253737681676, 0.3497471663617724, 0.9359041349591976], 
             274 -> RGBColor[
              0.20313982636998706`, 0.33084321569671615`, 0.9348798846421041],
              87 -> RGBColor[
              0.18684859723136407`, 0.31372010094843716`, 0.9339521232433733],
              130 -> RGBColor[
              0.21566341381177923`, 0.3440063001393452, 0.9355930844199268], 
             35 -> 
             RGBColor[
              0.19009976398754364`, 0.3171372833450601, 0.9341372723804675], 
             379 -> RGBColor[
              0.18246816409549027`, 0.30911598798713175`, 0.9337026640565553],
              31 -> RGBColor[
              0.9842583887354778, 0.9877584534482328, 0.9105427668445933], 18 -> 
             RGBColor[
              0.9925358512363838, 0.9864432654728553, 0.42895165434603927`], 
             24 -> RGBColor[
              0.2601817623901309, 0.39079790712151985`, 0.9381283385124692], 
             151 -> RGBColor[
              0.20761230953904478`, 0.335544079079207, 0.935134585942136], 
             137 -> RGBColor[
              0.29264465833089975`, 0.42491846902175034`, 0.9399770524117451],
              330 -> RGBColor[
              0.18870039039885345`, 0.3156664529779366, 0.9340575801247794], 
             296 -> RGBColor[
              0.17907641669607907`, 0.3055510464211448, 0.9335095090597996], 
             266 -> RGBColor[
              0.6582217134144572, 0.7329270722804612, 0.9665690470276681], 
             302 -> RGBColor[
              0.19470143524485908`, 0.32197393159930776`, 0.9343993307510091],
              283 -> RGBColor[
              0.9319225428018962, 0.7678025982169813, 0.26408148383634866`], 
             388 -> RGBColor[
              0.2707814877613013, 0.40193889054802484`, 0.938731977191469], 
             284 -> RGBColor[
              0.7398648594018855, 0.7967073184367315, 0.9747064728211174], 
             318 -> RGBColor[
              0.21345649486519924`, 0.3416866883997466, 0.9354674036507632], 
             238 -> RGBColor[
              0.20088219976865415`, 0.32847030699692126`, 0.9347513161470175],
              72 -> RGBColor[
              0.46553671991296847`, 0.576982707272407, 0.9510679023901947], 
             288 -> RGBColor[
              0.2137339467700851, 0.34197830794324846`, 0.935483204126293], 
             382 -> RGBColor[
              0.3220959675484921, 0.453405070901625, 0.9417446481272771], 389 -> 
             RGBColor[
              0.9931232770303468, 0.9876997098482838, 0.4928893268471293], 
             172 -> RGBColor[
              0.3796233347917912, 0.5032323849982215, 0.9454102410985666], 
             243 -> RGBColor[
              0.23139395253121084`, 0.36054009370722817`, 0.9364889153287519],
              88 -> RGBColor[
              0.4303958842275222, 0.5472090154169172, 0.9486454230522088], 
             273 -> RGBColor[
              0.5240458703783706, 0.6244830714274116, 0.9556739570409113], 
             202 -> 
             RGBColor[
              0.3275914997751332, 0.4581650247028605, 0.9420948185812503], 
             393 -> RGBColor[
              0.7219717591850786, 0.7827290925547635, 0.9729230558120345], 98 -> 
             RGBColor[
              0.1932487717488401, 0.3204470901608064, 0.9343166037139339], 30 -> 
             RGBColor[
              0.20069898841488326`, 0.3282777402478373, 0.9347408825314572], 
             116 -> RGBColor[
              0.24002120291967022`, 0.3696078808647668, 0.9369802244755014], 
             373 -> RGBColor[
              0.19798515205544082`, 0.3254253261669, 0.934586333565548], 240 -> 
             RGBColor[
              0.17933281357579656`, 0.305820535798229, 0.9335241104827943], 
             317 -> RGBColor[
              0.18850413369751906`, 0.3154601747414406, 0.9340464035959741], 
             391 -> RGBColor[
              0.8202342132018924, 0.1565346061243149, 0.16700961145439447`], 
             73 -> RGBColor[
              0.1985117660113969, 0.3259788308238631, 0.9346163234512842], 
             303 -> RGBColor[
              0.8939300581111314, 0.611242991794526, 0.23320497928678602`], 
             29 -> RGBColor[
              0.18584110899752487`, 0.3126611669362287, 0.9338947482789014], 
             360 -> RGBColor[
              0.6627555094400547, 0.736468908193784, 0.9670209334447669], 320 -> 
             RGBColor[
              0.18370800885926494`, 0.3104191434445573, 0.9337732713816664], 
             75 -> RGBColor[
              0.18190969424137163`, 0.30852900076141915`, 0.9336708600245455],
              200 -> RGBColor[
              0.19404714705117995`, 0.3212862332234835, 0.9343620700063117], 
             301 -> RGBColor[
              0.24986810421890843`, 0.3799575984598681, 0.937540990937308], 
             156 -> RGBColor[
              0.20187169700218524`, 0.3295103313271106, 0.9348076665506371], 
             25 -> RGBColor[
              0.3639618362230004, 0.489667182107741, 0.9444123042586827], 38 -> 
             RGBColor[
              0.2587257572717294, 0.3892675534260234, 0.9380454211749428], 
             365 -> RGBColor[
              0.30601698137869693`, 0.43897362839923615`, 0.940738586426738], 
             380 -> RGBColor[
              0.7203821791624184, 0.7814873005598058, 0.9727646213308456], 
             370 -> RGBColor[
              0.18554668841356567`, 0.31235171223514435`, 0.9338779814622011],
              3 -> RGBColor[
              0.23621542372166607`, 0.36560776562732644`, 0.9367634909803209],
              57 -> 
             RGBColor[
              0.3482989604247025, 0.47610078633028297`, 0.9434142796629524], 
             227 -> RGBColor[
              0.2739918424465178, 0.40531317687043084`, 0.9389148021414978], 
             39 -> RGBColor[
              0.19817415326039348`, 0.32562397841667373`, 0.9345970969045678],
              109 -> RGBColor[
              0.1827503081177702, 0.3094125392435122, 0.9337187317412295], 
             256 -> RGBColor[
              0.9923039511135691, 0.9910855002530954, 0.777206976991627], 339 -> 
             RGBColor[
              0.38195753878243316`, 0.5052541551744117, 0.9455589745127948], 
             287 -> RGBColor[0.817319, 0.134127, 0.164218], 239 -> 
             RGBColor[
              0.5071373117219987, 0.6107559417882819, 0.9543428533653905], 
             285 -> RGBColor[
              0.18427610046840573`, 0.31101624374485265`, 0.9338056233583907],
              345 -> RGBColor[
              0.8280837295399454, 0.865755504473851, 0.9834645594342339], 366 -> 
             RGBColor[
              0.9933000584574108, 0.9880778274454297, 0.5121308942145434], 
             216 -> RGBColor[
              0.21581639795358076`, 0.3441670961721334, 0.9356017966404827], 
             21 -> RGBColor[
              0.19666790482252822`, 0.3240408158068105, 0.9345113182843263], 
             355 -> RGBColor[
              0.2081404760074813, 0.3360992155252221, 0.9351646642411613], 
             175 -> RGBColor[
              0.19013667027984396`, 0.3171760741982618, 0.9341393741392161], 
             7 -> RGBColor[
              0.25494849258932906`, 0.3852974087524073, 0.9378303115392425], 
             13 -> RGBColor[
              0.21336291477373137`, 0.3415883297902934, 0.9354620744029933], 
             294 -> RGBColor[
              0.20973292712492791`, 0.3377729826168909, 0.9352553519764795], 
             193 -> RGBColor[
              0.8379281346647119, 0.8736051659010814, 0.9844035275832383], 60 -> 
             RGBColor[
              0.7070237961498369, 0.7710516302229059, 0.9714331825533382], 65 -> 
             RGBColor[
              0.3764941167365503, 0.5005220135978444, 0.9452108500911456], 69 -> 
             RGBColor[
              0.5728179374316162, 0.6640784326178184, 0.9595134728173111], 
             217 -> RGBColor[
              0.2082469591636211, 0.3362111360737471, 0.9351707282993756], 
             214 -> RGBColor[
              0.8789213821202363, 0.5430920994852084, 0.22068137214366979`], 
             170 -> RGBColor[
              0.23550398192177388`, 0.3648599951876243, 0.9367229754223009], 
             359 -> RGBColor[
              0.32568965645452963`, 0.4565177436079784, 0.9419736348065956], 
             74 -> RGBColor[
              0.24853385159996577`, 0.37855521436085726`, 0.9374650072245091],
              246 -> RGBColor[
              0.2167015948028579, 0.34509749418544555`, 0.9356522072915177], 
             264 -> RGBColor[
              0.2599789274537134, 0.39058471474286727`, 0.9381167873629076], 
             278 -> RGBColor[
              0.1880939032775767, 0.3150289965599703, 0.9340230415804399], 45 -> 
             RGBColor[
              0.23972125787035842`, 0.36929261960032556`, 0.9369631430486721],
              306 -> RGBColor[
              0.22229995450050422`, 0.350981725184178, 0.9359710255942676], 
             237 -> RGBColor[
              0.18222514168352894`, 0.3088605560236495, 0.9336888242897137], 
             228 -> RGBColor[
              0.22400797509009437`, 0.3527769631185974, 0.9360682948400547], 
             180 -> RGBColor[
              0.18842432755960442`, 0.31537629343049095`, 0.9340418587544824],
              383 -> RGBColor[
              0.3583175561905998, 0.4847783904334387, 0.944052655726059], 53 -> 
             RGBColor[
              0.40260480881009003`, 0.5231377827104023, 0.9468746003012931], 
             304 -> RGBColor[
              0.2822705085644714, 0.4140145798581486, 0.9393862599297264], 48 -> 
             RGBColor[
              0.20793893985757575`, 0.3358873882535414, 0.9351531870555702], 
             5 -> RGBColor[
              0.18681770269069906`, 0.3136876288273712, 0.9339503638449868], 
             101 -> RGBColor[
              0.8539737461394735, 0.41587144104017043`, 0.19931862629877445`],
              333 -> RGBColor[
              0.9537765326908467, 0.9650471942815904, 0.9631284525300384], 
             267 -> RGBColor[
              0.19756403157199334`, 0.32498270183821587`, 0.9345623513770076],
              120 -> RGBColor[
              0.41254771032069193`, 0.531749824254125, 0.9475081531933861], 
             147 -> RGBColor[
              0.24721508689536167`, 0.3771691090418067, 0.9373899055255195], 
             89 -> RGBColor[
              0.23222586891438338`, 0.3614144905724877, 0.9365362917360636], 
             43 -> RGBColor[
              0.194697223000598, 0.3219695042635176, 0.9343990908699299], 199 -> 
             RGBColor[
              0.9887357523774989, 0.9896099583772056, 0.8363412642506296], 
             268 -> 
             RGBColor[
              0.187660141527025, 0.31457308545805707`, 0.933998339490439], 
             169 -> RGBColor[
              0.45725872125089195`, 0.5702622550389433, 0.9504162280122078], 
             20 -> RGBColor[
              0.3846257063952153, 0.5075651878546001, 0.9457289877937134], 4 -> 
             RGBColor[
              0.2008450066857079, 0.32843121470856707`, 0.9347491980559659], 
             167 -> RGBColor[
              0.2358064817309028, 0.3651779416666145, 0.9367402023389224], 
             142 -> RGBColor[
              0.4741596199861951, 0.5839831660090739, 0.9517467286706829], 16 -> 
             RGBColor[
              0.22895368331262583`, 0.3579752160364906, 0.9363499456068083], 
             281 -> RGBColor[
              0.39875120665503094`, 0.5197999862113661, 0.9466290521795794], 
             289 -> RGBColor[
              0.4742143938317012, 0.5840276338843894, 0.9517510406684443], 
             398 -> RGBColor[
              0.1808071689883251, 0.3073701768163288, 0.9336080728424244], 
             178 -> RGBColor[
              0.18300767959384703`, 0.309683052983163, 0.9337333886660452], 
             58 -> RGBColor[
              0.19320352841391442`, 0.32039953654720643`, 0.9343140271729413],
              186 -> RGBColor[
              0.2065811071166083, 0.33446021995121644`, 0.9350758604897056], 
             122 -> RGBColor[
              0.18936604401309215`, 0.31636609713137825`, 0.934095488113364], 
             249 -> RGBColor[
              0.18362197162651986`, 0.31032871285786656`, 0.9337683716885422],
              113 -> RGBColor[
              0.1856485479005117, 0.3124587730141891, 0.9338837822092951], 52 -> 
             RGBColor[
              0.9889946602077696, 0.9897170234186503, 0.8320504914710569], 
             187 -> RGBColor[
              0.21634716160662554`, 0.34472496242384276`, 0.9356320228453292],
              259 -> RGBColor[
              0.8954246210317355, 0.9194513034296, 0.9898875937806444], 42 -> 
             RGBColor[
              0.183885630512114, 0.31060583506356493`, 0.9337833866720284], 
             134 -> RGBColor[
              0.17911500115561352`, 0.3055916011345115, 0.9335117063876894], 
             313 -> RGBColor[
              0.28461757525764775`, 0.41648149576530025`, 0.9395199219057286],
              248 -> RGBColor[
              0.1829127869860106, 0.3095833148357881, 0.9337279846724099], 
             174 -> RGBColor[
              0.41783566912403936`, 0.5363299883890472, 0.947845097252377], 
             215 -> 
             RGBColor[
              0.7060709713767632, 0.7703072762684443, 0.9713382138846121], 
             399 -> RGBColor[
              0.3593758114062829, 0.48569499791180964`, 0.944120086812624], 
             83 -> RGBColor[
              0.9509849302078126, 0.9629652217205732, 0.9678539073672795], 95 -> 
             RGBColor[
              0.24723118250472642`, 0.37718602654776967`, 0.9373908221466615],
              166 -> RGBColor[
              0.2451744333338886, 0.3750242527637898, 0.93727369332407], 384 -> 
             RGBColor[
              0.9335847383251342, 0.7743926495727972, 0.2654189253710895], 
             233 -> RGBColor[
              0.9703310152107799, 0.9773935002394792, 0.9351060317243296], 
             295 -> RGBColor[
              0.18590102371033476`, 0.3127241410982041, 0.9338981603331601], 
             141 -> RGBColor[
              0.3557668224000087, 0.48256907302763663`, 0.9438901252244479], 
             319 -> RGBColor[
              0.8324443832728455, 0.2503873238203034, 0.17870208410375396`], 
             205 -> RGBColor[
              0.18515378626434187`, 0.3119387471648751, 0.9338556062660495], 
             224 -> RGBColor[
              0.4977475489543879, 0.6031329093695432, 0.9536036568444898], 
             231 -> RGBColor[
              0.19120668731506069`, 0.31830072994527303`, 0.9342003100264233],
              332 -> RGBColor[
              0.8178049183525352, 0.13786198138836525`, 0.164683315963154], 
             68 -> RGBColor[
              0.8216043579673015, 0.8605890294596807, 0.9828465511894319], 10 -> 
             RGBColor[
              0.8429670986480872, 0.3312695252776902, 0.18877864823079255`], 
             250 -> RGBColor[
              0.19372013073248498`, 0.3209425183385029, 0.9343434469107393], 
             282 -> RGBColor[
              0.31502354175322494`, 0.44727929114822085`, 0.9412939994095033],
              374 -> RGBColor[
              0.1836365577609456, 0.3103440438099624, 0.9337692023473195], 
             232 -> RGBColor[
              0.19035994618760685`, 0.3174107513338308, 0.934152089371856], 
             253 -> RGBColor[
              0.8251923969012658, 0.19464537872765014`, 0.17175757376438203`],
              55 -> RGBColor[
              0.8037373305687819, 0.8466049783610714, 0.9810726838248541], 
             325 -> RGBColor[
              0.23827199083861747`, 0.36776934806112876`, 0.9368806094352129],
              91 -> RGBColor[
              0.5925759149291727, 0.6801188488370776, 0.961068893181775], 105 -> 
             RGBColor[
              0.9853022906708313, 0.9881901337255575, 0.8932426102441758], 36 -> 
             RGBColor[
              0.24565388341041777`, 0.3755281851931126, 0.9373009972966455], 
             123 -> RGBColor[
              0.843157812611701, 0.33273543637341757`, 0.18896127613772973`], 
             94 -> RGBColor[
              0.1791057270796212, 0.3055818534926332, 0.9335111782427814], 
             312 -> RGBColor[
              0.5478165382686445, 0.6437811704771209, 0.9575452710920592], 96 -> 
             RGBColor[
              0.21162927735784165`, 0.3397661669472325, 0.9353633463168451], 
             2 -> RGBColor[
              0.20182540810126717`, 0.3294616787573599, 0.9348050304662081], 
             262 -> RGBColor[
              0.36433321534571095`, 0.4899888520377754, 0.9444359682079841], 
             272 -> RGBColor[
              0.19665135271400355`, 0.3240234184912868, 0.9345103756662324], 
             97 -> RGBColor[
              0.2986247548964671, 0.43120392967218313`, 0.9403176100643942], 
             372 -> RGBColor[
              0.179946795179367, 0.3064658693922636, 0.9335590758268132], 356 -> 
             RGBColor[
              0.9453835605713274, 0.9587877294170835, 0.9773355650906732], 
             346 -> RGBColor[
              0.20342618893072584`, 0.3311442009044876, 0.9348961925663027], 
             341 -> RGBColor[
              0.24934350578881678`, 0.3794062122483802, 0.9375111158327881], 
             209 -> RGBColor[
              0.2650455441851616, 0.3959100501696741, 0.9384053236903759], 
             378 -> RGBColor[
              0.24023703411797065`, 0.3698347331386689, 0.9369925157429511], 
             66 -> RGBColor[
              0.19612721011213427`, 0.3234725113841618, 0.9344805265204555], 
             139 -> RGBColor[
              0.30694355404168716`, 0.4399475150161388, 0.940791353369154], 
             56 -> RGBColor[
              0.5183980864407423, 0.6198979459970778, 0.9552293428008269], 
             335 -> RGBColor[
              0.1982643030525542, 0.3257187315640616, 0.9346022308018668], 
             314 -> RGBColor[
              0.18275376889499648`, 0.30941617673980293`, 0.9337189288273728],
              144 -> RGBColor[
              0.5812572311839399, 0.6709298314718057, 0.9601778449356456], 
             298 -> RGBColor[
              0.20546571259734456`, 0.33328786959137313`, 0.9350123404219118],
              204 -> RGBColor[
              0.17994083687002446`, 0.30645960683136597`, 0.9335587365099107],
              207 -> 
             RGBColor[
              0.1915172466480543, 0.31862714749484833`, 0.934217995921006], 
             334 -> RGBColor[
              0.9602115875305376, 0.8774464833562946, 0.2999299602777051], 
             149 -> RGBColor[
              0.21032620428650672`, 0.3383965545296549, 0.9352891382331565], 
             219 -> RGBColor[0.178927, 0.305394, 0.933501], 400 -> 
             RGBColor[
              0.8221152183090297, 0.17099283563946593`, 0.16881086406928056`],
              9 -> RGBColor[
              0.6863588655876156, 0.7549080294084094, 0.9693734953996518], 11 -> 
             RGBColor[
              0.873192830390407, 0.9017242770380856, 0.9877671057427206], 44 -> 
             RGBColor[
              0.22831342724773274`, 0.3573022663177088, 0.9363134839710866], 
             153 -> RGBColor[
              0.20565135384863537`, 0.33348299031681494`, 0.9350229124165412],
              32 -> RGBColor[
              0.8215188663850046, 0.16640901342833042`, 0.16823979679335105`],
              162 -> RGBColor[
              0.19529691214488243`, 0.32259981557664835`, 0.9344332422795363],
              90 -> RGBColor[
              0.21556902434658207`, 0.3439070908267852, 0.9355877090795206], 
             331 -> RGBColor[
              0.24096885499463874`, 0.3706039232801706, 0.9370341918592453], 
             8 -> RGBColor[
              0.25559866423556843`, 0.38598078037586825`, 0.937867337852653], 
             364 -> RGBColor[
              0.92133834354613, 0.7258397751431882, 0.2555651886720716], 342 -> 
             RGBColor[
              0.18639411010760892`, 0.31324240616522253`, 0.9339262408740289],
              163 -> RGBColor[
              0.17905422337022397`, 0.30552771982853294`, 0.9335082451827241],
              49 -> RGBColor[
              0.18369802063003998`, 0.31040864518235156`, 0.9337727025667882],
              338 -> RGBColor[
              0.21013611726343454`, 0.33819676101619267`, 0.9352783130584011],
              76 -> RGBColor[
              0.2829350020755027, 0.41471300466956446`, 0.9394241018521495], 
             369 -> RGBColor[
              0.1804054273287139, 0.30694792086018496`, 0.933585194249233], 
             82 -> RGBColor[
              0.7597586089991939, 0.8122484668202457, 0.9766892958633172], 67 -> 
             RGBColor[
              0.17940647345367122`, 0.30589795700018124`, 0.9335283053038692],
              211 -> RGBColor[
              0.23248905082520588`, 0.3616911114474591, 
               0.9365512795565422]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9mGk41G3YxiVbGGbGGGMMZp+JsVWihTktLbQQJSTFQyShTSoPqYhQlpJK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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 5}], {
             RGBColor[
             0.18431548798727523`, 0.3110576425244974, 0.9338078664193217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.18382719114068813`, 0.31054441157892615`, 0.933780058636279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 73}], {
             RGBColor[
             0.19016251964762415`, 0.3172032435227433, 0.9341408462224705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[
             0.18373091059218155`, 0.31044321461790636`, 0.9337745756014759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 162}], {
             RGBColor[
             0.18855509271436693`, 0.315513735899136, 0.9340493056365965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 183}], {
             RGBColor[
             0.18524860197516257`, 0.312038404488611, 0.9338610058805135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 291}], {
             RGBColor[
             0.1886369117353484, 0.31559973287781307`, 0.934053965108801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 357}], {
             RGBColor[
             0.18390843895748787`, 0.3106298081857918, 0.9337846855792504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 368}], {
             RGBColor[
             0.1828231865844723, 0.30948913913277776`, 0.9337228820620942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 387}], {
             RGBColor[
             0.1836776641650684, 0.31038724924699196`, 0.9337715432962228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 28}], {
             RGBColor[
             0.1967107027357332, 0.32408579912713337`, 0.9345137555621694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 39}], {
             RGBColor[
             0.19999978068083032`, 0.3275428285870168, 0.934701063685388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 50}], {
             RGBColor[
             0.216476564027812, 0.3448609725730971, 0.935639392121782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 106}], {
             RGBColor[
             0.19417223523988333`, 0.32141770884085996`, 0.9343691935936069]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 137}], {
             RGBColor[
             0.24723503321608348`, 0.3771900738895551, 0.9373910414389766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 138}], {
             RGBColor[
             0.24536530114030092`, 0.3752248669300471, 0.9372845629632816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 149}], {
             RGBColor[
             0.20607580619388693`, 0.3339291166435074, 0.9350470843496823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 164}], {
             RGBColor[
             0.20840908696131982`, 0.3363815426686245, 0.935179961237608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 197}], {
             RGBColor[
             0.1965684920257088, 0.3239363266542179, 0.9345056568726156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 210}], {
             RGBColor[
             0.223753059772891, 0.352509030957652, 0.9360537777898534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 217}], {
             RGBColor[
             0.20503618363244414`, 0.3328364074155535, 0.9349878793827919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 230}], {
             RGBColor[
             0.2114753909347174, 0.33960442255956613`, 0.9353545827127028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 254}], {
             RGBColor[
             0.19445154659843222`, 0.32171128278805783`, 0.9343850999622723]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 258}], {
             RGBColor[
             0.2197390144926751, 0.34829001486297484`, 0.935825183849393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 314}], {
             RGBColor[
             0.19228958849813182`, 0.3194389277485814, 0.9342619796467905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 328}], {
             RGBColor[
             0.2165885293871429, 0.3449786552647677, 0.935645768383358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 7}], {
             RGBColor[
             0.24558195815549755`, 0.37545258718986685`, 0.9372969012597816]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 13}], {
             RGBColor[
             0.2247891692476987, 0.3535980477088099, 0.9361127826916571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 14}], {
             RGBColor[
             0.28743237026540935`, 0.41667525783150516`, 0.9397814519424676]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 21}], {
             RGBColor[
             0.21644166427209716`, 0.34482429071706844`, 0.9356374046323236]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 51}], {
             RGBColor[
             0.2187121116641707, 0.34721067488081686`, 0.9357667032524762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 79}], {
             RGBColor[
             0.21763331081573253`, 0.34607678678918397`, 0.9357052671401005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 188}], {
             RGBColor[
             0.25601232241971317`, 0.38641556135484806`, 0.9378908950742876]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 232}], {
             RGBColor[
             0.21328768495463646`, 0.3415092584805786, 0.9354577901760884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 293}], {
             RGBColor[
             0.2751725873267546, 0.40605645004464963`, 0.939000269414517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 373}], {
             RGBColor[
             0.21710028788855346`, 0.3455165458971132, 0.9356749122729344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 390}], {
             RGBColor[
             0.22459916207358144`, 0.353398338121662, 0.9361019620641815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 84}], {
             RGBColor[
             0.20756604892203795`, 0.3354954562376403, 0.935131951468434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 125}], {
             RGBColor[
             0.196721601742191, 0.3240972546739574, 0.9345143762444637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 165}], {
             RGBColor[
             0.21319278532882907`, 0.3414095129568713, 0.9354523857827901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 184}], {
             RGBColor[
             0.20719899217930893`, 0.3351096563282905, 0.9351110481299474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 185}], {
             RGBColor[
             0.1966973229914563, 0.32407173616757357`, 0.9345129936055264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 190}], {
             RGBColor[
             0.20649883851719153`, 0.33437375043709894`, 0.9350711754146743]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.1963748100004493, 0.3237327545655205, 0.9344946269678038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 252}], {
             RGBColor[
             0.20339315185029538`, 0.3311094768382833, 0.9348943111534462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 274}], {
             RGBColor[
             0.2019924165278475, 0.3296372152026416, 0.934814541349035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 288}], {
             RGBColor[
             0.2072894767278965, 0.33520476132590776`, 0.9351162010911295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 318}], {
             RGBColor[
             0.20715075077545358`, 0.3350589515541568, 0.9351083008533645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.18632940584411195`, 0.31317439788179996`, 0.9339225560619441]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 113}], {
             RGBColor[
             0.18623312529560537`, 0.31307320092078017`, 0.9339170730271409]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 162}], {
             RGBColor[
             0.19105730741779076`, 0.3181437222020098, 0.9341918030622616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 183}], {
             RGBColor[
             0.1877508166785864, 0.3146683907914848, 0.9340035033061785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 270}], {
             RGBColor[
             0.19738135324155764`, 0.32479069533045285`, 0.9345519481163376]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 291}], {
             RGBColor[
             0.19113912643877223`, 0.3182297191806869, 0.9341964625344661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 357}], {
             RGBColor[
             0.1864106536609117, 0.3132597944886656, 0.9339271830049154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 368}], {
             RGBColor[
             0.18532540128789612`, 0.31211912543565157`, 0.9338653794877592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 10}], {
             RGBColor[
             0.8845651997050992, 0.6376155087725291, 0.5907990623624317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.6643840547861006, 0.7335496374888852, 0.969847038397682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 69}], {
             RGBColor[
             0.7494906190968638, 0.8040199624425932, 0.9761664746556911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 71}], {
             RGBColor[
             0.9479335881069795, 0.9604436363507414, 0.9644935461230137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 93}], {
             RGBColor[
             0.6343460318717724, 0.7075322117954237, 0.9679330421391619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 129}], {
             RGBColor[
             0.8727497313117147, 0.5467966411297123, 0.579484556485264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 131}], {
             RGBColor[
             0.8701371040264215, 0.8993351938028649, 0.9874630507499915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 142}], {
             RGBColor[
             0.7001614603741532, 0.763972329138221, 0.9722831025823769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 201}], {
             RGBColor[
             0.7959386825090102, 0.8413708229845736, 0.9800676455168078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 253}], {
             RGBColor[
             0.8756778488316885, 0.5693034354975091, 0.5822885251292265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 273}], {
             RGBColor[
             0.7251045855702409, 0.7842222818473898, 0.9742467167674911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 281}], {
             RGBColor[
             0.6624572537085711, 0.7318807392393671, 0.9697242643368251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 303}], {
             RGBColor[
             0.9100466794366213, 0.777602242030947, 0.6130122278904285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 364}], {
             RGBColor[
             0.9237508221541206, 0.8349006337052781, 0.6241923325830713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 391}], {
             RGBColor[
             0.8731987569820019, 0.5502480491958415, 0.5799145439742327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 394}], {
             RGBColor[
             0.6418942074247149, 0.7140700620770483, 0.9684140052108057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 13}], {
             RGBColor[
             0.23415570368153021`, 0.3634428692713504, 0.9366461929711178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 14}], {
             RGBColor[
             0.29679890469924086`, 0.4265200793940456, 0.9403148622219284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 21}], {
             RGBColor[
             0.22580819870592864`, 0.3546691122796089, 0.9361708149117844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 93}], {
             RGBColor[
             0.29873862778538124`, 0.4282001700379434, 0.9404384596617476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 142}], {
             RGBColor[
             0.36455405628776205`, 0.4846402873807406, 0.9447885201049626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 188}], {
             RGBColor[
             0.2653788568535447, 0.3962603829173885, 0.9384243053537484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 273}], {
             RGBColor[
             0.3894971814838498, 0.5048902400899095, 0.9467521342900769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 293}], {
             RGBColor[
             0.28453912176058604`, 0.41590127160719004`, 0.9395336796939777]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 390}], {
             RGBColor[
             0.23396569650741295`, 0.36324315968420245`, 0.9366353723436424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 16}], {
             RGBColor[
             0.24227617377409713`, 0.3719779982061794, 0.9371086417297306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 25}], {
             RGBColor[
             0.3097802502292844, 0.43782398124180466`, 0.9411398210556678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 76}], {
             RGBColor[
             0.26926683315553557`, 0.4003468925227164, 0.9386457198524012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 117}], {
             RGBColor[
             0.40706513411417244`, 0.5192304619580248, 0.9481280690845475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 202}], {
             RGBColor[
             0.2915950820053508, 0.42207290253936436`, 0.9399810782169516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 234}], {
             RGBColor[
             0.2512674523014992, 0.38142840201846384`, 0.9376206817404615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 239}], {
             RGBColor[
             0.3813679879787836, 0.49836836108207505`, 0.9461050956090218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 269}], {
             RGBColor[
             0.30450100126350144`, 0.4332513611304116, 0.9408034319798247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 302}], {
             RGBColor[
             0.22515004974021374`, 0.353977355987588, 0.936133334301831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 323}], {
             RGBColor[
             0.3381102648791732, 0.4623620160236, 0.9429449845379104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 365}], {
             RGBColor[
             0.2808078228071327, 0.4124772043875522, 0.9393029621396956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 377}], {
             RGBColor[
             0.25514638831763914`, 0.3855054097101751, 0.9378415814082092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 388}], {
             RGBColor[
             0.26319007599843486`, 0.3939598354619466, 0.938299657522061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 18}], {
             RGBColor[
             0.8394473584119997, 0.8706756474406323, 0.6991625748728455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 56}], {
             RGBColor[
             0.6023784760141789, 0.6874029877027437, 0.9623014191002394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 65}], {
             RGBColor[
             0.531426491162083, 0.6277150215031269, 0.9572921727453987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 100}], {
             RGBColor[
             0.5370355289675518, 0.6325732881317867, 0.9576495756744858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 174}], {
             RGBColor[
             0.5520972673558275, 0.6456190088987284, 0.9586092963260144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 198}], {
             RGBColor[
             0.7575782172127392, 0.8106163649808842, 0.9764530707316865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 203}], {
             RGBColor[
             0.4981842108201723, 0.5989222290765547, 0.9551740040370065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 266}], {
             RGBColor[
             0.6722902895010364, 0.7439175508444353, 0.9679712712136599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 313}], {
             RGBColor[
             0.4854882204226317, 0.5856947625868548, 0.9544467086526902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 339}], {
             RGBColor[
             0.5341582021850244, 0.6300810922914106, 0.9574662349562233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 358}], {
             RGBColor[
             0.48197798109692647`, 0.5820052784935108, 0.954246805716025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 384}], {
             RGBColor[
             0.8099718019563749, 0.7646503394906032, 0.6173962103853706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 32}], {
             RGBColor[
             0.8322429825165458, 0.24883926935301032`, 0.1785092225120718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 52}], {
             RGBColor[
             0.9159808794279284, 0.6604932743481702, 0.5104145698509248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 60}], {
             RGBColor[
             0.774995447398962, 0.551160577750298, 0.5801059153920654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 68}], {
             RGBColor[
             0.8322857283076943, 0.5959292773686855, 0.5858125997101122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.8311516302547027, 0.2404506576348733, 0.17746414235362473`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 253}], {
             RGBColor[
             0.8340797477746764, 0.2629574520026702, 0.18026811099758727`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 271}], {
             RGBColor[
             0.8314849257202783, 0.24301251263429177`, 0.17778330646786333`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 303}], {
             RGBColor[
             0.8684485783796092, 0.4712562585361081, 0.21099181375878928`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 333}], {
             RGBColor[
             0.8983718156694669, 0.6481583597796403, 0.5759535503804154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 334}], {
             RGBColor[
             0.9015893430893124, 0.6043580043169925, 0.2443543042542488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 337}], {
             RGBColor[
             0.8999731601904741, 0.6493526399014464, 0.5732428918038912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 345}], {
             RGBColor[
             0.8355254140940163, 0.5985125148757706, 0.5861216038325132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 353}], {
             RGBColor[
             0.9181134493807003, 0.6596306220979193, 0.3482638350680197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 364}], {
             RGBColor[
             0.8821527210971085, 0.5285546502104392, 0.22217191845143208`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 391}], {
             RGBColor[
             0.8316006559249898, 0.24390206570100256`, 0.1778941298425935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 54}], {
             RGBColor[
             0.9107233154962703, 0.8671374351819781, 0.6324945514745149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 83}], {
             RGBColor[
             0.9120888802991098, 0.9323447493793293, 0.977810506555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 118}], {
             RGBColor[
             0.6153201099210919, 0.6928744863891039, 0.9658821576068201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 123}], {
             RGBColor[
             0.8581753215010539, 0.6172298567057516, 0.5883641909402252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 141}], {
             RGBColor[
             0.6144798263952078, 0.6921466750328611, 0.9658286154835842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 161}], {
             RGBColor[
             0.8763695857039919, 0.7238270844566292, 0.6044849794547379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 196}], {
             RGBColor[
             0.8586587168624804, 0.8901351694289188, 0.9863808290196707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 206}], {
             RGBColor[
             0.6510406164097462, 0.7238137937447175, 0.9681582366938735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 214}], {
             RGBColor[
             0.8760571062553216, 0.722408188261647, 0.6042242389431952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 286}], {
             RGBColor[
             0.5972181184299319, 0.677195451192008, 0.9647287147159659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 332}], {
             RGBColor[
             0.8454988743714711, 0.5197931292132254, 0.5762252108529373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 366}], {
             RGBColor[
             0.9332464444239088, 0.9449010522417576, 0.749948999978632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 386}], {
             RGBColor[
             0.6075598618760001, 0.6861529495738531, 0.9653876814635047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 19}], {
             RGBColor[
             0.22114916866345258`, 0.3497721763054004, 0.9359054900432826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 24}], {
             RGBColor[
             0.25148362362516946`, 0.3816556117856949, 0.9376329923775478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 65}], {
             RGBColor[
             0.30963980079837916`, 0.4365176650238572, 0.941174248166886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 100}], {
             RGBColor[
             0.315248838603848, 0.44137593165251704`, 0.941531651095973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 107}], {
             RGBColor[
             0.23293330946253646`, 0.362158055442918, 0.9365765794287164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 124}], {
             RGBColor[
             0.23470207361547668`, 0.3640171387137828, 0.9366773079305742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 150}], {
             RGBColor[
             0.24059607423843102`, 0.37021210706973123`, 0.937012962546659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 157}], {
             RGBColor[
             0.24482342257705114`, 0.37465531820298625`, 0.937253703780742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 167}], {
             RGBColor[
             0.2392959832955554, 0.36884562905824225`, 0.9369389242907744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 168}], {
             RGBColor[
             0.22037492795635888`, 0.34895840023254887`, 0.9358613981804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 203}], {
             RGBColor[
             0.2763975204564685, 0.40772487259728496`, 0.9390560794584938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 206}], {
             RGBColor[
             0.33583694364464667`, 0.4592083134506097, 0.9428435069438263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 211}], {
             RGBColor[
             0.23763726784270695`, 0.3671022139486645, 0.9368444628995842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 238}], {
             RGBColor[
             0.2218338423144311, 0.3504918117233956, 0.9359444811948219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 341}], {
             RGBColor[
             0.2460644953245124, 0.3759597643491251, 0.9373243810377072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 358}], {
             RGBColor[
             0.26019129073322267`, 0.39080792201424114`, 0.9381288811375124]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 14}], {
             RGBColor[
             0.27600611579144196`, 0.4046655399129887, 0.9391307436538039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 21}], {
             RGBColor[
             0.2050154097981298, 0.332814572798552, 0.9349866963436598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 51}], {
             RGBColor[
             0.20728585719020337`, 0.33520095696230034`, 0.9351159949638125]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 79}], {
             RGBColor[
             0.20620705634176517`, 0.33406706887066745`, 0.9350545588514367]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 87}], {
             RGBColor[
             0.2001057560025477, 0.3276542153693653, 0.9347070988231834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 205}], {
             RGBColor[
             0.19925835051903662`, 0.3267635384775842, 0.9346588403345214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 232}], {
             RGBColor[
             0.20186143048066912`, 0.3294995405620621, 0.9348070818874247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 277}], {
             RGBColor[
             0.19923872667069553`, 0.3267429125687539, 0.9346577227853893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 373}], {
             RGBColor[
             0.2056740334145861, 0.3335068279785967, 0.9350242039842707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 390}], {
             RGBColor[
             0.2131729075996141, 0.34138862020314553`, 0.9354512537755177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 69}], {
             RGBColor[
             0.45573362712038445`, 0.5659105913267511, 0.9511564428609628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 71}], {
             RGBColor[
             0.6541765961305002, 0.7223342652348994, 0.9394835143282855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 201}], {
             RGBColor[
             0.5021816905325309, 0.6032614518687315, 0.9550576137220795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 212}], {
             RGBColor[
             0.45821441723172895`, 0.5679246084974616, 0.9513517397459614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 273}], {
             RGBColor[
             0.4313475935937616, 0.5461129107315478, 0.9492366849727629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 289}], {
             RGBColor[
             0.4064318553204269, 0.5258851919600367, 0.9472752267865294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 293}], {
             RGBColor[
             0.32638953387049785`, 0.45712394224882835`, 0.9420182303766638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 390}], {
             RGBColor[
             0.27581610861732475`, 0.40446583032584077`, 0.9391199230263283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 35}], {
             RGBColor[
             0.1861148468094702, 0.312948882732563, 0.933910337242333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 106}], {
             RGBColor[
             0.18432449600494816`, 0.311067110522213, 0.933808379412602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 154}], {
             RGBColor[
             0.18425132424679044`, 0.31099020236503183`, 0.933804212389223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 207}], {
             RGBColor[
             0.18682358813972555`, 0.3136938148074571, 0.9339506990126021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 231}], {
             RGBColor[
             0.18666830847322874`, 0.31353060603266947`, 0.9339418560653108]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 369}], {
             RGBColor[
             0.18126767848005537`, 0.30785420149012543`, 0.9336342981767156]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 372}], {
             RGBColor[
             0.1810383624053819, 0.30761317575616476`, 0.9336212389655058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 392}], {
             RGBColor[
             0.19259602959164984`, 0.3197610167673564, 0.9342794310137273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 25}], {
             RGBColor[
             0.2964577597678131, 0.4238211990721158, 0.9403811249327455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 37}], {
             RGBColor[
             0.25664259349321183`, 0.38707801621458926`, 0.9379267880795208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 76}], {
             RGBColor[
             0.2559443426940643, 0.3863441103530275, 0.937887023729479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 77}], {
             RGBColor[
             0.21295289463759554`, 0.3411573726304365, 0.9354387243628108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 78}], {
             RGBColor[
             0.22470970081672578`, 0.3535145213492678, 0.9361082570820762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 80}], {
             RGBColor[
             0.21603013302378776`, 0.34439174528250716`, 0.9356139685365383]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 96}], {
             RGBColor[
             0.22029148033523374`, 0.34887069149186156`, 0.9358566459618267]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 182}], {
             RGBColor[
             0.23539065510704868`, 0.36474088152001305`, 0.9367165216278543]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.22265042245962569`, 0.35135008923016664`, 0.9359909842260687]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 269}], {
             RGBColor[
             0.29117851080203017`, 0.41924857896072276`, 0.9400447358569024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 302}], {
             RGBColor[
             0.21182755927874247`, 0.3399745738178992, 0.9353746381789088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 323}], {
             RGBColor[
             0.3247877744177019, 0.4483592338539112, 0.9421862884149881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 365}], {
             RGBColor[
             0.2674853323456614, 0.39847442221786333`, 0.9385442660167731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 377}], {
             RGBColor[
             0.24182389785616784`, 0.37150262754048624`, 0.9370828852852868]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 388}], {
             RGBColor[
             0.24986758553696356`, 0.3799570532922577, 0.9375409613991386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 18}], {
             RGBColor[
             0.9100987698336667, 0.6000343504740516, 0.3015369122339562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 31}], {
             RGBColor[
             0.9059600385832136, 0.6006919444617403, 0.5423324684832332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 62}], {
             RGBColor[
             0.9097327710312662, 0.6022520662838114, 0.4798085283004041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.8649138899410389, 0.5692261022124661, 0.5823263856846504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 111}], {
             RGBColor[
             0.8271368865255229, 0.20959157806047718`, 0.1736196192245576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 222}], {
             RGBColor[
             0.88937458998013, 0.5883335736307327, 0.570901233962067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 223}], {
             RGBColor[
             0.843439007132864, 0.3336207383005069, 0.18918058014291417`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 247}], {
             RGBColor[
             0.8225002166596341, 0.17395210166956507`, 0.16917953892461288`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 256}], {
             RGBColor[
             0.9099828197722593, 0.6023554678641716, 0.47566457355675007`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 292}], {
             RGBColor[
             0.8235767865158092, 0.18222708934004583`, 0.17021046343469787`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 310}], {
             RGBColor[
             0.8270891883762761, 0.20922494918390394`, 0.1735739434229715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 319}], {
             RGBColor[
             0.8300530358518976, 0.23200637964777565`, 0.17641212711281357`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 384}], {
             RGBColor[
             0.8806232133780418, 0.49400904252402256`, 0.21977054774648136`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 99}], {
             RGBColor[
             0.947350971343756, 0.9556350172112698, 0.7097411277967336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 144}], {
             RGBColor[
             0.7868965412101618, 0.8286865484723305, 0.6945647496408425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.9106667100371233, 0.9263839830131071, 0.7062421502048801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 218}], {
             RGBColor[
             0.776406098847213, 0.8201699347730458, 0.6937389035902746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 266}], {
             RGBColor[
             0.8253787823254205, 0.8596851688766582, 0.6977603506868537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 310}], {
             RGBColor[
             0.9095262697789932, 0.5956338641827077, 0.30098868553505453`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 319}], {
             RGBColor[
             0.9124901172546147, 0.6184152946465793, 0.3038268692248966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 384}], {
             RGBColor[
             0.9630602947807589, 0.8804179575228263, 0.3471852898585644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 24}], {
             RGBColor[
             0.22984730742841403`, 0.35891447164122536`, 0.936400836178204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 85}], {
             RGBColor[
             0.19070082938217475`, 0.3177690411845645, 0.9341715021654952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 107}], {
             RGBColor[
             0.211296993265781, 0.33941691529844853`, 0.9353444232293726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 124}], {
             RGBColor[
             0.21306575741872125`, 0.34127599856931323`, 0.9354451517312304]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 150}], {
             RGBColor[
             0.21895975804167556`, 0.3474709669252617, 0.9357808063473152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 152}], {
             RGBColor[
             0.2001783639532218, 0.3277305309291337, 0.9347112337385604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 157}], {
             RGBColor[
             0.2231871063802957, 0.35191417805851677`, 0.9360215475813982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 160}], {
             RGBColor[
             0.19740416245689973`, 0.32481466926196517`, 0.9345532470674082]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 167}], {
             RGBColor[
             0.21765966709879997`, 0.34610448891377266`, 0.9357067680914306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 168}], {
             RGBColor[
             0.19873861175960342`, 0.3262172600880793, 0.9346292419810562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 181}], {
             RGBColor[
             0.19581756515250187`, 0.3231470548989638, 0.9344628926980831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 211}], {
             RGBColor[
             0.2160009516459515, 0.344361073804195, 0.9356123067002404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 238}], {
             RGBColor[
             0.20019752611767563`, 0.32775067157892607`, 0.9347123249954781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 64}], {
             RGBColor[
             0.6886054780275248, 0.7470570557801346, 0.690028677840299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 88}], {
             RGBColor[
             0.40751079531136875`, 0.5273871016357587, 0.9471872054229611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 89}], {
             RGBColor[
             0.30842578765479933`, 0.4344898392135439, 0.9411326397648885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 120}], {
             RGBColor[
             0.3985867083579536, 0.5196575060543626, 0.9466185704935497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 140}], {
             RGBColor[
             0.3954861818985797, 0.5169719858722439, 0.9464210076892463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 189}], {
             RGBColor[
             0.30889970680782364`, 0.4349879582915822, 0.9411596287595527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 195}], {
             RGBColor[
             0.40462199010322386`, 0.5248849637600351, 0.9470031333095683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 241}], {
             RGBColor[
             0.33276855688740864`, 0.46007563309772936`, 0.9425189244607857]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 255}], {
             RGBColor[
             0.37940724758906264`, 0.5030452211240766, 0.9453964722130872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 257}], {
             RGBColor[
             0.6770229856308323, 0.7421397259892473, 0.9411883411446311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 263}], {
             RGBColor[
             0.3432288815576954, 0.4710700975490908, 0.943114624476095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 312}], {
             RGBColor[
             0.4662211223319299, 0.5756731791658605, 0.9516371294428863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 336}], {
             RGBColor[
             0.3097133743307097, 0.43584317444763615`, 0.9412059659212678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 356}], {
             RGBColor[
             0.6650046334832713, 0.7331764586358418, 0.9615322764421933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 359}], {
             RGBColor[
             0.3551576814248725, 0.48204146573128925`, 0.9438513113001545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 360}], {
             RGBColor[
             0.523690607917635, 0.622017048024192, 0.9563749606192402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 389}], {
             RGBColor[
             0.688874491712781, 0.747632448851442, 0.7193091573204213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 109}], {
             RGBColor[
             0.1897091064701492, 0.31672667752516137`, 0.9341150250127779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[
             0.19167285067202883`, 0.3187906971899105, 0.9342268573399758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 132}], {
             RGBColor[
             0.1947709663990963, 0.3220470132509409, 0.9344032904473808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 180}], {
             RGBColor[
             0.19254611619106632`, 0.3197085546186507, 0.9342765885194044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 232}], {
             RGBColor[
             0.19351392550506752`, 0.32072578357032067`, 0.9343317038280912]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 249}], {
             RGBColor[
             0.19014493822452405`, 0.31718476433233855`, 0.9341398449864342]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 370}], {
             RGBColor[
             0.19110729661804693`, 0.31819626402097745`, 0.9341946498732637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 45}], {
             RGBColor[
             0.24087710963769857`, 0.3705074930930349, 0.9370289670968927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 74}], {
             RGBColor[
             0.24528340650250224`, 0.37513879047330073`, 0.9372798991848111]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 116}], {
             RGBColor[
             0.24102708216235447`, 0.3706651237252555, 0.9370375078103073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 141}], {
             RGBColor[
             0.2988998919025237, 0.4271457198066904, 0.9404924581847806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 179}], {
             RGBColor[
             0.2344230766191157, 0.3637238951811761, 0.9366614194643705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 209}], {
             RGBColor[
             0.25353925279510015`, 0.38381620837770913`, 0.9377500574177445]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 286}], {
             RGBColor[
             0.2816381839372477, 0.41219449596583724`, 0.9393925574171622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 290}], {
             RGBColor[
             0.2497813465899759, 0.3798664106911086, 0.9375360502186867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 304}], {
             RGBColor[
             0.2621517349847551, 0.3928684732219464, 0.9382405255374198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 338}], {
             RGBColor[
             0.2260845393342366, 0.35495956380096844`, 0.9361865521017572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 38}], {
             RGBColor[
             0.23532272116707456`, 0.36466947864183974`, 0.936712652890472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 92}], {
             RGBColor[
             0.20814505737279243`, 0.33610403083063944`, 0.9351649251431382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 98}], {
             RGBColor[
             0.2025842284056299, 0.3302592470092312, 0.9348482441599675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 119}], {
             RGBColor[
             0.22585475434557115`, 0.35471804520867123`, 0.936173466186589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 128}], {
             RGBColor[
             0.2579108106564282, 0.38841099286274205`, 0.9379990111708069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 130}], {
             RGBColor[
             0.21379154943709947`, 0.3420388519985006, 0.935486484512964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 139}], {
             RGBColor[
             0.2594316195520534, 0.3900094594368974, 0.9380856189875776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 143}], {
             RGBColor[
             0.20541157212716055`, 0.3332309645245057, 0.9350092572022285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 146}], {
             RGBColor[
             0.20552449462249126`, 0.333349653226798, 0.9350156879712836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 151}], {
             RGBColor[
             0.20976599730073225`, 0.3378077414684315, 0.9352572352740687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 158}], {
             RGBColor[
             0.20153001639620693`, 0.3291512033464258, 0.9347882083455978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 186}], {
             RGBColor[
             0.209250396089514, 0.3372658119044362, 0.9352278725478533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 213}], {
             RGBColor[
             0.2686665233533321, 0.39817491739397315`, 0.9386679570758016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 267}], {
             RGBColor[
             0.20474185831720654`, 0.33252705284793593`, 0.9349711179915043]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 306}], {
             RGBColor[
             0.21710981978146196`, 0.345526564520917, 0.9356754551001344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 308}], {
             RGBColor[
             0.21238372481471685`, 0.3405591390591399, 0.9354063109834092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 311}], {
             RGBColor[
             0.2072579319428704, 0.33517160575679045`, 0.9351144046622886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 346}], {
             RGBColor[
             0.20767293699657277`, 0.3356078023810718, 0.935138038586152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 348}], {
             RGBColor[
             0.20651189165865158`, 0.3343874701163905, 0.93507191877177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 354}], {
             RGBColor[
             0.20401044687486744`, 0.3317582930478737, 0.9349294651918895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 374}], {
             RGBColor[
             0.19777812141168266`, 0.3252077238338092, 0.9345745434766604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 33}], {
             RGBColor[
             0.2533855843329195, 0.3836546930808141, 0.9377413062261555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 56}], {
             RGBColor[
             0.3892899244154366, 0.5053479265592988, 0.9466788406566481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 65}], {
             RGBColor[
             0.3183379395633406, 0.44565996035968214`, 0.9416695943018074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 100}], {
             RGBColor[
             0.32394697736880945`, 0.450518226988342, 0.9420269972308946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 107}], {
             RGBColor[
             0.2416314482274979, 0.371300350778743, 0.9370719255636378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 124}], {
             RGBColor[
             0.24340021238043813`, 0.3731594340496077, 0.9371726540654957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 150}], {
             RGBColor[
             0.24929421300339247`, 0.3793544024055562, 0.9375083086815804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 157}], {
             RGBColor[
             0.2535215613420126, 0.38379761353881126`, 0.9377490499156633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 167}], {
             RGBColor[
             0.24799412206051685`, 0.37798792439406714`, 0.9374342704256958]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 168}], {
             RGBColor[
             0.22907306672132033`, 0.35810069556837376`, 0.9363567443153216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 203}], {
             RGBColor[
             0.2850956592214299, 0.4168671679331099, 0.9395514255934152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 206}], {
             RGBColor[
             0.3445350824096081, 0.46835060878643464`, 0.9433388530787478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 211}], {
             RGBColor[
             0.2463354066076684, 0.3762445092844895, 0.9373398090345058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 238}], {
             RGBColor[
             0.23053198107939255`, 0.35963410705922055`, 0.9364398273297434]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 341}], {
             RGBColor[
             0.25476263408947386`, 0.38510205968495004`, 0.9378197271726287]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 358}], {
             RGBColor[
             0.2688894294981841, 0.3999502173500661, 0.9386242272724338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 386}], {
             RGBColor[
             0.3010543278758621, 0.4306897646155703, 0.940568297848379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 37}], {
             RGBColor[
             0.3241466699483991, 0.4529239992502145, 0.9419579674054581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 62}], {
             RGBColor[
             0.6778828449272916, 0.740272939600058, 0.8649535953688089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[
             0.32344841914925154`, 0.45219009338865274`, 0.9419182030554161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 78}], {
             RGBColor[
             0.29221377727191306`, 0.41936050438489303`, 0.9401394364080135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 91}], {
             RGBColor[
             0.47826887557608655`, 0.5848930154724093, 0.9527405987202289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 117}], {
             RGBColor[
             0.4612467201078884, 0.5710736628239611, 0.9514005522875624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 182}], {
             RGBColor[
             0.30289473156223595`, 0.4305868645556383, 0.9407477009537915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 187}], {
             RGBColor[
             0.29015449891481293`, 0.4171960722657919, 0.940022163552006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 208}], {
             RGBColor[
             0.3291899186131193, 0.4582247733572693, 0.9422451729560961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 239}], {
             RGBColor[
             0.43554957397249955`, 0.5502115619480115, 0.9493775788120367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 269}], {
             RGBColor[
             0.35868258725721747`, 0.48509456199634804`, 0.9440759151828396]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 309}], {
             RGBColor[
             0.5306642654095335, 0.6265873056000757, 0.957441478589943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 323}], {
             RGBColor[
             0.3922918508728892, 0.5142052168895364, 0.9462174677409253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 362}], {
             RGBColor[
             0.5776163710657185, 0.6632666473879071, 0.9621212256893779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 365}], {
             RGBColor[
             0.33498940880084865`, 0.4643204052534886, 0.9425754453427104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 377}], {
             RGBColor[
             0.3093279743113551, 0.4373486105761115, 0.941114064611224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 388}], {
             RGBColor[
             0.31737166199215083`, 0.44580303632788293`, 0.9415721407250759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 395}], {
             RGBColor[
             0.4013213562160271, 0.522026120581628, 0.946792819836912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 70}], {
             RGBColor[
             0.1896105861046007, 0.3166231263744179, 0.9341094144237078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 177}], {
             RGBColor[
             0.18182665700375172`, 0.3084417233598157, 0.9336661311767056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 285}], {
             RGBColor[
             0.1832664520031871, 0.30995503919249784`, 0.9337481253719375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 324}], {
             RGBColor[
             0.1839722969253371, 0.31069692695883033`, 0.9337883221960501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 40}], {
             RGBColor[
             0.19924073649984758`, 0.3267450250266232, 0.9346578372421862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 41}], {
             RGBColor[
             0.1999138771125005, 0.32745253849010136`, 0.9346961716042546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 48}], {
             RGBColor[
             0.20648582903789775`, 0.33436007664951256`, 0.9350704345440743]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 63}], {
             RGBColor[
             0.1971785692903057, 0.32457755654044196`, 0.9345403998703059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 86}], {
             RGBColor[
             0.23656599040606416`, 0.3659762334398404, 0.9367834552343804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 250}], {
             RGBColor[
             0.19937642447535237`, 0.3268876416919933, 0.9346655644716588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 265}], {
             RGBColor[
             0.20201462184730384`, 0.32966055440128883`, 0.9348158059091283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 295}], {
             RGBColor[
             0.19546687096427723`, 0.32277845307184394`, 0.9344429211828693]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 325}], {
             RGBColor[
             0.22165235452841858`, 0.35030105655330623`, 0.9359341457338957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 376}], {
             RGBColor[
             0.24560585367761548`, 0.37547770289867644`, 0.937298262074416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 39}], {
             RGBColor[
             0.19488507531529636`, 0.3221669489567903, 0.9344097887813494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 50}], {
             RGBColor[
             0.21136185866227802`, 0.33948509294287055`, 0.9353481172177434]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 106}], {
             RGBColor[
             0.18905752987434937`, 0.31604182921063345`, 0.9340779186895682]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 197}], {
             RGBColor[
             0.19145378666017485`, 0.3185604470239914, 0.9342143819685769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 217}], {
             RGBColor[
             0.19992147826691017`, 0.32746052778532697`, 0.9346966044787532]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 231}], {
             RGBColor[
             0.19140134234262995`, 0.31850532472108994`, 0.934211395342277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 254}], {
             RGBColor[
             0.1893368412328983, 0.3163354031578313, 0.9340938250582336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 314}], {
             RGBColor[
             0.18717488313259786`, 0.3140630481183549, 0.9339707047427519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 369}], {
             RGBColor[
             0.1860007123494566, 0.3128289201785459, 0.9339038374536819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 113}], {
             RGBColor[
             0.1857448284490183, 0.3125599699752089, 0.9338892652440982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 162}], {
             RGBColor[
             0.19056901057120365`, 0.3176304912564385, 0.9341639952792189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 183}], {
             RGBColor[
             0.18726251983199932`, 0.31415515984591347`, 0.9339756955231359]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 270}], {
             RGBColor[
             0.19689305639497057`, 0.3242774643848816, 0.9345241403332949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 357}], {
             RGBColor[
             0.18592235681432462`, 0.3127465635430944, 0.9338993752218727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 153}], {
             RGBColor[
             0.2031751711317593, 0.3308803652823261, 0.9348818974739992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 168}], {
             RGBColor[
             0.19933167973369648`, 0.3268406121315325, 0.9346630163248155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 175}], {
             RGBColor[
             0.19541782934736363`, 0.32272690722304953`, 0.9344401283353366]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 211}], {
             RGBColor[
             0.21659401962004457`, 0.3449844258476482, 0.9356460810439997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 216}], {
             RGBColor[
             0.208257693184232, 0.33622241820998533`, 0.93517133958597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 229}], {
             RGBColor[
             0.19931037008134544`, 0.32681821433580155`, 0.9346618027716389]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 294}], {
             RGBColor[
             0.2052159577699056, 0.3330253614323641, 0.9349981172539683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 329}], {
             RGBColor[
             0.23151896311630302`, 0.36067148775828894`, 0.9364960344966363]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 341}], {
             RGBColor[
             0.22502124710185, 0.35384197624810876`, 0.9361259991821227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 343}], {
             RGBColor[
             0.2007094287814945, 0.32828871373510315`, 0.9347414770948905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 358}], {
             RGBColor[
             0.2391480425105603, 0.3686901339132248, 0.9369304992819277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 379}], {
             RGBColor[
             0.19158357625518677`, 0.31869686411748455`, 0.9342217732940062]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 99}], {
             RGBColor[
             0.9432122400933031, 0.9562926111989585, 0.9505366840460105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 111}], {
             RGBColor[
             0.905435236677787, 0.5966580870469695, 0.5418299175859177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 169}], {
             RGBColor[
             0.7207585549931849, 0.779010354243588, 0.9304794974284005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 199}], {
             RGBColor[
             0.9864970705564884, 0.9886842059127192, 0.8734420155476115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 215}], {
             RGBColor[
             0.8451646800561206, 0.8790328648583385, 0.9409404903646027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 222}], {
             RGBColor[
             0.967672940132394, 0.9754000826172251, 0.9391115323234271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 223}], {
             RGBColor[
             0.9217373572851282, 0.7206872472869994, 0.5573908785042743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 224}], {
             RGBColor[
             0.7410029688449329, 0.7954456814088879, 0.9320732118445416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 247}], {
             RGBColor[
             0.9007985668118983, 0.5610186106560575, 0.5373898372859729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 259}], {
             RGBColor[
             0.9398415048836066, 0.9536048784389164, 0.9502151803126189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 292}], {
             RGBColor[
             0.9018751366680733, 0.5692935983265383, 0.5384207617960579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 363}], {
             RGBColor[
             0.6793920980440895, 0.7432878081939467, 0.9278140990011539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 383}], {
             RGBColor[
             0.6712879724630387, 0.7362684219408357, 0.9272977112853262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 393}], {
             RGBColor[
             0.8531150739602782, 0.8852437730014981, 0.9417329113283139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 400}], {
             RGBColor[
             0.9031868035222537, 0.5793756445438494, 0.5396768154569369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 46}], {
             RGBColor[
             0.8135276706473076, 0.5072097485112304, 0.5747459012560696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 52}], {
             RGBColor[
             0.905256763296387, 0.5780630184234903, 0.500145144132204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 71}], {
             RGBColor[
             0.8956113709184261, 0.5716673969312225, 0.5522037062726537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 105}], {
             RGBColor[
             0.903410578527918, 0.577299573576944, 0.5307412035187635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 111}], {
             RGBColor[
             0.8240654755025505, 0.18598336703701845`, 0.17067843256029655`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 129}], {
             RGBColor[
             0.8204275141231614, 0.1580204017101934, 0.16719471663490398`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 199}], {
             RGBColor[
             0.9051273093812517, 0.578009485902768, 0.5022905305219902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 215}], {
             RGBColor[
             0.7637949188808839, 0.4683581448483874, 0.5697890053389816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 247}], {
             RGBColor[
             0.8194288056366617, 0.15034389064610632`, 0.16623835226035183`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 259}], {
             RGBColor[
             0.85847174370837, 0.5429301584289652, 0.5790636952869976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 271}], {
             RGBColor[
             0.8207608095887371, 0.16058225670961188`, 0.16751388074914259`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 287}], {
             RGBColor[
             0.8194189331925024, 0.1502680067141652, 0.16622889839667554`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 292}], {
             RGBColor[
             0.8205053754928366, 0.15861887831658708`, 0.16726927677043682`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 303}], {
             RGBColor[
             0.857724462248068, 0.3888260026114282, 0.20072238804006853`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 333}], {
             RGBColor[
             0.8876476995379257, 0.5657281038549604, 0.5656841246616948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 337}], {
             RGBColor[
             0.8892490440589328, 0.5669223839767665, 0.5629734660851704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 345}], {
             RGBColor[
             0.824801297962475, 0.5160822589510907, 0.5758521781137924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 353}], {
             RGBColor[
             0.9073893332491589, 0.5772003661732394, 0.33799440934929903`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 385}], {
             RGBColor[
             0.907968224972722, 0.5784385570350095, 0.40100320095353803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 391}], {
             RGBColor[
             0.8208765397934485, 0.16147180977632267`, 0.16762470412387276`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 400}], {
             RGBColor[
             0.8218170423470171, 0.16870092453389818`, 0.1685253304313158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 58}], {
             RGBColor[
             0.21989646734481127`, 0.3484555077936574, 0.9358341505563915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 74}], {
             RGBColor[
             0.24756162893783695`, 0.3775333467004828, 0.9374096405821755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 107}], {
             RGBColor[
             0.23483527017028652`, 0.36415713673803723`, 0.9366848932773241]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 116}], {
             RGBColor[
             0.24330530459768918`, 0.3730596799524376, 0.9371672492076716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 118}], {
             RGBColor[
             0.30201839786374246`, 0.43026808739011524`, 0.9406757417053806]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 124}], {
             RGBColor[
             0.23660403432322674`, 0.366016220008902, 0.9367856217791819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 141}], {
             RGBColor[
             0.3011781143378584, 0.42954027603387246`, 0.9406221995821449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 150}], {
             RGBColor[
             0.24249803494618108`, 0.37221118836485045`, 0.9371212763952667]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 152}], {
             RGBColor[
             0.2237166408577273, 0.3524707523687224, 0.9360517037865118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 156}], {
             RGBColor[
             0.22423055163894667`, 0.35301090518360945`, 0.9360809702452394]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 157}], {
             RGBColor[
             0.2467253832848012, 0.3766543994981055, 0.9373620176293496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 179}], {
             RGBColor[
             0.23670129905445042`, 0.3661184514083582, 0.9367911608617348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 206}], {
             RGBColor[
             0.33773890435239673`, 0.4612073947457289, 0.942951820792434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 209}], {
             RGBColor[
             0.25581747523043485`, 0.38621076460489123`, 0.9378797988151089]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 245}], {
             RGBColor[
             0.22074175679161856`, 0.34934396059669826`, 0.9358822885398935]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 286}], {
             RGBColor[
             0.2839164063725824, 0.41458905219301934`, 0.9395222988145264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 386}], {
             RGBColor[
             0.2942581498186507, 0.4235465505748645, 0.9401812655620653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 43}], {
             RGBColor[
             0.18881744465394812`, 0.3157894844217095, 0.9340642461914408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 159}], {
             RGBColor[
             0.1825395439463383, 0.30919101273611693`, 0.9337067290334642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 250}], {
             RGBColor[
             0.1883288985198916, 0.31527599145920215`, 0.9340364242118455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 265}], {
             RGBColor[
             0.19096709589184307`, 0.31804890416849774`, 0.9341866656493147]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 321}], {
             RGBColor[
             0.18374554341254123`, 0.3104585946398788, 0.9337754089189481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 375}], {
             RGBColor[
             0.19286667153168213`, 0.3200454786060204, 0.9342948436718334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 381}], {
             RGBColor[
             0.18614322275265005`, 0.3129787076479837, 0.9339119532103186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 73}], {
             RGBColor[
             0.19430576499947028`, 0.3215580570844616, 0.9343767979158759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 154}], {
             RGBColor[
             0.18823624142486384`, 0.31517860297752887`, 0.9340311475273575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 207}], {
             RGBColor[
             0.19080850531779897`, 0.3178822154199542, 0.9341776341507367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 231}], {
             RGBColor[
             0.19065322565130216`, 0.31771900664516656`, 0.9341687912034454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 280}], {
             RGBColor[
             0.19951437129521365`, 0.3270326325460011, 0.9346734203389759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 291}], {
             RGBColor[
             0.19278015708719454`, 0.31995454643953136`, 0.9342899168022064]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 372}], {
             RGBColor[
             0.18502327958345532`, 0.31180157636866185`, 0.9338481741036404]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 387}], {
             RGBColor[
             0.1878209095169145, 0.3147420628087102, 0.9340074949896282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 392}], {
             RGBColor[
             0.19658094676972326`, 0.3239494173798535, 0.934506366151862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 61}], {
             RGBColor[
             0.23146005042347673`, 0.36060956678284806`, 0.9364926795059334]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 70}], {
             RGBColor[
             0.22130912604082534`, 0.3499403016509027, 0.9359145993792883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 90}], {
             RGBColor[
             0.2306114538784999, 0.35971763800994894`, 0.9364443531880831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 95}], {
             RGBColor[
             0.2464425329575721, 0.37635710587044113`, 0.9373459097216534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 148}], {
             RGBColor[
             0.2511034439451054, 0.38125601883716365`, 0.9376113417071936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 228}], {
             RGBColor[
             0.23483092925025606`, 0.364152574155855, 0.9366846460683501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 276}], {
             RGBColor[
             0.31234957064668134`, 0.4391299345139409, 0.941337201922877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 282}], {
             RGBColor[
             0.28033871258182136`, 0.4114037381706667, 0.9392974983530744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 301}], {
             RGBColor[
             0.2477609938146631, 0.37774289182649035`, 0.9374209941169768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 305}], {
             RGBColor[
             0.2718566625317226, 0.40306896740175535`, 0.9387932068040659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 361}], {
             RGBColor[
             0.32761397052464425`, 0.4523511904771868, 0.9423098359853219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 382}], {
             RGBColor[
             0.2838749254794549, 0.4144666280473688, 0.9395228227119613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 76}], {
             RGBColor[
             0.28363325287465024`, 0.4154469105311262, 0.9394638662021915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 78}], {
             RGBColor[
             0.25239861099731176`, 0.3826173215273665, 0.9376850995547887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 80}], {
             RGBColor[
             0.24371904320437376`, 0.3734945454606058, 0.9371908110092508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 96}], {
             RGBColor[
             0.24798039051581972`, 0.3779734916699602, 0.9374334884345392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 104}], {
             RGBColor[
             0.2541903466574486, 0.3845005493087726, 0.9377871362499982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 117}], {
             RGBColor[
             0.4214315538332871, 0.5343304799664346, 0.9489462154343377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 145}], {
             RGBColor[
             0.2671022972631469, 0.3980718280603137, 0.9385224527354736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 182}], {
             RGBColor[
             0.26307956528763465`, 0.3938436816981118, 0.9382933641005669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 187}], {
             RGBColor[
             0.2503393326402117, 0.3804528894082654, 0.9375678266987812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 208}], {
             RGBColor[
             0.289374752338518, 0.42148159049974276`, 0.9397908361028714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 269}], {
             RGBColor[
             0.3188674209826161, 0.4483513791388215, 0.9416215783296149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 323}], {
             RGBColor[
             0.35247668459828785`, 0.4774620340320098, 0.9437631308877006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 365}], {
             RGBColor[
             0.29517424252624735`, 0.4275772223959621, 0.9401211084894857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 377}], {
             RGBColor[
             0.2695128080367538, 0.400605427718585, 0.9386597277579993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 388}], {
             RGBColor[
             0.27755649571754953`, 0.4090598534703564, 0.9391178038718512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 395}], {
             RGBColor[
             0.3615061899414258, 0.48528293772410147`, 0.9443384829836874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 44}], {
             RGBColor[
             0.24351959225973108`, 0.37328490987186613`, 0.9371794525730147]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 66}], {
             RGBColor[
             0.22742648369193186`, 0.3563700324050926, 0.9362629738476992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 81}], {
             RGBColor[
             0.2439408678768847, 0.37372769725591143`, 0.9372034435961902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 119}], {
             RGBColor[
             0.249257790450226, 0.37931611999285497`, 0.9375062344710599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 128}], {
             RGBColor[
             0.281313846761083, 0.4130090676469258, 0.9393317794552777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 130}], {
             RGBColor[
             0.23719458554175432`, 0.36663692678268434`, 0.9368192527974348]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 135}], {
             RGBColor[
             0.2970405045044002, 0.42707857493039736`, 0.9403174695829958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 146}], {
             RGBColor[
             0.2289275307271461, 0.3579477280109817, 0.9363484562557545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 151}], {
             RGBColor[
             0.23316903340538708`, 0.36240581625261525`, 0.9365900035585395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 213}], {
             RGBColor[
             0.2920695594579869, 0.42277299217815684`, 0.9400007253602725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 224}], {
             RGBColor[
             0.37823665311305865`, 0.49620023139778335`, 0.9458245390097163]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 227}], {
             RGBColor[
             0.2663587998591236, 0.39729036514822713`, 0.9384801116582203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 243}], {
             RGBColor[
             0.24505985490147014`, 0.37490382356662577`, 0.9372671682518474]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 267}], {
             RGBColor[
             0.22814489442186137`, 0.3571251276321197, 0.9363038862759752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 306}], {
             RGBColor[
             0.24051285588611682`, 0.3701246393051007, 0.9370082233846052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 311}], {
             RGBColor[
             0.23066096804752526`, 0.35976968054097413`, 0.9364471729467594]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 346}], {
             RGBColor[
             0.23107597310122763`, 0.36020587716525554`, 0.9364708068706228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 350}], {
             RGBColor[
             0.3036355127427933, 0.43279083959174136`, 0.9407376976762094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 363}], {
             RGBColor[
             0.3166257823122153, 0.444042358182842, 0.9415654261663287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 383}], {
             RGBColor[
             0.3085216567311646, 0.43702297192973105`, 0.9410490384505009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 47}], {
             RGBColor[
             0.18958921033534365`, 0.3166006590856267, 0.9341081971052712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 50}], {
             RGBColor[
             0.21465093660737516`, 0.342942122402754, 0.9355354253409618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 136}], {
             RGBColor[
             0.19040517985093924`, 0.31745829478197307`, 0.9341546653620656]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 149}], {
             RGBColor[
             0.2042501787734501, 0.33201026647316434`, 0.9349431175688622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 164}], {
             RGBColor[
             0.20658345954088297`, 0.3344626924982814, 0.9350759944567879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 197}], {
             RGBColor[
             0.19474286460527196`, 0.3220174764838748, 0.9344016900917953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 210}], {
             RGBColor[
             0.22192743235245416`, 0.35059018078730897`, 0.9359498110090333]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 217}], {
             RGBColor[
             0.2032105562120073, 0.33091755724521044`, 0.9348839126019717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 230}], {
             RGBColor[
             0.20964976351428055`, 0.33768557238922303`, 0.9352506159318827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 254}], {
             RGBColor[
             0.19262591917799537`, 0.31979243261771473`, 0.934281133181452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 258}], {
             RGBColor[
             0.21791338707223826`, 0.34637116469263174`, 0.9357212170685729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 314}], {
             RGBColor[
             0.19046396107769498`, 0.3175200775782383, 0.9341580128659703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 328}], {
             RGBColor[
             0.21476290196670605`, 0.3430598050944246, 0.9355418016025379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 41}], {
             RGBColor[
             0.19412189539412833`, 0.3213647984712409, 0.9343663268138622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 48}], {
             RGBColor[
             0.20069384731952558`, 0.3282723366306521, 0.934740589753682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 63}], {
             RGBColor[
             0.19138658757193353`, 0.3184898165215815, 0.9342105550799136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 103}], {
             RGBColor[
             0.19411926264855695`, 0.32136203128871965`, 0.9343661768828968]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 265}], {
             RGBColor[
             0.1962226401289317, 0.32357281438242835`, 0.9344859611187359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 295}], {
             RGBColor[
             0.1896748892459051, 0.31669071305298346`, 0.934113076392477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 48}], {
             RGBColor[
             0.2013669879321785, 0.3289798500941302, 0.9347789241157504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 63}], {
             RGBColor[
             0.19205972818458644`, 0.31919732998505956`, 0.9342488894419819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.1942575833696331, 0.32150741513661096`, 0.934374054043335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 265}], {
             RGBColor[
             0.19689578074158462`, 0.3242803278459065, 0.9345242954808043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 295}], {
             RGBColor[
             0.19034802985855803`, 0.31739822651646155`, 0.9341514107545453]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 325}], {
             RGBColor[
             0.2165335134226994, 0.3449208299979239, 0.9356426353055718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 381}], {
             RGBColor[
             0.19207190760239157`, 0.31921013132539244`, 0.934249583041808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 67}], {
             RGBColor[
             0.18164605198289263`, 0.3082518960318731, 0.9336558459879488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 75}], {
             RGBColor[
             0.18289766237674282`, 0.30956741791249204`, 0.9337271233482869]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 133}], {
             RGBColor[
             0.1836453052262827, 0.310353237950653, 0.9337697005025297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 178}], {
             RGBColor[
             0.18344665505298052`, 0.31014444402336394`, 0.9337583876690367]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 200}], {
             RGBColor[
             0.18896638878164698`, 0.3159460341435242, 0.9340727283391701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 278}], {
             RGBColor[
             0.18598976689484537`, 0.3128174158117676, 0.9339032141262342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 296}], {
             RGBColor[
             0.18148102360409654`, 0.30807844074235485`, 0.933646447865914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 320}], {
             RGBColor[
             0.18379681968568948`, 0.3105124892540611, 0.9337783290268474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 330}], {
             RGBColor[
             0.18629301045548374`, 0.31313614402075074`, 0.9339204833984038]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 347}], {
             RGBColor[
             0.18410501336322643`, 0.3108364203497602, 0.9337958802008515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 367}], {
             RGBColor[
             0.1849893429390042, 0.3117659068036362, 0.9338462414619436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 398}], {
             RGBColor[
             0.18234639975021955`, 0.30898800593994685`, 0.9336957297572264]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 159}], {
             RGBColor[
             0.1884193222929882, 0.31537103257792504`, 0.9340415737119533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 250}], {
             RGBColor[
             0.19420867686654147`, 0.32145601130101026`, 0.9343712688903346]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 265}], {
             RGBColor[
             0.19684687423849298`, 0.3242289240103058, 0.934521510327804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 321}], {
             RGBColor[
             0.1896253217591911, 0.31663861448168684`, 0.9341102535974373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 325}], {
             RGBColor[
             0.21648460691960775`, 0.3448694261623232, 0.9356398501525713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 375}], {
             RGBColor[
             0.19874644987833204`, 0.3262254984478285, 0.9346296883503225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 381}], {
             RGBColor[
             0.19202300109929993`, 0.3191587274897918, 0.9342467978888077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 66}], {
             RGBColor[
             0.21222031867993352`, 0.3403873888509353, 0.9353970052457711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 81}], {
             RGBColor[
             0.22873470286488637`, 0.35774505370175413`, 0.9363374749942621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 119}], {
             RGBColor[
             0.23405162543822766`, 0.3633334764386976, 0.9366402658691317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[
             0.26610768174908467`, 0.39702642409276845`, 0.9384658108533496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 130}], {
             RGBColor[
             0.22198842052975598`, 0.350654283228527, 0.9359532841955067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 135}], {
             RGBColor[
             0.2818343394924019, 0.41109593137624006`, 0.9394515009810677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 146}], {
             RGBColor[
             0.21372136571514777`, 0.3419650844568244, 0.9354824876538264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 151}], {
             RGBColor[
             0.21796286839338874`, 0.3464231726984579, 0.9357240349566114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 227}], {
             RGBColor[
             0.25115263484712524`, 0.3813077215940698, 0.9376141430562922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 243}], {
             RGBColor[
             0.2298536898894718, 0.3589211800124685, 0.9364011996499193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 267}], {
             RGBColor[
             0.21293872940986303`, 0.3411424840779623, 0.935437917674047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 275}], {
             RGBColor[
             0.21122882729611786`, 0.33934526854236047`, 0.9353405412782427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 311}], {
             RGBColor[
             0.21545480303552692`, 0.34378703698681684`, 0.9355812043448313]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 317}], {
             RGBColor[
             0.2084087804726259, 0.3363812205295747, 0.9351799437835304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 326}], {
             RGBColor[
             0.2349425006851034, 0.3642698428079171, 0.9366909998965096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 344}], {
             RGBColor[
             0.20993796520971017`, 0.3379884906441625, 0.9352670285920812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 346}], {
             RGBColor[
             0.2158698080892293, 0.3442232336110982, 0.9356048382686947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 383}], {
             RGBColor[
             0.29331549171916627`, 0.4210403283755737, 0.9401830698485728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 48}], {
             RGBColor[
             0.2238300988639671, 0.3525900039269335, 0.9360581650521211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 74}], {
             RGBColor[
             0.2441275547351621, 0.3739239169805914, 0.9372140751365906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 103}], {
             RGBColor[
             0.21725551419299843`, 0.345679698585001, 0.9356837521813359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 116}], {
             RGBColor[
             0.23987123039501432`, 0.3694502502325462, 0.9369716837620867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 262}], {
             RGBColor[
             0.30202723660803465`, 0.4296407358190505, 0.9406995556283282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 290}], {
             RGBColor[
             0.24862549482263574`, 0.3786515371983993, 0.9374702261704662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 304}], {
             RGBColor[
             0.2609958832174149, 0.3916535997292371, 0.9381747014891992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 338}], {
             RGBColor[
             0.2249286875668965, 0.3537446903082591, 0.9361207280535366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 52}], {
             RGBColor[
             0.89726556755869, 0.9188637535063902, 0.9066512485949225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 60}], {
             RGBColor[
             0.7562801355297237, 0.809531056908518, 0.9763425941360632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 102}], {
             RGBColor[
             0.5772856165740025, 0.6623742905041798, 0.9623565848838942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 105}], {
             RGBColor[
             0.8954193827902208, 0.9181003086598438, 0.937247307981482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 128}], {
             RGBColor[
             0.5547192055800235, 0.6423805327309791, 0.9609350717272003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 139}], {
             RGBColor[
             0.5562400144756487, 0.6439789993051345, 0.961021679543971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 199}], {
             RGBColor[
             0.8971361136435547, 0.9188102209856679, 0.9087966349847089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 213}], {
             RGBColor[
             0.5654749182769274, 0.6521444572622102, 0.9616040176321952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 215}], {
             RGBColor[
             0.7558037231431869, 0.8091588799312872, 0.9762951098017001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 259}], {
             RGBColor[
             0.850480547970673, 0.8837308935118651, 0.9855697997497163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 271}], {
             RGBColor[
             0.8127696138510401, 0.5013829917925117, 0.574019985211861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 287}], {
             RGBColor[
             0.8114277374548052, 0.49106874179706506`, 0.572735002859394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 333}], {
             RGBColor[
             0.8796565038002286, 0.9065288389378603, 0.9721902291244133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 337}], {
             RGBColor[
             0.8812578483212357, 0.9077231190596664, 0.969479570547889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 345}], {
             RGBColor[
             0.8168101022247779, 0.8568829940339906, 0.982358282576511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 350}], {
             RGBColor[
             0.5770408715617338, 0.6621623046757947, 0.9623409899481321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 353}], {
             RGBColor[
             0.8993981375114619, 0.9180011012561393, 0.7445005138120175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 400}], {
             RGBColor[
             0.81382584660932, 0.509501659616798, 0.5750314348940344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 136}], {
             RGBColor[
             0.18182023692588944`, 0.308434975450926, 0.9336657655627689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 149}], {
             RGBColor[
             0.1956652358484003, 0.3229869471421173, 0.9344542177695655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 155}], {
             RGBColor[
             0.18345196765990118`, 0.3101500279100763, 0.9337586902141416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 268}], {
             RGBColor[
             0.18433220446865944`, 0.3110752126063183, 0.9338088183982067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 279}], {
             RGBColor[
             0.19002059109890063`, 0.3170540676192452, 0.934132763601585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 299}], {
             RGBColor[
             0.184696983160691, 0.3114586181399484, 0.9338295920050762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 300}], {
             RGBColor[
             0.18858263454534693`, 0.31554268410974895`, 0.9340508741031263]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 371}], {
             RGBColor[
             0.18051873474236652`, 0.3070670141360388, 0.9335916469388172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.1986316801099837, 0.3261048681444708, 0.9346231523818017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 86}], {
             RGBColor[
             0.23801910122574216`, 0.3675035450438693, 0.9368662077458763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 103}], {
             RGBColor[
             0.2013643551866071, 0.328977082911609, 0.9347787741847848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 295}], {
             RGBColor[
             0.19691998178395526`, 0.3243057646758728, 0.9345256736943651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 191}], {
             RGBColor[
             0.18385357890938503`, 0.3105721467969078, 0.933781561380669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 225}], {
             RGBColor[
             0.19609003670444464`, 0.3234334397757498, 0.9344784095498806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 235}], {
             RGBColor[
             0.1884735679979762, 0.31542804825324383`, 0.9340446629246031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 261}], {
             RGBColor[
             0.1864507904031121, 0.31330198074953464`, 0.9339294687330069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 327}], {
             RGBColor[
             0.18473066760764006`, 0.3114940226294092, 0.9338315102844983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 335}], {
             RGBColor[
             0.1909811618412971, 0.3180636883732066, 0.9341874666843275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 349}], {
             RGBColor[
             0.19105637302960854`, 0.3181427401007867, 0.9341917498502368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 355}], {
             RGBColor[
             0.19591924831876065`, 0.3232539303537868, 0.9344686834039748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 127}], {
             RGBColor[
             0.28524823564473223`, 0.4143130772255349, 0.9396595042068966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 137}], {
             RGBColor[
             0.2618861891426283, 0.3925893677052923, 0.9382254030945505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 138}], {
             RGBColor[
             0.26001645706684573`, 0.3906241607457843, 0.9381189246188555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 147}], {
             RGBColor[
             0.23917140342485926`, 0.3687146877153205, 0.9369318296514377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 164}], {
             RGBColor[
             0.22306024288786463`, 0.3517808364843617, 0.9360143228931819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 197}], {
             RGBColor[
             0.21121964795225362`, 0.33933562046995513`, 0.9353400185281894]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 210}], {
             RGBColor[
             0.23840421569943582`, 0.3679083247733892, 0.9368881394454274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 217}], {
             RGBColor[
             0.21968733955898895`, 0.34823570123129066`, 0.9358222410383658]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 230}], {
             RGBColor[
             0.2261265468612622, 0.35500371637530337`, 0.9361889443682767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 242}], {
             RGBColor[
             0.2857631387189643, 0.41475906038865373`, 0.9396923133754758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 254}], {
             RGBColor[
             0.20910270252497706`, 0.33711057660379506`, 0.9352194616178461]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 258}], {
             RGBColor[
             0.23439017041921995`, 0.3636893086787121, 0.9366595455049669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 328}], {
             RGBColor[
             0.23123968531368772`, 0.36037794908050486`, 0.9364801300389318]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 331}], {
             RGBColor[
             0.2360482874744978, 0.36543209483450245`, 0.9367539728183005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 79}], {
             RGBColor[
             0.20012999875823717`, 0.3276796960426744, 0.934708479412256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 87}], {
             RGBColor[
             0.1940286984190197, 0.3212668425413722, 0.9343610193840024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 126}], {
             RGBColor[
             0.1918840790772874, 0.31901271163649164`, 0.9342388864851707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 176}], {
             RGBColor[
             0.19370665948804128`, 0.32092835920646634`, 0.9343426797432972]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 205}], {
             RGBColor[
             0.19318129293550862`, 0.32037616564959115`, 0.9343127608953405]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 232}], {
             RGBColor[
             0.19578437289714112`, 0.32311216773406903`, 0.9344610024482438]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 277}], {
             RGBColor[
             0.19316166908716753`, 0.3203555397407608, 0.9343116433462084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 298}], {
             RGBColor[
             0.20333725610200998`, 0.3310507268628402, 0.9348911279732717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 373}], {
             RGBColor[
             0.1995969758310581, 0.32711945515060364`, 0.9346781245450898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 390}], {
             RGBColor[
             0.2070958500160861, 0.33500124737515247`, 0.935105174336337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 60}], {
             RGBColor[
             0.8480092281788032, 0.880384326820778, 0.9017418370121976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 68}], {
             RGBColor[
             0.9052995090875355, 0.9251530264391655, 0.9074485213302443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 105}], {
             RGBColor[
             0.9871484754393005, 0.988953578572104, 0.8626465508576164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 129}], {
             RGBColor[
             0.904165411034544, 0.5696744067053534, 0.4991000639737569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 199}], {
             RGBColor[
             0.9888652062926342, 0.9896634908979279, 0.8341958778608433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 271}], {
             RGBColor[
             0.9044987065001195, 0.5722362617047718, 0.4994192280879955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 287}], {
             RGBColor[
             0.9031568301038848, 0.5619220117093251, 0.49813424573552845`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 303}], {
             RGBColor[
             0.9414623591594504, 0.8004800076065881, 0.5326277353789215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 333}], {
             RGBColor[
             0.9713855964493081, 0.9773821088501203, 0.8975894720005477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 337}], {
             RGBColor[
             0.9729869409703154, 0.9785763889719264, 0.8948788134240234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 345}], {
             RGBColor[
             0.9085391948738575, 0.9277362639462506, 0.9077575254526454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 353}], {
             RGBColor[
             0.9911272301605415, 0.9888543711683995, 0.6698997566881519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 391}], {
             RGBColor[
             0.904614436704831, 0.5731258147714826, 0.49953005146272567`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 69}], {
             RGBColor[
             0.4877113731208531, 0.5936081076641104, 0.9531940365593021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 93}], {
             RGBColor[
             0.37256678589576175`, 0.4971203570169409, 0.9449606040427729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 131}], {
             RGBColor[
             0.6083578580504109, 0.6889233390243821, 0.9644906126536026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 142}], {
             RGBColor[
             0.43838221439814257`, 0.5535604743597381, 0.949310664485988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 188}], {
             RGBColor[
             0.33920701496392514`, 0.465180569896386, 0.9429464497347737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 201}], {
             RGBColor[
             0.5341594365329997, 0.6309589682060907, 0.9570952074204189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 264}], {
             RGBColor[
             0.3312918681319017, 0.4568612487266348, 0.9424956938321003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 273}], {
             RGBColor[
             0.4633253395942303, 0.573810427068907, 0.9512742786711021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 281}], {
             RGBColor[
             0.40067800773256046`, 0.5214688844608842, 0.9467518262404362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[
             0.35836727987096656`, 0.4848214585861875, 0.944055824075003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 394}], {
             RGBColor[
             0.38011496144870427`, 0.5036582072985654, 0.9454415671144167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 64}], {
             RGBColor[
             0.970419525130984, 0.9095497585157698, 0.3557751825465969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 83}], {
             RGBColor[
             0.9496193654049732, 0.8977579075232218, 0.6225379522867944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 123}], {
             RGBColor[
             0.8957058066069172, 0.5826430148496441, 0.23309163667201951`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 161}], {
             RGBColor[
             0.9139000708098552, 0.6892402426005217, 0.2492124251865322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 196}], {
             RGBColor[
             0.8961892019683437, 0.8555483275728113, 0.6311082747514651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 198}], {
             RGBColor[
             0.8885256847199983, 0.8494376469396148, 0.6303773216350153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 206}], {
             RGBColor[
             0.6885711015156095, 0.68922695188861, 0.6128856824256679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 214}], {
             RGBColor[
             0.913587591361185, 0.6878213464055395, 0.24895168467498954`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 310}], {
             RGBColor[
             0.8873852444618682, 0.5186875281092153, 0.22512385696518958`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 332}], {
             RGBColor[
             0.8830293594773344, 0.4852062873571179, 0.22095265658473165`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 389}], {
             RGBColor[
             0.9706885388162402, 0.9101251515870772, 0.3850556620267193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 57}], {
             RGBColor[
             0.5760181454967422, 0.6613528823456771, 0.9622434817439033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 68}], {
             RGBColor[
             0.8126708442680417, 0.8535970039103761, 0.981959617507143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 72}], {
             RGBColor[
             0.6346370252408752, 0.7117938428167392, 0.9660702931075245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 83}], {
             RGBColor[
             0.8773611303882973, 0.9047851000408222, 0.9744632955960668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 123}], {
             RGBColor[
             0.8234475715902414, 0.5896702073672445, 0.5850169799812919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 161}], {
             RGBColor[
             0.8416418357931794, 0.6962674351181222, 0.6011377684958046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 196}], {
             RGBColor[
             0.8239309669516679, 0.8625755200904117, 0.9830336180607375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 236}], {
             RGBColor[
             0.6566866391587384, 0.7296947127190476, 0.9678061194855357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 262}], {
             RGBColor[
             0.5840352729572464, 0.6682969151994234, 0.9627543260164191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 284}], {
             RGBColor[
             0.7718010949853338, 0.8216561483989014, 0.9778895783229857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 334}], {
             RGBColor[
             0.8819744590496598, 0.862025730858683, 0.6405013220512796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 366}], {
             RGBColor[
             0.8985186945130963, 0.9173414029032505, 0.7466017890196988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 397}], {
             RGBColor[
             0.5839584526615165, 0.6682303773203624, 0.9627494310951048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 65}], {
             RGBColor[
             0.4474461015886463, 0.5602099797974611, 0.9502200964459863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 100}], {
             RGBColor[
             0.4530551393941151, 0.565068246426121, 0.9505774993750733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 174}], {
             RGBColor[
             0.4681168777823908, 0.5781139671930625, 0.9515372200266019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 198}], {
             RGBColor[
             0.6735978276393025, 0.7431113232752183, 0.969380994432274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 203}], {
             RGBColor[
             0.4142038212467356, 0.5314171873708888, 0.948101927737594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 206}], {
             RGBColor[
             0.4736432444349138, 0.5829006282242136, 0.9518893552229266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 266}], {
             RGBColor[
             0.5883098999275997, 0.6764125091387695, 0.9608991949142476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 341}], {
             RGBColor[
             0.38387079611477953`, 0.499652079122729, 0.9463702293168075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 358}], {
             RGBColor[
             0.3979975915234898, 0.5145002367878451, 0.9471747294166126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 68}], {
             RGBColor[
             0.584951659196002, 0.6683449078949819, 0.9631304154261922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 72}], {
             RGBColor[
             0.4069178401688355, 0.5265417468013449, 0.9472410910265736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 86}], {
             RGBColor[
             0.30819911150930557`, 0.43761024408224003`, 0.9409967540495674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 108}], {
             RGBColor[
             0.32733127751038416`, 0.4577193635987606, 0.9420863025998256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 236}], {
             RGBColor[
             0.4289674540866987, 0.5444426167036535, 0.9489769174045849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 262}], {
             RGBColor[
             0.35631608788520674`, 0.4830448191840292, 0.9439251239354682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 284}], {
             RGBColor[
             0.544081909913294, 0.6364040523835073, 0.9590603762420349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 297}], {
             RGBColor[
             0.3224295006293375, 0.45256728530617585`, 0.9418071536579791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 325}], {
             RGBColor[
             0.29328547563165996`, 0.42193506719570584`, 0.9401474445490827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 376}], {
             RGBColor[
             0.31723897478085683`, 0.4471117135410761, 0.941511560889603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 397}], {
             RGBColor[
             0.3562392675894767, 0.4829782813049682, 0.943920229014154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 124}], {
             RGBColor[
             0.20991109539232988`, 0.337960248762451, 0.9352654983957317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 152}], {
             RGBColor[
             0.19702370192683044`, 0.32441478112227146`, 0.9345315804030616]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 156}], {
             RGBColor[
             0.19753761270804981`, 0.3249549339371585, 0.9345608468617892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 160}], {
             RGBColor[
             0.1942495004305084, 0.32149891945510295`, 0.9343735937319094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 179}], {
             RGBColor[
             0.21000836012355356`, 0.3380624801619072, 0.9352710374782847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 181}], {
             RGBColor[
             0.19266290312611054`, 0.31983130509210156`, 0.9342832393625844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 220}], {
             RGBColor[
             0.186453938859043, 0.31330528997634166`, 0.9339296480329143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[
             0.1940488178607217, 0.32128798935024727`, 0.9343621651564433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 352}], {
             RGBColor[
             0.18979453396815193`, 0.3168164672419784, 0.9341198899824106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 396}], {
             RGBColor[
             0.18880077082680655`, 0.315771959172202, 0.9340632966416518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 132}], {
             RGBColor[
             0.20457320024571096`, 0.33234978252125474`, 0.93496151316384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 149}], {
             RGBColor[
             0.21329928840113216`, 0.34152145443854653`, 0.9354584509752006]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 155}], {
             RGBColor[
             0.20108602021263303`, 0.3286845352065056, 0.9347629234197767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 164}], {
             RGBColor[
             0.215632569168565, 0.3439738804636637, 0.9355913278631264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 210}], {
             RGBColor[
             0.23097654198013617`, 0.36010136875269116`, 0.9364651444153718]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 230}], {
             RGBColor[
             0.21869887314196257`, 0.34719676035460534`, 0.9357659493382211]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 258}], {
             RGBColor[
             0.2269624966999203, 0.35588235265801405`, 0.9362365504749113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 264}], {
             RGBColor[
             0.2381256499847355, 0.3676155345451527, 0.9368722755400762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 268}], {
             RGBColor[
             0.2019662570213913, 0.3296097199027477, 0.9348130516038419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 279}], {
             RGBColor[
             0.2076546436516325, 0.3355885749156745, 0.9351369968072203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 299}], {
             RGBColor[
             0.20233103571342284`, 0.3299931254363777, 0.9348338252107113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 300}], {
             RGBColor[
             0.20621668709807878`, 0.3340771914061782, 0.9350551073087614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 328}], {
             RGBColor[
             0.22381201159438807`, 0.3525709930598068, 0.9360571350088763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 394}], {
             RGBColor[
             0.286948743301538, 0.41441249311708334`, 0.9398181488223927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 68}], {
             RGBColor[
             0.7643140770585692, 0.8158203298412934, 0.9771398668713851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 72}], {
             RGBColor[
             0.5862802580314027, 0.6740171687476564, 0.9612505424717664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 102}], {
             RGBColor[
             0.5280292771941157, 0.6238948638185677, 0.9574471733011694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 105}], {
             RGBColor[
             0.8461630434103341, 0.8796208819742317, 0.932337896398757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 108}], {
             RGBColor[
             0.5066936953729514, 0.6051947855450721, 0.9560957540450186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 139}], {
             RGBColor[
             0.506983675095762, 0.6054995726195224, 0.9561122679612462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 297}], {
             RGBColor[
             0.5017919184919047, 0.6000427072524873, 0.955816605103172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 333}], {
             RGBColor[
             0.8304001644203418, 0.8680494122522482, 0.9672808175416883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 337}], {
             RGBColor[
             0.8320015089413489, 0.8692436923740543, 0.9645701589651641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 345}], {
             RGBColor[
             0.7675537628448912, 0.8184035673483785, 0.9774488709937861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 353}], {
             RGBColor[
             0.8501417981315751, 0.8795216745705272, 0.7395911022292926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 70}], {
             RGBColor[
             0.20711529305388426`, 0.33502168324063814`, 0.9351062815885762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 90}], {
             RGBColor[
             0.21641762089155886`, 0.3447990195996844, 0.935636035397371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 95}], {
             RGBColor[
             0.23224869997063102`, 0.3614384874601766, 0.9365375919309413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 148}], {
             RGBColor[
             0.23690961095816437`, 0.3663374004268991, 0.9368030239164815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 228}], {
             RGBColor[
             0.220637096263315, 0.34923395574559046`, 0.935876328277638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 282}], {
             RGBColor[
             0.2661448795948803, 0.3964851197604022, 0.9384891805623623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 285}], {
             RGBColor[
             0.2007711589524707, 0.32835359605871806`, 0.934744992536806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 301}], {
             RGBColor[
             0.23356716082772205`, 0.3628242734162258, 0.9366126763262647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 382}], {
             RGBColor[
             0.2696810924925139, 0.39954800963710424`, 0.9387145049212492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 91}], {
             RGBColor[
             0.7921898842803778, 0.8354987729647263, 0.873281889830355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 111}], {
             RGBColor[
             0.9092079691258396, 0.5982182088690406, 0.47930597740308856`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 117}], {
             RGBColor[
             0.7751677288121797, 0.821679420316278, 0.8719418433976884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 223}], {
             RGBColor[
             0.9255100897331807, 0.7222473691090705, 0.4948669383214451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 247}], {
             RGBColor[
             0.9045712992599508, 0.5625787324781286, 0.4748658971031438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 256}], {
             RGBColor[
             0.992053902372576, 0.9909820986727351, 0.781350931735281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 319}], {
             RGBColor[
             0.9121241184522142, 0.6206330104563391, 0.4820984852913445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 323}], {
             RGBColor[
             0.7062128595771804, 0.7648109743818534, 0.8667587588510515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 362}], {
             RGBColor[
             0.8915373797700097, 0.913872404880224, 0.882662516799504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 395}], {
             RGBColor[
             0.7152423649203183, 0.772631878073945, 0.8673341109470382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 103}], {
             RGBColor[
             0.19205709543901506`, 0.31919456280253833`, 0.9342487395110164]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 295}], {
             RGBColor[
             0.1876127220363632, 0.31452324456680214`, 0.9339956390205967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 88}], {
             RGBColor[
             0.7114905669436782, 0.7668789695612932, 0.6914868954695467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 101}], {
             RGBColor[
             0.9232794978996539, 0.7012101823729198, 0.31682349709282953`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 115}], {
             RGBColor[
             0.973846560757742, 0.9231368127839409, 0.35853265585475147`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 120}], {
             RGBColor[
             0.7025664799902631, 0.759149373979897, 0.6909182605401354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 123}], {
             RGBColor[
             0.9178715311357676, 0.6596421800395433, 0.31164482201230714`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 140}], {
             RGBColor[
             0.6994659535308891, 0.7564638537977784, 0.690720697735832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 161}], {
             RGBColor[
             0.9360657953387055, 0.766239407790421, 0.32776561052681985`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 193}], {
             RGBColor[
             0.9152566921622731, 0.9300770448033753, 0.7093659477350615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 195}], {
             RGBColor[
             0.7086017617355334, 0.7643768316855696, 0.6913028233561538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 214}], {
             RGBColor[
             0.9357533158900353, 0.7648205115954387, 0.32750487001527717`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 233}], {
             RGBColor[
             0.9814581324353071, 0.9819712119725741, 0.6847171998056071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 257}], {
             RGBColor[
             0.9810027572631417, 0.9816315939147817, 0.6854880311912166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 283}], {
             RGBColor[
             0.9622538962308652, 0.8771757609613251, 0.3492049258616166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 312}], {
             RGBColor[
             0.7702008939642393, 0.8151650470913949, 0.695936819489472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 332}], {
             RGBColor[
             0.9051950840061846, 0.5622054525470171, 0.2995058419250193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 356}], {
             RGBColor[
             0.9689844051155808, 0.9726683265613763, 0.7058319664887789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 360}], {
             RGBColor[
             0.8276703795499445, 0.8615089159497265, 0.7006746506658257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 380}], {
             RGBColor[
             0.8564837144111264, 0.8840181121327374, 0.7035464946088651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 389}], {
             RGBColor[
             0.9928542633450905, 0.9871243167769764, 0.4636088473670069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 100}], {
             RGBColor[
             0.38210315454201915`, 0.5053802802265043, 0.9455682530202327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 167}], {
             RGBColor[
             0.30615029923372655`, 0.43284997763222943`, 0.940975526215034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 174}], {
             RGBColor[
             0.39716489293029483`, 0.5184260009934458, 0.9465279736717613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 198}], {
             RGBColor[
             0.6026458427872066, 0.6834233570756016, 0.9643717480774334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 203}], {
             RGBColor[
             0.34325183639463963`, 0.4717292211712722, 0.9430926813827534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 206}], {
             RGBColor[
             0.4026912595828178, 0.5232126620245969, 0.9468801088680859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 211}], {
             RGBColor[
             0.3044915837808781, 0.4311065625226518, 0.9408810648238439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 266}], {
             RGBColor[
             0.5173579150755038, 0.6167245429391528, 0.9558899485594068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 313}], {
             RGBColor[
             0.33055584599709903`, 0.45850175468157234`, 0.9423653859984371]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 329}], {
             RGBColor[
             0.31941652727713654`, 0.4467936244332925, 0.9417310182764805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 340}], {
             RGBColor[
             0.3239430587205376, 0.45155129597897675`, 0.941988797545779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 341}], {
             RGBColor[
             0.31291881126268356`, 0.4399641129231123, 0.9413609829619669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 358}], {
             RGBColor[
             0.3270456066713938, 0.4548122705882284, 0.942165483061772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 81}], {
             RGBColor[
             0.21264159429708712`, 0.3408301762349806, 0.9354209962689466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 119}], {
             RGBColor[
             0.21795851687042844`, 0.3464185989719241, 0.9357237871438162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 130}], {
             RGBColor[
             0.20589531196195676`, 0.3337394057617535, 0.9350368054701912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 146}], {
             RGBColor[
             0.19762825714734855`, 0.3250502069900508, 0.9345660089285108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 151}], {
             RGBColor[
             0.20186975982558952`, 0.3295082952316844, 0.9348075562312959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 158}], {
             RGBColor[
             0.19363377892106423`, 0.3208517571096786, 0.934338529302825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 243}], {
             RGBColor[
             0.21376058132167255`, 0.342006302545695, 0.9354847209246038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 267}], {
             RGBColor[
             0.1968456208420638, 0.3242276066111888, 0.9345214389487315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 275}], {
             RGBColor[
             0.19513571872831864`, 0.3224303910755869, 0.9344240625529272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 311}], {
             RGBColor[
             0.19936169446772767`, 0.32687215952004334`, 0.9346647256195157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 317}], {
             RGBColor[
             0.19231567190482668`, 0.3194663430628012, 0.9342634650582149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 344}], {
             RGBColor[
             0.19384485664191092`, 0.32107361317738903`, 0.9343505498667657]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 346}], {
             RGBColor[
             0.19977669952143007`, 0.3273083561443247, 0.9346883595433791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 354}], {
             RGBColor[
             0.19611420939972474`, 0.3234588468111266, 0.9344797861491166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 75}], {
             RGBColor[
             0.1806580838475214, 0.3072134788808002, 0.9335995826642074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 126}], {
             RGBColor[
             0.18098291600078534`, 0.3075548980694286, 0.9336180813747896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 133}], {
             RGBColor[
             0.1814057266970613, 0.30799929891896116`, 0.9336421598184501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 200}], {
             RGBColor[
             0.1867268102524256, 0.3135920951118324, 0.9339451876550904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 320}], {
             RGBColor[
             0.1815572411564681, 0.30815855022236927`, 0.9336507883427678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 347}], {
             RGBColor[
             0.18186543483400505`, 0.3084824813180684, 0.9336683395167719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 398}], {
             RGBColor[
             0.18010682122099816`, 0.306634066908255, 0.9335681890731469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 72}], {
             RGBColor[
             0.6435705389401349, 0.7187858683660439, 0.9669572267898132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 236}], {
             RGBColor[
             0.6656201528579981, 0.7366867382683524, 0.9686930531678246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 262}], {
             RGBColor[
             0.5929687866565062, 0.6752889407487281, 0.9636412596987081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 284}], {
             RGBColor[
             0.7807346086845934, 0.8286481739482061, 0.9787765120052747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 333}], {
             RGBColor[
             0.8876904453290742, 0.9128181118706356, 0.9729875018597351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 334}], {
             RGBColor[
             0.8909079727489195, 0.8690177564079877, 0.6413882557335685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 337}], {
             RGBColor[
             0.8892917898500812, 0.9140123919924417, 0.970276843283211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 376}], {
             RGBColor[
             0.5538916735521564, 0.639355835105775, 0.9612276966528428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 391}], {
             RGBColor[
             0.8209192855845969, 0.5085618177919978, 0.5749280813219132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 397}], {
             RGBColor[
             0.5928919663607762, 0.6752224028696671, 0.9636363647773936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 93}], {
             RGBColor[
             0.45767335020652483`, 0.5675906819706489, 0.951280040300782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 131}], {
             RGBColor[
             0.693464422361174, 0.75939366397809, 0.9708100489116116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 142}], {
             RGBColor[
             0.5234887787089056, 0.6240307993134462, 0.955630100743997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 188}], {
             RGBColor[
             0.42431357927468827`, 0.535650894850094, 0.9492658859927827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 201}], {
             RGBColor[
             0.6192660008437627, 0.7014292931597987, 0.9634146436784279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 273}], {
             RGBColor[
             0.5484319039049934, 0.644280752022615, 0.9575937149291112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 281}], {
             RGBColor[
             0.4857845720433236, 0.5919392094145923, 0.9530712624984452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 293}], {
             RGBColor[
             0.44347384418172964`, 0.5552917835398956, 0.950375260333012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 394}], {
             RGBColor[
             0.46522152575946735`, 0.5741285322522734, 0.9517610033724258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 90}], {
             RGBColor[
             0.2062666965089075, 0.33412975446773896`, 0.9350579552707259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 95}], {
             RGBColor[
             0.22209777558797966`, 0.3507692223282312, 0.9359595118042963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 177}], {
             RGBColor[
             0.1891804395703839, 0.31617101509409057`, 0.9340849182149289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 228}], {
             RGBColor[
             0.21048617188066365`, 0.3385646906136451, 0.9352982481509928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 246}], {
             RGBColor[
             0.2068329817370454, 0.33472495614706915`, 0.9350902043767244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 260}], {
             RGBColor[
             0.19294770058427305`, 0.3201306452778321, 0.9342994581565066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 285}], {
             RGBColor[
             0.1906202345698193, 0.31768433092677273`, 0.9341669124101608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 110}], {
             RGBColor[
             0.9113332721380322, 0.9312595378862136, 0.9610025753124077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 131}], {
             RGBColor[
             0.8919073913712897, 0.9158173378862382, 0.9591371203789343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 201}], {
             RGBColor[
             0.8177089698538784, 0.8578529670679469, 0.9517417151457506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 212}], {
             RGBColor[
             0.7737416965530766, 0.822516123696677, 0.9480358411696325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 271}], {
             RGBColor[
             0.8948533141221586, 0.565840640212504, 0.5514777902284453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 273}], {
             RGBColor[
             0.7468748729151091, 0.8007044259307632, 0.9459207863964338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 287}], {
             RGBColor[
             0.8935114377259239, 0.5555263902170573, 0.5501928078759782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 289}], {
             RGBColor[
             0.7219591346417744, 0.780476707159252, 0.9439593282102003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 292}], {
             RGBColor[
             0.8945978800262582, 0.5638772618194792, 0.5512331862497395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 303}], {
             RGBColor[
             0.9318169667814895, 0.7940843861143203, 0.5846862975193713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 385}], {
             RGBColor[
             0.9820607295061435, 0.9836969405379016, 0.7849671104328407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 400}], {
             RGBColor[
             0.8959095468804387, 0.5739593080367903, 0.5524892399106185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 86}], {
             RGBColor[
             0.3668179912534385, 0.4880512045533021, 0.9448235654131886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 108}], {
             RGBColor[
             0.3859501572545172, 0.5081603240698226, 0.9459131139634468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 236}], {
             RGBColor[
             0.4875863338308316, 0.5948835771747154, 0.9528037287682061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 262}], {
             RGBColor[
             0.4149349676293397, 0.5334857796550911, 0.9477519352990894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 284}], {
             RGBColor[
             0.602700789657427, 0.6868450128545692, 0.9628871876056561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 297}], {
             RGBColor[
             0.3810483803734705, 0.5030082457772378, 0.9456339650216002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 325}], {
             RGBColor[
             0.35190435537579295`, 0.4723760276667679, 0.9439742559127038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 333}], {
             RGBColor[
             0.7096566263019076, 0.7710149507769987, 0.9570981774601166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 337}], {
             RGBColor[
             0.7112579708229148, 0.7722092308988048, 0.9543875188835923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 376}], {
             RGBColor[
             0.3758578545249899, 0.4975526740121381, 0.9453383722532241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 397}], {
             RGBColor[
             0.4148581473336097, 0.5334192417760302, 0.947747040377775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.21536881746289013`, 0.3436966606981754, 0.9355763075936738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 162}], {
             RGBColor[
             0.19690433907813965`, 0.3242893232002557, 0.9345247828654102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 183}], {
             RGBColor[
             0.19359784833893534`, 0.3208139917897307, 0.9343364831093273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 189}], {
             RGBColor[
             0.2158427366159144, 0.3441947797762137, 0.9356032965883381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 207}], {
             RGBColor[
             0.1950145063297256, 0.32230298915935574`, 0.934417159686145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 280}], {
             RGBColor[
             0.2037203723071403, 0.3314534062854026, 0.9349129458743843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 291}], {
             RGBColor[
             0.19698615809912115`, 0.32437532017893284`, 0.9345294423376147]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 336}], {
             RGBColor[
             0.2166564041388005, 0.3450499959322676, 0.9356496337500533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 368}], {
             RGBColor[
             0.19117243294824504`, 0.31826472643389747`, 0.934198359290908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 387}], {
             RGBColor[
             0.19202691052884113`, 0.31916283654811173`, 0.9342470205250366]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 116}], {
             RGBColor[
             0.244277527259818, 0.37408154761281204`, 0.9372226158500052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 118}], {
             RGBColor[
             0.3029906205258713, 0.4312899550504897, 0.9407311083477143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 141}], {
             RGBColor[
             0.3021503369999872, 0.43056214369424695`, 0.9406775662244785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 179}], {
             RGBColor[
             0.23767352171657924`, 0.3671403190687327, 0.9368465275040685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 209}], {
             RGBColor[
             0.2567896978925637, 0.3872326322652657, 0.9379351654574425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 286}], {
             RGBColor[
             0.28488862903471124`, 0.4156109198533938, 0.9395776654568602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 290}], {
             RGBColor[
             0.2530317916874394, 0.3832828345786652, 0.9377211582583846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 304}], {
             RGBColor[
             0.2654021800822186, 0.39628489710950293`, 0.9384256335771177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 338}], {
             RGBColor[
             0.22933498443170014`, 0.35837598768852497`, 0.9363716601414551]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 386}], {
             RGBColor[
             0.29523037248077955`, 0.42456841823523894`, 0.9402366322043989]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 126}], {
             RGBColor[
             0.18223452639463555`, 0.3088704199500476, 0.9336893587351277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 133}], {
             RGBColor[
             0.18265733709091148`, 0.3093148207995801, 0.9337134371787883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 178}], {
             RGBColor[
             0.18245868691760933`, 0.30910602687229105`, 0.9337021243452953]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 200}], {
             RGBColor[
             0.1879784206462758, 0.3149076169924513, 0.9340164650154286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 296}], {
             RGBColor[
             0.18049305546872535`, 0.30704002359128196`, 0.9335901845421726]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 320}], {
             RGBColor[
             0.18280885155031829`, 0.3094740721029882, 0.933722065703106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 330}], {
             RGBColor[
             0.18530504232011252`, 0.31209772686967785`, 0.9338642200746624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 347}], {
             RGBColor[
             0.18311704522785527`, 0.30979800319868733`, 0.9337396168771099]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 398}], {
             RGBColor[
             0.18135843161484838`, 0.30794958878887396`, 0.9336394664334849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 78}], {
             RGBColor[
             0.2517003601981642, 0.38188341566580475`, 0.9376453352047469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 80}], {
             RGBColor[
             0.24302079240522623`, 0.37276063959904404`, 0.9371510466592089]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.24728213971667218`, 0.37723958580839845`, 0.9373937240844974]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 117}], {
             RGBColor[
             0.4207333030341396, 0.5335965741048728, 0.9489064510842957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.2623813144884871, 0.39310977583655005`, 0.9382535997505249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 187}], {
             RGBColor[
             0.24964108184106412`, 0.37971898354670364`, 0.9375280623487394]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 208}], {
             RGBColor[
             0.28867650153937047`, 0.420747684638181, 0.9397510717528295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 239}], {
             RGBColor[
             0.3950361568987507, 0.5127344732289232, 0.94688347760877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 269}], {
             RGBColor[
             0.3181691701834686, 0.44761747327725976`, 0.9415818139795731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 323}], {
             RGBColor[
             0.3517784337991403, 0.4767281281704481, 0.9437233665376588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 365}], {
             RGBColor[
             0.2944759917270998, 0.42684331653440033`, 0.9400813441394438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 377}], {
             RGBColor[
             0.2688145572376063, 0.39987152185702324`, 0.9386199634079575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 388}], {
             RGBColor[
             0.276858244918402, 0.40832594760879465`, 0.9390780395218092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 395}], {
             RGBColor[
             0.36080793914227827`, 0.4845490318625397, 0.9442987186336453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 78}], {
             RGBColor[
             0.20870891214169546`, 0.33669667794321373`, 0.9351970358380788]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 80}], {
             RGBColor[
             0.20002934434875747`, 0.3275739018764531, 0.9347027472925409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 96}], {
             RGBColor[
             0.20429069166020342`, 0.3320528480858075, 0.9349454247178293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 182}], {
             RGBColor[
             0.21938986643201835`, 0.34792303811395897`, 0.9358053003838569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 187}], {
             RGBColor[
             0.2066496337845954, 0.33453224582411256`, 0.9350797629820713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 244}], {
             RGBColor[
             0.18965577385650711`, 0.31667062156674053`, 0.9341119877993296]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 302}], {
             RGBColor[
             0.19582677060371215`, 0.3231567304118451, 0.9344634169349113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 377}], {
             RGBColor[
             0.22582310918113752`, 0.35468478413443216`, 0.9361716640412894]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 388}], {
             RGBColor[
             0.23386679686193323`, 0.36313920988620363`, 0.9366297401551412]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 80}], {
             RGBColor[
             0.21178615052788774`, 0.3399310505952844, 0.9353722800118063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 96}], {
             RGBColor[
             0.2160474978393337, 0.3444099968046388, 0.9356149574370947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 104}], {
             RGBColor[
             0.22225745398096258`, 0.35093705444345114`, 0.9359686052525535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 182}], {
             RGBColor[
             0.23114667261114863`, 0.3602801868327903, 0.9364748331031223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 187}], {
             RGBColor[
             0.21840643996372563`, 0.3468893945429439, 0.9357492957013367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 208}], {
             RGBColor[
             0.257441859662032, 0.38791809563442126`, 0.9379723051054267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 302}], {
             RGBColor[
             0.2075835767828424, 0.33551387913067643`, 0.9351329496541767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 377}], {
             RGBColor[
             0.2375799153602678, 0.3670419328532635, 0.9368411967605548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 388}], {
             RGBColor[
             0.2456236030410635, 0.37549635860503494`, 0.9372992728744065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 87}], {
             RGBColor[
             0.19294989757058154`, 0.3201329544497393, 0.9342995832716268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 126}], {
             RGBColor[
             0.19080527822884924`, 0.31787882354485875`, 0.9341774503727951]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 176}], {
             RGBColor[
             0.19262785863960308`, 0.31979447111483345`, 0.9342812436309215]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 205}], {
             RGBColor[
             0.19210249208707042`, 0.3192422775579583, 0.9342513247829649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 232}], {
             RGBColor[
             0.19470557204870292`, 0.32197827964243614`, 0.9343995663358682]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[
             0.19208286823872933`, 0.31922165164912797`, 0.9342502072338328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 298}], {
             RGBColor[
             0.20225845525357178`, 0.3299168387712073, 0.934829691860896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 373}], {
             RGBColor[
             0.19851817498261992`, 0.32598556705897075`, 0.9346166884327141]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 390}], {
             RGBColor[
             0.2060170491676479, 0.3338673592835195, 0.9350437382239613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 96}], {
             RGBColor[
             0.2073679300463957, 0.3352872207378781, 0.9351206688915568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 104}], {
             RGBColor[
             0.2135778861880246, 0.34181427837669043`, 0.9354743167070156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 182}], {
             RGBColor[
             0.22246710481821064`, 0.35115741076602963`, 0.9359805445575843]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 187}], {
             RGBColor[
             0.20972687217078761`, 0.3377666184761832, 0.9352550071557988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 244}], {
             RGBColor[
             0.1927330122426994, 0.31990499421881113`, 0.9342872319730569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 302}], {
             RGBColor[
             0.1989040089899044, 0.3263911030639157, 0.9346386611086387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 377}], {
             RGBColor[
             0.2289003475673298, 0.3579191567865028, 0.9363469082150169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 388}], {
             RGBColor[
             0.23694403524812552`, 0.36637358253827423`, 0.9368049843288686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 119}], {
             RGBColor[
             0.2344729010553813, 0.363776263822743, 0.9366642568923073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 128}], {
             RGBColor[
             0.2665289573662383, 0.3974692114768138, 0.9384898018765251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.2224096961469096, 0.35109707061257234`, 0.9359772752186821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 135}], {
             RGBColor[
             0.2822556151095555, 0.41153871876028536`, 0.9394754920042432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 146}], {
             RGBColor[
             0.2141426413323014, 0.3424078718408697, 0.9355064786770019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 166}], {
             RGBColor[
             0.2371652059079643, 0.3666060469247946, 0.9368175796707537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 227}], {
             RGBColor[
             0.2515739104642789, 0.38175050897811513`, 0.9376381340794677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 243}], {
             RGBColor[
             0.2302749655066254, 0.3593639673965138, 0.9364251906730947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[
             0.21336000502701669`, 0.3415852714620077, 0.9354619086972226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 275}], {
             RGBColor[
             0.21165010291327152`, 0.33978805592640576`, 0.9353645323014182]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 311}], {
             RGBColor[
             0.21587607865268055`, 0.34422982437086214`, 0.9356051953680067]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 326}], {
             RGBColor[
             0.23536377630225702`, 0.36471263019196243`, 0.936714990919685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 344}], {
             RGBColor[
             0.2103592408268638, 0.3384312780282078, 0.9352910196152566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 346}], {
             RGBColor[
             0.21629108370638292`, 0.34466602099514354`, 0.9356288292918702]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 363}], {
             RGBColor[
             0.3018408929173706, 0.42850250201273, 0.940723448587576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 383}], {
             RGBColor[
             0.2937367673363199, 0.42148311575961905`, 0.9402070608717483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 172}], {
             RGBColor[
             0.5696909718954926, 0.6577404259092337, 0.9610497684809419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 194}], {
             RGBColor[
             0.6075992658363466, 0.6905170696190597, 0.963481170694517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 233}], {
             RGBColor[
             0.865044812104987, 0.8948209835298624, 0.9558976637938235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 256}], {
             RGBColor[
             0.8760312800563814, 0.9016669835366705, 0.876948136427472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 257}], {
             RGBColor[
             0.8645894369328215, 0.89448136547207, 0.956668495179433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 310}], {
             RGBColor[
             0.7931376486603983, 0.5085364648564028, 0.5748575062936936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 316}], {
             RGBColor[
             0.7359499332008539, 0.7936489483339444, 0.9743162695644639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 399}], {
             RGBColor[
             0.5595672102027384, 0.6489717323660277, 0.9604046913379707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 118}], {
             RGBColor[
             0.6542161598297946, 0.7234949587303476, 0.9559255584190995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 123}], {
             RGBColor[
             0.8970713714097568, 0.6478503290469954, 0.5784075917525047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 141}], {
             RGBColor[
             0.6533758763039106, 0.7227671473741049, 0.9558720162958637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 161}], {
             RGBColor[
             0.9152656356126947, 0.754447556797873, 0.5945283802670174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 196}], {
             RGBColor[
             0.8975547667711833, 0.9207556417701627, 0.9764242298319501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 214}], {
             RGBColor[
             0.9149531561640245, 0.7530286606028909, 0.5942676397554747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 286}], {
             RGBColor[
             0.6361141683386347, 0.7078159235332517, 0.9547721155282454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 332}], {
             RGBColor[
             0.8843949242801739, 0.5504136015544692, 0.5662686116652167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 334}], {
             RGBColor[
             0.9555982588691752, 0.9202058525384339, 0.6338919338224923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 366}], {
             RGBColor[
             0.9721424943326117, 0.9755215245830015, 0.7399924007909114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 125}], {
             RGBColor[
             0.20344264397852102`, 0.33116149620303065`, 0.9348971296569317]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 184}], {
             RGBColor[
             0.21392003441563898`, 0.34217389785736374`, 0.9354938015424155]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 185}], {
             RGBColor[
             0.20341836522778634`, 0.3311359776966468, 0.9348957470179945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 190}], {
             RGBColor[
             0.21321988075352158`, 0.3414379919661722, 0.9354539288271424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 252}], {
             RGBColor[
             0.2101141940866254, 0.33817371836735655`, 0.9352770645659143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 270}], {
             RGBColor[
             0.21111604747539212`, 0.339226729800124, 0.9353341186342953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 274}], {
             RGBColor[
             0.20871345876417752`, 0.33670145673171487`, 0.935197294761503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 288}], {
             RGBColor[
             0.21401051896422651`, 0.342269002854981, 0.9354989545035975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 318}], {
             RGBColor[
             0.2138717930117836, 0.3421231930832301, 0.9354910542658326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 168}], {
             RGBColor[
             0.18992658867508105`, 0.3169552651117129, 0.9341274103026127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 238}], {
             RGBColor[
             0.19138550303315327`, 0.3184886766025597, 0.9342104933170345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 379}], {
             RGBColor[
             0.18217848519657132`, 0.30881151709766497`, 0.9336861672718034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 236}], {
             RGBColor[
             0.3888676051713017, 0.5059520744556105, 0.9465593917911999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 262}], {
             RGBColor[
             0.31621623896980977`, 0.44455427693598626`, 0.9415075983220833]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 265}], {
             RGBColor[
             0.23354789403514828`, 0.36280402279564555`, 0.9366115791109302]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 297}], {
             RGBColor[
             0.28232965171394053`, 0.4140767430581329, 0.9393896280445941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 325}], {
             RGBColor[
             0.25318562671626305`, 0.38344452494766296`, 0.9377299189356977]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 376}], {
             RGBColor[
             0.2771391258654599, 0.4086211712930332, 0.939094035276218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 397}], {
             RGBColor[
             0.3161394186740798, 0.4444877390569253, 0.9415027034007689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 176}], {
             RGBColor[
             0.18652655830038561`, 0.3133816176135313, 0.933933783602668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 205}], {
             RGBColor[
             0.18600119174785296`, 0.31282942405665615`, 0.9339038647547113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 232}], {
             RGBColor[
             0.18860427170948546`, 0.315565426141134, 0.9340521063076146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 277}], {
             RGBColor[
             0.18598156789951187`, 0.3128087981478258, 0.9339027472055792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 373}], {
             RGBColor[
             0.19241687464340246`, 0.3195727135576686, 0.9342692284044607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 390}], {
             RGBColor[
             0.19991574882843044`, 0.32745450578221735`, 0.9346962781957078]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 89}], {
             RGBColor[
             0.33131087657095276`, 0.4543117529947025, 0.9425908573941362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 120}], {
             RGBColor[
             0.42147179727410705`, 0.5394794198355211, 0.9480767881227974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 140}], {
             RGBColor[
             0.41837127081473313`, 0.5367938996534025, 0.947879225318494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 189}], {
             RGBColor[
             0.331784795723977, 0.4548098720727408, 0.9426178463888004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 195}], {
             RGBColor[
             0.42750707901937735`, 0.5447068775411936, 0.948461350938816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 233}], {
             RGBColor[
             0.7003634497191511, 0.7623012578281982, 0.9418757273882692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 255}], {
             RGBColor[
             0.40229233650521606`, 0.5228671349052352, 0.9468546898423349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 257}], {
             RGBColor[
             0.6999080745469857, 0.7619616397704058, 0.9426465587738788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 263}], {
             RGBColor[
             0.3661139704738488, 0.49089201133024934`, 0.9445728421053426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 336}], {
             RGBColor[
             0.33259846324686315`, 0.4556650882287947, 0.9426641835505155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 356}], {
             RGBColor[
             0.6878897223994248, 0.7529983724170004, 0.962990494071441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 359}], {
             RGBColor[
             0.3780427703410259, 0.5018633795124479, 0.9453095289294022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 360}], {
             RGBColor[
             0.5465756968337885, 0.6418389618053506, 0.9578331782484879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 389}], {
             RGBColor[
             0.7117595806289345, 0.7674543626326005, 0.720767374949669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 162}], {
             RGBColor[
             0.2137613905296329, 0.342007153074568, 0.9354847670077999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 183}], {
             RGBColor[
             0.21045489979042858`, 0.338531821664043, 0.935296467251717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 189}], {
             RGBColor[
             0.23269978806740765`, 0.361912609650526, 0.9365632807307278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 263}], {
             RGBColor[
             0.2670289628172794, 0.39799474890803455`, 0.93851827644727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 270}], {
             RGBColor[
             0.22008543635339983`, 0.34865412620301106`, 0.935844912061876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.22057742375863354`, 0.3491712361597149, 0.935872930016774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 291}], {
             RGBColor[
             0.2138432095506144, 0.34209315005324514`, 0.9354894264800044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 336}], {
             RGBColor[
             0.23351345559029374`, 0.36276782580657996`, 0.9366096178924429]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 359}], {
             RGBColor[
             0.2789577626844565, 0.40896611709023306`, 0.9392549632713296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 95}], {
             RGBColor[
             0.23140010342565426`, 0.3605465586872775, 0.936489265613091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 97}], {
             RGBColor[
             0.2570968896215246, 0.3875555102494842, 0.9379526595719574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.23037172884023532`, 0.35946567179528754`, 0.9364307012017953]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 228}], {
             RGBColor[
             0.21978849971833822`, 0.34834202697269134`, 0.9358280019597877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 246}], {
             RGBColor[
             0.21613530957472, 0.3445022925061154, 0.9356199581855191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 260}], {
             RGBColor[
             0.20225002842194761`, 0.32990798163687834`, 0.9348292119653014]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 326}], {
             RGBColor[
             0.22857029923452804`, 0.35757225506245527`, 0.9363281124507266]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 172}], {
             RGBColor[
             0.48609962486048197`, 0.5916756169176496, 0.9532395671401708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 192}], {
             RGBColor[
             0.4254211791359827, 0.5344518171008017, 0.9495440785539795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 208}], {
             RGBColor[
             0.4434969579662055, 0.5534506067219376, 0.9505734674176423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 221}], {
             RGBColor[
             0.48124384050183955`, 0.5874697805650118, 0.9529301608546397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 256}], {
             RGBColor[
             0.792439933021371, 0.8356021745450866, 0.869137935086701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 316}], {
             RGBColor[
             0.6523585861658432, 0.7275841393423603, 0.9665060682236928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 351}], {
             RGBColor[
             0.45106536887988224`, 0.5613307052601594, 0.9510072153286632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 395}], {
             RGBColor[
             0.5156283955691132, 0.6172519539462964, 0.9551211142984581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 399}], {
             RGBColor[
             0.4759758631677278, 0.5829069233744436, 0.9525944899971995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 98}], {
             RGBColor[
             0.19880960071600262`, 0.32629187398221465`, 0.9346332846971046]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 119}], {
             RGBColor[
             0.22208012665594387`, 0.3507506721816547, 0.9359585067237262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 130}], {
             RGBColor[
             0.2100169217474722, 0.33807147897148404`, 0.935271525050101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 143}], {
             RGBColor[
             0.20163694443753327`, 0.3292635914974891, 0.9347942977393655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 146}], {
             RGBColor[
             0.20174986693286398`, 0.32938228019978144`, 0.9348007285084208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 151}], {
             RGBColor[
             0.20599136961110498`, 0.33384036844141496`, 0.9350422758112056]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 158}], {
             RGBColor[
             0.19775538870657966`, 0.32518383031940923`, 0.9345732488827347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 186}], {
             RGBColor[
             0.20547576839988674`, 0.33329843887741967`, 0.9350129130849905]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 267}], {
             RGBColor[
             0.20096723062757926`, 0.3285596798209194, 0.9347561585286415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 306}], {
             RGBColor[
             0.21333519209183469`, 0.34155919149390046`, 0.9354604956372714]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 308}], {
             RGBColor[
             0.20860909712508957`, 0.3365917660321234, 0.9351913515205462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 346}], {
             RGBColor[
             0.2038983093069455, 0.33164042935405524`, 0.934923079123289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 348}], {
             RGBColor[
             0.2027372639690243, 0.3304200970893739, 0.9348569593089071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 354}], {
             RGBColor[
             0.20023581918524017`, 0.32779092002085713`, 0.9347145057290265]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 374}], {
             RGBColor[
             0.1940034937220554, 0.32124035080679264`, 0.9343595840137974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 131}], {
             RGBColor[
             0.5783198351360825, 0.6629059133309206, 0.9625766163950823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 142}], {
             RGBColor[
             0.4083441914838143, 0.5275430486662767, 0.9473966682274677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 188}], {
             RGBColor[
             0.3091689920495968, 0.43916314420292457`, 0.9410324534762535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 201}], {
             RGBColor[
             0.5041214136186714, 0.6049415425126292, 0.9551812111618987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 264}], {
             RGBColor[
             0.3012538452175734, 0.43084382303317337`, 0.9405816975735801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 273}], {
             RGBColor[
             0.433287316679902, 0.5477930013754455, 0.949360282412582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 281}], {
             RGBColor[
             0.3706399848182322, 0.4954514587674228, 0.944837829981916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 293}], {
             RGBColor[
             0.3283292569566383, 0.4588040328927261, 0.9421418278164828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 394}], {
             RGBColor[
             0.35007693853437594`, 0.4776407816051039, 0.9435275708558966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 204}], {
             RGBColor[
             0.1795232819748228, 0.3060207301619996, 0.9335349573763461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.18066543438157506`, 0.30722120475814135`, 0.9336000012662475]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 307}], {
             RGBColor[
             0.17906784709075121`, 0.30554203922260087`, 0.9335090210334537]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 324}], {
             RGBColor[
             0.18239675869616345`, 0.30904093638507546`, 0.9336985976246985]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 97}], {
             RGBColor[
             0.27292796870059677`, 0.4041949781099764, 0.9388542161055278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 148}], {
             RGBColor[
             0.2518920934922597, 0.3820849395144922, 0.9376562541322015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 166}], {
             RGBColor[
             0.24620280791930751`, 0.37610513965577974`, 0.9373322577353658]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 169}], {
             RGBColor[
             0.3522449518778092, 0.4737241407933565, 0.9439035250794346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 228}], {
             RGBColor[
             0.2356195787974104, 0.36498149483318354`, 0.9367295584933581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 246}], {
             RGBColor[
             0.23196638865379215`, 0.3611417603666076, 0.9365215147190895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 276}], {
             RGBColor[
             0.3131382201938357, 0.4399588551912694, 0.9413821143478849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 282}], {
             RGBColor[
             0.2811273621289757, 0.41223265884799526`, 0.9393424107780823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 305}], {
             RGBColor[
             0.2726453120788769, 0.4038978880790839, 0.9388381192290738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 326}], {
             RGBColor[
             0.24440137831360023`, 0.3742117229229475, 0.9372296689842969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 361}], {
             RGBColor[
             0.32840262007179855`, 0.45318011115451534`, 0.9423547484103298]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 382}], {
             RGBColor[
             0.2846635750266093, 0.4152955487246973, 0.9395677351369693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 104}], {
             RGBColor[
             0.21783923349947054`, 0.34629322458604483`, 0.935716994132304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 182}], {
             RGBColor[
             0.2267284521296566, 0.35563635697538404`, 0.9362232219828728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 187}], {
             RGBColor[
             0.2139882194822336, 0.34224556468553763`, 0.9354976845810872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 208}], {
             RGBColor[
             0.25302363918053994`, 0.383274265777015, 0.9377206939851772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 225}], {
             RGBColor[
             0.21005566506834547`, 0.33811220065819025`, 0.9352737314249091]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 261}], {
             RGBColor[
             0.20041641876701294`, 0.3279807416319751, 0.9347247906080353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 377}], {
             RGBColor[
             0.23316169487877575`, 0.36239810299585723`, 0.9365895856403053]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 388}], {
             RGBColor[
             0.24120538255957147`, 0.37085252874762864`, 0.937047661754157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 166}], {
             RGBColor[
             0.27189959411517783`, 0.40311409121798647`, 0.9387956516942321]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 169}], {
             RGBColor[
             0.37794173807367953`, 0.5007330923555633, 0.945366919038301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 224}], {
             RGBColor[
             0.3981861519254275, 0.5171684195208632, 0.946960633454442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 246}], {
             RGBColor[
             0.2576631748496625, 0.38815071192881434`, 0.9379849086779559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 276}], {
             RGBColor[
             0.33883500638970604`, 0.46696780675347616`, 0.9428455083067513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 326}], {
             RGBColor[
             0.27009816450947055`, 0.40122067448515425`, 0.9386930629431633]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 363}], {
             RGBColor[
             0.3365752811245841, 0.4650105463059218, 0.9427015206110543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 382}], {
             RGBColor[
             0.3103603612224796, 0.44230450028690405`, 0.9410311290958356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 383}], {
             RGBColor[
             0.32847115554353346`, 0.45799116005281093`, 0.9421851328952267]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 393}], {
             RGBColor[
             0.5102982570407728, 0.6069665111134733, 0.9566203329382144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 134}], {
             RGBColor[
             0.1861818864522268, 0.313019345647659, 0.9339141550508117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 143}], {
             RGBColor[
             0.19607611547037074`, 0.3234188076760809, 0.9344776167561948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 151}], {
             RGBColor[
             0.20043054064394245`, 0.3279955846200067, 0.934725594828035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 158}], {
             RGBColor[
             0.19219455973941713`, 0.31933904649800093`, 0.9342565678995641]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 163}], {
             RGBColor[
             0.18615149755953203`, 0.3129874049946697, 0.933912424448329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.1906510637312114, 0.3177167343300775, 0.9341686680852945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 186}], {
             RGBColor[
             0.1999149394327242, 0.32745365505601143`, 0.9346962321018197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 240}], {
             RGBColor[
             0.18629079266231832`, 0.3131338129795177, 0.9339203570983641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 272}], {
             RGBColor[
             0.1949500622314218, 0.3222352543260466, 0.9344134896900831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 306}], {
             RGBColor[
             0.20777436312467215`, 0.33571440767249217`, 0.9351438146541007]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 308}], {
             RGBColor[
             0.20304826815792704`, 0.3307469822107151, 0.9348746705373756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 342}], {
             RGBColor[
             0.1898214409282245, 0.31684474816301444`, 0.9341214222939813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 348}], {
             RGBColor[
             0.19717643500186177`, 0.3245753132679656, 0.9345402783257364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 354}], {
             RGBColor[
             0.19467499021807763`, 0.3219461361994489, 0.9343978247458558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 374}], {
             RGBColor[
             0.18844266475489285`, 0.3153955669853844, 0.9340429030306268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 378}], {
             RGBColor[
             0.21674290293340537`, 0.34514091164973765`, 0.9356545597284425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 144}], {
             RGBColor[
             0.7417116613175341, 0.797878300210745, 0.9753542230915366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 169}], {
             RGBColor[
             0.6797124063510102, 0.7475445119943138, 0.9704734146298177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[
             0.7312212189545854, 0.7893616865114603, 0.9745283770409688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 222}], {
             RGBColor[
             0.9266267914902193, 0.9439342403679507, 0.9791054495248444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 223}], {
             RGBColor[
             0.8806912086429535, 0.689221405037725, 0.5973847957056915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 276}], {
             RGBColor[
             0.6406056746670367, 0.7137792263922267, 0.9679520038982681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 361}], {
             RGBColor[
             0.6558700745449995, 0.7270004823554725, 0.968924637960713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 382}], {
             RGBColor[
             0.6121310294998102, 0.6891159199256546, 0.9661376246873524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 384}], {
             RGBColor[
             0.9178754148881313, 0.8496097092612407, 0.6279747633092586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 393}], {
             RGBColor[
             0.8120689253181035, 0.8537779307522239, 0.9817268285297311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 157}], {
             RGBColor[
             0.31728677632069113`, 0.4435179334056334, 0.9416477086340886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 167}], {
             RGBColor[
             0.3117593370391954, 0.4377082442608893, 0.941332929144121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 174}], {
             RGBColor[
             0.4027739307357637, 0.5232842676221057, 0.9468853766008484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 198}], {
             RGBColor[
             0.6082548805926754, 0.6882816237042615, 0.9647291510065205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 203}], {
             RGBColor[
             0.3488608742001085, 0.47658748779993204`, 0.9434500843118405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 206}], {
             RGBColor[
             0.40830029738828666`, 0.5280709286532568, 0.947237511797173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 211}], {
             RGBColor[
             0.31010062158634694`, 0.43596482915131163`, 0.941238467752931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 266}], {
             RGBColor[
             0.5229669528809726, 0.6215828095678126, 0.9562473514884939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 341}], {
             RGBColor[
             0.3185278490681524, 0.4448223795517722, 0.9417183858910539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 358}], {
             RGBColor[
             0.33265464447686266`, 0.4596705372168882, 0.942522885990859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 115}], {
             RGBColor[
             0.9045408089975616, 0.6377980714511916, 0.24102778506069641`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 123}], {
             RGBColor[
             0.8485657793755872, 0.374303438706794, 0.1941399512182521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 161}], {
             RGBColor[
             0.8667600435785252, 0.4809006664576717, 0.21026073973276477`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 193}], {
             RGBColor[
             0.8459509404020927, 0.6447383034706259, 0.5918610769410064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 253}], {
             RGBColor[
             0.8395830715203696, 0.3052584098839103, 0.18553810003157822`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 283}], {
             RGBColor[
             0.8929481444706848, 0.5918370196285758, 0.23170005506756156`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 332}], {
             RGBColor[
             0.8358893322460044, 0.27686671121426787`, 0.18200097113096422`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 334}], {
             RGBColor[
             0.9070926668350056, 0.6466589621982325, 0.24962429328823976`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 356}], {
             RGBColor[
             0.8996786533554004, 0.687329585228627, 0.5883270956947237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 364}], {
             RGBColor[
             0.8876560448428017, 0.5708556080916793, 0.22744190748542303`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 366}], {
             RGBColor[
             0.9236369022984421, 0.7019746342428002, 0.3557247602566589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 380}], {
             RGBColor[
             0.787177962650946, 0.5986793707999881, 0.5860416238148101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 389}], {
             RGBColor[
             0.9235485115849101, 0.701785575444227, 0.3461039765729519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 108}], {
             RGBColor[
             0.3276991764172302, 0.45803801914073383`, 0.9421097447928497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 139}], {
             RGBColor[
             0.3279891561400408, 0.4583428062151842, 0.9421262587090772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 213}], {
             RGBColor[
             0.33722405994131943`, 0.4665082641722599, 0.9427085967973012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 297}], {
             RGBColor[
             0.32279739953618347`, 0.45288594084814915`, 0.9418305958510031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 333}], {
             RGBColor[
             0.6514056454646207, 0.7208926458479099, 0.9532948082895194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 337}], {
             RGBColor[
             0.6530069899856277, 0.722086925969716, 0.9505841497129952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 345}], {
             RGBColor[
             0.5885592438891699, 0.6712468009440402, 0.9634628617416172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 350}], {
             RGBColor[
             0.3487900132261258, 0.4765261115858444, 0.9434455691132382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 378}], {
             RGBColor[
             0.29463589617818253`, 0.42328641527644917`, 0.9402268398959757]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 122}], {
             RGBColor[
             0.1920779072643653, 0.3192164373505274, 0.9342499247136817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 295}], {
             RGBColor[
             0.1903453971129866, 0.3173954593339403, 0.9341512608235798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 145}], {
             RGBColor[
             0.2369611402467977, 0.36639156097639836`, 0.9368059584332384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 170}], {
             RGBColor[
             0.22977658578143667`, 0.35884013870624076`, 0.936396808685032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 182}], {
             RGBColor[
             0.23293840827128548`, 0.36216341461419643`, 0.9365768697983317]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 187}], {
             RGBColor[
             0.2201981756238625, 0.34877262232435, 0.935851332396546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 192}], {
             RGBColor[
             0.24115781649194606`, 0.3708025337946915, 0.9370449529369735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 208}], {
             RGBColor[
             0.25923359532216883`, 0.3898013234158274, 0.9380743418006362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 225}], {
             RGBColor[
             0.2162656212099744, 0.3446392582970026, 0.935627379240368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 235}], {
             RGBColor[
             0.20864915250350596`, 0.3366338667744967, 0.9351936326150905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 261}], {
             RGBColor[
             0.20662637490864183`, 0.3345077992707875, 0.9350784384234943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 327}], {
             RGBColor[
             0.20490625211316982`, 0.332699841150662, 0.9349804799749857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 335}], {
             RGBColor[
             0.21115674634682685`, 0.33926950689445945`, 0.9353364363748149]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 349}], {
             RGBColor[
             0.21123195753513827`, 0.3393485586220395, 0.9353407195407242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 351}], {
             RGBColor[
             0.26680200623584566`, 0.3976814219540492, 0.9385080897116571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 355}], {
             RGBColor[
             0.21609483282429037`, 0.34445974887503966`, 0.9356176530944622]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 199}], {
             RGBColor[
             0.9870190215241651, 0.9889000460513815, 0.8647919372474027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 215}], {
             RGBColor[
             0.8456866310237973, 0.8792487049970009, 0.932290412064394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 259}], {
             RGBColor[
             0.9403634558512834, 0.9538207185775788, 0.9415651020124101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 271}], {
             RGBColor[
             0.9026525217316504, 0.5714728168582255, 0.530015287474555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 287}], {
             RGBColor[
             0.9013106453354156, 0.5611585668627788, 0.528730305122088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 303}], {
             RGBColor[
             0.9396161743909813, 0.7997165627600418, 0.5632237947654809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 333}], {
             RGBColor[
             0.969539411680839, 0.9766186640035739, 0.9281855313871071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 337}], {
             RGBColor[
             0.9711407562018461, 0.97781294412538, 0.9254748728105828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 345}], {
             RGBColor[
             0.9066930101053883, 0.9269728190997042, 0.9383535848392048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 350}], {
             RGBColor[
             0.6669237794423443, 0.7322521297415084, 0.9183362922108259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 353}], {
             RGBColor[
             0.9892810453920724, 0.988090926321853, 0.7004958160747115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 400}], {
             RGBColor[
             0.9037087544899305, 0.5795914846825118, 0.5310267371567282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 197}], {
             RGBColor[
             0.18891531916432497`, 0.315892356737718, 0.9340698200000144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 217}], {
             RGBColor[
             0.1973830107710603, 0.32479243749905357`, 0.9345520425101908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 231}], {
             RGBColor[
             0.1888628748467801, 0.31583723443481654`, 0.9340668333737145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 254}], {
             RGBColor[
             0.18679837373704838`, 0.3136673128715579, 0.9339492630896711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 314}], {
             RGBColor[
             0.18463641563674799`, 0.3113949578320815, 0.9338261427741893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 369}], {
             RGBColor[
             0.18346224485360668`, 0.3101608298922725, 0.9337592754851194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 124}], {
             RGBColor[
             0.22484989821780513`, 0.3536618777068309, 0.9361162411166642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 150}], {
             RGBColor[
             0.23074389884075946`, 0.35985684606277935`, 0.936451895732749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 152}], {
             RGBColor[
             0.2119625047523057, 0.3401164100666513, 0.9353823231239942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.2124764155335251, 0.34065656288153834`, 0.9354115895827217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.2349712471793796, 0.36430005719603437`, 0.936692636966832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 160}], {
             RGBColor[
             0.20918830325598364`, 0.33720054839948277`, 0.935224336452842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 167}], {
             RGBColor[
             0.22944380789788385`, 0.3584903680512903, 0.9363778574768644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.2249471629490288, 0.3537641091062871, 0.9361217801992172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 181}], {
             RGBColor[
             0.20760170595158578`, 0.3355329340364814, 0.935133982083517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 211}], {
             RGBColor[
             0.2277850924450354, 0.3567469529417126, 0.9362833960856742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 238}], {
             RGBColor[
             0.21198166691675951`, 0.34013655071644366`, 0.9353834143809119]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 245}], {
             RGBColor[
             0.20898762068619692`, 0.33698961829462715`, 0.9352129078773759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 386}], {
             RGBColor[
             0.2825040137132291, 0.4111922082727934, 0.9395118848995476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 297}], {
             RGBColor[
             0.30146181771501923`, 0.43418586257465347`, 0.9404791765948524]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 325}], {
             RGBColor[
             0.2723177927173417, 0.4035536444641835, 0.9388194674859559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 376}], {
             RGBColor[
             0.29627129186653856`, 0.4287302908095537, 0.9401835838264763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 378}], {
             RGBColor[
             0.2733003143570183, 0.40458633700295354`, 0.938875420639825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 397}], {
             RGBColor[
             0.3352715846751584, 0.4645968585734458, 0.9425922519510271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 114}], {
             RGBColor[
             0.18471405231964982`, 0.3114765589082613, 0.9338305640684275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 132}], {
             RGBColor[
             0.1878121680467173, 0.3147328749692917, 0.9340069971758325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 180}], {
             RGBColor[
             0.18558731783868732`, 0.3123944163370016, 0.933880295247856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 232}], {
             RGBColor[
             0.18655512715268852`, 0.3134116452886715, 0.9339354105565427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 249}], {
             RGBColor[
             0.18318613987214505`, 0.3098706260506894, 0.9337435517148859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 370}], {
             RGBColor[
             0.18414849826566793`, 0.3108821257393283, 0.9337983566017154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 111}], {
             RGBColor[
             0.8397873767221564, 0.5455755079920095, 0.5794773016000505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 117}], {
             RGBColor[
             0.7057471364084966, 0.7690367194392469, 0.9721131675946504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 202}], {
             RGBColor[
             0.590277084299675, 0.6718791600205865, 0.9639661767270546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 212}], {
             RGBColor[
             0.715371093239261, 0.7768498811487758, 0.9728708007300837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 239}], {
             RGBColor[
             0.6800499902731076, 0.7481746185632971, 0.9700901941191247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 247}], {
             RGBColor[
             0.8351507068562677, 0.5099360316010974, 0.5750372213001058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 269}], {
             RGBColor[
             0.6031830035578256, 0.6830576186116337, 0.9647885304899277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 287}], {
             RGBColor[
             0.8351408344121083, 0.5098601476691562, 0.5750277674364295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 289}], {
             RGBColor[
             0.6635885313279589, 0.7348104646113509, 0.9687942877706517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 292}], {
             RGBColor[
             0.8362272767124428, 0.5182110192715781, 0.5760681458101908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 303}], {
             RGBColor[
             0.873446363467674, 0.7484181435664192, 0.6095212570798225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 309}], {
             RGBColor[
             0.7751646817101416, 0.8245503622153614, 0.9781540938970312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 362}], {
             RGBColor[
             0.8221167873663267, 0.8612297040031928, 0.982833840996466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 385}], {
             RGBColor[
             0.923690126192328, 0.9380306979900004, 0.809802069993292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 400}], {
             RGBColor[
             0.8375389435666232, 0.5282930654888892, 0.5773241994710698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 199}], {
             RGBColor[
             0.9076739184987976, 0.597583839511456, 0.5047291662889358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 222}], {
             RGBColor[
             0.8888497880747033, 0.5842997162159619, 0.5703986830647514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 223}], {
             RGBColor[
             0.8429142052274374, 0.3295868808857362, 0.18867802924559862`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 247}], {
             RGBColor[
             0.8219754147542075, 0.16991824425479435`, 0.1686769880272973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 271}], {
             RGBColor[
             0.823307418706283, 0.18015661031829988`, 0.16995251651608806`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 287}], {
             RGBColor[
             0.8219655423100481, 0.16984236032285321`, 0.168667534163621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 292}], {
             RGBColor[
             0.8230519846103825, 0.1781932319252751, 0.16970791253738232`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 309}], {
             RGBColor[
             0.7619893896080814, 0.48453257486905843`, 0.5717938606242228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 319}], {
             RGBColor[
             0.8295282339464709, 0.2279725222330049, 0.17590957621549802`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 362}], {
             RGBColor[
             0.8089414952642664, 0.5212119166568898, 0.5764736077236575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 385}], {
             RGBColor[
             0.9105148340902678, 0.5980129106436974, 0.4034418367204835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[
             0.8243636514645629, 0.1882752781425862, 0.17096396619826132`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 177}], {
             RGBColor[
             0.18091855533538903`, 0.3074872509293952, 0.9336144161301083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 219}], {
             RGBColor[
             0.17968380010062157`, 0.30618944488965105`, 0.933544098646145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 248}], {
             RGBColor[
             0.18167669359362687`, 0.3082841023075451, 0.9336575909823499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 251}], {
             RGBColor[
             0.18268323345773074`, 0.30934203952303163`, 0.9337149119385684]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 260}], {
             RGBColor[
             0.18468581634927816`, 0.3114468811131368, 0.9338289560716861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 162}], {
             RGBColor[
             0.19047273002269705`, 0.31752929429541876`, 0.9341585122444157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 183}], {
             RGBColor[
             0.18716623928349274`, 0.31405396288489373`, 0.9339702124883327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 270}], {
             RGBColor[
             0.196796775846464, 0.3241762674238618, 0.9345186572984918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 357}], {
             RGBColor[
             0.18582607626581804`, 0.31264536658207454`, 0.9338938921870696]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 368}], {
             RGBColor[
             0.18474082389280244`, 0.3115046975290605, 0.9338320886699134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 132}], {
             RGBColor[
             0.1897759122485969, 0.31679689463404087`, 0.9341188295030303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 155}], {
             RGBColor[
             0.18628873221551898`, 0.3131316473192917, 0.933920239758967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 180}], {
             RGBColor[
             0.18755106204056693`, 0.3144584360017507, 0.9339921275750538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 249}], {
             RGBColor[
             0.18514988407402466`, 0.3119346457154385, 0.9338553840420838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 268}], {
             RGBColor[
             0.18716896902427724`, 0.3140568320155338, 0.9339703679430321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 279}], {
             RGBColor[
             0.19285735565451845`, 0.32003568702846064`, 0.9342943131464105]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 299}], {
             RGBColor[
             0.1875337477163088, 0.31444023754916384`, 0.9339911415499016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 300}], {
             RGBColor[
             0.19141939910096473`, 0.3185243035189643, 0.9342124236479517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 370}], {
             RGBColor[
             0.18611224246754757`, 0.3129461454040774, 0.9339101889289132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 123}], {
             RGBColor[
             0.8991328422336753, 0.5962300691178152, 0.23584910998017405`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 161}], {
             RGBColor[
             0.9173271064366133, 0.7028272968686928, 0.25196989849468676`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 193}], {
             RGBColor[
             0.8965180032601808, 0.866664933881647, 0.6335702357029284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 195}], {
             RGBColor[
             0.6898630728334411, 0.7009647207638414, 0.6155071113240207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 214}], {
             RGBColor[
             0.917014626987943, 0.7014084006737106, 0.2517091579831441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 253}], {
             RGBColor[
             0.8901501343784577, 0.5271850402949314, 0.22724725879350022`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 257}], {
             RGBColor[
             0.9622640683610495, 0.9182194829930534, 0.6096923191590835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 283}], {
             RGBColor[
             0.9435152073287729, 0.813763650039597, 0.2734092138294835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 312}], {
             RGBColor[
             0.7514622050621471, 0.7517529361696669, 0.6201411074573389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 332}], {
             RGBColor[
             0.8864563951040925, 0.498793341625289, 0.2237101298928862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 334}], {
             RGBColor[
             0.9576597296930937, 0.8685855926092536, 0.2913334520501617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 356}], {
             RGBColor[
             0.9502457162134885, 0.9092562156396481, 0.6300362544566458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 360}], {
             RGBColor[
             0.8089316906478522, 0.7980968050279984, 0.6248789386336926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 364}], {
             RGBColor[
             0.9382231077008898, 0.7927822385027005, 0.26915106624734497`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 366}], {
             RGBColor[
             0.9742039651565302, 0.9239012646538212, 0.3974339190185809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 380}], {
             RGBColor[
             0.8377450255090341, 0.8206060012110092, 0.627750782576732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 389}], {
             RGBColor[
             0.9741155744429982, 0.9237122058552483, 0.3878131353348738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 141}], {
             RGBColor[
             0.29789401265983945`, 0.4260884769462017, 0.9404351748499746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 179}], {
             RGBColor[
             0.23341719737643146`, 0.3626666523206874, 0.9366041361295647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 209}], {
             RGBColor[
             0.2525333735524159, 0.38275896551722044`, 0.9376927740829386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 286}], {
             RGBColor[
             0.28063230469456346`, 0.41113725310534854`, 0.9393352740823563]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 290}], {
             RGBColor[
             0.24877546734729164`, 0.3788091678306199, 0.9374787668838809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 304}], {
             RGBColor[
             0.26114585574207083`, 0.3918112303614577, 0.938183242202614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 338}], {
             RGBColor[
             0.22507866009155236`, 0.35390232094047974`, 0.9361292687669514]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 239}], {
             RGBColor[
             0.5328344578573876, 0.6316180426642315, 0.9563658268409162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 269}], {
             RGBColor[
             0.45596747114210545`, 0.5665010427125681, 0.9510641632117192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 309}], {
             RGBColor[
             0.6279491492944215, 0.7079937863162957, 0.9644297266188226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 323}], {
             RGBColor[
             0.4895767347577772, 0.5956116976057565, 0.9532057157698048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 362}], {
             RGBColor[
             0.6749012549506066, 0.7446731281041272, 0.9691094737182575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 365}], {
             RGBColor[
             0.4322742926857367, 0.5457268859697086, 0.94956369337159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 377}], {
             RGBColor[
             0.40661285819624315`, 0.5187550912923315, 0.9481023126401036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 385}], {
             RGBColor[
             0.776474593776608, 0.8214741220909348, 0.7960777027150834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 388}], {
             RGBColor[
             0.4146565458770389, 0.527209517044103, 0.9485603887539554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 395}], {
             RGBColor[
             0.49860624010091514`, 0.6034326012978481, 0.9537810678657916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 124}], {
             RGBColor[
             0.29203302591126107`, 0.41977282835890883`, 0.9401070895447208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[
             0.35660710592589273`, 0.4832968843838794, 0.9439436673476838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 150}], {
             RGBColor[
             0.29792702653421543`, 0.4259677967148573, 0.9404427441608055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 179}], {
             RGBColor[
             0.29213029064248475`, 0.4198750597583651, 0.9401126286272736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 196}], {
             RGBColor[
             0.6007859963931654, 0.6812853787799371, 0.9644958808837701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 206}], {
             RGBColor[
             0.39316789594043106`, 0.5149640030957358, 0.9462732885579729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 209}], {
             RGBColor[
             0.3112464668184692, 0.43996737295489813`, 0.9412012665806477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 286}], {
             RGBColor[
             0.33934539796061675`, 0.46834566054302623`, 0.9428437665800653]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 386}], {
             RGBColor[
             0.34968714140668505`, 0.4773031589248714, 0.9435027333276041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 128}], {
             RGBColor[
             0.2718458799395796, 0.4030576342137573, 0.9387925927513947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 130}], {
             RGBColor[
             0.2277266187202509, 0.3566854933495158, 0.936280066093552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 135}], {
             RGBColor[
             0.2875725376828968, 0.4171271414972289, 0.9397782828791128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 146}], {
             RGBColor[
             0.2194595639056427, 0.3479962945778132, 0.9358092695518716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 151}], {
             RGBColor[
             0.22370106658388367`, 0.35245438281944674`, 0.9360508168546565]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 213}], {
             RGBColor[
             0.2826015926364835, 0.4128215587449884, 0.9394615386563896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 227}], {
             RGBColor[
             0.25689083303762017`, 0.3873389317150586, 0.9379409249543373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 243}], {
             RGBColor[
             0.23559188807996673`, 0.3649523901334573, 0.9367279815479644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 267}], {
             RGBColor[
             0.21867692760035795`, 0.34717369419895117`, 0.9357646995720923]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 306}], {
             RGBColor[
             0.2310448890646134, 0.36017320587193224`, 0.9364690366807222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 311}], {
             RGBColor[
             0.22119300122602184`, 0.3498182471078057, 0.9359079862428765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 344}], {
             RGBColor[
             0.2156761634002051, 0.3440197007651513, 0.9355938104901265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 346}], {
             RGBColor[
             0.2216080062797242, 0.35025444373208703`, 0.9359316201667398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 350}], {
             RGBColor[
             0.2941675459212899, 0.42283940615857285`, 0.9401985109723265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 354}], {
             RGBColor[
             0.21794551615801888`, 0.3464049343988889, 0.9357230467724773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 140}], {
             RGBColor[
             0.409447183861318, 0.5290643040720063, 0.9473105903890827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 147}], {
             RGBColor[
             0.3298813986080268, 0.4544594666479659, 0.9424490293594527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 193}], {
             RGBColor[
             0.6252379224927019, 0.7026774950776031, 0.9659558403883122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 195}], {
             RGBColor[
             0.41858299206596217`, 0.5369772819597975, 0.9478927160094046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 241}], {
             RGBColor[
             0.34672955885014695`, 0.4721679512974918, 0.9434085071606221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 242}], {
             RGBColor[
             0.3764731339021319, 0.500503839321299, 0.9452095130834909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 255}], {
             RGBColor[
             0.39336824955180094`, 0.5151375393238391, 0.9462860549129236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 263}], {
             RGBColor[
             0.3571898835204337, 0.4831624157488532, 0.9440042071759314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 312}], {
             RGBColor[
             0.4801821242946682, 0.587765497365623, 0.9525267121427227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 331}], {
             RGBColor[
             0.3267582826576653, 0.45117687376714777`, 0.9422711725263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 356}], {
             RGBColor[
             0.6789656354460096, 0.7452687768356042, 0.9624218591420297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 359}], {
             RGBColor[
             0.3691186833876108, 0.4941337839310517, 0.9447408939999908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 360}], {
             RGBColor[
             0.5376516098803733, 0.6341093662239545, 0.9572645433190765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 380}], {
             RGBColor[
             0.5664649447415552, 0.6566185624069654, 0.9601363872621158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 389}], {
             RGBColor[
             0.7028354936755193, 0.7597247670512044, 0.7201987400202577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[
             0.2188856606362972, 0.3473930858541622, 0.9357765866096961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 202}], {
             RGBColor[
             0.2856578369982738, 0.41583248159385067`, 0.9396429608971655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 234}], {
             RGBColor[
             0.2453302072944222, 0.37518798107295015`, 0.9372825644206755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 289}], {
             RGBColor[
             0.3589692840265578, 0.4787637861846151, 0.9444710719407625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 298}], {
             RGBColor[
             0.2245949434093795, 0.353393904038107, 0.9361017218174963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 173}], {
             RGBColor[
             0.18447873947082444`, 0.3112292301844495, 0.9338171633498009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 338}], {
             RGBColor[
             0.19975108063826336`, 0.32728142907378543`, 0.9346869005858826]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 161}], {
             RGBColor[
             0.861352076814639, 0.4393326641242953, 0.20508206465224244`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 196}], {
             RGBColor[
             0.8436412079731275, 0.6056407490965849, 0.5869779142171753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 214}], {
             RGBColor[
             0.8610395973659686, 0.437913767929313, 0.20482132414069976`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 253}], {
             RGBColor[
             0.8341751047564834, 0.26369040755053386`, 0.1803594249510559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 283}], {
             RGBColor[
             0.8875401777067986, 0.5502690172951994, 0.2265213799870392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 332}], {
             RGBColor[
             0.8304813654821182, 0.2352987088808914, 0.17682229605044186`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 334}], {
             RGBColor[
             0.9016847000711192, 0.6050909598648562, 0.2444456182077174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 356}], {
             RGBColor[
             0.8942706865915142, 0.6457615828952505, 0.5831484206142015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 364}], {
             RGBColor[
             0.8822480780789155, 0.5292876057583029, 0.22226323240490067`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 366}], {
             RGBColor[
             0.9182289355345559, 0.6604066319094237, 0.35054608517613656`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 389}], {
             RGBColor[
             0.9181405448210238, 0.6602175731108506, 0.3409253014924295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 150}], {
             RGBColor[
             0.2325126629936997, 0.36171592933364405`, 0.9365526242346068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 152}], {
             RGBColor[
             0.2137312689052459, 0.34197549333751603`, 0.935483051625852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 156}], {
             RGBColor[
             0.21424517968646528`, 0.3425156461524031, 0.9355123180845796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 157}], {
             RGBColor[
             0.2367400113323198, 0.3661591404668991, 0.9367933654686897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 160}], {
             RGBColor[
             0.21095706740892387`, 0.3390596316703475, 0.9353250649546998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 167}], {
             RGBColor[
             0.23121257205082407`, 0.360349451322155, 0.9364785859787222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 179}], {
             RGBColor[
             0.22671592710196903`, 0.3556231923771518, 0.9362225087010749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 181}], {
             RGBColor[
             0.209370470104526, 0.33739201730734614`, 0.9352347105853747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 238}], {
             RGBColor[
             0.21375043106969976`, 0.3419956339873084, 0.9354841428827698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 245}], {
             RGBColor[
             0.21075638483913717`, 0.33884870156549185`, 0.9353136363792337]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 386}], {
             RGBColor[
             0.28427277786616933`, 0.41305129154365816`, 0.9396126134014054]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 184}], {
             RGBColor[
             0.20307558723579205`, 0.3307756962936808, 0.934876226318445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 185}], {
             RGBColor[
             0.1925739180479394, 0.31973777613296384`, 0.9342781717940241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 190}], {
             RGBColor[
             0.20237543357367466`, 0.3300397904024893, 0.934836353603172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 226}], {
             RGBColor[
             0.1922514050569324, 0.3193987945309108, 0.9342598051563016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 252}], {
             RGBColor[
             0.19926974690677848`, 0.32677551680367367`, 0.934659489341944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 274}], {
             RGBColor[
             0.19786901158433057`, 0.32530325516803194`, 0.9345797195375327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 288}], {
             RGBColor[
             0.2031660717843796, 0.3308708012912981, 0.9348813792796271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 318}], {
             RGBColor[
             0.20302734583193666`, 0.33072499151954715`, 0.9348734790418622]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 176}], {
             RGBColor[
             0.18438193895865332`, 0.3111274867086507, 0.9338116507038363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 205}], {
             RGBColor[
             0.18385657240612066`, 0.31057529315177557`, 0.9337817318558796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 298}], {
             RGBColor[
             0.194012535572622, 0.32124985436502457`, 0.9343600989338109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 320}], {
             RGBColor[
             0.18313368370358218`, 0.3098154912916167, 0.9337405644136882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 347}], {
             RGBColor[
             0.18344187738111917`, 0.31013942238731573`, 0.9337581155876922]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 373}], {
             RGBColor[
             0.19027225530167013`, 0.317318582652788, 0.934147095505629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 137}], {
             RGBColor[
             0.31600670483300364`, 0.4466421785419929, 0.9414111535240912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 138}], {
             RGBColor[
             0.31413697275722113`, 0.44467697158248487`, 0.9413046750483962]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 193}], {
             RGBColor[
             0.5886484429999097, 0.6709855269816585, 0.9636243911098379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 210}], {
             RGBColor[
             0.29252473138981117`, 0.4219611356100898, 0.9400738898749681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 242}], {
             RGBColor[
             0.33988365440933965`, 0.4688118712253543, 0.9428780638050165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 255}], {
             RGBColor[
             0.35677877005900877`, 0.4834455712278943, 0.9439546056344492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 258}], {
             RGBColor[
             0.2885106861095953, 0.4177421195154126, 0.9398452959345076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 264}], {
             RGBColor[
             0.2996738393944105, 0.42947530140255136`, 0.9404810209996725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 312}], {
             RGBColor[
             0.44359264480187605`, 0.5560735292696781, 0.9501952628642483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 328}], {
             RGBColor[
             0.2853602010040631, 0.41443075991720546`, 0.9396658804684725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 331}], {
             RGBColor[
             0.29016880316487315`, 0.419484905671203, 0.9399397232478413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 380}], {
             RGBColor[
             0.529875465248763, 0.6249265943110206, 0.9578049379836415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 394}], {
             RGBColor[
             0.348496932711213, 0.47627225997448197`, 0.9434268942819889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 130}], {
             RGBColor[
             0.2597826750311079, 0.39037844100358665`, 0.9381056110777697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 135}], {
             RGBColor[
             0.31962859399375376`, 0.45082008915129973`, 0.9416038278633306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 139}], {
             RGBColor[
             0.3054227451460619, 0.43834904844198347`, 0.9407047455523833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 151}], {
             RGBColor[
             0.2557571228947407, 0.38614733047351757`, 0.9378763618388744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 213}], {
             RGBColor[
             0.3146576489473405, 0.4465145063990592, 0.9412870836406073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 215}], {
             RGBColor[
             0.5049864538136, 0.6035289290681363, 0.9559781758101122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 224}], {
             RGBColor[
             0.40082474260241224`, 0.5199417456186857, 0.9471108972900512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 227}], {
             RGBColor[
             0.28894688934847723`, 0.42103187936912945`, 0.9397664699385552]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 243}], {
             RGBColor[
             0.26764794439082373`, 0.39864533778752814`, 0.9385535265321823]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 259}], {
             RGBColor[
             0.599663278641086, 0.6781009426487141, 0.9652528657581285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 306}], {
             RGBColor[
             0.2631009453754704, 0.39386615352600307`, 0.9382945816649401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 350}], {
             RGBColor[
             0.32622360223214686`, 0.4565323538126437, 0.9420240559565443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 383}], {
             RGBColor[
             0.3311097462205182, 0.46076448615063337`, 0.9423353967308358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 131}], {
             RGBColor[
             0.8167235345760251, 0.5021703426652091, 0.5741281307411844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 253}], {
             RGBColor[
             0.822264279381292, 0.17213858435985327`, 0.16895360512041946`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 271}], {
             RGBColor[
             0.8196694573268939, 0.15219364499147486`, 0.1664688005906955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 287}], {
             RGBColor[
             0.8183275809306592, 0.1418793949960282, 0.16518381823822845`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 303}], {
             RGBColor[
             0.8566331099862248, 0.3804373908932912, 0.19967730788162147`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 333}], {
             RGBColor[
             0.8865563472760825, 0.5573394921368233, 0.5646390445032476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 337}], {
             RGBColor[
             0.8881576917970897, 0.5585337722586294, 0.5619283859267235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 353}], {
             RGBColor[
             0.9062979809873158, 0.5688117544551025, 0.33694932919085196`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 364}], {
             RGBColor[
             0.8703372527037241, 0.4377357825676223, 0.21085741257426427`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 391}], {
             RGBColor[
             0.8197851875316053, 0.15308319805818565`, 0.1665796239654257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 135}], {
             RGBColor[
             0.27550933277442513`, 0.40444794828705827`, 0.9390913012054878]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 146}], {
             RGBColor[
             0.20739635899717102`, 0.3353171013676426, 0.9351222878782466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 151}], {
             RGBColor[
             0.211637861675412, 0.3397751896092761, 0.9353638351810314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 158}], {
             RGBColor[
             0.20340188077088672`, 0.3311186514872704, 0.9348948082525605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 227}], {
             RGBColor[
             0.24482762812914852`, 0.374659738504888, 0.9372539432807123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 243}], {
             RGBColor[
             0.22352868317149505`, 0.3522731969232867, 0.9360409998743393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 267}], {
             RGBColor[
             0.20661372269188627`, 0.33449450098878053`, 0.9350777178984673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 275}], {
             RGBColor[
             0.2049038205781411, 0.33269728545317867`, 0.934980341502663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 306}], {
             RGBColor[
             0.21898168415614172`, 0.3474940126617616, 0.9357820550070972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 311}], {
             RGBColor[
             0.20912979631755016`, 0.33713905389763504`, 0.9352210045692514]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 317}], {
             RGBColor[
             0.20208377375464914`, 0.3297332374403929, 0.9348197440079504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 344}], {
             RGBColor[
             0.20361295849173341`, 0.3313405075549807, 0.9349068288165013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 346}], {
             RGBColor[
             0.20954480137125253`, 0.3375752505219164, 0.9352446384931148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 354}], {
             RGBColor[
             0.2058823112495472, 0.3337257411887183, 0.9350360650988523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 142}], {
             RGBColor[
             0.6441352636384634, 0.7193460306737178, 0.9669266768382974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 201}], {
             RGBColor[
             0.7399124857733206, 0.7967445245200704, 0.9747112197727283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 273}], {
             RGBColor[
             0.6690783888345512, 0.7395959833828867, 0.9688902910234116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 281}], {
             RGBColor[
             0.6064310569728814, 0.687254440774864, 0.9643678385927457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 293}], {
             RGBColor[
             0.5641203291112874, 0.6506070149001673, 0.9616718364273125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 303}], {
             RGBColor[
             0.8540204827009316, 0.7329759435664439, 0.607655802146349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 391}], {
             RGBColor[
             0.817172560246312, 0.5056217507313383, 0.5745581182301532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 394}], {
             RGBColor[
             0.585868010689025, 0.6694437636125451, 0.9630575794667262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 149}], {
             RGBColor[
             0.20160011613108555`, 0.32922488261236305`, 0.9347922004217959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 155}], {
             RGBColor[
             0.18938684794258642`, 0.3163879633803221, 0.934096672866372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 180}], {
             RGBColor[
             0.1906491777676344, 0.3177147520627811, 0.9341685606824588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 249}], {
             RGBColor[
             0.18824799980109214`, 0.3151909617764689, 0.9340318171494888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 268}], {
             RGBColor[
             0.19026708475134468`, 0.3173131480765642, 0.9341468010504371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 279}], {
             RGBColor[
             0.1959554713815859, 0.323292003089491, 0.9344707462538155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 299}], {
             RGBColor[
             0.19063186344337624`, 0.3176965536101942, 0.9341675746573066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 300}], {
             RGBColor[
             0.1945175148280322, 0.3217806195799947, 0.9343888567553567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 370}], {
             RGBColor[
             0.189210358194615, 0.3162024614651078, 0.9340866220363182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 178}], {
             RGBColor[
             0.18320632976714918`, 0.309891846910452, 0.9337447014995381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 200}], {
             RGBColor[
             0.18872606349581567`, 0.31569343703061226`, 0.9340590421696713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 278}], {
             RGBColor[
             0.18574944160901402`, 0.31256481869885566`, 0.9338895279567354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 296}], {
             RGBColor[
             0.18124069831826523`, 0.30782584362944293`, 0.9336327616964153]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 320}], {
             RGBColor[
             0.18355649439985816`, 0.3102598921411492, 0.9337646428573487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 330}], {
             RGBColor[
             0.1860526851696524, 0.3128835469078388, 0.9339067972289052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 347}], {
             RGBColor[
             0.18386468807739512`, 0.3105838232368483, 0.9337821940313528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 367}], {
             RGBColor[
             0.18474901765317286`, 0.31151330969072427`, 0.9338325552924449]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 398}], {
             RGBColor[
             0.18210607446438823`, 0.30873540882703493`, 0.9336820435877278]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 163}], {
             RGBColor[
             0.17908461226291875`, 0.3055596604815222, 0.9335099757852068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 171}], {
             RGBColor[
             0.18358417843459812`, 0.31028898981693004`, 0.9337662194221723]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 240}], {
             RGBColor[
             0.17922390736570504`, 0.3057060684663703, 0.9335179084352418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 272}], {
             RGBColor[
             0.18788317693480855`, 0.3148075098128992, 0.9340110410269609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 342}], {
             RGBColor[
             0.18275455563161122`, 0.309417003649867, 0.9337189736308591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 374}], {
             RGBColor[
             0.18137577945827954`, 0.307967822472237, 0.9336404543675045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 213}], {
             RGBColor[
             0.33038430669065766`, 0.46058401368253077`, 0.9422727737683254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 215}], {
             RGBColor[
             0.5207131115569171, 0.6175984363516078, 0.9569638659378303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 224}], {
             RGBColor[
             0.41655140034572946`, 0.5340112529021572, 0.9480965874177693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 227}], {
             RGBColor[
             0.3046735470917944, 0.4351013866526011, 0.9407521600662733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 243}], {
             RGBColor[
             0.2833746021341409, 0.41271484507099976`, 0.9395392166599004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 259}], {
             RGBColor[
             0.6153899363844033, 0.6921704499321857, 0.9662385558858466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 350}], {
             RGBColor[
             0.3419502599754641, 0.47060186109611535`, 0.9430097460842624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 363}], {
             RGBColor[
             0.3549405295448861, 0.4818533796872159, 0.9438374745743816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 383}], {
             RGBColor[
             0.3468364039638354, 0.47483399343410504`, 0.9433210868585539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 393}], {
             RGBColor[
             0.5286635054610748, 0.6238093444947674, 0.9577562869015417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 149}], {
             RGBColor[
             0.19648120536399588`, 0.3238445828384636, 0.9345006860263599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 155}], {
             RGBColor[
             0.18426793717549678`, 0.3110076636064226, 0.933805158470936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 268}], {
             RGBColor[
             0.18514817398425504`, 0.3119328483026647, 0.9338552866550012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 279}], {
             RGBColor[
             0.19083656061449622`, 0.3179117033155916, 0.9341792318583795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 299}], {
             RGBColor[
             0.1855129526762866, 0.3123162538362948, 0.9338760602618706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 300}], {
             RGBColor[
             0.18939860406094253`, 0.3164003198060953, 0.9340973423599207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 371}], {
             RGBColor[
             0.1813347042579621, 0.3079246498323852, 0.9336381151956117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 138}], {
             RGBColor[
             0.29077492625511725`, 0.4229532620622423, 0.93987057393605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 164}], {
             RGBColor[
             0.2538187120761361, 0.3841099378008197, 0.9377659722103766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 210}], {
             RGBColor[
             0.2691626848877073, 0.40023742608984725`, 0.9386397887626219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 230}], {
             RGBColor[
             0.2568850160495337, 0.38733281769176137`, 0.9379405936854713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 242}], {
             RGBColor[
             0.31652160790723577`, 0.4470881617051118, 0.9414439626926704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 258}], {
             RGBColor[
             0.2651486396074914, 0.3960184099951701, 0.9384111948221615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 264}], {
             RGBColor[
             0.27631179289230656`, 0.4077515918823088, 0.9390469198873264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 328}], {
             RGBColor[
             0.2619981545019592, 0.39270705039696285`, 0.9382317793561266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 394}], {
             RGBColor[
             0.32513488620910913`, 0.45454855045423936`, 0.9419927931696428]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 149}], {
             RGBColor[
             0.2496156992329207, 0.3796923048161946, 0.9375266168467558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 164}], {
             RGBColor[
             0.2519489800003536, 0.38214473084131173`, 0.9376594937346815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 210}], {
             RGBColor[
             0.2672929528119248, 0.3982722191303392, 0.9385333102869269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 230}], {
             RGBColor[
             0.2550152839737512, 0.38536761073225334`, 0.9378341152097762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 242}], {
             RGBColor[
             0.31465187583145326`, 0.4451229547456037, 0.9413374842169753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 258}], {
             RGBColor[
             0.26327890753170885`, 0.39405320303566205`, 0.9383047163464664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 264}], {
             RGBColor[
             0.27444206081652406`, 0.4057863849228008, 0.9389404414116314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 281}], {
             RGBColor[
             0.3438282004171828, 0.4703940206570502, 0.9431965738199672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 328}], {
             RGBColor[
             0.2601284224261766, 0.3907418434374549, 0.9381253008804314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 394}], {
             RGBColor[
             0.32326515413332657`, 0.4525833434947314, 0.9418863146939478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 186}], {
             RGBColor[
             0.2567623305791477, 0.38720386748367763`, 0.9379336069294297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 213}], {
             RGBColor[
             0.3161784578429658, 0.4481129729732145, 0.941373691457378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 215}], {
             RGBColor[
             0.5065072627092252, 0.6051273956422916, 0.956064783626883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 306}], {
             RGBColor[
             0.2646217542710957, 0.39546462010015837`, 0.9383811894817108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 308}], {
             RGBColor[
             0.25989565930435055`, 0.3904971946383813, 0.9381120453649856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 345}], {
             RGBColor[
             0.5675136417908162, 0.652851509744995, 0.962127956401694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 350}], {
             RGBColor[
             0.3277444111277722, 0.4581308203867991, 0.942110663773315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 378}], {
             RGBColor[
             0.27359029407982893`, 0.40489112407740385`, 0.9388919345560525]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 147}], {
             RGBColor[
             0.32678087214865287`, 0.45177394646584723`, 0.9422514665551494]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 193}], {
             RGBColor[
             0.6221373960333281, 0.6999919748954846, 0.9657582775840088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 195}], {
             RGBColor[
             0.4154824656065883, 0.5342917617776789, 0.9476951532051012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 241}], {
             RGBColor[
             0.343629032390773, 0.46948243111537313`, 0.9432109443563187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 242}], {
             RGBColor[
             0.3733726074427579, 0.4978183191391804, 0.9450119502791875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 255}], {
             RGBColor[
             0.390267723092427, 0.5124520191417203, 0.9460884921086202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 263}], {
             RGBColor[
             0.35408935706105976`, 0.48047689556673456`, 0.943806644371628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 312}], {
             RGBColor[
             0.4770815978352943, 0.5850799771835042, 0.9523291493384193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 331}], {
             RGBColor[
             0.3236577561982914, 0.4484913535850291, 0.9420736097220124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 356}], {
             RGBColor[
             0.6758651089866358, 0.7425832566534856, 0.9622242963377263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 359}], {
             RGBColor[
             0.36601815692823686`, 0.491448263748933, 0.9445433311956875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 360}], {
             RGBColor[
             0.5345510834209994, 0.6314238460418358, 0.9570669805147731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 380}], {
             RGBColor[
             0.5633644182821813, 0.6539330422248467, 0.9599388244578124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 389}], {
             RGBColor[
             0.6997349672161455, 0.7570392468690857, 0.7200011772159544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 179}], {
             RGBColor[
             0.2912900071166007, 0.41914724840212236`, 0.9400590865040379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 196}], {
             RGBColor[
             0.5999457128672814, 0.6805575674236943, 0.9644423387605343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 209}], {
             RGBColor[
             0.3104061832925851, 0.4392395615986554, 0.9411477244574119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 286}], {
             RGBColor[
             0.3385051144347327, 0.4676178491867835, 0.9427902244568296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 290}], {
             RGBColor[
             0.3066482770874609, 0.4352897639120549, 0.9409337172583541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 304}], {
             RGBColor[
             0.31901866548224, 0.4482918264428926, 0.9416381925770871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 386}], {
             RGBColor[
             0.348846857880801, 0.4765753475686286, 0.9434491912043683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.37498442055197767`, 0.49560326154572176`, 0.9453825139194686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 201}], {
             RGBColor[
             0.5699368421210522, 0.6613816598554264, 0.9595312716051138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 273}], {
             RGBColor[
             0.4991027451822828, 0.6042331187182427, 0.9537103428557971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 281}], {
             RGBColor[
             0.436455413320613, 0.55189157611022, 0.9491878904251312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 293}], {
             RGBColor[
             0.3941446854590191, 0.5152441502355233, 0.946491888259698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 394}], {
             RGBColor[
             0.4158923670367568, 0.5340808989479011, 0.9478776312991117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 151}], {
             RGBColor[
             0.2032578843654731, 0.3309673021352812, 0.934886607870296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 158}], {
             RGBColor[
             0.1950219034609478, 0.3223107640132754, 0.9344175809418251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 171}], {
             RGBColor[
             0.19347840745274208`, 0.320688451845352, 0.9343296811275554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 186}], {
             RGBColor[
             0.20274228315425485`, 0.3304253725712859, 0.9348572451440806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 272}], {
             RGBColor[
             0.19777740595295248`, 0.3252069718413211, 0.9345745027323441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 306}], {
             RGBColor[
             0.21060170684620283`, 0.33868612518776664`, 0.9353048276963617]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 308}], {
             RGBColor[
             0.2058756118794577, 0.33371869972598955`, 0.9350356835796365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 342}], {
             RGBColor[
             0.19264878464975516`, 0.3198164656782889, 0.9342824353362423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 348}], {
             RGBColor[
             0.20000377872339242`, 0.3275470307832401, 0.9347012913679973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 354}], {
             RGBColor[
             0.1975023339396083, 0.32491785371472337`, 0.9345588377881168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 374}], {
             RGBColor[
             0.1912700084764235, 0.3183672845006589, 0.9342039160728877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 378}], {
             RGBColor[
             0.21957024665493602`, 0.3481126291650121, 0.9358155727707034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 148}], {
             RGBColor[
             0.41890511783186646`, 0.5289568419765102, 0.9490497655266936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 169}], {
             RGBColor[
             0.5192579762174159, 0.6205960432553745, 0.9552970364739267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 218}], {
             RGBColor[
             0.5707667888209911, 0.662413217772521, 0.9593519988850778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 222}], {
             RGBColor[
             0.7661723613566251, 0.8169857716290115, 0.9639290713689532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 276}], {
             RGBColor[
             0.48015124453344243`, 0.5868307576532874, 0.952775625742377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 282}], {
             RGBColor[
             0.44814038646858245`, 0.5591045613100133, 0.9507359221725744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 305}], {
             RGBColor[
             0.4396583364184836, 0.550769790541102, 0.9502316306235659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 339}], {
             RGBColor[
             0.48160738498318656`, 0.5880919933231088, 0.9528684097242202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 361}], {
             RGBColor[
             0.4954156444114053, 0.6000520136165334, 0.9537482598048219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 382}], {
             RGBColor[
             0.451676599366216, 0.5621674511867154, 0.9509612465314614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 384}], {
             RGBColor[
             0.757420984754537, 0.7226612405223014, 0.6127983851533676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 165}], {
             RGBColor[
             0.23770682741222313`, 0.3671753254665574, 0.9368484242141641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 170}], {
             RGBColor[
             0.24268853638713495`, 0.37241141745778183`, 0.9371321251705074]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 182}], {
             RGBColor[
             0.24585035887698375`, 0.3757346933657375, 0.937312186283807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 192}], {
             RGBColor[
             0.25406976709764434`, 0.3843738125462326, 0.9377802694224489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 208}], {
             RGBColor[
             0.2721455459278671, 0.4033726021673685, 0.9388096582861116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 221}], {
             RGBColor[
             0.3098924284635012, 0.43739177601044266`, 0.941166351723109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 225}], {
             RGBColor[
             0.22917757181567264`, 0.3582105370485437, 0.9363626957258434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 235}], {
             RGBColor[
             0.22156110310920424`, 0.35020514552603776`, 0.9359289491005658]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 335}], {
             RGBColor[
             0.2240686969525251, 0.3528407856460005, 0.9360717528602902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 349}], {
             RGBColor[
             0.2241439081408365, 0.35291983737358057`, 0.9360760360261996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 351}], {
             RGBColor[
             0.2797139568415439, 0.4112527007055903, 0.9392434061971325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 355}], {
             RGBColor[
             0.22900678342998865`, 0.3580310276265808, 0.9363529695799375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 395}], {
             RGBColor[
             0.3442769835307749, 0.46717394939172724`, 0.9433573051669275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 151}], {
             RGBColor[
             0.20337080686080378`, 0.3310859908375735, 0.9348930386393511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 158}], {
             RGBColor[
             0.1951348259562785, 0.3224294527155677, 0.9344240117108803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 227}], {
             RGBColor[
             0.2365605733145403, 0.3659705397331854, 0.936783146739032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 243}], {
             RGBColor[
             0.21526162835688684`, 0.343583998151584, 0.9355702033326591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 267}], {
             RGBColor[
             0.19834666787727806`, 0.32580530221707793`, 0.9346069213567869]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 275}], {
             RGBColor[
             0.1966367657635329, 0.324008086681476, 0.9345095449609826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 306}], {
             RGBColor[
             0.2107146293415335, 0.33880481389005895`, 0.9353112584654169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 311}], {
             RGBColor[
             0.20086274150294195`, 0.3284498551259324, 0.9347502080275711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 317}], {
             RGBColor[
             0.19381671894004093`, 0.32104403866869025`, 0.9343489474662702]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 344}], {
             RGBColor[
             0.1953459036771252, 0.3226513087832781, 0.9344360322748211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 346}], {
             RGBColor[
             0.20127774655664432`, 0.3288860517502138, 0.9347738419514344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 354}], {
             RGBColor[
             0.197615256434939, 0.32503654241701563`, 0.9345652685571719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 195}], {
             RGBColor[
             0.3359166803532971, 0.45968692435363845`, 0.9428335921754714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 217}], {
             RGBColor[
             0.2277310230294914, 0.3566901225577769, 0.9362803169124476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 231}], {
             RGBColor[
             0.2192108871052112, 0.34773491949353985`, 0.9357951077759714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 241}], {
             RGBColor[
             0.2640632471374818, 0.3948775936913327, 0.9383493833266887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 242}], {
             RGBColor[
             0.29380682218946674`, 0.42321348171513995`, 0.9401503892495575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 255}], {
             RGBColor[
             0.3107019378391358, 0.4378471817176799, 0.9412269310789902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 312}], {
             RGBColor[
             0.3975158125820031, 0.5104751397594638, 0.9474675883087893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 331}], {
             RGBColor[
             0.2440919709450002, 0.37388651616098867`, 0.9372120486923824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 359}], {
             RGBColor[
             0.28645237167494564`, 0.4168434263248926, 0.9396817701660576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 392}], {
             RGBColor[
             0.2251386082236323, 0.35396533022822685`, 0.9361326827243879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 218}], {
             RGBColor[
             0.40841467546891774`, 0.5204402282772255, 0.9482239194761258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 228}], {
             RGBColor[
             0.2402804897849437, 0.36988040779990605`, 0.9369949904788982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 276}], {
             RGBColor[
             0.31779913118136904`, 0.44485776815799194`, 0.9416475463334251]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.285788273116509, 0.4171315718147177, 0.9396078427636225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 301}], {
             RGBColor[
             0.25321055434935075`, 0.3834707254705414, 0.9377313385275249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 305}], {
             RGBColor[
             0.2773062230664102, 0.4087968010458064, 0.939103551214614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 313}], {
             RGBColor[
             0.27058528986872044`, 0.4017326741232574, 0.9387208040117352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 339}], {
             RGBColor[
             0.3192552716311131, 0.4461190038278132, 0.9417403303152683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 340}], {
             RGBColor[
             0.263972502592159, 0.39478221542066183`, 0.9383442155590771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 361}], {
             RGBColor[
             0.33306353105933184`, 0.4580790241212378, 0.94262018039587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 382}], {
             RGBColor[
             0.2893244860141426, 0.42019446169141983`, 0.9398331671225094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 155}], {
             RGBColor[
             0.19811293609800762`, 0.3255596352976139, 0.9345936106777326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 164}], {
             RGBColor[
             0.21265948505393958`, 0.340848980554772, 0.9354220151210823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 210}], {
             RGBColor[
             0.22800345786551077`, 0.3569764688437995, 0.9362958316733276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 230}], {
             RGBColor[
             0.21572578902733716`, 0.34407186044571364`, 0.935596636596177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 258}], {
             RGBColor[
             0.22398941258529487`, 0.35275745274912235`, 0.9360672377328672]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 264}], {
             RGBColor[
             0.23515256587011008`, 0.3644906346362611, 0.9367029627980321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 268}], {
             RGBColor[
             0.19899317290676588`, 0.326484819993856, 0.9346437388617977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 279}], {
             RGBColor[
             0.20468155953700706`, 0.33246367500678287`, 0.9349676840651762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 299}], {
             RGBColor[
             0.19935795159879743`, 0.32686822552748607`, 0.9346645124686672]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 300}], {
             RGBColor[
             0.20324360298345337`, 0.33095229149728655`, 0.9348857945667173]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 328}], {
             RGBColor[
             0.22083892747976266`, 0.3494460931509151, 0.9358878222668322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 152}], {
             RGBColor[
             0.21962526952820027`, 0.3481704616934645, 0.9358187062419367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 156}], {
             RGBColor[
             0.22013918030941965`, 0.34871061450835156`, 0.9358479727006643]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 157}], {
             RGBColor[
             0.24263401195527415`, 0.3723541088228476, 0.9371290200847746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 160}], {
             RGBColor[
             0.2168510680318782, 0.345254600026296, 0.9356607195707846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 167}], {
             RGBColor[
             0.2371065726737784, 0.3665444196781035, 0.936814240594807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 179}], {
             RGBColor[
             0.23260992772492337`, 0.36181816073310025`, 0.9365581633171598]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 181}], {
             RGBColor[
             0.21526447072748034`, 0.3435869856632946, 0.9355703652014595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 206}], {
             RGBColor[
             0.33364753302286965`, 0.45690710407047097`, 0.9427188232478589]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 211}], {
             RGBColor[
             0.23544785722092995`, 0.3648010045685258, 0.9367197792036168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 238}], {
             RGBColor[
             0.21964443169265407`, 0.3481906023432569, 0.9358197974988545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 386}], {
             RGBColor[
             0.29016677848912364`, 0.4192462598996066, 0.9399482680174902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 158}], {
             RGBColor[
             0.19937632863451948`, 0.3268875409572013, 0.9346655590136652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 186}], {
             RGBColor[
             0.20709670832782653`, 0.33500214951521173`, 0.9351052232159208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 227}], {
             RGBColor[
             0.2408020759927813, 0.3704286279748189, 0.937024694041817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 267}], {
             RGBColor[
             0.20258817055551906`, 0.33026339045871145`, 0.9348484686595718]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 306}], {
             RGBColor[
             0.21495613201977448`, 0.3432629021316925, 0.9355528057682019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 308}], {
             RGBColor[
             0.2102300370530294, 0.33829547666991544`, 0.9352836616514766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 311}], {
             RGBColor[
             0.20510424418118295`, 0.33290794336756596`, 0.934991755330356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 317}], {
             RGBColor[
             0.1980582216182819, 0.3255021269103238, 0.9345904947690551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 344}], {
             RGBColor[
             0.1995874063553662, 0.3271093970249116, 0.9346775795776059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 346}], {
             RGBColor[
             0.2055192492348853, 0.3333441399918473, 0.9350153892542195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 348}], {
             RGBColor[
             0.20435820389696413`, 0.332123807727166, 0.9349492694398375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 354}], {
             RGBColor[
             0.20185675911317996`, 0.3294946306586492, 0.934806815859957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 156}], {
             RGBColor[
             0.20135778622096587`, 0.32897017851222354`, 0.9347784000919095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 157}], {
             RGBColor[
             0.22385261786682037`, 0.3526136728267195, 0.9360594474760198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 160}], {
             RGBColor[
             0.19806967394342445`, 0.325514164030168, 0.9345911469620297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 179}], {
             RGBColor[
             0.2138285336364696, 0.3420777247369723, 0.935488590708405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 181}], {
             RGBColor[
             0.1964830766390266, 0.32384654966716653`, 0.9345007925927047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 238}], {
             RGBColor[
             0.20086303760420032`, 0.32845016634712887`, 0.9347502248900996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 245}], {
             RGBColor[
             0.19786899137363773`, 0.3253032339253123, 0.9345797183865636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 168}], {
             RGBColor[
             0.20180786245057253`, 0.3294432371660213, 0.9348040312673576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 175}], {
             RGBColor[
             0.19789401206423968`, 0.32532953225753836`, 0.9345811432778787]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 211}], {
             RGBColor[
             0.21907020233692062`, 0.34758705088213704`, 0.9357870959865418]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 216}], {
             RGBColor[
             0.21073387590110806`, 0.33882504324447416`, 0.935312354528512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 229}], {
             RGBColor[
             0.2017865527982215, 0.3294208393702904, 0.934802817714181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 294}], {
             RGBColor[
             0.20769214048678164`, 0.33562798646685293`, 0.9351391321965103]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 329}], {
             RGBColor[
             0.23399514583317907`, 0.36327411279277777`, 0.9366370494391784]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 341}], {
             RGBColor[
             0.22749742981872606`, 0.3564446012825976, 0.9362670141246647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 343}], {
             RGBColor[
             0.20318561149837056`, 0.330891338769592, 0.9348824920374326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 358}], {
             RGBColor[
             0.24162422522743635`, 0.37129275894771363`, 0.9370715142244698]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 379}], {
             RGBColor[
             0.19405975897206282`, 0.32129948915197337`, 0.9343627882365483]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 207}], {
             RGBColor[
             0.18894498275511917`, 0.315923535052423, 0.9340715092976267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 231}], {
             RGBColor[
             0.18878970308862236`, 0.3157603262776354, 0.9340626663503354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 369}], {
             RGBColor[
             0.183389073095449, 0.31008392173509136`, 0.9337551084617403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 372}], {
             RGBColor[
             0.18315975702077553`, 0.3098428960011307, 0.9337420492505304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 387}], {
             RGBColor[
             0.18595738695423472`, 0.312783382441179, 0.9339013701365182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 392}], {
             RGBColor[
             0.19471742420704347`, 0.3219907370123223, 0.934400241298752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 249}], {
             RGBColor[
             0.18476081976801417`, 0.3115257144617197, 0.9338332274054255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 268}], {
             RGBColor[
             0.18677990471826675`, 0.31364790076181503`, 0.9339482113063738]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 279}], {
             RGBColor[
             0.19246829134850796`, 0.31962675577474187`, 0.9342721565097523]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.1871446834102983, 0.31403130629544507`, 0.9339689849132433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 300}], {
             RGBColor[
             0.19103033479495424`, 0.31811537226524556`, 0.9341902670112934]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 370}], {
             RGBColor[
             0.18572317816153708`, 0.3125372141503586, 0.9338880322922549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 371}], {
             RGBColor[
             0.18296643499197385`, 0.3096397022915355, 0.9337310398469844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 160}], {
             RGBColor[
             0.19858358472464382`, 0.32605431684505504`, 0.9346204134207573]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.21434244441768896`, 0.34261787755185935`, 0.9355178571671325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 181}], {
             RGBColor[
             0.19699698742024596`, 0.3243867024820536, 0.9345300590514323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 245}], {
             RGBColor[
             0.1983829021548571, 0.32584338674019936`, 0.9346089848452912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 352}], {
             RGBColor[
             0.19412861826228733`, 0.32137186463193046`, 0.9343667096712585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 396}], {
             RGBColor[
             0.19313485512094197`, 0.32032735656215416`, 0.9343101163304997]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 160}], {
             RGBColor[
             0.22107841637049833`, 0.349697811159551, 0.9359014608048675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 167}], {
             RGBColor[
             0.24133392101239853`, 0.37098763081135855`, 0.93705498182889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 168}], {
             RGBColor[
             0.222412865673202, 0.35110040198566517`, 0.9359774557185156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 203}], {
             RGBColor[
             0.2784354581733116, 0.40986687435040126`, 0.9391721369966093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 206}], {
             RGBColor[
             0.3378748813614898, 0.46135031520372605`, 0.942959564481942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 211}], {
             RGBColor[
             0.23967520555955008`, 0.36924421570178084`, 0.9369605204376998]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 238}], {
             RGBColor[
             0.22387178003127423`, 0.3526338134765119, 0.9360605387329375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 341}], {
             RGBColor[
             0.24810243304135554`, 0.37810176610224144`, 0.9374404385758228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 358}], {
             RGBColor[
             0.2622292284500658, 0.3929499237673575, 0.938244938675628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 386}], {
             RGBColor[
             0.2943941268277438, 0.42368947103286164`, 0.9401890092515732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 267}], {
             RGBColor[
             0.19435218965099377`, 0.3216068523367057, 0.934379441731101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 306}], {
             RGBColor[
             0.20672015111524922`, 0.33460636400968674`, 0.935083778839731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 308}], {
             RGBColor[
             0.20199405614850408`, 0.32963893854790965`, 0.9348146347230057]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 311}], {
             RGBColor[
             0.19686826327665763`, 0.3242514052455602, 0.9345227284018851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 317}], {
             RGBColor[
             0.18982224071375664`, 0.31684558878831803`, 0.9341214678405843]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 344}], {
             RGBColor[
             0.19135142545084088`, 0.31845285890290587`, 0.934208552649135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 346}], {
             RGBColor[
             0.19728326833036003`, 0.3246876018698416, 0.9345463623257486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 348}], {
             RGBColor[
             0.1961222229924388, 0.3234672696051602, 0.9344802425113666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 354}], {
             RGBColor[
             0.1936207782086547, 0.3208380925366434, 0.9343377889314861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 374}], {
             RGBColor[
             0.1873884527454699, 0.3142875233225789, 0.9339828672162569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 250}], {
             RGBColor[
             0.18793077615893167`, 0.3148575396154177, 0.934013751732358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 265}], {
             RGBColor[
             0.19056897353088317`, 0.3176304523247132, 0.9341639931698273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 321}], {
             RGBColor[
             0.1833474210515813, 0.31004014279609426`, 0.9337527364394607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 375}], {
             RGBColor[
             0.19246854917072223`, 0.3196270267622359, 0.9342721711923458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 381}], {
             RGBColor[
             0.18574510039169012`, 0.3125602558041992, 0.9338892807308311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[
             0.19370887514270452`, 0.320930687999998, 0.9343428059215524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 238}], {
             RGBColor[
             0.19808883610787825`, 0.32553430467996036`, 0.9345922382189475]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 245}], {
             RGBColor[
             0.19509478987731566`, 0.3223873722581438, 0.9344217317154114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 196}], {
             RGBColor[
             0.8618354721760655, 0.7122379768474625, 0.603098702731688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 214}], {
             RGBColor[
             0.8792338615689066, 0.5445109956801907, 0.22094211265521246`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 253}], {
             RGBColor[
             0.8523693689594214, 0.3702876353014115, 0.19648021346556857`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 283}], {
             RGBColor[
             0.9057344419097366, 0.6568662450460772, 0.2426421685015519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 332}], {
             RGBColor[
             0.848675629685056, 0.3418959366317691, 0.19294308456495457`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 334}], {
             RGBColor[
             0.9198789642740572, 0.7116881876157337, 0.2605664067222301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.9124649507944522, 0.7523588106461282, 0.5992692091287142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 364}], {
             RGBColor[
             0.9004423422818535, 0.6358848335091806, 0.23838402091941335`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 366}], {
             RGBColor[
             0.9364231997374939, 0.7670038596603013, 0.3666668736906492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 389}], {
             RGBColor[
             0.9363348090239618, 0.7668148008617284, 0.3570460900069422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 183}], {
             RGBColor[
             0.1919904214056781, 0.3191244841661233, 0.9342449425234534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 270}], {
             RGBColor[
             0.20162095796864934`, 0.3292467887050914, 0.9347933873336124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 280}], {
             RGBColor[
             0.20211294537388308`, 0.32976389866179523`, 0.9348214052885103]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 291}], {
             RGBColor[
             0.1953787311658639, 0.32268581255532547`, 0.9344379017517408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 336}], {
             RGBColor[
             0.21504897720554328`, 0.3433604883086603, 0.9355580931641793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 357}], {
             RGBColor[
             0.1906502583880034, 0.3177158878633042, 0.9341686222221902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 368}], {
             RGBColor[
             0.18956500601498782`, 0.31657521881029016`, 0.934106818705034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 171}], {
             RGBColor[
             0.18355378954190335`, 0.31025704916394076`, 0.9337644888196897]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 240}], {
             RGBColor[
             0.17919351847301027`, 0.305674127813381, 0.9335161778327592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 272}], {
             RGBColor[
             0.18785278804211375`, 0.3147755691599099, 0.9340093104244782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 342}], {
             RGBColor[
             0.18272416673891645`, 0.30938506299687774`, 0.9337172430283764]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 374}], {
             RGBColor[
             0.1813453905655848, 0.3079358818192477, 0.9336387237650219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 210}], {
             RGBColor[
             0.23033673863294363`, 0.3594288948689166, 0.9364287085612534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 230}], {
             RGBColor[
             0.21805906979477002`, 0.3465242864708308, 0.9357295134841028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 258}], {
             RGBColor[
             0.22632269335272776`, 0.3552098787742395, 0.936200114620793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 264}], {
             RGBColor[
             0.23748584663754294`, 0.36694306066137816`, 0.9368358396859577]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 279}], {
             RGBColor[
             0.20701484030443992`, 0.33491610103189995`, 0.9351005609531018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 328}], {
             RGBColor[
             0.22317220824719552`, 0.35189851917603227`, 0.9360206991547579]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 170}], {
             RGBColor[
             0.23052227294686206`, 0.35962390319639986`, 0.9364392744659576]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 172}], {
             RGBColor[
             0.3025819493818708, 0.42881009810169846`, 0.9407829073040905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 184}], {
             RGBColor[
             0.21954677082243013`, 0.3480879545765947, 0.9358142358567716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 190}], {
             RGBColor[
             0.21884661716031273`, 0.34735204868540315`, 0.9357743631414985]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 192}], {
             RGBColor[
             0.24190350365737148`, 0.3715862982848506, 0.9370874187178992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 221}], {
             RGBColor[
             0.29772616502322835`, 0.42460426174906063`, 0.9404735010185594]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 226}], {
             RGBColor[
             0.20872258864357046`, 0.33671105281382463`, 0.935197814694628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 252}], {
             RGBColor[
             0.21574093049341658`, 0.3440877750865875, 0.9355974988802704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 274}], {
             RGBColor[
             0.21434019517096867`, 0.34261551345094576`, 0.9355177290758593]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 288}], {
             RGBColor[
             0.2196372553710177, 0.3481830595742119, 0.9358193888179538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 318}], {
             RGBColor[
             0.21949852941857476`, 0.348037249802461, 0.9358114885801888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 322}], {
             RGBColor[
             0.2103258844391586, 0.3383962183498125, 0.9352891200183233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 351}], {
             RGBColor[
             0.26754769340127105`, 0.39846518644420825`, 0.9385505554925828]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 355}], {
             RGBColor[
             0.2168405199897158, 0.34524351336519876`, 0.9356601188753879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 399}], {
             RGBColor[
             0.2924581876891166, 0.42004140455849254`, 0.9401378301611192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 169}], {
             RGBColor[
             0.3512165772923903, 0.4726432539013666, 0.9438449606681389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 246}], {
             RGBColor[
             0.23093801406837325`, 0.3600608734746177, 0.9364629503077938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 326}], {
             RGBColor[
             0.24337300372818133`, 0.3731308360309576, 0.9371711045730012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 363}], {
             RGBColor[
             0.3098501203432949, 0.43692070785172515`, 0.9411795622408922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 383}], {
             RGBColor[
             0.3017459947622442, 0.42990132159861427`, 0.9406631745250644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 168}], {
             RGBColor[
             0.21688542639170627`, 0.3452907128409211, 0.935662676228548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.2729080188918158, 0.40405718520565725`, 0.9388573575066418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 211}], {
             RGBColor[
             0.23414776627805434`, 0.3634345265570368, 0.9366457409477322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 216}], {
             RGBColor[
             0.22581143984224178`, 0.35467251891937396`, 0.9361709994897025]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 238}], {
             RGBColor[
             0.2183443407497785, 0.3468241243317679, 0.9357457592429699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 341}], {
             RGBColor[
             0.2425749937598598, 0.37229207695749733`, 0.9371256590858552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 358}], {
             RGBColor[
             0.25670178916857006`, 0.3871402346226134, 0.9379301591856604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 211}], {
             RGBColor[
             0.2152267109388578, 0.3435472977313434, 0.935568214837358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 216}], {
             RGBColor[
             0.20689038450304525`, 0.3347852900936806, 0.9350934733793282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 238}], {
             RGBColor[
             0.19942328541058194`, 0.3269368955060745, 0.9346682331325956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 341}], {
             RGBColor[
             0.22365393842066325`, 0.35240484813180395`, 0.936048132975481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 379}], {
             RGBColor[
             0.190216267574, 0.31725973600117974`, 0.9341439070873645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 218}], {
             RGBColor[
             0.5087675338544672, 0.6120794295560898, 0.9544711904233589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 222}], {
             RGBColor[
             0.7041731063901011, 0.7666519834125803, 0.9590482629072343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 224}], {
             RGBColor[
             0.4775031351026399, 0.5866975822042433, 0.9520099424283488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 276}], {
             RGBColor[
             0.41815198956691846`, 0.5364969694368562, 0.947894817280658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 326}], {
             RGBColor[
             0.349415147686683, 0.47074983716853436`, 0.9437423719170701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 361}], {
             RGBColor[
             0.4334163894448813, 0.5497182254001022, 0.948867451343103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 363}], {
             RGBColor[
             0.4158922643017966, 0.5345397089893019, 0.947750829584961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 382}], {
             RGBColor[
             0.38967734439969204`, 0.5118336629702842, 0.9460804380697425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 383}], {
             RGBColor[
             0.4077881387207459, 0.527520322736191, 0.9472344418691334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 393}], {
             RGBColor[
             0.5896152402179853, 0.6764956737968535, 0.9616696419121211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[
             0.2468852126322833, 0.37682239027607506`, 0.9373711196742425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 208}], {
             RGBColor[
             0.26496099146250607`, 0.3958211798972109, 0.9384005085379051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 221}], {
             RGBColor[
             0.30270787399814014`, 0.42984035374028506`, 0.9407572019749026]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 225}], {
             RGBColor[
             0.22199301735031157`, 0.3506591147783862, 0.9359535459776369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 235}], {
             RGBColor[
             0.21437654864384317`, 0.34265372325588017`, 0.9355197993523594]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 322}], {
             RGBColor[
             0.2153075934140704, 0.3436323103410369, 0.9355728209746665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 335}], {
             RGBColor[
             0.21688414248716403`, 0.34528936337584293`, 0.9356626031120838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 349}], {
             RGBColor[
             0.21695935367547547`, 0.34536841510342303`, 0.9356668862779931]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 351}], {
             RGBColor[
             0.27252940237618284`, 0.4037012784354327, 0.938834256448926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 355}], {
             RGBColor[
             0.2218222289646276, 0.3504796053564232, 0.9359438198317311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 186}], {
             RGBColor[
             0.1973172314150955, 0.32472329922528254`, 0.9345482964731804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 240}], {
             RGBColor[
             0.18369308464468964`, 0.3104034571487888, 0.9337724214697247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 272}], {
             RGBColor[
             0.19235235421379315`, 0.3195048984953177, 0.9342655540614437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 308}], {
             RGBColor[
             0.20045056014029836`, 0.3280166263799862, 0.9347267349087363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 342}], {
             RGBColor[
             0.18722373291059582`, 0.31411439233228555`, 0.933973486665342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 348}], {
             RGBColor[
             0.1945787269842331, 0.32184495743723673`, 0.934392342697097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 374}], {
             RGBColor[
             0.18584495673726414`, 0.3126652111546555, 0.9338949674019874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 192}], {
             RGBColor[
             0.31894488906729196`, 0.44600858518137365`, 0.9417147525123752]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 194}], {
             RGBColor[
             0.41753162873264527`, 0.5360090287080477, 0.9478416433121417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 221}], {
             RGBColor[
             0.3747675504331488, 0.4990265486455837, 0.9451008348130354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 256}], {
             RGBColor[
             0.6859636429526801, 0.7471589426256584, 0.8613086090450968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 316}], {
             RGBColor[
             0.5458822960971526, 0.6391409074229324, 0.9586767421820886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 351}], {
             RGBColor[
             0.3445890788111915, 0.47288747334073133`, 0.943177889287059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 399}], {
             RGBColor[
             0.369499573099037, 0.49446369145501556`, 0.9447651639555954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 198}], {
             RGBColor[
             0.6233166189809511, 0.701327344471203, 0.9656888716580491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 203}], {
             RGBColor[
             0.3639226125883841, 0.4896332085668736, 0.9444098049633691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 266}], {
             RGBColor[
             0.5380286912692482, 0.6346285303347542, 0.9572070721400225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 313}], {
             RGBColor[
             0.35122662219084355`, 0.47640574207717373`, 0.9436825095790529]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 329}], {
             RGBColor[
             0.34008730347088106`, 0.4646976118288939, 0.9430481418570962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 340}], {
             RGBColor[
             0.3446138349142821, 0.46945528337457815`, 0.9433059211263948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 341}], {
             RGBColor[
             0.3335895874564281, 0.4578681003187137, 0.9426781065425826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 358}], {
             RGBColor[
             0.34771638286513834`, 0.47271625798382977`, 0.9434826066423876]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 204}], {
             RGBColor[
             0.1850387535749342, 0.31181784051481387`, 0.9338490553245634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 216}], {
             RGBColor[
             0.20297653411671235`, 0.3306715851851976, 0.9348705853898494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 229}], {
             RGBColor[
             0.1940292110138258, 0.32126738131101384`, 0.9343610485755184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 294}], {
             RGBColor[
             0.19993479870238595`, 0.3274745284075764, 0.9346973630578478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 307}], {
             RGBColor[
             0.18458331869086259`, 0.3113391495754152, 0.933823118981671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 343}], {
             RGBColor[
             0.19542826971397487`, 0.32273788071031545`, 0.93444072289877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 379}], {
             RGBColor[
             0.1863024171876671, 0.3131460310926968, 0.9339210190978857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 205}], {
             RGBColor[
             0.18567915281687453`, 0.3124909407217502, 0.9338855251140061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 232}], {
             RGBColor[
             0.18828223277850703`, 0.3152269428062281, 0.9340337666669094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 277}], {
             RGBColor[
             0.18565952896853344`, 0.31247031481291987`, 0.933884407564874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 298}], {
             RGBColor[
             0.19583511598337588`, 0.32316550193499927`, 0.9344638921919373]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 320}], {
             RGBColor[
             0.18495626411433608`, 0.3117311388615913, 0.9338443576718145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 347}], {
             RGBColor[
             0.18526445779187303`, 0.3120550699572905, 0.9338619088458187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 373}], {
             RGBColor[
             0.192094835712424, 0.3192342302227627, 0.9342508887637553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 390}], {
             RGBColor[
             0.199593709897452, 0.3271160224473115, 0.9346779385550025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 219}], {
             RGBColor[
             0.18016175523476746`, 0.3066918060397442, 0.9335713174839634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 248}], {
             RGBColor[
             0.18215464872777276`, 0.30878646345763827`, 0.9336848098201683]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 260}], {
             RGBColor[
             0.18516377148342406`, 0.31194924226322995`, 0.9338561749095045]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 285}], {
             RGBColor[
             0.18283630546897034`, 0.3095029279121705, 0.9337236291631588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 200}], {
             RGBColor[
             0.1885274133225135, 0.31548464310332325`, 0.9340477293361784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 278}], {
             RGBColor[
             0.18555079143571185`, 0.31235602477156665`, 0.9338782151232425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 296}], {
             RGBColor[
             0.18104204814496305`, 0.30761704970215387`, 0.9336214488629224]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 330}], {
             RGBColor[
             0.18585403499635023`, 0.3126747529805498, 0.9338954843954123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 367}], {
             RGBColor[
             0.18455036747987072`, 0.3113045157634352, 0.933821242458952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 398}], {
             RGBColor[
             0.18190742429108608`, 0.30852661489974587`, 0.9336707307542348]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 209}], {
             RGBColor[
             0.24592936800917714`, 0.3758177369731411, 0.9373166857370019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 245}], {
             RGBColor[
             0.21085364957036085`, 0.33895093296494805`, 0.9353191754617867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 286}], {
             RGBColor[
             0.2740282991513247, 0.4041960245612692, 0.9389591857364195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 290}], {
             RGBColor[
             0.24217146180405288`, 0.37186793928654055`, 0.9371026785379442]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 352}], {
             RGBColor[
             0.20659936567779108`, 0.3344794108566792, 0.9350769002877538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 386}], {
             RGBColor[
             0.284370042597393, 0.41315352294311436`, 0.9396181524839584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 232}], {
             RGBColor[
             0.18939213687360562`, 0.3163935223821609, 0.9340969740631693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 249}], {
             RGBColor[
             0.18602314959306215`, 0.3128525031441788, 0.9339051152215123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 268}], {
             RGBColor[
             0.1880422345433147, 0.314974689444274, 0.9340200991224608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 370}], {
             RGBColor[
             0.18698550798658503`, 0.3138640028328177, 0.9339599201083417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 238}], {
             RGBColor[
             0.1965022388034804, 0.3238666903169589, 0.9345018838496224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 245}], {
             RGBColor[
             0.1935081925729178, 0.3207197578951424, 0.9343313773460864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 187}], {
             RGBColor[
             0.22908739425404853`, 0.35811575471368917`, 0.9363575602471148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 208}], {
             RGBColor[
             0.2681228139523549, 0.39914445580516655`, 0.9385805696512048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 323}], {
             RGBColor[
             0.3312247462121247, 0.45512489933743366`, 0.9425528644360341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 377}], {
             RGBColor[
             0.2482608696505907, 0.3782682930240088, 0.9374494613063329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 388}], {
             RGBColor[
             0.2563045573313864, 0.38672271877578024`, 0.9379075374201846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 395}], {
             RGBColor[
             0.3402542515552627, 0.4629458030295253, 0.9431282165320207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 270}], {
             RGBColor[
             0.198314467229445, 0.32577145729456636`, 0.9346050875775294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 291}], {
             RGBColor[
             0.1920722404266596, 0.31921048114480044`, 0.9342496019956579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 357}], {
             RGBColor[
             0.18734376764879906`, 0.31424055645277915`, 0.9339803224661072]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 368}], {
             RGBColor[
             0.18625851527578347`, 0.31309988739976513`, 0.933918518948951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 185}], {
             RGBColor[
             0.20305130848505737`, 0.330750177787297, 0.9348748436795078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 190}], {
             RGBColor[
             0.21285282401079259`, 0.34105219205682236`, 0.9354330254886557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 226}], {
             RGBColor[
             0.20272879549405032`, 0.3304111961852439, 0.9348564770417853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 252}], {
             RGBColor[
             0.20974713734389644`, 0.3377879184580067, 0.9352561612274277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 274}], {
             RGBColor[
             0.20834640202144852`, 0.33631565682236503`, 0.9351763914230165]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 288}], {
             RGBColor[
             0.21364346222149755`, 0.3418832029456312, 0.9354780511651108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 318}], {
             RGBColor[
             0.2135047362690546, 0.34173739317388024`, 0.935470150927346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 190}], {
             RGBColor[
             0.20235115482293997`, 0.33001427189610544`, 0.9348349709642347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 226}], {
             RGBColor[
             0.1922271263061977, 0.3193732760245269, 0.9342584225173644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 252}], {
             RGBColor[
             0.1992454681560438, 0.3267499982972898, 0.9346581067030068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 274}], {
             RGBColor[
             0.19784473283359588`, 0.32527773666164805`, 0.9345783368985956]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 288}], {
             RGBColor[
             0.2031417930336449, 0.3308452827849142, 0.93487999664069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 318}], {
             RGBColor[
             0.20300306708120197`, 0.33069947301316327`, 0.9348720964029251]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 357}], {
             RGBColor[
             0.18927662196416456`, 0.31627210888827, 0.9340903956599655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 272}], {
             RGBColor[
             0.20161622991530592`, 0.3292418192212516, 0.9347931180779689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 306}], {
             RGBColor[
             0.21444053080855624`, 0.3427209725676972, 0.9355234430419865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 308}], {
             RGBColor[
             0.20971443584181115`, 0.3377535471059201, 0.9352542989252615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 342}], {
             RGBColor[
             0.19648760861210862`, 0.32385131305821946`, 0.9345010506818672]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 348}], {
             RGBColor[
             0.2038426026857459, 0.33158187816317064`, 0.9349199067136222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 374}], {
             RGBColor[
             0.19510883243877694`, 0.3224021318805894, 0.9344225314185126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 378}], {
             RGBColor[
             0.22340907061728948`, 0.35214747654494266`, 0.9360341881163283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 208}], {
             RGBColor[
             0.25538258130493185`, 0.38575366351532014`, 0.9378550322494192]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 302}], {
             RGBColor[
             0.20552429842574232`, 0.33334944701157526`, 0.9350156767981692]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 377}], {
             RGBColor[
             0.2355206370031677, 0.36487750073416236`, 0.9367239239045473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 388}], {
             RGBColor[
             0.2435643246839634, 0.37333192648593383`, 0.937182000018399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 201}], {
             RGBColor[
             0.47076164268683474`, 0.5730017553920743, 0.9531670568538995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 264}], {
             RGBColor[
             0.26789407428573686`, 0.39890403591261847`, 0.9385675432655809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 273}], {
             RGBColor[
             0.39992754574806544`, 0.5158532142548906, 0.9473461281045827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 281}], {
             RGBColor[
             0.3372802138863956, 0.4635116716468679, 0.9428236756739168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 293}], {
             RGBColor[
             0.29496948602480166`, 0.4268642457721712, 0.9401276735084836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 394}], {
             RGBColor[
             0.3167171676025393, 0.44570099448454903`, 0.9415134165478973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 207}], {
             RGBColor[
             0.2123454769342431, 0.3405189381117063, 0.935404132823199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 241}], {
             RGBColor[
             0.2570425573000169, 0.3874984035347115, 0.937949565426625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 263}], {
             RGBColor[
             0.2675028819703037, 0.39849286798607286`, 0.9385452654419342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 280}], {
             RGBColor[
             0.2210513429116578, 0.3496693552377532, 0.9358999190114381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 291}], {
             RGBColor[
             0.21431712870363867`, 0.34259126913128346`, 0.9355164154746687]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 336}], {
             RGBColor[
             0.23398737474331802`, 0.3632659448846183, 0.936636606887107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 359}], {
             RGBColor[
             0.2794316818374808, 0.4094642361682714, 0.9392819522659938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 226}], {
             RGBColor[
             0.20202864183193292`, 0.3296752902940524, 0.9348166043265123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 252}], {
             RGBColor[
             0.20904698368177904`, 0.3370520125668152, 0.9352162885121547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 274}], {
             RGBColor[
             0.20764624835933113`, 0.33557975093117354`, 0.9351365187077434]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 288}], {
             RGBColor[
             0.21294330855938015`, 0.3411472970544397, 0.9354381784498378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 318}], {
             RGBColor[
             0.21280458260693721`, 0.34100148728268875`, 0.9354302782120729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 225}], {
             RGBColor[
             0.19624559498378968`, 0.32359694139030604`, 0.9344872683637615]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 235}], {
             RGBColor[
             0.18862912627732129`, 0.3155915498678, 0.9340535217384839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 261}], {
             RGBColor[
             0.18660634868245718`, 0.3134654823640909, 0.9339383275468877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 322}], {
             RGBColor[
             0.18956017104754852`, 0.31657013695295677`, 0.934106543360791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 327}], {
             RGBColor[
             0.1848862258869851, 0.3116575242439654, 0.9338403690983792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 335}], {
             RGBColor[
             0.19113672012064215`, 0.3182271899877628, 0.9341963254982084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 349}], {
             RGBColor[
             0.1912119313089536, 0.3183062417153429, 0.9342006086641177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 355}], {
             RGBColor[
             0.19607480659810572`, 0.32341743196834305`, 0.9344775422178556]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 208}], {
             RGBColor[
             0.27634222217301546`, 0.40778357498566165`, 0.9390486527898467]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 221}], {
             RGBColor[
             0.3140891047086496, 0.4418027488287358, 0.9414053462268441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[
             0.233374248060821, 0.36262150986683694`, 0.9366016902295785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 322}], {
             RGBColor[
             0.2266888241245798, 0.3555947054294877, 0.936220965226608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 335}], {
             RGBColor[
             0.22826537319767345`, 0.3572517584642937, 0.9363107473640253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 349}], {
             RGBColor[
             0.22834058438598487`, 0.3573308101918738, 0.9363150305299347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 351}], {
             RGBColor[
             0.2839106330866923, 0.41566367352388345`, 0.9394824007008676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 355}], {
             RGBColor[
             0.233203459675137, 0.36244200044487396`, 0.9365919640836726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 399}], {
             RGBColor[
             0.3088211273745378, 0.43723989163816773`, 0.941069675369404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 195}], {
             RGBColor[
             0.6312732042379722, 0.7079049527832757, 0.9663404032043308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 242}], {
             RGBColor[
             0.5891633460741419, 0.6714315101447773, 0.963657200278417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 253}], {
             RGBColor[
             0.8315602657829888, 0.5341252723143658, 0.5780805506738103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 255}], {
             RGBColor[
             0.606058461723811, 0.6860652101473173, 0.9647337421078497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 283}], {
             RGBColor[
             0.884925338733304, 0.8207038820590313, 0.6242425057097936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 312}], {
             RGBColor[
             0.6928723364666782, 0.7586931681891012, 0.9709743993376487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 332}], {
             RGBColor[
             0.8278665265086236, 0.5057335736447233, 0.5745434217731962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 356}], {
             RGBColor[
             0.8916558476180196, 0.9161964476590825, 0.9808695463369558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 360}], {
             RGBColor[
             0.7503418220523833, 0.8050370370474327, 0.9757122305140027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 364}], {
             RGBColor[
             0.8796332391054209, 0.7997224705221349, 0.619984358127655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 380}], {
             RGBColor[
             0.7791551569135652, 0.8275462332304435, 0.978584074457042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 389}], {
             RGBColor[
             0.9155257058475293, 0.9306524378746825, 0.7386464272151838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 221}], {
             RGBColor[
             0.41267584437400284`, 0.5318031923554098, 0.9475322370266106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 233}], {
             RGBColor[
             0.7128854689421396, 0.7730895863286765, 0.9426895386250231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 256}], {
             RGBColor[
             0.7238719368935342, 0.7799355863354847, 0.863740011258672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 316}], {
             RGBColor[
             0.5837905900380065, 0.6719175511327584, 0.9611081443956637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 399}], {
             RGBColor[
             0.40740786703989107`, 0.5272403351648417, 0.9471965661691704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 241}], {
             RGBColor[
             0.35276484059541724`, 0.47739540900316435`, 0.9437930699766406]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 242}], {
             RGBColor[
             0.3825084156474021, 0.5057312970269716, 0.9455940758995094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.3994035312970712, 0.5203649970295117, 0.9466706177289421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 263}], {
             RGBColor[
             0.3632251652657039, 0.4883898734545258, 0.9443887699919498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 312}], {
             RGBColor[
             0.48621740603993846`, 0.5929929550712956, 0.9529112749587412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 356}], {
             RGBColor[
             0.6850009171912799, 0.7504962345412768, 0.9628064219580481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 359}], {
             RGBColor[
             0.375153965132881, 0.49936124163672424`, 0.9451254568160093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 360}], {
             RGBColor[
             0.5436868916256435, 0.6393368239296271, 0.957649106135095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 380}], {
             RGBColor[
             0.5725002264868254, 0.6618460201126379, 0.9605209500781344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 389}], {
             RGBColor[
             0.7088707754207897, 0.764952224756877, 0.7205833028362763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 206}], {
             RGBColor[
             0.6365065028818196, 0.7122246861355508, 0.9667719599708235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 214}], {
             RGBColor[
             0.8615229927273951, 0.7108190806524803, 0.6028379622201453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 286}], {
             RGBColor[
             0.5826840049020053, 0.6656063435828412, 0.963342437992916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 332}], {
             RGBColor[
             0.8309647608435446, 0.5082040216040586, 0.5748389341298874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 334}], {
             RGBColor[
             0.9021680954325457, 0.8779962725880234, 0.6424622562871629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 366}], {
             RGBColor[
             0.9187123308959824, 0.9333119446325909, 0.748562723255582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 386}], {
             RGBColor[
             0.5930257483480736, 0.6745638419646864, 0.9640014047404548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 217}], {
             RGBColor[
             0.19977926755688577`, 0.3273110553124115, 0.9346885057891993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 231}], {
             RGBColor[
             0.19125913163260555`, 0.3183558522481745, 0.9342032966527232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 254}], {
             RGBColor[
             0.18919463052287389`, 0.31618593068491585`, 0.9340857263686796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 314}], {
             RGBColor[
             0.18703267242257346`, 0.3139135756454394, 0.9339626060531978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 369}], {
             RGBColor[
             0.18585850163943218`, 0.31267944770563044`, 0.933895738764128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 392}], {
             RGBColor[
             0.19718685275102665`, 0.3245862629828614, 0.9345408716011396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 203}], {
             RGBColor[
             0.5694035624452959, 0.6546305646490294, 0.9622535793690412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 206}], {
             RGBColor[
             0.6288429856334741, 0.7061140055023541, 0.9660410068543737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 214}], {
             RGBColor[
             0.8538594754790496, 0.7047084000192836, 0.6021070091036955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 266}], {
             RGBColor[
             0.74350964112616, 0.79962588641691, 0.9750508465456946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 310}], {
             RGBColor[
             0.8276571285797327, 0.5355745817229594, 0.5782791813938954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 384}], {
             RGBColor[
             0.8811911535814985, 0.820358675063078, 0.6244757857174054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 215}], {
             RGBColor[
             0.8474033618771311, 0.8799586173228249, 0.9038397390676208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 222}], {
             RGBColor[
             0.9699116219534045, 0.9763258350817114, 0.9020107810264453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 223}], {
             RGBColor[
             0.9239760391061387, 0.7216129997514857, 0.5202901272072924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 224}], {
             RGBColor[
             0.7432416506659434, 0.7963714338733744, 0.8949724605475597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 247}], {
             RGBColor[
             0.9030372486329088, 0.5619443631205439, 0.500289085988991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 259}], {
             RGBColor[
             0.9420801867046171, 0.9545306309034027, 0.913114429015637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 271}], {
             RGBColor[
             0.9043692525849842, 0.5721827291840494, 0.5015646144777819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 287}], {
             RGBColor[
             0.9030273761887495, 0.5618684791886028, 0.5002796321253148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 292}], {
             RGBColor[
             0.9041138184890838, 0.5702193507910247, 0.501320010499076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 345}], {
             RGBColor[
             0.9084097409587222, 0.9276827314255283, 0.9099029118424318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 350}], {
             RGBColor[
             0.6686405102956781, 0.7329620420673324, 0.8898856192140527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 353}], {
             RGBColor[
             0.9909977762454061, 0.988800838647677, 0.6720451430779383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 393}], {
             RGBColor[
             0.8553537557812887, 0.8861695254659845, 0.9046321600313321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 400}], {
             RGBColor[
             0.9054254853432643, 0.5803013970083357, 0.502576064159955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 234}], {
             RGBColor[
             0.22049169370930496`, 0.34908112844227146`, 0.9358680478172909]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 296}], {
             RGBColor[
             0.1865617818736295, 0.3134186398223141, 0.9339357895330556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 298}], {
             RGBColor[
             0.19975642982426225`, 0.3272870514074283, 0.9346872052141117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 320}], {
             RGBColor[
             0.18887757795522245`, 0.31585268833402036`, 0.934067670693989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 330}], {
             RGBColor[
             0.1913737687250167, 0.31847634310071005`, 0.9342098250655455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 347}], {
             RGBColor[
             0.1891857716327594, 0.31617661942971953`, 0.9340852218679931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 367}], {
             RGBColor[
             0.19007010120853718`, 0.31710610588359545`, 0.9341355831290852]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 398}], {
             RGBColor[
             0.18742715801975252`, 0.3143282050199061, 0.933985071424368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 273}], {
             RGBColor[
             0.5948799673171399, 0.6816316125645953, 0.9614948857902279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 281}], {
             RGBColor[
             0.5322326354554701, 0.6292900699565726, 0.956972433359562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 293}], {
             RGBColor[
             0.4899219075938762, 0.5926426440818758, 0.9542764311941287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 303}], {
             RGBColor[
             0.7798220611835203, 0.6750115727481525, 0.6002603969131654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 394}], {
             RGBColor[
             0.5116695891716139, 0.6114793927942537, 0.9556621742335425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 212}], {
             RGBColor[
             0.45268550871471924`, 0.56313574583105, 0.9509994425842794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 234}], {
             RGBColor[
             0.28726387007128157`, 0.41752052418196, 0.9397344221047603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 239}], {
             RGBColor[
             0.4173644057485659, 0.5344604832455712, 0.9482188359733204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 269}], {
             RGBColor[
             0.34049741903328384`, 0.46934348329390774`, 0.9429171723441234]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 289}], {
             RGBColor[
             0.4009029468034172, 0.5210963292936249, 0.9469229296248474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 309}], {
             RGBColor[
             0.5124790971855998, 0.6108362268976354, 0.9562827357512269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 362}], {
             RGBColor[
             0.5594312028417849, 0.6475155686854668, 0.9609624828506617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 365}], {
             RGBColor[
             0.31680424057691503`, 0.4485693265510483, 0.9414167025039941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 206}], {
             RGBColor[
             0.36944897924090714`, 0.4944198695980247, 0.9447619401596937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 211}], {
             RGBColor[
             0.27124930343896736`, 0.4023137700960795, 0.9387628961154517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 216}], {
             RGBColor[
             0.26291297700315486`, 0.3935517624584167, 0.938288154657422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 266}], {
             RGBColor[
             0.4841156347335931, 0.5879317505125805, 0.9537717798510146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 329}], {
             RGBColor[
             0.28617424693522586`, 0.4180008320067203, 0.9396128495680883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 341}], {
             RGBColor[
             0.2796765309207728, 0.4111713204965401, 0.9392428142535747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 358}], {
             RGBColor[
             0.29380332632948314`, 0.42601947816165614`, 0.9400473143533797]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 229}], {
             RGBColor[
             0.18893129430891603`, 0.3159091476275659, 0.9340707297608657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 237}], {
             RGBColor[
             0.18108298927677668`, 0.3076600814275077, 0.9336237803998122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 307}], {
             RGBColor[
             0.17948540198595286`, 0.30598091589196724`, 0.9335328001670183]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 343}], {
             RGBColor[
             0.1903303530090651, 0.3173796470268675, 0.9341504040841173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 232}], {
             RGBColor[
             0.18775686622597437`, 0.3146747492493529, 0.9340038478189527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 277}], {
             RGBColor[
             0.18513416241600078`, 0.31191812125604473`, 0.9338544887169173]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 373}], {
             RGBColor[
             0.19156946915989134`, 0.31868203666588757`, 0.9342209699157987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 390}], {
             RGBColor[
             0.19906834334491935`, 0.32656382889043634`, 0.9346480197070459]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 266}], {
             RGBColor[
             0.5435550579217713, 0.6394151913659053, 0.9575592073363473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 286}], {
             RGBColor[
             0.375065904449271, 0.49928496789863985`, 0.9451198456671187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 386}], {
             RGBColor[
             0.3854076478953393, 0.5082424662804851, 0.9457788124146576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 231}], {
             RGBColor[
             0.1913619669815575, 0.3184639387200607, 0.9342091529737147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 280}], {
             RGBColor[
             0.200223112625469, 0.32777756462089525`, 0.9347137821092452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 291}], {
             RGBColor[
             0.19348889841744987`, 0.3206994785144255, 0.9343302785724756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 368}], {
             RGBColor[
             0.18767517326657374`, 0.3145888847693901, 0.9339991955257688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 372}], {
             RGBColor[
             0.18573202091371066`, 0.31254650844355597`, 0.9338885358739095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 387}], {
             RGBColor[
             0.18852965084716983`, 0.3154869948836043, 0.9340478567598975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 392}], {
             RGBColor[
             0.1972896880999786, 0.3246943494547476, 0.9345467279221311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 221}], {
             RGBColor[
             0.3321648835388723, 0.4608015384498717, 0.9424347350905069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 225}], {
             RGBColor[
             0.2514500268910438, 0.38162029948797277`, 0.9376310790932412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 323}], {
             RGBColor[
             0.3575199332630081, 0.48276280813906464`, 0.9440503364383386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 351}], {
             RGBColor[
             0.301986411916915, 0.43466246314501933`, 0.9405117895645303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 388}], {
             RGBColor[
             0.28259974438226976`, 0.4143606275774112, 0.9394050094224892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 395}], {
             RGBColor[
             0.366549438606146, 0.4905837118311563, 0.9446256885343254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 286}], {
             RGBColor[
             0.29314447532730914`, 0.4242883377578022, 0.9400478236897936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 290}], {
             RGBColor[
             0.2612876379800373, 0.3919602524830736, 0.938191316491318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 304}], {
             RGBColor[
             0.2736580263748165, 0.40496231501391133`, 0.9388957918100511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 338}], {
             RGBColor[
             0.23759083072429804`, 0.3670534055929334, 0.9368418183743885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 386}], {
             RGBColor[
             0.30348621877337745`, 0.4332458361396474, 0.9407067904373323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 230}], {
             RGBColor[
             0.2334030426063412, 0.36265177475985827`, 0.9366033300363481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 258}], {
             RGBColor[
             0.24166666616429894`, 0.371337367063267, 0.9370739311730383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 264}], {
             RGBColor[
             0.2528298194491141, 0.3830705489504057, 0.9377096562382032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 279}], {
             RGBColor[
             0.2223588131160111, 0.3510435893209275, 0.9359743775053473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 328}], {
             RGBColor[
             0.2385161810587667, 0.36802600746505976`, 0.9368945157070033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 394}], {
             RGBColor[
             0.30165291276591666`, 0.42986750752233627`, 0.9406555295205197]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 216}], {
             RGBColor[
             0.22415272438939332`, 0.35292910380979625`, 0.9360765380985124]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 238}], {
             RGBColor[
             0.21668562529693003`, 0.34508070922219014`, 0.9356512978517798]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 341}], {
             RGBColor[
             0.24091627830701134`, 0.3705486618479197, 0.9370311976946651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 358}], {
             RGBColor[
             0.2550430737157216, 0.3853968195130357, 0.9378356977944702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 239}], {
             RGBColor[
             0.542458414688152, 0.6394312043737607, 0.9571234599763494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 289}], {
             RGBColor[
             0.5259969557430033, 0.6260670504218144, 0.9558275536278764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 309}], {
             RGBColor[
             0.6375731061251859, 0.7158069480258249, 0.965187359754256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 362}], {
             RGBColor[
             0.6845252117813709, 0.7524862898136562, 0.9698671068536907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 385}], {
             RGBColor[
             0.7860985506073723, 0.8292872838004639, 0.7968353358505167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 215}], {
             RGBColor[
             0.5157421665105038, 0.6132928535993672, 0.9566471217151071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 227}], {
             RGBColor[
             0.29970260204538113`, 0.43079580390036054`, 0.94043541584355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 259}], {
             RGBColor[
             0.6104189913379899, 0.6878648671799451, 0.9659218116631232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 306}], {
             RGBColor[
             0.2738566580723743, 0.4036300780572341, 0.9389635275699348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 308}], {
             RGBColor[
             0.2691305631056292, 0.398662652595457, 0.9386943834532097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 345}], {
             RGBColor[
             0.5767485455920949, 0.6610169677020706, 0.962710294489918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 350}], {
             RGBColor[
             0.33697931492905076`, 0.46629627834387477`, 0.942693001861539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 378}], {
             RGBColor[
             0.2828251978811075, 0.4130565820344796, 0.9394742726442766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 257}], {
             RGBColor[
             0.9241708234933428, 0.7599031818045514, 0.5786645333196092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 310}], {
             RGBColor[
             0.8527190352209195, 0.3739582811888842, 0.19685354443386982`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 332}], {
             RGBColor[
             0.8483631502363858, 0.34047704043678684`, 0.1926823440534119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 389}], {
             RGBColor[
             0.9360223295752915, 0.7653959046667461, 0.35678534949539953`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 224}], {
             RGBColor[
             0.6019092601655756, 0.6867200928189938, 0.9624709353645509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 227}], {
             RGBColor[
             0.4900314069116405, 0.5878102265694376, 0.9551265080130549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 259}], {
             RGBColor[
             0.8007477962042493, 0.8448792898490222, 0.9806129038326282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 345}], {
             RGBColor[
             0.7670773504583543, 0.8180313903711476, 0.977401386659423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 350}], {
             RGBColor[
             0.5273081197953102, 0.6233107010129518, 0.9573840940310441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 353}], {
             RGBColor[
             0.8496653857450382, 0.8791494975932964, 0.7395436178949295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 393}], {
             RGBColor[
             0.7140213652809209, 0.7765181844116039, 0.9721306348483233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 400}], {
             RGBColor[
             0.7640930948428964, 0.47065005595395515`, 0.5700745389769464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 229}], {
             RGBColor[
             0.2068690748506942, 0.33476289229794964`, 0.9350922598261517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 294}], {
             RGBColor[
             0.21277466253925434`, 0.3409700393945122, 0.9354285743084811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 329}], {
             RGBColor[
             0.23907766788565177`, 0.368616165720437, 0.936926491551149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 340}], {
             RGBColor[
             0.2436041993290528, 0.3733738372661213, 0.9371842708204476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 341}], {
             RGBColor[
             0.2325799518711988, 0.3617866542102568, 0.9365564562366354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 343}], {
             RGBColor[
             0.20826813355084325`, 0.33623339169725125`, 0.9351719341494034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 358}], {
             RGBColor[
             0.24670674727990904`, 0.37663481187537284`, 0.9373609563364405]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 231}], {
             RGBColor[
             0.19972682323934088`, 0.32725593300951006`, 0.9346855191628995]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 254}], {
             RGBColor[
             0.1976623221296092, 0.32508601144625143`, 0.934567948878856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 314}], {
             RGBColor[
             0.1955003640293088, 0.322813656406775, 0.9344448285633742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 331}], {
             RGBColor[
             0.22460790707912992`, 0.3534075296769589, 0.9361024600793104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 392}], {
             RGBColor[
             0.20565454435776198`, 0.333486343744197, 0.935023094111316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 222}], {
             RGBColor[
             0.7556819189936763, 0.8084691579297268, 0.9631032253183853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 276}], {
             RGBColor[
             0.46966080217049366`, 0.5783141439540027, 0.951949779691809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 282}], {
             RGBColor[
             0.4376499441056336, 0.5505879476107286, 0.9499100761220066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 305}], {
             RGBColor[
             0.42916789405553485`, 0.5422531768418173, 0.9494057845729981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 339}], {
             RGBColor[
             0.47111694262023773`, 0.5795753796238241, 0.9520425636736524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 361}], {
             RGBColor[
             0.4849252020484565, 0.5915353999172487, 0.952922413754254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 382}], {
             RGBColor[
             0.44118615700326724`, 0.5536508374874307, 0.9501354004808935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 384}], {
             RGBColor[
             0.7469305423915883, 0.7141446268230167, 0.6119725391027997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 248}], {
             RGBColor[
             0.1809198934930053, 0.30748865741789405`, 0.933614492336205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 251}], {
             RGBColor[
             0.1819264333571092, 0.30854659463338063`, 0.9336718132924233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 260}], {
             RGBColor[
             0.1839290162486566, 0.31065143622348573`, 0.9337858574255411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 352}], {
             RGBColor[
             0.1830449444132805, 0.30972222067111355`, 0.9337355108423835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 396}], {
             RGBColor[
             0.18205118127193512`, 0.30867771260133725`, 0.9336789175016247]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 256}], {
             RGBColor[
             0.6811078585940378, 0.7429531062730206, 0.8609992027595657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 316}], {
             RGBColor[
             0.5410265117385101, 0.6349350710702945, 0.9583673358965574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 351}], {
             RGBColor[
             0.33973329445254913`, 0.4686816369880935, 0.9428684830015278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 399}], {
             RGBColor[
             0.36464378874039466`, 0.49025785510237774`, 0.9444557576700642]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 223}], {
             RGBColor[
             0.9051519086820443, 0.7083288764559916, 0.5859596439831081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 224}], {
             RGBColor[
             0.724417520241849, 0.7830873105778803, 0.9606419773233753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 247}], {
             RGBColor[
             0.8842131182088144, 0.5486602398250497, 0.5659586027648067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 259}], {
             RGBColor[
             0.9232560562805229, 0.9412465076079086, 0.9787839457914527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 292}], {
             RGBColor[
             0.8852896880649895, 0.5569352274955306, 0.5669895272748917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 363}], {
             RGBColor[
             0.6628066494410058, 0.7309294373629389, 0.9563828644799877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 383}], {
             RGBColor[
             0.6547025238599551, 0.723910051109828, 0.9558664767641599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 393}], {
             RGBColor[
             0.8365296253571944, 0.8728854021704904, 0.9703016768071477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 247}], {
             RGBColor[
             0.8382775353615486, 0.29394740449482404`, 0.18423794894565387`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 292}], {
             RGBColor[
             0.8393541052177236, 0.30222239216530483`, 0.1852688734557389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 319}], {
             RGBColor[
             0.845830354553812, 0.35200168247303465`, 0.19147053713385456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 385}], {
             RGBColor[
             0.9268169546976089, 0.7220420708837272, 0.4190027976388401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 393}], {
             RGBColor[
             0.7905940425099285, 0.6181725668402647, 0.5885810229879949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 400}], {
             RGBColor[
             0.8406657720719041, 0.3123044383826159, 0.18652492711661786`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 227}], {
             RGBColor[
             0.3858696957004528, 0.504223043119987, 0.9462592294929938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 259}], {
             RGBColor[
             0.6965860849930616, 0.7612921063995717, 0.9717456253125671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 363}], {
             RGBColor[
             0.4361366781535445, 0.5509750361546019, 0.9493445440011021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 383}], {
             RGBColor[
             0.42803255257249384`, 0.5439556499014909, 0.9488281562852744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 393}], {
             RGBColor[
             0.6098596540697332, 0.6929310009621534, 0.9632633563282622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 235}], {
             RGBColor[
             0.20086558407238086`, 0.32845284284664206`, 0.9347503699076954]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 261}], {
             RGBColor[
             0.19884280647751676`, 0.32632677534293286`, 0.9346351757160992]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 322}], {
             RGBColor[
             0.2017966288426081, 0.3294314299317988, 0.9348033915300026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 327}], {
             RGBColor[
             0.19712268368204472`, 0.3245188172228074, 0.9345372172675908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 335}], {
             RGBColor[
             0.20337317791570175`, 0.3310884829666048, 0.93489317366742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 349}], {
             RGBColor[
             0.2034483891040132, 0.3311675346941849, 0.9348974568333293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 355}], {
             RGBColor[
             0.2083112643931653, 0.336278724947185, 0.9351743903870672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 252}], {
             RGBColor[
             0.19892295516503677`, 0.32641101669523676`, 0.9346397400652842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 274}], {
             RGBColor[
             0.1975222198425889, 0.324938755059595, 0.9345599702608729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 288}], {
             RGBColor[
             0.20281928004263788`, 0.3305063011828612, 0.9348616300029674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 315}], {
             RGBColor[
             0.186507225222572, 0.3133612973229612, 0.9339326826124872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 318}], {
             RGBColor[
             0.20268055409019498`, 0.33036049141111024`, 0.9348537297652024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 322}], {
             RGBColor[
             0.1935079091107788, 0.32071945995846174`, 0.9343313612033369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 243}], {
             RGBColor[
             0.2526928974888643, 0.38292663528882953`, 0.9377018587351249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 306}], {
             RGBColor[
             0.248145898473511, 0.3781474510273044, 0.9374429138678827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 311}], {
             RGBColor[
             0.23829401063491945`, 0.3677924922631779, 0.9368818634300369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 346}], {
             RGBColor[
             0.23870901568862182`, 0.3682286888874592, 0.9369054973539003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 350}], {
             RGBColor[
             0.3112685553301875, 0.44081365131394507`, 0.9411723881594869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 363}], {
             RGBColor[
             0.3242588248996095, 0.45206516990504564`, 0.9420001166496061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 383}], {
             RGBColor[
             0.3161546993185588, 0.44504578365193476`, 0.9414837289337784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 276}], {
             RGBColor[
             0.3015266164865197, 0.4277543234766833, 0.9407208506945814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 282}], {
             RGBColor[
             0.26951575842165965`, 0.40002812713340913`, 0.938681147124779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 301}], {
             RGBColor[
             0.2369380396545014, 0.36636728078923275`, 0.9368046428886814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 305}], {
             RGBColor[
             0.26103370837156087`, 0.39169335636449776`, 0.9381768555757705]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 382}], {
             RGBColor[
             0.27305197131929326`, 0.4030910170101112, 0.9389064714836659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 294}], {
             RGBColor[
             0.20382733943636777`, 0.33156583552032837`, 0.9349190374941501]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 307}], {
             RGBColor[
             0.18847585942484443`, 0.31543045668816716`, 0.9340447934179733]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[
             0.2301303447827652, 0.3592119618462532, 0.9364169547368181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 340}], {
             RGBColor[
             0.23465687622616624`, 0.36396963339193744`, 0.9366747340061166]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 343}], {
             RGBColor[
             0.1993208104479567, 0.32682918782306747`, 0.9346623973350723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 258}], {
             RGBColor[
             0.22938899732612533`, 0.3584327586651811, 0.9363747360958877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 264}], {
             RGBColor[
             0.2405521506109405, 0.3701659405523198, 0.9370104611610526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 279}], {
             RGBColor[
             0.2100811442778375, 0.33813898092284156`, 0.9352751824281966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 299}], {
             RGBColor[
             0.20475753633962784`, 0.33254353144354476`, 0.9349720108316877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 300}], {
             RGBColor[
             0.2086431877242838, 0.3366275974133453, 0.9351932929297377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 328}], {
             RGBColor[
             0.2262385122205931, 0.35512139906697393`, 0.9361953206298528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 331}], {
             RGBColor[
             0.21608777115484973`, 0.34445232661272185`, 0.9356172509428343]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 369}], {
             RGBColor[
             0.1858060573218873, 0.312624325402729, 0.9338927521378282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 372}], {
             RGBColor[
             0.18557674124721385`, 0.3123832996687683, 0.9338796929266182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 392}], {
             RGBColor[
             0.1971344084334818, 0.32453114067996, 0.9345378849748398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 277}], {
             RGBColor[
             0.18773724237763328`, 0.31465412334052256`, 0.9340027302698206]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 373}], {
             RGBColor[
             0.19417254912152382`, 0.3214180387503654, 0.934369211468702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 390}], {
             RGBColor[
             0.20167142330655186`, 0.3292998309749142, 0.9347962612599492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 256}], {
             RGBColor[
             0.9813174831621745, 0.9842395002462874, 0.8561565043579783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 257}], {
             RGBColor[
             0.9698756400386146, 0.9770538821816868, 0.9358768631099392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 310}], {
             RGBColor[
             0.8984238517661913, 0.5911089815660195, 0.5540658742241997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 316}], {
             RGBColor[
             0.8412361363066468, 0.8762214650435611, 0.9535246374949702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 389}], {
             RGBColor[
             0.9817271461205633, 0.9825466050438816, 0.7139976792857294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 298}], {
             RGBColor[
             0.22620097648238727`, 0.3550819466262163, 0.936193183025091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 365}], {
             RGBColor[
             0.27647661087306347`, 0.4079248260301478, 0.9390563060275041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 261}], {
             RGBColor[
             0.19122633777104836`, 0.31832138382042696`, 0.9342014290908216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 322}], {
             RGBColor[
             0.1941801601361397, 0.32142603840929285`, 0.934369644904725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 327}], {
             RGBColor[
             0.1895062149755763, 0.31651342570030144`, 0.934103470642313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 335}], {
             RGBColor[
             0.19575670920923333`, 0.32308309144409886`, 0.9344594270421422]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 349}], {
             RGBColor[
             0.19583192039754477`, 0.3231621431716789, 0.9344637102080516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 355}], {
             RGBColor[
             0.2006947956866969, 0.3282733334246791, 0.9347406437617896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 262}], {
             RGBColor[
             0.4369845815472029, 0.5513866495573997, 0.9494877616771007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 284}], {
             RGBColor[
             0.6247504035752902, 0.7047458827568778, 0.9646230139836673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 334}], {
             RGBColor[
             0.7349237676396162, 0.7451154652166593, 0.6272347577119612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 366}], {
             RGBColor[
             0.7514680031030527, 0.8004311372612268, 0.7333352246803804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 376}], {
             RGBColor[
             0.397907468442853, 0.5154535439144465, 0.9470741986312354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 397}], {
             RGBColor[
             0.4369077612514729, 0.5513201116783387, 0.9494828667557864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 307}], {
             RGBColor[
             0.1806275543927051, 0.307181390488109, 0.9335978440569198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 324}], {
             RGBColor[
             0.18395646599811732`, 0.31068028765058353`, 0.9337874206481647]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 269}], {
             RGBColor[
             0.4302703250067166, 0.5456389418366184, 0.9490411897361934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 309}], {
             RGBColor[
             0.6022520031590326, 0.6871316854403461, 0.9624067531432969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 323}], {
             RGBColor[
             0.4638795886223883, 0.5747495967298069, 0.9511827422942791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 362}], {
             RGBColor[
             0.6492041088152176, 0.7238110272281775, 0.9670865002427318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 365}], {
             RGBColor[
             0.4065771465503478, 0.524864785093759, 0.9475407198960643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 377}], {
             RGBColor[
             0.3809157120608543, 0.4978929904163819, 0.9460793391645779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 385}], {
             RGBColor[
             0.750777447641219, 0.8006120212149852, 0.7940547292395577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 388}], {
             RGBColor[
             0.38895939974165, 0.5063474161681534, 0.9465374152784297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 272}], {
             RGBColor[
             0.18799208314490007`, 0.3149219771447579, 0.9340172430745133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 342}], {
             RGBColor[
             0.18286346184170274`, 0.30953147098172573`, 0.9337251756784115]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 374}], {
             RGBColor[
             0.18148468566837106`, 0.3080822898040957, 0.933646656415057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 242}], {
             RGBColor[
             0.31065498243158685`, 0.4409219663646659, 0.9411098670507269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 255}], {
             RGBColor[
             0.32755009808125596`, 0.4555556663672059, 0.9421864088801596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 312}], {
             RGBColor[
             0.41436397282412324`, 0.5281836244089898, 0.9484270661099586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 331}], {
             RGBColor[
             0.26094013118712034`, 0.3915950008105146, 0.9381715264935517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 359}], {
             RGBColor[
             0.3033005319170658, 0.43455191097441853`, 0.9406412479672268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 360}], {
             RGBColor[
             0.4718334584098283, 0.5745274932673213, 0.9531648972863125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 380}], {
             RGBColor[
             0.5006467932710101, 0.5970366894503322, 0.9560367412293518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 392}], {
             RGBColor[
             0.24198676846575243`, 0.37167381487775275`, 0.9370921605255572]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 255}], {
             RGBColor[
             0.3572936731332409, 0.48389155439101317`, 0.9439874148030284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 312}], {
             RGBColor[
             0.4441075478761082, 0.5565195124327971, 0.9502280720328274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 331}], {
             RGBColor[
             0.2906837062391053, 0.4199308888343219, 0.9399725324164205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 380}], {
             RGBColor[
             0.5303903683229951, 0.6253725774741394, 0.9578377471522206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 267}], {
             RGBColor[
             0.2144789920516021, 0.342761397772722, 0.9355256333528797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 275}], {
             RGBColor[
             0.21276908993785693`, 0.3409641822371201, 0.9354282569570754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 311}], {
             RGBColor[
             0.21699506567726595`, 0.34540595068157653`, 0.9356689200236639]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 326}], {
             RGBColor[
             0.23648276332684243`, 0.36588875650267677`, 0.9367787155753422]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 344}], {
             RGBColor[
             0.2114782278514492, 0.3396074043389222, 0.9353547442709138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 346}], {
             RGBColor[
             0.21741007073096835`, 0.3458421473058579, 0.9356925539475274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 363}], {
             RGBColor[
             0.302959879941956, 0.42967862832344433`, 0.9407871732432331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 383}], {
             RGBColor[
             0.29485575436090533`, 0.42265924207033345`, 0.9402707855274055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 302}], {
             RGBColor[
             0.18853043849765405`, 0.3154878227542032, 0.9340479016154273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 352}], {
             RGBColor[
             0.1906398234149592, 0.3177049200450192, 0.9341680279659126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 396}], {
             RGBColor[
             0.1896460602736138, 0.31666041197524286`, 0.9341114346251538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 248}], {
             RGBColor[
             0.19980719089443424`, 0.32734040451061686`, 0.9346900959819637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 251}], {
             RGBColor[
             0.20081373075853814`, 0.3283983417261034, 0.9347474169381822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 260}], {
             RGBColor[
             0.20281631365008554`, 0.33050318331620854`, 0.9348614610713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 326}], {
             RGBColor[
             0.22913658446266597`, 0.35816745674178546`, 0.9363603615567251]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 271}], {
             RGBColor[
             0.8186707488403941, 0.14451713392738777`, 0.16551243621614334`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 287}], {
             RGBColor[
             0.8173288724441594, 0.1342028839319411, 0.1642274538636763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 292}], {
             RGBColor[
             0.8184153147444937, 0.14255375553436297`, 0.16526783223743757`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 319}], {
             RGBColor[
             0.8248915640805821, 0.1923330458420928, 0.17146949591555327`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 362}], {
             RGBColor[
             0.8043048253983777, 0.4855724402659776, 0.5720335274237128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 385}], {
             RGBColor[
             0.9058781642243791, 0.5623734342527853, 0.3990017564205388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 393}], {
             RGBColor[
             0.7696552520366986, 0.45850393020932284`, 0.5685799817696936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 400}], {
             RGBColor[
             0.8197269815986742, 0.15263580175167407`, 0.16652388589831657`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 251}], {
             RGBColor[
             0.1839193268501145, 0.3106412520512747, 0.9337853056286283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 260}], {
             RGBColor[
             0.1859219097416619, 0.3127460936413798, 0.933899349761746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 275}], {
             RGBColor[
             0.18852850716525682`, 0.3154857928014001, 0.9340477916289045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 268}], {
             RGBColor[
             0.18564105657677243`, 0.3124508991579618, 0.9338833555894905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 279}], {
             RGBColor[
             0.19132944320701362`, 0.3184297541708887, 0.934207300792869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 299}], {
             RGBColor[
             0.186005835268804, 0.3128343046915919, 0.9339041291963601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 300}], {
             RGBColor[
             0.18989148665345995`, 0.3169183706613924, 0.9341254112944102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 370}], {
             RGBColor[
             0.18458433002004276`, 0.31134021254650546`, 0.9338231765753717]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 265}], {
             RGBColor[
             0.19635832810443649`, 0.32371543104779843`, 0.9344936883482087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 321}], {
             RGBColor[
             0.18913677562513462`, 0.3161251215191795, 0.934082431617842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 325}], {
             RGBColor[
             0.21599606078555122`, 0.34435593319981583`, 0.9356120281729761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 375}], {
             RGBColor[
             0.19825790374427554`, 0.32571200548532114`, 0.9346018663707272]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 381}], {
             RGBColor[
             0.19153445496524343`, 0.31864523452728444`, 0.9342189759092124]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 260}], {
             RGBColor[
             0.1869284496057658, 0.31380403085686637`, 0.9339566707179645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 275}], {
             RGBColor[
             0.1895350470293607, 0.3165437300168866, 0.9341051125851229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 274}], {
             RGBColor[
             0.20454056169243495`, 0.3323154773323579, 0.9349596544465153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 288}], {
             RGBColor[
             0.20983762189248398`, 0.33788302345562404`, 0.9352613141886098]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 318}], {
             RGBColor[
             0.20969889594004104`, 0.3377372136838731, 0.9352534139508448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 283}], {
             RGBColor[
             0.878557469851581, 0.4812239884723157, 0.21791952880036536`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 332}], {
             RGBColor[
             0.8214986576269006, 0.1662536800580077, 0.16822044486376803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 334}], {
             RGBColor[
             0.8927019922159016, 0.5360459310419723, 0.23584376702104354`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 364}], {
             RGBColor[
             0.8732653702236979, 0.4602425769354192, 0.2136613812182268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 366}], {
             RGBColor[
             0.9092462276793383, 0.5913616030865398, 0.3419442339894627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 391}], {
             RGBColor[
             0.8227133050515791, 0.17558999242598253`, 0.16938359260938823`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 314}], {
             RGBColor[
             0.1849157269952969, 0.31168853177927935`, 0.9338420491428545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 369}], {
             RGBColor[
             0.1837415562121556, 0.31045440383947037`, 0.9337751818537847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 312}], {
             RGBColor[
             0.46100266352577723`, 0.571153212435337, 0.9513046138622602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 331}], {
             RGBColor[
             0.30757882188877433`, 0.4345645888368619, 0.9410490742458533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 356}], {
             RGBColor[
             0.6597861746771188, 0.7286564919053182, 0.9611997608615672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 359}], {
             RGBColor[
             0.3499392226187198, 0.4775214990007658, 0.9435187957195283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 360}], {
             RGBColor[
             0.5184721491114823, 0.6174970812936685, 0.956042445038614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 380}], {
             RGBColor[
             0.5472854839726642, 0.6400062774766795, 0.9589142889816533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 310}], {
             RGBColor[
             0.9094103197175858, 0.5979549815728277, 0.4751163468578484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 316}], {
             RGBColor[
             0.8522226042580414, 0.8830674650503693, 0.8745751101286188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 319}], {
             RGBColor[
             0.9123741671932073, 0.6207364120366994, 0.4779545305476905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 384}], {
             RGBColor[
             0.9629443447193516, 0.8827390749129462, 0.5213129511813582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 310}], {
             RGBColor[
             0.8979684765940259, 0.5907693635082272, 0.5548367056098094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 356}], {
             RGBColor[
             0.9574019127188883, 0.9677509967704889, 0.9569916297931109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 360}], {
             RGBColor[
             0.816087887153252, 0.8565915861588391, 0.9518343139701578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 389}], {
             RGBColor[
             0.981271770948398, 0.982206986986089, 0.7147685106713391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 264}], {
             RGBColor[
             0.24881577416889822`, 0.37885153285572853`, 0.9374810622977428]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 279}], {
             RGBColor[
             0.2183447678357952, 0.34682457322625027`, 0.9357457835648868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 281}], {
             RGBColor[
             0.318201913769557, 0.44345916858997797`, 0.9417371947060786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 300}], {
             RGBColor[
             0.21690681128224154`, 0.345313189716754, 0.9356638940664279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 328}], {
             RGBColor[
             0.23450213577855084`, 0.36380699137038264`, 0.936665921766543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 394}], {
             RGBColor[
             0.29763886748570073`, 0.42564849142765915`, 0.9404269355800592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 271}], {
             RGBColor[
             0.8577136869121025, 0.5371034017102467, 0.5783377792427893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 287}], {
             RGBColor[
             0.8563718105158677, 0.5267891517148, 0.5770527968903222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 292}], {
             RGBColor[
             0.8574582528162021, 0.5351400233172219, 0.5780931752640834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 345}], {
             RGBColor[
             0.8617541752858404, 0.8926034039517254, 0.9866760766074392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 350}], {
             RGBColor[
             0.6219849446227963, 0.6978827145935297, 0.9666587839790601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 353}], {
             RGBColor[
             0.9443422105725244, 0.9537215111738743, 0.7488183078429457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 393}], {
             RGBColor[
             0.808698190108407, 0.8510901979921818, 0.9814053247963395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 400}], {
             RGBColor[
             0.8587699196703826, 0.545222069534533, 0.5793492289249624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 327}], {
             RGBColor[
             0.1874834373807122, 0.31438735819659225`, 0.9339882764507168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 335}], {
             RGBColor[
             0.19373393161436922`, 0.3209570239403897, 0.934344232850546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 349}], {
             RGBColor[
             0.19380914280268063`, 0.32103607566796977`, 0.9343485160164554]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 355}], {
             RGBColor[
             0.19867201809183277`, 0.32614726592096993`, 0.9346254495701933]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 284}], {
             RGBColor[
             0.5520990373737982, 0.6433480852372535, 0.9595712205145508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 325}], {
             RGBColor[
             0.3013026030921642, 0.42887910004945207`, 0.9406582888215985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 376}], {
             RGBColor[
             0.3252561022413611, 0.4540557463948223, 0.9420224051621189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 397}], {
             RGBColor[
             0.364256395049981, 0.48992231415871446`, 0.9444310732866698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 336}], {
             RGBColor[
             0.2683165494931898, 0.3993480841421268, 0.9385916026036494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 359}], {
             RGBColor[
             0.31376085658735253`, 0.4455463754257799, 0.941236947982536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 360}], {
             RGBColor[
             0.48229378308011506`, 0.5855219577186828, 0.9537605973016217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 279}], {
             RGBColor[
             0.22950792112061041`, 0.35855775511338905`, 0.9363815086300517]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 281}], {
             RGBColor[
             0.3293650670543722, 0.4551923504771167, 0.9423729197712435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 328}], {
             RGBColor[
             0.24566528906336602`, 0.3755401732575213, 0.9373016468317077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 394}], {
             RGBColor[
             0.30880202077051594`, 0.4373816733147978, 0.941062660645224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 321}], {
             RGBColor[
             0.19177497299708612`, 0.31889803422847507`, 0.9342326730553113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 325}], {
             RGBColor[
             0.2186342581575027, 0.34712884590911136`, 0.9357622696104455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 375}], {
             RGBColor[
             0.20089610111622702`, 0.32848491819461667`, 0.9347521078081966]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 381}], {
             RGBColor[
             0.19417265233719494`, 0.3214181472365799, 0.9343692173466818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 358}], {
             RGBColor[
             0.4679094050103473, 0.5710147999295367, 0.9528445815300333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 384}], {
             RGBColor[
             0.7959032258697958, 0.7536598609266292, 0.6159939861993788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 275}], {
             RGBColor[
             0.19585412945824818`, 0.323185486302614, 0.9344649749812033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 306}], {
             RGBColor[
             0.20993199303624877`, 0.33798221351119695`, 0.9352666884856375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 311}], {
             RGBColor[
             0.20008010519765723`, 0.3276272547470704, 0.9347056380477918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 317}], {
             RGBColor[
             0.1930340826347562, 0.32022143828982824`, 0.9343043774864909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 344}], {
             RGBColor[
             0.1945632673718405, 0.321828708404416, 0.9343914622950418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 346}], {
             RGBColor[
             0.20049511025135958`, 0.32806345137135173`, 0.9347292719716551]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 354}], {
             RGBColor[
             0.19683262012965425`, 0.3242139420381536, 0.9345206985773926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 279}], {
             RGBColor[
             0.19334852815726622`, 0.3205519404709839, 0.9343222846938173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 299}], {
             RGBColor[
             0.18802492021905656`, 0.3149564909916871, 0.9340191130973085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 300}], {
             RGBColor[
             0.1919105716037125, 0.31904055696148764`, 0.9342403951953585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 370}], {
             RGBColor[
             0.18660341497029534`, 0.3134623988466007, 0.9339381604763201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 371}], {
             RGBColor[
             0.1838466718007321, 0.3105648869877775, 0.9337811680310495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 309}], {
             RGBColor[
             0.5253850164437505, 0.6220146854886827, 0.9571050895141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 323}], {
             RGBColor[
             0.38701260190710624`, 0.5096325967781434, 0.9458810786650822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 362}], {
             RGBColor[
             0.5723371220999356, 0.658694027276514, 0.9617848366135348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 365}], {
             RGBColor[
             0.3297101598350657, 0.4597477851420956, 0.9422390562668672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 377}], {
             RGBColor[
             0.30404872534557215`, 0.4327759904647185, 0.9407776755353809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 388}], {
             RGBColor[
             0.3120924130263679, 0.44123041621648995`, 0.9412357516492327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 336}], {
             RGBColor[
             0.2213730230293102, 0.3500074614371033, 0.9359182382182554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 357}], {
             RGBColor[
             0.1969743042117703, 0.32436286099174727`, 0.9345287672762663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 287}], {
             RGBColor[
             0.8186608763962349, 0.14444124999544666`, 0.16550298235246705`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 292}], {
             RGBColor[
             0.8197473186965691, 0.15279212159786854`, 0.16654336072622833`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 303}], {
             RGBColor[
             0.8569664054518005, 0.38299924589270967`, 0.19999647199586007`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 333}], {
             RGBColor[
             0.8868896427416582, 0.5599013471362418, 0.5649582086174862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 337}], {
             RGBColor[
             0.8884909872626653, 0.561095627258048, 0.562247550040962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 345}], {
             RGBColor[
             0.8240432411662075, 0.5102555022323721, 0.5751262620695841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 353}], {
             RGBColor[
             0.9066312764528914, 0.571373609454521, 0.33726849330509057`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 385}], {
             RGBColor[
             0.9072101681764545, 0.5726118003162909, 0.40027728490932957`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 391}], {
             RGBColor[
             0.820118482997181, 0.15564505305760412`, 0.1668987880796643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 400}], {
             RGBColor[
             0.8210589855507496, 0.16287416781517963`, 0.16779941438710733`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 308}], {
             RGBColor[
             0.20474955864050876`, 0.33253514637595527`, 0.9349715565135248]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 342}], {
             RGBColor[
             0.19152273141080622`, 0.31863291232825464`, 0.9342183082701306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 348}], {
             RGBColor[
             0.1988777254844435, 0.3263634774332058, 0.9346371643018856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 374}], {
             RGBColor[
             0.19014395523747457`, 0.3171837311506246, 0.934139789006776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 375}], {
             RGBColor[
             0.1997235147350348, 0.3272524555617131, 0.9346853307484737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 378}], {
             RGBColor[
             0.2184441934159871, 0.34692907581497784`, 0.9357514457045917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 281}], {
             RGBColor[
             0.46139853851670076`, 0.5721415288193888, 0.9511515046102453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 293}], {
             RGBColor[
             0.4190878106551068, 0.5354941029446921, 0.9484555024448121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 394}], {
             RGBColor[
             0.4408354922328445, 0.55433085165707, 0.9498412454842259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 288}], {
             RGBColor[
             0.20843688657003606`, 0.3364107618199823, 0.9351815443841986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 318}], {
             RGBColor[
             0.20829816061759315`, 0.33626495204823137`, 0.9351736441464337]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 311}], {
             RGBColor[
             0.19837020308391207`, 0.32583003921146847`, 0.9346082616519875]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 317}], {
             RGBColor[
             0.19132418052101102`, 0.3184242227542263, 0.9342070010906866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 344}], {
             RGBColor[
             0.19285336525809532`, 0.32003149286881416`, 0.9342940858992375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 346}], {
             RGBColor[
             0.1987852081376144, 0.3262662358357499, 0.9346318955758508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 282}], {
             RGBColor[
             0.3470343998180849, 0.475005487491495, 0.9433337029793059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 301}], {
             RGBColor[
             0.3144566810509267, 0.44134464114731864`, 0.9414571987432081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 305}], {
             RGBColor[
             0.33855234976798615`, 0.46667071672258365`, 0.9428294114302973]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 339}], {
             RGBColor[
             0.38050139833268903`, 0.5039929195045905, 0.9454661905309516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 361}], {
             RGBColor[
             0.3943096577609078, 0.5159529397980152, 0.9463460406115533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 382}], {
             RGBColor[
             0.35057061271571854`, 0.4780683773681971, 0.9435590273381926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 373}], {
             RGBColor[
             0.19154984531155025`, 0.31866141075705723`, 0.9342198523666666]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 390}], {
             RGBColor[
             0.19904871949657826`, 0.326543202981606, 0.9346469021579138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 296}], {
             RGBColor[
             0.1835851599868279, 0.3102900214905575, 0.9337662753201197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 302}], {
             RGBColor[
             0.19139766926121787`, 0.31850146407963903`, 0.9342111861657245]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 330}], {
             RGBColor[
             0.18839714683821507`, 0.31534772476895345`, 0.9340403108526096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 367}], {
             RGBColor[
             0.18709347932173553`, 0.31397748755183885`, 0.9339660689161493]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 299}], {
             RGBColor[
             0.19371330684929777`, 0.320935346004614, 0.9343430583006869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 300}], {
             RGBColor[
             0.1975989582339537, 0.32501941197441453`, 0.9345643403987369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 328}], {
             RGBColor[
             0.215194282730263, 0.3435132136280431, 0.9355663680988517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 370}], {
             RGBColor[
             0.19229180160053655`, 0.3194412538595276, 0.9342621056796985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 371}], {
             RGBColor[
             0.1895350584309733, 0.3165437420007044, 0.9341051132344278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 291}], {
             RGBColor[
             0.20219476439486456`, 0.32984989564047235`, 0.9348260647607148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 336}], {
             RGBColor[
             0.22186501043454393`, 0.3505245713938071, 0.9359462561731533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 368}], {
             RGBColor[
             0.19638103924398845`, 0.323739301895437, 0.934494981714008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 387}], {
             RGBColor[
             0.19723551682458454`, 0.32463741200965124`, 0.9345436429481366]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 392}], {
             RGBColor[
             0.20599555407739328`, 0.33384476658079454`, 0.9350425141103704]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 293}], {
             RGBColor[
             0.356440478793437, 0.4831525603366694, 0.9439330500141462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 394}], {
             RGBColor[
             0.3781881603711747, 0.5019893090490473, 0.9453187930535599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 301}], {
             RGBColor[
             0.2824458229860667, 0.41361844480404447`, 0.9394174951734057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 305}], {
             RGBColor[
             0.30654149170312617`, 0.4389445203793095, 0.9407897078604948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 313}], {
             RGBColor[
             0.2998205585054363, 0.43188039345676055`, 0.940406960657616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 339}], {
             RGBColor[
             0.34849054026782905`, 0.4762667231613163, 0.9434264869611491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 340}], {
             RGBColor[
             0.29320777122887487`, 0.42492993475416496`, 0.9400303722049579]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 361}], {
             RGBColor[
             0.36229879969604784`, 0.48822674345474093`, 0.9443063370417508]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 382}], {
             RGBColor[
             0.3185597546508585, 0.45034218102492296`, 0.9415193237683902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 312}], {
             RGBColor[
             0.7398695405352704, 0.7057918843470511, 0.6108133774642039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 332}], {
             RGBColor[
             0.8748637305772158, 0.45283228980267326`, 0.21438239989975133`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 334}], {
             RGBColor[
             0.9460670651662169, 0.8226245407866379, 0.2820057220570269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 356}], {
             RGBColor[
             0.9386530516866118, 0.8632951638170323, 0.6207085244635109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 360}], {
             RGBColor[
             0.7973390261209754, 0.7521357532053826, 0.6155512086405578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 364}], {
             RGBColor[
             0.9266304431740131, 0.7468211866800847, 0.25982333625421017`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 366}], {
             RGBColor[
             0.9626113006296535, 0.8779402128312055, 0.388106189025446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 380}], {
             RGBColor[
             0.8261523609821573, 0.7746449493883936, 0.6184230525835972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 389}], {
             RGBColor[
             0.9625229099161214, 0.8777511540326326, 0.378485405341739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 334}], {
             RGBColor[
             0.8500382234662116, 0.8370769008965131, 0.6373182165494112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 366}], {
             RGBColor[
             0.8665824589296481, 0.8923925729410807, 0.7434186835178305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 397}], {
             RGBColor[
             0.5520222170780682, 0.6432815473581924, 0.9595663255932364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 324}], {
             RGBColor[
             0.1849819453905557, 0.31175813151118514`, 0.9338458201825032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 290}], {
             RGBColor[
             0.28938656912218486`, 0.4203385400712017, 0.9398338164907357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 304}], {
             RGBColor[
             0.3017569575169641, 0.43334060260203944`, 0.9405382918094687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 386}], {
             RGBColor[
             0.331585149915525, 0.4616241237277755, 0.94234929043675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 292}], {
             RGBColor[
             0.8184054423003344, 0.14247787160242187`, 0.16525837837376128`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 303}], {
             RGBColor[
             0.8556245290555657, 0.372684995897263, 0.19871148964339302`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 353}], {
             RGBColor[
             0.9052894000566567, 0.5610593594590743, 0.33598351095262347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 385}], {
             RGBColor[
             0.9058682917802197, 0.5622975503208443, 0.39899230255686247`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 391}], {
             RGBColor[
             0.8187766066009462, 0.14533080306215745`, 0.16561380572719725`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 400}], {
             RGBColor[
             0.8197171091545148, 0.15255991781973297`, 0.16651443203464028`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 318}], {
             RGBColor[
             0.21359522081764215`, 0.3418324981714975, 0.9354753038885282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 304}], {
             RGBColor[
             0.2699001201696922, 0.4010125173273108, 0.9386817846109934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 338}], {
             RGBColor[
             0.2338329245191738, 0.3631036079063329, 0.9366278111753308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 336}], {
             RGBColor[
             0.21513079622652476`, 0.34344648528733734`, 0.9355627526363838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 368}], {
             RGBColor[
             0.1896468250359693, 0.3166612157889672, 0.9341114781772385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 387}], {
             RGBColor[
             0.1905013026165654, 0.3175593259031815, 0.9341601394113672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 303}], {
             RGBColor[
             0.8567109713559, 0.3810358674996849, 0.1997518680171543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 309}], {
             RGBColor[
             0.7584292895983676, 0.45716808614862703`, 0.568384704834363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 362}], {
             RGBColor[
             0.8053813952545528, 0.4938474279364584, 0.5730644519337977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 385}], {
             RGBColor[
             0.9069547340805542, 0.5706484219232661, 0.4000326809306238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 400}], {
             RGBColor[
             0.8208035514548493, 0.16091078942215484`, 0.1675548104084016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 394}], {
             RGBColor[
             0.3358774325095808, 0.4653418831743506, 0.9426227908881267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 301}], {
             RGBColor[
             0.22980051567191817`, 0.3588652905383795, 0.9363981714568937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 313}], {
             RGBColor[
             0.24717525119128783`, 0.3771272391910956, 0.937387636941104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 329}], {
             RGBColor[
             0.23603593247132534`, 0.36541910894281576`, 0.9367532692191475]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 340}], {
             RGBColor[
             0.24056246391472638`, 0.3701767804885, 0.937011048488446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 343}], {
             RGBColor[
             0.20522639813651683`, 0.33303633491963003`, 0.9349987118174017]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 330}], {
             RGBColor[
             0.18388840354746627`, 0.31060874969954066`, 0.9337835445922895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 367}], {
             RGBColor[
             0.18258473603098674`, 0.3092385124824261, 0.9337093026558292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 398}], {
             RGBColor[
             0.17994179284220208`, 0.3064606116187368, 0.933558790951112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 325}], {
             RGBColor[
             0.267416015836295, 0.3984015661715987, 0.9385403185441094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 375}], {
             RGBColor[
             0.2496778587950193, 0.3797576384571041, 0.9375301567418605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 376}], {
             RGBColor[
             0.2913695149854919, 0.423578212516969, 0.9399044348846297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 378}], {
             RGBColor[
             0.2683985374759716, 0.3994342587103688, 0.9385962716979784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 397}], {
             RGBColor[
             0.33036980779411174`, 0.4594447802808611, 0.9423131030091806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 320}], {
             RGBColor[
             0.19458686072830475`, 0.3218535065179652, 0.9343928059017892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 347}], {
             RGBColor[
             0.1948950544058417, 0.32217743761366435`, 0.9344103570757931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 373}], {
             RGBColor[
             0.20172543232639267`, 0.32935659787913657`, 0.93479933699373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 390}], {
             RGBColor[
             0.2092243065114207, 0.3372383901036854, 0.935226386784977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 300}], {
             RGBColor[
             0.19227535029574405`, 0.31942396249511773`, 0.934261168802228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 370}], {
             RGBColor[
             0.1869681936623269, 0.3138458043802308, 0.9339589340831895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 371}], {
             RGBColor[
             0.18421145049276366`, 0.3109482925214076, 0.933801941637919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 370}], {
             RGBColor[
             0.19085384504698283`, 0.3179298703500313, 0.9341802161812396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 371}], {
             RGBColor[
             0.1880971018774196, 0.31503235849120814`, 0.934023223735969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 305}], {
             RGBColor[
             0.27396377293596785`, 0.4052836740351331, 0.9389132036243971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 313}], {
             RGBColor[
             0.2672428397382781, 0.39821954711258417`, 0.9385304564215183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 329}], {
             RGBColor[
             0.25610352101831557`, 0.38651141686430435`, 0.9378960886995618]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 339}], {
             RGBColor[
             0.3159128215006708, 0.4426058768171399, 0.9415499827250514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 340}], {
             RGBColor[
             0.26063005246171667`, 0.3912690884099886, 0.9381538679688604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 361}], {
             RGBColor[
             0.3297210809288895, 0.45456589711056455`, 0.9424298328056531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 382}], {
             RGBColor[
             0.2859820358837003, 0.41668133468074653`, 0.9396428195322926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 367}], {
             RGBColor[
             0.19039724530537674`, 0.31744995507150764`, 0.934154213501434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 377}], {
             RGBColor[
             0.22469777382228445`, 0.35350198532189486`, 0.9361075778573873]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 353}], {
             RGBColor[
             0.9435949291122223, 0.7996173553563373, 0.3704770005960165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 385}], {
             RGBColor[
             0.9441738208357854, 0.8008555462181073, 0.4334857922002555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 391}], {
             RGBColor[
             0.8570821356565119, 0.38388879895942046`, 0.20010729537059024`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 400}], {
             RGBColor[
             0.8580226382100805, 0.391117913716996, 0.20100792167803327`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 338}], {
             RGBColor[
             0.24620331291395298`, 0.37610567043717064`, 0.9373322864940637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 313}], {
             RGBColor[
             0.29133850845533754`, 0.4235456226878492, 0.9399026691086074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 329}], {
             RGBColor[
             0.28019918973537505`, 0.41183749243956935`, 0.9392683013866509]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 339}], {
             RGBColor[
             0.3400084902177303, 0.4679319523924049, 0.9429221954121405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 340}], {
             RGBColor[
             0.2847257211787761, 0.4165951639852536, 0.9395260806559493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 361}], {
             RGBColor[
             0.353816749645949, 0.47989197268582956`, 0.9438020454927423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 382}], {
             RGBColor[
             0.31007770460075973`, 0.44200741025601153`, 0.9410150322193817]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 308}], {
             RGBColor[
             0.2175738595337591, 0.3460142997224009, 0.9357018814775424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 311}], {
             RGBColor[
             0.21244806666191265`, 0.3406267664200514, 0.9354099751564218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 346}], {
             RGBColor[
             0.21286307171561503`, 0.3410629630443328, 0.9354336090802852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 348}], {
             RGBColor[
             0.21170202637769384`, 0.33984263077965143`, 0.9353674892659032]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 350}], {
             RGBColor[
             0.2854226113571807, 0.41364792547081863`, 0.9397004998858718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 354}], {
             RGBColor[
             0.2092005815939097, 0.33721345371113465`, 0.9352250356860227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 378}], {
             RGBColor[
             0.23126849430923743`, 0.36040822916142345`, 0.9364817706686093]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 343}], {
             RGBColor[
             0.1898749181249935, 0.3169009560874688, 0.9341244677412249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 348}], {
             RGBColor[
             0.20697593141094872`, 0.33487520531787435`, 0.9350983451491781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 354}], {
             RGBColor[
             0.20447448662716458`, 0.33224602824935756`, 0.9349558915692975]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 374}], {
             RGBColor[
             0.1982421611639798, 0.32569545903529307`, 0.9346009698540684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 378}], {
             RGBColor[
             0.22654239934249232`, 0.35544080369964637`, 0.9362126265518842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 323}], {
             RGBColor[
             0.5589942800594222, 0.6511253403818711, 0.9592466420721857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 362}], {
             RGBColor[
             0.7443188002522516, 0.8001867708802417, 0.9751504000206381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 365}], {
             RGBColor[
             0.5016918379873817, 0.6012405287458232, 0.9556046196739707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 385}], {
             RGBColor[
             0.845892139078253, 0.8769877648670494, 0.8021186290174642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 316}], {
             RGBColor[
             0.7693289728620583, 0.48993694637010154`, 0.5724844799948403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 319}], {
             RGBColor[
             0.8294805357972241, 0.22760589335643167`, 0.17586390041391192`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 384}], {
             RGBColor[
             0.8800507133233684, 0.4896085562326786, 0.2192223210475797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 317}], {
             RGBColor[
             0.19555015626042008`, 0.32286599119868276`, 0.934447664157275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 344}], {
             RGBColor[
             0.19707934099750435`, 0.3244732613132706, 0.9345347489658259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 346}], {
             RGBColor[
             0.20301118387702347`, 0.33070800428020625`, 0.9348725586424393]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 354}], {
             RGBColor[
             0.19934869375531813`, 0.32685849494700814`, 0.9346639852481768]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 356}], {
             RGBColor[
             0.746600049419986, 0.8012844499471021, 0.9674404180913663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 359}], {
             RGBColor[
             0.4367530973615871, 0.5501494570425497, 0.9497594529493274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 360}], {
             RGBColor[
             0.6052860238543496, 0.6901250393354524, 0.9622831022684131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 380}], {
             RGBColor[
             0.6340993587155315, 0.7126342355184634, 0.9651549462114524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 389}], {
             RGBColor[
             0.7704699076494956, 0.8157404401627024, 0.7252172989695943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 329}], {
             RGBColor[
             0.27347825653768526`, 0.4047733655170204, 0.9388855541837721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 339}], {
             RGBColor[
             0.3332875570200404, 0.460867825469856, 0.9425394482092617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 340}], {
             RGBColor[
             0.2780047879810863, 0.40953103706270466`, 0.9391433334530706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 358}], {
             RGBColor[
             0.28110733593194254`, 0.4127920116719563, 0.9393200189690635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 361}], {
             RGBColor[
             0.3470958164482592, 0.47282784576328063`, 0.9434192982898635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 369}], {
             RGBColor[
             0.1815795981118552, 0.30818204879999395`, 0.9336520615383029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 322}], {
             RGBColor[
             0.18811052101816012`, 0.31504646285894905`, 0.9340239879361825]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 351}], {
             RGBColor[
             0.5108480401165528, 0.6087959957654421, 0.956444390370581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 399}], {
             RGBColor[
             0.5357585344043984, 0.6303722138797264, 0.9580316650391174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 344}], {
             RGBColor[
             0.19003331843460333`, 0.31706744485602845`, 0.9341334884045249]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 346}], {
             RGBColor[
             0.19596516131412245`, 0.3233021878229641, 0.9344712980811385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 354}], {
             RGBColor[
             0.19230267119241712`, 0.319452678489766, 0.934262724686876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 322}], {
             RGBColor[
             0.20428384988578308`, 0.3320456569470981, 0.9349450350888977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 384}], {
             RGBColor[
             0.8830145607989899, 0.5123899866965502, 0.22206050473742173`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 347}], {
             RGBColor[
             0.1840162025368019, 0.3107430745402564, 0.9337908225556705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 398}], {
             RGBColor[
             0.182257588923795, 0.30889466013044303`, 0.9336906721120455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 375}], {
             RGBColor[
             0.19367454863692518`, 0.3208946086659977, 0.9343408510778299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 381}], {
             RGBColor[
             0.18695109985789307`, 0.313827837707961, 0.9339579606163151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 327}], {
             RGBColor[
             0.19043725974580353`, 0.3174920127854582, 0.9341564922646202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 335}], {
             RGBColor[
             0.19668775397946056`, 0.3240616785292556, 0.9345124486644494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 349}], {
             RGBColor[
             0.19676296516777197`, 0.32414073025683565`, 0.9345167318303588]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 355}], {
             RGBColor[
             0.2016258404569241, 0.32925192050983587`, 0.9347936653840967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 362}], {
             RGBColor[
             0.6059463857156073, 0.6878046821697024, 0.9639263891716204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 365}], {
             RGBColor[
             0.3633194234507374, 0.48885844003528395`, 0.9443806088249529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 377}], {
             RGBColor[
             0.3376579889612439, 0.46188664535790686`, 0.9429192280934666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 388}], {
             RGBColor[
             0.34570167664203966`, 0.47034107110967827`, 0.9433773042073184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 395}], {
             RGBColor[
             0.42965137086591587`, 0.5465641553634234, 0.9485979833191546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 376}], {
             RGBColor[
             0.26222548998781436`, 0.392945994406499, 0.9382447257757333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 397}], {
             RGBColor[
             0.3012257827964342, 0.4288125621703911, 0.9406533939002841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 363}], {
             RGBColor[
             0.3080486907375876, 0.43502729111889293`, 0.9410769734898234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 383}], {
             RGBColor[
             0.2999445651565369, 0.428007904865782, 0.9405605857739958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 335}], {
             RGBColor[
             0.19201380881889718`, 0.3191490658202642, 0.9342462744020376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 349}], {
             RGBColor[
             0.19208902000720862`, 0.3192281175478443, 0.934250557567947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 355}], {
             RGBColor[
             0.19695189529636073`, 0.3243393078008444, 0.9345274911216848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 339}], {
             RGBColor[
             0.322148238300078, 0.44915969522157617`, 0.9419050804873051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 340}], {
             RGBColor[
             0.2668654692611238, 0.39782290681442484`, 0.9385089657311141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 341}], {
             RGBColor[
             0.2558412218032698, 0.3862357237585604, 0.9378811511473018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 343}], {
             RGBColor[
             0.23152940348291426`, 0.3606824612455548, 0.9364966290600697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 358}], {
             RGBColor[
             0.26996801721198005`, 0.40108388142367646`, 0.9386856512471069]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 367}], {
             RGBColor[
             0.1873967228823739, 0.314296215760822, 0.9339833381883191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 398}], {
             RGBColor[
             0.18475377969358928`, 0.31151831489713266`, 0.9338328264836019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 392}], {
             RGBColor[
             0.22201549227327083`, 0.35068273734740874`, 0.9359548258912509]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 334}], {
             RGBColor[
             0.8890082529415364, 0.5076542323723299, 0.23230663812042954`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 356}], {
             RGBColor[
             0.8815942394619314, 0.5483248554027244, 0.5710094405269136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 364}], {
             RGBColor[
             0.8695716309493327, 0.4318508782657767, 0.2101242523176128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 366}], {
             RGBColor[
             0.905552488404973, 0.5629699044168974, 0.3384071050888487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 380}], {
             RGBColor[
             0.7690935487574768, 0.4596746409740855, 0.5687239686469998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 389}], {
             RGBColor[
             0.905464097691441, 0.5627808456183245, 0.32878632140514163`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 337}], {
             RGBColor[
             0.9553778772118539, 0.9662414744033965, 0.9604177939535141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 345}], {
             RGBColor[
             0.8909301311153961, 0.9154013493777207, 0.9732965059821361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 353}], {
             RGBColor[
             0.97351816640208, 0.9765194565998694, 0.7354387372176427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 391}], {
             RGBColor[
             0.8870053729463696, 0.5607909002029526, 0.5650690319922165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 364}], {
             RGBColor[
             0.9407749655383337, 0.8016431292497415, 0.27774757447488835`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 366}], {
             RGBColor[
             0.9767558229939741, 0.9327621554008622, 0.40603042724612426`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 391}], {
             RGBColor[
             0.890222900366215, 0.5169905447403047, 0.23346978586604977`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 349}], {
             RGBColor[
             0.19833951424086566`, 0.32579778329164166`, 0.9346065139677762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 355}], {
             RGBColor[
             0.20320238953001776`, 0.3309089735446419, 0.934883447521514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 359}], {
             RGBColor[
             0.2802453493603669, 0.4103194523243253, 0.9393282894277089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 345}], {
             RGBColor[
             0.8925314756364031, 0.9165956294995268, 0.9705858474056119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 353}], {
             RGBColor[
             0.9751195109230872, 0.9777137367216755, 0.7327280786411184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 391}], {
             RGBColor[
             0.8886067174673766, 0.5619851803247587, 0.5623583734156922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 340}], {
             RGBColor[
             0.326674769743479, 0.4539173667672604, 0.9421628597566036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 361}], {
             RGBColor[
             0.39576579821065194`, 0.5172141754678363, 0.9464388245933966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 382}], {
             RGBColor[
             0.3520267531654626, 0.47932961303801835`, 0.943651811320036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 343}], {
             RGBColor[
             0.2360559349263153, 0.3654401327912391, 0.9367544083293682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 358}], {
             RGBColor[
             0.2744945486553811, 0.4058415529693607, 0.9389434305164055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 361}], {
             RGBColor[
             0.34048302917169776`, 0.46587738706068504`, 0.9430427098372054]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 358}], {
             RGBColor[
             0.26347030119752707`, 0.39425436991349627`, 0.9383156159325932]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 348}], {
             RGBColor[
             0.1937491041812462, 0.3209729712701737, 0.9343450969057838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 374}], {
             RGBColor[
             0.18501533393427727`, 0.31179322498759243`, 0.9338477216106742]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 346}], {
             RGBColor[
             0.19749434605120672`, 0.3249094579375519, 0.9345583828896893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 354}], {
             RGBColor[
             0.1938318559295014, 0.32105994860435383`, 0.9343498094954268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 350}], {
             RGBColor[
             0.5883144988769012, 0.6710348151156551, 0.9634472668058549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 353}], {
             RGBColor[
             0.9106717648266294, 0.9268736116959997, 0.7456067906697404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 354}], {
             RGBColor[
             0.1997636988090205, 0.3272946915712895, 0.9346876191720402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 398}], {
             RGBColor[
             0.182565782601332, 0.30921859122614215`, 0.9337082232860494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 354}], {
             RGBColor[
             0.19860265347109932`, 0.3260743593066081, 0.9346214993576583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 374}], {
             RGBColor[
             0.19237032800791454`, 0.3195237900925436, 0.9342665776424293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 378}], {
             RGBColor[
             0.22067056618642705`, 0.3492691347568969, 0.935878234340245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 355}], {
             RGBColor[
             0.20327760071832918`, 0.33098802527222193`, 0.9348877306874234]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 355}], {
             RGBColor[
             0.2588476494190366, 0.38932088860423164`, 0.9380551008583563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 395}], {
             RGBColor[
             0.37411784951982285`, 0.4984638103693781, 0.9450594364453463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 399}], {
             RGBColor[
             0.33446531711843736`, 0.46411877979752536`, 0.9425328121440877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 396}], {
             RGBColor[
             0.18539177638104404`, 0.312188889866974, 0.9338691594511209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 391}], {
             RGBColor[
             0.9067470066576029, 0.5722631625212318, 0.3373793166798207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 400}], {
             RGBColor[
             0.9076875092111716, 0.5794922772788073, 0.33827994298726377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 374}], {
             RGBColor[
             0.18986888322413037`, 0.3168946130240269, 0.9341241240625486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 359}], {
             RGBColor[
             0.6355366085129286, 0.7076527365125309, 0.9596545999486343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 360}], {
             RGBColor[
             0.804069535005691, 0.8476283188054337, 0.97217824926772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 364}], {
             RGBColor[
             0.9333609520587287, 0.8423137522801358, 0.6164503768813724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 380}], {
             RGBColor[
             0.8328828698668729, 0.8701375149884446, 0.9750500932107594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 389}], {
             RGBColor[
             0.969253418800837, 0.9732437196326836, 0.7351124459689012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 360}], {
             RGBColor[
             0.49422258294729215`, 0.5964933259008812, 0.9544972841256812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 380}], {
             RGBColor[
             0.6915688443012366, 0.7589781043767949, 0.9698927773878063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 389}], {
             RGBColor[
             0.8279393932352007, 0.862084309021034, 0.7299551301459482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 382}], {
             RGBColor[
             0.3658350125936814, 0.49128963333144304`, 0.9445316614006376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 365}], {
             RGBColor[
             0.5486439436435668, 0.6379198705336546, 0.9602843667734056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 385}], {
             RGBColor[
             0.892844244734438, 0.9136671066548807, 0.806798376116899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 383}], {
             RGBColor[
             0.36642168177165046`, 0.49179777668654956`, 0.9445690434418867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 393}], {
             RGBColor[
             0.5482487832688899, 0.640773127747212, 0.9590042434848745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 366}], {
             RGBColor[
             0.9573192010017704, 0.856958801294309, 0.38384804144330753`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 380}], {
             RGBColor[
             0.8208602613542741, 0.753663537851497, 0.6141649050014586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 391}], {
             RGBColor[
             0.8707862783740112, 0.44118719063375156`, 0.21128740006323304`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 377}], {
             RGBColor[
             0.2803555468892034, 0.41200183372185906`, 0.9392772056952516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 388}], {
             RGBColor[
             0.2883992345699991, 0.4204562594736305, 0.9397352818091035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 372}], {
             RGBColor[
             0.1818899475322301, 0.30850824571809776`, 0.9336697354786725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 387}], {
             RGBColor[
             0.18468757746568928`, 0.3114487321581461, 0.9338290563646603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 387}], {
             RGBColor[
             0.18274442511282618`, 0.30940635583231196`, 0.9337183967128011]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 392}], {
             RGBColor[
             0.19150446236563495`, 0.31861371040345526`, 0.9342172678750348]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 390}], {
             RGBColor[
             0.20548402624046883`, 0.3333071183914488, 0.9350133833567951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 381}], {
             RGBColor[
             0.196072227977034, 0.3234147216741027, 0.9344773953692003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 397}], {
             RGBColor[
             0.32517928194563106`, 0.4539892085157613, 0.9420175102408045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 388}], {
             RGBColor[
             0.26273780008050557`, 0.39348446479625343`, 0.9382739010776171]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 389}], {
             RGBColor[
             0.8567527280963826, 0.8845935052040448, 0.7328269740889874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 393}], {
             RGBColor[
             0.5401446576878393, 0.6337537414941011, 0.9584878557690468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 400}], {
             RGBColor[
             0.9082664009347345, 0.5807304681405772, 0.40128873459150277`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 395}], {
             RGBColor[
             0.35473118198517756`, 0.4781619748017699, 0.9439526563033052]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.027885652381746694`], {
             RGBColor[
             0.1818132732838514, 0.3084276562216236, 0.9336653689936567]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.027885652381746694`], {
             RGBColor[
             0.20182540810126717`, 0.3294616787573599, 0.9348050304662081]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.027885652381746694`], {
             RGBColor[
             0.23621542372166607`, 0.36560776562732644`, 0.9367634909803209]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.027885652381746694`], {
             RGBColor[
             0.2008450066857079, 0.32843121470856707`, 0.9347491980559659]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.027885652381746694`], {
             RGBColor[
             0.18681770269069906`, 0.3136876288273712, 0.9339503638449868]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.027885652381746694`], {
             RGBColor[
             0.9261633007621113, 0.943961492267368, 0.992819476494071]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.027885652381746694`], {
             RGBColor[
             0.25494849258932906`, 0.3852974087524073, 0.9378303115392425]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.027885652381746694`], {
             RGBColor[
             0.25559866423556843`, 0.38598078037586825`, 0.937867337852653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.027885652381746694`], {
             RGBColor[
             0.6863588655876156, 0.7549080294084094, 0.9693734953996518]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.027885652381746694`], {
             RGBColor[
             0.8429670986480872, 0.3312695252776902, 0.18877864823079255`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.027885652381746694`], {
             RGBColor[
             0.873192830390407, 0.9017242770380856, 0.9877671057427206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.027885652381746694`], {
             RGBColor[
             0.242785484860208, 0.37251331644986996`, 0.9371376462426264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.027885652381746694`], {
             RGBColor[
             0.21336291477373137`, 0.3415883297902934, 0.9354620744029933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.027885652381746694`], {
             RGBColor[
             0.3386493168091526, 0.46774275003568394`, 0.9427994129046144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.027885652381746694`], {
             RGBColor[
             0.18212992963139682`, 0.3087604821200659, 0.9336834021041983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.027885652381746694`], {
             RGBColor[
             0.22895368331262583`, 0.3579752160364906, 0.9363499456068083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.027885652381746694`], {
             RGBColor[
             0.8276616884309496, 0.21362543547524793`, 0.17412217012187317`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.027885652381746694`], {
             RGBColor[
             0.9925358512363838, 0.9864432654728553, 0.42895165434603927`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.027885652381746694`], {
             RGBColor[
             0.19951285246669712`, 0.3270310361609309, 0.9346733338439388]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.027885652381746694`], {
             RGBColor[
             0.3846257063952153, 0.5075651878546001, 0.9457289877937134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.027885652381746694`], {
             RGBColor[
             0.19666790482252822`, 0.3240408158068105, 0.9345113182843263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.027885652381746694`], {
             RGBColor[
             0.24203296140503872`, 0.3717223665857442, 0.9370947911451132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.027885652381746694`], {
             RGBColor[
             0.2119196850624197, 0.340071403857656, 0.9353798846060012]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.027885652381746694`], {
             RGBColor[
             0.2601817623901309, 0.39079790712151985`, 0.9381283385124692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.027885652381746694`], {
             RGBColor[
             0.3639618362230004, 0.489667182107741, 0.9444123042586827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.027885652381746694`], {
             RGBColor[
             0.1822568035379685, 0.30889383464014303`, 0.9336906273854845]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.027885652381746694`], {
             RGBColor[
             0.20503271821821972`, 0.3328327650454837, 0.9349876820325784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.027885652381746694`], {
             RGBColor[
             0.19159599737019925`, 0.31870991949690686`, 0.9342224806581308]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.027885652381746694`], {
             RGBColor[
             0.18584110899752487`, 0.3126611669362287, 0.9338947482789014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.027885652381746694`], {
             RGBColor[
             0.20069898841488326`, 0.3282777402478373, 0.9347408825314572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.027885652381746694`], {
             RGBColor[
             0.9842583887354778, 0.9877584534482328, 0.9105427668445933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.027885652381746694`], {
             RGBColor[
             0.8215188663850046, 0.16640901342833042`, 0.16823979679335105`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.027885652381746694`], {
             RGBColor[
             0.24658940627570813`, 0.37651147904010834`, 0.9373542739398417]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.027885652381746694`], {
             RGBColor[
             0.1829376663072982, 0.30960946457990146`, 0.9337294015129516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.027885652381746694`], {
             RGBColor[
             0.19009976398754364`, 0.3171372833450601, 0.9341372723804675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.027885652381746694`], {
             RGBColor[
             0.24565388341041777`, 0.3755281851931126, 0.9373009972966455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.027885652381746694`], {
             RGBColor[
             0.2843315036737978, 0.41618081639268795`, 0.9395036305522334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.027885652381746694`], {
             RGBColor[
             0.2587257572717294, 0.3892675534260234, 0.9380454211749428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.027885652381746694`], {
             RGBColor[
             0.19817415326039348`, 0.32562397841667373`, 0.9345970969045678]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.027885652381746694`], {
             RGBColor[
             0.1934487547814754, 0.32065728500776275`, 0.934327992451794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.027885652381746694`], {
             RGBColor[
             0.19479503600678127`, 0.322072311934719, 0.9344046611759306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.027885652381746694`], {
             RGBColor[
             0.183885630512114, 0.31060583506356493`, 0.9337833866720284]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.027885652381746694`], {
             RGBColor[
             0.194697223000598, 0.3219695042635176, 0.9343990908699299]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.027885652381746694`], {
             RGBColor[
             0.22831342724773274`, 0.3573022663177088, 0.9363134839710866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.027885652381746694`], {
             RGBColor[
             0.23972125787035842`, 0.36929261960032556`, 0.9369631430486721]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.027885652381746694`], {
             RGBColor[
             0.8055364749096104, 0.8480104835941301, 0.9812520057187881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.027885652381746694`], {
             RGBColor[
             0.18100426741029385`, 0.3075773397545796, 0.9336192973059745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.027885652381746694`], {
             RGBColor[
             0.20793893985757575`, 0.3358873882535414, 0.9351531870555702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.027885652381746694`], {
             RGBColor[
             0.18369802063003998`, 0.31040864518235156`, 0.9337727025667882]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.027885652381746694`], {
             RGBColor[
             0.23112771995435683`, 0.3602602663888343, 0.9364737537773559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.027885652381746694`], {
             RGBColor[
             0.20120879960667537`, 0.3288135841343073, 0.9347699155246316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.027885652381746694`], {
             RGBColor[
             0.9889946602077696, 0.9897170234186503, 0.8320504914710569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.027885652381746694`], {
             RGBColor[
             0.40260480881009003`, 0.5231377827104023, 0.9468746003012931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.027885652381746694`], {
             RGBColor[
             0.9482538006021336, 0.8325505933258706, 0.2772219972063093]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.027885652381746694`], {
             RGBColor[
             0.8037373305687819, 0.8466049783610714, 0.9810726838248541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.027885652381746694`], {
             RGBColor[
             0.5183980864407423, 0.6198979459970778, 0.9552293428008269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.027885652381746694`], {
             RGBColor[
             0.3482989604247025, 0.47610078633028297`, 0.9434142796629524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.027885652381746694`], {
             RGBColor[
             0.19320352841391442`, 0.32039953654720643`, 0.9343140271729413]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.027885652381746694`], {
             RGBColor[
             0.21627237251575757`, 0.34464635434743823`, 0.9356277637172448]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.027885652381746694`], {
             RGBColor[
             0.7070237961498369, 0.7710516302229059, 0.9714331825533382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.027885652381746694`], {
             RGBColor[
             0.21726621743653565`, 0.3456909483725835, 0.9356843617152213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.027885652381746694`], {
             RGBColor[
             0.9918038536315829, 0.990878697092375, 0.7854948864789351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.027885652381746694`], {
             RGBColor[
             0.18932442036239164`, 0.31632234803540016`, 0.9340931177080333]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.027885652381746694`], {
             RGBColor[
             0.9925852496598342, 0.986548923705669, 0.43432836788688456`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.027885652381746694`], {
             RGBColor[
             0.3764941167365503, 0.5005220135978444, 0.9452108500911456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.027885652381746694`], {
             RGBColor[
             0.19612721011213427`, 0.3234725113841618, 0.9344805265204555]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.027885652381746694`], {
             RGBColor[
             0.17940647345367122`, 0.30589795700018124`, 0.9335283053038692]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.027885652381746694`], {
             RGBColor[
             0.8216043579673015, 0.8605890294596807, 0.9828465511894319]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.027885652381746694`], {
             RGBColor[
             0.5728179374316162, 0.6640784326178184, 0.9595134728173111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.027885652381746694`], {
             RGBColor[
             0.1969643686712329, 0.32435241810869275`, 0.934528201461931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.027885652381746694`], {
             RGBColor[
             0.9697038754518477, 0.9769257804341147, 0.9361676157519565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.027885652381746694`], {
             RGBColor[
             0.46553671991296847`, 0.576982707272407, 0.9510679023901947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.027885652381746694`], {
             RGBColor[
             0.1985117660113969, 0.3259788308238631, 0.9346163234512842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.027885652381746694`], {
             RGBColor[
             0.24853385159996577`, 0.37855521436085726`, 0.9374650072245091]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.027885652381746694`], {
             RGBColor[
             0.18190969424137163`, 0.30852900076141915`, 0.9336708600245455]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.027885652381746694`], {
             RGBColor[
             0.2829350020755027, 0.41471300466956446`, 0.9394241018521495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.027885652381746694`], {
             RGBColor[
             0.1969521059625652, 0.3243395292243824, 0.9345275031188135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.027885652381746694`], {
             RGBColor[
             0.22046571832082573`, 0.34905382666204504`, 0.9358665685573442]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.027885652381746694`], {
             RGBColor[
             0.199051197909799, 0.3265458079510415, 0.9346470432998802]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.027885652381746694`], {
             RGBColor[
             0.20310658273494972`, 0.3308082745285237, 0.9348779914662683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.027885652381746694`], {
             RGBColor[
             0.22915597848204, 0.35818784108579943`, 0.9363614660174375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.027885652381746694`], {
             RGBColor[
             0.7597586089991939, 0.8122484668202457, 0.9766892958633172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.027885652381746694`], {
             RGBColor[
             0.9509849302078126, 0.9629652217205732, 0.9678539073672795]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.027885652381746694`], {
             RGBColor[
             0.21428709115836797`, 0.3425596977667136, 0.935514704880902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.027885652381746694`], {
             RGBColor[
             0.1818888062976524, 0.30850704620819813`, 0.9336696704870515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.027885652381746694`], {
             RGBColor[
             0.2680992625939086, 0.39911970183419715`, 0.9385792284361825]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.027885652381746694`], {
             RGBColor[
             0.18684859723136407`, 0.31372010094843716`, 0.9339521232433733]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.027885652381746694`], {
             RGBColor[
             0.4303958842275222, 0.5472090154169172, 0.9486454230522088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.027885652381746694`], {
             RGBColor[
             0.23222586891438338`, 0.3614144905724877, 0.9365362917360636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.027885652381746694`], {
             RGBColor[
             0.21556902434658207`, 0.3439070908267852, 0.9355877090795206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.027885652381746694`], {
             RGBColor[
             0.5925759149291727, 0.6801188488370776, 0.961068893181775]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.027885652381746694`], {
             RGBColor[
             0.20437042968316516`, 0.3321366578036229, 0.9349499656802752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.027885652381746694`], {
             RGBColor[
             0.3425287629814334, 0.47110293132347947`, 0.9430466077842526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.027885652381746694`], {
             RGBColor[
             0.1791057270796212, 0.3055818534926332, 0.9335111782427814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.027885652381746694`], {
             RGBColor[
             0.24723118250472642`, 0.37718602654776967`, 0.9373908221466615]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.027885652381746694`], {
             RGBColor[
             0.21162927735784165`, 0.3397661669472325, 0.9353633463168451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.027885652381746694`], {
             RGBColor[
             0.2986247548964671, 0.43120392967218313`, 0.9403176100643942]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.027885652381746694`], {
             RGBColor[
             0.1932487717488401, 0.3204470901608064, 0.9343166037139339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.027885652381746694`], {
             RGBColor[
             0.9021660914511284, 0.9248267689496842, 0.9905306012474278]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.027885652381746694`], {
             RGBColor[
             0.387712192347488, 0.5102385468551641, 0.9459256559493198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.027885652381746694`], {
             RGBColor[
             0.8539737461394735, 0.41587144104017043`, 0.19931862629877445`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.027885652381746694`], {
             RGBColor[
             0.34903475823839447`, 0.4767380974142295, 0.9434611640490004]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.027885652381746694`], {
             RGBColor[
             0.19478977051563845`, 0.3220667775696765, 0.9344043613139996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.027885652381746694`], {
             RGBColor[
             0.22404918964109946`, 0.35282028222485723`, 0.936070641947763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.027885652381746694`], {
             RGBColor[
             0.9853022906708313, 0.9881901337255575, 0.8932426102441758]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.027885652381746694`], {
             RGBColor[
             0.1865190623784995, 0.31337373892436005`, 0.9339333567210057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.027885652381746694`], {
             RGBColor[
             0.2230811340648649, 0.3518027944359661, 0.9360155126148064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.027885652381746694`], {
             RGBColor[
             0.3063635945960659, 0.4393379408672382, 0.9407583255366989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.027885652381746694`], {
             RGBColor[
             0.1827503081177702, 0.3094125392435122, 0.9337187317412295]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.027885652381746694`], {
             RGBColor[
             0.8529626688242167, 0.8855932953383124, 0.985837534872859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.027885652381746694`], {
             RGBColor[
             0.8266120846200963, 0.20555772064570646`, 0.17311706832724205`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.027885652381746694`], {
             RGBColor[
             0.1804406002012431, 0.3069848897793021, 0.93358719729229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.027885652381746694`], {
             RGBColor[
             0.1856485479005117, 0.3124587730141891, 0.9338837822092951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.027885652381746694`], {
             RGBColor[
             0.18667779652152947`, 0.3135405785730105, 0.9339423963956253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.027885652381746694`], {
             RGBColor[
             0.9551078718556497, 0.8597247018622127, 0.2827369438226184]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.027885652381746694`], {
             RGBColor[
             0.24002120291967022`, 0.3696078808647668, 0.9369802244755014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.027885652381746694`], {
             RGBColor[
             0.5585316039927765, 0.6524801435401812, 0.9583888003164419]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.027885652381746694`], {
             RGBColor[
             0.3574473894517768, 0.48402469574012214`, 0.9439972094709195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.027885652381746694`], {
             RGBColor[
             0.2397898236287226, 0.36936468655968646`, 0.936967047767177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.027885652381746694`], {
             RGBColor[
             0.41254771032069193`, 0.531749824254125, 0.9475081531933861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.027885652381746694`], {
             RGBColor[
             0.24372417422141443`, 0.37349993848484087`, 0.9371911032130806]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.027885652381746694`], {
             RGBColor[
             0.18936604401309215`, 0.31636609713137825`, 0.934095488113364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.027885652381746694`], {
             RGBColor[
             0.843157812611701, 0.33273543637341757`, 0.18896127613772973`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.027885652381746694`], {
             RGBColor[
             0.22661866237074535`, 0.3555209609776956, 0.9362169696185221]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.027885652381746694`], {
             RGBColor[
             0.1925981967986741, 0.3197632946393477, 0.9342795544329613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.027885652381746694`], {
             RGBColor[
             0.18255935854789945`, 0.309211839138676, 0.9337078574457099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.027885652381746694`], {
             RGBColor[
             0.3393687513351076, 0.46836588806223545`, 0.9428452546364373]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.027885652381746694`], {
             RGBColor[
             0.3039019362504366, 0.4367505818678281, 0.9406181377356125]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.027885652381746694`], {
             RGBColor[
             0.8193361618613183, 0.1496317899920564, 0.1661496364764569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.027885652381746694`], {
             RGBColor[
             0.21566341381177923`, 0.3440063001393452, 0.9355930844199268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.027885652381746694`], {
             RGBColor[
             0.8141109072907318, 0.8547088953383618, 0.982106625005912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.027885652381746694`], {
             RGBColor[
             0.19287402797566439`, 0.32005321069507126`, 0.9342952626104353]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.027885652381746694`], {
             RGBColor[
             0.18340497994045135`, 0.3101006408377411, 0.933756014333031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.027885652381746694`], {
             RGBColor[
             0.17911500115561352`, 0.3055916011345115, 0.9335117063876894]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.027885652381746694`], {
             RGBColor[
             0.335355251737071, 0.46488959643477135`, 0.9425895179910487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.027885652381746694`], {
             RGBColor[
             0.18263620644148504`, 0.30929261114727236`, 0.9337122338195634]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.027885652381746694`], {
             RGBColor[
             0.29264465833089975`, 0.42491846902175034`, 0.9399770524117451]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.027885652381746694`], {
             RGBColor[
             0.2889051941793347, 0.4209880551027343, 0.939764095460355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.027885652381746694`], {
             RGBColor[
             0.30694355404168716`, 0.4399475150161388, 0.940791353369154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.027885652381746694`], {
             RGBColor[
             0.4063466574019441, 0.5263787838898877, 0.9471130275847793]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.027885652381746694`], {
             RGBColor[
             0.3557668224000087, 0.48256907302763663`, 0.9438901252244479]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.027885652381746694`], {
             RGBColor[
             0.4741596199861951, 0.5839831660090739, 0.9517467286706829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.027885652381746694`], {
             RGBColor[
             0.19890345919190142`, 0.32639052519135536`, 0.9346386297984558]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.027885652381746694`], {
             RGBColor[
             0.5812572311839399, 0.6709298314718057, 0.9601778449356456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.027885652381746694`], {
             RGBColor[
             0.24987309085249598`, 0.3799628397279394, 0.9375412749187138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.027885652381746694`], {
             RGBColor[
             0.1991293041825628, 0.32662790259593993`, 0.9346514913365662]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.027885652381746694`], {
             RGBColor[
             0.24721508689536167`, 0.3771691090418067, 0.9373899055255195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.027885652381746694`], {
             RGBColor[
             0.25655300447979307`, 0.38698385248121464`, 0.9379216861177417]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.027885652381746694`], {
             RGBColor[
             0.21032620428650672`, 0.3383965545296549, 0.9352891382331565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.027885652381746694`], {
             RGBColor[
             0.23840666361665402`, 0.3679108976895925, 0.9368882788506916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.027885652381746694`], {
             RGBColor[
             0.20761230953904478`, 0.335544079079207, 0.935134585942136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.027885652381746694`], {
             RGBColor[
             0.2008438754397465, 0.3284300256973365, 0.9347491336331819]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.027885652381746694`], {
             RGBColor[
             0.20565135384863537`, 0.33348299031681494`, 0.9350229124165412]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.027885652381746694`], {
             RGBColor[
             0.18637271886218407`, 0.3132199226099977, 0.9339250226742475]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.027885652381746694`], {
             RGBColor[
             0.1858996679095085, 0.31272271606557295`, 0.9338980831223087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.027885652381746694`], {
             RGBColor[
             0.20187169700218524`, 0.3295103313271106, 0.9348076665506371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.027885652381746694`], {
             RGBColor[
             0.24686136029389427`, 0.3767973199561026, 0.9373697613188575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.027885652381746694`], {
             RGBColor[
             0.1911403477299942, 0.3182310028351955, 0.9341965320851944]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.027885652381746694`], {
             RGBColor[
             0.18214142158537838`, 0.30877256089233246`, 0.9336840565539767]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.027885652381746694`], {
             RGBColor[
             0.19529547244710238`, 0.32259830236299947`, 0.9344331602908775]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.027885652381746694`], {
             RGBColor[
             0.8795463410175769, 0.5459298918751729, 0.22120285316675511`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.027885652381746694`], {
             RGBColor[
             0.19529691214488243`, 0.32259981557664835`, 0.9344332422795363]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.027885652381746694`], {
             RGBColor[
             0.17905422337022397`, 0.30552771982853294`, 0.9335082451827241]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.027885652381746694`], {
             RGBColor[
             0.21499276582137244`, 0.3433014065798891, 0.935554892009008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.027885652381746694`], {
             RGBColor[
             0.22554056397195027`, 0.35438781120517543`, 0.9361555735096144]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.027885652381746694`], {
             RGBColor[
             0.2451744333338886, 0.3750242527637898, 0.93727369332407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.027885652381746694`], {
             RGBColor[
             0.2358064817309028, 0.3651779416666145, 0.9367402023389224]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.027885652381746694`], {
             RGBColor[
             0.19796437105250972`, 0.32540348401522773`, 0.9345851501181738]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.027885652381746694`], {
             RGBColor[
             0.45725872125089195`, 0.5702622550389433, 0.9504162280122078]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.027885652381746694`], {
             RGBColor[
             0.23550398192177388`, 0.3648599951876243, 0.9367229754223009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.027885652381746694`], {
             RGBColor[
             0.18805335571358273`, 0.3149863784993486, 0.9340207324566552]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.027885652381746694`], {
             RGBColor[
             0.3796233347917912, 0.5032323849982215, 0.9454102410985666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.027885652381746694`], {
             RGBColor[
             0.17959143492855675`, 0.30609236323752076`, 0.933538838586238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.027885652381746694`], {
             RGBColor[
             0.41783566912403936`, 0.5363299883890472, 0.947845097252377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.027885652381746694`], {
             RGBColor[
             0.19013667027984396`, 0.3171760741982618, 0.9341393741392161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.027885652381746694`], {
             RGBColor[
             0.18620451936940718`, 0.3130431342786254, 0.9339154439619627]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.027885652381746694`], {
             RGBColor[
             0.18139651046953492`, 0.3079896120794884, 0.9336416349679267]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.027885652381746694`], {
             RGBColor[
             0.18300767959384703`, 0.309683052983163, 0.9337333886660452]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.027885652381746694`], {
             RGBColor[
             0.2268131918331927, 0.35572542377660804`, 0.9362280477836279]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.027885652381746694`], {
             RGBColor[
             0.18842432755960442`, 0.31537629343049095`, 0.9340418587544824]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.027885652381746694`], {
             RGBColor[
             0.19212227783830665`, 0.31926307363699663`, 0.9342524515522274]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.027885652381746694`], {
             RGBColor[
             0.24182762690147153`, 0.3715065470035356, 0.9370830976489003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.027885652381746694`], {
             RGBColor[
             0.18868393066647376`, 0.3156491527555983, 0.9340566427673703]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.027885652381746694`], {
             RGBColor[
             0.21355297767290998`, 0.3417880979480139, 0.9354728982039288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.027885652381746694`], {
             RGBColor[
             0.19254963929720473`, 0.31971225762658, 0.9342767891550869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.027885652381746694`], {
             RGBColor[
             0.2065811071166083, 0.33446021995121644`, 0.9350758604897056]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.027885652381746694`], {
             RGBColor[
             0.21634716160662554`, 0.34472496242384276`, 0.9356320228453292]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.027885652381746694`], {
             RGBColor[
             0.27580922111776024`, 0.4072233570823697, 0.9390182991682543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.027885652381746694`], {
             RGBColor[
             0.2331737072204319, 0.36241072872856434`, 0.9365902697253919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.027885652381746694`], {
             RGBColor[
             0.2121526703486752, 0.34031628616563087`, 0.9353931527733826]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.027885652381746694`], {
             RGBColor[
             0.1840091371887301, 0.310735648411464, 0.9337904201945499]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.027885652381746694`], {
             RGBColor[
             0.2582664433427927, 0.3887847853645258, 0.938019263926184]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.027885652381746694`], {
             RGBColor[
             0.8379281346647119, 0.8736051659010814, 0.9844035275832383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.027885652381746694`], {
             RGBColor[
             0.4554399226734993, 0.5687856724178738, 0.9502730455257168]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.027885652381746694`], {
             RGBColor[
             0.42461827381123246`, 0.5422047396654701, 0.9482772788254231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.027885652381746694`], {
             RGBColor[
             0.844124603334554, 0.8785460618197521, 0.9849945522966208]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.027885652381746694`], {
             RGBColor[
             0.19131157595015044`, 0.3184109745510759, 0.9342062832790229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.027885652381746694`], {
             RGBColor[
             0.8287975688378628, 0.8663247005533589, 0.9835326460637211]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.027885652381746694`], {
             RGBColor[
             0.9887357523774989, 0.9896099583772056, 0.8363412642506296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.027885652381746694`], {
             RGBColor[
             0.19404714705117995`, 0.3212862332234835, 0.9343620700063117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.027885652381746694`], {
             RGBColor[
             0.6657140642559093, 0.738780153701779, 0.9673158145395446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.027885652381746694`], {
             RGBColor[
             0.3275914997751332, 0.4581650247028605, 0.9420948185812503]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.027885652381746694`], {
             RGBColor[
             0.3100095560527289, 0.44293642874469996`, 0.9409745126743612]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.027885652381746694`], {
             RGBColor[
             0.17994083687002446`, 0.30645960683136597`, 0.9335587365099107]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.027885652381746694`], {
             RGBColor[
             0.18515378626434187`, 0.3119387471648751, 0.9338556062660495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.027885652381746694`], {
             RGBColor[
             0.4288884024290853, 0.5459033104513494, 0.9485493676450263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.027885652381746694`], {
             RGBColor[
             0.1915172466480543, 0.31862714749484833`, 0.934217995921006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.027885652381746694`], {
             RGBColor[
             0.2944180010032382, 0.4267823646067975, 0.9400780416535094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.027885652381746694`], {
             RGBColor[
             0.2650455441851616, 0.3959100501696741, 0.9384053236903759]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.027885652381746694`], {
             RGBColor[
             0.2456807114445148, 0.37555638315794415`, 0.9373025251134988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.027885652381746694`], {
             RGBColor[
             0.23248905082520588`, 0.3616911114474591, 0.9365512795565422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.027885652381746694`], {
             RGBColor[
             0.5777795176543054, 0.6681064669592394, 0.9599040665873084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.027885652381746694`], {
             RGBColor[
             0.3254133616442444, 0.45627843093029025`, 0.9419560295456021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.027885652381746694`], {
             RGBColor[
             0.8789213821202363, 0.5430920994852084, 0.22068137214366979`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.027885652381746694`], {
             RGBColor[
             0.7060709713767632, 0.7703072762684443, 0.9713382138846121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.027885652381746694`], {
             RGBColor[
             0.21581639795358076`, 0.3441670961721334, 0.9356017966404827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.027885652381746694`], {
             RGBColor[
             0.2082469591636211, 0.3362111360737471, 0.9351707282993756]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.027885652381746694`], {
             RGBColor[
             0.5602763464580424, 0.6538966040732364, 0.9585261528345099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.027885652381746694`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.027885652381746694`], {
             RGBColor[
             0.17970434930417156`, 0.30621104340547683`, 0.9335452688928874]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.027885652381746694`], {
             RGBColor[
             0.36991176607450643`, 0.49482071229294583`, 0.9447914285275043]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.027885652381746694`], {
             RGBColor[
             0.9510874915293103, 0.9630417117862173, 0.9676802978022608]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.027885652381746694`], {
             RGBColor[
             0.8592163258347785, 0.4536160411257659, 0.20423899016395516`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.027885652381746694`], {
             RGBColor[
             0.4977475489543879, 0.6031329093695432, 0.9536036568444898]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.027885652381746694`], {
             RGBColor[
             0.2084820527788493, 0.336458234369148, 0.9351841165329731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.027885652381746694`], {
             RGBColor[
             0.19190461331519068`, 0.3190342944224739, 0.9342400558796418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.027885652381746694`], {
             RGBColor[
             0.2739918424465178, 0.40531317687043084`, 0.9389148021414978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.027885652381746694`], {
             RGBColor[
             0.22400797509009437`, 0.3527769631185974, 0.9360682948400547]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.027885652381746694`], {
             RGBColor[
             0.19792175174780763`, 0.3253586884237658, 0.9345827230118207]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.027885652381746694`], {
             RGBColor[
             0.2211253737681676, 0.3497471663617724, 0.9359041349591976]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.027885652381746694`], {
             RGBColor[
             0.19120668731506069`, 0.31830072994527303`, 0.9342003100264233]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.027885652381746694`], {
             RGBColor[
             0.19035994618760685`, 0.3174107513338308, 0.934152089371856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.027885652381746694`], {
             RGBColor[
             0.9703310152107799, 0.9773935002394792, 0.9351060317243296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.027885652381746694`], {
             RGBColor[
             0.24693624036742998`, 0.3768760236610595, 0.9373740256282702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.027885652381746694`], {
             RGBColor[
             0.19324911536591247`, 0.3204474513241361, 0.9343166232824178]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.027885652381746694`], {
             RGBColor[
             0.5096359477486948, 0.612784447077024, 0.9545395551462174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.027885652381746694`], {
             RGBColor[
             0.18222514168352894`, 0.3088605560236495, 0.9336888242897137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.027885652381746694`], {
             RGBColor[
             0.20088219976865415`, 0.32847030699692126`, 0.9347513161470175]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.027885652381746694`], {
             RGBColor[
             0.5071373117219987, 0.6107559417882819, 0.9543428533653905]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.027885652381746694`], {
             RGBColor[
             0.17933281357579656`, 0.305820535798229, 0.9335241104827943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.027885652381746694`], {
             RGBColor[
             0.28091140737960196`, 0.41258607834085864`, 0.939308861127858]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.027885652381746694`], {
             RGBColor[
             0.3403985574835718, 0.4692578543884732, 0.9429108729735957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.027885652381746694`], {
             RGBColor[
             0.23139395253121084`, 0.36054009370722817`, 0.9364889153287519]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.027885652381746694`], {
             RGBColor[
             0.18235944175044905`, 0.3090017139090986, 0.9336964724798456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.027885652381746694`], {
             RGBColor[
             0.19489410730752896`, 0.3221764421532881, 0.9344103031399453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.027885652381746694`], {
             RGBColor[
             0.2167015948028579, 0.34509749418544555`, 0.9356522072915177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.027885652381746694`], {
             RGBColor[
             0.8173387448883187, 0.1342787678638822, 0.16423690772735258`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.027885652381746694`], {
             RGBColor[
             0.1829127869860106, 0.3095833148357881, 0.9337279846724099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.027885652381746694`], {
             RGBColor[
             0.18362197162651986`, 0.31032871285786656`, 0.9337683716885422]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.027885652381746694`], {
             RGBColor[
             0.19372013073248498`, 0.3209425183385029, 0.9343434469107393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.027885652381746694`], {
             RGBColor[
             0.1849258667142184, 0.3116991892667612, 0.9338426265848467]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.027885652381746694`], {
             RGBColor[
             0.20594129701488287`, 0.33378773896799957`, 0.9350394242509266]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.027885652381746694`], {
             RGBColor[
             0.8251923969012658, 0.19464537872765014`, 0.17175757376438203`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.027885652381746694`], {
             RGBColor[
             0.1870776850955973, 0.3139608868187558, 0.9339651694583363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.027885652381746694`], {
             RGBColor[
             0.37418878878290995`, 0.4985252543935531, 0.9450639566324611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.027885652381746694`], {
             RGBColor[
             0.9923039511135691, 0.9910855002530954, 0.777206976991627]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.027885652381746694`], {
             RGBColor[
             0.9694202648664492, 0.9767142641238943, 0.9366476944955487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.027885652381746694`], {
             RGBColor[
             0.23765262088408304`, 0.3671183509685898, 0.9368453372325779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.027885652381746694`], {
             RGBColor[
             0.8954246210317355, 0.9194513034296, 0.9898875937806444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.027885652381746694`], {
             RGBColor[
             0.1889310324973132, 0.31590887244697147`, 0.9340707148510822]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.027885652381746694`], {
             RGBColor[
             0.18920356017618423`, 0.31619531631671777`, 0.9340862348992254]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.027885652381746694`], {
             RGBColor[
             0.36433321534571095`, 0.4899888520377754, 0.9444359682079841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.027885652381746694`], {
             RGBColor[
             0.30183205672017543`, 0.43457500724358145`, 0.9405002611584765]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.027885652381746694`], {
             RGBColor[
             0.2599789274537134, 0.39058471474286727`, 0.9381167873629076]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.027885652381746694`], {
             RGBColor[
             0.19899652547638796`, 0.32648834375709396`, 0.934643929785678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.027885652381746694`], {
             RGBColor[
             0.6582217134144572, 0.7329270722804612, 0.9665690470276681]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.027885652381746694`], {
             RGBColor[
             0.19756403157199334`, 0.32498270183821587`, 0.9345623513770076]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.027885652381746694`], {
             RGBColor[
             0.187660141527025, 0.31457308545805707`, 0.933998339490439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.027885652381746694`], {
             RGBColor[
             0.3534033382914345, 0.480521941884955, 0.9437395261069965]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.027885652381746694`], {
             RGBColor[
             0.20794500379241626`, 0.3358937618335345, 0.9351535323876885]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.027885652381746694`], {
             RGBColor[
             0.8200027527924696, 0.15475549999089333`, 0.1667879647049341]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.027885652381746694`], {
             RGBColor[
             0.19665135271400355`, 0.3240234184912868, 0.9345103756662324]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.027885652381746694`], {
             RGBColor[
             0.5240458703783706, 0.6244830714274116, 0.9556739570409113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.027885652381746694`], {
             RGBColor[
             0.20313982636998706`, 0.33084321569671615`, 0.9348798846421041]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.027885652381746694`], {
             RGBColor[
             0.194144227344503, 0.3213882707670121, 0.934367598585399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.027885652381746694`], {
             RGBColor[
             0.37904525788294496`, 0.5027316838347692, 0.9453734065491083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.027885652381746694`], {
             RGBColor[
             0.1851145385676597, 0.3118974953472144, 0.9338533711677852]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.027885652381746694`], {
             RGBColor[
             0.1880939032775767, 0.3150289965599703, 0.9340230415804399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.027885652381746694`], {
             RGBColor[
             0.1990369147875074, 0.3265307954839108, 0.9346462298971957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.027885652381746694`], {
             RGBColor[
             0.2089289786028837, 0.3369279817469421, 0.9352095682974844]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.027885652381746694`], {
             RGBColor[
             0.39875120665503094`, 0.5197999862113661, 0.9466290521795794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.027885652381746694`], {
             RGBColor[
             0.31502354175322494`, 0.44727929114822085`, 0.9412939994095033]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.027885652381746694`], {
             RGBColor[
             0.9319225428018962, 0.7678025982169813, 0.26408148383634866`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.027885652381746694`], {
             RGBColor[
             0.7398648594018855, 0.7967073184367315, 0.9747064728211174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.027885652381746694`], {
             RGBColor[
             0.18427610046840573`, 0.31101624374485265`, 0.9338056233583907]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.027885652381746694`], {
             RGBColor[
             0.3212434064694567, 0.45266662534593033`, 0.9416903236892111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.027885652381746694`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.027885652381746694`], {
             RGBColor[
             0.2137339467700851, 0.34197830794324846`, 0.935483204126293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.027885652381746694`], {
             RGBColor[
             0.4742143938317012, 0.5840276338843894, 0.9517510406684443]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.027885652381746694`], {
             RGBColor[
             0.25752973177491306`, 0.38801045479647306`, 0.9379773092922603]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.027885652381746694`], {
             RGBColor[
             0.1954605501868454, 0.3227718095340026, 0.9344425612239453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.027885652381746694`], {
             RGBColor[
             0.8194918846006688, 0.15082874320484374`, 0.1662987567475226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.027885652381746694`], {
             RGBColor[
             0.3141297509318431, 0.44650513446197276`, 0.941237047848713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.027885652381746694`], {
             RGBColor[
             0.20973292712492791`, 0.3377729826168909, 0.9352553519764795]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.027885652381746694`], {
             RGBColor[
             0.18590102371033476`, 0.3127241410982041, 0.9338981603331601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.027885652381746694`], {
             RGBColor[
             0.17907641669607907`, 0.3055510464211448, 0.9335095090597996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.027885652381746694`], {
             RGBColor[
             0.2965600408339725, 0.42903378428206873`, 0.9402000276530058]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.027885652381746694`], {
             RGBColor[
             0.20546571259734456`, 0.33328786959137313`, 0.9350123404219118]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.027885652381746694`], {
             RGBColor[
             0.18838969891108812`, 0.3153398965253172, 0.9340398867041779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.027885652381746694`], {
             RGBColor[
             0.19616100168040002`, 0.3235080284649182, 0.934482450900278]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.027885652381746694`], {
             RGBColor[
             0.24986810421890843`, 0.3799575984598681, 0.937540990937308]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.027885652381746694`], {
             RGBColor[
             0.19470143524485908`, 0.32197393159930776`, 0.9343993307510091]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.027885652381746694`], {
             RGBColor[
             0.8939300581111314, 0.611242991794526, 0.23320497928678602`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.027885652381746694`], {
             RGBColor[
             0.2822705085644714, 0.4140145798581486, 0.9393862599297264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.027885652381746694`], {
             RGBColor[
             0.29805944165302733`, 0.4306097496103981, 0.9402854163114862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.027885652381746694`], {
             RGBColor[
             0.22229995450050422`, 0.350981725184178, 0.9359710255942676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.027885652381746694`], {
             RGBColor[
             0.17902996710188124`, 0.3055022249525685, 0.933506863824126]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.027885652381746694`], {
             RGBColor[
             0.212847764567014, 0.3410468742606238, 0.9354327373608172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.027885652381746694`], {
             RGBColor[
             0.6973666945960665, 0.7635074290924103, 0.9704706529212034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.027885652381746694`], {
             RGBColor[
             0.8265166883216026, 0.20482446289255998`, 0.17302571672406986`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.027885652381746694`], {
             RGBColor[
             0.2025961788233211, 0.3302718076559249, 0.934848924718576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.027885652381746694`], {
             RGBColor[
             0.5478165382686445, 0.6437811704771209, 0.9575452710920592]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.027885652381746694`], {
             RGBColor[
             0.28461757525764775`, 0.41648149576530025`, 0.9395199219057286]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.027885652381746694`], {
             RGBColor[
             0.18275376889499648`, 0.30941617673980293`, 0.9337189288273728]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.027885652381746694`], {
             RGBColor[
             0.1811098371299533, 0.3076883002234485, 0.9336253093453327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.027885652381746694`], {
             RGBColor[
             0.7121412574025138, 0.7750494298476431, 0.9719432432656107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.027885652381746694`], {
             RGBColor[
             0.18850413369751906`, 0.3154601747414406, 0.9340464035959741]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.027885652381746694`], {
             RGBColor[
             0.21345649486519924`, 0.3416866883997466, 0.9354674036507632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.027885652381746694`], {
             RGBColor[
             0.8324443832728455, 0.2503873238203034, 0.17870208410375396`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.027885652381746694`], {
             RGBColor[
             0.18370800885926494`, 0.3104191434445573, 0.9337732713816664]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.027885652381746694`], {
             RGBColor[
             0.18455342051778426`, 0.3113077246998561, 0.9338214163249446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.027885652381746694`], {
             RGBColor[
             0.1951112049063669, 0.3224046254944496, 0.9344226665270321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.027885652381746694`], {
             RGBColor[
             0.42062186552277797`, 0.5387432516713317, 0.9480226312231679]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.027885652381746694`], {
             RGBColor[
             0.1856877903127057, 0.31250001927751764`, 0.9338860170066157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.027885652381746694`], {
             RGBColor[
             0.23827199083861747`, 0.36776934806112876`, 0.9368806094352129]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.027885652381746694`], {
             RGBColor[
             0.24157157412247404`, 0.37123741929812537`, 0.9370685158219325]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.027885652381746694`], {
             RGBColor[
             0.18576331458524015`, 0.3125794000764668, 0.9338903180022083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.027885652381746694`], {
             RGBColor[
             0.2313516506730186, 0.3604956317721754, 0.9364865063005079]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.027885652381746694`], {
             RGBColor[
             0.2623389378177228, 0.3930652352687406, 0.9382511864618155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.027885652381746694`], {
             RGBColor[
             0.18870039039885345`, 0.3156664529779366, 0.9340575801247794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.027885652381746694`], {
             RGBColor[
             0.24096885499463874`, 0.3706039232801706, 0.9370341918592453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.027885652381746694`], {
             RGBColor[
             0.8178049183525352, 0.13786198138836525`, 0.164683315963154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.027885652381746694`], {
             RGBColor[
             0.9537765326908467, 0.9650471942815904, 0.9631284525300384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.027885652381746694`], {
             RGBColor[
             0.9602115875305376, 0.8774464833562946, 0.2999299602777051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.027885652381746694`], {
             RGBColor[
             0.1982643030525542, 0.3257187315640616, 0.9346022308018668]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.027885652381746694`], {
             RGBColor[
             0.23480104226620413`, 0.36412116104067216`, 0.9366829440488222]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.027885652381746694`], {
             RGBColor[
             0.956979221732861, 0.9674357545252026, 0.9577071353769899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.027885652381746694`], {
             RGBColor[
             0.21013611726343454`, 0.33819676101619267`, 0.9352783130584011]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.027885652381746694`], {
             RGBColor[
             0.38195753878243316`, 0.5052541551744117, 0.9455589745127948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.027885652381746694`], {
             RGBColor[
             0.27139200070452485`, 0.4025805783601091, 0.9387667450004126]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.027885652381746694`], {
             RGBColor[
             0.24934350578881678`, 0.3794062122483802, 0.9375111158327881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.027885652381746694`], {
             RGBColor[
             0.18639411010760892`, 0.31324240616522253`, 0.9339262408740289]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.027885652381746694`], {
             RGBColor[
             0.20071986914810575`, 0.3282996872223691, 0.9347420716583239]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.027885652381746694`], {
             RGBColor[
             0.1915625031716876, 0.3186747149706162, 0.9342205732130758]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.027885652381746694`], {
             RGBColor[
             0.8280837295399454, 0.865755504473851, 0.9834645594342339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.027885652381746694`], {
             RGBColor[
             0.20342618893072584`, 0.3311442009044876, 0.9348961925663027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.027885652381746694`], {
             RGBColor[
             0.18432439621433888`, 0.3110670056359555, 0.9338083737296745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.027885652381746694`], {
             RGBColor[
             0.20110409825488346`, 0.3287035363751249, 0.9347639529375389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.027885652381746694`], {
             RGBColor[
             0.19841472542917707`, 0.32587683501922177`, 0.9346107971336854]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.027885652381746694`], {
             RGBColor[
             0.3485452682138572, 0.4763141257574593, 0.943429974177476]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.027885652381746694`], {
             RGBColor[
             0.3095548228305918, 0.44254256168324113`, 0.9409455374755513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.027885652381746694`], {
             RGBColor[
             0.18638553952238943`, 0.3132333979367503, 0.9339257527918797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.027885652381746694`], {
             RGBColor[
             0.9932598001133134, 0.9879917189181485, 0.507749021905247]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.027885652381746694`], {
             RGBColor[
             0.19610120868731518`, 0.3234451822380914, 0.9344790457777777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.027885652381746694`], {
             RGBColor[
             0.2081404760074813, 0.3360992155252221, 0.9351646642411613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.027885652381746694`], {
             RGBColor[
             0.9453835605713274, 0.9587877294170835, 0.9773355650906732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.027885652381746694`], {
             RGBColor[
             0.18600360463112436`, 0.31283196014996, 0.9339040021648441]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.027885652381746694`], {
             RGBColor[
             0.2775970966062373, 0.4091025275786123, 0.9391201160323983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.027885652381746694`], {
             RGBColor[
             0.32568965645452963`, 0.4565177436079784, 0.9419736348065956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.027885652381746694`], {
             RGBColor[
             0.6627555094400547, 0.736468908193784, 0.9670209334447669]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.027885652381746694`], {
             RGBColor[
             0.40957405763887067`, 0.529174195761261, 0.9473186746739982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.027885652381746694`], {
             RGBColor[
             0.7912709059084366, 0.8368661126680731, 0.979830147120073]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.027885652381746694`], {
             RGBColor[
             0.3745258073527012, 0.4988171629396605, 0.9450854311577144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.027885652381746694`], {
             RGBColor[
             0.92133834354613, 0.7258397751431882, 0.2555651886720716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.027885652381746694`], {
             RGBColor[
             0.30601698137869693`, 0.43897362839923615`, 0.940738586426738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.027885652381746694`], {
             RGBColor[
             0.9933000584574108, 0.9880778274454297, 0.5121308942145434]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.027885652381746694`], {
             RGBColor[
             0.1860930553658944, 0.31292597854370746`, 0.9339090962518588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.027885652381746694`], {
             RGBColor[
             0.1838330998850932, 0.3105506220439319, 0.9337803951305317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.027885652381746694`], {
             RGBColor[
             0.1804054273287139, 0.30694792086018496`, 0.933585194249233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.027885652381746694`], {
             RGBColor[
             0.18554668841356567`, 0.31235171223514435`, 0.9338779814622011]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.027885652381746694`], {
             RGBColor[
             0.18003320207443918`, 0.306556688517498, 0.93356399657166]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.027885652381746694`], {
             RGBColor[
             0.179946795179367, 0.3064658693922636, 0.9335590758268132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.027885652381746694`], {
             RGBColor[
             0.19798515205544082`, 0.3254253261669, 0.934586333565548]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.027885652381746694`], {
             RGBColor[
             0.1836365577609456, 0.3103440438099624, 0.9337692023473195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.027885652381746694`], {
             RGBColor[
             0.20279567675606608`, 0.3304814926321394, 0.9348602858307151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.027885652381746694`], {
             RGBColor[
             0.28617898913701123`, 0.4181226407518692, 0.9396088421162536]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.027885652381746694`], {
             RGBColor[
             0.25469411239970985`, 0.38503003904448196`, 0.9378158249637654]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.027885652381746694`], {
             RGBColor[
             0.24023703411797065`, 0.3698347331386689, 0.9369925157429511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.027885652381746694`], {
             RGBColor[
             0.18246816409549027`, 0.30911598798713175`, 0.9337026640565553]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.027885652381746694`], {
             RGBColor[
             0.7203821791624184, 0.7814873005598058, 0.9727646213308456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.027885652381746694`], {
             RGBColor[
             0.1893487791980019, 0.3163479507160659, 0.9340945049076855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.027885652381746694`], {
             RGBColor[
             0.3220959675484921, 0.453405070901625, 0.9417446481272771]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.027885652381746694`], {
             RGBColor[
             0.3583175561905998, 0.4847783904334387, 0.944052655726059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.027885652381746694`], {
             RGBColor[
             0.9335847383251342, 0.7743926495727972, 0.2654189253710895]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.027885652381746694`], {
             RGBColor[
             0.9944175835604394, 0.9904681006416884, 0.633766605113725]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.027885652381746694`], {
             RGBColor[
             0.3419268933615933, 0.4705816221096207, 0.9430082571842888]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.027885652381746694`], {
             RGBColor[
             0.18554205504628538`, 0.3123468422723603, 0.933877717598789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.027885652381746694`], {
             RGBColor[
             0.2707814877613013, 0.40193889054802484`, 0.938731977191469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.027885652381746694`], {
             RGBColor[
             0.9931232770303468, 0.9876997098482838, 0.4928893268471293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.027885652381746694`], {
             RGBColor[
             0.21298290042549683`, 0.3411889106159976, 0.9354404331480423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.027885652381746694`], {
             RGBColor[
             0.8202342132018924, 0.1565346061243149, 0.16700961145439447`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.027885652381746694`], {
             RGBColor[
             0.2030621295519029, 0.3307615514146469, 0.9348754599232564]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.027885652381746694`], {
             RGBColor[
             0.7219717591850786, 0.7827290925547635, 0.9729230558120345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.027885652381746694`], {
             RGBColor[
             0.35762511408731845`, 0.48417863188672844`, 0.9440085339275405]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.027885652381746694`], {
             RGBColor[
             0.4386808762090538, 0.554385059055515, 0.9491733354151413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.027885652381746694`], {
             RGBColor[
             0.18439801323969868`, 0.31114438179719767`, 0.9338125661103621]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.027885652381746694`], {
             RGBColor[
             0.36417957475425095`, 0.48985577627965343`, 0.9444261783653554]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.027885652381746694`], {
             RGBColor[
             0.1808071689883251, 0.3073701768163288, 0.9336080728424244]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.027885652381746694`], {
             RGBColor[
             0.3593758114062829, 0.48569499791180964`, 0.944120086812624]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.027885652381746694`], {
             RGBColor[
             0.8221152183090297, 0.17099283563946593`, 0.16881086406928056`]},
             StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{3.8349504055390835`*^9, 3.834957759852075*^9, 
  3.835023917277974*^9},
 CellLabel->
  "Out[179]=",ExpressionUUID->"84fbb0f9-9875-4f7f-8237-47e95d5df4e1"]
}, Open  ]],

Cell["Estimated with Max-Min Deviation v Calculated: (r = 3)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 3.8349503922098827`*^9}, {3.8349504781120467`*^9, 
  3.8349504928656063`*^9}},ExpressionUUID->"cebc3af3-6532-4d50-b24a-\
ca9c91221958"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphin4", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsi4", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}], 
     "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"mMDi3400", ",", "kri4"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502554527807`*^9}, {3.8349577716948586`*^9, 3.8349577796673746`*^9}},
 CellLabel->
  "In[180]:=",ExpressionUUID->"7ff2ad81-2165-47c6-b5cd-bb6907eb449f"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN3AuYzmXewPH7z7a1WxZbu0o1DqFsy5TT0CKyGGKYrMNM4zSN46CIkAnD
aEgSLzN2286E9b6tVta7r8OyJGq9yRLZ16FW1GoTNqKN9/m6v3Nde139rk8z
8zz/w33/7t99/+/nqTr5Dz8wplII4ZvvhYDjkxBmp6I49e+jUmanXJiKfqm4
HOLPpam4ORUXU7EoFQf9+7AkvgYXpDyUirq+bkAqmqZ+f8bj/Cj1708m8X0b
Dd43OeUOj9/Q4P01Un/LTOL5aibxnHh1iMcpSlmWioe8HjzitQ5I/X2u3pQy
KxVdPGe6x+b1N3j8Gzw+EpynSyqGpqJ36vcrUlHdc1T3PLRXLY//oMH9Vwvx
d9U8L/f7me1YmMTrQ9rnz0ZT7+cl7wl/kYq23sfjKecrv6+dxGhrv1VNYnA9
lUNso8q2U/sQ7wWHepxVtsOjSWwLpM/b+P4NHgM7Ktef4euQ4PXTQuzjafYz
0m/zUm7zOiYksf8nGFxXbduwttdf+9/a85TtOdC8wkN6T4htdY/tRH9Mtz+n
24/TPV5326e77YPc93VJjBr6qK/vbPDazl4PebPO65nvdSDXgo1SP3/X9u2d
xFzpbf70Noaa90kScyGxnavYzlUM2qiK7VXF/iv0fgvNjULv+/4Qx80jqfg6
FeeUdlhpHFRyeqV5x/3clsR7wo3K9TT1OpoaXE9Tr6ep18P4ftG4aJ6Ptt/w
lPL7yf4es/SU8hpk3N+exHGPN4TYVrhRL2vi34d5/BKPX+LxSzx+iccv8Rwl
1rVc8zfX/M01h7FliH3Y0v5r6Xghn+cYZzTTcZTv8fI9Xr7Hy/eY+b6uPMTX
lRu8FttorvL674Q4xrG2PzPO6e92Sexz/HGIuYeMtRLzGslrxt6YJNb0Mb6+
rvla1/FZ1/bbHWL77TbPcYESh5Sc3237ZoR4jgzzP8Pzkf8HDMbAAdvzgO1J
/81yPMxyPCB9O8txt9c4ZX7VD/E66xtZukB3K31e3/yq/2/XOcXYprTJFK93
iuenzjazv5rZH7hKm9mf+LjtmWY7ptneSNS1nuwPsd7jXCUG+PdmRrFSd7CW
Uq+oc4OSeK8njc6Om7tCHDd3mQt3Gbd7/GLbE/fqET2lnBNrKe1dxbyoYjtW
8fVYxbFVxbFVxfHFONlinNHLSntvsZ1p32q2K1azTavZrtTnxebzYoO8Xmxe
I+OPOjQxiXUILyrHmWh79UhieyFthrkh1kraa5jtNcyoaLdS2x+LlXYqtZ2w
u45S1glTzP8pjsNxSbx2rKFPhnjvT3r/47zXcd7nOO9znO+nvv/VoL4z3x0O
sc7jSj2oxBEttG7cYd3AHydRjlPP+61nnuBhPaLcdz3vu55BnlBPZxilulDL
lTqHbTRXGUe/SjlWx+ts8yPP8ZdnnuTZr3nmSp6Rr+RN+9TrWiVxPYes4VoZ
XbSinu8JsY7vMb/2GLT7HvPrtyGuzfCANvX39G+HENsWd2g72zPb/Mk2f7Jt
x2zzJtsgb5j/qydxnVXdfsANSj/PSWIb40rdr4f1iNLnV6QPkrh2wHlaptuU
ejXD9j9h0C8n7JcT9gvrgx+EeL1YRYmO2ln3KtePrBuo++2MfjpFt+hnylyA
1IuaKd8IcRy8YfxVGQ/M0wUh9n+BwXyD9Dfz5w+TOKciUVuZV8mD4+bBcfPg
uEE+HDcfmBc3h1hXNhu79ZBSX3CgzjffKnkeXKx79LhWskZgpuOzlvGQrtT9
eliP6JVxGmIO1DIfyNe+ScxlPKDkcl/HBjLPLAkxb7BIy5R4KcT8Tje/083X
dPM83TxPt16kWy/SjWIttT2W2u5LjT16XGmLpfbDUvuBeXdNiNe7xutd4/Xi
PC3TJUqQ61hXByn5z/p2aojjGO9XgnGNExzfOd4/ztX9yv3nOM5zHOc5xgDz
cVOI+bjJIBextrb1dcvMt2XGJt2sh5T3L/P9y3z/MvNwmXn4yxDnJvytHtAu
/r239tWhSr1jr+BKDttnlSr6yH6rZL9Vqshn++u6EMcmFmihFmmZrtDevq/i
/J94zfhnPaAEufyJ9/GJ18/81CmJ830n6yae007WSurS1hDrDfbTLUqc0cvK
8wfO8vjfSWJ9wjf0r3pOv1bGdbCe4CH9TInpHu+bEI+D5/Rr/cbjXRPimg1v
0lNaxb+P1snKei0/xDUIztdyXaXVfF0zzdN8Zd4lP/tb7/Ckst7CHsq1NU/i
3ICnlGtsbp1obozWYvPoksG8lGbOppkvaeZGmjmRZk6kmQ9p5lOaeZFmXqWZ
18xPO0Ocw7CzblCCeQypXcxHt9rPyPNFK+O75u2NRkttrwVaqEVapiuU673R
60TqE8/t74U4T+NGJU4oz/E4XmdbL98PsS7iGiWoh1hXOQ/7AkOSOB66JXGO
xi26TYlROkZnWR8HWx+xWPcr9RFrabp212zNUaLU++ga4rq9qzFP1+j7yn11
9b66el+8/4Ekvv8Bf/+A94289gHHR4ckjqkO5i3W1916SsnfDuZrB2O0TlbG
G/PL6hDnkdUG+yvYTico6yXWV7tCfN8u37fL9+0yeP8u37fL9w0NcU7C7v6c
rTk6QBm/Pwvx+QMX61Ldo8e1kq+/Tmtopu3VM8R2wiwlaAcsMT8aG810qM7V
/UquYC3trtmaowOUXGH93yiJe15YU4lW2sX27Wv79jVW6y6lffvavn1tX567
+4T43IitlGD8s1Z71likK/WgHlauEWvqdOvJLUk8LnLMWwzGGTVle4g1BQt0
u+9n3ptozNBSXajlyvMZ5uoAzfc41/ozztCFWq5EhrbRXM33fjJtp0yjj3Jv
md5npv2baf8yT7ZI4n3hZ8r8iIkS3Dfz0Zchzmm4SolqjuO5jmN8UBfobmW8
4kAtUdbx9yex1uIZvawE9ZZ9iSeSuC+DL+pFZW/iCevMOyF+/vGOsVdPKbUF
m+tox9s1Xg/O0cW6VDfoHj2ujOFrjBrK+H0gxDbG4M+JttD5jrPpIebHdPNo
ujFDS3Wulut+rRiv+0Ic+/s8zj7/vs9j7PMY+4z9ynoEc3SAUs9Yz50OcX7E
rUqc0ctKn+Ewne37J4U4/2E/JbboVj2tZ/SyctxJHheZF1nPPxHiuv8JY5Oy
fsfayvr9JyE+i+D9ukN/7N/v0Hb2T2vzGg/pZ0qftna8tDYG6nzr2r0h5i3e
pcQwZX/s1hDXCDjEfmwdYi1vbWTqUJ2rjG/M1hwdbLsPT2K7Yz+dpFt0q57W
y0qu4jAlaHfWj0+FOF5wjhKLdanu0eN6RhkzeI0yXlg/PGYU6Twt0zW6Td9X
1ifIuuS24GcyIa7t8D09obf5uvFKnvJ8fzTE8YKlulL362EleN5B9gWYr7sb
WdpTma+R2se8dHcS5zI8qMxdWFMbKdFKmWereg9Vvb+q3l9V7w/H+rrxyv0x
b3we4rzxuTmFfZRg/sBblPmR9fcXIa6bsbcWapGW6RJ9SVcoedPEmKZz9Cld
qnv0uJ7RS0r+NDFvkPrAOmGE7TvC9sWVelBp5xG28wjbeYTtO8K2Rp5fZob4
/ILFSuxUnmMwXUutG38yDulnSs3A1jrfvPinuYLUjUlJ7CfM1D76udJXyL72
myGuOd80WE8i+93s66y1v9baX2vtr7X211r7a61Bf/00xDkJJ+p0naGlulDL
lbUKZmgb7aSsZ/hc4rkQ518cpyW6WJ/zfrCGjlM+Z2beb+z4a2x7Ypb21H8q
tb6xMdn6O9ZYp0M87t9DXE/gDn1HCdYPPAeND/E5CLsqMU/X6PtKvcK6ynMS
66mRSTw+7tVTytoF62lz7aDEaC12vGcl8XkTt+nnyhjHbkqM0jFKPjewTxuY
Dw3MhwbmQwPzoYH50MB8aGA+4D49qtd63AzN1QFKXWX9+WqI689XjVX6pVZ8
3nPBvLlgvuCbesH8uWD+XDB/qEdvhVg/3jJO6CWljmLFc/9diZ8LJrGf77L/
cJ6+r/Qx1lWCfmbf/9MQn5ewqfbV1fqm7lKC5yecoDw/sQ76OMR1Di7TTUqw
HsLa2tbx8vsQ8w7ra3fN0p66QIndSu7hZC3RuR5/vcdf7/HXe/z1Hn+9x1/v
8dYbu5Uxut7jr/f47C/VSWJdxsn6ju5VcvW1EPcTXzNW6jmlHr1mvvGccafx
ol5UnjGQ5wz2q36exO8bIXtWyLpxVohrTLxfiR1K7cE7tJ31+f+MQebl7Ua6
NtHFulTf0j16XC8p8yRmmnf1k/h5U33bsb7zXH3nL9ygO5U5Dpn/6xj3aFct
1PH6mBbpPC3TJbpG31fGDM6wP9rb7viiXlRiotIvPMe/HuJzPBYosV2Z27GL
9lb2BZl3OyZxvd7R82IrzdQ+elGZhzsak6xfTaxfOFGn6wydq/N1oZbrPqVW
NjGaaYbmap4O0Hzl+Y15YJ73Mc/7mOd94OfKfeAt2lEnKe37/SS2Lxbo67pd
iaHKPsK15gNO0Xm6TdN8XTcdo+TB90Pc48Jm2lqLtaqvS9fumqXZmqODdZSW
2j4Nk3jshrZTQ9sJh2pD26ah+dfQNmpoeze0vej/F0Lsb5yvC7VcCfr4Bfsb
m2mGttFczVP6mbH4dBLrB1JDkPr0jxA/3/mHwec6SL3i+bAgic+H2E8n6RTd
olv1svJ8iN2UGKbDdZTO8jw3e9ybPS7e7DEwSwt0uI7SMcrxqLe/C7HO4iwl
dij1Fqm3zUOsdThTN+hOvcbXVVfqHvPrv0LcZ8AndJlu0o+VYL7F2trWfHgs
iesZnK8v6Ku6Sr9U1jjYTPM0X5mPOhm5+oaeUz7XQuaq74U4lrG9Fujrul2/
7+tb6VBlXDOf/CjE+QSrKDFOS/RN/VQvVLyO+wl+FhZircxzzOQ5ZvIcM3mO
mTzHTJ7jJs9xk+e4yXOc5DlO8hwnebYnewOPJHGdj+v0PWVv4BFjvOMkJ8T3
YT8l1ulG5b3IOGA/4e0Qaxc21mZK7NfDekSPKnUNa2k9zdEBOljZh+B5fXmI
8/Vy+3i5fYyFWqRlSqzQA/qFMk8ut//rpPwqxLrzlcf7yuPhEn1J1+haJahR
SJ36bog1GJtrR+2sxTpTd2p135+uo7TU+vBMEtdjeL/O0t/pDqVGYDtl/vkg
xLqFU3SbbleCWogttJtSp3iOnBDiOhjrK3FKebbD5tpBR+ponazFWqJzzbdp
SVx/4E81W6drqb6mK/WwHlXWxlioxBzr+BBjim5RavMQ7x+ztEBH6Rit2E8c
GeI+1UjjLT2hl3Ss93W994UzdKF+rd8oNeJ6I0PbKHWC5/9XQhzfmKNjlVin
jG8coo+YJ71CXGf1Mh7TKTpPt+kHyrqnl+3Vy/bqZfuwbp8d4jPAbGOxPqc8
12INZT+E+eoPIc5X+IQSm/Rj/ZcyX2FtbatDzKtnk1jHsLF21rd1vx5RahfW
0nqaroO1WMnbv4XYv5itE3W6ztBSXajluk/361ElmCcwQ3N1gBbqNOvItyHW
pm/N72/tUyzWLUqQ/9/an9/anzhKxyj1ifXDfUn8ngd+rCeVPrjP6Kw9tL95
+4Mk9jPm6Fh9RdcpMcT7eibEeRuba0edqcQG3anUW6xvXlQ2LyqbF5WtM5Wt
M5XND9yn+/WwHtXK5kxlc6ayOYM5OkAH6xwlf/h8s22Idbat8aBO0CPKPix2
0JFKHWU/5idJ3FfAqbpad+jflWinE5R9mdQ/V/oIu+hYfUXX6W2+fohSV9qn
/EUS97HxdT2gnyj72NhI79ZW2kWJvjpU2ecmv38e4roEM7SVtlYiUz9Xnhnx
Fu2uWZqtk7RUeT6ifowxJug7uldPKfMj1tI6Wk/TtbmO1GJ91na9yrhVx+or
uk4ZK1fZL1fZL1fZL21CXEtjri7Smv79Vm3keL4qidFZe2h/x8+IEMfPCPth
hO0+wnhb9ys5j1W1lqZrd83WHB2gg7Vi3JwPcTxjbW2rY/RtPaxH9LzXcd7r
OG+/nLcfztsPOEc5L2032HhNV+pRPad8ZoOdtFCnKcdlnd4ziWMN+2mOvqIb
lT7G25Rg3U4d/lkSg1rLevp640btrYVapGW6RF/S5bpC1yrra9aDw0PcD8We
SizQ3+t63ay79aSSU9hZe2h/5fNp1hN3JvFzFxynJTpbF+tzelwvKGsPrKFX
jqWP2h9X2w9X2w84STfqVr3aPrjafsCKz6+Lkjj/Fvl+nKZbdKue1jN6WZmb
sZsW6HAdpQTrUvavB9k/2F2ztKcOsu0H2U+D7KdB9s8g+wUna8X3RfskcT8A
5+urukq/VPYB+hh5yvMs37tskMTvcOJv9YB+okQjbaVd9BfK/FAjxLUY5mm+
TtTpOkPn6nxdqOX6gu7Taz1PE22mGZqreZqv3C/PU91C7B+8SetrN/uom33U
zT7ACfp7Xa+79ZQy32AHHa2TtURZL/BdjseN/1I+56EN7wtxPXufka0TdYYu
1HJ9QWknvF4ztI3mar7nO+v5zvr+s57zrOc8a9+d9dxYqgv1b3rW85/1/Gc9
P3bSXC1U6jH7Q72S+Dk8LtKDSi3HmtpI79ZW2kV7mZ/IeoX1601JXLdiR52p
T+kzukF3Kp+J4DVaXQnWtXx+/58hrh1xmRKb9U96SFlcYGsdqHy+z/zxfIj1
Hm/UOlqghVqkZbpEiZd0ua7QL5R9Ghyq7J+zD/JwEvc98He6Q9kjxTu0sbJ+
GRjiWgdzlRisi/Q1XannlL7Gmnq3dtIRnueY5znmeY75/mOe45jB8Y55PGyk
HJd9hA9DfG7GJjpS31LihF5Svj+Cs+2vv9hff7G/ME3ba4EWapn+Up/X5bpC
iQP6hdJvf7HfaI+ptg8O1of0WV2kK/WgHlPaaqrjbKrjbKrjbKrjaapjClkH
3pvEdR8e0fNKjmMLJdgHZp5/OsR5GvvpJCW26FY9rWf0sjLnP21/YIEO0+Fa
pMzTd4e4/sGr/Lmz9tD+1qV3Q+zfd+1XbKnttUCf1+X6um7Xd+27d+1PZL8c
u2hvHeo47JrEfciujseujseujseujseujseuxsP6jPfxwxD764fGQ/qsbteD
ynVhC71X6T/q0K9D3M/9tfmMRVqmS5R4SdfoWv1K2d/Fp23/j0Kcg3G4LtDN
uls/sj8/sj/xPu2sPZR+5btwNyZx3Y85+opu1PeUuE176iNa8X3VlknMZ5yk
0/Rp3aJb9bSe0cvKurOlUaDDdLgWacX3Wv87xH0dfEKXKfEH3aQf67+U/Tys
rewlMW/2D3HfB5trRyVm6jO6QXcqcyZW15uUeZP6e4txuzbRkfqWfqgn9JKy
v8vnQqONcVqib+qneqHidan31QuxdmInzdWBukiP6Q2+r6Y20rt1hE51/D6Y
xM8THnQc41Sdpat1h7IfhO30Qccx3zf4XhK/54AN9U7toy/qRSXaa0edqHwP
gs/leoT4eRw2VaKvTtXVuks/Vb5nhD/RCcq+FuvLfklcX2K2TtQZulDL9QU9
q6wt8XrN0DZK5CrrW55bf5rE51YcpyU6Wxfrc3pcLyjrP7xOa+ideuXYynMs
OfwfIdYBfFqJrfqhntDTekYvK2Mc79dhSt3hc4QWRjvtpVN0m27XDyrek0S7
6ZX//0fKmUmsj9hFf6XvKXXvyuv0ER2vjOt7kjg+8XYdqW/ph3pJibHe18te
J2ZoO+2lQ3SKvuz9vux94rdKTX3Z+8UsLdBROkZpD+rfU0mse0+ZR9hR++s0
nalz9Cl9RjfoTt2jV77bnvjd9iTWSrxJ6yvz4G9CnAdxmRKbdbce0o/0pDIv
Yg/trzx/sD54OMR9PaytbXWMEm/rYT2i55X9vSvH0nraXO/VkVqs7PMx/z/k
/eICXaa/0c36kZ5U1gB4n3bWHtpfByrn+6PxkZ5UjvVH2w07aw/trxyH/Yb/
CXEPBPN1rs7Xcl2lBHs12ESbaR/N08eU7w0xH9xhNNS79F4dptR65L8faZfy
0RDHz6PGFH1Zt+hW/UC/VT6/xpu1pXbTLC3Q4TpKx2iRznLc/2+I6228Ueto
C22p7bVAH9MyfV636XZ9VwnWuZimPP/yOcaoEPfTMVOHKsF3trCjTtLHlc8r
/h+zL1/H
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[37, 104] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[119, 243] -> 
             RGBColor[0.905825, 0.92682, 0.9588341086956522], 
             UndirectedEdge[165, 226] -> 
             RGBColor[
              0.9661353695652174, 0.9287442608695653, 0.6174985434782609], 
             UndirectedEdge[235, 261] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[56, 198] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[50, 254] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[249, 268] -> 
             RGBColor[
              0.5858990652173913, 0.6483570217391305, 0.8506541739130435], 
             UndirectedEdge[38, 224] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[79, 87] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[38, 311] -> 
             RGBColor[
              0.9172722826086956, 0.9329257826086956, 0.8102031304347828], 
             UndirectedEdge[37, 145] -> 
             RGBColor[
              0.9614017608695653, 0.8858897826086958, 0.5654167826086957], 
             UndirectedEdge[147, 359] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[192, 349] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[213, 308] -> 
             RGBColor[
              0.8185345652173912, 0.8584653913043478, 0.9501769782608696], 
             UndirectedEdge[262, 397] -> 
             RGBColor[
              0.977582652173913, 0.934850043478261, 0.4688675652173915], 
             UndirectedEdge[129, 364] -> 
             RGBColor[
              0.7247748913043478, 0.7619545217391305, 0.6637009130434783], 
             UndirectedEdge[54, 83] -> 
             RGBColor[
              0.9004813913043477, 0.9234834347826086, 0.9903699130434782], 
             UndirectedEdge[13, 277] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[191, 235] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[54, 214] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[87, 176] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[16, 377] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[158, 344] -> 
             RGBColor[
              0.8292568913043479, 0.8630205652173913, 0.722638956521739], 
             UndirectedEdge[95, 228] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[193, 283] -> 
             RGBColor[0.9409797173913044, 0.871139695652174, 0.62151], 
             UndirectedEdge[11, 366] -> 
             RGBColor[
              0.9577559565217392, 0.8631764347826087, 0.3215687608695652], 
             UndirectedEdge[106, 231] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[76, 388] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[208, 351] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[208, 225] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[163, 374] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[165, 288] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[110, 239] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[14, 273] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[231, 372] -> 
             RGBColor[
              0.8292568913043479, 0.8630205652173913, 0.722638956521739], 
             UndirectedEdge[5, 162] -> 
             RGBColor[
              0.977582652173913, 0.934850043478261, 0.4688675652173915], 
             UndirectedEdge[36, 90] -> 
             RGBColor[
              0.9479054130434783, 0.8323812608695653, 0.5545573043478261], 
             UndirectedEdge[258, 328] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[91, 208] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[155, 370] -> 
             RGBColor[
              0.9165473260869565, 0.9313751739130436, 0.7312960869565217], 
             UndirectedEdge[66, 243] -> 
             RGBColor[
              0.9536300652173912, 0.8805743043478262, 0.6000962608695652], 
             UndirectedEdge[253, 334] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[50, 210] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[239, 365] -> 
             RGBColor[
              0.9022020217391304, 0.5615271739130434, 0.5139578913043479], 
             UndirectedEdge[13, 51] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[258, 300] -> 
             RGBColor[
              0.9614017608695653, 0.8858897826086958, 0.5654167826086957], 
             UndirectedEdge[30, 294] -> 
             RGBColor[
              0.9467338478260869, 0.9554450869565217, 0.7341753043478261], 
             UndirectedEdge[31, 292] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[203, 216] -> 
             RGBColor[0.8755362608695652, 0.901176, 0.8721707173913045], 
             UndirectedEdge[64, 233] -> 
             RGBColor[
              0.9356947173913044, 0.7782312173913045, 0.5444354347826088], 
             UndirectedEdge[50, 242] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[133, 398] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[7, 390] -> 
             RGBColor[
              0.9357184782608696, 0.7828522173913045, 0.2671357826086957], 
             UndirectedEdge[186, 342] -> 
             RGBColor[
              0.977582652173913, 0.934850043478261, 0.4688675652173915], 
             UndirectedEdge[347, 398] -> 
             RGBColor[
              0.7814113260869565, 0.825494347826087, 0.797479695652174], 
             UndirectedEdge[321, 375] -> 
             RGBColor[
              0.958891304347826, 0.9688617826086956, 0.9544704782608696], 
             UndirectedEdge[149, 279] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[38, 306] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[12, 358] -> 
             RGBColor[0.8755362608695652, 0.901176, 0.8721707173913045], 
             UndirectedEdge[139, 378] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[272, 374] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[21, 114] -> 
             RGBColor[
              0.9135966956521739, 0.9321354782608695, 0.9241546304347826], 
             UndirectedEdge[250, 321] -> 
             RGBColor[
              0.9630171956521738, 0.9514639130434783, 0.6759429782608696], 
             UndirectedEdge[19, 152] -> 
             RGBColor[
              0.9695560434782609, 0.9753736086956522, 0.8718457826086957], 
             UndirectedEdge[270, 336] -> 
             RGBColor[
              0.7991548695652174, 0.8431877826086956, 0.9805727826086956], 
             UndirectedEdge[87, 277] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[37, 377] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[312, 356] -> 
             RGBColor[
              0.7777357391304347, 0.8247040434782609, 0.9114311956521739], 
             UndirectedEdge[294, 343] -> 
             RGBColor[
              0.8702948695652173, 0.8994135217391304, 0.9874906956521738], 
             UndirectedEdge[170, 349] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[176, 390] -> 
             RGBColor[
              0.965077347826087, 0.8866800869565219, 0.4514652826086958], 
             UndirectedEdge[235, 327] -> 
             RGBColor[
              0.947458804347826, 0.9569956956521739, 0.8130823478260871], 
             UndirectedEdge[271, 400] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[45, 103] -> 
             RGBColor[
              0.9643523913043479, 0.8851294782608696, 0.37255823913043473`], 
             UndirectedEdge[30, 343] -> 
             RGBColor[
              0.9165473260869565, 0.9313751739130436, 0.7312960869565217], 
             UndirectedEdge[200, 234] -> 
             RGBColor[
              0.9614017608695653, 0.8858897826086958, 0.5654167826086957], 
             UndirectedEdge[282, 382] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[305, 382] -> 
             RGBColor[
              0.946240956521739, 0.9594271739130434, 0.9758842173913044], 
             UndirectedEdge[50, 164] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[259, 287] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[90, 95] -> 
             RGBColor[0.951581, 0.8331715652173914, 0.44060580434782626`], 
             UndirectedEdge[44, 243] -> 
             RGBColor[
              0.9756675434782609, 0.9608985217391305, 0.6545292391304348], 
             UndirectedEdge[82, 194] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[124, 150] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[233, 316] -> 
             RGBColor[
              0.9356947173913044, 0.7782312173913045, 0.5444354347826087], 
             UndirectedEdge[87, 390] -> 
             RGBColor[
              0.9614017608695653, 0.8858897826086958, 0.5654167826086957], 
             UndirectedEdge[72, 376] -> 
             RGBColor[
              0.893174652173913, 0.9173853913043478, 0.980247847826087], 
             UndirectedEdge[99, 169] -> 
             RGBColor[
              0.938645347826087, 0.7774709130434785, 0.35157689130434777`], 
             UndirectedEdge[127, 137] -> 
             RGBColor[
              0.9050950652173912, 0.5627235217391304, 0.4660126739130436], 
             UndirectedEdge[68, 391] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[292, 309] -> 
             RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 
             UndirectedEdge[88, 140] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[153, 216] -> 
             RGBColor[
              0.876318804347826, 0.9007699565217391, 0.8061644347826089], 
             UndirectedEdge[145, 165] -> 
             RGBColor[
              0.9536300652173912, 0.8805743043478262, 0.6000962608695652], 
             UndirectedEdge[37, 76] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[6, 391] -> 
             RGBColor[0.951581, 0.8331715652173914, 0.44060580434782626`], 
             UndirectedEdge[203, 206] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[298, 320] -> 
             RGBColor[
              0.9200953478260869, 0.7012395217391305, 0.2906130652173913], 
             UndirectedEdge[39, 164] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[107, 156] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[31, 222] -> 
             RGBColor[
              0.9695560434782609, 0.9753736086956522, 0.8718457826086957], 
             UndirectedEdge[301, 329] -> 
             RGBColor[
              0.876318804347826, 0.9007699565217391, 0.8061644347826089], 
             UndirectedEdge[126, 320] -> 
             RGBColor[
              0.9033191086956521, 0.7092027826086956, 0.5905543043478261], 
             UndirectedEdge[49, 191] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[122, 173] -> 
             RGBColor[
              0.947458804347826, 0.9569956956521739, 0.8130823478260871], 
             UndirectedEdge[60, 102] -> 
             RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 
             UndirectedEdge[120, 380] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[110, 247] -> 
             RGBColor[
              0.947458804347826, 0.9569956956521739, 0.8130823478260871], 
             UndirectedEdge[59, 149] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[92, 346] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[6, 142] -> 
             RGBColor[
              0.8965150869565218, 0.621685130434783, 0.2352949565217392], 
             UndirectedEdge[176, 232] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[60, 345] -> 
             RGBColor[
              0.958891304347826, 0.9688617826086956, 0.9544704782608696], 
             UndirectedEdge[79, 126] -> 
             RGBColor[
              0.9695560434782609, 0.9753736086956522, 0.8718457826086957], 
             UndirectedEdge[14, 212] -> 
             RGBColor[
              0.8291993043478261, 0.8649772173913044, 0.8675522826086957], 
             UndirectedEdge[22, 338] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[195, 389] -> 
             RGBColor[
              0.7806863695652173, 0.8239437391304347, 0.718572652173913], 
             UndirectedEdge[14, 293] -> 
             RGBColor[
              0.9164897391304347, 0.9333318260869565, 0.8762094130434783], 
             UndirectedEdge[201, 394] -> 
             RGBColor[
              0.8726432173913043, 0.899979652173913, 0.9201159347826087], 
             UndirectedEdge[20, 189] -> 
             RGBColor[0.905825, 0.92682, 0.9588341086956522], 
             UndirectedEdge[195, 359] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[222, 224] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[54, 389] -> 
             RGBColor[
              0.7344339130434782, 0.7919820869565217, 0.9747672608695652], 
             UndirectedEdge[123, 366] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[120, 263] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[332, 364] -> 
             RGBColor[0.720649, 0.7793523913043479, 0.9422284130434784], 
             UndirectedEdge[70, 228] -> 
             RGBColor[
              0.9152726739130435, 0.7634811304347828, 0.600528652173913], 
             UndirectedEdge[74, 141] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[212, 385] -> 
             RGBColor[
              0.8131282826086956, 0.8089132608695653, 0.6346187826086958], 
             UndirectedEdge[256, 384] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[158, 317] -> 
             RGBColor[
              0.9467338478260869, 0.9554450869565217, 0.7341753043478261], 
             UndirectedEdge[76, 208] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[101, 253] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[111, 309] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[145, 170] -> 
             RGBColor[
              0.9577559565217392, 0.8631764347826087, 0.3215687608695652], 
             UndirectedEdge[59, 279] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[83, 334] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[242, 312] -> 
             RGBColor[
              0.7814113260869565, 0.825494347826087, 0.797479695652174], 
             UndirectedEdge[140, 356] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[172, 316] -> 
             RGBColor[
              0.7777357391304347, 0.8247040434782609, 0.9114311956521739], 
             UndirectedEdge[217, 331] -> 
             RGBColor[
              0.9164897391304347, 0.9333318260869565, 0.8762094130434783], 
             UndirectedEdge[263, 336] -> 
             RGBColor[
              0.8726432173913043, 0.899979652173913, 0.9201159347826087], 
             UndirectedEdge[122, 338] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[303, 400] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[133, 367] -> 
             RGBColor[
              0.9695560434782609, 0.9753736086956522, 0.8718457826086957], 
             UndirectedEdge[136, 279] -> 
             RGBColor[
              0.8726432173913043, 0.899979652173913, 0.9201159347826087], 
             UndirectedEdge[117, 365] -> 
             RGBColor[
              0.905152652173913, 0.5607668695652175, 0.3210993478260869], 
             UndirectedEdge[33, 245] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[162, 368] -> 
             RGBColor[
              0.9661353695652174, 0.9287442608695653, 0.6174985434782609], 
             UndirectedEdge[46, 128] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[117, 269] -> 
             RGBColor[
              0.7313713260869565, 0.7839075652173914, 0.7146903913043477], 
             UndirectedEdge[98, 134] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[90, 326] -> 
             RGBColor[
              0.9479054130434783, 0.8323812608695653, 0.5545573043478261], 
             UndirectedEdge[119, 306] -> 
             RGBColor[
              0.9165473260869565, 0.9313751739130436, 0.7312960869565217], 
             UndirectedEdge[150, 211] -> 
             RGBColor[
              0.977582652173913, 0.934850043478261, 0.4688675652173915], 
             UndirectedEdge[388, 395] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[102, 108] -> 
             RGBColor[
              0.8185345652173912, 0.8584653913043478, 0.9501769782608696], 
             UndirectedEdge[15, 392] -> 
             RGBColor[
              0.9863898695652173, 0.965453695652174, 0.4269912173913043], 
             UndirectedEdge[32, 292] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[115, 332] -> 
             RGBColor[0.905825, 0.92682, 0.9588341086956522], 
             UndirectedEdge[93, 293] -> 
             RGBColor[
              0.6152844782608696, 0.693981347826087, 0.9653561304347826], 
             UndirectedEdge[98, 171] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[276, 305] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[75, 347] -> 
             RGBColor[
              0.7263454130434783, 0.6140079130434783, 0.5921688478260869], 
             UndirectedEdge[64, 193] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[18, 99] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[74, 290] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[39, 230] -> 
             RGBColor[
              0.9233611739130434, 0.941455304347826, 0.9831270652173913], 
             UndirectedEdge[259, 345] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[30, 168] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[231, 331] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[137, 242] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[172, 221] -> 
             RGBColor[
              0.7777357391304347, 0.8247040434782609, 0.9114311956521739], 
             UndirectedEdge[157, 211] -> 
             RGBColor[
              0.976857695652174, 0.9332994347826087, 0.38996052173913043`], 
             UndirectedEdge[46, 213] -> 
             RGBColor[
              0.8185345652173912, 0.8584653913043478, 0.9501769782608696], 
             UndirectedEdge[184, 318] -> 
             RGBColor[
              0.9467338478260869, 0.9554450869565217, 0.734175304347826], 
             UndirectedEdge[201, 293] -> 
             RGBColor[
              0.9135966956521739, 0.9321354782608695, 0.9241546304347826], 
             UndirectedEdge[64, 115] -> 
             RGBColor[
              0.9135966956521739, 0.9321354782608695, 0.9241546304347826], 
             UndirectedEdge[174, 266] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[80, 104] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[265, 321] -> 
             RGBColor[
              0.958891304347826, 0.9688617826086956, 0.9544704782608696], 
             UndirectedEdge[178, 296] -> 
             RGBColor[
              0.9768001086956521, 0.9352560869565217, 0.534873847826087], 
             UndirectedEdge[114, 249] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[255, 380] -> 
             RGBColor[0.9409797173913044, 0.871139695652174, 0.62151], 
             UndirectedEdge[253, 391] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[40, 63] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[23, 311] -> 
             RGBColor[
              0.9004187173913044, 0.8772678695652174, 0.6432759130434783], 
             UndirectedEdge[156, 396] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[93, 281] -> 
             RGBColor[
              0.6755948478260869, 0.6959056086956521, 0.6240205652173914], 
             UndirectedEdge[27, 325] -> 
             RGBColor[
              0.9756675434782609, 0.9608985217391305, 0.6545292391304348], 
             UndirectedEdge[12, 107] -> 
             RGBColor[
              0.8689974130434783, 0.8772663043478262, 0.6762679130434783], 
             UndirectedEdge[255, 312] -> 
             RGBColor[
              0.7520524565217391, 0.7216664782608696, 0.6131501956521739], 
             UndirectedEdge[257, 310] -> 
             RGBColor[
              0.9135966956521739, 0.9321354782608695, 0.9241546304347826], 
             UndirectedEdge[50, 197] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[215, 350] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[49, 235] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[239, 323] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[211, 216] -> 
             RGBColor[
              0.8594652391304348, 0.8451120434782609, 0.6392372173913043], 
             UndirectedEdge[98, 151] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[10, 32] -> 
             RGBColor[
              0.8263062608695653, 0.8637808695652174, 0.9154975000000001], 
             UndirectedEdge[330, 367] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[99, 384] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[127, 138] -> 
             RGBColor[
              0.7414232391304347, 0.4363806956521739, 0.5657576086956522], 
             UndirectedEdge[292, 385] -> 
             RGBColor[
              0.9661353695652174, 0.9287442608695653, 0.6174985434782609], 
             UndirectedEdge[177, 219] -> 
             RGBColor[
              0.893174652173913, 0.9173853913043478, 0.980247847826087], 
             UndirectedEdge[170, 322] -> 
             RGBColor[
              0.9797934347826087, 0.9435006521739131, 0.3760017391304348], 
             UndirectedEdge[261, 335] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[6, 253] -> 
             RGBColor[0.951581, 0.8331715652173914, 0.44060580434782626`], 
             UndirectedEdge[95, 246] -> 
             RGBColor[
              0.977582652173913, 0.934850043478261, 0.4688675652173915], 
             UndirectedEdge[50, 331] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[9, 358] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[99, 144] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[2, 28] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[138, 258] -> 
             RGBColor[
              0.8263062608695653, 0.8637808695652174, 0.9154975000000001], 
             UndirectedEdge[144, 384] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[79, 277] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[346, 354] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[144, 148] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[38, 346] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[38, 363] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[78, 104] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[95, 282] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[92, 306] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[9, 339] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[36, 148] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[62, 395] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[32, 247] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[168, 379] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[137, 230] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[268, 279] -> 
             RGBColor[
              0.5830060217391304, 0.6471606739130435, 0.8985993913043478], 
             UndirectedEdge[185, 288] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[233, 310] -> 
             RGBColor[
              0.9356947173913044, 0.7782312173913045, 0.5444354347826087], 
             UndirectedEdge[150, 386] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[138, 281] -> 
             RGBColor[
              0.8131282826086956, 0.8089132608695653, 0.6346187826086958], 
             UndirectedEdge[88, 257] -> 
             RGBColor[
              0.9164897391304347, 0.9333318260869565, 0.8762094130434783], 
             UndirectedEdge[27, 40] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[159, 250] -> 
             RGBColor[
              0.9401374130434782, 0.9334920434782609, 0.6831858260869565], 
             UndirectedEdge[169, 363] -> 
             RGBColor[
              0.9152726739130435, 0.7634811304347828, 0.600528652173913], 
             UndirectedEdge[144, 382] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[35, 207] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[71, 287] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[148, 361] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[215, 393] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[33, 124] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[31, 111] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[113, 357] -> 
             RGBColor[
              0.8334635869565218, 0.7434335652173915, 0.6109754565217391], 
             UndirectedEdge[30, 329] -> 
             RGBColor[
              0.875593847826087, 0.899219347826087, 0.7272573913043477], 
             UndirectedEdge[117, 239] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[209, 338] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[208, 323] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[71, 212] -> 
             RGBColor[
              0.8291993043478261, 0.8649772173913044, 0.8675522826086957], 
             UndirectedEdge[199, 292] -> 
             RGBColor[
              0.8185345652173912, 0.8584653913043478, 0.9501769782608696], 
             UndirectedEdge[11, 386] -> 
             RGBColor[
              0.9642948043478261, 0.8870861304347827, 0.5174715652173913], 
             UndirectedEdge[130, 267] -> 
             RGBColor[
              0.9165473260869565, 0.9313751739130436, 0.7312960869565217], 
             UndirectedEdge[67, 347] -> 
             RGBColor[
              0.7806863695652173, 0.8239437391304347, 0.718572652173913], 
             UndirectedEdge[211, 358] -> 
             RGBColor[
              0.9768001086956521, 0.9352560869565217, 0.534873847826087], 
             UndirectedEdge[2, 164] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[266, 358] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[57, 397] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[209, 386] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[74, 386] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[47, 268] -> 
             RGBColor[
              0.5866816086956522, 0.6479509782608696, 0.784647891304348], 
             UndirectedEdge[108, 397] -> 
             RGBColor[
              0.829981847826087, 0.8645711739130435, 0.8015460000000001], 
             UndirectedEdge[157, 358] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[10, 129] -> 
             RGBColor[
              0.8226604565217391, 0.8410675217391305, 0.6716494782608695], 
             UndirectedEdge[171, 308] -> 
             RGBColor[
              0.9756675434782609, 0.9608985217391305, 0.6545292391304348], 
             UndirectedEdge[225, 335] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[45, 116] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[261, 349] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[118, 209] -> 
             RGBColor[
              0.9467338478260869, 0.9554450869565217, 0.734175304347826], 
             UndirectedEdge[329, 343] -> 
             RGBColor[
              0.7991548695652174, 0.8431877826086956, 0.9805727826086956], 
             UndirectedEdge[163, 171] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[106, 217] -> 
             RGBColor[0.905825, 0.92682, 0.9588341086956522], 
             UndirectedEdge[55, 123] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[129, 353] -> 
             RGBColor[
              0.9401374130434782, 0.9334920434782609, 0.6831858260869565], 
             UndirectedEdge[38, 66] -> 
             RGBColor[
              0.965077347826087, 0.8866800869565219, 0.4514652826086958], 
             UndirectedEdge[23, 119] -> 
             RGBColor[
              0.9004187173913044, 0.8772678695652174, 0.6432759130434783], 
             UndirectedEdge[306, 354] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[28, 39] -> 
             RGBColor[
              0.9630171956521738, 0.9514639130434783, 0.6759429782608696], 
             UndirectedEdge[158, 267] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[194, 399] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[102, 333] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[16, 80] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[72, 333] -> 
             RGBColor[
              0.9695560434782609, 0.9753736086956522, 0.8718457826086957], 
             UndirectedEdge[167, 211] -> 
             RGBColor[
              0.977582652173913, 0.934850043478261, 0.4688675652173915], 
             UndirectedEdge[193, 255] -> 
             RGBColor[0.9409797173913044, 0.871139695652174, 0.62151], 
             UndirectedEdge[168, 211] -> 
             RGBColor[
              0.976857695652174, 0.9332994347826087, 0.38996052173913043`], 
             UndirectedEdge[70, 246] -> 
             RGBColor[
              0.9225167391304349, 0.7233636086956523, 0.26355671739130443`], 
             UndirectedEdge[322, 349] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[193, 312] -> 
             RGBColor[
              0.7573136956521738, 0.8099539565217391, 0.9675244130434782], 
             UndirectedEdge[194, 221] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[208, 221] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[112, 251] -> 
             RGBColor[
              0.675594847826087, 0.6959056086956521, 0.6240205652173914], 
             UndirectedEdge[297, 325] -> 
             RGBColor[0.905825, 0.92682, 0.9588341086956522], 
             UndirectedEdge[170, 225] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[27, 250] -> 
             RGBColor[
              0.9797934347826087, 0.9435006521739131, 0.3760017391304348], 
             UndirectedEdge[67, 126] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[12, 157] -> 
             RGBColor[
              0.875593847826087, 0.899219347826087, 0.7272573913043477], 
             UndirectedEdge[316, 399] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[76, 377] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[3, 51] -> 
             RGBColor[
              0.9702612608695653, 0.9113463913043478, 0.3389710434782609], 
             UndirectedEdge[23, 186] -> 
             RGBColor[
              0.977582652173913, 0.934850043478261, 0.4688675652173915], 
             UndirectedEdge[17, 319] -> 
             RGBColor[
              0.876318804347826, 0.9007699565217391, 0.8061644347826089], 
             UndirectedEdge[115, 360] -> 
             RGBColor[
              0.9165473260869565, 0.9313751739130436, 0.7312960869565217], 
             UndirectedEdge[131, 142] -> 
             RGBColor[
              0.9152726739130435, 0.7634811304347828, 0.600528652173913], 
             UndirectedEdge[23, 130] -> 
             RGBColor[
              0.9004187173913044, 0.8772678695652174, 0.6432759130434783], 
             UndirectedEdge[348, 354] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[76, 80] -> 
             RGBColor[
              0.958891304347826, 0.9688617826086956, 0.9544704782608696], 
             UndirectedEdge[38, 81] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[131, 281] -> 
             RGBColor[
              0.9534850217391304, 0.919309652173913, 0.6389122826086957], 
             UndirectedEdge[157, 167] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[165, 172] -> 
             RGBColor[
              0.7699640434782609, 0.8193885652173913, 0.9461106739130435], 
             UndirectedEdge[255, 331] -> 
             RGBColor[
              0.9642948043478261, 0.8870861304347827, 0.5174715652173913], 
             UndirectedEdge[59, 268] -> 
             RGBColor[
              0.5830060217391304, 0.6471606739130434, 0.8985993913043478], 
             UndirectedEdge[161, 364] -> 
             RGBColor[
              0.7313137391304347, 0.7858642173913044, 0.8596037173913045], 
             UndirectedEdge[149, 164] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[10, 52] -> 
             RGBColor[
              0.7830044347826086, 0.8310589130434782, 0.9788335652173913], 
             UndirectedEdge[132, 155] -> 
             RGBColor[
              0.9172722826086956, 0.9329257826086956, 0.8102031304347828], 
             UndirectedEdge[353, 400] -> 
             RGBColor[
              0.9233611739130434, 0.941455304347826, 0.9831270652173913], 
             UndirectedEdge[250, 265] -> 
             RGBColor[
              0.9756675434782609, 0.9608985217391305, 0.6545292391304348], 
             UndirectedEdge[82, 233] -> 
             RGBColor[
              0.938645347826087, 0.7774709130434785, 0.35157689130434777`], 
             UndirectedEdge[66, 81] -> 
             RGBColor[
              0.9642948043478261, 0.8870861304347827, 0.5174715652173913], 
             UndirectedEdge[69, 201] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[84, 184] -> 
             RGBColor[
              0.9306052391304347, 0.9013377826086957, 0.6461551304347826], 
             UndirectedEdge[180, 268] -> 
             RGBColor[
              0.585956652173913, 0.6464003695652174, 0.7057408478260869], 
             UndirectedEdge[17, 247] -> 
             RGBColor[
              0.876318804347826, 0.9007699565217391, 0.8061644347826089], 
             UndirectedEdge[188, 394] -> 
             RGBColor[0.8755362608695652, 0.901176, 0.8721707173913045], 
             UndirectedEdge[241, 312] -> 
             RGBColor[
              0.7806287826086956, 0.8259003913043478, 0.8634859782608696], 
             UndirectedEdge[81, 128] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[65, 198] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[356, 380] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[40, 265] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[19, 168] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[195, 241] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[33, 141] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[65, 100] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[15, 207] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[81, 135] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[259, 271] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[194, 233] -> 
             RGBColor[
              0.9393703043478261, 0.7790215217391306, 0.4304839347826089], 
             UndirectedEdge[101, 283] -> 
             RGBColor[
              0.9577559565217392, 0.8631764347826087, 0.3215687608695652], 
             UndirectedEdge[145, 192] -> 
             RGBColor[
              0.9643523913043479, 0.8851294782608696, 0.37255823913043473`], 
             UndirectedEdge[68, 397] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[142, 201] -> 
             RGBColor[
              0.9356947173913044, 0.7782312173913045, 0.5444354347826087], 
             UndirectedEdge[146, 354] -> 
             RGBColor[
              0.9768001086956521, 0.9352560869565217, 0.534873847826087], 
             UndirectedEdge[153, 329] -> 
             RGBColor[
              0.876318804347826, 0.9007699565217391, 0.8061644347826089], 
             UndirectedEdge[132, 279] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[257, 389] -> 
             RGBColor[
              0.7042473913043479, 0.7679121739130434, 0.9718880434782609], 
             UndirectedEdge[107, 386] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[157, 203] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[264, 281] -> 
             RGBColor[
              0.9661353695652174, 0.9287442608695653, 0.6174985434782609], 
             UndirectedEdge[244, 302] -> 
             RGBColor[
              0.9661353695652174, 0.9287442608695653, 0.6174985434782609], 
             UndirectedEdge[46, 105] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[126, 347] -> 
             RGBColor[
              0.7573136956521738, 0.8099539565217391, 0.9675244130434782], 
             UndirectedEdge[129, 253] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[14, 69] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[118, 124] -> 
             RGBColor[
              0.9467338478260869, 0.9554450869565217, 0.734175304347826], 
             UndirectedEdge[181, 245] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[33, 152] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[47, 371] -> 
             RGBColor[
              0.9172722826086956, 0.9329257826086956, 0.8102031304347828], 
             UndirectedEdge[131, 273] -> 
             RGBColor[
              0.958891304347826, 0.9688617826086956, 0.9544704782608696], 
             UndirectedEdge[230, 299] -> 
             RGBColor[
              0.947458804347826, 0.9569956956521739, 0.8130823478260871], 
             UndirectedEdge[107, 181] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[4, 318] -> 
             RGBColor[
              0.9467338478260869, 0.9554450869565217, 0.734175304347826], 
             UndirectedEdge[10, 333] -> 
             RGBColor[
              0.8291993043478261, 0.8649772173913044, 0.8675522826086957], 
             UndirectedEdge[152, 238] -> 
             RGBColor[
              0.9630171956521738, 0.9514639130434783, 0.6759429782608696], 
             UndirectedEdge[50, 147] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[39, 217] -> 
             RGBColor[
              0.893174652173913, 0.9173853913043478, 0.980247847826087], 
             UndirectedEdge[98, 308] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[31, 363] -> 
             RGBColor[
              0.9695560434782609, 0.9753736086956522, 0.8718457826086957], 
             UndirectedEdge[286, 386] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[137, 138] -> 
             RGBColor[
              0.8291993043478261, 0.8649772173913044, 0.8675522826086957], 
             UndirectedEdge[35, 372] -> 
             RGBColor[
              0.8291993043478261, 0.8649772173913044, 0.8675522826086957], 
             UndirectedEdge[130, 158] -> 
             RGBColor[
              0.9165473260869565, 0.9313751739130436, 0.7312960869565217], 
             UndirectedEdge[277, 373] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[234, 365] -> 
             RGBColor[
              0.8765187391304348, 0.45848960869565225`, 0.21567689130434786`],
              UndirectedEdge[310, 316] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[218, 305] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[155, 279] -> 
             RGBColor[
              0.9135966956521739, 0.9321354782608695, 0.9241546304347826], 
             UndirectedEdge[32, 129] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[92, 158] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[332, 334] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[268, 300] -> 
             RGBColor[
              0.5573227391304347, 0.5441231086956523, 0.6003183913043478], 
             UndirectedEdge[224, 227] -> 
             RGBColor[
              0.9863898695652173, 0.965453695652174, 0.4269912173913043], 
             UndirectedEdge[25, 91] -> 
             RGBColor[
              0.965077347826087, 0.8866800869565219, 0.4514652826086958], 
             UndirectedEdge[74, 304] -> 
             RGBColor[
              0.7284206956521739, 0.7846678695652174, 0.9075489347826087], 
             UndirectedEdge[86, 397] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[32, 111] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[59, 394] -> 
             RGBColor[
              0.8726432173913043, 0.899979652173913, 0.9201159347826087], 
             UndirectedEdge[170, 355] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[9, 56] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[44, 317] -> 
             RGBColor[
              0.9401374130434782, 0.9334920434782609, 0.6831858260869565], 
             UndirectedEdge[236, 262] -> 
             RGBColor[
              0.9306052391304347, 0.9013377826086957, 0.6461551304347826], 
             UndirectedEdge[119, 346] -> 
             RGBColor[
              0.9165473260869565, 0.9313751739130436, 0.7312960869565217], 
             UndirectedEdge[80, 244] -> 
             RGBColor[
              0.958891304347826, 0.9688617826086956, 0.9544704782608696], 
             UndirectedEdge[20, 360] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[196, 206] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[187, 302] -> 
             RGBColor[
              0.9306052391304347, 0.9013377826086957, 0.6461551304347826], 
             UndirectedEdge[147, 312] -> 
             RGBColor[
              0.7806863695652173, 0.8239437391304347, 0.718572652173913], 
             UndirectedEdge[259, 400] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[120, 312] -> 
             RGBColor[
              0.7806863695652173, 0.8239437391304347, 0.718572652173913], 
             UndirectedEdge[52, 60] -> 
             RGBColor[
              0.9360115217391303, 0.9508899130434783, 0.9617133260869566], 
             UndirectedEdge[266, 384] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[135, 393] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[77, 244] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[239, 385] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[278, 296] -> 
             RGBColor[
              0.976857695652174, 0.9332994347826087, 0.38996052173913043`], 
             UndirectedEdge[267, 275] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[148, 340] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[202, 212] -> 
             RGBColor[
              0.7830044347826086, 0.8310589130434782, 0.9788335652173913], 
             UndirectedEdge[81, 346] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[50, 217] -> 
             RGBColor[
              0.9172722826086956, 0.9329257826086956, 0.8102031304347828], 
             UndirectedEdge[5, 183] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[313, 339] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[4, 184] -> 
             RGBColor[
              0.9004813913043477, 0.9234834347826086, 0.9903699130434782], 
             UndirectedEdge[104, 349] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[119, 135] -> 
             RGBColor[
              0.9135966956521739, 0.9321354782608695, 0.9241546304347826], 
             UndirectedEdge[53, 273] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[224, 259] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[110, 289] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[59, 155] -> 
             RGBColor[
              0.9135966956521739, 0.9321354782608695, 0.9241546304347826], 
             UndirectedEdge[5, 29] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[119, 311] -> 
             RGBColor[
              0.840108347826087, 0.8753436086956522, 0.9846114782608696], 
             UndirectedEdge[68, 72] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[121, 234] -> 
             RGBColor[
              0.9643523913043479, 0.8851294782608696, 0.37255823913043473`], 
             UndirectedEdge[20, 336] -> 
             RGBColor[
              0.8648715217391304, 0.8946641739130434, 0.9547954130434784], 
             UndirectedEdge[17, 256] -> 
             RGBColor[
              0.876318804347826, 0.9007699565217391, 0.8061644347826089], 
             UndirectedEdge[186, 272] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[45, 304] -> 
             RGBColor[
              0.7313713260869565, 0.7839075652173914, 0.7146903913043477], 
             UndirectedEdge[165, 252] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[106, 254] -> 
             RGBColor[
              0.958891304347826, 0.9688617826086956, 0.9544704782608696], 
             UndirectedEdge[144, 169] -> 
             RGBColor[
              0.938645347826087, 0.7774709130434785, 0.35157689130434777`], 
             UndirectedEdge[191, 355] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[96, 377] -> 
             RGBColor[
              0.977582652173913, 0.934850043478261, 0.4688675652173915], 
             UndirectedEdge[110, 303] -> 
             RGBColor[
              0.947458804347826, 0.9569956956521739, 0.8130823478260871], 
             UndirectedEdge[177, 260] -> 
             RGBColor[
              0.8622063695652175, 0.7214393478260872, 0.6048922826086958], 
             UndirectedEdge[20, 88] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[57, 68] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[127, 264] -> 
             RGBColor[
              0.8944303260869565, 0.5562116956521739, 0.5486373695652175], 
             UndirectedEdge[171, 186] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[362, 385] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[109, 370] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[123, 161] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[119, 213] -> 
             RGBColor[0.7528179130434782, 0.806989, 0.975954347826087], 
             UndirectedEdge[140, 360] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[320, 347] -> 
             RGBColor[0.7143918478260869, 0.5597295652173913, 0.5821945], 
             UndirectedEdge[10, 345] -> 
             RGBColor[
              0.8058842173913043, 0.8490307826086956, 0.9715907173913043], 
             UndirectedEdge[169, 383] -> 
             RGBColor[
              0.9385877608695652, 0.7794275652173914, 0.4964902173913044], 
             UndirectedEdge[154, 372] -> 
             RGBColor[
              0.6655274782608696, 0.7386343913043478, 0.9672972173913044], 
             UndirectedEdge[167, 341] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[186, 308] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[145, 225] -> 
             RGBColor[
              0.9642948043478261, 0.8870861304347827, 0.5174715652173913], 
             UndirectedEdge[12, 65] -> 
             RGBColor[
              0.8648715217391304, 0.8946641739130434, 0.9547954130434784], 
             UndirectedEdge[274, 288] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[143, 171] -> 
             RGBColor[
              0.9702612608695653, 0.9113463913043478, 0.3389710434782609], 
             UndirectedEdge[167, 168] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[203, 341] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[114, 299] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[154, 231] -> 
             RGBColor[
              0.8292568913043479, 0.8630205652173913, 0.722638956521739], 
             UndirectedEdge[218, 384] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[360, 380] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[98, 306] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[57, 262] -> 
             RGBColor[
              0.9661353695652174, 0.9287442608695653, 0.6174985434782609], 
             UndirectedEdge[152, 160] -> 
             RGBColor[
              0.9033191086956521, 0.7092027826086956, 0.5905543043478261], 
             UndirectedEdge[311, 354] -> 
             RGBColor[
              0.9164897391304347, 0.9333318260869565, 0.8762094130434783], 
             UndirectedEdge[287, 303] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[222, 247] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[24, 206] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[92, 308] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[18, 266] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[28, 314] -> 
             RGBColor[
              0.9756675434782609, 0.9608985217391305, 0.6545292391304348], 
             UndirectedEdge[128, 139] -> 
             RGBColor[
              0.976857695652174, 0.9332994347826087, 0.38996052173913043`], 
             UndirectedEdge[160, 181] -> 
             RGBColor[
              0.9274167391304349, 0.7247431739130434, 0.42050958695652185`], 
             UndirectedEdge[42, 296] -> 
             RGBColor[
              0.9306052391304347, 0.9013377826086957, 0.6461551304347826], 
             UndirectedEdge[121, 289] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[22, 286] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[128, 213] -> 
             RGBColor[
              0.8292568913043479, 0.8630205652173913, 0.722638956521739], 
             UndirectedEdge[178, 398] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[6, 129] -> 
             RGBColor[
              0.9442596086956523, 0.8096679130434785, 0.3107092826086957], 
             UndirectedEdge[265, 375] -> 
             RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 
             UndirectedEdge[162, 270] -> 
             RGBColor[
              0.9004187173913044, 0.8772678695652174, 0.6432759130434783], 
             UndirectedEdge[199, 271] -> 
             RGBColor[
              0.8263062608695653, 0.8637808695652174, 0.9154975000000001], 
             UndirectedEdge[60, 72] -> 
             RGBColor[
              0.958891304347826, 0.9688617826086956, 0.9544704782608696], 
             UndirectedEdge[230, 258] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[38, 135] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[42, 67] -> 
             RGBColor[
              0.9467338478260869, 0.9554450869565217, 0.734175304347826], 
             UndirectedEdge[220, 352] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[4, 226] -> 
             RGBColor[
              0.9306052391304347, 0.9013377826086957, 0.6461551304347826], 
             UndirectedEdge[134, 163] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[25, 76] -> 
             RGBColor[
              0.9536300652173912, 0.8805743043478262, 0.6000962608695652], 
             UndirectedEdge[250, 375] -> 
             RGBColor[
              0.9756675434782609, 0.9608985217391305, 0.6545292391304348], 
             UndirectedEdge[50, 138] -> 
             RGBColor[
              0.829981847826087, 0.8645711739130435, 0.8015460000000001], 
             UndirectedEdge[24, 157] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[127, 328] -> 
             RGBColor[
              0.9050950652173912, 0.5627235217391304, 0.4660126739130436], 
             UndirectedEdge[107, 245] -> 
             RGBColor[
              0.9630171956521738, 0.9514639130434783, 0.6759429782608696], 
             UndirectedEdge[16, 96] -> 
             RGBColor[
              0.977582652173913, 0.934850043478261, 0.4688675652173915], 
             UndirectedEdge[42, 278] -> 
             RGBColor[
              0.9467338478260869, 0.9554450869565217, 0.734175304347826], 
             UndirectedEdge[51, 176] -> 
             RGBColor[
              0.977582652173913, 0.934850043478261, 0.4688675652173915], 
             UndirectedEdge[33, 386] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[78, 187] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[107, 150] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[312, 360] -> 
             RGBColor[
              0.7806863695652173, 0.8239437391304347, 0.718572652173913], 
             UndirectedEdge[78, 208] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[28, 197] -> 
             RGBColor[
              0.9863898695652173, 0.965453695652174, 0.4269912173913043], 
             UndirectedEdge[221, 316] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[243, 383] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[83, 332] -> 
             RGBColor[
              0.9360115217391303, 0.9508899130434783, 0.9617133260869566], 
             UndirectedEdge[98, 354] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[46, 215] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[375, 381] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[286, 304] -> 
             RGBColor[
              0.7284206956521739, 0.7846678695652174, 0.9075489347826087], 
             UndirectedEdge[225, 235] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[96, 225] -> 
             RGBColor[
              0.9768001086956521, 0.9352560869565217, 0.534873847826087], 
             UndirectedEdge[20, 389] -> 
             RGBColor[
              0.7699640434782609, 0.8193885652173913, 0.9461106739130435], 
             UndirectedEdge[259, 393] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[97, 166] -> 
             RGBColor[
              0.7284206956521739, 0.7846678695652174, 0.9075489347826087], 
             UndirectedEdge[115, 334] -> 
             RGBColor[
              0.9164897391304347, 0.9333318260869565, 0.8762094130434783], 
             UndirectedEdge[251, 260] -> 
             RGBColor[
              0.6373825000000001, 0.5400770869565219, 0.5856369347826087], 
             UndirectedEdge[119, 344] -> 
             RGBColor[0.7528179130434782, 0.806989, 0.975954347826087], 
             UndirectedEdge[329, 341] -> 
             RGBColor[
              0.875593847826087, 0.899219347826087, 0.7272573913043477], 
             UndirectedEdge[283, 334] -> 
             RGBColor[
              0.9642948043478261, 0.8870861304347827, 0.5174715652173913], 
             UndirectedEdge[1, 5] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[364, 391] -> 
             RGBColor[
              0.7320962826086956, 0.7854581739130435, 0.7935974347826089], 
             UndirectedEdge[48, 295] -> 
             RGBColor[
              0.7814113260869565, 0.825494347826087, 0.797479695652174], 
             UndirectedEdge[105, 199] -> 
             RGBColor[
              0.8291993043478261, 0.8649772173913044, 0.8675522826086957], 
             UndirectedEdge[281, 293] -> 
             RGBColor[
              0.9004187173913044, 0.8772678695652174, 0.6432759130434783], 
             UndirectedEdge[216, 358] -> 
             RGBColor[0.8755362608695652, 0.901176, 0.8721707173913045], 
             UndirectedEdge[100, 206] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[168, 341] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[199, 259] -> 
             RGBColor[
              0.8292568913043479, 0.8630205652173913, 0.722638956521739], 
             UndirectedEdge[19, 24] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[136, 299] -> 
             RGBColor[
              0.876318804347826, 0.9007699565217391, 0.8061644347826089], 
             UndirectedEdge[64, 123] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[101, 334] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[2, 328] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[235, 349] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[45, 290] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[225, 327] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[24, 386] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[363, 393] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[2, 258] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[8, 234] -> 
             RGBColor[
              0.9614017608695653, 0.8858897826086958, 0.5654167826086957], 
             UndirectedEdge[44, 151] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[253, 283] -> 
             RGBColor[
              0.965077347826087, 0.8866800869565219, 0.4514652826086958], 
             UndirectedEdge[257, 360] -> 
             RGBColor[
              0.9165473260869565, 0.9313751739130436, 0.7312960869565217], 
             UndirectedEdge[65, 358] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[282, 340] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[256, 316] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[96, 182] -> 
             RGBColor[
              0.976857695652174, 0.9332994347826087, 0.38996052173913043`], 
             UndirectedEdge[2, 106] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[210, 279] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[279, 371] -> 
             RGBColor[
              0.9135966956521739, 0.9321354782608695, 0.9241546304347826], 
             UndirectedEdge[271, 353] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[306, 311] -> 
             RGBColor[
              0.9165473260869565, 0.9313751739130436, 0.7312960869565217], 
             UndirectedEdge[64, 312] -> 
             RGBColor[
              0.7777357391304347, 0.8247040434782609, 0.9114311956521739], 
             UndirectedEdge[137, 210] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[264, 394] -> 
             RGBColor[
              0.8648715217391304, 0.8946641739130434, 0.9547954130434784], 
             UndirectedEdge[199, 224] -> 
             RGBColor[
              0.8292568913043479, 0.8630205652173913, 0.722638956521739], 
             UndirectedEdge[61, 301] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[48, 103] -> 
             RGBColor[
              0.7520524565217391, 0.7216664782608696, 0.6131501956521739], 
             UndirectedEdge[7, 14] -> 
             RGBColor[
              0.9642948043478261, 0.8870861304347827, 0.5174715652173913], 
             UndirectedEdge[88, 195] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[211, 341] -> 
             RGBColor[
              0.976857695652174, 0.9332994347826087, 0.38996052173913043`], 
             UndirectedEdge[84, 185] -> 
             RGBColor[
              0.976857695652174, 0.9332994347826087, 0.38996052173913043`], 
             UndirectedEdge[368, 387] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[134, 171] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[41, 295] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[77, 388] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[142, 273] -> 
             RGBColor[
              0.9279230217391304, 0.772915739130435, 0.5791149130434783], 
             UndirectedEdge[64, 140] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[150, 157] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[210, 264] -> 
             RGBColor[
              0.9756675434782609, 0.9608985217391305, 0.6545292391304348], 
             UndirectedEdge[202, 309] -> 
             RGBColor[
              0.9360115217391303, 0.9508899130434783, 0.9617133260869566], 
             UndirectedEdge[105, 287] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[157, 160] -> 
             RGBColor[
              0.9266917826086957, 0.7231925652173914, 0.3416025434782608], 
             UndirectedEdge[153, 379] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[207, 387] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[93, 264] -> 
             RGBColor[
              0.6810011304347825, 0.7454577391304348, 0.9395787608695653], 
             UndirectedEdge[202, 365] -> 
             RGBColor[
              0.8589001956521738, 0.5288052173913043, 0.5772939565217391], 
             UndirectedEdge[138, 230] -> 
             RGBColor[
              0.7830044347826086, 0.8310589130434782, 0.9788335652173913], 
             UndirectedEdge[5, 291] -> 
             RGBColor[
              0.9393703043478261, 0.7790215217391306, 0.4304839347826089], 
             UndirectedEdge[241, 360] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[299, 300] -> 
             RGBColor[
              0.965077347826087, 0.8866800869565219, 0.4514652826086958], 
             UndirectedEdge[9, 266] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[226, 322] -> 
             RGBColor[
              0.9702612608695653, 0.9113463913043478, 0.3389710434782609], 
             UndirectedEdge[175, 216] -> 
             RGBColor[
              0.876318804347826, 0.9007699565217391, 0.8061644347826089], 
             UndirectedEdge[115, 257] -> 
             RGBColor[
              0.840108347826087, 0.8753436086956522, 0.9846114782608696], 
             UndirectedEdge[146, 275] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[64, 101] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[79, 390] -> 
             RGBColor[
              0.9642948043478261, 0.8870861304347827, 0.5174715652173913], 
             UndirectedEdge[98, 378] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[37, 80] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[344, 354] -> 
             RGBColor[
              0.8291993043478261, 0.8649772173913044, 0.8675522826086957], 
             UndirectedEdge[119, 227] -> 
             RGBColor[
              0.9099508913043479, 0.9094221304347827, 0.6803066086956522], 
             UndirectedEdge[81, 166] -> 
             RGBColor[
              0.7313137391304347, 0.7858642173913044, 0.8596037173913045], 
             UndirectedEdge[192, 221] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[242, 331] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[225, 322] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[165, 170] -> 
             RGBColor[
              0.9756675434782609, 0.9608985217391305, 0.6545292391304348], 
             UndirectedEdge[41, 250] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[31, 393] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[140, 312] -> 
             RGBColor[
              0.7806287826086956, 0.8259003913043478, 0.8634859782608696], 
             UndirectedEdge[56, 100] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[89, 183] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[39, 210] -> 
             RGBColor[
              0.9630171956521738, 0.9514639130434783, 0.6759429782608696], 
             UndirectedEdge[34, 321] -> 
             RGBColor[
              0.9233611739130434, 0.941455304347826, 0.9831270652173913], 
             UndirectedEdge[148, 301] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[136, 155] -> 
             RGBColor[
              0.7991548695652174, 0.8431877826086956, 0.9805727826086956], 
             UndirectedEdge[51, 205] -> 
             RGBColor[
              0.9306052391304347, 0.9013377826086957, 0.6461551304347826], 
             UndirectedEdge[11, 123] -> 
             RGBColor[
              0.9614017608695653, 0.8858897826086958, 0.5654167826086958], 
             UndirectedEdge[223, 400] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[6, 201] -> 
             RGBColor[
              0.9479054130434783, 0.8323812608695653, 0.5545573043478261], 
             UndirectedEdge[201, 273] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[54, 196] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[84, 288] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[177, 248] -> 
             RGBColor[
              0.9164897391304347, 0.9333318260869565, 0.8762094130434783], 
             UndirectedEdge[76, 117] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[342, 348] -> 
             RGBColor[
              0.9661353695652174, 0.9287442608695653, 0.6174985434782609], 
             UndirectedEdge[332, 389] -> 
             RGBColor[
              0.7699640434782609, 0.8193885652173913, 0.9461106739130435], 
             UndirectedEdge[68, 236] -> 
             RGBColor[
              0.947458804347826, 0.9569956956521739, 0.8130823478260871], 
             UndirectedEdge[84, 318] -> 
             RGBColor[
              0.976857695652174, 0.9332994347826087, 0.38996052173913043`], 
             UndirectedEdge[15, 372] -> 
             RGBColor[
              0.8292568913043479, 0.8630205652173913, 0.722638956521739], 
             UndirectedEdge[88, 189] -> 
             RGBColor[
              0.9164897391304347, 0.9333318260869565, 0.8762094130434783], 
             UndirectedEdge[364, 380] -> 
             RGBColor[
              0.707998652173913, 0.7699177826086956, 0.9636421521739131], 
             UndirectedEdge[103, 295] -> 
             RGBColor[
              0.965077347826087, 0.8866800869565219, 0.4514652826086958], 
             UndirectedEdge[20, 257] -> 
             RGBColor[0.905825, 0.92682, 0.9588341086956522], 
             UndirectedEdge[12, 24] -> 
             RGBColor[
              0.8726432173913043, 0.899979652173913, 0.9201159347826087], 
             UndirectedEdge[152, 157] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[26, 70] -> 
             RGBColor[
              0.9385877608695652, 0.7794275652173914, 0.49649021739130444`], 
             UndirectedEdge[33, 74] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[124, 238] -> 
             RGBColor[
              0.9863898695652173, 0.965453695652174, 0.4269912173913043], 
             UndirectedEdge[148, 339] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[175, 229] -> 
             RGBColor[
              0.947458804347826, 0.9569956956521739, 0.8130823478260871], 
             UndirectedEdge[105, 337] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[158, 306] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[136, 268] -> 
             RGBColor[
              0.4685641956521739, 0.5582129782608696, 0.9550175434782608], 
             UndirectedEdge[133, 278] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[197, 254] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[296, 398] -> 
             RGBColor[
              0.977582652173913, 0.934850043478261, 0.4688675652173915], 
             UndirectedEdge[10, 271] -> 
             RGBColor[
              0.8263062608695653, 0.8637808695652174, 0.9154975000000001], 
             UndirectedEdge[221, 399] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[187, 388] -> 
             RGBColor[
              0.947458804347826, 0.9569956956521739, 0.8130823478260871], 
             UndirectedEdge[143, 186] -> 
             RGBColor[
              0.977582652173913, 0.934850043478261, 0.4688675652173915], 
             UndirectedEdge[372, 387] -> 
             RGBColor[
              0.829981847826087, 0.8645711739130435, 0.8015460000000001], 
             UndirectedEdge[147, 255] -> 
             RGBColor[
              0.9643523913043479, 0.8851294782608696, 0.37255823913043473`], 
             UndirectedEdge[27, 86] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[19, 157] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[192, 208] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[88, 89] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[54, 332] -> 
             RGBColor[
              0.9360115217391303, 0.9508899130434783, 0.9617133260869566], 
             UndirectedEdge[282, 301] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[264, 328] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[124, 156] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[64, 120] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[55, 236] -> 
             RGBColor[
              0.9004813913043477, 0.9234834347826086, 0.9903699130434782], 
             UndirectedEdge[11, 196] -> 
             RGBColor[
              0.9642948043478261, 0.8870861304347827, 0.5174715652173913], 
             UndirectedEdge[223, 319] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[61, 70] -> 
             RGBColor[
              0.9393703043478261, 0.7790215217391306, 0.4304839347826089], 
             UndirectedEdge[307, 343] -> 
             RGBColor[
              0.9164897391304347, 0.9333318260869565, 0.8762094130434783], 
             UndirectedEdge[13, 87] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[119, 128] -> 
             RGBColor[
              0.9165473260869565, 0.9313751739130436, 0.7312960869565217], 
             UndirectedEdge[92, 130] -> 
             RGBColor[
              0.9135966956521739, 0.9321354782608695, 0.9241546304347826], 
             UndirectedEdge[263, 359] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[22, 304] -> 
             RGBColor[
              0.7320962826086956, 0.7854581739130435, 0.7935974347826089], 
             UndirectedEdge[139, 306] -> 
             RGBColor[
              0.976857695652174, 0.9332994347826087, 0.38996052173913043`], 
             UndirectedEdge[1, 73] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[7, 13] -> 
             RGBColor[
              0.9614017608695653, 0.8858897826086958, 0.5654167826086958], 
             UndirectedEdge[170, 335] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[276, 361] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[46, 345] -> 
             RGBColor[
              0.958891304347826, 0.9688617826086956, 0.9544704782608696], 
             UndirectedEdge[36, 301] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[50, 328] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[55, 83] -> 
             RGBColor[
              0.9004813913043477, 0.9234834347826086, 0.9903699130434782], 
             UndirectedEdge[143, 306] -> 
             RGBColor[
              0.976857695652174, 0.9332994347826087, 0.38996052173913043`], 
             UndirectedEdge[32, 400] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[20, 195] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[203, 266] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[255, 359] -> 
             RGBColor[
              0.9536300652173912, 0.8805743043478262, 0.6000962608695652], 
             UndirectedEdge[128, 215] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[230, 328] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[44, 146] -> 
             RGBColor[
              0.9702612608695653, 0.9113463913043478, 0.3389710434782609], 
             UndirectedEdge[56, 206] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[55, 196] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[93, 188] -> 
             RGBColor[
              0.6916658695652174, 0.7519695652173912, 0.8569540652173914], 
             UndirectedEdge[52, 271] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[193, 253] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[120, 193] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[28, 217] -> 
             RGBColor[
              0.9099508913043479, 0.9094221304347827, 0.6803066086956522], 
             UndirectedEdge[124, 245] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[36, 282] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[276, 339] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[377, 388] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[129, 131] -> 
             RGBColor[
              0.9630171956521738, 0.9514639130434783, 0.6759429782608696], 
             UndirectedEdge[69, 142] -> 
             RGBColor[
              0.9279230217391304, 0.772915739130435, 0.5791149130434783], 
             UndirectedEdge[11, 118] -> 
             RGBColor[
              0.9180999347826087, 0.8531678260869566, 0.6287528478260869], 
             UndirectedEdge[53, 293] -> 
             RGBColor[
              0.9135966956521739, 0.9321354782608695, 0.9241546304347826], 
             UndirectedEdge[2, 137] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[102, 213] -> 
             RGBColor[
              0.8185345652173912, 0.8584653913043478, 0.9501769782608696], 
             UndirectedEdge[269, 362] -> 
             RGBColor[
              0.7284206956521739, 0.7846678695652174, 0.9075489347826087], 
             UndirectedEdge[147, 242] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[58, 220] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[177, 285] -> 
             RGBColor[
              0.893174652173913, 0.9173853913043478, 0.980247847826087], 
             UndirectedEdge[213, 215] -> 
             RGBColor[
              0.8292568913043479, 0.8630205652173913, 0.722638956521739], 
             UndirectedEdge[61, 382] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[83, 123] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[207, 368] -> 
             RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 
             UndirectedEdge[117, 377] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[207, 392] -> 
             RGBColor[
              0.9756675434782609, 0.9608985217391305, 0.6545292391304348], 
             UndirectedEdge[43, 325] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[83, 196] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[81, 130] -> 
             RGBColor[
              0.9164897391304347, 0.9333318260869565, 0.8762094130434783], 
             UndirectedEdge[204, 229] -> 
             RGBColor[
              0.9401374130434782, 0.9334920434782609, 0.6831858260869565], 
             UndirectedEdge[44, 267] -> 
             RGBColor[
              0.9863898695652173, 0.965453695652174, 0.4269912173913043], 
             UndirectedEdge[38, 130] -> 
             RGBColor[
              0.9172722826086956, 0.9329257826086956, 0.8102031304347828], 
             UndirectedEdge[226, 318] -> 
             RGBColor[
              0.976857695652174, 0.9332994347826087, 0.38996052173913043`], 
             UndirectedEdge[202, 362] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[59, 230] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[131, 394] -> 
             RGBColor[
              0.8522211739130434, 0.8852295652173913, 0.9762091521739131], 
             UndirectedEdge[93, 142] -> 
             RGBColor[
              0.6373825000000001, 0.5400770869565219, 0.5856369347826087], 
             UndirectedEdge[301, 340] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[16, 76] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[25, 239] -> 
             RGBColor[
              0.9614017608695653, 0.8858897826086958, 0.5654167826086958], 
             UndirectedEdge[46, 60] -> 
             RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 
             UndirectedEdge[57, 297] -> 
             RGBColor[0.905825, 0.92682, 0.9588341086956522], 
             UndirectedEdge[221, 351] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[365, 377] -> 
             RGBColor[
              0.9058776086956521, 0.5623174782608695, 0.400006391304348], 
             UndirectedEdge[334, 366] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[209, 290] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[174, 313] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[56, 358] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[304, 338] -> 
             RGBColor[
              0.7284206956521739, 0.7846678695652174, 0.9075489347826087], 
             UndirectedEdge[130, 306] -> 
             RGBColor[
              0.9165473260869565, 0.9313751739130436, 0.7312960869565217], 
             UndirectedEdge[11, 206] -> 
             RGBColor[
              0.9614017608695653, 0.8858897826086958, 0.5654167826086958], 
             UndirectedEdge[120, 140] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[193, 356] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[166, 246] -> 
             RGBColor[
              0.7152427173913044, 0.7298002608695653, 0.6266702173913044], 
             UndirectedEdge[76, 182] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[6, 364] -> 
             RGBColor[
              0.6892410652173914, 0.6281217826086958, 0.5984084565217391], 
             UndirectedEdge[288, 318] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[128, 151] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[30, 379] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[70, 90] -> 
             RGBColor[
              0.8965150869565218, 0.621685130434783, 0.2352949565217392], 
             UndirectedEdge[137, 394] -> 
             RGBColor[0.8755362608695652, 0.901176, 0.8721707173913045], 
             UndirectedEdge[25, 269] -> 
             RGBColor[
              0.7027374130434783, 0.6816303043478262, 0.6092679347826087], 
             UndirectedEdge[38, 227] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[128, 135] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[129, 303] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[132, 299] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[352, 396] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[155, 268] -> 
             RGBColor[
              0.5095176739130435, 0.5903688043478261, 0.9590562391304348], 
             UndirectedEdge[8, 16] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[213, 378] -> 
             RGBColor[
              0.8263062608695653, 0.8637808695652174, 0.9154975000000001], 
             UndirectedEdge[164, 230] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[218, 339] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[101, 366] -> 
             RGBColor[
              0.9797934347826087, 0.9435006521739131, 0.3760017391304348], 
             UndirectedEdge[169, 361] -> 
             RGBColor[
              0.938645347826087, 0.7774709130434785, 0.35157689130434777`], 
             UndirectedEdge[65, 341] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[46, 353] -> 
             RGBColor[
              0.9360115217391303, 0.9508899130434783, 0.9617133260869566], 
             UndirectedEdge[279, 300] -> 
             RGBColor[
              0.9614017608695653, 0.8858897826086958, 0.5654167826086957], 
             UndirectedEdge[203, 358] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[81, 243] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[176, 320] -> 
             RGBColor[
              0.9274167391304349, 0.7247431739130435, 0.42050958695652185`], 
             UndirectedEdge[112, 248] -> 
             RGBColor[
              0.9768001086956521, 0.9352560869565217, 0.534873847826087], 
             UndirectedEdge[58, 179] -> 
             RGBColor[
              0.7806287826086956, 0.8259003913043478, 0.8634859782608696], 
             UndirectedEdge[23, 213] -> 
             RGBColor[
              0.8131282826086956, 0.8089132608695653, 0.6346187826086958], 
             UndirectedEdge[243, 326] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[269, 377] -> 
             RGBColor[
              0.7320962826086956, 0.7854581739130435, 0.7935974347826089], 
             UndirectedEdge[222, 363] -> 
             RGBColor[
              0.946240956521739, 0.9594271739130434, 0.9758842173913044], 
             UndirectedEdge[30, 341] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[23, 348] -> 
             RGBColor[
              0.9661353695652174, 0.9287442608695653, 0.6174985434782609], 
             UndirectedEdge[16, 25] -> 
             RGBColor[
              0.965077347826087, 0.8866800869565219, 0.4514652826086958], 
             UndirectedEdge[25, 62] -> 
             RGBColor[
              0.965077347826087, 0.8866800869565219, 0.4514652826086958], 
             UndirectedEdge[16, 388] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[207, 372] -> 
             RGBColor[
              0.8185345652173912, 0.8584653913043478, 0.9501769782608696], 
             UndirectedEdge[249, 279] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[151, 267] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[185, 252] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[218, 382] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[284, 334] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[145, 235] -> 
             RGBColor[
              0.965077347826087, 0.8866800869565219, 0.4514652826086958], 
             UndirectedEdge[78, 302] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[235, 335] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[21, 109] -> 
             RGBColor[
              0.9164897391304347, 0.9333318260869565, 0.8762094130434783], 
             UndirectedEdge[283, 389] -> 
             RGBColor[
              0.7520524565217391, 0.7216664782608696, 0.6131501956521739], 
             UndirectedEdge[91, 395] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[240, 374] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[301, 339] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[303, 353] -> 
             RGBColor[
              0.947458804347826, 0.9569956956521739, 0.8130823478260871], 
             UndirectedEdge[92, 143] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[53, 394] -> 
             RGBColor[
              0.8726432173913043, 0.899979652173913, 0.9201159347826087], 
             UndirectedEdge[139, 345] -> 
             RGBColor[
              0.9534850217391304, 0.919309652173913, 0.6389122826086957], 
             UndirectedEdge[224, 393] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[175, 204] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[131, 293] -> 
             RGBColor[
              0.893174652173913, 0.9173853913043478, 0.980247847826087], 
             UndirectedEdge[166, 383] -> 
             RGBColor[
              0.7313137391304347, 0.7858642173913044, 0.8596037173913045], 
             UndirectedEdge[92, 348] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[212, 289] -> 
             RGBColor[
              0.8263062608695653, 0.8637808695652174, 0.9154975000000001], 
             UndirectedEdge[161, 214] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[124, 386] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[227, 350] -> 
             RGBColor[
              0.9630171956521738, 0.9514639130434783, 0.6759429782608696], 
             UndirectedEdge[258, 279] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[63, 103] -> 
             RGBColor[
              0.9577559565217392, 0.8631764347826087, 0.3215687608695652], 
             UndirectedEdge[291, 336] -> 
             RGBColor[
              0.8212528913043479, 0.6892835217391307, 0.6008535869565218], 
             UndirectedEdge[292, 400] -> 
             RGBColor[
              0.958891304347826, 0.9688617826086956, 0.9544704782608696], 
             UndirectedEdge[149, 300] -> 
             RGBColor[
              0.9642948043478261, 0.8870861304347827, 0.5174715652173913], 
             UndirectedEdge[356, 364] -> 
             RGBColor[
              0.7284206956521739, 0.7846678695652174, 0.9075489347826087], 
             UndirectedEdge[100, 167] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[334, 391] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[309, 323] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[8, 202] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[127, 380] -> 
             RGBColor[
              0.8817799782608695, 0.5467770869565217, 0.5700511086956522], 
             UndirectedEdge[130, 151] -> 
             RGBColor[
              0.9135966956521739, 0.9321354782608695, 0.9241546304347826], 
             UndirectedEdge[335, 355] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[117, 395] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[256, 310] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[362, 365] -> 
             RGBColor[
              0.9022020217391304, 0.5615271739130434, 0.5139578913043479], 
             UndirectedEdge[163, 342] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[125, 288] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[161, 253] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[12, 211] -> 
             RGBColor[
              0.8594652391304348, 0.8451120434782609, 0.6392372173913043], 
             UndirectedEdge[107, 152] -> 
             RGBColor[
              0.9630171956521738, 0.9514639130434783, 0.6759429782608696], 
             UndirectedEdge[183, 291] -> 
             RGBColor[
              0.9393703043478261, 0.7790215217391306, 0.4304839347826089], 
             UndirectedEdge[149, 299] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[57, 284] -> 
             RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 
             UndirectedEdge[230, 279] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[186, 374] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[30, 175] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[261, 327] -> 
             RGBColor[
              0.9467338478260869, 0.9554450869565217, 0.7341753043478261], 
             UndirectedEdge[271, 333] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[199, 247] -> 
             RGBColor[
              0.829981847826087, 0.8645711739130435, 0.8015460000000001], 
             UndirectedEdge[99, 223] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[200, 367] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[111, 400] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[277, 390] -> 
             RGBColor[
              0.9642948043478261, 0.8870861304347827, 0.5174715652173913], 
             UndirectedEdge[79, 298] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[96, 388] -> 
             RGBColor[
              0.977582652173913, 0.934850043478261, 0.4688675652173915], 
             UndirectedEdge[153, 175] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[127, 331] -> 
             RGBColor[
              0.9050950652173912, 0.5627235217391304, 0.4660126739130436], 
             UndirectedEdge[6, 93] -> 
             RGBColor[
              0.649593195652174, 0.5942271304347828, 0.5957588043478261], 
             UndirectedEdge[76, 239] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[333, 337] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[253, 332] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[31, 400] -> 
             RGBColor[
              0.9695560434782609, 0.9753736086956522, 0.8718457826086957], 
             UndirectedEdge[39, 149] -> 
             RGBColor[
              0.9695560434782609, 0.9753736086956522, 0.8718457826086957], 
             UndirectedEdge[49, 335] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[57, 236] -> 
             RGBColor[
              0.9360115217391303, 0.9508899130434783, 0.9617133260869566], 
             UndirectedEdge[76, 323] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[2, 210] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[25, 395] -> 
             RGBColor[
              0.9642948043478261, 0.8870861304347827, 0.5174715652173913], 
             UndirectedEdge[62, 91] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[148, 313] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[98, 163] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[271, 292] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[148, 228] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[105, 333] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[9, 65] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[129, 337] -> 
             RGBColor[
              0.9863898695652173, 0.965453695652174, 0.4269912173913043], 
             UndirectedEdge[62, 323] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[286, 290] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[96, 261] -> 
             RGBColor[
              0.976857695652174, 0.9332994347826087, 0.38996052173913043`], 
             UndirectedEdge[48, 86] -> 
             RGBColor[
              0.7814113260869565, 0.825494347826087, 0.797479695652174], 
             UndirectedEdge[137, 328] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[110, 212] -> 
             RGBColor[
              0.7830044347826086, 0.8310589130434782, 0.9788335652173913], 
             UndirectedEdge[163, 272] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[245, 396] -> 
             RGBColor[
              0.9695560434782609, 0.9753736086956522, 0.8718457826086957], 
             UndirectedEdge[25, 37] -> 
             RGBColor[
              0.9614017608695653, 0.8858897826086958, 0.5654167826086958], 
             UndirectedEdge[79, 373] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[34, 43] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[100, 358] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[273, 394] -> 
             RGBColor[
              0.8648715217391304, 0.8946641739130434, 0.9547954130434784], 
             UndirectedEdge[89, 189] -> 
             RGBColor[
              0.9135966956521739, 0.9321354782608695, 0.9241546304347826], 
             UndirectedEdge[268, 299] -> 
             RGBColor[
              0.5866816086956521, 0.6479509782608697, 0.784647891304348], 
             UndirectedEdge[143, 272] -> 
             RGBColor[
              0.977582652173913, 0.934850043478261, 0.4688675652173915], 
             UndirectedEdge[339, 382] -> 
             RGBColor[
              0.958891304347826, 0.9688617826086956, 0.9544704782608696], 
             UndirectedEdge[111, 223] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[71, 131] -> 
             RGBColor[
              0.9695560434782609, 0.9753736086956522, 0.8718457826086957], 
             UndirectedEdge[114, 370] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[4, 125] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[246, 251] -> 
             RGBColor[
              0.675594847826087, 0.6959056086956521, 0.6240205652173914], 
             UndirectedEdge[30, 229] -> 
             RGBColor[
              0.9467338478260869, 0.9554450869565217, 0.7341753043478261], 
             UndirectedEdge[115, 366] -> 
             RGBColor[
              0.9099508913043479, 0.9094221304347827, 0.6803066086956522], 
             UndirectedEdge[89, 270] -> 
             RGBColor[
              0.9135966956521739, 0.9321354782608695, 0.9241546304347826], 
             UndirectedEdge[197, 369] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[276, 301] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[69, 188] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[191, 225] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[223, 247] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[72, 86] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[19, 85] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[320, 398] -> 
             RGBColor[
              0.9274167391304349, 0.7247431739130434, 0.42050958695652185`], 
             UndirectedEdge[249, 300] -> 
             RGBColor[
              0.9642948043478261, 0.8870861304347827, 0.5174715652173913], 
             UndirectedEdge[18, 319] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[6, 273] -> 
             RGBColor[
              0.9401337173913044, 0.8270657826086958, 0.5892367826086957], 
             UndirectedEdge[158, 348] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[61, 228] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[70, 260] -> 
             RGBColor[
              0.8843043913043479, 0.5675350869565221, 0.2251730869565218], 
             UndirectedEdge[144, 305] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[165, 351] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[132, 370] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[104, 145] -> 
             RGBColor[
              0.9643523913043479, 0.8851294782608696, 0.37255823913043473`], 
             UndirectedEdge[207, 231] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[21, 249] -> 
             RGBColor[
              0.9164897391304347, 0.9333318260869565, 0.8762094130434783], 
             UndirectedEdge[7, 93] -> 
             RGBColor[
              0.6630895434782609, 0.647735652173913, 0.6066182826086957], 
             UndirectedEdge[140, 255] -> 
             RGBColor[
              0.9642948043478261, 0.8870861304347827, 0.5174715652173913], 
             UndirectedEdge[100, 157] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[42, 178] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[115, 195] -> 
             RGBColor[
              0.9165473260869565, 0.9313751739130436, 0.7312960869565217], 
             UndirectedEdge[281, 394] -> 
             RGBColor[
              0.8594652391304348, 0.8451120434782609, 0.6392372173913043], 
             UndirectedEdge[215, 224] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[99, 222] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[55, 284] -> 
             RGBColor[
              0.9360115217391303, 0.9508899130434783, 0.9617133260869566], 
             UndirectedEdge[32, 337] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[172, 399] -> 
             RGBColor[
              0.7806287826086956, 0.8259003913043478, 0.8634859782608696], 
             UndirectedEdge[267, 346] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[222, 393] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[116, 179] -> 
             RGBColor[
              0.7777357391304347, 0.8247040434782609, 0.9114311956521739], 
             UndirectedEdge[120, 360] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[144, 222] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[237, 307] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[18, 144] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[309, 365] -> 
             RGBColor[
              0.8944303260869565, 0.5562116956521739, 0.5486373695652174], 
             UndirectedEdge[189, 241] -> 
             RGBColor[
              0.9164897391304347, 0.9333318260869565, 0.8762094130434783], 
             UndirectedEdge[268, 370] -> 
             RGBColor[
              0.585956652173913, 0.6464003695652174, 0.7057408478260869], 
             UndirectedEdge[336, 359] -> 
             RGBColor[
              0.8648715217391304, 0.8946641739130434, 0.9547954130434784], 
             UndirectedEdge[115, 123] -> 
             RGBColor[
              0.9135966956521739, 0.9321354782608695, 0.9241546304347826], 
             UndirectedEdge[6, 394] -> 
             RGBColor[
              0.8334635869565218, 0.7434335652173915, 0.6109754565217391], 
             UndirectedEdge[259, 353] -> 
             RGBColor[
              0.9467338478260869, 0.9554450869565217, 0.7341753043478261], 
             UndirectedEdge[98, 348] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[145, 349] -> 
             RGBColor[
              0.9642948043478261, 0.8870861304347827, 0.5174715652173913], 
             UndirectedEdge[287, 292] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[53, 69] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[236, 284] -> 
             RGBColor[
              0.9360115217391303, 0.9508899130434783, 0.9617133260869566], 
             UndirectedEdge[119, 146] -> 
             RGBColor[
              0.9004187173913044, 0.8772678695652174, 0.6432759130434783], 
             UndirectedEdge[198, 310] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[198, 384] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[111, 292] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[40, 295] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[5, 270] -> 
             RGBColor[
              0.9172722826086956, 0.9329257826086956, 0.8102031304347828], 
             UndirectedEdge[104, 355] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[356, 360] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[42, 398] -> 
             RGBColor[
              0.947458804347826, 0.9569956956521739, 0.8130823478260871], 
             UndirectedEdge[153, 211] -> 
             RGBColor[
              0.977582652173913, 0.934850043478261, 0.4688675652173915], 
             UndirectedEdge[223, 385] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[144, 361] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[216, 229] -> 
             RGBColor[0.8293413913043477, 0.8672576956521738, 0.983452], 
             UndirectedEdge[161, 389] -> 
             RGBColor[
              0.7806287826086956, 0.8259003913043478, 0.8634859782608696], 
             UndirectedEdge[313, 340] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[241, 380] -> 
             RGBColor[
              0.9695560434782609, 0.9753736086956522, 0.8718457826086957], 
             UndirectedEdge[258, 281] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[344, 346] -> 
             RGBColor[
              0.8292568913043479, 0.8630205652173913, 0.722638956521739], 
             UndirectedEdge[79, 205] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[227, 306] -> 
             RGBColor[
              0.9863898695652173, 0.965453695652174, 0.4269912173913043], 
             UndirectedEdge[43, 381] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[98, 143] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[243, 267] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[58, 152] -> 
             RGBColor[
              0.9695560434782609, 0.9753736086956522, 0.8718457826086957], 
             UndirectedEdge[376, 397] -> 
             RGBColor[
              0.9172722826086956, 0.9329257826086956, 0.8102031304347828], 
             UndirectedEdge[114, 279] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[148, 218] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[55, 366] -> 
             RGBColor[
              0.9401374130434782, 0.9334920434782609, 0.6831858260869565], 
             UndirectedEdge[99, 361] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[97, 169] -> 
             RGBColor[
              0.9356947173913044, 0.7782312173913045, 0.5444354347826088], 
             UndirectedEdge[43, 250] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[112, 177] -> 
             RGBColor[
              0.9004187173913044, 0.8772678695652174, 0.6432759130434783], 
             UndirectedEdge[255, 356] -> 
             RGBColor[
              0.9614017608695653, 0.8858897826086958, 0.5654167826086958], 
             UndirectedEdge[210, 328] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[91, 221] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[32, 345] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[210, 258] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[189, 359] -> 
             RGBColor[0.905825, 0.92682, 0.9588341086956522], 
             UndirectedEdge[164, 258] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[354, 374] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[235, 322] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[147, 392] -> 
             RGBColor[
              0.9863898695652173, 0.965453695652174, 0.4269912173913043], 
             UndirectedEdge[123, 283] -> 
             RGBColor[
              0.9614017608695653, 0.8858897826086958, 0.5654167826086957], 
             UndirectedEdge[202, 239] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[180, 249] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[2, 197] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[174, 329] -> 
             RGBColor[
              0.876318804347826, 0.9007699565217391, 0.8061644347826089], 
             UndirectedEdge[193, 242] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[58, 160] -> 
             RGBColor[
              0.926634195652174, 0.7251492173913043, 0.4865158695652174], 
             UndirectedEdge[50, 137] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[326, 383] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[157, 238] -> 
             RGBColor[
              0.9863898695652173, 0.965453695652174, 0.4269912173913043], 
             UndirectedEdge[243, 346] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[235, 355] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[44, 135] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[33, 206] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[88, 263] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[82, 399] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[271, 287] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[31, 223] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[108, 376] -> 
             RGBColor[0.7528179130434782, 0.806989, 0.975954347826087], 
             UndirectedEdge[301, 361] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[80, 388] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[47, 136] -> 
             RGBColor[
              0.876318804347826, 0.9007699565217391, 0.8061644347826089], 
             UndirectedEdge[39, 50] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[120, 389] -> 
             RGBColor[
              0.7806863695652173, 0.8239437391304347, 0.718572652173913], 
             UndirectedEdge[28, 106] -> 
             RGBColor[
              0.9756675434782609, 0.9608985217391305, 0.6545292391304348], 
             UndirectedEdge[97, 326] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[195, 242] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[90, 260] -> 
             RGBColor[
              0.8965150869565218, 0.621685130434783, 0.2352949565217392], 
             UndirectedEdge[73, 368] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[52, 287] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[135, 243] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[311, 317] -> 
             RGBColor[
              0.8702948695652173, 0.8994135217391304, 0.9874906956521738], 
             UndirectedEdge[6, 10] -> 
             RGBColor[
              0.7871266304347826, 0.7072347826086958, 0.6063570217391305], 
             UndirectedEdge[363, 383] -> 
             RGBColor[
              0.9695560434782609, 0.9753736086956522, 0.8718457826086957], 
             UndirectedEdge[227, 346] -> 
             RGBColor[
              0.9863898695652173, 0.965453695652174, 0.4269912173913043], 
             UndirectedEdge[157, 341] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[18, 310] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[37, 96] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[218, 222] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[65, 203] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[105, 303] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[119, 267] -> 
             RGBColor[
              0.9165473260869565, 0.9313751739130436, 0.7312960869565217], 
             UndirectedEdge[20, 312] -> 
             RGBColor[
              0.7699640434782609, 0.8193885652173913, 0.9461106739130435], 
             UndirectedEdge[285, 324] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[16, 302] -> 
             RGBColor[
              0.977582652173913, 0.934850043478261, 0.4688675652173915], 
             UndirectedEdge[65, 313] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[280, 392] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[1, 357] -> 
             RGBColor[
              0.876318804347826, 0.9007699565217391, 0.8061644347826089], 
             UndirectedEdge[26, 177] -> 
             RGBColor[
              0.9164897391304347, 0.9333318260869565, 0.8762094130434783], 
             UndirectedEdge[69, 293] -> 
             RGBColor[0.905825, 0.92682, 0.9588341086956522], 
             UndirectedEdge[165, 399] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[108, 297] -> 
             RGBColor[0.7528179130434782, 0.806989, 0.975954347826087], 
             UndirectedEdge[192, 335] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[134, 272] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[86, 236] -> 
             RGBColor[
              0.947458804347826, 0.9569956956521739, 0.8130823478260871], 
             UndirectedEdge[312, 389] -> 
             RGBColor[
              0.5683864347826086, 0.6604807391304347, 0.9591646086956521], 
             UndirectedEdge[156, 245] -> 
             RGBColor[
              0.9695560434782609, 0.9753736086956522, 0.8718457826086957], 
             UndirectedEdge[153, 168] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[118, 150] -> 
             RGBColor[
              0.947458804347826, 0.9569956956521739, 0.8130823478260871], 
             UndirectedEdge[195, 255] -> 
             RGBColor[
              0.9643523913043479, 0.8851294782608696, 0.37255823913043473`], 
             UndirectedEdge[109, 180] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[143, 378] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[135, 383] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[20, 120] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[149, 230] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[16, 77] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[168, 238] -> 
             RGBColor[
              0.9863898695652173, 0.965453695652174, 0.4269912173913043], 
             UndirectedEdge[104, 335] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[79, 232] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[47, 299] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[236, 397] -> 
             RGBColor[
              0.947458804347826, 0.9569956956521739, 0.8130823478260871], 
             UndirectedEdge[33, 118] -> 
             RGBColor[
              0.947458804347826, 0.9569956956521739, 0.8130823478260871], 
             UndirectedEdge[51, 79] -> 
             RGBColor[
              0.9768001086956521, 0.9352560869565217, 0.534873847826087], 
             UndirectedEdge[24, 168] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[269, 365] -> 
             RGBColor[
              0.6435376739130435, 0.3572676956521739, 0.5578090434782609], 
             UndirectedEdge[98, 240] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[29, 113] -> 
             RGBColor[
              0.9508560434782609, 0.8316209565217394, 0.3616987608695652], 
             UndirectedEdge[330, 398] -> 
             RGBColor[
              0.947458804347826, 0.9569956956521739, 0.8130823478260871], 
             UndirectedEdge[43, 265] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[209, 304] -> 
             RGBColor[
              0.7313713260869565, 0.7839075652173914, 0.7146903913043477], 
             UndirectedEdge[107, 238] -> 
             RGBColor[
              0.9797934347826087, 0.9435006521739131, 0.3760017391304348], 
             UndirectedEdge[298, 347] -> 
             RGBColor[
              0.7740899347826087, 0.8019906956521738, 0.6675831739130434], 
             UndirectedEdge[153, 343] -> 
             RGBColor[
              0.9172722826086956, 0.9329257826086956, 0.8102031304347828], 
             UndirectedEdge[110, 292] -> 
             RGBColor[
              0.9360115217391303, 0.9508899130434783, 0.9617133260869566], 
             UndirectedEdge[332, 366] -> 
             RGBColor[
              0.9756675434782609, 0.9608985217391305, 0.6545292391304348], 
             UndirectedEdge[39, 136] -> 
             RGBColor[
              0.8522211739130434, 0.8852295652173913, 0.9762091521739131], 
             UndirectedEdge[115, 380] -> 
             RGBColor[
              0.893174652173913, 0.9173853913043478, 0.980247847826087], 
             UndirectedEdge[167, 238] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[1, 162] -> 
             RGBColor[
              0.977582652173913, 0.934850043478261, 0.4688675652173915], 
             UndirectedEdge[128, 243] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[196, 366] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[136, 149] -> 
             RGBColor[0.8755362608695652, 0.901176, 0.8721707173913045], 
             UndirectedEdge[263, 360] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[267, 354] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[192, 355] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[24, 100] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[11, 286] -> 
             RGBColor[
              0.9614017608695653, 0.8858897826086958, 0.5654167826086958], 
             UndirectedEdge[71, 110] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[186, 306] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[6, 131] -> 
             RGBColor[
              0.9274833695652174, 0.8176311739130436, 0.6106505217391305], 
             UndirectedEdge[53, 264] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[83, 118] -> 
             RGBColor[
              0.9004813913043477, 0.9234834347826086, 0.9903699130434782], 
             UndirectedEdge[98, 272] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[200, 330] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[101, 389] -> 
             RGBColor[
              0.7740899347826087, 0.8019906956521738, 0.6675831739130434], 
             UndirectedEdge[10, 353] -> 
             RGBColor[
              0.7830044347826086, 0.8310589130434782, 0.9788335652173913], 
             UndirectedEdge[174, 340] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[77, 187] -> 
             RGBColor[
              0.9467338478260869, 0.9554450869565217, 0.7341753043478261], 
             UndirectedEdge[137, 264] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[20, 356] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[130, 227] -> 
             RGBColor[
              0.9099508913043479, 0.9094221304347827, 0.6803066086956522], 
             UndirectedEdge[24, 150] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[282, 339] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[69, 93] -> 
             RGBColor[
              0.6810011304347826, 0.7454577391304348, 0.9395787608695653], 
             UndirectedEdge[65, 266] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[189, 336] -> 
             RGBColor[
              0.7991548695652174, 0.8431877826086956, 0.9805727826086956], 
             UndirectedEdge[191, 322] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[297, 376] -> 
             RGBColor[
              0.840108347826087, 0.8753436086956522, 0.9846114782608696], 
             UndirectedEdge[33, 286] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[145, 351] -> 
             RGBColor[
              0.9642948043478261, 0.8870861304347827, 0.5174715652173913], 
             UndirectedEdge[83, 141] -> 
             RGBColor[
              0.9467338478260869, 0.9554450869565217, 0.734175304347826], 
             UndirectedEdge[148, 276] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[124, 160] -> 
             RGBColor[
              0.9266917826086957, 0.7231925652173914, 0.3416025434782608], 
             UndirectedEdge[25, 362] -> 
             RGBColor[
              0.9614017608695653, 0.8858897826086958, 0.5654167826086958], 
             UndirectedEdge[96, 208] -> 
             RGBColor[
              0.9768001086956521, 0.9352560869565217, 0.534873847826087], 
             UndirectedEdge[240, 272] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[25, 182] -> 
             RGBColor[
              0.9643523913043479, 0.8851294782608696, 0.37255823913043473`], 
             UndirectedEdge[101, 380] -> 
             RGBColor[
              0.9630171956521738, 0.9514639130434783, 0.6759429782608696], 
             UndirectedEdge[24, 358] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[202, 234] -> 
             RGBColor[
              0.9180999347826087, 0.8531678260869566, 0.628752847826087], 
             UndirectedEdge[17, 62] -> 
             RGBColor[
              0.876318804347826, 0.9007699565217391, 0.8061644347826089], 
             UndirectedEdge[24, 211] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[2, 39] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[164, 328] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[228, 301] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[118, 286] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[139, 215] -> 
             RGBColor[
              0.976857695652174, 0.9332994347826087, 0.38996052173913043`], 
             UndirectedEdge[239, 377] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[348, 374] -> 
             RGBColor[
              0.9756675434782609, 0.9608985217391305, 0.6545292391304348], 
             UndirectedEdge[8, 388] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[249, 370] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[61, 285] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[162, 280] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[126, 205] -> 
             RGBColor[
              0.9233611739130434, 0.941455304347826, 0.9831270652173913], 
             UndirectedEdge[161, 334] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[192, 399] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[69, 281] -> 
             RGBColor[
              0.9661353695652174, 0.9287442608695653, 0.6174985434782609], 
             UndirectedEdge[38, 128] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.947458804347826, 0.9569956956521739, 0.8130823478260871], 
             UndirectedEdge[145, 355] -> 
             RGBColor[
              0.9642948043478261, 0.8870861304347827, 0.5174715652173913], 
             UndirectedEdge[23, 139] -> 
             RGBColor[
              0.9607290869565218, 0.8791921304347826, 0.30194034782608703`], 
             UndirectedEdge[120, 359] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[117, 309] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[19, 167] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[26, 285] -> 
             RGBColor[
              0.9695560434782609, 0.9753736086956522, 0.8718457826086957], 
             UndirectedEdge[166, 169] -> 
             RGBColor[
              0.6770303695652174, 0.573971739130435, 0.5882865869565218], 
             UndirectedEdge[31, 383] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[146, 346] -> 
             RGBColor[
              0.976857695652174, 0.9332994347826087, 0.38996052173913043`], 
             UndirectedEdge[191, 349] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[212, 362] -> 
             RGBColor[
              0.8263062608695653, 0.8637808695652174, 0.9154975000000001], 
             UndirectedEdge[242, 380] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[175, 307] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[140, 193] -> 
             RGBColor[
              0.9695560434782609, 0.9753736086956522, 0.8718457826086957], 
             UndirectedEdge[8, 25] -> 
             RGBColor[
              0.9614017608695653, 0.8858897826086958, 0.5654167826086957], 
             UndirectedEdge[8, 269] -> 
             RGBColor[
              0.7284206956521739, 0.7846678695652174, 0.9075489347826087], 
             UndirectedEdge[155, 371] -> 
             RGBColor[
              0.840108347826087, 0.8753436086956522, 0.9846114782608696], 
             UndirectedEdge[55, 161] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[110, 202] -> 
             RGBColor[
              0.9004813913043477, 0.9234834347826086, 0.9903699130434782], 
             UndirectedEdge[332, 380] -> 
             RGBColor[
              0.958891304347826, 0.9688617826086956, 0.9544704782608696], 
             UndirectedEdge[359, 360] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[128, 350] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[272, 378] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[52, 345] -> 
             RGBColor[
              0.9233611739130434, 0.941455304347826, 0.9831270652173913], 
             UndirectedEdge[32, 333] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[85, 168] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[23, 354] -> 
             RGBColor[
              0.9768001086956521, 0.9352560869565217, 0.534873847826087], 
             UndirectedEdge[51, 373] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[55, 334] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[66, 267] -> 
             RGBColor[
              0.9643523913043479, 0.8851294782608696, 0.37255823913043473`], 
             UndirectedEdge[30, 153] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[179, 290] -> 
             RGBColor[
              0.7806863695652173, 0.8239437391304347, 0.718572652173913], 
             UndirectedEdge[178, 200] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[340, 358] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[31, 259] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[92, 146] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[3, 373] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[174, 341] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[248, 260] -> 
             RGBColor[
              0.9385877608695652, 0.7794275652173914, 0.49649021739130444`], 
             UndirectedEdge[41, 325] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[66, 346] -> 
             RGBColor[
              0.9643523913043479, 0.8851294782608696, 0.37255823913043473`], 
             UndirectedEdge[53, 142] -> 
             RGBColor[
              0.9356947173913044, 0.7782312173913045, 0.5444354347826088], 
             UndirectedEdge[38, 44] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[76, 187] -> 
             RGBColor[
              0.9360115217391303, 0.9508899130434783, 0.9617133260869566], 
             UndirectedEdge[156, 160] -> 
             RGBColor[
              0.926634195652174, 0.7251492173913043, 0.4865158695652174], 
             UndirectedEdge[141, 290] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[3, 79] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[301, 382] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[193, 389] -> 
             RGBColor[
              0.7573136956521738, 0.8099539565217391, 0.9675244130434782], 
             UndirectedEdge[189, 291] -> 
             RGBColor[
              0.8622063695652175, 0.7214393478260872, 0.6048922826086958], 
             UndirectedEdge[161, 196] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[83, 161] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[100, 211] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[32, 287] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[156, 181] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[126, 176] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[46, 350] -> 
             RGBColor[
              0.958891304347826, 0.9688617826086956, 0.9544704782608696], 
             UndirectedEdge[47, 149] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[57, 108] -> 
             RGBColor[
              0.8185345652173912, 0.8584653913043478, 0.9501769782608696], 
             UndirectedEdge[105, 400] -> 
             RGBColor[
              0.9695560434782609, 0.9753736086956522, 0.8718457826086957], 
             UndirectedEdge[62, 256] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[193, 332] -> 
             RGBColor[
              0.958891304347826, 0.9688617826086956, 0.9544704782608696], 
             UndirectedEdge[1, 387] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[72, 284] -> 
             RGBColor[
              0.958891304347826, 0.9688617826086956, 0.9544704782608696], 
             UndirectedEdge[127, 394] -> 
             RGBColor[
              0.7877601956521739, 0.47257947826086955`, 0.5703760434782609], 
             UndirectedEdge[110, 385] -> 
             RGBColor[
              0.9306052391304347, 0.9013377826086957, 0.6461551304347826], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[97, 393] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[19, 150] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[272, 342] -> 
             RGBColor[
              0.977582652173913, 0.934850043478261, 0.4688675652173915], 
             UndirectedEdge[96, 187] -> 
             RGBColor[
              0.9306052391304347, 0.9013377826086957, 0.6461551304347826], 
             UndirectedEdge[129, 333] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[19, 160] -> 
             RGBColor[
              0.926634195652174, 0.7251492173913043, 0.4865158695652174], 
             UndirectedEdge[183, 357] -> 
             RGBColor[
              0.876318804347826, 0.9007699565217391, 0.8061644347826089], 
             UndirectedEdge[197, 217] -> 
             RGBColor[
              0.9165473260869565, 0.9313751739130436, 0.7312960869565217], 
             UndirectedEdge[199, 345] -> 
             RGBColor[
              0.8058842173913043, 0.8490307826086956, 0.9715907173913043], 
             UndirectedEdge[44, 346] -> 
             RGBColor[
              0.9863898695652173, 0.965453695652174, 0.4269912173913043], 
             UndirectedEdge[78, 80] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[42, 320] -> 
             RGBColor[
              0.8804393260869565, 0.6912309130434783, 0.597797152173913], 
             UndirectedEdge[161, 332] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[239, 309] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[8, 377] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[75, 126] -> 
             RGBColor[
              0.9152726739130435, 0.7634811304347828, 0.600528652173913], 
             UndirectedEdge[54, 310] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[65, 211] -> 
             RGBColor[
              0.9661353695652174, 0.9287442608695653, 0.6174985434782609], 
             UndirectedEdge[88, 356] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[98, 158] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[13, 390] -> 
             RGBColor[
              0.9614017608695653, 0.8858897826086958, 0.5654167826086957], 
             UndirectedEdge[241, 242] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[12, 238] -> 
             RGBColor[
              0.8689974130434783, 0.8772663043478262, 0.6762679130434783], 
             UndirectedEdge[175, 343] -> 
             RGBColor[
              0.9172722826086956, 0.9329257826086956, 0.8102031304347828], 
             UndirectedEdge[59, 258] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[152, 156] -> 
             RGBColor[
              0.9695560434782609, 0.9753736086956522, 0.8718457826086957], 
             UndirectedEdge[39, 258] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[183, 368] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[44, 119] -> 
             RGBColor[
              0.9099508913043479, 0.9094221304347827, 0.6803066086956522], 
             UndirectedEdge[149, 264] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[120, 241] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[116, 304] -> 
             RGBColor[
              0.7284206956521739, 0.7846678695652174, 0.9075489347826087], 
             UndirectedEdge[82, 256] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[98, 186] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[72, 262] -> 
             RGBColor[
              0.9534850217391304, 0.919309652173913, 0.6389122826086957], 
             UndirectedEdge[147, 241] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[13, 205] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[142, 394] -> 
             RGBColor[
              0.8212528913043479, 0.6892835217391307, 0.6008535869565218], 
             UndirectedEdge[42, 75] -> 
             RGBColor[0.8923928913043477, 0.7455092608695654, 0.6077715], 
             UndirectedEdge[56, 341] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[306, 378] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[27, 295] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[111, 247] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[128, 259] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[52, 68] -> 
             RGBColor[
              0.947458804347826, 0.9569956956521739, 0.8130823478260871], 
             UndirectedEdge[241, 359] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[361, 382] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[14, 390] -> 
             RGBColor[
              0.9642948043478261, 0.8870861304347827, 0.5174715652173913], 
             UndirectedEdge[11, 332] -> 
             RGBColor[
              0.9536300652173912, 0.8805743043478262, 0.6000962608695652], 
             UndirectedEdge[22, 209] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[33, 156] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[283, 332] -> 
             RGBColor[
              0.9536300652173912, 0.8805743043478262, 0.6000962608695652], 
             UndirectedEdge[150, 181] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[117, 323] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[199, 223] -> 
             RGBColor[
              0.8263062608695653, 0.8637808695652174, 0.9154975000000001], 
             UndirectedEdge[128, 306] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[184, 288] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[145, 182] -> 
             RGBColor[
              0.9643523913043479, 0.8851294782608696, 0.37255823913043473`], 
             UndirectedEdge[284, 397] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[61, 148] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[34, 159] -> 
             RGBColor[
              0.9004813913043477, 0.9234834347826086, 0.9903699130434782], 
             UndirectedEdge[276, 382] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[59, 164] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[80, 377] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[180, 370] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[98, 374] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[139, 350] -> 
             RGBColor[
              0.9534850217391304, 0.919309652173913, 0.6389122826086957], 
             UndirectedEdge[36, 276] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[53, 281] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[73, 183] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[101, 115] -> 
             RGBColor[
              0.9099508913043479, 0.9094221304347827, 0.6803066086956522], 
             UndirectedEdge[283, 366] -> 
             RGBColor[
              0.9577559565217392, 0.8631764347826087, 0.3215687608695652], 
             UndirectedEdge[22, 141] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[197, 314] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[13, 14] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[323, 395] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[93, 131] -> 
             RGBColor[0.6683507826086956, 0.7360231304347826, 0.9609925], 
             UndirectedEdge[52, 105] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[178, 330] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[92, 98] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[37, 323] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[279, 370] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[150, 160] -> 
             RGBColor[
              0.9274167391304349, 0.7247431739130435, 0.42050958695652185`], 
             UndirectedEdge[188, 273] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[179, 386] -> 
             RGBColor[
              0.7806287826086956, 0.8259003913043478, 0.8634859782608696], 
             UndirectedEdge[141, 179] -> 
             RGBColor[
              0.7806863695652173, 0.8239437391304347, 0.718572652173913], 
             UndirectedEdge[117, 388] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[198, 214] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[150, 238] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[331, 392] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[323, 365] -> 
             RGBColor[
              0.9022020217391304, 0.5615271739130434, 0.5139578913043479], 
             UndirectedEdge[6, 71] -> 
             RGBColor[
              0.9507984565217391, 0.8335776086956523, 0.5066120869565218], 
             UndirectedEdge[132, 249] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[348, 378] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[174, 198] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[72, 236] -> 
             RGBColor[
              0.9233611739130434, 0.941455304347826, 0.9831270652173913], 
             UndirectedEdge[9, 100] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[51, 298] -> 
             RGBColor[
              0.9702612608695653, 0.9113463913043478, 0.3389710434782609], 
             UndirectedEdge[23, 128] -> 
             RGBColor[
              0.976857695652174, 0.9332994347826087, 0.38996052173913043`], 
             UndirectedEdge[215, 353] -> 
             RGBColor[
              0.9467338478260869, 0.9554450869565217, 0.7341753043478261], 
             UndirectedEdge[80, 96] -> 
             RGBColor[
              0.9534850217391304, 0.919309652173913, 0.6389122826086957], 
             UndirectedEdge[78, 388] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[312, 380] -> 
             RGBColor[
              0.7573136956521738, 0.8099539565217391, 0.9675244130434782], 
             UndirectedEdge[57, 325] -> 
             RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 
             UndirectedEdge[308, 374] -> 
             RGBColor[
              0.9756675434782609, 0.9608985217391305, 0.6545292391304348], 
             UndirectedEdge[76, 365] -> 
             RGBColor[
              0.8944303260869565, 0.5562116956521739, 0.5486373695652174], 
             UndirectedEdge[182, 187] -> 
             RGBColor[
              0.9467338478260869, 0.9554450869565217, 0.7341753043478261], 
             UndirectedEdge[74, 286] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[137, 164] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[149, 258] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[147, 331] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[42, 367] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[16, 365] -> 
             RGBColor[
              0.9058776086956521, 0.5623174782608695, 0.40000639130434795`], 
             UndirectedEdge[113, 183] -> 
             RGBColor[0.951581, 0.8331715652173914, 0.44060580434782626`], 
             UndirectedEdge[16, 323] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[340, 343] -> 
             RGBColor[
              0.9164897391304347, 0.9333318260869565, 0.8762094130434783], 
             UndirectedEdge[323, 362] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[334, 364] -> 
             RGBColor[
              0.7313137391304347, 0.7858642173913044, 0.8596037173913045], 
             UndirectedEdge[94, 324] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[135, 350] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[31, 215] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[3, 21] -> 
             RGBColor[
              0.9099508913043479, 0.9094221304347827, 0.6803066086956522], 
             UndirectedEdge[127, 193] -> 
             RGBColor[
              0.8817799782608695, 0.5467770869565217, 0.5700511086956522], 
             UndirectedEdge[50, 230] -> 
             RGBColor[
              0.947458804347826, 0.9569956956521739, 0.8130823478260871], 
             UndirectedEdge[169, 382] -> 
             RGBColor[
              0.9152726739130435, 0.7634811304347828, 0.600528652173913], 
             UndirectedEdge[12, 19] -> 
             RGBColor[0.8755362608695652, 0.901176, 0.8721707173913045], 
             UndirectedEdge[133, 296] -> 
             RGBColor[
              0.9534850217391304, 0.919309652173913, 0.6389122826086957], 
             UndirectedEdge[214, 332] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[76, 395] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[299, 370] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[170, 235] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[46, 400] -> 
             RGBColor[
              0.958891304347826, 0.9688617826086956, 0.9544704782608696], 
             UndirectedEdge[65, 329] -> 
             RGBColor[
              0.8648715217391304, 0.8946641739130434, 0.9547954130434784], 
             UndirectedEdge[81, 267] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[104, 182] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[23, 306] -> 
             RGBColor[
              0.976857695652174, 0.9332994347826087, 0.38996052173913043`], 
             UndirectedEdge[209, 286] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[150, 167] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[4, 288] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[171, 272] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[78, 182] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[143, 374] -> 
             RGBColor[
              0.9702612608695653, 0.9113463913043478, 0.3389710434782609], 
             UndirectedEdge[55, 262] -> 
             RGBColor[
              0.9306052391304347, 0.9013377826086957, 0.6461551304347826], 
             UndirectedEdge[165, 190] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[2, 149] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[39, 47] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[230, 300] -> 
             RGBColor[
              0.9180999347826087, 0.8531678260869566, 0.628752847826087], 
             UndirectedEdge[40, 48] -> 
             RGBColor[
              0.7814113260869565, 0.825494347826087, 0.797479695652174], 
             UndirectedEdge[25, 208] -> 
             RGBColor[
              0.9642948043478261, 0.8870861304347827, 0.5174715652173913], 
             UndirectedEdge[32, 52] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[161, 366] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[190, 318] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[179, 245] -> 
             RGBColor[
              0.7573136956521738, 0.8099539565217391, 0.9675244130434782], 
             UndirectedEdge[37, 182] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[12, 206] -> 
             RGBColor[
              0.8726432173913043, 0.899979652173913, 0.9201159347826087], 
             UndirectedEdge[18, 218] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[92, 119] -> 
             RGBColor[
              0.9135966956521739, 0.9321354782608695, 0.9241546304347826], 
             UndirectedEdge[215, 400] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[71, 292] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[158, 346] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[92, 151] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[104, 170] -> 
             RGBColor[
              0.9863898695652173, 0.965453695652174, 0.4269912173913043], 
             UndirectedEdge[82, 316] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[287, 353] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[368, 372] -> 
             RGBColor[
              0.8185345652173912, 0.8584653913043478, 0.9501769782608696], 
             UndirectedEdge[9, 203] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[17, 384] -> 
             RGBColor[0.8755362608695652, 0.901176, 0.8721707173913045], 
             UndirectedEdge[82, 310] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[129, 287] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[81, 363] -> 
             RGBColor[
              0.9695560434782609, 0.9753736086956522, 0.8718457826086957], 
             UndirectedEdge[64, 356] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[245, 352] -> 
             RGBColor[
              0.9695560434782609, 0.9753736086956522, 0.8718457826086957], 
             UndirectedEdge[87, 232] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[88, 255] -> 
             RGBColor[
              0.9642948043478261, 0.8870861304347827, 0.5174715652173913], 
             UndirectedEdge[154, 392] -> 
             RGBColor[
              0.8226604565217391, 0.8410675217391305, 0.6716494782608695], 
             UndirectedEdge[22, 45] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[116, 141] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[97, 224] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[66, 151] -> 
             RGBColor[
              0.9614017608695653, 0.8858897826086958, 0.5654167826086958], 
             UndirectedEdge[165, 221] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[101, 332] -> 
             RGBColor[
              0.9756675434782609, 0.9608985217391305, 0.6545292391304348], 
             UndirectedEdge[58, 396] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[35, 387] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[198, 266] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[188, 264] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[119, 151] -> 
             RGBColor[
              0.9135966956521739, 0.9321354782608695, 0.9241546304347826], 
             UndirectedEdge[247, 400] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[305, 361] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[138, 210] -> 
             RGBColor[
              0.8226604565217391, 0.8410675217391305, 0.6716494782608695], 
             UndirectedEdge[197, 231] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[225, 261] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[83, 286] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[19, 238] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[62, 117] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[65, 167] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[268, 371] -> 
             RGBColor[
              0.5095176739130436, 0.5903688043478261, 0.9590562391304348], 
             UndirectedEdge[172, 192] -> 
             RGBColor[
              0.7806863695652173, 0.8239437391304347, 0.718572652173913], 
             UndirectedEdge[52, 353] -> 
             RGBColor[
              0.9004813913043477, 0.9234834347826086, 0.9903699130434782], 
             UndirectedEdge[126, 298] -> 
             RGBColor[
              0.9630171956521738, 0.9514639130434783, 0.6759429782608696], 
             UndirectedEdge[146, 306] -> 
             RGBColor[
              0.976857695652174, 0.9332994347826087, 0.38996052173913043`], 
             UndirectedEdge[21, 132] -> 
             RGBColor[
              0.9172722826086956, 0.9329257826086956, 0.8102031304347828], 
             UndirectedEdge[89, 162] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[9, 18] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[255, 360] -> 
             RGBColor[
              0.9643523913043479, 0.8851294782608696, 0.37255823913043473`], 
             UndirectedEdge[124, 152] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[88, 389] -> 
             RGBColor[
              0.7806287826086956, 0.8259003913043478, 0.8634859782608696], 
             UndirectedEdge[12, 167] -> 
             RGBColor[
              0.876318804347826, 0.9007699565217391, 0.8061644347826089], 
             UndirectedEdge[32, 303] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[49, 261] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[283, 360] -> 
             RGBColor[
              0.9643523913043479, 0.8851294782608696, 0.37255823913043473`], 
             UndirectedEdge[282, 305] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[32, 385] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[167, 216] -> 
             RGBColor[
              0.876318804347826, 0.9007699565217391, 0.8061644347826089], 
             UndirectedEdge[252, 318] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[2, 217] -> 
             RGBColor[
              0.9172722826086956, 0.9329257826086956, 0.8102031304347828], 
             UndirectedEdge[305, 329] -> 
             RGBColor[
              0.8522211739130434, 0.8852295652173913, 0.9762091521739131], 
             UndirectedEdge[87, 373] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[20, 241] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[59, 210] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[290, 304] -> 
             RGBColor[
              0.7313713260869565, 0.7839075652173914, 0.7146903913043477], 
             UndirectedEdge[115, 312] -> 
             RGBColor[
              0.7042473913043479, 0.7679121739130434, 0.9718880434782609], 
             UndirectedEdge[214, 389] -> 
             RGBColor[
              0.7777357391304347, 0.8247040434782609, 0.9114311956521739], 
             UndirectedEdge[144, 276] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[196, 286] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[124, 181] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[216, 341] -> 
             RGBColor[
              0.875593847826087, 0.899219347826087, 0.7272573913043477], 
             UndirectedEdge[294, 340] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[104, 235] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[125, 318] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[109, 232] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[182, 388] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[97, 382] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[140, 147] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[59, 300] -> 
             RGBColor[
              0.9614017608695653, 0.8858897826086958, 0.5654167826086957], 
             UndirectedEdge[205, 373] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[215, 259] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[136, 300] -> 
             RGBColor[
              0.8469599347826087, 0.7969420869565218, 0.6218349347826088], 
             UndirectedEdge[152, 245] -> 
             RGBColor[
              0.946240956521739, 0.9594271739130434, 0.9758842173913044], 
             UndirectedEdge[44, 128] -> 
             RGBColor[
              0.9863898695652173, 0.965453695652174, 0.4269912173913043], 
             UndirectedEdge[241, 392] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[240, 342] -> 
             RGBColor[
              0.9768001086956521, 0.9352560869565217, 0.534873847826087], 
             UndirectedEdge[123, 214] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[125, 274] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[298, 373] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[119, 350] -> 
             RGBColor[
              0.893174652173913, 0.9173853913043478, 0.980247847826087], 
             UndirectedEdge[22, 179] -> 
             RGBColor[
              0.7814113260869565, 0.825494347826087, 0.797479695652174], 
             UndirectedEdge[1, 183] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[112, 260] -> 
             RGBColor[
              0.9225167391304349, 0.7233636086956523, 0.26355671739130443`], 
             UndirectedEdge[183, 270] -> 
             RGBColor[
              0.9172722826086956, 0.9329257826086956, 0.8102031304347828], 
             UndirectedEdge[152, 181] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[169, 276] -> 
             RGBColor[
              0.9356947173913044, 0.7782312173913045, 0.5444354347826087], 
             UndirectedEdge[349, 355] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[171, 240] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[114, 132] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[17, 222] -> 
             RGBColor[
              0.8522211739130434, 0.8852295652173913, 0.9762091521739131], 
             UndirectedEdge[46, 259] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[13, 79] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[146, 311] -> 
             RGBColor[
              0.9004187173913044, 0.8772678695652174, 0.6432759130434783], 
             UndirectedEdge[44, 275] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[193, 195] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[86, 297] -> 
             RGBColor[
              0.9172722826086956, 0.9329257826086956, 0.8102031304347828], 
             UndirectedEdge[197, 392] -> 
             RGBColor[
              0.9863898695652173, 0.965453695652174, 0.4269912173913043], 
             UndirectedEdge[217, 392] -> 
             RGBColor[
              0.9099508913043479, 0.9094221304347827, 0.6803066086956522], 
             UndirectedEdge[101, 193] -> 
             RGBColor[
              0.9630171956521738, 0.9514639130434783, 0.6759429782608696], 
             UndirectedEdge[216, 340] -> 
             RGBColor[0.8755362608695652, 0.901176, 0.8721707173913045], 
             UndirectedEdge[125, 190] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[99, 276] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[27, 63] -> 
             RGBColor[
              0.9797934347826087, 0.9435006521739131, 0.3760017391304348], 
             UndirectedEdge[184, 226] -> 
             RGBColor[
              0.9306052391304347, 0.9013377826086957, 0.6461551304347826], 
             UndirectedEdge[107, 211] -> 
             RGBColor[
              0.9702612608695653, 0.9113463913043478, 0.3389710434782609], 
             UndirectedEdge[216, 294] -> 
             RGBColor[0.8293413913043477, 0.8672576956521738, 0.983452], 
             UndirectedEdge[68, 284] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[89, 359] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[23, 267] -> 
             RGBColor[
              0.976857695652174, 0.9332994347826087, 0.38996052173913043`], 
             UndirectedEdge[140, 242] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[64, 214] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[296, 367] -> 
             RGBColor[
              0.9768001086956521, 0.9352560869565217, 0.534873847826087], 
             UndirectedEdge[275, 346] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[301, 305] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[81, 119] -> 
             RGBColor[
              0.9164897391304347, 0.9333318260869565, 0.8762094130434783], 
             UndirectedEdge[327, 355] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[317, 344] -> 
             RGBColor[
              0.7830044347826086, 0.8310589130434782, 0.9788335652173913], 
             UndirectedEdge[184, 190] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[10, 303] -> 
             RGBColor[
              0.829981847826087, 0.8645711739130435, 0.8015460000000001], 
             UndirectedEdge[149, 268] -> 
             RGBColor[
              0.5858990652173913, 0.6483570217391305, 0.8506541739130435], 
             UndirectedEdge[38, 267] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[253, 366] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[165, 355] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[339, 340] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[185, 318] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[36, 70] -> 
             RGBColor[
              0.9356947173913044, 0.7782312173913045, 0.5444354347826088], 
             UndirectedEdge[69, 131] -> 
             RGBColor[
              0.958891304347826, 0.9688617826086956, 0.9544704782608696], 
             UndirectedEdge[283, 312] -> 
             RGBColor[
              0.7520524565217391, 0.7216664782608696, 0.6131501956521739], 
             UndirectedEdge[75, 330] -> 
             RGBColor[0.8923928913043477, 0.7455092608695654, 0.6077715], 
             UndirectedEdge[169, 222] -> 
             RGBColor[
              0.9152726739130435, 0.7634811304347828, 0.600528652173913], 
             UndirectedEdge[90, 246] -> 
             RGBColor[
              0.9347274347826088, 0.7775136521739132, 0.2736785869565218], 
             UndirectedEdge[62, 362] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[158, 374] -> 
             RGBColor[
              0.9863898695652173, 0.965453695652174, 0.4269912173913043], 
             UndirectedEdge[82, 172] -> 
             RGBColor[
              0.7806863695652173, 0.8239437391304347, 0.718572652173913], 
             UndirectedEdge[306, 346] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[53, 188] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[84, 190] -> 
             RGBColor[
              0.9768001086956521, 0.9352560869565217, 0.534873847826087], 
             UndirectedEdge[78, 96] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[46, 199] -> 
             RGBColor[
              0.8185345652173912, 0.8584653913043478, 0.9501769782608696], 
             UndirectedEdge[159, 265] -> 
             RGBColor[
              0.9360115217391303, 0.9508899130434783, 0.9617133260869566], 
             UndirectedEdge[332, 356] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[199, 222] -> 
             RGBColor[
              0.8058842173913043, 0.8490307826086956, 0.9715907173913043], 
             UndirectedEdge[114, 300] -> 
             RGBColor[
              0.9614017608695653, 0.8858897826086958, 0.5654167826086957], 
             UndirectedEdge[139, 213] -> 
             RGBColor[
              0.8131282826086956, 0.8089132608695653, 0.6346187826086958], 
             UndirectedEdge[106, 369] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[109, 114] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[58, 245] -> 
             RGBColor[
              0.9695560434782609, 0.9753736086956522, 0.8718457826086957], 
             UndirectedEdge[151, 317] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[99, 218] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[55, 57] -> 
             RGBColor[
              0.9360115217391303, 0.9508899130434783, 0.9617133260869566], 
             UndirectedEdge[247, 287] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[44, 66] -> 
             RGBColor[
              0.9577559565217392, 0.8631764347826087, 0.3215687608695652], 
             UndirectedEdge[116, 290] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[278, 367] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[102, 297] -> 
             RGBColor[0.905825, 0.92682, 0.9588341086956522], 
             UndirectedEdge[104, 187] -> 
             RGBColor[
              0.9467338478260869, 0.9554450869565217, 0.7341753043478261], 
             UndirectedEdge[136, 371] -> 
             RGBColor[
              0.7991548695652174, 0.8431877826086956, 0.9805727826086956], 
             UndirectedEdge[80, 302] -> 
             RGBColor[
              0.9534850217391304, 0.919309652173913, 0.6389122826086957], 
             UndirectedEdge[176, 373] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[112, 219] -> 
             RGBColor[
              0.9534850217391304, 0.919309652173913, 0.6389122826086957], 
             UndirectedEdge[33, 179] -> 
             RGBColor[
              0.7814113260869565, 0.825494347826087, 0.797479695652174], 
             UndirectedEdge[123, 334] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[94, 307] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[73, 89] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[267, 311] -> 
             RGBColor[
              0.9165473260869565, 0.9313751739130436, 0.7312960869565217], 
             UndirectedEdge[52, 391] -> 
             RGBColor[
              0.947458804347826, 0.9569956956521739, 0.8130823478260871], 
             UndirectedEdge[105, 271] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[187, 377] -> 
             RGBColor[
              0.947458804347826, 0.9569956956521739, 0.8130823478260871], 
             UndirectedEdge[58, 124] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[11, 54] -> 
             RGBColor[
              0.9180999347826087, 0.8531678260869566, 0.6287528478260869], 
             UndirectedEdge[115, 283] -> 
             RGBColor[
              0.8879134130434783, 0.8290979130434784, 0.6258736304347826], 
             UndirectedEdge[292, 362] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[15, 154] -> 
             RGBColor[
              0.8292568913043479, 0.8630205652173913, 0.722638956521739], 
             UndirectedEdge[158, 311] -> 
             RGBColor[
              0.9165473260869565, 0.9313751739130436, 0.7312960869565217], 
             UndirectedEdge[123, 253] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[236, 376] -> 
             RGBColor[
              0.8702948695652173, 0.8994135217391304, 0.9874906956521738], 
             UndirectedEdge[206, 386] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[74, 338] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[293, 394] -> 
             RGBColor[
              0.7991548695652174, 0.8431877826086956, 0.9805727826086956], 
             UndirectedEdge[41, 381] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[59, 328] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[123, 196] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[23, 38] -> 
             RGBColor[
              0.977582652173913, 0.934850043478261, 0.4688675652173915], 
             UndirectedEdge[61, 282] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.7740899347826087, 0.8019906956521738, 0.6675831739130434], 
             UndirectedEdge[3, 232] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[110, 362] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[125, 252] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[49, 327] -> 
             RGBColor[
              0.9467338478260869, 0.9554450869565217, 0.7341753043478261], 
             UndirectedEdge[89, 291] -> 
             RGBColor[
              0.9356947173913044, 0.7782312173913045, 0.5444354347826088], 
             UndirectedEdge[34, 250] -> 
             RGBColor[
              0.9401374130434782, 0.9334920434782609, 0.6831858260869565], 
             UndirectedEdge[125, 226] -> 
             RGBColor[
              0.9768001086956521, 0.9352560869565217, 0.534873847826087], 
             UndirectedEdge[3, 14] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[105, 345] -> 
             RGBColor[
              0.9695560434782609, 0.9753736086956522, 0.8718457826086957], 
             UndirectedEdge[88, 336] -> 
             RGBColor[0.8755362608695652, 0.901176, 0.8721707173913045], 
             UndirectedEdge[162, 357] -> 
             RGBColor[
              0.8594652391304348, 0.8451120434782609, 0.6392372173913043], 
             UndirectedEdge[279, 328] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[312, 359] -> 
             RGBColor[
              0.7699640434782609, 0.8193885652173913, 0.9461106739130435], 
             UndirectedEdge[202, 289] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[27, 48] -> 
             RGBColor[
              0.7740899347826087, 0.8019906956521738, 0.6675831739130434], 
             UndirectedEdge[115, 193] -> 
             RGBColor[
              0.893174652173913, 0.9173853913043478, 0.980247847826087], 
             UndirectedEdge[117, 385] -> 
             RGBColor[
              0.976857695652174, 0.9332994347826087, 0.38996052173913043`], 
             UndirectedEdge[179, 352] -> 
             RGBColor[
              0.7806287826086956, 0.8259003913043478, 0.8634859782608696], 
             UndirectedEdge[8, 365] -> 
             RGBColor[
              0.9022020217391304, 0.5615271739130434, 0.5139578913043479], 
             UndirectedEdge[105, 353] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[231, 392] -> 
             RGBColor[
              0.9863898695652173, 0.965453695652174, 0.4269912173913043], 
             UndirectedEdge[109, 132] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[23, 158] -> 
             RGBColor[
              0.976857695652174, 0.9332994347826087, 0.38996052173913043`], 
             UndirectedEdge[105, 350] -> 
             RGBColor[
              0.9695560434782609, 0.9753736086956522, 0.8718457826086957], 
             UndirectedEdge[172, 351] -> 
             RGBColor[
              0.7806287826086956, 0.8259003913043478, 0.8634859782608696], 
             UndirectedEdge[34, 375] -> 
             RGBColor[
              0.9360115217391303, 0.9508899130434783, 0.9617133260869566], 
             UndirectedEdge[32, 391] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[140, 241] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[89, 336] -> 
             RGBColor[
              0.8726432173913043, 0.899979652173913, 0.9201159347826087], 
             UndirectedEdge[74, 118] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[138, 328] -> 
             RGBColor[
              0.8291993043478261, 0.8649772173913044, 0.8675522826086957], 
             UndirectedEdge[189, 207] -> 
             RGBColor[0.905825, 0.92682, 0.9588341086956522], 
             UndirectedEdge[273, 281] -> 
             RGBColor[
              0.9661353695652174, 0.9287442608695653, 0.6174985434782609], 
             UndirectedEdge[49, 225] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[43, 159] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[113, 368] -> 
             RGBColor[
              0.9401337173913044, 0.8270657826086958, 0.5892367826086957], 
             UndirectedEdge[11, 83] -> 
             RGBColor[
              0.9180999347826087, 0.8531678260869566, 0.6287528478260869], 
             UndirectedEdge[151, 344] -> 
             RGBColor[
              0.8263062608695653, 0.8637808695652174, 0.9154975000000001], 
             UndirectedEdge[182, 377] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[198, 203] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[208, 395] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[305, 339] -> 
             RGBColor[
              0.958891304347826, 0.9688617826086956, 0.9544704782608696], 
             UndirectedEdge[9, 313] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[267, 317] -> 
             RGBColor[
              0.9467338478260869, 0.9554450869565217, 0.7341753043478261], 
             UndirectedEdge[306, 350] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[111, 362] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[104, 261] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[243, 363] -> 
             RGBColor[
              0.958891304347826, 0.9688617826086956, 0.9544704782608696], 
             UndirectedEdge[154, 369] -> 
             RGBColor[
              0.8291993043478261, 0.8649772173913044, 0.8675522826086957], 
             UndirectedEdge[218, 282] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[7, 293] -> 
             RGBColor[
              0.8879134130434783, 0.8290979130434784, 0.6258736304347827], 
             UndirectedEdge[24, 167] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[326, 363] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[276, 282] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[337, 345] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[107, 124] -> 
             RGBColor[
              0.9863898695652173, 0.965453695652174, 0.4269912173913043], 
             UndirectedEdge[128, 227] -> 
             RGBColor[
              0.9863898695652173, 0.965453695652174, 0.4269912173913043], 
             UndirectedEdge[25, 365] -> 
             RGBColor[
              0.8765187391304348, 0.45848960869565225`, 0.21567689130434786`],
              UndirectedEdge[97, 363] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[13, 373] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[64, 195] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[77, 96] -> 
             RGBColor[
              0.976857695652174, 0.9332994347826087, 0.38996052173913043`], 
             UndirectedEdge[6, 53] -> 
             RGBColor[
              0.9479054130434783, 0.8323812608695653, 0.5545573043478261], 
             UndirectedEdge[216, 343] -> 
             RGBColor[
              0.7991548695652174, 0.8431877826086956, 0.9805727826086956], 
             UndirectedEdge[26, 324] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[142, 281] -> 
             RGBColor[
              0.9225167391304349, 0.7233636086956523, 0.26355671739130443`], 
             UndirectedEdge[100, 341] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[115, 364] -> 
             RGBColor[0.654932347826087, 0.727876, 0.9680057826086956], 
             UndirectedEdge[150, 152] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[10, 68] -> 
             RGBColor[
              0.829981847826087, 0.8645711739130435, 0.8015460000000001], 
             UndirectedEdge[190, 288] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[23, 146] -> 
             RGBColor[
              0.9607290869565218, 0.8791921304347826, 0.30194034782608703`], 
             UndirectedEdge[188, 201] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[148, 382] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[14, 71] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[228, 276] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[56, 174] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[16, 182] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[104, 192] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[145, 395] -> 
             RGBColor[
              0.9642948043478261, 0.8870861304347827, 0.5174715652173913], 
             UndirectedEdge[219, 251] -> 
             RGBColor[0.6683507826086956, 0.7360231304347826, 0.9609925], 
             UndirectedEdge[150, 179] -> 
             RGBColor[
              0.7814113260869565, 0.825494347826087, 0.797479695652174], 
             UndirectedEdge[73, 207] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[265, 325] -> 
             RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 
             UndirectedEdge[39, 314] -> 
             RGBColor[
              0.958891304347826, 0.9688617826086956, 0.9544704782608696], 
             UndirectedEdge[20, 263] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[66, 146] -> 
             RGBColor[
              0.9482237826086957, 0.8310221739130436, 0.28453806521739133`], 
             UndirectedEdge[7, 21] -> 
             RGBColor[
              0.8879134130434783, 0.8290979130434784, 0.6258736304347827], 
             UndirectedEdge[107, 167] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[120, 195] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[365, 388] -> 
             RGBColor[
              0.9058776086956521, 0.5623174782608695, 0.400006391304348], 
             UndirectedEdge[134, 342] -> 
             RGBColor[
              0.9768001086956521, 0.9352560869565217, 0.534873847826087], 
             UndirectedEdge[227, 311] -> 
             RGBColor[
              0.9099508913043479, 0.9094221304347827, 0.6803066086956522], 
             UndirectedEdge[78, 377] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[21, 370] -> 
             RGBColor[
              0.9165473260869565, 0.9313751739130436, 0.7312960869565217], 
             UndirectedEdge[2, 230] -> 
             RGBColor[
              0.947458804347826, 0.9569956956521739, 0.8130823478260871], 
             UndirectedEdge[24, 203] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[54, 206] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[66, 130] -> 
             RGBColor[
              0.8879134130434783, 0.8290979130434784, 0.6258736304347827], 
             UndirectedEdge[101, 356] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[222, 383] -> 
             RGBColor[
              0.9695560434782609, 0.9753736086956522, 0.8718457826086957], 
             UndirectedEdge[31, 247] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[46, 333] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[287, 385] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[42, 330] -> 
             RGBColor[
              0.9004813913043477, 0.9234834347826086, 0.9903699130434782], 
             UndirectedEdge[151, 227] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[36, 382] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[218, 361] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[196, 334] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[34, 265] -> 
             RGBColor[
              0.9360115217391303, 0.9508899130434783, 0.9617133260869566], 
             UndirectedEdge[372, 392] -> 
             RGBColor[
              0.8226604565217391, 0.8410675217391305, 0.6716494782608695], 
             UndirectedEdge[127, 210] -> 
             RGBColor[
              0.8985562173913044, 0.5388138260869566, 0.2701098695652174], 
             UndirectedEdge[33, 157] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[139, 308] -> 
             RGBColor[
              0.9661353695652174, 0.9287442608695653, 0.6174985434782609], 
             UndirectedEdge[38, 146] -> 
             RGBColor[
              0.977582652173913, 0.934850043478261, 0.4688675652173915], 
             UndirectedEdge[55, 68] -> 
             RGBColor[
              0.947458804347826, 0.9569956956521739, 0.8130823478260871], 
             UndirectedEdge[35, 392] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[51, 126] -> 
             RGBColor[
              0.9534850217391304, 0.919309652173913, 0.6389122826086957], 
             UndirectedEdge[130, 243] -> 
             RGBColor[0.905825, 0.92682, 0.9588341086956522], 
             UndirectedEdge[12, 203] -> 
             RGBColor[0.8755362608695652, 0.901176, 0.8721707173913045], 
             UndirectedEdge[182, 395] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[99, 382] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[17, 31] -> 
             RGBColor[0.8755362608695652, 0.901176, 0.8721707173913045], 
             UndirectedEdge[77, 78] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[243, 344] -> 
             RGBColor[
              0.8185345652173912, 0.8584653913043478, 0.9501769782608696], 
             UndirectedEdge[305, 313] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[189, 280] -> 
             RGBColor[
              0.9135966956521739, 0.9321354782608695, 0.9241546304347826], 
             UndirectedEdge[104, 208] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[191, 335] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[225, 355] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[308, 348] -> 
             RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 
             UndirectedEdge[132, 149] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[128, 224] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[192, 225] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[84, 252] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[30, 211] -> 
             RGBColor[
              0.976857695652174, 0.9332994347826087, 0.38996052173913043`], 
             UndirectedEdge[138, 242] -> 
             RGBColor[
              0.829981847826087, 0.8645711739130435, 0.8015460000000001], 
             UndirectedEdge[27, 41] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[102, 139] -> 
             RGBColor[
              0.9661353695652174, 0.9287442608695653, 0.6174985434782609], 
             UndirectedEdge[203, 329] -> 
             RGBColor[0.8755362608695652, 0.901176, 0.8721707173913045], 
             UndirectedEdge[195, 312] -> 
             RGBColor[
              0.7806863695652173, 0.8239437391304347, 0.718572652173913], 
             UndirectedEdge[51, 87] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[83, 366] -> 
             RGBColor[
              0.9401374130434782, 0.9334920434782609, 0.6831858260869565], 
             UndirectedEdge[8, 302] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[146, 344] -> 
             RGBColor[
              0.8131282826086956, 0.8089132608695653, 0.6346187826086958], 
             UndirectedEdge[67, 320] -> 
             RGBColor[
              0.9266917826086957, 0.7231925652173914, 0.3416025434782608], 
             UndirectedEdge[90, 166] -> 
             RGBColor[
              0.6892410652173914, 0.6281217826086958, 0.5984084565217391], 
             UndirectedEdge[12, 341] -> 
             RGBColor[
              0.875593847826087, 0.899219347826087, 0.7272573913043477], 
             UndirectedEdge[3, 13] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[153, 341] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[192, 351] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[12, 150] -> 
             RGBColor[
              0.876318804347826, 0.9007699565217391, 0.8061644347826089], 
             UndirectedEdge[99, 393] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[4, 190] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[373, 390] -> 
             RGBColor[
              0.9614017608695653, 0.8858897826086958, 0.5654167826086957], 
             UndirectedEdge[23, 308] -> 
             RGBColor[
              0.9661353695652174, 0.9287442608695653, 0.6174985434782609], 
             UndirectedEdge[37, 187] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[17, 292] -> 
             RGBColor[
              0.8648715217391304, 0.8946641739130434, 0.9547954130434784], 
             UndirectedEdge[309, 385] -> 
             RGBColor[
              0.9661353695652174, 0.9287442608695653, 0.6174985434782609], 
             UndirectedEdge[140, 380] -> 
             RGBColor[
              0.9695560434782609, 0.9753736086956522, 0.8718457826086957], 
             UndirectedEdge[119, 354] -> 
             RGBColor[
              0.9164897391304347, 0.9333318260869565, 0.8762094130434783], 
             UndirectedEdge[36, 305] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[91, 351] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[130, 275] -> 
             RGBColor[
              0.9135966956521739, 0.9321354782608695, 0.9241546304347826], 
             UndirectedEdge[46, 102] -> 
             RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 
             UndirectedEdge[111, 271] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[104, 351] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[174, 203] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[294, 313] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[206, 266] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[167, 358] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[315, 322] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[176, 347] -> 
             RGBColor[
              0.7814113260869565, 0.825494347826087, 0.797479695652174], 
             UndirectedEdge[92, 186] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[149, 210] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[171, 374] -> 
             RGBColor[
              0.9797934347826087, 0.9435006521739131, 0.3760017391304348], 
             UndirectedEdge[228, 282] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[164, 210] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[196, 214] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[204, 307] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[127, 255] -> 
             RGBColor[
              0.8765187391304348, 0.45848960869565225`, 0.21567689130434786`],
              UndirectedEdge[68, 334] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[16, 269] -> 
             RGBColor[
              0.7320962826086956, 0.7854581739130435, 0.7935974347826089], 
             UndirectedEdge[68, 337] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[23, 374] -> 
             RGBColor[
              0.9702612608695653, 0.9113463913043478, 0.3389710434782609], 
             UndirectedEdge[22, 116] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[192, 322] -> 
             RGBColor[
              0.9863898695652173, 0.965453695652174, 0.4269912173913043], 
             UndirectedEdge[70, 95] -> 
             RGBColor[
              0.9393703043478261, 0.7790215217391306, 0.4304839347826088], 
             UndirectedEdge[71, 273] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[135, 215] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[161, 283] -> 
             RGBColor[
              0.9642948043478261, 0.8870861304347827, 0.5174715652173913], 
             UndirectedEdge[18, 384] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[71, 303] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[32, 353] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[188, 281] -> 
             RGBColor[
              0.9768001086956521, 0.9352560869565217, 0.534873847826087], 
             UndirectedEdge[54, 198] -> 
             RGBColor[
              0.947458804347826, 0.9569956956521739, 0.8130823478260871], 
             UndirectedEdge[271, 385] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[150, 206] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[317, 346] -> 
             RGBColor[
              0.9467338478260869, 0.9554450869565217, 0.734175304347826], 
             UndirectedEdge[146, 243] -> 
             RGBColor[
              0.9661353695652174, 0.9287442608695653, 0.6174985434782609], 
             UndirectedEdge[91, 316] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[196, 386] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[151, 306] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[27, 376] -> 
             RGBColor[
              0.9099508913043479, 0.9094221304347827, 0.6803066086956522], 
             UndirectedEdge[280, 387] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[308, 354] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[327, 349] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[60, 108] -> 
             RGBColor[
              0.8185345652173912, 0.8584653913043478, 0.9501769782608696], 
             UndirectedEdge[353, 391] -> 
             RGBColor[
              0.947458804347826, 0.9569956956521739, 0.8130823478260871], 
             UndirectedEdge[140, 195] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[17, 18] -> 
             RGBColor[
              0.876318804347826, 0.9007699565217391, 0.8061644347826089], 
             UndirectedEdge[87, 205] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[221, 256] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[194, 316] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[16, 37] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[252, 288] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[60, 353] -> 
             RGBColor[
              0.9360115217391303, 0.9508899130434783, 0.9617133260869566], 
             UndirectedEdge[206, 286] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[220, 396] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[133, 320] -> 
             RGBColor[
              0.9033191086956521, 0.7092027826086956, 0.5905543043478261], 
             UndirectedEdge[28, 231] -> 
             RGBColor[
              0.9863898695652173, 0.965453695652174, 0.4269912173913043], 
             UndirectedEdge[239, 269] -> 
             RGBColor[
              0.7284206956521739, 0.7846678695652174, 0.9075489347826087], 
             UndirectedEdge[212, 239] -> 
             RGBColor[
              0.8263062608695653, 0.8637808695652174, 0.9154975000000001], 
             UndirectedEdge[77, 182] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[280, 336] -> 
             RGBColor[
              0.8726432173913043, 0.899979652173913, 0.9201159347826087], 
             UndirectedEdge[199, 400] -> 
             RGBColor[
              0.8058842173913043, 0.8490307826086956, 0.9715907173913043], 
             UndirectedEdge[73, 336] -> 
             RGBColor[
              0.876318804347826, 0.9007699565217391, 0.8061644347826089], 
             UndirectedEdge[305, 340] -> 
             RGBColor[
              0.9695560434782609, 0.9753736086956522, 0.8718457826086957], 
             UndirectedEdge[259, 350] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[247, 393] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[30, 216] -> 
             RGBColor[
              0.875593847826087, 0.899219347826087, 0.7272573913043477], 
             UndirectedEdge[291, 387] -> 
             RGBColor[
              0.9393703043478261, 0.7790215217391306, 0.4304839347826088], 
             UndirectedEdge[45, 338] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[219, 248] -> 
             RGBColor[
              0.9695560434782609, 0.9753736086956522, 0.8718457826086957], 
             UndirectedEdge[158, 354] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[191, 327] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[165, 192] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[143, 354] -> 
             RGBColor[
              0.9768001086956521, 0.9352560869565217, 0.534873847826087], 
             UndirectedEdge[115, 161] -> 
             RGBColor[
              0.9164897391304347, 0.9333318260869565, 0.8762094130434783], 
             UndirectedEdge[296, 330] -> 
             RGBColor[
              0.9306052391304347, 0.9013377826086957, 0.6461551304347826], 
             UndirectedEdge[45, 262] -> 
             RGBColor[
              0.976857695652174, 0.9332994347826087, 0.38996052173913043`], 
             UndirectedEdge[37, 208] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[306, 348] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[189, 263] -> 
             RGBColor[
              0.9135966956521739, 0.9321354782608695, 0.9241546304347826], 
             UndirectedEdge[2, 50] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[241, 331] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[135, 213] -> 
             RGBColor[
              0.8263062608695653, 0.8637808695652174, 0.9154975000000001], 
             UndirectedEdge[49, 349] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[256, 319] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[64, 332] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[213, 350] -> 
             RGBColor[
              0.8058842173913043, 0.8490307826086956, 0.9715907173913043], 
             UndirectedEdge[333, 345] -> 
             RGBColor[
              0.9695560434782609, 0.9753736086956522, 0.8718457826086957], 
             UndirectedEdge[53, 201] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[9, 384] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[24, 33] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[20, 359] -> 
             RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 
             UndirectedEdge[35, 291] -> 
             RGBColor[
              0.9385877608695652, 0.7794275652173914, 0.49649021739130444`], 
             UndirectedEdge[316, 351] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[195, 263] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[67, 200] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[232, 277] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[88, 120] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[247, 271] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[202, 269] -> 
             RGBColor[0.6851188695652173, 0.7519459130434782, 0.970885], 
             UndirectedEdge[207, 291] -> 
             RGBColor[
              0.9279230217391304, 0.772915739130435, 0.5791149130434783], 
             UndirectedEdge[72, 397] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[200, 298] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[233, 389] -> 
             RGBColor[
              0.7263454130434783, 0.6140079130434783, 0.5921688478260869], 
             UndirectedEdge[44, 311] -> 
             RGBColor[
              0.9099508913043479, 0.9094221304347827, 0.6803066086956522], 
             UndirectedEdge[137, 258] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[46, 287] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[84, 274] -> 
             RGBColor[
              0.976857695652174, 0.9332994347826087, 0.38996052173913043`], 
             UndirectedEdge[270, 357] -> 
             RGBColor[
              0.7991548695652174, 0.8431877826086956, 0.9805727826086956], 
             UndirectedEdge[44, 344] -> 
             RGBColor[
              0.8226604565217391, 0.8410675217391305, 0.6716494782608695], 
             UndirectedEdge[44, 383] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[193, 364] -> 
             RGBColor[
              0.707998652173913, 0.7699177826086956, 0.9636421521739131], 
             UndirectedEdge[43, 375] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[184, 252] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[16, 78] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[345, 353] -> 
             RGBColor[
              0.9233611739130434, 0.941455304347826, 0.9831270652173913], 
             UndirectedEdge[167, 203] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[329, 340] -> 
             RGBColor[0.8755362608695652, 0.901176, 0.8721707173913045], 
             UndirectedEdge[193, 380] -> 
             RGBColor[
              0.946240956521739, 0.9594271739130434, 0.9758842173913044], 
             UndirectedEdge[115, 253] -> 
             RGBColor[
              0.9172722826086956, 0.9329257826086956, 0.8102031304347828], 
             UndirectedEdge[113, 270] -> 
             RGBColor[
              0.8744170652173914, 0.775589391304348, 0.6150141521739131], 
             UndirectedEdge[121, 202] -> 
             RGBColor[
              0.9467338478260869, 0.9554450869565217, 0.7341753043478261], 
             UndirectedEdge[17, 111] -> 
             RGBColor[
              0.8726432173913043, 0.899979652173913, 0.9201159347826087], 
             UndirectedEdge[73, 280] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[127, 242] -> 
             RGBColor[
              0.9058776086956521, 0.5623174782608695, 0.400006391304348], 
             UndirectedEdge[19, 211] -> 
             RGBColor[
              0.9768001086956521, 0.9352560869565217, 0.534873847826087], 
             UndirectedEdge[213, 345] -> 
             RGBColor[
              0.8058842173913043, 0.8490307826086956, 0.9715907173913043], 
             UndirectedEdge[102, 350] -> 
             RGBColor[
              0.958891304347826, 0.9688617826086956, 0.9544704782608696], 
             UndirectedEdge[81, 227] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[144, 218] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[130, 354] -> 
             RGBColor[
              0.9164897391304347, 0.9333318260869565, 0.8762094130434783], 
             UndirectedEdge[104, 327] -> 
             RGBColor[
              0.9467338478260869, 0.9554450869565217, 0.7341753043478261], 
             UndirectedEdge[10, 253] -> 
             RGBColor[
              0.829981847826087, 0.8645711739130435, 0.8015460000000001], 
             UndirectedEdge[40, 41] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[5, 113] -> 
             RGBColor[0.951581, 0.8331715652173914, 0.44060580434782626`], 
             UndirectedEdge[271, 337] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[325, 376] -> 
             RGBColor[0.905825, 0.92682, 0.9588341086956522], 
             UndirectedEdge[52, 337] -> 
             RGBColor[
              0.9467338478260869, 0.9554450869565217, 0.734175304347826], 
             UndirectedEdge[246, 260] -> 
             RGBColor[
              0.9225167391304349, 0.7233636086956523, 0.26355671739130443`], 
             UndirectedEdge[22, 290] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[24, 107] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[314, 369] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[187, 208] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[9, 174] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[6, 303] -> 
             RGBColor[0.951581, 0.8331715652173914, 0.44060580434782626`], 
             UndirectedEdge[100, 198] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[101, 123] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[210, 394] -> 
             RGBColor[
              0.8689974130434783, 0.8772663043478262, 0.6762679130434783], 
             UndirectedEdge[213, 227] -> 
             RGBColor[
              0.8226604565217391, 0.8410675217391305, 0.6716494782608695], 
             UndirectedEdge[32, 46] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[303, 391] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[248, 251] -> 
             RGBColor[
              0.6916658695652174, 0.7519695652173912, 0.8569540652173914], 
             UndirectedEdge[239, 388] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[205, 277] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[308, 378] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[119, 130] -> 
             RGBColor[
              0.840108347826087, 0.8753436086956522, 0.9846114782608696], 
             UndirectedEdge[28, 254] -> 
             RGBColor[
              0.9630171956521738, 0.9514639130434783, 0.6759429782608696], 
             UndirectedEdge[217, 314] -> 
             RGBColor[0.905825, 0.92682, 0.9588341086956522], 
             UndirectedEdge[229, 307] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[114, 155] -> 
             RGBColor[
              0.9135966956521739, 0.9321354782608695, 0.9241546304347826], 
             UndirectedEdge[226, 288] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[217, 231] -> 
             RGBColor[
              0.9165473260869565, 0.9313751739130436, 0.7312960869565217], 
             UndirectedEdge[151, 346] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[114, 180] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[215, 345] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[190, 252] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[275, 311] -> 
             RGBColor[
              0.9135966956521739, 0.9321354782608695, 0.9241546304347826], 
             UndirectedEdge[75, 320] -> 
             RGBColor[
              0.8723508260869566, 0.513256739130435, 0.2151987391304348], 
             UndirectedEdge[169, 393] -> 
             RGBColor[
              0.938645347826087, 0.7774709130434785, 0.35157689130434777`], 
             UndirectedEdge[80, 182] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[239, 362] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[171, 342] -> 
             RGBColor[
              0.9702612608695653, 0.9113463913043478, 0.3389710434782609], 
             UndirectedEdge[107, 157] -> 
             RGBColor[
              0.9863898695652173, 0.965453695652174, 0.4269912173913043], 
             UndirectedEdge[116, 286] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[37, 117] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[111, 222] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[57, 72] -> 
             RGBColor[
              0.958891304347826, 0.9688617826086956, 0.9544704782608696], 
             UndirectedEdge[8, 323] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[115, 356] -> 
             RGBColor[
              0.9135966956521739, 0.9321354782608695, 0.9241546304347826], 
             UndirectedEdge[129, 391] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[271, 303] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[141, 196] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[8, 117] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[278, 330] -> 
             RGBColor[
              0.9467338478260869, 0.9554450869565217, 0.7341753043478261], 
             UndirectedEdge[95, 276] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[114, 268] -> 
             RGBColor[
              0.5830060217391304, 0.6471606739130434, 0.8985993913043478], 
             UndirectedEdge[95, 148] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[236, 366] -> 
             RGBColor[
              0.9401374130434782, 0.9334920434782609, 0.6831858260869565], 
             UndirectedEdge[108, 378] -> 
             RGBColor[
              0.8263062608695653, 0.8637808695652174, 0.9154975000000001], 
             UndirectedEdge[33, 107] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[309, 362] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[178, 278] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[21, 232] -> 
             RGBColor[
              0.9172722826086956, 0.9329257826086956, 0.8102031304347828], 
             UndirectedEdge[20, 140] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[33, 150] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[38, 213] -> 
             RGBColor[
              0.829981847826087, 0.8645711739130435, 0.8015460000000001], 
             UndirectedEdge[86, 262] -> 
             RGBColor[
              0.977582652173913, 0.934850043478261, 0.4688675652173915], 
             UndirectedEdge[17, 310] -> 
             RGBColor[
              0.8726432173913043, 0.899979652173913, 0.9201159347826087], 
             UndirectedEdge[222, 223] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[19, 124] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[184, 274] -> 
             RGBColor[
              0.9467338478260869, 0.9554450869565217, 0.734175304347826], 
             UndirectedEdge[195, 360] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[186, 378] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[31, 169] -> 
             RGBColor[
              0.9385877608695652, 0.7794275652173914, 0.49649021739130444`], 
             UndirectedEdge[4, 84] -> 
             RGBColor[
              0.9306052391304347, 0.9013377826086957, 0.6461551304347826], 
             UndirectedEdge[81, 383] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[327, 335] -> 
             RGBColor[
              0.947458804347826, 0.9569956956521739, 0.8130823478260871], 
             UndirectedEdge[11, 214] -> 
             RGBColor[
              0.9614017608695653, 0.8858897826086958, 0.5654167826086958], 
             UndirectedEdge[15, 35] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[151, 354] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[91, 192] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[44, 130] -> 
             RGBColor[
              0.9099508913043479, 0.9094221304347827, 0.6803066086956522], 
             UndirectedEdge[195, 356] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[226, 315] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[65, 206] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[287, 400] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[247, 319] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[55, 72] -> 
             RGBColor[
              0.9233611739130434, 0.941455304347826, 0.9831270652173913], 
             UndirectedEdge[313, 329] -> 
             RGBColor[
              0.8726432173913043, 0.899979652173913, 0.9201159347826087], 
             UndirectedEdge[5, 357] -> 
             RGBColor[
              0.876318804347826, 0.9007699565217391, 0.8061644347826089], 
             UndirectedEdge[39, 328] -> 
             RGBColor[
              0.9695560434782609, 0.9753736086956522, 0.8718457826086957], 
             UndirectedEdge[310, 384] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[66, 344] -> 
             RGBColor[
              0.8006229782608696, 0.7607433043478262, 0.6172165000000001], 
             UndirectedEdge[271, 391] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[203, 211] -> 
             RGBColor[
              0.9768001086956521, 0.9352560869565217, 0.534873847826087], 
             UndirectedEdge[100, 203] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[323, 377] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[351, 395] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[179, 209] -> 
             RGBColor[
              0.7806863695652173, 0.8239437391304347, 0.718572652173913], 
             UndirectedEdge[283, 356] -> 
             RGBColor[
              0.9614017608695653, 0.8858897826086958, 0.5654167826086958], 
             UndirectedEdge[77, 80] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[200, 398] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[280, 368] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[3, 390] -> 
             RGBColor[
              0.9577559565217392, 0.8631764347826087, 0.3215687608695652], 
             UndirectedEdge[64, 380] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[139, 186] -> 
             RGBColor[
              0.977582652173913, 0.934850043478261, 0.4688675652173915], 
             UndirectedEdge[160, 245] -> 
             RGBColor[
              0.9033191086956521, 0.7092027826086957, 0.5905543043478261], 
             UndirectedEdge[64, 360] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[72, 337] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[11, 141] -> 
             RGBColor[
              0.9643523913043479, 0.8851294782608696, 0.37255823913043473`], 
             UndirectedEdge[62, 223] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[351, 399] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[205, 232] -> 
             RGBColor[
              0.947458804347826, 0.9569956956521739, 0.8130823478260871], 
             UndirectedEdge[175, 379] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[144, 339] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[66, 275] -> 
             RGBColor[
              0.9614017608695653, 0.8858897826086958, 0.5654167826086958], 
             UndirectedEdge[311, 346] -> 
             RGBColor[
              0.9165473260869565, 0.9313751739130436, 0.7312960869565217], 
             UndirectedEdge[81, 326] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[145, 335] -> 
             RGBColor[
              0.965077347826087, 0.8866800869565219, 0.4514652826086958], 
             UndirectedEdge[24, 56] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[310, 319] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[131, 303] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[146, 317] -> 
             RGBColor[
              0.9306052391304347, 0.9013377826086957, 0.6461551304347826], 
             UndirectedEdge[159, 321] -> 
             RGBColor[
              0.9233611739130434, 0.941455304347826, 0.9831270652173913], 
             UndirectedEdge[339, 361] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[60, 297] -> 
             RGBColor[0.905825, 0.92682, 0.9588341086956522], 
             UndirectedEdge[1, 368] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[15, 106] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[144, 282] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[333, 391] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[85, 238] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[130, 135] -> 
             RGBColor[
              0.9135966956521739, 0.9321354782608695, 0.9241546304347826], 
             UndirectedEdge[194, 256] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[129, 271] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[12, 168] -> 
             RGBColor[
              0.875593847826087, 0.899219347826087, 0.7272573913043477], 
             UndirectedEdge[32, 271] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[227, 363] -> 
             RGBColor[
              0.9630171956521738, 0.9514639130434783, 0.6759429782608696], 
             UndirectedEdge[351, 355] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[70, 285] -> 
             RGBColor[
              0.9152726739130435, 0.7634811304347828, 0.600528652173913], 
             UndirectedEdge[19, 107] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[88, 359] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[128, 130] -> 
             RGBColor[
              0.9165473260869565, 0.9313751739130436, 0.7312960869565217], 
             UndirectedEdge[72, 297] -> 
             RGBColor[
              0.893174652173913, 0.9173853913043478, 0.980247847826087], 
             UndirectedEdge[125, 184] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[41, 63] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[67, 133] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[272, 308] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[199, 287] -> 
             RGBColor[
              0.8263062608695653, 0.8637808695652174, 0.9154975000000001], 
             UndirectedEdge[60, 333] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[86, 325] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[77, 377] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[62, 319] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[52, 199] -> 
             RGBColor[
              0.7830044347826086, 0.8310589130434782, 0.9788335652173913], 
             UndirectedEdge[57, 376] -> 
             RGBColor[0.905825, 0.92682, 0.9588341086956522], 
             UndirectedEdge[11, 161] -> 
             RGBColor[
              0.9642948043478261, 0.8870861304347827, 0.5174715652173913], 
             UndirectedEdge[155, 300] -> 
             RGBColor[
              0.8879134130434783, 0.8290979130434784, 0.6258736304347826], 
             UndirectedEdge[81, 275] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[100, 266] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[56, 266] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[82, 257] -> 
             RGBColor[
              0.9165473260869565, 0.9313751739130436, 0.7312960869565217], 
             UndirectedEdge[32, 259] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[261, 355] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[74, 179] -> 
             RGBColor[
              0.7777357391304347, 0.8247040434782609, 0.9114311956521739], 
             UndirectedEdge[100, 174] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[208, 388] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[249, 299] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[58, 181] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[271, 345] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[20, 89] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[174, 358] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[185, 274] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[106, 314] -> 
             RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 
             UndirectedEdge[73, 387] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[191, 261] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[135, 227] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[102, 345] -> 
             RGBColor[
              0.958891304347826, 0.9688617826086956, 0.9544704782608696], 
             UndirectedEdge[72, 108] -> 
             RGBColor[
              0.8058842173913043, 0.8490307826086956, 0.9715907173913043], 
             UndirectedEdge[7, 273] -> 
             RGBColor[
              0.9536300652173912, 0.8805743043478262, 0.6000962608695652], 
             UndirectedEdge[111, 385] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[25, 187] -> 
             RGBColor[
              0.9180999347826087, 0.8531678260869566, 0.6287528478260869], 
             UndirectedEdge[290, 338] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[133, 200] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[64, 88] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[23, 92] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[38, 350] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[135, 224] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[329, 358] -> 
             RGBColor[0.8755362608695652, 0.901176, 0.8721707173913045], 
             UndirectedEdge[4, 185] -> 
             RGBColor[
              0.9467338478260869, 0.9554450869565217, 0.734175304347826], 
             UndirectedEdge[111, 199] -> 
             RGBColor[
              0.8263062608695653, 0.8637808695652174, 0.9154975000000001], 
             UndirectedEdge[138, 264] -> 
             RGBColor[
              0.8185345652173912, 0.8584653913043478, 0.9501769782608696], 
             UndirectedEdge[275, 344] -> 
             RGBColor[
              0.8263062608695653, 0.8637808695652174, 0.9154975000000001], 
             UndirectedEdge[300, 371] -> 
             RGBColor[
              0.8879134130434783, 0.8290979130434784, 0.6258736304347827], 
             UndirectedEdge[69, 273] -> 
             RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 
             UndirectedEdge[65, 174] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[217, 254] -> 
             RGBColor[
              0.893174652173913, 0.9173853913043478, 0.980247847826087], 
             UndirectedEdge[102, 378] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[246, 326] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[120, 242] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[25, 117] -> 
             RGBColor[
              0.9643523913043479, 0.8851294782608696, 0.37255823913043473`], 
             UndirectedEdge[44, 227] -> 
             RGBColor[
              0.9797934347826087, 0.9435006521739131, 0.3760017391304348], 
             UndirectedEdge[118, 206] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[151, 158] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[151, 308] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[298, 390] -> 
             RGBColor[
              0.9577559565217392, 0.8631764347826087, 0.3215687608695652], 
             UndirectedEdge[62, 111] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[131, 201] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[291, 368] -> 
             RGBColor[
              0.9279230217391304, 0.772915739130435, 0.5791149130434783], 
             UndirectedEdge[35, 73] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[273, 293] -> 
             RGBColor[0.905825, 0.92682, 0.9588341086956522], 
             UndirectedEdge[4, 274] -> 
             RGBColor[
              0.9467338478260869, 0.9554450869565217, 0.734175304347826], 
             UndirectedEdge[10, 337] -> 
             RGBColor[
              0.8292568913043479, 0.8630205652173913, 0.722638956521739], 
             UndirectedEdge[27, 265] -> 
             RGBColor[
              0.9756675434782609, 0.9608985217391305, 0.6545292391304348], 
             UndirectedEdge[262, 325] -> 
             RGBColor[
              0.9661353695652174, 0.9287442608695653, 0.6174985434782609], 
             UndirectedEdge[46, 337] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[322, 327] -> 
             RGBColor[
              0.9401374130434782, 0.9334920434782609, 0.6831858260869565], 
             UndirectedEdge[59, 299] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[254, 369] -> 
             RGBColor[
              0.9695560434782609, 0.9753736086956522, 0.8718457826086957], 
             UndirectedEdge[262, 376] -> 
             RGBColor[
              0.9004187173913044, 0.8772678695652174, 0.6432759130434783], 
             UndirectedEdge[360, 389] -> 
             RGBColor[
              0.7806863695652173, 0.8239437391304347, 0.718572652173913], 
             UndirectedEdge[159, 381] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[77, 302] -> 
             RGBColor[
              0.976857695652174, 0.9332994347826087, 0.38996052173913043`], 
             UndirectedEdge[67, 398] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[12, 100] -> 
             RGBColor[
              0.8726432173913043, 0.899979652173913, 0.9201159347826087], 
             UndirectedEdge[329, 339] -> 
             RGBColor[
              0.8648715217391304, 0.8946641739130434, 0.9547954130434784], 
             UndirectedEdge[1, 113] -> 
             RGBColor[0.951581, 0.8331715652173914, 0.44060580434782626`], 
             UndirectedEdge[232, 390] -> 
             RGBColor[
              0.965077347826087, 0.8866800869565219, 0.4514652826086958], 
             UndirectedEdge[319, 384] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[342, 374] -> 
             RGBColor[
              0.9702612608695653, 0.9113463913043478, 0.3389710434782609], 
             UndirectedEdge[200, 320] -> 
             RGBColor[
              0.9237411521739131, 0.7239528695652174, 0.5344610869565217], 
             UndirectedEdge[35, 231] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[96, 104] -> 
             RGBColor[
              0.976857695652174, 0.9332994347826087, 0.38996052173913043`], 
             UndirectedEdge[106, 197] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[41, 265] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[52, 303] -> 
             RGBColor[
              0.947458804347826, 0.9569956956521739, 0.8130823478260871], 
             UndirectedEdge[170, 208] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[49, 355] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[140, 359] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[20, 255] -> 
             RGBColor[
              0.9536300652173912, 0.8805743043478262, 0.6000962608695652], 
             UndirectedEdge[117, 362] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[188, 293] -> 
             RGBColor[
              0.9164897391304347, 0.9333318260869565, 0.8762094130434783], 
             UndirectedEdge[149, 155] -> 
             RGBColor[
              0.9164897391304347, 0.9333318260869565, 0.8762094130434783], 
             UndirectedEdge[7, 188] -> 
             RGBColor[
              0.9642948043478261, 0.8870861304347827, 0.5174715652173913], 
             UndirectedEdge[120, 331] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[169, 218] -> 
             RGBColor[
              0.9393703043478261, 0.7790215217391306, 0.4304839347826088], 
             UndirectedEdge[345, 350] -> 
             RGBColor[
              0.946240956521739, 0.9594271739130434, 0.9758842173913044], 
             UndirectedEdge[147, 217] -> 
             RGBColor[
              0.9165473260869565, 0.9313751739130436, 0.7312960869565217], 
             UndirectedEdge[141, 386] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[128, 383] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[138, 394] -> 
             RGBColor[
              0.7118644347826086, 0.7748331739130434, 0.9719156521739131], 
             UndirectedEdge[132, 300] -> 
             RGBColor[
              0.965077347826087, 0.8866800869565219, 0.4514652826086958], 
             UndirectedEdge[103, 122] -> 
             RGBColor[
              0.965077347826087, 0.8866800869565219, 0.4514652826086958], 
             UndirectedEdge[147, 195] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[123, 389] -> 
             RGBColor[
              0.7777357391304347, 0.8247040434782609, 0.9114311956521739], 
             UndirectedEdge[93, 394] -> 
             RGBColor[0.574331, 0.6618255217391305, 0.9613174347826088], 
             UndirectedEdge[199, 350] -> 
             RGBColor[
              0.8058842173913043, 0.8490307826086956, 0.9715907173913043], 
             UndirectedEdge[66, 158] -> 
             RGBColor[
              0.9643523913043479, 0.8851294782608696, 0.37255823913043473`], 
             UndirectedEdge[105, 215] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[253, 364] -> 
             RGBColor[
              0.7320962826086956, 0.7854581739130435, 0.7935974347826089], 
             UndirectedEdge[76, 78] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[153, 358] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[54, 64] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[84, 125] -> 
             RGBColor[
              0.9768001086956521, 0.9352560869565217, 0.534873847826087], 
             UndirectedEdge[195, 380] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[81, 146] -> 
             RGBColor[
              0.9768001086956521, 0.9352560869565217, 0.534873847826087], 
             UndirectedEdge[275, 317] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[25, 377] -> 
             RGBColor[
              0.965077347826087, 0.8866800869565219, 0.4514652826086958], 
             UndirectedEdge[180, 232] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[52, 333] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[97, 276] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[51, 390] -> 
             RGBColor[
              0.9482237826086957, 0.8310221739130436, 0.28453806521739133`], 
             UndirectedEdge[199, 393] -> 
             RGBColor[
              0.8292568913043479, 0.8630205652173913, 0.722638956521739], 
             UndirectedEdge[169, 224] -> 
             RGBColor[
              0.938645347826087, 0.7774709130434785, 0.35157689130434777`], 
             UndirectedEdge[132, 268] -> 
             RGBColor[
              0.5866816086956522, 0.6479509782608696, 0.784647891304348], 
             UndirectedEdge[162, 183] -> 
             RGBColor[
              0.977582652173913, 0.934850043478261, 0.4688675652173915], 
             UndirectedEdge[15, 231] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[246, 248] -> 
             RGBColor[
              0.9768001086956521, 0.9352560869565217, 0.534873847826087], 
             UndirectedEdge[44, 81] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[39, 197] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[57, 86] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[74, 209] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[115, 389] -> 
             RGBColor[
              0.7042473913043479, 0.7679121739130434, 0.9718880434782609], 
             UndirectedEdge[157, 168] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[224, 363] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[47, 279] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[58, 352] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[101, 161] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[23, 98] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[37, 388] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[13, 21] -> 
             RGBColor[
              0.9135966956521739, 0.9321354782608695, 0.9241546304347826], 
             UndirectedEdge[159, 375] -> 
             RGBColor[
              0.9360115217391303, 0.9508899130434783, 0.9617133260869566], 
             UndirectedEdge[130, 346] -> 
             RGBColor[
              0.9165473260869565, 0.9313751739130436, 0.7312960869565217], 
             UndirectedEdge[104, 225] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[226, 252] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[64, 283] -> 
             RGBColor[
              0.9614017608695653, 0.8858897826086958, 0.5654167826086957], 
             UndirectedEdge[262, 284] -> 
             RGBColor[
              0.9661353695652174, 0.9287442608695653, 0.6174985434782609], 
             UndirectedEdge[282, 313] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[88, 360] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[210, 230] -> 
             RGBColor[
              0.9401374130434782, 0.9334920434782609, 0.6831858260869565], 
             UndirectedEdge[2, 138] -> 
             RGBColor[
              0.829981847826087, 0.8645711739130435, 0.8015460000000001], 
             UndirectedEdge[178, 367] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[54, 123] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[36, 95] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[294, 301] -> 
             RGBColor[
              0.947458804347826, 0.9569956956521739, 0.8130823478260871], 
             UndirectedEdge[60, 337] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[251, 275] -> 
             RGBColor[
              0.6887728260869566, 0.7507732173913043, 0.9048992826086957], 
             UndirectedEdge[66, 311] -> 
             RGBColor[
              0.8879134130434783, 0.8290979130434784, 0.6258736304347827], 
             UndirectedEdge[110, 400] -> 
             RGBColor[
              0.9233611739130434, 0.941455304347826, 0.9831270652173913], 
             UndirectedEdge[143, 151] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[157, 206] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[226, 274] -> 
             RGBColor[
              0.976857695652174, 0.9332994347826087, 0.38996052173913043`], 
             UndirectedEdge[86, 265] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[64, 389] -> 
             RGBColor[
              0.7777357391304347, 0.8247040434782609, 0.9114311956521739], 
             UndirectedEdge[120, 356] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[164, 279] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[24, 238] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[213, 259] -> 
             RGBColor[
              0.8292568913043479, 0.8630205652173913, 0.722638956521739], 
             UndirectedEdge[73, 162] -> 
             RGBColor[
              0.977582652173913, 0.934850043478261, 0.4688675652173915], 
             UndirectedEdge[257, 356] -> 
             RGBColor[
              0.9135966956521739, 0.9321354782608695, 0.9241546304347826], 
             UndirectedEdge[6, 281] -> 
             RGBColor[
              0.9347274347826088, 0.7775136521739132, 0.2736785869565218], 
             UndirectedEdge[176, 277] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[140, 263] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[54, 161] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[7, 142] -> 
             RGBColor[
              0.9100114347826087, 0.6751936521739133, 0.24615443478260873`], 
             UndirectedEdge[81, 311] -> 
             RGBColor[
              0.9164897391304347, 0.9333318260869565, 0.8762094130434783], 
             UndirectedEdge[204, 237] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[134, 374] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[264, 279] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[81, 344] -> 
             RGBColor[
              0.8291993043478261, 0.8649772173913044, 0.8675522826086957], 
             UndirectedEdge[287, 391] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[90, 228] -> 
             RGBColor[
              0.9274833695652174, 0.8176311739130436, 0.6106505217391305], 
             UndirectedEdge[222, 259] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[143, 342] -> 
             RGBColor[
              0.9607290869565218, 0.8791921304347826, 0.30194034782608703`], 
             UndirectedEdge[68, 262] -> 
             RGBColor[
              0.977582652173913, 0.934850043478261, 0.4688675652173915], 
             UndirectedEdge[73, 189] -> 
             RGBColor[
              0.9172722826086956, 0.9329257826086956, 0.8102031304347828], 
             UndirectedEdge[79, 176] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[14, 289] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[126, 373] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[313, 361] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[56, 203] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[163, 240] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[283, 380] -> 
             RGBColor[0.9409797173913044, 0.871139695652174, 0.62151], 
             UndirectedEdge[165, 318] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[184, 185] -> 
             RGBColor[
              0.9467338478260869, 0.9554450869565217, 0.734175304347826], 
             UndirectedEdge[123, 364] -> 
             RGBColor[
              0.7284206956521739, 0.7846678695652174, 0.9075489347826087], 
             UndirectedEdge[24, 341] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[10, 364] -> 
             RGBColor[
              0.5676419130434782, 0.6595213913043478, 0.9593486521739131], 
             UndirectedEdge[59, 132] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[110, 309] -> 
             RGBColor[
              0.9360115217391303, 0.9508899130434783, 0.9617133260869566], 
             UndirectedEdge[28, 50] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[120, 147] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[322, 335] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[9, 198] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[214, 257] -> 
             RGBColor[
              0.9135966956521739, 0.9321354782608695, 0.9241546304347826], 
             UndirectedEdge[190, 274] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[18, 198] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[280, 291] -> 
             RGBColor[
              0.9356947173913044, 0.7782312173913045, 0.5444354347826088], 
             UndirectedEdge[156, 179] -> 
             RGBColor[
              0.7806287826086956, 0.8259003913043478, 0.8634859782608696], 
             UndirectedEdge[76, 96] -> 
             RGBColor[
              0.9661353695652174, 0.9287442608695653, 0.6174985434782609], 
             UndirectedEdge[143, 158] -> 
             RGBColor[
              0.976857695652174, 0.9332994347826087, 0.38996052173913043`], 
             UndirectedEdge[252, 274] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[272, 348] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[51, 232] -> 
             RGBColor[
              0.977582652173913, 0.934850043478261, 0.4688675652173915], 
             UndirectedEdge[66, 317] -> 
             RGBColor[
              0.9180999347826087, 0.8531678260869566, 0.6287528478260869], 
             UndirectedEdge[258, 264] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[17, 223] -> 
             RGBColor[
              0.8726432173913043, 0.899979652173913, 0.9201159347826087], 
             UndirectedEdge[46, 271] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[93, 201] -> 
             RGBColor[
              0.6887728260869566, 0.7507732173913043, 0.9048992826086957], 
             UndirectedEdge[232, 373] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[182, 208] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[10, 391] -> 
             RGBColor[
              0.829981847826087, 0.8645711739130435, 0.8015460000000001], 
             UndirectedEdge[284, 366] -> 
             RGBColor[
              0.9756675434782609, 0.9608985217391305, 0.6545292391304348], 
             UndirectedEdge[154, 387] -> 
             RGBColor[
              0.829981847826087, 0.8645711739130435, 0.8015460000000001], 
             UndirectedEdge[135, 363] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[37, 269] -> 
             RGBColor[
              0.7284206956521739, 0.7846678695652174, 0.9075489347826087], 
             UndirectedEdge[201, 281] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[302, 377] -> 
             RGBColor[
              0.977582652173913, 0.934850043478261, 0.4688675652173915], 
             UndirectedEdge[179, 286] -> 
             RGBColor[
              0.7777357391304347, 0.8247040434782609, 0.9114311956521739], 
             UndirectedEdge[108, 325] -> 
             RGBColor[
              0.8185345652173912, 0.8584653913043478, 0.9501769782608696], 
             UndirectedEdge[279, 299] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[196, 332] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[31, 224] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[200, 296] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[170, 221] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[198, 206] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[36, 361] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[132, 180] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[127, 312] -> 
             RGBColor[
              0.6928527173913044, 0.39730386956521735`, 0.5616913043478261], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.9385877608695652, 0.7794275652173914, 0.4964902173913044], 
             UndirectedEdge[67, 75] -> 
             RGBColor[
              0.938645347826087, 0.7774709130434785, 0.35157689130434777`], 
             UndirectedEdge[110, 287] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[88, 233] -> 
             RGBColor[
              0.9385877608695652, 0.7794275652173914, 0.49649021739130444`], 
             UndirectedEdge[168, 216] -> 
             RGBColor[
              0.875593847826087, 0.899219347826087, 0.7272573913043477], 
             UndirectedEdge[1, 291] -> 
             RGBColor[
              0.9393703043478261, 0.7790215217391306, 0.4304839347826089], 
             UndirectedEdge[115, 214] -> 
             RGBColor[
              0.9135966956521739, 0.9321354782608695, 0.9241546304347826], 
             UndirectedEdge[233, 256] -> 
             RGBColor[
              0.9393703043478261, 0.7790215217391306, 0.4304839347826088], 
             UndirectedEdge[4, 252] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[91, 399] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[76, 269] -> 
             RGBColor[0.720649, 0.7793523913043479, 0.9422284130434784], 
             UndirectedEdge[91, 172] -> 
             RGBColor[
              0.7814113260869565, 0.825494347826087, 0.797479695652174], 
             UndirectedEdge[165, 184] -> 
             RGBColor[
              0.9360115217391303, 0.9508899130434783, 0.9617133260869566], 
             UndirectedEdge[60, 139] -> 
             RGBColor[
              0.9661353695652174, 0.9287442608695653, 0.6174985434782609], 
             UndirectedEdge[356, 359] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[228, 305] -> 
             RGBColor[
              0.946240956521739, 0.9594271739130434, 0.9758842173913044], 
             UndirectedEdge[141, 209] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[171, 348] -> 
             RGBColor[
              0.9756675434782609, 0.9608985217391305, 0.6545292391304348], 
             UndirectedEdge[10, 60] -> 
             RGBColor[
              0.8185345652173912, 0.8584653913043478, 0.9501769782608696], 
             UndirectedEdge[234, 298] -> 
             RGBColor[
              0.9577559565217392, 0.8631764347826087, 0.3215687608695652], 
             UndirectedEdge[323, 388] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[294, 329] -> 
             RGBColor[0.8293413913043477, 0.8672576956521738, 0.983452], 
             UndirectedEdge[211, 238] -> 
             RGBColor[
              0.9702612608695653, 0.9113463913043478, 0.3389710434782609], 
             UndirectedEdge[31, 99] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[111, 319] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[258, 394] -> 
             RGBColor[
              0.8726432173913043, 0.899979652173913, 0.9201159347826087], 
             UndirectedEdge[101, 364] -> 
             RGBColor[
              0.7247748913043478, 0.7619545217391305, 0.6637009130434783], 
             UndirectedEdge[225, 349] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[118, 386] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[95, 326] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[228, 382] -> 
             RGBColor[
              0.946240956521739, 0.9594271739130434, 0.9758842173913044], 
             UndirectedEdge[120, 255] -> 
             RGBColor[
              0.9643523913043479, 0.8851294782608696, 0.37255823913043473`], 
             UndirectedEdge[222, 292] -> 
             RGBColor[
              0.958891304347826, 0.9688617826086956, 0.9544704782608696], 
             UndirectedEdge[325, 397] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[155, 299] -> 
             RGBColor[
              0.9172722826086956, 0.9329257826086956, 0.8102031304347828], 
             UndirectedEdge[17, 99] -> 
             RGBColor[
              0.875593847826087, 0.899219347826087, 0.7272573913043477], 
             UndirectedEdge[60, 105] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[229, 340] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[297, 375] -> 
             RGBColor[0.905825, 0.92682, 0.9588341086956522], 
             UndirectedEdge[155, 249] -> 
             RGBColor[
              0.9164897391304347, 0.9333318260869565, 0.8762094130434783], 
             UndirectedEdge[143, 348] -> 
             RGBColor[
              0.9661353695652174, 0.9287442608695653, 0.6174985434782609], 
             UndirectedEdge[175, 294] -> 
             RGBColor[
              0.947458804347826, 0.9569956956521739, 0.8130823478260871], 
             UndirectedEdge[19, 181] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[153, 294] -> 
             RGBColor[
              0.947458804347826, 0.9569956956521739, 0.8130823478260871], 
             UndirectedEdge[68, 376] -> 
             RGBColor[
              0.9172722826086956, 0.9329257826086956, 0.8102031304347828], 
             UndirectedEdge[317, 354] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[2, 254] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[243, 311] -> 
             RGBColor[0.905825, 0.92682, 0.9588341086956522], 
             UndirectedEdge[23, 143] -> 
             RGBColor[
              0.9607290869565218, 0.8791921304347826, 0.30194034782608703`], 
             UndirectedEdge[20, 64] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[75, 296] -> 
             RGBColor[
              0.9225167391304349, 0.7233636086956523, 0.26355671739130443`], 
             UndirectedEdge[146, 227] -> 
             RGBColor[
              0.9702612608695653, 0.9113463913043478, 0.3389710434782609], 
             UndirectedEdge[160, 238] -> 
             RGBColor[
              0.9200953478260869, 0.7012395217391305, 0.2906130652173913], 
             UndirectedEdge[75, 178] -> 
             RGBColor[
              0.9385877608695652, 0.7794275652173914, 0.4964902173913044], 
             UndirectedEdge[95, 166] -> 
             RGBColor[
              0.7320962826086956, 0.7854581739130435, 0.7935974347826089], 
             UndirectedEdge[25, 309] -> 
             RGBColor[
              0.9536300652173912, 0.8805743043478262, 0.6000962608695652], 
             UndirectedEdge[166, 326] -> 
             RGBColor[
              0.7284206956521739, 0.7846678695652174, 0.9075489347826087], 
             UndirectedEdge[158, 308] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[229, 343] -> 
             RGBColor[
              0.8702948695652173, 0.8994135217391304, 0.9874906956521738], 
             UndirectedEdge[229, 294] -> 
             RGBColor[
              0.9004813913043477, 0.9234834347826086, 0.9903699130434782], 
             UndirectedEdge[64, 257] -> 
             RGBColor[
              0.9135966956521739, 0.9321354782608695, 0.9241546304347826], 
             UndirectedEdge[56, 65] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[170, 192] -> 
             RGBColor[
              0.9863898695652173, 0.965453695652174, 0.4269912173913043], 
             UndirectedEdge[133, 347] -> 
             RGBColor[
              0.7573136956521738, 0.8099539565217391, 0.9675244130434782], 
             UndirectedEdge[223, 393] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[116, 338] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[32, 71] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[95, 361] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[247, 292] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[337, 391] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[181, 238] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[97, 246] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[62, 247] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[207, 280] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[145, 221] -> 
             RGBColor[
              0.9614017608695653, 0.8858897826086958, 0.5654167826086958], 
             UndirectedEdge[10, 334] -> 
             RGBColor[
              0.8291993043478261, 0.8649772173913044, 0.8675522826086957], 
             UndirectedEdge[25, 78] -> 
             RGBColor[
              0.9614017608695653, 0.8858897826086958, 0.5654167826086958], 
             UndirectedEdge[46, 139] -> 
             RGBColor[
              0.9661353695652174, 0.9287442608695653, 0.6174985434782609], 
             UndirectedEdge[224, 383] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[138, 164] -> 
             RGBColor[
              0.8263062608695653, 0.8637808695652174, 0.9154975000000001], 
             UndirectedEdge[53, 93] -> 
             RGBColor[
              0.6887728260869566, 0.7507732173913043, 0.9048992826086957], 
             UndirectedEdge[31, 199] -> 
             RGBColor[
              0.8291993043478261, 0.8649772173913044, 0.8675522826086957], 
             UndirectedEdge[98, 342] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[141, 304] -> 
             RGBColor[
              0.7313713260869565, 0.7839075652173914, 0.7146903913043477], 
             UndirectedEdge[32, 105] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[216, 329] -> 
             RGBColor[
              0.7582013913043478, 0.8110319565217391, 0.9765340869565218], 
             UndirectedEdge[164, 264] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[118, 196] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[75, 398] -> 
             RGBColor[
              0.9393703043478261, 0.7790215217391306, 0.4304839347826088], 
             UndirectedEdge[45, 48] -> 
             RGBColor[
              0.7806863695652173, 0.8239437391304347, 0.718572652173913], 
             UndirectedEdge[248, 275] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[200, 347] -> 
             RGBColor[
              0.7777357391304347, 0.8247040434782609, 0.9114311956521739], 
             UndirectedEdge[33, 58] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[134, 240] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[267, 344] -> 
             RGBColor[
              0.8292568913043479, 0.8630205652173913, 0.722638956521739], 
             UndirectedEdge[141, 286] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[33, 209] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[47, 155] -> 
             RGBColor[
              0.9172722826086956, 0.9329257826086956, 0.8102031304347828], 
             UndirectedEdge[153, 229] -> 
             RGBColor[
              0.947458804347826, 0.9569956956521739, 0.8130823478260871], 
             UndirectedEdge[64, 161] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[3, 293] -> 
             RGBColor[
              0.9099508913043479, 0.9094221304347827, 0.6803066086956522], 
             UndirectedEdge[133, 178] -> 
             RGBColor[
              0.9695560434782609, 0.9753736086956522, 0.8718457826086957], 
             UndirectedEdge[113, 162] -> 
             RGBColor[
              0.9347274347826088, 0.7775136521739132, 0.2736785869565218], 
             UndirectedEdge[313, 358] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[259, 292] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[4, 165] -> 
             RGBColor[
              0.9360115217391303, 0.9508899130434783, 0.9617133260869566], 
             UndirectedEdge[247, 385] -> 
             RGBColor[
              0.977582652173913, 0.934850043478261, 0.4688675652173915], 
             UndirectedEdge[38, 243] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[265, 381] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[15, 369] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[30, 358] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[133, 330] -> 
             RGBColor[
              0.9233611739130434, 0.941455304347826, 0.9831270652173913], 
             UndirectedEdge[223, 292] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[44, 326] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[123, 356] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[35, 154] -> 
             RGBColor[
              0.8291993043478261, 0.8649772173913044, 0.8675522826086957], 
             UndirectedEdge[146, 151] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[111, 287] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[42, 133] -> 
             RGBColor[
              0.9233611739130434, 0.941455304347826, 0.9831270652173913], 
             UndirectedEdge[40, 103] -> 
             RGBColor[
              0.965077347826087, 0.8866800869565219, 0.4514652826086958], 
             UndirectedEdge[219, 260] -> 
             RGBColor[
              0.9152726739130435, 0.7634811304347828, 0.600528652173913], 
             UndirectedEdge[151, 186] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[8, 76] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[124, 167] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[162, 291] -> 
             RGBColor[
              0.9225167391304349, 0.7233636086956523, 0.26355671739130443`], 
             UndirectedEdge[242, 255] -> 
             RGBColor[
              0.965077347826087, 0.8866800869565219, 0.4514652826086958], 
             UndirectedEdge[182, 323] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[138, 149] -> 
             RGBColor[
              0.8291993043478261, 0.8649772173913044, 0.8675522826086957], 
             UndirectedEdge[199, 353] -> 
             RGBColor[
              0.7830044347826086, 0.8310589130434782, 0.9788335652173913], 
             UndirectedEdge[34, 381] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[148, 305] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[97, 383] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[154, 207] -> 
             RGBColor[
              0.8185345652173912, 0.8584653913043478, 0.9501769782608696], 
             UndirectedEdge[272, 375] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[25, 323] -> 
             RGBColor[
              0.9614017608695653, 0.8858897826086958, 0.5654167826086958], 
             UndirectedEdge[236, 334] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[23, 346] -> 
             RGBColor[
              0.976857695652174, 0.9332994347826087, 0.38996052173913043`], 
             UndirectedEdge[23, 151] -> 
             RGBColor[
              0.9739070652173913, 0.9340597391304348, 0.5828190652173914], 
             UndirectedEdge[250, 381] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[230, 264] -> 
             RGBColor[
              0.9360115217391303, 0.9508899130434783, 0.9617133260869566], 
             UndirectedEdge[60, 68] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[50, 258] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[121, 298] -> 
             RGBColor[
              0.9863898695652173, 0.965453695652174, 0.4269912173913043], 
             UndirectedEdge[95, 382] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[42, 200] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[254, 314] -> 
             RGBColor[
              0.958891304347826, 0.9688617826086956, 0.9544704782608696], 
             UndirectedEdge[95, 305] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[321, 381] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[116, 209] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[364, 366] -> 
             RGBColor[
              0.7247748913043479, 0.7619545217391305, 0.6637009130434783], 
             UndirectedEdge[58, 156] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[118, 179] -> 
             RGBColor[
              0.7344339130434782, 0.7919820869565217, 0.9747672608695652], 
             UndirectedEdge[149, 328] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[215, 227] -> 
             RGBColor[
              0.9863898695652173, 0.965453695652174, 0.4269912173913043], 
             UndirectedEdge[70, 177] -> 
             RGBColor[
              0.8622063695652175, 0.7214393478260872, 0.6048922826086957], 
             UndirectedEdge[383, 393] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[14, 201] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[5, 368] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[214, 310] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[35, 280] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[243, 275] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[131, 391] -> 
             RGBColor[
              0.9703385869565218, 0.9749675652173913, 0.8058395000000002], 
             UndirectedEdge[2, 314] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[282, 361] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[110, 269] -> 
             RGBColor[0.6851188695652173, 0.7519459130434782, 0.970885], 
             UndirectedEdge[193, 360] -> 
             RGBColor[
              0.9696136304347825, 0.9734169565217392, 0.7269324565217391], 
             UndirectedEdge[71, 400] -> 
             RGBColor[
              0.9695560434782609, 0.9753736086956522, 0.8718457826086957], 
             UndirectedEdge[110, 117] -> 
             RGBColor[
              0.9467338478260869, 0.9554450869565217, 0.734175304347826], 
             UndirectedEdge[170, 351] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[121, 200] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[38, 383] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[172, 256] -> 
             RGBColor[
              0.7814113260869565, 0.825494347826087, 0.797479695652174], 
             UndirectedEdge[127, 258] -> 
             RGBColor[
              0.9022020217391304, 0.5615271739130434, 0.5139578913043479], 
             UndirectedEdge[25, 388] -> 
             RGBColor[
              0.965077347826087, 0.8866800869565219, 0.4514652826086958], 
             UndirectedEdge[51, 277] -> 
             RGBColor[
              0.9768001086956521, 0.9352560869565217, 0.534873847826087], 
             UndirectedEdge[85, 379] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[267, 306] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[176, 298] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[269, 323] -> 
             RGBColor[
              0.7284206956521739, 0.7846678695652174, 0.9075489347826087], 
             UndirectedEdge[21, 180] -> 
             RGBColor[
              0.9165473260869565, 0.9313751739130436, 0.7312960869565217], 
             UndirectedEdge[36, 228] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[74, 116] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[3, 188] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[69, 394] -> 
             RGBColor[
              0.8648715217391304, 0.8946641739130434, 0.9547954130434784], 
             UndirectedEdge[37, 395] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[172, 194] -> 
             RGBColor[
              0.7814113260869565, 0.825494347826087, 0.797479695652174], 
             UndirectedEdge[59, 264] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[28, 369] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[130, 344] -> 
             RGBColor[0.7528179130434782, 0.806989, 0.975954347826087], 
             UndirectedEdge[29, 270] -> 
             RGBColor[
              0.9165473260869565, 0.9313751739130436, 0.7312960869565217], 
             UndirectedEdge[41, 48] -> 
             RGBColor[
              0.7814113260869565, 0.825494347826087, 0.797479695652174], 
             UndirectedEdge[12, 124] -> 
             RGBColor[
              0.875593847826087, 0.899219347826087, 0.7272573913043477], 
             UndirectedEdge[61, 95] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[213, 306] -> 
             RGBColor[
              0.8292568913043479, 0.8630205652173913, 0.722638956521739], 
             UndirectedEdge[63, 295] -> 
             RGBColor[
              0.9871148260869566, 0.9670043043478261, 0.5058982608695654], 
             UndirectedEdge[302, 367] -> 
             RGBColor[
              0.9768001086956521, 0.9352560869565217, 0.534873847826087], 
             UndirectedEdge[140, 331] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[92, 354] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[151, 311] -> 
             RGBColor[
              0.9135966956521739, 0.9321354782608695, 0.9241546304347826], 
             UndirectedEdge[299, 371] -> 
             RGBColor[
              0.9172722826086956, 0.9329257826086956, 0.8102031304347828], 
             UndirectedEdge[140, 389] -> 
             RGBColor[
              0.7806287826086956, 0.8259003913043478, 0.8634859782608696], 
             UndirectedEdge[176, 205] -> 
             RGBColor[
              0.947458804347826, 0.9569956956521739, 0.8130823478260871], 
             UndirectedEdge[152, 179] -> 
             RGBColor[
              0.7573136956521738, 0.8099539565217391, 0.9675244130434782], 
             UndirectedEdge[142, 293] -> 
             RGBColor[
              0.8622063695652175, 0.7214393478260872, 0.6048922826086957], 
             UndirectedEdge[105, 259] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[274, 318] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[231, 369] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[151, 348] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[147, 231] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[66, 354] -> 
             RGBColor[
              0.9642948043478261, 0.8870861304347827, 0.5174715652173913], 
             UndirectedEdge[24, 65] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[42, 347] -> 
             RGBColor[
              0.7344339130434782, 0.7919820869565217, 0.9747672608695652], 
             UndirectedEdge[52, 129] -> 
             RGBColor[
              0.9401374130434782, 0.9334920434782609, 0.6831858260869565], 
             UndirectedEdge[3, 7] -> 
             RGBColor[
              0.9577559565217392, 0.8631764347826087, 0.3215687608695652], 
             UndirectedEdge[156, 352] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[229, 329] -> 
             RGBColor[0.8293413913043477, 0.8672576956521738, 0.983452], 
             UndirectedEdge[80, 187] -> 
             RGBColor[
              0.9233611739130434, 0.941455304347826, 0.9831270652173913], 
             UndirectedEdge[247, 362] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[43, 321] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[84, 270] -> 
             RGBColor[
              0.9004187173913044, 0.8772678695652174, 0.6432759130434783], 
             UndirectedEdge[318, 322] -> 
             RGBColor[
              0.9863898695652173, 0.965453695652174, 0.4269912173913043], 
             UndirectedEdge[218, 276] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[201, 303] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[283, 364] -> 
             RGBColor[
              0.7027374130434783, 0.6816303043478262, 0.6092679347826087], 
             UndirectedEdge[65, 340] -> 
             RGBColor[
              0.9822063913043477, 0.9848082173913044, 0.850432043478261], 
             UndirectedEdge[83, 214] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[124, 157] -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             UndirectedEdge[311, 344] -> 
             RGBColor[0.7528179130434782, 0.806989, 0.975954347826087], 
             UndirectedEdge[190, 226] -> 
             RGBColor[
              0.9768001086956521, 0.9352560869565217, 0.534873847826087], 
             UndirectedEdge[380, 389] -> 
             RGBColor[
              0.7573136956521738, 0.8099539565217391, 0.9675244130434782], 
             UndirectedEdge[124, 179] -> 
             RGBColor[
              0.7806863695652173, 0.8239437391304347, 0.718572652173913], 
             UndirectedEdge[199, 215] -> 
             RGBColor[
              0.8292568913043479, 0.8630205652173913, 0.722638956521739], 
             UndirectedEdge[146, 267] -> 
             RGBColor[
              0.976857695652174, 0.9332994347826087, 0.38996052173913043`], 
             UndirectedEdge[109, 249] -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             UndirectedEdge[36, 61] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[13, 232] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[38, 119] -> 
             RGBColor[
              0.9172722826086956, 0.9329257826086956, 0.8102031304347828], 
             UndirectedEdge[91, 256] -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             UndirectedEdge[6, 69] -> 
             RGBColor[
              0.9401337173913044, 0.8270657826086958, 0.5892367826086957], 
             UndirectedEdge[90, 97] -> 
             RGBColor[
              0.9479054130434783, 0.8323812608695653, 0.5545573043478261], 
             UndirectedEdge[233, 257] -> 
             RGBColor[
              0.8622063695652175, 0.7214393478260872, 0.6048922826086957], 
             UndirectedEdge[66, 119] -> 
             RGBColor[
              0.8879134130434783, 0.8290979130434784, 0.6258736304347827], 
             UndirectedEdge[33, 116] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[335, 349] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[165, 274] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[95, 169] -> 
             RGBColor[
              0.9393703043478261, 0.7790215217391306, 0.4304839347826089], 
             UndirectedEdge[135, 259] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[93, 273] -> 
             RGBColor[
              0.6810011304347825, 0.7454577391304348, 0.9395787608695653], 
             UndirectedEdge[89, 263] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[71, 289] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[32, 215] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[8, 239] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[110, 111] -> 
             RGBColor[
              0.9437832173913043, 0.9562053913043478, 0.9270338478260869], 
             UndirectedEdge[29, 162] -> 
             RGBColor[
              0.976857695652174, 0.9332994347826087, 0.38996052173913043`], 
             UndirectedEdge[337, 353] -> 
             RGBColor[
              0.9467338478260869, 0.9554450869565217, 0.7341753043478261], 
             UndirectedEdge[306, 308] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[185, 190] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[71, 385] -> 
             RGBColor[
              0.9768001086956521, 0.9352560869565217, 0.534873847826087], 
             UndirectedEdge[146, 158] -> 
             RGBColor[
              0.976857695652174, 0.9332994347826087, 0.38996052173913043`], 
             UndirectedEdge[157, 386] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[24, 124] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[22, 74] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[303, 385] -> 
             RGBColor[
              0.977582652173913, 0.934850043478261, 0.4688675652173915], 
             UndirectedEdge[130, 317] -> 
             RGBColor[
              0.8702948695652173, 0.8994135217391304, 0.9874906956521738], 
             UndirectedEdge[73, 291] -> 
             RGBColor[
              0.9393703043478261, 0.7790215217391306, 0.4304839347826089], 
             UndirectedEdge[241, 255] -> 
             RGBColor[
              0.9642948043478261, 0.8870861304347827, 0.5174715652173913], 
             UndirectedEdge[385, 400] -> 
             RGBColor[
              0.9534850217391304, 0.919309652173913, 0.6389122826086957], 
             UndirectedEdge[130, 311] -> 
             RGBColor[
              0.840108347826087, 0.8753436086956522, 0.9846114782608696], 
             UndirectedEdge[143, 308] -> 
             RGBColor[
              0.9661353695652174, 0.9287442608695653, 0.6174985434782609], 
             UndirectedEdge[297, 397] -> 
             RGBColor[
              0.9172722826086956, 0.9329257826086956, 0.8102031304347828], 
             UndirectedEdge[237, 324] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[107, 160] -> 
             RGBColor[
              0.9200953478260869, 0.7012395217391305, 0.2906130652173913], 
             UndirectedEdge[125, 185] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[269, 388] -> 
             RGBColor[
              0.7320962826086956, 0.7854581739130435, 0.7935974347826089], 
             UndirectedEdge[47, 300] -> 
             RGBColor[
              0.965077347826087, 0.8866800869565219, 0.4514652826086958], 
             UndirectedEdge[37, 365] -> 
             RGBColor[
              0.9022020217391304, 0.5615271739130434, 0.5139578913043479], 
             UndirectedEdge[356, 389] -> 
             RGBColor[
              0.7777357391304347, 0.8247040434782609, 0.9114311956521739], 
             UndirectedEdge[227, 243] -> 
             RGBColor[
              0.9756675434782609, 0.9608985217391305, 0.6545292391304348], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.7740899347826087, 0.8019906956521738, 0.6675831739130434], 
             UndirectedEdge[186, 348] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[61, 90] -> 
             RGBColor[0.951581, 0.8331715652173914, 0.44060580434782626`], 
             UndirectedEdge[72, 325] -> 
             RGBColor[
              0.958891304347826, 0.9688617826086956, 0.9544704782608696], 
             UndirectedEdge[341, 358] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[102, 337] -> 
             RGBColor[
              0.9822639782608695, 0.9828515652173914, 0.7055187173913043], 
             UndirectedEdge[297, 378] -> 
             RGBColor[
              0.9135966956521739, 0.9321354782608695, 0.9241546304347826], 
             UndirectedEdge[300, 370] -> 
             RGBColor[
              0.9643523913043479, 0.8851294782608696, 0.37255823913043473`], 
             UndirectedEdge[46, 52] -> 
             RGBColor[
              0.9360115217391303, 0.9508899130434783, 0.9617133260869566], 
             UndirectedEdge[75, 200] -> 
             RGBColor[
              0.9356947173913044, 0.7782312173913045, 0.5444354347826087], 
             UndirectedEdge[204, 343] -> 
             RGBColor[
              0.9099508913043479, 0.9094221304347827, 0.6803066086956522], 
             UndirectedEdge[32, 199] -> 
             RGBColor[
              0.8263062608695653, 0.8637808695652174, 0.9154975000000001], 
             UndirectedEdge[301, 313] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[166, 363] -> 
             RGBColor[
              0.707998652173913, 0.7699177826086956, 0.9636421521739131], 
             UndirectedEdge[333, 353] -> 
             RGBColor[
              0.9466762608695651, 0.9574017391304348, 0.8790886304347827], 
             UndirectedEdge[130, 146] -> 
             RGBColor[
              0.9004187173913044, 0.8772678695652174, 0.6432759130434783], 
             UndirectedEdge[71, 271] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[123, 332] -> 
             RGBColor[
              0.9793133478260869, 0.9836118695652174, 0.8983772608695653], 
             UndirectedEdge[340, 361] -> 
             RGBColor[
              0.9929287173913044, 0.9893633913043478, 0.6228940217391304], 
             UndirectedEdge[165, 322] -> 
             RGBColor[
              0.9756675434782609, 0.9608985217391305, 0.6545292391304348], 
             UndirectedEdge[278, 302] -> 
             RGBColor[
              0.976857695652174, 0.9332994347826087, 0.38996052173913043`], 
             UndirectedEdge[322, 355] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[68, 333] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[150, 156] -> 
             RGBColor[
              0.9936536739130435, 0.9909140000000001, 0.7018010652173915], 
             UndirectedEdge[29, 357] -> 
             RGBColor[
              0.875593847826087, 0.899219347826087, 0.7272573913043477], 
             UndirectedEdge[250, 325] -> 
             RGBColor[
              0.9756675434782609, 0.9608985217391305, 0.6545292391304348], 
             UndirectedEdge[53, 131] -> 
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791], 
             UndirectedEdge[92, 267] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[269, 309] -> 
             RGBColor[
              0.7206489999999999, 0.7793523913043479, 0.9422284130434784], 
             UndirectedEdge[162, 336] -> 
             RGBColor[
              0.8594652391304348, 0.8451120434782609, 0.6392372173913043], 
             UndirectedEdge[94, 204] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[29, 183] -> 
             RGBColor[
              0.9937112608695653, 0.988957347826087, 0.5568877391304349], 
             UndirectedEdge[145, 208] -> 
             RGBColor[
              0.9642948043478261, 0.8870861304347827, 0.5174715652173913], 
             UndirectedEdge[75, 133] -> 
             RGBColor[
              0.9152726739130435, 0.7634811304347828, 0.600528652173913], 
             UndirectedEdge[169, 326] -> 
             RGBColor[
              0.9356947173913044, 0.7782312173913045, 0.5444354347826087], 
             UndirectedEdge[95, 97] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[37, 78] -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             UndirectedEdge[55, 397] -> 
             RGBColor[
              0.947458804347826, 0.9569956956521739, 0.8130823478260871], 
             UndirectedEdge[185, 226] -> 
             RGBColor[
              0.976857695652174, 0.9332994347826087, 0.38996052173913043`], 
             UndirectedEdge[39, 254] -> 
             RGBColor[
              0.946240956521739, 0.9594271739130434, 0.9758842173913044], 
             UndirectedEdge[71, 201] -> 
             RGBColor[
              0.9899780869565218, 0.990123695652174, 0.8157525652173914], 
             UndirectedEdge[227, 383] -> 
             RGBColor[
              0.9863322826086957, 0.9674103478260869, 0.5719045434782609], 
             UndirectedEdge[38, 151] -> 
             RGBColor[
              0.9907606304347827, 0.989717652173913, 0.7497462826086958], 
             UndirectedEdge[45, 74] -> 
             RGBColor[
              0.9900356739130435, 0.9881670434782609, 0.6708392391304348], 
             UndirectedEdge[292, 303] -> 
             RGBColor[
              0.9829889347826086, 0.9844021739130435, 0.7844257608695654], 
             UndirectedEdge[185, 357] -> 
             RGBColor[
              0.875593847826087, 0.899219347826087, 0.7272573913043477], 
             UndirectedEdge[86, 376] -> 
             RGBColor[
              0.9172722826086956, 0.9329257826086956, 0.8102031304347828], 
             UndirectedEdge[212, 309] -> 
             RGBColor[
              0.8185345652173912, 0.8584653913043478, 0.9501769782608696], 
             UndirectedEdge[50, 127] -> 
             RGBColor[
              0.9058776086956521, 0.5623174782608695, 0.40000639130434795`], 
             UndirectedEdge[92, 374] -> 
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652], 
             UndirectedEdge[118, 141] -> 
             RGBColor[
              0.9467338478260869, 0.9554450869565217, 0.734175304347826], 
             UndirectedEdge[205, 390] -> 
             RGBColor[
              0.9180999347826087, 0.8531678260869566, 0.628752847826087]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.9357184782608696, 0.7828522173913045, 0.2671357826086957], 
             316 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             308 -> RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 160 -> 
             RGBColor[
              0.8603972608695653, 0.45897839130434787`, 0.20522439130434783`],
              245 -> RGBColor[
              0.946240956521739, 0.9594271739130434, 0.9758842173913044], 155 -> 
             RGBColor[
              0.840108347826087, 0.8753436086956522, 0.9846114782608696], 213 -> 
             RGBColor[
              0.6655274782608696, 0.7386343913043478, 0.9672972173913044], 
             352 -> RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 27 -> 
             RGBColor[
              0.9797934347826087, 0.9435006521739131, 0.3760017391304348], 
             367 -> RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 19 -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             164 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             190 -> RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             103 -> RGBColor[
              0.9357184782608696, 0.7828522173913045, 0.2671357826086957], 
             138 -> RGBColor[
              0.6655274782608696, 0.7386343913043478, 0.9672972173913044], 
             291 -> RGBColor[
              0.8843043913043479, 0.5675350869565221, 0.2251730869565218], 28 -> 
             RGBColor[
              0.9797934347826087, 0.9435006521739131, 0.3760017391304348], 
             337 -> RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             195 -> RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             114 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 93 -> 
             RGBColor[
              0.3904606086956522, 0.5126190869565217, 0.9461007826086957], 34 -> 
             RGBColor[
              0.9004813913043477, 0.9234834347826086, 0.9903699130434782], 
             161 -> RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 22 -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             124 -> RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             84 -> RGBColor[
              0.9607290869565218, 0.8791921304347826, 0.30194034782608703`], 
             46 -> RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 241 -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             185 -> RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             390 -> RGBColor[
              0.9357184782608696, 0.7828522173913045, 0.2671357826086957], 
             121 -> RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             322 -> RGBColor[
              0.9797934347826087, 0.9435006521739131, 0.3760017391304348], 
             126 -> RGBColor[
              0.946240956521739, 0.9594271739130434, 0.9758842173913044], 236 -> 
             RGBColor[
              0.9004813913043477, 0.9234834347826086, 0.9903699130434782], 78 -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             376 -> RGBColor[
              0.840108347826087, 0.8753436086956522, 0.9846114782608696], 254 -> 
             RGBColor[
              0.946240956521739, 0.9594271739130434, 0.9758842173913044], 290 -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             251 -> RGBColor[
              0.3904606086956522, 0.5126190869565217, 0.9461007826086957], 
             165 -> RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 100 -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             235 -> RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 70 -> 
             RGBColor[
              0.8843043913043479, 0.5675350869565221, 0.2251730869565218], 
             234 -> RGBColor[
              0.9357184782608696, 0.7828522173913045, 0.2671357826086957], 
             257 -> RGBColor[
              0.840108347826087, 0.8753436086956522, 0.9846114782608696], 135 -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             265 -> RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 111 -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             381 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             182 -> RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             188 -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             154 -> RGBColor[
              0.6655274782608696, 0.7386343913043478, 0.9672972173913044], 
             336 -> RGBColor[
              0.7582013913043478, 0.8110319565217391, 0.9765340869565218], 
             315 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             368 -> RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 269 -> 
             RGBColor[
              0.46975634782608694`, 0.5804083913043478, 0.9514000869565218], 
             208 -> RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 86 -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             119 -> RGBColor[
              0.840108347826087, 0.8753436086956522, 0.9846114782608696], 377 -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             140 -> RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 85 -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             351 -> RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             242 -> RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             117 -> RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             47 -> RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 81 -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             275 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 23 -> 
             RGBColor[
              0.9607290869565218, 0.8791921304347826, 0.30194034782608703`], 
             328 -> RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             110 -> RGBColor[
              0.9004813913043477, 0.9234834347826086, 0.9903699130434782], 6 -> 
             RGBColor[
              0.9087257826086957, 0.6758351739130438, 0.24541682608695659`], 
             218 -> RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             108 -> RGBColor[
              0.6655274782608696, 0.7386343913043478, 0.9672972173913044], 
             297 -> RGBColor[
              0.840108347826087, 0.8753436086956522, 0.9846114782608696], 157 -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             354 -> RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             385 -> RGBColor[
              0.9607290869565218, 0.8791921304347826, 0.30194034782608703`], 
             270 -> RGBColor[
              0.840108347826087, 0.8753436086956522, 0.9846114782608696], 392 -> 
             RGBColor[
              0.9797934347826087, 0.9435006521739131, 0.3760017391304348], 33 -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             252 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             394 -> RGBColor[
              0.7582013913043478, 0.8110319565217391, 0.9765340869565218], 
             260 -> RGBColor[
              0.8843043913043479, 0.5675350869565221, 0.2251730869565218], 
             159 -> RGBColor[
              0.9004813913043477, 0.9234834347826086, 0.9903699130434782], 
             183 -> RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 99 -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             329 -> RGBColor[
              0.7582013913043478, 0.8110319565217391, 0.9765340869565218], 
             309 -> RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 17 -> 
             RGBColor[
              0.7582013913043478, 0.8110319565217391, 0.9765340869565218], 
             349 -> RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             347 -> RGBColor[
              0.5683864347826086, 0.6604807391304347, 0.9591646086956521], 
             340 -> RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             277 -> RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             104 -> RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             79 -> RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             327 -> RGBColor[
              0.9004813913043477, 0.9234834347826086, 0.9903699130434782], 
             191 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 50 -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             225 -> RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 61 -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             196 -> RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 1 -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             263 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             201 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             371 -> RGBColor[
              0.840108347826087, 0.8753436086956522, 0.9846114782608696], 293 -> 
             RGBColor[
              0.840108347826087, 0.8753436086956522, 0.9846114782608696], 362 -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             184 -> RGBColor[
              0.9004813913043477, 0.9234834347826086, 0.9903699130434782], 
             106 -> RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 206 -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             358 -> RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             247 -> RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             220 -> RGBColor[
              0.9004813913043477, 0.9234834347826086, 0.9903699130434782], 
             107 -> RGBColor[
              0.9797934347826087, 0.9435006521739131, 0.3760017391304348], 
             375 -> RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 131 -> 
             RGBColor[
              0.946240956521739, 0.9594271739130434, 0.9758842173913044], 127 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 210 -> 
             RGBColor[
              0.9797934347826087, 0.9435006521739131, 0.3760017391304348], 
             357 -> RGBColor[
              0.7582013913043478, 0.8110319565217391, 0.9765340869565218], 
             181 -> RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             194 -> RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             118 -> RGBColor[
              0.9004813913043477, 0.9234834347826086, 0.9903699130434782], 
             348 -> 
             RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 276 -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             305 -> RGBColor[
              0.946240956521739, 0.9594271739130434, 0.9758842173913044], 343 -> 
             RGBColor[
              0.840108347826087, 0.8753436086956522, 0.9846114782608696], 280 -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             189 -> RGBColor[
              0.840108347826087, 0.8753436086956522, 0.9846114782608696], 168 -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             363 -> RGBColor[
              0.946240956521739, 0.9594271739130434, 0.9758842173913044], 41 -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 14 -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 77 -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             51 -> RGBColor[
              0.9607290869565218, 0.8791921304347826, 0.30194034782608703`], 
             179 -> RGBColor[
              0.5683864347826086, 0.6604807391304347, 0.9591646086956521], 
             223 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             323 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             292 -> RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 396 -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             321 -> RGBColor[
              0.946240956521739, 0.9594271739130434, 0.9758842173913044], 143 -> 
             RGBColor[
              0.9607290869565218, 0.8791921304347826, 0.30194034782608703`], 
             112 -> RGBColor[
              0.9607290869565218, 0.8791921304347826, 0.30194034782608703`], 
             197 -> RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             54 -> RGBColor[
              0.9004813913043477, 0.9234834347826086, 0.9903699130434782], 71 -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             177 -> RGBColor[
              0.840108347826087, 0.8753436086956522, 0.9846114782608696], 158 -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             226 -> RGBColor[
              0.9607290869565218, 0.8791921304347826, 0.30194034782608703`], 
             350 -> RGBColor[
              0.946240956521739, 0.9594271739130434, 0.9758842173913044], 203 -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             115 -> RGBColor[
              0.840108347826087, 0.8753436086956522, 0.9846114782608696], 173 -> 
             RGBColor[
              0.9004813913043477, 0.9234834347826086, 0.9903699130434782], 
             212 -> RGBColor[
              0.6655274782608696, 0.7386343913043478, 0.9672972173913044], 
             129 -> RGBColor[
              0.9797934347826087, 0.9435006521739131, 0.3760017391304348], 
             279 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 26 -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 40 -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             146 -> RGBColor[
              0.9607290869565218, 0.8791921304347826, 0.30194034782608703`], 
             386 -> RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             192 -> RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             300 -> RGBColor[
              0.9357184782608696, 0.7828522173913045, 0.2671357826086957], 
             221 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 62 -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             286 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             152 -> RGBColor[
              0.946240956521739, 0.9594271739130434, 0.9758842173913044], 64 -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             307 -> RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 37 -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             148 -> RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             261 -> RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             387 -> RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 15 -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             136 -> RGBColor[
              0.7582013913043478, 0.8110319565217391, 0.9765340869565218], 
             198 -> RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 63 -> 
             RGBColor[
              0.9797934347826087, 0.9435006521739131, 0.3760017391304348], 
             310 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             171 -> RGBColor[
              0.9797934347826087, 0.9435006521739131, 0.3760017391304348], 
             395 -> RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             311 -> RGBColor[
              0.840108347826087, 0.8753436086956522, 0.9846114782608696], 353 -> 
             RGBColor[
              0.9004813913043477, 0.9234834347826086, 0.9903699130434782], 59 -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             397 -> RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             229 -> RGBColor[
              0.9004813913043477, 0.9234834347826086, 0.9903699130434782], 
             102 -> RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 299 -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             128 -> RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             12 -> RGBColor[
              0.7582013913043478, 0.8110319565217391, 0.9765340869565218], 
             222 -> RGBColor[
              0.946240956521739, 0.9594271739130434, 0.9758842173913044], 92 -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             271 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             361 -> RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             344 -> RGBColor[
              0.6655274782608696, 0.7386343913043478, 0.9672972173913044], 
             132 -> RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 80 -> 
             RGBColor[
              0.946240956521739, 0.9594271739130434, 0.9758842173913044], 324 -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             244 -> 
             RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 150 -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             125 -> RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             258 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             133 -> RGBColor[
              0.946240956521739, 0.9594271739130434, 0.9758842173913044], 255 -> 
             RGBColor[
              0.9357184782608696, 0.7828522173913045, 0.2671357826086957], 
             326 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             176 -> RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             230 -> RGBColor[
              0.9004813913043477, 0.9234834347826086, 0.9903699130434782], 
             274 -> RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             87 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             130 -> RGBColor[
              0.840108347826087, 0.8753436086956522, 0.9846114782608696], 35 -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             379 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 31 -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 18 -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 24 -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             151 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             137 -> RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             330 -> RGBColor[
              0.9004813913043477, 0.9234834347826086, 0.9903699130434782], 
             296 -> RGBColor[
              0.9607290869565218, 0.8791921304347826, 0.30194034782608703`], 
             266 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             302 -> RGBColor[
              0.9607290869565218, 0.8791921304347826, 0.30194034782608703`], 
             283 -> RGBColor[
              0.9357184782608696, 0.7828522173913045, 0.2671357826086957], 
             388 -> RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             284 -> RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 318 -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             238 -> RGBColor[
              0.9797934347826087, 0.9435006521739131, 0.3760017391304348], 72 -> 
             RGBColor[
              0.946240956521739, 0.9594271739130434, 0.9758842173913044], 288 -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             382 -> RGBColor[
              0.946240956521739, 0.9594271739130434, 0.9758842173913044], 389 -> 
             RGBColor[
              0.5683864347826086, 0.6604807391304347, 0.9591646086956521], 
             172 -> RGBColor[
              0.5683864347826086, 0.6604807391304347, 0.9591646086956521], 
             243 -> RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 88 -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             273 -> RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 202 -> 
             RGBColor[
              0.9004813913043477, 0.9234834347826086, 0.9903699130434782], 
             393 -> RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             98 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 30 -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             116 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             373 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             240 -> RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             317 -> RGBColor[
              0.9004813913043477, 0.9234834347826086, 0.9903699130434782], 
             391 -> RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 73 -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             303 -> RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 29 -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             360 -> RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             320 -> 
             RGBColor[
              0.8603972608695653, 0.45897839130434787`, 0.20522439130434783`],
              75 -> RGBColor[
              0.8843043913043479, 0.5675350869565221, 0.2251730869565218], 
             200 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             301 -> RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             156 -> RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 25 -> 
             RGBColor[
              0.9357184782608696, 0.7828522173913045, 0.2671357826086957], 38 -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             365 -> RGBColor[0.817319, 0.134127, 0.164218], 380 -> 
             RGBColor[
              0.946240956521739, 0.9594271739130434, 0.9758842173913044], 370 -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             3 -> RGBColor[
              0.9797934347826087, 0.9435006521739131, 0.3760017391304348], 57 -> 
             RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 227 -> 
             RGBColor[
              0.9797934347826087, 0.9435006521739131, 0.3760017391304348], 39 -> 
             RGBColor[
              0.946240956521739, 0.9594271739130434, 0.9758842173913044], 109 -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             256 -> RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             339 -> RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 287 -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             239 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             285 -> RGBColor[
              0.946240956521739, 0.9594271739130434, 0.9758842173913044], 345 -> 
             RGBColor[
              0.946240956521739, 0.9594271739130434, 0.9758842173913044], 366 -> 
             RGBColor[
              0.9797934347826087, 0.9435006521739131, 0.3760017391304348], 
             216 -> RGBColor[
              0.7582013913043478, 0.8110319565217391, 0.9765340869565218], 21 -> 
             RGBColor[
              0.840108347826087, 0.8753436086956522, 0.9846114782608696], 355 -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             175 -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 7 -> 
             RGBColor[
              0.9357184782608696, 0.7828522173913045, 0.2671357826086957], 13 -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             294 -> RGBColor[
              0.9004813913043477, 0.9234834347826086, 0.9903699130434782], 
             193 -> RGBColor[
              0.946240956521739, 0.9594271739130434, 0.9758842173913044], 60 -> 
             RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 65 -> 
             RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 69 -> 
             RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 217 -> 
             RGBColor[
              0.840108347826087, 0.8753436086956522, 0.9846114782608696], 214 -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             170 -> RGBColor[
              0.9797934347826087, 0.9435006521739131, 0.3760017391304348], 
             359 -> RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 74 -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             246 -> RGBColor[
              0.9607290869565218, 0.8791921304347826, 0.30194034782608703`], 
             264 -> RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 278 -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             45 -> RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             306 -> RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             237 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             228 -> RGBColor[
              0.946240956521739, 0.9594271739130434, 0.9758842173913044], 180 -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             383 -> RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 53 -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             304 -> RGBColor[
              0.46975634782608694`, 0.5804083913043478, 0.9514000869565218], 
             48 -> RGBColor[
              0.5683864347826086, 0.6604807391304347, 0.9591646086956521], 5 -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             101 -> RGBColor[
              0.9797934347826087, 0.9435006521739131, 0.3760017391304348], 
             333 -> RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             267 -> RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             120 -> RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             147 -> RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             89 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 43 -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             199 -> RGBColor[
              0.6655274782608696, 0.7386343913043478, 0.9672972173913044], 
             268 -> RGBColor[0.178927, 0.305394, 0.933501], 169 -> 
             RGBColor[
              0.8843043913043479, 0.5675350869565221, 0.2251730869565218], 20 -> 
             RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 4 -> 
             RGBColor[
              0.9004813913043477, 0.9234834347826086, 0.9903699130434782], 
             167 -> RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             142 -> RGBColor[
              0.8843043913043479, 0.5675350869565221, 0.2251730869565218], 16 -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             281 -> RGBColor[
              0.9607290869565218, 0.8791921304347826, 0.30194034782608703`], 
             289 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             398 -> RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             178 -> RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 58 -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             186 -> RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             122 -> RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             249 -> RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             113 -> 
             RGBColor[
              0.9087257826086957, 0.6758351739130438, 0.24541682608695659`], 
             52 -> RGBColor[
              0.9004813913043477, 0.9234834347826086, 0.9903699130434782], 
             187 -> RGBColor[
              0.9004813913043477, 0.9234834347826086, 0.9903699130434782], 
             259 -> RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             42 -> RGBColor[
              0.9004813913043477, 0.9234834347826086, 0.9903699130434782], 
             134 -> RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             313 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             248 -> RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             174 -> RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             215 -> RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             399 -> RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 83 -> 
             RGBColor[
              0.9004813913043477, 0.9234834347826086, 0.9903699130434782], 95 -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             166 -> RGBColor[
              0.46975634782608694`, 0.5804083913043478, 0.9514000869565218], 
             384 -> RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             233 -> RGBColor[
              0.8843043913043479, 0.5675350869565221, 0.2251730869565218], 
             295 -> RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             141 -> RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             319 -> RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             205 -> RGBColor[
              0.9004813913043477, 0.9234834347826086, 0.9903699130434782], 
             224 -> RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             231 -> RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             332 -> RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 68 -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 10 -> 
             RGBColor[
              0.6655274782608696, 0.7386343913043478, 0.9672972173913044], 
             250 -> RGBColor[
              0.9797934347826087, 0.9435006521739131, 0.3760017391304348], 
             282 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             374 -> RGBColor[
              0.9797934347826087, 0.9435006521739131, 0.3760017391304348], 
             232 -> RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             253 -> RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 55 -> 
             RGBColor[
              0.9004813913043477, 0.9234834347826086, 0.9903699130434782], 
             325 -> RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 91 -> 
             RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             105 -> RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 36 -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             123 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 94 -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             312 -> RGBColor[
              0.5683864347826086, 0.6604807391304347, 0.9591646086956521], 96 -> 
             RGBColor[
              0.9607290869565218, 0.8791921304347826, 0.30194034782608703`], 
             2 -> RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             262 -> RGBColor[
              0.9607290869565218, 0.8791921304347826, 0.30194034782608703`], 
             272 -> RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 97 -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             372 -> RGBColor[
              0.6655274782608696, 0.7386343913043478, 0.9672972173913044], 
             356 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             346 -> RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             341 -> RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             209 -> RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             378 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 66 -> 
             RGBColor[
              0.9357184782608696, 0.7828522173913045, 0.2671357826086957], 
             139 -> RGBColor[
              0.9607290869565218, 0.8791921304347826, 0.30194034782608703`], 
             56 -> RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             335 -> RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 
             314 -> RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 144 -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             298 -> RGBColor[
              0.9797934347826087, 0.9435006521739131, 0.3760017391304348], 
             204 -> RGBColor[
              0.9797934347826087, 0.9435006521739131, 0.3760017391304348], 
             207 -> RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 334 -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             149 -> RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 
             219 -> RGBColor[
              0.946240956521739, 0.9594271739130434, 0.9758842173913044], 400 -> 
             RGBColor[
              0.946240956521739, 0.9594271739130434, 0.9758842173913044], 9 -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 11 -> 
             RGBColor[
              0.9357184782608696, 0.7828522173913045, 0.2671357826086957], 44 -> 
             RGBColor[
              0.9797934347826087, 0.9435006521739131, 0.3760017391304348], 
             153 -> RGBColor[
              0.9944362173913044, 0.9905079565217392, 0.6357947826086959], 32 -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             162 -> RGBColor[
              0.9607290869565218, 0.8791921304347826, 0.30194034782608703`], 
             90 -> RGBColor[
              0.9087257826086957, 0.6758351739130438, 0.24541682608695659`], 
             331 -> RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 8 -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 
             364 -> RGBColor[
              0.46975634782608694`, 0.5804083913043478, 0.9514000869565218], 
             342 -> RGBColor[
              0.9607290869565218, 0.8791921304347826, 0.30194034782608703`], 
             163 -> 
             RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 49 -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             338 -> RGBColor[
              0.9870850434782609, 0.9889273478260869, 0.8636977826086957], 76 -> 
             RGBColor[
              0.971541652173913, 0.9782963913043479, 0.9330567391304349], 369 -> 
             RGBColor[
              0.9928711304347826, 0.9913200434782609, 0.7678073478260871], 82 -> 
             RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             67 -> RGBColor[
              0.9929863043478261, 0.9874067391304349, 0.47798069565217377`], 
             211 -> RGBColor[
              0.9607290869565218, 0.8791921304347826, 
               0.30194034782608703`]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9mGk41G3YxiVbGGbGGGMMZp+JsVWihTktLbQQJSTFQyShTSoPqYhQlpJK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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 5}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 73}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[0.951581, 0.8331715652173914, 0.44060580434782626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 162}], {
             RGBColor[
             0.977582652173913, 0.934850043478261, 0.4688675652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 183}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 291}], {
             RGBColor[
             0.9393703043478261, 0.7790215217391306, 0.4304839347826089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 357}], {
             RGBColor[
             0.876318804347826, 0.9007699565217391, 0.8061644347826089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 368}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 387}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 28}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 39}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 50}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 106}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 137}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 138}], {
             RGBColor[
             0.829981847826087, 0.8645711739130435, 0.8015460000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 149}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 164}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 197}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 210}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 217}], {
             RGBColor[
             0.9172722826086956, 0.9329257826086956, 0.8102031304347828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 230}], {
             RGBColor[
             0.947458804347826, 0.9569956956521739, 0.8130823478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 254}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 258}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 314}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 328}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 7}], {
             RGBColor[
             0.9577559565217392, 0.8631764347826087, 0.3215687608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 13}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 14}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 21}], {
             RGBColor[
             0.9099508913043479, 0.9094221304347827, 0.6803066086956522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 51}], {
             RGBColor[
             0.9702612608695653, 0.9113463913043478, 0.3389710434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 79}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 188}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 232}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 293}], {
             RGBColor[
             0.9099508913043479, 0.9094221304347827, 0.6803066086956522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 373}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 390}], {
             RGBColor[
             0.9577559565217392, 0.8631764347826087, 0.3215687608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 84}], {
             RGBColor[
             0.9306052391304347, 0.9013377826086957, 0.6461551304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 125}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 165}], {
             RGBColor[
             0.9360115217391303, 0.9508899130434783, 0.9617133260869566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 184}], {
             RGBColor[
             0.9004813913043477, 0.9234834347826086, 0.9903699130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 185}], {
             RGBColor[
             0.9467338478260869, 0.9554450869565217, 0.734175304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 190}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.9306052391304347, 0.9013377826086957, 0.6461551304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 252}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 274}], {
             RGBColor[
             0.9467338478260869, 0.9554450869565217, 0.734175304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 288}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 318}], {
             RGBColor[
             0.9467338478260869, 0.9554450869565217, 0.734175304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 113}], {
             RGBColor[0.951581, 0.8331715652173914, 0.44060580434782626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 162}], {
             RGBColor[
             0.977582652173913, 0.934850043478261, 0.4688675652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 183}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 270}], {
             RGBColor[
             0.9172722826086956, 0.9329257826086956, 0.8102031304347828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 291}], {
             RGBColor[
             0.9393703043478261, 0.7790215217391306, 0.4304839347826089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 357}], {
             RGBColor[
             0.876318804347826, 0.9007699565217391, 0.8061644347826089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 368}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 10}], {
             RGBColor[
             0.7871266304347826, 0.7072347826086958, 0.6063570217391305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.9479054130434783, 0.8323812608695653, 0.5545573043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 69}], {
             RGBColor[
             0.9401337173913044, 0.8270657826086958, 0.5892367826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 71}], {
             RGBColor[
             0.9507984565217391, 0.8335776086956523, 0.5066120869565218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 93}], {
             RGBColor[
             0.649593195652174, 0.5942271304347828, 0.5957588043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 129}], {
             RGBColor[
             0.9442596086956523, 0.8096679130434785, 0.3107092826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 131}], {
             RGBColor[
             0.9274833695652174, 0.8176311739130436, 0.6106505217391305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 142}], {
             RGBColor[
             0.8965150869565218, 0.621685130434783, 0.2352949565217392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 201}], {
             RGBColor[
             0.9479054130434783, 0.8323812608695653, 0.5545573043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 253}], {
             RGBColor[0.951581, 0.8331715652173914, 0.44060580434782626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 273}], {
             RGBColor[
             0.9401337173913044, 0.8270657826086958, 0.5892367826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 281}], {
             RGBColor[
             0.9347274347826088, 0.7775136521739132, 0.2736785869565218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 303}], {
             RGBColor[0.951581, 0.8331715652173914, 0.44060580434782626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 364}], {
             RGBColor[
             0.6892410652173914, 0.6281217826086958, 0.5984084565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 391}], {
             RGBColor[0.951581, 0.8331715652173914, 0.44060580434782626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 394}], {
             RGBColor[
             0.8334635869565218, 0.7434335652173915, 0.6109754565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 13}], {
             RGBColor[
             0.9614017608695653, 0.8858897826086958, 0.5654167826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 14}], {
             RGBColor[
             0.9642948043478261, 0.8870861304347827, 0.5174715652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 21}], {
             RGBColor[
             0.8879134130434783, 0.8290979130434784, 0.6258736304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 93}], {
             RGBColor[
             0.6630895434782609, 0.647735652173913, 0.6066182826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 142}], {
             RGBColor[
             0.9100114347826087, 0.6751936521739133, 0.24615443478260873`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 188}], {
             RGBColor[
             0.9642948043478261, 0.8870861304347827, 0.5174715652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 273}], {
             RGBColor[
             0.9536300652173912, 0.8805743043478262, 0.6000962608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 293}], {
             RGBColor[
             0.8879134130434783, 0.8290979130434784, 0.6258736304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 390}], {
             RGBColor[
             0.9357184782608696, 0.7828522173913045, 0.2671357826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 16}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 25}], {
             RGBColor[
             0.9614017608695653, 0.8858897826086958, 0.5654167826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 76}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 117}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 202}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 234}], {
             RGBColor[
             0.9614017608695653, 0.8858897826086958, 0.5654167826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 239}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 269}], {
             RGBColor[
             0.7284206956521739, 0.7846678695652174, 0.9075489347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 302}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 323}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 365}], {
             RGBColor[
             0.9022020217391304, 0.5615271739130434, 0.5139578913043479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 377}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 388}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 18}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 56}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 65}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 100}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 174}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 198}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 203}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 266}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 313}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 339}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 358}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 384}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 32}], {
             RGBColor[
             0.8263062608695653, 0.8637808695652174, 0.9154975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 52}], {
             RGBColor[
             0.7830044347826086, 0.8310589130434782, 0.9788335652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 60}], {
             RGBColor[
             0.8185345652173912, 0.8584653913043478, 0.9501769782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 68}], {
             RGBColor[
             0.829981847826087, 0.8645711739130435, 0.8015460000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.8226604565217391, 0.8410675217391305, 0.6716494782608695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 253}], {
             RGBColor[
             0.829981847826087, 0.8645711739130435, 0.8015460000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 271}], {
             RGBColor[
             0.8263062608695653, 0.8637808695652174, 0.9154975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 303}], {
             RGBColor[
             0.829981847826087, 0.8645711739130435, 0.8015460000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 333}], {
             RGBColor[
             0.8291993043478261, 0.8649772173913044, 0.8675522826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 334}], {
             RGBColor[
             0.8291993043478261, 0.8649772173913044, 0.8675522826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 337}], {
             RGBColor[
             0.8292568913043479, 0.8630205652173913, 0.722638956521739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 345}], {
             RGBColor[
             0.8058842173913043, 0.8490307826086956, 0.9715907173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 353}], {
             RGBColor[
             0.7830044347826086, 0.8310589130434782, 0.9788335652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 364}], {
             RGBColor[
             0.5676419130434782, 0.6595213913043478, 0.9593486521739131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 391}], {
             RGBColor[
             0.829981847826087, 0.8645711739130435, 0.8015460000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 54}], {
             RGBColor[
             0.9180999347826087, 0.8531678260869566, 0.6287528478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 83}], {
             RGBColor[
             0.9180999347826087, 0.8531678260869566, 0.6287528478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 118}], {
             RGBColor[
             0.9180999347826087, 0.8531678260869566, 0.6287528478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 123}], {
             RGBColor[
             0.9614017608695653, 0.8858897826086958, 0.5654167826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 141}], {
             RGBColor[
             0.9643523913043479, 0.8851294782608696, 0.37255823913043473`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 161}], {
             RGBColor[
             0.9642948043478261, 0.8870861304347827, 0.5174715652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 196}], {
             RGBColor[
             0.9642948043478261, 0.8870861304347827, 0.5174715652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 206}], {
             RGBColor[
             0.9614017608695653, 0.8858897826086958, 0.5654167826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 214}], {
             RGBColor[
             0.9614017608695653, 0.8858897826086958, 0.5654167826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 286}], {
             RGBColor[
             0.9614017608695653, 0.8858897826086958, 0.5654167826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 332}], {
             RGBColor[
             0.9536300652173912, 0.8805743043478262, 0.6000962608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 366}], {
             RGBColor[
             0.9577559565217392, 0.8631764347826087, 0.3215687608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 386}], {
             RGBColor[
             0.9642948043478261, 0.8870861304347827, 0.5174715652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 19}], {
             RGBColor[0.8755362608695652, 0.901176, 0.8721707173913045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 24}], {
             RGBColor[
             0.8726432173913043, 0.899979652173913, 0.9201159347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 65}], {
             RGBColor[
             0.8648715217391304, 0.8946641739130434, 0.9547954130434784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 100}], {
             RGBColor[
             0.8726432173913043, 0.899979652173913, 0.9201159347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 107}], {
             RGBColor[
             0.8689974130434783, 0.8772663043478262, 0.6762679130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 124}], {
             RGBColor[
             0.875593847826087, 0.899219347826087, 0.7272573913043477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 150}], {
             RGBColor[
             0.876318804347826, 0.9007699565217391, 0.8061644347826089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 157}], {
             RGBColor[
             0.875593847826087, 0.899219347826087, 0.7272573913043477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 167}], {
             RGBColor[
             0.876318804347826, 0.9007699565217391, 0.8061644347826089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 168}], {
             RGBColor[
             0.875593847826087, 0.899219347826087, 0.7272573913043477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 203}], {
             RGBColor[0.8755362608695652, 0.901176, 0.8721707173913045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 206}], {
             RGBColor[
             0.8726432173913043, 0.899979652173913, 0.9201159347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 211}], {
             RGBColor[
             0.8594652391304348, 0.8451120434782609, 0.6392372173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 238}], {
             RGBColor[
             0.8689974130434783, 0.8772663043478262, 0.6762679130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 341}], {
             RGBColor[
             0.875593847826087, 0.899219347826087, 0.7272573913043477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 358}], {
             RGBColor[0.8755362608695652, 0.901176, 0.8721707173913045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 14}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 21}], {
             RGBColor[
             0.9135966956521739, 0.9321354782608695, 0.9241546304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 51}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 79}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 87}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 205}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 232}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 277}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 373}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 390}], {
             RGBColor[
             0.9614017608695653, 0.8858897826086958, 0.5654167826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 69}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 71}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 201}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 212}], {
             RGBColor[
             0.8291993043478261, 0.8649772173913044, 0.8675522826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 273}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 289}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 293}], {
             RGBColor[
             0.9164897391304347, 0.9333318260869565, 0.8762094130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 390}], {
             RGBColor[
             0.9642948043478261, 0.8870861304347827, 0.5174715652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 35}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 106}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 154}], {
             RGBColor[
             0.8292568913043479, 0.8630205652173913, 0.722638956521739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 207}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 231}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 369}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 372}], {
             RGBColor[
             0.8292568913043479, 0.8630205652173913, 0.722638956521739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 392}], {
             RGBColor[
             0.9863898695652173, 0.965453695652174, 0.4269912173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 25}], {
             RGBColor[
             0.965077347826087, 0.8866800869565219, 0.4514652826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 37}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 76}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 77}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 78}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 80}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 96}], {
             RGBColor[
             0.977582652173913, 0.934850043478261, 0.4688675652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 182}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.947458804347826, 0.9569956956521739, 0.8130823478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 269}], {
             RGBColor[
             0.7320962826086956, 0.7854581739130435, 0.7935974347826089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 302}], {
             RGBColor[
             0.977582652173913, 0.934850043478261, 0.4688675652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 323}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 365}], {
             RGBColor[
             0.9058776086956521, 0.5623174782608695, 0.40000639130434795`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 377}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 388}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 18}], {
             RGBColor[
             0.876318804347826, 0.9007699565217391, 0.8061644347826089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 31}], {
             RGBColor[0.8755362608695652, 0.901176, 0.8721707173913045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 62}], {
             RGBColor[
             0.876318804347826, 0.9007699565217391, 0.8061644347826089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.875593847826087, 0.899219347826087, 0.7272573913043477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 111}], {
             RGBColor[
             0.8726432173913043, 0.899979652173913, 0.9201159347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 222}], {
             RGBColor[
             0.8522211739130434, 0.8852295652173913, 0.9762091521739131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 223}], {
             RGBColor[
             0.8726432173913043, 0.899979652173913, 0.9201159347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 247}], {
             RGBColor[
             0.876318804347826, 0.9007699565217391, 0.8061644347826089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 256}], {
             RGBColor[
             0.876318804347826, 0.9007699565217391, 0.8061644347826089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 292}], {
             RGBColor[
             0.8648715217391304, 0.8946641739130434, 0.9547954130434784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 310}], {
             RGBColor[
             0.8726432173913043, 0.899979652173913, 0.9201159347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 319}], {
             RGBColor[
             0.876318804347826, 0.9007699565217391, 0.8061644347826089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 384}], {
             RGBColor[0.8755362608695652, 0.901176, 0.8721707173913045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 99}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 144}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 218}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 266}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 310}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 319}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 384}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 24}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 85}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 107}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 124}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 150}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 152}], {
             RGBColor[
             0.9695560434782609, 0.9753736086956522, 0.8718457826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 157}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 160}], {
             RGBColor[
             0.926634195652174, 0.7251492173913043, 0.4865158695652174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 167}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 168}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 181}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 211}], {
             RGBColor[
             0.9768001086956521, 0.9352560869565217, 0.534873847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 238}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 64}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 88}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 89}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 120}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 140}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 189}], {
             RGBColor[0.905825, 0.92682, 0.9588341086956522]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{20, 195}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 241}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 255}], {
             RGBColor[
             0.9536300652173912, 0.8805743043478262, 0.6000962608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 257}], {
             RGBColor[0.905825, 0.92682, 0.9588341086956522]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{20, 263}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 312}], {
             RGBColor[
             0.7699640434782609, 0.8193885652173913, 0.9461106739130435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 336}], {
             RGBColor[
             0.8648715217391304, 0.8946641739130434, 0.9547954130434784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 356}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 359}], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 360}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 389}], {
             RGBColor[
             0.7699640434782609, 0.8193885652173913, 0.9461106739130435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 109}], {
             RGBColor[
             0.9164897391304347, 0.9333318260869565, 0.8762094130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[
             0.9135966956521739, 0.9321354782608695, 0.9241546304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 132}], {
             RGBColor[
             0.9172722826086956, 0.9329257826086956, 0.8102031304347828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 180}], {
             RGBColor[
             0.9165473260869565, 0.9313751739130436, 0.7312960869565217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 232}], {
             RGBColor[
             0.9172722826086956, 0.9329257826086956, 0.8102031304347828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 249}], {
             RGBColor[
             0.9164897391304347, 0.9333318260869565, 0.8762094130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 370}], {
             RGBColor[
             0.9165473260869565, 0.9313751739130436, 0.7312960869565217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 45}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 74}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 116}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 141}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 179}], {
             RGBColor[
             0.7814113260869565, 0.825494347826087, 0.797479695652174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 209}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 286}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 290}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 304}], {
             RGBColor[
             0.7320962826086956, 0.7854581739130435, 0.7935974347826089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 338}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 38}], {
             RGBColor[
             0.977582652173913, 0.934850043478261, 0.4688675652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 92}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 98}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 119}], {
             RGBColor[
             0.9004187173913044, 0.8772678695652174, 0.6432759130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 128}], {
             RGBColor[
             0.976857695652174, 0.9332994347826087, 0.38996052173913043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 130}], {
             RGBColor[
             0.9004187173913044, 0.8772678695652174, 0.6432759130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 139}], {
             RGBColor[
             0.9607290869565218, 0.8791921304347826, 0.30194034782608703`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 143}], {
             RGBColor[
             0.9607290869565218, 0.8791921304347826, 0.30194034782608703`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 146}], {
             RGBColor[
             0.9607290869565218, 0.8791921304347826, 0.30194034782608703`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 151}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 158}], {
             RGBColor[
             0.976857695652174, 0.9332994347826087, 0.38996052173913043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 186}], {
             RGBColor[
             0.977582652173913, 0.934850043478261, 0.4688675652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 213}], {
             RGBColor[
             0.8131282826086956, 0.8089132608695653, 0.6346187826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 267}], {
             RGBColor[
             0.976857695652174, 0.9332994347826087, 0.38996052173913043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 306}], {
             RGBColor[
             0.976857695652174, 0.9332994347826087, 0.38996052173913043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 308}], {
             RGBColor[
             0.9661353695652174, 0.9287442608695653, 0.6174985434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 311}], {
             RGBColor[
             0.9004187173913044, 0.8772678695652174, 0.6432759130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 346}], {
             RGBColor[
             0.976857695652174, 0.9332994347826087, 0.38996052173913043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 348}], {
             RGBColor[
             0.9661353695652174, 0.9287442608695653, 0.6174985434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 354}], {
             RGBColor[
             0.9768001086956521, 0.9352560869565217, 0.534873847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 374}], {
             RGBColor[
             0.9702612608695653, 0.9113463913043478, 0.3389710434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 33}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 56}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 65}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 100}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 107}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 124}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 150}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 157}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 167}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 168}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 203}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 206}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 211}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 238}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 341}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 358}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 386}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 37}], {
             RGBColor[
             0.9614017608695653, 0.8858897826086958, 0.5654167826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 62}], {
             RGBColor[
             0.965077347826087, 0.8866800869565219, 0.4514652826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[
             0.9536300652173912, 0.8805743043478262, 0.6000962608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 78}], {
             RGBColor[
             0.9614017608695653, 0.8858897826086958, 0.5654167826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 91}], {
             RGBColor[
             0.965077347826087, 0.8866800869565219, 0.4514652826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 117}], {
             RGBColor[
             0.9643523913043479, 0.8851294782608696, 0.37255823913043473`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 182}], {
             RGBColor[
             0.9643523913043479, 0.8851294782608696, 0.37255823913043473`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 187}], {
             RGBColor[
             0.9180999347826087, 0.8531678260869566, 0.6287528478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 208}], {
             RGBColor[
             0.9642948043478261, 0.8870861304347827, 0.5174715652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 239}], {
             RGBColor[
             0.9614017608695653, 0.8858897826086958, 0.5654167826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 269}], {
             RGBColor[
             0.7027374130434783, 0.6816303043478262, 0.6092679347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 309}], {
             RGBColor[
             0.9536300652173912, 0.8805743043478262, 0.6000962608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 323}], {
             RGBColor[
             0.9614017608695653, 0.8858897826086958, 0.5654167826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 362}], {
             RGBColor[
             0.9614017608695653, 0.8858897826086958, 0.5654167826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 365}], {
             RGBColor[
             0.8765187391304348, 0.45848960869565225`, 0.21567689130434786`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 377}], {
             RGBColor[
             0.965077347826087, 0.8866800869565219, 0.4514652826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 388}], {
             RGBColor[
             0.965077347826087, 0.8866800869565219, 0.4514652826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 395}], {
             RGBColor[
             0.9642948043478261, 0.8870861304347827, 0.5174715652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 70}], {
             RGBColor[
             0.9385877608695652, 0.7794275652173914, 0.49649021739130444`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 177}], {
             RGBColor[
             0.9164897391304347, 0.9333318260869565, 0.8762094130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 285}], {
             RGBColor[
             0.9695560434782609, 0.9753736086956522, 0.8718457826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 324}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 40}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 41}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 48}], {
             RGBColor[
             0.7740899347826087, 0.8019906956521738, 0.6675831739130434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 63}], {
             RGBColor[
             0.9797934347826087, 0.9435006521739131, 0.3760017391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 86}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 250}], {
             RGBColor[
             0.9797934347826087, 0.9435006521739131, 0.3760017391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 265}], {
             RGBColor[
             0.9756675434782609, 0.9608985217391305, 0.6545292391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 295}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 325}], {
             RGBColor[
             0.9756675434782609, 0.9608985217391305, 0.6545292391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 376}], {
             RGBColor[
             0.9099508913043479, 0.9094221304347827, 0.6803066086956522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 39}], {
             RGBColor[
             0.9630171956521738, 0.9514639130434783, 0.6759429782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 50}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 106}], {
             RGBColor[
             0.9756675434782609, 0.9608985217391305, 0.6545292391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 197}], {
             RGBColor[
             0.9863898695652173, 0.965453695652174, 0.4269912173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 217}], {
             RGBColor[
             0.9099508913043479, 0.9094221304347827, 0.6803066086956522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 231}], {
             RGBColor[
             0.9863898695652173, 0.965453695652174, 0.4269912173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 254}], {
             RGBColor[
             0.9630171956521738, 0.9514639130434783, 0.6759429782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 314}], {
             RGBColor[
             0.9756675434782609, 0.9608985217391305, 0.6545292391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 369}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 113}], {
             RGBColor[
             0.9508560434782609, 0.8316209565217394, 0.3616987608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 162}], {
             RGBColor[
             0.976857695652174, 0.9332994347826087, 0.38996052173913043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 183}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 270}], {
             RGBColor[
             0.9165473260869565, 0.9313751739130436, 0.7312960869565217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 357}], {
             RGBColor[
             0.875593847826087, 0.899219347826087, 0.7272573913043477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 153}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 168}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 175}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 211}], {
             RGBColor[
             0.976857695652174, 0.9332994347826087, 0.38996052173913043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 216}], {
             RGBColor[
             0.875593847826087, 0.899219347826087, 0.7272573913043477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 229}], {
             RGBColor[
             0.9467338478260869, 0.9554450869565217, 0.7341753043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 294}], {
             RGBColor[
             0.9467338478260869, 0.9554450869565217, 0.7341753043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 329}], {
             RGBColor[
             0.875593847826087, 0.899219347826087, 0.7272573913043477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 341}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 343}], {
             RGBColor[
             0.9165473260869565, 0.9313751739130436, 0.7312960869565217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 358}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 379}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 99}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 111}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 169}], {
             RGBColor[
             0.9385877608695652, 0.7794275652173914, 0.49649021739130444`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 199}], {
             RGBColor[
             0.8291993043478261, 0.8649772173913044, 0.8675522826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 215}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 222}], {
             RGBColor[
             0.9695560434782609, 0.9753736086956522, 0.8718457826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 223}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 224}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 247}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 259}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 292}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 363}], {
             RGBColor[
             0.9695560434782609, 0.9753736086956522, 0.8718457826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 383}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 393}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 400}], {
             RGBColor[
             0.9695560434782609, 0.9753736086956522, 0.8718457826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 46}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 52}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 71}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 105}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 111}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 129}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 199}], {
             RGBColor[
             0.8263062608695653, 0.8637808695652174, 0.9154975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 215}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 247}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 259}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 271}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 287}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 292}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 303}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 333}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 337}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 345}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 353}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 385}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 391}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 400}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 58}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 74}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 107}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 116}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 118}], {
             RGBColor[
             0.947458804347826, 0.9569956956521739, 0.8130823478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 124}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 141}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 150}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 152}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 156}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 157}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 179}], {
             RGBColor[
             0.7814113260869565, 0.825494347826087, 0.797479695652174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 206}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 209}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 245}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 286}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 386}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 43}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 159}], {
             RGBColor[
             0.9004813913043477, 0.9234834347826086, 0.9903699130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 250}], {
             RGBColor[
             0.9401374130434782, 0.9334920434782609, 0.6831858260869565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 265}], {
             RGBColor[
             0.9360115217391303, 0.9508899130434783, 0.9617133260869566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 321}], {
             RGBColor[
             0.9233611739130434, 0.941455304347826, 0.9831270652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 375}], {
             RGBColor[
             0.9360115217391303, 0.9508899130434783, 0.9617133260869566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 381}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 73}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 154}], {
             RGBColor[
             0.8291993043478261, 0.8649772173913044, 0.8675522826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 207}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 231}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 280}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 291}], {
             RGBColor[
             0.9385877608695652, 0.7794275652173914, 0.49649021739130444`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 372}], {
             RGBColor[
             0.8291993043478261, 0.8649772173913044, 0.8675522826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 387}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 392}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 61}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 70}], {
             RGBColor[
             0.9356947173913044, 0.7782312173913045, 0.5444354347826088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 90}], {
             RGBColor[
             0.9479054130434783, 0.8323812608695653, 0.5545573043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 95}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 148}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 228}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 276}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 282}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 301}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 305}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 361}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 382}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 76}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 78}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 80}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 96}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 104}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 117}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 145}], {
             RGBColor[
             0.9614017608695653, 0.8858897826086958, 0.5654167826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 182}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 187}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 208}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 269}], {
             RGBColor[
             0.7284206956521739, 0.7846678695652174, 0.9075489347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 323}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 365}], {
             RGBColor[
             0.9022020217391304, 0.5615271739130434, 0.5139578913043479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 377}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 388}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 395}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 44}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 66}], {
             RGBColor[
             0.965077347826087, 0.8866800869565219, 0.4514652826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 81}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 119}], {
             RGBColor[
             0.9172722826086956, 0.9329257826086956, 0.8102031304347828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 128}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 130}], {
             RGBColor[
             0.9172722826086956, 0.9329257826086956, 0.8102031304347828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 135}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 146}], {
             RGBColor[
             0.977582652173913, 0.934850043478261, 0.4688675652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 151}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 213}], {
             RGBColor[
             0.829981847826087, 0.8645711739130435, 0.8015460000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 224}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 227}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 243}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 267}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 306}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 311}], {
             RGBColor[
             0.9172722826086956, 0.9329257826086956, 0.8102031304347828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 346}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 350}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 363}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 383}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 47}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 50}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 136}], {
             RGBColor[
             0.8522211739130434, 0.8852295652173913, 0.9762091521739131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 149}], {
             RGBColor[
             0.9695560434782609, 0.9753736086956522, 0.8718457826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 164}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 197}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 210}], {
             RGBColor[
             0.9630171956521738, 0.9514639130434783, 0.6759429782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 217}], {
             RGBColor[
             0.893174652173913, 0.9173853913043478, 0.980247847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 230}], {
             RGBColor[
             0.9233611739130434, 0.941455304347826, 0.9831270652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 254}], {
             RGBColor[
             0.946240956521739, 0.9594271739130434, 0.9758842173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 258}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 314}], {
             RGBColor[
             0.958891304347826, 0.9688617826086956, 0.9544704782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 328}], {
             RGBColor[
             0.9695560434782609, 0.9753736086956522, 0.8718457826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 41}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 48}], {
             RGBColor[
             0.7814113260869565, 0.825494347826087, 0.797479695652174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 63}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 103}], {
             RGBColor[
             0.965077347826087, 0.8866800869565219, 0.4514652826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 265}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 295}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 48}], {
             RGBColor[
             0.7814113260869565, 0.825494347826087, 0.797479695652174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 63}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 265}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 295}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 325}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 381}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 67}], {
             RGBColor[
             0.9467338478260869, 0.9554450869565217, 0.734175304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 75}], {
             RGBColor[0.8923928913043477, 0.7455092608695654, 0.6077715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 133}], {
             RGBColor[
             0.9233611739130434, 0.941455304347826, 0.9831270652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 178}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 200}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 278}], {
             RGBColor[
             0.9467338478260869, 0.9554450869565217, 0.734175304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 296}], {
             RGBColor[
             0.9306052391304347, 0.9013377826086957, 0.6461551304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 320}], {
             RGBColor[
             0.8804393260869565, 0.6912309130434783, 0.597797152173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 330}], {
             RGBColor[
             0.9004813913043477, 0.9234834347826086, 0.9903699130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 347}], {
             RGBColor[
             0.7344339130434782, 0.7919820869565217, 0.9747672608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 367}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 398}], {
             RGBColor[
             0.947458804347826, 0.9569956956521739, 0.8130823478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 159}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 250}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 265}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 321}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 325}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 375}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 381}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 66}], {
             RGBColor[
             0.9577559565217392, 0.8631764347826087, 0.3215687608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 81}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 119}], {
             RGBColor[
             0.9099508913043479, 0.9094221304347827, 0.6803066086956522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[
             0.9863898695652173, 0.965453695652174, 0.4269912173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 130}], {
             RGBColor[
             0.9099508913043479, 0.9094221304347827, 0.6803066086956522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 135}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 146}], {
             RGBColor[
             0.9702612608695653, 0.9113463913043478, 0.3389710434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 151}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 227}], {
             RGBColor[
             0.9797934347826087, 0.9435006521739131, 0.3760017391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 243}], {
             RGBColor[
             0.9756675434782609, 0.9608985217391305, 0.6545292391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 267}], {
             RGBColor[
             0.9863898695652173, 0.965453695652174, 0.4269912173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 275}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 311}], {
             RGBColor[
             0.9099508913043479, 0.9094221304347827, 0.6803066086956522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 317}], {
             RGBColor[
             0.9401374130434782, 0.9334920434782609, 0.6831858260869565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 326}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 344}], {
             RGBColor[
             0.8226604565217391, 0.8410675217391305, 0.6716494782608695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 346}], {
             RGBColor[
             0.9863898695652173, 0.965453695652174, 0.4269912173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 383}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 48}], {
             RGBColor[
             0.7806863695652173, 0.8239437391304347, 0.718572652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 74}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 103}], {
             RGBColor[
             0.9643523913043479, 0.8851294782608696, 0.37255823913043473`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 116}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 262}], {
             RGBColor[
             0.976857695652174, 0.9332994347826087, 0.38996052173913043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 290}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 304}], {
             RGBColor[
             0.7313713260869565, 0.7839075652173914, 0.7146903913043477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 338}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 52}], {
             RGBColor[
             0.9360115217391303, 0.9508899130434783, 0.9617133260869566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 60}], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 102}], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 105}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 128}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 139}], {
             RGBColor[
             0.9661353695652174, 0.9287442608695653, 0.6174985434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 199}], {
             RGBColor[
             0.8185345652173912, 0.8584653913043478, 0.9501769782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 213}], {
             RGBColor[
             0.8185345652173912, 0.8584653913043478, 0.9501769782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 215}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 259}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 271}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 287}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 333}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 337}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 345}], {
             RGBColor[
             0.958891304347826, 0.9688617826086956, 0.9544704782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 350}], {
             RGBColor[
             0.958891304347826, 0.9688617826086956, 0.9544704782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 353}], {
             RGBColor[
             0.9360115217391303, 0.9508899130434783, 0.9617133260869566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 400}], {
             RGBColor[
             0.958891304347826, 0.9688617826086956, 0.9544704782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 136}], {
             RGBColor[
             0.876318804347826, 0.9007699565217391, 0.8061644347826089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 149}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 155}], {
             RGBColor[
             0.9172722826086956, 0.9329257826086956, 0.8102031304347828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 268}], {
             RGBColor[
             0.5866816086956522, 0.6479509782608696, 0.784647891304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 279}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 299}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 300}], {
             RGBColor[
             0.965077347826087, 0.8866800869565219, 0.4514652826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 371}], {
             RGBColor[
             0.9172722826086956, 0.9329257826086956, 0.8102031304347828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.7740899347826087, 0.8019906956521738, 0.6675831739130434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 86}], {
             RGBColor[
             0.7814113260869565, 0.825494347826087, 0.797479695652174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 103}], {
             RGBColor[
             0.7520524565217391, 0.7216664782608696, 0.6131501956521739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 295}], {
             RGBColor[
             0.7814113260869565, 0.825494347826087, 0.797479695652174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 191}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 225}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 235}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 261}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 327}], {
             RGBColor[
             0.9467338478260869, 0.9554450869565217, 0.7341753043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 335}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 349}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 355}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 127}], {
             RGBColor[
             0.9058776086956521, 0.5623174782608695, 0.40000639130434795`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 137}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 138}], {
             RGBColor[
             0.829981847826087, 0.8645711739130435, 0.8015460000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 147}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 164}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 197}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 210}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 217}], {
             RGBColor[
             0.9172722826086956, 0.9329257826086956, 0.8102031304347828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 230}], {
             RGBColor[
             0.947458804347826, 0.9569956956521739, 0.8130823478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 242}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 254}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 258}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 328}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 331}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 79}], {
             RGBColor[
             0.9768001086956521, 0.9352560869565217, 0.534873847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 87}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 126}], {
             RGBColor[
             0.9534850217391304, 0.919309652173913, 0.6389122826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 176}], {
             RGBColor[
             0.977582652173913, 0.934850043478261, 0.4688675652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 205}], {
             RGBColor[
             0.9306052391304347, 0.9013377826086957, 0.6461551304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 232}], {
             RGBColor[
             0.977582652173913, 0.934850043478261, 0.4688675652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 277}], {
             RGBColor[
             0.9768001086956521, 0.9352560869565217, 0.534873847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 298}], {
             RGBColor[
             0.9702612608695653, 0.9113463913043478, 0.3389710434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 373}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 390}], {
             RGBColor[
             0.9482237826086957, 0.8310221739130436, 0.28453806521739133`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 60}], {
             RGBColor[
             0.9360115217391303, 0.9508899130434783, 0.9617133260869566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 68}], {
             RGBColor[
             0.947458804347826, 0.9569956956521739, 0.8130823478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 105}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 129}], {
             RGBColor[
             0.9401374130434782, 0.9334920434782609, 0.6831858260869565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 199}], {
             RGBColor[
             0.7830044347826086, 0.8310589130434782, 0.9788335652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 271}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 287}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 303}], {
             RGBColor[
             0.947458804347826, 0.9569956956521739, 0.8130823478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 333}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 337}], {
             RGBColor[
             0.9467338478260869, 0.9554450869565217, 0.734175304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 345}], {
             RGBColor[
             0.9233611739130434, 0.941455304347826, 0.9831270652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 353}], {
             RGBColor[
             0.9004813913043477, 0.9234834347826086, 0.9903699130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 391}], {
             RGBColor[
             0.947458804347826, 0.9569956956521739, 0.8130823478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 69}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 93}], {
             RGBColor[
             0.6887728260869566, 0.7507732173913043, 0.9048992826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 131}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 142}], {
             RGBColor[
             0.9356947173913044, 0.7782312173913045, 0.5444354347826088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 188}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 201}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 264}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 273}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 281}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[
             0.9135966956521739, 0.9321354782608695, 0.9241546304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 394}], {
             RGBColor[
             0.8726432173913043, 0.899979652173913, 0.9201159347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 64}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 83}], {
             RGBColor[
             0.9004813913043477, 0.9234834347826086, 0.9903699130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 123}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 161}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 196}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 198}], {
             RGBColor[
             0.947458804347826, 0.9569956956521739, 0.8130823478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 206}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 214}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 310}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 332}], {
             RGBColor[
             0.9360115217391303, 0.9508899130434783, 0.9617133260869566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 389}], {
             RGBColor[
             0.7344339130434782, 0.7919820869565217, 0.9747672608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 57}], {
             RGBColor[
             0.9360115217391303, 0.9508899130434783, 0.9617133260869566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 68}], {
             RGBColor[
             0.947458804347826, 0.9569956956521739, 0.8130823478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 72}], {
             RGBColor[
             0.9233611739130434, 0.941455304347826, 0.9831270652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 83}], {
             RGBColor[
             0.9004813913043477, 0.9234834347826086, 0.9903699130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 123}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 161}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 196}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 236}], {
             RGBColor[
             0.9004813913043477, 0.9234834347826086, 0.9903699130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 262}], {
             RGBColor[
             0.9306052391304347, 0.9013377826086957, 0.6461551304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 284}], {
             RGBColor[
             0.9360115217391303, 0.9508899130434783, 0.9617133260869566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 334}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 366}], {
             RGBColor[
             0.9401374130434782, 0.9334920434782609, 0.6831858260869565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 397}], {
             RGBColor[
             0.947458804347826, 0.9569956956521739, 0.8130823478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 65}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 100}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 174}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 198}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 203}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 206}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 266}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 341}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 358}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 68}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 72}], {
             RGBColor[
             0.958891304347826, 0.9688617826086956, 0.9544704782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 86}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 108}], {
             RGBColor[
             0.8185345652173912, 0.8584653913043478, 0.9501769782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 236}], {
             RGBColor[
             0.9360115217391303, 0.9508899130434783, 0.9617133260869566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 262}], {
             RGBColor[
             0.9661353695652174, 0.9287442608695653, 0.6174985434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 284}], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 297}], {
             RGBColor[0.905825, 0.92682, 0.9588341086956522]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{57, 325}], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 376}], {
             RGBColor[0.905825, 0.92682, 0.9588341086956522]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{57, 397}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 124}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 152}], {
             RGBColor[
             0.9695560434782609, 0.9753736086956522, 0.8718457826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 156}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 160}], {
             RGBColor[
             0.926634195652174, 0.7251492173913043, 0.4865158695652174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 179}], {
             RGBColor[
             0.7806287826086956, 0.8259003913043478, 0.8634859782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 181}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 220}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[
             0.9695560434782609, 0.9753736086956522, 0.8718457826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 352}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 396}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 132}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 149}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 155}], {
             RGBColor[
             0.9135966956521739, 0.9321354782608695, 0.9241546304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 164}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 210}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 230}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 258}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 264}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 268}], {
             RGBColor[
             0.5830060217391304, 0.6471606739130434, 0.8985993913043478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 279}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 299}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 300}], {
             RGBColor[
             0.9614017608695653, 0.8858897826086958, 0.5654167826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 328}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 394}], {
             RGBColor[
             0.8726432173913043, 0.899979652173913, 0.9201159347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 68}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 72}], {
             RGBColor[
             0.958891304347826, 0.9688617826086956, 0.9544704782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 102}], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 105}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 108}], {
             RGBColor[
             0.8185345652173912, 0.8584653913043478, 0.9501769782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 139}], {
             RGBColor[
             0.9661353695652174, 0.9287442608695653, 0.6174985434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 297}], {
             RGBColor[0.905825, 0.92682, 0.9588341086956522]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{60, 333}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 337}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 345}], {
             RGBColor[
             0.958891304347826, 0.9688617826086956, 0.9544704782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 353}], {
             RGBColor[
             0.9360115217391303, 0.9508899130434783, 0.9617133260869566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 70}], {
             RGBColor[
             0.9393703043478261, 0.7790215217391306, 0.4304839347826089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 90}], {
             RGBColor[0.951581, 0.8331715652173914, 0.44060580434782626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 95}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 148}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 228}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 282}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 285}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 301}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 382}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 91}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 111}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 117}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 223}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 247}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 256}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 319}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 323}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 362}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 395}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 103}], {
             RGBColor[
             0.9577559565217392, 0.8631764347826087, 0.3215687608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 295}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 88}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 101}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 115}], {
             RGBColor[
             0.9135966956521739, 0.9321354782608695, 0.9241546304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 120}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 123}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 140}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 161}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 193}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 195}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 214}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 233}], {
             RGBColor[
             0.9356947173913044, 0.7782312173913045, 0.5444354347826088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 257}], {
             RGBColor[
             0.9135966956521739, 0.9321354782608695, 0.9241546304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 283}], {
             RGBColor[
             0.9614017608695653, 0.8858897826086958, 0.5654167826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 312}], {
             RGBColor[
             0.7777357391304347, 0.8247040434782609, 0.9114311956521739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 332}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 356}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 360}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 380}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 389}], {
             RGBColor[
             0.7777357391304347, 0.8247040434782609, 0.9114311956521739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 100}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 167}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 174}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 198}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 203}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 206}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 211}], {
             RGBColor[
             0.9661353695652174, 0.9287442608695653, 0.6174985434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 266}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 313}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 329}], {
             RGBColor[
             0.8648715217391304, 0.8946641739130434, 0.9547954130434784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 340}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 341}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 358}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 81}], {
             RGBColor[
             0.9642948043478261, 0.8870861304347827, 0.5174715652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 119}], {
             RGBColor[
             0.8879134130434783, 0.8290979130434784, 0.6258736304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 130}], {
             RGBColor[
             0.8879134130434783, 0.8290979130434784, 0.6258736304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 146}], {
             RGBColor[
             0.9482237826086957, 0.8310221739130436, 0.28453806521739133`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 151}], {
             RGBColor[
             0.9614017608695653, 0.8858897826086958, 0.5654167826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 158}], {
             RGBColor[
             0.9643523913043479, 0.8851294782608696, 0.37255823913043473`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 243}], {
             RGBColor[
             0.9536300652173912, 0.8805743043478262, 0.6000962608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 267}], {
             RGBColor[
             0.9643523913043479, 0.8851294782608696, 0.37255823913043473`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 275}], {
             RGBColor[
             0.9614017608695653, 0.8858897826086958, 0.5654167826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 311}], {
             RGBColor[
             0.8879134130434783, 0.8290979130434784, 0.6258736304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 317}], {
             RGBColor[
             0.9180999347826087, 0.8531678260869566, 0.6287528478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 344}], {
             RGBColor[
             0.8006229782608696, 0.7607433043478262, 0.6172165000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 346}], {
             RGBColor[
             0.9643523913043479, 0.8851294782608696, 0.37255823913043473`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 354}], {
             RGBColor[
             0.9642948043478261, 0.8870861304347827, 0.5174715652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 75}], {
             RGBColor[
             0.938645347826087, 0.7774709130434785, 0.35157689130434777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 126}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 133}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 200}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 320}], {
             RGBColor[
             0.9266917826086957, 0.7231925652173914, 0.3416025434782608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 347}], {
             RGBColor[
             0.7806863695652173, 0.8239437391304347, 0.718572652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 398}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 72}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 236}], {
             RGBColor[
             0.947458804347826, 0.9569956956521739, 0.8130823478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 262}], {
             RGBColor[
             0.977582652173913, 0.934850043478261, 0.4688675652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 284}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 333}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 334}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 337}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 376}], {
             RGBColor[
             0.9172722826086956, 0.9329257826086956, 0.8102031304347828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 391}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 397}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 93}], {
             RGBColor[
             0.6810011304347826, 0.7454577391304348, 0.9395787608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 131}], {
             RGBColor[
             0.958891304347826, 0.9688617826086956, 0.9544704782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 142}], {
             RGBColor[
             0.9279230217391304, 0.772915739130435, 0.5791149130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 188}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 201}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 273}], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 281}], {
             RGBColor[
             0.9661353695652174, 0.9287442608695653, 0.6174985434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 293}], {
             RGBColor[0.905825, 0.92682, 0.9588341086956522]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{69, 394}], {
             RGBColor[
             0.8648715217391304, 0.8946641739130434, 0.9547954130434784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 90}], {
             RGBColor[
             0.8965150869565218, 0.621685130434783, 0.2352949565217392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 95}], {
             RGBColor[
             0.9393703043478261, 0.7790215217391306, 0.4304839347826088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 177}], {
             RGBColor[
             0.8622063695652175, 0.7214393478260872, 0.6048922826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 228}], {
             RGBColor[
             0.9152726739130435, 0.7634811304347828, 0.600528652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 246}], {
             RGBColor[
             0.9225167391304349, 0.7233636086956523, 0.26355671739130443`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 260}], {
             RGBColor[
             0.8843043913043479, 0.5675350869565221, 0.2251730869565218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 285}], {
             RGBColor[
             0.9152726739130435, 0.7634811304347828, 0.600528652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 110}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 131}], {
             RGBColor[
             0.9695560434782609, 0.9753736086956522, 0.8718457826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 201}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 212}], {
             RGBColor[
             0.8291993043478261, 0.8649772173913044, 0.8675522826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 271}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 273}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 287}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 289}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 292}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 303}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 385}], {
             RGBColor[
             0.9768001086956521, 0.9352560869565217, 0.534873847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 400}], {
             RGBColor[
             0.9695560434782609, 0.9753736086956522, 0.8718457826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 86}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 108}], {
             RGBColor[
             0.8058842173913043, 0.8490307826086956, 0.9715907173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 236}], {
             RGBColor[
             0.9233611739130434, 0.941455304347826, 0.9831270652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 262}], {
             RGBColor[
             0.9534850217391304, 0.919309652173913, 0.6389122826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 284}], {
             RGBColor[
             0.958891304347826, 0.9688617826086956, 0.9544704782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 297}], {
             RGBColor[
             0.893174652173913, 0.9173853913043478, 0.980247847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 325}], {
             RGBColor[
             0.958891304347826, 0.9688617826086956, 0.9544704782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 333}], {
             RGBColor[
             0.9695560434782609, 0.9753736086956522, 0.8718457826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 337}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 376}], {
             RGBColor[
             0.893174652173913, 0.9173853913043478, 0.980247847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 397}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 162}], {
             RGBColor[
             0.977582652173913, 0.934850043478261, 0.4688675652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 183}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 189}], {
             RGBColor[
             0.9172722826086956, 0.9329257826086956, 0.8102031304347828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 207}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 280}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 291}], {
             RGBColor[
             0.9393703043478261, 0.7790215217391306, 0.4304839347826089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 336}], {
             RGBColor[
             0.876318804347826, 0.9007699565217391, 0.8061644347826089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 368}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 387}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 116}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 118}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 141}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 179}], {
             RGBColor[
             0.7777357391304347, 0.8247040434782609, 0.9114311956521739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 209}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 286}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 290}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 304}], {
             RGBColor[
             0.7284206956521739, 0.7846678695652174, 0.9075489347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 338}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 386}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 126}], {
             RGBColor[
             0.9152726739130435, 0.7634811304347828, 0.600528652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 133}], {
             RGBColor[
             0.9152726739130435, 0.7634811304347828, 0.600528652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 178}], {
             RGBColor[
             0.9385877608695652, 0.7794275652173914, 0.4964902173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 200}], {
             RGBColor[
             0.9356947173913044, 0.7782312173913045, 0.5444354347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 296}], {
             RGBColor[
             0.9225167391304349, 0.7233636086956523, 0.26355671739130443`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 320}], {
             RGBColor[
             0.8723508260869566, 0.513256739130435, 0.2151987391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 330}], {
             RGBColor[0.8923928913043477, 0.7455092608695654, 0.6077715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 347}], {
             RGBColor[
             0.7263454130434783, 0.6140079130434783, 0.5921688478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 398}], {
             RGBColor[
             0.9393703043478261, 0.7790215217391306, 0.4304839347826088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 78}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 80}], {
             RGBColor[
             0.958891304347826, 0.9688617826086956, 0.9544704782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.9661353695652174, 0.9287442608695653, 0.6174985434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 117}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 187}], {
             RGBColor[
             0.9360115217391303, 0.9508899130434783, 0.9617133260869566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 208}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 239}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 269}], {
             RGBColor[0.720649, 0.7793523913043479, 0.9422284130434784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 323}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 365}], {
             RGBColor[
             0.8944303260869565, 0.5562116956521739, 0.5486373695652174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 377}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 388}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 395}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 78}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 80}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 96}], {
             RGBColor[
             0.976857695652174, 0.9332994347826087, 0.38996052173913043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 182}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 187}], {
             RGBColor[
             0.9467338478260869, 0.9554450869565217, 0.7341753043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 244}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 302}], {
             RGBColor[
             0.976857695652174, 0.9332994347826087, 0.38996052173913043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 377}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 388}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 80}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 96}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 104}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 182}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 187}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 208}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 302}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 377}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 388}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 87}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 126}], {
             RGBColor[
             0.9695560434782609, 0.9753736086956522, 0.8718457826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 176}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 205}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 232}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 298}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 373}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 390}], {
             RGBColor[
             0.9642948043478261, 0.8870861304347827, 0.5174715652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 96}], {
             RGBColor[
             0.9534850217391304, 0.919309652173913, 0.6389122826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 104}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 182}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 187}], {
             RGBColor[
             0.9233611739130434, 0.941455304347826, 0.9831270652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 244}], {
             RGBColor[
             0.958891304347826, 0.9688617826086956, 0.9544704782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 302}], {
             RGBColor[
             0.9534850217391304, 0.919309652173913, 0.6389122826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 377}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 388}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 119}], {
             RGBColor[
             0.9164897391304347, 0.9333318260869565, 0.8762094130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 128}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.9164897391304347, 0.9333318260869565, 0.8762094130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 135}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 146}], {
             RGBColor[
             0.9768001086956521, 0.9352560869565217, 0.534873847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 166}], {
             RGBColor[
             0.7313137391304347, 0.7858642173913044, 0.8596037173913045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 227}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 243}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 275}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 311}], {
             RGBColor[
             0.9164897391304347, 0.9333318260869565, 0.8762094130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 326}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 344}], {
             RGBColor[
             0.8291993043478261, 0.8649772173913044, 0.8675522826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 346}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 363}], {
             RGBColor[
             0.9695560434782609, 0.9753736086956522, 0.8718457826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 383}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 172}], {
             RGBColor[
             0.7806863695652173, 0.8239437391304347, 0.718572652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 194}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 233}], {
             RGBColor[
             0.938645347826087, 0.7774709130434785, 0.35157689130434777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 256}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 257}], {
             RGBColor[
             0.9165473260869565, 0.9313751739130436, 0.7312960869565217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 310}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 316}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 399}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 118}], {
             RGBColor[
             0.9004813913043477, 0.9234834347826086, 0.9903699130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 123}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 141}], {
             RGBColor[
             0.9467338478260869, 0.9554450869565217, 0.734175304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 161}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 196}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 214}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 286}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 332}], {
             RGBColor[
             0.9360115217391303, 0.9508899130434783, 0.9617133260869566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 334}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 366}], {
             RGBColor[
             0.9401374130434782, 0.9334920434782609, 0.6831858260869565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 125}], {
             RGBColor[
             0.9768001086956521, 0.9352560869565217, 0.534873847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 184}], {
             RGBColor[
             0.9306052391304347, 0.9013377826086957, 0.6461551304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 185}], {
             RGBColor[
             0.976857695652174, 0.9332994347826087, 0.38996052173913043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 190}], {
             RGBColor[
             0.9768001086956521, 0.9352560869565217, 0.534873847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 252}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 270}], {
             RGBColor[
             0.9004187173913044, 0.8772678695652174, 0.6432759130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 274}], {
             RGBColor[
             0.976857695652174, 0.9332994347826087, 0.38996052173913043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 288}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 318}], {
             RGBColor[
             0.976857695652174, 0.9332994347826087, 0.38996052173913043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 168}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 238}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 379}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 236}], {
             RGBColor[
             0.947458804347826, 0.9569956956521739, 0.8130823478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 262}], {
             RGBColor[
             0.977582652173913, 0.934850043478261, 0.4688675652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 265}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 297}], {
             RGBColor[
             0.9172722826086956, 0.9329257826086956, 0.8102031304347828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 325}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 376}], {
             RGBColor[
             0.9172722826086956, 0.9329257826086956, 0.8102031304347828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 397}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 176}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 205}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 232}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 277}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 373}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 390}], {
             RGBColor[
             0.9614017608695653, 0.8858897826086958, 0.5654167826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 89}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 120}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 140}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 189}], {
             RGBColor[
             0.9164897391304347, 0.9333318260869565, 0.8762094130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 195}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 233}], {
             RGBColor[
             0.9385877608695652, 0.7794275652173914, 0.49649021739130444`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 255}], {
             RGBColor[
             0.9642948043478261, 0.8870861304347827, 0.5174715652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 257}], {
             RGBColor[
             0.9164897391304347, 0.9333318260869565, 0.8762094130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 263}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 336}], {
             RGBColor[0.8755362608695652, 0.901176, 0.8721707173913045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 356}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 359}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 360}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 389}], {
             RGBColor[
             0.7806287826086956, 0.8259003913043478, 0.8634859782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 162}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 183}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 189}], {
             RGBColor[
             0.9135966956521739, 0.9321354782608695, 0.9241546304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 263}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 270}], {
             RGBColor[
             0.9135966956521739, 0.9321354782608695, 0.9241546304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 291}], {
             RGBColor[
             0.9356947173913044, 0.7782312173913045, 0.5444354347826088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 336}], {
             RGBColor[
             0.8726432173913043, 0.899979652173913, 0.9201159347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 359}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 95}], {
             RGBColor[0.951581, 0.8331715652173914, 0.44060580434782626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 97}], {
             RGBColor[
             0.9479054130434783, 0.8323812608695653, 0.5545573043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.6892410652173914, 0.6281217826086958, 0.5984084565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 228}], {
             RGBColor[
             0.9274833695652174, 0.8176311739130436, 0.6106505217391305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 246}], {
             RGBColor[
             0.9347274347826088, 0.7775136521739132, 0.2736785869565218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 260}], {
             RGBColor[
             0.8965150869565218, 0.621685130434783, 0.2352949565217392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 326}], {
             RGBColor[
             0.9479054130434783, 0.8323812608695653, 0.5545573043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 172}], {
             RGBColor[
             0.7814113260869565, 0.825494347826087, 0.797479695652174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 192}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 208}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 221}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 256}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 316}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 351}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 395}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 399}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 98}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 119}], {
             RGBColor[
             0.9135966956521739, 0.9321354782608695, 0.9241546304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 130}], {
             RGBColor[
             0.9135966956521739, 0.9321354782608695, 0.9241546304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 143}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 146}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 151}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 158}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 186}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 267}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 306}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 308}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 346}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 348}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 354}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 374}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 131}], {
             RGBColor[0.6683507826086956, 0.7360231304347826, 0.9609925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 142}], {
             RGBColor[
             0.6373825000000001, 0.5400770869565219, 0.5856369347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 188}], {
             RGBColor[
             0.6916658695652174, 0.7519695652173912, 0.8569540652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 201}], {
             RGBColor[
             0.6887728260869566, 0.7507732173913043, 0.9048992826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 264}], {
             RGBColor[
             0.6810011304347825, 0.7454577391304348, 0.9395787608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 273}], {
             RGBColor[
             0.6810011304347825, 0.7454577391304348, 0.9395787608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 281}], {
             RGBColor[
             0.6755948478260869, 0.6959056086956521, 0.6240205652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 293}], {
             RGBColor[
             0.6152844782608696, 0.693981347826087, 0.9653561304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 394}], {
             RGBColor[0.574331, 0.6618255217391305, 0.9613174347826088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 204}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 307}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 324}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 97}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 148}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 166}], {
             RGBColor[
             0.7320962826086956, 0.7854581739130435, 0.7935974347826089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 169}], {
             RGBColor[
             0.9393703043478261, 0.7790215217391306, 0.4304839347826089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 228}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 246}], {
             RGBColor[
             0.977582652173913, 0.934850043478261, 0.4688675652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 276}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 282}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 305}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 326}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 361}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 382}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 104}], {
             RGBColor[
             0.976857695652174, 0.9332994347826087, 0.38996052173913043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 182}], {
             RGBColor[
             0.976857695652174, 0.9332994347826087, 0.38996052173913043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 187}], {
             RGBColor[
             0.9306052391304347, 0.9013377826086957, 0.6461551304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 208}], {
             RGBColor[
             0.9768001086956521, 0.9352560869565217, 0.534873847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 225}], {
             RGBColor[
             0.9768001086956521, 0.9352560869565217, 0.534873847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 261}], {
             RGBColor[
             0.976857695652174, 0.9332994347826087, 0.38996052173913043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 377}], {
             RGBColor[
             0.977582652173913, 0.934850043478261, 0.4688675652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 388}], {
             RGBColor[
             0.977582652173913, 0.934850043478261, 0.4688675652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 166}], {
             RGBColor[
             0.7284206956521739, 0.7846678695652174, 0.9075489347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 169}], {
             RGBColor[
             0.9356947173913044, 0.7782312173913045, 0.5444354347826088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 224}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 246}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 276}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 326}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 363}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 382}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 383}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 393}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 134}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 143}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 151}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 158}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 163}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 186}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 240}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 272}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 306}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 308}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 342}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 348}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 354}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 374}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 378}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 144}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 169}], {
             RGBColor[
             0.938645347826087, 0.7774709130434785, 0.35157689130434777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 222}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 223}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 276}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 361}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 382}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 384}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 393}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 157}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 167}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 174}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 198}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 203}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 206}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 211}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 266}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 341}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 358}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 115}], {
             RGBColor[
             0.9099508913043479, 0.9094221304347827, 0.6803066086956522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 123}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 161}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 193}], {
             RGBColor[
             0.9630171956521738, 0.9514639130434783, 0.6759429782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 253}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 283}], {
             RGBColor[
             0.9577559565217392, 0.8631764347826087, 0.3215687608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 332}], {
             RGBColor[
             0.9756675434782609, 0.9608985217391305, 0.6545292391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 334}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 356}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 364}], {
             RGBColor[
             0.7247748913043478, 0.7619545217391305, 0.6637009130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 366}], {
             RGBColor[
             0.9797934347826087, 0.9435006521739131, 0.3760017391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 380}], {
             RGBColor[
             0.9630171956521738, 0.9514639130434783, 0.6759429782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 389}], {
             RGBColor[
             0.7740899347826087, 0.8019906956521738, 0.6675831739130434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 108}], {
             RGBColor[
             0.8185345652173912, 0.8584653913043478, 0.9501769782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 139}], {
             RGBColor[
             0.9661353695652174, 0.9287442608695653, 0.6174985434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 213}], {
             RGBColor[
             0.8185345652173912, 0.8584653913043478, 0.9501769782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 297}], {
             RGBColor[0.905825, 0.92682, 0.9588341086956522]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{102, 333}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 337}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 345}], {
             RGBColor[
             0.958891304347826, 0.9688617826086956, 0.9544704782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 350}], {
             RGBColor[
             0.958891304347826, 0.9688617826086956, 0.9544704782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 378}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 122}], {
             RGBColor[
             0.965077347826087, 0.8866800869565219, 0.4514652826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 295}], {
             RGBColor[
             0.965077347826087, 0.8866800869565219, 0.4514652826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 145}], {
             RGBColor[
             0.9643523913043479, 0.8851294782608696, 0.37255823913043473`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 170}], {
             RGBColor[
             0.9863898695652173, 0.965453695652174, 0.4269912173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 182}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 187}], {
             RGBColor[
             0.9467338478260869, 0.9554450869565217, 0.7341753043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 192}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 208}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 225}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 235}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 261}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 327}], {
             RGBColor[
             0.9467338478260869, 0.9554450869565217, 0.7341753043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 335}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 349}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 351}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 355}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 199}], {
             RGBColor[
             0.8291993043478261, 0.8649772173913044, 0.8675522826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 215}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 259}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 271}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 287}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 303}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 333}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 337}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 345}], {
             RGBColor[
             0.9695560434782609, 0.9753736086956522, 0.8718457826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 350}], {
             RGBColor[
             0.9695560434782609, 0.9753736086956522, 0.8718457826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 353}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 400}], {
             RGBColor[
             0.9695560434782609, 0.9753736086956522, 0.8718457826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 197}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 217}], {
             RGBColor[0.905825, 0.92682, 0.9588341086956522]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{106, 231}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 254}], {
             RGBColor[
             0.958891304347826, 0.9688617826086956, 0.9544704782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 314}], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 369}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 124}], {
             RGBColor[
             0.9863898695652173, 0.965453695652174, 0.4269912173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 150}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 152}], {
             RGBColor[
             0.9630171956521738, 0.9514639130434783, 0.6759429782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.9863898695652173, 0.965453695652174, 0.4269912173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 160}], {
             RGBColor[
             0.9200953478260869, 0.7012395217391305, 0.2906130652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 167}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.7740899347826087, 0.8019906956521738, 0.6675831739130434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 181}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 211}], {
             RGBColor[
             0.9702612608695653, 0.9113463913043478, 0.3389710434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 238}], {
             RGBColor[
             0.9797934347826087, 0.9435006521739131, 0.3760017391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 245}], {
             RGBColor[
             0.9630171956521738, 0.9514639130434783, 0.6759429782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 386}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 297}], {
             RGBColor[0.7528179130434782, 0.806989, 0.975954347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 325}], {
             RGBColor[
             0.8185345652173912, 0.8584653913043478, 0.9501769782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 376}], {
             RGBColor[0.7528179130434782, 0.806989, 0.975954347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 378}], {
             RGBColor[
             0.8263062608695653, 0.8637808695652174, 0.9154975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 397}], {
             RGBColor[
             0.829981847826087, 0.8645711739130435, 0.8015460000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 114}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 132}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 180}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 232}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 249}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 370}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 111}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 117}], {
             RGBColor[
             0.9467338478260869, 0.9554450869565217, 0.734175304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 202}], {
             RGBColor[
             0.9004813913043477, 0.9234834347826086, 0.9903699130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 212}], {
             RGBColor[
             0.7830044347826086, 0.8310589130434782, 0.9788335652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 239}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 247}], {
             RGBColor[
             0.947458804347826, 0.9569956956521739, 0.8130823478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 269}], {
             RGBColor[0.6851188695652173, 0.7519459130434782, 0.970885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 287}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 289}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 292}], {
             RGBColor[
             0.9360115217391303, 0.9508899130434783, 0.9617133260869566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 303}], {
             RGBColor[
             0.947458804347826, 0.9569956956521739, 0.8130823478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 309}], {
             RGBColor[
             0.9360115217391303, 0.9508899130434783, 0.9617133260869566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 362}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 385}], {
             RGBColor[
             0.9306052391304347, 0.9013377826086957, 0.6461551304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 400}], {
             RGBColor[
             0.9233611739130434, 0.941455304347826, 0.9831270652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 199}], {
             RGBColor[
             0.8263062608695653, 0.8637808695652174, 0.9154975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 222}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 223}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 247}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 271}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 287}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 292}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 309}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 319}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 362}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 385}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 177}], {
             RGBColor[
             0.9004187173913044, 0.8772678695652174, 0.6432759130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 219}], {
             RGBColor[
             0.9534850217391304, 0.919309652173913, 0.6389122826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 248}], {
             RGBColor[
             0.9768001086956521, 0.9352560869565217, 0.534873847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 251}], {
             RGBColor[
             0.675594847826087, 0.6959056086956521, 0.6240205652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 260}], {
             RGBColor[
             0.9225167391304349, 0.7233636086956523, 0.26355671739130443`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 162}], {
             RGBColor[
             0.9347274347826088, 0.7775136521739132, 0.2736785869565218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 183}], {
             RGBColor[0.951581, 0.8331715652173914, 0.44060580434782626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 270}], {
             RGBColor[
             0.8744170652173914, 0.775589391304348, 0.6150141521739131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 357}], {
             RGBColor[
             0.8334635869565218, 0.7434335652173915, 0.6109754565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 368}], {
             RGBColor[
             0.9401337173913044, 0.8270657826086958, 0.5892367826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 132}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 155}], {
             RGBColor[
             0.9135966956521739, 0.9321354782608695, 0.9241546304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 180}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 249}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 268}], {
             RGBColor[
             0.5830060217391304, 0.6471606739130434, 0.8985993913043478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 279}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 299}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 300}], {
             RGBColor[
             0.9614017608695653, 0.8858897826086958, 0.5654167826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 370}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 123}], {
             RGBColor[
             0.9135966956521739, 0.9321354782608695, 0.9241546304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 161}], {
             RGBColor[
             0.9164897391304347, 0.9333318260869565, 0.8762094130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 193}], {
             RGBColor[
             0.893174652173913, 0.9173853913043478, 0.980247847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 195}], {
             RGBColor[
             0.9165473260869565, 0.9313751739130436, 0.7312960869565217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 214}], {
             RGBColor[
             0.9135966956521739, 0.9321354782608695, 0.9241546304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 253}], {
             RGBColor[
             0.9172722826086956, 0.9329257826086956, 0.8102031304347828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 257}], {
             RGBColor[
             0.840108347826087, 0.8753436086956522, 0.9846114782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 283}], {
             RGBColor[
             0.8879134130434783, 0.8290979130434784, 0.6258736304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 312}], {
             RGBColor[
             0.7042473913043479, 0.7679121739130434, 0.9718880434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 332}], {
             RGBColor[0.905825, 0.92682, 0.9588341086956522]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{115, 334}], {
             RGBColor[
             0.9164897391304347, 0.9333318260869565, 0.8762094130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 356}], {
             RGBColor[
             0.9135966956521739, 0.9321354782608695, 0.9241546304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 360}], {
             RGBColor[
             0.9165473260869565, 0.9313751739130436, 0.7312960869565217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 364}], {
             RGBColor[0.654932347826087, 0.727876, 0.9680057826086956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 366}], {
             RGBColor[
             0.9099508913043479, 0.9094221304347827, 0.6803066086956522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 380}], {
             RGBColor[
             0.893174652173913, 0.9173853913043478, 0.980247847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 389}], {
             RGBColor[
             0.7042473913043479, 0.7679121739130434, 0.9718880434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 141}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 179}], {
             RGBColor[
             0.7777357391304347, 0.8247040434782609, 0.9114311956521739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 209}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 286}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 290}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 304}], {
             RGBColor[
             0.7284206956521739, 0.7846678695652174, 0.9075489347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 338}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 239}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 269}], {
             RGBColor[
             0.7313713260869565, 0.7839075652173914, 0.7146903913043477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 309}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 323}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 362}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 365}], {
             RGBColor[
             0.905152652173913, 0.5607668695652175, 0.3210993478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 377}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 385}], {
             RGBColor[
             0.976857695652174, 0.9332994347826087, 0.38996052173913043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 388}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 395}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 124}], {
             RGBColor[
             0.9467338478260869, 0.9554450869565217, 0.734175304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[
             0.9467338478260869, 0.9554450869565217, 0.734175304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 150}], {
             RGBColor[
             0.947458804347826, 0.9569956956521739, 0.8130823478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 179}], {
             RGBColor[
             0.7344339130434782, 0.7919820869565217, 0.9747672608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 196}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 206}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 209}], {
             RGBColor[
             0.9467338478260869, 0.9554450869565217, 0.734175304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 286}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 386}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 128}], {
             RGBColor[
             0.9165473260869565, 0.9313751739130436, 0.7312960869565217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 130}], {
             RGBColor[
             0.840108347826087, 0.8753436086956522, 0.9846114782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 135}], {
             RGBColor[
             0.9135966956521739, 0.9321354782608695, 0.9241546304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 146}], {
             RGBColor[
             0.9004187173913044, 0.8772678695652174, 0.6432759130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 151}], {
             RGBColor[
             0.9135966956521739, 0.9321354782608695, 0.9241546304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 213}], {
             RGBColor[0.7528179130434782, 0.806989, 0.975954347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 227}], {
             RGBColor[
             0.9099508913043479, 0.9094221304347827, 0.6803066086956522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 243}], {
             RGBColor[0.905825, 0.92682, 0.9588341086956522]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{119, 267}], {
             RGBColor[
             0.9165473260869565, 0.9313751739130436, 0.7312960869565217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 306}], {
             RGBColor[
             0.9165473260869565, 0.9313751739130436, 0.7312960869565217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 311}], {
             RGBColor[
             0.840108347826087, 0.8753436086956522, 0.9846114782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 344}], {
             RGBColor[0.7528179130434782, 0.806989, 0.975954347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 346}], {
             RGBColor[
             0.9165473260869565, 0.9313751739130436, 0.7312960869565217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 350}], {
             RGBColor[
             0.893174652173913, 0.9173853913043478, 0.980247847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 354}], {
             RGBColor[
             0.9164897391304347, 0.9333318260869565, 0.8762094130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 140}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 147}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 193}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 195}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 241}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 242}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 255}], {
             RGBColor[
             0.9643523913043479, 0.8851294782608696, 0.37255823913043473`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 263}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 312}], {
             RGBColor[
             0.7806863695652173, 0.8239437391304347, 0.718572652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 331}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 356}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 359}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 360}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 380}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 389}], {
             RGBColor[
             0.7806863695652173, 0.8239437391304347, 0.718572652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 202}], {
             RGBColor[
             0.9467338478260869, 0.9554450869565217, 0.7341753043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 234}], {
             RGBColor[
             0.9643523913043479, 0.8851294782608696, 0.37255823913043473`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 289}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 298}], {
             RGBColor[
             0.9863898695652173, 0.965453695652174, 0.4269912173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 173}], {
             RGBColor[
             0.947458804347826, 0.9569956956521739, 0.8130823478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 338}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 161}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 196}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 214}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 253}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 283}], {
             RGBColor[
             0.9614017608695653, 0.8858897826086958, 0.5654167826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 332}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 334}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 356}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 364}], {
             RGBColor[
             0.7284206956521739, 0.7846678695652174, 0.9075489347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 366}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 389}], {
             RGBColor[
             0.7777357391304347, 0.8247040434782609, 0.9114311956521739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 150}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 152}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 156}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 157}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 160}], {
             RGBColor[
             0.9266917826086957, 0.7231925652173914, 0.3416025434782608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 167}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 179}], {
             RGBColor[
             0.7806863695652173, 0.8239437391304347, 0.718572652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 181}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 238}], {
             RGBColor[
             0.9863898695652173, 0.965453695652174, 0.4269912173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 245}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 386}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 184}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 185}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 190}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 226}], {
             RGBColor[
             0.9768001086956521, 0.9352560869565217, 0.534873847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 252}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 274}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 288}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 318}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 176}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 205}], {
             RGBColor[
             0.9233611739130434, 0.941455304347826, 0.9831270652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 298}], {
             RGBColor[
             0.9630171956521738, 0.9514639130434783, 0.6759429782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 320}], {
             RGBColor[
             0.9033191086956521, 0.7092027826086956, 0.5905543043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 347}], {
             RGBColor[
             0.7573136956521738, 0.8099539565217391, 0.9675244130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 373}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 137}], {
             RGBColor[
             0.9050950652173912, 0.5627235217391304, 0.4660126739130436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 138}], {
             RGBColor[
             0.7414232391304347, 0.4363806956521739, 0.5657576086956522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 193}], {
             RGBColor[
             0.8817799782608695, 0.5467770869565217, 0.5700511086956522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 210}], {
             RGBColor[
             0.8985562173913044, 0.5388138260869566, 0.2701098695652174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 242}], {
             RGBColor[
             0.9058776086956521, 0.5623174782608695, 0.400006391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 255}], {
             RGBColor[
             0.8765187391304348, 0.45848960869565225`, 0.21567689130434786`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 258}], {
             RGBColor[
             0.9022020217391304, 0.5615271739130434, 0.5139578913043479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 264}], {
             RGBColor[
             0.8944303260869565, 0.5562116956521739, 0.5486373695652175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 312}], {
             RGBColor[
             0.6928527173913044, 0.39730386956521735`, 0.5616913043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 328}], {
             RGBColor[
             0.9050950652173912, 0.5627235217391304, 0.4660126739130436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 331}], {
             RGBColor[
             0.9050950652173912, 0.5627235217391304, 0.4660126739130436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 380}], {
             RGBColor[
             0.8817799782608695, 0.5467770869565217, 0.5700511086956522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 394}], {
             RGBColor[
             0.7877601956521739, 0.47257947826086955`, 0.5703760434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 130}], {
             RGBColor[
             0.9165473260869565, 0.9313751739130436, 0.7312960869565217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 135}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 139}], {
             RGBColor[
             0.976857695652174, 0.9332994347826087, 0.38996052173913043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 151}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 213}], {
             RGBColor[
             0.8292568913043479, 0.8630205652173913, 0.722638956521739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 215}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 224}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 227}], {
             RGBColor[
             0.9863898695652173, 0.965453695652174, 0.4269912173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 243}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 259}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 306}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 350}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 383}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 131}], {
             RGBColor[
             0.9630171956521738, 0.9514639130434783, 0.6759429782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 253}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 271}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 287}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 303}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 333}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 337}], {
             RGBColor[
             0.9863898695652173, 0.965453695652174, 0.4269912173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 353}], {
             RGBColor[
             0.9401374130434782, 0.9334920434782609, 0.6831858260869565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 364}], {
             RGBColor[
             0.7247748913043478, 0.7619545217391305, 0.6637009130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 391}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 135}], {
             RGBColor[
             0.9135966956521739, 0.9321354782608695, 0.9241546304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 146}], {
             RGBColor[
             0.9004187173913044, 0.8772678695652174, 0.6432759130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 151}], {
             RGBColor[
             0.9135966956521739, 0.9321354782608695, 0.9241546304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 158}], {
             RGBColor[
             0.9165473260869565, 0.9313751739130436, 0.7312960869565217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 227}], {
             RGBColor[
             0.9099508913043479, 0.9094221304347827, 0.6803066086956522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 243}], {
             RGBColor[0.905825, 0.92682, 0.9588341086956522]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{130, 267}], {
             RGBColor[
             0.9165473260869565, 0.9313751739130436, 0.7312960869565217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 275}], {
             RGBColor[
             0.9135966956521739, 0.9321354782608695, 0.9241546304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 306}], {
             RGBColor[
             0.9165473260869565, 0.9313751739130436, 0.7312960869565217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 311}], {
             RGBColor[
             0.840108347826087, 0.8753436086956522, 0.9846114782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 317}], {
             RGBColor[
             0.8702948695652173, 0.8994135217391304, 0.9874906956521738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 344}], {
             RGBColor[0.7528179130434782, 0.806989, 0.975954347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 346}], {
             RGBColor[
             0.9165473260869565, 0.9313751739130436, 0.7312960869565217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 354}], {
             RGBColor[
             0.9164897391304347, 0.9333318260869565, 0.8762094130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 142}], {
             RGBColor[
             0.9152726739130435, 0.7634811304347828, 0.600528652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 201}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 273}], {
             RGBColor[
             0.958891304347826, 0.9688617826086956, 0.9544704782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 281}], {
             RGBColor[
             0.9534850217391304, 0.919309652173913, 0.6389122826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 293}], {
             RGBColor[
             0.893174652173913, 0.9173853913043478, 0.980247847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 303}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 391}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 394}], {
             RGBColor[
             0.8522211739130434, 0.8852295652173913, 0.9762091521739131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 149}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 155}], {
             RGBColor[
             0.9172722826086956, 0.9329257826086956, 0.8102031304347828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 180}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 249}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 268}], {
             RGBColor[
             0.5866816086956522, 0.6479509782608696, 0.784647891304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 279}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 299}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 300}], {
             RGBColor[
             0.965077347826087, 0.8866800869565219, 0.4514652826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 370}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 178}], {
             RGBColor[
             0.9695560434782609, 0.9753736086956522, 0.8718457826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 200}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 278}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 296}], {
             RGBColor[
             0.9534850217391304, 0.919309652173913, 0.6389122826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 320}], {
             RGBColor[
             0.9033191086956521, 0.7092027826086956, 0.5905543043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 330}], {
             RGBColor[
             0.9233611739130434, 0.941455304347826, 0.9831270652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 347}], {
             RGBColor[
             0.7573136956521738, 0.8099539565217391, 0.9675244130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 367}], {
             RGBColor[
             0.9695560434782609, 0.9753736086956522, 0.8718457826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 398}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 163}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 171}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 240}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 272}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 342}], {
             RGBColor[
             0.9768001086956521, 0.9352560869565217, 0.534873847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 374}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 213}], {
             RGBColor[
             0.8263062608695653, 0.8637808695652174, 0.9154975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 215}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 224}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 227}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 243}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 259}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 350}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 363}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 383}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 393}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 149}], {
             RGBColor[0.8755362608695652, 0.901176, 0.8721707173913045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 155}], {
             RGBColor[
             0.7991548695652174, 0.8431877826086956, 0.9805727826086956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 268}], {
             RGBColor[
             0.4685641956521739, 0.5582129782608696, 0.9550175434782608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 279}], {
             RGBColor[
             0.8726432173913043, 0.899979652173913, 0.9201159347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 299}], {
             RGBColor[
             0.876318804347826, 0.9007699565217391, 0.8061644347826089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 300}], {
             RGBColor[
             0.8469599347826087, 0.7969420869565218, 0.6218349347826088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 371}], {
             RGBColor[
             0.7991548695652174, 0.8431877826086956, 0.9805727826086956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 138}], {
             RGBColor[
             0.8291993043478261, 0.8649772173913044, 0.8675522826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 164}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 210}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 230}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 242}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 258}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 264}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 328}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 394}], {
             RGBColor[0.8755362608695652, 0.901176, 0.8721707173913045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 149}], {
             RGBColor[
             0.8291993043478261, 0.8649772173913044, 0.8675522826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 164}], {
             RGBColor[
             0.8263062608695653, 0.8637808695652174, 0.9154975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 210}], {
             RGBColor[
             0.8226604565217391, 0.8410675217391305, 0.6716494782608695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 230}], {
             RGBColor[
             0.7830044347826086, 0.8310589130434782, 0.9788335652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 242}], {
             RGBColor[
             0.829981847826087, 0.8645711739130435, 0.8015460000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 258}], {
             RGBColor[
             0.8263062608695653, 0.8637808695652174, 0.9154975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 264}], {
             RGBColor[
             0.8185345652173912, 0.8584653913043478, 0.9501769782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 281}], {
             RGBColor[
             0.8131282826086956, 0.8089132608695653, 0.6346187826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 328}], {
             RGBColor[
             0.8291993043478261, 0.8649772173913044, 0.8675522826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 394}], {
             RGBColor[
             0.7118644347826086, 0.7748331739130434, 0.9719156521739131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 186}], {
             RGBColor[
             0.977582652173913, 0.934850043478261, 0.4688675652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 213}], {
             RGBColor[
             0.8131282826086956, 0.8089132608695653, 0.6346187826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 215}], {
             RGBColor[
             0.976857695652174, 0.9332994347826087, 0.38996052173913043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 306}], {
             RGBColor[
             0.976857695652174, 0.9332994347826087, 0.38996052173913043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 308}], {
             RGBColor[
             0.9661353695652174, 0.9287442608695653, 0.6174985434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 345}], {
             RGBColor[
             0.9534850217391304, 0.919309652173913, 0.6389122826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 350}], {
             RGBColor[
             0.9534850217391304, 0.919309652173913, 0.6389122826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 378}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 147}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 193}], {
             RGBColor[
             0.9695560434782609, 0.9753736086956522, 0.8718457826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 195}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 241}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 242}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 255}], {
             RGBColor[
             0.9642948043478261, 0.8870861304347827, 0.5174715652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 263}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 312}], {
             RGBColor[
             0.7806287826086956, 0.8259003913043478, 0.8634859782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 331}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 356}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 359}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 360}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 380}], {
             RGBColor[
             0.9695560434782609, 0.9753736086956522, 0.8718457826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 389}], {
             RGBColor[
             0.7806287826086956, 0.8259003913043478, 0.8634859782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 179}], {
             RGBColor[
             0.7806863695652173, 0.8239437391304347, 0.718572652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 196}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 209}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 286}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 290}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 304}], {
             RGBColor[
             0.7313713260869565, 0.7839075652173914, 0.7146903913043477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 386}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.9385877608695652, 0.7794275652173914, 0.4964902173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 201}], {
             RGBColor[
             0.9356947173913044, 0.7782312173913045, 0.5444354347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 273}], {
             RGBColor[
             0.9279230217391304, 0.772915739130435, 0.5791149130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 281}], {
             RGBColor[
             0.9225167391304349, 0.7233636086956523, 0.26355671739130443`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 293}], {
             RGBColor[
             0.8622063695652175, 0.7214393478260872, 0.6048922826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 394}], {
             RGBColor[
             0.8212528913043479, 0.6892835217391307, 0.6008535869565218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 151}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 158}], {
             RGBColor[
             0.976857695652174, 0.9332994347826087, 0.38996052173913043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 171}], {
             RGBColor[
             0.9702612608695653, 0.9113463913043478, 0.3389710434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 186}], {
             RGBColor[
             0.977582652173913, 0.934850043478261, 0.4688675652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 272}], {
             RGBColor[
             0.977582652173913, 0.934850043478261, 0.4688675652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 306}], {
             RGBColor[
             0.976857695652174, 0.9332994347826087, 0.38996052173913043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 308}], {
             RGBColor[
             0.9661353695652174, 0.9287442608695653, 0.6174985434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 342}], {
             RGBColor[
             0.9607290869565218, 0.8791921304347826, 0.30194034782608703`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 348}], {
             RGBColor[
             0.9661353695652174, 0.9287442608695653, 0.6174985434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 354}], {
             RGBColor[
             0.9768001086956521, 0.9352560869565217, 0.534873847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 374}], {
             RGBColor[
             0.9702612608695653, 0.9113463913043478, 0.3389710434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 378}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 148}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 169}], {
             RGBColor[
             0.938645347826087, 0.7774709130434785, 0.35157689130434777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 218}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 222}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 276}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 282}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 305}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 339}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 361}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 382}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 384}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 165}], {
             RGBColor[
             0.9536300652173912, 0.8805743043478262, 0.6000962608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 170}], {
             RGBColor[
             0.9577559565217392, 0.8631764347826087, 0.3215687608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 182}], {
             RGBColor[
             0.9643523913043479, 0.8851294782608696, 0.37255823913043473`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 192}], {
             RGBColor[
             0.9643523913043479, 0.8851294782608696, 0.37255823913043473`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 208}], {
             RGBColor[
             0.9642948043478261, 0.8870861304347827, 0.5174715652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 221}], {
             RGBColor[
             0.9614017608695653, 0.8858897826086958, 0.5654167826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 225}], {
             RGBColor[
             0.9642948043478261, 0.8870861304347827, 0.5174715652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 235}], {
             RGBColor[
             0.965077347826087, 0.8866800869565219, 0.4514652826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 335}], {
             RGBColor[
             0.965077347826087, 0.8866800869565219, 0.4514652826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 349}], {
             RGBColor[
             0.9642948043478261, 0.8870861304347827, 0.5174715652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 351}], {
             RGBColor[
             0.9642948043478261, 0.8870861304347827, 0.5174715652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 355}], {
             RGBColor[
             0.9642948043478261, 0.8870861304347827, 0.5174715652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 395}], {
             RGBColor[
             0.9642948043478261, 0.8870861304347827, 0.5174715652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 151}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 158}], {
             RGBColor[
             0.976857695652174, 0.9332994347826087, 0.38996052173913043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 227}], {
             RGBColor[
             0.9702612608695653, 0.9113463913043478, 0.3389710434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 243}], {
             RGBColor[
             0.9661353695652174, 0.9287442608695653, 0.6174985434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 267}], {
             RGBColor[
             0.976857695652174, 0.9332994347826087, 0.38996052173913043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 275}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 306}], {
             RGBColor[
             0.976857695652174, 0.9332994347826087, 0.38996052173913043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 311}], {
             RGBColor[
             0.9004187173913044, 0.8772678695652174, 0.6432759130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 317}], {
             RGBColor[
             0.9306052391304347, 0.9013377826086957, 0.6461551304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 344}], {
             RGBColor[
             0.8131282826086956, 0.8089132608695653, 0.6346187826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 346}], {
             RGBColor[
             0.976857695652174, 0.9332994347826087, 0.38996052173913043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 354}], {
             RGBColor[
             0.9768001086956521, 0.9352560869565217, 0.534873847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 195}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 217}], {
             RGBColor[
             0.9165473260869565, 0.9313751739130436, 0.7312960869565217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 231}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 241}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 242}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 255}], {
             RGBColor[
             0.9643523913043479, 0.8851294782608696, 0.37255823913043473`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 312}], {
             RGBColor[
             0.7806863695652173, 0.8239437391304347, 0.718572652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 331}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 359}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 392}], {
             RGBColor[
             0.9863898695652173, 0.965453695652174, 0.4269912173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 218}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 228}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 276}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 301}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 305}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 313}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 339}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 340}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 361}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 382}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 155}], {
             RGBColor[
             0.9164897391304347, 0.9333318260869565, 0.8762094130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 164}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 210}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 230}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 258}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 264}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 268}], {
             RGBColor[
             0.5858990652173913, 0.6483570217391305, 0.8506541739130435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 279}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 299}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 300}], {
             RGBColor[
             0.9642948043478261, 0.8870861304347827, 0.5174715652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 328}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 152}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 156}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 157}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 160}], {
             RGBColor[
             0.9274167391304349, 0.7247431739130435, 0.42050958695652185`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 167}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 179}], {
             RGBColor[
             0.7814113260869565, 0.825494347826087, 0.797479695652174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 181}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 206}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 211}], {
             RGBColor[
             0.977582652173913, 0.934850043478261, 0.4688675652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 238}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 386}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 158}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 186}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 227}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 267}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 306}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 308}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 311}], {
             RGBColor[
             0.9135966956521739, 0.9321354782608695, 0.9241546304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 317}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 344}], {
             RGBColor[
             0.8263062608695653, 0.8637808695652174, 0.9154975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 346}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 348}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 354}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 156}], {
             RGBColor[
             0.9695560434782609, 0.9753736086956522, 0.8718457826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 157}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 160}], {
             RGBColor[
             0.9033191086956521, 0.7092027826086956, 0.5905543043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 179}], {
             RGBColor[
             0.7573136956521738, 0.8099539565217391, 0.9675244130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 181}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 238}], {
             RGBColor[
             0.9630171956521738, 0.9514639130434783, 0.6759429782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 245}], {
             RGBColor[
             0.946240956521739, 0.9594271739130434, 0.9758842173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 168}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 175}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 211}], {
             RGBColor[
             0.977582652173913, 0.934850043478261, 0.4688675652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 216}], {
             RGBColor[
             0.876318804347826, 0.9007699565217391, 0.8061644347826089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 229}], {
             RGBColor[
             0.947458804347826, 0.9569956956521739, 0.8130823478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 294}], {
             RGBColor[
             0.947458804347826, 0.9569956956521739, 0.8130823478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 329}], {
             RGBColor[
             0.876318804347826, 0.9007699565217391, 0.8061644347826089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 341}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 343}], {
             RGBColor[
             0.9172722826086956, 0.9329257826086956, 0.8102031304347828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 358}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 379}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 207}], {
             RGBColor[
             0.8185345652173912, 0.8584653913043478, 0.9501769782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 231}], {
             RGBColor[
             0.8292568913043479, 0.8630205652173913, 0.722638956521739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 369}], {
             RGBColor[
             0.8291993043478261, 0.8649772173913044, 0.8675522826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 372}], {
             RGBColor[
             0.6655274782608696, 0.7386343913043478, 0.9672972173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 387}], {
             RGBColor[
             0.829981847826087, 0.8645711739130435, 0.8015460000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 392}], {
             RGBColor[
             0.8226604565217391, 0.8410675217391305, 0.6716494782608695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 249}], {
             RGBColor[
             0.9164897391304347, 0.9333318260869565, 0.8762094130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 268}], {
             RGBColor[
             0.5095176739130435, 0.5903688043478261, 0.9590562391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 279}], {
             RGBColor[
             0.9135966956521739, 0.9321354782608695, 0.9241546304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.9172722826086956, 0.9329257826086956, 0.8102031304347828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 300}], {
             RGBColor[
             0.8879134130434783, 0.8290979130434784, 0.6258736304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 370}], {
             RGBColor[
             0.9165473260869565, 0.9313751739130436, 0.7312960869565217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 371}], {
             RGBColor[
             0.840108347826087, 0.8753436086956522, 0.9846114782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 160}], {
             RGBColor[
             0.926634195652174, 0.7251492173913043, 0.4865158695652174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.7806287826086956, 0.8259003913043478, 0.8634859782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 181}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 245}], {
             RGBColor[
             0.9695560434782609, 0.9753736086956522, 0.8718457826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 352}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 396}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 160}], {
             RGBColor[
             0.9266917826086957, 0.7231925652173914, 0.3416025434782608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 167}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 168}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 203}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 206}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 211}], {
             RGBColor[
             0.976857695652174, 0.9332994347826087, 0.38996052173913043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 238}], {
             RGBColor[
             0.9863898695652173, 0.965453695652174, 0.4269912173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 341}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 358}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 386}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 267}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 306}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 308}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 311}], {
             RGBColor[
             0.9165473260869565, 0.9313751739130436, 0.7312960869565217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 317}], {
             RGBColor[
             0.9467338478260869, 0.9554450869565217, 0.7341753043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 344}], {
             RGBColor[
             0.8292568913043479, 0.8630205652173913, 0.722638956521739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 346}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 348}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 354}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 374}], {
             RGBColor[
             0.9863898695652173, 0.965453695652174, 0.4269912173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 250}], {
             RGBColor[
             0.9401374130434782, 0.9334920434782609, 0.6831858260869565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 265}], {
             RGBColor[
             0.9360115217391303, 0.9508899130434783, 0.9617133260869566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 321}], {
             RGBColor[
             0.9233611739130434, 0.941455304347826, 0.9831270652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 375}], {
             RGBColor[
             0.9360115217391303, 0.9508899130434783, 0.9617133260869566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 381}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[
             0.9274167391304349, 0.7247431739130434, 0.42050958695652185`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 238}], {
             RGBColor[
             0.9200953478260869, 0.7012395217391305, 0.2906130652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 245}], {
             RGBColor[
             0.9033191086956521, 0.7092027826086957, 0.5905543043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 196}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 214}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 253}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 283}], {
             RGBColor[
             0.9642948043478261, 0.8870861304347827, 0.5174715652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 332}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 334}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 364}], {
             RGBColor[
             0.7313137391304347, 0.7858642173913044, 0.8596037173913045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 366}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 389}], {
             RGBColor[
             0.7806287826086956, 0.8259003913043478, 0.8634859782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 183}], {
             RGBColor[
             0.977582652173913, 0.934850043478261, 0.4688675652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 270}], {
             RGBColor[
             0.9004187173913044, 0.8772678695652174, 0.6432759130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 280}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 291}], {
             RGBColor[
             0.9225167391304349, 0.7233636086956523, 0.26355671739130443`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 336}], {
             RGBColor[
             0.8594652391304348, 0.8451120434782609, 0.6392372173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 357}], {
             RGBColor[
             0.8594652391304348, 0.8451120434782609, 0.6392372173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 368}], {
             RGBColor[
             0.9661353695652174, 0.9287442608695653, 0.6174985434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 171}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 240}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 272}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 342}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 374}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 210}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 230}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 258}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 264}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 279}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 328}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 170}], {
             RGBColor[
             0.9756675434782609, 0.9608985217391305, 0.6545292391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 172}], {
             RGBColor[
             0.7699640434782609, 0.8193885652173913, 0.9461106739130435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 184}], {
             RGBColor[
             0.9360115217391303, 0.9508899130434783, 0.9617133260869566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 190}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 192}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 221}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 226}], {
             RGBColor[
             0.9661353695652174, 0.9287442608695653, 0.6174985434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 252}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 274}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 288}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 318}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 322}], {
             RGBColor[
             0.9756675434782609, 0.9608985217391305, 0.6545292391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 351}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 355}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 399}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 169}], {
             RGBColor[
             0.6770303695652174, 0.573971739130435, 0.5882865869565218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 246}], {
             RGBColor[
             0.7152427173913044, 0.7298002608695653, 0.6266702173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 326}], {
             RGBColor[
             0.7284206956521739, 0.7846678695652174, 0.9075489347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 363}], {
             RGBColor[
             0.707998652173913, 0.7699177826086956, 0.9636421521739131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 383}], {
             RGBColor[
             0.7313137391304347, 0.7858642173913044, 0.8596037173913045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 168}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 211}], {
             RGBColor[
             0.977582652173913, 0.934850043478261, 0.4688675652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 216}], {
             RGBColor[
             0.876318804347826, 0.9007699565217391, 0.8061644347826089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 238}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 341}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 358}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 211}], {
             RGBColor[
             0.976857695652174, 0.9332994347826087, 0.38996052173913043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 216}], {
             RGBColor[
             0.875593847826087, 0.899219347826087, 0.7272573913043477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 238}], {
             RGBColor[
             0.9863898695652173, 0.965453695652174, 0.4269912173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 341}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 379}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 218}], {
             RGBColor[
             0.9393703043478261, 0.7790215217391306, 0.4304839347826088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 222}], {
             RGBColor[
             0.9152726739130435, 0.7634811304347828, 0.600528652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 224}], {
             RGBColor[
             0.938645347826087, 0.7774709130434785, 0.35157689130434777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 276}], {
             RGBColor[
             0.9356947173913044, 0.7782312173913045, 0.5444354347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 326}], {
             RGBColor[
             0.9356947173913044, 0.7782312173913045, 0.5444354347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 361}], {
             RGBColor[
             0.938645347826087, 0.7774709130434785, 0.35157689130434777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 363}], {
             RGBColor[
             0.9152726739130435, 0.7634811304347828, 0.600528652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 382}], {
             RGBColor[
             0.9152726739130435, 0.7634811304347828, 0.600528652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 383}], {
             RGBColor[
             0.9385877608695652, 0.7794275652173914, 0.4964902173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 393}], {
             RGBColor[
             0.938645347826087, 0.7774709130434785, 0.35157689130434777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[
             0.9863898695652173, 0.965453695652174, 0.4269912173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 208}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 221}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 225}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 235}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 322}], {
             RGBColor[
             0.9797934347826087, 0.9435006521739131, 0.3760017391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 335}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 349}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 351}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 355}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 186}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 240}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 272}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 308}], {
             RGBColor[
             0.9756675434782609, 0.9608985217391305, 0.6545292391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 342}], {
             RGBColor[
             0.9702612608695653, 0.9113463913043478, 0.3389710434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 348}], {
             RGBColor[
             0.9756675434782609, 0.9608985217391305, 0.6545292391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 374}], {
             RGBColor[
             0.9797934347826087, 0.9435006521739131, 0.3760017391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 192}], {
             RGBColor[
             0.7806863695652173, 0.8239437391304347, 0.718572652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 194}], {
             RGBColor[
             0.7814113260869565, 0.825494347826087, 0.797479695652174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 221}], {
             RGBColor[
             0.7777357391304347, 0.8247040434782609, 0.9114311956521739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 256}], {
             RGBColor[
             0.7814113260869565, 0.825494347826087, 0.797479695652174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 316}], {
             RGBColor[
             0.7777357391304347, 0.8247040434782609, 0.9114311956521739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 351}], {
             RGBColor[
             0.7806287826086956, 0.8259003913043478, 0.8634859782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 399}], {
             RGBColor[
             0.7806287826086956, 0.8259003913043478, 0.8634859782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 198}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 203}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 266}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 313}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 329}], {
             RGBColor[
             0.876318804347826, 0.9007699565217391, 0.8061644347826089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 340}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 341}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 358}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 204}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 216}], {
             RGBColor[
             0.876318804347826, 0.9007699565217391, 0.8061644347826089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 229}], {
             RGBColor[
             0.947458804347826, 0.9569956956521739, 0.8130823478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 294}], {
             RGBColor[
             0.947458804347826, 0.9569956956521739, 0.8130823478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 307}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 343}], {
             RGBColor[
             0.9172722826086956, 0.9329257826086956, 0.8102031304347828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 379}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 205}], {
             RGBColor[
             0.947458804347826, 0.9569956956521739, 0.8130823478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 232}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 277}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 298}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 320}], {
             RGBColor[
             0.9274167391304349, 0.7247431739130435, 0.42050958695652185`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 347}], {
             RGBColor[
             0.7814113260869565, 0.825494347826087, 0.797479695652174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 373}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 390}], {
             RGBColor[
             0.965077347826087, 0.8866800869565219, 0.4514652826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 219}], {
             RGBColor[
             0.893174652173913, 0.9173853913043478, 0.980247847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 248}], {
             RGBColor[
             0.9164897391304347, 0.9333318260869565, 0.8762094130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 260}], {
             RGBColor[
             0.8622063695652175, 0.7214393478260872, 0.6048922826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 285}], {
             RGBColor[
             0.893174652173913, 0.9173853913043478, 0.980247847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 200}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 278}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 296}], {
             RGBColor[
             0.9768001086956521, 0.9352560869565217, 0.534873847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 330}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 367}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 398}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 209}], {
             RGBColor[
             0.7806863695652173, 0.8239437391304347, 0.718572652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 245}], {
             RGBColor[
             0.7573136956521738, 0.8099539565217391, 0.9675244130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 286}], {
             RGBColor[
             0.7777357391304347, 0.8247040434782609, 0.9114311956521739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 290}], {
             RGBColor[
             0.7806863695652173, 0.8239437391304347, 0.718572652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 352}], {
             RGBColor[
             0.7806287826086956, 0.8259003913043478, 0.8634859782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 386}], {
             RGBColor[
             0.7806287826086956, 0.8259003913043478, 0.8634859782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 232}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 249}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 268}], {
             RGBColor[
             0.585956652173913, 0.6464003695652174, 0.7057408478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 370}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 238}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 245}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 187}], {
             RGBColor[
             0.9467338478260869, 0.9554450869565217, 0.7341753043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 208}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 323}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 377}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 388}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 395}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 270}], {
             RGBColor[
             0.9172722826086956, 0.9329257826086956, 0.8102031304347828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 291}], {
             RGBColor[
             0.9393703043478261, 0.7790215217391306, 0.4304839347826089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 357}], {
             RGBColor[
             0.876318804347826, 0.9007699565217391, 0.8061644347826089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 368}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 185}], {
             RGBColor[
             0.9467338478260869, 0.9554450869565217, 0.734175304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 190}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 226}], {
             RGBColor[
             0.9306052391304347, 0.9013377826086957, 0.6461551304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 252}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 274}], {
             RGBColor[
             0.9467338478260869, 0.9554450869565217, 0.734175304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 288}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 318}], {
             RGBColor[
             0.9467338478260869, 0.9554450869565217, 0.734175304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 190}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 226}], {
             RGBColor[
             0.976857695652174, 0.9332994347826087, 0.38996052173913043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 252}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 274}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 288}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 318}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 357}], {
             RGBColor[
             0.875593847826087, 0.899219347826087, 0.7272573913043477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 272}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 306}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 308}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 342}], {
             RGBColor[
             0.977582652173913, 0.934850043478261, 0.4688675652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 348}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 374}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 378}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 208}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 302}], {
             RGBColor[
             0.9306052391304347, 0.9013377826086957, 0.6461551304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 377}], {
             RGBColor[
             0.947458804347826, 0.9569956956521739, 0.8130823478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 388}], {
             RGBColor[
             0.947458804347826, 0.9569956956521739, 0.8130823478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 201}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 264}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 273}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 281}], {
             RGBColor[
             0.9768001086956521, 0.9352560869565217, 0.534873847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 293}], {
             RGBColor[
             0.9164897391304347, 0.9333318260869565, 0.8762094130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 394}], {
             RGBColor[0.8755362608695652, 0.901176, 0.8721707173913045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 207}], {
             RGBColor[0.905825, 0.92682, 0.9588341086956522]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{189, 241}], {
             RGBColor[
             0.9164897391304347, 0.9333318260869565, 0.8762094130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 263}], {
             RGBColor[
             0.9135966956521739, 0.9321354782608695, 0.9241546304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 280}], {
             RGBColor[
             0.9135966956521739, 0.9321354782608695, 0.9241546304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 291}], {
             RGBColor[
             0.8622063695652175, 0.7214393478260872, 0.6048922826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 336}], {
             RGBColor[
             0.7991548695652174, 0.8431877826086956, 0.9805727826086956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 359}], {
             RGBColor[0.905825, 0.92682, 0.9588341086956522]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{190, 226}], {
             RGBColor[
             0.9768001086956521, 0.9352560869565217, 0.534873847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 252}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 274}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 288}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 318}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 225}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 235}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 261}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 322}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 327}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 335}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 349}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 355}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 208}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 221}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 322}], {
             RGBColor[
             0.9863898695652173, 0.965453695652174, 0.4269912173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 335}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 349}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 351}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 355}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 399}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 195}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 242}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 253}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 255}], {
             RGBColor[0.9409797173913044, 0.871139695652174, 0.62151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 283}], {
             RGBColor[0.9409797173913044, 0.871139695652174, 0.62151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 312}], {
             RGBColor[
             0.7573136956521738, 0.8099539565217391, 0.9675244130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 332}], {
             RGBColor[
             0.958891304347826, 0.9688617826086956, 0.9544704782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 356}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 360}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 364}], {
             RGBColor[
             0.707998652173913, 0.7699177826086956, 0.9636421521739131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 380}], {
             RGBColor[
             0.946240956521739, 0.9594271739130434, 0.9758842173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 389}], {
             RGBColor[
             0.7573136956521738, 0.8099539565217391, 0.9675244130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 221}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 233}], {
             RGBColor[
             0.9393703043478261, 0.7790215217391306, 0.4304839347826089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 256}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 316}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 399}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 241}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 242}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.9643523913043479, 0.8851294782608696, 0.37255823913043473`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 263}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 312}], {
             RGBColor[
             0.7806863695652173, 0.8239437391304347, 0.718572652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 356}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 359}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 360}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 380}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 389}], {
             RGBColor[
             0.7806863695652173, 0.8239437391304347, 0.718572652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 206}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 214}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 286}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 332}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 334}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 366}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 386}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 217}], {
             RGBColor[
             0.9165473260869565, 0.9313751739130436, 0.7312960869565217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 231}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 254}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 314}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 369}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 392}], {
             RGBColor[
             0.9863898695652173, 0.965453695652174, 0.4269912173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 203}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 206}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 214}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 266}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 310}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 384}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 215}], {
             RGBColor[
             0.8292568913043479, 0.8630205652173913, 0.722638956521739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 222}], {
             RGBColor[
             0.8058842173913043, 0.8490307826086956, 0.9715907173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 223}], {
             RGBColor[
             0.8263062608695653, 0.8637808695652174, 0.9154975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 224}], {
             RGBColor[
             0.8292568913043479, 0.8630205652173913, 0.722638956521739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 247}], {
             RGBColor[
             0.829981847826087, 0.8645711739130435, 0.8015460000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 259}], {
             RGBColor[
             0.8292568913043479, 0.8630205652173913, 0.722638956521739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 271}], {
             RGBColor[
             0.8263062608695653, 0.8637808695652174, 0.9154975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 287}], {
             RGBColor[
             0.8263062608695653, 0.8637808695652174, 0.9154975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 292}], {
             RGBColor[
             0.8185345652173912, 0.8584653913043478, 0.9501769782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 345}], {
             RGBColor[
             0.8058842173913043, 0.8490307826086956, 0.9715907173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 350}], {
             RGBColor[
             0.8058842173913043, 0.8490307826086956, 0.9715907173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 353}], {
             RGBColor[
             0.7830044347826086, 0.8310589130434782, 0.9788335652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 393}], {
             RGBColor[
             0.8292568913043479, 0.8630205652173913, 0.722638956521739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 400}], {
             RGBColor[
             0.8058842173913043, 0.8490307826086956, 0.9715907173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 234}], {
             RGBColor[
             0.9614017608695653, 0.8858897826086958, 0.5654167826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 296}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 298}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 320}], {
             RGBColor[
             0.9237411521739131, 0.7239528695652174, 0.5344610869565217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 330}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 347}], {
             RGBColor[
             0.7777357391304347, 0.8247040434782609, 0.9114311956521739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 367}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 398}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 273}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 281}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 293}], {
             RGBColor[
             0.9135966956521739, 0.9321354782608695, 0.9241546304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 303}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 394}], {
             RGBColor[
             0.8726432173913043, 0.899979652173913, 0.9201159347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 212}], {
             RGBColor[
             0.7830044347826086, 0.8310589130434782, 0.9788335652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 234}], {
             RGBColor[
             0.9180999347826087, 0.8531678260869566, 0.628752847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 239}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 269}], {
             RGBColor[0.6851188695652173, 0.7519459130434782, 0.970885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 289}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 309}], {
             RGBColor[
             0.9360115217391303, 0.9508899130434783, 0.9617133260869566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 362}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 365}], {
             RGBColor[
             0.8589001956521738, 0.5288052173913043, 0.5772939565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 206}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 211}], {
             RGBColor[
             0.9768001086956521, 0.9352560869565217, 0.534873847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 216}], {
             RGBColor[0.8755362608695652, 0.901176, 0.8721707173913045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 266}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 329}], {
             RGBColor[0.8755362608695652, 0.901176, 0.8721707173913045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 341}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 358}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 229}], {
             RGBColor[
             0.9401374130434782, 0.9334920434782609, 0.6831858260869565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 237}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 307}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 343}], {
             RGBColor[
             0.9099508913043479, 0.9094221304347827, 0.6803066086956522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 232}], {
             RGBColor[
             0.947458804347826, 0.9569956956521739, 0.8130823478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 277}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 373}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 390}], {
             RGBColor[
             0.9180999347826087, 0.8531678260869566, 0.628752847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 266}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 286}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 386}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 231}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 280}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 291}], {
             RGBColor[
             0.9279230217391304, 0.772915739130435, 0.5791149130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 368}], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 372}], {
             RGBColor[
             0.8185345652173912, 0.8584653913043478, 0.9501769782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 387}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 392}], {
             RGBColor[
             0.9756675434782609, 0.9608985217391305, 0.6545292391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 221}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 225}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 323}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 351}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 388}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 395}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 286}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 290}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 304}], {
             RGBColor[
             0.7313713260869565, 0.7839075652173914, 0.7146903913043477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 338}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 386}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 230}], {
             RGBColor[
             0.9401374130434782, 0.9334920434782609, 0.6831858260869565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 258}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 264}], {
             RGBColor[
             0.9756675434782609, 0.9608985217391305, 0.6545292391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 279}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 328}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 394}], {
             RGBColor[
             0.8689974130434783, 0.8772663043478262, 0.6762679130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 216}], {
             RGBColor[
             0.8594652391304348, 0.8451120434782609, 0.6392372173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 238}], {
             RGBColor[
             0.9702612608695653, 0.9113463913043478, 0.3389710434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 341}], {
             RGBColor[
             0.976857695652174, 0.9332994347826087, 0.38996052173913043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 358}], {
             RGBColor[
             0.9768001086956521, 0.9352560869565217, 0.534873847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 239}], {
             RGBColor[
             0.8263062608695653, 0.8637808695652174, 0.9154975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 289}], {
             RGBColor[
             0.8263062608695653, 0.8637808695652174, 0.9154975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 309}], {
             RGBColor[
             0.8185345652173912, 0.8584653913043478, 0.9501769782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 362}], {
             RGBColor[
             0.8263062608695653, 0.8637808695652174, 0.9154975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 385}], {
             RGBColor[
             0.8131282826086956, 0.8089132608695653, 0.6346187826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 215}], {
             RGBColor[
             0.8292568913043479, 0.8630205652173913, 0.722638956521739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 227}], {
             RGBColor[
             0.8226604565217391, 0.8410675217391305, 0.6716494782608695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 259}], {
             RGBColor[
             0.8292568913043479, 0.8630205652173913, 0.722638956521739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 306}], {
             RGBColor[
             0.8292568913043479, 0.8630205652173913, 0.722638956521739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 308}], {
             RGBColor[
             0.8185345652173912, 0.8584653913043478, 0.9501769782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 345}], {
             RGBColor[
             0.8058842173913043, 0.8490307826086956, 0.9715907173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 350}], {
             RGBColor[
             0.8058842173913043, 0.8490307826086956, 0.9715907173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 378}], {
             RGBColor[
             0.8263062608695653, 0.8637808695652174, 0.9154975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 257}], {
             RGBColor[
             0.9135966956521739, 0.9321354782608695, 0.9241546304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 310}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 332}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 389}], {
             RGBColor[
             0.7777357391304347, 0.8247040434782609, 0.9114311956521739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 224}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 227}], {
             RGBColor[
             0.9863898695652173, 0.965453695652174, 0.4269912173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 259}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 345}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 350}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 353}], {
             RGBColor[
             0.9467338478260869, 0.9554450869565217, 0.7341753043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 393}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 400}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 229}], {
             RGBColor[0.8293413913043477, 0.8672576956521738, 0.983452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 294}], {
             RGBColor[0.8293413913043477, 0.8672576956521738, 0.983452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 329}], {
             RGBColor[
             0.7582013913043478, 0.8110319565217391, 0.9765340869565218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 340}], {
             RGBColor[0.8755362608695652, 0.901176, 0.8721707173913045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 341}], {
             RGBColor[
             0.875593847826087, 0.899219347826087, 0.7272573913043477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 343}], {
             RGBColor[
             0.7991548695652174, 0.8431877826086956, 0.9805727826086956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 358}], {
             RGBColor[0.8755362608695652, 0.901176, 0.8721707173913045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 231}], {
             RGBColor[
             0.9165473260869565, 0.9313751739130436, 0.7312960869565217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 254}], {
             RGBColor[
             0.893174652173913, 0.9173853913043478, 0.980247847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 314}], {
             RGBColor[0.905825, 0.92682, 0.9588341086956522]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{217, 331}], {
             RGBColor[
             0.9164897391304347, 0.9333318260869565, 0.8762094130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 392}], {
             RGBColor[
             0.9099508913043479, 0.9094221304347827, 0.6803066086956522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 222}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 276}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 282}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 305}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 339}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 361}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 382}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 384}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 248}], {
             RGBColor[
             0.9695560434782609, 0.9753736086956522, 0.8718457826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 251}], {
             RGBColor[0.6683507826086956, 0.7360231304347826, 0.9609925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 260}], {
             RGBColor[
             0.9152726739130435, 0.7634811304347828, 0.600528652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 352}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 396}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 256}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 316}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 351}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 399}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 223}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 224}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 247}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 259}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 292}], {
             RGBColor[
             0.958891304347826, 0.9688617826086956, 0.9544704782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 363}], {
             RGBColor[
             0.946240956521739, 0.9594271739130434, 0.9758842173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 383}], {
             RGBColor[
             0.9695560434782609, 0.9753736086956522, 0.8718457826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 393}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 247}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 292}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 319}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 385}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 393}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 400}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 227}], {
             RGBColor[
             0.9863898695652173, 0.965453695652174, 0.4269912173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 259}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 363}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 383}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 393}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 235}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 261}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 322}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 327}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 335}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 349}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 355}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 252}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 274}], {
             RGBColor[
             0.976857695652174, 0.9332994347826087, 0.38996052173913043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 288}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 315}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 318}], {
             RGBColor[
             0.976857695652174, 0.9332994347826087, 0.38996052173913043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 322}], {
             RGBColor[
             0.9702612608695653, 0.9113463913043478, 0.3389710434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 243}], {
             RGBColor[
             0.9756675434782609, 0.9608985217391305, 0.6545292391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 306}], {
             RGBColor[
             0.9863898695652173, 0.965453695652174, 0.4269912173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 311}], {
             RGBColor[
             0.9099508913043479, 0.9094221304347827, 0.6803066086956522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 346}], {
             RGBColor[
             0.9863898695652173, 0.965453695652174, 0.4269912173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 350}], {
             RGBColor[
             0.9630171956521738, 0.9514639130434783, 0.6759429782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 363}], {
             RGBColor[
             0.9630171956521738, 0.9514639130434783, 0.6759429782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 383}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 276}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 282}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 301}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 305}], {
             RGBColor[
             0.946240956521739, 0.9594271739130434, 0.9758842173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 382}], {
             RGBColor[
             0.946240956521739, 0.9594271739130434, 0.9758842173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 294}], {
             RGBColor[
             0.9004813913043477, 0.9234834347826086, 0.9903699130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 307}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[0.8293413913043477, 0.8672576956521738, 0.983452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 340}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 343}], {
             RGBColor[
             0.8702948695652173, 0.8994135217391304, 0.9874906956521738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 258}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 264}], {
             RGBColor[
             0.9360115217391303, 0.9508899130434783, 0.9617133260869566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 279}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 299}], {
             RGBColor[
             0.947458804347826, 0.9569956956521739, 0.8130823478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 300}], {
             RGBColor[
             0.9180999347826087, 0.8531678260869566, 0.628752847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 328}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 331}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 369}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 372}], {
             RGBColor[
             0.8292568913043479, 0.8630205652173913, 0.722638956521739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 392}], {
             RGBColor[
             0.9863898695652173, 0.965453695652174, 0.4269912173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 277}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 373}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 390}], {
             RGBColor[
             0.965077347826087, 0.8866800869565219, 0.4514652826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 256}], {
             RGBColor[
             0.9393703043478261, 0.7790215217391306, 0.4304839347826088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 257}], {
             RGBColor[
             0.8622063695652175, 0.7214393478260872, 0.6048922826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 310}], {
             RGBColor[
             0.9356947173913044, 0.7782312173913045, 0.5444354347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 316}], {
             RGBColor[
             0.9356947173913044, 0.7782312173913045, 0.5444354347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 389}], {
             RGBColor[
             0.7263454130434783, 0.6140079130434783, 0.5921688478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 298}], {
             RGBColor[
             0.9577559565217392, 0.8631764347826087, 0.3215687608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 365}], {
             RGBColor[
             0.8765187391304348, 0.45848960869565225`, 0.21567689130434786`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 261}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 322}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 327}], {
             RGBColor[
             0.947458804347826, 0.9569956956521739, 0.8130823478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 335}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 349}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 355}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 262}], {
             RGBColor[
             0.9306052391304347, 0.9013377826086957, 0.6461551304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 284}], {
             RGBColor[
             0.9360115217391303, 0.9508899130434783, 0.9617133260869566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 334}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 366}], {
             RGBColor[
             0.9401374130434782, 0.9334920434782609, 0.6831858260869565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 376}], {
             RGBColor[
             0.8702948695652173, 0.8994135217391304, 0.9874906956521738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 397}], {
             RGBColor[
             0.947458804347826, 0.9569956956521739, 0.8130823478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 307}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 324}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 269}], {
             RGBColor[
             0.7284206956521739, 0.7846678695652174, 0.9075489347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 309}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 323}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 362}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 365}], {
             RGBColor[
             0.9022020217391304, 0.5615271739130434, 0.5139578913043479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 377}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 385}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 388}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 272}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 342}], {
             RGBColor[
             0.9768001086956521, 0.9352560869565217, 0.534873847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 374}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 242}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 255}], {
             RGBColor[
             0.9642948043478261, 0.8870861304347827, 0.5174715652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 312}], {
             RGBColor[
             0.7806287826086956, 0.8259003913043478, 0.8634859782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 331}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 359}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 360}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 380}], {
             RGBColor[
             0.9695560434782609, 0.9753736086956522, 0.8718457826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 392}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 255}], {
             RGBColor[
             0.965077347826087, 0.8866800869565219, 0.4514652826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 312}], {
             RGBColor[
             0.7814113260869565, 0.825494347826087, 0.797479695652174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 331}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 380}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 267}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 275}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 311}], {
             RGBColor[0.905825, 0.92682, 0.9588341086956522]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{243, 326}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 344}], {
             RGBColor[
             0.8185345652173912, 0.8584653913043478, 0.9501769782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 346}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 363}], {
             RGBColor[
             0.958891304347826, 0.9688617826086956, 0.9544704782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 383}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 302}], {
             RGBColor[
             0.9661353695652174, 0.9287442608695653, 0.6174985434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 352}], {
             RGBColor[
             0.9695560434782609, 0.9753736086956522, 0.8718457826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 396}], {
             RGBColor[
             0.9695560434782609, 0.9753736086956522, 0.8718457826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 248}], {
             RGBColor[
             0.9768001086956521, 0.9352560869565217, 0.534873847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 251}], {
             RGBColor[
             0.675594847826087, 0.6959056086956521, 0.6240205652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 260}], {
             RGBColor[
             0.9225167391304349, 0.7233636086956523, 0.26355671739130443`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 326}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 271}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 287}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 292}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 319}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 362}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 385}], {
             RGBColor[
             0.977582652173913, 0.934850043478261, 0.4688675652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 393}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 400}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 251}], {
             RGBColor[
             0.6916658695652174, 0.7519695652173912, 0.8569540652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 260}], {
             RGBColor[
             0.9385877608695652, 0.7794275652173914, 0.49649021739130444`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 275}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 268}], {
             RGBColor[
             0.5858990652173913, 0.6483570217391305, 0.8506541739130435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 279}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 299}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 300}], {
             RGBColor[
             0.9642948043478261, 0.8870861304347827, 0.5174715652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 370}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 265}], {
             RGBColor[
             0.9756675434782609, 0.9608985217391305, 0.6545292391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 321}], {
             RGBColor[
             0.9630171956521738, 0.9514639130434783, 0.6759429782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 325}], {
             RGBColor[
             0.9756675434782609, 0.9608985217391305, 0.6545292391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 375}], {
             RGBColor[
             0.9756675434782609, 0.9608985217391305, 0.6545292391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 381}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 260}], {
             RGBColor[
             0.6373825000000001, 0.5400770869565219, 0.5856369347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 275}], {
             RGBColor[
             0.6887728260869566, 0.7507732173913043, 0.9048992826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 274}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 288}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 318}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 283}], {
             RGBColor[
             0.965077347826087, 0.8866800869565219, 0.4514652826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 332}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 334}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 364}], {
             RGBColor[
             0.7320962826086956, 0.7854581739130435, 0.7935974347826089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 366}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 391}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 314}], {
             RGBColor[
             0.958891304347826, 0.9688617826086956, 0.9544704782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 369}], {
             RGBColor[
             0.9695560434782609, 0.9753736086956522, 0.8718457826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 312}], {
             RGBColor[
             0.7520524565217391, 0.7216664782608696, 0.6131501956521739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 331}], {
             RGBColor[
             0.9642948043478261, 0.8870861304347827, 0.5174715652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 356}], {
             RGBColor[
             0.9614017608695653, 0.8858897826086958, 0.5654167826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 359}], {
             RGBColor[
             0.9536300652173912, 0.8805743043478262, 0.6000962608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 360}], {
             RGBColor[
             0.9643523913043479, 0.8851294782608696, 0.37255823913043473`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 380}], {
             RGBColor[0.9409797173913044, 0.871139695652174, 0.62151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 310}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 316}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 319}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 384}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 310}], {
             RGBColor[
             0.9135966956521739, 0.9321354782608695, 0.9241546304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 356}], {
             RGBColor[
             0.9135966956521739, 0.9321354782608695, 0.9241546304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 360}], {
             RGBColor[
             0.9165473260869565, 0.9313751739130436, 0.7312960869565217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 389}], {
             RGBColor[
             0.7042473913043479, 0.7679121739130434, 0.9718880434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 264}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 279}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 281}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 300}], {
             RGBColor[
             0.9614017608695653, 0.8858897826086958, 0.5654167826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 328}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 394}], {
             RGBColor[
             0.8726432173913043, 0.899979652173913, 0.9201159347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 271}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 287}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 292}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 345}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 350}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 353}], {
             RGBColor[
             0.9467338478260869, 0.9554450869565217, 0.7341753043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 393}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 400}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 327}], {
             RGBColor[
             0.9467338478260869, 0.9554450869565217, 0.7341753043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 335}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 349}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 355}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 284}], {
             RGBColor[
             0.9661353695652174, 0.9287442608695653, 0.6174985434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 325}], {
             RGBColor[
             0.9661353695652174, 0.9287442608695653, 0.6174985434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 376}], {
             RGBColor[
             0.9004187173913044, 0.8772678695652174, 0.6432759130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 397}], {
             RGBColor[
             0.977582652173913, 0.934850043478261, 0.4688675652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 336}], {
             RGBColor[
             0.8726432173913043, 0.899979652173913, 0.9201159347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 359}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 360}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 279}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 281}], {
             RGBColor[
             0.9661353695652174, 0.9287442608695653, 0.6174985434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 328}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 394}], {
             RGBColor[
             0.8648715217391304, 0.8946641739130434, 0.9547954130434784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 321}], {
             RGBColor[
             0.958891304347826, 0.9688617826086956, 0.9544704782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 325}], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 375}], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 381}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 358}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 384}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 275}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 306}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 311}], {
             RGBColor[
             0.9165473260869565, 0.9313751739130436, 0.7312960869565217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 317}], {
             RGBColor[
             0.9467338478260869, 0.9554450869565217, 0.7341753043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 344}], {
             RGBColor[
             0.8292568913043479, 0.8630205652173913, 0.722638956521739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 346}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 354}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 279}], {
             RGBColor[
             0.5830060217391304, 0.6471606739130435, 0.8985993913043478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 299}], {
             RGBColor[
             0.5866816086956521, 0.6479509782608697, 0.784647891304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 300}], {
             RGBColor[
             0.5573227391304347, 0.5441231086956523, 0.6003183913043478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 370}], {
             RGBColor[
             0.585956652173913, 0.6464003695652174, 0.7057408478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 371}], {
             RGBColor[
             0.5095176739130436, 0.5903688043478261, 0.9590562391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 309}], {
             RGBColor[
             0.7206489999999999, 0.7793523913043479, 0.9422284130434784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 323}], {
             RGBColor[
             0.7284206956521739, 0.7846678695652174, 0.9075489347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 362}], {
             RGBColor[
             0.7284206956521739, 0.7846678695652174, 0.9075489347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 365}], {
             RGBColor[
             0.6435376739130435, 0.3572676956521739, 0.5578090434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 377}], {
             RGBColor[
             0.7320962826086956, 0.7854581739130435, 0.7935974347826089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 388}], {
             RGBColor[
             0.7320962826086956, 0.7854581739130435, 0.7935974347826089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 336}], {
             RGBColor[
             0.7991548695652174, 0.8431877826086956, 0.9805727826086956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 357}], {
             RGBColor[
             0.7991548695652174, 0.8431877826086956, 0.9805727826086956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 287}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 292}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 303}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 333}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 337}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 345}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 353}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 385}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 391}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 400}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 308}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 342}], {
             RGBColor[
             0.977582652173913, 0.934850043478261, 0.4688675652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 348}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 374}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 375}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 378}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 281}], {
             RGBColor[
             0.9661353695652174, 0.9287442608695653, 0.6174985434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 293}], {
             RGBColor[0.905825, 0.92682, 0.9588341086956522]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{273, 394}], {
             RGBColor[
             0.8648715217391304, 0.8946641739130434, 0.9547954130434784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 288}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 318}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 311}], {
             RGBColor[
             0.9135966956521739, 0.9321354782608695, 0.9241546304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 317}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 344}], {
             RGBColor[
             0.8263062608695653, 0.8637808695652174, 0.9154975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 346}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 282}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 301}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 305}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 339}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 361}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 382}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 373}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 390}], {
             RGBColor[
             0.9642948043478261, 0.8870861304347827, 0.5174715652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 296}], {
             RGBColor[
             0.976857695652174, 0.9332994347826087, 0.38996052173913043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 302}], {
             RGBColor[
             0.976857695652174, 0.9332994347826087, 0.38996052173913043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 330}], {
             RGBColor[
             0.9467338478260869, 0.9554450869565217, 0.7341753043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 367}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 299}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 300}], {
             RGBColor[
             0.9614017608695653, 0.8858897826086958, 0.5654167826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 328}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 370}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 371}], {
             RGBColor[
             0.9135966956521739, 0.9321354782608695, 0.9241546304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 291}], {
             RGBColor[
             0.9356947173913044, 0.7782312173913045, 0.5444354347826088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 336}], {
             RGBColor[
             0.8726432173913043, 0.899979652173913, 0.9201159347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 368}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 387}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 392}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 293}], {
             RGBColor[
             0.9004187173913044, 0.8772678695652174, 0.6432759130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 394}], {
             RGBColor[
             0.8594652391304348, 0.8451120434782609, 0.6392372173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 301}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 305}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 313}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 339}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 340}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 361}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 382}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 312}], {
             RGBColor[
             0.7520524565217391, 0.7216664782608696, 0.6131501956521739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 332}], {
             RGBColor[
             0.9536300652173912, 0.8805743043478262, 0.6000962608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 334}], {
             RGBColor[
             0.9642948043478261, 0.8870861304347827, 0.5174715652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 356}], {
             RGBColor[
             0.9614017608695653, 0.8858897826086958, 0.5654167826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 360}], {
             RGBColor[
             0.9643523913043479, 0.8851294782608696, 0.37255823913043473`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 364}], {
             RGBColor[
             0.7027374130434783, 0.6816303043478262, 0.6092679347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 366}], {
             RGBColor[
             0.9577559565217392, 0.8631764347826087, 0.3215687608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 380}], {
             RGBColor[0.9409797173913044, 0.871139695652174, 0.62151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 389}], {
             RGBColor[
             0.7520524565217391, 0.7216664782608696, 0.6131501956521739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 334}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 366}], {
             RGBColor[
             0.9756675434782609, 0.9608985217391305, 0.6545292391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 397}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 324}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 290}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 304}], {
             RGBColor[
             0.7284206956521739, 0.7846678695652174, 0.9075489347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 386}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 292}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 303}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 353}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 385}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 391}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 400}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 318}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 304}], {
             RGBColor[
             0.7313713260869565, 0.7839075652173914, 0.7146903913043477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 338}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 336}], {
             RGBColor[
             0.8212528913043479, 0.6892835217391307, 0.6008535869565218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 368}], {
             RGBColor[
             0.9279230217391304, 0.772915739130435, 0.5791149130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 387}], {
             RGBColor[
             0.9393703043478261, 0.7790215217391306, 0.4304839347826088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 303}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 309}], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 362}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 385}], {
             RGBColor[
             0.9661353695652174, 0.9287442608695653, 0.6174985434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 400}], {
             RGBColor[
             0.958891304347826, 0.9688617826086956, 0.9544704782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 394}], {
             RGBColor[
             0.7991548695652174, 0.8431877826086956, 0.9805727826086956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 301}], {
             RGBColor[
             0.947458804347826, 0.9569956956521739, 0.8130823478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 313}], {
             RGBColor[
             0.9437832173913043, 0.9562053913043478, 0.9270338478260869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 329}], {
             RGBColor[0.8293413913043477, 0.8672576956521738, 0.983452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 340}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 343}], {
             RGBColor[
             0.8702948695652173, 0.8994135217391304, 0.9874906956521738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 330}], {
             RGBColor[
             0.9306052391304347, 0.9013377826086957, 0.6461551304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 367}], {
             RGBColor[
             0.9768001086956521, 0.9352560869565217, 0.534873847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 398}], {
             RGBColor[
             0.977582652173913, 0.934850043478261, 0.4688675652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 325}], {
             RGBColor[0.905825, 0.92682, 0.9588341086956522]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{297, 375}], {
             RGBColor[0.905825, 0.92682, 0.9588341086956522]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{297, 376}], {
             RGBColor[
             0.840108347826087, 0.8753436086956522, 0.9846114782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 378}], {
             RGBColor[
             0.9135966956521739, 0.9321354782608695, 0.9241546304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 397}], {
             RGBColor[
             0.9172722826086956, 0.9329257826086956, 0.8102031304347828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 320}], {
             RGBColor[
             0.9200953478260869, 0.7012395217391305, 0.2906130652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 347}], {
             RGBColor[
             0.7740899347826087, 0.8019906956521738, 0.6675831739130434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 373}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 390}], {
             RGBColor[
             0.9577559565217392, 0.8631764347826087, 0.3215687608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 300}], {
             RGBColor[
             0.965077347826087, 0.8866800869565219, 0.4514652826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 370}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 371}], {
             RGBColor[
             0.9172722826086956, 0.9329257826086956, 0.8102031304347828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 370}], {
             RGBColor[
             0.9643523913043479, 0.8851294782608696, 0.37255823913043473`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 371}], {
             RGBColor[
             0.8879134130434783, 0.8290979130434784, 0.6258736304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 305}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 313}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 329}], {
             RGBColor[
             0.876318804347826, 0.9007699565217391, 0.8061644347826089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 339}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 340}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 361}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 382}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 367}], {
             RGBColor[
             0.9768001086956521, 0.9352560869565217, 0.534873847826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 377}], {
             RGBColor[
             0.977582652173913, 0.934850043478261, 0.4688675652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 353}], {
             RGBColor[
             0.947458804347826, 0.9569956956521739, 0.8130823478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 385}], {
             RGBColor[
             0.977582652173913, 0.934850043478261, 0.4688675652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 391}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 400}], {
             RGBColor[
             0.9703385869565218, 0.9749675652173913, 0.8058395000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 338}], {
             RGBColor[
             0.7284206956521739, 0.7846678695652174, 0.9075489347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 313}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 329}], {
             RGBColor[
             0.8522211739130434, 0.8852295652173913, 0.9762091521739131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 339}], {
             RGBColor[
             0.958891304347826, 0.9688617826086956, 0.9544704782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 340}], {
             RGBColor[
             0.9695560434782609, 0.9753736086956522, 0.8718457826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 361}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 382}], {
             RGBColor[
             0.946240956521739, 0.9594271739130434, 0.9758842173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 308}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 311}], {
             RGBColor[
             0.9165473260869565, 0.9313751739130436, 0.7312960869565217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 346}], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 348}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 350}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 354}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 378}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 343}], {
             RGBColor[
             0.9164897391304347, 0.9333318260869565, 0.8762094130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 348}], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 354}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 374}], {
             RGBColor[
             0.9756675434782609, 0.9608985217391305, 0.6545292391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 378}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 323}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 362}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 365}], {
             RGBColor[
             0.8944303260869565, 0.5562116956521739, 0.5486373695652174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 385}], {
             RGBColor[
             0.9661353695652174, 0.9287442608695653, 0.6174985434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 316}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 319}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 384}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 317}], {
             RGBColor[
             0.8702948695652173, 0.8994135217391304, 0.9874906956521738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 344}], {
             RGBColor[0.7528179130434782, 0.806989, 0.975954347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 346}], {
             RGBColor[
             0.9165473260869565, 0.9313751739130436, 0.7312960869565217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 354}], {
             RGBColor[
             0.9164897391304347, 0.9333318260869565, 0.8762094130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 356}], {
             RGBColor[
             0.7777357391304347, 0.8247040434782609, 0.9114311956521739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 359}], {
             RGBColor[
             0.7699640434782609, 0.8193885652173913, 0.9461106739130435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 360}], {
             RGBColor[
             0.7806863695652173, 0.8239437391304347, 0.718572652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 380}], {
             RGBColor[
             0.7573136956521738, 0.8099539565217391, 0.9675244130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 389}], {
             RGBColor[
             0.5683864347826086, 0.6604807391304347, 0.9591646086956521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 329}], {
             RGBColor[
             0.8726432173913043, 0.899979652173913, 0.9201159347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 339}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 340}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 358}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 361}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 369}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 322}], {
             RGBColor[0.9834392391304347, 0.966214, 0.6198497608695652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 351}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 399}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 344}], {
             RGBColor[
             0.7830044347826086, 0.8310589130434782, 0.9788335652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 346}], {
             RGBColor[
             0.9467338478260869, 0.9554450869565217, 0.734175304347826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 354}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 322}], {
             RGBColor[
             0.9863898695652173, 0.965453695652174, 0.4269912173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 384}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 347}], {
             RGBColor[0.7143918478260869, 0.5597295652173913, 0.5821945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 398}], {
             RGBColor[
             0.9274167391304349, 0.7247431739130434, 0.42050958695652185`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 375}], {
             RGBColor[
             0.958891304347826, 0.9688617826086956, 0.9544704782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 381}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 327}], {
             RGBColor[
             0.9401374130434782, 0.9334920434782609, 0.6831858260869565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 335}], {
             RGBColor[
             0.9871148260869566, 0.9670043043478261, 0.5058982608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 349}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 355}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 362}], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 365}], {
             RGBColor[
             0.9022020217391304, 0.5615271739130434, 0.5139578913043479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 377}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 388}], {
             RGBColor[
             0.9907606304347827, 0.989717652173913, 0.7497462826086958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 395}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 376}], {
             RGBColor[0.905825, 0.92682, 0.9588341086956522]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{325, 397}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 363}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 383}], {
             RGBColor[
             0.9899780869565218, 0.990123695652174, 0.8157525652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 335}], {
             RGBColor[
             0.947458804347826, 0.9569956956521739, 0.8130823478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 349}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 355}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 339}], {
             RGBColor[
             0.8648715217391304, 0.8946641739130434, 0.9547954130434784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 340}], {
             RGBColor[0.8755362608695652, 0.901176, 0.8721707173913045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 341}], {
             RGBColor[
             0.875593847826087, 0.899219347826087, 0.7272573913043477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 343}], {
             RGBColor[
             0.7991548695652174, 0.8431877826086956, 0.9805727826086956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 358}], {
             RGBColor[0.8755362608695652, 0.901176, 0.8721707173913045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 367}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 398}], {
             RGBColor[
             0.947458804347826, 0.9569956956521739, 0.8130823478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 392}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 334}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 356}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 364}], {
             RGBColor[0.720649, 0.7793523913043479, 0.9422284130434784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 366}], {
             RGBColor[
             0.9756675434782609, 0.9608985217391305, 0.6545292391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 380}], {
             RGBColor[
             0.958891304347826, 0.9688617826086956, 0.9544704782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 389}], {
             RGBColor[
             0.7699640434782609, 0.8193885652173913, 0.9461106739130435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 337}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 345}], {
             RGBColor[
             0.9695560434782609, 0.9753736086956522, 0.8718457826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 353}], {
             RGBColor[
             0.9466762608695651, 0.9574017391304348, 0.8790886304347827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 391}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 364}], {
             RGBColor[
             0.7313137391304347, 0.7858642173913044, 0.8596037173913045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 366}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 391}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 349}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 355}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 359}], {
             RGBColor[
             0.8648715217391304, 0.8946641739130434, 0.9547954130434784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 345}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 353}], {
             RGBColor[
             0.9467338478260869, 0.9554450869565217, 0.7341753043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 391}], {
             RGBColor[
             0.9937112608695653, 0.988957347826087, 0.5568877391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 340}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 361}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 382}], {
             RGBColor[
             0.958891304347826, 0.9688617826086956, 0.9544704782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 343}], {
             RGBColor[
             0.9164897391304347, 0.9333318260869565, 0.8762094130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 358}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 361}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 358}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 348}], {
             RGBColor[
             0.9661353695652174, 0.9287442608695653, 0.6174985434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 374}], {
             RGBColor[
             0.9702612608695653, 0.9113463913043478, 0.3389710434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 346}], {
             RGBColor[
             0.8292568913043479, 0.8630205652173913, 0.722638956521739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 354}], {
             RGBColor[
             0.8291993043478261, 0.8649772173913044, 0.8675522826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 350}], {
             RGBColor[
             0.946240956521739, 0.9594271739130434, 0.9758842173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 353}], {
             RGBColor[
             0.9233611739130434, 0.941455304347826, 0.9831270652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 354}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 398}], {
             RGBColor[
             0.7814113260869565, 0.825494347826087, 0.797479695652174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 354}], {
             RGBColor[
             0.9822063913043477, 0.9848082173913044, 0.850432043478261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 374}], {
             RGBColor[
             0.9756675434782609, 0.9608985217391305, 0.6545292391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 378}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 355}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 355}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 395}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 399}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 396}], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 391}], {
             RGBColor[
             0.947458804347826, 0.9569956956521739, 0.8130823478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 400}], {
             RGBColor[
             0.9233611739130434, 0.941455304347826, 0.9831270652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 374}], {
             RGBColor[
             0.9863322826086957, 0.9674103478260869, 0.5719045434782609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 359}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 360}], {
             RGBColor[
             0.9900356739130435, 0.9881670434782609, 0.6708392391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 364}], {
             RGBColor[
             0.7284206956521739, 0.7846678695652174, 0.9075489347826087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 380}], {
             RGBColor[0.9666629999999999, 0.9741772608695651, 0.919791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 389}], {
             RGBColor[
             0.7777357391304347, 0.8247040434782609, 0.9114311956521739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 360}], {
             RGBColor[
             0.9822639782608695, 0.9828515652173914, 0.7055187173913043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 380}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 389}], {
             RGBColor[
             0.7806863695652173, 0.8239437391304347, 0.718572652173913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 382}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 365}], {
             RGBColor[
             0.9022020217391304, 0.5615271739130434, 0.5139578913043479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 385}], {
             RGBColor[
             0.9739070652173913, 0.9340597391304348, 0.5828190652173914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 383}], {
             RGBColor[
             0.9695560434782609, 0.9753736086956522, 0.8718457826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 393}], {
             RGBColor[
             0.9696136304347825, 0.9734169565217392, 0.7269324565217391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 366}], {
             RGBColor[
             0.7247748913043479, 0.7619545217391305, 0.6637009130434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 380}], {
             RGBColor[
             0.707998652173913, 0.7699177826086956, 0.9636421521739131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 391}], {
             RGBColor[
             0.7320962826086956, 0.7854581739130435, 0.7935974347826089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 377}], {
             RGBColor[
             0.9058776086956521, 0.5623174782608695, 0.400006391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 388}], {
             RGBColor[
             0.9058776086956521, 0.5623174782608695, 0.400006391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 372}], {
             RGBColor[
             0.8185345652173912, 0.8584653913043478, 0.9501769782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 387}], {
             RGBColor[
             0.9829889347826086, 0.9844021739130435, 0.7844257608695654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 387}], {
             RGBColor[
             0.829981847826087, 0.8645711739130435, 0.8015460000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 392}], {
             RGBColor[
             0.8226604565217391, 0.8410675217391305, 0.6716494782608695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 390}], {
             RGBColor[
             0.9614017608695653, 0.8858897826086958, 0.5654167826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 381}], {
             RGBColor[
             0.9793133478260869, 0.9836118695652174, 0.8983772608695653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 397}], {
             RGBColor[
             0.9172722826086956, 0.9329257826086956, 0.8102031304347828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 388}], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 389}], {
             RGBColor[
             0.7573136956521738, 0.8099539565217391, 0.9675244130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 393}], {
             RGBColor[
             0.9929287173913044, 0.9893633913043478, 0.6228940217391304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 400}], {
             RGBColor[
             0.9534850217391304, 0.919309652173913, 0.6389122826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 395}], {
             RGBColor[
             0.9936536739130435, 0.9909140000000001, 0.7018010652173915]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.027885652381746694`], {
             RGBColor[
             0.9797934347826087, 0.9435006521739131, 0.3760017391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.027885652381746694`], {
             RGBColor[
             0.9004813913043477, 0.9234834347826086, 0.9903699130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.027885652381746694`], {
             RGBColor[
             0.9087257826086957, 0.6758351739130438, 0.24541682608695659`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.027885652381746694`], {
             RGBColor[
             0.9357184782608696, 0.7828522173913045, 0.2671357826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.027885652381746694`], {
             RGBColor[
             0.6655274782608696, 0.7386343913043478, 0.9672972173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.027885652381746694`], {
             RGBColor[
             0.9357184782608696, 0.7828522173913045, 0.2671357826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.027885652381746694`], {
             RGBColor[
             0.7582013913043478, 0.8110319565217391, 0.9765340869565218]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.027885652381746694`], {
             RGBColor[
             0.7582013913043478, 0.8110319565217391, 0.9765340869565218]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.027885652381746694`], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.027885652381746694`], {
             RGBColor[
             0.840108347826087, 0.8753436086956522, 0.9846114782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.027885652381746694`], {
             RGBColor[
             0.9607290869565218, 0.8791921304347826, 0.30194034782608703`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.027885652381746694`], {
             RGBColor[
             0.9357184782608696, 0.7828522173913045, 0.2671357826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.027885652381746694`], {
             RGBColor[
             0.9797934347826087, 0.9435006521739131, 0.3760017391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.027885652381746694`], {
             RGBColor[
             0.9797934347826087, 0.9435006521739131, 0.3760017391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.027885652381746694`], {
             RGBColor[
             0.9004813913043477, 0.9234834347826086, 0.9903699130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.027885652381746694`], {
             RGBColor[
             0.946240956521739, 0.9594271739130434, 0.9758842173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.027885652381746694`], {
             RGBColor[
             0.9004813913043477, 0.9234834347826086, 0.9903699130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.027885652381746694`], {
             RGBColor[
             0.9797934347826087, 0.9435006521739131, 0.3760017391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.027885652381746694`], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.027885652381746694`], {
             RGBColor[
             0.5683864347826086, 0.6604807391304347, 0.9591646086956521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.027885652381746694`], {
             RGBColor[
             0.9607290869565218, 0.8791921304347826, 0.30194034782608703`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.027885652381746694`], {
             RGBColor[
             0.9004813913043477, 0.9234834347826086, 0.9903699130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.027885652381746694`], {
             RGBColor[
             0.9004813913043477, 0.9234834347826086, 0.9903699130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.027885652381746694`], {
             RGBColor[
             0.9004813913043477, 0.9234834347826086, 0.9903699130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.027885652381746694`], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.027885652381746694`], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.027885652381746694`], {
             RGBColor[
             0.9797934347826087, 0.9435006521739131, 0.3760017391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.027885652381746694`], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.027885652381746694`], {
             RGBColor[
             0.9357184782608696, 0.7828522173913045, 0.2671357826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.027885652381746694`], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.027885652381746694`], {
             RGBColor[
             0.8843043913043479, 0.5675350869565221, 0.2251730869565218]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.027885652381746694`], {
             RGBColor[
             0.946240956521739, 0.9594271739130434, 0.9758842173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.027885652381746694`], {
             RGBColor[
             0.8843043913043479, 0.5675350869565221, 0.2251730869565218]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.027885652381746694`], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.027885652381746694`], {
             RGBColor[
             0.946240956521739, 0.9594271739130434, 0.9758842173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.027885652381746694`], {
             RGBColor[
             0.9004813913043477, 0.9234834347826086, 0.9903699130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.027885652381746694`], {
             RGBColor[
             0.9607290869565218, 0.8791921304347826, 0.30194034782608703`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.027885652381746694`], {
             RGBColor[
             0.9087257826086957, 0.6758351739130438, 0.24541682608695659`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.027885652381746694`], {
             RGBColor[
             0.3904606086956522, 0.5126190869565217, 0.9461007826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.027885652381746694`], {
             RGBColor[
             0.9607290869565218, 0.8791921304347826, 0.30194034782608703`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.027885652381746694`], {
             RGBColor[
             0.9797934347826087, 0.9435006521739131, 0.3760017391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.027885652381746694`], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.027885652381746694`], {
             RGBColor[
             0.9357184782608696, 0.7828522173913045, 0.2671357826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.027885652381746694`], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.027885652381746694`], {
             RGBColor[
             0.9797934347826087, 0.9435006521739131, 0.3760017391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.027885652381746694`], {
             RGBColor[
             0.6655274782608696, 0.7386343913043478, 0.9672972173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.027885652381746694`], {
             RGBColor[
             0.9004813913043477, 0.9234834347826086, 0.9903699130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.027885652381746694`], {
             RGBColor[
             0.9607290869565218, 0.8791921304347826, 0.30194034782608703`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.027885652381746694`], {
             RGBColor[
             0.9087257826086957, 0.6758351739130438, 0.24541682608695659`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.027885652381746694`], {
             RGBColor[
             0.840108347826087, 0.8753436086956522, 0.9846114782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.027885652381746694`], {
             RGBColor[
             0.9004813913043477, 0.9234834347826086, 0.9903699130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.027885652381746694`], {
             RGBColor[
             0.840108347826087, 0.8753436086956522, 0.9846114782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.027885652381746694`], {
             RGBColor[
             0.946240956521739, 0.9594271739130434, 0.9758842173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.027885652381746694`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.027885652381746694`], {
             RGBColor[
             0.9797934347826087, 0.9435006521739131, 0.3760017391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.027885652381746694`], {
             RGBColor[
             0.840108347826087, 0.8753436086956522, 0.9846114782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.027885652381746694`], {
             RGBColor[
             0.946240956521739, 0.9594271739130434, 0.9758842173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.027885652381746694`], {
             RGBColor[
             0.946240956521739, 0.9594271739130434, 0.9758842173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.027885652381746694`], {
             RGBColor[
             0.7582013913043478, 0.8110319565217391, 0.9765340869565218]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.027885652381746694`], {
             RGBColor[
             0.6655274782608696, 0.7386343913043478, 0.9672972173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.027885652381746694`], {
             RGBColor[
             0.9607290869565218, 0.8791921304347826, 0.30194034782608703`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.027885652381746694`], {
             RGBColor[
             0.8843043913043479, 0.5675350869565221, 0.2251730869565218]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.027885652381746694`], {
             RGBColor[
             0.9607290869565218, 0.8791921304347826, 0.30194034782608703`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.027885652381746694`], {
             RGBColor[
             0.9357184782608696, 0.7828522173913045, 0.2671357826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.027885652381746694`], {
             RGBColor[
             0.9607290869565218, 0.8791921304347826, 0.30194034782608703`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.027885652381746694`], {
             RGBColor[
             0.946240956521739, 0.9594271739130434, 0.9758842173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.027885652381746694`], {
             RGBColor[
             0.6655274782608696, 0.7386343913043478, 0.9672972173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.027885652381746694`], {
             RGBColor[
             0.840108347826087, 0.8753436086956522, 0.9846114782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.027885652381746694`], {
             RGBColor[
             0.9004813913043477, 0.9234834347826086, 0.9903699130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.027885652381746694`], {
             RGBColor[
             0.8603972608695653, 0.45897839130434787`, 0.20522439130434783`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.027885652381746694`], {
             RGBColor[
             0.9607290869565218, 0.8791921304347826, 0.30194034782608703`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.027885652381746694`], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.027885652381746694`], {
             RGBColor[
             0.46975634782608694`, 0.5804083913043478, 0.9514000869565218]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.027885652381746694`], {
             RGBColor[
             0.8843043913043479, 0.5675350869565221, 0.2251730869565218]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.027885652381746694`], {
             RGBColor[
             0.9797934347826087, 0.9435006521739131, 0.3760017391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.027885652381746694`], {
             RGBColor[
             0.9797934347826087, 0.9435006521739131, 0.3760017391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.027885652381746694`], {
             RGBColor[
             0.5683864347826086, 0.6604807391304347, 0.9591646086956521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.027885652381746694`], {
             RGBColor[
             0.9004813913043477, 0.9234834347826086, 0.9903699130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.027885652381746694`], {
             RGBColor[
             0.840108347826087, 0.8753436086956522, 0.9846114782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.027885652381746694`], {
             RGBColor[
             0.5683864347826086, 0.6604807391304347, 0.9591646086956521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.027885652381746694`], {
             RGBColor[
             0.9004813913043477, 0.9234834347826086, 0.9903699130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.027885652381746694`], {
             RGBColor[
             0.9004813913043477, 0.9234834347826086, 0.9903699130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.027885652381746694`], {
             RGBColor[
             0.840108347826087, 0.8753436086956522, 0.9846114782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.027885652381746694`], {
             RGBColor[
             0.946240956521739, 0.9594271739130434, 0.9758842173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.027885652381746694`], {
             RGBColor[
             0.6655274782608696, 0.7386343913043478, 0.9672972173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.027885652381746694`], {
             RGBColor[
             0.9004813913043477, 0.9234834347826086, 0.9903699130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.027885652381746694`], {
             RGBColor[
             0.9797934347826087, 0.9435006521739131, 0.3760017391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.027885652381746694`], {
             RGBColor[
             0.9004813913043477, 0.9234834347826086, 0.9903699130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.027885652381746694`], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.027885652381746694`], {
             RGBColor[
             0.9797934347826087, 0.9435006521739131, 0.3760017391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.027885652381746694`], {
             RGBColor[
             0.9607290869565218, 0.8791921304347826, 0.30194034782608703`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.027885652381746694`], {
             RGBColor[
             0.6655274782608696, 0.7386343913043478, 0.9672972173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.027885652381746694`], {
             RGBColor[
             0.6655274782608696, 0.7386343913043478, 0.9672972173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.027885652381746694`], {
             RGBColor[
             0.7582013913043478, 0.8110319565217391, 0.9765340869565218]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.027885652381746694`], {
             RGBColor[
             0.840108347826087, 0.8753436086956522, 0.9846114782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.027885652381746694`], {
             RGBColor[
             0.946240956521739, 0.9594271739130434, 0.9758842173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.027885652381746694`], {
             RGBColor[
             0.9004813913043477, 0.9234834347826086, 0.9903699130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.027885652381746694`], {
             RGBColor[
             0.946240956521739, 0.9594271739130434, 0.9758842173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.027885652381746694`], {
             RGBColor[
             0.9607290869565218, 0.8791921304347826, 0.30194034782608703`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.027885652381746694`], {
             RGBColor[
             0.9797934347826087, 0.9435006521739131, 0.3760017391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.027885652381746694`], {
             RGBColor[
             0.946240956521739, 0.9594271739130434, 0.9758842173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.027885652381746694`], {
             RGBColor[
             0.9004813913043477, 0.9234834347826086, 0.9903699130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.027885652381746694`], {
             RGBColor[
             0.9004813913043477, 0.9234834347826086, 0.9903699130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.027885652381746694`], {
             RGBColor[
             0.8843043913043479, 0.5675350869565221, 0.2251730869565218]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.027885652381746694`], {
             RGBColor[
             0.9357184782608696, 0.7828522173913045, 0.2671357826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.027885652381746694`], {
             RGBColor[
             0.9004813913043477, 0.9234834347826086, 0.9903699130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.027885652381746694`], {
             RGBColor[
             0.9797934347826087, 0.9435006521739131, 0.3760017391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.027885652381746694`], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.027885652381746694`], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.027885652381746694`], {
             RGBColor[
             0.946240956521739, 0.9594271739130434, 0.9758842173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.027885652381746694`], {
             RGBColor[
             0.9607290869565218, 0.8791921304347826, 0.30194034782608703`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.027885652381746694`], {
             RGBColor[
             0.9797934347826087, 0.9435006521739131, 0.3760017391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.027885652381746694`], {
             RGBColor[
             0.3904606086956522, 0.5126190869565217, 0.9461007826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.027885652381746694`], {
             RGBColor[
             0.946240956521739, 0.9594271739130434, 0.9758842173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.027885652381746694`], {
             RGBColor[
             0.9357184782608696, 0.7828522173913045, 0.2671357826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.027885652381746694`], {
             RGBColor[
             0.840108347826087, 0.8753436086956522, 0.9846114782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.027885652381746694`], {
             RGBColor[
             0.8843043913043479, 0.5675350869565221, 0.2251730869565218]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.027885652381746694`], {
             RGBColor[
             0.9607290869565218, 0.8791921304347826, 0.30194034782608703`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.027885652381746694`], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.027885652381746694`], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.027885652381746694`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.027885652381746694`], {
             RGBColor[
             0.46975634782608694`, 0.5804083913043478, 0.9514000869565218]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.027885652381746694`], {
             RGBColor[
             0.840108347826087, 0.8753436086956522, 0.9846114782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.027885652381746694`], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.027885652381746694`], {
             RGBColor[
             0.9607290869565218, 0.8791921304347826, 0.30194034782608703`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.027885652381746694`], {
             RGBColor[
             0.9357184782608696, 0.7828522173913045, 0.2671357826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.027885652381746694`], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.027885652381746694`], {
             RGBColor[
             0.946240956521739, 0.9594271739130434, 0.9758842173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.027885652381746694`], {
             RGBColor[
             0.8843043913043479, 0.5675350869565221, 0.2251730869565218]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.027885652381746694`], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.027885652381746694`], {
             RGBColor[
             0.840108347826087, 0.8753436086956522, 0.9846114782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.027885652381746694`], {
             RGBColor[
             0.9004813913043477, 0.9234834347826086, 0.9903699130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.027885652381746694`], {
             RGBColor[
             0.9607290869565218, 0.8791921304347826, 0.30194034782608703`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.027885652381746694`], {
             RGBColor[
             0.840108347826087, 0.8753436086956522, 0.9846114782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.027885652381746694`], {
             RGBColor[
             0.9797934347826087, 0.9435006521739131, 0.3760017391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.027885652381746694`], {
             RGBColor[
             0.9357184782608696, 0.7828522173913045, 0.2671357826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.027885652381746694`], {
             RGBColor[
             0.9607290869565218, 0.8791921304347826, 0.30194034782608703`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.027885652381746694`], {
             RGBColor[
             0.46975634782608694`, 0.5804083913043478, 0.9514000869565218]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.027885652381746694`], {
             RGBColor[
             0.946240956521739, 0.9594271739130434, 0.9758842173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.027885652381746694`], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.027885652381746694`], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.027885652381746694`], {
             RGBColor[
             0.840108347826087, 0.8753436086956522, 0.9846114782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.027885652381746694`], {
             RGBColor[
             0.5683864347826086, 0.6604807391304347, 0.9591646086956521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.027885652381746694`], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.027885652381746694`], {
             RGBColor[
             0.9004813913043477, 0.9234834347826086, 0.9903699130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.027885652381746694`], {
             RGBColor[
             0.8603972608695653, 0.45897839130434787`, 0.20522439130434783`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.027885652381746694`], {
             RGBColor[
             0.946240956521739, 0.9594271739130434, 0.9758842173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.027885652381746694`], {
             RGBColor[
             0.9797934347826087, 0.9435006521739131, 0.3760017391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.027885652381746694`], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.027885652381746694`], {
             RGBColor[
             0.9004813913043477, 0.9234834347826086, 0.9903699130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.027885652381746694`], {
             RGBColor[
             0.7582013913043478, 0.8110319565217391, 0.9765340869565218]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.027885652381746694`], {
             RGBColor[
             0.9004813913043477, 0.9234834347826086, 0.9903699130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.027885652381746694`], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.027885652381746694`], {
             RGBColor[
             0.7582013913043478, 0.8110319565217391, 0.9765340869565218]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.027885652381746694`], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.027885652381746694`], {
             RGBColor[
             0.9607290869565218, 0.8791921304347826, 0.30194034782608703`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.027885652381746694`], {
             RGBColor[
             0.840108347826087, 0.8753436086956522, 0.9846114782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.027885652381746694`], {
             RGBColor[
             0.6655274782608696, 0.7386343913043478, 0.9672972173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.027885652381746694`], {
             RGBColor[
             0.946240956521739, 0.9594271739130434, 0.9758842173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.027885652381746694`], {
             RGBColor[
             0.5683864347826086, 0.6604807391304347, 0.9591646086956521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.027885652381746694`], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.027885652381746694`], {
             RGBColor[
             0.946240956521739, 0.9594271739130434, 0.9758842173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.027885652381746694`], {
             RGBColor[
             0.9004813913043477, 0.9234834347826086, 0.9903699130434782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.027885652381746694`], {
             RGBColor[
             0.7582013913043478, 0.8110319565217391, 0.9765340869565218]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.027885652381746694`], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.027885652381746694`], {
             RGBColor[
             0.946240956521739, 0.9594271739130434, 0.9758842173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.027885652381746694`], {
             RGBColor[
             0.46975634782608694`, 0.5804083913043478, 0.9514000869565218]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.027885652381746694`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.027885652381746694`], {
             RGBColor[
             0.9797934347826087, 0.9435006521739131, 0.3760017391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.027885652381746694`], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.027885652381746694`], {
             RGBColor[
             0.840108347826087, 0.8753436086956522, 0.9846114782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.027885652381746694`], {
             RGBColor[
             0.6655274782608696, 0.7386343913043478, 0.9672972173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.027885652381746694`], {
             RGBColor[
             0.9797934347826087, 0.9435006521739131, 0.3760017391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.027885652381746694`], {
             RGBColor[
             0.971541652173913, 0.9782963913043479, 0.9330567391304349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.027885652381746694`], {
             RGBColor[
             0.840108347826087, 0.8753436086956522, 0.9846114782608696]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.027885652381746694`], {
             RGBColor[
             0.946240956521739, 0.9594271739130434, 0.9758842173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.027885652381746694`], {
             RGBColor[
             0.9870850434782609, 0.9889273478260869, 0.8636977826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.027885652381746694`], {
             RGBColor[
             0.946240956521739, 0.9594271739130434, 0.9758842173913044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.027885652381746694`], {
             RGBColor[
             0.9607290869565218, 0.8791921304347826, 0.30194034782608703`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.027885652381746694`], {
             RGBColor[
             0.5683864347826086, 0.6604807391304347, 0.9591646086956521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.027885652381746694`], {
             RGBColor[
             0.9357184782608696, 0.7828522173913045, 0.2671357826086957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.027885652381746694`], {
             RGBColor[
             0.9797934347826087, 0.9435006521739131, 0.3760017391304348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.027885652381746694`], {
             RGBColor[
             0.9929863043478261, 0.9874067391304349, 0.47798069565217377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.027885652381746694`], {
             RGBColor[
             0.7582013913043478, 0.8110319565217391, 0.9765340869565218]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.027885652381746694`], {
             RGBColor[
             0.9944362173913044, 0.9905079565217392, 0.6357947826086959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.027885652381746694`], {
             RGBColor[
             0.9928711304347826, 0.9913200434782609, 0.7678073478260871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.027885652381746694`], {
             RGBColor[
             0.946240956521739, 0.9594271739130434, 0.9758842173913044]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN3AuYzmXewPH7z7a1WxZbu0o1DqFsy5TT0CKyGGKYrMNM4zSN46CIkAnD
aEgSLzN2286E9b6tVta7r8OyJGq9yRLZ16FW1GoTNqKN9/m6v3Nde139rk8z
8zz/w33/7t99/+/nqTr5Dz8wplII4ZvvhYDjkxBmp6I49e+jUmanXJiKfqm4
HOLPpam4ORUXU7EoFQf9+7AkvgYXpDyUirq+bkAqmqZ+f8bj/Cj1708m8X0b
Dd43OeUOj9/Q4P01Un/LTOL5aibxnHh1iMcpSlmWioe8HjzitQ5I/X2u3pQy
KxVdPGe6x+b1N3j8Gzw+EpynSyqGpqJ36vcrUlHdc1T3PLRXLY//oMH9Vwvx
d9U8L/f7me1YmMTrQ9rnz0ZT7+cl7wl/kYq23sfjKecrv6+dxGhrv1VNYnA9
lUNso8q2U/sQ7wWHepxVtsOjSWwLpM/b+P4NHgM7Ktef4euQ4PXTQuzjafYz
0m/zUm7zOiYksf8nGFxXbduwttdf+9/a85TtOdC8wkN6T4htdY/tRH9Mtz+n
24/TPV5326e77YPc93VJjBr6qK/vbPDazl4PebPO65nvdSDXgo1SP3/X9u2d
xFzpbf70Noaa90kScyGxnavYzlUM2qiK7VXF/iv0fgvNjULv+/4Qx80jqfg6
FeeUdlhpHFRyeqV5x/3clsR7wo3K9TT1OpoaXE9Tr6ep18P4ftG4aJ6Ptt/w
lPL7yf4es/SU8hpk3N+exHGPN4TYVrhRL2vi34d5/BKPX+LxSzx+iccv8Rwl
1rVc8zfX/M01h7FliH3Y0v5r6Xghn+cYZzTTcZTv8fI9Xr7Hy/eY+b6uPMTX
lRu8FttorvL674Q4xrG2PzPO6e92Sexz/HGIuYeMtRLzGslrxt6YJNb0Mb6+
rvla1/FZ1/bbHWL77TbPcYESh5Sc3237ZoR4jgzzP8Pzkf8HDMbAAdvzgO1J
/81yPMxyPCB9O8txt9c4ZX7VD/E66xtZukB3K31e3/yq/2/XOcXYprTJFK93
iuenzjazv5rZH7hKm9mf+LjtmWY7ptneSNS1nuwPsd7jXCUG+PdmRrFSd7CW
Uq+oc4OSeK8njc6Om7tCHDd3mQt3Gbd7/GLbE/fqET2lnBNrKe1dxbyoYjtW
8fVYxbFVxbFVxfHFONlinNHLSntvsZ1p32q2K1azTavZrtTnxebzYoO8Xmxe
I+OPOjQxiXUILyrHmWh79UhieyFthrkh1kraa5jtNcyoaLdS2x+LlXYqtZ2w
u45S1glTzP8pjsNxSbx2rKFPhnjvT3r/47zXcd7nOO9znO+nvv/VoL4z3x0O
sc7jSj2oxBEttG7cYd3AHydRjlPP+61nnuBhPaLcdz3vu55BnlBPZxilulDL
lTqHbTRXGUe/SjlWx+ts8yPP8ZdnnuTZr3nmSp6Rr+RN+9TrWiVxPYes4VoZ
XbSinu8JsY7vMb/2GLT7HvPrtyGuzfCANvX39G+HENsWd2g72zPb/Mk2f7Jt
x2zzJtsgb5j/qydxnVXdfsANSj/PSWIb40rdr4f1iNLnV6QPkrh2wHlaptuU
ejXD9j9h0C8n7JcT9gvrgx+EeL1YRYmO2ln3KtePrBuo++2MfjpFt+hnylyA
1IuaKd8IcRy8YfxVGQ/M0wUh9n+BwXyD9Dfz5w+TOKciUVuZV8mD4+bBcfPg
uEE+HDcfmBc3h1hXNhu79ZBSX3CgzjffKnkeXKx79LhWskZgpuOzlvGQrtT9
eliP6JVxGmIO1DIfyNe+ScxlPKDkcl/HBjLPLAkxb7BIy5R4KcT8Tje/083X
dPM83TxPt16kWy/SjWIttT2W2u5LjT16XGmLpfbDUvuBeXdNiNe7xutd4/Xi
PC3TJUqQ61hXByn5z/p2aojjGO9XgnGNExzfOd4/ztX9yv3nOM5zHOc5xgDz
cVOI+bjJIBextrb1dcvMt2XGJt2sh5T3L/P9y3z/MvNwmXn4yxDnJvytHtAu
/r239tWhSr1jr+BKDttnlSr6yH6rZL9Vqshn++u6EMcmFmihFmmZrtDevq/i
/J94zfhnPaAEufyJ9/GJ18/81CmJ830n6yae007WSurS1hDrDfbTLUqc0cvK
8wfO8vjfSWJ9wjf0r3pOv1bGdbCe4CH9TInpHu+bEI+D5/Rr/cbjXRPimg1v
0lNaxb+P1snKei0/xDUIztdyXaXVfF0zzdN8Zd4lP/tb7/Ckst7CHsq1NU/i
3ICnlGtsbp1obozWYvPoksG8lGbOppkvaeZGmjmRZk6kmQ9p5lOaeZFmXqWZ
18xPO0Ocw7CzblCCeQypXcxHt9rPyPNFK+O75u2NRkttrwVaqEVapiuU673R
60TqE8/t74U4T+NGJU4oz/E4XmdbL98PsS7iGiWoh1hXOQ/7AkOSOB66JXGO
xi26TYlROkZnWR8HWx+xWPcr9RFrabp212zNUaLU++ga4rq9qzFP1+j7yn11
9b66el+8/4Ekvv8Bf/+A94289gHHR4ckjqkO5i3W1916SsnfDuZrB2O0TlbG
G/PL6hDnkdUG+yvYTico6yXWV7tCfN8u37fL9+0yeP8u37fL9w0NcU7C7v6c
rTk6QBm/Pwvx+QMX61Ldo8e1kq+/Tmtopu3VM8R2wiwlaAcsMT8aG810qM7V
/UquYC3trtmaowOUXGH93yiJe15YU4lW2sX27Wv79jVW6y6lffvavn1tX567
+4T43IitlGD8s1Z71likK/WgHlauEWvqdOvJLUk8LnLMWwzGGTVle4g1BQt0
u+9n3ptozNBSXajlyvMZ5uoAzfc41/ozztCFWq5EhrbRXM33fjJtp0yjj3Jv
md5npv2baf8yT7ZI4n3hZ8r8iIkS3Dfz0Zchzmm4SolqjuO5jmN8UBfobmW8
4kAtUdbx9yex1uIZvawE9ZZ9iSeSuC+DL+pFZW/iCevMOyF+/vGOsVdPKbUF
m+tox9s1Xg/O0cW6VDfoHj2ujOFrjBrK+H0gxDbG4M+JttD5jrPpIebHdPNo
ujFDS3Wulut+rRiv+0Ic+/s8zj7/vs9j7PMY+4z9ynoEc3SAUs9Yz50OcX7E
rUqc0ctKn+Ewne37J4U4/2E/JbboVj2tZ/SyctxJHheZF1nPPxHiuv8JY5Oy
fsfayvr9JyE+i+D9ukN/7N/v0Hb2T2vzGg/pZ0qftna8tDYG6nzr2r0h5i3e
pcQwZX/s1hDXCDjEfmwdYi1vbWTqUJ2rjG/M1hwdbLsPT2K7Yz+dpFt0q57W
y0qu4jAlaHfWj0+FOF5wjhKLdanu0eN6RhkzeI0yXlg/PGYU6Twt0zW6Td9X
1ifIuuS24GcyIa7t8D09obf5uvFKnvJ8fzTE8YKlulL362EleN5B9gWYr7sb
WdpTma+R2se8dHcS5zI8qMxdWFMbKdFKmWereg9Vvb+q3l9V7w/H+rrxyv0x
b3we4rzxuTmFfZRg/sBblPmR9fcXIa6bsbcWapGW6RJ9SVcoedPEmKZz9Cld
qnv0uJ7RS0r+NDFvkPrAOmGE7TvC9sWVelBp5xG28wjbeYTtO8K2Rp5fZob4
/ILFSuxUnmMwXUutG38yDulnSs3A1jrfvPinuYLUjUlJ7CfM1D76udJXyL72
myGuOd80WE8i+93s66y1v9baX2vtr7X211r7a61Bf/00xDkJJ+p0naGlulDL
lbUKZmgb7aSsZ/hc4rkQ518cpyW6WJ/zfrCGjlM+Z2beb+z4a2x7Ypb21H8q
tb6xMdn6O9ZYp0M87t9DXE/gDn1HCdYPPAeND/E5CLsqMU/X6PtKvcK6ynMS
66mRSTw+7tVTytoF62lz7aDEaC12vGcl8XkTt+nnyhjHbkqM0jFKPjewTxuY
Dw3MhwbmQwPzoYH50MB8aGA+4D49qtd63AzN1QFKXWX9+WqI689XjVX6pVZ8
3nPBvLlgvuCbesH8uWD+XDB/qEdvhVg/3jJO6CWljmLFc/9diZ8LJrGf77L/
cJ6+r/Qx1lWCfmbf/9MQn5ewqfbV1fqm7lKC5yecoDw/sQ76OMR1Di7TTUqw
HsLa2tbx8vsQ8w7ra3fN0p66QIndSu7hZC3RuR5/vcdf7/HXe/z1Hn+9x1/v
8dYbu5Uxut7jr/f47C/VSWJdxsn6ju5VcvW1EPcTXzNW6jmlHr1mvvGccafx
ol5UnjGQ5wz2q36exO8bIXtWyLpxVohrTLxfiR1K7cE7tJ31+f+MQebl7Ua6
NtHFulTf0j16XC8p8yRmmnf1k/h5U33bsb7zXH3nL9ygO5U5Dpn/6xj3aFct
1PH6mBbpPC3TJbpG31fGDM6wP9rb7viiXlRiotIvPMe/HuJzPBYosV2Z27GL
9lb2BZl3OyZxvd7R82IrzdQ+elGZhzsak6xfTaxfOFGn6wydq/N1oZbrPqVW
NjGaaYbmap4O0Hzl+Y15YJ73Mc/7mOd94OfKfeAt2lEnKe37/SS2Lxbo67pd
iaHKPsK15gNO0Xm6TdN8XTcdo+TB90Pc48Jm2lqLtaqvS9fumqXZmqODdZSW
2j4Nk3jshrZTQ9sJh2pD26ah+dfQNmpoeze0vej/F0Lsb5yvC7VcCfr4Bfsb
m2mGttFczVP6mbH4dBLrB1JDkPr0jxA/3/mHwec6SL3i+bAgic+H2E8n6RTd
olv1svJ8iN2UGKbDdZTO8jw3e9ybPS7e7DEwSwt0uI7SMcrxqLe/C7HO4iwl
dij1Fqm3zUOsdThTN+hOvcbXVVfqHvPrv0LcZ8AndJlu0o+VYL7F2trWfHgs
iesZnK8v6Ku6Sr9U1jjYTPM0X5mPOhm5+oaeUz7XQuaq74U4lrG9Fujrul2/
7+tb6VBlXDOf/CjE+QSrKDFOS/RN/VQvVLyO+wl+FhZircxzzOQ5ZvIcM3mO
mTzHTJ7jJs9xk+e4yXOc5DlO8hwnebYnewOPJHGdj+v0PWVv4BFjvOMkJ8T3
YT8l1ulG5b3IOGA/4e0Qaxc21mZK7NfDekSPKnUNa2k9zdEBOljZh+B5fXmI
8/Vy+3i5fYyFWqRlSqzQA/qFMk8ut//rpPwqxLrzlcf7yuPhEn1J1+haJahR
SJ36bog1GJtrR+2sxTpTd2p135+uo7TU+vBMEtdjeL/O0t/pDqVGYDtl/vkg
xLqFU3SbbleCWogttJtSp3iOnBDiOhjrK3FKebbD5tpBR+ponazFWqJzzbdp
SVx/4E81W6drqb6mK/WwHlXWxlioxBzr+BBjim5RavMQ7x+ztEBH6Rit2E8c
GeI+1UjjLT2hl3Ss93W994UzdKF+rd8oNeJ6I0PbKHWC5/9XQhzfmKNjlVin
jG8coo+YJ71CXGf1Mh7TKTpPt+kHyrqnl+3Vy/bqZfuwbp8d4jPAbGOxPqc8
12INZT+E+eoPIc5X+IQSm/Rj/ZcyX2FtbatDzKtnk1jHsLF21rd1vx5RahfW
0nqaroO1WMnbv4XYv5itE3W6ztBSXajluk/361ElmCcwQ3N1gBbqNOvItyHW
pm/N72/tUyzWLUqQ/9/an9/anzhKxyj1ifXDfUn8ngd+rCeVPrjP6Kw9tL95
+4Mk9jPm6Fh9RdcpMcT7eibEeRuba0edqcQG3anUW6xvXlQ2LyqbF5WtM5Wt
M5XND9yn+/WwHtXK5kxlc6ayOYM5OkAH6xwlf/h8s22Idbat8aBO0CPKPix2
0JFKHWU/5idJ3FfAqbpad+jflWinE5R9mdQ/V/oIu+hYfUXX6W2+fohSV9qn
/EUS97HxdT2gnyj72NhI79ZW2kWJvjpU2ecmv38e4roEM7SVtlYiUz9Xnhnx
Fu2uWZqtk7RUeT6ifowxJug7uldPKfMj1tI6Wk/TtbmO1GJ91na9yrhVx+or
uk4ZK1fZL1fZL1fZL21CXEtjri7Smv79Vm3keL4qidFZe2h/x8+IEMfPCPth
hO0+wnhb9ys5j1W1lqZrd83WHB2gg7Vi3JwPcTxjbW2rY/RtPaxH9LzXcd7r
OG+/nLcfztsPOEc5L2032HhNV+pRPad8ZoOdtFCnKcdlnd4ziWMN+2mOvqIb
lT7G25Rg3U4d/lkSg1rLevp640btrYVapGW6RF/S5bpC1yrra9aDw0PcD8We
SizQ3+t63ay79aSSU9hZe2h/5fNp1hN3JvFzFxynJTpbF+tzelwvKGsPrKFX
jqWP2h9X2w9X2w84STfqVr3aPrjafsCKz6+Lkjj/Fvl+nKZbdKue1jN6WZmb
sZsW6HAdpQTrUvavB9k/2F2ztKcOsu0H2U+D7KdB9s8g+wUna8X3RfskcT8A
5+urukq/VPYB+hh5yvMs37tskMTvcOJv9YB+okQjbaVd9BfK/FAjxLUY5mm+
TtTpOkPn6nxdqOX6gu7Taz1PE22mGZqreZqv3C/PU91C7B+8SetrN/uom33U
zT7ACfp7Xa+79ZQy32AHHa2TtURZL/BdjseN/1I+56EN7wtxPXufka0TdYYu
1HJ9QWknvF4ztI3mar7nO+v5zvr+s57zrOc8a9+d9dxYqgv1b3rW85/1/Gc9
P3bSXC1U6jH7Q72S+Dk8LtKDSi3HmtpI79ZW2kV7mZ/IeoX1601JXLdiR52p
T+kzukF3Kp+J4DVaXQnWtXx+/58hrh1xmRKb9U96SFlcYGsdqHy+z/zxfIj1
Hm/UOlqghVqkZbpEiZd0ua7QL5R9Ghyq7J+zD/JwEvc98He6Q9kjxTu0sbJ+
GRjiWgdzlRisi/Q1XannlL7Gmnq3dtIRnueY5znmeY75/mOe45jB8Y55PGyk
HJd9hA9DfG7GJjpS31LihF5Svj+Cs+2vv9hff7G/ME3ba4EWapn+Up/X5bpC
iQP6hdJvf7HfaI+ptg8O1of0WV2kK/WgHlPaaqrjbKrjbKrjbKrjaapjClkH
3pvEdR8e0fNKjmMLJdgHZp5/OsR5GvvpJCW26FY9rWf0sjLnP21/YIEO0+Fa
pMzTd4e4/sGr/Lmz9tD+1qV3Q+zfd+1XbKnttUCf1+X6um7Xd+27d+1PZL8c
u2hvHeo47JrEfciujseujseujseujseujseuxsP6jPfxwxD764fGQ/qsbteD
ynVhC71X6T/q0K9D3M/9tfmMRVqmS5R4SdfoWv1K2d/Fp23/j0Kcg3G4LtDN
uls/sj8/sj/xPu2sPZR+5btwNyZx3Y85+opu1PeUuE176iNa8X3VlknMZ5yk
0/Rp3aJb9bSe0cvKurOlUaDDdLgWacX3Wv87xH0dfEKXKfEH3aQf67+U/Tys
rewlMW/2D3HfB5trRyVm6jO6QXcqcyZW15uUeZP6e4txuzbRkfqWfqgn9JKy
v8vnQqONcVqib+qneqHidan31QuxdmInzdWBukiP6Q2+r6Y20rt1hE51/D6Y
xM8THnQc41Sdpat1h7IfhO30Qccx3zf4XhK/54AN9U7toy/qRSXaa0edqHwP
gs/leoT4eRw2VaKvTtXVuks/Vb5nhD/RCcq+FuvLfklcX2K2TtQZulDL9QU9
q6wt8XrN0DZK5CrrW55bf5rE51YcpyU6Wxfrc3pcLyjrP7xOa+ideuXYynMs
OfwfIdYBfFqJrfqhntDTekYvK2Mc79dhSt3hc4QWRjvtpVN0m27XDyrek0S7
6ZX//0fKmUmsj9hFf6XvKXXvyuv0ER2vjOt7kjg+8XYdqW/ph3pJibHe18te
J2ZoO+2lQ3SKvuz9vux94rdKTX3Z+8UsLdBROkZpD+rfU0mse0+ZR9hR++s0
nalz9Cl9RjfoTt2jV77bnvjd9iTWSrxJ6yvz4G9CnAdxmRKbdbce0o/0pDIv
Yg/trzx/sD54OMR9PaytbXWMEm/rYT2i55X9vSvH0nraXO/VkVqs7PMx/z/k
/eICXaa/0c36kZ5U1gB4n3bWHtpfByrn+6PxkZ5UjvVH2w07aw/trxyH/Yb/
CXEPBPN1rs7Xcl2lBHs12ESbaR/N08eU7w0xH9xhNNS79F4dptR65L8faZfy
0RDHz6PGFH1Zt+hW/UC/VT6/xpu1pXbTLC3Q4TpKx2iRznLc/2+I6228Ueto
C22p7bVAH9MyfV636XZ9VwnWuZimPP/yOcaoEPfTMVOHKsF3trCjTtLHlc8r
/h+zL1/H
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[37, 104] -> 
             RGBColor[
              0.2541903466574486, 0.3845005493087726, 0.9377871362499982], 
             UndirectedEdge[119, 243] -> 
             RGBColor[
              0.23559188807996673`, 0.3649523901334573, 0.9367279815479644], 
             UndirectedEdge[165, 226] -> 
             RGBColor[
              0.20872258864357046`, 0.33671105281382463`, 0.935197814694628], 
             UndirectedEdge[235, 261] -> 
             RGBColor[
              0.19122633777104836`, 0.31832138382042696`, 0.9342014290908216],
              UndirectedEdge[56, 198] -> 
             RGBColor[
              0.6735978276393025, 0.7431113232752183, 0.969380994432274], 
             UndirectedEdge[50, 254] -> 
             RGBColor[
              0.20910270252497706`, 0.33711057660379506`, 0.9352194616178461],
              UndirectedEdge[249, 268] -> 
             RGBColor[
              0.18564105657677243`, 0.3124508991579618, 0.9338833555894905], 
             UndirectedEdge[38, 224] -> 
             RGBColor[
              0.37823665311305865`, 0.49620023139778335`, 0.9458245390097163],
              UndirectedEdge[79, 87] -> 
             RGBColor[
              0.19294989757058154`, 0.3201329544497393, 0.9342995832716268], 
             UndirectedEdge[38, 311] -> 
             RGBColor[
              0.23066096804752526`, 0.35976968054097413`, 0.9364471729467594],
              UndirectedEdge[37, 145] -> 
             RGBColor[
              0.2671022972631469, 0.3980718280603137, 0.9385224527354736], 
             UndirectedEdge[147, 359] -> 
             RGBColor[
              0.28645237167494564`, 0.4168434263248926, 0.9396817701660576], 
             UndirectedEdge[192, 349] -> 
             RGBColor[
              0.22834058438598487`, 0.3573308101918738, 0.9363150305299347], 
             UndirectedEdge[213, 308] -> 
             RGBColor[
              0.2691305631056292, 0.398662652595457, 0.9386943834532097], 
             UndirectedEdge[262, 397] -> 
             RGBColor[
              0.364256395049981, 0.48992231415871446`, 0.9444310732866698], 
             UndirectedEdge[129, 364] -> 
             RGBColor[
              0.8703372527037241, 0.4377357825676223, 0.21085741257426427`], 
             UndirectedEdge[54, 83] -> 
             RGBColor[
              0.9496193654049732, 0.8977579075232218, 0.6225379522867944], 
             UndirectedEdge[13, 277] -> 
             RGBColor[
              0.19923872667069553`, 0.3267429125687539, 0.9346577227853893], 
             UndirectedEdge[191, 235] -> 
             RGBColor[
              0.18862912627732129`, 0.3155915498678, 0.9340535217384839], 
             UndirectedEdge[54, 214] -> 
             RGBColor[
              0.913587591361185, 0.6878213464055395, 0.24895168467498954`], 
             UndirectedEdge[87, 176] -> 
             RGBColor[
              0.18652655830038561`, 0.3133816176135313, 0.933933783602668], 
             UndirectedEdge[16, 377] -> 
             RGBColor[
              0.24182389785616784`, 0.37150262754048624`, 0.9370828852852868],
              UndirectedEdge[158, 344] -> 
             RGBColor[
              0.19135142545084088`, 0.31845285890290587`, 0.934208552649135], 
             UndirectedEdge[95, 228] -> 
             RGBColor[
              0.2356195787974104, 0.36498149483318354`, 0.9367295584933581], 
             UndirectedEdge[193, 283] -> 
             RGBColor[
              0.884925338733304, 0.8207038820590313, 0.6242425057097936], 
             UndirectedEdge[11, 366] -> 
             RGBColor[
              0.9332464444239088, 0.9449010522417576, 0.749948999978632], 
             UndirectedEdge[106, 231] -> 
             RGBColor[
              0.1888628748467801, 0.31583723443481654`, 0.9340668333737145], 
             UndirectedEdge[76, 388] -> 
             RGBColor[
              0.276858244918402, 0.40832594760879465`, 0.9390780395218092], 
             UndirectedEdge[208, 351] -> 
             RGBColor[
              0.301986411916915, 0.43466246314501933`, 0.9405117895645303], 
             UndirectedEdge[208, 225] -> 
             RGBColor[
              0.2514500268910438, 0.38162029948797277`, 0.9376310790932412], 
             UndirectedEdge[163, 374] -> 
             RGBColor[
              0.1813453905655848, 0.3079358818192477, 0.9336387237650219], 
             UndirectedEdge[165, 288] -> 
             RGBColor[
              0.2196372553710177, 0.3481830595742119, 0.9358193888179538], 
             UndirectedEdge[110, 239] -> 
             RGBColor[
              0.6800499902731076, 0.7481746185632971, 0.9700901941191247], 
             UndirectedEdge[14, 273] -> 
             RGBColor[
              0.4313475935937616, 0.5461129107315478, 0.9492366849727629], 
             UndirectedEdge[231, 372] -> 
             RGBColor[
              0.18557674124721385`, 0.3123832996687683, 0.9338796929266182], 
             UndirectedEdge[5, 162] -> 
             RGBColor[
              0.19105730741779076`, 0.3181437222020098, 0.9341918030622616], 
             UndirectedEdge[36, 90] -> 
             RGBColor[
              0.2306114538784999, 0.35971763800994894`, 0.9364443531880831], 
             UndirectedEdge[258, 328] -> 
             RGBColor[
              0.23450213577855084`, 0.36380699137038264`, 0.936665921766543], 
             UndirectedEdge[91, 208] -> 
             RGBColor[
              0.4434969579662055, 0.5534506067219376, 0.9505734674176423], 
             UndirectedEdge[155, 370] -> 
             RGBColor[
              0.18572317816153708`, 0.3125372141503586, 0.9338880322922549], 
             UndirectedEdge[66, 243] -> 
             RGBColor[
              0.21376058132167255`, 0.342006302545695, 0.9354847209246038], 
             UndirectedEdge[253, 334] -> 
             RGBColor[
              0.8927019922159016, 0.5360459310419723, 0.23584376702104354`], 
             UndirectedEdge[50, 210] -> 
             RGBColor[
              0.23840421569943582`, 0.3679083247733892, 0.9368881394454274], 
             UndirectedEdge[239, 365] -> 
             RGBColor[
              0.4065771465503478, 0.524864785093759, 0.9475407198960643], 
             UndirectedEdge[13, 51] -> 
             RGBColor[
              0.20728585719020337`, 0.33520095696230034`, 0.9351159949638125],
              UndirectedEdge[258, 300] -> 
             RGBColor[
              0.21690681128224154`, 0.345313189716754, 0.9356638940664279], 
             UndirectedEdge[30, 294] -> 
             RGBColor[
              0.2052159577699056, 0.3330253614323641, 0.9349981172539683], 
             UndirectedEdge[31, 292] -> 
             RGBColor[
              0.9018751366680733, 0.5692935983265383, 0.5384207617960579], 
             UndirectedEdge[203, 216] -> 
             RGBColor[
              0.26291297700315486`, 0.3935517624584167, 0.938288154657422], 
             UndirectedEdge[64, 233] -> 
             RGBColor[
              0.9814581324353071, 0.9819712119725741, 0.6847171998056071], 
             UndirectedEdge[50, 242] -> 
             RGBColor[
              0.2857631387189643, 0.41475906038865373`, 0.9396923133754758], 
             UndirectedEdge[133, 398] -> 
             RGBColor[
              0.18210607446438823`, 0.30873540882703493`, 0.9336820435877278],
              UndirectedEdge[7, 390] -> 
             RGBColor[
              0.23396569650741295`, 0.36324315968420245`, 0.9366353723436424],
              UndirectedEdge[186, 342] -> 
             RGBColor[
              0.19648760861210862`, 0.32385131305821946`, 0.9345010506818672],
              UndirectedEdge[347, 398] -> 
             RGBColor[
              0.182565782601332, 0.30921859122614215`, 0.9337082232860494], 
             UndirectedEdge[321, 375] -> 
             RGBColor[
              0.19367454863692518`, 0.3208946086659977, 0.9343408510778299], 
             UndirectedEdge[149, 279] -> 
             RGBColor[
              0.20468155953700706`, 0.33246367500678287`, 0.9349676840651762],
              UndirectedEdge[38, 306] -> 
             RGBColor[
              0.24051285588611682`, 0.3701246393051007, 0.9370082233846052], 
             UndirectedEdge[12, 358] -> 
             RGBColor[
              0.26019129073322267`, 0.39080792201424114`, 0.9381288811375124],
              UndirectedEdge[139, 378] -> 
             RGBColor[
              0.27359029407982893`, 0.40489112407740385`, 0.9388919345560525],
              UndirectedEdge[272, 374] -> 
             RGBColor[
              0.19014395523747457`, 0.3171837311506246, 0.934139789006776], 
             UndirectedEdge[21, 114] -> 
             RGBColor[
              0.19167285067202883`, 0.3187906971899105, 0.9342268573399758], 
             UndirectedEdge[250, 321] -> 
             RGBColor[
              0.18913677562513462`, 0.3161251215191795, 0.934082431617842], 
             UndirectedEdge[19, 152] -> 
             RGBColor[
              0.2001783639532218, 0.3277305309291337, 0.9347112337385604], 
             UndirectedEdge[270, 336] -> 
             RGBColor[
              0.2213730230293102, 0.3500074614371033, 0.9359182382182554], 
             UndirectedEdge[87, 277] -> 
             RGBColor[
              0.18598156789951187`, 0.3128087981478258, 0.9339027472055792], 
             UndirectedEdge[37, 377] -> 
             RGBColor[
              0.2695128080367538, 0.400605427718585, 0.9386597277579993], 
             UndirectedEdge[312, 356] -> 
             RGBColor[
              0.746600049419986, 0.8012844499471021, 0.9674404180913663], 
             UndirectedEdge[294, 343] -> 
             RGBColor[
              0.20522639813651683`, 0.33303633491963003`, 0.9349987118174017],
              UndirectedEdge[170, 349] -> 
             RGBColor[
              0.21695935367547547`, 0.34536841510342303`, 0.9356668862779931],
              UndirectedEdge[176, 390] -> 
             RGBColor[
              0.199593709897452, 0.3271160224473115, 0.9346779385550025], 
             UndirectedEdge[235, 327] -> 
             RGBColor[
              0.1895062149755763, 0.31651342570030144`, 0.934103470642313], 
             UndirectedEdge[271, 400] -> 
             RGBColor[
              0.8210589855507496, 0.16287416781517963`, 0.16779941438710733`],
              UndirectedEdge[45, 103] -> 
             RGBColor[
              0.21725551419299843`, 0.345679698585001, 0.9356837521813359], 
             UndirectedEdge[30, 343] -> 
             RGBColor[
              0.2007094287814945, 0.32828871373510315`, 0.9347414770948905], 
             UndirectedEdge[200, 234] -> 
             RGBColor[
              0.22049169370930496`, 0.34908112844227146`, 0.9358680478172909],
              UndirectedEdge[282, 382] -> 
             RGBColor[
              0.3185597546508585, 0.45034218102492296`, 0.9415193237683902], 
             UndirectedEdge[305, 382] -> 
             RGBColor[
              0.31007770460075973`, 0.44200741025601153`, 0.9410150322193817],
              UndirectedEdge[50, 164] -> 
             RGBColor[
              0.22306024288786463`, 0.3517808364843617, 0.9360143228931819], 
             UndirectedEdge[259, 287] -> 
             RGBColor[
              0.8563718105158677, 0.5267891517148, 0.5770527968903222], 
             UndirectedEdge[90, 95] -> 
             RGBColor[
              0.23140010342565426`, 0.3605465586872775, 0.936489265613091], 
             UndirectedEdge[44, 243] -> 
             RGBColor[
              0.2298536898894718, 0.3589211800124685, 0.9364011996499193], 
             UndirectedEdge[82, 194] -> 
             RGBColor[
              0.6075992658363466, 0.6905170696190597, 0.963481170694517], 
             UndirectedEdge[124, 150] -> 
             RGBColor[
              0.2325126629936997, 0.36171592933364405`, 0.9365526242346068], 
             UndirectedEdge[233, 316] -> 
             RGBColor[
              0.8412361363066468, 0.8762214650435611, 0.9535246374949702], 
             UndirectedEdge[87, 390] -> 
             RGBColor[
              0.19991574882843044`, 0.32745450578221735`, 0.9346962781957078],
              UndirectedEdge[72, 376] -> 
             RGBColor[
              0.3758578545249899, 0.4975526740121381, 0.9453383722532241], 
             UndirectedEdge[99, 169] -> 
             RGBColor[
              0.6797124063510102, 0.7475445119943138, 0.9704734146298177], 
             UndirectedEdge[127, 137] -> 
             RGBColor[
              0.31600670483300364`, 0.4466421785419929, 0.9414111535240912], 
             UndirectedEdge[68, 391] -> 
             RGBColor[
              0.8209192855845969, 0.5085618177919978, 0.5749280813219132], 
             UndirectedEdge[292, 309] -> 
             RGBColor[
              0.7584292895983676, 0.45716808614862703`, 0.568384704834363], 
             UndirectedEdge[88, 140] -> 
             RGBColor[
              0.41837127081473313`, 0.5367938996534025, 0.947879225318494], 
             UndirectedEdge[153, 216] -> 
             RGBColor[
              0.21073387590110806`, 0.33882504324447416`, 0.935312354528512], 
             UndirectedEdge[145, 165] -> 
             RGBColor[
              0.23770682741222313`, 0.3671753254665574, 0.9368484242141641], 
             UndirectedEdge[37, 76] -> 
             RGBColor[
              0.28363325287465024`, 0.4154469105311262, 0.9394638662021915], 
             UndirectedEdge[6, 391] -> 
             RGBColor[
              0.8731987569820019, 0.5502480491958415, 0.5799145439742327], 
             UndirectedEdge[203, 206] -> 
             RGBColor[
              0.36944897924090714`, 0.4944198695980247, 0.9447619401596937], 
             UndirectedEdge[298, 320] -> 
             RGBColor[
              0.19458686072830475`, 0.3218535065179652, 0.9343928059017892], 
             UndirectedEdge[39, 164] -> 
             RGBColor[
              0.20658345954088297`, 0.3344626924982814, 0.9350759944567879], 
             UndirectedEdge[107, 156] -> 
             RGBColor[
              0.2124764155335251, 0.34065656288153834`, 0.9354115895827217], 
             UndirectedEdge[31, 222] -> 
             RGBColor[
              0.967672940132394, 0.9754000826172251, 0.9391115323234271], 
             UndirectedEdge[301, 329] -> 
             RGBColor[
              0.25610352101831557`, 0.38651141686430435`, 0.9378960886995618],
              UndirectedEdge[126, 320] -> 
             RGBColor[
              0.18313368370358218`, 0.3098154912916167, 0.9337405644136882], 
             UndirectedEdge[49, 191] -> 
             RGBColor[
              0.18385357890938503`, 0.3105721467969078, 0.933781561380669], 
             UndirectedEdge[122, 173] -> 
             RGBColor[
              0.18447873947082444`, 0.3112292301844495, 0.9338171633498009], 
             UndirectedEdge[60, 102] -> 
             RGBColor[
              0.5280292771941157, 0.6238948638185677, 0.9574471733011694], 
             UndirectedEdge[120, 380] -> 
             RGBColor[
              0.5664649447415552, 0.6566185624069654, 0.9601363872621158], 
             UndirectedEdge[110, 247] -> 
             RGBColor[
              0.8351507068562677, 0.5099360316010974, 0.5750372213001058], 
             UndirectedEdge[59, 149] -> 
             RGBColor[
              0.21329928840113216`, 0.34152145443854653`, 0.9354584509752006],
              UndirectedEdge[92, 346] -> 
             RGBColor[
              0.2038983093069455, 0.33164042935405524`, 0.934923079123289], 
             UndirectedEdge[6, 142] -> 
             RGBColor[
              0.7001614603741532, 0.763972329138221, 0.9722831025823769], 
             UndirectedEdge[176, 232] -> 
             RGBColor[
              0.18828223277850703`, 0.3152269428062281, 0.9340337666669094], 
             UndirectedEdge[60, 345] -> 
             RGBColor[
              0.7675537628448912, 0.8184035673483785, 0.9774488709937861], 
             UndirectedEdge[79, 126] -> 
             RGBColor[
              0.19080527822884924`, 0.31787882354485875`, 0.9341774503727951],
              UndirectedEdge[14, 212] -> 
             RGBColor[
              0.45821441723172895`, 0.5679246084974616, 0.9513517397459614], 
             UndirectedEdge[22, 338] -> 
             RGBColor[
              0.2260845393342366, 0.35495956380096844`, 0.9361865521017572], 
             UndirectedEdge[195, 389] -> 
             RGBColor[
              0.7088707754207897, 0.764952224756877, 0.7205833028362763], 
             UndirectedEdge[14, 293] -> 
             RGBColor[
              0.32638953387049785`, 0.45712394224882835`, 0.9420182303766638],
              UndirectedEdge[201, 394] -> 
             RGBColor[
              0.5116695891716139, 0.6114793927942537, 0.9556621742335425], 
             UndirectedEdge[20, 189] -> 
             RGBColor[
              0.30889970680782364`, 0.4349879582915822, 0.9411596287595527], 
             UndirectedEdge[195, 359] -> 
             RGBColor[
              0.375153965132881, 0.49936124163672424`, 0.9451254568160093], 
             UndirectedEdge[222, 224] -> 
             RGBColor[
              0.724417520241849, 0.7830873105778803, 0.9606419773233753], 
             UndirectedEdge[54, 389] -> 
             RGBColor[
              0.9706885388162402, 0.9101251515870772, 0.3850556620267193], 
             UndirectedEdge[123, 366] -> 
             RGBColor[
              0.9182289355345559, 0.6604066319094237, 0.35054608517613656`], 
             UndirectedEdge[120, 263] -> 
             RGBColor[
              0.3571898835204337, 0.4831624157488532, 0.9440042071759314], 
             UndirectedEdge[332, 364] -> 
             RGBColor[
              0.8695716309493327, 0.4318508782657767, 0.2101242523176128], 
             UndirectedEdge[70, 228] -> 
             RGBColor[
              0.21048617188066365`, 0.3385646906136451, 0.9352982481509928], 
             UndirectedEdge[74, 141] -> 
             RGBColor[
              0.3021503369999872, 0.43056214369424695`, 0.9406775662244785], 
             UndirectedEdge[212, 385] -> 
             RGBColor[
              0.7860985506073723, 0.8292872838004639, 0.7968353358505167], 
             UndirectedEdge[256, 384] -> 
             RGBColor[
              0.9629443447193516, 0.8827390749129462, 0.5213129511813582], 
             UndirectedEdge[158, 317] -> 
             RGBColor[
              0.18982224071375664`, 0.31684558878831803`, 0.9341214678405843],
              UndirectedEdge[76, 208] -> 
             RGBColor[
              0.28867650153937047`, 0.420747684638181, 0.9397510717528295], 
             UndirectedEdge[101, 253] -> 
             RGBColor[
              0.8395830715203696, 0.3052584098839103, 0.18553810003157822`], 
             UndirectedEdge[111, 309] -> 
             RGBColor[
              0.7619893896080814, 0.48453257486905843`, 0.5717938606242228], 
             UndirectedEdge[145, 170] -> 
             RGBColor[
              0.24268853638713495`, 0.37241141745778183`, 0.9371321251705074],
              UndirectedEdge[59, 279] -> 
             RGBColor[
              0.2076546436516325, 0.3355885749156745, 0.9351369968072203], 
             UndirectedEdge[83, 334] -> 
             RGBColor[
              0.9555982588691752, 0.9202058525384339, 0.6338919338224923], 
             UndirectedEdge[242, 312] -> 
             RGBColor[
              0.4441075478761082, 0.5565195124327971, 0.9502280720328274], 
             UndirectedEdge[140, 356] -> 
             RGBColor[
              0.6758651089866358, 0.7425832566534856, 0.9622242963377263], 
             UndirectedEdge[172, 316] -> 
             RGBColor[
              0.5458822960971526, 0.6391409074229324, 0.9586767421820886], 
             UndirectedEdge[217, 331] -> 
             RGBColor[
              0.22460790707912992`, 0.3534075296769589, 0.9361024600793104], 
             UndirectedEdge[263, 336] -> 
             RGBColor[
              0.2683165494931898, 0.3993480841421268, 0.9385916026036494], 
             UndirectedEdge[122, 338] -> 
             RGBColor[
              0.19975108063826336`, 0.32728142907378543`, 0.9346869005858826],
              UndirectedEdge[303, 400] -> 
             RGBColor[
              0.8580226382100805, 0.391117913716996, 0.20100792167803327`], 
             UndirectedEdge[133, 367] -> 
             RGBColor[
              0.18474901765317286`, 0.31151330969072427`, 0.9338325552924449],
              UndirectedEdge[136, 279] -> 
             RGBColor[
              0.19083656061449622`, 0.3179117033155916, 0.9341792318583795], 
             UndirectedEdge[117, 365] -> 
             RGBColor[
              0.4322742926857367, 0.5457268859697086, 0.94956369337159], 
             UndirectedEdge[33, 245] -> 
             RGBColor[
              0.22074175679161856`, 0.34934396059669826`, 0.9358822885398935],
              UndirectedEdge[162, 368] -> 
             RGBColor[
              0.18956500601498782`, 0.31657521881029016`, 0.934106818705034], 
             UndirectedEdge[46, 128] -> 
             RGBColor[
              0.5547192055800235, 0.6423805327309791, 0.9609350717272003], 
             UndirectedEdge[117, 269] -> 
             RGBColor[
              0.45596747114210545`, 0.5665010427125681, 0.9510641632117192], 
             UndirectedEdge[98, 134] -> 
             RGBColor[
              0.1861818864522268, 0.313019345647659, 0.9339141550508117], 
             UndirectedEdge[90, 326] -> 
             RGBColor[
              0.22857029923452804`, 0.35757225506245527`, 0.9363281124507266],
              UndirectedEdge[119, 306] -> 
             RGBColor[
              0.2310448890646134, 0.36017320587193224`, 0.9364690366807222], 
             UndirectedEdge[150, 211] -> 
             RGBColor[
              0.23544785722092995`, 0.3648010045685258, 0.9367197792036168], 
             UndirectedEdge[388, 395] -> 
             RGBColor[
              0.35473118198517756`, 0.4781619748017699, 0.9439526563033052], 
             UndirectedEdge[102, 108] -> 
             RGBColor[
              0.3276991764172302, 0.45803801914073383`, 0.9421097447928497], 
             UndirectedEdge[15, 392] -> 
             RGBColor[
              0.19259602959164984`, 0.3197610167673564, 0.9342794310137273], 
             UndirectedEdge[32, 292] -> 
             RGBColor[
              0.8205053754928366, 0.15861887831658708`, 0.16726927677043682`],
              UndirectedEdge[115, 332] -> 
             RGBColor[
              0.8864563951040925, 0.498793341625289, 0.2237101298928862], 
             UndirectedEdge[93, 293] -> 
             RGBColor[
              0.3283292569566383, 0.4588040328927261, 0.9421418278164828], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.1906510637312114, 0.3177167343300775, 0.9341686680852945], 
             UndirectedEdge[276, 305] -> 
             RGBColor[
              0.33855234976798615`, 0.46667071672258365`, 0.9428294114302973],
              UndirectedEdge[75, 347] -> 
             RGBColor[
              0.18311704522785527`, 0.30979800319868733`, 0.9337396168771099],
              UndirectedEdge[64, 193] -> 
             RGBColor[
              0.9152566921622731, 0.9300770448033753, 0.7093659477350615], 
             UndirectedEdge[18, 99] -> 
             RGBColor[
              0.947350971343756, 0.9556350172112698, 0.7097411277967336], 
             UndirectedEdge[74, 290] -> 
             RGBColor[
              0.2530317916874394, 0.3832828345786652, 0.9377211582583846], 
             UndirectedEdge[39, 230] -> 
             RGBColor[
              0.20964976351428055`, 0.33768557238922303`, 0.9352506159318827],
              UndirectedEdge[259, 345] -> 
             RGBColor[
              0.8617541752858404, 0.8926034039517254, 0.9866760766074392], 
             UndirectedEdge[30, 168] -> 
             RGBColor[
              0.19933167973369648`, 0.3268406121315325, 0.9346630163248155], 
             UndirectedEdge[231, 331] -> 
             RGBColor[
              0.21608777115484973`, 0.34445232661272185`, 0.9356172509428343],
              UndirectedEdge[137, 242] -> 
             RGBColor[
              0.31652160790723577`, 0.4470881617051118, 0.9414439626926704], 
             UndirectedEdge[172, 221] -> 
             RGBColor[
              0.3747675504331488, 0.4990265486455837, 0.9451008348130354], 
             UndirectedEdge[157, 211] -> 
             RGBColor[
              0.23967520555955008`, 0.36924421570178084`, 0.9369605204376998],
              UndirectedEdge[46, 213] -> 
             RGBColor[
              0.5654749182769274, 0.6521444572622102, 0.9616040176321952], 
             UndirectedEdge[184, 318] -> 
             RGBColor[
              0.2135047362690546, 0.34173739317388024`, 0.935470150927346], 
             UndirectedEdge[201, 293] -> 
             RGBColor[
              0.4899219075938762, 0.5926426440818758, 0.9542764311941287], 
             UndirectedEdge[64, 115] -> 
             RGBColor[
              0.973846560757742, 0.9231368127839409, 0.35853265585475147`], 
             UndirectedEdge[174, 266] -> 
             RGBColor[
              0.5380286912692482, 0.6346285303347542, 0.9572070721400225], 
             UndirectedEdge[80, 104] -> 
             RGBColor[
              0.2135778861880246, 0.34181427837669043`, 0.9354743167070156], 
             UndirectedEdge[265, 321] -> 
             RGBColor[
              0.19177497299708612`, 0.31889803422847507`, 0.9342326730553113],
              UndirectedEdge[178, 296] -> 
             RGBColor[
              0.18104204814496305`, 0.30761704970215387`, 0.9336214488629224],
              UndirectedEdge[114, 249] -> 
             RGBColor[
              0.18514988407402466`, 0.3119346457154385, 0.9338553840420838], 
             UndirectedEdge[255, 380] -> 
             RGBColor[
              0.5472854839726642, 0.6400062774766795, 0.9589142889816533], 
             UndirectedEdge[253, 391] -> 
             RGBColor[
              0.8227133050515791, 0.17558999242598253`, 0.16938359260938823`],
              UndirectedEdge[40, 63] -> 
             RGBColor[
              0.19138658757193353`, 0.3184898165215815, 0.9342105550799136], 
             UndirectedEdge[23, 311] -> 
             RGBColor[
              0.2072579319428704, 0.33517160575679045`, 0.9351144046622886], 
             UndirectedEdge[156, 396] -> 
             RGBColor[
              0.19313485512094197`, 0.32032735656215416`, 0.9343101163304997],
              UndirectedEdge[93, 281] -> 
             RGBColor[
              0.3706399848182322, 0.4954514587674228, 0.944837829981916], 
             UndirectedEdge[27, 325] -> 
             RGBColor[
              0.22165235452841858`, 0.35030105655330623`, 0.9359341457338957],
              UndirectedEdge[12, 107] -> 
             RGBColor[
              0.23293330946253646`, 0.362158055442918, 0.9365765794287164], 
             UndirectedEdge[255, 312] -> 
             RGBColor[
              0.46100266352577723`, 0.571153212435337, 0.9513046138622602], 
             UndirectedEdge[257, 310] -> 
             RGBColor[
              0.8979684765940259, 0.5907693635082272, 0.5548367056098094], 
             UndirectedEdge[50, 197] -> 
             RGBColor[
              0.21121964795225362`, 0.33933562046995513`, 0.9353400185281894],
              UndirectedEdge[215, 350] -> 
             RGBColor[
              0.5273081197953102, 0.6233107010129518, 0.9573840940310441], 
             UndirectedEdge[49, 235] -> 
             RGBColor[
              0.1884735679979762, 0.31542804825324383`, 0.9340446629246031], 
             UndirectedEdge[239, 323] -> 
             RGBColor[
              0.4638795886223883, 0.5747495967298069, 0.9511827422942791], 
             UndirectedEdge[211, 216] -> 
             RGBColor[
              0.22415272438939332`, 0.35292910380979625`, 0.9360765380985124],
              UndirectedEdge[98, 151] -> 
             RGBColor[
              0.20043054064394245`, 0.3279955846200067, 0.934725594828035], 
             UndirectedEdge[10, 32] -> 
             RGBColor[
              0.8322429825165458, 0.24883926935301032`, 0.1785092225120718], 
             UndirectedEdge[330, 367] -> 
             RGBColor[
              0.1873967228823739, 0.314296215760822, 0.9339833381883191], 
             UndirectedEdge[99, 384] -> 
             RGBColor[
              0.9178754148881313, 0.8496097092612407, 0.6279747633092586], 
             UndirectedEdge[127, 138] -> 
             RGBColor[
              0.31413697275722113`, 0.44467697158248487`, 0.9413046750483962],
              UndirectedEdge[292, 385] -> 
             RGBColor[
              0.9069547340805542, 0.5706484219232661, 0.4000326809306238], 
             UndirectedEdge[177, 219] -> 
             RGBColor[
              0.18016175523476746`, 0.3066918060397442, 0.9335713174839634], 
             UndirectedEdge[170, 322] -> 
             RGBColor[
              0.2153075934140704, 0.3436323103410369, 0.9355728209746665], 
             UndirectedEdge[261, 335] -> 
             RGBColor[
              0.19373393161436922`, 0.3209570239403897, 0.934344232850546], 
             UndirectedEdge[6, 253] -> 
             RGBColor[
              0.8756778488316885, 0.5693034354975091, 0.5822885251292265], 
             UndirectedEdge[95, 246] -> 
             RGBColor[
              0.23196638865379215`, 0.3611417603666076, 0.9365215147190895], 
             UndirectedEdge[50, 331] -> 
             RGBColor[
              0.2360482874744978, 0.36543209483450245`, 0.9367539728183005], 
             UndirectedEdge[9, 358] -> 
             RGBColor[
              0.48197798109692647`, 0.5820052784935108, 0.954246805716025], 
             UndirectedEdge[99, 144] -> 
             RGBColor[
              0.7417116613175341, 0.797878300210745, 0.9753542230915366], 
             UndirectedEdge[2, 28] -> 
             RGBColor[
              0.1967107027357332, 0.32408579912713337`, 0.9345137555621694], 
             UndirectedEdge[138, 258] -> 
             RGBColor[
              0.26327890753170885`, 0.39405320303566205`, 0.9383047163464664],
              UndirectedEdge[144, 384] -> 
             RGBColor[
              0.757420984754537, 0.7226612405223014, 0.6127983851533676], 
             UndirectedEdge[79, 277] -> 
             RGBColor[
              0.19208286823872933`, 0.31922165164912797`, 0.9342502072338328],
              UndirectedEdge[346, 354] -> 
             RGBColor[
              0.1997636988090205, 0.3272946915712895, 0.9346876191720402], 
             UndirectedEdge[144, 148] -> 
             RGBColor[
              0.41890511783186646`, 0.5289568419765102, 0.9490497655266936], 
             UndirectedEdge[38, 346] -> 
             RGBColor[
              0.23107597310122763`, 0.36020587716525554`, 0.9364708068706228],
              UndirectedEdge[38, 363] -> 
             RGBColor[
              0.3166257823122153, 0.444042358182842, 0.9415654261663287], 
             UndirectedEdge[78, 104] -> 
             RGBColor[
              0.22225745398096258`, 0.35093705444345114`, 0.9359686052525535],
              UndirectedEdge[95, 282] -> 
             RGBColor[
              0.2811273621289757, 0.41223265884799526`, 0.9393424107780823], 
             UndirectedEdge[92, 306] -> 
             RGBColor[
              0.21333519209183469`, 0.34155919149390046`, 0.9354604956372714],
              UndirectedEdge[9, 339] -> 
             RGBColor[
              0.5341582021850244, 0.6300810922914106, 0.9574662349562233], 
             UndirectedEdge[36, 148] -> 
             RGBColor[
              0.2511034439451054, 0.38125601883716365`, 0.9376113417071936], 
             UndirectedEdge[62, 395] -> 
             RGBColor[
              0.7152423649203183, 0.772631878073945, 0.8673341109470382], 
             UndirectedEdge[32, 247] -> 
             RGBColor[
              0.8194288056366617, 0.15034389064610632`, 0.16623835226035183`],
              UndirectedEdge[168, 379] -> 
             RGBColor[
              0.190216267574, 0.31725973600117974`, 0.9341439070873645], 
             UndirectedEdge[137, 230] -> 
             RGBColor[
              0.2568850160495337, 0.38733281769176137`, 0.9379405936854713], 
             UndirectedEdge[268, 279] -> 
             RGBColor[
              0.19334852815726622`, 0.3205519404709839, 0.9343222846938173], 
             UndirectedEdge[185, 288] -> 
             RGBColor[
              0.2031417930336449, 0.3308452827849142, 0.93487999664069], 
             UndirectedEdge[233, 310] -> 
             RGBColor[
              0.8984238517661913, 0.5911089815660195, 0.5540658742241997], 
             UndirectedEdge[150, 386] -> 
             RGBColor[
              0.29016677848912364`, 0.4192462598996066, 0.9399482680174902], 
             UndirectedEdge[138, 281] -> 
             RGBColor[
              0.3438282004171828, 0.4703940206570502, 0.9431965738199672], 
             UndirectedEdge[88, 257] -> 
             RGBColor[
              0.6999080745469857, 0.7619616397704058, 0.9426465587738788], 
             UndirectedEdge[27, 40] -> 
             RGBColor[
              0.19924073649984758`, 0.3267450250266232, 0.9346578372421862], 
             UndirectedEdge[159, 250] -> 
             RGBColor[
              0.18793077615893167`, 0.3148575396154177, 0.934013751732358], 
             UndirectedEdge[169, 363] -> 
             RGBColor[
              0.4158922643017966, 0.5345397089893019, 0.947750829584961], 
             UndirectedEdge[144, 382] -> 
             RGBColor[
              0.451676599366216, 0.5621674511867154, 0.9509612465314614], 
             UndirectedEdge[35, 207] -> 
             RGBColor[
              0.19080850531779897`, 0.3178822154199542, 0.9341776341507367], 
             UndirectedEdge[71, 287] -> 
             RGBColor[
              0.8935114377259239, 0.5555263902170573, 0.5501928078759782], 
             UndirectedEdge[148, 361] -> 
             RGBColor[
              0.33306353105933184`, 0.4580790241212378, 0.94262018039587], 
             UndirectedEdge[215, 393] -> 
             RGBColor[
              0.7140213652809209, 0.7765181844116039, 0.9721306348483233], 
             UndirectedEdge[33, 124] -> 
             RGBColor[
              0.23660403432322674`, 0.366016220008902, 0.9367856217791819], 
             UndirectedEdge[31, 111] -> 
             RGBColor[
              0.905435236677787, 0.5966580870469695, 0.5418299175859177], 
             UndirectedEdge[113, 357] -> 
             RGBColor[
              0.18582607626581804`, 0.31264536658207454`, 0.9338938921870696],
              UndirectedEdge[30, 329] -> 
             RGBColor[
              0.23151896311630302`, 0.36067148775828894`, 0.9364960344966363],
              UndirectedEdge[117, 239] -> 
             RGBColor[
              0.5328344578573876, 0.6316180426642315, 0.9563658268409162], 
             UndirectedEdge[209, 338] -> 
             RGBColor[
              0.23759083072429804`, 0.3670534055929334, 0.9368418183743885], 
             UndirectedEdge[208, 323] -> 
             RGBColor[
              0.3575199332630081, 0.48276280813906464`, 0.9440503364383386], 
             UndirectedEdge[71, 212] -> 
             RGBColor[
              0.7737416965530766, 0.822516123696677, 0.9480358411696325], 
             UndirectedEdge[199, 292] -> 
             RGBColor[
              0.9041138184890838, 0.5702193507910247, 0.501320010499076], 
             UndirectedEdge[11, 386] -> 
             RGBColor[
              0.6075598618760001, 0.6861529495738531, 0.9653876814635047], 
             UndirectedEdge[130, 267] -> 
             RGBColor[
              0.20661372269188627`, 0.33449450098878053`, 0.9350777178984673],
              UndirectedEdge[67, 347] -> 
             RGBColor[
              0.18186543483400505`, 0.3084824813180684, 0.9336683395167719], 
             UndirectedEdge[211, 358] -> 
             RGBColor[
              0.2550430737157216, 0.3853968195130357, 0.9378356977944702], 
             UndirectedEdge[2, 164] -> 
             RGBColor[
              0.20840908696131982`, 0.3363815426686245, 0.935179961237608], 
             UndirectedEdge[266, 358] -> 
             RGBColor[
              0.4679094050103473, 0.5710147999295367, 0.9528445815300333], 
             UndirectedEdge[57, 397] -> 
             RGBColor[
              0.3562392675894767, 0.4829782813049682, 0.943920229014154], 
             UndirectedEdge[209, 386] -> 
             RGBColor[
              0.30348621877337745`, 0.4332458361396474, 0.9407067904373323], 
             UndirectedEdge[74, 386] -> 
             RGBColor[
              0.29523037248077955`, 0.42456841823523894`, 0.9402366322043989],
              UndirectedEdge[47, 268] -> 
             RGBColor[
              0.18433220446865944`, 0.3110752126063183, 0.9338088183982067], 
             UndirectedEdge[108, 397] -> 
             RGBColor[
              0.3352715846751584, 0.4645968585734458, 0.9425922519510271], 
             UndirectedEdge[157, 358] -> 
             RGBColor[
              0.2622292284500658, 0.3929499237673575, 0.938244938675628], 
             UndirectedEdge[10, 129] -> 
             RGBColor[
              0.8311516302547027, 0.2404506576348733, 0.17746414235362473`], 
             UndirectedEdge[171, 308] -> 
             RGBColor[
              0.20045056014029836`, 0.3280166263799862, 0.9347267349087363], 
             UndirectedEdge[225, 335] -> 
             RGBColor[
              0.20337317791570175`, 0.3310884829666048, 0.93489317366742], 
             UndirectedEdge[45, 116] -> 
             RGBColor[
              0.23987123039501432`, 0.3694502502325462, 0.9369716837620867], 
             UndirectedEdge[261, 349] -> 
             RGBColor[
              0.19380914280268063`, 0.32103607566796977`, 0.9343485160164554],
              UndirectedEdge[118, 209] -> 
             RGBColor[
              0.3112464668184692, 0.43996737295489813`, 0.9412012665806477], 
             UndirectedEdge[329, 343] -> 
             RGBColor[
              0.23152940348291426`, 0.3606824612455548, 0.9364966290600697], 
             UndirectedEdge[163, 171] -> 
             RGBColor[
              0.18355378954190335`, 0.31025704916394076`, 0.9337644888196897],
              UndirectedEdge[106, 217] -> 
             RGBColor[
              0.1973830107710603, 0.32479243749905357`, 0.9345520425101908], 
             UndirectedEdge[55, 123] -> 
             RGBColor[
              0.8234475715902414, 0.5896702073672445, 0.5850169799812919], 
             UndirectedEdge[129, 353] -> 
             RGBColor[
              0.9062979809873158, 0.5688117544551025, 0.33694932919085196`], 
             UndirectedEdge[38, 66] -> 
             RGBColor[
              0.22742648369193186`, 0.3563700324050926, 0.9362629738476992], 
             UndirectedEdge[23, 119] -> 
             RGBColor[
              0.22585475434557115`, 0.35471804520867123`, 0.936173466186589], 
             UndirectedEdge[306, 354] -> 
             RGBColor[
              0.2092005815939097, 0.33721345371113465`, 0.9352250356860227], 
             UndirectedEdge[28, 39] -> 
             RGBColor[
              0.19488507531529636`, 0.3221669489567903, 0.9344097887813494], 
             UndirectedEdge[158, 267] -> 
             RGBColor[
              0.19435218965099377`, 0.3216068523367057, 0.934379441731101], 
             UndirectedEdge[194, 399] -> 
             RGBColor[
              0.40740786703989107`, 0.5272403351648417, 0.9471965661691704], 
             UndirectedEdge[102, 333] -> 
             RGBColor[
              0.6514056454646207, 0.7208926458479099, 0.9532948082895194], 
             UndirectedEdge[16, 80] -> 
             RGBColor[
              0.21603013302378776`, 0.34439174528250716`, 0.9356139685365383],
              UndirectedEdge[72, 333] -> 
             RGBColor[
              0.7096566263019076, 0.7710149507769987, 0.9570981774601166], 
             UndirectedEdge[167, 211] -> 
             RGBColor[
              0.23414776627805434`, 0.3634345265570368, 0.9366457409477322], 
             UndirectedEdge[193, 255] -> 
             RGBColor[
              0.606058461723811, 0.6860652101473173, 0.9647337421078497], 
             UndirectedEdge[168, 211] -> 
             RGBColor[
              0.2152267109388578, 0.3435472977313434, 0.935568214837358], 
             UndirectedEdge[70, 246] -> 
             RGBColor[
              0.2068329817370454, 0.33472495614706915`, 0.9350902043767244], 
             UndirectedEdge[322, 349] -> 
             RGBColor[
              0.19676296516777197`, 0.32414073025683565`, 0.9345167318303588],
              UndirectedEdge[193, 312] -> 
             RGBColor[
              0.6928723364666782, 0.7586931681891012, 0.9709743993376487], 
             UndirectedEdge[194, 221] -> 
             RGBColor[
              0.41267584437400284`, 0.5318031923554098, 0.9475322370266106], 
             UndirectedEdge[208, 221] -> 
             RGBColor[
              0.3321648835388723, 0.4608015384498717, 0.9424347350905069], 
             UndirectedEdge[112, 251] -> 
             RGBColor[
              0.18268323345773074`, 0.30934203952303163`, 0.9337149119385684],
              UndirectedEdge[297, 325] -> 
             RGBColor[
              0.267416015836295, 0.3984015661715987, 0.9385403185441094], 
             UndirectedEdge[170, 225] -> 
             RGBColor[
              0.22199301735031157`, 0.3506591147783862, 0.9359535459776369], 
             UndirectedEdge[27, 250] -> 
             RGBColor[
              0.19937642447535237`, 0.3268876416919933, 0.9346655644716588], 
             UndirectedEdge[67, 126] -> 
             RGBColor[
              0.18098291600078534`, 0.3075548980694286, 0.9336180813747896], 
             UndirectedEdge[12, 157] -> 
             RGBColor[
              0.24482342257705114`, 0.37465531820298625`, 0.937253703780742], 
             UndirectedEdge[316, 399] -> 
             RGBColor[
              0.5357585344043984, 0.6303722138797264, 0.9580316650391174], 
             UndirectedEdge[76, 377] -> 
             RGBColor[
              0.2688145572376063, 0.39987152185702324`, 0.9386199634079575], 
             UndirectedEdge[3, 51] -> 
             RGBColor[
              0.2187121116641707, 0.34721067488081686`, 0.9357667032524762], 
             UndirectedEdge[23, 186] -> 
             RGBColor[
              0.209250396089514, 0.3372658119044362, 0.9352278725478533], 
             UndirectedEdge[17, 319] -> 
             RGBColor[
              0.8300530358518976, 0.23200637964777565`, 0.17641212711281357`],
              UndirectedEdge[115, 360] -> 
             RGBColor[
              0.8089316906478522, 0.7980968050279984, 0.6248789386336926], 
             UndirectedEdge[131, 142] -> 
             RGBColor[
              0.6441352636384634, 0.7193460306737178, 0.9669266768382974], 
             UndirectedEdge[23, 130] -> 
             RGBColor[
              0.21379154943709947`, 0.3420388519985006, 0.935486484512964], 
             UndirectedEdge[348, 354] -> 
             RGBColor[
              0.19860265347109932`, 0.3260743593066081, 0.9346214993576583], 
             UndirectedEdge[76, 80] -> 
             RGBColor[
              0.24302079240522623`, 0.37276063959904404`, 0.9371510466592089],
              UndirectedEdge[38, 81] -> 
             RGBColor[
              0.2439408678768847, 0.37372769725591143`, 0.9372034435961902], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.22057742375863354`, 0.3491712361597149, 0.935872930016774], 
             UndirectedEdge[131, 281] -> 
             RGBColor[
              0.6064310569728814, 0.687254440774864, 0.9643678385927457], 
             UndirectedEdge[157, 167] -> 
             RGBColor[
              0.24133392101239853`, 0.37098763081135855`, 0.93705498182889], 
             UndirectedEdge[165, 172] -> 
             RGBColor[
              0.3025819493818708, 0.42881009810169846`, 0.9407829073040905], 
             UndirectedEdge[255, 331] -> 
             RGBColor[
              0.30757882188877433`, 0.4345645888368619, 0.9410490742458533], 
             UndirectedEdge[59, 268] -> 
             RGBColor[
              0.2019662570213913, 0.3296097199027477, 0.9348130516038419], 
             UndirectedEdge[161, 364] -> 
             RGBColor[
              0.9004423422818535, 0.6358848335091806, 0.23838402091941335`], 
             UndirectedEdge[149, 164] -> 
             RGBColor[
              0.21265948505393958`, 0.340848980554772, 0.9354220151210823], 
             UndirectedEdge[10, 52] -> 
             RGBColor[
              0.9159808794279284, 0.6604932743481702, 0.5104145698509248], 
             UndirectedEdge[132, 155] -> 
             RGBColor[
              0.18938684794258642`, 0.3163879633803221, 0.934096672866372], 
             UndirectedEdge[353, 400] -> 
             RGBColor[
              0.9076875092111716, 0.5794922772788073, 0.33827994298726377`], 
             UndirectedEdge[250, 265] -> 
             RGBColor[
              0.19635832810443649`, 0.32371543104779843`, 0.9344936883482087],
              UndirectedEdge[82, 233] -> 
             RGBColor[
              0.865044812104987, 0.8948209835298624, 0.9558976637938235], 
             UndirectedEdge[66, 81] -> 
             RGBColor[
              0.21264159429708712`, 0.3408301762349806, 0.9354209962689466], 
             UndirectedEdge[69, 201] -> 
             RGBColor[
              0.6192660008437627, 0.7014292931597987, 0.9634146436784279], 
             UndirectedEdge[84, 184] -> 
             RGBColor[
              0.21392003441563898`, 0.34217389785736374`, 0.9354938015424155],
              UndirectedEdge[180, 268] -> 
             RGBColor[
              0.1880422345433147, 0.314974689444274, 0.9340200991224608], 
             UndirectedEdge[17, 247] -> 
             RGBColor[
              0.8225002166596341, 0.17395210166956507`, 0.16917953892461288`],
              UndirectedEdge[188, 394] -> 
             RGBColor[
              0.3167171676025393, 0.44570099448454903`, 0.9415134165478973], 
             UndirectedEdge[241, 312] -> 
             RGBColor[
              0.41436397282412324`, 0.5281836244089898, 0.9484270661099586], 
             UndirectedEdge[81, 128] -> 
             RGBColor[
              0.2665289573662383, 0.3974692114768138, 0.9384898018765251], 
             UndirectedEdge[65, 198] -> 
             RGBColor[
              0.6026458427872066, 0.6834233570756016, 0.9643717480774334], 
             UndirectedEdge[356, 380] -> 
             RGBColor[
              0.8328828698668729, 0.8701375149884446, 0.9750500932107594], 
             UndirectedEdge[40, 265] -> 
             RGBColor[
              0.1962226401289317, 0.32357281438242835`, 0.9344859611187359], 
             UndirectedEdge[19, 168] -> 
             RGBColor[
              0.19873861175960342`, 0.3262172600880793, 0.9346292419810562], 
             UndirectedEdge[195, 241] -> 
             RGBColor[
              0.35276484059541724`, 0.47739540900316435`, 0.9437930699766406],
              UndirectedEdge[33, 141] -> 
             RGBColor[
              0.3011781143378584, 0.42954027603387246`, 0.9406221995821449], 
             UndirectedEdge[65, 100] -> 
             RGBColor[
              0.38210315454201915`, 0.5053802802265043, 0.9455682530202327], 
             UndirectedEdge[15, 207] -> 
             RGBColor[
              0.18682358813972555`, 0.3136938148074571, 0.9339506990126021], 
             UndirectedEdge[81, 135] -> 
             RGBColor[
              0.2822556151095555, 0.41153871876028536`, 0.9394754920042432], 
             UndirectedEdge[259, 271] -> 
             RGBColor[
              0.8577136869121025, 0.5371034017102467, 0.5783377792427893], 
             UndirectedEdge[194, 233] -> 
             RGBColor[
              0.7128854689421396, 0.7730895863286765, 0.9426895386250231], 
             UndirectedEdge[101, 283] -> 
             RGBColor[
              0.8929481444706848, 0.5918370196285758, 0.23170005506756156`], 
             UndirectedEdge[145, 192] -> 
             RGBColor[
              0.25406976709764434`, 0.3843738125462326, 0.9377802694224489], 
             UndirectedEdge[68, 397] -> 
             RGBColor[
              0.5928919663607762, 0.6752224028696671, 0.9636363647773936], 
             UndirectedEdge[142, 201] -> 
             RGBColor[
              0.5699368421210522, 0.6613816598554264, 0.9595312716051138], 
             UndirectedEdge[146, 354] -> 
             RGBColor[
              0.197615256434939, 0.32503654241701563`, 0.9345652685571719], 
             UndirectedEdge[153, 329] -> 
             RGBColor[
              0.23399514583317907`, 0.36327411279277777`, 0.9366370494391784],
              UndirectedEdge[132, 279] -> 
             RGBColor[
              0.1959554713815859, 0.323292003089491, 0.9344707462538155], 
             UndirectedEdge[257, 389] -> 
             RGBColor[
              0.981271770948398, 0.982206986986089, 0.7147685106713391], 
             UndirectedEdge[107, 386] -> 
             RGBColor[
              0.2825040137132291, 0.4111922082727934, 0.9395118848995476], 
             UndirectedEdge[157, 203] -> 
             RGBColor[
              0.2784354581733116, 0.40986687435040126`, 0.9391721369966093], 
             UndirectedEdge[264, 281] -> 
             RGBColor[
              0.3293650670543722, 0.4551923504771167, 0.9423729197712435], 
             UndirectedEdge[244, 302] -> 
             RGBColor[
              0.18853043849765405`, 0.3154878227542032, 0.9340479016154273], 
             UndirectedEdge[46, 105] -> 
             RGBColor[
              0.8954193827902208, 0.9181003086598438, 0.937247307981482], 
             UndirectedEdge[126, 347] -> 
             RGBColor[
              0.18344187738111917`, 0.31013942238731573`, 0.9337581155876922],
              UndirectedEdge[129, 253] -> 
             RGBColor[
              0.822264279381292, 0.17213858435985327`, 0.16895360512041946`], 
             UndirectedEdge[14, 69] -> 
             RGBColor[
              0.45573362712038445`, 0.5659105913267511, 0.9511564428609628], 
             UndirectedEdge[118, 124] -> 
             RGBColor[
              0.29203302591126107`, 0.41977282835890883`, 0.9401070895447208],
              UndirectedEdge[181, 245] -> 
             RGBColor[
              0.1935081925729178, 0.3207197578951424, 0.9343313773460864], 
             UndirectedEdge[33, 152] -> 
             RGBColor[
              0.2237166408577273, 0.3524707523687224, 0.9360517037865118], 
             UndirectedEdge[47, 371] -> 
             RGBColor[
              0.18051873474236652`, 0.3070670141360388, 0.9335916469388172], 
             UndirectedEdge[131, 273] -> 
             RGBColor[
              0.6690783888345512, 0.7395959833828867, 0.9688902910234116], 
             UndirectedEdge[230, 299] -> 
             RGBColor[
              0.20475753633962784`, 0.33254353144354476`, 0.9349720108316877],
              UndirectedEdge[107, 181] -> 
             RGBColor[
              0.20760170595158578`, 0.3355329340364814, 0.935133982083517], 
             UndirectedEdge[4, 318] -> 
             RGBColor[
              0.20715075077545358`, 0.3350589515541568, 0.9351083008533645], 
             UndirectedEdge[10, 333] -> 
             RGBColor[
              0.8983718156694669, 0.6481583597796403, 0.5759535503804154], 
             UndirectedEdge[152, 238] -> 
             RGBColor[
              0.20086303760420032`, 0.32845016634712887`, 0.9347502248900996],
              UndirectedEdge[50, 147] -> 
             RGBColor[
              0.23917140342485926`, 0.3687146877153205, 0.9369318296514377], 
             UndirectedEdge[39, 217] -> 
             RGBColor[
              0.2032105562120073, 0.33091755724521044`, 0.9348839126019717], 
             UndirectedEdge[98, 308] -> 
             RGBColor[
              0.20304826815792704`, 0.3307469822107151, 0.9348746705373756], 
             UndirectedEdge[31, 363] -> 
             RGBColor[
              0.6793920980440895, 0.7432878081939467, 0.9278140990011539], 
             UndirectedEdge[286, 386] -> 
             RGBColor[
              0.331585149915525, 0.4616241237277755, 0.94234929043675], 
             UndirectedEdge[137, 138] -> 
             RGBColor[
              0.29077492625511725`, 0.4229532620622423, 0.93987057393605], 
             UndirectedEdge[35, 372] -> 
             RGBColor[
              0.18502327958345532`, 0.31180157636866185`, 0.9338481741036404],
              UndirectedEdge[130, 158] -> 
             RGBColor[
              0.20340188077088672`, 0.3311186514872704, 0.9348948082525605], 
             UndirectedEdge[277, 373] -> 
             RGBColor[
              0.19154984531155025`, 0.31866141075705723`, 0.9342198523666666],
              UndirectedEdge[234, 365] -> 
             RGBColor[
              0.27647661087306347`, 0.4079248260301478, 0.9390563060275041], 
             UndirectedEdge[310, 316] -> 
             RGBColor[
              0.7693289728620583, 0.48993694637010154`, 0.5724844799948403], 
             UndirectedEdge[218, 305] -> 
             RGBColor[
              0.42916789405553485`, 0.5422531768418173, 0.9494057845729981], 
             UndirectedEdge[155, 279] -> 
             RGBColor[
              0.19246829134850796`, 0.31962675577474187`, 0.9342721565097523],
              UndirectedEdge[32, 129] -> 
             RGBColor[
              0.8204275141231614, 0.1580204017101934, 0.16719471663490398`], 
             UndirectedEdge[92, 158] -> 
             RGBColor[
              0.19775538870657966`, 0.32518383031940923`, 0.9345732488827347],
              UndirectedEdge[332, 334] -> 
             RGBColor[
              0.8890082529415364, 0.5076542323723299, 0.23230663812042954`], 
             UndirectedEdge[268, 300] -> 
             RGBColor[
              0.1919105716037125, 0.31904055696148764`, 0.9342403951953585], 
             UndirectedEdge[224, 227] -> 
             RGBColor[
              0.3858696957004528, 0.504223043119987, 0.9462592294929938], 
             UndirectedEdge[25, 91] -> 
             RGBColor[
              0.47826887557608655`, 0.5848930154724093, 0.9527405987202289], 
             UndirectedEdge[74, 304] -> 
             RGBColor[
              0.2654021800822186, 0.39628489710950293`, 0.9384256335771177], 
             UndirectedEdge[86, 397] -> 
             RGBColor[
              0.3161394186740798, 0.4444877390569253, 0.9415027034007689], 
             UndirectedEdge[32, 111] -> 
             RGBColor[
              0.8240654755025505, 0.18598336703701845`, 0.17067843256029655`],
              UndirectedEdge[59, 394] -> 
             RGBColor[
              0.286948743301538, 0.41441249311708334`, 0.9398181488223927], 
             UndirectedEdge[170, 355] -> 
             RGBColor[
              0.2218222289646276, 0.3504796053564232, 0.9359438198317311], 
             UndirectedEdge[9, 56] -> 
             RGBColor[
              0.6023784760141789, 0.6874029877027437, 0.9623014191002394], 
             UndirectedEdge[44, 317] -> 
             RGBColor[
              0.2084087804726259, 0.3363812205295747, 0.9351799437835304], 
             UndirectedEdge[236, 262] -> 
             RGBColor[
              0.4369845815472029, 0.5513866495573997, 0.9494877616771007], 
             UndirectedEdge[119, 346] -> 
             RGBColor[
              0.2216080062797242, 0.35025444373208703`, 0.9359316201667398], 
             UndirectedEdge[80, 244] -> 
             RGBColor[
              0.1927330122426994, 0.31990499421881113`, 0.9342872319730569], 
             UndirectedEdge[20, 360] -> 
             RGBColor[
              0.523690607917635, 0.622017048024192, 0.9563749606192402], 
             UndirectedEdge[196, 206] -> 
             RGBColor[
              0.6365065028818196, 0.7122246861355508, 0.9667719599708235], 
             UndirectedEdge[187, 302] -> 
             RGBColor[
              0.20552429842574232`, 0.33334944701157526`, 0.9350156767981692],
              UndirectedEdge[147, 312] -> 
             RGBColor[
              0.3975158125820031, 0.5104751397594638, 0.9474675883087893], 
             UndirectedEdge[259, 400] -> 
             RGBColor[
              0.8587699196703826, 0.545222069534533, 0.5793492289249624], 
             UndirectedEdge[120, 312] -> 
             RGBColor[
              0.4801821242946682, 0.587765497365623, 0.9525267121427227], 
             UndirectedEdge[52, 60] -> 
             RGBColor[
              0.8480092281788032, 0.880384326820778, 0.9017418370121976], 
             UndirectedEdge[266, 384] -> 
             RGBColor[
              0.7959032258697958, 0.7536598609266292, 0.6159939861993788], 
             UndirectedEdge[135, 393] -> 
             RGBColor[
              0.5286635054610748, 0.6238093444947674, 0.9577562869015417], 
             UndirectedEdge[77, 244] -> 
             RGBColor[
              0.18965577385650711`, 0.31667062156674053`, 0.9341119877993296],
              UndirectedEdge[239, 385] -> 
             RGBColor[
              0.750777447641219, 0.8006120212149852, 0.7940547292395577], 
             UndirectedEdge[278, 296] -> 
             RGBColor[
              0.1835851599868279, 0.3102900214905575, 0.9337662753201197], 
             UndirectedEdge[267, 275] -> 
             RGBColor[
              0.19585412945824818`, 0.323185486302614, 0.9344649749812033], 
             UndirectedEdge[148, 340] -> 
             RGBColor[
              0.263972502592159, 0.39478221542066183`, 0.9383442155590771], 
             UndirectedEdge[202, 212] -> 
             RGBColor[
              0.45268550871471924`, 0.56313574583105, 0.9509994425842794], 
             UndirectedEdge[81, 346] -> 
             RGBColor[
              0.21629108370638292`, 0.34466602099514354`, 0.9356288292918702],
              UndirectedEdge[50, 217] -> 
             RGBColor[
              0.21968733955898895`, 0.34823570123129066`, 0.9358222410383658],
              UndirectedEdge[5, 183] -> 
             RGBColor[
              0.1877508166785864, 0.3146683907914848, 0.9340035033061785], 
             UndirectedEdge[313, 339] -> 
             RGBColor[
              0.3332875570200404, 0.460867825469856, 0.9425394482092617], 
             UndirectedEdge[4, 184] -> 
             RGBColor[
              0.20719899217930893`, 0.3351096563282905, 0.9351110481299474], 
             UndirectedEdge[104, 349] -> 
             RGBColor[
              0.21123195753513827`, 0.3393485586220395, 0.9353407195407242], 
             UndirectedEdge[119, 135] -> 
             RGBColor[
              0.2875725376828968, 0.4171271414972289, 0.9397782828791128], 
             UndirectedEdge[53, 273] -> 
             RGBColor[
              0.4633253395942303, 0.573810427068907, 0.9512742786711021], 
             UndirectedEdge[224, 259] -> 
             RGBColor[
              0.6965860849930616, 0.7612921063995717, 0.9717456253125671], 
             UndirectedEdge[110, 289] -> 
             RGBColor[
              0.6635885313279589, 0.7348104646113509, 0.9687942877706517], 
             UndirectedEdge[59, 155] -> 
             RGBColor[
              0.20108602021263303`, 0.3286845352065056, 0.9347629234197767], 
             UndirectedEdge[5, 29] -> 
             RGBColor[
              0.18632940584411195`, 0.31317439788179996`, 0.9339225560619441],
              UndirectedEdge[119, 311] -> 
             RGBColor[
              0.22119300122602184`, 0.3498182471078057, 0.9359079862428765], 
             UndirectedEdge[68, 72] -> 
             RGBColor[
              0.6435705389401349, 0.7187858683660439, 0.9669572267898132], 
             UndirectedEdge[121, 234] -> 
             RGBColor[
              0.2453302072944222, 0.37518798107295015`, 0.9372825644206755], 
             UndirectedEdge[20, 336] -> 
             RGBColor[
              0.3097133743307097, 0.43584317444763615`, 0.9412059659212678], 
             UndirectedEdge[17, 256] -> 
             RGBColor[
              0.9099828197722593, 0.6023554678641716, 0.47566457355675007`], 
             UndirectedEdge[186, 272] -> 
             RGBColor[
              0.20161622991530592`, 0.3292418192212516, 0.9347931180779689], 
             UndirectedEdge[45, 304] -> 
             RGBColor[
              0.2609958832174149, 0.3916535997292371, 0.9381747014891992], 
             UndirectedEdge[165, 252] -> 
             RGBColor[
              0.21574093049341658`, 0.3440877750865875, 0.9355974988802704], 
             UndirectedEdge[106, 254] -> 
             RGBColor[
              0.18679837373704838`, 0.3136673128715579, 0.9339492630896711], 
             UndirectedEdge[144, 169] -> 
             RGBColor[
              0.5192579762174159, 0.6205960432553745, 0.9552970364739267], 
             UndirectedEdge[191, 355] -> 
             RGBColor[
              0.19607480659810572`, 0.32341743196834305`, 0.9344775422178556],
              UndirectedEdge[96, 377] -> 
             RGBColor[
              0.23316169487877575`, 0.36239810299585723`, 0.9365895856403053],
              UndirectedEdge[110, 303] -> 
             RGBColor[
              0.873446363467674, 0.7484181435664192, 0.6095212570798225], 
             UndirectedEdge[177, 260] -> 
             RGBColor[
              0.18516377148342406`, 0.31194924226322995`, 0.9338561749095045],
              UndirectedEdge[20, 88] -> 
             RGBColor[
              0.40751079531136875`, 0.5273871016357587, 0.9471872054229611], 
             UndirectedEdge[57, 68] -> 
             RGBColor[
              0.584951659196002, 0.6683449078949819, 0.9631304154261922], 
             UndirectedEdge[127, 264] -> 
             RGBColor[
              0.2996738393944105, 0.42947530140255136`, 0.9404810209996725], 
             UndirectedEdge[171, 186] -> 
             RGBColor[
              0.1973172314150955, 0.32472329922528254`, 0.9345482964731804], 
             UndirectedEdge[362, 385] -> 
             RGBColor[
              0.892844244734438, 0.9136671066548807, 0.806798376116899], 
             UndirectedEdge[109, 370] -> 
             RGBColor[
              0.18414849826566793`, 0.3108821257393283, 0.9337983566017154], 
             UndirectedEdge[123, 161] -> 
             RGBColor[
              0.861352076814639, 0.4393326641242953, 0.20508206465224244`], 
             UndirectedEdge[119, 213] -> 
             RGBColor[
              0.2826015926364835, 0.4128215587449884, 0.9394615386563896], 
             UndirectedEdge[140, 360] -> 
             RGBColor[
              0.5345510834209994, 0.6314238460418358, 0.9570669805147731], 
             UndirectedEdge[320, 347] -> 
             RGBColor[
              0.1840162025368019, 0.3107430745402564, 0.9337908225556705], 
             UndirectedEdge[10, 345] -> 
             RGBColor[
              0.8355254140940163, 0.5985125148757706, 0.5861216038325132], 
             UndirectedEdge[169, 383] -> 
             RGBColor[
              0.4077881387207459, 0.527520322736191, 0.9472344418691334], 
             UndirectedEdge[154, 372] -> 
             RGBColor[
              0.18315975702077553`, 0.3098428960011307, 0.9337420492505304], 
             UndirectedEdge[167, 341] -> 
             RGBColor[
              0.2425749937598598, 0.37229207695749733`, 0.9371256590858552], 
             UndirectedEdge[186, 308] -> 
             RGBColor[
              0.20971443584181115`, 0.3377535471059201, 0.9352542989252615], 
             UndirectedEdge[145, 225] -> 
             RGBColor[
              0.22917757181567264`, 0.3582105370485437, 0.9363626957258434], 
             UndirectedEdge[12, 65] -> 
             RGBColor[
              0.30963980079837916`, 0.4365176650238572, 0.941174248166886], 
             UndirectedEdge[274, 288] -> 
             RGBColor[
              0.20843688657003606`, 0.3364107618199823, 0.9351815443841986], 
             UndirectedEdge[143, 171] -> 
             RGBColor[
              0.19347840745274208`, 0.320688451845352, 0.9343296811275554], 
             UndirectedEdge[167, 168] -> 
             RGBColor[
              0.21688542639170627`, 0.3452907128409211, 0.935662676228548], 
             UndirectedEdge[203, 341] -> 
             RGBColor[
              0.2796765309207728, 0.4111713204965401, 0.9392428142535747], 
             UndirectedEdge[114, 299] -> 
             RGBColor[
              0.1875337477163088, 0.31444023754916384`, 0.9339911415499016], 
             UndirectedEdge[154, 231] -> 
             RGBColor[
              0.18878970308862236`, 0.3157603262776354, 0.9340626663503354], 
             UndirectedEdge[218, 384] -> 
             RGBColor[
              0.7469305423915883, 0.7141446268230167, 0.6119725391027997], 
             UndirectedEdge[360, 380] -> 
             RGBColor[
              0.6915688443012366, 0.7589781043767949, 0.9698927773878063], 
             UndirectedEdge[98, 306] -> 
             RGBColor[
              0.20777436312467215`, 0.33571440767249217`, 0.9351438146541007],
              UndirectedEdge[57, 262] -> 
             RGBColor[
              0.35631608788520674`, 0.4830448191840292, 0.9439251239354682], 
             UndirectedEdge[152, 160] -> 
             RGBColor[
              0.19806967394342445`, 0.325514164030168, 0.9345911469620297], 
             UndirectedEdge[311, 354] -> 
             RGBColor[
              0.19934869375531813`, 0.32685849494700814`, 0.9346639852481768],
              UndirectedEdge[287, 303] -> 
             RGBColor[
              0.8556245290555657, 0.372684995897263, 0.19871148964339302`], 
             UndirectedEdge[222, 247] -> 
             RGBColor[
              0.8842131182088144, 0.5486602398250497, 0.5659586027648067], 
             UndirectedEdge[24, 206] -> 
             RGBColor[
              0.3445350824096081, 0.46835060878643464`, 0.9433388530787478], 
             UndirectedEdge[92, 308] -> 
             RGBColor[
              0.20860909712508957`, 0.3365917660321234, 0.9351913515205462], 
             UndirectedEdge[18, 266] -> 
             RGBColor[
              0.8253787823254205, 0.8596851688766582, 0.6977603506868537], 
             UndirectedEdge[28, 314] -> 
             RGBColor[
              0.18717488313259786`, 0.3140630481183549, 0.9339707047427519], 
             UndirectedEdge[128, 139] -> 
             RGBColor[
              0.3054227451460619, 0.43834904844198347`, 0.9407047455523833], 
             UndirectedEdge[160, 181] -> 
             RGBColor[
              0.19370887514270452`, 0.320930687999998, 0.9343428059215524], 
             UndirectedEdge[42, 296] -> 
             RGBColor[
              0.18148102360409654`, 0.30807844074235485`, 0.933646447865914], 
             UndirectedEdge[121, 289] -> 
             RGBColor[
              0.3589692840265578, 0.4787637861846151, 0.9444710719407625], 
             UndirectedEdge[22, 286] -> 
             RGBColor[
              0.2816381839372477, 0.41219449596583724`, 0.9393925574171622], 
             UndirectedEdge[128, 213] -> 
             RGBColor[
              0.3146576489473405, 0.4465145063990592, 0.9412870836406073], 
             UndirectedEdge[178, 398] -> 
             RGBColor[
              0.18190742429108608`, 0.30852661489974587`, 0.9336707307542348],
              UndirectedEdge[6, 129] -> 
             RGBColor[
              0.8727497313117147, 0.5467966411297123, 0.579484556485264], 
             UndirectedEdge[265, 375] -> 
             RGBColor[
              0.20089610111622702`, 0.32848491819461667`, 0.9347521078081966],
              UndirectedEdge[162, 270] -> 
             RGBColor[
              0.20162095796864934`, 0.3292467887050914, 0.9347933873336124], 
             UndirectedEdge[199, 271] -> 
             RGBColor[
              0.9043692525849842, 0.5721827291840494, 0.5015646144777819], 
             UndirectedEdge[60, 72] -> 
             RGBColor[
              0.5862802580314027, 0.6740171687476564, 0.9612505424717664], 
             UndirectedEdge[230, 258] -> 
             RGBColor[
              0.22938899732612533`, 0.3584327586651811, 0.9363747360958877], 
             UndirectedEdge[38, 135] -> 
             RGBColor[
              0.2970405045044002, 0.42707857493039736`, 0.9403174695829958], 
             UndirectedEdge[42, 67] -> 
             RGBColor[
              0.18164605198289263`, 0.3082518960318731, 0.9336558459879488], 
             UndirectedEdge[220, 352] -> 
             RGBColor[
              0.1830449444132805, 0.30972222067111355`, 0.9337355108423835], 
             UndirectedEdge[4, 226] -> 
             RGBColor[
              0.1963748100004493, 0.3237327545655205, 0.9344946269678038], 
             UndirectedEdge[134, 163] -> 
             RGBColor[
              0.17908461226291875`, 0.3055596604815222, 0.9335099757852068], 
             UndirectedEdge[25, 76] -> 
             RGBColor[
              0.32344841914925154`, 0.45219009338865274`, 0.9419182030554161],
              UndirectedEdge[250, 375] -> 
             RGBColor[
              0.19825790374427554`, 0.32571200548532114`, 0.9346018663707272],
              UndirectedEdge[50, 138] -> 
             RGBColor[
              0.26001645706684573`, 0.3906241607457843, 0.9381189246188555], 
             UndirectedEdge[24, 157] -> 
             RGBColor[
              0.2535215613420126, 0.38379761353881126`, 0.9377490499156633], 
             UndirectedEdge[127, 328] -> 
             RGBColor[
              0.2853602010040631, 0.41443075991720546`, 0.9396658804684725], 
             UndirectedEdge[107, 245] -> 
             RGBColor[
              0.20898762068619692`, 0.33698961829462715`, 0.9352129078773759],
              UndirectedEdge[16, 96] -> 
             RGBColor[
              0.22029148033523374`, 0.34887069149186156`, 0.9358566459618267],
              UndirectedEdge[42, 278] -> 
             RGBColor[
              0.18598976689484537`, 0.3128174158117676, 0.9339032141262342], 
             UndirectedEdge[51, 176] -> 
             RGBColor[
              0.19370665948804128`, 0.32092835920646634`, 0.9343426797432972],
              UndirectedEdge[33, 386] -> 
             RGBColor[
              0.2942581498186507, 0.4235465505748645, 0.9401812655620653], 
             UndirectedEdge[78, 187] -> 
             RGBColor[
              0.21840643996372563`, 0.3468893945429439, 0.9357492957013367], 
             UndirectedEdge[107, 150] -> 
             RGBColor[
              0.23074389884075946`, 0.35985684606277935`, 0.936451895732749], 
             UndirectedEdge[312, 360] -> 
             RGBColor[
              0.6052860238543496, 0.6901250393354524, 0.9622831022684131], 
             UndirectedEdge[78, 208] -> 
             RGBColor[
              0.257441859662032, 0.38791809563442126`, 0.9379723051054267], 
             UndirectedEdge[28, 197] -> 
             RGBColor[
              0.19145378666017485`, 0.3185604470239914, 0.9342143819685769], 
             UndirectedEdge[221, 316] -> 
             RGBColor[
              0.5410265117385101, 0.6349350710702945, 0.9583673358965574], 
             UndirectedEdge[243, 383] -> 
             RGBColor[
              0.29485575436090533`, 0.42265924207033345`, 0.9402707855274055],
              UndirectedEdge[83, 332] -> 
             RGBColor[
              0.8843949242801739, 0.5504136015544692, 0.5662686116652167], 
             UndirectedEdge[98, 354] -> 
             RGBColor[
              0.19467499021807763`, 0.3219461361994489, 0.9343978247458558], 
             UndirectedEdge[46, 215] -> 
             RGBColor[
              0.7558037231431869, 0.8091588799312872, 0.9762951098017001], 
             UndirectedEdge[375, 381] -> 
             RGBColor[
              0.196072227977034, 0.3234147216741027, 0.9344773953692003], 
             UndirectedEdge[286, 304] -> 
             RGBColor[
              0.3017569575169641, 0.43334060260203944`, 0.9405382918094687], 
             UndirectedEdge[225, 235] -> 
             RGBColor[
              0.20086558407238086`, 0.32845284284664206`, 0.9347503699076954],
              UndirectedEdge[96, 225] -> 
             RGBColor[
              0.21005566506834547`, 0.33811220065819025`, 0.9352737314249091],
              UndirectedEdge[20, 389] -> 
             RGBColor[
              0.688874491712781, 0.747632448851442, 0.7193091573204213], 
             UndirectedEdge[259, 393] -> 
             RGBColor[
              0.808698190108407, 0.8510901979921818, 0.9814053247963395], 
             UndirectedEdge[97, 166] -> 
             RGBColor[
              0.27189959411517783`, 0.40311409121798647`, 0.9387956516942321],
              UndirectedEdge[115, 334] -> 
             RGBColor[
              0.9576597296930937, 0.8685855926092536, 0.2913334520501617], 
             UndirectedEdge[251, 260] -> 
             RGBColor[
              0.1869284496057658, 0.31380403085686637`, 0.9339566707179645], 
             UndirectedEdge[119, 344] -> 
             RGBColor[
              0.2156761634002051, 0.3440197007651513, 0.9355938104901265], 
             UndirectedEdge[329, 341] -> 
             RGBColor[
              0.2558412218032698, 0.3862357237585604, 0.9378811511473018], 
             UndirectedEdge[283, 334] -> 
             RGBColor[
              0.9460670651662169, 0.8226245407866379, 0.2820057220570269], 
             UndirectedEdge[1, 5] -> 
             RGBColor[
              0.18431548798727523`, 0.3110576425244974, 0.9338078664193217], 
             UndirectedEdge[364, 391] -> 
             RGBColor[
              0.8707862783740112, 0.44118719063375156`, 0.21128740006323304`],
              UndirectedEdge[48, 295] -> 
             RGBColor[
              0.19691998178395526`, 0.3243057646758728, 0.9345256736943651], 
             UndirectedEdge[105, 199] -> 
             RGBColor[
              0.9870190215241651, 0.9889000460513815, 0.8647919372474027], 
             UndirectedEdge[281, 293] -> 
             RGBColor[
              0.356440478793437, 0.4831525603366694, 0.9439330500141462], 
             UndirectedEdge[216, 358] -> 
             RGBColor[
              0.24670674727990904`, 0.37663481187537284`, 0.9373609563364405],
              UndirectedEdge[100, 206] -> 
             RGBColor[
              0.40830029738828666`, 0.5280709286532568, 0.947237511797173], 
             UndirectedEdge[168, 341] -> 
             RGBColor[
              0.22365393842066325`, 0.35240484813180395`, 0.936048132975481], 
             UndirectedEdge[199, 259] -> 
             RGBColor[
              0.9420801867046171, 0.9545306309034027, 0.913114429015637], 
             UndirectedEdge[19, 24] -> 
             RGBColor[
              0.22984730742841403`, 0.35891447164122536`, 0.936400836178204], 
             UndirectedEdge[136, 299] -> 
             RGBColor[
              0.1855129526762866, 0.3123162538362948, 0.9338760602618706], 
             UndirectedEdge[64, 123] -> 
             RGBColor[
              0.9178715311357676, 0.6596421800395433, 0.31164482201230714`], 
             UndirectedEdge[101, 334] -> 
             RGBColor[
              0.9070926668350056, 0.6466589621982325, 0.24962429328823976`], 
             UndirectedEdge[2, 328] -> 
             RGBColor[
              0.2165885293871429, 0.3449786552647677, 0.935645768383358], 
             UndirectedEdge[235, 349] -> 
             RGBColor[
              0.19583192039754477`, 0.3231621431716789, 0.9344637102080516], 
             UndirectedEdge[45, 290] -> 
             RGBColor[
              0.24862549482263574`, 0.3786515371983993, 0.9374702261704662], 
             UndirectedEdge[225, 327] -> 
             RGBColor[
              0.19712268368204472`, 0.3245188172228074, 0.9345372172675908], 
             UndirectedEdge[24, 386] -> 
             RGBColor[
              0.3010543278758621, 0.4306897646155703, 0.940568297848379], 
             UndirectedEdge[363, 393] -> 
             RGBColor[
              0.5482487832688899, 0.640773127747212, 0.9590042434848745], 
             UndirectedEdge[2, 258] -> 
             RGBColor[
              0.2197390144926751, 0.34829001486297484`, 0.935825183849393], 
             UndirectedEdge[8, 234] -> 
             RGBColor[
              0.2512674523014992, 0.38142840201846384`, 0.9376206817404615], 
             UndirectedEdge[44, 151] -> 
             RGBColor[
              0.21796286839338874`, 0.3464231726984579, 0.9357240349566114], 
             UndirectedEdge[253, 283] -> 
             RGBColor[
              0.878557469851581, 0.4812239884723157, 0.21791952880036536`], 
             UndirectedEdge[257, 360] -> 
             RGBColor[
              0.816087887153252, 0.8565915861588391, 0.9518343139701578], 
             UndirectedEdge[65, 358] -> 
             RGBColor[
              0.3270456066713938, 0.4548122705882284, 0.942165483061772], 
             UndirectedEdge[282, 340] -> 
             RGBColor[
              0.29320777122887487`, 0.42492993475416496`, 0.9400303722049579],
              UndirectedEdge[256, 316] -> 
             RGBColor[
              0.8522226042580414, 0.8830674650503693, 0.8745751101286188], 
             UndirectedEdge[96, 182] -> 
             RGBColor[
              0.2267284521296566, 0.35563635697538404`, 0.9362232219828728], 
             UndirectedEdge[2, 106] -> 
             RGBColor[
              0.19417223523988333`, 0.32141770884085996`, 0.9343691935936069],
              UndirectedEdge[210, 279] -> 
             RGBColor[
              0.2223588131160111, 0.3510435893209275, 0.9359743775053473], 
             UndirectedEdge[279, 371] -> 
             RGBColor[
              0.1895350584309733, 0.3165437420007044, 0.9341051132344278], 
             UndirectedEdge[271, 353] -> 
             RGBColor[
              0.9066312764528914, 0.571373609454521, 0.33726849330509057`], 
             UndirectedEdge[306, 311] -> 
             RGBColor[
              0.21244806666191265`, 0.3406267664200514, 0.9354099751564218], 
             UndirectedEdge[64, 312] -> 
             RGBColor[
              0.7702008939642393, 0.8151650470913949, 0.695936819489472], 
             UndirectedEdge[137, 210] -> 
             RGBColor[
              0.2691626848877073, 0.40023742608984725`, 0.9386397887626219], 
             UndirectedEdge[264, 394] -> 
             RGBColor[
              0.30880202077051594`, 0.4373816733147978, 0.941062660645224], 
             UndirectedEdge[199, 224] -> 
             RGBColor[
              0.7432416506659434, 0.7963714338733744, 0.8949724605475597], 
             UndirectedEdge[61, 301] -> 
             RGBColor[
              0.23356716082772205`, 0.3628242734162258, 0.9366126763262647], 
             UndirectedEdge[48, 103] -> 
             RGBColor[
              0.2013643551866071, 0.328977082911609, 0.9347787741847848], 
             UndirectedEdge[7, 14] -> 
             RGBColor[
              0.29679890469924086`, 0.4265200793940456, 0.9403148622219284], 
             UndirectedEdge[88, 195] -> 
             RGBColor[
              0.42750707901937735`, 0.5447068775411936, 0.948461350938816], 
             UndirectedEdge[211, 341] -> 
             RGBColor[
              0.24091627830701134`, 0.3705486618479197, 0.9370311976946651], 
             UndirectedEdge[84, 185] -> 
             RGBColor[
              0.20341836522778634`, 0.3311359776966468, 0.9348957470179945], 
             UndirectedEdge[368, 387] -> 
             RGBColor[
              0.18468757746568928`, 0.3114487321581461, 0.9338290563646603], 
             UndirectedEdge[134, 171] -> 
             RGBColor[
              0.18358417843459812`, 0.31028898981693004`, 0.9337662194221723],
              UndirectedEdge[41, 295] -> 
             RGBColor[
              0.19034802985855803`, 0.31739822651646155`, 0.9341514107545453],
              UndirectedEdge[77, 388] -> 
             RGBColor[
              0.23386679686193323`, 0.36313920988620363`, 0.9366297401551412],
              UndirectedEdge[142, 273] -> 
             RGBColor[
              0.4991027451822828, 0.6042331187182427, 0.9537103428557971], 
             UndirectedEdge[64, 140] -> 
             RGBColor[
              0.6994659535308891, 0.7564638537977784, 0.690720697735832], 
             UndirectedEdge[150, 157] -> 
             RGBColor[
              0.24263401195527415`, 0.3723541088228476, 0.9371290200847746], 
             UndirectedEdge[210, 264] -> 
             RGBColor[
              0.2528298194491141, 0.3830705489504057, 0.9377096562382032], 
             UndirectedEdge[202, 309] -> 
             RGBColor[
              0.5124790971855998, 0.6108362268976354, 0.9562827357512269], 
             UndirectedEdge[105, 287] -> 
             RGBColor[
              0.9013106453354156, 0.5611585668627788, 0.528730305122088], 
             UndirectedEdge[157, 160] -> 
             RGBColor[
              0.22107841637049833`, 0.349697811159551, 0.9359014608048675], 
             UndirectedEdge[153, 379] -> 
             RGBColor[
              0.19405975897206282`, 0.32129948915197337`, 0.9343627882365483],
              UndirectedEdge[207, 387] -> 
             RGBColor[
              0.18852965084716983`, 0.3154869948836043, 0.9340478567598975], 
             UndirectedEdge[93, 264] -> 
             RGBColor[
              0.3012538452175734, 0.43084382303317337`, 0.9405816975735801], 
             UndirectedEdge[202, 365] -> 
             RGBColor[
              0.31680424057691503`, 0.4485693265510483, 0.9414167025039941], 
             UndirectedEdge[138, 230] -> 
             RGBColor[
              0.2550152839737512, 0.38536761073225334`, 0.9378341152097762], 
             UndirectedEdge[5, 291] -> 
             RGBColor[
              0.19113912643877223`, 0.3182297191806869, 0.9341964625344661], 
             UndirectedEdge[241, 360] -> 
             RGBColor[
              0.4718334584098283, 0.5745274932673213, 0.9531648972863125], 
             UndirectedEdge[299, 300] -> 
             RGBColor[
              0.19227535029574405`, 0.31942396249511773`, 0.934261168802228], 
             UndirectedEdge[9, 266] -> 
             RGBColor[
              0.6722902895010364, 0.7439175508444353, 0.9679712712136599], 
             UndirectedEdge[226, 322] -> 
             RGBColor[
              0.1935079091107788, 0.32071945995846174`, 0.9343313612033369], 
             UndirectedEdge[175, 216] -> 
             RGBColor[
              0.20297653411671235`, 0.3306715851851976, 0.9348705853898494], 
             UndirectedEdge[115, 257] -> 
             RGBColor[
              0.9622640683610495, 0.9182194829930534, 0.6096923191590835], 
             UndirectedEdge[146, 275] -> 
             RGBColor[
              0.1966367657635329, 0.324008086681476, 0.9345095449609826], 
             UndirectedEdge[64, 101] -> 
             RGBColor[
              0.9232794978996539, 0.7012101823729198, 0.31682349709282953`], 
             UndirectedEdge[79, 390] -> 
             RGBColor[
              0.2060170491676479, 0.3338673592835195, 0.9350437382239613], 
             UndirectedEdge[98, 378] -> 
             RGBColor[
              0.21674290293340537`, 0.34514091164973765`, 0.9356545597284425],
              UndirectedEdge[37, 80] -> 
             RGBColor[
              0.24371904320437376`, 0.3734945454606058, 0.9371908110092508], 
             UndirectedEdge[344, 354] -> 
             RGBColor[
              0.1938318559295014, 0.32105994860435383`, 0.9343498094954268], 
             UndirectedEdge[119, 227] -> 
             RGBColor[
              0.25689083303762017`, 0.3873389317150586, 0.9379409249543373], 
             UndirectedEdge[81, 166] -> 
             RGBColor[
              0.2371652059079643, 0.3666060469247946, 0.9368175796707537], 
             UndirectedEdge[192, 221] -> 
             RGBColor[
              0.3140891047086496, 0.4418027488287358, 0.9414053462268441], 
             UndirectedEdge[242, 331] -> 
             RGBColor[
              0.2906837062391053, 0.4199308888343219, 0.9399725324164205], 
             UndirectedEdge[225, 322] -> 
             RGBColor[
              0.2017966288426081, 0.3294314299317988, 0.9348033915300026], 
             UndirectedEdge[165, 170] -> 
             RGBColor[
              0.23052227294686206`, 0.35962390319639986`, 0.9364392744659576],
              UndirectedEdge[41, 250] -> 
             RGBColor[
              0.1942575833696331, 0.32150741513661096`, 0.934374054043335], 
             UndirectedEdge[31, 393] -> 
             RGBColor[
              0.8531150739602782, 0.8852437730014981, 0.9417329113283139], 
             UndirectedEdge[140, 312] -> 
             RGBColor[
              0.4770815978352943, 0.5850799771835042, 0.9523291493384193], 
             UndirectedEdge[56, 100] -> 
             RGBColor[
              0.4530551393941151, 0.565068246426121, 0.9505774993750733], 
             UndirectedEdge[89, 183] -> 
             RGBColor[
              0.21045489979042858`, 0.338531821664043, 0.935296467251717], 
             UndirectedEdge[39, 210] -> 
             RGBColor[
              0.22192743235245416`, 0.35059018078730897`, 0.9359498110090333],
              UndirectedEdge[34, 321] -> 
             RGBColor[
              0.18374554341254123`, 0.3104585946398788, 0.9337754089189481], 
             UndirectedEdge[148, 301] -> 
             RGBColor[
              0.25321055434935075`, 0.3834707254705414, 0.9377313385275249], 
             UndirectedEdge[136, 155] -> 
             RGBColor[
              0.18426793717549678`, 0.3110076636064226, 0.933805158470936], 
             UndirectedEdge[51, 205] -> 
             RGBColor[
              0.19318129293550862`, 0.32037616564959115`, 0.9343127608953405],
              UndirectedEdge[11, 123] -> 
             RGBColor[
              0.8581753215010539, 0.6172298567057516, 0.5883641909402252], 
             UndirectedEdge[223, 400] -> 
             RGBColor[
              0.8406657720719041, 0.3123044383826159, 0.18652492711661786`], 
             UndirectedEdge[6, 201] -> 
             RGBColor[
              0.7959386825090102, 0.8413708229845736, 0.9800676455168078], 
             UndirectedEdge[201, 273] -> 
             RGBColor[
              0.5948799673171399, 0.6816316125645953, 0.9614948857902279], 
             UndirectedEdge[54, 196] -> 
             RGBColor[
              0.8961892019683437, 0.8555483275728113, 0.6311082747514651], 
             UndirectedEdge[84, 288] -> 
             RGBColor[
              0.21401051896422651`, 0.342269002854981, 0.9354989545035975], 
             UndirectedEdge[177, 248] -> 
             RGBColor[
              0.18215464872777276`, 0.30878646345763827`, 0.9336848098201683],
              UndirectedEdge[76, 117] -> 
             RGBColor[
              0.4207333030341396, 0.5335965741048728, 0.9489064510842957], 
             UndirectedEdge[342, 348] -> 
             RGBColor[
              0.1937491041812462, 0.3209729712701737, 0.9343450969057838], 
             UndirectedEdge[332, 389] -> 
             RGBColor[
              0.905464097691441, 0.5627808456183245, 0.32878632140514163`], 
             UndirectedEdge[68, 236] -> 
             RGBColor[
              0.6656201528579981, 0.7366867382683524, 0.9686930531678246], 
             UndirectedEdge[84, 318] -> 
             RGBColor[
              0.2138717930117836, 0.3421231930832301, 0.9354910542658326], 
             UndirectedEdge[15, 372] -> 
             RGBColor[
              0.1810383624053819, 0.30761317575616476`, 0.9336212389655058], 
             UndirectedEdge[88, 189] -> 
             RGBColor[
              0.331784795723977, 0.4548098720727408, 0.9426178463888004], 
             UndirectedEdge[364, 380] -> 
             RGBColor[
              0.8208602613542741, 0.753663537851497, 0.6141649050014586], 
             UndirectedEdge[103, 295] -> 
             RGBColor[
              0.1903453971129866, 0.3173954593339403, 0.9341512608235798], 
             UndirectedEdge[20, 257] -> 
             RGBColor[
              0.6770229856308323, 0.7421397259892473, 0.9411883411446311], 
             UndirectedEdge[12, 24] -> 
             RGBColor[
              0.25148362362516946`, 0.3816556117856949, 0.9376329923775478], 
             UndirectedEdge[152, 157] -> 
             RGBColor[
              0.22385261786682037`, 0.3526136728267195, 0.9360594474760198], 
             UndirectedEdge[26, 70] -> 
             RGBColor[
              0.1896105861046007, 0.3166231263744179, 0.9341094144237078], 
             UndirectedEdge[33, 74] -> 
             RGBColor[
              0.24756162893783695`, 0.3775333467004828, 0.9374096405821755], 
             UndirectedEdge[124, 238] -> 
             RGBColor[
              0.21375043106969976`, 0.3419956339873084, 0.9354841428827698], 
             UndirectedEdge[148, 339] -> 
             RGBColor[
              0.3192552716311131, 0.4461190038278132, 0.9417403303152683], 
             UndirectedEdge[175, 229] -> 
             RGBColor[
              0.1940292110138258, 0.32126738131101384`, 0.9343610485755184], 
             UndirectedEdge[105, 337] -> 
             RGBColor[
              0.9711407562018461, 0.97781294412538, 0.9254748728105828], 
             UndirectedEdge[158, 306] -> 
             RGBColor[
              0.20672015111524922`, 0.33460636400968674`, 0.935083778839731], 
             UndirectedEdge[136, 268] -> 
             RGBColor[
              0.18514817398425504`, 0.3119328483026647, 0.9338552866550012], 
             UndirectedEdge[133, 278] -> 
             RGBColor[
              0.18574944160901402`, 0.31256481869885566`, 0.9338895279567354],
              UndirectedEdge[197, 254] -> 
             RGBColor[
              0.18919463052287389`, 0.31618593068491585`, 0.9340857263686796],
              UndirectedEdge[296, 398] -> 
             RGBColor[
              0.17994179284220208`, 0.3064606116187368, 0.933558790951112], 
             UndirectedEdge[10, 271] -> 
             RGBColor[
              0.8314849257202783, 0.24301251263429177`, 0.17778330646786333`],
              UndirectedEdge[221, 399] -> 
             RGBColor[
              0.36464378874039466`, 0.49025785510237774`, 0.9444557576700642],
              UndirectedEdge[187, 388] -> 
             RGBColor[
              0.2435643246839634, 0.37333192648593383`, 0.937182000018399], 
             UndirectedEdge[143, 186] -> 
             RGBColor[
              0.20274228315425485`, 0.3304253725712859, 0.9348572451440806], 
             UndirectedEdge[372, 387] -> 
             RGBColor[
              0.18274442511282618`, 0.30940635583231196`, 0.9337183967128011],
              UndirectedEdge[147, 255] -> 
             RGBColor[
              0.3107019378391358, 0.4378471817176799, 0.9412269310789902], 
             UndirectedEdge[27, 86] -> 
             RGBColor[
              0.23656599040606416`, 0.3659762334398404, 0.9367834552343804], 
             UndirectedEdge[19, 157] -> 
             RGBColor[
              0.2231871063802957, 0.35191417805851677`, 0.9360215475813982], 
             UndirectedEdge[192, 208] -> 
             RGBColor[
              0.27634222217301546`, 0.40778357498566165`, 0.9390486527898467],
              UndirectedEdge[88, 89] -> 
             RGBColor[
              0.33131087657095276`, 0.4543117529947025, 0.9425908573941362], 
             UndirectedEdge[54, 332] -> 
             RGBColor[
              0.8830293594773344, 0.4852062873571179, 0.22095265658473165`], 
             UndirectedEdge[282, 301] -> 
             RGBColor[
              0.2824458229860667, 0.41361844480404447`, 0.9394174951734057], 
             UndirectedEdge[264, 328] -> 
             RGBColor[
              0.24566528906336602`, 0.3755401732575213, 0.9373016468317077], 
             UndirectedEdge[124, 156] -> 
             RGBColor[
              0.21424517968646528`, 0.3425156461524031, 0.9355123180845796], 
             UndirectedEdge[64, 120] -> 
             RGBColor[
              0.7025664799902631, 0.759149373979897, 0.6909182605401354], 
             UndirectedEdge[55, 236] -> 
             RGBColor[
              0.6566866391587384, 0.7296947127190476, 0.9678061194855357], 
             UndirectedEdge[11, 196] -> 
             RGBColor[
              0.8586587168624804, 0.8901351694289188, 0.9863808290196707], 
             UndirectedEdge[223, 319] -> 
             RGBColor[
              0.845830354553812, 0.35200168247303465`, 0.19147053713385456`], 
             UndirectedEdge[61, 70] -> 
             RGBColor[
              0.20711529305388426`, 0.33502168324063814`, 0.9351062815885762],
              UndirectedEdge[307, 343] -> 
             RGBColor[
              0.1898749181249935, 0.3169009560874688, 0.9341244677412249], 
             UndirectedEdge[13, 87] -> 
             RGBColor[
              0.2001057560025477, 0.3276542153693653, 0.9347070988231834], 
             UndirectedEdge[119, 128] -> 
             RGBColor[
              0.2718458799395796, 0.4030576342137573, 0.9387925927513947], 
             UndirectedEdge[92, 130] -> 
             RGBColor[
              0.2100169217474722, 0.33807147897148404`, 0.935271525050101], 
             UndirectedEdge[263, 359] -> 
             RGBColor[
              0.31376085658735253`, 0.4455463754257799, 0.941236947982536], 
             UndirectedEdge[22, 304] -> 
             RGBColor[
              0.2621517349847551, 0.3928684732219464, 0.9382405255374198], 
             UndirectedEdge[139, 306] -> 
             RGBColor[
              0.2646217542710957, 0.39546462010015837`, 0.9383811894817108], 
             UndirectedEdge[1, 73] -> 
             RGBColor[
              0.19016251964762415`, 0.3172032435227433, 0.9341408462224705], 
             UndirectedEdge[7, 13] -> 
             RGBColor[
              0.23415570368153021`, 0.3634428692713504, 0.9366461929711178], 
             UndirectedEdge[170, 335] -> 
             RGBColor[
              0.21688414248716403`, 0.34528936337584293`, 0.9356626031120838],
              UndirectedEdge[276, 361] -> 
             RGBColor[
              0.3943096577609078, 0.5159529397980152, 0.9463460406115533], 
             UndirectedEdge[46, 345] -> 
             RGBColor[
              0.8168101022247779, 0.8568829940339906, 0.982358282576511], 
             UndirectedEdge[36, 301] -> 
             RGBColor[
              0.2477609938146631, 0.37774289182649035`, 0.9374209941169768], 
             UndirectedEdge[50, 328] -> 
             RGBColor[
              0.23123968531368772`, 0.36037794908050486`, 0.9364801300389318],
              UndirectedEdge[55, 83] -> 
             RGBColor[
              0.8773611303882973, 0.9047851000408222, 0.9744632955960668], 
             UndirectedEdge[143, 306] -> 
             RGBColor[
              0.21060170684620283`, 0.33868612518776664`, 0.9353048276963617],
              UndirectedEdge[32, 400] -> 
             RGBColor[
              0.8218170423470171, 0.16870092453389818`, 0.1685253304313158], 
             UndirectedEdge[20, 195] -> 
             RGBColor[
              0.40462199010322386`, 0.5248849637600351, 0.9470031333095683], 
             UndirectedEdge[203, 266] -> 
             RGBColor[
              0.4841156347335931, 0.5879317505125805, 0.9537717798510146], 
             UndirectedEdge[255, 359] -> 
             RGBColor[
              0.3499392226187198, 0.4775214990007658, 0.9435187957195283], 
             UndirectedEdge[128, 215] -> 
             RGBColor[
              0.5049864538136, 0.6035289290681363, 0.9559781758101122], 
             UndirectedEdge[230, 328] -> 
             RGBColor[
              0.2262385122205931, 0.35512139906697393`, 0.9361953206298528], 
             UndirectedEdge[44, 146] -> 
             RGBColor[
              0.21372136571514777`, 0.3419650844568244, 0.9354824876538264], 
             UndirectedEdge[56, 206] -> 
             RGBColor[
              0.4736432444349138, 0.5829006282242136, 0.9518893552229266], 
             UndirectedEdge[55, 196] -> 
             RGBColor[
              0.8239309669516679, 0.8625755200904117, 0.9830336180607375], 
             UndirectedEdge[93, 188] -> 
             RGBColor[
              0.3091689920495968, 0.43916314420292457`, 0.9410324534762535], 
             UndirectedEdge[52, 271] -> 
             RGBColor[
              0.9044987065001195, 0.5722362617047718, 0.4994192280879955], 
             UndirectedEdge[193, 253] -> 
             RGBColor[
              0.8315602657829888, 0.5341252723143658, 0.5780805506738103], 
             UndirectedEdge[120, 193] -> 
             RGBColor[
              0.6252379224927019, 0.7026774950776031, 0.9659558403883122], 
             UndirectedEdge[28, 217] -> 
             RGBColor[
              0.19992147826691017`, 0.32746052778532697`, 0.9346966044787532],
              UndirectedEdge[124, 245] -> 
             RGBColor[
              0.21075638483913717`, 0.33884870156549185`, 0.9353136363792337],
              UndirectedEdge[36, 282] -> 
             RGBColor[
              0.28033871258182136`, 0.4114037381706667, 0.9392974983530744], 
             UndirectedEdge[276, 339] -> 
             RGBColor[
              0.38050139833268903`, 0.5039929195045905, 0.9454661905309516], 
             UndirectedEdge[377, 388] -> 
             RGBColor[
              0.26273780008050557`, 0.39348446479625343`, 0.9382739010776171],
              UndirectedEdge[129, 131] -> 
             RGBColor[
              0.8167235345760251, 0.5021703426652091, 0.5741281307411844], 
             UndirectedEdge[69, 142] -> 
             RGBColor[
              0.5234887787089056, 0.6240307993134462, 0.955630100743997], 
             UndirectedEdge[11, 118] -> 
             RGBColor[
              0.6153201099210919, 0.6928744863891039, 0.9658821576068201], 
             UndirectedEdge[53, 293] -> 
             RGBColor[
              0.35836727987096656`, 0.4848214585861875, 0.944055824075003], 
             UndirectedEdge[2, 137] -> 
             RGBColor[
              0.24723503321608348`, 0.3771900738895551, 0.9373910414389766], 
             UndirectedEdge[102, 213] -> 
             RGBColor[
              0.33722405994131943`, 0.4665082641722599, 0.9427085967973012], 
             UndirectedEdge[269, 362] -> 
             RGBColor[
              0.5723371220999356, 0.658694027276514, 0.9617848366135348], 
             UndirectedEdge[147, 242] -> 
             RGBColor[
              0.29380682218946674`, 0.42321348171513995`, 0.9401503892495575],
              UndirectedEdge[58, 220] -> 
             RGBColor[
              0.186453938859043, 0.31330528997634166`, 0.9339296480329143], 
             UndirectedEdge[177, 285] -> 
             RGBColor[
              0.18283630546897034`, 0.3095029279121705, 0.9337236291631588], 
             UndirectedEdge[213, 215] -> 
             RGBColor[
              0.5157421665105038, 0.6132928535993672, 0.9566471217151071], 
             UndirectedEdge[61, 382] -> 
             RGBColor[
              0.2696810924925139, 0.39954800963710424`, 0.9387145049212492], 
             UndirectedEdge[83, 123] -> 
             RGBColor[
              0.8970713714097568, 0.6478503290469954, 0.5784075917525047], 
             UndirectedEdge[207, 368] -> 
             RGBColor[
              0.18767517326657374`, 0.3145888847693901, 0.9339991955257688], 
             UndirectedEdge[117, 377] -> 
             RGBColor[
              0.40661285819624315`, 0.5187550912923315, 0.9481023126401036], 
             UndirectedEdge[207, 392] -> 
             RGBColor[
              0.1972896880999786, 0.3246943494547476, 0.9345467279221311], 
             UndirectedEdge[43, 325] -> 
             RGBColor[
              0.21648460691960775`, 0.3448694261623232, 0.9356398501525713], 
             UndirectedEdge[83, 196] -> 
             RGBColor[
              0.8975547667711833, 0.9207556417701627, 0.9764242298319501], 
             UndirectedEdge[81, 130] -> 
             RGBColor[
              0.2224096961469096, 0.35109707061257234`, 0.9359772752186821], 
             UndirectedEdge[204, 229] -> 
             RGBColor[
              0.18893129430891603`, 0.3159091476275659, 0.9340707297608657], 
             UndirectedEdge[44, 267] -> 
             RGBColor[
              0.21293872940986303`, 0.3411424840779623, 0.935437917674047], 
             UndirectedEdge[38, 130] -> 
             RGBColor[
              0.23719458554175432`, 0.36663692678268434`, 0.9368192527974348],
              UndirectedEdge[226, 318] -> 
             RGBColor[
              0.20268055409019498`, 0.33036049141111024`, 0.9348537297652024],
              UndirectedEdge[202, 362] -> 
             RGBColor[
              0.5594312028417849, 0.6475155686854668, 0.9609624828506617], 
             UndirectedEdge[59, 230] -> 
             RGBColor[
              0.21869887314196257`, 0.34719676035460534`, 0.9357659493382211],
              UndirectedEdge[131, 394] -> 
             RGBColor[
              0.585868010689025, 0.6694437636125451, 0.9630575794667262], 
             UndirectedEdge[93, 142] -> 
             RGBColor[
              0.4083441914838143, 0.5275430486662767, 0.9473966682274677], 
             UndirectedEdge[301, 340] -> 
             RGBColor[
              0.26063005246171667`, 0.3912690884099886, 0.9381538679688604], 
             UndirectedEdge[16, 76] -> 
             RGBColor[
              0.2559443426940643, 0.3863441103530275, 0.937887023729479], 
             UndirectedEdge[25, 239] -> 
             RGBColor[
              0.43554957397249955`, 0.5502115619480115, 0.9493775788120367], 
             UndirectedEdge[46, 60] -> 
             RGBColor[
              0.7562801355297237, 0.809531056908518, 0.9763425941360632], 
             UndirectedEdge[57, 297] -> 
             RGBColor[
              0.3224295006293375, 0.45256728530617585`, 0.9418071536579791], 
             UndirectedEdge[221, 351] -> 
             RGBColor[
              0.33973329445254913`, 0.4686816369880935, 0.9428684830015278], 
             UndirectedEdge[365, 377] -> 
             RGBColor[
              0.2803555468892034, 0.41200183372185906`, 0.9392772056952516], 
             UndirectedEdge[334, 366] -> 
             RGBColor[
              0.9767558229939741, 0.9327621554008622, 0.40603042724612426`], 
             UndirectedEdge[209, 290] -> 
             RGBColor[
              0.2612876379800373, 0.3919602524830736, 0.938191316491318], 
             UndirectedEdge[174, 313] -> 
             RGBColor[
              0.35122662219084355`, 0.47640574207717373`, 0.9436825095790529],
              UndirectedEdge[56, 358] -> 
             RGBColor[
              0.3979975915234898, 0.5145002367878451, 0.9471747294166126], 
             UndirectedEdge[304, 338] -> 
             RGBColor[
              0.24620331291395298`, 0.37610567043717064`, 0.9373322864940637],
              UndirectedEdge[130, 306] -> 
             RGBColor[
              0.21898168415614172`, 0.3474940126617616, 0.9357820550070972], 
             UndirectedEdge[11, 206] -> 
             RGBColor[
              0.6510406164097462, 0.7238137937447175, 0.9681582366938735], 
             UndirectedEdge[120, 140] -> 
             RGBColor[
              0.409447183861318, 0.5290643040720063, 0.9473105903890827], 
             UndirectedEdge[193, 356] -> 
             RGBColor[
              0.8916558476180196, 0.9161964476590825, 0.9808695463369558], 
             UndirectedEdge[166, 246] -> 
             RGBColor[
              0.23093801406837325`, 0.3600608734746177, 0.9364629503077938], 
             UndirectedEdge[76, 182] -> 
             RGBColor[
              0.2623813144884871, 0.39310977583655005`, 0.9382535997505249], 
             UndirectedEdge[6, 364] -> 
             RGBColor[
              0.9237508221541206, 0.8349006337052781, 0.6241923325830713], 
             UndirectedEdge[288, 318] -> 
             RGBColor[
              0.21359522081764215`, 0.3418324981714975, 0.9354753038885282], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.285788273116509, 0.4171315718147177, 0.9396078427636225], 
             UndirectedEdge[128, 151] -> 
             RGBColor[
              0.2557571228947407, 0.38614733047351757`, 0.9378763618388744], 
             UndirectedEdge[30, 379] -> 
             RGBColor[
              0.19158357625518677`, 0.31869686411748455`, 0.9342217732940062],
              UndirectedEdge[70, 90] -> 
             RGBColor[
              0.2062666965089075, 0.33412975446773896`, 0.9350579552707259], 
             UndirectedEdge[137, 394] -> 
             RGBColor[
              0.32513488620910913`, 0.45454855045423936`, 0.9419927931696428],
              UndirectedEdge[25, 269] -> 
             RGBColor[
              0.35868258725721747`, 0.48509456199634804`, 0.9440759151828396],
              UndirectedEdge[38, 227] -> 
             RGBColor[
              0.2663587998591236, 0.39729036514822713`, 0.9384801116582203], 
             UndirectedEdge[128, 135] -> 
             RGBColor[
              0.31962859399375376`, 0.45082008915129973`, 0.9416038278633306],
              UndirectedEdge[129, 303] -> 
             RGBColor[
              0.8566331099862248, 0.3804373908932912, 0.19967730788162147`], 
             UndirectedEdge[132, 299] -> 
             RGBColor[
              0.19063186344337624`, 0.3176965536101942, 0.9341675746573066], 
             UndirectedEdge[352, 396] -> 
             RGBColor[
              0.18539177638104404`, 0.312188889866974, 0.9338691594511209], 
             UndirectedEdge[155, 268] -> 
             RGBColor[
              0.18677990471826675`, 0.31364790076181503`, 0.9339482113063738],
              UndirectedEdge[8, 16] -> 
             RGBColor[
              0.24227617377409713`, 0.3719779982061794, 0.9371086417297306], 
             UndirectedEdge[213, 378] -> 
             RGBColor[
              0.2828251978811075, 0.4130565820344796, 0.9394742726442766], 
             UndirectedEdge[164, 230] -> 
             RGBColor[
              0.21805906979477002`, 0.3465242864708308, 0.9357295134841028], 
             UndirectedEdge[218, 339] -> 
             RGBColor[
              0.47111694262023773`, 0.5795753796238241, 0.9520425636736524], 
             UndirectedEdge[101, 366] -> 
             RGBColor[
              0.9236369022984421, 0.7019746342428002, 0.3557247602566589], 
             UndirectedEdge[169, 361] -> 
             RGBColor[
              0.4334163894448813, 0.5497182254001022, 0.948867451343103], 
             UndirectedEdge[65, 341] -> 
             RGBColor[
              0.31291881126268356`, 0.4399641129231123, 0.9413609829619669], 
             UndirectedEdge[46, 353] -> 
             RGBColor[
              0.8993981375114619, 0.9180011012561393, 0.7445005138120175], 
             UndirectedEdge[279, 300] -> 
             RGBColor[
              0.1975989582339537, 0.32501941197441453`, 0.9345643403987369], 
             UndirectedEdge[203, 358] -> 
             RGBColor[
              0.29380332632948314`, 0.42601947816165614`, 0.9400473143533797],
              UndirectedEdge[81, 243] -> 
             RGBColor[
              0.2302749655066254, 0.3593639673965138, 0.9364251906730947], 
             UndirectedEdge[176, 320] -> 
             RGBColor[
              0.18495626411433608`, 0.3117311388615913, 0.9338443576718145], 
             UndirectedEdge[112, 248] -> 
             RGBColor[
              0.18167669359362687`, 0.3082841023075451, 0.9336575909823499], 
             UndirectedEdge[58, 179] -> 
             RGBColor[
              0.21000836012355356`, 0.3380624801619072, 0.9352710374782847], 
             UndirectedEdge[23, 213] -> 
             RGBColor[
              0.2686665233533321, 0.39817491739397315`, 0.9386679570758016], 
             UndirectedEdge[243, 326] -> 
             RGBColor[
              0.23648276332684243`, 0.36588875650267677`, 0.9367787155753422],
              UndirectedEdge[269, 377] -> 
             RGBColor[
              0.30404872534557215`, 0.4327759904647185, 0.9407776755353809], 
             UndirectedEdge[222, 363] -> 
             RGBColor[
              0.6628066494410058, 0.7309294373629389, 0.9563828644799877], 
             UndirectedEdge[30, 341] -> 
             RGBColor[
              0.22502124710185, 0.35384197624810876`, 0.9361259991821227], 
             UndirectedEdge[23, 348] -> 
             RGBColor[
              0.20651189165865158`, 0.3343874701163905, 0.93507191877177], 
             UndirectedEdge[16, 25] -> 
             RGBColor[
              0.2964577597678131, 0.4238211990721158, 0.9403811249327455], 
             UndirectedEdge[25, 62] -> 
             RGBColor[
              0.6778828449272916, 0.740272939600058, 0.8649535953688089], 
             UndirectedEdge[16, 388] -> 
             RGBColor[
              0.24986758553696356`, 0.3799570532922577, 0.9375409613991386], 
             UndirectedEdge[207, 372] -> 
             RGBColor[
              0.18573202091371066`, 0.31254650844355597`, 0.9338885358739095],
              UndirectedEdge[249, 279] -> 
             RGBColor[
              0.19132944320701362`, 0.3184297541708887, 0.934207300792869], 
             UndirectedEdge[151, 267] -> 
             RGBColor[
              0.20258817055551906`, 0.33026339045871145`, 0.9348484686595718],
              UndirectedEdge[185, 252] -> 
             RGBColor[
              0.1992454681560438, 0.3267499982972898, 0.9346581067030068], 
             UndirectedEdge[218, 382] -> 
             RGBColor[
              0.44118615700326724`, 0.5536508374874307, 0.9501354004808935], 
             UndirectedEdge[284, 334] -> 
             RGBColor[
              0.8500382234662116, 0.8370769008965131, 0.6373182165494112], 
             UndirectedEdge[145, 235] -> 
             RGBColor[
              0.22156110310920424`, 0.35020514552603776`, 0.9359289491005658],
              UndirectedEdge[78, 302] -> 
             RGBColor[
              0.2075835767828424, 0.33551387913067643`, 0.9351329496541767], 
             UndirectedEdge[235, 335] -> 
             RGBColor[
              0.19575670920923333`, 0.32308309144409886`, 0.9344594270421422],
              UndirectedEdge[21, 109] -> 
             RGBColor[
              0.1897091064701492, 0.31672667752516137`, 0.9341150250127779], 
             UndirectedEdge[283, 389] -> 
             RGBColor[
              0.9625229099161214, 0.8777511540326326, 0.378485405341739], 
             UndirectedEdge[91, 395] -> 
             RGBColor[
              0.5156283955691132, 0.6172519539462964, 0.9551211142984581], 
             UndirectedEdge[240, 374] -> 
             RGBColor[
              0.18148468566837106`, 0.3080822898040957, 0.933646656415057], 
             UndirectedEdge[301, 339] -> 
             RGBColor[
              0.3159128215006708, 0.4426058768171399, 0.9415499827250514], 
             UndirectedEdge[303, 353] -> 
             RGBColor[
              0.9435949291122223, 0.7996173553563373, 0.3704770005960165], 
             UndirectedEdge[92, 143] -> 
             RGBColor[
              0.20163694443753327`, 0.3292635914974891, 0.9347942977393655], 
             UndirectedEdge[53, 394] -> 
             RGBColor[
              0.38011496144870427`, 0.5036582072985654, 0.9454415671144167], 
             UndirectedEdge[139, 345] -> 
             RGBColor[
              0.5675136417908162, 0.652851509744995, 0.962127956401694], 
             UndirectedEdge[224, 393] -> 
             RGBColor[
              0.6098596540697332, 0.6929310009621534, 0.9632633563282622], 
             UndirectedEdge[175, 204] -> 
             RGBColor[
              0.1850387535749342, 0.31181784051481387`, 0.9338490553245634], 
             UndirectedEdge[131, 293] -> 
             RGBColor[
              0.5641203291112874, 0.6506070149001673, 0.9616718364273125], 
             UndirectedEdge[166, 383] -> 
             RGBColor[
              0.3017459947622442, 0.42990132159861427`, 0.9406631745250644], 
             UndirectedEdge[92, 348] -> 
             RGBColor[
              0.2027372639690243, 0.3304200970893739, 0.9348569593089071], 
             UndirectedEdge[212, 289] -> 
             RGBColor[
              0.5259969557430033, 0.6260670504218144, 0.9558275536278764], 
             UndirectedEdge[161, 214] -> 
             RGBColor[
              0.8792338615689066, 0.5445109956801907, 0.22094211265521246`], 
             UndirectedEdge[124, 386] -> 
             RGBColor[
              0.28427277786616933`, 0.41305129154365816`, 0.9396126134014054],
              UndirectedEdge[227, 350] -> 
             RGBColor[
              0.3112685553301875, 0.44081365131394507`, 0.9411723881594869], 
             UndirectedEdge[258, 279] -> 
             RGBColor[
              0.2183447678357952, 0.34682457322625027`, 0.9357457835648868], 
             UndirectedEdge[63, 103] -> 
             RGBColor[
              0.19205709543901506`, 0.31919456280253833`, 0.9342487395110164],
              UndirectedEdge[291, 336] -> 
             RGBColor[
              0.21513079622652476`, 0.34344648528733734`, 0.9355627526363838],
              UndirectedEdge[292, 400] -> 
             RGBColor[
              0.8208035514548493, 0.16091078942215484`, 0.1675548104084016], 
             UndirectedEdge[149, 300] -> 
             RGBColor[
              0.20324360298345337`, 0.33095229149728655`, 0.9348857945667173],
              UndirectedEdge[356, 364] -> 
             RGBColor[
              0.9333609520587287, 0.8423137522801358, 0.6164503768813724], 
             UndirectedEdge[100, 167] -> 
             RGBColor[
              0.3117593370391954, 0.4377082442608893, 0.941332929144121], 
             UndirectedEdge[334, 391] -> 
             RGBColor[
              0.890222900366215, 0.5169905447403047, 0.23346978586604977`], 
             UndirectedEdge[309, 323] -> 
             RGBColor[
              0.5589942800594222, 0.6511253403818711, 0.9592466420721857], 
             UndirectedEdge[8, 202] -> 
             RGBColor[
              0.2915950820053508, 0.42207290253936436`, 0.9399810782169516], 
             UndirectedEdge[127, 380] -> 
             RGBColor[
              0.529875465248763, 0.6249265943110206, 0.9578049379836415], 
             UndirectedEdge[130, 151] -> 
             RGBColor[
              0.211637861675412, 0.3397751896092761, 0.9353638351810314], 
             UndirectedEdge[335, 355] -> 
             RGBColor[
              0.20320238953001776`, 0.3309089735446419, 0.934883447521514], 
             UndirectedEdge[117, 395] -> 
             RGBColor[
              0.49860624010091514`, 0.6034326012978481, 0.9537810678657916], 
             UndirectedEdge[256, 310] -> 
             RGBColor[
              0.9094103197175858, 0.5979549815728277, 0.4751163468578484], 
             UndirectedEdge[362, 365] -> 
             RGBColor[
              0.5486439436435668, 0.6379198705336546, 0.9602843667734056], 
             UndirectedEdge[163, 342] -> 
             RGBColor[
              0.18272416673891645`, 0.30938506299687774`, 0.9337172430283764],
              UndirectedEdge[125, 288] -> 
             RGBColor[
              0.2031660717843796, 0.3308708012912981, 0.9348813792796271], 
             UndirectedEdge[161, 253] -> 
             RGBColor[
              0.8523693689594214, 0.3702876353014115, 0.19648021346556857`], 
             UndirectedEdge[12, 211] -> 
             RGBColor[
              0.23763726784270695`, 0.3671022139486645, 0.9368444628995842], 
             UndirectedEdge[107, 152] -> 
             RGBColor[
              0.2119625047523057, 0.3401164100666513, 0.9353823231239942], 
             UndirectedEdge[183, 291] -> 
             RGBColor[
              0.1920722404266596, 0.31921048114480044`, 0.9342496019956579], 
             UndirectedEdge[149, 299] -> 
             RGBColor[
              0.19935795159879743`, 0.32686822552748607`, 0.9346645124686672],
              UndirectedEdge[57, 284] -> 
             RGBColor[
              0.544081909913294, 0.6364040523835073, 0.9590603762420349], 
             UndirectedEdge[230, 279] -> 
             RGBColor[
              0.2100811442778375, 0.33813898092284156`, 0.9352751824281966], 
             UndirectedEdge[186, 374] -> 
             RGBColor[
              0.19510883243877694`, 0.3224021318805894, 0.9344225314185126], 
             UndirectedEdge[30, 175] -> 
             RGBColor[
              0.19541782934736363`, 0.32272690722304953`, 0.9344401283353366],
              UndirectedEdge[261, 327] -> 
             RGBColor[
              0.1874834373807122, 0.31438735819659225`, 0.9339882764507168], 
             UndirectedEdge[271, 333] -> 
             RGBColor[
              0.8868896427416582, 0.5599013471362418, 0.5649582086174862], 
             UndirectedEdge[199, 247] -> 
             RGBColor[
              0.9030372486329088, 0.5619443631205439, 0.500289085988991], 
             UndirectedEdge[99, 223] -> 
             RGBColor[
              0.8806912086429535, 0.689221405037725, 0.5973847957056915], 
             UndirectedEdge[200, 367] -> 
             RGBColor[
              0.19007010120853718`, 0.31710610588359545`, 0.9341355831290852],
              UndirectedEdge[111, 400] -> 
             RGBColor[
              0.8243636514645629, 0.1882752781425862, 0.17096396619826132`], 
             UndirectedEdge[277, 390] -> 
             RGBColor[
              0.19904871949657826`, 0.326543202981606, 0.9346469021579138], 
             UndirectedEdge[79, 298] -> 
             RGBColor[
              0.20225845525357178`, 0.3299168387712073, 0.934829691860896], 
             UndirectedEdge[96, 388] -> 
             RGBColor[
              0.24120538255957147`, 0.37085252874762864`, 0.937047661754157], 
             UndirectedEdge[153, 175] -> 
             RGBColor[
              0.19789401206423968`, 0.32532953225753836`, 0.9345811432778787],
              UndirectedEdge[127, 331] -> 
             RGBColor[
              0.29016880316487315`, 0.419484905671203, 0.9399397232478413], 
             UndirectedEdge[6, 93] -> 
             RGBColor[
              0.6343460318717724, 0.7075322117954237, 0.9679330421391619], 
             UndirectedEdge[76, 239] -> 
             RGBColor[
              0.3950361568987507, 0.5127344732289232, 0.94688347760877], 
             UndirectedEdge[333, 337] -> 
             RGBColor[
              0.9553778772118539, 0.9662414744033965, 0.9604177939535141], 
             UndirectedEdge[253, 332] -> 
             RGBColor[
              0.8214986576269006, 0.1662536800580077, 0.16822044486376803`], 
             UndirectedEdge[31, 400] -> 
             RGBColor[
              0.9031868035222537, 0.5793756445438494, 0.5396768154569369], 
             UndirectedEdge[39, 149] -> 
             RGBColor[
              0.2042501787734501, 0.33201026647316434`, 0.9349431175688622], 
             UndirectedEdge[49, 335] -> 
             RGBColor[
              0.1909811618412971, 0.3180636883732066, 0.9341874666843275], 
             UndirectedEdge[57, 236] -> 
             RGBColor[
              0.4289674540866987, 0.5444426167036535, 0.9489769174045849], 
             UndirectedEdge[76, 323] -> 
             RGBColor[
              0.3517784337991403, 0.4767281281704481, 0.9437233665376588], 
             UndirectedEdge[2, 210] -> 
             RGBColor[
              0.223753059772891, 0.352509030957652, 0.9360537777898534], 
             UndirectedEdge[25, 395] -> 
             RGBColor[
              0.4013213562160271, 0.522026120581628, 0.946792819836912], 
             UndirectedEdge[62, 91] -> 
             RGBColor[
              0.7921898842803778, 0.8354987729647263, 0.873281889830355], 
             UndirectedEdge[148, 313] -> 
             RGBColor[
              0.27058528986872044`, 0.4017326741232574, 0.9387208040117352], 
             UndirectedEdge[98, 163] -> 
             RGBColor[
              0.18615149755953203`, 0.3129874049946697, 0.933912424448329], 
             UndirectedEdge[271, 292] -> 
             RGBColor[
              0.8197473186965691, 0.15279212159786854`, 0.16654336072622833`],
              UndirectedEdge[148, 228] -> 
             RGBColor[
              0.2402804897849437, 0.36988040779990605`, 0.9369949904788982], 
             UndirectedEdge[105, 333] -> 
             RGBColor[
              0.969539411680839, 0.9766186640035739, 0.9281855313871071], 
             UndirectedEdge[9, 65] -> 
             RGBColor[
              0.531426491162083, 0.6277150215031269, 0.9572921727453987], 
             UndirectedEdge[129, 337] -> 
             RGBColor[
              0.8881576917970897, 0.5585337722586294, 0.5619283859267235], 
             UndirectedEdge[62, 323] -> 
             RGBColor[
              0.7062128595771804, 0.7648109743818534, 0.8667587588510515], 
             UndirectedEdge[286, 290] -> 
             RGBColor[
              0.28938656912218486`, 0.4203385400712017, 0.9398338164907357], 
             UndirectedEdge[96, 261] -> 
             RGBColor[
              0.20041641876701294`, 0.3279807416319751, 0.9347247906080353], 
             UndirectedEdge[48, 86] -> 
             RGBColor[
              0.23801910122574216`, 0.3675035450438693, 0.9368662077458763], 
             UndirectedEdge[137, 328] -> 
             RGBColor[
              0.2619981545019592, 0.39270705039696285`, 0.9382317793561266], 
             UndirectedEdge[110, 212] -> 
             RGBColor[
              0.715371093239261, 0.7768498811487758, 0.9728708007300837], 
             UndirectedEdge[163, 272] -> 
             RGBColor[
              0.18785278804211375`, 0.3147755691599099, 0.9340093104244782], 
             UndirectedEdge[245, 396] -> 
             RGBColor[
              0.1896460602736138, 0.31666041197524286`, 0.9341114346251538], 
             UndirectedEdge[25, 37] -> 
             RGBColor[
              0.3241466699483991, 0.4529239992502145, 0.9419579674054581], 
             UndirectedEdge[79, 373] -> 
             RGBColor[
              0.19851817498261992`, 0.32598556705897075`, 0.9346166884327141],
              UndirectedEdge[34, 43] -> 
             RGBColor[
              0.18881744465394812`, 0.3157894844217095, 0.9340642461914408], 
             UndirectedEdge[100, 358] -> 
             RGBColor[
              0.33265464447686266`, 0.4596705372168882, 0.942522885990859], 
             UndirectedEdge[273, 394] -> 
             RGBColor[
              0.4408354922328445, 0.55433085165707, 0.9498412454842259], 
             UndirectedEdge[89, 189] -> 
             RGBColor[
              0.23269978806740765`, 0.361912609650526, 0.9365632807307278], 
             UndirectedEdge[268, 299] -> 
             RGBColor[
              0.18802492021905656`, 0.3149564909916871, 0.9340191130973085], 
             UndirectedEdge[143, 272] -> 
             RGBColor[
              0.19777740595295248`, 0.3252069718413211, 0.9345745027323441], 
             UndirectedEdge[339, 382] -> 
             RGBColor[
              0.3520267531654626, 0.47932961303801835`, 0.943651811320036], 
             UndirectedEdge[111, 223] -> 
             RGBColor[
              0.8429142052274374, 0.3295868808857362, 0.18867802924559862`], 
             UndirectedEdge[71, 131] -> 
             RGBColor[
              0.8919073913712897, 0.9158173378862382, 0.9591371203789343], 
             UndirectedEdge[114, 370] -> 
             RGBColor[
              0.18611224246754757`, 0.3129461454040774, 0.9339101889289132], 
             UndirectedEdge[4, 125] -> 
             RGBColor[
              0.196721601742191, 0.3240972546739574, 0.9345143762444637], 
             UndirectedEdge[246, 251] -> 
             RGBColor[
              0.20081373075853814`, 0.3283983417261034, 0.9347474169381822], 
             UndirectedEdge[30, 229] -> 
             RGBColor[
              0.19931037008134544`, 0.32681821433580155`, 0.9346618027716389],
              UndirectedEdge[115, 366] -> 
             RGBColor[
              0.9742039651565302, 0.9239012646538212, 0.3974339190185809], 
             UndirectedEdge[89, 270] -> 
             RGBColor[
              0.22008543635339983`, 0.34865412620301106`, 0.935844912061876], 
             UndirectedEdge[197, 369] -> 
             RGBColor[
              0.18585850163943218`, 0.31267944770563044`, 0.933895738764128], 
             UndirectedEdge[276, 301] -> 
             RGBColor[
              0.3144566810509267, 0.44134464114731864`, 0.9414571987432081], 
             UndirectedEdge[69, 188] -> 
             RGBColor[
              0.42431357927468827`, 0.535650894850094, 0.9492658859927827], 
             UndirectedEdge[191, 225] -> 
             RGBColor[
              0.19624559498378968`, 0.32359694139030604`, 0.9344872683637615],
              UndirectedEdge[223, 247] -> 
             RGBColor[
              0.8382775353615486, 0.29394740449482404`, 0.18423794894565387`],
              UndirectedEdge[72, 86] -> 
             RGBColor[
              0.3668179912534385, 0.4880512045533021, 0.9448235654131886], 
             UndirectedEdge[19, 85] -> 
             RGBColor[
              0.19070082938217475`, 0.3177690411845645, 0.9341715021654952], 
             UndirectedEdge[320, 398] -> 
             RGBColor[
              0.182257588923795, 0.30889466013044303`, 0.9336906721120455], 
             UndirectedEdge[249, 300] -> 
             RGBColor[
              0.18989148665345995`, 0.3169183706613924, 0.9341254112944102], 
             UndirectedEdge[18, 319] -> 
             RGBColor[
              0.9124901172546147, 0.6184152946465793, 0.3038268692248966], 
             UndirectedEdge[6, 273] -> 
             RGBColor[
              0.7251045855702409, 0.7842222818473898, 0.9742467167674911], 
             UndirectedEdge[158, 348] -> 
             RGBColor[
              0.1961222229924388, 0.3234672696051602, 0.9344802425113666], 
             UndirectedEdge[61, 228] -> 
             RGBColor[
              0.220637096263315, 0.34923395574559046`, 0.935876328277638], 
             UndirectedEdge[70, 260] -> 
             RGBColor[
              0.19294770058427305`, 0.3201306452778321, 0.9342994581565066], 
             UndirectedEdge[144, 305] -> 
             RGBColor[
              0.4396583364184836, 0.550769790541102, 0.9502316306235659], 
             UndirectedEdge[165, 351] -> 
             RGBColor[
              0.26754769340127105`, 0.39846518644420825`, 0.9385505554925828],
              UndirectedEdge[132, 370] -> 
             RGBColor[
              0.189210358194615, 0.3162024614651078, 0.9340866220363182], 
             UndirectedEdge[104, 145] -> 
             RGBColor[
              0.2369611402467977, 0.36639156097639836`, 0.9368059584332384], 
             UndirectedEdge[207, 231] -> 
             RGBColor[
              0.1913619669815575, 0.3184639387200607, 0.9342091529737147], 
             UndirectedEdge[21, 249] -> 
             RGBColor[
              0.19014493822452405`, 0.31718476433233855`, 0.9341398449864342],
              UndirectedEdge[7, 93] -> 
             RGBColor[
              0.29873862778538124`, 0.4282001700379434, 0.9404384596617476], 
             UndirectedEdge[140, 255] -> 
             RGBColor[
              0.390267723092427, 0.5124520191417203, 0.9460884921086202], 
             UndirectedEdge[100, 157] -> 
             RGBColor[
              0.31728677632069113`, 0.4435179334056334, 0.9416477086340886], 
             UndirectedEdge[42, 178] -> 
             RGBColor[
              0.18344665505298052`, 0.31014444402336394`, 0.9337583876690367],
              UndirectedEdge[115, 195] -> 
             RGBColor[
              0.6898630728334411, 0.7009647207638414, 0.6155071113240207], 
             UndirectedEdge[281, 394] -> 
             RGBColor[
              0.3781881603711747, 0.5019893090490473, 0.9453187930535599], 
             UndirectedEdge[215, 224] -> 
             RGBColor[
              0.6019092601655756, 0.6867200928189938, 0.9624709353645509], 
             UndirectedEdge[99, 222] -> 
             RGBColor[
              0.9266267914902193, 0.9439342403679507, 0.9791054495248444], 
             UndirectedEdge[55, 284] -> 
             RGBColor[
              0.7718010949853338, 0.8216561483989014, 0.9778895783229857], 
             UndirectedEdge[32, 337] -> 
             RGBColor[
              0.8892490440589328, 0.5669223839767665, 0.5629734660851704], 
             UndirectedEdge[172, 399] -> 
             RGBColor[
              0.369499573099037, 0.49446369145501556`, 0.9447651639555954], 
             UndirectedEdge[267, 346] -> 
             RGBColor[
              0.20049511025135958`, 0.32806345137135173`, 0.9347292719716551],
              UndirectedEdge[222, 393] -> 
             RGBColor[
              0.8365296253571944, 0.8728854021704904, 0.9703016768071477], 
             UndirectedEdge[116, 179] -> 
             RGBColor[
              0.23341719737643146`, 0.3626666523206874, 0.9366041361295647], 
             UndirectedEdge[120, 360] -> 
             RGBColor[
              0.5376516098803733, 0.6341093662239545, 0.9572645433190765], 
             UndirectedEdge[144, 222] -> 
             RGBColor[
              0.7661723613566251, 0.8169857716290115, 0.9639290713689532], 
             UndirectedEdge[237, 307] -> 
             RGBColor[
              0.1806275543927051, 0.307181390488109, 0.9335978440569198], 
             UndirectedEdge[18, 144] -> 
             RGBColor[
              0.7868965412101618, 0.8286865484723305, 0.6945647496408425], 
             UndirectedEdge[309, 365] -> 
             RGBColor[
              0.5016918379873817, 0.6012405287458232, 0.9556046196739707], 
             UndirectedEdge[189, 241] -> 
             RGBColor[
              0.2570425573000169, 0.3874984035347115, 0.937949565426625], 
             UndirectedEdge[268, 370] -> 
             RGBColor[
              0.18660341497029534`, 0.3134623988466007, 0.9339381604763201], 
             UndirectedEdge[336, 359] -> 
             RGBColor[
              0.2802453493603669, 0.4103194523243253, 0.9393282894277089], 
             UndirectedEdge[115, 123] -> 
             RGBColor[
              0.8991328422336753, 0.5962300691178152, 0.23584910998017405`], 
             UndirectedEdge[6, 394] -> 
             RGBColor[
              0.6418942074247149, 0.7140700620770483, 0.9684140052108057], 
             UndirectedEdge[259, 353] -> 
             RGBColor[
              0.9443422105725244, 0.9537215111738743, 0.7488183078429457], 
             UndirectedEdge[98, 348] -> 
             RGBColor[
              0.19717643500186177`, 0.3245753132679656, 0.9345402783257364], 
             UndirectedEdge[145, 349] -> 
             RGBColor[
              0.2241439081408365, 0.35291983737358057`, 0.9360760360261996], 
             UndirectedEdge[287, 292] -> 
             RGBColor[
              0.8184054423003344, 0.14247787160242187`, 0.16525837837376128`],
              UndirectedEdge[53, 69] -> 
             RGBColor[
              0.4877113731208531, 0.5936081076641104, 0.9531940365593021], 
             UndirectedEdge[236, 284] -> 
             RGBColor[
              0.6247504035752902, 0.7047458827568778, 0.9646230139836673], 
             UndirectedEdge[119, 146] -> 
             RGBColor[
              0.2194595639056427, 0.3479962945778132, 0.9358092695518716], 
             UndirectedEdge[198, 310] -> 
             RGBColor[
              0.8276571285797327, 0.5355745817229594, 0.5782791813938954], 
             UndirectedEdge[198, 384] -> 
             RGBColor[
              0.8811911535814985, 0.820358675063078, 0.6244757857174054], 
             UndirectedEdge[111, 292] -> 
             RGBColor[
              0.8230519846103825, 0.1781932319252751, 0.16970791253738232`], 
             UndirectedEdge[40, 295] -> 
             RGBColor[
              0.1896748892459051, 0.31669071305298346`, 0.934113076392477], 
             UndirectedEdge[5, 270] -> 
             RGBColor[
              0.19738135324155764`, 0.32479069533045285`, 0.9345519481163376],
              UndirectedEdge[104, 355] -> 
             RGBColor[
              0.21609483282429037`, 0.34445974887503966`, 0.9356176530944622],
              UndirectedEdge[356, 360] -> 
             RGBColor[
              0.804069535005691, 0.8476283188054337, 0.97217824926772], 
             UndirectedEdge[42, 398] -> 
             RGBColor[
              0.18234639975021955`, 0.30898800593994685`, 0.9336957297572264],
              UndirectedEdge[153, 211] -> 
             RGBColor[
              0.21907020233692062`, 0.34758705088213704`, 0.9357870959865418],
              UndirectedEdge[223, 385] -> 
             RGBColor[
              0.9268169546976089, 0.7220420708837272, 0.4190027976388401], 
             UndirectedEdge[144, 361] -> 
             RGBColor[
              0.4954156444114053, 0.6000520136165334, 0.9537482598048219], 
             UndirectedEdge[216, 229] -> 
             RGBColor[
              0.2068690748506942, 0.33476289229794964`, 0.9350922598261517], 
             UndirectedEdge[161, 389] -> 
             RGBColor[
              0.9363348090239618, 0.7668148008617284, 0.3570460900069422], 
             UndirectedEdge[313, 340] -> 
             RGBColor[
              0.2780047879810863, 0.40953103706270466`, 0.9391433334530706], 
             UndirectedEdge[241, 380] -> 
             RGBColor[
              0.5006467932710101, 0.5970366894503322, 0.9560367412293518], 
             UndirectedEdge[258, 281] -> 
             RGBColor[
              0.318201913769557, 0.44345916858997797`, 0.9417371947060786], 
             UndirectedEdge[344, 346] -> 
             RGBColor[
              0.19749434605120672`, 0.3249094579375519, 0.9345583828896893], 
             UndirectedEdge[79, 205] -> 
             RGBColor[
              0.19210249208707042`, 0.3192422775579583, 0.9342513247829649], 
             UndirectedEdge[227, 306] -> 
             RGBColor[
              0.248145898473511, 0.3781474510273044, 0.9374429138678827], 
             UndirectedEdge[43, 381] -> 
             RGBColor[
              0.19202300109929993`, 0.3191587274897918, 0.9342467978888077], 
             UndirectedEdge[98, 143] -> 
             RGBColor[
              0.19607611547037074`, 0.3234188076760809, 0.9344776167561948], 
             UndirectedEdge[243, 267] -> 
             RGBColor[
              0.2144789920516021, 0.342761397772722, 0.9355256333528797], 
             UndirectedEdge[58, 152] -> 
             RGBColor[
              0.19702370192683044`, 0.32441478112227146`, 0.9345315804030616],
              UndirectedEdge[376, 397] -> 
             RGBColor[
              0.32517928194563106`, 0.4539892085157613, 0.9420175102408045], 
             UndirectedEdge[114, 279] -> 
             RGBColor[
              0.19285735565451845`, 0.32003568702846064`, 0.9342943131464105],
              UndirectedEdge[148, 218] -> 
             RGBColor[
              0.40841467546891774`, 0.5204402282772255, 0.9482239194761258], 
             UndirectedEdge[55, 366] -> 
             RGBColor[
              0.8985186945130963, 0.9173414029032505, 0.7466017890196988], 
             UndirectedEdge[99, 361] -> 
             RGBColor[
              0.6558700745449995, 0.7270004823554725, 0.968924637960713], 
             UndirectedEdge[97, 169] -> 
             RGBColor[
              0.37794173807367953`, 0.5007330923555633, 0.945366919038301], 
             UndirectedEdge[43, 250] -> 
             RGBColor[
              0.19420867686654147`, 0.32145601130101026`, 0.9343712688903346],
              UndirectedEdge[112, 177] -> 
             RGBColor[
              0.18091855533538903`, 0.3074872509293952, 0.9336144161301083], 
             UndirectedEdge[255, 356] -> 
             RGBColor[
              0.6597861746771188, 0.7286564919053182, 0.9611997608615672], 
             UndirectedEdge[210, 328] -> 
             RGBColor[
              0.2385161810587667, 0.36802600746505976`, 0.9368945157070033], 
             UndirectedEdge[91, 221] -> 
             RGBColor[
              0.48124384050183955`, 0.5874697805650118, 0.9529301608546397], 
             UndirectedEdge[32, 345] -> 
             RGBColor[
              0.824801297962475, 0.5160822589510907, 0.5758521781137924], 
             UndirectedEdge[210, 258] -> 
             RGBColor[
              0.24166666616429894`, 0.371337367063267, 0.9370739311730383], 
             UndirectedEdge[189, 359] -> 
             RGBColor[
              0.2794316818374808, 0.4094642361682714, 0.9392819522659938], 
             UndirectedEdge[164, 258] -> 
             RGBColor[
              0.22632269335272776`, 0.3552098787742395, 0.936200114620793], 
             UndirectedEdge[354, 374] -> 
             RGBColor[
              0.18986888322413037`, 0.3168946130240269, 0.9341241240625486], 
             UndirectedEdge[235, 322] -> 
             RGBColor[
              0.1941801601361397, 0.32142603840929285`, 0.934369644904725], 
             UndirectedEdge[147, 392] -> 
             RGBColor[
              0.2251386082236323, 0.35396533022822685`, 0.9361326827243879], 
             UndirectedEdge[123, 283] -> 
             RGBColor[
              0.8875401777067986, 0.5502690172951994, 0.2265213799870392], 
             UndirectedEdge[202, 239] -> 
             RGBColor[
              0.4173644057485659, 0.5344604832455712, 0.9482188359733204], 
             UndirectedEdge[180, 249] -> 
             RGBColor[
              0.18602314959306215`, 0.3128525031441788, 0.9339051152215123], 
             UndirectedEdge[2, 197] -> 
             RGBColor[
              0.1965684920257088, 0.3239363266542179, 0.9345056568726156], 
             UndirectedEdge[174, 329] -> 
             RGBColor[
              0.34008730347088106`, 0.4646976118288939, 0.9430481418570962], 
             UndirectedEdge[193, 242] -> 
             RGBColor[
              0.5891633460741419, 0.6714315101447773, 0.963657200278417], 
             UndirectedEdge[58, 160] -> 
             RGBColor[
              0.1942495004305084, 0.32149891945510295`, 0.9343735937319094], 
             UndirectedEdge[50, 137] -> 
             RGBColor[
              0.2618861891426283, 0.3925893677052923, 0.9382254030945505], 
             UndirectedEdge[326, 383] -> 
             RGBColor[
              0.2999445651565369, 0.428007904865782, 0.9405605857739958], 
             UndirectedEdge[157, 238] -> 
             RGBColor[
              0.22387178003127423`, 0.3526338134765119, 0.9360605387329375], 
             UndirectedEdge[243, 346] -> 
             RGBColor[
              0.21741007073096835`, 0.3458421473058579, 0.9356925539475274], 
             UndirectedEdge[235, 355] -> 
             RGBColor[
              0.2006947956866969, 0.3282733334246791, 0.9347406437617896], 
             UndirectedEdge[44, 135] -> 
             RGBColor[
              0.2818343394924019, 0.41109593137624006`, 0.9394515009810677], 
             UndirectedEdge[33, 206] -> 
             RGBColor[
              0.33773890435239673`, 0.4612073947457289, 0.942951820792434], 
             UndirectedEdge[88, 263] -> 
             RGBColor[
              0.3661139704738488, 0.49089201133024934`, 0.9445728421053426], 
             UndirectedEdge[82, 399] -> 
             RGBColor[
              0.5595672102027384, 0.6489717323660277, 0.9604046913379707], 
             UndirectedEdge[271, 287] -> 
             RGBColor[
              0.8186608763962349, 0.14444124999544666`, 0.16550298235246705`],
              UndirectedEdge[31, 223] -> 
             RGBColor[
              0.9217373572851282, 0.7206872472869994, 0.5573908785042743], 
             UndirectedEdge[108, 376] -> 
             RGBColor[
              0.29627129186653856`, 0.4287302908095537, 0.9401835838264763], 
             UndirectedEdge[301, 361] -> 
             RGBColor[
              0.3297210809288895, 0.45456589711056455`, 0.9424298328056531], 
             UndirectedEdge[80, 388] -> 
             RGBColor[
              0.23694403524812552`, 0.36637358253827423`, 0.9368049843288686],
              UndirectedEdge[47, 136] -> 
             RGBColor[
              0.18182023692588944`, 0.308434975450926, 0.9336657655627689], 
             UndirectedEdge[39, 50] -> 
             RGBColor[
              0.21465093660737516`, 0.342942122402754, 0.9355354253409618], 
             UndirectedEdge[120, 389] -> 
             RGBColor[
              0.7028354936755193, 0.7597247670512044, 0.7201987400202577], 
             UndirectedEdge[28, 106] -> 
             RGBColor[
              0.18905752987434937`, 0.31604182921063345`, 0.9340779186895682],
              UndirectedEdge[97, 326] -> 
             RGBColor[
              0.27009816450947055`, 0.40122067448515425`, 0.9386930629431633],
              UndirectedEdge[195, 242] -> 
             RGBColor[
              0.3825084156474021, 0.5057312970269716, 0.9455940758995094], 
             UndirectedEdge[90, 260] -> 
             RGBColor[
              0.20225002842194761`, 0.32990798163687834`, 0.9348292119653014],
              UndirectedEdge[73, 368] -> 
             RGBColor[
              0.19117243294824504`, 0.31826472643389747`, 0.934198359290908], 
             UndirectedEdge[52, 287] -> 
             RGBColor[
              0.9031568301038848, 0.5619220117093251, 0.49813424573552845`], 
             UndirectedEdge[135, 243] -> 
             RGBColor[
              0.2833746021341409, 0.41271484507099976`, 0.9395392166599004], 
             UndirectedEdge[311, 317] -> 
             RGBColor[
              0.19555015626042008`, 0.32286599119868276`, 0.934447664157275], 
             UndirectedEdge[6, 10] -> 
             RGBColor[
              0.8845651997050992, 0.6376155087725291, 0.5907990623624317], 
             UndirectedEdge[363, 383] -> 
             RGBColor[
              0.36642168177165046`, 0.49179777668654956`, 0.9445690434418867],
              UndirectedEdge[227, 346] -> 
             RGBColor[
              0.23870901568862182`, 0.3682286888874592, 0.9369054973539003], 
             UndirectedEdge[157, 341] -> 
             RGBColor[
              0.24810243304135554`, 0.37810176610224144`, 0.9374404385758228],
              UndirectedEdge[18, 310] -> 
             RGBColor[
              0.9095262697789932, 0.5956338641827077, 0.30098868553505453`], 
             UndirectedEdge[37, 96] -> 
             RGBColor[
              0.24798039051581972`, 0.3779734916699602, 0.9374334884345392], 
             UndirectedEdge[218, 222] -> 
             RGBColor[
              0.7556819189936763, 0.8084691579297268, 0.9631032253183853], 
             UndirectedEdge[65, 203] -> 
             RGBColor[
              0.34325183639463963`, 0.4717292211712722, 0.9430926813827534], 
             UndirectedEdge[105, 303] -> 
             RGBColor[
              0.9396161743909813, 0.7997165627600418, 0.5632237947654809], 
             UndirectedEdge[119, 267] -> 
             RGBColor[
              0.21867692760035795`, 0.34717369419895117`, 0.9357646995720923],
              UndirectedEdge[20, 312] -> 
             RGBColor[
              0.4662211223319299, 0.5756731791658605, 0.9516371294428863], 
             UndirectedEdge[285, 324] -> 
             RGBColor[
              0.1849819453905557, 0.31175813151118514`, 0.9338458201825032], 
             UndirectedEdge[16, 302] -> 
             RGBColor[
              0.21182755927874247`, 0.3399745738178992, 0.9353746381789088], 
             UndirectedEdge[65, 313] -> 
             RGBColor[
              0.33055584599709903`, 0.45850175468157234`, 0.9423653859984371],
              UndirectedEdge[280, 392] -> 
             RGBColor[
              0.20599555407739328`, 0.33384476658079454`, 0.9350425141103704],
              UndirectedEdge[1, 357] -> 
             RGBColor[
              0.18390843895748787`, 0.3106298081857918, 0.9337846855792504], 
             UndirectedEdge[26, 177] -> 
             RGBColor[
              0.18182665700375172`, 0.3084417233598157, 0.9336661311767056], 
             UndirectedEdge[69, 293] -> 
             RGBColor[
              0.44347384418172964`, 0.5552917835398956, 0.950375260333012], 
             UndirectedEdge[165, 399] -> 
             RGBColor[
              0.2924581876891166, 0.42004140455849254`, 0.9401378301611192], 
             UndirectedEdge[108, 297] -> 
             RGBColor[
              0.30146181771501923`, 0.43418586257465347`, 0.9404791765948524],
              UndirectedEdge[192, 335] -> 
             RGBColor[
              0.22826537319767345`, 0.3572517584642937, 0.9363107473640253], 
             UndirectedEdge[134, 272] -> 
             RGBColor[
              0.18788317693480855`, 0.3148075098128992, 0.9340110410269609], 
             UndirectedEdge[86, 236] -> 
             RGBColor[
              0.3888676051713017, 0.5059520744556105, 0.9465593917911999], 
             UndirectedEdge[312, 389] -> 
             RGBColor[
              0.7704699076494956, 0.8157404401627024, 0.7252172989695943], 
             UndirectedEdge[156, 245] -> 
             RGBColor[
              0.1983829021548571, 0.32584338674019936`, 0.9346089848452912], 
             UndirectedEdge[153, 168] -> 
             RGBColor[
              0.20180786245057253`, 0.3294432371660213, 0.9348040312673576], 
             UndirectedEdge[118, 150] -> 
             RGBColor[
              0.29792702653421543`, 0.4259677967148573, 0.9404427441608055], 
             UndirectedEdge[195, 255] -> 
             RGBColor[
              0.3994035312970712, 0.5203649970295117, 0.9466706177289421], 
             UndirectedEdge[109, 180] -> 
             RGBColor[
              0.18558731783868732`, 0.3123944163370016, 0.933880295247856], 
             UndirectedEdge[143, 378] -> 
             RGBColor[
              0.21957024665493602`, 0.3481126291650121, 0.9358155727707034], 
             UndirectedEdge[135, 383] -> 
             RGBColor[
              0.3468364039638354, 0.47483399343410504`, 0.9433210868585539], 
             UndirectedEdge[20, 120] -> 
             RGBColor[
              0.3985867083579536, 0.5196575060543626, 0.9466185704935497], 
             UndirectedEdge[149, 230] -> 
             RGBColor[
              0.21572578902733716`, 0.34407186044571364`, 0.935596636596177], 
             UndirectedEdge[16, 77] -> 
             RGBColor[
              0.21295289463759554`, 0.3411573726304365, 0.9354387243628108], 
             UndirectedEdge[168, 238] -> 
             RGBColor[
              0.19942328541058194`, 0.3269368955060745, 0.9346682331325956], 
             UndirectedEdge[104, 335] -> 
             RGBColor[
              0.21115674634682685`, 0.33926950689445945`, 0.9353364363748149],
              UndirectedEdge[79, 232] -> 
             RGBColor[
              0.19470557204870292`, 0.32197827964243614`, 0.9343995663358682],
              UndirectedEdge[47, 299] -> 
             RGBColor[
              0.184696983160691, 0.3114586181399484, 0.9338295920050762], 
             UndirectedEdge[236, 397] -> 
             RGBColor[
              0.4369077612514729, 0.5513201116783387, 0.9494828667557864], 
             UndirectedEdge[33, 118] -> 
             RGBColor[
              0.30201839786374246`, 0.43026808739011524`, 0.9406757417053806],
              UndirectedEdge[51, 79] -> 
             RGBColor[
              0.20012999875823717`, 0.3276796960426744, 0.934708479412256], 
             UndirectedEdge[24, 168] -> 
             RGBColor[
              0.22907306672132033`, 0.35810069556837376`, 0.9363567443153216],
              UndirectedEdge[269, 365] -> 
             RGBColor[
              0.3297101598350657, 0.4597477851420956, 0.9422390562668672], 
             UndirectedEdge[98, 240] -> 
             RGBColor[
              0.18629079266231832`, 0.3131338129795177, 0.9339203570983641], 
             UndirectedEdge[29, 113] -> 
             RGBColor[
              0.1857448284490183, 0.3125599699752089, 0.9338892652440982], 
             UndirectedEdge[330, 398] -> 
             RGBColor[
              0.18475377969358928`, 0.31151831489713266`, 0.9338328264836019],
              UndirectedEdge[43, 265] -> 
             RGBColor[
              0.19684687423849298`, 0.3242289240103058, 0.934521510327804], 
             UndirectedEdge[209, 304] -> 
             RGBColor[
              0.2736580263748165, 0.40496231501391133`, 0.9388957918100511], 
             UndirectedEdge[107, 238] -> 
             RGBColor[
              0.21198166691675951`, 0.34013655071644366`, 0.9353834143809119],
              UndirectedEdge[298, 347] -> 
             RGBColor[
              0.1948950544058417, 0.32217743761366435`, 0.9344103570757931], 
             UndirectedEdge[153, 343] -> 
             RGBColor[
              0.20318561149837056`, 0.330891338769592, 0.9348824920374326], 
             UndirectedEdge[110, 292] -> 
             RGBColor[
              0.8362272767124428, 0.5182110192715781, 0.5760681458101908], 
             UndirectedEdge[332, 366] -> 
             RGBColor[
              0.905552488404973, 0.5629699044168974, 0.3384071050888487], 
             UndirectedEdge[39, 136] -> 
             RGBColor[
              0.19040517985093924`, 0.31745829478197307`, 0.9341546653620656],
              UndirectedEdge[115, 380] -> 
             RGBColor[
              0.8377450255090341, 0.8206060012110092, 0.627750782576732], 
             UndirectedEdge[167, 238] -> 
             RGBColor[
              0.2183443407497785, 0.3468241243317679, 0.9357457592429699], 
             UndirectedEdge[1, 162] -> 
             RGBColor[
              0.18855509271436693`, 0.315513735899136, 0.9340493056365965], 
             UndirectedEdge[128, 243] -> 
             RGBColor[
              0.26764794439082373`, 0.39864533778752814`, 0.9385535265321823],
              UndirectedEdge[196, 366] -> 
             RGBColor[
              0.9187123308959824, 0.9333119446325909, 0.748562723255582], 
             UndirectedEdge[136, 149] -> 
             RGBColor[
              0.19648120536399588`, 0.3238445828384636, 0.9345006860263599], 
             UndirectedEdge[263, 360] -> 
             RGBColor[
              0.48229378308011506`, 0.5855219577186828, 0.9537605973016217], 
             UndirectedEdge[267, 354] -> 
             RGBColor[
              0.19683262012965425`, 0.3242139420381536, 0.9345206985773926], 
             UndirectedEdge[192, 355] -> 
             RGBColor[
              0.233203459675137, 0.36244200044487396`, 0.9365919640836726], 
             UndirectedEdge[24, 100] -> 
             RGBColor[
              0.32394697736880945`, 0.450518226988342, 0.9420269972308946], 
             UndirectedEdge[11, 286] -> 
             RGBColor[
              0.5972181184299319, 0.677195451192008, 0.9647287147159659], 
             UndirectedEdge[71, 110] -> 
             RGBColor[
              0.9113332721380322, 0.9312595378862136, 0.9610025753124077], 
             UndirectedEdge[186, 306] -> 
             RGBColor[
              0.21444053080855624`, 0.3427209725676972, 0.9355234430419865], 
             UndirectedEdge[6, 131] -> 
             RGBColor[
              0.8701371040264215, 0.8993351938028649, 0.9874630507499915], 
             UndirectedEdge[53, 264] -> 
             RGBColor[
              0.3312918681319017, 0.4568612487266348, 0.9424956938321003], 
             UndirectedEdge[83, 118] -> 
             RGBColor[
              0.6542161598297946, 0.7234949587303476, 0.9559255584190995], 
             UndirectedEdge[98, 272] -> 
             RGBColor[
              0.1949500622314218, 0.3222352543260466, 0.9344134896900831], 
             UndirectedEdge[200, 330] -> 
             RGBColor[
              0.1913737687250167, 0.31847634310071005`, 0.9342098250655455], 
             UndirectedEdge[101, 389] -> 
             RGBColor[
              0.9235485115849101, 0.701785575444227, 0.3461039765729519], 
             UndirectedEdge[10, 353] -> 
             RGBColor[
              0.9181134493807003, 0.6596306220979193, 0.3482638350680197], 
             UndirectedEdge[174, 340] -> 
             RGBColor[
              0.3446138349142821, 0.46945528337457815`, 0.9433059211263948], 
             UndirectedEdge[77, 187] -> 
             RGBColor[
              0.2066496337845954, 0.33453224582411256`, 0.9350797629820713], 
             UndirectedEdge[137, 264] -> 
             RGBColor[
              0.27631179289230656`, 0.4077515918823088, 0.9390469198873264], 
             UndirectedEdge[20, 356] -> 
             RGBColor[
              0.6650046334832713, 0.7331764586358418, 0.9615322764421933], 
             UndirectedEdge[130, 227] -> 
             RGBColor[
              0.24482762812914852`, 0.374659738504888, 0.9372539432807123], 
             UndirectedEdge[24, 150] -> 
             RGBColor[
              0.24929421300339247`, 0.3793544024055562, 0.9375083086815804], 
             UndirectedEdge[282, 339] -> 
             RGBColor[
              0.34849054026782905`, 0.4762667231613163, 0.9434264869611491], 
             UndirectedEdge[69, 93] -> 
             RGBColor[
              0.45767335020652483`, 0.5675906819706489, 0.951280040300782], 
             UndirectedEdge[65, 266] -> 
             RGBColor[
              0.5173579150755038, 0.6167245429391528, 0.9558899485594068], 
             UndirectedEdge[189, 336] -> 
             RGBColor[
              0.23398737474331802`, 0.3632659448846183, 0.936636606887107], 
             UndirectedEdge[191, 322] -> 
             RGBColor[
              0.18956017104754852`, 0.31657013695295677`, 0.934106543360791], 
             UndirectedEdge[297, 376] -> 
             RGBColor[
              0.2913695149854919, 0.423578212516969, 0.9399044348846297], 
             UndirectedEdge[33, 286] -> 
             RGBColor[
              0.2839164063725824, 0.41458905219301934`, 0.9395222988145264], 
             UndirectedEdge[145, 351] -> 
             RGBColor[
              0.2797139568415439, 0.4112527007055903, 0.9392434061971325], 
             UndirectedEdge[83, 141] -> 
             RGBColor[
              0.6533758763039106, 0.7227671473741049, 0.9558720162958637], 
             UndirectedEdge[148, 276] -> 
             RGBColor[
              0.31779913118136904`, 0.44485776815799194`, 0.9416475463334251],
              UndirectedEdge[124, 160] -> 
             RGBColor[
              0.21095706740892387`, 0.3390596316703475, 0.9353250649546998], 
             UndirectedEdge[25, 362] -> 
             RGBColor[
              0.5776163710657185, 0.6632666473879071, 0.9621212256893779], 
             UndirectedEdge[96, 208] -> 
             RGBColor[
              0.25302363918053994`, 0.383274265777015, 0.9377206939851772], 
             UndirectedEdge[240, 272] -> 
             RGBColor[
              0.18799208314490007`, 0.3149219771447579, 0.9340172430745133], 
             UndirectedEdge[25, 182] -> 
             RGBColor[
              0.30289473156223595`, 0.4305868645556383, 0.9407477009537915], 
             UndirectedEdge[101, 380] -> 
             RGBColor[
              0.787177962650946, 0.5986793707999881, 0.5860416238148101], 
             UndirectedEdge[24, 358] -> 
             RGBColor[
              0.2688894294981841, 0.3999502173500661, 0.9386242272724338], 
             UndirectedEdge[202, 234] -> 
             RGBColor[
              0.28726387007128157`, 0.41752052418196, 0.9397344221047603], 
             UndirectedEdge[17, 62] -> 
             RGBColor[
              0.9097327710312662, 0.6022520662838114, 0.4798085283004041], 
             UndirectedEdge[24, 211] -> 
             RGBColor[
              0.2463354066076684, 0.3762445092844895, 0.9373398090345058], 
             UndirectedEdge[2, 39] -> 
             RGBColor[
              0.19999978068083032`, 0.3275428285870168, 0.934701063685388], 
             UndirectedEdge[164, 328] -> 
             RGBColor[
              0.22317220824719552`, 0.35189851917603227`, 0.9360206991547579],
              UndirectedEdge[228, 301] -> 
             RGBColor[
              0.2369380396545014, 0.36636728078923275`, 0.9368046428886814], 
             UndirectedEdge[118, 286] -> 
             RGBColor[
              0.33934539796061675`, 0.46834566054302623`, 0.9428437665800653],
              UndirectedEdge[139, 215] -> 
             RGBColor[
              0.5065072627092252, 0.6051273956422916, 0.956064783626883], 
             UndirectedEdge[239, 377] -> 
             RGBColor[
              0.3809157120608543, 0.4978929904163819, 0.9460793391645779], 
             UndirectedEdge[348, 374] -> 
             RGBColor[
              0.19237032800791454`, 0.3195237900925436, 0.9342665776424293], 
             UndirectedEdge[8, 388] -> 
             RGBColor[
              0.26319007599843486`, 0.3939598354619466, 0.938299657522061], 
             UndirectedEdge[249, 370] -> 
             RGBColor[
              0.18458433002004276`, 0.31134021254650546`, 0.9338231765753717],
              UndirectedEdge[61, 285] -> 
             RGBColor[
              0.2007711589524707, 0.32835359605871806`, 0.934744992536806], 
             UndirectedEdge[162, 280] -> 
             RGBColor[
              0.20211294537388308`, 0.32976389866179523`, 0.9348214052885103],
              UndirectedEdge[126, 205] -> 
             RGBColor[
              0.18385657240612066`, 0.31057529315177557`, 0.9337817318558796],
              UndirectedEdge[161, 334] -> 
             RGBColor[
              0.9198789642740572, 0.7116881876157337, 0.2605664067222301], 
             UndirectedEdge[192, 399] -> 
             RGBColor[
              0.3088211273745378, 0.43723989163816773`, 0.941069675369404], 
             UndirectedEdge[69, 281] -> 
             RGBColor[
              0.4857845720433236, 0.5919392094145923, 0.9530712624984452], 
             UndirectedEdge[38, 128] -> 
             RGBColor[
              0.281313846761083, 0.4130090676469258, 0.9393317794552777], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.22265042245962569`, 0.35135008923016664`, 0.9359909842260687],
              UndirectedEdge[145, 355] -> 
             RGBColor[
              0.22900678342998865`, 0.3580310276265808, 0.9363529695799375], 
             UndirectedEdge[23, 139] -> 
             RGBColor[
              0.2594316195520534, 0.3900094594368974, 0.9380856189875776], 
             UndirectedEdge[120, 359] -> 
             RGBColor[
              0.3691186833876108, 0.4941337839310517, 0.9447408939999908], 
             UndirectedEdge[117, 309] -> 
             RGBColor[
              0.6279491492944215, 0.7079937863162957, 0.9644297266188226], 
             UndirectedEdge[19, 167] -> 
             RGBColor[
              0.21765966709879997`, 0.34610448891377266`, 0.9357067680914306],
              UndirectedEdge[26, 285] -> 
             RGBColor[
              0.1832664520031871, 0.30995503919249784`, 0.9337481253719375], 
             UndirectedEdge[166, 169] -> 
             RGBColor[
              0.3512165772923903, 0.4726432539013666, 0.9438449606681389], 
             UndirectedEdge[31, 383] -> 
             RGBColor[
              0.6712879724630387, 0.7362684219408357, 0.9272977112853262], 
             UndirectedEdge[146, 346] -> 
             RGBColor[
              0.20127774655664432`, 0.3288860517502138, 0.9347738419514344], 
             UndirectedEdge[191, 349] -> 
             RGBColor[
              0.1912119313089536, 0.3183062417153429, 0.9342006086641177], 
             UndirectedEdge[212, 362] -> 
             RGBColor[
              0.6845252117813709, 0.7524862898136562, 0.9698671068536907], 
             UndirectedEdge[242, 380] -> 
             RGBColor[
              0.5303903683229951, 0.6253725774741394, 0.9578377471522206], 
             UndirectedEdge[175, 307] -> 
             RGBColor[
              0.18458331869086259`, 0.3113391495754152, 0.933823118981671], 
             UndirectedEdge[140, 193] -> 
             RGBColor[
              0.6221373960333281, 0.6999919748954846, 0.9657582775840088], 
             UndirectedEdge[8, 25] -> 
             RGBColor[
              0.3097802502292844, 0.43782398124180466`, 0.9411398210556678], 
             UndirectedEdge[8, 269] -> 
             RGBColor[
              0.30450100126350144`, 0.4332513611304116, 0.9408034319798247], 
             UndirectedEdge[155, 371] -> 
             RGBColor[
              0.18296643499197385`, 0.3096397022915355, 0.9337310398469844], 
             UndirectedEdge[55, 161] -> 
             RGBColor[
              0.8416418357931794, 0.6962674351181222, 0.6011377684958046], 
             UndirectedEdge[110, 202] -> 
             RGBColor[
              0.590277084299675, 0.6718791600205865, 0.9639661767270546], 
             UndirectedEdge[332, 380] -> 
             RGBColor[
              0.7690935487574768, 0.4596746409740855, 0.5687239686469998], 
             UndirectedEdge[359, 360] -> 
             RGBColor[
              0.49422258294729215`, 0.5964933259008812, 0.9544972841256812], 
             UndirectedEdge[128, 350] -> 
             RGBColor[
              0.32622360223214686`, 0.4565323538126437, 0.9420240559565443], 
             UndirectedEdge[272, 378] -> 
             RGBColor[
              0.2184441934159871, 0.34692907581497784`, 0.9357514457045917], 
             UndirectedEdge[52, 345] -> 
             RGBColor[
              0.9085391948738575, 0.9277362639462506, 0.9077575254526454], 
             UndirectedEdge[32, 333] -> 
             RGBColor[
              0.8876476995379257, 0.5657281038549604, 0.5656841246616948], 
             UndirectedEdge[85, 168] -> 
             RGBColor[
              0.18992658867508105`, 0.3169552651117129, 0.9341274103026127], 
             UndirectedEdge[23, 354] -> 
             RGBColor[
              0.20401044687486744`, 0.3317582930478737, 0.9349294651918895], 
             UndirectedEdge[51, 373] -> 
             RGBColor[
              0.1995969758310581, 0.32711945515060364`, 0.9346781245450898], 
             UndirectedEdge[55, 334] -> 
             RGBColor[
              0.8819744590496598, 0.862025730858683, 0.6405013220512796], 
             UndirectedEdge[66, 267] -> 
             RGBColor[
              0.1968456208420638, 0.3242276066111888, 0.9345214389487315], 
             UndirectedEdge[30, 153] -> 
             RGBColor[
              0.2031751711317593, 0.3308803652823261, 0.9348818974739992], 
             UndirectedEdge[179, 290] -> 
             RGBColor[
              0.24217146180405288`, 0.37186793928654055`, 0.9371026785379442],
              UndirectedEdge[178, 200] -> 
             RGBColor[
              0.1885274133225135, 0.31548464310332325`, 0.9340477293361784], 
             UndirectedEdge[340, 358] -> 
             RGBColor[
              0.2744945486553811, 0.4058415529693607, 0.9389434305164055], 
             UndirectedEdge[31, 259] -> 
             RGBColor[
              0.9398415048836066, 0.9536048784389164, 0.9502151803126189], 
             UndirectedEdge[92, 146] -> 
             RGBColor[
              0.20174986693286398`, 0.32938228019978144`, 0.9348007285084208],
              UndirectedEdge[3, 373] -> 
             RGBColor[
              0.21710028788855346`, 0.3455165458971132, 0.9356749122729344], 
             UndirectedEdge[174, 341] -> 
             RGBColor[
              0.3335895874564281, 0.4578681003187137, 0.9426781065425826], 
             UndirectedEdge[248, 260] -> 
             RGBColor[
              0.1859219097416619, 0.3127460936413798, 0.933899349761746], 
             UndirectedEdge[41, 325] -> 
             RGBColor[
              0.2165335134226994, 0.3449208299979239, 0.9356426353055718], 
             UndirectedEdge[66, 346] -> 
             RGBColor[
              0.19977669952143007`, 0.3273083561443247, 0.9346883595433791], 
             UndirectedEdge[53, 142] -> 
             RGBColor[
              0.43838221439814257`, 0.5535604743597381, 0.949310664485988], 
             UndirectedEdge[38, 44] -> 
             RGBColor[
              0.24351959225973108`, 0.37328490987186613`, 0.9371794525730147],
              UndirectedEdge[76, 187] -> 
             RGBColor[
              0.24964108184106412`, 0.37971898354670364`, 0.9375280623487394],
              UndirectedEdge[156, 160] -> 
             RGBColor[
              0.19858358472464382`, 0.32605431684505504`, 0.9346204134207573],
              UndirectedEdge[141, 290] -> 
             RGBColor[
              0.3066482770874609, 0.4352897639120549, 0.9409337172583541], 
             UndirectedEdge[3, 79] -> 
             RGBColor[
              0.21763331081573253`, 0.34607678678918397`, 0.9357052671401005],
              UndirectedEdge[301, 382] -> 
             RGBColor[
              0.2859820358837003, 0.41668133468074653`, 0.9396428195322926], 
             UndirectedEdge[193, 389] -> 
             RGBColor[
              0.9155257058475293, 0.9306524378746825, 0.7386464272151838], 
             UndirectedEdge[189, 291] -> 
             RGBColor[
              0.21431712870363867`, 0.34259126913128346`, 0.9355164154746687],
              UndirectedEdge[161, 196] -> 
             RGBColor[
              0.8618354721760655, 0.7122379768474625, 0.603098702731688], 
             UndirectedEdge[83, 161] -> 
             RGBColor[
              0.9152656356126947, 0.754447556797873, 0.5945283802670174], 
             UndirectedEdge[100, 211] -> 
             RGBColor[
              0.31010062158634694`, 0.43596482915131163`, 0.941238467752931], 
             UndirectedEdge[32, 287] -> 
             RGBColor[
              0.8194189331925024, 0.1502680067141652, 0.16622889839667554`], 
             UndirectedEdge[156, 181] -> 
             RGBColor[
              0.19699698742024596`, 0.3243867024820536, 0.9345300590514323], 
             UndirectedEdge[126, 176] -> 
             RGBColor[
              0.18438193895865332`, 0.3111274867086507, 0.9338116507038363], 
             UndirectedEdge[46, 350] -> 
             RGBColor[
              0.5770408715617338, 0.6621623046757947, 0.9623409899481321], 
             UndirectedEdge[47, 149] -> 
             RGBColor[
              0.1956652358484003, 0.3229869471421173, 0.9344542177695655], 
             UndirectedEdge[57, 108] -> 
             RGBColor[
              0.32733127751038416`, 0.4577193635987606, 0.9420863025998256], 
             UndirectedEdge[105, 400] -> 
             RGBColor[
              0.9037087544899305, 0.5795914846825118, 0.5310267371567282], 
             UndirectedEdge[62, 256] -> 
             RGBColor[
              0.992053902372576, 0.9909820986727351, 0.781350931735281], 
             UndirectedEdge[193, 332] -> 
             RGBColor[
              0.8278665265086236, 0.5057335736447233, 0.5745434217731962], 
             UndirectedEdge[1, 387] -> 
             RGBColor[
              0.1836776641650684, 0.31038724924699196`, 0.9337715432962228], 
             UndirectedEdge[72, 284] -> 
             RGBColor[
              0.602700789657427, 0.6868450128545692, 0.9628871876056561], 
             UndirectedEdge[127, 394] -> 
             RGBColor[
              0.348496932711213, 0.47627225997448197`, 0.9434268942819889], 
             UndirectedEdge[110, 385] -> 
             RGBColor[
              0.923690126192328, 0.9380306979900004, 0.809802069993292], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.18382719114068813`, 0.31054441157892615`, 0.933780058636279], 
             UndirectedEdge[97, 393] -> 
             RGBColor[
              0.5102982570407728, 0.6069665111134733, 0.9566203329382144], 
             UndirectedEdge[19, 150] -> 
             RGBColor[
              0.21895975804167556`, 0.3474709669252617, 0.9357808063473152], 
             UndirectedEdge[272, 342] -> 
             RGBColor[
              0.19152273141080622`, 0.31863291232825464`, 0.9342183082701306],
              UndirectedEdge[96, 187] -> 
             RGBColor[
              0.2139882194822336, 0.34224556468553763`, 0.9354976845810872], 
             UndirectedEdge[129, 333] -> 
             RGBColor[
              0.8865563472760825, 0.5573394921368233, 0.5646390445032476], 
             UndirectedEdge[19, 160] -> 
             RGBColor[
              0.19740416245689973`, 0.32481466926196517`, 0.9345532470674082],
              UndirectedEdge[183, 357] -> 
             RGBColor[
              0.18734376764879906`, 0.31424055645277915`, 0.9339803224661072],
              UndirectedEdge[197, 217] -> 
             RGBColor[
              0.19977926755688577`, 0.3273110553124115, 0.9346885057891993], 
             UndirectedEdge[199, 345] -> 
             RGBColor[
              0.9084097409587222, 0.9276827314255283, 0.9099029118424318], 
             UndirectedEdge[44, 346] -> 
             RGBColor[
              0.2158698080892293, 0.3442232336110982, 0.9356048382686947], 
             UndirectedEdge[78, 80] -> 
             RGBColor[
              0.21178615052788774`, 0.3399310505952844, 0.9353722800118063], 
             UndirectedEdge[42, 320] -> 
             RGBColor[
              0.18379681968568948`, 0.3105124892540611, 0.9337783290268474], 
             UndirectedEdge[161, 332] -> 
             RGBColor[
              0.848675629685056, 0.3418959366317691, 0.19294308456495457`], 
             UndirectedEdge[239, 309] -> 
             RGBColor[
              0.6022520031590326, 0.6871316854403461, 0.9624067531432969], 
             UndirectedEdge[8, 377] -> 
             RGBColor[
              0.25514638831763914`, 0.3855054097101751, 0.9378415814082092], 
             UndirectedEdge[75, 126] -> 
             RGBColor[
              0.18223452639463555`, 0.3088704199500476, 0.9336893587351277], 
             UndirectedEdge[54, 310] -> 
             RGBColor[
              0.8873852444618682, 0.5186875281092153, 0.22512385696518958`], 
             UndirectedEdge[65, 211] -> 
             RGBColor[
              0.3044915837808781, 0.4311065625226518, 0.9408810648238439], 
             UndirectedEdge[88, 356] -> 
             RGBColor[
              0.6878897223994248, 0.7529983724170004, 0.962990494071441], 
             UndirectedEdge[98, 158] -> 
             RGBColor[
              0.19219455973941713`, 0.31933904649800093`, 0.9342565678995641],
              UndirectedEdge[13, 390] -> 
             RGBColor[
              0.2131729075996141, 0.34138862020314553`, 0.9354512537755177], 
             UndirectedEdge[241, 242] -> 
             RGBColor[
              0.31065498243158685`, 0.4409219663646659, 0.9411098670507269], 
             UndirectedEdge[12, 238] -> 
             RGBColor[
              0.2218338423144311, 0.3504918117233956, 0.9359444811948219], 
             UndirectedEdge[175, 343] -> 
             RGBColor[
              0.19542826971397487`, 0.32273788071031545`, 0.93444072289877], 
             UndirectedEdge[59, 258] -> 
             RGBColor[
              0.2269624966999203, 0.35588235265801405`, 0.9362365504749113], 
             UndirectedEdge[152, 156] -> 
             RGBColor[
              0.20135778622096587`, 0.32897017851222354`, 0.9347784000919095],
              UndirectedEdge[39, 258] -> 
             RGBColor[
              0.21791338707223826`, 0.34637116469263174`, 0.9357212170685729],
              UndirectedEdge[183, 368] -> 
             RGBColor[
              0.18625851527578347`, 0.31309988739976513`, 0.933918518948951], 
             UndirectedEdge[44, 119] -> 
             RGBColor[
              0.23405162543822766`, 0.3633334764386976, 0.9366402658691317], 
             UndirectedEdge[149, 264] -> 
             RGBColor[
              0.23515256587011008`, 0.3644906346362611, 0.9367029627980321], 
             UndirectedEdge[120, 241] -> 
             RGBColor[
              0.34672955885014695`, 0.4721679512974918, 0.9434085071606221], 
             UndirectedEdge[116, 304] -> 
             RGBColor[
              0.26114585574207083`, 0.3918112303614577, 0.938183242202614], 
             UndirectedEdge[82, 256] -> 
             RGBColor[
              0.8760312800563814, 0.9016669835366705, 0.876948136427472], 
             UndirectedEdge[98, 186] -> 
             RGBColor[
              0.1999149394327242, 0.32745365505601143`, 0.9346962321018197], 
             UndirectedEdge[72, 262] -> 
             RGBColor[
              0.4149349676293397, 0.5334857796550911, 0.9477519352990894], 
             UndirectedEdge[147, 241] -> 
             RGBColor[
              0.2640632471374818, 0.3948775936913327, 0.9383493833266887], 
             UndirectedEdge[13, 205] -> 
             RGBColor[
              0.19925835051903662`, 0.3267635384775842, 0.9346588403345214], 
             UndirectedEdge[142, 394] -> 
             RGBColor[
              0.4158923670367568, 0.5340808989479011, 0.9478776312991117], 
             UndirectedEdge[42, 75] -> 
             RGBColor[
              0.18289766237674282`, 0.30956741791249204`, 0.9337271233482869],
              UndirectedEdge[56, 341] -> 
             RGBColor[
              0.38387079611477953`, 0.499652079122729, 0.9463702293168075], 
             UndirectedEdge[306, 378] -> 
             RGBColor[
              0.23126849430923743`, 0.36040822916142345`, 0.9364817706686093],
              UndirectedEdge[27, 295] -> 
             RGBColor[
              0.19546687096427723`, 0.32277845307184394`, 0.9344429211828693],
              UndirectedEdge[111, 247] -> 
             RGBColor[
              0.8219754147542075, 0.16991824425479435`, 0.1686769880272973], 
             UndirectedEdge[128, 259] -> 
             RGBColor[
              0.599663278641086, 0.6781009426487141, 0.9652528657581285], 
             UndirectedEdge[52, 68] -> 
             RGBColor[
              0.9052995090875355, 0.9251530264391655, 0.9074485213302443], 
             UndirectedEdge[241, 359] -> 
             RGBColor[
              0.3033005319170658, 0.43455191097441853`, 0.9406412479672268], 
             UndirectedEdge[361, 382] -> 
             RGBColor[
              0.3658350125936814, 0.49128963333144304`, 0.9445316614006376], 
             UndirectedEdge[14, 390] -> 
             RGBColor[
              0.27581610861732475`, 0.40446583032584077`, 0.9391199230263283],
              UndirectedEdge[11, 332] -> 
             RGBColor[
              0.8454988743714711, 0.5197931292132254, 0.5762252108529373], 
             UndirectedEdge[22, 209] -> 
             RGBColor[
              0.25353925279510015`, 0.38381620837770913`, 0.9377500574177445],
              UndirectedEdge[33, 156] -> 
             RGBColor[
              0.22423055163894667`, 0.35301090518360945`, 0.9360809702452394],
              UndirectedEdge[283, 332] -> 
             RGBColor[
              0.8748637305772158, 0.45283228980267326`, 0.21438239989975133`],
              UndirectedEdge[150, 181] -> 
             RGBColor[
              0.21526447072748034`, 0.3435869856632946, 0.9355703652014595], 
             UndirectedEdge[117, 323] -> 
             RGBColor[
              0.4895767347577772, 0.5956116976057565, 0.9532057157698048], 
             UndirectedEdge[199, 223] -> 
             RGBColor[
              0.9239760391061387, 0.7216129997514857, 0.5202901272072924], 
             UndirectedEdge[128, 306] -> 
             RGBColor[
              0.2631009453754704, 0.39386615352600307`, 0.9382945816649401], 
             UndirectedEdge[184, 288] -> 
             RGBColor[
              0.21364346222149755`, 0.3418832029456312, 0.9354780511651108], 
             UndirectedEdge[145, 182] -> 
             RGBColor[
              0.24585035887698375`, 0.3757346933657375, 0.937312186283807], 
             UndirectedEdge[284, 397] -> 
             RGBColor[
              0.5520222170780682, 0.6432815473581924, 0.9595663255932364], 
             UndirectedEdge[61, 148] -> 
             RGBColor[
              0.23690961095816437`, 0.3663374004268991, 0.9368030239164815], 
             UndirectedEdge[34, 159] -> 
             RGBColor[
              0.1825395439463383, 0.30919101273611693`, 0.9337067290334642], 
             UndirectedEdge[276, 382] -> 
             RGBColor[
              0.35057061271571854`, 0.4780683773681971, 0.9435590273381926], 
             UndirectedEdge[59, 164] -> 
             RGBColor[
              0.215632569168565, 0.3439738804636637, 0.9355913278631264], 
             UndirectedEdge[80, 377] -> 
             RGBColor[
              0.2289003475673298, 0.3579191567865028, 0.9363469082150169], 
             UndirectedEdge[180, 370] -> 
             RGBColor[
              0.18698550798658503`, 0.3138640028328177, 0.9339599201083417], 
             UndirectedEdge[98, 374] -> 
             RGBColor[
              0.18844266475489285`, 0.3153955669853844, 0.9340429030306268], 
             UndirectedEdge[139, 350] -> 
             RGBColor[
              0.3277444111277722, 0.4581308203867991, 0.942110663773315], 
             UndirectedEdge[36, 276] -> 
             RGBColor[
              0.31234957064668134`, 0.4391299345139409, 0.941337201922877], 
             UndirectedEdge[53, 281] -> 
             RGBColor[
              0.40067800773256046`, 0.5214688844608842, 0.9467518262404362], 
             UndirectedEdge[73, 183] -> 
             RGBColor[
              0.19359784833893534`, 0.3208139917897307, 0.9343364831093273], 
             UndirectedEdge[101, 115] -> 
             RGBColor[
              0.9045408089975616, 0.6377980714511916, 0.24102778506069641`], 
             UndirectedEdge[283, 366] -> 
             RGBColor[
              0.9626113006296535, 0.8779402128312055, 0.388106189025446], 
             UndirectedEdge[22, 141] -> 
             RGBColor[
              0.2988998919025237, 0.4271457198066904, 0.9404924581847806], 
             UndirectedEdge[197, 314] -> 
             RGBColor[
              0.18703267242257346`, 0.3139135756454394, 0.9339626060531978], 
             UndirectedEdge[13, 14] -> 
             RGBColor[
              0.27600611579144196`, 0.4046655399129887, 0.9391307436538039], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.18066543438157506`, 0.30722120475814135`, 0.9336000012662475],
              UndirectedEdge[323, 395] -> 
             RGBColor[
              0.42965137086591587`, 0.5465641553634234, 0.9485979833191546], 
             UndirectedEdge[93, 131] -> 
             RGBColor[
              0.5783198351360825, 0.6629059133309206, 0.9625766163950823], 
             UndirectedEdge[52, 105] -> 
             RGBColor[
              0.9871484754393005, 0.988953578572104, 0.8626465508576164], 
             UndirectedEdge[178, 330] -> 
             RGBColor[
              0.18585403499635023`, 0.3126747529805498, 0.9338954843954123], 
             UndirectedEdge[92, 98] -> 
             RGBColor[
              0.19880960071600262`, 0.32629187398221465`, 0.9346332846971046],
              UndirectedEdge[37, 323] -> 
             RGBColor[
              0.35247668459828785`, 0.4774620340320098, 0.9437631308877006], 
             UndirectedEdge[279, 370] -> 
             RGBColor[
              0.19229180160053655`, 0.3194412538595276, 0.9342621056796985], 
             UndirectedEdge[150, 160] -> 
             RGBColor[
              0.2168510680318782, 0.345254600026296, 0.9356607195707846], 
             UndirectedEdge[188, 273] -> 
             RGBColor[
              0.39992754574806544`, 0.5158532142548906, 0.9473461281045827], 
             UndirectedEdge[179, 386] -> 
             RGBColor[
              0.284370042597393, 0.41315352294311436`, 0.9396181524839584], 
             UndirectedEdge[141, 179] -> 
             RGBColor[
              0.2912900071166007, 0.41914724840212236`, 0.9400590865040379], 
             UndirectedEdge[117, 388] -> 
             RGBColor[
              0.4146565458770389, 0.527209517044103, 0.9485603887539554], 
             UndirectedEdge[198, 214] -> 
             RGBColor[
              0.8538594754790496, 0.7047084000192836, 0.6021070091036955], 
             UndirectedEdge[150, 238] -> 
             RGBColor[
              0.21964443169265407`, 0.3481906023432569, 0.9358197974988545], 
             UndirectedEdge[331, 392] -> 
             RGBColor[
              0.22201549227327083`, 0.35068273734740874`, 0.9359548258912509],
              UndirectedEdge[323, 365] -> 
             RGBColor[
              0.3633194234507374, 0.48885844003528395`, 0.9443806088249529], 
             UndirectedEdge[6, 71] -> 
             RGBColor[
              0.9479335881069795, 0.9604436363507414, 0.9644935461230137], 
             UndirectedEdge[132, 249] -> 
             RGBColor[
              0.18824799980109214`, 0.3151909617764689, 0.9340318171494888], 
             UndirectedEdge[348, 378] -> 
             RGBColor[
              0.22067056618642705`, 0.3492691347568969, 0.935878234340245], 
             UndirectedEdge[174, 198] -> 
             RGBColor[
              0.6233166189809511, 0.701327344471203, 0.9656888716580491], 
             UndirectedEdge[72, 236] -> 
             RGBColor[
              0.4875863338308316, 0.5948835771747154, 0.9528037287682061], 
             UndirectedEdge[9, 100] -> 
             RGBColor[
              0.5370355289675518, 0.6325732881317867, 0.9576495756744858], 
             UndirectedEdge[51, 298] -> 
             RGBColor[
              0.20333725610200998`, 0.3310507268628402, 0.9348911279732717], 
             UndirectedEdge[23, 128] -> 
             RGBColor[
              0.2579108106564282, 0.38841099286274205`, 0.9379990111708069], 
             UndirectedEdge[215, 353] -> 
             RGBColor[
              0.8496653857450382, 0.8791494975932964, 0.7395436178949295], 
             UndirectedEdge[80, 96] -> 
             RGBColor[
              0.2073679300463957, 0.3352872207378781, 0.9351206688915568], 
             UndirectedEdge[78, 388] -> 
             RGBColor[
              0.2456236030410635, 0.37549635860503494`, 0.9372992728744065], 
             UndirectedEdge[312, 380] -> 
             RGBColor[
              0.6340993587155315, 0.7126342355184634, 0.9651549462114524], 
             UndirectedEdge[57, 325] -> 
             RGBColor[
              0.29328547563165996`, 0.42193506719570584`, 0.9401474445490827],
              UndirectedEdge[308, 374] -> 
             RGBColor[
              0.1982421611639798, 0.32569545903529307`, 0.9346009698540684], 
             UndirectedEdge[76, 365] -> 
             RGBColor[
              0.2944759917270998, 0.42684331653440033`, 0.9400813441394438], 
             UndirectedEdge[182, 187] -> 
             RGBColor[
              0.22908739425404853`, 0.35811575471368917`, 0.9363575602471148],
              UndirectedEdge[74, 286] -> 
             RGBColor[
              0.28488862903471124`, 0.4156109198533938, 0.9395776654568602], 
             UndirectedEdge[137, 164] -> 
             RGBColor[
              0.2538187120761361, 0.3841099378008197, 0.9377659722103766], 
             UndirectedEdge[149, 258] -> 
             RGBColor[
              0.22398941258529487`, 0.35275745274912235`, 0.9360672377328672],
              UndirectedEdge[147, 331] -> 
             RGBColor[
              0.2440919709450002, 0.37388651616098867`, 0.9372120486923824], 
             UndirectedEdge[42, 367] -> 
             RGBColor[
              0.1849893429390042, 0.3117659068036362, 0.9338462414619436], 
             UndirectedEdge[16, 365] -> 
             RGBColor[
              0.2674853323456614, 0.39847442221786333`, 0.9385442660167731], 
             UndirectedEdge[113, 183] -> 
             RGBColor[
              0.18716623928349274`, 0.31405396288489373`, 0.9339702124883327],
              UndirectedEdge[16, 323] -> 
             RGBColor[
              0.3247877744177019, 0.4483592338539112, 0.9421862884149881], 
             UndirectedEdge[340, 343] -> 
             RGBColor[
              0.2360559349263153, 0.3654401327912391, 0.9367544083293682], 
             UndirectedEdge[323, 362] -> 
             RGBColor[
              0.6059463857156073, 0.6878046821697024, 0.9639263891716204], 
             UndirectedEdge[334, 364] -> 
             RGBColor[
              0.9407749655383337, 0.8016431292497415, 0.27774757447488835`], 
             UndirectedEdge[94, 324] -> 
             RGBColor[
              0.18239675869616345`, 0.30904093638507546`, 0.9336985976246985],
              UndirectedEdge[135, 350] -> 
             RGBColor[
              0.3419502599754641, 0.47060186109611535`, 0.9430097460842624], 
             UndirectedEdge[31, 215] -> 
             RGBColor[
              0.8451646800561206, 0.8790328648583385, 0.9409404903646027], 
             UndirectedEdge[3, 21] -> 
             RGBColor[
              0.21644166427209716`, 0.34482429071706844`, 0.9356374046323236],
              UndirectedEdge[127, 193] -> 
             RGBColor[
              0.5886484429999097, 0.6709855269816585, 0.9636243911098379], 
             UndirectedEdge[50, 230] -> 
             RGBColor[
              0.2261265468612622, 0.35500371637530337`, 0.9361889443682767], 
             UndirectedEdge[169, 382] -> 
             RGBColor[
              0.38967734439969204`, 0.5118336629702842, 0.9460804380697425], 
             UndirectedEdge[12, 19] -> 
             RGBColor[
              0.22114916866345258`, 0.3497721763054004, 0.9359054900432826], 
             UndirectedEdge[133, 296] -> 
             RGBColor[
              0.18124069831826523`, 0.30782584362944293`, 0.9336327616964153],
              UndirectedEdge[214, 332] -> 
             RGBColor[
              0.8483631502363858, 0.34047704043678684`, 0.1926823440534119], 
             UndirectedEdge[76, 395] -> 
             RGBColor[
              0.36080793914227827`, 0.4845490318625397, 0.9442987186336453], 
             UndirectedEdge[299, 370] -> 
             RGBColor[
              0.1869681936623269, 0.3138458043802308, 0.9339589340831895], 
             UndirectedEdge[170, 235] -> 
             RGBColor[
              0.21437654864384317`, 0.34265372325588017`, 0.9355197993523594],
              UndirectedEdge[46, 400] -> 
             RGBColor[
              0.81382584660932, 0.509501659616798, 0.5750314348940344], 
             UndirectedEdge[65, 329] -> 
             RGBColor[
              0.31941652727713654`, 0.4467936244332925, 0.9417310182764805], 
             UndirectedEdge[81, 267] -> 
             RGBColor[
              0.21336000502701669`, 0.3415852714620077, 0.9354619086972226], 
             UndirectedEdge[104, 182] -> 
             RGBColor[
              0.23293840827128548`, 0.36216341461419643`, 0.9365768697983317],
              UndirectedEdge[23, 306] -> 
             RGBColor[
              0.21710981978146196`, 0.345526564520917, 0.9356754551001344], 
             UndirectedEdge[209, 286] -> 
             RGBColor[
              0.29314447532730914`, 0.4242883377578022, 0.9400478236897936], 
             UndirectedEdge[150, 167] -> 
             RGBColor[
              0.2371065726737784, 0.3665444196781035, 0.936814240594807], 
             UndirectedEdge[4, 288] -> 
             RGBColor[
              0.2072894767278965, 0.33520476132590776`, 0.9351162010911295], 
             UndirectedEdge[171, 272] -> 
             RGBColor[
              0.19235235421379315`, 0.3195048984953177, 0.9342655540614437], 
             UndirectedEdge[78, 182] -> 
             RGBColor[
              0.23114667261114863`, 0.3602801868327903, 0.9364748331031223], 
             UndirectedEdge[143, 374] -> 
             RGBColor[
              0.1912700084764235, 0.3183672845006589, 0.9342039160728877], 
             UndirectedEdge[55, 262] -> 
             RGBColor[
              0.5840352729572464, 0.6682969151994234, 0.9627543260164191], 
             UndirectedEdge[165, 190] -> 
             RGBColor[
              0.21884661716031273`, 0.34735204868540315`, 0.9357743631414985],
              UndirectedEdge[2, 149] -> 
             RGBColor[
              0.20607580619388693`, 0.3339291166435074, 0.9350470843496823], 
             UndirectedEdge[39, 47] -> 
             RGBColor[
              0.18958921033534365`, 0.3166006590856267, 0.9341081971052712], 
             UndirectedEdge[230, 300] -> 
             RGBColor[
              0.2086431877242838, 0.3366275974133453, 0.9351932929297377], 
             UndirectedEdge[40, 48] -> 
             RGBColor[
              0.20069384731952558`, 0.3282723366306521, 0.934740589753682], 
             UndirectedEdge[25, 208] -> 
             RGBColor[
              0.3291899186131193, 0.4582247733572693, 0.9422451729560961], 
             UndirectedEdge[32, 52] -> 
             RGBColor[
              0.905256763296387, 0.5780630184234903, 0.500145144132204], 
             UndirectedEdge[161, 366] -> 
             RGBColor[
              0.9364231997374939, 0.7670038596603013, 0.3666668736906492], 
             UndirectedEdge[190, 318] -> 
             RGBColor[
              0.21280458260693721`, 0.34100148728268875`, 0.9354302782120729],
              UndirectedEdge[179, 245] -> 
             RGBColor[
              0.21085364957036085`, 0.33895093296494805`, 0.9353191754617867],
              UndirectedEdge[37, 182] -> 
             RGBColor[
              0.26307956528763465`, 0.3938436816981118, 0.9382933641005669], 
             UndirectedEdge[12, 206] -> 
             RGBColor[
              0.33583694364464667`, 0.4592083134506097, 0.9428435069438263], 
             UndirectedEdge[18, 218] -> 
             RGBColor[
              0.776406098847213, 0.8201699347730458, 0.6937389035902746], 
             UndirectedEdge[92, 119] -> 
             RGBColor[
              0.22208012665594387`, 0.3507506721816547, 0.9359585067237262], 
             UndirectedEdge[215, 400] -> 
             RGBColor[
              0.7640930948428964, 0.47065005595395515`, 0.5700745389769464], 
             UndirectedEdge[71, 292] -> 
             RGBColor[
              0.8945978800262582, 0.5638772618194792, 0.5512331862497395], 
             UndirectedEdge[158, 346] -> 
             RGBColor[
              0.19728326833036003`, 0.3246876018698416, 0.9345463623257486], 
             UndirectedEdge[92, 151] -> 
             RGBColor[
              0.20599136961110498`, 0.33384036844141496`, 0.9350422758112056],
              UndirectedEdge[104, 170] -> 
             RGBColor[
              0.22977658578143667`, 0.35884013870624076`, 0.936396808685032], 
             UndirectedEdge[82, 316] -> 
             RGBColor[
              0.7359499332008539, 0.7936489483339444, 0.9743162695644639], 
             UndirectedEdge[287, 353] -> 
             RGBColor[
              0.9052894000566567, 0.5610593594590743, 0.33598351095262347`], 
             UndirectedEdge[368, 372] -> 
             RGBColor[
              0.1818899475322301, 0.30850824571809776`, 0.9336697354786725], 
             UndirectedEdge[9, 203] -> 
             RGBColor[
              0.4981842108201723, 0.5989222290765547, 0.9551740040370065], 
             UndirectedEdge[17, 384] -> 
             RGBColor[
              0.8806232133780418, 0.49400904252402256`, 0.21977054774648136`],
              UndirectedEdge[82, 310] -> 
             RGBColor[
              0.7931376486603983, 0.5085364648564028, 0.5748575062936936], 
             UndirectedEdge[129, 287] -> 
             RGBColor[
              0.8183275809306592, 0.1418793949960282, 0.16518381823822845`], 
             UndirectedEdge[81, 363] -> 
             RGBColor[
              0.3018408929173706, 0.42850250201273, 0.940723448587576], 
             UndirectedEdge[64, 356] -> 
             RGBColor[
              0.9689844051155808, 0.9726683265613763, 0.7058319664887789], 
             UndirectedEdge[245, 352] -> 
             RGBColor[
              0.1906398234149592, 0.3177049200450192, 0.9341680279659126], 
             UndirectedEdge[87, 232] -> 
             RGBColor[
              0.18860427170948546`, 0.315565426141134, 0.9340521063076146], 
             UndirectedEdge[88, 255] -> 
             RGBColor[
              0.40229233650521606`, 0.5228671349052352, 0.9468546898423349], 
             UndirectedEdge[154, 392] -> 
             RGBColor[
              0.19471742420704347`, 0.3219907370123223, 0.934400241298752], 
             UndirectedEdge[22, 45] -> 
             RGBColor[
              0.24087710963769857`, 0.3705074930930349, 0.9370289670968927], 
             UndirectedEdge[116, 141] -> 
             RGBColor[
              0.29789401265983945`, 0.4260884769462017, 0.9404351748499746], 
             UndirectedEdge[97, 224] -> 
             RGBColor[
              0.3981861519254275, 0.5171684195208632, 0.946960633454442], 
             UndirectedEdge[66, 151] -> 
             RGBColor[
              0.20186975982558952`, 0.3295082952316844, 0.9348075562312959], 
             UndirectedEdge[165, 221] -> 
             RGBColor[
              0.29772616502322835`, 0.42460426174906063`, 0.9404735010185594],
              UndirectedEdge[101, 332] -> 
             RGBColor[
              0.8358893322460044, 0.27686671121426787`, 0.18200097113096422`],
              UndirectedEdge[58, 396] -> 
             RGBColor[
              0.18880077082680655`, 0.315771959172202, 0.9340632966416518], 
             UndirectedEdge[35, 387] -> 
             RGBColor[
              0.1878209095169145, 0.3147420628087102, 0.9340074949896282], 
             UndirectedEdge[198, 266] -> 
             RGBColor[0.74350964112616, 0.79962588641691, 0.9750508465456946],
              UndirectedEdge[188, 264] -> 
             RGBColor[
              0.26789407428573686`, 0.39890403591261847`, 0.9385675432655809],
              UndirectedEdge[119, 151] -> 
             RGBColor[
              0.22370106658388367`, 0.35245438281944674`, 0.9360508168546565],
              UndirectedEdge[247, 400] -> 
             RGBColor[
              0.8197269815986742, 0.15263580175167407`, 0.16652388589831657`],
              UndirectedEdge[305, 361] -> 
             RGBColor[
              0.353816749645949, 0.47989197268582956`, 0.9438020454927423], 
             UndirectedEdge[138, 210] -> 
             RGBColor[
              0.2672929528119248, 0.3982722191303392, 0.9385333102869269], 
             UndirectedEdge[197, 231] -> 
             RGBColor[
              0.19125913163260555`, 0.3183558522481745, 0.9342032966527232], 
             UndirectedEdge[225, 261] -> 
             RGBColor[
              0.19884280647751676`, 0.32632677534293286`, 0.9346351757160992],
              UndirectedEdge[83, 286] -> 
             RGBColor[
              0.6361141683386347, 0.7078159235332517, 0.9547721155282454], 
             UndirectedEdge[19, 238] -> 
             RGBColor[
              0.20019752611767563`, 0.32775067157892607`, 0.9347123249954781],
              UndirectedEdge[62, 117] -> 
             RGBColor[
              0.7751677288121797, 0.821679420316278, 0.8719418433976884], 
             UndirectedEdge[65, 167] -> 
             RGBColor[
              0.30615029923372655`, 0.43284997763222943`, 0.940975526215034], 
             UndirectedEdge[268, 371] -> 
             RGBColor[
              0.1838466718007321, 0.3105648869877775, 0.9337811680310495], 
             UndirectedEdge[172, 192] -> 
             RGBColor[
              0.31894488906729196`, 0.44600858518137365`, 0.9417147525123752],
              UndirectedEdge[52, 353] -> 
             RGBColor[
              0.9911272301605415, 0.9888543711683995, 0.6698997566881519], 
             UndirectedEdge[126, 298] -> 
             RGBColor[
              0.194012535572622, 0.32124985436502457`, 0.9343600989338109], 
             UndirectedEdge[146, 306] -> 
             RGBColor[
              0.2107146293415335, 0.33880481389005895`, 0.9353112584654169], 
             UndirectedEdge[21, 132] -> 
             RGBColor[
              0.1947709663990963, 0.3220470132509409, 0.9344032904473808], 
             UndirectedEdge[89, 162] -> 
             RGBColor[
              0.2137613905296329, 0.342007153074568, 0.9354847670077999], 
             UndirectedEdge[9, 18] -> 
             RGBColor[
              0.8394473584119997, 0.8706756474406323, 0.6991625748728455], 
             UndirectedEdge[255, 360] -> 
             RGBColor[
              0.5184721491114823, 0.6174970812936685, 0.956042445038614], 
             UndirectedEdge[124, 152] -> 
             RGBColor[
              0.2137312689052459, 0.34197549333751603`, 0.935483051625852], 
             UndirectedEdge[88, 389] -> 
             RGBColor[
              0.7117595806289345, 0.7674543626326005, 0.720767374949669], 
             UndirectedEdge[12, 167] -> 
             RGBColor[
              0.2392959832955554, 0.36884562905824225`, 0.9369389242907744], 
             UndirectedEdge[32, 303] -> 
             RGBColor[
              0.857724462248068, 0.3888260026114282, 0.20072238804006853`], 
             UndirectedEdge[49, 261] -> 
             RGBColor[
              0.1864507904031121, 0.31330198074953464`, 0.9339294687330069], 
             UndirectedEdge[283, 360] -> 
             RGBColor[
              0.7973390261209754, 0.7521357532053826, 0.6155512086405578], 
             UndirectedEdge[282, 305] -> 
             RGBColor[
              0.30654149170312617`, 0.4389445203793095, 0.9407897078604948], 
             UndirectedEdge[32, 385] -> 
             RGBColor[
              0.907968224972722, 0.5784385570350095, 0.40100320095353803`], 
             UndirectedEdge[167, 216] -> 
             RGBColor[
              0.22581143984224178`, 0.35467251891937396`, 0.9361709994897025],
              UndirectedEdge[252, 318] -> 
             RGBColor[
              0.20969889594004104`, 0.3377372136838731, 0.9352534139508448], 
             UndirectedEdge[2, 217] -> 
             RGBColor[
              0.20503618363244414`, 0.3328364074155535, 0.9349878793827919], 
             UndirectedEdge[305, 329] -> 
             RGBColor[
              0.28019918973537505`, 0.41183749243956935`, 0.9392683013866509],
              UndirectedEdge[87, 373] -> 
             RGBColor[
              0.19241687464340246`, 0.3195727135576686, 0.9342692284044607], 
             UndirectedEdge[20, 241] -> 
             RGBColor[
              0.33276855688740864`, 0.46007563309772936`, 0.9425189244607857],
              UndirectedEdge[59, 210] -> 
             RGBColor[
              0.23097654198013617`, 0.36010136875269116`, 0.9364651444153718],
              UndirectedEdge[290, 304] -> 
             RGBColor[
              0.2699001201696922, 0.4010125173273108, 0.9386817846109934], 
             UndirectedEdge[115, 312] -> 
             RGBColor[
              0.7514622050621471, 0.7517529361696669, 0.6201411074573389], 
             UndirectedEdge[214, 389] -> 
             RGBColor[
              0.9360223295752915, 0.7653959046667461, 0.35678534949539953`], 
             UndirectedEdge[144, 276] -> 
             RGBColor[
              0.48015124453344243`, 0.5868307576532874, 0.952775625742377], 
             UndirectedEdge[196, 286] -> 
             RGBColor[
              0.5826840049020053, 0.6656063435828412, 0.963342437992916], 
             UndirectedEdge[124, 181] -> 
             RGBColor[
              0.209370470104526, 0.33739201730734614`, 0.9352347105853747], 
             UndirectedEdge[216, 341] -> 
             RGBColor[
              0.2325799518711988, 0.3617866542102568, 0.9365564562366354], 
             UndirectedEdge[294, 340] -> 
             RGBColor[
              0.24056246391472638`, 0.3701767804885, 0.937011048488446], 
             UndirectedEdge[104, 235] -> 
             RGBColor[
              0.20864915250350596`, 0.3366338667744967, 0.9351936326150905], 
             UndirectedEdge[125, 318] -> 
             RGBColor[
              0.20302734583193666`, 0.33072499151954715`, 0.9348734790418622],
              UndirectedEdge[109, 232] -> 
             RGBColor[
              0.18655512715268852`, 0.3134116452886715, 0.9339354105565427], 
             UndirectedEdge[182, 388] -> 
             RGBColor[
              0.2563045573313864, 0.38672271877578024`, 0.9379075374201846], 
             UndirectedEdge[97, 382] -> 
             RGBColor[
              0.3103603612224796, 0.44230450028690405`, 0.9410311290958356], 
             UndirectedEdge[140, 147] -> 
             RGBColor[
              0.32678087214865287`, 0.45177394646584723`, 0.9422514665551494],
              UndirectedEdge[59, 300] -> 
             RGBColor[
              0.20621668709807878`, 0.3340771914061782, 0.9350551073087614], 
             UndirectedEdge[205, 373] -> 
             RGBColor[
              0.19156946915989134`, 0.31868203666588757`, 0.9342209699157987],
              UndirectedEdge[215, 259] -> 
             RGBColor[
              0.8007477962042493, 0.8448792898490222, 0.9806129038326282], 
             UndirectedEdge[136, 300] -> 
             RGBColor[
              0.18939860406094253`, 0.3164003198060953, 0.9340973423599207], 
             UndirectedEdge[152, 245] -> 
             RGBColor[
              0.19786899137363773`, 0.3253032339253123, 0.9345797183865636], 
             UndirectedEdge[44, 128] -> 
             RGBColor[
              0.26610768174908467`, 0.39702642409276845`, 0.9384658108533496],
              UndirectedEdge[241, 392] -> 
             RGBColor[
              0.24198676846575243`, 0.37167381487775275`, 0.9370921605255572],
              UndirectedEdge[240, 342] -> 
             RGBColor[
              0.18286346184170274`, 0.30953147098172573`, 0.9337251756784115],
              UndirectedEdge[123, 214] -> 
             RGBColor[
              0.8610395973659686, 0.437913767929313, 0.20482132414069976`], 
             UndirectedEdge[125, 274] -> 
             RGBColor[
              0.19786901158433057`, 0.32530325516803194`, 0.9345797195375327],
              UndirectedEdge[298, 373] -> 
             RGBColor[
              0.20172543232639267`, 0.32935659787913657`, 0.93479933699373], 
             UndirectedEdge[119, 350] -> 
             RGBColor[
              0.2941675459212899, 0.42283940615857285`, 0.9401985109723265], 
             UndirectedEdge[22, 179] -> 
             RGBColor[
              0.2344230766191157, 0.3637238951811761, 0.9366614194643705], 
             UndirectedEdge[1, 183] -> 
             RGBColor[
              0.18524860197516257`, 0.312038404488611, 0.9338610058805135], 
             UndirectedEdge[112, 260] -> 
             RGBColor[
              0.18468581634927816`, 0.3114468811131368, 0.9338289560716861], 
             UndirectedEdge[183, 270] -> 
             RGBColor[
              0.198314467229445, 0.32577145729456636`, 0.9346050875775294], 
             UndirectedEdge[152, 181] -> 
             RGBColor[
              0.1964830766390266, 0.32384654966716653`, 0.9345007925927047], 
             UndirectedEdge[169, 276] -> 
             RGBColor[
              0.41815198956691846`, 0.5364969694368562, 0.947894817280658], 
             UndirectedEdge[349, 355] -> 
             RGBColor[
              0.20327760071832918`, 0.33098802527222193`, 0.9348877306874234],
              UndirectedEdge[171, 240] -> 
             RGBColor[
              0.18369308464468964`, 0.3104034571487888, 0.9337724214697247], 
             UndirectedEdge[114, 132] -> 
             RGBColor[
              0.1897759122485969, 0.31679689463404087`, 0.9341188295030303], 
             UndirectedEdge[17, 222] -> 
             RGBColor[
              0.88937458998013, 0.5883335736307327, 0.570901233962067], 
             UndirectedEdge[46, 259] -> 
             RGBColor[
              0.850480547970673, 0.8837308935118651, 0.9855697997497163], 
             UndirectedEdge[13, 79] -> 
             RGBColor[
              0.20620705634176517`, 0.33406706887066745`, 0.9350545588514367],
              UndirectedEdge[146, 311] -> 
             RGBColor[
              0.20086274150294195`, 0.3284498551259324, 0.9347502080275711], 
             UndirectedEdge[44, 275] -> 
             RGBColor[
              0.21122882729611786`, 0.33934526854236047`, 0.9353405412782427],
              UndirectedEdge[193, 195] -> 
             RGBColor[
              0.6312732042379722, 0.7079049527832757, 0.9663404032043308], 
             UndirectedEdge[86, 297] -> 
             RGBColor[
              0.28232965171394053`, 0.4140767430581329, 0.9393896280445941], 
             UndirectedEdge[197, 392] -> 
             RGBColor[
              0.19718685275102665`, 0.3245862629828614, 0.9345408716011396], 
             UndirectedEdge[217, 392] -> 
             RGBColor[
              0.20565454435776198`, 0.333486343744197, 0.935023094111316], 
             UndirectedEdge[101, 193] -> 
             RGBColor[
              0.8459509404020927, 0.6447383034706259, 0.5918610769410064], 
             UndirectedEdge[216, 340] -> 
             RGBColor[
              0.2436041993290528, 0.3733738372661213, 0.9371842708204476], 
             UndirectedEdge[125, 190] -> 
             RGBColor[
              0.20237543357367466`, 0.3300397904024893, 0.934836353603172], 
             UndirectedEdge[99, 276] -> 
             RGBColor[
              0.6406056746670367, 0.7137792263922267, 0.9679520038982681], 
             UndirectedEdge[27, 63] -> 
             RGBColor[
              0.1971785692903057, 0.32457755654044196`, 0.9345403998703059], 
             UndirectedEdge[184, 226] -> 
             RGBColor[
              0.20272879549405032`, 0.3304111961852439, 0.9348564770417853], 
             UndirectedEdge[107, 211] -> 
             RGBColor[
              0.2277850924450354, 0.3567469529417126, 0.9362833960856742], 
             UndirectedEdge[216, 294] -> 
             RGBColor[
              0.21277466253925434`, 0.3409700393945122, 0.9354285743084811], 
             UndirectedEdge[68, 284] -> 
             RGBColor[
              0.7807346086845934, 0.8286481739482061, 0.9787765120052747], 
             UndirectedEdge[89, 359] -> 
             RGBColor[
              0.2789577626844565, 0.40896611709023306`, 0.9392549632713296], 
             UndirectedEdge[23, 267] -> 
             RGBColor[
              0.20474185831720654`, 0.33252705284793593`, 0.9349711179915043],
              UndirectedEdge[140, 242] -> 
             RGBColor[
              0.3733726074427579, 0.4978183191391804, 0.9450119502791875], 
             UndirectedEdge[64, 214] -> 
             RGBColor[
              0.9357533158900353, 0.7648205115954387, 0.32750487001527717`], 
             UndirectedEdge[296, 367] -> 
             RGBColor[
              0.18258473603098674`, 0.3092385124824261, 0.9337093026558292], 
             UndirectedEdge[275, 346] -> 
             RGBColor[
              0.1987852081376144, 0.3262662358357499, 0.9346318955758508], 
             UndirectedEdge[301, 305] -> 
             RGBColor[
              0.27396377293596785`, 0.4052836740351331, 0.9389132036243971], 
             UndirectedEdge[81, 119] -> 
             RGBColor[
              0.2344729010553813, 0.363776263822743, 0.9366642568923073], 
             UndirectedEdge[327, 355] -> 
             RGBColor[
              0.19695189529636073`, 0.3243393078008444, 0.9345274911216848], 
             UndirectedEdge[317, 344] -> 
             RGBColor[
              0.19003331843460333`, 0.31706744485602845`, 0.9341334884045249],
              UndirectedEdge[184, 190] -> 
             RGBColor[
              0.21285282401079259`, 0.34105219205682236`, 0.9354330254886557],
              UndirectedEdge[10, 303] -> 
             RGBColor[
              0.8684485783796092, 0.4712562585361081, 0.21099181375878928`], 
             UndirectedEdge[149, 268] -> 
             RGBColor[
              0.19899317290676588`, 0.326484819993856, 0.9346437388617977], 
             UndirectedEdge[38, 267] -> 
             RGBColor[
              0.22814489442186137`, 0.3571251276321197, 0.9363038862759752], 
             UndirectedEdge[253, 366] -> 
             RGBColor[
              0.9092462276793383, 0.5913616030865398, 0.3419442339894627], 
             UndirectedEdge[165, 355] -> 
             RGBColor[
              0.2168405199897158, 0.34524351336519876`, 0.9356601188753879], 
             UndirectedEdge[339, 340] -> 
             RGBColor[
              0.326674769743479, 0.4539173667672604, 0.9421628597566036], 
             UndirectedEdge[185, 318] -> 
             RGBColor[
              0.20300306708120197`, 0.33069947301316327`, 0.9348720964029251],
              UndirectedEdge[36, 70] -> 
             RGBColor[
              0.22130912604082534`, 0.3499403016509027, 0.9359145993792883], 
             UndirectedEdge[69, 131] -> 
             RGBColor[
              0.693464422361174, 0.75939366397809, 0.9708100489116116], 
             UndirectedEdge[283, 312] -> 
             RGBColor[
              0.7398695405352704, 0.7057918843470511, 0.6108133774642039], 
             UndirectedEdge[75, 330] -> 
             RGBColor[
              0.18530504232011252`, 0.31209772686967785`, 0.9338642200746624],
              UndirectedEdge[169, 222] -> 
             RGBColor[
              0.7041731063901011, 0.7666519834125803, 0.9590482629072343], 
             UndirectedEdge[90, 246] -> 
             RGBColor[
              0.21613530957472, 0.3445022925061154, 0.9356199581855191], 
             UndirectedEdge[62, 362] -> 
             RGBColor[
              0.8915373797700097, 0.913872404880224, 0.882662516799504], 
             UndirectedEdge[158, 374] -> 
             RGBColor[
              0.1873884527454699, 0.3142875233225789, 0.9339828672162569], 
             UndirectedEdge[82, 172] -> 
             RGBColor[
              0.5696909718954926, 0.6577404259092337, 0.9610497684809419], 
             UndirectedEdge[306, 346] -> 
             RGBColor[
              0.21286307171561503`, 0.3410629630443328, 0.9354336090802852], 
             UndirectedEdge[53, 188] -> 
             RGBColor[
              0.33920701496392514`, 0.465180569896386, 0.9429464497347737], 
             UndirectedEdge[84, 190] -> 
             RGBColor[
              0.21321988075352158`, 0.3414379919661722, 0.9354539288271424], 
             UndirectedEdge[78, 96] -> 
             RGBColor[
              0.2160474978393337, 0.3444099968046388, 0.9356149574370947], 
             UndirectedEdge[46, 199] -> 
             RGBColor[
              0.8971361136435547, 0.9188102209856679, 0.9087966349847089], 
             UndirectedEdge[159, 265] -> 
             RGBColor[
              0.19056897353088317`, 0.3176304523247132, 0.9341639931698273], 
             UndirectedEdge[332, 356] -> 
             RGBColor[
              0.8815942394619314, 0.5483248554027244, 0.5710094405269136], 
             UndirectedEdge[199, 222] -> 
             RGBColor[
              0.9699116219534045, 0.9763258350817114, 0.9020107810264453], 
             UndirectedEdge[114, 300] -> 
             RGBColor[
              0.19141939910096473`, 0.3185243035189643, 0.9342124236479517], 
             UndirectedEdge[139, 213] -> 
             RGBColor[
              0.3161784578429658, 0.4481129729732145, 0.941373691457378], 
             UndirectedEdge[106, 369] -> 
             RGBColor[
              0.18346224485360668`, 0.3101608298922725, 0.9337592754851194], 
             UndirectedEdge[109, 114] -> 
             RGBColor[
              0.18471405231964982`, 0.3114765589082613, 0.9338305640684275], 
             UndirectedEdge[58, 245] -> 
             RGBColor[
              0.1940488178607217, 0.32128798935024727`, 0.9343621651564433], 
             UndirectedEdge[151, 317] -> 
             RGBColor[
              0.1980582216182819, 0.3255021269103238, 0.9345904947690551], 
             UndirectedEdge[99, 218] -> 
             RGBColor[
              0.7312212189545854, 0.7893616865114603, 0.9745283770409688], 
             UndirectedEdge[55, 57] -> 
             RGBColor[
              0.5760181454967422, 0.6613528823456771, 0.9622434817439033], 
             UndirectedEdge[247, 287] -> 
             RGBColor[
              0.8173288724441594, 0.1342028839319411, 0.1642274538636763], 
             UndirectedEdge[44, 66] -> 
             RGBColor[
              0.21222031867993352`, 0.3403873888509353, 0.9353970052457711], 
             UndirectedEdge[116, 290] -> 
             RGBColor[
              0.24877546734729164`, 0.3788091678306199, 0.9374787668838809], 
             UndirectedEdge[278, 367] -> 
             RGBColor[
              0.18709347932173553`, 0.31397748755183885`, 0.9339660689161493],
              UndirectedEdge[102, 297] -> 
             RGBColor[
              0.32279739953618347`, 0.45288594084814915`, 0.9418305958510031],
              UndirectedEdge[104, 187] -> 
             RGBColor[
              0.2201981756238625, 0.34877262232435, 0.935851332396546], 
             UndirectedEdge[136, 371] -> 
             RGBColor[
              0.1813347042579621, 0.3079246498323852, 0.9336381151956117], 
             UndirectedEdge[80, 302] -> 
             RGBColor[
              0.1989040089899044, 0.3263911030639157, 0.9346386611086387], 
             UndirectedEdge[176, 373] -> 
             RGBColor[
              0.192094835712424, 0.3192342302227627, 0.9342508887637553], 
             UndirectedEdge[112, 219] -> 
             RGBColor[
              0.17968380010062157`, 0.30618944488965105`, 0.933544098646145], 
             UndirectedEdge[33, 179] -> 
             RGBColor[
              0.23670129905445042`, 0.3661184514083582, 0.9367911608617348], 
             UndirectedEdge[123, 334] -> 
             RGBColor[
              0.9016847000711192, 0.6050909598648562, 0.2444456182077174], 
             UndirectedEdge[94, 307] -> 
             RGBColor[
              0.17906784709075121`, 0.30554203922260087`, 0.9335090210334537],
              UndirectedEdge[73, 89] -> 
             RGBColor[
              0.21536881746289013`, 0.3436966606981754, 0.9355763075936738], 
             UndirectedEdge[267, 311] -> 
             RGBColor[
              0.20008010519765723`, 0.3276272547470704, 0.9347056380477918], 
             UndirectedEdge[52, 391] -> 
             RGBColor[
              0.904614436704831, 0.5731258147714826, 0.49953005146272567`], 
             UndirectedEdge[105, 271] -> 
             RGBColor[
              0.9026525217316504, 0.5714728168582255, 0.530015287474555], 
             UndirectedEdge[187, 377] -> 
             RGBColor[
              0.2355206370031677, 0.36487750073416236`, 0.9367239239045473], 
             UndirectedEdge[58, 124] -> 
             RGBColor[
              0.20991109539232988`, 0.337960248762451, 0.9352654983957317], 
             UndirectedEdge[11, 54] -> 
             RGBColor[
              0.9107233154962703, 0.8671374351819781, 0.6324945514745149], 
             UndirectedEdge[115, 283] -> 
             RGBColor[
              0.9435152073287729, 0.813763650039597, 0.2734092138294835], 
             UndirectedEdge[292, 362] -> 
             RGBColor[
              0.8053813952545528, 0.4938474279364584, 0.5730644519337977], 
             UndirectedEdge[15, 154] -> 
             RGBColor[
              0.18425132424679044`, 0.31099020236503183`, 0.933804212389223], 
             UndirectedEdge[158, 311] -> 
             RGBColor[
              0.19686826327665763`, 0.3242514052455602, 0.9345227284018851], 
             UndirectedEdge[123, 253] -> 
             RGBColor[
              0.8341751047564834, 0.26369040755053386`, 0.1803594249510559], 
             UndirectedEdge[236, 376] -> 
             RGBColor[
              0.397907468442853, 0.5154535439144465, 0.9470741986312354], 
             UndirectedEdge[206, 386] -> 
             RGBColor[
              0.3854076478953393, 0.5082424662804851, 0.9457788124146576], 
             UndirectedEdge[74, 338] -> 
             RGBColor[
              0.22933498443170014`, 0.35837598768852497`, 0.9363716601414551],
              UndirectedEdge[293, 394] -> 
             RGBColor[
              0.3358774325095808, 0.4653418831743506, 0.9426227908881267], 
             UndirectedEdge[41, 381] -> 
             RGBColor[
              0.19207190760239157`, 0.31921013132539244`, 0.934249583041808], 
             UndirectedEdge[59, 328] -> 
             RGBColor[
              0.22381201159438807`, 0.3525709930598068, 0.9360571350088763], 
             UndirectedEdge[123, 196] -> 
             RGBColor[
              0.8436412079731275, 0.6056407490965849, 0.5869779142171753], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.9124649507944522, 0.7523588106461282, 0.5992692091287142], 
             UndirectedEdge[23, 38] -> 
             RGBColor[
              0.23532272116707456`, 0.36466947864183974`, 0.936712652890472], 
             UndirectedEdge[61, 282] -> 
             RGBColor[
              0.2661448795948803, 0.3964851197604022, 0.9384891805623623], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.2249471629490288, 0.3537641091062871, 0.9361217801992172], 
             UndirectedEdge[3, 232] -> 
             RGBColor[
              0.21328768495463646`, 0.3415092584805786, 0.9354577901760884], 
             UndirectedEdge[110, 362] -> 
             RGBColor[
              0.8221167873663267, 0.8612297040031928, 0.982833840996466], 
             UndirectedEdge[125, 252] -> 
             RGBColor[
              0.19926974690677848`, 0.32677551680367367`, 0.934659489341944], 
             UndirectedEdge[49, 327] -> 
             RGBColor[
              0.18473066760764006`, 0.3114940226294092, 0.9338315102844983], 
             UndirectedEdge[89, 291] -> 
             RGBColor[
              0.2138432095506144, 0.34209315005324514`, 0.9354894264800044], 
             UndirectedEdge[34, 250] -> 
             RGBColor[
              0.1883288985198916, 0.31527599145920215`, 0.9340364242118455], 
             UndirectedEdge[125, 226] -> 
             RGBColor[
              0.1922514050569324, 0.3193987945309108, 0.9342598051563016], 
             UndirectedEdge[3, 14] -> 
             RGBColor[
              0.28743237026540935`, 0.41667525783150516`, 0.9397814519424676],
              UndirectedEdge[105, 345] -> 
             RGBColor[
              0.9066930101053883, 0.9269728190997042, 0.9383535848392048], 
             UndirectedEdge[88, 336] -> 
             RGBColor[
              0.33259846324686315`, 0.4556650882287947, 0.9426641835505155], 
             UndirectedEdge[162, 357] -> 
             RGBColor[
              0.1906502583880034, 0.3177158878633042, 0.9341686222221902], 
             UndirectedEdge[279, 328] -> 
             RGBColor[
              0.215194282730263, 0.3435132136280431, 0.9355663680988517], 
             UndirectedEdge[312, 359] -> 
             RGBColor[
              0.4367530973615871, 0.5501494570425497, 0.9497594529493274], 
             UndirectedEdge[202, 289] -> 
             RGBColor[
              0.4009029468034172, 0.5210963292936249, 0.9469229296248474], 
             UndirectedEdge[27, 48] -> 
             RGBColor[
              0.20648582903789775`, 0.33436007664951256`, 0.9350704345440743],
              UndirectedEdge[115, 193] -> 
             RGBColor[
              0.8965180032601808, 0.866664933881647, 0.6335702357029284], 
             UndirectedEdge[117, 385] -> 
             RGBColor[
              0.776474593776608, 0.8214741220909348, 0.7960777027150834], 
             UndirectedEdge[179, 352] -> 
             RGBColor[
              0.20659936567779108`, 0.3344794108566792, 0.9350769002877538], 
             UndirectedEdge[8, 365] -> 
             RGBColor[
              0.2808078228071327, 0.4124772043875522, 0.9393029621396956], 
             UndirectedEdge[105, 353] -> 
             RGBColor[
              0.9892810453920724, 0.988090926321853, 0.7004958160747115], 
             UndirectedEdge[231, 392] -> 
             RGBColor[
              0.1971344084334818, 0.32453114067996, 0.9345378849748398], 
             UndirectedEdge[109, 132] -> 
             RGBColor[
              0.1878121680467173, 0.3147328749692917, 0.9340069971758325], 
             UndirectedEdge[23, 158] -> 
             RGBColor[
              0.20153001639620693`, 0.3291512033464258, 0.9347882083455978], 
             UndirectedEdge[105, 350] -> 
             RGBColor[
              0.6669237794423443, 0.7322521297415084, 0.9183362922108259], 
             UndirectedEdge[172, 351] -> 
             RGBColor[
              0.3445890788111915, 0.47288747334073133`, 0.943177889287059], 
             UndirectedEdge[34, 375] -> 
             RGBColor[
              0.19286667153168213`, 0.3200454786060204, 0.9342948436718334], 
             UndirectedEdge[32, 391] -> 
             RGBColor[
              0.8208765397934485, 0.16147180977632267`, 0.16762470412387276`],
              UndirectedEdge[140, 241] -> 
             RGBColor[
              0.343629032390773, 0.46948243111537313`, 0.9432109443563187], 
             UndirectedEdge[89, 336] -> 
             RGBColor[
              0.23351345559029374`, 0.36276782580657996`, 0.9366096178924429],
              UndirectedEdge[74, 118] -> 
             RGBColor[
              0.3029906205258713, 0.4312899550504897, 0.9407311083477143], 
             UndirectedEdge[138, 328] -> 
             RGBColor[
              0.2601284224261766, 0.3907418434374549, 0.9381253008804314], 
             UndirectedEdge[189, 207] -> 
             RGBColor[
              0.2123454769342431, 0.3405189381117063, 0.935404132823199], 
             UndirectedEdge[273, 281] -> 
             RGBColor[
              0.46139853851670076`, 0.5721415288193888, 0.9511515046102453], 
             UndirectedEdge[49, 225] -> 
             RGBColor[
              0.19609003670444464`, 0.3234334397757498, 0.9344784095498806], 
             UndirectedEdge[43, 159] -> 
             RGBColor[
              0.1884193222929882, 0.31537103257792504`, 0.9340415737119533], 
             UndirectedEdge[113, 368] -> 
             RGBColor[
              0.18474082389280244`, 0.3115046975290605, 0.9338320886699134], 
             UndirectedEdge[11, 83] -> 
             RGBColor[0.9120888802991098, 0.9323447493793293, 0.977810506555],
              UndirectedEdge[151, 344] -> 
             RGBColor[
              0.1995874063553662, 0.3271093970249116, 0.9346775795776059], 
             UndirectedEdge[182, 377] -> 
             RGBColor[
              0.2482608696505907, 0.3782682930240088, 0.9374494613063329], 
             UndirectedEdge[198, 203] -> 
             RGBColor[
              0.5694035624452959, 0.6546305646490294, 0.9622535793690412], 
             UndirectedEdge[208, 395] -> 
             RGBColor[
              0.366549438606146, 0.4905837118311563, 0.9446256885343254], 
             UndirectedEdge[305, 339] -> 
             RGBColor[
              0.3400084902177303, 0.4679319523924049, 0.9429221954121405], 
             UndirectedEdge[9, 313] -> 
             RGBColor[
              0.4854882204226317, 0.5856947625868548, 0.9544467086526902], 
             UndirectedEdge[267, 317] -> 
             RGBColor[
              0.1930340826347562, 0.32022143828982824`, 0.9343043774864909], 
             UndirectedEdge[306, 350] -> 
             RGBColor[
              0.2854226113571807, 0.41364792547081863`, 0.9397004998858718], 
             UndirectedEdge[111, 362] -> 
             RGBColor[
              0.8089414952642664, 0.5212119166568898, 0.5764736077236575], 
             UndirectedEdge[104, 261] -> 
             RGBColor[
              0.20662637490864183`, 0.3345077992707875, 0.9350784384234943], 
             UndirectedEdge[243, 363] -> 
             RGBColor[
              0.302959879941956, 0.42967862832344433`, 0.9407871732432331], 
             UndirectedEdge[154, 369] -> 
             RGBColor[
              0.183389073095449, 0.31008392173509136`, 0.9337551084617403], 
             UndirectedEdge[218, 282] -> 
             RGBColor[
              0.4376499441056336, 0.5505879476107286, 0.9499100761220066], 
             UndirectedEdge[7, 293] -> 
             RGBColor[
              0.28453912176058604`, 0.41590127160719004`, 0.9395336796939777],
              UndirectedEdge[24, 167] -> 
             RGBColor[
              0.24799412206051685`, 0.37798792439406714`, 0.9374342704256958],
              UndirectedEdge[326, 363] -> 
             RGBColor[
              0.3080486907375876, 0.43502729111889293`, 0.9410769734898234], 
             UndirectedEdge[276, 282] -> 
             RGBColor[
              0.3470343998180849, 0.475005487491495, 0.9433337029793059], 
             UndirectedEdge[337, 345] -> 
             RGBColor[
              0.8925314756364031, 0.9165956294995268, 0.9705858474056119], 
             UndirectedEdge[107, 124] -> 
             RGBColor[
              0.22484989821780513`, 0.3536618777068309, 0.9361162411166642], 
             UndirectedEdge[128, 227] -> 
             RGBColor[
              0.28894688934847723`, 0.42103187936912945`, 0.9397664699385552],
              UndirectedEdge[25, 365] -> 
             RGBColor[
              0.33498940880084865`, 0.4643204052534886, 0.9425754453427104], 
             UndirectedEdge[97, 363] -> 
             RGBColor[
              0.3365752811245841, 0.4650105463059218, 0.9427015206110543], 
             UndirectedEdge[13, 373] -> 
             RGBColor[
              0.2056740334145861, 0.3335068279785967, 0.9350242039842707], 
             UndirectedEdge[64, 195] -> 
             RGBColor[
              0.7086017617355334, 0.7643768316855696, 0.6913028233561538], 
             UndirectedEdge[77, 96] -> 
             RGBColor[
              0.20429069166020342`, 0.3320528480858075, 0.9349454247178293], 
             UndirectedEdge[6, 53] -> 
             RGBColor[
              0.6643840547861006, 0.7335496374888852, 0.969847038397682], 
             UndirectedEdge[216, 343] -> 
             RGBColor[
              0.20826813355084325`, 0.33623339169725125`, 0.9351719341494034],
              UndirectedEdge[26, 324] -> 
             RGBColor[
              0.1839722969253371, 0.31069692695883033`, 0.9337883221960501], 
             UndirectedEdge[142, 281] -> 
             RGBColor[
              0.436455413320613, 0.55189157611022, 0.9491878904251312], 
             UndirectedEdge[100, 341] -> 
             RGBColor[
              0.3185278490681524, 0.4448223795517722, 0.9417183858910539], 
             UndirectedEdge[115, 364] -> 
             RGBColor[
              0.9382231077008898, 0.7927822385027005, 0.26915106624734497`], 
             UndirectedEdge[150, 152] -> 
             RGBColor[
              0.21962526952820027`, 0.3481704616934645, 0.9358187062419367], 
             UndirectedEdge[10, 68] -> 
             RGBColor[
              0.8322857283076943, 0.5959292773686855, 0.5858125997101122], 
             UndirectedEdge[190, 288] -> 
             RGBColor[
              0.21294330855938015`, 0.3411472970544397, 0.9354381784498378], 
             UndirectedEdge[23, 146] -> 
             RGBColor[
              0.20552449462249126`, 0.333349653226798, 0.9350156879712836], 
             UndirectedEdge[188, 201] -> 
             RGBColor[
              0.47076164268683474`, 0.5730017553920743, 0.9531670568538995], 
             UndirectedEdge[148, 382] -> 
             RGBColor[
              0.2893244860141426, 0.42019446169141983`, 0.9398331671225094], 
             UndirectedEdge[14, 71] -> 
             RGBColor[
              0.6541765961305002, 0.7223342652348994, 0.9394835143282855], 
             UndirectedEdge[228, 276] -> 
             RGBColor[
              0.3015266164865197, 0.4277543234766833, 0.9407208506945814], 
             UndirectedEdge[56, 174] -> 
             RGBColor[
              0.4681168777823908, 0.5781139671930625, 0.9515372200266019], 
             UndirectedEdge[16, 182] -> 
             RGBColor[
              0.23539065510704868`, 0.36474088152001305`, 0.9367165216278543],
              UndirectedEdge[104, 192] -> 
             RGBColor[
              0.24115781649194606`, 0.3708025337946915, 0.9370449529369735], 
             UndirectedEdge[145, 395] -> 
             RGBColor[
              0.3442769835307749, 0.46717394939172724`, 0.9433573051669275], 
             UndirectedEdge[219, 251] -> 
             RGBColor[
              0.1819264333571092, 0.30854659463338063`, 0.9336718132924233], 
             UndirectedEdge[150, 179] -> 
             RGBColor[
              0.23260992772492337`, 0.36181816073310025`, 0.9365581633171598],
              UndirectedEdge[73, 207] -> 
             RGBColor[
              0.1950145063297256, 0.32230298915935574`, 0.934417159686145], 
             UndirectedEdge[265, 325] -> 
             RGBColor[
              0.2186342581575027, 0.34712884590911136`, 0.9357622696104455], 
             UndirectedEdge[39, 314] -> 
             RGBColor[
              0.19046396107769498`, 0.3175200775782383, 0.9341580128659703], 
             UndirectedEdge[20, 263] -> 
             RGBColor[
              0.3432288815576954, 0.4710700975490908, 0.943114624476095], 
             UndirectedEdge[66, 146] -> 
             RGBColor[
              0.19762825714734855`, 0.3250502069900508, 0.9345660089285108], 
             UndirectedEdge[7, 21] -> 
             RGBColor[
              0.22580819870592864`, 0.3546691122796089, 0.9361708149117844], 
             UndirectedEdge[107, 167] -> 
             RGBColor[
              0.22944380789788385`, 0.3584903680512903, 0.9363778574768644], 
             UndirectedEdge[120, 195] -> 
             RGBColor[
              0.41858299206596217`, 0.5369772819597975, 0.9478927160094046], 
             UndirectedEdge[365, 388] -> 
             RGBColor[
              0.2883992345699991, 0.4204562594736305, 0.9397352818091035], 
             UndirectedEdge[134, 342] -> 
             RGBColor[
              0.18275455563161122`, 0.309417003649867, 0.9337189736308591], 
             UndirectedEdge[227, 311] -> 
             RGBColor[
              0.23829401063491945`, 0.3677924922631779, 0.9368818634300369], 
             UndirectedEdge[78, 377] -> 
             RGBColor[
              0.2375799153602678, 0.3670419328532635, 0.9368411967605548], 
             UndirectedEdge[21, 370] -> 
             RGBColor[
              0.19110729661804693`, 0.31819626402097745`, 0.9341946498732637],
              UndirectedEdge[2, 230] -> 
             RGBColor[
              0.2114753909347174, 0.33960442255956613`, 0.9353545827127028], 
             UndirectedEdge[24, 203] -> 
             RGBColor[
              0.2850956592214299, 0.4168671679331099, 0.9395514255934152], 
             UndirectedEdge[54, 206] -> 
             RGBColor[
              0.6885711015156095, 0.68922695188861, 0.6128856824256679], 
             UndirectedEdge[66, 130] -> 
             RGBColor[
              0.20589531196195676`, 0.3337394057617535, 0.9350368054701912], 
             UndirectedEdge[101, 356] -> 
             RGBColor[
              0.8996786533554004, 0.687329585228627, 0.5883270956947237], 
             UndirectedEdge[222, 383] -> 
             RGBColor[
              0.6547025238599551, 0.723910051109828, 0.9558664767641599], 
             UndirectedEdge[31, 247] -> 
             RGBColor[
              0.9007985668118983, 0.5610186106560575, 0.5373898372859729], 
             UndirectedEdge[46, 333] -> 
             RGBColor[
              0.8796565038002286, 0.9065288389378603, 0.9721902291244133], 
             UndirectedEdge[287, 385] -> 
             RGBColor[
              0.9058682917802197, 0.5622975503208443, 0.39899230255686247`], 
             UndirectedEdge[42, 330] -> 
             RGBColor[
              0.18629301045548374`, 0.31313614402075074`, 0.9339204833984038],
              UndirectedEdge[151, 227] -> 
             RGBColor[
              0.2408020759927813, 0.3704286279748189, 0.937024694041817], 
             UndirectedEdge[36, 382] -> 
             RGBColor[
              0.2838749254794549, 0.4144666280473688, 0.9395228227119613], 
             UndirectedEdge[218, 361] -> 
             RGBColor[
              0.4849252020484565, 0.5915353999172487, 0.952922413754254], 
             UndirectedEdge[196, 334] -> 
             RGBColor[
              0.9021680954325457, 0.8779962725880234, 0.6424622562871629], 
             UndirectedEdge[34, 265] -> 
             RGBColor[
              0.19096709589184307`, 0.31804890416849774`, 0.9341866656493147],
              UndirectedEdge[372, 392] -> 
             RGBColor[
              0.19150446236563495`, 0.31861371040345526`, 0.9342172678750348],
              UndirectedEdge[127, 210] -> 
             RGBColor[
              0.29252473138981117`, 0.4219611356100898, 0.9400738898749681], 
             UndirectedEdge[33, 157] -> 
             RGBColor[
              0.2467253832848012, 0.3766543994981055, 0.9373620176293496], 
             UndirectedEdge[139, 308] -> 
             RGBColor[
              0.25989565930435055`, 0.3904971946383813, 0.9381120453649856], 
             UndirectedEdge[38, 146] -> 
             RGBColor[
              0.2289275307271461, 0.3579477280109817, 0.9363484562557545], 
             UndirectedEdge[55, 68] -> 
             RGBColor[
              0.8126708442680417, 0.8535970039103761, 0.981959617507143], 
             UndirectedEdge[35, 392] -> 
             RGBColor[
              0.19658094676972326`, 0.3239494173798535, 0.934506366151862], 
             UndirectedEdge[51, 126] -> 
             RGBColor[
              0.1918840790772874, 0.31901271163649164`, 0.9342388864851707], 
             UndirectedEdge[130, 243] -> 
             RGBColor[
              0.22352868317149505`, 0.3522731969232867, 0.9360409998743393], 
             UndirectedEdge[12, 203] -> 
             RGBColor[
              0.2763975204564685, 0.40772487259728496`, 0.9390560794584938], 
             UndirectedEdge[182, 395] -> 
             RGBColor[
              0.3402542515552627, 0.4629458030295253, 0.9431282165320207], 
             UndirectedEdge[99, 382] -> 
             RGBColor[
              0.6121310294998102, 0.6891159199256546, 0.9661376246873524], 
             UndirectedEdge[17, 31] -> 
             RGBColor[
              0.9059600385832136, 0.6006919444617403, 0.5423324684832332], 
             UndirectedEdge[77, 78] -> 
             RGBColor[
              0.20870891214169546`, 0.33669667794321373`, 0.9351970358380788],
              UndirectedEdge[243, 344] -> 
             RGBColor[
              0.2114782278514492, 0.3396074043389222, 0.9353547442709138], 
             UndirectedEdge[305, 313] -> 
             RGBColor[
              0.29133850845533754`, 0.4235456226878492, 0.9399026691086074], 
             UndirectedEdge[189, 280] -> 
             RGBColor[
              0.2210513429116578, 0.3496693552377532, 0.9358999190114381], 
             UndirectedEdge[104, 208] -> 
             RGBColor[
              0.25923359532216883`, 0.3898013234158274, 0.9380743418006362], 
             UndirectedEdge[191, 335] -> 
             RGBColor[
              0.19113672012064215`, 0.3182271899877628, 0.9341963254982084], 
             UndirectedEdge[225, 355] -> 
             RGBColor[
              0.2083112643931653, 0.336278724947185, 0.9351743903870672], 
             UndirectedEdge[308, 348] -> 
             RGBColor[
              0.20697593141094872`, 0.33487520531787435`, 0.9350983451491781],
              UndirectedEdge[132, 149] -> 
             RGBColor[
              0.20160011613108555`, 0.32922488261236305`, 0.9347922004217959],
              UndirectedEdge[128, 224] -> 
             RGBColor[
              0.40082474260241224`, 0.5199417456186857, 0.9471108972900512], 
             UndirectedEdge[192, 225] -> 
             RGBColor[
              0.233374248060821, 0.36262150986683694`, 0.9366016902295785], 
             UndirectedEdge[84, 252] -> 
             RGBColor[
              0.2101141940866254, 0.33817371836735655`, 0.9352770645659143], 
             UndirectedEdge[30, 211] -> 
             RGBColor[
              0.21659401962004457`, 0.3449844258476482, 0.9356460810439997], 
             UndirectedEdge[138, 242] -> 
             RGBColor[
              0.31465187583145326`, 0.4451229547456037, 0.9413374842169753], 
             UndirectedEdge[27, 41] -> 
             RGBColor[
              0.1999138771125005, 0.32745253849010136`, 0.9346961716042546], 
             UndirectedEdge[102, 139] -> 
             RGBColor[
              0.3279891561400408, 0.4583428062151842, 0.9421262587090772], 
             UndirectedEdge[203, 329] -> 
             RGBColor[
              0.28617424693522586`, 0.4180008320067203, 0.9396128495680883], 
             UndirectedEdge[195, 312] -> 
             RGBColor[
              0.48621740603993846`, 0.5929929550712956, 0.9529112749587412], 
             UndirectedEdge[51, 87] -> 
             RGBColor[
              0.1940286984190197, 0.3212668425413722, 0.9343610193840024], 
             UndirectedEdge[83, 366] -> 
             RGBColor[
              0.9721424943326117, 0.9755215245830015, 0.7399924007909114], 
             UndirectedEdge[8, 302] -> 
             RGBColor[
              0.22515004974021374`, 0.353977355987588, 0.936133334301831], 
             UndirectedEdge[146, 344] -> 
             RGBColor[
              0.1953459036771252, 0.3226513087832781, 0.9344360322748211], 
             UndirectedEdge[67, 320] -> 
             RGBColor[
              0.1815572411564681, 0.30815855022236927`, 0.9336507883427678], 
             UndirectedEdge[90, 166] -> 
             RGBColor[
              0.23037172884023532`, 0.35946567179528754`, 0.9364307012017953],
              UndirectedEdge[12, 341] -> 
             RGBColor[
              0.2460644953245124, 0.3759597643491251, 0.9373243810377072], 
             UndirectedEdge[3, 13] -> 
             RGBColor[
              0.2247891692476987, 0.3535980477088099, 0.9361127826916571], 
             UndirectedEdge[153, 341] -> 
             RGBColor[
              0.22749742981872606`, 0.3564446012825976, 0.9362670141246647], 
             UndirectedEdge[192, 351] -> 
             RGBColor[
              0.2839106330866923, 0.41566367352388345`, 0.9394824007008676], 
             UndirectedEdge[12, 150] -> 
             RGBColor[
              0.24059607423843102`, 0.37021210706973123`, 0.937012962546659], 
             UndirectedEdge[99, 393] -> 
             RGBColor[
              0.8120689253181035, 0.8537779307522239, 0.9817268285297311], 
             UndirectedEdge[4, 190] -> 
             RGBColor[
              0.20649883851719153`, 0.33437375043709894`, 0.9350711754146743],
              UndirectedEdge[373, 390] -> 
             RGBColor[
              0.20548402624046883`, 0.3333071183914488, 0.9350133833567951], 
             UndirectedEdge[23, 308] -> 
             RGBColor[
              0.21238372481471685`, 0.3405591390591399, 0.9354063109834092], 
             UndirectedEdge[37, 187] -> 
             RGBColor[
              0.2503393326402117, 0.3804528894082654, 0.9375678266987812], 
             UndirectedEdge[17, 292] -> 
             RGBColor[
              0.8235767865158092, 0.18222708934004583`, 0.17021046343469787`],
              UndirectedEdge[309, 385] -> 
             RGBColor[
              0.845892139078253, 0.8769877648670494, 0.8021186290174642], 
             UndirectedEdge[140, 380] -> 
             RGBColor[
              0.5633644182821813, 0.6539330422248467, 0.9599388244578124], 
             UndirectedEdge[119, 354] -> 
             RGBColor[
              0.21794551615801888`, 0.3464049343988889, 0.9357230467724773], 
             UndirectedEdge[36, 305] -> 
             RGBColor[
              0.2718566625317226, 0.40306896740175535`, 0.9387932068040659], 
             UndirectedEdge[91, 351] -> 
             RGBColor[
              0.45106536887988224`, 0.5613307052601594, 0.9510072153286632], 
             UndirectedEdge[130, 275] -> 
             RGBColor[
              0.2049038205781411, 0.33269728545317867`, 0.934980341502663], 
             UndirectedEdge[46, 102] -> 
             RGBColor[
              0.5772856165740025, 0.6623742905041798, 0.9623565848838942], 
             UndirectedEdge[111, 271] -> 
             RGBColor[
              0.823307418706283, 0.18015661031829988`, 0.16995251651608806`], 
             UndirectedEdge[104, 351] -> 
             RGBColor[
              0.26680200623584566`, 0.3976814219540492, 0.9385080897116571], 
             UndirectedEdge[174, 203] -> 
             RGBColor[
              0.3639226125883841, 0.4896332085668736, 0.9444098049633691], 
             UndirectedEdge[294, 313] -> 
             RGBColor[
              0.24717525119128783`, 0.3771272391910956, 0.937387636941104], 
             UndirectedEdge[206, 266] -> 
             RGBColor[
              0.5435550579217713, 0.6394151913659053, 0.9575592073363473], 
             UndirectedEdge[167, 358] -> 
             RGBColor[
              0.25670178916857006`, 0.3871402346226134, 0.9379301591856604], 
             UndirectedEdge[315, 322] -> 
             RGBColor[
              0.18811052101816012`, 0.31504646285894905`, 0.9340239879361825],
              UndirectedEdge[176, 347] -> 
             RGBColor[
              0.18526445779187303`, 0.3120550699572905, 0.9338619088458187], 
             UndirectedEdge[92, 186] -> 
             RGBColor[
              0.20547576839988674`, 0.33329843887741967`, 0.9350129130849905],
              UndirectedEdge[149, 210] -> 
             RGBColor[
              0.22800345786551077`, 0.3569764688437995, 0.9362958316733276], 
             UndirectedEdge[171, 374] -> 
             RGBColor[
              0.18584495673726414`, 0.3126652111546555, 0.9338949674019874], 
             UndirectedEdge[228, 282] -> 
             RGBColor[
              0.26951575842165965`, 0.40002812713340913`, 0.938681147124779], 
             UndirectedEdge[164, 210] -> 
             RGBColor[
              0.23033673863294363`, 0.3594288948689166, 0.9364287085612534], 
             UndirectedEdge[196, 214] -> 
             RGBColor[
              0.8615229927273951, 0.7108190806524803, 0.6028379622201453], 
             UndirectedEdge[204, 307] -> 
             RGBColor[
              0.17948540198595286`, 0.30598091589196724`, 0.9335328001670183],
              UndirectedEdge[127, 255] -> 
             RGBColor[
              0.35677877005900877`, 0.4834455712278943, 0.9439546056344492], 
             UndirectedEdge[68, 334] -> 
             RGBColor[
              0.8909079727489195, 0.8690177564079877, 0.6413882557335685], 
             UndirectedEdge[16, 269] -> 
             RGBColor[
              0.29117851080203017`, 0.41924857896072276`, 0.9400447358569024],
              UndirectedEdge[68, 337] -> 
             RGBColor[
              0.8892917898500812, 0.9140123919924417, 0.970276843283211], 
             UndirectedEdge[23, 374] -> 
             RGBColor[
              0.19777812141168266`, 0.3252077238338092, 0.9345745434766604], 
             UndirectedEdge[22, 116] -> 
             RGBColor[
              0.24102708216235447`, 0.3706651237252555, 0.9370375078103073], 
             UndirectedEdge[192, 322] -> 
             RGBColor[
              0.2266888241245798, 0.3555947054294877, 0.936220965226608], 
             UndirectedEdge[70, 95] -> 
             RGBColor[
              0.22209777558797966`, 0.3507692223282312, 0.9359595118042963], 
             UndirectedEdge[71, 273] -> 
             RGBColor[
              0.7468748729151091, 0.8007044259307632, 0.9459207863964338], 
             UndirectedEdge[135, 215] -> 
             RGBColor[
              0.5207131115569171, 0.6175984363516078, 0.9569638659378303], 
             UndirectedEdge[161, 283] -> 
             RGBColor[
              0.9057344419097366, 0.6568662450460772, 0.2426421685015519], 
             UndirectedEdge[18, 384] -> 
             RGBColor[
              0.9630602947807589, 0.8804179575228263, 0.3471852898585644], 
             UndirectedEdge[71, 303] -> 
             RGBColor[
              0.9318169667814895, 0.7940843861143203, 0.5846862975193713], 
             UndirectedEdge[32, 353] -> 
             RGBColor[
              0.9073893332491589, 0.5772003661732394, 0.33799440934929903`], 
             UndirectedEdge[188, 281] -> 
             RGBColor[
              0.3372802138863956, 0.4635116716468679, 0.9428236756739168], 
             UndirectedEdge[54, 198] -> 
             RGBColor[
              0.8885256847199983, 0.8494376469396148, 0.6303773216350153], 
             UndirectedEdge[271, 385] -> 
             RGBColor[
              0.9072101681764545, 0.5726118003162909, 0.40027728490932957`], 
             UndirectedEdge[150, 206] -> 
             RGBColor[
              0.33364753302286965`, 0.45690710407047097`, 0.9427188232478589],
              UndirectedEdge[317, 346] -> 
             RGBColor[
              0.19596516131412245`, 0.3233021878229641, 0.9344712980811385], 
             UndirectedEdge[146, 243] -> 
             RGBColor[
              0.21526162835688684`, 0.343583998151584, 0.9355702033326591], 
             UndirectedEdge[91, 316] -> 
             RGBColor[
              0.6523585861658432, 0.7275841393423603, 0.9665060682236928], 
             UndirectedEdge[196, 386] -> 
             RGBColor[
              0.5930257483480736, 0.6745638419646864, 0.9640014047404548], 
             UndirectedEdge[151, 306] -> 
             RGBColor[
              0.21495613201977448`, 0.3432629021316925, 0.9355528057682019], 
             UndirectedEdge[27, 376] -> 
             RGBColor[
              0.24560585367761548`, 0.37547770289867644`, 0.937298262074416], 
             UndirectedEdge[280, 387] -> 
             RGBColor[
              0.19723551682458454`, 0.32463741200965124`, 0.9345436429481366],
              UndirectedEdge[308, 354] -> 
             RGBColor[
              0.20447448662716458`, 0.33224602824935756`, 0.9349558915692975],
              UndirectedEdge[327, 349] -> 
             RGBColor[
              0.19208902000720862`, 0.3192281175478443, 0.934250557567947], 
             UndirectedEdge[60, 108] -> 
             RGBColor[
              0.5066936953729514, 0.6051947855450721, 0.9560957540450186], 
             UndirectedEdge[353, 391] -> 
             RGBColor[
              0.9067470066576029, 0.5722631625212318, 0.3373793166798207], 
             UndirectedEdge[140, 195] -> 
             RGBColor[
              0.4154824656065883, 0.5342917617776789, 0.9476951532051012], 
             UndirectedEdge[17, 18] -> 
             RGBColor[
              0.9100987698336667, 0.6000343504740516, 0.3015369122339562], 
             UndirectedEdge[87, 205] -> 
             RGBColor[
              0.18600119174785296`, 0.31282942405665615`, 0.9339038647547113],
              UndirectedEdge[221, 256] -> 
             RGBColor[
              0.6811078585940378, 0.7429531062730206, 0.8609992027595657], 
             UndirectedEdge[194, 316] -> 
             RGBColor[
              0.5837905900380065, 0.6719175511327584, 0.9611081443956637], 
             UndirectedEdge[16, 37] -> 
             RGBColor[
              0.25664259349321183`, 0.38707801621458926`, 0.9379267880795208],
              UndirectedEdge[252, 288] -> 
             RGBColor[
              0.20983762189248398`, 0.33788302345562404`, 0.9352613141886098],
              UndirectedEdge[60, 353] -> 
             RGBColor[
              0.8501417981315751, 0.8795216745705272, 0.7395911022292926], 
             UndirectedEdge[206, 286] -> 
             RGBColor[
              0.375065904449271, 0.49928496789863985`, 0.9451198456671187], 
             UndirectedEdge[220, 396] -> 
             RGBColor[
              0.18205118127193512`, 0.30867771260133725`, 0.9336789175016247],
              UndirectedEdge[133, 320] -> 
             RGBColor[
              0.18355649439985816`, 0.3102598921411492, 0.9337646428573487], 
             UndirectedEdge[28, 231] -> 
             RGBColor[
              0.19140134234262995`, 0.31850532472108994`, 0.934211395342277], 
             UndirectedEdge[239, 269] -> 
             RGBColor[
              0.4302703250067166, 0.5456389418366184, 0.9490411897361934], 
             UndirectedEdge[212, 239] -> 
             RGBColor[
              0.542458414688152, 0.6394312043737607, 0.9571234599763494], 
             UndirectedEdge[77, 182] -> 
             RGBColor[
              0.21938986643201835`, 0.34792303811395897`, 0.9358053003838569],
              UndirectedEdge[280, 336] -> 
             RGBColor[
              0.22186501043454393`, 0.3505245713938071, 0.9359462561731533], 
             UndirectedEdge[199, 400] -> 
             RGBColor[
              0.9054254853432643, 0.5803013970083357, 0.502576064159955], 
             UndirectedEdge[73, 336] -> 
             RGBColor[
              0.2166564041388005, 0.3450499959322676, 0.9356496337500533], 
             UndirectedEdge[305, 340] -> 
             RGBColor[
              0.2847257211787761, 0.4165951639852536, 0.9395260806559493], 
             UndirectedEdge[259, 350] -> 
             RGBColor[
              0.6219849446227963, 0.6978827145935297, 0.9666587839790601], 
             UndirectedEdge[247, 393] -> 
             RGBColor[
              0.7696552520366986, 0.45850393020932284`, 0.5685799817696936], 
             UndirectedEdge[30, 216] -> 
             RGBColor[
              0.208257693184232, 0.33622241820998533`, 0.93517133958597], 
             UndirectedEdge[291, 387] -> 
             RGBColor[
              0.1905013026165654, 0.3175593259031815, 0.9341601394113672], 
             UndirectedEdge[45, 338] -> 
             RGBColor[
              0.2249286875668965, 0.3537446903082591, 0.9361207280535366], 
             UndirectedEdge[219, 248] -> 
             RGBColor[
              0.1809198934930053, 0.30748865741789405`, 0.933614492336205], 
             UndirectedEdge[158, 354] -> 
             RGBColor[
              0.1936207782086547, 0.3208380925366434, 0.9343377889314861], 
             UndirectedEdge[191, 327] -> 
             RGBColor[
              0.1848862258869851, 0.3116575242439654, 0.9338403690983792], 
             UndirectedEdge[165, 192] -> 
             RGBColor[
              0.24190350365737148`, 0.3715862982848506, 0.9370874187178992], 
             UndirectedEdge[143, 354] -> 
             RGBColor[
              0.1975023339396083, 0.32491785371472337`, 0.9345588377881168], 
             UndirectedEdge[115, 161] -> 
             RGBColor[
              0.9173271064366133, 0.7028272968686928, 0.25196989849468676`], 
             UndirectedEdge[296, 330] -> 
             RGBColor[
              0.18388840354746627`, 0.31060874969954066`, 0.9337835445922895],
              UndirectedEdge[45, 262] -> 
             RGBColor[
              0.30202723660803465`, 0.4296407358190505, 0.9406995556283282], 
             UndirectedEdge[37, 208] -> 
             RGBColor[
              0.289374752338518, 0.42148159049974276`, 0.9397908361028714], 
             UndirectedEdge[306, 348] -> 
             RGBColor[
              0.21170202637769384`, 0.33984263077965143`, 0.9353674892659032],
              UndirectedEdge[189, 263] -> 
             RGBColor[
              0.2675028819703037, 0.39849286798607286`, 0.9385452654419342], 
             UndirectedEdge[2, 50] -> 
             RGBColor[
              0.216476564027812, 0.3448609725730971, 0.935639392121782], 
             UndirectedEdge[241, 331] -> 
             RGBColor[
              0.26094013118712034`, 0.3915950008105146, 0.9381715264935517], 
             UndirectedEdge[135, 213] -> 
             RGBColor[
              0.33038430669065766`, 0.46058401368253077`, 0.9422727737683254],
              UndirectedEdge[49, 349] -> 
             RGBColor[
              0.19105637302960854`, 0.3181427401007867, 0.9341917498502368], 
             UndirectedEdge[256, 319] -> 
             RGBColor[
              0.9123741671932073, 0.6207364120366994, 0.4779545305476905], 
             UndirectedEdge[64, 332] -> 
             RGBColor[
              0.9051950840061846, 0.5622054525470171, 0.2995058419250193], 
             UndirectedEdge[213, 350] -> 
             RGBColor[
              0.33697931492905076`, 0.46629627834387477`, 0.942693001861539], 
             UndirectedEdge[333, 345] -> 
             RGBColor[
              0.8909301311153961, 0.9154013493777207, 0.9732965059821361], 
             UndirectedEdge[53, 201] -> 
             RGBColor[
              0.5341594365329997, 0.6309589682060907, 0.9570952074204189], 
             UndirectedEdge[9, 384] -> 
             RGBColor[
              0.8099718019563749, 0.7646503394906032, 0.6173962103853706], 
             UndirectedEdge[24, 33] -> 
             RGBColor[
              0.2533855843329195, 0.3836546930808141, 0.9377413062261555], 
             UndirectedEdge[20, 359] -> 
             RGBColor[
              0.3551576814248725, 0.48204146573128925`, 0.9438513113001545], 
             UndirectedEdge[35, 291] -> 
             RGBColor[
              0.19278015708719454`, 0.31995454643953136`, 0.9342899168022064],
              UndirectedEdge[316, 351] -> 
             RGBColor[
              0.5108480401165528, 0.6087959957654421, 0.956444390370581], 
             UndirectedEdge[195, 263] -> 
             RGBColor[
              0.3632251652657039, 0.4883898734545258, 0.9443887699919498], 
             UndirectedEdge[67, 200] -> 
             RGBColor[
              0.1867268102524256, 0.3135920951118324, 0.9339451876550904], 
             UndirectedEdge[232, 277] -> 
             RGBColor[
              0.18773724237763328`, 0.31465412334052256`, 0.9340027302698206],
              UndirectedEdge[88, 120] -> 
             RGBColor[
              0.42147179727410705`, 0.5394794198355211, 0.9480767881227974], 
             UndirectedEdge[247, 271] -> 
             RGBColor[
              0.8186707488403941, 0.14451713392738777`, 0.16551243621614334`],
              UndirectedEdge[202, 269] -> 
             RGBColor[
              0.34049741903328384`, 0.46934348329390774`, 0.9429171723441234],
              UndirectedEdge[207, 291] -> 
             RGBColor[
              0.19348889841744987`, 0.3206994785144255, 0.9343302785724756], 
             UndirectedEdge[72, 397] -> 
             RGBColor[
              0.4148581473336097, 0.5334192417760302, 0.947747040377775], 
             UndirectedEdge[200, 298] -> 
             RGBColor[
              0.19975642982426225`, 0.3272870514074283, 0.9346872052141117], 
             UndirectedEdge[233, 389] -> 
             RGBColor[
              0.9817271461205633, 0.9825466050438816, 0.7139976792857294], 
             UndirectedEdge[44, 311] -> 
             RGBColor[
              0.21545480303552692`, 0.34378703698681684`, 0.9355812043448313],
              UndirectedEdge[137, 258] -> 
             RGBColor[
              0.2651486396074914, 0.3960184099951701, 0.9384111948221615], 
             UndirectedEdge[46, 287] -> 
             RGBColor[
              0.8114277374548052, 0.49106874179706506`, 0.572735002859394], 
             UndirectedEdge[84, 274] -> 
             RGBColor[
              0.20871345876417752`, 0.33670145673171487`, 0.935197294761503], 
             UndirectedEdge[270, 357] -> 
             RGBColor[
              0.1969743042117703, 0.32436286099174727`, 0.9345287672762663], 
             UndirectedEdge[44, 344] -> 
             RGBColor[
              0.20993796520971017`, 0.3379884906441625, 0.9352670285920812], 
             UndirectedEdge[44, 383] -> 
             RGBColor[
              0.29331549171916627`, 0.4210403283755737, 0.9401830698485728], 
             UndirectedEdge[193, 364] -> 
             RGBColor[
              0.8796332391054209, 0.7997224705221349, 0.619984358127655], 
             UndirectedEdge[43, 375] -> 
             RGBColor[
              0.19874644987833204`, 0.3262254984478285, 0.9346296883503225], 
             UndirectedEdge[184, 252] -> 
             RGBColor[
              0.20974713734389644`, 0.3377879184580067, 0.9352561612274277], 
             UndirectedEdge[16, 78] -> 
             RGBColor[
              0.22470970081672578`, 0.3535145213492678, 0.9361082570820762], 
             UndirectedEdge[345, 353] -> 
             RGBColor[
              0.9106717648266294, 0.9268736116959997, 0.7456067906697404], 
             UndirectedEdge[167, 203] -> 
             RGBColor[
              0.2729080188918158, 0.40405718520565725`, 0.9388573575066418], 
             UndirectedEdge[329, 340] -> 
             RGBColor[
              0.2668654692611238, 0.39782290681442484`, 0.9385089657311141], 
             UndirectedEdge[193, 380] -> 
             RGBColor[
              0.7791551569135652, 0.8275462332304435, 0.978584074457042], 
             UndirectedEdge[115, 253] -> 
             RGBColor[
              0.8901501343784577, 0.5271850402949314, 0.22724725879350022`], 
             UndirectedEdge[113, 270] -> 
             RGBColor[
              0.196796775846464, 0.3241762674238618, 0.9345186572984918], 
             UndirectedEdge[121, 202] -> 
             RGBColor[
              0.2856578369982738, 0.41583248159385067`, 0.9396429608971655], 
             UndirectedEdge[17, 111] -> 
             RGBColor[
              0.8271368865255229, 0.20959157806047718`, 0.1736196192245576], 
             UndirectedEdge[73, 280] -> 
             RGBColor[
              0.2037203723071403, 0.3314534062854026, 0.9349129458743843], 
             UndirectedEdge[127, 242] -> 
             RGBColor[
              0.33988365440933965`, 0.4688118712253543, 0.9428780638050165], 
             UndirectedEdge[19, 211] -> 
             RGBColor[
              0.2160009516459515, 0.344361073804195, 0.9356123067002404], 
             UndirectedEdge[213, 345] -> 
             RGBColor[
              0.5767485455920949, 0.6610169677020706, 0.962710294489918], 
             UndirectedEdge[102, 350] -> 
             RGBColor[
              0.3487900132261258, 0.4765261115858444, 0.9434455691132382], 
             UndirectedEdge[81, 227] -> 
             RGBColor[
              0.2515739104642789, 0.38175050897811513`, 0.9376381340794677], 
             UndirectedEdge[144, 218] -> 
             RGBColor[
              0.5707667888209911, 0.662413217772521, 0.9593519988850778], 
             UndirectedEdge[130, 354] -> 
             RGBColor[
              0.2058823112495472, 0.3337257411887183, 0.9350360650988523], 
             UndirectedEdge[104, 327] -> 
             RGBColor[
              0.20490625211316982`, 0.332699841150662, 0.9349804799749857], 
             UndirectedEdge[10, 253] -> 
             RGBColor[
              0.8340797477746764, 0.2629574520026702, 0.18026811099758727`], 
             UndirectedEdge[40, 41] -> 
             RGBColor[
              0.19412189539412833`, 0.3213647984712409, 0.9343663268138622], 
             UndirectedEdge[5, 113] -> 
             RGBColor[
              0.18623312529560537`, 0.31307320092078017`, 0.9339170730271409],
              UndirectedEdge[271, 337] -> 
             RGBColor[
              0.8884909872626653, 0.561095627258048, 0.562247550040962], 
             UndirectedEdge[325, 376] -> 
             RGBColor[
              0.26222548998781436`, 0.392945994406499, 0.9382447257757333], 
             UndirectedEdge[52, 337] -> 
             RGBColor[
              0.9729869409703154, 0.9785763889719264, 0.8948788134240234], 
             UndirectedEdge[246, 260] -> 
             RGBColor[
              0.20281631365008554`, 0.33050318331620854`, 0.9348614610713], 
             UndirectedEdge[22, 290] -> 
             RGBColor[
              0.2497813465899759, 0.3798664106911086, 0.9375360502186867], 
             UndirectedEdge[24, 107] -> 
             RGBColor[
              0.2416314482274979, 0.371300350778743, 0.9370719255636378], 
             UndirectedEdge[314, 369] -> 
             RGBColor[
              0.1815795981118552, 0.30818204879999395`, 0.9336520615383029], 
             UndirectedEdge[187, 208] -> 
             RGBColor[
              0.25538258130493185`, 0.38575366351532014`, 0.9378550322494192],
              UndirectedEdge[9, 174] -> 
             RGBColor[
              0.5520972673558275, 0.6456190088987284, 0.9586092963260144], 
             UndirectedEdge[6, 303] -> 
             RGBColor[
              0.9100466794366213, 0.777602242030947, 0.6130122278904285], 
             UndirectedEdge[100, 198] -> 
             RGBColor[
              0.6082548805926754, 0.6882816237042615, 0.9647291510065205], 
             UndirectedEdge[101, 123] -> 
             RGBColor[
              0.8485657793755872, 0.374303438706794, 0.1941399512182521], 
             UndirectedEdge[210, 394] -> 
             RGBColor[
              0.30165291276591666`, 0.42986750752233627`, 0.9406555295205197],
              UndirectedEdge[213, 227] -> 
             RGBColor[
              0.29970260204538113`, 0.43079580390036054`, 0.94043541584355], 
             UndirectedEdge[32, 46] -> 
             RGBColor[
              0.8135276706473076, 0.5072097485112304, 0.5747459012560696], 
             UndirectedEdge[303, 391] -> 
             RGBColor[
              0.8570821356565119, 0.38388879895942046`, 0.20010729537059024`],
              UndirectedEdge[248, 251] -> 
             RGBColor[
              0.1839193268501145, 0.3106412520512747, 0.9337853056286283], 
             UndirectedEdge[239, 388] -> 
             RGBColor[
              0.38895939974165, 0.5063474161681534, 0.9465374152784297], 
             UndirectedEdge[205, 277] -> 
             RGBColor[
              0.18513416241600078`, 0.31191812125604473`, 0.9338544887169173],
              UndirectedEdge[308, 378] -> 
             RGBColor[
              0.22654239934249232`, 0.35544080369964637`, 0.9362126265518842],
              UndirectedEdge[119, 130] -> 
             RGBColor[
              0.2277266187202509, 0.3566854933495158, 0.936280066093552], 
             UndirectedEdge[28, 254] -> 
             RGBColor[
              0.1893368412328983, 0.3163354031578313, 0.9340938250582336], 
             UndirectedEdge[217, 314] -> 
             RGBColor[
              0.1955003640293088, 0.322813656406775, 0.9344448285633742], 
             UndirectedEdge[229, 307] -> 
             RGBColor[
              0.18847585942484443`, 0.31543045668816716`, 0.9340447934179733],
              UndirectedEdge[114, 155] -> 
             RGBColor[
              0.18628873221551898`, 0.3131316473192917, 0.933920239758967], 
             UndirectedEdge[226, 288] -> 
             RGBColor[
              0.20281928004263788`, 0.3305063011828612, 0.9348616300029674], 
             UndirectedEdge[217, 231] -> 
             RGBColor[
              0.19972682323934088`, 0.32725593300951006`, 0.9346855191628995],
              UndirectedEdge[151, 346] -> 
             RGBColor[
              0.2055192492348853, 0.3333441399918473, 0.9350153892542195], 
             UndirectedEdge[114, 180] -> 
             RGBColor[
              0.18755106204056693`, 0.3144584360017507, 0.9339921275750538], 
             UndirectedEdge[215, 345] -> 
             RGBColor[
              0.7670773504583543, 0.8180313903711476, 0.977401386659423], 
             UndirectedEdge[190, 252] -> 
             RGBColor[
              0.20904698368177904`, 0.3370520125668152, 0.9352162885121547], 
             UndirectedEdge[275, 311] -> 
             RGBColor[
              0.19837020308391207`, 0.32583003921146847`, 0.9346082616519875],
              UndirectedEdge[75, 320] -> 
             RGBColor[
              0.18280885155031829`, 0.3094740721029882, 0.933722065703106], 
             UndirectedEdge[169, 393] -> 
             RGBColor[
              0.5896152402179853, 0.6764956737968535, 0.9616696419121211], 
             UndirectedEdge[80, 182] -> 
             RGBColor[
              0.22246710481821064`, 0.35115741076602963`, 0.9359805445575843],
              UndirectedEdge[239, 362] -> 
             RGBColor[
              0.6492041088152176, 0.7238110272281775, 0.9670865002427318], 
             UndirectedEdge[171, 342] -> 
             RGBColor[
              0.18722373291059582`, 0.31411439233228555`, 0.933973486665342], 
             UndirectedEdge[107, 157] -> 
             RGBColor[
              0.2349712471793796, 0.36430005719603437`, 0.936692636966832], 
             UndirectedEdge[116, 286] -> 
             RGBColor[
              0.28063230469456346`, 0.41113725310534854`, 0.9393352740823563],
              UndirectedEdge[37, 117] -> 
             RGBColor[
              0.4214315538332871, 0.5343304799664346, 0.9489462154343377], 
             UndirectedEdge[111, 222] -> 
             RGBColor[
              0.8888497880747033, 0.5842997162159619, 0.5703986830647514], 
             UndirectedEdge[57, 72] -> 
             RGBColor[
              0.4069178401688355, 0.5265417468013449, 0.9472410910265736], 
             UndirectedEdge[8, 323] -> 
             RGBColor[
              0.3381102648791732, 0.4623620160236, 0.9429449845379104], 
             UndirectedEdge[115, 356] -> 
             RGBColor[
              0.9502457162134885, 0.9092562156396481, 0.6300362544566458], 
             UndirectedEdge[129, 391] -> 
             RGBColor[
              0.8197851875316053, 0.15308319805818565`, 0.1665796239654257], 
             UndirectedEdge[271, 303] -> 
             RGBColor[
              0.8569664054518005, 0.38299924589270967`, 0.19999647199586007`],
              UndirectedEdge[141, 196] -> 
             RGBColor[
              0.5999457128672814, 0.6805575674236943, 0.9644423387605343], 
             UndirectedEdge[8, 117] -> 
             RGBColor[
              0.40706513411417244`, 0.5192304619580248, 0.9481280690845475], 
             UndirectedEdge[278, 330] -> 
             RGBColor[
              0.18839714683821507`, 0.31534772476895345`, 0.9340403108526096],
              UndirectedEdge[95, 276] -> 
             RGBColor[
              0.3131382201938357, 0.4399588551912694, 0.9413821143478849], 
             UndirectedEdge[114, 268] -> 
             RGBColor[
              0.18716896902427724`, 0.3140568320155338, 0.9339703679430321], 
             UndirectedEdge[95, 148] -> 
             RGBColor[
              0.2518920934922597, 0.3820849395144922, 0.9376562541322015], 
             UndirectedEdge[236, 366] -> 
             RGBColor[
              0.7514680031030527, 0.8004311372612268, 0.7333352246803804], 
             UndirectedEdge[108, 378] -> 
             RGBColor[
              0.2733003143570183, 0.40458633700295354`, 0.938875420639825], 
             UndirectedEdge[33, 107] -> 
             RGBColor[
              0.23483527017028652`, 0.36415713673803723`, 0.9366848932773241],
              UndirectedEdge[309, 362] -> 
             RGBColor[
              0.7443188002522516, 0.8001867708802417, 0.9751504000206381], 
             UndirectedEdge[178, 278] -> 
             RGBColor[
              0.18555079143571185`, 0.31235602477156665`, 0.9338782151232425],
              UndirectedEdge[21, 232] -> 
             RGBColor[
              0.19351392550506752`, 0.32072578357032067`, 0.9343317038280912],
              UndirectedEdge[20, 140] -> 
             RGBColor[
              0.3954861818985797, 0.5169719858722439, 0.9464210076892463], 
             UndirectedEdge[33, 150] -> 
             RGBColor[
              0.24249803494618108`, 0.37221118836485045`, 0.9371212763952667],
              UndirectedEdge[38, 213] -> 
             RGBColor[
              0.2920695594579869, 0.42277299217815684`, 0.9400007253602725], 
             UndirectedEdge[86, 262] -> 
             RGBColor[
              0.31621623896980977`, 0.44455427693598626`, 0.9415075983220833],
              UndirectedEdge[17, 310] -> 
             RGBColor[
              0.8270891883762761, 0.20922494918390394`, 0.1735739434229715], 
             UndirectedEdge[222, 223] -> 
             RGBColor[
              0.9051519086820443, 0.7083288764559916, 0.5859596439831081], 
             UndirectedEdge[19, 124] -> 
             RGBColor[
              0.21306575741872125`, 0.34127599856931323`, 0.9354451517312304],
              UndirectedEdge[184, 274] -> 
             RGBColor[
              0.20834640202144852`, 0.33631565682236503`, 0.9351763914230165],
              UndirectedEdge[195, 360] -> 
             RGBColor[
              0.5436868916256435, 0.6393368239296271, 0.957649106135095], 
             UndirectedEdge[186, 378] -> 
             RGBColor[
              0.22340907061728948`, 0.35214747654494266`, 0.9360341881163283],
              UndirectedEdge[31, 169] -> 
             RGBColor[
              0.7207585549931849, 0.779010354243588, 0.9304794974284005], 
             UndirectedEdge[4, 84] -> 
             RGBColor[
              0.20756604892203795`, 0.3354954562376403, 0.935131951468434], 
             UndirectedEdge[81, 383] -> 
             RGBColor[
              0.2937367673363199, 0.42148311575961905`, 0.9402070608717483], 
             UndirectedEdge[327, 335] -> 
             RGBColor[
              0.19201380881889718`, 0.3191490658202642, 0.9342462744020376], 
             UndirectedEdge[11, 214] -> 
             RGBColor[
              0.8760571062553216, 0.722408188261647, 0.6042242389431952], 
             UndirectedEdge[15, 35] -> 
             RGBColor[
              0.1861148468094702, 0.312948882732563, 0.933910337242333], 
             UndirectedEdge[151, 354] -> 
             RGBColor[
              0.20185675911317996`, 0.3294946306586492, 0.934806815859957], 
             UndirectedEdge[91, 192] -> 
             RGBColor[
              0.4254211791359827, 0.5344518171008017, 0.9495440785539795], 
             UndirectedEdge[44, 130] -> 
             RGBColor[
              0.22198842052975598`, 0.350654283228527, 0.9359532841955067], 
             UndirectedEdge[195, 356] -> 
             RGBColor[
              0.6850009171912799, 0.7504962345412768, 0.9628064219580481], 
             UndirectedEdge[226, 315] -> 
             RGBColor[
              0.186507225222572, 0.3133612973229612, 0.9339326826124872], 
             UndirectedEdge[65, 206] -> 
             RGBColor[
              0.4026912595828178, 0.5232126620245969, 0.9468801088680859], 
             UndirectedEdge[287, 400] -> 
             RGBColor[
              0.8197171091545148, 0.15255991781973297`, 0.16651443203464028`],
              UndirectedEdge[247, 319] -> 
             RGBColor[
              0.8248915640805821, 0.1923330458420928, 0.17146949591555327`], 
             UndirectedEdge[55, 72] -> 
             RGBColor[
              0.6346370252408752, 0.7117938428167392, 0.9660702931075245], 
             UndirectedEdge[313, 329] -> 
             RGBColor[
              0.27347825653768526`, 0.4047733655170204, 0.9388855541837721], 
             UndirectedEdge[5, 357] -> 
             RGBColor[
              0.1864106536609117, 0.3132597944886656, 0.9339271830049154], 
             UndirectedEdge[39, 328] -> 
             RGBColor[
              0.21476290196670605`, 0.3430598050944246, 0.9355418016025379], 
             UndirectedEdge[310, 384] -> 
             RGBColor[
              0.8800507133233684, 0.4896085562326786, 0.2192223210475797], 
             UndirectedEdge[66, 344] -> 
             RGBColor[
              0.19384485664191092`, 0.32107361317738903`, 0.9343505498667657],
              UndirectedEdge[271, 391] -> 
             RGBColor[
              0.820118482997181, 0.15564505305760412`, 0.1668987880796643], 
             UndirectedEdge[203, 211] -> 
             RGBColor[
              0.27124930343896736`, 0.4023137700960795, 0.9387628961154517], 
             UndirectedEdge[100, 203] -> 
             RGBColor[
              0.3488608742001085, 0.47658748779993204`, 0.9434500843118405], 
             UndirectedEdge[323, 377] -> 
             RGBColor[
              0.3376579889612439, 0.46188664535790686`, 0.9429192280934666], 
             UndirectedEdge[351, 395] -> 
             RGBColor[
              0.37411784951982285`, 0.4984638103693781, 0.9450594364453463], 
             UndirectedEdge[179, 209] -> 
             RGBColor[
              0.24592936800917714`, 0.3758177369731411, 0.9373166857370019], 
             UndirectedEdge[283, 356] -> 
             RGBColor[
              0.9386530516866118, 0.8632951638170323, 0.6207085244635109], 
             UndirectedEdge[77, 80] -> 
             RGBColor[
              0.20002934434875747`, 0.3275739018764531, 0.9347027472925409], 
             UndirectedEdge[200, 398] -> 
             RGBColor[
              0.18742715801975252`, 0.3143282050199061, 0.933985071424368], 
             UndirectedEdge[280, 368] -> 
             RGBColor[
              0.19638103924398845`, 0.323739301895437, 0.934494981714008], 
             UndirectedEdge[3, 390] -> 
             RGBColor[
              0.22459916207358144`, 0.353398338121662, 0.9361019620641815], 
             UndirectedEdge[64, 380] -> 
             RGBColor[
              0.8564837144111264, 0.8840181121327374, 0.7035464946088651], 
             UndirectedEdge[139, 186] -> 
             RGBColor[
              0.2567623305791477, 0.38720386748367763`, 0.9379336069294297], 
             UndirectedEdge[160, 245] -> 
             RGBColor[
              0.19509478987731566`, 0.3223873722581438, 0.9344217317154114], 
             UndirectedEdge[64, 360] -> 
             RGBColor[
              0.8276703795499445, 0.8615089159497265, 0.7006746506658257], 
             UndirectedEdge[72, 337] -> 
             RGBColor[
              0.7112579708229148, 0.7722092308988048, 0.9543875188835923], 
             UndirectedEdge[11, 141] -> 
             RGBColor[
              0.6144798263952078, 0.6921466750328611, 0.9658286154835842], 
             UndirectedEdge[62, 223] -> 
             RGBColor[
              0.9255100897331807, 0.7222473691090705, 0.4948669383214451], 
             UndirectedEdge[351, 399] -> 
             RGBColor[
              0.33446531711843736`, 0.46411877979752536`, 0.9425328121440877],
              UndirectedEdge[205, 232] -> 
             RGBColor[
              0.18775686622597437`, 0.3146747492493529, 0.9340038478189527], 
             UndirectedEdge[175, 379] -> 
             RGBColor[
              0.1863024171876671, 0.3131460310926968, 0.9339210190978857], 
             UndirectedEdge[144, 339] -> 
             RGBColor[
              0.48160738498318656`, 0.5880919933231088, 0.9528684097242202], 
             UndirectedEdge[66, 275] -> 
             RGBColor[
              0.19513571872831864`, 0.3224303910755869, 0.9344240625529272], 
             UndirectedEdge[311, 346] -> 
             RGBColor[
              0.20301118387702347`, 0.33070800428020625`, 0.9348725586424393],
              UndirectedEdge[81, 326] -> 
             RGBColor[
              0.23536377630225702`, 0.36471263019196243`, 0.936714990919685], 
             UndirectedEdge[145, 335] -> 
             RGBColor[
              0.2240686969525251, 0.3528407856460005, 0.9360717528602902], 
             UndirectedEdge[24, 56] -> 
             RGBColor[
              0.3892899244154366, 0.5053479265592988, 0.9466788406566481], 
             UndirectedEdge[310, 319] -> 
             RGBColor[
              0.8294805357972241, 0.22760589335643167`, 0.17586390041391192`],
              UndirectedEdge[131, 303] -> 
             RGBColor[
              0.8540204827009316, 0.7329759435664439, 0.607655802146349], 
             UndirectedEdge[146, 317] -> 
             RGBColor[
              0.19381671894004093`, 0.32104403866869025`, 0.9343489474662702],
              UndirectedEdge[159, 321] -> 
             RGBColor[
              0.1833474210515813, 0.31004014279609426`, 0.9337527364394607], 
             UndirectedEdge[339, 361] -> 
             RGBColor[
              0.39576579821065194`, 0.5172141754678363, 0.9464388245933966], 
             UndirectedEdge[60, 297] -> 
             RGBColor[
              0.5017919184919047, 0.6000427072524873, 0.955816605103172], 
             UndirectedEdge[1, 368] -> 
             RGBColor[
              0.1828231865844723, 0.30948913913277776`, 0.9337228820620942], 
             UndirectedEdge[15, 106] -> 
             RGBColor[
              0.18432449600494816`, 0.311067110522213, 0.933808379412602], 
             UndirectedEdge[144, 282] -> 
             RGBColor[
              0.44814038646858245`, 0.5591045613100133, 0.9507359221725744], 
             UndirectedEdge[333, 391] -> 
             RGBColor[
              0.8870053729463696, 0.5607909002029526, 0.5650690319922165], 
             UndirectedEdge[85, 238] -> 
             RGBColor[
              0.19138550303315327`, 0.3184886766025597, 0.9342104933170345], 
             UndirectedEdge[130, 135] -> 
             RGBColor[
              0.27550933277442513`, 0.40444794828705827`, 0.9390913012054878],
              UndirectedEdge[194, 256] -> 
             RGBColor[
              0.7238719368935342, 0.7799355863354847, 0.863740011258672], 
             UndirectedEdge[129, 271] -> 
             RGBColor[
              0.8196694573268939, 0.15219364499147486`, 0.1664688005906955], 
             UndirectedEdge[12, 168] -> 
             RGBColor[
              0.22037492795635888`, 0.34895840023254887`, 0.9358613981804], 
             UndirectedEdge[32, 271] -> 
             RGBColor[
              0.8207608095887371, 0.16058225670961188`, 0.16751388074914259`],
              UndirectedEdge[227, 363] -> 
             RGBColor[
              0.3242588248996095, 0.45206516990504564`, 0.9420001166496061], 
             UndirectedEdge[351, 355] -> 
             RGBColor[
              0.2588476494190366, 0.38932088860423164`, 0.9380551008583563], 
             UndirectedEdge[70, 285] -> 
             RGBColor[
              0.1906202345698193, 0.31768433092677273`, 0.9341669124101608], 
             UndirectedEdge[19, 107] -> 
             RGBColor[
              0.211296993265781, 0.33941691529844853`, 0.9353444232293726], 
             UndirectedEdge[88, 359] -> 
             RGBColor[
              0.3780427703410259, 0.5018633795124479, 0.9453095289294022], 
             UndirectedEdge[128, 130] -> 
             RGBColor[
              0.2597826750311079, 0.39037844100358665`, 0.9381056110777697], 
             UndirectedEdge[72, 297] -> 
             RGBColor[
              0.3810483803734705, 0.5030082457772378, 0.9456339650216002], 
             UndirectedEdge[125, 184] -> 
             RGBColor[
              0.20307558723579205`, 0.3307756962936808, 0.934876226318445], 
             UndirectedEdge[41, 63] -> 
             RGBColor[
              0.19205972818458644`, 0.31919732998505956`, 0.9342488894419819],
              UndirectedEdge[67, 133] -> 
             RGBColor[
              0.1814057266970613, 0.30799929891896116`, 0.9336421598184501], 
             UndirectedEdge[272, 308] -> 
             RGBColor[
              0.20474955864050876`, 0.33253514637595527`, 0.9349715565135248],
              UndirectedEdge[199, 287] -> 
             RGBColor[
              0.9030273761887495, 0.5618684791886028, 0.5002796321253148], 
             UndirectedEdge[60, 333] -> 
             RGBColor[
              0.8304001644203418, 0.8680494122522482, 0.9672808175416883], 
             UndirectedEdge[86, 325] -> 
             RGBColor[
              0.25318562671626305`, 0.38344452494766296`, 0.9377299189356977],
              UndirectedEdge[77, 377] -> 
             RGBColor[
              0.22582310918113752`, 0.35468478413443216`, 0.9361716640412894],
              UndirectedEdge[62, 319] -> 
             RGBColor[
              0.9121241184522142, 0.6206330104563391, 0.4820984852913445], 
             UndirectedEdge[52, 199] -> 
             RGBColor[
              0.9888652062926342, 0.9896634908979279, 0.8341958778608433], 
             UndirectedEdge[57, 376] -> 
             RGBColor[
              0.31723897478085683`, 0.4471117135410761, 0.941511560889603], 
             UndirectedEdge[11, 161] -> 
             RGBColor[
              0.8763695857039919, 0.7238270844566292, 0.6044849794547379], 
             UndirectedEdge[155, 300] -> 
             RGBColor[
              0.19103033479495424`, 0.31811537226524556`, 0.9341902670112934],
              UndirectedEdge[81, 275] -> 
             RGBColor[
              0.21165010291327152`, 0.33978805592640576`, 0.9353645323014182],
              UndirectedEdge[100, 266] -> 
             RGBColor[
              0.5229669528809726, 0.6215828095678126, 0.9562473514884939], 
             UndirectedEdge[56, 266] -> 
             RGBColor[
              0.5883098999275997, 0.6764125091387695, 0.9608991949142476], 
             UndirectedEdge[82, 257] -> 
             RGBColor[
              0.8645894369328215, 0.89448136547207, 0.956668495179433], 
             UndirectedEdge[32, 259] -> 
             RGBColor[
              0.85847174370837, 0.5429301584289652, 0.5790636952869976], 
             UndirectedEdge[261, 355] -> 
             RGBColor[
              0.19867201809183277`, 0.32614726592096993`, 0.9346254495701933],
              UndirectedEdge[74, 179] -> 
             RGBColor[
              0.23767352171657924`, 0.3671403190687327, 0.9368465275040685], 
             UndirectedEdge[100, 174] -> 
             RGBColor[
              0.4027739307357637, 0.5232842676221057, 0.9468853766008484], 
             UndirectedEdge[208, 388] -> 
             RGBColor[
              0.28259974438226976`, 0.4143606275774112, 0.9394050094224892], 
             UndirectedEdge[249, 299] -> 
             RGBColor[
              0.186005835268804, 0.3128343046915919, 0.9339041291963601], 
             UndirectedEdge[58, 181] -> 
             RGBColor[
              0.19266290312611054`, 0.31983130509210156`, 0.9342832393625844],
              UndirectedEdge[271, 345] -> 
             RGBColor[
              0.8240432411662075, 0.5102555022323721, 0.5751262620695841], 
             UndirectedEdge[20, 89] -> 
             RGBColor[
              0.30842578765479933`, 0.4344898392135439, 0.9411326397648885], 
             UndirectedEdge[174, 358] -> 
             RGBColor[
              0.34771638286513834`, 0.47271625798382977`, 0.9434826066423876],
              UndirectedEdge[185, 274] -> 
             RGBColor[
              0.19784473283359588`, 0.32527773666164805`, 0.9345783368985956],
              UndirectedEdge[106, 314] -> 
             RGBColor[
              0.18463641563674799`, 0.3113949578320815, 0.9338261427741893], 
             UndirectedEdge[73, 387] -> 
             RGBColor[
              0.19202691052884113`, 0.31916283654811173`, 0.9342470205250366],
              UndirectedEdge[191, 261] -> 
             RGBColor[
              0.18660634868245718`, 0.3134654823640909, 0.9339383275468877], 
             UndirectedEdge[135, 227] -> 
             RGBColor[
              0.3046735470917944, 0.4351013866526011, 0.9407521600662733], 
             UndirectedEdge[102, 345] -> 
             RGBColor[
              0.5885592438891699, 0.6712468009440402, 0.9634628617416172], 
             UndirectedEdge[72, 108] -> 
             RGBColor[
              0.3859501572545172, 0.5081603240698226, 0.9459131139634468], 
             UndirectedEdge[7, 273] -> 
             RGBColor[
              0.3894971814838498, 0.5048902400899095, 0.9467521342900769], 
             UndirectedEdge[111, 385] -> 
             RGBColor[
              0.9105148340902678, 0.5980129106436974, 0.4034418367204835], 
             UndirectedEdge[25, 187] -> 
             RGBColor[
              0.29015449891481293`, 0.4171960722657919, 0.940022163552006], 
             UndirectedEdge[290, 338] -> 
             RGBColor[
              0.2338329245191738, 0.3631036079063329, 0.9366278111753308], 
             UndirectedEdge[133, 200] -> 
             RGBColor[
              0.18872606349581567`, 0.31569343703061226`, 0.9340590421696713],
              UndirectedEdge[64, 88] -> 
             RGBColor[
              0.7114905669436782, 0.7668789695612932, 0.6914868954695467], 
             UndirectedEdge[23, 92] -> 
             RGBColor[
              0.20814505737279243`, 0.33610403083063944`, 0.9351649251431382],
              UndirectedEdge[38, 350] -> 
             RGBColor[
              0.3036355127427933, 0.43279083959174136`, 0.9407376976762094], 
             UndirectedEdge[135, 224] -> 
             RGBColor[
              0.41655140034572946`, 0.5340112529021572, 0.9480965874177693], 
             UndirectedEdge[329, 358] -> 
             RGBColor[
              0.26996801721198005`, 0.40108388142367646`, 0.9386856512471069],
              UndirectedEdge[4, 185] -> 
             RGBColor[
              0.1966973229914563, 0.32407173616757357`, 0.9345129936055264], 
             UndirectedEdge[111, 199] -> 
             RGBColor[
              0.9076739184987976, 0.597583839511456, 0.5047291662889358], 
             UndirectedEdge[138, 264] -> 
             RGBColor[
              0.27444206081652406`, 0.4057863849228008, 0.9389404414116314], 
             UndirectedEdge[275, 344] -> 
             RGBColor[
              0.19285336525809532`, 0.32003149286881416`, 0.9342940858992375],
              UndirectedEdge[300, 371] -> 
             RGBColor[
              0.1880971018774196, 0.31503235849120814`, 0.934023223735969], 
             UndirectedEdge[69, 273] -> 
             RGBColor[
              0.5484319039049934, 0.644280752022615, 0.9575937149291112], 
             UndirectedEdge[65, 174] -> 
             RGBColor[
              0.39716489293029483`, 0.5184260009934458, 0.9465279736717613], 
             UndirectedEdge[217, 254] -> 
             RGBColor[
              0.1976623221296092, 0.32508601144625143`, 0.934567948878856], 
             UndirectedEdge[102, 378] -> 
             RGBColor[
              0.29463589617818253`, 0.42328641527644917`, 0.9402268398959757],
              UndirectedEdge[246, 326] -> 
             RGBColor[
              0.22913658446266597`, 0.35816745674178546`, 0.9363603615567251],
              UndirectedEdge[120, 242] -> 
             RGBColor[
              0.3764731339021319, 0.500503839321299, 0.9452095130834909], 
             UndirectedEdge[25, 117] -> 
             RGBColor[
              0.4612467201078884, 0.5710736628239611, 0.9514005522875624], 
             UndirectedEdge[44, 227] -> 
             RGBColor[
              0.25115263484712524`, 0.3813077215940698, 0.9376141430562922], 
             UndirectedEdge[118, 206] -> 
             RGBColor[
              0.39316789594043106`, 0.5149640030957358, 0.9462732885579729], 
             UndirectedEdge[151, 158] -> 
             RGBColor[
              0.19937632863451948`, 0.3268875409572013, 0.9346655590136652], 
             UndirectedEdge[151, 308] -> 
             RGBColor[
              0.2102300370530294, 0.33829547666991544`, 0.9352836616514766], 
             UndirectedEdge[298, 390] -> 
             RGBColor[
              0.2092243065114207, 0.3372383901036854, 0.935226386784977], 
             UndirectedEdge[62, 111] -> 
             RGBColor[
              0.9092079691258396, 0.5982182088690406, 0.47930597740308856`], 
             UndirectedEdge[131, 201] -> 
             RGBColor[
              0.7399124857733206, 0.7967445245200704, 0.9747112197727283], 
             UndirectedEdge[291, 368] -> 
             RGBColor[
              0.1896468250359693, 0.3166612157889672, 0.9341114781772385], 
             UndirectedEdge[35, 73] -> 
             RGBColor[
              0.19430576499947028`, 0.3215580570844616, 0.9343767979158759], 
             UndirectedEdge[273, 293] -> 
             RGBColor[
              0.4190878106551068, 0.5354941029446921, 0.9484555024448121], 
             UndirectedEdge[4, 274] -> 
             RGBColor[
              0.2019924165278475, 0.3296372152026416, 0.934814541349035], 
             UndirectedEdge[10, 337] -> 
             RGBColor[
              0.8999731601904741, 0.6493526399014464, 0.5732428918038912], 
             UndirectedEdge[27, 265] -> 
             RGBColor[
              0.20201462184730384`, 0.32966055440128883`, 0.9348158059091283],
              UndirectedEdge[262, 325] -> 
             RGBColor[
              0.3013026030921642, 0.42887910004945207`, 0.9406582888215985], 
             UndirectedEdge[46, 337] -> 
             RGBColor[
              0.8812578483212357, 0.9077231190596664, 0.969479570547889], 
             UndirectedEdge[322, 327] -> 
             RGBColor[
              0.19043725974580353`, 0.3174920127854582, 0.9341564922646202], 
             UndirectedEdge[59, 299] -> 
             RGBColor[
              0.20233103571342284`, 0.3299931254363777, 0.9348338252107113], 
             UndirectedEdge[254, 369] -> 
             RGBColor[
              0.1837415562121556, 0.31045440383947037`, 0.9337751818537847], 
             UndirectedEdge[262, 376] -> 
             RGBColor[
              0.3252561022413611, 0.4540557463948223, 0.9420224051621189], 
             UndirectedEdge[360, 389] -> 
             RGBColor[
              0.8279393932352007, 0.862084309021034, 0.7299551301459482], 
             UndirectedEdge[159, 381] -> 
             RGBColor[
              0.18574510039169012`, 0.3125602558041992, 0.9338892807308311], 
             UndirectedEdge[77, 302] -> 
             RGBColor[
              0.19582677060371215`, 0.3231567304118451, 0.9344634169349113], 
             UndirectedEdge[67, 398] -> 
             RGBColor[
              0.18010682122099816`, 0.306634066908255, 0.9335681890731469], 
             UndirectedEdge[12, 100] -> 
             RGBColor[
              0.315248838603848, 0.44137593165251704`, 0.941531651095973], 
             UndirectedEdge[329, 339] -> 
             RGBColor[
              0.322148238300078, 0.44915969522157617`, 0.9419050804873051], 
             UndirectedEdge[1, 113] -> 
             RGBColor[
              0.18373091059218155`, 0.31044321461790636`, 0.9337745756014759],
              UndirectedEdge[232, 390] -> 
             RGBColor[
              0.20167142330655186`, 0.3292998309749142, 0.9347962612599492], 
             UndirectedEdge[319, 384] -> 
             RGBColor[
              0.8830145607989899, 0.5123899866965502, 0.22206050473742173`], 
             UndirectedEdge[342, 374] -> 
             RGBColor[
              0.18501533393427727`, 0.31179322498759243`, 0.9338477216106742],
              UndirectedEdge[200, 320] -> 
             RGBColor[
              0.18887757795522245`, 0.31585268833402036`, 0.934067670693989], 
             UndirectedEdge[35, 231] -> 
             RGBColor[
              0.19065322565130216`, 0.31771900664516656`, 0.9341687912034454],
              UndirectedEdge[96, 104] -> 
             RGBColor[
              0.21783923349947054`, 0.34629322458604483`, 0.935716994132304], 
             UndirectedEdge[106, 197] -> 
             RGBColor[
              0.18891531916432497`, 0.315892356737718, 0.9340698200000144], 
             UndirectedEdge[41, 265] -> 
             RGBColor[
              0.19689578074158462`, 0.3242803278459065, 0.9345242954808043], 
             UndirectedEdge[52, 303] -> 
             RGBColor[
              0.9414623591594504, 0.8004800076065881, 0.5326277353789215], 
             UndirectedEdge[170, 208] -> 
             RGBColor[
              0.26496099146250607`, 0.3958211798972109, 0.9384005085379051], 
             UndirectedEdge[49, 355] -> 
             RGBColor[
              0.19591924831876065`, 0.3232539303537868, 0.9344686834039748], 
             UndirectedEdge[140, 359] -> 
             RGBColor[
              0.36601815692823686`, 0.491448263748933, 0.9445433311956875], 
             UndirectedEdge[20, 255] -> 
             RGBColor[
              0.37940724758906264`, 0.5030452211240766, 0.9453964722130872], 
             UndirectedEdge[117, 362] -> 
             RGBColor[
              0.6749012549506066, 0.7446731281041272, 0.9691094737182575], 
             UndirectedEdge[188, 293] -> 
             RGBColor[
              0.29496948602480166`, 0.4268642457721712, 0.9401276735084836], 
             UndirectedEdge[149, 155] -> 
             RGBColor[
              0.19811293609800762`, 0.3255596352976139, 0.9345936106777326], 
             UndirectedEdge[7, 188] -> 
             RGBColor[
              0.2653788568535447, 0.3962603829173885, 0.9384243053537484], 
             UndirectedEdge[120, 331] -> 
             RGBColor[
              0.3267582826576653, 0.45117687376714777`, 0.9422711725263158], 
             UndirectedEdge[169, 218] -> 
             RGBColor[
              0.5087675338544672, 0.6120794295560898, 0.9544711904233589], 
             UndirectedEdge[345, 350] -> 
             RGBColor[
              0.5883144988769012, 0.6710348151156551, 0.9634472668058549], 
             UndirectedEdge[147, 217] -> 
             RGBColor[
              0.2277310230294914, 0.3566901225577769, 0.9362803169124476], 
             UndirectedEdge[141, 386] -> 
             RGBColor[
              0.348846857880801, 0.4765753475686286, 0.9434491912043683], 
             UndirectedEdge[128, 383] -> 
             RGBColor[
              0.3311097462205182, 0.46076448615063337`, 0.9423353967308358], 
             UndirectedEdge[138, 394] -> 
             RGBColor[
              0.32326515413332657`, 0.4525833434947314, 0.9418863146939478], 
             UndirectedEdge[132, 300] -> 
             RGBColor[
              0.1945175148280322, 0.3217806195799947, 0.9343888567553567], 
             UndirectedEdge[103, 122] -> 
             RGBColor[
              0.1920779072643653, 0.3192164373505274, 0.9342499247136817], 
             UndirectedEdge[147, 195] -> 
             RGBColor[
              0.3359166803532971, 0.45968692435363845`, 0.9428335921754714], 
             UndirectedEdge[123, 389] -> 
             RGBColor[
              0.9181405448210238, 0.6602175731108506, 0.3409253014924295], 
             UndirectedEdge[93, 394] -> 
             RGBColor[
              0.35007693853437594`, 0.4776407816051039, 0.9435275708558966], 
             UndirectedEdge[199, 350] -> 
             RGBColor[
              0.6686405102956781, 0.7329620420673324, 0.8898856192140527], 
             UndirectedEdge[66, 158] -> 
             RGBColor[
              0.19363377892106423`, 0.3208517571096786, 0.934338529302825], 
             UndirectedEdge[105, 215] -> 
             RGBColor[
              0.8456866310237973, 0.8792487049970009, 0.932290412064394], 
             UndirectedEdge[253, 364] -> 
             RGBColor[
              0.8732653702236979, 0.4602425769354192, 0.2136613812182268], 
             UndirectedEdge[76, 78] -> 
             RGBColor[
              0.2517003601981642, 0.38188341566580475`, 0.9376453352047469], 
             UndirectedEdge[153, 358] -> 
             RGBColor[
              0.24162422522743635`, 0.37129275894771363`, 0.9370715142244698],
              UndirectedEdge[54, 64] -> 
             RGBColor[
              0.970419525130984, 0.9095497585157698, 0.3557751825465969], 
             UndirectedEdge[84, 125] -> 
             RGBColor[
              0.20344264397852102`, 0.33116149620303065`, 0.9348971296569317],
              UndirectedEdge[195, 380] -> 
             RGBColor[
              0.5725002264868254, 0.6618460201126379, 0.9605209500781344], 
             UndirectedEdge[81, 146] -> 
             RGBColor[
              0.2141426413323014, 0.3424078718408697, 0.9355064786770019], 
             UndirectedEdge[275, 317] -> 
             RGBColor[
              0.19132418052101102`, 0.3184242227542263, 0.9342070010906866], 
             UndirectedEdge[25, 377] -> 
             RGBColor[
              0.3093279743113551, 0.4373486105761115, 0.941114064611224], 
             UndirectedEdge[180, 232] -> 
             RGBColor[
              0.18939213687360562`, 0.3163935223821609, 0.9340969740631693], 
             UndirectedEdge[52, 333] -> 
             RGBColor[
              0.9713855964493081, 0.9773821088501203, 0.8975894720005477], 
             UndirectedEdge[97, 276] -> 
             RGBColor[
              0.33883500638970604`, 0.46696780675347616`, 0.9428455083067513],
              UndirectedEdge[51, 390] -> 
             RGBColor[
              0.2070958500160861, 0.33500124737515247`, 0.935105174336337], 
             UndirectedEdge[199, 393] -> 
             RGBColor[
              0.8553537557812887, 0.8861695254659845, 0.9046321600313321], 
             UndirectedEdge[169, 224] -> 
             RGBColor[
              0.4775031351026399, 0.5866975822042433, 0.9520099424283488], 
             UndirectedEdge[132, 268] -> 
             RGBColor[
              0.19026708475134468`, 0.3173131480765642, 0.9341468010504371], 
             UndirectedEdge[162, 183] -> 
             RGBColor[
              0.1919904214056781, 0.3191244841661233, 0.9342449425234534], 
             UndirectedEdge[15, 231] -> 
             RGBColor[
              0.18666830847322874`, 0.31353060603266947`, 0.9339418560653108],
              UndirectedEdge[246, 248] -> 
             RGBColor[
              0.19980719089443424`, 0.32734040451061686`, 0.9346900959819637],
              UndirectedEdge[44, 81] -> 
             RGBColor[
              0.22873470286488637`, 0.35774505370175413`, 0.9363374749942621],
              UndirectedEdge[39, 197] -> 
             RGBColor[
              0.19474286460527196`, 0.3220174764838748, 0.9344016900917953], 
             UndirectedEdge[57, 86] -> 
             RGBColor[
              0.30819911150930557`, 0.43761024408224003`, 0.9409967540495674],
              UndirectedEdge[74, 209] -> 
             RGBColor[
              0.2567896978925637, 0.3872326322652657, 0.9379351654574425], 
             UndirectedEdge[115, 389] -> 
             RGBColor[
              0.9741155744429982, 0.9237122058552483, 0.3878131353348738], 
             UndirectedEdge[157, 168] -> 
             RGBColor[
              0.222412865673202, 0.35110040198566517`, 0.9359774557185156], 
             UndirectedEdge[224, 363] -> 
             RGBColor[
              0.4361366781535445, 0.5509750361546019, 0.9493445440011021], 
             UndirectedEdge[47, 279] -> 
             RGBColor[
              0.19002059109890063`, 0.3170540676192452, 0.934132763601585], 
             UndirectedEdge[58, 352] -> 
             RGBColor[
              0.18979453396815193`, 0.3168164672419784, 0.9341198899824106], 
             UndirectedEdge[101, 161] -> 
             RGBColor[
              0.8667600435785252, 0.4809006664576717, 0.21026073973276477`], 
             UndirectedEdge[23, 98] -> 
             RGBColor[
              0.2025842284056299, 0.3302592470092312, 0.9348482441599675], 
             UndirectedEdge[37, 388] -> 
             RGBColor[
              0.27755649571754953`, 0.4090598534703564, 0.9391178038718512], 
             UndirectedEdge[13, 21] -> 
             RGBColor[
              0.2050154097981298, 0.332814572798552, 0.9349866963436598], 
             UndirectedEdge[159, 375] -> 
             RGBColor[
              0.19246854917072223`, 0.3196270267622359, 0.9342721711923458], 
             UndirectedEdge[130, 346] -> 
             RGBColor[
              0.20954480137125253`, 0.3375752505219164, 0.9352446384931148], 
             UndirectedEdge[104, 225] -> 
             RGBColor[
              0.2162656212099744, 0.3446392582970026, 0.935627379240368], 
             UndirectedEdge[226, 252] -> 
             RGBColor[
              0.19892295516503677`, 0.32641101669523676`, 0.9346397400652842],
              UndirectedEdge[64, 283] -> 
             RGBColor[
              0.9622538962308652, 0.8771757609613251, 0.3492049258616166], 
             UndirectedEdge[262, 284] -> 
             RGBColor[
              0.5520990373737982, 0.6433480852372535, 0.9595712205145508], 
             UndirectedEdge[282, 313] -> 
             RGBColor[
              0.2998205585054363, 0.43188039345676055`, 0.940406960657616], 
             UndirectedEdge[88, 360] -> 
             RGBColor[
              0.5465756968337885, 0.6418389618053506, 0.9578331782484879], 
             UndirectedEdge[210, 230] -> 
             RGBColor[
              0.2334030426063412, 0.36265177475985827`, 0.9366033300363481], 
             UndirectedEdge[2, 138] -> 
             RGBColor[
              0.24536530114030092`, 0.3752248669300471, 0.9372845629632816], 
             UndirectedEdge[178, 367] -> 
             RGBColor[
              0.18455036747987072`, 0.3113045157634352, 0.933821242458952], 
             UndirectedEdge[54, 123] -> 
             RGBColor[
              0.8957058066069172, 0.5826430148496441, 0.23309163667201951`], 
             UndirectedEdge[36, 95] -> 
             RGBColor[
              0.2464425329575721, 0.37635710587044113`, 0.9373459097216534], 
             UndirectedEdge[294, 301] -> 
             RGBColor[
              0.22980051567191817`, 0.3588652905383795, 0.9363981714568937], 
             UndirectedEdge[60, 337] -> 
             RGBColor[
              0.8320015089413489, 0.8692436923740543, 0.9645701589651641], 
             UndirectedEdge[251, 275] -> 
             RGBColor[
              0.1895350470293607, 0.3165437300168866, 0.9341051125851229], 
             UndirectedEdge[66, 311] -> 
             RGBColor[
              0.19936169446772767`, 0.32687215952004334`, 0.9346647256195157],
              UndirectedEdge[110, 400] -> 
             RGBColor[
              0.8375389435666232, 0.5282930654888892, 0.5773241994710698], 
             UndirectedEdge[143, 151] -> 
             RGBColor[
              0.2032578843654731, 0.3309673021352812, 0.934886607870296], 
             UndirectedEdge[157, 206] -> 
             RGBColor[
              0.3378748813614898, 0.46135031520372605`, 0.942959564481942], 
             UndirectedEdge[226, 274] -> 
             RGBColor[
              0.1975222198425889, 0.324938755059595, 0.9345599702608729], 
             UndirectedEdge[86, 265] -> 
             RGBColor[
              0.23354789403514828`, 0.36280402279564555`, 0.9366115791109302],
              UndirectedEdge[64, 389] -> 
             RGBColor[
              0.9928542633450905, 0.9871243167769764, 0.4636088473670069], 
             UndirectedEdge[120, 356] -> 
             RGBColor[
              0.6789656354460096, 0.7452687768356042, 0.9624218591420297], 
             UndirectedEdge[164, 279] -> 
             RGBColor[
              0.20701484030443992`, 0.33491610103189995`, 0.9351005609531018],
              UndirectedEdge[24, 238] -> 
             RGBColor[
              0.23053198107939255`, 0.35963410705922055`, 0.9364398273297434],
              UndirectedEdge[213, 259] -> 
             RGBColor[
              0.6104189913379899, 0.6878648671799451, 0.9659218116631232], 
             UndirectedEdge[73, 162] -> 
             RGBColor[
              0.19690433907813965`, 0.3242893232002557, 0.9345247828654102], 
             UndirectedEdge[257, 356] -> 
             RGBColor[
              0.9574019127188883, 0.9677509967704889, 0.9569916297931109], 
             UndirectedEdge[6, 281] -> 
             RGBColor[
              0.6624572537085711, 0.7318807392393671, 0.9697242643368251], 
             UndirectedEdge[176, 277] -> 
             RGBColor[
              0.18565952896853344`, 0.31247031481291987`, 0.933884407564874], 
             UndirectedEdge[140, 263] -> 
             RGBColor[
              0.35408935706105976`, 0.48047689556673456`, 0.943806644371628], 
             UndirectedEdge[54, 161] -> 
             RGBColor[
              0.9139000708098552, 0.6892402426005217, 0.2492124251865322], 
             UndirectedEdge[7, 142] -> 
             RGBColor[
              0.36455405628776205`, 0.4846402873807406, 0.9447885201049626], 
             UndirectedEdge[81, 311] -> 
             RGBColor[
              0.21587607865268055`, 0.34422982437086214`, 0.9356051953680067],
              UndirectedEdge[204, 237] -> 
             RGBColor[
              0.18108298927677668`, 0.3076600814275077, 0.9336237803998122], 
             UndirectedEdge[134, 374] -> 
             RGBColor[
              0.18137577945827954`, 0.307967822472237, 0.9336404543675045], 
             UndirectedEdge[264, 279] -> 
             RGBColor[
              0.22950792112061041`, 0.35855775511338905`, 0.9363815086300517],
              UndirectedEdge[81, 344] -> 
             RGBColor[
              0.2103592408268638, 0.3384312780282078, 0.9352910196152566], 
             UndirectedEdge[287, 391] -> 
             RGBColor[
              0.8187766066009462, 0.14533080306215745`, 0.16561380572719725`],
              UndirectedEdge[90, 228] -> 
             RGBColor[
              0.21978849971833822`, 0.34834202697269134`, 0.9358280019597877],
              UndirectedEdge[222, 259] -> 
             RGBColor[
              0.9232560562805229, 0.9412465076079086, 0.9787839457914527], 
             UndirectedEdge[143, 342] -> 
             RGBColor[
              0.19264878464975516`, 0.3198164656782889, 0.9342824353362423], 
             UndirectedEdge[68, 262] -> 
             RGBColor[
              0.5929687866565062, 0.6752889407487281, 0.9636412596987081], 
             UndirectedEdge[73, 189] -> 
             RGBColor[
              0.2158427366159144, 0.3441947797762137, 0.9356032965883381], 
             UndirectedEdge[79, 176] -> 
             RGBColor[
              0.19262785863960308`, 0.31979447111483345`, 0.9342812436309215],
              UndirectedEdge[14, 289] -> 
             RGBColor[
              0.4064318553204269, 0.5258851919600367, 0.9472752267865294], 
             UndirectedEdge[126, 373] -> 
             RGBColor[
              0.19027225530167013`, 0.317318582652788, 0.934147095505629], 
             UndirectedEdge[313, 361] -> 
             RGBColor[
              0.3470958164482592, 0.47282784576328063`, 0.9434192982898635], 
             UndirectedEdge[56, 203] -> 
             RGBColor[
              0.4142038212467356, 0.5314171873708888, 0.948101927737594], 
             UndirectedEdge[163, 240] -> 
             RGBColor[
              0.17919351847301027`, 0.305674127813381, 0.9335161778327592], 
             UndirectedEdge[283, 380] -> 
             RGBColor[
              0.8261523609821573, 0.7746449493883936, 0.6184230525835972], 
             UndirectedEdge[165, 318] -> 
             RGBColor[
              0.21949852941857476`, 0.348037249802461, 0.9358114885801888], 
             UndirectedEdge[184, 185] -> 
             RGBColor[
              0.20305130848505737`, 0.330750177787297, 0.9348748436795078], 
             UndirectedEdge[123, 364] -> 
             RGBColor[
              0.8822480780789155, 0.5292876057583029, 0.22226323240490067`], 
             UndirectedEdge[24, 341] -> 
             RGBColor[
              0.25476263408947386`, 0.38510205968495004`, 0.9378197271726287],
              UndirectedEdge[10, 364] -> 
             RGBColor[
              0.8821527210971085, 0.5285546502104392, 0.22217191845143208`], 
             UndirectedEdge[59, 132] -> 
             RGBColor[
              0.20457320024571096`, 0.33234978252125474`, 0.93496151316384], 
             UndirectedEdge[110, 309] -> 
             RGBColor[
              0.7751646817101416, 0.8245503622153614, 0.9781540938970312], 
             UndirectedEdge[28, 50] -> 
             RGBColor[
              0.21136185866227802`, 0.33948509294287055`, 0.9353481172177434],
              UndirectedEdge[120, 147] -> 
             RGBColor[
              0.3298813986080268, 0.4544594666479659, 0.9424490293594527], 
             UndirectedEdge[322, 335] -> 
             RGBColor[
              0.19668775397946056`, 0.3240616785292556, 0.9345124486644494], 
             UndirectedEdge[9, 198] -> 
             RGBColor[
              0.7575782172127392, 0.8106163649808842, 0.9764530707316865], 
             UndirectedEdge[214, 257] -> 
             RGBColor[
              0.9241708234933428, 0.7599031818045514, 0.5786645333196092], 
             UndirectedEdge[190, 274] -> 
             RGBColor[
              0.20764624835933113`, 0.33557975093117354`, 0.9351365187077434],
              UndirectedEdge[18, 198] -> 
             RGBColor[
              0.9106667100371233, 0.9263839830131071, 0.7062421502048801], 
             UndirectedEdge[280, 291] -> 
             RGBColor[
              0.20219476439486456`, 0.32984989564047235`, 0.9348260647607148],
              UndirectedEdge[156, 179] -> 
             RGBColor[
              0.21434244441768896`, 0.34261787755185935`, 0.9355178571671325],
              UndirectedEdge[76, 96] -> 
             RGBColor[
              0.24728213971667218`, 0.37723958580839845`, 0.9373937240844974],
              UndirectedEdge[143, 158] -> 
             RGBColor[
              0.1950219034609478, 0.3223107640132754, 0.9344175809418251], 
             UndirectedEdge[252, 274] -> 
             RGBColor[
              0.20454056169243495`, 0.3323154773323579, 0.9349596544465153], 
             UndirectedEdge[272, 348] -> 
             RGBColor[
              0.1988777254844435, 0.3263634774332058, 0.9346371643018856], 
             UndirectedEdge[51, 232] -> 
             RGBColor[
              0.19578437289714112`, 0.32311216773406903`, 0.9344610024482438],
              UndirectedEdge[66, 317] -> 
             RGBColor[
              0.19231567190482668`, 0.3194663430628012, 0.9342634650582149], 
             UndirectedEdge[258, 264] -> 
             RGBColor[
              0.24881577416889822`, 0.37885153285572853`, 0.9374810622977428],
              UndirectedEdge[17, 223] -> 
             RGBColor[
              0.843439007132864, 0.3336207383005069, 0.18918058014291417`], 
             UndirectedEdge[46, 271] -> 
             RGBColor[
              0.8127696138510401, 0.5013829917925117, 0.574019985211861], 
             UndirectedEdge[93, 201] -> 
             RGBColor[
              0.5041214136186714, 0.6049415425126292, 0.9551812111618987], 
             UndirectedEdge[232, 373] -> 
             RGBColor[
              0.19417254912152382`, 0.3214180387503654, 0.934369211468702], 
             UndirectedEdge[182, 208] -> 
             RGBColor[
              0.2681228139523549, 0.39914445580516655`, 0.9385805696512048], 
             UndirectedEdge[10, 391] -> 
             RGBColor[
              0.8316006559249898, 0.24390206570100256`, 0.1778941298425935], 
             UndirectedEdge[284, 366] -> 
             RGBColor[
              0.8665824589296481, 0.8923925729410807, 0.7434186835178305], 
             UndirectedEdge[154, 387] -> 
             RGBColor[
              0.18595738695423472`, 0.312783382441179, 0.9339013701365182], 
             UndirectedEdge[135, 363] -> 
             RGBColor[
              0.3549405295448861, 0.4818533796872159, 0.9438374745743816], 
             UndirectedEdge[37, 269] -> 
             RGBColor[
              0.3188674209826161, 0.4483513791388215, 0.9416215783296149], 
             UndirectedEdge[201, 281] -> 
             RGBColor[
              0.5322326354554701, 0.6292900699565726, 0.956972433359562], 
             UndirectedEdge[302, 377] -> 
             RGBColor[
              0.22469777382228445`, 0.35350198532189486`, 0.9361075778573873],
              UndirectedEdge[179, 286] -> 
             RGBColor[
              0.2740282991513247, 0.4041960245612692, 0.9389591857364195], 
             UndirectedEdge[108, 325] -> 
             RGBColor[
              0.2723177927173417, 0.4035536444641835, 0.9388194674859559], 
             UndirectedEdge[279, 299] -> 
             RGBColor[
              0.19371330684929777`, 0.320935346004614, 0.9343430583006869], 
             UndirectedEdge[196, 332] -> 
             RGBColor[
              0.8309647608435446, 0.5082040216040586, 0.5748389341298874], 
             UndirectedEdge[31, 224] -> 
             RGBColor[
              0.7410029688449329, 0.7954456814088879, 0.9320732118445416], 
             UndirectedEdge[200, 296] -> 
             RGBColor[
              0.1865617818736295, 0.3134186398223141, 0.9339357895330556], 
             UndirectedEdge[170, 221] -> 
             RGBColor[
              0.30270787399814014`, 0.42984035374028506`, 0.9407572019749026],
              UndirectedEdge[198, 206] -> 
             RGBColor[
              0.6288429856334741, 0.7061140055023541, 0.9660410068543737], 
             UndirectedEdge[36, 361] -> 
             RGBColor[
              0.32761397052464425`, 0.4523511904771868, 0.9423098359853219], 
             UndirectedEdge[132, 180] -> 
             RGBColor[
              0.1906491777676344, 0.3177147520627811, 0.9341685606824588], 
             UndirectedEdge[127, 312] -> 
             RGBColor[
              0.44359264480187605`, 0.5560735292696781, 0.9501952628642483], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.37498442055197767`, 0.49560326154572176`, 0.9453825139194686],
              UndirectedEdge[67, 75] -> 
             RGBColor[
              0.1806580838475214, 0.3072134788808002, 0.9335995826642074], 
             UndirectedEdge[110, 287] -> 
             RGBColor[
              0.8351408344121083, 0.5098601476691562, 0.5750277674364295], 
             UndirectedEdge[88, 233] -> 
             RGBColor[
              0.7003634497191511, 0.7623012578281982, 0.9418757273882692], 
             UndirectedEdge[168, 216] -> 
             RGBColor[
              0.20689038450304525`, 0.3347852900936806, 0.9350934733793282], 
             UndirectedEdge[1, 291] -> 
             RGBColor[
              0.1886369117353484, 0.31559973287781307`, 0.934053965108801], 
             UndirectedEdge[115, 214] -> 
             RGBColor[
              0.917014626987943, 0.7014084006737106, 0.2517091579831441], 
             UndirectedEdge[233, 256] -> 
             RGBColor[
              0.9813174831621745, 0.9842395002462874, 0.8561565043579783], 
             UndirectedEdge[4, 252] -> 
             RGBColor[
              0.20339315185029538`, 0.3311094768382833, 0.9348943111534462], 
             UndirectedEdge[91, 399] -> 
             RGBColor[
              0.4759758631677278, 0.5829069233744436, 0.9525944899971995], 
             UndirectedEdge[76, 269] -> 
             RGBColor[
              0.3181691701834686, 0.44761747327725976`, 0.9415818139795731], 
             UndirectedEdge[91, 172] -> 
             RGBColor[
              0.48609962486048197`, 0.5916756169176496, 0.9532395671401708], 
             UndirectedEdge[165, 184] -> 
             RGBColor[
              0.21954677082243013`, 0.3480879545765947, 0.9358142358567716], 
             UndirectedEdge[60, 139] -> 
             RGBColor[
              0.506983675095762, 0.6054995726195224, 0.9561122679612462], 
             UndirectedEdge[356, 359] -> 
             RGBColor[
              0.6355366085129286, 0.7076527365125309, 0.9596545999486343], 
             UndirectedEdge[228, 305] -> 
             RGBColor[
              0.26103370837156087`, 0.39169335636449776`, 0.9381768555757705],
              UndirectedEdge[141, 209] -> 
             RGBColor[
              0.3104061832925851, 0.4392395615986554, 0.9411477244574119], 
             UndirectedEdge[171, 348] -> 
             RGBColor[
              0.1945787269842331, 0.32184495743723673`, 0.934392342697097], 
             UndirectedEdge[10, 60] -> 
             RGBColor[
              0.774995447398962, 0.551160577750298, 0.5801059153920654], 
             UndirectedEdge[234, 298] -> 
             RGBColor[
              0.22620097648238727`, 0.3550819466262163, 0.936193183025091], 
             UndirectedEdge[323, 388] -> 
             RGBColor[
              0.34570167664203966`, 0.47034107110967827`, 0.9433773042073184],
              UndirectedEdge[294, 329] -> 
             RGBColor[
              0.23603593247132534`, 0.36541910894281576`, 0.9367532692191475],
              UndirectedEdge[211, 238] -> 
             RGBColor[
              0.21668562529693003`, 0.34508070922219014`, 0.9356512978517798],
              UndirectedEdge[31, 99] -> 
             RGBColor[
              0.9432122400933031, 0.9562926111989585, 0.9505366840460105], 
             UndirectedEdge[111, 319] -> 
             RGBColor[
              0.8295282339464709, 0.2279725222330049, 0.17590957621549802`], 
             UndirectedEdge[258, 394] -> 
             RGBColor[
              0.29763886748570073`, 0.42564849142765915`, 0.9404269355800592],
              UndirectedEdge[101, 364] -> 
             RGBColor[
              0.8876560448428017, 0.5708556080916793, 0.22744190748542303`], 
             UndirectedEdge[225, 349] -> 
             RGBColor[
              0.2034483891040132, 0.3311675346941849, 0.9348974568333293], 
             UndirectedEdge[118, 386] -> 
             RGBColor[
              0.34968714140668505`, 0.4773031589248714, 0.9435027333276041], 
             UndirectedEdge[95, 326] -> 
             RGBColor[
              0.24440137831360023`, 0.3742117229229475, 0.9372296689842969], 
             UndirectedEdge[228, 382] -> 
             RGBColor[
              0.27305197131929326`, 0.4030910170101112, 0.9389064714836659], 
             UndirectedEdge[120, 255] -> 
             RGBColor[
              0.39336824955180094`, 0.5151375393238391, 0.9462860549129236], 
             UndirectedEdge[222, 292] -> 
             RGBColor[
              0.8852896880649895, 0.5569352274955306, 0.5669895272748917], 
             UndirectedEdge[325, 397] -> 
             RGBColor[
              0.3012257827964342, 0.4288125621703911, 0.9406533939002841], 
             UndirectedEdge[155, 299] -> 
             RGBColor[
              0.1871446834102983, 0.31403130629544507`, 0.9339689849132433], 
             UndirectedEdge[17, 99] -> 
             RGBColor[
              0.8649138899410389, 0.5692261022124661, 0.5823263856846504], 
             UndirectedEdge[60, 105] -> 
             RGBColor[
              0.8461630434103341, 0.8796208819742317, 0.932337896398757], 
             UndirectedEdge[229, 340] -> 
             RGBColor[
              0.23465687622616624`, 0.36396963339193744`, 0.9366747340061166],
              UndirectedEdge[297, 375] -> 
             RGBColor[
              0.2496778587950193, 0.3797576384571041, 0.9375301567418605], 
             UndirectedEdge[155, 249] -> 
             RGBColor[
              0.18476081976801417`, 0.3115257144617197, 0.9338332274054255], 
             UndirectedEdge[143, 348] -> 
             RGBColor[
              0.20000377872339242`, 0.3275470307832401, 0.9347012913679973], 
             UndirectedEdge[175, 294] -> 
             RGBColor[
              0.19993479870238595`, 0.3274745284075764, 0.9346973630578478], 
             UndirectedEdge[19, 181] -> 
             RGBColor[
              0.19581756515250187`, 0.3231470548989638, 0.9344628926980831], 
             UndirectedEdge[153, 294] -> 
             RGBColor[
              0.20769214048678164`, 0.33562798646685293`, 0.9351391321965103],
              UndirectedEdge[68, 376] -> 
             RGBColor[
              0.5538916735521564, 0.639355835105775, 0.9612276966528428], 
             UndirectedEdge[317, 354] -> 
             RGBColor[
              0.19230267119241712`, 0.319452678489766, 0.934262724686876], 
             UndirectedEdge[2, 254] -> 
             RGBColor[
              0.19445154659843222`, 0.32171128278805783`, 0.9343850999622723],
              UndirectedEdge[243, 311] -> 
             RGBColor[
              0.21699506567726595`, 0.34540595068157653`, 0.9356689200236639],
              UndirectedEdge[23, 143] -> 
             RGBColor[
              0.20541157212716055`, 0.3332309645245057, 0.9350092572022285], 
             UndirectedEdge[20, 64] -> 
             RGBColor[
              0.6886054780275248, 0.7470570557801346, 0.690028677840299], 
             UndirectedEdge[75, 296] -> 
             RGBColor[
              0.18049305546872535`, 0.30704002359128196`, 0.9335901845421726],
              UndirectedEdge[146, 227] -> 
             RGBColor[
              0.2365605733145403, 0.3659705397331854, 0.936783146739032], 
             UndirectedEdge[160, 238] -> 
             RGBColor[
              0.19808883610787825`, 0.32553430467996036`, 0.9345922382189475],
              UndirectedEdge[75, 178] -> 
             RGBColor[
              0.18245868691760933`, 0.30910602687229105`, 0.9337021243452953],
              UndirectedEdge[95, 166] -> 
             RGBColor[
              0.24620280791930751`, 0.37610513965577974`, 0.9373322577353658],
              UndirectedEdge[25, 309] -> 
             RGBColor[
              0.5306642654095335, 0.6265873056000757, 0.957441478589943], 
             UndirectedEdge[166, 326] -> 
             RGBColor[
              0.24337300372818133`, 0.3731308360309576, 0.9371711045730012], 
             UndirectedEdge[158, 308] -> 
             RGBColor[
              0.20199405614850408`, 0.32963893854790965`, 0.9348146347230057],
              UndirectedEdge[229, 343] -> 
             RGBColor[
              0.1993208104479567, 0.32682918782306747`, 0.9346623973350723], 
             UndirectedEdge[229, 294] -> 
             RGBColor[
              0.20382733943636777`, 0.33156583552032837`, 0.9349190374941501],
              UndirectedEdge[64, 257] -> 
             RGBColor[
              0.9810027572631417, 0.9816315939147817, 0.6854880311912166], 
             UndirectedEdge[56, 65] -> 
             RGBColor[
              0.4474461015886463, 0.5602099797974611, 0.9502200964459863], 
             UndirectedEdge[170, 192] -> 
             RGBColor[
              0.2468852126322833, 0.37682239027607506`, 0.9373711196742425], 
             UndirectedEdge[133, 347] -> 
             RGBColor[
              0.18386468807739512`, 0.3105838232368483, 0.9337821940313528], 
             UndirectedEdge[223, 393] -> 
             RGBColor[
              0.7905940425099285, 0.6181725668402647, 0.5885810229879949], 
             UndirectedEdge[116, 338] -> 
             RGBColor[
              0.22507866009155236`, 0.35390232094047974`, 0.9361292687669514],
              UndirectedEdge[32, 71] -> 
             RGBColor[
              0.8956113709184261, 0.5716673969312225, 0.5522037062726537], 
             UndirectedEdge[95, 361] -> 
             RGBColor[
              0.32840262007179855`, 0.45318011115451534`, 0.9423547484103298],
              UndirectedEdge[247, 292] -> 
             RGBColor[
              0.8184153147444937, 0.14255375553436297`, 0.16526783223743757`],
              UndirectedEdge[337, 391] -> 
             RGBColor[
              0.8886067174673766, 0.5619851803247587, 0.5623583734156922], 
             UndirectedEdge[181, 238] -> 
             RGBColor[
              0.1965022388034804, 0.3238666903169589, 0.9345018838496224], 
             UndirectedEdge[97, 246] -> 
             RGBColor[
              0.2576631748496625, 0.38815071192881434`, 0.9379849086779559], 
             UndirectedEdge[62, 247] -> 
             RGBColor[
              0.9045712992599508, 0.5625787324781286, 0.4748658971031438], 
             UndirectedEdge[207, 280] -> 
             RGBColor[
              0.200223112625469, 0.32777756462089525`, 0.9347137821092452], 
             UndirectedEdge[145, 221] -> 
             RGBColor[
              0.3098924284635012, 0.43739177601044266`, 0.941166351723109], 
             UndirectedEdge[10, 334] -> 
             RGBColor[
              0.9015893430893124, 0.6043580043169925, 0.2443543042542488], 
             UndirectedEdge[25, 78] -> 
             RGBColor[
              0.29221377727191306`, 0.41936050438489303`, 0.9401394364080135],
              UndirectedEdge[46, 139] -> 
             RGBColor[
              0.5562400144756487, 0.6439789993051345, 0.961021679543971], 
             UndirectedEdge[224, 383] -> 
             RGBColor[
              0.42803255257249384`, 0.5439556499014909, 0.9488281562852744], 
             UndirectedEdge[138, 164] -> 
             RGBColor[
              0.2519489800003536, 0.38214473084131173`, 0.9376594937346815], 
             UndirectedEdge[53, 93] -> 
             RGBColor[
              0.37256678589576175`, 0.4971203570169409, 0.9449606040427729], 
             UndirectedEdge[31, 199] -> 
             RGBColor[
              0.9864970705564884, 0.9886842059127192, 0.8734420155476115], 
             UndirectedEdge[98, 342] -> 
             RGBColor[
              0.1898214409282245, 0.31684474816301444`, 0.9341214222939813], 
             UndirectedEdge[141, 304] -> 
             RGBColor[
              0.31901866548224, 0.4482918264428926, 0.9416381925770871], 
             UndirectedEdge[32, 105] -> 
             RGBColor[
              0.903410578527918, 0.577299573576944, 0.5307412035187635], 
             UndirectedEdge[216, 329] -> 
             RGBColor[
              0.23907766788565177`, 0.368616165720437, 0.936926491551149], 
             UndirectedEdge[164, 264] -> 
             RGBColor[
              0.23748584663754294`, 0.36694306066137816`, 0.9368358396859577],
              UndirectedEdge[118, 196] -> 
             RGBColor[
              0.6007859963931654, 0.6812853787799371, 0.9644958808837701], 
             UndirectedEdge[75, 398] -> 
             RGBColor[
              0.18135843161484838`, 0.30794958878887396`, 0.9336394664334849],
              UndirectedEdge[45, 48] -> 
             RGBColor[
              0.2238300988639671, 0.3525900039269335, 0.9360581650521211], 
             UndirectedEdge[248, 275] -> 
             RGBColor[
              0.18852850716525682`, 0.3154857928014001, 0.9340477916289045], 
             UndirectedEdge[200, 347] -> 
             RGBColor[
              0.1891857716327594, 0.31617661942971953`, 0.9340852218679931], 
             UndirectedEdge[33, 58] -> 
             RGBColor[
              0.21989646734481127`, 0.3484555077936574, 0.9358341505563915], 
             UndirectedEdge[134, 240] -> 
             RGBColor[
              0.17922390736570504`, 0.3057060684663703, 0.9335179084352418], 
             UndirectedEdge[267, 344] -> 
             RGBColor[
              0.1945632673718405, 0.321828708404416, 0.9343914622950418], 
             UndirectedEdge[141, 286] -> 
             RGBColor[
              0.3385051144347327, 0.4676178491867835, 0.9427902244568296], 
             UndirectedEdge[33, 209] -> 
             RGBColor[
              0.25581747523043485`, 0.38621076460489123`, 0.9378797988151089],
              UndirectedEdge[47, 155] -> 
             RGBColor[
              0.18345196765990118`, 0.3101500279100763, 0.9337586902141416], 
             UndirectedEdge[153, 229] -> 
             RGBColor[
              0.2017865527982215, 0.3294208393702904, 0.934802817714181], 
             UndirectedEdge[64, 161] -> 
             RGBColor[
              0.9360657953387055, 0.766239407790421, 0.32776561052681985`], 
             UndirectedEdge[3, 293] -> 
             RGBColor[
              0.2751725873267546, 0.40605645004464963`, 0.939000269414517], 
             UndirectedEdge[133, 178] -> 
             RGBColor[
              0.18320632976714918`, 0.309891846910452, 0.9337447014995381], 
             UndirectedEdge[113, 162] -> 
             RGBColor[
              0.19047273002269705`, 0.31752929429541876`, 0.9341585122444157],
              UndirectedEdge[313, 358] -> 
             RGBColor[
              0.28110733593194254`, 0.4127920116719563, 0.9393200189690635], 
             UndirectedEdge[259, 292] -> 
             RGBColor[
              0.8574582528162021, 0.5351400233172219, 0.5780931752640834], 
             UndirectedEdge[4, 165] -> 
             RGBColor[
              0.21319278532882907`, 0.3414095129568713, 0.9354523857827901], 
             UndirectedEdge[247, 385] -> 
             RGBColor[
              0.9058781642243791, 0.5623734342527853, 0.3990017564205388], 
             UndirectedEdge[38, 243] -> 
             RGBColor[
              0.24505985490147014`, 0.37490382356662577`, 0.9372671682518474],
              UndirectedEdge[265, 381] -> 
             RGBColor[
              0.19417265233719494`, 0.3214181472365799, 0.9343692173466818], 
             UndirectedEdge[15, 369] -> 
             RGBColor[
              0.18126767848005537`, 0.30785420149012543`, 0.9336342981767156],
              UndirectedEdge[30, 358] -> 
             RGBColor[
              0.2391480425105603, 0.3686901339132248, 0.9369304992819277], 
             UndirectedEdge[133, 330] -> 
             RGBColor[
              0.1860526851696524, 0.3128835469078388, 0.9339067972289052], 
             UndirectedEdge[223, 292] -> 
             RGBColor[
              0.8393541052177236, 0.30222239216530483`, 0.1852688734557389], 
             UndirectedEdge[44, 326] -> 
             RGBColor[
              0.2349425006851034, 0.3642698428079171, 0.9366909998965096], 
             UndirectedEdge[123, 356] -> 
             RGBColor[
              0.8942706865915142, 0.6457615828952505, 0.5831484206142015], 
             UndirectedEdge[35, 154] -> 
             RGBColor[
              0.18823624142486384`, 0.31517860297752887`, 0.9340311475273575],
              UndirectedEdge[146, 151] -> 
             RGBColor[
              0.20337080686080378`, 0.3310859908375735, 0.9348930386393511], 
             UndirectedEdge[111, 287] -> 
             RGBColor[
              0.8219655423100481, 0.16984236032285321`, 0.168667534163621], 
             UndirectedEdge[42, 133] -> 
             RGBColor[
              0.1836453052262827, 0.310353237950653, 0.9337697005025297], 
             UndirectedEdge[40, 103] -> 
             RGBColor[
              0.19411926264855695`, 0.32136203128871965`, 0.9343661768828968],
              UndirectedEdge[219, 260] -> 
             RGBColor[
              0.1839290162486566, 0.31065143622348573`, 0.9337858574255411], 
             UndirectedEdge[151, 186] -> 
             RGBColor[
              0.20709670832782653`, 0.33500214951521173`, 0.9351052232159208],
              UndirectedEdge[8, 76] -> 
             RGBColor[
              0.26926683315553557`, 0.4003468925227164, 0.9386457198524012], 
             UndirectedEdge[124, 167] -> 
             RGBColor[
              0.23121257205082407`, 0.360349451322155, 0.9364785859787222], 
             UndirectedEdge[162, 291] -> 
             RGBColor[
              0.1953787311658639, 0.32268581255532547`, 0.9344379017517408], 
             UndirectedEdge[242, 255] -> 
             RGBColor[
              0.3572936731332409, 0.48389155439101317`, 0.9439874148030284], 
             UndirectedEdge[182, 323] -> 
             RGBColor[
              0.3312247462121247, 0.45512489933743366`, 0.9425528644360341], 
             UndirectedEdge[138, 149] -> 
             RGBColor[
              0.2496156992329207, 0.3796923048161946, 0.9375266168467558], 
             UndirectedEdge[199, 353] -> 
             RGBColor[
              0.9909977762454061, 0.988800838647677, 0.6720451430779383], 
             UndirectedEdge[34, 381] -> 
             RGBColor[
              0.18614322275265005`, 0.3129787076479837, 0.9339119532103186], 
             UndirectedEdge[148, 305] -> 
             RGBColor[
              0.2773062230664102, 0.4087968010458064, 0.939103551214614], 
             UndirectedEdge[97, 383] -> 
             RGBColor[
              0.32847115554353346`, 0.45799116005281093`, 0.9421851328952267],
              UndirectedEdge[154, 207] -> 
             RGBColor[
              0.18894498275511917`, 0.315923535052423, 0.9340715092976267], 
             UndirectedEdge[272, 375] -> 
             RGBColor[
              0.1997235147350348, 0.3272524555617131, 0.9346853307484737], 
             UndirectedEdge[25, 323] -> 
             RGBColor[
              0.3922918508728892, 0.5142052168895364, 0.9462174677409253], 
             UndirectedEdge[236, 334] -> 
             RGBColor[
              0.7349237676396162, 0.7451154652166593, 0.6272347577119612], 
             UndirectedEdge[23, 346] -> 
             RGBColor[
              0.20767293699657277`, 0.3356078023810718, 0.935138038586152], 
             UndirectedEdge[23, 151] -> 
             RGBColor[
              0.20976599730073225`, 0.3378077414684315, 0.9352572352740687], 
             UndirectedEdge[250, 381] -> 
             RGBColor[
              0.19153445496524343`, 0.31864523452728444`, 0.9342189759092124],
              UndirectedEdge[230, 264] -> 
             RGBColor[
              0.2405521506109405, 0.3701659405523198, 0.9370104611610526], 
             UndirectedEdge[60, 68] -> 
             RGBColor[
              0.7643140770585692, 0.8158203298412934, 0.9771398668713851], 
             UndirectedEdge[50, 258] -> 
             RGBColor[
              0.23439017041921995`, 0.3636893086787121, 0.9366595455049669], 
             UndirectedEdge[121, 298] -> 
             RGBColor[
              0.2245949434093795, 0.353393904038107, 0.9361017218174963], 
             UndirectedEdge[95, 382] -> 
             RGBColor[
              0.2846635750266093, 0.4152955487246973, 0.9395677351369693], 
             UndirectedEdge[42, 200] -> 
             RGBColor[
              0.18896638878164698`, 0.3159460341435242, 0.9340727283391701], 
             UndirectedEdge[254, 314] -> 
             RGBColor[
              0.1849157269952969, 0.31168853177927935`, 0.9338420491428545], 
             UndirectedEdge[95, 305] -> 
             RGBColor[
              0.2726453120788769, 0.4038978880790839, 0.9388381192290738], 
             UndirectedEdge[321, 381] -> 
             RGBColor[
              0.18695109985789307`, 0.313827837707961, 0.9339579606163151], 
             UndirectedEdge[116, 209] -> 
             RGBColor[
              0.2525333735524159, 0.38275896551722044`, 0.9376927740829386], 
             UndirectedEdge[364, 366] -> 
             RGBColor[
              0.9573192010017704, 0.856958801294309, 0.38384804144330753`], 
             UndirectedEdge[58, 156] -> 
             RGBColor[
              0.19753761270804981`, 0.3249549339371585, 0.9345608468617892], 
             UndirectedEdge[118, 179] -> 
             RGBColor[
              0.29213029064248475`, 0.4198750597583651, 0.9401126286272736], 
             UndirectedEdge[149, 328] -> 
             RGBColor[
              0.22083892747976266`, 0.3494460931509151, 0.9358878222668322], 
             UndirectedEdge[215, 227] -> 
             RGBColor[
              0.4900314069116405, 0.5878102265694376, 0.9551265080130549], 
             UndirectedEdge[70, 177] -> 
             RGBColor[
              0.1891804395703839, 0.31617101509409057`, 0.9340849182149289], 
             UndirectedEdge[383, 393] -> 
             RGBColor[
              0.5401446576878393, 0.6337537414941011, 0.9584878557690468], 
             UndirectedEdge[14, 201] -> 
             RGBColor[
              0.5021816905325309, 0.6032614518687315, 0.9550576137220795], 
             UndirectedEdge[5, 368] -> 
             RGBColor[
              0.18532540128789612`, 0.31211912543565157`, 0.9338653794877592],
              UndirectedEdge[214, 310] -> 
             RGBColor[
              0.8527190352209195, 0.3739582811888842, 0.19685354443386982`], 
             UndirectedEdge[35, 280] -> 
             RGBColor[
              0.19951437129521365`, 0.3270326325460011, 0.9346734203389759], 
             UndirectedEdge[243, 275] -> 
             RGBColor[
              0.21276908993785693`, 0.3409641822371201, 0.9354282569570754], 
             UndirectedEdge[131, 391] -> 
             RGBColor[
              0.817172560246312, 0.5056217507313383, 0.5745581182301532], 
             UndirectedEdge[2, 314] -> 
             RGBColor[
              0.19228958849813182`, 0.3194389277485814, 0.9342619796467905], 
             UndirectedEdge[282, 361] -> 
             RGBColor[
              0.36229879969604784`, 0.48822674345474093`, 0.9443063370417508],
              UndirectedEdge[110, 269] -> 
             RGBColor[
              0.6031830035578256, 0.6830576186116337, 0.9647885304899277], 
             UndirectedEdge[193, 360] -> 
             RGBColor[
              0.7503418220523833, 0.8050370370474327, 0.9757122305140027], 
             UndirectedEdge[71, 400] -> 
             RGBColor[
              0.8959095468804387, 0.5739593080367903, 0.5524892399106185], 
             UndirectedEdge[110, 117] -> 
             RGBColor[
              0.7057471364084966, 0.7690367194392469, 0.9721131675946504], 
             UndirectedEdge[170, 351] -> 
             RGBColor[
              0.27252940237618284`, 0.4037012784354327, 0.938834256448926], 
             UndirectedEdge[121, 200] -> 
             RGBColor[
              0.2188856606362972, 0.3473930858541622, 0.9357765866096961], 
             UndirectedEdge[38, 383] -> 
             RGBColor[
              0.3085216567311646, 0.43702297192973105`, 0.9410490384505009], 
             UndirectedEdge[172, 256] -> 
             RGBColor[
              0.6859636429526801, 0.7471589426256584, 0.8613086090450968], 
             UndirectedEdge[127, 258] -> 
             RGBColor[
              0.2885106861095953, 0.4177421195154126, 0.9398452959345076], 
             UndirectedEdge[25, 388] -> 
             RGBColor[
              0.31737166199215083`, 0.44580303632788293`, 0.9415721407250759],
              UndirectedEdge[51, 277] -> 
             RGBColor[
              0.19316166908716753`, 0.3203555397407608, 0.9343116433462084], 
             UndirectedEdge[85, 379] -> 
             RGBColor[
              0.18217848519657132`, 0.30881151709766497`, 0.9336861672718034],
              UndirectedEdge[267, 306] -> 
             RGBColor[
              0.20993199303624877`, 0.33798221351119695`, 0.9352666884856375],
              UndirectedEdge[176, 298] -> 
             RGBColor[
              0.19583511598337588`, 0.32316550193499927`, 0.9344638921919373],
              UndirectedEdge[269, 323] -> 
             RGBColor[
              0.38701260190710624`, 0.5096325967781434, 0.9458810786650822], 
             UndirectedEdge[21, 180] -> 
             RGBColor[
              0.19254611619106632`, 0.3197085546186507, 0.9342765885194044], 
             UndirectedEdge[36, 228] -> 
             RGBColor[
              0.23483092925025606`, 0.364152574155855, 0.9366846460683501], 
             UndirectedEdge[74, 116] -> 
             RGBColor[
              0.244277527259818, 0.37408154761281204`, 0.9372226158500052], 
             UndirectedEdge[3, 188] -> 
             RGBColor[
              0.25601232241971317`, 0.38641556135484806`, 0.9378908950742876],
              UndirectedEdge[69, 394] -> 
             RGBColor[
              0.46522152575946735`, 0.5741285322522734, 0.9517610033724258], 
             UndirectedEdge[37, 395] -> 
             RGBColor[
              0.3615061899414258, 0.48528293772410147`, 0.9443384829836874], 
             UndirectedEdge[172, 194] -> 
             RGBColor[
              0.41753162873264527`, 0.5360090287080477, 0.9478416433121417], 
             UndirectedEdge[59, 264] -> 
             RGBColor[
              0.2381256499847355, 0.3676155345451527, 0.9368722755400762], 
             UndirectedEdge[28, 369] -> 
             RGBColor[
              0.1860007123494566, 0.3128289201785459, 0.9339038374536819], 
             UndirectedEdge[130, 344] -> 
             RGBColor[
              0.20361295849173341`, 0.3313405075549807, 0.9349068288165013], 
             UndirectedEdge[29, 270] -> 
             RGBColor[
              0.19689305639497057`, 0.3242774643848816, 0.9345241403332949], 
             UndirectedEdge[41, 48] -> 
             RGBColor[
              0.2013669879321785, 0.3289798500941302, 0.9347789241157504], 
             UndirectedEdge[12, 124] -> 
             RGBColor[
              0.23470207361547668`, 0.3640171387137828, 0.9366773079305742], 
             UndirectedEdge[61, 95] -> 
             RGBColor[
              0.23224869997063102`, 0.3614384874601766, 0.9365375919309413], 
             UndirectedEdge[213, 306] -> 
             RGBColor[
              0.2738566580723743, 0.4036300780572341, 0.9389635275699348], 
             UndirectedEdge[63, 295] -> 
             RGBColor[
              0.1876127220363632, 0.31452324456680214`, 0.9339956390205967], 
             UndirectedEdge[302, 367] -> 
             RGBColor[
              0.19039724530537674`, 0.31744995507150764`, 0.934154213501434], 
             UndirectedEdge[140, 331] -> 
             RGBColor[
              0.3236577561982914, 0.4484913535850291, 0.9420736097220124], 
             UndirectedEdge[92, 354] -> 
             RGBColor[
              0.20023581918524017`, 0.32779092002085713`, 0.9347145057290265],
              UndirectedEdge[151, 311] -> 
             RGBColor[
              0.20510424418118295`, 0.33290794336756596`, 0.934991755330356], 
             UndirectedEdge[299, 371] -> 
             RGBColor[
              0.18421145049276366`, 0.3109482925214076, 0.933801941637919], 
             UndirectedEdge[140, 389] -> 
             RGBColor[
              0.6997349672161455, 0.7570392468690857, 0.7200011772159544], 
             UndirectedEdge[176, 205] -> 
             RGBColor[
              0.18567915281687453`, 0.3124909407217502, 0.9338855251140061], 
             UndirectedEdge[152, 179] -> 
             RGBColor[
              0.2138285336364696, 0.3420777247369723, 0.935488590708405], 
             UndirectedEdge[142, 293] -> 
             RGBColor[
              0.3941446854590191, 0.5152441502355233, 0.946491888259698], 
             UndirectedEdge[105, 259] -> 
             RGBColor[
              0.9403634558512834, 0.9538207185775788, 0.9415651020124101], 
             UndirectedEdge[274, 318] -> 
             RGBColor[
              0.20829816061759315`, 0.33626495204823137`, 0.9351736441464337],
              UndirectedEdge[231, 369] -> 
             RGBColor[
              0.1858060573218873, 0.312624325402729, 0.9338927521378282], 
             UndirectedEdge[151, 348] -> 
             RGBColor[
              0.20435820389696413`, 0.332123807727166, 0.9349492694398375], 
             UndirectedEdge[147, 231] -> 
             RGBColor[
              0.2192108871052112, 0.34773491949353985`, 0.9357951077759714], 
             UndirectedEdge[66, 354] -> 
             RGBColor[
              0.19611420939972474`, 0.3234588468111266, 0.9344797861491166], 
             UndirectedEdge[24, 65] -> 
             RGBColor[
              0.3183379395633406, 0.44565996035968214`, 0.9416695943018074], 
             UndirectedEdge[42, 347] -> 
             RGBColor[
              0.18410501336322643`, 0.3108364203497602, 0.9337958802008515], 
             UndirectedEdge[52, 129] -> 
             RGBColor[
              0.904165411034544, 0.5696744067053534, 0.4991000639737569], 
             UndirectedEdge[3, 7] -> 
             RGBColor[
              0.24558195815549755`, 0.37545258718986685`, 0.9372969012597816],
              UndirectedEdge[156, 352] -> 
             RGBColor[
              0.19412861826228733`, 0.32137186463193046`, 0.9343667096712585],
              UndirectedEdge[229, 329] -> 
             RGBColor[
              0.2301303447827652, 0.3592119618462532, 0.9364169547368181], 
             UndirectedEdge[80, 187] -> 
             RGBColor[
              0.20972687217078761`, 0.3377666184761832, 0.9352550071557988], 
             UndirectedEdge[247, 362] -> 
             RGBColor[
              0.8043048253983777, 0.4855724402659776, 0.5720335274237128], 
             UndirectedEdge[43, 321] -> 
             RGBColor[
              0.1896253217591911, 0.31663861448168684`, 0.9341102535974373], 
             UndirectedEdge[84, 270] -> 
             RGBColor[
              0.21111604747539212`, 0.339226729800124, 0.9353341186342953], 
             UndirectedEdge[318, 322] -> 
             RGBColor[
              0.20428384988578308`, 0.3320456569470981, 0.9349450350888977], 
             UndirectedEdge[218, 276] -> 
             RGBColor[
              0.46966080217049366`, 0.5783141439540027, 0.951949779691809], 
             UndirectedEdge[201, 303] -> 
             RGBColor[
              0.7798220611835203, 0.6750115727481525, 0.6002603969131654], 
             UndirectedEdge[283, 364] -> 
             RGBColor[
              0.9266304431740131, 0.7468211866800847, 0.25982333625421017`], 
             UndirectedEdge[65, 340] -> 
             RGBColor[
              0.3239430587205376, 0.45155129597897675`, 0.941988797545779], 
             UndirectedEdge[83, 214] -> 
             RGBColor[
              0.9149531561640245, 0.7530286606028909, 0.5942676397554747], 
             UndirectedEdge[124, 157] -> 
             RGBColor[
              0.2367400113323198, 0.3661591404668991, 0.9367933654686897], 
             UndirectedEdge[311, 344] -> 
             RGBColor[
              0.19707934099750435`, 0.3244732613132706, 0.9345347489658259], 
             UndirectedEdge[190, 226] -> 
             RGBColor[
              0.20202864183193292`, 0.3296752902940524, 0.9348166043265123], 
             UndirectedEdge[380, 389] -> 
             RGBColor[
              0.8567527280963826, 0.8845935052040448, 0.7328269740889874], 
             UndirectedEdge[124, 179] -> 
             RGBColor[
              0.22671592710196903`, 0.3556231923771518, 0.9362225087010749], 
             UndirectedEdge[199, 215] -> 
             RGBColor[
              0.8474033618771311, 0.8799586173228249, 0.9038397390676208], 
             UndirectedEdge[146, 267] -> 
             RGBColor[
              0.19834666787727806`, 0.32580530221707793`, 0.9346069213567869],
              UndirectedEdge[109, 249] -> 
             RGBColor[
              0.18318613987214505`, 0.3098706260506894, 0.9337435517148859], 
             UndirectedEdge[36, 61] -> 
             RGBColor[
              0.23146005042347673`, 0.36060956678284806`, 0.9364926795059334],
              UndirectedEdge[13, 232] -> 
             RGBColor[
              0.20186143048066912`, 0.3294995405620621, 0.9348070818874247], 
             UndirectedEdge[38, 119] -> 
             RGBColor[
              0.249257790450226, 0.37931611999285497`, 0.9375062344710599], 
             UndirectedEdge[91, 256] -> 
             RGBColor[
              0.792439933021371, 0.8356021745450866, 0.869137935086701], 
             UndirectedEdge[6, 69] -> 
             RGBColor[
              0.7494906190968638, 0.8040199624425932, 0.9761664746556911], 
             UndirectedEdge[90, 97] -> 
             RGBColor[
              0.2570968896215246, 0.3875555102494842, 0.9379526595719574], 
             UndirectedEdge[233, 257] -> 
             RGBColor[
              0.9698756400386146, 0.9770538821816868, 0.9358768631099392], 
             UndirectedEdge[66, 119] -> 
             RGBColor[
              0.21795851687042844`, 0.3464185989719241, 0.9357237871438162], 
             UndirectedEdge[33, 116] -> 
             RGBColor[
              0.24330530459768918`, 0.3730596799524376, 0.9371672492076716], 
             UndirectedEdge[335, 349] -> 
             RGBColor[
              0.19833951424086566`, 0.32579778329164166`, 0.9346065139677762],
              UndirectedEdge[165, 274] -> 
             RGBColor[
              0.21434019517096867`, 0.34261551345094576`, 0.9355177290758593],
              UndirectedEdge[95, 169] -> 
             RGBColor[
              0.3522449518778092, 0.4737241407933565, 0.9439035250794346], 
             UndirectedEdge[135, 259] -> 
             RGBColor[
              0.6153899363844033, 0.6921704499321857, 0.9662385558858466], 
             UndirectedEdge[93, 273] -> 
             RGBColor[
              0.433287316679902, 0.5477930013754455, 0.949360282412582], 
             UndirectedEdge[89, 263] -> 
             RGBColor[
              0.2670289628172794, 0.39799474890803455`, 0.93851827644727], 
             UndirectedEdge[71, 289] -> 
             RGBColor[
              0.7219591346417744, 0.780476707159252, 0.9439593282102003], 
             UndirectedEdge[32, 215] -> 
             RGBColor[
              0.7637949188808839, 0.4683581448483874, 0.5697890053389816], 
             UndirectedEdge[8, 239] -> 
             RGBColor[
              0.3813679879787836, 0.49836836108207505`, 0.9461050956090218], 
             UndirectedEdge[110, 111] -> 
             RGBColor[
              0.8397873767221564, 0.5455755079920095, 0.5794773016000505], 
             UndirectedEdge[29, 162] -> 
             RGBColor[
              0.19056901057120365`, 0.3176304912564385, 0.9341639952792189], 
             UndirectedEdge[337, 353] -> 
             RGBColor[
              0.9751195109230872, 0.9777137367216755, 0.7327280786411184], 
             UndirectedEdge[306, 308] -> 
             RGBColor[
              0.2175738595337591, 0.3460142997224009, 0.9357018814775424], 
             UndirectedEdge[185, 190] -> 
             RGBColor[
              0.20235115482293997`, 0.33001427189610544`, 0.9348349709642347],
              UndirectedEdge[71, 385] -> 
             RGBColor[
              0.9820607295061435, 0.9836969405379016, 0.7849671104328407], 
             UndirectedEdge[146, 158] -> 
             RGBColor[
              0.1951348259562785, 0.3224294527155677, 0.9344240117108803], 
             UndirectedEdge[157, 386] -> 
             RGBColor[
              0.2943941268277438, 0.42368947103286164`, 0.9401890092515732], 
             UndirectedEdge[24, 124] -> 
             RGBColor[
              0.24340021238043813`, 0.3731594340496077, 0.9371726540654957], 
             UndirectedEdge[22, 74] -> 
             RGBColor[
              0.24528340650250224`, 0.37513879047330073`, 0.9372798991848111],
              UndirectedEdge[303, 385] -> 
             RGBColor[
              0.9441738208357854, 0.8008555462181073, 0.4334857922002555], 
             UndirectedEdge[130, 317] -> 
             RGBColor[
              0.20208377375464914`, 0.3297332374403929, 0.9348197440079504], 
             UndirectedEdge[73, 291] -> 
             RGBColor[
              0.19698615809912115`, 0.32437532017893284`, 0.9345294423376147],
              UndirectedEdge[241, 255] -> 
             RGBColor[
              0.32755009808125596`, 0.4555556663672059, 0.9421864088801596], 
             UndirectedEdge[385, 400] -> 
             RGBColor[
              0.9082664009347345, 0.5807304681405772, 0.40128873459150277`], 
             UndirectedEdge[130, 311] -> 
             RGBColor[
              0.20912979631755016`, 0.33713905389763504`, 0.9352210045692514],
              UndirectedEdge[143, 308] -> 
             RGBColor[
              0.2058756118794577, 0.33371869972598955`, 0.9350356835796365], 
             UndirectedEdge[297, 397] -> 
             RGBColor[
              0.33036980779411174`, 0.4594447802808611, 0.9423131030091806], 
             UndirectedEdge[237, 324] -> 
             RGBColor[
              0.18395646599811732`, 0.31068028765058353`, 0.9337874206481647],
              UndirectedEdge[107, 160] -> 
             RGBColor[
              0.20918830325598364`, 0.33720054839948277`, 0.935224336452842], 
             UndirectedEdge[125, 185] -> 
             RGBColor[
              0.1925739180479394, 0.31973777613296384`, 0.9342781717940241], 
             UndirectedEdge[269, 388] -> 
             RGBColor[
              0.3120924130263679, 0.44123041621648995`, 0.9412357516492327], 
             UndirectedEdge[47, 300] -> 
             RGBColor[
              0.18858263454534693`, 0.31554268410974895`, 0.9340508741031263],
              UndirectedEdge[37, 365] -> 
             RGBColor[
              0.29517424252624735`, 0.4275772223959621, 0.9401211084894857], 
             UndirectedEdge[356, 389] -> 
             RGBColor[
              0.969253418800837, 0.9732437196326836, 0.7351124459689012], 
             UndirectedEdge[227, 243] -> 
             RGBColor[
              0.2526928974888643, 0.38292663528882953`, 0.9377018587351249], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.1986316801099837, 0.3261048681444708, 0.9346231523818017], 
             UndirectedEdge[186, 348] -> 
             RGBColor[
              0.2038426026857459, 0.33158187816317064`, 0.9349199067136222], 
             UndirectedEdge[61, 90] -> 
             RGBColor[
              0.21641762089155886`, 0.3447990195996844, 0.935636035397371], 
             UndirectedEdge[72, 325] -> 
             RGBColor[
              0.35190435537579295`, 0.4723760276667679, 0.9439742559127038], 
             UndirectedEdge[341, 358] -> 
             RGBColor[
              0.26347030119752707`, 0.39425436991349627`, 0.9383156159325932],
              UndirectedEdge[102, 337] -> 
             RGBColor[
              0.6530069899856277, 0.722086925969716, 0.9505841497129952], 
             UndirectedEdge[297, 378] -> 
             RGBColor[
              0.2683985374759716, 0.3994342587103688, 0.9385962716979784], 
             UndirectedEdge[300, 370] -> 
             RGBColor[
              0.19085384504698283`, 0.3179298703500313, 0.9341802161812396], 
             UndirectedEdge[46, 52] -> 
             RGBColor[
              0.89726556755869, 0.9188637535063902, 0.9066512485949225], 
             UndirectedEdge[75, 200] -> 
             RGBColor[
              0.1879784206462758, 0.3149076169924513, 0.9340164650154286], 
             UndirectedEdge[204, 343] -> 
             RGBColor[
              0.1903303530090651, 0.3173796470268675, 0.9341504040841173], 
             UndirectedEdge[32, 199] -> 
             RGBColor[
              0.9051273093812517, 0.578009485902768, 0.5022905305219902], 
             UndirectedEdge[301, 313] -> 
             RGBColor[
              0.2672428397382781, 0.39821954711258417`, 0.9385304564215183], 
             UndirectedEdge[166, 363] -> 
             RGBColor[
              0.3098501203432949, 0.43692070785172515`, 0.9411795622408922], 
             UndirectedEdge[333, 353] -> 
             RGBColor[
              0.97351816640208, 0.9765194565998694, 0.7354387372176427], 
             UndirectedEdge[130, 146] -> 
             RGBColor[
              0.20739635899717102`, 0.3353171013676426, 0.9351222878782466], 
             UndirectedEdge[71, 271] -> 
             RGBColor[
              0.8948533141221586, 0.565840640212504, 0.5514777902284453], 
             UndirectedEdge[123, 332] -> 
             RGBColor[
              0.8304813654821182, 0.2352987088808914, 0.17682229605044186`], 
             UndirectedEdge[340, 361] -> 
             RGBColor[
              0.34048302917169776`, 0.46587738706068504`, 0.9430427098372054],
              UndirectedEdge[165, 322] -> 
             RGBColor[
              0.2103258844391586, 0.3383962183498125, 0.9352891200183233], 
             UndirectedEdge[278, 302] -> 
             RGBColor[
              0.19139766926121787`, 0.31850146407963903`, 0.9342111861657245],
              UndirectedEdge[322, 355] -> 
             RGBColor[
              0.2016258404569241, 0.32925192050983587`, 0.9347936653840967], 
             UndirectedEdge[68, 333] -> 
             RGBColor[
              0.8876904453290742, 0.9128181118706356, 0.9729875018597351], 
             UndirectedEdge[150, 156] -> 
             RGBColor[
              0.22013918030941965`, 0.34871061450835156`, 0.9358479727006643],
              UndirectedEdge[29, 357] -> 
             RGBColor[
              0.18592235681432462`, 0.3127465635430944, 0.9338993752218727], 
             UndirectedEdge[250, 325] -> 
             RGBColor[
              0.21599606078555122`, 0.34435593319981583`, 0.9356120281729761],
              UndirectedEdge[53, 131] -> 
             RGBColor[
              0.6083578580504109, 0.6889233390243821, 0.9644906126536026], 
             UndirectedEdge[92, 267] -> 
             RGBColor[
              0.20096723062757926`, 0.3285596798209194, 0.9347561585286415], 
             UndirectedEdge[269, 309] -> 
             RGBColor[
              0.5253850164437505, 0.6220146854886827, 0.9571050895141], 
             UndirectedEdge[162, 336] -> 
             RGBColor[
              0.21504897720554328`, 0.3433604883086603, 0.9355580931641793], 
             UndirectedEdge[94, 204] -> 
             RGBColor[
              0.1795232819748228, 0.3060207301619996, 0.9335349573763461], 
             UndirectedEdge[29, 183] -> 
             RGBColor[
              0.18726251983199932`, 0.31415515984591347`, 0.9339756955231359],
              UndirectedEdge[145, 208] -> 
             RGBColor[
              0.2721455459278671, 0.4033726021673685, 0.9388096582861116], 
             UndirectedEdge[75, 133] -> 
             RGBColor[
              0.18265733709091148`, 0.3093148207995801, 0.9337134371787883], 
             UndirectedEdge[169, 326] -> 
             RGBColor[
              0.349415147686683, 0.47074983716853436`, 0.9437423719170701], 
             UndirectedEdge[95, 97] -> 
             RGBColor[
              0.27292796870059677`, 0.4041949781099764, 0.9388542161055278], 
             UndirectedEdge[37, 78] -> 
             RGBColor[
              0.25239861099731176`, 0.3826173215273665, 0.9376850995547887], 
             UndirectedEdge[55, 397] -> 
             RGBColor[
              0.5839584526615165, 0.6682303773203624, 0.9627494310951048], 
             UndirectedEdge[185, 226] -> 
             RGBColor[
              0.1922271263061977, 0.3193732760245269, 0.9342584225173644], 
             UndirectedEdge[39, 254] -> 
             RGBColor[
              0.19262591917799537`, 0.31979243261771473`, 0.934281133181452], 
             UndirectedEdge[71, 201] -> 
             RGBColor[
              0.8177089698538784, 0.8578529670679469, 0.9517417151457506], 
             UndirectedEdge[227, 383] -> 
             RGBColor[
              0.3161546993185588, 0.44504578365193476`, 0.9414837289337784], 
             UndirectedEdge[38, 151] -> 
             RGBColor[
              0.23316903340538708`, 0.36240581625261525`, 0.9365900035585395],
              UndirectedEdge[45, 74] -> 
             RGBColor[
              0.2441275547351621, 0.3739239169805914, 0.9372140751365906], 
             UndirectedEdge[292, 303] -> 
             RGBColor[
              0.8567109713559, 0.3810358674996849, 0.1997518680171543], 
             UndirectedEdge[185, 357] -> 
             RGBColor[
              0.18927662196416456`, 0.31627210888827, 0.9340903956599655], 
             UndirectedEdge[86, 376] -> 
             RGBColor[
              0.2771391258654599, 0.4086211712930332, 0.939094035276218], 
             UndirectedEdge[212, 309] -> 
             RGBColor[
              0.6375731061251859, 0.7158069480258249, 0.965187359754256], 
             UndirectedEdge[50, 127] -> 
             RGBColor[
              0.28524823564473223`, 0.4143130772255349, 0.9396595042068966], 
             UndirectedEdge[92, 374] -> 
             RGBColor[
              0.1940034937220554, 0.32124035080679264`, 0.9343595840137974], 
             UndirectedEdge[118, 141] -> 
             RGBColor[
              0.35660710592589273`, 0.4832968843838794, 0.9439436673476838], 
             UndirectedEdge[205, 390] -> 
             RGBColor[
              0.19906834334491935`, 0.32656382889043634`, 
               0.9346480197070459]}, GraphLayout -> {"Dimension" -> 2}, 
           ImageSize -> 500, VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.24987309085249598`, 0.3799628397279394, 0.9375412749187138], 
             316 -> RGBColor[
              0.7121412574025138, 0.7750494298476431, 0.9719432432656107], 
             308 -> RGBColor[
              0.212847764567014, 0.3410468742606238, 0.9354327373608172], 160 -> 
             RGBColor[
              0.19529547244710238`, 0.32259830236299947`, 0.9344331602908775],
              245 -> RGBColor[
              0.19489410730752896`, 0.3221764421532881, 0.9344103031399453], 
             155 -> RGBColor[
              0.1858996679095085, 0.31272271606557295`, 0.9338980831223087], 
             213 -> RGBColor[
              0.3254133616442444, 0.45627843093029025`, 0.9419560295456021], 
             352 -> RGBColor[
              0.18638553952238943`, 0.3132333979367503, 0.9339257527918797], 
             27 -> RGBColor[
              0.20503271821821972`, 0.3328327650454837, 0.9349876820325784], 
             367 -> RGBColor[
              0.1860930553658944, 0.31292597854370746`, 0.9339090962518588], 
             19 -> 
             RGBColor[
              0.19951285246669712`, 0.3270310361609309, 0.9346733338439388], 
             164 -> RGBColor[
              0.21499276582137244`, 0.3433014065798891, 0.935554892009008], 
             190 -> RGBColor[
              0.2121526703486752, 0.34031628616563087`, 0.9353931527733826], 
             103 -> RGBColor[
              0.19478977051563845`, 0.3220667775696765, 0.9344043613139996], 
             138 -> RGBColor[
              0.2889051941793347, 0.4209880551027343, 0.939764095460355], 291 -> 
             RGBColor[
              0.1954605501868454, 0.3227718095340026, 0.9344425612239453], 28 -> 
             RGBColor[
              0.19159599737019925`, 0.31870991949690686`, 0.9342224806581308],
              337 -> RGBColor[
              0.956979221732861, 0.9674357545252026, 0.9577071353769899], 195 -> 
             RGBColor[
              0.42461827381123246`, 0.5422047396654701, 0.9482772788254231], 
             114 -> RGBColor[
              0.18667779652152947`, 0.3135405785730105, 0.9339423963956253], 
             93 -> RGBColor[
              0.3425287629814334, 0.47110293132347947`, 0.9430466077842526], 
             34 -> RGBColor[
              0.1829376663072982, 0.30960946457990146`, 0.9337294015129516], 
             161 -> RGBColor[
              0.8795463410175769, 0.5459298918751729, 0.22120285316675511`], 
             22 -> RGBColor[
              0.24203296140503872`, 0.3717223665857442, 0.9370947911451132], 
             124 -> RGBColor[
              0.22661866237074535`, 0.3555209609776956, 0.9362169696185221], 
             84 -> RGBColor[
              0.21428709115836797`, 0.3425596977667136, 0.935514704880902], 
             46 -> RGBColor[
              0.8055364749096104, 0.8480104835941301, 0.9812520057187881], 
             241 -> RGBColor[
              0.28091140737960196`, 0.41258607834085864`, 0.939308861127858], 
             185 -> RGBColor[
              0.19254963929720473`, 0.31971225762658, 0.9342767891550869], 
             390 -> RGBColor[
              0.21298290042549683`, 0.3411889106159976, 0.9354404331480423], 
             121 -> RGBColor[
              0.24372417422141443`, 0.37349993848484087`, 0.9371911032130806],
              322 -> RGBColor[
              0.1951112049063669, 0.3224046254944496, 0.9344226665270321], 
             126 -> RGBColor[
              0.18255935854789945`, 0.309211839138676, 0.9337078574457099], 
             236 -> RGBColor[
              0.5096359477486948, 0.612784447077024, 0.9545395551462174], 78 -> 
             RGBColor[
              0.22046571832082573`, 0.34905382666204504`, 0.9358665685573442],
              376 -> RGBColor[
              0.28617898913701123`, 0.4181226407518692, 0.9396088421162536], 
             254 -> RGBColor[
              0.1870776850955973, 0.3139608868187558, 0.9339651694583363], 
             290 -> RGBColor[
              0.25752973177491306`, 0.38801045479647306`, 0.9379773092922603],
              251 -> RGBColor[
              0.1849258667142184, 0.3116991892667612, 0.9338426265848467], 
             165 -> RGBColor[
              0.22554056397195027`, 0.35438781120517543`, 0.9361555735096144],
              100 -> RGBColor[
              0.387712192347488, 0.5102385468551641, 0.9459256559493198], 235 -> 
             RGBColor[
              0.19324911536591247`, 0.3204474513241361, 0.9343166232824178], 
             70 -> RGBColor[
              0.1969643686712329, 0.32435241810869275`, 0.934528201461931], 
             234 -> RGBColor[
              0.24693624036742998`, 0.3768760236610595, 0.9373740256282702], 
             257 -> RGBColor[
              0.9694202648664492, 0.9767142641238943, 0.9366476944955487], 
             135 -> RGBColor[
              0.335355251737071, 0.46488959643477135`, 0.9425895179910487], 
             265 -> RGBColor[
              0.19899652547638796`, 0.32648834375709396`, 0.934643929785678], 
             111 -> RGBColor[
              0.8266120846200963, 0.20555772064570646`, 0.17311706832724205`],
              381 -> RGBColor[
              0.1893487791980019, 0.3163479507160659, 0.9340945049076855], 
             182 -> RGBColor[
              0.24182762690147153`, 0.3715065470035356, 0.9370830976489003], 
             188 -> RGBColor[
              0.27580922111776024`, 0.4072233570823697, 0.9390182991682543], 
             154 -> RGBColor[
              0.18637271886218407`, 0.3132199226099977, 0.9339250226742475], 
             336 -> RGBColor[
              0.23480104226620413`, 0.36412116104067216`, 0.9366829440488222],
              315 -> RGBColor[
              0.1811098371299533, 0.3076883002234485, 0.9336253093453327], 
             368 -> RGBColor[
              0.1838330998850932, 0.3105506220439319, 0.9337803951305317], 
             269 -> RGBColor[
              0.3534033382914345, 0.480521941884955, 0.9437395261069965], 208 -> 
             RGBColor[
              0.2944180010032382, 0.4267823646067975, 0.9400780416535094], 86 -> 
             RGBColor[
              0.2680992625939086, 0.39911970183419715`, 0.9385792284361825], 
             119 -> 
             RGBColor[
              0.2397898236287226, 0.36936468655968646`, 0.936967047767177], 
             377 -> RGBColor[
              0.25469411239970985`, 0.38503003904448196`, 0.9378158249637654],
              140 -> RGBColor[
              0.4063466574019441, 0.5263787838898877, 0.9471130275847793], 85 -> 
             RGBColor[
              0.1818888062976524, 0.30850704620819813`, 0.9336696704870515], 
             351 -> RGBColor[
              0.3095548228305918, 0.44254256168324113`, 0.9409455374755513], 
             242 -> RGBColor[
              0.3403985574835718, 0.4692578543884732, 0.9429108729735957], 
             117 -> RGBColor[
              0.5585316039927765, 0.6524801435401812, 0.9583888003164419], 47 -> 
             RGBColor[
              0.18100426741029385`, 0.3075773397545796, 0.9336192973059745], 
             81 -> RGBColor[
              0.22915597848204, 0.35818784108579943`, 0.9363614660174375], 
             275 -> RGBColor[
              0.194144227344503, 0.3213882707670121, 0.934367598585399], 23 -> 
             RGBColor[
              0.2119196850624197, 0.340071403857656, 0.9353798846060012], 328 -> 
             RGBColor[
              0.2313516506730186, 0.3604956317721754, 0.9364865063005079], 
             110 -> RGBColor[
              0.8529626688242167, 0.8855932953383124, 0.985837534872859], 6 -> 
             RGBColor[
              0.9261633007621113, 0.943961492267368, 0.992819476494071], 218 -> 
             RGBColor[
              0.5602763464580424, 0.6538966040732364, 0.9585261528345099], 
             108 -> RGBColor[
              0.3063635945960659, 0.4393379408672382, 0.9407583255366989], 
             297 -> RGBColor[
              0.2965600408339725, 0.42903378428206873`, 0.9402000276530058], 
             157 -> RGBColor[
              0.24686136029389427`, 0.3767973199561026, 0.9373697613188575], 
             354 -> RGBColor[
              0.19610120868731518`, 0.3234451822380914, 0.9344790457777777], 
             385 -> RGBColor[
              0.9944175835604394, 0.9904681006416884, 0.633766605113725], 270 -> 
             RGBColor[
              0.20794500379241626`, 0.3358937618335345, 0.9351535323876885], 
             392 -> RGBColor[
              0.2030621295519029, 0.3307615514146469, 0.9348754599232564], 33 -> 
             RGBColor[
              0.24658940627570813`, 0.37651147904010834`, 0.9373542739398417],
              252 -> RGBColor[
              0.20594129701488287`, 0.33378773896799957`, 0.9350394242509266],
              394 -> 
             RGBColor[
              0.35762511408731845`, 0.48417863188672844`, 0.9440085339275405],
              260 -> RGBColor[
              0.1889310324973132, 0.31590887244697147`, 0.9340707148510822], 
             159 -> RGBColor[
              0.18214142158537838`, 0.30877256089233246`, 0.9336840565539767],
              183 -> RGBColor[
              0.18868393066647376`, 0.3156491527555983, 0.9340566427673703], 
             99 -> RGBColor[
              0.9021660914511284, 0.9248267689496842, 0.9905306012474278], 
             329 -> RGBColor[
              0.2623389378177228, 0.3930652352687406, 0.9382511864618155], 
             309 -> RGBColor[
              0.6973666945960665, 0.7635074290924103, 0.9704706529212034], 17 -> 
             RGBColor[
              0.8276616884309496, 0.21362543547524793`, 0.17412217012187317`],
              349 -> RGBColor[
              0.19841472542917707`, 0.32587683501922177`, 0.9346107971336854],
              347 -> RGBColor[
              0.18432439621433888`, 0.3110670056359555, 0.9338083737296745], 
             340 -> RGBColor[
              0.27139200070452485`, 0.4025805783601091, 0.9387667450004126], 
             277 -> RGBColor[
              0.1851145385676597, 0.3118974953472144, 0.9338533711677852], 
             104 -> RGBColor[
              0.22404918964109946`, 0.35282028222485723`, 0.936070641947763], 
             79 -> RGBColor[
              0.199051197909799, 0.3265458079510415, 0.9346470432998802], 327 -> 
             RGBColor[
              0.18576331458524015`, 0.3125794000764668, 0.9338903180022083], 
             191 -> RGBColor[
              0.1840091371887301, 0.310735648411464, 0.9337904201945499], 50 -> 
             RGBColor[
              0.23112771995435683`, 0.3602602663888343, 0.9364737537773559], 
             225 -> RGBColor[
              0.2084820527788493, 0.336458234369148, 0.9351841165329731], 61 -> 
             RGBColor[
              0.21726621743653565`, 0.3456909483725835, 0.9356843617152213], 
             196 -> RGBColor[
              0.844124603334554, 0.8785460618197521, 0.9849945522966208], 1 -> 
             RGBColor[
              0.1818132732838514, 0.3084276562216236, 0.9336653689936567], 
             263 -> RGBColor[
              0.30183205672017543`, 0.43457500724358145`, 0.9405002611584765],
              201 -> RGBColor[
              0.6657140642559093, 0.738780153701779, 0.9673158145395446], 371 -> 
             RGBColor[
              0.18003320207443918`, 0.306556688517498, 0.93356399657166], 293 -> 
             RGBColor[
              0.3141297509318431, 0.44650513446197276`, 0.941237047848713], 
             362 -> RGBColor[
              0.7912709059084366, 0.8368661126680731, 0.979830147120073], 184 -> 
             RGBColor[
              0.21355297767290998`, 0.3417880979480139, 0.9354728982039288], 
             106 -> RGBColor[
              0.1865190623784995, 0.31337373892436005`, 0.9339333567210057], 
             206 -> RGBColor[
              0.4288884024290853, 0.5459033104513494, 0.9485493676450263], 
             358 -> RGBColor[
              0.2775970966062373, 0.4091025275786123, 0.9391201160323983], 
             247 -> RGBColor[
              0.8173387448883187, 0.1342787678638822, 0.16423690772735258`], 
             220 -> RGBColor[
              0.17970434930417156`, 0.30621104340547683`, 0.9335452688928874],
              107 -> RGBColor[
              0.2230811340648649, 0.3518027944359661, 0.9360155126148064], 
             375 -> RGBColor[
              0.20279567675606608`, 0.3304814926321394, 0.9348602858307151], 
             131 -> RGBColor[
              0.8141109072907318, 0.8547088953383618, 0.982106625005912], 127 -> 
             RGBColor[
              0.3393687513351076, 0.46836588806223545`, 0.9428452546364373], 
             210 -> RGBColor[
              0.2456807114445148, 0.37555638315794415`, 0.9373025251134988], 
             357 -> RGBColor[
              0.18600360463112436`, 0.31283196014996, 0.9339040021648441], 
             181 -> RGBColor[
              0.19212227783830665`, 0.31926307363699663`, 0.9342524515522274],
              194 -> RGBColor[
              0.4554399226734993, 0.5687856724178738, 0.9502730455257168], 
             118 -> RGBColor[
              0.3574473894517768, 0.48402469574012214`, 0.9439972094709195], 
             348 -> RGBColor[
              0.20110409825488346`, 0.3287035363751249, 0.9347639529375389], 
             276 -> RGBColor[
              0.37904525788294496`, 0.5027316838347692, 0.9453734065491083], 
             305 -> RGBColor[
              0.29805944165302733`, 0.4306097496103981, 0.9402854163114862], 
             343 -> RGBColor[
              0.20071986914810575`, 0.3282996872223691, 0.9347420716583239], 
             280 -> RGBColor[
              0.2089289786028837, 0.3369279817469421, 0.9352095682974844], 
             189 -> RGBColor[
              0.2331737072204319, 0.36241072872856434`, 0.9365902697253919], 
             168 -> RGBColor[
              0.19796437105250972`, 0.32540348401522773`, 0.9345851501181738],
              363 -> 
             RGBColor[
              0.3745258073527012, 0.4988171629396605, 0.9450854311577144], 41 -> 
             RGBColor[
              0.19479503600678127`, 0.322072311934719, 0.9344046611759306], 
             14 -> RGBColor[
              0.3386493168091526, 0.46774275003568394`, 0.9427994129046144], 
             77 -> RGBColor[
              0.1969521059625652, 0.3243395292243824, 0.9345275031188135], 51 -> 
             RGBColor[
              0.20120879960667537`, 0.3288135841343073, 0.9347699155246316], 
             179 -> RGBColor[
              0.2268131918331927, 0.35572542377660804`, 0.9362280477836279], 
             223 -> RGBColor[
              0.8592163258347785, 0.4536160411257659, 0.20423899016395516`], 
             323 -> RGBColor[
              0.42062186552277797`, 0.5387432516713317, 0.9480226312231679], 
             292 -> RGBColor[
              0.8194918846006688, 0.15082874320484374`, 0.1662987567475226], 
             396 -> RGBColor[
              0.18439801323969868`, 0.31114438179719767`, 0.9338125661103621],
              321 -> RGBColor[
              0.18455342051778426`, 0.3113077246998561, 0.9338214163249446], 
             143 -> RGBColor[
              0.19890345919190142`, 0.32639052519135536`, 0.9346386297984558],
              112 -> RGBColor[
              0.1804406002012431, 0.3069848897793021, 0.93358719729229], 197 -> 
             RGBColor[
              0.19131157595015044`, 0.3184109745510759, 0.9342062832790229], 
             54 -> RGBColor[
              0.9482538006021336, 0.8325505933258706, 0.2772219972063093], 71 -> 
             RGBColor[
              0.9697038754518477, 0.9769257804341147, 0.9361676157519565], 
             177 -> RGBColor[
              0.18139651046953492`, 0.3079896120794884, 0.9336416349679267], 
             158 -> RGBColor[
              0.1911403477299942, 0.3182310028351955, 0.9341965320851944], 
             226 -> RGBColor[
              0.19190461331519068`, 0.3190342944224739, 0.9342400558796418], 
             350 -> RGBColor[
              0.3485452682138572, 0.4763141257574593, 0.943429974177476], 203 -> 
             RGBColor[
              0.3100095560527289, 0.44293642874469996`, 0.9409745126743612], 
             115 -> RGBColor[
              0.9551078718556497, 0.8597247018622127, 0.2827369438226184], 
             173 -> RGBColor[
              0.17959143492855675`, 0.30609236323752076`, 0.933538838586238], 
             212 -> RGBColor[
              0.5777795176543054, 0.6681064669592394, 0.9599040665873084], 
             129 -> 
             RGBColor[
              0.8193361618613183, 0.1496317899920564, 0.1661496364764569], 
             279 -> RGBColor[
              0.1990369147875074, 0.3265307954839108, 0.9346462298971957], 26 -> 
             RGBColor[
              0.1822568035379685, 0.30889383464014303`, 0.9336906273854845], 
             40 -> RGBColor[
              0.1934487547814754, 0.32065728500776275`, 0.934327992451794], 
             146 -> RGBColor[
              0.1991293041825628, 0.32662790259593993`, 0.9346514913365662], 
             386 -> RGBColor[
              0.3419268933615933, 0.4705816221096207, 0.9430082571842888], 
             192 -> RGBColor[
              0.2582664433427927, 0.3887847853645258, 0.938019263926184], 300 -> 
             RGBColor[
              0.19616100168040002`, 0.3235080284649182, 0.934482450900278], 
             221 -> RGBColor[
              0.36991176607450643`, 0.49482071229294583`, 0.9447914285275043],
              62 -> RGBColor[
              0.9918038536315829, 0.990878697092375, 0.7854948864789351], 286 -> 
             RGBColor[
              0.3212434064694567, 0.45266662534593033`, 0.9416903236892111], 
             152 -> RGBColor[
              0.2008438754397465, 0.3284300256973365, 0.9347491336331819], 64 -> 
             RGBColor[
              0.9925852496598342, 0.986548923705669, 0.43432836788688456`], 
             307 -> RGBColor[
              0.17902996710188124`, 0.3055022249525685, 0.933506863824126], 
             37 -> RGBColor[
              0.2843315036737978, 0.41618081639268795`, 0.9395036305522334], 
             148 -> RGBColor[
              0.25655300447979307`, 0.38698385248121464`, 0.9379216861177417],
              261 -> RGBColor[
              0.18920356017618423`, 0.31619531631671777`, 0.9340862348992254],
              387 -> RGBColor[
              0.18554205504628538`, 0.3123468422723603, 0.933877717598789], 
             15 -> RGBColor[
              0.18212992963139682`, 0.3087604821200659, 0.9336834021041983], 
             136 -> RGBColor[
              0.18263620644148504`, 0.30929261114727236`, 0.9337122338195634],
              198 -> RGBColor[
              0.8287975688378628, 0.8663247005533589, 0.9835326460637211], 63 -> 
             RGBColor[
              0.18932442036239164`, 0.31632234803540016`, 0.9340931177080333],
              310 -> RGBColor[
              0.8265166883216026, 0.20482446289255998`, 0.17302571672406986`],
              171 -> RGBColor[
              0.18805335571358273`, 0.3149863784993486, 0.9340207324566552], 
             395 -> 
             RGBColor[
              0.4386808762090538, 0.554385059055515, 0.9491733354151413], 311 -> 
             RGBColor[
              0.2025961788233211, 0.3302718076559249, 0.934848924718576], 353 -> 
             RGBColor[
              0.9932598001133134, 0.9879917189181485, 0.507749021905247], 59 -> 
             RGBColor[
              0.21627237251575757`, 0.34464635434743823`, 0.9356277637172448],
              397 -> RGBColor[
              0.36417957475425095`, 0.48985577627965343`, 0.9444261783653554],
              229 -> RGBColor[
              0.19792175174780763`, 0.3253586884237658, 0.9345827230118207], 
             102 -> RGBColor[
              0.34903475823839447`, 0.4767380974142295, 0.9434611640490004], 
             299 -> RGBColor[
              0.18838969891108812`, 0.3153398965253172, 0.9340398867041779], 
             128 -> RGBColor[
              0.3039019362504366, 0.4367505818678281, 0.9406181377356125], 12 -> 
             RGBColor[
              0.242785484860208, 0.37251331644986996`, 0.9371376462426264], 
             222 -> RGBColor[
              0.9510874915293103, 0.9630417117862173, 0.9676802978022608], 92 -> 
             RGBColor[
              0.20437042968316516`, 0.3321366578036229, 0.9349499656802752], 
             271 -> RGBColor[
              0.8200027527924696, 0.15475549999089333`, 0.1667879647049341], 
             361 -> RGBColor[
              0.40957405763887067`, 0.529174195761261, 0.9473186746739982], 
             344 -> RGBColor[
              0.1915625031716876, 0.3186747149706162, 0.9342205732130758], 
             132 -> RGBColor[
              0.19287402797566439`, 0.32005321069507126`, 0.9342952626104353],
              80 -> RGBColor[
              0.20310658273494972`, 0.3308082745285237, 0.9348779914662683], 
             324 -> RGBColor[
              0.1856877903127057, 0.31250001927751764`, 0.9338860170066157], 
             244 -> RGBColor[
              0.18235944175044905`, 0.3090017139090986, 0.9336964724798456], 
             150 -> RGBColor[
              0.23840666361665402`, 0.3679108976895925, 0.9368882788506916], 
             125 -> RGBColor[
              0.1925981967986741, 0.3197632946393477, 0.9342795544329613], 
             258 -> RGBColor[
              0.23765262088408304`, 0.3671183509685898, 0.9368453372325779], 
             133 -> RGBColor[
              0.18340497994045135`, 0.3101006408377411, 0.933756014333031], 
             255 -> RGBColor[
              0.37418878878290995`, 0.4985252543935531, 0.9450639566324611], 
             326 -> 
             RGBColor[
              0.24157157412247404`, 0.37123741929812537`, 0.9370685158219325],
              176 -> RGBColor[
              0.18620451936940718`, 0.3130431342786254, 0.9339154439619627], 
             230 -> RGBColor[
              0.2211253737681676, 0.3497471663617724, 0.9359041349591976], 
             274 -> RGBColor[
              0.20313982636998706`, 0.33084321569671615`, 0.9348798846421041],
              87 -> RGBColor[
              0.18684859723136407`, 0.31372010094843716`, 0.9339521232433733],
              130 -> RGBColor[
              0.21566341381177923`, 0.3440063001393452, 0.9355930844199268], 
             35 -> RGBColor[
              0.19009976398754364`, 0.3171372833450601, 0.9341372723804675], 
             379 -> RGBColor[
              0.18246816409549027`, 0.30911598798713175`, 0.9337026640565553],
              31 -> RGBColor[
              0.9842583887354778, 0.9877584534482328, 0.9105427668445933], 18 -> 
             RGBColor[
              0.9925358512363838, 0.9864432654728553, 0.42895165434603927`], 
             24 -> RGBColor[
              0.2601817623901309, 0.39079790712151985`, 0.9381283385124692], 
             151 -> RGBColor[
              0.20761230953904478`, 0.335544079079207, 0.935134585942136], 
             137 -> RGBColor[
              0.29264465833089975`, 0.42491846902175034`, 0.9399770524117451],
              330 -> RGBColor[
              0.18870039039885345`, 0.3156664529779366, 0.9340575801247794], 
             296 -> RGBColor[
              0.17907641669607907`, 0.3055510464211448, 0.9335095090597996], 
             266 -> RGBColor[
              0.6582217134144572, 0.7329270722804612, 0.9665690470276681], 
             302 -> RGBColor[
              0.19470143524485908`, 0.32197393159930776`, 0.9343993307510091],
              283 -> RGBColor[
              0.9319225428018962, 0.7678025982169813, 0.26408148383634866`], 
             388 -> RGBColor[
              0.2707814877613013, 0.40193889054802484`, 0.938731977191469], 
             284 -> RGBColor[
              0.7398648594018855, 0.7967073184367315, 0.9747064728211174], 
             318 -> RGBColor[
              0.21345649486519924`, 0.3416866883997466, 0.9354674036507632], 
             238 -> RGBColor[
              0.20088219976865415`, 0.32847030699692126`, 0.9347513161470175],
              72 -> RGBColor[
              0.46553671991296847`, 0.576982707272407, 0.9510679023901947], 
             288 -> RGBColor[
              0.2137339467700851, 0.34197830794324846`, 0.935483204126293], 
             382 -> 
             RGBColor[
              0.3220959675484921, 0.453405070901625, 0.9417446481272771], 389 -> 
             RGBColor[
              0.9931232770303468, 0.9876997098482838, 0.4928893268471293], 
             172 -> RGBColor[
              0.3796233347917912, 0.5032323849982215, 0.9454102410985666], 
             243 -> RGBColor[
              0.23139395253121084`, 0.36054009370722817`, 0.9364889153287519],
              88 -> RGBColor[
              0.4303958842275222, 0.5472090154169172, 0.9486454230522088], 
             273 -> RGBColor[
              0.5240458703783706, 0.6244830714274116, 0.9556739570409113], 
             202 -> RGBColor[
              0.3275914997751332, 0.4581650247028605, 0.9420948185812503], 
             393 -> RGBColor[
              0.7219717591850786, 0.7827290925547635, 0.9729230558120345], 98 -> 
             RGBColor[
              0.1932487717488401, 0.3204470901608064, 0.9343166037139339], 30 -> 
             RGBColor[
              0.20069898841488326`, 0.3282777402478373, 0.9347408825314572], 
             116 -> RGBColor[
              0.24002120291967022`, 0.3696078808647668, 0.9369802244755014], 
             373 -> RGBColor[
              0.19798515205544082`, 0.3254253261669, 0.934586333565548], 240 -> 
             RGBColor[
              0.17933281357579656`, 0.305820535798229, 0.9335241104827943], 
             317 -> RGBColor[
              0.18850413369751906`, 0.3154601747414406, 0.9340464035959741], 
             391 -> RGBColor[
              0.8202342132018924, 0.1565346061243149, 0.16700961145439447`], 
             73 -> RGBColor[
              0.1985117660113969, 0.3259788308238631, 0.9346163234512842], 
             303 -> RGBColor[
              0.8939300581111314, 0.611242991794526, 0.23320497928678602`], 
             29 -> RGBColor[
              0.18584110899752487`, 0.3126611669362287, 0.9338947482789014], 
             360 -> RGBColor[
              0.6627555094400547, 0.736468908193784, 0.9670209334447669], 320 -> 
             RGBColor[
              0.18370800885926494`, 0.3104191434445573, 0.9337732713816664], 
             75 -> RGBColor[
              0.18190969424137163`, 0.30852900076141915`, 0.9336708600245455],
              200 -> RGBColor[
              0.19404714705117995`, 0.3212862332234835, 0.9343620700063117], 
             301 -> RGBColor[
              0.24986810421890843`, 0.3799575984598681, 0.937540990937308], 
             156 -> RGBColor[
              0.20187169700218524`, 0.3295103313271106, 0.9348076665506371], 
             25 -> 
             RGBColor[
              0.3639618362230004, 0.489667182107741, 0.9444123042586827], 38 -> 
             RGBColor[
              0.2587257572717294, 0.3892675534260234, 0.9380454211749428], 
             365 -> RGBColor[
              0.30601698137869693`, 0.43897362839923615`, 0.940738586426738], 
             380 -> RGBColor[
              0.7203821791624184, 0.7814873005598058, 0.9727646213308456], 
             370 -> RGBColor[
              0.18554668841356567`, 0.31235171223514435`, 0.9338779814622011],
              3 -> RGBColor[
              0.23621542372166607`, 0.36560776562732644`, 0.9367634909803209],
              57 -> RGBColor[
              0.3482989604247025, 0.47610078633028297`, 0.9434142796629524], 
             227 -> RGBColor[
              0.2739918424465178, 0.40531317687043084`, 0.9389148021414978], 
             39 -> RGBColor[
              0.19817415326039348`, 0.32562397841667373`, 0.9345970969045678],
              109 -> RGBColor[
              0.1827503081177702, 0.3094125392435122, 0.9337187317412295], 
             256 -> RGBColor[
              0.9923039511135691, 0.9910855002530954, 0.777206976991627], 339 -> 
             RGBColor[
              0.38195753878243316`, 0.5052541551744117, 0.9455589745127948], 
             287 -> RGBColor[0.817319, 0.134127, 0.164218], 239 -> 
             RGBColor[
              0.5071373117219987, 0.6107559417882819, 0.9543428533653905], 
             285 -> RGBColor[
              0.18427610046840573`, 0.31101624374485265`, 0.9338056233583907],
              345 -> RGBColor[
              0.8280837295399454, 0.865755504473851, 0.9834645594342339], 366 -> 
             RGBColor[
              0.9933000584574108, 0.9880778274454297, 0.5121308942145434], 
             216 -> RGBColor[
              0.21581639795358076`, 0.3441670961721334, 0.9356017966404827], 
             21 -> RGBColor[
              0.19666790482252822`, 0.3240408158068105, 0.9345113182843263], 
             355 -> RGBColor[
              0.2081404760074813, 0.3360992155252221, 0.9351646642411613], 
             175 -> RGBColor[
              0.19013667027984396`, 0.3171760741982618, 0.9341393741392161], 
             7 -> RGBColor[
              0.25494849258932906`, 0.3852974087524073, 0.9378303115392425], 
             13 -> RGBColor[
              0.21336291477373137`, 0.3415883297902934, 0.9354620744029933], 
             294 -> RGBColor[
              0.20973292712492791`, 0.3377729826168909, 0.9352553519764795], 
             193 -> RGBColor[
              0.8379281346647119, 0.8736051659010814, 0.9844035275832383], 60 -> 
             RGBColor[
              0.7070237961498369, 0.7710516302229059, 0.9714331825533382], 65 -> 
             RGBColor[
              0.3764941167365503, 0.5005220135978444, 0.9452108500911456], 69 -> 
             RGBColor[
              0.5728179374316162, 0.6640784326178184, 0.9595134728173111], 
             217 -> RGBColor[
              0.2082469591636211, 0.3362111360737471, 0.9351707282993756], 
             214 -> RGBColor[
              0.8789213821202363, 0.5430920994852084, 0.22068137214366979`], 
             170 -> RGBColor[
              0.23550398192177388`, 0.3648599951876243, 0.9367229754223009], 
             359 -> RGBColor[
              0.32568965645452963`, 0.4565177436079784, 0.9419736348065956], 
             74 -> RGBColor[
              0.24853385159996577`, 0.37855521436085726`, 0.9374650072245091],
              246 -> RGBColor[
              0.2167015948028579, 0.34509749418544555`, 0.9356522072915177], 
             264 -> RGBColor[
              0.2599789274537134, 0.39058471474286727`, 0.9381167873629076], 
             278 -> RGBColor[
              0.1880939032775767, 0.3150289965599703, 0.9340230415804399], 45 -> 
             RGBColor[
              0.23972125787035842`, 0.36929261960032556`, 0.9369631430486721],
              306 -> RGBColor[
              0.22229995450050422`, 0.350981725184178, 0.9359710255942676], 
             237 -> RGBColor[
              0.18222514168352894`, 0.3088605560236495, 0.9336888242897137], 
             228 -> RGBColor[
              0.22400797509009437`, 0.3527769631185974, 0.9360682948400547], 
             180 -> RGBColor[
              0.18842432755960442`, 0.31537629343049095`, 0.9340418587544824],
              383 -> RGBColor[
              0.3583175561905998, 0.4847783904334387, 0.944052655726059], 53 -> 
             RGBColor[
              0.40260480881009003`, 0.5231377827104023, 0.9468746003012931], 
             304 -> RGBColor[
              0.2822705085644714, 0.4140145798581486, 0.9393862599297264], 48 -> 
             RGBColor[
              0.20793893985757575`, 0.3358873882535414, 0.9351531870555702], 
             5 -> RGBColor[
              0.18681770269069906`, 0.3136876288273712, 0.9339503638449868], 
             101 -> RGBColor[
              0.8539737461394735, 0.41587144104017043`, 0.19931862629877445`],
              333 -> RGBColor[
              0.9537765326908467, 0.9650471942815904, 0.9631284525300384], 
             267 -> 
             RGBColor[
              0.19756403157199334`, 0.32498270183821587`, 0.9345623513770076],
              120 -> RGBColor[
              0.41254771032069193`, 0.531749824254125, 0.9475081531933861], 
             147 -> RGBColor[
              0.24721508689536167`, 0.3771691090418067, 0.9373899055255195], 
             89 -> RGBColor[
              0.23222586891438338`, 0.3614144905724877, 0.9365362917360636], 
             43 -> RGBColor[
              0.194697223000598, 0.3219695042635176, 0.9343990908699299], 199 -> 
             RGBColor[
              0.9887357523774989, 0.9896099583772056, 0.8363412642506296], 
             268 -> RGBColor[
              0.187660141527025, 0.31457308545805707`, 0.933998339490439], 
             169 -> RGBColor[
              0.45725872125089195`, 0.5702622550389433, 0.9504162280122078], 
             20 -> RGBColor[
              0.3846257063952153, 0.5075651878546001, 0.9457289877937134], 4 -> 
             RGBColor[
              0.2008450066857079, 0.32843121470856707`, 0.9347491980559659], 
             167 -> RGBColor[
              0.2358064817309028, 0.3651779416666145, 0.9367402023389224], 
             142 -> RGBColor[
              0.4741596199861951, 0.5839831660090739, 0.9517467286706829], 16 -> 
             RGBColor[
              0.22895368331262583`, 0.3579752160364906, 0.9363499456068083], 
             281 -> RGBColor[
              0.39875120665503094`, 0.5197999862113661, 0.9466290521795794], 
             289 -> RGBColor[
              0.4742143938317012, 0.5840276338843894, 0.9517510406684443], 
             398 -> RGBColor[
              0.1808071689883251, 0.3073701768163288, 0.9336080728424244], 
             178 -> RGBColor[
              0.18300767959384703`, 0.309683052983163, 0.9337333886660452], 
             58 -> RGBColor[
              0.19320352841391442`, 0.32039953654720643`, 0.9343140271729413],
              186 -> RGBColor[
              0.2065811071166083, 0.33446021995121644`, 0.9350758604897056], 
             122 -> RGBColor[
              0.18936604401309215`, 0.31636609713137825`, 0.934095488113364], 
             249 -> RGBColor[
              0.18362197162651986`, 0.31032871285786656`, 0.9337683716885422],
              113 -> RGBColor[
              0.1856485479005117, 0.3124587730141891, 0.9338837822092951], 52 -> 
             RGBColor[
              0.9889946602077696, 0.9897170234186503, 0.8320504914710569], 
             187 -> RGBColor[
              0.21634716160662554`, 0.34472496242384276`, 0.9356320228453292],
              259 -> 
             RGBColor[
              0.8954246210317355, 0.9194513034296, 0.9898875937806444], 42 -> 
             RGBColor[
              0.183885630512114, 0.31060583506356493`, 0.9337833866720284], 
             134 -> RGBColor[
              0.17911500115561352`, 0.3055916011345115, 0.9335117063876894], 
             313 -> RGBColor[
              0.28461757525764775`, 0.41648149576530025`, 0.9395199219057286],
              248 -> RGBColor[
              0.1829127869860106, 0.3095833148357881, 0.9337279846724099], 
             174 -> RGBColor[
              0.41783566912403936`, 0.5363299883890472, 0.947845097252377], 
             215 -> RGBColor[
              0.7060709713767632, 0.7703072762684443, 0.9713382138846121], 
             399 -> RGBColor[
              0.3593758114062829, 0.48569499791180964`, 0.944120086812624], 
             83 -> RGBColor[
              0.9509849302078126, 0.9629652217205732, 0.9678539073672795], 95 -> 
             RGBColor[
              0.24723118250472642`, 0.37718602654776967`, 0.9373908221466615],
              166 -> RGBColor[
              0.2451744333338886, 0.3750242527637898, 0.93727369332407], 384 -> 
             RGBColor[
              0.9335847383251342, 0.7743926495727972, 0.2654189253710895], 
             233 -> RGBColor[
              0.9703310152107799, 0.9773935002394792, 0.9351060317243296], 
             295 -> RGBColor[
              0.18590102371033476`, 0.3127241410982041, 0.9338981603331601], 
             141 -> RGBColor[
              0.3557668224000087, 0.48256907302763663`, 0.9438901252244479], 
             319 -> RGBColor[
              0.8324443832728455, 0.2503873238203034, 0.17870208410375396`], 
             205 -> RGBColor[
              0.18515378626434187`, 0.3119387471648751, 0.9338556062660495], 
             224 -> RGBColor[
              0.4977475489543879, 0.6031329093695432, 0.9536036568444898], 
             231 -> RGBColor[
              0.19120668731506069`, 0.31830072994527303`, 0.9342003100264233],
              332 -> RGBColor[
              0.8178049183525352, 0.13786198138836525`, 0.164683315963154], 
             68 -> RGBColor[
              0.8216043579673015, 0.8605890294596807, 0.9828465511894319], 10 -> 
             RGBColor[
              0.8429670986480872, 0.3312695252776902, 0.18877864823079255`], 
             250 -> RGBColor[
              0.19372013073248498`, 0.3209425183385029, 0.9343434469107393], 
             282 -> RGBColor[
              0.31502354175322494`, 0.44727929114822085`, 0.9412939994095033],
              374 -> 
             RGBColor[
              0.1836365577609456, 0.3103440438099624, 0.9337692023473195], 
             232 -> RGBColor[
              0.19035994618760685`, 0.3174107513338308, 0.934152089371856], 
             253 -> RGBColor[
              0.8251923969012658, 0.19464537872765014`, 0.17175757376438203`],
              55 -> RGBColor[
              0.8037373305687819, 0.8466049783610714, 0.9810726838248541], 
             325 -> RGBColor[
              0.23827199083861747`, 0.36776934806112876`, 0.9368806094352129],
              91 -> RGBColor[
              0.5925759149291727, 0.6801188488370776, 0.961068893181775], 105 -> 
             RGBColor[
              0.9853022906708313, 0.9881901337255575, 0.8932426102441758], 36 -> 
             RGBColor[
              0.24565388341041777`, 0.3755281851931126, 0.9373009972966455], 
             123 -> RGBColor[
              0.843157812611701, 0.33273543637341757`, 0.18896127613772973`], 
             94 -> RGBColor[
              0.1791057270796212, 0.3055818534926332, 0.9335111782427814], 
             312 -> RGBColor[
              0.5478165382686445, 0.6437811704771209, 0.9575452710920592], 96 -> 
             RGBColor[
              0.21162927735784165`, 0.3397661669472325, 0.9353633463168451], 
             2 -> RGBColor[
              0.20182540810126717`, 0.3294616787573599, 0.9348050304662081], 
             262 -> RGBColor[
              0.36433321534571095`, 0.4899888520377754, 0.9444359682079841], 
             272 -> RGBColor[
              0.19665135271400355`, 0.3240234184912868, 0.9345103756662324], 
             97 -> RGBColor[
              0.2986247548964671, 0.43120392967218313`, 0.9403176100643942], 
             372 -> RGBColor[
              0.179946795179367, 0.3064658693922636, 0.9335590758268132], 356 -> 
             RGBColor[
              0.9453835605713274, 0.9587877294170835, 0.9773355650906732], 
             346 -> RGBColor[
              0.20342618893072584`, 0.3311442009044876, 0.9348961925663027], 
             341 -> RGBColor[
              0.24934350578881678`, 0.3794062122483802, 0.9375111158327881], 
             209 -> RGBColor[
              0.2650455441851616, 0.3959100501696741, 0.9384053236903759], 
             378 -> RGBColor[
              0.24023703411797065`, 0.3698347331386689, 0.9369925157429511], 
             66 -> RGBColor[
              0.19612721011213427`, 0.3234725113841618, 0.9344805265204555], 
             139 -> RGBColor[
              0.30694355404168716`, 0.4399475150161388, 0.940791353369154], 
             56 -> 
             RGBColor[
              0.5183980864407423, 0.6198979459970778, 0.9552293428008269], 
             335 -> RGBColor[
              0.1982643030525542, 0.3257187315640616, 0.9346022308018668], 
             314 -> RGBColor[
              0.18275376889499648`, 0.30941617673980293`, 0.9337189288273728],
              144 -> RGBColor[
              0.5812572311839399, 0.6709298314718057, 0.9601778449356456], 
             298 -> RGBColor[
              0.20546571259734456`, 0.33328786959137313`, 0.9350123404219118],
              204 -> RGBColor[
              0.17994083687002446`, 0.30645960683136597`, 0.9335587365099107],
              207 -> RGBColor[
              0.1915172466480543, 0.31862714749484833`, 0.934217995921006], 
             334 -> RGBColor[
              0.9602115875305376, 0.8774464833562946, 0.2999299602777051], 
             149 -> RGBColor[
              0.21032620428650672`, 0.3383965545296549, 0.9352891382331565], 
             219 -> RGBColor[0.178927, 0.305394, 0.933501], 400 -> 
             RGBColor[
              0.8221152183090297, 0.17099283563946593`, 0.16881086406928056`],
              9 -> RGBColor[
              0.6863588655876156, 0.7549080294084094, 0.9693734953996518], 11 -> 
             RGBColor[
              0.873192830390407, 0.9017242770380856, 0.9877671057427206], 44 -> 
             RGBColor[
              0.22831342724773274`, 0.3573022663177088, 0.9363134839710866], 
             153 -> RGBColor[
              0.20565135384863537`, 0.33348299031681494`, 0.9350229124165412],
              32 -> RGBColor[
              0.8215188663850046, 0.16640901342833042`, 0.16823979679335105`],
              162 -> RGBColor[
              0.19529691214488243`, 0.32259981557664835`, 0.9344332422795363],
              90 -> RGBColor[
              0.21556902434658207`, 0.3439070908267852, 0.9355877090795206], 
             331 -> RGBColor[
              0.24096885499463874`, 0.3706039232801706, 0.9370341918592453], 
             8 -> RGBColor[
              0.25559866423556843`, 0.38598078037586825`, 0.937867337852653], 
             364 -> RGBColor[
              0.92133834354613, 0.7258397751431882, 0.2555651886720716], 342 -> 
             RGBColor[
              0.18639411010760892`, 0.31324240616522253`, 0.9339262408740289],
              163 -> RGBColor[
              0.17905422337022397`, 0.30552771982853294`, 0.9335082451827241],
              49 -> RGBColor[
              0.18369802063003998`, 0.31040864518235156`, 0.9337727025667882],
              338 -> 
             RGBColor[
              0.21013611726343454`, 0.33819676101619267`, 0.9352783130584011],
              76 -> RGBColor[
              0.2829350020755027, 0.41471300466956446`, 0.9394241018521495], 
             369 -> RGBColor[
              0.1804054273287139, 0.30694792086018496`, 0.933585194249233], 
             82 -> RGBColor[
              0.7597586089991939, 0.8122484668202457, 0.9766892958633172], 67 -> 
             RGBColor[
              0.17940647345367122`, 0.30589795700018124`, 0.9335283053038692],
              211 -> RGBColor[
              0.23248905082520588`, 0.3616911114474591, 
               0.9365512795565422]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9mGk41G3YxiVbGGbGGGMMZp+JsVWihTktLbQQJSTFQyShTSoPqYhQlpJK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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 5}], {
             RGBColor[
             0.18431548798727523`, 0.3110576425244974, 0.9338078664193217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.18382719114068813`, 0.31054441157892615`, 0.933780058636279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 73}], {
             RGBColor[
             0.19016251964762415`, 0.3172032435227433, 0.9341408462224705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[
             0.18373091059218155`, 0.31044321461790636`, 0.9337745756014759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 162}], {
             RGBColor[
             0.18855509271436693`, 0.315513735899136, 0.9340493056365965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 183}], {
             RGBColor[
             0.18524860197516257`, 0.312038404488611, 0.9338610058805135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 291}], {
             RGBColor[
             0.1886369117353484, 0.31559973287781307`, 0.934053965108801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 357}], {
             RGBColor[
             0.18390843895748787`, 0.3106298081857918, 0.9337846855792504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 368}], {
             RGBColor[
             0.1828231865844723, 0.30948913913277776`, 0.9337228820620942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 387}], {
             RGBColor[
             0.1836776641650684, 0.31038724924699196`, 0.9337715432962228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 28}], {
             RGBColor[
             0.1967107027357332, 0.32408579912713337`, 0.9345137555621694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 39}], {
             RGBColor[
             0.19999978068083032`, 0.3275428285870168, 0.934701063685388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 50}], {
             RGBColor[
             0.216476564027812, 0.3448609725730971, 0.935639392121782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 106}], {
             RGBColor[
             0.19417223523988333`, 0.32141770884085996`, 0.9343691935936069]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 137}], {
             RGBColor[
             0.24723503321608348`, 0.3771900738895551, 0.9373910414389766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 138}], {
             RGBColor[
             0.24536530114030092`, 0.3752248669300471, 0.9372845629632816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 149}], {
             RGBColor[
             0.20607580619388693`, 0.3339291166435074, 0.9350470843496823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 164}], {
             RGBColor[
             0.20840908696131982`, 0.3363815426686245, 0.935179961237608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 197}], {
             RGBColor[
             0.1965684920257088, 0.3239363266542179, 0.9345056568726156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 210}], {
             RGBColor[
             0.223753059772891, 0.352509030957652, 0.9360537777898534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 217}], {
             RGBColor[
             0.20503618363244414`, 0.3328364074155535, 0.9349878793827919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 230}], {
             RGBColor[
             0.2114753909347174, 0.33960442255956613`, 0.9353545827127028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 254}], {
             RGBColor[
             0.19445154659843222`, 0.32171128278805783`, 0.9343850999622723]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 258}], {
             RGBColor[
             0.2197390144926751, 0.34829001486297484`, 0.935825183849393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 314}], {
             RGBColor[
             0.19228958849813182`, 0.3194389277485814, 0.9342619796467905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 328}], {
             RGBColor[
             0.2165885293871429, 0.3449786552647677, 0.935645768383358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 7}], {
             RGBColor[
             0.24558195815549755`, 0.37545258718986685`, 0.9372969012597816]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 13}], {
             RGBColor[
             0.2247891692476987, 0.3535980477088099, 0.9361127826916571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 14}], {
             RGBColor[
             0.28743237026540935`, 0.41667525783150516`, 0.9397814519424676]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 21}], {
             RGBColor[
             0.21644166427209716`, 0.34482429071706844`, 0.9356374046323236]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 51}], {
             RGBColor[
             0.2187121116641707, 0.34721067488081686`, 0.9357667032524762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 79}], {
             RGBColor[
             0.21763331081573253`, 0.34607678678918397`, 0.9357052671401005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 188}], {
             RGBColor[
             0.25601232241971317`, 0.38641556135484806`, 0.9378908950742876]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 232}], {
             RGBColor[
             0.21328768495463646`, 0.3415092584805786, 0.9354577901760884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 293}], {
             RGBColor[
             0.2751725873267546, 0.40605645004464963`, 0.939000269414517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 373}], {
             RGBColor[
             0.21710028788855346`, 0.3455165458971132, 0.9356749122729344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 390}], {
             RGBColor[
             0.22459916207358144`, 0.353398338121662, 0.9361019620641815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 84}], {
             RGBColor[
             0.20756604892203795`, 0.3354954562376403, 0.935131951468434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 125}], {
             RGBColor[
             0.196721601742191, 0.3240972546739574, 0.9345143762444637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 165}], {
             RGBColor[
             0.21319278532882907`, 0.3414095129568713, 0.9354523857827901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 184}], {
             RGBColor[
             0.20719899217930893`, 0.3351096563282905, 0.9351110481299474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 185}], {
             RGBColor[
             0.1966973229914563, 0.32407173616757357`, 0.9345129936055264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 190}], {
             RGBColor[
             0.20649883851719153`, 0.33437375043709894`, 0.9350711754146743]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.1963748100004493, 0.3237327545655205, 0.9344946269678038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 252}], {
             RGBColor[
             0.20339315185029538`, 0.3311094768382833, 0.9348943111534462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 274}], {
             RGBColor[
             0.2019924165278475, 0.3296372152026416, 0.934814541349035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 288}], {
             RGBColor[
             0.2072894767278965, 0.33520476132590776`, 0.9351162010911295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 318}], {
             RGBColor[
             0.20715075077545358`, 0.3350589515541568, 0.9351083008533645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.18632940584411195`, 0.31317439788179996`, 0.9339225560619441]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 113}], {
             RGBColor[
             0.18623312529560537`, 0.31307320092078017`, 0.9339170730271409]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 162}], {
             RGBColor[
             0.19105730741779076`, 0.3181437222020098, 0.9341918030622616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 183}], {
             RGBColor[
             0.1877508166785864, 0.3146683907914848, 0.9340035033061785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 270}], {
             RGBColor[
             0.19738135324155764`, 0.32479069533045285`, 0.9345519481163376]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 291}], {
             RGBColor[
             0.19113912643877223`, 0.3182297191806869, 0.9341964625344661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 357}], {
             RGBColor[
             0.1864106536609117, 0.3132597944886656, 0.9339271830049154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 368}], {
             RGBColor[
             0.18532540128789612`, 0.31211912543565157`, 0.9338653794877592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 10}], {
             RGBColor[
             0.8845651997050992, 0.6376155087725291, 0.5907990623624317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.6643840547861006, 0.7335496374888852, 0.969847038397682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 69}], {
             RGBColor[
             0.7494906190968638, 0.8040199624425932, 0.9761664746556911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 71}], {
             RGBColor[
             0.9479335881069795, 0.9604436363507414, 0.9644935461230137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 93}], {
             RGBColor[
             0.6343460318717724, 0.7075322117954237, 0.9679330421391619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 129}], {
             RGBColor[
             0.8727497313117147, 0.5467966411297123, 0.579484556485264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 131}], {
             RGBColor[
             0.8701371040264215, 0.8993351938028649, 0.9874630507499915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 142}], {
             RGBColor[
             0.7001614603741532, 0.763972329138221, 0.9722831025823769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 201}], {
             RGBColor[
             0.7959386825090102, 0.8413708229845736, 0.9800676455168078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 253}], {
             RGBColor[
             0.8756778488316885, 0.5693034354975091, 0.5822885251292265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 273}], {
             RGBColor[
             0.7251045855702409, 0.7842222818473898, 0.9742467167674911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 281}], {
             RGBColor[
             0.6624572537085711, 0.7318807392393671, 0.9697242643368251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 303}], {
             RGBColor[
             0.9100466794366213, 0.777602242030947, 0.6130122278904285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 364}], {
             RGBColor[
             0.9237508221541206, 0.8349006337052781, 0.6241923325830713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 391}], {
             RGBColor[
             0.8731987569820019, 0.5502480491958415, 0.5799145439742327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 394}], {
             RGBColor[
             0.6418942074247149, 0.7140700620770483, 0.9684140052108057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 13}], {
             RGBColor[
             0.23415570368153021`, 0.3634428692713504, 0.9366461929711178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 14}], {
             RGBColor[
             0.29679890469924086`, 0.4265200793940456, 0.9403148622219284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 21}], {
             RGBColor[
             0.22580819870592864`, 0.3546691122796089, 0.9361708149117844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 93}], {
             RGBColor[
             0.29873862778538124`, 0.4282001700379434, 0.9404384596617476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 142}], {
             RGBColor[
             0.36455405628776205`, 0.4846402873807406, 0.9447885201049626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 188}], {
             RGBColor[
             0.2653788568535447, 0.3962603829173885, 0.9384243053537484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 273}], {
             RGBColor[
             0.3894971814838498, 0.5048902400899095, 0.9467521342900769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 293}], {
             RGBColor[
             0.28453912176058604`, 0.41590127160719004`, 0.9395336796939777]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 390}], {
             RGBColor[
             0.23396569650741295`, 0.36324315968420245`, 0.9366353723436424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 16}], {
             RGBColor[
             0.24227617377409713`, 0.3719779982061794, 0.9371086417297306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 25}], {
             RGBColor[
             0.3097802502292844, 0.43782398124180466`, 0.9411398210556678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 76}], {
             RGBColor[
             0.26926683315553557`, 0.4003468925227164, 0.9386457198524012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 117}], {
             RGBColor[
             0.40706513411417244`, 0.5192304619580248, 0.9481280690845475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 202}], {
             RGBColor[
             0.2915950820053508, 0.42207290253936436`, 0.9399810782169516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 234}], {
             RGBColor[
             0.2512674523014992, 0.38142840201846384`, 0.9376206817404615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 239}], {
             RGBColor[
             0.3813679879787836, 0.49836836108207505`, 0.9461050956090218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 269}], {
             RGBColor[
             0.30450100126350144`, 0.4332513611304116, 0.9408034319798247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 302}], {
             RGBColor[
             0.22515004974021374`, 0.353977355987588, 0.936133334301831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 323}], {
             RGBColor[
             0.3381102648791732, 0.4623620160236, 0.9429449845379104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 365}], {
             RGBColor[
             0.2808078228071327, 0.4124772043875522, 0.9393029621396956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 377}], {
             RGBColor[
             0.25514638831763914`, 0.3855054097101751, 0.9378415814082092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 388}], {
             RGBColor[
             0.26319007599843486`, 0.3939598354619466, 0.938299657522061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 18}], {
             RGBColor[
             0.8394473584119997, 0.8706756474406323, 0.6991625748728455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 56}], {
             RGBColor[
             0.6023784760141789, 0.6874029877027437, 0.9623014191002394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 65}], {
             RGBColor[
             0.531426491162083, 0.6277150215031269, 0.9572921727453987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 100}], {
             RGBColor[
             0.5370355289675518, 0.6325732881317867, 0.9576495756744858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 174}], {
             RGBColor[
             0.5520972673558275, 0.6456190088987284, 0.9586092963260144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 198}], {
             RGBColor[
             0.7575782172127392, 0.8106163649808842, 0.9764530707316865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 203}], {
             RGBColor[
             0.4981842108201723, 0.5989222290765547, 0.9551740040370065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 266}], {
             RGBColor[
             0.6722902895010364, 0.7439175508444353, 0.9679712712136599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 313}], {
             RGBColor[
             0.4854882204226317, 0.5856947625868548, 0.9544467086526902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 339}], {
             RGBColor[
             0.5341582021850244, 0.6300810922914106, 0.9574662349562233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 358}], {
             RGBColor[
             0.48197798109692647`, 0.5820052784935108, 0.954246805716025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 384}], {
             RGBColor[
             0.8099718019563749, 0.7646503394906032, 0.6173962103853706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 32}], {
             RGBColor[
             0.8322429825165458, 0.24883926935301032`, 0.1785092225120718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 52}], {
             RGBColor[
             0.9159808794279284, 0.6604932743481702, 0.5104145698509248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 60}], {
             RGBColor[
             0.774995447398962, 0.551160577750298, 0.5801059153920654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 68}], {
             RGBColor[
             0.8322857283076943, 0.5959292773686855, 0.5858125997101122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.8311516302547027, 0.2404506576348733, 0.17746414235362473`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 253}], {
             RGBColor[
             0.8340797477746764, 0.2629574520026702, 0.18026811099758727`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 271}], {
             RGBColor[
             0.8314849257202783, 0.24301251263429177`, 0.17778330646786333`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 303}], {
             RGBColor[
             0.8684485783796092, 0.4712562585361081, 0.21099181375878928`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 333}], {
             RGBColor[
             0.8983718156694669, 0.6481583597796403, 0.5759535503804154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 334}], {
             RGBColor[
             0.9015893430893124, 0.6043580043169925, 0.2443543042542488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 337}], {
             RGBColor[
             0.8999731601904741, 0.6493526399014464, 0.5732428918038912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 345}], {
             RGBColor[
             0.8355254140940163, 0.5985125148757706, 0.5861216038325132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 353}], {
             RGBColor[
             0.9181134493807003, 0.6596306220979193, 0.3482638350680197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 364}], {
             RGBColor[
             0.8821527210971085, 0.5285546502104392, 0.22217191845143208`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 391}], {
             RGBColor[
             0.8316006559249898, 0.24390206570100256`, 0.1778941298425935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 54}], {
             RGBColor[
             0.9107233154962703, 0.8671374351819781, 0.6324945514745149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 83}], {
             RGBColor[
             0.9120888802991098, 0.9323447493793293, 0.977810506555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 118}], {
             RGBColor[
             0.6153201099210919, 0.6928744863891039, 0.9658821576068201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 123}], {
             RGBColor[
             0.8581753215010539, 0.6172298567057516, 0.5883641909402252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 141}], {
             RGBColor[
             0.6144798263952078, 0.6921466750328611, 0.9658286154835842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 161}], {
             RGBColor[
             0.8763695857039919, 0.7238270844566292, 0.6044849794547379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 196}], {
             RGBColor[
             0.8586587168624804, 0.8901351694289188, 0.9863808290196707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 206}], {
             RGBColor[
             0.6510406164097462, 0.7238137937447175, 0.9681582366938735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 214}], {
             RGBColor[
             0.8760571062553216, 0.722408188261647, 0.6042242389431952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 286}], {
             RGBColor[
             0.5972181184299319, 0.677195451192008, 0.9647287147159659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 332}], {
             RGBColor[
             0.8454988743714711, 0.5197931292132254, 0.5762252108529373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 366}], {
             RGBColor[
             0.9332464444239088, 0.9449010522417576, 0.749948999978632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 386}], {
             RGBColor[
             0.6075598618760001, 0.6861529495738531, 0.9653876814635047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 19}], {
             RGBColor[
             0.22114916866345258`, 0.3497721763054004, 0.9359054900432826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 24}], {
             RGBColor[
             0.25148362362516946`, 0.3816556117856949, 0.9376329923775478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 65}], {
             RGBColor[
             0.30963980079837916`, 0.4365176650238572, 0.941174248166886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 100}], {
             RGBColor[
             0.315248838603848, 0.44137593165251704`, 0.941531651095973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 107}], {
             RGBColor[
             0.23293330946253646`, 0.362158055442918, 0.9365765794287164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 124}], {
             RGBColor[
             0.23470207361547668`, 0.3640171387137828, 0.9366773079305742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 150}], {
             RGBColor[
             0.24059607423843102`, 0.37021210706973123`, 0.937012962546659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 157}], {
             RGBColor[
             0.24482342257705114`, 0.37465531820298625`, 0.937253703780742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 167}], {
             RGBColor[
             0.2392959832955554, 0.36884562905824225`, 0.9369389242907744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 168}], {
             RGBColor[
             0.22037492795635888`, 0.34895840023254887`, 0.9358613981804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 203}], {
             RGBColor[
             0.2763975204564685, 0.40772487259728496`, 0.9390560794584938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 206}], {
             RGBColor[
             0.33583694364464667`, 0.4592083134506097, 0.9428435069438263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 211}], {
             RGBColor[
             0.23763726784270695`, 0.3671022139486645, 0.9368444628995842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 238}], {
             RGBColor[
             0.2218338423144311, 0.3504918117233956, 0.9359444811948219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 341}], {
             RGBColor[
             0.2460644953245124, 0.3759597643491251, 0.9373243810377072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 358}], {
             RGBColor[
             0.26019129073322267`, 0.39080792201424114`, 0.9381288811375124]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 14}], {
             RGBColor[
             0.27600611579144196`, 0.4046655399129887, 0.9391307436538039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 21}], {
             RGBColor[
             0.2050154097981298, 0.332814572798552, 0.9349866963436598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 51}], {
             RGBColor[
             0.20728585719020337`, 0.33520095696230034`, 0.9351159949638125]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 79}], {
             RGBColor[
             0.20620705634176517`, 0.33406706887066745`, 0.9350545588514367]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 87}], {
             RGBColor[
             0.2001057560025477, 0.3276542153693653, 0.9347070988231834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 205}], {
             RGBColor[
             0.19925835051903662`, 0.3267635384775842, 0.9346588403345214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 232}], {
             RGBColor[
             0.20186143048066912`, 0.3294995405620621, 0.9348070818874247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 277}], {
             RGBColor[
             0.19923872667069553`, 0.3267429125687539, 0.9346577227853893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 373}], {
             RGBColor[
             0.2056740334145861, 0.3335068279785967, 0.9350242039842707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 390}], {
             RGBColor[
             0.2131729075996141, 0.34138862020314553`, 0.9354512537755177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 69}], {
             RGBColor[
             0.45573362712038445`, 0.5659105913267511, 0.9511564428609628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 71}], {
             RGBColor[
             0.6541765961305002, 0.7223342652348994, 0.9394835143282855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 201}], {
             RGBColor[
             0.5021816905325309, 0.6032614518687315, 0.9550576137220795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 212}], {
             RGBColor[
             0.45821441723172895`, 0.5679246084974616, 0.9513517397459614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 273}], {
             RGBColor[
             0.4313475935937616, 0.5461129107315478, 0.9492366849727629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 289}], {
             RGBColor[
             0.4064318553204269, 0.5258851919600367, 0.9472752267865294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 293}], {
             RGBColor[
             0.32638953387049785`, 0.45712394224882835`, 0.9420182303766638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 390}], {
             RGBColor[
             0.27581610861732475`, 0.40446583032584077`, 0.9391199230263283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 35}], {
             RGBColor[
             0.1861148468094702, 0.312948882732563, 0.933910337242333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 106}], {
             RGBColor[
             0.18432449600494816`, 0.311067110522213, 0.933808379412602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 154}], {
             RGBColor[
             0.18425132424679044`, 0.31099020236503183`, 0.933804212389223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 207}], {
             RGBColor[
             0.18682358813972555`, 0.3136938148074571, 0.9339506990126021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 231}], {
             RGBColor[
             0.18666830847322874`, 0.31353060603266947`, 0.9339418560653108]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 369}], {
             RGBColor[
             0.18126767848005537`, 0.30785420149012543`, 0.9336342981767156]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 372}], {
             RGBColor[
             0.1810383624053819, 0.30761317575616476`, 0.9336212389655058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 392}], {
             RGBColor[
             0.19259602959164984`, 0.3197610167673564, 0.9342794310137273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 25}], {
             RGBColor[
             0.2964577597678131, 0.4238211990721158, 0.9403811249327455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 37}], {
             RGBColor[
             0.25664259349321183`, 0.38707801621458926`, 0.9379267880795208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 76}], {
             RGBColor[
             0.2559443426940643, 0.3863441103530275, 0.937887023729479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 77}], {
             RGBColor[
             0.21295289463759554`, 0.3411573726304365, 0.9354387243628108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 78}], {
             RGBColor[
             0.22470970081672578`, 0.3535145213492678, 0.9361082570820762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 80}], {
             RGBColor[
             0.21603013302378776`, 0.34439174528250716`, 0.9356139685365383]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 96}], {
             RGBColor[
             0.22029148033523374`, 0.34887069149186156`, 0.9358566459618267]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 182}], {
             RGBColor[
             0.23539065510704868`, 0.36474088152001305`, 0.9367165216278543]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.22265042245962569`, 0.35135008923016664`, 0.9359909842260687]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 269}], {
             RGBColor[
             0.29117851080203017`, 0.41924857896072276`, 0.9400447358569024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 302}], {
             RGBColor[
             0.21182755927874247`, 0.3399745738178992, 0.9353746381789088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 323}], {
             RGBColor[
             0.3247877744177019, 0.4483592338539112, 0.9421862884149881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 365}], {
             RGBColor[
             0.2674853323456614, 0.39847442221786333`, 0.9385442660167731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 377}], {
             RGBColor[
             0.24182389785616784`, 0.37150262754048624`, 0.9370828852852868]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 388}], {
             RGBColor[
             0.24986758553696356`, 0.3799570532922577, 0.9375409613991386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 18}], {
             RGBColor[
             0.9100987698336667, 0.6000343504740516, 0.3015369122339562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 31}], {
             RGBColor[
             0.9059600385832136, 0.6006919444617403, 0.5423324684832332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 62}], {
             RGBColor[
             0.9097327710312662, 0.6022520662838114, 0.4798085283004041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.8649138899410389, 0.5692261022124661, 0.5823263856846504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 111}], {
             RGBColor[
             0.8271368865255229, 0.20959157806047718`, 0.1736196192245576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 222}], {
             RGBColor[
             0.88937458998013, 0.5883335736307327, 0.570901233962067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 223}], {
             RGBColor[
             0.843439007132864, 0.3336207383005069, 0.18918058014291417`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 247}], {
             RGBColor[
             0.8225002166596341, 0.17395210166956507`, 0.16917953892461288`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 256}], {
             RGBColor[
             0.9099828197722593, 0.6023554678641716, 0.47566457355675007`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 292}], {
             RGBColor[
             0.8235767865158092, 0.18222708934004583`, 0.17021046343469787`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 310}], {
             RGBColor[
             0.8270891883762761, 0.20922494918390394`, 0.1735739434229715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 319}], {
             RGBColor[
             0.8300530358518976, 0.23200637964777565`, 0.17641212711281357`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 384}], {
             RGBColor[
             0.8806232133780418, 0.49400904252402256`, 0.21977054774648136`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 99}], {
             RGBColor[
             0.947350971343756, 0.9556350172112698, 0.7097411277967336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 144}], {
             RGBColor[
             0.7868965412101618, 0.8286865484723305, 0.6945647496408425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.9106667100371233, 0.9263839830131071, 0.7062421502048801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 218}], {
             RGBColor[
             0.776406098847213, 0.8201699347730458, 0.6937389035902746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 266}], {
             RGBColor[
             0.8253787823254205, 0.8596851688766582, 0.6977603506868537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 310}], {
             RGBColor[
             0.9095262697789932, 0.5956338641827077, 0.30098868553505453`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 319}], {
             RGBColor[
             0.9124901172546147, 0.6184152946465793, 0.3038268692248966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 384}], {
             RGBColor[
             0.9630602947807589, 0.8804179575228263, 0.3471852898585644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 24}], {
             RGBColor[
             0.22984730742841403`, 0.35891447164122536`, 0.936400836178204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 85}], {
             RGBColor[
             0.19070082938217475`, 0.3177690411845645, 0.9341715021654952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 107}], {
             RGBColor[
             0.211296993265781, 0.33941691529844853`, 0.9353444232293726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 124}], {
             RGBColor[
             0.21306575741872125`, 0.34127599856931323`, 0.9354451517312304]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 150}], {
             RGBColor[
             0.21895975804167556`, 0.3474709669252617, 0.9357808063473152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 152}], {
             RGBColor[
             0.2001783639532218, 0.3277305309291337, 0.9347112337385604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 157}], {
             RGBColor[
             0.2231871063802957, 0.35191417805851677`, 0.9360215475813982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 160}], {
             RGBColor[
             0.19740416245689973`, 0.32481466926196517`, 0.9345532470674082]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 167}], {
             RGBColor[
             0.21765966709879997`, 0.34610448891377266`, 0.9357067680914306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 168}], {
             RGBColor[
             0.19873861175960342`, 0.3262172600880793, 0.9346292419810562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 181}], {
             RGBColor[
             0.19581756515250187`, 0.3231470548989638, 0.9344628926980831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 211}], {
             RGBColor[
             0.2160009516459515, 0.344361073804195, 0.9356123067002404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 238}], {
             RGBColor[
             0.20019752611767563`, 0.32775067157892607`, 0.9347123249954781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 64}], {
             RGBColor[
             0.6886054780275248, 0.7470570557801346, 0.690028677840299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 88}], {
             RGBColor[
             0.40751079531136875`, 0.5273871016357587, 0.9471872054229611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 89}], {
             RGBColor[
             0.30842578765479933`, 0.4344898392135439, 0.9411326397648885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 120}], {
             RGBColor[
             0.3985867083579536, 0.5196575060543626, 0.9466185704935497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 140}], {
             RGBColor[
             0.3954861818985797, 0.5169719858722439, 0.9464210076892463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 189}], {
             RGBColor[
             0.30889970680782364`, 0.4349879582915822, 0.9411596287595527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 195}], {
             RGBColor[
             0.40462199010322386`, 0.5248849637600351, 0.9470031333095683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 241}], {
             RGBColor[
             0.33276855688740864`, 0.46007563309772936`, 0.9425189244607857]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 255}], {
             RGBColor[
             0.37940724758906264`, 0.5030452211240766, 0.9453964722130872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 257}], {
             RGBColor[
             0.6770229856308323, 0.7421397259892473, 0.9411883411446311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 263}], {
             RGBColor[
             0.3432288815576954, 0.4710700975490908, 0.943114624476095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 312}], {
             RGBColor[
             0.4662211223319299, 0.5756731791658605, 0.9516371294428863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 336}], {
             RGBColor[
             0.3097133743307097, 0.43584317444763615`, 0.9412059659212678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 356}], {
             RGBColor[
             0.6650046334832713, 0.7331764586358418, 0.9615322764421933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 359}], {
             RGBColor[
             0.3551576814248725, 0.48204146573128925`, 0.9438513113001545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 360}], {
             RGBColor[
             0.523690607917635, 0.622017048024192, 0.9563749606192402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 389}], {
             RGBColor[
             0.688874491712781, 0.747632448851442, 0.7193091573204213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 109}], {
             RGBColor[
             0.1897091064701492, 0.31672667752516137`, 0.9341150250127779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[
             0.19167285067202883`, 0.3187906971899105, 0.9342268573399758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 132}], {
             RGBColor[
             0.1947709663990963, 0.3220470132509409, 0.9344032904473808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 180}], {
             RGBColor[
             0.19254611619106632`, 0.3197085546186507, 0.9342765885194044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 232}], {
             RGBColor[
             0.19351392550506752`, 0.32072578357032067`, 0.9343317038280912]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 249}], {
             RGBColor[
             0.19014493822452405`, 0.31718476433233855`, 0.9341398449864342]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 370}], {
             RGBColor[
             0.19110729661804693`, 0.31819626402097745`, 0.9341946498732637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 45}], {
             RGBColor[
             0.24087710963769857`, 0.3705074930930349, 0.9370289670968927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 74}], {
             RGBColor[
             0.24528340650250224`, 0.37513879047330073`, 0.9372798991848111]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 116}], {
             RGBColor[
             0.24102708216235447`, 0.3706651237252555, 0.9370375078103073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 141}], {
             RGBColor[
             0.2988998919025237, 0.4271457198066904, 0.9404924581847806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 179}], {
             RGBColor[
             0.2344230766191157, 0.3637238951811761, 0.9366614194643705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 209}], {
             RGBColor[
             0.25353925279510015`, 0.38381620837770913`, 0.9377500574177445]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 286}], {
             RGBColor[
             0.2816381839372477, 0.41219449596583724`, 0.9393925574171622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 290}], {
             RGBColor[
             0.2497813465899759, 0.3798664106911086, 0.9375360502186867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 304}], {
             RGBColor[
             0.2621517349847551, 0.3928684732219464, 0.9382405255374198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 338}], {
             RGBColor[
             0.2260845393342366, 0.35495956380096844`, 0.9361865521017572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 38}], {
             RGBColor[
             0.23532272116707456`, 0.36466947864183974`, 0.936712652890472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 92}], {
             RGBColor[
             0.20814505737279243`, 0.33610403083063944`, 0.9351649251431382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 98}], {
             RGBColor[
             0.2025842284056299, 0.3302592470092312, 0.9348482441599675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 119}], {
             RGBColor[
             0.22585475434557115`, 0.35471804520867123`, 0.936173466186589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 128}], {
             RGBColor[
             0.2579108106564282, 0.38841099286274205`, 0.9379990111708069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 130}], {
             RGBColor[
             0.21379154943709947`, 0.3420388519985006, 0.935486484512964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 139}], {
             RGBColor[
             0.2594316195520534, 0.3900094594368974, 0.9380856189875776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 143}], {
             RGBColor[
             0.20541157212716055`, 0.3332309645245057, 0.9350092572022285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 146}], {
             RGBColor[
             0.20552449462249126`, 0.333349653226798, 0.9350156879712836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 151}], {
             RGBColor[
             0.20976599730073225`, 0.3378077414684315, 0.9352572352740687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 158}], {
             RGBColor[
             0.20153001639620693`, 0.3291512033464258, 0.9347882083455978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 186}], {
             RGBColor[
             0.209250396089514, 0.3372658119044362, 0.9352278725478533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 213}], {
             RGBColor[
             0.2686665233533321, 0.39817491739397315`, 0.9386679570758016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 267}], {
             RGBColor[
             0.20474185831720654`, 0.33252705284793593`, 0.9349711179915043]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 306}], {
             RGBColor[
             0.21710981978146196`, 0.345526564520917, 0.9356754551001344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 308}], {
             RGBColor[
             0.21238372481471685`, 0.3405591390591399, 0.9354063109834092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 311}], {
             RGBColor[
             0.2072579319428704, 0.33517160575679045`, 0.9351144046622886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 346}], {
             RGBColor[
             0.20767293699657277`, 0.3356078023810718, 0.935138038586152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 348}], {
             RGBColor[
             0.20651189165865158`, 0.3343874701163905, 0.93507191877177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 354}], {
             RGBColor[
             0.20401044687486744`, 0.3317582930478737, 0.9349294651918895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 374}], {
             RGBColor[
             0.19777812141168266`, 0.3252077238338092, 0.9345745434766604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 33}], {
             RGBColor[
             0.2533855843329195, 0.3836546930808141, 0.9377413062261555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 56}], {
             RGBColor[
             0.3892899244154366, 0.5053479265592988, 0.9466788406566481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 65}], {
             RGBColor[
             0.3183379395633406, 0.44565996035968214`, 0.9416695943018074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 100}], {
             RGBColor[
             0.32394697736880945`, 0.450518226988342, 0.9420269972308946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 107}], {
             RGBColor[
             0.2416314482274979, 0.371300350778743, 0.9370719255636378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 124}], {
             RGBColor[
             0.24340021238043813`, 0.3731594340496077, 0.9371726540654957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 150}], {
             RGBColor[
             0.24929421300339247`, 0.3793544024055562, 0.9375083086815804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 157}], {
             RGBColor[
             0.2535215613420126, 0.38379761353881126`, 0.9377490499156633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 167}], {
             RGBColor[
             0.24799412206051685`, 0.37798792439406714`, 0.9374342704256958]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 168}], {
             RGBColor[
             0.22907306672132033`, 0.35810069556837376`, 0.9363567443153216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 203}], {
             RGBColor[
             0.2850956592214299, 0.4168671679331099, 0.9395514255934152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 206}], {
             RGBColor[
             0.3445350824096081, 0.46835060878643464`, 0.9433388530787478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 211}], {
             RGBColor[
             0.2463354066076684, 0.3762445092844895, 0.9373398090345058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 238}], {
             RGBColor[
             0.23053198107939255`, 0.35963410705922055`, 0.9364398273297434]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 341}], {
             RGBColor[
             0.25476263408947386`, 0.38510205968495004`, 0.9378197271726287]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 358}], {
             RGBColor[
             0.2688894294981841, 0.3999502173500661, 0.9386242272724338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 386}], {
             RGBColor[
             0.3010543278758621, 0.4306897646155703, 0.940568297848379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 37}], {
             RGBColor[
             0.3241466699483991, 0.4529239992502145, 0.9419579674054581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 62}], {
             RGBColor[
             0.6778828449272916, 0.740272939600058, 0.8649535953688089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[
             0.32344841914925154`, 0.45219009338865274`, 0.9419182030554161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 78}], {
             RGBColor[
             0.29221377727191306`, 0.41936050438489303`, 0.9401394364080135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 91}], {
             RGBColor[
             0.47826887557608655`, 0.5848930154724093, 0.9527405987202289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 117}], {
             RGBColor[
             0.4612467201078884, 0.5710736628239611, 0.9514005522875624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 182}], {
             RGBColor[
             0.30289473156223595`, 0.4305868645556383, 0.9407477009537915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 187}], {
             RGBColor[
             0.29015449891481293`, 0.4171960722657919, 0.940022163552006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 208}], {
             RGBColor[
             0.3291899186131193, 0.4582247733572693, 0.9422451729560961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 239}], {
             RGBColor[
             0.43554957397249955`, 0.5502115619480115, 0.9493775788120367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 269}], {
             RGBColor[
             0.35868258725721747`, 0.48509456199634804`, 0.9440759151828396]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 309}], {
             RGBColor[
             0.5306642654095335, 0.6265873056000757, 0.957441478589943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 323}], {
             RGBColor[
             0.3922918508728892, 0.5142052168895364, 0.9462174677409253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 362}], {
             RGBColor[
             0.5776163710657185, 0.6632666473879071, 0.9621212256893779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 365}], {
             RGBColor[
             0.33498940880084865`, 0.4643204052534886, 0.9425754453427104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 377}], {
             RGBColor[
             0.3093279743113551, 0.4373486105761115, 0.941114064611224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 388}], {
             RGBColor[
             0.31737166199215083`, 0.44580303632788293`, 0.9415721407250759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 395}], {
             RGBColor[
             0.4013213562160271, 0.522026120581628, 0.946792819836912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 70}], {
             RGBColor[
             0.1896105861046007, 0.3166231263744179, 0.9341094144237078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 177}], {
             RGBColor[
             0.18182665700375172`, 0.3084417233598157, 0.9336661311767056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 285}], {
             RGBColor[
             0.1832664520031871, 0.30995503919249784`, 0.9337481253719375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 324}], {
             RGBColor[
             0.1839722969253371, 0.31069692695883033`, 0.9337883221960501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 40}], {
             RGBColor[
             0.19924073649984758`, 0.3267450250266232, 0.9346578372421862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 41}], {
             RGBColor[
             0.1999138771125005, 0.32745253849010136`, 0.9346961716042546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 48}], {
             RGBColor[
             0.20648582903789775`, 0.33436007664951256`, 0.9350704345440743]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 63}], {
             RGBColor[
             0.1971785692903057, 0.32457755654044196`, 0.9345403998703059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 86}], {
             RGBColor[
             0.23656599040606416`, 0.3659762334398404, 0.9367834552343804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 250}], {
             RGBColor[
             0.19937642447535237`, 0.3268876416919933, 0.9346655644716588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 265}], {
             RGBColor[
             0.20201462184730384`, 0.32966055440128883`, 0.9348158059091283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 295}], {
             RGBColor[
             0.19546687096427723`, 0.32277845307184394`, 0.9344429211828693]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 325}], {
             RGBColor[
             0.22165235452841858`, 0.35030105655330623`, 0.9359341457338957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 376}], {
             RGBColor[
             0.24560585367761548`, 0.37547770289867644`, 0.937298262074416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 39}], {
             RGBColor[
             0.19488507531529636`, 0.3221669489567903, 0.9344097887813494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 50}], {
             RGBColor[
             0.21136185866227802`, 0.33948509294287055`, 0.9353481172177434]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 106}], {
             RGBColor[
             0.18905752987434937`, 0.31604182921063345`, 0.9340779186895682]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 197}], {
             RGBColor[
             0.19145378666017485`, 0.3185604470239914, 0.9342143819685769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 217}], {
             RGBColor[
             0.19992147826691017`, 0.32746052778532697`, 0.9346966044787532]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 231}], {
             RGBColor[
             0.19140134234262995`, 0.31850532472108994`, 0.934211395342277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 254}], {
             RGBColor[
             0.1893368412328983, 0.3163354031578313, 0.9340938250582336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 314}], {
             RGBColor[
             0.18717488313259786`, 0.3140630481183549, 0.9339707047427519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 369}], {
             RGBColor[
             0.1860007123494566, 0.3128289201785459, 0.9339038374536819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 113}], {
             RGBColor[
             0.1857448284490183, 0.3125599699752089, 0.9338892652440982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 162}], {
             RGBColor[
             0.19056901057120365`, 0.3176304912564385, 0.9341639952792189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 183}], {
             RGBColor[
             0.18726251983199932`, 0.31415515984591347`, 0.9339756955231359]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 270}], {
             RGBColor[
             0.19689305639497057`, 0.3242774643848816, 0.9345241403332949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 357}], {
             RGBColor[
             0.18592235681432462`, 0.3127465635430944, 0.9338993752218727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 153}], {
             RGBColor[
             0.2031751711317593, 0.3308803652823261, 0.9348818974739992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 168}], {
             RGBColor[
             0.19933167973369648`, 0.3268406121315325, 0.9346630163248155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 175}], {
             RGBColor[
             0.19541782934736363`, 0.32272690722304953`, 0.9344401283353366]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 211}], {
             RGBColor[
             0.21659401962004457`, 0.3449844258476482, 0.9356460810439997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 216}], {
             RGBColor[
             0.208257693184232, 0.33622241820998533`, 0.93517133958597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 229}], {
             RGBColor[
             0.19931037008134544`, 0.32681821433580155`, 0.9346618027716389]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 294}], {
             RGBColor[
             0.2052159577699056, 0.3330253614323641, 0.9349981172539683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 329}], {
             RGBColor[
             0.23151896311630302`, 0.36067148775828894`, 0.9364960344966363]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 341}], {
             RGBColor[
             0.22502124710185, 0.35384197624810876`, 0.9361259991821227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 343}], {
             RGBColor[
             0.2007094287814945, 0.32828871373510315`, 0.9347414770948905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 358}], {
             RGBColor[
             0.2391480425105603, 0.3686901339132248, 0.9369304992819277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 379}], {
             RGBColor[
             0.19158357625518677`, 0.31869686411748455`, 0.9342217732940062]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 99}], {
             RGBColor[
             0.9432122400933031, 0.9562926111989585, 0.9505366840460105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 111}], {
             RGBColor[
             0.905435236677787, 0.5966580870469695, 0.5418299175859177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 169}], {
             RGBColor[
             0.7207585549931849, 0.779010354243588, 0.9304794974284005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 199}], {
             RGBColor[
             0.9864970705564884, 0.9886842059127192, 0.8734420155476115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 215}], {
             RGBColor[
             0.8451646800561206, 0.8790328648583385, 0.9409404903646027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 222}], {
             RGBColor[
             0.967672940132394, 0.9754000826172251, 0.9391115323234271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 223}], {
             RGBColor[
             0.9217373572851282, 0.7206872472869994, 0.5573908785042743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 224}], {
             RGBColor[
             0.7410029688449329, 0.7954456814088879, 0.9320732118445416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 247}], {
             RGBColor[
             0.9007985668118983, 0.5610186106560575, 0.5373898372859729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 259}], {
             RGBColor[
             0.9398415048836066, 0.9536048784389164, 0.9502151803126189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 292}], {
             RGBColor[
             0.9018751366680733, 0.5692935983265383, 0.5384207617960579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 363}], {
             RGBColor[
             0.6793920980440895, 0.7432878081939467, 0.9278140990011539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 383}], {
             RGBColor[
             0.6712879724630387, 0.7362684219408357, 0.9272977112853262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 393}], {
             RGBColor[
             0.8531150739602782, 0.8852437730014981, 0.9417329113283139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 400}], {
             RGBColor[
             0.9031868035222537, 0.5793756445438494, 0.5396768154569369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 46}], {
             RGBColor[
             0.8135276706473076, 0.5072097485112304, 0.5747459012560696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 52}], {
             RGBColor[
             0.905256763296387, 0.5780630184234903, 0.500145144132204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 71}], {
             RGBColor[
             0.8956113709184261, 0.5716673969312225, 0.5522037062726537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 105}], {
             RGBColor[
             0.903410578527918, 0.577299573576944, 0.5307412035187635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 111}], {
             RGBColor[
             0.8240654755025505, 0.18598336703701845`, 0.17067843256029655`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 129}], {
             RGBColor[
             0.8204275141231614, 0.1580204017101934, 0.16719471663490398`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 199}], {
             RGBColor[
             0.9051273093812517, 0.578009485902768, 0.5022905305219902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 215}], {
             RGBColor[
             0.7637949188808839, 0.4683581448483874, 0.5697890053389816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 247}], {
             RGBColor[
             0.8194288056366617, 0.15034389064610632`, 0.16623835226035183`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 259}], {
             RGBColor[
             0.85847174370837, 0.5429301584289652, 0.5790636952869976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 271}], {
             RGBColor[
             0.8207608095887371, 0.16058225670961188`, 0.16751388074914259`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 287}], {
             RGBColor[
             0.8194189331925024, 0.1502680067141652, 0.16622889839667554`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 292}], {
             RGBColor[
             0.8205053754928366, 0.15861887831658708`, 0.16726927677043682`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 303}], {
             RGBColor[
             0.857724462248068, 0.3888260026114282, 0.20072238804006853`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 333}], {
             RGBColor[
             0.8876476995379257, 0.5657281038549604, 0.5656841246616948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 337}], {
             RGBColor[
             0.8892490440589328, 0.5669223839767665, 0.5629734660851704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 345}], {
             RGBColor[
             0.824801297962475, 0.5160822589510907, 0.5758521781137924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 353}], {
             RGBColor[
             0.9073893332491589, 0.5772003661732394, 0.33799440934929903`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 385}], {
             RGBColor[
             0.907968224972722, 0.5784385570350095, 0.40100320095353803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 391}], {
             RGBColor[
             0.8208765397934485, 0.16147180977632267`, 0.16762470412387276`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 400}], {
             RGBColor[
             0.8218170423470171, 0.16870092453389818`, 0.1685253304313158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 58}], {
             RGBColor[
             0.21989646734481127`, 0.3484555077936574, 0.9358341505563915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 74}], {
             RGBColor[
             0.24756162893783695`, 0.3775333467004828, 0.9374096405821755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 107}], {
             RGBColor[
             0.23483527017028652`, 0.36415713673803723`, 0.9366848932773241]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 116}], {
             RGBColor[
             0.24330530459768918`, 0.3730596799524376, 0.9371672492076716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 118}], {
             RGBColor[
             0.30201839786374246`, 0.43026808739011524`, 0.9406757417053806]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 124}], {
             RGBColor[
             0.23660403432322674`, 0.366016220008902, 0.9367856217791819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 141}], {
             RGBColor[
             0.3011781143378584, 0.42954027603387246`, 0.9406221995821449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 150}], {
             RGBColor[
             0.24249803494618108`, 0.37221118836485045`, 0.9371212763952667]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 152}], {
             RGBColor[
             0.2237166408577273, 0.3524707523687224, 0.9360517037865118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 156}], {
             RGBColor[
             0.22423055163894667`, 0.35301090518360945`, 0.9360809702452394]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 157}], {
             RGBColor[
             0.2467253832848012, 0.3766543994981055, 0.9373620176293496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 179}], {
             RGBColor[
             0.23670129905445042`, 0.3661184514083582, 0.9367911608617348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 206}], {
             RGBColor[
             0.33773890435239673`, 0.4612073947457289, 0.942951820792434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 209}], {
             RGBColor[
             0.25581747523043485`, 0.38621076460489123`, 0.9378797988151089]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 245}], {
             RGBColor[
             0.22074175679161856`, 0.34934396059669826`, 0.9358822885398935]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 286}], {
             RGBColor[
             0.2839164063725824, 0.41458905219301934`, 0.9395222988145264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 386}], {
             RGBColor[
             0.2942581498186507, 0.4235465505748645, 0.9401812655620653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 43}], {
             RGBColor[
             0.18881744465394812`, 0.3157894844217095, 0.9340642461914408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 159}], {
             RGBColor[
             0.1825395439463383, 0.30919101273611693`, 0.9337067290334642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 250}], {
             RGBColor[
             0.1883288985198916, 0.31527599145920215`, 0.9340364242118455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 265}], {
             RGBColor[
             0.19096709589184307`, 0.31804890416849774`, 0.9341866656493147]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 321}], {
             RGBColor[
             0.18374554341254123`, 0.3104585946398788, 0.9337754089189481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 375}], {
             RGBColor[
             0.19286667153168213`, 0.3200454786060204, 0.9342948436718334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 381}], {
             RGBColor[
             0.18614322275265005`, 0.3129787076479837, 0.9339119532103186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 73}], {
             RGBColor[
             0.19430576499947028`, 0.3215580570844616, 0.9343767979158759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 154}], {
             RGBColor[
             0.18823624142486384`, 0.31517860297752887`, 0.9340311475273575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 207}], {
             RGBColor[
             0.19080850531779897`, 0.3178822154199542, 0.9341776341507367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 231}], {
             RGBColor[
             0.19065322565130216`, 0.31771900664516656`, 0.9341687912034454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 280}], {
             RGBColor[
             0.19951437129521365`, 0.3270326325460011, 0.9346734203389759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 291}], {
             RGBColor[
             0.19278015708719454`, 0.31995454643953136`, 0.9342899168022064]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 372}], {
             RGBColor[
             0.18502327958345532`, 0.31180157636866185`, 0.9338481741036404]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 387}], {
             RGBColor[
             0.1878209095169145, 0.3147420628087102, 0.9340074949896282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 392}], {
             RGBColor[
             0.19658094676972326`, 0.3239494173798535, 0.934506366151862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 61}], {
             RGBColor[
             0.23146005042347673`, 0.36060956678284806`, 0.9364926795059334]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 70}], {
             RGBColor[
             0.22130912604082534`, 0.3499403016509027, 0.9359145993792883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 90}], {
             RGBColor[
             0.2306114538784999, 0.35971763800994894`, 0.9364443531880831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 95}], {
             RGBColor[
             0.2464425329575721, 0.37635710587044113`, 0.9373459097216534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 148}], {
             RGBColor[
             0.2511034439451054, 0.38125601883716365`, 0.9376113417071936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 228}], {
             RGBColor[
             0.23483092925025606`, 0.364152574155855, 0.9366846460683501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 276}], {
             RGBColor[
             0.31234957064668134`, 0.4391299345139409, 0.941337201922877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 282}], {
             RGBColor[
             0.28033871258182136`, 0.4114037381706667, 0.9392974983530744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 301}], {
             RGBColor[
             0.2477609938146631, 0.37774289182649035`, 0.9374209941169768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 305}], {
             RGBColor[
             0.2718566625317226, 0.40306896740175535`, 0.9387932068040659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 361}], {
             RGBColor[
             0.32761397052464425`, 0.4523511904771868, 0.9423098359853219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 382}], {
             RGBColor[
             0.2838749254794549, 0.4144666280473688, 0.9395228227119613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 76}], {
             RGBColor[
             0.28363325287465024`, 0.4154469105311262, 0.9394638662021915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 78}], {
             RGBColor[
             0.25239861099731176`, 0.3826173215273665, 0.9376850995547887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 80}], {
             RGBColor[
             0.24371904320437376`, 0.3734945454606058, 0.9371908110092508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 96}], {
             RGBColor[
             0.24798039051581972`, 0.3779734916699602, 0.9374334884345392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 104}], {
             RGBColor[
             0.2541903466574486, 0.3845005493087726, 0.9377871362499982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 117}], {
             RGBColor[
             0.4214315538332871, 0.5343304799664346, 0.9489462154343377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 145}], {
             RGBColor[
             0.2671022972631469, 0.3980718280603137, 0.9385224527354736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 182}], {
             RGBColor[
             0.26307956528763465`, 0.3938436816981118, 0.9382933641005669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 187}], {
             RGBColor[
             0.2503393326402117, 0.3804528894082654, 0.9375678266987812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 208}], {
             RGBColor[
             0.289374752338518, 0.42148159049974276`, 0.9397908361028714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 269}], {
             RGBColor[
             0.3188674209826161, 0.4483513791388215, 0.9416215783296149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 323}], {
             RGBColor[
             0.35247668459828785`, 0.4774620340320098, 0.9437631308877006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 365}], {
             RGBColor[
             0.29517424252624735`, 0.4275772223959621, 0.9401211084894857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 377}], {
             RGBColor[
             0.2695128080367538, 0.400605427718585, 0.9386597277579993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 388}], {
             RGBColor[
             0.27755649571754953`, 0.4090598534703564, 0.9391178038718512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 395}], {
             RGBColor[
             0.3615061899414258, 0.48528293772410147`, 0.9443384829836874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 44}], {
             RGBColor[
             0.24351959225973108`, 0.37328490987186613`, 0.9371794525730147]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 66}], {
             RGBColor[
             0.22742648369193186`, 0.3563700324050926, 0.9362629738476992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 81}], {
             RGBColor[
             0.2439408678768847, 0.37372769725591143`, 0.9372034435961902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 119}], {
             RGBColor[
             0.249257790450226, 0.37931611999285497`, 0.9375062344710599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 128}], {
             RGBColor[
             0.281313846761083, 0.4130090676469258, 0.9393317794552777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 130}], {
             RGBColor[
             0.23719458554175432`, 0.36663692678268434`, 0.9368192527974348]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 135}], {
             RGBColor[
             0.2970405045044002, 0.42707857493039736`, 0.9403174695829958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 146}], {
             RGBColor[
             0.2289275307271461, 0.3579477280109817, 0.9363484562557545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 151}], {
             RGBColor[
             0.23316903340538708`, 0.36240581625261525`, 0.9365900035585395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 213}], {
             RGBColor[
             0.2920695594579869, 0.42277299217815684`, 0.9400007253602725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 224}], {
             RGBColor[
             0.37823665311305865`, 0.49620023139778335`, 0.9458245390097163]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 227}], {
             RGBColor[
             0.2663587998591236, 0.39729036514822713`, 0.9384801116582203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 243}], {
             RGBColor[
             0.24505985490147014`, 0.37490382356662577`, 0.9372671682518474]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 267}], {
             RGBColor[
             0.22814489442186137`, 0.3571251276321197, 0.9363038862759752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 306}], {
             RGBColor[
             0.24051285588611682`, 0.3701246393051007, 0.9370082233846052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 311}], {
             RGBColor[
             0.23066096804752526`, 0.35976968054097413`, 0.9364471729467594]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 346}], {
             RGBColor[
             0.23107597310122763`, 0.36020587716525554`, 0.9364708068706228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 350}], {
             RGBColor[
             0.3036355127427933, 0.43279083959174136`, 0.9407376976762094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 363}], {
             RGBColor[
             0.3166257823122153, 0.444042358182842, 0.9415654261663287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 383}], {
             RGBColor[
             0.3085216567311646, 0.43702297192973105`, 0.9410490384505009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 47}], {
             RGBColor[
             0.18958921033534365`, 0.3166006590856267, 0.9341081971052712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 50}], {
             RGBColor[
             0.21465093660737516`, 0.342942122402754, 0.9355354253409618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 136}], {
             RGBColor[
             0.19040517985093924`, 0.31745829478197307`, 0.9341546653620656]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 149}], {
             RGBColor[
             0.2042501787734501, 0.33201026647316434`, 0.9349431175688622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 164}], {
             RGBColor[
             0.20658345954088297`, 0.3344626924982814, 0.9350759944567879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 197}], {
             RGBColor[
             0.19474286460527196`, 0.3220174764838748, 0.9344016900917953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 210}], {
             RGBColor[
             0.22192743235245416`, 0.35059018078730897`, 0.9359498110090333]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 217}], {
             RGBColor[
             0.2032105562120073, 0.33091755724521044`, 0.9348839126019717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 230}], {
             RGBColor[
             0.20964976351428055`, 0.33768557238922303`, 0.9352506159318827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 254}], {
             RGBColor[
             0.19262591917799537`, 0.31979243261771473`, 0.934281133181452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 258}], {
             RGBColor[
             0.21791338707223826`, 0.34637116469263174`, 0.9357212170685729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 314}], {
             RGBColor[
             0.19046396107769498`, 0.3175200775782383, 0.9341580128659703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 328}], {
             RGBColor[
             0.21476290196670605`, 0.3430598050944246, 0.9355418016025379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 41}], {
             RGBColor[
             0.19412189539412833`, 0.3213647984712409, 0.9343663268138622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 48}], {
             RGBColor[
             0.20069384731952558`, 0.3282723366306521, 0.934740589753682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 63}], {
             RGBColor[
             0.19138658757193353`, 0.3184898165215815, 0.9342105550799136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 103}], {
             RGBColor[
             0.19411926264855695`, 0.32136203128871965`, 0.9343661768828968]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 265}], {
             RGBColor[
             0.1962226401289317, 0.32357281438242835`, 0.9344859611187359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 295}], {
             RGBColor[
             0.1896748892459051, 0.31669071305298346`, 0.934113076392477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 48}], {
             RGBColor[
             0.2013669879321785, 0.3289798500941302, 0.9347789241157504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 63}], {
             RGBColor[
             0.19205972818458644`, 0.31919732998505956`, 0.9342488894419819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.1942575833696331, 0.32150741513661096`, 0.934374054043335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 265}], {
             RGBColor[
             0.19689578074158462`, 0.3242803278459065, 0.9345242954808043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 295}], {
             RGBColor[
             0.19034802985855803`, 0.31739822651646155`, 0.9341514107545453]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 325}], {
             RGBColor[
             0.2165335134226994, 0.3449208299979239, 0.9356426353055718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 381}], {
             RGBColor[
             0.19207190760239157`, 0.31921013132539244`, 0.934249583041808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 67}], {
             RGBColor[
             0.18164605198289263`, 0.3082518960318731, 0.9336558459879488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 75}], {
             RGBColor[
             0.18289766237674282`, 0.30956741791249204`, 0.9337271233482869]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 133}], {
             RGBColor[
             0.1836453052262827, 0.310353237950653, 0.9337697005025297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 178}], {
             RGBColor[
             0.18344665505298052`, 0.31014444402336394`, 0.9337583876690367]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 200}], {
             RGBColor[
             0.18896638878164698`, 0.3159460341435242, 0.9340727283391701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 278}], {
             RGBColor[
             0.18598976689484537`, 0.3128174158117676, 0.9339032141262342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 296}], {
             RGBColor[
             0.18148102360409654`, 0.30807844074235485`, 0.933646447865914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 320}], {
             RGBColor[
             0.18379681968568948`, 0.3105124892540611, 0.9337783290268474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 330}], {
             RGBColor[
             0.18629301045548374`, 0.31313614402075074`, 0.9339204833984038]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 347}], {
             RGBColor[
             0.18410501336322643`, 0.3108364203497602, 0.9337958802008515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 367}], {
             RGBColor[
             0.1849893429390042, 0.3117659068036362, 0.9338462414619436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 398}], {
             RGBColor[
             0.18234639975021955`, 0.30898800593994685`, 0.9336957297572264]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 159}], {
             RGBColor[
             0.1884193222929882, 0.31537103257792504`, 0.9340415737119533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 250}], {
             RGBColor[
             0.19420867686654147`, 0.32145601130101026`, 0.9343712688903346]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 265}], {
             RGBColor[
             0.19684687423849298`, 0.3242289240103058, 0.934521510327804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 321}], {
             RGBColor[
             0.1896253217591911, 0.31663861448168684`, 0.9341102535974373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 325}], {
             RGBColor[
             0.21648460691960775`, 0.3448694261623232, 0.9356398501525713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 375}], {
             RGBColor[
             0.19874644987833204`, 0.3262254984478285, 0.9346296883503225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 381}], {
             RGBColor[
             0.19202300109929993`, 0.3191587274897918, 0.9342467978888077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 66}], {
             RGBColor[
             0.21222031867993352`, 0.3403873888509353, 0.9353970052457711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 81}], {
             RGBColor[
             0.22873470286488637`, 0.35774505370175413`, 0.9363374749942621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 119}], {
             RGBColor[
             0.23405162543822766`, 0.3633334764386976, 0.9366402658691317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[
             0.26610768174908467`, 0.39702642409276845`, 0.9384658108533496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 130}], {
             RGBColor[
             0.22198842052975598`, 0.350654283228527, 0.9359532841955067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 135}], {
             RGBColor[
             0.2818343394924019, 0.41109593137624006`, 0.9394515009810677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 146}], {
             RGBColor[
             0.21372136571514777`, 0.3419650844568244, 0.9354824876538264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 151}], {
             RGBColor[
             0.21796286839338874`, 0.3464231726984579, 0.9357240349566114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 227}], {
             RGBColor[
             0.25115263484712524`, 0.3813077215940698, 0.9376141430562922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 243}], {
             RGBColor[
             0.2298536898894718, 0.3589211800124685, 0.9364011996499193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 267}], {
             RGBColor[
             0.21293872940986303`, 0.3411424840779623, 0.935437917674047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 275}], {
             RGBColor[
             0.21122882729611786`, 0.33934526854236047`, 0.9353405412782427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 311}], {
             RGBColor[
             0.21545480303552692`, 0.34378703698681684`, 0.9355812043448313]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 317}], {
             RGBColor[
             0.2084087804726259, 0.3363812205295747, 0.9351799437835304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 326}], {
             RGBColor[
             0.2349425006851034, 0.3642698428079171, 0.9366909998965096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 344}], {
             RGBColor[
             0.20993796520971017`, 0.3379884906441625, 0.9352670285920812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 346}], {
             RGBColor[
             0.2158698080892293, 0.3442232336110982, 0.9356048382686947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 383}], {
             RGBColor[
             0.29331549171916627`, 0.4210403283755737, 0.9401830698485728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 48}], {
             RGBColor[
             0.2238300988639671, 0.3525900039269335, 0.9360581650521211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 74}], {
             RGBColor[
             0.2441275547351621, 0.3739239169805914, 0.9372140751365906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 103}], {
             RGBColor[
             0.21725551419299843`, 0.345679698585001, 0.9356837521813359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 116}], {
             RGBColor[
             0.23987123039501432`, 0.3694502502325462, 0.9369716837620867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 262}], {
             RGBColor[
             0.30202723660803465`, 0.4296407358190505, 0.9406995556283282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 290}], {
             RGBColor[
             0.24862549482263574`, 0.3786515371983993, 0.9374702261704662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 304}], {
             RGBColor[
             0.2609958832174149, 0.3916535997292371, 0.9381747014891992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 338}], {
             RGBColor[
             0.2249286875668965, 0.3537446903082591, 0.9361207280535366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 52}], {
             RGBColor[
             0.89726556755869, 0.9188637535063902, 0.9066512485949225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 60}], {
             RGBColor[
             0.7562801355297237, 0.809531056908518, 0.9763425941360632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 102}], {
             RGBColor[
             0.5772856165740025, 0.6623742905041798, 0.9623565848838942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 105}], {
             RGBColor[
             0.8954193827902208, 0.9181003086598438, 0.937247307981482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 128}], {
             RGBColor[
             0.5547192055800235, 0.6423805327309791, 0.9609350717272003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 139}], {
             RGBColor[
             0.5562400144756487, 0.6439789993051345, 0.961021679543971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 199}], {
             RGBColor[
             0.8971361136435547, 0.9188102209856679, 0.9087966349847089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 213}], {
             RGBColor[
             0.5654749182769274, 0.6521444572622102, 0.9616040176321952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 215}], {
             RGBColor[
             0.7558037231431869, 0.8091588799312872, 0.9762951098017001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 259}], {
             RGBColor[
             0.850480547970673, 0.8837308935118651, 0.9855697997497163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 271}], {
             RGBColor[
             0.8127696138510401, 0.5013829917925117, 0.574019985211861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 287}], {
             RGBColor[
             0.8114277374548052, 0.49106874179706506`, 0.572735002859394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 333}], {
             RGBColor[
             0.8796565038002286, 0.9065288389378603, 0.9721902291244133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 337}], {
             RGBColor[
             0.8812578483212357, 0.9077231190596664, 0.969479570547889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 345}], {
             RGBColor[
             0.8168101022247779, 0.8568829940339906, 0.982358282576511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 350}], {
             RGBColor[
             0.5770408715617338, 0.6621623046757947, 0.9623409899481321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 353}], {
             RGBColor[
             0.8993981375114619, 0.9180011012561393, 0.7445005138120175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 400}], {
             RGBColor[
             0.81382584660932, 0.509501659616798, 0.5750314348940344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 136}], {
             RGBColor[
             0.18182023692588944`, 0.308434975450926, 0.9336657655627689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 149}], {
             RGBColor[
             0.1956652358484003, 0.3229869471421173, 0.9344542177695655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 155}], {
             RGBColor[
             0.18345196765990118`, 0.3101500279100763, 0.9337586902141416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 268}], {
             RGBColor[
             0.18433220446865944`, 0.3110752126063183, 0.9338088183982067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 279}], {
             RGBColor[
             0.19002059109890063`, 0.3170540676192452, 0.934132763601585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 299}], {
             RGBColor[
             0.184696983160691, 0.3114586181399484, 0.9338295920050762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 300}], {
             RGBColor[
             0.18858263454534693`, 0.31554268410974895`, 0.9340508741031263]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 371}], {
             RGBColor[
             0.18051873474236652`, 0.3070670141360388, 0.9335916469388172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.1986316801099837, 0.3261048681444708, 0.9346231523818017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 86}], {
             RGBColor[
             0.23801910122574216`, 0.3675035450438693, 0.9368662077458763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 103}], {
             RGBColor[
             0.2013643551866071, 0.328977082911609, 0.9347787741847848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 295}], {
             RGBColor[
             0.19691998178395526`, 0.3243057646758728, 0.9345256736943651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 191}], {
             RGBColor[
             0.18385357890938503`, 0.3105721467969078, 0.933781561380669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 225}], {
             RGBColor[
             0.19609003670444464`, 0.3234334397757498, 0.9344784095498806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 235}], {
             RGBColor[
             0.1884735679979762, 0.31542804825324383`, 0.9340446629246031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 261}], {
             RGBColor[
             0.1864507904031121, 0.31330198074953464`, 0.9339294687330069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 327}], {
             RGBColor[
             0.18473066760764006`, 0.3114940226294092, 0.9338315102844983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 335}], {
             RGBColor[
             0.1909811618412971, 0.3180636883732066, 0.9341874666843275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 349}], {
             RGBColor[
             0.19105637302960854`, 0.3181427401007867, 0.9341917498502368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 355}], {
             RGBColor[
             0.19591924831876065`, 0.3232539303537868, 0.9344686834039748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 127}], {
             RGBColor[
             0.28524823564473223`, 0.4143130772255349, 0.9396595042068966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 137}], {
             RGBColor[
             0.2618861891426283, 0.3925893677052923, 0.9382254030945505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 138}], {
             RGBColor[
             0.26001645706684573`, 0.3906241607457843, 0.9381189246188555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 147}], {
             RGBColor[
             0.23917140342485926`, 0.3687146877153205, 0.9369318296514377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 164}], {
             RGBColor[
             0.22306024288786463`, 0.3517808364843617, 0.9360143228931819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 197}], {
             RGBColor[
             0.21121964795225362`, 0.33933562046995513`, 0.9353400185281894]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 210}], {
             RGBColor[
             0.23840421569943582`, 0.3679083247733892, 0.9368881394454274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 217}], {
             RGBColor[
             0.21968733955898895`, 0.34823570123129066`, 0.9358222410383658]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 230}], {
             RGBColor[
             0.2261265468612622, 0.35500371637530337`, 0.9361889443682767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 242}], {
             RGBColor[
             0.2857631387189643, 0.41475906038865373`, 0.9396923133754758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 254}], {
             RGBColor[
             0.20910270252497706`, 0.33711057660379506`, 0.9352194616178461]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 258}], {
             RGBColor[
             0.23439017041921995`, 0.3636893086787121, 0.9366595455049669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 328}], {
             RGBColor[
             0.23123968531368772`, 0.36037794908050486`, 0.9364801300389318]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 331}], {
             RGBColor[
             0.2360482874744978, 0.36543209483450245`, 0.9367539728183005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 79}], {
             RGBColor[
             0.20012999875823717`, 0.3276796960426744, 0.934708479412256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 87}], {
             RGBColor[
             0.1940286984190197, 0.3212668425413722, 0.9343610193840024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 126}], {
             RGBColor[
             0.1918840790772874, 0.31901271163649164`, 0.9342388864851707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 176}], {
             RGBColor[
             0.19370665948804128`, 0.32092835920646634`, 0.9343426797432972]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 205}], {
             RGBColor[
             0.19318129293550862`, 0.32037616564959115`, 0.9343127608953405]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 232}], {
             RGBColor[
             0.19578437289714112`, 0.32311216773406903`, 0.9344610024482438]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 277}], {
             RGBColor[
             0.19316166908716753`, 0.3203555397407608, 0.9343116433462084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 298}], {
             RGBColor[
             0.20333725610200998`, 0.3310507268628402, 0.9348911279732717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 373}], {
             RGBColor[
             0.1995969758310581, 0.32711945515060364`, 0.9346781245450898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 390}], {
             RGBColor[
             0.2070958500160861, 0.33500124737515247`, 0.935105174336337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 60}], {
             RGBColor[
             0.8480092281788032, 0.880384326820778, 0.9017418370121976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 68}], {
             RGBColor[
             0.9052995090875355, 0.9251530264391655, 0.9074485213302443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 105}], {
             RGBColor[
             0.9871484754393005, 0.988953578572104, 0.8626465508576164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 129}], {
             RGBColor[
             0.904165411034544, 0.5696744067053534, 0.4991000639737569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 199}], {
             RGBColor[
             0.9888652062926342, 0.9896634908979279, 0.8341958778608433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 271}], {
             RGBColor[
             0.9044987065001195, 0.5722362617047718, 0.4994192280879955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 287}], {
             RGBColor[
             0.9031568301038848, 0.5619220117093251, 0.49813424573552845`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 303}], {
             RGBColor[
             0.9414623591594504, 0.8004800076065881, 0.5326277353789215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 333}], {
             RGBColor[
             0.9713855964493081, 0.9773821088501203, 0.8975894720005477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 337}], {
             RGBColor[
             0.9729869409703154, 0.9785763889719264, 0.8948788134240234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 345}], {
             RGBColor[
             0.9085391948738575, 0.9277362639462506, 0.9077575254526454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 353}], {
             RGBColor[
             0.9911272301605415, 0.9888543711683995, 0.6698997566881519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 391}], {
             RGBColor[
             0.904614436704831, 0.5731258147714826, 0.49953005146272567`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 69}], {
             RGBColor[
             0.4877113731208531, 0.5936081076641104, 0.9531940365593021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 93}], {
             RGBColor[
             0.37256678589576175`, 0.4971203570169409, 0.9449606040427729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 131}], {
             RGBColor[
             0.6083578580504109, 0.6889233390243821, 0.9644906126536026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 142}], {
             RGBColor[
             0.43838221439814257`, 0.5535604743597381, 0.949310664485988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 188}], {
             RGBColor[
             0.33920701496392514`, 0.465180569896386, 0.9429464497347737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 201}], {
             RGBColor[
             0.5341594365329997, 0.6309589682060907, 0.9570952074204189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 264}], {
             RGBColor[
             0.3312918681319017, 0.4568612487266348, 0.9424956938321003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 273}], {
             RGBColor[
             0.4633253395942303, 0.573810427068907, 0.9512742786711021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 281}], {
             RGBColor[
             0.40067800773256046`, 0.5214688844608842, 0.9467518262404362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[
             0.35836727987096656`, 0.4848214585861875, 0.944055824075003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 394}], {
             RGBColor[
             0.38011496144870427`, 0.5036582072985654, 0.9454415671144167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 64}], {
             RGBColor[
             0.970419525130984, 0.9095497585157698, 0.3557751825465969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 83}], {
             RGBColor[
             0.9496193654049732, 0.8977579075232218, 0.6225379522867944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 123}], {
             RGBColor[
             0.8957058066069172, 0.5826430148496441, 0.23309163667201951`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 161}], {
             RGBColor[
             0.9139000708098552, 0.6892402426005217, 0.2492124251865322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 196}], {
             RGBColor[
             0.8961892019683437, 0.8555483275728113, 0.6311082747514651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 198}], {
             RGBColor[
             0.8885256847199983, 0.8494376469396148, 0.6303773216350153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 206}], {
             RGBColor[
             0.6885711015156095, 0.68922695188861, 0.6128856824256679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 214}], {
             RGBColor[
             0.913587591361185, 0.6878213464055395, 0.24895168467498954`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 310}], {
             RGBColor[
             0.8873852444618682, 0.5186875281092153, 0.22512385696518958`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 332}], {
             RGBColor[
             0.8830293594773344, 0.4852062873571179, 0.22095265658473165`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 389}], {
             RGBColor[
             0.9706885388162402, 0.9101251515870772, 0.3850556620267193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 57}], {
             RGBColor[
             0.5760181454967422, 0.6613528823456771, 0.9622434817439033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 68}], {
             RGBColor[
             0.8126708442680417, 0.8535970039103761, 0.981959617507143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 72}], {
             RGBColor[
             0.6346370252408752, 0.7117938428167392, 0.9660702931075245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 83}], {
             RGBColor[
             0.8773611303882973, 0.9047851000408222, 0.9744632955960668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 123}], {
             RGBColor[
             0.8234475715902414, 0.5896702073672445, 0.5850169799812919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 161}], {
             RGBColor[
             0.8416418357931794, 0.6962674351181222, 0.6011377684958046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 196}], {
             RGBColor[
             0.8239309669516679, 0.8625755200904117, 0.9830336180607375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 236}], {
             RGBColor[
             0.6566866391587384, 0.7296947127190476, 0.9678061194855357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 262}], {
             RGBColor[
             0.5840352729572464, 0.6682969151994234, 0.9627543260164191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 284}], {
             RGBColor[
             0.7718010949853338, 0.8216561483989014, 0.9778895783229857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 334}], {
             RGBColor[
             0.8819744590496598, 0.862025730858683, 0.6405013220512796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 366}], {
             RGBColor[
             0.8985186945130963, 0.9173414029032505, 0.7466017890196988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 397}], {
             RGBColor[
             0.5839584526615165, 0.6682303773203624, 0.9627494310951048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 65}], {
             RGBColor[
             0.4474461015886463, 0.5602099797974611, 0.9502200964459863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 100}], {
             RGBColor[
             0.4530551393941151, 0.565068246426121, 0.9505774993750733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 174}], {
             RGBColor[
             0.4681168777823908, 0.5781139671930625, 0.9515372200266019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 198}], {
             RGBColor[
             0.6735978276393025, 0.7431113232752183, 0.969380994432274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 203}], {
             RGBColor[
             0.4142038212467356, 0.5314171873708888, 0.948101927737594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 206}], {
             RGBColor[
             0.4736432444349138, 0.5829006282242136, 0.9518893552229266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 266}], {
             RGBColor[
             0.5883098999275997, 0.6764125091387695, 0.9608991949142476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 341}], {
             RGBColor[
             0.38387079611477953`, 0.499652079122729, 0.9463702293168075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 358}], {
             RGBColor[
             0.3979975915234898, 0.5145002367878451, 0.9471747294166126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 68}], {
             RGBColor[
             0.584951659196002, 0.6683449078949819, 0.9631304154261922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 72}], {
             RGBColor[
             0.4069178401688355, 0.5265417468013449, 0.9472410910265736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 86}], {
             RGBColor[
             0.30819911150930557`, 0.43761024408224003`, 0.9409967540495674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 108}], {
             RGBColor[
             0.32733127751038416`, 0.4577193635987606, 0.9420863025998256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 236}], {
             RGBColor[
             0.4289674540866987, 0.5444426167036535, 0.9489769174045849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 262}], {
             RGBColor[
             0.35631608788520674`, 0.4830448191840292, 0.9439251239354682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 284}], {
             RGBColor[
             0.544081909913294, 0.6364040523835073, 0.9590603762420349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 297}], {
             RGBColor[
             0.3224295006293375, 0.45256728530617585`, 0.9418071536579791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 325}], {
             RGBColor[
             0.29328547563165996`, 0.42193506719570584`, 0.9401474445490827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 376}], {
             RGBColor[
             0.31723897478085683`, 0.4471117135410761, 0.941511560889603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 397}], {
             RGBColor[
             0.3562392675894767, 0.4829782813049682, 0.943920229014154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 124}], {
             RGBColor[
             0.20991109539232988`, 0.337960248762451, 0.9352654983957317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 152}], {
             RGBColor[
             0.19702370192683044`, 0.32441478112227146`, 0.9345315804030616]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 156}], {
             RGBColor[
             0.19753761270804981`, 0.3249549339371585, 0.9345608468617892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 160}], {
             RGBColor[
             0.1942495004305084, 0.32149891945510295`, 0.9343735937319094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 179}], {
             RGBColor[
             0.21000836012355356`, 0.3380624801619072, 0.9352710374782847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 181}], {
             RGBColor[
             0.19266290312611054`, 0.31983130509210156`, 0.9342832393625844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 220}], {
             RGBColor[
             0.186453938859043, 0.31330528997634166`, 0.9339296480329143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[
             0.1940488178607217, 0.32128798935024727`, 0.9343621651564433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 352}], {
             RGBColor[
             0.18979453396815193`, 0.3168164672419784, 0.9341198899824106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 396}], {
             RGBColor[
             0.18880077082680655`, 0.315771959172202, 0.9340632966416518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 132}], {
             RGBColor[
             0.20457320024571096`, 0.33234978252125474`, 0.93496151316384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 149}], {
             RGBColor[
             0.21329928840113216`, 0.34152145443854653`, 0.9354584509752006]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 155}], {
             RGBColor[
             0.20108602021263303`, 0.3286845352065056, 0.9347629234197767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 164}], {
             RGBColor[
             0.215632569168565, 0.3439738804636637, 0.9355913278631264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 210}], {
             RGBColor[
             0.23097654198013617`, 0.36010136875269116`, 0.9364651444153718]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 230}], {
             RGBColor[
             0.21869887314196257`, 0.34719676035460534`, 0.9357659493382211]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 258}], {
             RGBColor[
             0.2269624966999203, 0.35588235265801405`, 0.9362365504749113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 264}], {
             RGBColor[
             0.2381256499847355, 0.3676155345451527, 0.9368722755400762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 268}], {
             RGBColor[
             0.2019662570213913, 0.3296097199027477, 0.9348130516038419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 279}], {
             RGBColor[
             0.2076546436516325, 0.3355885749156745, 0.9351369968072203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 299}], {
             RGBColor[
             0.20233103571342284`, 0.3299931254363777, 0.9348338252107113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 300}], {
             RGBColor[
             0.20621668709807878`, 0.3340771914061782, 0.9350551073087614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 328}], {
             RGBColor[
             0.22381201159438807`, 0.3525709930598068, 0.9360571350088763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 394}], {
             RGBColor[
             0.286948743301538, 0.41441249311708334`, 0.9398181488223927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 68}], {
             RGBColor[
             0.7643140770585692, 0.8158203298412934, 0.9771398668713851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 72}], {
             RGBColor[
             0.5862802580314027, 0.6740171687476564, 0.9612505424717664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 102}], {
             RGBColor[
             0.5280292771941157, 0.6238948638185677, 0.9574471733011694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 105}], {
             RGBColor[
             0.8461630434103341, 0.8796208819742317, 0.932337896398757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 108}], {
             RGBColor[
             0.5066936953729514, 0.6051947855450721, 0.9560957540450186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 139}], {
             RGBColor[
             0.506983675095762, 0.6054995726195224, 0.9561122679612462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 297}], {
             RGBColor[
             0.5017919184919047, 0.6000427072524873, 0.955816605103172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 333}], {
             RGBColor[
             0.8304001644203418, 0.8680494122522482, 0.9672808175416883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 337}], {
             RGBColor[
             0.8320015089413489, 0.8692436923740543, 0.9645701589651641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 345}], {
             RGBColor[
             0.7675537628448912, 0.8184035673483785, 0.9774488709937861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 353}], {
             RGBColor[
             0.8501417981315751, 0.8795216745705272, 0.7395911022292926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 70}], {
             RGBColor[
             0.20711529305388426`, 0.33502168324063814`, 0.9351062815885762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 90}], {
             RGBColor[
             0.21641762089155886`, 0.3447990195996844, 0.935636035397371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 95}], {
             RGBColor[
             0.23224869997063102`, 0.3614384874601766, 0.9365375919309413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 148}], {
             RGBColor[
             0.23690961095816437`, 0.3663374004268991, 0.9368030239164815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 228}], {
             RGBColor[
             0.220637096263315, 0.34923395574559046`, 0.935876328277638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 282}], {
             RGBColor[
             0.2661448795948803, 0.3964851197604022, 0.9384891805623623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 285}], {
             RGBColor[
             0.2007711589524707, 0.32835359605871806`, 0.934744992536806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 301}], {
             RGBColor[
             0.23356716082772205`, 0.3628242734162258, 0.9366126763262647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 382}], {
             RGBColor[
             0.2696810924925139, 0.39954800963710424`, 0.9387145049212492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 91}], {
             RGBColor[
             0.7921898842803778, 0.8354987729647263, 0.873281889830355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 111}], {
             RGBColor[
             0.9092079691258396, 0.5982182088690406, 0.47930597740308856`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 117}], {
             RGBColor[
             0.7751677288121797, 0.821679420316278, 0.8719418433976884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 223}], {
             RGBColor[
             0.9255100897331807, 0.7222473691090705, 0.4948669383214451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 247}], {
             RGBColor[
             0.9045712992599508, 0.5625787324781286, 0.4748658971031438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 256}], {
             RGBColor[
             0.992053902372576, 0.9909820986727351, 0.781350931735281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 319}], {
             RGBColor[
             0.9121241184522142, 0.6206330104563391, 0.4820984852913445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 323}], {
             RGBColor[
             0.7062128595771804, 0.7648109743818534, 0.8667587588510515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 362}], {
             RGBColor[
             0.8915373797700097, 0.913872404880224, 0.882662516799504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 395}], {
             RGBColor[
             0.7152423649203183, 0.772631878073945, 0.8673341109470382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 103}], {
             RGBColor[
             0.19205709543901506`, 0.31919456280253833`, 0.9342487395110164]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 295}], {
             RGBColor[
             0.1876127220363632, 0.31452324456680214`, 0.9339956390205967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 88}], {
             RGBColor[
             0.7114905669436782, 0.7668789695612932, 0.6914868954695467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 101}], {
             RGBColor[
             0.9232794978996539, 0.7012101823729198, 0.31682349709282953`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 115}], {
             RGBColor[
             0.973846560757742, 0.9231368127839409, 0.35853265585475147`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 120}], {
             RGBColor[
             0.7025664799902631, 0.759149373979897, 0.6909182605401354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 123}], {
             RGBColor[
             0.9178715311357676, 0.6596421800395433, 0.31164482201230714`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 140}], {
             RGBColor[
             0.6994659535308891, 0.7564638537977784, 0.690720697735832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 161}], {
             RGBColor[
             0.9360657953387055, 0.766239407790421, 0.32776561052681985`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 193}], {
             RGBColor[
             0.9152566921622731, 0.9300770448033753, 0.7093659477350615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 195}], {
             RGBColor[
             0.7086017617355334, 0.7643768316855696, 0.6913028233561538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 214}], {
             RGBColor[
             0.9357533158900353, 0.7648205115954387, 0.32750487001527717`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 233}], {
             RGBColor[
             0.9814581324353071, 0.9819712119725741, 0.6847171998056071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 257}], {
             RGBColor[
             0.9810027572631417, 0.9816315939147817, 0.6854880311912166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 283}], {
             RGBColor[
             0.9622538962308652, 0.8771757609613251, 0.3492049258616166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 312}], {
             RGBColor[
             0.7702008939642393, 0.8151650470913949, 0.695936819489472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 332}], {
             RGBColor[
             0.9051950840061846, 0.5622054525470171, 0.2995058419250193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 356}], {
             RGBColor[
             0.9689844051155808, 0.9726683265613763, 0.7058319664887789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 360}], {
             RGBColor[
             0.8276703795499445, 0.8615089159497265, 0.7006746506658257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 380}], {
             RGBColor[
             0.8564837144111264, 0.8840181121327374, 0.7035464946088651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 389}], {
             RGBColor[
             0.9928542633450905, 0.9871243167769764, 0.4636088473670069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 100}], {
             RGBColor[
             0.38210315454201915`, 0.5053802802265043, 0.9455682530202327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 167}], {
             RGBColor[
             0.30615029923372655`, 0.43284997763222943`, 0.940975526215034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 174}], {
             RGBColor[
             0.39716489293029483`, 0.5184260009934458, 0.9465279736717613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 198}], {
             RGBColor[
             0.6026458427872066, 0.6834233570756016, 0.9643717480774334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 203}], {
             RGBColor[
             0.34325183639463963`, 0.4717292211712722, 0.9430926813827534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 206}], {
             RGBColor[
             0.4026912595828178, 0.5232126620245969, 0.9468801088680859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 211}], {
             RGBColor[
             0.3044915837808781, 0.4311065625226518, 0.9408810648238439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 266}], {
             RGBColor[
             0.5173579150755038, 0.6167245429391528, 0.9558899485594068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 313}], {
             RGBColor[
             0.33055584599709903`, 0.45850175468157234`, 0.9423653859984371]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 329}], {
             RGBColor[
             0.31941652727713654`, 0.4467936244332925, 0.9417310182764805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 340}], {
             RGBColor[
             0.3239430587205376, 0.45155129597897675`, 0.941988797545779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 341}], {
             RGBColor[
             0.31291881126268356`, 0.4399641129231123, 0.9413609829619669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 358}], {
             RGBColor[
             0.3270456066713938, 0.4548122705882284, 0.942165483061772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 81}], {
             RGBColor[
             0.21264159429708712`, 0.3408301762349806, 0.9354209962689466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 119}], {
             RGBColor[
             0.21795851687042844`, 0.3464185989719241, 0.9357237871438162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 130}], {
             RGBColor[
             0.20589531196195676`, 0.3337394057617535, 0.9350368054701912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 146}], {
             RGBColor[
             0.19762825714734855`, 0.3250502069900508, 0.9345660089285108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 151}], {
             RGBColor[
             0.20186975982558952`, 0.3295082952316844, 0.9348075562312959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 158}], {
             RGBColor[
             0.19363377892106423`, 0.3208517571096786, 0.934338529302825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 243}], {
             RGBColor[
             0.21376058132167255`, 0.342006302545695, 0.9354847209246038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 267}], {
             RGBColor[
             0.1968456208420638, 0.3242276066111888, 0.9345214389487315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 275}], {
             RGBColor[
             0.19513571872831864`, 0.3224303910755869, 0.9344240625529272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 311}], {
             RGBColor[
             0.19936169446772767`, 0.32687215952004334`, 0.9346647256195157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 317}], {
             RGBColor[
             0.19231567190482668`, 0.3194663430628012, 0.9342634650582149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 344}], {
             RGBColor[
             0.19384485664191092`, 0.32107361317738903`, 0.9343505498667657]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 346}], {
             RGBColor[
             0.19977669952143007`, 0.3273083561443247, 0.9346883595433791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 354}], {
             RGBColor[
             0.19611420939972474`, 0.3234588468111266, 0.9344797861491166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 75}], {
             RGBColor[
             0.1806580838475214, 0.3072134788808002, 0.9335995826642074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 126}], {
             RGBColor[
             0.18098291600078534`, 0.3075548980694286, 0.9336180813747896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 133}], {
             RGBColor[
             0.1814057266970613, 0.30799929891896116`, 0.9336421598184501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 200}], {
             RGBColor[
             0.1867268102524256, 0.3135920951118324, 0.9339451876550904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 320}], {
             RGBColor[
             0.1815572411564681, 0.30815855022236927`, 0.9336507883427678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 347}], {
             RGBColor[
             0.18186543483400505`, 0.3084824813180684, 0.9336683395167719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 398}], {
             RGBColor[
             0.18010682122099816`, 0.306634066908255, 0.9335681890731469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 72}], {
             RGBColor[
             0.6435705389401349, 0.7187858683660439, 0.9669572267898132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 236}], {
             RGBColor[
             0.6656201528579981, 0.7366867382683524, 0.9686930531678246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 262}], {
             RGBColor[
             0.5929687866565062, 0.6752889407487281, 0.9636412596987081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 284}], {
             RGBColor[
             0.7807346086845934, 0.8286481739482061, 0.9787765120052747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 333}], {
             RGBColor[
             0.8876904453290742, 0.9128181118706356, 0.9729875018597351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 334}], {
             RGBColor[
             0.8909079727489195, 0.8690177564079877, 0.6413882557335685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 337}], {
             RGBColor[
             0.8892917898500812, 0.9140123919924417, 0.970276843283211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 376}], {
             RGBColor[
             0.5538916735521564, 0.639355835105775, 0.9612276966528428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 391}], {
             RGBColor[
             0.8209192855845969, 0.5085618177919978, 0.5749280813219132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 397}], {
             RGBColor[
             0.5928919663607762, 0.6752224028696671, 0.9636363647773936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 93}], {
             RGBColor[
             0.45767335020652483`, 0.5675906819706489, 0.951280040300782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 131}], {
             RGBColor[
             0.693464422361174, 0.75939366397809, 0.9708100489116116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 142}], {
             RGBColor[
             0.5234887787089056, 0.6240307993134462, 0.955630100743997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 188}], {
             RGBColor[
             0.42431357927468827`, 0.535650894850094, 0.9492658859927827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 201}], {
             RGBColor[
             0.6192660008437627, 0.7014292931597987, 0.9634146436784279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 273}], {
             RGBColor[
             0.5484319039049934, 0.644280752022615, 0.9575937149291112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 281}], {
             RGBColor[
             0.4857845720433236, 0.5919392094145923, 0.9530712624984452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 293}], {
             RGBColor[
             0.44347384418172964`, 0.5552917835398956, 0.950375260333012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 394}], {
             RGBColor[
             0.46522152575946735`, 0.5741285322522734, 0.9517610033724258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 90}], {
             RGBColor[
             0.2062666965089075, 0.33412975446773896`, 0.9350579552707259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 95}], {
             RGBColor[
             0.22209777558797966`, 0.3507692223282312, 0.9359595118042963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 177}], {
             RGBColor[
             0.1891804395703839, 0.31617101509409057`, 0.9340849182149289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 228}], {
             RGBColor[
             0.21048617188066365`, 0.3385646906136451, 0.9352982481509928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 246}], {
             RGBColor[
             0.2068329817370454, 0.33472495614706915`, 0.9350902043767244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 260}], {
             RGBColor[
             0.19294770058427305`, 0.3201306452778321, 0.9342994581565066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 285}], {
             RGBColor[
             0.1906202345698193, 0.31768433092677273`, 0.9341669124101608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 110}], {
             RGBColor[
             0.9113332721380322, 0.9312595378862136, 0.9610025753124077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 131}], {
             RGBColor[
             0.8919073913712897, 0.9158173378862382, 0.9591371203789343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 201}], {
             RGBColor[
             0.8177089698538784, 0.8578529670679469, 0.9517417151457506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 212}], {
             RGBColor[
             0.7737416965530766, 0.822516123696677, 0.9480358411696325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 271}], {
             RGBColor[
             0.8948533141221586, 0.565840640212504, 0.5514777902284453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 273}], {
             RGBColor[
             0.7468748729151091, 0.8007044259307632, 0.9459207863964338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 287}], {
             RGBColor[
             0.8935114377259239, 0.5555263902170573, 0.5501928078759782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 289}], {
             RGBColor[
             0.7219591346417744, 0.780476707159252, 0.9439593282102003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 292}], {
             RGBColor[
             0.8945978800262582, 0.5638772618194792, 0.5512331862497395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 303}], {
             RGBColor[
             0.9318169667814895, 0.7940843861143203, 0.5846862975193713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 385}], {
             RGBColor[
             0.9820607295061435, 0.9836969405379016, 0.7849671104328407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 400}], {
             RGBColor[
             0.8959095468804387, 0.5739593080367903, 0.5524892399106185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 86}], {
             RGBColor[
             0.3668179912534385, 0.4880512045533021, 0.9448235654131886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 108}], {
             RGBColor[
             0.3859501572545172, 0.5081603240698226, 0.9459131139634468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 236}], {
             RGBColor[
             0.4875863338308316, 0.5948835771747154, 0.9528037287682061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 262}], {
             RGBColor[
             0.4149349676293397, 0.5334857796550911, 0.9477519352990894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 284}], {
             RGBColor[
             0.602700789657427, 0.6868450128545692, 0.9628871876056561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 297}], {
             RGBColor[
             0.3810483803734705, 0.5030082457772378, 0.9456339650216002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 325}], {
             RGBColor[
             0.35190435537579295`, 0.4723760276667679, 0.9439742559127038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 333}], {
             RGBColor[
             0.7096566263019076, 0.7710149507769987, 0.9570981774601166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 337}], {
             RGBColor[
             0.7112579708229148, 0.7722092308988048, 0.9543875188835923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 376}], {
             RGBColor[
             0.3758578545249899, 0.4975526740121381, 0.9453383722532241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 397}], {
             RGBColor[
             0.4148581473336097, 0.5334192417760302, 0.947747040377775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.21536881746289013`, 0.3436966606981754, 0.9355763075936738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 162}], {
             RGBColor[
             0.19690433907813965`, 0.3242893232002557, 0.9345247828654102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 183}], {
             RGBColor[
             0.19359784833893534`, 0.3208139917897307, 0.9343364831093273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 189}], {
             RGBColor[
             0.2158427366159144, 0.3441947797762137, 0.9356032965883381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 207}], {
             RGBColor[
             0.1950145063297256, 0.32230298915935574`, 0.934417159686145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 280}], {
             RGBColor[
             0.2037203723071403, 0.3314534062854026, 0.9349129458743843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 291}], {
             RGBColor[
             0.19698615809912115`, 0.32437532017893284`, 0.9345294423376147]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 336}], {
             RGBColor[
             0.2166564041388005, 0.3450499959322676, 0.9356496337500533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 368}], {
             RGBColor[
             0.19117243294824504`, 0.31826472643389747`, 0.934198359290908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 387}], {
             RGBColor[
             0.19202691052884113`, 0.31916283654811173`, 0.9342470205250366]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 116}], {
             RGBColor[
             0.244277527259818, 0.37408154761281204`, 0.9372226158500052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 118}], {
             RGBColor[
             0.3029906205258713, 0.4312899550504897, 0.9407311083477143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 141}], {
             RGBColor[
             0.3021503369999872, 0.43056214369424695`, 0.9406775662244785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 179}], {
             RGBColor[
             0.23767352171657924`, 0.3671403190687327, 0.9368465275040685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 209}], {
             RGBColor[
             0.2567896978925637, 0.3872326322652657, 0.9379351654574425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 286}], {
             RGBColor[
             0.28488862903471124`, 0.4156109198533938, 0.9395776654568602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 290}], {
             RGBColor[
             0.2530317916874394, 0.3832828345786652, 0.9377211582583846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 304}], {
             RGBColor[
             0.2654021800822186, 0.39628489710950293`, 0.9384256335771177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 338}], {
             RGBColor[
             0.22933498443170014`, 0.35837598768852497`, 0.9363716601414551]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 386}], {
             RGBColor[
             0.29523037248077955`, 0.42456841823523894`, 0.9402366322043989]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 126}], {
             RGBColor[
             0.18223452639463555`, 0.3088704199500476, 0.9336893587351277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 133}], {
             RGBColor[
             0.18265733709091148`, 0.3093148207995801, 0.9337134371787883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 178}], {
             RGBColor[
             0.18245868691760933`, 0.30910602687229105`, 0.9337021243452953]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 200}], {
             RGBColor[
             0.1879784206462758, 0.3149076169924513, 0.9340164650154286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 296}], {
             RGBColor[
             0.18049305546872535`, 0.30704002359128196`, 0.9335901845421726]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 320}], {
             RGBColor[
             0.18280885155031829`, 0.3094740721029882, 0.933722065703106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 330}], {
             RGBColor[
             0.18530504232011252`, 0.31209772686967785`, 0.9338642200746624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 347}], {
             RGBColor[
             0.18311704522785527`, 0.30979800319868733`, 0.9337396168771099]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 398}], {
             RGBColor[
             0.18135843161484838`, 0.30794958878887396`, 0.9336394664334849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 78}], {
             RGBColor[
             0.2517003601981642, 0.38188341566580475`, 0.9376453352047469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 80}], {
             RGBColor[
             0.24302079240522623`, 0.37276063959904404`, 0.9371510466592089]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.24728213971667218`, 0.37723958580839845`, 0.9373937240844974]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 117}], {
             RGBColor[
             0.4207333030341396, 0.5335965741048728, 0.9489064510842957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.2623813144884871, 0.39310977583655005`, 0.9382535997505249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 187}], {
             RGBColor[
             0.24964108184106412`, 0.37971898354670364`, 0.9375280623487394]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 208}], {
             RGBColor[
             0.28867650153937047`, 0.420747684638181, 0.9397510717528295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 239}], {
             RGBColor[
             0.3950361568987507, 0.5127344732289232, 0.94688347760877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 269}], {
             RGBColor[
             0.3181691701834686, 0.44761747327725976`, 0.9415818139795731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 323}], {
             RGBColor[
             0.3517784337991403, 0.4767281281704481, 0.9437233665376588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 365}], {
             RGBColor[
             0.2944759917270998, 0.42684331653440033`, 0.9400813441394438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 377}], {
             RGBColor[
             0.2688145572376063, 0.39987152185702324`, 0.9386199634079575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 388}], {
             RGBColor[
             0.276858244918402, 0.40832594760879465`, 0.9390780395218092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 395}], {
             RGBColor[
             0.36080793914227827`, 0.4845490318625397, 0.9442987186336453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 78}], {
             RGBColor[
             0.20870891214169546`, 0.33669667794321373`, 0.9351970358380788]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 80}], {
             RGBColor[
             0.20002934434875747`, 0.3275739018764531, 0.9347027472925409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 96}], {
             RGBColor[
             0.20429069166020342`, 0.3320528480858075, 0.9349454247178293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 182}], {
             RGBColor[
             0.21938986643201835`, 0.34792303811395897`, 0.9358053003838569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 187}], {
             RGBColor[
             0.2066496337845954, 0.33453224582411256`, 0.9350797629820713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 244}], {
             RGBColor[
             0.18965577385650711`, 0.31667062156674053`, 0.9341119877993296]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 302}], {
             RGBColor[
             0.19582677060371215`, 0.3231567304118451, 0.9344634169349113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 377}], {
             RGBColor[
             0.22582310918113752`, 0.35468478413443216`, 0.9361716640412894]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 388}], {
             RGBColor[
             0.23386679686193323`, 0.36313920988620363`, 0.9366297401551412]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 80}], {
             RGBColor[
             0.21178615052788774`, 0.3399310505952844, 0.9353722800118063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 96}], {
             RGBColor[
             0.2160474978393337, 0.3444099968046388, 0.9356149574370947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 104}], {
             RGBColor[
             0.22225745398096258`, 0.35093705444345114`, 0.9359686052525535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 182}], {
             RGBColor[
             0.23114667261114863`, 0.3602801868327903, 0.9364748331031223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 187}], {
             RGBColor[
             0.21840643996372563`, 0.3468893945429439, 0.9357492957013367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 208}], {
             RGBColor[
             0.257441859662032, 0.38791809563442126`, 0.9379723051054267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 302}], {
             RGBColor[
             0.2075835767828424, 0.33551387913067643`, 0.9351329496541767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 377}], {
             RGBColor[
             0.2375799153602678, 0.3670419328532635, 0.9368411967605548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 388}], {
             RGBColor[
             0.2456236030410635, 0.37549635860503494`, 0.9372992728744065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 87}], {
             RGBColor[
             0.19294989757058154`, 0.3201329544497393, 0.9342995832716268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 126}], {
             RGBColor[
             0.19080527822884924`, 0.31787882354485875`, 0.9341774503727951]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 176}], {
             RGBColor[
             0.19262785863960308`, 0.31979447111483345`, 0.9342812436309215]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 205}], {
             RGBColor[
             0.19210249208707042`, 0.3192422775579583, 0.9342513247829649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 232}], {
             RGBColor[
             0.19470557204870292`, 0.32197827964243614`, 0.9343995663358682]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[
             0.19208286823872933`, 0.31922165164912797`, 0.9342502072338328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 298}], {
             RGBColor[
             0.20225845525357178`, 0.3299168387712073, 0.934829691860896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 373}], {
             RGBColor[
             0.19851817498261992`, 0.32598556705897075`, 0.9346166884327141]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 390}], {
             RGBColor[
             0.2060170491676479, 0.3338673592835195, 0.9350437382239613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 96}], {
             RGBColor[
             0.2073679300463957, 0.3352872207378781, 0.9351206688915568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 104}], {
             RGBColor[
             0.2135778861880246, 0.34181427837669043`, 0.9354743167070156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 182}], {
             RGBColor[
             0.22246710481821064`, 0.35115741076602963`, 0.9359805445575843]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 187}], {
             RGBColor[
             0.20972687217078761`, 0.3377666184761832, 0.9352550071557988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 244}], {
             RGBColor[
             0.1927330122426994, 0.31990499421881113`, 0.9342872319730569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 302}], {
             RGBColor[
             0.1989040089899044, 0.3263911030639157, 0.9346386611086387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 377}], {
             RGBColor[
             0.2289003475673298, 0.3579191567865028, 0.9363469082150169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 388}], {
             RGBColor[
             0.23694403524812552`, 0.36637358253827423`, 0.9368049843288686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 119}], {
             RGBColor[
             0.2344729010553813, 0.363776263822743, 0.9366642568923073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 128}], {
             RGBColor[
             0.2665289573662383, 0.3974692114768138, 0.9384898018765251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.2224096961469096, 0.35109707061257234`, 0.9359772752186821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 135}], {
             RGBColor[
             0.2822556151095555, 0.41153871876028536`, 0.9394754920042432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 146}], {
             RGBColor[
             0.2141426413323014, 0.3424078718408697, 0.9355064786770019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 166}], {
             RGBColor[
             0.2371652059079643, 0.3666060469247946, 0.9368175796707537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 227}], {
             RGBColor[
             0.2515739104642789, 0.38175050897811513`, 0.9376381340794677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 243}], {
             RGBColor[
             0.2302749655066254, 0.3593639673965138, 0.9364251906730947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[
             0.21336000502701669`, 0.3415852714620077, 0.9354619086972226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 275}], {
             RGBColor[
             0.21165010291327152`, 0.33978805592640576`, 0.9353645323014182]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 311}], {
             RGBColor[
             0.21587607865268055`, 0.34422982437086214`, 0.9356051953680067]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 326}], {
             RGBColor[
             0.23536377630225702`, 0.36471263019196243`, 0.936714990919685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 344}], {
             RGBColor[
             0.2103592408268638, 0.3384312780282078, 0.9352910196152566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 346}], {
             RGBColor[
             0.21629108370638292`, 0.34466602099514354`, 0.9356288292918702]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 363}], {
             RGBColor[
             0.3018408929173706, 0.42850250201273, 0.940723448587576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 383}], {
             RGBColor[
             0.2937367673363199, 0.42148311575961905`, 0.9402070608717483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 172}], {
             RGBColor[
             0.5696909718954926, 0.6577404259092337, 0.9610497684809419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 194}], {
             RGBColor[
             0.6075992658363466, 0.6905170696190597, 0.963481170694517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 233}], {
             RGBColor[
             0.865044812104987, 0.8948209835298624, 0.9558976637938235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 256}], {
             RGBColor[
             0.8760312800563814, 0.9016669835366705, 0.876948136427472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 257}], {
             RGBColor[
             0.8645894369328215, 0.89448136547207, 0.956668495179433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 310}], {
             RGBColor[
             0.7931376486603983, 0.5085364648564028, 0.5748575062936936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 316}], {
             RGBColor[
             0.7359499332008539, 0.7936489483339444, 0.9743162695644639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 399}], {
             RGBColor[
             0.5595672102027384, 0.6489717323660277, 0.9604046913379707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 118}], {
             RGBColor[
             0.6542161598297946, 0.7234949587303476, 0.9559255584190995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 123}], {
             RGBColor[
             0.8970713714097568, 0.6478503290469954, 0.5784075917525047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 141}], {
             RGBColor[
             0.6533758763039106, 0.7227671473741049, 0.9558720162958637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 161}], {
             RGBColor[
             0.9152656356126947, 0.754447556797873, 0.5945283802670174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 196}], {
             RGBColor[
             0.8975547667711833, 0.9207556417701627, 0.9764242298319501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 214}], {
             RGBColor[
             0.9149531561640245, 0.7530286606028909, 0.5942676397554747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 286}], {
             RGBColor[
             0.6361141683386347, 0.7078159235332517, 0.9547721155282454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 332}], {
             RGBColor[
             0.8843949242801739, 0.5504136015544692, 0.5662686116652167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 334}], {
             RGBColor[
             0.9555982588691752, 0.9202058525384339, 0.6338919338224923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 366}], {
             RGBColor[
             0.9721424943326117, 0.9755215245830015, 0.7399924007909114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 125}], {
             RGBColor[
             0.20344264397852102`, 0.33116149620303065`, 0.9348971296569317]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 184}], {
             RGBColor[
             0.21392003441563898`, 0.34217389785736374`, 0.9354938015424155]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 185}], {
             RGBColor[
             0.20341836522778634`, 0.3311359776966468, 0.9348957470179945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 190}], {
             RGBColor[
             0.21321988075352158`, 0.3414379919661722, 0.9354539288271424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 252}], {
             RGBColor[
             0.2101141940866254, 0.33817371836735655`, 0.9352770645659143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 270}], {
             RGBColor[
             0.21111604747539212`, 0.339226729800124, 0.9353341186342953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 274}], {
             RGBColor[
             0.20871345876417752`, 0.33670145673171487`, 0.935197294761503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 288}], {
             RGBColor[
             0.21401051896422651`, 0.342269002854981, 0.9354989545035975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 318}], {
             RGBColor[
             0.2138717930117836, 0.3421231930832301, 0.9354910542658326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 168}], {
             RGBColor[
             0.18992658867508105`, 0.3169552651117129, 0.9341274103026127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 238}], {
             RGBColor[
             0.19138550303315327`, 0.3184886766025597, 0.9342104933170345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 379}], {
             RGBColor[
             0.18217848519657132`, 0.30881151709766497`, 0.9336861672718034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 236}], {
             RGBColor[
             0.3888676051713017, 0.5059520744556105, 0.9465593917911999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 262}], {
             RGBColor[
             0.31621623896980977`, 0.44455427693598626`, 0.9415075983220833]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 265}], {
             RGBColor[
             0.23354789403514828`, 0.36280402279564555`, 0.9366115791109302]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 297}], {
             RGBColor[
             0.28232965171394053`, 0.4140767430581329, 0.9393896280445941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 325}], {
             RGBColor[
             0.25318562671626305`, 0.38344452494766296`, 0.9377299189356977]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 376}], {
             RGBColor[
             0.2771391258654599, 0.4086211712930332, 0.939094035276218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 397}], {
             RGBColor[
             0.3161394186740798, 0.4444877390569253, 0.9415027034007689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 176}], {
             RGBColor[
             0.18652655830038561`, 0.3133816176135313, 0.933933783602668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 205}], {
             RGBColor[
             0.18600119174785296`, 0.31282942405665615`, 0.9339038647547113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 232}], {
             RGBColor[
             0.18860427170948546`, 0.315565426141134, 0.9340521063076146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 277}], {
             RGBColor[
             0.18598156789951187`, 0.3128087981478258, 0.9339027472055792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 373}], {
             RGBColor[
             0.19241687464340246`, 0.3195727135576686, 0.9342692284044607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 390}], {
             RGBColor[
             0.19991574882843044`, 0.32745450578221735`, 0.9346962781957078]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 89}], {
             RGBColor[
             0.33131087657095276`, 0.4543117529947025, 0.9425908573941362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 120}], {
             RGBColor[
             0.42147179727410705`, 0.5394794198355211, 0.9480767881227974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 140}], {
             RGBColor[
             0.41837127081473313`, 0.5367938996534025, 0.947879225318494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 189}], {
             RGBColor[
             0.331784795723977, 0.4548098720727408, 0.9426178463888004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 195}], {
             RGBColor[
             0.42750707901937735`, 0.5447068775411936, 0.948461350938816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 233}], {
             RGBColor[
             0.7003634497191511, 0.7623012578281982, 0.9418757273882692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 255}], {
             RGBColor[
             0.40229233650521606`, 0.5228671349052352, 0.9468546898423349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 257}], {
             RGBColor[
             0.6999080745469857, 0.7619616397704058, 0.9426465587738788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 263}], {
             RGBColor[
             0.3661139704738488, 0.49089201133024934`, 0.9445728421053426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 336}], {
             RGBColor[
             0.33259846324686315`, 0.4556650882287947, 0.9426641835505155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 356}], {
             RGBColor[
             0.6878897223994248, 0.7529983724170004, 0.962990494071441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 359}], {
             RGBColor[
             0.3780427703410259, 0.5018633795124479, 0.9453095289294022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 360}], {
             RGBColor[
             0.5465756968337885, 0.6418389618053506, 0.9578331782484879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 389}], {
             RGBColor[
             0.7117595806289345, 0.7674543626326005, 0.720767374949669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 162}], {
             RGBColor[
             0.2137613905296329, 0.342007153074568, 0.9354847670077999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 183}], {
             RGBColor[
             0.21045489979042858`, 0.338531821664043, 0.935296467251717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 189}], {
             RGBColor[
             0.23269978806740765`, 0.361912609650526, 0.9365632807307278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 263}], {
             RGBColor[
             0.2670289628172794, 0.39799474890803455`, 0.93851827644727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 270}], {
             RGBColor[
             0.22008543635339983`, 0.34865412620301106`, 0.935844912061876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.22057742375863354`, 0.3491712361597149, 0.935872930016774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 291}], {
             RGBColor[
             0.2138432095506144, 0.34209315005324514`, 0.9354894264800044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 336}], {
             RGBColor[
             0.23351345559029374`, 0.36276782580657996`, 0.9366096178924429]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 359}], {
             RGBColor[
             0.2789577626844565, 0.40896611709023306`, 0.9392549632713296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 95}], {
             RGBColor[
             0.23140010342565426`, 0.3605465586872775, 0.936489265613091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 97}], {
             RGBColor[
             0.2570968896215246, 0.3875555102494842, 0.9379526595719574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.23037172884023532`, 0.35946567179528754`, 0.9364307012017953]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 228}], {
             RGBColor[
             0.21978849971833822`, 0.34834202697269134`, 0.9358280019597877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 246}], {
             RGBColor[
             0.21613530957472, 0.3445022925061154, 0.9356199581855191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 260}], {
             RGBColor[
             0.20225002842194761`, 0.32990798163687834`, 0.9348292119653014]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 326}], {
             RGBColor[
             0.22857029923452804`, 0.35757225506245527`, 0.9363281124507266]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 172}], {
             RGBColor[
             0.48609962486048197`, 0.5916756169176496, 0.9532395671401708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 192}], {
             RGBColor[
             0.4254211791359827, 0.5344518171008017, 0.9495440785539795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 208}], {
             RGBColor[
             0.4434969579662055, 0.5534506067219376, 0.9505734674176423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 221}], {
             RGBColor[
             0.48124384050183955`, 0.5874697805650118, 0.9529301608546397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 256}], {
             RGBColor[
             0.792439933021371, 0.8356021745450866, 0.869137935086701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 316}], {
             RGBColor[
             0.6523585861658432, 0.7275841393423603, 0.9665060682236928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 351}], {
             RGBColor[
             0.45106536887988224`, 0.5613307052601594, 0.9510072153286632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 395}], {
             RGBColor[
             0.5156283955691132, 0.6172519539462964, 0.9551211142984581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 399}], {
             RGBColor[
             0.4759758631677278, 0.5829069233744436, 0.9525944899971995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 98}], {
             RGBColor[
             0.19880960071600262`, 0.32629187398221465`, 0.9346332846971046]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 119}], {
             RGBColor[
             0.22208012665594387`, 0.3507506721816547, 0.9359585067237262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 130}], {
             RGBColor[
             0.2100169217474722, 0.33807147897148404`, 0.935271525050101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 143}], {
             RGBColor[
             0.20163694443753327`, 0.3292635914974891, 0.9347942977393655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 146}], {
             RGBColor[
             0.20174986693286398`, 0.32938228019978144`, 0.9348007285084208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 151}], {
             RGBColor[
             0.20599136961110498`, 0.33384036844141496`, 0.9350422758112056]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 158}], {
             RGBColor[
             0.19775538870657966`, 0.32518383031940923`, 0.9345732488827347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 186}], {
             RGBColor[
             0.20547576839988674`, 0.33329843887741967`, 0.9350129130849905]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 267}], {
             RGBColor[
             0.20096723062757926`, 0.3285596798209194, 0.9347561585286415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 306}], {
             RGBColor[
             0.21333519209183469`, 0.34155919149390046`, 0.9354604956372714]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 308}], {
             RGBColor[
             0.20860909712508957`, 0.3365917660321234, 0.9351913515205462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 346}], {
             RGBColor[
             0.2038983093069455, 0.33164042935405524`, 0.934923079123289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 348}], {
             RGBColor[
             0.2027372639690243, 0.3304200970893739, 0.9348569593089071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 354}], {
             RGBColor[
             0.20023581918524017`, 0.32779092002085713`, 0.9347145057290265]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 374}], {
             RGBColor[
             0.1940034937220554, 0.32124035080679264`, 0.9343595840137974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 131}], {
             RGBColor[
             0.5783198351360825, 0.6629059133309206, 0.9625766163950823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 142}], {
             RGBColor[
             0.4083441914838143, 0.5275430486662767, 0.9473966682274677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 188}], {
             RGBColor[
             0.3091689920495968, 0.43916314420292457`, 0.9410324534762535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 201}], {
             RGBColor[
             0.5041214136186714, 0.6049415425126292, 0.9551812111618987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 264}], {
             RGBColor[
             0.3012538452175734, 0.43084382303317337`, 0.9405816975735801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 273}], {
             RGBColor[
             0.433287316679902, 0.5477930013754455, 0.949360282412582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 281}], {
             RGBColor[
             0.3706399848182322, 0.4954514587674228, 0.944837829981916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 293}], {
             RGBColor[
             0.3283292569566383, 0.4588040328927261, 0.9421418278164828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 394}], {
             RGBColor[
             0.35007693853437594`, 0.4776407816051039, 0.9435275708558966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 204}], {
             RGBColor[
             0.1795232819748228, 0.3060207301619996, 0.9335349573763461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.18066543438157506`, 0.30722120475814135`, 0.9336000012662475]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 307}], {
             RGBColor[
             0.17906784709075121`, 0.30554203922260087`, 0.9335090210334537]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 324}], {
             RGBColor[
             0.18239675869616345`, 0.30904093638507546`, 0.9336985976246985]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 97}], {
             RGBColor[
             0.27292796870059677`, 0.4041949781099764, 0.9388542161055278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 148}], {
             RGBColor[
             0.2518920934922597, 0.3820849395144922, 0.9376562541322015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 166}], {
             RGBColor[
             0.24620280791930751`, 0.37610513965577974`, 0.9373322577353658]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 169}], {
             RGBColor[
             0.3522449518778092, 0.4737241407933565, 0.9439035250794346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 228}], {
             RGBColor[
             0.2356195787974104, 0.36498149483318354`, 0.9367295584933581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 246}], {
             RGBColor[
             0.23196638865379215`, 0.3611417603666076, 0.9365215147190895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 276}], {
             RGBColor[
             0.3131382201938357, 0.4399588551912694, 0.9413821143478849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 282}], {
             RGBColor[
             0.2811273621289757, 0.41223265884799526`, 0.9393424107780823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 305}], {
             RGBColor[
             0.2726453120788769, 0.4038978880790839, 0.9388381192290738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 326}], {
             RGBColor[
             0.24440137831360023`, 0.3742117229229475, 0.9372296689842969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 361}], {
             RGBColor[
             0.32840262007179855`, 0.45318011115451534`, 0.9423547484103298]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 382}], {
             RGBColor[
             0.2846635750266093, 0.4152955487246973, 0.9395677351369693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 104}], {
             RGBColor[
             0.21783923349947054`, 0.34629322458604483`, 0.935716994132304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 182}], {
             RGBColor[
             0.2267284521296566, 0.35563635697538404`, 0.9362232219828728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 187}], {
             RGBColor[
             0.2139882194822336, 0.34224556468553763`, 0.9354976845810872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 208}], {
             RGBColor[
             0.25302363918053994`, 0.383274265777015, 0.9377206939851772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 225}], {
             RGBColor[
             0.21005566506834547`, 0.33811220065819025`, 0.9352737314249091]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 261}], {
             RGBColor[
             0.20041641876701294`, 0.3279807416319751, 0.9347247906080353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 377}], {
             RGBColor[
             0.23316169487877575`, 0.36239810299585723`, 0.9365895856403053]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 388}], {
             RGBColor[
             0.24120538255957147`, 0.37085252874762864`, 0.937047661754157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 166}], {
             RGBColor[
             0.27189959411517783`, 0.40311409121798647`, 0.9387956516942321]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 169}], {
             RGBColor[
             0.37794173807367953`, 0.5007330923555633, 0.945366919038301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 224}], {
             RGBColor[
             0.3981861519254275, 0.5171684195208632, 0.946960633454442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 246}], {
             RGBColor[
             0.2576631748496625, 0.38815071192881434`, 0.9379849086779559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 276}], {
             RGBColor[
             0.33883500638970604`, 0.46696780675347616`, 0.9428455083067513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 326}], {
             RGBColor[
             0.27009816450947055`, 0.40122067448515425`, 0.9386930629431633]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 363}], {
             RGBColor[
             0.3365752811245841, 0.4650105463059218, 0.9427015206110543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 382}], {
             RGBColor[
             0.3103603612224796, 0.44230450028690405`, 0.9410311290958356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 383}], {
             RGBColor[
             0.32847115554353346`, 0.45799116005281093`, 0.9421851328952267]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 393}], {
             RGBColor[
             0.5102982570407728, 0.6069665111134733, 0.9566203329382144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 134}], {
             RGBColor[
             0.1861818864522268, 0.313019345647659, 0.9339141550508117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 143}], {
             RGBColor[
             0.19607611547037074`, 0.3234188076760809, 0.9344776167561948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 151}], {
             RGBColor[
             0.20043054064394245`, 0.3279955846200067, 0.934725594828035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 158}], {
             RGBColor[
             0.19219455973941713`, 0.31933904649800093`, 0.9342565678995641]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 163}], {
             RGBColor[
             0.18615149755953203`, 0.3129874049946697, 0.933912424448329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.1906510637312114, 0.3177167343300775, 0.9341686680852945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 186}], {
             RGBColor[
             0.1999149394327242, 0.32745365505601143`, 0.9346962321018197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 240}], {
             RGBColor[
             0.18629079266231832`, 0.3131338129795177, 0.9339203570983641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 272}], {
             RGBColor[
             0.1949500622314218, 0.3222352543260466, 0.9344134896900831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 306}], {
             RGBColor[
             0.20777436312467215`, 0.33571440767249217`, 0.9351438146541007]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 308}], {
             RGBColor[
             0.20304826815792704`, 0.3307469822107151, 0.9348746705373756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 342}], {
             RGBColor[
             0.1898214409282245, 0.31684474816301444`, 0.9341214222939813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 348}], {
             RGBColor[
             0.19717643500186177`, 0.3245753132679656, 0.9345402783257364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 354}], {
             RGBColor[
             0.19467499021807763`, 0.3219461361994489, 0.9343978247458558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 374}], {
             RGBColor[
             0.18844266475489285`, 0.3153955669853844, 0.9340429030306268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 378}], {
             RGBColor[
             0.21674290293340537`, 0.34514091164973765`, 0.9356545597284425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 144}], {
             RGBColor[
             0.7417116613175341, 0.797878300210745, 0.9753542230915366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 169}], {
             RGBColor[
             0.6797124063510102, 0.7475445119943138, 0.9704734146298177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[
             0.7312212189545854, 0.7893616865114603, 0.9745283770409688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 222}], {
             RGBColor[
             0.9266267914902193, 0.9439342403679507, 0.9791054495248444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 223}], {
             RGBColor[
             0.8806912086429535, 0.689221405037725, 0.5973847957056915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 276}], {
             RGBColor[
             0.6406056746670367, 0.7137792263922267, 0.9679520038982681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 361}], {
             RGBColor[
             0.6558700745449995, 0.7270004823554725, 0.968924637960713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 382}], {
             RGBColor[
             0.6121310294998102, 0.6891159199256546, 0.9661376246873524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 384}], {
             RGBColor[
             0.9178754148881313, 0.8496097092612407, 0.6279747633092586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 393}], {
             RGBColor[
             0.8120689253181035, 0.8537779307522239, 0.9817268285297311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 157}], {
             RGBColor[
             0.31728677632069113`, 0.4435179334056334, 0.9416477086340886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 167}], {
             RGBColor[
             0.3117593370391954, 0.4377082442608893, 0.941332929144121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 174}], {
             RGBColor[
             0.4027739307357637, 0.5232842676221057, 0.9468853766008484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 198}], {
             RGBColor[
             0.6082548805926754, 0.6882816237042615, 0.9647291510065205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 203}], {
             RGBColor[
             0.3488608742001085, 0.47658748779993204`, 0.9434500843118405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 206}], {
             RGBColor[
             0.40830029738828666`, 0.5280709286532568, 0.947237511797173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 211}], {
             RGBColor[
             0.31010062158634694`, 0.43596482915131163`, 0.941238467752931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 266}], {
             RGBColor[
             0.5229669528809726, 0.6215828095678126, 0.9562473514884939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 341}], {
             RGBColor[
             0.3185278490681524, 0.4448223795517722, 0.9417183858910539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 358}], {
             RGBColor[
             0.33265464447686266`, 0.4596705372168882, 0.942522885990859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 115}], {
             RGBColor[
             0.9045408089975616, 0.6377980714511916, 0.24102778506069641`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 123}], {
             RGBColor[
             0.8485657793755872, 0.374303438706794, 0.1941399512182521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 161}], {
             RGBColor[
             0.8667600435785252, 0.4809006664576717, 0.21026073973276477`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 193}], {
             RGBColor[
             0.8459509404020927, 0.6447383034706259, 0.5918610769410064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 253}], {
             RGBColor[
             0.8395830715203696, 0.3052584098839103, 0.18553810003157822`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 283}], {
             RGBColor[
             0.8929481444706848, 0.5918370196285758, 0.23170005506756156`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 332}], {
             RGBColor[
             0.8358893322460044, 0.27686671121426787`, 0.18200097113096422`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 334}], {
             RGBColor[
             0.9070926668350056, 0.6466589621982325, 0.24962429328823976`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 356}], {
             RGBColor[
             0.8996786533554004, 0.687329585228627, 0.5883270956947237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 364}], {
             RGBColor[
             0.8876560448428017, 0.5708556080916793, 0.22744190748542303`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 366}], {
             RGBColor[
             0.9236369022984421, 0.7019746342428002, 0.3557247602566589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 380}], {
             RGBColor[
             0.787177962650946, 0.5986793707999881, 0.5860416238148101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 389}], {
             RGBColor[
             0.9235485115849101, 0.701785575444227, 0.3461039765729519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 108}], {
             RGBColor[
             0.3276991764172302, 0.45803801914073383`, 0.9421097447928497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 139}], {
             RGBColor[
             0.3279891561400408, 0.4583428062151842, 0.9421262587090772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 213}], {
             RGBColor[
             0.33722405994131943`, 0.4665082641722599, 0.9427085967973012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 297}], {
             RGBColor[
             0.32279739953618347`, 0.45288594084814915`, 0.9418305958510031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 333}], {
             RGBColor[
             0.6514056454646207, 0.7208926458479099, 0.9532948082895194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 337}], {
             RGBColor[
             0.6530069899856277, 0.722086925969716, 0.9505841497129952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 345}], {
             RGBColor[
             0.5885592438891699, 0.6712468009440402, 0.9634628617416172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 350}], {
             RGBColor[
             0.3487900132261258, 0.4765261115858444, 0.9434455691132382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 378}], {
             RGBColor[
             0.29463589617818253`, 0.42328641527644917`, 0.9402268398959757]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 122}], {
             RGBColor[
             0.1920779072643653, 0.3192164373505274, 0.9342499247136817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 295}], {
             RGBColor[
             0.1903453971129866, 0.3173954593339403, 0.9341512608235798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 145}], {
             RGBColor[
             0.2369611402467977, 0.36639156097639836`, 0.9368059584332384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 170}], {
             RGBColor[
             0.22977658578143667`, 0.35884013870624076`, 0.936396808685032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 182}], {
             RGBColor[
             0.23293840827128548`, 0.36216341461419643`, 0.9365768697983317]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 187}], {
             RGBColor[
             0.2201981756238625, 0.34877262232435, 0.935851332396546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 192}], {
             RGBColor[
             0.24115781649194606`, 0.3708025337946915, 0.9370449529369735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 208}], {
             RGBColor[
             0.25923359532216883`, 0.3898013234158274, 0.9380743418006362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 225}], {
             RGBColor[
             0.2162656212099744, 0.3446392582970026, 0.935627379240368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 235}], {
             RGBColor[
             0.20864915250350596`, 0.3366338667744967, 0.9351936326150905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 261}], {
             RGBColor[
             0.20662637490864183`, 0.3345077992707875, 0.9350784384234943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 327}], {
             RGBColor[
             0.20490625211316982`, 0.332699841150662, 0.9349804799749857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 335}], {
             RGBColor[
             0.21115674634682685`, 0.33926950689445945`, 0.9353364363748149]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 349}], {
             RGBColor[
             0.21123195753513827`, 0.3393485586220395, 0.9353407195407242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 351}], {
             RGBColor[
             0.26680200623584566`, 0.3976814219540492, 0.9385080897116571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 355}], {
             RGBColor[
             0.21609483282429037`, 0.34445974887503966`, 0.9356176530944622]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 199}], {
             RGBColor[
             0.9870190215241651, 0.9889000460513815, 0.8647919372474027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 215}], {
             RGBColor[
             0.8456866310237973, 0.8792487049970009, 0.932290412064394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 259}], {
             RGBColor[
             0.9403634558512834, 0.9538207185775788, 0.9415651020124101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 271}], {
             RGBColor[
             0.9026525217316504, 0.5714728168582255, 0.530015287474555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 287}], {
             RGBColor[
             0.9013106453354156, 0.5611585668627788, 0.528730305122088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 303}], {
             RGBColor[
             0.9396161743909813, 0.7997165627600418, 0.5632237947654809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 333}], {
             RGBColor[
             0.969539411680839, 0.9766186640035739, 0.9281855313871071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 337}], {
             RGBColor[
             0.9711407562018461, 0.97781294412538, 0.9254748728105828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 345}], {
             RGBColor[
             0.9066930101053883, 0.9269728190997042, 0.9383535848392048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 350}], {
             RGBColor[
             0.6669237794423443, 0.7322521297415084, 0.9183362922108259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 353}], {
             RGBColor[
             0.9892810453920724, 0.988090926321853, 0.7004958160747115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 400}], {
             RGBColor[
             0.9037087544899305, 0.5795914846825118, 0.5310267371567282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 197}], {
             RGBColor[
             0.18891531916432497`, 0.315892356737718, 0.9340698200000144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 217}], {
             RGBColor[
             0.1973830107710603, 0.32479243749905357`, 0.9345520425101908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 231}], {
             RGBColor[
             0.1888628748467801, 0.31583723443481654`, 0.9340668333737145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 254}], {
             RGBColor[
             0.18679837373704838`, 0.3136673128715579, 0.9339492630896711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 314}], {
             RGBColor[
             0.18463641563674799`, 0.3113949578320815, 0.9338261427741893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 369}], {
             RGBColor[
             0.18346224485360668`, 0.3101608298922725, 0.9337592754851194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 124}], {
             RGBColor[
             0.22484989821780513`, 0.3536618777068309, 0.9361162411166642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 150}], {
             RGBColor[
             0.23074389884075946`, 0.35985684606277935`, 0.936451895732749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 152}], {
             RGBColor[
             0.2119625047523057, 0.3401164100666513, 0.9353823231239942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.2124764155335251, 0.34065656288153834`, 0.9354115895827217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.2349712471793796, 0.36430005719603437`, 0.936692636966832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 160}], {
             RGBColor[
             0.20918830325598364`, 0.33720054839948277`, 0.935224336452842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 167}], {
             RGBColor[
             0.22944380789788385`, 0.3584903680512903, 0.9363778574768644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.2249471629490288, 0.3537641091062871, 0.9361217801992172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 181}], {
             RGBColor[
             0.20760170595158578`, 0.3355329340364814, 0.935133982083517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 211}], {
             RGBColor[
             0.2277850924450354, 0.3567469529417126, 0.9362833960856742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 238}], {
             RGBColor[
             0.21198166691675951`, 0.34013655071644366`, 0.9353834143809119]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 245}], {
             RGBColor[
             0.20898762068619692`, 0.33698961829462715`, 0.9352129078773759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 386}], {
             RGBColor[
             0.2825040137132291, 0.4111922082727934, 0.9395118848995476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 297}], {
             RGBColor[
             0.30146181771501923`, 0.43418586257465347`, 0.9404791765948524]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 325}], {
             RGBColor[
             0.2723177927173417, 0.4035536444641835, 0.9388194674859559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 376}], {
             RGBColor[
             0.29627129186653856`, 0.4287302908095537, 0.9401835838264763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 378}], {
             RGBColor[
             0.2733003143570183, 0.40458633700295354`, 0.938875420639825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 397}], {
             RGBColor[
             0.3352715846751584, 0.4645968585734458, 0.9425922519510271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 114}], {
             RGBColor[
             0.18471405231964982`, 0.3114765589082613, 0.9338305640684275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 132}], {
             RGBColor[
             0.1878121680467173, 0.3147328749692917, 0.9340069971758325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 180}], {
             RGBColor[
             0.18558731783868732`, 0.3123944163370016, 0.933880295247856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 232}], {
             RGBColor[
             0.18655512715268852`, 0.3134116452886715, 0.9339354105565427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 249}], {
             RGBColor[
             0.18318613987214505`, 0.3098706260506894, 0.9337435517148859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 370}], {
             RGBColor[
             0.18414849826566793`, 0.3108821257393283, 0.9337983566017154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 111}], {
             RGBColor[
             0.8397873767221564, 0.5455755079920095, 0.5794773016000505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 117}], {
             RGBColor[
             0.7057471364084966, 0.7690367194392469, 0.9721131675946504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 202}], {
             RGBColor[
             0.590277084299675, 0.6718791600205865, 0.9639661767270546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 212}], {
             RGBColor[
             0.715371093239261, 0.7768498811487758, 0.9728708007300837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 239}], {
             RGBColor[
             0.6800499902731076, 0.7481746185632971, 0.9700901941191247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 247}], {
             RGBColor[
             0.8351507068562677, 0.5099360316010974, 0.5750372213001058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 269}], {
             RGBColor[
             0.6031830035578256, 0.6830576186116337, 0.9647885304899277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 287}], {
             RGBColor[
             0.8351408344121083, 0.5098601476691562, 0.5750277674364295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 289}], {
             RGBColor[
             0.6635885313279589, 0.7348104646113509, 0.9687942877706517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 292}], {
             RGBColor[
             0.8362272767124428, 0.5182110192715781, 0.5760681458101908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 303}], {
             RGBColor[
             0.873446363467674, 0.7484181435664192, 0.6095212570798225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 309}], {
             RGBColor[
             0.7751646817101416, 0.8245503622153614, 0.9781540938970312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 362}], {
             RGBColor[
             0.8221167873663267, 0.8612297040031928, 0.982833840996466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 385}], {
             RGBColor[
             0.923690126192328, 0.9380306979900004, 0.809802069993292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 400}], {
             RGBColor[
             0.8375389435666232, 0.5282930654888892, 0.5773241994710698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 199}], {
             RGBColor[
             0.9076739184987976, 0.597583839511456, 0.5047291662889358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 222}], {
             RGBColor[
             0.8888497880747033, 0.5842997162159619, 0.5703986830647514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 223}], {
             RGBColor[
             0.8429142052274374, 0.3295868808857362, 0.18867802924559862`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 247}], {
             RGBColor[
             0.8219754147542075, 0.16991824425479435`, 0.1686769880272973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 271}], {
             RGBColor[
             0.823307418706283, 0.18015661031829988`, 0.16995251651608806`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 287}], {
             RGBColor[
             0.8219655423100481, 0.16984236032285321`, 0.168667534163621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 292}], {
             RGBColor[
             0.8230519846103825, 0.1781932319252751, 0.16970791253738232`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 309}], {
             RGBColor[
             0.7619893896080814, 0.48453257486905843`, 0.5717938606242228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 319}], {
             RGBColor[
             0.8295282339464709, 0.2279725222330049, 0.17590957621549802`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 362}], {
             RGBColor[
             0.8089414952642664, 0.5212119166568898, 0.5764736077236575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 385}], {
             RGBColor[
             0.9105148340902678, 0.5980129106436974, 0.4034418367204835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[
             0.8243636514645629, 0.1882752781425862, 0.17096396619826132`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 177}], {
             RGBColor[
             0.18091855533538903`, 0.3074872509293952, 0.9336144161301083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 219}], {
             RGBColor[
             0.17968380010062157`, 0.30618944488965105`, 0.933544098646145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 248}], {
             RGBColor[
             0.18167669359362687`, 0.3082841023075451, 0.9336575909823499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 251}], {
             RGBColor[
             0.18268323345773074`, 0.30934203952303163`, 0.9337149119385684]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 260}], {
             RGBColor[
             0.18468581634927816`, 0.3114468811131368, 0.9338289560716861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 162}], {
             RGBColor[
             0.19047273002269705`, 0.31752929429541876`, 0.9341585122444157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 183}], {
             RGBColor[
             0.18716623928349274`, 0.31405396288489373`, 0.9339702124883327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 270}], {
             RGBColor[
             0.196796775846464, 0.3241762674238618, 0.9345186572984918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 357}], {
             RGBColor[
             0.18582607626581804`, 0.31264536658207454`, 0.9338938921870696]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 368}], {
             RGBColor[
             0.18474082389280244`, 0.3115046975290605, 0.9338320886699134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 132}], {
             RGBColor[
             0.1897759122485969, 0.31679689463404087`, 0.9341188295030303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 155}], {
             RGBColor[
             0.18628873221551898`, 0.3131316473192917, 0.933920239758967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 180}], {
             RGBColor[
             0.18755106204056693`, 0.3144584360017507, 0.9339921275750538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 249}], {
             RGBColor[
             0.18514988407402466`, 0.3119346457154385, 0.9338553840420838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 268}], {
             RGBColor[
             0.18716896902427724`, 0.3140568320155338, 0.9339703679430321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 279}], {
             RGBColor[
             0.19285735565451845`, 0.32003568702846064`, 0.9342943131464105]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 299}], {
             RGBColor[
             0.1875337477163088, 0.31444023754916384`, 0.9339911415499016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 300}], {
             RGBColor[
             0.19141939910096473`, 0.3185243035189643, 0.9342124236479517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 370}], {
             RGBColor[
             0.18611224246754757`, 0.3129461454040774, 0.9339101889289132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 123}], {
             RGBColor[
             0.8991328422336753, 0.5962300691178152, 0.23584910998017405`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 161}], {
             RGBColor[
             0.9173271064366133, 0.7028272968686928, 0.25196989849468676`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 193}], {
             RGBColor[
             0.8965180032601808, 0.866664933881647, 0.6335702357029284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 195}], {
             RGBColor[
             0.6898630728334411, 0.7009647207638414, 0.6155071113240207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 214}], {
             RGBColor[
             0.917014626987943, 0.7014084006737106, 0.2517091579831441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 253}], {
             RGBColor[
             0.8901501343784577, 0.5271850402949314, 0.22724725879350022`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 257}], {
             RGBColor[
             0.9622640683610495, 0.9182194829930534, 0.6096923191590835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 283}], {
             RGBColor[
             0.9435152073287729, 0.813763650039597, 0.2734092138294835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 312}], {
             RGBColor[
             0.7514622050621471, 0.7517529361696669, 0.6201411074573389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 332}], {
             RGBColor[
             0.8864563951040925, 0.498793341625289, 0.2237101298928862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 334}], {
             RGBColor[
             0.9576597296930937, 0.8685855926092536, 0.2913334520501617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 356}], {
             RGBColor[
             0.9502457162134885, 0.9092562156396481, 0.6300362544566458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 360}], {
             RGBColor[
             0.8089316906478522, 0.7980968050279984, 0.6248789386336926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 364}], {
             RGBColor[
             0.9382231077008898, 0.7927822385027005, 0.26915106624734497`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 366}], {
             RGBColor[
             0.9742039651565302, 0.9239012646538212, 0.3974339190185809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 380}], {
             RGBColor[
             0.8377450255090341, 0.8206060012110092, 0.627750782576732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 389}], {
             RGBColor[
             0.9741155744429982, 0.9237122058552483, 0.3878131353348738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 141}], {
             RGBColor[
             0.29789401265983945`, 0.4260884769462017, 0.9404351748499746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 179}], {
             RGBColor[
             0.23341719737643146`, 0.3626666523206874, 0.9366041361295647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 209}], {
             RGBColor[
             0.2525333735524159, 0.38275896551722044`, 0.9376927740829386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 286}], {
             RGBColor[
             0.28063230469456346`, 0.41113725310534854`, 0.9393352740823563]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 290}], {
             RGBColor[
             0.24877546734729164`, 0.3788091678306199, 0.9374787668838809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 304}], {
             RGBColor[
             0.26114585574207083`, 0.3918112303614577, 0.938183242202614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 338}], {
             RGBColor[
             0.22507866009155236`, 0.35390232094047974`, 0.9361292687669514]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 239}], {
             RGBColor[
             0.5328344578573876, 0.6316180426642315, 0.9563658268409162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 269}], {
             RGBColor[
             0.45596747114210545`, 0.5665010427125681, 0.9510641632117192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 309}], {
             RGBColor[
             0.6279491492944215, 0.7079937863162957, 0.9644297266188226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 323}], {
             RGBColor[
             0.4895767347577772, 0.5956116976057565, 0.9532057157698048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 362}], {
             RGBColor[
             0.6749012549506066, 0.7446731281041272, 0.9691094737182575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 365}], {
             RGBColor[
             0.4322742926857367, 0.5457268859697086, 0.94956369337159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 377}], {
             RGBColor[
             0.40661285819624315`, 0.5187550912923315, 0.9481023126401036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 385}], {
             RGBColor[
             0.776474593776608, 0.8214741220909348, 0.7960777027150834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 388}], {
             RGBColor[
             0.4146565458770389, 0.527209517044103, 0.9485603887539554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 395}], {
             RGBColor[
             0.49860624010091514`, 0.6034326012978481, 0.9537810678657916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 124}], {
             RGBColor[
             0.29203302591126107`, 0.41977282835890883`, 0.9401070895447208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[
             0.35660710592589273`, 0.4832968843838794, 0.9439436673476838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 150}], {
             RGBColor[
             0.29792702653421543`, 0.4259677967148573, 0.9404427441608055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 179}], {
             RGBColor[
             0.29213029064248475`, 0.4198750597583651, 0.9401126286272736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 196}], {
             RGBColor[
             0.6007859963931654, 0.6812853787799371, 0.9644958808837701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 206}], {
             RGBColor[
             0.39316789594043106`, 0.5149640030957358, 0.9462732885579729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 209}], {
             RGBColor[
             0.3112464668184692, 0.43996737295489813`, 0.9412012665806477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 286}], {
             RGBColor[
             0.33934539796061675`, 0.46834566054302623`, 0.9428437665800653]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 386}], {
             RGBColor[
             0.34968714140668505`, 0.4773031589248714, 0.9435027333276041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 128}], {
             RGBColor[
             0.2718458799395796, 0.4030576342137573, 0.9387925927513947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 130}], {
             RGBColor[
             0.2277266187202509, 0.3566854933495158, 0.936280066093552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 135}], {
             RGBColor[
             0.2875725376828968, 0.4171271414972289, 0.9397782828791128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 146}], {
             RGBColor[
             0.2194595639056427, 0.3479962945778132, 0.9358092695518716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 151}], {
             RGBColor[
             0.22370106658388367`, 0.35245438281944674`, 0.9360508168546565]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 213}], {
             RGBColor[
             0.2826015926364835, 0.4128215587449884, 0.9394615386563896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 227}], {
             RGBColor[
             0.25689083303762017`, 0.3873389317150586, 0.9379409249543373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 243}], {
             RGBColor[
             0.23559188807996673`, 0.3649523901334573, 0.9367279815479644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 267}], {
             RGBColor[
             0.21867692760035795`, 0.34717369419895117`, 0.9357646995720923]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 306}], {
             RGBColor[
             0.2310448890646134, 0.36017320587193224`, 0.9364690366807222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 311}], {
             RGBColor[
             0.22119300122602184`, 0.3498182471078057, 0.9359079862428765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 344}], {
             RGBColor[
             0.2156761634002051, 0.3440197007651513, 0.9355938104901265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 346}], {
             RGBColor[
             0.2216080062797242, 0.35025444373208703`, 0.9359316201667398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 350}], {
             RGBColor[
             0.2941675459212899, 0.42283940615857285`, 0.9401985109723265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 354}], {
             RGBColor[
             0.21794551615801888`, 0.3464049343988889, 0.9357230467724773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 140}], {
             RGBColor[
             0.409447183861318, 0.5290643040720063, 0.9473105903890827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 147}], {
             RGBColor[
             0.3298813986080268, 0.4544594666479659, 0.9424490293594527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 193}], {
             RGBColor[
             0.6252379224927019, 0.7026774950776031, 0.9659558403883122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 195}], {
             RGBColor[
             0.41858299206596217`, 0.5369772819597975, 0.9478927160094046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 241}], {
             RGBColor[
             0.34672955885014695`, 0.4721679512974918, 0.9434085071606221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 242}], {
             RGBColor[
             0.3764731339021319, 0.500503839321299, 0.9452095130834909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 255}], {
             RGBColor[
             0.39336824955180094`, 0.5151375393238391, 0.9462860549129236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 263}], {
             RGBColor[
             0.3571898835204337, 0.4831624157488532, 0.9440042071759314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 312}], {
             RGBColor[
             0.4801821242946682, 0.587765497365623, 0.9525267121427227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 331}], {
             RGBColor[
             0.3267582826576653, 0.45117687376714777`, 0.9422711725263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 356}], {
             RGBColor[
             0.6789656354460096, 0.7452687768356042, 0.9624218591420297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 359}], {
             RGBColor[
             0.3691186833876108, 0.4941337839310517, 0.9447408939999908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 360}], {
             RGBColor[
             0.5376516098803733, 0.6341093662239545, 0.9572645433190765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 380}], {
             RGBColor[
             0.5664649447415552, 0.6566185624069654, 0.9601363872621158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 389}], {
             RGBColor[
             0.7028354936755193, 0.7597247670512044, 0.7201987400202577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[
             0.2188856606362972, 0.3473930858541622, 0.9357765866096961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 202}], {
             RGBColor[
             0.2856578369982738, 0.41583248159385067`, 0.9396429608971655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 234}], {
             RGBColor[
             0.2453302072944222, 0.37518798107295015`, 0.9372825644206755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 289}], {
             RGBColor[
             0.3589692840265578, 0.4787637861846151, 0.9444710719407625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 298}], {
             RGBColor[
             0.2245949434093795, 0.353393904038107, 0.9361017218174963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 173}], {
             RGBColor[
             0.18447873947082444`, 0.3112292301844495, 0.9338171633498009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 338}], {
             RGBColor[
             0.19975108063826336`, 0.32728142907378543`, 0.9346869005858826]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 161}], {
             RGBColor[
             0.861352076814639, 0.4393326641242953, 0.20508206465224244`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 196}], {
             RGBColor[
             0.8436412079731275, 0.6056407490965849, 0.5869779142171753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 214}], {
             RGBColor[
             0.8610395973659686, 0.437913767929313, 0.20482132414069976`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 253}], {
             RGBColor[
             0.8341751047564834, 0.26369040755053386`, 0.1803594249510559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 283}], {
             RGBColor[
             0.8875401777067986, 0.5502690172951994, 0.2265213799870392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 332}], {
             RGBColor[
             0.8304813654821182, 0.2352987088808914, 0.17682229605044186`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 334}], {
             RGBColor[
             0.9016847000711192, 0.6050909598648562, 0.2444456182077174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 356}], {
             RGBColor[
             0.8942706865915142, 0.6457615828952505, 0.5831484206142015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 364}], {
             RGBColor[
             0.8822480780789155, 0.5292876057583029, 0.22226323240490067`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 366}], {
             RGBColor[
             0.9182289355345559, 0.6604066319094237, 0.35054608517613656`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 389}], {
             RGBColor[
             0.9181405448210238, 0.6602175731108506, 0.3409253014924295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 150}], {
             RGBColor[
             0.2325126629936997, 0.36171592933364405`, 0.9365526242346068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 152}], {
             RGBColor[
             0.2137312689052459, 0.34197549333751603`, 0.935483051625852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 156}], {
             RGBColor[
             0.21424517968646528`, 0.3425156461524031, 0.9355123180845796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 157}], {
             RGBColor[
             0.2367400113323198, 0.3661591404668991, 0.9367933654686897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 160}], {
             RGBColor[
             0.21095706740892387`, 0.3390596316703475, 0.9353250649546998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 167}], {
             RGBColor[
             0.23121257205082407`, 0.360349451322155, 0.9364785859787222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 179}], {
             RGBColor[
             0.22671592710196903`, 0.3556231923771518, 0.9362225087010749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 181}], {
             RGBColor[
             0.209370470104526, 0.33739201730734614`, 0.9352347105853747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 238}], {
             RGBColor[
             0.21375043106969976`, 0.3419956339873084, 0.9354841428827698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 245}], {
             RGBColor[
             0.21075638483913717`, 0.33884870156549185`, 0.9353136363792337]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 386}], {
             RGBColor[
             0.28427277786616933`, 0.41305129154365816`, 0.9396126134014054]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 184}], {
             RGBColor[
             0.20307558723579205`, 0.3307756962936808, 0.934876226318445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 185}], {
             RGBColor[
             0.1925739180479394, 0.31973777613296384`, 0.9342781717940241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 190}], {
             RGBColor[
             0.20237543357367466`, 0.3300397904024893, 0.934836353603172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 226}], {
             RGBColor[
             0.1922514050569324, 0.3193987945309108, 0.9342598051563016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 252}], {
             RGBColor[
             0.19926974690677848`, 0.32677551680367367`, 0.934659489341944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 274}], {
             RGBColor[
             0.19786901158433057`, 0.32530325516803194`, 0.9345797195375327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 288}], {
             RGBColor[
             0.2031660717843796, 0.3308708012912981, 0.9348813792796271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 318}], {
             RGBColor[
             0.20302734583193666`, 0.33072499151954715`, 0.9348734790418622]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 176}], {
             RGBColor[
             0.18438193895865332`, 0.3111274867086507, 0.9338116507038363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 205}], {
             RGBColor[
             0.18385657240612066`, 0.31057529315177557`, 0.9337817318558796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 298}], {
             RGBColor[
             0.194012535572622, 0.32124985436502457`, 0.9343600989338109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 320}], {
             RGBColor[
             0.18313368370358218`, 0.3098154912916167, 0.9337405644136882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 347}], {
             RGBColor[
             0.18344187738111917`, 0.31013942238731573`, 0.9337581155876922]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 373}], {
             RGBColor[
             0.19027225530167013`, 0.317318582652788, 0.934147095505629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 137}], {
             RGBColor[
             0.31600670483300364`, 0.4466421785419929, 0.9414111535240912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 138}], {
             RGBColor[
             0.31413697275722113`, 0.44467697158248487`, 0.9413046750483962]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 193}], {
             RGBColor[
             0.5886484429999097, 0.6709855269816585, 0.9636243911098379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 210}], {
             RGBColor[
             0.29252473138981117`, 0.4219611356100898, 0.9400738898749681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 242}], {
             RGBColor[
             0.33988365440933965`, 0.4688118712253543, 0.9428780638050165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 255}], {
             RGBColor[
             0.35677877005900877`, 0.4834455712278943, 0.9439546056344492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 258}], {
             RGBColor[
             0.2885106861095953, 0.4177421195154126, 0.9398452959345076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 264}], {
             RGBColor[
             0.2996738393944105, 0.42947530140255136`, 0.9404810209996725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 312}], {
             RGBColor[
             0.44359264480187605`, 0.5560735292696781, 0.9501952628642483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 328}], {
             RGBColor[
             0.2853602010040631, 0.41443075991720546`, 0.9396658804684725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 331}], {
             RGBColor[
             0.29016880316487315`, 0.419484905671203, 0.9399397232478413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 380}], {
             RGBColor[
             0.529875465248763, 0.6249265943110206, 0.9578049379836415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 394}], {
             RGBColor[
             0.348496932711213, 0.47627225997448197`, 0.9434268942819889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 130}], {
             RGBColor[
             0.2597826750311079, 0.39037844100358665`, 0.9381056110777697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 135}], {
             RGBColor[
             0.31962859399375376`, 0.45082008915129973`, 0.9416038278633306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 139}], {
             RGBColor[
             0.3054227451460619, 0.43834904844198347`, 0.9407047455523833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 151}], {
             RGBColor[
             0.2557571228947407, 0.38614733047351757`, 0.9378763618388744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 213}], {
             RGBColor[
             0.3146576489473405, 0.4465145063990592, 0.9412870836406073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 215}], {
             RGBColor[
             0.5049864538136, 0.6035289290681363, 0.9559781758101122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 224}], {
             RGBColor[
             0.40082474260241224`, 0.5199417456186857, 0.9471108972900512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 227}], {
             RGBColor[
             0.28894688934847723`, 0.42103187936912945`, 0.9397664699385552]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 243}], {
             RGBColor[
             0.26764794439082373`, 0.39864533778752814`, 0.9385535265321823]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 259}], {
             RGBColor[
             0.599663278641086, 0.6781009426487141, 0.9652528657581285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 306}], {
             RGBColor[
             0.2631009453754704, 0.39386615352600307`, 0.9382945816649401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 350}], {
             RGBColor[
             0.32622360223214686`, 0.4565323538126437, 0.9420240559565443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 383}], {
             RGBColor[
             0.3311097462205182, 0.46076448615063337`, 0.9423353967308358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 131}], {
             RGBColor[
             0.8167235345760251, 0.5021703426652091, 0.5741281307411844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 253}], {
             RGBColor[
             0.822264279381292, 0.17213858435985327`, 0.16895360512041946`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 271}], {
             RGBColor[
             0.8196694573268939, 0.15219364499147486`, 0.1664688005906955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 287}], {
             RGBColor[
             0.8183275809306592, 0.1418793949960282, 0.16518381823822845`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 303}], {
             RGBColor[
             0.8566331099862248, 0.3804373908932912, 0.19967730788162147`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 333}], {
             RGBColor[
             0.8865563472760825, 0.5573394921368233, 0.5646390445032476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 337}], {
             RGBColor[
             0.8881576917970897, 0.5585337722586294, 0.5619283859267235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 353}], {
             RGBColor[
             0.9062979809873158, 0.5688117544551025, 0.33694932919085196`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 364}], {
             RGBColor[
             0.8703372527037241, 0.4377357825676223, 0.21085741257426427`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 391}], {
             RGBColor[
             0.8197851875316053, 0.15308319805818565`, 0.1665796239654257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 135}], {
             RGBColor[
             0.27550933277442513`, 0.40444794828705827`, 0.9390913012054878]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 146}], {
             RGBColor[
             0.20739635899717102`, 0.3353171013676426, 0.9351222878782466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 151}], {
             RGBColor[
             0.211637861675412, 0.3397751896092761, 0.9353638351810314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 158}], {
             RGBColor[
             0.20340188077088672`, 0.3311186514872704, 0.9348948082525605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 227}], {
             RGBColor[
             0.24482762812914852`, 0.374659738504888, 0.9372539432807123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 243}], {
             RGBColor[
             0.22352868317149505`, 0.3522731969232867, 0.9360409998743393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 267}], {
             RGBColor[
             0.20661372269188627`, 0.33449450098878053`, 0.9350777178984673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 275}], {
             RGBColor[
             0.2049038205781411, 0.33269728545317867`, 0.934980341502663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 306}], {
             RGBColor[
             0.21898168415614172`, 0.3474940126617616, 0.9357820550070972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 311}], {
             RGBColor[
             0.20912979631755016`, 0.33713905389763504`, 0.9352210045692514]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 317}], {
             RGBColor[
             0.20208377375464914`, 0.3297332374403929, 0.9348197440079504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 344}], {
             RGBColor[
             0.20361295849173341`, 0.3313405075549807, 0.9349068288165013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 346}], {
             RGBColor[
             0.20954480137125253`, 0.3375752505219164, 0.9352446384931148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 354}], {
             RGBColor[
             0.2058823112495472, 0.3337257411887183, 0.9350360650988523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 142}], {
             RGBColor[
             0.6441352636384634, 0.7193460306737178, 0.9669266768382974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 201}], {
             RGBColor[
             0.7399124857733206, 0.7967445245200704, 0.9747112197727283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 273}], {
             RGBColor[
             0.6690783888345512, 0.7395959833828867, 0.9688902910234116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 281}], {
             RGBColor[
             0.6064310569728814, 0.687254440774864, 0.9643678385927457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 293}], {
             RGBColor[
             0.5641203291112874, 0.6506070149001673, 0.9616718364273125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 303}], {
             RGBColor[
             0.8540204827009316, 0.7329759435664439, 0.607655802146349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 391}], {
             RGBColor[
             0.817172560246312, 0.5056217507313383, 0.5745581182301532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 394}], {
             RGBColor[
             0.585868010689025, 0.6694437636125451, 0.9630575794667262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 149}], {
             RGBColor[
             0.20160011613108555`, 0.32922488261236305`, 0.9347922004217959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 155}], {
             RGBColor[
             0.18938684794258642`, 0.3163879633803221, 0.934096672866372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 180}], {
             RGBColor[
             0.1906491777676344, 0.3177147520627811, 0.9341685606824588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 249}], {
             RGBColor[
             0.18824799980109214`, 0.3151909617764689, 0.9340318171494888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 268}], {
             RGBColor[
             0.19026708475134468`, 0.3173131480765642, 0.9341468010504371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 279}], {
             RGBColor[
             0.1959554713815859, 0.323292003089491, 0.9344707462538155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 299}], {
             RGBColor[
             0.19063186344337624`, 0.3176965536101942, 0.9341675746573066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 300}], {
             RGBColor[
             0.1945175148280322, 0.3217806195799947, 0.9343888567553567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 370}], {
             RGBColor[
             0.189210358194615, 0.3162024614651078, 0.9340866220363182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 178}], {
             RGBColor[
             0.18320632976714918`, 0.309891846910452, 0.9337447014995381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 200}], {
             RGBColor[
             0.18872606349581567`, 0.31569343703061226`, 0.9340590421696713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 278}], {
             RGBColor[
             0.18574944160901402`, 0.31256481869885566`, 0.9338895279567354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 296}], {
             RGBColor[
             0.18124069831826523`, 0.30782584362944293`, 0.9336327616964153]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 320}], {
             RGBColor[
             0.18355649439985816`, 0.3102598921411492, 0.9337646428573487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 330}], {
             RGBColor[
             0.1860526851696524, 0.3128835469078388, 0.9339067972289052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 347}], {
             RGBColor[
             0.18386468807739512`, 0.3105838232368483, 0.9337821940313528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 367}], {
             RGBColor[
             0.18474901765317286`, 0.31151330969072427`, 0.9338325552924449]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 398}], {
             RGBColor[
             0.18210607446438823`, 0.30873540882703493`, 0.9336820435877278]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 163}], {
             RGBColor[
             0.17908461226291875`, 0.3055596604815222, 0.9335099757852068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 171}], {
             RGBColor[
             0.18358417843459812`, 0.31028898981693004`, 0.9337662194221723]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 240}], {
             RGBColor[
             0.17922390736570504`, 0.3057060684663703, 0.9335179084352418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 272}], {
             RGBColor[
             0.18788317693480855`, 0.3148075098128992, 0.9340110410269609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 342}], {
             RGBColor[
             0.18275455563161122`, 0.309417003649867, 0.9337189736308591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 374}], {
             RGBColor[
             0.18137577945827954`, 0.307967822472237, 0.9336404543675045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 213}], {
             RGBColor[
             0.33038430669065766`, 0.46058401368253077`, 0.9422727737683254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 215}], {
             RGBColor[
             0.5207131115569171, 0.6175984363516078, 0.9569638659378303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 224}], {
             RGBColor[
             0.41655140034572946`, 0.5340112529021572, 0.9480965874177693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 227}], {
             RGBColor[
             0.3046735470917944, 0.4351013866526011, 0.9407521600662733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 243}], {
             RGBColor[
             0.2833746021341409, 0.41271484507099976`, 0.9395392166599004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 259}], {
             RGBColor[
             0.6153899363844033, 0.6921704499321857, 0.9662385558858466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 350}], {
             RGBColor[
             0.3419502599754641, 0.47060186109611535`, 0.9430097460842624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 363}], {
             RGBColor[
             0.3549405295448861, 0.4818533796872159, 0.9438374745743816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 383}], {
             RGBColor[
             0.3468364039638354, 0.47483399343410504`, 0.9433210868585539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 393}], {
             RGBColor[
             0.5286635054610748, 0.6238093444947674, 0.9577562869015417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 149}], {
             RGBColor[
             0.19648120536399588`, 0.3238445828384636, 0.9345006860263599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 155}], {
             RGBColor[
             0.18426793717549678`, 0.3110076636064226, 0.933805158470936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 268}], {
             RGBColor[
             0.18514817398425504`, 0.3119328483026647, 0.9338552866550012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 279}], {
             RGBColor[
             0.19083656061449622`, 0.3179117033155916, 0.9341792318583795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 299}], {
             RGBColor[
             0.1855129526762866, 0.3123162538362948, 0.9338760602618706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 300}], {
             RGBColor[
             0.18939860406094253`, 0.3164003198060953, 0.9340973423599207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 371}], {
             RGBColor[
             0.1813347042579621, 0.3079246498323852, 0.9336381151956117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 138}], {
             RGBColor[
             0.29077492625511725`, 0.4229532620622423, 0.93987057393605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 164}], {
             RGBColor[
             0.2538187120761361, 0.3841099378008197, 0.9377659722103766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 210}], {
             RGBColor[
             0.2691626848877073, 0.40023742608984725`, 0.9386397887626219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 230}], {
             RGBColor[
             0.2568850160495337, 0.38733281769176137`, 0.9379405936854713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 242}], {
             RGBColor[
             0.31652160790723577`, 0.4470881617051118, 0.9414439626926704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 258}], {
             RGBColor[
             0.2651486396074914, 0.3960184099951701, 0.9384111948221615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 264}], {
             RGBColor[
             0.27631179289230656`, 0.4077515918823088, 0.9390469198873264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 328}], {
             RGBColor[
             0.2619981545019592, 0.39270705039696285`, 0.9382317793561266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 394}], {
             RGBColor[
             0.32513488620910913`, 0.45454855045423936`, 0.9419927931696428]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 149}], {
             RGBColor[
             0.2496156992329207, 0.3796923048161946, 0.9375266168467558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 164}], {
             RGBColor[
             0.2519489800003536, 0.38214473084131173`, 0.9376594937346815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 210}], {
             RGBColor[
             0.2672929528119248, 0.3982722191303392, 0.9385333102869269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 230}], {
             RGBColor[
             0.2550152839737512, 0.38536761073225334`, 0.9378341152097762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 242}], {
             RGBColor[
             0.31465187583145326`, 0.4451229547456037, 0.9413374842169753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 258}], {
             RGBColor[
             0.26327890753170885`, 0.39405320303566205`, 0.9383047163464664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 264}], {
             RGBColor[
             0.27444206081652406`, 0.4057863849228008, 0.9389404414116314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 281}], {
             RGBColor[
             0.3438282004171828, 0.4703940206570502, 0.9431965738199672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 328}], {
             RGBColor[
             0.2601284224261766, 0.3907418434374549, 0.9381253008804314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 394}], {
             RGBColor[
             0.32326515413332657`, 0.4525833434947314, 0.9418863146939478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 186}], {
             RGBColor[
             0.2567623305791477, 0.38720386748367763`, 0.9379336069294297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 213}], {
             RGBColor[
             0.3161784578429658, 0.4481129729732145, 0.941373691457378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 215}], {
             RGBColor[
             0.5065072627092252, 0.6051273956422916, 0.956064783626883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 306}], {
             RGBColor[
             0.2646217542710957, 0.39546462010015837`, 0.9383811894817108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 308}], {
             RGBColor[
             0.25989565930435055`, 0.3904971946383813, 0.9381120453649856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 345}], {
             RGBColor[
             0.5675136417908162, 0.652851509744995, 0.962127956401694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 350}], {
             RGBColor[
             0.3277444111277722, 0.4581308203867991, 0.942110663773315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 378}], {
             RGBColor[
             0.27359029407982893`, 0.40489112407740385`, 0.9388919345560525]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 147}], {
             RGBColor[
             0.32678087214865287`, 0.45177394646584723`, 0.9422514665551494]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 193}], {
             RGBColor[
             0.6221373960333281, 0.6999919748954846, 0.9657582775840088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 195}], {
             RGBColor[
             0.4154824656065883, 0.5342917617776789, 0.9476951532051012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 241}], {
             RGBColor[
             0.343629032390773, 0.46948243111537313`, 0.9432109443563187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 242}], {
             RGBColor[
             0.3733726074427579, 0.4978183191391804, 0.9450119502791875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 255}], {
             RGBColor[
             0.390267723092427, 0.5124520191417203, 0.9460884921086202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 263}], {
             RGBColor[
             0.35408935706105976`, 0.48047689556673456`, 0.943806644371628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 312}], {
             RGBColor[
             0.4770815978352943, 0.5850799771835042, 0.9523291493384193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 331}], {
             RGBColor[
             0.3236577561982914, 0.4484913535850291, 0.9420736097220124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 356}], {
             RGBColor[
             0.6758651089866358, 0.7425832566534856, 0.9622242963377263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 359}], {
             RGBColor[
             0.36601815692823686`, 0.491448263748933, 0.9445433311956875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 360}], {
             RGBColor[
             0.5345510834209994, 0.6314238460418358, 0.9570669805147731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 380}], {
             RGBColor[
             0.5633644182821813, 0.6539330422248467, 0.9599388244578124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 389}], {
             RGBColor[
             0.6997349672161455, 0.7570392468690857, 0.7200011772159544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 179}], {
             RGBColor[
             0.2912900071166007, 0.41914724840212236`, 0.9400590865040379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 196}], {
             RGBColor[
             0.5999457128672814, 0.6805575674236943, 0.9644423387605343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 209}], {
             RGBColor[
             0.3104061832925851, 0.4392395615986554, 0.9411477244574119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 286}], {
             RGBColor[
             0.3385051144347327, 0.4676178491867835, 0.9427902244568296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 290}], {
             RGBColor[
             0.3066482770874609, 0.4352897639120549, 0.9409337172583541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 304}], {
             RGBColor[
             0.31901866548224, 0.4482918264428926, 0.9416381925770871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 386}], {
             RGBColor[
             0.348846857880801, 0.4765753475686286, 0.9434491912043683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.37498442055197767`, 0.49560326154572176`, 0.9453825139194686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 201}], {
             RGBColor[
             0.5699368421210522, 0.6613816598554264, 0.9595312716051138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 273}], {
             RGBColor[
             0.4991027451822828, 0.6042331187182427, 0.9537103428557971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 281}], {
             RGBColor[
             0.436455413320613, 0.55189157611022, 0.9491878904251312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 293}], {
             RGBColor[
             0.3941446854590191, 0.5152441502355233, 0.946491888259698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 394}], {
             RGBColor[
             0.4158923670367568, 0.5340808989479011, 0.9478776312991117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 151}], {
             RGBColor[
             0.2032578843654731, 0.3309673021352812, 0.934886607870296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 158}], {
             RGBColor[
             0.1950219034609478, 0.3223107640132754, 0.9344175809418251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 171}], {
             RGBColor[
             0.19347840745274208`, 0.320688451845352, 0.9343296811275554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 186}], {
             RGBColor[
             0.20274228315425485`, 0.3304253725712859, 0.9348572451440806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 272}], {
             RGBColor[
             0.19777740595295248`, 0.3252069718413211, 0.9345745027323441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 306}], {
             RGBColor[
             0.21060170684620283`, 0.33868612518776664`, 0.9353048276963617]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 308}], {
             RGBColor[
             0.2058756118794577, 0.33371869972598955`, 0.9350356835796365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 342}], {
             RGBColor[
             0.19264878464975516`, 0.3198164656782889, 0.9342824353362423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 348}], {
             RGBColor[
             0.20000377872339242`, 0.3275470307832401, 0.9347012913679973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 354}], {
             RGBColor[
             0.1975023339396083, 0.32491785371472337`, 0.9345588377881168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 374}], {
             RGBColor[
             0.1912700084764235, 0.3183672845006589, 0.9342039160728877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 378}], {
             RGBColor[
             0.21957024665493602`, 0.3481126291650121, 0.9358155727707034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 148}], {
             RGBColor[
             0.41890511783186646`, 0.5289568419765102, 0.9490497655266936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 169}], {
             RGBColor[
             0.5192579762174159, 0.6205960432553745, 0.9552970364739267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 218}], {
             RGBColor[
             0.5707667888209911, 0.662413217772521, 0.9593519988850778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 222}], {
             RGBColor[
             0.7661723613566251, 0.8169857716290115, 0.9639290713689532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 276}], {
             RGBColor[
             0.48015124453344243`, 0.5868307576532874, 0.952775625742377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 282}], {
             RGBColor[
             0.44814038646858245`, 0.5591045613100133, 0.9507359221725744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 305}], {
             RGBColor[
             0.4396583364184836, 0.550769790541102, 0.9502316306235659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 339}], {
             RGBColor[
             0.48160738498318656`, 0.5880919933231088, 0.9528684097242202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 361}], {
             RGBColor[
             0.4954156444114053, 0.6000520136165334, 0.9537482598048219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 382}], {
             RGBColor[
             0.451676599366216, 0.5621674511867154, 0.9509612465314614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 384}], {
             RGBColor[
             0.757420984754537, 0.7226612405223014, 0.6127983851533676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 165}], {
             RGBColor[
             0.23770682741222313`, 0.3671753254665574, 0.9368484242141641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 170}], {
             RGBColor[
             0.24268853638713495`, 0.37241141745778183`, 0.9371321251705074]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 182}], {
             RGBColor[
             0.24585035887698375`, 0.3757346933657375, 0.937312186283807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 192}], {
             RGBColor[
             0.25406976709764434`, 0.3843738125462326, 0.9377802694224489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 208}], {
             RGBColor[
             0.2721455459278671, 0.4033726021673685, 0.9388096582861116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 221}], {
             RGBColor[
             0.3098924284635012, 0.43739177601044266`, 0.941166351723109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 225}], {
             RGBColor[
             0.22917757181567264`, 0.3582105370485437, 0.9363626957258434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 235}], {
             RGBColor[
             0.22156110310920424`, 0.35020514552603776`, 0.9359289491005658]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 335}], {
             RGBColor[
             0.2240686969525251, 0.3528407856460005, 0.9360717528602902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 349}], {
             RGBColor[
             0.2241439081408365, 0.35291983737358057`, 0.9360760360261996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 351}], {
             RGBColor[
             0.2797139568415439, 0.4112527007055903, 0.9392434061971325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 355}], {
             RGBColor[
             0.22900678342998865`, 0.3580310276265808, 0.9363529695799375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 395}], {
             RGBColor[
             0.3442769835307749, 0.46717394939172724`, 0.9433573051669275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 151}], {
             RGBColor[
             0.20337080686080378`, 0.3310859908375735, 0.9348930386393511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 158}], {
             RGBColor[
             0.1951348259562785, 0.3224294527155677, 0.9344240117108803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 227}], {
             RGBColor[
             0.2365605733145403, 0.3659705397331854, 0.936783146739032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 243}], {
             RGBColor[
             0.21526162835688684`, 0.343583998151584, 0.9355702033326591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 267}], {
             RGBColor[
             0.19834666787727806`, 0.32580530221707793`, 0.9346069213567869]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 275}], {
             RGBColor[
             0.1966367657635329, 0.324008086681476, 0.9345095449609826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 306}], {
             RGBColor[
             0.2107146293415335, 0.33880481389005895`, 0.9353112584654169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 311}], {
             RGBColor[
             0.20086274150294195`, 0.3284498551259324, 0.9347502080275711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 317}], {
             RGBColor[
             0.19381671894004093`, 0.32104403866869025`, 0.9343489474662702]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 344}], {
             RGBColor[
             0.1953459036771252, 0.3226513087832781, 0.9344360322748211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 346}], {
             RGBColor[
             0.20127774655664432`, 0.3288860517502138, 0.9347738419514344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 354}], {
             RGBColor[
             0.197615256434939, 0.32503654241701563`, 0.9345652685571719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 195}], {
             RGBColor[
             0.3359166803532971, 0.45968692435363845`, 0.9428335921754714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 217}], {
             RGBColor[
             0.2277310230294914, 0.3566901225577769, 0.9362803169124476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 231}], {
             RGBColor[
             0.2192108871052112, 0.34773491949353985`, 0.9357951077759714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 241}], {
             RGBColor[
             0.2640632471374818, 0.3948775936913327, 0.9383493833266887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 242}], {
             RGBColor[
             0.29380682218946674`, 0.42321348171513995`, 0.9401503892495575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 255}], {
             RGBColor[
             0.3107019378391358, 0.4378471817176799, 0.9412269310789902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 312}], {
             RGBColor[
             0.3975158125820031, 0.5104751397594638, 0.9474675883087893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 331}], {
             RGBColor[
             0.2440919709450002, 0.37388651616098867`, 0.9372120486923824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 359}], {
             RGBColor[
             0.28645237167494564`, 0.4168434263248926, 0.9396817701660576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 392}], {
             RGBColor[
             0.2251386082236323, 0.35396533022822685`, 0.9361326827243879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 218}], {
             RGBColor[
             0.40841467546891774`, 0.5204402282772255, 0.9482239194761258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 228}], {
             RGBColor[
             0.2402804897849437, 0.36988040779990605`, 0.9369949904788982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 276}], {
             RGBColor[
             0.31779913118136904`, 0.44485776815799194`, 0.9416475463334251]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.285788273116509, 0.4171315718147177, 0.9396078427636225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 301}], {
             RGBColor[
             0.25321055434935075`, 0.3834707254705414, 0.9377313385275249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 305}], {
             RGBColor[
             0.2773062230664102, 0.4087968010458064, 0.939103551214614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 313}], {
             RGBColor[
             0.27058528986872044`, 0.4017326741232574, 0.9387208040117352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 339}], {
             RGBColor[
             0.3192552716311131, 0.4461190038278132, 0.9417403303152683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 340}], {
             RGBColor[
             0.263972502592159, 0.39478221542066183`, 0.9383442155590771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 361}], {
             RGBColor[
             0.33306353105933184`, 0.4580790241212378, 0.94262018039587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 382}], {
             RGBColor[
             0.2893244860141426, 0.42019446169141983`, 0.9398331671225094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 155}], {
             RGBColor[
             0.19811293609800762`, 0.3255596352976139, 0.9345936106777326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 164}], {
             RGBColor[
             0.21265948505393958`, 0.340848980554772, 0.9354220151210823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 210}], {
             RGBColor[
             0.22800345786551077`, 0.3569764688437995, 0.9362958316733276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 230}], {
             RGBColor[
             0.21572578902733716`, 0.34407186044571364`, 0.935596636596177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 258}], {
             RGBColor[
             0.22398941258529487`, 0.35275745274912235`, 0.9360672377328672]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 264}], {
             RGBColor[
             0.23515256587011008`, 0.3644906346362611, 0.9367029627980321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 268}], {
             RGBColor[
             0.19899317290676588`, 0.326484819993856, 0.9346437388617977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 279}], {
             RGBColor[
             0.20468155953700706`, 0.33246367500678287`, 0.9349676840651762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 299}], {
             RGBColor[
             0.19935795159879743`, 0.32686822552748607`, 0.9346645124686672]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 300}], {
             RGBColor[
             0.20324360298345337`, 0.33095229149728655`, 0.9348857945667173]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 328}], {
             RGBColor[
             0.22083892747976266`, 0.3494460931509151, 0.9358878222668322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 152}], {
             RGBColor[
             0.21962526952820027`, 0.3481704616934645, 0.9358187062419367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 156}], {
             RGBColor[
             0.22013918030941965`, 0.34871061450835156`, 0.9358479727006643]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 157}], {
             RGBColor[
             0.24263401195527415`, 0.3723541088228476, 0.9371290200847746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 160}], {
             RGBColor[
             0.2168510680318782, 0.345254600026296, 0.9356607195707846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 167}], {
             RGBColor[
             0.2371065726737784, 0.3665444196781035, 0.936814240594807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 179}], {
             RGBColor[
             0.23260992772492337`, 0.36181816073310025`, 0.9365581633171598]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 181}], {
             RGBColor[
             0.21526447072748034`, 0.3435869856632946, 0.9355703652014595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 206}], {
             RGBColor[
             0.33364753302286965`, 0.45690710407047097`, 0.9427188232478589]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 211}], {
             RGBColor[
             0.23544785722092995`, 0.3648010045685258, 0.9367197792036168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 238}], {
             RGBColor[
             0.21964443169265407`, 0.3481906023432569, 0.9358197974988545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 386}], {
             RGBColor[
             0.29016677848912364`, 0.4192462598996066, 0.9399482680174902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 158}], {
             RGBColor[
             0.19937632863451948`, 0.3268875409572013, 0.9346655590136652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 186}], {
             RGBColor[
             0.20709670832782653`, 0.33500214951521173`, 0.9351052232159208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 227}], {
             RGBColor[
             0.2408020759927813, 0.3704286279748189, 0.937024694041817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 267}], {
             RGBColor[
             0.20258817055551906`, 0.33026339045871145`, 0.9348484686595718]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 306}], {
             RGBColor[
             0.21495613201977448`, 0.3432629021316925, 0.9355528057682019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 308}], {
             RGBColor[
             0.2102300370530294, 0.33829547666991544`, 0.9352836616514766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 311}], {
             RGBColor[
             0.20510424418118295`, 0.33290794336756596`, 0.934991755330356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 317}], {
             RGBColor[
             0.1980582216182819, 0.3255021269103238, 0.9345904947690551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 344}], {
             RGBColor[
             0.1995874063553662, 0.3271093970249116, 0.9346775795776059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 346}], {
             RGBColor[
             0.2055192492348853, 0.3333441399918473, 0.9350153892542195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 348}], {
             RGBColor[
             0.20435820389696413`, 0.332123807727166, 0.9349492694398375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 354}], {
             RGBColor[
             0.20185675911317996`, 0.3294946306586492, 0.934806815859957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 156}], {
             RGBColor[
             0.20135778622096587`, 0.32897017851222354`, 0.9347784000919095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 157}], {
             RGBColor[
             0.22385261786682037`, 0.3526136728267195, 0.9360594474760198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 160}], {
             RGBColor[
             0.19806967394342445`, 0.325514164030168, 0.9345911469620297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 179}], {
             RGBColor[
             0.2138285336364696, 0.3420777247369723, 0.935488590708405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 181}], {
             RGBColor[
             0.1964830766390266, 0.32384654966716653`, 0.9345007925927047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 238}], {
             RGBColor[
             0.20086303760420032`, 0.32845016634712887`, 0.9347502248900996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 245}], {
             RGBColor[
             0.19786899137363773`, 0.3253032339253123, 0.9345797183865636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 168}], {
             RGBColor[
             0.20180786245057253`, 0.3294432371660213, 0.9348040312673576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 175}], {
             RGBColor[
             0.19789401206423968`, 0.32532953225753836`, 0.9345811432778787]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 211}], {
             RGBColor[
             0.21907020233692062`, 0.34758705088213704`, 0.9357870959865418]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 216}], {
             RGBColor[
             0.21073387590110806`, 0.33882504324447416`, 0.935312354528512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 229}], {
             RGBColor[
             0.2017865527982215, 0.3294208393702904, 0.934802817714181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 294}], {
             RGBColor[
             0.20769214048678164`, 0.33562798646685293`, 0.9351391321965103]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 329}], {
             RGBColor[
             0.23399514583317907`, 0.36327411279277777`, 0.9366370494391784]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 341}], {
             RGBColor[
             0.22749742981872606`, 0.3564446012825976, 0.9362670141246647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 343}], {
             RGBColor[
             0.20318561149837056`, 0.330891338769592, 0.9348824920374326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 358}], {
             RGBColor[
             0.24162422522743635`, 0.37129275894771363`, 0.9370715142244698]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 379}], {
             RGBColor[
             0.19405975897206282`, 0.32129948915197337`, 0.9343627882365483]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 207}], {
             RGBColor[
             0.18894498275511917`, 0.315923535052423, 0.9340715092976267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 231}], {
             RGBColor[
             0.18878970308862236`, 0.3157603262776354, 0.9340626663503354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 369}], {
             RGBColor[
             0.183389073095449, 0.31008392173509136`, 0.9337551084617403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 372}], {
             RGBColor[
             0.18315975702077553`, 0.3098428960011307, 0.9337420492505304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 387}], {
             RGBColor[
             0.18595738695423472`, 0.312783382441179, 0.9339013701365182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 392}], {
             RGBColor[
             0.19471742420704347`, 0.3219907370123223, 0.934400241298752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 249}], {
             RGBColor[
             0.18476081976801417`, 0.3115257144617197, 0.9338332274054255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 268}], {
             RGBColor[
             0.18677990471826675`, 0.31364790076181503`, 0.9339482113063738]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 279}], {
             RGBColor[
             0.19246829134850796`, 0.31962675577474187`, 0.9342721565097523]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.1871446834102983, 0.31403130629544507`, 0.9339689849132433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 300}], {
             RGBColor[
             0.19103033479495424`, 0.31811537226524556`, 0.9341902670112934]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 370}], {
             RGBColor[
             0.18572317816153708`, 0.3125372141503586, 0.9338880322922549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 371}], {
             RGBColor[
             0.18296643499197385`, 0.3096397022915355, 0.9337310398469844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 160}], {
             RGBColor[
             0.19858358472464382`, 0.32605431684505504`, 0.9346204134207573]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.21434244441768896`, 0.34261787755185935`, 0.9355178571671325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 181}], {
             RGBColor[
             0.19699698742024596`, 0.3243867024820536, 0.9345300590514323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 245}], {
             RGBColor[
             0.1983829021548571, 0.32584338674019936`, 0.9346089848452912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 352}], {
             RGBColor[
             0.19412861826228733`, 0.32137186463193046`, 0.9343667096712585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 396}], {
             RGBColor[
             0.19313485512094197`, 0.32032735656215416`, 0.9343101163304997]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 160}], {
             RGBColor[
             0.22107841637049833`, 0.349697811159551, 0.9359014608048675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 167}], {
             RGBColor[
             0.24133392101239853`, 0.37098763081135855`, 0.93705498182889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 168}], {
             RGBColor[
             0.222412865673202, 0.35110040198566517`, 0.9359774557185156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 203}], {
             RGBColor[
             0.2784354581733116, 0.40986687435040126`, 0.9391721369966093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 206}], {
             RGBColor[
             0.3378748813614898, 0.46135031520372605`, 0.942959564481942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 211}], {
             RGBColor[
             0.23967520555955008`, 0.36924421570178084`, 0.9369605204376998]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 238}], {
             RGBColor[
             0.22387178003127423`, 0.3526338134765119, 0.9360605387329375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 341}], {
             RGBColor[
             0.24810243304135554`, 0.37810176610224144`, 0.9374404385758228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 358}], {
             RGBColor[
             0.2622292284500658, 0.3929499237673575, 0.938244938675628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 386}], {
             RGBColor[
             0.2943941268277438, 0.42368947103286164`, 0.9401890092515732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 267}], {
             RGBColor[
             0.19435218965099377`, 0.3216068523367057, 0.934379441731101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 306}], {
             RGBColor[
             0.20672015111524922`, 0.33460636400968674`, 0.935083778839731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 308}], {
             RGBColor[
             0.20199405614850408`, 0.32963893854790965`, 0.9348146347230057]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 311}], {
             RGBColor[
             0.19686826327665763`, 0.3242514052455602, 0.9345227284018851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 317}], {
             RGBColor[
             0.18982224071375664`, 0.31684558878831803`, 0.9341214678405843]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 344}], {
             RGBColor[
             0.19135142545084088`, 0.31845285890290587`, 0.934208552649135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 346}], {
             RGBColor[
             0.19728326833036003`, 0.3246876018698416, 0.9345463623257486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 348}], {
             RGBColor[
             0.1961222229924388, 0.3234672696051602, 0.9344802425113666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 354}], {
             RGBColor[
             0.1936207782086547, 0.3208380925366434, 0.9343377889314861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 374}], {
             RGBColor[
             0.1873884527454699, 0.3142875233225789, 0.9339828672162569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 250}], {
             RGBColor[
             0.18793077615893167`, 0.3148575396154177, 0.934013751732358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 265}], {
             RGBColor[
             0.19056897353088317`, 0.3176304523247132, 0.9341639931698273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 321}], {
             RGBColor[
             0.1833474210515813, 0.31004014279609426`, 0.9337527364394607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 375}], {
             RGBColor[
             0.19246854917072223`, 0.3196270267622359, 0.9342721711923458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 381}], {
             RGBColor[
             0.18574510039169012`, 0.3125602558041992, 0.9338892807308311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[
             0.19370887514270452`, 0.320930687999998, 0.9343428059215524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 238}], {
             RGBColor[
             0.19808883610787825`, 0.32553430467996036`, 0.9345922382189475]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 245}], {
             RGBColor[
             0.19509478987731566`, 0.3223873722581438, 0.9344217317154114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 196}], {
             RGBColor[
             0.8618354721760655, 0.7122379768474625, 0.603098702731688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 214}], {
             RGBColor[
             0.8792338615689066, 0.5445109956801907, 0.22094211265521246`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 253}], {
             RGBColor[
             0.8523693689594214, 0.3702876353014115, 0.19648021346556857`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 283}], {
             RGBColor[
             0.9057344419097366, 0.6568662450460772, 0.2426421685015519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 332}], {
             RGBColor[
             0.848675629685056, 0.3418959366317691, 0.19294308456495457`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 334}], {
             RGBColor[
             0.9198789642740572, 0.7116881876157337, 0.2605664067222301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.9124649507944522, 0.7523588106461282, 0.5992692091287142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 364}], {
             RGBColor[
             0.9004423422818535, 0.6358848335091806, 0.23838402091941335`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 366}], {
             RGBColor[
             0.9364231997374939, 0.7670038596603013, 0.3666668736906492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 389}], {
             RGBColor[
             0.9363348090239618, 0.7668148008617284, 0.3570460900069422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 183}], {
             RGBColor[
             0.1919904214056781, 0.3191244841661233, 0.9342449425234534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 270}], {
             RGBColor[
             0.20162095796864934`, 0.3292467887050914, 0.9347933873336124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 280}], {
             RGBColor[
             0.20211294537388308`, 0.32976389866179523`, 0.9348214052885103]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 291}], {
             RGBColor[
             0.1953787311658639, 0.32268581255532547`, 0.9344379017517408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 336}], {
             RGBColor[
             0.21504897720554328`, 0.3433604883086603, 0.9355580931641793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 357}], {
             RGBColor[
             0.1906502583880034, 0.3177158878633042, 0.9341686222221902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 368}], {
             RGBColor[
             0.18956500601498782`, 0.31657521881029016`, 0.934106818705034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 171}], {
             RGBColor[
             0.18355378954190335`, 0.31025704916394076`, 0.9337644888196897]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 240}], {
             RGBColor[
             0.17919351847301027`, 0.305674127813381, 0.9335161778327592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 272}], {
             RGBColor[
             0.18785278804211375`, 0.3147755691599099, 0.9340093104244782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 342}], {
             RGBColor[
             0.18272416673891645`, 0.30938506299687774`, 0.9337172430283764]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 374}], {
             RGBColor[
             0.1813453905655848, 0.3079358818192477, 0.9336387237650219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 210}], {
             RGBColor[
             0.23033673863294363`, 0.3594288948689166, 0.9364287085612534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 230}], {
             RGBColor[
             0.21805906979477002`, 0.3465242864708308, 0.9357295134841028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 258}], {
             RGBColor[
             0.22632269335272776`, 0.3552098787742395, 0.936200114620793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 264}], {
             RGBColor[
             0.23748584663754294`, 0.36694306066137816`, 0.9368358396859577]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 279}], {
             RGBColor[
             0.20701484030443992`, 0.33491610103189995`, 0.9351005609531018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 328}], {
             RGBColor[
             0.22317220824719552`, 0.35189851917603227`, 0.9360206991547579]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 170}], {
             RGBColor[
             0.23052227294686206`, 0.35962390319639986`, 0.9364392744659576]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 172}], {
             RGBColor[
             0.3025819493818708, 0.42881009810169846`, 0.9407829073040905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 184}], {
             RGBColor[
             0.21954677082243013`, 0.3480879545765947, 0.9358142358567716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 190}], {
             RGBColor[
             0.21884661716031273`, 0.34735204868540315`, 0.9357743631414985]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 192}], {
             RGBColor[
             0.24190350365737148`, 0.3715862982848506, 0.9370874187178992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 221}], {
             RGBColor[
             0.29772616502322835`, 0.42460426174906063`, 0.9404735010185594]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 226}], {
             RGBColor[
             0.20872258864357046`, 0.33671105281382463`, 0.935197814694628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 252}], {
             RGBColor[
             0.21574093049341658`, 0.3440877750865875, 0.9355974988802704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 274}], {
             RGBColor[
             0.21434019517096867`, 0.34261551345094576`, 0.9355177290758593]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 288}], {
             RGBColor[
             0.2196372553710177, 0.3481830595742119, 0.9358193888179538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 318}], {
             RGBColor[
             0.21949852941857476`, 0.348037249802461, 0.9358114885801888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 322}], {
             RGBColor[
             0.2103258844391586, 0.3383962183498125, 0.9352891200183233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 351}], {
             RGBColor[
             0.26754769340127105`, 0.39846518644420825`, 0.9385505554925828]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 355}], {
             RGBColor[
             0.2168405199897158, 0.34524351336519876`, 0.9356601188753879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 399}], {
             RGBColor[
             0.2924581876891166, 0.42004140455849254`, 0.9401378301611192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 169}], {
             RGBColor[
             0.3512165772923903, 0.4726432539013666, 0.9438449606681389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 246}], {
             RGBColor[
             0.23093801406837325`, 0.3600608734746177, 0.9364629503077938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 326}], {
             RGBColor[
             0.24337300372818133`, 0.3731308360309576, 0.9371711045730012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 363}], {
             RGBColor[
             0.3098501203432949, 0.43692070785172515`, 0.9411795622408922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 383}], {
             RGBColor[
             0.3017459947622442, 0.42990132159861427`, 0.9406631745250644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 168}], {
             RGBColor[
             0.21688542639170627`, 0.3452907128409211, 0.935662676228548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.2729080188918158, 0.40405718520565725`, 0.9388573575066418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 211}], {
             RGBColor[
             0.23414776627805434`, 0.3634345265570368, 0.9366457409477322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 216}], {
             RGBColor[
             0.22581143984224178`, 0.35467251891937396`, 0.9361709994897025]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 238}], {
             RGBColor[
             0.2183443407497785, 0.3468241243317679, 0.9357457592429699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 341}], {
             RGBColor[
             0.2425749937598598, 0.37229207695749733`, 0.9371256590858552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 358}], {
             RGBColor[
             0.25670178916857006`, 0.3871402346226134, 0.9379301591856604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 211}], {
             RGBColor[
             0.2152267109388578, 0.3435472977313434, 0.935568214837358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 216}], {
             RGBColor[
             0.20689038450304525`, 0.3347852900936806, 0.9350934733793282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 238}], {
             RGBColor[
             0.19942328541058194`, 0.3269368955060745, 0.9346682331325956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 341}], {
             RGBColor[
             0.22365393842066325`, 0.35240484813180395`, 0.936048132975481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 379}], {
             RGBColor[
             0.190216267574, 0.31725973600117974`, 0.9341439070873645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 218}], {
             RGBColor[
             0.5087675338544672, 0.6120794295560898, 0.9544711904233589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 222}], {
             RGBColor[
             0.7041731063901011, 0.7666519834125803, 0.9590482629072343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 224}], {
             RGBColor[
             0.4775031351026399, 0.5866975822042433, 0.9520099424283488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 276}], {
             RGBColor[
             0.41815198956691846`, 0.5364969694368562, 0.947894817280658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 326}], {
             RGBColor[
             0.349415147686683, 0.47074983716853436`, 0.9437423719170701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 361}], {
             RGBColor[
             0.4334163894448813, 0.5497182254001022, 0.948867451343103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 363}], {
             RGBColor[
             0.4158922643017966, 0.5345397089893019, 0.947750829584961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 382}], {
             RGBColor[
             0.38967734439969204`, 0.5118336629702842, 0.9460804380697425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 383}], {
             RGBColor[
             0.4077881387207459, 0.527520322736191, 0.9472344418691334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 393}], {
             RGBColor[
             0.5896152402179853, 0.6764956737968535, 0.9616696419121211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[
             0.2468852126322833, 0.37682239027607506`, 0.9373711196742425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 208}], {
             RGBColor[
             0.26496099146250607`, 0.3958211798972109, 0.9384005085379051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 221}], {
             RGBColor[
             0.30270787399814014`, 0.42984035374028506`, 0.9407572019749026]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 225}], {
             RGBColor[
             0.22199301735031157`, 0.3506591147783862, 0.9359535459776369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 235}], {
             RGBColor[
             0.21437654864384317`, 0.34265372325588017`, 0.9355197993523594]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 322}], {
             RGBColor[
             0.2153075934140704, 0.3436323103410369, 0.9355728209746665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 335}], {
             RGBColor[
             0.21688414248716403`, 0.34528936337584293`, 0.9356626031120838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 349}], {
             RGBColor[
             0.21695935367547547`, 0.34536841510342303`, 0.9356668862779931]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 351}], {
             RGBColor[
             0.27252940237618284`, 0.4037012784354327, 0.938834256448926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 355}], {
             RGBColor[
             0.2218222289646276, 0.3504796053564232, 0.9359438198317311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 186}], {
             RGBColor[
             0.1973172314150955, 0.32472329922528254`, 0.9345482964731804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 240}], {
             RGBColor[
             0.18369308464468964`, 0.3104034571487888, 0.9337724214697247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 272}], {
             RGBColor[
             0.19235235421379315`, 0.3195048984953177, 0.9342655540614437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 308}], {
             RGBColor[
             0.20045056014029836`, 0.3280166263799862, 0.9347267349087363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 342}], {
             RGBColor[
             0.18722373291059582`, 0.31411439233228555`, 0.933973486665342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 348}], {
             RGBColor[
             0.1945787269842331, 0.32184495743723673`, 0.934392342697097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 374}], {
             RGBColor[
             0.18584495673726414`, 0.3126652111546555, 0.9338949674019874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 192}], {
             RGBColor[
             0.31894488906729196`, 0.44600858518137365`, 0.9417147525123752]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 194}], {
             RGBColor[
             0.41753162873264527`, 0.5360090287080477, 0.9478416433121417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 221}], {
             RGBColor[
             0.3747675504331488, 0.4990265486455837, 0.9451008348130354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 256}], {
             RGBColor[
             0.6859636429526801, 0.7471589426256584, 0.8613086090450968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 316}], {
             RGBColor[
             0.5458822960971526, 0.6391409074229324, 0.9586767421820886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 351}], {
             RGBColor[
             0.3445890788111915, 0.47288747334073133`, 0.943177889287059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 399}], {
             RGBColor[
             0.369499573099037, 0.49446369145501556`, 0.9447651639555954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 198}], {
             RGBColor[
             0.6233166189809511, 0.701327344471203, 0.9656888716580491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 203}], {
             RGBColor[
             0.3639226125883841, 0.4896332085668736, 0.9444098049633691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 266}], {
             RGBColor[
             0.5380286912692482, 0.6346285303347542, 0.9572070721400225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 313}], {
             RGBColor[
             0.35122662219084355`, 0.47640574207717373`, 0.9436825095790529]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 329}], {
             RGBColor[
             0.34008730347088106`, 0.4646976118288939, 0.9430481418570962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 340}], {
             RGBColor[
             0.3446138349142821, 0.46945528337457815`, 0.9433059211263948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 341}], {
             RGBColor[
             0.3335895874564281, 0.4578681003187137, 0.9426781065425826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 358}], {
             RGBColor[
             0.34771638286513834`, 0.47271625798382977`, 0.9434826066423876]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 204}], {
             RGBColor[
             0.1850387535749342, 0.31181784051481387`, 0.9338490553245634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 216}], {
             RGBColor[
             0.20297653411671235`, 0.3306715851851976, 0.9348705853898494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 229}], {
             RGBColor[
             0.1940292110138258, 0.32126738131101384`, 0.9343610485755184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 294}], {
             RGBColor[
             0.19993479870238595`, 0.3274745284075764, 0.9346973630578478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 307}], {
             RGBColor[
             0.18458331869086259`, 0.3113391495754152, 0.933823118981671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 343}], {
             RGBColor[
             0.19542826971397487`, 0.32273788071031545`, 0.93444072289877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 379}], {
             RGBColor[
             0.1863024171876671, 0.3131460310926968, 0.9339210190978857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 205}], {
             RGBColor[
             0.18567915281687453`, 0.3124909407217502, 0.9338855251140061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 232}], {
             RGBColor[
             0.18828223277850703`, 0.3152269428062281, 0.9340337666669094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 277}], {
             RGBColor[
             0.18565952896853344`, 0.31247031481291987`, 0.933884407564874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 298}], {
             RGBColor[
             0.19583511598337588`, 0.32316550193499927`, 0.9344638921919373]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 320}], {
             RGBColor[
             0.18495626411433608`, 0.3117311388615913, 0.9338443576718145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 347}], {
             RGBColor[
             0.18526445779187303`, 0.3120550699572905, 0.9338619088458187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 373}], {
             RGBColor[
             0.192094835712424, 0.3192342302227627, 0.9342508887637553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 390}], {
             RGBColor[
             0.199593709897452, 0.3271160224473115, 0.9346779385550025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 219}], {
             RGBColor[
             0.18016175523476746`, 0.3066918060397442, 0.9335713174839634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 248}], {
             RGBColor[
             0.18215464872777276`, 0.30878646345763827`, 0.9336848098201683]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 260}], {
             RGBColor[
             0.18516377148342406`, 0.31194924226322995`, 0.9338561749095045]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 285}], {
             RGBColor[
             0.18283630546897034`, 0.3095029279121705, 0.9337236291631588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 200}], {
             RGBColor[
             0.1885274133225135, 0.31548464310332325`, 0.9340477293361784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 278}], {
             RGBColor[
             0.18555079143571185`, 0.31235602477156665`, 0.9338782151232425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 296}], {
             RGBColor[
             0.18104204814496305`, 0.30761704970215387`, 0.9336214488629224]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 330}], {
             RGBColor[
             0.18585403499635023`, 0.3126747529805498, 0.9338954843954123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 367}], {
             RGBColor[
             0.18455036747987072`, 0.3113045157634352, 0.933821242458952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 398}], {
             RGBColor[
             0.18190742429108608`, 0.30852661489974587`, 0.9336707307542348]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 209}], {
             RGBColor[
             0.24592936800917714`, 0.3758177369731411, 0.9373166857370019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 245}], {
             RGBColor[
             0.21085364957036085`, 0.33895093296494805`, 0.9353191754617867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 286}], {
             RGBColor[
             0.2740282991513247, 0.4041960245612692, 0.9389591857364195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 290}], {
             RGBColor[
             0.24217146180405288`, 0.37186793928654055`, 0.9371026785379442]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 352}], {
             RGBColor[
             0.20659936567779108`, 0.3344794108566792, 0.9350769002877538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 386}], {
             RGBColor[
             0.284370042597393, 0.41315352294311436`, 0.9396181524839584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 232}], {
             RGBColor[
             0.18939213687360562`, 0.3163935223821609, 0.9340969740631693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 249}], {
             RGBColor[
             0.18602314959306215`, 0.3128525031441788, 0.9339051152215123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 268}], {
             RGBColor[
             0.1880422345433147, 0.314974689444274, 0.9340200991224608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 370}], {
             RGBColor[
             0.18698550798658503`, 0.3138640028328177, 0.9339599201083417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 238}], {
             RGBColor[
             0.1965022388034804, 0.3238666903169589, 0.9345018838496224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 245}], {
             RGBColor[
             0.1935081925729178, 0.3207197578951424, 0.9343313773460864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 187}], {
             RGBColor[
             0.22908739425404853`, 0.35811575471368917`, 0.9363575602471148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 208}], {
             RGBColor[
             0.2681228139523549, 0.39914445580516655`, 0.9385805696512048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 323}], {
             RGBColor[
             0.3312247462121247, 0.45512489933743366`, 0.9425528644360341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 377}], {
             RGBColor[
             0.2482608696505907, 0.3782682930240088, 0.9374494613063329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 388}], {
             RGBColor[
             0.2563045573313864, 0.38672271877578024`, 0.9379075374201846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 395}], {
             RGBColor[
             0.3402542515552627, 0.4629458030295253, 0.9431282165320207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 270}], {
             RGBColor[
             0.198314467229445, 0.32577145729456636`, 0.9346050875775294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 291}], {
             RGBColor[
             0.1920722404266596, 0.31921048114480044`, 0.9342496019956579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 357}], {
             RGBColor[
             0.18734376764879906`, 0.31424055645277915`, 0.9339803224661072]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 368}], {
             RGBColor[
             0.18625851527578347`, 0.31309988739976513`, 0.933918518948951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 185}], {
             RGBColor[
             0.20305130848505737`, 0.330750177787297, 0.9348748436795078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 190}], {
             RGBColor[
             0.21285282401079259`, 0.34105219205682236`, 0.9354330254886557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 226}], {
             RGBColor[
             0.20272879549405032`, 0.3304111961852439, 0.9348564770417853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 252}], {
             RGBColor[
             0.20974713734389644`, 0.3377879184580067, 0.9352561612274277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 274}], {
             RGBColor[
             0.20834640202144852`, 0.33631565682236503`, 0.9351763914230165]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 288}], {
             RGBColor[
             0.21364346222149755`, 0.3418832029456312, 0.9354780511651108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 318}], {
             RGBColor[
             0.2135047362690546, 0.34173739317388024`, 0.935470150927346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 190}], {
             RGBColor[
             0.20235115482293997`, 0.33001427189610544`, 0.9348349709642347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 226}], {
             RGBColor[
             0.1922271263061977, 0.3193732760245269, 0.9342584225173644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 252}], {
             RGBColor[
             0.1992454681560438, 0.3267499982972898, 0.9346581067030068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 274}], {
             RGBColor[
             0.19784473283359588`, 0.32527773666164805`, 0.9345783368985956]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 288}], {
             RGBColor[
             0.2031417930336449, 0.3308452827849142, 0.93487999664069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 318}], {
             RGBColor[
             0.20300306708120197`, 0.33069947301316327`, 0.9348720964029251]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 357}], {
             RGBColor[
             0.18927662196416456`, 0.31627210888827, 0.9340903956599655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 272}], {
             RGBColor[
             0.20161622991530592`, 0.3292418192212516, 0.9347931180779689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 306}], {
             RGBColor[
             0.21444053080855624`, 0.3427209725676972, 0.9355234430419865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 308}], {
             RGBColor[
             0.20971443584181115`, 0.3377535471059201, 0.9352542989252615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 342}], {
             RGBColor[
             0.19648760861210862`, 0.32385131305821946`, 0.9345010506818672]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 348}], {
             RGBColor[
             0.2038426026857459, 0.33158187816317064`, 0.9349199067136222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 374}], {
             RGBColor[
             0.19510883243877694`, 0.3224021318805894, 0.9344225314185126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 378}], {
             RGBColor[
             0.22340907061728948`, 0.35214747654494266`, 0.9360341881163283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 208}], {
             RGBColor[
             0.25538258130493185`, 0.38575366351532014`, 0.9378550322494192]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 302}], {
             RGBColor[
             0.20552429842574232`, 0.33334944701157526`, 0.9350156767981692]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 377}], {
             RGBColor[
             0.2355206370031677, 0.36487750073416236`, 0.9367239239045473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 388}], {
             RGBColor[
             0.2435643246839634, 0.37333192648593383`, 0.937182000018399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 201}], {
             RGBColor[
             0.47076164268683474`, 0.5730017553920743, 0.9531670568538995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 264}], {
             RGBColor[
             0.26789407428573686`, 0.39890403591261847`, 0.9385675432655809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 273}], {
             RGBColor[
             0.39992754574806544`, 0.5158532142548906, 0.9473461281045827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 281}], {
             RGBColor[
             0.3372802138863956, 0.4635116716468679, 0.9428236756739168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 293}], {
             RGBColor[
             0.29496948602480166`, 0.4268642457721712, 0.9401276735084836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 394}], {
             RGBColor[
             0.3167171676025393, 0.44570099448454903`, 0.9415134165478973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 207}], {
             RGBColor[
             0.2123454769342431, 0.3405189381117063, 0.935404132823199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 241}], {
             RGBColor[
             0.2570425573000169, 0.3874984035347115, 0.937949565426625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 263}], {
             RGBColor[
             0.2675028819703037, 0.39849286798607286`, 0.9385452654419342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 280}], {
             RGBColor[
             0.2210513429116578, 0.3496693552377532, 0.9358999190114381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 291}], {
             RGBColor[
             0.21431712870363867`, 0.34259126913128346`, 0.9355164154746687]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 336}], {
             RGBColor[
             0.23398737474331802`, 0.3632659448846183, 0.936636606887107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 359}], {
             RGBColor[
             0.2794316818374808, 0.4094642361682714, 0.9392819522659938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 226}], {
             RGBColor[
             0.20202864183193292`, 0.3296752902940524, 0.9348166043265123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 252}], {
             RGBColor[
             0.20904698368177904`, 0.3370520125668152, 0.9352162885121547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 274}], {
             RGBColor[
             0.20764624835933113`, 0.33557975093117354`, 0.9351365187077434]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 288}], {
             RGBColor[
             0.21294330855938015`, 0.3411472970544397, 0.9354381784498378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 318}], {
             RGBColor[
             0.21280458260693721`, 0.34100148728268875`, 0.9354302782120729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 225}], {
             RGBColor[
             0.19624559498378968`, 0.32359694139030604`, 0.9344872683637615]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 235}], {
             RGBColor[
             0.18862912627732129`, 0.3155915498678, 0.9340535217384839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 261}], {
             RGBColor[
             0.18660634868245718`, 0.3134654823640909, 0.9339383275468877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 322}], {
             RGBColor[
             0.18956017104754852`, 0.31657013695295677`, 0.934106543360791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 327}], {
             RGBColor[
             0.1848862258869851, 0.3116575242439654, 0.9338403690983792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 335}], {
             RGBColor[
             0.19113672012064215`, 0.3182271899877628, 0.9341963254982084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 349}], {
             RGBColor[
             0.1912119313089536, 0.3183062417153429, 0.9342006086641177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 355}], {
             RGBColor[
             0.19607480659810572`, 0.32341743196834305`, 0.9344775422178556]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 208}], {
             RGBColor[
             0.27634222217301546`, 0.40778357498566165`, 0.9390486527898467]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 221}], {
             RGBColor[
             0.3140891047086496, 0.4418027488287358, 0.9414053462268441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[
             0.233374248060821, 0.36262150986683694`, 0.9366016902295785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 322}], {
             RGBColor[
             0.2266888241245798, 0.3555947054294877, 0.936220965226608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 335}], {
             RGBColor[
             0.22826537319767345`, 0.3572517584642937, 0.9363107473640253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 349}], {
             RGBColor[
             0.22834058438598487`, 0.3573308101918738, 0.9363150305299347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 351}], {
             RGBColor[
             0.2839106330866923, 0.41566367352388345`, 0.9394824007008676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 355}], {
             RGBColor[
             0.233203459675137, 0.36244200044487396`, 0.9365919640836726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 399}], {
             RGBColor[
             0.3088211273745378, 0.43723989163816773`, 0.941069675369404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 195}], {
             RGBColor[
             0.6312732042379722, 0.7079049527832757, 0.9663404032043308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 242}], {
             RGBColor[
             0.5891633460741419, 0.6714315101447773, 0.963657200278417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 253}], {
             RGBColor[
             0.8315602657829888, 0.5341252723143658, 0.5780805506738103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 255}], {
             RGBColor[
             0.606058461723811, 0.6860652101473173, 0.9647337421078497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 283}], {
             RGBColor[
             0.884925338733304, 0.8207038820590313, 0.6242425057097936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 312}], {
             RGBColor[
             0.6928723364666782, 0.7586931681891012, 0.9709743993376487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 332}], {
             RGBColor[
             0.8278665265086236, 0.5057335736447233, 0.5745434217731962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 356}], {
             RGBColor[
             0.8916558476180196, 0.9161964476590825, 0.9808695463369558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 360}], {
             RGBColor[
             0.7503418220523833, 0.8050370370474327, 0.9757122305140027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 364}], {
             RGBColor[
             0.8796332391054209, 0.7997224705221349, 0.619984358127655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 380}], {
             RGBColor[
             0.7791551569135652, 0.8275462332304435, 0.978584074457042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 389}], {
             RGBColor[
             0.9155257058475293, 0.9306524378746825, 0.7386464272151838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 221}], {
             RGBColor[
             0.41267584437400284`, 0.5318031923554098, 0.9475322370266106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 233}], {
             RGBColor[
             0.7128854689421396, 0.7730895863286765, 0.9426895386250231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 256}], {
             RGBColor[
             0.7238719368935342, 0.7799355863354847, 0.863740011258672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 316}], {
             RGBColor[
             0.5837905900380065, 0.6719175511327584, 0.9611081443956637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 399}], {
             RGBColor[
             0.40740786703989107`, 0.5272403351648417, 0.9471965661691704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 241}], {
             RGBColor[
             0.35276484059541724`, 0.47739540900316435`, 0.9437930699766406]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 242}], {
             RGBColor[
             0.3825084156474021, 0.5057312970269716, 0.9455940758995094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.3994035312970712, 0.5203649970295117, 0.9466706177289421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 263}], {
             RGBColor[
             0.3632251652657039, 0.4883898734545258, 0.9443887699919498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 312}], {
             RGBColor[
             0.48621740603993846`, 0.5929929550712956, 0.9529112749587412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 356}], {
             RGBColor[
             0.6850009171912799, 0.7504962345412768, 0.9628064219580481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 359}], {
             RGBColor[
             0.375153965132881, 0.49936124163672424`, 0.9451254568160093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 360}], {
             RGBColor[
             0.5436868916256435, 0.6393368239296271, 0.957649106135095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 380}], {
             RGBColor[
             0.5725002264868254, 0.6618460201126379, 0.9605209500781344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 389}], {
             RGBColor[
             0.7088707754207897, 0.764952224756877, 0.7205833028362763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 206}], {
             RGBColor[
             0.6365065028818196, 0.7122246861355508, 0.9667719599708235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 214}], {
             RGBColor[
             0.8615229927273951, 0.7108190806524803, 0.6028379622201453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 286}], {
             RGBColor[
             0.5826840049020053, 0.6656063435828412, 0.963342437992916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 332}], {
             RGBColor[
             0.8309647608435446, 0.5082040216040586, 0.5748389341298874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 334}], {
             RGBColor[
             0.9021680954325457, 0.8779962725880234, 0.6424622562871629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 366}], {
             RGBColor[
             0.9187123308959824, 0.9333119446325909, 0.748562723255582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 386}], {
             RGBColor[
             0.5930257483480736, 0.6745638419646864, 0.9640014047404548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 217}], {
             RGBColor[
             0.19977926755688577`, 0.3273110553124115, 0.9346885057891993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 231}], {
             RGBColor[
             0.19125913163260555`, 0.3183558522481745, 0.9342032966527232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 254}], {
             RGBColor[
             0.18919463052287389`, 0.31618593068491585`, 0.9340857263686796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 314}], {
             RGBColor[
             0.18703267242257346`, 0.3139135756454394, 0.9339626060531978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 369}], {
             RGBColor[
             0.18585850163943218`, 0.31267944770563044`, 0.933895738764128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 392}], {
             RGBColor[
             0.19718685275102665`, 0.3245862629828614, 0.9345408716011396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 203}], {
             RGBColor[
             0.5694035624452959, 0.6546305646490294, 0.9622535793690412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 206}], {
             RGBColor[
             0.6288429856334741, 0.7061140055023541, 0.9660410068543737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 214}], {
             RGBColor[
             0.8538594754790496, 0.7047084000192836, 0.6021070091036955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 266}], {
             RGBColor[
             0.74350964112616, 0.79962588641691, 0.9750508465456946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 310}], {
             RGBColor[
             0.8276571285797327, 0.5355745817229594, 0.5782791813938954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 384}], {
             RGBColor[
             0.8811911535814985, 0.820358675063078, 0.6244757857174054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 215}], {
             RGBColor[
             0.8474033618771311, 0.8799586173228249, 0.9038397390676208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 222}], {
             RGBColor[
             0.9699116219534045, 0.9763258350817114, 0.9020107810264453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 223}], {
             RGBColor[
             0.9239760391061387, 0.7216129997514857, 0.5202901272072924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 224}], {
             RGBColor[
             0.7432416506659434, 0.7963714338733744, 0.8949724605475597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 247}], {
             RGBColor[
             0.9030372486329088, 0.5619443631205439, 0.500289085988991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 259}], {
             RGBColor[
             0.9420801867046171, 0.9545306309034027, 0.913114429015637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 271}], {
             RGBColor[
             0.9043692525849842, 0.5721827291840494, 0.5015646144777819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 287}], {
             RGBColor[
             0.9030273761887495, 0.5618684791886028, 0.5002796321253148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 292}], {
             RGBColor[
             0.9041138184890838, 0.5702193507910247, 0.501320010499076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 345}], {
             RGBColor[
             0.9084097409587222, 0.9276827314255283, 0.9099029118424318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 350}], {
             RGBColor[
             0.6686405102956781, 0.7329620420673324, 0.8898856192140527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 353}], {
             RGBColor[
             0.9909977762454061, 0.988800838647677, 0.6720451430779383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 393}], {
             RGBColor[
             0.8553537557812887, 0.8861695254659845, 0.9046321600313321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 400}], {
             RGBColor[
             0.9054254853432643, 0.5803013970083357, 0.502576064159955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 234}], {
             RGBColor[
             0.22049169370930496`, 0.34908112844227146`, 0.9358680478172909]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 296}], {
             RGBColor[
             0.1865617818736295, 0.3134186398223141, 0.9339357895330556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 298}], {
             RGBColor[
             0.19975642982426225`, 0.3272870514074283, 0.9346872052141117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 320}], {
             RGBColor[
             0.18887757795522245`, 0.31585268833402036`, 0.934067670693989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 330}], {
             RGBColor[
             0.1913737687250167, 0.31847634310071005`, 0.9342098250655455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 347}], {
             RGBColor[
             0.1891857716327594, 0.31617661942971953`, 0.9340852218679931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 367}], {
             RGBColor[
             0.19007010120853718`, 0.31710610588359545`, 0.9341355831290852]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 398}], {
             RGBColor[
             0.18742715801975252`, 0.3143282050199061, 0.933985071424368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 273}], {
             RGBColor[
             0.5948799673171399, 0.6816316125645953, 0.9614948857902279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 281}], {
             RGBColor[
             0.5322326354554701, 0.6292900699565726, 0.956972433359562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 293}], {
             RGBColor[
             0.4899219075938762, 0.5926426440818758, 0.9542764311941287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 303}], {
             RGBColor[
             0.7798220611835203, 0.6750115727481525, 0.6002603969131654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 394}], {
             RGBColor[
             0.5116695891716139, 0.6114793927942537, 0.9556621742335425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 212}], {
             RGBColor[
             0.45268550871471924`, 0.56313574583105, 0.9509994425842794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 234}], {
             RGBColor[
             0.28726387007128157`, 0.41752052418196, 0.9397344221047603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 239}], {
             RGBColor[
             0.4173644057485659, 0.5344604832455712, 0.9482188359733204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 269}], {
             RGBColor[
             0.34049741903328384`, 0.46934348329390774`, 0.9429171723441234]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 289}], {
             RGBColor[
             0.4009029468034172, 0.5210963292936249, 0.9469229296248474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 309}], {
             RGBColor[
             0.5124790971855998, 0.6108362268976354, 0.9562827357512269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 362}], {
             RGBColor[
             0.5594312028417849, 0.6475155686854668, 0.9609624828506617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 365}], {
             RGBColor[
             0.31680424057691503`, 0.4485693265510483, 0.9414167025039941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 206}], {
             RGBColor[
             0.36944897924090714`, 0.4944198695980247, 0.9447619401596937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 211}], {
             RGBColor[
             0.27124930343896736`, 0.4023137700960795, 0.9387628961154517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 216}], {
             RGBColor[
             0.26291297700315486`, 0.3935517624584167, 0.938288154657422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 266}], {
             RGBColor[
             0.4841156347335931, 0.5879317505125805, 0.9537717798510146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 329}], {
             RGBColor[
             0.28617424693522586`, 0.4180008320067203, 0.9396128495680883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 341}], {
             RGBColor[
             0.2796765309207728, 0.4111713204965401, 0.9392428142535747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 358}], {
             RGBColor[
             0.29380332632948314`, 0.42601947816165614`, 0.9400473143533797]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 229}], {
             RGBColor[
             0.18893129430891603`, 0.3159091476275659, 0.9340707297608657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 237}], {
             RGBColor[
             0.18108298927677668`, 0.3076600814275077, 0.9336237803998122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 307}], {
             RGBColor[
             0.17948540198595286`, 0.30598091589196724`, 0.9335328001670183]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 343}], {
             RGBColor[
             0.1903303530090651, 0.3173796470268675, 0.9341504040841173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 232}], {
             RGBColor[
             0.18775686622597437`, 0.3146747492493529, 0.9340038478189527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 277}], {
             RGBColor[
             0.18513416241600078`, 0.31191812125604473`, 0.9338544887169173]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 373}], {
             RGBColor[
             0.19156946915989134`, 0.31868203666588757`, 0.9342209699157987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 390}], {
             RGBColor[
             0.19906834334491935`, 0.32656382889043634`, 0.9346480197070459]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 266}], {
             RGBColor[
             0.5435550579217713, 0.6394151913659053, 0.9575592073363473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 286}], {
             RGBColor[
             0.375065904449271, 0.49928496789863985`, 0.9451198456671187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 386}], {
             RGBColor[
             0.3854076478953393, 0.5082424662804851, 0.9457788124146576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 231}], {
             RGBColor[
             0.1913619669815575, 0.3184639387200607, 0.9342091529737147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 280}], {
             RGBColor[
             0.200223112625469, 0.32777756462089525`, 0.9347137821092452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 291}], {
             RGBColor[
             0.19348889841744987`, 0.3206994785144255, 0.9343302785724756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 368}], {
             RGBColor[
             0.18767517326657374`, 0.3145888847693901, 0.9339991955257688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 372}], {
             RGBColor[
             0.18573202091371066`, 0.31254650844355597`, 0.9338885358739095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 387}], {
             RGBColor[
             0.18852965084716983`, 0.3154869948836043, 0.9340478567598975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 392}], {
             RGBColor[
             0.1972896880999786, 0.3246943494547476, 0.9345467279221311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 221}], {
             RGBColor[
             0.3321648835388723, 0.4608015384498717, 0.9424347350905069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 225}], {
             RGBColor[
             0.2514500268910438, 0.38162029948797277`, 0.9376310790932412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 323}], {
             RGBColor[
             0.3575199332630081, 0.48276280813906464`, 0.9440503364383386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 351}], {
             RGBColor[
             0.301986411916915, 0.43466246314501933`, 0.9405117895645303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 388}], {
             RGBColor[
             0.28259974438226976`, 0.4143606275774112, 0.9394050094224892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 395}], {
             RGBColor[
             0.366549438606146, 0.4905837118311563, 0.9446256885343254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 286}], {
             RGBColor[
             0.29314447532730914`, 0.4242883377578022, 0.9400478236897936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 290}], {
             RGBColor[
             0.2612876379800373, 0.3919602524830736, 0.938191316491318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 304}], {
             RGBColor[
             0.2736580263748165, 0.40496231501391133`, 0.9388957918100511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 338}], {
             RGBColor[
             0.23759083072429804`, 0.3670534055929334, 0.9368418183743885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 386}], {
             RGBColor[
             0.30348621877337745`, 0.4332458361396474, 0.9407067904373323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 230}], {
             RGBColor[
             0.2334030426063412, 0.36265177475985827`, 0.9366033300363481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 258}], {
             RGBColor[
             0.24166666616429894`, 0.371337367063267, 0.9370739311730383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 264}], {
             RGBColor[
             0.2528298194491141, 0.3830705489504057, 0.9377096562382032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 279}], {
             RGBColor[
             0.2223588131160111, 0.3510435893209275, 0.9359743775053473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 328}], {
             RGBColor[
             0.2385161810587667, 0.36802600746505976`, 0.9368945157070033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 394}], {
             RGBColor[
             0.30165291276591666`, 0.42986750752233627`, 0.9406555295205197]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 216}], {
             RGBColor[
             0.22415272438939332`, 0.35292910380979625`, 0.9360765380985124]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 238}], {
             RGBColor[
             0.21668562529693003`, 0.34508070922219014`, 0.9356512978517798]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 341}], {
             RGBColor[
             0.24091627830701134`, 0.3705486618479197, 0.9370311976946651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 358}], {
             RGBColor[
             0.2550430737157216, 0.3853968195130357, 0.9378356977944702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 239}], {
             RGBColor[
             0.542458414688152, 0.6394312043737607, 0.9571234599763494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 289}], {
             RGBColor[
             0.5259969557430033, 0.6260670504218144, 0.9558275536278764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 309}], {
             RGBColor[
             0.6375731061251859, 0.7158069480258249, 0.965187359754256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 362}], {
             RGBColor[
             0.6845252117813709, 0.7524862898136562, 0.9698671068536907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 385}], {
             RGBColor[
             0.7860985506073723, 0.8292872838004639, 0.7968353358505167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 215}], {
             RGBColor[
             0.5157421665105038, 0.6132928535993672, 0.9566471217151071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 227}], {
             RGBColor[
             0.29970260204538113`, 0.43079580390036054`, 0.94043541584355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 259}], {
             RGBColor[
             0.6104189913379899, 0.6878648671799451, 0.9659218116631232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 306}], {
             RGBColor[
             0.2738566580723743, 0.4036300780572341, 0.9389635275699348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 308}], {
             RGBColor[
             0.2691305631056292, 0.398662652595457, 0.9386943834532097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 345}], {
             RGBColor[
             0.5767485455920949, 0.6610169677020706, 0.962710294489918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 350}], {
             RGBColor[
             0.33697931492905076`, 0.46629627834387477`, 0.942693001861539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 378}], {
             RGBColor[
             0.2828251978811075, 0.4130565820344796, 0.9394742726442766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 257}], {
             RGBColor[
             0.9241708234933428, 0.7599031818045514, 0.5786645333196092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 310}], {
             RGBColor[
             0.8527190352209195, 0.3739582811888842, 0.19685354443386982`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 332}], {
             RGBColor[
             0.8483631502363858, 0.34047704043678684`, 0.1926823440534119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 389}], {
             RGBColor[
             0.9360223295752915, 0.7653959046667461, 0.35678534949539953`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 224}], {
             RGBColor[
             0.6019092601655756, 0.6867200928189938, 0.9624709353645509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 227}], {
             RGBColor[
             0.4900314069116405, 0.5878102265694376, 0.9551265080130549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 259}], {
             RGBColor[
             0.8007477962042493, 0.8448792898490222, 0.9806129038326282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 345}], {
             RGBColor[
             0.7670773504583543, 0.8180313903711476, 0.977401386659423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 350}], {
             RGBColor[
             0.5273081197953102, 0.6233107010129518, 0.9573840940310441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 353}], {
             RGBColor[
             0.8496653857450382, 0.8791494975932964, 0.7395436178949295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 393}], {
             RGBColor[
             0.7140213652809209, 0.7765181844116039, 0.9721306348483233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 400}], {
             RGBColor[
             0.7640930948428964, 0.47065005595395515`, 0.5700745389769464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 229}], {
             RGBColor[
             0.2068690748506942, 0.33476289229794964`, 0.9350922598261517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 294}], {
             RGBColor[
             0.21277466253925434`, 0.3409700393945122, 0.9354285743084811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 329}], {
             RGBColor[
             0.23907766788565177`, 0.368616165720437, 0.936926491551149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 340}], {
             RGBColor[
             0.2436041993290528, 0.3733738372661213, 0.9371842708204476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 341}], {
             RGBColor[
             0.2325799518711988, 0.3617866542102568, 0.9365564562366354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 343}], {
             RGBColor[
             0.20826813355084325`, 0.33623339169725125`, 0.9351719341494034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 358}], {
             RGBColor[
             0.24670674727990904`, 0.37663481187537284`, 0.9373609563364405]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 231}], {
             RGBColor[
             0.19972682323934088`, 0.32725593300951006`, 0.9346855191628995]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 254}], {
             RGBColor[
             0.1976623221296092, 0.32508601144625143`, 0.934567948878856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 314}], {
             RGBColor[
             0.1955003640293088, 0.322813656406775, 0.9344448285633742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 331}], {
             RGBColor[
             0.22460790707912992`, 0.3534075296769589, 0.9361024600793104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 392}], {
             RGBColor[
             0.20565454435776198`, 0.333486343744197, 0.935023094111316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 222}], {
             RGBColor[
             0.7556819189936763, 0.8084691579297268, 0.9631032253183853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 276}], {
             RGBColor[
             0.46966080217049366`, 0.5783141439540027, 0.951949779691809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 282}], {
             RGBColor[
             0.4376499441056336, 0.5505879476107286, 0.9499100761220066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 305}], {
             RGBColor[
             0.42916789405553485`, 0.5422531768418173, 0.9494057845729981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 339}], {
             RGBColor[
             0.47111694262023773`, 0.5795753796238241, 0.9520425636736524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 361}], {
             RGBColor[
             0.4849252020484565, 0.5915353999172487, 0.952922413754254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 382}], {
             RGBColor[
             0.44118615700326724`, 0.5536508374874307, 0.9501354004808935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 384}], {
             RGBColor[
             0.7469305423915883, 0.7141446268230167, 0.6119725391027997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 248}], {
             RGBColor[
             0.1809198934930053, 0.30748865741789405`, 0.933614492336205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 251}], {
             RGBColor[
             0.1819264333571092, 0.30854659463338063`, 0.9336718132924233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 260}], {
             RGBColor[
             0.1839290162486566, 0.31065143622348573`, 0.9337858574255411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 352}], {
             RGBColor[
             0.1830449444132805, 0.30972222067111355`, 0.9337355108423835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 396}], {
             RGBColor[
             0.18205118127193512`, 0.30867771260133725`, 0.9336789175016247]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 256}], {
             RGBColor[
             0.6811078585940378, 0.7429531062730206, 0.8609992027595657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 316}], {
             RGBColor[
             0.5410265117385101, 0.6349350710702945, 0.9583673358965574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 351}], {
             RGBColor[
             0.33973329445254913`, 0.4686816369880935, 0.9428684830015278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 399}], {
             RGBColor[
             0.36464378874039466`, 0.49025785510237774`, 0.9444557576700642]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 223}], {
             RGBColor[
             0.9051519086820443, 0.7083288764559916, 0.5859596439831081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 224}], {
             RGBColor[
             0.724417520241849, 0.7830873105778803, 0.9606419773233753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 247}], {
             RGBColor[
             0.8842131182088144, 0.5486602398250497, 0.5659586027648067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 259}], {
             RGBColor[
             0.9232560562805229, 0.9412465076079086, 0.9787839457914527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 292}], {
             RGBColor[
             0.8852896880649895, 0.5569352274955306, 0.5669895272748917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 363}], {
             RGBColor[
             0.6628066494410058, 0.7309294373629389, 0.9563828644799877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 383}], {
             RGBColor[
             0.6547025238599551, 0.723910051109828, 0.9558664767641599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 393}], {
             RGBColor[
             0.8365296253571944, 0.8728854021704904, 0.9703016768071477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 247}], {
             RGBColor[
             0.8382775353615486, 0.29394740449482404`, 0.18423794894565387`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 292}], {
             RGBColor[
             0.8393541052177236, 0.30222239216530483`, 0.1852688734557389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 319}], {
             RGBColor[
             0.845830354553812, 0.35200168247303465`, 0.19147053713385456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 385}], {
             RGBColor[
             0.9268169546976089, 0.7220420708837272, 0.4190027976388401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 393}], {
             RGBColor[
             0.7905940425099285, 0.6181725668402647, 0.5885810229879949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 400}], {
             RGBColor[
             0.8406657720719041, 0.3123044383826159, 0.18652492711661786`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 227}], {
             RGBColor[
             0.3858696957004528, 0.504223043119987, 0.9462592294929938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 259}], {
             RGBColor[
             0.6965860849930616, 0.7612921063995717, 0.9717456253125671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 363}], {
             RGBColor[
             0.4361366781535445, 0.5509750361546019, 0.9493445440011021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 383}], {
             RGBColor[
             0.42803255257249384`, 0.5439556499014909, 0.9488281562852744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 393}], {
             RGBColor[
             0.6098596540697332, 0.6929310009621534, 0.9632633563282622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 235}], {
             RGBColor[
             0.20086558407238086`, 0.32845284284664206`, 0.9347503699076954]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 261}], {
             RGBColor[
             0.19884280647751676`, 0.32632677534293286`, 0.9346351757160992]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 322}], {
             RGBColor[
             0.2017966288426081, 0.3294314299317988, 0.9348033915300026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 327}], {
             RGBColor[
             0.19712268368204472`, 0.3245188172228074, 0.9345372172675908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 335}], {
             RGBColor[
             0.20337317791570175`, 0.3310884829666048, 0.93489317366742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 349}], {
             RGBColor[
             0.2034483891040132, 0.3311675346941849, 0.9348974568333293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 355}], {
             RGBColor[
             0.2083112643931653, 0.336278724947185, 0.9351743903870672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 252}], {
             RGBColor[
             0.19892295516503677`, 0.32641101669523676`, 0.9346397400652842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 274}], {
             RGBColor[
             0.1975222198425889, 0.324938755059595, 0.9345599702608729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 288}], {
             RGBColor[
             0.20281928004263788`, 0.3305063011828612, 0.9348616300029674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 315}], {
             RGBColor[
             0.186507225222572, 0.3133612973229612, 0.9339326826124872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 318}], {
             RGBColor[
             0.20268055409019498`, 0.33036049141111024`, 0.9348537297652024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 322}], {
             RGBColor[
             0.1935079091107788, 0.32071945995846174`, 0.9343313612033369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 243}], {
             RGBColor[
             0.2526928974888643, 0.38292663528882953`, 0.9377018587351249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 306}], {
             RGBColor[
             0.248145898473511, 0.3781474510273044, 0.9374429138678827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 311}], {
             RGBColor[
             0.23829401063491945`, 0.3677924922631779, 0.9368818634300369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 346}], {
             RGBColor[
             0.23870901568862182`, 0.3682286888874592, 0.9369054973539003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 350}], {
             RGBColor[
             0.3112685553301875, 0.44081365131394507`, 0.9411723881594869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 363}], {
             RGBColor[
             0.3242588248996095, 0.45206516990504564`, 0.9420001166496061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 383}], {
             RGBColor[
             0.3161546993185588, 0.44504578365193476`, 0.9414837289337784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 276}], {
             RGBColor[
             0.3015266164865197, 0.4277543234766833, 0.9407208506945814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 282}], {
             RGBColor[
             0.26951575842165965`, 0.40002812713340913`, 0.938681147124779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 301}], {
             RGBColor[
             0.2369380396545014, 0.36636728078923275`, 0.9368046428886814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 305}], {
             RGBColor[
             0.26103370837156087`, 0.39169335636449776`, 0.9381768555757705]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 382}], {
             RGBColor[
             0.27305197131929326`, 0.4030910170101112, 0.9389064714836659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 294}], {
             RGBColor[
             0.20382733943636777`, 0.33156583552032837`, 0.9349190374941501]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 307}], {
             RGBColor[
             0.18847585942484443`, 0.31543045668816716`, 0.9340447934179733]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[
             0.2301303447827652, 0.3592119618462532, 0.9364169547368181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 340}], {
             RGBColor[
             0.23465687622616624`, 0.36396963339193744`, 0.9366747340061166]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 343}], {
             RGBColor[
             0.1993208104479567, 0.32682918782306747`, 0.9346623973350723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 258}], {
             RGBColor[
             0.22938899732612533`, 0.3584327586651811, 0.9363747360958877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 264}], {
             RGBColor[
             0.2405521506109405, 0.3701659405523198, 0.9370104611610526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 279}], {
             RGBColor[
             0.2100811442778375, 0.33813898092284156`, 0.9352751824281966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 299}], {
             RGBColor[
             0.20475753633962784`, 0.33254353144354476`, 0.9349720108316877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 300}], {
             RGBColor[
             0.2086431877242838, 0.3366275974133453, 0.9351932929297377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 328}], {
             RGBColor[
             0.2262385122205931, 0.35512139906697393`, 0.9361953206298528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 331}], {
             RGBColor[
             0.21608777115484973`, 0.34445232661272185`, 0.9356172509428343]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 369}], {
             RGBColor[
             0.1858060573218873, 0.312624325402729, 0.9338927521378282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 372}], {
             RGBColor[
             0.18557674124721385`, 0.3123832996687683, 0.9338796929266182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 392}], {
             RGBColor[
             0.1971344084334818, 0.32453114067996, 0.9345378849748398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 277}], {
             RGBColor[
             0.18773724237763328`, 0.31465412334052256`, 0.9340027302698206]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 373}], {
             RGBColor[
             0.19417254912152382`, 0.3214180387503654, 0.934369211468702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 390}], {
             RGBColor[
             0.20167142330655186`, 0.3292998309749142, 0.9347962612599492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 256}], {
             RGBColor[
             0.9813174831621745, 0.9842395002462874, 0.8561565043579783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 257}], {
             RGBColor[
             0.9698756400386146, 0.9770538821816868, 0.9358768631099392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 310}], {
             RGBColor[
             0.8984238517661913, 0.5911089815660195, 0.5540658742241997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 316}], {
             RGBColor[
             0.8412361363066468, 0.8762214650435611, 0.9535246374949702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 389}], {
             RGBColor[
             0.9817271461205633, 0.9825466050438816, 0.7139976792857294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 298}], {
             RGBColor[
             0.22620097648238727`, 0.3550819466262163, 0.936193183025091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 365}], {
             RGBColor[
             0.27647661087306347`, 0.4079248260301478, 0.9390563060275041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 261}], {
             RGBColor[
             0.19122633777104836`, 0.31832138382042696`, 0.9342014290908216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 322}], {
             RGBColor[
             0.1941801601361397, 0.32142603840929285`, 0.934369644904725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 327}], {
             RGBColor[
             0.1895062149755763, 0.31651342570030144`, 0.934103470642313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 335}], {
             RGBColor[
             0.19575670920923333`, 0.32308309144409886`, 0.9344594270421422]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 349}], {
             RGBColor[
             0.19583192039754477`, 0.3231621431716789, 0.9344637102080516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 355}], {
             RGBColor[
             0.2006947956866969, 0.3282733334246791, 0.9347406437617896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 262}], {
             RGBColor[
             0.4369845815472029, 0.5513866495573997, 0.9494877616771007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 284}], {
             RGBColor[
             0.6247504035752902, 0.7047458827568778, 0.9646230139836673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 334}], {
             RGBColor[
             0.7349237676396162, 0.7451154652166593, 0.6272347577119612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 366}], {
             RGBColor[
             0.7514680031030527, 0.8004311372612268, 0.7333352246803804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 376}], {
             RGBColor[
             0.397907468442853, 0.5154535439144465, 0.9470741986312354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 397}], {
             RGBColor[
             0.4369077612514729, 0.5513201116783387, 0.9494828667557864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 307}], {
             RGBColor[
             0.1806275543927051, 0.307181390488109, 0.9335978440569198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 324}], {
             RGBColor[
             0.18395646599811732`, 0.31068028765058353`, 0.9337874206481647]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 269}], {
             RGBColor[
             0.4302703250067166, 0.5456389418366184, 0.9490411897361934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 309}], {
             RGBColor[
             0.6022520031590326, 0.6871316854403461, 0.9624067531432969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 323}], {
             RGBColor[
             0.4638795886223883, 0.5747495967298069, 0.9511827422942791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 362}], {
             RGBColor[
             0.6492041088152176, 0.7238110272281775, 0.9670865002427318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 365}], {
             RGBColor[
             0.4065771465503478, 0.524864785093759, 0.9475407198960643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 377}], {
             RGBColor[
             0.3809157120608543, 0.4978929904163819, 0.9460793391645779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 385}], {
             RGBColor[
             0.750777447641219, 0.8006120212149852, 0.7940547292395577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 388}], {
             RGBColor[
             0.38895939974165, 0.5063474161681534, 0.9465374152784297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 272}], {
             RGBColor[
             0.18799208314490007`, 0.3149219771447579, 0.9340172430745133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 342}], {
             RGBColor[
             0.18286346184170274`, 0.30953147098172573`, 0.9337251756784115]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 374}], {
             RGBColor[
             0.18148468566837106`, 0.3080822898040957, 0.933646656415057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 242}], {
             RGBColor[
             0.31065498243158685`, 0.4409219663646659, 0.9411098670507269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 255}], {
             RGBColor[
             0.32755009808125596`, 0.4555556663672059, 0.9421864088801596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 312}], {
             RGBColor[
             0.41436397282412324`, 0.5281836244089898, 0.9484270661099586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 331}], {
             RGBColor[
             0.26094013118712034`, 0.3915950008105146, 0.9381715264935517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 359}], {
             RGBColor[
             0.3033005319170658, 0.43455191097441853`, 0.9406412479672268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 360}], {
             RGBColor[
             0.4718334584098283, 0.5745274932673213, 0.9531648972863125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 380}], {
             RGBColor[
             0.5006467932710101, 0.5970366894503322, 0.9560367412293518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 392}], {
             RGBColor[
             0.24198676846575243`, 0.37167381487775275`, 0.9370921605255572]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 255}], {
             RGBColor[
             0.3572936731332409, 0.48389155439101317`, 0.9439874148030284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 312}], {
             RGBColor[
             0.4441075478761082, 0.5565195124327971, 0.9502280720328274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 331}], {
             RGBColor[
             0.2906837062391053, 0.4199308888343219, 0.9399725324164205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 380}], {
             RGBColor[
             0.5303903683229951, 0.6253725774741394, 0.9578377471522206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 267}], {
             RGBColor[
             0.2144789920516021, 0.342761397772722, 0.9355256333528797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 275}], {
             RGBColor[
             0.21276908993785693`, 0.3409641822371201, 0.9354282569570754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 311}], {
             RGBColor[
             0.21699506567726595`, 0.34540595068157653`, 0.9356689200236639]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 326}], {
             RGBColor[
             0.23648276332684243`, 0.36588875650267677`, 0.9367787155753422]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 344}], {
             RGBColor[
             0.2114782278514492, 0.3396074043389222, 0.9353547442709138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 346}], {
             RGBColor[
             0.21741007073096835`, 0.3458421473058579, 0.9356925539475274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 363}], {
             RGBColor[
             0.302959879941956, 0.42967862832344433`, 0.9407871732432331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 383}], {
             RGBColor[
             0.29485575436090533`, 0.42265924207033345`, 0.9402707855274055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 302}], {
             RGBColor[
             0.18853043849765405`, 0.3154878227542032, 0.9340479016154273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 352}], {
             RGBColor[
             0.1906398234149592, 0.3177049200450192, 0.9341680279659126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 396}], {
             RGBColor[
             0.1896460602736138, 0.31666041197524286`, 0.9341114346251538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 248}], {
             RGBColor[
             0.19980719089443424`, 0.32734040451061686`, 0.9346900959819637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 251}], {
             RGBColor[
             0.20081373075853814`, 0.3283983417261034, 0.9347474169381822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 260}], {
             RGBColor[
             0.20281631365008554`, 0.33050318331620854`, 0.9348614610713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 326}], {
             RGBColor[
             0.22913658446266597`, 0.35816745674178546`, 0.9363603615567251]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 271}], {
             RGBColor[
             0.8186707488403941, 0.14451713392738777`, 0.16551243621614334`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 287}], {
             RGBColor[
             0.8173288724441594, 0.1342028839319411, 0.1642274538636763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 292}], {
             RGBColor[
             0.8184153147444937, 0.14255375553436297`, 0.16526783223743757`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 319}], {
             RGBColor[
             0.8248915640805821, 0.1923330458420928, 0.17146949591555327`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 362}], {
             RGBColor[
             0.8043048253983777, 0.4855724402659776, 0.5720335274237128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 385}], {
             RGBColor[
             0.9058781642243791, 0.5623734342527853, 0.3990017564205388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 393}], {
             RGBColor[
             0.7696552520366986, 0.45850393020932284`, 0.5685799817696936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 400}], {
             RGBColor[
             0.8197269815986742, 0.15263580175167407`, 0.16652388589831657`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 251}], {
             RGBColor[
             0.1839193268501145, 0.3106412520512747, 0.9337853056286283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 260}], {
             RGBColor[
             0.1859219097416619, 0.3127460936413798, 0.933899349761746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 275}], {
             RGBColor[
             0.18852850716525682`, 0.3154857928014001, 0.9340477916289045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 268}], {
             RGBColor[
             0.18564105657677243`, 0.3124508991579618, 0.9338833555894905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 279}], {
             RGBColor[
             0.19132944320701362`, 0.3184297541708887, 0.934207300792869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 299}], {
             RGBColor[
             0.186005835268804, 0.3128343046915919, 0.9339041291963601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 300}], {
             RGBColor[
             0.18989148665345995`, 0.3169183706613924, 0.9341254112944102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 370}], {
             RGBColor[
             0.18458433002004276`, 0.31134021254650546`, 0.9338231765753717]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 265}], {
             RGBColor[
             0.19635832810443649`, 0.32371543104779843`, 0.9344936883482087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 321}], {
             RGBColor[
             0.18913677562513462`, 0.3161251215191795, 0.934082431617842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 325}], {
             RGBColor[
             0.21599606078555122`, 0.34435593319981583`, 0.9356120281729761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 375}], {
             RGBColor[
             0.19825790374427554`, 0.32571200548532114`, 0.9346018663707272]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 381}], {
             RGBColor[
             0.19153445496524343`, 0.31864523452728444`, 0.9342189759092124]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 260}], {
             RGBColor[
             0.1869284496057658, 0.31380403085686637`, 0.9339566707179645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 275}], {
             RGBColor[
             0.1895350470293607, 0.3165437300168866, 0.9341051125851229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 274}], {
             RGBColor[
             0.20454056169243495`, 0.3323154773323579, 0.9349596544465153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 288}], {
             RGBColor[
             0.20983762189248398`, 0.33788302345562404`, 0.9352613141886098]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 318}], {
             RGBColor[
             0.20969889594004104`, 0.3377372136838731, 0.9352534139508448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 283}], {
             RGBColor[
             0.878557469851581, 0.4812239884723157, 0.21791952880036536`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 332}], {
             RGBColor[
             0.8214986576269006, 0.1662536800580077, 0.16822044486376803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 334}], {
             RGBColor[
             0.8927019922159016, 0.5360459310419723, 0.23584376702104354`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 364}], {
             RGBColor[
             0.8732653702236979, 0.4602425769354192, 0.2136613812182268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 366}], {
             RGBColor[
             0.9092462276793383, 0.5913616030865398, 0.3419442339894627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 391}], {
             RGBColor[
             0.8227133050515791, 0.17558999242598253`, 0.16938359260938823`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 314}], {
             RGBColor[
             0.1849157269952969, 0.31168853177927935`, 0.9338420491428545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 369}], {
             RGBColor[
             0.1837415562121556, 0.31045440383947037`, 0.9337751818537847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 312}], {
             RGBColor[
             0.46100266352577723`, 0.571153212435337, 0.9513046138622602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 331}], {
             RGBColor[
             0.30757882188877433`, 0.4345645888368619, 0.9410490742458533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 356}], {
             RGBColor[
             0.6597861746771188, 0.7286564919053182, 0.9611997608615672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 359}], {
             RGBColor[
             0.3499392226187198, 0.4775214990007658, 0.9435187957195283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 360}], {
             RGBColor[
             0.5184721491114823, 0.6174970812936685, 0.956042445038614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 380}], {
             RGBColor[
             0.5472854839726642, 0.6400062774766795, 0.9589142889816533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 310}], {
             RGBColor[
             0.9094103197175858, 0.5979549815728277, 0.4751163468578484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 316}], {
             RGBColor[
             0.8522226042580414, 0.8830674650503693, 0.8745751101286188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 319}], {
             RGBColor[
             0.9123741671932073, 0.6207364120366994, 0.4779545305476905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 384}], {
             RGBColor[
             0.9629443447193516, 0.8827390749129462, 0.5213129511813582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 310}], {
             RGBColor[
             0.8979684765940259, 0.5907693635082272, 0.5548367056098094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 356}], {
             RGBColor[
             0.9574019127188883, 0.9677509967704889, 0.9569916297931109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 360}], {
             RGBColor[
             0.816087887153252, 0.8565915861588391, 0.9518343139701578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 389}], {
             RGBColor[
             0.981271770948398, 0.982206986986089, 0.7147685106713391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 264}], {
             RGBColor[
             0.24881577416889822`, 0.37885153285572853`, 0.9374810622977428]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 279}], {
             RGBColor[
             0.2183447678357952, 0.34682457322625027`, 0.9357457835648868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 281}], {
             RGBColor[
             0.318201913769557, 0.44345916858997797`, 0.9417371947060786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 300}], {
             RGBColor[
             0.21690681128224154`, 0.345313189716754, 0.9356638940664279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 328}], {
             RGBColor[
             0.23450213577855084`, 0.36380699137038264`, 0.936665921766543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 394}], {
             RGBColor[
             0.29763886748570073`, 0.42564849142765915`, 0.9404269355800592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 271}], {
             RGBColor[
             0.8577136869121025, 0.5371034017102467, 0.5783377792427893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 287}], {
             RGBColor[
             0.8563718105158677, 0.5267891517148, 0.5770527968903222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 292}], {
             RGBColor[
             0.8574582528162021, 0.5351400233172219, 0.5780931752640834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 345}], {
             RGBColor[
             0.8617541752858404, 0.8926034039517254, 0.9866760766074392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 350}], {
             RGBColor[
             0.6219849446227963, 0.6978827145935297, 0.9666587839790601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 353}], {
             RGBColor[
             0.9443422105725244, 0.9537215111738743, 0.7488183078429457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 393}], {
             RGBColor[
             0.808698190108407, 0.8510901979921818, 0.9814053247963395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 400}], {
             RGBColor[
             0.8587699196703826, 0.545222069534533, 0.5793492289249624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 327}], {
             RGBColor[
             0.1874834373807122, 0.31438735819659225`, 0.9339882764507168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 335}], {
             RGBColor[
             0.19373393161436922`, 0.3209570239403897, 0.934344232850546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 349}], {
             RGBColor[
             0.19380914280268063`, 0.32103607566796977`, 0.9343485160164554]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 355}], {
             RGBColor[
             0.19867201809183277`, 0.32614726592096993`, 0.9346254495701933]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 284}], {
             RGBColor[
             0.5520990373737982, 0.6433480852372535, 0.9595712205145508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 325}], {
             RGBColor[
             0.3013026030921642, 0.42887910004945207`, 0.9406582888215985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 376}], {
             RGBColor[
             0.3252561022413611, 0.4540557463948223, 0.9420224051621189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 397}], {
             RGBColor[
             0.364256395049981, 0.48992231415871446`, 0.9444310732866698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 336}], {
             RGBColor[
             0.2683165494931898, 0.3993480841421268, 0.9385916026036494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 359}], {
             RGBColor[
             0.31376085658735253`, 0.4455463754257799, 0.941236947982536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 360}], {
             RGBColor[
             0.48229378308011506`, 0.5855219577186828, 0.9537605973016217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 279}], {
             RGBColor[
             0.22950792112061041`, 0.35855775511338905`, 0.9363815086300517]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 281}], {
             RGBColor[
             0.3293650670543722, 0.4551923504771167, 0.9423729197712435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 328}], {
             RGBColor[
             0.24566528906336602`, 0.3755401732575213, 0.9373016468317077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 394}], {
             RGBColor[
             0.30880202077051594`, 0.4373816733147978, 0.941062660645224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 321}], {
             RGBColor[
             0.19177497299708612`, 0.31889803422847507`, 0.9342326730553113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 325}], {
             RGBColor[
             0.2186342581575027, 0.34712884590911136`, 0.9357622696104455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 375}], {
             RGBColor[
             0.20089610111622702`, 0.32848491819461667`, 0.9347521078081966]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 381}], {
             RGBColor[
             0.19417265233719494`, 0.3214181472365799, 0.9343692173466818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 358}], {
             RGBColor[
             0.4679094050103473, 0.5710147999295367, 0.9528445815300333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 384}], {
             RGBColor[
             0.7959032258697958, 0.7536598609266292, 0.6159939861993788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 275}], {
             RGBColor[
             0.19585412945824818`, 0.323185486302614, 0.9344649749812033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 306}], {
             RGBColor[
             0.20993199303624877`, 0.33798221351119695`, 0.9352666884856375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 311}], {
             RGBColor[
             0.20008010519765723`, 0.3276272547470704, 0.9347056380477918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 317}], {
             RGBColor[
             0.1930340826347562, 0.32022143828982824`, 0.9343043774864909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 344}], {
             RGBColor[
             0.1945632673718405, 0.321828708404416, 0.9343914622950418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 346}], {
             RGBColor[
             0.20049511025135958`, 0.32806345137135173`, 0.9347292719716551]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 354}], {
             RGBColor[
             0.19683262012965425`, 0.3242139420381536, 0.9345206985773926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 279}], {
             RGBColor[
             0.19334852815726622`, 0.3205519404709839, 0.9343222846938173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 299}], {
             RGBColor[
             0.18802492021905656`, 0.3149564909916871, 0.9340191130973085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 300}], {
             RGBColor[
             0.1919105716037125, 0.31904055696148764`, 0.9342403951953585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 370}], {
             RGBColor[
             0.18660341497029534`, 0.3134623988466007, 0.9339381604763201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 371}], {
             RGBColor[
             0.1838466718007321, 0.3105648869877775, 0.9337811680310495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 309}], {
             RGBColor[
             0.5253850164437505, 0.6220146854886827, 0.9571050895141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 323}], {
             RGBColor[
             0.38701260190710624`, 0.5096325967781434, 0.9458810786650822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 362}], {
             RGBColor[
             0.5723371220999356, 0.658694027276514, 0.9617848366135348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 365}], {
             RGBColor[
             0.3297101598350657, 0.4597477851420956, 0.9422390562668672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 377}], {
             RGBColor[
             0.30404872534557215`, 0.4327759904647185, 0.9407776755353809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 388}], {
             RGBColor[
             0.3120924130263679, 0.44123041621648995`, 0.9412357516492327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 336}], {
             RGBColor[
             0.2213730230293102, 0.3500074614371033, 0.9359182382182554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 357}], {
             RGBColor[
             0.1969743042117703, 0.32436286099174727`, 0.9345287672762663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 287}], {
             RGBColor[
             0.8186608763962349, 0.14444124999544666`, 0.16550298235246705`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 292}], {
             RGBColor[
             0.8197473186965691, 0.15279212159786854`, 0.16654336072622833`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 303}], {
             RGBColor[
             0.8569664054518005, 0.38299924589270967`, 0.19999647199586007`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 333}], {
             RGBColor[
             0.8868896427416582, 0.5599013471362418, 0.5649582086174862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 337}], {
             RGBColor[
             0.8884909872626653, 0.561095627258048, 0.562247550040962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 345}], {
             RGBColor[
             0.8240432411662075, 0.5102555022323721, 0.5751262620695841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 353}], {
             RGBColor[
             0.9066312764528914, 0.571373609454521, 0.33726849330509057`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 385}], {
             RGBColor[
             0.9072101681764545, 0.5726118003162909, 0.40027728490932957`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 391}], {
             RGBColor[
             0.820118482997181, 0.15564505305760412`, 0.1668987880796643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 400}], {
             RGBColor[
             0.8210589855507496, 0.16287416781517963`, 0.16779941438710733`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 308}], {
             RGBColor[
             0.20474955864050876`, 0.33253514637595527`, 0.9349715565135248]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 342}], {
             RGBColor[
             0.19152273141080622`, 0.31863291232825464`, 0.9342183082701306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 348}], {
             RGBColor[
             0.1988777254844435, 0.3263634774332058, 0.9346371643018856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 374}], {
             RGBColor[
             0.19014395523747457`, 0.3171837311506246, 0.934139789006776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 375}], {
             RGBColor[
             0.1997235147350348, 0.3272524555617131, 0.9346853307484737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 378}], {
             RGBColor[
             0.2184441934159871, 0.34692907581497784`, 0.9357514457045917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 281}], {
             RGBColor[
             0.46139853851670076`, 0.5721415288193888, 0.9511515046102453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 293}], {
             RGBColor[
             0.4190878106551068, 0.5354941029446921, 0.9484555024448121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 394}], {
             RGBColor[
             0.4408354922328445, 0.55433085165707, 0.9498412454842259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 288}], {
             RGBColor[
             0.20843688657003606`, 0.3364107618199823, 0.9351815443841986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 318}], {
             RGBColor[
             0.20829816061759315`, 0.33626495204823137`, 0.9351736441464337]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 311}], {
             RGBColor[
             0.19837020308391207`, 0.32583003921146847`, 0.9346082616519875]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 317}], {
             RGBColor[
             0.19132418052101102`, 0.3184242227542263, 0.9342070010906866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 344}], {
             RGBColor[
             0.19285336525809532`, 0.32003149286881416`, 0.9342940858992375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 346}], {
             RGBColor[
             0.1987852081376144, 0.3262662358357499, 0.9346318955758508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 282}], {
             RGBColor[
             0.3470343998180849, 0.475005487491495, 0.9433337029793059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 301}], {
             RGBColor[
             0.3144566810509267, 0.44134464114731864`, 0.9414571987432081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 305}], {
             RGBColor[
             0.33855234976798615`, 0.46667071672258365`, 0.9428294114302973]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 339}], {
             RGBColor[
             0.38050139833268903`, 0.5039929195045905, 0.9454661905309516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 361}], {
             RGBColor[
             0.3943096577609078, 0.5159529397980152, 0.9463460406115533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 382}], {
             RGBColor[
             0.35057061271571854`, 0.4780683773681971, 0.9435590273381926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 373}], {
             RGBColor[
             0.19154984531155025`, 0.31866141075705723`, 0.9342198523666666]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 390}], {
             RGBColor[
             0.19904871949657826`, 0.326543202981606, 0.9346469021579138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 296}], {
             RGBColor[
             0.1835851599868279, 0.3102900214905575, 0.9337662753201197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 302}], {
             RGBColor[
             0.19139766926121787`, 0.31850146407963903`, 0.9342111861657245]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 330}], {
             RGBColor[
             0.18839714683821507`, 0.31534772476895345`, 0.9340403108526096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 367}], {
             RGBColor[
             0.18709347932173553`, 0.31397748755183885`, 0.9339660689161493]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 299}], {
             RGBColor[
             0.19371330684929777`, 0.320935346004614, 0.9343430583006869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 300}], {
             RGBColor[
             0.1975989582339537, 0.32501941197441453`, 0.9345643403987369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 328}], {
             RGBColor[
             0.215194282730263, 0.3435132136280431, 0.9355663680988517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 370}], {
             RGBColor[
             0.19229180160053655`, 0.3194412538595276, 0.9342621056796985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 371}], {
             RGBColor[
             0.1895350584309733, 0.3165437420007044, 0.9341051132344278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 291}], {
             RGBColor[
             0.20219476439486456`, 0.32984989564047235`, 0.9348260647607148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 336}], {
             RGBColor[
             0.22186501043454393`, 0.3505245713938071, 0.9359462561731533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 368}], {
             RGBColor[
             0.19638103924398845`, 0.323739301895437, 0.934494981714008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 387}], {
             RGBColor[
             0.19723551682458454`, 0.32463741200965124`, 0.9345436429481366]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 392}], {
             RGBColor[
             0.20599555407739328`, 0.33384476658079454`, 0.9350425141103704]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 293}], {
             RGBColor[
             0.356440478793437, 0.4831525603366694, 0.9439330500141462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 394}], {
             RGBColor[
             0.3781881603711747, 0.5019893090490473, 0.9453187930535599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 301}], {
             RGBColor[
             0.2824458229860667, 0.41361844480404447`, 0.9394174951734057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 305}], {
             RGBColor[
             0.30654149170312617`, 0.4389445203793095, 0.9407897078604948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 313}], {
             RGBColor[
             0.2998205585054363, 0.43188039345676055`, 0.940406960657616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 339}], {
             RGBColor[
             0.34849054026782905`, 0.4762667231613163, 0.9434264869611491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 340}], {
             RGBColor[
             0.29320777122887487`, 0.42492993475416496`, 0.9400303722049579]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 361}], {
             RGBColor[
             0.36229879969604784`, 0.48822674345474093`, 0.9443063370417508]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 382}], {
             RGBColor[
             0.3185597546508585, 0.45034218102492296`, 0.9415193237683902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 312}], {
             RGBColor[
             0.7398695405352704, 0.7057918843470511, 0.6108133774642039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 332}], {
             RGBColor[
             0.8748637305772158, 0.45283228980267326`, 0.21438239989975133`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 334}], {
             RGBColor[
             0.9460670651662169, 0.8226245407866379, 0.2820057220570269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 356}], {
             RGBColor[
             0.9386530516866118, 0.8632951638170323, 0.6207085244635109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 360}], {
             RGBColor[
             0.7973390261209754, 0.7521357532053826, 0.6155512086405578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 364}], {
             RGBColor[
             0.9266304431740131, 0.7468211866800847, 0.25982333625421017`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 366}], {
             RGBColor[
             0.9626113006296535, 0.8779402128312055, 0.388106189025446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 380}], {
             RGBColor[
             0.8261523609821573, 0.7746449493883936, 0.6184230525835972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 389}], {
             RGBColor[
             0.9625229099161214, 0.8777511540326326, 0.378485405341739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 334}], {
             RGBColor[
             0.8500382234662116, 0.8370769008965131, 0.6373182165494112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 366}], {
             RGBColor[
             0.8665824589296481, 0.8923925729410807, 0.7434186835178305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 397}], {
             RGBColor[
             0.5520222170780682, 0.6432815473581924, 0.9595663255932364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 324}], {
             RGBColor[
             0.1849819453905557, 0.31175813151118514`, 0.9338458201825032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 290}], {
             RGBColor[
             0.28938656912218486`, 0.4203385400712017, 0.9398338164907357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 304}], {
             RGBColor[
             0.3017569575169641, 0.43334060260203944`, 0.9405382918094687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 386}], {
             RGBColor[
             0.331585149915525, 0.4616241237277755, 0.94234929043675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 292}], {
             RGBColor[
             0.8184054423003344, 0.14247787160242187`, 0.16525837837376128`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 303}], {
             RGBColor[
             0.8556245290555657, 0.372684995897263, 0.19871148964339302`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 353}], {
             RGBColor[
             0.9052894000566567, 0.5610593594590743, 0.33598351095262347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 385}], {
             RGBColor[
             0.9058682917802197, 0.5622975503208443, 0.39899230255686247`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 391}], {
             RGBColor[
             0.8187766066009462, 0.14533080306215745`, 0.16561380572719725`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 400}], {
             RGBColor[
             0.8197171091545148, 0.15255991781973297`, 0.16651443203464028`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 318}], {
             RGBColor[
             0.21359522081764215`, 0.3418324981714975, 0.9354753038885282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 304}], {
             RGBColor[
             0.2699001201696922, 0.4010125173273108, 0.9386817846109934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 338}], {
             RGBColor[
             0.2338329245191738, 0.3631036079063329, 0.9366278111753308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 336}], {
             RGBColor[
             0.21513079622652476`, 0.34344648528733734`, 0.9355627526363838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 368}], {
             RGBColor[
             0.1896468250359693, 0.3166612157889672, 0.9341114781772385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 387}], {
             RGBColor[
             0.1905013026165654, 0.3175593259031815, 0.9341601394113672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 303}], {
             RGBColor[
             0.8567109713559, 0.3810358674996849, 0.1997518680171543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 309}], {
             RGBColor[
             0.7584292895983676, 0.45716808614862703`, 0.568384704834363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 362}], {
             RGBColor[
             0.8053813952545528, 0.4938474279364584, 0.5730644519337977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 385}], {
             RGBColor[
             0.9069547340805542, 0.5706484219232661, 0.4000326809306238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 400}], {
             RGBColor[
             0.8208035514548493, 0.16091078942215484`, 0.1675548104084016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 394}], {
             RGBColor[
             0.3358774325095808, 0.4653418831743506, 0.9426227908881267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 301}], {
             RGBColor[
             0.22980051567191817`, 0.3588652905383795, 0.9363981714568937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 313}], {
             RGBColor[
             0.24717525119128783`, 0.3771272391910956, 0.937387636941104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 329}], {
             RGBColor[
             0.23603593247132534`, 0.36541910894281576`, 0.9367532692191475]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 340}], {
             RGBColor[
             0.24056246391472638`, 0.3701767804885, 0.937011048488446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 343}], {
             RGBColor[
             0.20522639813651683`, 0.33303633491963003`, 0.9349987118174017]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 330}], {
             RGBColor[
             0.18388840354746627`, 0.31060874969954066`, 0.9337835445922895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 367}], {
             RGBColor[
             0.18258473603098674`, 0.3092385124824261, 0.9337093026558292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 398}], {
             RGBColor[
             0.17994179284220208`, 0.3064606116187368, 0.933558790951112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 325}], {
             RGBColor[
             0.267416015836295, 0.3984015661715987, 0.9385403185441094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 375}], {
             RGBColor[
             0.2496778587950193, 0.3797576384571041, 0.9375301567418605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 376}], {
             RGBColor[
             0.2913695149854919, 0.423578212516969, 0.9399044348846297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 378}], {
             RGBColor[
             0.2683985374759716, 0.3994342587103688, 0.9385962716979784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 397}], {
             RGBColor[
             0.33036980779411174`, 0.4594447802808611, 0.9423131030091806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 320}], {
             RGBColor[
             0.19458686072830475`, 0.3218535065179652, 0.9343928059017892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 347}], {
             RGBColor[
             0.1948950544058417, 0.32217743761366435`, 0.9344103570757931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 373}], {
             RGBColor[
             0.20172543232639267`, 0.32935659787913657`, 0.93479933699373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 390}], {
             RGBColor[
             0.2092243065114207, 0.3372383901036854, 0.935226386784977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 300}], {
             RGBColor[
             0.19227535029574405`, 0.31942396249511773`, 0.934261168802228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 370}], {
             RGBColor[
             0.1869681936623269, 0.3138458043802308, 0.9339589340831895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 371}], {
             RGBColor[
             0.18421145049276366`, 0.3109482925214076, 0.933801941637919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 370}], {
             RGBColor[
             0.19085384504698283`, 0.3179298703500313, 0.9341802161812396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 371}], {
             RGBColor[
             0.1880971018774196, 0.31503235849120814`, 0.934023223735969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 305}], {
             RGBColor[
             0.27396377293596785`, 0.4052836740351331, 0.9389132036243971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 313}], {
             RGBColor[
             0.2672428397382781, 0.39821954711258417`, 0.9385304564215183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 329}], {
             RGBColor[
             0.25610352101831557`, 0.38651141686430435`, 0.9378960886995618]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 339}], {
             RGBColor[
             0.3159128215006708, 0.4426058768171399, 0.9415499827250514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 340}], {
             RGBColor[
             0.26063005246171667`, 0.3912690884099886, 0.9381538679688604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 361}], {
             RGBColor[
             0.3297210809288895, 0.45456589711056455`, 0.9424298328056531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 382}], {
             RGBColor[
             0.2859820358837003, 0.41668133468074653`, 0.9396428195322926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 367}], {
             RGBColor[
             0.19039724530537674`, 0.31744995507150764`, 0.934154213501434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 377}], {
             RGBColor[
             0.22469777382228445`, 0.35350198532189486`, 0.9361075778573873]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 353}], {
             RGBColor[
             0.9435949291122223, 0.7996173553563373, 0.3704770005960165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 385}], {
             RGBColor[
             0.9441738208357854, 0.8008555462181073, 0.4334857922002555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 391}], {
             RGBColor[
             0.8570821356565119, 0.38388879895942046`, 0.20010729537059024`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 400}], {
             RGBColor[
             0.8580226382100805, 0.391117913716996, 0.20100792167803327`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 338}], {
             RGBColor[
             0.24620331291395298`, 0.37610567043717064`, 0.9373322864940637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 313}], {
             RGBColor[
             0.29133850845533754`, 0.4235456226878492, 0.9399026691086074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 329}], {
             RGBColor[
             0.28019918973537505`, 0.41183749243956935`, 0.9392683013866509]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 339}], {
             RGBColor[
             0.3400084902177303, 0.4679319523924049, 0.9429221954121405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 340}], {
             RGBColor[
             0.2847257211787761, 0.4165951639852536, 0.9395260806559493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 361}], {
             RGBColor[
             0.353816749645949, 0.47989197268582956`, 0.9438020454927423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 382}], {
             RGBColor[
             0.31007770460075973`, 0.44200741025601153`, 0.9410150322193817]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 308}], {
             RGBColor[
             0.2175738595337591, 0.3460142997224009, 0.9357018814775424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 311}], {
             RGBColor[
             0.21244806666191265`, 0.3406267664200514, 0.9354099751564218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 346}], {
             RGBColor[
             0.21286307171561503`, 0.3410629630443328, 0.9354336090802852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 348}], {
             RGBColor[
             0.21170202637769384`, 0.33984263077965143`, 0.9353674892659032]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 350}], {
             RGBColor[
             0.2854226113571807, 0.41364792547081863`, 0.9397004998858718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 354}], {
             RGBColor[
             0.2092005815939097, 0.33721345371113465`, 0.9352250356860227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 378}], {
             RGBColor[
             0.23126849430923743`, 0.36040822916142345`, 0.9364817706686093]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 343}], {
             RGBColor[
             0.1898749181249935, 0.3169009560874688, 0.9341244677412249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 348}], {
             RGBColor[
             0.20697593141094872`, 0.33487520531787435`, 0.9350983451491781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 354}], {
             RGBColor[
             0.20447448662716458`, 0.33224602824935756`, 0.9349558915692975]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 374}], {
             RGBColor[
             0.1982421611639798, 0.32569545903529307`, 0.9346009698540684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 378}], {
             RGBColor[
             0.22654239934249232`, 0.35544080369964637`, 0.9362126265518842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 323}], {
             RGBColor[
             0.5589942800594222, 0.6511253403818711, 0.9592466420721857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 362}], {
             RGBColor[
             0.7443188002522516, 0.8001867708802417, 0.9751504000206381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 365}], {
             RGBColor[
             0.5016918379873817, 0.6012405287458232, 0.9556046196739707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 385}], {
             RGBColor[
             0.845892139078253, 0.8769877648670494, 0.8021186290174642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 316}], {
             RGBColor[
             0.7693289728620583, 0.48993694637010154`, 0.5724844799948403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 319}], {
             RGBColor[
             0.8294805357972241, 0.22760589335643167`, 0.17586390041391192`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 384}], {
             RGBColor[
             0.8800507133233684, 0.4896085562326786, 0.2192223210475797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 317}], {
             RGBColor[
             0.19555015626042008`, 0.32286599119868276`, 0.934447664157275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 344}], {
             RGBColor[
             0.19707934099750435`, 0.3244732613132706, 0.9345347489658259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 346}], {
             RGBColor[
             0.20301118387702347`, 0.33070800428020625`, 0.9348725586424393]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 354}], {
             RGBColor[
             0.19934869375531813`, 0.32685849494700814`, 0.9346639852481768]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 356}], {
             RGBColor[
             0.746600049419986, 0.8012844499471021, 0.9674404180913663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 359}], {
             RGBColor[
             0.4367530973615871, 0.5501494570425497, 0.9497594529493274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 360}], {
             RGBColor[
             0.6052860238543496, 0.6901250393354524, 0.9622831022684131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 380}], {
             RGBColor[
             0.6340993587155315, 0.7126342355184634, 0.9651549462114524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 389}], {
             RGBColor[
             0.7704699076494956, 0.8157404401627024, 0.7252172989695943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 329}], {
             RGBColor[
             0.27347825653768526`, 0.4047733655170204, 0.9388855541837721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 339}], {
             RGBColor[
             0.3332875570200404, 0.460867825469856, 0.9425394482092617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 340}], {
             RGBColor[
             0.2780047879810863, 0.40953103706270466`, 0.9391433334530706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 358}], {
             RGBColor[
             0.28110733593194254`, 0.4127920116719563, 0.9393200189690635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 361}], {
             RGBColor[
             0.3470958164482592, 0.47282784576328063`, 0.9434192982898635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 369}], {
             RGBColor[
             0.1815795981118552, 0.30818204879999395`, 0.9336520615383029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 322}], {
             RGBColor[
             0.18811052101816012`, 0.31504646285894905`, 0.9340239879361825]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 351}], {
             RGBColor[
             0.5108480401165528, 0.6087959957654421, 0.956444390370581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 399}], {
             RGBColor[
             0.5357585344043984, 0.6303722138797264, 0.9580316650391174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 344}], {
             RGBColor[
             0.19003331843460333`, 0.31706744485602845`, 0.9341334884045249]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 346}], {
             RGBColor[
             0.19596516131412245`, 0.3233021878229641, 0.9344712980811385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 354}], {
             RGBColor[
             0.19230267119241712`, 0.319452678489766, 0.934262724686876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 322}], {
             RGBColor[
             0.20428384988578308`, 0.3320456569470981, 0.9349450350888977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 384}], {
             RGBColor[
             0.8830145607989899, 0.5123899866965502, 0.22206050473742173`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 347}], {
             RGBColor[
             0.1840162025368019, 0.3107430745402564, 0.9337908225556705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 398}], {
             RGBColor[
             0.182257588923795, 0.30889466013044303`, 0.9336906721120455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 375}], {
             RGBColor[
             0.19367454863692518`, 0.3208946086659977, 0.9343408510778299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 381}], {
             RGBColor[
             0.18695109985789307`, 0.313827837707961, 0.9339579606163151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 327}], {
             RGBColor[
             0.19043725974580353`, 0.3174920127854582, 0.9341564922646202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 335}], {
             RGBColor[
             0.19668775397946056`, 0.3240616785292556, 0.9345124486644494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 349}], {
             RGBColor[
             0.19676296516777197`, 0.32414073025683565`, 0.9345167318303588]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 355}], {
             RGBColor[
             0.2016258404569241, 0.32925192050983587`, 0.9347936653840967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 362}], {
             RGBColor[
             0.6059463857156073, 0.6878046821697024, 0.9639263891716204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 365}], {
             RGBColor[
             0.3633194234507374, 0.48885844003528395`, 0.9443806088249529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 377}], {
             RGBColor[
             0.3376579889612439, 0.46188664535790686`, 0.9429192280934666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 388}], {
             RGBColor[
             0.34570167664203966`, 0.47034107110967827`, 0.9433773042073184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 395}], {
             RGBColor[
             0.42965137086591587`, 0.5465641553634234, 0.9485979833191546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 376}], {
             RGBColor[
             0.26222548998781436`, 0.392945994406499, 0.9382447257757333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 397}], {
             RGBColor[
             0.3012257827964342, 0.4288125621703911, 0.9406533939002841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 363}], {
             RGBColor[
             0.3080486907375876, 0.43502729111889293`, 0.9410769734898234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 383}], {
             RGBColor[
             0.2999445651565369, 0.428007904865782, 0.9405605857739958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 335}], {
             RGBColor[
             0.19201380881889718`, 0.3191490658202642, 0.9342462744020376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 349}], {
             RGBColor[
             0.19208902000720862`, 0.3192281175478443, 0.934250557567947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 355}], {
             RGBColor[
             0.19695189529636073`, 0.3243393078008444, 0.9345274911216848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 339}], {
             RGBColor[
             0.322148238300078, 0.44915969522157617`, 0.9419050804873051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 340}], {
             RGBColor[
             0.2668654692611238, 0.39782290681442484`, 0.9385089657311141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 341}], {
             RGBColor[
             0.2558412218032698, 0.3862357237585604, 0.9378811511473018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 343}], {
             RGBColor[
             0.23152940348291426`, 0.3606824612455548, 0.9364966290600697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 358}], {
             RGBColor[
             0.26996801721198005`, 0.40108388142367646`, 0.9386856512471069]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 367}], {
             RGBColor[
             0.1873967228823739, 0.314296215760822, 0.9339833381883191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 398}], {
             RGBColor[
             0.18475377969358928`, 0.31151831489713266`, 0.9338328264836019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 392}], {
             RGBColor[
             0.22201549227327083`, 0.35068273734740874`, 0.9359548258912509]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 334}], {
             RGBColor[
             0.8890082529415364, 0.5076542323723299, 0.23230663812042954`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 356}], {
             RGBColor[
             0.8815942394619314, 0.5483248554027244, 0.5710094405269136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 364}], {
             RGBColor[
             0.8695716309493327, 0.4318508782657767, 0.2101242523176128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 366}], {
             RGBColor[
             0.905552488404973, 0.5629699044168974, 0.3384071050888487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 380}], {
             RGBColor[
             0.7690935487574768, 0.4596746409740855, 0.5687239686469998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 389}], {
             RGBColor[
             0.905464097691441, 0.5627808456183245, 0.32878632140514163`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 337}], {
             RGBColor[
             0.9553778772118539, 0.9662414744033965, 0.9604177939535141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 345}], {
             RGBColor[
             0.8909301311153961, 0.9154013493777207, 0.9732965059821361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 353}], {
             RGBColor[
             0.97351816640208, 0.9765194565998694, 0.7354387372176427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 391}], {
             RGBColor[
             0.8870053729463696, 0.5607909002029526, 0.5650690319922165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 364}], {
             RGBColor[
             0.9407749655383337, 0.8016431292497415, 0.27774757447488835`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 366}], {
             RGBColor[
             0.9767558229939741, 0.9327621554008622, 0.40603042724612426`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 391}], {
             RGBColor[
             0.890222900366215, 0.5169905447403047, 0.23346978586604977`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 349}], {
             RGBColor[
             0.19833951424086566`, 0.32579778329164166`, 0.9346065139677762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 355}], {
             RGBColor[
             0.20320238953001776`, 0.3309089735446419, 0.934883447521514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 359}], {
             RGBColor[
             0.2802453493603669, 0.4103194523243253, 0.9393282894277089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 345}], {
             RGBColor[
             0.8925314756364031, 0.9165956294995268, 0.9705858474056119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 353}], {
             RGBColor[
             0.9751195109230872, 0.9777137367216755, 0.7327280786411184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 391}], {
             RGBColor[
             0.8886067174673766, 0.5619851803247587, 0.5623583734156922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 340}], {
             RGBColor[
             0.326674769743479, 0.4539173667672604, 0.9421628597566036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 361}], {
             RGBColor[
             0.39576579821065194`, 0.5172141754678363, 0.9464388245933966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 382}], {
             RGBColor[
             0.3520267531654626, 0.47932961303801835`, 0.943651811320036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 343}], {
             RGBColor[
             0.2360559349263153, 0.3654401327912391, 0.9367544083293682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 358}], {
             RGBColor[
             0.2744945486553811, 0.4058415529693607, 0.9389434305164055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 361}], {
             RGBColor[
             0.34048302917169776`, 0.46587738706068504`, 0.9430427098372054]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 358}], {
             RGBColor[
             0.26347030119752707`, 0.39425436991349627`, 0.9383156159325932]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 348}], {
             RGBColor[
             0.1937491041812462, 0.3209729712701737, 0.9343450969057838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 374}], {
             RGBColor[
             0.18501533393427727`, 0.31179322498759243`, 0.9338477216106742]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 346}], {
             RGBColor[
             0.19749434605120672`, 0.3249094579375519, 0.9345583828896893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 354}], {
             RGBColor[
             0.1938318559295014, 0.32105994860435383`, 0.9343498094954268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 350}], {
             RGBColor[
             0.5883144988769012, 0.6710348151156551, 0.9634472668058549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 353}], {
             RGBColor[
             0.9106717648266294, 0.9268736116959997, 0.7456067906697404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 354}], {
             RGBColor[
             0.1997636988090205, 0.3272946915712895, 0.9346876191720402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 398}], {
             RGBColor[
             0.182565782601332, 0.30921859122614215`, 0.9337082232860494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 354}], {
             RGBColor[
             0.19860265347109932`, 0.3260743593066081, 0.9346214993576583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 374}], {
             RGBColor[
             0.19237032800791454`, 0.3195237900925436, 0.9342665776424293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 378}], {
             RGBColor[
             0.22067056618642705`, 0.3492691347568969, 0.935878234340245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 355}], {
             RGBColor[
             0.20327760071832918`, 0.33098802527222193`, 0.9348877306874234]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 355}], {
             RGBColor[
             0.2588476494190366, 0.38932088860423164`, 0.9380551008583563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 395}], {
             RGBColor[
             0.37411784951982285`, 0.4984638103693781, 0.9450594364453463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 399}], {
             RGBColor[
             0.33446531711843736`, 0.46411877979752536`, 0.9425328121440877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 396}], {
             RGBColor[
             0.18539177638104404`, 0.312188889866974, 0.9338691594511209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 391}], {
             RGBColor[
             0.9067470066576029, 0.5722631625212318, 0.3373793166798207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 400}], {
             RGBColor[
             0.9076875092111716, 0.5794922772788073, 0.33827994298726377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 374}], {
             RGBColor[
             0.18986888322413037`, 0.3168946130240269, 0.9341241240625486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 359}], {
             RGBColor[
             0.6355366085129286, 0.7076527365125309, 0.9596545999486343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 360}], {
             RGBColor[
             0.804069535005691, 0.8476283188054337, 0.97217824926772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 364}], {
             RGBColor[
             0.9333609520587287, 0.8423137522801358, 0.6164503768813724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 380}], {
             RGBColor[
             0.8328828698668729, 0.8701375149884446, 0.9750500932107594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 389}], {
             RGBColor[
             0.969253418800837, 0.9732437196326836, 0.7351124459689012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 360}], {
             RGBColor[
             0.49422258294729215`, 0.5964933259008812, 0.9544972841256812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 380}], {
             RGBColor[
             0.6915688443012366, 0.7589781043767949, 0.9698927773878063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 389}], {
             RGBColor[
             0.8279393932352007, 0.862084309021034, 0.7299551301459482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 382}], {
             RGBColor[
             0.3658350125936814, 0.49128963333144304`, 0.9445316614006376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 365}], {
             RGBColor[
             0.5486439436435668, 0.6379198705336546, 0.9602843667734056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 385}], {
             RGBColor[
             0.892844244734438, 0.9136671066548807, 0.806798376116899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 383}], {
             RGBColor[
             0.36642168177165046`, 0.49179777668654956`, 0.9445690434418867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 393}], {
             RGBColor[
             0.5482487832688899, 0.640773127747212, 0.9590042434848745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 366}], {
             RGBColor[
             0.9573192010017704, 0.856958801294309, 0.38384804144330753`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 380}], {
             RGBColor[
             0.8208602613542741, 0.753663537851497, 0.6141649050014586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 391}], {
             RGBColor[
             0.8707862783740112, 0.44118719063375156`, 0.21128740006323304`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 377}], {
             RGBColor[
             0.2803555468892034, 0.41200183372185906`, 0.9392772056952516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 388}], {
             RGBColor[
             0.2883992345699991, 0.4204562594736305, 0.9397352818091035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 372}], {
             RGBColor[
             0.1818899475322301, 0.30850824571809776`, 0.9336697354786725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 387}], {
             RGBColor[
             0.18468757746568928`, 0.3114487321581461, 0.9338290563646603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 387}], {
             RGBColor[
             0.18274442511282618`, 0.30940635583231196`, 0.9337183967128011]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 392}], {
             RGBColor[
             0.19150446236563495`, 0.31861371040345526`, 0.9342172678750348]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 390}], {
             RGBColor[
             0.20548402624046883`, 0.3333071183914488, 0.9350133833567951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 381}], {
             RGBColor[
             0.196072227977034, 0.3234147216741027, 0.9344773953692003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 397}], {
             RGBColor[
             0.32517928194563106`, 0.4539892085157613, 0.9420175102408045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 388}], {
             RGBColor[
             0.26273780008050557`, 0.39348446479625343`, 0.9382739010776171]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 389}], {
             RGBColor[
             0.8567527280963826, 0.8845935052040448, 0.7328269740889874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 393}], {
             RGBColor[
             0.5401446576878393, 0.6337537414941011, 0.9584878557690468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 400}], {
             RGBColor[
             0.9082664009347345, 0.5807304681405772, 0.40128873459150277`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 395}], {
             RGBColor[
             0.35473118198517756`, 0.4781619748017699, 0.9439526563033052]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.027885652381746694`], {
             RGBColor[
             0.1818132732838514, 0.3084276562216236, 0.9336653689936567]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.027885652381746694`], {
             RGBColor[
             0.20182540810126717`, 0.3294616787573599, 0.9348050304662081]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.027885652381746694`], {
             RGBColor[
             0.23621542372166607`, 0.36560776562732644`, 0.9367634909803209]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.027885652381746694`], {
             RGBColor[
             0.2008450066857079, 0.32843121470856707`, 0.9347491980559659]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.027885652381746694`], {
             RGBColor[
             0.18681770269069906`, 0.3136876288273712, 0.9339503638449868]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.027885652381746694`], {
             RGBColor[
             0.9261633007621113, 0.943961492267368, 0.992819476494071]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.027885652381746694`], {
             RGBColor[
             0.25494849258932906`, 0.3852974087524073, 0.9378303115392425]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.027885652381746694`], {
             RGBColor[
             0.25559866423556843`, 0.38598078037586825`, 0.937867337852653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.027885652381746694`], {
             RGBColor[
             0.6863588655876156, 0.7549080294084094, 0.9693734953996518]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.027885652381746694`], {
             RGBColor[
             0.8429670986480872, 0.3312695252776902, 0.18877864823079255`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.027885652381746694`], {
             RGBColor[
             0.873192830390407, 0.9017242770380856, 0.9877671057427206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.027885652381746694`], {
             RGBColor[
             0.242785484860208, 0.37251331644986996`, 0.9371376462426264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.027885652381746694`], {
             RGBColor[
             0.21336291477373137`, 0.3415883297902934, 0.9354620744029933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.027885652381746694`], {
             RGBColor[
             0.3386493168091526, 0.46774275003568394`, 0.9427994129046144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.027885652381746694`], {
             RGBColor[
             0.18212992963139682`, 0.3087604821200659, 0.9336834021041983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.027885652381746694`], {
             RGBColor[
             0.22895368331262583`, 0.3579752160364906, 0.9363499456068083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.027885652381746694`], {
             RGBColor[
             0.8276616884309496, 0.21362543547524793`, 0.17412217012187317`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.027885652381746694`], {
             RGBColor[
             0.9925358512363838, 0.9864432654728553, 0.42895165434603927`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.027885652381746694`], {
             RGBColor[
             0.19951285246669712`, 0.3270310361609309, 0.9346733338439388]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.027885652381746694`], {
             RGBColor[
             0.3846257063952153, 0.5075651878546001, 0.9457289877937134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.027885652381746694`], {
             RGBColor[
             0.19666790482252822`, 0.3240408158068105, 0.9345113182843263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.027885652381746694`], {
             RGBColor[
             0.24203296140503872`, 0.3717223665857442, 0.9370947911451132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.027885652381746694`], {
             RGBColor[
             0.2119196850624197, 0.340071403857656, 0.9353798846060012]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.027885652381746694`], {
             RGBColor[
             0.2601817623901309, 0.39079790712151985`, 0.9381283385124692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.027885652381746694`], {
             RGBColor[
             0.3639618362230004, 0.489667182107741, 0.9444123042586827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.027885652381746694`], {
             RGBColor[
             0.1822568035379685, 0.30889383464014303`, 0.9336906273854845]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.027885652381746694`], {
             RGBColor[
             0.20503271821821972`, 0.3328327650454837, 0.9349876820325784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.027885652381746694`], {
             RGBColor[
             0.19159599737019925`, 0.31870991949690686`, 0.9342224806581308]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.027885652381746694`], {
             RGBColor[
             0.18584110899752487`, 0.3126611669362287, 0.9338947482789014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.027885652381746694`], {
             RGBColor[
             0.20069898841488326`, 0.3282777402478373, 0.9347408825314572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.027885652381746694`], {
             RGBColor[
             0.9842583887354778, 0.9877584534482328, 0.9105427668445933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.027885652381746694`], {
             RGBColor[
             0.8215188663850046, 0.16640901342833042`, 0.16823979679335105`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.027885652381746694`], {
             RGBColor[
             0.24658940627570813`, 0.37651147904010834`, 0.9373542739398417]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.027885652381746694`], {
             RGBColor[
             0.1829376663072982, 0.30960946457990146`, 0.9337294015129516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.027885652381746694`], {
             RGBColor[
             0.19009976398754364`, 0.3171372833450601, 0.9341372723804675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.027885652381746694`], {
             RGBColor[
             0.24565388341041777`, 0.3755281851931126, 0.9373009972966455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.027885652381746694`], {
             RGBColor[
             0.2843315036737978, 0.41618081639268795`, 0.9395036305522334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.027885652381746694`], {
             RGBColor[
             0.2587257572717294, 0.3892675534260234, 0.9380454211749428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.027885652381746694`], {
             RGBColor[
             0.19817415326039348`, 0.32562397841667373`, 0.9345970969045678]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.027885652381746694`], {
             RGBColor[
             0.1934487547814754, 0.32065728500776275`, 0.934327992451794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.027885652381746694`], {
             RGBColor[
             0.19479503600678127`, 0.322072311934719, 0.9344046611759306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.027885652381746694`], {
             RGBColor[
             0.183885630512114, 0.31060583506356493`, 0.9337833866720284]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.027885652381746694`], {
             RGBColor[
             0.194697223000598, 0.3219695042635176, 0.9343990908699299]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.027885652381746694`], {
             RGBColor[
             0.22831342724773274`, 0.3573022663177088, 0.9363134839710866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.027885652381746694`], {
             RGBColor[
             0.23972125787035842`, 0.36929261960032556`, 0.9369631430486721]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.027885652381746694`], {
             RGBColor[
             0.8055364749096104, 0.8480104835941301, 0.9812520057187881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.027885652381746694`], {
             RGBColor[
             0.18100426741029385`, 0.3075773397545796, 0.9336192973059745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.027885652381746694`], {
             RGBColor[
             0.20793893985757575`, 0.3358873882535414, 0.9351531870555702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.027885652381746694`], {
             RGBColor[
             0.18369802063003998`, 0.31040864518235156`, 0.9337727025667882]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.027885652381746694`], {
             RGBColor[
             0.23112771995435683`, 0.3602602663888343, 0.9364737537773559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.027885652381746694`], {
             RGBColor[
             0.20120879960667537`, 0.3288135841343073, 0.9347699155246316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.027885652381746694`], {
             RGBColor[
             0.9889946602077696, 0.9897170234186503, 0.8320504914710569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.027885652381746694`], {
             RGBColor[
             0.40260480881009003`, 0.5231377827104023, 0.9468746003012931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.027885652381746694`], {
             RGBColor[
             0.9482538006021336, 0.8325505933258706, 0.2772219972063093]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.027885652381746694`], {
             RGBColor[
             0.8037373305687819, 0.8466049783610714, 0.9810726838248541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.027885652381746694`], {
             RGBColor[
             0.5183980864407423, 0.6198979459970778, 0.9552293428008269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.027885652381746694`], {
             RGBColor[
             0.3482989604247025, 0.47610078633028297`, 0.9434142796629524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.027885652381746694`], {
             RGBColor[
             0.19320352841391442`, 0.32039953654720643`, 0.9343140271729413]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.027885652381746694`], {
             RGBColor[
             0.21627237251575757`, 0.34464635434743823`, 0.9356277637172448]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.027885652381746694`], {
             RGBColor[
             0.7070237961498369, 0.7710516302229059, 0.9714331825533382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.027885652381746694`], {
             RGBColor[
             0.21726621743653565`, 0.3456909483725835, 0.9356843617152213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.027885652381746694`], {
             RGBColor[
             0.9918038536315829, 0.990878697092375, 0.7854948864789351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.027885652381746694`], {
             RGBColor[
             0.18932442036239164`, 0.31632234803540016`, 0.9340931177080333]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.027885652381746694`], {
             RGBColor[
             0.9925852496598342, 0.986548923705669, 0.43432836788688456`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.027885652381746694`], {
             RGBColor[
             0.3764941167365503, 0.5005220135978444, 0.9452108500911456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.027885652381746694`], {
             RGBColor[
             0.19612721011213427`, 0.3234725113841618, 0.9344805265204555]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.027885652381746694`], {
             RGBColor[
             0.17940647345367122`, 0.30589795700018124`, 0.9335283053038692]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.027885652381746694`], {
             RGBColor[
             0.8216043579673015, 0.8605890294596807, 0.9828465511894319]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.027885652381746694`], {
             RGBColor[
             0.5728179374316162, 0.6640784326178184, 0.9595134728173111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.027885652381746694`], {
             RGBColor[
             0.1969643686712329, 0.32435241810869275`, 0.934528201461931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.027885652381746694`], {
             RGBColor[
             0.9697038754518477, 0.9769257804341147, 0.9361676157519565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.027885652381746694`], {
             RGBColor[
             0.46553671991296847`, 0.576982707272407, 0.9510679023901947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.027885652381746694`], {
             RGBColor[
             0.1985117660113969, 0.3259788308238631, 0.9346163234512842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.027885652381746694`], {
             RGBColor[
             0.24853385159996577`, 0.37855521436085726`, 0.9374650072245091]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.027885652381746694`], {
             RGBColor[
             0.18190969424137163`, 0.30852900076141915`, 0.9336708600245455]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.027885652381746694`], {
             RGBColor[
             0.2829350020755027, 0.41471300466956446`, 0.9394241018521495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.027885652381746694`], {
             RGBColor[
             0.1969521059625652, 0.3243395292243824, 0.9345275031188135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.027885652381746694`], {
             RGBColor[
             0.22046571832082573`, 0.34905382666204504`, 0.9358665685573442]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.027885652381746694`], {
             RGBColor[
             0.199051197909799, 0.3265458079510415, 0.9346470432998802]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.027885652381746694`], {
             RGBColor[
             0.20310658273494972`, 0.3308082745285237, 0.9348779914662683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.027885652381746694`], {
             RGBColor[
             0.22915597848204, 0.35818784108579943`, 0.9363614660174375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.027885652381746694`], {
             RGBColor[
             0.7597586089991939, 0.8122484668202457, 0.9766892958633172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.027885652381746694`], {
             RGBColor[
             0.9509849302078126, 0.9629652217205732, 0.9678539073672795]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.027885652381746694`], {
             RGBColor[
             0.21428709115836797`, 0.3425596977667136, 0.935514704880902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.027885652381746694`], {
             RGBColor[
             0.1818888062976524, 0.30850704620819813`, 0.9336696704870515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.027885652381746694`], {
             RGBColor[
             0.2680992625939086, 0.39911970183419715`, 0.9385792284361825]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.027885652381746694`], {
             RGBColor[
             0.18684859723136407`, 0.31372010094843716`, 0.9339521232433733]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.027885652381746694`], {
             RGBColor[
             0.4303958842275222, 0.5472090154169172, 0.9486454230522088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.027885652381746694`], {
             RGBColor[
             0.23222586891438338`, 0.3614144905724877, 0.9365362917360636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.027885652381746694`], {
             RGBColor[
             0.21556902434658207`, 0.3439070908267852, 0.9355877090795206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.027885652381746694`], {
             RGBColor[
             0.5925759149291727, 0.6801188488370776, 0.961068893181775]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.027885652381746694`], {
             RGBColor[
             0.20437042968316516`, 0.3321366578036229, 0.9349499656802752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.027885652381746694`], {
             RGBColor[
             0.3425287629814334, 0.47110293132347947`, 0.9430466077842526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.027885652381746694`], {
             RGBColor[
             0.1791057270796212, 0.3055818534926332, 0.9335111782427814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.027885652381746694`], {
             RGBColor[
             0.24723118250472642`, 0.37718602654776967`, 0.9373908221466615]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.027885652381746694`], {
             RGBColor[
             0.21162927735784165`, 0.3397661669472325, 0.9353633463168451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.027885652381746694`], {
             RGBColor[
             0.2986247548964671, 0.43120392967218313`, 0.9403176100643942]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.027885652381746694`], {
             RGBColor[
             0.1932487717488401, 0.3204470901608064, 0.9343166037139339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.027885652381746694`], {
             RGBColor[
             0.9021660914511284, 0.9248267689496842, 0.9905306012474278]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.027885652381746694`], {
             RGBColor[
             0.387712192347488, 0.5102385468551641, 0.9459256559493198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.027885652381746694`], {
             RGBColor[
             0.8539737461394735, 0.41587144104017043`, 0.19931862629877445`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.027885652381746694`], {
             RGBColor[
             0.34903475823839447`, 0.4767380974142295, 0.9434611640490004]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.027885652381746694`], {
             RGBColor[
             0.19478977051563845`, 0.3220667775696765, 0.9344043613139996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.027885652381746694`], {
             RGBColor[
             0.22404918964109946`, 0.35282028222485723`, 0.936070641947763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.027885652381746694`], {
             RGBColor[
             0.9853022906708313, 0.9881901337255575, 0.8932426102441758]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.027885652381746694`], {
             RGBColor[
             0.1865190623784995, 0.31337373892436005`, 0.9339333567210057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.027885652381746694`], {
             RGBColor[
             0.2230811340648649, 0.3518027944359661, 0.9360155126148064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.027885652381746694`], {
             RGBColor[
             0.3063635945960659, 0.4393379408672382, 0.9407583255366989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.027885652381746694`], {
             RGBColor[
             0.1827503081177702, 0.3094125392435122, 0.9337187317412295]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.027885652381746694`], {
             RGBColor[
             0.8529626688242167, 0.8855932953383124, 0.985837534872859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.027885652381746694`], {
             RGBColor[
             0.8266120846200963, 0.20555772064570646`, 0.17311706832724205`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.027885652381746694`], {
             RGBColor[
             0.1804406002012431, 0.3069848897793021, 0.93358719729229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.027885652381746694`], {
             RGBColor[
             0.1856485479005117, 0.3124587730141891, 0.9338837822092951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.027885652381746694`], {
             RGBColor[
             0.18667779652152947`, 0.3135405785730105, 0.9339423963956253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.027885652381746694`], {
             RGBColor[
             0.9551078718556497, 0.8597247018622127, 0.2827369438226184]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.027885652381746694`], {
             RGBColor[
             0.24002120291967022`, 0.3696078808647668, 0.9369802244755014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.027885652381746694`], {
             RGBColor[
             0.5585316039927765, 0.6524801435401812, 0.9583888003164419]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.027885652381746694`], {
             RGBColor[
             0.3574473894517768, 0.48402469574012214`, 0.9439972094709195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.027885652381746694`], {
             RGBColor[
             0.2397898236287226, 0.36936468655968646`, 0.936967047767177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.027885652381746694`], {
             RGBColor[
             0.41254771032069193`, 0.531749824254125, 0.9475081531933861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.027885652381746694`], {
             RGBColor[
             0.24372417422141443`, 0.37349993848484087`, 0.9371911032130806]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.027885652381746694`], {
             RGBColor[
             0.18936604401309215`, 0.31636609713137825`, 0.934095488113364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.027885652381746694`], {
             RGBColor[
             0.843157812611701, 0.33273543637341757`, 0.18896127613772973`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.027885652381746694`], {
             RGBColor[
             0.22661866237074535`, 0.3555209609776956, 0.9362169696185221]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.027885652381746694`], {
             RGBColor[
             0.1925981967986741, 0.3197632946393477, 0.9342795544329613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.027885652381746694`], {
             RGBColor[
             0.18255935854789945`, 0.309211839138676, 0.9337078574457099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.027885652381746694`], {
             RGBColor[
             0.3393687513351076, 0.46836588806223545`, 0.9428452546364373]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.027885652381746694`], {
             RGBColor[
             0.3039019362504366, 0.4367505818678281, 0.9406181377356125]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.027885652381746694`], {
             RGBColor[
             0.8193361618613183, 0.1496317899920564, 0.1661496364764569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.027885652381746694`], {
             RGBColor[
             0.21566341381177923`, 0.3440063001393452, 0.9355930844199268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.027885652381746694`], {
             RGBColor[
             0.8141109072907318, 0.8547088953383618, 0.982106625005912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.027885652381746694`], {
             RGBColor[
             0.19287402797566439`, 0.32005321069507126`, 0.9342952626104353]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.027885652381746694`], {
             RGBColor[
             0.18340497994045135`, 0.3101006408377411, 0.933756014333031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.027885652381746694`], {
             RGBColor[
             0.17911500115561352`, 0.3055916011345115, 0.9335117063876894]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.027885652381746694`], {
             RGBColor[
             0.335355251737071, 0.46488959643477135`, 0.9425895179910487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.027885652381746694`], {
             RGBColor[
             0.18263620644148504`, 0.30929261114727236`, 0.9337122338195634]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.027885652381746694`], {
             RGBColor[
             0.29264465833089975`, 0.42491846902175034`, 0.9399770524117451]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.027885652381746694`], {
             RGBColor[
             0.2889051941793347, 0.4209880551027343, 0.939764095460355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.027885652381746694`], {
             RGBColor[
             0.30694355404168716`, 0.4399475150161388, 0.940791353369154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.027885652381746694`], {
             RGBColor[
             0.4063466574019441, 0.5263787838898877, 0.9471130275847793]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.027885652381746694`], {
             RGBColor[
             0.3557668224000087, 0.48256907302763663`, 0.9438901252244479]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.027885652381746694`], {
             RGBColor[
             0.4741596199861951, 0.5839831660090739, 0.9517467286706829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.027885652381746694`], {
             RGBColor[
             0.19890345919190142`, 0.32639052519135536`, 0.9346386297984558]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.027885652381746694`], {
             RGBColor[
             0.5812572311839399, 0.6709298314718057, 0.9601778449356456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.027885652381746694`], {
             RGBColor[
             0.24987309085249598`, 0.3799628397279394, 0.9375412749187138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.027885652381746694`], {
             RGBColor[
             0.1991293041825628, 0.32662790259593993`, 0.9346514913365662]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.027885652381746694`], {
             RGBColor[
             0.24721508689536167`, 0.3771691090418067, 0.9373899055255195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.027885652381746694`], {
             RGBColor[
             0.25655300447979307`, 0.38698385248121464`, 0.9379216861177417]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.027885652381746694`], {
             RGBColor[
             0.21032620428650672`, 0.3383965545296549, 0.9352891382331565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.027885652381746694`], {
             RGBColor[
             0.23840666361665402`, 0.3679108976895925, 0.9368882788506916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.027885652381746694`], {
             RGBColor[
             0.20761230953904478`, 0.335544079079207, 0.935134585942136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.027885652381746694`], {
             RGBColor[
             0.2008438754397465, 0.3284300256973365, 0.9347491336331819]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.027885652381746694`], {
             RGBColor[
             0.20565135384863537`, 0.33348299031681494`, 0.9350229124165412]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.027885652381746694`], {
             RGBColor[
             0.18637271886218407`, 0.3132199226099977, 0.9339250226742475]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.027885652381746694`], {
             RGBColor[
             0.1858996679095085, 0.31272271606557295`, 0.9338980831223087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.027885652381746694`], {
             RGBColor[
             0.20187169700218524`, 0.3295103313271106, 0.9348076665506371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.027885652381746694`], {
             RGBColor[
             0.24686136029389427`, 0.3767973199561026, 0.9373697613188575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.027885652381746694`], {
             RGBColor[
             0.1911403477299942, 0.3182310028351955, 0.9341965320851944]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.027885652381746694`], {
             RGBColor[
             0.18214142158537838`, 0.30877256089233246`, 0.9336840565539767]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.027885652381746694`], {
             RGBColor[
             0.19529547244710238`, 0.32259830236299947`, 0.9344331602908775]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.027885652381746694`], {
             RGBColor[
             0.8795463410175769, 0.5459298918751729, 0.22120285316675511`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.027885652381746694`], {
             RGBColor[
             0.19529691214488243`, 0.32259981557664835`, 0.9344332422795363]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.027885652381746694`], {
             RGBColor[
             0.17905422337022397`, 0.30552771982853294`, 0.9335082451827241]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.027885652381746694`], {
             RGBColor[
             0.21499276582137244`, 0.3433014065798891, 0.935554892009008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.027885652381746694`], {
             RGBColor[
             0.22554056397195027`, 0.35438781120517543`, 0.9361555735096144]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.027885652381746694`], {
             RGBColor[
             0.2451744333338886, 0.3750242527637898, 0.93727369332407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.027885652381746694`], {
             RGBColor[
             0.2358064817309028, 0.3651779416666145, 0.9367402023389224]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.027885652381746694`], {
             RGBColor[
             0.19796437105250972`, 0.32540348401522773`, 0.9345851501181738]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.027885652381746694`], {
             RGBColor[
             0.45725872125089195`, 0.5702622550389433, 0.9504162280122078]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.027885652381746694`], {
             RGBColor[
             0.23550398192177388`, 0.3648599951876243, 0.9367229754223009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.027885652381746694`], {
             RGBColor[
             0.18805335571358273`, 0.3149863784993486, 0.9340207324566552]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.027885652381746694`], {
             RGBColor[
             0.3796233347917912, 0.5032323849982215, 0.9454102410985666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.027885652381746694`], {
             RGBColor[
             0.17959143492855675`, 0.30609236323752076`, 0.933538838586238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.027885652381746694`], {
             RGBColor[
             0.41783566912403936`, 0.5363299883890472, 0.947845097252377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.027885652381746694`], {
             RGBColor[
             0.19013667027984396`, 0.3171760741982618, 0.9341393741392161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.027885652381746694`], {
             RGBColor[
             0.18620451936940718`, 0.3130431342786254, 0.9339154439619627]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.027885652381746694`], {
             RGBColor[
             0.18139651046953492`, 0.3079896120794884, 0.9336416349679267]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.027885652381746694`], {
             RGBColor[
             0.18300767959384703`, 0.309683052983163, 0.9337333886660452]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.027885652381746694`], {
             RGBColor[
             0.2268131918331927, 0.35572542377660804`, 0.9362280477836279]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.027885652381746694`], {
             RGBColor[
             0.18842432755960442`, 0.31537629343049095`, 0.9340418587544824]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.027885652381746694`], {
             RGBColor[
             0.19212227783830665`, 0.31926307363699663`, 0.9342524515522274]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.027885652381746694`], {
             RGBColor[
             0.24182762690147153`, 0.3715065470035356, 0.9370830976489003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.027885652381746694`], {
             RGBColor[
             0.18868393066647376`, 0.3156491527555983, 0.9340566427673703]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.027885652381746694`], {
             RGBColor[
             0.21355297767290998`, 0.3417880979480139, 0.9354728982039288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.027885652381746694`], {
             RGBColor[
             0.19254963929720473`, 0.31971225762658, 0.9342767891550869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.027885652381746694`], {
             RGBColor[
             0.2065811071166083, 0.33446021995121644`, 0.9350758604897056]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.027885652381746694`], {
             RGBColor[
             0.21634716160662554`, 0.34472496242384276`, 0.9356320228453292]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.027885652381746694`], {
             RGBColor[
             0.27580922111776024`, 0.4072233570823697, 0.9390182991682543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.027885652381746694`], {
             RGBColor[
             0.2331737072204319, 0.36241072872856434`, 0.9365902697253919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.027885652381746694`], {
             RGBColor[
             0.2121526703486752, 0.34031628616563087`, 0.9353931527733826]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.027885652381746694`], {
             RGBColor[
             0.1840091371887301, 0.310735648411464, 0.9337904201945499]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.027885652381746694`], {
             RGBColor[
             0.2582664433427927, 0.3887847853645258, 0.938019263926184]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.027885652381746694`], {
             RGBColor[
             0.8379281346647119, 0.8736051659010814, 0.9844035275832383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.027885652381746694`], {
             RGBColor[
             0.4554399226734993, 0.5687856724178738, 0.9502730455257168]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.027885652381746694`], {
             RGBColor[
             0.42461827381123246`, 0.5422047396654701, 0.9482772788254231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.027885652381746694`], {
             RGBColor[
             0.844124603334554, 0.8785460618197521, 0.9849945522966208]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.027885652381746694`], {
             RGBColor[
             0.19131157595015044`, 0.3184109745510759, 0.9342062832790229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.027885652381746694`], {
             RGBColor[
             0.8287975688378628, 0.8663247005533589, 0.9835326460637211]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.027885652381746694`], {
             RGBColor[
             0.9887357523774989, 0.9896099583772056, 0.8363412642506296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.027885652381746694`], {
             RGBColor[
             0.19404714705117995`, 0.3212862332234835, 0.9343620700063117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.027885652381746694`], {
             RGBColor[
             0.6657140642559093, 0.738780153701779, 0.9673158145395446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.027885652381746694`], {
             RGBColor[
             0.3275914997751332, 0.4581650247028605, 0.9420948185812503]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.027885652381746694`], {
             RGBColor[
             0.3100095560527289, 0.44293642874469996`, 0.9409745126743612]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.027885652381746694`], {
             RGBColor[
             0.17994083687002446`, 0.30645960683136597`, 0.9335587365099107]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.027885652381746694`], {
             RGBColor[
             0.18515378626434187`, 0.3119387471648751, 0.9338556062660495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.027885652381746694`], {
             RGBColor[
             0.4288884024290853, 0.5459033104513494, 0.9485493676450263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.027885652381746694`], {
             RGBColor[
             0.1915172466480543, 0.31862714749484833`, 0.934217995921006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.027885652381746694`], {
             RGBColor[
             0.2944180010032382, 0.4267823646067975, 0.9400780416535094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.027885652381746694`], {
             RGBColor[
             0.2650455441851616, 0.3959100501696741, 0.9384053236903759]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.027885652381746694`], {
             RGBColor[
             0.2456807114445148, 0.37555638315794415`, 0.9373025251134988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.027885652381746694`], {
             RGBColor[
             0.23248905082520588`, 0.3616911114474591, 0.9365512795565422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.027885652381746694`], {
             RGBColor[
             0.5777795176543054, 0.6681064669592394, 0.9599040665873084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.027885652381746694`], {
             RGBColor[
             0.3254133616442444, 0.45627843093029025`, 0.9419560295456021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.027885652381746694`], {
             RGBColor[
             0.8789213821202363, 0.5430920994852084, 0.22068137214366979`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.027885652381746694`], {
             RGBColor[
             0.7060709713767632, 0.7703072762684443, 0.9713382138846121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.027885652381746694`], {
             RGBColor[
             0.21581639795358076`, 0.3441670961721334, 0.9356017966404827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.027885652381746694`], {
             RGBColor[
             0.2082469591636211, 0.3362111360737471, 0.9351707282993756]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.027885652381746694`], {
             RGBColor[
             0.5602763464580424, 0.6538966040732364, 0.9585261528345099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.027885652381746694`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.027885652381746694`], {
             RGBColor[
             0.17970434930417156`, 0.30621104340547683`, 0.9335452688928874]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.027885652381746694`], {
             RGBColor[
             0.36991176607450643`, 0.49482071229294583`, 0.9447914285275043]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.027885652381746694`], {
             RGBColor[
             0.9510874915293103, 0.9630417117862173, 0.9676802978022608]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.027885652381746694`], {
             RGBColor[
             0.8592163258347785, 0.4536160411257659, 0.20423899016395516`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.027885652381746694`], {
             RGBColor[
             0.4977475489543879, 0.6031329093695432, 0.9536036568444898]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.027885652381746694`], {
             RGBColor[
             0.2084820527788493, 0.336458234369148, 0.9351841165329731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.027885652381746694`], {
             RGBColor[
             0.19190461331519068`, 0.3190342944224739, 0.9342400558796418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.027885652381746694`], {
             RGBColor[
             0.2739918424465178, 0.40531317687043084`, 0.9389148021414978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.027885652381746694`], {
             RGBColor[
             0.22400797509009437`, 0.3527769631185974, 0.9360682948400547]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.027885652381746694`], {
             RGBColor[
             0.19792175174780763`, 0.3253586884237658, 0.9345827230118207]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.027885652381746694`], {
             RGBColor[
             0.2211253737681676, 0.3497471663617724, 0.9359041349591976]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.027885652381746694`], {
             RGBColor[
             0.19120668731506069`, 0.31830072994527303`, 0.9342003100264233]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.027885652381746694`], {
             RGBColor[
             0.19035994618760685`, 0.3174107513338308, 0.934152089371856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.027885652381746694`], {
             RGBColor[
             0.9703310152107799, 0.9773935002394792, 0.9351060317243296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.027885652381746694`], {
             RGBColor[
             0.24693624036742998`, 0.3768760236610595, 0.9373740256282702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.027885652381746694`], {
             RGBColor[
             0.19324911536591247`, 0.3204474513241361, 0.9343166232824178]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.027885652381746694`], {
             RGBColor[
             0.5096359477486948, 0.612784447077024, 0.9545395551462174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.027885652381746694`], {
             RGBColor[
             0.18222514168352894`, 0.3088605560236495, 0.9336888242897137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.027885652381746694`], {
             RGBColor[
             0.20088219976865415`, 0.32847030699692126`, 0.9347513161470175]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.027885652381746694`], {
             RGBColor[
             0.5071373117219987, 0.6107559417882819, 0.9543428533653905]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.027885652381746694`], {
             RGBColor[
             0.17933281357579656`, 0.305820535798229, 0.9335241104827943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.027885652381746694`], {
             RGBColor[
             0.28091140737960196`, 0.41258607834085864`, 0.939308861127858]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.027885652381746694`], {
             RGBColor[
             0.3403985574835718, 0.4692578543884732, 0.9429108729735957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.027885652381746694`], {
             RGBColor[
             0.23139395253121084`, 0.36054009370722817`, 0.9364889153287519]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.027885652381746694`], {
             RGBColor[
             0.18235944175044905`, 0.3090017139090986, 0.9336964724798456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.027885652381746694`], {
             RGBColor[
             0.19489410730752896`, 0.3221764421532881, 0.9344103031399453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.027885652381746694`], {
             RGBColor[
             0.2167015948028579, 0.34509749418544555`, 0.9356522072915177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.027885652381746694`], {
             RGBColor[
             0.8173387448883187, 0.1342787678638822, 0.16423690772735258`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.027885652381746694`], {
             RGBColor[
             0.1829127869860106, 0.3095833148357881, 0.9337279846724099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.027885652381746694`], {
             RGBColor[
             0.18362197162651986`, 0.31032871285786656`, 0.9337683716885422]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.027885652381746694`], {
             RGBColor[
             0.19372013073248498`, 0.3209425183385029, 0.9343434469107393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.027885652381746694`], {
             RGBColor[
             0.1849258667142184, 0.3116991892667612, 0.9338426265848467]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.027885652381746694`], {
             RGBColor[
             0.20594129701488287`, 0.33378773896799957`, 0.9350394242509266]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.027885652381746694`], {
             RGBColor[
             0.8251923969012658, 0.19464537872765014`, 0.17175757376438203`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.027885652381746694`], {
             RGBColor[
             0.1870776850955973, 0.3139608868187558, 0.9339651694583363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.027885652381746694`], {
             RGBColor[
             0.37418878878290995`, 0.4985252543935531, 0.9450639566324611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.027885652381746694`], {
             RGBColor[
             0.9923039511135691, 0.9910855002530954, 0.777206976991627]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.027885652381746694`], {
             RGBColor[
             0.9694202648664492, 0.9767142641238943, 0.9366476944955487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.027885652381746694`], {
             RGBColor[
             0.23765262088408304`, 0.3671183509685898, 0.9368453372325779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.027885652381746694`], {
             RGBColor[
             0.8954246210317355, 0.9194513034296, 0.9898875937806444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.027885652381746694`], {
             RGBColor[
             0.1889310324973132, 0.31590887244697147`, 0.9340707148510822]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.027885652381746694`], {
             RGBColor[
             0.18920356017618423`, 0.31619531631671777`, 0.9340862348992254]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.027885652381746694`], {
             RGBColor[
             0.36433321534571095`, 0.4899888520377754, 0.9444359682079841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.027885652381746694`], {
             RGBColor[
             0.30183205672017543`, 0.43457500724358145`, 0.9405002611584765]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.027885652381746694`], {
             RGBColor[
             0.2599789274537134, 0.39058471474286727`, 0.9381167873629076]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.027885652381746694`], {
             RGBColor[
             0.19899652547638796`, 0.32648834375709396`, 0.934643929785678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.027885652381746694`], {
             RGBColor[
             0.6582217134144572, 0.7329270722804612, 0.9665690470276681]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.027885652381746694`], {
             RGBColor[
             0.19756403157199334`, 0.32498270183821587`, 0.9345623513770076]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.027885652381746694`], {
             RGBColor[
             0.187660141527025, 0.31457308545805707`, 0.933998339490439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.027885652381746694`], {
             RGBColor[
             0.3534033382914345, 0.480521941884955, 0.9437395261069965]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.027885652381746694`], {
             RGBColor[
             0.20794500379241626`, 0.3358937618335345, 0.9351535323876885]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.027885652381746694`], {
             RGBColor[
             0.8200027527924696, 0.15475549999089333`, 0.1667879647049341]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.027885652381746694`], {
             RGBColor[
             0.19665135271400355`, 0.3240234184912868, 0.9345103756662324]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.027885652381746694`], {
             RGBColor[
             0.5240458703783706, 0.6244830714274116, 0.9556739570409113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.027885652381746694`], {
             RGBColor[
             0.20313982636998706`, 0.33084321569671615`, 0.9348798846421041]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.027885652381746694`], {
             RGBColor[
             0.194144227344503, 0.3213882707670121, 0.934367598585399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.027885652381746694`], {
             RGBColor[
             0.37904525788294496`, 0.5027316838347692, 0.9453734065491083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.027885652381746694`], {
             RGBColor[
             0.1851145385676597, 0.3118974953472144, 0.9338533711677852]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.027885652381746694`], {
             RGBColor[
             0.1880939032775767, 0.3150289965599703, 0.9340230415804399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.027885652381746694`], {
             RGBColor[
             0.1990369147875074, 0.3265307954839108, 0.9346462298971957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.027885652381746694`], {
             RGBColor[
             0.2089289786028837, 0.3369279817469421, 0.9352095682974844]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.027885652381746694`], {
             RGBColor[
             0.39875120665503094`, 0.5197999862113661, 0.9466290521795794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.027885652381746694`], {
             RGBColor[
             0.31502354175322494`, 0.44727929114822085`, 0.9412939994095033]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.027885652381746694`], {
             RGBColor[
             0.9319225428018962, 0.7678025982169813, 0.26408148383634866`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.027885652381746694`], {
             RGBColor[
             0.7398648594018855, 0.7967073184367315, 0.9747064728211174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.027885652381746694`], {
             RGBColor[
             0.18427610046840573`, 0.31101624374485265`, 0.9338056233583907]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.027885652381746694`], {
             RGBColor[
             0.3212434064694567, 0.45266662534593033`, 0.9416903236892111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.027885652381746694`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.027885652381746694`], {
             RGBColor[
             0.2137339467700851, 0.34197830794324846`, 0.935483204126293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.027885652381746694`], {
             RGBColor[
             0.4742143938317012, 0.5840276338843894, 0.9517510406684443]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.027885652381746694`], {
             RGBColor[
             0.25752973177491306`, 0.38801045479647306`, 0.9379773092922603]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.027885652381746694`], {
             RGBColor[
             0.1954605501868454, 0.3227718095340026, 0.9344425612239453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.027885652381746694`], {
             RGBColor[
             0.8194918846006688, 0.15082874320484374`, 0.1662987567475226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.027885652381746694`], {
             RGBColor[
             0.3141297509318431, 0.44650513446197276`, 0.941237047848713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.027885652381746694`], {
             RGBColor[
             0.20973292712492791`, 0.3377729826168909, 0.9352553519764795]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.027885652381746694`], {
             RGBColor[
             0.18590102371033476`, 0.3127241410982041, 0.9338981603331601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.027885652381746694`], {
             RGBColor[
             0.17907641669607907`, 0.3055510464211448, 0.9335095090597996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.027885652381746694`], {
             RGBColor[
             0.2965600408339725, 0.42903378428206873`, 0.9402000276530058]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.027885652381746694`], {
             RGBColor[
             0.20546571259734456`, 0.33328786959137313`, 0.9350123404219118]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.027885652381746694`], {
             RGBColor[
             0.18838969891108812`, 0.3153398965253172, 0.9340398867041779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.027885652381746694`], {
             RGBColor[
             0.19616100168040002`, 0.3235080284649182, 0.934482450900278]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.027885652381746694`], {
             RGBColor[
             0.24986810421890843`, 0.3799575984598681, 0.937540990937308]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.027885652381746694`], {
             RGBColor[
             0.19470143524485908`, 0.32197393159930776`, 0.9343993307510091]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.027885652381746694`], {
             RGBColor[
             0.8939300581111314, 0.611242991794526, 0.23320497928678602`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.027885652381746694`], {
             RGBColor[
             0.2822705085644714, 0.4140145798581486, 0.9393862599297264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.027885652381746694`], {
             RGBColor[
             0.29805944165302733`, 0.4306097496103981, 0.9402854163114862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.027885652381746694`], {
             RGBColor[
             0.22229995450050422`, 0.350981725184178, 0.9359710255942676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.027885652381746694`], {
             RGBColor[
             0.17902996710188124`, 0.3055022249525685, 0.933506863824126]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.027885652381746694`], {
             RGBColor[
             0.212847764567014, 0.3410468742606238, 0.9354327373608172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.027885652381746694`], {
             RGBColor[
             0.6973666945960665, 0.7635074290924103, 0.9704706529212034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.027885652381746694`], {
             RGBColor[
             0.8265166883216026, 0.20482446289255998`, 0.17302571672406986`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.027885652381746694`], {
             RGBColor[
             0.2025961788233211, 0.3302718076559249, 0.934848924718576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.027885652381746694`], {
             RGBColor[
             0.5478165382686445, 0.6437811704771209, 0.9575452710920592]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.027885652381746694`], {
             RGBColor[
             0.28461757525764775`, 0.41648149576530025`, 0.9395199219057286]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.027885652381746694`], {
             RGBColor[
             0.18275376889499648`, 0.30941617673980293`, 0.9337189288273728]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.027885652381746694`], {
             RGBColor[
             0.1811098371299533, 0.3076883002234485, 0.9336253093453327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.027885652381746694`], {
             RGBColor[
             0.7121412574025138, 0.7750494298476431, 0.9719432432656107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.027885652381746694`], {
             RGBColor[
             0.18850413369751906`, 0.3154601747414406, 0.9340464035959741]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.027885652381746694`], {
             RGBColor[
             0.21345649486519924`, 0.3416866883997466, 0.9354674036507632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.027885652381746694`], {
             RGBColor[
             0.8324443832728455, 0.2503873238203034, 0.17870208410375396`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.027885652381746694`], {
             RGBColor[
             0.18370800885926494`, 0.3104191434445573, 0.9337732713816664]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.027885652381746694`], {
             RGBColor[
             0.18455342051778426`, 0.3113077246998561, 0.9338214163249446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.027885652381746694`], {
             RGBColor[
             0.1951112049063669, 0.3224046254944496, 0.9344226665270321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.027885652381746694`], {
             RGBColor[
             0.42062186552277797`, 0.5387432516713317, 0.9480226312231679]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.027885652381746694`], {
             RGBColor[
             0.1856877903127057, 0.31250001927751764`, 0.9338860170066157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.027885652381746694`], {
             RGBColor[
             0.23827199083861747`, 0.36776934806112876`, 0.9368806094352129]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.027885652381746694`], {
             RGBColor[
             0.24157157412247404`, 0.37123741929812537`, 0.9370685158219325]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.027885652381746694`], {
             RGBColor[
             0.18576331458524015`, 0.3125794000764668, 0.9338903180022083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.027885652381746694`], {
             RGBColor[
             0.2313516506730186, 0.3604956317721754, 0.9364865063005079]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.027885652381746694`], {
             RGBColor[
             0.2623389378177228, 0.3930652352687406, 0.9382511864618155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.027885652381746694`], {
             RGBColor[
             0.18870039039885345`, 0.3156664529779366, 0.9340575801247794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.027885652381746694`], {
             RGBColor[
             0.24096885499463874`, 0.3706039232801706, 0.9370341918592453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.027885652381746694`], {
             RGBColor[
             0.8178049183525352, 0.13786198138836525`, 0.164683315963154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.027885652381746694`], {
             RGBColor[
             0.9537765326908467, 0.9650471942815904, 0.9631284525300384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.027885652381746694`], {
             RGBColor[
             0.9602115875305376, 0.8774464833562946, 0.2999299602777051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.027885652381746694`], {
             RGBColor[
             0.1982643030525542, 0.3257187315640616, 0.9346022308018668]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.027885652381746694`], {
             RGBColor[
             0.23480104226620413`, 0.36412116104067216`, 0.9366829440488222]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.027885652381746694`], {
             RGBColor[
             0.956979221732861, 0.9674357545252026, 0.9577071353769899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.027885652381746694`], {
             RGBColor[
             0.21013611726343454`, 0.33819676101619267`, 0.9352783130584011]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.027885652381746694`], {
             RGBColor[
             0.38195753878243316`, 0.5052541551744117, 0.9455589745127948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.027885652381746694`], {
             RGBColor[
             0.27139200070452485`, 0.4025805783601091, 0.9387667450004126]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.027885652381746694`], {
             RGBColor[
             0.24934350578881678`, 0.3794062122483802, 0.9375111158327881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.027885652381746694`], {
             RGBColor[
             0.18639411010760892`, 0.31324240616522253`, 0.9339262408740289]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.027885652381746694`], {
             RGBColor[
             0.20071986914810575`, 0.3282996872223691, 0.9347420716583239]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.027885652381746694`], {
             RGBColor[
             0.1915625031716876, 0.3186747149706162, 0.9342205732130758]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.027885652381746694`], {
             RGBColor[
             0.8280837295399454, 0.865755504473851, 0.9834645594342339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.027885652381746694`], {
             RGBColor[
             0.20342618893072584`, 0.3311442009044876, 0.9348961925663027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.027885652381746694`], {
             RGBColor[
             0.18432439621433888`, 0.3110670056359555, 0.9338083737296745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.027885652381746694`], {
             RGBColor[
             0.20110409825488346`, 0.3287035363751249, 0.9347639529375389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.027885652381746694`], {
             RGBColor[
             0.19841472542917707`, 0.32587683501922177`, 0.9346107971336854]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.027885652381746694`], {
             RGBColor[
             0.3485452682138572, 0.4763141257574593, 0.943429974177476]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.027885652381746694`], {
             RGBColor[
             0.3095548228305918, 0.44254256168324113`, 0.9409455374755513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.027885652381746694`], {
             RGBColor[
             0.18638553952238943`, 0.3132333979367503, 0.9339257527918797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.027885652381746694`], {
             RGBColor[
             0.9932598001133134, 0.9879917189181485, 0.507749021905247]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.027885652381746694`], {
             RGBColor[
             0.19610120868731518`, 0.3234451822380914, 0.9344790457777777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.027885652381746694`], {
             RGBColor[
             0.2081404760074813, 0.3360992155252221, 0.9351646642411613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.027885652381746694`], {
             RGBColor[
             0.9453835605713274, 0.9587877294170835, 0.9773355650906732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.027885652381746694`], {
             RGBColor[
             0.18600360463112436`, 0.31283196014996, 0.9339040021648441]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.027885652381746694`], {
             RGBColor[
             0.2775970966062373, 0.4091025275786123, 0.9391201160323983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.027885652381746694`], {
             RGBColor[
             0.32568965645452963`, 0.4565177436079784, 0.9419736348065956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.027885652381746694`], {
             RGBColor[
             0.6627555094400547, 0.736468908193784, 0.9670209334447669]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.027885652381746694`], {
             RGBColor[
             0.40957405763887067`, 0.529174195761261, 0.9473186746739982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.027885652381746694`], {
             RGBColor[
             0.7912709059084366, 0.8368661126680731, 0.979830147120073]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.027885652381746694`], {
             RGBColor[
             0.3745258073527012, 0.4988171629396605, 0.9450854311577144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.027885652381746694`], {
             RGBColor[
             0.92133834354613, 0.7258397751431882, 0.2555651886720716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.027885652381746694`], {
             RGBColor[
             0.30601698137869693`, 0.43897362839923615`, 0.940738586426738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.027885652381746694`], {
             RGBColor[
             0.9933000584574108, 0.9880778274454297, 0.5121308942145434]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.027885652381746694`], {
             RGBColor[
             0.1860930553658944, 0.31292597854370746`, 0.9339090962518588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.027885652381746694`], {
             RGBColor[
             0.1838330998850932, 0.3105506220439319, 0.9337803951305317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.027885652381746694`], {
             RGBColor[
             0.1804054273287139, 0.30694792086018496`, 0.933585194249233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.027885652381746694`], {
             RGBColor[
             0.18554668841356567`, 0.31235171223514435`, 0.9338779814622011]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.027885652381746694`], {
             RGBColor[
             0.18003320207443918`, 0.306556688517498, 0.93356399657166]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.027885652381746694`], {
             RGBColor[
             0.179946795179367, 0.3064658693922636, 0.9335590758268132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.027885652381746694`], {
             RGBColor[
             0.19798515205544082`, 0.3254253261669, 0.934586333565548]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.027885652381746694`], {
             RGBColor[
             0.1836365577609456, 0.3103440438099624, 0.9337692023473195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.027885652381746694`], {
             RGBColor[
             0.20279567675606608`, 0.3304814926321394, 0.9348602858307151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.027885652381746694`], {
             RGBColor[
             0.28617898913701123`, 0.4181226407518692, 0.9396088421162536]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.027885652381746694`], {
             RGBColor[
             0.25469411239970985`, 0.38503003904448196`, 0.9378158249637654]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.027885652381746694`], {
             RGBColor[
             0.24023703411797065`, 0.3698347331386689, 0.9369925157429511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.027885652381746694`], {
             RGBColor[
             0.18246816409549027`, 0.30911598798713175`, 0.9337026640565553]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.027885652381746694`], {
             RGBColor[
             0.7203821791624184, 0.7814873005598058, 0.9727646213308456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.027885652381746694`], {
             RGBColor[
             0.1893487791980019, 0.3163479507160659, 0.9340945049076855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.027885652381746694`], {
             RGBColor[
             0.3220959675484921, 0.453405070901625, 0.9417446481272771]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.027885652381746694`], {
             RGBColor[
             0.3583175561905998, 0.4847783904334387, 0.944052655726059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.027885652381746694`], {
             RGBColor[
             0.9335847383251342, 0.7743926495727972, 0.2654189253710895]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.027885652381746694`], {
             RGBColor[
             0.9944175835604394, 0.9904681006416884, 0.633766605113725]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.027885652381746694`], {
             RGBColor[
             0.3419268933615933, 0.4705816221096207, 0.9430082571842888]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.027885652381746694`], {
             RGBColor[
             0.18554205504628538`, 0.3123468422723603, 0.933877717598789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.027885652381746694`], {
             RGBColor[
             0.2707814877613013, 0.40193889054802484`, 0.938731977191469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.027885652381746694`], {
             RGBColor[
             0.9931232770303468, 0.9876997098482838, 0.4928893268471293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.027885652381746694`], {
             RGBColor[
             0.21298290042549683`, 0.3411889106159976, 0.9354404331480423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.027885652381746694`], {
             RGBColor[
             0.8202342132018924, 0.1565346061243149, 0.16700961145439447`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.027885652381746694`], {
             RGBColor[
             0.2030621295519029, 0.3307615514146469, 0.9348754599232564]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.027885652381746694`], {
             RGBColor[
             0.7219717591850786, 0.7827290925547635, 0.9729230558120345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.027885652381746694`], {
             RGBColor[
             0.35762511408731845`, 0.48417863188672844`, 0.9440085339275405]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.027885652381746694`], {
             RGBColor[
             0.4386808762090538, 0.554385059055515, 0.9491733354151413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.027885652381746694`], {
             RGBColor[
             0.18439801323969868`, 0.31114438179719767`, 0.9338125661103621]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.027885652381746694`], {
             RGBColor[
             0.36417957475425095`, 0.48985577627965343`, 0.9444261783653554]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.027885652381746694`], {
             RGBColor[
             0.1808071689883251, 0.3073701768163288, 0.9336080728424244]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.027885652381746694`], {
             RGBColor[
             0.3593758114062829, 0.48569499791180964`, 0.944120086812624]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.027885652381746694`], {
             RGBColor[
             0.8221152183090297, 0.17099283563946593`, 0.16881086406928056`]},
             StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{{3.8349502435193233`*^9, 3.8349502581408367`*^9}, 
   3.8349577843740606`*^9, 3.8350239210086985`*^9},
 CellLabel->
  "Out[180]=",ExpressionUUID->"dc0b7e4d-ff83-4334-99df-19cc2dcc1f2b"]
}, Open  ]],

Cell["Estimated with Max-Min Deviation v Calculated: (r = 6)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 3.8349503922098827`*^9}, {3.8349504781120467`*^9, 
  3.834950521977162*^9}},ExpressionUUID->"2d687918-5d18-40cb-8f85-\
c0ac4ced7136"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphin4", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsi4", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}], 
     "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"mMDi6400", ",", "kri4"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502554527807`*^9}, {3.8349505249112787`*^9, 3.834950525026289*^9}, {
   3.834957796266032*^9, 3.834957804349044*^9}},
 CellLabel->
  "In[181]:=",ExpressionUUID->"8e32d1cf-cb5f-48d2-9db4-743db5002b99"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN3AuYzmXewPH7z7a1WxZbu0o1DqFsy5TT0CKyGGKYrMNM4zSN46CIkAnD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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[37, 104] -> 
             RGBColor[
              0.9943421694915254, 0.9919283559322034, 0.7434284237288136], 
             UndirectedEdge[119, 243] -> 
             RGBColor[
              0.9693975254237287, 0.9766973050847457, 0.936686186440678], 
             UndirectedEdge[165, 226] -> 
             RGBColor[
              0.9943646186440678, 0.9911655932203389, 0.6869367881355932], 
             UndirectedEdge[235, 261] -> 
             RGBColor[0.9898175, 0.9803278305084746, 0.5934689237288135], 
             UndirectedEdge[56, 198] -> 
             RGBColor[
              0.8778211016949153, 0.5380959830508475, 0.21976327118644068`], 
             UndirectedEdge[50, 254] -> 
             RGBColor[
              0.9769608050847457, 0.9798721694915253, 0.7919133983050847], 
             UndirectedEdge[249, 268] -> 
             RGBColor[
              0.5832377118644068, 0.6375270254237289, 0.6698147033898305], 
             UndirectedEdge[38, 224] -> 
             RGBColor[
              0.9077532288135592, 0.5942106949152541, 0.495205313559322], 
             UndirectedEdge[79, 87] -> 
             RGBColor[
              0.9261968305084747, 0.7374332372881356, 0.2735270593220339], 
             UndirectedEdge[38, 311] -> 
             RGBColor[
              0.9066254322033898, 0.5937443220338983, 0.5138958220338984], 
             UndirectedEdge[37, 145] -> 
             RGBColor[
              0.9946472288135593, 0.9917700677966101, 0.7176971610169492], 
             UndirectedEdge[147, 359] -> 
             RGBColor[
              0.9648175338983052, 0.8905516101694915, 0.524708847457627], 
             UndirectedEdge[192, 349] -> 
             RGBColor[
              0.9795373389830508, 0.9418228305084746, 0.44421932203389836`], 
             UndirectedEdge[213, 308] -> 
             RGBColor[
              0.962564186440678, 0.9714136440677966, 0.9398625254237288], 
             UndirectedEdge[262, 397] -> 
             RGBColor[
              0.8910515084745763, 0.5472080847457624, 0.22864865254237282`], 
             UndirectedEdge[129, 364] -> 
             RGBColor[
              0.9111080762711865, 0.9279776440677966, 0.8069427118644068], 
             UndirectedEdge[54, 83] -> 
             RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             UndirectedEdge[13, 277] -> 
             RGBColor[
              0.937860533898305, 0.8033932542372882, 0.5776536101694916], 
             UndirectedEdge[191, 235] -> 
             RGBColor[
              0.9926716016949153, 0.9894902711864407, 0.6441065508474575], 
             UndirectedEdge[54, 214] -> 
             RGBColor[
              0.9875753898305084, 0.9891301186440679, 0.8555714745762713], 
             UndirectedEdge[87, 176] -> 
             RGBColor[
              0.9373446271186441, 0.775037372881356, 0.3168341440677966], 
             UndirectedEdge[16, 377] -> 
             RGBColor[
              0.9551625932203389, 0.8479322372881355, 0.41029961864406783`], 
             UndirectedEdge[158, 344] -> 
             RGBColor[
              0.9661096186440677, 0.9444313559322033, 0.6508836355932202], 
             UndirectedEdge[95, 228] -> 
             RGBColor[
              0.9420044915254238, 0.7961967288135594, 0.3207224491525424], 
             UndirectedEdge[193, 283] -> 
             RGBColor[
              0.9823856355932203, 0.955258406779661, 0.5645975338983049], 
             UndirectedEdge[11, 366] -> 
             RGBColor[
              0.955727813559322, 0.8491411864406779, 0.47182036440677977`], 
             UndirectedEdge[106, 231] -> 
             RGBColor[
              0.8826887881355933, 0.8278300338983051, 0.6260242627118644], 
             UndirectedEdge[76, 388] -> 
             RGBColor[
              0.8910515084745763, 0.5472080847457624, 0.22864865254237282`], 
             UndirectedEdge[208, 351] -> 
             RGBColor[
              0.9075365593220339, 0.6231713898305085, 0.26830506779661006`], 
             UndirectedEdge[208, 225] -> 
             RGBColor[
              0.9186703559322034, 0.6592166779661018, 0.44009520338983066`], 
             UndirectedEdge[163, 374] -> 
             RGBColor[
              0.9270259152542373, 0.7483891016949151, 0.26014154237288134`], 
             UndirectedEdge[165, 288] -> 
             RGBColor[
              0.9100312711864407, 0.5943806779661016, 0.4013326610169491], 
             UndirectedEdge[110, 239] -> 
             RGBColor[
              0.9868013389830508, 0.9879907288135594, 0.8317095762711864], 
             UndirectedEdge[14, 273] -> 
             RGBColor[
              0.9941044576271186, 0.9897983559322034, 0.599684779661017], 
             UndirectedEdge[231, 372] -> 
             RGBColor[
              0.9436100254237287, 0.8760466610169491, 0.6193426779661018], 
             UndirectedEdge[5, 162] -> 
             RGBColor[
              0.9504665254237288, 0.8282819322033899, 0.46758700847457635`], 
             UndirectedEdge[36, 90] -> 
             RGBColor[
              0.9813270762711863, 0.9823411186440678, 0.7220449237288135], 
             UndirectedEdge[258, 328] -> 
             RGBColor[
              0.9941044576271186, 0.9897983559322034, 0.599684779661017], 
             UndirectedEdge[91, 208] -> 
             RGBColor[
              0.9075365593220339, 0.6231713898305085, 0.26830506779661006`], 
             UndirectedEdge[155, 370] -> 
             RGBColor[
              0.975286313559322, 0.9413245762711865, 0.6062333644067797], 
             UndirectedEdge[66, 243] -> 
             RGBColor[
              0.9784864576271186, 0.9829137118644068, 0.8961288305084747], 
             UndirectedEdge[253, 334] -> 
             RGBColor[
              0.9726846949152543, 0.9195212033898306, 0.34838562711864407`], 
             UndirectedEdge[50, 210] -> 
             RGBColor[
              0.987251813559322, 0.9674967288135593, 0.5038510847457626], 
             UndirectedEdge[239, 365] -> 
             RGBColor[
              0.9872293644067797, 0.9682594915254237, 0.560342720338983], 
             UndirectedEdge[13, 51] -> 
             RGBColor[
              0.9845457457627118, 0.9870579830508475, 0.869090593220339], 
             UndirectedEdge[258, 300] -> 
             RGBColor[
              0.972029313559322, 0.9761942711864406, 0.800261127118644], 
             UndirectedEdge[30, 294] -> 
             RGBColor[
              0.9875753898305084, 0.9891301186440679, 0.8555714745762714], 
             UndirectedEdge[31, 292] -> 
             RGBColor[
              0.9909587796610169, 0.9905292372881356, 0.7994999491525425], 
             UndirectedEdge[203, 216] -> 
             RGBColor[
              0.9859759576271186, 0.9854145423728814, 0.6829368220338982], 
             UndirectedEdge[64, 233] -> 
             RGBColor[
              0.9943646186440678, 0.9911655932203389, 0.6869367881355932], 
             UndirectedEdge[50, 242] -> 
             RGBColor[
              0.9946696779661017, 0.9910073050847458, 0.6612055254237288], 
             UndirectedEdge[133, 398] -> 
             RGBColor[
              0.9929542118644068, 0.9900947457627118, 0.6748669237288135], 
             UndirectedEdge[7, 390] -> 
             RGBColor[
              0.9442735677966102, 0.8068645084745764, 0.5080629661016949], 
             UndirectedEdge[186, 342] -> 
             RGBColor[
              0.9801165593220339, 0.9445906271186439, 0.3772570169491524], 
             UndirectedEdge[347, 398] -> 
             RGBColor[
              0.8948605508474576, 0.9148378474576271, 0.7746079322033899], 
             UndirectedEdge[321, 375] -> 
             RGBColor[
              0.9904025254237288, 0.9788224915254238, 0.45676603389830495`], 
             UndirectedEdge[149, 279] -> 
             RGBColor[
              0.9431457711864406, 0.8063981355932204, 0.5267534745762712], 
             UndirectedEdge[38, 306] -> 
             RGBColor[
              0.8816119830508475, 0.4942330677966101, 0.22041421186440677`], 
             UndirectedEdge[12, 358] -> 
             RGBColor[
              0.975286313559322, 0.9413245762711865, 0.6062333644067797], 
             UndirectedEdge[139, 378] -> 
             RGBColor[
              0.9826880508474576, 0.953148593220339, 0.3971342711864405], 
             UndirectedEdge[272, 374] -> 
             RGBColor[
              0.9483099491525424, 0.8256306101694915, 0.3144659237288135], 
             UndirectedEdge[21, 114] -> 
             RGBColor[
              0.9923916355932203, 0.9908373220338984, 0.7550781779661018], 
             UndirectedEdge[250, 321] -> 
             RGBColor[
              0.993256627118644, 0.9879849322033899, 0.5074036610169489], 
             UndirectedEdge[19, 152] -> 
             RGBColor[0.9636785, 0.9621449830508475, 0.6964504830508474], 
             UndirectedEdge[270, 336] -> 
             RGBColor[
              0.964466033898305, 0.9730194067796609, 0.9450339152542373], 
             UndirectedEdge[87, 277] -> 
             RGBColor[
              0.8918006949152543, 0.6015740508474576, 0.23142818644067797`], 
             UndirectedEdge[37, 377] -> 
             RGBColor[
              0.9554227542372882, 0.8492994745762712, 0.4975516271186441], 
             UndirectedEdge[312, 356] -> 
             RGBColor[
              0.9711814830508474, 0.9743808474576271, 0.7079800084745762], 
             UndirectedEdge[294, 343] -> 
             RGBColor[
              0.9864475932203389, 0.9886637457627119, 0.8742619830508476], 
             UndirectedEdge[170, 349] -> 
             RGBColor[
              0.9792547288135593, 0.9412183559322034, 0.4134589491525423], 
             UndirectedEdge[176, 390] -> 
             RGBColor[0.9898175, 0.9803278305084746, 0.5934689237288135], 
             UndirectedEdge[235, 327] -> 
             RGBColor[
              0.9923889915254238, 0.9888857966101695, 0.6133461779661016], 
             UndirectedEdge[271, 400] -> 
             RGBColor[
              0.9588325254237289, 0.8673491186440678, 0.3229326355932203], 
             UndirectedEdge[45, 103] -> 
             RGBColor[
              0.9909587796610169, 0.9905292372881356, 0.7994999491525423], 
             UndirectedEdge[30, 343] -> 
             RGBColor[
              0.9864475932203389, 0.9886637457627119, 0.8742619830508476], 
             UndirectedEdge[200, 234] -> 
             RGBColor[
              0.9595562457627118, 0.8696923559322034, 0.5204754915254237], 
             UndirectedEdge[282, 382] -> 
             RGBColor[
              0.9938218474576271, 0.9891938813559322, 0.568924406779661], 
             UndirectedEdge[305, 382] -> 
             RGBColor[
              0.9871063983050847, 0.9878324406779662, 0.8059783135593221], 
             UndirectedEdge[50, 164] -> 
             RGBColor[
              0.945423813559322, 0.8065681186440679, 0.43288082203389827`], 
             UndirectedEdge[259, 287] -> 
             RGBColor[
              0.9941044576271186, 0.9897983559322034, 0.599684779661017], 
             UndirectedEdge[90, 95] -> 
             RGBColor[
              0.9329290423728813, 0.7997153559322034, 0.586001338983051], 
             UndirectedEdge[44, 243] -> 
             RGBColor[
              0.9818698474576271, 0.9843128305084745, 0.8400573050847457], 
             UndirectedEdge[82, 194] -> 
             RGBColor[
              0.922283372881356, 0.6901234915254237, 0.3825755423728814], 
             UndirectedEdge[124, 150] -> 
             RGBColor[
              0.856889779661017, 0.3784302033898306, 0.19976724576271188`], 
             UndirectedEdge[233, 316] -> 
             RGBColor[
              0.993821847457627, 0.9891938813559322, 0.5689244067796608], 
             UndirectedEdge[87, 390] -> 
             RGBColor[
              0.9396137033898305, 0.7857051525423728, 0.5041746610169491], 
             UndirectedEdge[72, 376] -> 
             RGBColor[
              0.9906986186440678, 0.9891620000000001, 0.7122479406779663], 
             UndirectedEdge[99, 169] -> 
             RGBColor[
              0.9090864661016949, 0.7288814915254238, 0.5910318813559322], 
             UndirectedEdge[127, 137] -> 
             RGBColor[
              0.9726846949152542, 0.9195212033898306, 0.34838562711864407`], 
             UndirectedEdge[68, 391] -> 
             RGBColor[
              0.9504665254237288, 0.8282819322033899, 0.46758700847457635`], 
             UndirectedEdge[292, 309] -> 
             RGBColor[
              0.9904160084745762, 0.9885575254237289, 0.6814875677966101], 
             UndirectedEdge[88, 140] -> 
             RGBColor[
              0.9726846949152543, 0.9195212033898306, 0.34838562711864407`], 
             UndirectedEdge[153, 216] -> 
             RGBColor[
              0.9531432118644068, 0.8662211016949153, 0.5900661355932204], 
             UndirectedEdge[145, 165] -> 
             RGBColor[
              0.9946696779661017, 0.9910073050847458, 0.6612055254237288], 
             UndirectedEdge[37, 76] -> 
             RGBColor[
              0.9712066186440678, 0.9118772372881355, 0.5102516949152542], 
             UndirectedEdge[6, 391] -> 
             RGBColor[
              0.9278261610169491, 0.8134688983050847, 0.6066426101694915], 
             UndirectedEdge[203, 206] -> 
             RGBColor[
              0.9826880508474576, 0.953148593220339, 0.3971342711864405], 
             UndirectedEdge[298, 320] -> 
             RGBColor[
              0.9838459745762711, 0.966860372881356, 0.6164142457627119], 
             UndirectedEdge[39, 164] -> 
             RGBColor[
              0.9420179745762711, 0.8059317627118645, 0.5454439830508475], 
             UndirectedEdge[107, 156] -> 
             RGBColor[
              0.9909812288135593, 0.9897664745762712, 0.7430083135593221], 
             UndirectedEdge[31, 222] -> 
             RGBColor[
              0.9935167881355933, 0.9893521694915255, 0.5946556694915254], 
             UndirectedEdge[301, 329] -> 
             RGBColor[
              0.9685407372881356, 0.9267177288135593, 0.6053167881355932], 
             UndirectedEdge[126, 320] -> 
             RGBColor[
              0.9735549661016949, 0.979235813559322, 0.904476559322034], 
             UndirectedEdge[49, 191] -> 
             RGBColor[
              0.9937993983050848, 0.9899566440677967, 0.6254160423728812], 
             UndirectedEdge[122, 173] -> 
             RGBColor[
              0.9349259406779661, 0.9473484915254238, 0.8399478983050848], 
             UndirectedEdge[60, 102] -> 
             RGBColor[
              0.9717467033898305, 0.9755897966101694, 0.7695007542372881], 
             UndirectedEdge[120, 380] -> 
             RGBColor[
              0.9710411101694915, 0.948109254237288, 0.642535906779661], 
             UndirectedEdge[110, 247] -> 
             RGBColor[
              0.9506153050847457, 0.9623355254237289, 0.956205127118644], 
             UndirectedEdge[59, 149] -> 
             RGBColor[
              0.9912611949152542, 0.9884194237288135, 0.6320366864406779], 
             UndirectedEdge[92, 346] -> 
             RGBColor[
              0.9384859067796609, 0.785238779661017, 0.5228651694915254], 
             UndirectedEdge[6, 142] -> 
             RGBColor[
              0.9714640932203389, 0.9749853220338983, 0.7387403813559321], 
             UndirectedEdge[176, 232] -> 
             RGBColor[
              0.946764593220339, 0.8173060677966102, 0.32466826271186444`], 
             UndirectedEdge[60, 345] -> 
             RGBColor[
              0.9546030508474576, 0.9656636101694915, 0.9617293728813558], 
             UndirectedEdge[79, 126] -> 
             RGBColor[
              0.9623936864406779, 0.9318966440677966, 0.6364479406779662], 
             UndirectedEdge[14, 212] -> 
             RGBColor[
              0.9584611949152542, 0.9661148644067796, 0.8421927118644068], 
             UndirectedEdge[22, 338] -> 
             RGBColor[
              0.9869692033898305, 0.9668922542372882, 0.47309071186440677`], 
             UndirectedEdge[195, 389] -> 
             RGBColor[
              0.9278261610169491, 0.8134688983050847, 0.6066426101694915], 
             UndirectedEdge[14, 293] -> 
             RGBColor[
              0.9584611949152542, 0.9661148644067796, 0.8421927118644068], 
             UndirectedEdge[201, 394] -> 
             RGBColor[
              0.9923916355932203, 0.9908373220338984, 0.7550781779661018], 
             UndirectedEdge[20, 189] -> 
             RGBColor[
              0.946139372881356, 0.8214204406779662, 0.28982788983050856`], 
             UndirectedEdge[195, 359] -> 
             RGBColor[
              0.9217646271186442, 0.727529847457627, 0.255908186440678], 
             UndirectedEdge[222, 224] -> 
             RGBColor[
              0.9912611949152542, 0.9884194237288135, 0.6320366864406779], 
             UndirectedEdge[54, 389] -> 
             RGBColor[
              0.9697512711864407, 0.9760242881355932, 0.8941337796610169], 
             UndirectedEdge[123, 366] -> 
             RGBColor[
              0.9371621525423728, 0.7880264745762711, 0.2711588389830508], 
             UndirectedEdge[120, 263] -> 
             RGBColor[
              0.9801300423728814, 0.954325661016949, 0.6019785508474575], 
             UndirectedEdge[332, 364] -> 
             RGBColor[
              0.9102602457627119, 0.926164220338983, 0.7146615932203388], 
             UndirectedEdge[70, 228] -> 
             RGBColor[
              0.9912503559322035, 0.9806359152542373, 0.549047152542373], 
             UndirectedEdge[74, 141] -> 
             RGBColor[
              0.9786697033898306, 0.9427236949152542, 0.5501618389830508], 
             UndirectedEdge[212, 385] -> 
             RGBColor[
              0.9510433305084746, 0.9426042881355932, 0.6848382711864406], 
             UndirectedEdge[256, 384] -> 
             RGBColor[
              0.8652462542372881, 0.4426617288135592, 0.20776941525423728`], 
             UndirectedEdge[158, 317] -> 
             RGBColor[
              0.9759726016949153, 0.9517871525423729, 0.6341881779661016], 
             UndirectedEdge[76, 208] -> 
             RGBColor[
              0.8952297457627119, 0.5793238474576272, 0.2326497372881356], 
             UndirectedEdge[101, 253] -> 
             RGBColor[
              0.946139372881356, 0.8214204406779662, 0.28982788983050856`], 
             UndirectedEdge[111, 309] -> 
             RGBColor[
              0.9941044576271186, 0.9897983559322034, 0.599684779661017], 
             UndirectedEdge[145, 170] -> 
             RGBColor[
              0.9941044576271186, 0.9897983559322034, 0.599684779661017], 
             UndirectedEdge[59, 279] -> 
             RGBColor[
              0.9445759830508476, 0.8047546949152543, 0.3405997033898305], 
             UndirectedEdge[83, 334] -> 
             RGBColor[
              0.9849737711864406, 0.9673267457627119, 0.5977237372881355], 
             UndirectedEdge[242, 312] -> 
             RGBColor[
              0.9723119237288136, 0.9767987457627119, 0.8310215000000001], 
             UndirectedEdge[140, 356] -> 
             RGBColor[
              0.9789721186440679, 0.9406138813559322, 0.3826985762711864], 
             UndirectedEdge[172, 316] -> 
             RGBColor[
              0.9714640932203389, 0.9749853220338983, 0.7387403813559321], 
             UndirectedEdge[217, 331] -> 
             RGBColor[
              0.9856735423728813, 0.9875243559322034, 0.8504000847457627], 
             UndirectedEdge[263, 336] -> 
             RGBColor[
              0.9784864576271186, 0.9829137118644068, 0.8961288305084747], 
             UndirectedEdge[122, 338] -> 
             RGBColor[
              0.9943870677966102, 0.9904028305084747, 0.630445152542373], 
             UndirectedEdge[303, 400] -> 
             RGBColor[
              0.9872293644067797, 0.9682594915254237, 0.560342720338983], 
             UndirectedEdge[133, 367] -> 
             RGBColor[
              0.9047027881355932, 0.5625613050847458, 0.472513720338983], 
             UndirectedEdge[136, 279] -> 
             RGBColor[
              0.9329290423728813, 0.7997153559322034, 0.586001338983051], 
             UndirectedEdge[117, 365] -> 
             RGBColor[
              0.987251813559322, 0.9674967288135593, 0.5038510847457626], 
             UndirectedEdge[33, 245] -> 
             RGBColor[
              0.9926716016949153, 0.9894902711864407, 0.6441065508474575], 
             UndirectedEdge[162, 368] -> 
             RGBColor[
              0.9946472288135593, 0.9917700677966101, 0.7176971610169492], 
             UndirectedEdge[46, 128] -> 
             RGBColor[
              0.9408780847457627, 0.8005611864406779, 0.28559453389830514`], 
             UndirectedEdge[117, 269] -> 
             RGBColor[
              0.9581785847457627, 0.9655103898305084, 0.8114323389830508], 
             UndirectedEdge[98, 134] -> 
             RGBColor[
              0.9130592627118643, 0.6267928305084745, 0.48051588983050836`], 
             UndirectedEdge[90, 326] -> 
             RGBColor[
              0.9747570423728813, 0.9606439661016949, 0.6569716016949152], 
             UndirectedEdge[119, 306] -> 
             RGBColor[
              0.9534730084745762, 0.8834024576271187, 0.6026472203389831], 
             UndirectedEdge[150, 211] -> 
             RGBColor[
              0.9454013644067797, 0.8073308813559323, 0.4893724576271187], 
             UndirectedEdge[388, 395] -> 
             RGBColor[
              0.8559265254237287, 0.40034301694915236`, 0.19999280508474573`],
              UndirectedEdge[102, 108] -> 
             RGBColor[
              0.9918264152542373, 0.989628372881356, 0.6935574322033898], 
             UndirectedEdge[15, 392] -> 
             RGBColor[
              0.9906986186440678, 0.9891620000000001, 0.7122479406779663], 
             UndirectedEdge[32, 292] -> 
             RGBColor[
              0.9764141101694915, 0.9417909491525425, 0.5875428559322036], 
             UndirectedEdge[115, 332] -> 
             RGBColor[
              0.9901333983050847, 0.9879530508474577, 0.6507271949152542], 
             UndirectedEdge[93, 293] -> 
             RGBColor[
              0.8984348474576271, 0.9218515762711864, 0.9901747118644068], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.8752676440677966, 0.48463032203389805`, 0.21594858474576267`],
              UndirectedEdge[276, 305] -> 
             RGBColor[
              0.9868013389830508, 0.9879907288135594, 0.8317095762711864], 
             UndirectedEdge[75, 347] -> 
             RGBColor[
              0.8906095254237288, 0.9143395932203391, 0.9366219745762712], 
             UndirectedEdge[64, 193] -> 
             RGBColor[
              0.993214372881356, 0.9914619830508475, 0.7621189322033898], 
             UndirectedEdge[18, 99] -> 
             RGBColor[
              0.8872410677966103, 0.5803646779661018, 0.2275973898305085], 
             UndirectedEdge[74, 290] -> 
             RGBColor[
              0.9861015677966102, 0.9677931186440678, 0.5790332288135592], 
             UndirectedEdge[39, 230] -> 
             RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             UndirectedEdge[259, 345] -> 
             RGBColor[
              0.9769608050847457, 0.9798721694915253, 0.7919133983050847], 
             UndirectedEdge[30, 168] -> 
             RGBColor[
              0.9912638389830508, 0.9903709491525424, 0.7737686864406781], 
             UndirectedEdge[231, 331] -> 
             RGBColor[
              0.9648175338983052, 0.8905516101694915, 0.5247088474576271], 
             UndirectedEdge[137, 242] -> 
             RGBColor[
              0.9912503559322035, 0.9806359152542373, 0.549047152542373], 
             UndirectedEdge[172, 221] -> 
             RGBColor[
              0.9686099915254237, 0.9658228813559322, 0.6881027542372882], 
             UndirectedEdge[157, 211] -> 
             RGBColor[
              0.9360816355932203, 0.7650121694915255, 0.4815958474576271], 
             UndirectedEdge[46, 213] -> 
             RGBColor[
              0.9281559576271186, 0.830650254237288, 0.6192236949152543], 
             UndirectedEdge[184, 318] -> 
             RGBColor[
              0.9181051355932204, 0.6580077288135595, 0.37857445762711867`], 
             UndirectedEdge[201, 293] -> 
             RGBColor[
              0.9584611949152542, 0.9661148644067796, 0.8421927118644068], 
             UndirectedEdge[64, 115] -> 
             RGBColor[
              0.9909587796610169, 0.9905292372881356, 0.7994999491525425], 
             UndirectedEdge[174, 266] -> 
             RGBColor[
              0.9501614661016949, 0.8284402203389831, 0.4933182711864407], 
             UndirectedEdge[80, 104] -> 
             RGBColor[
              0.9868013389830508, 0.9879907288135594, 0.8317095762711864], 
             UndirectedEdge[265, 321] -> 
             RGBColor[
              0.9937993983050848, 0.9899566440677967, 0.6254160423728812], 
             UndirectedEdge[178, 296] -> 
             RGBColor[
              0.9689687627118644, 0.9069864915254237, 0.33394993220338975`], 
             UndirectedEdge[114, 249] -> 
             RGBColor[
              0.9912503559322035, 0.9806359152542373, 0.549047152542373], 
             UndirectedEdge[255, 380] -> 
             RGBColor[
              0.9329290423728813, 0.7997153559322034, 0.586001338983051], 
             UndirectedEdge[253, 391] -> 
             RGBColor[
              0.9356167966101696, 0.7797019322033898, 0.2813611779661017], 
             UndirectedEdge[40, 63] -> 
             RGBColor[
              0.9861015677966102, 0.9677931186440678, 0.5790332288135592], 
             UndirectedEdge[23, 311] -> 
             RGBColor[
              0.9573006525423728, 0.8687596101694917, 0.5578565084745764], 
             UndirectedEdge[156, 396] -> 
             RGBColor[
              0.9909812288135593, 0.9897664745762712, 0.7430083135593221], 
             UndirectedEdge[93, 281] -> 
             RGBColor[
              0.9163602796610169, 0.8862337796610169, 0.6392863728813559], 
             UndirectedEdge[27, 325] -> 
             RGBColor[
              0.948211720338983, 0.8625432033898306, 0.5984138644067798], 
             UndirectedEdge[12, 107] -> 
             RGBColor[
              0.9898534322033898, 0.9893001016949152, 0.7616988220338983], 
             UndirectedEdge[255, 312] -> 
             RGBColor[
              0.9230660593220339, 0.792359559322034, 0.6026967966101695], 
             UndirectedEdge[257, 310] -> 
             RGBColor[
              0.920593033898305, 0.7076492372881356, 0.2801861440677965], 
             UndirectedEdge[50, 197] -> 
             RGBColor[
              0.9554452033898304, 0.8485367118644067, 0.44105999152542363`], 
             UndirectedEdge[215, 350] -> 
             RGBColor[
              0.905139720338983, 0.6801973050847459, 0.5748041610169491], 
             UndirectedEdge[49, 235] -> 
             RGBColor[
              0.993214372881356, 0.9914619830508475, 0.7621189322033898], 
             UndirectedEdge[239, 323] -> 
             RGBColor[
              0.9797975000000001, 0.9431900677966102, 0.5314713305084746], 
             UndirectedEdge[211, 216] -> 
             RGBColor[
              0.9868013389830508, 0.9879907288135594, 0.8317095762711864], 
             UndirectedEdge[98, 151] -> 
             RGBColor[
              0.9108036694915254, 0.6258600847457625, 0.517896906779661], 
             UndirectedEdge[10, 32] -> 
             RGBColor[
              0.9525307033898305, 0.9245408474576271, 0.6531433983050847], 
             UndirectedEdge[330, 367] -> 
             RGBColor[
              0.8461092966101695, 0.5186061016949153, 0.5760739491525424], 
             UndirectedEdge[99, 384] -> 
             RGBColor[
              0.882480966101695, 0.559255338983051, 0.22365157627118648`], 
             UndirectedEdge[127, 138] -> 
             RGBColor[
              0.939895533898305, 0.9050001525423729, 0.6415311864406779], 
             UndirectedEdge[292, 385] -> 
             RGBColor[
              0.9838459745762711, 0.966860372881356, 0.6164142457627119], 
             UndirectedEdge[177, 219] -> 
             RGBColor[
              0.9708790677966102, 0.9764906610169491, 0.8754432711864406], 
             UndirectedEdge[170, 322] -> 
             RGBColor[
              0.9813270762711863, 0.9823411186440678, 0.7220449237288135], 
             UndirectedEdge[261, 335] -> 
             RGBColor[
              0.9838324915254237, 0.9571253389830509, 0.3916927118644067], 
             UndirectedEdge[6, 253] -> 
             RGBColor[
              0.9574621949152542, 0.9282187457627118, 0.6447956694915254], 
             UndirectedEdge[95, 246] -> 
             RGBColor[
              0.9170045254237289, 0.7064205084745763, 0.2519623728813559], 
             UndirectedEdge[50, 331] -> 
             RGBColor[
              0.9932368220338983, 0.990699220338983, 0.7056272966101693], 
             UndirectedEdge[9, 358] -> 
             RGBColor[
              0.9764141101694915, 0.9417909491525425, 0.5875428559322036], 
             UndirectedEdge[99, 144] -> 
             RGBColor[
              0.842910186440678, 0.3149521355932204, 0.18810233050847458`], 
             UndirectedEdge[2, 28] -> 
             RGBColor[
              0.9302939745762713, 0.7433864406779662, 0.4963980508474576], 
             UndirectedEdge[138, 258] -> 
             RGBColor[
              0.9581785847457627, 0.9655103898305084, 0.8114323389830508], 
             UndirectedEdge[144, 384] -> 
             RGBColor[
              0.856889779661017, 0.3784302033898306, 0.19976724576271188`], 
             UndirectedEdge[79, 277] -> 
             RGBColor[
              0.9308566949152544, 0.758592593220339, 0.2774153644067797], 
             UndirectedEdge[346, 354] -> 
             RGBColor[
              0.977541906779661, 0.9422573220338983, 0.5688523474576271], 
             UndirectedEdge[144, 148] -> 
             RGBColor[
              0.8912859152542374, 0.5142893898305085, 0.24186611864406782`], 
             UndirectedEdge[38, 346] -> 
             RGBColor[
              0.9077532288135592, 0.5942106949152541, 0.495205313559322], 
             UndirectedEdge[38, 363] -> 
             RGBColor[
              0.8827420254237288, 0.5764942203389829, 0.5794963644067797], 
             UndirectedEdge[78, 104] -> 
             RGBColor[
              0.9937993983050848, 0.9899566440677967, 0.6254160423728812], 
             UndirectedEdge[95, 282] -> 
             RGBColor[
              0.9445759830508476, 0.8047546949152543, 0.3405997033898305], 
             UndirectedEdge[92, 306] -> 
             RGBColor[
              0.9123446610169492, 0.6852611525423729, 0.24807406779661018`], 
             UndirectedEdge[9, 339] -> 
             RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             UndirectedEdge[36, 148] -> 
             RGBColor[
              0.9792547288135593, 0.9412183559322034, 0.4134589491525423], 
             UndirectedEdge[62, 395] -> 
             RGBColor[
              0.9358214745762712, 0.7636449322033898, 0.39434383898305087`], 
             UndirectedEdge[32, 247] -> 
             RGBColor[
              0.943611466101695, 0.9175348644067797, 0.6559668813559323], 
             UndirectedEdge[168, 379] -> 
             RGBColor[
              0.9410465593220338, 0.7860132372881357, 0.45975288983050855`], 
             UndirectedEdge[137, 230] -> 
             RGBColor[0.9898175, 0.9803278305084746, 0.5934689237288135], 
             UndirectedEdge[268, 279] -> 
             RGBColor[
              0.5376937796610171, 0.4640637033898306, 0.5844087457627118], 
             UndirectedEdge[185, 288] -> 
             RGBColor[
              0.8991800847457627, 0.5589398644067795, 0.26030289830508463`], 
             UndirectedEdge[233, 310] -> 
             RGBColor[
              0.931444220338983, 0.7430900508474576, 0.421215906779661], 
             UndirectedEdge[150, 386] -> 
             RGBColor[
              0.944858593220339, 0.8053591694915255, 0.37136007627118633`], 
             UndirectedEdge[138, 281] -> 
             RGBColor[
              0.939895533898305, 0.9050001525423729, 0.641531186440678], 
             UndirectedEdge[88, 257] -> 
             RGBColor[
              0.9764006271186441, 0.9320559152542371, 0.36282132203389816`], 
             UndirectedEdge[27, 40] -> 
             RGBColor[
              0.9535712372881355, 0.8464898644067798, 0.3186992796610169], 
             UndirectedEdge[159, 250] -> 
             RGBColor[
              0.9665326016949152, 0.9713074237288135, 0.7470881101694914], 
             UndirectedEdge[169, 363] -> 
             RGBColor[
              0.9447400677966101, 0.9583078135593219, 0.9784248305084746], 
             UndirectedEdge[144, 382] -> 
             RGBColor[
              0.9061356440677966, 0.5628693898305085, 0.42809194915254245`], 
             UndirectedEdge[35, 207] -> 
             RGBColor[
              0.9554452033898304, 0.8485367118644067, 0.44105999152542363`], 
             UndirectedEdge[71, 287] -> 
             RGBColor[
              0.9906986186440678, 0.9891620000000001, 0.7122479406779663], 
             UndirectedEdge[148, 361] -> 
             RGBColor[
              0.9798199491525423, 0.9424273050847458, 0.4749796949152542], 
             UndirectedEdge[215, 393] -> 
             RGBColor[
              0.9117147966101695, 0.6552871525423729, 0.2723061525423728], 
             UndirectedEdge[33, 124] -> 
             RGBColor[
              0.9052878135593221, 0.561055966101695, 0.33581083050847443`], 
             UndirectedEdge[31, 111] -> 
             RGBColor[
              0.9946472288135593, 0.9917700677966101, 0.7176971610169492], 
             UndirectedEdge[113, 357] -> 
             RGBColor[
              0.9473273983050847, 0.9300695762711864, 0.6704025762711863], 
             UndirectedEdge[30, 329] -> 
             RGBColor[
              0.9834179491525423, 0.9865916101694916, 0.8877811016949153], 
             UndirectedEdge[117, 239] -> 
             RGBColor[
              0.9943646186440678, 0.9911655932203389, 0.6869367881355932], 
             UndirectedEdge[209, 338] -> 
             RGBColor[
              0.9918264152542373, 0.989628372881356, 0.6935574322033898], 
             UndirectedEdge[208, 323] -> 
             RGBColor[
              0.9038206271186442, 0.6106366779661019, 0.25386937288135597`], 
             UndirectedEdge[71, 212] -> 
             RGBColor[
              0.9547727457627118, 0.9648740338983051, 0.9239955000000001], 
             UndirectedEdge[199, 292] -> 
             RGBColor[
              0.9735549661016949, 0.979235813559322, 0.904476559322034], 
             UndirectedEdge[11, 386] -> 
             RGBColor[
              0.9941044576271186, 0.9897983559322034, 0.599684779661017], 
             UndirectedEdge[130, 267] -> 
             RGBColor[
              0.9862585677966101, 0.9860190169491526, 0.7136971949152541], 
             UndirectedEdge[67, 347] -> 
             RGBColor[
              0.8322003135593221, 0.6681295423728815, 0.5961390593220339], 
             UndirectedEdge[211, 358] -> 
             RGBColor[
              0.9797975000000001, 0.9431900677966102, 0.5314713305084746], 
             UndirectedEdge[2, 164] -> 
             RGBColor[
              0.9442735677966102, 0.8068645084745764, 0.5080629661016949], 
             UndirectedEdge[266, 358] -> 
             RGBColor[
              0.9797975000000001, 0.9431900677966102, 0.5314713305084746], 
             UndirectedEdge[57, 397] -> 
             RGBColor[
              0.9066462288135593, 0.6233215762711863, 0.550106533898305], 
             UndirectedEdge[209, 386] -> 
             RGBColor[
              0.9915438050847457, 0.9890238983050847, 0.6627970593220338], 
             UndirectedEdge[74, 386] -> 
             RGBColor[
              0.9926716016949153, 0.9894902711864407, 0.6441065508474575], 
             UndirectedEdge[47, 268] -> 
             RGBColor[
              0.5683739830508474, 0.5873881779661017, 0.6120719237288135], 
             UndirectedEdge[108, 397] -> 
             RGBColor[
              0.9119314661016948, 0.6263264576271185, 0.49920639830508473`], 
             UndirectedEdge[157, 358] -> 
             RGBColor[
              0.921536966101695, 0.7162738813559322, 0.26963875423728817`], 
             UndirectedEdge[10, 129] -> 
             RGBColor[
              0.9670978220338983, 0.972516372881356, 0.8086088559322033], 
             UndirectedEdge[171, 308] -> 
             RGBColor[
              0.9509115677966101, 0.8474339830508475, 0.5723136610169492], 
             UndirectedEdge[225, 335] -> 
             RGBColor[
              0.9875344237288135, 0.9681012033898305, 0.5346114576271187], 
             UndirectedEdge[45, 116] -> 
             RGBColor[
              0.9479058728813559, 0.8275074745762712, 0.5306992881355932], 
             UndirectedEdge[261, 349] -> 
             RGBColor[
              0.9764006271186441, 0.9320559152542374, 0.36282132203389833`], 
             UndirectedEdge[118, 209] -> 
             RGBColor[
              0.9796142542372881, 0.9833800847457628, 0.8774383220338984], 
             UndirectedEdge[329, 343] -> 
             RGBColor[
              0.9822901525423728, 0.9861252372881357, 0.9064716101694915], 
             UndirectedEdge[163, 171] -> 
             RGBColor[
              0.9270259152542373, 0.7483891016949151, 0.26014154237288134`], 
             UndirectedEdge[106, 217] -> 
             RGBColor[
              0.9035447966101695, 0.924802779661017, 0.9517154999999999], 
             UndirectedEdge[55, 123] -> 
             RGBColor[
              0.9537462627118644, 0.915684033898305, 0.6303599745762711], 
             UndirectedEdge[129, 353] -> 
             RGBColor[
              0.9868237881355932, 0.9872279661016949, 0.775217940677966], 
             UndirectedEdge[38, 66] -> 
             RGBColor[
              0.9066254322033898, 0.5937443220338983, 0.5138958220338984], 
             UndirectedEdge[23, 119] -> 
             RGBColor[
              0.948211720338983, 0.8625432033898306, 0.5984138644067798], 
             UndirectedEdge[306, 354] -> 
             RGBColor[
              0.9514006610169492, 0.8422796949152542, 0.29406124576271186`], 
             UndirectedEdge[28, 39] -> 
             RGBColor[
              0.9280383813559322, 0.7424536949152543, 0.5337790677966103], 
             UndirectedEdge[158, 267] -> 
             RGBColor[
              0.9829706610169491, 0.9537530677966102, 0.42789464406779637`], 
             UndirectedEdge[194, 399] -> 
             RGBColor[
              0.922283372881356, 0.6901234915254237, 0.3825755423728814], 
             UndirectedEdge[102, 333] -> 
             RGBColor[
              0.975821406779661, 0.9292881186440678, 0.42978362711864404`], 
             UndirectedEdge[16, 80] -> 
             RGBColor[
              0.9865411779661017, 0.9866234915254237, 0.7444575677966101], 
             UndirectedEdge[72, 333] -> 
             RGBColor[
              0.975821406779661, 0.9292881186440678, 0.42978362711864404`], 
             UndirectedEdge[167, 211] -> 
             RGBColor[
              0.9909452966101695, 0.9807942033898305, 0.5747784152542372], 
             UndirectedEdge[193, 255] -> 
             RGBColor[
              0.9442735677966102, 0.8068645084745764, 0.5080629661016949], 
             UndirectedEdge[168, 211] -> 
             RGBColor[
              0.9946472288135593, 0.9917700677966101, 0.7176971610169492], 
             UndirectedEdge[70, 246] -> 
             RGBColor[
              0.9662503898305085, 0.8908596949152543, 0.4802870762711865], 
             UndirectedEdge[322, 349] -> 
             RGBColor[
              0.9673251779661016, 0.9355745423728814, 0.6281002118644068], 
             UndirectedEdge[193, 312] -> 
             RGBColor[
              0.9708790677966102, 0.9764906610169491, 0.8754432711864406], 
             UndirectedEdge[194, 221] -> 
             RGBColor[
              0.9906851355932204, 0.979426966101695, 0.487526406779661], 
             UndirectedEdge[208, 221] -> 
             RGBColor[
              0.9149684237288136, 0.6482408135593222, 0.29717645762711864`], 
             UndirectedEdge[112, 251] -> 
             RGBColor[
              0.9323652881355932, 0.9465740338983051, 0.9030601779661016], 
             UndirectedEdge[297, 325] -> 
             RGBColor[
              0.9142895847457626, 0.7150779322033898, 0.5704481186440679], 
             UndirectedEdge[170, 225] -> 
             RGBColor[
              0.9941044576271186, 0.9897983559322034, 0.599684779661017], 
             UndirectedEdge[27, 250] -> 
             RGBColor[
              0.9601412711864407, 0.8681870169491526, 0.3837726016949151], 
             UndirectedEdge[67, 126] -> 
             RGBColor[
              0.9140179576271186, 0.7325593898305085, 0.5826841525423729], 
             UndirectedEdge[12, 157] -> 
             RGBColor[
              0.9315704491525423, 0.7631466779661018, 0.5563578813559322], 
             UndirectedEdge[316, 399] -> 
             RGBColor[
              0.9220007627118644, 0.6895190169491526, 0.3518151694915253], 
             UndirectedEdge[76, 377] -> 
             RGBColor[
              0.9322872033898304, 0.7692483559322032, 0.2643748983050847], 
             UndirectedEdge[3, 51] -> 
             RGBColor[
              0.9921090254237288, 0.9902328474576272, 0.7243178050847456], 
             UndirectedEdge[23, 186] -> 
             RGBColor[
              0.9572871694915255, 0.8590245762711866, 0.33313497457627117`], 
             UndirectedEdge[17, 319] -> 
             RGBColor[
              0.9547727457627118, 0.9648740338983051, 0.9239955000000001], 
             UndirectedEdge[115, 360] -> 
             RGBColor[
              0.9909587796610169, 0.9905292372881356, 0.7994999491525425], 
             UndirectedEdge[131, 142] -> 
             RGBColor[
              0.9937993983050848, 0.9899566440677967, 0.6254160423728812], 
             UndirectedEdge[23, 130] -> 
             RGBColor[
              0.9531432118644068, 0.8662211016949153, 0.5900661355932204], 
             UndirectedEdge[348, 354] -> 
             RGBColor[
              0.9689687627118644, 0.9069864915254237, 0.33394993220338975`], 
             UndirectedEdge[76, 80] -> 
             RGBColor[
              0.9636657881355932, 0.9079396101694914, 0.598532847457627], 
             UndirectedEdge[38, 81] -> 
             RGBColor[
              0.9100312711864407, 0.5943806779661016, 0.4013326610169491], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.9457064237288135, 0.8071725932203391, 0.46364119491525435`], 
             UndirectedEdge[131, 281] -> 
             RGBColor[
              0.9760815677966102, 0.9306553559322034, 0.5170356355932203], 
             UndirectedEdge[157, 167] -> 
             RGBColor[
              0.9326847627118644, 0.7538780169491526, 0.31294583898305084`], 
             UndirectedEdge[165, 172] -> 
             RGBColor[
              0.972029313559322, 0.9761942711864406, 0.800261127118644], 
             UndirectedEdge[255, 331] -> 
             RGBColor[
              0.9442735677966102, 0.8068645084745764, 0.5080629661016949], 
             UndirectedEdge[59, 268] -> 
             RGBColor[
              0.5858092033898306, 0.6460849915254238, 0.6896919576271185], 
             UndirectedEdge[161, 364] -> 
             RGBColor[
              0.8879500762711865, 0.8486892881355932, 0.6302576186440678], 
             UndirectedEdge[149, 164] -> 
             RGBColor[
              0.9431457711864406, 0.8063981355932204, 0.5267534745762712], 
             UndirectedEdge[10, 52] -> 
             RGBColor[
              0.9496715593220338, 0.9619857118644067, 0.9700771016949152], 
             UndirectedEdge[132, 155] -> 
             RGBColor[
              0.9890056016949152, 0.9874866779661018, 0.6694177033898304], 
             UndirectedEdge[353, 400] -> 
             RGBColor[
              0.979688533898305, 0.9643218644067797, 0.6486238728813558], 
             UndirectedEdge[250, 265] -> 
             RGBColor[
              0.9937993983050848, 0.9899566440677967, 0.6254160423728812], 
             UndirectedEdge[82, 233] -> 
             RGBColor[
              0.9225659830508475, 0.690727966101695, 0.4133359152542372], 
             UndirectedEdge[66, 81] -> 
             RGBColor[
              0.9909812288135593, 0.9897664745762712, 0.7430083135593221], 
             UndirectedEdge[69, 201] -> 
             RGBColor[
              0.9457064237288135, 0.8071725932203391, 0.46364119491525435`], 
             UndirectedEdge[84, 184] -> 
             RGBColor[
              0.993256627118644, 0.9879849322033898, 0.5074036610169491], 
             UndirectedEdge[180, 268] -> 
             RGBColor[
              0.5758058474576271, 0.6124576016949151, 0.6409433135593219], 
             UndirectedEdge[17, 247] -> 
             RGBColor[
              0.9219701016949152, 0.9406179491525424, 0.9924195254237288], 
             UndirectedEdge[188, 394] -> 
             RGBColor[
              0.9886897033898305, 0.9798614576271187, 0.6121594322033899], 
             UndirectedEdge[241, 312] -> 
             RGBColor[
              0.9723119237288136, 0.9767987457627119, 0.8310215000000001], 
             UndirectedEdge[81, 128] -> 
             RGBColor[
              0.9798199491525423, 0.9424273050847458, 0.4749796949152542], 
             UndirectedEdge[65, 198] -> 
             RGBColor[
              0.9267619067796611, 0.7226934576271187, 0.4738192372881356], 
             UndirectedEdge[356, 380] -> 
             RGBColor[
              0.9810444661016948, 0.9817366440677966, 0.6912845508474575], 
             UndirectedEdge[40, 265] -> 
             RGBColor[
              0.9872293644067797, 0.9682594915254237, 0.560342720338983], 
             UndirectedEdge[19, 168] -> 
             RGBColor[
              0.9912503559322035, 0.9806359152542373, 0.549047152542373], 
             UndirectedEdge[195, 241] -> 
             RGBColor[
              0.9504665254237288, 0.8282819322033899, 0.46758700847457635`], 
             UndirectedEdge[33, 141] -> 
             RGBColor[
              0.9792547288135593, 0.9412183559322034, 0.4134589491525423], 
             UndirectedEdge[65, 100] -> 
             RGBColor[
              0.9872293644067797, 0.9682594915254237, 0.560342720338983], 
             UndirectedEdge[15, 207] -> 
             RGBColor[
              0.9551625932203389, 0.8479322372881355, 0.41029961864406783`], 
             UndirectedEdge[81, 135] -> 
             RGBColor[
              0.9935392372881355, 0.988589406779661, 0.5381640338983049], 
             UndirectedEdge[259, 271] -> 
             RGBColor[
              0.9659677796610169, 0.8902552203389831, 0.4495267033898305], 
             UndirectedEdge[194, 233] -> 
             RGBColor[
              0.9941044576271186, 0.9897983559322034, 0.599684779661017], 
             UndirectedEdge[101, 283] -> 
             RGBColor[
              0.9498553050847458, 0.8339551525423728, 0.30426358474576265`], 
             UndirectedEdge[145, 192] -> 
             RGBColor[
              0.9943870677966102, 0.9904028305084747, 0.630445152542373], 
             UndirectedEdge[68, 397] -> 
             RGBColor[
              0.9144921186440678, 0.6271009152542371, 0.4360941186440679], 
             UndirectedEdge[142, 201] -> 
             RGBColor[
              0.9941044576271186, 0.9897983559322034, 0.599684779661017], 
             UndirectedEdge[146, 354] -> 
             RGBColor[
              0.9797975000000001, 0.9431900677966102, 0.5314713305084746], 
             UndirectedEdge[153, 329] -> 
             RGBColor[
              0.9531432118644068, 0.8662211016949153, 0.5900661355932204], 
             UndirectedEdge[132, 279] -> 
             RGBColor[
              0.9445759830508476, 0.8047546949152543, 0.3405997033898305], 
             UndirectedEdge[257, 389] -> 
             RGBColor[
              0.961178127118644, 0.9407534576271186, 0.6592313644067795], 
             UndirectedEdge[107, 386] -> 
             RGBColor[
              0.993821847457627, 0.9891938813559322, 0.5689244067796608], 
             UndirectedEdge[157, 203] -> 
             RGBColor[
              0.9352562542372882, 0.7624359830508475, 0.3328230932203389], 
             UndirectedEdge[264, 281] -> 
             RGBColor[
              0.9586777542372881, 0.9193619322033898, 0.6220122457627119], 
             UndirectedEdge[244, 302] -> 
             RGBColor[
              0.9715703813559322, 0.9287898644067797, 0.5917976694915255], 
             UndirectedEdge[46, 105] -> 
             RGBColor[
              0.9520393644067796, 0.8479003559322034, 0.5536231525423729], 
             UndirectedEdge[126, 347] -> 
             RGBColor[
              0.8777168983050847, 0.9049116610169492, 0.9668365508474577], 
             UndirectedEdge[129, 253] -> 
             RGBColor[
              0.9798199491525423, 0.9424273050847458, 0.4749796949152542], 
             UndirectedEdge[14, 69] -> 
             RGBColor[
              0.9457064237288135, 0.8071725932203391, 0.46364119491525435`], 
             UndirectedEdge[118, 124] -> 
             RGBColor[
              0.8933582627118644, 0.5554121525423729, 0.550452093220339], 
             UndirectedEdge[181, 245] -> 
             RGBColor[0.9898175, 0.9803278305084746, 0.5934689237288135], 
             UndirectedEdge[33, 152] -> 
             RGBColor[
              0.9665326016949152, 0.9713074237288135, 0.7470881101694914], 
             UndirectedEdge[47, 371] -> 
             RGBColor[
              0.9738259745762712, 0.9297226101694915, 0.5544166525423728], 
             UndirectedEdge[131, 273] -> 
             RGBColor[
              0.9937993983050848, 0.9899566440677967, 0.6254160423728812], 
             UndirectedEdge[230, 299] -> 
             RGBColor[
              0.9648175338983052, 0.8905516101694915, 0.524708847457627], 
             UndirectedEdge[107, 181] -> 
             RGBColor[
              0.9909677457627118, 0.9800314406779661, 0.5182867796610169], 
             UndirectedEdge[4, 318] -> 
             RGBColor[
              0.9161097033898304, 0.6584422203389833, 0.5032074830508475], 
             UndirectedEdge[10, 333] -> 
             RGBColor[
              0.9488147711864406, 0.9120061355932203, 0.6387077033898305], 
             UndirectedEdge[152, 238] -> 
             RGBColor[
              0.964819779661017, 0.9723463898305085, 0.9024815084745763], 
             UndirectedEdge[50, 147] -> 
             RGBColor[
              0.9932368220338983, 0.990699220338983, 0.7056272966101693], 
             UndirectedEdge[39, 217] -> 
             RGBColor[
              0.9834179491525423, 0.9865916101694916, 0.8877811016949153], 
             UndirectedEdge[98, 308] -> 
             RGBColor[
              0.9096758728813559, 0.6253937118644066, 0.5365874152542374], 
             UndirectedEdge[31, 363] -> 
             RGBColor[
              0.9670753728813559, 0.9732791355932203, 0.8651004915254237], 
             UndirectedEdge[286, 386] -> 
             RGBColor[
              0.9601412711864407, 0.8681870169491526, 0.3837726016949151], 
             UndirectedEdge[137, 138] -> 
             RGBColor[0.9547592627118644, 0.955139, 0.6992739661016949], 
             UndirectedEdge[35, 372] -> 
             RGBColor[
              0.972029313559322, 0.9761942711864406, 0.800261127118644], 
             UndirectedEdge[130, 158] -> 
             RGBColor[
              0.9759726016949153, 0.9517871525423729, 0.6341881779661016], 
             UndirectedEdge[277, 373] -> 
             RGBColor[
              0.9454013644067797, 0.8073308813559323, 0.4893724576271187], 
             UndirectedEdge[234, 365] -> 
             RGBColor[
              0.9861015677966102, 0.9677931186440678, 0.5790332288135592], 
             UndirectedEdge[310, 316] -> 
             RGBColor[0.930879, 0.7418811016949154, 0.35969516101694904`], 
             UndirectedEdge[218, 305] -> 
             RGBColor[
              0.9845457457627118, 0.9870579830508475, 0.869090593220339], 
             UndirectedEdge[155, 279] -> 
             RGBColor[
              0.9408901779661016, 0.8054653898305086, 0.5641344915254238], 
             UndirectedEdge[32, 129] -> 
             RGBColor[
              0.9798199491525423, 0.9424273050847458, 0.4749796949152542], 
             UndirectedEdge[92, 158] -> 
             RGBColor[
              0.9299127627118644, 0.7499679491525423, 0.287962754237288], 
             UndirectedEdge[332, 334] -> 
             RGBColor[
              0.9864039830508475, 0.9656833050847458, 0.4115699661016948], 
             UndirectedEdge[268, 300] -> 
             RGBColor[
              0.5642992796610169, 0.6336898559322033, 0.9517890508474576], 
             UndirectedEdge[224, 227] -> 
             RGBColor[
              0.9915438050847457, 0.9890238983050847, 0.6627970593220338], 
             UndirectedEdge[25, 91] -> 
             RGBColor[
              0.9823856355932203, 0.955258406779661, 0.5645975338983049], 
             UndirectedEdge[74, 304] -> 
             RGBColor[
              0.9099578305084746, 0.9282740338983051, 0.8821248559322034], 
             UndirectedEdge[86, 397] -> 
             RGBColor[
              0.8910515084745763, 0.5472080847457624, 0.22864865254237282`], 
             UndirectedEdge[32, 111] -> 
             RGBColor[
              0.9801025593220339, 0.943031779661017, 0.5057400677966103], 
             UndirectedEdge[59, 394] -> 
             RGBColor[
              0.9912611949152542, 0.9884194237288135, 0.6320366864406779], 
             UndirectedEdge[170, 355] -> 
             RGBColor[
              0.986686593220339, 0.966287779661017, 0.44233033898305063`], 
             UndirectedEdge[9, 56] -> 
             RGBColor[
              0.9420179745762711, 0.8059317627118645, 0.5454439830508475], 
             UndirectedEdge[44, 317] -> 
             RGBColor[
              0.9868013389830508, 0.9879907288135594, 0.8317095762711864], 
             UndirectedEdge[236, 262] -> 
             RGBColor[
              0.9700788220338983, 0.9114108644067795, 0.5289422033898304], 
             UndirectedEdge[119, 346] -> 
             RGBColor[
              0.9796142542372881, 0.9833800847457628, 0.8774383220338984], 
             UndirectedEdge[80, 244] -> 
             RGBColor[
              0.9822901525423728, 0.9861252372881357, 0.9064716101694915], 
             UndirectedEdge[20, 360] -> 
             RGBColor[
              0.9606840423728813, 0.8701587288135594, 0.5017849830508475], 
             UndirectedEdge[196, 206] -> 
             RGBColor[
              0.9562466355932203, 0.9370755593220338, 0.6675790932203389], 
             UndirectedEdge[187, 302] -> 
             RGBColor[
              0.9726981779661017, 0.9292562372881357, 0.5731071610169493], 
             UndirectedEdge[147, 312] -> 
             RGBColor[
              0.9708790677966102, 0.9764906610169491, 0.8754432711864406], 
             UndirectedEdge[259, 400] -> 
             RGBColor[
              0.987251813559322, 0.9674967288135593, 0.5038510847457626], 
             UndirectedEdge[120, 312] -> 
             RGBColor[
              0.961178127118644, 0.9407534576271186, 0.6592313644067795], 
             UndirectedEdge[52, 60] -> 
             RGBColor[
              0.9546030508474576, 0.9656636101694915, 0.9617293728813558], 
             UndirectedEdge[266, 384] -> 
             RGBColor[
              0.9454013644067797, 0.8073308813559323, 0.4893724576271187], 
             UndirectedEdge[135, 393] -> 
             RGBColor[
              0.9826880508474576, 0.953148593220339, 0.3971342711864405], 
             UndirectedEdge[77, 244] -> 
             RGBColor[
              0.975286313559322, 0.9413245762711865, 0.6062333644067797], 
             UndirectedEdge[239, 385] -> 
             RGBColor[
              0.9872293644067797, 0.9682594915254237, 0.560342720338983], 
             UndirectedEdge[278, 296] -> 
             RGBColor[
              0.9345726271186441, 0.7711273050847458, 0.2918510593220338], 
             UndirectedEdge[267, 275] -> 
             RGBColor[
              0.9926716016949153, 0.9894902711864407, 0.6441065508474575], 
             UndirectedEdge[148, 340] -> 
             RGBColor[
              0.9764006271186441, 0.9320559152542374, 0.36282132203389833`], 
             UndirectedEdge[202, 212] -> 
             RGBColor[
              0.9570283389830508, 0.965806779661017, 0.8866144830508473], 
             UndirectedEdge[81, 346] -> 
             RGBColor[
              0.9921090254237288, 0.9902328474576272, 0.7243178050847456], 
             UndirectedEdge[50, 217] -> 
             RGBColor[
              0.9868237881355932, 0.9872279661016949, 0.775217940677966], 
             UndirectedEdge[5, 183] -> 
             RGBColor[
              0.9430486610169492, 0.8047713559322034, 0.3102325677966101], 
             UndirectedEdge[313, 339] -> 
             RGBColor[
              0.9749537711864407, 0.9301889830508474, 0.5357261440677965], 
             UndirectedEdge[4, 184] -> 
             RGBColor[
              0.9918264152542373, 0.989628372881356, 0.6935574322033898], 
             UndirectedEdge[104, 349] -> 
             RGBColor[
              0.9797975000000001, 0.9431900677966102, 0.5314713305084746], 
             UndirectedEdge[119, 135] -> 
             RGBColor[
              0.9810444661016948, 0.9817366440677966, 0.6912845508474575], 
             UndirectedEdge[53, 273] -> 
             RGBColor[
              0.9813270762711863, 0.9823411186440678, 0.7220449237288135], 
             UndirectedEdge[224, 259] -> 
             RGBColor[
              0.9921090254237288, 0.9902328474576272, 0.7243178050847456], 
             UndirectedEdge[110, 289] -> 
             RGBColor[
              0.9865411779661017, 0.9866234915254237, 0.7444575677966101], 
             UndirectedEdge[59, 155] -> 
             RGBColor[
              0.9890056016949152, 0.9874866779661018, 0.6694177033898304], 
             UndirectedEdge[5, 29] -> 
             RGBColor[
              0.9012206610169492, 0.6438427457627119, 0.2392623050847458], 
             UndirectedEdge[119, 311] -> 
             RGBColor[
              0.9784864576271186, 0.9829137118644068, 0.8961288305084747], 
             UndirectedEdge[68, 72] -> 
             RGBColor[
              0.9943870677966102, 0.9904028305084747, 0.630445152542373], 
             UndirectedEdge[121, 234] -> 
             RGBColor[
              0.9935194322033898, 0.9913036949152543, 0.7363876694915255], 
             UndirectedEdge[20, 336] -> 
             RGBColor[
              0.948211720338983, 0.8625432033898306, 0.5984138644067798], 
             UndirectedEdge[17, 256] -> 
             RGBColor[
              0.8780010254237287, 0.6016039999999998, 0.5863209322033898], 
             UndirectedEdge[186, 272] -> 
             RGBColor[
              0.9838324915254237, 0.9571253389830509, 0.3916927118644067], 
             UndirectedEdge[45, 304] -> 
             RGBColor[
              0.9088300338983051, 0.9278076610169492, 0.9008153644067797], 
             UndirectedEdge[165, 252] -> 
             RGBColor[
              0.9712290677966101, 0.9111144745762711, 0.4537600593220338], 
             UndirectedEdge[106, 254] -> 
             RGBColor[
              0.8936818135593221, 0.9174469830508474, 0.9684109576271187], 
             UndirectedEdge[144, 169] -> 
             RGBColor[
              0.8834952796610169, 0.5480563559322034, 0.5671475508474576], 
             UndirectedEdge[191, 355] -> 
             RGBColor[
              0.986686593220339, 0.966287779661017, 0.44233033898305063`], 
             UndirectedEdge[96, 377] -> 
             RGBColor[
              0.9445940169491525, 0.8130958983050847, 0.30003022881355923`], 
             UndirectedEdge[110, 303] -> 
             RGBColor[
              0.9868013389830508, 0.9879907288135594, 0.8317095762711864], 
             UndirectedEdge[177, 260] -> 
             RGBColor[
              0.961178127118644, 0.9407534576271186, 0.6592313644067795], 
             UndirectedEdge[20, 88] -> 
             RGBColor[
              0.9535712372881355, 0.8464898644067798, 0.3186992796610169], 
             UndirectedEdge[57, 68] -> 
             RGBColor[
              0.9871063983050847, 0.9878324406779662, 0.8059783135593221], 
             UndirectedEdge[127, 264] -> 
             RGBColor[
              0.9586777542372881, 0.9193619322033898, 0.6220122457627117], 
             UndirectedEdge[171, 186] -> 
             RGBColor[
              0.9520258813559321, 0.8381653220338983, 0.32890161864406775`], 
             UndirectedEdge[362, 385] -> 
             RGBColor[
              0.987251813559322, 0.9674967288135593, 0.5038510847457626], 
             UndirectedEdge[109, 370] -> 
             RGBColor[
              0.9615368983050847, 0.8819170677966102, 0.30507854237288135`], 
             UndirectedEdge[123, 161] -> 
             RGBColor[
              0.9529460169491525, 0.8506042372881355, 0.28385890677966097`], 
             UndirectedEdge[119, 213] -> 
             RGBColor[
              0.9546030508474576, 0.9656636101694915, 0.961729372881356], 
             UndirectedEdge[140, 360] -> 
             RGBColor[
              0.9797975000000001, 0.9431900677966102, 0.5314713305084746], 
             UndirectedEdge[320, 347] -> 
             RGBColor[
              0.8917373220338983, 0.914805966101695, 0.9179314661016951], 
             UndirectedEdge[10, 345] -> 
             RGBColor[
              0.9496715593220338, 0.9619857118644067, 0.9700771016949152], 
             UndirectedEdge[169, 383] -> 
             RGBColor[
              0.9708790677966102, 0.9764906610169491, 0.8754432711864406], 
             UndirectedEdge[154, 372] -> 
             RGBColor[
              0.9240532033898305, 0.9419186440677966, 0.980125906779661], 
             UndirectedEdge[167, 341] -> 
             RGBColor[
              0.923365033898305, 0.7115593050847457, 0.3051692288135593], 
             UndirectedEdge[186, 308] -> 
             RGBColor[
              0.9864341101694916, 0.9789287118644068, 0.6495404491525424], 
             UndirectedEdge[145, 225] -> 
             RGBColor[
              0.9949522881355932, 0.991611779661017, 0.6919658983050849], 
             UndirectedEdge[12, 65] -> 
             RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             UndirectedEdge[274, 288] -> 
             RGBColor[
              0.9091834406779662, 0.5925672542372881, 0.30905154237288124`], 
             UndirectedEdge[143, 171] -> 
             RGBColor[
              0.9531671610169491, 0.8483667288135592, 0.5349326440677966], 
             UndirectedEdge[167, 168] -> 
             RGBColor[
              0.9912503559322035, 0.9806359152542373, 0.549047152542373], 
             UndirectedEdge[203, 341] -> 
             RGBColor[
              0.9259365254237288, 0.7201172711864406, 0.3250464830508474], 
             UndirectedEdge[114, 299] -> 
             RGBColor[
              0.9662503898305085, 0.8908596949152543, 0.4802870762711865], 
             UndirectedEdge[154, 231] -> 
             RGBColor[
              0.9179916694915254, 0.8559795932203389, 0.6293914830508475], 
             UndirectedEdge[218, 384] -> 
             RGBColor[
              0.9431457711864406, 0.8063981355932204, 0.5267534745762712], 
             UndirectedEdge[360, 380] -> 
             RGBColor[
              0.9818698474576271, 0.9843128305084745, 0.8400573050847457], 
             UndirectedEdge[98, 306] -> 
             RGBColor[
              0.885790220338983, 0.5263488305084744, 0.22441529661016946`], 
             UndirectedEdge[57, 262] -> 
             RGBColor[
              0.9636657881355932, 0.9079396101694914, 0.598532847457627], 
             UndirectedEdge[152, 160] -> 
             RGBColor[
              0.9670753728813559, 0.9732791355932203, 0.8651004915254237], 
             UndirectedEdge[311, 354] -> 
             RGBColor[
              0.9764141101694915, 0.9417909491525425, 0.5875428559322036], 
             UndirectedEdge[287, 303] -> 
             RGBColor[
              0.9940820084745763, 0.9905611186440678, 0.6561764152542373], 
             UndirectedEdge[222, 247] -> 
             RGBColor[
              0.9573307542372882, 0.963696966101695, 0.7191512203389829], 
             UndirectedEdge[24, 206] -> 
             RGBColor[
              0.9345726271186441, 0.7711273050847458, 0.2918510593220338], 
             UndirectedEdge[92, 308] -> 
             RGBColor[
              0.936230313559322, 0.7843060338983051, 0.560246186440678], 
             UndirectedEdge[18, 266] -> 
             RGBColor[
              0.9501614661016949, 0.8284402203389831, 0.4933182711864407], 
             UndirectedEdge[28, 314] -> 
             RGBColor[
              0.9302939745762713, 0.7433864406779662, 0.4963980508474576], 
             UndirectedEdge[128, 139] -> 
             RGBColor[
              0.9789721186440679, 0.9406138813559322, 0.3826985762711864], 
             UndirectedEdge[160, 181] -> 
             RGBColor[
              0.9909452966101695, 0.9807942033898305, 0.5747784152542372], 
             UndirectedEdge[42, 296] -> 
             RGBColor[
              0.9812578389830509, 0.954792033898305, 0.5832880423728812], 
             UndirectedEdge[121, 289] -> 
             RGBColor[
              0.9943870677966102, 0.9904028305084747, 0.630445152542373], 
             UndirectedEdge[22, 286] -> 
             RGBColor[
              0.9535712372881355, 0.8464898644067798, 0.3186992796610169], 
             UndirectedEdge[128, 213] -> 
             RGBColor[
              0.9525307033898305, 0.9245408474576271, 0.6531433983050847], 
             UndirectedEdge[178, 398] -> 
             RGBColor[
              0.9795373389830508, 0.9418228305084746, 0.44421932203389836`], 
             UndirectedEdge[6, 129] -> 
             RGBColor[
              0.972029313559322, 0.9761942711864406, 0.800261127118644], 
             UndirectedEdge[265, 375] -> 
             RGBColor[
              0.9909452966101695, 0.9807942033898305, 0.5747784152542372], 
             UndirectedEdge[162, 270] -> 
             RGBColor[
              0.9772434152542373, 0.9804766440677966, 0.8226737711864407], 
             UndirectedEdge[199, 271] -> 
             RGBColor[
              0.9485415169491525, 0.8797245593220339, 0.6109949491525424], 
             UndirectedEdge[60, 72] -> 
             RGBColor[
              0.9717467033898305, 0.9755897966101694, 0.7695007542372881], 
             UndirectedEdge[230, 258] -> 
             RGBColor[
              0.9932368220338983, 0.990699220338983, 0.7056272966101693], 
             UndirectedEdge[38, 135] -> 
             RGBColor[
              0.9091834406779662, 0.592567254237288, 0.30905154237288124`], 
             UndirectedEdge[42, 67] -> 
             RGBColor[
              0.9291661779661017, 0.7429200677966102, 0.5150885593220339], 
             UndirectedEdge[220, 352] -> 
             RGBColor[
              0.9906986186440678, 0.9891620000000001, 0.7122479406779663], 
             UndirectedEdge[4, 226] -> 
             RGBColor[
              0.9920865762711863, 0.9909956101694916, 0.7808094406779661], 
             UndirectedEdge[134, 163] -> 
             RGBColor[
              0.9648175338983052, 0.8905516101694915, 0.524708847457627], 
             UndirectedEdge[25, 76] -> 
             RGBColor[
              0.9700788220338983, 0.9114108644067795, 0.5289422033898304], 
             UndirectedEdge[250, 375] -> 
             RGBColor[
              0.9904025254237288, 0.9788224915254238, 0.45676603389830495`], 
             UndirectedEdge[50, 138] -> 
             RGBColor[
              0.9581785847457627, 0.9655103898305084, 0.8114323389830508], 
             UndirectedEdge[24, 157] -> 
             RGBColor[
              0.8871408305084746, 0.5804146949152543, 0.22753988135593223`], 
             UndirectedEdge[127, 328] -> 
             RGBColor[
              0.975821406779661, 0.9292881186440678, 0.42978362711864404`], 
             UndirectedEdge[107, 245] -> 
             RGBColor[
              0.9932368220338983, 0.990699220338983, 0.7056272966101693], 
             UndirectedEdge[16, 96] -> 
             RGBColor[
              0.9832532711864407, 0.9543575423728813, 0.45865501694915245`], 
             UndirectedEdge[42, 278] -> 
             RGBColor[
              0.9431457711864406, 0.8063981355932204, 0.5267534745762712], 
             UndirectedEdge[51, 176] -> 
             RGBColor[
              0.9886897033898305, 0.9798614576271187, 0.6121594322033899], 
             UndirectedEdge[33, 386] -> 
             RGBColor[
              0.993256627118644, 0.9879849322033899, 0.5074036610169489], 
             UndirectedEdge[78, 187] -> 
             RGBColor[
              0.9904160084745762, 0.9885575254237289, 0.6814875677966101], 
             UndirectedEdge[107, 150] -> 
             RGBColor[
              0.945423813559322, 0.8065681186440679, 0.43288082203389827`], 
             UndirectedEdge[312, 360] -> 
             RGBColor[
              0.9720068644067796, 0.9769570338983051, 0.8567527627118644], 
             UndirectedEdge[78, 208] -> 
             RGBColor[
              0.9178225254237289, 0.6574032542372883, 0.3478140847457626], 
             UndirectedEdge[28, 197] -> 
             RGBColor[
              0.8925023559322034, 0.6012239322033899, 0.23183074576271187`], 
             UndirectedEdge[221, 316] -> 
             RGBColor[
              0.9904025254237288, 0.9788224915254238, 0.45676603389830495`], 
             UndirectedEdge[243, 383] -> 
             RGBColor[
              0.9807420508474576, 0.9838464576271186, 0.8587478135593221], 
             UndirectedEdge[83, 332] -> 
             RGBColor[
              0.9912611949152542, 0.9884194237288135, 0.6320366864406779], 
             UndirectedEdge[98, 354] -> 
             RGBColor[
              0.8996423898305085, 0.5785209152542371, 0.24986828813559323`], 
             UndirectedEdge[46, 215] -> 
             RGBColor[
              0.8836241186440678, 0.5488618474576271, 0.2239507542372881], 
             UndirectedEdge[375, 381] -> 
             RGBColor[
              0.9909452966101695, 0.9807942033898305, 0.5747784152542372], 
             UndirectedEdge[286, 304] -> 
             RGBColor[0.8774275, 0.806970779661017, 0.621790906779661], 
             UndirectedEdge[225, 235] -> 
             RGBColor[
              0.9935194322033898, 0.9913036949152543, 0.7363876694915255], 
             UndirectedEdge[96, 225] -> 
             RGBColor[
              0.9838184915254238, 0.9555664915254236, 0.5201757627118644], 
             UndirectedEdge[20, 389] -> 
             RGBColor[
              0.9383487372881356, 0.855187406779661, 0.6151093220338983], 
             UndirectedEdge[259, 393] -> 
             RGBColor[
              0.9835358813559322, 0.9549620169491524, 0.4894153898305083], 
             UndirectedEdge[97, 166] -> 
             RGBColor[
              0.9065744406779661, 0.9268749152542373, 0.9381963813559322], 
             UndirectedEdge[115, 334] -> 
             RGBColor[
              0.9838459745762711, 0.966860372881356, 0.6164142457627119], 
             UndirectedEdge[251, 260] -> 
             RGBColor[
              0.9237921440677965, 0.9113032033898304, 0.6681577627118642], 
             UndirectedEdge[119, 344] -> 
             RGBColor[
              0.964466033898305, 0.9730194067796609, 0.9450339152542373], 
             UndirectedEdge[329, 341] -> 
             RGBColor[
              0.9192210762711864, 0.7187558305084746, 0.5621003898305084], 
             UndirectedEdge[283, 334] -> 
             RGBColor[
              0.9764006271186441, 0.9320559152542371, 0.36282132203389816`], 
             UndirectedEdge[1, 5] -> 
             RGBColor[
              0.8783628305084745, 0.528002593220339, 0.21971739830508474`], 
             UndirectedEdge[364, 391] -> 
             RGBColor[
              0.8669049237288136, 0.7652522711864407, 0.6133241949152543], 
             UndirectedEdge[48, 295] -> 
             RGBColor[
              0.9723119237288136, 0.9767987457627119, 0.8310215000000001], 
             UndirectedEdge[105, 199] -> 
             RGBColor[
              0.9735549661016949, 0.979235813559322, 0.904476559322034], 
             UndirectedEdge[281, 293] -> 
             RGBColor[
              0.939895533898305, 0.9050001525423729, 0.6415311864406779], 
             UndirectedEdge[216, 358] -> 
             RGBColor[
              0.9722566694915254, 0.9392524406779661, 0.6197524830508474], 
             UndirectedEdge[100, 206] -> 
             RGBColor[
              0.9764006271186441, 0.9320559152542371, 0.36282132203389816`], 
             UndirectedEdge[168, 341] -> 
             RGBColor[
              0.9270669661016949, 0.7225351694915254, 0.44808797457627125`], 
             UndirectedEdge[199, 259] -> 
             RGBColor[
              0.9769608050847457, 0.9798721694915253, 0.7919133983050847], 
             UndirectedEdge[19, 24] -> 
             RGBColor[
              0.9420044915254238, 0.7961967288135594, 0.3207224491525424], 
             UndirectedEdge[136, 299] -> 
             RGBColor[
              0.9534730084745762, 0.8834024576271187, 0.6026472203389831], 
             UndirectedEdge[64, 123] -> 
             RGBColor[
              0.9760815677966102, 0.9306553559322034, 0.5170356355932203], 
             UndirectedEdge[101, 334] -> 
             RGBColor[
              0.9535712372881355, 0.8464898644067798, 0.3186992796610169], 
             UndirectedEdge[2, 328] -> 
             RGBColor[
              0.9929542118644068, 0.9900947457627118, 0.6748669237288135], 
             UndirectedEdge[235, 349] -> 
             RGBColor[
              0.9786697033898306, 0.9427236949152542, 0.5501618389830508], 
             UndirectedEdge[45, 290] -> 
             RGBColor[
              0.9849737711864406, 0.9673267457627119, 0.5977237372881355], 
             UndirectedEdge[225, 327] -> 
             RGBColor[
              0.9938218474576271, 0.9891938813559322, 0.568924406779661], 
             UndirectedEdge[24, 386] -> 
             RGBColor[
              0.944858593220339, 0.8053591694915255, 0.37136007627118633`], 
             UndirectedEdge[363, 393] -> 
             RGBColor[
              0.9562466355932203, 0.9370755593220338, 0.6675790932203389], 
             UndirectedEdge[2, 258] -> 
             RGBColor[
              0.9932368220338983, 0.990699220338983, 0.7056272966101693], 
             UndirectedEdge[8, 234] -> 
             RGBColor[
              0.9595562457627118, 0.8696923559322034, 0.5204754915254237], 
             UndirectedEdge[44, 151] -> 
             RGBColor[
              0.9909587796610169, 0.9905292372881356, 0.7994999491525425], 
             UndirectedEdge[253, 283] -> 
             RGBColor[
              0.9689687627118644, 0.9069864915254237, 0.33394993220338975`], 
             UndirectedEdge[257, 360] -> 
             RGBColor[
              0.9835134322033898, 0.9557247796610169, 0.5459070254237287], 
             UndirectedEdge[65, 358] -> 
             RGBColor[
              0.9797975000000001, 0.9431900677966102, 0.5314713305084746], 
             UndirectedEdge[282, 340] -> 
             RGBColor[
              0.9901199152542373, 0.9782180169491526, 0.42600566101694903`], 
             UndirectedEdge[256, 316] -> 
             RGBColor[
              0.9136442881355932, 0.6252874915254236, 0.3438129999999998], 
             UndirectedEdge[96, 182] -> 
             RGBColor[
              0.9829706610169491, 0.9537530677966102, 0.42789464406779637`], 
             UndirectedEdge[2, 106] -> 
             RGBColor[
              0.9099578305084746, 0.9282740338983051, 0.8821248559322034], 
             UndirectedEdge[210, 279] -> 
             RGBColor[
              0.9382885593220339, 0.7836620169491526, 0.30628675423728813`], 
             UndirectedEdge[279, 371] -> 
             RGBColor[
              0.9431457711864406, 0.8063981355932204, 0.5267534745762712], 
             UndirectedEdge[271, 353] -> 
             RGBColor[0.9584045, 0.8870803559322034, 0.5942994915254236], 
             UndirectedEdge[306, 311] -> 
             RGBColor[
              0.9625619406779661, 0.8896188644067797, 0.5620898644067798], 
             UndirectedEdge[64, 312] -> 
             RGBColor[
              0.9720068644067796, 0.9769570338983051, 0.8567527627118644], 
             UndirectedEdge[137, 210] -> 
             RGBColor[
              0.9838324915254237, 0.9571253389830509, 0.3916927118644067], 
             UndirectedEdge[264, 394] -> 
             RGBColor[
              0.9746827627118644, 0.979702186440678, 0.8857860508474575], 
             UndirectedEdge[199, 224] -> 
             RGBColor[
              0.9746827627118644, 0.979702186440678, 0.8857860508474575], 
             UndirectedEdge[61, 301] -> 
             RGBColor[
              0.9578209661016949, 0.8693823559322034, 0.2906428474576271], 
             UndirectedEdge[48, 103] -> 
             RGBColor[
              0.9708790677966102, 0.9764906610169491, 0.8754432711864406], 
             UndirectedEdge[7, 14] -> 
             RGBColor[
              0.9457064237288135, 0.8071725932203391, 0.46364119491525435`], 
             UndirectedEdge[88, 195] -> 
             RGBColor[
              0.9430486610169492, 0.8047713559322034, 0.3102325677966101], 
             UndirectedEdge[211, 341] -> 
             RGBColor[
              0.9267619067796611, 0.7226934576271187, 0.4738192372881356], 
             UndirectedEdge[84, 185] -> 
             RGBColor[
              0.9826880508474576, 0.953148593220339, 0.3971342711864405], 
             UndirectedEdge[368, 387] -> 
             RGBColor[
              0.9606840423728813, 0.8701587288135594, 0.5017849830508475], 
             UndirectedEdge[134, 171] -> 
             RGBColor[
              0.9542949576271187, 0.8488331016949152, 0.5162421355932203], 
             UndirectedEdge[41, 295] -> 
             RGBColor[
              0.9801025593220339, 0.943031779661017, 0.5057400677966103], 
             UndirectedEdge[77, 388] -> 
             RGBColor[
              0.8996423898305085, 0.5785209152542371, 0.24986828813559323`], 
             UndirectedEdge[142, 273] -> 
             RGBColor[
              0.993256627118644, 0.9879849322033899, 0.5074036610169489], 
             UndirectedEdge[64, 140] -> 
             RGBColor[
              0.9797975000000001, 0.9431900677966102, 0.5314713305084746], 
             UndirectedEdge[150, 157] -> 
             RGBColor[
              0.8871408305084746, 0.5804146949152543, 0.22753988135593223`], 
             UndirectedEdge[210, 264] -> 
             RGBColor[
              0.9698255508474576, 0.9569660677966101, 0.6653193305084746], 
             UndirectedEdge[202, 309] -> 
             RGBColor[
              0.9926716016949153, 0.9894902711864407, 0.6441065508474575], 
             UndirectedEdge[105, 287] -> 
             RGBColor[
              0.9906986186440678, 0.9891620000000001, 0.7122479406779663], 
             UndirectedEdge[157, 160] -> 
             RGBColor[
              0.9360816355932203, 0.7650121694915255, 0.4815958474576271], 
             UndirectedEdge[153, 379] -> 
             RGBColor[
              0.9070833728813559, 0.6644018983050848, 0.2438407118644068], 
             UndirectedEdge[207, 387] -> 
             RGBColor[
              0.921764627118644, 0.727529847457627, 0.255908186440678], 
             UndirectedEdge[93, 264] -> 
             RGBColor[
              0.91721706779661, 0.9362133559322033, 0.9706557711864406], 
             UndirectedEdge[202, 365] -> 
             RGBColor[
              0.9861015677966102, 0.9677931186440678, 0.5790332288135592], 
             UndirectedEdge[138, 230] -> 
             RGBColor[
              0.9570283389830508, 0.965806779661017, 0.8866144830508473], 
             UndirectedEdge[5, 291] -> 
             RGBColor[
              0.9456502796610169, 0.8265747288135594, 0.5680803050847458], 
             UndirectedEdge[241, 360] -> 
             RGBColor[
              0.9946472288135593, 0.9917700677966101, 0.7176971610169492], 
             UndirectedEdge[299, 300] -> 
             RGBColor[
              0.9436100254237287, 0.8760466610169491, 0.6193426779661018], 
             UndirectedEdge[9, 266] -> 
             RGBColor[
              0.9909587796610169, 0.9905292372881356, 0.7994999491525425], 
             UndirectedEdge[226, 322] -> 
             RGBColor[
              0.9818698474576271, 0.9843128305084745, 0.8400573050847457], 
             UndirectedEdge[175, 216] -> 
             RGBColor[
              0.9862585677966101, 0.9860190169491526, 0.7136971949152541], 
             UndirectedEdge[115, 257] -> 
             RGBColor[
              0.9801300423728814, 0.954325661016949, 0.6019785508474575], 
             UndirectedEdge[146, 275] -> 
             RGBColor[
              0.993214372881356, 0.9914619830508475, 0.7621189322033898], 
             UndirectedEdge[64, 101] -> 
             RGBColor[
              0.9606840423728813, 0.8701587288135594, 0.5017849830508475], 
             UndirectedEdge[79, 390] -> 
             RGBColor[
              0.9786697033898306, 0.9427236949152542, 0.5501618389830508], 
             UndirectedEdge[98, 378] -> 
             RGBColor[
              0.9033583220338983, 0.5910556271186438, 0.26430398305084735`], 
             UndirectedEdge[37, 80] -> 
             RGBColor[
              0.9868013389830508, 0.9879907288135594, 0.8317095762711864], 
             UndirectedEdge[344, 354] -> 
             RGBColor[
              0.9623936864406779, 0.9318966440677966, 0.6364479406779662], 
             UndirectedEdge[119, 227] -> 
             RGBColor[
              0.9813270762711863, 0.9823411186440678, 0.7220449237288135], 
             UndirectedEdge[81, 166] -> 
             RGBColor[
              0.9111080762711865, 0.9279776440677966, 0.8069427118644068], 
             UndirectedEdge[192, 221] -> 
             RGBColor[
              0.9906851355932204, 0.979426966101695, 0.487526406779661], 
             UndirectedEdge[242, 331] -> 
             RGBColor[
              0.9935194322033898, 0.9913036949152543, 0.7363876694915255], 
             UndirectedEdge[225, 322] -> 
             RGBColor[
              0.982174906779661, 0.9841545423728814, 0.8143260423728815], 
             UndirectedEdge[165, 170] -> 
             RGBColor[
              0.993821847457627, 0.9891938813559322, 0.5689244067796608], 
             UndirectedEdge[41, 250] -> 
             RGBColor[
              0.9792547288135593, 0.9412183559322034, 0.4134589491525423], 
             UndirectedEdge[31, 393] -> 
             RGBColor[
              0.9835134322033898, 0.9557247796610169, 0.5459070254237287], 
             UndirectedEdge[140, 312] -> 
             RGBColor[
              0.9574621949152542, 0.9282187457627118, 0.6447956694915254], 
             UndirectedEdge[56, 100] -> 
             RGBColor[
              0.9382885593220339, 0.7836620169491526, 0.30628675423728813`], 
             UndirectedEdge[89, 183] -> 
             RGBColor[
              0.9382885593220339, 0.7836620169491526, 0.30628675423728813`], 
             UndirectedEdge[39, 210] -> 
             RGBColor[
              0.9838459745762711, 0.966860372881356, 0.6164142457627119], 
             UndirectedEdge[34, 321] -> 
             RGBColor[
              0.9892882118644067, 0.988091152542373, 0.7001780762711863], 
             UndirectedEdge[148, 301] -> 
             RGBColor[
              0.9615368983050847, 0.8819170677966102, 0.30507854237288135`], 
             UndirectedEdge[136, 155] -> 
             RGBColor[
              0.9773586610169491, 0.9824473389830508, 0.9148193389830509], 
             UndirectedEdge[51, 205] -> 
             RGBColor[
              0.9887031864406779, 0.9895964915254238, 0.8368809661016949], 
             UndirectedEdge[11, 123] -> 
             RGBColor[
              0.9763866271186441, 0.9304970677966102, 0.491304372881356], 
             UndirectedEdge[223, 400] -> 
             RGBColor[0.9827181779661016, 0.966394, 0.6351047542372881], 
             UndirectedEdge[6, 201] -> 
             RGBColor[
              0.9723119237288136, 0.9767987457627119, 0.8310215000000001], 
             UndirectedEdge[201, 273] -> 
             RGBColor[
              0.9941044576271186, 0.9897983559322034, 0.599684779661017], 
             UndirectedEdge[54, 196] -> 
             RGBColor[
              0.964819779661017, 0.9723463898305085, 0.9024815084745763], 
             UndirectedEdge[84, 288] -> 
             RGBColor[
              0.9091834406779662, 0.5925672542372881, 0.30905154237288124`], 
             UndirectedEdge[177, 248] -> 
             RGBColor[
              0.9648940593220339, 0.9532881694915254, 0.6736670593220339], 
             UndirectedEdge[76, 117] -> 
             RGBColor[
              0.9712290677966101, 0.9111144745762711, 0.4537600593220338], 
             UndirectedEdge[342, 348] -> 
             RGBColor[
              0.9726846949152542, 0.9195212033898303, 0.34838562711864385`], 
             UndirectedEdge[332, 389] -> 
             RGBColor[
              0.9711814830508474, 0.9743808474576271, 0.7079800084745762], 
             UndirectedEdge[68, 236] -> 
             RGBColor[
              0.9935194322033898, 0.9913036949152543, 0.7363876694915255], 
             UndirectedEdge[84, 318] -> 
             RGBColor[
              0.9175399152542374, 0.6567987796610171, 0.31705371186440673`], 
             UndirectedEdge[15, 372] -> 
             RGBColor[
              0.9717467033898305, 0.9755897966101694, 0.7695007542372881], 
             UndirectedEdge[88, 189] -> 
             RGBColor[
              0.9726846949152543, 0.9195212033898306, 0.34838562711864407`], 
             UndirectedEdge[364, 380] -> 
             RGBColor[
              0.8986133050847458, 0.9211248813559322, 0.9600632288135593], 
             UndirectedEdge[103, 295] -> 
             RGBColor[
              0.9935194322033898, 0.9913036949152543, 0.7363876694915255], 
             UndirectedEdge[20, 257] -> 
             RGBColor[
              0.9498553050847458, 0.8339551525423728, 0.30426358474576265`], 
             UndirectedEdge[12, 24] -> 
             RGBColor[
              0.9408901779661016, 0.8054653898305086, 0.5641344915254238], 
             UndirectedEdge[152, 157] -> 
             RGBColor[
              0.9088148389830508, 0.7463629491525423, 0.6032679152542373], 
             UndirectedEdge[26, 70] -> 
             RGBColor[
              0.9912503559322035, 0.9806359152542373, 0.549047152542373], 
             UndirectedEdge[33, 74] -> 
             RGBColor[
              0.9926716016949153, 0.9894902711864407, 0.6441065508474575], 
             UndirectedEdge[124, 238] -> 
             RGBColor[
              0.9035749915254236, 0.5620949322033899, 0.4912042288135593], 
             UndirectedEdge[148, 339] -> 
             RGBColor[
              0.9786697033898306, 0.9427236949152542, 0.5501618389830508], 
             UndirectedEdge[175, 229] -> 
             RGBColor[
              0.9340781101694915, 0.9455350677966101, 0.7476667796610168], 
             UndirectedEdge[105, 337] -> 
             RGBColor[
              0.9573006525423728, 0.8687596101694917, 0.5578565084745764], 
             UndirectedEdge[158, 306] -> 
             RGBColor[
              0.9551165932203389, 0.8548144067796609, 0.30849694067796596`], 
             UndirectedEdge[136, 268] -> 
             RGBColor[
              0.5741622627118643, 0.6410456525423729, 0.935093593220339], 
             UndirectedEdge[133, 278] -> 
             RGBColor[
              0.9442735677966102, 0.8068645084745764, 0.5080629661016949], 
             UndirectedEdge[197, 254] -> 
             RGBColor[
              0.938018940677966, 0.8380060508474576, 0.6025282372881355], 
             UndirectedEdge[296, 398] -> 
             RGBColor[
              0.9832532711864407, 0.9543575423728813, 0.45865501694915245`], 
             UndirectedEdge[10, 271] -> 
             RGBColor[
              0.938678533898305, 0.8723687627118644, 0.627690406779661], 
             UndirectedEdge[221, 399] -> 
             RGBColor[
              0.9191466610169492, 0.6803565762711865, 0.30117754237288136`], 
             UndirectedEdge[187, 388] -> 
             RGBColor[
              0.9108036694915254, 0.6258600847457625, 0.517896906779661], 
             UndirectedEdge[143, 186] -> 
             RGBColor[
              0.9886897033898305, 0.9798614576271187, 0.6121594322033899], 
             UndirectedEdge[372, 387] -> 
             RGBColor[
              0.9383487372881356, 0.855187406779661, 0.6151093220338983], 
             UndirectedEdge[147, 255] -> 
             RGBColor[
              0.9442735677966102, 0.8068645084745764, 0.5080629661016949], 
             UndirectedEdge[27, 86] -> 
             RGBColor[
              0.9375484915254237, 0.7901076101694915, 0.2686082542372881], 
             UndirectedEdge[19, 157] -> 
             RGBColor[
              0.9326847627118644, 0.7538780169491526, 0.31294583898305084`], 
             UndirectedEdge[192, 208] -> 
             RGBColor[
              0.9181051355932204, 0.6580077288135595, 0.37857445762711867`], 
             UndirectedEdge[88, 89] -> 
             RGBColor[
              0.9382885593220339, 0.7836620169491526, 0.30628675423728813`], 
             UndirectedEdge[54, 332] -> 
             RGBColor[
              0.9912611949152542, 0.9884194237288135, 0.6320366864406779], 
             UndirectedEdge[282, 301] -> 
             RGBColor[
              0.9752561864406779, 0.9280791694915254, 0.3682628813559321], 
             UndirectedEdge[264, 328] -> 
             RGBColor[
              0.9766781949152542, 0.9792676949152542, 0.7611530254237289], 
             UndirectedEdge[124, 156] -> 
             RGBColor[
              0.9024471949152542, 0.5616285593220339, 0.5098947372881357], 
             UndirectedEdge[64, 120] -> 
             RGBColor[
              0.9835134322033898, 0.9557247796610169, 0.5459070254237287], 
             UndirectedEdge[55, 236] -> 
             RGBColor[
              0.9708790677966102, 0.9764906610169491, 0.8754432711864406], 
             UndirectedEdge[11, 196] -> 
             RGBColor[
              0.9673804322033899, 0.9731208474576272, 0.8393692288135595], 
             UndirectedEdge[223, 319] -> 
             RGBColor[
              0.9864475932203389, 0.9886637457627119, 0.8742619830508476], 
             UndirectedEdge[61, 70] -> 
             RGBColor[
              0.9763866271186441, 0.9304970677966102, 0.491304372881356], 
             UndirectedEdge[307, 343] -> 
             RGBColor[
              0.9890056016949152, 0.9874866779661018, 0.6694177033898304], 
             UndirectedEdge[13, 87] -> 
             RGBColor[
              0.9332006694915254, 0.7822338983050847, 0.5737653050847458], 
             UndirectedEdge[119, 128] -> 
             RGBColor[
              0.9673251779661016, 0.9355745423728814, 0.6281002118644068], 
             UndirectedEdge[92, 130] -> 
             RGBColor[
              0.9332006694915254, 0.7822338983050847, 0.5737653050847458], 
             UndirectedEdge[263, 359] -> 
             RGBColor[
              0.9625619406779661, 0.8896188644067797, 0.5620898644067798], 
             UndirectedEdge[22, 304] -> 
             RGBColor[
              0.9039728220338983, 0.9050715423728813, 0.6803486440677966], 
             UndirectedEdge[139, 306] -> 
             RGBColor[
              0.9651199491525424, 0.8884417966101694, 0.3572455847457626], 
             UndirectedEdge[1, 73] -> 
             RGBColor[
              0.9117147966101695, 0.6552871525423729, 0.2723061525423728], 
             UndirectedEdge[7, 13] -> 
             RGBColor[
              0.937860533898305, 0.8033932542372882, 0.5776536101694916], 
             UndirectedEdge[170, 335] -> 
             RGBColor[
              0.986686593220339, 0.966287779661017, 0.44233033898305063`], 
             UndirectedEdge[276, 361] -> 
             RGBColor[
              0.9943646186440678, 0.9911655932203389, 0.6869367881355932], 
             UndirectedEdge[46, 345] -> 
             RGBColor[
              0.938018940677966, 0.8380060508474576, 0.6025282372881355], 
             UndirectedEdge[36, 301] -> 
             RGBColor[
              0.9755387966101694, 0.9286836440677966, 0.399023254237288], 
             UndirectedEdge[50, 328] -> 
             RGBColor[
              0.9941044576271186, 0.9897983559322034, 0.599684779661017], 
             UndirectedEdge[55, 83] -> 
             RGBColor[
              0.9697512711864407, 0.9760242881355932, 0.8941337796610169], 
             UndirectedEdge[143, 306] -> 
             RGBColor[
              0.9636897372881356, 0.8900852372881356, 0.5433993559322033], 
             UndirectedEdge[32, 400] -> 
             RGBColor[
              0.9726846949152543, 0.9195212033898306, 0.34838562711864407`], 
             UndirectedEdge[20, 195] -> 
             RGBColor[
              0.9165033389830508, 0.706670593220339, 0.2516748305084746], 
             UndirectedEdge[203, 266] -> 
             RGBColor[
              0.9935167881355933, 0.9893521694915255, 0.5946556694915254], 
             UndirectedEdge[255, 359] -> 
             RGBColor[
              0.9170045254237289, 0.7064205084745763, 0.2519623728813559], 
             UndirectedEdge[128, 215] -> 
             RGBColor[
              0.9079988644067797, 0.6427524406779661, 0.2578704576271187], 
             UndirectedEdge[230, 328] -> 
             RGBColor[
              0.9929542118644068, 0.9900947457627118, 0.6748669237288135], 
             UndirectedEdge[44, 146] -> 
             RGBColor[
              0.9943421694915254, 0.9919283559322034, 0.7434284237288136], 
             UndirectedEdge[56, 206] -> 
             RGBColor[
              0.9345726271186441, 0.7711273050847458, 0.2918510593220338], 
             UndirectedEdge[55, 196] -> 
             RGBColor[
              0.9447400677966101, 0.9583078135593219, 0.9784248305084746], 
             UndirectedEdge[93, 188] -> 
             RGBColor[
              0.9312240084745762, 0.9363726271186441, 0.6970291525423729], 
             UndirectedEdge[52, 271] -> 
             RGBColor[
              0.9485415169491525, 0.8797245593220339, 0.6109949491525424], 
             UndirectedEdge[193, 253] -> 
             RGBColor[
              0.9786697033898306, 0.9427236949152542, 0.5501618389830508], 
             UndirectedEdge[120, 193] -> 
             RGBColor[
              0.9823856355932203, 0.955258406779661, 0.5645975338983049], 
             UndirectedEdge[28, 217] -> 
             RGBColor[
              0.9238809406779661, 0.7399151864406781, 0.5659886949152542], 
             UndirectedEdge[124, 245] -> 
             RGBColor[
              0.9047027881355932, 0.5625613050847458, 0.472513720338983], 
             UndirectedEdge[36, 282] -> 
             RGBColor[
              0.9929740169491525, 0.9873804576271187, 0.476643288135593], 
             UndirectedEdge[276, 339] -> 
             RGBColor[
              0.993214372881356, 0.9914619830508475, 0.7621189322033898], 
             UndirectedEdge[377, 388] -> 
             RGBColor[
              0.8752676440677966, 0.48463032203389805`, 0.21594858474576267`],
              UndirectedEdge[129, 131] -> 
             RGBColor[
              0.9943646186440678, 0.9911655932203389, 0.6869367881355932], 
             UndirectedEdge[69, 142] -> 
             RGBColor[
              0.944858593220339, 0.8053591694915255, 0.37136007627118633`], 
             UndirectedEdge[11, 118] -> 
             RGBColor[
              0.982174906779661, 0.9841545423728814, 0.8143260423728815], 
             UndirectedEdge[53, 293] -> 
             RGBColor[
              0.945683813559322, 0.958657627118644, 0.9645528559322034], 
             UndirectedEdge[2, 137] -> 
             RGBColor[0.9898175, 0.9803278305084746, 0.5934689237288135], 
             UndirectedEdge[102, 213] -> 
             RGBColor[
              0.9668152118644068, 0.9719118983050847, 0.7778484830508474], 
             UndirectedEdge[269, 362] -> 
             RGBColor[
              0.9581785847457627, 0.9655103898305084, 0.8114323389830508], 
             UndirectedEdge[147, 242] -> 
             RGBColor[
              0.9935194322033898, 0.9913036949152543, 0.7363876694915255], 
             UndirectedEdge[58, 220] -> 
             RGBColor[
              0.9764141101694915, 0.9417909491525425, 0.5875428559322036], 
             UndirectedEdge[177, 285] -> 
             RGBColor[
              0.9717467033898305, 0.9755897966101694, 0.7695007542372881], 
             UndirectedEdge[213, 215] -> 
             RGBColor[
              0.8952767372881356, 0.6728415084745762, 0.5914996186440677], 
             UndirectedEdge[61, 382] -> 
             RGBColor[
              0.9763866271186441, 0.9304970677966102, 0.491304372881356], 
             UndirectedEdge[83, 123] -> 
             RGBColor[
              0.9738259745762712, 0.9297226101694915, 0.5544166525423728], 
             UndirectedEdge[207, 368] -> 
             RGBColor[
              0.9554227542372882, 0.8492994745762712, 0.4975516271186441], 
             UndirectedEdge[117, 377] -> 
             RGBColor[
              0.9554452033898304, 0.8485367118644067, 0.44105999152542363`], 
             UndirectedEdge[207, 392] -> 
             RGBColor[
              0.9520393644067796, 0.8479003559322034, 0.5536231525423729], 
             UndirectedEdge[43, 325] -> 
             RGBColor[
              0.9693975254237287, 0.9766973050847457, 0.936686186440678], 
             UndirectedEdge[83, 196] -> 
             RGBColor[
              0.964819779661017, 0.9723463898305085, 0.9024815084745763], 
             UndirectedEdge[81, 130] -> 
             RGBColor[
              0.9868237881355932, 0.9872279661016949, 0.775217940677966], 
             UndirectedEdge[204, 229] -> 
             RGBColor[
              0.9349259406779661, 0.9473484915254238, 0.8399478983050848], 
             UndirectedEdge[44, 267] -> 
             RGBColor[
              0.9937993983050848, 0.9899566440677967, 0.6254160423728812], 
             UndirectedEdge[38, 130] -> 
             RGBColor[
              0.9024679915254237, 0.5912058135593219, 0.5461054491525423], 
             UndirectedEdge[226, 318] -> 
             RGBColor[
              0.9183652966101695, 0.659374966101695, 0.4658264661016949], 
             UndirectedEdge[202, 362] -> 
             RGBColor[
              0.9932368220338983, 0.990699220338983, 0.7056272966101693], 
             UndirectedEdge[59, 230] -> 
             RGBColor[
              0.9923889915254238, 0.9888857966101695, 0.6133461779661016], 
             UndirectedEdge[131, 394] -> 
             RGBColor[
              0.9920865762711863, 0.9909956101694916, 0.7808094406779661], 
             UndirectedEdge[93, 142] -> 
             RGBColor[
              0.9340781101694915, 0.9455350677966101, 0.7476667796610168], 
             UndirectedEdge[301, 340] -> 
             RGBColor[
              0.9726846949152542, 0.9195212033898306, 0.34838562711864407`], 
             UndirectedEdge[16, 76] -> 
             RGBColor[
              0.9709464576271186, 0.9105099999999999, 0.422999686440678], 
             UndirectedEdge[25, 239] -> 
             RGBColor[
              0.993214372881356, 0.9914619830508475, 0.7621189322033898], 
             UndirectedEdge[46, 60] -> 
             RGBColor[
              0.9330874491525423, 0.8343281525423728, 0.6108759661016949], 
             UndirectedEdge[57, 297] -> 
             RGBColor[
              0.9192210762711864, 0.7187558305084746, 0.5621003898305084], 
             UndirectedEdge[221, 351] -> 
             RGBColor[
              0.9801165593220339, 0.9445906271186439, 0.3772570169491524], 
             UndirectedEdge[365, 377] -> 
             RGBColor[
              0.9483099491525424, 0.8256306101694915, 0.3144659237288135], 
             UndirectedEdge[334, 366] -> 
             RGBColor[
              0.9483099491525424, 0.8256306101694915, 0.3144659237288135], 
             UndirectedEdge[209, 290] -> 
             RGBColor[
              0.9849737711864406, 0.9673267457627119, 0.5977237372881355], 
             UndirectedEdge[174, 313] -> 
             RGBColor[
              0.9319008644067797, 0.767167220338983, 0.26692548305084746`], 
             UndirectedEdge[56, 358] -> 
             RGBColor[
              0.9308566949152544, 0.758592593220339, 0.2774153644067797], 
             UndirectedEdge[304, 338] -> 
             RGBColor[
              0.910825466101695, 0.9273731694915255, 0.7761823389830509], 
             UndirectedEdge[130, 306] -> 
             RGBColor[0.9584045, 0.8870803559322034, 0.5942994915254237], 
             UndirectedEdge[11, 206] -> 
             RGBColor[
              0.9838184915254238, 0.9555664915254236, 0.5201757627118644], 
             UndirectedEdge[120, 140] -> 
             RGBColor[
              0.9689687627118644, 0.9069864915254237, 0.33394993220338975`], 
             UndirectedEdge[193, 356] -> 
             RGBColor[
              0.9923889915254238, 0.9888857966101695, 0.6133461779661016], 
             UndirectedEdge[166, 246] -> 
             RGBColor[
              0.8826887881355933, 0.8278300338983051, 0.6260242627118644], 
             UndirectedEdge[76, 182] -> 
             RGBColor[
              0.970663847457627, 0.9099055254237287, 0.39223931355932184`], 
             UndirectedEdge[6, 364] -> 
             RGBColor[
              0.8887503220338984, 0.9137690847457627, 0.976758686440678], 
             UndirectedEdge[288, 318] -> 
             RGBColor[
              0.8340319491525424, 0.2625900508474577, 0.18022233898305084`], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.9789721186440679, 0.9406138813559322, 0.3826985762711864], 
             UndirectedEdge[128, 151] -> 
             RGBColor[
              0.9764141101694915, 0.9417909491525425, 0.5875428559322036], 
             UndirectedEdge[30, 379] -> 
             RGBColor[
              0.9373581101694914, 0.7847724067796611, 0.5415556779661017], 
             UndirectedEdge[70, 90] -> 
             RGBColor[
              0.982174906779661, 0.9841545423728814, 0.8143260423728815], 
             UndirectedEdge[137, 394] -> 
             RGBColor[
              0.9886897033898305, 0.9798614576271187, 0.6121594322033899], 
             UndirectedEdge[25, 269] -> 
             RGBColor[
              0.9570283389830508, 0.965806779661017, 0.8866144830508473], 
             UndirectedEdge[38, 227] -> 
             RGBColor[
              0.9094660508474577, 0.5931717288135592, 0.33981191525423715`], 
             UndirectedEdge[128, 135] -> 
             RGBColor[
              0.9789721186440679, 0.9406138813559322, 0.3826985762711864], 
             UndirectedEdge[129, 303] -> 
             RGBColor[
              0.9943646186440678, 0.9911655932203389, 0.6869367881355932], 
             UndirectedEdge[132, 299] -> 
             RGBColor[
              0.9651199491525424, 0.8884417966101694, 0.3572455847457626], 
             UndirectedEdge[352, 396] -> 
             RGBColor[
              0.9941044576271186, 0.9897983559322034, 0.599684779661017], 
             UndirectedEdge[155, 268] -> 
             RGBColor[
              0.5821233983050847, 0.646795686440678, 0.9132267457627119], 
             UndirectedEdge[8, 16] -> 
             RGBColor[
              0.9604238813559323, 0.8687914915254238, 0.41453297457627125`], 
             UndirectedEdge[213, 378] -> 
             RGBColor[
              0.9562466355932203, 0.9370755593220338, 0.6675790932203389], 
             UndirectedEdge[164, 230] -> 
             RGBColor[
              0.9442735677966102, 0.8068645084745764, 0.5080629661016949], 
             UndirectedEdge[218, 339] -> 
             RGBColor[
              0.9909587796610169, 0.9905292372881356, 0.7994999491525423], 
             UndirectedEdge[101, 366] -> 
             RGBColor[
              0.921764627118644, 0.727529847457627, 0.255908186440678], 
             UndirectedEdge[169, 361] -> 
             RGBColor[
              0.972029313559322, 0.9761942711864406, 0.800261127118644], 
             UndirectedEdge[65, 341] -> 
             RGBColor[
              0.9267619067796611, 0.7226934576271187, 0.4738192372881356], 
             UndirectedEdge[46, 353] -> 
             RGBColor[
              0.9478819237288135, 0.8453618474576271, 0.585832779661017], 
             UndirectedEdge[279, 300] -> 
             RGBColor[
              0.9230660593220339, 0.792359559322034, 0.6026967966101695], 
             UndirectedEdge[203, 358] -> 
             RGBColor[
              0.9789721186440679, 0.9406138813559322, 0.3826985762711864], 
             UndirectedEdge[81, 243] -> 
             RGBColor[
              0.9818922966101694, 0.9835500677966101, 0.7835656694915254], 
             UndirectedEdge[176, 320] -> 
             RGBColor[
              0.987561906779661, 0.9793950847457628, 0.6308499406779662], 
             UndirectedEdge[112, 248] -> 
             RGBColor[
              0.9849737711864406, 0.9673267457627119, 0.5977237372881355], 
             UndirectedEdge[58, 179] -> 
             RGBColor[
              0.9525307033898305, 0.9245408474576271, 0.6531433983050847], 
             UndirectedEdge[23, 213] -> 
             RGBColor[
              0.9334172457627119, 0.8515095084745763, 0.6234570508474577], 
             UndirectedEdge[243, 326] -> 
             RGBColor[
              0.9747570423728813, 0.9606439661016949, 0.6569716016949152], 
             UndirectedEdge[269, 377] -> 
             RGBColor[
              0.9192367203389831, 0.8236442711864407, 0.6220471779661016], 
             UndirectedEdge[222, 363] -> 
             RGBColor[
              0.9662499915254237, 0.9707029491525423, 0.7163277372881356], 
             UndirectedEdge[30, 341] -> 
             RGBColor[
              0.9233785169491525, 0.7212943389830508, 0.5298907627118645], 
             UndirectedEdge[23, 348] -> 
             RGBColor[
              0.9498553050847458, 0.8339551525423728, 0.30426358474576265`], 
             UndirectedEdge[16, 25] -> 
             RGBColor[
              0.9929542118644068, 0.9900947457627118, 0.6748669237288135], 
             UndirectedEdge[25, 62] -> 
             RGBColor[
              0.9929542118644068, 0.9900947457627118, 0.6748669237288135], 
             UndirectedEdge[16, 388] -> 
             RGBColor[
              0.9139268983050848, 0.6258919661016947, 0.37457337288135595`], 
             UndirectedEdge[207, 372] -> 
             RGBColor[
              0.9330874491525423, 0.8343281525423728, 0.6108759661016949], 
             UndirectedEdge[249, 279] -> 
             RGBColor[
              0.9420044915254238, 0.7961967288135594, 0.3207224491525424], 
             UndirectedEdge[151, 267] -> 
             RGBColor[
              0.9904160084745762, 0.9885575254237289, 0.6814875677966101], 
             UndirectedEdge[185, 252] -> 
             RGBColor[
              0.9603778813559322, 0.875673661016949, 0.3127302966101694], 
             UndirectedEdge[218, 382] -> 
             RGBColor[
              0.9923916355932203, 0.9908373220338984, 0.7550781779661018], 
             UndirectedEdge[284, 334] -> 
             RGBColor[
              0.9875344237288135, 0.9681012033898305, 0.5346114576271187], 
             UndirectedEdge[145, 235] -> 
             RGBColor[
              0.9935194322033898, 0.9913036949152543, 0.7363876694915255], 
             UndirectedEdge[78, 302] -> 
             RGBColor[
              0.9755387966101694, 0.9286836440677966, 0.399023254237288], 
             UndirectedEdge[235, 335] -> 
             RGBColor[
              0.9861015677966102, 0.9677931186440678, 0.5790332288135592], 
             UndirectedEdge[21, 109] -> 
             RGBColor[
              0.9738259745762712, 0.9297226101694915, 0.5544166525423728], 
             UndirectedEdge[283, 389] -> 
             RGBColor[
              0.961178127118644, 0.9407534576271186, 0.6592313644067795], 
             UndirectedEdge[91, 395] -> 
             RGBColor[
              0.9252528983050847, 0.728808593220339, 0.28407444915254226`], 
             UndirectedEdge[240, 374] -> 
             RGBColor[
              0.9548799830508474, 0.8473277627118644, 0.3795392457627117], 
             UndirectedEdge[301, 339] -> 
             RGBColor[
              0.9749537711864407, 0.9301889830508474, 0.5357261440677965], 
             UndirectedEdge[303, 353] -> 
             RGBColor[
              0.9868013389830508, 0.9879907288135594, 0.8317095762711864], 
             UndirectedEdge[92, 143] -> 
             RGBColor[
              0.9384859067796609, 0.785238779661017, 0.5228651694915254], 
             UndirectedEdge[53, 394] -> 
             RGBColor[
              0.9796142542372881, 0.9833800847457628, 0.8774383220338984], 
             UndirectedEdge[139, 345] -> 
             RGBColor[
              0.9761129745762711, 0.9780587457627119, 0.6996322796610168], 
             UndirectedEdge[224, 393] -> 
             RGBColor[
              0.9812578389830509, 0.954792033898305, 0.5832880423728812], 
             UndirectedEdge[175, 204] -> 
             RGBColor[
              0.9941044576271186, 0.9897983559322034, 0.599684779661017], 
             UndirectedEdge[131, 293] -> 
             RGBColor[
              0.9581561355932203, 0.9662731525423729, 0.8679239745762712], 
             UndirectedEdge[166, 383] -> 
             RGBColor[
              0.9099578305084746, 0.9282740338983051, 0.8821248559322034], 
             UndirectedEdge[92, 348] -> 
             RGBColor[
              0.9299127627118644, 0.7499679491525423, 0.287962754237288], 
             UndirectedEdge[212, 289] -> 
             RGBColor[
              0.9578959745762712, 0.9649059152542373, 0.780671966101695], 
             UndirectedEdge[161, 214] -> 
             RGBColor[
              0.9666954322033898, 0.9100117457627118, 0.5850137288135593], 
             UndirectedEdge[124, 386] -> 
             RGBColor[
              0.9052878135593221, 0.561055966101695, 0.3358108305084745], 
             UndirectedEdge[227, 350] -> 
             RGBColor[
              0.9763955847457626, 0.9786632203389831, 0.7303926525423727], 
             UndirectedEdge[258, 279] -> 
             RGBColor[
              0.945423813559322, 0.8065681186440679, 0.43288082203389827`], 
             UndirectedEdge[63, 103] -> 
             RGBColor[
              0.9920865762711865, 0.9909956101694916, 0.780809440677966], 
             UndirectedEdge[291, 336] -> 
             RGBColor[
              0.9773586610169491, 0.9824473389830508, 0.9148193389830509], 
             UndirectedEdge[292, 400] -> 
             RGBColor[
              0.9838459745762711, 0.966860372881356, 0.6164142457627119], 
             UndirectedEdge[149, 300] -> 
             RGBColor[
              0.9697512711864407, 0.9760242881355932, 0.8941337796610169], 
             UndirectedEdge[356, 364] -> 
             RGBColor[
              0.9102602457627119, 0.926164220338983, 0.7146615932203388], 
             UndirectedEdge[100, 167] -> 
             RGBColor[
              0.9838324915254237, 0.9571253389830509, 0.3916927118644067], 
             UndirectedEdge[334, 391] -> 
             RGBColor[
              0.9430486610169492, 0.8047713559322034, 0.3102325677966101], 
             UndirectedEdge[309, 323] -> 
             RGBColor[
              0.9792547288135593, 0.9412183559322034, 0.4134589491525423], 
             UndirectedEdge[8, 202] -> 
             RGBColor[
              0.9595562457627118, 0.8696923559322034, 0.5204754915254237], 
             UndirectedEdge[127, 380] -> 
             RGBColor[
              0.9636092457627118, 0.9230398305084746, 0.6136645169491526], 
             UndirectedEdge[130, 151] -> 
             RGBColor[
              0.9834179491525423, 0.9865916101694916, 0.8877811016949153], 
             UndirectedEdge[335, 355] -> 
             RGBColor[
              0.9801165593220339, 0.944590627118644, 0.3772570169491524], 
             UndirectedEdge[117, 395] -> 
             RGBColor[
              0.9361040847457627, 0.764249406779661, 0.4251042118644067], 
             UndirectedEdge[256, 310] -> 
             RGBColor[0.8512666610169491, 0.379183661016949, 0.1961045], 
             UndirectedEdge[362, 365] -> 
             RGBColor[
              0.987251813559322, 0.9674967288135593, 0.5038510847457626], 
             UndirectedEdge[163, 342] -> 
             RGBColor[
              0.9551165932203389, 0.8548144067796609, 0.30849694067796596`], 
             UndirectedEdge[125, 288] -> 
             RGBColor[
              0.9088810254237288, 0.5946770677966101, 0.4765148050847457], 
             UndirectedEdge[161, 253] -> 
             RGBColor[
              0.9566619491525423, 0.8631389491525423, 0.2982946016949153], 
             UndirectedEdge[12, 211] -> 
             RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             UndirectedEdge[107, 152] -> 
             RGBColor[
              0.9670978220338983, 0.972516372881356, 0.8086088559322033], 
             UndirectedEdge[183, 291] -> 
             RGBColor[0.9827181779661016, 0.966394, 0.6351047542372881], 
             UndirectedEdge[149, 299] -> 
             RGBColor[
              0.9636897372881356, 0.8900852372881356, 0.5433993559322033], 
             UndirectedEdge[57, 284] -> 
             RGBColor[
              0.9871063983050847, 0.9878324406779662, 0.8059783135593221], 
             UndirectedEdge[230, 279] -> 
             RGBColor[
              0.9442735677966102, 0.8068645084745764, 0.5080629661016949], 
             UndirectedEdge[186, 374] -> 
             RGBColor[
              0.9520258813559321, 0.8381653220338983, 0.32890161864406775`], 
             UndirectedEdge[30, 175] -> 
             RGBColor[
              0.9904160084745762, 0.9885575254237289, 0.6814875677966101], 
             UndirectedEdge[261, 327] -> 
             RGBColor[
              0.9901199152542373, 0.9782180169491526, 0.42600566101694903`], 
             UndirectedEdge[271, 333] -> 
             RGBColor[
              0.9476847288135593, 0.8297449830508474, 0.2796255508474576], 
             UndirectedEdge[199, 247] -> 
             RGBColor[
              0.9407523220338982, 0.9549797288135593, 0.9729005847457627], 
             UndirectedEdge[99, 223] -> 
             RGBColor[
              0.9269105847457627, 0.7419873220338984, 0.5524695762711864], 
             UndirectedEdge[200, 367] -> 
             RGBColor[
              0.8721724576271186, 0.4412580508474577, 0.2121797711864407], 
             UndirectedEdge[111, 400] -> 
             RGBColor[
              0.9875344237288135, 0.9681012033898305, 0.5346114576271187], 
             UndirectedEdge[277, 390] -> 
             RGBColor[
              0.9442735677966102, 0.8068645084745764, 0.5080629661016949], 
             UndirectedEdge[79, 298] -> 
             RGBColor[
              0.9726846949152543, 0.9195212033898306, 0.34838562711864407`], 
             UndirectedEdge[96, 388] -> 
             RGBColor[
              0.9033583220338983, 0.5910556271186438, 0.26430398305084735`], 
             UndirectedEdge[153, 175] -> 
             RGBColor[
              0.9601412711864407, 0.8681870169491526, 0.3837726016949151], 
             UndirectedEdge[127, 331] -> 
             RGBColor[
              0.9749537711864407, 0.9301889830508474, 0.5357261440677965], 
             UndirectedEdge[6, 93] -> 
             RGBColor[
              0.9122855762711863, 0.9325354576271185, 0.9790034999999999], 
             UndirectedEdge[76, 239] -> 
             RGBColor[
              0.9712066186440678, 0.9118772372881355, 0.5102516949152542], 
             UndirectedEdge[333, 337] -> 
             RGBColor[
              0.9424234406779661, 0.8088857288135594, 0.27539219491525424`], 
             UndirectedEdge[253, 332] -> 
             RGBColor[
              0.9789721186440679, 0.9406138813559322, 0.3826985762711864], 
             UndirectedEdge[31, 400] -> 
             RGBColor[
              0.9872293644067797, 0.9682594915254237, 0.560342720338983], 
             UndirectedEdge[39, 149] -> 
             RGBColor[
              0.9887031864406779, 0.9895964915254238, 0.8368809661016949], 
             UndirectedEdge[49, 335] -> 
             RGBColor[
              0.9872293644067797, 0.9682594915254237, 0.560342720338983], 
             UndirectedEdge[57, 236] -> 
             RGBColor[
              0.9856735423728813, 0.9875243559322034, 0.8504000847457627], 
             UndirectedEdge[76, 323] -> 
             RGBColor[
              0.9566619491525423, 0.8631389491525423, 0.2982946016949153], 
             UndirectedEdge[2, 210] -> 
             RGBColor[
              0.9861015677966102, 0.9677931186440678, 0.5790332288135592], 
             UndirectedEdge[25, 395] -> 
             RGBColor[
              0.9349538389830508, 0.7645457966101695, 0.5002863559322033], 
             UndirectedEdge[62, 91] -> 
             RGBColor[
              0.9832532711864407, 0.9543575423728813, 0.45865501694915245`], 
             UndirectedEdge[148, 313] -> 
             RGBColor[
              0.9615368983050847, 0.8819170677966102, 0.30507854237288135`], 
             UndirectedEdge[98, 163] -> 
             RGBColor[
              0.885790220338983, 0.5263488305084744, 0.22441529661016946`], 
             UndirectedEdge[271, 292] -> 
             RGBColor[
              0.9625619406779661, 0.8896188644067797, 0.5620898644067798], 
             UndirectedEdge[148, 228] -> 
             RGBColor[
              0.9764006271186441, 0.9320559152542374, 0.36282132203389833`], 
             UndirectedEdge[105, 333] -> 
             RGBColor[
              0.9726981779661017, 0.9292562372881357, 0.5731071610169493], 
             UndirectedEdge[9, 65] -> 
             RGBColor[
              0.9909587796610169, 0.9905292372881356, 0.7994999491525425], 
             UndirectedEdge[129, 337] -> 
             RGBColor[
              0.9607064915254238, 0.869395966101695, 0.44529334745762705`], 
             UndirectedEdge[62, 323] -> 
             RGBColor[
              0.9795373389830508, 0.9418228305084746, 0.44421932203389836`], 
             UndirectedEdge[286, 290] -> 
             RGBColor[
              0.9535712372881355, 0.8464898644067798, 0.3186992796610169], 
             UndirectedEdge[96, 261] -> 
             RGBColor[
              0.9801165593220339, 0.9445906271186439, 0.3772570169491524], 
             UndirectedEdge[48, 86] -> 
             RGBColor[
              0.948871313559322, 0.8969059152542371, 0.6235760338983051], 
             UndirectedEdge[137, 328] -> 
             RGBColor[
              0.9906851355932204, 0.979426966101695, 0.487526406779661], 
             UndirectedEdge[110, 212] -> 
             RGBColor[
              0.9506153050847457, 0.9623355254237289, 0.956205127118644], 
             UndirectedEdge[163, 272] -> 
             RGBColor[
              0.9588325254237289, 0.8673491186440678, 0.3229326355932203], 
             UndirectedEdge[245, 396] -> 
             RGBColor[
              0.9932368220338983, 0.990699220338983, 0.7056272966101693], 
             UndirectedEdge[25, 37] -> 
             RGBColor[
              0.993214372881356, 0.9914619830508475, 0.7621189322033898], 
             UndirectedEdge[79, 373] -> 
             RGBColor[
              0.9797975000000001, 0.9431900677966102, 0.5314713305084746], 
             UndirectedEdge[34, 43] -> 
             RGBColor[
              0.9773586610169491, 0.9824473389830508, 0.9148193389830509], 
             UndirectedEdge[100, 358] -> 
             RGBColor[
              0.9726846949152543, 0.9195212033898306, 0.34838562711864407`], 
             UndirectedEdge[273, 394] -> 
             RGBColor[
              0.9915438050847457, 0.9890238983050847, 0.6627970593220338], 
             UndirectedEdge[89, 189] -> 
             RGBColor[
              0.9308566949152544, 0.758592593220339, 0.2774153644067797], 
             UndirectedEdge[268, 299] -> 
             RGBColor[
              0.5582377457627119, 0.5477508050847457, 0.6010546271186441], 
             UndirectedEdge[143, 272] -> 
             RGBColor[
              0.9849737711864406, 0.9673267457627119, 0.5977237372881355], 
             UndirectedEdge[339, 382] -> 
             RGBColor[
              0.9935194322033898, 0.9913036949152543, 0.7363876694915255], 
             UndirectedEdge[111, 223] -> 
             RGBColor[
              0.9901360423728813, 0.9899045762711864, 0.7924591949152544], 
             UndirectedEdge[71, 131] -> 
             RGBColor[
              0.9909587796610169, 0.9905292372881356, 0.7994999491525425], 
             UndirectedEdge[114, 370] -> 
             RGBColor[
              0.9801025593220339, 0.943031779661017, 0.5057400677966103], 
             UndirectedEdge[4, 125] -> 
             RGBColor[
              0.9909587796610169, 0.9905292372881356, 0.7994999491525423], 
             UndirectedEdge[246, 251] -> 
             RGBColor[
              0.9062240423728813, 0.846596406779661, 0.6282690762711864], 
             UndirectedEdge[30, 229] -> 
             RGBColor[
              0.9312374915254237, 0.9461076610169492, 0.921750686440678], 
             UndirectedEdge[115, 366] -> 
             RGBColor[
              0.9520393644067796, 0.8479003559322034, 0.5536231525423729], 
             UndirectedEdge[89, 270] -> 
             RGBColor[
              0.9279975508474576, 0.7960374576271187, 0.5943490677966101], 
             UndirectedEdge[197, 369] -> 
             RGBColor[
              0.9509115677966101, 0.8474339830508475, 0.5723136610169492], 
             UndirectedEdge[276, 301] -> 
             RGBColor[
              0.9760815677966102, 0.9306553559322034, 0.5170356355932203], 
             UndirectedEdge[69, 188] -> 
             RGBColor[
              0.9420044915254238, 0.7961967288135594, 0.3207224491525424], 
             UndirectedEdge[191, 225] -> 
             RGBColor[
              0.9941044576271186, 0.9897983559322034, 0.599684779661017], 
             UndirectedEdge[223, 247] -> 
             RGBColor[
              0.9536449491525423, 0.9644076610169492, 0.9426860084745763], 
             UndirectedEdge[72, 86] -> 
             RGBColor[
              0.9709464576271186, 0.9105099999999999, 0.422999686440678], 
             UndirectedEdge[19, 85] -> 
             RGBColor[
              0.9726846949152542, 0.9195212033898306, 0.34838562711864407`], 
             UndirectedEdge[320, 398] -> 
             RGBColor[
              0.9906986186440678, 0.9891620000000001, 0.7122479406779663], 
             UndirectedEdge[249, 300] -> 
             RGBColor[
              0.9686099915254237, 0.9658228813559322, 0.6881027542372882], 
             UndirectedEdge[18, 319] -> 
             RGBColor[
              0.9467780762711864, 0.8270411016949153, 0.5493897966101695], 
             UndirectedEdge[6, 273] -> 
             RGBColor[
              0.9714640932203389, 0.9749853220338983, 0.7387403813559321], 
             UndirectedEdge[158, 348] -> 
             RGBColor[
              0.9726846949152542, 0.9195212033898303, 0.34838562711864385`], 
             UndirectedEdge[61, 228] -> 
             RGBColor[
              0.9726846949152542, 0.9195212033898306, 0.34838562711864407`], 
             UndirectedEdge[70, 260] -> 
             RGBColor[
              0.9838184915254238, 0.9555664915254236, 0.5201757627118644], 
             UndirectedEdge[144, 305] -> 
             RGBColor[
              0.8982897542372881, 0.5590900508474577, 0.5421043644067797], 
             UndirectedEdge[165, 351] -> 
             RGBColor[
              0.9835358813559322, 0.9549620169491524, 0.4894153898305083], 
             UndirectedEdge[132, 370] -> 
             RGBColor[
              0.9789721186440679, 0.9406138813559322, 0.3826985762711864], 
             UndirectedEdge[104, 145] -> 
             RGBColor[
              0.9946472288135593, 0.9917700677966101, 0.7176971610169492], 
             UndirectedEdge[207, 231] -> 
             RGBColor[
              0.9270259152542373, 0.7483891016949151, 0.26014154237288134`], 
             UndirectedEdge[21, 249] -> 
             RGBColor[
              0.9886897033898305, 0.9798614576271187, 0.6121594322033899], 
             UndirectedEdge[7, 93] -> 
             RGBColor[
              0.8856800762711865, 0.7629093050847457, 0.6116231949152542], 
             UndirectedEdge[140, 255] -> 
             RGBColor[
              0.9308566949152544, 0.758592593220339, 0.2774153644067797], 
             UndirectedEdge[100, 157] -> 
             RGBColor[
              0.9289688305084746, 0.7413433050847458, 0.2985101440677965], 
             UndirectedEdge[42, 178] -> 
             RGBColor[
              0.977541906779661, 0.9422573220338983, 0.5688523474576271], 
             UndirectedEdge[115, 195] -> 
             RGBColor[
              0.9467780762711864, 0.8270411016949153, 0.5493897966101696], 
             UndirectedEdge[281, 394] -> 
             RGBColor[
              0.9738259745762712, 0.9297226101694915, 0.5544166525423728], 
             UndirectedEdge[215, 224] -> 
             RGBColor[
              0.920287940677966, 0.6905579830508475, 0.5072085677966102], 
             UndirectedEdge[99, 222] -> 
             RGBColor[
              0.9305963898305085, 0.7412766271186442, 0.3289347881355932], 
             UndirectedEdge[55, 284] -> 
             RGBColor[
              0.9723119237288136, 0.9767987457627119, 0.8310215000000001], 
             UndirectedEdge[32, 337] -> 
             RGBColor[
              0.946139372881356, 0.8214204406779662, 0.28982788983050856`], 
             UndirectedEdge[172, 399] -> 
             RGBColor[
              0.9002082288135593, 0.676519406779661, 0.5831518898305085], 
             UndirectedEdge[267, 346] -> 
             RGBColor[
              0.9915438050847457, 0.9890238983050847, 0.6627970593220338], 
             UndirectedEdge[222, 393] -> 
             RGBColor[
              0.9826880508474576, 0.953148593220339, 0.3971342711864405], 
             UndirectedEdge[116, 179] -> 
             RGBColor[
              0.9228946694915254, 0.8097909999999999, 0.6149903389830509], 
             UndirectedEdge[120, 360] -> 
             RGBColor[
              0.9835134322033898, 0.9557247796610169, 0.5459070254237287], 
             UndirectedEdge[144, 222] -> 
             RGBColor[
              0.9050052033898306, 0.5604514915254237, 0.3050504576271186], 
             UndirectedEdge[237, 307] -> 
             RGBColor[
              0.9826880508474576, 0.953148593220339, 0.3971342711864405], 
             UndirectedEdge[18, 144] -> 
             RGBColor[
              0.8616498813559322, 0.39953954237288136`, 0.20371305932203393`],
              UndirectedEdge[309, 365] -> 
             RGBColor[
              0.986686593220339, 0.966287779661017, 0.44233033898305063`], 
             UndirectedEdge[189, 241] -> 
             RGBColor[
              0.9801025593220339, 0.943031779661017, 0.5057400677966103], 
             UndirectedEdge[268, 370] -> 
             RGBColor[
              0.5720899152542374, 0.5999228898305085, 0.6265076186440679], 
             UndirectedEdge[336, 359] -> 
             RGBColor[
              0.9534730084745762, 0.8834024576271187, 0.6026472203389831], 
             UndirectedEdge[115, 123] -> 
             RGBColor[
              0.9726981779661017, 0.9292562372881357, 0.5731071610169493], 
             UndirectedEdge[6, 394] -> 
             RGBColor[
              0.9697512711864407, 0.9760242881355932, 0.8941337796610169], 
             UndirectedEdge[259, 353] -> 
             RGBColor[
              0.9868237881355932, 0.9872279661016949, 0.775217940677966], 
             UndirectedEdge[98, 348] -> 
             RGBColor[
              0.9033583220338983, 0.5910556271186438, 0.26430398305084735`], 
             UndirectedEdge[145, 349] -> 
             RGBColor[
              0.9801025593220339, 0.943031779661017, 0.5057400677966103], 
             UndirectedEdge[287, 292] -> 
             RGBColor[
              0.9906986186440678, 0.9891620000000001, 0.7122479406779663], 
             UndirectedEdge[53, 69] -> 
             RGBColor[
              0.9329290423728813, 0.7997153559322034, 0.586001338983051], 
             UndirectedEdge[236, 284] -> 
             RGBColor[
              0.9935194322033898, 0.9913036949152543, 0.7363876694915255], 
             UndirectedEdge[119, 146] -> 
             RGBColor[
              0.9818698474576271, 0.9843128305084745, 0.8400573050847457], 
             UndirectedEdge[198, 310] -> 
             RGBColor[
              0.8638415084745763, 0.4746179152542373, 0.20809835593220338`], 
             UndirectedEdge[198, 384] -> 
             RGBColor[
              0.8778211016949153, 0.5380959830508475, 0.21976327118644068`], 
             UndirectedEdge[111, 292] -> 
             RGBColor[
              0.9912638389830508, 0.9903709491525424, 0.7737686864406781], 
             UndirectedEdge[40, 295] -> 
             RGBColor[
              0.9875344237288135, 0.9681012033898305, 0.5346114576271187], 
             UndirectedEdge[5, 270] -> 
             RGBColor[
              0.9327576525423729, 0.8171467966101695, 0.5982948813559321], 
             UndirectedEdge[104, 355] -> 
             RGBColor[
              0.9872293644067797, 0.9682594915254237, 0.560342720338983], 
             UndirectedEdge[356, 360] -> 
             RGBColor[
              0.9935167881355933, 0.9893521694915255, 0.5946556694915254], 
             UndirectedEdge[42, 398] -> 
             RGBColor[
              0.9918264152542373, 0.989628372881356, 0.6935574322033898], 
             UndirectedEdge[153, 211] -> 
             RGBColor[
              0.9606840423728813, 0.8701587288135594, 0.5017849830508475], 
             UndirectedEdge[223, 385] -> 
             RGBColor[0.9827181779661016, 0.966394, 0.6351047542372881], 
             UndirectedEdge[144, 361] -> 
             RGBColor[
              0.9058530338983051, 0.5622649152542373, 0.3973315762711864], 
             UndirectedEdge[216, 229] -> 
             RGBColor[
              0.9270800508474576, 0.9435691525423728, 0.953960313559322], 
             UndirectedEdge[161, 389] -> 
             RGBColor[
              0.948871313559322, 0.8969059152542371, 0.623576033898305], 
             UndirectedEdge[313, 340] -> 
             RGBColor[
              0.9726846949152542, 0.9195212033898306, 0.34838562711864407`], 
             UndirectedEdge[241, 380] -> 
             RGBColor[
              0.982174906779661, 0.9841545423728814, 0.8143260423728815], 
             UndirectedEdge[258, 281] -> 
             RGBColor[
              0.9761040169491525, 0.929892593220339, 0.46054399999999995`], 
             UndirectedEdge[344, 346] -> 
             RGBColor[
              0.9746827627118644, 0.979702186440678, 0.8857860508474575], 
             UndirectedEdge[79, 205] -> 
             RGBColor[
              0.9764141101694915, 0.9417909491525425, 0.5875428559322036], 
             UndirectedEdge[227, 306] -> 
             RGBColor[
              0.9654025593220339, 0.8890462711864406, 0.38800595762711854`], 
             UndirectedEdge[43, 381] -> 
             RGBColor[
              0.9818698474576271, 0.9843128305084745, 0.8400573050847457], 
             UndirectedEdge[98, 143] -> 
             RGBColor[
              0.9119314661016948, 0.6263264576271185, 0.4992063983050847], 
             UndirectedEdge[243, 267] -> 
             RGBColor[
              0.9813270762711863, 0.9823411186440678, 0.7220449237288135], 
             UndirectedEdge[58, 152] -> 
             RGBColor[
              0.9525307033898305, 0.9245408474576271, 0.6531433983050847], 
             UndirectedEdge[376, 397] -> 
             RGBColor[
              0.9108036694915254, 0.6258600847457625, 0.517896906779661], 
             UndirectedEdge[114, 279] -> 
             RGBColor[
              0.9457064237288135, 0.8071725932203391, 0.46364119491525435`], 
             UndirectedEdge[148, 218] -> 
             RGBColor[
              0.977541906779661, 0.9422573220338983, 0.5688523474576271], 
             UndirectedEdge[55, 366] -> 
             RGBColor[
              0.9330874491525423, 0.8343281525423728, 0.6108759661016949], 
             UndirectedEdge[99, 361] -> 
             RGBColor[
              0.931444220338983, 0.7430900508474576, 0.421215906779661], 
             UndirectedEdge[97, 169] -> 
             RGBColor[
              0.9674956779661017, 0.9750915423728814, 0.9315147966101696], 
             UndirectedEdge[43, 250] -> 
             RGBColor[
              0.9813270762711863, 0.9823411186440678, 0.7220449237288135], 
             UndirectedEdge[112, 177] -> 
             RGBColor[
              0.9697512711864407, 0.9760242881355932, 0.8941337796610169], 
             UndirectedEdge[255, 356] -> 
             RGBColor[
              0.9445759830508476, 0.8047546949152543, 0.3405997033898305], 
             UndirectedEdge[210, 328] -> 
             RGBColor[
              0.9869692033898305, 0.9668922542372882, 0.47309071186440677`], 
             UndirectedEdge[91, 221] -> 
             RGBColor[
              0.9801165593220339, 0.9445906271186439, 0.3772570169491524], 
             UndirectedEdge[32, 345] -> 
             RGBColor[
              0.9623936864406779, 0.9318966440677966, 0.6364479406779662], 
             UndirectedEdge[210, 258] -> 
             RGBColor[
              0.987251813559322, 0.9674967288135593, 0.5038510847457626], 
             UndirectedEdge[189, 359] -> 
             RGBColor[
              0.9514006610169492, 0.8422796949152542, 0.29406124576271186`], 
             UndirectedEdge[164, 258] -> 
             RGBColor[
              0.945423813559322, 0.8065681186440679, 0.43288082203389827`], 
             UndirectedEdge[354, 374] -> 
             RGBColor[
              0.9408780847457627, 0.8005611864406779, 0.28559453389830514`], 
             UndirectedEdge[235, 322] -> 
             RGBColor[
              0.9807420508474576, 0.9838464576271186, 0.8587478135593221], 
             UndirectedEdge[147, 392] -> 
             RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             UndirectedEdge[123, 283] -> 
             RGBColor[
              0.9652528305084745, 0.8944517796610169, 0.31951423728813544`], 
             UndirectedEdge[202, 239] -> 
             RGBColor[
              0.993214372881356, 0.9914619830508475, 0.7621189322033898], 
             UndirectedEdge[180, 249] -> 
             RGBColor[
              0.9801165593220339, 0.9445906271186439, 0.3772570169491524], 
             UndirectedEdge[2, 197] -> 
             RGBColor[
              0.9542949576271187, 0.8488331016949152, 0.5162421355932203], 
             UndirectedEdge[174, 329] -> 
             RGBColor[
              0.9426206355932203, 0.824502593220339, 0.5815994237288136], 
             UndirectedEdge[193, 242] -> 
             RGBColor[
              0.9935194322033898, 0.9913036949152543, 0.7363876694915255], 
             UndirectedEdge[58, 160] -> 
             RGBColor[
              0.9797975000000001, 0.9431900677966102, 0.5314713305084746], 
             UndirectedEdge[50, 137] -> 
             RGBColor[
              0.9909677457627118, 0.9800314406779661, 0.5182867796610169], 
             UndirectedEdge[326, 383] -> 
             RGBColor[
              0.9861015677966102, 0.9677931186440678, 0.5790332288135592], 
             UndirectedEdge[157, 238] -> 
             RGBColor[
              0.9338260423728812, 0.7640794237288135, 0.5189768644067796], 
             UndirectedEdge[243, 346] -> 
             RGBColor[
              0.9796142542372881, 0.9833800847457628, 0.8774383220338984], 
             UndirectedEdge[235, 355] -> 
             RGBColor[
              0.9861015677966102, 0.9677931186440678, 0.5790332288135592], 
             UndirectedEdge[44, 135] -> 
             RGBColor[
              0.9935167881355933, 0.9893521694915255, 0.5946556694915254], 
             UndirectedEdge[33, 206] -> 
             RGBColor[
              0.9829706610169491, 0.9537530677966102, 0.42789464406779637`], 
             UndirectedEdge[88, 263] -> 
             RGBColor[
              0.9838459745762711, 0.966860372881356, 0.6164142457627119], 
             UndirectedEdge[82, 399] -> 
             RGBColor[
              0.8507448983050847, 0.3910531016949153, 0.1962266779661017], 
             UndirectedEdge[271, 287] -> 
             RGBColor[
              0.9656851694915254, 0.8896507457627119, 0.41876633050847456`], 
             UndirectedEdge[31, 223] -> 
             RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             UndirectedEdge[108, 376] -> 
             RGBColor[
              0.9887031864406779, 0.9895964915254238, 0.8368809661016949], 
             UndirectedEdge[301, 361] -> 
             RGBColor[
              0.9761040169491525, 0.929892593220339, 0.46054399999999995`], 
             UndirectedEdge[80, 388] -> 
             RGBColor[
              0.9066462288135593, 0.6233215762711863, 0.550106533898305], 
             UndirectedEdge[47, 136] -> 
             RGBColor[
              0.9636092457627118, 0.9230398305084746, 0.6136645169491526], 
             UndirectedEdge[39, 50] -> 
             RGBColor[
              0.9909812288135593, 0.9897664745762712, 0.7430083135593221], 
             UndirectedEdge[120, 389] -> 
             RGBColor[
              0.961178127118644, 0.9407534576271186, 0.6592313644067795], 
             UndirectedEdge[28, 106] -> 
             RGBColor[
              0.8481652288135594, 0.6806648644067796, 0.597713466101695], 
             UndirectedEdge[97, 326] -> 
             RGBColor[0.9827181779661016, 0.966394, 0.6351047542372881], 
             UndirectedEdge[195, 242] -> 
             RGBColor[
              0.9504665254237288, 0.8282819322033899, 0.46758700847457635`], 
             UndirectedEdge[90, 260] -> 
             RGBColor[
              0.9710411101694915, 0.948109254237288, 0.642535906779661], 
             UndirectedEdge[73, 368] -> 
             RGBColor[
              0.9835134322033898, 0.9557247796610169, 0.5459070254237287], 
             UndirectedEdge[52, 287] -> 
             RGBColor[
              0.9766781949152542, 0.9792676949152542, 0.7611530254237289], 
             UndirectedEdge[135, 243] -> 
             RGBColor[
              0.9810444661016948, 0.9817366440677966, 0.6912845508474575], 
             UndirectedEdge[311, 317] -> 
             RGBColor[
              0.9834179491525423, 0.9865916101694916, 0.8877811016949153], 
             UndirectedEdge[6, 10] -> 
             RGBColor[
              0.9447400677966101, 0.9583078135593219, 0.9784248305084746], 
             UndirectedEdge[363, 383] -> 
             RGBColor[0.9659475762711864, 0.9728127627118643, 0.883791], 
             UndirectedEdge[227, 346] -> 
             RGBColor[
              0.9915438050847457, 0.9890238983050847, 0.6627970593220338], 
             UndirectedEdge[157, 341] -> 
             RGBColor[
              0.868501372881356, 0.49577727118644066`, 0.21198666101694913`], 
             UndirectedEdge[18, 310] -> 
             RGBColor[
              0.8872410677966103, 0.5803646779661018, 0.2275973898305085], 
             UndirectedEdge[37, 96] -> 
             RGBColor[
              0.9835134322033898, 0.9557247796610169, 0.5459070254237287], 
             UndirectedEdge[218, 222] -> 
             RGBColor[
              0.9912611949152542, 0.9884194237288135, 0.6320366864406779], 
             UndirectedEdge[65, 203] -> 
             RGBColor[
              0.9935167881355933, 0.9893521694915255, 0.5946556694915254], 
             UndirectedEdge[105, 303] -> 
             RGBColor[
              0.9909587796610169, 0.9905292372881356, 0.7994999491525425], 
             UndirectedEdge[119, 267] -> 
             RGBColor[
              0.9813270762711863, 0.9823411186440678, 0.7220449237288135], 
             UndirectedEdge[20, 312] -> 
             RGBColor[
              0.9383487372881356, 0.855187406779661, 0.6151093220338983], 
             UndirectedEdge[285, 324] -> 
             RGBColor[
              0.9940820084745763, 0.9905611186440678, 0.6561764152542373], 
             UndirectedEdge[16, 302] -> 
             RGBColor[
              0.975821406779661, 0.9292881186440678, 0.42978362711864404`], 
             UndirectedEdge[65, 313] -> 
             RGBColor[
              0.9760815677966102, 0.9306553559322034, 0.5170356355932203], 
             UndirectedEdge[280, 392] -> 
             RGBColor[
              0.9912638389830508, 0.9903709491525424, 0.7737686864406781], 
             UndirectedEdge[1, 357] -> 
             RGBColor[
              0.8863574999999999, 0.6658355254237289, 0.5943231016949152], 
             UndirectedEdge[26, 177] -> 
             RGBColor[
              0.9686099915254237, 0.9658228813559322, 0.6881027542372882], 
             UndirectedEdge[69, 293] -> 
             RGBColor[
              0.9092153305084746, 0.7816756779661018, 0.6138680084745762], 
             UndirectedEdge[165, 399] -> 
             RGBColor[
              0.9225659830508475, 0.690727966101695, 0.41333591525423724`], 
             UndirectedEdge[108, 297] -> 
             RGBColor[
              0.924506313559322, 0.7217607118644067, 0.5112002542372881], 
             UndirectedEdge[192, 335] -> 
             RGBColor[
              0.9869692033898305, 0.9668922542372882, 0.47309071186440677`], 
             UndirectedEdge[134, 272] -> 
             RGBColor[
              0.9861015677966102, 0.9677931186440678, 0.5790332288135592], 
             UndirectedEdge[86, 236] -> 
             RGBColor[
              0.9700788220338983, 0.9114108644067795, 0.5289422033898303], 
             UndirectedEdge[312, 389] -> 
             RGBColor[
              0.9496715593220338, 0.9619857118644067, 0.9700771016949152], 
             UndirectedEdge[156, 245] -> 
             RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             UndirectedEdge[153, 168] -> 
             RGBColor[
              0.9609891016949152, 0.8700004406779662, 0.4760537203389832], 
             UndirectedEdge[118, 150] -> 
             RGBColor[
              0.9329290423728813, 0.7997153559322034, 0.586001338983051], 
             UndirectedEdge[195, 255] -> 
             RGBColor[
              0.9012206610169492, 0.6438427457627119, 0.2392623050847458], 
             UndirectedEdge[109, 180] -> 
             RGBColor[
              0.9652528305084745, 0.8944517796610169, 0.31951423728813544`], 
             UndirectedEdge[143, 378] -> 
             RGBColor[
              0.9812578389830509, 0.954792033898305, 0.5832880423728812], 
             UndirectedEdge[135, 383] -> 
             RGBColor[
              0.9923889915254238, 0.9888857966101695, 0.6133461779661016], 
             UndirectedEdge[20, 120] -> 
             RGBColor[
              0.9498553050847458, 0.8339551525423728, 0.30426358474576265`], 
             UndirectedEdge[149, 230] -> 
             RGBColor[
              0.9909587796610169, 0.9905292372881356, 0.7994999491525423], 
             UndirectedEdge[16, 77] -> 
             RGBColor[
              0.9795373389830508, 0.9418228305084746, 0.44421932203389836`], 
             UndirectedEdge[168, 238] -> 
             RGBColor[
              0.9923916355932203, 0.9908373220338984, 0.7550781779661018], 
             UndirectedEdge[104, 335] -> 
             RGBColor[
              0.9872293644067797, 0.9682594915254237, 0.560342720338983], 
             UndirectedEdge[79, 232] -> 
             RGBColor[
              0.9356167966101696, 0.7797019322033898, 0.2813611779661017], 
             UndirectedEdge[47, 299] -> 
             RGBColor[
              0.9476847288135593, 0.8297449830508474, 0.2796255508474576], 
             UndirectedEdge[236, 397] -> 
             RGBColor[
              0.9130592627118643, 0.6267928305084745, 0.4805158898305084], 
             UndirectedEdge[33, 118] -> 
             RGBColor[
              0.9813270762711863, 0.9823411186440678, 0.7220449237288135], 
             UndirectedEdge[51, 79] -> 
             RGBColor[
              0.977541906779661, 0.9422573220338983, 0.5688523474576271], 
             UndirectedEdge[24, 168] -> 
             RGBColor[
              0.9457064237288135, 0.8071725932203391, 0.46364119491525435`], 
             UndirectedEdge[269, 365] -> 
             RGBColor[
              0.9510433305084746, 0.9426042881355932, 0.6848382711864406], 
             UndirectedEdge[98, 240] -> 
             RGBColor[
              0.9136442881355932, 0.6252874915254236, 0.3438129999999998], 
             UndirectedEdge[29, 113] -> 
             RGBColor[
              0.9345726271186441, 0.7711273050847458, 0.2918510593220338], 
             UndirectedEdge[330, 398] -> 
             RGBColor[
              0.934360720338983, 0.9461395423728813, 0.7784271525423729], 
             UndirectedEdge[43, 265] -> 
             RGBColor[
              0.9818698474576271, 0.9843128305084745, 0.8400573050847457], 
             UndirectedEdge[209, 304] -> 
             RGBColor[
              0.9088300338983051, 0.9278076610169492, 0.9008153644067797], 
             UndirectedEdge[107, 238] -> 
             RGBColor[
              0.9921090254237288, 0.9902328474576272, 0.7243178050847456], 
             UndirectedEdge[298, 347] -> 
             RGBColor[
              0.8880079067796611, 0.892536220338983, 0.6787742372881356], 
             UndirectedEdge[153, 343] -> 
             RGBColor[
              0.9561728559322034, 0.8682932372881357, 0.5765470169491527], 
             UndirectedEdge[110, 292] -> 
             RGBColor[
              0.9834179491525423, 0.9865916101694916, 0.8877811016949153], 
             UndirectedEdge[332, 366] -> 
             RGBColor[
              0.9545973728813559, 0.8467232881355932, 0.34877887288135584`], 
             UndirectedEdge[39, 136] -> 
             RGBColor[
              0.9784864576271186, 0.9829137118644068, 0.8961288305084747], 
             UndirectedEdge[115, 380] -> 
             RGBColor[
              0.9784864576271186, 0.9829137118644068, 0.8961288305084747], 
             UndirectedEdge[167, 238] -> 
             RGBColor[
              0.9886897033898305, 0.9798614576271187, 0.6121594322033899], 
             UndirectedEdge[1, 162] -> 
             RGBColor[
              0.922848593220339, 0.6913324406779662, 0.4440962881355933], 
             UndirectedEdge[128, 243] -> 
             RGBColor[
              0.9673251779661016, 0.9355745423728814, 0.6281002118644068], 
             UndirectedEdge[196, 366] -> 
             RGBColor[
              0.9281559576271186, 0.830650254237288, 0.6192236949152542], 
             UndirectedEdge[136, 149] -> 
             RGBColor[
              0.9796142542372881, 0.9833800847457628, 0.8774383220338984], 
             UndirectedEdge[263, 360] -> 
             RGBColor[
              0.9909587796610169, 0.9905292372881356, 0.7994999491525425], 
             UndirectedEdge[267, 354] -> 
             RGBColor[
              0.9792547288135593, 0.9412183559322034, 0.4134589491525423], 
             UndirectedEdge[192, 355] -> 
             RGBColor[
              0.9869692033898305, 0.9668922542372882, 0.47309071186440677`], 
             UndirectedEdge[24, 100] -> 
             RGBColor[
              0.9382885593220339, 0.7836620169491526, 0.30628675423728813`], 
             UndirectedEdge[11, 286] -> 
             RGBColor[
              0.9609891016949152, 0.8700004406779662, 0.4760537203389832], 
             UndirectedEdge[71, 110] -> 
             RGBColor[
              0.9834179491525423, 0.9865916101694916, 0.8877811016949153], 
             UndirectedEdge[186, 306] -> 
             RGBColor[
              0.9625484576271186, 0.8798838305084746, 0.3373683305084746], 
             UndirectedEdge[6, 131] -> 
             RGBColor[
              0.9720068644067796, 0.9769570338983051, 0.8567527627118644], 
             UndirectedEdge[53, 264] -> 
             RGBColor[
              0.964466033898305, 0.9730194067796609, 0.9450339152542373], 
             UndirectedEdge[83, 118] -> 
             RGBColor[
              0.9796142542372881, 0.9833800847457628, 0.8774383220338984], 
             UndirectedEdge[98, 272] -> 
             RGBColor[
              0.907074254237288, 0.6035903389830506, 0.2787396779661016], 
             UndirectedEdge[200, 330] -> 
             RGBColor[
              0.9009627542372881, 0.8257371525423729, 0.624035720338983], 
             UndirectedEdge[101, 389] -> 
             RGBColor[
              0.9383487372881356, 0.855187406779661, 0.6151093220338983], 
             UndirectedEdge[10, 353] -> 
             RGBColor[
              0.9595345423728814, 0.9693415084745762, 0.9533816440677966], 
             UndirectedEdge[174, 340] -> 
             RGBColor[
              0.946764593220339, 0.8173060677966102, 0.32466826271186444`], 
             UndirectedEdge[77, 187] -> 
             RGBColor[
              0.9764141101694915, 0.9417909491525425, 0.5875428559322036], 
             UndirectedEdge[137, 264] -> 
             RGBColor[
              0.9735414830508474, 0.9695007796610169, 0.6797550254237288], 
             UndirectedEdge[20, 356] -> 
             RGBColor[
              0.9598586610169492, 0.8675825423728813, 0.35301222881355926`], 
             UndirectedEdge[130, 227] -> 
             RGBColor[
              0.9862585677966101, 0.9860190169491526, 0.7136971949152541], 
             UndirectedEdge[24, 150] -> 
             RGBColor[
              0.896460559322034, 0.6227334067796612, 0.23531649152542378`], 
             UndirectedEdge[282, 339] -> 
             RGBColor[
              0.9923889915254238, 0.9888857966101695, 0.6133461779661016], 
             UndirectedEdge[69, 93] -> 
             RGBColor[
              0.8856800762711865, 0.7629093050847457, 0.6116231949152542], 
             UndirectedEdge[65, 266] -> 
             RGBColor[
              0.9943421694915254, 0.9919283559322034, 0.7434284237288136], 
             UndirectedEdge[189, 336] -> 
             RGBColor[
              0.9673251779661016, 0.9355745423728814, 0.6281002118644068], 
             UndirectedEdge[191, 322] -> 
             RGBColor[
              0.9813270762711863, 0.9823411186440678, 0.7220449237288135], 
             UndirectedEdge[297, 376] -> 
             RGBColor[
              0.9233785169491525, 0.7212943389830508, 0.5298907627118645], 
             UndirectedEdge[33, 286] -> 
             RGBColor[
              0.9601412711864407, 0.8681870169491526, 0.3837726016949151], 
             UndirectedEdge[145, 351] -> 
             RGBColor[
              0.9838184915254238, 0.9555664915254236, 0.5201757627118644], 
             UndirectedEdge[83, 141] -> 
             RGBColor[
              0.977541906779661, 0.9422573220338983, 0.5688523474576271], 
             UndirectedEdge[148, 276] -> 
             RGBColor[
              0.9797975000000001, 0.9431900677966102, 0.5314713305084746], 
             UndirectedEdge[124, 160] -> 
             RGBColor[
              0.9058305847457627, 0.5630276779661016, 0.4538232118644068], 
             UndirectedEdge[25, 362] -> 
             RGBColor[
              0.9932368220338983, 0.990699220338983, 0.7056272966101693], 
             UndirectedEdge[96, 208] -> 
             RGBColor[
              0.9075365593220339, 0.6231713898305085, 0.26830506779661006`], 
             UndirectedEdge[240, 272] -> 
             RGBColor[
              0.986686593220339, 0.966287779661017, 0.44233033898305063`], 
             UndirectedEdge[25, 182] -> 
             RGBColor[
              0.9926716016949153, 0.9894902711864407, 0.6441065508474575], 
             UndirectedEdge[101, 380] -> 
             RGBColor[
              0.948211720338983, 0.8625432033898306, 0.5984138644067798], 
             UndirectedEdge[24, 358] -> 
             RGBColor[
              0.9308566949152544, 0.758592593220339, 0.2774153644067797], 
             UndirectedEdge[202, 234] -> 
             RGBColor[
              0.9920865762711865, 0.9909956101694916, 0.780809440677966], 
             UndirectedEdge[17, 62] -> 
             RGBColor[
              0.9578959745762712, 0.9649059152542373, 0.780671966101695], 
             UndirectedEdge[24, 211] -> 
             RGBColor[
              0.9454013644067797, 0.8073308813559323, 0.4893724576271187], 
             UndirectedEdge[2, 39] -> 
             RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             UndirectedEdge[164, 328] -> 
             RGBColor[
              0.9451412033898305, 0.8059636440677966, 0.4021204491525424], 
             UndirectedEdge[228, 301] -> 
             RGBColor[
              0.9726846949152542, 0.9195212033898306, 0.34838562711864407`], 
             UndirectedEdge[118, 286] -> 
             RGBColor[
              0.948211720338983, 0.8625432033898306, 0.5984138644067797], 
             UndirectedEdge[139, 215] -> 
             RGBColor[
              0.9217181525423729, 0.6889145423728814, 0.3210547966101694], 
             UndirectedEdge[239, 377] -> 
             RGBColor[
              0.9554227542372882, 0.8492994745762712, 0.4975516271186441], 
             UndirectedEdge[348, 374] -> 
             RGBColor[
              0.9445940169491525, 0.8130958983050847, 0.30003022881355923`], 
             UndirectedEdge[8, 388] -> 
             RGBColor[
              0.8805289322033898, 0.5054895762711863, 0.2201819406779661], 
             UndirectedEdge[249, 370] -> 
             RGBColor[
              0.9764006271186441, 0.9320559152542374, 0.36282132203389833`], 
             UndirectedEdge[61, 285] -> 
             RGBColor[
              0.975821406779661, 0.9292881186440678, 0.42978362711864404`], 
             UndirectedEdge[162, 280] -> 
             RGBColor[
              0.9949522881355932, 0.991611779661017, 0.6919658983050849], 
             UndirectedEdge[126, 205] -> 
             RGBColor[
              0.9735549661016949, 0.979235813559322, 0.904476559322034], 
             UndirectedEdge[161, 334] -> 
             RGBColor[
              0.964093813559322, 0.8882083728813559, 0.32716599152542364`], 
             UndirectedEdge[192, 399] -> 
             RGBColor[
              0.922283372881356, 0.6901234915254237, 0.3825755423728814], 
             UndirectedEdge[69, 281] -> 
             RGBColor[
              0.9271407627118644, 0.7460578813559322, 0.2629796694915254], 
             UndirectedEdge[38, 128] -> 
             RGBColor[
              0.895464152542373, 0.5464051525423728, 0.24586720338983054`], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.9906986186440678, 0.9891620000000001, 0.7122479406779663], 
             UndirectedEdge[145, 355] -> 
             RGBColor[
              0.9875344237288135, 0.9681012033898305, 0.5346114576271187], 
             UndirectedEdge[23, 139] -> 
             RGBColor[
              0.9598586610169492, 0.8675825423728813, 0.35301222881355926`], 
             UndirectedEdge[120, 359] -> 
             RGBColor[
              0.9551165932203389, 0.8548144067796609, 0.30849694067796596`], 
             UndirectedEdge[117, 309] -> 
             RGBColor[
              0.993821847457627, 0.9891938813559322, 0.5689244067796608], 
             UndirectedEdge[19, 167] -> 
             RGBColor[
              0.9875484237288136, 0.9696600508474577, 0.406128406779661], 
             UndirectedEdge[26, 285] -> 
             RGBColor[
              0.9906851355932204, 0.979426966101695, 0.487526406779661], 
             UndirectedEdge[166, 169] -> 
             RGBColor[
              0.8887503220338984, 0.9137690847457627, 0.976758686440678], 
             UndirectedEdge[31, 383] -> 
             RGBColor[
              0.993214372881356, 0.9914619830508475, 0.7621189322033898], 
             UndirectedEdge[146, 346] -> 
             RGBColor[
              0.9920865762711863, 0.9909956101694916, 0.7808094406779661], 
             UndirectedEdge[191, 349] -> 
             RGBColor[
              0.9792547288135593, 0.9412183559322034, 0.4134589491525423], 
             UndirectedEdge[212, 362] -> 
             RGBColor[
              0.9581785847457627, 0.9655103898305084, 0.8114323389830508], 
             UndirectedEdge[242, 380] -> 
             RGBColor[
              0.982174906779661, 0.9841545423728814, 0.8143260423728815], 
             UndirectedEdge[175, 307] -> 
             RGBColor[
              0.9929740169491525, 0.9873804576271187, 0.476643288135593], 
             UndirectedEdge[140, 193] -> 
             RGBColor[
              0.9786697033898306, 0.9427236949152542, 0.5501618389830508], 
             UndirectedEdge[8, 25] -> 
             RGBColor[
              0.9595562457627118, 0.8696923559322034, 0.5204754915254237], 
             UndirectedEdge[8, 269] -> 
             RGBColor[
              0.9244980084745762, 0.8445035254237289, 0.6262805338983051], 
             UndirectedEdge[155, 371] -> 
             RGBColor[
              0.9875753898305084, 0.9891301186440679, 0.8555714745762713], 
             UndirectedEdge[55, 161] -> 
             RGBColor[
              0.948871313559322, 0.8969059152542371, 0.6235760338983051], 
             UndirectedEdge[110, 202] -> 
             RGBColor[
              0.9856735423728813, 0.9875243559322034, 0.8504000847457627], 
             UndirectedEdge[332, 380] -> 
             RGBColor[
              0.9810444661016948, 0.9817366440677966, 0.6912845508474575], 
             UndirectedEdge[359, 360] -> 
             RGBColor[
              0.9659453305084746, 0.8910179830508475, 0.5060183389830508], 
             UndirectedEdge[128, 350] -> 
             RGBColor[
              0.9623936864406779, 0.9318966440677966, 0.6364479406779662], 
             UndirectedEdge[272, 378] -> 
             RGBColor[
              0.9764006271186441, 0.9320559152542371, 0.36282132203389816`], 
             UndirectedEdge[52, 345] -> 
             RGBColor[
              0.9595345423728813, 0.9693415084745762, 0.9533816440677966], 
             UndirectedEdge[32, 333] -> 
             RGBColor[
              0.9615368983050847, 0.8819170677966102, 0.30507854237288135`], 
             UndirectedEdge[85, 168] -> 
             RGBColor[
              0.9763866271186441, 0.9304970677966102, 0.491304372881356], 
             UndirectedEdge[23, 354] -> 
             RGBColor[
              0.946139372881356, 0.8214204406779662, 0.28982788983050856`], 
             UndirectedEdge[51, 373] -> 
             RGBColor[
              0.9920865762711863, 0.9909956101694916, 0.7808094406779661], 
             UndirectedEdge[55, 334] -> 
             RGBColor[
              0.9648940593220339, 0.9532881694915254, 0.6736670593220339], 
             UndirectedEdge[66, 267] -> 
             RGBColor[
              0.9904160084745762, 0.9885575254237289, 0.6814875677966101], 
             UndirectedEdge[30, 153] -> 
             RGBColor[
              0.9573006525423728, 0.8687596101694917, 0.5578565084745764], 
             UndirectedEdge[179, 290] -> 
             RGBColor[
              0.9599625677966102, 0.9496102711864407, 0.6820147881355931], 
             UndirectedEdge[178, 200] -> 
             RGBColor[
              0.946139372881356, 0.8214204406779662, 0.28982788983050856`], 
             UndirectedEdge[340, 358] -> 
             RGBColor[
              0.9764006271186441, 0.9320559152542374, 0.36282132203389833`], 
             UndirectedEdge[31, 259] -> 
             RGBColor[
              0.9943646186440678, 0.9911655932203389, 0.6869367881355932], 
             UndirectedEdge[92, 146] -> 
             RGBColor[0.9407415, 0.7861715254237288, 0.48548415254237287`], 
             UndirectedEdge[3, 373] -> 
             RGBColor[
              0.9943646186440678, 0.9911655932203389, 0.6869367881355932], 
             UndirectedEdge[174, 341] -> 
             RGBColor[
              0.8825812033898306, 0.5592053220338983, 0.22370908474576273`], 
             UndirectedEdge[248, 260] -> 
             RGBColor[
              0.9764006271186441, 0.9320559152542371, 0.36282132203389816`], 
             UndirectedEdge[41, 325] -> 
             RGBColor[
              0.9673251779661016, 0.9355745423728814, 0.6281002118644068], 
             UndirectedEdge[66, 346] -> 
             RGBColor[
              0.9887031864406779, 0.9895964915254238, 0.8368809661016949], 
             UndirectedEdge[53, 142] -> 
             RGBColor[
              0.9813270762711863, 0.9823411186440678, 0.7220449237288135], 
             UndirectedEdge[38, 44] -> 
             RGBColor[
              0.9100088220338983, 0.5951434406779661, 0.4578242966101695], 
             UndirectedEdge[76, 187] -> 
             RGBColor[
              0.9678232288135593, 0.9104781186440678, 0.5663232203389832], 
             UndirectedEdge[156, 160] -> 
             RGBColor[
              0.9909587796610169, 0.9905292372881356, 0.7994999491525425], 
             UndirectedEdge[141, 290] -> 
             RGBColor[
              0.9726846949152543, 0.9195212033898306, 0.34838562711864407`], 
             UndirectedEdge[3, 79] -> 
             RGBColor[
              0.9798199491525423, 0.9424273050847458, 0.4749796949152542], 
             UndirectedEdge[301, 382] -> 
             RGBColor[
              0.9763866271186441, 0.9304970677966102, 0.491304372881356], 
             UndirectedEdge[193, 389] -> 
             RGBColor[
              0.9708790677966102, 0.9764906610169491, 0.8754432711864406], 
             UndirectedEdge[189, 291] -> 
             RGBColor[
              0.975286313559322, 0.9413245762711865, 0.6062333644067797], 
             UndirectedEdge[161, 196] -> 
             RGBColor[
              0.9439398220338983, 0.8932280169491524, 0.6319237627118643], 
             UndirectedEdge[83, 161] -> 
             RGBColor[
              0.9689510254237288, 0.9109444915254237, 0.5476327118644068], 
             UndirectedEdge[100, 211] -> 
             RGBColor[
              0.9872293644067797, 0.9682594915254237, 0.560342720338983], 
             UndirectedEdge[32, 287] -> 
             RGBColor[
              0.9795373389830508, 0.9418228305084746, 0.44421932203389836`], 
             UndirectedEdge[156, 181] -> 
             RGBColor[
              0.987561906779661, 0.9793950847457628, 0.6308499406779662], 
             UndirectedEdge[126, 176] -> 
             RGBColor[
              0.9735414830508474, 0.9695007796610169, 0.6797550254237288], 
             UndirectedEdge[46, 350] -> 
             RGBColor[
              0.938018940677966, 0.8380060508474576, 0.6025282372881355], 
             UndirectedEdge[47, 149] -> 
             RGBColor[
              0.9738259745762712, 0.9297226101694915, 0.5544166525423728], 
             UndirectedEdge[57, 108] -> 
             RGBColor[
              0.9845457457627118, 0.9870579830508475, 0.869090593220339], 
             UndirectedEdge[105, 400] -> 
             RGBColor[
              0.9838459745762711, 0.966860372881356, 0.6164142457627119], 
             UndirectedEdge[62, 256] -> 
             RGBColor[
              0.9139268983050848, 0.6258919661016947, 0.37457337288135595`], 
             UndirectedEdge[193, 332] -> 
             RGBColor[
              0.9923889915254238, 0.9888857966101695, 0.6133461779661016], 
             UndirectedEdge[1, 387] -> 
             RGBColor[
              0.888885406779661, 0.5697211016949153, 0.22818411016949153`], 
             UndirectedEdge[72, 284] -> 
             RGBColor[
              0.9943870677966102, 0.9904028305084747, 0.630445152542373], 
             UndirectedEdge[127, 394] -> 
             RGBColor[
              0.9738259745762712, 0.9297226101694915, 0.5544166525423728], 
             UndirectedEdge[110, 385] -> 
             RGBColor[
              0.979688533898305, 0.9643218644067797, 0.6486238728813558], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.8736027288135593, 0.5068932542372883, 0.21577158474576275`], 
             UndirectedEdge[97, 393] -> 
             RGBColor[
              0.9790022457627119, 0.9538592881355932, 0.6206690593220339], 
             UndirectedEdge[19, 150] -> 
             RGBColor[
              0.9420044915254238, 0.7961967288135594, 0.3207224491525424], 
             UndirectedEdge[272, 342] -> 
             RGBColor[
              0.9764006271186441, 0.9320559152542371, 0.36282132203389816`], 
             UndirectedEdge[96, 187] -> 
             RGBColor[
              0.9801300423728814, 0.954325661016949, 0.6019785508474575], 
             UndirectedEdge[129, 333] -> 
             RGBColor[
              0.9761040169491525, 0.929892593220339, 0.46054399999999995`], 
             UndirectedEdge[19, 160] -> 
             RGBColor[
              0.9909452966101695, 0.9807942033898305, 0.5747784152542372], 
             UndirectedEdge[183, 357] -> 
             RGBColor[
              0.9510433305084746, 0.9426042881355932, 0.6848382711864407], 
             UndirectedEdge[197, 217] -> 
             RGBColor[
              0.9478819237288135, 0.8453618474576271, 0.585832779661017], 
             UndirectedEdge[199, 345] -> 
             RGBColor[
              0.9595345423728813, 0.9693415084745762, 0.9533816440677966], 
             UndirectedEdge[44, 346] -> 
             RGBColor[
              0.9920865762711863, 0.9909956101694916, 0.7808094406779661], 
             UndirectedEdge[78, 80] -> 
             RGBColor[
              0.9862585677966101, 0.9860190169491526, 0.7136971949152541], 
             UndirectedEdge[42, 320] -> 
             RGBColor[
              0.9887031864406779, 0.9895964915254238, 0.8368809661016949], 
             UndirectedEdge[161, 332] -> 
             RGBColor[
              0.9703812372881355, 0.9093010508474575, 0.361478940677966], 
             UndirectedEdge[239, 309] -> 
             RGBColor[
              0.9937993983050848, 0.9899566440677967, 0.6254160423728812], 
             UndirectedEdge[8, 377] -> 
             RGBColor[
              0.921764627118644, 0.727529847457627, 0.255908186440678], 
             UndirectedEdge[75, 126] -> 
             RGBColor[
              0.9724271694915254, 0.9787694406779661, 0.9231670677966102], 
             UndirectedEdge[54, 310] -> 
             RGBColor[
              0.9291661779661017, 0.7429200677966102, 0.5150885593220339], 
             UndirectedEdge[65, 211] -> 
             RGBColor[
              0.9943421694915254, 0.9919283559322034, 0.7434284237288136], 
             UndirectedEdge[88, 356] -> 
             RGBColor[
              0.9864039830508475, 0.9656833050847458, 0.4115699661016948], 
             UndirectedEdge[98, 158] -> 
             RGBColor[
              0.9033583220338983, 0.5910556271186438, 0.26430398305084735`], 
             UndirectedEdge[13, 390] -> 
             RGBColor[
              0.9856735423728813, 0.9875243559322034, 0.8504000847457627], 
             UndirectedEdge[241, 242] -> 
             RGBColor[
              0.9949522881355932, 0.991611779661017, 0.6919658983050849], 
             UndirectedEdge[12, 238] -> 
             RGBColor[
              0.9875753898305084, 0.9891301186440679, 0.8555714745762713], 
             UndirectedEdge[175, 343] -> 
             RGBColor[
              0.9892882118644067, 0.988091152542373, 0.7001780762711863], 
             UndirectedEdge[59, 258] -> 
             RGBColor[
              0.9935392372881355, 0.988589406779661, 0.5381640338983049], 
             UndirectedEdge[152, 156] -> 
             RGBColor[
              0.9636919830508475, 0.9718800169491526, 0.9211720169491526], 
             UndirectedEdge[39, 258] -> 
             RGBColor[
              0.9909812288135593, 0.9897664745762712, 0.7430083135593221], 
             UndirectedEdge[183, 368] -> 
             RGBColor[
              0.9872293644067797, 0.9682594915254237, 0.560342720338983], 
             UndirectedEdge[44, 119] -> 
             RGBColor[
              0.9818698474576271, 0.9843128305084745, 0.8400573050847457], 
             UndirectedEdge[149, 264] -> 
             RGBColor[
              0.9746827627118644, 0.979702186440678, 0.8857860508474575], 
             UndirectedEdge[120, 241] -> 
             RGBColor[
              0.9838184915254238, 0.9555664915254236, 0.5201757627118644], 
             UndirectedEdge[116, 304] -> 
             RGBColor[
              0.8669049237288136, 0.7652522711864407, 0.6133241949152544], 
             UndirectedEdge[82, 256] -> 
             RGBColor[
              0.8423884237288135, 0.32682157627118624`, 0.18822450847457622`],
              UndirectedEdge[98, 186] -> 
             RGBColor[
              0.910790186440678, 0.6161250508474574, 0.29317537288135587`], 
             UndirectedEdge[72, 262] -> 
             RGBColor[
              0.9709464576271186, 0.9105099999999999, 0.422999686440678], 
             UndirectedEdge[147, 241] -> 
             RGBColor[
              0.9935194322033898, 0.9913036949152543, 0.7363876694915255], 
             UndirectedEdge[13, 205] -> 
             RGBColor[
              0.9834179491525423, 0.9865916101694916, 0.8877811016949153], 
             UndirectedEdge[142, 394] -> 
             RGBColor[
              0.9915438050847457, 0.9890238983050847, 0.6627970593220338], 
             UndirectedEdge[42, 75] -> 
             RGBColor[
              0.9875753898305084, 0.9891301186440679, 0.8555714745762713], 
             UndirectedEdge[56, 341] -> 
             RGBColor[
              0.8778211016949153, 0.5380959830508475, 0.21976327118644068`], 
             UndirectedEdge[306, 378] -> 
             RGBColor[
              0.9551165932203389, 0.8548144067796609, 0.30849694067796596`], 
             UndirectedEdge[27, 295] -> 
             RGBColor[
              0.9609891016949152, 0.8700004406779662, 0.4760537203389832], 
             UndirectedEdge[111, 247] -> 
             RGBColor[
              0.9584611949152542, 0.9661148644067796, 0.8421927118644068], 
             UndirectedEdge[128, 259] -> 
             RGBColor[
              0.9798199491525423, 0.9424273050847458, 0.4749796949152542], 
             UndirectedEdge[52, 68] -> 
             RGBColor[
              0.9772434152542373, 0.9804766440677966, 0.8226737711864407], 
             UndirectedEdge[241, 359] -> 
             RGBColor[
              0.9662503898305085, 0.8908596949152543, 0.4802870762711865], 
             UndirectedEdge[361, 382] -> 
             RGBColor[
              0.9946696779661017, 0.9910073050847458, 0.6612055254237288], 
             UndirectedEdge[14, 390] -> 
             RGBColor[
              0.9935194322033898, 0.9913036949152543, 0.7363876694915255], 
             UndirectedEdge[11, 332] -> 
             RGBColor[
              0.9938218474576271, 0.9891938813559322, 0.568924406779661], 
             UndirectedEdge[22, 209] -> 
             RGBColor[
              0.9849737711864406, 0.9673267457627119, 0.5977237372881355], 
             UndirectedEdge[33, 156] -> 
             RGBColor[
              0.9904160084745762, 0.9885575254237289, 0.6814875677966101], 
             UndirectedEdge[283, 332] -> 
             RGBColor[
              0.9826880508474576, 0.953148593220339, 0.3971342711864405], 
             UndirectedEdge[150, 181] -> 
             RGBColor[
              0.9420044915254238, 0.7961967288135594, 0.3207224491525424], 
             UndirectedEdge[117, 323] -> 
             RGBColor[
              0.9798199491525423, 0.9424273050847458, 0.4749796949152542], 
             UndirectedEdge[199, 223] -> 
             RGBColor[
              0.9724271694915254, 0.9787694406779661, 0.9231670677966102], 
             UndirectedEdge[128, 306] -> 
             RGBColor[
              0.9514006610169492, 0.8422796949152542, 0.29406124576271186`], 
             UndirectedEdge[184, 288] -> 
             RGBColor[
              0.9097486610169492, 0.5937762033898304, 0.37057228813559323`], 
             UndirectedEdge[145, 182] -> 
             RGBColor[
              0.9941044576271186, 0.9897983559322034, 0.599684779661017], 
             UndirectedEdge[284, 397] -> 
             RGBColor[
              0.9144921186440678, 0.6271009152542371, 0.4360941186440679], 
             UndirectedEdge[61, 148] -> 
             RGBColor[
              0.9615368983050847, 0.8819170677966102, 0.30507854237288135`], 
             UndirectedEdge[34, 159] -> 
             RGBColor[
              0.962564186440678, 0.9714136440677966, 0.9398625254237288], 
             UndirectedEdge[276, 382] -> 
             RGBColor[
              0.9946472288135593, 0.9917700677966101, 0.7176971610169492], 
             UndirectedEdge[59, 164] -> 
             RGBColor[
              0.9445759830508476, 0.8047546949152543, 0.3405997033898305], 
             UndirectedEdge[80, 377] -> 
             RGBColor[
              0.9478819237288135, 0.8453618474576271, 0.5858327796610169], 
             UndirectedEdge[180, 370] -> 
             RGBColor[
              0.9689687627118644, 0.9069864915254237, 0.33394993220338975`], 
             UndirectedEdge[98, 374] -> 
             RGBColor[
              0.8752676440677966, 0.48463032203389805`, 0.21594858474576267`],
              UndirectedEdge[139, 350] -> 
             RGBColor[
              0.9761129745762711, 0.9780587457627119, 0.6996322796610168], 
             UndirectedEdge[36, 276] -> 
             RGBColor[
              0.9937993983050848, 0.9899566440677967, 0.6254160423728812], 
             UndirectedEdge[53, 281] -> 
             RGBColor[
              0.9636092457627118, 0.9230398305084746, 0.6136645169491526], 
             UndirectedEdge[73, 183] -> 
             RGBColor[
              0.9764006271186441, 0.9320559152542371, 0.36282132203389816`], 
             UndirectedEdge[101, 115] -> 
             RGBColor[
              0.9573006525423728, 0.8687596101694917, 0.5578565084745764], 
             UndirectedEdge[283, 366] -> 
             RGBColor[
              0.9445940169491525, 0.8130958983050847, 0.30003022881355923`], 
             UndirectedEdge[22, 141] -> 
             RGBColor[
              0.9726846949152543, 0.9195212033898306, 0.34838562711864407`], 
             UndirectedEdge[197, 314] -> 
             RGBColor[
              0.9542949576271187, 0.8488331016949152, 0.5162421355932203], 
             UndirectedEdge[13, 14] -> 
             RGBColor[
              0.9871063983050847, 0.9878324406779662, 0.8059783135593221], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.9726846949152542, 0.9195212033898303, 0.34838562711864385`], 
             UndirectedEdge[323, 395] -> 
             RGBColor[
              0.921536966101695, 0.7162738813559322, 0.26963875423728817`], 
             UndirectedEdge[93, 131] -> 
             RGBColor[
              0.9346208813559322, 0.9475067796610169, 0.8656791610169492], 
             UndirectedEdge[52, 105] -> 
             RGBColor[
              0.9735549661016949, 0.979235813559322, 0.904476559322034], 
             UndirectedEdge[178, 330] -> 
             RGBColor[
              0.9200762118644068, 0.8987684915254237, 0.6537220677966102], 
             UndirectedEdge[92, 98] -> 
             RGBColor[
              0.8605863898305084, 0.4215023728813557, 0.2038811101694915], 
             UndirectedEdge[37, 323] -> 
             RGBColor[
              0.9797975000000001, 0.9431900677966102, 0.5314713305084746], 
             UndirectedEdge[279, 370] -> 
             RGBColor[
              0.9308566949152544, 0.758592593220339, 0.2774153644067797], 
             UndirectedEdge[150, 160] -> 
             RGBColor[
              0.9454013644067797, 0.8073308813559323, 0.4893724576271187], 
             UndirectedEdge[188, 273] -> 
             RGBColor[
              0.9904025254237288, 0.9788224915254238, 0.45676603389830495`], 
             UndirectedEdge[179, 386] -> 
             RGBColor[
              0.9665326016949152, 0.9713074237288135, 0.7470881101694914], 
             UndirectedEdge[141, 179] -> 
             RGBColor[
              0.9525307033898305, 0.9245408474576271, 0.6531433983050847], 
             UndirectedEdge[117, 388] -> 
             RGBColor[
              0.9142095084745763, 0.6264964406779658, 0.40533374576271175`], 
             UndirectedEdge[198, 214] -> 
             RGBColor[
              0.922250720338983, 0.720827966101695, 0.5485812711864407], 
             UndirectedEdge[150, 238] -> 
             RGBColor[
              0.9431457711864406, 0.8063981355932204, 0.5267534745762712], 
             UndirectedEdge[331, 392] -> 
             RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             UndirectedEdge[323, 365] -> 
             RGBColor[
              0.9726846949152543, 0.9195212033898306, 0.34838562711864407`], 
             UndirectedEdge[6, 71] -> 
             RGBColor[
              0.9686234745762712, 0.9755579152542373, 0.9128242881355932], 
             UndirectedEdge[132, 249] -> 
             RGBColor[
              0.9901199152542373, 0.9782180169491526, 0.42600566101694903`], 
             UndirectedEdge[348, 378] -> 
             RGBColor[
              0.9726846949152542, 0.9195212033898303, 0.34838562711864385`], 
             UndirectedEdge[174, 198] -> 
             RGBColor[
              0.8825812033898306, 0.5592053220338983, 0.22370908474576273`], 
             UndirectedEdge[72, 236] -> 
             RGBColor[
              0.9929542118644068, 0.9900947457627118, 0.6748669237288135], 
             UndirectedEdge[9, 100] -> 
             RGBColor[
              0.9838459745762711, 0.966860372881356, 0.6164142457627119], 
             UndirectedEdge[51, 298] -> 
             RGBColor[
              0.9849737711864406, 0.9673267457627119, 0.5977237372881355], 
             UndirectedEdge[23, 128] -> 
             RGBColor[
              0.946139372881356, 0.8214204406779662, 0.28982788983050856`], 
             UndirectedEdge[215, 353] -> 
             RGBColor[
              0.9150027033898305, 0.6875531016949152, 0.5581087033898304], 
             UndirectedEdge[80, 96] -> 
             RGBColor[
              0.9759726016949153, 0.9517871525423729, 0.6341881779661016], 
             UndirectedEdge[78, 388] -> 
             RGBColor[
              0.9136442881355932, 0.6252874915254236, 0.3438129999999998], 
             UndirectedEdge[312, 380] -> 
             RGBColor[
              0.9595345423728813, 0.9693415084745762, 0.9533816440677967], 
             UndirectedEdge[57, 325] -> 
             RGBColor[
              0.9743290169491525, 0.9803752033898305, 0.9283384576271186], 
             UndirectedEdge[308, 374] -> 
             RGBColor[
              0.9509115677966101, 0.8474339830508475, 0.5723136610169491], 
             UndirectedEdge[76, 365] -> 
             RGBColor[
              0.964093813559322, 0.8882083728813559, 0.32716599152542364`], 
             UndirectedEdge[182, 187] -> 
             RGBColor[
              0.9904160084745762, 0.9885575254237289, 0.6814875677966101], 
             UndirectedEdge[74, 286] -> 
             RGBColor[
              0.9595562457627118, 0.8696923559322034, 0.5204754915254237], 
             UndirectedEdge[137, 164] -> 
             RGBColor[
              0.9420044915254238, 0.7961967288135594, 0.3207224491525424], 
             UndirectedEdge[149, 258] -> 
             RGBColor[
              0.9921090254237288, 0.9902328474576272, 0.7243178050847456], 
             UndirectedEdge[147, 331] -> 
             RGBColor[
              0.9920865762711865, 0.9909956101694916, 0.780809440677966], 
             UndirectedEdge[42, 367] -> 
             RGBColor[
              0.9035749915254236, 0.5620949322033899, 0.4912042288135593], 
             UndirectedEdge[16, 365] -> 
             RGBColor[
              0.9869692033898305, 0.9668922542372882, 0.47309071186440677`], 
             UndirectedEdge[113, 183] -> 
             RGBColor[
              0.9764006271186441, 0.9320559152542371, 0.36282132203389816`], 
             UndirectedEdge[16, 323] -> 
             RGBColor[
              0.9795373389830508, 0.9418228305084746, 0.44421932203389836`], 
             UndirectedEdge[340, 343] -> 
             RGBColor[
              0.9864341101694916, 0.9789287118644068, 0.6495404491525424], 
             UndirectedEdge[323, 362] -> 
             RGBColor[
              0.9798199491525423, 0.9424273050847458, 0.4749796949152542], 
             UndirectedEdge[334, 364] -> 
             RGBColor[
              0.9039728220338983, 0.9050715423728813, 0.6803486440677966], 
             UndirectedEdge[94, 324] -> 
             RGBColor[
              0.9835134322033898, 0.9557247796610169, 0.5459070254237287], 
             UndirectedEdge[135, 350] -> 
             RGBColor[
              0.9761129745762711, 0.9780587457627119, 0.6996322796610168], 
             UndirectedEdge[31, 215] -> 
             RGBColor[
              0.922543533898305, 0.6914907288135593, 0.46982755084745764`], 
             UndirectedEdge[3, 21] -> 
             RGBColor[
              0.9921090254237288, 0.9902328474576272, 0.7243178050847456], 
             UndirectedEdge[127, 193] -> 
             RGBColor[
              0.9749537711864407, 0.9301889830508474, 0.5357261440677965], 
             UndirectedEdge[50, 230] -> 
             RGBColor[
              0.9932368220338983, 0.990699220338983, 0.7056272966101693], 
             UndirectedEdge[169, 382] -> 
             RGBColor[
              0.9723119237288136, 0.9767987457627119, 0.8310215000000001], 
             UndirectedEdge[12, 19] -> 
             RGBColor[
              0.9864341101694916, 0.9789287118644068, 0.6495404491525424], 
             UndirectedEdge[133, 296] -> 
             RGBColor[
              0.9823856355932203, 0.955258406779661, 0.5645975338983049], 
             UndirectedEdge[214, 332] -> 
             RGBColor[
              0.9890056016949152, 0.9874866779661018, 0.6694177033898304], 
             UndirectedEdge[76, 395] -> 
             RGBColor[
              0.9129460847457627, 0.6849610508474575, 0.24841911864406777`], 
             UndirectedEdge[299, 370] -> 
             RGBColor[
              0.9514006610169492, 0.8422796949152542, 0.29406124576271186`], 
             UndirectedEdge[170, 235] -> 
             RGBColor[
              0.9926716016949153, 0.9894902711864407, 0.6441065508474575], 
             UndirectedEdge[46, 400] -> 
             RGBColor[
              0.9483099491525424, 0.8256306101694915, 0.3144659237288135], 
             UndirectedEdge[65, 329] -> 
             RGBColor[
              0.9868013389830508, 0.9879907288135594, 0.8317095762711864], 
             UndirectedEdge[81, 267] -> 
             RGBColor[
              0.993821847457627, 0.9891938813559322, 0.5689244067796608], 
             UndirectedEdge[104, 182] -> 
             RGBColor[
              0.9937993983050848, 0.9899566440677967, 0.6254160423728812], 
             UndirectedEdge[23, 306] -> 
             RGBColor[
              0.9322872033898305, 0.7692483559322034, 0.26437489830508476`], 
             UndirectedEdge[209, 286] -> 
             RGBColor[0.9584284491525423, 0.8692259830508475, 0.539166], 
             UndirectedEdge[150, 167] -> 
             RGBColor[
              0.9420044915254238, 0.7961967288135594, 0.3207224491525424], 
             UndirectedEdge[4, 288] -> 
             RGBColor[
              0.9077532288135592, 0.5942106949152541, 0.495205313559322], 
             UndirectedEdge[171, 272] -> 
             RGBColor[
              0.9483099491525424, 0.8256306101694915, 0.3144659237288135], 
             UndirectedEdge[78, 182] -> 
             RGBColor[
              0.993256627118644, 0.9879849322033899, 0.5074036610169489], 
             UndirectedEdge[143, 374] -> 
             RGBColor[
              0.9531671610169491, 0.8483667288135592, 0.5349326440677966], 
             UndirectedEdge[55, 262] -> 
             RGBColor[
              0.948871313559322, 0.8969059152542371, 0.6235760338983051], 
             UndirectedEdge[165, 190] -> 
             RGBColor[
              0.9909812288135593, 0.9897664745762712, 0.7430083135593221], 
             UndirectedEdge[2, 149] -> 
             RGBColor[
              0.9909587796610169, 0.9905292372881356, 0.7994999491525423], 
             UndirectedEdge[39, 47] -> 
             RGBColor[
              0.9726981779661017, 0.9292562372881357, 0.5731071610169493], 
             UndirectedEdge[230, 300] -> 
             RGBColor[
              0.9708790677966102, 0.9764906610169491, 0.8754432711864406], 
             UndirectedEdge[40, 48] -> 
             RGBColor[
              0.9648940593220339, 0.9532881694915254, 0.6736670593220337], 
             UndirectedEdge[25, 208] -> 
             RGBColor[0.9172375, 0.6589085932203391, 0.48451697457627113`], 
             UndirectedEdge[32, 52] -> 
             RGBColor[
              0.9623936864406779, 0.9318966440677966, 0.6364479406779662], 
             UndirectedEdge[161, 366] -> 
             RGBColor[
              0.9322872033898304, 0.7692483559322032, 0.2643748983050847], 
             UndirectedEdge[190, 318] -> 
             RGBColor[
              0.914981906779661, 0.6579758474576273, 0.5218979915254238], 
             UndirectedEdge[179, 245] -> 
             RGBColor[0.9659475762711864, 0.9728127627118643, 0.883791], 
             UndirectedEdge[37, 182] -> 
             RGBColor[
              0.9937993983050848, 0.9899566440677967, 0.6254160423728812], 
             UndirectedEdge[12, 206] -> 
             RGBColor[
              0.9790022457627119, 0.9538592881355932, 0.6206690593220339], 
             UndirectedEdge[18, 218] -> 
             RGBColor[
              0.9479058728813559, 0.8275074745762712, 0.5306992881355932], 
             UndirectedEdge[92, 119] -> 
             RGBColor[0.9282691779661016, 0.778556, 0.5821130338983052], 
             UndirectedEdge[215, 400] -> 
             RGBColor[
              0.9154307288135592, 0.6678218644067797, 0.28674184745762704`], 
             UndirectedEdge[71, 292] -> 
             RGBColor[
              0.9875753898305084, 0.9891301186440679, 0.8555714745762714], 
             UndirectedEdge[158, 346] -> 
             RGBColor[
              0.9812578389830509, 0.954792033898305, 0.5832880423728812], 
             UndirectedEdge[92, 151] -> 
             RGBColor[
              0.9373581101694914, 0.7847724067796611, 0.5415556779661018], 
             UndirectedEdge[104, 170] -> 
             RGBColor[
              0.9937993983050848, 0.9899566440677967, 0.6254160423728812], 
             UndirectedEdge[82, 316] -> 
             RGBColor[
              0.9220007627118644, 0.6895190169491525, 0.35181516949152525`], 
             UndirectedEdge[287, 353] -> 
             RGBColor[
              0.9865411779661017, 0.9866234915254237, 0.7444575677966101], 
             UndirectedEdge[368, 372] -> 
             RGBColor[
              0.9720068644067796, 0.9769570338983051, 0.8567527627118644], 
             UndirectedEdge[9, 203] -> 
             RGBColor[
              0.9901333983050847, 0.9879530508474577, 0.6507271949152542], 
             UndirectedEdge[17, 384] -> 
             RGBColor[
              0.9092153305084746, 0.7816756779661018, 0.6138680084745762], 
             UndirectedEdge[82, 310] -> 
             RGBColor[
              0.8596231355932203, 0.443415186440678, 0.20410666949152545`], 
             UndirectedEdge[129, 287] -> 
             RGBColor[
              0.9941044576271186, 0.9897983559322034, 0.599684779661017], 
             UndirectedEdge[81, 363] -> 
             RGBColor[
              0.9670978220338983, 0.972516372881356, 0.8086088559322033], 
             UndirectedEdge[64, 356] -> 
             RGBColor[
              0.9935167881355933, 0.9893521694915255, 0.5946556694915254], 
             UndirectedEdge[245, 352] -> 
             RGBColor[
              0.9929542118644068, 0.9900947457627118, 0.6748669237288135], 
             UndirectedEdge[87, 232] -> 
             RGBColor[
              0.8965607966101695, 0.6226833898305084, 0.23537400000000003`], 
             UndirectedEdge[88, 255] -> 
             RGBColor[
              0.9382885593220339, 0.7836620169491526, 0.30628675423728813`], 
             UndirectedEdge[154, 392] -> 
             RGBColor[
              0.9430051186440678, 0.9554908474576271, 0.9228730932203391], 
             UndirectedEdge[22, 45] -> 
             RGBColor[
              0.9849737711864406, 0.9673267457627119, 0.5977237372881355], 
             UndirectedEdge[116, 141] -> 
             RGBColor[
              0.9356167966101696, 0.7797019322033898, 0.2813611779661017], 
             UndirectedEdge[97, 224] -> 
             RGBColor[
              0.9875753898305084, 0.9891301186440679, 0.8555714745762713], 
             UndirectedEdge[66, 151] -> 
             RGBColor[
              0.9875753898305084, 0.9891301186440679, 0.8555714745762714], 
             UndirectedEdge[165, 221] -> 
             RGBColor[
              0.9909677457627118, 0.9800314406779661, 0.5182867796610169], 
             UndirectedEdge[101, 332] -> 
             RGBColor[
              0.9598586610169492, 0.8675825423728813, 0.35301222881355926`], 
             UndirectedEdge[58, 396] -> 
             RGBColor[
              0.9798199491525423, 0.9424273050847458, 0.4749796949152542], 
             UndirectedEdge[35, 387] -> 
             RGBColor[
              0.9607064915254238, 0.869395966101695, 0.44529334745762705`], 
             UndirectedEdge[198, 266] -> 
             RGBColor[
              0.9267619067796611, 0.7226934576271187, 0.4738192372881356], 
             UndirectedEdge[188, 264] -> 
             RGBColor[
              0.9735414830508474, 0.9695007796610169, 0.6797550254237288], 
             UndirectedEdge[119, 151] -> 
             RGBColor[
              0.9784864576271186, 0.9829137118644068, 0.8961288305084747], 
             UndirectedEdge[247, 400] -> 
             RGBColor[
              0.9510433305084746, 0.9426042881355932, 0.6848382711864406], 
             UndirectedEdge[305, 361] -> 
             RGBColor[
              0.9868237881355932, 0.9872279661016949, 0.775217940677966], 
             UndirectedEdge[138, 210] -> 
             RGBColor[
              0.9510433305084746, 0.9426042881355932, 0.6848382711864406], 
             UndirectedEdge[197, 231] -> 
             RGBColor[
              0.9270259152542373, 0.7483891016949151, 0.26014154237288134`], 
             UndirectedEdge[225, 261] -> 
             RGBColor[
              0.9912503559322035, 0.9806359152542373, 0.549047152542373], 
             UndirectedEdge[83, 286] -> 
             RGBColor[0.9584284491525423, 0.8692259830508475, 0.539166], 
             UndirectedEdge[19, 238] -> 
             RGBColor[
              0.9886897033898305, 0.9798614576271187, 0.6121594322033899], 
             UndirectedEdge[62, 117] -> 
             RGBColor[
              0.9941044576271186, 0.9897983559322034, 0.599684779661017], 
             UndirectedEdge[65, 167] -> 
             RGBColor[
              0.9909452966101695, 0.9807942033898305, 0.5747784152542372], 
             UndirectedEdge[268, 371] -> 
             RGBColor[
              0.5843789915254236, 0.6477284322033898, 0.8758457288135593], 
             UndirectedEdge[172, 192] -> 
             RGBColor[
              0.9717467033898305, 0.9755897966101694, 0.7695007542372881], 
             UndirectedEdge[52, 353] -> 
             RGBColor[
              0.9693975254237288, 0.9766973050847458, 0.9366861864406779], 
             UndirectedEdge[126, 298] -> 
             RGBColor[
              0.9698255508474576, 0.9569660677966101, 0.6653193305084745], 
             UndirectedEdge[146, 306] -> 
             RGBColor[
              0.9659453305084746, 0.8910179830508475, 0.5060183389830508], 
             UndirectedEdge[21, 132] -> 
             RGBColor[
              0.9912611949152542, 0.9884194237288135, 0.6320366864406779], 
             UndirectedEdge[89, 162] -> 
             RGBColor[
              0.9457064237288135, 0.8071725932203391, 0.46364119491525435`], 
             UndirectedEdge[9, 18] -> 
             RGBColor[
              0.9467780762711864, 0.8270411016949153, 0.5493897966101696], 
             UndirectedEdge[255, 360] -> 
             RGBColor[
              0.9454013644067797, 0.8073308813559323, 0.4893724576271187], 
             UndirectedEdge[124, 152] -> 
             RGBColor[
              0.8785637881355932, 0.5443784576271187, 0.575495279661017], 
             UndirectedEdge[88, 389] -> 
             RGBColor[
              0.9648940593220339, 0.9532881694915254, 0.6736670593220337], 
             UndirectedEdge[12, 167] -> 
             RGBColor[
              0.9864341101694916, 0.9789287118644068, 0.6495404491525424], 
             UndirectedEdge[32, 303] -> 
             RGBColor[
              0.9797975000000001, 0.9431900677966102, 0.5314713305084746], 
             UndirectedEdge[49, 261] -> 
             RGBColor[
              0.9909452966101695, 0.9807942033898305, 0.5747784152542372], 
             UndirectedEdge[283, 360] -> 
             RGBColor[
              0.9835134322033898, 0.9557247796610169, 0.5459070254237287], 
             UndirectedEdge[282, 305] -> 
             RGBColor[
              0.9859759576271186, 0.9854145423728814, 0.6829368220338982], 
             UndirectedEdge[32, 385] -> 
             RGBColor[
              0.9726846949152543, 0.9195212033898306, 0.34838562711864407`], 
             UndirectedEdge[167, 216] -> 
             RGBColor[
              0.983404466101695, 0.9768565762711865, 0.6630595677966101], 
             UndirectedEdge[252, 318] -> 
             RGBColor[
              0.8952297457627119, 0.5793238474576272, 0.2326497372881356], 
             UndirectedEdge[2, 217] -> 
             RGBColor[
              0.9856735423728813, 0.9875243559322034, 0.8504000847457627], 
             UndirectedEdge[305, 329] -> 
             RGBColor[
              0.9792605084745762, 0.9840531016949153, 0.9199907288135593], 
             UndirectedEdge[87, 373] -> 
             RGBColor[0.9407415, 0.7861715254237288, 0.48548415254237287`], 
             UndirectedEdge[20, 241] -> 
             RGBColor[
              0.9609891016949152, 0.8700004406779662, 0.4760537203389832], 
             UndirectedEdge[59, 210] -> 
             RGBColor[
              0.9864039830508475, 0.9656833050847458, 0.4115699661016948], 
             UndirectedEdge[290, 304] -> 
             RGBColor[
              0.9039728220338983, 0.9050715423728813, 0.6803486440677966], 
             UndirectedEdge[115, 312] -> 
             RGBColor[
              0.9686234745762712, 0.9755579152542373, 0.9128242881355932], 
             UndirectedEdge[214, 389] -> 
             RGBColor[
              0.9674956779661017, 0.9750915423728814, 0.9315147966101696], 
             UndirectedEdge[144, 276] -> 
             RGBColor[
              0.9058305847457627, 0.5630276779661016, 0.4538232118644068], 
             UndirectedEdge[196, 286] -> 
             RGBColor[
              0.9334172457627119, 0.8515095084745763, 0.6234570508474576], 
             UndirectedEdge[124, 181] -> 
             RGBColor[
              0.9024337118644068, 0.5518935254237288, 0.2851732033898305], 
             UndirectedEdge[216, 341] -> 
             RGBColor[
              0.9192210762711864, 0.7187558305084746, 0.5621003898305084], 
             UndirectedEdge[294, 340] -> 
             RGBColor[
              0.987561906779661, 0.9793950847457628, 0.6308499406779662], 
             UndirectedEdge[104, 235] -> 
             RGBColor[
              0.993214372881356, 0.9914619830508475, 0.7621189322033898], 
             UndirectedEdge[125, 318] -> 
             RGBColor[0.9172375, 0.6589085932203391, 0.48451697457627113`], 
             UndirectedEdge[109, 232] -> 
             RGBColor[
              0.9319008644067797, 0.767167220338983, 0.26692548305084746`], 
             UndirectedEdge[182, 388] -> 
             RGBColor[
              0.9136442881355932, 0.6252874915254236, 0.3438129999999998], 
             UndirectedEdge[97, 382] -> 
             RGBColor[
              0.9901360423728813, 0.9899045762711864, 0.7924591949152544], 
             UndirectedEdge[140, 147] -> 
             RGBColor[
              0.9786697033898306, 0.9427236949152542, 0.5501618389830508], 
             UndirectedEdge[59, 300] -> 
             RGBColor[
              0.9711814830508474, 0.9743808474576271, 0.7079800084745762], 
             UndirectedEdge[205, 373] -> 
             RGBColor[
              0.9909587796610169, 0.9905292372881356, 0.7994999491525425], 
             UndirectedEdge[215, 259] -> 
             RGBColor[
              0.9225659830508475, 0.690727966101695, 0.4133359152542372], 
             UndirectedEdge[136, 300] -> 
             RGBColor[
              0.9595345423728813, 0.9693415084745762, 0.9533816440677967], 
             UndirectedEdge[152, 245] -> 
             RGBColor[0.9659475762711864, 0.9728127627118643, 0.883791], 
             UndirectedEdge[44, 128] -> 
             RGBColor[
              0.9797975000000001, 0.9431900677966102, 0.5314713305084746], 
             UndirectedEdge[241, 392] -> 
             RGBColor[
              0.9912638389830508, 0.9903709491525424, 0.7737686864406781], 
             UndirectedEdge[240, 342] -> 
             RGBColor[
              0.9829706610169491, 0.9537530677966102, 0.42789464406779637`], 
             UndirectedEdge[123, 214] -> 
             RGBColor[
              0.9715703813559322, 0.9287898644067797, 0.5917976694915255], 
             UndirectedEdge[125, 274] -> 
             RGBColor[
              0.9923889915254238, 0.9888857966101695, 0.6133461779661016], 
             UndirectedEdge[298, 373] -> 
             RGBColor[
              0.9872293644067797, 0.9682594915254237, 0.560342720338983], 
             UndirectedEdge[119, 350] -> 
             RGBColor[
              0.964466033898305, 0.9730194067796609, 0.9450339152542373], 
             UndirectedEdge[22, 179] -> 
             RGBColor[
              0.9599625677966102, 0.9496102711864407, 0.6820147881355931], 
             UndirectedEdge[1, 183] -> 
             RGBColor[
              0.9154307288135592, 0.6678218644067797, 0.28674184745762704`], 
             UndirectedEdge[112, 260] -> 
             RGBColor[
              0.9812578389830509, 0.954792033898305, 0.5832880423728812], 
             UndirectedEdge[183, 270] -> 
             RGBColor[
              0.9698255508474576, 0.9569660677966101, 0.6653193305084746], 
             UndirectedEdge[152, 181] -> 
             RGBColor[0.9636785, 0.9621449830508475, 0.6964504830508474], 
             UndirectedEdge[169, 276] -> 
             RGBColor[
              0.9720068644067796, 0.9769570338983051, 0.8567527627118644], 
             UndirectedEdge[349, 355] -> 
             RGBColor[
              0.9726846949152543, 0.9195212033898306, 0.34838562711864407`], 
             UndirectedEdge[171, 240] -> 
             RGBColor[
              0.9548799830508474, 0.8473277627118644, 0.3795392457627117], 
             UndirectedEdge[114, 132] -> 
             RGBColor[
              0.9938218474576271, 0.9891938813559322, 0.568924406779661], 
             UndirectedEdge[17, 222] -> 
             RGBColor[
              0.9573307542372882, 0.963696966101695, 0.7191512203389829], 
             UndirectedEdge[46, 259] -> 
             RGBColor[
              0.9554452033898304, 0.8485367118644067, 0.44105999152542363`], 
             UndirectedEdge[13, 79] -> 
             RGBColor[
              0.9722566694915254, 0.9392524406779661, 0.6197524830508474], 
             UndirectedEdge[146, 311] -> 
             RGBColor[
              0.9909587796610169, 0.9905292372881356, 0.7994999491525425], 
             UndirectedEdge[44, 275] -> 
             RGBColor[
              0.993214372881356, 0.9914619830508475, 0.7621189322033898], 
             UndirectedEdge[193, 195] -> 
             RGBColor[
              0.9490336694915255, 0.8279738474576271, 0.5120087796610169], 
             UndirectedEdge[86, 297] -> 
             RGBColor[
              0.9036263559322033, 0.6426423389830507, 0.24064250847457624`], 
             UndirectedEdge[197, 392] -> 
             RGBColor[
              0.9520393644067796, 0.8479003559322034, 0.5536231525423729], 
             UndirectedEdge[217, 392] -> 
             RGBColor[
              0.9834179491525423, 0.9865916101694916, 0.8877811016949153], 
             UndirectedEdge[101, 193] -> 
             RGBColor[
              0.9595562457627118, 0.8696923559322034, 0.5204754915254237], 
             UndirectedEdge[216, 340] -> 
             RGBColor[
              0.983404466101695, 0.9768565762711865, 0.6630595677966101], 
             UndirectedEdge[125, 190] -> 
             RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             UndirectedEdge[99, 276] -> 
             RGBColor[
              0.9314217711864408, 0.7438528135593221, 0.4777075423728814], 
             UndirectedEdge[27, 63] -> 
             RGBColor[
              0.9595562457627118, 0.8696923559322034, 0.5204754915254237], 
             UndirectedEdge[184, 226] -> 
             RGBColor[
              0.9940820084745763, 0.9905611186440678, 0.6561764152542373], 
             UndirectedEdge[107, 211] -> 
             RGBColor[
              0.9943646186440678, 0.9911655932203389, 0.6869367881355932], 
             UndirectedEdge[216, 294] -> 
             RGBColor[
              0.9834179491525423, 0.9865916101694916, 0.8877811016949153], 
             UndirectedEdge[68, 284] -> 
             RGBColor[
              0.9949522881355932, 0.991611779661017, 0.6919658983050849], 
             UndirectedEdge[89, 359] -> 
             RGBColor[
              0.9170045254237289, 0.7064205084745763, 0.2519623728813559], 
             UndirectedEdge[23, 267] -> 
             RGBColor[
              0.9601412711864407, 0.8681870169491526, 0.3837726016949151], 
             UndirectedEdge[140, 242] -> 
             RGBColor[
              0.9801025593220339, 0.943031779661017, 0.5057400677966103], 
             UndirectedEdge[64, 214] -> 
             RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             UndirectedEdge[296, 367] -> 
             RGBColor[
              0.8950018474576271, 0.5268241016949151, 0.2563018135593219], 
             UndirectedEdge[275, 346] -> 
             RGBColor[
              0.9909587796610169, 0.9905292372881356, 0.7994999491525423], 
             UndirectedEdge[301, 305] -> 
             RGBColor[
              0.9685407372881356, 0.9267177288135593, 0.6053167881355932], 
             UndirectedEdge[81, 119] -> 
             RGBColor[
              0.9818922966101694, 0.9835500677966101, 0.7835656694915254], 
             UndirectedEdge[327, 355] -> 
             RGBColor[
              0.9864039830508475, 0.9656833050847458, 0.4115699661016948], 
             UndirectedEdge[317, 344] -> 
             RGBColor[
              0.9693975254237288, 0.9766973050847458, 0.9366861864406779], 
             UndirectedEdge[184, 190] -> 
             RGBColor[
              0.9906986186440678, 0.9891620000000001, 0.7122479406779663], 
             UndirectedEdge[10, 303] -> 
             RGBColor[
              0.9670753728813559, 0.9732791355932203, 0.8651004915254237], 
             UndirectedEdge[149, 268] -> 
             RGBColor[
              0.5843789915254237, 0.6477284322033898, 0.8758457288135593], 
             UndirectedEdge[38, 267] -> 
             RGBColor[
              0.9094660508474577, 0.5931717288135592, 0.33981191525423715`], 
             UndirectedEdge[253, 366] -> 
             RGBColor[
              0.9408780847457627, 0.8005611864406779, 0.28559453389830514`], 
             UndirectedEdge[165, 355] -> 
             RGBColor[
              0.987251813559322, 0.9674967288135593, 0.5038510847457626], 
             UndirectedEdge[339, 340] -> 
             RGBColor[0.9898175, 0.9803278305084746, 0.5934689237288135], 
             UndirectedEdge[185, 318] -> 
             RGBColor[
              0.9075365593220339, 0.6231713898305085, 0.26830506779661006`], 
             UndirectedEdge[36, 70] -> 
             RGBColor[
              0.9941044576271186, 0.9897983559322034, 0.599684779661017], 
             UndirectedEdge[69, 131] -> 
             RGBColor[
              0.9454013644067797, 0.8073308813559323, 0.4893724576271187], 
             UndirectedEdge[283, 312] -> 
             RGBColor[
              0.961178127118644, 0.9407534576271186, 0.6592313644067795], 
             UndirectedEdge[75, 330] -> 
             RGBColor[
              0.9301096949152542, 0.9456412881355932, 0.9404411949152542], 
             UndirectedEdge[169, 222] -> 
             RGBColor[
              0.9711814830508474, 0.9743808474576271, 0.7079800084745762], 
             UndirectedEdge[90, 246] -> 
             RGBColor[
              0.9534730084745762, 0.8834024576271187, 0.6026472203389831], 
             UndirectedEdge[62, 362] -> 
             RGBColor[
              0.9941044576271186, 0.9897983559322034, 0.599684779661017], 
             UndirectedEdge[158, 374] -> 
             RGBColor[
              0.9445940169491525, 0.8130958983050847, 0.30003022881355923`], 
             UndirectedEdge[82, 172] -> 
             RGBColor[
              0.9002082288135593, 0.6765194067796609, 0.5831518898305085], 
             UndirectedEdge[306, 346] -> 
             RGBColor[
              0.9636897372881356, 0.8900852372881356, 0.5433993559322035], 
             UndirectedEdge[53, 188] -> 
             RGBColor[
              0.9784729745762711, 0.9731786779661017, 0.6714072966101695], 
             UndirectedEdge[84, 190] -> 
             RGBColor[
              0.9901333983050847, 0.9879530508474577, 0.6507271949152542], 
             UndirectedEdge[78, 96] -> 
             RGBColor[
              0.9829706610169491, 0.9537530677966102, 0.42789464406779637`], 
             UndirectedEdge[46, 199] -> 
             RGBColor[
              0.938018940677966, 0.8380060508474576, 0.6025282372881355], 
             UndirectedEdge[159, 265] -> 
             RGBColor[
              0.9670753728813559, 0.9732791355932203, 0.8651004915254237], 
             UndirectedEdge[332, 356] -> 
             RGBColor[
              0.9926914067796611, 0.9867759830508475, 0.4458829152542371], 
             UndirectedEdge[199, 222] -> 
             RGBColor[
              0.9761129745762711, 0.9780587457627119, 0.6996322796610168], 
             UndirectedEdge[114, 300] -> 
             RGBColor[
              0.9723119237288136, 0.9767987457627119, 0.8310215000000001], 
             UndirectedEdge[139, 213] -> 
             RGBColor[
              0.9662499915254237, 0.9707029491525423, 0.7163277372881356], 
             UndirectedEdge[106, 369] -> 
             RGBColor[
              0.9065744406779661, 0.9268749152542373, 0.9381963813559322], 
             UndirectedEdge[109, 114] -> 
             RGBColor[
              0.9763866271186441, 0.9304970677966102, 0.491304372881356], 
             UndirectedEdge[58, 245] -> 
             RGBColor[
              0.9786697033898306, 0.9427236949152542, 0.5501618389830508], 
             UndirectedEdge[151, 317] -> 
             RGBColor[
              0.9834179491525423, 0.9865916101694916, 0.8877811016949153], 
             UndirectedEdge[99, 218] -> 
             RGBColor[
              0.9291661779661017, 0.7429200677966102, 0.5150885593220339], 
             UndirectedEdge[55, 57] -> 
             RGBColor[
              0.9644660338983051, 0.973019406779661, 0.9450339152542373], 
             UndirectedEdge[247, 287] -> 
             RGBColor[
              0.9578959745762712, 0.9649059152542373, 0.780671966101695], 
             UndirectedEdge[44, 66] -> 
             RGBColor[
              0.9909587796610169, 0.9905292372881356, 0.7994999491525425], 
             UndirectedEdge[116, 290] -> 
             RGBColor[
              0.9430486610169492, 0.8047713559322034, 0.3102325677966101], 
             UndirectedEdge[278, 367] -> 
             RGBColor[
              0.856889779661017, 0.3784302033898306, 0.19976724576271188`], 
             UndirectedEdge[102, 297] -> 
             RGBColor[
              0.9265017457627118, 0.721326220338983, 0.3865672288135593], 
             UndirectedEdge[104, 187] -> 
             RGBColor[
              0.9909587796610169, 0.9905292372881356, 0.7994999491525425], 
             UndirectedEdge[136, 371] -> 
             RGBColor[
              0.9796142542372881, 0.9833800847457628, 0.8774383220338984], 
             UndirectedEdge[80, 302] -> 
             RGBColor[
              0.9685407372881356, 0.9267177288135593, 0.6053167881355932], 
             UndirectedEdge[176, 373] -> 
             RGBColor[
              0.9909452966101695, 0.9807942033898305, 0.5747784152542372], 
             UndirectedEdge[112, 219] -> 
             RGBColor[
              0.9909587796610169, 0.9905292372881356, 0.7994999491525423], 
             UndirectedEdge[33, 179] -> 
             RGBColor[
              0.9665326016949152, 0.9713074237288135, 0.7470881101694914], 
             UndirectedEdge[123, 334] -> 
             RGBColor[
              0.9689687627118644, 0.9069864915254238, 0.33394993220338975`], 
             UndirectedEdge[94, 307] -> 
             RGBColor[
              0.9826880508474576, 0.953148593220339, 0.3971342711864405], 
             UndirectedEdge[73, 89] -> 
             RGBColor[
              0.9345726271186441, 0.7711273050847458, 0.2918510593220338], 
             UndirectedEdge[267, 311] -> 
             RGBColor[
              0.9904160084745762, 0.9885575254237289, 0.6814875677966101], 
             UndirectedEdge[52, 391] -> 
             RGBColor[
              0.9327576525423729, 0.8171467966101695, 0.5982948813559322], 
             UndirectedEdge[105, 271] -> 
             RGBColor[
              0.9625619406779661, 0.8896188644067797, 0.5620898644067798], 
             UndirectedEdge[187, 377] -> 
             RGBColor[
              0.9520393644067796, 0.8479003559322034, 0.5536231525423729], 
             UndirectedEdge[58, 124] -> 
             RGBColor[
              0.8912859152542374, 0.5142893898305085, 0.24186611864406782`], 
             UndirectedEdge[11, 54] -> 
             RGBColor[
              0.9923916355932203, 0.9908373220338984, 0.7550781779661018], 
             UndirectedEdge[115, 283] -> 
             RGBColor[
              0.9801300423728814, 0.954325661016949, 0.6019785508474575], 
             UndirectedEdge[292, 362] -> 
             RGBColor[
              0.9909812288135593, 0.9897664745762712, 0.7430083135593221], 
             UndirectedEdge[15, 154] -> 
             RGBColor[
              0.9461283474576272, 0.9555227288135593, 0.7795495593220338], 
             UndirectedEdge[158, 311] -> 
             RGBColor[
              0.9801300423728814, 0.954325661016949, 0.6019785508474575], 
             UndirectedEdge[123, 253] -> 
             RGBColor[
              0.9615368983050847, 0.8819170677966102, 0.30507854237288135`], 
             UndirectedEdge[236, 376] -> 
             RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             UndirectedEdge[206, 386] -> 
             RGBColor[
              0.9829706610169491, 0.9537530677966102, 0.42789464406779637`], 
             UndirectedEdge[74, 338] -> 
             RGBColor[
              0.9929542118644068, 0.9900947457627118, 0.6748669237288135], 
             UndirectedEdge[293, 394] -> 
             RGBColor[
              0.9559005423728812, 0.965340406779661, 0.9053049915254237], 
             UndirectedEdge[41, 381] -> 
             RGBColor[
              0.9797975000000001, 0.9431900677966102, 0.5314713305084746], 
             UndirectedEdge[59, 328] -> 
             RGBColor[
              0.993256627118644, 0.9879849322033898, 0.5074036610169491], 
             UndirectedEdge[123, 196] -> 
             RGBColor[
              0.9488147711864406, 0.9120061355932203, 0.6387077033898305], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.9703812372881355, 0.9093010508474575, 0.361478940677966], 
             UndirectedEdge[23, 38] -> 
             RGBColor[
              0.8763506949152542, 0.47337381355932195`, 0.2161808559322034], 
             UndirectedEdge[61, 282] -> 
             RGBColor[
              0.9752561864406779, 0.9280791694915254, 0.3682628813559321], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.9670978220338983, 0.972516372881356, 0.8086088559322033], 
             UndirectedEdge[3, 232] -> 
             RGBColor[
              0.9501839152542373, 0.8276774576271186, 0.4368266355932203], 
             UndirectedEdge[110, 362] -> 
             RGBColor[
              0.9868237881355932, 0.9872279661016949, 0.775217940677966], 
             UndirectedEdge[125, 252] -> 
             RGBColor[
              0.9700788220338983, 0.9114108644067795, 0.5289422033898304], 
             UndirectedEdge[49, 327] -> 
             RGBColor[
              0.9935167881355933, 0.9893521694915255, 0.5946556694915254], 
             UndirectedEdge[89, 291] -> 
             RGBColor[
              0.9408901779661016, 0.8054653898305086, 0.5641344915254238], 
             UndirectedEdge[34, 250] -> 
             RGBColor[
              0.9892882118644067, 0.988091152542373, 0.7001780762711863], 
             UndirectedEdge[125, 226] -> 
             RGBColor[
              0.993214372881356, 0.9914619830508475, 0.7621189322033898], 
             UndirectedEdge[3, 14] -> 
             RGBColor[
              0.9946696779661017, 0.9910073050847458, 0.6612055254237288], 
             UndirectedEdge[105, 345] -> 
             RGBColor[
              0.9735549661016949, 0.979235813559322, 0.904476559322034], 
             UndirectedEdge[88, 336] -> 
             RGBColor[
              0.9747570423728813, 0.9606439661016949, 0.6569716016949152], 
             UndirectedEdge[162, 357] -> 
             RGBColor[
              0.9584611949152542, 0.9661148644067796, 0.8421927118644068], 
             UndirectedEdge[279, 328] -> 
             RGBColor[
              0.9451412033898305, 0.8059636440677966, 0.4021204491525424], 
             UndirectedEdge[312, 359] -> 
             RGBColor[
              0.9436100254237287, 0.8760466610169491, 0.6193426779661017], 
             UndirectedEdge[202, 289] -> 
             RGBColor[
              0.9929542118644068, 0.9900947457627118, 0.6748669237288135], 
             UndirectedEdge[27, 48] -> 
             RGBColor[
              0.9383487372881356, 0.855187406779661, 0.6151093220338983], 
             UndirectedEdge[115, 193] -> 
             RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             UndirectedEdge[117, 385] -> 
             RGBColor[
              0.987251813559322, 0.9674967288135593, 0.5038510847457626], 
             UndirectedEdge[179, 352] -> 
             RGBColor[
              0.9668152118644068, 0.9719118983050847, 0.7778484830508474], 
             UndirectedEdge[8, 365] -> 
             RGBColor[
              0.9535712372881355, 0.8464898644067798, 0.3186992796610169], 
             UndirectedEdge[105, 353] -> 
             RGBColor[
              0.9834179491525423, 0.9865916101694916, 0.8877811016949153], 
             UndirectedEdge[231, 392] -> 
             RGBColor[
              0.9625619406779661, 0.8896188644067797, 0.5620898644067798], 
             UndirectedEdge[109, 132] -> 
             RGBColor[
              0.9752561864406779, 0.9280791694915254, 0.3682628813559321], 
             UndirectedEdge[23, 158] -> 
             RGBColor[
              0.9498553050847458, 0.8339551525423728, 0.30426358474576265`], 
             UndirectedEdge[105, 350] -> 
             RGBColor[
              0.9735549661016949, 0.979235813559322, 0.904476559322034], 
             UndirectedEdge[172, 351] -> 
             RGBColor[
              0.961178127118644, 0.9407534576271186, 0.6592313644067795], 
             UndirectedEdge[34, 375] -> 
             RGBColor[
              0.9864341101694916, 0.9789287118644068, 0.6495404491525424], 
             UndirectedEdge[32, 391] -> 
             RGBColor[
              0.9356167966101696, 0.7797019322033898, 0.2813611779661017], 
             UndirectedEdge[140, 241] -> 
             RGBColor[
              0.9801025593220339, 0.943031779661017, 0.5057400677966103], 
             UndirectedEdge[89, 336] -> 
             RGBColor[
              0.9329290423728813, 0.7997153559322034, 0.586001338983051], 
             UndirectedEdge[74, 118] -> 
             RGBColor[
              0.9807420508474576, 0.9838464576271186, 0.8587478135593221], 
             UndirectedEdge[138, 328] -> 
             RGBColor[
              0.9578959745762712, 0.9649059152542373, 0.780671966101695], 
             UndirectedEdge[189, 207] -> 
             RGBColor[
              0.9408780847457627, 0.8005611864406779, 0.28559453389830514`], 
             UndirectedEdge[273, 281] -> 
             RGBColor[
              0.9755387966101694, 0.9286836440677966, 0.399023254237288], 
             UndirectedEdge[49, 225] -> 
             RGBColor[
              0.9946472288135593, 0.9917700677966101, 0.7176971610169492], 
             UndirectedEdge[43, 159] -> 
             RGBColor[
              0.9546030508474576, 0.9656636101694915, 0.961729372881356], 
             UndirectedEdge[113, 368] -> 
             RGBColor[
              0.9835134322033898, 0.9557247796610169, 0.5459070254237287], 
             UndirectedEdge[11, 83] -> 
             RGBColor[
              0.9923916355932203, 0.9908373220338984, 0.7550781779661018], 
             UndirectedEdge[151, 344] -> 
             RGBColor[
              0.9735549661016949, 0.979235813559322, 0.904476559322034], 
             UndirectedEdge[182, 377] -> 
             RGBColor[
              0.9548799830508474, 0.8473277627118644, 0.3795392457627117], 
             UndirectedEdge[198, 203] -> 
             RGBColor[
              0.9259365254237288, 0.7201172711864406, 0.3250464830508474], 
             UndirectedEdge[208, 395] -> 
             RGBColor[
              0.8601047627118644, 0.4324587796610171, 0.20399388983050848`], 
             UndirectedEdge[305, 339] -> 
             RGBColor[
              0.9856735423728813, 0.9875243559322034, 0.8504000847457627], 
             UndirectedEdge[9, 313] -> 
             RGBColor[
              0.9726981779661017, 0.9292562372881357, 0.5731071610169493], 
             UndirectedEdge[267, 317] -> 
             RGBColor[
              0.9862585677966101, 0.9860190169491526, 0.7136971949152541], 
             UndirectedEdge[306, 350] -> 
             RGBColor[
              0.9485415169491525, 0.8797245593220339, 0.6109949491525424], 
             UndirectedEdge[111, 362] -> 
             RGBColor[
              0.9946696779661017, 0.9910073050847458, 0.6612055254237288], 
             UndirectedEdge[104, 261] -> 
             RGBColor[
              0.9909452966101695, 0.9807942033898305, 0.5747784152542372], 
             UndirectedEdge[243, 363] -> 
             RGBColor[
              0.9546030508474576, 0.9656636101694915, 0.961729372881356], 
             UndirectedEdge[154, 369] -> 
             RGBColor[
              0.9418773220338983, 0.9550244745762713, 0.9415636016949153], 
             UndirectedEdge[218, 282] -> 
             RGBColor[
              0.9912611949152542, 0.9884194237288135, 0.6320366864406779], 
             UndirectedEdge[7, 293] -> 
             RGBColor[
              0.9092153305084746, 0.7816756779661018, 0.6138680084745762], 
             UndirectedEdge[24, 167] -> 
             RGBColor[
              0.9420044915254238, 0.7961967288135594, 0.3207224491525424], 
             UndirectedEdge[326, 363] -> 
             RGBColor[
              0.9599625677966102, 0.9496102711864407, 0.6820147881355931], 
             UndirectedEdge[276, 282] -> 
             RGBColor[
              0.9935167881355933, 0.9893521694915255, 0.5946556694915254], 
             UndirectedEdge[337, 345] -> 
             RGBColor[
              0.9432802288135593, 0.8588653050847458, 0.606761593220339], 
             UndirectedEdge[107, 124] -> 
             RGBColor[
              0.9058530338983051, 0.5622649152542373, 0.39733157627118637`], 
             UndirectedEdge[128, 227] -> 
             RGBColor[
              0.9792547288135593, 0.9412183559322034, 0.4134589491525423], 
             UndirectedEdge[25, 365] -> 
             RGBColor[
              0.9861015677966102, 0.9677931186440678, 0.5790332288135592], 
             UndirectedEdge[97, 363] -> 
             RGBColor[
              0.962564186440678, 0.9714136440677966, 0.9398625254237288], 
             UndirectedEdge[13, 373] -> 
             RGBColor[
              0.9868013389830508, 0.9879907288135594, 0.8317095762711864], 
             UndirectedEdge[64, 195] -> 
             RGBColor[
              0.9501614661016949, 0.8284402203389831, 0.49331827118644067`], 
             UndirectedEdge[77, 96] -> 
             RGBColor[
              0.9689687627118644, 0.9069864915254237, 0.33394993220338975`], 
             UndirectedEdge[6, 53] -> 
             RGBColor[
              0.9595345423728813, 0.9693415084745762, 0.9533816440677967], 
             UndirectedEdge[216, 343] -> 
             RGBColor[
              0.9822901525423728, 0.9861252372881357, 0.9064716101694915], 
             UndirectedEdge[26, 324] -> 
             RGBColor[
              0.9909452966101695, 0.9807942033898305, 0.5747784152542372], 
             UndirectedEdge[142, 281] -> 
             RGBColor[
              0.9755387966101694, 0.9286836440677966, 0.399023254237288], 
             UndirectedEdge[100, 341] -> 
             RGBColor[
              0.9196491016949153, 0.6990245932203389, 0.29073353389830503`], 
             UndirectedEdge[115, 364] -> 
             RGBColor[
              0.9077022372881356, 0.9273412881355932, 0.9195058728813561], 
             UndirectedEdge[150, 152] -> 
             RGBColor[
              0.9181345677966102, 0.7886816610169491, 0.6110445254237289], 
             UndirectedEdge[10, 68] -> 
             RGBColor[
              0.9673804322033899, 0.9731208474576272, 0.8393692288135595], 
             UndirectedEdge[190, 288] -> 
             RGBColor[
              0.9066254322033898, 0.5937443220338983, 0.5138958220338984], 
             UndirectedEdge[23, 146] -> 
             RGBColor[
              0.9606840423728813, 0.8701587288135594, 0.5017849830508475], 
             UndirectedEdge[188, 201] -> 
             RGBColor[
              0.9912503559322035, 0.9806359152542373, 0.549047152542373], 
             UndirectedEdge[148, 382] -> 
             RGBColor[
              0.9801025593220339, 0.943031779661017, 0.5057400677966103], 
             UndirectedEdge[14, 71] -> 
             RGBColor[
              0.9912638389830508, 0.9903709491525424, 0.7737686864406781], 
             UndirectedEdge[228, 276] -> 
             RGBColor[
              0.9909452966101695, 0.9807942033898305, 0.5747784152542372], 
             UndirectedEdge[56, 174] -> 
             RGBColor[
              0.9012206610169492, 0.6438427457627119, 0.2392623050847458], 
             UndirectedEdge[16, 182] -> 
             RGBColor[
              0.9935392372881355, 0.988589406779661, 0.5381640338983049], 
             UndirectedEdge[104, 192] -> 
             RGBColor[
              0.9940820084745763, 0.9905611186440678, 0.6561764152542373], 
             UndirectedEdge[145, 395] -> 
             RGBColor[
              0.9363866949152542, 0.7648538813559322, 0.4558645847457628], 
             UndirectedEdge[219, 251] -> 
             RGBColor[
              0.9334930847457628, 0.947040406779661, 0.8843696694915253], 
             UndirectedEdge[150, 179] -> 
             RGBColor[
              0.9181345677966102, 0.7886816610169491, 0.6110445254237289], 
             UndirectedEdge[73, 207] -> 
             RGBColor[
              0.9445940169491525, 0.8130958983050847, 0.30003022881355923`], 
             UndirectedEdge[265, 325] -> 
             RGBColor[
              0.9818698474576271, 0.9843128305084745, 0.8400573050847457], 
             UndirectedEdge[39, 314] -> 
             RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             UndirectedEdge[20, 263] -> 
             RGBColor[
              0.9573006525423728, 0.8687596101694917, 0.5578565084745764], 
             UndirectedEdge[66, 146] -> 
             RGBColor[
              0.9909587796610169, 0.9905292372881356, 0.7994999491525425], 
             UndirectedEdge[7, 21] -> 
             RGBColor[
              0.9431457711864406, 0.8063981355932204, 0.5267534745762712], 
             UndirectedEdge[107, 167] -> 
             RGBColor[
              0.9909677457627118, 0.9800314406779661, 0.5182867796610169], 
             UndirectedEdge[120, 195] -> 
             RGBColor[
              0.9393327288135593, 0.7922366440677966, 0.2957968728813558], 
             UndirectedEdge[365, 388] -> 
             RGBColor[
              0.907074254237288, 0.6035903389830506, 0.2787396779661016], 
             UndirectedEdge[134, 342] -> 
             RGBColor[
              0.9823856355932203, 0.955258406779661, 0.5645975338983049], 
             UndirectedEdge[227, 311] -> 
             RGBColor[
              0.9904160084745762, 0.9885575254237289, 0.6814875677966101], 
             UndirectedEdge[78, 377] -> 
             RGBColor[
              0.9548799830508474, 0.8473277627118644, 0.3795392457627117], 
             UndirectedEdge[21, 370] -> 
             RGBColor[
              0.977541906779661, 0.9422573220338983, 0.5688523474576271], 
             UndirectedEdge[2, 230] -> 
             RGBColor[
              0.9920865762711865, 0.9909956101694916, 0.780809440677966], 
             UndirectedEdge[24, 203] -> 
             RGBColor[
              0.9445759830508476, 0.8047546949152543, 0.3405997033898305], 
             UndirectedEdge[54, 206] -> 
             RGBColor[
              0.9812578389830509, 0.954792033898305, 0.5832880423728812], 
             UndirectedEdge[66, 130] -> 
             RGBColor[
              0.9834179491525423, 0.9865916101694916, 0.8877811016949153], 
             UndirectedEdge[101, 356] -> 
             RGBColor[
              0.9598586610169492, 0.8675825423728813, 0.35301222881355926`], 
             UndirectedEdge[222, 383] -> 
             RGBColor[
              0.9923889915254238, 0.9888857966101695, 0.6133461779661016], 
             UndirectedEdge[31, 247] -> 
             RGBColor[
              0.9581561355932203, 0.9662731525423729, 0.8679239745762712], 
             UndirectedEdge[46, 333] -> 
             RGBColor[
              0.9371621525423728, 0.7880264745762711, 0.2711588389830508], 
             UndirectedEdge[287, 385] -> 
             RGBColor[
              0.9869692033898305, 0.9668922542372882, 0.47309071186440677`], 
             UndirectedEdge[42, 330] -> 
             RGBColor[
              0.9323652881355932, 0.9465740338983051, 0.9030601779661016], 
             UndirectedEdge[151, 227] -> 
             RGBColor[
              0.9904160084745762, 0.9885575254237289, 0.6814875677966101], 
             UndirectedEdge[36, 382] -> 
             RGBColor[
              0.9941044576271186, 0.9897983559322034, 0.599684779661017], 
             UndirectedEdge[218, 361] -> 
             RGBColor[
              0.9921090254237288, 0.9902328474576272, 0.7243178050847456], 
             UndirectedEdge[196, 334] -> 
             RGBColor[
              0.9599625677966102, 0.9496102711864407, 0.6820147881355931], 
             UndirectedEdge[34, 265] -> 
             RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             UndirectedEdge[372, 392] -> 
             RGBColor[
              0.9686234745762712, 0.9755579152542373, 0.9128242881355932], 
             UndirectedEdge[127, 210] -> 
             RGBColor[
              0.9689687627118644, 0.9069864915254238, 0.33394993220338975`], 
             UndirectedEdge[33, 157] -> 
             RGBColor[
              0.9355388644067797, 0.7630404576271187, 0.3635834661016948], 
             UndirectedEdge[139, 308] -> 
             RGBColor[
              0.9890056016949152, 0.9874866779661018, 0.6694177033898304], 
             UndirectedEdge[38, 146] -> 
             RGBColor[
              0.9100088220338983, 0.5951434406779661, 0.4578242966101695], 
             UndirectedEdge[55, 68] -> 
             RGBColor[
              0.9723119237288136, 0.9767987457627119, 0.8310215000000001], 
             UndirectedEdge[35, 392] -> 
             RGBColor[
              0.9909812288135593, 0.9897664745762712, 0.7430083135593221], 
             UndirectedEdge[51, 126] -> 
             RGBColor[
              0.9746827627118644, 0.979702186440678, 0.8857860508474575], 
             UndirectedEdge[130, 243] -> 
             RGBColor[
              0.9743290169491525, 0.9803752033898305, 0.9283384576271186], 
             UndirectedEdge[12, 203] -> 
             RGBColor[
              0.9890056016949152, 0.9874866779661018, 0.6694177033898304], 
             UndirectedEdge[182, 395] -> 
             RGBColor[
              0.9355388644067797, 0.7630404576271187, 0.3635834661016948], 
             UndirectedEdge[99, 382] -> 
             RGBColor[
              0.9317268305084746, 0.7436945254237288, 0.45197627966101706`], 
             UndirectedEdge[17, 31] -> 
             RGBColor[
              0.9581561355932203, 0.9662731525423729, 0.8679239745762712], 
             UndirectedEdge[77, 78] -> 
             RGBColor[
              0.9792547288135593, 0.9412183559322034, 0.4134589491525423], 
             UndirectedEdge[243, 344] -> 
             RGBColor[
              0.964466033898305, 0.9730194067796609, 0.9450339152542373], 
             UndirectedEdge[305, 313] -> 
             RGBColor[
              0.9685407372881356, 0.9267177288135593, 0.6053167881355932], 
             UndirectedEdge[189, 280] -> 
             RGBColor[
              0.9801025593220339, 0.943031779661017, 0.5057400677966103], 
             UndirectedEdge[104, 208] -> 
             RGBColor[
              0.9183652966101695, 0.659374966101695, 0.4658264661016949], 
             UndirectedEdge[191, 335] -> 
             RGBColor[
              0.986686593220339, 0.966287779661017, 0.44233033898305063`], 
             UndirectedEdge[225, 355] -> 
             RGBColor[
              0.9875344237288135, 0.9681012033898305, 0.5346114576271187], 
             UndirectedEdge[308, 348] -> 
             RGBColor[
              0.9790022457627119, 0.9538592881355932, 0.6206690593220339], 
             UndirectedEdge[132, 149] -> 
             RGBColor[
              0.9912611949152542, 0.9884194237288135, 0.6320366864406779], 
             UndirectedEdge[128, 224] -> 
             RGBColor[
              0.977541906779661, 0.9422573220338983, 0.5688523474576271], 
             UndirectedEdge[192, 225] -> 
             RGBColor[
              0.9943870677966102, 0.9904028305084747, 0.630445152542373], 
             UndirectedEdge[84, 252] -> 
             RGBColor[
              0.9703812372881355, 0.9093010508474575, 0.361478940677966], 
             UndirectedEdge[30, 211] -> 
             RGBColor[
              0.9909587796610169, 0.9905292372881356, 0.7994999491525425], 
             UndirectedEdge[138, 242] -> 
             RGBColor[
              0.9584611949152542, 0.9661148644067796, 0.8421927118644068], 
             UndirectedEdge[27, 41] -> 
             RGBColor[
              0.946139372881356, 0.8214204406779662, 0.28982788983050856`], 
             UndirectedEdge[102, 139] -> 
             RGBColor[
              0.993256627118644, 0.9879849322033898, 0.5074036610169491], 
             UndirectedEdge[203, 329] -> 
             RGBColor[
              0.9859759576271186, 0.9854145423728814, 0.6829368220338982], 
             UndirectedEdge[195, 312] -> 
             RGBColor[
              0.9278261610169491, 0.8134688983050847, 0.6066426101694915], 
             UndirectedEdge[51, 87] -> 
             RGBColor[
              0.9384859067796609, 0.785238779661017, 0.5228651694915254], 
             UndirectedEdge[83, 366] -> 
             RGBColor[
              0.9531671610169491, 0.8483667288135592, 0.5349326440677966], 
             UndirectedEdge[8, 302] -> 
             RGBColor[
              0.9424234406779661, 0.8088857288135594, 0.27539219491525424`], 
             UndirectedEdge[146, 344] -> 
             RGBColor[
              0.9769383559322034, 0.9806349322033898, 0.8484050338983051], 
             UndirectedEdge[67, 320] -> 
             RGBColor[
              0.9280383813559322, 0.7424536949152543, 0.5337790677966103], 
             UndirectedEdge[90, 166] -> 
             RGBColor[
              0.8986133050847458, 0.9211248813559322, 0.9600632288135593], 
             UndirectedEdge[12, 341] -> 
             RGBColor[
              0.922250720338983, 0.720827966101695, 0.5485812711864406], 
             UndirectedEdge[3, 13] -> 
             RGBColor[
              0.9868237881355932, 0.9872279661016949, 0.775217940677966], 
             UndirectedEdge[153, 341] -> 
             RGBColor[
              0.893103779661017, 0.6009238305084745, 0.23217579661016952`], 
             UndirectedEdge[192, 351] -> 
             RGBColor[
              0.9832532711864407, 0.9543575423728813, 0.45865501694915245`], 
             UndirectedEdge[12, 150] -> 
             RGBColor[
              0.9408901779661016, 0.8054653898305086, 0.5641344915254238], 
             UndirectedEdge[99, 393] -> 
             RGBColor[
              0.920593033898305, 0.7076492372881356, 0.2801861440677965], 
             UndirectedEdge[4, 190] -> 
             RGBColor[
              0.9887031864406779, 0.9895964915254238, 0.8368809661016949], 
             UndirectedEdge[373, 390] -> 
             RGBColor[
              0.993214372881356, 0.9914619830508475, 0.7621189322033898], 
             UndirectedEdge[23, 308] -> 
             RGBColor[
              0.9561728559322034, 0.8682932372881357, 0.5765470169491527], 
             UndirectedEdge[37, 187] -> 
             RGBColor[
              0.9909587796610169, 0.9905292372881356, 0.7994999491525425], 
             UndirectedEdge[17, 292] -> 
             RGBColor[
              0.9547727457627118, 0.9648740338983051, 0.9239955000000001], 
             UndirectedEdge[309, 385] -> 
             RGBColor[
              0.986686593220339, 0.966287779661017, 0.44233033898305063`], 
             UndirectedEdge[140, 380] -> 
             RGBColor[
              0.9673251779661016, 0.9355745423728814, 0.6281002118644068], 
             UndirectedEdge[119, 354] -> 
             RGBColor[
              0.9673251779661016, 0.9355745423728814, 0.6281002118644068], 
             UndirectedEdge[36, 305] -> 
             RGBColor[
              0.9862585677966101, 0.9860190169491526, 0.7136971949152541], 
             UndirectedEdge[91, 351] -> 
             RGBColor[
              0.9726846949152542, 0.9195212033898303, 0.34838562711864385`], 
             UndirectedEdge[130, 275] -> 
             RGBColor[
              0.9856735423728813, 0.9875243559322034, 0.8504000847457627], 
             UndirectedEdge[46, 102] -> 
             RGBColor[
              0.9551625932203389, 0.8479322372881355, 0.41029961864406783`], 
             UndirectedEdge[111, 271] -> 
             RGBColor[
              0.9662503898305085, 0.8908596949152543, 0.4802870762711865], 
             UndirectedEdge[104, 351] -> 
             RGBColor[
              0.9835134322033898, 0.9557247796610169, 0.5459070254237287], 
             UndirectedEdge[174, 203] -> 
             RGBColor[
              0.9493360847457628, 0.8258640338983051, 0.3445455169491525], 
             UndirectedEdge[294, 313] -> 
             RGBColor[
              0.9726981779661017, 0.9292562372881357, 0.5731071610169493], 
             UndirectedEdge[206, 266] -> 
             RGBColor[
              0.9835134322033898, 0.9557247796610169, 0.5459070254237287], 
             UndirectedEdge[167, 358] -> 
             RGBColor[
              0.9764006271186441, 0.9320559152542374, 0.36282132203389833`], 
             UndirectedEdge[315, 322] -> 
             RGBColor[
              0.982174906779661, 0.9841545423728814, 0.8143260423728815], 
             UndirectedEdge[176, 347] -> 
             RGBColor[
              0.8917238389830509, 0.9050709322033899, 0.6932099322033898], 
             UndirectedEdge[92, 186] -> 
             RGBColor[
              0.9373446271186441, 0.775037372881356, 0.3168341440677966], 
             UndirectedEdge[149, 210] -> 
             RGBColor[
              0.9849737711864406, 0.9673267457627119, 0.5977237372881355], 
             UndirectedEdge[171, 374] -> 
             RGBColor[
              0.9165033389830508, 0.7066705932203389, 0.25167483050847456`], 
             UndirectedEdge[228, 282] -> 
             RGBColor[
              0.9901199152542373, 0.9782180169491526, 0.42600566101694903`], 
             UndirectedEdge[164, 210] -> 
             RGBColor[
              0.9382885593220339, 0.7836620169491526, 0.30628675423728813`], 
             UndirectedEdge[196, 214] -> 
             RGBColor[
              0.962564186440678, 0.9714136440677966, 0.9398625254237288], 
             UndirectedEdge[204, 307] -> 
             RGBColor[
              0.9938218474576271, 0.9891938813559322, 0.568924406779661], 
             UndirectedEdge[127, 255] -> 
             RGBColor[
              0.9271407627118644, 0.7460578813559322, 0.2629796694915254], 
             UndirectedEdge[68, 334] -> 
             RGBColor[
              0.9875344237288135, 0.9681012033898305, 0.5346114576271187], 
             UndirectedEdge[16, 269] -> 
             RGBColor[
              0.9578959745762712, 0.9649059152542373, 0.780671966101695], 
             UndirectedEdge[68, 337] -> 
             RGBColor[
              0.9609891016949152, 0.8700004406779662, 0.4760537203389832], 
             UndirectedEdge[23, 374] -> 
             RGBColor[
              0.921764627118644, 0.727529847457627, 0.255908186440678], 
             UndirectedEdge[22, 116] -> 
             RGBColor[
              0.9430486610169492, 0.8047713559322034, 0.3102325677966101], 
             UndirectedEdge[192, 322] -> 
             RGBColor[
              0.9816096864406779, 0.982945593220339, 0.7528052966101695], 
             UndirectedEdge[70, 95] -> 
             RGBColor[
              0.9457064237288135, 0.8071725932203391, 0.46364119491525435`], 
             UndirectedEdge[71, 273] -> 
             RGBColor[
              0.9904160084745762, 0.9885575254237289, 0.6814875677966101], 
             UndirectedEdge[135, 215] -> 
             RGBColor[
              0.9217181525423729, 0.6889145423728814, 0.3210547966101694], 
             UndirectedEdge[161, 283] -> 
             RGBColor[
              0.9603778813559322, 0.875673661016949, 0.3127302966101694], 
             UndirectedEdge[18, 384] -> 
             RGBColor[
              0.9012206610169492, 0.6438427457627119, 0.2392623050847458], 
             UndirectedEdge[71, 303] -> 
             RGBColor[
              0.9909587796610169, 0.9905292372881356, 0.7994999491525425], 
             UndirectedEdge[32, 353] -> 
             RGBColor[
              0.9722566694915254, 0.9392524406779661, 0.6197524830508474], 
             UndirectedEdge[188, 281] -> 
             RGBColor[
              0.9726846949152542, 0.9195212033898306, 0.34838562711864407`], 
             UndirectedEdge[54, 198] -> 
             RGBColor[
              0.924506313559322, 0.7217607118644067, 0.5112002542372881], 
             UndirectedEdge[271, 385] -> 
             RGBColor[
              0.9588325254237289, 0.8673491186440678, 0.3229326355932203], 
             UndirectedEdge[150, 206] -> 
             RGBColor[
              0.9345726271186441, 0.7711273050847458, 0.2918510593220338], 
             UndirectedEdge[317, 346] -> 
             RGBColor[
              0.9845457457627118, 0.9870579830508475, 0.869090593220339], 
             UndirectedEdge[146, 243] -> 
             RGBColor[
              0.9818698474576271, 0.9843128305084745, 0.8400573050847457], 
             UndirectedEdge[91, 316] -> 
             RGBColor[
              0.9829706610169491, 0.9537530677966102, 0.42789464406779637`], 
             UndirectedEdge[196, 386] -> 
             RGBColor[
              0.9665326016949152, 0.9713074237288135, 0.7470881101694914], 
             UndirectedEdge[151, 306] -> 
             RGBColor[
              0.9625619406779661, 0.8896188644067797, 0.5620898644067798], 
             UndirectedEdge[27, 376] -> 
             RGBColor[
              0.9573006525423728, 0.8687596101694917, 0.5578565084745764], 
             UndirectedEdge[280, 387] -> 
             RGBColor[
              0.9609891016949152, 0.8700004406779662, 0.4760537203389832], 
             UndirectedEdge[308, 354] -> 
             RGBColor[
              0.975286313559322, 0.9413245762711865, 0.6062333644067797], 
             UndirectedEdge[327, 349] -> 
             RGBColor[
              0.9789721186440679, 0.9406138813559322, 0.3826985762711864], 
             UndirectedEdge[60, 108] -> 
             RGBColor[
              0.9697512711864407, 0.9760242881355932, 0.8941337796610169], 
             UndirectedEdge[353, 391] -> 
             RGBColor[
              0.9426206355932203, 0.824502593220339, 0.5815994237288136], 
             UndirectedEdge[140, 195] -> 
             RGBColor[
              0.9356167966101696, 0.7797019322033898, 0.2813611779661017], 
             UndirectedEdge[17, 18] -> 
             RGBColor[
              0.9139754322033898, 0.8027850169491526, 0.6178138220338983], 
             UndirectedEdge[87, 205] -> 
             RGBColor[
              0.9373581101694914, 0.7847724067796611, 0.5415556779661018], 
             UndirectedEdge[221, 256] -> 
             RGBColor[
              0.910790186440678, 0.6161250508474574, 0.29317537288135587`], 
             UndirectedEdge[194, 316] -> 
             RGBColor[
              0.9935392372881355, 0.988589406779661, 0.5381640338983049], 
             UndirectedEdge[16, 37] -> 
             RGBColor[
              0.9940820084745763, 0.9905611186440678, 0.6561764152542373], 
             UndirectedEdge[252, 288] -> 
             RGBColor[
              0.8868732711864407, 0.5150923220338981, 0.22464756779661013`], 
             UndirectedEdge[60, 353] -> 
             RGBColor[
              0.9644660338983051, 0.973019406779661, 0.9450339152542373], 
             UndirectedEdge[206, 286] -> 
             RGBColor[
              0.9498553050847458, 0.8339551525423728, 0.30426358474576265`], 
             UndirectedEdge[220, 396] -> 
             RGBColor[
              0.9909812288135593, 0.9897664745762712, 0.7430083135593221], 
             UndirectedEdge[133, 320] -> 
             RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             UndirectedEdge[28, 231] -> 
             RGBColor[
              0.9030249322033899, 0.6429424406779661, 0.24029745762711865`], 
             UndirectedEdge[239, 269] -> 
             RGBColor[
              0.9581561355932203, 0.9662731525423729, 0.8679239745762712], 
             UndirectedEdge[212, 239] -> 
             RGBColor[
              0.9581561355932203, 0.9662731525423729, 0.8679239745762712], 
             UndirectedEdge[77, 182] -> 
             RGBColor[
              0.9792547288135593, 0.9412183559322034, 0.4134589491525423], 
             UndirectedEdge[280, 336] -> 
             RGBColor[
              0.982174906779661, 0.9841545423728814, 0.8143260423728815], 
             UndirectedEdge[199, 400] -> 
             RGBColor[
              0.9698255508474576, 0.9569660677966101, 0.6653193305084745], 
             UndirectedEdge[73, 336] -> 
             RGBColor[
              0.9710411101694915, 0.948109254237288, 0.642535906779661], 
             UndirectedEdge[305, 340] -> 
             RGBColor[
              0.983404466101695, 0.9768565762711865, 0.6630595677966101], 
             UndirectedEdge[259, 350] -> 
             RGBColor[
              0.9769608050847457, 0.9798721694915253, 0.7919133983050847], 
             UndirectedEdge[247, 393] -> 
             RGBColor[
              0.9473273983050847, 0.9300695762711864, 0.6704025762711863], 
             UndirectedEdge[30, 216] -> 
             RGBColor[
              0.9834179491525423, 0.9865916101694916, 0.8877811016949153], 
             UndirectedEdge[291, 387] -> 
             RGBColor[
              0.9561728559322034, 0.8682932372881357, 0.5765470169491526], 
             UndirectedEdge[45, 338] -> 
             RGBColor[
              0.9918264152542373, 0.989628372881356, 0.6935574322033898], 
             UndirectedEdge[219, 248] -> 
             RGBColor[
              0.9861015677966102, 0.9677931186440678, 0.5790332288135592], 
             UndirectedEdge[158, 354] -> 
             RGBColor[
              0.9689687627118644, 0.9069864915254237, 0.33394993220338975`], 
             UndirectedEdge[191, 327] -> 
             RGBColor[
              0.9929740169491525, 0.9873804576271187, 0.476643288135593], 
             UndirectedEdge[165, 192] -> 
             RGBColor[
              0.9941044576271186, 0.9897983559322034, 0.599684779661017], 
             UndirectedEdge[143, 354] -> 
             RGBColor[
              0.977541906779661, 0.9422573220338983, 0.5688523474576271], 
             UndirectedEdge[115, 161] -> 
             RGBColor[
              0.9678232288135593, 0.9104781186440678, 0.5663232203389831], 
             UndirectedEdge[296, 330] -> 
             RGBColor[
              0.9237921440677965, 0.9113032033898304, 0.6681577627118642], 
             UndirectedEdge[45, 262] -> 
             RGBColor[
              0.9689510254237288, 0.9109444915254237, 0.5476327118644068], 
             UndirectedEdge[37, 208] -> 
             RGBColor[
              0.9183652966101695, 0.659374966101695, 0.4658264661016949], 
             UndirectedEdge[306, 348] -> 
             RGBColor[
              0.9551165932203389, 0.8548144067796609, 0.30849694067796596`], 
             UndirectedEdge[189, 263] -> 
             RGBColor[
              0.9764141101694915, 0.9417909491525425, 0.5875428559322036], 
             UndirectedEdge[2, 50] -> 
             RGBColor[
              0.9932368220338983, 0.990699220338983, 0.7056272966101693], 
             UndirectedEdge[241, 331] -> 
             RGBColor[
              0.9935194322033898, 0.9913036949152543, 0.7363876694915255], 
             UndirectedEdge[135, 213] -> 
             RGBColor[
              0.9662499915254237, 0.9707029491525423, 0.7163277372881356], 
             UndirectedEdge[49, 349] -> 
             RGBColor[
              0.9797975000000001, 0.9431900677966102, 0.5314713305084746], 
             UndirectedEdge[256, 319] -> 
             RGBColor[
              0.9108036694915254, 0.6258600847457625, 0.517896906779661], 
             UndirectedEdge[64, 332] -> 
             RGBColor[
              0.9935167881355933, 0.9893521694915255, 0.5946556694915254], 
             UndirectedEdge[213, 350] -> 
             RGBColor[
              0.9496715593220338, 0.9619857118644067, 0.9700771016949152], 
             UndirectedEdge[333, 345] -> 
             RGBColor[
              0.9586777542372881, 0.9193619322033898, 0.6220122457627117], 
             UndirectedEdge[53, 201] -> 
             RGBColor[
              0.982174906779661, 0.9841545423728814, 0.8143260423728815], 
             UndirectedEdge[9, 384] -> 
             RGBColor[
              0.9420179745762711, 0.8059317627118645, 0.5454439830508475], 
             UndirectedEdge[24, 33] -> 
             RGBColor[
              0.944858593220339, 0.8053591694915255, 0.37136007627118633`], 
             UndirectedEdge[20, 359] -> 
             RGBColor[
              0.9322872033898305, 0.7692483559322034, 0.26437489830508476`], 
             UndirectedEdge[35, 291] -> 
             RGBColor[
              0.9898534322033898, 0.9893001016949152, 0.7616988220338983], 
             UndirectedEdge[316, 351] -> 
             RGBColor[
              0.9829706610169491, 0.9537530677966102, 0.42789464406779637`], 
             UndirectedEdge[195, 263] -> 
             RGBColor[
              0.9467780762711864, 0.8270411016949153, 0.5493897966101695], 
             UndirectedEdge[67, 200] -> 
             RGBColor[
              0.8977636440677966, 0.6220831864406781, 0.2360641016949153], 
             UndirectedEdge[232, 277] -> 
             RGBColor[
              0.9012206610169492, 0.6438427457627119, 0.2392623050847458], 
             UndirectedEdge[88, 120] -> 
             RGBColor[
              0.9764006271186441, 0.9320559152542371, 0.36282132203389816`], 
             UndirectedEdge[247, 271] -> 
             RGBColor[
              0.9297592966101695, 0.8653627796610169, 0.6305138898305085], 
             UndirectedEdge[202, 269] -> 
             RGBColor[
              0.9570283389830508, 0.965806779661017, 0.8866144830508473], 
             UndirectedEdge[207, 291] -> 
             RGBColor[
              0.9509115677966101, 0.8474339830508475, 0.5723136610169492], 
             UndirectedEdge[72, 397] -> 
             RGBColor[
              0.9139268983050848, 0.6258919661016947, 0.37457337288135595`], 
             UndirectedEdge[200, 298] -> 
             RGBColor[
              0.9535712372881355, 0.8464898644067798, 0.3186992796610169], 
             UndirectedEdge[233, 389] -> 
             RGBColor[
              0.972029313559322, 0.9761942711864406, 0.800261127118644], 
             UndirectedEdge[44, 311] -> 
             RGBColor[
              0.9909587796610169, 0.9905292372881356, 0.7994999491525425], 
             UndirectedEdge[137, 258] -> 
             RGBColor[
              0.9909677457627118, 0.9800314406779661, 0.5182867796610169], 
             UndirectedEdge[46, 287] -> 
             RGBColor[
              0.9551625932203389, 0.8479322372881355, 0.41029961864406783`], 
             UndirectedEdge[84, 274] -> 
             RGBColor[
              0.9926914067796611, 0.9867759830508475, 0.4458829152542371], 
             UndirectedEdge[270, 357] -> 
             RGBColor[
              0.9407523220338982, 0.9549797288135593, 0.9729005847457627], 
             UndirectedEdge[44, 344] -> 
             RGBColor[
              0.9769383559322034, 0.9806349322033898, 0.8484050338983051], 
             UndirectedEdge[44, 383] -> 
             RGBColor[
              0.993214372881356, 0.9914619830508475, 0.7621189322033898], 
             UndirectedEdge[193, 364] -> 
             RGBColor[
              0.9099578305084746, 0.9282740338983051, 0.8821248559322034], 
             UndirectedEdge[43, 375] -> 
             RGBColor[
              0.9784729745762711, 0.9731786779661017, 0.6714072966101695], 
             UndirectedEdge[184, 252] -> 
             RGBColor[
              0.9709464576271186, 0.9105099999999999, 0.422999686440678], 
             UndirectedEdge[16, 78] -> 
             RGBColor[
              0.9935392372881355, 0.988589406779661, 0.5381640338983049], 
             UndirectedEdge[345, 353] -> 
             RGBColor[
              0.9693975254237288, 0.9766973050847458, 0.9366861864406779], 
             UndirectedEdge[167, 203] -> 
             RGBColor[
              0.9901199152542373, 0.9782180169491526, 0.42600566101694903`], 
             UndirectedEdge[329, 340] -> 
             RGBColor[
              0.983404466101695, 0.9768565762711865, 0.6630595677966101], 
             UndirectedEdge[193, 380] -> 
             RGBColor[
              0.9807420508474576, 0.9838464576271186, 0.8587478135593221], 
             UndirectedEdge[115, 253] -> 
             RGBColor[
              0.9764141101694915, 0.9417909491525425, 0.5875428559322036], 
             UndirectedEdge[113, 270] -> 
             RGBColor[
              0.9661096186440677, 0.9444313559322033, 0.6508836355932202], 
             UndirectedEdge[121, 202] -> 
             RGBColor[
              0.9935194322033898, 0.9913036949152543, 0.7363876694915255], 
             UndirectedEdge[17, 111] -> 
             RGBColor[
              0.9584611949152542, 0.9661148644067796, 0.8421927118644068], 
             UndirectedEdge[73, 280] -> 
             RGBColor[
              0.9838184915254238, 0.9555664915254236, 0.5201757627118644], 
             UndirectedEdge[127, 242] -> 
             RGBColor[
              0.9763866271186441, 0.9304970677966102, 0.491304372881356], 
             UndirectedEdge[19, 211] -> 
             RGBColor[
              0.9909452966101695, 0.9807942033898305, 0.5747784152542372], 
             UndirectedEdge[213, 345] -> 
             RGBColor[
              0.9496715593220338, 0.9619857118644067, 0.9700771016949152], 
             UndirectedEdge[102, 350] -> 
             RGBColor[
              0.9766781949152542, 0.9792676949152542, 0.7611530254237289], 
             UndirectedEdge[81, 227] -> 
             RGBColor[
              0.993821847457627, 0.9891938813559322, 0.5689244067796608], 
             UndirectedEdge[144, 218] -> 
             RGBColor[
              0.9035749915254236, 0.5620949322033899, 0.4912042288135593], 
             UndirectedEdge[130, 354] -> 
             RGBColor[
              0.9722566694915254, 0.9392524406779661, 0.6197524830508474], 
             UndirectedEdge[104, 327] -> 
             RGBColor[
              0.9935167881355933, 0.9893521694915255, 0.5946556694915254], 
             UndirectedEdge[10, 253] -> 
             RGBColor[
              0.9525307033898305, 0.9245408474576271, 0.6531433983050847], 
             UndirectedEdge[40, 41] -> 
             RGBColor[
              0.9726846949152543, 0.9195212033898306, 0.34838562711864407`], 
             UndirectedEdge[5, 113] -> 
             RGBColor[
              0.9393327288135593, 0.7922366440677966, 0.2957968728813558], 
             UndirectedEdge[271, 337] -> 
             RGBColor[
              0.9322872033898305, 0.7692483559322034, 0.26437489830508476`], 
             UndirectedEdge[325, 376] -> 
             RGBColor[
              0.9784864576271186, 0.9829137118644068, 0.8961288305084747], 
             UndirectedEdge[52, 337] -> 
             RGBColor[
              0.9432802288135593, 0.8588653050847458, 0.606761593220339], 
             UndirectedEdge[246, 260] -> 
             RGBColor[
              0.9551165932203389, 0.8548144067796609, 0.30849694067796596`], 
             UndirectedEdge[22, 290] -> 
             RGBColor[
              0.9801165593220339, 0.944590627118644, 0.3772570169491524], 
             UndirectedEdge[24, 107] -> 
             RGBColor[
              0.945423813559322, 0.8065681186440679, 0.43288082203389827`], 
             UndirectedEdge[314, 369] -> 
             RGBColor[
              0.9887031864406779, 0.9895964915254238, 0.8368809661016949], 
             UndirectedEdge[187, 208] -> 
             RGBColor[
              0.914981906779661, 0.6579758474576273, 0.5218979915254238], 
             UndirectedEdge[9, 174] -> 
             RGBColor[
              0.9467780762711864, 0.8270411016949153, 0.5493897966101696], 
             UndirectedEdge[6, 303] -> 
             RGBColor[
              0.9720068644067796, 0.9769570338983051, 0.8567527627118644], 
             UndirectedEdge[100, 198] -> 
             RGBColor[
              0.9196491016949153, 0.6990245932203389, 0.29073353389830503`], 
             UndirectedEdge[101, 123] -> 
             RGBColor[
              0.9424234406779661, 0.8088857288135594, 0.27539219491525424`], 
             UndirectedEdge[210, 394] -> 
             RGBColor[
              0.9849737711864406, 0.9673267457627119, 0.5977237372881355], 
             UndirectedEdge[213, 227] -> 
             RGBColor[
              0.9665326016949152, 0.9713074237288135, 0.7470881101694914], 
             UndirectedEdge[32, 46] -> 
             RGBColor[
              0.9408780847457627, 0.8005611864406779, 0.28559453389830514`], 
             UndirectedEdge[303, 391] -> 
             RGBColor[
              0.9501614661016949, 0.8284402203389831, 0.49331827118644067`], 
             UndirectedEdge[248, 251] -> 
             RGBColor[
              0.9275080762711865, 0.9238379152542373, 0.6825934576271186], 
             UndirectedEdge[239, 388] -> 
             RGBColor[
              0.9141870593220338, 0.6272592033898303, 0.4618253813559322], 
             UndirectedEdge[205, 277] -> 
             RGBColor[
              0.9420179745762711, 0.8059317627118645, 0.5454439830508475], 
             UndirectedEdge[308, 378] -> 
             RGBColor[
              0.9790022457627119, 0.9538592881355932, 0.6206690593220339], 
             UndirectedEdge[119, 130] -> 
             RGBColor[
              0.9743290169491525, 0.9803752033898305, 0.9283384576271186], 
             UndirectedEdge[28, 254] -> 
             RGBColor[
              0.9140179576271186, 0.7325593898305085, 0.5826841525423729], 
             UndirectedEdge[217, 314] -> 
             RGBColor[
              0.9856735423728813, 0.9875243559322034, 0.8504000847457627], 
             UndirectedEdge[229, 307] -> 
             RGBColor[0.9337955, 0.9449305932203389, 0.7169064067796609], 
             UndirectedEdge[114, 155] -> 
             RGBColor[
              0.9901360423728813, 0.9899045762711864, 0.7924591949152544], 
             UndirectedEdge[226, 288] -> 
             RGBColor[
              0.9100088220338983, 0.595143440677966, 0.4578242966101695], 
             UndirectedEdge[217, 231] -> 
             RGBColor[0.9584045, 0.8870803559322034, 0.5942994915254237], 
             UndirectedEdge[151, 346] -> 
             RGBColor[
              0.9887031864406779, 0.9895964915254238, 0.8368809661016949], 
             UndirectedEdge[114, 180] -> 
             RGBColor[
              0.9838184915254238, 0.9555664915254236, 0.5201757627118644], 
             UndirectedEdge[215, 345] -> 
             RGBColor[
              0.905139720338983, 0.6801973050847459, 0.5748041610169491], 
             UndirectedEdge[190, 252] -> 
             RGBColor[
              0.9678232288135593, 0.9104781186440678, 0.5663232203389831], 
             UndirectedEdge[275, 311] -> 
             RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             UndirectedEdge[75, 320] -> 
             RGBColor[
              0.9864475932203389, 0.9886637457627119, 0.8742619830508476], 
             UndirectedEdge[169, 393] -> 
             RGBColor[
              0.961178127118644, 0.9407534576271186, 0.6592313644067795], 
             UndirectedEdge[80, 182] -> 
             RGBColor[
              0.9862585677966101, 0.9860190169491526, 0.7136971949152541], 
             UndirectedEdge[239, 362] -> 
             RGBColor[
              0.9943646186440678, 0.9911655932203389, 0.6869367881355932], 
             UndirectedEdge[171, 342] -> 
             RGBColor[
              0.9445940169491525, 0.8130958983050847, 0.30003022881355923`], 
             UndirectedEdge[107, 157] -> 
             RGBColor[
              0.9361040847457627, 0.764249406779661, 0.4251042118644067], 
             UndirectedEdge[116, 286] -> 
             RGBColor[
              0.9165033389830508, 0.706670593220339, 0.2516748305084746], 
             UndirectedEdge[37, 117] -> 
             RGBColor[
              0.9943646186440678, 0.9911655932203389, 0.6869367881355932], 
             UndirectedEdge[111, 222] -> 
             RGBColor[
              0.9938218474576271, 0.9891938813559322, 0.568924406779661], 
             UndirectedEdge[57, 72] -> 
             RGBColor[
              0.9865411779661017, 0.9866234915254237, 0.7444575677966101], 
             UndirectedEdge[8, 323] -> 
             RGBColor[
              0.946139372881356, 0.8214204406779662, 0.28982788983050856`], 
             UndirectedEdge[115, 356] -> 
             RGBColor[
              0.9901333983050847, 0.9879530508474577, 0.6507271949152542], 
             UndirectedEdge[129, 391] -> 
             RGBColor[
              0.9501839152542373, 0.8276774576271186, 0.4368266355932203], 
             UndirectedEdge[271, 303] -> 
             RGBColor[
              0.9659453305084746, 0.8910179830508475, 0.5060183389830508], 
             UndirectedEdge[141, 196] -> 
             RGBColor[
              0.9525307033898305, 0.9245408474576271, 0.6531433983050847], 
             UndirectedEdge[8, 117] -> 
             RGBColor[
              0.9607064915254238, 0.869395966101695, 0.44529334745762705`], 
             UndirectedEdge[278, 330] -> 
             RGBColor[
              0.8856800762711865, 0.7629093050847457, 0.6116231949152542], 
             UndirectedEdge[95, 276] -> 
             RGBColor[
              0.9454013644067797, 0.8073308813559323, 0.4893724576271187], 
             UndirectedEdge[114, 268] -> 
             RGBColor[
              0.5869396440677966, 0.6485028898305085, 0.8127334491525424], 
             UndirectedEdge[95, 148] -> 
             RGBColor[
              0.9308566949152544, 0.758592593220339, 0.2774153644067797], 
             UndirectedEdge[236, 366] -> 
             RGBColor[
              0.9542949576271187, 0.8488331016949152, 0.5162421355932203], 
             UndirectedEdge[108, 378] -> 
             RGBColor[
              0.9812578389830509, 0.954792033898305, 0.5832880423728812], 
             UndirectedEdge[33, 107] -> 
             RGBColor[
              0.993821847457627, 0.9891938813559322, 0.5689244067796608], 
             UndirectedEdge[309, 362] -> 
             RGBColor[
              0.993821847457627, 0.9891938813559322, 0.5689244067796608], 
             UndirectedEdge[178, 278] -> 
             RGBColor[
              0.9308566949152544, 0.758592593220339, 0.2774153644067797], 
             UndirectedEdge[21, 232] -> 
             RGBColor[
              0.9479058728813559, 0.8275074745762712, 0.5306992881355932], 
             UndirectedEdge[20, 140] -> 
             RGBColor[
              0.946139372881356, 0.8214204406779662, 0.28982788983050856`], 
             UndirectedEdge[33, 150] -> 
             RGBColor[
              0.944858593220339, 0.8053591694915255, 0.37136007627118633`], 
             UndirectedEdge[38, 213] -> 
             RGBColor[
              0.8827420254237288, 0.5764942203389829, 0.5794963644067797], 
             UndirectedEdge[86, 262] -> 
             RGBColor[
              0.9480710677966101, 0.8318261186440676, 0.27707496610169485`], 
             UndirectedEdge[17, 310] -> 
             RGBColor[
              0.8952357372881357, 0.7181976101694916, 0.602203093220339], 
             UndirectedEdge[222, 223] -> 
             RGBColor[
              0.9890056016949152, 0.9874866779661018, 0.6694177033898304], 
             UndirectedEdge[19, 124] -> 
             RGBColor[
              0.9024337118644068, 0.5518935254237288, 0.2851732033898305], 
             UndirectedEdge[184, 274] -> 
             RGBColor[
              0.993256627118644, 0.9879849322033898, 0.5074036610169491], 
             UndirectedEdge[195, 360] -> 
             RGBColor[
              0.9501614661016949, 0.8284402203389831, 0.4933182711864407], 
             UndirectedEdge[186, 378] -> 
             RGBColor[
              0.9801165593220339, 0.9445906271186439, 0.3772570169491524], 
             UndirectedEdge[31, 169] -> 
             RGBColor[
              0.9720068644067796, 0.9769570338983051, 0.8567527627118644], 
             UndirectedEdge[4, 84] -> 
             RGBColor[
              0.9912611949152542, 0.9884194237288135, 0.6320366864406779], 
             UndirectedEdge[81, 383] -> 
             RGBColor[
              0.9932368220338983, 0.990699220338983, 0.7056272966101693], 
             UndirectedEdge[327, 335] -> 
             RGBColor[
              0.9864039830508475, 0.9656833050847458, 0.4115699661016948], 
             UndirectedEdge[11, 214] -> 
             RGBColor[
              0.9901360423728813, 0.9899045762711864, 0.7924591949152544], 
             UndirectedEdge[15, 35] -> 
             RGBColor[
              0.9941044576271186, 0.9897983559322034, 0.599684779661017], 
             UndirectedEdge[151, 354] -> 
             RGBColor[
              0.9764141101694915, 0.9417909491525425, 0.5875428559322036], 
             UndirectedEdge[91, 192] -> 
             RGBColor[
              0.9832532711864407, 0.9543575423728813, 0.45865501694915245`], 
             UndirectedEdge[44, 130] -> 
             RGBColor[
              0.9868013389830508, 0.9879907288135594, 0.8317095762711864], 
             UndirectedEdge[195, 356] -> 
             RGBColor[
              0.9493360847457628, 0.8258640338983051, 0.3445455169491525], 
             UndirectedEdge[226, 315] -> 
             RGBColor[
              0.9946472288135593, 0.9917700677966101, 0.7176971610169492], 
             UndirectedEdge[65, 206] -> 
             RGBColor[
              0.9835134322033898, 0.9557247796610169, 0.5459070254237287], 
             UndirectedEdge[287, 400] -> 
             RGBColor[
              0.9869692033898305, 0.9668922542372882, 0.47309071186440677`], 
             UndirectedEdge[247, 319] -> 
             RGBColor[
              0.9547727457627118, 0.9648740338983051, 0.9239955000000001], 
             UndirectedEdge[55, 72] -> 
             RGBColor[
              0.9717467033898305, 0.9755897966101694, 0.7695007542372881], 
             UndirectedEdge[313, 329] -> 
             RGBColor[
              0.9685407372881356, 0.9267177288135593, 0.6053167881355932], 
             UndirectedEdge[5, 357] -> 
             RGBColor[
              0.9139754322033898, 0.8027850169491526, 0.6178138220338982], 
             UndirectedEdge[39, 328] -> 
             RGBColor[
              0.9906986186440678, 0.9891620000000001, 0.7122479406779663], 
             UndirectedEdge[310, 384] -> 
             RGBColor[
              0.882480966101695, 0.559255338983051, 0.22365157627118648`], 
             UndirectedEdge[66, 344] -> 
             RGBColor[
              0.9735549661016949, 0.979235813559322, 0.904476559322034], 
             UndirectedEdge[271, 391] -> 
             RGBColor[
              0.9217646271186442, 0.727529847457627, 0.255908186440678], 
             UndirectedEdge[203, 211] -> 
             RGBColor[
              0.9935167881355933, 0.9893521694915255, 0.5946556694915254], 
             UndirectedEdge[100, 203] -> 
             RGBColor[
              0.9864039830508475, 0.9656833050847458, 0.4115699661016948], 
             UndirectedEdge[323, 377] -> 
             RGBColor[
              0.9408780847457627, 0.8005611864406779, 0.28559453389830514`], 
             UndirectedEdge[351, 395] -> 
             RGBColor[
              0.9252528983050847, 0.728808593220339, 0.28407444915254226`], 
             UndirectedEdge[179, 209] -> 
             RGBColor[
              0.964819779661017, 0.9723463898305085, 0.9024815084745763], 
             UndirectedEdge[283, 356] -> 
             RGBColor[
              0.9826880508474576, 0.953148593220339, 0.3971342711864405], 
             UndirectedEdge[77, 80] -> 
             RGBColor[
              0.9722566694915254, 0.9392524406779661, 0.6197524830508474], 
             UndirectedEdge[200, 398] -> 
             RGBColor[
              0.9604238813559323, 0.8687914915254238, 0.41453297457627125`], 
             UndirectedEdge[280, 368] -> 
             RGBColor[
              0.9946472288135593, 0.9917700677966101, 0.7176971610169492], 
             UndirectedEdge[3, 390] -> 
             RGBColor[
              0.9932368220338983, 0.990699220338983, 0.7056272966101693], 
             UndirectedEdge[64, 380] -> 
             RGBColor[
              0.9818698474576271, 0.9843128305084745, 0.8400573050847457], 
             UndirectedEdge[139, 186] -> 
             RGBColor[
              0.9901199152542373, 0.9782180169491526, 0.42600566101694903`], 
             UndirectedEdge[160, 245] -> 
             RGBColor[
              0.993214372881356, 0.9914619830508475, 0.7621189322033898], 
             UndirectedEdge[64, 360] -> 
             RGBColor[
              0.9943421694915254, 0.9919283559322034, 0.7434284237288136], 
             UndirectedEdge[72, 337] -> 
             RGBColor[
              0.9604238813559323, 0.8687914915254238, 0.41453297457627125`], 
             UndirectedEdge[11, 141] -> 
             RGBColor[
              0.9801025593220339, 0.943031779661017, 0.5057400677966103], 
             UndirectedEdge[62, 223] -> 
             RGBColor[
              0.9895708220338983, 0.9886956271186441, 0.7309384491525424], 
             UndirectedEdge[351, 399] -> 
             RGBColor[
              0.9117147966101695, 0.6552871525423728, 0.2723061525423728], 
             UndirectedEdge[205, 232] -> 
             RGBColor[
              0.9467780762711864, 0.8270411016949153, 0.5493897966101696], 
             UndirectedEdge[175, 379] -> 
             RGBColor[
              0.9401987288135594, 0.784199813559322, 0.36747177118644053`], 
             UndirectedEdge[144, 339] -> 
             RGBColor[
              0.9047027881355932, 0.5625613050847458, 0.472513720338983], 
             UndirectedEdge[66, 275] -> 
             RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             UndirectedEdge[311, 346] -> 
             RGBColor[
              0.9887031864406779, 0.9895964915254238, 0.8368809661016949], 
             UndirectedEdge[81, 326] -> 
             RGBColor[
              0.987251813559322, 0.9674967288135593, 0.5038510847457626], 
             UndirectedEdge[145, 335] -> 
             RGBColor[
              0.9875344237288135, 0.9681012033898305, 0.5346114576271187], 
             UndirectedEdge[24, 56] -> 
             RGBColor[
              0.896460559322034, 0.6227334067796612, 0.23531649152542378`], 
             UndirectedEdge[310, 319] -> 
             RGBColor[
              0.9280383813559322, 0.7424536949152543, 0.5337790677966103], 
             UndirectedEdge[131, 303] -> 
             RGBColor[
              0.9943421694915254, 0.9919283559322034, 0.7434284237288136], 
             UndirectedEdge[146, 317] -> 
             RGBColor[
              0.9868013389830508, 0.9879907288135594, 0.8317095762711864], 
             UndirectedEdge[159, 321] -> 
             RGBColor[
              0.9665326016949152, 0.9713074237288135, 0.7470881101694914], 
             UndirectedEdge[339, 361] -> 
             RGBColor[
              0.9932368220338983, 0.990699220338983, 0.7056272966101693], 
             UndirectedEdge[60, 297] -> 
             RGBColor[
              0.9044266016949152, 0.7077221355932203, 0.5871435762711864], 
             UndirectedEdge[1, 368] -> 
             RGBColor[
              0.922543533898305, 0.6914907288135594, 0.46982755084745764`], 
             UndirectedEdge[15, 106] -> 
             RGBColor[
              0.910825466101695, 0.9273731694915255, 0.7761823389830509], 
             UndirectedEdge[144, 282] -> 
             RGBColor[
              0.9050052033898306, 0.5604514915254237, 0.3050504576271186], 
             UndirectedEdge[333, 391] -> 
             RGBColor[
              0.9319008644067797, 0.767167220338983, 0.26692548305084746`], 
             UndirectedEdge[85, 238] -> 
             RGBColor[
              0.9738259745762712, 0.9297226101694915, 0.5544166525423728], 
             UndirectedEdge[130, 135] -> 
             RGBColor[
              0.9859759576271186, 0.9854145423728814, 0.6829368220338982], 
             UndirectedEdge[194, 256] -> 
             RGBColor[
              0.9139268983050848, 0.6258919661016947, 0.37457337288135595`], 
             UndirectedEdge[129, 271] -> 
             RGBColor[
              0.9659677796610169, 0.8902552203389831, 0.4495267033898305], 
             UndirectedEdge[12, 168] -> 
             RGBColor[
              0.9901360423728813, 0.9899045762711864, 0.7924591949152544], 
             UndirectedEdge[32, 271] -> 
             RGBColor[
              0.9514006610169492, 0.8422796949152542, 0.29406124576271186`], 
             UndirectedEdge[227, 363] -> 
             RGBColor[
              0.9665326016949152, 0.9713074237288135, 0.7470881101694914], 
             UndirectedEdge[351, 355] -> 
             RGBColor[
              0.9764006271186441, 0.9320559152542371, 0.36282132203389816`], 
             UndirectedEdge[70, 285] -> 
             RGBColor[
              0.9943870677966102, 0.9904028305084747, 0.630445152542373], 
             UndirectedEdge[19, 107] -> 
             RGBColor[
              0.9909677457627118, 0.9800314406779661, 0.5182867796610169], 
             UndirectedEdge[88, 359] -> 
             RGBColor[
              0.9588325254237289, 0.8673491186440678, 0.3229326355932203], 
             UndirectedEdge[128, 130] -> 
             RGBColor[
              0.9722566694915254, 0.9392524406779661, 0.6197524830508474], 
             UndirectedEdge[72, 297] -> 
             RGBColor[
              0.9265017457627118, 0.721326220338983, 0.3865672288135593], 
             UndirectedEdge[125, 184] -> 
             RGBColor[
              0.9929542118644068, 0.9900947457627118, 0.6748669237288135], 
             UndirectedEdge[41, 63] -> 
             RGBColor[
              0.9786697033898306, 0.9427236949152542, 0.5501618389830508], 
             UndirectedEdge[67, 133] -> 
             RGBColor[
              0.9302939745762713, 0.7433864406779662, 0.4963980508474576], 
             UndirectedEdge[272, 308] -> 
             RGBColor[0.9827181779661016, 0.966394, 0.6351047542372881], 
             UndirectedEdge[199, 287] -> 
             RGBColor[
              0.9766781949152542, 0.9792676949152542, 0.7611530254237289], 
             UndirectedEdge[60, 333] -> 
             RGBColor[
              0.9537462627118644, 0.915684033898305, 0.6303599745762711], 
             UndirectedEdge[86, 325] -> 
             RGBColor[
              0.9587342966101694, 0.9042617118644067, 0.6068805762711864], 
             UndirectedEdge[77, 377] -> 
             RGBColor[
              0.9408780847457627, 0.8005611864406779, 0.28559453389830514`], 
             UndirectedEdge[62, 319] -> 
             RGBColor[
              0.9906986186440678, 0.9891620000000001, 0.7122479406779663], 
             UndirectedEdge[52, 199] -> 
             RGBColor[
              0.9595345423728813, 0.9693415084745762, 0.9533816440677966], 
             UndirectedEdge[57, 376] -> 
             RGBColor[
              0.9834179491525423, 0.9865916101694916, 0.8877811016949153], 
             UndirectedEdge[11, 161] -> 
             RGBColor[
              0.9715116779661017, 0.9117189491525424, 0.4845204322033899], 
             UndirectedEdge[155, 300] -> 
             RGBColor[
              0.9674956779661017, 0.9750915423728814, 0.9315147966101696], 
             UndirectedEdge[81, 275] -> 
             RGBColor[
              0.9932368220338983, 0.990699220338983, 0.7056272966101693], 
             UndirectedEdge[100, 266] -> 
             RGBColor[
              0.9872293644067797, 0.9682594915254237, 0.560342720338983], 
             UndirectedEdge[56, 266] -> 
             RGBColor[
              0.9454013644067797, 0.8073308813559323, 0.4893724576271187], 
             UndirectedEdge[82, 257] -> 
             RGBColor[
              0.9117147966101695, 0.6552871525423729, 0.2723061525423728], 
             UndirectedEdge[32, 259] -> 
             RGBColor[
              0.9798199491525423, 0.9424273050847458, 0.4749796949152542], 
             UndirectedEdge[261, 355] -> 
             RGBColor[
              0.9838324915254237, 0.9571253389830509, 0.3916927118644067], 
             UndirectedEdge[74, 179] -> 
             RGBColor[0.9659475762711864, 0.9728127627118643, 0.883791], 
             UndirectedEdge[100, 174] -> 
             RGBColor[
              0.9430486610169492, 0.8047713559322034, 0.3102325677966101], 
             UndirectedEdge[208, 388] -> 
             RGBColor[
              0.8382101864406779, 0.29470581355932196`, 0.18422342372881356`],
              UndirectedEdge[249, 299] -> 
             RGBColor[
              0.9625484576271186, 0.8798838305084746, 0.3373683305084746], 
             UndirectedEdge[58, 181] -> 
             RGBColor[
              0.9764006271186441, 0.9320559152542374, 0.36282132203389833`], 
             UndirectedEdge[271, 345] -> 
             RGBColor[
              0.9485415169491525, 0.8797245593220339, 0.6109949491525424], 
             UndirectedEdge[20, 89] -> 
             RGBColor[
              0.9117432372881356, 0.6855612542372882, 0.2477290169491526], 
             UndirectedEdge[174, 358] -> 
             RGBColor[
              0.9356167966101696, 0.7797019322033898, 0.2813611779661017], 
             UndirectedEdge[185, 274] -> 
             RGBColor[
              0.9826880508474576, 0.953148593220339, 0.3971342711864405], 
             UndirectedEdge[106, 314] -> 
             RGBColor[
              0.9099578305084746, 0.9282740338983051, 0.8821248559322034], 
             UndirectedEdge[73, 387] -> 
             RGBColor[
              0.9498553050847458, 0.8339551525423728, 0.30426358474576265`], 
             UndirectedEdge[191, 261] -> 
             RGBColor[
              0.9904025254237288, 0.9788224915254238, 0.45676603389830495`], 
             UndirectedEdge[135, 227] -> 
             RGBColor[
              0.9929740169491525, 0.9873804576271187, 0.476643288135593], 
             UndirectedEdge[102, 345] -> 
             RGBColor[
              0.9766781949152542, 0.9792676949152542, 0.7611530254237289], 
             UndirectedEdge[72, 108] -> 
             RGBColor[
              0.9918264152542373, 0.989628372881356, 0.6935574322033898], 
             UndirectedEdge[7, 273] -> 
             RGBColor[
              0.944858593220339, 0.8053591694915255, 0.37136007627118633`], 
             UndirectedEdge[111, 385] -> 
             RGBColor[
              0.9875344237288135, 0.9681012033898305, 0.5346114576271187], 
             UndirectedEdge[25, 187] -> 
             RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             UndirectedEdge[290, 338] -> 
             RGBColor[
              0.9869692033898305, 0.9668922542372882, 0.47309071186440677`], 
             UndirectedEdge[133, 200] -> 
             RGBColor[
              0.9595562457627118, 0.8696923559322034, 0.5204754915254237], 
             UndirectedEdge[64, 88] -> 
             RGBColor[
              0.9872293644067797, 0.9682594915254237, 0.560342720338983], 
             UndirectedEdge[23, 92] -> 
             RGBColor[
              0.9070833728813559, 0.6644018983050848, 0.2438407118644068], 
             UndirectedEdge[38, 350] -> 
             RGBColor[
              0.8926050084745762, 0.5838500169491525, 0.562800906779661], 
             UndirectedEdge[135, 224] -> 
             RGBColor[
              0.9912611949152542, 0.9884194237288135, 0.6320366864406779], 
             UndirectedEdge[329, 358] -> 
             RGBColor[
              0.9722566694915254, 0.9392524406779661, 0.6197524830508474], 
             UndirectedEdge[4, 185] -> 
             RGBColor[
              0.9812578389830509, 0.954792033898305, 0.5832880423728812], 
             UndirectedEdge[111, 199] -> 
             RGBColor[
              0.9772434152542373, 0.9804766440677966, 0.8226737711864407], 
             UndirectedEdge[138, 264] -> 
             RGBColor[
              0.9407523220338982, 0.9549797288135593, 0.9729005847457627], 
             UndirectedEdge[275, 344] -> 
             RGBColor[
              0.9758105593220339, 0.980168559322034, 0.8670955423728812], 
             UndirectedEdge[300, 371] -> 
             RGBColor[
              0.9697512711864407, 0.9760242881355932, 0.8941337796610169], 
             UndirectedEdge[69, 273] -> 
             RGBColor[
              0.944858593220339, 0.8053591694915255, 0.37136007627118633`], 
             UndirectedEdge[65, 174] -> 
             RGBColor[
              0.9501614661016949, 0.8284402203389831, 0.49331827118644067`], 
             UndirectedEdge[217, 254] -> 
             RGBColor[
              0.9693975254237288, 0.9766973050847458, 0.9366861864406779], 
             UndirectedEdge[102, 378] -> 
             RGBColor[
              0.9832532711864407, 0.9543575423728813, 0.45865501694915245`], 
             UndirectedEdge[246, 326] -> 
             RGBColor[
              0.9588325254237289, 0.8673491186440678, 0.3229326355932203], 
             UndirectedEdge[120, 242] -> 
             RGBColor[
              0.9838184915254238, 0.9555664915254236, 0.5201757627118644], 
             UndirectedEdge[25, 117] -> 
             RGBColor[
              0.9932368220338983, 0.990699220338983, 0.7056272966101693], 
             UndirectedEdge[44, 227] -> 
             RGBColor[
              0.9937993983050848, 0.9899566440677967, 0.6254160423728812], 
             UndirectedEdge[118, 206] -> 
             RGBColor[
              0.9710411101694915, 0.948109254237288, 0.642535906779661], 
             UndirectedEdge[151, 158] -> 
             RGBColor[
              0.9801300423728814, 0.954325661016949, 0.6019785508474575], 
             UndirectedEdge[151, 308] -> 
             RGBColor[
              0.9864475932203389, 0.9886637457627119, 0.8742619830508476], 
             UndirectedEdge[298, 390] -> 
             RGBColor[
              0.9861015677966102, 0.9677931186440678, 0.5790332288135592], 
             UndirectedEdge[62, 111] -> 
             RGBColor[
              0.9943870677966102, 0.9904028305084747, 0.630445152542373], 
             UndirectedEdge[131, 201] -> 
             RGBColor[
              0.9946472288135593, 0.9917700677966101, 0.7176971610169492], 
             UndirectedEdge[291, 368] -> 
             RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             UndirectedEdge[35, 73] -> 
             RGBColor[
              0.9835358813559322, 0.9549620169491524, 0.4894153898305083], 
             UndirectedEdge[273, 293] -> 
             RGBColor[
              0.9576133644067797, 0.9643014406779662, 0.7499115932203388], 
             UndirectedEdge[4, 274] -> 
             RGBColor[
              0.9912611949152542, 0.9884194237288135, 0.6320366864406779], 
             UndirectedEdge[10, 337] -> 
             RGBColor[
              0.9334172457627119, 0.8515095084745763, 0.6234570508474576], 
             UndirectedEdge[27, 265] -> 
             RGBColor[
              0.9606840423728813, 0.8701587288135594, 0.5017849830508475], 
             UndirectedEdge[262, 325] -> 
             RGBColor[
              0.9587342966101694, 0.9042617118644067, 0.6068805762711864], 
             UndirectedEdge[46, 337] -> 
             RGBColor[
              0.921764627118644, 0.727529847457627, 0.255908186440678], 
             UndirectedEdge[322, 327] -> 
             RGBColor[
              0.9810444661016948, 0.9817366440677966, 0.6912845508474575], 
             UndirectedEdge[59, 299] -> 
             RGBColor[
              0.9651199491525424, 0.8884417966101694, 0.3572455847457626], 
             UndirectedEdge[254, 369] -> 
             RGBColor[
              0.9724271694915254, 0.9787694406779661, 0.9231670677966102], 
             UndirectedEdge[262, 376] -> 
             RGBColor[
              0.9678232288135593, 0.9104781186440678, 0.5663232203389832], 
             UndirectedEdge[360, 389] -> 
             RGBColor[
              0.9720068644067796, 0.9769570338983051, 0.8567527627118644], 
             UndirectedEdge[159, 381] -> 
             RGBColor[
              0.9670753728813559, 0.9732791355932203, 0.8651004915254237], 
             UndirectedEdge[77, 302] -> 
             RGBColor[
              0.9615368983050847, 0.8819170677966102, 0.30507854237288135`], 
             UndirectedEdge[67, 398] -> 
             RGBColor[
              0.9311616101694915, 0.7424855762711865, 0.3904555338983051], 
             UndirectedEdge[12, 100] -> 
             RGBColor[0.9827181779661016, 0.966394, 0.6351047542372881], 
             UndirectedEdge[329, 339] -> 
             RGBColor[
              0.9856735423728813, 0.9875243559322034, 0.8504000847457627], 
             UndirectedEdge[1, 113] -> 
             RGBColor[
              0.9117147966101695, 0.6552871525423729, 0.2723061525423728], 
             UndirectedEdge[232, 390] -> 
             RGBColor[
              0.9490336694915255, 0.8279738474576271, 0.5120087796610169], 
             UndirectedEdge[319, 384] -> 
             RGBColor[
              0.9420179745762711, 0.8059317627118645, 0.5454439830508475], 
             UndirectedEdge[342, 374] -> 
             RGBColor[
              0.9445940169491525, 0.8130958983050847, 0.30003022881355923`], 
             UndirectedEdge[200, 320] -> 
             RGBColor[
              0.9573006525423728, 0.8687596101694917, 0.5578565084745764], 
             UndirectedEdge[35, 231] -> 
             RGBColor[
              0.9659677796610169, 0.8902552203389831, 0.4495267033898305], 
             UndirectedEdge[96, 104] -> 
             RGBColor[
              0.9835134322033898, 0.9557247796610169, 0.5459070254237287], 
             UndirectedEdge[106, 197] -> 
             RGBColor[
              0.8721662118644068, 0.7861115254237288, 0.6175575508474577], 
             UndirectedEdge[41, 265] -> 
             RGBColor[
              0.9797975000000001, 0.9431900677966102, 0.5314713305084746], 
             UndirectedEdge[52, 303] -> 
             RGBColor[
              0.9769383559322034, 0.9806349322033898, 0.8484050338983051], 
             UndirectedEdge[170, 208] -> 
             RGBColor[
              0.9178225254237289, 0.6574032542372883, 0.3478140847457626], 
             UndirectedEdge[49, 355] -> 
             RGBColor[
              0.9872293644067797, 0.9682594915254237, 0.560342720338983], 
             UndirectedEdge[140, 359] -> 
             RGBColor[
              0.9514006610169492, 0.8422796949152542, 0.29406124576271186`], 
             UndirectedEdge[20, 255] -> 
             RGBColor[
              0.9117432372881356, 0.6855612542372882, 0.2477290169491526], 
             UndirectedEdge[117, 362] -> 
             RGBColor[
              0.9943870677966101, 0.9904028305084746, 0.6304451525423728], 
             UndirectedEdge[188, 293] -> 
             RGBColor[0.9547592627118644, 0.955139, 0.6992739661016949], 
             UndirectedEdge[149, 155] -> 
             RGBColor[
              0.9875753898305084, 0.9891301186440679, 0.8555714745762713], 
             UndirectedEdge[7, 188] -> 
             RGBColor[
              0.9420044915254238, 0.7961967288135594, 0.3207224491525424], 
             UndirectedEdge[120, 331] -> 
             RGBColor[
              0.9823856355932203, 0.955258406779661, 0.5645975338983049], 
             UndirectedEdge[169, 218] -> 
             RGBColor[
              0.9697512711864407, 0.9760242881355932, 0.8941337796610169], 
             UndirectedEdge[345, 350] -> 
             RGBColor[
              0.9595345423728813, 0.9693415084745762, 0.9533816440677966], 
             UndirectedEdge[147, 217] -> 
             RGBColor[
              0.9856735423728813, 0.9875243559322034, 0.8504000847457627], 
             UndirectedEdge[141, 386] -> 
             RGBColor[
              0.9792547288135593, 0.9412183559322034, 0.4134589491525423], 
             UndirectedEdge[128, 383] -> 
             RGBColor[
              0.9786697033898306, 0.9427236949152542, 0.5501618389830508], 
             UndirectedEdge[138, 394] -> 
             RGBColor[
              0.9559005423728812, 0.965340406779661, 0.9053049915254237], 
             UndirectedEdge[132, 300] -> 
             RGBColor[
              0.9711814830508474, 0.9743808474576271, 0.7079800084745762], 
             UndirectedEdge[103, 122] -> 
             RGBColor[
              0.9935194322033898, 0.9913036949152543, 0.7363876694915255], 
             UndirectedEdge[147, 195] -> 
             RGBColor[
              0.9490336694915255, 0.8279738474576271, 0.5120087796610169], 
             UndirectedEdge[123, 389] -> 
             RGBColor[
              0.9537462627118644, 0.915684033898305, 0.6303599745762711], 
             UndirectedEdge[93, 394] -> 
             RGBColor[
              0.9323652881355932, 0.9465740338983051, 0.9030601779661016], 
             UndirectedEdge[199, 350] -> 
             RGBColor[
              0.9595345423728813, 0.9693415084745762, 0.9533816440677966], 
             UndirectedEdge[66, 158] -> 
             RGBColor[
              0.9801300423728814, 0.954325661016949, 0.6019785508474575], 
             UndirectedEdge[105, 215] -> 
             RGBColor[
              0.9191601440677966, 0.6900916101694916, 0.5258990762711866], 
             UndirectedEdge[253, 364] -> 
             RGBColor[
              0.8965409576271187, 0.8800021186440679, 0.6514772542372882], 
             UndirectedEdge[76, 78] -> 
             RGBColor[
              0.970663847457627, 0.9099055254237287, 0.39223931355932184`], 
             UndirectedEdge[153, 358] -> 
             RGBColor[
              0.946139372881356, 0.8214204406779662, 0.28982788983050856`], 
             UndirectedEdge[54, 64] -> 
             RGBColor[
              0.9920865762711863, 0.9909956101694916, 0.7808094406779661], 
             UndirectedEdge[84, 125] -> 
             RGBColor[
              0.9923889915254238, 0.9888857966101695, 0.6133461779661016], 
             UndirectedEdge[195, 380] -> 
             RGBColor[
              0.9376891440677966, 0.8208246949152542, 0.589947152542373], 
             UndirectedEdge[81, 146] -> 
             RGBColor[
              0.9943646186440678, 0.9911655932203389, 0.6869367881355932], 
             UndirectedEdge[275, 317] -> 
             RGBColor[
              0.9856735423728813, 0.9875243559322034, 0.8504000847457627], 
             UndirectedEdge[25, 377] -> 
             RGBColor[
              0.9542949576271187, 0.8488331016949152, 0.5162421355932203], 
             UndirectedEdge[180, 232] -> 
             RGBColor[
              0.9393327288135593, 0.7922366440677966, 0.2957968728813558], 
             UndirectedEdge[52, 333] -> 
             RGBColor[
              0.9586777542372881, 0.9193619322033898, 0.6220122457627119], 
             UndirectedEdge[97, 276] -> 
             RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             UndirectedEdge[51, 390] -> 
             RGBColor[
              0.9909587796610169, 0.9905292372881356, 0.7994999491525423], 
             UndirectedEdge[199, 393] -> 
             RGBColor[
              0.9661096186440677, 0.9444313559322033, 0.6508836355932202], 
             UndirectedEdge[169, 224] -> 
             RGBColor[
              0.9697512711864407, 0.9760242881355932, 0.8941337796610169], 
             UndirectedEdge[132, 268] -> 
             RGBColor[
              0.5858092033898306, 0.6460849915254238, 0.6896919576271185], 
             UndirectedEdge[162, 183] -> 
             RGBColor[
              0.9875344237288135, 0.9681012033898305, 0.5346114576271187], 
             UndirectedEdge[15, 231] -> 
             RGBColor[
              0.9656851694915254, 0.8896507457627119, 0.41876633050847456`], 
             UndirectedEdge[246, 248] -> 
             RGBColor[
              0.9588325254237289, 0.8673491186440678, 0.3229326355932203], 
             UndirectedEdge[44, 81] -> 
             RGBColor[
              0.9943646186440678, 0.9911655932203389, 0.6869367881355932], 
             UndirectedEdge[39, 197] -> 
             RGBColor[
              0.9520393644067796, 0.8479003559322034, 0.5536231525423729], 
             UndirectedEdge[57, 86] -> 
             RGBColor[
              0.9636657881355932, 0.9079396101694914, 0.598532847457627], 
             UndirectedEdge[74, 209] -> 
             RGBColor[
              0.9909587796610169, 0.9905292372881356, 0.7994999491525423], 
             UndirectedEdge[115, 389] -> 
             RGBColor[
              0.9686234745762712, 0.9755579152542373, 0.9128242881355932], 
             UndirectedEdge[157, 168] -> 
             RGBColor[
              0.9363866949152542, 0.7648538813559322, 0.4558645847457628], 
             UndirectedEdge[224, 363] -> 
             RGBColor[
              0.964819779661017, 0.9723463898305085, 0.9024815084745763], 
             UndirectedEdge[47, 279] -> 
             RGBColor[
              0.9271407627118644, 0.7460578813559322, 0.2629796694915254], 
             UndirectedEdge[58, 352] -> 
             RGBColor[
              0.9795373389830508, 0.9418228305084746, 0.44421932203389836`], 
             UndirectedEdge[101, 161] -> 
             RGBColor[
              0.9375484915254237, 0.7901076101694915, 0.2686082542372881], 
             UndirectedEdge[23, 98] -> 
             RGBColor[
              0.8805289322033898, 0.5054895762711863, 0.2201819406779661], 
             UndirectedEdge[37, 388] -> 
             RGBColor[
              0.9141870593220338, 0.6272592033898303, 0.4618253813559322], 
             UndirectedEdge[13, 21] -> 
             RGBColor[
              0.9845457457627118, 0.9870579830508475, 0.869090593220339], 
             UndirectedEdge[159, 375] -> 
             RGBColor[0.9636785, 0.9621449830508475, 0.6964504830508474], 
             UndirectedEdge[130, 346] -> 
             RGBColor[
              0.9845457457627118, 0.9870579830508475, 0.869090593220339], 
             UndirectedEdge[104, 225] -> 
             RGBColor[
              0.9946472288135593, 0.9917700677966101, 0.7176971610169492], 
             UndirectedEdge[226, 252] -> 
             RGBColor[
              0.9712066186440678, 0.9118772372881355, 0.5102516949152542], 
             UndirectedEdge[64, 283] -> 
             RGBColor[
              0.9835134322033898, 0.9557247796610169, 0.5459070254237287], 
             UndirectedEdge[262, 284] -> 
             RGBColor[
              0.9715116779661017, 0.9117189491525424, 0.4845204322033899], 
             UndirectedEdge[282, 313] -> 
             RGBColor[
              0.9752561864406779, 0.9280791694915254, 0.3682628813559321], 
             UndirectedEdge[88, 360] -> 
             RGBColor[
              0.9872293644067797, 0.9682594915254237, 0.560342720338983], 
             UndirectedEdge[210, 230] -> 
             RGBColor[
              0.9861015677966102, 0.9677931186440678, 0.5790332288135592], 
             UndirectedEdge[2, 138] -> 
             RGBColor[
              0.9570283389830508, 0.965806779661017, 0.8866144830508473], 
             UndirectedEdge[178, 367] -> 
             RGBColor[
              0.8912859152542374, 0.5142893898305085, 0.24186611864406782`], 
             UndirectedEdge[54, 123] -> 
             RGBColor[
              0.9738259745762712, 0.9297226101694915, 0.5544166525423728], 
             UndirectedEdge[36, 95] -> 
             RGBColor[
              0.944858593220339, 0.8053591694915255, 0.37136007627118633`], 
             UndirectedEdge[294, 301] -> 
             RGBColor[
              0.9726981779661017, 0.9292562372881357, 0.5731071610169493], 
             UndirectedEdge[60, 337] -> 
             RGBColor[
              0.9383487372881356, 0.855187406779661, 0.6151093220338983], 
             UndirectedEdge[251, 275] -> 
             RGBColor[
              0.9334930847457628, 0.947040406779661, 0.8843696694915253], 
             UndirectedEdge[66, 311] -> 
             RGBColor[
              0.9875753898305084, 0.9891301186440679, 0.8555714745762714], 
             UndirectedEdge[110, 400] -> 
             RGBColor[
              0.979688533898305, 0.9643218644067797, 0.6486238728813558], 
             UndirectedEdge[143, 151] -> 
             RGBColor[
              0.9887031864406779, 0.9895964915254238, 0.8368809661016949], 
             UndirectedEdge[157, 206] -> 
             RGBColor[
              0.9252528983050847, 0.728808593220339, 0.28407444915254226`], 
             UndirectedEdge[226, 274] -> 
             RGBColor[
              0.9935167881355933, 0.9893521694915255, 0.5946556694915254], 
             UndirectedEdge[86, 265] -> 
             RGBColor[
              0.9712066186440678, 0.9118772372881355, 0.5102516949152542], 
             UndirectedEdge[64, 389] -> 
             RGBColor[
              0.9720068644067796, 0.9769570338983051, 0.8567527627118644], 
             UndirectedEdge[120, 356] -> 
             RGBColor[
              0.9826880508474576, 0.953148593220339, 0.3971342711864405], 
             UndirectedEdge[164, 279] -> 
             RGBColor[
              0.896460559322034, 0.6227334067796612, 0.23531649152542378`], 
             UndirectedEdge[24, 238] -> 
             RGBColor[
              0.9431457711864406, 0.8063981355932204, 0.5267534745762712], 
             UndirectedEdge[213, 259] -> 
             RGBColor[
              0.9670978220338983, 0.972516372881356, 0.8086088559322033], 
             UndirectedEdge[73, 162] -> 
             RGBColor[
              0.9838184915254238, 0.9555664915254236, 0.5201757627118644], 
             UndirectedEdge[257, 356] -> 
             RGBColor[
              0.9826880508474576, 0.953148593220339, 0.3971342711864405], 
             UndirectedEdge[6, 281] -> 
             RGBColor[
              0.9537462627118644, 0.915684033898305, 0.6303599745762711], 
             UndirectedEdge[176, 277] -> 
             RGBColor[
              0.9420044915254238, 0.7961967288135594, 0.3207224491525424], 
             UndirectedEdge[140, 263] -> 
             RGBColor[
              0.9764141101694915, 0.9417909491525425, 0.5875428559322036], 
             UndirectedEdge[54, 161] -> 
             RGBColor[
              0.9689510254237288, 0.9109444915254237, 0.5476327118644068], 
             UndirectedEdge[7, 142] -> 
             RGBColor[
              0.944858593220339, 0.8053591694915255, 0.37136007627118633`], 
             UndirectedEdge[81, 311] -> 
             RGBColor[
              0.9909812288135593, 0.9897664745762712, 0.7430083135593221], 
             UndirectedEdge[204, 237] -> 
             RGBColor[
              0.9838184915254238, 0.9555664915254236, 0.5201757627118644], 
             UndirectedEdge[134, 374] -> 
             RGBColor[
              0.9542949576271187, 0.8488331016949152, 0.5162421355932203], 
             UndirectedEdge[264, 279] -> 
             RGBColor[
              0.9279975508474576, 0.7960374576271187, 0.5943490677966101], 
             UndirectedEdge[81, 344] -> 
             RGBColor[
              0.9769608050847457, 0.9798721694915253, 0.7919133983050847], 
             UndirectedEdge[287, 391] -> 
             RGBColor[
              0.9499013050847458, 0.8270729830508474, 0.4060662627118644], 
             UndirectedEdge[90, 228] -> 
             RGBColor[
              0.9784729745762711, 0.9731786779661017, 0.6714072966101695], 
             UndirectedEdge[222, 259] -> 
             RGBColor[
              0.9935392372881355, 0.988589406779661, 0.5381640338983049], 
             UndirectedEdge[143, 342] -> 
             RGBColor[
              0.9812578389830509, 0.954792033898305, 0.5832880423728812], 
             UndirectedEdge[68, 262] -> 
             RGBColor[
              0.9715116779661017, 0.9117189491525424, 0.4845204322033899], 
             UndirectedEdge[73, 189] -> 
             RGBColor[
              0.9689687627118644, 0.9069864915254237, 0.33394993220338975`], 
             UndirectedEdge[79, 176] -> 
             RGBColor[
              0.9764006271186441, 0.9320559152542374, 0.36282132203389833`], 
             UndirectedEdge[14, 289] -> 
             RGBColor[
              0.9943870677966102, 0.9904028305084747, 0.630445152542373], 
             UndirectedEdge[126, 373] -> 
             RGBColor[
              0.9769383559322034, 0.9806349322033898, 0.8484050338983051], 
             UndirectedEdge[313, 361] -> 
             RGBColor[
              0.9761040169491525, 0.929892593220339, 0.46054399999999995`], 
             UndirectedEdge[56, 203] -> 
             RGBColor[
              0.9445759830508476, 0.8047546949152543, 0.3405997033898305], 
             UndirectedEdge[163, 240] -> 
             RGBColor[
              0.9654025593220339, 0.8890462711864406, 0.38800595762711854`], 
             UndirectedEdge[283, 380] -> 
             RGBColor[
              0.9710411101694915, 0.948109254237288, 0.642535906779661], 
             UndirectedEdge[165, 318] -> 
             RGBColor[
              0.9183877457627119, 0.6586122033898306, 0.4093348305084745], 
             UndirectedEdge[184, 185] -> 
             RGBColor[
              0.9832532711864407, 0.9543575423728813, 0.45865501694915245`], 
             UndirectedEdge[123, 364] -> 
             RGBColor[
              0.8928250254237289, 0.867467406779661, 0.637041559322034], 
             UndirectedEdge[24, 341] -> 
             RGBColor[
              0.8778211016949153, 0.5380959830508475, 0.21976327118644068`], 
             UndirectedEdge[10, 364] -> 
             RGBColor[
              0.8838188305084747, 0.910091186440678, 0.9851064152542373], 
             UndirectedEdge[59, 132] -> 
             RGBColor[
              0.9926914067796611, 0.9867759830508475, 0.4458829152542371], 
             UndirectedEdge[110, 309] -> 
             RGBColor[
              0.9862585677966101, 0.9860190169491526, 0.7136971949152541], 
             UndirectedEdge[28, 50] -> 
             RGBColor[
              0.931444220338983, 0.7430900508474576, 0.421215906779661], 
             UndirectedEdge[120, 147] -> 
             RGBColor[
              0.9823856355932203, 0.955258406779661, 0.5645975338983049], 
             UndirectedEdge[322, 335] -> 
             RGBColor[
              0.9747570423728813, 0.9606439661016949, 0.6569716016949152], 
             UndirectedEdge[9, 198] -> 
             RGBColor[
              0.9233785169491525, 0.7212943389830508, 0.5298907627118645], 
             UndirectedEdge[214, 257] -> 
             RGBColor[
              0.9790022457627119, 0.9538592881355932, 0.6206690593220339], 
             UndirectedEdge[190, 274] -> 
             RGBColor[
              0.9901333983050847, 0.9879530508474577, 0.6507271949152542], 
             UndirectedEdge[18, 198] -> 
             RGBColor[
              0.8825812033898306, 0.5592053220338983, 0.22370908474576273`], 
             UndirectedEdge[280, 291] -> 
             RGBColor[
              0.9901360423728813, 0.9899045762711864, 0.7924591949152544], 
             UndirectedEdge[156, 179] -> 
             RGBColor[
              0.9636919830508475, 0.9718800169491526, 0.9211720169491526], 
             UndirectedEdge[76, 96] -> 
             RGBColor[
              0.9603778813559322, 0.875673661016949, 0.3127302966101694], 
             UndirectedEdge[143, 158] -> 
             RGBColor[
              0.9812578389830509, 0.954792033898305, 0.5832880423728812], 
             UndirectedEdge[252, 274] -> 
             RGBColor[
              0.9703812372881355, 0.9093010508474575, 0.361478940677966], 
             UndirectedEdge[272, 348] -> 
             RGBColor[
              0.9764006271186441, 0.9320559152542371, 0.36282132203389816`], 
             UndirectedEdge[51, 232] -> 
             RGBColor[
              0.9479058728813559, 0.8275074745762712, 0.5306992881355932], 
             UndirectedEdge[66, 317] -> 
             RGBColor[
              0.9834179491525423, 0.9865916101694916, 0.8877811016949153], 
             UndirectedEdge[258, 264] -> 
             RGBColor[
              0.9769608050847457, 0.9798721694915253, 0.7919133983050847], 
             UndirectedEdge[17, 223] -> 
             RGBColor[
              0.9536449491525423, 0.9644076610169492, 0.9426860084745763], 
             UndirectedEdge[46, 271] -> 
             RGBColor[
              0.9270259152542373, 0.7483891016949151, 0.26014154237288134`], 
             UndirectedEdge[93, 201] -> 
             RGBColor[
              0.9349259406779661, 0.9473484915254238, 0.8399478983050848], 
             UndirectedEdge[232, 373] -> 
             RGBColor[
              0.9501614661016949, 0.8284402203389831, 0.4933182711864407], 
             UndirectedEdge[182, 208] -> 
             RGBColor[
              0.9178225254237289, 0.6574032542372883, 0.3478140847457626], 
             UndirectedEdge[10, 391] -> 
             RGBColor[
              0.9228946694915254, 0.8097909999999999, 0.6149903389830509], 
             UndirectedEdge[284, 366] -> 
             RGBColor[
              0.955727813559322, 0.8491411864406779, 0.47182036440677977`], 
             UndirectedEdge[154, 387] -> 
             RGBColor[
              0.9127303813559322, 0.8351203389830508, 0.625158127118644], 
             UndirectedEdge[135, 363] -> 
             RGBColor[
              0.9662499915254237, 0.9707029491525423, 0.7163277372881356], 
             UndirectedEdge[37, 269] -> 
             RGBColor[
              0.9581561355932203, 0.9662731525423729, 0.8679239745762712], 
             UndirectedEdge[201, 281] -> 
             RGBColor[
              0.9763866271186441, 0.9304970677966102, 0.491304372881356], 
             UndirectedEdge[302, 377] -> 
             RGBColor[
              0.9371621525423728, 0.7880264745762711, 0.2711588389830508], 
             UndirectedEdge[179, 286] -> 
             RGBColor[
              0.9334172457627119, 0.8515095084745763, 0.6234570508474576], 
             UndirectedEdge[108, 325] -> 
             RGBColor[
              0.9796142542372881, 0.9833800847457628, 0.8774383220338984], 
             UndirectedEdge[279, 299] -> 
             RGBColor[
              0.9170045254237289, 0.7064205084745763, 0.2519623728813559], 
             UndirectedEdge[196, 332] -> 
             RGBColor[
              0.9662499915254237, 0.9707029491525423, 0.7163277372881355], 
             UndirectedEdge[31, 224] -> 
             RGBColor[
              0.9920865762711863, 0.9909956101694916, 0.7808094406779661], 
             UndirectedEdge[200, 296] -> 
             RGBColor[
              0.9498553050847458, 0.8339551525423728, 0.30426358474576265`], 
             UndirectedEdge[170, 221] -> 
             RGBColor[
              0.9904025254237288, 0.9788224915254238, 0.45676603389830495`], 
             UndirectedEdge[198, 206] -> 
             RGBColor[
              0.9159331694915254, 0.6864898813559321, 0.2762978389830507], 
             UndirectedEdge[36, 361] -> 
             RGBColor[
              0.993821847457627, 0.9891938813559322, 0.5689244067796608], 
             UndirectedEdge[132, 180] -> 
             RGBColor[
              0.9826880508474576, 0.953148593220339, 0.3971342711864405], 
             UndirectedEdge[127, 312] -> 
             RGBColor[
              0.9537462627118644, 0.915684033898305, 0.6303599745762711], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.9904025254237288, 0.9788224915254238, 0.45676603389830495`], 
             UndirectedEdge[67, 75] -> 
             RGBColor[
              0.9269105847457627, 0.7419873220338984, 0.5524695762711864], 
             UndirectedEdge[110, 287] -> 
             RGBColor[
              0.9865411779661017, 0.9866234915254237, 0.7444575677966101], 
             UndirectedEdge[88, 233] -> 
             RGBColor[
              0.987251813559322, 0.9674967288135593, 0.5038510847457626], 
             UndirectedEdge[168, 216] -> 
             RGBColor[
              0.9871063983050847, 0.9878324406779662, 0.8059783135593221], 
             UndirectedEdge[1, 291] -> 
             RGBColor[
              0.9180323474576271, 0.6896252372881357, 0.5445895847457627], 
             UndirectedEdge[115, 214] -> 
             RGBColor[
              0.9864475932203389, 0.9886637457627119, 0.8742619830508476], 
             UndirectedEdge[233, 256] -> 
             RGBColor[
              0.9142095084745763, 0.6264964406779658, 0.40533374576271175`], 
             UndirectedEdge[4, 252] -> 
             RGBColor[
              0.9689510254237288, 0.9109444915254237, 0.5476327118644068], 
             UndirectedEdge[91, 399] -> 
             RGBColor[
              0.9117147966101695, 0.6552871525423728, 0.2723061525423728], 
             UndirectedEdge[76, 269] -> 
             RGBColor[
              0.9350205847457627, 0.886222033898305, 0.6347472457627119], 
             UndirectedEdge[91, 172] -> 
             RGBColor[
              0.961178127118644, 0.9407534576271186, 0.6592313644067795], 
             UndirectedEdge[165, 184] -> 
             RGBColor[
              0.9941044576271186, 0.9897983559322034, 0.599684779661017], 
             UndirectedEdge[60, 139] -> 
             RGBColor[
              0.9711814830508474, 0.9743808474576271, 0.7079800084745762], 
             UndirectedEdge[356, 359] -> 
             RGBColor[
              0.9651199491525424, 0.8884417966101694, 0.3572455847457626], 
             UndirectedEdge[228, 305] -> 
             RGBColor[
              0.983404466101695, 0.9768565762711865, 0.6630595677966101], 
             UndirectedEdge[141, 209] -> 
             RGBColor[
              0.977541906779661, 0.9422573220338983, 0.5688523474576271], 
             UndirectedEdge[171, 348] -> 
             RGBColor[
              0.9445940169491525, 0.8130958983050847, 0.30003022881355923`], 
             UndirectedEdge[10, 60] -> 
             RGBColor[
              0.9447400677966101, 0.9583078135593219, 0.9784248305084746], 
             UndirectedEdge[234, 298] -> 
             RGBColor[
              0.9861015677966102, 0.9677931186440678, 0.5790332288135592], 
             UndirectedEdge[323, 388] -> 
             RGBColor[
              0.8996423898305085, 0.5785209152542371, 0.24986828813559323`], 
             UndirectedEdge[294, 329] -> 
             RGBColor[
              0.9834179491525423, 0.9865916101694916, 0.8877811016949153], 
             UndirectedEdge[211, 238] -> 
             RGBColor[
              0.9920865762711863, 0.9909956101694916, 0.7808094406779661], 
             UndirectedEdge[31, 99] -> 
             RGBColor[
              0.9314217711864408, 0.7438528135593221, 0.4777075423728814], 
             UndirectedEdge[111, 319] -> 
             RGBColor[
              0.9912638389830508, 0.9903709491525424, 0.7737686864406781], 
             UndirectedEdge[258, 394] -> 
             RGBColor[
              0.9921090254237288, 0.9902328474576272, 0.7243178050847456], 
             UndirectedEdge[101, 364] -> 
             RGBColor[0.8774275, 0.806970779661017, 0.621790906779661], 
             UndirectedEdge[225, 349] -> 
             RGBColor[
              0.9801025593220339, 0.943031779661017, 0.5057400677966103], 
             UndirectedEdge[118, 386] -> 
             RGBColor[
              0.9813270762711863, 0.9823411186440678, 0.7220449237288135], 
             UndirectedEdge[95, 326] -> 
             RGBColor[
              0.9382885593220339, 0.7836620169491526, 0.30628675423728813`], 
             UndirectedEdge[228, 382] -> 
             RGBColor[
              0.9912503559322035, 0.9806359152542373, 0.549047152542373], 
             UndirectedEdge[120, 255] -> 
             RGBColor[
              0.9345726271186441, 0.7711273050847458, 0.2918510593220338], 
             UndirectedEdge[222, 292] -> 
             RGBColor[
              0.9901333983050847, 0.9879530508474577, 0.6507271949152542], 
             UndirectedEdge[325, 397] -> 
             RGBColor[
              0.9017147372881356, 0.6196436779661014, 0.5584542627118644], 
             UndirectedEdge[155, 299] -> 
             RGBColor[
              0.9614341440677966, 0.8891524915254237, 0.580780372881356], 
             UndirectedEdge[17, 99] -> 
             RGBColor[
              0.8952357372881357, 0.7181976101694916, 0.602203093220339], 
             UndirectedEdge[60, 105] -> 
             RGBColor[
              0.9686234745762712, 0.9755579152542373, 0.9128242881355932], 
             UndirectedEdge[229, 340] -> 
             RGBColor[
              0.9312240084745762, 0.9363726271186441, 0.6970291525423729], 
             UndirectedEdge[297, 375] -> 
             RGBColor[
              0.923365033898305, 0.7115593050847457, 0.3051692288135593], 
             UndirectedEdge[155, 249] -> 
             RGBColor[
              0.9864341101694916, 0.9789287118644068, 0.6495404491525424], 
             UndirectedEdge[143, 348] -> 
             RGBColor[
              0.9812578389830509, 0.954792033898305, 0.5832880423728812], 
             UndirectedEdge[175, 294] -> 
             RGBColor[
              0.9904160084745762, 0.9885575254237289, 0.6814875677966101], 
             UndirectedEdge[19, 181] -> 
             RGBColor[
              0.9875484237288136, 0.9696600508474577, 0.406128406779661], 
             UndirectedEdge[153, 294] -> 
             RGBColor[
              0.9573006525423728, 0.8687596101694917, 0.5578565084745764], 
             UndirectedEdge[68, 376] -> 
             RGBColor[
              0.9912638389830508, 0.9903709491525424, 0.7737686864406781], 
             UndirectedEdge[317, 354] -> 
             RGBColor[
              0.9722566694915254, 0.9392524406779661, 0.6197524830508474], 
             UndirectedEdge[2, 254] -> 
             RGBColor[
              0.9758105593220339, 0.980168559322034, 0.8670955423728812], 
             UndirectedEdge[243, 311] -> 
             RGBColor[
              0.9784864576271186, 0.9829137118644068, 0.8961288305084747], 
             UndirectedEdge[23, 143] -> 
             RGBColor[0.9584284491525423, 0.8692259830508475, 0.539166], 
             UndirectedEdge[20, 64] -> 
             RGBColor[
              0.9606840423728813, 0.8701587288135594, 0.5017849830508475], 
             UndirectedEdge[75, 296] -> 
             RGBColor[
              0.9790022457627119, 0.9538592881355932, 0.6206690593220339], 
             UndirectedEdge[146, 227] -> 
             RGBColor[
              0.9937993983050848, 0.9899566440677967, 0.6254160423728812], 
             UndirectedEdge[160, 238] -> 
             RGBColor[
              0.9920865762711863, 0.9909956101694916, 0.7808094406779661], 
             UndirectedEdge[75, 178] -> 
             RGBColor[
              0.975286313559322, 0.9413245762711865, 0.6062333644067797], 
             UndirectedEdge[95, 166] -> 
             RGBColor[
              0.8621448220338983, 0.7441429322033899, 0.6093783813559323], 
             UndirectedEdge[25, 309] -> 
             RGBColor[
              0.9926716016949153, 0.9894902711864407, 0.6441065508474575], 
             UndirectedEdge[166, 326] -> 
             RGBColor[
              0.9039728220338983, 0.9050715423728813, 0.6803486440677966], 
             UndirectedEdge[158, 308] -> 
             RGBColor[
              0.9790022457627119, 0.9538592881355932, 0.6206690593220339], 
             UndirectedEdge[229, 343] -> 
             RGBColor[
              0.9301096949152542, 0.9456412881355932, 0.9404411949152542], 
             UndirectedEdge[229, 294] -> 
             RGBColor[
              0.9312374915254237, 0.9461076610169492, 0.921750686440678], 
             UndirectedEdge[64, 257] -> 
             RGBColor[
              0.9835134322033898, 0.9557247796610169, 0.5459070254237287], 
             UndirectedEdge[56, 65] -> 
             RGBColor[
              0.9454013644067797, 0.8073308813559323, 0.4893724576271187], 
             UndirectedEdge[170, 192] -> 
             RGBColor[
              0.9935392372881355, 0.988589406779661, 0.5381640338983049], 
             UndirectedEdge[133, 347] -> 
             RGBColor[
              0.8939929152542374, 0.9157387118644068, 0.8805504491525423], 
             UndirectedEdge[223, 393] -> 
             RGBColor[
              0.9790022457627119, 0.9538592881355932, 0.6206690593220339], 
             UndirectedEdge[116, 338] -> 
             RGBColor[
              0.9499013050847458, 0.8270729830508474, 0.4060662627118644], 
             UndirectedEdge[32, 71] -> 
             RGBColor[
              0.9764141101694915, 0.9417909491525425, 0.5875428559322036], 
             UndirectedEdge[95, 361] -> 
             RGBColor[
              0.945423813559322, 0.8065681186440679, 0.43288082203389827`], 
             UndirectedEdge[247, 292] -> 
             RGBColor[
              0.9547727457627118, 0.9648740338983051, 0.9239955000000001], 
             UndirectedEdge[337, 391] -> 
             RGBColor[
              0.9165033389830508, 0.706670593220339, 0.2516748305084746], 
             UndirectedEdge[181, 238] -> 
             RGBColor[
              0.9886897033898305, 0.9798614576271187, 0.6121594322033899], 
             UndirectedEdge[97, 246] -> 
             RGBColor[
              0.9614341440677966, 0.8891524915254237, 0.580780372881356], 
             UndirectedEdge[62, 247] -> 
             RGBColor[
              0.9578959745762712, 0.9649059152542373, 0.780671966101695], 
             UndirectedEdge[207, 280] -> 
             RGBColor[
              0.955727813559322, 0.8491411864406779, 0.47182036440677977`], 
             UndirectedEdge[145, 221] -> 
             RGBColor[
              0.9912503559322035, 0.9806359152542373, 0.549047152542373], 
             UndirectedEdge[10, 334] -> 
             RGBColor[
              0.9599625677966102, 0.9496102711864407, 0.6820147881355931], 
             UndirectedEdge[25, 78] -> 
             RGBColor[
              0.9926716016949153, 0.9894902711864407, 0.6441065508474575], 
             UndirectedEdge[46, 139] -> 
             RGBColor[
              0.9545973728813559, 0.8467232881355932, 0.34877887288135584`], 
             UndirectedEdge[224, 383] -> 
             RGBColor[
              0.9909587796610169, 0.9905292372881356, 0.7994999491525423], 
             UndirectedEdge[138, 164] -> 
             RGBColor[
              0.9092153305084746, 0.7816756779661018, 0.6138680084745762], 
             UndirectedEdge[53, 93] -> 
             RGBColor[
              0.9221485593220338, 0.9398912542372881, 0.9623080423728814], 
             UndirectedEdge[31, 199] -> 
             RGBColor[
              0.9769383559322034, 0.9806349322033898, 0.8484050338983051], 
             UndirectedEdge[98, 342] -> 
             RGBColor[
              0.9033583220338983, 0.5910556271186438, 0.26430398305084735`], 
             UndirectedEdge[141, 304] -> 
             RGBColor[
              0.8965409576271187, 0.8800021186440679, 0.6514772542372882], 
             UndirectedEdge[32, 105] -> 
             RGBColor[
              0.9764141101694915, 0.9417909491525425, 0.5875428559322036], 
             UndirectedEdge[216, 329] -> 
             RGBColor[
              0.9792605084745762, 0.9840531016949153, 0.9199907288135593], 
             UndirectedEdge[164, 264] -> 
             RGBColor[
              0.9279975508474576, 0.7960374576271187, 0.5943490677966101], 
             UndirectedEdge[118, 196] -> 
             RGBColor[
              0.9546030508474576, 0.9656636101694915, 0.961729372881356], 
             UndirectedEdge[75, 398] -> 
             RGBColor[
              0.9895708220338983, 0.9886956271186441, 0.7309384491525424], 
             UndirectedEdge[45, 48] -> 
             RGBColor[
              0.9697512711864407, 0.9760242881355932, 0.8941337796610169], 
             UndirectedEdge[248, 275] -> 
             RGBColor[
              0.9861015677966102, 0.9677931186440678, 0.5790332288135592], 
             UndirectedEdge[200, 347] -> 
             RGBColor[0.8614625847457628, 0.7944354576271186, 0.6202165], 
             UndirectedEdge[33, 58] -> 
             RGBColor[
              0.9792547288135593, 0.9412183559322034, 0.4134589491525423], 
             UndirectedEdge[134, 240] -> 
             RGBColor[
              0.9926716016949153, 0.9894902711864407, 0.6441065508474575], 
             UndirectedEdge[267, 344] -> 
             RGBColor[
              0.9763955847457626, 0.9786632203389831, 0.7303926525423727], 
             UndirectedEdge[141, 286] -> 
             RGBColor[
              0.946139372881356, 0.8214204406779662, 0.28982788983050856`], 
             UndirectedEdge[33, 209] -> 
             RGBColor[
              0.9915438050847457, 0.9890238983050847, 0.6627970593220338], 
             UndirectedEdge[47, 155] -> 
             RGBColor[
              0.9715703813559322, 0.9287898644067797, 0.5917976694915255], 
             UndirectedEdge[153, 229] -> 
             RGBColor[
              0.9009627542372881, 0.8257371525423729, 0.624035720338983], 
             UndirectedEdge[64, 161] -> 
             RGBColor[
              0.9712066186440678, 0.9118772372881355, 0.5102516949152542], 
             UndirectedEdge[3, 293] -> 
             RGBColor[
              0.9581785847457627, 0.9655103898305084, 0.8114323389830508], 
             UndirectedEdge[133, 178] -> 
             RGBColor[
              0.9786697033898306, 0.9427236949152542, 0.5501618389830508], 
             UndirectedEdge[113, 162] -> 
             RGBColor[
              0.9838184915254238, 0.9555664915254236, 0.5201757627118644], 
             UndirectedEdge[313, 358] -> 
             RGBColor[
              0.9615368983050847, 0.8819170677966102, 0.30507854237288135`], 
             UndirectedEdge[259, 292] -> 
             RGBColor[
              0.9909812288135593, 0.9897664745762712, 0.7430083135593221], 
             UndirectedEdge[4, 165] -> 
             RGBColor[
              0.9921090254237288, 0.9902328474576272, 0.7243178050847456], 
             UndirectedEdge[247, 385] -> 
             RGBColor[
              0.9510433305084746, 0.9426042881355932, 0.6848382711864406], 
             UndirectedEdge[38, 243] -> 
             RGBColor[0.8975365, 0.5875279152542372, 0.5544531779661017], 
             UndirectedEdge[265, 381] -> 
             RGBColor[
              0.9943421694915254, 0.9919283559322034, 0.7434284237288136], 
             UndirectedEdge[15, 369] -> 
             RGBColor[
              0.9895708220338983, 0.9886956271186441, 0.7309384491525424], 
             UndirectedEdge[30, 358] -> 
             RGBColor[
              0.9764141101694915, 0.9417909491525425, 0.5875428559322036], 
             UndirectedEdge[133, 330] -> 
             RGBColor[
              0.9334930847457628, 0.947040406779661, 0.8843696694915253], 
             UndirectedEdge[223, 292] -> 
             RGBColor[
              0.9864475932203389, 0.9886637457627119, 0.8742619830508476], 
             UndirectedEdge[44, 326] -> 
             RGBColor[
              0.9872293644067797, 0.9682594915254237, 0.560342720338983], 
             UndirectedEdge[123, 356] -> 
             RGBColor[
              0.9752561864406779, 0.9280791694915254, 0.3682628813559321], 
             UndirectedEdge[35, 154] -> 
             RGBColor[
              0.9464109576271187, 0.9561272033898305, 0.8103099322033898], 
             UndirectedEdge[146, 151] -> 
             RGBColor[
              0.9909587796610169, 0.9905292372881356, 0.7994999491525425], 
             UndirectedEdge[111, 287] -> 
             RGBColor[
              0.9943870677966102, 0.9904028305084747, 0.630445152542373], 
             UndirectedEdge[42, 133] -> 
             RGBColor[
              0.9909587796610169, 0.9905292372881356, 0.7994999491525423], 
             UndirectedEdge[40, 103] -> 
             RGBColor[
              0.9861015677966102, 0.9677931186440678, 0.5790332288135592], 
             UndirectedEdge[219, 260] -> 
             RGBColor[
              0.9823856355932203, 0.955258406779661, 0.5645975338983049], 
             UndirectedEdge[151, 186] -> 
             RGBColor[
              0.987561906779661, 0.9793950847457628, 0.6308499406779662], 
             UndirectedEdge[8, 76] -> 
             RGBColor[
              0.9375484915254237, 0.7901076101694915, 0.2686082542372881], 
             UndirectedEdge[124, 167] -> 
             RGBColor[
              0.9024337118644068, 0.5518935254237288, 0.2851732033898305], 
             UndirectedEdge[162, 291] -> 
             RGBColor[
              0.9901360423728813, 0.9899045762711864, 0.7924591949152544], 
             UndirectedEdge[242, 255] -> 
             RGBColor[
              0.9457064237288135, 0.8071725932203391, 0.46364119491525435`], 
             UndirectedEdge[182, 323] -> 
             RGBColor[
              0.9792547288135593, 0.9412183559322034, 0.4134589491525423], 
             UndirectedEdge[138, 149] -> 
             RGBColor[
              0.9559005423728812, 0.965340406779661, 0.9053049915254237], 
             UndirectedEdge[199, 353] -> 
             RGBColor[
              0.9693975254237288, 0.9766973050847458, 0.9366861864406779], 
             UndirectedEdge[34, 381] -> 
             RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             UndirectedEdge[148, 305] -> 
             RGBColor[
              0.9722566694915254, 0.9392524406779661, 0.6197524830508474], 
             UndirectedEdge[97, 383] -> 
             RGBColor[
              0.9887031864406779, 0.9895964915254238, 0.8368809661016949], 
             UndirectedEdge[154, 207] -> 
             RGBColor[
              0.907469093220339, 0.8142610847457626, 0.6209247711864406], 
             UndirectedEdge[272, 375] -> 
             RGBColor[
              0.9838324915254237, 0.9571253389830509, 0.3916927118644067], 
             UndirectedEdge[25, 323] -> 
             RGBColor[
              0.9786697033898306, 0.9427236949152542, 0.5501618389830508], 
             UndirectedEdge[236, 334] -> 
             RGBColor[
              0.9861015677966102, 0.9677931186440678, 0.5790332288135592], 
             UndirectedEdge[23, 346] -> 
             RGBColor[0.9584284491525423, 0.8692259830508475, 0.539166], 
             UndirectedEdge[23, 151] -> 
             RGBColor[
              0.9573006525423728, 0.8687596101694917, 0.5578565084745764], 
             UndirectedEdge[250, 381] -> 
             RGBColor[
              0.9937993983050848, 0.9899566440677967, 0.6254160423728812], 
             UndirectedEdge[230, 264] -> 
             RGBColor[
              0.9758105593220339, 0.980168559322034, 0.8670955423728812], 
             UndirectedEdge[60, 68] -> 
             RGBColor[
              0.9723119237288136, 0.9767987457627119, 0.8310215000000001], 
             UndirectedEdge[50, 258] -> 
             RGBColor[
              0.9943870677966101, 0.9904028305084746, 0.6304451525423728], 
             UndirectedEdge[121, 298] -> 
             RGBColor[
              0.9875344237288135, 0.9681012033898305, 0.5346114576271187], 
             UndirectedEdge[95, 382] -> 
             RGBColor[
              0.9457064237288135, 0.8071725932203391, 0.46364119491525435`], 
             UndirectedEdge[42, 200] -> 
             RGBColor[0.9584284491525423, 0.8692259830508475, 0.539166], 
             UndirectedEdge[254, 314] -> 
             RGBColor[
              0.9758105593220339, 0.980168559322034, 0.8670955423728812], 
             UndirectedEdge[95, 305] -> 
             RGBColor[
              0.937860533898305, 0.8033932542372882, 0.5776536101694916], 
             UndirectedEdge[321, 381] -> 
             RGBColor[
              0.9937993983050848, 0.9899566440677967, 0.6254160423728812], 
             UndirectedEdge[116, 209] -> 
             RGBColor[
              0.9479058728813559, 0.8275074745762712, 0.5306992881355932], 
             UndirectedEdge[364, 366] -> 
             RGBColor[
              0.8721662118644068, 0.7861115254237288, 0.6175575508474577], 
             UndirectedEdge[58, 156] -> 
             RGBColor[
              0.9764141101694915, 0.9417909491525425, 0.5875428559322036], 
             UndirectedEdge[118, 179] -> 
             RGBColor[
              0.9546030508474576, 0.9656636101694915, 0.961729372881356], 
             UndirectedEdge[149, 328] -> 
             RGBColor[
              0.9918264152542373, 0.989628372881356, 0.6935574322033898], 
             UndirectedEdge[215, 227] -> 
             RGBColor[
              0.9220007627118644, 0.6895190169491525, 0.35181516949152525`], 
             UndirectedEdge[70, 177] -> 
             RGBColor[
              0.9723119237288136, 0.9767987457627119, 0.8310215000000001], 
             UndirectedEdge[383, 393] -> 
             RGBColor[
              0.9823856355932203, 0.955258406779661, 0.5645975338983049], 
             UndirectedEdge[14, 201] -> 
             RGBColor[
              0.9949522881355932, 0.991611779661017, 0.6919658983050849], 
             UndirectedEdge[5, 368] -> 
             RGBColor[
              0.9501614661016949, 0.8284402203389831, 0.4933182711864407], 
             UndirectedEdge[214, 310] -> 
             RGBColor[
              0.9269105847457627, 0.7419873220338984, 0.5524695762711864], 
             UndirectedEdge[35, 280] -> 
             RGBColor[
              0.9946696779661017, 0.9910073050847458, 0.6612055254237288], 
             UndirectedEdge[243, 275] -> 
             RGBColor[
              0.9807420508474576, 0.9838464576271186, 0.8587478135593221], 
             UndirectedEdge[131, 391] -> 
             RGBColor[
              0.9501614661016949, 0.8284402203389831, 0.49331827118644067`], 
             UndirectedEdge[2, 314] -> 
             RGBColor[
              0.9920865762711865, 0.9909956101694916, 0.780809440677966], 
             UndirectedEdge[282, 361] -> 
             RGBColor[
              0.9935392372881355, 0.988589406779661, 0.5381640338983049], 
             UndirectedEdge[110, 269] -> 
             RGBColor[
              0.9506153050847457, 0.9623355254237289, 0.956205127118644], 
             UndirectedEdge[193, 360] -> 
             RGBColor[
              0.993214372881356, 0.9914619830508475, 0.7621189322033898], 
             UndirectedEdge[71, 400] -> 
             RGBColor[
              0.9838459745762711, 0.966860372881356, 0.6164142457627119], 
             UndirectedEdge[110, 117] -> 
             RGBColor[
              0.9868237881355932, 0.9872279661016949, 0.775217940677966], 
             UndirectedEdge[170, 351] -> 
             RGBColor[
              0.9829706610169491, 0.9537530677966102, 0.42789464406779637`], 
             UndirectedEdge[121, 200] -> 
             RGBColor[
              0.9609891016949152, 0.8700004406779662, 0.4760537203389832], 
             UndirectedEdge[38, 383] -> 
             RGBColor[
              0.9088810254237288, 0.59467706779661, 0.4765148050847457], 
             UndirectedEdge[172, 256] -> 
             RGBColor[
              0.8918517542372881, 0.612287881355932, 0.575149720338983], 
             UndirectedEdge[127, 258] -> 
             RGBColor[
              0.9761040169491525, 0.929892593220339, 0.46054399999999995`], 
             UndirectedEdge[25, 388] -> 
             RGBColor[
              0.9130592627118643, 0.6267928305084745, 0.4805158898305084], 
             UndirectedEdge[51, 277] -> 
             RGBColor[
              0.9431457711864406, 0.8063981355932204, 0.5267534745762712], 
             UndirectedEdge[85, 379] -> 
             RGBColor[
              0.9224808983050847, 0.7248985254237288, 0.25909136440677966`], 
             UndirectedEdge[267, 306] -> 
             RGBColor[
              0.9654025593220339, 0.8890462711864406, 0.38800595762711854`], 
             UndirectedEdge[176, 298] -> 
             RGBColor[
              0.9838324915254237, 0.9571253389830509, 0.3916927118644067], 
             UndirectedEdge[269, 323] -> 
             RGBColor[
              0.943611466101695, 0.9175348644067797, 0.6559668813559323], 
             UndirectedEdge[21, 180] -> 
             RGBColor[
              0.9812578389830509, 0.954792033898305, 0.5832880423728812], 
             UndirectedEdge[36, 228] -> 
             RGBColor[
              0.9904025254237288, 0.9788224915254238, 0.45676603389830495`], 
             UndirectedEdge[74, 116] -> 
             RGBColor[
              0.9490336694915255, 0.8279738474576271, 0.5120087796610169], 
             UndirectedEdge[3, 188] -> 
             RGBColor[
              0.9909677457627118, 0.9800314406779661, 0.5182867796610169], 
             UndirectedEdge[69, 394] -> 
             RGBColor[
              0.9431457711864406, 0.8063981355932204, 0.5267534745762712], 
             UndirectedEdge[37, 395] -> 
             RGBColor[
              0.9360816355932203, 0.7650121694915255, 0.4815958474576271], 
             UndirectedEdge[172, 194] -> 
             RGBColor[
              0.9717467033898305, 0.9755897966101694, 0.7695007542372881], 
             UndirectedEdge[59, 264] -> 
             RGBColor[
              0.9761129745762711, 0.9780587457627119, 0.6996322796610168], 
             UndirectedEdge[28, 369] -> 
             RGBColor[
              0.9269105847457627, 0.7419873220338984, 0.5524695762711864], 
             UndirectedEdge[130, 344] -> 
             RGBColor[
              0.9693975254237288, 0.9766973050847458, 0.9366861864406779], 
             UndirectedEdge[29, 270] -> 
             RGBColor[
              0.9279975508474576, 0.7960374576271187, 0.5943490677966101], 
             UndirectedEdge[41, 48] -> 
             RGBColor[
              0.9574621949152542, 0.9282187457627118, 0.6447956694915254], 
             UndirectedEdge[12, 124] -> 
             RGBColor[
              0.9013193983050847, 0.561162186440678, 0.5285852457627118], 
             UndirectedEdge[61, 95] -> 
             RGBColor[
              0.9271407627118644, 0.7460578813559322, 0.2629796694915254], 
             UndirectedEdge[213, 306] -> 
             RGBColor[
              0.938678533898305, 0.8723687627118644, 0.627690406779661], 
             UndirectedEdge[63, 295] -> 
             RGBColor[
              0.9935194322033898, 0.9913036949152543, 0.7363876694915255], 
             UndirectedEdge[302, 367] -> 
             RGBColor[
              0.8875699830508474, 0.5017546779661017, 0.22743042372881356`], 
             UndirectedEdge[140, 331] -> 
             RGBColor[
              0.9786697033898306, 0.9427236949152542, 0.5501618389830508], 
             UndirectedEdge[92, 354] -> 
             RGBColor[
              0.9261968305084747, 0.7374332372881356, 0.2735270593220339], 
             UndirectedEdge[151, 311] -> 
             RGBColor[
              0.9875753898305084, 0.9891301186440679, 0.8555714745762714], 
             UndirectedEdge[299, 371] -> 
             RGBColor[
              0.9636897372881356, 0.8900852372881356, 0.5433993559322035], 
             UndirectedEdge[140, 389] -> 
             RGBColor[
              0.9574621949152542, 0.9282187457627118, 0.6447956694915254], 
             UndirectedEdge[176, 205] -> 
             RGBColor[
              0.987561906779661, 0.9793950847457628, 0.6308499406779662], 
             UndirectedEdge[152, 179] -> 
             RGBColor[
              0.9398085762711864, 0.9546299152542372, 0.9867725593220339], 
             UndirectedEdge[142, 293] -> 
             RGBColor[
              0.9576133644067797, 0.9643014406779662, 0.7499115932203388], 
             UndirectedEdge[105, 259] -> 
             RGBColor[
              0.9909812288135593, 0.9897664745762712, 0.7430083135593221], 
             UndirectedEdge[274, 318] -> 
             RGBColor[
              0.9175399152542374, 0.6567987796610171, 0.31705371186440673`], 
             UndirectedEdge[231, 369] -> 
             RGBColor[
              0.9614341440677966, 0.8891524915254237, 0.5807803728813559], 
             UndirectedEdge[151, 348] -> 
             RGBColor[
              0.9801300423728814, 0.954325661016949, 0.6019785508474575], 
             UndirectedEdge[147, 231] -> 
             RGBColor[
              0.9648175338983052, 0.8905516101694915, 0.524708847457627], 
             UndirectedEdge[66, 354] -> 
             RGBColor[
              0.9764141101694915, 0.9417909491525425, 0.5875428559322036], 
             UndirectedEdge[24, 65] -> 
             RGBColor[
              0.9454013644067797, 0.8073308813559323, 0.4893724576271187], 
             UndirectedEdge[42, 347] -> 
             RGBColor[
              0.8928651186440678, 0.9152723389830508, 0.8992409576271186], 
             UndirectedEdge[52, 129] -> 
             RGBColor[
              0.9769608050847457, 0.9798721694915253, 0.7919133983050847], 
             UndirectedEdge[3, 7] -> 
             RGBColor[
              0.945423813559322, 0.8065681186440679, 0.43288082203389827`], 
             UndirectedEdge[156, 352] -> 
             RGBColor[
              0.9906986186440678, 0.9891620000000001, 0.7122479406779663], 
             UndirectedEdge[229, 329] -> 
             RGBColor[
              0.9270800508474576, 0.9435691525423728, 0.953960313559322], 
             UndirectedEdge[80, 187] -> 
             RGBColor[
              0.9834179491525423, 0.9865916101694916, 0.8877811016949153], 
             UndirectedEdge[247, 362] -> 
             RGBColor[
              0.9581785847457627, 0.9655103898305084, 0.8114323389830508], 
             UndirectedEdge[43, 321] -> 
             RGBColor[
              0.9813270762711863, 0.9823411186440678, 0.7220449237288135], 
             UndirectedEdge[84, 270] -> 
             RGBColor[
              0.9761129745762711, 0.9780587457627119, 0.6996322796610168], 
             UndirectedEdge[318, 322] -> 
             RGBColor[
              0.9058929745762712, 0.6517594406779662, 0.5624553474576272], 
             UndirectedEdge[218, 276] -> 
             RGBColor[
              0.9920865762711863, 0.9909956101694916, 0.7808094406779661], 
             UndirectedEdge[201, 303] -> 
             RGBColor[
              0.9946472288135593, 0.9917700677966101, 0.7176971610169492], 
             UndirectedEdge[283, 364] -> 
             RGBColor[
              0.9002568898305086, 0.8925368305084744, 0.6659129491525423], 
             UndirectedEdge[65, 340] -> 
             RGBColor[
              0.9909452966101695, 0.9807942033898305, 0.5747784152542372], 
             UndirectedEdge[83, 214] -> 
             RGBColor[
              0.9875753898305084, 0.9891301186440679, 0.8555714745762713], 
             UndirectedEdge[124, 157] -> 
             RGBColor[
              0.8475700508474576, 0.33611149152542374`, 0.19199063559322033`],
              UndirectedEdge[311, 344] -> 
             RGBColor[
              0.9735549661016949, 0.979235813559322, 0.904476559322034], 
             UndirectedEdge[190, 226] -> 
             RGBColor[
              0.9909587796610169, 0.9905292372881356, 0.7994999491525425], 
             UndirectedEdge[380, 389] -> 
             RGBColor[
              0.9595345423728813, 0.9693415084745762, 0.9533816440677967], 
             UndirectedEdge[124, 179] -> 
             RGBColor[
              0.8785637881355932, 0.5443784576271187, 0.575495279661017], 
             UndirectedEdge[199, 215] -> 
             RGBColor[
              0.905139720338983, 0.6801973050847457, 0.5748041610169492], 
             UndirectedEdge[146, 267] -> 
             RGBColor[
              0.9937993983050848, 0.9899566440677967, 0.6254160423728812], 
             UndirectedEdge[109, 249] -> 
             RGBColor[
              0.9726846949152542, 0.9195212033898306, 0.34838562711864407`], 
             UndirectedEdge[36, 61] -> 
             RGBColor[
              0.9755387966101694, 0.9286836440677966, 0.399023254237288], 
             UndirectedEdge[13, 232] -> 
             RGBColor[
              0.9426206355932203, 0.824502593220339, 0.5815994237288136], 
             UndirectedEdge[38, 119] -> 
             RGBColor[0.8975365, 0.5875279152542372, 0.5544531779661017], 
             UndirectedEdge[91, 256] -> 
             RGBColor[
              0.9033583220338983, 0.5910556271186438, 0.26430398305084735`], 
             UndirectedEdge[6, 69] -> 
             RGBColor[
              0.9230660593220339, 0.792359559322034, 0.6026967966101695], 
             UndirectedEdge[90, 97] -> 
             RGBColor[
              0.9773586610169491, 0.9824473389830508, 0.9148193389830509], 
             UndirectedEdge[233, 257] -> 
             RGBColor[
              0.9835358813559322, 0.9549620169491524, 0.4894153898305083], 
             UndirectedEdge[66, 119] -> 
             RGBColor[
              0.9784864576271186, 0.9829137118644068, 0.8961288305084747], 
             UndirectedEdge[33, 116] -> 
             RGBColor[
              0.9496186949152543, 0.8264685084745763, 0.3753058898305084], 
             UndirectedEdge[335, 349] -> 
             RGBColor[
              0.9726846949152543, 0.9195212033898306, 0.34838562711864407`], 
             UndirectedEdge[165, 274] -> 
             RGBColor[
              0.9935392372881355, 0.988589406779661, 0.5381640338983049], 
             UndirectedEdge[95, 169] -> 
             RGBColor[
              0.9230660593220339, 0.792359559322034, 0.6026967966101695], 
             UndirectedEdge[135, 259] -> 
             RGBColor[
              0.9935392372881355, 0.988589406779661, 0.5381640338983049], 
             UndirectedEdge[93, 273] -> 
             RGBColor[
              0.9340781101694915, 0.9455350677966101, 0.7476667796610168], 
             UndirectedEdge[89, 263] -> 
             RGBColor[
              0.9420179745762711, 0.8059317627118645, 0.5454439830508475], 
             UndirectedEdge[71, 289] -> 
             RGBColor[
              0.9906986186440678, 0.9891620000000001, 0.7122479406779663], 
             UndirectedEdge[32, 215] -> 
             RGBColor[
              0.9079988644067797, 0.6427524406779661, 0.2578704576271187], 
             UndirectedEdge[8, 239] -> 
             RGBColor[
              0.9606840423728813, 0.8701587288135594, 0.5017849830508475], 
             UndirectedEdge[110, 111] -> 
             RGBColor[
              0.9871063983050847, 0.9878324406779662, 0.8059783135593221], 
             UndirectedEdge[29, 162] -> 
             RGBColor[
              0.9457064237288135, 0.8071725932203391, 0.46364119491525435`], 
             UndirectedEdge[337, 353] -> 
             RGBColor[
              0.9531432118644068, 0.8662211016949153, 0.5900661355932204], 
             UndirectedEdge[306, 308] -> 
             RGBColor[
              0.9614341440677966, 0.8891524915254237, 0.5807803728813559], 
             UndirectedEdge[185, 190] -> 
             RGBColor[
              0.9801300423728814, 0.954325661016949, 0.6019785508474575], 
             UndirectedEdge[71, 385] -> 
             RGBColor[
              0.9838459745762711, 0.966860372881356, 0.6164142457627119], 
             UndirectedEdge[146, 158] -> 
             RGBColor[
              0.9835134322033898, 0.9557247796610169, 0.5459070254237287], 
             UndirectedEdge[157, 386] -> 
             RGBColor[
              0.9355388644067797, 0.7630404576271187, 0.3635834661016948], 
             UndirectedEdge[24, 124] -> 
             RGBColor[
              0.856889779661017, 0.3784302033898306, 0.19976724576271188`], 
             UndirectedEdge[22, 74] -> 
             RGBColor[
              0.9861015677966102, 0.9677931186440678, 0.5790332288135592], 
             UndirectedEdge[303, 385] -> 
             RGBColor[
              0.9872293644067797, 0.9682594915254237, 0.560342720338983], 
             UndirectedEdge[130, 317] -> 
             RGBColor[
              0.9792605084745762, 0.9840531016949153, 0.9199907288135593], 
             UndirectedEdge[73, 291] -> 
             RGBColor[
              0.9790022457627119, 0.9538592881355932, 0.6206690593220339], 
             UndirectedEdge[241, 255] -> 
             RGBColor[
              0.9457064237288135, 0.8071725932203391, 0.46364119491525435`], 
             UndirectedEdge[385, 400] -> 
             RGBColor[
              0.9801165593220339, 0.944590627118644, 0.3772570169491524], 
             UndirectedEdge[130, 311] -> 
             RGBColor[
              0.9834179491525423, 0.9865916101694916, 0.8877811016949153], 
             UndirectedEdge[143, 308] -> 
             RGBColor[
              0.9875753898305084, 0.9891301186440679, 0.8555714745762713], 
             UndirectedEdge[297, 397] -> 
             RGBColor[
              0.8466067966101695, 0.35802430508474553`, 0.1922161949152542], 
             UndirectedEdge[237, 324] -> 
             RGBColor[
              0.9835134322033898, 0.9557247796610169, 0.5459070254237287], 
             UndirectedEdge[107, 160] -> 
             RGBColor[
              0.9943646186440678, 0.9911655932203389, 0.6869367881355932], 
             UndirectedEdge[125, 185] -> 
             RGBColor[
              0.9823856355932203, 0.955258406779661, 0.5645975338983049], 
             UndirectedEdge[269, 388] -> 
             RGBColor[
              0.8780010254237287, 0.6016039999999998, 0.5863209322033898], 
             UndirectedEdge[47, 300] -> 
             RGBColor[
              0.9537462627118644, 0.915684033898305, 0.6303599745762711], 
             UndirectedEdge[37, 365] -> 
             RGBColor[
              0.9872293644067797, 0.9682594915254237, 0.560342720338983], 
             UndirectedEdge[356, 389] -> 
             RGBColor[
              0.9711814830508474, 0.9743808474576271, 0.7079800084745762], 
             UndirectedEdge[227, 243] -> 
             RGBColor[
              0.9813270762711863, 0.9823411186440678, 0.7220449237288135], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.9708790677966102, 0.9764906610169491, 0.8754432711864406], 
             UndirectedEdge[186, 348] -> 
             RGBColor[
              0.9801165593220339, 0.9445906271186439, 0.3772570169491524], 
             UndirectedEdge[61, 90] -> 
             RGBColor[
              0.9636092457627118, 0.9230398305084746, 0.6136645169491526], 
             UndirectedEdge[72, 325] -> 
             RGBColor[
              0.9816096864406779, 0.982945593220339, 0.7528052966101695], 
             UndirectedEdge[341, 358] -> 
             RGBColor[
              0.9122172372881356, 0.6739551694915253, 0.2618621440677966], 
             UndirectedEdge[102, 337] -> 
             RGBColor[
              0.9604238813559323, 0.8687914915254238, 0.41453297457627125`], 
             UndirectedEdge[297, 378] -> 
             RGBColor[
              0.9159331694915254, 0.6864898813559321, 0.2762978389830507], 
             UndirectedEdge[300, 370] -> 
             RGBColor[
              0.9574621949152542, 0.9282187457627118, 0.6447956694915254], 
             UndirectedEdge[46, 52] -> 
             RGBColor[
              0.938018940677966, 0.8380060508474576, 0.6025282372881355], 
             UndirectedEdge[75, 200] -> 
             RGBColor[
              0.9561728559322034, 0.8682932372881357, 0.5765470169491526], 
             UndirectedEdge[204, 343] -> 
             RGBColor[
              0.9901360423728813, 0.9899045762711864, 0.7924591949152544], 
             UndirectedEdge[32, 199] -> 
             RGBColor[
              0.9623936864406779, 0.9318966440677966, 0.6364479406779662], 
             UndirectedEdge[301, 313] -> 
             RGBColor[
              0.9578209661016949, 0.8693823559322034, 0.2906428474576271], 
             UndirectedEdge[166, 363] -> 
             RGBColor[
              0.8838188305084747, 0.910091186440678, 0.9851064152542373], 
             UndirectedEdge[333, 353] -> 
             RGBColor[
              0.9685407372881356, 0.9267177288135593, 0.6053167881355932], 
             UndirectedEdge[130, 146] -> 
             RGBColor[
              0.9868013389830508, 0.9879907288135594, 0.8317095762711864], 
             UndirectedEdge[71, 271] -> 
             RGBColor[
              0.9625619406779661, 0.8896188644067797, 0.5620898644067798], 
             UndirectedEdge[123, 332] -> 
             RGBColor[
              0.9752561864406779, 0.9280791694915254, 0.3682628813559321], 
             UndirectedEdge[340, 361] -> 
             RGBColor[
              0.9909677457627118, 0.9800314406779661, 0.5182867796610169], 
             UndirectedEdge[165, 322] -> 
             RGBColor[
              0.9818922966101694, 0.9835500677966101, 0.7835656694915254], 
             UndirectedEdge[278, 302] -> 
             RGBColor[
              0.9271407627118644, 0.7460578813559322, 0.2629796694915254], 
             UndirectedEdge[322, 355] -> 
             RGBColor[
              0.9747570423728813, 0.9606439661016949, 0.6569716016949152], 
             UndirectedEdge[68, 333] -> 
             RGBColor[
              0.9763866271186441, 0.9304970677966102, 0.491304372881356], 
             UndirectedEdge[150, 156] -> 
             RGBColor[
              0.9420179745762711, 0.8059317627118645, 0.5454439830508475], 
             UndirectedEdge[29, 357] -> 
             RGBColor[
              0.9092153305084746, 0.7816756779661018, 0.6138680084745762], 
             UndirectedEdge[250, 325] -> 
             RGBColor[
              0.9813270762711863, 0.9823411186440678, 0.7220449237288135], 
             UndirectedEdge[53, 131] -> 
             RGBColor[
              0.9818698474576271, 0.9843128305084745, 0.8400573050847457], 
             UndirectedEdge[92, 267] -> 
             RGBColor[
              0.9401987288135594, 0.784199813559322, 0.3674717711864406], 
             UndirectedEdge[269, 309] -> 
             RGBColor[
              0.9576133644067797, 0.9643014406779662, 0.7499115932203388], 
             UndirectedEdge[162, 336] -> 
             RGBColor[
              0.982174906779661, 0.9841545423728814, 0.8143260423728815], 
             UndirectedEdge[94, 204] -> 
             RGBColor[
              0.9838184915254238, 0.9555664915254236, 0.5201757627118644], 
             UndirectedEdge[29, 183] -> 
             RGBColor[
              0.9382885593220339, 0.7836620169491526, 0.30628675423728813`], 
             UndirectedEdge[145, 208] -> 
             RGBColor[
              0.9186703559322034, 0.6592166779661018, 0.4400952033898306], 
             UndirectedEdge[75, 133] -> 
             RGBColor[
              0.9887031864406779, 0.9895964915254238, 0.8368809661016949], 
             UndirectedEdge[169, 326] -> 
             RGBColor[
              0.9648940593220339, 0.9532881694915254, 0.6736670593220339], 
             UndirectedEdge[95, 97] -> 
             RGBColor[
              0.9408901779661016, 0.8054653898305086, 0.5641344915254238], 
             UndirectedEdge[37, 78] -> 
             RGBColor[
              0.9937993983050848, 0.9899566440677967, 0.6254160423728812], 
             UndirectedEdge[55, 397] -> 
             RGBColor[
              0.8918517542372881, 0.612287881355932, 0.575149720338983], 
             UndirectedEdge[185, 226] -> 
             RGBColor[
              0.9835134322033898, 0.9557247796610169, 0.5459070254237287], 
             UndirectedEdge[39, 254] -> 
             RGBColor[
              0.9735549661016949, 0.979235813559322, 0.904476559322034], 
             UndirectedEdge[71, 201] -> 
             RGBColor[
              0.9912638389830508, 0.9903709491525424, 0.7737686864406781], 
             UndirectedEdge[227, 383] -> 
             RGBColor[
              0.9926716016949153, 0.9894902711864407, 0.6441065508474575], 
             UndirectedEdge[38, 151] -> 
             RGBColor[
              0.9066254322033898, 0.5937443220338983, 0.5138958220338984], 
             UndirectedEdge[45, 74] -> 
             RGBColor[
              0.9909587796610169, 0.9905292372881356, 0.7994999491525423], 
             UndirectedEdge[292, 303] -> 
             RGBColor[
              0.9909587796610169, 0.9905292372881356, 0.7994999491525425], 
             UndirectedEdge[185, 357] -> 
             RGBColor[
              0.9473273983050847, 0.9300695762711864, 0.6704025762711863], 
             UndirectedEdge[86, 376] -> 
             RGBColor[
              0.9678232288135593, 0.9104781186440678, 0.5663232203389832], 
             UndirectedEdge[212, 309] -> 
             RGBColor[
              0.9576133644067797, 0.9643014406779662, 0.7499115932203388], 
             UndirectedEdge[50, 127] -> 
             RGBColor[
              0.9761040169491525, 0.929892593220339, 0.46054399999999995`], 
             UndirectedEdge[92, 374] -> 
             RGBColor[
              0.9018220847457628, 0.6435426440677965, 0.2396073559322034], 
             UndirectedEdge[118, 141] -> 
             RGBColor[
              0.9673251779661016, 0.9355745423728814, 0.6281002118644068], 
             UndirectedEdge[205, 390] -> 
             RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.9949522881355932, 0.991611779661017, 0.6919658983050849], 316 -> 
             RGBColor[
              0.993256627118644, 0.9879849322033899, 0.5074036610169489], 308 -> 
             RGBColor[
              0.9853197966101694, 0.988197372881356, 0.8929524915254238], 160 -> 
             RGBColor[
              0.9943421694915254, 0.9919283559322034, 0.7434284237288136], 
             245 -> RGBColor[
              0.9920865762711865, 0.9909956101694916, 0.780809440677966], 155 -> 
             RGBColor[
              0.9853197966101694, 0.988197372881356, 0.8929524915254238], 213 -> 
             RGBColor[
              0.9398085762711864, 0.9546299152542372, 0.9867725593220339], 
             352 -> RGBColor[
              0.9938218474576271, 0.9891938813559322, 0.568924406779661], 27 -> 
             RGBColor[
              0.9270259152542373, 0.7483891016949153, 0.2601415423728814], 
             367 -> RGBColor[0.817319, 0.134127, 0.164218], 19 -> 
             RGBColor[
              0.9875484237288136, 0.9696600508474577, 0.406128406779661], 164 -> 
             RGBColor[
              0.896460559322034, 0.6227334067796612, 0.23531649152542378`], 
             190 -> RGBColor[
              0.9875753898305084, 0.9891301186440679, 0.8555714745762714], 
             103 -> RGBColor[
              0.9920865762711865, 0.9909956101694916, 0.780809440677966], 138 -> 
             RGBColor[
              0.9219701016949152, 0.9406179491525424, 0.9924195254237288], 
             291 -> RGBColor[
              0.9853197966101694, 0.988197372881356, 0.8929524915254238], 28 -> 
             RGBColor[
              0.868501372881356, 0.49577727118644077`, 0.21198666101694918`], 
             337 -> RGBColor[
              0.9270259152542373, 0.7483891016949153, 0.2601415423728814], 
             195 -> RGBColor[
              0.9059807627118645, 0.6649520847457627, 0.24320811864406783`], 
             114 -> RGBColor[
              0.9949522881355932, 0.991611779661017, 0.6919658983050849], 93 -> 
             RGBColor[
              0.874899593220339, 0.9030852033898304, 0.9879298983050847], 34 -> 
             RGBColor[
              0.9853197966101694, 0.988197372881356, 0.8929524915254238], 161 -> 
             RGBColor[
              0.9480710677966101, 0.8318261186440676, 0.27707496610169485`], 
             22 -> RGBColor[
              0.9801165593220339, 0.944590627118644, 0.3772570169491524], 124 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 84 -> 
             RGBColor[
              0.9926914067796611, 0.9867759830508475, 0.4458829152542371], 46 -> 
             RGBColor[
              0.9165033389830508, 0.7066705932203389, 0.25167483050847456`], 
             241 -> RGBColor[
              0.9949522881355932, 0.991611779661017, 0.6919658983050849], 185 -> 
             RGBColor[
              0.9726846949152542, 0.9195212033898303, 0.34838562711864385`], 
             390 -> RGBColor[
              0.9920865762711865, 0.9909956101694916, 0.780809440677966], 121 -> 
             RGBColor[
              0.9949522881355932, 0.991611779661017, 0.6919658983050849], 322 -> 
             RGBColor[
              0.9693975254237287, 0.9766973050847457, 0.936686186440678], 126 -> 
             RGBColor[
              0.9595345423728813, 0.9693415084745762, 0.9533816440677966], 
             236 -> RGBColor[
              0.9920865762711865, 0.9909956101694916, 0.780809440677966], 78 -> 
             RGBColor[
              0.993256627118644, 0.9879849322033899, 0.5074036610169489], 376 -> 
             RGBColor[
              0.9875753898305084, 0.9891301186440679, 0.8555714745762714], 
             254 -> RGBColor[
              0.9595345423728813, 0.9693415084745762, 0.9533816440677966], 
             290 -> RGBColor[
              0.9801165593220339, 0.944590627118644, 0.3772570169491524], 251 -> 
             RGBColor[
              0.874899593220339, 0.9030852033898304, 0.9879298983050847], 165 -> 
             RGBColor[
              0.9943870677966101, 0.9904028305084746, 0.6304451525423728], 
             100 -> RGBColor[
              0.9801165593220339, 0.944590627118644, 0.3772570169491524], 235 -> 
             RGBColor[
              0.9920865762711865, 0.9909956101694916, 0.780809440677966], 70 -> 
             RGBColor[
              0.9949522881355932, 0.991611779661017, 0.6919658983050849], 234 -> 
             RGBColor[
              0.9920865762711865, 0.9909956101694916, 0.780809440677966], 257 -> 
             RGBColor[
              0.9726846949152542, 0.9195212033898303, 0.34838562711864385`], 
             135 -> RGBColor[
              0.9926914067796611, 0.9867759830508475, 0.4458829152542371], 
             265 -> RGBColor[
              0.9943421694915254, 0.9919283559322034, 0.7434284237288136], 
             111 -> RGBColor[
              0.9949522881355932, 0.991611779661017, 0.6919658983050849], 381 -> 
             RGBColor[
              0.9943421694915254, 0.9919283559322034, 0.7434284237288136], 
             182 -> RGBColor[
              0.993256627118644, 0.9879849322033899, 0.5074036610169489], 188 -> 
             RGBColor[
              0.9875484237288136, 0.9696600508474577, 0.406128406779661], 
             154 -> 
             RGBColor[
              0.8984348474576271, 0.9218515762711864, 0.9901747118644068], 
             336 -> RGBColor[
              0.9693975254237287, 0.9766973050847457, 0.936686186440678], 315 -> 
             RGBColor[
              0.9949522881355932, 0.991611779661017, 0.6919658983050849], 368 -> 
             RGBColor[
              0.9943421694915254, 0.9919283559322034, 0.7434284237288136], 
             269 -> RGBColor[
              0.9219701016949152, 0.9406179491525424, 0.9924195254237288], 
             208 -> RGBColor[
              0.8423884237288136, 0.3268215762711867, 0.1882245084745763], 86 -> 
             RGBColor[
              0.9480710677966101, 0.8318261186440676, 0.27707496610169485`], 
             119 -> RGBColor[
              0.9693975254237287, 0.9766973050847457, 0.936686186440678], 377 -> 
             RGBColor[
              0.9165033389830508, 0.7066705932203389, 0.25167483050847456`], 
             140 -> RGBColor[
              0.9652528305084747, 0.894451779661017, 0.31951423728813566`], 
             85 -> RGBColor[
              0.9578209661016949, 0.8693823559322034, 0.2906428474576271], 
             351 -> RGBColor[
              0.9726846949152542, 0.9195212033898303, 0.34838562711864385`], 
             242 -> RGBColor[
              0.9949522881355932, 0.991611779661017, 0.6919658983050849], 117 -> 
             RGBColor[
              0.9943870677966101, 0.9904028305084746, 0.6304451525423728], 47 -> 
             RGBColor[
              0.9578209661016949, 0.8693823559322034, 0.2906428474576271], 81 -> 
             RGBColor[
              0.9943870677966101, 0.9904028305084746, 0.6304451525423728], 
             275 -> RGBColor[
              0.9920865762711865, 0.9909956101694916, 0.780809440677966], 23 -> 
             RGBColor[
              0.9270259152542373, 0.7483891016949153, 0.2601415423728814], 
             328 -> RGBColor[
              0.9938218474576271, 0.9891938813559322, 0.568924406779661], 110 -> 
             RGBColor[
              0.9792605084745762, 0.9840531016949153, 0.9199907288135593], 6 -> 
             RGBColor[
              0.9496715593220338, 0.9619857118644067, 0.9700771016949152], 
             218 -> RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             108 -> RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             297 -> RGBColor[
              0.8591816440677966, 0.4534585593220338, 0.2042100508474576], 
             157 -> RGBColor[
              0.8778211016949152, 0.5380959830508475, 0.21976327118644068`], 
             354 -> RGBColor[
              0.9652528305084747, 0.894451779661017, 0.31951423728813566`], 
             385 -> RGBColor[
              0.9801165593220339, 0.944590627118644, 0.3772570169491524], 270 -> 
             RGBColor[
              0.9595345423728813, 0.9693415084745762, 0.9533816440677966], 
             392 -> RGBColor[
              0.9875753898305084, 0.9891301186440679, 0.8555714745762714], 33 -> 
             RGBColor[
              0.993256627118644, 0.9879849322033899, 0.5074036610169489], 252 -> 
             RGBColor[
              0.9480710677966101, 0.8318261186440676, 0.27707496610169485`], 
             394 -> RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             260 -> RGBColor[
              0.9726846949152542, 0.9195212033898303, 0.34838562711864385`], 
             159 -> RGBColor[
              0.9398085762711864, 0.9546299152542372, 0.9867725593220339], 
             183 -> RGBColor[
              0.9801165593220339, 0.944590627118644, 0.3772570169491524], 99 -> 
             RGBColor[
              0.868501372881356, 0.49577727118644077`, 0.21198666101694918`], 
             329 -> RGBColor[
              0.9792605084745762, 0.9840531016949153, 0.9199907288135593], 
             309 -> RGBColor[
              0.993256627118644, 0.9879849322033899, 0.5074036610169489], 17 -> 
             RGBColor[
              0.9219701016949152, 0.9406179491525424, 0.9924195254237288], 
             349 -> RGBColor[
              0.9652528305084747, 0.894451779661017, 0.31951423728813566`], 
             347 -> RGBColor[
              0.7958992542372882, 0.840481813559322, 0.9802914576271187], 340 -> 
             RGBColor[
              0.9875484237288136, 0.9696600508474577, 0.406128406779661], 277 -> 
             RGBColor[
              0.896460559322034, 0.6227334067796612, 0.23531649152542378`], 
             104 -> RGBColor[
              0.9943421694915254, 0.9919283559322034, 0.7434284237288136], 79 -> 
             RGBColor[
              0.9652528305084747, 0.894451779661017, 0.31951423728813566`], 
             327 -> RGBColor[
              0.9926914067796611, 0.9867759830508475, 0.4458829152542371], 
             191 -> RGBColor[
              0.993256627118644, 0.9879849322033899, 0.5074036610169489], 50 -> 
             RGBColor[
              0.9943870677966101, 0.9904028305084746, 0.6304451525423728], 
             225 -> RGBColor[
              0.9949522881355932, 0.991611779661017, 0.6919658983050849], 61 -> 
             RGBColor[
              0.9578209661016949, 0.8693823559322034, 0.2906428474576271], 
             196 -> RGBColor[
              0.9398085762711864, 0.9546299152542372, 0.9867725593220339], 1 -> 
             RGBColor[
              0.8507448983050847, 0.3910531016949153, 0.1962266779661017], 
             263 -> RGBColor[
              0.9875753898305084, 0.9891301186440679, 0.8555714745762714], 
             201 -> RGBColor[
              0.9949522881355932, 0.991611779661017, 0.6919658983050849], 371 -> 
             RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             293 -> RGBColor[
              0.9219701016949152, 0.9406179491525424, 0.9924195254237288], 
             362 -> RGBColor[
              0.9943870677966101, 0.9904028305084746, 0.6304451525423728], 
             184 -> RGBColor[
              0.9938218474576271, 0.9891938813559322, 0.568924406779661], 106 -> 
             RGBColor[
              0.8278290847457628, 0.8655524576271186, 0.9834402711864407], 
             206 -> RGBColor[
              0.9726846949152542, 0.9195212033898303, 0.34838562711864385`], 
             358 -> RGBColor[
              0.9652528305084747, 0.894451779661017, 0.31951423728813566`], 
             247 -> RGBColor[
              0.9219701016949152, 0.9406179491525424, 0.9924195254237288], 
             220 -> RGBColor[
              0.9875753898305084, 0.9891301186440679, 0.8555714745762714], 
             107 -> RGBColor[
              0.9943870677966101, 0.9904028305084746, 0.6304451525423728], 
             375 -> RGBColor[
              0.9875484237288136, 0.9696600508474577, 0.406128406779661], 131 -> 
             RGBColor[
              0.9943421694915254, 0.9919283559322034, 0.7434284237288136], 
             127 -> RGBColor[
              0.9578209661016949, 0.8693823559322034, 0.2906428474576271], 
             210 -> RGBColor[
              0.9801165593220339, 0.944590627118644, 0.3772570169491524], 357 -> 
             RGBColor[
              0.9219701016949152, 0.9406179491525424, 0.9924195254237288], 
             181 -> RGBColor[
              0.9875484237288136, 0.9696600508474577, 0.406128406779661], 194 -> 
             RGBColor[
              0.9938218474576271, 0.9891938813559322, 0.568924406779661], 118 -> 
             RGBColor[
              0.9693975254237287, 0.9766973050847457, 0.936686186440678], 348 -> 
             RGBColor[
              0.9726846949152542, 0.9195212033898303, 0.34838562711864385`], 
             276 -> 
             RGBColor[
              0.9943421694915254, 0.9919283559322034, 0.7434284237288136], 
             305 -> RGBColor[
              0.9792605084745762, 0.9840531016949153, 0.9199907288135593], 
             343 -> RGBColor[
              0.9853197966101694, 0.988197372881356, 0.8929524915254238], 280 -> 
             RGBColor[
              0.9949522881355932, 0.991611779661017, 0.6919658983050849], 189 -> 
             RGBColor[
              0.9652528305084747, 0.894451779661017, 0.31951423728813566`], 
             168 -> RGBColor[
              0.9949522881355932, 0.991611779661017, 0.6919658983050849], 363 -> 
             RGBColor[
              0.9398085762711864, 0.9546299152542372, 0.9867725593220339], 41 -> 
             RGBColor[
              0.9652528305084747, 0.894451779661017, 0.31951423728813566`], 
             14 -> RGBColor[
              0.9949522881355932, 0.991611779661017, 0.6919658983050849], 77 -> 
             RGBColor[
              0.9652528305084747, 0.894451779661017, 0.31951423728813566`], 
             51 -> RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             179 -> RGBColor[
              0.9398085762711864, 0.9546299152542372, 0.9867725593220339], 
             223 -> RGBColor[
              0.9853197966101694, 0.988197372881356, 0.8929524915254238], 323 -> 
             RGBColor[
              0.9652528305084747, 0.894451779661017, 0.31951423728813566`], 
             292 -> RGBColor[
              0.9875753898305084, 0.9891301186440679, 0.8555714745762714], 
             396 -> RGBColor[
              0.9943870677966101, 0.9904028305084746, 0.6304451525423728], 
             321 -> RGBColor[
              0.993256627118644, 0.9879849322033899, 0.5074036610169489], 143 -> 
             RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             112 -> RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             197 -> RGBColor[
              0.9165033389830508, 0.7066705932203389, 0.25167483050847456`], 
             54 -> RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 71 -> 
             RGBColor[
              0.9875753898305084, 0.9891301186440679, 0.8555714745762714], 
             177 -> RGBColor[
              0.9496715593220338, 0.9619857118644067, 0.9700771016949152], 
             158 -> RGBColor[
              0.9726846949152542, 0.9195212033898303, 0.34838562711864385`], 
             226 -> RGBColor[
              0.9943421694915254, 0.9919283559322034, 0.7434284237288136], 
             350 -> RGBColor[
              0.9595345423728813, 0.9693415084745762, 0.9533816440677966], 
             203 -> RGBColor[
              0.9926914067796611, 0.9867759830508475, 0.4458829152542371], 
             115 -> RGBColor[
              0.9875753898305084, 0.9891301186440679, 0.8555714745762714], 
             173 -> RGBColor[
              0.874899593220339, 0.9030852033898304, 0.9879298983050847], 212 -> 
             RGBColor[
              0.9219701016949152, 0.9406179491525424, 0.9924195254237288], 
             129 -> RGBColor[
              0.9943870677966101, 0.9904028305084746, 0.6304451525423728], 
             279 -> RGBColor[
              0.896460559322034, 0.6227334067796612, 0.23531649152542378`], 
             26 -> RGBColor[
              0.9875484237288136, 0.9696600508474577, 0.406128406779661], 40 -> 
             RGBColor[
              0.9801165593220339, 0.944590627118644, 0.3772570169491524], 146 -> 
             RGBColor[
              0.9943421694915254, 0.9919283559322034, 0.7434284237288136], 
             386 -> RGBColor[
              0.993256627118644, 0.9879849322033899, 0.5074036610169489], 192 -> 
             RGBColor[
              0.9938218474576271, 0.9891938813559322, 0.568924406779661], 300 -> 
             RGBColor[
              0.9496715593220338, 0.9619857118644067, 0.9700771016949152], 
             221 -> RGBColor[
              0.9875484237288136, 0.9696600508474577, 0.406128406779661], 62 -> 
             RGBColor[
              0.9938218474576271, 0.9891938813559322, 0.568924406779661], 286 -> 
             RGBColor[
              0.9270259152542373, 0.7483891016949153, 0.2601415423728814], 
             152 -> RGBColor[
              0.9398085762711864, 0.9546299152542372, 0.9867725593220339], 64 -> 
             RGBColor[
              0.9943421694915254, 0.9919283559322034, 0.7434284237288136], 
             307 -> RGBColor[
              0.9926914067796611, 0.9867759830508475, 0.4458829152542371], 37 -> 
             RGBColor[
              0.9943421694915254, 0.9919283559322034, 0.7434284237288136], 
             148 -> RGBColor[
              0.9652528305084747, 0.894451779661017, 0.31951423728813566`], 
             261 -> RGBColor[
              0.9875484237288136, 0.9696600508474577, 0.406128406779661], 387 -> 
             RGBColor[
              0.9270259152542373, 0.7483891016949153, 0.2601415423728814], 15 -> 
             RGBColor[
              0.9938218474576271, 0.9891938813559322, 0.568924406779661], 136 -> 
             RGBColor[
              0.9693975254237287, 0.9766973050847457, 0.936686186440678], 198 -> 
             RGBColor[
              0.8591816440677966, 0.4534585593220338, 0.2042100508474576], 63 -> 
             RGBColor[
              0.9920865762711865, 0.9909956101694916, 0.780809440677966], 310 -> 
             RGBColor[
              0.868501372881356, 0.49577727118644077`, 0.21198666101694918`], 
             171 -> RGBColor[
              0.9165033389830508, 0.7066705932203389, 0.25167483050847456`], 
             395 -> RGBColor[
              0.8778211016949152, 0.5380959830508475, 0.21976327118644068`], 
             311 -> RGBColor[
              0.9875753898305084, 0.9891301186440679, 0.8555714745762714], 
             353 -> RGBColor[
              0.9792605084745762, 0.9840531016949153, 0.9199907288135593], 59 -> 
             RGBColor[
              0.9926914067796611, 0.9867759830508475, 0.4458829152542371], 
             397 -> RGBColor[
              0.8340319491525423, 0.26259005084745723`, 0.1802223389830508], 
             229 -> RGBColor[
              0.874899593220339, 0.9030852033898304, 0.9879298983050847], 102 -> 
             RGBColor[
              0.9938218474576271, 0.9891938813559322, 0.568924406779661], 299 -> 
             RGBColor[
              0.9375484915254237, 0.7901076101694915, 0.2686082542372881], 
             128 -> RGBColor[
              0.9652528305084747, 0.894451779661017, 0.31951423728813566`], 
             12 -> RGBColor[
              0.9853197966101694, 0.988197372881356, 0.8929524915254238], 222 -> 
             RGBColor[
              0.9926914067796611, 0.9867759830508475, 0.4458829152542371], 92 -> 
             RGBColor[
              0.8871408305084746, 0.5804146949152542, 0.2275398813559322], 
             271 -> RGBColor[
              0.9375484915254237, 0.7901076101694915, 0.2686082542372881], 
             361 -> RGBColor[
              0.9943870677966101, 0.9904028305084746, 0.6304451525423728], 
             344 -> RGBColor[
              0.9595345423728813, 0.9693415084745762, 0.9533816440677966], 
             132 -> RGBColor[
              0.9926914067796611, 0.9867759830508475, 0.4458829152542371], 80 -> 
             RGBColor[
              0.9792605084745762, 0.9840531016949153, 0.9199907288135593], 
             324 -> RGBColor[
              0.9943421694915254, 0.9919283559322034, 0.7434284237288136], 
             244 -> RGBColor[
              0.9853197966101694, 0.988197372881356, 0.8929524915254238], 150 -> 
             RGBColor[
              0.896460559322034, 0.6227334067796612, 0.23531649152542378`], 
             125 -> RGBColor[
              0.9920865762711865, 0.9909956101694916, 0.780809440677966], 258 -> 
             RGBColor[
              0.9943870677966101, 0.9904028305084746, 0.6304451525423728], 
             133 -> RGBColor[
              0.9920865762711865, 0.9909956101694916, 0.780809440677966], 255 -> 
             RGBColor[
              0.896460559322034, 0.6227334067796612, 0.23531649152542378`], 
             326 -> RGBColor[
              0.9801165593220339, 0.944590627118644, 0.3772570169491524], 176 -> 
             RGBColor[
              0.9875484237288136, 0.9696600508474577, 0.406128406779661], 230 -> 
             RGBColor[
              0.9920865762711865, 0.9909956101694916, 0.780809440677966], 274 -> 
             RGBColor[
              0.9926914067796611, 0.9867759830508475, 0.4458829152542371], 87 -> 
             RGBColor[
              0.8871408305084746, 0.5804146949152542, 0.2275398813559322], 
             130 -> RGBColor[
              0.9792605084745762, 0.9840531016949153, 0.9199907288135593], 35 -> 
             RGBColor[
              0.9943870677966101, 0.9904028305084746, 0.6304451525423728], 
             379 -> RGBColor[
              0.8871408305084746, 0.5804146949152542, 0.2275398813559322], 31 -> 
             RGBColor[
              0.9943421694915254, 0.9919283559322034, 0.7434284237288136], 18 -> 
             RGBColor[
              0.9059807627118645, 0.6649520847457627, 0.24320811864406783`], 
             24 -> RGBColor[
              0.896460559322034, 0.6227334067796612, 0.23531649152542378`], 
             151 -> RGBColor[
              0.9875753898305084, 0.9891301186440679, 0.8555714745762714], 
             137 -> RGBColor[
              0.9875484237288136, 0.9696600508474577, 0.406128406779661], 330 -> 
             RGBColor[
              0.874899593220339, 0.9030852033898304, 0.9879298983050847], 296 -> 
             RGBColor[
              0.9726846949152542, 0.9195212033898303, 0.34838562711864385`], 
             266 -> RGBColor[
              0.9943421694915254, 0.9919283559322034, 0.7434284237288136], 
             302 -> RGBColor[
              0.9578209661016949, 0.8693823559322034, 0.2906428474576271], 
             283 -> RGBColor[
              0.9726846949152542, 0.9195212033898303, 0.34838562711864385`], 
             388 -> RGBColor[
              0.8340319491525423, 0.26259005084745723`, 0.1802223389830508], 
             284 -> RGBColor[
              0.9949522881355932, 0.991611779661017, 0.6919658983050849], 
             318 -> 
             RGBColor[
              0.8423884237288136, 0.3268215762711867, 0.1882245084745763], 
             238 -> RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 72 -> 
             RGBColor[
              0.9938218474576271, 0.9891938813559322, 0.568924406779661], 288 -> 
             RGBColor[
              0.8256754745762712, 0.19835852542372862`, 0.1722201694915254], 
             382 -> RGBColor[
              0.9949522881355932, 0.991611779661017, 0.6919658983050849], 389 -> 
             RGBColor[
              0.9496715593220338, 0.9619857118644067, 0.9700771016949152], 
             172 -> RGBColor[
              0.9496715593220338, 0.9619857118644067, 0.9700771016949152], 
             243 -> RGBColor[
              0.9693975254237287, 0.9766973050847457, 0.936686186440678], 88 -> 
             RGBColor[
              0.9801165593220339, 0.944590627118644, 0.3772570169491524], 273 -> 
             RGBColor[
              0.993256627118644, 0.9879849322033899, 0.5074036610169489], 202 -> 
             RGBColor[
              0.9920865762711865, 0.9909956101694916, 0.780809440677966], 393 -> 
             RGBColor[
              0.9726846949152542, 0.9195212033898303, 0.34838562711864385`], 
             98 -> RGBColor[
              0.8340319491525423, 0.26259005084745723`, 0.1802223389830508], 
             30 -> RGBColor[
              0.9875753898305084, 0.9891301186440679, 0.8555714745762714], 
             116 -> RGBColor[
              0.9059807627118645, 0.6649520847457627, 0.24320811864406783`], 
             373 -> RGBColor[
              0.9943421694915254, 0.9919283559322034, 0.7434284237288136], 
             240 -> RGBColor[
              0.993256627118644, 0.9879849322033899, 0.5074036610169489], 317 -> 
             RGBColor[
              0.9792605084745762, 0.9840531016949153, 0.9199907288135593], 
             391 -> RGBColor[
              0.9059807627118645, 0.6649520847457627, 0.24320811864406783`], 
             73 -> RGBColor[
              0.9726846949152542, 0.9195212033898303, 0.34838562711864385`], 
             303 -> RGBColor[
              0.9943421694915254, 0.9919283559322034, 0.7434284237288136], 29 -> 
             RGBColor[
              0.896460559322034, 0.6227334067796612, 0.23531649152542378`], 
             360 -> RGBColor[
              0.9943421694915254, 0.9919283559322034, 0.7434284237288136], 
             320 -> RGBColor[
              0.9875753898305084, 0.9891301186440679, 0.8555714745762714], 75 -> 
             RGBColor[
              0.9853197966101694, 0.988197372881356, 0.8929524915254238], 200 -> 
             RGBColor[
              0.9270259152542373, 0.7483891016949153, 0.2601415423728814], 
             301 -> RGBColor[
              0.9578209661016949, 0.8693823559322034, 0.2906428474576271], 
             156 -> RGBColor[
              0.9875753898305084, 0.9891301186440679, 0.8555714745762714], 25 -> 
             RGBColor[
              0.9920865762711865, 0.9909956101694916, 0.780809440677966], 38 -> 
             RGBColor[
              0.8256754745762712, 0.19835852542372862`, 0.1722201694915254], 
             365 -> RGBColor[
              0.9801165593220339, 0.944590627118644, 0.3772570169491524], 380 -> 
             RGBColor[
              0.9693975254237287, 0.9766973050847457, 0.936686186440678], 370 -> 
             RGBColor[
              0.9652528305084747, 0.894451779661017, 0.31951423728813566`], 3 -> 
             RGBColor[
              0.9943870677966101, 0.9904028305084746, 0.6304451525423728], 57 -> 
             RGBColor[
              0.9792605084745762, 0.9840531016949153, 0.9199907288135593], 
             227 -> RGBColor[
              0.993256627118644, 0.9879849322033899, 0.5074036610169489], 39 -> 
             RGBColor[
              0.9875753898305084, 0.9891301186440679, 0.8555714745762714], 
             109 -> RGBColor[
              0.9578209661016949, 0.8693823559322034, 0.2906428474576271], 
             256 -> RGBColor[
              0.8340319491525423, 0.26259005084745723`, 0.1802223389830508], 
             339 -> RGBColor[
              0.9920865762711865, 0.9909956101694916, 0.780809440677966], 287 -> 
             RGBColor[
              0.9938218474576271, 0.9891938813559322, 0.568924406779661], 239 -> 
             RGBColor[
              0.9943421694915254, 0.9919283559322034, 0.7434284237288136], 
             285 -> RGBColor[
              0.9938218474576271, 0.9891938813559322, 0.568924406779661], 345 -> 
             RGBColor[
              0.9595345423728813, 0.9693415084745762, 0.9533816440677966], 
             366 -> RGBColor[
              0.9165033389830508, 0.7066705932203389, 0.25167483050847456`], 
             216 -> RGBColor[
              0.9792605084745762, 0.9840531016949153, 0.9199907288135593], 21 -> 
             RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             355 -> RGBColor[
              0.9801165593220339, 0.944590627118644, 0.3772570169491524], 175 -> 
             RGBColor[
              0.993256627118644, 0.9879849322033899, 0.5074036610169489], 7 -> R\
GBColor[0.896460559322034, 0.6227334067796612, 0.23531649152542378`], 13 -> 
             RGBColor[
              0.9792605084745762, 0.9840531016949153, 0.9199907288135593], 
             294 -> RGBColor[
              0.9875753898305084, 0.9891301186440679, 0.8555714745762714], 
             193 -> RGBColor[
              0.9920865762711865, 0.9909956101694916, 0.780809440677966], 60 -> 
             RGBColor[
              0.9496715593220338, 0.9619857118644067, 0.9700771016949152], 65 -> 
             RGBColor[
              0.9943421694915254, 0.9919283559322034, 0.7434284237288136], 69 -> 
             RGBColor[
              0.896460559322034, 0.6227334067796612, 0.23531649152542378`], 
             217 -> RGBColor[
              0.9792605084745762, 0.9840531016949153, 0.9199907288135593], 
             214 -> RGBColor[
              0.9853197966101694, 0.988197372881356, 0.8929524915254238], 170 -> 
             RGBColor[
              0.993256627118644, 0.9879849322033899, 0.5074036610169489], 359 -> 
             RGBColor[
              0.9375484915254237, 0.7901076101694915, 0.2686082542372881], 74 -> 
             RGBColor[
              0.9920865762711865, 0.9909956101694916, 0.780809440677966], 246 -> 
             RGBColor[
              0.9375484915254237, 0.7901076101694915, 0.2686082542372881], 
             264 -> RGBColor[
              0.9595345423728813, 0.9693415084745762, 0.9533816440677966], 
             278 -> RGBColor[
              0.896460559322034, 0.6227334067796612, 0.23531649152542378`], 
             45 -> RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             306 -> RGBColor[
              0.9375484915254237, 0.7901076101694915, 0.2686082542372881], 
             237 -> RGBColor[
              0.9726846949152542, 0.9195212033898303, 0.34838562711864385`], 
             228 -> RGBColor[
              0.9875484237288136, 0.9696600508474577, 0.406128406779661], 180 -> 
             RGBColor[
              0.9726846949152542, 0.9195212033898303, 0.34838562711864385`], 
             383 -> RGBColor[
              0.9920865762711865, 0.9909956101694916, 0.780809440677966], 53 -> 
             RGBColor[
              0.9693975254237287, 0.9766973050847457, 0.936686186440678], 304 -> 
             RGBColor[
              0.8278290847457628, 0.8655524576271186, 0.9834402711864407], 48 -> 
             RGBColor[
              0.9496715593220338, 0.9619857118644067, 0.9700771016949152], 5 -> 
             RGBColor[
              0.9059807627118645, 0.6649520847457627, 0.24320811864406783`], 
             101 -> 
             RGBColor[
              0.9270259152542373, 0.7483891016949153, 0.2601415423728814], 
             333 -> RGBColor[
              0.9578209661016949, 0.8693823559322034, 0.2906428474576271], 
             267 -> RGBColor[
              0.993256627118644, 0.9879849322033899, 0.5074036610169489], 120 -> 
             RGBColor[
              0.9726846949152542, 0.9195212033898303, 0.34838562711864385`], 
             147 -> RGBColor[
              0.9920865762711865, 0.9909956101694916, 0.780809440677966], 89 -> 
             RGBColor[
              0.896460559322034, 0.6227334067796612, 0.23531649152542378`], 
             43 -> RGBColor[
              0.9693975254237287, 0.9766973050847457, 0.936686186440678], 199 -> 
             RGBColor[
              0.9595345423728813, 0.9693415084745762, 0.9533816440677966], 
             268 -> RGBColor[0.178927, 0.305394, 0.933501], 169 -> 
             RGBColor[
              0.9496715593220338, 0.9619857118644067, 0.9700771016949152], 20 -> 
             RGBColor[
              0.9270259152542373, 0.7483891016949153, 0.2601415423728814], 4 -> 
             RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             167 -> RGBColor[
              0.9875484237288136, 0.9696600508474577, 0.406128406779661], 142 -> 
             RGBColor[
              0.993256627118644, 0.9879849322033899, 0.5074036610169489], 16 -> 
             RGBColor[
              0.9938218474576271, 0.9891938813559322, 0.568924406779661], 281 -> 
             RGBColor[
              0.9578209661016949, 0.8693823559322034, 0.2906428474576271], 
             289 -> RGBColor[
              0.9938218474576271, 0.9891938813559322, 0.568924406779661], 398 -> 
             RGBColor[
              0.9938218474576271, 0.9891938813559322, 0.568924406779661], 178 -> 
             RGBColor[
              0.9652528305084747, 0.894451779661017, 0.31951423728813566`], 
             58 -> RGBColor[
              0.9652528305084747, 0.894451779661017, 0.31951423728813566`], 
             186 -> RGBColor[
              0.9875484237288136, 0.9696600508474577, 0.406128406779661], 122 -> 
             RGBColor[
              0.9949522881355932, 0.991611779661017, 0.6919658983050849], 249 -> 
             RGBColor[
              0.9875484237288136, 0.9696600508474577, 0.406128406779661], 113 -> 
             RGBColor[
              0.9726846949152542, 0.9195212033898303, 0.34838562711864385`], 
             52 -> RGBColor[
              0.9595345423728813, 0.9693415084745762, 0.9533816440677966], 
             187 -> 
             RGBColor[
              0.9875753898305084, 0.9891301186440679, 0.8555714745762714], 
             259 -> RGBColor[
              0.9943870677966101, 0.9904028305084746, 0.6304451525423728], 42 -> 
             RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             134 -> RGBColor[
              0.9920865762711865, 0.9909956101694916, 0.780809440677966], 313 -> 
             RGBColor[
              0.9578209661016949, 0.8693823559322034, 0.2906428474576271], 
             248 -> RGBColor[
              0.9801165593220339, 0.944590627118644, 0.3772570169491524], 174 -> 
             RGBColor[
              0.9059807627118645, 0.6649520847457627, 0.24320811864406783`], 
             215 -> RGBColor[
              0.8507448983050847, 0.3910531016949153, 0.1962266779661017], 
             399 -> RGBColor[
              0.8507448983050847, 0.3910531016949153, 0.1962266779661017], 83 -> 
             RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 95 -> 
             RGBColor[
              0.896460559322034, 0.6227334067796612, 0.23531649152542378`], 
             166 -> RGBColor[
              0.8278290847457628, 0.8655524576271186, 0.9834402711864407], 
             384 -> RGBColor[
              0.896460559322034, 0.6227334067796612, 0.23531649152542378`], 
             233 -> RGBColor[
              0.9943870677966101, 0.9904028305084746, 0.6304451525423728], 
             295 -> RGBColor[
              0.9949522881355932, 0.991611779661017, 0.6919658983050849], 141 -> 
             RGBColor[
              0.9652528305084747, 0.894451779661017, 0.31951423728813566`], 
             319 -> RGBColor[
              0.9875753898305084, 0.9891301186440679, 0.8555714745762714], 
             205 -> RGBColor[
              0.9875753898305084, 0.9891301186440679, 0.8555714745762714], 
             224 -> RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             231 -> RGBColor[
              0.9375484915254237, 0.7901076101694915, 0.2686082542372881], 
             332 -> RGBColor[
              0.9926914067796611, 0.9867759830508475, 0.4458829152542371], 68 -> 
             RGBColor[
              0.9949522881355932, 0.991611779661017, 0.6919658983050849], 10 -> 
             RGBColor[
              0.9398085762711864, 0.9546299152542372, 0.9867725593220339], 
             250 -> RGBColor[
              0.993256627118644, 0.9879849322033899, 0.5074036610169489], 282 -> 
             RGBColor[
              0.9926914067796611, 0.9867759830508475, 0.4458829152542371], 
             374 -> RGBColor[
              0.9165033389830508, 0.7066705932203389, 0.25167483050847456`], 
             232 -> RGBColor[
              0.9059807627118645, 0.6649520847457627, 0.24320811864406783`], 
             253 -> RGBColor[
              0.9652528305084747, 0.894451779661017, 0.31951423728813566`], 
             55 -> RGBColor[
              0.9496715593220338, 0.9619857118644067, 0.9700771016949152], 
             325 -> RGBColor[
              0.9693975254237287, 0.9766973050847457, 0.936686186440678], 91 -> 
             RGBColor[
              0.9726846949152542, 0.9195212033898303, 0.34838562711864385`], 
             105 -> RGBColor[
              0.9875753898305084, 0.9891301186440679, 0.8555714745762714], 36 -> 
             RGBColor[
              0.993256627118644, 0.9879849322033899, 0.5074036610169489], 123 -> 
             RGBColor[
              0.9578209661016949, 0.8693823559322034, 0.2906428474576271], 94 -> 
             RGBColor[
              0.9726846949152542, 0.9195212033898303, 0.34838562711864385`], 
             312 -> RGBColor[
              0.9496715593220338, 0.9619857118644067, 0.9700771016949152], 96 -> 
             RGBColor[
              0.9726846949152542, 0.9195212033898303, 0.34838562711864385`], 
             2 -> RGBColor[
              0.9920865762711865, 0.9909956101694916, 0.780809440677966], 262 -> 
             RGBColor[
              0.9480710677966101, 0.8318261186440676, 0.27707496610169485`], 
             272 -> RGBColor[
              0.9801165593220339, 0.944590627118644, 0.3772570169491524], 97 -> 
             RGBColor[
              0.9853197966101694, 0.988197372881356, 0.8929524915254238], 372 -> 
             RGBColor[
              0.9496715593220338, 0.9619857118644067, 0.9700771016949152], 
             356 -> RGBColor[
              0.9926914067796611, 0.9867759830508475, 0.4458829152542371], 
             346 -> RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             341 -> RGBColor[
              0.8591816440677966, 0.4534585593220338, 0.2042100508474576], 
             209 -> RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             378 -> RGBColor[
              0.9726846949152542, 0.9195212033898303, 0.34838562711864385`], 
             66 -> RGBColor[
              0.9875753898305084, 0.9891301186440679, 0.8555714745762714], 
             139 -> RGBColor[
              0.9926914067796611, 0.9867759830508475, 0.4458829152542371], 56 -> 
             RGBColor[
              0.896460559322034, 0.6227334067796612, 0.23531649152542378`], 
             335 -> RGBColor[
              0.9801165593220339, 0.944590627118644, 0.3772570169491524], 314 -> 
             RGBColor[
              0.9920865762711865, 0.9909956101694916, 0.780809440677966], 144 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 298 -> 
             RGBColor[
              0.9801165593220339, 0.944590627118644, 0.3772570169491524], 204 -> 
             RGBColor[
              0.9949522881355932, 0.991611779661017, 0.6919658983050849], 207 -> 
             RGBColor[
              0.9165033389830508, 0.7066705932203389, 0.25167483050847456`], 
             334 -> RGBColor[
              0.9801165593220339, 0.944590627118644, 0.3772570169491524], 149 -> 
             RGBColor[
              0.9898309830508474, 0.9900628644067797, 0.8181904576271186], 
             219 -> RGBColor[
              0.9920865762711865, 0.9909956101694916, 0.780809440677966], 400 -> 
             RGBColor[
              0.9801165593220339, 0.944590627118644, 0.3772570169491524], 9 -> 
             RGBColor[
              0.9875753898305084, 0.9891301186440679, 0.8555714745762714], 11 -> 
             RGBColor[
              0.9949522881355932, 0.991611779661017, 0.6919658983050849], 44 -> 
             RGBColor[
              0.9943421694915254, 0.9919283559322034, 0.7434284237288136], 
             153 -> RGBColor[
              0.9270259152542373, 0.7483891016949153, 0.2601415423728814], 32 -> 
             RGBColor[
              0.9652528305084747, 0.894451779661017, 0.31951423728813566`], 
             162 -> RGBColor[
              0.9949522881355932, 0.991611779661017, 0.6919658983050849], 90 -> 
             RGBColor[
              0.9693975254237287, 0.9766973050847457, 0.936686186440678], 331 -> 
             RGBColor[
              0.9920865762711865, 0.9909956101694916, 0.780809440677966], 8 -> 
             RGBColor[
              0.9270259152542373, 0.7483891016949153, 0.2601415423728814], 
             364 -> RGBColor[
              0.8278290847457628, 0.8655524576271186, 0.9834402711864407], 
             342 -> RGBColor[
              0.9726846949152542, 0.9195212033898303, 0.34838562711864385`], 
             163 -> RGBColor[
              0.9375484915254237, 0.7901076101694915, 0.2686082542372881], 49 -> 
             RGBColor[
              0.9943421694915254, 0.9919283559322034, 0.7434284237288136], 
             338 -> 
             RGBColor[
              0.9938218474576271, 0.9891938813559322, 0.568924406779661], 76 -> 
             RGBColor[
              0.9480710677966101, 0.8318261186440676, 0.27707496610169485`], 
             369 -> RGBColor[
              0.9853197966101694, 0.988197372881356, 0.8929524915254238], 82 -> 
             RGBColor[
              0.8507448983050847, 0.3910531016949153, 0.1962266779661017], 67 -> 
             RGBColor[
              0.868501372881356, 0.49577727118644077`, 0.21198666101694918`], 
             211 -> RGBColor[
              0.9943421694915254, 0.9919283559322034, 
               0.7434284237288136]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9mGk41G3YxiVbGGbGGGMMZp+JsVWihTktLbQQJSTFQyShTSoPqYhQlpJK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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 5}], {
             RGBColor[
             0.8783628305084745, 0.528002593220339, 0.21971739830508474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.8736027288135593, 0.5068932542372883, 0.21577158474576275`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 73}], {
             RGBColor[
             0.9117147966101695, 0.6552871525423729, 0.2723061525423728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[
             0.9117147966101695, 0.6552871525423729, 0.2723061525423728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 162}], {
             RGBColor[
             0.922848593220339, 0.6913324406779662, 0.4440962881355933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 183}], {
             RGBColor[
             0.9154307288135592, 0.6678218644067797, 0.28674184745762704`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 291}], {
             RGBColor[
             0.9180323474576271, 0.6896252372881357, 0.5445895847457627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 357}], {
             RGBColor[
             0.8863574999999999, 0.6658355254237289, 0.5943231016949152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 368}], {
             RGBColor[
             0.922543533898305, 0.6914907288135594, 0.46982755084745764`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 387}], {
             RGBColor[
             0.888885406779661, 0.5697211016949153, 0.22818411016949153`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 28}], {
             RGBColor[
             0.9302939745762713, 0.7433864406779662, 0.4963980508474576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 39}], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 50}], {
             RGBColor[
             0.9932368220338983, 0.990699220338983, 0.7056272966101693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 106}], {
             RGBColor[
             0.9099578305084746, 0.9282740338983051, 0.8821248559322034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 137}], {
             RGBColor[0.9898175, 0.9803278305084746, 0.5934689237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 138}], {
             RGBColor[
             0.9570283389830508, 0.965806779661017, 0.8866144830508473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 149}], {
             RGBColor[
             0.9909587796610169, 0.9905292372881356, 0.7994999491525423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 164}], {
             RGBColor[
             0.9442735677966102, 0.8068645084745764, 0.5080629661016949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 197}], {
             RGBColor[
             0.9542949576271187, 0.8488331016949152, 0.5162421355932203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 210}], {
             RGBColor[
             0.9861015677966102, 0.9677931186440678, 0.5790332288135592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 217}], {
             RGBColor[
             0.9856735423728813, 0.9875243559322034, 0.8504000847457627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 230}], {
             RGBColor[
             0.9920865762711865, 0.9909956101694916, 0.780809440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 254}], {
             RGBColor[
             0.9758105593220339, 0.980168559322034, 0.8670955423728812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 258}], {
             RGBColor[
             0.9932368220338983, 0.990699220338983, 0.7056272966101693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 314}], {
             RGBColor[
             0.9920865762711865, 0.9909956101694916, 0.780809440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 328}], {
             RGBColor[
             0.9929542118644068, 0.9900947457627118, 0.6748669237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 7}], {
             RGBColor[
             0.945423813559322, 0.8065681186440679, 0.43288082203389827`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 13}], {
             RGBColor[
             0.9868237881355932, 0.9872279661016949, 0.775217940677966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 14}], {
             RGBColor[
             0.9946696779661017, 0.9910073050847458, 0.6612055254237288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 21}], {
             RGBColor[
             0.9921090254237288, 0.9902328474576272, 0.7243178050847456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 51}], {
             RGBColor[
             0.9921090254237288, 0.9902328474576272, 0.7243178050847456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 79}], {
             RGBColor[
             0.9798199491525423, 0.9424273050847458, 0.4749796949152542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 188}], {
             RGBColor[
             0.9909677457627118, 0.9800314406779661, 0.5182867796610169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 232}], {
             RGBColor[
             0.9501839152542373, 0.8276774576271186, 0.4368266355932203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 293}], {
             RGBColor[
             0.9581785847457627, 0.9655103898305084, 0.8114323389830508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 373}], {
             RGBColor[
             0.9943646186440678, 0.9911655932203389, 0.6869367881355932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 390}], {
             RGBColor[
             0.9932368220338983, 0.990699220338983, 0.7056272966101693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 84}], {
             RGBColor[
             0.9912611949152542, 0.9884194237288135, 0.6320366864406779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 125}], {
             RGBColor[
             0.9909587796610169, 0.9905292372881356, 0.7994999491525423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 165}], {
             RGBColor[
             0.9921090254237288, 0.9902328474576272, 0.7243178050847456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 184}], {
             RGBColor[
             0.9918264152542373, 0.989628372881356, 0.6935574322033898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 185}], {
             RGBColor[
             0.9812578389830509, 0.954792033898305, 0.5832880423728812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 190}], {
             RGBColor[
             0.9887031864406779, 0.9895964915254238, 0.8368809661016949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.9920865762711863, 0.9909956101694916, 0.7808094406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 252}], {
             RGBColor[
             0.9689510254237288, 0.9109444915254237, 0.5476327118644068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 274}], {
             RGBColor[
             0.9912611949152542, 0.9884194237288135, 0.6320366864406779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 288}], {
             RGBColor[
             0.9077532288135592, 0.5942106949152541, 0.495205313559322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 318}], {
             RGBColor[
             0.9161097033898304, 0.6584422203389833, 0.5032074830508475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.9012206610169492, 0.6438427457627119, 0.2392623050847458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 113}], {
             RGBColor[
             0.9393327288135593, 0.7922366440677966, 0.2957968728813558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 162}], {
             RGBColor[
             0.9504665254237288, 0.8282819322033899, 0.46758700847457635`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 183}], {
             RGBColor[
             0.9430486610169492, 0.8047713559322034, 0.3102325677966101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 270}], {
             RGBColor[
             0.9327576525423729, 0.8171467966101695, 0.5982948813559321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 291}], {
             RGBColor[
             0.9456502796610169, 0.8265747288135594, 0.5680803050847458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 357}], {
             RGBColor[
             0.9139754322033898, 0.8027850169491526, 0.6178138220338982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 368}], {
             RGBColor[
             0.9501614661016949, 0.8284402203389831, 0.4933182711864407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 10}], {
             RGBColor[
             0.9447400677966101, 0.9583078135593219, 0.9784248305084746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.9595345423728813, 0.9693415084745762, 0.9533816440677967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 69}], {
             RGBColor[
             0.9230660593220339, 0.792359559322034, 0.6026967966101695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 71}], {
             RGBColor[
             0.9686234745762712, 0.9755579152542373, 0.9128242881355932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 93}], {
             RGBColor[
             0.9122855762711863, 0.9325354576271185, 0.9790034999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 129}], {
             RGBColor[
             0.972029313559322, 0.9761942711864406, 0.800261127118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 131}], {
             RGBColor[
             0.9720068644067796, 0.9769570338983051, 0.8567527627118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 142}], {
             RGBColor[
             0.9714640932203389, 0.9749853220338983, 0.7387403813559321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 201}], {
             RGBColor[
             0.9723119237288136, 0.9767987457627119, 0.8310215000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 253}], {
             RGBColor[
             0.9574621949152542, 0.9282187457627118, 0.6447956694915254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 273}], {
             RGBColor[
             0.9714640932203389, 0.9749853220338983, 0.7387403813559321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 281}], {
             RGBColor[
             0.9537462627118644, 0.915684033898305, 0.6303599745762711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 303}], {
             RGBColor[
             0.9720068644067796, 0.9769570338983051, 0.8567527627118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 364}], {
             RGBColor[
             0.8887503220338984, 0.9137690847457627, 0.976758686440678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 391}], {
             RGBColor[
             0.9278261610169491, 0.8134688983050847, 0.6066426101694915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 394}], {
             RGBColor[
             0.9697512711864407, 0.9760242881355932, 0.8941337796610169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 13}], {
             RGBColor[
             0.937860533898305, 0.8033932542372882, 0.5776536101694916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 14}], {
             RGBColor[
             0.9457064237288135, 0.8071725932203391, 0.46364119491525435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 21}], {
             RGBColor[
             0.9431457711864406, 0.8063981355932204, 0.5267534745762712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 93}], {
             RGBColor[
             0.8856800762711865, 0.7629093050847457, 0.6116231949152542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 142}], {
             RGBColor[
             0.944858593220339, 0.8053591694915255, 0.37136007627118633`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 188}], {
             RGBColor[
             0.9420044915254238, 0.7961967288135594, 0.3207224491525424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 273}], {
             RGBColor[
             0.944858593220339, 0.8053591694915255, 0.37136007627118633`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 293}], {
             RGBColor[
             0.9092153305084746, 0.7816756779661018, 0.6138680084745762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 390}], {
             RGBColor[
             0.9442735677966102, 0.8068645084745764, 0.5080629661016949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 16}], {
             RGBColor[
             0.9604238813559323, 0.8687914915254238, 0.41453297457627125`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 25}], {
             RGBColor[
             0.9595562457627118, 0.8696923559322034, 0.5204754915254237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 76}], {
             RGBColor[
             0.9375484915254237, 0.7901076101694915, 0.2686082542372881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 117}], {
             RGBColor[
             0.9607064915254238, 0.869395966101695, 0.44529334745762705`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 202}], {
             RGBColor[
             0.9595562457627118, 0.8696923559322034, 0.5204754915254237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 234}], {
             RGBColor[
             0.9595562457627118, 0.8696923559322034, 0.5204754915254237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 239}], {
             RGBColor[
             0.9606840423728813, 0.8701587288135594, 0.5017849830508475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 269}], {
             RGBColor[
             0.9244980084745762, 0.8445035254237289, 0.6262805338983051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 302}], {
             RGBColor[
             0.9424234406779661, 0.8088857288135594, 0.27539219491525424`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 323}], {
             RGBColor[
             0.946139372881356, 0.8214204406779662, 0.28982788983050856`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 365}], {
             RGBColor[
             0.9535712372881355, 0.8464898644067798, 0.3186992796610169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 377}], {
             RGBColor[
             0.921764627118644, 0.727529847457627, 0.255908186440678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 388}], {
             RGBColor[
             0.8805289322033898, 0.5054895762711863, 0.2201819406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 18}], {
             RGBColor[
             0.9467780762711864, 0.8270411016949153, 0.5493897966101696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 56}], {
             RGBColor[
             0.9420179745762711, 0.8059317627118645, 0.5454439830508475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 65}], {
             RGBColor[
             0.9909587796610169, 0.9905292372881356, 0.7994999491525425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 100}], {
             RGBColor[
             0.9838459745762711, 0.966860372881356, 0.6164142457627119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 174}], {
             RGBColor[
             0.9467780762711864, 0.8270411016949153, 0.5493897966101696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 198}], {
             RGBColor[
             0.9233785169491525, 0.7212943389830508, 0.5298907627118645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 203}], {
             RGBColor[
             0.9901333983050847, 0.9879530508474577, 0.6507271949152542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 266}], {
             RGBColor[
             0.9909587796610169, 0.9905292372881356, 0.7994999491525425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 313}], {
             RGBColor[
             0.9726981779661017, 0.9292562372881357, 0.5731071610169493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 339}], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 358}], {
             RGBColor[
             0.9764141101694915, 0.9417909491525425, 0.5875428559322036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 384}], {
             RGBColor[
             0.9420179745762711, 0.8059317627118645, 0.5454439830508475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 32}], {
             RGBColor[
             0.9525307033898305, 0.9245408474576271, 0.6531433983050847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 52}], {
             RGBColor[
             0.9496715593220338, 0.9619857118644067, 0.9700771016949152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 60}], {
             RGBColor[
             0.9447400677966101, 0.9583078135593219, 0.9784248305084746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 68}], {
             RGBColor[
             0.9673804322033899, 0.9731208474576272, 0.8393692288135595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.9670978220338983, 0.972516372881356, 0.8086088559322033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 253}], {
             RGBColor[
             0.9525307033898305, 0.9245408474576271, 0.6531433983050847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 271}], {
             RGBColor[
             0.938678533898305, 0.8723687627118644, 0.627690406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 303}], {
             RGBColor[
             0.9670753728813559, 0.9732791355932203, 0.8651004915254237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 333}], {
             RGBColor[
             0.9488147711864406, 0.9120061355932203, 0.6387077033898305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 334}], {
             RGBColor[
             0.9599625677966102, 0.9496102711864407, 0.6820147881355931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 337}], {
             RGBColor[
             0.9334172457627119, 0.8515095084745763, 0.6234570508474576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 345}], {
             RGBColor[
             0.9496715593220338, 0.9619857118644067, 0.9700771016949152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 353}], {
             RGBColor[
             0.9595345423728814, 0.9693415084745762, 0.9533816440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 364}], {
             RGBColor[
             0.8838188305084747, 0.910091186440678, 0.9851064152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 391}], {
             RGBColor[
             0.9228946694915254, 0.8097909999999999, 0.6149903389830509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 54}], {
             RGBColor[
             0.9923916355932203, 0.9908373220338984, 0.7550781779661018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 83}], {
             RGBColor[
             0.9923916355932203, 0.9908373220338984, 0.7550781779661018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 118}], {
             RGBColor[
             0.982174906779661, 0.9841545423728814, 0.8143260423728815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 123}], {
             RGBColor[
             0.9763866271186441, 0.9304970677966102, 0.491304372881356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 141}], {
             RGBColor[
             0.9801025593220339, 0.943031779661017, 0.5057400677966103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 161}], {
             RGBColor[
             0.9715116779661017, 0.9117189491525424, 0.4845204322033899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 196}], {
             RGBColor[
             0.9673804322033899, 0.9731208474576272, 0.8393692288135595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 206}], {
             RGBColor[
             0.9838184915254238, 0.9555664915254236, 0.5201757627118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 214}], {
             RGBColor[
             0.9901360423728813, 0.9899045762711864, 0.7924591949152544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 286}], {
             RGBColor[
             0.9609891016949152, 0.8700004406779662, 0.4760537203389832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 332}], {
             RGBColor[
             0.9938218474576271, 0.9891938813559322, 0.568924406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 366}], {
             RGBColor[
             0.955727813559322, 0.8491411864406779, 0.47182036440677977`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 386}], {
             RGBColor[
             0.9941044576271186, 0.9897983559322034, 0.599684779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 19}], {
             RGBColor[
             0.9864341101694916, 0.9789287118644068, 0.6495404491525424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 24}], {
             RGBColor[
             0.9408901779661016, 0.8054653898305086, 0.5641344915254238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 65}], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 100}], {
             RGBColor[0.9827181779661016, 0.966394, 0.6351047542372881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 107}], {
             RGBColor[
             0.9898534322033898, 0.9893001016949152, 0.7616988220338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 124}], {
             RGBColor[
             0.9013193983050847, 0.561162186440678, 0.5285852457627118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 150}], {
             RGBColor[
             0.9408901779661016, 0.8054653898305086, 0.5641344915254238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 157}], {
             RGBColor[
             0.9315704491525423, 0.7631466779661018, 0.5563578813559322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 167}], {
             RGBColor[
             0.9864341101694916, 0.9789287118644068, 0.6495404491525424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 168}], {
             RGBColor[
             0.9901360423728813, 0.9899045762711864, 0.7924591949152544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 203}], {
             RGBColor[
             0.9890056016949152, 0.9874866779661018, 0.6694177033898304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 206}], {
             RGBColor[
             0.9790022457627119, 0.9538592881355932, 0.6206690593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 211}], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 238}], {
             RGBColor[
             0.9875753898305084, 0.9891301186440679, 0.8555714745762713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 341}], {
             RGBColor[
             0.922250720338983, 0.720827966101695, 0.5485812711864406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 358}], {
             RGBColor[
             0.975286313559322, 0.9413245762711865, 0.6062333644067797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 14}], {
             RGBColor[
             0.9871063983050847, 0.9878324406779662, 0.8059783135593221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 21}], {
             RGBColor[
             0.9845457457627118, 0.9870579830508475, 0.869090593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 51}], {
             RGBColor[
             0.9845457457627118, 0.9870579830508475, 0.869090593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 79}], {
             RGBColor[
             0.9722566694915254, 0.9392524406779661, 0.6197524830508474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 87}], {
             RGBColor[
             0.9332006694915254, 0.7822338983050847, 0.5737653050847458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 205}], {
             RGBColor[
             0.9834179491525423, 0.9865916101694916, 0.8877811016949153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 232}], {
             RGBColor[
             0.9426206355932203, 0.824502593220339, 0.5815994237288136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 277}], {
             RGBColor[
             0.937860533898305, 0.8033932542372882, 0.5776536101694916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 373}], {
             RGBColor[
             0.9868013389830508, 0.9879907288135594, 0.8317095762711864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 390}], {
             RGBColor[
             0.9856735423728813, 0.9875243559322034, 0.8504000847457627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 69}], {
             RGBColor[
             0.9457064237288135, 0.8071725932203391, 0.46364119491525435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 71}], {
             RGBColor[
             0.9912638389830508, 0.9903709491525424, 0.7737686864406781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 201}], {
             RGBColor[
             0.9949522881355932, 0.991611779661017, 0.6919658983050849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 212}], {
             RGBColor[
             0.9584611949152542, 0.9661148644067796, 0.8421927118644068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 273}], {
             RGBColor[
             0.9941044576271186, 0.9897983559322034, 0.599684779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 289}], {
             RGBColor[
             0.9943870677966102, 0.9904028305084747, 0.630445152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 293}], {
             RGBColor[
             0.9584611949152542, 0.9661148644067796, 0.8421927118644068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 390}], {
             RGBColor[
             0.9935194322033898, 0.9913036949152543, 0.7363876694915255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 35}], {
             RGBColor[
             0.9941044576271186, 0.9897983559322034, 0.599684779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 106}], {
             RGBColor[
             0.910825466101695, 0.9273731694915255, 0.7761823389830509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 154}], {
             RGBColor[
             0.9461283474576272, 0.9555227288135593, 0.7795495593220338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 207}], {
             RGBColor[
             0.9551625932203389, 0.8479322372881355, 0.41029961864406783`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 231}], {
             RGBColor[
             0.9656851694915254, 0.8896507457627119, 0.41876633050847456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 369}], {
             RGBColor[
             0.9895708220338983, 0.9886956271186441, 0.7309384491525424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 372}], {
             RGBColor[
             0.9717467033898305, 0.9755897966101694, 0.7695007542372881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 392}], {
             RGBColor[
             0.9906986186440678, 0.9891620000000001, 0.7122479406779663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 25}], {
             RGBColor[
             0.9929542118644068, 0.9900947457627118, 0.6748669237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 37}], {
             RGBColor[
             0.9940820084745763, 0.9905611186440678, 0.6561764152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 76}], {
             RGBColor[
             0.9709464576271186, 0.9105099999999999, 0.422999686440678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 77}], {
             RGBColor[
             0.9795373389830508, 0.9418228305084746, 0.44421932203389836`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 78}], {
             RGBColor[
             0.9935392372881355, 0.988589406779661, 0.5381640338983049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 80}], {
             RGBColor[
             0.9865411779661017, 0.9866234915254237, 0.7444575677966101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 96}], {
             RGBColor[
             0.9832532711864407, 0.9543575423728813, 0.45865501694915245`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 182}], {
             RGBColor[
             0.9935392372881355, 0.988589406779661, 0.5381640338983049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.9906986186440678, 0.9891620000000001, 0.7122479406779663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 269}], {
             RGBColor[
             0.9578959745762712, 0.9649059152542373, 0.780671966101695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 302}], {
             RGBColor[
             0.975821406779661, 0.9292881186440678, 0.42978362711864404`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 323}], {
             RGBColor[
             0.9795373389830508, 0.9418228305084746, 0.44421932203389836`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 365}], {
             RGBColor[
             0.9869692033898305, 0.9668922542372882, 0.47309071186440677`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 377}], {
             RGBColor[
             0.9551625932203389, 0.8479322372881355, 0.41029961864406783`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 388}], {
             RGBColor[
             0.9139268983050848, 0.6258919661016947, 0.37457337288135595`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 18}], {
             RGBColor[
             0.9139754322033898, 0.8027850169491526, 0.6178138220338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 31}], {
             RGBColor[
             0.9581561355932203, 0.9662731525423729, 0.8679239745762712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 62}], {
             RGBColor[
             0.9578959745762712, 0.9649059152542373, 0.780671966101695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.8952357372881357, 0.7181976101694916, 0.602203093220339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 111}], {
             RGBColor[
             0.9584611949152542, 0.9661148644067796, 0.8421927118644068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 222}], {
             RGBColor[
             0.9573307542372882, 0.963696966101695, 0.7191512203389829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 223}], {
             RGBColor[
             0.9536449491525423, 0.9644076610169492, 0.9426860084745763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 247}], {
             RGBColor[
             0.9219701016949152, 0.9406179491525424, 0.9924195254237288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 256}], {
             RGBColor[
             0.8780010254237287, 0.6016039999999998, 0.5863209322033898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 292}], {
             RGBColor[
             0.9547727457627118, 0.9648740338983051, 0.9239955000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 310}], {
             RGBColor[
             0.8952357372881357, 0.7181976101694916, 0.602203093220339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 319}], {
             RGBColor[
             0.9547727457627118, 0.9648740338983051, 0.9239955000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 384}], {
             RGBColor[
             0.9092153305084746, 0.7816756779661018, 0.6138680084745762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 99}], {
             RGBColor[
             0.8872410677966103, 0.5803646779661018, 0.2275973898305085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 144}], {
             RGBColor[
             0.8616498813559322, 0.39953954237288136`, 0.20371305932203393`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.8825812033898306, 0.5592053220338983, 0.22370908474576273`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 218}], {
             RGBColor[
             0.9479058728813559, 0.8275074745762712, 0.5306992881355932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 266}], {
             RGBColor[
             0.9501614661016949, 0.8284402203389831, 0.4933182711864407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 310}], {
             RGBColor[
             0.8872410677966103, 0.5803646779661018, 0.2275973898305085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 319}], {
             RGBColor[
             0.9467780762711864, 0.8270411016949153, 0.5493897966101695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 384}], {
             RGBColor[
             0.9012206610169492, 0.6438427457627119, 0.2392623050847458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 24}], {
             RGBColor[
             0.9420044915254238, 0.7961967288135594, 0.3207224491525424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 85}], {
             RGBColor[
             0.9726846949152542, 0.9195212033898306, 0.34838562711864407`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 107}], {
             RGBColor[
             0.9909677457627118, 0.9800314406779661, 0.5182867796610169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 124}], {
             RGBColor[
             0.9024337118644068, 0.5518935254237288, 0.2851732033898305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 150}], {
             RGBColor[
             0.9420044915254238, 0.7961967288135594, 0.3207224491525424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 152}], {
             RGBColor[0.9636785, 0.9621449830508475, 0.6964504830508474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 157}], {
             RGBColor[
             0.9326847627118644, 0.7538780169491526, 0.31294583898305084`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 160}], {
             RGBColor[
             0.9909452966101695, 0.9807942033898305, 0.5747784152542372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 167}], {
             RGBColor[
             0.9875484237288136, 0.9696600508474577, 0.406128406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 168}], {
             RGBColor[
             0.9912503559322035, 0.9806359152542373, 0.549047152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 181}], {
             RGBColor[
             0.9875484237288136, 0.9696600508474577, 0.406128406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 211}], {
             RGBColor[
             0.9909452966101695, 0.9807942033898305, 0.5747784152542372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 238}], {
             RGBColor[
             0.9886897033898305, 0.9798614576271187, 0.6121594322033899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 64}], {
             RGBColor[
             0.9606840423728813, 0.8701587288135594, 0.5017849830508475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 88}], {
             RGBColor[
             0.9535712372881355, 0.8464898644067798, 0.3186992796610169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 89}], {
             RGBColor[
             0.9117432372881356, 0.6855612542372882, 0.2477290169491526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 120}], {
             RGBColor[
             0.9498553050847458, 0.8339551525423728, 0.30426358474576265`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 140}], {
             RGBColor[
             0.946139372881356, 0.8214204406779662, 0.28982788983050856`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 189}], {
             RGBColor[
             0.946139372881356, 0.8214204406779662, 0.28982788983050856`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 195}], {
             RGBColor[
             0.9165033389830508, 0.706670593220339, 0.2516748305084746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 241}], {
             RGBColor[
             0.9609891016949152, 0.8700004406779662, 0.4760537203389832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 255}], {
             RGBColor[
             0.9117432372881356, 0.6855612542372882, 0.2477290169491526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 257}], {
             RGBColor[
             0.9498553050847458, 0.8339551525423728, 0.30426358474576265`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 263}], {
             RGBColor[
             0.9573006525423728, 0.8687596101694917, 0.5578565084745764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 312}], {
             RGBColor[
             0.9383487372881356, 0.855187406779661, 0.6151093220338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 336}], {
             RGBColor[
             0.948211720338983, 0.8625432033898306, 0.5984138644067798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 356}], {
             RGBColor[
             0.9598586610169492, 0.8675825423728813, 0.35301222881355926`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 359}], {
             RGBColor[
             0.9322872033898305, 0.7692483559322034, 0.26437489830508476`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 360}], {
             RGBColor[
             0.9606840423728813, 0.8701587288135594, 0.5017849830508475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 389}], {
             RGBColor[
             0.9383487372881356, 0.855187406779661, 0.6151093220338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 109}], {
             RGBColor[
             0.9738259745762712, 0.9297226101694915, 0.5544166525423728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[
             0.9923916355932203, 0.9908373220338984, 0.7550781779661018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 132}], {
             RGBColor[
             0.9912611949152542, 0.9884194237288135, 0.6320366864406779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 180}], {
             RGBColor[
             0.9812578389830509, 0.954792033898305, 0.5832880423728812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 232}], {
             RGBColor[
             0.9479058728813559, 0.8275074745762712, 0.5306992881355932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 249}], {
             RGBColor[
             0.9886897033898305, 0.9798614576271187, 0.6121594322033899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 370}], {
             RGBColor[
             0.977541906779661, 0.9422573220338983, 0.5688523474576271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 45}], {
             RGBColor[
             0.9849737711864406, 0.9673267457627119, 0.5977237372881355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 74}], {
             RGBColor[
             0.9861015677966102, 0.9677931186440678, 0.5790332288135592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 116}], {
             RGBColor[
             0.9430486610169492, 0.8047713559322034, 0.3102325677966101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 141}], {
             RGBColor[
             0.9726846949152543, 0.9195212033898306, 0.34838562711864407`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 179}], {
             RGBColor[
             0.9599625677966102, 0.9496102711864407, 0.6820147881355931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 209}], {
             RGBColor[
             0.9849737711864406, 0.9673267457627119, 0.5977237372881355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 286}], {
             RGBColor[
             0.9535712372881355, 0.8464898644067798, 0.3186992796610169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 290}], {
             RGBColor[
             0.9801165593220339, 0.944590627118644, 0.3772570169491524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 304}], {
             RGBColor[
             0.9039728220338983, 0.9050715423728813, 0.6803486440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 338}], {
             RGBColor[
             0.9869692033898305, 0.9668922542372882, 0.47309071186440677`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 38}], {
             RGBColor[
             0.8763506949152542, 0.47337381355932195`, 0.2161808559322034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 92}], {
             RGBColor[
             0.9070833728813559, 0.6644018983050848, 0.2438407118644068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 98}], {
             RGBColor[
             0.8805289322033898, 0.5054895762711863, 0.2201819406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 119}], {
             RGBColor[
             0.948211720338983, 0.8625432033898306, 0.5984138644067798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 128}], {
             RGBColor[
             0.946139372881356, 0.8214204406779662, 0.28982788983050856`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 130}], {
             RGBColor[
             0.9531432118644068, 0.8662211016949153, 0.5900661355932204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 139}], {
             RGBColor[
             0.9598586610169492, 0.8675825423728813, 0.35301222881355926`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 143}], {
             RGBColor[0.9584284491525423, 0.8692259830508475, 0.539166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 146}], {
             RGBColor[
             0.9606840423728813, 0.8701587288135594, 0.5017849830508475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 151}], {
             RGBColor[
             0.9573006525423728, 0.8687596101694917, 0.5578565084745764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 158}], {
             RGBColor[
             0.9498553050847458, 0.8339551525423728, 0.30426358474576265`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 186}], {
             RGBColor[
             0.9572871694915255, 0.8590245762711866, 0.33313497457627117`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 213}], {
             RGBColor[
             0.9334172457627119, 0.8515095084745763, 0.6234570508474577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 267}], {
             RGBColor[
             0.9601412711864407, 0.8681870169491526, 0.3837726016949151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 306}], {
             RGBColor[
             0.9322872033898305, 0.7692483559322034, 0.26437489830508476`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 308}], {
             RGBColor[
             0.9561728559322034, 0.8682932372881357, 0.5765470169491527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 311}], {
             RGBColor[
             0.9573006525423728, 0.8687596101694917, 0.5578565084745764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 346}], {
             RGBColor[0.9584284491525423, 0.8692259830508475, 0.539166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 348}], {
             RGBColor[
             0.9498553050847458, 0.8339551525423728, 0.30426358474576265`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 354}], {
             RGBColor[
             0.946139372881356, 0.8214204406779662, 0.28982788983050856`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 374}], {
             RGBColor[
             0.921764627118644, 0.727529847457627, 0.255908186440678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 33}], {
             RGBColor[
             0.944858593220339, 0.8053591694915255, 0.37136007627118633`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 56}], {
             RGBColor[
             0.896460559322034, 0.6227334067796612, 0.23531649152542378`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 65}], {
             RGBColor[
             0.9454013644067797, 0.8073308813559323, 0.4893724576271187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 100}], {
             RGBColor[
             0.9382885593220339, 0.7836620169491526, 0.30628675423728813`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 107}], {
             RGBColor[
             0.945423813559322, 0.8065681186440679, 0.43288082203389827`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 124}], {
             RGBColor[
             0.856889779661017, 0.3784302033898306, 0.19976724576271188`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 150}], {
             RGBColor[
             0.896460559322034, 0.6227334067796612, 0.23531649152542378`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 157}], {
             RGBColor[
             0.8871408305084746, 0.5804146949152543, 0.22753988135593223`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 167}], {
             RGBColor[
             0.9420044915254238, 0.7961967288135594, 0.3207224491525424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 168}], {
             RGBColor[
             0.9457064237288135, 0.8071725932203391, 0.46364119491525435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 203}], {
             RGBColor[
             0.9445759830508476, 0.8047546949152543, 0.3405997033898305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 206}], {
             RGBColor[
             0.9345726271186441, 0.7711273050847458, 0.2918510593220338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 211}], {
             RGBColor[
             0.9454013644067797, 0.8073308813559323, 0.4893724576271187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 238}], {
             RGBColor[
             0.9431457711864406, 0.8063981355932204, 0.5267534745762712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 341}], {
             RGBColor[
             0.8778211016949153, 0.5380959830508475, 0.21976327118644068`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 358}], {
             RGBColor[
             0.9308566949152544, 0.758592593220339, 0.2774153644067797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 386}], {
             RGBColor[
             0.944858593220339, 0.8053591694915255, 0.37136007627118633`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 37}], {
             RGBColor[
             0.993214372881356, 0.9914619830508475, 0.7621189322033898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 62}], {
             RGBColor[
             0.9929542118644068, 0.9900947457627118, 0.6748669237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[
             0.9700788220338983, 0.9114108644067795, 0.5289422033898304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 78}], {
             RGBColor[
             0.9926716016949153, 0.9894902711864407, 0.6441065508474575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 91}], {
             RGBColor[
             0.9823856355932203, 0.955258406779661, 0.5645975338983049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 117}], {
             RGBColor[
             0.9932368220338983, 0.990699220338983, 0.7056272966101693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 182}], {
             RGBColor[
             0.9926716016949153, 0.9894902711864407, 0.6441065508474575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 187}], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 208}], {
             RGBColor[0.9172375, 0.6589085932203391, 0.48451697457627113`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 239}], {
             RGBColor[
             0.993214372881356, 0.9914619830508475, 0.7621189322033898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 269}], {
             RGBColor[
             0.9570283389830508, 0.965806779661017, 0.8866144830508473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 309}], {
             RGBColor[
             0.9926716016949153, 0.9894902711864407, 0.6441065508474575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 323}], {
             RGBColor[
             0.9786697033898306, 0.9427236949152542, 0.5501618389830508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 362}], {
             RGBColor[
             0.9932368220338983, 0.990699220338983, 0.7056272966101693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 365}], {
             RGBColor[
             0.9861015677966102, 0.9677931186440678, 0.5790332288135592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 377}], {
             RGBColor[
             0.9542949576271187, 0.8488331016949152, 0.5162421355932203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 388}], {
             RGBColor[
             0.9130592627118643, 0.6267928305084745, 0.4805158898305084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 395}], {
             RGBColor[
             0.9349538389830508, 0.7645457966101695, 0.5002863559322033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 70}], {
             RGBColor[
             0.9912503559322035, 0.9806359152542373, 0.549047152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 177}], {
             RGBColor[
             0.9686099915254237, 0.9658228813559322, 0.6881027542372882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 285}], {
             RGBColor[
             0.9906851355932204, 0.979426966101695, 0.487526406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 324}], {
             RGBColor[
             0.9909452966101695, 0.9807942033898305, 0.5747784152542372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 40}], {
             RGBColor[
             0.9535712372881355, 0.8464898644067798, 0.3186992796610169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 41}], {
             RGBColor[
             0.946139372881356, 0.8214204406779662, 0.28982788983050856`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 48}], {
             RGBColor[
             0.9383487372881356, 0.855187406779661, 0.6151093220338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 63}], {
             RGBColor[
             0.9595562457627118, 0.8696923559322034, 0.5204754915254237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 86}], {
             RGBColor[
             0.9375484915254237, 0.7901076101694915, 0.2686082542372881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 250}], {
             RGBColor[
             0.9601412711864407, 0.8681870169491526, 0.3837726016949151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 265}], {
             RGBColor[
             0.9606840423728813, 0.8701587288135594, 0.5017849830508475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 295}], {
             RGBColor[
             0.9609891016949152, 0.8700004406779662, 0.4760537203389832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 325}], {
             RGBColor[
             0.948211720338983, 0.8625432033898306, 0.5984138644067798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 376}], {
             RGBColor[
             0.9573006525423728, 0.8687596101694917, 0.5578565084745764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 39}], {
             RGBColor[
             0.9280383813559322, 0.7424536949152543, 0.5337790677966103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 50}], {
             RGBColor[
             0.931444220338983, 0.7430900508474576, 0.421215906779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 106}], {
             RGBColor[
             0.8481652288135594, 0.6806648644067796, 0.597713466101695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 197}], {
             RGBColor[
             0.8925023559322034, 0.6012239322033899, 0.23183074576271187`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 217}], {
             RGBColor[
             0.9238809406779661, 0.7399151864406781, 0.5659886949152542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 231}], {
             RGBColor[
             0.9030249322033899, 0.6429424406779661, 0.24029745762711865`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 254}], {
             RGBColor[
             0.9140179576271186, 0.7325593898305085, 0.5826841525423729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 314}], {
             RGBColor[
             0.9302939745762713, 0.7433864406779662, 0.4963980508474576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 369}], {
             RGBColor[
             0.9269105847457627, 0.7419873220338984, 0.5524695762711864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 113}], {
             RGBColor[
             0.9345726271186441, 0.7711273050847458, 0.2918510593220338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 162}], {
             RGBColor[
             0.9457064237288135, 0.8071725932203391, 0.46364119491525435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 183}], {
             RGBColor[
             0.9382885593220339, 0.7836620169491526, 0.30628675423728813`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 270}], {
             RGBColor[
             0.9279975508474576, 0.7960374576271187, 0.5943490677966101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 357}], {
             RGBColor[
             0.9092153305084746, 0.7816756779661018, 0.6138680084745762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 153}], {
             RGBColor[
             0.9573006525423728, 0.8687596101694917, 0.5578565084745764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 168}], {
             RGBColor[
             0.9912638389830508, 0.9903709491525424, 0.7737686864406781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 175}], {
             RGBColor[
             0.9904160084745762, 0.9885575254237289, 0.6814875677966101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 211}], {
             RGBColor[
             0.9909587796610169, 0.9905292372881356, 0.7994999491525425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 216}], {
             RGBColor[
             0.9834179491525423, 0.9865916101694916, 0.8877811016949153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 229}], {
             RGBColor[
             0.9312374915254237, 0.9461076610169492, 0.921750686440678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 294}], {
             RGBColor[
             0.9875753898305084, 0.9891301186440679, 0.8555714745762714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 329}], {
             RGBColor[
             0.9834179491525423, 0.9865916101694916, 0.8877811016949153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 341}], {
             RGBColor[
             0.9233785169491525, 0.7212943389830508, 0.5298907627118645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 343}], {
             RGBColor[
             0.9864475932203389, 0.9886637457627119, 0.8742619830508476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 358}], {
             RGBColor[
             0.9764141101694915, 0.9417909491525425, 0.5875428559322036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 379}], {
             RGBColor[
             0.9373581101694914, 0.7847724067796611, 0.5415556779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 99}], {
             RGBColor[
             0.9314217711864408, 0.7438528135593221, 0.4777075423728814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 111}], {
             RGBColor[
             0.9946472288135593, 0.9917700677966101, 0.7176971610169492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 169}], {
             RGBColor[
             0.9720068644067796, 0.9769570338983051, 0.8567527627118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 199}], {
             RGBColor[
             0.9769383559322034, 0.9806349322033898, 0.8484050338983051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 215}], {
             RGBColor[
             0.922543533898305, 0.6914907288135593, 0.46982755084745764`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 222}], {
             RGBColor[
             0.9935167881355933, 0.9893521694915255, 0.5946556694915254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 223}], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 224}], {
             RGBColor[
             0.9920865762711863, 0.9909956101694916, 0.7808094406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 247}], {
             RGBColor[
             0.9581561355932203, 0.9662731525423729, 0.8679239745762712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 259}], {
             RGBColor[
             0.9943646186440678, 0.9911655932203389, 0.6869367881355932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 292}], {
             RGBColor[
             0.9909587796610169, 0.9905292372881356, 0.7994999491525425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 363}], {
             RGBColor[
             0.9670753728813559, 0.9732791355932203, 0.8651004915254237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 383}], {
             RGBColor[
             0.993214372881356, 0.9914619830508475, 0.7621189322033898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 393}], {
             RGBColor[
             0.9835134322033898, 0.9557247796610169, 0.5459070254237287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 400}], {
             RGBColor[
             0.9872293644067797, 0.9682594915254237, 0.560342720338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 46}], {
             RGBColor[
             0.9408780847457627, 0.8005611864406779, 0.28559453389830514`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 52}], {
             RGBColor[
             0.9623936864406779, 0.9318966440677966, 0.6364479406779662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 71}], {
             RGBColor[
             0.9764141101694915, 0.9417909491525425, 0.5875428559322036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 105}], {
             RGBColor[
             0.9764141101694915, 0.9417909491525425, 0.5875428559322036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 111}], {
             RGBColor[
             0.9801025593220339, 0.943031779661017, 0.5057400677966103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 129}], {
             RGBColor[
             0.9798199491525423, 0.9424273050847458, 0.4749796949152542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 199}], {
             RGBColor[
             0.9623936864406779, 0.9318966440677966, 0.6364479406779662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 215}], {
             RGBColor[
             0.9079988644067797, 0.6427524406779661, 0.2578704576271187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 247}], {
             RGBColor[
             0.943611466101695, 0.9175348644067797, 0.6559668813559323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 259}], {
             RGBColor[
             0.9798199491525423, 0.9424273050847458, 0.4749796949152542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 271}], {
             RGBColor[
             0.9514006610169492, 0.8422796949152542, 0.29406124576271186`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 287}], {
             RGBColor[
             0.9795373389830508, 0.9418228305084746, 0.44421932203389836`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 292}], {
             RGBColor[
             0.9764141101694915, 0.9417909491525425, 0.5875428559322036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 303}], {
             RGBColor[
             0.9797975000000001, 0.9431900677966102, 0.5314713305084746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 333}], {
             RGBColor[
             0.9615368983050847, 0.8819170677966102, 0.30507854237288135`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 337}], {
             RGBColor[
             0.946139372881356, 0.8214204406779662, 0.28982788983050856`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 345}], {
             RGBColor[
             0.9623936864406779, 0.9318966440677966, 0.6364479406779662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 353}], {
             RGBColor[
             0.9722566694915254, 0.9392524406779661, 0.6197524830508474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 385}], {
             RGBColor[
             0.9726846949152543, 0.9195212033898306, 0.34838562711864407`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 391}], {
             RGBColor[
             0.9356167966101696, 0.7797019322033898, 0.2813611779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 400}], {
             RGBColor[
             0.9726846949152543, 0.9195212033898306, 0.34838562711864407`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 58}], {
             RGBColor[
             0.9792547288135593, 0.9412183559322034, 0.4134589491525423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 74}], {
             RGBColor[
             0.9926716016949153, 0.9894902711864407, 0.6441065508474575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 107}], {
             RGBColor[
             0.993821847457627, 0.9891938813559322, 0.5689244067796608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 116}], {
             RGBColor[
             0.9496186949152543, 0.8264685084745763, 0.3753058898305084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 118}], {
             RGBColor[
             0.9813270762711863, 0.9823411186440678, 0.7220449237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 124}], {
             RGBColor[
             0.9052878135593221, 0.561055966101695, 0.33581083050847443`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 141}], {
             RGBColor[
             0.9792547288135593, 0.9412183559322034, 0.4134589491525423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 150}], {
             RGBColor[
             0.944858593220339, 0.8053591694915255, 0.37136007627118633`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 152}], {
             RGBColor[
             0.9665326016949152, 0.9713074237288135, 0.7470881101694914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 156}], {
             RGBColor[
             0.9904160084745762, 0.9885575254237289, 0.6814875677966101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 157}], {
             RGBColor[
             0.9355388644067797, 0.7630404576271187, 0.3635834661016948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 179}], {
             RGBColor[
             0.9665326016949152, 0.9713074237288135, 0.7470881101694914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 206}], {
             RGBColor[
             0.9829706610169491, 0.9537530677966102, 0.42789464406779637`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 209}], {
             RGBColor[
             0.9915438050847457, 0.9890238983050847, 0.6627970593220338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 245}], {
             RGBColor[
             0.9926716016949153, 0.9894902711864407, 0.6441065508474575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 286}], {
             RGBColor[
             0.9601412711864407, 0.8681870169491526, 0.3837726016949151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 386}], {
             RGBColor[
             0.993256627118644, 0.9879849322033899, 0.5074036610169489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 43}], {
             RGBColor[
             0.9773586610169491, 0.9824473389830508, 0.9148193389830509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 159}], {
             RGBColor[
             0.962564186440678, 0.9714136440677966, 0.9398625254237288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 250}], {
             RGBColor[
             0.9892882118644067, 0.988091152542373, 0.7001780762711863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 265}], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 321}], {
             RGBColor[
             0.9892882118644067, 0.988091152542373, 0.7001780762711863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 375}], {
             RGBColor[
             0.9864341101694916, 0.9789287118644068, 0.6495404491525424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 381}], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 73}], {
             RGBColor[
             0.9835358813559322, 0.9549620169491524, 0.4894153898305083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 154}], {
             RGBColor[
             0.9464109576271187, 0.9561272033898305, 0.8103099322033898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 207}], {
             RGBColor[
             0.9554452033898304, 0.8485367118644067, 0.44105999152542363`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 231}], {
             RGBColor[
             0.9659677796610169, 0.8902552203389831, 0.4495267033898305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 280}], {
             RGBColor[
             0.9946696779661017, 0.9910073050847458, 0.6612055254237288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 291}], {
             RGBColor[
             0.9898534322033898, 0.9893001016949152, 0.7616988220338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 372}], {
             RGBColor[
             0.972029313559322, 0.9761942711864406, 0.800261127118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 387}], {
             RGBColor[
             0.9607064915254238, 0.869395966101695, 0.44529334745762705`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 392}], {
             RGBColor[
             0.9909812288135593, 0.9897664745762712, 0.7430083135593221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 61}], {
             RGBColor[
             0.9755387966101694, 0.9286836440677966, 0.399023254237288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 70}], {
             RGBColor[
             0.9941044576271186, 0.9897983559322034, 0.599684779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 90}], {
             RGBColor[
             0.9813270762711863, 0.9823411186440678, 0.7220449237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 95}], {
             RGBColor[
             0.944858593220339, 0.8053591694915255, 0.37136007627118633`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 148}], {
             RGBColor[
             0.9792547288135593, 0.9412183559322034, 0.4134589491525423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 228}], {
             RGBColor[
             0.9904025254237288, 0.9788224915254238, 0.45676603389830495`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 276}], {
             RGBColor[
             0.9937993983050848, 0.9899566440677967, 0.6254160423728812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 282}], {
             RGBColor[
             0.9929740169491525, 0.9873804576271187, 0.476643288135593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 301}], {
             RGBColor[
             0.9755387966101694, 0.9286836440677966, 0.399023254237288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 305}], {
             RGBColor[
             0.9862585677966101, 0.9860190169491526, 0.7136971949152541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 361}], {
             RGBColor[
             0.993821847457627, 0.9891938813559322, 0.5689244067796608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 382}], {
             RGBColor[
             0.9941044576271186, 0.9897983559322034, 0.599684779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 76}], {
             RGBColor[
             0.9712066186440678, 0.9118772372881355, 0.5102516949152542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 78}], {
             RGBColor[
             0.9937993983050848, 0.9899566440677967, 0.6254160423728812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 80}], {
             RGBColor[
             0.9868013389830508, 0.9879907288135594, 0.8317095762711864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 96}], {
             RGBColor[
             0.9835134322033898, 0.9557247796610169, 0.5459070254237287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 104}], {
             RGBColor[
             0.9943421694915254, 0.9919283559322034, 0.7434284237288136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 117}], {
             RGBColor[
             0.9943646186440678, 0.9911655932203389, 0.6869367881355932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 145}], {
             RGBColor[
             0.9946472288135593, 0.9917700677966101, 0.7176971610169492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 182}], {
             RGBColor[
             0.9937993983050848, 0.9899566440677967, 0.6254160423728812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 187}], {
             RGBColor[
             0.9909587796610169, 0.9905292372881356, 0.7994999491525425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 208}], {
             RGBColor[
             0.9183652966101695, 0.659374966101695, 0.4658264661016949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 269}], {
             RGBColor[
             0.9581561355932203, 0.9662731525423729, 0.8679239745762712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 323}], {
             RGBColor[
             0.9797975000000001, 0.9431900677966102, 0.5314713305084746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 365}], {
             RGBColor[
             0.9872293644067797, 0.9682594915254237, 0.560342720338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 377}], {
             RGBColor[
             0.9554227542372882, 0.8492994745762712, 0.4975516271186441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 388}], {
             RGBColor[
             0.9141870593220338, 0.6272592033898303, 0.4618253813559322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 395}], {
             RGBColor[
             0.9360816355932203, 0.7650121694915255, 0.4815958474576271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 44}], {
             RGBColor[
             0.9100088220338983, 0.5951434406779661, 0.4578242966101695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 66}], {
             RGBColor[
             0.9066254322033898, 0.5937443220338983, 0.5138958220338984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 81}], {
             RGBColor[
             0.9100312711864407, 0.5943806779661016, 0.4013326610169491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 119}], {
             RGBColor[0.8975365, 0.5875279152542372, 0.5544531779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 128}], {
             RGBColor[
             0.895464152542373, 0.5464051525423728, 0.24586720338983054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 130}], {
             RGBColor[
             0.9024679915254237, 0.5912058135593219, 0.5461054491525423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 135}], {
             RGBColor[
             0.9091834406779662, 0.592567254237288, 0.30905154237288124`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 146}], {
             RGBColor[
             0.9100088220338983, 0.5951434406779661, 0.4578242966101695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 151}], {
             RGBColor[
             0.9066254322033898, 0.5937443220338983, 0.5138958220338984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 213}], {
             RGBColor[
             0.8827420254237288, 0.5764942203389829, 0.5794963644067797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 224}], {
             RGBColor[
             0.9077532288135592, 0.5942106949152541, 0.495205313559322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 227}], {
             RGBColor[
             0.9094660508474577, 0.5931717288135592, 0.33981191525423715`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 243}], {
             RGBColor[0.8975365, 0.5875279152542372, 0.5544531779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 267}], {
             RGBColor[
             0.9094660508474577, 0.5931717288135592, 0.33981191525423715`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 306}], {
             RGBColor[
             0.8816119830508475, 0.4942330677966101, 0.22041421186440677`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 311}], {
             RGBColor[
             0.9066254322033898, 0.5937443220338983, 0.5138958220338984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 346}], {
             RGBColor[
             0.9077532288135592, 0.5942106949152541, 0.495205313559322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 350}], {
             RGBColor[
             0.8926050084745762, 0.5838500169491525, 0.562800906779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 363}], {
             RGBColor[
             0.8827420254237288, 0.5764942203389829, 0.5794963644067797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 383}], {
             RGBColor[
             0.9088810254237288, 0.59467706779661, 0.4765148050847457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 47}], {
             RGBColor[
             0.9726981779661017, 0.9292562372881357, 0.5731071610169493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 50}], {
             RGBColor[
             0.9909812288135593, 0.9897664745762712, 0.7430083135593221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 136}], {
             RGBColor[
             0.9784864576271186, 0.9829137118644068, 0.8961288305084747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 149}], {
             RGBColor[
             0.9887031864406779, 0.9895964915254238, 0.8368809661016949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 164}], {
             RGBColor[
             0.9420179745762711, 0.8059317627118645, 0.5454439830508475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 197}], {
             RGBColor[
             0.9520393644067796, 0.8479003559322034, 0.5536231525423729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 210}], {
             RGBColor[
             0.9838459745762711, 0.966860372881356, 0.6164142457627119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 217}], {
             RGBColor[
             0.9834179491525423, 0.9865916101694916, 0.8877811016949153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 230}], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 254}], {
             RGBColor[
             0.9735549661016949, 0.979235813559322, 0.904476559322034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 258}], {
             RGBColor[
             0.9909812288135593, 0.9897664745762712, 0.7430083135593221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 314}], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 328}], {
             RGBColor[
             0.9906986186440678, 0.9891620000000001, 0.7122479406779663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 41}], {
             RGBColor[
             0.9726846949152543, 0.9195212033898306, 0.34838562711864407`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 48}], {
             RGBColor[
             0.9648940593220339, 0.9532881694915254, 0.6736670593220337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 63}], {
             RGBColor[
             0.9861015677966102, 0.9677931186440678, 0.5790332288135592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 103}], {
             RGBColor[
             0.9861015677966102, 0.9677931186440678, 0.5790332288135592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 265}], {
             RGBColor[
             0.9872293644067797, 0.9682594915254237, 0.560342720338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 295}], {
             RGBColor[
             0.9875344237288135, 0.9681012033898305, 0.5346114576271187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 48}], {
             RGBColor[
             0.9574621949152542, 0.9282187457627118, 0.6447956694915254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 63}], {
             RGBColor[
             0.9786697033898306, 0.9427236949152542, 0.5501618389830508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.9792547288135593, 0.9412183559322034, 0.4134589491525423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 265}], {
             RGBColor[
             0.9797975000000001, 0.9431900677966102, 0.5314713305084746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 295}], {
             RGBColor[
             0.9801025593220339, 0.943031779661017, 0.5057400677966103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 325}], {
             RGBColor[
             0.9673251779661016, 0.9355745423728814, 0.6281002118644068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 381}], {
             RGBColor[
             0.9797975000000001, 0.9431900677966102, 0.5314713305084746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 67}], {
             RGBColor[
             0.9291661779661017, 0.7429200677966102, 0.5150885593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 75}], {
             RGBColor[
             0.9875753898305084, 0.9891301186440679, 0.8555714745762713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 133}], {
             RGBColor[
             0.9909587796610169, 0.9905292372881356, 0.7994999491525423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 178}], {
             RGBColor[
             0.977541906779661, 0.9422573220338983, 0.5688523474576271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 200}], {
             RGBColor[0.9584284491525423, 0.8692259830508475, 0.539166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 278}], {
             RGBColor[
             0.9431457711864406, 0.8063981355932204, 0.5267534745762712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 296}], {
             RGBColor[
             0.9812578389830509, 0.954792033898305, 0.5832880423728812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 320}], {
             RGBColor[
             0.9887031864406779, 0.9895964915254238, 0.8368809661016949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 330}], {
             RGBColor[
             0.9323652881355932, 0.9465740338983051, 0.9030601779661016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 347}], {
             RGBColor[
             0.8928651186440678, 0.9152723389830508, 0.8992409576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 367}], {
             RGBColor[
             0.9035749915254236, 0.5620949322033899, 0.4912042288135593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 398}], {
             RGBColor[
             0.9918264152542373, 0.989628372881356, 0.6935574322033898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 159}], {
             RGBColor[
             0.9546030508474576, 0.9656636101694915, 0.961729372881356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 250}], {
             RGBColor[
             0.9813270762711863, 0.9823411186440678, 0.7220449237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 265}], {
             RGBColor[
             0.9818698474576271, 0.9843128305084745, 0.8400573050847457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 321}], {
             RGBColor[
             0.9813270762711863, 0.9823411186440678, 0.7220449237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 325}], {
             RGBColor[
             0.9693975254237287, 0.9766973050847457, 0.936686186440678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 375}], {
             RGBColor[
             0.9784729745762711, 0.9731786779661017, 0.6714072966101695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 381}], {
             RGBColor[
             0.9818698474576271, 0.9843128305084745, 0.8400573050847457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 66}], {
             RGBColor[
             0.9909587796610169, 0.9905292372881356, 0.7994999491525425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 81}], {
             RGBColor[
             0.9943646186440678, 0.9911655932203389, 0.6869367881355932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 119}], {
             RGBColor[
             0.9818698474576271, 0.9843128305084745, 0.8400573050847457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[
             0.9797975000000001, 0.9431900677966102, 0.5314713305084746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 130}], {
             RGBColor[
             0.9868013389830508, 0.9879907288135594, 0.8317095762711864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 135}], {
             RGBColor[
             0.9935167881355933, 0.9893521694915255, 0.5946556694915254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 146}], {
             RGBColor[
             0.9943421694915254, 0.9919283559322034, 0.7434284237288136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 151}], {
             RGBColor[
             0.9909587796610169, 0.9905292372881356, 0.7994999491525425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 227}], {
             RGBColor[
             0.9937993983050848, 0.9899566440677967, 0.6254160423728812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 243}], {
             RGBColor[
             0.9818698474576271, 0.9843128305084745, 0.8400573050847457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 267}], {
             RGBColor[
             0.9937993983050848, 0.9899566440677967, 0.6254160423728812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 275}], {
             RGBColor[
             0.993214372881356, 0.9914619830508475, 0.7621189322033898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 311}], {
             RGBColor[
             0.9909587796610169, 0.9905292372881356, 0.7994999491525425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 317}], {
             RGBColor[
             0.9868013389830508, 0.9879907288135594, 0.8317095762711864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 326}], {
             RGBColor[
             0.9872293644067797, 0.9682594915254237, 0.560342720338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 344}], {
             RGBColor[
             0.9769383559322034, 0.9806349322033898, 0.8484050338983051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 346}], {
             RGBColor[
             0.9920865762711863, 0.9909956101694916, 0.7808094406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 383}], {
             RGBColor[
             0.993214372881356, 0.9914619830508475, 0.7621189322033898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 48}], {
             RGBColor[
             0.9697512711864407, 0.9760242881355932, 0.8941337796610169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 74}], {
             RGBColor[
             0.9909587796610169, 0.9905292372881356, 0.7994999491525423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 103}], {
             RGBColor[
             0.9909587796610169, 0.9905292372881356, 0.7994999491525423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 116}], {
             RGBColor[
             0.9479058728813559, 0.8275074745762712, 0.5306992881355932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 262}], {
             RGBColor[
             0.9689510254237288, 0.9109444915254237, 0.5476327118644068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 290}], {
             RGBColor[
             0.9849737711864406, 0.9673267457627119, 0.5977237372881355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 304}], {
             RGBColor[
             0.9088300338983051, 0.9278076610169492, 0.9008153644067797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 338}], {
             RGBColor[
             0.9918264152542373, 0.989628372881356, 0.6935574322033898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 52}], {
             RGBColor[
             0.938018940677966, 0.8380060508474576, 0.6025282372881355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 60}], {
             RGBColor[
             0.9330874491525423, 0.8343281525423728, 0.6108759661016949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 102}], {
             RGBColor[
             0.9551625932203389, 0.8479322372881355, 0.41029961864406783`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 105}], {
             RGBColor[
             0.9520393644067796, 0.8479003559322034, 0.5536231525423729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 128}], {
             RGBColor[
             0.9408780847457627, 0.8005611864406779, 0.28559453389830514`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 139}], {
             RGBColor[
             0.9545973728813559, 0.8467232881355932, 0.34877887288135584`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 199}], {
             RGBColor[
             0.938018940677966, 0.8380060508474576, 0.6025282372881355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 213}], {
             RGBColor[
             0.9281559576271186, 0.830650254237288, 0.6192236949152543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 215}], {
             RGBColor[
             0.8836241186440678, 0.5488618474576271, 0.2239507542372881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 259}], {
             RGBColor[
             0.9554452033898304, 0.8485367118644067, 0.44105999152542363`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 271}], {
             RGBColor[
             0.9270259152542373, 0.7483891016949151, 0.26014154237288134`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 287}], {
             RGBColor[
             0.9551625932203389, 0.8479322372881355, 0.41029961864406783`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 333}], {
             RGBColor[
             0.9371621525423728, 0.7880264745762711, 0.2711588389830508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 337}], {
             RGBColor[
             0.921764627118644, 0.727529847457627, 0.255908186440678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 345}], {
             RGBColor[
             0.938018940677966, 0.8380060508474576, 0.6025282372881355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 350}], {
             RGBColor[
             0.938018940677966, 0.8380060508474576, 0.6025282372881355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 353}], {
             RGBColor[
             0.9478819237288135, 0.8453618474576271, 0.585832779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 400}], {
             RGBColor[
             0.9483099491525424, 0.8256306101694915, 0.3144659237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 136}], {
             RGBColor[
             0.9636092457627118, 0.9230398305084746, 0.6136645169491526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 149}], {
             RGBColor[
             0.9738259745762712, 0.9297226101694915, 0.5544166525423728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 155}], {
             RGBColor[
             0.9715703813559322, 0.9287898644067797, 0.5917976694915255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 268}], {
             RGBColor[
             0.5683739830508474, 0.5873881779661017, 0.6120719237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 279}], {
             RGBColor[
             0.9271407627118644, 0.7460578813559322, 0.2629796694915254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 299}], {
             RGBColor[
             0.9476847288135593, 0.8297449830508474, 0.2796255508474576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 300}], {
             RGBColor[
             0.9537462627118644, 0.915684033898305, 0.6303599745762711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 371}], {
             RGBColor[
             0.9738259745762712, 0.9297226101694915, 0.5544166525423728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.9708790677966102, 0.9764906610169491, 0.8754432711864406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 86}], {
             RGBColor[
             0.948871313559322, 0.8969059152542371, 0.6235760338983051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 103}], {
             RGBColor[
             0.9708790677966102, 0.9764906610169491, 0.8754432711864406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 295}], {
             RGBColor[
             0.9723119237288136, 0.9767987457627119, 0.8310215000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 191}], {
             RGBColor[
             0.9937993983050848, 0.9899566440677967, 0.6254160423728812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 225}], {
             RGBColor[
             0.9946472288135593, 0.9917700677966101, 0.7176971610169492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 235}], {
             RGBColor[
             0.993214372881356, 0.9914619830508475, 0.7621189322033898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 261}], {
             RGBColor[
             0.9909452966101695, 0.9807942033898305, 0.5747784152542372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 327}], {
             RGBColor[
             0.9935167881355933, 0.9893521694915255, 0.5946556694915254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 335}], {
             RGBColor[
             0.9872293644067797, 0.9682594915254237, 0.560342720338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 349}], {
             RGBColor[
             0.9797975000000001, 0.9431900677966102, 0.5314713305084746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 355}], {
             RGBColor[
             0.9872293644067797, 0.9682594915254237, 0.560342720338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 127}], {
             RGBColor[
             0.9761040169491525, 0.929892593220339, 0.46054399999999995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 137}], {
             RGBColor[
             0.9909677457627118, 0.9800314406779661, 0.5182867796610169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 138}], {
             RGBColor[
             0.9581785847457627, 0.9655103898305084, 0.8114323389830508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 147}], {
             RGBColor[
             0.9932368220338983, 0.990699220338983, 0.7056272966101693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 164}], {
             RGBColor[
             0.945423813559322, 0.8065681186440679, 0.43288082203389827`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 197}], {
             RGBColor[
             0.9554452033898304, 0.8485367118644067, 0.44105999152542363`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 210}], {
             RGBColor[
             0.987251813559322, 0.9674967288135593, 0.5038510847457626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 217}], {
             RGBColor[
             0.9868237881355932, 0.9872279661016949, 0.775217940677966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 230}], {
             RGBColor[
             0.9932368220338983, 0.990699220338983, 0.7056272966101693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 242}], {
             RGBColor[
             0.9946696779661017, 0.9910073050847458, 0.6612055254237288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 254}], {
             RGBColor[
             0.9769608050847457, 0.9798721694915253, 0.7919133983050847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 258}], {
             RGBColor[
             0.9943870677966101, 0.9904028305084746, 0.6304451525423728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 328}], {
             RGBColor[
             0.9941044576271186, 0.9897983559322034, 0.599684779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 331}], {
             RGBColor[
             0.9932368220338983, 0.990699220338983, 0.7056272966101693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 79}], {
             RGBColor[
             0.977541906779661, 0.9422573220338983, 0.5688523474576271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 87}], {
             RGBColor[
             0.9384859067796609, 0.785238779661017, 0.5228651694915254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 126}], {
             RGBColor[
             0.9746827627118644, 0.979702186440678, 0.8857860508474575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 176}], {
             RGBColor[
             0.9886897033898305, 0.9798614576271187, 0.6121594322033899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 205}], {
             RGBColor[
             0.9887031864406779, 0.9895964915254238, 0.8368809661016949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 232}], {
             RGBColor[
             0.9479058728813559, 0.8275074745762712, 0.5306992881355932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 277}], {
             RGBColor[
             0.9431457711864406, 0.8063981355932204, 0.5267534745762712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 298}], {
             RGBColor[
             0.9849737711864406, 0.9673267457627119, 0.5977237372881355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 373}], {
             RGBColor[
             0.9920865762711863, 0.9909956101694916, 0.7808094406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 390}], {
             RGBColor[
             0.9909587796610169, 0.9905292372881356, 0.7994999491525423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 60}], {
             RGBColor[
             0.9546030508474576, 0.9656636101694915, 0.9617293728813558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 68}], {
             RGBColor[
             0.9772434152542373, 0.9804766440677966, 0.8226737711864407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 105}], {
             RGBColor[
             0.9735549661016949, 0.979235813559322, 0.904476559322034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 129}], {
             RGBColor[
             0.9769608050847457, 0.9798721694915253, 0.7919133983050847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 199}], {
             RGBColor[
             0.9595345423728813, 0.9693415084745762, 0.9533816440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 271}], {
             RGBColor[
             0.9485415169491525, 0.8797245593220339, 0.6109949491525424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 287}], {
             RGBColor[
             0.9766781949152542, 0.9792676949152542, 0.7611530254237289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 303}], {
             RGBColor[
             0.9769383559322034, 0.9806349322033898, 0.8484050338983051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 333}], {
             RGBColor[
             0.9586777542372881, 0.9193619322033898, 0.6220122457627119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 337}], {
             RGBColor[
             0.9432802288135593, 0.8588653050847458, 0.606761593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 345}], {
             RGBColor[
             0.9595345423728813, 0.9693415084745762, 0.9533816440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 353}], {
             RGBColor[
             0.9693975254237288, 0.9766973050847458, 0.9366861864406779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 391}], {
             RGBColor[
             0.9327576525423729, 0.8171467966101695, 0.5982948813559322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 69}], {
             RGBColor[
             0.9329290423728813, 0.7997153559322034, 0.586001338983051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 93}], {
             RGBColor[
             0.9221485593220338, 0.9398912542372881, 0.9623080423728814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 131}], {
             RGBColor[
             0.9818698474576271, 0.9843128305084745, 0.8400573050847457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 142}], {
             RGBColor[
             0.9813270762711863, 0.9823411186440678, 0.7220449237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 188}], {
             RGBColor[
             0.9784729745762711, 0.9731786779661017, 0.6714072966101695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 201}], {
             RGBColor[
             0.982174906779661, 0.9841545423728814, 0.8143260423728815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 264}], {
             RGBColor[
             0.964466033898305, 0.9730194067796609, 0.9450339152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 273}], {
             RGBColor[
             0.9813270762711863, 0.9823411186440678, 0.7220449237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 281}], {
             RGBColor[
             0.9636092457627118, 0.9230398305084746, 0.6136645169491526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[
             0.945683813559322, 0.958657627118644, 0.9645528559322034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 394}], {
             RGBColor[
             0.9796142542372881, 0.9833800847457628, 0.8774383220338984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 64}], {
             RGBColor[
             0.9920865762711863, 0.9909956101694916, 0.7808094406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 83}], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 123}], {
             RGBColor[
             0.9738259745762712, 0.9297226101694915, 0.5544166525423728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 161}], {
             RGBColor[
             0.9689510254237288, 0.9109444915254237, 0.5476327118644068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 196}], {
             RGBColor[
             0.964819779661017, 0.9723463898305085, 0.9024815084745763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 198}], {
             RGBColor[
             0.924506313559322, 0.7217607118644067, 0.5112002542372881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 206}], {
             RGBColor[
             0.9812578389830509, 0.954792033898305, 0.5832880423728812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 214}], {
             RGBColor[
             0.9875753898305084, 0.9891301186440679, 0.8555714745762713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 310}], {
             RGBColor[
             0.9291661779661017, 0.7429200677966102, 0.5150885593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 332}], {
             RGBColor[
             0.9912611949152542, 0.9884194237288135, 0.6320366864406779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 389}], {
             RGBColor[
             0.9697512711864407, 0.9760242881355932, 0.8941337796610169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 57}], {
             RGBColor[
             0.9644660338983051, 0.973019406779661, 0.9450339152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 68}], {
             RGBColor[
             0.9723119237288136, 0.9767987457627119, 0.8310215000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 72}], {
             RGBColor[
             0.9717467033898305, 0.9755897966101694, 0.7695007542372881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 83}], {
             RGBColor[
             0.9697512711864407, 0.9760242881355932, 0.8941337796610169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 123}], {
             RGBColor[
             0.9537462627118644, 0.915684033898305, 0.6303599745762711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 161}], {
             RGBColor[
             0.948871313559322, 0.8969059152542371, 0.6235760338983051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 196}], {
             RGBColor[
             0.9447400677966101, 0.9583078135593219, 0.9784248305084746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 236}], {
             RGBColor[
             0.9708790677966102, 0.9764906610169491, 0.8754432711864406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 262}], {
             RGBColor[
             0.948871313559322, 0.8969059152542371, 0.6235760338983051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 284}], {
             RGBColor[
             0.9723119237288136, 0.9767987457627119, 0.8310215000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 334}], {
             RGBColor[
             0.9648940593220339, 0.9532881694915254, 0.6736670593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 366}], {
             RGBColor[
             0.9330874491525423, 0.8343281525423728, 0.6108759661016949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 397}], {
             RGBColor[
             0.8918517542372881, 0.612287881355932, 0.575149720338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 65}], {
             RGBColor[
             0.9454013644067797, 0.8073308813559323, 0.4893724576271187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 100}], {
             RGBColor[
             0.9382885593220339, 0.7836620169491526, 0.30628675423728813`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 174}], {
             RGBColor[
             0.9012206610169492, 0.6438427457627119, 0.2392623050847458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 198}], {
             RGBColor[
             0.8778211016949153, 0.5380959830508475, 0.21976327118644068`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 203}], {
             RGBColor[
             0.9445759830508476, 0.8047546949152543, 0.3405997033898305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 206}], {
             RGBColor[
             0.9345726271186441, 0.7711273050847458, 0.2918510593220338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 266}], {
             RGBColor[
             0.9454013644067797, 0.8073308813559323, 0.4893724576271187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 341}], {
             RGBColor[
             0.8778211016949153, 0.5380959830508475, 0.21976327118644068`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 358}], {
             RGBColor[
             0.9308566949152544, 0.758592593220339, 0.2774153644067797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 68}], {
             RGBColor[
             0.9871063983050847, 0.9878324406779662, 0.8059783135593221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 72}], {
             RGBColor[
             0.9865411779661017, 0.9866234915254237, 0.7444575677966101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 86}], {
             RGBColor[
             0.9636657881355932, 0.9079396101694914, 0.598532847457627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 108}], {
             RGBColor[
             0.9845457457627118, 0.9870579830508475, 0.869090593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 236}], {
             RGBColor[
             0.9856735423728813, 0.9875243559322034, 0.8504000847457627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 262}], {
             RGBColor[
             0.9636657881355932, 0.9079396101694914, 0.598532847457627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 284}], {
             RGBColor[
             0.9871063983050847, 0.9878324406779662, 0.8059783135593221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 297}], {
             RGBColor[
             0.9192210762711864, 0.7187558305084746, 0.5621003898305084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 325}], {
             RGBColor[
             0.9743290169491525, 0.9803752033898305, 0.9283384576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 376}], {
             RGBColor[
             0.9834179491525423, 0.9865916101694916, 0.8877811016949153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 397}], {
             RGBColor[
             0.9066462288135593, 0.6233215762711863, 0.550106533898305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 124}], {
             RGBColor[
             0.8912859152542374, 0.5142893898305085, 0.24186611864406782`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 152}], {
             RGBColor[
             0.9525307033898305, 0.9245408474576271, 0.6531433983050847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 156}], {
             RGBColor[
             0.9764141101694915, 0.9417909491525425, 0.5875428559322036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 160}], {
             RGBColor[
             0.9797975000000001, 0.9431900677966102, 0.5314713305084746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 179}], {
             RGBColor[
             0.9525307033898305, 0.9245408474576271, 0.6531433983050847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 181}], {
             RGBColor[
             0.9764006271186441, 0.9320559152542374, 0.36282132203389833`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 220}], {
             RGBColor[
             0.9764141101694915, 0.9417909491525425, 0.5875428559322036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[
             0.9786697033898306, 0.9427236949152542, 0.5501618389830508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 352}], {
             RGBColor[
             0.9795373389830508, 0.9418228305084746, 0.44421932203389836`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 396}], {
             RGBColor[
             0.9798199491525423, 0.9424273050847458, 0.4749796949152542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 132}], {
             RGBColor[
             0.9926914067796611, 0.9867759830508475, 0.4458829152542371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 149}], {
             RGBColor[
             0.9912611949152542, 0.9884194237288135, 0.6320366864406779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 155}], {
             RGBColor[
             0.9890056016949152, 0.9874866779661018, 0.6694177033898304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 164}], {
             RGBColor[
             0.9445759830508476, 0.8047546949152543, 0.3405997033898305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 210}], {
             RGBColor[
             0.9864039830508475, 0.9656833050847458, 0.4115699661016948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 230}], {
             RGBColor[
             0.9923889915254238, 0.9888857966101695, 0.6133461779661016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 258}], {
             RGBColor[
             0.9935392372881355, 0.988589406779661, 0.5381640338983049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 264}], {
             RGBColor[
             0.9761129745762711, 0.9780587457627119, 0.6996322796610168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 268}], {
             RGBColor[
             0.5858092033898306, 0.6460849915254238, 0.6896919576271185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 279}], {
             RGBColor[
             0.9445759830508476, 0.8047546949152543, 0.3405997033898305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 299}], {
             RGBColor[
             0.9651199491525424, 0.8884417966101694, 0.3572455847457626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 300}], {
             RGBColor[
             0.9711814830508474, 0.9743808474576271, 0.7079800084745762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 328}], {
             RGBColor[
             0.993256627118644, 0.9879849322033898, 0.5074036610169491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 394}], {
             RGBColor[
             0.9912611949152542, 0.9884194237288135, 0.6320366864406779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 68}], {
             RGBColor[
             0.9723119237288136, 0.9767987457627119, 0.8310215000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 72}], {
             RGBColor[
             0.9717467033898305, 0.9755897966101694, 0.7695007542372881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 102}], {
             RGBColor[
             0.9717467033898305, 0.9755897966101694, 0.7695007542372881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 105}], {
             RGBColor[
             0.9686234745762712, 0.9755579152542373, 0.9128242881355932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 108}], {
             RGBColor[
             0.9697512711864407, 0.9760242881355932, 0.8941337796610169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 139}], {
             RGBColor[
             0.9711814830508474, 0.9743808474576271, 0.7079800084745762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 297}], {
             RGBColor[
             0.9044266016949152, 0.7077221355932203, 0.5871435762711864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 333}], {
             RGBColor[
             0.9537462627118644, 0.915684033898305, 0.6303599745762711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 337}], {
             RGBColor[
             0.9383487372881356, 0.855187406779661, 0.6151093220338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 345}], {
             RGBColor[
             0.9546030508474576, 0.9656636101694915, 0.9617293728813558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 353}], {
             RGBColor[
             0.9644660338983051, 0.973019406779661, 0.9450339152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 70}], {
             RGBColor[
             0.9763866271186441, 0.9304970677966102, 0.491304372881356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 90}], {
             RGBColor[
             0.9636092457627118, 0.9230398305084746, 0.6136645169491526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 95}], {
             RGBColor[
             0.9271407627118644, 0.7460578813559322, 0.2629796694915254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 148}], {
             RGBColor[
             0.9615368983050847, 0.8819170677966102, 0.30507854237288135`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 228}], {
             RGBColor[
             0.9726846949152542, 0.9195212033898306, 0.34838562711864407`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 282}], {
             RGBColor[
             0.9752561864406779, 0.9280791694915254, 0.3682628813559321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 285}], {
             RGBColor[
             0.975821406779661, 0.9292881186440678, 0.42978362711864404`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 301}], {
             RGBColor[
             0.9578209661016949, 0.8693823559322034, 0.2906428474576271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 382}], {
             RGBColor[
             0.9763866271186441, 0.9304970677966102, 0.491304372881356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 91}], {
             RGBColor[
             0.9832532711864407, 0.9543575423728813, 0.45865501694915245`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 111}], {
             RGBColor[
             0.9943870677966102, 0.9904028305084747, 0.630445152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 117}], {
             RGBColor[
             0.9941044576271186, 0.9897983559322034, 0.599684779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 223}], {
             RGBColor[
             0.9895708220338983, 0.9886956271186441, 0.7309384491525424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 247}], {
             RGBColor[
             0.9578959745762712, 0.9649059152542373, 0.780671966101695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 256}], {
             RGBColor[
             0.9139268983050848, 0.6258919661016947, 0.37457337288135595`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 319}], {
             RGBColor[
             0.9906986186440678, 0.9891620000000001, 0.7122479406779663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 323}], {
             RGBColor[
             0.9795373389830508, 0.9418228305084746, 0.44421932203389836`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 362}], {
             RGBColor[
             0.9941044576271186, 0.9897983559322034, 0.599684779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 395}], {
             RGBColor[
             0.9358214745762712, 0.7636449322033898, 0.39434383898305087`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 103}], {
             RGBColor[
             0.9920865762711865, 0.9909956101694916, 0.780809440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 295}], {
             RGBColor[
             0.9935194322033898, 0.9913036949152543, 0.7363876694915255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 88}], {
             RGBColor[
             0.9872293644067797, 0.9682594915254237, 0.560342720338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 101}], {
             RGBColor[
             0.9606840423728813, 0.8701587288135594, 0.5017849830508475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 115}], {
             RGBColor[
             0.9909587796610169, 0.9905292372881356, 0.7994999491525425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 120}], {
             RGBColor[
             0.9835134322033898, 0.9557247796610169, 0.5459070254237287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 123}], {
             RGBColor[
             0.9760815677966102, 0.9306553559322034, 0.5170356355932203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 140}], {
             RGBColor[
             0.9797975000000001, 0.9431900677966102, 0.5314713305084746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 161}], {
             RGBColor[
             0.9712066186440678, 0.9118772372881355, 0.5102516949152542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 193}], {
             RGBColor[
             0.993214372881356, 0.9914619830508475, 0.7621189322033898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 195}], {
             RGBColor[
             0.9501614661016949, 0.8284402203389831, 0.49331827118644067`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 214}], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 233}], {
             RGBColor[
             0.9943646186440678, 0.9911655932203389, 0.6869367881355932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 257}], {
             RGBColor[
             0.9835134322033898, 0.9557247796610169, 0.5459070254237287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 283}], {
             RGBColor[
             0.9835134322033898, 0.9557247796610169, 0.5459070254237287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 312}], {
             RGBColor[
             0.9720068644067796, 0.9769570338983051, 0.8567527627118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 332}], {
             RGBColor[
             0.9935167881355933, 0.9893521694915255, 0.5946556694915254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 356}], {
             RGBColor[
             0.9935167881355933, 0.9893521694915255, 0.5946556694915254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 360}], {
             RGBColor[
             0.9943421694915254, 0.9919283559322034, 0.7434284237288136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 380}], {
             RGBColor[
             0.9818698474576271, 0.9843128305084745, 0.8400573050847457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 389}], {
             RGBColor[
             0.9720068644067796, 0.9769570338983051, 0.8567527627118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 100}], {
             RGBColor[
             0.9872293644067797, 0.9682594915254237, 0.560342720338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 167}], {
             RGBColor[
             0.9909452966101695, 0.9807942033898305, 0.5747784152542372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 174}], {
             RGBColor[
             0.9501614661016949, 0.8284402203389831, 0.49331827118644067`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 198}], {
             RGBColor[
             0.9267619067796611, 0.7226934576271187, 0.4738192372881356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 203}], {
             RGBColor[
             0.9935167881355933, 0.9893521694915255, 0.5946556694915254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 206}], {
             RGBColor[
             0.9835134322033898, 0.9557247796610169, 0.5459070254237287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 211}], {
             RGBColor[
             0.9943421694915254, 0.9919283559322034, 0.7434284237288136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 266}], {
             RGBColor[
             0.9943421694915254, 0.9919283559322034, 0.7434284237288136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 313}], {
             RGBColor[
             0.9760815677966102, 0.9306553559322034, 0.5170356355932203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 329}], {
             RGBColor[
             0.9868013389830508, 0.9879907288135594, 0.8317095762711864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 340}], {
             RGBColor[
             0.9909452966101695, 0.9807942033898305, 0.5747784152542372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 341}], {
             RGBColor[
             0.9267619067796611, 0.7226934576271187, 0.4738192372881356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 358}], {
             RGBColor[
             0.9797975000000001, 0.9431900677966102, 0.5314713305084746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 81}], {
             RGBColor[
             0.9909812288135593, 0.9897664745762712, 0.7430083135593221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 119}], {
             RGBColor[
             0.9784864576271186, 0.9829137118644068, 0.8961288305084747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 130}], {
             RGBColor[
             0.9834179491525423, 0.9865916101694916, 0.8877811016949153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 146}], {
             RGBColor[
             0.9909587796610169, 0.9905292372881356, 0.7994999491525425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 151}], {
             RGBColor[
             0.9875753898305084, 0.9891301186440679, 0.8555714745762714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 158}], {
             RGBColor[
             0.9801300423728814, 0.954325661016949, 0.6019785508474575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 243}], {
             RGBColor[
             0.9784864576271186, 0.9829137118644068, 0.8961288305084747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 267}], {
             RGBColor[
             0.9904160084745762, 0.9885575254237289, 0.6814875677966101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 275}], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 311}], {
             RGBColor[
             0.9875753898305084, 0.9891301186440679, 0.8555714745762714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 317}], {
             RGBColor[
             0.9834179491525423, 0.9865916101694916, 0.8877811016949153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 344}], {
             RGBColor[
             0.9735549661016949, 0.979235813559322, 0.904476559322034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 346}], {
             RGBColor[
             0.9887031864406779, 0.9895964915254238, 0.8368809661016949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 354}], {
             RGBColor[
             0.9764141101694915, 0.9417909491525425, 0.5875428559322036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 75}], {
             RGBColor[
             0.9269105847457627, 0.7419873220338984, 0.5524695762711864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 126}], {
             RGBColor[
             0.9140179576271186, 0.7325593898305085, 0.5826841525423729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 133}], {
             RGBColor[
             0.9302939745762713, 0.7433864406779662, 0.4963980508474576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 200}], {
             RGBColor[
             0.8977636440677966, 0.6220831864406781, 0.2360641016949153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 320}], {
             RGBColor[
             0.9280383813559322, 0.7424536949152543, 0.5337790677966103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 347}], {
             RGBColor[
             0.8322003135593221, 0.6681295423728815, 0.5961390593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 398}], {
             RGBColor[
             0.9311616101694915, 0.7424855762711865, 0.3904555338983051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 72}], {
             RGBColor[
             0.9943870677966102, 0.9904028305084747, 0.630445152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 236}], {
             RGBColor[
             0.9935194322033898, 0.9913036949152543, 0.7363876694915255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 262}], {
             RGBColor[
             0.9715116779661017, 0.9117189491525424, 0.4845204322033899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 284}], {
             RGBColor[
             0.9949522881355932, 0.991611779661017, 0.6919658983050849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 333}], {
             RGBColor[
             0.9763866271186441, 0.9304970677966102, 0.491304372881356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 334}], {
             RGBColor[
             0.9875344237288135, 0.9681012033898305, 0.5346114576271187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 337}], {
             RGBColor[
             0.9609891016949152, 0.8700004406779662, 0.4760537203389832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 376}], {
             RGBColor[
             0.9912638389830508, 0.9903709491525424, 0.7737686864406781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 391}], {
             RGBColor[
             0.9504665254237288, 0.8282819322033899, 0.46758700847457635`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 397}], {
             RGBColor[
             0.9144921186440678, 0.6271009152542371, 0.4360941186440679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 93}], {
             RGBColor[
             0.8856800762711865, 0.7629093050847457, 0.6116231949152542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 131}], {
             RGBColor[
             0.9454013644067797, 0.8073308813559323, 0.4893724576271187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 142}], {
             RGBColor[
             0.944858593220339, 0.8053591694915255, 0.37136007627118633`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 188}], {
             RGBColor[
             0.9420044915254238, 0.7961967288135594, 0.3207224491525424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 201}], {
             RGBColor[
             0.9457064237288135, 0.8071725932203391, 0.46364119491525435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 273}], {
             RGBColor[
             0.944858593220339, 0.8053591694915255, 0.37136007627118633`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 281}], {
             RGBColor[
             0.9271407627118644, 0.7460578813559322, 0.2629796694915254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 293}], {
             RGBColor[
             0.9092153305084746, 0.7816756779661018, 0.6138680084745762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 394}], {
             RGBColor[
             0.9431457711864406, 0.8063981355932204, 0.5267534745762712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 90}], {
             RGBColor[
             0.982174906779661, 0.9841545423728814, 0.8143260423728815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 95}], {
             RGBColor[
             0.9457064237288135, 0.8071725932203391, 0.46364119491525435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 177}], {
             RGBColor[
             0.9723119237288136, 0.9767987457627119, 0.8310215000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 228}], {
             RGBColor[
             0.9912503559322035, 0.9806359152542373, 0.549047152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 246}], {
             RGBColor[
             0.9662503898305085, 0.8908596949152543, 0.4802870762711865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 260}], {
             RGBColor[
             0.9838184915254238, 0.9555664915254236, 0.5201757627118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 285}], {
             RGBColor[
             0.9943870677966102, 0.9904028305084747, 0.630445152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 110}], {
             RGBColor[
             0.9834179491525423, 0.9865916101694916, 0.8877811016949153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 131}], {
             RGBColor[
             0.9909587796610169, 0.9905292372881356, 0.7994999491525425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 201}], {
             RGBColor[
             0.9912638389830508, 0.9903709491525424, 0.7737686864406781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 212}], {
             RGBColor[
             0.9547727457627118, 0.9648740338983051, 0.9239955000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 271}], {
             RGBColor[
             0.9625619406779661, 0.8896188644067797, 0.5620898644067798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 273}], {
             RGBColor[
             0.9904160084745762, 0.9885575254237289, 0.6814875677966101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 287}], {
             RGBColor[
             0.9906986186440678, 0.9891620000000001, 0.7122479406779663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 289}], {
             RGBColor[
             0.9906986186440678, 0.9891620000000001, 0.7122479406779663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 292}], {
             RGBColor[
             0.9875753898305084, 0.9891301186440679, 0.8555714745762714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 303}], {
             RGBColor[
             0.9909587796610169, 0.9905292372881356, 0.7994999491525425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 385}], {
             RGBColor[
             0.9838459745762711, 0.966860372881356, 0.6164142457627119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 400}], {
             RGBColor[
             0.9838459745762711, 0.966860372881356, 0.6164142457627119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 86}], {
             RGBColor[
             0.9709464576271186, 0.9105099999999999, 0.422999686440678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 108}], {
             RGBColor[
             0.9918264152542373, 0.989628372881356, 0.6935574322033898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 236}], {
             RGBColor[
             0.9929542118644068, 0.9900947457627118, 0.6748669237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 262}], {
             RGBColor[
             0.9709464576271186, 0.9105099999999999, 0.422999686440678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 284}], {
             RGBColor[
             0.9943870677966102, 0.9904028305084747, 0.630445152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 297}], {
             RGBColor[
             0.9265017457627118, 0.721326220338983, 0.3865672288135593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 325}], {
             RGBColor[
             0.9816096864406779, 0.982945593220339, 0.7528052966101695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 333}], {
             RGBColor[
             0.975821406779661, 0.9292881186440678, 0.42978362711864404`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 337}], {
             RGBColor[
             0.9604238813559323, 0.8687914915254238, 0.41453297457627125`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 376}], {
             RGBColor[
             0.9906986186440678, 0.9891620000000001, 0.7122479406779663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 397}], {
             RGBColor[
             0.9139268983050848, 0.6258919661016947, 0.37457337288135595`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.9345726271186441, 0.7711273050847458, 0.2918510593220338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 162}], {
             RGBColor[
             0.9838184915254238, 0.9555664915254236, 0.5201757627118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 183}], {
             RGBColor[
             0.9764006271186441, 0.9320559152542371, 0.36282132203389816`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 189}], {
             RGBColor[
             0.9689687627118644, 0.9069864915254237, 0.33394993220338975`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 207}], {
             RGBColor[
             0.9445940169491525, 0.8130958983050847, 0.30003022881355923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 280}], {
             RGBColor[
             0.9838184915254238, 0.9555664915254236, 0.5201757627118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 291}], {
             RGBColor[
             0.9790022457627119, 0.9538592881355932, 0.6206690593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 336}], {
             RGBColor[
             0.9710411101694915, 0.948109254237288, 0.642535906779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 368}], {
             RGBColor[
             0.9835134322033898, 0.9557247796610169, 0.5459070254237287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 387}], {
             RGBColor[
             0.9498553050847458, 0.8339551525423728, 0.30426358474576265`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 116}], {
             RGBColor[
             0.9490336694915255, 0.8279738474576271, 0.5120087796610169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 118}], {
             RGBColor[
             0.9807420508474576, 0.9838464576271186, 0.8587478135593221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 141}], {
             RGBColor[
             0.9786697033898306, 0.9427236949152542, 0.5501618389830508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 179}], {
             RGBColor[0.9659475762711864, 0.9728127627118643, 0.883791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 209}], {
             RGBColor[
             0.9909587796610169, 0.9905292372881356, 0.7994999491525423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 286}], {
             RGBColor[
             0.9595562457627118, 0.8696923559322034, 0.5204754915254237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 290}], {
             RGBColor[
             0.9861015677966102, 0.9677931186440678, 0.5790332288135592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 304}], {
             RGBColor[
             0.9099578305084746, 0.9282740338983051, 0.8821248559322034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 338}], {
             RGBColor[
             0.9929542118644068, 0.9900947457627118, 0.6748669237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 386}], {
             RGBColor[
             0.9926716016949153, 0.9894902711864407, 0.6441065508474575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 126}], {
             RGBColor[
             0.9724271694915254, 0.9787694406779661, 0.9231670677966102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 133}], {
             RGBColor[
             0.9887031864406779, 0.9895964915254238, 0.8368809661016949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 178}], {
             RGBColor[
             0.975286313559322, 0.9413245762711865, 0.6062333644067797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 200}], {
             RGBColor[
             0.9561728559322034, 0.8682932372881357, 0.5765470169491526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 296}], {
             RGBColor[
             0.9790022457627119, 0.9538592881355932, 0.6206690593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 320}], {
             RGBColor[
             0.9864475932203389, 0.9886637457627119, 0.8742619830508476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 330}], {
             RGBColor[
             0.9301096949152542, 0.9456412881355932, 0.9404411949152542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 347}], {
             RGBColor[
             0.8906095254237288, 0.9143395932203391, 0.9366219745762712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 398}], {
             RGBColor[
             0.9895708220338983, 0.9886956271186441, 0.7309384491525424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 78}], {
             RGBColor[
             0.970663847457627, 0.9099055254237287, 0.39223931355932184`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 80}], {
             RGBColor[
             0.9636657881355932, 0.9079396101694914, 0.598532847457627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.9603778813559322, 0.875673661016949, 0.3127302966101694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 117}], {
             RGBColor[
             0.9712290677966101, 0.9111144745762711, 0.4537600593220338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.970663847457627, 0.9099055254237287, 0.39223931355932184`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 187}], {
             RGBColor[
             0.9678232288135593, 0.9104781186440678, 0.5663232203389832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 208}], {
             RGBColor[
             0.8952297457627119, 0.5793238474576272, 0.2326497372881356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 239}], {
             RGBColor[
             0.9712066186440678, 0.9118772372881355, 0.5102516949152542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 269}], {
             RGBColor[
             0.9350205847457627, 0.886222033898305, 0.6347472457627119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 323}], {
             RGBColor[
             0.9566619491525423, 0.8631389491525423, 0.2982946016949153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 365}], {
             RGBColor[
             0.964093813559322, 0.8882083728813559, 0.32716599152542364`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 377}], {
             RGBColor[
             0.9322872033898304, 0.7692483559322032, 0.2643748983050847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 388}], {
             RGBColor[
             0.8910515084745763, 0.5472080847457624, 0.22864865254237282`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 395}], {
             RGBColor[
             0.9129460847457627, 0.6849610508474575, 0.24841911864406777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 78}], {
             RGBColor[
             0.9792547288135593, 0.9412183559322034, 0.4134589491525423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 80}], {
             RGBColor[
             0.9722566694915254, 0.9392524406779661, 0.6197524830508474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 96}], {
             RGBColor[
             0.9689687627118644, 0.9069864915254237, 0.33394993220338975`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 182}], {
             RGBColor[
             0.9792547288135593, 0.9412183559322034, 0.4134589491525423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 187}], {
             RGBColor[
             0.9764141101694915, 0.9417909491525425, 0.5875428559322036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 244}], {
             RGBColor[
             0.975286313559322, 0.9413245762711865, 0.6062333644067797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 302}], {
             RGBColor[
             0.9615368983050847, 0.8819170677966102, 0.30507854237288135`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 377}], {
             RGBColor[
             0.9408780847457627, 0.8005611864406779, 0.28559453389830514`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 388}], {
             RGBColor[
             0.8996423898305085, 0.5785209152542371, 0.24986828813559323`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 80}], {
             RGBColor[
             0.9862585677966101, 0.9860190169491526, 0.7136971949152541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 96}], {
             RGBColor[
             0.9829706610169491, 0.9537530677966102, 0.42789464406779637`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 104}], {
             RGBColor[
             0.9937993983050848, 0.9899566440677967, 0.6254160423728812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 182}], {
             RGBColor[
             0.993256627118644, 0.9879849322033899, 0.5074036610169489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 187}], {
             RGBColor[
             0.9904160084745762, 0.9885575254237289, 0.6814875677966101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 208}], {
             RGBColor[
             0.9178225254237289, 0.6574032542372883, 0.3478140847457626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 302}], {
             RGBColor[
             0.9755387966101694, 0.9286836440677966, 0.399023254237288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 377}], {
             RGBColor[
             0.9548799830508474, 0.8473277627118644, 0.3795392457627117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 388}], {
             RGBColor[
             0.9136442881355932, 0.6252874915254236, 0.3438129999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 87}], {
             RGBColor[
             0.9261968305084747, 0.7374332372881356, 0.2735270593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 126}], {
             RGBColor[
             0.9623936864406779, 0.9318966440677966, 0.6364479406779662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 176}], {
             RGBColor[
             0.9764006271186441, 0.9320559152542374, 0.36282132203389833`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 205}], {
             RGBColor[
             0.9764141101694915, 0.9417909491525425, 0.5875428559322036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 232}], {
             RGBColor[
             0.9356167966101696, 0.7797019322033898, 0.2813611779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[
             0.9308566949152544, 0.758592593220339, 0.2774153644067797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 298}], {
             RGBColor[
             0.9726846949152543, 0.9195212033898306, 0.34838562711864407`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 373}], {
             RGBColor[
             0.9797975000000001, 0.9431900677966102, 0.5314713305084746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 390}], {
             RGBColor[
             0.9786697033898306, 0.9427236949152542, 0.5501618389830508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 96}], {
             RGBColor[
             0.9759726016949153, 0.9517871525423729, 0.6341881779661016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 104}], {
             RGBColor[
             0.9868013389830508, 0.9879907288135594, 0.8317095762711864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 182}], {
             RGBColor[
             0.9862585677966101, 0.9860190169491526, 0.7136971949152541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 187}], {
             RGBColor[
             0.9834179491525423, 0.9865916101694916, 0.8877811016949153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 244}], {
             RGBColor[
             0.9822901525423728, 0.9861252372881357, 0.9064716101694915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 302}], {
             RGBColor[
             0.9685407372881356, 0.9267177288135593, 0.6053167881355932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 377}], {
             RGBColor[
             0.9478819237288135, 0.8453618474576271, 0.5858327796610169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 388}], {
             RGBColor[
             0.9066462288135593, 0.6233215762711863, 0.550106533898305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 119}], {
             RGBColor[
             0.9818922966101694, 0.9835500677966101, 0.7835656694915254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 128}], {
             RGBColor[
             0.9798199491525423, 0.9424273050847458, 0.4749796949152542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.9868237881355932, 0.9872279661016949, 0.775217940677966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 135}], {
             RGBColor[
             0.9935392372881355, 0.988589406779661, 0.5381640338983049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 146}], {
             RGBColor[
             0.9943646186440678, 0.9911655932203389, 0.6869367881355932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 166}], {
             RGBColor[
             0.9111080762711865, 0.9279776440677966, 0.8069427118644068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 227}], {
             RGBColor[
             0.993821847457627, 0.9891938813559322, 0.5689244067796608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 243}], {
             RGBColor[
             0.9818922966101694, 0.9835500677966101, 0.7835656694915254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[
             0.993821847457627, 0.9891938813559322, 0.5689244067796608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 275}], {
             RGBColor[
             0.9932368220338983, 0.990699220338983, 0.7056272966101693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 311}], {
             RGBColor[
             0.9909812288135593, 0.9897664745762712, 0.7430083135593221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 326}], {
             RGBColor[
             0.987251813559322, 0.9674967288135593, 0.5038510847457626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 344}], {
             RGBColor[
             0.9769608050847457, 0.9798721694915253, 0.7919133983050847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 346}], {
             RGBColor[
             0.9921090254237288, 0.9902328474576272, 0.7243178050847456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 363}], {
             RGBColor[
             0.9670978220338983, 0.972516372881356, 0.8086088559322033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 383}], {
             RGBColor[
             0.9932368220338983, 0.990699220338983, 0.7056272966101693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 172}], {
             RGBColor[
             0.9002082288135593, 0.6765194067796609, 0.5831518898305085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 194}], {
             RGBColor[
             0.922283372881356, 0.6901234915254237, 0.3825755423728814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 233}], {
             RGBColor[
             0.9225659830508475, 0.690727966101695, 0.4133359152542372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 256}], {
             RGBColor[
             0.8423884237288135, 0.32682157627118624`, 0.18822450847457622`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 257}], {
             RGBColor[
             0.9117147966101695, 0.6552871525423729, 0.2723061525423728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 310}], {
             RGBColor[
             0.8596231355932203, 0.443415186440678, 0.20410666949152545`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 316}], {
             RGBColor[
             0.9220007627118644, 0.6895190169491525, 0.35181516949152525`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 399}], {
             RGBColor[
             0.8507448983050847, 0.3910531016949153, 0.1962266779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 118}], {
             RGBColor[
             0.9796142542372881, 0.9833800847457628, 0.8774383220338984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 123}], {
             RGBColor[
             0.9738259745762712, 0.9297226101694915, 0.5544166525423728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 141}], {
             RGBColor[
             0.977541906779661, 0.9422573220338983, 0.5688523474576271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 161}], {
             RGBColor[
             0.9689510254237288, 0.9109444915254237, 0.5476327118644068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 196}], {
             RGBColor[
             0.964819779661017, 0.9723463898305085, 0.9024815084745763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 214}], {
             RGBColor[
             0.9875753898305084, 0.9891301186440679, 0.8555714745762713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 286}], {
             RGBColor[0.9584284491525423, 0.8692259830508475, 0.539166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 332}], {
             RGBColor[
             0.9912611949152542, 0.9884194237288135, 0.6320366864406779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 334}], {
             RGBColor[
             0.9849737711864406, 0.9673267457627119, 0.5977237372881355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 366}], {
             RGBColor[
             0.9531671610169491, 0.8483667288135592, 0.5349326440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 125}], {
             RGBColor[
             0.9923889915254238, 0.9888857966101695, 0.6133461779661016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 184}], {
             RGBColor[
             0.993256627118644, 0.9879849322033898, 0.5074036610169491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 185}], {
             RGBColor[
             0.9826880508474576, 0.953148593220339, 0.3971342711864405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 190}], {
             RGBColor[
             0.9901333983050847, 0.9879530508474577, 0.6507271949152542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 252}], {
             RGBColor[
             0.9703812372881355, 0.9093010508474575, 0.361478940677966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 270}], {
             RGBColor[
             0.9761129745762711, 0.9780587457627119, 0.6996322796610168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 274}], {
             RGBColor[
             0.9926914067796611, 0.9867759830508475, 0.4458829152542371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 288}], {
             RGBColor[
             0.9091834406779662, 0.5925672542372881, 0.30905154237288124`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 318}], {
             RGBColor[
             0.9175399152542374, 0.6567987796610171, 0.31705371186440673`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 168}], {
             RGBColor[
             0.9763866271186441, 0.9304970677966102, 0.491304372881356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 238}], {
             RGBColor[
             0.9738259745762712, 0.9297226101694915, 0.5544166525423728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 379}], {
             RGBColor[
             0.9224808983050847, 0.7248985254237288, 0.25909136440677966`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 236}], {
             RGBColor[
             0.9700788220338983, 0.9114108644067795, 0.5289422033898303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 262}], {
             RGBColor[
             0.9480710677966101, 0.8318261186440676, 0.27707496610169485`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 265}], {
             RGBColor[
             0.9712066186440678, 0.9118772372881355, 0.5102516949152542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 297}], {
             RGBColor[
             0.9036263559322033, 0.6426423389830507, 0.24064250847457624`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 325}], {
             RGBColor[
             0.9587342966101694, 0.9042617118644067, 0.6068805762711864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 376}], {
             RGBColor[
             0.9678232288135593, 0.9104781186440678, 0.5663232203389832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 397}], {
             RGBColor[
             0.8910515084745763, 0.5472080847457624, 0.22864865254237282`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 176}], {
             RGBColor[
             0.9373446271186441, 0.775037372881356, 0.3168341440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 205}], {
             RGBColor[
             0.9373581101694914, 0.7847724067796611, 0.5415556779661018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 232}], {
             RGBColor[
             0.8965607966101695, 0.6226833898305084, 0.23537400000000003`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 277}], {
             RGBColor[
             0.8918006949152543, 0.6015740508474576, 0.23142818644067797`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 373}], {
             RGBColor[0.9407415, 0.7861715254237288, 0.48548415254237287`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 390}], {
             RGBColor[
             0.9396137033898305, 0.7857051525423728, 0.5041746610169491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 89}], {
             RGBColor[
             0.9382885593220339, 0.7836620169491526, 0.30628675423728813`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 120}], {
             RGBColor[
             0.9764006271186441, 0.9320559152542371, 0.36282132203389816`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 140}], {
             RGBColor[
             0.9726846949152543, 0.9195212033898306, 0.34838562711864407`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 189}], {
             RGBColor[
             0.9726846949152543, 0.9195212033898306, 0.34838562711864407`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 195}], {
             RGBColor[
             0.9430486610169492, 0.8047713559322034, 0.3102325677966101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 233}], {
             RGBColor[
             0.987251813559322, 0.9674967288135593, 0.5038510847457626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 255}], {
             RGBColor[
             0.9382885593220339, 0.7836620169491526, 0.30628675423728813`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 257}], {
             RGBColor[
             0.9764006271186441, 0.9320559152542371, 0.36282132203389816`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 263}], {
             RGBColor[
             0.9838459745762711, 0.966860372881356, 0.6164142457627119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 336}], {
             RGBColor[
             0.9747570423728813, 0.9606439661016949, 0.6569716016949152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 356}], {
             RGBColor[
             0.9864039830508475, 0.9656833050847458, 0.4115699661016948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 359}], {
             RGBColor[
             0.9588325254237289, 0.8673491186440678, 0.3229326355932203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 360}], {
             RGBColor[
             0.9872293644067797, 0.9682594915254237, 0.560342720338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 389}], {
             RGBColor[
             0.9648940593220339, 0.9532881694915254, 0.6736670593220337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 162}], {
             RGBColor[
             0.9457064237288135, 0.8071725932203391, 0.46364119491525435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 183}], {
             RGBColor[
             0.9382885593220339, 0.7836620169491526, 0.30628675423728813`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 189}], {
             RGBColor[
             0.9308566949152544, 0.758592593220339, 0.2774153644067797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 263}], {
             RGBColor[
             0.9420179745762711, 0.8059317627118645, 0.5454439830508475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 270}], {
             RGBColor[
             0.9279975508474576, 0.7960374576271187, 0.5943490677966101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.9457064237288135, 0.8071725932203391, 0.46364119491525435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 291}], {
             RGBColor[
             0.9408901779661016, 0.8054653898305086, 0.5641344915254238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 336}], {
             RGBColor[
             0.9329290423728813, 0.7997153559322034, 0.586001338983051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 359}], {
             RGBColor[
             0.9170045254237289, 0.7064205084745763, 0.2519623728813559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 95}], {
             RGBColor[
             0.9329290423728813, 0.7997153559322034, 0.586001338983051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 97}], {
             RGBColor[
             0.9773586610169491, 0.9824473389830508, 0.9148193389830509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.8986133050847458, 0.9211248813559322, 0.9600632288135593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 228}], {
             RGBColor[
             0.9784729745762711, 0.9731786779661017, 0.6714072966101695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 246}], {
             RGBColor[
             0.9534730084745762, 0.8834024576271187, 0.6026472203389831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 260}], {
             RGBColor[
             0.9710411101694915, 0.948109254237288, 0.642535906779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 326}], {
             RGBColor[
             0.9747570423728813, 0.9606439661016949, 0.6569716016949152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 172}], {
             RGBColor[
             0.961178127118644, 0.9407534576271186, 0.6592313644067795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 192}], {
             RGBColor[
             0.9832532711864407, 0.9543575423728813, 0.45865501694915245`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 208}], {
             RGBColor[
             0.9075365593220339, 0.6231713898305085, 0.26830506779661006`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 221}], {
             RGBColor[
             0.9801165593220339, 0.9445906271186439, 0.3772570169491524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 256}], {
             RGBColor[
             0.9033583220338983, 0.5910556271186438, 0.26430398305084735`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 316}], {
             RGBColor[
             0.9829706610169491, 0.9537530677966102, 0.42789464406779637`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 351}], {
             RGBColor[
             0.9726846949152542, 0.9195212033898303, 0.34838562711864385`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 395}], {
             RGBColor[
             0.9252528983050847, 0.728808593220339, 0.28407444915254226`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 399}], {
             RGBColor[
             0.9117147966101695, 0.6552871525423728, 0.2723061525423728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 98}], {
             RGBColor[
             0.8605863898305084, 0.4215023728813557, 0.2038811101694915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 119}], {
             RGBColor[0.9282691779661016, 0.778556, 0.5821130338983052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 130}], {
             RGBColor[
             0.9332006694915254, 0.7822338983050847, 0.5737653050847458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 143}], {
             RGBColor[
             0.9384859067796609, 0.785238779661017, 0.5228651694915254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 146}], {
             RGBColor[0.9407415, 0.7861715254237288, 0.48548415254237287`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 151}], {
             RGBColor[
             0.9373581101694914, 0.7847724067796611, 0.5415556779661018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 158}], {
             RGBColor[
             0.9299127627118644, 0.7499679491525423, 0.287962754237288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 186}], {
             RGBColor[
             0.9373446271186441, 0.775037372881356, 0.3168341440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 267}], {
             RGBColor[
             0.9401987288135594, 0.784199813559322, 0.3674717711864406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 306}], {
             RGBColor[
             0.9123446610169492, 0.6852611525423729, 0.24807406779661018`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 308}], {
             RGBColor[
             0.936230313559322, 0.7843060338983051, 0.560246186440678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 346}], {
             RGBColor[
             0.9384859067796609, 0.785238779661017, 0.5228651694915254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 348}], {
             RGBColor[
             0.9299127627118644, 0.7499679491525423, 0.287962754237288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 354}], {
             RGBColor[
             0.9261968305084747, 0.7374332372881356, 0.2735270593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 374}], {
             RGBColor[
             0.9018220847457628, 0.6435426440677965, 0.2396073559322034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 131}], {
             RGBColor[
             0.9346208813559322, 0.9475067796610169, 0.8656791610169492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 142}], {
             RGBColor[
             0.9340781101694915, 0.9455350677966101, 0.7476667796610168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 188}], {
             RGBColor[
             0.9312240084745762, 0.9363726271186441, 0.6970291525423729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 201}], {
             RGBColor[
             0.9349259406779661, 0.9473484915254238, 0.8399478983050848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 264}], {
             RGBColor[
             0.91721706779661, 0.9362133559322033, 0.9706557711864406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 273}], {
             RGBColor[
             0.9340781101694915, 0.9455350677966101, 0.7476667796610168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 281}], {
             RGBColor[
             0.9163602796610169, 0.8862337796610169, 0.6392863728813559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 293}], {
             RGBColor[
             0.8984348474576271, 0.9218515762711864, 0.9901747118644068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 394}], {
             RGBColor[
             0.9323652881355932, 0.9465740338983051, 0.9030601779661016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 204}], {
             RGBColor[
             0.9838184915254238, 0.9555664915254236, 0.5201757627118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.9726846949152542, 0.9195212033898303, 0.34838562711864385`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 307}], {
             RGBColor[
             0.9826880508474576, 0.953148593220339, 0.3971342711864405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 324}], {
             RGBColor[
             0.9835134322033898, 0.9557247796610169, 0.5459070254237287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 97}], {
             RGBColor[
             0.9408901779661016, 0.8054653898305086, 0.5641344915254238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 148}], {
             RGBColor[
             0.9308566949152544, 0.758592593220339, 0.2774153644067797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 166}], {
             RGBColor[
             0.8621448220338983, 0.7441429322033899, 0.6093783813559323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 169}], {
             RGBColor[
             0.9230660593220339, 0.792359559322034, 0.6026967966101695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 228}], {
             RGBColor[
             0.9420044915254238, 0.7961967288135594, 0.3207224491525424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 246}], {
             RGBColor[
             0.9170045254237289, 0.7064205084745763, 0.2519623728813559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 276}], {
             RGBColor[
             0.9454013644067797, 0.8073308813559323, 0.4893724576271187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 282}], {
             RGBColor[
             0.9445759830508476, 0.8047546949152543, 0.3405997033898305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 305}], {
             RGBColor[
             0.937860533898305, 0.8033932542372882, 0.5776536101694916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 326}], {
             RGBColor[
             0.9382885593220339, 0.7836620169491526, 0.30628675423728813`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 361}], {
             RGBColor[
             0.945423813559322, 0.8065681186440679, 0.43288082203389827`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 382}], {
             RGBColor[
             0.9457064237288135, 0.8071725932203391, 0.46364119491525435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 104}], {
             RGBColor[
             0.9835134322033898, 0.9557247796610169, 0.5459070254237287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 182}], {
             RGBColor[
             0.9829706610169491, 0.9537530677966102, 0.42789464406779637`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 187}], {
             RGBColor[
             0.9801300423728814, 0.954325661016949, 0.6019785508474575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 208}], {
             RGBColor[
             0.9075365593220339, 0.6231713898305085, 0.26830506779661006`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 225}], {
             RGBColor[
             0.9838184915254238, 0.9555664915254236, 0.5201757627118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 261}], {
             RGBColor[
             0.9801165593220339, 0.9445906271186439, 0.3772570169491524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 377}], {
             RGBColor[
             0.9445940169491525, 0.8130958983050847, 0.30003022881355923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 388}], {
             RGBColor[
             0.9033583220338983, 0.5910556271186438, 0.26430398305084735`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 166}], {
             RGBColor[
             0.9065744406779661, 0.9268749152542373, 0.9381963813559322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 169}], {
             RGBColor[
             0.9674956779661017, 0.9750915423728814, 0.9315147966101696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 224}], {
             RGBColor[
             0.9875753898305084, 0.9891301186440679, 0.8555714745762713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 246}], {
             RGBColor[
             0.9614341440677966, 0.8891524915254237, 0.580780372881356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 276}], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 326}], {
             RGBColor[0.9827181779661016, 0.966394, 0.6351047542372881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 363}], {
             RGBColor[
             0.962564186440678, 0.9714136440677966, 0.9398625254237288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 382}], {
             RGBColor[
             0.9901360423728813, 0.9899045762711864, 0.7924591949152544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 383}], {
             RGBColor[
             0.9887031864406779, 0.9895964915254238, 0.8368809661016949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 393}], {
             RGBColor[
             0.9790022457627119, 0.9538592881355932, 0.6206690593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 134}], {
             RGBColor[
             0.9130592627118643, 0.6267928305084745, 0.48051588983050836`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 143}], {
             RGBColor[
             0.9119314661016948, 0.6263264576271185, 0.4992063983050847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 151}], {
             RGBColor[
             0.9108036694915254, 0.6258600847457625, 0.517896906779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 158}], {
             RGBColor[
             0.9033583220338983, 0.5910556271186438, 0.26430398305084735`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 163}], {
             RGBColor[
             0.885790220338983, 0.5263488305084744, 0.22441529661016946`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.8752676440677966, 0.48463032203389805`, 0.21594858474576267`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 186}], {
             RGBColor[
             0.910790186440678, 0.6161250508474574, 0.29317537288135587`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 240}], {
             RGBColor[
             0.9136442881355932, 0.6252874915254236, 0.3438129999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 272}], {
             RGBColor[
             0.907074254237288, 0.6035903389830506, 0.2787396779661016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 306}], {
             RGBColor[
             0.885790220338983, 0.5263488305084744, 0.22441529661016946`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 308}], {
             RGBColor[
             0.9096758728813559, 0.6253937118644066, 0.5365874152542374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 342}], {
             RGBColor[
             0.9033583220338983, 0.5910556271186438, 0.26430398305084735`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 348}], {
             RGBColor[
             0.9033583220338983, 0.5910556271186438, 0.26430398305084735`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 354}], {
             RGBColor[
             0.8996423898305085, 0.5785209152542371, 0.24986828813559323`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 374}], {
             RGBColor[
             0.8752676440677966, 0.48463032203389805`, 0.21594858474576267`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 378}], {
             RGBColor[
             0.9033583220338983, 0.5910556271186438, 0.26430398305084735`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 144}], {
             RGBColor[
             0.842910186440678, 0.3149521355932204, 0.18810233050847458`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 169}], {
             RGBColor[
             0.9090864661016949, 0.7288814915254238, 0.5910318813559322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[
             0.9291661779661017, 0.7429200677966102, 0.5150885593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 222}], {
             RGBColor[
             0.9305963898305085, 0.7412766271186442, 0.3289347881355932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 223}], {
             RGBColor[
             0.9269105847457627, 0.7419873220338984, 0.5524695762711864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 276}], {
             RGBColor[
             0.9314217711864408, 0.7438528135593221, 0.4777075423728814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 361}], {
             RGBColor[
             0.931444220338983, 0.7430900508474576, 0.421215906779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 382}], {
             RGBColor[
             0.9317268305084746, 0.7436945254237288, 0.45197627966101706`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 384}], {
             RGBColor[
             0.882480966101695, 0.559255338983051, 0.22365157627118648`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 393}], {
             RGBColor[
             0.920593033898305, 0.7076492372881356, 0.2801861440677965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 157}], {
             RGBColor[
             0.9289688305084746, 0.7413433050847458, 0.2985101440677965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 167}], {
             RGBColor[
             0.9838324915254237, 0.9571253389830509, 0.3916927118644067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 174}], {
             RGBColor[
             0.9430486610169492, 0.8047713559322034, 0.3102325677966101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 198}], {
             RGBColor[
             0.9196491016949153, 0.6990245932203389, 0.29073353389830503`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 203}], {
             RGBColor[
             0.9864039830508475, 0.9656833050847458, 0.4115699661016948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 206}], {
             RGBColor[
             0.9764006271186441, 0.9320559152542371, 0.36282132203389816`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 211}], {
             RGBColor[
             0.9872293644067797, 0.9682594915254237, 0.560342720338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 266}], {
             RGBColor[
             0.9872293644067797, 0.9682594915254237, 0.560342720338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 341}], {
             RGBColor[
             0.9196491016949153, 0.6990245932203389, 0.29073353389830503`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 358}], {
             RGBColor[
             0.9726846949152543, 0.9195212033898306, 0.34838562711864407`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 115}], {
             RGBColor[
             0.9573006525423728, 0.8687596101694917, 0.5578565084745764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 123}], {
             RGBColor[
             0.9424234406779661, 0.8088857288135594, 0.27539219491525424`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 161}], {
             RGBColor[
             0.9375484915254237, 0.7901076101694915, 0.2686082542372881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 193}], {
             RGBColor[
             0.9595562457627118, 0.8696923559322034, 0.5204754915254237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 253}], {
             RGBColor[
             0.946139372881356, 0.8214204406779662, 0.28982788983050856`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 283}], {
             RGBColor[
             0.9498553050847458, 0.8339551525423728, 0.30426358474576265`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 332}], {
             RGBColor[
             0.9598586610169492, 0.8675825423728813, 0.35301222881355926`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 334}], {
             RGBColor[
             0.9535712372881355, 0.8464898644067798, 0.3186992796610169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 356}], {
             RGBColor[
             0.9598586610169492, 0.8675825423728813, 0.35301222881355926`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 364}], {
             RGBColor[0.8774275, 0.806970779661017, 0.621790906779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 366}], {
             RGBColor[
             0.921764627118644, 0.727529847457627, 0.255908186440678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 380}], {
             RGBColor[
             0.948211720338983, 0.8625432033898306, 0.5984138644067798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 389}], {
             RGBColor[
             0.9383487372881356, 0.855187406779661, 0.6151093220338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 108}], {
             RGBColor[
             0.9918264152542373, 0.989628372881356, 0.6935574322033898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 139}], {
             RGBColor[
             0.993256627118644, 0.9879849322033898, 0.5074036610169491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 213}], {
             RGBColor[
             0.9668152118644068, 0.9719118983050847, 0.7778484830508474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 297}], {
             RGBColor[
             0.9265017457627118, 0.721326220338983, 0.3865672288135593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 333}], {
             RGBColor[
             0.975821406779661, 0.9292881186440678, 0.42978362711864404`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 337}], {
             RGBColor[
             0.9604238813559323, 0.8687914915254238, 0.41453297457627125`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 345}], {
             RGBColor[
             0.9766781949152542, 0.9792676949152542, 0.7611530254237289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 350}], {
             RGBColor[
             0.9766781949152542, 0.9792676949152542, 0.7611530254237289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 378}], {
             RGBColor[
             0.9832532711864407, 0.9543575423728813, 0.45865501694915245`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 122}], {
             RGBColor[
             0.9935194322033898, 0.9913036949152543, 0.7363876694915255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 295}], {
             RGBColor[
             0.9935194322033898, 0.9913036949152543, 0.7363876694915255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 145}], {
             RGBColor[
             0.9946472288135593, 0.9917700677966101, 0.7176971610169492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 170}], {
             RGBColor[
             0.9937993983050848, 0.9899566440677967, 0.6254160423728812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 182}], {
             RGBColor[
             0.9937993983050848, 0.9899566440677967, 0.6254160423728812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 187}], {
             RGBColor[
             0.9909587796610169, 0.9905292372881356, 0.7994999491525425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 192}], {
             RGBColor[
             0.9940820084745763, 0.9905611186440678, 0.6561764152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 208}], {
             RGBColor[
             0.9183652966101695, 0.659374966101695, 0.4658264661016949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 225}], {
             RGBColor[
             0.9946472288135593, 0.9917700677966101, 0.7176971610169492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 235}], {
             RGBColor[
             0.993214372881356, 0.9914619830508475, 0.7621189322033898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 261}], {
             RGBColor[
             0.9909452966101695, 0.9807942033898305, 0.5747784152542372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 327}], {
             RGBColor[
             0.9935167881355933, 0.9893521694915255, 0.5946556694915254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 335}], {
             RGBColor[
             0.9872293644067797, 0.9682594915254237, 0.560342720338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 349}], {
             RGBColor[
             0.9797975000000001, 0.9431900677966102, 0.5314713305084746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 351}], {
             RGBColor[
             0.9835134322033898, 0.9557247796610169, 0.5459070254237287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 355}], {
             RGBColor[
             0.9872293644067797, 0.9682594915254237, 0.560342720338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 199}], {
             RGBColor[
             0.9735549661016949, 0.979235813559322, 0.904476559322034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 215}], {
             RGBColor[
             0.9191601440677966, 0.6900916101694916, 0.5258990762711866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 259}], {
             RGBColor[
             0.9909812288135593, 0.9897664745762712, 0.7430083135593221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 271}], {
             RGBColor[
             0.9625619406779661, 0.8896188644067797, 0.5620898644067798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 287}], {
             RGBColor[
             0.9906986186440678, 0.9891620000000001, 0.7122479406779663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 303}], {
             RGBColor[
             0.9909587796610169, 0.9905292372881356, 0.7994999491525425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 333}], {
             RGBColor[
             0.9726981779661017, 0.9292562372881357, 0.5731071610169493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 337}], {
             RGBColor[
             0.9573006525423728, 0.8687596101694917, 0.5578565084745764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 345}], {
             RGBColor[
             0.9735549661016949, 0.979235813559322, 0.904476559322034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 350}], {
             RGBColor[
             0.9735549661016949, 0.979235813559322, 0.904476559322034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 353}], {
             RGBColor[
             0.9834179491525423, 0.9865916101694916, 0.8877811016949153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 400}], {
             RGBColor[
             0.9838459745762711, 0.966860372881356, 0.6164142457627119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 197}], {
             RGBColor[
             0.8721662118644068, 0.7861115254237288, 0.6175575508474577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 217}], {
             RGBColor[
             0.9035447966101695, 0.924802779661017, 0.9517154999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 231}], {
             RGBColor[
             0.8826887881355933, 0.8278300338983051, 0.6260242627118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 254}], {
             RGBColor[
             0.8936818135593221, 0.9174469830508474, 0.9684109576271187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 314}], {
             RGBColor[
             0.9099578305084746, 0.9282740338983051, 0.8821248559322034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 369}], {
             RGBColor[
             0.9065744406779661, 0.9268749152542373, 0.9381963813559322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 124}], {
             RGBColor[
             0.9058530338983051, 0.5622649152542373, 0.39733157627118637`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 150}], {
             RGBColor[
             0.945423813559322, 0.8065681186440679, 0.43288082203389827`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 152}], {
             RGBColor[
             0.9670978220338983, 0.972516372881356, 0.8086088559322033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.9909812288135593, 0.9897664745762712, 0.7430083135593221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.9361040847457627, 0.764249406779661, 0.4251042118644067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 160}], {
             RGBColor[
             0.9943646186440678, 0.9911655932203389, 0.6869367881355932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 167}], {
             RGBColor[
             0.9909677457627118, 0.9800314406779661, 0.5182867796610169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.9670978220338983, 0.972516372881356, 0.8086088559322033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 181}], {
             RGBColor[
             0.9909677457627118, 0.9800314406779661, 0.5182867796610169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 211}], {
             RGBColor[
             0.9943646186440678, 0.9911655932203389, 0.6869367881355932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 238}], {
             RGBColor[
             0.9921090254237288, 0.9902328474576272, 0.7243178050847456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 245}], {
             RGBColor[
             0.9932368220338983, 0.990699220338983, 0.7056272966101693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 386}], {
             RGBColor[
             0.993821847457627, 0.9891938813559322, 0.5689244067796608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 297}], {
             RGBColor[
             0.924506313559322, 0.7217607118644067, 0.5112002542372881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 325}], {
             RGBColor[
             0.9796142542372881, 0.9833800847457628, 0.8774383220338984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 376}], {
             RGBColor[
             0.9887031864406779, 0.9895964915254238, 0.8368809661016949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 378}], {
             RGBColor[
             0.9812578389830509, 0.954792033898305, 0.5832880423728812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 397}], {
             RGBColor[
             0.9119314661016948, 0.6263264576271185, 0.49920639830508473`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 114}], {
             RGBColor[
             0.9763866271186441, 0.9304970677966102, 0.491304372881356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 132}], {
             RGBColor[
             0.9752561864406779, 0.9280791694915254, 0.3682628813559321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 180}], {
             RGBColor[
             0.9652528305084745, 0.8944517796610169, 0.31951423728813544`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 232}], {
             RGBColor[
             0.9319008644067797, 0.767167220338983, 0.26692548305084746`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 249}], {
             RGBColor[
             0.9726846949152542, 0.9195212033898306, 0.34838562711864407`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 370}], {
             RGBColor[
             0.9615368983050847, 0.8819170677966102, 0.30507854237288135`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 111}], {
             RGBColor[
             0.9871063983050847, 0.9878324406779662, 0.8059783135593221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 117}], {
             RGBColor[
             0.9868237881355932, 0.9872279661016949, 0.775217940677966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 202}], {
             RGBColor[
             0.9856735423728813, 0.9875243559322034, 0.8504000847457627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 212}], {
             RGBColor[
             0.9506153050847457, 0.9623355254237289, 0.956205127118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 239}], {
             RGBColor[
             0.9868013389830508, 0.9879907288135594, 0.8317095762711864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 247}], {
             RGBColor[
             0.9506153050847457, 0.9623355254237289, 0.956205127118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 269}], {
             RGBColor[
             0.9506153050847457, 0.9623355254237289, 0.956205127118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 287}], {
             RGBColor[
             0.9865411779661017, 0.9866234915254237, 0.7444575677966101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 289}], {
             RGBColor[
             0.9865411779661017, 0.9866234915254237, 0.7444575677966101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 292}], {
             RGBColor[
             0.9834179491525423, 0.9865916101694916, 0.8877811016949153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 303}], {
             RGBColor[
             0.9868013389830508, 0.9879907288135594, 0.8317095762711864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 309}], {
             RGBColor[
             0.9862585677966101, 0.9860190169491526, 0.7136971949152541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 362}], {
             RGBColor[
             0.9868237881355932, 0.9872279661016949, 0.775217940677966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 385}], {
             RGBColor[
             0.979688533898305, 0.9643218644067797, 0.6486238728813558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 400}], {
             RGBColor[
             0.979688533898305, 0.9643218644067797, 0.6486238728813558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 199}], {
             RGBColor[
             0.9772434152542373, 0.9804766440677966, 0.8226737711864407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 222}], {
             RGBColor[
             0.9938218474576271, 0.9891938813559322, 0.568924406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 223}], {
             RGBColor[
             0.9901360423728813, 0.9899045762711864, 0.7924591949152544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 247}], {
             RGBColor[
             0.9584611949152542, 0.9661148644067796, 0.8421927118644068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 271}], {
             RGBColor[
             0.9662503898305085, 0.8908596949152543, 0.4802870762711865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 287}], {
             RGBColor[
             0.9943870677966102, 0.9904028305084747, 0.630445152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 292}], {
             RGBColor[
             0.9912638389830508, 0.9903709491525424, 0.7737686864406781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 309}], {
             RGBColor[
             0.9941044576271186, 0.9897983559322034, 0.599684779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 319}], {
             RGBColor[
             0.9912638389830508, 0.9903709491525424, 0.7737686864406781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 362}], {
             RGBColor[
             0.9946696779661017, 0.9910073050847458, 0.6612055254237288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 385}], {
             RGBColor[
             0.9875344237288135, 0.9681012033898305, 0.5346114576271187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[
             0.9875344237288135, 0.9681012033898305, 0.5346114576271187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 177}], {
             RGBColor[
             0.9697512711864407, 0.9760242881355932, 0.8941337796610169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 219}], {
             RGBColor[
             0.9909587796610169, 0.9905292372881356, 0.7994999491525423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 248}], {
             RGBColor[
             0.9849737711864406, 0.9673267457627119, 0.5977237372881355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 251}], {
             RGBColor[
             0.9323652881355932, 0.9465740338983051, 0.9030601779661016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 260}], {
             RGBColor[
             0.9812578389830509, 0.954792033898305, 0.5832880423728812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 162}], {
             RGBColor[
             0.9838184915254238, 0.9555664915254236, 0.5201757627118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 183}], {
             RGBColor[
             0.9764006271186441, 0.9320559152542371, 0.36282132203389816`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 270}], {
             RGBColor[
             0.9661096186440677, 0.9444313559322033, 0.6508836355932202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 357}], {
             RGBColor[
             0.9473273983050847, 0.9300695762711864, 0.6704025762711863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 368}], {
             RGBColor[
             0.9835134322033898, 0.9557247796610169, 0.5459070254237287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 132}], {
             RGBColor[
             0.9938218474576271, 0.9891938813559322, 0.568924406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 155}], {
             RGBColor[
             0.9901360423728813, 0.9899045762711864, 0.7924591949152544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 180}], {
             RGBColor[
             0.9838184915254238, 0.9555664915254236, 0.5201757627118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 249}], {
             RGBColor[
             0.9912503559322035, 0.9806359152542373, 0.549047152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 268}], {
             RGBColor[
             0.5869396440677966, 0.6485028898305085, 0.8127334491525424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 279}], {
             RGBColor[
             0.9457064237288135, 0.8071725932203391, 0.46364119491525435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 299}], {
             RGBColor[
             0.9662503898305085, 0.8908596949152543, 0.4802870762711865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 300}], {
             RGBColor[
             0.9723119237288136, 0.9767987457627119, 0.8310215000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 370}], {
             RGBColor[
             0.9801025593220339, 0.943031779661017, 0.5057400677966103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 123}], {
             RGBColor[
             0.9726981779661017, 0.9292562372881357, 0.5731071610169493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 161}], {
             RGBColor[
             0.9678232288135593, 0.9104781186440678, 0.5663232203389831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 193}], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 195}], {
             RGBColor[
             0.9467780762711864, 0.8270411016949153, 0.5493897966101696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 214}], {
             RGBColor[
             0.9864475932203389, 0.9886637457627119, 0.8742619830508476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 253}], {
             RGBColor[
             0.9764141101694915, 0.9417909491525425, 0.5875428559322036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 257}], {
             RGBColor[
             0.9801300423728814, 0.954325661016949, 0.6019785508474575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 283}], {
             RGBColor[
             0.9801300423728814, 0.954325661016949, 0.6019785508474575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 312}], {
             RGBColor[
             0.9686234745762712, 0.9755579152542373, 0.9128242881355932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 332}], {
             RGBColor[
             0.9901333983050847, 0.9879530508474577, 0.6507271949152542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 334}], {
             RGBColor[
             0.9838459745762711, 0.966860372881356, 0.6164142457627119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 356}], {
             RGBColor[
             0.9901333983050847, 0.9879530508474577, 0.6507271949152542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 360}], {
             RGBColor[
             0.9909587796610169, 0.9905292372881356, 0.7994999491525425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 364}], {
             RGBColor[
             0.9077022372881356, 0.9273412881355932, 0.9195058728813561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 366}], {
             RGBColor[
             0.9520393644067796, 0.8479003559322034, 0.5536231525423729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 380}], {
             RGBColor[
             0.9784864576271186, 0.9829137118644068, 0.8961288305084747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 389}], {
             RGBColor[
             0.9686234745762712, 0.9755579152542373, 0.9128242881355932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 141}], {
             RGBColor[
             0.9356167966101696, 0.7797019322033898, 0.2813611779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 179}], {
             RGBColor[
             0.9228946694915254, 0.8097909999999999, 0.6149903389830509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 209}], {
             RGBColor[
             0.9479058728813559, 0.8275074745762712, 0.5306992881355932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 286}], {
             RGBColor[
             0.9165033389830508, 0.706670593220339, 0.2516748305084746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 290}], {
             RGBColor[
             0.9430486610169492, 0.8047713559322034, 0.3102325677966101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 304}], {
             RGBColor[
             0.8669049237288136, 0.7652522711864407, 0.6133241949152544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 338}], {
             RGBColor[
             0.9499013050847458, 0.8270729830508474, 0.4060662627118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 239}], {
             RGBColor[
             0.9943646186440678, 0.9911655932203389, 0.6869367881355932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 269}], {
             RGBColor[
             0.9581785847457627, 0.9655103898305084, 0.8114323389830508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 309}], {
             RGBColor[
             0.993821847457627, 0.9891938813559322, 0.5689244067796608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 323}], {
             RGBColor[
             0.9798199491525423, 0.9424273050847458, 0.4749796949152542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 362}], {
             RGBColor[
             0.9943870677966101, 0.9904028305084746, 0.6304451525423728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 365}], {
             RGBColor[
             0.987251813559322, 0.9674967288135593, 0.5038510847457626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 377}], {
             RGBColor[
             0.9554452033898304, 0.8485367118644067, 0.44105999152542363`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 385}], {
             RGBColor[
             0.987251813559322, 0.9674967288135593, 0.5038510847457626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 388}], {
             RGBColor[
             0.9142095084745763, 0.6264964406779658, 0.40533374576271175`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 395}], {
             RGBColor[
             0.9361040847457627, 0.764249406779661, 0.4251042118644067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 124}], {
             RGBColor[
             0.8933582627118644, 0.5554121525423729, 0.550452093220339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[
             0.9673251779661016, 0.9355745423728814, 0.6281002118644068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 150}], {
             RGBColor[
             0.9329290423728813, 0.7997153559322034, 0.586001338983051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 179}], {
             RGBColor[
             0.9546030508474576, 0.9656636101694915, 0.961729372881356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 196}], {
             RGBColor[
             0.9546030508474576, 0.9656636101694915, 0.961729372881356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 206}], {
             RGBColor[
             0.9710411101694915, 0.948109254237288, 0.642535906779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 209}], {
             RGBColor[
             0.9796142542372881, 0.9833800847457628, 0.8774383220338984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 286}], {
             RGBColor[
             0.948211720338983, 0.8625432033898306, 0.5984138644067797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 386}], {
             RGBColor[
             0.9813270762711863, 0.9823411186440678, 0.7220449237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 128}], {
             RGBColor[
             0.9673251779661016, 0.9355745423728814, 0.6281002118644068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 130}], {
             RGBColor[
             0.9743290169491525, 0.9803752033898305, 0.9283384576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 135}], {
             RGBColor[
             0.9810444661016948, 0.9817366440677966, 0.6912845508474575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 146}], {
             RGBColor[
             0.9818698474576271, 0.9843128305084745, 0.8400573050847457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 151}], {
             RGBColor[
             0.9784864576271186, 0.9829137118644068, 0.8961288305084747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 213}], {
             RGBColor[
             0.9546030508474576, 0.9656636101694915, 0.961729372881356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 227}], {
             RGBColor[
             0.9813270762711863, 0.9823411186440678, 0.7220449237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 243}], {
             RGBColor[
             0.9693975254237287, 0.9766973050847457, 0.936686186440678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 267}], {
             RGBColor[
             0.9813270762711863, 0.9823411186440678, 0.7220449237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 306}], {
             RGBColor[
             0.9534730084745762, 0.8834024576271187, 0.6026472203389831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 311}], {
             RGBColor[
             0.9784864576271186, 0.9829137118644068, 0.8961288305084747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 344}], {
             RGBColor[
             0.964466033898305, 0.9730194067796609, 0.9450339152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 346}], {
             RGBColor[
             0.9796142542372881, 0.9833800847457628, 0.8774383220338984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 350}], {
             RGBColor[
             0.964466033898305, 0.9730194067796609, 0.9450339152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 354}], {
             RGBColor[
             0.9673251779661016, 0.9355745423728814, 0.6281002118644068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 140}], {
             RGBColor[
             0.9689687627118644, 0.9069864915254237, 0.33394993220338975`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 147}], {
             RGBColor[
             0.9823856355932203, 0.955258406779661, 0.5645975338983049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 193}], {
             RGBColor[
             0.9823856355932203, 0.955258406779661, 0.5645975338983049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 195}], {
             RGBColor[
             0.9393327288135593, 0.7922366440677966, 0.2957968728813558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 241}], {
             RGBColor[
             0.9838184915254238, 0.9555664915254236, 0.5201757627118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 242}], {
             RGBColor[
             0.9838184915254238, 0.9555664915254236, 0.5201757627118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 255}], {
             RGBColor[
             0.9345726271186441, 0.7711273050847458, 0.2918510593220338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 263}], {
             RGBColor[
             0.9801300423728814, 0.954325661016949, 0.6019785508474575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 312}], {
             RGBColor[
             0.961178127118644, 0.9407534576271186, 0.6592313644067795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 331}], {
             RGBColor[
             0.9823856355932203, 0.955258406779661, 0.5645975338983049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 356}], {
             RGBColor[
             0.9826880508474576, 0.953148593220339, 0.3971342711864405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 359}], {
             RGBColor[
             0.9551165932203389, 0.8548144067796609, 0.30849694067796596`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 360}], {
             RGBColor[
             0.9835134322033898, 0.9557247796610169, 0.5459070254237287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 380}], {
             RGBColor[
             0.9710411101694915, 0.948109254237288, 0.642535906779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 389}], {
             RGBColor[
             0.961178127118644, 0.9407534576271186, 0.6592313644067795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[
             0.9609891016949152, 0.8700004406779662, 0.4760537203389832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 202}], {
             RGBColor[
             0.9935194322033898, 0.9913036949152543, 0.7363876694915255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 234}], {
             RGBColor[
             0.9935194322033898, 0.9913036949152543, 0.7363876694915255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 289}], {
             RGBColor[
             0.9943870677966102, 0.9904028305084747, 0.630445152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 298}], {
             RGBColor[
             0.9875344237288135, 0.9681012033898305, 0.5346114576271187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 173}], {
             RGBColor[
             0.9349259406779661, 0.9473484915254238, 0.8399478983050848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 338}], {
             RGBColor[
             0.9943870677966102, 0.9904028305084747, 0.630445152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 161}], {
             RGBColor[
             0.9529460169491525, 0.8506042372881355, 0.28385890677966097`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 196}], {
             RGBColor[
             0.9488147711864406, 0.9120061355932203, 0.6387077033898305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 214}], {
             RGBColor[
             0.9715703813559322, 0.9287898644067797, 0.5917976694915255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 253}], {
             RGBColor[
             0.9615368983050847, 0.8819170677966102, 0.30507854237288135`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 283}], {
             RGBColor[
             0.9652528305084745, 0.8944517796610169, 0.31951423728813544`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 332}], {
             RGBColor[
             0.9752561864406779, 0.9280791694915254, 0.3682628813559321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 334}], {
             RGBColor[
             0.9689687627118644, 0.9069864915254238, 0.33394993220338975`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 356}], {
             RGBColor[
             0.9752561864406779, 0.9280791694915254, 0.3682628813559321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 364}], {
             RGBColor[
             0.8928250254237289, 0.867467406779661, 0.637041559322034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 366}], {
             RGBColor[
             0.9371621525423728, 0.7880264745762711, 0.2711588389830508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 389}], {
             RGBColor[
             0.9537462627118644, 0.915684033898305, 0.6303599745762711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 150}], {
             RGBColor[
             0.856889779661017, 0.3784302033898306, 0.19976724576271188`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 152}], {
             RGBColor[
             0.8785637881355932, 0.5443784576271187, 0.575495279661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 156}], {
             RGBColor[
             0.9024471949152542, 0.5616285593220339, 0.5098947372881357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 157}], {
             RGBColor[
             0.8475700508474576, 0.33611149152542374`, 0.19199063559322033`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 160}], {
             RGBColor[
             0.9058305847457627, 0.5630276779661016, 0.4538232118644068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 167}], {
             RGBColor[
             0.9024337118644068, 0.5518935254237288, 0.2851732033898305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 179}], {
             RGBColor[
             0.8785637881355932, 0.5443784576271187, 0.575495279661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 181}], {
             RGBColor[
             0.9024337118644068, 0.5518935254237288, 0.2851732033898305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 238}], {
             RGBColor[
             0.9035749915254236, 0.5620949322033899, 0.4912042288135593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 245}], {
             RGBColor[
             0.9047027881355932, 0.5625613050847458, 0.472513720338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 386}], {
             RGBColor[
             0.9052878135593221, 0.561055966101695, 0.3358108305084745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 184}], {
             RGBColor[
             0.9929542118644068, 0.9900947457627118, 0.6748669237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 185}], {
             RGBColor[
             0.9823856355932203, 0.955258406779661, 0.5645975338983049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 190}], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 226}], {
             RGBColor[
             0.993214372881356, 0.9914619830508475, 0.7621189322033898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 252}], {
             RGBColor[
             0.9700788220338983, 0.9114108644067795, 0.5289422033898304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 274}], {
             RGBColor[
             0.9923889915254238, 0.9888857966101695, 0.6133461779661016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 288}], {
             RGBColor[
             0.9088810254237288, 0.5946770677966101, 0.4765148050847457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 318}], {
             RGBColor[0.9172375, 0.6589085932203391, 0.48451697457627113`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 176}], {
             RGBColor[
             0.9735414830508474, 0.9695007796610169, 0.6797550254237288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 205}], {
             RGBColor[
             0.9735549661016949, 0.979235813559322, 0.904476559322034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 298}], {
             RGBColor[
             0.9698255508474576, 0.9569660677966101, 0.6653193305084745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 320}], {
             RGBColor[
             0.9735549661016949, 0.979235813559322, 0.904476559322034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 347}], {
             RGBColor[
             0.8777168983050847, 0.9049116610169492, 0.9668365508474577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 373}], {
             RGBColor[
             0.9769383559322034, 0.9806349322033898, 0.8484050338983051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 137}], {
             RGBColor[
             0.9726846949152542, 0.9195212033898306, 0.34838562711864407`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 138}], {
             RGBColor[
             0.939895533898305, 0.9050001525423729, 0.6415311864406779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 193}], {
             RGBColor[
             0.9749537711864407, 0.9301889830508474, 0.5357261440677965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 210}], {
             RGBColor[
             0.9689687627118644, 0.9069864915254238, 0.33394993220338975`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 242}], {
             RGBColor[
             0.9763866271186441, 0.9304970677966102, 0.491304372881356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 255}], {
             RGBColor[
             0.9271407627118644, 0.7460578813559322, 0.2629796694915254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 258}], {
             RGBColor[
             0.9761040169491525, 0.929892593220339, 0.46054399999999995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 264}], {
             RGBColor[
             0.9586777542372881, 0.9193619322033898, 0.6220122457627117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 312}], {
             RGBColor[
             0.9537462627118644, 0.915684033898305, 0.6303599745762711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 328}], {
             RGBColor[
             0.975821406779661, 0.9292881186440678, 0.42978362711864404`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 331}], {
             RGBColor[
             0.9749537711864407, 0.9301889830508474, 0.5357261440677965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 380}], {
             RGBColor[
             0.9636092457627118, 0.9230398305084746, 0.6136645169491526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 394}], {
             RGBColor[
             0.9738259745762712, 0.9297226101694915, 0.5544166525423728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 130}], {
             RGBColor[
             0.9722566694915254, 0.9392524406779661, 0.6197524830508474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 135}], {
             RGBColor[
             0.9789721186440679, 0.9406138813559322, 0.3826985762711864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 139}], {
             RGBColor[
             0.9789721186440679, 0.9406138813559322, 0.3826985762711864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 151}], {
             RGBColor[
             0.9764141101694915, 0.9417909491525425, 0.5875428559322036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 213}], {
             RGBColor[
             0.9525307033898305, 0.9245408474576271, 0.6531433983050847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 215}], {
             RGBColor[
             0.9079988644067797, 0.6427524406779661, 0.2578704576271187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 224}], {
             RGBColor[
             0.977541906779661, 0.9422573220338983, 0.5688523474576271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 227}], {
             RGBColor[
             0.9792547288135593, 0.9412183559322034, 0.4134589491525423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 243}], {
             RGBColor[
             0.9673251779661016, 0.9355745423728814, 0.6281002118644068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 259}], {
             RGBColor[
             0.9798199491525423, 0.9424273050847458, 0.4749796949152542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 306}], {
             RGBColor[
             0.9514006610169492, 0.8422796949152542, 0.29406124576271186`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 350}], {
             RGBColor[
             0.9623936864406779, 0.9318966440677966, 0.6364479406779662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 383}], {
             RGBColor[
             0.9786697033898306, 0.9427236949152542, 0.5501618389830508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 131}], {
             RGBColor[
             0.9943646186440678, 0.9911655932203389, 0.6869367881355932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 253}], {
             RGBColor[
             0.9798199491525423, 0.9424273050847458, 0.4749796949152542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 271}], {
             RGBColor[
             0.9659677796610169, 0.8902552203389831, 0.4495267033898305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 287}], {
             RGBColor[
             0.9941044576271186, 0.9897983559322034, 0.599684779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 303}], {
             RGBColor[
             0.9943646186440678, 0.9911655932203389, 0.6869367881355932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 333}], {
             RGBColor[
             0.9761040169491525, 0.929892593220339, 0.46054399999999995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 337}], {
             RGBColor[
             0.9607064915254238, 0.869395966101695, 0.44529334745762705`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 353}], {
             RGBColor[
             0.9868237881355932, 0.9872279661016949, 0.775217940677966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 364}], {
             RGBColor[
             0.9111080762711865, 0.9279776440677966, 0.8069427118644068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 391}], {
             RGBColor[
             0.9501839152542373, 0.8276774576271186, 0.4368266355932203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 135}], {
             RGBColor[
             0.9859759576271186, 0.9854145423728814, 0.6829368220338982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 146}], {
             RGBColor[
             0.9868013389830508, 0.9879907288135594, 0.8317095762711864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 151}], {
             RGBColor[
             0.9834179491525423, 0.9865916101694916, 0.8877811016949153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 158}], {
             RGBColor[
             0.9759726016949153, 0.9517871525423729, 0.6341881779661016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 227}], {
             RGBColor[
             0.9862585677966101, 0.9860190169491526, 0.7136971949152541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 243}], {
             RGBColor[
             0.9743290169491525, 0.9803752033898305, 0.9283384576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 267}], {
             RGBColor[
             0.9862585677966101, 0.9860190169491526, 0.7136971949152541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 275}], {
             RGBColor[
             0.9856735423728813, 0.9875243559322034, 0.8504000847457627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 306}], {
             RGBColor[0.9584045, 0.8870803559322034, 0.5942994915254237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 311}], {
             RGBColor[
             0.9834179491525423, 0.9865916101694916, 0.8877811016949153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 317}], {
             RGBColor[
             0.9792605084745762, 0.9840531016949153, 0.9199907288135593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 344}], {
             RGBColor[
             0.9693975254237288, 0.9766973050847458, 0.9366861864406779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 346}], {
             RGBColor[
             0.9845457457627118, 0.9870579830508475, 0.869090593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 354}], {
             RGBColor[
             0.9722566694915254, 0.9392524406779661, 0.6197524830508474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 142}], {
             RGBColor[
             0.9937993983050848, 0.9899566440677967, 0.6254160423728812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 201}], {
             RGBColor[
             0.9946472288135593, 0.9917700677966101, 0.7176971610169492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 273}], {
             RGBColor[
             0.9937993983050848, 0.9899566440677967, 0.6254160423728812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 281}], {
             RGBColor[
             0.9760815677966102, 0.9306553559322034, 0.5170356355932203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 293}], {
             RGBColor[
             0.9581561355932203, 0.9662731525423729, 0.8679239745762712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 303}], {
             RGBColor[
             0.9943421694915254, 0.9919283559322034, 0.7434284237288136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 391}], {
             RGBColor[
             0.9501614661016949, 0.8284402203389831, 0.49331827118644067`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 394}], {
             RGBColor[
             0.9920865762711863, 0.9909956101694916, 0.7808094406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 149}], {
             RGBColor[
             0.9912611949152542, 0.9884194237288135, 0.6320366864406779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 155}], {
             RGBColor[
             0.9890056016949152, 0.9874866779661018, 0.6694177033898304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 180}], {
             RGBColor[
             0.9826880508474576, 0.953148593220339, 0.3971342711864405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 249}], {
             RGBColor[
             0.9901199152542373, 0.9782180169491526, 0.42600566101694903`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 268}], {
             RGBColor[
             0.5858092033898306, 0.6460849915254238, 0.6896919576271185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 279}], {
             RGBColor[
             0.9445759830508476, 0.8047546949152543, 0.3405997033898305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 299}], {
             RGBColor[
             0.9651199491525424, 0.8884417966101694, 0.3572455847457626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 300}], {
             RGBColor[
             0.9711814830508474, 0.9743808474576271, 0.7079800084745762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 370}], {
             RGBColor[
             0.9789721186440679, 0.9406138813559322, 0.3826985762711864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 178}], {
             RGBColor[
             0.9786697033898306, 0.9427236949152542, 0.5501618389830508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 200}], {
             RGBColor[
             0.9595562457627118, 0.8696923559322034, 0.5204754915254237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 278}], {
             RGBColor[
             0.9442735677966102, 0.8068645084745764, 0.5080629661016949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 296}], {
             RGBColor[
             0.9823856355932203, 0.955258406779661, 0.5645975338983049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 320}], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 330}], {
             RGBColor[
             0.9334930847457628, 0.947040406779661, 0.8843696694915253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 347}], {
             RGBColor[
             0.8939929152542374, 0.9157387118644068, 0.8805504491525423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 367}], {
             RGBColor[
             0.9047027881355932, 0.5625613050847458, 0.472513720338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 398}], {
             RGBColor[
             0.9929542118644068, 0.9900947457627118, 0.6748669237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 163}], {
             RGBColor[
             0.9648175338983052, 0.8905516101694915, 0.524708847457627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 171}], {
             RGBColor[
             0.9542949576271187, 0.8488331016949152, 0.5162421355932203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 240}], {
             RGBColor[
             0.9926716016949153, 0.9894902711864407, 0.6441065508474575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 272}], {
             RGBColor[
             0.9861015677966102, 0.9677931186440678, 0.5790332288135592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 342}], {
             RGBColor[
             0.9823856355932203, 0.955258406779661, 0.5645975338983049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 374}], {
             RGBColor[
             0.9542949576271187, 0.8488331016949152, 0.5162421355932203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 213}], {
             RGBColor[
             0.9662499915254237, 0.9707029491525423, 0.7163277372881356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 215}], {
             RGBColor[
             0.9217181525423729, 0.6889145423728814, 0.3210547966101694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 224}], {
             RGBColor[
             0.9912611949152542, 0.9884194237288135, 0.6320366864406779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 227}], {
             RGBColor[
             0.9929740169491525, 0.9873804576271187, 0.476643288135593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 243}], {
             RGBColor[
             0.9810444661016948, 0.9817366440677966, 0.6912845508474575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 259}], {
             RGBColor[
             0.9935392372881355, 0.988589406779661, 0.5381640338983049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 350}], {
             RGBColor[
             0.9761129745762711, 0.9780587457627119, 0.6996322796610168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 363}], {
             RGBColor[
             0.9662499915254237, 0.9707029491525423, 0.7163277372881356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 383}], {
             RGBColor[
             0.9923889915254238, 0.9888857966101695, 0.6133461779661016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 393}], {
             RGBColor[
             0.9826880508474576, 0.953148593220339, 0.3971342711864405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 149}], {
             RGBColor[
             0.9796142542372881, 0.9833800847457628, 0.8774383220338984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 155}], {
             RGBColor[
             0.9773586610169491, 0.9824473389830508, 0.9148193389830509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 268}], {
             RGBColor[
             0.5741622627118643, 0.6410456525423729, 0.935093593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 279}], {
             RGBColor[
             0.9329290423728813, 0.7997153559322034, 0.586001338983051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 299}], {
             RGBColor[
             0.9534730084745762, 0.8834024576271187, 0.6026472203389831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 300}], {
             RGBColor[
             0.9595345423728813, 0.9693415084745762, 0.9533816440677967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 371}], {
             RGBColor[
             0.9796142542372881, 0.9833800847457628, 0.8774383220338984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 138}], {
             RGBColor[0.9547592627118644, 0.955139, 0.6992739661016949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 164}], {
             RGBColor[
             0.9420044915254238, 0.7961967288135594, 0.3207224491525424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 210}], {
             RGBColor[
             0.9838324915254237, 0.9571253389830509, 0.3916927118644067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 230}], {
             RGBColor[0.9898175, 0.9803278305084746, 0.5934689237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 242}], {
             RGBColor[
             0.9912503559322035, 0.9806359152542373, 0.549047152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 258}], {
             RGBColor[
             0.9909677457627118, 0.9800314406779661, 0.5182867796610169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 264}], {
             RGBColor[
             0.9735414830508474, 0.9695007796610169, 0.6797550254237288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 328}], {
             RGBColor[
             0.9906851355932204, 0.979426966101695, 0.487526406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 394}], {
             RGBColor[
             0.9886897033898305, 0.9798614576271187, 0.6121594322033899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 149}], {
             RGBColor[
             0.9559005423728812, 0.965340406779661, 0.9053049915254237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 164}], {
             RGBColor[
             0.9092153305084746, 0.7816756779661018, 0.6138680084745762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 210}], {
             RGBColor[
             0.9510433305084746, 0.9426042881355932, 0.6848382711864406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 230}], {
             RGBColor[
             0.9570283389830508, 0.965806779661017, 0.8866144830508473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 242}], {
             RGBColor[
             0.9584611949152542, 0.9661148644067796, 0.8421927118644068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 258}], {
             RGBColor[
             0.9581785847457627, 0.9655103898305084, 0.8114323389830508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 264}], {
             RGBColor[
             0.9407523220338982, 0.9549797288135593, 0.9729005847457627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 281}], {
             RGBColor[
             0.939895533898305, 0.9050001525423729, 0.641531186440678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 328}], {
             RGBColor[
             0.9578959745762712, 0.9649059152542373, 0.780671966101695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 394}], {
             RGBColor[
             0.9559005423728812, 0.965340406779661, 0.9053049915254237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 186}], {
             RGBColor[
             0.9901199152542373, 0.9782180169491526, 0.42600566101694903`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 213}], {
             RGBColor[
             0.9662499915254237, 0.9707029491525423, 0.7163277372881356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 215}], {
             RGBColor[
             0.9217181525423729, 0.6889145423728814, 0.3210547966101694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 306}], {
             RGBColor[
             0.9651199491525424, 0.8884417966101694, 0.3572455847457626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 308}], {
             RGBColor[
             0.9890056016949152, 0.9874866779661018, 0.6694177033898304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 345}], {
             RGBColor[
             0.9761129745762711, 0.9780587457627119, 0.6996322796610168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 350}], {
             RGBColor[
             0.9761129745762711, 0.9780587457627119, 0.6996322796610168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 378}], {
             RGBColor[
             0.9826880508474576, 0.953148593220339, 0.3971342711864405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 147}], {
             RGBColor[
             0.9786697033898306, 0.9427236949152542, 0.5501618389830508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 193}], {
             RGBColor[
             0.9786697033898306, 0.9427236949152542, 0.5501618389830508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 195}], {
             RGBColor[
             0.9356167966101696, 0.7797019322033898, 0.2813611779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 241}], {
             RGBColor[
             0.9801025593220339, 0.943031779661017, 0.5057400677966103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 242}], {
             RGBColor[
             0.9801025593220339, 0.943031779661017, 0.5057400677966103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 255}], {
             RGBColor[
             0.9308566949152544, 0.758592593220339, 0.2774153644067797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 263}], {
             RGBColor[
             0.9764141101694915, 0.9417909491525425, 0.5875428559322036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 312}], {
             RGBColor[
             0.9574621949152542, 0.9282187457627118, 0.6447956694915254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 331}], {
             RGBColor[
             0.9786697033898306, 0.9427236949152542, 0.5501618389830508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 356}], {
             RGBColor[
             0.9789721186440679, 0.9406138813559322, 0.3826985762711864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 359}], {
             RGBColor[
             0.9514006610169492, 0.8422796949152542, 0.29406124576271186`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 360}], {
             RGBColor[
             0.9797975000000001, 0.9431900677966102, 0.5314713305084746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 380}], {
             RGBColor[
             0.9673251779661016, 0.9355745423728814, 0.6281002118644068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 389}], {
             RGBColor[
             0.9574621949152542, 0.9282187457627118, 0.6447956694915254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 179}], {
             RGBColor[
             0.9525307033898305, 0.9245408474576271, 0.6531433983050847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 196}], {
             RGBColor[
             0.9525307033898305, 0.9245408474576271, 0.6531433983050847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 209}], {
             RGBColor[
             0.977541906779661, 0.9422573220338983, 0.5688523474576271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 286}], {
             RGBColor[
             0.946139372881356, 0.8214204406779662, 0.28982788983050856`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 290}], {
             RGBColor[
             0.9726846949152543, 0.9195212033898306, 0.34838562711864407`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 304}], {
             RGBColor[
             0.8965409576271187, 0.8800021186440679, 0.6514772542372882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 386}], {
             RGBColor[
             0.9792547288135593, 0.9412183559322034, 0.4134589491525423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.9904025254237288, 0.9788224915254238, 0.45676603389830495`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 201}], {
             RGBColor[
             0.9941044576271186, 0.9897983559322034, 0.599684779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 273}], {
             RGBColor[
             0.993256627118644, 0.9879849322033899, 0.5074036610169489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 281}], {
             RGBColor[
             0.9755387966101694, 0.9286836440677966, 0.399023254237288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 293}], {
             RGBColor[
             0.9576133644067797, 0.9643014406779662, 0.7499115932203388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 394}], {
             RGBColor[
             0.9915438050847457, 0.9890238983050847, 0.6627970593220338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 151}], {
             RGBColor[
             0.9887031864406779, 0.9895964915254238, 0.8368809661016949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 158}], {
             RGBColor[
             0.9812578389830509, 0.954792033898305, 0.5832880423728812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 171}], {
             RGBColor[
             0.9531671610169491, 0.8483667288135592, 0.5349326440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 186}], {
             RGBColor[
             0.9886897033898305, 0.9798614576271187, 0.6121594322033899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 272}], {
             RGBColor[
             0.9849737711864406, 0.9673267457627119, 0.5977237372881355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 306}], {
             RGBColor[
             0.9636897372881356, 0.8900852372881356, 0.5433993559322033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 308}], {
             RGBColor[
             0.9875753898305084, 0.9891301186440679, 0.8555714745762713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 342}], {
             RGBColor[
             0.9812578389830509, 0.954792033898305, 0.5832880423728812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 348}], {
             RGBColor[
             0.9812578389830509, 0.954792033898305, 0.5832880423728812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 354}], {
             RGBColor[
             0.977541906779661, 0.9422573220338983, 0.5688523474576271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 374}], {
             RGBColor[
             0.9531671610169491, 0.8483667288135592, 0.5349326440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 378}], {
             RGBColor[
             0.9812578389830509, 0.954792033898305, 0.5832880423728812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 148}], {
             RGBColor[
             0.8912859152542374, 0.5142893898305085, 0.24186611864406782`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 169}], {
             RGBColor[
             0.8834952796610169, 0.5480563559322034, 0.5671475508474576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 218}], {
             RGBColor[
             0.9035749915254236, 0.5620949322033899, 0.4912042288135593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 222}], {
             RGBColor[
             0.9050052033898306, 0.5604514915254237, 0.3050504576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 276}], {
             RGBColor[
             0.9058305847457627, 0.5630276779661016, 0.4538232118644068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 282}], {
             RGBColor[
             0.9050052033898306, 0.5604514915254237, 0.3050504576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 305}], {
             RGBColor[
             0.8982897542372881, 0.5590900508474577, 0.5421043644067797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 339}], {
             RGBColor[
             0.9047027881355932, 0.5625613050847458, 0.472513720338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 361}], {
             RGBColor[
             0.9058530338983051, 0.5622649152542373, 0.3973315762711864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 382}], {
             RGBColor[
             0.9061356440677966, 0.5628693898305085, 0.42809194915254245`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 384}], {
             RGBColor[
             0.856889779661017, 0.3784302033898306, 0.19976724576271188`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 165}], {
             RGBColor[
             0.9946696779661017, 0.9910073050847458, 0.6612055254237288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 170}], {
             RGBColor[
             0.9941044576271186, 0.9897983559322034, 0.599684779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 182}], {
             RGBColor[
             0.9941044576271186, 0.9897983559322034, 0.599684779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 192}], {
             RGBColor[
             0.9943870677966102, 0.9904028305084747, 0.630445152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 208}], {
             RGBColor[
             0.9186703559322034, 0.6592166779661018, 0.4400952033898306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 221}], {
             RGBColor[
             0.9912503559322035, 0.9806359152542373, 0.549047152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 225}], {
             RGBColor[
             0.9949522881355932, 0.991611779661017, 0.6919658983050849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 235}], {
             RGBColor[
             0.9935194322033898, 0.9913036949152543, 0.7363876694915255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 335}], {
             RGBColor[
             0.9875344237288135, 0.9681012033898305, 0.5346114576271187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 349}], {
             RGBColor[
             0.9801025593220339, 0.943031779661017, 0.5057400677966103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 351}], {
             RGBColor[
             0.9838184915254238, 0.9555664915254236, 0.5201757627118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 355}], {
             RGBColor[
             0.9875344237288135, 0.9681012033898305, 0.5346114576271187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 395}], {
             RGBColor[
             0.9363866949152542, 0.7648538813559322, 0.4558645847457628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 151}], {
             RGBColor[
             0.9909587796610169, 0.9905292372881356, 0.7994999491525425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 158}], {
             RGBColor[
             0.9835134322033898, 0.9557247796610169, 0.5459070254237287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 227}], {
             RGBColor[
             0.9937993983050848, 0.9899566440677967, 0.6254160423728812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 243}], {
             RGBColor[
             0.9818698474576271, 0.9843128305084745, 0.8400573050847457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 267}], {
             RGBColor[
             0.9937993983050848, 0.9899566440677967, 0.6254160423728812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 275}], {
             RGBColor[
             0.993214372881356, 0.9914619830508475, 0.7621189322033898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 306}], {
             RGBColor[
             0.9659453305084746, 0.8910179830508475, 0.5060183389830508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 311}], {
             RGBColor[
             0.9909587796610169, 0.9905292372881356, 0.7994999491525425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 317}], {
             RGBColor[
             0.9868013389830508, 0.9879907288135594, 0.8317095762711864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 344}], {
             RGBColor[
             0.9769383559322034, 0.9806349322033898, 0.8484050338983051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 346}], {
             RGBColor[
             0.9920865762711863, 0.9909956101694916, 0.7808094406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 354}], {
             RGBColor[
             0.9797975000000001, 0.9431900677966102, 0.5314713305084746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 195}], {
             RGBColor[
             0.9490336694915255, 0.8279738474576271, 0.5120087796610169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 217}], {
             RGBColor[
             0.9856735423728813, 0.9875243559322034, 0.8504000847457627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 231}], {
             RGBColor[
             0.9648175338983052, 0.8905516101694915, 0.524708847457627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 241}], {
             RGBColor[
             0.9935194322033898, 0.9913036949152543, 0.7363876694915255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 242}], {
             RGBColor[
             0.9935194322033898, 0.9913036949152543, 0.7363876694915255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 255}], {
             RGBColor[
             0.9442735677966102, 0.8068645084745764, 0.5080629661016949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 312}], {
             RGBColor[
             0.9708790677966102, 0.9764906610169491, 0.8754432711864406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 331}], {
             RGBColor[
             0.9920865762711865, 0.9909956101694916, 0.780809440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 359}], {
             RGBColor[
             0.9648175338983052, 0.8905516101694915, 0.524708847457627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 392}], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 218}], {
             RGBColor[
             0.977541906779661, 0.9422573220338983, 0.5688523474576271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 228}], {
             RGBColor[
             0.9764006271186441, 0.9320559152542374, 0.36282132203389833`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 276}], {
             RGBColor[
             0.9797975000000001, 0.9431900677966102, 0.5314713305084746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.9789721186440679, 0.9406138813559322, 0.3826985762711864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 301}], {
             RGBColor[
             0.9615368983050847, 0.8819170677966102, 0.30507854237288135`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 305}], {
             RGBColor[
             0.9722566694915254, 0.9392524406779661, 0.6197524830508474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 313}], {
             RGBColor[
             0.9615368983050847, 0.8819170677966102, 0.30507854237288135`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 339}], {
             RGBColor[
             0.9786697033898306, 0.9427236949152542, 0.5501618389830508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 340}], {
             RGBColor[
             0.9764006271186441, 0.9320559152542374, 0.36282132203389833`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 361}], {
             RGBColor[
             0.9798199491525423, 0.9424273050847458, 0.4749796949152542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 382}], {
             RGBColor[
             0.9801025593220339, 0.943031779661017, 0.5057400677966103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 155}], {
             RGBColor[
             0.9875753898305084, 0.9891301186440679, 0.8555714745762713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 164}], {
             RGBColor[
             0.9431457711864406, 0.8063981355932204, 0.5267534745762712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 210}], {
             RGBColor[
             0.9849737711864406, 0.9673267457627119, 0.5977237372881355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 230}], {
             RGBColor[
             0.9909587796610169, 0.9905292372881356, 0.7994999491525423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 258}], {
             RGBColor[
             0.9921090254237288, 0.9902328474576272, 0.7243178050847456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 264}], {
             RGBColor[
             0.9746827627118644, 0.979702186440678, 0.8857860508474575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 268}], {
             RGBColor[
             0.5843789915254237, 0.6477284322033898, 0.8758457288135593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 279}], {
             RGBColor[
             0.9431457711864406, 0.8063981355932204, 0.5267534745762712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 299}], {
             RGBColor[
             0.9636897372881356, 0.8900852372881356, 0.5433993559322033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 300}], {
             RGBColor[
             0.9697512711864407, 0.9760242881355932, 0.8941337796610169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 328}], {
             RGBColor[
             0.9918264152542373, 0.989628372881356, 0.6935574322033898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 152}], {
             RGBColor[
             0.9181345677966102, 0.7886816610169491, 0.6110445254237289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 156}], {
             RGBColor[
             0.9420179745762711, 0.8059317627118645, 0.5454439830508475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 157}], {
             RGBColor[
             0.8871408305084746, 0.5804146949152543, 0.22753988135593223`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 160}], {
             RGBColor[
             0.9454013644067797, 0.8073308813559323, 0.4893724576271187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 167}], {
             RGBColor[
             0.9420044915254238, 0.7961967288135594, 0.3207224491525424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 179}], {
             RGBColor[
             0.9181345677966102, 0.7886816610169491, 0.6110445254237289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 181}], {
             RGBColor[
             0.9420044915254238, 0.7961967288135594, 0.3207224491525424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 206}], {
             RGBColor[
             0.9345726271186441, 0.7711273050847458, 0.2918510593220338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 211}], {
             RGBColor[
             0.9454013644067797, 0.8073308813559323, 0.4893724576271187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 238}], {
             RGBColor[
             0.9431457711864406, 0.8063981355932204, 0.5267534745762712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 386}], {
             RGBColor[
             0.944858593220339, 0.8053591694915255, 0.37136007627118633`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 158}], {
             RGBColor[
             0.9801300423728814, 0.954325661016949, 0.6019785508474575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 186}], {
             RGBColor[
             0.987561906779661, 0.9793950847457628, 0.6308499406779662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 227}], {
             RGBColor[
             0.9904160084745762, 0.9885575254237289, 0.6814875677966101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 267}], {
             RGBColor[
             0.9904160084745762, 0.9885575254237289, 0.6814875677966101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 306}], {
             RGBColor[
             0.9625619406779661, 0.8896188644067797, 0.5620898644067798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 308}], {
             RGBColor[
             0.9864475932203389, 0.9886637457627119, 0.8742619830508476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 311}], {
             RGBColor[
             0.9875753898305084, 0.9891301186440679, 0.8555714745762714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 317}], {
             RGBColor[
             0.9834179491525423, 0.9865916101694916, 0.8877811016949153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 344}], {
             RGBColor[
             0.9735549661016949, 0.979235813559322, 0.904476559322034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 346}], {
             RGBColor[
             0.9887031864406779, 0.9895964915254238, 0.8368809661016949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 348}], {
             RGBColor[
             0.9801300423728814, 0.954325661016949, 0.6019785508474575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 354}], {
             RGBColor[
             0.9764141101694915, 0.9417909491525425, 0.5875428559322036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 156}], {
             RGBColor[
             0.9636919830508475, 0.9718800169491526, 0.9211720169491526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 157}], {
             RGBColor[
             0.9088148389830508, 0.7463629491525423, 0.6032679152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 160}], {
             RGBColor[
             0.9670753728813559, 0.9732791355932203, 0.8651004915254237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 179}], {
             RGBColor[
             0.9398085762711864, 0.9546299152542372, 0.9867725593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 181}], {
             RGBColor[0.9636785, 0.9621449830508475, 0.6964504830508474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 238}], {
             RGBColor[
             0.964819779661017, 0.9723463898305085, 0.9024815084745763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 245}], {
             RGBColor[0.9659475762711864, 0.9728127627118643, 0.883791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 168}], {
             RGBColor[
             0.9609891016949152, 0.8700004406779662, 0.4760537203389832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 175}], {
             RGBColor[
             0.9601412711864407, 0.8681870169491526, 0.3837726016949151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 211}], {
             RGBColor[
             0.9606840423728813, 0.8701587288135594, 0.5017849830508475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 216}], {
             RGBColor[
             0.9531432118644068, 0.8662211016949153, 0.5900661355932204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 229}], {
             RGBColor[
             0.9009627542372881, 0.8257371525423729, 0.624035720338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 294}], {
             RGBColor[
             0.9573006525423728, 0.8687596101694917, 0.5578565084745764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 329}], {
             RGBColor[
             0.9531432118644068, 0.8662211016949153, 0.5900661355932204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 341}], {
             RGBColor[
             0.893103779661017, 0.6009238305084745, 0.23217579661016952`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 343}], {
             RGBColor[
             0.9561728559322034, 0.8682932372881357, 0.5765470169491527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 358}], {
             RGBColor[
             0.946139372881356, 0.8214204406779662, 0.28982788983050856`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 379}], {
             RGBColor[
             0.9070833728813559, 0.6644018983050848, 0.2438407118644068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 207}], {
             RGBColor[
             0.907469093220339, 0.8142610847457626, 0.6209247711864406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 231}], {
             RGBColor[
             0.9179916694915254, 0.8559795932203389, 0.6293914830508475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 369}], {
             RGBColor[
             0.9418773220338983, 0.9550244745762713, 0.9415636016949153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 372}], {
             RGBColor[
             0.9240532033898305, 0.9419186440677966, 0.980125906779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 387}], {
             RGBColor[
             0.9127303813559322, 0.8351203389830508, 0.625158127118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 392}], {
             RGBColor[
             0.9430051186440678, 0.9554908474576271, 0.9228730932203391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 249}], {
             RGBColor[
             0.9864341101694916, 0.9789287118644068, 0.6495404491525424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 268}], {
             RGBColor[
             0.5821233983050847, 0.646795686440678, 0.9132267457627119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 279}], {
             RGBColor[
             0.9408901779661016, 0.8054653898305086, 0.5641344915254238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.9614341440677966, 0.8891524915254237, 0.580780372881356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 300}], {
             RGBColor[
             0.9674956779661017, 0.9750915423728814, 0.9315147966101696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 370}], {
             RGBColor[
             0.975286313559322, 0.9413245762711865, 0.6062333644067797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 371}], {
             RGBColor[
             0.9875753898305084, 0.9891301186440679, 0.8555714745762713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 160}], {
             RGBColor[
             0.9909587796610169, 0.9905292372881356, 0.7994999491525425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.9636919830508475, 0.9718800169491526, 0.9211720169491526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 181}], {
             RGBColor[
             0.987561906779661, 0.9793950847457628, 0.6308499406779662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 245}], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 352}], {
             RGBColor[
             0.9906986186440678, 0.9891620000000001, 0.7122479406779663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 396}], {
             RGBColor[
             0.9909812288135593, 0.9897664745762712, 0.7430083135593221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 160}], {
             RGBColor[
             0.9360816355932203, 0.7650121694915255, 0.4815958474576271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 167}], {
             RGBColor[
             0.9326847627118644, 0.7538780169491526, 0.31294583898305084`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 168}], {
             RGBColor[
             0.9363866949152542, 0.7648538813559322, 0.4558645847457628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 203}], {
             RGBColor[
             0.9352562542372882, 0.7624359830508475, 0.3328230932203389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 206}], {
             RGBColor[
             0.9252528983050847, 0.728808593220339, 0.28407444915254226`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 211}], {
             RGBColor[
             0.9360816355932203, 0.7650121694915255, 0.4815958474576271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 238}], {
             RGBColor[
             0.9338260423728812, 0.7640794237288135, 0.5189768644067796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 341}], {
             RGBColor[
             0.868501372881356, 0.49577727118644066`, 0.21198666101694913`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 358}], {
             RGBColor[
             0.921536966101695, 0.7162738813559322, 0.26963875423728817`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 386}], {
             RGBColor[
             0.9355388644067797, 0.7630404576271187, 0.3635834661016948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 267}], {
             RGBColor[
             0.9829706610169491, 0.9537530677966102, 0.42789464406779637`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 306}], {
             RGBColor[
             0.9551165932203389, 0.8548144067796609, 0.30849694067796596`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 308}], {
             RGBColor[
             0.9790022457627119, 0.9538592881355932, 0.6206690593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 311}], {
             RGBColor[
             0.9801300423728814, 0.954325661016949, 0.6019785508474575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 317}], {
             RGBColor[
             0.9759726016949153, 0.9517871525423729, 0.6341881779661016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 344}], {
             RGBColor[
             0.9661096186440677, 0.9444313559322033, 0.6508836355932202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 346}], {
             RGBColor[
             0.9812578389830509, 0.954792033898305, 0.5832880423728812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 348}], {
             RGBColor[
             0.9726846949152542, 0.9195212033898303, 0.34838562711864385`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 354}], {
             RGBColor[
             0.9689687627118644, 0.9069864915254237, 0.33394993220338975`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 374}], {
             RGBColor[
             0.9445940169491525, 0.8130958983050847, 0.30003022881355923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 250}], {
             RGBColor[
             0.9665326016949152, 0.9713074237288135, 0.7470881101694914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 265}], {
             RGBColor[
             0.9670753728813559, 0.9732791355932203, 0.8651004915254237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 321}], {
             RGBColor[
             0.9665326016949152, 0.9713074237288135, 0.7470881101694914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 375}], {
             RGBColor[0.9636785, 0.9621449830508475, 0.6964504830508474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 381}], {
             RGBColor[
             0.9670753728813559, 0.9732791355932203, 0.8651004915254237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[
             0.9909452966101695, 0.9807942033898305, 0.5747784152542372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 238}], {
             RGBColor[
             0.9920865762711863, 0.9909956101694916, 0.7808094406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 245}], {
             RGBColor[
             0.993214372881356, 0.9914619830508475, 0.7621189322033898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 196}], {
             RGBColor[
             0.9439398220338983, 0.8932280169491524, 0.6319237627118643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 214}], {
             RGBColor[
             0.9666954322033898, 0.9100117457627118, 0.5850137288135593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 253}], {
             RGBColor[
             0.9566619491525423, 0.8631389491525423, 0.2982946016949153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 283}], {
             RGBColor[
             0.9603778813559322, 0.875673661016949, 0.3127302966101694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 332}], {
             RGBColor[
             0.9703812372881355, 0.9093010508474575, 0.361478940677966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 334}], {
             RGBColor[
             0.964093813559322, 0.8882083728813559, 0.32716599152542364`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.9703812372881355, 0.9093010508474575, 0.361478940677966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 364}], {
             RGBColor[
             0.8879500762711865, 0.8486892881355932, 0.6302576186440678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 366}], {
             RGBColor[
             0.9322872033898304, 0.7692483559322032, 0.2643748983050847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 389}], {
             RGBColor[
             0.948871313559322, 0.8969059152542371, 0.623576033898305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 183}], {
             RGBColor[
             0.9875344237288135, 0.9681012033898305, 0.5346114576271187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 270}], {
             RGBColor[
             0.9772434152542373, 0.9804766440677966, 0.8226737711864407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 280}], {
             RGBColor[
             0.9949522881355932, 0.991611779661017, 0.6919658983050849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 291}], {
             RGBColor[
             0.9901360423728813, 0.9899045762711864, 0.7924591949152544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 336}], {
             RGBColor[
             0.982174906779661, 0.9841545423728814, 0.8143260423728815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 357}], {
             RGBColor[
             0.9584611949152542, 0.9661148644067796, 0.8421927118644068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 368}], {
             RGBColor[
             0.9946472288135593, 0.9917700677966101, 0.7176971610169492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 171}], {
             RGBColor[
             0.9270259152542373, 0.7483891016949151, 0.26014154237288134`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 240}], {
             RGBColor[
             0.9654025593220339, 0.8890462711864406, 0.38800595762711854`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 272}], {
             RGBColor[
             0.9588325254237289, 0.8673491186440678, 0.3229326355932203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 342}], {
             RGBColor[
             0.9551165932203389, 0.8548144067796609, 0.30849694067796596`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 374}], {
             RGBColor[
             0.9270259152542373, 0.7483891016949151, 0.26014154237288134`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 210}], {
             RGBColor[
             0.9382885593220339, 0.7836620169491526, 0.30628675423728813`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 230}], {
             RGBColor[
             0.9442735677966102, 0.8068645084745764, 0.5080629661016949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 258}], {
             RGBColor[
             0.945423813559322, 0.8065681186440679, 0.43288082203389827`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 264}], {
             RGBColor[
             0.9279975508474576, 0.7960374576271187, 0.5943490677966101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 279}], {
             RGBColor[
             0.896460559322034, 0.6227334067796612, 0.23531649152542378`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 328}], {
             RGBColor[
             0.9451412033898305, 0.8059636440677966, 0.4021204491525424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 170}], {
             RGBColor[
             0.993821847457627, 0.9891938813559322, 0.5689244067796608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 172}], {
             RGBColor[
             0.972029313559322, 0.9761942711864406, 0.800261127118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 184}], {
             RGBColor[
             0.9941044576271186, 0.9897983559322034, 0.599684779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 190}], {
             RGBColor[
             0.9909812288135593, 0.9897664745762712, 0.7430083135593221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 192}], {
             RGBColor[
             0.9941044576271186, 0.9897983559322034, 0.599684779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 221}], {
             RGBColor[
             0.9909677457627118, 0.9800314406779661, 0.5182867796610169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 226}], {
             RGBColor[
             0.9943646186440678, 0.9911655932203389, 0.6869367881355932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 252}], {
             RGBColor[
             0.9712290677966101, 0.9111144745762711, 0.4537600593220338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 274}], {
             RGBColor[
             0.9935392372881355, 0.988589406779661, 0.5381640338983049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 288}], {
             RGBColor[
             0.9100312711864407, 0.5943806779661016, 0.4013326610169491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 318}], {
             RGBColor[
             0.9183877457627119, 0.6586122033898306, 0.4093348305084745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 322}], {
             RGBColor[
             0.9818922966101694, 0.9835500677966101, 0.7835656694915254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 351}], {
             RGBColor[
             0.9835358813559322, 0.9549620169491524, 0.4894153898305083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 355}], {
             RGBColor[
             0.987251813559322, 0.9674967288135593, 0.5038510847457626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 399}], {
             RGBColor[
             0.9225659830508475, 0.690727966101695, 0.41333591525423724`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 169}], {
             RGBColor[
             0.8887503220338984, 0.9137690847457627, 0.976758686440678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 246}], {
             RGBColor[
             0.8826887881355933, 0.8278300338983051, 0.6260242627118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 326}], {
             RGBColor[
             0.9039728220338983, 0.9050715423728813, 0.6803486440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 363}], {
             RGBColor[
             0.8838188305084747, 0.910091186440678, 0.9851064152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 383}], {
             RGBColor[
             0.9099578305084746, 0.9282740338983051, 0.8821248559322034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 168}], {
             RGBColor[
             0.9912503559322035, 0.9806359152542373, 0.549047152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.9901199152542373, 0.9782180169491526, 0.42600566101694903`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 211}], {
             RGBColor[
             0.9909452966101695, 0.9807942033898305, 0.5747784152542372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 216}], {
             RGBColor[
             0.983404466101695, 0.9768565762711865, 0.6630595677966101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 238}], {
             RGBColor[
             0.9886897033898305, 0.9798614576271187, 0.6121594322033899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 341}], {
             RGBColor[
             0.923365033898305, 0.7115593050847457, 0.3051692288135593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 358}], {
             RGBColor[
             0.9764006271186441, 0.9320559152542374, 0.36282132203389833`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 211}], {
             RGBColor[
             0.9946472288135593, 0.9917700677966101, 0.7176971610169492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 216}], {
             RGBColor[
             0.9871063983050847, 0.9878324406779662, 0.8059783135593221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 238}], {
             RGBColor[
             0.9923916355932203, 0.9908373220338984, 0.7550781779661018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 341}], {
             RGBColor[
             0.9270669661016949, 0.7225351694915254, 0.44808797457627125`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 379}], {
             RGBColor[
             0.9410465593220338, 0.7860132372881357, 0.45975288983050855`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 218}], {
             RGBColor[
             0.9697512711864407, 0.9760242881355932, 0.8941337796610169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 222}], {
             RGBColor[
             0.9711814830508474, 0.9743808474576271, 0.7079800084745762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 224}], {
             RGBColor[
             0.9697512711864407, 0.9760242881355932, 0.8941337796610169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 276}], {
             RGBColor[
             0.9720068644067796, 0.9769570338983051, 0.8567527627118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 326}], {
             RGBColor[
             0.9648940593220339, 0.9532881694915254, 0.6736670593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 361}], {
             RGBColor[
             0.972029313559322, 0.9761942711864406, 0.800261127118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 363}], {
             RGBColor[
             0.9447400677966101, 0.9583078135593219, 0.9784248305084746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 382}], {
             RGBColor[
             0.9723119237288136, 0.9767987457627119, 0.8310215000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 383}], {
             RGBColor[
             0.9708790677966102, 0.9764906610169491, 0.8754432711864406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 393}], {
             RGBColor[
             0.961178127118644, 0.9407534576271186, 0.6592313644067795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[
             0.9935392372881355, 0.988589406779661, 0.5381640338983049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 208}], {
             RGBColor[
             0.9178225254237289, 0.6574032542372883, 0.3478140847457626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 221}], {
             RGBColor[
             0.9904025254237288, 0.9788224915254238, 0.45676603389830495`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 225}], {
             RGBColor[
             0.9941044576271186, 0.9897983559322034, 0.599684779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 235}], {
             RGBColor[
             0.9926716016949153, 0.9894902711864407, 0.6441065508474575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 322}], {
             RGBColor[
             0.9813270762711863, 0.9823411186440678, 0.7220449237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 335}], {
             RGBColor[
             0.986686593220339, 0.966287779661017, 0.44233033898305063`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 349}], {
             RGBColor[
             0.9792547288135593, 0.9412183559322034, 0.4134589491525423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 351}], {
             RGBColor[
             0.9829706610169491, 0.9537530677966102, 0.42789464406779637`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 355}], {
             RGBColor[
             0.986686593220339, 0.966287779661017, 0.44233033898305063`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 186}], {
             RGBColor[
             0.9520258813559321, 0.8381653220338983, 0.32890161864406775`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 240}], {
             RGBColor[
             0.9548799830508474, 0.8473277627118644, 0.3795392457627117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 272}], {
             RGBColor[
             0.9483099491525424, 0.8256306101694915, 0.3144659237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 308}], {
             RGBColor[
             0.9509115677966101, 0.8474339830508475, 0.5723136610169492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 342}], {
             RGBColor[
             0.9445940169491525, 0.8130958983050847, 0.30003022881355923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 348}], {
             RGBColor[
             0.9445940169491525, 0.8130958983050847, 0.30003022881355923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 374}], {
             RGBColor[
             0.9165033389830508, 0.7066705932203389, 0.25167483050847456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 192}], {
             RGBColor[
             0.9717467033898305, 0.9755897966101694, 0.7695007542372881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 194}], {
             RGBColor[
             0.9717467033898305, 0.9755897966101694, 0.7695007542372881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 221}], {
             RGBColor[
             0.9686099915254237, 0.9658228813559322, 0.6881027542372882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 256}], {
             RGBColor[
             0.8918517542372881, 0.612287881355932, 0.575149720338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 316}], {
             RGBColor[
             0.9714640932203389, 0.9749853220338983, 0.7387403813559321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 351}], {
             RGBColor[
             0.961178127118644, 0.9407534576271186, 0.6592313644067795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 399}], {
             RGBColor[
             0.9002082288135593, 0.676519406779661, 0.5831518898305085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 198}], {
             RGBColor[
             0.8825812033898306, 0.5592053220338983, 0.22370908474576273`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 203}], {
             RGBColor[
             0.9493360847457628, 0.8258640338983051, 0.3445455169491525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 266}], {
             RGBColor[
             0.9501614661016949, 0.8284402203389831, 0.4933182711864407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 313}], {
             RGBColor[
             0.9319008644067797, 0.767167220338983, 0.26692548305084746`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 329}], {
             RGBColor[
             0.9426206355932203, 0.824502593220339, 0.5815994237288136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 340}], {
             RGBColor[
             0.946764593220339, 0.8173060677966102, 0.32466826271186444`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 341}], {
             RGBColor[
             0.8825812033898306, 0.5592053220338983, 0.22370908474576273`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 358}], {
             RGBColor[
             0.9356167966101696, 0.7797019322033898, 0.2813611779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 204}], {
             RGBColor[
             0.9941044576271186, 0.9897983559322034, 0.599684779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 216}], {
             RGBColor[
             0.9862585677966101, 0.9860190169491526, 0.7136971949152541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 229}], {
             RGBColor[
             0.9340781101694915, 0.9455350677966101, 0.7476667796610168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 294}], {
             RGBColor[
             0.9904160084745762, 0.9885575254237289, 0.6814875677966101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 307}], {
             RGBColor[
             0.9929740169491525, 0.9873804576271187, 0.476643288135593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 343}], {
             RGBColor[
             0.9892882118644067, 0.988091152542373, 0.7001780762711863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 379}], {
             RGBColor[
             0.9401987288135594, 0.784199813559322, 0.36747177118644053`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 205}], {
             RGBColor[
             0.987561906779661, 0.9793950847457628, 0.6308499406779662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 232}], {
             RGBColor[
             0.946764593220339, 0.8173060677966102, 0.32466826271186444`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 277}], {
             RGBColor[
             0.9420044915254238, 0.7961967288135594, 0.3207224491525424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 298}], {
             RGBColor[
             0.9838324915254237, 0.9571253389830509, 0.3916927118644067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 320}], {
             RGBColor[
             0.987561906779661, 0.9793950847457628, 0.6308499406779662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 347}], {
             RGBColor[
             0.8917238389830509, 0.9050709322033899, 0.6932099322033898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 373}], {
             RGBColor[
             0.9909452966101695, 0.9807942033898305, 0.5747784152542372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 390}], {
             RGBColor[0.9898175, 0.9803278305084746, 0.5934689237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 219}], {
             RGBColor[
             0.9708790677966102, 0.9764906610169491, 0.8754432711864406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 248}], {
             RGBColor[
             0.9648940593220339, 0.9532881694915254, 0.6736670593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 260}], {
             RGBColor[
             0.961178127118644, 0.9407534576271186, 0.6592313644067795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 285}], {
             RGBColor[
             0.9717467033898305, 0.9755897966101694, 0.7695007542372881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 200}], {
             RGBColor[
             0.946139372881356, 0.8214204406779662, 0.28982788983050856`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 278}], {
             RGBColor[
             0.9308566949152544, 0.758592593220339, 0.2774153644067797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 296}], {
             RGBColor[
             0.9689687627118644, 0.9069864915254237, 0.33394993220338975`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 330}], {
             RGBColor[
             0.9200762118644068, 0.8987684915254237, 0.6537220677966102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 367}], {
             RGBColor[
             0.8912859152542374, 0.5142893898305085, 0.24186611864406782`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 398}], {
             RGBColor[
             0.9795373389830508, 0.9418228305084746, 0.44421932203389836`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 209}], {
             RGBColor[
             0.964819779661017, 0.9723463898305085, 0.9024815084745763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 245}], {
             RGBColor[0.9659475762711864, 0.9728127627118643, 0.883791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 286}], {
             RGBColor[
             0.9334172457627119, 0.8515095084745763, 0.6234570508474576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 290}], {
             RGBColor[
             0.9599625677966102, 0.9496102711864407, 0.6820147881355931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 352}], {
             RGBColor[
             0.9668152118644068, 0.9719118983050847, 0.7778484830508474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 386}], {
             RGBColor[
             0.9665326016949152, 0.9713074237288135, 0.7470881101694914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 232}], {
             RGBColor[
             0.9393327288135593, 0.7922366440677966, 0.2957968728813558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 249}], {
             RGBColor[
             0.9801165593220339, 0.9445906271186439, 0.3772570169491524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 268}], {
             RGBColor[
             0.5758058474576271, 0.6124576016949151, 0.6409433135593219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 370}], {
             RGBColor[
             0.9689687627118644, 0.9069864915254237, 0.33394993220338975`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 238}], {
             RGBColor[
             0.9886897033898305, 0.9798614576271187, 0.6121594322033899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 245}], {
             RGBColor[0.9898175, 0.9803278305084746, 0.5934689237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 187}], {
             RGBColor[
             0.9904160084745762, 0.9885575254237289, 0.6814875677966101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 208}], {
             RGBColor[
             0.9178225254237289, 0.6574032542372883, 0.3478140847457626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 323}], {
             RGBColor[
             0.9792547288135593, 0.9412183559322034, 0.4134589491525423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 377}], {
             RGBColor[
             0.9548799830508474, 0.8473277627118644, 0.3795392457627117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 388}], {
             RGBColor[
             0.9136442881355932, 0.6252874915254236, 0.3438129999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 395}], {
             RGBColor[
             0.9355388644067797, 0.7630404576271187, 0.3635834661016948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 270}], {
             RGBColor[
             0.9698255508474576, 0.9569660677966101, 0.6653193305084746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 291}], {
             RGBColor[0.9827181779661016, 0.966394, 0.6351047542372881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 357}], {
             RGBColor[
             0.9510433305084746, 0.9426042881355932, 0.6848382711864407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 368}], {
             RGBColor[
             0.9872293644067797, 0.9682594915254237, 0.560342720338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 185}], {
             RGBColor[
             0.9832532711864407, 0.9543575423728813, 0.45865501694915245`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 190}], {
             RGBColor[
             0.9906986186440678, 0.9891620000000001, 0.7122479406779663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 226}], {
             RGBColor[
             0.9940820084745763, 0.9905611186440678, 0.6561764152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 252}], {
             RGBColor[
             0.9709464576271186, 0.9105099999999999, 0.422999686440678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 274}], {
             RGBColor[
             0.993256627118644, 0.9879849322033898, 0.5074036610169491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 288}], {
             RGBColor[
             0.9097486610169492, 0.5937762033898304, 0.37057228813559323`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 318}], {
             RGBColor[
             0.9181051355932204, 0.6580077288135595, 0.37857445762711867`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 190}], {
             RGBColor[
             0.9801300423728814, 0.954325661016949, 0.6019785508474575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 226}], {
             RGBColor[
             0.9835134322033898, 0.9557247796610169, 0.5459070254237287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 252}], {
             RGBColor[
             0.9603778813559322, 0.875673661016949, 0.3127302966101694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 274}], {
             RGBColor[
             0.9826880508474576, 0.953148593220339, 0.3971342711864405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 288}], {
             RGBColor[
             0.8991800847457627, 0.5589398644067795, 0.26030289830508463`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 318}], {
             RGBColor[
             0.9075365593220339, 0.6231713898305085, 0.26830506779661006`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 357}], {
             RGBColor[
             0.9473273983050847, 0.9300695762711864, 0.6704025762711863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 272}], {
             RGBColor[
             0.9838324915254237, 0.9571253389830509, 0.3916927118644067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 306}], {
             RGBColor[
             0.9625484576271186, 0.8798838305084746, 0.3373683305084746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 308}], {
             RGBColor[
             0.9864341101694916, 0.9789287118644068, 0.6495404491525424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 342}], {
             RGBColor[
             0.9801165593220339, 0.9445906271186439, 0.3772570169491524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 348}], {
             RGBColor[
             0.9801165593220339, 0.9445906271186439, 0.3772570169491524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 374}], {
             RGBColor[
             0.9520258813559321, 0.8381653220338983, 0.32890161864406775`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 378}], {
             RGBColor[
             0.9801165593220339, 0.9445906271186439, 0.3772570169491524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 208}], {
             RGBColor[
             0.914981906779661, 0.6579758474576273, 0.5218979915254238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 302}], {
             RGBColor[
             0.9726981779661017, 0.9292562372881357, 0.5731071610169493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 377}], {
             RGBColor[
             0.9520393644067796, 0.8479003559322034, 0.5536231525423729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 388}], {
             RGBColor[
             0.9108036694915254, 0.6258600847457625, 0.517896906779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 201}], {
             RGBColor[
             0.9912503559322035, 0.9806359152542373, 0.549047152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 264}], {
             RGBColor[
             0.9735414830508474, 0.9695007796610169, 0.6797550254237288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 273}], {
             RGBColor[
             0.9904025254237288, 0.9788224915254238, 0.45676603389830495`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 281}], {
             RGBColor[
             0.9726846949152542, 0.9195212033898306, 0.34838562711864407`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 293}], {
             RGBColor[0.9547592627118644, 0.955139, 0.6992739661016949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 394}], {
             RGBColor[
             0.9886897033898305, 0.9798614576271187, 0.6121594322033899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 207}], {
             RGBColor[
             0.9408780847457627, 0.8005611864406779, 0.28559453389830514`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 241}], {
             RGBColor[
             0.9801025593220339, 0.943031779661017, 0.5057400677966103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 263}], {
             RGBColor[
             0.9764141101694915, 0.9417909491525425, 0.5875428559322036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 280}], {
             RGBColor[
             0.9801025593220339, 0.943031779661017, 0.5057400677966103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 291}], {
             RGBColor[
             0.975286313559322, 0.9413245762711865, 0.6062333644067797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 336}], {
             RGBColor[
             0.9673251779661016, 0.9355745423728814, 0.6281002118644068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 359}], {
             RGBColor[
             0.9514006610169492, 0.8422796949152542, 0.29406124576271186`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 226}], {
             RGBColor[
             0.9909587796610169, 0.9905292372881356, 0.7994999491525425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 252}], {
             RGBColor[
             0.9678232288135593, 0.9104781186440678, 0.5663232203389831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 274}], {
             RGBColor[
             0.9901333983050847, 0.9879530508474577, 0.6507271949152542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 288}], {
             RGBColor[
             0.9066254322033898, 0.5937443220338983, 0.5138958220338984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 318}], {
             RGBColor[
             0.914981906779661, 0.6579758474576273, 0.5218979915254238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 225}], {
             RGBColor[
             0.9941044576271186, 0.9897983559322034, 0.599684779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 235}], {
             RGBColor[
             0.9926716016949153, 0.9894902711864407, 0.6441065508474575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 261}], {
             RGBColor[
             0.9904025254237288, 0.9788224915254238, 0.45676603389830495`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 322}], {
             RGBColor[
             0.9813270762711863, 0.9823411186440678, 0.7220449237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 327}], {
             RGBColor[
             0.9929740169491525, 0.9873804576271187, 0.476643288135593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 335}], {
             RGBColor[
             0.986686593220339, 0.966287779661017, 0.44233033898305063`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 349}], {
             RGBColor[
             0.9792547288135593, 0.9412183559322034, 0.4134589491525423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 355}], {
             RGBColor[
             0.986686593220339, 0.966287779661017, 0.44233033898305063`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 208}], {
             RGBColor[
             0.9181051355932204, 0.6580077288135595, 0.37857445762711867`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 221}], {
             RGBColor[
             0.9906851355932204, 0.979426966101695, 0.487526406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[
             0.9943870677966102, 0.9904028305084747, 0.630445152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 322}], {
             RGBColor[
             0.9816096864406779, 0.982945593220339, 0.7528052966101695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 335}], {
             RGBColor[
             0.9869692033898305, 0.9668922542372882, 0.47309071186440677`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 349}], {
             RGBColor[
             0.9795373389830508, 0.9418228305084746, 0.44421932203389836`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 351}], {
             RGBColor[
             0.9832532711864407, 0.9543575423728813, 0.45865501694915245`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 355}], {
             RGBColor[
             0.9869692033898305, 0.9668922542372882, 0.47309071186440677`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 399}], {
             RGBColor[
             0.922283372881356, 0.6901234915254237, 0.3825755423728814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 195}], {
             RGBColor[
             0.9490336694915255, 0.8279738474576271, 0.5120087796610169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 242}], {
             RGBColor[
             0.9935194322033898, 0.9913036949152543, 0.7363876694915255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 253}], {
             RGBColor[
             0.9786697033898306, 0.9427236949152542, 0.5501618389830508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 255}], {
             RGBColor[
             0.9442735677966102, 0.8068645084745764, 0.5080629661016949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 283}], {
             RGBColor[
             0.9823856355932203, 0.955258406779661, 0.5645975338983049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 312}], {
             RGBColor[
             0.9708790677966102, 0.9764906610169491, 0.8754432711864406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 332}], {
             RGBColor[
             0.9923889915254238, 0.9888857966101695, 0.6133461779661016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 356}], {
             RGBColor[
             0.9923889915254238, 0.9888857966101695, 0.6133461779661016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 360}], {
             RGBColor[
             0.993214372881356, 0.9914619830508475, 0.7621189322033898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 364}], {
             RGBColor[
             0.9099578305084746, 0.9282740338983051, 0.8821248559322034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 380}], {
             RGBColor[
             0.9807420508474576, 0.9838464576271186, 0.8587478135593221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 389}], {
             RGBColor[
             0.9708790677966102, 0.9764906610169491, 0.8754432711864406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 221}], {
             RGBColor[
             0.9906851355932204, 0.979426966101695, 0.487526406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 233}], {
             RGBColor[
             0.9941044576271186, 0.9897983559322034, 0.599684779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 256}], {
             RGBColor[
             0.9139268983050848, 0.6258919661016947, 0.37457337288135595`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 316}], {
             RGBColor[
             0.9935392372881355, 0.988589406779661, 0.5381640338983049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 399}], {
             RGBColor[
             0.922283372881356, 0.6901234915254237, 0.3825755423728814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 241}], {
             RGBColor[
             0.9504665254237288, 0.8282819322033899, 0.46758700847457635`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 242}], {
             RGBColor[
             0.9504665254237288, 0.8282819322033899, 0.46758700847457635`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.9012206610169492, 0.6438427457627119, 0.2392623050847458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 263}], {
             RGBColor[
             0.9467780762711864, 0.8270411016949153, 0.5493897966101695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 312}], {
             RGBColor[
             0.9278261610169491, 0.8134688983050847, 0.6066426101694915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 356}], {
             RGBColor[
             0.9493360847457628, 0.8258640338983051, 0.3445455169491525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 359}], {
             RGBColor[
             0.9217646271186442, 0.727529847457627, 0.255908186440678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 360}], {
             RGBColor[
             0.9501614661016949, 0.8284402203389831, 0.4933182711864407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 380}], {
             RGBColor[
             0.9376891440677966, 0.8208246949152542, 0.589947152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 389}], {
             RGBColor[
             0.9278261610169491, 0.8134688983050847, 0.6066426101694915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 206}], {
             RGBColor[
             0.9562466355932203, 0.9370755593220338, 0.6675790932203389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 214}], {
             RGBColor[
             0.962564186440678, 0.9714136440677966, 0.9398625254237288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 286}], {
             RGBColor[
             0.9334172457627119, 0.8515095084745763, 0.6234570508474576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 332}], {
             RGBColor[
             0.9662499915254237, 0.9707029491525423, 0.7163277372881355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 334}], {
             RGBColor[
             0.9599625677966102, 0.9496102711864407, 0.6820147881355931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 366}], {
             RGBColor[
             0.9281559576271186, 0.830650254237288, 0.6192236949152542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 386}], {
             RGBColor[
             0.9665326016949152, 0.9713074237288135, 0.7470881101694914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 217}], {
             RGBColor[
             0.9478819237288135, 0.8453618474576271, 0.585832779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 231}], {
             RGBColor[
             0.9270259152542373, 0.7483891016949151, 0.26014154237288134`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 254}], {
             RGBColor[
             0.938018940677966, 0.8380060508474576, 0.6025282372881355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 314}], {
             RGBColor[
             0.9542949576271187, 0.8488331016949152, 0.5162421355932203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 369}], {
             RGBColor[
             0.9509115677966101, 0.8474339830508475, 0.5723136610169492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 392}], {
             RGBColor[
             0.9520393644067796, 0.8479003559322034, 0.5536231525423729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 203}], {
             RGBColor[
             0.9259365254237288, 0.7201172711864406, 0.3250464830508474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 206}], {
             RGBColor[
             0.9159331694915254, 0.6864898813559321, 0.2762978389830507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 214}], {
             RGBColor[
             0.922250720338983, 0.720827966101695, 0.5485812711864407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 266}], {
             RGBColor[
             0.9267619067796611, 0.7226934576271187, 0.4738192372881356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 310}], {
             RGBColor[
             0.8638415084745763, 0.4746179152542373, 0.20809835593220338`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 384}], {
             RGBColor[
             0.8778211016949153, 0.5380959830508475, 0.21976327118644068`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 215}], {
             RGBColor[
             0.905139720338983, 0.6801973050847457, 0.5748041610169492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 222}], {
             RGBColor[
             0.9761129745762711, 0.9780587457627119, 0.6996322796610168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 223}], {
             RGBColor[
             0.9724271694915254, 0.9787694406779661, 0.9231670677966102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 224}], {
             RGBColor[
             0.9746827627118644, 0.979702186440678, 0.8857860508474575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 247}], {
             RGBColor[
             0.9407523220338982, 0.9549797288135593, 0.9729005847457627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 259}], {
             RGBColor[
             0.9769608050847457, 0.9798721694915253, 0.7919133983050847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 271}], {
             RGBColor[
             0.9485415169491525, 0.8797245593220339, 0.6109949491525424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 287}], {
             RGBColor[
             0.9766781949152542, 0.9792676949152542, 0.7611530254237289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 292}], {
             RGBColor[
             0.9735549661016949, 0.979235813559322, 0.904476559322034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 345}], {
             RGBColor[
             0.9595345423728813, 0.9693415084745762, 0.9533816440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 350}], {
             RGBColor[
             0.9595345423728813, 0.9693415084745762, 0.9533816440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 353}], {
             RGBColor[
             0.9693975254237288, 0.9766973050847458, 0.9366861864406779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 393}], {
             RGBColor[
             0.9661096186440677, 0.9444313559322033, 0.6508836355932202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 400}], {
             RGBColor[
             0.9698255508474576, 0.9569660677966101, 0.6653193305084745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 234}], {
             RGBColor[
             0.9595562457627118, 0.8696923559322034, 0.5204754915254237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 296}], {
             RGBColor[
             0.9498553050847458, 0.8339551525423728, 0.30426358474576265`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 298}], {
             RGBColor[
             0.9535712372881355, 0.8464898644067798, 0.3186992796610169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 320}], {
             RGBColor[
             0.9573006525423728, 0.8687596101694917, 0.5578565084745764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 330}], {
             RGBColor[
             0.9009627542372881, 0.8257371525423729, 0.624035720338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 347}], {
             RGBColor[0.8614625847457628, 0.7944354576271186, 0.6202165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 367}], {
             RGBColor[
             0.8721724576271186, 0.4412580508474577, 0.2121797711864407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 398}], {
             RGBColor[
             0.9604238813559323, 0.8687914915254238, 0.41453297457627125`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 273}], {
             RGBColor[
             0.9941044576271186, 0.9897983559322034, 0.599684779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 281}], {
             RGBColor[
             0.9763866271186441, 0.9304970677966102, 0.491304372881356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 293}], {
             RGBColor[
             0.9584611949152542, 0.9661148644067796, 0.8421927118644068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 303}], {
             RGBColor[
             0.9946472288135593, 0.9917700677966101, 0.7176971610169492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 394}], {
             RGBColor[
             0.9923916355932203, 0.9908373220338984, 0.7550781779661018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 212}], {
             RGBColor[
             0.9570283389830508, 0.965806779661017, 0.8866144830508473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 234}], {
             RGBColor[
             0.9920865762711865, 0.9909956101694916, 0.780809440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 239}], {
             RGBColor[
             0.993214372881356, 0.9914619830508475, 0.7621189322033898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 269}], {
             RGBColor[
             0.9570283389830508, 0.965806779661017, 0.8866144830508473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 289}], {
             RGBColor[
             0.9929542118644068, 0.9900947457627118, 0.6748669237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 309}], {
             RGBColor[
             0.9926716016949153, 0.9894902711864407, 0.6441065508474575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 362}], {
             RGBColor[
             0.9932368220338983, 0.990699220338983, 0.7056272966101693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 365}], {
             RGBColor[
             0.9861015677966102, 0.9677931186440678, 0.5790332288135592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 206}], {
             RGBColor[
             0.9826880508474576, 0.953148593220339, 0.3971342711864405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 211}], {
             RGBColor[
             0.9935167881355933, 0.9893521694915255, 0.5946556694915254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 216}], {
             RGBColor[
             0.9859759576271186, 0.9854145423728814, 0.6829368220338982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 266}], {
             RGBColor[
             0.9935167881355933, 0.9893521694915255, 0.5946556694915254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 329}], {
             RGBColor[
             0.9859759576271186, 0.9854145423728814, 0.6829368220338982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 341}], {
             RGBColor[
             0.9259365254237288, 0.7201172711864406, 0.3250464830508474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 358}], {
             RGBColor[
             0.9789721186440679, 0.9406138813559322, 0.3826985762711864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 229}], {
             RGBColor[
             0.9349259406779661, 0.9473484915254238, 0.8399478983050848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 237}], {
             RGBColor[
             0.9838184915254238, 0.9555664915254236, 0.5201757627118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 307}], {
             RGBColor[
             0.9938218474576271, 0.9891938813559322, 0.568924406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 343}], {
             RGBColor[
             0.9901360423728813, 0.9899045762711864, 0.7924591949152544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 232}], {
             RGBColor[
             0.9467780762711864, 0.8270411016949153, 0.5493897966101696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 277}], {
             RGBColor[
             0.9420179745762711, 0.8059317627118645, 0.5454439830508475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 373}], {
             RGBColor[
             0.9909587796610169, 0.9905292372881356, 0.7994999491525425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 390}], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 266}], {
             RGBColor[
             0.9835134322033898, 0.9557247796610169, 0.5459070254237287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 286}], {
             RGBColor[
             0.9498553050847458, 0.8339551525423728, 0.30426358474576265`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 386}], {
             RGBColor[
             0.9829706610169491, 0.9537530677966102, 0.42789464406779637`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 231}], {
             RGBColor[
             0.9270259152542373, 0.7483891016949151, 0.26014154237288134`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 280}], {
             RGBColor[
             0.955727813559322, 0.8491411864406779, 0.47182036440677977`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 291}], {
             RGBColor[
             0.9509115677966101, 0.8474339830508475, 0.5723136610169492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 368}], {
             RGBColor[
             0.9554227542372882, 0.8492994745762712, 0.4975516271186441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 372}], {
             RGBColor[
             0.9330874491525423, 0.8343281525423728, 0.6108759661016949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 387}], {
             RGBColor[
             0.921764627118644, 0.727529847457627, 0.255908186440678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 392}], {
             RGBColor[
             0.9520393644067796, 0.8479003559322034, 0.5536231525423729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 221}], {
             RGBColor[
             0.9149684237288136, 0.6482408135593222, 0.29717645762711864`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 225}], {
             RGBColor[
             0.9186703559322034, 0.6592166779661018, 0.44009520338983066`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 323}], {
             RGBColor[
             0.9038206271186442, 0.6106366779661019, 0.25386937288135597`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 351}], {
             RGBColor[
             0.9075365593220339, 0.6231713898305085, 0.26830506779661006`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 388}], {
             RGBColor[
             0.8382101864406779, 0.29470581355932196`, 0.18422342372881356`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 395}], {
             RGBColor[
             0.8601047627118644, 0.4324587796610171, 0.20399388983050848`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 286}], {
             RGBColor[0.9584284491525423, 0.8692259830508475, 0.539166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 290}], {
             RGBColor[
             0.9849737711864406, 0.9673267457627119, 0.5977237372881355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 304}], {
             RGBColor[
             0.9088300338983051, 0.9278076610169492, 0.9008153644067797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 338}], {
             RGBColor[
             0.9918264152542373, 0.989628372881356, 0.6935574322033898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 386}], {
             RGBColor[
             0.9915438050847457, 0.9890238983050847, 0.6627970593220338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 230}], {
             RGBColor[
             0.9861015677966102, 0.9677931186440678, 0.5790332288135592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 258}], {
             RGBColor[
             0.987251813559322, 0.9674967288135593, 0.5038510847457626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 264}], {
             RGBColor[
             0.9698255508474576, 0.9569660677966101, 0.6653193305084746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 279}], {
             RGBColor[
             0.9382885593220339, 0.7836620169491526, 0.30628675423728813`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 328}], {
             RGBColor[
             0.9869692033898305, 0.9668922542372882, 0.47309071186440677`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 394}], {
             RGBColor[
             0.9849737711864406, 0.9673267457627119, 0.5977237372881355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 216}], {
             RGBColor[
             0.9868013389830508, 0.9879907288135594, 0.8317095762711864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 238}], {
             RGBColor[
             0.9920865762711863, 0.9909956101694916, 0.7808094406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 341}], {
             RGBColor[
             0.9267619067796611, 0.7226934576271187, 0.4738192372881356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 358}], {
             RGBColor[
             0.9797975000000001, 0.9431900677966102, 0.5314713305084746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 239}], {
             RGBColor[
             0.9581561355932203, 0.9662731525423729, 0.8679239745762712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 289}], {
             RGBColor[
             0.9578959745762712, 0.9649059152542373, 0.780671966101695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 309}], {
             RGBColor[
             0.9576133644067797, 0.9643014406779662, 0.7499115932203388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 362}], {
             RGBColor[
             0.9581785847457627, 0.9655103898305084, 0.8114323389830508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 385}], {
             RGBColor[
             0.9510433305084746, 0.9426042881355932, 0.6848382711864406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 215}], {
             RGBColor[
             0.8952767372881356, 0.6728415084745762, 0.5914996186440677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 227}], {
             RGBColor[
             0.9665326016949152, 0.9713074237288135, 0.7470881101694914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 259}], {
             RGBColor[
             0.9670978220338983, 0.972516372881356, 0.8086088559322033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 306}], {
             RGBColor[
             0.938678533898305, 0.8723687627118644, 0.627690406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 308}], {
             RGBColor[
             0.962564186440678, 0.9714136440677966, 0.9398625254237288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 345}], {
             RGBColor[
             0.9496715593220338, 0.9619857118644067, 0.9700771016949152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 350}], {
             RGBColor[
             0.9496715593220338, 0.9619857118644067, 0.9700771016949152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 378}], {
             RGBColor[
             0.9562466355932203, 0.9370755593220338, 0.6675790932203389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 257}], {
             RGBColor[
             0.9790022457627119, 0.9538592881355932, 0.6206690593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 310}], {
             RGBColor[
             0.9269105847457627, 0.7419873220338984, 0.5524695762711864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 332}], {
             RGBColor[
             0.9890056016949152, 0.9874866779661018, 0.6694177033898304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 389}], {
             RGBColor[
             0.9674956779661017, 0.9750915423728814, 0.9315147966101696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 224}], {
             RGBColor[
             0.920287940677966, 0.6905579830508475, 0.5072085677966102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 227}], {
             RGBColor[
             0.9220007627118644, 0.6895190169491525, 0.35181516949152525`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 259}], {
             RGBColor[
             0.9225659830508475, 0.690727966101695, 0.4133359152542372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 345}], {
             RGBColor[
             0.905139720338983, 0.6801973050847459, 0.5748041610169491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 350}], {
             RGBColor[
             0.905139720338983, 0.6801973050847459, 0.5748041610169491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 353}], {
             RGBColor[
             0.9150027033898305, 0.6875531016949152, 0.5581087033898304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 393}], {
             RGBColor[
             0.9117147966101695, 0.6552871525423729, 0.2723061525423728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 400}], {
             RGBColor[
             0.9154307288135592, 0.6678218644067797, 0.28674184745762704`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 229}], {
             RGBColor[
             0.9270800508474576, 0.9435691525423728, 0.953960313559322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 294}], {
             RGBColor[
             0.9834179491525423, 0.9865916101694916, 0.8877811016949153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 329}], {
             RGBColor[
             0.9792605084745762, 0.9840531016949153, 0.9199907288135593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 340}], {
             RGBColor[
             0.983404466101695, 0.9768565762711865, 0.6630595677966101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 341}], {
             RGBColor[
             0.9192210762711864, 0.7187558305084746, 0.5621003898305084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 343}], {
             RGBColor[
             0.9822901525423728, 0.9861252372881357, 0.9064716101694915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 358}], {
             RGBColor[
             0.9722566694915254, 0.9392524406779661, 0.6197524830508474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 231}], {
             RGBColor[0.9584045, 0.8870803559322034, 0.5942994915254237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 254}], {
             RGBColor[
             0.9693975254237288, 0.9766973050847458, 0.9366861864406779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 314}], {
             RGBColor[
             0.9856735423728813, 0.9875243559322034, 0.8504000847457627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 331}], {
             RGBColor[
             0.9856735423728813, 0.9875243559322034, 0.8504000847457627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 392}], {
             RGBColor[
             0.9834179491525423, 0.9865916101694916, 0.8877811016949153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 222}], {
             RGBColor[
             0.9912611949152542, 0.9884194237288135, 0.6320366864406779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 276}], {
             RGBColor[
             0.9920865762711863, 0.9909956101694916, 0.7808094406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 282}], {
             RGBColor[
             0.9912611949152542, 0.9884194237288135, 0.6320366864406779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 305}], {
             RGBColor[
             0.9845457457627118, 0.9870579830508475, 0.869090593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 339}], {
             RGBColor[
             0.9909587796610169, 0.9905292372881356, 0.7994999491525423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 361}], {
             RGBColor[
             0.9921090254237288, 0.9902328474576272, 0.7243178050847456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 382}], {
             RGBColor[
             0.9923916355932203, 0.9908373220338984, 0.7550781779661018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 384}], {
             RGBColor[
             0.9431457711864406, 0.8063981355932204, 0.5267534745762712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 248}], {
             RGBColor[
             0.9861015677966102, 0.9677931186440678, 0.5790332288135592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 251}], {
             RGBColor[
             0.9334930847457628, 0.947040406779661, 0.8843696694915253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 260}], {
             RGBColor[
             0.9823856355932203, 0.955258406779661, 0.5645975338983049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 352}], {
             RGBColor[
             0.9906986186440678, 0.9891620000000001, 0.7122479406779663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 396}], {
             RGBColor[
             0.9909812288135593, 0.9897664745762712, 0.7430083135593221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 256}], {
             RGBColor[
             0.910790186440678, 0.6161250508474574, 0.29317537288135587`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 316}], {
             RGBColor[
             0.9904025254237288, 0.9788224915254238, 0.45676603389830495`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 351}], {
             RGBColor[
             0.9801165593220339, 0.9445906271186439, 0.3772570169491524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 399}], {
             RGBColor[
             0.9191466610169492, 0.6803565762711865, 0.30117754237288136`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 223}], {
             RGBColor[
             0.9890056016949152, 0.9874866779661018, 0.6694177033898304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 224}], {
             RGBColor[
             0.9912611949152542, 0.9884194237288135, 0.6320366864406779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 247}], {
             RGBColor[
             0.9573307542372882, 0.963696966101695, 0.7191512203389829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 259}], {
             RGBColor[
             0.9935392372881355, 0.988589406779661, 0.5381640338983049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 292}], {
             RGBColor[
             0.9901333983050847, 0.9879530508474577, 0.6507271949152542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 363}], {
             RGBColor[
             0.9662499915254237, 0.9707029491525423, 0.7163277372881356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 383}], {
             RGBColor[
             0.9923889915254238, 0.9888857966101695, 0.6133461779661016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 393}], {
             RGBColor[
             0.9826880508474576, 0.953148593220339, 0.3971342711864405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 247}], {
             RGBColor[
             0.9536449491525423, 0.9644076610169492, 0.9426860084745763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 292}], {
             RGBColor[
             0.9864475932203389, 0.9886637457627119, 0.8742619830508476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 319}], {
             RGBColor[
             0.9864475932203389, 0.9886637457627119, 0.8742619830508476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 385}], {
             RGBColor[0.9827181779661016, 0.966394, 0.6351047542372881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 393}], {
             RGBColor[
             0.9790022457627119, 0.9538592881355932, 0.6206690593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 400}], {
             RGBColor[0.9827181779661016, 0.966394, 0.6351047542372881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 227}], {
             RGBColor[
             0.9915438050847457, 0.9890238983050847, 0.6627970593220338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 259}], {
             RGBColor[
             0.9921090254237288, 0.9902328474576272, 0.7243178050847456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 363}], {
             RGBColor[
             0.964819779661017, 0.9723463898305085, 0.9024815084745763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 383}], {
             RGBColor[
             0.9909587796610169, 0.9905292372881356, 0.7994999491525423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 393}], {
             RGBColor[
             0.9812578389830509, 0.954792033898305, 0.5832880423728812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 235}], {
             RGBColor[
             0.9935194322033898, 0.9913036949152543, 0.7363876694915255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 261}], {
             RGBColor[
             0.9912503559322035, 0.9806359152542373, 0.549047152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 322}], {
             RGBColor[
             0.982174906779661, 0.9841545423728814, 0.8143260423728815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 327}], {
             RGBColor[
             0.9938218474576271, 0.9891938813559322, 0.568924406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 335}], {
             RGBColor[
             0.9875344237288135, 0.9681012033898305, 0.5346114576271187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 349}], {
             RGBColor[
             0.9801025593220339, 0.943031779661017, 0.5057400677966103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 355}], {
             RGBColor[
             0.9875344237288135, 0.9681012033898305, 0.5346114576271187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 252}], {
             RGBColor[
             0.9712066186440678, 0.9118772372881355, 0.5102516949152542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 274}], {
             RGBColor[
             0.9935167881355933, 0.9893521694915255, 0.5946556694915254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 288}], {
             RGBColor[
             0.9100088220338983, 0.595143440677966, 0.4578242966101695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 315}], {
             RGBColor[
             0.9946472288135593, 0.9917700677966101, 0.7176971610169492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 318}], {
             RGBColor[
             0.9183652966101695, 0.659374966101695, 0.4658264661016949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 322}], {
             RGBColor[
             0.9818698474576271, 0.9843128305084745, 0.8400573050847457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 243}], {
             RGBColor[
             0.9813270762711863, 0.9823411186440678, 0.7220449237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 306}], {
             RGBColor[
             0.9654025593220339, 0.8890462711864406, 0.38800595762711854`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 311}], {
             RGBColor[
             0.9904160084745762, 0.9885575254237289, 0.6814875677966101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 346}], {
             RGBColor[
             0.9915438050847457, 0.9890238983050847, 0.6627970593220338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 350}], {
             RGBColor[
             0.9763955847457626, 0.9786632203389831, 0.7303926525423727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 363}], {
             RGBColor[
             0.9665326016949152, 0.9713074237288135, 0.7470881101694914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 383}], {
             RGBColor[
             0.9926716016949153, 0.9894902711864407, 0.6441065508474575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 276}], {
             RGBColor[
             0.9909452966101695, 0.9807942033898305, 0.5747784152542372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 282}], {
             RGBColor[
             0.9901199152542373, 0.9782180169491526, 0.42600566101694903`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 301}], {
             RGBColor[
             0.9726846949152542, 0.9195212033898306, 0.34838562711864407`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 305}], {
             RGBColor[
             0.983404466101695, 0.9768565762711865, 0.6630595677966101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 382}], {
             RGBColor[
             0.9912503559322035, 0.9806359152542373, 0.549047152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 294}], {
             RGBColor[
             0.9312374915254237, 0.9461076610169492, 0.921750686440678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 307}], {
             RGBColor[0.9337955, 0.9449305932203389, 0.7169064067796609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[
             0.9270800508474576, 0.9435691525423728, 0.953960313559322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 340}], {
             RGBColor[
             0.9312240084745762, 0.9363726271186441, 0.6970291525423729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 343}], {
             RGBColor[
             0.9301096949152542, 0.9456412881355932, 0.9404411949152542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 258}], {
             RGBColor[
             0.9932368220338983, 0.990699220338983, 0.7056272966101693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 264}], {
             RGBColor[
             0.9758105593220339, 0.980168559322034, 0.8670955423728812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 279}], {
             RGBColor[
             0.9442735677966102, 0.8068645084745764, 0.5080629661016949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 299}], {
             RGBColor[
             0.9648175338983052, 0.8905516101694915, 0.524708847457627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 300}], {
             RGBColor[
             0.9708790677966102, 0.9764906610169491, 0.8754432711864406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 328}], {
             RGBColor[
             0.9929542118644068, 0.9900947457627118, 0.6748669237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 331}], {
             RGBColor[
             0.9648175338983052, 0.8905516101694915, 0.5247088474576271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 369}], {
             RGBColor[
             0.9614341440677966, 0.8891524915254237, 0.5807803728813559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 372}], {
             RGBColor[
             0.9436100254237287, 0.8760466610169491, 0.6193426779661018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 392}], {
             RGBColor[
             0.9625619406779661, 0.8896188644067797, 0.5620898644067798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 277}], {
             RGBColor[
             0.9012206610169492, 0.6438427457627119, 0.2392623050847458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 373}], {
             RGBColor[
             0.9501614661016949, 0.8284402203389831, 0.4933182711864407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 390}], {
             RGBColor[
             0.9490336694915255, 0.8279738474576271, 0.5120087796610169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 256}], {
             RGBColor[
             0.9142095084745763, 0.6264964406779658, 0.40533374576271175`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 257}], {
             RGBColor[
             0.9835358813559322, 0.9549620169491524, 0.4894153898305083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 310}], {
             RGBColor[
             0.931444220338983, 0.7430900508474576, 0.421215906779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 316}], {
             RGBColor[
             0.993821847457627, 0.9891938813559322, 0.5689244067796608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 389}], {
             RGBColor[
             0.972029313559322, 0.9761942711864406, 0.800261127118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 298}], {
             RGBColor[
             0.9861015677966102, 0.9677931186440678, 0.5790332288135592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 365}], {
             RGBColor[
             0.9861015677966102, 0.9677931186440678, 0.5790332288135592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 261}], {
             RGBColor[0.9898175, 0.9803278305084746, 0.5934689237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 322}], {
             RGBColor[
             0.9807420508474576, 0.9838464576271186, 0.8587478135593221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 327}], {
             RGBColor[
             0.9923889915254238, 0.9888857966101695, 0.6133461779661016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 335}], {
             RGBColor[
             0.9861015677966102, 0.9677931186440678, 0.5790332288135592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 349}], {
             RGBColor[
             0.9786697033898306, 0.9427236949152542, 0.5501618389830508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 355}], {
             RGBColor[
             0.9861015677966102, 0.9677931186440678, 0.5790332288135592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 262}], {
             RGBColor[
             0.9700788220338983, 0.9114108644067795, 0.5289422033898304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 284}], {
             RGBColor[
             0.9935194322033898, 0.9913036949152543, 0.7363876694915255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 334}], {
             RGBColor[
             0.9861015677966102, 0.9677931186440678, 0.5790332288135592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 366}], {
             RGBColor[
             0.9542949576271187, 0.8488331016949152, 0.5162421355932203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 376}], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 397}], {
             RGBColor[
             0.9130592627118643, 0.6267928305084745, 0.4805158898305084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 307}], {
             RGBColor[
             0.9826880508474576, 0.953148593220339, 0.3971342711864405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 324}], {
             RGBColor[
             0.9835134322033898, 0.9557247796610169, 0.5459070254237287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 269}], {
             RGBColor[
             0.9581561355932203, 0.9662731525423729, 0.8679239745762712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 309}], {
             RGBColor[
             0.9937993983050848, 0.9899566440677967, 0.6254160423728812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 323}], {
             RGBColor[
             0.9797975000000001, 0.9431900677966102, 0.5314713305084746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 362}], {
             RGBColor[
             0.9943646186440678, 0.9911655932203389, 0.6869367881355932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 365}], {
             RGBColor[
             0.9872293644067797, 0.9682594915254237, 0.560342720338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 377}], {
             RGBColor[
             0.9554227542372882, 0.8492994745762712, 0.4975516271186441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 385}], {
             RGBColor[
             0.9872293644067797, 0.9682594915254237, 0.560342720338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 388}], {
             RGBColor[
             0.9141870593220338, 0.6272592033898303, 0.4618253813559322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 272}], {
             RGBColor[
             0.986686593220339, 0.966287779661017, 0.44233033898305063`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 342}], {
             RGBColor[
             0.9829706610169491, 0.9537530677966102, 0.42789464406779637`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 374}], {
             RGBColor[
             0.9548799830508474, 0.8473277627118644, 0.3795392457627117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 242}], {
             RGBColor[
             0.9949522881355932, 0.991611779661017, 0.6919658983050849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 255}], {
             RGBColor[
             0.9457064237288135, 0.8071725932203391, 0.46364119491525435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 312}], {
             RGBColor[
             0.9723119237288136, 0.9767987457627119, 0.8310215000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 331}], {
             RGBColor[
             0.9935194322033898, 0.9913036949152543, 0.7363876694915255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 359}], {
             RGBColor[
             0.9662503898305085, 0.8908596949152543, 0.4802870762711865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 360}], {
             RGBColor[
             0.9946472288135593, 0.9917700677966101, 0.7176971610169492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 380}], {
             RGBColor[
             0.982174906779661, 0.9841545423728814, 0.8143260423728815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 392}], {
             RGBColor[
             0.9912638389830508, 0.9903709491525424, 0.7737686864406781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 255}], {
             RGBColor[
             0.9457064237288135, 0.8071725932203391, 0.46364119491525435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 312}], {
             RGBColor[
             0.9723119237288136, 0.9767987457627119, 0.8310215000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 331}], {
             RGBColor[
             0.9935194322033898, 0.9913036949152543, 0.7363876694915255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 380}], {
             RGBColor[
             0.982174906779661, 0.9841545423728814, 0.8143260423728815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 267}], {
             RGBColor[
             0.9813270762711863, 0.9823411186440678, 0.7220449237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 275}], {
             RGBColor[
             0.9807420508474576, 0.9838464576271186, 0.8587478135593221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 311}], {
             RGBColor[
             0.9784864576271186, 0.9829137118644068, 0.8961288305084747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 326}], {
             RGBColor[
             0.9747570423728813, 0.9606439661016949, 0.6569716016949152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 344}], {
             RGBColor[
             0.964466033898305, 0.9730194067796609, 0.9450339152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 346}], {
             RGBColor[
             0.9796142542372881, 0.9833800847457628, 0.8774383220338984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 363}], {
             RGBColor[
             0.9546030508474576, 0.9656636101694915, 0.961729372881356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 383}], {
             RGBColor[
             0.9807420508474576, 0.9838464576271186, 0.8587478135593221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 302}], {
             RGBColor[
             0.9715703813559322, 0.9287898644067797, 0.5917976694915255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 352}], {
             RGBColor[
             0.9929542118644068, 0.9900947457627118, 0.6748669237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 396}], {
             RGBColor[
             0.9932368220338983, 0.990699220338983, 0.7056272966101693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 248}], {
             RGBColor[
             0.9588325254237289, 0.8673491186440678, 0.3229326355932203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 251}], {
             RGBColor[
             0.9062240423728813, 0.846596406779661, 0.6282690762711864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 260}], {
             RGBColor[
             0.9551165932203389, 0.8548144067796609, 0.30849694067796596`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 326}], {
             RGBColor[
             0.9588325254237289, 0.8673491186440678, 0.3229326355932203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 271}], {
             RGBColor[
             0.9297592966101695, 0.8653627796610169, 0.6305138898305085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 287}], {
             RGBColor[
             0.9578959745762712, 0.9649059152542373, 0.780671966101695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 292}], {
             RGBColor[
             0.9547727457627118, 0.9648740338983051, 0.9239955000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 319}], {
             RGBColor[
             0.9547727457627118, 0.9648740338983051, 0.9239955000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 362}], {
             RGBColor[
             0.9581785847457627, 0.9655103898305084, 0.8114323389830508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 385}], {
             RGBColor[
             0.9510433305084746, 0.9426042881355932, 0.6848382711864406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 393}], {
             RGBColor[
             0.9473273983050847, 0.9300695762711864, 0.6704025762711863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 400}], {
             RGBColor[
             0.9510433305084746, 0.9426042881355932, 0.6848382711864406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 251}], {
             RGBColor[
             0.9275080762711865, 0.9238379152542373, 0.6825934576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 260}], {
             RGBColor[
             0.9764006271186441, 0.9320559152542371, 0.36282132203389816`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 275}], {
             RGBColor[
             0.9861015677966102, 0.9677931186440678, 0.5790332288135592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 268}], {
             RGBColor[
             0.5832377118644068, 0.6375270254237289, 0.6698147033898305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 279}], {
             RGBColor[
             0.9420044915254238, 0.7961967288135594, 0.3207224491525424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 299}], {
             RGBColor[
             0.9625484576271186, 0.8798838305084746, 0.3373683305084746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 300}], {
             RGBColor[
             0.9686099915254237, 0.9658228813559322, 0.6881027542372882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 370}], {
             RGBColor[
             0.9764006271186441, 0.9320559152542374, 0.36282132203389833`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 265}], {
             RGBColor[
             0.9937993983050848, 0.9899566440677967, 0.6254160423728812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 321}], {
             RGBColor[
             0.993256627118644, 0.9879849322033899, 0.5074036610169489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 325}], {
             RGBColor[
             0.9813270762711863, 0.9823411186440678, 0.7220449237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 375}], {
             RGBColor[
             0.9904025254237288, 0.9788224915254238, 0.45676603389830495`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 381}], {
             RGBColor[
             0.9937993983050848, 0.9899566440677967, 0.6254160423728812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 260}], {
             RGBColor[
             0.9237921440677965, 0.9113032033898304, 0.6681577627118642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 275}], {
             RGBColor[
             0.9334930847457628, 0.947040406779661, 0.8843696694915253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 274}], {
             RGBColor[
             0.9703812372881355, 0.9093010508474575, 0.361478940677966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 288}], {
             RGBColor[
             0.8868732711864407, 0.5150923220338981, 0.22464756779661013`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 318}], {
             RGBColor[
             0.8952297457627119, 0.5793238474576272, 0.2326497372881356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 283}], {
             RGBColor[
             0.9689687627118644, 0.9069864915254237, 0.33394993220338975`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 332}], {
             RGBColor[
             0.9789721186440679, 0.9406138813559322, 0.3826985762711864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 334}], {
             RGBColor[
             0.9726846949152543, 0.9195212033898306, 0.34838562711864407`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 364}], {
             RGBColor[
             0.8965409576271187, 0.8800021186440679, 0.6514772542372882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 366}], {
             RGBColor[
             0.9408780847457627, 0.8005611864406779, 0.28559453389830514`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 391}], {
             RGBColor[
             0.9356167966101696, 0.7797019322033898, 0.2813611779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 314}], {
             RGBColor[
             0.9758105593220339, 0.980168559322034, 0.8670955423728812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 369}], {
             RGBColor[
             0.9724271694915254, 0.9787694406779661, 0.9231670677966102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 312}], {
             RGBColor[
             0.9230660593220339, 0.792359559322034, 0.6026967966101695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 331}], {
             RGBColor[
             0.9442735677966102, 0.8068645084745764, 0.5080629661016949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 356}], {
             RGBColor[
             0.9445759830508476, 0.8047546949152543, 0.3405997033898305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 359}], {
             RGBColor[
             0.9170045254237289, 0.7064205084745763, 0.2519623728813559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 360}], {
             RGBColor[
             0.9454013644067797, 0.8073308813559323, 0.4893724576271187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 380}], {
             RGBColor[
             0.9329290423728813, 0.7997153559322034, 0.586001338983051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 310}], {
             RGBColor[0.8512666610169491, 0.379183661016949, 0.1961045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 316}], {
             RGBColor[
             0.9136442881355932, 0.6252874915254236, 0.3438129999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 319}], {
             RGBColor[
             0.9108036694915254, 0.6258600847457625, 0.517896906779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 384}], {
             RGBColor[
             0.8652462542372881, 0.4426617288135592, 0.20776941525423728`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 310}], {
             RGBColor[
             0.920593033898305, 0.7076492372881356, 0.2801861440677965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 356}], {
             RGBColor[
             0.9826880508474576, 0.953148593220339, 0.3971342711864405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 360}], {
             RGBColor[
             0.9835134322033898, 0.9557247796610169, 0.5459070254237287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 389}], {
             RGBColor[
             0.961178127118644, 0.9407534576271186, 0.6592313644067795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 264}], {
             RGBColor[
             0.9769608050847457, 0.9798721694915253, 0.7919133983050847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 279}], {
             RGBColor[
             0.945423813559322, 0.8065681186440679, 0.43288082203389827`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 281}], {
             RGBColor[
             0.9761040169491525, 0.929892593220339, 0.46054399999999995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 300}], {
             RGBColor[
             0.972029313559322, 0.9761942711864406, 0.800261127118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 328}], {
             RGBColor[
             0.9941044576271186, 0.9897983559322034, 0.599684779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 394}], {
             RGBColor[
             0.9921090254237288, 0.9902328474576272, 0.7243178050847456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 271}], {
             RGBColor[
             0.9659677796610169, 0.8902552203389831, 0.4495267033898305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 287}], {
             RGBColor[
             0.9941044576271186, 0.9897983559322034, 0.599684779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 292}], {
             RGBColor[
             0.9909812288135593, 0.9897664745762712, 0.7430083135593221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 345}], {
             RGBColor[
             0.9769608050847457, 0.9798721694915253, 0.7919133983050847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 350}], {
             RGBColor[
             0.9769608050847457, 0.9798721694915253, 0.7919133983050847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 353}], {
             RGBColor[
             0.9868237881355932, 0.9872279661016949, 0.775217940677966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 393}], {
             RGBColor[
             0.9835358813559322, 0.9549620169491524, 0.4894153898305083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 400}], {
             RGBColor[
             0.987251813559322, 0.9674967288135593, 0.5038510847457626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 327}], {
             RGBColor[
             0.9901199152542373, 0.9782180169491526, 0.42600566101694903`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 335}], {
             RGBColor[
             0.9838324915254237, 0.9571253389830509, 0.3916927118644067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 349}], {
             RGBColor[
             0.9764006271186441, 0.9320559152542374, 0.36282132203389833`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 355}], {
             RGBColor[
             0.9838324915254237, 0.9571253389830509, 0.3916927118644067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 284}], {
             RGBColor[
             0.9715116779661017, 0.9117189491525424, 0.4845204322033899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 325}], {
             RGBColor[
             0.9587342966101694, 0.9042617118644067, 0.6068805762711864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 376}], {
             RGBColor[
             0.9678232288135593, 0.9104781186440678, 0.5663232203389832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 397}], {
             RGBColor[
             0.8910515084745763, 0.5472080847457624, 0.22864865254237282`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 336}], {
             RGBColor[
             0.9784864576271186, 0.9829137118644068, 0.8961288305084747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 359}], {
             RGBColor[
             0.9625619406779661, 0.8896188644067797, 0.5620898644067798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 360}], {
             RGBColor[
             0.9909587796610169, 0.9905292372881356, 0.7994999491525425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 279}], {
             RGBColor[
             0.9279975508474576, 0.7960374576271187, 0.5943490677966101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 281}], {
             RGBColor[
             0.9586777542372881, 0.9193619322033898, 0.6220122457627119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 328}], {
             RGBColor[
             0.9766781949152542, 0.9792676949152542, 0.7611530254237289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 394}], {
             RGBColor[
             0.9746827627118644, 0.979702186440678, 0.8857860508474575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 321}], {
             RGBColor[
             0.9937993983050848, 0.9899566440677967, 0.6254160423728812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 325}], {
             RGBColor[
             0.9818698474576271, 0.9843128305084745, 0.8400573050847457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 375}], {
             RGBColor[
             0.9909452966101695, 0.9807942033898305, 0.5747784152542372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 381}], {
             RGBColor[
             0.9943421694915254, 0.9919283559322034, 0.7434284237288136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 358}], {
             RGBColor[
             0.9797975000000001, 0.9431900677966102, 0.5314713305084746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 384}], {
             RGBColor[
             0.9454013644067797, 0.8073308813559323, 0.4893724576271187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 275}], {
             RGBColor[
             0.9926716016949153, 0.9894902711864407, 0.6441065508474575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 306}], {
             RGBColor[
             0.9654025593220339, 0.8890462711864406, 0.38800595762711854`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 311}], {
             RGBColor[
             0.9904160084745762, 0.9885575254237289, 0.6814875677966101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 317}], {
             RGBColor[
             0.9862585677966101, 0.9860190169491526, 0.7136971949152541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 344}], {
             RGBColor[
             0.9763955847457626, 0.9786632203389831, 0.7303926525423727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 346}], {
             RGBColor[
             0.9915438050847457, 0.9890238983050847, 0.6627970593220338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 354}], {
             RGBColor[
             0.9792547288135593, 0.9412183559322034, 0.4134589491525423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 279}], {
             RGBColor[
             0.5376937796610171, 0.4640637033898306, 0.5844087457627118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 299}], {
             RGBColor[
             0.5582377457627119, 0.5477508050847457, 0.6010546271186441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 300}], {
             RGBColor[
             0.5642992796610169, 0.6336898559322033, 0.9517890508474576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 370}], {
             RGBColor[
             0.5720899152542374, 0.5999228898305085, 0.6265076186440679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 371}], {
             RGBColor[
             0.5843789915254236, 0.6477284322033898, 0.8758457288135593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 309}], {
             RGBColor[
             0.9576133644067797, 0.9643014406779662, 0.7499115932203388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 323}], {
             RGBColor[
             0.943611466101695, 0.9175348644067797, 0.6559668813559323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 362}], {
             RGBColor[
             0.9581785847457627, 0.9655103898305084, 0.8114323389830508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 365}], {
             RGBColor[
             0.9510433305084746, 0.9426042881355932, 0.6848382711864406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 377}], {
             RGBColor[
             0.9192367203389831, 0.8236442711864407, 0.6220471779661016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 388}], {
             RGBColor[
             0.8780010254237287, 0.6016039999999998, 0.5863209322033898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 336}], {
             RGBColor[
             0.964466033898305, 0.9730194067796609, 0.9450339152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 357}], {
             RGBColor[
             0.9407523220338982, 0.9549797288135593, 0.9729005847457627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 287}], {
             RGBColor[
             0.9656851694915254, 0.8896507457627119, 0.41876633050847456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 292}], {
             RGBColor[
             0.9625619406779661, 0.8896188644067797, 0.5620898644067798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 303}], {
             RGBColor[
             0.9659453305084746, 0.8910179830508475, 0.5060183389830508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 333}], {
             RGBColor[
             0.9476847288135593, 0.8297449830508474, 0.2796255508474576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 337}], {
             RGBColor[
             0.9322872033898305, 0.7692483559322034, 0.26437489830508476`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 345}], {
             RGBColor[
             0.9485415169491525, 0.8797245593220339, 0.6109949491525424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 353}], {
             RGBColor[0.9584045, 0.8870803559322034, 0.5942994915254236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 385}], {
             RGBColor[
             0.9588325254237289, 0.8673491186440678, 0.3229326355932203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 391}], {
             RGBColor[
             0.9217646271186442, 0.727529847457627, 0.255908186440678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 400}], {
             RGBColor[
             0.9588325254237289, 0.8673491186440678, 0.3229326355932203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 308}], {
             RGBColor[0.9827181779661016, 0.966394, 0.6351047542372881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 342}], {
             RGBColor[
             0.9764006271186441, 0.9320559152542371, 0.36282132203389816`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 348}], {
             RGBColor[
             0.9764006271186441, 0.9320559152542371, 0.36282132203389816`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 374}], {
             RGBColor[
             0.9483099491525424, 0.8256306101694915, 0.3144659237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 375}], {
             RGBColor[
             0.9838324915254237, 0.9571253389830509, 0.3916927118644067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 378}], {
             RGBColor[
             0.9764006271186441, 0.9320559152542371, 0.36282132203389816`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 281}], {
             RGBColor[
             0.9755387966101694, 0.9286836440677966, 0.399023254237288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 293}], {
             RGBColor[
             0.9576133644067797, 0.9643014406779662, 0.7499115932203388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 394}], {
             RGBColor[
             0.9915438050847457, 0.9890238983050847, 0.6627970593220338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 288}], {
             RGBColor[
             0.9091834406779662, 0.5925672542372881, 0.30905154237288124`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 318}], {
             RGBColor[
             0.9175399152542374, 0.6567987796610171, 0.31705371186440673`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 311}], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 317}], {
             RGBColor[
             0.9856735423728813, 0.9875243559322034, 0.8504000847457627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 344}], {
             RGBColor[
             0.9758105593220339, 0.980168559322034, 0.8670955423728812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 346}], {
             RGBColor[
             0.9909587796610169, 0.9905292372881356, 0.7994999491525423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 282}], {
             RGBColor[
             0.9935167881355933, 0.9893521694915255, 0.5946556694915254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 301}], {
             RGBColor[
             0.9760815677966102, 0.9306553559322034, 0.5170356355932203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 305}], {
             RGBColor[
             0.9868013389830508, 0.9879907288135594, 0.8317095762711864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 339}], {
             RGBColor[
             0.993214372881356, 0.9914619830508475, 0.7621189322033898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 361}], {
             RGBColor[
             0.9943646186440678, 0.9911655932203389, 0.6869367881355932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 382}], {
             RGBColor[
             0.9946472288135593, 0.9917700677966101, 0.7176971610169492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 373}], {
             RGBColor[
             0.9454013644067797, 0.8073308813559323, 0.4893724576271187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 390}], {
             RGBColor[
             0.9442735677966102, 0.8068645084745764, 0.5080629661016949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 296}], {
             RGBColor[
             0.9345726271186441, 0.7711273050847458, 0.2918510593220338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 302}], {
             RGBColor[
             0.9271407627118644, 0.7460578813559322, 0.2629796694915254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 330}], {
             RGBColor[
             0.8856800762711865, 0.7629093050847457, 0.6116231949152542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 367}], {
             RGBColor[
             0.856889779661017, 0.3784302033898306, 0.19976724576271188`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 299}], {
             RGBColor[
             0.9170045254237289, 0.7064205084745763, 0.2519623728813559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 300}], {
             RGBColor[
             0.9230660593220339, 0.792359559322034, 0.6026967966101695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 328}], {
             RGBColor[
             0.9451412033898305, 0.8059636440677966, 0.4021204491525424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 370}], {
             RGBColor[
             0.9308566949152544, 0.758592593220339, 0.2774153644067797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 371}], {
             RGBColor[
             0.9431457711864406, 0.8063981355932204, 0.5267534745762712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 291}], {
             RGBColor[
             0.9901360423728813, 0.9899045762711864, 0.7924591949152544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 336}], {
             RGBColor[
             0.982174906779661, 0.9841545423728814, 0.8143260423728815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 368}], {
             RGBColor[
             0.9946472288135593, 0.9917700677966101, 0.7176971610169492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 387}], {
             RGBColor[
             0.9609891016949152, 0.8700004406779662, 0.4760537203389832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 392}], {
             RGBColor[
             0.9912638389830508, 0.9903709491525424, 0.7737686864406781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 293}], {
             RGBColor[
             0.939895533898305, 0.9050001525423729, 0.6415311864406779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 394}], {
             RGBColor[
             0.9738259745762712, 0.9297226101694915, 0.5544166525423728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 301}], {
             RGBColor[
             0.9752561864406779, 0.9280791694915254, 0.3682628813559321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 305}], {
             RGBColor[
             0.9859759576271186, 0.9854145423728814, 0.6829368220338982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 313}], {
             RGBColor[
             0.9752561864406779, 0.9280791694915254, 0.3682628813559321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 339}], {
             RGBColor[
             0.9923889915254238, 0.9888857966101695, 0.6133461779661016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 340}], {
             RGBColor[
             0.9901199152542373, 0.9782180169491526, 0.42600566101694903`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 361}], {
             RGBColor[
             0.9935392372881355, 0.988589406779661, 0.5381640338983049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 382}], {
             RGBColor[
             0.9938218474576271, 0.9891938813559322, 0.568924406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 312}], {
             RGBColor[
             0.961178127118644, 0.9407534576271186, 0.6592313644067795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 332}], {
             RGBColor[
             0.9826880508474576, 0.953148593220339, 0.3971342711864405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 334}], {
             RGBColor[
             0.9764006271186441, 0.9320559152542371, 0.36282132203389816`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 356}], {
             RGBColor[
             0.9826880508474576, 0.953148593220339, 0.3971342711864405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 360}], {
             RGBColor[
             0.9835134322033898, 0.9557247796610169, 0.5459070254237287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 364}], {
             RGBColor[
             0.9002568898305086, 0.8925368305084744, 0.6659129491525423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 366}], {
             RGBColor[
             0.9445940169491525, 0.8130958983050847, 0.30003022881355923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 380}], {
             RGBColor[
             0.9710411101694915, 0.948109254237288, 0.642535906779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 389}], {
             RGBColor[
             0.961178127118644, 0.9407534576271186, 0.6592313644067795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 334}], {
             RGBColor[
             0.9875344237288135, 0.9681012033898305, 0.5346114576271187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 366}], {
             RGBColor[
             0.955727813559322, 0.8491411864406779, 0.47182036440677977`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 397}], {
             RGBColor[
             0.9144921186440678, 0.6271009152542371, 0.4360941186440679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 324}], {
             RGBColor[
             0.9940820084745763, 0.9905611186440678, 0.6561764152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 290}], {
             RGBColor[
             0.9535712372881355, 0.8464898644067798, 0.3186992796610169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 304}], {
             RGBColor[0.8774275, 0.806970779661017, 0.621790906779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 386}], {
             RGBColor[
             0.9601412711864407, 0.8681870169491526, 0.3837726016949151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 292}], {
             RGBColor[
             0.9906986186440678, 0.9891620000000001, 0.7122479406779663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 303}], {
             RGBColor[
             0.9940820084745763, 0.9905611186440678, 0.6561764152542373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 353}], {
             RGBColor[
             0.9865411779661017, 0.9866234915254237, 0.7444575677966101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 385}], {
             RGBColor[
             0.9869692033898305, 0.9668922542372882, 0.47309071186440677`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 391}], {
             RGBColor[
             0.9499013050847458, 0.8270729830508474, 0.4060662627118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 400}], {
             RGBColor[
             0.9869692033898305, 0.9668922542372882, 0.47309071186440677`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 318}], {
             RGBColor[
             0.8340319491525424, 0.2625900508474577, 0.18022233898305084`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 304}], {
             RGBColor[
             0.9039728220338983, 0.9050715423728813, 0.6803486440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 338}], {
             RGBColor[
             0.9869692033898305, 0.9668922542372882, 0.47309071186440677`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 336}], {
             RGBColor[
             0.9773586610169491, 0.9824473389830508, 0.9148193389830509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 368}], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 387}], {
             RGBColor[
             0.9561728559322034, 0.8682932372881357, 0.5765470169491526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 303}], {
             RGBColor[
             0.9909587796610169, 0.9905292372881356, 0.7994999491525425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 309}], {
             RGBColor[
             0.9904160084745762, 0.9885575254237289, 0.6814875677966101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 362}], {
             RGBColor[
             0.9909812288135593, 0.9897664745762712, 0.7430083135593221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 385}], {
             RGBColor[
             0.9838459745762711, 0.966860372881356, 0.6164142457627119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 400}], {
             RGBColor[
             0.9838459745762711, 0.966860372881356, 0.6164142457627119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 394}], {
             RGBColor[
             0.9559005423728812, 0.965340406779661, 0.9053049915254237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 301}], {
             RGBColor[
             0.9726981779661017, 0.9292562372881357, 0.5731071610169493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 313}], {
             RGBColor[
             0.9726981779661017, 0.9292562372881357, 0.5731071610169493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 329}], {
             RGBColor[
             0.9834179491525423, 0.9865916101694916, 0.8877811016949153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 340}], {
             RGBColor[
             0.987561906779661, 0.9793950847457628, 0.6308499406779662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 343}], {
             RGBColor[
             0.9864475932203389, 0.9886637457627119, 0.8742619830508476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 330}], {
             RGBColor[
             0.9237921440677965, 0.9113032033898304, 0.6681577627118642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 367}], {
             RGBColor[
             0.8950018474576271, 0.5268241016949151, 0.2563018135593219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 398}], {
             RGBColor[
             0.9832532711864407, 0.9543575423728813, 0.45865501694915245`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 325}], {
             RGBColor[
             0.9142895847457626, 0.7150779322033898, 0.5704481186440679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 375}], {
             RGBColor[
             0.923365033898305, 0.7115593050847457, 0.3051692288135593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 376}], {
             RGBColor[
             0.9233785169491525, 0.7212943389830508, 0.5298907627118645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 378}], {
             RGBColor[
             0.9159331694915254, 0.6864898813559321, 0.2762978389830507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 397}], {
             RGBColor[
             0.8466067966101695, 0.35802430508474553`, 0.1922161949152542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 320}], {
             RGBColor[
             0.9838459745762711, 0.966860372881356, 0.6164142457627119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 347}], {
             RGBColor[
             0.8880079067796611, 0.892536220338983, 0.6787742372881356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 373}], {
             RGBColor[
             0.9872293644067797, 0.9682594915254237, 0.560342720338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 390}], {
             RGBColor[
             0.9861015677966102, 0.9677931186440678, 0.5790332288135592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 300}], {
             RGBColor[
             0.9436100254237287, 0.8760466610169491, 0.6193426779661018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 370}], {
             RGBColor[
             0.9514006610169492, 0.8422796949152542, 0.29406124576271186`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 371}], {
             RGBColor[
             0.9636897372881356, 0.8900852372881356, 0.5433993559322035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 370}], {
             RGBColor[
             0.9574621949152542, 0.9282187457627118, 0.6447956694915254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 371}], {
             RGBColor[
             0.9697512711864407, 0.9760242881355932, 0.8941337796610169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 305}], {
             RGBColor[
             0.9685407372881356, 0.9267177288135593, 0.6053167881355932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 313}], {
             RGBColor[
             0.9578209661016949, 0.8693823559322034, 0.2906428474576271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 329}], {
             RGBColor[
             0.9685407372881356, 0.9267177288135593, 0.6053167881355932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 339}], {
             RGBColor[
             0.9749537711864407, 0.9301889830508474, 0.5357261440677965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 340}], {
             RGBColor[
             0.9726846949152542, 0.9195212033898306, 0.34838562711864407`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 361}], {
             RGBColor[
             0.9761040169491525, 0.929892593220339, 0.46054399999999995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 382}], {
             RGBColor[
             0.9763866271186441, 0.9304970677966102, 0.491304372881356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 367}], {
             RGBColor[
             0.8875699830508474, 0.5017546779661017, 0.22743042372881356`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 377}], {
             RGBColor[
             0.9371621525423728, 0.7880264745762711, 0.2711588389830508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 353}], {
             RGBColor[
             0.9868013389830508, 0.9879907288135594, 0.8317095762711864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 385}], {
             RGBColor[
             0.9872293644067797, 0.9682594915254237, 0.560342720338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 391}], {
             RGBColor[
             0.9501614661016949, 0.8284402203389831, 0.49331827118644067`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 400}], {
             RGBColor[
             0.9872293644067797, 0.9682594915254237, 0.560342720338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 338}], {
             RGBColor[
             0.910825466101695, 0.9273731694915255, 0.7761823389830509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 313}], {
             RGBColor[
             0.9685407372881356, 0.9267177288135593, 0.6053167881355932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 329}], {
             RGBColor[
             0.9792605084745762, 0.9840531016949153, 0.9199907288135593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 339}], {
             RGBColor[
             0.9856735423728813, 0.9875243559322034, 0.8504000847457627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 340}], {
             RGBColor[
             0.983404466101695, 0.9768565762711865, 0.6630595677966101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 361}], {
             RGBColor[
             0.9868237881355932, 0.9872279661016949, 0.775217940677966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 382}], {
             RGBColor[
             0.9871063983050847, 0.9878324406779662, 0.8059783135593221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 308}], {
             RGBColor[
             0.9614341440677966, 0.8891524915254237, 0.5807803728813559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 311}], {
             RGBColor[
             0.9625619406779661, 0.8896188644067797, 0.5620898644067798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 346}], {
             RGBColor[
             0.9636897372881356, 0.8900852372881356, 0.5433993559322035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 348}], {
             RGBColor[
             0.9551165932203389, 0.8548144067796609, 0.30849694067796596`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 350}], {
             RGBColor[
             0.9485415169491525, 0.8797245593220339, 0.6109949491525424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 354}], {
             RGBColor[
             0.9514006610169492, 0.8422796949152542, 0.29406124576271186`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 378}], {
             RGBColor[
             0.9551165932203389, 0.8548144067796609, 0.30849694067796596`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 343}], {
             RGBColor[
             0.9890056016949152, 0.9874866779661018, 0.6694177033898304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 348}], {
             RGBColor[
             0.9790022457627119, 0.9538592881355932, 0.6206690593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 354}], {
             RGBColor[
             0.975286313559322, 0.9413245762711865, 0.6062333644067797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 374}], {
             RGBColor[
             0.9509115677966101, 0.8474339830508475, 0.5723136610169491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 378}], {
             RGBColor[
             0.9790022457627119, 0.9538592881355932, 0.6206690593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 323}], {
             RGBColor[
             0.9792547288135593, 0.9412183559322034, 0.4134589491525423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 362}], {
             RGBColor[
             0.993821847457627, 0.9891938813559322, 0.5689244067796608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 365}], {
             RGBColor[
             0.986686593220339, 0.966287779661017, 0.44233033898305063`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 385}], {
             RGBColor[
             0.986686593220339, 0.966287779661017, 0.44233033898305063`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 316}], {
             RGBColor[0.930879, 0.7418811016949154, 0.35969516101694904`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 319}], {
             RGBColor[
             0.9280383813559322, 0.7424536949152543, 0.5337790677966103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 384}], {
             RGBColor[
             0.882480966101695, 0.559255338983051, 0.22365157627118648`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 317}], {
             RGBColor[
             0.9834179491525423, 0.9865916101694916, 0.8877811016949153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 344}], {
             RGBColor[
             0.9735549661016949, 0.979235813559322, 0.904476559322034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 346}], {
             RGBColor[
             0.9887031864406779, 0.9895964915254238, 0.8368809661016949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 354}], {
             RGBColor[
             0.9764141101694915, 0.9417909491525425, 0.5875428559322036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 356}], {
             RGBColor[
             0.9711814830508474, 0.9743808474576271, 0.7079800084745762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 359}], {
             RGBColor[
             0.9436100254237287, 0.8760466610169491, 0.6193426779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 360}], {
             RGBColor[
             0.9720068644067796, 0.9769570338983051, 0.8567527627118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 380}], {
             RGBColor[
             0.9595345423728813, 0.9693415084745762, 0.9533816440677967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 389}], {
             RGBColor[
             0.9496715593220338, 0.9619857118644067, 0.9700771016949152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 329}], {
             RGBColor[
             0.9685407372881356, 0.9267177288135593, 0.6053167881355932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 339}], {
             RGBColor[
             0.9749537711864407, 0.9301889830508474, 0.5357261440677965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 340}], {
             RGBColor[
             0.9726846949152542, 0.9195212033898306, 0.34838562711864407`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 358}], {
             RGBColor[
             0.9615368983050847, 0.8819170677966102, 0.30507854237288135`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 361}], {
             RGBColor[
             0.9761040169491525, 0.929892593220339, 0.46054399999999995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 369}], {
             RGBColor[
             0.9887031864406779, 0.9895964915254238, 0.8368809661016949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 322}], {
             RGBColor[
             0.982174906779661, 0.9841545423728814, 0.8143260423728815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 351}], {
             RGBColor[
             0.9829706610169491, 0.9537530677966102, 0.42789464406779637`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 399}], {
             RGBColor[
             0.9220007627118644, 0.6895190169491526, 0.3518151694915253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 344}], {
             RGBColor[
             0.9693975254237288, 0.9766973050847458, 0.9366861864406779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 346}], {
             RGBColor[
             0.9845457457627118, 0.9870579830508475, 0.869090593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 354}], {
             RGBColor[
             0.9722566694915254, 0.9392524406779661, 0.6197524830508474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 322}], {
             RGBColor[
             0.9058929745762712, 0.6517594406779662, 0.5624553474576272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 384}], {
             RGBColor[
             0.9420179745762711, 0.8059317627118645, 0.5454439830508475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 347}], {
             RGBColor[
             0.8917373220338983, 0.914805966101695, 0.9179314661016951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 398}], {
             RGBColor[
             0.9906986186440678, 0.9891620000000001, 0.7122479406779663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 375}], {
             RGBColor[
             0.9904025254237288, 0.9788224915254238, 0.45676603389830495`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 381}], {
             RGBColor[
             0.9937993983050848, 0.9899566440677967, 0.6254160423728812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 327}], {
             RGBColor[
             0.9810444661016948, 0.9817366440677966, 0.6912845508474575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 335}], {
             RGBColor[
             0.9747570423728813, 0.9606439661016949, 0.6569716016949152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 349}], {
             RGBColor[
             0.9673251779661016, 0.9355745423728814, 0.6281002118644068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 355}], {
             RGBColor[
             0.9747570423728813, 0.9606439661016949, 0.6569716016949152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 362}], {
             RGBColor[
             0.9798199491525423, 0.9424273050847458, 0.4749796949152542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 365}], {
             RGBColor[
             0.9726846949152543, 0.9195212033898306, 0.34838562711864407`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 377}], {
             RGBColor[
             0.9408780847457627, 0.8005611864406779, 0.28559453389830514`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 388}], {
             RGBColor[
             0.8996423898305085, 0.5785209152542371, 0.24986828813559323`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 395}], {
             RGBColor[
             0.921536966101695, 0.7162738813559322, 0.26963875423728817`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 376}], {
             RGBColor[
             0.9784864576271186, 0.9829137118644068, 0.8961288305084747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 397}], {
             RGBColor[
             0.9017147372881356, 0.6196436779661014, 0.5584542627118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 363}], {
             RGBColor[
             0.9599625677966102, 0.9496102711864407, 0.6820147881355931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 383}], {
             RGBColor[
             0.9861015677966102, 0.9677931186440678, 0.5790332288135592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 335}], {
             RGBColor[
             0.9864039830508475, 0.9656833050847458, 0.4115699661016948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 349}], {
             RGBColor[
             0.9789721186440679, 0.9406138813559322, 0.3826985762711864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 355}], {
             RGBColor[
             0.9864039830508475, 0.9656833050847458, 0.4115699661016948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 339}], {
             RGBColor[
             0.9856735423728813, 0.9875243559322034, 0.8504000847457627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 340}], {
             RGBColor[
             0.983404466101695, 0.9768565762711865, 0.6630595677966101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 341}], {
             RGBColor[
             0.9192210762711864, 0.7187558305084746, 0.5621003898305084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 343}], {
             RGBColor[
             0.9822901525423728, 0.9861252372881357, 0.9064716101694915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 358}], {
             RGBColor[
             0.9722566694915254, 0.9392524406779661, 0.6197524830508474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 367}], {
             RGBColor[
             0.8461092966101695, 0.5186061016949153, 0.5760739491525424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 398}], {
             RGBColor[
             0.934360720338983, 0.9461395423728813, 0.7784271525423729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 392}], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 334}], {
             RGBColor[
             0.9864039830508475, 0.9656833050847458, 0.4115699661016948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 356}], {
             RGBColor[
             0.9926914067796611, 0.9867759830508475, 0.4458829152542371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 364}], {
             RGBColor[
             0.9102602457627119, 0.926164220338983, 0.7146615932203388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 366}], {
             RGBColor[
             0.9545973728813559, 0.8467232881355932, 0.34877887288135584`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 380}], {
             RGBColor[
             0.9810444661016948, 0.9817366440677966, 0.6912845508474575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 389}], {
             RGBColor[
             0.9711814830508474, 0.9743808474576271, 0.7079800084745762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 337}], {
             RGBColor[
             0.9424234406779661, 0.8088857288135594, 0.27539219491525424`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 345}], {
             RGBColor[
             0.9586777542372881, 0.9193619322033898, 0.6220122457627117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 353}], {
             RGBColor[
             0.9685407372881356, 0.9267177288135593, 0.6053167881355932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 391}], {
             RGBColor[
             0.9319008644067797, 0.767167220338983, 0.26692548305084746`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 364}], {
             RGBColor[
             0.9039728220338983, 0.9050715423728813, 0.6803486440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 366}], {
             RGBColor[
             0.9483099491525424, 0.8256306101694915, 0.3144659237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 391}], {
             RGBColor[
             0.9430486610169492, 0.8047713559322034, 0.3102325677966101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 349}], {
             RGBColor[
             0.9726846949152543, 0.9195212033898306, 0.34838562711864407`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 355}], {
             RGBColor[
             0.9801165593220339, 0.944590627118644, 0.3772570169491524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 359}], {
             RGBColor[
             0.9534730084745762, 0.8834024576271187, 0.6026472203389831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 345}], {
             RGBColor[
             0.9432802288135593, 0.8588653050847458, 0.606761593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 353}], {
             RGBColor[
             0.9531432118644068, 0.8662211016949153, 0.5900661355932204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 391}], {
             RGBColor[
             0.9165033389830508, 0.706670593220339, 0.2516748305084746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 340}], {
             RGBColor[0.9898175, 0.9803278305084746, 0.5934689237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 361}], {
             RGBColor[
             0.9932368220338983, 0.990699220338983, 0.7056272966101693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 382}], {
             RGBColor[
             0.9935194322033898, 0.9913036949152543, 0.7363876694915255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 343}], {
             RGBColor[
             0.9864341101694916, 0.9789287118644068, 0.6495404491525424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 358}], {
             RGBColor[
             0.9764006271186441, 0.9320559152542374, 0.36282132203389833`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 361}], {
             RGBColor[
             0.9909677457627118, 0.9800314406779661, 0.5182867796610169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 358}], {
             RGBColor[
             0.9122172372881356, 0.6739551694915253, 0.2618621440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 348}], {
             RGBColor[
             0.9726846949152542, 0.9195212033898303, 0.34838562711864385`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 374}], {
             RGBColor[
             0.9445940169491525, 0.8130958983050847, 0.30003022881355923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 346}], {
             RGBColor[
             0.9746827627118644, 0.979702186440678, 0.8857860508474575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 354}], {
             RGBColor[
             0.9623936864406779, 0.9318966440677966, 0.6364479406779662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 350}], {
             RGBColor[
             0.9595345423728813, 0.9693415084745762, 0.9533816440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 353}], {
             RGBColor[
             0.9693975254237288, 0.9766973050847458, 0.9366861864406779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 354}], {
             RGBColor[
             0.977541906779661, 0.9422573220338983, 0.5688523474576271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 398}], {
             RGBColor[
             0.8948605508474576, 0.9148378474576271, 0.7746079322033899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 354}], {
             RGBColor[
             0.9689687627118644, 0.9069864915254237, 0.33394993220338975`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 374}], {
             RGBColor[
             0.9445940169491525, 0.8130958983050847, 0.30003022881355923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 378}], {
             RGBColor[
             0.9726846949152542, 0.9195212033898303, 0.34838562711864385`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 355}], {
             RGBColor[
             0.9726846949152543, 0.9195212033898306, 0.34838562711864407`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 355}], {
             RGBColor[
             0.9764006271186441, 0.9320559152542371, 0.36282132203389816`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 395}], {
             RGBColor[
             0.9252528983050847, 0.728808593220339, 0.28407444915254226`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 399}], {
             RGBColor[
             0.9117147966101695, 0.6552871525423728, 0.2723061525423728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 396}], {
             RGBColor[
             0.9941044576271186, 0.9897983559322034, 0.599684779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 391}], {
             RGBColor[
             0.9426206355932203, 0.824502593220339, 0.5815994237288136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 400}], {
             RGBColor[
             0.979688533898305, 0.9643218644067797, 0.6486238728813558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 374}], {
             RGBColor[
             0.9408780847457627, 0.8005611864406779, 0.28559453389830514`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 359}], {
             RGBColor[
             0.9651199491525424, 0.8884417966101694, 0.3572455847457626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 360}], {
             RGBColor[
             0.9935167881355933, 0.9893521694915255, 0.5946556694915254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 364}], {
             RGBColor[
             0.9102602457627119, 0.926164220338983, 0.7146615932203388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 380}], {
             RGBColor[
             0.9810444661016948, 0.9817366440677966, 0.6912845508474575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 389}], {
             RGBColor[
             0.9711814830508474, 0.9743808474576271, 0.7079800084745762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 360}], {
             RGBColor[
             0.9659453305084746, 0.8910179830508475, 0.5060183389830508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 380}], {
             RGBColor[
             0.9818698474576271, 0.9843128305084745, 0.8400573050847457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 389}], {
             RGBColor[
             0.9720068644067796, 0.9769570338983051, 0.8567527627118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 382}], {
             RGBColor[
             0.9946696779661017, 0.9910073050847458, 0.6612055254237288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 365}], {
             RGBColor[
             0.987251813559322, 0.9674967288135593, 0.5038510847457626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 385}], {
             RGBColor[
             0.987251813559322, 0.9674967288135593, 0.5038510847457626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 383}], {
             RGBColor[0.9659475762711864, 0.9728127627118643, 0.883791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 393}], {
             RGBColor[
             0.9562466355932203, 0.9370755593220338, 0.6675790932203389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 366}], {
             RGBColor[
             0.8721662118644068, 0.7861115254237288, 0.6175575508474577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 380}], {
             RGBColor[
             0.8986133050847458, 0.9211248813559322, 0.9600632288135593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 391}], {
             RGBColor[
             0.8669049237288136, 0.7652522711864407, 0.6133241949152543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 377}], {
             RGBColor[
             0.9483099491525424, 0.8256306101694915, 0.3144659237288135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 388}], {
             RGBColor[
             0.907074254237288, 0.6035903389830506, 0.2787396779661016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 372}], {
             RGBColor[
             0.9720068644067796, 0.9769570338983051, 0.8567527627118644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 387}], {
             RGBColor[
             0.9606840423728813, 0.8701587288135594, 0.5017849830508475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 387}], {
             RGBColor[
             0.9383487372881356, 0.855187406779661, 0.6151093220338983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 392}], {
             RGBColor[
             0.9686234745762712, 0.9755579152542373, 0.9128242881355932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 390}], {
             RGBColor[
             0.993214372881356, 0.9914619830508475, 0.7621189322033898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 381}], {
             RGBColor[
             0.9909452966101695, 0.9807942033898305, 0.5747784152542372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 397}], {
             RGBColor[
             0.9108036694915254, 0.6258600847457625, 0.517896906779661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 388}], {
             RGBColor[
             0.8752676440677966, 0.48463032203389805`, 0.21594858474576267`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 389}], {
             RGBColor[
             0.9595345423728813, 0.9693415084745762, 0.9533816440677967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 393}], {
             RGBColor[
             0.9823856355932203, 0.955258406779661, 0.5645975338983049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 400}], {
             RGBColor[
             0.9801165593220339, 0.944590627118644, 0.3772570169491524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 395}], {
             RGBColor[
             0.8559265254237287, 0.40034301694915236`, 0.19999280508474573`]},
             StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.027885652381746694`], {
             RGBColor[
             0.8507448983050847, 0.3910531016949153, 0.1962266779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.027885652381746694`], {
             RGBColor[
             0.9920865762711865, 0.9909956101694916, 0.780809440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.027885652381746694`], {
             RGBColor[
             0.9943870677966101, 0.9904028305084746, 0.6304451525423728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.027885652381746694`], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.027885652381746694`], {
             RGBColor[
             0.9059807627118645, 0.6649520847457627, 0.24320811864406783`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.027885652381746694`], {
             RGBColor[
             0.9496715593220338, 0.9619857118644067, 0.9700771016949152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.027885652381746694`], {
             RGBColor[
             0.896460559322034, 0.6227334067796612, 0.23531649152542378`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.027885652381746694`], {
             RGBColor[
             0.9270259152542373, 0.7483891016949153, 0.2601415423728814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.027885652381746694`], {
             RGBColor[
             0.9875753898305084, 0.9891301186440679, 0.8555714745762714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.027885652381746694`], {
             RGBColor[
             0.9398085762711864, 0.9546299152542372, 0.9867725593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.027885652381746694`], {
             RGBColor[
             0.9949522881355932, 0.991611779661017, 0.6919658983050849]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.027885652381746694`], {
             RGBColor[
             0.9853197966101694, 0.988197372881356, 0.8929524915254238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.027885652381746694`], {
             RGBColor[
             0.9792605084745762, 0.9840531016949153, 0.9199907288135593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.027885652381746694`], {
             RGBColor[
             0.9949522881355932, 0.991611779661017, 0.6919658983050849]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.027885652381746694`], {
             RGBColor[
             0.9938218474576271, 0.9891938813559322, 0.568924406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.027885652381746694`], {
             RGBColor[
             0.9938218474576271, 0.9891938813559322, 0.568924406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.027885652381746694`], {
             RGBColor[
             0.9219701016949152, 0.9406179491525424, 0.9924195254237288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.027885652381746694`], {
             RGBColor[
             0.9059807627118645, 0.6649520847457627, 0.24320811864406783`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.027885652381746694`], {
             RGBColor[
             0.9875484237288136, 0.9696600508474577, 0.406128406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.027885652381746694`], {
             RGBColor[
             0.9270259152542373, 0.7483891016949153, 0.2601415423728814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.027885652381746694`], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.027885652381746694`], {
             RGBColor[
             0.9801165593220339, 0.944590627118644, 0.3772570169491524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.027885652381746694`], {
             RGBColor[
             0.9270259152542373, 0.7483891016949153, 0.2601415423728814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.027885652381746694`], {
             RGBColor[
             0.896460559322034, 0.6227334067796612, 0.23531649152542378`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.027885652381746694`], {
             RGBColor[
             0.9920865762711865, 0.9909956101694916, 0.780809440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.027885652381746694`], {
             RGBColor[
             0.9875484237288136, 0.9696600508474577, 0.406128406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.027885652381746694`], {
             RGBColor[
             0.9270259152542373, 0.7483891016949153, 0.2601415423728814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.027885652381746694`], {
             RGBColor[
             0.868501372881356, 0.49577727118644077`, 0.21198666101694918`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.027885652381746694`], {
             RGBColor[
             0.896460559322034, 0.6227334067796612, 0.23531649152542378`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.027885652381746694`], {
             RGBColor[
             0.9875753898305084, 0.9891301186440679, 0.8555714745762714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.027885652381746694`], {
             RGBColor[
             0.9943421694915254, 0.9919283559322034, 0.7434284237288136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.027885652381746694`], {
             RGBColor[
             0.9652528305084747, 0.894451779661017, 0.31951423728813566`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.027885652381746694`], {
             RGBColor[
             0.993256627118644, 0.9879849322033899, 0.5074036610169489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.027885652381746694`], {
             RGBColor[
             0.9853197966101694, 0.988197372881356, 0.8929524915254238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.027885652381746694`], {
             RGBColor[
             0.9943870677966101, 0.9904028305084746, 0.6304451525423728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.027885652381746694`], {
             RGBColor[
             0.993256627118644, 0.9879849322033899, 0.5074036610169489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.027885652381746694`], {
             RGBColor[
             0.9943421694915254, 0.9919283559322034, 0.7434284237288136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.027885652381746694`], {
             RGBColor[
             0.8256754745762712, 0.19835852542372862`, 0.1722201694915254]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.027885652381746694`], {
             RGBColor[
             0.9875753898305084, 0.9891301186440679, 0.8555714745762714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.027885652381746694`], {
             RGBColor[
             0.9801165593220339, 0.944590627118644, 0.3772570169491524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.027885652381746694`], {
             RGBColor[
             0.9652528305084747, 0.894451779661017, 0.31951423728813566`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.027885652381746694`], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.027885652381746694`], {
             RGBColor[
             0.9693975254237287, 0.9766973050847457, 0.936686186440678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.027885652381746694`], {
             RGBColor[
             0.9943421694915254, 0.9919283559322034, 0.7434284237288136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.027885652381746694`], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.027885652381746694`], {
             RGBColor[
             0.9165033389830508, 0.7066705932203389, 0.25167483050847456`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.027885652381746694`], {
             RGBColor[
             0.9578209661016949, 0.8693823559322034, 0.2906428474576271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.027885652381746694`], {
             RGBColor[
             0.9496715593220338, 0.9619857118644067, 0.9700771016949152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.027885652381746694`], {
             RGBColor[
             0.9943421694915254, 0.9919283559322034, 0.7434284237288136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.027885652381746694`], {
             RGBColor[
             0.9943870677966101, 0.9904028305084746, 0.6304451525423728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.027885652381746694`], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.027885652381746694`], {
             RGBColor[
             0.9595345423728813, 0.9693415084745762, 0.9533816440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.027885652381746694`], {
             RGBColor[
             0.9693975254237287, 0.9766973050847457, 0.936686186440678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.027885652381746694`], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.027885652381746694`], {
             RGBColor[
             0.9496715593220338, 0.9619857118644067, 0.9700771016949152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.027885652381746694`], {
             RGBColor[
             0.896460559322034, 0.6227334067796612, 0.23531649152542378`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.027885652381746694`], {
             RGBColor[
             0.9792605084745762, 0.9840531016949153, 0.9199907288135593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.027885652381746694`], {
             RGBColor[
             0.9652528305084747, 0.894451779661017, 0.31951423728813566`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.027885652381746694`], {
             RGBColor[
             0.9926914067796611, 0.9867759830508475, 0.4458829152542371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.027885652381746694`], {
             RGBColor[
             0.9496715593220338, 0.9619857118644067, 0.9700771016949152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.027885652381746694`], {
             RGBColor[
             0.9578209661016949, 0.8693823559322034, 0.2906428474576271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.027885652381746694`], {
             RGBColor[
             0.9938218474576271, 0.9891938813559322, 0.568924406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.027885652381746694`], {
             RGBColor[
             0.9920865762711865, 0.9909956101694916, 0.780809440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.027885652381746694`], {
             RGBColor[
             0.9943421694915254, 0.9919283559322034, 0.7434284237288136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.027885652381746694`], {
             RGBColor[
             0.9943421694915254, 0.9919283559322034, 0.7434284237288136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.027885652381746694`], {
             RGBColor[
             0.9875753898305084, 0.9891301186440679, 0.8555714745762714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.027885652381746694`], {
             RGBColor[
             0.868501372881356, 0.49577727118644077`, 0.21198666101694918`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.027885652381746694`], {
             RGBColor[
             0.9949522881355932, 0.991611779661017, 0.6919658983050849]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.027885652381746694`], {
             RGBColor[
             0.896460559322034, 0.6227334067796612, 0.23531649152542378`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.027885652381746694`], {
             RGBColor[
             0.9949522881355932, 0.991611779661017, 0.6919658983050849]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.027885652381746694`], {
             RGBColor[
             0.9875753898305084, 0.9891301186440679, 0.8555714745762714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.027885652381746694`], {
             RGBColor[
             0.9938218474576271, 0.9891938813559322, 0.568924406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.027885652381746694`], {
             RGBColor[
             0.9726846949152542, 0.9195212033898303, 0.34838562711864385`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.027885652381746694`], {
             RGBColor[
             0.9920865762711865, 0.9909956101694916, 0.780809440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.027885652381746694`], {
             RGBColor[
             0.9853197966101694, 0.988197372881356, 0.8929524915254238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.027885652381746694`], {
             RGBColor[
             0.9480710677966101, 0.8318261186440676, 0.27707496610169485`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.027885652381746694`], {
             RGBColor[
             0.9652528305084747, 0.894451779661017, 0.31951423728813566`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.027885652381746694`], {
             RGBColor[
             0.993256627118644, 0.9879849322033899, 0.5074036610169489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.027885652381746694`], {
             RGBColor[
             0.9652528305084747, 0.894451779661017, 0.31951423728813566`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.027885652381746694`], {
             RGBColor[
             0.9792605084745762, 0.9840531016949153, 0.9199907288135593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.027885652381746694`], {
             RGBColor[
             0.9943870677966101, 0.9904028305084746, 0.6304451525423728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.027885652381746694`], {
             RGBColor[
             0.8507448983050847, 0.3910531016949153, 0.1962266779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.027885652381746694`], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.027885652381746694`], {
             RGBColor[
             0.9926914067796611, 0.9867759830508475, 0.4458829152542371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.027885652381746694`], {
             RGBColor[
             0.9578209661016949, 0.8693823559322034, 0.2906428474576271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.027885652381746694`], {
             RGBColor[
             0.9480710677966101, 0.8318261186440676, 0.27707496610169485`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.027885652381746694`], {
             RGBColor[
             0.8871408305084746, 0.5804146949152542, 0.2275398813559322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.027885652381746694`], {
             RGBColor[
             0.9801165593220339, 0.944590627118644, 0.3772570169491524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.027885652381746694`], {
             RGBColor[
             0.896460559322034, 0.6227334067796612, 0.23531649152542378`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.027885652381746694`], {
             RGBColor[
             0.9693975254237287, 0.9766973050847457, 0.936686186440678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.027885652381746694`], {
             RGBColor[
             0.9726846949152542, 0.9195212033898303, 0.34838562711864385`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.027885652381746694`], {
             RGBColor[
             0.8871408305084746, 0.5804146949152542, 0.2275398813559322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.027885652381746694`], {
             RGBColor[
             0.874899593220339, 0.9030852033898304, 0.9879298983050847]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.027885652381746694`], {
             RGBColor[
             0.9726846949152542, 0.9195212033898303, 0.34838562711864385`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.027885652381746694`], {
             RGBColor[
             0.896460559322034, 0.6227334067796612, 0.23531649152542378`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.027885652381746694`], {
             RGBColor[
             0.9726846949152542, 0.9195212033898303, 0.34838562711864385`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.027885652381746694`], {
             RGBColor[
             0.9853197966101694, 0.988197372881356, 0.8929524915254238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.027885652381746694`], {
             RGBColor[
             0.8340319491525423, 0.26259005084745723`, 0.1802223389830508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.027885652381746694`], {
             RGBColor[
             0.868501372881356, 0.49577727118644077`, 0.21198666101694918`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.027885652381746694`], {
             RGBColor[
             0.9801165593220339, 0.944590627118644, 0.3772570169491524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.027885652381746694`], {
             RGBColor[
             0.9270259152542373, 0.7483891016949153, 0.2601415423728814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.027885652381746694`], {
             RGBColor[
             0.9938218474576271, 0.9891938813559322, 0.568924406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.027885652381746694`], {
             RGBColor[
             0.9920865762711865, 0.9909956101694916, 0.780809440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.027885652381746694`], {
             RGBColor[
             0.9943421694915254, 0.9919283559322034, 0.7434284237288136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.027885652381746694`], {
             RGBColor[
             0.9875753898305084, 0.9891301186440679, 0.8555714745762714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.027885652381746694`], {
             RGBColor[
             0.8278290847457628, 0.8655524576271186, 0.9834402711864407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.027885652381746694`], {
             RGBColor[
             0.9943870677966101, 0.9904028305084746, 0.6304451525423728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.027885652381746694`], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.027885652381746694`], {
             RGBColor[
             0.9578209661016949, 0.8693823559322034, 0.2906428474576271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.027885652381746694`], {
             RGBColor[
             0.9792605084745762, 0.9840531016949153, 0.9199907288135593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.027885652381746694`], {
             RGBColor[
             0.9949522881355932, 0.991611779661017, 0.6919658983050849]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.027885652381746694`], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.027885652381746694`], {
             RGBColor[
             0.9726846949152542, 0.9195212033898303, 0.34838562711864385`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.027885652381746694`], {
             RGBColor[
             0.9949522881355932, 0.991611779661017, 0.6919658983050849]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.027885652381746694`], {
             RGBColor[
             0.9875753898305084, 0.9891301186440679, 0.8555714745762714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.027885652381746694`], {
             RGBColor[
             0.9059807627118645, 0.6649520847457627, 0.24320811864406783`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.027885652381746694`], {
             RGBColor[
             0.9943870677966101, 0.9904028305084746, 0.6304451525423728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.027885652381746694`], {
             RGBColor[
             0.9693975254237287, 0.9766973050847457, 0.936686186440678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.027885652381746694`], {
             RGBColor[
             0.9693975254237287, 0.9766973050847457, 0.936686186440678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.027885652381746694`], {
             RGBColor[
             0.9726846949152542, 0.9195212033898303, 0.34838562711864385`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.027885652381746694`], {
             RGBColor[
             0.9949522881355932, 0.991611779661017, 0.6919658983050849]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.027885652381746694`], {
             RGBColor[
             0.9949522881355932, 0.991611779661017, 0.6919658983050849]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.027885652381746694`], {
             RGBColor[
             0.9578209661016949, 0.8693823559322034, 0.2906428474576271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.027885652381746694`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.027885652381746694`], {
             RGBColor[
             0.9920865762711865, 0.9909956101694916, 0.780809440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.027885652381746694`], {
             RGBColor[
             0.9595345423728813, 0.9693415084745762, 0.9533816440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.027885652381746694`], {
             RGBColor[
             0.9578209661016949, 0.8693823559322034, 0.2906428474576271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.027885652381746694`], {
             RGBColor[
             0.9652528305084747, 0.894451779661017, 0.31951423728813566`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.027885652381746694`], {
             RGBColor[
             0.9943870677966101, 0.9904028305084746, 0.6304451525423728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.027885652381746694`], {
             RGBColor[
             0.9792605084745762, 0.9840531016949153, 0.9199907288135593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.027885652381746694`], {
             RGBColor[
             0.9943421694915254, 0.9919283559322034, 0.7434284237288136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.027885652381746694`], {
             RGBColor[
             0.9926914067796611, 0.9867759830508475, 0.4458829152542371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.027885652381746694`], {
             RGBColor[
             0.9920865762711865, 0.9909956101694916, 0.780809440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.027885652381746694`], {
             RGBColor[
             0.9920865762711865, 0.9909956101694916, 0.780809440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.027885652381746694`], {
             RGBColor[
             0.9926914067796611, 0.9867759830508475, 0.4458829152542371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.027885652381746694`], {
             RGBColor[
             0.9693975254237287, 0.9766973050847457, 0.936686186440678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.027885652381746694`], {
             RGBColor[
             0.9875484237288136, 0.9696600508474577, 0.406128406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.027885652381746694`], {
             RGBColor[
             0.9219701016949152, 0.9406179491525424, 0.9924195254237288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.027885652381746694`], {
             RGBColor[
             0.9926914067796611, 0.9867759830508475, 0.4458829152542371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.027885652381746694`], {
             RGBColor[
             0.9652528305084747, 0.894451779661017, 0.31951423728813566`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.027885652381746694`], {
             RGBColor[
             0.9652528305084747, 0.894451779661017, 0.31951423728813566`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.027885652381746694`], {
             RGBColor[
             0.993256627118644, 0.9879849322033899, 0.5074036610169489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.027885652381746694`], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.027885652381746694`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.027885652381746694`], {
             RGBColor[
             0.9949522881355932, 0.991611779661017, 0.6919658983050849]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.027885652381746694`], {
             RGBColor[
             0.9943421694915254, 0.9919283559322034, 0.7434284237288136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.027885652381746694`], {
             RGBColor[
             0.9920865762711865, 0.9909956101694916, 0.780809440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.027885652381746694`], {
             RGBColor[
             0.9652528305084747, 0.894451779661017, 0.31951423728813566`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.027885652381746694`], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.027885652381746694`], {
             RGBColor[
             0.896460559322034, 0.6227334067796612, 0.23531649152542378`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.027885652381746694`], {
             RGBColor[
             0.9875753898305084, 0.9891301186440679, 0.8555714745762714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.027885652381746694`], {
             RGBColor[
             0.9398085762711864, 0.9546299152542372, 0.9867725593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.027885652381746694`], {
             RGBColor[
             0.9270259152542373, 0.7483891016949153, 0.2601415423728814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.027885652381746694`], {
             RGBColor[
             0.8984348474576271, 0.9218515762711864, 0.9901747118644068]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.027885652381746694`], {
             RGBColor[
             0.9853197966101694, 0.988197372881356, 0.8929524915254238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.027885652381746694`], {
             RGBColor[
             0.9875753898305084, 0.9891301186440679, 0.8555714745762714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.027885652381746694`], {
             RGBColor[
             0.8778211016949152, 0.5380959830508475, 0.21976327118644068`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.027885652381746694`], {
             RGBColor[
             0.9726846949152542, 0.9195212033898303, 0.34838562711864385`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.027885652381746694`], {
             RGBColor[
             0.9398085762711864, 0.9546299152542372, 0.9867725593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.027885652381746694`], {
             RGBColor[
             0.9943421694915254, 0.9919283559322034, 0.7434284237288136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.027885652381746694`], {
             RGBColor[
             0.9480710677966101, 0.8318261186440676, 0.27707496610169485`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.027885652381746694`], {
             RGBColor[
             0.9949522881355932, 0.991611779661017, 0.6919658983050849]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.027885652381746694`], {
             RGBColor[
             0.9375484915254237, 0.7901076101694915, 0.2686082542372881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.027885652381746694`], {
             RGBColor[
             0.896460559322034, 0.6227334067796612, 0.23531649152542378`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.027885652381746694`], {
             RGBColor[
             0.9943870677966101, 0.9904028305084746, 0.6304451525423728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.027885652381746694`], {
             RGBColor[
             0.8278290847457628, 0.8655524576271186, 0.9834402711864407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.027885652381746694`], {
             RGBColor[
             0.9875484237288136, 0.9696600508474577, 0.406128406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.027885652381746694`], {
             RGBColor[
             0.9949522881355932, 0.991611779661017, 0.6919658983050849]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.027885652381746694`], {
             RGBColor[
             0.9496715593220338, 0.9619857118644067, 0.9700771016949152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.027885652381746694`], {
             RGBColor[
             0.993256627118644, 0.9879849322033899, 0.5074036610169489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.027885652381746694`], {
             RGBColor[
             0.9165033389830508, 0.7066705932203389, 0.25167483050847456`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.027885652381746694`], {
             RGBColor[
             0.9496715593220338, 0.9619857118644067, 0.9700771016949152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.027885652381746694`], {
             RGBColor[
             0.874899593220339, 0.9030852033898304, 0.9879298983050847]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.027885652381746694`], {
             RGBColor[
             0.9059807627118645, 0.6649520847457627, 0.24320811864406783`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.027885652381746694`], {
             RGBColor[
             0.993256627118644, 0.9879849322033899, 0.5074036610169489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.027885652381746694`], {
             RGBColor[
             0.9875484237288136, 0.9696600508474577, 0.406128406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.027885652381746694`], {
             RGBColor[
             0.9496715593220338, 0.9619857118644067, 0.9700771016949152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.027885652381746694`], {
             RGBColor[
             0.9652528305084747, 0.894451779661017, 0.31951423728813566`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.027885652381746694`], {
             RGBColor[
             0.9398085762711864, 0.9546299152542372, 0.9867725593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.027885652381746694`], {
             RGBColor[
             0.9726846949152542, 0.9195212033898303, 0.34838562711864385`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.027885652381746694`], {
             RGBColor[
             0.9875484237288136, 0.9696600508474577, 0.406128406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.027885652381746694`], {
             RGBColor[
             0.993256627118644, 0.9879849322033899, 0.5074036610169489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.027885652381746694`], {
             RGBColor[
             0.9801165593220339, 0.944590627118644, 0.3772570169491524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.027885652381746694`], {
             RGBColor[
             0.9938218474576271, 0.9891938813559322, 0.568924406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.027885652381746694`], {
             RGBColor[
             0.9726846949152542, 0.9195212033898303, 0.34838562711864385`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.027885652381746694`], {
             RGBColor[
             0.9875484237288136, 0.9696600508474577, 0.406128406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.027885652381746694`], {
             RGBColor[
             0.9875753898305084, 0.9891301186440679, 0.8555714745762714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.027885652381746694`], {
             RGBColor[
             0.9875484237288136, 0.9696600508474577, 0.406128406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.027885652381746694`], {
             RGBColor[
             0.9652528305084747, 0.894451779661017, 0.31951423728813566`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.027885652381746694`], {
             RGBColor[
             0.9875753898305084, 0.9891301186440679, 0.8555714745762714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.027885652381746694`], {
             RGBColor[
             0.993256627118644, 0.9879849322033899, 0.5074036610169489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.027885652381746694`], {
             RGBColor[
             0.9938218474576271, 0.9891938813559322, 0.568924406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.027885652381746694`], {
             RGBColor[
             0.9920865762711865, 0.9909956101694916, 0.780809440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.027885652381746694`], {
             RGBColor[
             0.9938218474576271, 0.9891938813559322, 0.568924406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.027885652381746694`], {
             RGBColor[
             0.9059807627118645, 0.6649520847457627, 0.24320811864406783`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.027885652381746694`], {
             RGBColor[
             0.9398085762711864, 0.9546299152542372, 0.9867725593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.027885652381746694`], {
             RGBColor[
             0.9165033389830508, 0.7066705932203389, 0.25167483050847456`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.027885652381746694`], {
             RGBColor[
             0.8591816440677966, 0.4534585593220338, 0.2042100508474576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.027885652381746694`], {
             RGBColor[
             0.9595345423728813, 0.9693415084745762, 0.9533816440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.027885652381746694`], {
             RGBColor[
             0.9270259152542373, 0.7483891016949153, 0.2601415423728814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.027885652381746694`], {
             RGBColor[
             0.9949522881355932, 0.991611779661017, 0.6919658983050849]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.027885652381746694`], {
             RGBColor[
             0.9920865762711865, 0.9909956101694916, 0.780809440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.027885652381746694`], {
             RGBColor[
             0.9926914067796611, 0.9867759830508475, 0.4458829152542371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.027885652381746694`], {
             RGBColor[
             0.9949522881355932, 0.991611779661017, 0.6919658983050849]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.027885652381746694`], {
             RGBColor[
             0.9875753898305084, 0.9891301186440679, 0.8555714745762714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.027885652381746694`], {
             RGBColor[
             0.9726846949152542, 0.9195212033898303, 0.34838562711864385`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.027885652381746694`], {
             RGBColor[
             0.9165033389830508, 0.7066705932203389, 0.25167483050847456`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.027885652381746694`], {
             RGBColor[
             0.8423884237288136, 0.3268215762711867, 0.1882245084745763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.027885652381746694`], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.027885652381746694`], {
             RGBColor[
             0.9801165593220339, 0.944590627118644, 0.3772570169491524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.027885652381746694`], {
             RGBColor[
             0.9943421694915254, 0.9919283559322034, 0.7434284237288136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.027885652381746694`], {
             RGBColor[
             0.9219701016949152, 0.9406179491525424, 0.9924195254237288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.027885652381746694`], {
             RGBColor[
             0.9398085762711864, 0.9546299152542372, 0.9867725593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.027885652381746694`], {
             RGBColor[
             0.9853197966101694, 0.988197372881356, 0.8929524915254238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.027885652381746694`], {
             RGBColor[
             0.8507448983050847, 0.3910531016949153, 0.1962266779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.027885652381746694`], {
             RGBColor[
             0.9792605084745762, 0.9840531016949153, 0.9199907288135593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.027885652381746694`], {
             RGBColor[
             0.9792605084745762, 0.9840531016949153, 0.9199907288135593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.027885652381746694`], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.027885652381746694`], {
             RGBColor[
             0.9920865762711865, 0.9909956101694916, 0.780809440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.027885652381746694`], {
             RGBColor[
             0.9875753898305084, 0.9891301186440679, 0.8555714745762714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.027885652381746694`], {
             RGBColor[
             0.9875484237288136, 0.9696600508474577, 0.406128406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.027885652381746694`], {
             RGBColor[
             0.9926914067796611, 0.9867759830508475, 0.4458829152542371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.027885652381746694`], {
             RGBColor[
             0.9853197966101694, 0.988197372881356, 0.8929524915254238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.027885652381746694`], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.027885652381746694`], {
             RGBColor[
             0.9949522881355932, 0.991611779661017, 0.6919658983050849]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.027885652381746694`], {
             RGBColor[
             0.9943421694915254, 0.9919283559322034, 0.7434284237288136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.027885652381746694`], {
             RGBColor[
             0.993256627118644, 0.9879849322033899, 0.5074036610169489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.027885652381746694`], {
             RGBColor[
             0.9875484237288136, 0.9696600508474577, 0.406128406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.027885652381746694`], {
             RGBColor[
             0.874899593220339, 0.9030852033898304, 0.9879298983050847]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.027885652381746694`], {
             RGBColor[
             0.9920865762711865, 0.9909956101694916, 0.780809440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.027885652381746694`], {
             RGBColor[
             0.9375484915254237, 0.7901076101694915, 0.2686082542372881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.027885652381746694`], {
             RGBColor[
             0.9059807627118645, 0.6649520847457627, 0.24320811864406783`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.027885652381746694`], {
             RGBColor[
             0.9943870677966101, 0.9904028305084746, 0.6304451525423728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.027885652381746694`], {
             RGBColor[
             0.9920865762711865, 0.9909956101694916, 0.780809440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.027885652381746694`], {
             RGBColor[
             0.9920865762711865, 0.9909956101694916, 0.780809440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.027885652381746694`], {
             RGBColor[
             0.9920865762711865, 0.9909956101694916, 0.780809440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.027885652381746694`], {
             RGBColor[
             0.9726846949152542, 0.9195212033898303, 0.34838562711864385`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.027885652381746694`], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.027885652381746694`], {
             RGBColor[
             0.9943421694915254, 0.9919283559322034, 0.7434284237288136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.027885652381746694`], {
             RGBColor[
             0.993256627118644, 0.9879849322033899, 0.5074036610169489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.027885652381746694`], {
             RGBColor[
             0.9949522881355932, 0.991611779661017, 0.6919658983050849]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.027885652381746694`], {
             RGBColor[
             0.9949522881355932, 0.991611779661017, 0.6919658983050849]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.027885652381746694`], {
             RGBColor[
             0.9693975254237287, 0.9766973050847457, 0.936686186440678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.027885652381746694`], {
             RGBColor[
             0.9853197966101694, 0.988197372881356, 0.8929524915254238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.027885652381746694`], {
             RGBColor[
             0.9920865762711865, 0.9909956101694916, 0.780809440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.027885652381746694`], {
             RGBColor[
             0.9375484915254237, 0.7901076101694915, 0.2686082542372881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.027885652381746694`], {
             RGBColor[
             0.9219701016949152, 0.9406179491525424, 0.9924195254237288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.027885652381746694`], {
             RGBColor[
             0.9801165593220339, 0.944590627118644, 0.3772570169491524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.027885652381746694`], {
             RGBColor[
             0.9875484237288136, 0.9696600508474577, 0.406128406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.027885652381746694`], {
             RGBColor[
             0.993256627118644, 0.9879849322033899, 0.5074036610169489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.027885652381746694`], {
             RGBColor[
             0.874899593220339, 0.9030852033898304, 0.9879298983050847]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.027885652381746694`], {
             RGBColor[
             0.9480710677966101, 0.8318261186440676, 0.27707496610169485`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.027885652381746694`], {
             RGBColor[
             0.9652528305084747, 0.894451779661017, 0.31951423728813566`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.027885652381746694`], {
             RGBColor[
             0.9595345423728813, 0.9693415084745762, 0.9533816440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.027885652381746694`], {
             RGBColor[
             0.896460559322034, 0.6227334067796612, 0.23531649152542378`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.027885652381746694`], {
             RGBColor[
             0.8340319491525423, 0.26259005084745723`, 0.1802223389830508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.027885652381746694`], {
             RGBColor[
             0.9726846949152542, 0.9195212033898303, 0.34838562711864385`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.027885652381746694`], {
             RGBColor[
             0.9943870677966101, 0.9904028305084746, 0.6304451525423728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.027885652381746694`], {
             RGBColor[
             0.9943870677966101, 0.9904028305084746, 0.6304451525423728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.027885652381746694`], {
             RGBColor[
             0.9726846949152542, 0.9195212033898303, 0.34838562711864385`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.027885652381746694`], {
             RGBColor[
             0.9875484237288136, 0.9696600508474577, 0.406128406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.027885652381746694`], {
             RGBColor[
             0.9480710677966101, 0.8318261186440676, 0.27707496610169485`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.027885652381746694`], {
             RGBColor[
             0.9875753898305084, 0.9891301186440679, 0.8555714745762714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.027885652381746694`], {
             RGBColor[
             0.9595345423728813, 0.9693415084745762, 0.9533816440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.027885652381746694`], {
             RGBColor[
             0.9943421694915254, 0.9919283559322034, 0.7434284237288136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.027885652381746694`], {
             RGBColor[
             0.9943421694915254, 0.9919283559322034, 0.7434284237288136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.027885652381746694`], {
             RGBColor[
             0.993256627118644, 0.9879849322033899, 0.5074036610169489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.027885652381746694`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.027885652381746694`], {
             RGBColor[
             0.9219701016949152, 0.9406179491525424, 0.9924195254237288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.027885652381746694`], {
             RGBColor[
             0.9595345423728813, 0.9693415084745762, 0.9533816440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.027885652381746694`], {
             RGBColor[
             0.9375484915254237, 0.7901076101694915, 0.2686082542372881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.027885652381746694`], {
             RGBColor[
             0.9801165593220339, 0.944590627118644, 0.3772570169491524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.027885652381746694`], {
             RGBColor[
             0.993256627118644, 0.9879849322033899, 0.5074036610169489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.027885652381746694`], {
             RGBColor[
             0.9926914067796611, 0.9867759830508475, 0.4458829152542371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.027885652381746694`], {
             RGBColor[
             0.9920865762711865, 0.9909956101694916, 0.780809440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.027885652381746694`], {
             RGBColor[
             0.9943421694915254, 0.9919283559322034, 0.7434284237288136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.027885652381746694`], {
             RGBColor[
             0.896460559322034, 0.6227334067796612, 0.23531649152542378`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.027885652381746694`], {
             RGBColor[
             0.896460559322034, 0.6227334067796612, 0.23531649152542378`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.027885652381746694`], {
             RGBColor[
             0.896460559322034, 0.6227334067796612, 0.23531649152542378`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.027885652381746694`], {
             RGBColor[
             0.9949522881355932, 0.991611779661017, 0.6919658983050849]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.027885652381746694`], {
             RGBColor[
             0.9578209661016949, 0.8693823559322034, 0.2906428474576271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.027885652381746694`], {
             RGBColor[
             0.9926914067796611, 0.9867759830508475, 0.4458829152542371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.027885652381746694`], {
             RGBColor[
             0.9726846949152542, 0.9195212033898303, 0.34838562711864385`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.027885652381746694`], {
             RGBColor[
             0.9949522881355932, 0.991611779661017, 0.6919658983050849]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.027885652381746694`], {
             RGBColor[
             0.9938218474576271, 0.9891938813559322, 0.568924406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.027885652381746694`], {
             RGBColor[
             0.9270259152542373, 0.7483891016949153, 0.2601415423728814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.027885652381746694`], {
             RGBColor[
             0.9938218474576271, 0.9891938813559322, 0.568924406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.027885652381746694`], {
             RGBColor[
             0.8256754745762712, 0.19835852542372862`, 0.1722201694915254]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.027885652381746694`], {
             RGBColor[
             0.9938218474576271, 0.9891938813559322, 0.568924406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.027885652381746694`], {
             RGBColor[
             0.9801165593220339, 0.944590627118644, 0.3772570169491524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.027885652381746694`], {
             RGBColor[
             0.9853197966101694, 0.988197372881356, 0.8929524915254238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.027885652381746694`], {
             RGBColor[
             0.9875753898305084, 0.9891301186440679, 0.8555714745762714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.027885652381746694`], {
             RGBColor[
             0.9219701016949152, 0.9406179491525424, 0.9924195254237288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.027885652381746694`], {
             RGBColor[
             0.9875753898305084, 0.9891301186440679, 0.8555714745762714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.027885652381746694`], {
             RGBColor[
             0.9949522881355932, 0.991611779661017, 0.6919658983050849]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.027885652381746694`], {
             RGBColor[
             0.9726846949152542, 0.9195212033898303, 0.34838562711864385`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.027885652381746694`], {
             RGBColor[
             0.8591816440677966, 0.4534585593220338, 0.2042100508474576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.027885652381746694`], {
             RGBColor[
             0.9801165593220339, 0.944590627118644, 0.3772570169491524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.027885652381746694`], {
             RGBColor[
             0.9375484915254237, 0.7901076101694915, 0.2686082542372881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.027885652381746694`], {
             RGBColor[
             0.9496715593220338, 0.9619857118644067, 0.9700771016949152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.027885652381746694`], {
             RGBColor[
             0.9578209661016949, 0.8693823559322034, 0.2906428474576271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.027885652381746694`], {
             RGBColor[
             0.9578209661016949, 0.8693823559322034, 0.2906428474576271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.027885652381746694`], {
             RGBColor[
             0.9943421694915254, 0.9919283559322034, 0.7434284237288136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.027885652381746694`], {
             RGBColor[
             0.8278290847457628, 0.8655524576271186, 0.9834402711864407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.027885652381746694`], {
             RGBColor[
             0.9792605084745762, 0.9840531016949153, 0.9199907288135593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.027885652381746694`], {
             RGBColor[
             0.9375484915254237, 0.7901076101694915, 0.2686082542372881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.027885652381746694`], {
             RGBColor[
             0.9926914067796611, 0.9867759830508475, 0.4458829152542371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.027885652381746694`], {
             RGBColor[
             0.9853197966101694, 0.988197372881356, 0.8929524915254238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.027885652381746694`], {
             RGBColor[
             0.993256627118644, 0.9879849322033899, 0.5074036610169489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.027885652381746694`], {
             RGBColor[
             0.868501372881356, 0.49577727118644077`, 0.21198666101694918`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.027885652381746694`], {
             RGBColor[
             0.9875753898305084, 0.9891301186440679, 0.8555714745762714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.027885652381746694`], {
             RGBColor[
             0.9496715593220338, 0.9619857118644067, 0.9700771016949152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.027885652381746694`], {
             RGBColor[
             0.9578209661016949, 0.8693823559322034, 0.2906428474576271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.027885652381746694`], {
             RGBColor[
             0.9920865762711865, 0.9909956101694916, 0.780809440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.027885652381746694`], {
             RGBColor[
             0.9949522881355932, 0.991611779661017, 0.6919658983050849]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.027885652381746694`], {
             RGBColor[
             0.993256627118644, 0.9879849322033899, 0.5074036610169489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.027885652381746694`], {
             RGBColor[
             0.9792605084745762, 0.9840531016949153, 0.9199907288135593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.027885652381746694`], {
             RGBColor[
             0.8423884237288136, 0.3268215762711867, 0.1882245084745763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.027885652381746694`], {
             RGBColor[
             0.9875753898305084, 0.9891301186440679, 0.8555714745762714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.027885652381746694`], {
             RGBColor[
             0.9875753898305084, 0.9891301186440679, 0.8555714745762714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.027885652381746694`], {
             RGBColor[
             0.993256627118644, 0.9879849322033899, 0.5074036610169489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.027885652381746694`], {
             RGBColor[
             0.9693975254237287, 0.9766973050847457, 0.936686186440678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.027885652381746694`], {
             RGBColor[
             0.9652528305084747, 0.894451779661017, 0.31951423728813566`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.027885652381746694`], {
             RGBColor[
             0.9943421694915254, 0.9919283559322034, 0.7434284237288136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.027885652381746694`], {
             RGBColor[
             0.9693975254237287, 0.9766973050847457, 0.936686186440678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.027885652381746694`], {
             RGBColor[
             0.9801165593220339, 0.944590627118644, 0.3772570169491524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.027885652381746694`], {
             RGBColor[
             0.9926914067796611, 0.9867759830508475, 0.4458829152542371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.027885652381746694`], {
             RGBColor[
             0.9938218474576271, 0.9891938813559322, 0.568924406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.027885652381746694`], {
             RGBColor[
             0.9792605084745762, 0.9840531016949153, 0.9199907288135593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.027885652381746694`], {
             RGBColor[
             0.874899593220339, 0.9030852033898304, 0.9879298983050847]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.027885652381746694`], {
             RGBColor[
             0.9920865762711865, 0.9909956101694916, 0.780809440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.027885652381746694`], {
             RGBColor[
             0.9926914067796611, 0.9867759830508475, 0.4458829152542371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.027885652381746694`], {
             RGBColor[
             0.9578209661016949, 0.8693823559322034, 0.2906428474576271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.027885652381746694`], {
             RGBColor[
             0.9801165593220339, 0.944590627118644, 0.3772570169491524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.027885652381746694`], {
             RGBColor[
             0.9801165593220339, 0.944590627118644, 0.3772570169491524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.027885652381746694`], {
             RGBColor[
             0.9693975254237287, 0.9766973050847457, 0.936686186440678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.027885652381746694`], {
             RGBColor[
             0.9270259152542373, 0.7483891016949153, 0.2601415423728814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.027885652381746694`], {
             RGBColor[
             0.9938218474576271, 0.9891938813559322, 0.568924406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.027885652381746694`], {
             RGBColor[
             0.9920865762711865, 0.9909956101694916, 0.780809440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.027885652381746694`], {
             RGBColor[
             0.9875484237288136, 0.9696600508474577, 0.406128406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.027885652381746694`], {
             RGBColor[
             0.8591816440677966, 0.4534585593220338, 0.2042100508474576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.027885652381746694`], {
             RGBColor[
             0.9726846949152542, 0.9195212033898303, 0.34838562711864385`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.027885652381746694`], {
             RGBColor[
             0.9853197966101694, 0.988197372881356, 0.8929524915254238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.027885652381746694`], {
             RGBColor[
             0.9595345423728813, 0.9693415084745762, 0.9533816440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.027885652381746694`], {
             RGBColor[
             0.9595345423728813, 0.9693415084745762, 0.9533816440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.027885652381746694`], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.027885652381746694`], {
             RGBColor[
             0.7958992542372882, 0.840481813559322, 0.9802914576271187]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.027885652381746694`], {
             RGBColor[
             0.9726846949152542, 0.9195212033898303, 0.34838562711864385`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.027885652381746694`], {
             RGBColor[
             0.9652528305084747, 0.894451779661017, 0.31951423728813566`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.027885652381746694`], {
             RGBColor[
             0.9595345423728813, 0.9693415084745762, 0.9533816440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.027885652381746694`], {
             RGBColor[
             0.9726846949152542, 0.9195212033898303, 0.34838562711864385`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.027885652381746694`], {
             RGBColor[
             0.9938218474576271, 0.9891938813559322, 0.568924406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.027885652381746694`], {
             RGBColor[
             0.9792605084745762, 0.9840531016949153, 0.9199907288135593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.027885652381746694`], {
             RGBColor[
             0.9652528305084747, 0.894451779661017, 0.31951423728813566`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.027885652381746694`], {
             RGBColor[
             0.9801165593220339, 0.944590627118644, 0.3772570169491524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.027885652381746694`], {
             RGBColor[
             0.9926914067796611, 0.9867759830508475, 0.4458829152542371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.027885652381746694`], {
             RGBColor[
             0.9219701016949152, 0.9406179491525424, 0.9924195254237288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.027885652381746694`], {
             RGBColor[
             0.9652528305084747, 0.894451779661017, 0.31951423728813566`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.027885652381746694`], {
             RGBColor[
             0.9375484915254237, 0.7901076101694915, 0.2686082542372881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.027885652381746694`], {
             RGBColor[
             0.9943421694915254, 0.9919283559322034, 0.7434284237288136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.027885652381746694`], {
             RGBColor[
             0.9943870677966101, 0.9904028305084746, 0.6304451525423728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.027885652381746694`], {
             RGBColor[
             0.9943870677966101, 0.9904028305084746, 0.6304451525423728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.027885652381746694`], {
             RGBColor[
             0.9398085762711864, 0.9546299152542372, 0.9867725593220339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.027885652381746694`], {
             RGBColor[
             0.8278290847457628, 0.8655524576271186, 0.9834402711864407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.027885652381746694`], {
             RGBColor[
             0.9801165593220339, 0.944590627118644, 0.3772570169491524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.027885652381746694`], {
             RGBColor[
             0.9165033389830508, 0.7066705932203389, 0.25167483050847456`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.027885652381746694`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.027885652381746694`], {
             RGBColor[
             0.9943421694915254, 0.9919283559322034, 0.7434284237288136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.027885652381746694`], {
             RGBColor[
             0.9853197966101694, 0.988197372881356, 0.8929524915254238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.027885652381746694`], {
             RGBColor[
             0.9652528305084747, 0.894451779661017, 0.31951423728813566`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.027885652381746694`], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.027885652381746694`], {
             RGBColor[
             0.9496715593220338, 0.9619857118644067, 0.9700771016949152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.027885652381746694`], {
             RGBColor[
             0.9943421694915254, 0.9919283559322034, 0.7434284237288136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.027885652381746694`], {
             RGBColor[
             0.9165033389830508, 0.7066705932203389, 0.25167483050847456`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.027885652381746694`], {
             RGBColor[
             0.9875484237288136, 0.9696600508474577, 0.406128406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.027885652381746694`], {
             RGBColor[
             0.9875753898305084, 0.9891301186440679, 0.8555714745762714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.027885652381746694`], {
             RGBColor[
             0.9165033389830508, 0.7066705932203389, 0.25167483050847456`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.027885652381746694`], {
             RGBColor[
             0.9726846949152542, 0.9195212033898303, 0.34838562711864385`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.027885652381746694`], {
             RGBColor[
             0.8871408305084746, 0.5804146949152542, 0.2275398813559322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.027885652381746694`], {
             RGBColor[
             0.9693975254237287, 0.9766973050847457, 0.936686186440678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.027885652381746694`], {
             RGBColor[
             0.9943421694915254, 0.9919283559322034, 0.7434284237288136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.027885652381746694`], {
             RGBColor[
             0.9949522881355932, 0.991611779661017, 0.6919658983050849]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.027885652381746694`], {
             RGBColor[
             0.9920865762711865, 0.9909956101694916, 0.780809440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.027885652381746694`], {
             RGBColor[
             0.896460559322034, 0.6227334067796612, 0.23531649152542378`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.027885652381746694`], {
             RGBColor[
             0.9801165593220339, 0.944590627118644, 0.3772570169491524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.027885652381746694`], {
             RGBColor[
             0.993256627118644, 0.9879849322033899, 0.5074036610169489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.027885652381746694`], {
             RGBColor[
             0.9270259152542373, 0.7483891016949153, 0.2601415423728814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.027885652381746694`], {
             RGBColor[
             0.8340319491525423, 0.26259005084745723`, 0.1802223389830508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.027885652381746694`], {
             RGBColor[
             0.9496715593220338, 0.9619857118644067, 0.9700771016949152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.027885652381746694`], {
             RGBColor[
             0.9920865762711865, 0.9909956101694916, 0.780809440677966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.027885652381746694`], {
             RGBColor[
             0.9059807627118645, 0.6649520847457627, 0.24320811864406783`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.027885652381746694`], {
             RGBColor[
             0.9875753898305084, 0.9891301186440679, 0.8555714745762714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.027885652381746694`], {
             RGBColor[
             0.9726846949152542, 0.9195212033898303, 0.34838562711864385`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.027885652381746694`], {
             RGBColor[
             0.9898309830508474, 0.9900628644067797, 0.8181904576271186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.027885652381746694`], {
             RGBColor[
             0.8778211016949152, 0.5380959830508475, 0.21976327118644068`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.027885652381746694`], {
             RGBColor[
             0.9943870677966101, 0.9904028305084746, 0.6304451525423728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.027885652381746694`], {
             RGBColor[
             0.8340319491525423, 0.26259005084745723`, 0.1802223389830508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.027885652381746694`], {
             RGBColor[
             0.9938218474576271, 0.9891938813559322, 0.568924406779661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.027885652381746694`], {
             RGBColor[
             0.8507448983050847, 0.3910531016949153, 0.1962266779661017]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.027885652381746694`], {
             RGBColor[
             0.9801165593220339, 0.944590627118644, 0.3772570169491524]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN3AuYzmXewPH7z7a1WxZbu0o1DqFsy5TT0CKyGGKYrMNM4zSN46CIkAnD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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[37, 104] -> 
             RGBColor[
              0.2541903466574486, 0.3845005493087726, 0.9377871362499982], 
             UndirectedEdge[119, 243] -> 
             RGBColor[
              0.23559188807996673`, 0.3649523901334573, 0.9367279815479644], 
             UndirectedEdge[165, 226] -> 
             RGBColor[
              0.20872258864357046`, 0.33671105281382463`, 0.935197814694628], 
             UndirectedEdge[235, 261] -> 
             RGBColor[
              0.19122633777104836`, 0.31832138382042696`, 0.9342014290908216],
              UndirectedEdge[56, 198] -> 
             RGBColor[
              0.6735978276393025, 0.7431113232752183, 0.969380994432274], 
             UndirectedEdge[50, 254] -> 
             RGBColor[
              0.20910270252497706`, 0.33711057660379506`, 0.9352194616178461],
              UndirectedEdge[249, 268] -> 
             RGBColor[
              0.18564105657677243`, 0.3124508991579618, 0.9338833555894905], 
             UndirectedEdge[38, 224] -> 
             RGBColor[
              0.37823665311305865`, 0.49620023139778335`, 0.9458245390097163],
              UndirectedEdge[79, 87] -> 
             RGBColor[
              0.19294989757058154`, 0.3201329544497393, 0.9342995832716268], 
             UndirectedEdge[38, 311] -> 
             RGBColor[
              0.23066096804752526`, 0.35976968054097413`, 0.9364471729467594],
              UndirectedEdge[37, 145] -> 
             RGBColor[
              0.2671022972631469, 0.3980718280603137, 0.9385224527354736], 
             UndirectedEdge[147, 359] -> 
             RGBColor[
              0.28645237167494564`, 0.4168434263248926, 0.9396817701660576], 
             UndirectedEdge[192, 349] -> 
             RGBColor[
              0.22834058438598487`, 0.3573308101918738, 0.9363150305299347], 
             UndirectedEdge[213, 308] -> 
             RGBColor[
              0.2691305631056292, 0.398662652595457, 0.9386943834532097], 
             UndirectedEdge[262, 397] -> 
             RGBColor[
              0.364256395049981, 0.48992231415871446`, 0.9444310732866698], 
             UndirectedEdge[129, 364] -> 
             RGBColor[
              0.8703372527037241, 0.4377357825676223, 0.21085741257426427`], 
             UndirectedEdge[54, 83] -> 
             RGBColor[
              0.9496193654049732, 0.8977579075232218, 0.6225379522867944], 
             UndirectedEdge[13, 277] -> 
             RGBColor[
              0.19923872667069553`, 0.3267429125687539, 0.9346577227853893], 
             UndirectedEdge[191, 235] -> 
             RGBColor[
              0.18862912627732129`, 0.3155915498678, 0.9340535217384839], 
             UndirectedEdge[54, 214] -> 
             RGBColor[
              0.913587591361185, 0.6878213464055395, 0.24895168467498954`], 
             UndirectedEdge[87, 176] -> 
             RGBColor[
              0.18652655830038561`, 0.3133816176135313, 0.933933783602668], 
             UndirectedEdge[16, 377] -> 
             RGBColor[
              0.24182389785616784`, 0.37150262754048624`, 0.9370828852852868],
              UndirectedEdge[158, 344] -> 
             RGBColor[
              0.19135142545084088`, 0.31845285890290587`, 0.934208552649135], 
             UndirectedEdge[95, 228] -> 
             RGBColor[
              0.2356195787974104, 0.36498149483318354`, 0.9367295584933581], 
             UndirectedEdge[193, 283] -> 
             RGBColor[
              0.884925338733304, 0.8207038820590313, 0.6242425057097936], 
             UndirectedEdge[11, 366] -> 
             RGBColor[
              0.9332464444239088, 0.9449010522417576, 0.749948999978632], 
             UndirectedEdge[106, 231] -> 
             RGBColor[
              0.1888628748467801, 0.31583723443481654`, 0.9340668333737145], 
             UndirectedEdge[76, 388] -> 
             RGBColor[
              0.276858244918402, 0.40832594760879465`, 0.9390780395218092], 
             UndirectedEdge[208, 351] -> 
             RGBColor[
              0.301986411916915, 0.43466246314501933`, 0.9405117895645303], 
             UndirectedEdge[208, 225] -> 
             RGBColor[
              0.2514500268910438, 0.38162029948797277`, 0.9376310790932412], 
             UndirectedEdge[163, 374] -> 
             RGBColor[
              0.1813453905655848, 0.3079358818192477, 0.9336387237650219], 
             UndirectedEdge[165, 288] -> 
             RGBColor[
              0.2196372553710177, 0.3481830595742119, 0.9358193888179538], 
             UndirectedEdge[110, 239] -> 
             RGBColor[
              0.6800499902731076, 0.7481746185632971, 0.9700901941191247], 
             UndirectedEdge[14, 273] -> 
             RGBColor[
              0.4313475935937616, 0.5461129107315478, 0.9492366849727629], 
             UndirectedEdge[231, 372] -> 
             RGBColor[
              0.18557674124721385`, 0.3123832996687683, 0.9338796929266182], 
             UndirectedEdge[5, 162] -> 
             RGBColor[
              0.19105730741779076`, 0.3181437222020098, 0.9341918030622616], 
             UndirectedEdge[36, 90] -> 
             RGBColor[
              0.2306114538784999, 0.35971763800994894`, 0.9364443531880831], 
             UndirectedEdge[258, 328] -> 
             RGBColor[
              0.23450213577855084`, 0.36380699137038264`, 0.936665921766543], 
             UndirectedEdge[91, 208] -> 
             RGBColor[
              0.4434969579662055, 0.5534506067219376, 0.9505734674176423], 
             UndirectedEdge[155, 370] -> 
             RGBColor[
              0.18572317816153708`, 0.3125372141503586, 0.9338880322922549], 
             UndirectedEdge[66, 243] -> 
             RGBColor[
              0.21376058132167255`, 0.342006302545695, 0.9354847209246038], 
             UndirectedEdge[253, 334] -> 
             RGBColor[
              0.8927019922159016, 0.5360459310419723, 0.23584376702104354`], 
             UndirectedEdge[50, 210] -> 
             RGBColor[
              0.23840421569943582`, 0.3679083247733892, 0.9368881394454274], 
             UndirectedEdge[239, 365] -> 
             RGBColor[
              0.4065771465503478, 0.524864785093759, 0.9475407198960643], 
             UndirectedEdge[13, 51] -> 
             RGBColor[
              0.20728585719020337`, 0.33520095696230034`, 0.9351159949638125],
              UndirectedEdge[258, 300] -> 
             RGBColor[
              0.21690681128224154`, 0.345313189716754, 0.9356638940664279], 
             UndirectedEdge[30, 294] -> 
             RGBColor[
              0.2052159577699056, 0.3330253614323641, 0.9349981172539683], 
             UndirectedEdge[31, 292] -> 
             RGBColor[
              0.9018751366680733, 0.5692935983265383, 0.5384207617960579], 
             UndirectedEdge[203, 216] -> 
             RGBColor[
              0.26291297700315486`, 0.3935517624584167, 0.938288154657422], 
             UndirectedEdge[64, 233] -> 
             RGBColor[
              0.9814581324353071, 0.9819712119725741, 0.6847171998056071], 
             UndirectedEdge[50, 242] -> 
             RGBColor[
              0.2857631387189643, 0.41475906038865373`, 0.9396923133754758], 
             UndirectedEdge[133, 398] -> 
             RGBColor[
              0.18210607446438823`, 0.30873540882703493`, 0.9336820435877278],
              UndirectedEdge[7, 390] -> 
             RGBColor[
              0.23396569650741295`, 0.36324315968420245`, 0.9366353723436424],
              UndirectedEdge[186, 342] -> 
             RGBColor[
              0.19648760861210862`, 0.32385131305821946`, 0.9345010506818672],
              UndirectedEdge[347, 398] -> 
             RGBColor[
              0.182565782601332, 0.30921859122614215`, 0.9337082232860494], 
             UndirectedEdge[321, 375] -> 
             RGBColor[
              0.19367454863692518`, 0.3208946086659977, 0.9343408510778299], 
             UndirectedEdge[149, 279] -> 
             RGBColor[
              0.20468155953700706`, 0.33246367500678287`, 0.9349676840651762],
              UndirectedEdge[38, 306] -> 
             RGBColor[
              0.24051285588611682`, 0.3701246393051007, 0.9370082233846052], 
             UndirectedEdge[12, 358] -> 
             RGBColor[
              0.26019129073322267`, 0.39080792201424114`, 0.9381288811375124],
              UndirectedEdge[139, 378] -> 
             RGBColor[
              0.27359029407982893`, 0.40489112407740385`, 0.9388919345560525],
              UndirectedEdge[272, 374] -> 
             RGBColor[
              0.19014395523747457`, 0.3171837311506246, 0.934139789006776], 
             UndirectedEdge[21, 114] -> 
             RGBColor[
              0.19167285067202883`, 0.3187906971899105, 0.9342268573399758], 
             UndirectedEdge[250, 321] -> 
             RGBColor[
              0.18913677562513462`, 0.3161251215191795, 0.934082431617842], 
             UndirectedEdge[19, 152] -> 
             RGBColor[
              0.2001783639532218, 0.3277305309291337, 0.9347112337385604], 
             UndirectedEdge[270, 336] -> 
             RGBColor[
              0.2213730230293102, 0.3500074614371033, 0.9359182382182554], 
             UndirectedEdge[87, 277] -> 
             RGBColor[
              0.18598156789951187`, 0.3128087981478258, 0.9339027472055792], 
             UndirectedEdge[37, 377] -> 
             RGBColor[
              0.2695128080367538, 0.400605427718585, 0.9386597277579993], 
             UndirectedEdge[312, 356] -> 
             RGBColor[
              0.746600049419986, 0.8012844499471021, 0.9674404180913663], 
             UndirectedEdge[294, 343] -> 
             RGBColor[
              0.20522639813651683`, 0.33303633491963003`, 0.9349987118174017],
              UndirectedEdge[170, 349] -> 
             RGBColor[
              0.21695935367547547`, 0.34536841510342303`, 0.9356668862779931],
              UndirectedEdge[176, 390] -> 
             RGBColor[
              0.199593709897452, 0.3271160224473115, 0.9346779385550025], 
             UndirectedEdge[235, 327] -> 
             RGBColor[
              0.1895062149755763, 0.31651342570030144`, 0.934103470642313], 
             UndirectedEdge[271, 400] -> 
             RGBColor[
              0.8210589855507496, 0.16287416781517963`, 0.16779941438710733`],
              UndirectedEdge[45, 103] -> 
             RGBColor[
              0.21725551419299843`, 0.345679698585001, 0.9356837521813359], 
             UndirectedEdge[30, 343] -> 
             RGBColor[
              0.2007094287814945, 0.32828871373510315`, 0.9347414770948905], 
             UndirectedEdge[200, 234] -> 
             RGBColor[
              0.22049169370930496`, 0.34908112844227146`, 0.9358680478172909],
              UndirectedEdge[282, 382] -> 
             RGBColor[
              0.3185597546508585, 0.45034218102492296`, 0.9415193237683902], 
             UndirectedEdge[305, 382] -> 
             RGBColor[
              0.31007770460075973`, 0.44200741025601153`, 0.9410150322193817],
              UndirectedEdge[50, 164] -> 
             RGBColor[
              0.22306024288786463`, 0.3517808364843617, 0.9360143228931819], 
             UndirectedEdge[259, 287] -> 
             RGBColor[
              0.8563718105158677, 0.5267891517148, 0.5770527968903222], 
             UndirectedEdge[90, 95] -> 
             RGBColor[
              0.23140010342565426`, 0.3605465586872775, 0.936489265613091], 
             UndirectedEdge[44, 243] -> 
             RGBColor[
              0.2298536898894718, 0.3589211800124685, 0.9364011996499193], 
             UndirectedEdge[82, 194] -> 
             RGBColor[
              0.6075992658363466, 0.6905170696190597, 0.963481170694517], 
             UndirectedEdge[124, 150] -> 
             RGBColor[
              0.2325126629936997, 0.36171592933364405`, 0.9365526242346068], 
             UndirectedEdge[233, 316] -> 
             RGBColor[
              0.8412361363066468, 0.8762214650435611, 0.9535246374949702], 
             UndirectedEdge[87, 390] -> 
             RGBColor[
              0.19991574882843044`, 0.32745450578221735`, 0.9346962781957078],
              UndirectedEdge[72, 376] -> 
             RGBColor[
              0.3758578545249899, 0.4975526740121381, 0.9453383722532241], 
             UndirectedEdge[99, 169] -> 
             RGBColor[
              0.6797124063510102, 0.7475445119943138, 0.9704734146298177], 
             UndirectedEdge[127, 137] -> 
             RGBColor[
              0.31600670483300364`, 0.4466421785419929, 0.9414111535240912], 
             UndirectedEdge[68, 391] -> 
             RGBColor[
              0.8209192855845969, 0.5085618177919978, 0.5749280813219132], 
             UndirectedEdge[292, 309] -> 
             RGBColor[
              0.7584292895983676, 0.45716808614862703`, 0.568384704834363], 
             UndirectedEdge[88, 140] -> 
             RGBColor[
              0.41837127081473313`, 0.5367938996534025, 0.947879225318494], 
             UndirectedEdge[153, 216] -> 
             RGBColor[
              0.21073387590110806`, 0.33882504324447416`, 0.935312354528512], 
             UndirectedEdge[145, 165] -> 
             RGBColor[
              0.23770682741222313`, 0.3671753254665574, 0.9368484242141641], 
             UndirectedEdge[37, 76] -> 
             RGBColor[
              0.28363325287465024`, 0.4154469105311262, 0.9394638662021915], 
             UndirectedEdge[6, 391] -> 
             RGBColor[
              0.8731987569820019, 0.5502480491958415, 0.5799145439742327], 
             UndirectedEdge[203, 206] -> 
             RGBColor[
              0.36944897924090714`, 0.4944198695980247, 0.9447619401596937], 
             UndirectedEdge[298, 320] -> 
             RGBColor[
              0.19458686072830475`, 0.3218535065179652, 0.9343928059017892], 
             UndirectedEdge[39, 164] -> 
             RGBColor[
              0.20658345954088297`, 0.3344626924982814, 0.9350759944567879], 
             UndirectedEdge[107, 156] -> 
             RGBColor[
              0.2124764155335251, 0.34065656288153834`, 0.9354115895827217], 
             UndirectedEdge[31, 222] -> 
             RGBColor[
              0.967672940132394, 0.9754000826172251, 0.9391115323234271], 
             UndirectedEdge[301, 329] -> 
             RGBColor[
              0.25610352101831557`, 0.38651141686430435`, 0.9378960886995618],
              UndirectedEdge[126, 320] -> 
             RGBColor[
              0.18313368370358218`, 0.3098154912916167, 0.9337405644136882], 
             UndirectedEdge[49, 191] -> 
             RGBColor[
              0.18385357890938503`, 0.3105721467969078, 0.933781561380669], 
             UndirectedEdge[122, 173] -> 
             RGBColor[
              0.18447873947082444`, 0.3112292301844495, 0.9338171633498009], 
             UndirectedEdge[60, 102] -> 
             RGBColor[
              0.5280292771941157, 0.6238948638185677, 0.9574471733011694], 
             UndirectedEdge[120, 380] -> 
             RGBColor[
              0.5664649447415552, 0.6566185624069654, 0.9601363872621158], 
             UndirectedEdge[110, 247] -> 
             RGBColor[
              0.8351507068562677, 0.5099360316010974, 0.5750372213001058], 
             UndirectedEdge[59, 149] -> 
             RGBColor[
              0.21329928840113216`, 0.34152145443854653`, 0.9354584509752006],
              UndirectedEdge[92, 346] -> 
             RGBColor[
              0.2038983093069455, 0.33164042935405524`, 0.934923079123289], 
             UndirectedEdge[6, 142] -> 
             RGBColor[
              0.7001614603741532, 0.763972329138221, 0.9722831025823769], 
             UndirectedEdge[176, 232] -> 
             RGBColor[
              0.18828223277850703`, 0.3152269428062281, 0.9340337666669094], 
             UndirectedEdge[60, 345] -> 
             RGBColor[
              0.7675537628448912, 0.8184035673483785, 0.9774488709937861], 
             UndirectedEdge[79, 126] -> 
             RGBColor[
              0.19080527822884924`, 0.31787882354485875`, 0.9341774503727951],
              UndirectedEdge[14, 212] -> 
             RGBColor[
              0.45821441723172895`, 0.5679246084974616, 0.9513517397459614], 
             UndirectedEdge[22, 338] -> 
             RGBColor[
              0.2260845393342366, 0.35495956380096844`, 0.9361865521017572], 
             UndirectedEdge[195, 389] -> 
             RGBColor[
              0.7088707754207897, 0.764952224756877, 0.7205833028362763], 
             UndirectedEdge[14, 293] -> 
             RGBColor[
              0.32638953387049785`, 0.45712394224882835`, 0.9420182303766638],
              UndirectedEdge[201, 394] -> 
             RGBColor[
              0.5116695891716139, 0.6114793927942537, 0.9556621742335425], 
             UndirectedEdge[20, 189] -> 
             RGBColor[
              0.30889970680782364`, 0.4349879582915822, 0.9411596287595527], 
             UndirectedEdge[195, 359] -> 
             RGBColor[
              0.375153965132881, 0.49936124163672424`, 0.9451254568160093], 
             UndirectedEdge[222, 224] -> 
             RGBColor[
              0.724417520241849, 0.7830873105778803, 0.9606419773233753], 
             UndirectedEdge[54, 389] -> 
             RGBColor[
              0.9706885388162402, 0.9101251515870772, 0.3850556620267193], 
             UndirectedEdge[123, 366] -> 
             RGBColor[
              0.9182289355345559, 0.6604066319094237, 0.35054608517613656`], 
             UndirectedEdge[120, 263] -> 
             RGBColor[
              0.3571898835204337, 0.4831624157488532, 0.9440042071759314], 
             UndirectedEdge[332, 364] -> 
             RGBColor[
              0.8695716309493327, 0.4318508782657767, 0.2101242523176128], 
             UndirectedEdge[70, 228] -> 
             RGBColor[
              0.21048617188066365`, 0.3385646906136451, 0.9352982481509928], 
             UndirectedEdge[74, 141] -> 
             RGBColor[
              0.3021503369999872, 0.43056214369424695`, 0.9406775662244785], 
             UndirectedEdge[212, 385] -> 
             RGBColor[
              0.7860985506073723, 0.8292872838004639, 0.7968353358505167], 
             UndirectedEdge[256, 384] -> 
             RGBColor[
              0.9629443447193516, 0.8827390749129462, 0.5213129511813582], 
             UndirectedEdge[158, 317] -> 
             RGBColor[
              0.18982224071375664`, 0.31684558878831803`, 0.9341214678405843],
              UndirectedEdge[76, 208] -> 
             RGBColor[
              0.28867650153937047`, 0.420747684638181, 0.9397510717528295], 
             UndirectedEdge[101, 253] -> 
             RGBColor[
              0.8395830715203696, 0.3052584098839103, 0.18553810003157822`], 
             UndirectedEdge[111, 309] -> 
             RGBColor[
              0.7619893896080814, 0.48453257486905843`, 0.5717938606242228], 
             UndirectedEdge[145, 170] -> 
             RGBColor[
              0.24268853638713495`, 0.37241141745778183`, 0.9371321251705074],
              UndirectedEdge[59, 279] -> 
             RGBColor[
              0.2076546436516325, 0.3355885749156745, 0.9351369968072203], 
             UndirectedEdge[83, 334] -> 
             RGBColor[
              0.9555982588691752, 0.9202058525384339, 0.6338919338224923], 
             UndirectedEdge[242, 312] -> 
             RGBColor[
              0.4441075478761082, 0.5565195124327971, 0.9502280720328274], 
             UndirectedEdge[140, 356] -> 
             RGBColor[
              0.6758651089866358, 0.7425832566534856, 0.9622242963377263], 
             UndirectedEdge[172, 316] -> 
             RGBColor[
              0.5458822960971526, 0.6391409074229324, 0.9586767421820886], 
             UndirectedEdge[217, 331] -> 
             RGBColor[
              0.22460790707912992`, 0.3534075296769589, 0.9361024600793104], 
             UndirectedEdge[263, 336] -> 
             RGBColor[
              0.2683165494931898, 0.3993480841421268, 0.9385916026036494], 
             UndirectedEdge[122, 338] -> 
             RGBColor[
              0.19975108063826336`, 0.32728142907378543`, 0.9346869005858826],
              UndirectedEdge[303, 400] -> 
             RGBColor[
              0.8580226382100805, 0.391117913716996, 0.20100792167803327`], 
             UndirectedEdge[133, 367] -> 
             RGBColor[
              0.18474901765317286`, 0.31151330969072427`, 0.9338325552924449],
              UndirectedEdge[136, 279] -> 
             RGBColor[
              0.19083656061449622`, 0.3179117033155916, 0.9341792318583795], 
             UndirectedEdge[117, 365] -> 
             RGBColor[
              0.4322742926857367, 0.5457268859697086, 0.94956369337159], 
             UndirectedEdge[33, 245] -> 
             RGBColor[
              0.22074175679161856`, 0.34934396059669826`, 0.9358822885398935],
              UndirectedEdge[162, 368] -> 
             RGBColor[
              0.18956500601498782`, 0.31657521881029016`, 0.934106818705034], 
             UndirectedEdge[46, 128] -> 
             RGBColor[
              0.5547192055800235, 0.6423805327309791, 0.9609350717272003], 
             UndirectedEdge[117, 269] -> 
             RGBColor[
              0.45596747114210545`, 0.5665010427125681, 0.9510641632117192], 
             UndirectedEdge[98, 134] -> 
             RGBColor[
              0.1861818864522268, 0.313019345647659, 0.9339141550508117], 
             UndirectedEdge[90, 326] -> 
             RGBColor[
              0.22857029923452804`, 0.35757225506245527`, 0.9363281124507266],
              UndirectedEdge[119, 306] -> 
             RGBColor[
              0.2310448890646134, 0.36017320587193224`, 0.9364690366807222], 
             UndirectedEdge[150, 211] -> 
             RGBColor[
              0.23544785722092995`, 0.3648010045685258, 0.9367197792036168], 
             UndirectedEdge[388, 395] -> 
             RGBColor[
              0.35473118198517756`, 0.4781619748017699, 0.9439526563033052], 
             UndirectedEdge[102, 108] -> 
             RGBColor[
              0.3276991764172302, 0.45803801914073383`, 0.9421097447928497], 
             UndirectedEdge[15, 392] -> 
             RGBColor[
              0.19259602959164984`, 0.3197610167673564, 0.9342794310137273], 
             UndirectedEdge[32, 292] -> 
             RGBColor[
              0.8205053754928366, 0.15861887831658708`, 0.16726927677043682`],
              UndirectedEdge[115, 332] -> 
             RGBColor[
              0.8864563951040925, 0.498793341625289, 0.2237101298928862], 
             UndirectedEdge[93, 293] -> 
             RGBColor[
              0.3283292569566383, 0.4588040328927261, 0.9421418278164828], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.1906510637312114, 0.3177167343300775, 0.9341686680852945], 
             UndirectedEdge[276, 305] -> 
             RGBColor[
              0.33855234976798615`, 0.46667071672258365`, 0.9428294114302973],
              UndirectedEdge[75, 347] -> 
             RGBColor[
              0.18311704522785527`, 0.30979800319868733`, 0.9337396168771099],
              UndirectedEdge[64, 193] -> 
             RGBColor[
              0.9152566921622731, 0.9300770448033753, 0.7093659477350615], 
             UndirectedEdge[18, 99] -> 
             RGBColor[
              0.947350971343756, 0.9556350172112698, 0.7097411277967336], 
             UndirectedEdge[74, 290] -> 
             RGBColor[
              0.2530317916874394, 0.3832828345786652, 0.9377211582583846], 
             UndirectedEdge[39, 230] -> 
             RGBColor[
              0.20964976351428055`, 0.33768557238922303`, 0.9352506159318827],
              UndirectedEdge[259, 345] -> 
             RGBColor[
              0.8617541752858404, 0.8926034039517254, 0.9866760766074392], 
             UndirectedEdge[30, 168] -> 
             RGBColor[
              0.19933167973369648`, 0.3268406121315325, 0.9346630163248155], 
             UndirectedEdge[231, 331] -> 
             RGBColor[
              0.21608777115484973`, 0.34445232661272185`, 0.9356172509428343],
              UndirectedEdge[137, 242] -> 
             RGBColor[
              0.31652160790723577`, 0.4470881617051118, 0.9414439626926704], 
             UndirectedEdge[172, 221] -> 
             RGBColor[
              0.3747675504331488, 0.4990265486455837, 0.9451008348130354], 
             UndirectedEdge[157, 211] -> 
             RGBColor[
              0.23967520555955008`, 0.36924421570178084`, 0.9369605204376998],
              UndirectedEdge[46, 213] -> 
             RGBColor[
              0.5654749182769274, 0.6521444572622102, 0.9616040176321952], 
             UndirectedEdge[184, 318] -> 
             RGBColor[
              0.2135047362690546, 0.34173739317388024`, 0.935470150927346], 
             UndirectedEdge[201, 293] -> 
             RGBColor[
              0.4899219075938762, 0.5926426440818758, 0.9542764311941287], 
             UndirectedEdge[64, 115] -> 
             RGBColor[
              0.973846560757742, 0.9231368127839409, 0.35853265585475147`], 
             UndirectedEdge[174, 266] -> 
             RGBColor[
              0.5380286912692482, 0.6346285303347542, 0.9572070721400225], 
             UndirectedEdge[80, 104] -> 
             RGBColor[
              0.2135778861880246, 0.34181427837669043`, 0.9354743167070156], 
             UndirectedEdge[265, 321] -> 
             RGBColor[
              0.19177497299708612`, 0.31889803422847507`, 0.9342326730553113],
              UndirectedEdge[178, 296] -> 
             RGBColor[
              0.18104204814496305`, 0.30761704970215387`, 0.9336214488629224],
              UndirectedEdge[114, 249] -> 
             RGBColor[
              0.18514988407402466`, 0.3119346457154385, 0.9338553840420838], 
             UndirectedEdge[255, 380] -> 
             RGBColor[
              0.5472854839726642, 0.6400062774766795, 0.9589142889816533], 
             UndirectedEdge[253, 391] -> 
             RGBColor[
              0.8227133050515791, 0.17558999242598253`, 0.16938359260938823`],
              UndirectedEdge[40, 63] -> 
             RGBColor[
              0.19138658757193353`, 0.3184898165215815, 0.9342105550799136], 
             UndirectedEdge[23, 311] -> 
             RGBColor[
              0.2072579319428704, 0.33517160575679045`, 0.9351144046622886], 
             UndirectedEdge[156, 396] -> 
             RGBColor[
              0.19313485512094197`, 0.32032735656215416`, 0.9343101163304997],
              UndirectedEdge[93, 281] -> 
             RGBColor[
              0.3706399848182322, 0.4954514587674228, 0.944837829981916], 
             UndirectedEdge[27, 325] -> 
             RGBColor[
              0.22165235452841858`, 0.35030105655330623`, 0.9359341457338957],
              UndirectedEdge[12, 107] -> 
             RGBColor[
              0.23293330946253646`, 0.362158055442918, 0.9365765794287164], 
             UndirectedEdge[255, 312] -> 
             RGBColor[
              0.46100266352577723`, 0.571153212435337, 0.9513046138622602], 
             UndirectedEdge[257, 310] -> 
             RGBColor[
              0.8979684765940259, 0.5907693635082272, 0.5548367056098094], 
             UndirectedEdge[50, 197] -> 
             RGBColor[
              0.21121964795225362`, 0.33933562046995513`, 0.9353400185281894],
              UndirectedEdge[215, 350] -> 
             RGBColor[
              0.5273081197953102, 0.6233107010129518, 0.9573840940310441], 
             UndirectedEdge[49, 235] -> 
             RGBColor[
              0.1884735679979762, 0.31542804825324383`, 0.9340446629246031], 
             UndirectedEdge[239, 323] -> 
             RGBColor[
              0.4638795886223883, 0.5747495967298069, 0.9511827422942791], 
             UndirectedEdge[211, 216] -> 
             RGBColor[
              0.22415272438939332`, 0.35292910380979625`, 0.9360765380985124],
              UndirectedEdge[98, 151] -> 
             RGBColor[
              0.20043054064394245`, 0.3279955846200067, 0.934725594828035], 
             UndirectedEdge[10, 32] -> 
             RGBColor[
              0.8322429825165458, 0.24883926935301032`, 0.1785092225120718], 
             UndirectedEdge[330, 367] -> 
             RGBColor[
              0.1873967228823739, 0.314296215760822, 0.9339833381883191], 
             UndirectedEdge[99, 384] -> 
             RGBColor[
              0.9178754148881313, 0.8496097092612407, 0.6279747633092586], 
             UndirectedEdge[127, 138] -> 
             RGBColor[
              0.31413697275722113`, 0.44467697158248487`, 0.9413046750483962],
              UndirectedEdge[292, 385] -> 
             RGBColor[
              0.9069547340805542, 0.5706484219232661, 0.4000326809306238], 
             UndirectedEdge[177, 219] -> 
             RGBColor[
              0.18016175523476746`, 0.3066918060397442, 0.9335713174839634], 
             UndirectedEdge[170, 322] -> 
             RGBColor[
              0.2153075934140704, 0.3436323103410369, 0.9355728209746665], 
             UndirectedEdge[261, 335] -> 
             RGBColor[
              0.19373393161436922`, 0.3209570239403897, 0.934344232850546], 
             UndirectedEdge[6, 253] -> 
             RGBColor[
              0.8756778488316885, 0.5693034354975091, 0.5822885251292265], 
             UndirectedEdge[95, 246] -> 
             RGBColor[
              0.23196638865379215`, 0.3611417603666076, 0.9365215147190895], 
             UndirectedEdge[50, 331] -> 
             RGBColor[
              0.2360482874744978, 0.36543209483450245`, 0.9367539728183005], 
             UndirectedEdge[9, 358] -> 
             RGBColor[
              0.48197798109692647`, 0.5820052784935108, 0.954246805716025], 
             UndirectedEdge[99, 144] -> 
             RGBColor[
              0.7417116613175341, 0.797878300210745, 0.9753542230915366], 
             UndirectedEdge[2, 28] -> 
             RGBColor[
              0.1967107027357332, 0.32408579912713337`, 0.9345137555621694], 
             UndirectedEdge[138, 258] -> 
             RGBColor[
              0.26327890753170885`, 0.39405320303566205`, 0.9383047163464664],
              UndirectedEdge[144, 384] -> 
             RGBColor[
              0.757420984754537, 0.7226612405223014, 0.6127983851533676], 
             UndirectedEdge[79, 277] -> 
             RGBColor[
              0.19208286823872933`, 0.31922165164912797`, 0.9342502072338328],
              UndirectedEdge[346, 354] -> 
             RGBColor[
              0.1997636988090205, 0.3272946915712895, 0.9346876191720402], 
             UndirectedEdge[144, 148] -> 
             RGBColor[
              0.41890511783186646`, 0.5289568419765102, 0.9490497655266936], 
             UndirectedEdge[38, 346] -> 
             RGBColor[
              0.23107597310122763`, 0.36020587716525554`, 0.9364708068706228],
              UndirectedEdge[38, 363] -> 
             RGBColor[
              0.3166257823122153, 0.444042358182842, 0.9415654261663287], 
             UndirectedEdge[78, 104] -> 
             RGBColor[
              0.22225745398096258`, 0.35093705444345114`, 0.9359686052525535],
              UndirectedEdge[95, 282] -> 
             RGBColor[
              0.2811273621289757, 0.41223265884799526`, 0.9393424107780823], 
             UndirectedEdge[92, 306] -> 
             RGBColor[
              0.21333519209183469`, 0.34155919149390046`, 0.9354604956372714],
              UndirectedEdge[9, 339] -> 
             RGBColor[
              0.5341582021850244, 0.6300810922914106, 0.9574662349562233], 
             UndirectedEdge[36, 148] -> 
             RGBColor[
              0.2511034439451054, 0.38125601883716365`, 0.9376113417071936], 
             UndirectedEdge[62, 395] -> 
             RGBColor[
              0.7152423649203183, 0.772631878073945, 0.8673341109470382], 
             UndirectedEdge[32, 247] -> 
             RGBColor[
              0.8194288056366617, 0.15034389064610632`, 0.16623835226035183`],
              UndirectedEdge[168, 379] -> 
             RGBColor[
              0.190216267574, 0.31725973600117974`, 0.9341439070873645], 
             UndirectedEdge[137, 230] -> 
             RGBColor[
              0.2568850160495337, 0.38733281769176137`, 0.9379405936854713], 
             UndirectedEdge[268, 279] -> 
             RGBColor[
              0.19334852815726622`, 0.3205519404709839, 0.9343222846938173], 
             UndirectedEdge[185, 288] -> 
             RGBColor[
              0.2031417930336449, 0.3308452827849142, 0.93487999664069], 
             UndirectedEdge[233, 310] -> 
             RGBColor[
              0.8984238517661913, 0.5911089815660195, 0.5540658742241997], 
             UndirectedEdge[150, 386] -> 
             RGBColor[
              0.29016677848912364`, 0.4192462598996066, 0.9399482680174902], 
             UndirectedEdge[138, 281] -> 
             RGBColor[
              0.3438282004171828, 0.4703940206570502, 0.9431965738199672], 
             UndirectedEdge[88, 257] -> 
             RGBColor[
              0.6999080745469857, 0.7619616397704058, 0.9426465587738788], 
             UndirectedEdge[27, 40] -> 
             RGBColor[
              0.19924073649984758`, 0.3267450250266232, 0.9346578372421862], 
             UndirectedEdge[159, 250] -> 
             RGBColor[
              0.18793077615893167`, 0.3148575396154177, 0.934013751732358], 
             UndirectedEdge[169, 363] -> 
             RGBColor[
              0.4158922643017966, 0.5345397089893019, 0.947750829584961], 
             UndirectedEdge[144, 382] -> 
             RGBColor[
              0.451676599366216, 0.5621674511867154, 0.9509612465314614], 
             UndirectedEdge[35, 207] -> 
             RGBColor[
              0.19080850531779897`, 0.3178822154199542, 0.9341776341507367], 
             UndirectedEdge[71, 287] -> 
             RGBColor[
              0.8935114377259239, 0.5555263902170573, 0.5501928078759782], 
             UndirectedEdge[148, 361] -> 
             RGBColor[
              0.33306353105933184`, 0.4580790241212378, 0.94262018039587], 
             UndirectedEdge[215, 393] -> 
             RGBColor[
              0.7140213652809209, 0.7765181844116039, 0.9721306348483233], 
             UndirectedEdge[33, 124] -> 
             RGBColor[
              0.23660403432322674`, 0.366016220008902, 0.9367856217791819], 
             UndirectedEdge[31, 111] -> 
             RGBColor[
              0.905435236677787, 0.5966580870469695, 0.5418299175859177], 
             UndirectedEdge[113, 357] -> 
             RGBColor[
              0.18582607626581804`, 0.31264536658207454`, 0.9338938921870696],
              UndirectedEdge[30, 329] -> 
             RGBColor[
              0.23151896311630302`, 0.36067148775828894`, 0.9364960344966363],
              UndirectedEdge[117, 239] -> 
             RGBColor[
              0.5328344578573876, 0.6316180426642315, 0.9563658268409162], 
             UndirectedEdge[209, 338] -> 
             RGBColor[
              0.23759083072429804`, 0.3670534055929334, 0.9368418183743885], 
             UndirectedEdge[208, 323] -> 
             RGBColor[
              0.3575199332630081, 0.48276280813906464`, 0.9440503364383386], 
             UndirectedEdge[71, 212] -> 
             RGBColor[
              0.7737416965530766, 0.822516123696677, 0.9480358411696325], 
             UndirectedEdge[199, 292] -> 
             RGBColor[
              0.9041138184890838, 0.5702193507910247, 0.501320010499076], 
             UndirectedEdge[11, 386] -> 
             RGBColor[
              0.6075598618760001, 0.6861529495738531, 0.9653876814635047], 
             UndirectedEdge[130, 267] -> 
             RGBColor[
              0.20661372269188627`, 0.33449450098878053`, 0.9350777178984673],
              UndirectedEdge[67, 347] -> 
             RGBColor[
              0.18186543483400505`, 0.3084824813180684, 0.9336683395167719], 
             UndirectedEdge[211, 358] -> 
             RGBColor[
              0.2550430737157216, 0.3853968195130357, 0.9378356977944702], 
             UndirectedEdge[2, 164] -> 
             RGBColor[
              0.20840908696131982`, 0.3363815426686245, 0.935179961237608], 
             UndirectedEdge[266, 358] -> 
             RGBColor[
              0.4679094050103473, 0.5710147999295367, 0.9528445815300333], 
             UndirectedEdge[57, 397] -> 
             RGBColor[
              0.3562392675894767, 0.4829782813049682, 0.943920229014154], 
             UndirectedEdge[209, 386] -> 
             RGBColor[
              0.30348621877337745`, 0.4332458361396474, 0.9407067904373323], 
             UndirectedEdge[74, 386] -> 
             RGBColor[
              0.29523037248077955`, 0.42456841823523894`, 0.9402366322043989],
              UndirectedEdge[47, 268] -> 
             RGBColor[
              0.18433220446865944`, 0.3110752126063183, 0.9338088183982067], 
             UndirectedEdge[108, 397] -> 
             RGBColor[
              0.3352715846751584, 0.4645968585734458, 0.9425922519510271], 
             UndirectedEdge[157, 358] -> 
             RGBColor[
              0.2622292284500658, 0.3929499237673575, 0.938244938675628], 
             UndirectedEdge[10, 129] -> 
             RGBColor[
              0.8311516302547027, 0.2404506576348733, 0.17746414235362473`], 
             UndirectedEdge[171, 308] -> 
             RGBColor[
              0.20045056014029836`, 0.3280166263799862, 0.9347267349087363], 
             UndirectedEdge[225, 335] -> 
             RGBColor[
              0.20337317791570175`, 0.3310884829666048, 0.93489317366742], 
             UndirectedEdge[45, 116] -> 
             RGBColor[
              0.23987123039501432`, 0.3694502502325462, 0.9369716837620867], 
             UndirectedEdge[261, 349] -> 
             RGBColor[
              0.19380914280268063`, 0.32103607566796977`, 0.9343485160164554],
              UndirectedEdge[118, 209] -> 
             RGBColor[
              0.3112464668184692, 0.43996737295489813`, 0.9412012665806477], 
             UndirectedEdge[329, 343] -> 
             RGBColor[
              0.23152940348291426`, 0.3606824612455548, 0.9364966290600697], 
             UndirectedEdge[163, 171] -> 
             RGBColor[
              0.18355378954190335`, 0.31025704916394076`, 0.9337644888196897],
              UndirectedEdge[106, 217] -> 
             RGBColor[
              0.1973830107710603, 0.32479243749905357`, 0.9345520425101908], 
             UndirectedEdge[55, 123] -> 
             RGBColor[
              0.8234475715902414, 0.5896702073672445, 0.5850169799812919], 
             UndirectedEdge[129, 353] -> 
             RGBColor[
              0.9062979809873158, 0.5688117544551025, 0.33694932919085196`], 
             UndirectedEdge[38, 66] -> 
             RGBColor[
              0.22742648369193186`, 0.3563700324050926, 0.9362629738476992], 
             UndirectedEdge[23, 119] -> 
             RGBColor[
              0.22585475434557115`, 0.35471804520867123`, 0.936173466186589], 
             UndirectedEdge[306, 354] -> 
             RGBColor[
              0.2092005815939097, 0.33721345371113465`, 0.9352250356860227], 
             UndirectedEdge[28, 39] -> 
             RGBColor[
              0.19488507531529636`, 0.3221669489567903, 0.9344097887813494], 
             UndirectedEdge[158, 267] -> 
             RGBColor[
              0.19435218965099377`, 0.3216068523367057, 0.934379441731101], 
             UndirectedEdge[194, 399] -> 
             RGBColor[
              0.40740786703989107`, 0.5272403351648417, 0.9471965661691704], 
             UndirectedEdge[102, 333] -> 
             RGBColor[
              0.6514056454646207, 0.7208926458479099, 0.9532948082895194], 
             UndirectedEdge[16, 80] -> 
             RGBColor[
              0.21603013302378776`, 0.34439174528250716`, 0.9356139685365383],
              UndirectedEdge[72, 333] -> 
             RGBColor[
              0.7096566263019076, 0.7710149507769987, 0.9570981774601166], 
             UndirectedEdge[167, 211] -> 
             RGBColor[
              0.23414776627805434`, 0.3634345265570368, 0.9366457409477322], 
             UndirectedEdge[193, 255] -> 
             RGBColor[
              0.606058461723811, 0.6860652101473173, 0.9647337421078497], 
             UndirectedEdge[168, 211] -> 
             RGBColor[
              0.2152267109388578, 0.3435472977313434, 0.935568214837358], 
             UndirectedEdge[70, 246] -> 
             RGBColor[
              0.2068329817370454, 0.33472495614706915`, 0.9350902043767244], 
             UndirectedEdge[322, 349] -> 
             RGBColor[
              0.19676296516777197`, 0.32414073025683565`, 0.9345167318303588],
              UndirectedEdge[193, 312] -> 
             RGBColor[
              0.6928723364666782, 0.7586931681891012, 0.9709743993376487], 
             UndirectedEdge[194, 221] -> 
             RGBColor[
              0.41267584437400284`, 0.5318031923554098, 0.9475322370266106], 
             UndirectedEdge[208, 221] -> 
             RGBColor[
              0.3321648835388723, 0.4608015384498717, 0.9424347350905069], 
             UndirectedEdge[112, 251] -> 
             RGBColor[
              0.18268323345773074`, 0.30934203952303163`, 0.9337149119385684],
              UndirectedEdge[297, 325] -> 
             RGBColor[
              0.267416015836295, 0.3984015661715987, 0.9385403185441094], 
             UndirectedEdge[170, 225] -> 
             RGBColor[
              0.22199301735031157`, 0.3506591147783862, 0.9359535459776369], 
             UndirectedEdge[27, 250] -> 
             RGBColor[
              0.19937642447535237`, 0.3268876416919933, 0.9346655644716588], 
             UndirectedEdge[67, 126] -> 
             RGBColor[
              0.18098291600078534`, 0.3075548980694286, 0.9336180813747896], 
             UndirectedEdge[12, 157] -> 
             RGBColor[
              0.24482342257705114`, 0.37465531820298625`, 0.937253703780742], 
             UndirectedEdge[316, 399] -> 
             RGBColor[
              0.5357585344043984, 0.6303722138797264, 0.9580316650391174], 
             UndirectedEdge[76, 377] -> 
             RGBColor[
              0.2688145572376063, 0.39987152185702324`, 0.9386199634079575], 
             UndirectedEdge[3, 51] -> 
             RGBColor[
              0.2187121116641707, 0.34721067488081686`, 0.9357667032524762], 
             UndirectedEdge[23, 186] -> 
             RGBColor[
              0.209250396089514, 0.3372658119044362, 0.9352278725478533], 
             UndirectedEdge[17, 319] -> 
             RGBColor[
              0.8300530358518976, 0.23200637964777565`, 0.17641212711281357`],
              UndirectedEdge[115, 360] -> 
             RGBColor[
              0.8089316906478522, 0.7980968050279984, 0.6248789386336926], 
             UndirectedEdge[131, 142] -> 
             RGBColor[
              0.6441352636384634, 0.7193460306737178, 0.9669266768382974], 
             UndirectedEdge[23, 130] -> 
             RGBColor[
              0.21379154943709947`, 0.3420388519985006, 0.935486484512964], 
             UndirectedEdge[348, 354] -> 
             RGBColor[
              0.19860265347109932`, 0.3260743593066081, 0.9346214993576583], 
             UndirectedEdge[76, 80] -> 
             RGBColor[
              0.24302079240522623`, 0.37276063959904404`, 0.9371510466592089],
              UndirectedEdge[38, 81] -> 
             RGBColor[
              0.2439408678768847, 0.37372769725591143`, 0.9372034435961902], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.22057742375863354`, 0.3491712361597149, 0.935872930016774], 
             UndirectedEdge[131, 281] -> 
             RGBColor[
              0.6064310569728814, 0.687254440774864, 0.9643678385927457], 
             UndirectedEdge[157, 167] -> 
             RGBColor[
              0.24133392101239853`, 0.37098763081135855`, 0.93705498182889], 
             UndirectedEdge[165, 172] -> 
             RGBColor[
              0.3025819493818708, 0.42881009810169846`, 0.9407829073040905], 
             UndirectedEdge[255, 331] -> 
             RGBColor[
              0.30757882188877433`, 0.4345645888368619, 0.9410490742458533], 
             UndirectedEdge[59, 268] -> 
             RGBColor[
              0.2019662570213913, 0.3296097199027477, 0.9348130516038419], 
             UndirectedEdge[161, 364] -> 
             RGBColor[
              0.9004423422818535, 0.6358848335091806, 0.23838402091941335`], 
             UndirectedEdge[149, 164] -> 
             RGBColor[
              0.21265948505393958`, 0.340848980554772, 0.9354220151210823], 
             UndirectedEdge[10, 52] -> 
             RGBColor[
              0.9159808794279284, 0.6604932743481702, 0.5104145698509248], 
             UndirectedEdge[132, 155] -> 
             RGBColor[
              0.18938684794258642`, 0.3163879633803221, 0.934096672866372], 
             UndirectedEdge[353, 400] -> 
             RGBColor[
              0.9076875092111716, 0.5794922772788073, 0.33827994298726377`], 
             UndirectedEdge[250, 265] -> 
             RGBColor[
              0.19635832810443649`, 0.32371543104779843`, 0.9344936883482087],
              UndirectedEdge[82, 233] -> 
             RGBColor[
              0.865044812104987, 0.8948209835298624, 0.9558976637938235], 
             UndirectedEdge[66, 81] -> 
             RGBColor[
              0.21264159429708712`, 0.3408301762349806, 0.9354209962689466], 
             UndirectedEdge[69, 201] -> 
             RGBColor[
              0.6192660008437627, 0.7014292931597987, 0.9634146436784279], 
             UndirectedEdge[84, 184] -> 
             RGBColor[
              0.21392003441563898`, 0.34217389785736374`, 0.9354938015424155],
              UndirectedEdge[180, 268] -> 
             RGBColor[
              0.1880422345433147, 0.314974689444274, 0.9340200991224608], 
             UndirectedEdge[17, 247] -> 
             RGBColor[
              0.8225002166596341, 0.17395210166956507`, 0.16917953892461288`],
              UndirectedEdge[188, 394] -> 
             RGBColor[
              0.3167171676025393, 0.44570099448454903`, 0.9415134165478973], 
             UndirectedEdge[241, 312] -> 
             RGBColor[
              0.41436397282412324`, 0.5281836244089898, 0.9484270661099586], 
             UndirectedEdge[81, 128] -> 
             RGBColor[
              0.2665289573662383, 0.3974692114768138, 0.9384898018765251], 
             UndirectedEdge[65, 198] -> 
             RGBColor[
              0.6026458427872066, 0.6834233570756016, 0.9643717480774334], 
             UndirectedEdge[356, 380] -> 
             RGBColor[
              0.8328828698668729, 0.8701375149884446, 0.9750500932107594], 
             UndirectedEdge[40, 265] -> 
             RGBColor[
              0.1962226401289317, 0.32357281438242835`, 0.9344859611187359], 
             UndirectedEdge[19, 168] -> 
             RGBColor[
              0.19873861175960342`, 0.3262172600880793, 0.9346292419810562], 
             UndirectedEdge[195, 241] -> 
             RGBColor[
              0.35276484059541724`, 0.47739540900316435`, 0.9437930699766406],
              UndirectedEdge[33, 141] -> 
             RGBColor[
              0.3011781143378584, 0.42954027603387246`, 0.9406221995821449], 
             UndirectedEdge[65, 100] -> 
             RGBColor[
              0.38210315454201915`, 0.5053802802265043, 0.9455682530202327], 
             UndirectedEdge[15, 207] -> 
             RGBColor[
              0.18682358813972555`, 0.3136938148074571, 0.9339506990126021], 
             UndirectedEdge[81, 135] -> 
             RGBColor[
              0.2822556151095555, 0.41153871876028536`, 0.9394754920042432], 
             UndirectedEdge[259, 271] -> 
             RGBColor[
              0.8577136869121025, 0.5371034017102467, 0.5783377792427893], 
             UndirectedEdge[194, 233] -> 
             RGBColor[
              0.7128854689421396, 0.7730895863286765, 0.9426895386250231], 
             UndirectedEdge[101, 283] -> 
             RGBColor[
              0.8929481444706848, 0.5918370196285758, 0.23170005506756156`], 
             UndirectedEdge[145, 192] -> 
             RGBColor[
              0.25406976709764434`, 0.3843738125462326, 0.9377802694224489], 
             UndirectedEdge[68, 397] -> 
             RGBColor[
              0.5928919663607762, 0.6752224028696671, 0.9636363647773936], 
             UndirectedEdge[142, 201] -> 
             RGBColor[
              0.5699368421210522, 0.6613816598554264, 0.9595312716051138], 
             UndirectedEdge[146, 354] -> 
             RGBColor[
              0.197615256434939, 0.32503654241701563`, 0.9345652685571719], 
             UndirectedEdge[153, 329] -> 
             RGBColor[
              0.23399514583317907`, 0.36327411279277777`, 0.9366370494391784],
              UndirectedEdge[132, 279] -> 
             RGBColor[
              0.1959554713815859, 0.323292003089491, 0.9344707462538155], 
             UndirectedEdge[257, 389] -> 
             RGBColor[
              0.981271770948398, 0.982206986986089, 0.7147685106713391], 
             UndirectedEdge[107, 386] -> 
             RGBColor[
              0.2825040137132291, 0.4111922082727934, 0.9395118848995476], 
             UndirectedEdge[157, 203] -> 
             RGBColor[
              0.2784354581733116, 0.40986687435040126`, 0.9391721369966093], 
             UndirectedEdge[264, 281] -> 
             RGBColor[
              0.3293650670543722, 0.4551923504771167, 0.9423729197712435], 
             UndirectedEdge[244, 302] -> 
             RGBColor[
              0.18853043849765405`, 0.3154878227542032, 0.9340479016154273], 
             UndirectedEdge[46, 105] -> 
             RGBColor[
              0.8954193827902208, 0.9181003086598438, 0.937247307981482], 
             UndirectedEdge[126, 347] -> 
             RGBColor[
              0.18344187738111917`, 0.31013942238731573`, 0.9337581155876922],
              UndirectedEdge[129, 253] -> 
             RGBColor[
              0.822264279381292, 0.17213858435985327`, 0.16895360512041946`], 
             UndirectedEdge[14, 69] -> 
             RGBColor[
              0.45573362712038445`, 0.5659105913267511, 0.9511564428609628], 
             UndirectedEdge[118, 124] -> 
             RGBColor[
              0.29203302591126107`, 0.41977282835890883`, 0.9401070895447208],
              UndirectedEdge[181, 245] -> 
             RGBColor[
              0.1935081925729178, 0.3207197578951424, 0.9343313773460864], 
             UndirectedEdge[33, 152] -> 
             RGBColor[
              0.2237166408577273, 0.3524707523687224, 0.9360517037865118], 
             UndirectedEdge[47, 371] -> 
             RGBColor[
              0.18051873474236652`, 0.3070670141360388, 0.9335916469388172], 
             UndirectedEdge[131, 273] -> 
             RGBColor[
              0.6690783888345512, 0.7395959833828867, 0.9688902910234116], 
             UndirectedEdge[230, 299] -> 
             RGBColor[
              0.20475753633962784`, 0.33254353144354476`, 0.9349720108316877],
              UndirectedEdge[107, 181] -> 
             RGBColor[
              0.20760170595158578`, 0.3355329340364814, 0.935133982083517], 
             UndirectedEdge[4, 318] -> 
             RGBColor[
              0.20715075077545358`, 0.3350589515541568, 0.9351083008533645], 
             UndirectedEdge[10, 333] -> 
             RGBColor[
              0.8983718156694669, 0.6481583597796403, 0.5759535503804154], 
             UndirectedEdge[152, 238] -> 
             RGBColor[
              0.20086303760420032`, 0.32845016634712887`, 0.9347502248900996],
              UndirectedEdge[50, 147] -> 
             RGBColor[
              0.23917140342485926`, 0.3687146877153205, 0.9369318296514377], 
             UndirectedEdge[39, 217] -> 
             RGBColor[
              0.2032105562120073, 0.33091755724521044`, 0.9348839126019717], 
             UndirectedEdge[98, 308] -> 
             RGBColor[
              0.20304826815792704`, 0.3307469822107151, 0.9348746705373756], 
             UndirectedEdge[31, 363] -> 
             RGBColor[
              0.6793920980440895, 0.7432878081939467, 0.9278140990011539], 
             UndirectedEdge[286, 386] -> 
             RGBColor[
              0.331585149915525, 0.4616241237277755, 0.94234929043675], 
             UndirectedEdge[137, 138] -> 
             RGBColor[
              0.29077492625511725`, 0.4229532620622423, 0.93987057393605], 
             UndirectedEdge[35, 372] -> 
             RGBColor[
              0.18502327958345532`, 0.31180157636866185`, 0.9338481741036404],
              UndirectedEdge[130, 158] -> 
             RGBColor[
              0.20340188077088672`, 0.3311186514872704, 0.9348948082525605], 
             UndirectedEdge[277, 373] -> 
             RGBColor[
              0.19154984531155025`, 0.31866141075705723`, 0.9342198523666666],
              UndirectedEdge[234, 365] -> 
             RGBColor[
              0.27647661087306347`, 0.4079248260301478, 0.9390563060275041], 
             UndirectedEdge[310, 316] -> 
             RGBColor[
              0.7693289728620583, 0.48993694637010154`, 0.5724844799948403], 
             UndirectedEdge[218, 305] -> 
             RGBColor[
              0.42916789405553485`, 0.5422531768418173, 0.9494057845729981], 
             UndirectedEdge[155, 279] -> 
             RGBColor[
              0.19246829134850796`, 0.31962675577474187`, 0.9342721565097523],
              UndirectedEdge[32, 129] -> 
             RGBColor[
              0.8204275141231614, 0.1580204017101934, 0.16719471663490398`], 
             UndirectedEdge[92, 158] -> 
             RGBColor[
              0.19775538870657966`, 0.32518383031940923`, 0.9345732488827347],
              UndirectedEdge[332, 334] -> 
             RGBColor[
              0.8890082529415364, 0.5076542323723299, 0.23230663812042954`], 
             UndirectedEdge[268, 300] -> 
             RGBColor[
              0.1919105716037125, 0.31904055696148764`, 0.9342403951953585], 
             UndirectedEdge[224, 227] -> 
             RGBColor[
              0.3858696957004528, 0.504223043119987, 0.9462592294929938], 
             UndirectedEdge[25, 91] -> 
             RGBColor[
              0.47826887557608655`, 0.5848930154724093, 0.9527405987202289], 
             UndirectedEdge[74, 304] -> 
             RGBColor[
              0.2654021800822186, 0.39628489710950293`, 0.9384256335771177], 
             UndirectedEdge[86, 397] -> 
             RGBColor[
              0.3161394186740798, 0.4444877390569253, 0.9415027034007689], 
             UndirectedEdge[32, 111] -> 
             RGBColor[
              0.8240654755025505, 0.18598336703701845`, 0.17067843256029655`],
              UndirectedEdge[59, 394] -> 
             RGBColor[
              0.286948743301538, 0.41441249311708334`, 0.9398181488223927], 
             UndirectedEdge[170, 355] -> 
             RGBColor[
              0.2218222289646276, 0.3504796053564232, 0.9359438198317311], 
             UndirectedEdge[9, 56] -> 
             RGBColor[
              0.6023784760141789, 0.6874029877027437, 0.9623014191002394], 
             UndirectedEdge[44, 317] -> 
             RGBColor[
              0.2084087804726259, 0.3363812205295747, 0.9351799437835304], 
             UndirectedEdge[236, 262] -> 
             RGBColor[
              0.4369845815472029, 0.5513866495573997, 0.9494877616771007], 
             UndirectedEdge[119, 346] -> 
             RGBColor[
              0.2216080062797242, 0.35025444373208703`, 0.9359316201667398], 
             UndirectedEdge[80, 244] -> 
             RGBColor[
              0.1927330122426994, 0.31990499421881113`, 0.9342872319730569], 
             UndirectedEdge[20, 360] -> 
             RGBColor[
              0.523690607917635, 0.622017048024192, 0.9563749606192402], 
             UndirectedEdge[196, 206] -> 
             RGBColor[
              0.6365065028818196, 0.7122246861355508, 0.9667719599708235], 
             UndirectedEdge[187, 302] -> 
             RGBColor[
              0.20552429842574232`, 0.33334944701157526`, 0.9350156767981692],
              UndirectedEdge[147, 312] -> 
             RGBColor[
              0.3975158125820031, 0.5104751397594638, 0.9474675883087893], 
             UndirectedEdge[259, 400] -> 
             RGBColor[
              0.8587699196703826, 0.545222069534533, 0.5793492289249624], 
             UndirectedEdge[120, 312] -> 
             RGBColor[
              0.4801821242946682, 0.587765497365623, 0.9525267121427227], 
             UndirectedEdge[52, 60] -> 
             RGBColor[
              0.8480092281788032, 0.880384326820778, 0.9017418370121976], 
             UndirectedEdge[266, 384] -> 
             RGBColor[
              0.7959032258697958, 0.7536598609266292, 0.6159939861993788], 
             UndirectedEdge[135, 393] -> 
             RGBColor[
              0.5286635054610748, 0.6238093444947674, 0.9577562869015417], 
             UndirectedEdge[77, 244] -> 
             RGBColor[
              0.18965577385650711`, 0.31667062156674053`, 0.9341119877993296],
              UndirectedEdge[239, 385] -> 
             RGBColor[
              0.750777447641219, 0.8006120212149852, 0.7940547292395577], 
             UndirectedEdge[278, 296] -> 
             RGBColor[
              0.1835851599868279, 0.3102900214905575, 0.9337662753201197], 
             UndirectedEdge[267, 275] -> 
             RGBColor[
              0.19585412945824818`, 0.323185486302614, 0.9344649749812033], 
             UndirectedEdge[148, 340] -> 
             RGBColor[
              0.263972502592159, 0.39478221542066183`, 0.9383442155590771], 
             UndirectedEdge[202, 212] -> 
             RGBColor[
              0.45268550871471924`, 0.56313574583105, 0.9509994425842794], 
             UndirectedEdge[81, 346] -> 
             RGBColor[
              0.21629108370638292`, 0.34466602099514354`, 0.9356288292918702],
              UndirectedEdge[50, 217] -> 
             RGBColor[
              0.21968733955898895`, 0.34823570123129066`, 0.9358222410383658],
              UndirectedEdge[5, 183] -> 
             RGBColor[
              0.1877508166785864, 0.3146683907914848, 0.9340035033061785], 
             UndirectedEdge[313, 339] -> 
             RGBColor[
              0.3332875570200404, 0.460867825469856, 0.9425394482092617], 
             UndirectedEdge[4, 184] -> 
             RGBColor[
              0.20719899217930893`, 0.3351096563282905, 0.9351110481299474], 
             UndirectedEdge[104, 349] -> 
             RGBColor[
              0.21123195753513827`, 0.3393485586220395, 0.9353407195407242], 
             UndirectedEdge[119, 135] -> 
             RGBColor[
              0.2875725376828968, 0.4171271414972289, 0.9397782828791128], 
             UndirectedEdge[53, 273] -> 
             RGBColor[
              0.4633253395942303, 0.573810427068907, 0.9512742786711021], 
             UndirectedEdge[224, 259] -> 
             RGBColor[
              0.6965860849930616, 0.7612921063995717, 0.9717456253125671], 
             UndirectedEdge[110, 289] -> 
             RGBColor[
              0.6635885313279589, 0.7348104646113509, 0.9687942877706517], 
             UndirectedEdge[59, 155] -> 
             RGBColor[
              0.20108602021263303`, 0.3286845352065056, 0.9347629234197767], 
             UndirectedEdge[5, 29] -> 
             RGBColor[
              0.18632940584411195`, 0.31317439788179996`, 0.9339225560619441],
              UndirectedEdge[119, 311] -> 
             RGBColor[
              0.22119300122602184`, 0.3498182471078057, 0.9359079862428765], 
             UndirectedEdge[68, 72] -> 
             RGBColor[
              0.6435705389401349, 0.7187858683660439, 0.9669572267898132], 
             UndirectedEdge[121, 234] -> 
             RGBColor[
              0.2453302072944222, 0.37518798107295015`, 0.9372825644206755], 
             UndirectedEdge[20, 336] -> 
             RGBColor[
              0.3097133743307097, 0.43584317444763615`, 0.9412059659212678], 
             UndirectedEdge[17, 256] -> 
             RGBColor[
              0.9099828197722593, 0.6023554678641716, 0.47566457355675007`], 
             UndirectedEdge[186, 272] -> 
             RGBColor[
              0.20161622991530592`, 0.3292418192212516, 0.9347931180779689], 
             UndirectedEdge[45, 304] -> 
             RGBColor[
              0.2609958832174149, 0.3916535997292371, 0.9381747014891992], 
             UndirectedEdge[165, 252] -> 
             RGBColor[
              0.21574093049341658`, 0.3440877750865875, 0.9355974988802704], 
             UndirectedEdge[106, 254] -> 
             RGBColor[
              0.18679837373704838`, 0.3136673128715579, 0.9339492630896711], 
             UndirectedEdge[144, 169] -> 
             RGBColor[
              0.5192579762174159, 0.6205960432553745, 0.9552970364739267], 
             UndirectedEdge[191, 355] -> 
             RGBColor[
              0.19607480659810572`, 0.32341743196834305`, 0.9344775422178556],
              UndirectedEdge[96, 377] -> 
             RGBColor[
              0.23316169487877575`, 0.36239810299585723`, 0.9365895856403053],
              UndirectedEdge[110, 303] -> 
             RGBColor[
              0.873446363467674, 0.7484181435664192, 0.6095212570798225], 
             UndirectedEdge[177, 260] -> 
             RGBColor[
              0.18516377148342406`, 0.31194924226322995`, 0.9338561749095045],
              UndirectedEdge[20, 88] -> 
             RGBColor[
              0.40751079531136875`, 0.5273871016357587, 0.9471872054229611], 
             UndirectedEdge[57, 68] -> 
             RGBColor[
              0.584951659196002, 0.6683449078949819, 0.9631304154261922], 
             UndirectedEdge[127, 264] -> 
             RGBColor[
              0.2996738393944105, 0.42947530140255136`, 0.9404810209996725], 
             UndirectedEdge[171, 186] -> 
             RGBColor[
              0.1973172314150955, 0.32472329922528254`, 0.9345482964731804], 
             UndirectedEdge[362, 385] -> 
             RGBColor[
              0.892844244734438, 0.9136671066548807, 0.806798376116899], 
             UndirectedEdge[109, 370] -> 
             RGBColor[
              0.18414849826566793`, 0.3108821257393283, 0.9337983566017154], 
             UndirectedEdge[123, 161] -> 
             RGBColor[
              0.861352076814639, 0.4393326641242953, 0.20508206465224244`], 
             UndirectedEdge[119, 213] -> 
             RGBColor[
              0.2826015926364835, 0.4128215587449884, 0.9394615386563896], 
             UndirectedEdge[140, 360] -> 
             RGBColor[
              0.5345510834209994, 0.6314238460418358, 0.9570669805147731], 
             UndirectedEdge[320, 347] -> 
             RGBColor[
              0.1840162025368019, 0.3107430745402564, 0.9337908225556705], 
             UndirectedEdge[10, 345] -> 
             RGBColor[
              0.8355254140940163, 0.5985125148757706, 0.5861216038325132], 
             UndirectedEdge[169, 383] -> 
             RGBColor[
              0.4077881387207459, 0.527520322736191, 0.9472344418691334], 
             UndirectedEdge[154, 372] -> 
             RGBColor[
              0.18315975702077553`, 0.3098428960011307, 0.9337420492505304], 
             UndirectedEdge[167, 341] -> 
             RGBColor[
              0.2425749937598598, 0.37229207695749733`, 0.9371256590858552], 
             UndirectedEdge[186, 308] -> 
             RGBColor[
              0.20971443584181115`, 0.3377535471059201, 0.9352542989252615], 
             UndirectedEdge[145, 225] -> 
             RGBColor[
              0.22917757181567264`, 0.3582105370485437, 0.9363626957258434], 
             UndirectedEdge[12, 65] -> 
             RGBColor[
              0.30963980079837916`, 0.4365176650238572, 0.941174248166886], 
             UndirectedEdge[274, 288] -> 
             RGBColor[
              0.20843688657003606`, 0.3364107618199823, 0.9351815443841986], 
             UndirectedEdge[143, 171] -> 
             RGBColor[
              0.19347840745274208`, 0.320688451845352, 0.9343296811275554], 
             UndirectedEdge[167, 168] -> 
             RGBColor[
              0.21688542639170627`, 0.3452907128409211, 0.935662676228548], 
             UndirectedEdge[203, 341] -> 
             RGBColor[
              0.2796765309207728, 0.4111713204965401, 0.9392428142535747], 
             UndirectedEdge[114, 299] -> 
             RGBColor[
              0.1875337477163088, 0.31444023754916384`, 0.9339911415499016], 
             UndirectedEdge[154, 231] -> 
             RGBColor[
              0.18878970308862236`, 0.3157603262776354, 0.9340626663503354], 
             UndirectedEdge[218, 384] -> 
             RGBColor[
              0.7469305423915883, 0.7141446268230167, 0.6119725391027997], 
             UndirectedEdge[360, 380] -> 
             RGBColor[
              0.6915688443012366, 0.7589781043767949, 0.9698927773878063], 
             UndirectedEdge[98, 306] -> 
             RGBColor[
              0.20777436312467215`, 0.33571440767249217`, 0.9351438146541007],
              UndirectedEdge[57, 262] -> 
             RGBColor[
              0.35631608788520674`, 0.4830448191840292, 0.9439251239354682], 
             UndirectedEdge[152, 160] -> 
             RGBColor[
              0.19806967394342445`, 0.325514164030168, 0.9345911469620297], 
             UndirectedEdge[311, 354] -> 
             RGBColor[
              0.19934869375531813`, 0.32685849494700814`, 0.9346639852481768],
              UndirectedEdge[287, 303] -> 
             RGBColor[
              0.8556245290555657, 0.372684995897263, 0.19871148964339302`], 
             UndirectedEdge[222, 247] -> 
             RGBColor[
              0.8842131182088144, 0.5486602398250497, 0.5659586027648067], 
             UndirectedEdge[24, 206] -> 
             RGBColor[
              0.3445350824096081, 0.46835060878643464`, 0.9433388530787478], 
             UndirectedEdge[92, 308] -> 
             RGBColor[
              0.20860909712508957`, 0.3365917660321234, 0.9351913515205462], 
             UndirectedEdge[18, 266] -> 
             RGBColor[
              0.8253787823254205, 0.8596851688766582, 0.6977603506868537], 
             UndirectedEdge[28, 314] -> 
             RGBColor[
              0.18717488313259786`, 0.3140630481183549, 0.9339707047427519], 
             UndirectedEdge[128, 139] -> 
             RGBColor[
              0.3054227451460619, 0.43834904844198347`, 0.9407047455523833], 
             UndirectedEdge[160, 181] -> 
             RGBColor[
              0.19370887514270452`, 0.320930687999998, 0.9343428059215524], 
             UndirectedEdge[42, 296] -> 
             RGBColor[
              0.18148102360409654`, 0.30807844074235485`, 0.933646447865914], 
             UndirectedEdge[121, 289] -> 
             RGBColor[
              0.3589692840265578, 0.4787637861846151, 0.9444710719407625], 
             UndirectedEdge[22, 286] -> 
             RGBColor[
              0.2816381839372477, 0.41219449596583724`, 0.9393925574171622], 
             UndirectedEdge[128, 213] -> 
             RGBColor[
              0.3146576489473405, 0.4465145063990592, 0.9412870836406073], 
             UndirectedEdge[178, 398] -> 
             RGBColor[
              0.18190742429108608`, 0.30852661489974587`, 0.9336707307542348],
              UndirectedEdge[6, 129] -> 
             RGBColor[
              0.8727497313117147, 0.5467966411297123, 0.579484556485264], 
             UndirectedEdge[265, 375] -> 
             RGBColor[
              0.20089610111622702`, 0.32848491819461667`, 0.9347521078081966],
              UndirectedEdge[162, 270] -> 
             RGBColor[
              0.20162095796864934`, 0.3292467887050914, 0.9347933873336124], 
             UndirectedEdge[199, 271] -> 
             RGBColor[
              0.9043692525849842, 0.5721827291840494, 0.5015646144777819], 
             UndirectedEdge[60, 72] -> 
             RGBColor[
              0.5862802580314027, 0.6740171687476564, 0.9612505424717664], 
             UndirectedEdge[230, 258] -> 
             RGBColor[
              0.22938899732612533`, 0.3584327586651811, 0.9363747360958877], 
             UndirectedEdge[38, 135] -> 
             RGBColor[
              0.2970405045044002, 0.42707857493039736`, 0.9403174695829958], 
             UndirectedEdge[42, 67] -> 
             RGBColor[
              0.18164605198289263`, 0.3082518960318731, 0.9336558459879488], 
             UndirectedEdge[220, 352] -> 
             RGBColor[
              0.1830449444132805, 0.30972222067111355`, 0.9337355108423835], 
             UndirectedEdge[4, 226] -> 
             RGBColor[
              0.1963748100004493, 0.3237327545655205, 0.9344946269678038], 
             UndirectedEdge[134, 163] -> 
             RGBColor[
              0.17908461226291875`, 0.3055596604815222, 0.9335099757852068], 
             UndirectedEdge[25, 76] -> 
             RGBColor[
              0.32344841914925154`, 0.45219009338865274`, 0.9419182030554161],
              UndirectedEdge[250, 375] -> 
             RGBColor[
              0.19825790374427554`, 0.32571200548532114`, 0.9346018663707272],
              UndirectedEdge[50, 138] -> 
             RGBColor[
              0.26001645706684573`, 0.3906241607457843, 0.9381189246188555], 
             UndirectedEdge[24, 157] -> 
             RGBColor[
              0.2535215613420126, 0.38379761353881126`, 0.9377490499156633], 
             UndirectedEdge[127, 328] -> 
             RGBColor[
              0.2853602010040631, 0.41443075991720546`, 0.9396658804684725], 
             UndirectedEdge[107, 245] -> 
             RGBColor[
              0.20898762068619692`, 0.33698961829462715`, 0.9352129078773759],
              UndirectedEdge[16, 96] -> 
             RGBColor[
              0.22029148033523374`, 0.34887069149186156`, 0.9358566459618267],
              UndirectedEdge[42, 278] -> 
             RGBColor[
              0.18598976689484537`, 0.3128174158117676, 0.9339032141262342], 
             UndirectedEdge[51, 176] -> 
             RGBColor[
              0.19370665948804128`, 0.32092835920646634`, 0.9343426797432972],
              UndirectedEdge[33, 386] -> 
             RGBColor[
              0.2942581498186507, 0.4235465505748645, 0.9401812655620653], 
             UndirectedEdge[78, 187] -> 
             RGBColor[
              0.21840643996372563`, 0.3468893945429439, 0.9357492957013367], 
             UndirectedEdge[107, 150] -> 
             RGBColor[
              0.23074389884075946`, 0.35985684606277935`, 0.936451895732749], 
             UndirectedEdge[312, 360] -> 
             RGBColor[
              0.6052860238543496, 0.6901250393354524, 0.9622831022684131], 
             UndirectedEdge[78, 208] -> 
             RGBColor[
              0.257441859662032, 0.38791809563442126`, 0.9379723051054267], 
             UndirectedEdge[28, 197] -> 
             RGBColor[
              0.19145378666017485`, 0.3185604470239914, 0.9342143819685769], 
             UndirectedEdge[221, 316] -> 
             RGBColor[
              0.5410265117385101, 0.6349350710702945, 0.9583673358965574], 
             UndirectedEdge[243, 383] -> 
             RGBColor[
              0.29485575436090533`, 0.42265924207033345`, 0.9402707855274055],
              UndirectedEdge[83, 332] -> 
             RGBColor[
              0.8843949242801739, 0.5504136015544692, 0.5662686116652167], 
             UndirectedEdge[98, 354] -> 
             RGBColor[
              0.19467499021807763`, 0.3219461361994489, 0.9343978247458558], 
             UndirectedEdge[46, 215] -> 
             RGBColor[
              0.7558037231431869, 0.8091588799312872, 0.9762951098017001], 
             UndirectedEdge[375, 381] -> 
             RGBColor[
              0.196072227977034, 0.3234147216741027, 0.9344773953692003], 
             UndirectedEdge[286, 304] -> 
             RGBColor[
              0.3017569575169641, 0.43334060260203944`, 0.9405382918094687], 
             UndirectedEdge[225, 235] -> 
             RGBColor[
              0.20086558407238086`, 0.32845284284664206`, 0.9347503699076954],
              UndirectedEdge[96, 225] -> 
             RGBColor[
              0.21005566506834547`, 0.33811220065819025`, 0.9352737314249091],
              UndirectedEdge[20, 389] -> 
             RGBColor[
              0.688874491712781, 0.747632448851442, 0.7193091573204213], 
             UndirectedEdge[259, 393] -> 
             RGBColor[
              0.808698190108407, 0.8510901979921818, 0.9814053247963395], 
             UndirectedEdge[97, 166] -> 
             RGBColor[
              0.27189959411517783`, 0.40311409121798647`, 0.9387956516942321],
              UndirectedEdge[115, 334] -> 
             RGBColor[
              0.9576597296930937, 0.8685855926092536, 0.2913334520501617], 
             UndirectedEdge[251, 260] -> 
             RGBColor[
              0.1869284496057658, 0.31380403085686637`, 0.9339566707179645], 
             UndirectedEdge[119, 344] -> 
             RGBColor[
              0.2156761634002051, 0.3440197007651513, 0.9355938104901265], 
             UndirectedEdge[329, 341] -> 
             RGBColor[
              0.2558412218032698, 0.3862357237585604, 0.9378811511473018], 
             UndirectedEdge[283, 334] -> 
             RGBColor[
              0.9460670651662169, 0.8226245407866379, 0.2820057220570269], 
             UndirectedEdge[1, 5] -> 
             RGBColor[
              0.18431548798727523`, 0.3110576425244974, 0.9338078664193217], 
             UndirectedEdge[364, 391] -> 
             RGBColor[
              0.8707862783740112, 0.44118719063375156`, 0.21128740006323304`],
              UndirectedEdge[48, 295] -> 
             RGBColor[
              0.19691998178395526`, 0.3243057646758728, 0.9345256736943651], 
             UndirectedEdge[105, 199] -> 
             RGBColor[
              0.9870190215241651, 0.9889000460513815, 0.8647919372474027], 
             UndirectedEdge[281, 293] -> 
             RGBColor[
              0.356440478793437, 0.4831525603366694, 0.9439330500141462], 
             UndirectedEdge[216, 358] -> 
             RGBColor[
              0.24670674727990904`, 0.37663481187537284`, 0.9373609563364405],
              UndirectedEdge[100, 206] -> 
             RGBColor[
              0.40830029738828666`, 0.5280709286532568, 0.947237511797173], 
             UndirectedEdge[168, 341] -> 
             RGBColor[
              0.22365393842066325`, 0.35240484813180395`, 0.936048132975481], 
             UndirectedEdge[199, 259] -> 
             RGBColor[
              0.9420801867046171, 0.9545306309034027, 0.913114429015637], 
             UndirectedEdge[19, 24] -> 
             RGBColor[
              0.22984730742841403`, 0.35891447164122536`, 0.936400836178204], 
             UndirectedEdge[136, 299] -> 
             RGBColor[
              0.1855129526762866, 0.3123162538362948, 0.9338760602618706], 
             UndirectedEdge[64, 123] -> 
             RGBColor[
              0.9178715311357676, 0.6596421800395433, 0.31164482201230714`], 
             UndirectedEdge[101, 334] -> 
             RGBColor[
              0.9070926668350056, 0.6466589621982325, 0.24962429328823976`], 
             UndirectedEdge[2, 328] -> 
             RGBColor[
              0.2165885293871429, 0.3449786552647677, 0.935645768383358], 
             UndirectedEdge[235, 349] -> 
             RGBColor[
              0.19583192039754477`, 0.3231621431716789, 0.9344637102080516], 
             UndirectedEdge[45, 290] -> 
             RGBColor[
              0.24862549482263574`, 0.3786515371983993, 0.9374702261704662], 
             UndirectedEdge[225, 327] -> 
             RGBColor[
              0.19712268368204472`, 0.3245188172228074, 0.9345372172675908], 
             UndirectedEdge[24, 386] -> 
             RGBColor[
              0.3010543278758621, 0.4306897646155703, 0.940568297848379], 
             UndirectedEdge[363, 393] -> 
             RGBColor[
              0.5482487832688899, 0.640773127747212, 0.9590042434848745], 
             UndirectedEdge[2, 258] -> 
             RGBColor[
              0.2197390144926751, 0.34829001486297484`, 0.935825183849393], 
             UndirectedEdge[8, 234] -> 
             RGBColor[
              0.2512674523014992, 0.38142840201846384`, 0.9376206817404615], 
             UndirectedEdge[44, 151] -> 
             RGBColor[
              0.21796286839338874`, 0.3464231726984579, 0.9357240349566114], 
             UndirectedEdge[253, 283] -> 
             RGBColor[
              0.878557469851581, 0.4812239884723157, 0.21791952880036536`], 
             UndirectedEdge[257, 360] -> 
             RGBColor[
              0.816087887153252, 0.8565915861588391, 0.9518343139701578], 
             UndirectedEdge[65, 358] -> 
             RGBColor[
              0.3270456066713938, 0.4548122705882284, 0.942165483061772], 
             UndirectedEdge[282, 340] -> 
             RGBColor[
              0.29320777122887487`, 0.42492993475416496`, 0.9400303722049579],
              UndirectedEdge[256, 316] -> 
             RGBColor[
              0.8522226042580414, 0.8830674650503693, 0.8745751101286188], 
             UndirectedEdge[96, 182] -> 
             RGBColor[
              0.2267284521296566, 0.35563635697538404`, 0.9362232219828728], 
             UndirectedEdge[2, 106] -> 
             RGBColor[
              0.19417223523988333`, 0.32141770884085996`, 0.9343691935936069],
              UndirectedEdge[210, 279] -> 
             RGBColor[
              0.2223588131160111, 0.3510435893209275, 0.9359743775053473], 
             UndirectedEdge[279, 371] -> 
             RGBColor[
              0.1895350584309733, 0.3165437420007044, 0.9341051132344278], 
             UndirectedEdge[271, 353] -> 
             RGBColor[
              0.9066312764528914, 0.571373609454521, 0.33726849330509057`], 
             UndirectedEdge[306, 311] -> 
             RGBColor[
              0.21244806666191265`, 0.3406267664200514, 0.9354099751564218], 
             UndirectedEdge[64, 312] -> 
             RGBColor[
              0.7702008939642393, 0.8151650470913949, 0.695936819489472], 
             UndirectedEdge[137, 210] -> 
             RGBColor[
              0.2691626848877073, 0.40023742608984725`, 0.9386397887626219], 
             UndirectedEdge[264, 394] -> 
             RGBColor[
              0.30880202077051594`, 0.4373816733147978, 0.941062660645224], 
             UndirectedEdge[199, 224] -> 
             RGBColor[
              0.7432416506659434, 0.7963714338733744, 0.8949724605475597], 
             UndirectedEdge[61, 301] -> 
             RGBColor[
              0.23356716082772205`, 0.3628242734162258, 0.9366126763262647], 
             UndirectedEdge[48, 103] -> 
             RGBColor[
              0.2013643551866071, 0.328977082911609, 0.9347787741847848], 
             UndirectedEdge[7, 14] -> 
             RGBColor[
              0.29679890469924086`, 0.4265200793940456, 0.9403148622219284], 
             UndirectedEdge[88, 195] -> 
             RGBColor[
              0.42750707901937735`, 0.5447068775411936, 0.948461350938816], 
             UndirectedEdge[211, 341] -> 
             RGBColor[
              0.24091627830701134`, 0.3705486618479197, 0.9370311976946651], 
             UndirectedEdge[84, 185] -> 
             RGBColor[
              0.20341836522778634`, 0.3311359776966468, 0.9348957470179945], 
             UndirectedEdge[368, 387] -> 
             RGBColor[
              0.18468757746568928`, 0.3114487321581461, 0.9338290563646603], 
             UndirectedEdge[134, 171] -> 
             RGBColor[
              0.18358417843459812`, 0.31028898981693004`, 0.9337662194221723],
              UndirectedEdge[41, 295] -> 
             RGBColor[
              0.19034802985855803`, 0.31739822651646155`, 0.9341514107545453],
              UndirectedEdge[77, 388] -> 
             RGBColor[
              0.23386679686193323`, 0.36313920988620363`, 0.9366297401551412],
              UndirectedEdge[142, 273] -> 
             RGBColor[
              0.4991027451822828, 0.6042331187182427, 0.9537103428557971], 
             UndirectedEdge[64, 140] -> 
             RGBColor[
              0.6994659535308891, 0.7564638537977784, 0.690720697735832], 
             UndirectedEdge[150, 157] -> 
             RGBColor[
              0.24263401195527415`, 0.3723541088228476, 0.9371290200847746], 
             UndirectedEdge[210, 264] -> 
             RGBColor[
              0.2528298194491141, 0.3830705489504057, 0.9377096562382032], 
             UndirectedEdge[202, 309] -> 
             RGBColor[
              0.5124790971855998, 0.6108362268976354, 0.9562827357512269], 
             UndirectedEdge[105, 287] -> 
             RGBColor[
              0.9013106453354156, 0.5611585668627788, 0.528730305122088], 
             UndirectedEdge[157, 160] -> 
             RGBColor[
              0.22107841637049833`, 0.349697811159551, 0.9359014608048675], 
             UndirectedEdge[153, 379] -> 
             RGBColor[
              0.19405975897206282`, 0.32129948915197337`, 0.9343627882365483],
              UndirectedEdge[207, 387] -> 
             RGBColor[
              0.18852965084716983`, 0.3154869948836043, 0.9340478567598975], 
             UndirectedEdge[93, 264] -> 
             RGBColor[
              0.3012538452175734, 0.43084382303317337`, 0.9405816975735801], 
             UndirectedEdge[202, 365] -> 
             RGBColor[
              0.31680424057691503`, 0.4485693265510483, 0.9414167025039941], 
             UndirectedEdge[138, 230] -> 
             RGBColor[
              0.2550152839737512, 0.38536761073225334`, 0.9378341152097762], 
             UndirectedEdge[5, 291] -> 
             RGBColor[
              0.19113912643877223`, 0.3182297191806869, 0.9341964625344661], 
             UndirectedEdge[241, 360] -> 
             RGBColor[
              0.4718334584098283, 0.5745274932673213, 0.9531648972863125], 
             UndirectedEdge[299, 300] -> 
             RGBColor[
              0.19227535029574405`, 0.31942396249511773`, 0.934261168802228], 
             UndirectedEdge[9, 266] -> 
             RGBColor[
              0.6722902895010364, 0.7439175508444353, 0.9679712712136599], 
             UndirectedEdge[226, 322] -> 
             RGBColor[
              0.1935079091107788, 0.32071945995846174`, 0.9343313612033369], 
             UndirectedEdge[175, 216] -> 
             RGBColor[
              0.20297653411671235`, 0.3306715851851976, 0.9348705853898494], 
             UndirectedEdge[115, 257] -> 
             RGBColor[
              0.9622640683610495, 0.9182194829930534, 0.6096923191590835], 
             UndirectedEdge[146, 275] -> 
             RGBColor[
              0.1966367657635329, 0.324008086681476, 0.9345095449609826], 
             UndirectedEdge[64, 101] -> 
             RGBColor[
              0.9232794978996539, 0.7012101823729198, 0.31682349709282953`], 
             UndirectedEdge[79, 390] -> 
             RGBColor[
              0.2060170491676479, 0.3338673592835195, 0.9350437382239613], 
             UndirectedEdge[98, 378] -> 
             RGBColor[
              0.21674290293340537`, 0.34514091164973765`, 0.9356545597284425],
              UndirectedEdge[37, 80] -> 
             RGBColor[
              0.24371904320437376`, 0.3734945454606058, 0.9371908110092508], 
             UndirectedEdge[344, 354] -> 
             RGBColor[
              0.1938318559295014, 0.32105994860435383`, 0.9343498094954268], 
             UndirectedEdge[119, 227] -> 
             RGBColor[
              0.25689083303762017`, 0.3873389317150586, 0.9379409249543373], 
             UndirectedEdge[81, 166] -> 
             RGBColor[
              0.2371652059079643, 0.3666060469247946, 0.9368175796707537], 
             UndirectedEdge[192, 221] -> 
             RGBColor[
              0.3140891047086496, 0.4418027488287358, 0.9414053462268441], 
             UndirectedEdge[242, 331] -> 
             RGBColor[
              0.2906837062391053, 0.4199308888343219, 0.9399725324164205], 
             UndirectedEdge[225, 322] -> 
             RGBColor[
              0.2017966288426081, 0.3294314299317988, 0.9348033915300026], 
             UndirectedEdge[165, 170] -> 
             RGBColor[
              0.23052227294686206`, 0.35962390319639986`, 0.9364392744659576],
              UndirectedEdge[41, 250] -> 
             RGBColor[
              0.1942575833696331, 0.32150741513661096`, 0.934374054043335], 
             UndirectedEdge[31, 393] -> 
             RGBColor[
              0.8531150739602782, 0.8852437730014981, 0.9417329113283139], 
             UndirectedEdge[140, 312] -> 
             RGBColor[
              0.4770815978352943, 0.5850799771835042, 0.9523291493384193], 
             UndirectedEdge[56, 100] -> 
             RGBColor[
              0.4530551393941151, 0.565068246426121, 0.9505774993750733], 
             UndirectedEdge[89, 183] -> 
             RGBColor[
              0.21045489979042858`, 0.338531821664043, 0.935296467251717], 
             UndirectedEdge[39, 210] -> 
             RGBColor[
              0.22192743235245416`, 0.35059018078730897`, 0.9359498110090333],
              UndirectedEdge[34, 321] -> 
             RGBColor[
              0.18374554341254123`, 0.3104585946398788, 0.9337754089189481], 
             UndirectedEdge[148, 301] -> 
             RGBColor[
              0.25321055434935075`, 0.3834707254705414, 0.9377313385275249], 
             UndirectedEdge[136, 155] -> 
             RGBColor[
              0.18426793717549678`, 0.3110076636064226, 0.933805158470936], 
             UndirectedEdge[51, 205] -> 
             RGBColor[
              0.19318129293550862`, 0.32037616564959115`, 0.9343127608953405],
              UndirectedEdge[11, 123] -> 
             RGBColor[
              0.8581753215010539, 0.6172298567057516, 0.5883641909402252], 
             UndirectedEdge[223, 400] -> 
             RGBColor[
              0.8406657720719041, 0.3123044383826159, 0.18652492711661786`], 
             UndirectedEdge[6, 201] -> 
             RGBColor[
              0.7959386825090102, 0.8413708229845736, 0.9800676455168078], 
             UndirectedEdge[201, 273] -> 
             RGBColor[
              0.5948799673171399, 0.6816316125645953, 0.9614948857902279], 
             UndirectedEdge[54, 196] -> 
             RGBColor[
              0.8961892019683437, 0.8555483275728113, 0.6311082747514651], 
             UndirectedEdge[84, 288] -> 
             RGBColor[
              0.21401051896422651`, 0.342269002854981, 0.9354989545035975], 
             UndirectedEdge[177, 248] -> 
             RGBColor[
              0.18215464872777276`, 0.30878646345763827`, 0.9336848098201683],
              UndirectedEdge[76, 117] -> 
             RGBColor[
              0.4207333030341396, 0.5335965741048728, 0.9489064510842957], 
             UndirectedEdge[342, 348] -> 
             RGBColor[
              0.1937491041812462, 0.3209729712701737, 0.9343450969057838], 
             UndirectedEdge[332, 389] -> 
             RGBColor[
              0.905464097691441, 0.5627808456183245, 0.32878632140514163`], 
             UndirectedEdge[68, 236] -> 
             RGBColor[
              0.6656201528579981, 0.7366867382683524, 0.9686930531678246], 
             UndirectedEdge[84, 318] -> 
             RGBColor[
              0.2138717930117836, 0.3421231930832301, 0.9354910542658326], 
             UndirectedEdge[15, 372] -> 
             RGBColor[
              0.1810383624053819, 0.30761317575616476`, 0.9336212389655058], 
             UndirectedEdge[88, 189] -> 
             RGBColor[
              0.331784795723977, 0.4548098720727408, 0.9426178463888004], 
             UndirectedEdge[364, 380] -> 
             RGBColor[
              0.8208602613542741, 0.753663537851497, 0.6141649050014586], 
             UndirectedEdge[103, 295] -> 
             RGBColor[
              0.1903453971129866, 0.3173954593339403, 0.9341512608235798], 
             UndirectedEdge[20, 257] -> 
             RGBColor[
              0.6770229856308323, 0.7421397259892473, 0.9411883411446311], 
             UndirectedEdge[12, 24] -> 
             RGBColor[
              0.25148362362516946`, 0.3816556117856949, 0.9376329923775478], 
             UndirectedEdge[152, 157] -> 
             RGBColor[
              0.22385261786682037`, 0.3526136728267195, 0.9360594474760198], 
             UndirectedEdge[26, 70] -> 
             RGBColor[
              0.1896105861046007, 0.3166231263744179, 0.9341094144237078], 
             UndirectedEdge[33, 74] -> 
             RGBColor[
              0.24756162893783695`, 0.3775333467004828, 0.9374096405821755], 
             UndirectedEdge[124, 238] -> 
             RGBColor[
              0.21375043106969976`, 0.3419956339873084, 0.9354841428827698], 
             UndirectedEdge[148, 339] -> 
             RGBColor[
              0.3192552716311131, 0.4461190038278132, 0.9417403303152683], 
             UndirectedEdge[175, 229] -> 
             RGBColor[
              0.1940292110138258, 0.32126738131101384`, 0.9343610485755184], 
             UndirectedEdge[105, 337] -> 
             RGBColor[
              0.9711407562018461, 0.97781294412538, 0.9254748728105828], 
             UndirectedEdge[158, 306] -> 
             RGBColor[
              0.20672015111524922`, 0.33460636400968674`, 0.935083778839731], 
             UndirectedEdge[136, 268] -> 
             RGBColor[
              0.18514817398425504`, 0.3119328483026647, 0.9338552866550012], 
             UndirectedEdge[133, 278] -> 
             RGBColor[
              0.18574944160901402`, 0.31256481869885566`, 0.9338895279567354],
              UndirectedEdge[197, 254] -> 
             RGBColor[
              0.18919463052287389`, 0.31618593068491585`, 0.9340857263686796],
              UndirectedEdge[296, 398] -> 
             RGBColor[
              0.17994179284220208`, 0.3064606116187368, 0.933558790951112], 
             UndirectedEdge[10, 271] -> 
             RGBColor[
              0.8314849257202783, 0.24301251263429177`, 0.17778330646786333`],
              UndirectedEdge[221, 399] -> 
             RGBColor[
              0.36464378874039466`, 0.49025785510237774`, 0.9444557576700642],
              UndirectedEdge[187, 388] -> 
             RGBColor[
              0.2435643246839634, 0.37333192648593383`, 0.937182000018399], 
             UndirectedEdge[143, 186] -> 
             RGBColor[
              0.20274228315425485`, 0.3304253725712859, 0.9348572451440806], 
             UndirectedEdge[372, 387] -> 
             RGBColor[
              0.18274442511282618`, 0.30940635583231196`, 0.9337183967128011],
              UndirectedEdge[147, 255] -> 
             RGBColor[
              0.3107019378391358, 0.4378471817176799, 0.9412269310789902], 
             UndirectedEdge[27, 86] -> 
             RGBColor[
              0.23656599040606416`, 0.3659762334398404, 0.9367834552343804], 
             UndirectedEdge[19, 157] -> 
             RGBColor[
              0.2231871063802957, 0.35191417805851677`, 0.9360215475813982], 
             UndirectedEdge[192, 208] -> 
             RGBColor[
              0.27634222217301546`, 0.40778357498566165`, 0.9390486527898467],
              UndirectedEdge[88, 89] -> 
             RGBColor[
              0.33131087657095276`, 0.4543117529947025, 0.9425908573941362], 
             UndirectedEdge[54, 332] -> 
             RGBColor[
              0.8830293594773344, 0.4852062873571179, 0.22095265658473165`], 
             UndirectedEdge[282, 301] -> 
             RGBColor[
              0.2824458229860667, 0.41361844480404447`, 0.9394174951734057], 
             UndirectedEdge[264, 328] -> 
             RGBColor[
              0.24566528906336602`, 0.3755401732575213, 0.9373016468317077], 
             UndirectedEdge[124, 156] -> 
             RGBColor[
              0.21424517968646528`, 0.3425156461524031, 0.9355123180845796], 
             UndirectedEdge[64, 120] -> 
             RGBColor[
              0.7025664799902631, 0.759149373979897, 0.6909182605401354], 
             UndirectedEdge[55, 236] -> 
             RGBColor[
              0.6566866391587384, 0.7296947127190476, 0.9678061194855357], 
             UndirectedEdge[11, 196] -> 
             RGBColor[
              0.8586587168624804, 0.8901351694289188, 0.9863808290196707], 
             UndirectedEdge[223, 319] -> 
             RGBColor[
              0.845830354553812, 0.35200168247303465`, 0.19147053713385456`], 
             UndirectedEdge[61, 70] -> 
             RGBColor[
              0.20711529305388426`, 0.33502168324063814`, 0.9351062815885762],
              UndirectedEdge[307, 343] -> 
             RGBColor[
              0.1898749181249935, 0.3169009560874688, 0.9341244677412249], 
             UndirectedEdge[13, 87] -> 
             RGBColor[
              0.2001057560025477, 0.3276542153693653, 0.9347070988231834], 
             UndirectedEdge[119, 128] -> 
             RGBColor[
              0.2718458799395796, 0.4030576342137573, 0.9387925927513947], 
             UndirectedEdge[92, 130] -> 
             RGBColor[
              0.2100169217474722, 0.33807147897148404`, 0.935271525050101], 
             UndirectedEdge[263, 359] -> 
             RGBColor[
              0.31376085658735253`, 0.4455463754257799, 0.941236947982536], 
             UndirectedEdge[22, 304] -> 
             RGBColor[
              0.2621517349847551, 0.3928684732219464, 0.9382405255374198], 
             UndirectedEdge[139, 306] -> 
             RGBColor[
              0.2646217542710957, 0.39546462010015837`, 0.9383811894817108], 
             UndirectedEdge[1, 73] -> 
             RGBColor[
              0.19016251964762415`, 0.3172032435227433, 0.9341408462224705], 
             UndirectedEdge[7, 13] -> 
             RGBColor[
              0.23415570368153021`, 0.3634428692713504, 0.9366461929711178], 
             UndirectedEdge[170, 335] -> 
             RGBColor[
              0.21688414248716403`, 0.34528936337584293`, 0.9356626031120838],
              UndirectedEdge[276, 361] -> 
             RGBColor[
              0.3943096577609078, 0.5159529397980152, 0.9463460406115533], 
             UndirectedEdge[46, 345] -> 
             RGBColor[
              0.8168101022247779, 0.8568829940339906, 0.982358282576511], 
             UndirectedEdge[36, 301] -> 
             RGBColor[
              0.2477609938146631, 0.37774289182649035`, 0.9374209941169768], 
             UndirectedEdge[50, 328] -> 
             RGBColor[
              0.23123968531368772`, 0.36037794908050486`, 0.9364801300389318],
              UndirectedEdge[55, 83] -> 
             RGBColor[
              0.8773611303882973, 0.9047851000408222, 0.9744632955960668], 
             UndirectedEdge[143, 306] -> 
             RGBColor[
              0.21060170684620283`, 0.33868612518776664`, 0.9353048276963617],
              UndirectedEdge[32, 400] -> 
             RGBColor[
              0.8218170423470171, 0.16870092453389818`, 0.1685253304313158], 
             UndirectedEdge[20, 195] -> 
             RGBColor[
              0.40462199010322386`, 0.5248849637600351, 0.9470031333095683], 
             UndirectedEdge[203, 266] -> 
             RGBColor[
              0.4841156347335931, 0.5879317505125805, 0.9537717798510146], 
             UndirectedEdge[255, 359] -> 
             RGBColor[
              0.3499392226187198, 0.4775214990007658, 0.9435187957195283], 
             UndirectedEdge[128, 215] -> 
             RGBColor[
              0.5049864538136, 0.6035289290681363, 0.9559781758101122], 
             UndirectedEdge[230, 328] -> 
             RGBColor[
              0.2262385122205931, 0.35512139906697393`, 0.9361953206298528], 
             UndirectedEdge[44, 146] -> 
             RGBColor[
              0.21372136571514777`, 0.3419650844568244, 0.9354824876538264], 
             UndirectedEdge[56, 206] -> 
             RGBColor[
              0.4736432444349138, 0.5829006282242136, 0.9518893552229266], 
             UndirectedEdge[55, 196] -> 
             RGBColor[
              0.8239309669516679, 0.8625755200904117, 0.9830336180607375], 
             UndirectedEdge[93, 188] -> 
             RGBColor[
              0.3091689920495968, 0.43916314420292457`, 0.9410324534762535], 
             UndirectedEdge[52, 271] -> 
             RGBColor[
              0.9044987065001195, 0.5722362617047718, 0.4994192280879955], 
             UndirectedEdge[193, 253] -> 
             RGBColor[
              0.8315602657829888, 0.5341252723143658, 0.5780805506738103], 
             UndirectedEdge[120, 193] -> 
             RGBColor[
              0.6252379224927019, 0.7026774950776031, 0.9659558403883122], 
             UndirectedEdge[28, 217] -> 
             RGBColor[
              0.19992147826691017`, 0.32746052778532697`, 0.9346966044787532],
              UndirectedEdge[124, 245] -> 
             RGBColor[
              0.21075638483913717`, 0.33884870156549185`, 0.9353136363792337],
              UndirectedEdge[36, 282] -> 
             RGBColor[
              0.28033871258182136`, 0.4114037381706667, 0.9392974983530744], 
             UndirectedEdge[276, 339] -> 
             RGBColor[
              0.38050139833268903`, 0.5039929195045905, 0.9454661905309516], 
             UndirectedEdge[377, 388] -> 
             RGBColor[
              0.26273780008050557`, 0.39348446479625343`, 0.9382739010776171],
              UndirectedEdge[129, 131] -> 
             RGBColor[
              0.8167235345760251, 0.5021703426652091, 0.5741281307411844], 
             UndirectedEdge[69, 142] -> 
             RGBColor[
              0.5234887787089056, 0.6240307993134462, 0.955630100743997], 
             UndirectedEdge[11, 118] -> 
             RGBColor[
              0.6153201099210919, 0.6928744863891039, 0.9658821576068201], 
             UndirectedEdge[53, 293] -> 
             RGBColor[
              0.35836727987096656`, 0.4848214585861875, 0.944055824075003], 
             UndirectedEdge[2, 137] -> 
             RGBColor[
              0.24723503321608348`, 0.3771900738895551, 0.9373910414389766], 
             UndirectedEdge[102, 213] -> 
             RGBColor[
              0.33722405994131943`, 0.4665082641722599, 0.9427085967973012], 
             UndirectedEdge[269, 362] -> 
             RGBColor[
              0.5723371220999356, 0.658694027276514, 0.9617848366135348], 
             UndirectedEdge[147, 242] -> 
             RGBColor[
              0.29380682218946674`, 0.42321348171513995`, 0.9401503892495575],
              UndirectedEdge[58, 220] -> 
             RGBColor[
              0.186453938859043, 0.31330528997634166`, 0.9339296480329143], 
             UndirectedEdge[177, 285] -> 
             RGBColor[
              0.18283630546897034`, 0.3095029279121705, 0.9337236291631588], 
             UndirectedEdge[213, 215] -> 
             RGBColor[
              0.5157421665105038, 0.6132928535993672, 0.9566471217151071], 
             UndirectedEdge[61, 382] -> 
             RGBColor[
              0.2696810924925139, 0.39954800963710424`, 0.9387145049212492], 
             UndirectedEdge[83, 123] -> 
             RGBColor[
              0.8970713714097568, 0.6478503290469954, 0.5784075917525047], 
             UndirectedEdge[207, 368] -> 
             RGBColor[
              0.18767517326657374`, 0.3145888847693901, 0.9339991955257688], 
             UndirectedEdge[117, 377] -> 
             RGBColor[
              0.40661285819624315`, 0.5187550912923315, 0.9481023126401036], 
             UndirectedEdge[207, 392] -> 
             RGBColor[
              0.1972896880999786, 0.3246943494547476, 0.9345467279221311], 
             UndirectedEdge[43, 325] -> 
             RGBColor[
              0.21648460691960775`, 0.3448694261623232, 0.9356398501525713], 
             UndirectedEdge[83, 196] -> 
             RGBColor[
              0.8975547667711833, 0.9207556417701627, 0.9764242298319501], 
             UndirectedEdge[81, 130] -> 
             RGBColor[
              0.2224096961469096, 0.35109707061257234`, 0.9359772752186821], 
             UndirectedEdge[204, 229] -> 
             RGBColor[
              0.18893129430891603`, 0.3159091476275659, 0.9340707297608657], 
             UndirectedEdge[44, 267] -> 
             RGBColor[
              0.21293872940986303`, 0.3411424840779623, 0.935437917674047], 
             UndirectedEdge[38, 130] -> 
             RGBColor[
              0.23719458554175432`, 0.36663692678268434`, 0.9368192527974348],
              UndirectedEdge[226, 318] -> 
             RGBColor[
              0.20268055409019498`, 0.33036049141111024`, 0.9348537297652024],
              UndirectedEdge[202, 362] -> 
             RGBColor[
              0.5594312028417849, 0.6475155686854668, 0.9609624828506617], 
             UndirectedEdge[59, 230] -> 
             RGBColor[
              0.21869887314196257`, 0.34719676035460534`, 0.9357659493382211],
              UndirectedEdge[131, 394] -> 
             RGBColor[
              0.585868010689025, 0.6694437636125451, 0.9630575794667262], 
             UndirectedEdge[93, 142] -> 
             RGBColor[
              0.4083441914838143, 0.5275430486662767, 0.9473966682274677], 
             UndirectedEdge[301, 340] -> 
             RGBColor[
              0.26063005246171667`, 0.3912690884099886, 0.9381538679688604], 
             UndirectedEdge[16, 76] -> 
             RGBColor[
              0.2559443426940643, 0.3863441103530275, 0.937887023729479], 
             UndirectedEdge[25, 239] -> 
             RGBColor[
              0.43554957397249955`, 0.5502115619480115, 0.9493775788120367], 
             UndirectedEdge[46, 60] -> 
             RGBColor[
              0.7562801355297237, 0.809531056908518, 0.9763425941360632], 
             UndirectedEdge[57, 297] -> 
             RGBColor[
              0.3224295006293375, 0.45256728530617585`, 0.9418071536579791], 
             UndirectedEdge[221, 351] -> 
             RGBColor[
              0.33973329445254913`, 0.4686816369880935, 0.9428684830015278], 
             UndirectedEdge[365, 377] -> 
             RGBColor[
              0.2803555468892034, 0.41200183372185906`, 0.9392772056952516], 
             UndirectedEdge[334, 366] -> 
             RGBColor[
              0.9767558229939741, 0.9327621554008622, 0.40603042724612426`], 
             UndirectedEdge[209, 290] -> 
             RGBColor[
              0.2612876379800373, 0.3919602524830736, 0.938191316491318], 
             UndirectedEdge[174, 313] -> 
             RGBColor[
              0.35122662219084355`, 0.47640574207717373`, 0.9436825095790529],
              UndirectedEdge[56, 358] -> 
             RGBColor[
              0.3979975915234898, 0.5145002367878451, 0.9471747294166126], 
             UndirectedEdge[304, 338] -> 
             RGBColor[
              0.24620331291395298`, 0.37610567043717064`, 0.9373322864940637],
              UndirectedEdge[130, 306] -> 
             RGBColor[
              0.21898168415614172`, 0.3474940126617616, 0.9357820550070972], 
             UndirectedEdge[11, 206] -> 
             RGBColor[
              0.6510406164097462, 0.7238137937447175, 0.9681582366938735], 
             UndirectedEdge[120, 140] -> 
             RGBColor[
              0.409447183861318, 0.5290643040720063, 0.9473105903890827], 
             UndirectedEdge[193, 356] -> 
             RGBColor[
              0.8916558476180196, 0.9161964476590825, 0.9808695463369558], 
             UndirectedEdge[166, 246] -> 
             RGBColor[
              0.23093801406837325`, 0.3600608734746177, 0.9364629503077938], 
             UndirectedEdge[76, 182] -> 
             RGBColor[
              0.2623813144884871, 0.39310977583655005`, 0.9382535997505249], 
             UndirectedEdge[6, 364] -> 
             RGBColor[
              0.9237508221541206, 0.8349006337052781, 0.6241923325830713], 
             UndirectedEdge[288, 318] -> 
             RGBColor[
              0.21359522081764215`, 0.3418324981714975, 0.9354753038885282], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.285788273116509, 0.4171315718147177, 0.9396078427636225], 
             UndirectedEdge[128, 151] -> 
             RGBColor[
              0.2557571228947407, 0.38614733047351757`, 0.9378763618388744], 
             UndirectedEdge[30, 379] -> 
             RGBColor[
              0.19158357625518677`, 0.31869686411748455`, 0.9342217732940062],
              UndirectedEdge[70, 90] -> 
             RGBColor[
              0.2062666965089075, 0.33412975446773896`, 0.9350579552707259], 
             UndirectedEdge[137, 394] -> 
             RGBColor[
              0.32513488620910913`, 0.45454855045423936`, 0.9419927931696428],
              UndirectedEdge[25, 269] -> 
             RGBColor[
              0.35868258725721747`, 0.48509456199634804`, 0.9440759151828396],
              UndirectedEdge[38, 227] -> 
             RGBColor[
              0.2663587998591236, 0.39729036514822713`, 0.9384801116582203], 
             UndirectedEdge[128, 135] -> 
             RGBColor[
              0.31962859399375376`, 0.45082008915129973`, 0.9416038278633306],
              UndirectedEdge[129, 303] -> 
             RGBColor[
              0.8566331099862248, 0.3804373908932912, 0.19967730788162147`], 
             UndirectedEdge[132, 299] -> 
             RGBColor[
              0.19063186344337624`, 0.3176965536101942, 0.9341675746573066], 
             UndirectedEdge[352, 396] -> 
             RGBColor[
              0.18539177638104404`, 0.312188889866974, 0.9338691594511209], 
             UndirectedEdge[155, 268] -> 
             RGBColor[
              0.18677990471826675`, 0.31364790076181503`, 0.9339482113063738],
              UndirectedEdge[8, 16] -> 
             RGBColor[
              0.24227617377409713`, 0.3719779982061794, 0.9371086417297306], 
             UndirectedEdge[213, 378] -> 
             RGBColor[
              0.2828251978811075, 0.4130565820344796, 0.9394742726442766], 
             UndirectedEdge[164, 230] -> 
             RGBColor[
              0.21805906979477002`, 0.3465242864708308, 0.9357295134841028], 
             UndirectedEdge[218, 339] -> 
             RGBColor[
              0.47111694262023773`, 0.5795753796238241, 0.9520425636736524], 
             UndirectedEdge[101, 366] -> 
             RGBColor[
              0.9236369022984421, 0.7019746342428002, 0.3557247602566589], 
             UndirectedEdge[169, 361] -> 
             RGBColor[
              0.4334163894448813, 0.5497182254001022, 0.948867451343103], 
             UndirectedEdge[65, 341] -> 
             RGBColor[
              0.31291881126268356`, 0.4399641129231123, 0.9413609829619669], 
             UndirectedEdge[46, 353] -> 
             RGBColor[
              0.8993981375114619, 0.9180011012561393, 0.7445005138120175], 
             UndirectedEdge[279, 300] -> 
             RGBColor[
              0.1975989582339537, 0.32501941197441453`, 0.9345643403987369], 
             UndirectedEdge[203, 358] -> 
             RGBColor[
              0.29380332632948314`, 0.42601947816165614`, 0.9400473143533797],
              UndirectedEdge[81, 243] -> 
             RGBColor[
              0.2302749655066254, 0.3593639673965138, 0.9364251906730947], 
             UndirectedEdge[176, 320] -> 
             RGBColor[
              0.18495626411433608`, 0.3117311388615913, 0.9338443576718145], 
             UndirectedEdge[112, 248] -> 
             RGBColor[
              0.18167669359362687`, 0.3082841023075451, 0.9336575909823499], 
             UndirectedEdge[58, 179] -> 
             RGBColor[
              0.21000836012355356`, 0.3380624801619072, 0.9352710374782847], 
             UndirectedEdge[23, 213] -> 
             RGBColor[
              0.2686665233533321, 0.39817491739397315`, 0.9386679570758016], 
             UndirectedEdge[243, 326] -> 
             RGBColor[
              0.23648276332684243`, 0.36588875650267677`, 0.9367787155753422],
              UndirectedEdge[269, 377] -> 
             RGBColor[
              0.30404872534557215`, 0.4327759904647185, 0.9407776755353809], 
             UndirectedEdge[222, 363] -> 
             RGBColor[
              0.6628066494410058, 0.7309294373629389, 0.9563828644799877], 
             UndirectedEdge[30, 341] -> 
             RGBColor[
              0.22502124710185, 0.35384197624810876`, 0.9361259991821227], 
             UndirectedEdge[23, 348] -> 
             RGBColor[
              0.20651189165865158`, 0.3343874701163905, 0.93507191877177], 
             UndirectedEdge[16, 25] -> 
             RGBColor[
              0.2964577597678131, 0.4238211990721158, 0.9403811249327455], 
             UndirectedEdge[25, 62] -> 
             RGBColor[
              0.6778828449272916, 0.740272939600058, 0.8649535953688089], 
             UndirectedEdge[16, 388] -> 
             RGBColor[
              0.24986758553696356`, 0.3799570532922577, 0.9375409613991386], 
             UndirectedEdge[207, 372] -> 
             RGBColor[
              0.18573202091371066`, 0.31254650844355597`, 0.9338885358739095],
              UndirectedEdge[249, 279] -> 
             RGBColor[
              0.19132944320701362`, 0.3184297541708887, 0.934207300792869], 
             UndirectedEdge[151, 267] -> 
             RGBColor[
              0.20258817055551906`, 0.33026339045871145`, 0.9348484686595718],
              UndirectedEdge[185, 252] -> 
             RGBColor[
              0.1992454681560438, 0.3267499982972898, 0.9346581067030068], 
             UndirectedEdge[218, 382] -> 
             RGBColor[
              0.44118615700326724`, 0.5536508374874307, 0.9501354004808935], 
             UndirectedEdge[284, 334] -> 
             RGBColor[
              0.8500382234662116, 0.8370769008965131, 0.6373182165494112], 
             UndirectedEdge[145, 235] -> 
             RGBColor[
              0.22156110310920424`, 0.35020514552603776`, 0.9359289491005658],
              UndirectedEdge[78, 302] -> 
             RGBColor[
              0.2075835767828424, 0.33551387913067643`, 0.9351329496541767], 
             UndirectedEdge[235, 335] -> 
             RGBColor[
              0.19575670920923333`, 0.32308309144409886`, 0.9344594270421422],
              UndirectedEdge[21, 109] -> 
             RGBColor[
              0.1897091064701492, 0.31672667752516137`, 0.9341150250127779], 
             UndirectedEdge[283, 389] -> 
             RGBColor[
              0.9625229099161214, 0.8777511540326326, 0.378485405341739], 
             UndirectedEdge[91, 395] -> 
             RGBColor[
              0.5156283955691132, 0.6172519539462964, 0.9551211142984581], 
             UndirectedEdge[240, 374] -> 
             RGBColor[
              0.18148468566837106`, 0.3080822898040957, 0.933646656415057], 
             UndirectedEdge[301, 339] -> 
             RGBColor[
              0.3159128215006708, 0.4426058768171399, 0.9415499827250514], 
             UndirectedEdge[303, 353] -> 
             RGBColor[
              0.9435949291122223, 0.7996173553563373, 0.3704770005960165], 
             UndirectedEdge[92, 143] -> 
             RGBColor[
              0.20163694443753327`, 0.3292635914974891, 0.9347942977393655], 
             UndirectedEdge[53, 394] -> 
             RGBColor[
              0.38011496144870427`, 0.5036582072985654, 0.9454415671144167], 
             UndirectedEdge[139, 345] -> 
             RGBColor[
              0.5675136417908162, 0.652851509744995, 0.962127956401694], 
             UndirectedEdge[224, 393] -> 
             RGBColor[
              0.6098596540697332, 0.6929310009621534, 0.9632633563282622], 
             UndirectedEdge[175, 204] -> 
             RGBColor[
              0.1850387535749342, 0.31181784051481387`, 0.9338490553245634], 
             UndirectedEdge[131, 293] -> 
             RGBColor[
              0.5641203291112874, 0.6506070149001673, 0.9616718364273125], 
             UndirectedEdge[166, 383] -> 
             RGBColor[
              0.3017459947622442, 0.42990132159861427`, 0.9406631745250644], 
             UndirectedEdge[92, 348] -> 
             RGBColor[
              0.2027372639690243, 0.3304200970893739, 0.9348569593089071], 
             UndirectedEdge[212, 289] -> 
             RGBColor[
              0.5259969557430033, 0.6260670504218144, 0.9558275536278764], 
             UndirectedEdge[161, 214] -> 
             RGBColor[
              0.8792338615689066, 0.5445109956801907, 0.22094211265521246`], 
             UndirectedEdge[124, 386] -> 
             RGBColor[
              0.28427277786616933`, 0.41305129154365816`, 0.9396126134014054],
              UndirectedEdge[227, 350] -> 
             RGBColor[
              0.3112685553301875, 0.44081365131394507`, 0.9411723881594869], 
             UndirectedEdge[258, 279] -> 
             RGBColor[
              0.2183447678357952, 0.34682457322625027`, 0.9357457835648868], 
             UndirectedEdge[63, 103] -> 
             RGBColor[
              0.19205709543901506`, 0.31919456280253833`, 0.9342487395110164],
              UndirectedEdge[291, 336] -> 
             RGBColor[
              0.21513079622652476`, 0.34344648528733734`, 0.9355627526363838],
              UndirectedEdge[292, 400] -> 
             RGBColor[
              0.8208035514548493, 0.16091078942215484`, 0.1675548104084016], 
             UndirectedEdge[149, 300] -> 
             RGBColor[
              0.20324360298345337`, 0.33095229149728655`, 0.9348857945667173],
              UndirectedEdge[356, 364] -> 
             RGBColor[
              0.9333609520587287, 0.8423137522801358, 0.6164503768813724], 
             UndirectedEdge[100, 167] -> 
             RGBColor[
              0.3117593370391954, 0.4377082442608893, 0.941332929144121], 
             UndirectedEdge[334, 391] -> 
             RGBColor[
              0.890222900366215, 0.5169905447403047, 0.23346978586604977`], 
             UndirectedEdge[309, 323] -> 
             RGBColor[
              0.5589942800594222, 0.6511253403818711, 0.9592466420721857], 
             UndirectedEdge[8, 202] -> 
             RGBColor[
              0.2915950820053508, 0.42207290253936436`, 0.9399810782169516], 
             UndirectedEdge[127, 380] -> 
             RGBColor[
              0.529875465248763, 0.6249265943110206, 0.9578049379836415], 
             UndirectedEdge[130, 151] -> 
             RGBColor[
              0.211637861675412, 0.3397751896092761, 0.9353638351810314], 
             UndirectedEdge[335, 355] -> 
             RGBColor[
              0.20320238953001776`, 0.3309089735446419, 0.934883447521514], 
             UndirectedEdge[117, 395] -> 
             RGBColor[
              0.49860624010091514`, 0.6034326012978481, 0.9537810678657916], 
             UndirectedEdge[256, 310] -> 
             RGBColor[
              0.9094103197175858, 0.5979549815728277, 0.4751163468578484], 
             UndirectedEdge[362, 365] -> 
             RGBColor[
              0.5486439436435668, 0.6379198705336546, 0.9602843667734056], 
             UndirectedEdge[163, 342] -> 
             RGBColor[
              0.18272416673891645`, 0.30938506299687774`, 0.9337172430283764],
              UndirectedEdge[125, 288] -> 
             RGBColor[
              0.2031660717843796, 0.3308708012912981, 0.9348813792796271], 
             UndirectedEdge[161, 253] -> 
             RGBColor[
              0.8523693689594214, 0.3702876353014115, 0.19648021346556857`], 
             UndirectedEdge[12, 211] -> 
             RGBColor[
              0.23763726784270695`, 0.3671022139486645, 0.9368444628995842], 
             UndirectedEdge[107, 152] -> 
             RGBColor[
              0.2119625047523057, 0.3401164100666513, 0.9353823231239942], 
             UndirectedEdge[183, 291] -> 
             RGBColor[
              0.1920722404266596, 0.31921048114480044`, 0.9342496019956579], 
             UndirectedEdge[149, 299] -> 
             RGBColor[
              0.19935795159879743`, 0.32686822552748607`, 0.9346645124686672],
              UndirectedEdge[57, 284] -> 
             RGBColor[
              0.544081909913294, 0.6364040523835073, 0.9590603762420349], 
             UndirectedEdge[230, 279] -> 
             RGBColor[
              0.2100811442778375, 0.33813898092284156`, 0.9352751824281966], 
             UndirectedEdge[186, 374] -> 
             RGBColor[
              0.19510883243877694`, 0.3224021318805894, 0.9344225314185126], 
             UndirectedEdge[30, 175] -> 
             RGBColor[
              0.19541782934736363`, 0.32272690722304953`, 0.9344401283353366],
              UndirectedEdge[261, 327] -> 
             RGBColor[
              0.1874834373807122, 0.31438735819659225`, 0.9339882764507168], 
             UndirectedEdge[271, 333] -> 
             RGBColor[
              0.8868896427416582, 0.5599013471362418, 0.5649582086174862], 
             UndirectedEdge[199, 247] -> 
             RGBColor[
              0.9030372486329088, 0.5619443631205439, 0.500289085988991], 
             UndirectedEdge[99, 223] -> 
             RGBColor[
              0.8806912086429535, 0.689221405037725, 0.5973847957056915], 
             UndirectedEdge[200, 367] -> 
             RGBColor[
              0.19007010120853718`, 0.31710610588359545`, 0.9341355831290852],
              UndirectedEdge[111, 400] -> 
             RGBColor[
              0.8243636514645629, 0.1882752781425862, 0.17096396619826132`], 
             UndirectedEdge[277, 390] -> 
             RGBColor[
              0.19904871949657826`, 0.326543202981606, 0.9346469021579138], 
             UndirectedEdge[79, 298] -> 
             RGBColor[
              0.20225845525357178`, 0.3299168387712073, 0.934829691860896], 
             UndirectedEdge[96, 388] -> 
             RGBColor[
              0.24120538255957147`, 0.37085252874762864`, 0.937047661754157], 
             UndirectedEdge[153, 175] -> 
             RGBColor[
              0.19789401206423968`, 0.32532953225753836`, 0.9345811432778787],
              UndirectedEdge[127, 331] -> 
             RGBColor[
              0.29016880316487315`, 0.419484905671203, 0.9399397232478413], 
             UndirectedEdge[6, 93] -> 
             RGBColor[
              0.6343460318717724, 0.7075322117954237, 0.9679330421391619], 
             UndirectedEdge[76, 239] -> 
             RGBColor[
              0.3950361568987507, 0.5127344732289232, 0.94688347760877], 
             UndirectedEdge[333, 337] -> 
             RGBColor[
              0.9553778772118539, 0.9662414744033965, 0.9604177939535141], 
             UndirectedEdge[253, 332] -> 
             RGBColor[
              0.8214986576269006, 0.1662536800580077, 0.16822044486376803`], 
             UndirectedEdge[31, 400] -> 
             RGBColor[
              0.9031868035222537, 0.5793756445438494, 0.5396768154569369], 
             UndirectedEdge[39, 149] -> 
             RGBColor[
              0.2042501787734501, 0.33201026647316434`, 0.9349431175688622], 
             UndirectedEdge[49, 335] -> 
             RGBColor[
              0.1909811618412971, 0.3180636883732066, 0.9341874666843275], 
             UndirectedEdge[57, 236] -> 
             RGBColor[
              0.4289674540866987, 0.5444426167036535, 0.9489769174045849], 
             UndirectedEdge[76, 323] -> 
             RGBColor[
              0.3517784337991403, 0.4767281281704481, 0.9437233665376588], 
             UndirectedEdge[2, 210] -> 
             RGBColor[
              0.223753059772891, 0.352509030957652, 0.9360537777898534], 
             UndirectedEdge[25, 395] -> 
             RGBColor[
              0.4013213562160271, 0.522026120581628, 0.946792819836912], 
             UndirectedEdge[62, 91] -> 
             RGBColor[
              0.7921898842803778, 0.8354987729647263, 0.873281889830355], 
             UndirectedEdge[148, 313] -> 
             RGBColor[
              0.27058528986872044`, 0.4017326741232574, 0.9387208040117352], 
             UndirectedEdge[98, 163] -> 
             RGBColor[
              0.18615149755953203`, 0.3129874049946697, 0.933912424448329], 
             UndirectedEdge[271, 292] -> 
             RGBColor[
              0.8197473186965691, 0.15279212159786854`, 0.16654336072622833`],
              UndirectedEdge[148, 228] -> 
             RGBColor[
              0.2402804897849437, 0.36988040779990605`, 0.9369949904788982], 
             UndirectedEdge[105, 333] -> 
             RGBColor[
              0.969539411680839, 0.9766186640035739, 0.9281855313871071], 
             UndirectedEdge[9, 65] -> 
             RGBColor[
              0.531426491162083, 0.6277150215031269, 0.9572921727453987], 
             UndirectedEdge[129, 337] -> 
             RGBColor[
              0.8881576917970897, 0.5585337722586294, 0.5619283859267235], 
             UndirectedEdge[62, 323] -> 
             RGBColor[
              0.7062128595771804, 0.7648109743818534, 0.8667587588510515], 
             UndirectedEdge[286, 290] -> 
             RGBColor[
              0.28938656912218486`, 0.4203385400712017, 0.9398338164907357], 
             UndirectedEdge[96, 261] -> 
             RGBColor[
              0.20041641876701294`, 0.3279807416319751, 0.9347247906080353], 
             UndirectedEdge[48, 86] -> 
             RGBColor[
              0.23801910122574216`, 0.3675035450438693, 0.9368662077458763], 
             UndirectedEdge[137, 328] -> 
             RGBColor[
              0.2619981545019592, 0.39270705039696285`, 0.9382317793561266], 
             UndirectedEdge[110, 212] -> 
             RGBColor[
              0.715371093239261, 0.7768498811487758, 0.9728708007300837], 
             UndirectedEdge[163, 272] -> 
             RGBColor[
              0.18785278804211375`, 0.3147755691599099, 0.9340093104244782], 
             UndirectedEdge[245, 396] -> 
             RGBColor[
              0.1896460602736138, 0.31666041197524286`, 0.9341114346251538], 
             UndirectedEdge[25, 37] -> 
             RGBColor[
              0.3241466699483991, 0.4529239992502145, 0.9419579674054581], 
             UndirectedEdge[79, 373] -> 
             RGBColor[
              0.19851817498261992`, 0.32598556705897075`, 0.9346166884327141],
              UndirectedEdge[34, 43] -> 
             RGBColor[
              0.18881744465394812`, 0.3157894844217095, 0.9340642461914408], 
             UndirectedEdge[100, 358] -> 
             RGBColor[
              0.33265464447686266`, 0.4596705372168882, 0.942522885990859], 
             UndirectedEdge[273, 394] -> 
             RGBColor[
              0.4408354922328445, 0.55433085165707, 0.9498412454842259], 
             UndirectedEdge[89, 189] -> 
             RGBColor[
              0.23269978806740765`, 0.361912609650526, 0.9365632807307278], 
             UndirectedEdge[268, 299] -> 
             RGBColor[
              0.18802492021905656`, 0.3149564909916871, 0.9340191130973085], 
             UndirectedEdge[143, 272] -> 
             RGBColor[
              0.19777740595295248`, 0.3252069718413211, 0.9345745027323441], 
             UndirectedEdge[339, 382] -> 
             RGBColor[
              0.3520267531654626, 0.47932961303801835`, 0.943651811320036], 
             UndirectedEdge[111, 223] -> 
             RGBColor[
              0.8429142052274374, 0.3295868808857362, 0.18867802924559862`], 
             UndirectedEdge[71, 131] -> 
             RGBColor[
              0.8919073913712897, 0.9158173378862382, 0.9591371203789343], 
             UndirectedEdge[114, 370] -> 
             RGBColor[
              0.18611224246754757`, 0.3129461454040774, 0.9339101889289132], 
             UndirectedEdge[4, 125] -> 
             RGBColor[
              0.196721601742191, 0.3240972546739574, 0.9345143762444637], 
             UndirectedEdge[246, 251] -> 
             RGBColor[
              0.20081373075853814`, 0.3283983417261034, 0.9347474169381822], 
             UndirectedEdge[30, 229] -> 
             RGBColor[
              0.19931037008134544`, 0.32681821433580155`, 0.9346618027716389],
              UndirectedEdge[115, 366] -> 
             RGBColor[
              0.9742039651565302, 0.9239012646538212, 0.3974339190185809], 
             UndirectedEdge[89, 270] -> 
             RGBColor[
              0.22008543635339983`, 0.34865412620301106`, 0.935844912061876], 
             UndirectedEdge[197, 369] -> 
             RGBColor[
              0.18585850163943218`, 0.31267944770563044`, 0.933895738764128], 
             UndirectedEdge[276, 301] -> 
             RGBColor[
              0.3144566810509267, 0.44134464114731864`, 0.9414571987432081], 
             UndirectedEdge[69, 188] -> 
             RGBColor[
              0.42431357927468827`, 0.535650894850094, 0.9492658859927827], 
             UndirectedEdge[191, 225] -> 
             RGBColor[
              0.19624559498378968`, 0.32359694139030604`, 0.9344872683637615],
              UndirectedEdge[223, 247] -> 
             RGBColor[
              0.8382775353615486, 0.29394740449482404`, 0.18423794894565387`],
              UndirectedEdge[72, 86] -> 
             RGBColor[
              0.3668179912534385, 0.4880512045533021, 0.9448235654131886], 
             UndirectedEdge[19, 85] -> 
             RGBColor[
              0.19070082938217475`, 0.3177690411845645, 0.9341715021654952], 
             UndirectedEdge[320, 398] -> 
             RGBColor[
              0.182257588923795, 0.30889466013044303`, 0.9336906721120455], 
             UndirectedEdge[249, 300] -> 
             RGBColor[
              0.18989148665345995`, 0.3169183706613924, 0.9341254112944102], 
             UndirectedEdge[18, 319] -> 
             RGBColor[
              0.9124901172546147, 0.6184152946465793, 0.3038268692248966], 
             UndirectedEdge[6, 273] -> 
             RGBColor[
              0.7251045855702409, 0.7842222818473898, 0.9742467167674911], 
             UndirectedEdge[158, 348] -> 
             RGBColor[
              0.1961222229924388, 0.3234672696051602, 0.9344802425113666], 
             UndirectedEdge[61, 228] -> 
             RGBColor[
              0.220637096263315, 0.34923395574559046`, 0.935876328277638], 
             UndirectedEdge[70, 260] -> 
             RGBColor[
              0.19294770058427305`, 0.3201306452778321, 0.9342994581565066], 
             UndirectedEdge[144, 305] -> 
             RGBColor[
              0.4396583364184836, 0.550769790541102, 0.9502316306235659], 
             UndirectedEdge[165, 351] -> 
             RGBColor[
              0.26754769340127105`, 0.39846518644420825`, 0.9385505554925828],
              UndirectedEdge[132, 370] -> 
             RGBColor[
              0.189210358194615, 0.3162024614651078, 0.9340866220363182], 
             UndirectedEdge[104, 145] -> 
             RGBColor[
              0.2369611402467977, 0.36639156097639836`, 0.9368059584332384], 
             UndirectedEdge[207, 231] -> 
             RGBColor[
              0.1913619669815575, 0.3184639387200607, 0.9342091529737147], 
             UndirectedEdge[21, 249] -> 
             RGBColor[
              0.19014493822452405`, 0.31718476433233855`, 0.9341398449864342],
              UndirectedEdge[7, 93] -> 
             RGBColor[
              0.29873862778538124`, 0.4282001700379434, 0.9404384596617476], 
             UndirectedEdge[140, 255] -> 
             RGBColor[
              0.390267723092427, 0.5124520191417203, 0.9460884921086202], 
             UndirectedEdge[100, 157] -> 
             RGBColor[
              0.31728677632069113`, 0.4435179334056334, 0.9416477086340886], 
             UndirectedEdge[42, 178] -> 
             RGBColor[
              0.18344665505298052`, 0.31014444402336394`, 0.9337583876690367],
              UndirectedEdge[115, 195] -> 
             RGBColor[
              0.6898630728334411, 0.7009647207638414, 0.6155071113240207], 
             UndirectedEdge[281, 394] -> 
             RGBColor[
              0.3781881603711747, 0.5019893090490473, 0.9453187930535599], 
             UndirectedEdge[215, 224] -> 
             RGBColor[
              0.6019092601655756, 0.6867200928189938, 0.9624709353645509], 
             UndirectedEdge[99, 222] -> 
             RGBColor[
              0.9266267914902193, 0.9439342403679507, 0.9791054495248444], 
             UndirectedEdge[55, 284] -> 
             RGBColor[
              0.7718010949853338, 0.8216561483989014, 0.9778895783229857], 
             UndirectedEdge[32, 337] -> 
             RGBColor[
              0.8892490440589328, 0.5669223839767665, 0.5629734660851704], 
             UndirectedEdge[172, 399] -> 
             RGBColor[
              0.369499573099037, 0.49446369145501556`, 0.9447651639555954], 
             UndirectedEdge[267, 346] -> 
             RGBColor[
              0.20049511025135958`, 0.32806345137135173`, 0.9347292719716551],
              UndirectedEdge[222, 393] -> 
             RGBColor[
              0.8365296253571944, 0.8728854021704904, 0.9703016768071477], 
             UndirectedEdge[116, 179] -> 
             RGBColor[
              0.23341719737643146`, 0.3626666523206874, 0.9366041361295647], 
             UndirectedEdge[120, 360] -> 
             RGBColor[
              0.5376516098803733, 0.6341093662239545, 0.9572645433190765], 
             UndirectedEdge[144, 222] -> 
             RGBColor[
              0.7661723613566251, 0.8169857716290115, 0.9639290713689532], 
             UndirectedEdge[237, 307] -> 
             RGBColor[
              0.1806275543927051, 0.307181390488109, 0.9335978440569198], 
             UndirectedEdge[18, 144] -> 
             RGBColor[
              0.7868965412101618, 0.8286865484723305, 0.6945647496408425], 
             UndirectedEdge[309, 365] -> 
             RGBColor[
              0.5016918379873817, 0.6012405287458232, 0.9556046196739707], 
             UndirectedEdge[189, 241] -> 
             RGBColor[
              0.2570425573000169, 0.3874984035347115, 0.937949565426625], 
             UndirectedEdge[268, 370] -> 
             RGBColor[
              0.18660341497029534`, 0.3134623988466007, 0.9339381604763201], 
             UndirectedEdge[336, 359] -> 
             RGBColor[
              0.2802453493603669, 0.4103194523243253, 0.9393282894277089], 
             UndirectedEdge[115, 123] -> 
             RGBColor[
              0.8991328422336753, 0.5962300691178152, 0.23584910998017405`], 
             UndirectedEdge[6, 394] -> 
             RGBColor[
              0.6418942074247149, 0.7140700620770483, 0.9684140052108057], 
             UndirectedEdge[259, 353] -> 
             RGBColor[
              0.9443422105725244, 0.9537215111738743, 0.7488183078429457], 
             UndirectedEdge[98, 348] -> 
             RGBColor[
              0.19717643500186177`, 0.3245753132679656, 0.9345402783257364], 
             UndirectedEdge[145, 349] -> 
             RGBColor[
              0.2241439081408365, 0.35291983737358057`, 0.9360760360261996], 
             UndirectedEdge[287, 292] -> 
             RGBColor[
              0.8184054423003344, 0.14247787160242187`, 0.16525837837376128`],
              UndirectedEdge[53, 69] -> 
             RGBColor[
              0.4877113731208531, 0.5936081076641104, 0.9531940365593021], 
             UndirectedEdge[236, 284] -> 
             RGBColor[
              0.6247504035752902, 0.7047458827568778, 0.9646230139836673], 
             UndirectedEdge[119, 146] -> 
             RGBColor[
              0.2194595639056427, 0.3479962945778132, 0.9358092695518716], 
             UndirectedEdge[198, 310] -> 
             RGBColor[
              0.8276571285797327, 0.5355745817229594, 0.5782791813938954], 
             UndirectedEdge[198, 384] -> 
             RGBColor[
              0.8811911535814985, 0.820358675063078, 0.6244757857174054], 
             UndirectedEdge[111, 292] -> 
             RGBColor[
              0.8230519846103825, 0.1781932319252751, 0.16970791253738232`], 
             UndirectedEdge[40, 295] -> 
             RGBColor[
              0.1896748892459051, 0.31669071305298346`, 0.934113076392477], 
             UndirectedEdge[5, 270] -> 
             RGBColor[
              0.19738135324155764`, 0.32479069533045285`, 0.9345519481163376],
              UndirectedEdge[104, 355] -> 
             RGBColor[
              0.21609483282429037`, 0.34445974887503966`, 0.9356176530944622],
              UndirectedEdge[356, 360] -> 
             RGBColor[
              0.804069535005691, 0.8476283188054337, 0.97217824926772], 
             UndirectedEdge[42, 398] -> 
             RGBColor[
              0.18234639975021955`, 0.30898800593994685`, 0.9336957297572264],
              UndirectedEdge[153, 211] -> 
             RGBColor[
              0.21907020233692062`, 0.34758705088213704`, 0.9357870959865418],
              UndirectedEdge[223, 385] -> 
             RGBColor[
              0.9268169546976089, 0.7220420708837272, 0.4190027976388401], 
             UndirectedEdge[144, 361] -> 
             RGBColor[
              0.4954156444114053, 0.6000520136165334, 0.9537482598048219], 
             UndirectedEdge[216, 229] -> 
             RGBColor[
              0.2068690748506942, 0.33476289229794964`, 0.9350922598261517], 
             UndirectedEdge[161, 389] -> 
             RGBColor[
              0.9363348090239618, 0.7668148008617284, 0.3570460900069422], 
             UndirectedEdge[313, 340] -> 
             RGBColor[
              0.2780047879810863, 0.40953103706270466`, 0.9391433334530706], 
             UndirectedEdge[241, 380] -> 
             RGBColor[
              0.5006467932710101, 0.5970366894503322, 0.9560367412293518], 
             UndirectedEdge[258, 281] -> 
             RGBColor[
              0.318201913769557, 0.44345916858997797`, 0.9417371947060786], 
             UndirectedEdge[344, 346] -> 
             RGBColor[
              0.19749434605120672`, 0.3249094579375519, 0.9345583828896893], 
             UndirectedEdge[79, 205] -> 
             RGBColor[
              0.19210249208707042`, 0.3192422775579583, 0.9342513247829649], 
             UndirectedEdge[227, 306] -> 
             RGBColor[
              0.248145898473511, 0.3781474510273044, 0.9374429138678827], 
             UndirectedEdge[43, 381] -> 
             RGBColor[
              0.19202300109929993`, 0.3191587274897918, 0.9342467978888077], 
             UndirectedEdge[98, 143] -> 
             RGBColor[
              0.19607611547037074`, 0.3234188076760809, 0.9344776167561948], 
             UndirectedEdge[243, 267] -> 
             RGBColor[
              0.2144789920516021, 0.342761397772722, 0.9355256333528797], 
             UndirectedEdge[58, 152] -> 
             RGBColor[
              0.19702370192683044`, 0.32441478112227146`, 0.9345315804030616],
              UndirectedEdge[376, 397] -> 
             RGBColor[
              0.32517928194563106`, 0.4539892085157613, 0.9420175102408045], 
             UndirectedEdge[114, 279] -> 
             RGBColor[
              0.19285735565451845`, 0.32003568702846064`, 0.9342943131464105],
              UndirectedEdge[148, 218] -> 
             RGBColor[
              0.40841467546891774`, 0.5204402282772255, 0.9482239194761258], 
             UndirectedEdge[55, 366] -> 
             RGBColor[
              0.8985186945130963, 0.9173414029032505, 0.7466017890196988], 
             UndirectedEdge[99, 361] -> 
             RGBColor[
              0.6558700745449995, 0.7270004823554725, 0.968924637960713], 
             UndirectedEdge[97, 169] -> 
             RGBColor[
              0.37794173807367953`, 0.5007330923555633, 0.945366919038301], 
             UndirectedEdge[43, 250] -> 
             RGBColor[
              0.19420867686654147`, 0.32145601130101026`, 0.9343712688903346],
              UndirectedEdge[112, 177] -> 
             RGBColor[
              0.18091855533538903`, 0.3074872509293952, 0.9336144161301083], 
             UndirectedEdge[255, 356] -> 
             RGBColor[
              0.6597861746771188, 0.7286564919053182, 0.9611997608615672], 
             UndirectedEdge[210, 328] -> 
             RGBColor[
              0.2385161810587667, 0.36802600746505976`, 0.9368945157070033], 
             UndirectedEdge[91, 221] -> 
             RGBColor[
              0.48124384050183955`, 0.5874697805650118, 0.9529301608546397], 
             UndirectedEdge[32, 345] -> 
             RGBColor[
              0.824801297962475, 0.5160822589510907, 0.5758521781137924], 
             UndirectedEdge[210, 258] -> 
             RGBColor[
              0.24166666616429894`, 0.371337367063267, 0.9370739311730383], 
             UndirectedEdge[189, 359] -> 
             RGBColor[
              0.2794316818374808, 0.4094642361682714, 0.9392819522659938], 
             UndirectedEdge[164, 258] -> 
             RGBColor[
              0.22632269335272776`, 0.3552098787742395, 0.936200114620793], 
             UndirectedEdge[354, 374] -> 
             RGBColor[
              0.18986888322413037`, 0.3168946130240269, 0.9341241240625486], 
             UndirectedEdge[235, 322] -> 
             RGBColor[
              0.1941801601361397, 0.32142603840929285`, 0.934369644904725], 
             UndirectedEdge[147, 392] -> 
             RGBColor[
              0.2251386082236323, 0.35396533022822685`, 0.9361326827243879], 
             UndirectedEdge[123, 283] -> 
             RGBColor[
              0.8875401777067986, 0.5502690172951994, 0.2265213799870392], 
             UndirectedEdge[202, 239] -> 
             RGBColor[
              0.4173644057485659, 0.5344604832455712, 0.9482188359733204], 
             UndirectedEdge[180, 249] -> 
             RGBColor[
              0.18602314959306215`, 0.3128525031441788, 0.9339051152215123], 
             UndirectedEdge[2, 197] -> 
             RGBColor[
              0.1965684920257088, 0.3239363266542179, 0.9345056568726156], 
             UndirectedEdge[174, 329] -> 
             RGBColor[
              0.34008730347088106`, 0.4646976118288939, 0.9430481418570962], 
             UndirectedEdge[193, 242] -> 
             RGBColor[
              0.5891633460741419, 0.6714315101447773, 0.963657200278417], 
             UndirectedEdge[58, 160] -> 
             RGBColor[
              0.1942495004305084, 0.32149891945510295`, 0.9343735937319094], 
             UndirectedEdge[50, 137] -> 
             RGBColor[
              0.2618861891426283, 0.3925893677052923, 0.9382254030945505], 
             UndirectedEdge[326, 383] -> 
             RGBColor[
              0.2999445651565369, 0.428007904865782, 0.9405605857739958], 
             UndirectedEdge[157, 238] -> 
             RGBColor[
              0.22387178003127423`, 0.3526338134765119, 0.9360605387329375], 
             UndirectedEdge[243, 346] -> 
             RGBColor[
              0.21741007073096835`, 0.3458421473058579, 0.9356925539475274], 
             UndirectedEdge[235, 355] -> 
             RGBColor[
              0.2006947956866969, 0.3282733334246791, 0.9347406437617896], 
             UndirectedEdge[44, 135] -> 
             RGBColor[
              0.2818343394924019, 0.41109593137624006`, 0.9394515009810677], 
             UndirectedEdge[33, 206] -> 
             RGBColor[
              0.33773890435239673`, 0.4612073947457289, 0.942951820792434], 
             UndirectedEdge[88, 263] -> 
             RGBColor[
              0.3661139704738488, 0.49089201133024934`, 0.9445728421053426], 
             UndirectedEdge[82, 399] -> 
             RGBColor[
              0.5595672102027384, 0.6489717323660277, 0.9604046913379707], 
             UndirectedEdge[271, 287] -> 
             RGBColor[
              0.8186608763962349, 0.14444124999544666`, 0.16550298235246705`],
              UndirectedEdge[31, 223] -> 
             RGBColor[
              0.9217373572851282, 0.7206872472869994, 0.5573908785042743], 
             UndirectedEdge[108, 376] -> 
             RGBColor[
              0.29627129186653856`, 0.4287302908095537, 0.9401835838264763], 
             UndirectedEdge[301, 361] -> 
             RGBColor[
              0.3297210809288895, 0.45456589711056455`, 0.9424298328056531], 
             UndirectedEdge[80, 388] -> 
             RGBColor[
              0.23694403524812552`, 0.36637358253827423`, 0.9368049843288686],
              UndirectedEdge[47, 136] -> 
             RGBColor[
              0.18182023692588944`, 0.308434975450926, 0.9336657655627689], 
             UndirectedEdge[39, 50] -> 
             RGBColor[
              0.21465093660737516`, 0.342942122402754, 0.9355354253409618], 
             UndirectedEdge[120, 389] -> 
             RGBColor[
              0.7028354936755193, 0.7597247670512044, 0.7201987400202577], 
             UndirectedEdge[28, 106] -> 
             RGBColor[
              0.18905752987434937`, 0.31604182921063345`, 0.9340779186895682],
              UndirectedEdge[97, 326] -> 
             RGBColor[
              0.27009816450947055`, 0.40122067448515425`, 0.9386930629431633],
              UndirectedEdge[195, 242] -> 
             RGBColor[
              0.3825084156474021, 0.5057312970269716, 0.9455940758995094], 
             UndirectedEdge[90, 260] -> 
             RGBColor[
              0.20225002842194761`, 0.32990798163687834`, 0.9348292119653014],
              UndirectedEdge[73, 368] -> 
             RGBColor[
              0.19117243294824504`, 0.31826472643389747`, 0.934198359290908], 
             UndirectedEdge[52, 287] -> 
             RGBColor[
              0.9031568301038848, 0.5619220117093251, 0.49813424573552845`], 
             UndirectedEdge[135, 243] -> 
             RGBColor[
              0.2833746021341409, 0.41271484507099976`, 0.9395392166599004], 
             UndirectedEdge[311, 317] -> 
             RGBColor[
              0.19555015626042008`, 0.32286599119868276`, 0.934447664157275], 
             UndirectedEdge[6, 10] -> 
             RGBColor[
              0.8845651997050992, 0.6376155087725291, 0.5907990623624317], 
             UndirectedEdge[363, 383] -> 
             RGBColor[
              0.36642168177165046`, 0.49179777668654956`, 0.9445690434418867],
              UndirectedEdge[227, 346] -> 
             RGBColor[
              0.23870901568862182`, 0.3682286888874592, 0.9369054973539003], 
             UndirectedEdge[157, 341] -> 
             RGBColor[
              0.24810243304135554`, 0.37810176610224144`, 0.9374404385758228],
              UndirectedEdge[18, 310] -> 
             RGBColor[
              0.9095262697789932, 0.5956338641827077, 0.30098868553505453`], 
             UndirectedEdge[37, 96] -> 
             RGBColor[
              0.24798039051581972`, 0.3779734916699602, 0.9374334884345392], 
             UndirectedEdge[218, 222] -> 
             RGBColor[
              0.7556819189936763, 0.8084691579297268, 0.9631032253183853], 
             UndirectedEdge[65, 203] -> 
             RGBColor[
              0.34325183639463963`, 0.4717292211712722, 0.9430926813827534], 
             UndirectedEdge[105, 303] -> 
             RGBColor[
              0.9396161743909813, 0.7997165627600418, 0.5632237947654809], 
             UndirectedEdge[119, 267] -> 
             RGBColor[
              0.21867692760035795`, 0.34717369419895117`, 0.9357646995720923],
              UndirectedEdge[20, 312] -> 
             RGBColor[
              0.4662211223319299, 0.5756731791658605, 0.9516371294428863], 
             UndirectedEdge[285, 324] -> 
             RGBColor[
              0.1849819453905557, 0.31175813151118514`, 0.9338458201825032], 
             UndirectedEdge[16, 302] -> 
             RGBColor[
              0.21182755927874247`, 0.3399745738178992, 0.9353746381789088], 
             UndirectedEdge[65, 313] -> 
             RGBColor[
              0.33055584599709903`, 0.45850175468157234`, 0.9423653859984371],
              UndirectedEdge[280, 392] -> 
             RGBColor[
              0.20599555407739328`, 0.33384476658079454`, 0.9350425141103704],
              UndirectedEdge[1, 357] -> 
             RGBColor[
              0.18390843895748787`, 0.3106298081857918, 0.9337846855792504], 
             UndirectedEdge[26, 177] -> 
             RGBColor[
              0.18182665700375172`, 0.3084417233598157, 0.9336661311767056], 
             UndirectedEdge[69, 293] -> 
             RGBColor[
              0.44347384418172964`, 0.5552917835398956, 0.950375260333012], 
             UndirectedEdge[165, 399] -> 
             RGBColor[
              0.2924581876891166, 0.42004140455849254`, 0.9401378301611192], 
             UndirectedEdge[108, 297] -> 
             RGBColor[
              0.30146181771501923`, 0.43418586257465347`, 0.9404791765948524],
              UndirectedEdge[192, 335] -> 
             RGBColor[
              0.22826537319767345`, 0.3572517584642937, 0.9363107473640253], 
             UndirectedEdge[134, 272] -> 
             RGBColor[
              0.18788317693480855`, 0.3148075098128992, 0.9340110410269609], 
             UndirectedEdge[86, 236] -> 
             RGBColor[
              0.3888676051713017, 0.5059520744556105, 0.9465593917911999], 
             UndirectedEdge[312, 389] -> 
             RGBColor[
              0.7704699076494956, 0.8157404401627024, 0.7252172989695943], 
             UndirectedEdge[156, 245] -> 
             RGBColor[
              0.1983829021548571, 0.32584338674019936`, 0.9346089848452912], 
             UndirectedEdge[153, 168] -> 
             RGBColor[
              0.20180786245057253`, 0.3294432371660213, 0.9348040312673576], 
             UndirectedEdge[118, 150] -> 
             RGBColor[
              0.29792702653421543`, 0.4259677967148573, 0.9404427441608055], 
             UndirectedEdge[195, 255] -> 
             RGBColor[
              0.3994035312970712, 0.5203649970295117, 0.9466706177289421], 
             UndirectedEdge[109, 180] -> 
             RGBColor[
              0.18558731783868732`, 0.3123944163370016, 0.933880295247856], 
             UndirectedEdge[143, 378] -> 
             RGBColor[
              0.21957024665493602`, 0.3481126291650121, 0.9358155727707034], 
             UndirectedEdge[135, 383] -> 
             RGBColor[
              0.3468364039638354, 0.47483399343410504`, 0.9433210868585539], 
             UndirectedEdge[20, 120] -> 
             RGBColor[
              0.3985867083579536, 0.5196575060543626, 0.9466185704935497], 
             UndirectedEdge[149, 230] -> 
             RGBColor[
              0.21572578902733716`, 0.34407186044571364`, 0.935596636596177], 
             UndirectedEdge[16, 77] -> 
             RGBColor[
              0.21295289463759554`, 0.3411573726304365, 0.9354387243628108], 
             UndirectedEdge[168, 238] -> 
             RGBColor[
              0.19942328541058194`, 0.3269368955060745, 0.9346682331325956], 
             UndirectedEdge[104, 335] -> 
             RGBColor[
              0.21115674634682685`, 0.33926950689445945`, 0.9353364363748149],
              UndirectedEdge[79, 232] -> 
             RGBColor[
              0.19470557204870292`, 0.32197827964243614`, 0.9343995663358682],
              UndirectedEdge[47, 299] -> 
             RGBColor[
              0.184696983160691, 0.3114586181399484, 0.9338295920050762], 
             UndirectedEdge[236, 397] -> 
             RGBColor[
              0.4369077612514729, 0.5513201116783387, 0.9494828667557864], 
             UndirectedEdge[33, 118] -> 
             RGBColor[
              0.30201839786374246`, 0.43026808739011524`, 0.9406757417053806],
              UndirectedEdge[51, 79] -> 
             RGBColor[
              0.20012999875823717`, 0.3276796960426744, 0.934708479412256], 
             UndirectedEdge[24, 168] -> 
             RGBColor[
              0.22907306672132033`, 0.35810069556837376`, 0.9363567443153216],
              UndirectedEdge[269, 365] -> 
             RGBColor[
              0.3297101598350657, 0.4597477851420956, 0.9422390562668672], 
             UndirectedEdge[98, 240] -> 
             RGBColor[
              0.18629079266231832`, 0.3131338129795177, 0.9339203570983641], 
             UndirectedEdge[29, 113] -> 
             RGBColor[
              0.1857448284490183, 0.3125599699752089, 0.9338892652440982], 
             UndirectedEdge[330, 398] -> 
             RGBColor[
              0.18475377969358928`, 0.31151831489713266`, 0.9338328264836019],
              UndirectedEdge[43, 265] -> 
             RGBColor[
              0.19684687423849298`, 0.3242289240103058, 0.934521510327804], 
             UndirectedEdge[209, 304] -> 
             RGBColor[
              0.2736580263748165, 0.40496231501391133`, 0.9388957918100511], 
             UndirectedEdge[107, 238] -> 
             RGBColor[
              0.21198166691675951`, 0.34013655071644366`, 0.9353834143809119],
              UndirectedEdge[298, 347] -> 
             RGBColor[
              0.1948950544058417, 0.32217743761366435`, 0.9344103570757931], 
             UndirectedEdge[153, 343] -> 
             RGBColor[
              0.20318561149837056`, 0.330891338769592, 0.9348824920374326], 
             UndirectedEdge[110, 292] -> 
             RGBColor[
              0.8362272767124428, 0.5182110192715781, 0.5760681458101908], 
             UndirectedEdge[332, 366] -> 
             RGBColor[
              0.905552488404973, 0.5629699044168974, 0.3384071050888487], 
             UndirectedEdge[39, 136] -> 
             RGBColor[
              0.19040517985093924`, 0.31745829478197307`, 0.9341546653620656],
              UndirectedEdge[115, 380] -> 
             RGBColor[
              0.8377450255090341, 0.8206060012110092, 0.627750782576732], 
             UndirectedEdge[167, 238] -> 
             RGBColor[
              0.2183443407497785, 0.3468241243317679, 0.9357457592429699], 
             UndirectedEdge[1, 162] -> 
             RGBColor[
              0.18855509271436693`, 0.315513735899136, 0.9340493056365965], 
             UndirectedEdge[128, 243] -> 
             RGBColor[
              0.26764794439082373`, 0.39864533778752814`, 0.9385535265321823],
              UndirectedEdge[196, 366] -> 
             RGBColor[
              0.9187123308959824, 0.9333119446325909, 0.748562723255582], 
             UndirectedEdge[136, 149] -> 
             RGBColor[
              0.19648120536399588`, 0.3238445828384636, 0.9345006860263599], 
             UndirectedEdge[263, 360] -> 
             RGBColor[
              0.48229378308011506`, 0.5855219577186828, 0.9537605973016217], 
             UndirectedEdge[267, 354] -> 
             RGBColor[
              0.19683262012965425`, 0.3242139420381536, 0.9345206985773926], 
             UndirectedEdge[192, 355] -> 
             RGBColor[
              0.233203459675137, 0.36244200044487396`, 0.9365919640836726], 
             UndirectedEdge[24, 100] -> 
             RGBColor[
              0.32394697736880945`, 0.450518226988342, 0.9420269972308946], 
             UndirectedEdge[11, 286] -> 
             RGBColor[
              0.5972181184299319, 0.677195451192008, 0.9647287147159659], 
             UndirectedEdge[71, 110] -> 
             RGBColor[
              0.9113332721380322, 0.9312595378862136, 0.9610025753124077], 
             UndirectedEdge[186, 306] -> 
             RGBColor[
              0.21444053080855624`, 0.3427209725676972, 0.9355234430419865], 
             UndirectedEdge[6, 131] -> 
             RGBColor[
              0.8701371040264215, 0.8993351938028649, 0.9874630507499915], 
             UndirectedEdge[53, 264] -> 
             RGBColor[
              0.3312918681319017, 0.4568612487266348, 0.9424956938321003], 
             UndirectedEdge[83, 118] -> 
             RGBColor[
              0.6542161598297946, 0.7234949587303476, 0.9559255584190995], 
             UndirectedEdge[98, 272] -> 
             RGBColor[
              0.1949500622314218, 0.3222352543260466, 0.9344134896900831], 
             UndirectedEdge[200, 330] -> 
             RGBColor[
              0.1913737687250167, 0.31847634310071005`, 0.9342098250655455], 
             UndirectedEdge[101, 389] -> 
             RGBColor[
              0.9235485115849101, 0.701785575444227, 0.3461039765729519], 
             UndirectedEdge[10, 353] -> 
             RGBColor[
              0.9181134493807003, 0.6596306220979193, 0.3482638350680197], 
             UndirectedEdge[174, 340] -> 
             RGBColor[
              0.3446138349142821, 0.46945528337457815`, 0.9433059211263948], 
             UndirectedEdge[77, 187] -> 
             RGBColor[
              0.2066496337845954, 0.33453224582411256`, 0.9350797629820713], 
             UndirectedEdge[137, 264] -> 
             RGBColor[
              0.27631179289230656`, 0.4077515918823088, 0.9390469198873264], 
             UndirectedEdge[20, 356] -> 
             RGBColor[
              0.6650046334832713, 0.7331764586358418, 0.9615322764421933], 
             UndirectedEdge[130, 227] -> 
             RGBColor[
              0.24482762812914852`, 0.374659738504888, 0.9372539432807123], 
             UndirectedEdge[24, 150] -> 
             RGBColor[
              0.24929421300339247`, 0.3793544024055562, 0.9375083086815804], 
             UndirectedEdge[282, 339] -> 
             RGBColor[
              0.34849054026782905`, 0.4762667231613163, 0.9434264869611491], 
             UndirectedEdge[69, 93] -> 
             RGBColor[
              0.45767335020652483`, 0.5675906819706489, 0.951280040300782], 
             UndirectedEdge[65, 266] -> 
             RGBColor[
              0.5173579150755038, 0.6167245429391528, 0.9558899485594068], 
             UndirectedEdge[189, 336] -> 
             RGBColor[
              0.23398737474331802`, 0.3632659448846183, 0.936636606887107], 
             UndirectedEdge[191, 322] -> 
             RGBColor[
              0.18956017104754852`, 0.31657013695295677`, 0.934106543360791], 
             UndirectedEdge[297, 376] -> 
             RGBColor[
              0.2913695149854919, 0.423578212516969, 0.9399044348846297], 
             UndirectedEdge[33, 286] -> 
             RGBColor[
              0.2839164063725824, 0.41458905219301934`, 0.9395222988145264], 
             UndirectedEdge[145, 351] -> 
             RGBColor[
              0.2797139568415439, 0.4112527007055903, 0.9392434061971325], 
             UndirectedEdge[83, 141] -> 
             RGBColor[
              0.6533758763039106, 0.7227671473741049, 0.9558720162958637], 
             UndirectedEdge[148, 276] -> 
             RGBColor[
              0.31779913118136904`, 0.44485776815799194`, 0.9416475463334251],
              UndirectedEdge[124, 160] -> 
             RGBColor[
              0.21095706740892387`, 0.3390596316703475, 0.9353250649546998], 
             UndirectedEdge[25, 362] -> 
             RGBColor[
              0.5776163710657185, 0.6632666473879071, 0.9621212256893779], 
             UndirectedEdge[96, 208] -> 
             RGBColor[
              0.25302363918053994`, 0.383274265777015, 0.9377206939851772], 
             UndirectedEdge[240, 272] -> 
             RGBColor[
              0.18799208314490007`, 0.3149219771447579, 0.9340172430745133], 
             UndirectedEdge[25, 182] -> 
             RGBColor[
              0.30289473156223595`, 0.4305868645556383, 0.9407477009537915], 
             UndirectedEdge[101, 380] -> 
             RGBColor[
              0.787177962650946, 0.5986793707999881, 0.5860416238148101], 
             UndirectedEdge[24, 358] -> 
             RGBColor[
              0.2688894294981841, 0.3999502173500661, 0.9386242272724338], 
             UndirectedEdge[202, 234] -> 
             RGBColor[
              0.28726387007128157`, 0.41752052418196, 0.9397344221047603], 
             UndirectedEdge[17, 62] -> 
             RGBColor[
              0.9097327710312662, 0.6022520662838114, 0.4798085283004041], 
             UndirectedEdge[24, 211] -> 
             RGBColor[
              0.2463354066076684, 0.3762445092844895, 0.9373398090345058], 
             UndirectedEdge[2, 39] -> 
             RGBColor[
              0.19999978068083032`, 0.3275428285870168, 0.934701063685388], 
             UndirectedEdge[164, 328] -> 
             RGBColor[
              0.22317220824719552`, 0.35189851917603227`, 0.9360206991547579],
              UndirectedEdge[228, 301] -> 
             RGBColor[
              0.2369380396545014, 0.36636728078923275`, 0.9368046428886814], 
             UndirectedEdge[118, 286] -> 
             RGBColor[
              0.33934539796061675`, 0.46834566054302623`, 0.9428437665800653],
              UndirectedEdge[139, 215] -> 
             RGBColor[
              0.5065072627092252, 0.6051273956422916, 0.956064783626883], 
             UndirectedEdge[239, 377] -> 
             RGBColor[
              0.3809157120608543, 0.4978929904163819, 0.9460793391645779], 
             UndirectedEdge[348, 374] -> 
             RGBColor[
              0.19237032800791454`, 0.3195237900925436, 0.9342665776424293], 
             UndirectedEdge[8, 388] -> 
             RGBColor[
              0.26319007599843486`, 0.3939598354619466, 0.938299657522061], 
             UndirectedEdge[249, 370] -> 
             RGBColor[
              0.18458433002004276`, 0.31134021254650546`, 0.9338231765753717],
              UndirectedEdge[61, 285] -> 
             RGBColor[
              0.2007711589524707, 0.32835359605871806`, 0.934744992536806], 
             UndirectedEdge[162, 280] -> 
             RGBColor[
              0.20211294537388308`, 0.32976389866179523`, 0.9348214052885103],
              UndirectedEdge[126, 205] -> 
             RGBColor[
              0.18385657240612066`, 0.31057529315177557`, 0.9337817318558796],
              UndirectedEdge[161, 334] -> 
             RGBColor[
              0.9198789642740572, 0.7116881876157337, 0.2605664067222301], 
             UndirectedEdge[192, 399] -> 
             RGBColor[
              0.3088211273745378, 0.43723989163816773`, 0.941069675369404], 
             UndirectedEdge[69, 281] -> 
             RGBColor[
              0.4857845720433236, 0.5919392094145923, 0.9530712624984452], 
             UndirectedEdge[38, 128] -> 
             RGBColor[
              0.281313846761083, 0.4130090676469258, 0.9393317794552777], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.22265042245962569`, 0.35135008923016664`, 0.9359909842260687],
              UndirectedEdge[145, 355] -> 
             RGBColor[
              0.22900678342998865`, 0.3580310276265808, 0.9363529695799375], 
             UndirectedEdge[23, 139] -> 
             RGBColor[
              0.2594316195520534, 0.3900094594368974, 0.9380856189875776], 
             UndirectedEdge[120, 359] -> 
             RGBColor[
              0.3691186833876108, 0.4941337839310517, 0.9447408939999908], 
             UndirectedEdge[117, 309] -> 
             RGBColor[
              0.6279491492944215, 0.7079937863162957, 0.9644297266188226], 
             UndirectedEdge[19, 167] -> 
             RGBColor[
              0.21765966709879997`, 0.34610448891377266`, 0.9357067680914306],
              UndirectedEdge[26, 285] -> 
             RGBColor[
              0.1832664520031871, 0.30995503919249784`, 0.9337481253719375], 
             UndirectedEdge[166, 169] -> 
             RGBColor[
              0.3512165772923903, 0.4726432539013666, 0.9438449606681389], 
             UndirectedEdge[31, 383] -> 
             RGBColor[
              0.6712879724630387, 0.7362684219408357, 0.9272977112853262], 
             UndirectedEdge[146, 346] -> 
             RGBColor[
              0.20127774655664432`, 0.3288860517502138, 0.9347738419514344], 
             UndirectedEdge[191, 349] -> 
             RGBColor[
              0.1912119313089536, 0.3183062417153429, 0.9342006086641177], 
             UndirectedEdge[212, 362] -> 
             RGBColor[
              0.6845252117813709, 0.7524862898136562, 0.9698671068536907], 
             UndirectedEdge[242, 380] -> 
             RGBColor[
              0.5303903683229951, 0.6253725774741394, 0.9578377471522206], 
             UndirectedEdge[175, 307] -> 
             RGBColor[
              0.18458331869086259`, 0.3113391495754152, 0.933823118981671], 
             UndirectedEdge[140, 193] -> 
             RGBColor[
              0.6221373960333281, 0.6999919748954846, 0.9657582775840088], 
             UndirectedEdge[8, 25] -> 
             RGBColor[
              0.3097802502292844, 0.43782398124180466`, 0.9411398210556678], 
             UndirectedEdge[8, 269] -> 
             RGBColor[
              0.30450100126350144`, 0.4332513611304116, 0.9408034319798247], 
             UndirectedEdge[155, 371] -> 
             RGBColor[
              0.18296643499197385`, 0.3096397022915355, 0.9337310398469844], 
             UndirectedEdge[55, 161] -> 
             RGBColor[
              0.8416418357931794, 0.6962674351181222, 0.6011377684958046], 
             UndirectedEdge[110, 202] -> 
             RGBColor[
              0.590277084299675, 0.6718791600205865, 0.9639661767270546], 
             UndirectedEdge[332, 380] -> 
             RGBColor[
              0.7690935487574768, 0.4596746409740855, 0.5687239686469998], 
             UndirectedEdge[359, 360] -> 
             RGBColor[
              0.49422258294729215`, 0.5964933259008812, 0.9544972841256812], 
             UndirectedEdge[128, 350] -> 
             RGBColor[
              0.32622360223214686`, 0.4565323538126437, 0.9420240559565443], 
             UndirectedEdge[272, 378] -> 
             RGBColor[
              0.2184441934159871, 0.34692907581497784`, 0.9357514457045917], 
             UndirectedEdge[52, 345] -> 
             RGBColor[
              0.9085391948738575, 0.9277362639462506, 0.9077575254526454], 
             UndirectedEdge[32, 333] -> 
             RGBColor[
              0.8876476995379257, 0.5657281038549604, 0.5656841246616948], 
             UndirectedEdge[85, 168] -> 
             RGBColor[
              0.18992658867508105`, 0.3169552651117129, 0.9341274103026127], 
             UndirectedEdge[23, 354] -> 
             RGBColor[
              0.20401044687486744`, 0.3317582930478737, 0.9349294651918895], 
             UndirectedEdge[51, 373] -> 
             RGBColor[
              0.1995969758310581, 0.32711945515060364`, 0.9346781245450898], 
             UndirectedEdge[55, 334] -> 
             RGBColor[
              0.8819744590496598, 0.862025730858683, 0.6405013220512796], 
             UndirectedEdge[66, 267] -> 
             RGBColor[
              0.1968456208420638, 0.3242276066111888, 0.9345214389487315], 
             UndirectedEdge[30, 153] -> 
             RGBColor[
              0.2031751711317593, 0.3308803652823261, 0.9348818974739992], 
             UndirectedEdge[179, 290] -> 
             RGBColor[
              0.24217146180405288`, 0.37186793928654055`, 0.9371026785379442],
              UndirectedEdge[178, 200] -> 
             RGBColor[
              0.1885274133225135, 0.31548464310332325`, 0.9340477293361784], 
             UndirectedEdge[340, 358] -> 
             RGBColor[
              0.2744945486553811, 0.4058415529693607, 0.9389434305164055], 
             UndirectedEdge[31, 259] -> 
             RGBColor[
              0.9398415048836066, 0.9536048784389164, 0.9502151803126189], 
             UndirectedEdge[92, 146] -> 
             RGBColor[
              0.20174986693286398`, 0.32938228019978144`, 0.9348007285084208],
              UndirectedEdge[3, 373] -> 
             RGBColor[
              0.21710028788855346`, 0.3455165458971132, 0.9356749122729344], 
             UndirectedEdge[174, 341] -> 
             RGBColor[
              0.3335895874564281, 0.4578681003187137, 0.9426781065425826], 
             UndirectedEdge[248, 260] -> 
             RGBColor[
              0.1859219097416619, 0.3127460936413798, 0.933899349761746], 
             UndirectedEdge[41, 325] -> 
             RGBColor[
              0.2165335134226994, 0.3449208299979239, 0.9356426353055718], 
             UndirectedEdge[66, 346] -> 
             RGBColor[
              0.19977669952143007`, 0.3273083561443247, 0.9346883595433791], 
             UndirectedEdge[53, 142] -> 
             RGBColor[
              0.43838221439814257`, 0.5535604743597381, 0.949310664485988], 
             UndirectedEdge[38, 44] -> 
             RGBColor[
              0.24351959225973108`, 0.37328490987186613`, 0.9371794525730147],
              UndirectedEdge[76, 187] -> 
             RGBColor[
              0.24964108184106412`, 0.37971898354670364`, 0.9375280623487394],
              UndirectedEdge[156, 160] -> 
             RGBColor[
              0.19858358472464382`, 0.32605431684505504`, 0.9346204134207573],
              UndirectedEdge[141, 290] -> 
             RGBColor[
              0.3066482770874609, 0.4352897639120549, 0.9409337172583541], 
             UndirectedEdge[3, 79] -> 
             RGBColor[
              0.21763331081573253`, 0.34607678678918397`, 0.9357052671401005],
              UndirectedEdge[301, 382] -> 
             RGBColor[
              0.2859820358837003, 0.41668133468074653`, 0.9396428195322926], 
             UndirectedEdge[193, 389] -> 
             RGBColor[
              0.9155257058475293, 0.9306524378746825, 0.7386464272151838], 
             UndirectedEdge[189, 291] -> 
             RGBColor[
              0.21431712870363867`, 0.34259126913128346`, 0.9355164154746687],
              UndirectedEdge[161, 196] -> 
             RGBColor[
              0.8618354721760655, 0.7122379768474625, 0.603098702731688], 
             UndirectedEdge[83, 161] -> 
             RGBColor[
              0.9152656356126947, 0.754447556797873, 0.5945283802670174], 
             UndirectedEdge[100, 211] -> 
             RGBColor[
              0.31010062158634694`, 0.43596482915131163`, 0.941238467752931], 
             UndirectedEdge[32, 287] -> 
             RGBColor[
              0.8194189331925024, 0.1502680067141652, 0.16622889839667554`], 
             UndirectedEdge[156, 181] -> 
             RGBColor[
              0.19699698742024596`, 0.3243867024820536, 0.9345300590514323], 
             UndirectedEdge[126, 176] -> 
             RGBColor[
              0.18438193895865332`, 0.3111274867086507, 0.9338116507038363], 
             UndirectedEdge[46, 350] -> 
             RGBColor[
              0.5770408715617338, 0.6621623046757947, 0.9623409899481321], 
             UndirectedEdge[47, 149] -> 
             RGBColor[
              0.1956652358484003, 0.3229869471421173, 0.9344542177695655], 
             UndirectedEdge[57, 108] -> 
             RGBColor[
              0.32733127751038416`, 0.4577193635987606, 0.9420863025998256], 
             UndirectedEdge[105, 400] -> 
             RGBColor[
              0.9037087544899305, 0.5795914846825118, 0.5310267371567282], 
             UndirectedEdge[62, 256] -> 
             RGBColor[
              0.992053902372576, 0.9909820986727351, 0.781350931735281], 
             UndirectedEdge[193, 332] -> 
             RGBColor[
              0.8278665265086236, 0.5057335736447233, 0.5745434217731962], 
             UndirectedEdge[1, 387] -> 
             RGBColor[
              0.1836776641650684, 0.31038724924699196`, 0.9337715432962228], 
             UndirectedEdge[72, 284] -> 
             RGBColor[
              0.602700789657427, 0.6868450128545692, 0.9628871876056561], 
             UndirectedEdge[127, 394] -> 
             RGBColor[
              0.348496932711213, 0.47627225997448197`, 0.9434268942819889], 
             UndirectedEdge[110, 385] -> 
             RGBColor[
              0.923690126192328, 0.9380306979900004, 0.809802069993292], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.18382719114068813`, 0.31054441157892615`, 0.933780058636279], 
             UndirectedEdge[97, 393] -> 
             RGBColor[
              0.5102982570407728, 0.6069665111134733, 0.9566203329382144], 
             UndirectedEdge[19, 150] -> 
             RGBColor[
              0.21895975804167556`, 0.3474709669252617, 0.9357808063473152], 
             UndirectedEdge[272, 342] -> 
             RGBColor[
              0.19152273141080622`, 0.31863291232825464`, 0.9342183082701306],
              UndirectedEdge[96, 187] -> 
             RGBColor[
              0.2139882194822336, 0.34224556468553763`, 0.9354976845810872], 
             UndirectedEdge[129, 333] -> 
             RGBColor[
              0.8865563472760825, 0.5573394921368233, 0.5646390445032476], 
             UndirectedEdge[19, 160] -> 
             RGBColor[
              0.19740416245689973`, 0.32481466926196517`, 0.9345532470674082],
              UndirectedEdge[183, 357] -> 
             RGBColor[
              0.18734376764879906`, 0.31424055645277915`, 0.9339803224661072],
              UndirectedEdge[197, 217] -> 
             RGBColor[
              0.19977926755688577`, 0.3273110553124115, 0.9346885057891993], 
             UndirectedEdge[199, 345] -> 
             RGBColor[
              0.9084097409587222, 0.9276827314255283, 0.9099029118424318], 
             UndirectedEdge[44, 346] -> 
             RGBColor[
              0.2158698080892293, 0.3442232336110982, 0.9356048382686947], 
             UndirectedEdge[78, 80] -> 
             RGBColor[
              0.21178615052788774`, 0.3399310505952844, 0.9353722800118063], 
             UndirectedEdge[42, 320] -> 
             RGBColor[
              0.18379681968568948`, 0.3105124892540611, 0.9337783290268474], 
             UndirectedEdge[161, 332] -> 
             RGBColor[
              0.848675629685056, 0.3418959366317691, 0.19294308456495457`], 
             UndirectedEdge[239, 309] -> 
             RGBColor[
              0.6022520031590326, 0.6871316854403461, 0.9624067531432969], 
             UndirectedEdge[8, 377] -> 
             RGBColor[
              0.25514638831763914`, 0.3855054097101751, 0.9378415814082092], 
             UndirectedEdge[75, 126] -> 
             RGBColor[
              0.18223452639463555`, 0.3088704199500476, 0.9336893587351277], 
             UndirectedEdge[54, 310] -> 
             RGBColor[
              0.8873852444618682, 0.5186875281092153, 0.22512385696518958`], 
             UndirectedEdge[65, 211] -> 
             RGBColor[
              0.3044915837808781, 0.4311065625226518, 0.9408810648238439], 
             UndirectedEdge[88, 356] -> 
             RGBColor[
              0.6878897223994248, 0.7529983724170004, 0.962990494071441], 
             UndirectedEdge[98, 158] -> 
             RGBColor[
              0.19219455973941713`, 0.31933904649800093`, 0.9342565678995641],
              UndirectedEdge[13, 390] -> 
             RGBColor[
              0.2131729075996141, 0.34138862020314553`, 0.9354512537755177], 
             UndirectedEdge[241, 242] -> 
             RGBColor[
              0.31065498243158685`, 0.4409219663646659, 0.9411098670507269], 
             UndirectedEdge[12, 238] -> 
             RGBColor[
              0.2218338423144311, 0.3504918117233956, 0.9359444811948219], 
             UndirectedEdge[175, 343] -> 
             RGBColor[
              0.19542826971397487`, 0.32273788071031545`, 0.93444072289877], 
             UndirectedEdge[59, 258] -> 
             RGBColor[
              0.2269624966999203, 0.35588235265801405`, 0.9362365504749113], 
             UndirectedEdge[152, 156] -> 
             RGBColor[
              0.20135778622096587`, 0.32897017851222354`, 0.9347784000919095],
              UndirectedEdge[39, 258] -> 
             RGBColor[
              0.21791338707223826`, 0.34637116469263174`, 0.9357212170685729],
              UndirectedEdge[183, 368] -> 
             RGBColor[
              0.18625851527578347`, 0.31309988739976513`, 0.933918518948951], 
             UndirectedEdge[44, 119] -> 
             RGBColor[
              0.23405162543822766`, 0.3633334764386976, 0.9366402658691317], 
             UndirectedEdge[149, 264] -> 
             RGBColor[
              0.23515256587011008`, 0.3644906346362611, 0.9367029627980321], 
             UndirectedEdge[120, 241] -> 
             RGBColor[
              0.34672955885014695`, 0.4721679512974918, 0.9434085071606221], 
             UndirectedEdge[116, 304] -> 
             RGBColor[
              0.26114585574207083`, 0.3918112303614577, 0.938183242202614], 
             UndirectedEdge[82, 256] -> 
             RGBColor[
              0.8760312800563814, 0.9016669835366705, 0.876948136427472], 
             UndirectedEdge[98, 186] -> 
             RGBColor[
              0.1999149394327242, 0.32745365505601143`, 0.9346962321018197], 
             UndirectedEdge[72, 262] -> 
             RGBColor[
              0.4149349676293397, 0.5334857796550911, 0.9477519352990894], 
             UndirectedEdge[147, 241] -> 
             RGBColor[
              0.2640632471374818, 0.3948775936913327, 0.9383493833266887], 
             UndirectedEdge[13, 205] -> 
             RGBColor[
              0.19925835051903662`, 0.3267635384775842, 0.9346588403345214], 
             UndirectedEdge[142, 394] -> 
             RGBColor[
              0.4158923670367568, 0.5340808989479011, 0.9478776312991117], 
             UndirectedEdge[42, 75] -> 
             RGBColor[
              0.18289766237674282`, 0.30956741791249204`, 0.9337271233482869],
              UndirectedEdge[56, 341] -> 
             RGBColor[
              0.38387079611477953`, 0.499652079122729, 0.9463702293168075], 
             UndirectedEdge[306, 378] -> 
             RGBColor[
              0.23126849430923743`, 0.36040822916142345`, 0.9364817706686093],
              UndirectedEdge[27, 295] -> 
             RGBColor[
              0.19546687096427723`, 0.32277845307184394`, 0.9344429211828693],
              UndirectedEdge[111, 247] -> 
             RGBColor[
              0.8219754147542075, 0.16991824425479435`, 0.1686769880272973], 
             UndirectedEdge[128, 259] -> 
             RGBColor[
              0.599663278641086, 0.6781009426487141, 0.9652528657581285], 
             UndirectedEdge[52, 68] -> 
             RGBColor[
              0.9052995090875355, 0.9251530264391655, 0.9074485213302443], 
             UndirectedEdge[241, 359] -> 
             RGBColor[
              0.3033005319170658, 0.43455191097441853`, 0.9406412479672268], 
             UndirectedEdge[361, 382] -> 
             RGBColor[
              0.3658350125936814, 0.49128963333144304`, 0.9445316614006376], 
             UndirectedEdge[14, 390] -> 
             RGBColor[
              0.27581610861732475`, 0.40446583032584077`, 0.9391199230263283],
              UndirectedEdge[11, 332] -> 
             RGBColor[
              0.8454988743714711, 0.5197931292132254, 0.5762252108529373], 
             UndirectedEdge[22, 209] -> 
             RGBColor[
              0.25353925279510015`, 0.38381620837770913`, 0.9377500574177445],
              UndirectedEdge[33, 156] -> 
             RGBColor[
              0.22423055163894667`, 0.35301090518360945`, 0.9360809702452394],
              UndirectedEdge[283, 332] -> 
             RGBColor[
              0.8748637305772158, 0.45283228980267326`, 0.21438239989975133`],
              UndirectedEdge[150, 181] -> 
             RGBColor[
              0.21526447072748034`, 0.3435869856632946, 0.9355703652014595], 
             UndirectedEdge[117, 323] -> 
             RGBColor[
              0.4895767347577772, 0.5956116976057565, 0.9532057157698048], 
             UndirectedEdge[199, 223] -> 
             RGBColor[
              0.9239760391061387, 0.7216129997514857, 0.5202901272072924], 
             UndirectedEdge[128, 306] -> 
             RGBColor[
              0.2631009453754704, 0.39386615352600307`, 0.9382945816649401], 
             UndirectedEdge[184, 288] -> 
             RGBColor[
              0.21364346222149755`, 0.3418832029456312, 0.9354780511651108], 
             UndirectedEdge[145, 182] -> 
             RGBColor[
              0.24585035887698375`, 0.3757346933657375, 0.937312186283807], 
             UndirectedEdge[284, 397] -> 
             RGBColor[
              0.5520222170780682, 0.6432815473581924, 0.9595663255932364], 
             UndirectedEdge[61, 148] -> 
             RGBColor[
              0.23690961095816437`, 0.3663374004268991, 0.9368030239164815], 
             UndirectedEdge[34, 159] -> 
             RGBColor[
              0.1825395439463383, 0.30919101273611693`, 0.9337067290334642], 
             UndirectedEdge[276, 382] -> 
             RGBColor[
              0.35057061271571854`, 0.4780683773681971, 0.9435590273381926], 
             UndirectedEdge[59, 164] -> 
             RGBColor[
              0.215632569168565, 0.3439738804636637, 0.9355913278631264], 
             UndirectedEdge[80, 377] -> 
             RGBColor[
              0.2289003475673298, 0.3579191567865028, 0.9363469082150169], 
             UndirectedEdge[180, 370] -> 
             RGBColor[
              0.18698550798658503`, 0.3138640028328177, 0.9339599201083417], 
             UndirectedEdge[98, 374] -> 
             RGBColor[
              0.18844266475489285`, 0.3153955669853844, 0.9340429030306268], 
             UndirectedEdge[139, 350] -> 
             RGBColor[
              0.3277444111277722, 0.4581308203867991, 0.942110663773315], 
             UndirectedEdge[36, 276] -> 
             RGBColor[
              0.31234957064668134`, 0.4391299345139409, 0.941337201922877], 
             UndirectedEdge[53, 281] -> 
             RGBColor[
              0.40067800773256046`, 0.5214688844608842, 0.9467518262404362], 
             UndirectedEdge[73, 183] -> 
             RGBColor[
              0.19359784833893534`, 0.3208139917897307, 0.9343364831093273], 
             UndirectedEdge[101, 115] -> 
             RGBColor[
              0.9045408089975616, 0.6377980714511916, 0.24102778506069641`], 
             UndirectedEdge[283, 366] -> 
             RGBColor[
              0.9626113006296535, 0.8779402128312055, 0.388106189025446], 
             UndirectedEdge[22, 141] -> 
             RGBColor[
              0.2988998919025237, 0.4271457198066904, 0.9404924581847806], 
             UndirectedEdge[197, 314] -> 
             RGBColor[
              0.18703267242257346`, 0.3139135756454394, 0.9339626060531978], 
             UndirectedEdge[13, 14] -> 
             RGBColor[
              0.27600611579144196`, 0.4046655399129887, 0.9391307436538039], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.18066543438157506`, 0.30722120475814135`, 0.9336000012662475],
              UndirectedEdge[323, 395] -> 
             RGBColor[
              0.42965137086591587`, 0.5465641553634234, 0.9485979833191546], 
             UndirectedEdge[93, 131] -> 
             RGBColor[
              0.5783198351360825, 0.6629059133309206, 0.9625766163950823], 
             UndirectedEdge[52, 105] -> 
             RGBColor[
              0.9871484754393005, 0.988953578572104, 0.8626465508576164], 
             UndirectedEdge[178, 330] -> 
             RGBColor[
              0.18585403499635023`, 0.3126747529805498, 0.9338954843954123], 
             UndirectedEdge[92, 98] -> 
             RGBColor[
              0.19880960071600262`, 0.32629187398221465`, 0.9346332846971046],
              UndirectedEdge[37, 323] -> 
             RGBColor[
              0.35247668459828785`, 0.4774620340320098, 0.9437631308877006], 
             UndirectedEdge[279, 370] -> 
             RGBColor[
              0.19229180160053655`, 0.3194412538595276, 0.9342621056796985], 
             UndirectedEdge[150, 160] -> 
             RGBColor[
              0.2168510680318782, 0.345254600026296, 0.9356607195707846], 
             UndirectedEdge[188, 273] -> 
             RGBColor[
              0.39992754574806544`, 0.5158532142548906, 0.9473461281045827], 
             UndirectedEdge[179, 386] -> 
             RGBColor[
              0.284370042597393, 0.41315352294311436`, 0.9396181524839584], 
             UndirectedEdge[141, 179] -> 
             RGBColor[
              0.2912900071166007, 0.41914724840212236`, 0.9400590865040379], 
             UndirectedEdge[117, 388] -> 
             RGBColor[
              0.4146565458770389, 0.527209517044103, 0.9485603887539554], 
             UndirectedEdge[198, 214] -> 
             RGBColor[
              0.8538594754790496, 0.7047084000192836, 0.6021070091036955], 
             UndirectedEdge[150, 238] -> 
             RGBColor[
              0.21964443169265407`, 0.3481906023432569, 0.9358197974988545], 
             UndirectedEdge[331, 392] -> 
             RGBColor[
              0.22201549227327083`, 0.35068273734740874`, 0.9359548258912509],
              UndirectedEdge[323, 365] -> 
             RGBColor[
              0.3633194234507374, 0.48885844003528395`, 0.9443806088249529], 
             UndirectedEdge[6, 71] -> 
             RGBColor[
              0.9479335881069795, 0.9604436363507414, 0.9644935461230137], 
             UndirectedEdge[132, 249] -> 
             RGBColor[
              0.18824799980109214`, 0.3151909617764689, 0.9340318171494888], 
             UndirectedEdge[348, 378] -> 
             RGBColor[
              0.22067056618642705`, 0.3492691347568969, 0.935878234340245], 
             UndirectedEdge[174, 198] -> 
             RGBColor[
              0.6233166189809511, 0.701327344471203, 0.9656888716580491], 
             UndirectedEdge[72, 236] -> 
             RGBColor[
              0.4875863338308316, 0.5948835771747154, 0.9528037287682061], 
             UndirectedEdge[9, 100] -> 
             RGBColor[
              0.5370355289675518, 0.6325732881317867, 0.9576495756744858], 
             UndirectedEdge[51, 298] -> 
             RGBColor[
              0.20333725610200998`, 0.3310507268628402, 0.9348911279732717], 
             UndirectedEdge[23, 128] -> 
             RGBColor[
              0.2579108106564282, 0.38841099286274205`, 0.9379990111708069], 
             UndirectedEdge[215, 353] -> 
             RGBColor[
              0.8496653857450382, 0.8791494975932964, 0.7395436178949295], 
             UndirectedEdge[80, 96] -> 
             RGBColor[
              0.2073679300463957, 0.3352872207378781, 0.9351206688915568], 
             UndirectedEdge[78, 388] -> 
             RGBColor[
              0.2456236030410635, 0.37549635860503494`, 0.9372992728744065], 
             UndirectedEdge[312, 380] -> 
             RGBColor[
              0.6340993587155315, 0.7126342355184634, 0.9651549462114524], 
             UndirectedEdge[57, 325] -> 
             RGBColor[
              0.29328547563165996`, 0.42193506719570584`, 0.9401474445490827],
              UndirectedEdge[308, 374] -> 
             RGBColor[
              0.1982421611639798, 0.32569545903529307`, 0.9346009698540684], 
             UndirectedEdge[76, 365] -> 
             RGBColor[
              0.2944759917270998, 0.42684331653440033`, 0.9400813441394438], 
             UndirectedEdge[182, 187] -> 
             RGBColor[
              0.22908739425404853`, 0.35811575471368917`, 0.9363575602471148],
              UndirectedEdge[74, 286] -> 
             RGBColor[
              0.28488862903471124`, 0.4156109198533938, 0.9395776654568602], 
             UndirectedEdge[137, 164] -> 
             RGBColor[
              0.2538187120761361, 0.3841099378008197, 0.9377659722103766], 
             UndirectedEdge[149, 258] -> 
             RGBColor[
              0.22398941258529487`, 0.35275745274912235`, 0.9360672377328672],
              UndirectedEdge[147, 331] -> 
             RGBColor[
              0.2440919709450002, 0.37388651616098867`, 0.9372120486923824], 
             UndirectedEdge[42, 367] -> 
             RGBColor[
              0.1849893429390042, 0.3117659068036362, 0.9338462414619436], 
             UndirectedEdge[16, 365] -> 
             RGBColor[
              0.2674853323456614, 0.39847442221786333`, 0.9385442660167731], 
             UndirectedEdge[113, 183] -> 
             RGBColor[
              0.18716623928349274`, 0.31405396288489373`, 0.9339702124883327],
              UndirectedEdge[16, 323] -> 
             RGBColor[
              0.3247877744177019, 0.4483592338539112, 0.9421862884149881], 
             UndirectedEdge[340, 343] -> 
             RGBColor[
              0.2360559349263153, 0.3654401327912391, 0.9367544083293682], 
             UndirectedEdge[323, 362] -> 
             RGBColor[
              0.6059463857156073, 0.6878046821697024, 0.9639263891716204], 
             UndirectedEdge[334, 364] -> 
             RGBColor[
              0.9407749655383337, 0.8016431292497415, 0.27774757447488835`], 
             UndirectedEdge[94, 324] -> 
             RGBColor[
              0.18239675869616345`, 0.30904093638507546`, 0.9336985976246985],
              UndirectedEdge[135, 350] -> 
             RGBColor[
              0.3419502599754641, 0.47060186109611535`, 0.9430097460842624], 
             UndirectedEdge[31, 215] -> 
             RGBColor[
              0.8451646800561206, 0.8790328648583385, 0.9409404903646027], 
             UndirectedEdge[3, 21] -> 
             RGBColor[
              0.21644166427209716`, 0.34482429071706844`, 0.9356374046323236],
              UndirectedEdge[127, 193] -> 
             RGBColor[
              0.5886484429999097, 0.6709855269816585, 0.9636243911098379], 
             UndirectedEdge[50, 230] -> 
             RGBColor[
              0.2261265468612622, 0.35500371637530337`, 0.9361889443682767], 
             UndirectedEdge[169, 382] -> 
             RGBColor[
              0.38967734439969204`, 0.5118336629702842, 0.9460804380697425], 
             UndirectedEdge[12, 19] -> 
             RGBColor[
              0.22114916866345258`, 0.3497721763054004, 0.9359054900432826], 
             UndirectedEdge[133, 296] -> 
             RGBColor[
              0.18124069831826523`, 0.30782584362944293`, 0.9336327616964153],
              UndirectedEdge[214, 332] -> 
             RGBColor[
              0.8483631502363858, 0.34047704043678684`, 0.1926823440534119], 
             UndirectedEdge[76, 395] -> 
             RGBColor[
              0.36080793914227827`, 0.4845490318625397, 0.9442987186336453], 
             UndirectedEdge[299, 370] -> 
             RGBColor[
              0.1869681936623269, 0.3138458043802308, 0.9339589340831895], 
             UndirectedEdge[170, 235] -> 
             RGBColor[
              0.21437654864384317`, 0.34265372325588017`, 0.9355197993523594],
              UndirectedEdge[46, 400] -> 
             RGBColor[
              0.81382584660932, 0.509501659616798, 0.5750314348940344], 
             UndirectedEdge[65, 329] -> 
             RGBColor[
              0.31941652727713654`, 0.4467936244332925, 0.9417310182764805], 
             UndirectedEdge[81, 267] -> 
             RGBColor[
              0.21336000502701669`, 0.3415852714620077, 0.9354619086972226], 
             UndirectedEdge[104, 182] -> 
             RGBColor[
              0.23293840827128548`, 0.36216341461419643`, 0.9365768697983317],
              UndirectedEdge[23, 306] -> 
             RGBColor[
              0.21710981978146196`, 0.345526564520917, 0.9356754551001344], 
             UndirectedEdge[209, 286] -> 
             RGBColor[
              0.29314447532730914`, 0.4242883377578022, 0.9400478236897936], 
             UndirectedEdge[150, 167] -> 
             RGBColor[
              0.2371065726737784, 0.3665444196781035, 0.936814240594807], 
             UndirectedEdge[4, 288] -> 
             RGBColor[
              0.2072894767278965, 0.33520476132590776`, 0.9351162010911295], 
             UndirectedEdge[171, 272] -> 
             RGBColor[
              0.19235235421379315`, 0.3195048984953177, 0.9342655540614437], 
             UndirectedEdge[78, 182] -> 
             RGBColor[
              0.23114667261114863`, 0.3602801868327903, 0.9364748331031223], 
             UndirectedEdge[143, 374] -> 
             RGBColor[
              0.1912700084764235, 0.3183672845006589, 0.9342039160728877], 
             UndirectedEdge[55, 262] -> 
             RGBColor[
              0.5840352729572464, 0.6682969151994234, 0.9627543260164191], 
             UndirectedEdge[165, 190] -> 
             RGBColor[
              0.21884661716031273`, 0.34735204868540315`, 0.9357743631414985],
              UndirectedEdge[2, 149] -> 
             RGBColor[
              0.20607580619388693`, 0.3339291166435074, 0.9350470843496823], 
             UndirectedEdge[39, 47] -> 
             RGBColor[
              0.18958921033534365`, 0.3166006590856267, 0.9341081971052712], 
             UndirectedEdge[230, 300] -> 
             RGBColor[
              0.2086431877242838, 0.3366275974133453, 0.9351932929297377], 
             UndirectedEdge[40, 48] -> 
             RGBColor[
              0.20069384731952558`, 0.3282723366306521, 0.934740589753682], 
             UndirectedEdge[25, 208] -> 
             RGBColor[
              0.3291899186131193, 0.4582247733572693, 0.9422451729560961], 
             UndirectedEdge[32, 52] -> 
             RGBColor[
              0.905256763296387, 0.5780630184234903, 0.500145144132204], 
             UndirectedEdge[161, 366] -> 
             RGBColor[
              0.9364231997374939, 0.7670038596603013, 0.3666668736906492], 
             UndirectedEdge[190, 318] -> 
             RGBColor[
              0.21280458260693721`, 0.34100148728268875`, 0.9354302782120729],
              UndirectedEdge[179, 245] -> 
             RGBColor[
              0.21085364957036085`, 0.33895093296494805`, 0.9353191754617867],
              UndirectedEdge[37, 182] -> 
             RGBColor[
              0.26307956528763465`, 0.3938436816981118, 0.9382933641005669], 
             UndirectedEdge[12, 206] -> 
             RGBColor[
              0.33583694364464667`, 0.4592083134506097, 0.9428435069438263], 
             UndirectedEdge[18, 218] -> 
             RGBColor[
              0.776406098847213, 0.8201699347730458, 0.6937389035902746], 
             UndirectedEdge[92, 119] -> 
             RGBColor[
              0.22208012665594387`, 0.3507506721816547, 0.9359585067237262], 
             UndirectedEdge[215, 400] -> 
             RGBColor[
              0.7640930948428964, 0.47065005595395515`, 0.5700745389769464], 
             UndirectedEdge[71, 292] -> 
             RGBColor[
              0.8945978800262582, 0.5638772618194792, 0.5512331862497395], 
             UndirectedEdge[158, 346] -> 
             RGBColor[
              0.19728326833036003`, 0.3246876018698416, 0.9345463623257486], 
             UndirectedEdge[92, 151] -> 
             RGBColor[
              0.20599136961110498`, 0.33384036844141496`, 0.9350422758112056],
              UndirectedEdge[104, 170] -> 
             RGBColor[
              0.22977658578143667`, 0.35884013870624076`, 0.936396808685032], 
             UndirectedEdge[82, 316] -> 
             RGBColor[
              0.7359499332008539, 0.7936489483339444, 0.9743162695644639], 
             UndirectedEdge[287, 353] -> 
             RGBColor[
              0.9052894000566567, 0.5610593594590743, 0.33598351095262347`], 
             UndirectedEdge[368, 372] -> 
             RGBColor[
              0.1818899475322301, 0.30850824571809776`, 0.9336697354786725], 
             UndirectedEdge[9, 203] -> 
             RGBColor[
              0.4981842108201723, 0.5989222290765547, 0.9551740040370065], 
             UndirectedEdge[17, 384] -> 
             RGBColor[
              0.8806232133780418, 0.49400904252402256`, 0.21977054774648136`],
              UndirectedEdge[82, 310] -> 
             RGBColor[
              0.7931376486603983, 0.5085364648564028, 0.5748575062936936], 
             UndirectedEdge[129, 287] -> 
             RGBColor[
              0.8183275809306592, 0.1418793949960282, 0.16518381823822845`], 
             UndirectedEdge[81, 363] -> 
             RGBColor[
              0.3018408929173706, 0.42850250201273, 0.940723448587576], 
             UndirectedEdge[64, 356] -> 
             RGBColor[
              0.9689844051155808, 0.9726683265613763, 0.7058319664887789], 
             UndirectedEdge[245, 352] -> 
             RGBColor[
              0.1906398234149592, 0.3177049200450192, 0.9341680279659126], 
             UndirectedEdge[87, 232] -> 
             RGBColor[
              0.18860427170948546`, 0.315565426141134, 0.9340521063076146], 
             UndirectedEdge[88, 255] -> 
             RGBColor[
              0.40229233650521606`, 0.5228671349052352, 0.9468546898423349], 
             UndirectedEdge[154, 392] -> 
             RGBColor[
              0.19471742420704347`, 0.3219907370123223, 0.934400241298752], 
             UndirectedEdge[22, 45] -> 
             RGBColor[
              0.24087710963769857`, 0.3705074930930349, 0.9370289670968927], 
             UndirectedEdge[116, 141] -> 
             RGBColor[
              0.29789401265983945`, 0.4260884769462017, 0.9404351748499746], 
             UndirectedEdge[97, 224] -> 
             RGBColor[
              0.3981861519254275, 0.5171684195208632, 0.946960633454442], 
             UndirectedEdge[66, 151] -> 
             RGBColor[
              0.20186975982558952`, 0.3295082952316844, 0.9348075562312959], 
             UndirectedEdge[165, 221] -> 
             RGBColor[
              0.29772616502322835`, 0.42460426174906063`, 0.9404735010185594],
              UndirectedEdge[101, 332] -> 
             RGBColor[
              0.8358893322460044, 0.27686671121426787`, 0.18200097113096422`],
              UndirectedEdge[58, 396] -> 
             RGBColor[
              0.18880077082680655`, 0.315771959172202, 0.9340632966416518], 
             UndirectedEdge[35, 387] -> 
             RGBColor[
              0.1878209095169145, 0.3147420628087102, 0.9340074949896282], 
             UndirectedEdge[198, 266] -> 
             RGBColor[0.74350964112616, 0.79962588641691, 0.9750508465456946],
              UndirectedEdge[188, 264] -> 
             RGBColor[
              0.26789407428573686`, 0.39890403591261847`, 0.9385675432655809],
              UndirectedEdge[119, 151] -> 
             RGBColor[
              0.22370106658388367`, 0.35245438281944674`, 0.9360508168546565],
              UndirectedEdge[247, 400] -> 
             RGBColor[
              0.8197269815986742, 0.15263580175167407`, 0.16652388589831657`],
              UndirectedEdge[305, 361] -> 
             RGBColor[
              0.353816749645949, 0.47989197268582956`, 0.9438020454927423], 
             UndirectedEdge[138, 210] -> 
             RGBColor[
              0.2672929528119248, 0.3982722191303392, 0.9385333102869269], 
             UndirectedEdge[197, 231] -> 
             RGBColor[
              0.19125913163260555`, 0.3183558522481745, 0.9342032966527232], 
             UndirectedEdge[225, 261] -> 
             RGBColor[
              0.19884280647751676`, 0.32632677534293286`, 0.9346351757160992],
              UndirectedEdge[83, 286] -> 
             RGBColor[
              0.6361141683386347, 0.7078159235332517, 0.9547721155282454], 
             UndirectedEdge[19, 238] -> 
             RGBColor[
              0.20019752611767563`, 0.32775067157892607`, 0.9347123249954781],
              UndirectedEdge[62, 117] -> 
             RGBColor[
              0.7751677288121797, 0.821679420316278, 0.8719418433976884], 
             UndirectedEdge[65, 167] -> 
             RGBColor[
              0.30615029923372655`, 0.43284997763222943`, 0.940975526215034], 
             UndirectedEdge[268, 371] -> 
             RGBColor[
              0.1838466718007321, 0.3105648869877775, 0.9337811680310495], 
             UndirectedEdge[172, 192] -> 
             RGBColor[
              0.31894488906729196`, 0.44600858518137365`, 0.9417147525123752],
              UndirectedEdge[52, 353] -> 
             RGBColor[
              0.9911272301605415, 0.9888543711683995, 0.6698997566881519], 
             UndirectedEdge[126, 298] -> 
             RGBColor[
              0.194012535572622, 0.32124985436502457`, 0.9343600989338109], 
             UndirectedEdge[146, 306] -> 
             RGBColor[
              0.2107146293415335, 0.33880481389005895`, 0.9353112584654169], 
             UndirectedEdge[21, 132] -> 
             RGBColor[
              0.1947709663990963, 0.3220470132509409, 0.9344032904473808], 
             UndirectedEdge[89, 162] -> 
             RGBColor[
              0.2137613905296329, 0.342007153074568, 0.9354847670077999], 
             UndirectedEdge[9, 18] -> 
             RGBColor[
              0.8394473584119997, 0.8706756474406323, 0.6991625748728455], 
             UndirectedEdge[255, 360] -> 
             RGBColor[
              0.5184721491114823, 0.6174970812936685, 0.956042445038614], 
             UndirectedEdge[124, 152] -> 
             RGBColor[
              0.2137312689052459, 0.34197549333751603`, 0.935483051625852], 
             UndirectedEdge[88, 389] -> 
             RGBColor[
              0.7117595806289345, 0.7674543626326005, 0.720767374949669], 
             UndirectedEdge[12, 167] -> 
             RGBColor[
              0.2392959832955554, 0.36884562905824225`, 0.9369389242907744], 
             UndirectedEdge[32, 303] -> 
             RGBColor[
              0.857724462248068, 0.3888260026114282, 0.20072238804006853`], 
             UndirectedEdge[49, 261] -> 
             RGBColor[
              0.1864507904031121, 0.31330198074953464`, 0.9339294687330069], 
             UndirectedEdge[283, 360] -> 
             RGBColor[
              0.7973390261209754, 0.7521357532053826, 0.6155512086405578], 
             UndirectedEdge[282, 305] -> 
             RGBColor[
              0.30654149170312617`, 0.4389445203793095, 0.9407897078604948], 
             UndirectedEdge[32, 385] -> 
             RGBColor[
              0.907968224972722, 0.5784385570350095, 0.40100320095353803`], 
             UndirectedEdge[167, 216] -> 
             RGBColor[
              0.22581143984224178`, 0.35467251891937396`, 0.9361709994897025],
              UndirectedEdge[252, 318] -> 
             RGBColor[
              0.20969889594004104`, 0.3377372136838731, 0.9352534139508448], 
             UndirectedEdge[2, 217] -> 
             RGBColor[
              0.20503618363244414`, 0.3328364074155535, 0.9349878793827919], 
             UndirectedEdge[305, 329] -> 
             RGBColor[
              0.28019918973537505`, 0.41183749243956935`, 0.9392683013866509],
              UndirectedEdge[87, 373] -> 
             RGBColor[
              0.19241687464340246`, 0.3195727135576686, 0.9342692284044607], 
             UndirectedEdge[20, 241] -> 
             RGBColor[
              0.33276855688740864`, 0.46007563309772936`, 0.9425189244607857],
              UndirectedEdge[59, 210] -> 
             RGBColor[
              0.23097654198013617`, 0.36010136875269116`, 0.9364651444153718],
              UndirectedEdge[290, 304] -> 
             RGBColor[
              0.2699001201696922, 0.4010125173273108, 0.9386817846109934], 
             UndirectedEdge[115, 312] -> 
             RGBColor[
              0.7514622050621471, 0.7517529361696669, 0.6201411074573389], 
             UndirectedEdge[214, 389] -> 
             RGBColor[
              0.9360223295752915, 0.7653959046667461, 0.35678534949539953`], 
             UndirectedEdge[144, 276] -> 
             RGBColor[
              0.48015124453344243`, 0.5868307576532874, 0.952775625742377], 
             UndirectedEdge[196, 286] -> 
             RGBColor[
              0.5826840049020053, 0.6656063435828412, 0.963342437992916], 
             UndirectedEdge[124, 181] -> 
             RGBColor[
              0.209370470104526, 0.33739201730734614`, 0.9352347105853747], 
             UndirectedEdge[216, 341] -> 
             RGBColor[
              0.2325799518711988, 0.3617866542102568, 0.9365564562366354], 
             UndirectedEdge[294, 340] -> 
             RGBColor[
              0.24056246391472638`, 0.3701767804885, 0.937011048488446], 
             UndirectedEdge[104, 235] -> 
             RGBColor[
              0.20864915250350596`, 0.3366338667744967, 0.9351936326150905], 
             UndirectedEdge[125, 318] -> 
             RGBColor[
              0.20302734583193666`, 0.33072499151954715`, 0.9348734790418622],
              UndirectedEdge[109, 232] -> 
             RGBColor[
              0.18655512715268852`, 0.3134116452886715, 0.9339354105565427], 
             UndirectedEdge[182, 388] -> 
             RGBColor[
              0.2563045573313864, 0.38672271877578024`, 0.9379075374201846], 
             UndirectedEdge[97, 382] -> 
             RGBColor[
              0.3103603612224796, 0.44230450028690405`, 0.9410311290958356], 
             UndirectedEdge[140, 147] -> 
             RGBColor[
              0.32678087214865287`, 0.45177394646584723`, 0.9422514665551494],
              UndirectedEdge[59, 300] -> 
             RGBColor[
              0.20621668709807878`, 0.3340771914061782, 0.9350551073087614], 
             UndirectedEdge[205, 373] -> 
             RGBColor[
              0.19156946915989134`, 0.31868203666588757`, 0.9342209699157987],
              UndirectedEdge[215, 259] -> 
             RGBColor[
              0.8007477962042493, 0.8448792898490222, 0.9806129038326282], 
             UndirectedEdge[136, 300] -> 
             RGBColor[
              0.18939860406094253`, 0.3164003198060953, 0.9340973423599207], 
             UndirectedEdge[152, 245] -> 
             RGBColor[
              0.19786899137363773`, 0.3253032339253123, 0.9345797183865636], 
             UndirectedEdge[44, 128] -> 
             RGBColor[
              0.26610768174908467`, 0.39702642409276845`, 0.9384658108533496],
              UndirectedEdge[241, 392] -> 
             RGBColor[
              0.24198676846575243`, 0.37167381487775275`, 0.9370921605255572],
              UndirectedEdge[240, 342] -> 
             RGBColor[
              0.18286346184170274`, 0.30953147098172573`, 0.9337251756784115],
              UndirectedEdge[123, 214] -> 
             RGBColor[
              0.8610395973659686, 0.437913767929313, 0.20482132414069976`], 
             UndirectedEdge[125, 274] -> 
             RGBColor[
              0.19786901158433057`, 0.32530325516803194`, 0.9345797195375327],
              UndirectedEdge[298, 373] -> 
             RGBColor[
              0.20172543232639267`, 0.32935659787913657`, 0.93479933699373], 
             UndirectedEdge[119, 350] -> 
             RGBColor[
              0.2941675459212899, 0.42283940615857285`, 0.9401985109723265], 
             UndirectedEdge[22, 179] -> 
             RGBColor[
              0.2344230766191157, 0.3637238951811761, 0.9366614194643705], 
             UndirectedEdge[1, 183] -> 
             RGBColor[
              0.18524860197516257`, 0.312038404488611, 0.9338610058805135], 
             UndirectedEdge[112, 260] -> 
             RGBColor[
              0.18468581634927816`, 0.3114468811131368, 0.9338289560716861], 
             UndirectedEdge[183, 270] -> 
             RGBColor[
              0.198314467229445, 0.32577145729456636`, 0.9346050875775294], 
             UndirectedEdge[152, 181] -> 
             RGBColor[
              0.1964830766390266, 0.32384654966716653`, 0.9345007925927047], 
             UndirectedEdge[169, 276] -> 
             RGBColor[
              0.41815198956691846`, 0.5364969694368562, 0.947894817280658], 
             UndirectedEdge[349, 355] -> 
             RGBColor[
              0.20327760071832918`, 0.33098802527222193`, 0.9348877306874234],
              UndirectedEdge[171, 240] -> 
             RGBColor[
              0.18369308464468964`, 0.3104034571487888, 0.9337724214697247], 
             UndirectedEdge[114, 132] -> 
             RGBColor[
              0.1897759122485969, 0.31679689463404087`, 0.9341188295030303], 
             UndirectedEdge[17, 222] -> 
             RGBColor[
              0.88937458998013, 0.5883335736307327, 0.570901233962067], 
             UndirectedEdge[46, 259] -> 
             RGBColor[
              0.850480547970673, 0.8837308935118651, 0.9855697997497163], 
             UndirectedEdge[13, 79] -> 
             RGBColor[
              0.20620705634176517`, 0.33406706887066745`, 0.9350545588514367],
              UndirectedEdge[146, 311] -> 
             RGBColor[
              0.20086274150294195`, 0.3284498551259324, 0.9347502080275711], 
             UndirectedEdge[44, 275] -> 
             RGBColor[
              0.21122882729611786`, 0.33934526854236047`, 0.9353405412782427],
              UndirectedEdge[193, 195] -> 
             RGBColor[
              0.6312732042379722, 0.7079049527832757, 0.9663404032043308], 
             UndirectedEdge[86, 297] -> 
             RGBColor[
              0.28232965171394053`, 0.4140767430581329, 0.9393896280445941], 
             UndirectedEdge[197, 392] -> 
             RGBColor[
              0.19718685275102665`, 0.3245862629828614, 0.9345408716011396], 
             UndirectedEdge[217, 392] -> 
             RGBColor[
              0.20565454435776198`, 0.333486343744197, 0.935023094111316], 
             UndirectedEdge[101, 193] -> 
             RGBColor[
              0.8459509404020927, 0.6447383034706259, 0.5918610769410064], 
             UndirectedEdge[216, 340] -> 
             RGBColor[
              0.2436041993290528, 0.3733738372661213, 0.9371842708204476], 
             UndirectedEdge[125, 190] -> 
             RGBColor[
              0.20237543357367466`, 0.3300397904024893, 0.934836353603172], 
             UndirectedEdge[99, 276] -> 
             RGBColor[
              0.6406056746670367, 0.7137792263922267, 0.9679520038982681], 
             UndirectedEdge[27, 63] -> 
             RGBColor[
              0.1971785692903057, 0.32457755654044196`, 0.9345403998703059], 
             UndirectedEdge[184, 226] -> 
             RGBColor[
              0.20272879549405032`, 0.3304111961852439, 0.9348564770417853], 
             UndirectedEdge[107, 211] -> 
             RGBColor[
              0.2277850924450354, 0.3567469529417126, 0.9362833960856742], 
             UndirectedEdge[216, 294] -> 
             RGBColor[
              0.21277466253925434`, 0.3409700393945122, 0.9354285743084811], 
             UndirectedEdge[68, 284] -> 
             RGBColor[
              0.7807346086845934, 0.8286481739482061, 0.9787765120052747], 
             UndirectedEdge[89, 359] -> 
             RGBColor[
              0.2789577626844565, 0.40896611709023306`, 0.9392549632713296], 
             UndirectedEdge[23, 267] -> 
             RGBColor[
              0.20474185831720654`, 0.33252705284793593`, 0.9349711179915043],
              UndirectedEdge[140, 242] -> 
             RGBColor[
              0.3733726074427579, 0.4978183191391804, 0.9450119502791875], 
             UndirectedEdge[64, 214] -> 
             RGBColor[
              0.9357533158900353, 0.7648205115954387, 0.32750487001527717`], 
             UndirectedEdge[296, 367] -> 
             RGBColor[
              0.18258473603098674`, 0.3092385124824261, 0.9337093026558292], 
             UndirectedEdge[275, 346] -> 
             RGBColor[
              0.1987852081376144, 0.3262662358357499, 0.9346318955758508], 
             UndirectedEdge[301, 305] -> 
             RGBColor[
              0.27396377293596785`, 0.4052836740351331, 0.9389132036243971], 
             UndirectedEdge[81, 119] -> 
             RGBColor[
              0.2344729010553813, 0.363776263822743, 0.9366642568923073], 
             UndirectedEdge[327, 355] -> 
             RGBColor[
              0.19695189529636073`, 0.3243393078008444, 0.9345274911216848], 
             UndirectedEdge[317, 344] -> 
             RGBColor[
              0.19003331843460333`, 0.31706744485602845`, 0.9341334884045249],
              UndirectedEdge[184, 190] -> 
             RGBColor[
              0.21285282401079259`, 0.34105219205682236`, 0.9354330254886557],
              UndirectedEdge[10, 303] -> 
             RGBColor[
              0.8684485783796092, 0.4712562585361081, 0.21099181375878928`], 
             UndirectedEdge[149, 268] -> 
             RGBColor[
              0.19899317290676588`, 0.326484819993856, 0.9346437388617977], 
             UndirectedEdge[38, 267] -> 
             RGBColor[
              0.22814489442186137`, 0.3571251276321197, 0.9363038862759752], 
             UndirectedEdge[253, 366] -> 
             RGBColor[
              0.9092462276793383, 0.5913616030865398, 0.3419442339894627], 
             UndirectedEdge[165, 355] -> 
             RGBColor[
              0.2168405199897158, 0.34524351336519876`, 0.9356601188753879], 
             UndirectedEdge[339, 340] -> 
             RGBColor[
              0.326674769743479, 0.4539173667672604, 0.9421628597566036], 
             UndirectedEdge[185, 318] -> 
             RGBColor[
              0.20300306708120197`, 0.33069947301316327`, 0.9348720964029251],
              UndirectedEdge[36, 70] -> 
             RGBColor[
              0.22130912604082534`, 0.3499403016509027, 0.9359145993792883], 
             UndirectedEdge[69, 131] -> 
             RGBColor[
              0.693464422361174, 0.75939366397809, 0.9708100489116116], 
             UndirectedEdge[283, 312] -> 
             RGBColor[
              0.7398695405352704, 0.7057918843470511, 0.6108133774642039], 
             UndirectedEdge[75, 330] -> 
             RGBColor[
              0.18530504232011252`, 0.31209772686967785`, 0.9338642200746624],
              UndirectedEdge[169, 222] -> 
             RGBColor[
              0.7041731063901011, 0.7666519834125803, 0.9590482629072343], 
             UndirectedEdge[90, 246] -> 
             RGBColor[
              0.21613530957472, 0.3445022925061154, 0.9356199581855191], 
             UndirectedEdge[62, 362] -> 
             RGBColor[
              0.8915373797700097, 0.913872404880224, 0.882662516799504], 
             UndirectedEdge[158, 374] -> 
             RGBColor[
              0.1873884527454699, 0.3142875233225789, 0.9339828672162569], 
             UndirectedEdge[82, 172] -> 
             RGBColor[
              0.5696909718954926, 0.6577404259092337, 0.9610497684809419], 
             UndirectedEdge[306, 346] -> 
             RGBColor[
              0.21286307171561503`, 0.3410629630443328, 0.9354336090802852], 
             UndirectedEdge[53, 188] -> 
             RGBColor[
              0.33920701496392514`, 0.465180569896386, 0.9429464497347737], 
             UndirectedEdge[84, 190] -> 
             RGBColor[
              0.21321988075352158`, 0.3414379919661722, 0.9354539288271424], 
             UndirectedEdge[78, 96] -> 
             RGBColor[
              0.2160474978393337, 0.3444099968046388, 0.9356149574370947], 
             UndirectedEdge[46, 199] -> 
             RGBColor[
              0.8971361136435547, 0.9188102209856679, 0.9087966349847089], 
             UndirectedEdge[159, 265] -> 
             RGBColor[
              0.19056897353088317`, 0.3176304523247132, 0.9341639931698273], 
             UndirectedEdge[332, 356] -> 
             RGBColor[
              0.8815942394619314, 0.5483248554027244, 0.5710094405269136], 
             UndirectedEdge[199, 222] -> 
             RGBColor[
              0.9699116219534045, 0.9763258350817114, 0.9020107810264453], 
             UndirectedEdge[114, 300] -> 
             RGBColor[
              0.19141939910096473`, 0.3185243035189643, 0.9342124236479517], 
             UndirectedEdge[139, 213] -> 
             RGBColor[
              0.3161784578429658, 0.4481129729732145, 0.941373691457378], 
             UndirectedEdge[106, 369] -> 
             RGBColor[
              0.18346224485360668`, 0.3101608298922725, 0.9337592754851194], 
             UndirectedEdge[109, 114] -> 
             RGBColor[
              0.18471405231964982`, 0.3114765589082613, 0.9338305640684275], 
             UndirectedEdge[58, 245] -> 
             RGBColor[
              0.1940488178607217, 0.32128798935024727`, 0.9343621651564433], 
             UndirectedEdge[151, 317] -> 
             RGBColor[
              0.1980582216182819, 0.3255021269103238, 0.9345904947690551], 
             UndirectedEdge[99, 218] -> 
             RGBColor[
              0.7312212189545854, 0.7893616865114603, 0.9745283770409688], 
             UndirectedEdge[55, 57] -> 
             RGBColor[
              0.5760181454967422, 0.6613528823456771, 0.9622434817439033], 
             UndirectedEdge[247, 287] -> 
             RGBColor[
              0.8173288724441594, 0.1342028839319411, 0.1642274538636763], 
             UndirectedEdge[44, 66] -> 
             RGBColor[
              0.21222031867993352`, 0.3403873888509353, 0.9353970052457711], 
             UndirectedEdge[116, 290] -> 
             RGBColor[
              0.24877546734729164`, 0.3788091678306199, 0.9374787668838809], 
             UndirectedEdge[278, 367] -> 
             RGBColor[
              0.18709347932173553`, 0.31397748755183885`, 0.9339660689161493],
              UndirectedEdge[102, 297] -> 
             RGBColor[
              0.32279739953618347`, 0.45288594084814915`, 0.9418305958510031],
              UndirectedEdge[104, 187] -> 
             RGBColor[
              0.2201981756238625, 0.34877262232435, 0.935851332396546], 
             UndirectedEdge[136, 371] -> 
             RGBColor[
              0.1813347042579621, 0.3079246498323852, 0.9336381151956117], 
             UndirectedEdge[80, 302] -> 
             RGBColor[
              0.1989040089899044, 0.3263911030639157, 0.9346386611086387], 
             UndirectedEdge[176, 373] -> 
             RGBColor[
              0.192094835712424, 0.3192342302227627, 0.9342508887637553], 
             UndirectedEdge[112, 219] -> 
             RGBColor[
              0.17968380010062157`, 0.30618944488965105`, 0.933544098646145], 
             UndirectedEdge[33, 179] -> 
             RGBColor[
              0.23670129905445042`, 0.3661184514083582, 0.9367911608617348], 
             UndirectedEdge[123, 334] -> 
             RGBColor[
              0.9016847000711192, 0.6050909598648562, 0.2444456182077174], 
             UndirectedEdge[94, 307] -> 
             RGBColor[
              0.17906784709075121`, 0.30554203922260087`, 0.9335090210334537],
              UndirectedEdge[73, 89] -> 
             RGBColor[
              0.21536881746289013`, 0.3436966606981754, 0.9355763075936738], 
             UndirectedEdge[267, 311] -> 
             RGBColor[
              0.20008010519765723`, 0.3276272547470704, 0.9347056380477918], 
             UndirectedEdge[52, 391] -> 
             RGBColor[
              0.904614436704831, 0.5731258147714826, 0.49953005146272567`], 
             UndirectedEdge[105, 271] -> 
             RGBColor[
              0.9026525217316504, 0.5714728168582255, 0.530015287474555], 
             UndirectedEdge[187, 377] -> 
             RGBColor[
              0.2355206370031677, 0.36487750073416236`, 0.9367239239045473], 
             UndirectedEdge[58, 124] -> 
             RGBColor[
              0.20991109539232988`, 0.337960248762451, 0.9352654983957317], 
             UndirectedEdge[11, 54] -> 
             RGBColor[
              0.9107233154962703, 0.8671374351819781, 0.6324945514745149], 
             UndirectedEdge[115, 283] -> 
             RGBColor[
              0.9435152073287729, 0.813763650039597, 0.2734092138294835], 
             UndirectedEdge[292, 362] -> 
             RGBColor[
              0.8053813952545528, 0.4938474279364584, 0.5730644519337977], 
             UndirectedEdge[15, 154] -> 
             RGBColor[
              0.18425132424679044`, 0.31099020236503183`, 0.933804212389223], 
             UndirectedEdge[158, 311] -> 
             RGBColor[
              0.19686826327665763`, 0.3242514052455602, 0.9345227284018851], 
             UndirectedEdge[123, 253] -> 
             RGBColor[
              0.8341751047564834, 0.26369040755053386`, 0.1803594249510559], 
             UndirectedEdge[236, 376] -> 
             RGBColor[
              0.397907468442853, 0.5154535439144465, 0.9470741986312354], 
             UndirectedEdge[206, 386] -> 
             RGBColor[
              0.3854076478953393, 0.5082424662804851, 0.9457788124146576], 
             UndirectedEdge[74, 338] -> 
             RGBColor[
              0.22933498443170014`, 0.35837598768852497`, 0.9363716601414551],
              UndirectedEdge[293, 394] -> 
             RGBColor[
              0.3358774325095808, 0.4653418831743506, 0.9426227908881267], 
             UndirectedEdge[41, 381] -> 
             RGBColor[
              0.19207190760239157`, 0.31921013132539244`, 0.934249583041808], 
             UndirectedEdge[59, 328] -> 
             RGBColor[
              0.22381201159438807`, 0.3525709930598068, 0.9360571350088763], 
             UndirectedEdge[123, 196] -> 
             RGBColor[
              0.8436412079731275, 0.6056407490965849, 0.5869779142171753], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.9124649507944522, 0.7523588106461282, 0.5992692091287142], 
             UndirectedEdge[23, 38] -> 
             RGBColor[
              0.23532272116707456`, 0.36466947864183974`, 0.936712652890472], 
             UndirectedEdge[61, 282] -> 
             RGBColor[
              0.2661448795948803, 0.3964851197604022, 0.9384891805623623], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.2249471629490288, 0.3537641091062871, 0.9361217801992172], 
             UndirectedEdge[3, 232] -> 
             RGBColor[
              0.21328768495463646`, 0.3415092584805786, 0.9354577901760884], 
             UndirectedEdge[110, 362] -> 
             RGBColor[
              0.8221167873663267, 0.8612297040031928, 0.982833840996466], 
             UndirectedEdge[125, 252] -> 
             RGBColor[
              0.19926974690677848`, 0.32677551680367367`, 0.934659489341944], 
             UndirectedEdge[49, 327] -> 
             RGBColor[
              0.18473066760764006`, 0.3114940226294092, 0.9338315102844983], 
             UndirectedEdge[89, 291] -> 
             RGBColor[
              0.2138432095506144, 0.34209315005324514`, 0.9354894264800044], 
             UndirectedEdge[34, 250] -> 
             RGBColor[
              0.1883288985198916, 0.31527599145920215`, 0.9340364242118455], 
             UndirectedEdge[125, 226] -> 
             RGBColor[
              0.1922514050569324, 0.3193987945309108, 0.9342598051563016], 
             UndirectedEdge[3, 14] -> 
             RGBColor[
              0.28743237026540935`, 0.41667525783150516`, 0.9397814519424676],
              UndirectedEdge[105, 345] -> 
             RGBColor[
              0.9066930101053883, 0.9269728190997042, 0.9383535848392048], 
             UndirectedEdge[88, 336] -> 
             RGBColor[
              0.33259846324686315`, 0.4556650882287947, 0.9426641835505155], 
             UndirectedEdge[162, 357] -> 
             RGBColor[
              0.1906502583880034, 0.3177158878633042, 0.9341686222221902], 
             UndirectedEdge[279, 328] -> 
             RGBColor[
              0.215194282730263, 0.3435132136280431, 0.9355663680988517], 
             UndirectedEdge[312, 359] -> 
             RGBColor[
              0.4367530973615871, 0.5501494570425497, 0.9497594529493274], 
             UndirectedEdge[202, 289] -> 
             RGBColor[
              0.4009029468034172, 0.5210963292936249, 0.9469229296248474], 
             UndirectedEdge[27, 48] -> 
             RGBColor[
              0.20648582903789775`, 0.33436007664951256`, 0.9350704345440743],
              UndirectedEdge[115, 193] -> 
             RGBColor[
              0.8965180032601808, 0.866664933881647, 0.6335702357029284], 
             UndirectedEdge[117, 385] -> 
             RGBColor[
              0.776474593776608, 0.8214741220909348, 0.7960777027150834], 
             UndirectedEdge[179, 352] -> 
             RGBColor[
              0.20659936567779108`, 0.3344794108566792, 0.9350769002877538], 
             UndirectedEdge[8, 365] -> 
             RGBColor[
              0.2808078228071327, 0.4124772043875522, 0.9393029621396956], 
             UndirectedEdge[105, 353] -> 
             RGBColor[
              0.9892810453920724, 0.988090926321853, 0.7004958160747115], 
             UndirectedEdge[231, 392] -> 
             RGBColor[
              0.1971344084334818, 0.32453114067996, 0.9345378849748398], 
             UndirectedEdge[109, 132] -> 
             RGBColor[
              0.1878121680467173, 0.3147328749692917, 0.9340069971758325], 
             UndirectedEdge[23, 158] -> 
             RGBColor[
              0.20153001639620693`, 0.3291512033464258, 0.9347882083455978], 
             UndirectedEdge[105, 350] -> 
             RGBColor[
              0.6669237794423443, 0.7322521297415084, 0.9183362922108259], 
             UndirectedEdge[172, 351] -> 
             RGBColor[
              0.3445890788111915, 0.47288747334073133`, 0.943177889287059], 
             UndirectedEdge[34, 375] -> 
             RGBColor[
              0.19286667153168213`, 0.3200454786060204, 0.9342948436718334], 
             UndirectedEdge[32, 391] -> 
             RGBColor[
              0.8208765397934485, 0.16147180977632267`, 0.16762470412387276`],
              UndirectedEdge[140, 241] -> 
             RGBColor[
              0.343629032390773, 0.46948243111537313`, 0.9432109443563187], 
             UndirectedEdge[89, 336] -> 
             RGBColor[
              0.23351345559029374`, 0.36276782580657996`, 0.9366096178924429],
              UndirectedEdge[74, 118] -> 
             RGBColor[
              0.3029906205258713, 0.4312899550504897, 0.9407311083477143], 
             UndirectedEdge[138, 328] -> 
             RGBColor[
              0.2601284224261766, 0.3907418434374549, 0.9381253008804314], 
             UndirectedEdge[189, 207] -> 
             RGBColor[
              0.2123454769342431, 0.3405189381117063, 0.935404132823199], 
             UndirectedEdge[273, 281] -> 
             RGBColor[
              0.46139853851670076`, 0.5721415288193888, 0.9511515046102453], 
             UndirectedEdge[49, 225] -> 
             RGBColor[
              0.19609003670444464`, 0.3234334397757498, 0.9344784095498806], 
             UndirectedEdge[43, 159] -> 
             RGBColor[
              0.1884193222929882, 0.31537103257792504`, 0.9340415737119533], 
             UndirectedEdge[113, 368] -> 
             RGBColor[
              0.18474082389280244`, 0.3115046975290605, 0.9338320886699134], 
             UndirectedEdge[11, 83] -> 
             RGBColor[0.9120888802991098, 0.9323447493793293, 0.977810506555],
              UndirectedEdge[151, 344] -> 
             RGBColor[
              0.1995874063553662, 0.3271093970249116, 0.9346775795776059], 
             UndirectedEdge[182, 377] -> 
             RGBColor[
              0.2482608696505907, 0.3782682930240088, 0.9374494613063329], 
             UndirectedEdge[198, 203] -> 
             RGBColor[
              0.5694035624452959, 0.6546305646490294, 0.9622535793690412], 
             UndirectedEdge[208, 395] -> 
             RGBColor[
              0.366549438606146, 0.4905837118311563, 0.9446256885343254], 
             UndirectedEdge[305, 339] -> 
             RGBColor[
              0.3400084902177303, 0.4679319523924049, 0.9429221954121405], 
             UndirectedEdge[9, 313] -> 
             RGBColor[
              0.4854882204226317, 0.5856947625868548, 0.9544467086526902], 
             UndirectedEdge[267, 317] -> 
             RGBColor[
              0.1930340826347562, 0.32022143828982824`, 0.9343043774864909], 
             UndirectedEdge[306, 350] -> 
             RGBColor[
              0.2854226113571807, 0.41364792547081863`, 0.9397004998858718], 
             UndirectedEdge[111, 362] -> 
             RGBColor[
              0.8089414952642664, 0.5212119166568898, 0.5764736077236575], 
             UndirectedEdge[104, 261] -> 
             RGBColor[
              0.20662637490864183`, 0.3345077992707875, 0.9350784384234943], 
             UndirectedEdge[243, 363] -> 
             RGBColor[
              0.302959879941956, 0.42967862832344433`, 0.9407871732432331], 
             UndirectedEdge[154, 369] -> 
             RGBColor[
              0.183389073095449, 0.31008392173509136`, 0.9337551084617403], 
             UndirectedEdge[218, 282] -> 
             RGBColor[
              0.4376499441056336, 0.5505879476107286, 0.9499100761220066], 
             UndirectedEdge[7, 293] -> 
             RGBColor[
              0.28453912176058604`, 0.41590127160719004`, 0.9395336796939777],
              UndirectedEdge[24, 167] -> 
             RGBColor[
              0.24799412206051685`, 0.37798792439406714`, 0.9374342704256958],
              UndirectedEdge[326, 363] -> 
             RGBColor[
              0.3080486907375876, 0.43502729111889293`, 0.9410769734898234], 
             UndirectedEdge[276, 282] -> 
             RGBColor[
              0.3470343998180849, 0.475005487491495, 0.9433337029793059], 
             UndirectedEdge[337, 345] -> 
             RGBColor[
              0.8925314756364031, 0.9165956294995268, 0.9705858474056119], 
             UndirectedEdge[107, 124] -> 
             RGBColor[
              0.22484989821780513`, 0.3536618777068309, 0.9361162411166642], 
             UndirectedEdge[128, 227] -> 
             RGBColor[
              0.28894688934847723`, 0.42103187936912945`, 0.9397664699385552],
              UndirectedEdge[25, 365] -> 
             RGBColor[
              0.33498940880084865`, 0.4643204052534886, 0.9425754453427104], 
             UndirectedEdge[97, 363] -> 
             RGBColor[
              0.3365752811245841, 0.4650105463059218, 0.9427015206110543], 
             UndirectedEdge[13, 373] -> 
             RGBColor[
              0.2056740334145861, 0.3335068279785967, 0.9350242039842707], 
             UndirectedEdge[64, 195] -> 
             RGBColor[
              0.7086017617355334, 0.7643768316855696, 0.6913028233561538], 
             UndirectedEdge[77, 96] -> 
             RGBColor[
              0.20429069166020342`, 0.3320528480858075, 0.9349454247178293], 
             UndirectedEdge[6, 53] -> 
             RGBColor[
              0.6643840547861006, 0.7335496374888852, 0.969847038397682], 
             UndirectedEdge[216, 343] -> 
             RGBColor[
              0.20826813355084325`, 0.33623339169725125`, 0.9351719341494034],
              UndirectedEdge[26, 324] -> 
             RGBColor[
              0.1839722969253371, 0.31069692695883033`, 0.9337883221960501], 
             UndirectedEdge[142, 281] -> 
             RGBColor[
              0.436455413320613, 0.55189157611022, 0.9491878904251312], 
             UndirectedEdge[100, 341] -> 
             RGBColor[
              0.3185278490681524, 0.4448223795517722, 0.9417183858910539], 
             UndirectedEdge[115, 364] -> 
             RGBColor[
              0.9382231077008898, 0.7927822385027005, 0.26915106624734497`], 
             UndirectedEdge[150, 152] -> 
             RGBColor[
              0.21962526952820027`, 0.3481704616934645, 0.9358187062419367], 
             UndirectedEdge[10, 68] -> 
             RGBColor[
              0.8322857283076943, 0.5959292773686855, 0.5858125997101122], 
             UndirectedEdge[190, 288] -> 
             RGBColor[
              0.21294330855938015`, 0.3411472970544397, 0.9354381784498378], 
             UndirectedEdge[23, 146] -> 
             RGBColor[
              0.20552449462249126`, 0.333349653226798, 0.9350156879712836], 
             UndirectedEdge[188, 201] -> 
             RGBColor[
              0.47076164268683474`, 0.5730017553920743, 0.9531670568538995], 
             UndirectedEdge[148, 382] -> 
             RGBColor[
              0.2893244860141426, 0.42019446169141983`, 0.9398331671225094], 
             UndirectedEdge[14, 71] -> 
             RGBColor[
              0.6541765961305002, 0.7223342652348994, 0.9394835143282855], 
             UndirectedEdge[228, 276] -> 
             RGBColor[
              0.3015266164865197, 0.4277543234766833, 0.9407208506945814], 
             UndirectedEdge[56, 174] -> 
             RGBColor[
              0.4681168777823908, 0.5781139671930625, 0.9515372200266019], 
             UndirectedEdge[16, 182] -> 
             RGBColor[
              0.23539065510704868`, 0.36474088152001305`, 0.9367165216278543],
              UndirectedEdge[104, 192] -> 
             RGBColor[
              0.24115781649194606`, 0.3708025337946915, 0.9370449529369735], 
             UndirectedEdge[145, 395] -> 
             RGBColor[
              0.3442769835307749, 0.46717394939172724`, 0.9433573051669275], 
             UndirectedEdge[219, 251] -> 
             RGBColor[
              0.1819264333571092, 0.30854659463338063`, 0.9336718132924233], 
             UndirectedEdge[150, 179] -> 
             RGBColor[
              0.23260992772492337`, 0.36181816073310025`, 0.9365581633171598],
              UndirectedEdge[73, 207] -> 
             RGBColor[
              0.1950145063297256, 0.32230298915935574`, 0.934417159686145], 
             UndirectedEdge[265, 325] -> 
             RGBColor[
              0.2186342581575027, 0.34712884590911136`, 0.9357622696104455], 
             UndirectedEdge[39, 314] -> 
             RGBColor[
              0.19046396107769498`, 0.3175200775782383, 0.9341580128659703], 
             UndirectedEdge[20, 263] -> 
             RGBColor[
              0.3432288815576954, 0.4710700975490908, 0.943114624476095], 
             UndirectedEdge[66, 146] -> 
             RGBColor[
              0.19762825714734855`, 0.3250502069900508, 0.9345660089285108], 
             UndirectedEdge[7, 21] -> 
             RGBColor[
              0.22580819870592864`, 0.3546691122796089, 0.9361708149117844], 
             UndirectedEdge[107, 167] -> 
             RGBColor[
              0.22944380789788385`, 0.3584903680512903, 0.9363778574768644], 
             UndirectedEdge[120, 195] -> 
             RGBColor[
              0.41858299206596217`, 0.5369772819597975, 0.9478927160094046], 
             UndirectedEdge[365, 388] -> 
             RGBColor[
              0.2883992345699991, 0.4204562594736305, 0.9397352818091035], 
             UndirectedEdge[134, 342] -> 
             RGBColor[
              0.18275455563161122`, 0.309417003649867, 0.9337189736308591], 
             UndirectedEdge[227, 311] -> 
             RGBColor[
              0.23829401063491945`, 0.3677924922631779, 0.9368818634300369], 
             UndirectedEdge[78, 377] -> 
             RGBColor[
              0.2375799153602678, 0.3670419328532635, 0.9368411967605548], 
             UndirectedEdge[21, 370] -> 
             RGBColor[
              0.19110729661804693`, 0.31819626402097745`, 0.9341946498732637],
              UndirectedEdge[2, 230] -> 
             RGBColor[
              0.2114753909347174, 0.33960442255956613`, 0.9353545827127028], 
             UndirectedEdge[24, 203] -> 
             RGBColor[
              0.2850956592214299, 0.4168671679331099, 0.9395514255934152], 
             UndirectedEdge[54, 206] -> 
             RGBColor[
              0.6885711015156095, 0.68922695188861, 0.6128856824256679], 
             UndirectedEdge[66, 130] -> 
             RGBColor[
              0.20589531196195676`, 0.3337394057617535, 0.9350368054701912], 
             UndirectedEdge[101, 356] -> 
             RGBColor[
              0.8996786533554004, 0.687329585228627, 0.5883270956947237], 
             UndirectedEdge[222, 383] -> 
             RGBColor[
              0.6547025238599551, 0.723910051109828, 0.9558664767641599], 
             UndirectedEdge[31, 247] -> 
             RGBColor[
              0.9007985668118983, 0.5610186106560575, 0.5373898372859729], 
             UndirectedEdge[46, 333] -> 
             RGBColor[
              0.8796565038002286, 0.9065288389378603, 0.9721902291244133], 
             UndirectedEdge[287, 385] -> 
             RGBColor[
              0.9058682917802197, 0.5622975503208443, 0.39899230255686247`], 
             UndirectedEdge[42, 330] -> 
             RGBColor[
              0.18629301045548374`, 0.31313614402075074`, 0.9339204833984038],
              UndirectedEdge[151, 227] -> 
             RGBColor[
              0.2408020759927813, 0.3704286279748189, 0.937024694041817], 
             UndirectedEdge[36, 382] -> 
             RGBColor[
              0.2838749254794549, 0.4144666280473688, 0.9395228227119613], 
             UndirectedEdge[218, 361] -> 
             RGBColor[
              0.4849252020484565, 0.5915353999172487, 0.952922413754254], 
             UndirectedEdge[196, 334] -> 
             RGBColor[
              0.9021680954325457, 0.8779962725880234, 0.6424622562871629], 
             UndirectedEdge[34, 265] -> 
             RGBColor[
              0.19096709589184307`, 0.31804890416849774`, 0.9341866656493147],
              UndirectedEdge[372, 392] -> 
             RGBColor[
              0.19150446236563495`, 0.31861371040345526`, 0.9342172678750348],
              UndirectedEdge[127, 210] -> 
             RGBColor[
              0.29252473138981117`, 0.4219611356100898, 0.9400738898749681], 
             UndirectedEdge[33, 157] -> 
             RGBColor[
              0.2467253832848012, 0.3766543994981055, 0.9373620176293496], 
             UndirectedEdge[139, 308] -> 
             RGBColor[
              0.25989565930435055`, 0.3904971946383813, 0.9381120453649856], 
             UndirectedEdge[38, 146] -> 
             RGBColor[
              0.2289275307271461, 0.3579477280109817, 0.9363484562557545], 
             UndirectedEdge[55, 68] -> 
             RGBColor[
              0.8126708442680417, 0.8535970039103761, 0.981959617507143], 
             UndirectedEdge[35, 392] -> 
             RGBColor[
              0.19658094676972326`, 0.3239494173798535, 0.934506366151862], 
             UndirectedEdge[51, 126] -> 
             RGBColor[
              0.1918840790772874, 0.31901271163649164`, 0.9342388864851707], 
             UndirectedEdge[130, 243] -> 
             RGBColor[
              0.22352868317149505`, 0.3522731969232867, 0.9360409998743393], 
             UndirectedEdge[12, 203] -> 
             RGBColor[
              0.2763975204564685, 0.40772487259728496`, 0.9390560794584938], 
             UndirectedEdge[182, 395] -> 
             RGBColor[
              0.3402542515552627, 0.4629458030295253, 0.9431282165320207], 
             UndirectedEdge[99, 382] -> 
             RGBColor[
              0.6121310294998102, 0.6891159199256546, 0.9661376246873524], 
             UndirectedEdge[17, 31] -> 
             RGBColor[
              0.9059600385832136, 0.6006919444617403, 0.5423324684832332], 
             UndirectedEdge[77, 78] -> 
             RGBColor[
              0.20870891214169546`, 0.33669667794321373`, 0.9351970358380788],
              UndirectedEdge[243, 344] -> 
             RGBColor[
              0.2114782278514492, 0.3396074043389222, 0.9353547442709138], 
             UndirectedEdge[305, 313] -> 
             RGBColor[
              0.29133850845533754`, 0.4235456226878492, 0.9399026691086074], 
             UndirectedEdge[189, 280] -> 
             RGBColor[
              0.2210513429116578, 0.3496693552377532, 0.9358999190114381], 
             UndirectedEdge[104, 208] -> 
             RGBColor[
              0.25923359532216883`, 0.3898013234158274, 0.9380743418006362], 
             UndirectedEdge[191, 335] -> 
             RGBColor[
              0.19113672012064215`, 0.3182271899877628, 0.9341963254982084], 
             UndirectedEdge[225, 355] -> 
             RGBColor[
              0.2083112643931653, 0.336278724947185, 0.9351743903870672], 
             UndirectedEdge[308, 348] -> 
             RGBColor[
              0.20697593141094872`, 0.33487520531787435`, 0.9350983451491781],
              UndirectedEdge[132, 149] -> 
             RGBColor[
              0.20160011613108555`, 0.32922488261236305`, 0.9347922004217959],
              UndirectedEdge[128, 224] -> 
             RGBColor[
              0.40082474260241224`, 0.5199417456186857, 0.9471108972900512], 
             UndirectedEdge[192, 225] -> 
             RGBColor[
              0.233374248060821, 0.36262150986683694`, 0.9366016902295785], 
             UndirectedEdge[84, 252] -> 
             RGBColor[
              0.2101141940866254, 0.33817371836735655`, 0.9352770645659143], 
             UndirectedEdge[30, 211] -> 
             RGBColor[
              0.21659401962004457`, 0.3449844258476482, 0.9356460810439997], 
             UndirectedEdge[138, 242] -> 
             RGBColor[
              0.31465187583145326`, 0.4451229547456037, 0.9413374842169753], 
             UndirectedEdge[27, 41] -> 
             RGBColor[
              0.1999138771125005, 0.32745253849010136`, 0.9346961716042546], 
             UndirectedEdge[102, 139] -> 
             RGBColor[
              0.3279891561400408, 0.4583428062151842, 0.9421262587090772], 
             UndirectedEdge[203, 329] -> 
             RGBColor[
              0.28617424693522586`, 0.4180008320067203, 0.9396128495680883], 
             UndirectedEdge[195, 312] -> 
             RGBColor[
              0.48621740603993846`, 0.5929929550712956, 0.9529112749587412], 
             UndirectedEdge[51, 87] -> 
             RGBColor[
              0.1940286984190197, 0.3212668425413722, 0.9343610193840024], 
             UndirectedEdge[83, 366] -> 
             RGBColor[
              0.9721424943326117, 0.9755215245830015, 0.7399924007909114], 
             UndirectedEdge[8, 302] -> 
             RGBColor[
              0.22515004974021374`, 0.353977355987588, 0.936133334301831], 
             UndirectedEdge[146, 344] -> 
             RGBColor[
              0.1953459036771252, 0.3226513087832781, 0.9344360322748211], 
             UndirectedEdge[67, 320] -> 
             RGBColor[
              0.1815572411564681, 0.30815855022236927`, 0.9336507883427678], 
             UndirectedEdge[90, 166] -> 
             RGBColor[
              0.23037172884023532`, 0.35946567179528754`, 0.9364307012017953],
              UndirectedEdge[12, 341] -> 
             RGBColor[
              0.2460644953245124, 0.3759597643491251, 0.9373243810377072], 
             UndirectedEdge[3, 13] -> 
             RGBColor[
              0.2247891692476987, 0.3535980477088099, 0.9361127826916571], 
             UndirectedEdge[153, 341] -> 
             RGBColor[
              0.22749742981872606`, 0.3564446012825976, 0.9362670141246647], 
             UndirectedEdge[192, 351] -> 
             RGBColor[
              0.2839106330866923, 0.41566367352388345`, 0.9394824007008676], 
             UndirectedEdge[12, 150] -> 
             RGBColor[
              0.24059607423843102`, 0.37021210706973123`, 0.937012962546659], 
             UndirectedEdge[99, 393] -> 
             RGBColor[
              0.8120689253181035, 0.8537779307522239, 0.9817268285297311], 
             UndirectedEdge[4, 190] -> 
             RGBColor[
              0.20649883851719153`, 0.33437375043709894`, 0.9350711754146743],
              UndirectedEdge[373, 390] -> 
             RGBColor[
              0.20548402624046883`, 0.3333071183914488, 0.9350133833567951], 
             UndirectedEdge[23, 308] -> 
             RGBColor[
              0.21238372481471685`, 0.3405591390591399, 0.9354063109834092], 
             UndirectedEdge[37, 187] -> 
             RGBColor[
              0.2503393326402117, 0.3804528894082654, 0.9375678266987812], 
             UndirectedEdge[17, 292] -> 
             RGBColor[
              0.8235767865158092, 0.18222708934004583`, 0.17021046343469787`],
              UndirectedEdge[309, 385] -> 
             RGBColor[
              0.845892139078253, 0.8769877648670494, 0.8021186290174642], 
             UndirectedEdge[140, 380] -> 
             RGBColor[
              0.5633644182821813, 0.6539330422248467, 0.9599388244578124], 
             UndirectedEdge[119, 354] -> 
             RGBColor[
              0.21794551615801888`, 0.3464049343988889, 0.9357230467724773], 
             UndirectedEdge[36, 305] -> 
             RGBColor[
              0.2718566625317226, 0.40306896740175535`, 0.9387932068040659], 
             UndirectedEdge[91, 351] -> 
             RGBColor[
              0.45106536887988224`, 0.5613307052601594, 0.9510072153286632], 
             UndirectedEdge[130, 275] -> 
             RGBColor[
              0.2049038205781411, 0.33269728545317867`, 0.934980341502663], 
             UndirectedEdge[46, 102] -> 
             RGBColor[
              0.5772856165740025, 0.6623742905041798, 0.9623565848838942], 
             UndirectedEdge[111, 271] -> 
             RGBColor[
              0.823307418706283, 0.18015661031829988`, 0.16995251651608806`], 
             UndirectedEdge[104, 351] -> 
             RGBColor[
              0.26680200623584566`, 0.3976814219540492, 0.9385080897116571], 
             UndirectedEdge[174, 203] -> 
             RGBColor[
              0.3639226125883841, 0.4896332085668736, 0.9444098049633691], 
             UndirectedEdge[294, 313] -> 
             RGBColor[
              0.24717525119128783`, 0.3771272391910956, 0.937387636941104], 
             UndirectedEdge[206, 266] -> 
             RGBColor[
              0.5435550579217713, 0.6394151913659053, 0.9575592073363473], 
             UndirectedEdge[167, 358] -> 
             RGBColor[
              0.25670178916857006`, 0.3871402346226134, 0.9379301591856604], 
             UndirectedEdge[315, 322] -> 
             RGBColor[
              0.18811052101816012`, 0.31504646285894905`, 0.9340239879361825],
              UndirectedEdge[176, 347] -> 
             RGBColor[
              0.18526445779187303`, 0.3120550699572905, 0.9338619088458187], 
             UndirectedEdge[92, 186] -> 
             RGBColor[
              0.20547576839988674`, 0.33329843887741967`, 0.9350129130849905],
              UndirectedEdge[149, 210] -> 
             RGBColor[
              0.22800345786551077`, 0.3569764688437995, 0.9362958316733276], 
             UndirectedEdge[171, 374] -> 
             RGBColor[
              0.18584495673726414`, 0.3126652111546555, 0.9338949674019874], 
             UndirectedEdge[228, 282] -> 
             RGBColor[
              0.26951575842165965`, 0.40002812713340913`, 0.938681147124779], 
             UndirectedEdge[164, 210] -> 
             RGBColor[
              0.23033673863294363`, 0.3594288948689166, 0.9364287085612534], 
             UndirectedEdge[196, 214] -> 
             RGBColor[
              0.8615229927273951, 0.7108190806524803, 0.6028379622201453], 
             UndirectedEdge[204, 307] -> 
             RGBColor[
              0.17948540198595286`, 0.30598091589196724`, 0.9335328001670183],
              UndirectedEdge[127, 255] -> 
             RGBColor[
              0.35677877005900877`, 0.4834455712278943, 0.9439546056344492], 
             UndirectedEdge[68, 334] -> 
             RGBColor[
              0.8909079727489195, 0.8690177564079877, 0.6413882557335685], 
             UndirectedEdge[16, 269] -> 
             RGBColor[
              0.29117851080203017`, 0.41924857896072276`, 0.9400447358569024],
              UndirectedEdge[68, 337] -> 
             RGBColor[
              0.8892917898500812, 0.9140123919924417, 0.970276843283211], 
             UndirectedEdge[23, 374] -> 
             RGBColor[
              0.19777812141168266`, 0.3252077238338092, 0.9345745434766604], 
             UndirectedEdge[22, 116] -> 
             RGBColor[
              0.24102708216235447`, 0.3706651237252555, 0.9370375078103073], 
             UndirectedEdge[192, 322] -> 
             RGBColor[
              0.2266888241245798, 0.3555947054294877, 0.936220965226608], 
             UndirectedEdge[70, 95] -> 
             RGBColor[
              0.22209777558797966`, 0.3507692223282312, 0.9359595118042963], 
             UndirectedEdge[71, 273] -> 
             RGBColor[
              0.7468748729151091, 0.8007044259307632, 0.9459207863964338], 
             UndirectedEdge[135, 215] -> 
             RGBColor[
              0.5207131115569171, 0.6175984363516078, 0.9569638659378303], 
             UndirectedEdge[161, 283] -> 
             RGBColor[
              0.9057344419097366, 0.6568662450460772, 0.2426421685015519], 
             UndirectedEdge[18, 384] -> 
             RGBColor[
              0.9630602947807589, 0.8804179575228263, 0.3471852898585644], 
             UndirectedEdge[71, 303] -> 
             RGBColor[
              0.9318169667814895, 0.7940843861143203, 0.5846862975193713], 
             UndirectedEdge[32, 353] -> 
             RGBColor[
              0.9073893332491589, 0.5772003661732394, 0.33799440934929903`], 
             UndirectedEdge[188, 281] -> 
             RGBColor[
              0.3372802138863956, 0.4635116716468679, 0.9428236756739168], 
             UndirectedEdge[54, 198] -> 
             RGBColor[
              0.8885256847199983, 0.8494376469396148, 0.6303773216350153], 
             UndirectedEdge[271, 385] -> 
             RGBColor[
              0.9072101681764545, 0.5726118003162909, 0.40027728490932957`], 
             UndirectedEdge[150, 206] -> 
             RGBColor[
              0.33364753302286965`, 0.45690710407047097`, 0.9427188232478589],
              UndirectedEdge[317, 346] -> 
             RGBColor[
              0.19596516131412245`, 0.3233021878229641, 0.9344712980811385], 
             UndirectedEdge[146, 243] -> 
             RGBColor[
              0.21526162835688684`, 0.343583998151584, 0.9355702033326591], 
             UndirectedEdge[91, 316] -> 
             RGBColor[
              0.6523585861658432, 0.7275841393423603, 0.9665060682236928], 
             UndirectedEdge[196, 386] -> 
             RGBColor[
              0.5930257483480736, 0.6745638419646864, 0.9640014047404548], 
             UndirectedEdge[151, 306] -> 
             RGBColor[
              0.21495613201977448`, 0.3432629021316925, 0.9355528057682019], 
             UndirectedEdge[27, 376] -> 
             RGBColor[
              0.24560585367761548`, 0.37547770289867644`, 0.937298262074416], 
             UndirectedEdge[280, 387] -> 
             RGBColor[
              0.19723551682458454`, 0.32463741200965124`, 0.9345436429481366],
              UndirectedEdge[308, 354] -> 
             RGBColor[
              0.20447448662716458`, 0.33224602824935756`, 0.9349558915692975],
              UndirectedEdge[327, 349] -> 
             RGBColor[
              0.19208902000720862`, 0.3192281175478443, 0.934250557567947], 
             UndirectedEdge[60, 108] -> 
             RGBColor[
              0.5066936953729514, 0.6051947855450721, 0.9560957540450186], 
             UndirectedEdge[353, 391] -> 
             RGBColor[
              0.9067470066576029, 0.5722631625212318, 0.3373793166798207], 
             UndirectedEdge[140, 195] -> 
             RGBColor[
              0.4154824656065883, 0.5342917617776789, 0.9476951532051012], 
             UndirectedEdge[17, 18] -> 
             RGBColor[
              0.9100987698336667, 0.6000343504740516, 0.3015369122339562], 
             UndirectedEdge[87, 205] -> 
             RGBColor[
              0.18600119174785296`, 0.31282942405665615`, 0.9339038647547113],
              UndirectedEdge[221, 256] -> 
             RGBColor[
              0.6811078585940378, 0.7429531062730206, 0.8609992027595657], 
             UndirectedEdge[194, 316] -> 
             RGBColor[
              0.5837905900380065, 0.6719175511327584, 0.9611081443956637], 
             UndirectedEdge[16, 37] -> 
             RGBColor[
              0.25664259349321183`, 0.38707801621458926`, 0.9379267880795208],
              UndirectedEdge[252, 288] -> 
             RGBColor[
              0.20983762189248398`, 0.33788302345562404`, 0.9352613141886098],
              UndirectedEdge[60, 353] -> 
             RGBColor[
              0.8501417981315751, 0.8795216745705272, 0.7395911022292926], 
             UndirectedEdge[206, 286] -> 
             RGBColor[
              0.375065904449271, 0.49928496789863985`, 0.9451198456671187], 
             UndirectedEdge[220, 396] -> 
             RGBColor[
              0.18205118127193512`, 0.30867771260133725`, 0.9336789175016247],
              UndirectedEdge[133, 320] -> 
             RGBColor[
              0.18355649439985816`, 0.3102598921411492, 0.9337646428573487], 
             UndirectedEdge[28, 231] -> 
             RGBColor[
              0.19140134234262995`, 0.31850532472108994`, 0.934211395342277], 
             UndirectedEdge[239, 269] -> 
             RGBColor[
              0.4302703250067166, 0.5456389418366184, 0.9490411897361934], 
             UndirectedEdge[212, 239] -> 
             RGBColor[
              0.542458414688152, 0.6394312043737607, 0.9571234599763494], 
             UndirectedEdge[77, 182] -> 
             RGBColor[
              0.21938986643201835`, 0.34792303811395897`, 0.9358053003838569],
              UndirectedEdge[280, 336] -> 
             RGBColor[
              0.22186501043454393`, 0.3505245713938071, 0.9359462561731533], 
             UndirectedEdge[199, 400] -> 
             RGBColor[
              0.9054254853432643, 0.5803013970083357, 0.502576064159955], 
             UndirectedEdge[73, 336] -> 
             RGBColor[
              0.2166564041388005, 0.3450499959322676, 0.9356496337500533], 
             UndirectedEdge[305, 340] -> 
             RGBColor[
              0.2847257211787761, 0.4165951639852536, 0.9395260806559493], 
             UndirectedEdge[259, 350] -> 
             RGBColor[
              0.6219849446227963, 0.6978827145935297, 0.9666587839790601], 
             UndirectedEdge[247, 393] -> 
             RGBColor[
              0.7696552520366986, 0.45850393020932284`, 0.5685799817696936], 
             UndirectedEdge[30, 216] -> 
             RGBColor[
              0.208257693184232, 0.33622241820998533`, 0.93517133958597], 
             UndirectedEdge[291, 387] -> 
             RGBColor[
              0.1905013026165654, 0.3175593259031815, 0.9341601394113672], 
             UndirectedEdge[45, 338] -> 
             RGBColor[
              0.2249286875668965, 0.3537446903082591, 0.9361207280535366], 
             UndirectedEdge[219, 248] -> 
             RGBColor[
              0.1809198934930053, 0.30748865741789405`, 0.933614492336205], 
             UndirectedEdge[158, 354] -> 
             RGBColor[
              0.1936207782086547, 0.3208380925366434, 0.9343377889314861], 
             UndirectedEdge[191, 327] -> 
             RGBColor[
              0.1848862258869851, 0.3116575242439654, 0.9338403690983792], 
             UndirectedEdge[165, 192] -> 
             RGBColor[
              0.24190350365737148`, 0.3715862982848506, 0.9370874187178992], 
             UndirectedEdge[143, 354] -> 
             RGBColor[
              0.1975023339396083, 0.32491785371472337`, 0.9345588377881168], 
             UndirectedEdge[115, 161] -> 
             RGBColor[
              0.9173271064366133, 0.7028272968686928, 0.25196989849468676`], 
             UndirectedEdge[296, 330] -> 
             RGBColor[
              0.18388840354746627`, 0.31060874969954066`, 0.9337835445922895],
              UndirectedEdge[45, 262] -> 
             RGBColor[
              0.30202723660803465`, 0.4296407358190505, 0.9406995556283282], 
             UndirectedEdge[37, 208] -> 
             RGBColor[
              0.289374752338518, 0.42148159049974276`, 0.9397908361028714], 
             UndirectedEdge[306, 348] -> 
             RGBColor[
              0.21170202637769384`, 0.33984263077965143`, 0.9353674892659032],
              UndirectedEdge[189, 263] -> 
             RGBColor[
              0.2675028819703037, 0.39849286798607286`, 0.9385452654419342], 
             UndirectedEdge[2, 50] -> 
             RGBColor[
              0.216476564027812, 0.3448609725730971, 0.935639392121782], 
             UndirectedEdge[241, 331] -> 
             RGBColor[
              0.26094013118712034`, 0.3915950008105146, 0.9381715264935517], 
             UndirectedEdge[135, 213] -> 
             RGBColor[
              0.33038430669065766`, 0.46058401368253077`, 0.9422727737683254],
              UndirectedEdge[49, 349] -> 
             RGBColor[
              0.19105637302960854`, 0.3181427401007867, 0.9341917498502368], 
             UndirectedEdge[256, 319] -> 
             RGBColor[
              0.9123741671932073, 0.6207364120366994, 0.4779545305476905], 
             UndirectedEdge[64, 332] -> 
             RGBColor[
              0.9051950840061846, 0.5622054525470171, 0.2995058419250193], 
             UndirectedEdge[213, 350] -> 
             RGBColor[
              0.33697931492905076`, 0.46629627834387477`, 0.942693001861539], 
             UndirectedEdge[333, 345] -> 
             RGBColor[
              0.8909301311153961, 0.9154013493777207, 0.9732965059821361], 
             UndirectedEdge[53, 201] -> 
             RGBColor[
              0.5341594365329997, 0.6309589682060907, 0.9570952074204189], 
             UndirectedEdge[9, 384] -> 
             RGBColor[
              0.8099718019563749, 0.7646503394906032, 0.6173962103853706], 
             UndirectedEdge[24, 33] -> 
             RGBColor[
              0.2533855843329195, 0.3836546930808141, 0.9377413062261555], 
             UndirectedEdge[20, 359] -> 
             RGBColor[
              0.3551576814248725, 0.48204146573128925`, 0.9438513113001545], 
             UndirectedEdge[35, 291] -> 
             RGBColor[
              0.19278015708719454`, 0.31995454643953136`, 0.9342899168022064],
              UndirectedEdge[316, 351] -> 
             RGBColor[
              0.5108480401165528, 0.6087959957654421, 0.956444390370581], 
             UndirectedEdge[195, 263] -> 
             RGBColor[
              0.3632251652657039, 0.4883898734545258, 0.9443887699919498], 
             UndirectedEdge[67, 200] -> 
             RGBColor[
              0.1867268102524256, 0.3135920951118324, 0.9339451876550904], 
             UndirectedEdge[232, 277] -> 
             RGBColor[
              0.18773724237763328`, 0.31465412334052256`, 0.9340027302698206],
              UndirectedEdge[88, 120] -> 
             RGBColor[
              0.42147179727410705`, 0.5394794198355211, 0.9480767881227974], 
             UndirectedEdge[247, 271] -> 
             RGBColor[
              0.8186707488403941, 0.14451713392738777`, 0.16551243621614334`],
              UndirectedEdge[202, 269] -> 
             RGBColor[
              0.34049741903328384`, 0.46934348329390774`, 0.9429171723441234],
              UndirectedEdge[207, 291] -> 
             RGBColor[
              0.19348889841744987`, 0.3206994785144255, 0.9343302785724756], 
             UndirectedEdge[72, 397] -> 
             RGBColor[
              0.4148581473336097, 0.5334192417760302, 0.947747040377775], 
             UndirectedEdge[200, 298] -> 
             RGBColor[
              0.19975642982426225`, 0.3272870514074283, 0.9346872052141117], 
             UndirectedEdge[233, 389] -> 
             RGBColor[
              0.9817271461205633, 0.9825466050438816, 0.7139976792857294], 
             UndirectedEdge[44, 311] -> 
             RGBColor[
              0.21545480303552692`, 0.34378703698681684`, 0.9355812043448313],
              UndirectedEdge[137, 258] -> 
             RGBColor[
              0.2651486396074914, 0.3960184099951701, 0.9384111948221615], 
             UndirectedEdge[46, 287] -> 
             RGBColor[
              0.8114277374548052, 0.49106874179706506`, 0.572735002859394], 
             UndirectedEdge[84, 274] -> 
             RGBColor[
              0.20871345876417752`, 0.33670145673171487`, 0.935197294761503], 
             UndirectedEdge[270, 357] -> 
             RGBColor[
              0.1969743042117703, 0.32436286099174727`, 0.9345287672762663], 
             UndirectedEdge[44, 344] -> 
             RGBColor[
              0.20993796520971017`, 0.3379884906441625, 0.9352670285920812], 
             UndirectedEdge[44, 383] -> 
             RGBColor[
              0.29331549171916627`, 0.4210403283755737, 0.9401830698485728], 
             UndirectedEdge[193, 364] -> 
             RGBColor[
              0.8796332391054209, 0.7997224705221349, 0.619984358127655], 
             UndirectedEdge[43, 375] -> 
             RGBColor[
              0.19874644987833204`, 0.3262254984478285, 0.9346296883503225], 
             UndirectedEdge[184, 252] -> 
             RGBColor[
              0.20974713734389644`, 0.3377879184580067, 0.9352561612274277], 
             UndirectedEdge[16, 78] -> 
             RGBColor[
              0.22470970081672578`, 0.3535145213492678, 0.9361082570820762], 
             UndirectedEdge[345, 353] -> 
             RGBColor[
              0.9106717648266294, 0.9268736116959997, 0.7456067906697404], 
             UndirectedEdge[167, 203] -> 
             RGBColor[
              0.2729080188918158, 0.40405718520565725`, 0.9388573575066418], 
             UndirectedEdge[329, 340] -> 
             RGBColor[
              0.2668654692611238, 0.39782290681442484`, 0.9385089657311141], 
             UndirectedEdge[193, 380] -> 
             RGBColor[
              0.7791551569135652, 0.8275462332304435, 0.978584074457042], 
             UndirectedEdge[115, 253] -> 
             RGBColor[
              0.8901501343784577, 0.5271850402949314, 0.22724725879350022`], 
             UndirectedEdge[113, 270] -> 
             RGBColor[
              0.196796775846464, 0.3241762674238618, 0.9345186572984918], 
             UndirectedEdge[121, 202] -> 
             RGBColor[
              0.2856578369982738, 0.41583248159385067`, 0.9396429608971655], 
             UndirectedEdge[17, 111] -> 
             RGBColor[
              0.8271368865255229, 0.20959157806047718`, 0.1736196192245576], 
             UndirectedEdge[73, 280] -> 
             RGBColor[
              0.2037203723071403, 0.3314534062854026, 0.9349129458743843], 
             UndirectedEdge[127, 242] -> 
             RGBColor[
              0.33988365440933965`, 0.4688118712253543, 0.9428780638050165], 
             UndirectedEdge[19, 211] -> 
             RGBColor[
              0.2160009516459515, 0.344361073804195, 0.9356123067002404], 
             UndirectedEdge[213, 345] -> 
             RGBColor[
              0.5767485455920949, 0.6610169677020706, 0.962710294489918], 
             UndirectedEdge[102, 350] -> 
             RGBColor[
              0.3487900132261258, 0.4765261115858444, 0.9434455691132382], 
             UndirectedEdge[81, 227] -> 
             RGBColor[
              0.2515739104642789, 0.38175050897811513`, 0.9376381340794677], 
             UndirectedEdge[144, 218] -> 
             RGBColor[
              0.5707667888209911, 0.662413217772521, 0.9593519988850778], 
             UndirectedEdge[130, 354] -> 
             RGBColor[
              0.2058823112495472, 0.3337257411887183, 0.9350360650988523], 
             UndirectedEdge[104, 327] -> 
             RGBColor[
              0.20490625211316982`, 0.332699841150662, 0.9349804799749857], 
             UndirectedEdge[10, 253] -> 
             RGBColor[
              0.8340797477746764, 0.2629574520026702, 0.18026811099758727`], 
             UndirectedEdge[40, 41] -> 
             RGBColor[
              0.19412189539412833`, 0.3213647984712409, 0.9343663268138622], 
             UndirectedEdge[5, 113] -> 
             RGBColor[
              0.18623312529560537`, 0.31307320092078017`, 0.9339170730271409],
              UndirectedEdge[271, 337] -> 
             RGBColor[
              0.8884909872626653, 0.561095627258048, 0.562247550040962], 
             UndirectedEdge[325, 376] -> 
             RGBColor[
              0.26222548998781436`, 0.392945994406499, 0.9382447257757333], 
             UndirectedEdge[52, 337] -> 
             RGBColor[
              0.9729869409703154, 0.9785763889719264, 0.8948788134240234], 
             UndirectedEdge[246, 260] -> 
             RGBColor[
              0.20281631365008554`, 0.33050318331620854`, 0.9348614610713], 
             UndirectedEdge[22, 290] -> 
             RGBColor[
              0.2497813465899759, 0.3798664106911086, 0.9375360502186867], 
             UndirectedEdge[24, 107] -> 
             RGBColor[
              0.2416314482274979, 0.371300350778743, 0.9370719255636378], 
             UndirectedEdge[314, 369] -> 
             RGBColor[
              0.1815795981118552, 0.30818204879999395`, 0.9336520615383029], 
             UndirectedEdge[187, 208] -> 
             RGBColor[
              0.25538258130493185`, 0.38575366351532014`, 0.9378550322494192],
              UndirectedEdge[9, 174] -> 
             RGBColor[
              0.5520972673558275, 0.6456190088987284, 0.9586092963260144], 
             UndirectedEdge[6, 303] -> 
             RGBColor[
              0.9100466794366213, 0.777602242030947, 0.6130122278904285], 
             UndirectedEdge[100, 198] -> 
             RGBColor[
              0.6082548805926754, 0.6882816237042615, 0.9647291510065205], 
             UndirectedEdge[101, 123] -> 
             RGBColor[
              0.8485657793755872, 0.374303438706794, 0.1941399512182521], 
             UndirectedEdge[210, 394] -> 
             RGBColor[
              0.30165291276591666`, 0.42986750752233627`, 0.9406555295205197],
              UndirectedEdge[213, 227] -> 
             RGBColor[
              0.29970260204538113`, 0.43079580390036054`, 0.94043541584355], 
             UndirectedEdge[32, 46] -> 
             RGBColor[
              0.8135276706473076, 0.5072097485112304, 0.5747459012560696], 
             UndirectedEdge[303, 391] -> 
             RGBColor[
              0.8570821356565119, 0.38388879895942046`, 0.20010729537059024`],
              UndirectedEdge[248, 251] -> 
             RGBColor[
              0.1839193268501145, 0.3106412520512747, 0.9337853056286283], 
             UndirectedEdge[239, 388] -> 
             RGBColor[
              0.38895939974165, 0.5063474161681534, 0.9465374152784297], 
             UndirectedEdge[205, 277] -> 
             RGBColor[
              0.18513416241600078`, 0.31191812125604473`, 0.9338544887169173],
              UndirectedEdge[308, 378] -> 
             RGBColor[
              0.22654239934249232`, 0.35544080369964637`, 0.9362126265518842],
              UndirectedEdge[119, 130] -> 
             RGBColor[
              0.2277266187202509, 0.3566854933495158, 0.936280066093552], 
             UndirectedEdge[28, 254] -> 
             RGBColor[
              0.1893368412328983, 0.3163354031578313, 0.9340938250582336], 
             UndirectedEdge[217, 314] -> 
             RGBColor[
              0.1955003640293088, 0.322813656406775, 0.9344448285633742], 
             UndirectedEdge[229, 307] -> 
             RGBColor[
              0.18847585942484443`, 0.31543045668816716`, 0.9340447934179733],
              UndirectedEdge[114, 155] -> 
             RGBColor[
              0.18628873221551898`, 0.3131316473192917, 0.933920239758967], 
             UndirectedEdge[226, 288] -> 
             RGBColor[
              0.20281928004263788`, 0.3305063011828612, 0.9348616300029674], 
             UndirectedEdge[217, 231] -> 
             RGBColor[
              0.19972682323934088`, 0.32725593300951006`, 0.9346855191628995],
              UndirectedEdge[151, 346] -> 
             RGBColor[
              0.2055192492348853, 0.3333441399918473, 0.9350153892542195], 
             UndirectedEdge[114, 180] -> 
             RGBColor[
              0.18755106204056693`, 0.3144584360017507, 0.9339921275750538], 
             UndirectedEdge[215, 345] -> 
             RGBColor[
              0.7670773504583543, 0.8180313903711476, 0.977401386659423], 
             UndirectedEdge[190, 252] -> 
             RGBColor[
              0.20904698368177904`, 0.3370520125668152, 0.9352162885121547], 
             UndirectedEdge[275, 311] -> 
             RGBColor[
              0.19837020308391207`, 0.32583003921146847`, 0.9346082616519875],
              UndirectedEdge[75, 320] -> 
             RGBColor[
              0.18280885155031829`, 0.3094740721029882, 0.933722065703106], 
             UndirectedEdge[169, 393] -> 
             RGBColor[
              0.5896152402179853, 0.6764956737968535, 0.9616696419121211], 
             UndirectedEdge[80, 182] -> 
             RGBColor[
              0.22246710481821064`, 0.35115741076602963`, 0.9359805445575843],
              UndirectedEdge[239, 362] -> 
             RGBColor[
              0.6492041088152176, 0.7238110272281775, 0.9670865002427318], 
             UndirectedEdge[171, 342] -> 
             RGBColor[
              0.18722373291059582`, 0.31411439233228555`, 0.933973486665342], 
             UndirectedEdge[107, 157] -> 
             RGBColor[
              0.2349712471793796, 0.36430005719603437`, 0.936692636966832], 
             UndirectedEdge[116, 286] -> 
             RGBColor[
              0.28063230469456346`, 0.41113725310534854`, 0.9393352740823563],
              UndirectedEdge[37, 117] -> 
             RGBColor[
              0.4214315538332871, 0.5343304799664346, 0.9489462154343377], 
             UndirectedEdge[111, 222] -> 
             RGBColor[
              0.8888497880747033, 0.5842997162159619, 0.5703986830647514], 
             UndirectedEdge[57, 72] -> 
             RGBColor[
              0.4069178401688355, 0.5265417468013449, 0.9472410910265736], 
             UndirectedEdge[8, 323] -> 
             RGBColor[
              0.3381102648791732, 0.4623620160236, 0.9429449845379104], 
             UndirectedEdge[115, 356] -> 
             RGBColor[
              0.9502457162134885, 0.9092562156396481, 0.6300362544566458], 
             UndirectedEdge[129, 391] -> 
             RGBColor[
              0.8197851875316053, 0.15308319805818565`, 0.1665796239654257], 
             UndirectedEdge[271, 303] -> 
             RGBColor[
              0.8569664054518005, 0.38299924589270967`, 0.19999647199586007`],
              UndirectedEdge[141, 196] -> 
             RGBColor[
              0.5999457128672814, 0.6805575674236943, 0.9644423387605343], 
             UndirectedEdge[8, 117] -> 
             RGBColor[
              0.40706513411417244`, 0.5192304619580248, 0.9481280690845475], 
             UndirectedEdge[278, 330] -> 
             RGBColor[
              0.18839714683821507`, 0.31534772476895345`, 0.9340403108526096],
              UndirectedEdge[95, 276] -> 
             RGBColor[
              0.3131382201938357, 0.4399588551912694, 0.9413821143478849], 
             UndirectedEdge[114, 268] -> 
             RGBColor[
              0.18716896902427724`, 0.3140568320155338, 0.9339703679430321], 
             UndirectedEdge[95, 148] -> 
             RGBColor[
              0.2518920934922597, 0.3820849395144922, 0.9376562541322015], 
             UndirectedEdge[236, 366] -> 
             RGBColor[
              0.7514680031030527, 0.8004311372612268, 0.7333352246803804], 
             UndirectedEdge[108, 378] -> 
             RGBColor[
              0.2733003143570183, 0.40458633700295354`, 0.938875420639825], 
             UndirectedEdge[33, 107] -> 
             RGBColor[
              0.23483527017028652`, 0.36415713673803723`, 0.9366848932773241],
              UndirectedEdge[309, 362] -> 
             RGBColor[
              0.7443188002522516, 0.8001867708802417, 0.9751504000206381], 
             UndirectedEdge[178, 278] -> 
             RGBColor[
              0.18555079143571185`, 0.31235602477156665`, 0.9338782151232425],
              UndirectedEdge[21, 232] -> 
             RGBColor[
              0.19351392550506752`, 0.32072578357032067`, 0.9343317038280912],
              UndirectedEdge[20, 140] -> 
             RGBColor[
              0.3954861818985797, 0.5169719858722439, 0.9464210076892463], 
             UndirectedEdge[33, 150] -> 
             RGBColor[
              0.24249803494618108`, 0.37221118836485045`, 0.9371212763952667],
              UndirectedEdge[38, 213] -> 
             RGBColor[
              0.2920695594579869, 0.42277299217815684`, 0.9400007253602725], 
             UndirectedEdge[86, 262] -> 
             RGBColor[
              0.31621623896980977`, 0.44455427693598626`, 0.9415075983220833],
              UndirectedEdge[17, 310] -> 
             RGBColor[
              0.8270891883762761, 0.20922494918390394`, 0.1735739434229715], 
             UndirectedEdge[222, 223] -> 
             RGBColor[
              0.9051519086820443, 0.7083288764559916, 0.5859596439831081], 
             UndirectedEdge[19, 124] -> 
             RGBColor[
              0.21306575741872125`, 0.34127599856931323`, 0.9354451517312304],
              UndirectedEdge[184, 274] -> 
             RGBColor[
              0.20834640202144852`, 0.33631565682236503`, 0.9351763914230165],
              UndirectedEdge[195, 360] -> 
             RGBColor[
              0.5436868916256435, 0.6393368239296271, 0.957649106135095], 
             UndirectedEdge[186, 378] -> 
             RGBColor[
              0.22340907061728948`, 0.35214747654494266`, 0.9360341881163283],
              UndirectedEdge[31, 169] -> 
             RGBColor[
              0.7207585549931849, 0.779010354243588, 0.9304794974284005], 
             UndirectedEdge[4, 84] -> 
             RGBColor[
              0.20756604892203795`, 0.3354954562376403, 0.935131951468434], 
             UndirectedEdge[81, 383] -> 
             RGBColor[
              0.2937367673363199, 0.42148311575961905`, 0.9402070608717483], 
             UndirectedEdge[327, 335] -> 
             RGBColor[
              0.19201380881889718`, 0.3191490658202642, 0.9342462744020376], 
             UndirectedEdge[11, 214] -> 
             RGBColor[
              0.8760571062553216, 0.722408188261647, 0.6042242389431952], 
             UndirectedEdge[15, 35] -> 
             RGBColor[
              0.1861148468094702, 0.312948882732563, 0.933910337242333], 
             UndirectedEdge[151, 354] -> 
             RGBColor[
              0.20185675911317996`, 0.3294946306586492, 0.934806815859957], 
             UndirectedEdge[91, 192] -> 
             RGBColor[
              0.4254211791359827, 0.5344518171008017, 0.9495440785539795], 
             UndirectedEdge[44, 130] -> 
             RGBColor[
              0.22198842052975598`, 0.350654283228527, 0.9359532841955067], 
             UndirectedEdge[195, 356] -> 
             RGBColor[
              0.6850009171912799, 0.7504962345412768, 0.9628064219580481], 
             UndirectedEdge[226, 315] -> 
             RGBColor[
              0.186507225222572, 0.3133612973229612, 0.9339326826124872], 
             UndirectedEdge[65, 206] -> 
             RGBColor[
              0.4026912595828178, 0.5232126620245969, 0.9468801088680859], 
             UndirectedEdge[287, 400] -> 
             RGBColor[
              0.8197171091545148, 0.15255991781973297`, 0.16651443203464028`],
              UndirectedEdge[247, 319] -> 
             RGBColor[
              0.8248915640805821, 0.1923330458420928, 0.17146949591555327`], 
             UndirectedEdge[55, 72] -> 
             RGBColor[
              0.6346370252408752, 0.7117938428167392, 0.9660702931075245], 
             UndirectedEdge[313, 329] -> 
             RGBColor[
              0.27347825653768526`, 0.4047733655170204, 0.9388855541837721], 
             UndirectedEdge[5, 357] -> 
             RGBColor[
              0.1864106536609117, 0.3132597944886656, 0.9339271830049154], 
             UndirectedEdge[39, 328] -> 
             RGBColor[
              0.21476290196670605`, 0.3430598050944246, 0.9355418016025379], 
             UndirectedEdge[310, 384] -> 
             RGBColor[
              0.8800507133233684, 0.4896085562326786, 0.2192223210475797], 
             UndirectedEdge[66, 344] -> 
             RGBColor[
              0.19384485664191092`, 0.32107361317738903`, 0.9343505498667657],
              UndirectedEdge[271, 391] -> 
             RGBColor[
              0.820118482997181, 0.15564505305760412`, 0.1668987880796643], 
             UndirectedEdge[203, 211] -> 
             RGBColor[
              0.27124930343896736`, 0.4023137700960795, 0.9387628961154517], 
             UndirectedEdge[100, 203] -> 
             RGBColor[
              0.3488608742001085, 0.47658748779993204`, 0.9434500843118405], 
             UndirectedEdge[323, 377] -> 
             RGBColor[
              0.3376579889612439, 0.46188664535790686`, 0.9429192280934666], 
             UndirectedEdge[351, 395] -> 
             RGBColor[
              0.37411784951982285`, 0.4984638103693781, 0.9450594364453463], 
             UndirectedEdge[179, 209] -> 
             RGBColor[
              0.24592936800917714`, 0.3758177369731411, 0.9373166857370019], 
             UndirectedEdge[283, 356] -> 
             RGBColor[
              0.9386530516866118, 0.8632951638170323, 0.6207085244635109], 
             UndirectedEdge[77, 80] -> 
             RGBColor[
              0.20002934434875747`, 0.3275739018764531, 0.9347027472925409], 
             UndirectedEdge[200, 398] -> 
             RGBColor[
              0.18742715801975252`, 0.3143282050199061, 0.933985071424368], 
             UndirectedEdge[280, 368] -> 
             RGBColor[
              0.19638103924398845`, 0.323739301895437, 0.934494981714008], 
             UndirectedEdge[3, 390] -> 
             RGBColor[
              0.22459916207358144`, 0.353398338121662, 0.9361019620641815], 
             UndirectedEdge[64, 380] -> 
             RGBColor[
              0.8564837144111264, 0.8840181121327374, 0.7035464946088651], 
             UndirectedEdge[139, 186] -> 
             RGBColor[
              0.2567623305791477, 0.38720386748367763`, 0.9379336069294297], 
             UndirectedEdge[160, 245] -> 
             RGBColor[
              0.19509478987731566`, 0.3223873722581438, 0.9344217317154114], 
             UndirectedEdge[64, 360] -> 
             RGBColor[
              0.8276703795499445, 0.8615089159497265, 0.7006746506658257], 
             UndirectedEdge[72, 337] -> 
             RGBColor[
              0.7112579708229148, 0.7722092308988048, 0.9543875188835923], 
             UndirectedEdge[11, 141] -> 
             RGBColor[
              0.6144798263952078, 0.6921466750328611, 0.9658286154835842], 
             UndirectedEdge[62, 223] -> 
             RGBColor[
              0.9255100897331807, 0.7222473691090705, 0.4948669383214451], 
             UndirectedEdge[351, 399] -> 
             RGBColor[
              0.33446531711843736`, 0.46411877979752536`, 0.9425328121440877],
              UndirectedEdge[205, 232] -> 
             RGBColor[
              0.18775686622597437`, 0.3146747492493529, 0.9340038478189527], 
             UndirectedEdge[175, 379] -> 
             RGBColor[
              0.1863024171876671, 0.3131460310926968, 0.9339210190978857], 
             UndirectedEdge[144, 339] -> 
             RGBColor[
              0.48160738498318656`, 0.5880919933231088, 0.9528684097242202], 
             UndirectedEdge[66, 275] -> 
             RGBColor[
              0.19513571872831864`, 0.3224303910755869, 0.9344240625529272], 
             UndirectedEdge[311, 346] -> 
             RGBColor[
              0.20301118387702347`, 0.33070800428020625`, 0.9348725586424393],
              UndirectedEdge[81, 326] -> 
             RGBColor[
              0.23536377630225702`, 0.36471263019196243`, 0.936714990919685], 
             UndirectedEdge[145, 335] -> 
             RGBColor[
              0.2240686969525251, 0.3528407856460005, 0.9360717528602902], 
             UndirectedEdge[24, 56] -> 
             RGBColor[
              0.3892899244154366, 0.5053479265592988, 0.9466788406566481], 
             UndirectedEdge[310, 319] -> 
             RGBColor[
              0.8294805357972241, 0.22760589335643167`, 0.17586390041391192`],
              UndirectedEdge[131, 303] -> 
             RGBColor[
              0.8540204827009316, 0.7329759435664439, 0.607655802146349], 
             UndirectedEdge[146, 317] -> 
             RGBColor[
              0.19381671894004093`, 0.32104403866869025`, 0.9343489474662702],
              UndirectedEdge[159, 321] -> 
             RGBColor[
              0.1833474210515813, 0.31004014279609426`, 0.9337527364394607], 
             UndirectedEdge[339, 361] -> 
             RGBColor[
              0.39576579821065194`, 0.5172141754678363, 0.9464388245933966], 
             UndirectedEdge[60, 297] -> 
             RGBColor[
              0.5017919184919047, 0.6000427072524873, 0.955816605103172], 
             UndirectedEdge[1, 368] -> 
             RGBColor[
              0.1828231865844723, 0.30948913913277776`, 0.9337228820620942], 
             UndirectedEdge[15, 106] -> 
             RGBColor[
              0.18432449600494816`, 0.311067110522213, 0.933808379412602], 
             UndirectedEdge[144, 282] -> 
             RGBColor[
              0.44814038646858245`, 0.5591045613100133, 0.9507359221725744], 
             UndirectedEdge[333, 391] -> 
             RGBColor[
              0.8870053729463696, 0.5607909002029526, 0.5650690319922165], 
             UndirectedEdge[85, 238] -> 
             RGBColor[
              0.19138550303315327`, 0.3184886766025597, 0.9342104933170345], 
             UndirectedEdge[130, 135] -> 
             RGBColor[
              0.27550933277442513`, 0.40444794828705827`, 0.9390913012054878],
              UndirectedEdge[194, 256] -> 
             RGBColor[
              0.7238719368935342, 0.7799355863354847, 0.863740011258672], 
             UndirectedEdge[129, 271] -> 
             RGBColor[
              0.8196694573268939, 0.15219364499147486`, 0.1664688005906955], 
             UndirectedEdge[12, 168] -> 
             RGBColor[
              0.22037492795635888`, 0.34895840023254887`, 0.9358613981804], 
             UndirectedEdge[32, 271] -> 
             RGBColor[
              0.8207608095887371, 0.16058225670961188`, 0.16751388074914259`],
              UndirectedEdge[227, 363] -> 
             RGBColor[
              0.3242588248996095, 0.45206516990504564`, 0.9420001166496061], 
             UndirectedEdge[351, 355] -> 
             RGBColor[
              0.2588476494190366, 0.38932088860423164`, 0.9380551008583563], 
             UndirectedEdge[70, 285] -> 
             RGBColor[
              0.1906202345698193, 0.31768433092677273`, 0.9341669124101608], 
             UndirectedEdge[19, 107] -> 
             RGBColor[
              0.211296993265781, 0.33941691529844853`, 0.9353444232293726], 
             UndirectedEdge[88, 359] -> 
             RGBColor[
              0.3780427703410259, 0.5018633795124479, 0.9453095289294022], 
             UndirectedEdge[128, 130] -> 
             RGBColor[
              0.2597826750311079, 0.39037844100358665`, 0.9381056110777697], 
             UndirectedEdge[72, 297] -> 
             RGBColor[
              0.3810483803734705, 0.5030082457772378, 0.9456339650216002], 
             UndirectedEdge[125, 184] -> 
             RGBColor[
              0.20307558723579205`, 0.3307756962936808, 0.934876226318445], 
             UndirectedEdge[41, 63] -> 
             RGBColor[
              0.19205972818458644`, 0.31919732998505956`, 0.9342488894419819],
              UndirectedEdge[67, 133] -> 
             RGBColor[
              0.1814057266970613, 0.30799929891896116`, 0.9336421598184501], 
             UndirectedEdge[272, 308] -> 
             RGBColor[
              0.20474955864050876`, 0.33253514637595527`, 0.9349715565135248],
              UndirectedEdge[199, 287] -> 
             RGBColor[
              0.9030273761887495, 0.5618684791886028, 0.5002796321253148], 
             UndirectedEdge[60, 333] -> 
             RGBColor[
              0.8304001644203418, 0.8680494122522482, 0.9672808175416883], 
             UndirectedEdge[86, 325] -> 
             RGBColor[
              0.25318562671626305`, 0.38344452494766296`, 0.9377299189356977],
              UndirectedEdge[77, 377] -> 
             RGBColor[
              0.22582310918113752`, 0.35468478413443216`, 0.9361716640412894],
              UndirectedEdge[62, 319] -> 
             RGBColor[
              0.9121241184522142, 0.6206330104563391, 0.4820984852913445], 
             UndirectedEdge[52, 199] -> 
             RGBColor[
              0.9888652062926342, 0.9896634908979279, 0.8341958778608433], 
             UndirectedEdge[57, 376] -> 
             RGBColor[
              0.31723897478085683`, 0.4471117135410761, 0.941511560889603], 
             UndirectedEdge[11, 161] -> 
             RGBColor[
              0.8763695857039919, 0.7238270844566292, 0.6044849794547379], 
             UndirectedEdge[155, 300] -> 
             RGBColor[
              0.19103033479495424`, 0.31811537226524556`, 0.9341902670112934],
              UndirectedEdge[81, 275] -> 
             RGBColor[
              0.21165010291327152`, 0.33978805592640576`, 0.9353645323014182],
              UndirectedEdge[100, 266] -> 
             RGBColor[
              0.5229669528809726, 0.6215828095678126, 0.9562473514884939], 
             UndirectedEdge[56, 266] -> 
             RGBColor[
              0.5883098999275997, 0.6764125091387695, 0.9608991949142476], 
             UndirectedEdge[82, 257] -> 
             RGBColor[
              0.8645894369328215, 0.89448136547207, 0.956668495179433], 
             UndirectedEdge[32, 259] -> 
             RGBColor[
              0.85847174370837, 0.5429301584289652, 0.5790636952869976], 
             UndirectedEdge[261, 355] -> 
             RGBColor[
              0.19867201809183277`, 0.32614726592096993`, 0.9346254495701933],
              UndirectedEdge[74, 179] -> 
             RGBColor[
              0.23767352171657924`, 0.3671403190687327, 0.9368465275040685], 
             UndirectedEdge[100, 174] -> 
             RGBColor[
              0.4027739307357637, 0.5232842676221057, 0.9468853766008484], 
             UndirectedEdge[208, 388] -> 
             RGBColor[
              0.28259974438226976`, 0.4143606275774112, 0.9394050094224892], 
             UndirectedEdge[249, 299] -> 
             RGBColor[
              0.186005835268804, 0.3128343046915919, 0.9339041291963601], 
             UndirectedEdge[58, 181] -> 
             RGBColor[
              0.19266290312611054`, 0.31983130509210156`, 0.9342832393625844],
              UndirectedEdge[271, 345] -> 
             RGBColor[
              0.8240432411662075, 0.5102555022323721, 0.5751262620695841], 
             UndirectedEdge[20, 89] -> 
             RGBColor[
              0.30842578765479933`, 0.4344898392135439, 0.9411326397648885], 
             UndirectedEdge[174, 358] -> 
             RGBColor[
              0.34771638286513834`, 0.47271625798382977`, 0.9434826066423876],
              UndirectedEdge[185, 274] -> 
             RGBColor[
              0.19784473283359588`, 0.32527773666164805`, 0.9345783368985956],
              UndirectedEdge[106, 314] -> 
             RGBColor[
              0.18463641563674799`, 0.3113949578320815, 0.9338261427741893], 
             UndirectedEdge[73, 387] -> 
             RGBColor[
              0.19202691052884113`, 0.31916283654811173`, 0.9342470205250366],
              UndirectedEdge[191, 261] -> 
             RGBColor[
              0.18660634868245718`, 0.3134654823640909, 0.9339383275468877], 
             UndirectedEdge[135, 227] -> 
             RGBColor[
              0.3046735470917944, 0.4351013866526011, 0.9407521600662733], 
             UndirectedEdge[102, 345] -> 
             RGBColor[
              0.5885592438891699, 0.6712468009440402, 0.9634628617416172], 
             UndirectedEdge[72, 108] -> 
             RGBColor[
              0.3859501572545172, 0.5081603240698226, 0.9459131139634468], 
             UndirectedEdge[7, 273] -> 
             RGBColor[
              0.3894971814838498, 0.5048902400899095, 0.9467521342900769], 
             UndirectedEdge[111, 385] -> 
             RGBColor[
              0.9105148340902678, 0.5980129106436974, 0.4034418367204835], 
             UndirectedEdge[25, 187] -> 
             RGBColor[
              0.29015449891481293`, 0.4171960722657919, 0.940022163552006], 
             UndirectedEdge[290, 338] -> 
             RGBColor[
              0.2338329245191738, 0.3631036079063329, 0.9366278111753308], 
             UndirectedEdge[133, 200] -> 
             RGBColor[
              0.18872606349581567`, 0.31569343703061226`, 0.9340590421696713],
              UndirectedEdge[64, 88] -> 
             RGBColor[
              0.7114905669436782, 0.7668789695612932, 0.6914868954695467], 
             UndirectedEdge[23, 92] -> 
             RGBColor[
              0.20814505737279243`, 0.33610403083063944`, 0.9351649251431382],
              UndirectedEdge[38, 350] -> 
             RGBColor[
              0.3036355127427933, 0.43279083959174136`, 0.9407376976762094], 
             UndirectedEdge[135, 224] -> 
             RGBColor[
              0.41655140034572946`, 0.5340112529021572, 0.9480965874177693], 
             UndirectedEdge[329, 358] -> 
             RGBColor[
              0.26996801721198005`, 0.40108388142367646`, 0.9386856512471069],
              UndirectedEdge[4, 185] -> 
             RGBColor[
              0.1966973229914563, 0.32407173616757357`, 0.9345129936055264], 
             UndirectedEdge[111, 199] -> 
             RGBColor[
              0.9076739184987976, 0.597583839511456, 0.5047291662889358], 
             UndirectedEdge[138, 264] -> 
             RGBColor[
              0.27444206081652406`, 0.4057863849228008, 0.9389404414116314], 
             UndirectedEdge[275, 344] -> 
             RGBColor[
              0.19285336525809532`, 0.32003149286881416`, 0.9342940858992375],
              UndirectedEdge[300, 371] -> 
             RGBColor[
              0.1880971018774196, 0.31503235849120814`, 0.934023223735969], 
             UndirectedEdge[69, 273] -> 
             RGBColor[
              0.5484319039049934, 0.644280752022615, 0.9575937149291112], 
             UndirectedEdge[65, 174] -> 
             RGBColor[
              0.39716489293029483`, 0.5184260009934458, 0.9465279736717613], 
             UndirectedEdge[217, 254] -> 
             RGBColor[
              0.1976623221296092, 0.32508601144625143`, 0.934567948878856], 
             UndirectedEdge[102, 378] -> 
             RGBColor[
              0.29463589617818253`, 0.42328641527644917`, 0.9402268398959757],
              UndirectedEdge[246, 326] -> 
             RGBColor[
              0.22913658446266597`, 0.35816745674178546`, 0.9363603615567251],
              UndirectedEdge[120, 242] -> 
             RGBColor[
              0.3764731339021319, 0.500503839321299, 0.9452095130834909], 
             UndirectedEdge[25, 117] -> 
             RGBColor[
              0.4612467201078884, 0.5710736628239611, 0.9514005522875624], 
             UndirectedEdge[44, 227] -> 
             RGBColor[
              0.25115263484712524`, 0.3813077215940698, 0.9376141430562922], 
             UndirectedEdge[118, 206] -> 
             RGBColor[
              0.39316789594043106`, 0.5149640030957358, 0.9462732885579729], 
             UndirectedEdge[151, 158] -> 
             RGBColor[
              0.19937632863451948`, 0.3268875409572013, 0.9346655590136652], 
             UndirectedEdge[151, 308] -> 
             RGBColor[
              0.2102300370530294, 0.33829547666991544`, 0.9352836616514766], 
             UndirectedEdge[298, 390] -> 
             RGBColor[
              0.2092243065114207, 0.3372383901036854, 0.935226386784977], 
             UndirectedEdge[62, 111] -> 
             RGBColor[
              0.9092079691258396, 0.5982182088690406, 0.47930597740308856`], 
             UndirectedEdge[131, 201] -> 
             RGBColor[
              0.7399124857733206, 0.7967445245200704, 0.9747112197727283], 
             UndirectedEdge[291, 368] -> 
             RGBColor[
              0.1896468250359693, 0.3166612157889672, 0.9341114781772385], 
             UndirectedEdge[35, 73] -> 
             RGBColor[
              0.19430576499947028`, 0.3215580570844616, 0.9343767979158759], 
             UndirectedEdge[273, 293] -> 
             RGBColor[
              0.4190878106551068, 0.5354941029446921, 0.9484555024448121], 
             UndirectedEdge[4, 274] -> 
             RGBColor[
              0.2019924165278475, 0.3296372152026416, 0.934814541349035], 
             UndirectedEdge[10, 337] -> 
             RGBColor[
              0.8999731601904741, 0.6493526399014464, 0.5732428918038912], 
             UndirectedEdge[27, 265] -> 
             RGBColor[
              0.20201462184730384`, 0.32966055440128883`, 0.9348158059091283],
              UndirectedEdge[262, 325] -> 
             RGBColor[
              0.3013026030921642, 0.42887910004945207`, 0.9406582888215985], 
             UndirectedEdge[46, 337] -> 
             RGBColor[
              0.8812578483212357, 0.9077231190596664, 0.969479570547889], 
             UndirectedEdge[322, 327] -> 
             RGBColor[
              0.19043725974580353`, 0.3174920127854582, 0.9341564922646202], 
             UndirectedEdge[59, 299] -> 
             RGBColor[
              0.20233103571342284`, 0.3299931254363777, 0.9348338252107113], 
             UndirectedEdge[254, 369] -> 
             RGBColor[
              0.1837415562121556, 0.31045440383947037`, 0.9337751818537847], 
             UndirectedEdge[262, 376] -> 
             RGBColor[
              0.3252561022413611, 0.4540557463948223, 0.9420224051621189], 
             UndirectedEdge[360, 389] -> 
             RGBColor[
              0.8279393932352007, 0.862084309021034, 0.7299551301459482], 
             UndirectedEdge[159, 381] -> 
             RGBColor[
              0.18574510039169012`, 0.3125602558041992, 0.9338892807308311], 
             UndirectedEdge[77, 302] -> 
             RGBColor[
              0.19582677060371215`, 0.3231567304118451, 0.9344634169349113], 
             UndirectedEdge[67, 398] -> 
             RGBColor[
              0.18010682122099816`, 0.306634066908255, 0.9335681890731469], 
             UndirectedEdge[12, 100] -> 
             RGBColor[
              0.315248838603848, 0.44137593165251704`, 0.941531651095973], 
             UndirectedEdge[329, 339] -> 
             RGBColor[
              0.322148238300078, 0.44915969522157617`, 0.9419050804873051], 
             UndirectedEdge[1, 113] -> 
             RGBColor[
              0.18373091059218155`, 0.31044321461790636`, 0.9337745756014759],
              UndirectedEdge[232, 390] -> 
             RGBColor[
              0.20167142330655186`, 0.3292998309749142, 0.9347962612599492], 
             UndirectedEdge[319, 384] -> 
             RGBColor[
              0.8830145607989899, 0.5123899866965502, 0.22206050473742173`], 
             UndirectedEdge[342, 374] -> 
             RGBColor[
              0.18501533393427727`, 0.31179322498759243`, 0.9338477216106742],
              UndirectedEdge[200, 320] -> 
             RGBColor[
              0.18887757795522245`, 0.31585268833402036`, 0.934067670693989], 
             UndirectedEdge[35, 231] -> 
             RGBColor[
              0.19065322565130216`, 0.31771900664516656`, 0.9341687912034454],
              UndirectedEdge[96, 104] -> 
             RGBColor[
              0.21783923349947054`, 0.34629322458604483`, 0.935716994132304], 
             UndirectedEdge[106, 197] -> 
             RGBColor[
              0.18891531916432497`, 0.315892356737718, 0.9340698200000144], 
             UndirectedEdge[41, 265] -> 
             RGBColor[
              0.19689578074158462`, 0.3242803278459065, 0.9345242954808043], 
             UndirectedEdge[52, 303] -> 
             RGBColor[
              0.9414623591594504, 0.8004800076065881, 0.5326277353789215], 
             UndirectedEdge[170, 208] -> 
             RGBColor[
              0.26496099146250607`, 0.3958211798972109, 0.9384005085379051], 
             UndirectedEdge[49, 355] -> 
             RGBColor[
              0.19591924831876065`, 0.3232539303537868, 0.9344686834039748], 
             UndirectedEdge[140, 359] -> 
             RGBColor[
              0.36601815692823686`, 0.491448263748933, 0.9445433311956875], 
             UndirectedEdge[20, 255] -> 
             RGBColor[
              0.37940724758906264`, 0.5030452211240766, 0.9453964722130872], 
             UndirectedEdge[117, 362] -> 
             RGBColor[
              0.6749012549506066, 0.7446731281041272, 0.9691094737182575], 
             UndirectedEdge[188, 293] -> 
             RGBColor[
              0.29496948602480166`, 0.4268642457721712, 0.9401276735084836], 
             UndirectedEdge[149, 155] -> 
             RGBColor[
              0.19811293609800762`, 0.3255596352976139, 0.9345936106777326], 
             UndirectedEdge[7, 188] -> 
             RGBColor[
              0.2653788568535447, 0.3962603829173885, 0.9384243053537484], 
             UndirectedEdge[120, 331] -> 
             RGBColor[
              0.3267582826576653, 0.45117687376714777`, 0.9422711725263158], 
             UndirectedEdge[169, 218] -> 
             RGBColor[
              0.5087675338544672, 0.6120794295560898, 0.9544711904233589], 
             UndirectedEdge[345, 350] -> 
             RGBColor[
              0.5883144988769012, 0.6710348151156551, 0.9634472668058549], 
             UndirectedEdge[147, 217] -> 
             RGBColor[
              0.2277310230294914, 0.3566901225577769, 0.9362803169124476], 
             UndirectedEdge[141, 386] -> 
             RGBColor[
              0.348846857880801, 0.4765753475686286, 0.9434491912043683], 
             UndirectedEdge[128, 383] -> 
             RGBColor[
              0.3311097462205182, 0.46076448615063337`, 0.9423353967308358], 
             UndirectedEdge[138, 394] -> 
             RGBColor[
              0.32326515413332657`, 0.4525833434947314, 0.9418863146939478], 
             UndirectedEdge[132, 300] -> 
             RGBColor[
              0.1945175148280322, 0.3217806195799947, 0.9343888567553567], 
             UndirectedEdge[103, 122] -> 
             RGBColor[
              0.1920779072643653, 0.3192164373505274, 0.9342499247136817], 
             UndirectedEdge[147, 195] -> 
             RGBColor[
              0.3359166803532971, 0.45968692435363845`, 0.9428335921754714], 
             UndirectedEdge[123, 389] -> 
             RGBColor[
              0.9181405448210238, 0.6602175731108506, 0.3409253014924295], 
             UndirectedEdge[93, 394] -> 
             RGBColor[
              0.35007693853437594`, 0.4776407816051039, 0.9435275708558966], 
             UndirectedEdge[199, 350] -> 
             RGBColor[
              0.6686405102956781, 0.7329620420673324, 0.8898856192140527], 
             UndirectedEdge[66, 158] -> 
             RGBColor[
              0.19363377892106423`, 0.3208517571096786, 0.934338529302825], 
             UndirectedEdge[105, 215] -> 
             RGBColor[
              0.8456866310237973, 0.8792487049970009, 0.932290412064394], 
             UndirectedEdge[253, 364] -> 
             RGBColor[
              0.8732653702236979, 0.4602425769354192, 0.2136613812182268], 
             UndirectedEdge[76, 78] -> 
             RGBColor[
              0.2517003601981642, 0.38188341566580475`, 0.9376453352047469], 
             UndirectedEdge[153, 358] -> 
             RGBColor[
              0.24162422522743635`, 0.37129275894771363`, 0.9370715142244698],
              UndirectedEdge[54, 64] -> 
             RGBColor[
              0.970419525130984, 0.9095497585157698, 0.3557751825465969], 
             UndirectedEdge[84, 125] -> 
             RGBColor[
              0.20344264397852102`, 0.33116149620303065`, 0.9348971296569317],
              UndirectedEdge[195, 380] -> 
             RGBColor[
              0.5725002264868254, 0.6618460201126379, 0.9605209500781344], 
             UndirectedEdge[81, 146] -> 
             RGBColor[
              0.2141426413323014, 0.3424078718408697, 0.9355064786770019], 
             UndirectedEdge[275, 317] -> 
             RGBColor[
              0.19132418052101102`, 0.3184242227542263, 0.9342070010906866], 
             UndirectedEdge[25, 377] -> 
             RGBColor[
              0.3093279743113551, 0.4373486105761115, 0.941114064611224], 
             UndirectedEdge[180, 232] -> 
             RGBColor[
              0.18939213687360562`, 0.3163935223821609, 0.9340969740631693], 
             UndirectedEdge[52, 333] -> 
             RGBColor[
              0.9713855964493081, 0.9773821088501203, 0.8975894720005477], 
             UndirectedEdge[97, 276] -> 
             RGBColor[
              0.33883500638970604`, 0.46696780675347616`, 0.9428455083067513],
              UndirectedEdge[51, 390] -> 
             RGBColor[
              0.2070958500160861, 0.33500124737515247`, 0.935105174336337], 
             UndirectedEdge[199, 393] -> 
             RGBColor[
              0.8553537557812887, 0.8861695254659845, 0.9046321600313321], 
             UndirectedEdge[169, 224] -> 
             RGBColor[
              0.4775031351026399, 0.5866975822042433, 0.9520099424283488], 
             UndirectedEdge[132, 268] -> 
             RGBColor[
              0.19026708475134468`, 0.3173131480765642, 0.9341468010504371], 
             UndirectedEdge[162, 183] -> 
             RGBColor[
              0.1919904214056781, 0.3191244841661233, 0.9342449425234534], 
             UndirectedEdge[15, 231] -> 
             RGBColor[
              0.18666830847322874`, 0.31353060603266947`, 0.9339418560653108],
              UndirectedEdge[246, 248] -> 
             RGBColor[
              0.19980719089443424`, 0.32734040451061686`, 0.9346900959819637],
              UndirectedEdge[44, 81] -> 
             RGBColor[
              0.22873470286488637`, 0.35774505370175413`, 0.9363374749942621],
              UndirectedEdge[39, 197] -> 
             RGBColor[
              0.19474286460527196`, 0.3220174764838748, 0.9344016900917953], 
             UndirectedEdge[57, 86] -> 
             RGBColor[
              0.30819911150930557`, 0.43761024408224003`, 0.9409967540495674],
              UndirectedEdge[74, 209] -> 
             RGBColor[
              0.2567896978925637, 0.3872326322652657, 0.9379351654574425], 
             UndirectedEdge[115, 389] -> 
             RGBColor[
              0.9741155744429982, 0.9237122058552483, 0.3878131353348738], 
             UndirectedEdge[157, 168] -> 
             RGBColor[
              0.222412865673202, 0.35110040198566517`, 0.9359774557185156], 
             UndirectedEdge[224, 363] -> 
             RGBColor[
              0.4361366781535445, 0.5509750361546019, 0.9493445440011021], 
             UndirectedEdge[47, 279] -> 
             RGBColor[
              0.19002059109890063`, 0.3170540676192452, 0.934132763601585], 
             UndirectedEdge[58, 352] -> 
             RGBColor[
              0.18979453396815193`, 0.3168164672419784, 0.9341198899824106], 
             UndirectedEdge[101, 161] -> 
             RGBColor[
              0.8667600435785252, 0.4809006664576717, 0.21026073973276477`], 
             UndirectedEdge[23, 98] -> 
             RGBColor[
              0.2025842284056299, 0.3302592470092312, 0.9348482441599675], 
             UndirectedEdge[37, 388] -> 
             RGBColor[
              0.27755649571754953`, 0.4090598534703564, 0.9391178038718512], 
             UndirectedEdge[13, 21] -> 
             RGBColor[
              0.2050154097981298, 0.332814572798552, 0.9349866963436598], 
             UndirectedEdge[159, 375] -> 
             RGBColor[
              0.19246854917072223`, 0.3196270267622359, 0.9342721711923458], 
             UndirectedEdge[130, 346] -> 
             RGBColor[
              0.20954480137125253`, 0.3375752505219164, 0.9352446384931148], 
             UndirectedEdge[104, 225] -> 
             RGBColor[
              0.2162656212099744, 0.3446392582970026, 0.935627379240368], 
             UndirectedEdge[226, 252] -> 
             RGBColor[
              0.19892295516503677`, 0.32641101669523676`, 0.9346397400652842],
              UndirectedEdge[64, 283] -> 
             RGBColor[
              0.9622538962308652, 0.8771757609613251, 0.3492049258616166], 
             UndirectedEdge[262, 284] -> 
             RGBColor[
              0.5520990373737982, 0.6433480852372535, 0.9595712205145508], 
             UndirectedEdge[282, 313] -> 
             RGBColor[
              0.2998205585054363, 0.43188039345676055`, 0.940406960657616], 
             UndirectedEdge[88, 360] -> 
             RGBColor[
              0.5465756968337885, 0.6418389618053506, 0.9578331782484879], 
             UndirectedEdge[210, 230] -> 
             RGBColor[
              0.2334030426063412, 0.36265177475985827`, 0.9366033300363481], 
             UndirectedEdge[2, 138] -> 
             RGBColor[
              0.24536530114030092`, 0.3752248669300471, 0.9372845629632816], 
             UndirectedEdge[178, 367] -> 
             RGBColor[
              0.18455036747987072`, 0.3113045157634352, 0.933821242458952], 
             UndirectedEdge[54, 123] -> 
             RGBColor[
              0.8957058066069172, 0.5826430148496441, 0.23309163667201951`], 
             UndirectedEdge[36, 95] -> 
             RGBColor[
              0.2464425329575721, 0.37635710587044113`, 0.9373459097216534], 
             UndirectedEdge[294, 301] -> 
             RGBColor[
              0.22980051567191817`, 0.3588652905383795, 0.9363981714568937], 
             UndirectedEdge[60, 337] -> 
             RGBColor[
              0.8320015089413489, 0.8692436923740543, 0.9645701589651641], 
             UndirectedEdge[251, 275] -> 
             RGBColor[
              0.1895350470293607, 0.3165437300168866, 0.9341051125851229], 
             UndirectedEdge[66, 311] -> 
             RGBColor[
              0.19936169446772767`, 0.32687215952004334`, 0.9346647256195157],
              UndirectedEdge[110, 400] -> 
             RGBColor[
              0.8375389435666232, 0.5282930654888892, 0.5773241994710698], 
             UndirectedEdge[143, 151] -> 
             RGBColor[
              0.2032578843654731, 0.3309673021352812, 0.934886607870296], 
             UndirectedEdge[157, 206] -> 
             RGBColor[
              0.3378748813614898, 0.46135031520372605`, 0.942959564481942], 
             UndirectedEdge[226, 274] -> 
             RGBColor[
              0.1975222198425889, 0.324938755059595, 0.9345599702608729], 
             UndirectedEdge[86, 265] -> 
             RGBColor[
              0.23354789403514828`, 0.36280402279564555`, 0.9366115791109302],
              UndirectedEdge[64, 389] -> 
             RGBColor[
              0.9928542633450905, 0.9871243167769764, 0.4636088473670069], 
             UndirectedEdge[120, 356] -> 
             RGBColor[
              0.6789656354460096, 0.7452687768356042, 0.9624218591420297], 
             UndirectedEdge[164, 279] -> 
             RGBColor[
              0.20701484030443992`, 0.33491610103189995`, 0.9351005609531018],
              UndirectedEdge[24, 238] -> 
             RGBColor[
              0.23053198107939255`, 0.35963410705922055`, 0.9364398273297434],
              UndirectedEdge[213, 259] -> 
             RGBColor[
              0.6104189913379899, 0.6878648671799451, 0.9659218116631232], 
             UndirectedEdge[73, 162] -> 
             RGBColor[
              0.19690433907813965`, 0.3242893232002557, 0.9345247828654102], 
             UndirectedEdge[257, 356] -> 
             RGBColor[
              0.9574019127188883, 0.9677509967704889, 0.9569916297931109], 
             UndirectedEdge[6, 281] -> 
             RGBColor[
              0.6624572537085711, 0.7318807392393671, 0.9697242643368251], 
             UndirectedEdge[176, 277] -> 
             RGBColor[
              0.18565952896853344`, 0.31247031481291987`, 0.933884407564874], 
             UndirectedEdge[140, 263] -> 
             RGBColor[
              0.35408935706105976`, 0.48047689556673456`, 0.943806644371628], 
             UndirectedEdge[54, 161] -> 
             RGBColor[
              0.9139000708098552, 0.6892402426005217, 0.2492124251865322], 
             UndirectedEdge[7, 142] -> 
             RGBColor[
              0.36455405628776205`, 0.4846402873807406, 0.9447885201049626], 
             UndirectedEdge[81, 311] -> 
             RGBColor[
              0.21587607865268055`, 0.34422982437086214`, 0.9356051953680067],
              UndirectedEdge[204, 237] -> 
             RGBColor[
              0.18108298927677668`, 0.3076600814275077, 0.9336237803998122], 
             UndirectedEdge[134, 374] -> 
             RGBColor[
              0.18137577945827954`, 0.307967822472237, 0.9336404543675045], 
             UndirectedEdge[264, 279] -> 
             RGBColor[
              0.22950792112061041`, 0.35855775511338905`, 0.9363815086300517],
              UndirectedEdge[81, 344] -> 
             RGBColor[
              0.2103592408268638, 0.3384312780282078, 0.9352910196152566], 
             UndirectedEdge[287, 391] -> 
             RGBColor[
              0.8187766066009462, 0.14533080306215745`, 0.16561380572719725`],
              UndirectedEdge[90, 228] -> 
             RGBColor[
              0.21978849971833822`, 0.34834202697269134`, 0.9358280019597877],
              UndirectedEdge[222, 259] -> 
             RGBColor[
              0.9232560562805229, 0.9412465076079086, 0.9787839457914527], 
             UndirectedEdge[143, 342] -> 
             RGBColor[
              0.19264878464975516`, 0.3198164656782889, 0.9342824353362423], 
             UndirectedEdge[68, 262] -> 
             RGBColor[
              0.5929687866565062, 0.6752889407487281, 0.9636412596987081], 
             UndirectedEdge[73, 189] -> 
             RGBColor[
              0.2158427366159144, 0.3441947797762137, 0.9356032965883381], 
             UndirectedEdge[79, 176] -> 
             RGBColor[
              0.19262785863960308`, 0.31979447111483345`, 0.9342812436309215],
              UndirectedEdge[14, 289] -> 
             RGBColor[
              0.4064318553204269, 0.5258851919600367, 0.9472752267865294], 
             UndirectedEdge[126, 373] -> 
             RGBColor[
              0.19027225530167013`, 0.317318582652788, 0.934147095505629], 
             UndirectedEdge[313, 361] -> 
             RGBColor[
              0.3470958164482592, 0.47282784576328063`, 0.9434192982898635], 
             UndirectedEdge[56, 203] -> 
             RGBColor[
              0.4142038212467356, 0.5314171873708888, 0.948101927737594], 
             UndirectedEdge[163, 240] -> 
             RGBColor[
              0.17919351847301027`, 0.305674127813381, 0.9335161778327592], 
             UndirectedEdge[283, 380] -> 
             RGBColor[
              0.8261523609821573, 0.7746449493883936, 0.6184230525835972], 
             UndirectedEdge[165, 318] -> 
             RGBColor[
              0.21949852941857476`, 0.348037249802461, 0.9358114885801888], 
             UndirectedEdge[184, 185] -> 
             RGBColor[
              0.20305130848505737`, 0.330750177787297, 0.9348748436795078], 
             UndirectedEdge[123, 364] -> 
             RGBColor[
              0.8822480780789155, 0.5292876057583029, 0.22226323240490067`], 
             UndirectedEdge[24, 341] -> 
             RGBColor[
              0.25476263408947386`, 0.38510205968495004`, 0.9378197271726287],
              UndirectedEdge[10, 364] -> 
             RGBColor[
              0.8821527210971085, 0.5285546502104392, 0.22217191845143208`], 
             UndirectedEdge[59, 132] -> 
             RGBColor[
              0.20457320024571096`, 0.33234978252125474`, 0.93496151316384], 
             UndirectedEdge[110, 309] -> 
             RGBColor[
              0.7751646817101416, 0.8245503622153614, 0.9781540938970312], 
             UndirectedEdge[28, 50] -> 
             RGBColor[
              0.21136185866227802`, 0.33948509294287055`, 0.9353481172177434],
              UndirectedEdge[120, 147] -> 
             RGBColor[
              0.3298813986080268, 0.4544594666479659, 0.9424490293594527], 
             UndirectedEdge[322, 335] -> 
             RGBColor[
              0.19668775397946056`, 0.3240616785292556, 0.9345124486644494], 
             UndirectedEdge[9, 198] -> 
             RGBColor[
              0.7575782172127392, 0.8106163649808842, 0.9764530707316865], 
             UndirectedEdge[214, 257] -> 
             RGBColor[
              0.9241708234933428, 0.7599031818045514, 0.5786645333196092], 
             UndirectedEdge[190, 274] -> 
             RGBColor[
              0.20764624835933113`, 0.33557975093117354`, 0.9351365187077434],
              UndirectedEdge[18, 198] -> 
             RGBColor[
              0.9106667100371233, 0.9263839830131071, 0.7062421502048801], 
             UndirectedEdge[280, 291] -> 
             RGBColor[
              0.20219476439486456`, 0.32984989564047235`, 0.9348260647607148],
              UndirectedEdge[156, 179] -> 
             RGBColor[
              0.21434244441768896`, 0.34261787755185935`, 0.9355178571671325],
              UndirectedEdge[76, 96] -> 
             RGBColor[
              0.24728213971667218`, 0.37723958580839845`, 0.9373937240844974],
              UndirectedEdge[143, 158] -> 
             RGBColor[
              0.1950219034609478, 0.3223107640132754, 0.9344175809418251], 
             UndirectedEdge[252, 274] -> 
             RGBColor[
              0.20454056169243495`, 0.3323154773323579, 0.9349596544465153], 
             UndirectedEdge[272, 348] -> 
             RGBColor[
              0.1988777254844435, 0.3263634774332058, 0.9346371643018856], 
             UndirectedEdge[51, 232] -> 
             RGBColor[
              0.19578437289714112`, 0.32311216773406903`, 0.9344610024482438],
              UndirectedEdge[66, 317] -> 
             RGBColor[
              0.19231567190482668`, 0.3194663430628012, 0.9342634650582149], 
             UndirectedEdge[258, 264] -> 
             RGBColor[
              0.24881577416889822`, 0.37885153285572853`, 0.9374810622977428],
              UndirectedEdge[17, 223] -> 
             RGBColor[
              0.843439007132864, 0.3336207383005069, 0.18918058014291417`], 
             UndirectedEdge[46, 271] -> 
             RGBColor[
              0.8127696138510401, 0.5013829917925117, 0.574019985211861], 
             UndirectedEdge[93, 201] -> 
             RGBColor[
              0.5041214136186714, 0.6049415425126292, 0.9551812111618987], 
             UndirectedEdge[232, 373] -> 
             RGBColor[
              0.19417254912152382`, 0.3214180387503654, 0.934369211468702], 
             UndirectedEdge[182, 208] -> 
             RGBColor[
              0.2681228139523549, 0.39914445580516655`, 0.9385805696512048], 
             UndirectedEdge[10, 391] -> 
             RGBColor[
              0.8316006559249898, 0.24390206570100256`, 0.1778941298425935], 
             UndirectedEdge[284, 366] -> 
             RGBColor[
              0.8665824589296481, 0.8923925729410807, 0.7434186835178305], 
             UndirectedEdge[154, 387] -> 
             RGBColor[
              0.18595738695423472`, 0.312783382441179, 0.9339013701365182], 
             UndirectedEdge[135, 363] -> 
             RGBColor[
              0.3549405295448861, 0.4818533796872159, 0.9438374745743816], 
             UndirectedEdge[37, 269] -> 
             RGBColor[
              0.3188674209826161, 0.4483513791388215, 0.9416215783296149], 
             UndirectedEdge[201, 281] -> 
             RGBColor[
              0.5322326354554701, 0.6292900699565726, 0.956972433359562], 
             UndirectedEdge[302, 377] -> 
             RGBColor[
              0.22469777382228445`, 0.35350198532189486`, 0.9361075778573873],
              UndirectedEdge[179, 286] -> 
             RGBColor[
              0.2740282991513247, 0.4041960245612692, 0.9389591857364195], 
             UndirectedEdge[108, 325] -> 
             RGBColor[
              0.2723177927173417, 0.4035536444641835, 0.9388194674859559], 
             UndirectedEdge[279, 299] -> 
             RGBColor[
              0.19371330684929777`, 0.320935346004614, 0.9343430583006869], 
             UndirectedEdge[196, 332] -> 
             RGBColor[
              0.8309647608435446, 0.5082040216040586, 0.5748389341298874], 
             UndirectedEdge[31, 224] -> 
             RGBColor[
              0.7410029688449329, 0.7954456814088879, 0.9320732118445416], 
             UndirectedEdge[200, 296] -> 
             RGBColor[
              0.1865617818736295, 0.3134186398223141, 0.9339357895330556], 
             UndirectedEdge[170, 221] -> 
             RGBColor[
              0.30270787399814014`, 0.42984035374028506`, 0.9407572019749026],
              UndirectedEdge[198, 206] -> 
             RGBColor[
              0.6288429856334741, 0.7061140055023541, 0.9660410068543737], 
             UndirectedEdge[36, 361] -> 
             RGBColor[
              0.32761397052464425`, 0.4523511904771868, 0.9423098359853219], 
             UndirectedEdge[132, 180] -> 
             RGBColor[
              0.1906491777676344, 0.3177147520627811, 0.9341685606824588], 
             UndirectedEdge[127, 312] -> 
             RGBColor[
              0.44359264480187605`, 0.5560735292696781, 0.9501952628642483], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.37498442055197767`, 0.49560326154572176`, 0.9453825139194686],
              UndirectedEdge[67, 75] -> 
             RGBColor[
              0.1806580838475214, 0.3072134788808002, 0.9335995826642074], 
             UndirectedEdge[110, 287] -> 
             RGBColor[
              0.8351408344121083, 0.5098601476691562, 0.5750277674364295], 
             UndirectedEdge[88, 233] -> 
             RGBColor[
              0.7003634497191511, 0.7623012578281982, 0.9418757273882692], 
             UndirectedEdge[168, 216] -> 
             RGBColor[
              0.20689038450304525`, 0.3347852900936806, 0.9350934733793282], 
             UndirectedEdge[1, 291] -> 
             RGBColor[
              0.1886369117353484, 0.31559973287781307`, 0.934053965108801], 
             UndirectedEdge[115, 214] -> 
             RGBColor[
              0.917014626987943, 0.7014084006737106, 0.2517091579831441], 
             UndirectedEdge[233, 256] -> 
             RGBColor[
              0.9813174831621745, 0.9842395002462874, 0.8561565043579783], 
             UndirectedEdge[4, 252] -> 
             RGBColor[
              0.20339315185029538`, 0.3311094768382833, 0.9348943111534462], 
             UndirectedEdge[91, 399] -> 
             RGBColor[
              0.4759758631677278, 0.5829069233744436, 0.9525944899971995], 
             UndirectedEdge[76, 269] -> 
             RGBColor[
              0.3181691701834686, 0.44761747327725976`, 0.9415818139795731], 
             UndirectedEdge[91, 172] -> 
             RGBColor[
              0.48609962486048197`, 0.5916756169176496, 0.9532395671401708], 
             UndirectedEdge[165, 184] -> 
             RGBColor[
              0.21954677082243013`, 0.3480879545765947, 0.9358142358567716], 
             UndirectedEdge[60, 139] -> 
             RGBColor[
              0.506983675095762, 0.6054995726195224, 0.9561122679612462], 
             UndirectedEdge[356, 359] -> 
             RGBColor[
              0.6355366085129286, 0.7076527365125309, 0.9596545999486343], 
             UndirectedEdge[228, 305] -> 
             RGBColor[
              0.26103370837156087`, 0.39169335636449776`, 0.9381768555757705],
              UndirectedEdge[141, 209] -> 
             RGBColor[
              0.3104061832925851, 0.4392395615986554, 0.9411477244574119], 
             UndirectedEdge[171, 348] -> 
             RGBColor[
              0.1945787269842331, 0.32184495743723673`, 0.934392342697097], 
             UndirectedEdge[10, 60] -> 
             RGBColor[
              0.774995447398962, 0.551160577750298, 0.5801059153920654], 
             UndirectedEdge[234, 298] -> 
             RGBColor[
              0.22620097648238727`, 0.3550819466262163, 0.936193183025091], 
             UndirectedEdge[323, 388] -> 
             RGBColor[
              0.34570167664203966`, 0.47034107110967827`, 0.9433773042073184],
              UndirectedEdge[294, 329] -> 
             RGBColor[
              0.23603593247132534`, 0.36541910894281576`, 0.9367532692191475],
              UndirectedEdge[211, 238] -> 
             RGBColor[
              0.21668562529693003`, 0.34508070922219014`, 0.9356512978517798],
              UndirectedEdge[31, 99] -> 
             RGBColor[
              0.9432122400933031, 0.9562926111989585, 0.9505366840460105], 
             UndirectedEdge[111, 319] -> 
             RGBColor[
              0.8295282339464709, 0.2279725222330049, 0.17590957621549802`], 
             UndirectedEdge[258, 394] -> 
             RGBColor[
              0.29763886748570073`, 0.42564849142765915`, 0.9404269355800592],
              UndirectedEdge[101, 364] -> 
             RGBColor[
              0.8876560448428017, 0.5708556080916793, 0.22744190748542303`], 
             UndirectedEdge[225, 349] -> 
             RGBColor[
              0.2034483891040132, 0.3311675346941849, 0.9348974568333293], 
             UndirectedEdge[118, 386] -> 
             RGBColor[
              0.34968714140668505`, 0.4773031589248714, 0.9435027333276041], 
             UndirectedEdge[95, 326] -> 
             RGBColor[
              0.24440137831360023`, 0.3742117229229475, 0.9372296689842969], 
             UndirectedEdge[228, 382] -> 
             RGBColor[
              0.27305197131929326`, 0.4030910170101112, 0.9389064714836659], 
             UndirectedEdge[120, 255] -> 
             RGBColor[
              0.39336824955180094`, 0.5151375393238391, 0.9462860549129236], 
             UndirectedEdge[222, 292] -> 
             RGBColor[
              0.8852896880649895, 0.5569352274955306, 0.5669895272748917], 
             UndirectedEdge[325, 397] -> 
             RGBColor[
              0.3012257827964342, 0.4288125621703911, 0.9406533939002841], 
             UndirectedEdge[155, 299] -> 
             RGBColor[
              0.1871446834102983, 0.31403130629544507`, 0.9339689849132433], 
             UndirectedEdge[17, 99] -> 
             RGBColor[
              0.8649138899410389, 0.5692261022124661, 0.5823263856846504], 
             UndirectedEdge[60, 105] -> 
             RGBColor[
              0.8461630434103341, 0.8796208819742317, 0.932337896398757], 
             UndirectedEdge[229, 340] -> 
             RGBColor[
              0.23465687622616624`, 0.36396963339193744`, 0.9366747340061166],
              UndirectedEdge[297, 375] -> 
             RGBColor[
              0.2496778587950193, 0.3797576384571041, 0.9375301567418605], 
             UndirectedEdge[155, 249] -> 
             RGBColor[
              0.18476081976801417`, 0.3115257144617197, 0.9338332274054255], 
             UndirectedEdge[143, 348] -> 
             RGBColor[
              0.20000377872339242`, 0.3275470307832401, 0.9347012913679973], 
             UndirectedEdge[175, 294] -> 
             RGBColor[
              0.19993479870238595`, 0.3274745284075764, 0.9346973630578478], 
             UndirectedEdge[19, 181] -> 
             RGBColor[
              0.19581756515250187`, 0.3231470548989638, 0.9344628926980831], 
             UndirectedEdge[153, 294] -> 
             RGBColor[
              0.20769214048678164`, 0.33562798646685293`, 0.9351391321965103],
              UndirectedEdge[68, 376] -> 
             RGBColor[
              0.5538916735521564, 0.639355835105775, 0.9612276966528428], 
             UndirectedEdge[317, 354] -> 
             RGBColor[
              0.19230267119241712`, 0.319452678489766, 0.934262724686876], 
             UndirectedEdge[2, 254] -> 
             RGBColor[
              0.19445154659843222`, 0.32171128278805783`, 0.9343850999622723],
              UndirectedEdge[243, 311] -> 
             RGBColor[
              0.21699506567726595`, 0.34540595068157653`, 0.9356689200236639],
              UndirectedEdge[23, 143] -> 
             RGBColor[
              0.20541157212716055`, 0.3332309645245057, 0.9350092572022285], 
             UndirectedEdge[20, 64] -> 
             RGBColor[
              0.6886054780275248, 0.7470570557801346, 0.690028677840299], 
             UndirectedEdge[75, 296] -> 
             RGBColor[
              0.18049305546872535`, 0.30704002359128196`, 0.9335901845421726],
              UndirectedEdge[146, 227] -> 
             RGBColor[
              0.2365605733145403, 0.3659705397331854, 0.936783146739032], 
             UndirectedEdge[160, 238] -> 
             RGBColor[
              0.19808883610787825`, 0.32553430467996036`, 0.9345922382189475],
              UndirectedEdge[75, 178] -> 
             RGBColor[
              0.18245868691760933`, 0.30910602687229105`, 0.9337021243452953],
              UndirectedEdge[95, 166] -> 
             RGBColor[
              0.24620280791930751`, 0.37610513965577974`, 0.9373322577353658],
              UndirectedEdge[25, 309] -> 
             RGBColor[
              0.5306642654095335, 0.6265873056000757, 0.957441478589943], 
             UndirectedEdge[166, 326] -> 
             RGBColor[
              0.24337300372818133`, 0.3731308360309576, 0.9371711045730012], 
             UndirectedEdge[158, 308] -> 
             RGBColor[
              0.20199405614850408`, 0.32963893854790965`, 0.9348146347230057],
              UndirectedEdge[229, 343] -> 
             RGBColor[
              0.1993208104479567, 0.32682918782306747`, 0.9346623973350723], 
             UndirectedEdge[229, 294] -> 
             RGBColor[
              0.20382733943636777`, 0.33156583552032837`, 0.9349190374941501],
              UndirectedEdge[64, 257] -> 
             RGBColor[
              0.9810027572631417, 0.9816315939147817, 0.6854880311912166], 
             UndirectedEdge[56, 65] -> 
             RGBColor[
              0.4474461015886463, 0.5602099797974611, 0.9502200964459863], 
             UndirectedEdge[170, 192] -> 
             RGBColor[
              0.2468852126322833, 0.37682239027607506`, 0.9373711196742425], 
             UndirectedEdge[133, 347] -> 
             RGBColor[
              0.18386468807739512`, 0.3105838232368483, 0.9337821940313528], 
             UndirectedEdge[223, 393] -> 
             RGBColor[
              0.7905940425099285, 0.6181725668402647, 0.5885810229879949], 
             UndirectedEdge[116, 338] -> 
             RGBColor[
              0.22507866009155236`, 0.35390232094047974`, 0.9361292687669514],
              UndirectedEdge[32, 71] -> 
             RGBColor[
              0.8956113709184261, 0.5716673969312225, 0.5522037062726537], 
             UndirectedEdge[95, 361] -> 
             RGBColor[
              0.32840262007179855`, 0.45318011115451534`, 0.9423547484103298],
              UndirectedEdge[247, 292] -> 
             RGBColor[
              0.8184153147444937, 0.14255375553436297`, 0.16526783223743757`],
              UndirectedEdge[337, 391] -> 
             RGBColor[
              0.8886067174673766, 0.5619851803247587, 0.5623583734156922], 
             UndirectedEdge[181, 238] -> 
             RGBColor[
              0.1965022388034804, 0.3238666903169589, 0.9345018838496224], 
             UndirectedEdge[97, 246] -> 
             RGBColor[
              0.2576631748496625, 0.38815071192881434`, 0.9379849086779559], 
             UndirectedEdge[62, 247] -> 
             RGBColor[
              0.9045712992599508, 0.5625787324781286, 0.4748658971031438], 
             UndirectedEdge[207, 280] -> 
             RGBColor[
              0.200223112625469, 0.32777756462089525`, 0.9347137821092452], 
             UndirectedEdge[145, 221] -> 
             RGBColor[
              0.3098924284635012, 0.43739177601044266`, 0.941166351723109], 
             UndirectedEdge[10, 334] -> 
             RGBColor[
              0.9015893430893124, 0.6043580043169925, 0.2443543042542488], 
             UndirectedEdge[25, 78] -> 
             RGBColor[
              0.29221377727191306`, 0.41936050438489303`, 0.9401394364080135],
              UndirectedEdge[46, 139] -> 
             RGBColor[
              0.5562400144756487, 0.6439789993051345, 0.961021679543971], 
             UndirectedEdge[224, 383] -> 
             RGBColor[
              0.42803255257249384`, 0.5439556499014909, 0.9488281562852744], 
             UndirectedEdge[138, 164] -> 
             RGBColor[
              0.2519489800003536, 0.38214473084131173`, 0.9376594937346815], 
             UndirectedEdge[53, 93] -> 
             RGBColor[
              0.37256678589576175`, 0.4971203570169409, 0.9449606040427729], 
             UndirectedEdge[31, 199] -> 
             RGBColor[
              0.9864970705564884, 0.9886842059127192, 0.8734420155476115], 
             UndirectedEdge[98, 342] -> 
             RGBColor[
              0.1898214409282245, 0.31684474816301444`, 0.9341214222939813], 
             UndirectedEdge[141, 304] -> 
             RGBColor[
              0.31901866548224, 0.4482918264428926, 0.9416381925770871], 
             UndirectedEdge[32, 105] -> 
             RGBColor[
              0.903410578527918, 0.577299573576944, 0.5307412035187635], 
             UndirectedEdge[216, 329] -> 
             RGBColor[
              0.23907766788565177`, 0.368616165720437, 0.936926491551149], 
             UndirectedEdge[164, 264] -> 
             RGBColor[
              0.23748584663754294`, 0.36694306066137816`, 0.9368358396859577],
              UndirectedEdge[118, 196] -> 
             RGBColor[
              0.6007859963931654, 0.6812853787799371, 0.9644958808837701], 
             UndirectedEdge[75, 398] -> 
             RGBColor[
              0.18135843161484838`, 0.30794958878887396`, 0.9336394664334849],
              UndirectedEdge[45, 48] -> 
             RGBColor[
              0.2238300988639671, 0.3525900039269335, 0.9360581650521211], 
             UndirectedEdge[248, 275] -> 
             RGBColor[
              0.18852850716525682`, 0.3154857928014001, 0.9340477916289045], 
             UndirectedEdge[200, 347] -> 
             RGBColor[
              0.1891857716327594, 0.31617661942971953`, 0.9340852218679931], 
             UndirectedEdge[33, 58] -> 
             RGBColor[
              0.21989646734481127`, 0.3484555077936574, 0.9358341505563915], 
             UndirectedEdge[134, 240] -> 
             RGBColor[
              0.17922390736570504`, 0.3057060684663703, 0.9335179084352418], 
             UndirectedEdge[267, 344] -> 
             RGBColor[
              0.1945632673718405, 0.321828708404416, 0.9343914622950418], 
             UndirectedEdge[141, 286] -> 
             RGBColor[
              0.3385051144347327, 0.4676178491867835, 0.9427902244568296], 
             UndirectedEdge[33, 209] -> 
             RGBColor[
              0.25581747523043485`, 0.38621076460489123`, 0.9378797988151089],
              UndirectedEdge[47, 155] -> 
             RGBColor[
              0.18345196765990118`, 0.3101500279100763, 0.9337586902141416], 
             UndirectedEdge[153, 229] -> 
             RGBColor[
              0.2017865527982215, 0.3294208393702904, 0.934802817714181], 
             UndirectedEdge[64, 161] -> 
             RGBColor[
              0.9360657953387055, 0.766239407790421, 0.32776561052681985`], 
             UndirectedEdge[3, 293] -> 
             RGBColor[
              0.2751725873267546, 0.40605645004464963`, 0.939000269414517], 
             UndirectedEdge[133, 178] -> 
             RGBColor[
              0.18320632976714918`, 0.309891846910452, 0.9337447014995381], 
             UndirectedEdge[113, 162] -> 
             RGBColor[
              0.19047273002269705`, 0.31752929429541876`, 0.9341585122444157],
              UndirectedEdge[313, 358] -> 
             RGBColor[
              0.28110733593194254`, 0.4127920116719563, 0.9393200189690635], 
             UndirectedEdge[259, 292] -> 
             RGBColor[
              0.8574582528162021, 0.5351400233172219, 0.5780931752640834], 
             UndirectedEdge[4, 165] -> 
             RGBColor[
              0.21319278532882907`, 0.3414095129568713, 0.9354523857827901], 
             UndirectedEdge[247, 385] -> 
             RGBColor[
              0.9058781642243791, 0.5623734342527853, 0.3990017564205388], 
             UndirectedEdge[38, 243] -> 
             RGBColor[
              0.24505985490147014`, 0.37490382356662577`, 0.9372671682518474],
              UndirectedEdge[265, 381] -> 
             RGBColor[
              0.19417265233719494`, 0.3214181472365799, 0.9343692173466818], 
             UndirectedEdge[15, 369] -> 
             RGBColor[
              0.18126767848005537`, 0.30785420149012543`, 0.9336342981767156],
              UndirectedEdge[30, 358] -> 
             RGBColor[
              0.2391480425105603, 0.3686901339132248, 0.9369304992819277], 
             UndirectedEdge[133, 330] -> 
             RGBColor[
              0.1860526851696524, 0.3128835469078388, 0.9339067972289052], 
             UndirectedEdge[223, 292] -> 
             RGBColor[
              0.8393541052177236, 0.30222239216530483`, 0.1852688734557389], 
             UndirectedEdge[44, 326] -> 
             RGBColor[
              0.2349425006851034, 0.3642698428079171, 0.9366909998965096], 
             UndirectedEdge[123, 356] -> 
             RGBColor[
              0.8942706865915142, 0.6457615828952505, 0.5831484206142015], 
             UndirectedEdge[35, 154] -> 
             RGBColor[
              0.18823624142486384`, 0.31517860297752887`, 0.9340311475273575],
              UndirectedEdge[146, 151] -> 
             RGBColor[
              0.20337080686080378`, 0.3310859908375735, 0.9348930386393511], 
             UndirectedEdge[111, 287] -> 
             RGBColor[
              0.8219655423100481, 0.16984236032285321`, 0.168667534163621], 
             UndirectedEdge[42, 133] -> 
             RGBColor[
              0.1836453052262827, 0.310353237950653, 0.9337697005025297], 
             UndirectedEdge[40, 103] -> 
             RGBColor[
              0.19411926264855695`, 0.32136203128871965`, 0.9343661768828968],
              UndirectedEdge[219, 260] -> 
             RGBColor[
              0.1839290162486566, 0.31065143622348573`, 0.9337858574255411], 
             UndirectedEdge[151, 186] -> 
             RGBColor[
              0.20709670832782653`, 0.33500214951521173`, 0.9351052232159208],
              UndirectedEdge[8, 76] -> 
             RGBColor[
              0.26926683315553557`, 0.4003468925227164, 0.9386457198524012], 
             UndirectedEdge[124, 167] -> 
             RGBColor[
              0.23121257205082407`, 0.360349451322155, 0.9364785859787222], 
             UndirectedEdge[162, 291] -> 
             RGBColor[
              0.1953787311658639, 0.32268581255532547`, 0.9344379017517408], 
             UndirectedEdge[242, 255] -> 
             RGBColor[
              0.3572936731332409, 0.48389155439101317`, 0.9439874148030284], 
             UndirectedEdge[182, 323] -> 
             RGBColor[
              0.3312247462121247, 0.45512489933743366`, 0.9425528644360341], 
             UndirectedEdge[138, 149] -> 
             RGBColor[
              0.2496156992329207, 0.3796923048161946, 0.9375266168467558], 
             UndirectedEdge[199, 353] -> 
             RGBColor[
              0.9909977762454061, 0.988800838647677, 0.6720451430779383], 
             UndirectedEdge[34, 381] -> 
             RGBColor[
              0.18614322275265005`, 0.3129787076479837, 0.9339119532103186], 
             UndirectedEdge[148, 305] -> 
             RGBColor[
              0.2773062230664102, 0.4087968010458064, 0.939103551214614], 
             UndirectedEdge[97, 383] -> 
             RGBColor[
              0.32847115554353346`, 0.45799116005281093`, 0.9421851328952267],
              UndirectedEdge[154, 207] -> 
             RGBColor[
              0.18894498275511917`, 0.315923535052423, 0.9340715092976267], 
             UndirectedEdge[272, 375] -> 
             RGBColor[
              0.1997235147350348, 0.3272524555617131, 0.9346853307484737], 
             UndirectedEdge[25, 323] -> 
             RGBColor[
              0.3922918508728892, 0.5142052168895364, 0.9462174677409253], 
             UndirectedEdge[236, 334] -> 
             RGBColor[
              0.7349237676396162, 0.7451154652166593, 0.6272347577119612], 
             UndirectedEdge[23, 346] -> 
             RGBColor[
              0.20767293699657277`, 0.3356078023810718, 0.935138038586152], 
             UndirectedEdge[23, 151] -> 
             RGBColor[
              0.20976599730073225`, 0.3378077414684315, 0.9352572352740687], 
             UndirectedEdge[250, 381] -> 
             RGBColor[
              0.19153445496524343`, 0.31864523452728444`, 0.9342189759092124],
              UndirectedEdge[230, 264] -> 
             RGBColor[
              0.2405521506109405, 0.3701659405523198, 0.9370104611610526], 
             UndirectedEdge[60, 68] -> 
             RGBColor[
              0.7643140770585692, 0.8158203298412934, 0.9771398668713851], 
             UndirectedEdge[50, 258] -> 
             RGBColor[
              0.23439017041921995`, 0.3636893086787121, 0.9366595455049669], 
             UndirectedEdge[121, 298] -> 
             RGBColor[
              0.2245949434093795, 0.353393904038107, 0.9361017218174963], 
             UndirectedEdge[95, 382] -> 
             RGBColor[
              0.2846635750266093, 0.4152955487246973, 0.9395677351369693], 
             UndirectedEdge[42, 200] -> 
             RGBColor[
              0.18896638878164698`, 0.3159460341435242, 0.9340727283391701], 
             UndirectedEdge[254, 314] -> 
             RGBColor[
              0.1849157269952969, 0.31168853177927935`, 0.9338420491428545], 
             UndirectedEdge[95, 305] -> 
             RGBColor[
              0.2726453120788769, 0.4038978880790839, 0.9388381192290738], 
             UndirectedEdge[321, 381] -> 
             RGBColor[
              0.18695109985789307`, 0.313827837707961, 0.9339579606163151], 
             UndirectedEdge[116, 209] -> 
             RGBColor[
              0.2525333735524159, 0.38275896551722044`, 0.9376927740829386], 
             UndirectedEdge[364, 366] -> 
             RGBColor[
              0.9573192010017704, 0.856958801294309, 0.38384804144330753`], 
             UndirectedEdge[58, 156] -> 
             RGBColor[
              0.19753761270804981`, 0.3249549339371585, 0.9345608468617892], 
             UndirectedEdge[118, 179] -> 
             RGBColor[
              0.29213029064248475`, 0.4198750597583651, 0.9401126286272736], 
             UndirectedEdge[149, 328] -> 
             RGBColor[
              0.22083892747976266`, 0.3494460931509151, 0.9358878222668322], 
             UndirectedEdge[215, 227] -> 
             RGBColor[
              0.4900314069116405, 0.5878102265694376, 0.9551265080130549], 
             UndirectedEdge[70, 177] -> 
             RGBColor[
              0.1891804395703839, 0.31617101509409057`, 0.9340849182149289], 
             UndirectedEdge[383, 393] -> 
             RGBColor[
              0.5401446576878393, 0.6337537414941011, 0.9584878557690468], 
             UndirectedEdge[14, 201] -> 
             RGBColor[
              0.5021816905325309, 0.6032614518687315, 0.9550576137220795], 
             UndirectedEdge[5, 368] -> 
             RGBColor[
              0.18532540128789612`, 0.31211912543565157`, 0.9338653794877592],
              UndirectedEdge[214, 310] -> 
             RGBColor[
              0.8527190352209195, 0.3739582811888842, 0.19685354443386982`], 
             UndirectedEdge[35, 280] -> 
             RGBColor[
              0.19951437129521365`, 0.3270326325460011, 0.9346734203389759], 
             UndirectedEdge[243, 275] -> 
             RGBColor[
              0.21276908993785693`, 0.3409641822371201, 0.9354282569570754], 
             UndirectedEdge[131, 391] -> 
             RGBColor[
              0.817172560246312, 0.5056217507313383, 0.5745581182301532], 
             UndirectedEdge[2, 314] -> 
             RGBColor[
              0.19228958849813182`, 0.3194389277485814, 0.9342619796467905], 
             UndirectedEdge[282, 361] -> 
             RGBColor[
              0.36229879969604784`, 0.48822674345474093`, 0.9443063370417508],
              UndirectedEdge[110, 269] -> 
             RGBColor[
              0.6031830035578256, 0.6830576186116337, 0.9647885304899277], 
             UndirectedEdge[193, 360] -> 
             RGBColor[
              0.7503418220523833, 0.8050370370474327, 0.9757122305140027], 
             UndirectedEdge[71, 400] -> 
             RGBColor[
              0.8959095468804387, 0.5739593080367903, 0.5524892399106185], 
             UndirectedEdge[110, 117] -> 
             RGBColor[
              0.7057471364084966, 0.7690367194392469, 0.9721131675946504], 
             UndirectedEdge[170, 351] -> 
             RGBColor[
              0.27252940237618284`, 0.4037012784354327, 0.938834256448926], 
             UndirectedEdge[121, 200] -> 
             RGBColor[
              0.2188856606362972, 0.3473930858541622, 0.9357765866096961], 
             UndirectedEdge[38, 383] -> 
             RGBColor[
              0.3085216567311646, 0.43702297192973105`, 0.9410490384505009], 
             UndirectedEdge[172, 256] -> 
             RGBColor[
              0.6859636429526801, 0.7471589426256584, 0.8613086090450968], 
             UndirectedEdge[127, 258] -> 
             RGBColor[
              0.2885106861095953, 0.4177421195154126, 0.9398452959345076], 
             UndirectedEdge[25, 388] -> 
             RGBColor[
              0.31737166199215083`, 0.44580303632788293`, 0.9415721407250759],
              UndirectedEdge[51, 277] -> 
             RGBColor[
              0.19316166908716753`, 0.3203555397407608, 0.9343116433462084], 
             UndirectedEdge[85, 379] -> 
             RGBColor[
              0.18217848519657132`, 0.30881151709766497`, 0.9336861672718034],
              UndirectedEdge[267, 306] -> 
             RGBColor[
              0.20993199303624877`, 0.33798221351119695`, 0.9352666884856375],
              UndirectedEdge[176, 298] -> 
             RGBColor[
              0.19583511598337588`, 0.32316550193499927`, 0.9344638921919373],
              UndirectedEdge[269, 323] -> 
             RGBColor[
              0.38701260190710624`, 0.5096325967781434, 0.9458810786650822], 
             UndirectedEdge[21, 180] -> 
             RGBColor[
              0.19254611619106632`, 0.3197085546186507, 0.9342765885194044], 
             UndirectedEdge[36, 228] -> 
             RGBColor[
              0.23483092925025606`, 0.364152574155855, 0.9366846460683501], 
             UndirectedEdge[74, 116] -> 
             RGBColor[
              0.244277527259818, 0.37408154761281204`, 0.9372226158500052], 
             UndirectedEdge[3, 188] -> 
             RGBColor[
              0.25601232241971317`, 0.38641556135484806`, 0.9378908950742876],
              UndirectedEdge[69, 394] -> 
             RGBColor[
              0.46522152575946735`, 0.5741285322522734, 0.9517610033724258], 
             UndirectedEdge[37, 395] -> 
             RGBColor[
              0.3615061899414258, 0.48528293772410147`, 0.9443384829836874], 
             UndirectedEdge[172, 194] -> 
             RGBColor[
              0.41753162873264527`, 0.5360090287080477, 0.9478416433121417], 
             UndirectedEdge[59, 264] -> 
             RGBColor[
              0.2381256499847355, 0.3676155345451527, 0.9368722755400762], 
             UndirectedEdge[28, 369] -> 
             RGBColor[
              0.1860007123494566, 0.3128289201785459, 0.9339038374536819], 
             UndirectedEdge[130, 344] -> 
             RGBColor[
              0.20361295849173341`, 0.3313405075549807, 0.9349068288165013], 
             UndirectedEdge[29, 270] -> 
             RGBColor[
              0.19689305639497057`, 0.3242774643848816, 0.9345241403332949], 
             UndirectedEdge[41, 48] -> 
             RGBColor[
              0.2013669879321785, 0.3289798500941302, 0.9347789241157504], 
             UndirectedEdge[12, 124] -> 
             RGBColor[
              0.23470207361547668`, 0.3640171387137828, 0.9366773079305742], 
             UndirectedEdge[61, 95] -> 
             RGBColor[
              0.23224869997063102`, 0.3614384874601766, 0.9365375919309413], 
             UndirectedEdge[213, 306] -> 
             RGBColor[
              0.2738566580723743, 0.4036300780572341, 0.9389635275699348], 
             UndirectedEdge[63, 295] -> 
             RGBColor[
              0.1876127220363632, 0.31452324456680214`, 0.9339956390205967], 
             UndirectedEdge[302, 367] -> 
             RGBColor[
              0.19039724530537674`, 0.31744995507150764`, 0.934154213501434], 
             UndirectedEdge[140, 331] -> 
             RGBColor[
              0.3236577561982914, 0.4484913535850291, 0.9420736097220124], 
             UndirectedEdge[92, 354] -> 
             RGBColor[
              0.20023581918524017`, 0.32779092002085713`, 0.9347145057290265],
              UndirectedEdge[151, 311] -> 
             RGBColor[
              0.20510424418118295`, 0.33290794336756596`, 0.934991755330356], 
             UndirectedEdge[299, 371] -> 
             RGBColor[
              0.18421145049276366`, 0.3109482925214076, 0.933801941637919], 
             UndirectedEdge[140, 389] -> 
             RGBColor[
              0.6997349672161455, 0.7570392468690857, 0.7200011772159544], 
             UndirectedEdge[176, 205] -> 
             RGBColor[
              0.18567915281687453`, 0.3124909407217502, 0.9338855251140061], 
             UndirectedEdge[152, 179] -> 
             RGBColor[
              0.2138285336364696, 0.3420777247369723, 0.935488590708405], 
             UndirectedEdge[142, 293] -> 
             RGBColor[
              0.3941446854590191, 0.5152441502355233, 0.946491888259698], 
             UndirectedEdge[105, 259] -> 
             RGBColor[
              0.9403634558512834, 0.9538207185775788, 0.9415651020124101], 
             UndirectedEdge[274, 318] -> 
             RGBColor[
              0.20829816061759315`, 0.33626495204823137`, 0.9351736441464337],
              UndirectedEdge[231, 369] -> 
             RGBColor[
              0.1858060573218873, 0.312624325402729, 0.9338927521378282], 
             UndirectedEdge[151, 348] -> 
             RGBColor[
              0.20435820389696413`, 0.332123807727166, 0.9349492694398375], 
             UndirectedEdge[147, 231] -> 
             RGBColor[
              0.2192108871052112, 0.34773491949353985`, 0.9357951077759714], 
             UndirectedEdge[66, 354] -> 
             RGBColor[
              0.19611420939972474`, 0.3234588468111266, 0.9344797861491166], 
             UndirectedEdge[24, 65] -> 
             RGBColor[
              0.3183379395633406, 0.44565996035968214`, 0.9416695943018074], 
             UndirectedEdge[42, 347] -> 
             RGBColor[
              0.18410501336322643`, 0.3108364203497602, 0.9337958802008515], 
             UndirectedEdge[52, 129] -> 
             RGBColor[
              0.904165411034544, 0.5696744067053534, 0.4991000639737569], 
             UndirectedEdge[3, 7] -> 
             RGBColor[
              0.24558195815549755`, 0.37545258718986685`, 0.9372969012597816],
              UndirectedEdge[156, 352] -> 
             RGBColor[
              0.19412861826228733`, 0.32137186463193046`, 0.9343667096712585],
              UndirectedEdge[229, 329] -> 
             RGBColor[
              0.2301303447827652, 0.3592119618462532, 0.9364169547368181], 
             UndirectedEdge[80, 187] -> 
             RGBColor[
              0.20972687217078761`, 0.3377666184761832, 0.9352550071557988], 
             UndirectedEdge[247, 362] -> 
             RGBColor[
              0.8043048253983777, 0.4855724402659776, 0.5720335274237128], 
             UndirectedEdge[43, 321] -> 
             RGBColor[
              0.1896253217591911, 0.31663861448168684`, 0.9341102535974373], 
             UndirectedEdge[84, 270] -> 
             RGBColor[
              0.21111604747539212`, 0.339226729800124, 0.9353341186342953], 
             UndirectedEdge[318, 322] -> 
             RGBColor[
              0.20428384988578308`, 0.3320456569470981, 0.9349450350888977], 
             UndirectedEdge[218, 276] -> 
             RGBColor[
              0.46966080217049366`, 0.5783141439540027, 0.951949779691809], 
             UndirectedEdge[201, 303] -> 
             RGBColor[
              0.7798220611835203, 0.6750115727481525, 0.6002603969131654], 
             UndirectedEdge[283, 364] -> 
             RGBColor[
              0.9266304431740131, 0.7468211866800847, 0.25982333625421017`], 
             UndirectedEdge[65, 340] -> 
             RGBColor[
              0.3239430587205376, 0.45155129597897675`, 0.941988797545779], 
             UndirectedEdge[83, 214] -> 
             RGBColor[
              0.9149531561640245, 0.7530286606028909, 0.5942676397554747], 
             UndirectedEdge[124, 157] -> 
             RGBColor[
              0.2367400113323198, 0.3661591404668991, 0.9367933654686897], 
             UndirectedEdge[311, 344] -> 
             RGBColor[
              0.19707934099750435`, 0.3244732613132706, 0.9345347489658259], 
             UndirectedEdge[190, 226] -> 
             RGBColor[
              0.20202864183193292`, 0.3296752902940524, 0.9348166043265123], 
             UndirectedEdge[380, 389] -> 
             RGBColor[
              0.8567527280963826, 0.8845935052040448, 0.7328269740889874], 
             UndirectedEdge[124, 179] -> 
             RGBColor[
              0.22671592710196903`, 0.3556231923771518, 0.9362225087010749], 
             UndirectedEdge[199, 215] -> 
             RGBColor[
              0.8474033618771311, 0.8799586173228249, 0.9038397390676208], 
             UndirectedEdge[146, 267] -> 
             RGBColor[
              0.19834666787727806`, 0.32580530221707793`, 0.9346069213567869],
              UndirectedEdge[109, 249] -> 
             RGBColor[
              0.18318613987214505`, 0.3098706260506894, 0.9337435517148859], 
             UndirectedEdge[36, 61] -> 
             RGBColor[
              0.23146005042347673`, 0.36060956678284806`, 0.9364926795059334],
              UndirectedEdge[13, 232] -> 
             RGBColor[
              0.20186143048066912`, 0.3294995405620621, 0.9348070818874247], 
             UndirectedEdge[38, 119] -> 
             RGBColor[
              0.249257790450226, 0.37931611999285497`, 0.9375062344710599], 
             UndirectedEdge[91, 256] -> 
             RGBColor[
              0.792439933021371, 0.8356021745450866, 0.869137935086701], 
             UndirectedEdge[6, 69] -> 
             RGBColor[
              0.7494906190968638, 0.8040199624425932, 0.9761664746556911], 
             UndirectedEdge[90, 97] -> 
             RGBColor[
              0.2570968896215246, 0.3875555102494842, 0.9379526595719574], 
             UndirectedEdge[233, 257] -> 
             RGBColor[
              0.9698756400386146, 0.9770538821816868, 0.9358768631099392], 
             UndirectedEdge[66, 119] -> 
             RGBColor[
              0.21795851687042844`, 0.3464185989719241, 0.9357237871438162], 
             UndirectedEdge[33, 116] -> 
             RGBColor[
              0.24330530459768918`, 0.3730596799524376, 0.9371672492076716], 
             UndirectedEdge[335, 349] -> 
             RGBColor[
              0.19833951424086566`, 0.32579778329164166`, 0.9346065139677762],
              UndirectedEdge[165, 274] -> 
             RGBColor[
              0.21434019517096867`, 0.34261551345094576`, 0.9355177290758593],
              UndirectedEdge[95, 169] -> 
             RGBColor[
              0.3522449518778092, 0.4737241407933565, 0.9439035250794346], 
             UndirectedEdge[135, 259] -> 
             RGBColor[
              0.6153899363844033, 0.6921704499321857, 0.9662385558858466], 
             UndirectedEdge[93, 273] -> 
             RGBColor[
              0.433287316679902, 0.5477930013754455, 0.949360282412582], 
             UndirectedEdge[89, 263] -> 
             RGBColor[
              0.2670289628172794, 0.39799474890803455`, 0.93851827644727], 
             UndirectedEdge[71, 289] -> 
             RGBColor[
              0.7219591346417744, 0.780476707159252, 0.9439593282102003], 
             UndirectedEdge[32, 215] -> 
             RGBColor[
              0.7637949188808839, 0.4683581448483874, 0.5697890053389816], 
             UndirectedEdge[8, 239] -> 
             RGBColor[
              0.3813679879787836, 0.49836836108207505`, 0.9461050956090218], 
             UndirectedEdge[110, 111] -> 
             RGBColor[
              0.8397873767221564, 0.5455755079920095, 0.5794773016000505], 
             UndirectedEdge[29, 162] -> 
             RGBColor[
              0.19056901057120365`, 0.3176304912564385, 0.9341639952792189], 
             UndirectedEdge[337, 353] -> 
             RGBColor[
              0.9751195109230872, 0.9777137367216755, 0.7327280786411184], 
             UndirectedEdge[306, 308] -> 
             RGBColor[
              0.2175738595337591, 0.3460142997224009, 0.9357018814775424], 
             UndirectedEdge[185, 190] -> 
             RGBColor[
              0.20235115482293997`, 0.33001427189610544`, 0.9348349709642347],
              UndirectedEdge[71, 385] -> 
             RGBColor[
              0.9820607295061435, 0.9836969405379016, 0.7849671104328407], 
             UndirectedEdge[146, 158] -> 
             RGBColor[
              0.1951348259562785, 0.3224294527155677, 0.9344240117108803], 
             UndirectedEdge[157, 386] -> 
             RGBColor[
              0.2943941268277438, 0.42368947103286164`, 0.9401890092515732], 
             UndirectedEdge[24, 124] -> 
             RGBColor[
              0.24340021238043813`, 0.3731594340496077, 0.9371726540654957], 
             UndirectedEdge[22, 74] -> 
             RGBColor[
              0.24528340650250224`, 0.37513879047330073`, 0.9372798991848111],
              UndirectedEdge[303, 385] -> 
             RGBColor[
              0.9441738208357854, 0.8008555462181073, 0.4334857922002555], 
             UndirectedEdge[130, 317] -> 
             RGBColor[
              0.20208377375464914`, 0.3297332374403929, 0.9348197440079504], 
             UndirectedEdge[73, 291] -> 
             RGBColor[
              0.19698615809912115`, 0.32437532017893284`, 0.9345294423376147],
              UndirectedEdge[241, 255] -> 
             RGBColor[
              0.32755009808125596`, 0.4555556663672059, 0.9421864088801596], 
             UndirectedEdge[385, 400] -> 
             RGBColor[
              0.9082664009347345, 0.5807304681405772, 0.40128873459150277`], 
             UndirectedEdge[130, 311] -> 
             RGBColor[
              0.20912979631755016`, 0.33713905389763504`, 0.9352210045692514],
              UndirectedEdge[143, 308] -> 
             RGBColor[
              0.2058756118794577, 0.33371869972598955`, 0.9350356835796365], 
             UndirectedEdge[297, 397] -> 
             RGBColor[
              0.33036980779411174`, 0.4594447802808611, 0.9423131030091806], 
             UndirectedEdge[237, 324] -> 
             RGBColor[
              0.18395646599811732`, 0.31068028765058353`, 0.9337874206481647],
              UndirectedEdge[107, 160] -> 
             RGBColor[
              0.20918830325598364`, 0.33720054839948277`, 0.935224336452842], 
             UndirectedEdge[125, 185] -> 
             RGBColor[
              0.1925739180479394, 0.31973777613296384`, 0.9342781717940241], 
             UndirectedEdge[269, 388] -> 
             RGBColor[
              0.3120924130263679, 0.44123041621648995`, 0.9412357516492327], 
             UndirectedEdge[47, 300] -> 
             RGBColor[
              0.18858263454534693`, 0.31554268410974895`, 0.9340508741031263],
              UndirectedEdge[37, 365] -> 
             RGBColor[
              0.29517424252624735`, 0.4275772223959621, 0.9401211084894857], 
             UndirectedEdge[356, 389] -> 
             RGBColor[
              0.969253418800837, 0.9732437196326836, 0.7351124459689012], 
             UndirectedEdge[227, 243] -> 
             RGBColor[
              0.2526928974888643, 0.38292663528882953`, 0.9377018587351249], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.1986316801099837, 0.3261048681444708, 0.9346231523818017], 
             UndirectedEdge[186, 348] -> 
             RGBColor[
              0.2038426026857459, 0.33158187816317064`, 0.9349199067136222], 
             UndirectedEdge[61, 90] -> 
             RGBColor[
              0.21641762089155886`, 0.3447990195996844, 0.935636035397371], 
             UndirectedEdge[72, 325] -> 
             RGBColor[
              0.35190435537579295`, 0.4723760276667679, 0.9439742559127038], 
             UndirectedEdge[341, 358] -> 
             RGBColor[
              0.26347030119752707`, 0.39425436991349627`, 0.9383156159325932],
              UndirectedEdge[102, 337] -> 
             RGBColor[
              0.6530069899856277, 0.722086925969716, 0.9505841497129952], 
             UndirectedEdge[297, 378] -> 
             RGBColor[
              0.2683985374759716, 0.3994342587103688, 0.9385962716979784], 
             UndirectedEdge[300, 370] -> 
             RGBColor[
              0.19085384504698283`, 0.3179298703500313, 0.9341802161812396], 
             UndirectedEdge[46, 52] -> 
             RGBColor[
              0.89726556755869, 0.9188637535063902, 0.9066512485949225], 
             UndirectedEdge[75, 200] -> 
             RGBColor[
              0.1879784206462758, 0.3149076169924513, 0.9340164650154286], 
             UndirectedEdge[204, 343] -> 
             RGBColor[
              0.1903303530090651, 0.3173796470268675, 0.9341504040841173], 
             UndirectedEdge[32, 199] -> 
             RGBColor[
              0.9051273093812517, 0.578009485902768, 0.5022905305219902], 
             UndirectedEdge[301, 313] -> 
             RGBColor[
              0.2672428397382781, 0.39821954711258417`, 0.9385304564215183], 
             UndirectedEdge[166, 363] -> 
             RGBColor[
              0.3098501203432949, 0.43692070785172515`, 0.9411795622408922], 
             UndirectedEdge[333, 353] -> 
             RGBColor[
              0.97351816640208, 0.9765194565998694, 0.7354387372176427], 
             UndirectedEdge[130, 146] -> 
             RGBColor[
              0.20739635899717102`, 0.3353171013676426, 0.9351222878782466], 
             UndirectedEdge[71, 271] -> 
             RGBColor[
              0.8948533141221586, 0.565840640212504, 0.5514777902284453], 
             UndirectedEdge[123, 332] -> 
             RGBColor[
              0.8304813654821182, 0.2352987088808914, 0.17682229605044186`], 
             UndirectedEdge[340, 361] -> 
             RGBColor[
              0.34048302917169776`, 0.46587738706068504`, 0.9430427098372054],
              UndirectedEdge[165, 322] -> 
             RGBColor[
              0.2103258844391586, 0.3383962183498125, 0.9352891200183233], 
             UndirectedEdge[278, 302] -> 
             RGBColor[
              0.19139766926121787`, 0.31850146407963903`, 0.9342111861657245],
              UndirectedEdge[322, 355] -> 
             RGBColor[
              0.2016258404569241, 0.32925192050983587`, 0.9347936653840967], 
             UndirectedEdge[68, 333] -> 
             RGBColor[
              0.8876904453290742, 0.9128181118706356, 0.9729875018597351], 
             UndirectedEdge[150, 156] -> 
             RGBColor[
              0.22013918030941965`, 0.34871061450835156`, 0.9358479727006643],
              UndirectedEdge[29, 357] -> 
             RGBColor[
              0.18592235681432462`, 0.3127465635430944, 0.9338993752218727], 
             UndirectedEdge[250, 325] -> 
             RGBColor[
              0.21599606078555122`, 0.34435593319981583`, 0.9356120281729761],
              UndirectedEdge[53, 131] -> 
             RGBColor[
              0.6083578580504109, 0.6889233390243821, 0.9644906126536026], 
             UndirectedEdge[92, 267] -> 
             RGBColor[
              0.20096723062757926`, 0.3285596798209194, 0.9347561585286415], 
             UndirectedEdge[269, 309] -> 
             RGBColor[
              0.5253850164437505, 0.6220146854886827, 0.9571050895141], 
             UndirectedEdge[162, 336] -> 
             RGBColor[
              0.21504897720554328`, 0.3433604883086603, 0.9355580931641793], 
             UndirectedEdge[94, 204] -> 
             RGBColor[
              0.1795232819748228, 0.3060207301619996, 0.9335349573763461], 
             UndirectedEdge[29, 183] -> 
             RGBColor[
              0.18726251983199932`, 0.31415515984591347`, 0.9339756955231359],
              UndirectedEdge[145, 208] -> 
             RGBColor[
              0.2721455459278671, 0.4033726021673685, 0.9388096582861116], 
             UndirectedEdge[75, 133] -> 
             RGBColor[
              0.18265733709091148`, 0.3093148207995801, 0.9337134371787883], 
             UndirectedEdge[169, 326] -> 
             RGBColor[
              0.349415147686683, 0.47074983716853436`, 0.9437423719170701], 
             UndirectedEdge[95, 97] -> 
             RGBColor[
              0.27292796870059677`, 0.4041949781099764, 0.9388542161055278], 
             UndirectedEdge[37, 78] -> 
             RGBColor[
              0.25239861099731176`, 0.3826173215273665, 0.9376850995547887], 
             UndirectedEdge[55, 397] -> 
             RGBColor[
              0.5839584526615165, 0.6682303773203624, 0.9627494310951048], 
             UndirectedEdge[185, 226] -> 
             RGBColor[
              0.1922271263061977, 0.3193732760245269, 0.9342584225173644], 
             UndirectedEdge[39, 254] -> 
             RGBColor[
              0.19262591917799537`, 0.31979243261771473`, 0.934281133181452], 
             UndirectedEdge[71, 201] -> 
             RGBColor[
              0.8177089698538784, 0.8578529670679469, 0.9517417151457506], 
             UndirectedEdge[227, 383] -> 
             RGBColor[
              0.3161546993185588, 0.44504578365193476`, 0.9414837289337784], 
             UndirectedEdge[38, 151] -> 
             RGBColor[
              0.23316903340538708`, 0.36240581625261525`, 0.9365900035585395],
              UndirectedEdge[45, 74] -> 
             RGBColor[
              0.2441275547351621, 0.3739239169805914, 0.9372140751365906], 
             UndirectedEdge[292, 303] -> 
             RGBColor[
              0.8567109713559, 0.3810358674996849, 0.1997518680171543], 
             UndirectedEdge[185, 357] -> 
             RGBColor[
              0.18927662196416456`, 0.31627210888827, 0.9340903956599655], 
             UndirectedEdge[86, 376] -> 
             RGBColor[
              0.2771391258654599, 0.4086211712930332, 0.939094035276218], 
             UndirectedEdge[212, 309] -> 
             RGBColor[
              0.6375731061251859, 0.7158069480258249, 0.965187359754256], 
             UndirectedEdge[50, 127] -> 
             RGBColor[
              0.28524823564473223`, 0.4143130772255349, 0.9396595042068966], 
             UndirectedEdge[92, 374] -> 
             RGBColor[
              0.1940034937220554, 0.32124035080679264`, 0.9343595840137974], 
             UndirectedEdge[118, 141] -> 
             RGBColor[
              0.35660710592589273`, 0.4832968843838794, 0.9439436673476838], 
             UndirectedEdge[205, 390] -> 
             RGBColor[
              0.19906834334491935`, 0.32656382889043634`, 
               0.9346480197070459]}, GraphLayout -> {"Dimension" -> 2}, 
           ImageSize -> 500, VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.24987309085249598`, 0.3799628397279394, 0.9375412749187138], 
             316 -> 
             RGBColor[
              0.7121412574025138, 0.7750494298476431, 0.9719432432656107], 
             308 -> RGBColor[
              0.212847764567014, 0.3410468742606238, 0.9354327373608172], 160 -> 
             RGBColor[
              0.19529547244710238`, 0.32259830236299947`, 0.9344331602908775],
              245 -> RGBColor[
              0.19489410730752896`, 0.3221764421532881, 0.9344103031399453], 
             155 -> RGBColor[
              0.1858996679095085, 0.31272271606557295`, 0.9338980831223087], 
             213 -> RGBColor[
              0.3254133616442444, 0.45627843093029025`, 0.9419560295456021], 
             352 -> RGBColor[
              0.18638553952238943`, 0.3132333979367503, 0.9339257527918797], 
             27 -> RGBColor[
              0.20503271821821972`, 0.3328327650454837, 0.9349876820325784], 
             367 -> RGBColor[
              0.1860930553658944, 0.31292597854370746`, 0.9339090962518588], 
             19 -> RGBColor[
              0.19951285246669712`, 0.3270310361609309, 0.9346733338439388], 
             164 -> RGBColor[
              0.21499276582137244`, 0.3433014065798891, 0.935554892009008], 
             190 -> RGBColor[
              0.2121526703486752, 0.34031628616563087`, 0.9353931527733826], 
             103 -> RGBColor[
              0.19478977051563845`, 0.3220667775696765, 0.9344043613139996], 
             138 -> RGBColor[
              0.2889051941793347, 0.4209880551027343, 0.939764095460355], 291 -> 
             RGBColor[
              0.1954605501868454, 0.3227718095340026, 0.9344425612239453], 28 -> 
             RGBColor[
              0.19159599737019925`, 0.31870991949690686`, 0.9342224806581308],
              337 -> RGBColor[
              0.956979221732861, 0.9674357545252026, 0.9577071353769899], 195 -> 
             RGBColor[
              0.42461827381123246`, 0.5422047396654701, 0.9482772788254231], 
             114 -> RGBColor[
              0.18667779652152947`, 0.3135405785730105, 0.9339423963956253], 
             93 -> RGBColor[
              0.3425287629814334, 0.47110293132347947`, 0.9430466077842526], 
             34 -> RGBColor[
              0.1829376663072982, 0.30960946457990146`, 0.9337294015129516], 
             161 -> RGBColor[
              0.8795463410175769, 0.5459298918751729, 0.22120285316675511`], 
             22 -> RGBColor[
              0.24203296140503872`, 0.3717223665857442, 0.9370947911451132], 
             124 -> RGBColor[
              0.22661866237074535`, 0.3555209609776956, 0.9362169696185221], 
             84 -> 
             RGBColor[
              0.21428709115836797`, 0.3425596977667136, 0.935514704880902], 
             46 -> RGBColor[
              0.8055364749096104, 0.8480104835941301, 0.9812520057187881], 
             241 -> RGBColor[
              0.28091140737960196`, 0.41258607834085864`, 0.939308861127858], 
             185 -> RGBColor[
              0.19254963929720473`, 0.31971225762658, 0.9342767891550869], 
             390 -> RGBColor[
              0.21298290042549683`, 0.3411889106159976, 0.9354404331480423], 
             121 -> RGBColor[
              0.24372417422141443`, 0.37349993848484087`, 0.9371911032130806],
              322 -> RGBColor[
              0.1951112049063669, 0.3224046254944496, 0.9344226665270321], 
             126 -> RGBColor[
              0.18255935854789945`, 0.309211839138676, 0.9337078574457099], 
             236 -> RGBColor[
              0.5096359477486948, 0.612784447077024, 0.9545395551462174], 78 -> 
             RGBColor[
              0.22046571832082573`, 0.34905382666204504`, 0.9358665685573442],
              376 -> RGBColor[
              0.28617898913701123`, 0.4181226407518692, 0.9396088421162536], 
             254 -> RGBColor[
              0.1870776850955973, 0.3139608868187558, 0.9339651694583363], 
             290 -> RGBColor[
              0.25752973177491306`, 0.38801045479647306`, 0.9379773092922603],
              251 -> RGBColor[
              0.1849258667142184, 0.3116991892667612, 0.9338426265848467], 
             165 -> RGBColor[
              0.22554056397195027`, 0.35438781120517543`, 0.9361555735096144],
              100 -> RGBColor[
              0.387712192347488, 0.5102385468551641, 0.9459256559493198], 235 -> 
             RGBColor[
              0.19324911536591247`, 0.3204474513241361, 0.9343166232824178], 
             70 -> RGBColor[
              0.1969643686712329, 0.32435241810869275`, 0.934528201461931], 
             234 -> RGBColor[
              0.24693624036742998`, 0.3768760236610595, 0.9373740256282702], 
             257 -> RGBColor[
              0.9694202648664492, 0.9767142641238943, 0.9366476944955487], 
             135 -> RGBColor[
              0.335355251737071, 0.46488959643477135`, 0.9425895179910487], 
             265 -> RGBColor[
              0.19899652547638796`, 0.32648834375709396`, 0.934643929785678], 
             111 -> RGBColor[
              0.8266120846200963, 0.20555772064570646`, 0.17311706832724205`],
              381 -> RGBColor[
              0.1893487791980019, 0.3163479507160659, 0.9340945049076855], 
             182 -> 
             RGBColor[
              0.24182762690147153`, 0.3715065470035356, 0.9370830976489003], 
             188 -> RGBColor[
              0.27580922111776024`, 0.4072233570823697, 0.9390182991682543], 
             154 -> RGBColor[
              0.18637271886218407`, 0.3132199226099977, 0.9339250226742475], 
             336 -> RGBColor[
              0.23480104226620413`, 0.36412116104067216`, 0.9366829440488222],
              315 -> RGBColor[
              0.1811098371299533, 0.3076883002234485, 0.9336253093453327], 
             368 -> RGBColor[
              0.1838330998850932, 0.3105506220439319, 0.9337803951305317], 
             269 -> RGBColor[
              0.3534033382914345, 0.480521941884955, 0.9437395261069965], 208 -> 
             RGBColor[
              0.2944180010032382, 0.4267823646067975, 0.9400780416535094], 86 -> 
             RGBColor[
              0.2680992625939086, 0.39911970183419715`, 0.9385792284361825], 
             119 -> RGBColor[
              0.2397898236287226, 0.36936468655968646`, 0.936967047767177], 
             377 -> RGBColor[
              0.25469411239970985`, 0.38503003904448196`, 0.9378158249637654],
              140 -> RGBColor[
              0.4063466574019441, 0.5263787838898877, 0.9471130275847793], 85 -> 
             RGBColor[
              0.1818888062976524, 0.30850704620819813`, 0.9336696704870515], 
             351 -> RGBColor[
              0.3095548228305918, 0.44254256168324113`, 0.9409455374755513], 
             242 -> RGBColor[
              0.3403985574835718, 0.4692578543884732, 0.9429108729735957], 
             117 -> RGBColor[
              0.5585316039927765, 0.6524801435401812, 0.9583888003164419], 47 -> 
             RGBColor[
              0.18100426741029385`, 0.3075773397545796, 0.9336192973059745], 
             81 -> RGBColor[
              0.22915597848204, 0.35818784108579943`, 0.9363614660174375], 
             275 -> RGBColor[
              0.194144227344503, 0.3213882707670121, 0.934367598585399], 23 -> 
             RGBColor[
              0.2119196850624197, 0.340071403857656, 0.9353798846060012], 328 -> 
             RGBColor[
              0.2313516506730186, 0.3604956317721754, 0.9364865063005079], 
             110 -> RGBColor[
              0.8529626688242167, 0.8855932953383124, 0.985837534872859], 6 -> 
             RGBColor[
              0.9261633007621113, 0.943961492267368, 0.992819476494071], 218 -> 
             RGBColor[
              0.5602763464580424, 0.6538966040732364, 0.9585261528345099], 
             108 -> 
             RGBColor[
              0.3063635945960659, 0.4393379408672382, 0.9407583255366989], 
             297 -> RGBColor[
              0.2965600408339725, 0.42903378428206873`, 0.9402000276530058], 
             157 -> RGBColor[
              0.24686136029389427`, 0.3767973199561026, 0.9373697613188575], 
             354 -> RGBColor[
              0.19610120868731518`, 0.3234451822380914, 0.9344790457777777], 
             385 -> RGBColor[
              0.9944175835604394, 0.9904681006416884, 0.633766605113725], 270 -> 
             RGBColor[
              0.20794500379241626`, 0.3358937618335345, 0.9351535323876885], 
             392 -> RGBColor[
              0.2030621295519029, 0.3307615514146469, 0.9348754599232564], 33 -> 
             RGBColor[
              0.24658940627570813`, 0.37651147904010834`, 0.9373542739398417],
              252 -> RGBColor[
              0.20594129701488287`, 0.33378773896799957`, 0.9350394242509266],
              394 -> RGBColor[
              0.35762511408731845`, 0.48417863188672844`, 0.9440085339275405],
              260 -> RGBColor[
              0.1889310324973132, 0.31590887244697147`, 0.9340707148510822], 
             159 -> RGBColor[
              0.18214142158537838`, 0.30877256089233246`, 0.9336840565539767],
              183 -> RGBColor[
              0.18868393066647376`, 0.3156491527555983, 0.9340566427673703], 
             99 -> RGBColor[
              0.9021660914511284, 0.9248267689496842, 0.9905306012474278], 
             329 -> RGBColor[
              0.2623389378177228, 0.3930652352687406, 0.9382511864618155], 
             309 -> RGBColor[
              0.6973666945960665, 0.7635074290924103, 0.9704706529212034], 17 -> 
             RGBColor[
              0.8276616884309496, 0.21362543547524793`, 0.17412217012187317`],
              349 -> RGBColor[
              0.19841472542917707`, 0.32587683501922177`, 0.9346107971336854],
              347 -> RGBColor[
              0.18432439621433888`, 0.3110670056359555, 0.9338083737296745], 
             340 -> RGBColor[
              0.27139200070452485`, 0.4025805783601091, 0.9387667450004126], 
             277 -> RGBColor[
              0.1851145385676597, 0.3118974953472144, 0.9338533711677852], 
             104 -> RGBColor[
              0.22404918964109946`, 0.35282028222485723`, 0.936070641947763], 
             79 -> RGBColor[
              0.199051197909799, 0.3265458079510415, 0.9346470432998802], 327 -> 
             RGBColor[
              0.18576331458524015`, 0.3125794000764668, 0.9338903180022083], 
             191 -> 
             RGBColor[
              0.1840091371887301, 0.310735648411464, 0.9337904201945499], 50 -> 
             RGBColor[
              0.23112771995435683`, 0.3602602663888343, 0.9364737537773559], 
             225 -> RGBColor[
              0.2084820527788493, 0.336458234369148, 0.9351841165329731], 61 -> 
             RGBColor[
              0.21726621743653565`, 0.3456909483725835, 0.9356843617152213], 
             196 -> RGBColor[
              0.844124603334554, 0.8785460618197521, 0.9849945522966208], 1 -> 
             RGBColor[
              0.1818132732838514, 0.3084276562216236, 0.9336653689936567], 
             263 -> RGBColor[
              0.30183205672017543`, 0.43457500724358145`, 0.9405002611584765],
              201 -> RGBColor[
              0.6657140642559093, 0.738780153701779, 0.9673158145395446], 371 -> 
             RGBColor[
              0.18003320207443918`, 0.306556688517498, 0.93356399657166], 293 -> 
             RGBColor[
              0.3141297509318431, 0.44650513446197276`, 0.941237047848713], 
             362 -> RGBColor[
              0.7912709059084366, 0.8368661126680731, 0.979830147120073], 184 -> 
             RGBColor[
              0.21355297767290998`, 0.3417880979480139, 0.9354728982039288], 
             106 -> RGBColor[
              0.1865190623784995, 0.31337373892436005`, 0.9339333567210057], 
             206 -> RGBColor[
              0.4288884024290853, 0.5459033104513494, 0.9485493676450263], 
             358 -> RGBColor[
              0.2775970966062373, 0.4091025275786123, 0.9391201160323983], 
             247 -> RGBColor[
              0.8173387448883187, 0.1342787678638822, 0.16423690772735258`], 
             220 -> RGBColor[
              0.17970434930417156`, 0.30621104340547683`, 0.9335452688928874],
              107 -> RGBColor[
              0.2230811340648649, 0.3518027944359661, 0.9360155126148064], 
             375 -> RGBColor[
              0.20279567675606608`, 0.3304814926321394, 0.9348602858307151], 
             131 -> RGBColor[
              0.8141109072907318, 0.8547088953383618, 0.982106625005912], 127 -> 
             RGBColor[
              0.3393687513351076, 0.46836588806223545`, 0.9428452546364373], 
             210 -> RGBColor[
              0.2456807114445148, 0.37555638315794415`, 0.9373025251134988], 
             357 -> RGBColor[
              0.18600360463112436`, 0.31283196014996, 0.9339040021648441], 
             181 -> RGBColor[
              0.19212227783830665`, 0.31926307363699663`, 0.9342524515522274],
              194 -> 
             RGBColor[
              0.4554399226734993, 0.5687856724178738, 0.9502730455257168], 
             118 -> RGBColor[
              0.3574473894517768, 0.48402469574012214`, 0.9439972094709195], 
             348 -> RGBColor[
              0.20110409825488346`, 0.3287035363751249, 0.9347639529375389], 
             276 -> RGBColor[
              0.37904525788294496`, 0.5027316838347692, 0.9453734065491083], 
             305 -> RGBColor[
              0.29805944165302733`, 0.4306097496103981, 0.9402854163114862], 
             343 -> RGBColor[
              0.20071986914810575`, 0.3282996872223691, 0.9347420716583239], 
             280 -> RGBColor[
              0.2089289786028837, 0.3369279817469421, 0.9352095682974844], 
             189 -> RGBColor[
              0.2331737072204319, 0.36241072872856434`, 0.9365902697253919], 
             168 -> RGBColor[
              0.19796437105250972`, 0.32540348401522773`, 0.9345851501181738],
              363 -> RGBColor[
              0.3745258073527012, 0.4988171629396605, 0.9450854311577144], 41 -> 
             RGBColor[
              0.19479503600678127`, 0.322072311934719, 0.9344046611759306], 
             14 -> RGBColor[
              0.3386493168091526, 0.46774275003568394`, 0.9427994129046144], 
             77 -> RGBColor[
              0.1969521059625652, 0.3243395292243824, 0.9345275031188135], 51 -> 
             RGBColor[
              0.20120879960667537`, 0.3288135841343073, 0.9347699155246316], 
             179 -> RGBColor[
              0.2268131918331927, 0.35572542377660804`, 0.9362280477836279], 
             223 -> RGBColor[
              0.8592163258347785, 0.4536160411257659, 0.20423899016395516`], 
             323 -> RGBColor[
              0.42062186552277797`, 0.5387432516713317, 0.9480226312231679], 
             292 -> RGBColor[
              0.8194918846006688, 0.15082874320484374`, 0.1662987567475226], 
             396 -> RGBColor[
              0.18439801323969868`, 0.31114438179719767`, 0.9338125661103621],
              321 -> RGBColor[
              0.18455342051778426`, 0.3113077246998561, 0.9338214163249446], 
             143 -> RGBColor[
              0.19890345919190142`, 0.32639052519135536`, 0.9346386297984558],
              112 -> RGBColor[
              0.1804406002012431, 0.3069848897793021, 0.93358719729229], 197 -> 
             RGBColor[
              0.19131157595015044`, 0.3184109745510759, 0.9342062832790229], 
             54 -> RGBColor[
              0.9482538006021336, 0.8325505933258706, 0.2772219972063093], 71 -> 
             RGBColor[
              0.9697038754518477, 0.9769257804341147, 0.9361676157519565], 
             177 -> RGBColor[
              0.18139651046953492`, 0.3079896120794884, 0.9336416349679267], 
             158 -> RGBColor[
              0.1911403477299942, 0.3182310028351955, 0.9341965320851944], 
             226 -> RGBColor[
              0.19190461331519068`, 0.3190342944224739, 0.9342400558796418], 
             350 -> RGBColor[
              0.3485452682138572, 0.4763141257574593, 0.943429974177476], 203 -> 
             RGBColor[
              0.3100095560527289, 0.44293642874469996`, 0.9409745126743612], 
             115 -> RGBColor[
              0.9551078718556497, 0.8597247018622127, 0.2827369438226184], 
             173 -> RGBColor[
              0.17959143492855675`, 0.30609236323752076`, 0.933538838586238], 
             212 -> RGBColor[
              0.5777795176543054, 0.6681064669592394, 0.9599040665873084], 
             129 -> RGBColor[
              0.8193361618613183, 0.1496317899920564, 0.1661496364764569], 
             279 -> RGBColor[
              0.1990369147875074, 0.3265307954839108, 0.9346462298971957], 26 -> 
             RGBColor[
              0.1822568035379685, 0.30889383464014303`, 0.9336906273854845], 
             40 -> RGBColor[
              0.1934487547814754, 0.32065728500776275`, 0.934327992451794], 
             146 -> RGBColor[
              0.1991293041825628, 0.32662790259593993`, 0.9346514913365662], 
             386 -> RGBColor[
              0.3419268933615933, 0.4705816221096207, 0.9430082571842888], 
             192 -> RGBColor[
              0.2582664433427927, 0.3887847853645258, 0.938019263926184], 300 -> 
             RGBColor[
              0.19616100168040002`, 0.3235080284649182, 0.934482450900278], 
             221 -> RGBColor[
              0.36991176607450643`, 0.49482071229294583`, 0.9447914285275043],
              62 -> RGBColor[
              0.9918038536315829, 0.990878697092375, 0.7854948864789351], 286 -> 
             RGBColor[
              0.3212434064694567, 0.45266662534593033`, 0.9416903236892111], 
             152 -> RGBColor[
              0.2008438754397465, 0.3284300256973365, 0.9347491336331819], 64 -> 
             RGBColor[
              0.9925852496598342, 0.986548923705669, 0.43432836788688456`], 
             307 -> RGBColor[
              0.17902996710188124`, 0.3055022249525685, 0.933506863824126], 
             37 -> RGBColor[
              0.2843315036737978, 0.41618081639268795`, 0.9395036305522334], 
             148 -> 
             RGBColor[
              0.25655300447979307`, 0.38698385248121464`, 0.9379216861177417],
              261 -> RGBColor[
              0.18920356017618423`, 0.31619531631671777`, 0.9340862348992254],
              387 -> RGBColor[
              0.18554205504628538`, 0.3123468422723603, 0.933877717598789], 
             15 -> RGBColor[
              0.18212992963139682`, 0.3087604821200659, 0.9336834021041983], 
             136 -> RGBColor[
              0.18263620644148504`, 0.30929261114727236`, 0.9337122338195634],
              198 -> RGBColor[
              0.8287975688378628, 0.8663247005533589, 0.9835326460637211], 63 -> 
             RGBColor[
              0.18932442036239164`, 0.31632234803540016`, 0.9340931177080333],
              310 -> RGBColor[
              0.8265166883216026, 0.20482446289255998`, 0.17302571672406986`],
              171 -> RGBColor[
              0.18805335571358273`, 0.3149863784993486, 0.9340207324566552], 
             395 -> RGBColor[
              0.4386808762090538, 0.554385059055515, 0.9491733354151413], 311 -> 
             RGBColor[
              0.2025961788233211, 0.3302718076559249, 0.934848924718576], 353 -> 
             RGBColor[
              0.9932598001133134, 0.9879917189181485, 0.507749021905247], 59 -> 
             RGBColor[
              0.21627237251575757`, 0.34464635434743823`, 0.9356277637172448],
              397 -> RGBColor[
              0.36417957475425095`, 0.48985577627965343`, 0.9444261783653554],
              229 -> RGBColor[
              0.19792175174780763`, 0.3253586884237658, 0.9345827230118207], 
             102 -> RGBColor[
              0.34903475823839447`, 0.4767380974142295, 0.9434611640490004], 
             299 -> RGBColor[
              0.18838969891108812`, 0.3153398965253172, 0.9340398867041779], 
             128 -> RGBColor[
              0.3039019362504366, 0.4367505818678281, 0.9406181377356125], 12 -> 
             RGBColor[
              0.242785484860208, 0.37251331644986996`, 0.9371376462426264], 
             222 -> RGBColor[
              0.9510874915293103, 0.9630417117862173, 0.9676802978022608], 92 -> 
             RGBColor[
              0.20437042968316516`, 0.3321366578036229, 0.9349499656802752], 
             271 -> RGBColor[
              0.8200027527924696, 0.15475549999089333`, 0.1667879647049341], 
             361 -> RGBColor[
              0.40957405763887067`, 0.529174195761261, 0.9473186746739982], 
             344 -> RGBColor[
              0.1915625031716876, 0.3186747149706162, 0.9342205732130758], 
             132 -> 
             RGBColor[
              0.19287402797566439`, 0.32005321069507126`, 0.9342952626104353],
              80 -> RGBColor[
              0.20310658273494972`, 0.3308082745285237, 0.9348779914662683], 
             324 -> RGBColor[
              0.1856877903127057, 0.31250001927751764`, 0.9338860170066157], 
             244 -> RGBColor[
              0.18235944175044905`, 0.3090017139090986, 0.9336964724798456], 
             150 -> RGBColor[
              0.23840666361665402`, 0.3679108976895925, 0.9368882788506916], 
             125 -> RGBColor[
              0.1925981967986741, 0.3197632946393477, 0.9342795544329613], 
             258 -> RGBColor[
              0.23765262088408304`, 0.3671183509685898, 0.9368453372325779], 
             133 -> RGBColor[
              0.18340497994045135`, 0.3101006408377411, 0.933756014333031], 
             255 -> RGBColor[
              0.37418878878290995`, 0.4985252543935531, 0.9450639566324611], 
             326 -> RGBColor[
              0.24157157412247404`, 0.37123741929812537`, 0.9370685158219325],
              176 -> RGBColor[
              0.18620451936940718`, 0.3130431342786254, 0.9339154439619627], 
             230 -> RGBColor[
              0.2211253737681676, 0.3497471663617724, 0.9359041349591976], 
             274 -> RGBColor[
              0.20313982636998706`, 0.33084321569671615`, 0.9348798846421041],
              87 -> RGBColor[
              0.18684859723136407`, 0.31372010094843716`, 0.9339521232433733],
              130 -> RGBColor[
              0.21566341381177923`, 0.3440063001393452, 0.9355930844199268], 
             35 -> RGBColor[
              0.19009976398754364`, 0.3171372833450601, 0.9341372723804675], 
             379 -> RGBColor[
              0.18246816409549027`, 0.30911598798713175`, 0.9337026640565553],
              31 -> RGBColor[
              0.9842583887354778, 0.9877584534482328, 0.9105427668445933], 18 -> 
             RGBColor[
              0.9925358512363838, 0.9864432654728553, 0.42895165434603927`], 
             24 -> RGBColor[
              0.2601817623901309, 0.39079790712151985`, 0.9381283385124692], 
             151 -> RGBColor[
              0.20761230953904478`, 0.335544079079207, 0.935134585942136], 
             137 -> RGBColor[
              0.29264465833089975`, 0.42491846902175034`, 0.9399770524117451],
              330 -> RGBColor[
              0.18870039039885345`, 0.3156664529779366, 0.9340575801247794], 
             296 -> RGBColor[
              0.17907641669607907`, 0.3055510464211448, 0.9335095090597996], 
             266 -> 
             RGBColor[
              0.6582217134144572, 0.7329270722804612, 0.9665690470276681], 
             302 -> RGBColor[
              0.19470143524485908`, 0.32197393159930776`, 0.9343993307510091],
              283 -> RGBColor[
              0.9319225428018962, 0.7678025982169813, 0.26408148383634866`], 
             388 -> RGBColor[
              0.2707814877613013, 0.40193889054802484`, 0.938731977191469], 
             284 -> RGBColor[
              0.7398648594018855, 0.7967073184367315, 0.9747064728211174], 
             318 -> RGBColor[
              0.21345649486519924`, 0.3416866883997466, 0.9354674036507632], 
             238 -> RGBColor[
              0.20088219976865415`, 0.32847030699692126`, 0.9347513161470175],
              72 -> RGBColor[
              0.46553671991296847`, 0.576982707272407, 0.9510679023901947], 
             288 -> RGBColor[
              0.2137339467700851, 0.34197830794324846`, 0.935483204126293], 
             382 -> RGBColor[
              0.3220959675484921, 0.453405070901625, 0.9417446481272771], 389 -> 
             RGBColor[
              0.9931232770303468, 0.9876997098482838, 0.4928893268471293], 
             172 -> RGBColor[
              0.3796233347917912, 0.5032323849982215, 0.9454102410985666], 
             243 -> RGBColor[
              0.23139395253121084`, 0.36054009370722817`, 0.9364889153287519],
              88 -> RGBColor[
              0.4303958842275222, 0.5472090154169172, 0.9486454230522088], 
             273 -> RGBColor[
              0.5240458703783706, 0.6244830714274116, 0.9556739570409113], 
             202 -> RGBColor[
              0.3275914997751332, 0.4581650247028605, 0.9420948185812503], 
             393 -> RGBColor[
              0.7219717591850786, 0.7827290925547635, 0.9729230558120345], 98 -> 
             RGBColor[
              0.1932487717488401, 0.3204470901608064, 0.9343166037139339], 30 -> 
             RGBColor[
              0.20069898841488326`, 0.3282777402478373, 0.9347408825314572], 
             116 -> RGBColor[
              0.24002120291967022`, 0.3696078808647668, 0.9369802244755014], 
             373 -> RGBColor[
              0.19798515205544082`, 0.3254253261669, 0.934586333565548], 240 -> 
             RGBColor[
              0.17933281357579656`, 0.305820535798229, 0.9335241104827943], 
             317 -> RGBColor[
              0.18850413369751906`, 0.3154601747414406, 0.9340464035959741], 
             391 -> RGBColor[
              0.8202342132018924, 0.1565346061243149, 0.16700961145439447`], 
             73 -> 
             RGBColor[
              0.1985117660113969, 0.3259788308238631, 0.9346163234512842], 
             303 -> RGBColor[
              0.8939300581111314, 0.611242991794526, 0.23320497928678602`], 
             29 -> RGBColor[
              0.18584110899752487`, 0.3126611669362287, 0.9338947482789014], 
             360 -> RGBColor[
              0.6627555094400547, 0.736468908193784, 0.9670209334447669], 320 -> 
             RGBColor[
              0.18370800885926494`, 0.3104191434445573, 0.9337732713816664], 
             75 -> RGBColor[
              0.18190969424137163`, 0.30852900076141915`, 0.9336708600245455],
              200 -> RGBColor[
              0.19404714705117995`, 0.3212862332234835, 0.9343620700063117], 
             301 -> RGBColor[
              0.24986810421890843`, 0.3799575984598681, 0.937540990937308], 
             156 -> RGBColor[
              0.20187169700218524`, 0.3295103313271106, 0.9348076665506371], 
             25 -> RGBColor[
              0.3639618362230004, 0.489667182107741, 0.9444123042586827], 38 -> 
             RGBColor[
              0.2587257572717294, 0.3892675534260234, 0.9380454211749428], 
             365 -> RGBColor[
              0.30601698137869693`, 0.43897362839923615`, 0.940738586426738], 
             380 -> RGBColor[
              0.7203821791624184, 0.7814873005598058, 0.9727646213308456], 
             370 -> RGBColor[
              0.18554668841356567`, 0.31235171223514435`, 0.9338779814622011],
              3 -> RGBColor[
              0.23621542372166607`, 0.36560776562732644`, 0.9367634909803209],
              57 -> RGBColor[
              0.3482989604247025, 0.47610078633028297`, 0.9434142796629524], 
             227 -> RGBColor[
              0.2739918424465178, 0.40531317687043084`, 0.9389148021414978], 
             39 -> RGBColor[
              0.19817415326039348`, 0.32562397841667373`, 0.9345970969045678],
              109 -> RGBColor[
              0.1827503081177702, 0.3094125392435122, 0.9337187317412295], 
             256 -> RGBColor[
              0.9923039511135691, 0.9910855002530954, 0.777206976991627], 339 -> 
             RGBColor[
              0.38195753878243316`, 0.5052541551744117, 0.9455589745127948], 
             287 -> RGBColor[0.817319, 0.134127, 0.164218], 239 -> 
             RGBColor[
              0.5071373117219987, 0.6107559417882819, 0.9543428533653905], 
             285 -> RGBColor[
              0.18427610046840573`, 0.31101624374485265`, 0.9338056233583907],
              345 -> RGBColor[
              0.8280837295399454, 0.865755504473851, 0.9834645594342339], 366 -> 
             RGBColor[
              0.9933000584574108, 0.9880778274454297, 0.5121308942145434], 
             216 -> RGBColor[
              0.21581639795358076`, 0.3441670961721334, 0.9356017966404827], 
             21 -> RGBColor[
              0.19666790482252822`, 0.3240408158068105, 0.9345113182843263], 
             355 -> RGBColor[
              0.2081404760074813, 0.3360992155252221, 0.9351646642411613], 
             175 -> RGBColor[
              0.19013667027984396`, 0.3171760741982618, 0.9341393741392161], 
             7 -> RGBColor[
              0.25494849258932906`, 0.3852974087524073, 0.9378303115392425], 
             13 -> RGBColor[
              0.21336291477373137`, 0.3415883297902934, 0.9354620744029933], 
             294 -> RGBColor[
              0.20973292712492791`, 0.3377729826168909, 0.9352553519764795], 
             193 -> RGBColor[
              0.8379281346647119, 0.8736051659010814, 0.9844035275832383], 60 -> 
             RGBColor[
              0.7070237961498369, 0.7710516302229059, 0.9714331825533382], 65 -> 
             RGBColor[
              0.3764941167365503, 0.5005220135978444, 0.9452108500911456], 69 -> 
             RGBColor[
              0.5728179374316162, 0.6640784326178184, 0.9595134728173111], 
             217 -> RGBColor[
              0.2082469591636211, 0.3362111360737471, 0.9351707282993756], 
             214 -> RGBColor[
              0.8789213821202363, 0.5430920994852084, 0.22068137214366979`], 
             170 -> RGBColor[
              0.23550398192177388`, 0.3648599951876243, 0.9367229754223009], 
             359 -> RGBColor[
              0.32568965645452963`, 0.4565177436079784, 0.9419736348065956], 
             74 -> RGBColor[
              0.24853385159996577`, 0.37855521436085726`, 0.9374650072245091],
              246 -> RGBColor[
              0.2167015948028579, 0.34509749418544555`, 0.9356522072915177], 
             264 -> RGBColor[
              0.2599789274537134, 0.39058471474286727`, 0.9381167873629076], 
             278 -> RGBColor[
              0.1880939032775767, 0.3150289965599703, 0.9340230415804399], 45 -> 
             RGBColor[
              0.23972125787035842`, 0.36929261960032556`, 0.9369631430486721],
              306 -> RGBColor[
              0.22229995450050422`, 0.350981725184178, 0.9359710255942676], 
             237 -> RGBColor[
              0.18222514168352894`, 0.3088605560236495, 0.9336888242897137], 
             228 -> 
             RGBColor[
              0.22400797509009437`, 0.3527769631185974, 0.9360682948400547], 
             180 -> RGBColor[
              0.18842432755960442`, 0.31537629343049095`, 0.9340418587544824],
              383 -> RGBColor[
              0.3583175561905998, 0.4847783904334387, 0.944052655726059], 53 -> 
             RGBColor[
              0.40260480881009003`, 0.5231377827104023, 0.9468746003012931], 
             304 -> RGBColor[
              0.2822705085644714, 0.4140145798581486, 0.9393862599297264], 48 -> 
             RGBColor[
              0.20793893985757575`, 0.3358873882535414, 0.9351531870555702], 
             5 -> RGBColor[
              0.18681770269069906`, 0.3136876288273712, 0.9339503638449868], 
             101 -> RGBColor[
              0.8539737461394735, 0.41587144104017043`, 0.19931862629877445`],
              333 -> RGBColor[
              0.9537765326908467, 0.9650471942815904, 0.9631284525300384], 
             267 -> RGBColor[
              0.19756403157199334`, 0.32498270183821587`, 0.9345623513770076],
              120 -> RGBColor[
              0.41254771032069193`, 0.531749824254125, 0.9475081531933861], 
             147 -> RGBColor[
              0.24721508689536167`, 0.3771691090418067, 0.9373899055255195], 
             89 -> RGBColor[
              0.23222586891438338`, 0.3614144905724877, 0.9365362917360636], 
             43 -> RGBColor[
              0.194697223000598, 0.3219695042635176, 0.9343990908699299], 199 -> 
             RGBColor[
              0.9887357523774989, 0.9896099583772056, 0.8363412642506296], 
             268 -> RGBColor[
              0.187660141527025, 0.31457308545805707`, 0.933998339490439], 
             169 -> RGBColor[
              0.45725872125089195`, 0.5702622550389433, 0.9504162280122078], 
             20 -> RGBColor[
              0.3846257063952153, 0.5075651878546001, 0.9457289877937134], 4 -> 
             RGBColor[
              0.2008450066857079, 0.32843121470856707`, 0.9347491980559659], 
             167 -> RGBColor[
              0.2358064817309028, 0.3651779416666145, 0.9367402023389224], 
             142 -> RGBColor[
              0.4741596199861951, 0.5839831660090739, 0.9517467286706829], 16 -> 
             RGBColor[
              0.22895368331262583`, 0.3579752160364906, 0.9363499456068083], 
             281 -> RGBColor[
              0.39875120665503094`, 0.5197999862113661, 0.9466290521795794], 
             289 -> RGBColor[
              0.4742143938317012, 0.5840276338843894, 0.9517510406684443], 
             398 -> 
             RGBColor[
              0.1808071689883251, 0.3073701768163288, 0.9336080728424244], 
             178 -> RGBColor[
              0.18300767959384703`, 0.309683052983163, 0.9337333886660452], 
             58 -> RGBColor[
              0.19320352841391442`, 0.32039953654720643`, 0.9343140271729413],
              186 -> RGBColor[
              0.2065811071166083, 0.33446021995121644`, 0.9350758604897056], 
             122 -> RGBColor[
              0.18936604401309215`, 0.31636609713137825`, 0.934095488113364], 
             249 -> RGBColor[
              0.18362197162651986`, 0.31032871285786656`, 0.9337683716885422],
              113 -> RGBColor[
              0.1856485479005117, 0.3124587730141891, 0.9338837822092951], 52 -> 
             RGBColor[
              0.9889946602077696, 0.9897170234186503, 0.8320504914710569], 
             187 -> RGBColor[
              0.21634716160662554`, 0.34472496242384276`, 0.9356320228453292],
              259 -> RGBColor[
              0.8954246210317355, 0.9194513034296, 0.9898875937806444], 42 -> 
             RGBColor[
              0.183885630512114, 0.31060583506356493`, 0.9337833866720284], 
             134 -> RGBColor[
              0.17911500115561352`, 0.3055916011345115, 0.9335117063876894], 
             313 -> RGBColor[
              0.28461757525764775`, 0.41648149576530025`, 0.9395199219057286],
              248 -> RGBColor[
              0.1829127869860106, 0.3095833148357881, 0.9337279846724099], 
             174 -> RGBColor[
              0.41783566912403936`, 0.5363299883890472, 0.947845097252377], 
             215 -> RGBColor[
              0.7060709713767632, 0.7703072762684443, 0.9713382138846121], 
             399 -> RGBColor[
              0.3593758114062829, 0.48569499791180964`, 0.944120086812624], 
             83 -> RGBColor[
              0.9509849302078126, 0.9629652217205732, 0.9678539073672795], 95 -> 
             RGBColor[
              0.24723118250472642`, 0.37718602654776967`, 0.9373908221466615],
              166 -> RGBColor[
              0.2451744333338886, 0.3750242527637898, 0.93727369332407], 384 -> 
             RGBColor[
              0.9335847383251342, 0.7743926495727972, 0.2654189253710895], 
             233 -> RGBColor[
              0.9703310152107799, 0.9773935002394792, 0.9351060317243296], 
             295 -> RGBColor[
              0.18590102371033476`, 0.3127241410982041, 0.9338981603331601], 
             141 -> RGBColor[
              0.3557668224000087, 0.48256907302763663`, 0.9438901252244479], 
             319 -> 
             RGBColor[
              0.8324443832728455, 0.2503873238203034, 0.17870208410375396`], 
             205 -> RGBColor[
              0.18515378626434187`, 0.3119387471648751, 0.9338556062660495], 
             224 -> RGBColor[
              0.4977475489543879, 0.6031329093695432, 0.9536036568444898], 
             231 -> RGBColor[
              0.19120668731506069`, 0.31830072994527303`, 0.9342003100264233],
              332 -> RGBColor[
              0.8178049183525352, 0.13786198138836525`, 0.164683315963154], 
             68 -> RGBColor[
              0.8216043579673015, 0.8605890294596807, 0.9828465511894319], 10 -> 
             RGBColor[
              0.8429670986480872, 0.3312695252776902, 0.18877864823079255`], 
             250 -> RGBColor[
              0.19372013073248498`, 0.3209425183385029, 0.9343434469107393], 
             282 -> RGBColor[
              0.31502354175322494`, 0.44727929114822085`, 0.9412939994095033],
              374 -> RGBColor[
              0.1836365577609456, 0.3103440438099624, 0.9337692023473195], 
             232 -> RGBColor[
              0.19035994618760685`, 0.3174107513338308, 0.934152089371856], 
             253 -> RGBColor[
              0.8251923969012658, 0.19464537872765014`, 0.17175757376438203`],
              55 -> RGBColor[
              0.8037373305687819, 0.8466049783610714, 0.9810726838248541], 
             325 -> RGBColor[
              0.23827199083861747`, 0.36776934806112876`, 0.9368806094352129],
              91 -> RGBColor[
              0.5925759149291727, 0.6801188488370776, 0.961068893181775], 105 -> 
             RGBColor[
              0.9853022906708313, 0.9881901337255575, 0.8932426102441758], 36 -> 
             RGBColor[
              0.24565388341041777`, 0.3755281851931126, 0.9373009972966455], 
             123 -> RGBColor[
              0.843157812611701, 0.33273543637341757`, 0.18896127613772973`], 
             94 -> RGBColor[
              0.1791057270796212, 0.3055818534926332, 0.9335111782427814], 
             312 -> RGBColor[
              0.5478165382686445, 0.6437811704771209, 0.9575452710920592], 96 -> 
             RGBColor[
              0.21162927735784165`, 0.3397661669472325, 0.9353633463168451], 
             2 -> RGBColor[
              0.20182540810126717`, 0.3294616787573599, 0.9348050304662081], 
             262 -> RGBColor[
              0.36433321534571095`, 0.4899888520377754, 0.9444359682079841], 
             272 -> RGBColor[
              0.19665135271400355`, 0.3240234184912868, 0.9345103756662324], 
             97 -> 
             RGBColor[
              0.2986247548964671, 0.43120392967218313`, 0.9403176100643942], 
             372 -> RGBColor[
              0.179946795179367, 0.3064658693922636, 0.9335590758268132], 356 -> 
             RGBColor[
              0.9453835605713274, 0.9587877294170835, 0.9773355650906732], 
             346 -> RGBColor[
              0.20342618893072584`, 0.3311442009044876, 0.9348961925663027], 
             341 -> RGBColor[
              0.24934350578881678`, 0.3794062122483802, 0.9375111158327881], 
             209 -> RGBColor[
              0.2650455441851616, 0.3959100501696741, 0.9384053236903759], 
             378 -> RGBColor[
              0.24023703411797065`, 0.3698347331386689, 0.9369925157429511], 
             66 -> RGBColor[
              0.19612721011213427`, 0.3234725113841618, 0.9344805265204555], 
             139 -> RGBColor[
              0.30694355404168716`, 0.4399475150161388, 0.940791353369154], 
             56 -> RGBColor[
              0.5183980864407423, 0.6198979459970778, 0.9552293428008269], 
             335 -> RGBColor[
              0.1982643030525542, 0.3257187315640616, 0.9346022308018668], 
             314 -> RGBColor[
              0.18275376889499648`, 0.30941617673980293`, 0.9337189288273728],
              144 -> RGBColor[
              0.5812572311839399, 0.6709298314718057, 0.9601778449356456], 
             298 -> RGBColor[
              0.20546571259734456`, 0.33328786959137313`, 0.9350123404219118],
              204 -> RGBColor[
              0.17994083687002446`, 0.30645960683136597`, 0.9335587365099107],
              207 -> RGBColor[
              0.1915172466480543, 0.31862714749484833`, 0.934217995921006], 
             334 -> RGBColor[
              0.9602115875305376, 0.8774464833562946, 0.2999299602777051], 
             149 -> RGBColor[
              0.21032620428650672`, 0.3383965545296549, 0.9352891382331565], 
             219 -> RGBColor[0.178927, 0.305394, 0.933501], 400 -> 
             RGBColor[
              0.8221152183090297, 0.17099283563946593`, 0.16881086406928056`],
              9 -> RGBColor[
              0.6863588655876156, 0.7549080294084094, 0.9693734953996518], 11 -> 
             RGBColor[
              0.873192830390407, 0.9017242770380856, 0.9877671057427206], 44 -> 
             RGBColor[
              0.22831342724773274`, 0.3573022663177088, 0.9363134839710866], 
             153 -> RGBColor[
              0.20565135384863537`, 0.33348299031681494`, 0.9350229124165412],
              32 -> RGBColor[
              0.8215188663850046, 0.16640901342833042`, 0.16823979679335105`],
              162 -> RGBColor[
              0.19529691214488243`, 0.32259981557664835`, 0.9344332422795363],
              90 -> RGBColor[
              0.21556902434658207`, 0.3439070908267852, 0.9355877090795206], 
             331 -> RGBColor[
              0.24096885499463874`, 0.3706039232801706, 0.9370341918592453], 
             8 -> RGBColor[
              0.25559866423556843`, 0.38598078037586825`, 0.937867337852653], 
             364 -> RGBColor[
              0.92133834354613, 0.7258397751431882, 0.2555651886720716], 342 -> 
             RGBColor[
              0.18639411010760892`, 0.31324240616522253`, 0.9339262408740289],
              163 -> RGBColor[
              0.17905422337022397`, 0.30552771982853294`, 0.9335082451827241],
              49 -> RGBColor[
              0.18369802063003998`, 0.31040864518235156`, 0.9337727025667882],
              338 -> RGBColor[
              0.21013611726343454`, 0.33819676101619267`, 0.9352783130584011],
              76 -> RGBColor[
              0.2829350020755027, 0.41471300466956446`, 0.9394241018521495], 
             369 -> RGBColor[
              0.1804054273287139, 0.30694792086018496`, 0.933585194249233], 
             82 -> RGBColor[
              0.7597586089991939, 0.8122484668202457, 0.9766892958633172], 67 -> 
             RGBColor[
              0.17940647345367122`, 0.30589795700018124`, 0.9335283053038692],
              211 -> RGBColor[
              0.23248905082520588`, 0.3616911114474591, 
               0.9365512795565422]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9mGk41G3YxiVbGGbGGGMMZp+JsVWihTktLbQQJSTFQyShTSoPqYhQlpJK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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 5}], {
             RGBColor[
             0.18431548798727523`, 0.3110576425244974, 0.9338078664193217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.18382719114068813`, 0.31054441157892615`, 0.933780058636279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 73}], {
             RGBColor[
             0.19016251964762415`, 0.3172032435227433, 0.9341408462224705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[
             0.18373091059218155`, 0.31044321461790636`, 0.9337745756014759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 162}], {
             RGBColor[
             0.18855509271436693`, 0.315513735899136, 0.9340493056365965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 183}], {
             RGBColor[
             0.18524860197516257`, 0.312038404488611, 0.9338610058805135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 291}], {
             RGBColor[
             0.1886369117353484, 0.31559973287781307`, 0.934053965108801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 357}], {
             RGBColor[
             0.18390843895748787`, 0.3106298081857918, 0.9337846855792504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 368}], {
             RGBColor[
             0.1828231865844723, 0.30948913913277776`, 0.9337228820620942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 387}], {
             RGBColor[
             0.1836776641650684, 0.31038724924699196`, 0.9337715432962228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 28}], {
             RGBColor[
             0.1967107027357332, 0.32408579912713337`, 0.9345137555621694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 39}], {
             RGBColor[
             0.19999978068083032`, 0.3275428285870168, 0.934701063685388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 50}], {
             RGBColor[
             0.216476564027812, 0.3448609725730971, 0.935639392121782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 106}], {
             RGBColor[
             0.19417223523988333`, 0.32141770884085996`, 0.9343691935936069]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 137}], {
             RGBColor[
             0.24723503321608348`, 0.3771900738895551, 0.9373910414389766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 138}], {
             RGBColor[
             0.24536530114030092`, 0.3752248669300471, 0.9372845629632816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 149}], {
             RGBColor[
             0.20607580619388693`, 0.3339291166435074, 0.9350470843496823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 164}], {
             RGBColor[
             0.20840908696131982`, 0.3363815426686245, 0.935179961237608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 197}], {
             RGBColor[
             0.1965684920257088, 0.3239363266542179, 0.9345056568726156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 210}], {
             RGBColor[
             0.223753059772891, 0.352509030957652, 0.9360537777898534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 217}], {
             RGBColor[
             0.20503618363244414`, 0.3328364074155535, 0.9349878793827919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 230}], {
             RGBColor[
             0.2114753909347174, 0.33960442255956613`, 0.9353545827127028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 254}], {
             RGBColor[
             0.19445154659843222`, 0.32171128278805783`, 0.9343850999622723]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 258}], {
             RGBColor[
             0.2197390144926751, 0.34829001486297484`, 0.935825183849393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 314}], {
             RGBColor[
             0.19228958849813182`, 0.3194389277485814, 0.9342619796467905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 328}], {
             RGBColor[
             0.2165885293871429, 0.3449786552647677, 0.935645768383358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 7}], {
             RGBColor[
             0.24558195815549755`, 0.37545258718986685`, 0.9372969012597816]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 13}], {
             RGBColor[
             0.2247891692476987, 0.3535980477088099, 0.9361127826916571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 14}], {
             RGBColor[
             0.28743237026540935`, 0.41667525783150516`, 0.9397814519424676]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 21}], {
             RGBColor[
             0.21644166427209716`, 0.34482429071706844`, 0.9356374046323236]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 51}], {
             RGBColor[
             0.2187121116641707, 0.34721067488081686`, 0.9357667032524762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 79}], {
             RGBColor[
             0.21763331081573253`, 0.34607678678918397`, 0.9357052671401005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 188}], {
             RGBColor[
             0.25601232241971317`, 0.38641556135484806`, 0.9378908950742876]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 232}], {
             RGBColor[
             0.21328768495463646`, 0.3415092584805786, 0.9354577901760884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 293}], {
             RGBColor[
             0.2751725873267546, 0.40605645004464963`, 0.939000269414517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 373}], {
             RGBColor[
             0.21710028788855346`, 0.3455165458971132, 0.9356749122729344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 390}], {
             RGBColor[
             0.22459916207358144`, 0.353398338121662, 0.9361019620641815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 84}], {
             RGBColor[
             0.20756604892203795`, 0.3354954562376403, 0.935131951468434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 125}], {
             RGBColor[
             0.196721601742191, 0.3240972546739574, 0.9345143762444637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 165}], {
             RGBColor[
             0.21319278532882907`, 0.3414095129568713, 0.9354523857827901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 184}], {
             RGBColor[
             0.20719899217930893`, 0.3351096563282905, 0.9351110481299474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 185}], {
             RGBColor[
             0.1966973229914563, 0.32407173616757357`, 0.9345129936055264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 190}], {
             RGBColor[
             0.20649883851719153`, 0.33437375043709894`, 0.9350711754146743]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.1963748100004493, 0.3237327545655205, 0.9344946269678038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 252}], {
             RGBColor[
             0.20339315185029538`, 0.3311094768382833, 0.9348943111534462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 274}], {
             RGBColor[
             0.2019924165278475, 0.3296372152026416, 0.934814541349035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 288}], {
             RGBColor[
             0.2072894767278965, 0.33520476132590776`, 0.9351162010911295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 318}], {
             RGBColor[
             0.20715075077545358`, 0.3350589515541568, 0.9351083008533645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.18632940584411195`, 0.31317439788179996`, 0.9339225560619441]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 113}], {
             RGBColor[
             0.18623312529560537`, 0.31307320092078017`, 0.9339170730271409]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 162}], {
             RGBColor[
             0.19105730741779076`, 0.3181437222020098, 0.9341918030622616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 183}], {
             RGBColor[
             0.1877508166785864, 0.3146683907914848, 0.9340035033061785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 270}], {
             RGBColor[
             0.19738135324155764`, 0.32479069533045285`, 0.9345519481163376]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 291}], {
             RGBColor[
             0.19113912643877223`, 0.3182297191806869, 0.9341964625344661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 357}], {
             RGBColor[
             0.1864106536609117, 0.3132597944886656, 0.9339271830049154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 368}], {
             RGBColor[
             0.18532540128789612`, 0.31211912543565157`, 0.9338653794877592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 10}], {
             RGBColor[
             0.8845651997050992, 0.6376155087725291, 0.5907990623624317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.6643840547861006, 0.7335496374888852, 0.969847038397682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 69}], {
             RGBColor[
             0.7494906190968638, 0.8040199624425932, 0.9761664746556911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 71}], {
             RGBColor[
             0.9479335881069795, 0.9604436363507414, 0.9644935461230137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 93}], {
             RGBColor[
             0.6343460318717724, 0.7075322117954237, 0.9679330421391619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 129}], {
             RGBColor[
             0.8727497313117147, 0.5467966411297123, 0.579484556485264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 131}], {
             RGBColor[
             0.8701371040264215, 0.8993351938028649, 0.9874630507499915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 142}], {
             RGBColor[
             0.7001614603741532, 0.763972329138221, 0.9722831025823769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 201}], {
             RGBColor[
             0.7959386825090102, 0.8413708229845736, 0.9800676455168078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 253}], {
             RGBColor[
             0.8756778488316885, 0.5693034354975091, 0.5822885251292265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 273}], {
             RGBColor[
             0.7251045855702409, 0.7842222818473898, 0.9742467167674911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 281}], {
             RGBColor[
             0.6624572537085711, 0.7318807392393671, 0.9697242643368251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 303}], {
             RGBColor[
             0.9100466794366213, 0.777602242030947, 0.6130122278904285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 364}], {
             RGBColor[
             0.9237508221541206, 0.8349006337052781, 0.6241923325830713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 391}], {
             RGBColor[
             0.8731987569820019, 0.5502480491958415, 0.5799145439742327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 394}], {
             RGBColor[
             0.6418942074247149, 0.7140700620770483, 0.9684140052108057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 13}], {
             RGBColor[
             0.23415570368153021`, 0.3634428692713504, 0.9366461929711178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 14}], {
             RGBColor[
             0.29679890469924086`, 0.4265200793940456, 0.9403148622219284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 21}], {
             RGBColor[
             0.22580819870592864`, 0.3546691122796089, 0.9361708149117844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 93}], {
             RGBColor[
             0.29873862778538124`, 0.4282001700379434, 0.9404384596617476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 142}], {
             RGBColor[
             0.36455405628776205`, 0.4846402873807406, 0.9447885201049626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 188}], {
             RGBColor[
             0.2653788568535447, 0.3962603829173885, 0.9384243053537484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 273}], {
             RGBColor[
             0.3894971814838498, 0.5048902400899095, 0.9467521342900769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 293}], {
             RGBColor[
             0.28453912176058604`, 0.41590127160719004`, 0.9395336796939777]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 390}], {
             RGBColor[
             0.23396569650741295`, 0.36324315968420245`, 0.9366353723436424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 16}], {
             RGBColor[
             0.24227617377409713`, 0.3719779982061794, 0.9371086417297306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 25}], {
             RGBColor[
             0.3097802502292844, 0.43782398124180466`, 0.9411398210556678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 76}], {
             RGBColor[
             0.26926683315553557`, 0.4003468925227164, 0.9386457198524012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 117}], {
             RGBColor[
             0.40706513411417244`, 0.5192304619580248, 0.9481280690845475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 202}], {
             RGBColor[
             0.2915950820053508, 0.42207290253936436`, 0.9399810782169516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 234}], {
             RGBColor[
             0.2512674523014992, 0.38142840201846384`, 0.9376206817404615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 239}], {
             RGBColor[
             0.3813679879787836, 0.49836836108207505`, 0.9461050956090218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 269}], {
             RGBColor[
             0.30450100126350144`, 0.4332513611304116, 0.9408034319798247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 302}], {
             RGBColor[
             0.22515004974021374`, 0.353977355987588, 0.936133334301831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 323}], {
             RGBColor[
             0.3381102648791732, 0.4623620160236, 0.9429449845379104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 365}], {
             RGBColor[
             0.2808078228071327, 0.4124772043875522, 0.9393029621396956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 377}], {
             RGBColor[
             0.25514638831763914`, 0.3855054097101751, 0.9378415814082092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 388}], {
             RGBColor[
             0.26319007599843486`, 0.3939598354619466, 0.938299657522061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 18}], {
             RGBColor[
             0.8394473584119997, 0.8706756474406323, 0.6991625748728455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 56}], {
             RGBColor[
             0.6023784760141789, 0.6874029877027437, 0.9623014191002394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 65}], {
             RGBColor[
             0.531426491162083, 0.6277150215031269, 0.9572921727453987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 100}], {
             RGBColor[
             0.5370355289675518, 0.6325732881317867, 0.9576495756744858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 174}], {
             RGBColor[
             0.5520972673558275, 0.6456190088987284, 0.9586092963260144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 198}], {
             RGBColor[
             0.7575782172127392, 0.8106163649808842, 0.9764530707316865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 203}], {
             RGBColor[
             0.4981842108201723, 0.5989222290765547, 0.9551740040370065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 266}], {
             RGBColor[
             0.6722902895010364, 0.7439175508444353, 0.9679712712136599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 313}], {
             RGBColor[
             0.4854882204226317, 0.5856947625868548, 0.9544467086526902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 339}], {
             RGBColor[
             0.5341582021850244, 0.6300810922914106, 0.9574662349562233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 358}], {
             RGBColor[
             0.48197798109692647`, 0.5820052784935108, 0.954246805716025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 384}], {
             RGBColor[
             0.8099718019563749, 0.7646503394906032, 0.6173962103853706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 32}], {
             RGBColor[
             0.8322429825165458, 0.24883926935301032`, 0.1785092225120718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 52}], {
             RGBColor[
             0.9159808794279284, 0.6604932743481702, 0.5104145698509248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 60}], {
             RGBColor[
             0.774995447398962, 0.551160577750298, 0.5801059153920654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 68}], {
             RGBColor[
             0.8322857283076943, 0.5959292773686855, 0.5858125997101122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.8311516302547027, 0.2404506576348733, 0.17746414235362473`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 253}], {
             RGBColor[
             0.8340797477746764, 0.2629574520026702, 0.18026811099758727`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 271}], {
             RGBColor[
             0.8314849257202783, 0.24301251263429177`, 0.17778330646786333`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 303}], {
             RGBColor[
             0.8684485783796092, 0.4712562585361081, 0.21099181375878928`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 333}], {
             RGBColor[
             0.8983718156694669, 0.6481583597796403, 0.5759535503804154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 334}], {
             RGBColor[
             0.9015893430893124, 0.6043580043169925, 0.2443543042542488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 337}], {
             RGBColor[
             0.8999731601904741, 0.6493526399014464, 0.5732428918038912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 345}], {
             RGBColor[
             0.8355254140940163, 0.5985125148757706, 0.5861216038325132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 353}], {
             RGBColor[
             0.9181134493807003, 0.6596306220979193, 0.3482638350680197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 364}], {
             RGBColor[
             0.8821527210971085, 0.5285546502104392, 0.22217191845143208`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 391}], {
             RGBColor[
             0.8316006559249898, 0.24390206570100256`, 0.1778941298425935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 54}], {
             RGBColor[
             0.9107233154962703, 0.8671374351819781, 0.6324945514745149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 83}], {
             RGBColor[
             0.9120888802991098, 0.9323447493793293, 0.977810506555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 118}], {
             RGBColor[
             0.6153201099210919, 0.6928744863891039, 0.9658821576068201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 123}], {
             RGBColor[
             0.8581753215010539, 0.6172298567057516, 0.5883641909402252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 141}], {
             RGBColor[
             0.6144798263952078, 0.6921466750328611, 0.9658286154835842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 161}], {
             RGBColor[
             0.8763695857039919, 0.7238270844566292, 0.6044849794547379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 196}], {
             RGBColor[
             0.8586587168624804, 0.8901351694289188, 0.9863808290196707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 206}], {
             RGBColor[
             0.6510406164097462, 0.7238137937447175, 0.9681582366938735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 214}], {
             RGBColor[
             0.8760571062553216, 0.722408188261647, 0.6042242389431952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 286}], {
             RGBColor[
             0.5972181184299319, 0.677195451192008, 0.9647287147159659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 332}], {
             RGBColor[
             0.8454988743714711, 0.5197931292132254, 0.5762252108529373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 366}], {
             RGBColor[
             0.9332464444239088, 0.9449010522417576, 0.749948999978632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 386}], {
             RGBColor[
             0.6075598618760001, 0.6861529495738531, 0.9653876814635047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 19}], {
             RGBColor[
             0.22114916866345258`, 0.3497721763054004, 0.9359054900432826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 24}], {
             RGBColor[
             0.25148362362516946`, 0.3816556117856949, 0.9376329923775478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 65}], {
             RGBColor[
             0.30963980079837916`, 0.4365176650238572, 0.941174248166886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 100}], {
             RGBColor[
             0.315248838603848, 0.44137593165251704`, 0.941531651095973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 107}], {
             RGBColor[
             0.23293330946253646`, 0.362158055442918, 0.9365765794287164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 124}], {
             RGBColor[
             0.23470207361547668`, 0.3640171387137828, 0.9366773079305742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 150}], {
             RGBColor[
             0.24059607423843102`, 0.37021210706973123`, 0.937012962546659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 157}], {
             RGBColor[
             0.24482342257705114`, 0.37465531820298625`, 0.937253703780742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 167}], {
             RGBColor[
             0.2392959832955554, 0.36884562905824225`, 0.9369389242907744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 168}], {
             RGBColor[
             0.22037492795635888`, 0.34895840023254887`, 0.9358613981804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 203}], {
             RGBColor[
             0.2763975204564685, 0.40772487259728496`, 0.9390560794584938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 206}], {
             RGBColor[
             0.33583694364464667`, 0.4592083134506097, 0.9428435069438263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 211}], {
             RGBColor[
             0.23763726784270695`, 0.3671022139486645, 0.9368444628995842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 238}], {
             RGBColor[
             0.2218338423144311, 0.3504918117233956, 0.9359444811948219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 341}], {
             RGBColor[
             0.2460644953245124, 0.3759597643491251, 0.9373243810377072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 358}], {
             RGBColor[
             0.26019129073322267`, 0.39080792201424114`, 0.9381288811375124]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 14}], {
             RGBColor[
             0.27600611579144196`, 0.4046655399129887, 0.9391307436538039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 21}], {
             RGBColor[
             0.2050154097981298, 0.332814572798552, 0.9349866963436598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 51}], {
             RGBColor[
             0.20728585719020337`, 0.33520095696230034`, 0.9351159949638125]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 79}], {
             RGBColor[
             0.20620705634176517`, 0.33406706887066745`, 0.9350545588514367]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 87}], {
             RGBColor[
             0.2001057560025477, 0.3276542153693653, 0.9347070988231834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 205}], {
             RGBColor[
             0.19925835051903662`, 0.3267635384775842, 0.9346588403345214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 232}], {
             RGBColor[
             0.20186143048066912`, 0.3294995405620621, 0.9348070818874247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 277}], {
             RGBColor[
             0.19923872667069553`, 0.3267429125687539, 0.9346577227853893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 373}], {
             RGBColor[
             0.2056740334145861, 0.3335068279785967, 0.9350242039842707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 390}], {
             RGBColor[
             0.2131729075996141, 0.34138862020314553`, 0.9354512537755177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 69}], {
             RGBColor[
             0.45573362712038445`, 0.5659105913267511, 0.9511564428609628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 71}], {
             RGBColor[
             0.6541765961305002, 0.7223342652348994, 0.9394835143282855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 201}], {
             RGBColor[
             0.5021816905325309, 0.6032614518687315, 0.9550576137220795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 212}], {
             RGBColor[
             0.45821441723172895`, 0.5679246084974616, 0.9513517397459614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 273}], {
             RGBColor[
             0.4313475935937616, 0.5461129107315478, 0.9492366849727629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 289}], {
             RGBColor[
             0.4064318553204269, 0.5258851919600367, 0.9472752267865294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 293}], {
             RGBColor[
             0.32638953387049785`, 0.45712394224882835`, 0.9420182303766638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 390}], {
             RGBColor[
             0.27581610861732475`, 0.40446583032584077`, 0.9391199230263283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 35}], {
             RGBColor[
             0.1861148468094702, 0.312948882732563, 0.933910337242333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 106}], {
             RGBColor[
             0.18432449600494816`, 0.311067110522213, 0.933808379412602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 154}], {
             RGBColor[
             0.18425132424679044`, 0.31099020236503183`, 0.933804212389223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 207}], {
             RGBColor[
             0.18682358813972555`, 0.3136938148074571, 0.9339506990126021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 231}], {
             RGBColor[
             0.18666830847322874`, 0.31353060603266947`, 0.9339418560653108]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 369}], {
             RGBColor[
             0.18126767848005537`, 0.30785420149012543`, 0.9336342981767156]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 372}], {
             RGBColor[
             0.1810383624053819, 0.30761317575616476`, 0.9336212389655058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 392}], {
             RGBColor[
             0.19259602959164984`, 0.3197610167673564, 0.9342794310137273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 25}], {
             RGBColor[
             0.2964577597678131, 0.4238211990721158, 0.9403811249327455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 37}], {
             RGBColor[
             0.25664259349321183`, 0.38707801621458926`, 0.9379267880795208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 76}], {
             RGBColor[
             0.2559443426940643, 0.3863441103530275, 0.937887023729479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 77}], {
             RGBColor[
             0.21295289463759554`, 0.3411573726304365, 0.9354387243628108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 78}], {
             RGBColor[
             0.22470970081672578`, 0.3535145213492678, 0.9361082570820762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 80}], {
             RGBColor[
             0.21603013302378776`, 0.34439174528250716`, 0.9356139685365383]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 96}], {
             RGBColor[
             0.22029148033523374`, 0.34887069149186156`, 0.9358566459618267]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 182}], {
             RGBColor[
             0.23539065510704868`, 0.36474088152001305`, 0.9367165216278543]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.22265042245962569`, 0.35135008923016664`, 0.9359909842260687]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 269}], {
             RGBColor[
             0.29117851080203017`, 0.41924857896072276`, 0.9400447358569024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 302}], {
             RGBColor[
             0.21182755927874247`, 0.3399745738178992, 0.9353746381789088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 323}], {
             RGBColor[
             0.3247877744177019, 0.4483592338539112, 0.9421862884149881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 365}], {
             RGBColor[
             0.2674853323456614, 0.39847442221786333`, 0.9385442660167731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 377}], {
             RGBColor[
             0.24182389785616784`, 0.37150262754048624`, 0.9370828852852868]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 388}], {
             RGBColor[
             0.24986758553696356`, 0.3799570532922577, 0.9375409613991386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 18}], {
             RGBColor[
             0.9100987698336667, 0.6000343504740516, 0.3015369122339562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 31}], {
             RGBColor[
             0.9059600385832136, 0.6006919444617403, 0.5423324684832332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 62}], {
             RGBColor[
             0.9097327710312662, 0.6022520662838114, 0.4798085283004041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.8649138899410389, 0.5692261022124661, 0.5823263856846504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 111}], {
             RGBColor[
             0.8271368865255229, 0.20959157806047718`, 0.1736196192245576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 222}], {
             RGBColor[
             0.88937458998013, 0.5883335736307327, 0.570901233962067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 223}], {
             RGBColor[
             0.843439007132864, 0.3336207383005069, 0.18918058014291417`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 247}], {
             RGBColor[
             0.8225002166596341, 0.17395210166956507`, 0.16917953892461288`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 256}], {
             RGBColor[
             0.9099828197722593, 0.6023554678641716, 0.47566457355675007`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 292}], {
             RGBColor[
             0.8235767865158092, 0.18222708934004583`, 0.17021046343469787`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 310}], {
             RGBColor[
             0.8270891883762761, 0.20922494918390394`, 0.1735739434229715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 319}], {
             RGBColor[
             0.8300530358518976, 0.23200637964777565`, 0.17641212711281357`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 384}], {
             RGBColor[
             0.8806232133780418, 0.49400904252402256`, 0.21977054774648136`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 99}], {
             RGBColor[
             0.947350971343756, 0.9556350172112698, 0.7097411277967336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 144}], {
             RGBColor[
             0.7868965412101618, 0.8286865484723305, 0.6945647496408425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.9106667100371233, 0.9263839830131071, 0.7062421502048801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 218}], {
             RGBColor[
             0.776406098847213, 0.8201699347730458, 0.6937389035902746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 266}], {
             RGBColor[
             0.8253787823254205, 0.8596851688766582, 0.6977603506868537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 310}], {
             RGBColor[
             0.9095262697789932, 0.5956338641827077, 0.30098868553505453`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 319}], {
             RGBColor[
             0.9124901172546147, 0.6184152946465793, 0.3038268692248966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 384}], {
             RGBColor[
             0.9630602947807589, 0.8804179575228263, 0.3471852898585644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 24}], {
             RGBColor[
             0.22984730742841403`, 0.35891447164122536`, 0.936400836178204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 85}], {
             RGBColor[
             0.19070082938217475`, 0.3177690411845645, 0.9341715021654952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 107}], {
             RGBColor[
             0.211296993265781, 0.33941691529844853`, 0.9353444232293726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 124}], {
             RGBColor[
             0.21306575741872125`, 0.34127599856931323`, 0.9354451517312304]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 150}], {
             RGBColor[
             0.21895975804167556`, 0.3474709669252617, 0.9357808063473152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 152}], {
             RGBColor[
             0.2001783639532218, 0.3277305309291337, 0.9347112337385604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 157}], {
             RGBColor[
             0.2231871063802957, 0.35191417805851677`, 0.9360215475813982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 160}], {
             RGBColor[
             0.19740416245689973`, 0.32481466926196517`, 0.9345532470674082]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 167}], {
             RGBColor[
             0.21765966709879997`, 0.34610448891377266`, 0.9357067680914306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 168}], {
             RGBColor[
             0.19873861175960342`, 0.3262172600880793, 0.9346292419810562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 181}], {
             RGBColor[
             0.19581756515250187`, 0.3231470548989638, 0.9344628926980831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 211}], {
             RGBColor[
             0.2160009516459515, 0.344361073804195, 0.9356123067002404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 238}], {
             RGBColor[
             0.20019752611767563`, 0.32775067157892607`, 0.9347123249954781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 64}], {
             RGBColor[
             0.6886054780275248, 0.7470570557801346, 0.690028677840299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 88}], {
             RGBColor[
             0.40751079531136875`, 0.5273871016357587, 0.9471872054229611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 89}], {
             RGBColor[
             0.30842578765479933`, 0.4344898392135439, 0.9411326397648885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 120}], {
             RGBColor[
             0.3985867083579536, 0.5196575060543626, 0.9466185704935497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 140}], {
             RGBColor[
             0.3954861818985797, 0.5169719858722439, 0.9464210076892463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 189}], {
             RGBColor[
             0.30889970680782364`, 0.4349879582915822, 0.9411596287595527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 195}], {
             RGBColor[
             0.40462199010322386`, 0.5248849637600351, 0.9470031333095683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 241}], {
             RGBColor[
             0.33276855688740864`, 0.46007563309772936`, 0.9425189244607857]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 255}], {
             RGBColor[
             0.37940724758906264`, 0.5030452211240766, 0.9453964722130872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 257}], {
             RGBColor[
             0.6770229856308323, 0.7421397259892473, 0.9411883411446311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 263}], {
             RGBColor[
             0.3432288815576954, 0.4710700975490908, 0.943114624476095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 312}], {
             RGBColor[
             0.4662211223319299, 0.5756731791658605, 0.9516371294428863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 336}], {
             RGBColor[
             0.3097133743307097, 0.43584317444763615`, 0.9412059659212678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 356}], {
             RGBColor[
             0.6650046334832713, 0.7331764586358418, 0.9615322764421933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 359}], {
             RGBColor[
             0.3551576814248725, 0.48204146573128925`, 0.9438513113001545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 360}], {
             RGBColor[
             0.523690607917635, 0.622017048024192, 0.9563749606192402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 389}], {
             RGBColor[
             0.688874491712781, 0.747632448851442, 0.7193091573204213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 109}], {
             RGBColor[
             0.1897091064701492, 0.31672667752516137`, 0.9341150250127779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[
             0.19167285067202883`, 0.3187906971899105, 0.9342268573399758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 132}], {
             RGBColor[
             0.1947709663990963, 0.3220470132509409, 0.9344032904473808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 180}], {
             RGBColor[
             0.19254611619106632`, 0.3197085546186507, 0.9342765885194044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 232}], {
             RGBColor[
             0.19351392550506752`, 0.32072578357032067`, 0.9343317038280912]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 249}], {
             RGBColor[
             0.19014493822452405`, 0.31718476433233855`, 0.9341398449864342]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 370}], {
             RGBColor[
             0.19110729661804693`, 0.31819626402097745`, 0.9341946498732637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 45}], {
             RGBColor[
             0.24087710963769857`, 0.3705074930930349, 0.9370289670968927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 74}], {
             RGBColor[
             0.24528340650250224`, 0.37513879047330073`, 0.9372798991848111]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 116}], {
             RGBColor[
             0.24102708216235447`, 0.3706651237252555, 0.9370375078103073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 141}], {
             RGBColor[
             0.2988998919025237, 0.4271457198066904, 0.9404924581847806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 179}], {
             RGBColor[
             0.2344230766191157, 0.3637238951811761, 0.9366614194643705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 209}], {
             RGBColor[
             0.25353925279510015`, 0.38381620837770913`, 0.9377500574177445]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 286}], {
             RGBColor[
             0.2816381839372477, 0.41219449596583724`, 0.9393925574171622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 290}], {
             RGBColor[
             0.2497813465899759, 0.3798664106911086, 0.9375360502186867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 304}], {
             RGBColor[
             0.2621517349847551, 0.3928684732219464, 0.9382405255374198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 338}], {
             RGBColor[
             0.2260845393342366, 0.35495956380096844`, 0.9361865521017572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 38}], {
             RGBColor[
             0.23532272116707456`, 0.36466947864183974`, 0.936712652890472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 92}], {
             RGBColor[
             0.20814505737279243`, 0.33610403083063944`, 0.9351649251431382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 98}], {
             RGBColor[
             0.2025842284056299, 0.3302592470092312, 0.9348482441599675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 119}], {
             RGBColor[
             0.22585475434557115`, 0.35471804520867123`, 0.936173466186589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 128}], {
             RGBColor[
             0.2579108106564282, 0.38841099286274205`, 0.9379990111708069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 130}], {
             RGBColor[
             0.21379154943709947`, 0.3420388519985006, 0.935486484512964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 139}], {
             RGBColor[
             0.2594316195520534, 0.3900094594368974, 0.9380856189875776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 143}], {
             RGBColor[
             0.20541157212716055`, 0.3332309645245057, 0.9350092572022285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 146}], {
             RGBColor[
             0.20552449462249126`, 0.333349653226798, 0.9350156879712836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 151}], {
             RGBColor[
             0.20976599730073225`, 0.3378077414684315, 0.9352572352740687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 158}], {
             RGBColor[
             0.20153001639620693`, 0.3291512033464258, 0.9347882083455978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 186}], {
             RGBColor[
             0.209250396089514, 0.3372658119044362, 0.9352278725478533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 213}], {
             RGBColor[
             0.2686665233533321, 0.39817491739397315`, 0.9386679570758016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 267}], {
             RGBColor[
             0.20474185831720654`, 0.33252705284793593`, 0.9349711179915043]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 306}], {
             RGBColor[
             0.21710981978146196`, 0.345526564520917, 0.9356754551001344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 308}], {
             RGBColor[
             0.21238372481471685`, 0.3405591390591399, 0.9354063109834092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 311}], {
             RGBColor[
             0.2072579319428704, 0.33517160575679045`, 0.9351144046622886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 346}], {
             RGBColor[
             0.20767293699657277`, 0.3356078023810718, 0.935138038586152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 348}], {
             RGBColor[
             0.20651189165865158`, 0.3343874701163905, 0.93507191877177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 354}], {
             RGBColor[
             0.20401044687486744`, 0.3317582930478737, 0.9349294651918895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 374}], {
             RGBColor[
             0.19777812141168266`, 0.3252077238338092, 0.9345745434766604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 33}], {
             RGBColor[
             0.2533855843329195, 0.3836546930808141, 0.9377413062261555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 56}], {
             RGBColor[
             0.3892899244154366, 0.5053479265592988, 0.9466788406566481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 65}], {
             RGBColor[
             0.3183379395633406, 0.44565996035968214`, 0.9416695943018074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 100}], {
             RGBColor[
             0.32394697736880945`, 0.450518226988342, 0.9420269972308946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 107}], {
             RGBColor[
             0.2416314482274979, 0.371300350778743, 0.9370719255636378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 124}], {
             RGBColor[
             0.24340021238043813`, 0.3731594340496077, 0.9371726540654957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 150}], {
             RGBColor[
             0.24929421300339247`, 0.3793544024055562, 0.9375083086815804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 157}], {
             RGBColor[
             0.2535215613420126, 0.38379761353881126`, 0.9377490499156633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 167}], {
             RGBColor[
             0.24799412206051685`, 0.37798792439406714`, 0.9374342704256958]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 168}], {
             RGBColor[
             0.22907306672132033`, 0.35810069556837376`, 0.9363567443153216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 203}], {
             RGBColor[
             0.2850956592214299, 0.4168671679331099, 0.9395514255934152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 206}], {
             RGBColor[
             0.3445350824096081, 0.46835060878643464`, 0.9433388530787478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 211}], {
             RGBColor[
             0.2463354066076684, 0.3762445092844895, 0.9373398090345058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 238}], {
             RGBColor[
             0.23053198107939255`, 0.35963410705922055`, 0.9364398273297434]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 341}], {
             RGBColor[
             0.25476263408947386`, 0.38510205968495004`, 0.9378197271726287]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 358}], {
             RGBColor[
             0.2688894294981841, 0.3999502173500661, 0.9386242272724338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 386}], {
             RGBColor[
             0.3010543278758621, 0.4306897646155703, 0.940568297848379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 37}], {
             RGBColor[
             0.3241466699483991, 0.4529239992502145, 0.9419579674054581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 62}], {
             RGBColor[
             0.6778828449272916, 0.740272939600058, 0.8649535953688089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[
             0.32344841914925154`, 0.45219009338865274`, 0.9419182030554161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 78}], {
             RGBColor[
             0.29221377727191306`, 0.41936050438489303`, 0.9401394364080135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 91}], {
             RGBColor[
             0.47826887557608655`, 0.5848930154724093, 0.9527405987202289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 117}], {
             RGBColor[
             0.4612467201078884, 0.5710736628239611, 0.9514005522875624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 182}], {
             RGBColor[
             0.30289473156223595`, 0.4305868645556383, 0.9407477009537915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 187}], {
             RGBColor[
             0.29015449891481293`, 0.4171960722657919, 0.940022163552006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 208}], {
             RGBColor[
             0.3291899186131193, 0.4582247733572693, 0.9422451729560961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 239}], {
             RGBColor[
             0.43554957397249955`, 0.5502115619480115, 0.9493775788120367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 269}], {
             RGBColor[
             0.35868258725721747`, 0.48509456199634804`, 0.9440759151828396]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 309}], {
             RGBColor[
             0.5306642654095335, 0.6265873056000757, 0.957441478589943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 323}], {
             RGBColor[
             0.3922918508728892, 0.5142052168895364, 0.9462174677409253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 362}], {
             RGBColor[
             0.5776163710657185, 0.6632666473879071, 0.9621212256893779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 365}], {
             RGBColor[
             0.33498940880084865`, 0.4643204052534886, 0.9425754453427104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 377}], {
             RGBColor[
             0.3093279743113551, 0.4373486105761115, 0.941114064611224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 388}], {
             RGBColor[
             0.31737166199215083`, 0.44580303632788293`, 0.9415721407250759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 395}], {
             RGBColor[
             0.4013213562160271, 0.522026120581628, 0.946792819836912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 70}], {
             RGBColor[
             0.1896105861046007, 0.3166231263744179, 0.9341094144237078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 177}], {
             RGBColor[
             0.18182665700375172`, 0.3084417233598157, 0.9336661311767056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 285}], {
             RGBColor[
             0.1832664520031871, 0.30995503919249784`, 0.9337481253719375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 324}], {
             RGBColor[
             0.1839722969253371, 0.31069692695883033`, 0.9337883221960501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 40}], {
             RGBColor[
             0.19924073649984758`, 0.3267450250266232, 0.9346578372421862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 41}], {
             RGBColor[
             0.1999138771125005, 0.32745253849010136`, 0.9346961716042546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 48}], {
             RGBColor[
             0.20648582903789775`, 0.33436007664951256`, 0.9350704345440743]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 63}], {
             RGBColor[
             0.1971785692903057, 0.32457755654044196`, 0.9345403998703059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 86}], {
             RGBColor[
             0.23656599040606416`, 0.3659762334398404, 0.9367834552343804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 250}], {
             RGBColor[
             0.19937642447535237`, 0.3268876416919933, 0.9346655644716588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 265}], {
             RGBColor[
             0.20201462184730384`, 0.32966055440128883`, 0.9348158059091283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 295}], {
             RGBColor[
             0.19546687096427723`, 0.32277845307184394`, 0.9344429211828693]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 325}], {
             RGBColor[
             0.22165235452841858`, 0.35030105655330623`, 0.9359341457338957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 376}], {
             RGBColor[
             0.24560585367761548`, 0.37547770289867644`, 0.937298262074416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 39}], {
             RGBColor[
             0.19488507531529636`, 0.3221669489567903, 0.9344097887813494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 50}], {
             RGBColor[
             0.21136185866227802`, 0.33948509294287055`, 0.9353481172177434]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 106}], {
             RGBColor[
             0.18905752987434937`, 0.31604182921063345`, 0.9340779186895682]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 197}], {
             RGBColor[
             0.19145378666017485`, 0.3185604470239914, 0.9342143819685769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 217}], {
             RGBColor[
             0.19992147826691017`, 0.32746052778532697`, 0.9346966044787532]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 231}], {
             RGBColor[
             0.19140134234262995`, 0.31850532472108994`, 0.934211395342277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 254}], {
             RGBColor[
             0.1893368412328983, 0.3163354031578313, 0.9340938250582336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 314}], {
             RGBColor[
             0.18717488313259786`, 0.3140630481183549, 0.9339707047427519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 369}], {
             RGBColor[
             0.1860007123494566, 0.3128289201785459, 0.9339038374536819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 113}], {
             RGBColor[
             0.1857448284490183, 0.3125599699752089, 0.9338892652440982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 162}], {
             RGBColor[
             0.19056901057120365`, 0.3176304912564385, 0.9341639952792189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 183}], {
             RGBColor[
             0.18726251983199932`, 0.31415515984591347`, 0.9339756955231359]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 270}], {
             RGBColor[
             0.19689305639497057`, 0.3242774643848816, 0.9345241403332949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 357}], {
             RGBColor[
             0.18592235681432462`, 0.3127465635430944, 0.9338993752218727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 153}], {
             RGBColor[
             0.2031751711317593, 0.3308803652823261, 0.9348818974739992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 168}], {
             RGBColor[
             0.19933167973369648`, 0.3268406121315325, 0.9346630163248155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 175}], {
             RGBColor[
             0.19541782934736363`, 0.32272690722304953`, 0.9344401283353366]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 211}], {
             RGBColor[
             0.21659401962004457`, 0.3449844258476482, 0.9356460810439997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 216}], {
             RGBColor[
             0.208257693184232, 0.33622241820998533`, 0.93517133958597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 229}], {
             RGBColor[
             0.19931037008134544`, 0.32681821433580155`, 0.9346618027716389]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 294}], {
             RGBColor[
             0.2052159577699056, 0.3330253614323641, 0.9349981172539683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 329}], {
             RGBColor[
             0.23151896311630302`, 0.36067148775828894`, 0.9364960344966363]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 341}], {
             RGBColor[
             0.22502124710185, 0.35384197624810876`, 0.9361259991821227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 343}], {
             RGBColor[
             0.2007094287814945, 0.32828871373510315`, 0.9347414770948905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 358}], {
             RGBColor[
             0.2391480425105603, 0.3686901339132248, 0.9369304992819277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 379}], {
             RGBColor[
             0.19158357625518677`, 0.31869686411748455`, 0.9342217732940062]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 99}], {
             RGBColor[
             0.9432122400933031, 0.9562926111989585, 0.9505366840460105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 111}], {
             RGBColor[
             0.905435236677787, 0.5966580870469695, 0.5418299175859177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 169}], {
             RGBColor[
             0.7207585549931849, 0.779010354243588, 0.9304794974284005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 199}], {
             RGBColor[
             0.9864970705564884, 0.9886842059127192, 0.8734420155476115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 215}], {
             RGBColor[
             0.8451646800561206, 0.8790328648583385, 0.9409404903646027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 222}], {
             RGBColor[
             0.967672940132394, 0.9754000826172251, 0.9391115323234271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 223}], {
             RGBColor[
             0.9217373572851282, 0.7206872472869994, 0.5573908785042743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 224}], {
             RGBColor[
             0.7410029688449329, 0.7954456814088879, 0.9320732118445416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 247}], {
             RGBColor[
             0.9007985668118983, 0.5610186106560575, 0.5373898372859729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 259}], {
             RGBColor[
             0.9398415048836066, 0.9536048784389164, 0.9502151803126189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 292}], {
             RGBColor[
             0.9018751366680733, 0.5692935983265383, 0.5384207617960579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 363}], {
             RGBColor[
             0.6793920980440895, 0.7432878081939467, 0.9278140990011539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 383}], {
             RGBColor[
             0.6712879724630387, 0.7362684219408357, 0.9272977112853262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 393}], {
             RGBColor[
             0.8531150739602782, 0.8852437730014981, 0.9417329113283139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 400}], {
             RGBColor[
             0.9031868035222537, 0.5793756445438494, 0.5396768154569369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 46}], {
             RGBColor[
             0.8135276706473076, 0.5072097485112304, 0.5747459012560696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 52}], {
             RGBColor[
             0.905256763296387, 0.5780630184234903, 0.500145144132204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 71}], {
             RGBColor[
             0.8956113709184261, 0.5716673969312225, 0.5522037062726537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 105}], {
             RGBColor[
             0.903410578527918, 0.577299573576944, 0.5307412035187635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 111}], {
             RGBColor[
             0.8240654755025505, 0.18598336703701845`, 0.17067843256029655`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 129}], {
             RGBColor[
             0.8204275141231614, 0.1580204017101934, 0.16719471663490398`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 199}], {
             RGBColor[
             0.9051273093812517, 0.578009485902768, 0.5022905305219902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 215}], {
             RGBColor[
             0.7637949188808839, 0.4683581448483874, 0.5697890053389816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 247}], {
             RGBColor[
             0.8194288056366617, 0.15034389064610632`, 0.16623835226035183`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 259}], {
             RGBColor[
             0.85847174370837, 0.5429301584289652, 0.5790636952869976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 271}], {
             RGBColor[
             0.8207608095887371, 0.16058225670961188`, 0.16751388074914259`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 287}], {
             RGBColor[
             0.8194189331925024, 0.1502680067141652, 0.16622889839667554`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 292}], {
             RGBColor[
             0.8205053754928366, 0.15861887831658708`, 0.16726927677043682`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 303}], {
             RGBColor[
             0.857724462248068, 0.3888260026114282, 0.20072238804006853`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 333}], {
             RGBColor[
             0.8876476995379257, 0.5657281038549604, 0.5656841246616948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 337}], {
             RGBColor[
             0.8892490440589328, 0.5669223839767665, 0.5629734660851704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 345}], {
             RGBColor[
             0.824801297962475, 0.5160822589510907, 0.5758521781137924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 353}], {
             RGBColor[
             0.9073893332491589, 0.5772003661732394, 0.33799440934929903`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 385}], {
             RGBColor[
             0.907968224972722, 0.5784385570350095, 0.40100320095353803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 391}], {
             RGBColor[
             0.8208765397934485, 0.16147180977632267`, 0.16762470412387276`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 400}], {
             RGBColor[
             0.8218170423470171, 0.16870092453389818`, 0.1685253304313158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 58}], {
             RGBColor[
             0.21989646734481127`, 0.3484555077936574, 0.9358341505563915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 74}], {
             RGBColor[
             0.24756162893783695`, 0.3775333467004828, 0.9374096405821755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 107}], {
             RGBColor[
             0.23483527017028652`, 0.36415713673803723`, 0.9366848932773241]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 116}], {
             RGBColor[
             0.24330530459768918`, 0.3730596799524376, 0.9371672492076716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 118}], {
             RGBColor[
             0.30201839786374246`, 0.43026808739011524`, 0.9406757417053806]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 124}], {
             RGBColor[
             0.23660403432322674`, 0.366016220008902, 0.9367856217791819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 141}], {
             RGBColor[
             0.3011781143378584, 0.42954027603387246`, 0.9406221995821449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 150}], {
             RGBColor[
             0.24249803494618108`, 0.37221118836485045`, 0.9371212763952667]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 152}], {
             RGBColor[
             0.2237166408577273, 0.3524707523687224, 0.9360517037865118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 156}], {
             RGBColor[
             0.22423055163894667`, 0.35301090518360945`, 0.9360809702452394]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 157}], {
             RGBColor[
             0.2467253832848012, 0.3766543994981055, 0.9373620176293496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 179}], {
             RGBColor[
             0.23670129905445042`, 0.3661184514083582, 0.9367911608617348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 206}], {
             RGBColor[
             0.33773890435239673`, 0.4612073947457289, 0.942951820792434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 209}], {
             RGBColor[
             0.25581747523043485`, 0.38621076460489123`, 0.9378797988151089]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 245}], {
             RGBColor[
             0.22074175679161856`, 0.34934396059669826`, 0.9358822885398935]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 286}], {
             RGBColor[
             0.2839164063725824, 0.41458905219301934`, 0.9395222988145264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 386}], {
             RGBColor[
             0.2942581498186507, 0.4235465505748645, 0.9401812655620653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 43}], {
             RGBColor[
             0.18881744465394812`, 0.3157894844217095, 0.9340642461914408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 159}], {
             RGBColor[
             0.1825395439463383, 0.30919101273611693`, 0.9337067290334642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 250}], {
             RGBColor[
             0.1883288985198916, 0.31527599145920215`, 0.9340364242118455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 265}], {
             RGBColor[
             0.19096709589184307`, 0.31804890416849774`, 0.9341866656493147]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 321}], {
             RGBColor[
             0.18374554341254123`, 0.3104585946398788, 0.9337754089189481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 375}], {
             RGBColor[
             0.19286667153168213`, 0.3200454786060204, 0.9342948436718334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 381}], {
             RGBColor[
             0.18614322275265005`, 0.3129787076479837, 0.9339119532103186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 73}], {
             RGBColor[
             0.19430576499947028`, 0.3215580570844616, 0.9343767979158759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 154}], {
             RGBColor[
             0.18823624142486384`, 0.31517860297752887`, 0.9340311475273575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 207}], {
             RGBColor[
             0.19080850531779897`, 0.3178822154199542, 0.9341776341507367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 231}], {
             RGBColor[
             0.19065322565130216`, 0.31771900664516656`, 0.9341687912034454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 280}], {
             RGBColor[
             0.19951437129521365`, 0.3270326325460011, 0.9346734203389759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 291}], {
             RGBColor[
             0.19278015708719454`, 0.31995454643953136`, 0.9342899168022064]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 372}], {
             RGBColor[
             0.18502327958345532`, 0.31180157636866185`, 0.9338481741036404]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 387}], {
             RGBColor[
             0.1878209095169145, 0.3147420628087102, 0.9340074949896282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 392}], {
             RGBColor[
             0.19658094676972326`, 0.3239494173798535, 0.934506366151862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 61}], {
             RGBColor[
             0.23146005042347673`, 0.36060956678284806`, 0.9364926795059334]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 70}], {
             RGBColor[
             0.22130912604082534`, 0.3499403016509027, 0.9359145993792883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 90}], {
             RGBColor[
             0.2306114538784999, 0.35971763800994894`, 0.9364443531880831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 95}], {
             RGBColor[
             0.2464425329575721, 0.37635710587044113`, 0.9373459097216534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 148}], {
             RGBColor[
             0.2511034439451054, 0.38125601883716365`, 0.9376113417071936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 228}], {
             RGBColor[
             0.23483092925025606`, 0.364152574155855, 0.9366846460683501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 276}], {
             RGBColor[
             0.31234957064668134`, 0.4391299345139409, 0.941337201922877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 282}], {
             RGBColor[
             0.28033871258182136`, 0.4114037381706667, 0.9392974983530744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 301}], {
             RGBColor[
             0.2477609938146631, 0.37774289182649035`, 0.9374209941169768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 305}], {
             RGBColor[
             0.2718566625317226, 0.40306896740175535`, 0.9387932068040659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 361}], {
             RGBColor[
             0.32761397052464425`, 0.4523511904771868, 0.9423098359853219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 382}], {
             RGBColor[
             0.2838749254794549, 0.4144666280473688, 0.9395228227119613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 76}], {
             RGBColor[
             0.28363325287465024`, 0.4154469105311262, 0.9394638662021915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 78}], {
             RGBColor[
             0.25239861099731176`, 0.3826173215273665, 0.9376850995547887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 80}], {
             RGBColor[
             0.24371904320437376`, 0.3734945454606058, 0.9371908110092508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 96}], {
             RGBColor[
             0.24798039051581972`, 0.3779734916699602, 0.9374334884345392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 104}], {
             RGBColor[
             0.2541903466574486, 0.3845005493087726, 0.9377871362499982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 117}], {
             RGBColor[
             0.4214315538332871, 0.5343304799664346, 0.9489462154343377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 145}], {
             RGBColor[
             0.2671022972631469, 0.3980718280603137, 0.9385224527354736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 182}], {
             RGBColor[
             0.26307956528763465`, 0.3938436816981118, 0.9382933641005669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 187}], {
             RGBColor[
             0.2503393326402117, 0.3804528894082654, 0.9375678266987812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 208}], {
             RGBColor[
             0.289374752338518, 0.42148159049974276`, 0.9397908361028714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 269}], {
             RGBColor[
             0.3188674209826161, 0.4483513791388215, 0.9416215783296149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 323}], {
             RGBColor[
             0.35247668459828785`, 0.4774620340320098, 0.9437631308877006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 365}], {
             RGBColor[
             0.29517424252624735`, 0.4275772223959621, 0.9401211084894857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 377}], {
             RGBColor[
             0.2695128080367538, 0.400605427718585, 0.9386597277579993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 388}], {
             RGBColor[
             0.27755649571754953`, 0.4090598534703564, 0.9391178038718512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 395}], {
             RGBColor[
             0.3615061899414258, 0.48528293772410147`, 0.9443384829836874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 44}], {
             RGBColor[
             0.24351959225973108`, 0.37328490987186613`, 0.9371794525730147]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 66}], {
             RGBColor[
             0.22742648369193186`, 0.3563700324050926, 0.9362629738476992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 81}], {
             RGBColor[
             0.2439408678768847, 0.37372769725591143`, 0.9372034435961902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 119}], {
             RGBColor[
             0.249257790450226, 0.37931611999285497`, 0.9375062344710599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 128}], {
             RGBColor[
             0.281313846761083, 0.4130090676469258, 0.9393317794552777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 130}], {
             RGBColor[
             0.23719458554175432`, 0.36663692678268434`, 0.9368192527974348]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 135}], {
             RGBColor[
             0.2970405045044002, 0.42707857493039736`, 0.9403174695829958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 146}], {
             RGBColor[
             0.2289275307271461, 0.3579477280109817, 0.9363484562557545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 151}], {
             RGBColor[
             0.23316903340538708`, 0.36240581625261525`, 0.9365900035585395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 213}], {
             RGBColor[
             0.2920695594579869, 0.42277299217815684`, 0.9400007253602725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 224}], {
             RGBColor[
             0.37823665311305865`, 0.49620023139778335`, 0.9458245390097163]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 227}], {
             RGBColor[
             0.2663587998591236, 0.39729036514822713`, 0.9384801116582203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 243}], {
             RGBColor[
             0.24505985490147014`, 0.37490382356662577`, 0.9372671682518474]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 267}], {
             RGBColor[
             0.22814489442186137`, 0.3571251276321197, 0.9363038862759752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 306}], {
             RGBColor[
             0.24051285588611682`, 0.3701246393051007, 0.9370082233846052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 311}], {
             RGBColor[
             0.23066096804752526`, 0.35976968054097413`, 0.9364471729467594]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 346}], {
             RGBColor[
             0.23107597310122763`, 0.36020587716525554`, 0.9364708068706228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 350}], {
             RGBColor[
             0.3036355127427933, 0.43279083959174136`, 0.9407376976762094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 363}], {
             RGBColor[
             0.3166257823122153, 0.444042358182842, 0.9415654261663287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 383}], {
             RGBColor[
             0.3085216567311646, 0.43702297192973105`, 0.9410490384505009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 47}], {
             RGBColor[
             0.18958921033534365`, 0.3166006590856267, 0.9341081971052712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 50}], {
             RGBColor[
             0.21465093660737516`, 0.342942122402754, 0.9355354253409618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 136}], {
             RGBColor[
             0.19040517985093924`, 0.31745829478197307`, 0.9341546653620656]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 149}], {
             RGBColor[
             0.2042501787734501, 0.33201026647316434`, 0.9349431175688622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 164}], {
             RGBColor[
             0.20658345954088297`, 0.3344626924982814, 0.9350759944567879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 197}], {
             RGBColor[
             0.19474286460527196`, 0.3220174764838748, 0.9344016900917953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 210}], {
             RGBColor[
             0.22192743235245416`, 0.35059018078730897`, 0.9359498110090333]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 217}], {
             RGBColor[
             0.2032105562120073, 0.33091755724521044`, 0.9348839126019717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 230}], {
             RGBColor[
             0.20964976351428055`, 0.33768557238922303`, 0.9352506159318827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 254}], {
             RGBColor[
             0.19262591917799537`, 0.31979243261771473`, 0.934281133181452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 258}], {
             RGBColor[
             0.21791338707223826`, 0.34637116469263174`, 0.9357212170685729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 314}], {
             RGBColor[
             0.19046396107769498`, 0.3175200775782383, 0.9341580128659703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 328}], {
             RGBColor[
             0.21476290196670605`, 0.3430598050944246, 0.9355418016025379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 41}], {
             RGBColor[
             0.19412189539412833`, 0.3213647984712409, 0.9343663268138622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 48}], {
             RGBColor[
             0.20069384731952558`, 0.3282723366306521, 0.934740589753682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 63}], {
             RGBColor[
             0.19138658757193353`, 0.3184898165215815, 0.9342105550799136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 103}], {
             RGBColor[
             0.19411926264855695`, 0.32136203128871965`, 0.9343661768828968]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 265}], {
             RGBColor[
             0.1962226401289317, 0.32357281438242835`, 0.9344859611187359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 295}], {
             RGBColor[
             0.1896748892459051, 0.31669071305298346`, 0.934113076392477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 48}], {
             RGBColor[
             0.2013669879321785, 0.3289798500941302, 0.9347789241157504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 63}], {
             RGBColor[
             0.19205972818458644`, 0.31919732998505956`, 0.9342488894419819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.1942575833696331, 0.32150741513661096`, 0.934374054043335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 265}], {
             RGBColor[
             0.19689578074158462`, 0.3242803278459065, 0.9345242954808043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 295}], {
             RGBColor[
             0.19034802985855803`, 0.31739822651646155`, 0.9341514107545453]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 325}], {
             RGBColor[
             0.2165335134226994, 0.3449208299979239, 0.9356426353055718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 381}], {
             RGBColor[
             0.19207190760239157`, 0.31921013132539244`, 0.934249583041808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 67}], {
             RGBColor[
             0.18164605198289263`, 0.3082518960318731, 0.9336558459879488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 75}], {
             RGBColor[
             0.18289766237674282`, 0.30956741791249204`, 0.9337271233482869]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 133}], {
             RGBColor[
             0.1836453052262827, 0.310353237950653, 0.9337697005025297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 178}], {
             RGBColor[
             0.18344665505298052`, 0.31014444402336394`, 0.9337583876690367]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 200}], {
             RGBColor[
             0.18896638878164698`, 0.3159460341435242, 0.9340727283391701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 278}], {
             RGBColor[
             0.18598976689484537`, 0.3128174158117676, 0.9339032141262342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 296}], {
             RGBColor[
             0.18148102360409654`, 0.30807844074235485`, 0.933646447865914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 320}], {
             RGBColor[
             0.18379681968568948`, 0.3105124892540611, 0.9337783290268474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 330}], {
             RGBColor[
             0.18629301045548374`, 0.31313614402075074`, 0.9339204833984038]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 347}], {
             RGBColor[
             0.18410501336322643`, 0.3108364203497602, 0.9337958802008515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 367}], {
             RGBColor[
             0.1849893429390042, 0.3117659068036362, 0.9338462414619436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 398}], {
             RGBColor[
             0.18234639975021955`, 0.30898800593994685`, 0.9336957297572264]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 159}], {
             RGBColor[
             0.1884193222929882, 0.31537103257792504`, 0.9340415737119533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 250}], {
             RGBColor[
             0.19420867686654147`, 0.32145601130101026`, 0.9343712688903346]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 265}], {
             RGBColor[
             0.19684687423849298`, 0.3242289240103058, 0.934521510327804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 321}], {
             RGBColor[
             0.1896253217591911, 0.31663861448168684`, 0.9341102535974373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 325}], {
             RGBColor[
             0.21648460691960775`, 0.3448694261623232, 0.9356398501525713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 375}], {
             RGBColor[
             0.19874644987833204`, 0.3262254984478285, 0.9346296883503225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 381}], {
             RGBColor[
             0.19202300109929993`, 0.3191587274897918, 0.9342467978888077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 66}], {
             RGBColor[
             0.21222031867993352`, 0.3403873888509353, 0.9353970052457711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 81}], {
             RGBColor[
             0.22873470286488637`, 0.35774505370175413`, 0.9363374749942621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 119}], {
             RGBColor[
             0.23405162543822766`, 0.3633334764386976, 0.9366402658691317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[
             0.26610768174908467`, 0.39702642409276845`, 0.9384658108533496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 130}], {
             RGBColor[
             0.22198842052975598`, 0.350654283228527, 0.9359532841955067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 135}], {
             RGBColor[
             0.2818343394924019, 0.41109593137624006`, 0.9394515009810677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 146}], {
             RGBColor[
             0.21372136571514777`, 0.3419650844568244, 0.9354824876538264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 151}], {
             RGBColor[
             0.21796286839338874`, 0.3464231726984579, 0.9357240349566114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 227}], {
             RGBColor[
             0.25115263484712524`, 0.3813077215940698, 0.9376141430562922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 243}], {
             RGBColor[
             0.2298536898894718, 0.3589211800124685, 0.9364011996499193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 267}], {
             RGBColor[
             0.21293872940986303`, 0.3411424840779623, 0.935437917674047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 275}], {
             RGBColor[
             0.21122882729611786`, 0.33934526854236047`, 0.9353405412782427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 311}], {
             RGBColor[
             0.21545480303552692`, 0.34378703698681684`, 0.9355812043448313]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 317}], {
             RGBColor[
             0.2084087804726259, 0.3363812205295747, 0.9351799437835304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 326}], {
             RGBColor[
             0.2349425006851034, 0.3642698428079171, 0.9366909998965096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 344}], {
             RGBColor[
             0.20993796520971017`, 0.3379884906441625, 0.9352670285920812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 346}], {
             RGBColor[
             0.2158698080892293, 0.3442232336110982, 0.9356048382686947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 383}], {
             RGBColor[
             0.29331549171916627`, 0.4210403283755737, 0.9401830698485728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 48}], {
             RGBColor[
             0.2238300988639671, 0.3525900039269335, 0.9360581650521211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 74}], {
             RGBColor[
             0.2441275547351621, 0.3739239169805914, 0.9372140751365906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 103}], {
             RGBColor[
             0.21725551419299843`, 0.345679698585001, 0.9356837521813359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 116}], {
             RGBColor[
             0.23987123039501432`, 0.3694502502325462, 0.9369716837620867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 262}], {
             RGBColor[
             0.30202723660803465`, 0.4296407358190505, 0.9406995556283282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 290}], {
             RGBColor[
             0.24862549482263574`, 0.3786515371983993, 0.9374702261704662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 304}], {
             RGBColor[
             0.2609958832174149, 0.3916535997292371, 0.9381747014891992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 338}], {
             RGBColor[
             0.2249286875668965, 0.3537446903082591, 0.9361207280535366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 52}], {
             RGBColor[
             0.89726556755869, 0.9188637535063902, 0.9066512485949225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 60}], {
             RGBColor[
             0.7562801355297237, 0.809531056908518, 0.9763425941360632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 102}], {
             RGBColor[
             0.5772856165740025, 0.6623742905041798, 0.9623565848838942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 105}], {
             RGBColor[
             0.8954193827902208, 0.9181003086598438, 0.937247307981482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 128}], {
             RGBColor[
             0.5547192055800235, 0.6423805327309791, 0.9609350717272003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 139}], {
             RGBColor[
             0.5562400144756487, 0.6439789993051345, 0.961021679543971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 199}], {
             RGBColor[
             0.8971361136435547, 0.9188102209856679, 0.9087966349847089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 213}], {
             RGBColor[
             0.5654749182769274, 0.6521444572622102, 0.9616040176321952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 215}], {
             RGBColor[
             0.7558037231431869, 0.8091588799312872, 0.9762951098017001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 259}], {
             RGBColor[
             0.850480547970673, 0.8837308935118651, 0.9855697997497163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 271}], {
             RGBColor[
             0.8127696138510401, 0.5013829917925117, 0.574019985211861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 287}], {
             RGBColor[
             0.8114277374548052, 0.49106874179706506`, 0.572735002859394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 333}], {
             RGBColor[
             0.8796565038002286, 0.9065288389378603, 0.9721902291244133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 337}], {
             RGBColor[
             0.8812578483212357, 0.9077231190596664, 0.969479570547889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 345}], {
             RGBColor[
             0.8168101022247779, 0.8568829940339906, 0.982358282576511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 350}], {
             RGBColor[
             0.5770408715617338, 0.6621623046757947, 0.9623409899481321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 353}], {
             RGBColor[
             0.8993981375114619, 0.9180011012561393, 0.7445005138120175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 400}], {
             RGBColor[
             0.81382584660932, 0.509501659616798, 0.5750314348940344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 136}], {
             RGBColor[
             0.18182023692588944`, 0.308434975450926, 0.9336657655627689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 149}], {
             RGBColor[
             0.1956652358484003, 0.3229869471421173, 0.9344542177695655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 155}], {
             RGBColor[
             0.18345196765990118`, 0.3101500279100763, 0.9337586902141416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 268}], {
             RGBColor[
             0.18433220446865944`, 0.3110752126063183, 0.9338088183982067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 279}], {
             RGBColor[
             0.19002059109890063`, 0.3170540676192452, 0.934132763601585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 299}], {
             RGBColor[
             0.184696983160691, 0.3114586181399484, 0.9338295920050762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 300}], {
             RGBColor[
             0.18858263454534693`, 0.31554268410974895`, 0.9340508741031263]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 371}], {
             RGBColor[
             0.18051873474236652`, 0.3070670141360388, 0.9335916469388172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.1986316801099837, 0.3261048681444708, 0.9346231523818017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 86}], {
             RGBColor[
             0.23801910122574216`, 0.3675035450438693, 0.9368662077458763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 103}], {
             RGBColor[
             0.2013643551866071, 0.328977082911609, 0.9347787741847848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 295}], {
             RGBColor[
             0.19691998178395526`, 0.3243057646758728, 0.9345256736943651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 191}], {
             RGBColor[
             0.18385357890938503`, 0.3105721467969078, 0.933781561380669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 225}], {
             RGBColor[
             0.19609003670444464`, 0.3234334397757498, 0.9344784095498806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 235}], {
             RGBColor[
             0.1884735679979762, 0.31542804825324383`, 0.9340446629246031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 261}], {
             RGBColor[
             0.1864507904031121, 0.31330198074953464`, 0.9339294687330069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 327}], {
             RGBColor[
             0.18473066760764006`, 0.3114940226294092, 0.9338315102844983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 335}], {
             RGBColor[
             0.1909811618412971, 0.3180636883732066, 0.9341874666843275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 349}], {
             RGBColor[
             0.19105637302960854`, 0.3181427401007867, 0.9341917498502368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 355}], {
             RGBColor[
             0.19591924831876065`, 0.3232539303537868, 0.9344686834039748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 127}], {
             RGBColor[
             0.28524823564473223`, 0.4143130772255349, 0.9396595042068966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 137}], {
             RGBColor[
             0.2618861891426283, 0.3925893677052923, 0.9382254030945505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 138}], {
             RGBColor[
             0.26001645706684573`, 0.3906241607457843, 0.9381189246188555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 147}], {
             RGBColor[
             0.23917140342485926`, 0.3687146877153205, 0.9369318296514377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 164}], {
             RGBColor[
             0.22306024288786463`, 0.3517808364843617, 0.9360143228931819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 197}], {
             RGBColor[
             0.21121964795225362`, 0.33933562046995513`, 0.9353400185281894]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 210}], {
             RGBColor[
             0.23840421569943582`, 0.3679083247733892, 0.9368881394454274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 217}], {
             RGBColor[
             0.21968733955898895`, 0.34823570123129066`, 0.9358222410383658]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 230}], {
             RGBColor[
             0.2261265468612622, 0.35500371637530337`, 0.9361889443682767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 242}], {
             RGBColor[
             0.2857631387189643, 0.41475906038865373`, 0.9396923133754758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 254}], {
             RGBColor[
             0.20910270252497706`, 0.33711057660379506`, 0.9352194616178461]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 258}], {
             RGBColor[
             0.23439017041921995`, 0.3636893086787121, 0.9366595455049669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 328}], {
             RGBColor[
             0.23123968531368772`, 0.36037794908050486`, 0.9364801300389318]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 331}], {
             RGBColor[
             0.2360482874744978, 0.36543209483450245`, 0.9367539728183005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 79}], {
             RGBColor[
             0.20012999875823717`, 0.3276796960426744, 0.934708479412256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 87}], {
             RGBColor[
             0.1940286984190197, 0.3212668425413722, 0.9343610193840024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 126}], {
             RGBColor[
             0.1918840790772874, 0.31901271163649164`, 0.9342388864851707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 176}], {
             RGBColor[
             0.19370665948804128`, 0.32092835920646634`, 0.9343426797432972]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 205}], {
             RGBColor[
             0.19318129293550862`, 0.32037616564959115`, 0.9343127608953405]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 232}], {
             RGBColor[
             0.19578437289714112`, 0.32311216773406903`, 0.9344610024482438]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 277}], {
             RGBColor[
             0.19316166908716753`, 0.3203555397407608, 0.9343116433462084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 298}], {
             RGBColor[
             0.20333725610200998`, 0.3310507268628402, 0.9348911279732717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 373}], {
             RGBColor[
             0.1995969758310581, 0.32711945515060364`, 0.9346781245450898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 390}], {
             RGBColor[
             0.2070958500160861, 0.33500124737515247`, 0.935105174336337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 60}], {
             RGBColor[
             0.8480092281788032, 0.880384326820778, 0.9017418370121976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 68}], {
             RGBColor[
             0.9052995090875355, 0.9251530264391655, 0.9074485213302443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 105}], {
             RGBColor[
             0.9871484754393005, 0.988953578572104, 0.8626465508576164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 129}], {
             RGBColor[
             0.904165411034544, 0.5696744067053534, 0.4991000639737569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 199}], {
             RGBColor[
             0.9888652062926342, 0.9896634908979279, 0.8341958778608433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 271}], {
             RGBColor[
             0.9044987065001195, 0.5722362617047718, 0.4994192280879955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 287}], {
             RGBColor[
             0.9031568301038848, 0.5619220117093251, 0.49813424573552845`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 303}], {
             RGBColor[
             0.9414623591594504, 0.8004800076065881, 0.5326277353789215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 333}], {
             RGBColor[
             0.9713855964493081, 0.9773821088501203, 0.8975894720005477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 337}], {
             RGBColor[
             0.9729869409703154, 0.9785763889719264, 0.8948788134240234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 345}], {
             RGBColor[
             0.9085391948738575, 0.9277362639462506, 0.9077575254526454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 353}], {
             RGBColor[
             0.9911272301605415, 0.9888543711683995, 0.6698997566881519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 391}], {
             RGBColor[
             0.904614436704831, 0.5731258147714826, 0.49953005146272567`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 69}], {
             RGBColor[
             0.4877113731208531, 0.5936081076641104, 0.9531940365593021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 93}], {
             RGBColor[
             0.37256678589576175`, 0.4971203570169409, 0.9449606040427729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 131}], {
             RGBColor[
             0.6083578580504109, 0.6889233390243821, 0.9644906126536026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 142}], {
             RGBColor[
             0.43838221439814257`, 0.5535604743597381, 0.949310664485988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 188}], {
             RGBColor[
             0.33920701496392514`, 0.465180569896386, 0.9429464497347737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 201}], {
             RGBColor[
             0.5341594365329997, 0.6309589682060907, 0.9570952074204189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 264}], {
             RGBColor[
             0.3312918681319017, 0.4568612487266348, 0.9424956938321003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 273}], {
             RGBColor[
             0.4633253395942303, 0.573810427068907, 0.9512742786711021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 281}], {
             RGBColor[
             0.40067800773256046`, 0.5214688844608842, 0.9467518262404362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[
             0.35836727987096656`, 0.4848214585861875, 0.944055824075003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 394}], {
             RGBColor[
             0.38011496144870427`, 0.5036582072985654, 0.9454415671144167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 64}], {
             RGBColor[
             0.970419525130984, 0.9095497585157698, 0.3557751825465969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 83}], {
             RGBColor[
             0.9496193654049732, 0.8977579075232218, 0.6225379522867944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 123}], {
             RGBColor[
             0.8957058066069172, 0.5826430148496441, 0.23309163667201951`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 161}], {
             RGBColor[
             0.9139000708098552, 0.6892402426005217, 0.2492124251865322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 196}], {
             RGBColor[
             0.8961892019683437, 0.8555483275728113, 0.6311082747514651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 198}], {
             RGBColor[
             0.8885256847199983, 0.8494376469396148, 0.6303773216350153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 206}], {
             RGBColor[
             0.6885711015156095, 0.68922695188861, 0.6128856824256679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 214}], {
             RGBColor[
             0.913587591361185, 0.6878213464055395, 0.24895168467498954`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 310}], {
             RGBColor[
             0.8873852444618682, 0.5186875281092153, 0.22512385696518958`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 332}], {
             RGBColor[
             0.8830293594773344, 0.4852062873571179, 0.22095265658473165`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 389}], {
             RGBColor[
             0.9706885388162402, 0.9101251515870772, 0.3850556620267193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 57}], {
             RGBColor[
             0.5760181454967422, 0.6613528823456771, 0.9622434817439033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 68}], {
             RGBColor[
             0.8126708442680417, 0.8535970039103761, 0.981959617507143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 72}], {
             RGBColor[
             0.6346370252408752, 0.7117938428167392, 0.9660702931075245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 83}], {
             RGBColor[
             0.8773611303882973, 0.9047851000408222, 0.9744632955960668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 123}], {
             RGBColor[
             0.8234475715902414, 0.5896702073672445, 0.5850169799812919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 161}], {
             RGBColor[
             0.8416418357931794, 0.6962674351181222, 0.6011377684958046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 196}], {
             RGBColor[
             0.8239309669516679, 0.8625755200904117, 0.9830336180607375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 236}], {
             RGBColor[
             0.6566866391587384, 0.7296947127190476, 0.9678061194855357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 262}], {
             RGBColor[
             0.5840352729572464, 0.6682969151994234, 0.9627543260164191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 284}], {
             RGBColor[
             0.7718010949853338, 0.8216561483989014, 0.9778895783229857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 334}], {
             RGBColor[
             0.8819744590496598, 0.862025730858683, 0.6405013220512796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 366}], {
             RGBColor[
             0.8985186945130963, 0.9173414029032505, 0.7466017890196988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 397}], {
             RGBColor[
             0.5839584526615165, 0.6682303773203624, 0.9627494310951048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 65}], {
             RGBColor[
             0.4474461015886463, 0.5602099797974611, 0.9502200964459863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 100}], {
             RGBColor[
             0.4530551393941151, 0.565068246426121, 0.9505774993750733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 174}], {
             RGBColor[
             0.4681168777823908, 0.5781139671930625, 0.9515372200266019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 198}], {
             RGBColor[
             0.6735978276393025, 0.7431113232752183, 0.969380994432274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 203}], {
             RGBColor[
             0.4142038212467356, 0.5314171873708888, 0.948101927737594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 206}], {
             RGBColor[
             0.4736432444349138, 0.5829006282242136, 0.9518893552229266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 266}], {
             RGBColor[
             0.5883098999275997, 0.6764125091387695, 0.9608991949142476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 341}], {
             RGBColor[
             0.38387079611477953`, 0.499652079122729, 0.9463702293168075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 358}], {
             RGBColor[
             0.3979975915234898, 0.5145002367878451, 0.9471747294166126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 68}], {
             RGBColor[
             0.584951659196002, 0.6683449078949819, 0.9631304154261922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 72}], {
             RGBColor[
             0.4069178401688355, 0.5265417468013449, 0.9472410910265736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 86}], {
             RGBColor[
             0.30819911150930557`, 0.43761024408224003`, 0.9409967540495674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 108}], {
             RGBColor[
             0.32733127751038416`, 0.4577193635987606, 0.9420863025998256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 236}], {
             RGBColor[
             0.4289674540866987, 0.5444426167036535, 0.9489769174045849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 262}], {
             RGBColor[
             0.35631608788520674`, 0.4830448191840292, 0.9439251239354682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 284}], {
             RGBColor[
             0.544081909913294, 0.6364040523835073, 0.9590603762420349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 297}], {
             RGBColor[
             0.3224295006293375, 0.45256728530617585`, 0.9418071536579791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 325}], {
             RGBColor[
             0.29328547563165996`, 0.42193506719570584`, 0.9401474445490827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 376}], {
             RGBColor[
             0.31723897478085683`, 0.4471117135410761, 0.941511560889603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 397}], {
             RGBColor[
             0.3562392675894767, 0.4829782813049682, 0.943920229014154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 124}], {
             RGBColor[
             0.20991109539232988`, 0.337960248762451, 0.9352654983957317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 152}], {
             RGBColor[
             0.19702370192683044`, 0.32441478112227146`, 0.9345315804030616]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 156}], {
             RGBColor[
             0.19753761270804981`, 0.3249549339371585, 0.9345608468617892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 160}], {
             RGBColor[
             0.1942495004305084, 0.32149891945510295`, 0.9343735937319094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 179}], {
             RGBColor[
             0.21000836012355356`, 0.3380624801619072, 0.9352710374782847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 181}], {
             RGBColor[
             0.19266290312611054`, 0.31983130509210156`, 0.9342832393625844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 220}], {
             RGBColor[
             0.186453938859043, 0.31330528997634166`, 0.9339296480329143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[
             0.1940488178607217, 0.32128798935024727`, 0.9343621651564433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 352}], {
             RGBColor[
             0.18979453396815193`, 0.3168164672419784, 0.9341198899824106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 396}], {
             RGBColor[
             0.18880077082680655`, 0.315771959172202, 0.9340632966416518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 132}], {
             RGBColor[
             0.20457320024571096`, 0.33234978252125474`, 0.93496151316384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 149}], {
             RGBColor[
             0.21329928840113216`, 0.34152145443854653`, 0.9354584509752006]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 155}], {
             RGBColor[
             0.20108602021263303`, 0.3286845352065056, 0.9347629234197767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 164}], {
             RGBColor[
             0.215632569168565, 0.3439738804636637, 0.9355913278631264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 210}], {
             RGBColor[
             0.23097654198013617`, 0.36010136875269116`, 0.9364651444153718]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 230}], {
             RGBColor[
             0.21869887314196257`, 0.34719676035460534`, 0.9357659493382211]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 258}], {
             RGBColor[
             0.2269624966999203, 0.35588235265801405`, 0.9362365504749113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 264}], {
             RGBColor[
             0.2381256499847355, 0.3676155345451527, 0.9368722755400762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 268}], {
             RGBColor[
             0.2019662570213913, 0.3296097199027477, 0.9348130516038419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 279}], {
             RGBColor[
             0.2076546436516325, 0.3355885749156745, 0.9351369968072203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 299}], {
             RGBColor[
             0.20233103571342284`, 0.3299931254363777, 0.9348338252107113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 300}], {
             RGBColor[
             0.20621668709807878`, 0.3340771914061782, 0.9350551073087614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 328}], {
             RGBColor[
             0.22381201159438807`, 0.3525709930598068, 0.9360571350088763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 394}], {
             RGBColor[
             0.286948743301538, 0.41441249311708334`, 0.9398181488223927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 68}], {
             RGBColor[
             0.7643140770585692, 0.8158203298412934, 0.9771398668713851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 72}], {
             RGBColor[
             0.5862802580314027, 0.6740171687476564, 0.9612505424717664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 102}], {
             RGBColor[
             0.5280292771941157, 0.6238948638185677, 0.9574471733011694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 105}], {
             RGBColor[
             0.8461630434103341, 0.8796208819742317, 0.932337896398757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 108}], {
             RGBColor[
             0.5066936953729514, 0.6051947855450721, 0.9560957540450186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 139}], {
             RGBColor[
             0.506983675095762, 0.6054995726195224, 0.9561122679612462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 297}], {
             RGBColor[
             0.5017919184919047, 0.6000427072524873, 0.955816605103172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 333}], {
             RGBColor[
             0.8304001644203418, 0.8680494122522482, 0.9672808175416883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 337}], {
             RGBColor[
             0.8320015089413489, 0.8692436923740543, 0.9645701589651641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 345}], {
             RGBColor[
             0.7675537628448912, 0.8184035673483785, 0.9774488709937861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 353}], {
             RGBColor[
             0.8501417981315751, 0.8795216745705272, 0.7395911022292926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 70}], {
             RGBColor[
             0.20711529305388426`, 0.33502168324063814`, 0.9351062815885762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 90}], {
             RGBColor[
             0.21641762089155886`, 0.3447990195996844, 0.935636035397371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 95}], {
             RGBColor[
             0.23224869997063102`, 0.3614384874601766, 0.9365375919309413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 148}], {
             RGBColor[
             0.23690961095816437`, 0.3663374004268991, 0.9368030239164815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 228}], {
             RGBColor[
             0.220637096263315, 0.34923395574559046`, 0.935876328277638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 282}], {
             RGBColor[
             0.2661448795948803, 0.3964851197604022, 0.9384891805623623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 285}], {
             RGBColor[
             0.2007711589524707, 0.32835359605871806`, 0.934744992536806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 301}], {
             RGBColor[
             0.23356716082772205`, 0.3628242734162258, 0.9366126763262647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 382}], {
             RGBColor[
             0.2696810924925139, 0.39954800963710424`, 0.9387145049212492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 91}], {
             RGBColor[
             0.7921898842803778, 0.8354987729647263, 0.873281889830355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 111}], {
             RGBColor[
             0.9092079691258396, 0.5982182088690406, 0.47930597740308856`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 117}], {
             RGBColor[
             0.7751677288121797, 0.821679420316278, 0.8719418433976884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 223}], {
             RGBColor[
             0.9255100897331807, 0.7222473691090705, 0.4948669383214451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 247}], {
             RGBColor[
             0.9045712992599508, 0.5625787324781286, 0.4748658971031438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 256}], {
             RGBColor[
             0.992053902372576, 0.9909820986727351, 0.781350931735281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 319}], {
             RGBColor[
             0.9121241184522142, 0.6206330104563391, 0.4820984852913445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 323}], {
             RGBColor[
             0.7062128595771804, 0.7648109743818534, 0.8667587588510515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 362}], {
             RGBColor[
             0.8915373797700097, 0.913872404880224, 0.882662516799504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 395}], {
             RGBColor[
             0.7152423649203183, 0.772631878073945, 0.8673341109470382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 103}], {
             RGBColor[
             0.19205709543901506`, 0.31919456280253833`, 0.9342487395110164]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 295}], {
             RGBColor[
             0.1876127220363632, 0.31452324456680214`, 0.9339956390205967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 88}], {
             RGBColor[
             0.7114905669436782, 0.7668789695612932, 0.6914868954695467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 101}], {
             RGBColor[
             0.9232794978996539, 0.7012101823729198, 0.31682349709282953`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 115}], {
             RGBColor[
             0.973846560757742, 0.9231368127839409, 0.35853265585475147`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 120}], {
             RGBColor[
             0.7025664799902631, 0.759149373979897, 0.6909182605401354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 123}], {
             RGBColor[
             0.9178715311357676, 0.6596421800395433, 0.31164482201230714`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 140}], {
             RGBColor[
             0.6994659535308891, 0.7564638537977784, 0.690720697735832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 161}], {
             RGBColor[
             0.9360657953387055, 0.766239407790421, 0.32776561052681985`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 193}], {
             RGBColor[
             0.9152566921622731, 0.9300770448033753, 0.7093659477350615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 195}], {
             RGBColor[
             0.7086017617355334, 0.7643768316855696, 0.6913028233561538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 214}], {
             RGBColor[
             0.9357533158900353, 0.7648205115954387, 0.32750487001527717`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 233}], {
             RGBColor[
             0.9814581324353071, 0.9819712119725741, 0.6847171998056071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 257}], {
             RGBColor[
             0.9810027572631417, 0.9816315939147817, 0.6854880311912166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 283}], {
             RGBColor[
             0.9622538962308652, 0.8771757609613251, 0.3492049258616166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 312}], {
             RGBColor[
             0.7702008939642393, 0.8151650470913949, 0.695936819489472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 332}], {
             RGBColor[
             0.9051950840061846, 0.5622054525470171, 0.2995058419250193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 356}], {
             RGBColor[
             0.9689844051155808, 0.9726683265613763, 0.7058319664887789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 360}], {
             RGBColor[
             0.8276703795499445, 0.8615089159497265, 0.7006746506658257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 380}], {
             RGBColor[
             0.8564837144111264, 0.8840181121327374, 0.7035464946088651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 389}], {
             RGBColor[
             0.9928542633450905, 0.9871243167769764, 0.4636088473670069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 100}], {
             RGBColor[
             0.38210315454201915`, 0.5053802802265043, 0.9455682530202327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 167}], {
             RGBColor[
             0.30615029923372655`, 0.43284997763222943`, 0.940975526215034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 174}], {
             RGBColor[
             0.39716489293029483`, 0.5184260009934458, 0.9465279736717613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 198}], {
             RGBColor[
             0.6026458427872066, 0.6834233570756016, 0.9643717480774334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 203}], {
             RGBColor[
             0.34325183639463963`, 0.4717292211712722, 0.9430926813827534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 206}], {
             RGBColor[
             0.4026912595828178, 0.5232126620245969, 0.9468801088680859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 211}], {
             RGBColor[
             0.3044915837808781, 0.4311065625226518, 0.9408810648238439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 266}], {
             RGBColor[
             0.5173579150755038, 0.6167245429391528, 0.9558899485594068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 313}], {
             RGBColor[
             0.33055584599709903`, 0.45850175468157234`, 0.9423653859984371]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 329}], {
             RGBColor[
             0.31941652727713654`, 0.4467936244332925, 0.9417310182764805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 340}], {
             RGBColor[
             0.3239430587205376, 0.45155129597897675`, 0.941988797545779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 341}], {
             RGBColor[
             0.31291881126268356`, 0.4399641129231123, 0.9413609829619669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 358}], {
             RGBColor[
             0.3270456066713938, 0.4548122705882284, 0.942165483061772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 81}], {
             RGBColor[
             0.21264159429708712`, 0.3408301762349806, 0.9354209962689466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 119}], {
             RGBColor[
             0.21795851687042844`, 0.3464185989719241, 0.9357237871438162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 130}], {
             RGBColor[
             0.20589531196195676`, 0.3337394057617535, 0.9350368054701912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 146}], {
             RGBColor[
             0.19762825714734855`, 0.3250502069900508, 0.9345660089285108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 151}], {
             RGBColor[
             0.20186975982558952`, 0.3295082952316844, 0.9348075562312959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 158}], {
             RGBColor[
             0.19363377892106423`, 0.3208517571096786, 0.934338529302825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 243}], {
             RGBColor[
             0.21376058132167255`, 0.342006302545695, 0.9354847209246038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 267}], {
             RGBColor[
             0.1968456208420638, 0.3242276066111888, 0.9345214389487315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 275}], {
             RGBColor[
             0.19513571872831864`, 0.3224303910755869, 0.9344240625529272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 311}], {
             RGBColor[
             0.19936169446772767`, 0.32687215952004334`, 0.9346647256195157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 317}], {
             RGBColor[
             0.19231567190482668`, 0.3194663430628012, 0.9342634650582149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 344}], {
             RGBColor[
             0.19384485664191092`, 0.32107361317738903`, 0.9343505498667657]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 346}], {
             RGBColor[
             0.19977669952143007`, 0.3273083561443247, 0.9346883595433791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 354}], {
             RGBColor[
             0.19611420939972474`, 0.3234588468111266, 0.9344797861491166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 75}], {
             RGBColor[
             0.1806580838475214, 0.3072134788808002, 0.9335995826642074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 126}], {
             RGBColor[
             0.18098291600078534`, 0.3075548980694286, 0.9336180813747896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 133}], {
             RGBColor[
             0.1814057266970613, 0.30799929891896116`, 0.9336421598184501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 200}], {
             RGBColor[
             0.1867268102524256, 0.3135920951118324, 0.9339451876550904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 320}], {
             RGBColor[
             0.1815572411564681, 0.30815855022236927`, 0.9336507883427678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 347}], {
             RGBColor[
             0.18186543483400505`, 0.3084824813180684, 0.9336683395167719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 398}], {
             RGBColor[
             0.18010682122099816`, 0.306634066908255, 0.9335681890731469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 72}], {
             RGBColor[
             0.6435705389401349, 0.7187858683660439, 0.9669572267898132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 236}], {
             RGBColor[
             0.6656201528579981, 0.7366867382683524, 0.9686930531678246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 262}], {
             RGBColor[
             0.5929687866565062, 0.6752889407487281, 0.9636412596987081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 284}], {
             RGBColor[
             0.7807346086845934, 0.8286481739482061, 0.9787765120052747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 333}], {
             RGBColor[
             0.8876904453290742, 0.9128181118706356, 0.9729875018597351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 334}], {
             RGBColor[
             0.8909079727489195, 0.8690177564079877, 0.6413882557335685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 337}], {
             RGBColor[
             0.8892917898500812, 0.9140123919924417, 0.970276843283211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 376}], {
             RGBColor[
             0.5538916735521564, 0.639355835105775, 0.9612276966528428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 391}], {
             RGBColor[
             0.8209192855845969, 0.5085618177919978, 0.5749280813219132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 397}], {
             RGBColor[
             0.5928919663607762, 0.6752224028696671, 0.9636363647773936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 93}], {
             RGBColor[
             0.45767335020652483`, 0.5675906819706489, 0.951280040300782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 131}], {
             RGBColor[
             0.693464422361174, 0.75939366397809, 0.9708100489116116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 142}], {
             RGBColor[
             0.5234887787089056, 0.6240307993134462, 0.955630100743997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 188}], {
             RGBColor[
             0.42431357927468827`, 0.535650894850094, 0.9492658859927827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 201}], {
             RGBColor[
             0.6192660008437627, 0.7014292931597987, 0.9634146436784279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 273}], {
             RGBColor[
             0.5484319039049934, 0.644280752022615, 0.9575937149291112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 281}], {
             RGBColor[
             0.4857845720433236, 0.5919392094145923, 0.9530712624984452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 293}], {
             RGBColor[
             0.44347384418172964`, 0.5552917835398956, 0.950375260333012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 394}], {
             RGBColor[
             0.46522152575946735`, 0.5741285322522734, 0.9517610033724258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 90}], {
             RGBColor[
             0.2062666965089075, 0.33412975446773896`, 0.9350579552707259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 95}], {
             RGBColor[
             0.22209777558797966`, 0.3507692223282312, 0.9359595118042963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 177}], {
             RGBColor[
             0.1891804395703839, 0.31617101509409057`, 0.9340849182149289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 228}], {
             RGBColor[
             0.21048617188066365`, 0.3385646906136451, 0.9352982481509928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 246}], {
             RGBColor[
             0.2068329817370454, 0.33472495614706915`, 0.9350902043767244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 260}], {
             RGBColor[
             0.19294770058427305`, 0.3201306452778321, 0.9342994581565066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 285}], {
             RGBColor[
             0.1906202345698193, 0.31768433092677273`, 0.9341669124101608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 110}], {
             RGBColor[
             0.9113332721380322, 0.9312595378862136, 0.9610025753124077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 131}], {
             RGBColor[
             0.8919073913712897, 0.9158173378862382, 0.9591371203789343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 201}], {
             RGBColor[
             0.8177089698538784, 0.8578529670679469, 0.9517417151457506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 212}], {
             RGBColor[
             0.7737416965530766, 0.822516123696677, 0.9480358411696325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 271}], {
             RGBColor[
             0.8948533141221586, 0.565840640212504, 0.5514777902284453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 273}], {
             RGBColor[
             0.7468748729151091, 0.8007044259307632, 0.9459207863964338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 287}], {
             RGBColor[
             0.8935114377259239, 0.5555263902170573, 0.5501928078759782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 289}], {
             RGBColor[
             0.7219591346417744, 0.780476707159252, 0.9439593282102003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 292}], {
             RGBColor[
             0.8945978800262582, 0.5638772618194792, 0.5512331862497395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 303}], {
             RGBColor[
             0.9318169667814895, 0.7940843861143203, 0.5846862975193713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 385}], {
             RGBColor[
             0.9820607295061435, 0.9836969405379016, 0.7849671104328407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 400}], {
             RGBColor[
             0.8959095468804387, 0.5739593080367903, 0.5524892399106185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 86}], {
             RGBColor[
             0.3668179912534385, 0.4880512045533021, 0.9448235654131886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 108}], {
             RGBColor[
             0.3859501572545172, 0.5081603240698226, 0.9459131139634468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 236}], {
             RGBColor[
             0.4875863338308316, 0.5948835771747154, 0.9528037287682061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 262}], {
             RGBColor[
             0.4149349676293397, 0.5334857796550911, 0.9477519352990894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 284}], {
             RGBColor[
             0.602700789657427, 0.6868450128545692, 0.9628871876056561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 297}], {
             RGBColor[
             0.3810483803734705, 0.5030082457772378, 0.9456339650216002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 325}], {
             RGBColor[
             0.35190435537579295`, 0.4723760276667679, 0.9439742559127038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 333}], {
             RGBColor[
             0.7096566263019076, 0.7710149507769987, 0.9570981774601166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 337}], {
             RGBColor[
             0.7112579708229148, 0.7722092308988048, 0.9543875188835923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 376}], {
             RGBColor[
             0.3758578545249899, 0.4975526740121381, 0.9453383722532241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 397}], {
             RGBColor[
             0.4148581473336097, 0.5334192417760302, 0.947747040377775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.21536881746289013`, 0.3436966606981754, 0.9355763075936738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 162}], {
             RGBColor[
             0.19690433907813965`, 0.3242893232002557, 0.9345247828654102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 183}], {
             RGBColor[
             0.19359784833893534`, 0.3208139917897307, 0.9343364831093273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 189}], {
             RGBColor[
             0.2158427366159144, 0.3441947797762137, 0.9356032965883381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 207}], {
             RGBColor[
             0.1950145063297256, 0.32230298915935574`, 0.934417159686145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 280}], {
             RGBColor[
             0.2037203723071403, 0.3314534062854026, 0.9349129458743843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 291}], {
             RGBColor[
             0.19698615809912115`, 0.32437532017893284`, 0.9345294423376147]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 336}], {
             RGBColor[
             0.2166564041388005, 0.3450499959322676, 0.9356496337500533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 368}], {
             RGBColor[
             0.19117243294824504`, 0.31826472643389747`, 0.934198359290908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 387}], {
             RGBColor[
             0.19202691052884113`, 0.31916283654811173`, 0.9342470205250366]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 116}], {
             RGBColor[
             0.244277527259818, 0.37408154761281204`, 0.9372226158500052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 118}], {
             RGBColor[
             0.3029906205258713, 0.4312899550504897, 0.9407311083477143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 141}], {
             RGBColor[
             0.3021503369999872, 0.43056214369424695`, 0.9406775662244785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 179}], {
             RGBColor[
             0.23767352171657924`, 0.3671403190687327, 0.9368465275040685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 209}], {
             RGBColor[
             0.2567896978925637, 0.3872326322652657, 0.9379351654574425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 286}], {
             RGBColor[
             0.28488862903471124`, 0.4156109198533938, 0.9395776654568602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 290}], {
             RGBColor[
             0.2530317916874394, 0.3832828345786652, 0.9377211582583846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 304}], {
             RGBColor[
             0.2654021800822186, 0.39628489710950293`, 0.9384256335771177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 338}], {
             RGBColor[
             0.22933498443170014`, 0.35837598768852497`, 0.9363716601414551]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 386}], {
             RGBColor[
             0.29523037248077955`, 0.42456841823523894`, 0.9402366322043989]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 126}], {
             RGBColor[
             0.18223452639463555`, 0.3088704199500476, 0.9336893587351277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 133}], {
             RGBColor[
             0.18265733709091148`, 0.3093148207995801, 0.9337134371787883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 178}], {
             RGBColor[
             0.18245868691760933`, 0.30910602687229105`, 0.9337021243452953]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 200}], {
             RGBColor[
             0.1879784206462758, 0.3149076169924513, 0.9340164650154286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 296}], {
             RGBColor[
             0.18049305546872535`, 0.30704002359128196`, 0.9335901845421726]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 320}], {
             RGBColor[
             0.18280885155031829`, 0.3094740721029882, 0.933722065703106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 330}], {
             RGBColor[
             0.18530504232011252`, 0.31209772686967785`, 0.9338642200746624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 347}], {
             RGBColor[
             0.18311704522785527`, 0.30979800319868733`, 0.9337396168771099]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 398}], {
             RGBColor[
             0.18135843161484838`, 0.30794958878887396`, 0.9336394664334849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 78}], {
             RGBColor[
             0.2517003601981642, 0.38188341566580475`, 0.9376453352047469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 80}], {
             RGBColor[
             0.24302079240522623`, 0.37276063959904404`, 0.9371510466592089]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.24728213971667218`, 0.37723958580839845`, 0.9373937240844974]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 117}], {
             RGBColor[
             0.4207333030341396, 0.5335965741048728, 0.9489064510842957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.2623813144884871, 0.39310977583655005`, 0.9382535997505249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 187}], {
             RGBColor[
             0.24964108184106412`, 0.37971898354670364`, 0.9375280623487394]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 208}], {
             RGBColor[
             0.28867650153937047`, 0.420747684638181, 0.9397510717528295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 239}], {
             RGBColor[
             0.3950361568987507, 0.5127344732289232, 0.94688347760877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 269}], {
             RGBColor[
             0.3181691701834686, 0.44761747327725976`, 0.9415818139795731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 323}], {
             RGBColor[
             0.3517784337991403, 0.4767281281704481, 0.9437233665376588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 365}], {
             RGBColor[
             0.2944759917270998, 0.42684331653440033`, 0.9400813441394438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 377}], {
             RGBColor[
             0.2688145572376063, 0.39987152185702324`, 0.9386199634079575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 388}], {
             RGBColor[
             0.276858244918402, 0.40832594760879465`, 0.9390780395218092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 395}], {
             RGBColor[
             0.36080793914227827`, 0.4845490318625397, 0.9442987186336453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 78}], {
             RGBColor[
             0.20870891214169546`, 0.33669667794321373`, 0.9351970358380788]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 80}], {
             RGBColor[
             0.20002934434875747`, 0.3275739018764531, 0.9347027472925409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 96}], {
             RGBColor[
             0.20429069166020342`, 0.3320528480858075, 0.9349454247178293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 182}], {
             RGBColor[
             0.21938986643201835`, 0.34792303811395897`, 0.9358053003838569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 187}], {
             RGBColor[
             0.2066496337845954, 0.33453224582411256`, 0.9350797629820713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 244}], {
             RGBColor[
             0.18965577385650711`, 0.31667062156674053`, 0.9341119877993296]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 302}], {
             RGBColor[
             0.19582677060371215`, 0.3231567304118451, 0.9344634169349113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 377}], {
             RGBColor[
             0.22582310918113752`, 0.35468478413443216`, 0.9361716640412894]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 388}], {
             RGBColor[
             0.23386679686193323`, 0.36313920988620363`, 0.9366297401551412]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 80}], {
             RGBColor[
             0.21178615052788774`, 0.3399310505952844, 0.9353722800118063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 96}], {
             RGBColor[
             0.2160474978393337, 0.3444099968046388, 0.9356149574370947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 104}], {
             RGBColor[
             0.22225745398096258`, 0.35093705444345114`, 0.9359686052525535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 182}], {
             RGBColor[
             0.23114667261114863`, 0.3602801868327903, 0.9364748331031223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 187}], {
             RGBColor[
             0.21840643996372563`, 0.3468893945429439, 0.9357492957013367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 208}], {
             RGBColor[
             0.257441859662032, 0.38791809563442126`, 0.9379723051054267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 302}], {
             RGBColor[
             0.2075835767828424, 0.33551387913067643`, 0.9351329496541767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 377}], {
             RGBColor[
             0.2375799153602678, 0.3670419328532635, 0.9368411967605548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 388}], {
             RGBColor[
             0.2456236030410635, 0.37549635860503494`, 0.9372992728744065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 87}], {
             RGBColor[
             0.19294989757058154`, 0.3201329544497393, 0.9342995832716268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 126}], {
             RGBColor[
             0.19080527822884924`, 0.31787882354485875`, 0.9341774503727951]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 176}], {
             RGBColor[
             0.19262785863960308`, 0.31979447111483345`, 0.9342812436309215]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 205}], {
             RGBColor[
             0.19210249208707042`, 0.3192422775579583, 0.9342513247829649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 232}], {
             RGBColor[
             0.19470557204870292`, 0.32197827964243614`, 0.9343995663358682]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[
             0.19208286823872933`, 0.31922165164912797`, 0.9342502072338328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 298}], {
             RGBColor[
             0.20225845525357178`, 0.3299168387712073, 0.934829691860896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 373}], {
             RGBColor[
             0.19851817498261992`, 0.32598556705897075`, 0.9346166884327141]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 390}], {
             RGBColor[
             0.2060170491676479, 0.3338673592835195, 0.9350437382239613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 96}], {
             RGBColor[
             0.2073679300463957, 0.3352872207378781, 0.9351206688915568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 104}], {
             RGBColor[
             0.2135778861880246, 0.34181427837669043`, 0.9354743167070156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 182}], {
             RGBColor[
             0.22246710481821064`, 0.35115741076602963`, 0.9359805445575843]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 187}], {
             RGBColor[
             0.20972687217078761`, 0.3377666184761832, 0.9352550071557988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 244}], {
             RGBColor[
             0.1927330122426994, 0.31990499421881113`, 0.9342872319730569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 302}], {
             RGBColor[
             0.1989040089899044, 0.3263911030639157, 0.9346386611086387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 377}], {
             RGBColor[
             0.2289003475673298, 0.3579191567865028, 0.9363469082150169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 388}], {
             RGBColor[
             0.23694403524812552`, 0.36637358253827423`, 0.9368049843288686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 119}], {
             RGBColor[
             0.2344729010553813, 0.363776263822743, 0.9366642568923073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 128}], {
             RGBColor[
             0.2665289573662383, 0.3974692114768138, 0.9384898018765251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.2224096961469096, 0.35109707061257234`, 0.9359772752186821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 135}], {
             RGBColor[
             0.2822556151095555, 0.41153871876028536`, 0.9394754920042432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 146}], {
             RGBColor[
             0.2141426413323014, 0.3424078718408697, 0.9355064786770019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 166}], {
             RGBColor[
             0.2371652059079643, 0.3666060469247946, 0.9368175796707537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 227}], {
             RGBColor[
             0.2515739104642789, 0.38175050897811513`, 0.9376381340794677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 243}], {
             RGBColor[
             0.2302749655066254, 0.3593639673965138, 0.9364251906730947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[
             0.21336000502701669`, 0.3415852714620077, 0.9354619086972226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 275}], {
             RGBColor[
             0.21165010291327152`, 0.33978805592640576`, 0.9353645323014182]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 311}], {
             RGBColor[
             0.21587607865268055`, 0.34422982437086214`, 0.9356051953680067]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 326}], {
             RGBColor[
             0.23536377630225702`, 0.36471263019196243`, 0.936714990919685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 344}], {
             RGBColor[
             0.2103592408268638, 0.3384312780282078, 0.9352910196152566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 346}], {
             RGBColor[
             0.21629108370638292`, 0.34466602099514354`, 0.9356288292918702]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 363}], {
             RGBColor[
             0.3018408929173706, 0.42850250201273, 0.940723448587576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 383}], {
             RGBColor[
             0.2937367673363199, 0.42148311575961905`, 0.9402070608717483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 172}], {
             RGBColor[
             0.5696909718954926, 0.6577404259092337, 0.9610497684809419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 194}], {
             RGBColor[
             0.6075992658363466, 0.6905170696190597, 0.963481170694517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 233}], {
             RGBColor[
             0.865044812104987, 0.8948209835298624, 0.9558976637938235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 256}], {
             RGBColor[
             0.8760312800563814, 0.9016669835366705, 0.876948136427472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 257}], {
             RGBColor[
             0.8645894369328215, 0.89448136547207, 0.956668495179433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 310}], {
             RGBColor[
             0.7931376486603983, 0.5085364648564028, 0.5748575062936936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 316}], {
             RGBColor[
             0.7359499332008539, 0.7936489483339444, 0.9743162695644639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 399}], {
             RGBColor[
             0.5595672102027384, 0.6489717323660277, 0.9604046913379707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 118}], {
             RGBColor[
             0.6542161598297946, 0.7234949587303476, 0.9559255584190995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 123}], {
             RGBColor[
             0.8970713714097568, 0.6478503290469954, 0.5784075917525047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 141}], {
             RGBColor[
             0.6533758763039106, 0.7227671473741049, 0.9558720162958637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 161}], {
             RGBColor[
             0.9152656356126947, 0.754447556797873, 0.5945283802670174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 196}], {
             RGBColor[
             0.8975547667711833, 0.9207556417701627, 0.9764242298319501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 214}], {
             RGBColor[
             0.9149531561640245, 0.7530286606028909, 0.5942676397554747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 286}], {
             RGBColor[
             0.6361141683386347, 0.7078159235332517, 0.9547721155282454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 332}], {
             RGBColor[
             0.8843949242801739, 0.5504136015544692, 0.5662686116652167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 334}], {
             RGBColor[
             0.9555982588691752, 0.9202058525384339, 0.6338919338224923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 366}], {
             RGBColor[
             0.9721424943326117, 0.9755215245830015, 0.7399924007909114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 125}], {
             RGBColor[
             0.20344264397852102`, 0.33116149620303065`, 0.9348971296569317]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 184}], {
             RGBColor[
             0.21392003441563898`, 0.34217389785736374`, 0.9354938015424155]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 185}], {
             RGBColor[
             0.20341836522778634`, 0.3311359776966468, 0.9348957470179945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 190}], {
             RGBColor[
             0.21321988075352158`, 0.3414379919661722, 0.9354539288271424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 252}], {
             RGBColor[
             0.2101141940866254, 0.33817371836735655`, 0.9352770645659143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 270}], {
             RGBColor[
             0.21111604747539212`, 0.339226729800124, 0.9353341186342953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 274}], {
             RGBColor[
             0.20871345876417752`, 0.33670145673171487`, 0.935197294761503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 288}], {
             RGBColor[
             0.21401051896422651`, 0.342269002854981, 0.9354989545035975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 318}], {
             RGBColor[
             0.2138717930117836, 0.3421231930832301, 0.9354910542658326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 168}], {
             RGBColor[
             0.18992658867508105`, 0.3169552651117129, 0.9341274103026127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 238}], {
             RGBColor[
             0.19138550303315327`, 0.3184886766025597, 0.9342104933170345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 379}], {
             RGBColor[
             0.18217848519657132`, 0.30881151709766497`, 0.9336861672718034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 236}], {
             RGBColor[
             0.3888676051713017, 0.5059520744556105, 0.9465593917911999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 262}], {
             RGBColor[
             0.31621623896980977`, 0.44455427693598626`, 0.9415075983220833]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 265}], {
             RGBColor[
             0.23354789403514828`, 0.36280402279564555`, 0.9366115791109302]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 297}], {
             RGBColor[
             0.28232965171394053`, 0.4140767430581329, 0.9393896280445941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 325}], {
             RGBColor[
             0.25318562671626305`, 0.38344452494766296`, 0.9377299189356977]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 376}], {
             RGBColor[
             0.2771391258654599, 0.4086211712930332, 0.939094035276218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 397}], {
             RGBColor[
             0.3161394186740798, 0.4444877390569253, 0.9415027034007689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 176}], {
             RGBColor[
             0.18652655830038561`, 0.3133816176135313, 0.933933783602668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 205}], {
             RGBColor[
             0.18600119174785296`, 0.31282942405665615`, 0.9339038647547113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 232}], {
             RGBColor[
             0.18860427170948546`, 0.315565426141134, 0.9340521063076146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 277}], {
             RGBColor[
             0.18598156789951187`, 0.3128087981478258, 0.9339027472055792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 373}], {
             RGBColor[
             0.19241687464340246`, 0.3195727135576686, 0.9342692284044607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 390}], {
             RGBColor[
             0.19991574882843044`, 0.32745450578221735`, 0.9346962781957078]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 89}], {
             RGBColor[
             0.33131087657095276`, 0.4543117529947025, 0.9425908573941362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 120}], {
             RGBColor[
             0.42147179727410705`, 0.5394794198355211, 0.9480767881227974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 140}], {
             RGBColor[
             0.41837127081473313`, 0.5367938996534025, 0.947879225318494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 189}], {
             RGBColor[
             0.331784795723977, 0.4548098720727408, 0.9426178463888004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 195}], {
             RGBColor[
             0.42750707901937735`, 0.5447068775411936, 0.948461350938816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 233}], {
             RGBColor[
             0.7003634497191511, 0.7623012578281982, 0.9418757273882692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 255}], {
             RGBColor[
             0.40229233650521606`, 0.5228671349052352, 0.9468546898423349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 257}], {
             RGBColor[
             0.6999080745469857, 0.7619616397704058, 0.9426465587738788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 263}], {
             RGBColor[
             0.3661139704738488, 0.49089201133024934`, 0.9445728421053426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 336}], {
             RGBColor[
             0.33259846324686315`, 0.4556650882287947, 0.9426641835505155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 356}], {
             RGBColor[
             0.6878897223994248, 0.7529983724170004, 0.962990494071441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 359}], {
             RGBColor[
             0.3780427703410259, 0.5018633795124479, 0.9453095289294022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 360}], {
             RGBColor[
             0.5465756968337885, 0.6418389618053506, 0.9578331782484879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 389}], {
             RGBColor[
             0.7117595806289345, 0.7674543626326005, 0.720767374949669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 162}], {
             RGBColor[
             0.2137613905296329, 0.342007153074568, 0.9354847670077999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 183}], {
             RGBColor[
             0.21045489979042858`, 0.338531821664043, 0.935296467251717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 189}], {
             RGBColor[
             0.23269978806740765`, 0.361912609650526, 0.9365632807307278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 263}], {
             RGBColor[
             0.2670289628172794, 0.39799474890803455`, 0.93851827644727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 270}], {
             RGBColor[
             0.22008543635339983`, 0.34865412620301106`, 0.935844912061876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.22057742375863354`, 0.3491712361597149, 0.935872930016774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 291}], {
             RGBColor[
             0.2138432095506144, 0.34209315005324514`, 0.9354894264800044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 336}], {
             RGBColor[
             0.23351345559029374`, 0.36276782580657996`, 0.9366096178924429]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 359}], {
             RGBColor[
             0.2789577626844565, 0.40896611709023306`, 0.9392549632713296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 95}], {
             RGBColor[
             0.23140010342565426`, 0.3605465586872775, 0.936489265613091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 97}], {
             RGBColor[
             0.2570968896215246, 0.3875555102494842, 0.9379526595719574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.23037172884023532`, 0.35946567179528754`, 0.9364307012017953]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 228}], {
             RGBColor[
             0.21978849971833822`, 0.34834202697269134`, 0.9358280019597877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 246}], {
             RGBColor[
             0.21613530957472, 0.3445022925061154, 0.9356199581855191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 260}], {
             RGBColor[
             0.20225002842194761`, 0.32990798163687834`, 0.9348292119653014]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 326}], {
             RGBColor[
             0.22857029923452804`, 0.35757225506245527`, 0.9363281124507266]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 172}], {
             RGBColor[
             0.48609962486048197`, 0.5916756169176496, 0.9532395671401708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 192}], {
             RGBColor[
             0.4254211791359827, 0.5344518171008017, 0.9495440785539795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 208}], {
             RGBColor[
             0.4434969579662055, 0.5534506067219376, 0.9505734674176423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 221}], {
             RGBColor[
             0.48124384050183955`, 0.5874697805650118, 0.9529301608546397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 256}], {
             RGBColor[
             0.792439933021371, 0.8356021745450866, 0.869137935086701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 316}], {
             RGBColor[
             0.6523585861658432, 0.7275841393423603, 0.9665060682236928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 351}], {
             RGBColor[
             0.45106536887988224`, 0.5613307052601594, 0.9510072153286632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 395}], {
             RGBColor[
             0.5156283955691132, 0.6172519539462964, 0.9551211142984581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 399}], {
             RGBColor[
             0.4759758631677278, 0.5829069233744436, 0.9525944899971995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 98}], {
             RGBColor[
             0.19880960071600262`, 0.32629187398221465`, 0.9346332846971046]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 119}], {
             RGBColor[
             0.22208012665594387`, 0.3507506721816547, 0.9359585067237262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 130}], {
             RGBColor[
             0.2100169217474722, 0.33807147897148404`, 0.935271525050101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 143}], {
             RGBColor[
             0.20163694443753327`, 0.3292635914974891, 0.9347942977393655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 146}], {
             RGBColor[
             0.20174986693286398`, 0.32938228019978144`, 0.9348007285084208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 151}], {
             RGBColor[
             0.20599136961110498`, 0.33384036844141496`, 0.9350422758112056]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 158}], {
             RGBColor[
             0.19775538870657966`, 0.32518383031940923`, 0.9345732488827347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 186}], {
             RGBColor[
             0.20547576839988674`, 0.33329843887741967`, 0.9350129130849905]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 267}], {
             RGBColor[
             0.20096723062757926`, 0.3285596798209194, 0.9347561585286415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 306}], {
             RGBColor[
             0.21333519209183469`, 0.34155919149390046`, 0.9354604956372714]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 308}], {
             RGBColor[
             0.20860909712508957`, 0.3365917660321234, 0.9351913515205462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 346}], {
             RGBColor[
             0.2038983093069455, 0.33164042935405524`, 0.934923079123289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 348}], {
             RGBColor[
             0.2027372639690243, 0.3304200970893739, 0.9348569593089071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 354}], {
             RGBColor[
             0.20023581918524017`, 0.32779092002085713`, 0.9347145057290265]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 374}], {
             RGBColor[
             0.1940034937220554, 0.32124035080679264`, 0.9343595840137974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 131}], {
             RGBColor[
             0.5783198351360825, 0.6629059133309206, 0.9625766163950823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 142}], {
             RGBColor[
             0.4083441914838143, 0.5275430486662767, 0.9473966682274677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 188}], {
             RGBColor[
             0.3091689920495968, 0.43916314420292457`, 0.9410324534762535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 201}], {
             RGBColor[
             0.5041214136186714, 0.6049415425126292, 0.9551812111618987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 264}], {
             RGBColor[
             0.3012538452175734, 0.43084382303317337`, 0.9405816975735801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 273}], {
             RGBColor[
             0.433287316679902, 0.5477930013754455, 0.949360282412582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 281}], {
             RGBColor[
             0.3706399848182322, 0.4954514587674228, 0.944837829981916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 293}], {
             RGBColor[
             0.3283292569566383, 0.4588040328927261, 0.9421418278164828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 394}], {
             RGBColor[
             0.35007693853437594`, 0.4776407816051039, 0.9435275708558966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 204}], {
             RGBColor[
             0.1795232819748228, 0.3060207301619996, 0.9335349573763461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.18066543438157506`, 0.30722120475814135`, 0.9336000012662475]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 307}], {
             RGBColor[
             0.17906784709075121`, 0.30554203922260087`, 0.9335090210334537]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 324}], {
             RGBColor[
             0.18239675869616345`, 0.30904093638507546`, 0.9336985976246985]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 97}], {
             RGBColor[
             0.27292796870059677`, 0.4041949781099764, 0.9388542161055278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 148}], {
             RGBColor[
             0.2518920934922597, 0.3820849395144922, 0.9376562541322015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 166}], {
             RGBColor[
             0.24620280791930751`, 0.37610513965577974`, 0.9373322577353658]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 169}], {
             RGBColor[
             0.3522449518778092, 0.4737241407933565, 0.9439035250794346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 228}], {
             RGBColor[
             0.2356195787974104, 0.36498149483318354`, 0.9367295584933581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 246}], {
             RGBColor[
             0.23196638865379215`, 0.3611417603666076, 0.9365215147190895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 276}], {
             RGBColor[
             0.3131382201938357, 0.4399588551912694, 0.9413821143478849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 282}], {
             RGBColor[
             0.2811273621289757, 0.41223265884799526`, 0.9393424107780823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 305}], {
             RGBColor[
             0.2726453120788769, 0.4038978880790839, 0.9388381192290738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 326}], {
             RGBColor[
             0.24440137831360023`, 0.3742117229229475, 0.9372296689842969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 361}], {
             RGBColor[
             0.32840262007179855`, 0.45318011115451534`, 0.9423547484103298]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 382}], {
             RGBColor[
             0.2846635750266093, 0.4152955487246973, 0.9395677351369693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 104}], {
             RGBColor[
             0.21783923349947054`, 0.34629322458604483`, 0.935716994132304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 182}], {
             RGBColor[
             0.2267284521296566, 0.35563635697538404`, 0.9362232219828728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 187}], {
             RGBColor[
             0.2139882194822336, 0.34224556468553763`, 0.9354976845810872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 208}], {
             RGBColor[
             0.25302363918053994`, 0.383274265777015, 0.9377206939851772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 225}], {
             RGBColor[
             0.21005566506834547`, 0.33811220065819025`, 0.9352737314249091]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 261}], {
             RGBColor[
             0.20041641876701294`, 0.3279807416319751, 0.9347247906080353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 377}], {
             RGBColor[
             0.23316169487877575`, 0.36239810299585723`, 0.9365895856403053]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 388}], {
             RGBColor[
             0.24120538255957147`, 0.37085252874762864`, 0.937047661754157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 166}], {
             RGBColor[
             0.27189959411517783`, 0.40311409121798647`, 0.9387956516942321]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 169}], {
             RGBColor[
             0.37794173807367953`, 0.5007330923555633, 0.945366919038301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 224}], {
             RGBColor[
             0.3981861519254275, 0.5171684195208632, 0.946960633454442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 246}], {
             RGBColor[
             0.2576631748496625, 0.38815071192881434`, 0.9379849086779559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 276}], {
             RGBColor[
             0.33883500638970604`, 0.46696780675347616`, 0.9428455083067513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 326}], {
             RGBColor[
             0.27009816450947055`, 0.40122067448515425`, 0.9386930629431633]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 363}], {
             RGBColor[
             0.3365752811245841, 0.4650105463059218, 0.9427015206110543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 382}], {
             RGBColor[
             0.3103603612224796, 0.44230450028690405`, 0.9410311290958356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 383}], {
             RGBColor[
             0.32847115554353346`, 0.45799116005281093`, 0.9421851328952267]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 393}], {
             RGBColor[
             0.5102982570407728, 0.6069665111134733, 0.9566203329382144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 134}], {
             RGBColor[
             0.1861818864522268, 0.313019345647659, 0.9339141550508117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 143}], {
             RGBColor[
             0.19607611547037074`, 0.3234188076760809, 0.9344776167561948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 151}], {
             RGBColor[
             0.20043054064394245`, 0.3279955846200067, 0.934725594828035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 158}], {
             RGBColor[
             0.19219455973941713`, 0.31933904649800093`, 0.9342565678995641]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 163}], {
             RGBColor[
             0.18615149755953203`, 0.3129874049946697, 0.933912424448329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.1906510637312114, 0.3177167343300775, 0.9341686680852945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 186}], {
             RGBColor[
             0.1999149394327242, 0.32745365505601143`, 0.9346962321018197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 240}], {
             RGBColor[
             0.18629079266231832`, 0.3131338129795177, 0.9339203570983641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 272}], {
             RGBColor[
             0.1949500622314218, 0.3222352543260466, 0.9344134896900831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 306}], {
             RGBColor[
             0.20777436312467215`, 0.33571440767249217`, 0.9351438146541007]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 308}], {
             RGBColor[
             0.20304826815792704`, 0.3307469822107151, 0.9348746705373756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 342}], {
             RGBColor[
             0.1898214409282245, 0.31684474816301444`, 0.9341214222939813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 348}], {
             RGBColor[
             0.19717643500186177`, 0.3245753132679656, 0.9345402783257364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 354}], {
             RGBColor[
             0.19467499021807763`, 0.3219461361994489, 0.9343978247458558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 374}], {
             RGBColor[
             0.18844266475489285`, 0.3153955669853844, 0.9340429030306268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 378}], {
             RGBColor[
             0.21674290293340537`, 0.34514091164973765`, 0.9356545597284425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 144}], {
             RGBColor[
             0.7417116613175341, 0.797878300210745, 0.9753542230915366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 169}], {
             RGBColor[
             0.6797124063510102, 0.7475445119943138, 0.9704734146298177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[
             0.7312212189545854, 0.7893616865114603, 0.9745283770409688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 222}], {
             RGBColor[
             0.9266267914902193, 0.9439342403679507, 0.9791054495248444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 223}], {
             RGBColor[
             0.8806912086429535, 0.689221405037725, 0.5973847957056915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 276}], {
             RGBColor[
             0.6406056746670367, 0.7137792263922267, 0.9679520038982681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 361}], {
             RGBColor[
             0.6558700745449995, 0.7270004823554725, 0.968924637960713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 382}], {
             RGBColor[
             0.6121310294998102, 0.6891159199256546, 0.9661376246873524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 384}], {
             RGBColor[
             0.9178754148881313, 0.8496097092612407, 0.6279747633092586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 393}], {
             RGBColor[
             0.8120689253181035, 0.8537779307522239, 0.9817268285297311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 157}], {
             RGBColor[
             0.31728677632069113`, 0.4435179334056334, 0.9416477086340886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 167}], {
             RGBColor[
             0.3117593370391954, 0.4377082442608893, 0.941332929144121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 174}], {
             RGBColor[
             0.4027739307357637, 0.5232842676221057, 0.9468853766008484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 198}], {
             RGBColor[
             0.6082548805926754, 0.6882816237042615, 0.9647291510065205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 203}], {
             RGBColor[
             0.3488608742001085, 0.47658748779993204`, 0.9434500843118405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 206}], {
             RGBColor[
             0.40830029738828666`, 0.5280709286532568, 0.947237511797173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 211}], {
             RGBColor[
             0.31010062158634694`, 0.43596482915131163`, 0.941238467752931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 266}], {
             RGBColor[
             0.5229669528809726, 0.6215828095678126, 0.9562473514884939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 341}], {
             RGBColor[
             0.3185278490681524, 0.4448223795517722, 0.9417183858910539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 358}], {
             RGBColor[
             0.33265464447686266`, 0.4596705372168882, 0.942522885990859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 115}], {
             RGBColor[
             0.9045408089975616, 0.6377980714511916, 0.24102778506069641`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 123}], {
             RGBColor[
             0.8485657793755872, 0.374303438706794, 0.1941399512182521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 161}], {
             RGBColor[
             0.8667600435785252, 0.4809006664576717, 0.21026073973276477`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 193}], {
             RGBColor[
             0.8459509404020927, 0.6447383034706259, 0.5918610769410064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 253}], {
             RGBColor[
             0.8395830715203696, 0.3052584098839103, 0.18553810003157822`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 283}], {
             RGBColor[
             0.8929481444706848, 0.5918370196285758, 0.23170005506756156`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 332}], {
             RGBColor[
             0.8358893322460044, 0.27686671121426787`, 0.18200097113096422`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 334}], {
             RGBColor[
             0.9070926668350056, 0.6466589621982325, 0.24962429328823976`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 356}], {
             RGBColor[
             0.8996786533554004, 0.687329585228627, 0.5883270956947237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 364}], {
             RGBColor[
             0.8876560448428017, 0.5708556080916793, 0.22744190748542303`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 366}], {
             RGBColor[
             0.9236369022984421, 0.7019746342428002, 0.3557247602566589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 380}], {
             RGBColor[
             0.787177962650946, 0.5986793707999881, 0.5860416238148101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 389}], {
             RGBColor[
             0.9235485115849101, 0.701785575444227, 0.3461039765729519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 108}], {
             RGBColor[
             0.3276991764172302, 0.45803801914073383`, 0.9421097447928497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 139}], {
             RGBColor[
             0.3279891561400408, 0.4583428062151842, 0.9421262587090772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 213}], {
             RGBColor[
             0.33722405994131943`, 0.4665082641722599, 0.9427085967973012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 297}], {
             RGBColor[
             0.32279739953618347`, 0.45288594084814915`, 0.9418305958510031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 333}], {
             RGBColor[
             0.6514056454646207, 0.7208926458479099, 0.9532948082895194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 337}], {
             RGBColor[
             0.6530069899856277, 0.722086925969716, 0.9505841497129952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 345}], {
             RGBColor[
             0.5885592438891699, 0.6712468009440402, 0.9634628617416172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 350}], {
             RGBColor[
             0.3487900132261258, 0.4765261115858444, 0.9434455691132382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 378}], {
             RGBColor[
             0.29463589617818253`, 0.42328641527644917`, 0.9402268398959757]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 122}], {
             RGBColor[
             0.1920779072643653, 0.3192164373505274, 0.9342499247136817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 295}], {
             RGBColor[
             0.1903453971129866, 0.3173954593339403, 0.9341512608235798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 145}], {
             RGBColor[
             0.2369611402467977, 0.36639156097639836`, 0.9368059584332384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 170}], {
             RGBColor[
             0.22977658578143667`, 0.35884013870624076`, 0.936396808685032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 182}], {
             RGBColor[
             0.23293840827128548`, 0.36216341461419643`, 0.9365768697983317]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 187}], {
             RGBColor[
             0.2201981756238625, 0.34877262232435, 0.935851332396546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 192}], {
             RGBColor[
             0.24115781649194606`, 0.3708025337946915, 0.9370449529369735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 208}], {
             RGBColor[
             0.25923359532216883`, 0.3898013234158274, 0.9380743418006362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 225}], {
             RGBColor[
             0.2162656212099744, 0.3446392582970026, 0.935627379240368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 235}], {
             RGBColor[
             0.20864915250350596`, 0.3366338667744967, 0.9351936326150905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 261}], {
             RGBColor[
             0.20662637490864183`, 0.3345077992707875, 0.9350784384234943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 327}], {
             RGBColor[
             0.20490625211316982`, 0.332699841150662, 0.9349804799749857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 335}], {
             RGBColor[
             0.21115674634682685`, 0.33926950689445945`, 0.9353364363748149]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 349}], {
             RGBColor[
             0.21123195753513827`, 0.3393485586220395, 0.9353407195407242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 351}], {
             RGBColor[
             0.26680200623584566`, 0.3976814219540492, 0.9385080897116571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 355}], {
             RGBColor[
             0.21609483282429037`, 0.34445974887503966`, 0.9356176530944622]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 199}], {
             RGBColor[
             0.9870190215241651, 0.9889000460513815, 0.8647919372474027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 215}], {
             RGBColor[
             0.8456866310237973, 0.8792487049970009, 0.932290412064394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 259}], {
             RGBColor[
             0.9403634558512834, 0.9538207185775788, 0.9415651020124101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 271}], {
             RGBColor[
             0.9026525217316504, 0.5714728168582255, 0.530015287474555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 287}], {
             RGBColor[
             0.9013106453354156, 0.5611585668627788, 0.528730305122088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 303}], {
             RGBColor[
             0.9396161743909813, 0.7997165627600418, 0.5632237947654809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 333}], {
             RGBColor[
             0.969539411680839, 0.9766186640035739, 0.9281855313871071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 337}], {
             RGBColor[
             0.9711407562018461, 0.97781294412538, 0.9254748728105828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 345}], {
             RGBColor[
             0.9066930101053883, 0.9269728190997042, 0.9383535848392048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 350}], {
             RGBColor[
             0.6669237794423443, 0.7322521297415084, 0.9183362922108259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 353}], {
             RGBColor[
             0.9892810453920724, 0.988090926321853, 0.7004958160747115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 400}], {
             RGBColor[
             0.9037087544899305, 0.5795914846825118, 0.5310267371567282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 197}], {
             RGBColor[
             0.18891531916432497`, 0.315892356737718, 0.9340698200000144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 217}], {
             RGBColor[
             0.1973830107710603, 0.32479243749905357`, 0.9345520425101908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 231}], {
             RGBColor[
             0.1888628748467801, 0.31583723443481654`, 0.9340668333737145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 254}], {
             RGBColor[
             0.18679837373704838`, 0.3136673128715579, 0.9339492630896711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 314}], {
             RGBColor[
             0.18463641563674799`, 0.3113949578320815, 0.9338261427741893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 369}], {
             RGBColor[
             0.18346224485360668`, 0.3101608298922725, 0.9337592754851194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 124}], {
             RGBColor[
             0.22484989821780513`, 0.3536618777068309, 0.9361162411166642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 150}], {
             RGBColor[
             0.23074389884075946`, 0.35985684606277935`, 0.936451895732749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 152}], {
             RGBColor[
             0.2119625047523057, 0.3401164100666513, 0.9353823231239942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.2124764155335251, 0.34065656288153834`, 0.9354115895827217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.2349712471793796, 0.36430005719603437`, 0.936692636966832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 160}], {
             RGBColor[
             0.20918830325598364`, 0.33720054839948277`, 0.935224336452842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 167}], {
             RGBColor[
             0.22944380789788385`, 0.3584903680512903, 0.9363778574768644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.2249471629490288, 0.3537641091062871, 0.9361217801992172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 181}], {
             RGBColor[
             0.20760170595158578`, 0.3355329340364814, 0.935133982083517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 211}], {
             RGBColor[
             0.2277850924450354, 0.3567469529417126, 0.9362833960856742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 238}], {
             RGBColor[
             0.21198166691675951`, 0.34013655071644366`, 0.9353834143809119]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 245}], {
             RGBColor[
             0.20898762068619692`, 0.33698961829462715`, 0.9352129078773759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 386}], {
             RGBColor[
             0.2825040137132291, 0.4111922082727934, 0.9395118848995476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 297}], {
             RGBColor[
             0.30146181771501923`, 0.43418586257465347`, 0.9404791765948524]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 325}], {
             RGBColor[
             0.2723177927173417, 0.4035536444641835, 0.9388194674859559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 376}], {
             RGBColor[
             0.29627129186653856`, 0.4287302908095537, 0.9401835838264763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 378}], {
             RGBColor[
             0.2733003143570183, 0.40458633700295354`, 0.938875420639825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 397}], {
             RGBColor[
             0.3352715846751584, 0.4645968585734458, 0.9425922519510271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 114}], {
             RGBColor[
             0.18471405231964982`, 0.3114765589082613, 0.9338305640684275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 132}], {
             RGBColor[
             0.1878121680467173, 0.3147328749692917, 0.9340069971758325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 180}], {
             RGBColor[
             0.18558731783868732`, 0.3123944163370016, 0.933880295247856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 232}], {
             RGBColor[
             0.18655512715268852`, 0.3134116452886715, 0.9339354105565427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 249}], {
             RGBColor[
             0.18318613987214505`, 0.3098706260506894, 0.9337435517148859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 370}], {
             RGBColor[
             0.18414849826566793`, 0.3108821257393283, 0.9337983566017154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 111}], {
             RGBColor[
             0.8397873767221564, 0.5455755079920095, 0.5794773016000505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 117}], {
             RGBColor[
             0.7057471364084966, 0.7690367194392469, 0.9721131675946504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 202}], {
             RGBColor[
             0.590277084299675, 0.6718791600205865, 0.9639661767270546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 212}], {
             RGBColor[
             0.715371093239261, 0.7768498811487758, 0.9728708007300837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 239}], {
             RGBColor[
             0.6800499902731076, 0.7481746185632971, 0.9700901941191247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 247}], {
             RGBColor[
             0.8351507068562677, 0.5099360316010974, 0.5750372213001058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 269}], {
             RGBColor[
             0.6031830035578256, 0.6830576186116337, 0.9647885304899277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 287}], {
             RGBColor[
             0.8351408344121083, 0.5098601476691562, 0.5750277674364295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 289}], {
             RGBColor[
             0.6635885313279589, 0.7348104646113509, 0.9687942877706517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 292}], {
             RGBColor[
             0.8362272767124428, 0.5182110192715781, 0.5760681458101908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 303}], {
             RGBColor[
             0.873446363467674, 0.7484181435664192, 0.6095212570798225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 309}], {
             RGBColor[
             0.7751646817101416, 0.8245503622153614, 0.9781540938970312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 362}], {
             RGBColor[
             0.8221167873663267, 0.8612297040031928, 0.982833840996466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 385}], {
             RGBColor[
             0.923690126192328, 0.9380306979900004, 0.809802069993292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 400}], {
             RGBColor[
             0.8375389435666232, 0.5282930654888892, 0.5773241994710698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 199}], {
             RGBColor[
             0.9076739184987976, 0.597583839511456, 0.5047291662889358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 222}], {
             RGBColor[
             0.8888497880747033, 0.5842997162159619, 0.5703986830647514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 223}], {
             RGBColor[
             0.8429142052274374, 0.3295868808857362, 0.18867802924559862`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 247}], {
             RGBColor[
             0.8219754147542075, 0.16991824425479435`, 0.1686769880272973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 271}], {
             RGBColor[
             0.823307418706283, 0.18015661031829988`, 0.16995251651608806`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 287}], {
             RGBColor[
             0.8219655423100481, 0.16984236032285321`, 0.168667534163621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 292}], {
             RGBColor[
             0.8230519846103825, 0.1781932319252751, 0.16970791253738232`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 309}], {
             RGBColor[
             0.7619893896080814, 0.48453257486905843`, 0.5717938606242228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 319}], {
             RGBColor[
             0.8295282339464709, 0.2279725222330049, 0.17590957621549802`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 362}], {
             RGBColor[
             0.8089414952642664, 0.5212119166568898, 0.5764736077236575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 385}], {
             RGBColor[
             0.9105148340902678, 0.5980129106436974, 0.4034418367204835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[
             0.8243636514645629, 0.1882752781425862, 0.17096396619826132`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 177}], {
             RGBColor[
             0.18091855533538903`, 0.3074872509293952, 0.9336144161301083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 219}], {
             RGBColor[
             0.17968380010062157`, 0.30618944488965105`, 0.933544098646145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 248}], {
             RGBColor[
             0.18167669359362687`, 0.3082841023075451, 0.9336575909823499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 251}], {
             RGBColor[
             0.18268323345773074`, 0.30934203952303163`, 0.9337149119385684]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 260}], {
             RGBColor[
             0.18468581634927816`, 0.3114468811131368, 0.9338289560716861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 162}], {
             RGBColor[
             0.19047273002269705`, 0.31752929429541876`, 0.9341585122444157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 183}], {
             RGBColor[
             0.18716623928349274`, 0.31405396288489373`, 0.9339702124883327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 270}], {
             RGBColor[
             0.196796775846464, 0.3241762674238618, 0.9345186572984918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 357}], {
             RGBColor[
             0.18582607626581804`, 0.31264536658207454`, 0.9338938921870696]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 368}], {
             RGBColor[
             0.18474082389280244`, 0.3115046975290605, 0.9338320886699134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 132}], {
             RGBColor[
             0.1897759122485969, 0.31679689463404087`, 0.9341188295030303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 155}], {
             RGBColor[
             0.18628873221551898`, 0.3131316473192917, 0.933920239758967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 180}], {
             RGBColor[
             0.18755106204056693`, 0.3144584360017507, 0.9339921275750538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 249}], {
             RGBColor[
             0.18514988407402466`, 0.3119346457154385, 0.9338553840420838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 268}], {
             RGBColor[
             0.18716896902427724`, 0.3140568320155338, 0.9339703679430321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 279}], {
             RGBColor[
             0.19285735565451845`, 0.32003568702846064`, 0.9342943131464105]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 299}], {
             RGBColor[
             0.1875337477163088, 0.31444023754916384`, 0.9339911415499016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 300}], {
             RGBColor[
             0.19141939910096473`, 0.3185243035189643, 0.9342124236479517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 370}], {
             RGBColor[
             0.18611224246754757`, 0.3129461454040774, 0.9339101889289132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 123}], {
             RGBColor[
             0.8991328422336753, 0.5962300691178152, 0.23584910998017405`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 161}], {
             RGBColor[
             0.9173271064366133, 0.7028272968686928, 0.25196989849468676`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 193}], {
             RGBColor[
             0.8965180032601808, 0.866664933881647, 0.6335702357029284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 195}], {
             RGBColor[
             0.6898630728334411, 0.7009647207638414, 0.6155071113240207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 214}], {
             RGBColor[
             0.917014626987943, 0.7014084006737106, 0.2517091579831441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 253}], {
             RGBColor[
             0.8901501343784577, 0.5271850402949314, 0.22724725879350022`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 257}], {
             RGBColor[
             0.9622640683610495, 0.9182194829930534, 0.6096923191590835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 283}], {
             RGBColor[
             0.9435152073287729, 0.813763650039597, 0.2734092138294835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 312}], {
             RGBColor[
             0.7514622050621471, 0.7517529361696669, 0.6201411074573389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 332}], {
             RGBColor[
             0.8864563951040925, 0.498793341625289, 0.2237101298928862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 334}], {
             RGBColor[
             0.9576597296930937, 0.8685855926092536, 0.2913334520501617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 356}], {
             RGBColor[
             0.9502457162134885, 0.9092562156396481, 0.6300362544566458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 360}], {
             RGBColor[
             0.8089316906478522, 0.7980968050279984, 0.6248789386336926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 364}], {
             RGBColor[
             0.9382231077008898, 0.7927822385027005, 0.26915106624734497`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 366}], {
             RGBColor[
             0.9742039651565302, 0.9239012646538212, 0.3974339190185809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 380}], {
             RGBColor[
             0.8377450255090341, 0.8206060012110092, 0.627750782576732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 389}], {
             RGBColor[
             0.9741155744429982, 0.9237122058552483, 0.3878131353348738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 141}], {
             RGBColor[
             0.29789401265983945`, 0.4260884769462017, 0.9404351748499746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 179}], {
             RGBColor[
             0.23341719737643146`, 0.3626666523206874, 0.9366041361295647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 209}], {
             RGBColor[
             0.2525333735524159, 0.38275896551722044`, 0.9376927740829386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 286}], {
             RGBColor[
             0.28063230469456346`, 0.41113725310534854`, 0.9393352740823563]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 290}], {
             RGBColor[
             0.24877546734729164`, 0.3788091678306199, 0.9374787668838809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 304}], {
             RGBColor[
             0.26114585574207083`, 0.3918112303614577, 0.938183242202614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 338}], {
             RGBColor[
             0.22507866009155236`, 0.35390232094047974`, 0.9361292687669514]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 239}], {
             RGBColor[
             0.5328344578573876, 0.6316180426642315, 0.9563658268409162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 269}], {
             RGBColor[
             0.45596747114210545`, 0.5665010427125681, 0.9510641632117192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 309}], {
             RGBColor[
             0.6279491492944215, 0.7079937863162957, 0.9644297266188226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 323}], {
             RGBColor[
             0.4895767347577772, 0.5956116976057565, 0.9532057157698048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 362}], {
             RGBColor[
             0.6749012549506066, 0.7446731281041272, 0.9691094737182575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 365}], {
             RGBColor[
             0.4322742926857367, 0.5457268859697086, 0.94956369337159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 377}], {
             RGBColor[
             0.40661285819624315`, 0.5187550912923315, 0.9481023126401036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 385}], {
             RGBColor[
             0.776474593776608, 0.8214741220909348, 0.7960777027150834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 388}], {
             RGBColor[
             0.4146565458770389, 0.527209517044103, 0.9485603887539554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 395}], {
             RGBColor[
             0.49860624010091514`, 0.6034326012978481, 0.9537810678657916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 124}], {
             RGBColor[
             0.29203302591126107`, 0.41977282835890883`, 0.9401070895447208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[
             0.35660710592589273`, 0.4832968843838794, 0.9439436673476838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 150}], {
             RGBColor[
             0.29792702653421543`, 0.4259677967148573, 0.9404427441608055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 179}], {
             RGBColor[
             0.29213029064248475`, 0.4198750597583651, 0.9401126286272736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 196}], {
             RGBColor[
             0.6007859963931654, 0.6812853787799371, 0.9644958808837701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 206}], {
             RGBColor[
             0.39316789594043106`, 0.5149640030957358, 0.9462732885579729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 209}], {
             RGBColor[
             0.3112464668184692, 0.43996737295489813`, 0.9412012665806477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 286}], {
             RGBColor[
             0.33934539796061675`, 0.46834566054302623`, 0.9428437665800653]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 386}], {
             RGBColor[
             0.34968714140668505`, 0.4773031589248714, 0.9435027333276041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 128}], {
             RGBColor[
             0.2718458799395796, 0.4030576342137573, 0.9387925927513947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 130}], {
             RGBColor[
             0.2277266187202509, 0.3566854933495158, 0.936280066093552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 135}], {
             RGBColor[
             0.2875725376828968, 0.4171271414972289, 0.9397782828791128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 146}], {
             RGBColor[
             0.2194595639056427, 0.3479962945778132, 0.9358092695518716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 151}], {
             RGBColor[
             0.22370106658388367`, 0.35245438281944674`, 0.9360508168546565]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 213}], {
             RGBColor[
             0.2826015926364835, 0.4128215587449884, 0.9394615386563896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 227}], {
             RGBColor[
             0.25689083303762017`, 0.3873389317150586, 0.9379409249543373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 243}], {
             RGBColor[
             0.23559188807996673`, 0.3649523901334573, 0.9367279815479644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 267}], {
             RGBColor[
             0.21867692760035795`, 0.34717369419895117`, 0.9357646995720923]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 306}], {
             RGBColor[
             0.2310448890646134, 0.36017320587193224`, 0.9364690366807222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 311}], {
             RGBColor[
             0.22119300122602184`, 0.3498182471078057, 0.9359079862428765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 344}], {
             RGBColor[
             0.2156761634002051, 0.3440197007651513, 0.9355938104901265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 346}], {
             RGBColor[
             0.2216080062797242, 0.35025444373208703`, 0.9359316201667398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 350}], {
             RGBColor[
             0.2941675459212899, 0.42283940615857285`, 0.9401985109723265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 354}], {
             RGBColor[
             0.21794551615801888`, 0.3464049343988889, 0.9357230467724773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 140}], {
             RGBColor[
             0.409447183861318, 0.5290643040720063, 0.9473105903890827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 147}], {
             RGBColor[
             0.3298813986080268, 0.4544594666479659, 0.9424490293594527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 193}], {
             RGBColor[
             0.6252379224927019, 0.7026774950776031, 0.9659558403883122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 195}], {
             RGBColor[
             0.41858299206596217`, 0.5369772819597975, 0.9478927160094046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 241}], {
             RGBColor[
             0.34672955885014695`, 0.4721679512974918, 0.9434085071606221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 242}], {
             RGBColor[
             0.3764731339021319, 0.500503839321299, 0.9452095130834909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 255}], {
             RGBColor[
             0.39336824955180094`, 0.5151375393238391, 0.9462860549129236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 263}], {
             RGBColor[
             0.3571898835204337, 0.4831624157488532, 0.9440042071759314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 312}], {
             RGBColor[
             0.4801821242946682, 0.587765497365623, 0.9525267121427227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 331}], {
             RGBColor[
             0.3267582826576653, 0.45117687376714777`, 0.9422711725263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 356}], {
             RGBColor[
             0.6789656354460096, 0.7452687768356042, 0.9624218591420297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 359}], {
             RGBColor[
             0.3691186833876108, 0.4941337839310517, 0.9447408939999908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 360}], {
             RGBColor[
             0.5376516098803733, 0.6341093662239545, 0.9572645433190765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 380}], {
             RGBColor[
             0.5664649447415552, 0.6566185624069654, 0.9601363872621158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 389}], {
             RGBColor[
             0.7028354936755193, 0.7597247670512044, 0.7201987400202577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[
             0.2188856606362972, 0.3473930858541622, 0.9357765866096961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 202}], {
             RGBColor[
             0.2856578369982738, 0.41583248159385067`, 0.9396429608971655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 234}], {
             RGBColor[
             0.2453302072944222, 0.37518798107295015`, 0.9372825644206755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 289}], {
             RGBColor[
             0.3589692840265578, 0.4787637861846151, 0.9444710719407625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 298}], {
             RGBColor[
             0.2245949434093795, 0.353393904038107, 0.9361017218174963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 173}], {
             RGBColor[
             0.18447873947082444`, 0.3112292301844495, 0.9338171633498009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 338}], {
             RGBColor[
             0.19975108063826336`, 0.32728142907378543`, 0.9346869005858826]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 161}], {
             RGBColor[
             0.861352076814639, 0.4393326641242953, 0.20508206465224244`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 196}], {
             RGBColor[
             0.8436412079731275, 0.6056407490965849, 0.5869779142171753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 214}], {
             RGBColor[
             0.8610395973659686, 0.437913767929313, 0.20482132414069976`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 253}], {
             RGBColor[
             0.8341751047564834, 0.26369040755053386`, 0.1803594249510559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 283}], {
             RGBColor[
             0.8875401777067986, 0.5502690172951994, 0.2265213799870392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 332}], {
             RGBColor[
             0.8304813654821182, 0.2352987088808914, 0.17682229605044186`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 334}], {
             RGBColor[
             0.9016847000711192, 0.6050909598648562, 0.2444456182077174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 356}], {
             RGBColor[
             0.8942706865915142, 0.6457615828952505, 0.5831484206142015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 364}], {
             RGBColor[
             0.8822480780789155, 0.5292876057583029, 0.22226323240490067`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 366}], {
             RGBColor[
             0.9182289355345559, 0.6604066319094237, 0.35054608517613656`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 389}], {
             RGBColor[
             0.9181405448210238, 0.6602175731108506, 0.3409253014924295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 150}], {
             RGBColor[
             0.2325126629936997, 0.36171592933364405`, 0.9365526242346068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 152}], {
             RGBColor[
             0.2137312689052459, 0.34197549333751603`, 0.935483051625852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 156}], {
             RGBColor[
             0.21424517968646528`, 0.3425156461524031, 0.9355123180845796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 157}], {
             RGBColor[
             0.2367400113323198, 0.3661591404668991, 0.9367933654686897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 160}], {
             RGBColor[
             0.21095706740892387`, 0.3390596316703475, 0.9353250649546998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 167}], {
             RGBColor[
             0.23121257205082407`, 0.360349451322155, 0.9364785859787222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 179}], {
             RGBColor[
             0.22671592710196903`, 0.3556231923771518, 0.9362225087010749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 181}], {
             RGBColor[
             0.209370470104526, 0.33739201730734614`, 0.9352347105853747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 238}], {
             RGBColor[
             0.21375043106969976`, 0.3419956339873084, 0.9354841428827698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 245}], {
             RGBColor[
             0.21075638483913717`, 0.33884870156549185`, 0.9353136363792337]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 386}], {
             RGBColor[
             0.28427277786616933`, 0.41305129154365816`, 0.9396126134014054]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 184}], {
             RGBColor[
             0.20307558723579205`, 0.3307756962936808, 0.934876226318445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 185}], {
             RGBColor[
             0.1925739180479394, 0.31973777613296384`, 0.9342781717940241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 190}], {
             RGBColor[
             0.20237543357367466`, 0.3300397904024893, 0.934836353603172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 226}], {
             RGBColor[
             0.1922514050569324, 0.3193987945309108, 0.9342598051563016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 252}], {
             RGBColor[
             0.19926974690677848`, 0.32677551680367367`, 0.934659489341944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 274}], {
             RGBColor[
             0.19786901158433057`, 0.32530325516803194`, 0.9345797195375327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 288}], {
             RGBColor[
             0.2031660717843796, 0.3308708012912981, 0.9348813792796271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 318}], {
             RGBColor[
             0.20302734583193666`, 0.33072499151954715`, 0.9348734790418622]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 176}], {
             RGBColor[
             0.18438193895865332`, 0.3111274867086507, 0.9338116507038363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 205}], {
             RGBColor[
             0.18385657240612066`, 0.31057529315177557`, 0.9337817318558796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 298}], {
             RGBColor[
             0.194012535572622, 0.32124985436502457`, 0.9343600989338109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 320}], {
             RGBColor[
             0.18313368370358218`, 0.3098154912916167, 0.9337405644136882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 347}], {
             RGBColor[
             0.18344187738111917`, 0.31013942238731573`, 0.9337581155876922]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 373}], {
             RGBColor[
             0.19027225530167013`, 0.317318582652788, 0.934147095505629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 137}], {
             RGBColor[
             0.31600670483300364`, 0.4466421785419929, 0.9414111535240912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 138}], {
             RGBColor[
             0.31413697275722113`, 0.44467697158248487`, 0.9413046750483962]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 193}], {
             RGBColor[
             0.5886484429999097, 0.6709855269816585, 0.9636243911098379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 210}], {
             RGBColor[
             0.29252473138981117`, 0.4219611356100898, 0.9400738898749681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 242}], {
             RGBColor[
             0.33988365440933965`, 0.4688118712253543, 0.9428780638050165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 255}], {
             RGBColor[
             0.35677877005900877`, 0.4834455712278943, 0.9439546056344492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 258}], {
             RGBColor[
             0.2885106861095953, 0.4177421195154126, 0.9398452959345076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 264}], {
             RGBColor[
             0.2996738393944105, 0.42947530140255136`, 0.9404810209996725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 312}], {
             RGBColor[
             0.44359264480187605`, 0.5560735292696781, 0.9501952628642483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 328}], {
             RGBColor[
             0.2853602010040631, 0.41443075991720546`, 0.9396658804684725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 331}], {
             RGBColor[
             0.29016880316487315`, 0.419484905671203, 0.9399397232478413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 380}], {
             RGBColor[
             0.529875465248763, 0.6249265943110206, 0.9578049379836415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 394}], {
             RGBColor[
             0.348496932711213, 0.47627225997448197`, 0.9434268942819889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 130}], {
             RGBColor[
             0.2597826750311079, 0.39037844100358665`, 0.9381056110777697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 135}], {
             RGBColor[
             0.31962859399375376`, 0.45082008915129973`, 0.9416038278633306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 139}], {
             RGBColor[
             0.3054227451460619, 0.43834904844198347`, 0.9407047455523833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 151}], {
             RGBColor[
             0.2557571228947407, 0.38614733047351757`, 0.9378763618388744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 213}], {
             RGBColor[
             0.3146576489473405, 0.4465145063990592, 0.9412870836406073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 215}], {
             RGBColor[
             0.5049864538136, 0.6035289290681363, 0.9559781758101122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 224}], {
             RGBColor[
             0.40082474260241224`, 0.5199417456186857, 0.9471108972900512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 227}], {
             RGBColor[
             0.28894688934847723`, 0.42103187936912945`, 0.9397664699385552]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 243}], {
             RGBColor[
             0.26764794439082373`, 0.39864533778752814`, 0.9385535265321823]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 259}], {
             RGBColor[
             0.599663278641086, 0.6781009426487141, 0.9652528657581285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 306}], {
             RGBColor[
             0.2631009453754704, 0.39386615352600307`, 0.9382945816649401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 350}], {
             RGBColor[
             0.32622360223214686`, 0.4565323538126437, 0.9420240559565443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 383}], {
             RGBColor[
             0.3311097462205182, 0.46076448615063337`, 0.9423353967308358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 131}], {
             RGBColor[
             0.8167235345760251, 0.5021703426652091, 0.5741281307411844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 253}], {
             RGBColor[
             0.822264279381292, 0.17213858435985327`, 0.16895360512041946`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 271}], {
             RGBColor[
             0.8196694573268939, 0.15219364499147486`, 0.1664688005906955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 287}], {
             RGBColor[
             0.8183275809306592, 0.1418793949960282, 0.16518381823822845`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 303}], {
             RGBColor[
             0.8566331099862248, 0.3804373908932912, 0.19967730788162147`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 333}], {
             RGBColor[
             0.8865563472760825, 0.5573394921368233, 0.5646390445032476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 337}], {
             RGBColor[
             0.8881576917970897, 0.5585337722586294, 0.5619283859267235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 353}], {
             RGBColor[
             0.9062979809873158, 0.5688117544551025, 0.33694932919085196`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 364}], {
             RGBColor[
             0.8703372527037241, 0.4377357825676223, 0.21085741257426427`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 391}], {
             RGBColor[
             0.8197851875316053, 0.15308319805818565`, 0.1665796239654257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 135}], {
             RGBColor[
             0.27550933277442513`, 0.40444794828705827`, 0.9390913012054878]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 146}], {
             RGBColor[
             0.20739635899717102`, 0.3353171013676426, 0.9351222878782466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 151}], {
             RGBColor[
             0.211637861675412, 0.3397751896092761, 0.9353638351810314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 158}], {
             RGBColor[
             0.20340188077088672`, 0.3311186514872704, 0.9348948082525605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 227}], {
             RGBColor[
             0.24482762812914852`, 0.374659738504888, 0.9372539432807123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 243}], {
             RGBColor[
             0.22352868317149505`, 0.3522731969232867, 0.9360409998743393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 267}], {
             RGBColor[
             0.20661372269188627`, 0.33449450098878053`, 0.9350777178984673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 275}], {
             RGBColor[
             0.2049038205781411, 0.33269728545317867`, 0.934980341502663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 306}], {
             RGBColor[
             0.21898168415614172`, 0.3474940126617616, 0.9357820550070972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 311}], {
             RGBColor[
             0.20912979631755016`, 0.33713905389763504`, 0.9352210045692514]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 317}], {
             RGBColor[
             0.20208377375464914`, 0.3297332374403929, 0.9348197440079504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 344}], {
             RGBColor[
             0.20361295849173341`, 0.3313405075549807, 0.9349068288165013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 346}], {
             RGBColor[
             0.20954480137125253`, 0.3375752505219164, 0.9352446384931148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 354}], {
             RGBColor[
             0.2058823112495472, 0.3337257411887183, 0.9350360650988523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 142}], {
             RGBColor[
             0.6441352636384634, 0.7193460306737178, 0.9669266768382974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 201}], {
             RGBColor[
             0.7399124857733206, 0.7967445245200704, 0.9747112197727283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 273}], {
             RGBColor[
             0.6690783888345512, 0.7395959833828867, 0.9688902910234116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 281}], {
             RGBColor[
             0.6064310569728814, 0.687254440774864, 0.9643678385927457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 293}], {
             RGBColor[
             0.5641203291112874, 0.6506070149001673, 0.9616718364273125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 303}], {
             RGBColor[
             0.8540204827009316, 0.7329759435664439, 0.607655802146349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 391}], {
             RGBColor[
             0.817172560246312, 0.5056217507313383, 0.5745581182301532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 394}], {
             RGBColor[
             0.585868010689025, 0.6694437636125451, 0.9630575794667262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 149}], {
             RGBColor[
             0.20160011613108555`, 0.32922488261236305`, 0.9347922004217959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 155}], {
             RGBColor[
             0.18938684794258642`, 0.3163879633803221, 0.934096672866372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 180}], {
             RGBColor[
             0.1906491777676344, 0.3177147520627811, 0.9341685606824588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 249}], {
             RGBColor[
             0.18824799980109214`, 0.3151909617764689, 0.9340318171494888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 268}], {
             RGBColor[
             0.19026708475134468`, 0.3173131480765642, 0.9341468010504371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 279}], {
             RGBColor[
             0.1959554713815859, 0.323292003089491, 0.9344707462538155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 299}], {
             RGBColor[
             0.19063186344337624`, 0.3176965536101942, 0.9341675746573066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 300}], {
             RGBColor[
             0.1945175148280322, 0.3217806195799947, 0.9343888567553567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 370}], {
             RGBColor[
             0.189210358194615, 0.3162024614651078, 0.9340866220363182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 178}], {
             RGBColor[
             0.18320632976714918`, 0.309891846910452, 0.9337447014995381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 200}], {
             RGBColor[
             0.18872606349581567`, 0.31569343703061226`, 0.9340590421696713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 278}], {
             RGBColor[
             0.18574944160901402`, 0.31256481869885566`, 0.9338895279567354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 296}], {
             RGBColor[
             0.18124069831826523`, 0.30782584362944293`, 0.9336327616964153]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 320}], {
             RGBColor[
             0.18355649439985816`, 0.3102598921411492, 0.9337646428573487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 330}], {
             RGBColor[
             0.1860526851696524, 0.3128835469078388, 0.9339067972289052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 347}], {
             RGBColor[
             0.18386468807739512`, 0.3105838232368483, 0.9337821940313528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 367}], {
             RGBColor[
             0.18474901765317286`, 0.31151330969072427`, 0.9338325552924449]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 398}], {
             RGBColor[
             0.18210607446438823`, 0.30873540882703493`, 0.9336820435877278]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 163}], {
             RGBColor[
             0.17908461226291875`, 0.3055596604815222, 0.9335099757852068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 171}], {
             RGBColor[
             0.18358417843459812`, 0.31028898981693004`, 0.9337662194221723]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 240}], {
             RGBColor[
             0.17922390736570504`, 0.3057060684663703, 0.9335179084352418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 272}], {
             RGBColor[
             0.18788317693480855`, 0.3148075098128992, 0.9340110410269609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 342}], {
             RGBColor[
             0.18275455563161122`, 0.309417003649867, 0.9337189736308591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 374}], {
             RGBColor[
             0.18137577945827954`, 0.307967822472237, 0.9336404543675045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 213}], {
             RGBColor[
             0.33038430669065766`, 0.46058401368253077`, 0.9422727737683254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 215}], {
             RGBColor[
             0.5207131115569171, 0.6175984363516078, 0.9569638659378303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 224}], {
             RGBColor[
             0.41655140034572946`, 0.5340112529021572, 0.9480965874177693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 227}], {
             RGBColor[
             0.3046735470917944, 0.4351013866526011, 0.9407521600662733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 243}], {
             RGBColor[
             0.2833746021341409, 0.41271484507099976`, 0.9395392166599004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 259}], {
             RGBColor[
             0.6153899363844033, 0.6921704499321857, 0.9662385558858466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 350}], {
             RGBColor[
             0.3419502599754641, 0.47060186109611535`, 0.9430097460842624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 363}], {
             RGBColor[
             0.3549405295448861, 0.4818533796872159, 0.9438374745743816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 383}], {
             RGBColor[
             0.3468364039638354, 0.47483399343410504`, 0.9433210868585539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 393}], {
             RGBColor[
             0.5286635054610748, 0.6238093444947674, 0.9577562869015417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 149}], {
             RGBColor[
             0.19648120536399588`, 0.3238445828384636, 0.9345006860263599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 155}], {
             RGBColor[
             0.18426793717549678`, 0.3110076636064226, 0.933805158470936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 268}], {
             RGBColor[
             0.18514817398425504`, 0.3119328483026647, 0.9338552866550012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 279}], {
             RGBColor[
             0.19083656061449622`, 0.3179117033155916, 0.9341792318583795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 299}], {
             RGBColor[
             0.1855129526762866, 0.3123162538362948, 0.9338760602618706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 300}], {
             RGBColor[
             0.18939860406094253`, 0.3164003198060953, 0.9340973423599207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 371}], {
             RGBColor[
             0.1813347042579621, 0.3079246498323852, 0.9336381151956117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 138}], {
             RGBColor[
             0.29077492625511725`, 0.4229532620622423, 0.93987057393605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 164}], {
             RGBColor[
             0.2538187120761361, 0.3841099378008197, 0.9377659722103766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 210}], {
             RGBColor[
             0.2691626848877073, 0.40023742608984725`, 0.9386397887626219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 230}], {
             RGBColor[
             0.2568850160495337, 0.38733281769176137`, 0.9379405936854713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 242}], {
             RGBColor[
             0.31652160790723577`, 0.4470881617051118, 0.9414439626926704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 258}], {
             RGBColor[
             0.2651486396074914, 0.3960184099951701, 0.9384111948221615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 264}], {
             RGBColor[
             0.27631179289230656`, 0.4077515918823088, 0.9390469198873264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 328}], {
             RGBColor[
             0.2619981545019592, 0.39270705039696285`, 0.9382317793561266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 394}], {
             RGBColor[
             0.32513488620910913`, 0.45454855045423936`, 0.9419927931696428]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 149}], {
             RGBColor[
             0.2496156992329207, 0.3796923048161946, 0.9375266168467558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 164}], {
             RGBColor[
             0.2519489800003536, 0.38214473084131173`, 0.9376594937346815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 210}], {
             RGBColor[
             0.2672929528119248, 0.3982722191303392, 0.9385333102869269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 230}], {
             RGBColor[
             0.2550152839737512, 0.38536761073225334`, 0.9378341152097762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 242}], {
             RGBColor[
             0.31465187583145326`, 0.4451229547456037, 0.9413374842169753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 258}], {
             RGBColor[
             0.26327890753170885`, 0.39405320303566205`, 0.9383047163464664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 264}], {
             RGBColor[
             0.27444206081652406`, 0.4057863849228008, 0.9389404414116314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 281}], {
             RGBColor[
             0.3438282004171828, 0.4703940206570502, 0.9431965738199672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 328}], {
             RGBColor[
             0.2601284224261766, 0.3907418434374549, 0.9381253008804314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 394}], {
             RGBColor[
             0.32326515413332657`, 0.4525833434947314, 0.9418863146939478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 186}], {
             RGBColor[
             0.2567623305791477, 0.38720386748367763`, 0.9379336069294297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 213}], {
             RGBColor[
             0.3161784578429658, 0.4481129729732145, 0.941373691457378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 215}], {
             RGBColor[
             0.5065072627092252, 0.6051273956422916, 0.956064783626883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 306}], {
             RGBColor[
             0.2646217542710957, 0.39546462010015837`, 0.9383811894817108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 308}], {
             RGBColor[
             0.25989565930435055`, 0.3904971946383813, 0.9381120453649856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 345}], {
             RGBColor[
             0.5675136417908162, 0.652851509744995, 0.962127956401694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 350}], {
             RGBColor[
             0.3277444111277722, 0.4581308203867991, 0.942110663773315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 378}], {
             RGBColor[
             0.27359029407982893`, 0.40489112407740385`, 0.9388919345560525]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 147}], {
             RGBColor[
             0.32678087214865287`, 0.45177394646584723`, 0.9422514665551494]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 193}], {
             RGBColor[
             0.6221373960333281, 0.6999919748954846, 0.9657582775840088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 195}], {
             RGBColor[
             0.4154824656065883, 0.5342917617776789, 0.9476951532051012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 241}], {
             RGBColor[
             0.343629032390773, 0.46948243111537313`, 0.9432109443563187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 242}], {
             RGBColor[
             0.3733726074427579, 0.4978183191391804, 0.9450119502791875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 255}], {
             RGBColor[
             0.390267723092427, 0.5124520191417203, 0.9460884921086202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 263}], {
             RGBColor[
             0.35408935706105976`, 0.48047689556673456`, 0.943806644371628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 312}], {
             RGBColor[
             0.4770815978352943, 0.5850799771835042, 0.9523291493384193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 331}], {
             RGBColor[
             0.3236577561982914, 0.4484913535850291, 0.9420736097220124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 356}], {
             RGBColor[
             0.6758651089866358, 0.7425832566534856, 0.9622242963377263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 359}], {
             RGBColor[
             0.36601815692823686`, 0.491448263748933, 0.9445433311956875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 360}], {
             RGBColor[
             0.5345510834209994, 0.6314238460418358, 0.9570669805147731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 380}], {
             RGBColor[
             0.5633644182821813, 0.6539330422248467, 0.9599388244578124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 389}], {
             RGBColor[
             0.6997349672161455, 0.7570392468690857, 0.7200011772159544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 179}], {
             RGBColor[
             0.2912900071166007, 0.41914724840212236`, 0.9400590865040379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 196}], {
             RGBColor[
             0.5999457128672814, 0.6805575674236943, 0.9644423387605343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 209}], {
             RGBColor[
             0.3104061832925851, 0.4392395615986554, 0.9411477244574119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 286}], {
             RGBColor[
             0.3385051144347327, 0.4676178491867835, 0.9427902244568296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 290}], {
             RGBColor[
             0.3066482770874609, 0.4352897639120549, 0.9409337172583541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 304}], {
             RGBColor[
             0.31901866548224, 0.4482918264428926, 0.9416381925770871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 386}], {
             RGBColor[
             0.348846857880801, 0.4765753475686286, 0.9434491912043683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.37498442055197767`, 0.49560326154572176`, 0.9453825139194686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 201}], {
             RGBColor[
             0.5699368421210522, 0.6613816598554264, 0.9595312716051138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 273}], {
             RGBColor[
             0.4991027451822828, 0.6042331187182427, 0.9537103428557971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 281}], {
             RGBColor[
             0.436455413320613, 0.55189157611022, 0.9491878904251312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 293}], {
             RGBColor[
             0.3941446854590191, 0.5152441502355233, 0.946491888259698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 394}], {
             RGBColor[
             0.4158923670367568, 0.5340808989479011, 0.9478776312991117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 151}], {
             RGBColor[
             0.2032578843654731, 0.3309673021352812, 0.934886607870296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 158}], {
             RGBColor[
             0.1950219034609478, 0.3223107640132754, 0.9344175809418251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 171}], {
             RGBColor[
             0.19347840745274208`, 0.320688451845352, 0.9343296811275554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 186}], {
             RGBColor[
             0.20274228315425485`, 0.3304253725712859, 0.9348572451440806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 272}], {
             RGBColor[
             0.19777740595295248`, 0.3252069718413211, 0.9345745027323441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 306}], {
             RGBColor[
             0.21060170684620283`, 0.33868612518776664`, 0.9353048276963617]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 308}], {
             RGBColor[
             0.2058756118794577, 0.33371869972598955`, 0.9350356835796365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 342}], {
             RGBColor[
             0.19264878464975516`, 0.3198164656782889, 0.9342824353362423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 348}], {
             RGBColor[
             0.20000377872339242`, 0.3275470307832401, 0.9347012913679973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 354}], {
             RGBColor[
             0.1975023339396083, 0.32491785371472337`, 0.9345588377881168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 374}], {
             RGBColor[
             0.1912700084764235, 0.3183672845006589, 0.9342039160728877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 378}], {
             RGBColor[
             0.21957024665493602`, 0.3481126291650121, 0.9358155727707034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 148}], {
             RGBColor[
             0.41890511783186646`, 0.5289568419765102, 0.9490497655266936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 169}], {
             RGBColor[
             0.5192579762174159, 0.6205960432553745, 0.9552970364739267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 218}], {
             RGBColor[
             0.5707667888209911, 0.662413217772521, 0.9593519988850778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 222}], {
             RGBColor[
             0.7661723613566251, 0.8169857716290115, 0.9639290713689532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 276}], {
             RGBColor[
             0.48015124453344243`, 0.5868307576532874, 0.952775625742377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 282}], {
             RGBColor[
             0.44814038646858245`, 0.5591045613100133, 0.9507359221725744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 305}], {
             RGBColor[
             0.4396583364184836, 0.550769790541102, 0.9502316306235659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 339}], {
             RGBColor[
             0.48160738498318656`, 0.5880919933231088, 0.9528684097242202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 361}], {
             RGBColor[
             0.4954156444114053, 0.6000520136165334, 0.9537482598048219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 382}], {
             RGBColor[
             0.451676599366216, 0.5621674511867154, 0.9509612465314614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 384}], {
             RGBColor[
             0.757420984754537, 0.7226612405223014, 0.6127983851533676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 165}], {
             RGBColor[
             0.23770682741222313`, 0.3671753254665574, 0.9368484242141641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 170}], {
             RGBColor[
             0.24268853638713495`, 0.37241141745778183`, 0.9371321251705074]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 182}], {
             RGBColor[
             0.24585035887698375`, 0.3757346933657375, 0.937312186283807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 192}], {
             RGBColor[
             0.25406976709764434`, 0.3843738125462326, 0.9377802694224489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 208}], {
             RGBColor[
             0.2721455459278671, 0.4033726021673685, 0.9388096582861116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 221}], {
             RGBColor[
             0.3098924284635012, 0.43739177601044266`, 0.941166351723109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 225}], {
             RGBColor[
             0.22917757181567264`, 0.3582105370485437, 0.9363626957258434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 235}], {
             RGBColor[
             0.22156110310920424`, 0.35020514552603776`, 0.9359289491005658]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 335}], {
             RGBColor[
             0.2240686969525251, 0.3528407856460005, 0.9360717528602902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 349}], {
             RGBColor[
             0.2241439081408365, 0.35291983737358057`, 0.9360760360261996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 351}], {
             RGBColor[
             0.2797139568415439, 0.4112527007055903, 0.9392434061971325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 355}], {
             RGBColor[
             0.22900678342998865`, 0.3580310276265808, 0.9363529695799375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 395}], {
             RGBColor[
             0.3442769835307749, 0.46717394939172724`, 0.9433573051669275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 151}], {
             RGBColor[
             0.20337080686080378`, 0.3310859908375735, 0.9348930386393511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 158}], {
             RGBColor[
             0.1951348259562785, 0.3224294527155677, 0.9344240117108803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 227}], {
             RGBColor[
             0.2365605733145403, 0.3659705397331854, 0.936783146739032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 243}], {
             RGBColor[
             0.21526162835688684`, 0.343583998151584, 0.9355702033326591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 267}], {
             RGBColor[
             0.19834666787727806`, 0.32580530221707793`, 0.9346069213567869]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 275}], {
             RGBColor[
             0.1966367657635329, 0.324008086681476, 0.9345095449609826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 306}], {
             RGBColor[
             0.2107146293415335, 0.33880481389005895`, 0.9353112584654169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 311}], {
             RGBColor[
             0.20086274150294195`, 0.3284498551259324, 0.9347502080275711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 317}], {
             RGBColor[
             0.19381671894004093`, 0.32104403866869025`, 0.9343489474662702]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 344}], {
             RGBColor[
             0.1953459036771252, 0.3226513087832781, 0.9344360322748211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 346}], {
             RGBColor[
             0.20127774655664432`, 0.3288860517502138, 0.9347738419514344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 354}], {
             RGBColor[
             0.197615256434939, 0.32503654241701563`, 0.9345652685571719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 195}], {
             RGBColor[
             0.3359166803532971, 0.45968692435363845`, 0.9428335921754714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 217}], {
             RGBColor[
             0.2277310230294914, 0.3566901225577769, 0.9362803169124476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 231}], {
             RGBColor[
             0.2192108871052112, 0.34773491949353985`, 0.9357951077759714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 241}], {
             RGBColor[
             0.2640632471374818, 0.3948775936913327, 0.9383493833266887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 242}], {
             RGBColor[
             0.29380682218946674`, 0.42321348171513995`, 0.9401503892495575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 255}], {
             RGBColor[
             0.3107019378391358, 0.4378471817176799, 0.9412269310789902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 312}], {
             RGBColor[
             0.3975158125820031, 0.5104751397594638, 0.9474675883087893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 331}], {
             RGBColor[
             0.2440919709450002, 0.37388651616098867`, 0.9372120486923824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 359}], {
             RGBColor[
             0.28645237167494564`, 0.4168434263248926, 0.9396817701660576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 392}], {
             RGBColor[
             0.2251386082236323, 0.35396533022822685`, 0.9361326827243879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 218}], {
             RGBColor[
             0.40841467546891774`, 0.5204402282772255, 0.9482239194761258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 228}], {
             RGBColor[
             0.2402804897849437, 0.36988040779990605`, 0.9369949904788982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 276}], {
             RGBColor[
             0.31779913118136904`, 0.44485776815799194`, 0.9416475463334251]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.285788273116509, 0.4171315718147177, 0.9396078427636225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 301}], {
             RGBColor[
             0.25321055434935075`, 0.3834707254705414, 0.9377313385275249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 305}], {
             RGBColor[
             0.2773062230664102, 0.4087968010458064, 0.939103551214614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 313}], {
             RGBColor[
             0.27058528986872044`, 0.4017326741232574, 0.9387208040117352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 339}], {
             RGBColor[
             0.3192552716311131, 0.4461190038278132, 0.9417403303152683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 340}], {
             RGBColor[
             0.263972502592159, 0.39478221542066183`, 0.9383442155590771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 361}], {
             RGBColor[
             0.33306353105933184`, 0.4580790241212378, 0.94262018039587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 382}], {
             RGBColor[
             0.2893244860141426, 0.42019446169141983`, 0.9398331671225094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 155}], {
             RGBColor[
             0.19811293609800762`, 0.3255596352976139, 0.9345936106777326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 164}], {
             RGBColor[
             0.21265948505393958`, 0.340848980554772, 0.9354220151210823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 210}], {
             RGBColor[
             0.22800345786551077`, 0.3569764688437995, 0.9362958316733276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 230}], {
             RGBColor[
             0.21572578902733716`, 0.34407186044571364`, 0.935596636596177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 258}], {
             RGBColor[
             0.22398941258529487`, 0.35275745274912235`, 0.9360672377328672]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 264}], {
             RGBColor[
             0.23515256587011008`, 0.3644906346362611, 0.9367029627980321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 268}], {
             RGBColor[
             0.19899317290676588`, 0.326484819993856, 0.9346437388617977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 279}], {
             RGBColor[
             0.20468155953700706`, 0.33246367500678287`, 0.9349676840651762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 299}], {
             RGBColor[
             0.19935795159879743`, 0.32686822552748607`, 0.9346645124686672]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 300}], {
             RGBColor[
             0.20324360298345337`, 0.33095229149728655`, 0.9348857945667173]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 328}], {
             RGBColor[
             0.22083892747976266`, 0.3494460931509151, 0.9358878222668322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 152}], {
             RGBColor[
             0.21962526952820027`, 0.3481704616934645, 0.9358187062419367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 156}], {
             RGBColor[
             0.22013918030941965`, 0.34871061450835156`, 0.9358479727006643]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 157}], {
             RGBColor[
             0.24263401195527415`, 0.3723541088228476, 0.9371290200847746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 160}], {
             RGBColor[
             0.2168510680318782, 0.345254600026296, 0.9356607195707846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 167}], {
             RGBColor[
             0.2371065726737784, 0.3665444196781035, 0.936814240594807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 179}], {
             RGBColor[
             0.23260992772492337`, 0.36181816073310025`, 0.9365581633171598]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 181}], {
             RGBColor[
             0.21526447072748034`, 0.3435869856632946, 0.9355703652014595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 206}], {
             RGBColor[
             0.33364753302286965`, 0.45690710407047097`, 0.9427188232478589]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 211}], {
             RGBColor[
             0.23544785722092995`, 0.3648010045685258, 0.9367197792036168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 238}], {
             RGBColor[
             0.21964443169265407`, 0.3481906023432569, 0.9358197974988545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 386}], {
             RGBColor[
             0.29016677848912364`, 0.4192462598996066, 0.9399482680174902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 158}], {
             RGBColor[
             0.19937632863451948`, 0.3268875409572013, 0.9346655590136652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 186}], {
             RGBColor[
             0.20709670832782653`, 0.33500214951521173`, 0.9351052232159208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 227}], {
             RGBColor[
             0.2408020759927813, 0.3704286279748189, 0.937024694041817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 267}], {
             RGBColor[
             0.20258817055551906`, 0.33026339045871145`, 0.9348484686595718]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 306}], {
             RGBColor[
             0.21495613201977448`, 0.3432629021316925, 0.9355528057682019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 308}], {
             RGBColor[
             0.2102300370530294, 0.33829547666991544`, 0.9352836616514766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 311}], {
             RGBColor[
             0.20510424418118295`, 0.33290794336756596`, 0.934991755330356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 317}], {
             RGBColor[
             0.1980582216182819, 0.3255021269103238, 0.9345904947690551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 344}], {
             RGBColor[
             0.1995874063553662, 0.3271093970249116, 0.9346775795776059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 346}], {
             RGBColor[
             0.2055192492348853, 0.3333441399918473, 0.9350153892542195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 348}], {
             RGBColor[
             0.20435820389696413`, 0.332123807727166, 0.9349492694398375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 354}], {
             RGBColor[
             0.20185675911317996`, 0.3294946306586492, 0.934806815859957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 156}], {
             RGBColor[
             0.20135778622096587`, 0.32897017851222354`, 0.9347784000919095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 157}], {
             RGBColor[
             0.22385261786682037`, 0.3526136728267195, 0.9360594474760198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 160}], {
             RGBColor[
             0.19806967394342445`, 0.325514164030168, 0.9345911469620297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 179}], {
             RGBColor[
             0.2138285336364696, 0.3420777247369723, 0.935488590708405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 181}], {
             RGBColor[
             0.1964830766390266, 0.32384654966716653`, 0.9345007925927047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 238}], {
             RGBColor[
             0.20086303760420032`, 0.32845016634712887`, 0.9347502248900996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 245}], {
             RGBColor[
             0.19786899137363773`, 0.3253032339253123, 0.9345797183865636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 168}], {
             RGBColor[
             0.20180786245057253`, 0.3294432371660213, 0.9348040312673576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 175}], {
             RGBColor[
             0.19789401206423968`, 0.32532953225753836`, 0.9345811432778787]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 211}], {
             RGBColor[
             0.21907020233692062`, 0.34758705088213704`, 0.9357870959865418]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 216}], {
             RGBColor[
             0.21073387590110806`, 0.33882504324447416`, 0.935312354528512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 229}], {
             RGBColor[
             0.2017865527982215, 0.3294208393702904, 0.934802817714181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 294}], {
             RGBColor[
             0.20769214048678164`, 0.33562798646685293`, 0.9351391321965103]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 329}], {
             RGBColor[
             0.23399514583317907`, 0.36327411279277777`, 0.9366370494391784]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 341}], {
             RGBColor[
             0.22749742981872606`, 0.3564446012825976, 0.9362670141246647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 343}], {
             RGBColor[
             0.20318561149837056`, 0.330891338769592, 0.9348824920374326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 358}], {
             RGBColor[
             0.24162422522743635`, 0.37129275894771363`, 0.9370715142244698]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 379}], {
             RGBColor[
             0.19405975897206282`, 0.32129948915197337`, 0.9343627882365483]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 207}], {
             RGBColor[
             0.18894498275511917`, 0.315923535052423, 0.9340715092976267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 231}], {
             RGBColor[
             0.18878970308862236`, 0.3157603262776354, 0.9340626663503354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 369}], {
             RGBColor[
             0.183389073095449, 0.31008392173509136`, 0.9337551084617403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 372}], {
             RGBColor[
             0.18315975702077553`, 0.3098428960011307, 0.9337420492505304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 387}], {
             RGBColor[
             0.18595738695423472`, 0.312783382441179, 0.9339013701365182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 392}], {
             RGBColor[
             0.19471742420704347`, 0.3219907370123223, 0.934400241298752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 249}], {
             RGBColor[
             0.18476081976801417`, 0.3115257144617197, 0.9338332274054255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 268}], {
             RGBColor[
             0.18677990471826675`, 0.31364790076181503`, 0.9339482113063738]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 279}], {
             RGBColor[
             0.19246829134850796`, 0.31962675577474187`, 0.9342721565097523]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.1871446834102983, 0.31403130629544507`, 0.9339689849132433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 300}], {
             RGBColor[
             0.19103033479495424`, 0.31811537226524556`, 0.9341902670112934]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 370}], {
             RGBColor[
             0.18572317816153708`, 0.3125372141503586, 0.9338880322922549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 371}], {
             RGBColor[
             0.18296643499197385`, 0.3096397022915355, 0.9337310398469844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 160}], {
             RGBColor[
             0.19858358472464382`, 0.32605431684505504`, 0.9346204134207573]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.21434244441768896`, 0.34261787755185935`, 0.9355178571671325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 181}], {
             RGBColor[
             0.19699698742024596`, 0.3243867024820536, 0.9345300590514323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 245}], {
             RGBColor[
             0.1983829021548571, 0.32584338674019936`, 0.9346089848452912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 352}], {
             RGBColor[
             0.19412861826228733`, 0.32137186463193046`, 0.9343667096712585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 396}], {
             RGBColor[
             0.19313485512094197`, 0.32032735656215416`, 0.9343101163304997]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 160}], {
             RGBColor[
             0.22107841637049833`, 0.349697811159551, 0.9359014608048675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 167}], {
             RGBColor[
             0.24133392101239853`, 0.37098763081135855`, 0.93705498182889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 168}], {
             RGBColor[
             0.222412865673202, 0.35110040198566517`, 0.9359774557185156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 203}], {
             RGBColor[
             0.2784354581733116, 0.40986687435040126`, 0.9391721369966093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 206}], {
             RGBColor[
             0.3378748813614898, 0.46135031520372605`, 0.942959564481942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 211}], {
             RGBColor[
             0.23967520555955008`, 0.36924421570178084`, 0.9369605204376998]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 238}], {
             RGBColor[
             0.22387178003127423`, 0.3526338134765119, 0.9360605387329375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 341}], {
             RGBColor[
             0.24810243304135554`, 0.37810176610224144`, 0.9374404385758228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 358}], {
             RGBColor[
             0.2622292284500658, 0.3929499237673575, 0.938244938675628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 386}], {
             RGBColor[
             0.2943941268277438, 0.42368947103286164`, 0.9401890092515732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 267}], {
             RGBColor[
             0.19435218965099377`, 0.3216068523367057, 0.934379441731101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 306}], {
             RGBColor[
             0.20672015111524922`, 0.33460636400968674`, 0.935083778839731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 308}], {
             RGBColor[
             0.20199405614850408`, 0.32963893854790965`, 0.9348146347230057]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 311}], {
             RGBColor[
             0.19686826327665763`, 0.3242514052455602, 0.9345227284018851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 317}], {
             RGBColor[
             0.18982224071375664`, 0.31684558878831803`, 0.9341214678405843]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 344}], {
             RGBColor[
             0.19135142545084088`, 0.31845285890290587`, 0.934208552649135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 346}], {
             RGBColor[
             0.19728326833036003`, 0.3246876018698416, 0.9345463623257486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 348}], {
             RGBColor[
             0.1961222229924388, 0.3234672696051602, 0.9344802425113666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 354}], {
             RGBColor[
             0.1936207782086547, 0.3208380925366434, 0.9343377889314861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 374}], {
             RGBColor[
             0.1873884527454699, 0.3142875233225789, 0.9339828672162569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 250}], {
             RGBColor[
             0.18793077615893167`, 0.3148575396154177, 0.934013751732358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 265}], {
             RGBColor[
             0.19056897353088317`, 0.3176304523247132, 0.9341639931698273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 321}], {
             RGBColor[
             0.1833474210515813, 0.31004014279609426`, 0.9337527364394607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 375}], {
             RGBColor[
             0.19246854917072223`, 0.3196270267622359, 0.9342721711923458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 381}], {
             RGBColor[
             0.18574510039169012`, 0.3125602558041992, 0.9338892807308311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[
             0.19370887514270452`, 0.320930687999998, 0.9343428059215524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 238}], {
             RGBColor[
             0.19808883610787825`, 0.32553430467996036`, 0.9345922382189475]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 245}], {
             RGBColor[
             0.19509478987731566`, 0.3223873722581438, 0.9344217317154114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 196}], {
             RGBColor[
             0.8618354721760655, 0.7122379768474625, 0.603098702731688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 214}], {
             RGBColor[
             0.8792338615689066, 0.5445109956801907, 0.22094211265521246`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 253}], {
             RGBColor[
             0.8523693689594214, 0.3702876353014115, 0.19648021346556857`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 283}], {
             RGBColor[
             0.9057344419097366, 0.6568662450460772, 0.2426421685015519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 332}], {
             RGBColor[
             0.848675629685056, 0.3418959366317691, 0.19294308456495457`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 334}], {
             RGBColor[
             0.9198789642740572, 0.7116881876157337, 0.2605664067222301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.9124649507944522, 0.7523588106461282, 0.5992692091287142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 364}], {
             RGBColor[
             0.9004423422818535, 0.6358848335091806, 0.23838402091941335`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 366}], {
             RGBColor[
             0.9364231997374939, 0.7670038596603013, 0.3666668736906492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 389}], {
             RGBColor[
             0.9363348090239618, 0.7668148008617284, 0.3570460900069422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 183}], {
             RGBColor[
             0.1919904214056781, 0.3191244841661233, 0.9342449425234534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 270}], {
             RGBColor[
             0.20162095796864934`, 0.3292467887050914, 0.9347933873336124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 280}], {
             RGBColor[
             0.20211294537388308`, 0.32976389866179523`, 0.9348214052885103]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 291}], {
             RGBColor[
             0.1953787311658639, 0.32268581255532547`, 0.9344379017517408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 336}], {
             RGBColor[
             0.21504897720554328`, 0.3433604883086603, 0.9355580931641793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 357}], {
             RGBColor[
             0.1906502583880034, 0.3177158878633042, 0.9341686222221902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 368}], {
             RGBColor[
             0.18956500601498782`, 0.31657521881029016`, 0.934106818705034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 171}], {
             RGBColor[
             0.18355378954190335`, 0.31025704916394076`, 0.9337644888196897]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 240}], {
             RGBColor[
             0.17919351847301027`, 0.305674127813381, 0.9335161778327592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 272}], {
             RGBColor[
             0.18785278804211375`, 0.3147755691599099, 0.9340093104244782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 342}], {
             RGBColor[
             0.18272416673891645`, 0.30938506299687774`, 0.9337172430283764]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 374}], {
             RGBColor[
             0.1813453905655848, 0.3079358818192477, 0.9336387237650219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 210}], {
             RGBColor[
             0.23033673863294363`, 0.3594288948689166, 0.9364287085612534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 230}], {
             RGBColor[
             0.21805906979477002`, 0.3465242864708308, 0.9357295134841028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 258}], {
             RGBColor[
             0.22632269335272776`, 0.3552098787742395, 0.936200114620793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 264}], {
             RGBColor[
             0.23748584663754294`, 0.36694306066137816`, 0.9368358396859577]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 279}], {
             RGBColor[
             0.20701484030443992`, 0.33491610103189995`, 0.9351005609531018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 328}], {
             RGBColor[
             0.22317220824719552`, 0.35189851917603227`, 0.9360206991547579]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 170}], {
             RGBColor[
             0.23052227294686206`, 0.35962390319639986`, 0.9364392744659576]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 172}], {
             RGBColor[
             0.3025819493818708, 0.42881009810169846`, 0.9407829073040905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 184}], {
             RGBColor[
             0.21954677082243013`, 0.3480879545765947, 0.9358142358567716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 190}], {
             RGBColor[
             0.21884661716031273`, 0.34735204868540315`, 0.9357743631414985]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 192}], {
             RGBColor[
             0.24190350365737148`, 0.3715862982848506, 0.9370874187178992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 221}], {
             RGBColor[
             0.29772616502322835`, 0.42460426174906063`, 0.9404735010185594]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 226}], {
             RGBColor[
             0.20872258864357046`, 0.33671105281382463`, 0.935197814694628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 252}], {
             RGBColor[
             0.21574093049341658`, 0.3440877750865875, 0.9355974988802704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 274}], {
             RGBColor[
             0.21434019517096867`, 0.34261551345094576`, 0.9355177290758593]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 288}], {
             RGBColor[
             0.2196372553710177, 0.3481830595742119, 0.9358193888179538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 318}], {
             RGBColor[
             0.21949852941857476`, 0.348037249802461, 0.9358114885801888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 322}], {
             RGBColor[
             0.2103258844391586, 0.3383962183498125, 0.9352891200183233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 351}], {
             RGBColor[
             0.26754769340127105`, 0.39846518644420825`, 0.9385505554925828]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 355}], {
             RGBColor[
             0.2168405199897158, 0.34524351336519876`, 0.9356601188753879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 399}], {
             RGBColor[
             0.2924581876891166, 0.42004140455849254`, 0.9401378301611192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 169}], {
             RGBColor[
             0.3512165772923903, 0.4726432539013666, 0.9438449606681389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 246}], {
             RGBColor[
             0.23093801406837325`, 0.3600608734746177, 0.9364629503077938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 326}], {
             RGBColor[
             0.24337300372818133`, 0.3731308360309576, 0.9371711045730012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 363}], {
             RGBColor[
             0.3098501203432949, 0.43692070785172515`, 0.9411795622408922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 383}], {
             RGBColor[
             0.3017459947622442, 0.42990132159861427`, 0.9406631745250644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 168}], {
             RGBColor[
             0.21688542639170627`, 0.3452907128409211, 0.935662676228548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.2729080188918158, 0.40405718520565725`, 0.9388573575066418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 211}], {
             RGBColor[
             0.23414776627805434`, 0.3634345265570368, 0.9366457409477322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 216}], {
             RGBColor[
             0.22581143984224178`, 0.35467251891937396`, 0.9361709994897025]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 238}], {
             RGBColor[
             0.2183443407497785, 0.3468241243317679, 0.9357457592429699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 341}], {
             RGBColor[
             0.2425749937598598, 0.37229207695749733`, 0.9371256590858552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 358}], {
             RGBColor[
             0.25670178916857006`, 0.3871402346226134, 0.9379301591856604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 211}], {
             RGBColor[
             0.2152267109388578, 0.3435472977313434, 0.935568214837358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 216}], {
             RGBColor[
             0.20689038450304525`, 0.3347852900936806, 0.9350934733793282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 238}], {
             RGBColor[
             0.19942328541058194`, 0.3269368955060745, 0.9346682331325956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 341}], {
             RGBColor[
             0.22365393842066325`, 0.35240484813180395`, 0.936048132975481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 379}], {
             RGBColor[
             0.190216267574, 0.31725973600117974`, 0.9341439070873645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 218}], {
             RGBColor[
             0.5087675338544672, 0.6120794295560898, 0.9544711904233589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 222}], {
             RGBColor[
             0.7041731063901011, 0.7666519834125803, 0.9590482629072343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 224}], {
             RGBColor[
             0.4775031351026399, 0.5866975822042433, 0.9520099424283488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 276}], {
             RGBColor[
             0.41815198956691846`, 0.5364969694368562, 0.947894817280658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 326}], {
             RGBColor[
             0.349415147686683, 0.47074983716853436`, 0.9437423719170701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 361}], {
             RGBColor[
             0.4334163894448813, 0.5497182254001022, 0.948867451343103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 363}], {
             RGBColor[
             0.4158922643017966, 0.5345397089893019, 0.947750829584961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 382}], {
             RGBColor[
             0.38967734439969204`, 0.5118336629702842, 0.9460804380697425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 383}], {
             RGBColor[
             0.4077881387207459, 0.527520322736191, 0.9472344418691334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 393}], {
             RGBColor[
             0.5896152402179853, 0.6764956737968535, 0.9616696419121211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[
             0.2468852126322833, 0.37682239027607506`, 0.9373711196742425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 208}], {
             RGBColor[
             0.26496099146250607`, 0.3958211798972109, 0.9384005085379051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 221}], {
             RGBColor[
             0.30270787399814014`, 0.42984035374028506`, 0.9407572019749026]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 225}], {
             RGBColor[
             0.22199301735031157`, 0.3506591147783862, 0.9359535459776369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 235}], {
             RGBColor[
             0.21437654864384317`, 0.34265372325588017`, 0.9355197993523594]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 322}], {
             RGBColor[
             0.2153075934140704, 0.3436323103410369, 0.9355728209746665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 335}], {
             RGBColor[
             0.21688414248716403`, 0.34528936337584293`, 0.9356626031120838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 349}], {
             RGBColor[
             0.21695935367547547`, 0.34536841510342303`, 0.9356668862779931]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 351}], {
             RGBColor[
             0.27252940237618284`, 0.4037012784354327, 0.938834256448926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 355}], {
             RGBColor[
             0.2218222289646276, 0.3504796053564232, 0.9359438198317311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 186}], {
             RGBColor[
             0.1973172314150955, 0.32472329922528254`, 0.9345482964731804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 240}], {
             RGBColor[
             0.18369308464468964`, 0.3104034571487888, 0.9337724214697247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 272}], {
             RGBColor[
             0.19235235421379315`, 0.3195048984953177, 0.9342655540614437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 308}], {
             RGBColor[
             0.20045056014029836`, 0.3280166263799862, 0.9347267349087363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 342}], {
             RGBColor[
             0.18722373291059582`, 0.31411439233228555`, 0.933973486665342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 348}], {
             RGBColor[
             0.1945787269842331, 0.32184495743723673`, 0.934392342697097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 374}], {
             RGBColor[
             0.18584495673726414`, 0.3126652111546555, 0.9338949674019874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 192}], {
             RGBColor[
             0.31894488906729196`, 0.44600858518137365`, 0.9417147525123752]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 194}], {
             RGBColor[
             0.41753162873264527`, 0.5360090287080477, 0.9478416433121417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 221}], {
             RGBColor[
             0.3747675504331488, 0.4990265486455837, 0.9451008348130354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 256}], {
             RGBColor[
             0.6859636429526801, 0.7471589426256584, 0.8613086090450968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 316}], {
             RGBColor[
             0.5458822960971526, 0.6391409074229324, 0.9586767421820886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 351}], {
             RGBColor[
             0.3445890788111915, 0.47288747334073133`, 0.943177889287059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 399}], {
             RGBColor[
             0.369499573099037, 0.49446369145501556`, 0.9447651639555954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 198}], {
             RGBColor[
             0.6233166189809511, 0.701327344471203, 0.9656888716580491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 203}], {
             RGBColor[
             0.3639226125883841, 0.4896332085668736, 0.9444098049633691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 266}], {
             RGBColor[
             0.5380286912692482, 0.6346285303347542, 0.9572070721400225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 313}], {
             RGBColor[
             0.35122662219084355`, 0.47640574207717373`, 0.9436825095790529]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 329}], {
             RGBColor[
             0.34008730347088106`, 0.4646976118288939, 0.9430481418570962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 340}], {
             RGBColor[
             0.3446138349142821, 0.46945528337457815`, 0.9433059211263948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 341}], {
             RGBColor[
             0.3335895874564281, 0.4578681003187137, 0.9426781065425826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 358}], {
             RGBColor[
             0.34771638286513834`, 0.47271625798382977`, 0.9434826066423876]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 204}], {
             RGBColor[
             0.1850387535749342, 0.31181784051481387`, 0.9338490553245634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 216}], {
             RGBColor[
             0.20297653411671235`, 0.3306715851851976, 0.9348705853898494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 229}], {
             RGBColor[
             0.1940292110138258, 0.32126738131101384`, 0.9343610485755184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 294}], {
             RGBColor[
             0.19993479870238595`, 0.3274745284075764, 0.9346973630578478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 307}], {
             RGBColor[
             0.18458331869086259`, 0.3113391495754152, 0.933823118981671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 343}], {
             RGBColor[
             0.19542826971397487`, 0.32273788071031545`, 0.93444072289877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 379}], {
             RGBColor[
             0.1863024171876671, 0.3131460310926968, 0.9339210190978857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 205}], {
             RGBColor[
             0.18567915281687453`, 0.3124909407217502, 0.9338855251140061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 232}], {
             RGBColor[
             0.18828223277850703`, 0.3152269428062281, 0.9340337666669094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 277}], {
             RGBColor[
             0.18565952896853344`, 0.31247031481291987`, 0.933884407564874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 298}], {
             RGBColor[
             0.19583511598337588`, 0.32316550193499927`, 0.9344638921919373]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 320}], {
             RGBColor[
             0.18495626411433608`, 0.3117311388615913, 0.9338443576718145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 347}], {
             RGBColor[
             0.18526445779187303`, 0.3120550699572905, 0.9338619088458187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 373}], {
             RGBColor[
             0.192094835712424, 0.3192342302227627, 0.9342508887637553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 390}], {
             RGBColor[
             0.199593709897452, 0.3271160224473115, 0.9346779385550025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 219}], {
             RGBColor[
             0.18016175523476746`, 0.3066918060397442, 0.9335713174839634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 248}], {
             RGBColor[
             0.18215464872777276`, 0.30878646345763827`, 0.9336848098201683]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 260}], {
             RGBColor[
             0.18516377148342406`, 0.31194924226322995`, 0.9338561749095045]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 285}], {
             RGBColor[
             0.18283630546897034`, 0.3095029279121705, 0.9337236291631588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 200}], {
             RGBColor[
             0.1885274133225135, 0.31548464310332325`, 0.9340477293361784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 278}], {
             RGBColor[
             0.18555079143571185`, 0.31235602477156665`, 0.9338782151232425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 296}], {
             RGBColor[
             0.18104204814496305`, 0.30761704970215387`, 0.9336214488629224]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 330}], {
             RGBColor[
             0.18585403499635023`, 0.3126747529805498, 0.9338954843954123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 367}], {
             RGBColor[
             0.18455036747987072`, 0.3113045157634352, 0.933821242458952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 398}], {
             RGBColor[
             0.18190742429108608`, 0.30852661489974587`, 0.9336707307542348]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 209}], {
             RGBColor[
             0.24592936800917714`, 0.3758177369731411, 0.9373166857370019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 245}], {
             RGBColor[
             0.21085364957036085`, 0.33895093296494805`, 0.9353191754617867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 286}], {
             RGBColor[
             0.2740282991513247, 0.4041960245612692, 0.9389591857364195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 290}], {
             RGBColor[
             0.24217146180405288`, 0.37186793928654055`, 0.9371026785379442]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 352}], {
             RGBColor[
             0.20659936567779108`, 0.3344794108566792, 0.9350769002877538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 386}], {
             RGBColor[
             0.284370042597393, 0.41315352294311436`, 0.9396181524839584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 232}], {
             RGBColor[
             0.18939213687360562`, 0.3163935223821609, 0.9340969740631693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 249}], {
             RGBColor[
             0.18602314959306215`, 0.3128525031441788, 0.9339051152215123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 268}], {
             RGBColor[
             0.1880422345433147, 0.314974689444274, 0.9340200991224608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 370}], {
             RGBColor[
             0.18698550798658503`, 0.3138640028328177, 0.9339599201083417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 238}], {
             RGBColor[
             0.1965022388034804, 0.3238666903169589, 0.9345018838496224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 245}], {
             RGBColor[
             0.1935081925729178, 0.3207197578951424, 0.9343313773460864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 187}], {
             RGBColor[
             0.22908739425404853`, 0.35811575471368917`, 0.9363575602471148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 208}], {
             RGBColor[
             0.2681228139523549, 0.39914445580516655`, 0.9385805696512048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 323}], {
             RGBColor[
             0.3312247462121247, 0.45512489933743366`, 0.9425528644360341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 377}], {
             RGBColor[
             0.2482608696505907, 0.3782682930240088, 0.9374494613063329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 388}], {
             RGBColor[
             0.2563045573313864, 0.38672271877578024`, 0.9379075374201846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 395}], {
             RGBColor[
             0.3402542515552627, 0.4629458030295253, 0.9431282165320207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 270}], {
             RGBColor[
             0.198314467229445, 0.32577145729456636`, 0.9346050875775294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 291}], {
             RGBColor[
             0.1920722404266596, 0.31921048114480044`, 0.9342496019956579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 357}], {
             RGBColor[
             0.18734376764879906`, 0.31424055645277915`, 0.9339803224661072]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 368}], {
             RGBColor[
             0.18625851527578347`, 0.31309988739976513`, 0.933918518948951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 185}], {
             RGBColor[
             0.20305130848505737`, 0.330750177787297, 0.9348748436795078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 190}], {
             RGBColor[
             0.21285282401079259`, 0.34105219205682236`, 0.9354330254886557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 226}], {
             RGBColor[
             0.20272879549405032`, 0.3304111961852439, 0.9348564770417853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 252}], {
             RGBColor[
             0.20974713734389644`, 0.3377879184580067, 0.9352561612274277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 274}], {
             RGBColor[
             0.20834640202144852`, 0.33631565682236503`, 0.9351763914230165]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 288}], {
             RGBColor[
             0.21364346222149755`, 0.3418832029456312, 0.9354780511651108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 318}], {
             RGBColor[
             0.2135047362690546, 0.34173739317388024`, 0.935470150927346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 190}], {
             RGBColor[
             0.20235115482293997`, 0.33001427189610544`, 0.9348349709642347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 226}], {
             RGBColor[
             0.1922271263061977, 0.3193732760245269, 0.9342584225173644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 252}], {
             RGBColor[
             0.1992454681560438, 0.3267499982972898, 0.9346581067030068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 274}], {
             RGBColor[
             0.19784473283359588`, 0.32527773666164805`, 0.9345783368985956]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 288}], {
             RGBColor[
             0.2031417930336449, 0.3308452827849142, 0.93487999664069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 318}], {
             RGBColor[
             0.20300306708120197`, 0.33069947301316327`, 0.9348720964029251]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 357}], {
             RGBColor[
             0.18927662196416456`, 0.31627210888827, 0.9340903956599655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 272}], {
             RGBColor[
             0.20161622991530592`, 0.3292418192212516, 0.9347931180779689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 306}], {
             RGBColor[
             0.21444053080855624`, 0.3427209725676972, 0.9355234430419865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 308}], {
             RGBColor[
             0.20971443584181115`, 0.3377535471059201, 0.9352542989252615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 342}], {
             RGBColor[
             0.19648760861210862`, 0.32385131305821946`, 0.9345010506818672]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 348}], {
             RGBColor[
             0.2038426026857459, 0.33158187816317064`, 0.9349199067136222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 374}], {
             RGBColor[
             0.19510883243877694`, 0.3224021318805894, 0.9344225314185126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 378}], {
             RGBColor[
             0.22340907061728948`, 0.35214747654494266`, 0.9360341881163283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 208}], {
             RGBColor[
             0.25538258130493185`, 0.38575366351532014`, 0.9378550322494192]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 302}], {
             RGBColor[
             0.20552429842574232`, 0.33334944701157526`, 0.9350156767981692]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 377}], {
             RGBColor[
             0.2355206370031677, 0.36487750073416236`, 0.9367239239045473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 388}], {
             RGBColor[
             0.2435643246839634, 0.37333192648593383`, 0.937182000018399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 201}], {
             RGBColor[
             0.47076164268683474`, 0.5730017553920743, 0.9531670568538995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 264}], {
             RGBColor[
             0.26789407428573686`, 0.39890403591261847`, 0.9385675432655809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 273}], {
             RGBColor[
             0.39992754574806544`, 0.5158532142548906, 0.9473461281045827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 281}], {
             RGBColor[
             0.3372802138863956, 0.4635116716468679, 0.9428236756739168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 293}], {
             RGBColor[
             0.29496948602480166`, 0.4268642457721712, 0.9401276735084836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 394}], {
             RGBColor[
             0.3167171676025393, 0.44570099448454903`, 0.9415134165478973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 207}], {
             RGBColor[
             0.2123454769342431, 0.3405189381117063, 0.935404132823199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 241}], {
             RGBColor[
             0.2570425573000169, 0.3874984035347115, 0.937949565426625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 263}], {
             RGBColor[
             0.2675028819703037, 0.39849286798607286`, 0.9385452654419342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 280}], {
             RGBColor[
             0.2210513429116578, 0.3496693552377532, 0.9358999190114381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 291}], {
             RGBColor[
             0.21431712870363867`, 0.34259126913128346`, 0.9355164154746687]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 336}], {
             RGBColor[
             0.23398737474331802`, 0.3632659448846183, 0.936636606887107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 359}], {
             RGBColor[
             0.2794316818374808, 0.4094642361682714, 0.9392819522659938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 226}], {
             RGBColor[
             0.20202864183193292`, 0.3296752902940524, 0.9348166043265123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 252}], {
             RGBColor[
             0.20904698368177904`, 0.3370520125668152, 0.9352162885121547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 274}], {
             RGBColor[
             0.20764624835933113`, 0.33557975093117354`, 0.9351365187077434]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 288}], {
             RGBColor[
             0.21294330855938015`, 0.3411472970544397, 0.9354381784498378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 318}], {
             RGBColor[
             0.21280458260693721`, 0.34100148728268875`, 0.9354302782120729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 225}], {
             RGBColor[
             0.19624559498378968`, 0.32359694139030604`, 0.9344872683637615]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 235}], {
             RGBColor[
             0.18862912627732129`, 0.3155915498678, 0.9340535217384839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 261}], {
             RGBColor[
             0.18660634868245718`, 0.3134654823640909, 0.9339383275468877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 322}], {
             RGBColor[
             0.18956017104754852`, 0.31657013695295677`, 0.934106543360791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 327}], {
             RGBColor[
             0.1848862258869851, 0.3116575242439654, 0.9338403690983792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 335}], {
             RGBColor[
             0.19113672012064215`, 0.3182271899877628, 0.9341963254982084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 349}], {
             RGBColor[
             0.1912119313089536, 0.3183062417153429, 0.9342006086641177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 355}], {
             RGBColor[
             0.19607480659810572`, 0.32341743196834305`, 0.9344775422178556]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 208}], {
             RGBColor[
             0.27634222217301546`, 0.40778357498566165`, 0.9390486527898467]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 221}], {
             RGBColor[
             0.3140891047086496, 0.4418027488287358, 0.9414053462268441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[
             0.233374248060821, 0.36262150986683694`, 0.9366016902295785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 322}], {
             RGBColor[
             0.2266888241245798, 0.3555947054294877, 0.936220965226608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 335}], {
             RGBColor[
             0.22826537319767345`, 0.3572517584642937, 0.9363107473640253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 349}], {
             RGBColor[
             0.22834058438598487`, 0.3573308101918738, 0.9363150305299347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 351}], {
             RGBColor[
             0.2839106330866923, 0.41566367352388345`, 0.9394824007008676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 355}], {
             RGBColor[
             0.233203459675137, 0.36244200044487396`, 0.9365919640836726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 399}], {
             RGBColor[
             0.3088211273745378, 0.43723989163816773`, 0.941069675369404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 195}], {
             RGBColor[
             0.6312732042379722, 0.7079049527832757, 0.9663404032043308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 242}], {
             RGBColor[
             0.5891633460741419, 0.6714315101447773, 0.963657200278417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 253}], {
             RGBColor[
             0.8315602657829888, 0.5341252723143658, 0.5780805506738103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 255}], {
             RGBColor[
             0.606058461723811, 0.6860652101473173, 0.9647337421078497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 283}], {
             RGBColor[
             0.884925338733304, 0.8207038820590313, 0.6242425057097936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 312}], {
             RGBColor[
             0.6928723364666782, 0.7586931681891012, 0.9709743993376487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 332}], {
             RGBColor[
             0.8278665265086236, 0.5057335736447233, 0.5745434217731962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 356}], {
             RGBColor[
             0.8916558476180196, 0.9161964476590825, 0.9808695463369558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 360}], {
             RGBColor[
             0.7503418220523833, 0.8050370370474327, 0.9757122305140027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 364}], {
             RGBColor[
             0.8796332391054209, 0.7997224705221349, 0.619984358127655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 380}], {
             RGBColor[
             0.7791551569135652, 0.8275462332304435, 0.978584074457042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 389}], {
             RGBColor[
             0.9155257058475293, 0.9306524378746825, 0.7386464272151838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 221}], {
             RGBColor[
             0.41267584437400284`, 0.5318031923554098, 0.9475322370266106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 233}], {
             RGBColor[
             0.7128854689421396, 0.7730895863286765, 0.9426895386250231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 256}], {
             RGBColor[
             0.7238719368935342, 0.7799355863354847, 0.863740011258672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 316}], {
             RGBColor[
             0.5837905900380065, 0.6719175511327584, 0.9611081443956637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 399}], {
             RGBColor[
             0.40740786703989107`, 0.5272403351648417, 0.9471965661691704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 241}], {
             RGBColor[
             0.35276484059541724`, 0.47739540900316435`, 0.9437930699766406]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 242}], {
             RGBColor[
             0.3825084156474021, 0.5057312970269716, 0.9455940758995094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.3994035312970712, 0.5203649970295117, 0.9466706177289421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 263}], {
             RGBColor[
             0.3632251652657039, 0.4883898734545258, 0.9443887699919498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 312}], {
             RGBColor[
             0.48621740603993846`, 0.5929929550712956, 0.9529112749587412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 356}], {
             RGBColor[
             0.6850009171912799, 0.7504962345412768, 0.9628064219580481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 359}], {
             RGBColor[
             0.375153965132881, 0.49936124163672424`, 0.9451254568160093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 360}], {
             RGBColor[
             0.5436868916256435, 0.6393368239296271, 0.957649106135095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 380}], {
             RGBColor[
             0.5725002264868254, 0.6618460201126379, 0.9605209500781344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 389}], {
             RGBColor[
             0.7088707754207897, 0.764952224756877, 0.7205833028362763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 206}], {
             RGBColor[
             0.6365065028818196, 0.7122246861355508, 0.9667719599708235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 214}], {
             RGBColor[
             0.8615229927273951, 0.7108190806524803, 0.6028379622201453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 286}], {
             RGBColor[
             0.5826840049020053, 0.6656063435828412, 0.963342437992916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 332}], {
             RGBColor[
             0.8309647608435446, 0.5082040216040586, 0.5748389341298874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 334}], {
             RGBColor[
             0.9021680954325457, 0.8779962725880234, 0.6424622562871629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 366}], {
             RGBColor[
             0.9187123308959824, 0.9333119446325909, 0.748562723255582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 386}], {
             RGBColor[
             0.5930257483480736, 0.6745638419646864, 0.9640014047404548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 217}], {
             RGBColor[
             0.19977926755688577`, 0.3273110553124115, 0.9346885057891993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 231}], {
             RGBColor[
             0.19125913163260555`, 0.3183558522481745, 0.9342032966527232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 254}], {
             RGBColor[
             0.18919463052287389`, 0.31618593068491585`, 0.9340857263686796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 314}], {
             RGBColor[
             0.18703267242257346`, 0.3139135756454394, 0.9339626060531978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 369}], {
             RGBColor[
             0.18585850163943218`, 0.31267944770563044`, 0.933895738764128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 392}], {
             RGBColor[
             0.19718685275102665`, 0.3245862629828614, 0.9345408716011396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 203}], {
             RGBColor[
             0.5694035624452959, 0.6546305646490294, 0.9622535793690412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 206}], {
             RGBColor[
             0.6288429856334741, 0.7061140055023541, 0.9660410068543737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 214}], {
             RGBColor[
             0.8538594754790496, 0.7047084000192836, 0.6021070091036955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 266}], {
             RGBColor[
             0.74350964112616, 0.79962588641691, 0.9750508465456946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 310}], {
             RGBColor[
             0.8276571285797327, 0.5355745817229594, 0.5782791813938954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 384}], {
             RGBColor[
             0.8811911535814985, 0.820358675063078, 0.6244757857174054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 215}], {
             RGBColor[
             0.8474033618771311, 0.8799586173228249, 0.9038397390676208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 222}], {
             RGBColor[
             0.9699116219534045, 0.9763258350817114, 0.9020107810264453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 223}], {
             RGBColor[
             0.9239760391061387, 0.7216129997514857, 0.5202901272072924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 224}], {
             RGBColor[
             0.7432416506659434, 0.7963714338733744, 0.8949724605475597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 247}], {
             RGBColor[
             0.9030372486329088, 0.5619443631205439, 0.500289085988991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 259}], {
             RGBColor[
             0.9420801867046171, 0.9545306309034027, 0.913114429015637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 271}], {
             RGBColor[
             0.9043692525849842, 0.5721827291840494, 0.5015646144777819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 287}], {
             RGBColor[
             0.9030273761887495, 0.5618684791886028, 0.5002796321253148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 292}], {
             RGBColor[
             0.9041138184890838, 0.5702193507910247, 0.501320010499076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 345}], {
             RGBColor[
             0.9084097409587222, 0.9276827314255283, 0.9099029118424318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 350}], {
             RGBColor[
             0.6686405102956781, 0.7329620420673324, 0.8898856192140527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 353}], {
             RGBColor[
             0.9909977762454061, 0.988800838647677, 0.6720451430779383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 393}], {
             RGBColor[
             0.8553537557812887, 0.8861695254659845, 0.9046321600313321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 400}], {
             RGBColor[
             0.9054254853432643, 0.5803013970083357, 0.502576064159955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 234}], {
             RGBColor[
             0.22049169370930496`, 0.34908112844227146`, 0.9358680478172909]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 296}], {
             RGBColor[
             0.1865617818736295, 0.3134186398223141, 0.9339357895330556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 298}], {
             RGBColor[
             0.19975642982426225`, 0.3272870514074283, 0.9346872052141117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 320}], {
             RGBColor[
             0.18887757795522245`, 0.31585268833402036`, 0.934067670693989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 330}], {
             RGBColor[
             0.1913737687250167, 0.31847634310071005`, 0.9342098250655455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 347}], {
             RGBColor[
             0.1891857716327594, 0.31617661942971953`, 0.9340852218679931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 367}], {
             RGBColor[
             0.19007010120853718`, 0.31710610588359545`, 0.9341355831290852]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 398}], {
             RGBColor[
             0.18742715801975252`, 0.3143282050199061, 0.933985071424368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 273}], {
             RGBColor[
             0.5948799673171399, 0.6816316125645953, 0.9614948857902279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 281}], {
             RGBColor[
             0.5322326354554701, 0.6292900699565726, 0.956972433359562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 293}], {
             RGBColor[
             0.4899219075938762, 0.5926426440818758, 0.9542764311941287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 303}], {
             RGBColor[
             0.7798220611835203, 0.6750115727481525, 0.6002603969131654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 394}], {
             RGBColor[
             0.5116695891716139, 0.6114793927942537, 0.9556621742335425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 212}], {
             RGBColor[
             0.45268550871471924`, 0.56313574583105, 0.9509994425842794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 234}], {
             RGBColor[
             0.28726387007128157`, 0.41752052418196, 0.9397344221047603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 239}], {
             RGBColor[
             0.4173644057485659, 0.5344604832455712, 0.9482188359733204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 269}], {
             RGBColor[
             0.34049741903328384`, 0.46934348329390774`, 0.9429171723441234]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 289}], {
             RGBColor[
             0.4009029468034172, 0.5210963292936249, 0.9469229296248474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 309}], {
             RGBColor[
             0.5124790971855998, 0.6108362268976354, 0.9562827357512269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 362}], {
             RGBColor[
             0.5594312028417849, 0.6475155686854668, 0.9609624828506617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 365}], {
             RGBColor[
             0.31680424057691503`, 0.4485693265510483, 0.9414167025039941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 206}], {
             RGBColor[
             0.36944897924090714`, 0.4944198695980247, 0.9447619401596937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 211}], {
             RGBColor[
             0.27124930343896736`, 0.4023137700960795, 0.9387628961154517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 216}], {
             RGBColor[
             0.26291297700315486`, 0.3935517624584167, 0.938288154657422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 266}], {
             RGBColor[
             0.4841156347335931, 0.5879317505125805, 0.9537717798510146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 329}], {
             RGBColor[
             0.28617424693522586`, 0.4180008320067203, 0.9396128495680883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 341}], {
             RGBColor[
             0.2796765309207728, 0.4111713204965401, 0.9392428142535747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 358}], {
             RGBColor[
             0.29380332632948314`, 0.42601947816165614`, 0.9400473143533797]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 229}], {
             RGBColor[
             0.18893129430891603`, 0.3159091476275659, 0.9340707297608657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 237}], {
             RGBColor[
             0.18108298927677668`, 0.3076600814275077, 0.9336237803998122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 307}], {
             RGBColor[
             0.17948540198595286`, 0.30598091589196724`, 0.9335328001670183]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 343}], {
             RGBColor[
             0.1903303530090651, 0.3173796470268675, 0.9341504040841173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 232}], {
             RGBColor[
             0.18775686622597437`, 0.3146747492493529, 0.9340038478189527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 277}], {
             RGBColor[
             0.18513416241600078`, 0.31191812125604473`, 0.9338544887169173]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 373}], {
             RGBColor[
             0.19156946915989134`, 0.31868203666588757`, 0.9342209699157987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 390}], {
             RGBColor[
             0.19906834334491935`, 0.32656382889043634`, 0.9346480197070459]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 266}], {
             RGBColor[
             0.5435550579217713, 0.6394151913659053, 0.9575592073363473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 286}], {
             RGBColor[
             0.375065904449271, 0.49928496789863985`, 0.9451198456671187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 386}], {
             RGBColor[
             0.3854076478953393, 0.5082424662804851, 0.9457788124146576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 231}], {
             RGBColor[
             0.1913619669815575, 0.3184639387200607, 0.9342091529737147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 280}], {
             RGBColor[
             0.200223112625469, 0.32777756462089525`, 0.9347137821092452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 291}], {
             RGBColor[
             0.19348889841744987`, 0.3206994785144255, 0.9343302785724756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 368}], {
             RGBColor[
             0.18767517326657374`, 0.3145888847693901, 0.9339991955257688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 372}], {
             RGBColor[
             0.18573202091371066`, 0.31254650844355597`, 0.9338885358739095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 387}], {
             RGBColor[
             0.18852965084716983`, 0.3154869948836043, 0.9340478567598975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 392}], {
             RGBColor[
             0.1972896880999786, 0.3246943494547476, 0.9345467279221311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 221}], {
             RGBColor[
             0.3321648835388723, 0.4608015384498717, 0.9424347350905069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 225}], {
             RGBColor[
             0.2514500268910438, 0.38162029948797277`, 0.9376310790932412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 323}], {
             RGBColor[
             0.3575199332630081, 0.48276280813906464`, 0.9440503364383386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 351}], {
             RGBColor[
             0.301986411916915, 0.43466246314501933`, 0.9405117895645303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 388}], {
             RGBColor[
             0.28259974438226976`, 0.4143606275774112, 0.9394050094224892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 395}], {
             RGBColor[
             0.366549438606146, 0.4905837118311563, 0.9446256885343254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 286}], {
             RGBColor[
             0.29314447532730914`, 0.4242883377578022, 0.9400478236897936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 290}], {
             RGBColor[
             0.2612876379800373, 0.3919602524830736, 0.938191316491318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 304}], {
             RGBColor[
             0.2736580263748165, 0.40496231501391133`, 0.9388957918100511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 338}], {
             RGBColor[
             0.23759083072429804`, 0.3670534055929334, 0.9368418183743885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 386}], {
             RGBColor[
             0.30348621877337745`, 0.4332458361396474, 0.9407067904373323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 230}], {
             RGBColor[
             0.2334030426063412, 0.36265177475985827`, 0.9366033300363481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 258}], {
             RGBColor[
             0.24166666616429894`, 0.371337367063267, 0.9370739311730383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 264}], {
             RGBColor[
             0.2528298194491141, 0.3830705489504057, 0.9377096562382032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 279}], {
             RGBColor[
             0.2223588131160111, 0.3510435893209275, 0.9359743775053473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 328}], {
             RGBColor[
             0.2385161810587667, 0.36802600746505976`, 0.9368945157070033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 394}], {
             RGBColor[
             0.30165291276591666`, 0.42986750752233627`, 0.9406555295205197]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 216}], {
             RGBColor[
             0.22415272438939332`, 0.35292910380979625`, 0.9360765380985124]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 238}], {
             RGBColor[
             0.21668562529693003`, 0.34508070922219014`, 0.9356512978517798]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 341}], {
             RGBColor[
             0.24091627830701134`, 0.3705486618479197, 0.9370311976946651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 358}], {
             RGBColor[
             0.2550430737157216, 0.3853968195130357, 0.9378356977944702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 239}], {
             RGBColor[
             0.542458414688152, 0.6394312043737607, 0.9571234599763494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 289}], {
             RGBColor[
             0.5259969557430033, 0.6260670504218144, 0.9558275536278764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 309}], {
             RGBColor[
             0.6375731061251859, 0.7158069480258249, 0.965187359754256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 362}], {
             RGBColor[
             0.6845252117813709, 0.7524862898136562, 0.9698671068536907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 385}], {
             RGBColor[
             0.7860985506073723, 0.8292872838004639, 0.7968353358505167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 215}], {
             RGBColor[
             0.5157421665105038, 0.6132928535993672, 0.9566471217151071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 227}], {
             RGBColor[
             0.29970260204538113`, 0.43079580390036054`, 0.94043541584355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 259}], {
             RGBColor[
             0.6104189913379899, 0.6878648671799451, 0.9659218116631232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 306}], {
             RGBColor[
             0.2738566580723743, 0.4036300780572341, 0.9389635275699348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 308}], {
             RGBColor[
             0.2691305631056292, 0.398662652595457, 0.9386943834532097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 345}], {
             RGBColor[
             0.5767485455920949, 0.6610169677020706, 0.962710294489918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 350}], {
             RGBColor[
             0.33697931492905076`, 0.46629627834387477`, 0.942693001861539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 378}], {
             RGBColor[
             0.2828251978811075, 0.4130565820344796, 0.9394742726442766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 257}], {
             RGBColor[
             0.9241708234933428, 0.7599031818045514, 0.5786645333196092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 310}], {
             RGBColor[
             0.8527190352209195, 0.3739582811888842, 0.19685354443386982`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 332}], {
             RGBColor[
             0.8483631502363858, 0.34047704043678684`, 0.1926823440534119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 389}], {
             RGBColor[
             0.9360223295752915, 0.7653959046667461, 0.35678534949539953`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 224}], {
             RGBColor[
             0.6019092601655756, 0.6867200928189938, 0.9624709353645509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 227}], {
             RGBColor[
             0.4900314069116405, 0.5878102265694376, 0.9551265080130549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 259}], {
             RGBColor[
             0.8007477962042493, 0.8448792898490222, 0.9806129038326282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 345}], {
             RGBColor[
             0.7670773504583543, 0.8180313903711476, 0.977401386659423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 350}], {
             RGBColor[
             0.5273081197953102, 0.6233107010129518, 0.9573840940310441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 353}], {
             RGBColor[
             0.8496653857450382, 0.8791494975932964, 0.7395436178949295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 393}], {
             RGBColor[
             0.7140213652809209, 0.7765181844116039, 0.9721306348483233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 400}], {
             RGBColor[
             0.7640930948428964, 0.47065005595395515`, 0.5700745389769464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 229}], {
             RGBColor[
             0.2068690748506942, 0.33476289229794964`, 0.9350922598261517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 294}], {
             RGBColor[
             0.21277466253925434`, 0.3409700393945122, 0.9354285743084811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 329}], {
             RGBColor[
             0.23907766788565177`, 0.368616165720437, 0.936926491551149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 340}], {
             RGBColor[
             0.2436041993290528, 0.3733738372661213, 0.9371842708204476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 341}], {
             RGBColor[
             0.2325799518711988, 0.3617866542102568, 0.9365564562366354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 343}], {
             RGBColor[
             0.20826813355084325`, 0.33623339169725125`, 0.9351719341494034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 358}], {
             RGBColor[
             0.24670674727990904`, 0.37663481187537284`, 0.9373609563364405]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 231}], {
             RGBColor[
             0.19972682323934088`, 0.32725593300951006`, 0.9346855191628995]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 254}], {
             RGBColor[
             0.1976623221296092, 0.32508601144625143`, 0.934567948878856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 314}], {
             RGBColor[
             0.1955003640293088, 0.322813656406775, 0.9344448285633742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 331}], {
             RGBColor[
             0.22460790707912992`, 0.3534075296769589, 0.9361024600793104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 392}], {
             RGBColor[
             0.20565454435776198`, 0.333486343744197, 0.935023094111316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 222}], {
             RGBColor[
             0.7556819189936763, 0.8084691579297268, 0.9631032253183853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 276}], {
             RGBColor[
             0.46966080217049366`, 0.5783141439540027, 0.951949779691809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 282}], {
             RGBColor[
             0.4376499441056336, 0.5505879476107286, 0.9499100761220066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 305}], {
             RGBColor[
             0.42916789405553485`, 0.5422531768418173, 0.9494057845729981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 339}], {
             RGBColor[
             0.47111694262023773`, 0.5795753796238241, 0.9520425636736524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 361}], {
             RGBColor[
             0.4849252020484565, 0.5915353999172487, 0.952922413754254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 382}], {
             RGBColor[
             0.44118615700326724`, 0.5536508374874307, 0.9501354004808935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 384}], {
             RGBColor[
             0.7469305423915883, 0.7141446268230167, 0.6119725391027997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 248}], {
             RGBColor[
             0.1809198934930053, 0.30748865741789405`, 0.933614492336205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 251}], {
             RGBColor[
             0.1819264333571092, 0.30854659463338063`, 0.9336718132924233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 260}], {
             RGBColor[
             0.1839290162486566, 0.31065143622348573`, 0.9337858574255411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 352}], {
             RGBColor[
             0.1830449444132805, 0.30972222067111355`, 0.9337355108423835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 396}], {
             RGBColor[
             0.18205118127193512`, 0.30867771260133725`, 0.9336789175016247]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 256}], {
             RGBColor[
             0.6811078585940378, 0.7429531062730206, 0.8609992027595657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 316}], {
             RGBColor[
             0.5410265117385101, 0.6349350710702945, 0.9583673358965574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 351}], {
             RGBColor[
             0.33973329445254913`, 0.4686816369880935, 0.9428684830015278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 399}], {
             RGBColor[
             0.36464378874039466`, 0.49025785510237774`, 0.9444557576700642]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 223}], {
             RGBColor[
             0.9051519086820443, 0.7083288764559916, 0.5859596439831081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 224}], {
             RGBColor[
             0.724417520241849, 0.7830873105778803, 0.9606419773233753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 247}], {
             RGBColor[
             0.8842131182088144, 0.5486602398250497, 0.5659586027648067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 259}], {
             RGBColor[
             0.9232560562805229, 0.9412465076079086, 0.9787839457914527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 292}], {
             RGBColor[
             0.8852896880649895, 0.5569352274955306, 0.5669895272748917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 363}], {
             RGBColor[
             0.6628066494410058, 0.7309294373629389, 0.9563828644799877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 383}], {
             RGBColor[
             0.6547025238599551, 0.723910051109828, 0.9558664767641599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 393}], {
             RGBColor[
             0.8365296253571944, 0.8728854021704904, 0.9703016768071477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 247}], {
             RGBColor[
             0.8382775353615486, 0.29394740449482404`, 0.18423794894565387`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 292}], {
             RGBColor[
             0.8393541052177236, 0.30222239216530483`, 0.1852688734557389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 319}], {
             RGBColor[
             0.845830354553812, 0.35200168247303465`, 0.19147053713385456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 385}], {
             RGBColor[
             0.9268169546976089, 0.7220420708837272, 0.4190027976388401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 393}], {
             RGBColor[
             0.7905940425099285, 0.6181725668402647, 0.5885810229879949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 400}], {
             RGBColor[
             0.8406657720719041, 0.3123044383826159, 0.18652492711661786`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 227}], {
             RGBColor[
             0.3858696957004528, 0.504223043119987, 0.9462592294929938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 259}], {
             RGBColor[
             0.6965860849930616, 0.7612921063995717, 0.9717456253125671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 363}], {
             RGBColor[
             0.4361366781535445, 0.5509750361546019, 0.9493445440011021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 383}], {
             RGBColor[
             0.42803255257249384`, 0.5439556499014909, 0.9488281562852744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 393}], {
             RGBColor[
             0.6098596540697332, 0.6929310009621534, 0.9632633563282622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 235}], {
             RGBColor[
             0.20086558407238086`, 0.32845284284664206`, 0.9347503699076954]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 261}], {
             RGBColor[
             0.19884280647751676`, 0.32632677534293286`, 0.9346351757160992]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 322}], {
             RGBColor[
             0.2017966288426081, 0.3294314299317988, 0.9348033915300026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 327}], {
             RGBColor[
             0.19712268368204472`, 0.3245188172228074, 0.9345372172675908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 335}], {
             RGBColor[
             0.20337317791570175`, 0.3310884829666048, 0.93489317366742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 349}], {
             RGBColor[
             0.2034483891040132, 0.3311675346941849, 0.9348974568333293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 355}], {
             RGBColor[
             0.2083112643931653, 0.336278724947185, 0.9351743903870672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 252}], {
             RGBColor[
             0.19892295516503677`, 0.32641101669523676`, 0.9346397400652842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 274}], {
             RGBColor[
             0.1975222198425889, 0.324938755059595, 0.9345599702608729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 288}], {
             RGBColor[
             0.20281928004263788`, 0.3305063011828612, 0.9348616300029674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 315}], {
             RGBColor[
             0.186507225222572, 0.3133612973229612, 0.9339326826124872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 318}], {
             RGBColor[
             0.20268055409019498`, 0.33036049141111024`, 0.9348537297652024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 322}], {
             RGBColor[
             0.1935079091107788, 0.32071945995846174`, 0.9343313612033369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 243}], {
             RGBColor[
             0.2526928974888643, 0.38292663528882953`, 0.9377018587351249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 306}], {
             RGBColor[
             0.248145898473511, 0.3781474510273044, 0.9374429138678827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 311}], {
             RGBColor[
             0.23829401063491945`, 0.3677924922631779, 0.9368818634300369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 346}], {
             RGBColor[
             0.23870901568862182`, 0.3682286888874592, 0.9369054973539003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 350}], {
             RGBColor[
             0.3112685553301875, 0.44081365131394507`, 0.9411723881594869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 363}], {
             RGBColor[
             0.3242588248996095, 0.45206516990504564`, 0.9420001166496061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 383}], {
             RGBColor[
             0.3161546993185588, 0.44504578365193476`, 0.9414837289337784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 276}], {
             RGBColor[
             0.3015266164865197, 0.4277543234766833, 0.9407208506945814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 282}], {
             RGBColor[
             0.26951575842165965`, 0.40002812713340913`, 0.938681147124779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 301}], {
             RGBColor[
             0.2369380396545014, 0.36636728078923275`, 0.9368046428886814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 305}], {
             RGBColor[
             0.26103370837156087`, 0.39169335636449776`, 0.9381768555757705]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 382}], {
             RGBColor[
             0.27305197131929326`, 0.4030910170101112, 0.9389064714836659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 294}], {
             RGBColor[
             0.20382733943636777`, 0.33156583552032837`, 0.9349190374941501]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 307}], {
             RGBColor[
             0.18847585942484443`, 0.31543045668816716`, 0.9340447934179733]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[
             0.2301303447827652, 0.3592119618462532, 0.9364169547368181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 340}], {
             RGBColor[
             0.23465687622616624`, 0.36396963339193744`, 0.9366747340061166]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 343}], {
             RGBColor[
             0.1993208104479567, 0.32682918782306747`, 0.9346623973350723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 258}], {
             RGBColor[
             0.22938899732612533`, 0.3584327586651811, 0.9363747360958877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 264}], {
             RGBColor[
             0.2405521506109405, 0.3701659405523198, 0.9370104611610526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 279}], {
             RGBColor[
             0.2100811442778375, 0.33813898092284156`, 0.9352751824281966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 299}], {
             RGBColor[
             0.20475753633962784`, 0.33254353144354476`, 0.9349720108316877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 300}], {
             RGBColor[
             0.2086431877242838, 0.3366275974133453, 0.9351932929297377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 328}], {
             RGBColor[
             0.2262385122205931, 0.35512139906697393`, 0.9361953206298528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 331}], {
             RGBColor[
             0.21608777115484973`, 0.34445232661272185`, 0.9356172509428343]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 369}], {
             RGBColor[
             0.1858060573218873, 0.312624325402729, 0.9338927521378282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 372}], {
             RGBColor[
             0.18557674124721385`, 0.3123832996687683, 0.9338796929266182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 392}], {
             RGBColor[
             0.1971344084334818, 0.32453114067996, 0.9345378849748398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 277}], {
             RGBColor[
             0.18773724237763328`, 0.31465412334052256`, 0.9340027302698206]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 373}], {
             RGBColor[
             0.19417254912152382`, 0.3214180387503654, 0.934369211468702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 390}], {
             RGBColor[
             0.20167142330655186`, 0.3292998309749142, 0.9347962612599492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 256}], {
             RGBColor[
             0.9813174831621745, 0.9842395002462874, 0.8561565043579783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 257}], {
             RGBColor[
             0.9698756400386146, 0.9770538821816868, 0.9358768631099392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 310}], {
             RGBColor[
             0.8984238517661913, 0.5911089815660195, 0.5540658742241997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 316}], {
             RGBColor[
             0.8412361363066468, 0.8762214650435611, 0.9535246374949702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 389}], {
             RGBColor[
             0.9817271461205633, 0.9825466050438816, 0.7139976792857294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 298}], {
             RGBColor[
             0.22620097648238727`, 0.3550819466262163, 0.936193183025091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 365}], {
             RGBColor[
             0.27647661087306347`, 0.4079248260301478, 0.9390563060275041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 261}], {
             RGBColor[
             0.19122633777104836`, 0.31832138382042696`, 0.9342014290908216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 322}], {
             RGBColor[
             0.1941801601361397, 0.32142603840929285`, 0.934369644904725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 327}], {
             RGBColor[
             0.1895062149755763, 0.31651342570030144`, 0.934103470642313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 335}], {
             RGBColor[
             0.19575670920923333`, 0.32308309144409886`, 0.9344594270421422]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 349}], {
             RGBColor[
             0.19583192039754477`, 0.3231621431716789, 0.9344637102080516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 355}], {
             RGBColor[
             0.2006947956866969, 0.3282733334246791, 0.9347406437617896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 262}], {
             RGBColor[
             0.4369845815472029, 0.5513866495573997, 0.9494877616771007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 284}], {
             RGBColor[
             0.6247504035752902, 0.7047458827568778, 0.9646230139836673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 334}], {
             RGBColor[
             0.7349237676396162, 0.7451154652166593, 0.6272347577119612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 366}], {
             RGBColor[
             0.7514680031030527, 0.8004311372612268, 0.7333352246803804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 376}], {
             RGBColor[
             0.397907468442853, 0.5154535439144465, 0.9470741986312354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 397}], {
             RGBColor[
             0.4369077612514729, 0.5513201116783387, 0.9494828667557864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 307}], {
             RGBColor[
             0.1806275543927051, 0.307181390488109, 0.9335978440569198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 324}], {
             RGBColor[
             0.18395646599811732`, 0.31068028765058353`, 0.9337874206481647]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 269}], {
             RGBColor[
             0.4302703250067166, 0.5456389418366184, 0.9490411897361934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 309}], {
             RGBColor[
             0.6022520031590326, 0.6871316854403461, 0.9624067531432969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 323}], {
             RGBColor[
             0.4638795886223883, 0.5747495967298069, 0.9511827422942791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 362}], {
             RGBColor[
             0.6492041088152176, 0.7238110272281775, 0.9670865002427318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 365}], {
             RGBColor[
             0.4065771465503478, 0.524864785093759, 0.9475407198960643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 377}], {
             RGBColor[
             0.3809157120608543, 0.4978929904163819, 0.9460793391645779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 385}], {
             RGBColor[
             0.750777447641219, 0.8006120212149852, 0.7940547292395577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 388}], {
             RGBColor[
             0.38895939974165, 0.5063474161681534, 0.9465374152784297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 272}], {
             RGBColor[
             0.18799208314490007`, 0.3149219771447579, 0.9340172430745133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 342}], {
             RGBColor[
             0.18286346184170274`, 0.30953147098172573`, 0.9337251756784115]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 374}], {
             RGBColor[
             0.18148468566837106`, 0.3080822898040957, 0.933646656415057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 242}], {
             RGBColor[
             0.31065498243158685`, 0.4409219663646659, 0.9411098670507269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 255}], {
             RGBColor[
             0.32755009808125596`, 0.4555556663672059, 0.9421864088801596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 312}], {
             RGBColor[
             0.41436397282412324`, 0.5281836244089898, 0.9484270661099586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 331}], {
             RGBColor[
             0.26094013118712034`, 0.3915950008105146, 0.9381715264935517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 359}], {
             RGBColor[
             0.3033005319170658, 0.43455191097441853`, 0.9406412479672268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 360}], {
             RGBColor[
             0.4718334584098283, 0.5745274932673213, 0.9531648972863125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 380}], {
             RGBColor[
             0.5006467932710101, 0.5970366894503322, 0.9560367412293518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 392}], {
             RGBColor[
             0.24198676846575243`, 0.37167381487775275`, 0.9370921605255572]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 255}], {
             RGBColor[
             0.3572936731332409, 0.48389155439101317`, 0.9439874148030284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 312}], {
             RGBColor[
             0.4441075478761082, 0.5565195124327971, 0.9502280720328274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 331}], {
             RGBColor[
             0.2906837062391053, 0.4199308888343219, 0.9399725324164205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 380}], {
             RGBColor[
             0.5303903683229951, 0.6253725774741394, 0.9578377471522206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 267}], {
             RGBColor[
             0.2144789920516021, 0.342761397772722, 0.9355256333528797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 275}], {
             RGBColor[
             0.21276908993785693`, 0.3409641822371201, 0.9354282569570754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 311}], {
             RGBColor[
             0.21699506567726595`, 0.34540595068157653`, 0.9356689200236639]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 326}], {
             RGBColor[
             0.23648276332684243`, 0.36588875650267677`, 0.9367787155753422]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 344}], {
             RGBColor[
             0.2114782278514492, 0.3396074043389222, 0.9353547442709138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 346}], {
             RGBColor[
             0.21741007073096835`, 0.3458421473058579, 0.9356925539475274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 363}], {
             RGBColor[
             0.302959879941956, 0.42967862832344433`, 0.9407871732432331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 383}], {
             RGBColor[
             0.29485575436090533`, 0.42265924207033345`, 0.9402707855274055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 302}], {
             RGBColor[
             0.18853043849765405`, 0.3154878227542032, 0.9340479016154273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 352}], {
             RGBColor[
             0.1906398234149592, 0.3177049200450192, 0.9341680279659126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 396}], {
             RGBColor[
             0.1896460602736138, 0.31666041197524286`, 0.9341114346251538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 248}], {
             RGBColor[
             0.19980719089443424`, 0.32734040451061686`, 0.9346900959819637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 251}], {
             RGBColor[
             0.20081373075853814`, 0.3283983417261034, 0.9347474169381822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 260}], {
             RGBColor[
             0.20281631365008554`, 0.33050318331620854`, 0.9348614610713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 326}], {
             RGBColor[
             0.22913658446266597`, 0.35816745674178546`, 0.9363603615567251]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 271}], {
             RGBColor[
             0.8186707488403941, 0.14451713392738777`, 0.16551243621614334`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 287}], {
             RGBColor[
             0.8173288724441594, 0.1342028839319411, 0.1642274538636763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 292}], {
             RGBColor[
             0.8184153147444937, 0.14255375553436297`, 0.16526783223743757`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 319}], {
             RGBColor[
             0.8248915640805821, 0.1923330458420928, 0.17146949591555327`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 362}], {
             RGBColor[
             0.8043048253983777, 0.4855724402659776, 0.5720335274237128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 385}], {
             RGBColor[
             0.9058781642243791, 0.5623734342527853, 0.3990017564205388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 393}], {
             RGBColor[
             0.7696552520366986, 0.45850393020932284`, 0.5685799817696936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 400}], {
             RGBColor[
             0.8197269815986742, 0.15263580175167407`, 0.16652388589831657`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 251}], {
             RGBColor[
             0.1839193268501145, 0.3106412520512747, 0.9337853056286283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 260}], {
             RGBColor[
             0.1859219097416619, 0.3127460936413798, 0.933899349761746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 275}], {
             RGBColor[
             0.18852850716525682`, 0.3154857928014001, 0.9340477916289045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 268}], {
             RGBColor[
             0.18564105657677243`, 0.3124508991579618, 0.9338833555894905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 279}], {
             RGBColor[
             0.19132944320701362`, 0.3184297541708887, 0.934207300792869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 299}], {
             RGBColor[
             0.186005835268804, 0.3128343046915919, 0.9339041291963601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 300}], {
             RGBColor[
             0.18989148665345995`, 0.3169183706613924, 0.9341254112944102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 370}], {
             RGBColor[
             0.18458433002004276`, 0.31134021254650546`, 0.9338231765753717]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 265}], {
             RGBColor[
             0.19635832810443649`, 0.32371543104779843`, 0.9344936883482087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 321}], {
             RGBColor[
             0.18913677562513462`, 0.3161251215191795, 0.934082431617842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 325}], {
             RGBColor[
             0.21599606078555122`, 0.34435593319981583`, 0.9356120281729761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 375}], {
             RGBColor[
             0.19825790374427554`, 0.32571200548532114`, 0.9346018663707272]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 381}], {
             RGBColor[
             0.19153445496524343`, 0.31864523452728444`, 0.9342189759092124]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 260}], {
             RGBColor[
             0.1869284496057658, 0.31380403085686637`, 0.9339566707179645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 275}], {
             RGBColor[
             0.1895350470293607, 0.3165437300168866, 0.9341051125851229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 274}], {
             RGBColor[
             0.20454056169243495`, 0.3323154773323579, 0.9349596544465153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 288}], {
             RGBColor[
             0.20983762189248398`, 0.33788302345562404`, 0.9352613141886098]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 318}], {
             RGBColor[
             0.20969889594004104`, 0.3377372136838731, 0.9352534139508448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 283}], {
             RGBColor[
             0.878557469851581, 0.4812239884723157, 0.21791952880036536`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 332}], {
             RGBColor[
             0.8214986576269006, 0.1662536800580077, 0.16822044486376803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 334}], {
             RGBColor[
             0.8927019922159016, 0.5360459310419723, 0.23584376702104354`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 364}], {
             RGBColor[
             0.8732653702236979, 0.4602425769354192, 0.2136613812182268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 366}], {
             RGBColor[
             0.9092462276793383, 0.5913616030865398, 0.3419442339894627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 391}], {
             RGBColor[
             0.8227133050515791, 0.17558999242598253`, 0.16938359260938823`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 314}], {
             RGBColor[
             0.1849157269952969, 0.31168853177927935`, 0.9338420491428545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 369}], {
             RGBColor[
             0.1837415562121556, 0.31045440383947037`, 0.9337751818537847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 312}], {
             RGBColor[
             0.46100266352577723`, 0.571153212435337, 0.9513046138622602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 331}], {
             RGBColor[
             0.30757882188877433`, 0.4345645888368619, 0.9410490742458533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 356}], {
             RGBColor[
             0.6597861746771188, 0.7286564919053182, 0.9611997608615672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 359}], {
             RGBColor[
             0.3499392226187198, 0.4775214990007658, 0.9435187957195283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 360}], {
             RGBColor[
             0.5184721491114823, 0.6174970812936685, 0.956042445038614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 380}], {
             RGBColor[
             0.5472854839726642, 0.6400062774766795, 0.9589142889816533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 310}], {
             RGBColor[
             0.9094103197175858, 0.5979549815728277, 0.4751163468578484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 316}], {
             RGBColor[
             0.8522226042580414, 0.8830674650503693, 0.8745751101286188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 319}], {
             RGBColor[
             0.9123741671932073, 0.6207364120366994, 0.4779545305476905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 384}], {
             RGBColor[
             0.9629443447193516, 0.8827390749129462, 0.5213129511813582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 310}], {
             RGBColor[
             0.8979684765940259, 0.5907693635082272, 0.5548367056098094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 356}], {
             RGBColor[
             0.9574019127188883, 0.9677509967704889, 0.9569916297931109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 360}], {
             RGBColor[
             0.816087887153252, 0.8565915861588391, 0.9518343139701578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 389}], {
             RGBColor[
             0.981271770948398, 0.982206986986089, 0.7147685106713391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 264}], {
             RGBColor[
             0.24881577416889822`, 0.37885153285572853`, 0.9374810622977428]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 279}], {
             RGBColor[
             0.2183447678357952, 0.34682457322625027`, 0.9357457835648868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 281}], {
             RGBColor[
             0.318201913769557, 0.44345916858997797`, 0.9417371947060786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 300}], {
             RGBColor[
             0.21690681128224154`, 0.345313189716754, 0.9356638940664279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 328}], {
             RGBColor[
             0.23450213577855084`, 0.36380699137038264`, 0.936665921766543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 394}], {
             RGBColor[
             0.29763886748570073`, 0.42564849142765915`, 0.9404269355800592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 271}], {
             RGBColor[
             0.8577136869121025, 0.5371034017102467, 0.5783377792427893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 287}], {
             RGBColor[
             0.8563718105158677, 0.5267891517148, 0.5770527968903222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 292}], {
             RGBColor[
             0.8574582528162021, 0.5351400233172219, 0.5780931752640834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 345}], {
             RGBColor[
             0.8617541752858404, 0.8926034039517254, 0.9866760766074392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 350}], {
             RGBColor[
             0.6219849446227963, 0.6978827145935297, 0.9666587839790601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 353}], {
             RGBColor[
             0.9443422105725244, 0.9537215111738743, 0.7488183078429457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 393}], {
             RGBColor[
             0.808698190108407, 0.8510901979921818, 0.9814053247963395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 400}], {
             RGBColor[
             0.8587699196703826, 0.545222069534533, 0.5793492289249624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 327}], {
             RGBColor[
             0.1874834373807122, 0.31438735819659225`, 0.9339882764507168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 335}], {
             RGBColor[
             0.19373393161436922`, 0.3209570239403897, 0.934344232850546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 349}], {
             RGBColor[
             0.19380914280268063`, 0.32103607566796977`, 0.9343485160164554]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 355}], {
             RGBColor[
             0.19867201809183277`, 0.32614726592096993`, 0.9346254495701933]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 284}], {
             RGBColor[
             0.5520990373737982, 0.6433480852372535, 0.9595712205145508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 325}], {
             RGBColor[
             0.3013026030921642, 0.42887910004945207`, 0.9406582888215985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 376}], {
             RGBColor[
             0.3252561022413611, 0.4540557463948223, 0.9420224051621189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 397}], {
             RGBColor[
             0.364256395049981, 0.48992231415871446`, 0.9444310732866698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 336}], {
             RGBColor[
             0.2683165494931898, 0.3993480841421268, 0.9385916026036494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 359}], {
             RGBColor[
             0.31376085658735253`, 0.4455463754257799, 0.941236947982536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 360}], {
             RGBColor[
             0.48229378308011506`, 0.5855219577186828, 0.9537605973016217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 279}], {
             RGBColor[
             0.22950792112061041`, 0.35855775511338905`, 0.9363815086300517]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 281}], {
             RGBColor[
             0.3293650670543722, 0.4551923504771167, 0.9423729197712435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 328}], {
             RGBColor[
             0.24566528906336602`, 0.3755401732575213, 0.9373016468317077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 394}], {
             RGBColor[
             0.30880202077051594`, 0.4373816733147978, 0.941062660645224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 321}], {
             RGBColor[
             0.19177497299708612`, 0.31889803422847507`, 0.9342326730553113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 325}], {
             RGBColor[
             0.2186342581575027, 0.34712884590911136`, 0.9357622696104455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 375}], {
             RGBColor[
             0.20089610111622702`, 0.32848491819461667`, 0.9347521078081966]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 381}], {
             RGBColor[
             0.19417265233719494`, 0.3214181472365799, 0.9343692173466818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 358}], {
             RGBColor[
             0.4679094050103473, 0.5710147999295367, 0.9528445815300333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 384}], {
             RGBColor[
             0.7959032258697958, 0.7536598609266292, 0.6159939861993788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 275}], {
             RGBColor[
             0.19585412945824818`, 0.323185486302614, 0.9344649749812033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 306}], {
             RGBColor[
             0.20993199303624877`, 0.33798221351119695`, 0.9352666884856375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 311}], {
             RGBColor[
             0.20008010519765723`, 0.3276272547470704, 0.9347056380477918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 317}], {
             RGBColor[
             0.1930340826347562, 0.32022143828982824`, 0.9343043774864909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 344}], {
             RGBColor[
             0.1945632673718405, 0.321828708404416, 0.9343914622950418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 346}], {
             RGBColor[
             0.20049511025135958`, 0.32806345137135173`, 0.9347292719716551]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 354}], {
             RGBColor[
             0.19683262012965425`, 0.3242139420381536, 0.9345206985773926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 279}], {
             RGBColor[
             0.19334852815726622`, 0.3205519404709839, 0.9343222846938173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 299}], {
             RGBColor[
             0.18802492021905656`, 0.3149564909916871, 0.9340191130973085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 300}], {
             RGBColor[
             0.1919105716037125, 0.31904055696148764`, 0.9342403951953585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 370}], {
             RGBColor[
             0.18660341497029534`, 0.3134623988466007, 0.9339381604763201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 371}], {
             RGBColor[
             0.1838466718007321, 0.3105648869877775, 0.9337811680310495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 309}], {
             RGBColor[
             0.5253850164437505, 0.6220146854886827, 0.9571050895141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 323}], {
             RGBColor[
             0.38701260190710624`, 0.5096325967781434, 0.9458810786650822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 362}], {
             RGBColor[
             0.5723371220999356, 0.658694027276514, 0.9617848366135348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 365}], {
             RGBColor[
             0.3297101598350657, 0.4597477851420956, 0.9422390562668672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 377}], {
             RGBColor[
             0.30404872534557215`, 0.4327759904647185, 0.9407776755353809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 388}], {
             RGBColor[
             0.3120924130263679, 0.44123041621648995`, 0.9412357516492327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 336}], {
             RGBColor[
             0.2213730230293102, 0.3500074614371033, 0.9359182382182554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 357}], {
             RGBColor[
             0.1969743042117703, 0.32436286099174727`, 0.9345287672762663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 287}], {
             RGBColor[
             0.8186608763962349, 0.14444124999544666`, 0.16550298235246705`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 292}], {
             RGBColor[
             0.8197473186965691, 0.15279212159786854`, 0.16654336072622833`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 303}], {
             RGBColor[
             0.8569664054518005, 0.38299924589270967`, 0.19999647199586007`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 333}], {
             RGBColor[
             0.8868896427416582, 0.5599013471362418, 0.5649582086174862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 337}], {
             RGBColor[
             0.8884909872626653, 0.561095627258048, 0.562247550040962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 345}], {
             RGBColor[
             0.8240432411662075, 0.5102555022323721, 0.5751262620695841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 353}], {
             RGBColor[
             0.9066312764528914, 0.571373609454521, 0.33726849330509057`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 385}], {
             RGBColor[
             0.9072101681764545, 0.5726118003162909, 0.40027728490932957`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 391}], {
             RGBColor[
             0.820118482997181, 0.15564505305760412`, 0.1668987880796643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 400}], {
             RGBColor[
             0.8210589855507496, 0.16287416781517963`, 0.16779941438710733`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 308}], {
             RGBColor[
             0.20474955864050876`, 0.33253514637595527`, 0.9349715565135248]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 342}], {
             RGBColor[
             0.19152273141080622`, 0.31863291232825464`, 0.9342183082701306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 348}], {
             RGBColor[
             0.1988777254844435, 0.3263634774332058, 0.9346371643018856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 374}], {
             RGBColor[
             0.19014395523747457`, 0.3171837311506246, 0.934139789006776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 375}], {
             RGBColor[
             0.1997235147350348, 0.3272524555617131, 0.9346853307484737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 378}], {
             RGBColor[
             0.2184441934159871, 0.34692907581497784`, 0.9357514457045917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 281}], {
             RGBColor[
             0.46139853851670076`, 0.5721415288193888, 0.9511515046102453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 293}], {
             RGBColor[
             0.4190878106551068, 0.5354941029446921, 0.9484555024448121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 394}], {
             RGBColor[
             0.4408354922328445, 0.55433085165707, 0.9498412454842259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 288}], {
             RGBColor[
             0.20843688657003606`, 0.3364107618199823, 0.9351815443841986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 318}], {
             RGBColor[
             0.20829816061759315`, 0.33626495204823137`, 0.9351736441464337]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 311}], {
             RGBColor[
             0.19837020308391207`, 0.32583003921146847`, 0.9346082616519875]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 317}], {
             RGBColor[
             0.19132418052101102`, 0.3184242227542263, 0.9342070010906866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 344}], {
             RGBColor[
             0.19285336525809532`, 0.32003149286881416`, 0.9342940858992375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 346}], {
             RGBColor[
             0.1987852081376144, 0.3262662358357499, 0.9346318955758508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 282}], {
             RGBColor[
             0.3470343998180849, 0.475005487491495, 0.9433337029793059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 301}], {
             RGBColor[
             0.3144566810509267, 0.44134464114731864`, 0.9414571987432081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 305}], {
             RGBColor[
             0.33855234976798615`, 0.46667071672258365`, 0.9428294114302973]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 339}], {
             RGBColor[
             0.38050139833268903`, 0.5039929195045905, 0.9454661905309516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 361}], {
             RGBColor[
             0.3943096577609078, 0.5159529397980152, 0.9463460406115533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 382}], {
             RGBColor[
             0.35057061271571854`, 0.4780683773681971, 0.9435590273381926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 373}], {
             RGBColor[
             0.19154984531155025`, 0.31866141075705723`, 0.9342198523666666]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 390}], {
             RGBColor[
             0.19904871949657826`, 0.326543202981606, 0.9346469021579138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 296}], {
             RGBColor[
             0.1835851599868279, 0.3102900214905575, 0.9337662753201197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 302}], {
             RGBColor[
             0.19139766926121787`, 0.31850146407963903`, 0.9342111861657245]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 330}], {
             RGBColor[
             0.18839714683821507`, 0.31534772476895345`, 0.9340403108526096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 367}], {
             RGBColor[
             0.18709347932173553`, 0.31397748755183885`, 0.9339660689161493]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 299}], {
             RGBColor[
             0.19371330684929777`, 0.320935346004614, 0.9343430583006869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 300}], {
             RGBColor[
             0.1975989582339537, 0.32501941197441453`, 0.9345643403987369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 328}], {
             RGBColor[
             0.215194282730263, 0.3435132136280431, 0.9355663680988517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 370}], {
             RGBColor[
             0.19229180160053655`, 0.3194412538595276, 0.9342621056796985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 371}], {
             RGBColor[
             0.1895350584309733, 0.3165437420007044, 0.9341051132344278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 291}], {
             RGBColor[
             0.20219476439486456`, 0.32984989564047235`, 0.9348260647607148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 336}], {
             RGBColor[
             0.22186501043454393`, 0.3505245713938071, 0.9359462561731533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 368}], {
             RGBColor[
             0.19638103924398845`, 0.323739301895437, 0.934494981714008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 387}], {
             RGBColor[
             0.19723551682458454`, 0.32463741200965124`, 0.9345436429481366]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 392}], {
             RGBColor[
             0.20599555407739328`, 0.33384476658079454`, 0.9350425141103704]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 293}], {
             RGBColor[
             0.356440478793437, 0.4831525603366694, 0.9439330500141462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 394}], {
             RGBColor[
             0.3781881603711747, 0.5019893090490473, 0.9453187930535599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 301}], {
             RGBColor[
             0.2824458229860667, 0.41361844480404447`, 0.9394174951734057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 305}], {
             RGBColor[
             0.30654149170312617`, 0.4389445203793095, 0.9407897078604948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 313}], {
             RGBColor[
             0.2998205585054363, 0.43188039345676055`, 0.940406960657616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 339}], {
             RGBColor[
             0.34849054026782905`, 0.4762667231613163, 0.9434264869611491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 340}], {
             RGBColor[
             0.29320777122887487`, 0.42492993475416496`, 0.9400303722049579]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 361}], {
             RGBColor[
             0.36229879969604784`, 0.48822674345474093`, 0.9443063370417508]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 382}], {
             RGBColor[
             0.3185597546508585, 0.45034218102492296`, 0.9415193237683902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 312}], {
             RGBColor[
             0.7398695405352704, 0.7057918843470511, 0.6108133774642039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 332}], {
             RGBColor[
             0.8748637305772158, 0.45283228980267326`, 0.21438239989975133`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 334}], {
             RGBColor[
             0.9460670651662169, 0.8226245407866379, 0.2820057220570269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 356}], {
             RGBColor[
             0.9386530516866118, 0.8632951638170323, 0.6207085244635109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 360}], {
             RGBColor[
             0.7973390261209754, 0.7521357532053826, 0.6155512086405578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 364}], {
             RGBColor[
             0.9266304431740131, 0.7468211866800847, 0.25982333625421017`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 366}], {
             RGBColor[
             0.9626113006296535, 0.8779402128312055, 0.388106189025446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 380}], {
             RGBColor[
             0.8261523609821573, 0.7746449493883936, 0.6184230525835972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 389}], {
             RGBColor[
             0.9625229099161214, 0.8777511540326326, 0.378485405341739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 334}], {
             RGBColor[
             0.8500382234662116, 0.8370769008965131, 0.6373182165494112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 366}], {
             RGBColor[
             0.8665824589296481, 0.8923925729410807, 0.7434186835178305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 397}], {
             RGBColor[
             0.5520222170780682, 0.6432815473581924, 0.9595663255932364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 324}], {
             RGBColor[
             0.1849819453905557, 0.31175813151118514`, 0.9338458201825032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 290}], {
             RGBColor[
             0.28938656912218486`, 0.4203385400712017, 0.9398338164907357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 304}], {
             RGBColor[
             0.3017569575169641, 0.43334060260203944`, 0.9405382918094687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 386}], {
             RGBColor[
             0.331585149915525, 0.4616241237277755, 0.94234929043675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 292}], {
             RGBColor[
             0.8184054423003344, 0.14247787160242187`, 0.16525837837376128`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 303}], {
             RGBColor[
             0.8556245290555657, 0.372684995897263, 0.19871148964339302`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 353}], {
             RGBColor[
             0.9052894000566567, 0.5610593594590743, 0.33598351095262347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 385}], {
             RGBColor[
             0.9058682917802197, 0.5622975503208443, 0.39899230255686247`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 391}], {
             RGBColor[
             0.8187766066009462, 0.14533080306215745`, 0.16561380572719725`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 400}], {
             RGBColor[
             0.8197171091545148, 0.15255991781973297`, 0.16651443203464028`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 318}], {
             RGBColor[
             0.21359522081764215`, 0.3418324981714975, 0.9354753038885282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 304}], {
             RGBColor[
             0.2699001201696922, 0.4010125173273108, 0.9386817846109934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 338}], {
             RGBColor[
             0.2338329245191738, 0.3631036079063329, 0.9366278111753308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 336}], {
             RGBColor[
             0.21513079622652476`, 0.34344648528733734`, 0.9355627526363838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 368}], {
             RGBColor[
             0.1896468250359693, 0.3166612157889672, 0.9341114781772385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 387}], {
             RGBColor[
             0.1905013026165654, 0.3175593259031815, 0.9341601394113672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 303}], {
             RGBColor[
             0.8567109713559, 0.3810358674996849, 0.1997518680171543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 309}], {
             RGBColor[
             0.7584292895983676, 0.45716808614862703`, 0.568384704834363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 362}], {
             RGBColor[
             0.8053813952545528, 0.4938474279364584, 0.5730644519337977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 385}], {
             RGBColor[
             0.9069547340805542, 0.5706484219232661, 0.4000326809306238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 400}], {
             RGBColor[
             0.8208035514548493, 0.16091078942215484`, 0.1675548104084016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 394}], {
             RGBColor[
             0.3358774325095808, 0.4653418831743506, 0.9426227908881267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 301}], {
             RGBColor[
             0.22980051567191817`, 0.3588652905383795, 0.9363981714568937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 313}], {
             RGBColor[
             0.24717525119128783`, 0.3771272391910956, 0.937387636941104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 329}], {
             RGBColor[
             0.23603593247132534`, 0.36541910894281576`, 0.9367532692191475]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 340}], {
             RGBColor[
             0.24056246391472638`, 0.3701767804885, 0.937011048488446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 343}], {
             RGBColor[
             0.20522639813651683`, 0.33303633491963003`, 0.9349987118174017]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 330}], {
             RGBColor[
             0.18388840354746627`, 0.31060874969954066`, 0.9337835445922895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 367}], {
             RGBColor[
             0.18258473603098674`, 0.3092385124824261, 0.9337093026558292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 398}], {
             RGBColor[
             0.17994179284220208`, 0.3064606116187368, 0.933558790951112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 325}], {
             RGBColor[
             0.267416015836295, 0.3984015661715987, 0.9385403185441094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 375}], {
             RGBColor[
             0.2496778587950193, 0.3797576384571041, 0.9375301567418605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 376}], {
             RGBColor[
             0.2913695149854919, 0.423578212516969, 0.9399044348846297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 378}], {
             RGBColor[
             0.2683985374759716, 0.3994342587103688, 0.9385962716979784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 397}], {
             RGBColor[
             0.33036980779411174`, 0.4594447802808611, 0.9423131030091806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 320}], {
             RGBColor[
             0.19458686072830475`, 0.3218535065179652, 0.9343928059017892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 347}], {
             RGBColor[
             0.1948950544058417, 0.32217743761366435`, 0.9344103570757931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 373}], {
             RGBColor[
             0.20172543232639267`, 0.32935659787913657`, 0.93479933699373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 390}], {
             RGBColor[
             0.2092243065114207, 0.3372383901036854, 0.935226386784977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 300}], {
             RGBColor[
             0.19227535029574405`, 0.31942396249511773`, 0.934261168802228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 370}], {
             RGBColor[
             0.1869681936623269, 0.3138458043802308, 0.9339589340831895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 371}], {
             RGBColor[
             0.18421145049276366`, 0.3109482925214076, 0.933801941637919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 370}], {
             RGBColor[
             0.19085384504698283`, 0.3179298703500313, 0.9341802161812396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 371}], {
             RGBColor[
             0.1880971018774196, 0.31503235849120814`, 0.934023223735969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 305}], {
             RGBColor[
             0.27396377293596785`, 0.4052836740351331, 0.9389132036243971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 313}], {
             RGBColor[
             0.2672428397382781, 0.39821954711258417`, 0.9385304564215183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 329}], {
             RGBColor[
             0.25610352101831557`, 0.38651141686430435`, 0.9378960886995618]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 339}], {
             RGBColor[
             0.3159128215006708, 0.4426058768171399, 0.9415499827250514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 340}], {
             RGBColor[
             0.26063005246171667`, 0.3912690884099886, 0.9381538679688604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 361}], {
             RGBColor[
             0.3297210809288895, 0.45456589711056455`, 0.9424298328056531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 382}], {
             RGBColor[
             0.2859820358837003, 0.41668133468074653`, 0.9396428195322926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 367}], {
             RGBColor[
             0.19039724530537674`, 0.31744995507150764`, 0.934154213501434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 377}], {
             RGBColor[
             0.22469777382228445`, 0.35350198532189486`, 0.9361075778573873]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 353}], {
             RGBColor[
             0.9435949291122223, 0.7996173553563373, 0.3704770005960165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 385}], {
             RGBColor[
             0.9441738208357854, 0.8008555462181073, 0.4334857922002555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 391}], {
             RGBColor[
             0.8570821356565119, 0.38388879895942046`, 0.20010729537059024`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 400}], {
             RGBColor[
             0.8580226382100805, 0.391117913716996, 0.20100792167803327`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 338}], {
             RGBColor[
             0.24620331291395298`, 0.37610567043717064`, 0.9373322864940637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 313}], {
             RGBColor[
             0.29133850845533754`, 0.4235456226878492, 0.9399026691086074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 329}], {
             RGBColor[
             0.28019918973537505`, 0.41183749243956935`, 0.9392683013866509]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 339}], {
             RGBColor[
             0.3400084902177303, 0.4679319523924049, 0.9429221954121405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 340}], {
             RGBColor[
             0.2847257211787761, 0.4165951639852536, 0.9395260806559493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 361}], {
             RGBColor[
             0.353816749645949, 0.47989197268582956`, 0.9438020454927423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 382}], {
             RGBColor[
             0.31007770460075973`, 0.44200741025601153`, 0.9410150322193817]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 308}], {
             RGBColor[
             0.2175738595337591, 0.3460142997224009, 0.9357018814775424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 311}], {
             RGBColor[
             0.21244806666191265`, 0.3406267664200514, 0.9354099751564218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 346}], {
             RGBColor[
             0.21286307171561503`, 0.3410629630443328, 0.9354336090802852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 348}], {
             RGBColor[
             0.21170202637769384`, 0.33984263077965143`, 0.9353674892659032]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 350}], {
             RGBColor[
             0.2854226113571807, 0.41364792547081863`, 0.9397004998858718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 354}], {
             RGBColor[
             0.2092005815939097, 0.33721345371113465`, 0.9352250356860227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 378}], {
             RGBColor[
             0.23126849430923743`, 0.36040822916142345`, 0.9364817706686093]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 343}], {
             RGBColor[
             0.1898749181249935, 0.3169009560874688, 0.9341244677412249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 348}], {
             RGBColor[
             0.20697593141094872`, 0.33487520531787435`, 0.9350983451491781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 354}], {
             RGBColor[
             0.20447448662716458`, 0.33224602824935756`, 0.9349558915692975]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 374}], {
             RGBColor[
             0.1982421611639798, 0.32569545903529307`, 0.9346009698540684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 378}], {
             RGBColor[
             0.22654239934249232`, 0.35544080369964637`, 0.9362126265518842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 323}], {
             RGBColor[
             0.5589942800594222, 0.6511253403818711, 0.9592466420721857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 362}], {
             RGBColor[
             0.7443188002522516, 0.8001867708802417, 0.9751504000206381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 365}], {
             RGBColor[
             0.5016918379873817, 0.6012405287458232, 0.9556046196739707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 385}], {
             RGBColor[
             0.845892139078253, 0.8769877648670494, 0.8021186290174642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 316}], {
             RGBColor[
             0.7693289728620583, 0.48993694637010154`, 0.5724844799948403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 319}], {
             RGBColor[
             0.8294805357972241, 0.22760589335643167`, 0.17586390041391192`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 384}], {
             RGBColor[
             0.8800507133233684, 0.4896085562326786, 0.2192223210475797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 317}], {
             RGBColor[
             0.19555015626042008`, 0.32286599119868276`, 0.934447664157275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 344}], {
             RGBColor[
             0.19707934099750435`, 0.3244732613132706, 0.9345347489658259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 346}], {
             RGBColor[
             0.20301118387702347`, 0.33070800428020625`, 0.9348725586424393]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 354}], {
             RGBColor[
             0.19934869375531813`, 0.32685849494700814`, 0.9346639852481768]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 356}], {
             RGBColor[
             0.746600049419986, 0.8012844499471021, 0.9674404180913663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 359}], {
             RGBColor[
             0.4367530973615871, 0.5501494570425497, 0.9497594529493274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 360}], {
             RGBColor[
             0.6052860238543496, 0.6901250393354524, 0.9622831022684131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 380}], {
             RGBColor[
             0.6340993587155315, 0.7126342355184634, 0.9651549462114524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 389}], {
             RGBColor[
             0.7704699076494956, 0.8157404401627024, 0.7252172989695943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 329}], {
             RGBColor[
             0.27347825653768526`, 0.4047733655170204, 0.9388855541837721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 339}], {
             RGBColor[
             0.3332875570200404, 0.460867825469856, 0.9425394482092617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 340}], {
             RGBColor[
             0.2780047879810863, 0.40953103706270466`, 0.9391433334530706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 358}], {
             RGBColor[
             0.28110733593194254`, 0.4127920116719563, 0.9393200189690635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 361}], {
             RGBColor[
             0.3470958164482592, 0.47282784576328063`, 0.9434192982898635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 369}], {
             RGBColor[
             0.1815795981118552, 0.30818204879999395`, 0.9336520615383029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 322}], {
             RGBColor[
             0.18811052101816012`, 0.31504646285894905`, 0.9340239879361825]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 351}], {
             RGBColor[
             0.5108480401165528, 0.6087959957654421, 0.956444390370581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 399}], {
             RGBColor[
             0.5357585344043984, 0.6303722138797264, 0.9580316650391174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 344}], {
             RGBColor[
             0.19003331843460333`, 0.31706744485602845`, 0.9341334884045249]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 346}], {
             RGBColor[
             0.19596516131412245`, 0.3233021878229641, 0.9344712980811385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 354}], {
             RGBColor[
             0.19230267119241712`, 0.319452678489766, 0.934262724686876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 322}], {
             RGBColor[
             0.20428384988578308`, 0.3320456569470981, 0.9349450350888977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 384}], {
             RGBColor[
             0.8830145607989899, 0.5123899866965502, 0.22206050473742173`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 347}], {
             RGBColor[
             0.1840162025368019, 0.3107430745402564, 0.9337908225556705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 398}], {
             RGBColor[
             0.182257588923795, 0.30889466013044303`, 0.9336906721120455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 375}], {
             RGBColor[
             0.19367454863692518`, 0.3208946086659977, 0.9343408510778299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 381}], {
             RGBColor[
             0.18695109985789307`, 0.313827837707961, 0.9339579606163151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 327}], {
             RGBColor[
             0.19043725974580353`, 0.3174920127854582, 0.9341564922646202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 335}], {
             RGBColor[
             0.19668775397946056`, 0.3240616785292556, 0.9345124486644494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 349}], {
             RGBColor[
             0.19676296516777197`, 0.32414073025683565`, 0.9345167318303588]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 355}], {
             RGBColor[
             0.2016258404569241, 0.32925192050983587`, 0.9347936653840967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 362}], {
             RGBColor[
             0.6059463857156073, 0.6878046821697024, 0.9639263891716204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 365}], {
             RGBColor[
             0.3633194234507374, 0.48885844003528395`, 0.9443806088249529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 377}], {
             RGBColor[
             0.3376579889612439, 0.46188664535790686`, 0.9429192280934666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 388}], {
             RGBColor[
             0.34570167664203966`, 0.47034107110967827`, 0.9433773042073184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 395}], {
             RGBColor[
             0.42965137086591587`, 0.5465641553634234, 0.9485979833191546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 376}], {
             RGBColor[
             0.26222548998781436`, 0.392945994406499, 0.9382447257757333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 397}], {
             RGBColor[
             0.3012257827964342, 0.4288125621703911, 0.9406533939002841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 363}], {
             RGBColor[
             0.3080486907375876, 0.43502729111889293`, 0.9410769734898234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 383}], {
             RGBColor[
             0.2999445651565369, 0.428007904865782, 0.9405605857739958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 335}], {
             RGBColor[
             0.19201380881889718`, 0.3191490658202642, 0.9342462744020376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 349}], {
             RGBColor[
             0.19208902000720862`, 0.3192281175478443, 0.934250557567947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 355}], {
             RGBColor[
             0.19695189529636073`, 0.3243393078008444, 0.9345274911216848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 339}], {
             RGBColor[
             0.322148238300078, 0.44915969522157617`, 0.9419050804873051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 340}], {
             RGBColor[
             0.2668654692611238, 0.39782290681442484`, 0.9385089657311141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 341}], {
             RGBColor[
             0.2558412218032698, 0.3862357237585604, 0.9378811511473018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 343}], {
             RGBColor[
             0.23152940348291426`, 0.3606824612455548, 0.9364966290600697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 358}], {
             RGBColor[
             0.26996801721198005`, 0.40108388142367646`, 0.9386856512471069]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 367}], {
             RGBColor[
             0.1873967228823739, 0.314296215760822, 0.9339833381883191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 398}], {
             RGBColor[
             0.18475377969358928`, 0.31151831489713266`, 0.9338328264836019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 392}], {
             RGBColor[
             0.22201549227327083`, 0.35068273734740874`, 0.9359548258912509]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 334}], {
             RGBColor[
             0.8890082529415364, 0.5076542323723299, 0.23230663812042954`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 356}], {
             RGBColor[
             0.8815942394619314, 0.5483248554027244, 0.5710094405269136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 364}], {
             RGBColor[
             0.8695716309493327, 0.4318508782657767, 0.2101242523176128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 366}], {
             RGBColor[
             0.905552488404973, 0.5629699044168974, 0.3384071050888487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 380}], {
             RGBColor[
             0.7690935487574768, 0.4596746409740855, 0.5687239686469998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 389}], {
             RGBColor[
             0.905464097691441, 0.5627808456183245, 0.32878632140514163`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 337}], {
             RGBColor[
             0.9553778772118539, 0.9662414744033965, 0.9604177939535141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 345}], {
             RGBColor[
             0.8909301311153961, 0.9154013493777207, 0.9732965059821361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 353}], {
             RGBColor[
             0.97351816640208, 0.9765194565998694, 0.7354387372176427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 391}], {
             RGBColor[
             0.8870053729463696, 0.5607909002029526, 0.5650690319922165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 364}], {
             RGBColor[
             0.9407749655383337, 0.8016431292497415, 0.27774757447488835`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 366}], {
             RGBColor[
             0.9767558229939741, 0.9327621554008622, 0.40603042724612426`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 391}], {
             RGBColor[
             0.890222900366215, 0.5169905447403047, 0.23346978586604977`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 349}], {
             RGBColor[
             0.19833951424086566`, 0.32579778329164166`, 0.9346065139677762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 355}], {
             RGBColor[
             0.20320238953001776`, 0.3309089735446419, 0.934883447521514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 359}], {
             RGBColor[
             0.2802453493603669, 0.4103194523243253, 0.9393282894277089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 345}], {
             RGBColor[
             0.8925314756364031, 0.9165956294995268, 0.9705858474056119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 353}], {
             RGBColor[
             0.9751195109230872, 0.9777137367216755, 0.7327280786411184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 391}], {
             RGBColor[
             0.8886067174673766, 0.5619851803247587, 0.5623583734156922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 340}], {
             RGBColor[
             0.326674769743479, 0.4539173667672604, 0.9421628597566036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 361}], {
             RGBColor[
             0.39576579821065194`, 0.5172141754678363, 0.9464388245933966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 382}], {
             RGBColor[
             0.3520267531654626, 0.47932961303801835`, 0.943651811320036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 343}], {
             RGBColor[
             0.2360559349263153, 0.3654401327912391, 0.9367544083293682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 358}], {
             RGBColor[
             0.2744945486553811, 0.4058415529693607, 0.9389434305164055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 361}], {
             RGBColor[
             0.34048302917169776`, 0.46587738706068504`, 0.9430427098372054]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 358}], {
             RGBColor[
             0.26347030119752707`, 0.39425436991349627`, 0.9383156159325932]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 348}], {
             RGBColor[
             0.1937491041812462, 0.3209729712701737, 0.9343450969057838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 374}], {
             RGBColor[
             0.18501533393427727`, 0.31179322498759243`, 0.9338477216106742]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 346}], {
             RGBColor[
             0.19749434605120672`, 0.3249094579375519, 0.9345583828896893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 354}], {
             RGBColor[
             0.1938318559295014, 0.32105994860435383`, 0.9343498094954268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 350}], {
             RGBColor[
             0.5883144988769012, 0.6710348151156551, 0.9634472668058549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 353}], {
             RGBColor[
             0.9106717648266294, 0.9268736116959997, 0.7456067906697404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 354}], {
             RGBColor[
             0.1997636988090205, 0.3272946915712895, 0.9346876191720402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 398}], {
             RGBColor[
             0.182565782601332, 0.30921859122614215`, 0.9337082232860494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 354}], {
             RGBColor[
             0.19860265347109932`, 0.3260743593066081, 0.9346214993576583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 374}], {
             RGBColor[
             0.19237032800791454`, 0.3195237900925436, 0.9342665776424293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 378}], {
             RGBColor[
             0.22067056618642705`, 0.3492691347568969, 0.935878234340245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 355}], {
             RGBColor[
             0.20327760071832918`, 0.33098802527222193`, 0.9348877306874234]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 355}], {
             RGBColor[
             0.2588476494190366, 0.38932088860423164`, 0.9380551008583563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 395}], {
             RGBColor[
             0.37411784951982285`, 0.4984638103693781, 0.9450594364453463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 399}], {
             RGBColor[
             0.33446531711843736`, 0.46411877979752536`, 0.9425328121440877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 396}], {
             RGBColor[
             0.18539177638104404`, 0.312188889866974, 0.9338691594511209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 391}], {
             RGBColor[
             0.9067470066576029, 0.5722631625212318, 0.3373793166798207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 400}], {
             RGBColor[
             0.9076875092111716, 0.5794922772788073, 0.33827994298726377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 374}], {
             RGBColor[
             0.18986888322413037`, 0.3168946130240269, 0.9341241240625486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 359}], {
             RGBColor[
             0.6355366085129286, 0.7076527365125309, 0.9596545999486343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 360}], {
             RGBColor[
             0.804069535005691, 0.8476283188054337, 0.97217824926772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 364}], {
             RGBColor[
             0.9333609520587287, 0.8423137522801358, 0.6164503768813724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 380}], {
             RGBColor[
             0.8328828698668729, 0.8701375149884446, 0.9750500932107594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 389}], {
             RGBColor[
             0.969253418800837, 0.9732437196326836, 0.7351124459689012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 360}], {
             RGBColor[
             0.49422258294729215`, 0.5964933259008812, 0.9544972841256812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 380}], {
             RGBColor[
             0.6915688443012366, 0.7589781043767949, 0.9698927773878063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 389}], {
             RGBColor[
             0.8279393932352007, 0.862084309021034, 0.7299551301459482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 382}], {
             RGBColor[
             0.3658350125936814, 0.49128963333144304`, 0.9445316614006376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 365}], {
             RGBColor[
             0.5486439436435668, 0.6379198705336546, 0.9602843667734056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 385}], {
             RGBColor[
             0.892844244734438, 0.9136671066548807, 0.806798376116899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 383}], {
             RGBColor[
             0.36642168177165046`, 0.49179777668654956`, 0.9445690434418867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 393}], {
             RGBColor[
             0.5482487832688899, 0.640773127747212, 0.9590042434848745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 366}], {
             RGBColor[
             0.9573192010017704, 0.856958801294309, 0.38384804144330753`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 380}], {
             RGBColor[
             0.8208602613542741, 0.753663537851497, 0.6141649050014586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 391}], {
             RGBColor[
             0.8707862783740112, 0.44118719063375156`, 0.21128740006323304`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 377}], {
             RGBColor[
             0.2803555468892034, 0.41200183372185906`, 0.9392772056952516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 388}], {
             RGBColor[
             0.2883992345699991, 0.4204562594736305, 0.9397352818091035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 372}], {
             RGBColor[
             0.1818899475322301, 0.30850824571809776`, 0.9336697354786725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 387}], {
             RGBColor[
             0.18468757746568928`, 0.3114487321581461, 0.9338290563646603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 387}], {
             RGBColor[
             0.18274442511282618`, 0.30940635583231196`, 0.9337183967128011]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 392}], {
             RGBColor[
             0.19150446236563495`, 0.31861371040345526`, 0.9342172678750348]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 390}], {
             RGBColor[
             0.20548402624046883`, 0.3333071183914488, 0.9350133833567951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 381}], {
             RGBColor[
             0.196072227977034, 0.3234147216741027, 0.9344773953692003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 397}], {
             RGBColor[
             0.32517928194563106`, 0.4539892085157613, 0.9420175102408045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 388}], {
             RGBColor[
             0.26273780008050557`, 0.39348446479625343`, 0.9382739010776171]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 389}], {
             RGBColor[
             0.8567527280963826, 0.8845935052040448, 0.7328269740889874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 393}], {
             RGBColor[
             0.5401446576878393, 0.6337537414941011, 0.9584878557690468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 400}], {
             RGBColor[
             0.9082664009347345, 0.5807304681405772, 0.40128873459150277`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 395}], {
             RGBColor[
             0.35473118198517756`, 0.4781619748017699, 0.9439526563033052]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.027885652381746694`], {
             RGBColor[
             0.1818132732838514, 0.3084276562216236, 0.9336653689936567]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.027885652381746694`], {
             RGBColor[
             0.20182540810126717`, 0.3294616787573599, 0.9348050304662081]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.027885652381746694`], {
             RGBColor[
             0.23621542372166607`, 0.36560776562732644`, 0.9367634909803209]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.027885652381746694`], {
             RGBColor[
             0.2008450066857079, 0.32843121470856707`, 0.9347491980559659]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.027885652381746694`], {
             RGBColor[
             0.18681770269069906`, 0.3136876288273712, 0.9339503638449868]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.027885652381746694`], {
             RGBColor[
             0.9261633007621113, 0.943961492267368, 0.992819476494071]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.027885652381746694`], {
             RGBColor[
             0.25494849258932906`, 0.3852974087524073, 0.9378303115392425]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.027885652381746694`], {
             RGBColor[
             0.25559866423556843`, 0.38598078037586825`, 0.937867337852653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.027885652381746694`], {
             RGBColor[
             0.6863588655876156, 0.7549080294084094, 0.9693734953996518]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.027885652381746694`], {
             RGBColor[
             0.8429670986480872, 0.3312695252776902, 0.18877864823079255`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.027885652381746694`], {
             RGBColor[
             0.873192830390407, 0.9017242770380856, 0.9877671057427206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.027885652381746694`], {
             RGBColor[
             0.242785484860208, 0.37251331644986996`, 0.9371376462426264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.027885652381746694`], {
             RGBColor[
             0.21336291477373137`, 0.3415883297902934, 0.9354620744029933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.027885652381746694`], {
             RGBColor[
             0.3386493168091526, 0.46774275003568394`, 0.9427994129046144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.027885652381746694`], {
             RGBColor[
             0.18212992963139682`, 0.3087604821200659, 0.9336834021041983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.027885652381746694`], {
             RGBColor[
             0.22895368331262583`, 0.3579752160364906, 0.9363499456068083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.027885652381746694`], {
             RGBColor[
             0.8276616884309496, 0.21362543547524793`, 0.17412217012187317`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.027885652381746694`], {
             RGBColor[
             0.9925358512363838, 0.9864432654728553, 0.42895165434603927`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.027885652381746694`], {
             RGBColor[
             0.19951285246669712`, 0.3270310361609309, 0.9346733338439388]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.027885652381746694`], {
             RGBColor[
             0.3846257063952153, 0.5075651878546001, 0.9457289877937134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.027885652381746694`], {
             RGBColor[
             0.19666790482252822`, 0.3240408158068105, 0.9345113182843263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.027885652381746694`], {
             RGBColor[
             0.24203296140503872`, 0.3717223665857442, 0.9370947911451132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.027885652381746694`], {
             RGBColor[
             0.2119196850624197, 0.340071403857656, 0.9353798846060012]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.027885652381746694`], {
             RGBColor[
             0.2601817623901309, 0.39079790712151985`, 0.9381283385124692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.027885652381746694`], {
             RGBColor[
             0.3639618362230004, 0.489667182107741, 0.9444123042586827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.027885652381746694`], {
             RGBColor[
             0.1822568035379685, 0.30889383464014303`, 0.9336906273854845]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.027885652381746694`], {
             RGBColor[
             0.20503271821821972`, 0.3328327650454837, 0.9349876820325784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.027885652381746694`], {
             RGBColor[
             0.19159599737019925`, 0.31870991949690686`, 0.9342224806581308]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.027885652381746694`], {
             RGBColor[
             0.18584110899752487`, 0.3126611669362287, 0.9338947482789014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.027885652381746694`], {
             RGBColor[
             0.20069898841488326`, 0.3282777402478373, 0.9347408825314572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.027885652381746694`], {
             RGBColor[
             0.9842583887354778, 0.9877584534482328, 0.9105427668445933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.027885652381746694`], {
             RGBColor[
             0.8215188663850046, 0.16640901342833042`, 0.16823979679335105`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.027885652381746694`], {
             RGBColor[
             0.24658940627570813`, 0.37651147904010834`, 0.9373542739398417]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.027885652381746694`], {
             RGBColor[
             0.1829376663072982, 0.30960946457990146`, 0.9337294015129516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.027885652381746694`], {
             RGBColor[
             0.19009976398754364`, 0.3171372833450601, 0.9341372723804675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.027885652381746694`], {
             RGBColor[
             0.24565388341041777`, 0.3755281851931126, 0.9373009972966455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.027885652381746694`], {
             RGBColor[
             0.2843315036737978, 0.41618081639268795`, 0.9395036305522334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.027885652381746694`], {
             RGBColor[
             0.2587257572717294, 0.3892675534260234, 0.9380454211749428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.027885652381746694`], {
             RGBColor[
             0.19817415326039348`, 0.32562397841667373`, 0.9345970969045678]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.027885652381746694`], {
             RGBColor[
             0.1934487547814754, 0.32065728500776275`, 0.934327992451794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.027885652381746694`], {
             RGBColor[
             0.19479503600678127`, 0.322072311934719, 0.9344046611759306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.027885652381746694`], {
             RGBColor[
             0.183885630512114, 0.31060583506356493`, 0.9337833866720284]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.027885652381746694`], {
             RGBColor[
             0.194697223000598, 0.3219695042635176, 0.9343990908699299]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.027885652381746694`], {
             RGBColor[
             0.22831342724773274`, 0.3573022663177088, 0.9363134839710866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.027885652381746694`], {
             RGBColor[
             0.23972125787035842`, 0.36929261960032556`, 0.9369631430486721]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.027885652381746694`], {
             RGBColor[
             0.8055364749096104, 0.8480104835941301, 0.9812520057187881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.027885652381746694`], {
             RGBColor[
             0.18100426741029385`, 0.3075773397545796, 0.9336192973059745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.027885652381746694`], {
             RGBColor[
             0.20793893985757575`, 0.3358873882535414, 0.9351531870555702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.027885652381746694`], {
             RGBColor[
             0.18369802063003998`, 0.31040864518235156`, 0.9337727025667882]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.027885652381746694`], {
             RGBColor[
             0.23112771995435683`, 0.3602602663888343, 0.9364737537773559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.027885652381746694`], {
             RGBColor[
             0.20120879960667537`, 0.3288135841343073, 0.9347699155246316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.027885652381746694`], {
             RGBColor[
             0.9889946602077696, 0.9897170234186503, 0.8320504914710569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.027885652381746694`], {
             RGBColor[
             0.40260480881009003`, 0.5231377827104023, 0.9468746003012931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.027885652381746694`], {
             RGBColor[
             0.9482538006021336, 0.8325505933258706, 0.2772219972063093]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.027885652381746694`], {
             RGBColor[
             0.8037373305687819, 0.8466049783610714, 0.9810726838248541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.027885652381746694`], {
             RGBColor[
             0.5183980864407423, 0.6198979459970778, 0.9552293428008269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.027885652381746694`], {
             RGBColor[
             0.3482989604247025, 0.47610078633028297`, 0.9434142796629524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.027885652381746694`], {
             RGBColor[
             0.19320352841391442`, 0.32039953654720643`, 0.9343140271729413]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.027885652381746694`], {
             RGBColor[
             0.21627237251575757`, 0.34464635434743823`, 0.9356277637172448]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.027885652381746694`], {
             RGBColor[
             0.7070237961498369, 0.7710516302229059, 0.9714331825533382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.027885652381746694`], {
             RGBColor[
             0.21726621743653565`, 0.3456909483725835, 0.9356843617152213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.027885652381746694`], {
             RGBColor[
             0.9918038536315829, 0.990878697092375, 0.7854948864789351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.027885652381746694`], {
             RGBColor[
             0.18932442036239164`, 0.31632234803540016`, 0.9340931177080333]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.027885652381746694`], {
             RGBColor[
             0.9925852496598342, 0.986548923705669, 0.43432836788688456`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.027885652381746694`], {
             RGBColor[
             0.3764941167365503, 0.5005220135978444, 0.9452108500911456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.027885652381746694`], {
             RGBColor[
             0.19612721011213427`, 0.3234725113841618, 0.9344805265204555]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.027885652381746694`], {
             RGBColor[
             0.17940647345367122`, 0.30589795700018124`, 0.9335283053038692]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.027885652381746694`], {
             RGBColor[
             0.8216043579673015, 0.8605890294596807, 0.9828465511894319]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.027885652381746694`], {
             RGBColor[
             0.5728179374316162, 0.6640784326178184, 0.9595134728173111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.027885652381746694`], {
             RGBColor[
             0.1969643686712329, 0.32435241810869275`, 0.934528201461931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.027885652381746694`], {
             RGBColor[
             0.9697038754518477, 0.9769257804341147, 0.9361676157519565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.027885652381746694`], {
             RGBColor[
             0.46553671991296847`, 0.576982707272407, 0.9510679023901947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.027885652381746694`], {
             RGBColor[
             0.1985117660113969, 0.3259788308238631, 0.9346163234512842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.027885652381746694`], {
             RGBColor[
             0.24853385159996577`, 0.37855521436085726`, 0.9374650072245091]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.027885652381746694`], {
             RGBColor[
             0.18190969424137163`, 0.30852900076141915`, 0.9336708600245455]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.027885652381746694`], {
             RGBColor[
             0.2829350020755027, 0.41471300466956446`, 0.9394241018521495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.027885652381746694`], {
             RGBColor[
             0.1969521059625652, 0.3243395292243824, 0.9345275031188135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.027885652381746694`], {
             RGBColor[
             0.22046571832082573`, 0.34905382666204504`, 0.9358665685573442]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.027885652381746694`], {
             RGBColor[
             0.199051197909799, 0.3265458079510415, 0.9346470432998802]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.027885652381746694`], {
             RGBColor[
             0.20310658273494972`, 0.3308082745285237, 0.9348779914662683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.027885652381746694`], {
             RGBColor[
             0.22915597848204, 0.35818784108579943`, 0.9363614660174375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.027885652381746694`], {
             RGBColor[
             0.7597586089991939, 0.8122484668202457, 0.9766892958633172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.027885652381746694`], {
             RGBColor[
             0.9509849302078126, 0.9629652217205732, 0.9678539073672795]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.027885652381746694`], {
             RGBColor[
             0.21428709115836797`, 0.3425596977667136, 0.935514704880902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.027885652381746694`], {
             RGBColor[
             0.1818888062976524, 0.30850704620819813`, 0.9336696704870515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.027885652381746694`], {
             RGBColor[
             0.2680992625939086, 0.39911970183419715`, 0.9385792284361825]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.027885652381746694`], {
             RGBColor[
             0.18684859723136407`, 0.31372010094843716`, 0.9339521232433733]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.027885652381746694`], {
             RGBColor[
             0.4303958842275222, 0.5472090154169172, 0.9486454230522088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.027885652381746694`], {
             RGBColor[
             0.23222586891438338`, 0.3614144905724877, 0.9365362917360636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.027885652381746694`], {
             RGBColor[
             0.21556902434658207`, 0.3439070908267852, 0.9355877090795206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.027885652381746694`], {
             RGBColor[
             0.5925759149291727, 0.6801188488370776, 0.961068893181775]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.027885652381746694`], {
             RGBColor[
             0.20437042968316516`, 0.3321366578036229, 0.9349499656802752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.027885652381746694`], {
             RGBColor[
             0.3425287629814334, 0.47110293132347947`, 0.9430466077842526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.027885652381746694`], {
             RGBColor[
             0.1791057270796212, 0.3055818534926332, 0.9335111782427814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.027885652381746694`], {
             RGBColor[
             0.24723118250472642`, 0.37718602654776967`, 0.9373908221466615]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.027885652381746694`], {
             RGBColor[
             0.21162927735784165`, 0.3397661669472325, 0.9353633463168451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.027885652381746694`], {
             RGBColor[
             0.2986247548964671, 0.43120392967218313`, 0.9403176100643942]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.027885652381746694`], {
             RGBColor[
             0.1932487717488401, 0.3204470901608064, 0.9343166037139339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.027885652381746694`], {
             RGBColor[
             0.9021660914511284, 0.9248267689496842, 0.9905306012474278]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.027885652381746694`], {
             RGBColor[
             0.387712192347488, 0.5102385468551641, 0.9459256559493198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.027885652381746694`], {
             RGBColor[
             0.8539737461394735, 0.41587144104017043`, 0.19931862629877445`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.027885652381746694`], {
             RGBColor[
             0.34903475823839447`, 0.4767380974142295, 0.9434611640490004]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.027885652381746694`], {
             RGBColor[
             0.19478977051563845`, 0.3220667775696765, 0.9344043613139996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.027885652381746694`], {
             RGBColor[
             0.22404918964109946`, 0.35282028222485723`, 0.936070641947763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.027885652381746694`], {
             RGBColor[
             0.9853022906708313, 0.9881901337255575, 0.8932426102441758]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.027885652381746694`], {
             RGBColor[
             0.1865190623784995, 0.31337373892436005`, 0.9339333567210057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.027885652381746694`], {
             RGBColor[
             0.2230811340648649, 0.3518027944359661, 0.9360155126148064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.027885652381746694`], {
             RGBColor[
             0.3063635945960659, 0.4393379408672382, 0.9407583255366989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.027885652381746694`], {
             RGBColor[
             0.1827503081177702, 0.3094125392435122, 0.9337187317412295]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.027885652381746694`], {
             RGBColor[
             0.8529626688242167, 0.8855932953383124, 0.985837534872859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.027885652381746694`], {
             RGBColor[
             0.8266120846200963, 0.20555772064570646`, 0.17311706832724205`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.027885652381746694`], {
             RGBColor[
             0.1804406002012431, 0.3069848897793021, 0.93358719729229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.027885652381746694`], {
             RGBColor[
             0.1856485479005117, 0.3124587730141891, 0.9338837822092951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.027885652381746694`], {
             RGBColor[
             0.18667779652152947`, 0.3135405785730105, 0.9339423963956253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.027885652381746694`], {
             RGBColor[
             0.9551078718556497, 0.8597247018622127, 0.2827369438226184]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.027885652381746694`], {
             RGBColor[
             0.24002120291967022`, 0.3696078808647668, 0.9369802244755014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.027885652381746694`], {
             RGBColor[
             0.5585316039927765, 0.6524801435401812, 0.9583888003164419]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.027885652381746694`], {
             RGBColor[
             0.3574473894517768, 0.48402469574012214`, 0.9439972094709195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.027885652381746694`], {
             RGBColor[
             0.2397898236287226, 0.36936468655968646`, 0.936967047767177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.027885652381746694`], {
             RGBColor[
             0.41254771032069193`, 0.531749824254125, 0.9475081531933861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.027885652381746694`], {
             RGBColor[
             0.24372417422141443`, 0.37349993848484087`, 0.9371911032130806]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.027885652381746694`], {
             RGBColor[
             0.18936604401309215`, 0.31636609713137825`, 0.934095488113364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.027885652381746694`], {
             RGBColor[
             0.843157812611701, 0.33273543637341757`, 0.18896127613772973`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.027885652381746694`], {
             RGBColor[
             0.22661866237074535`, 0.3555209609776956, 0.9362169696185221]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.027885652381746694`], {
             RGBColor[
             0.1925981967986741, 0.3197632946393477, 0.9342795544329613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.027885652381746694`], {
             RGBColor[
             0.18255935854789945`, 0.309211839138676, 0.9337078574457099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.027885652381746694`], {
             RGBColor[
             0.3393687513351076, 0.46836588806223545`, 0.9428452546364373]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.027885652381746694`], {
             RGBColor[
             0.3039019362504366, 0.4367505818678281, 0.9406181377356125]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.027885652381746694`], {
             RGBColor[
             0.8193361618613183, 0.1496317899920564, 0.1661496364764569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.027885652381746694`], {
             RGBColor[
             0.21566341381177923`, 0.3440063001393452, 0.9355930844199268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.027885652381746694`], {
             RGBColor[
             0.8141109072907318, 0.8547088953383618, 0.982106625005912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.027885652381746694`], {
             RGBColor[
             0.19287402797566439`, 0.32005321069507126`, 0.9342952626104353]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.027885652381746694`], {
             RGBColor[
             0.18340497994045135`, 0.3101006408377411, 0.933756014333031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.027885652381746694`], {
             RGBColor[
             0.17911500115561352`, 0.3055916011345115, 0.9335117063876894]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.027885652381746694`], {
             RGBColor[
             0.335355251737071, 0.46488959643477135`, 0.9425895179910487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.027885652381746694`], {
             RGBColor[
             0.18263620644148504`, 0.30929261114727236`, 0.9337122338195634]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.027885652381746694`], {
             RGBColor[
             0.29264465833089975`, 0.42491846902175034`, 0.9399770524117451]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.027885652381746694`], {
             RGBColor[
             0.2889051941793347, 0.4209880551027343, 0.939764095460355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.027885652381746694`], {
             RGBColor[
             0.30694355404168716`, 0.4399475150161388, 0.940791353369154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.027885652381746694`], {
             RGBColor[
             0.4063466574019441, 0.5263787838898877, 0.9471130275847793]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.027885652381746694`], {
             RGBColor[
             0.3557668224000087, 0.48256907302763663`, 0.9438901252244479]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.027885652381746694`], {
             RGBColor[
             0.4741596199861951, 0.5839831660090739, 0.9517467286706829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.027885652381746694`], {
             RGBColor[
             0.19890345919190142`, 0.32639052519135536`, 0.9346386297984558]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.027885652381746694`], {
             RGBColor[
             0.5812572311839399, 0.6709298314718057, 0.9601778449356456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.027885652381746694`], {
             RGBColor[
             0.24987309085249598`, 0.3799628397279394, 0.9375412749187138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.027885652381746694`], {
             RGBColor[
             0.1991293041825628, 0.32662790259593993`, 0.9346514913365662]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.027885652381746694`], {
             RGBColor[
             0.24721508689536167`, 0.3771691090418067, 0.9373899055255195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.027885652381746694`], {
             RGBColor[
             0.25655300447979307`, 0.38698385248121464`, 0.9379216861177417]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.027885652381746694`], {
             RGBColor[
             0.21032620428650672`, 0.3383965545296549, 0.9352891382331565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.027885652381746694`], {
             RGBColor[
             0.23840666361665402`, 0.3679108976895925, 0.9368882788506916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.027885652381746694`], {
             RGBColor[
             0.20761230953904478`, 0.335544079079207, 0.935134585942136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.027885652381746694`], {
             RGBColor[
             0.2008438754397465, 0.3284300256973365, 0.9347491336331819]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.027885652381746694`], {
             RGBColor[
             0.20565135384863537`, 0.33348299031681494`, 0.9350229124165412]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.027885652381746694`], {
             RGBColor[
             0.18637271886218407`, 0.3132199226099977, 0.9339250226742475]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.027885652381746694`], {
             RGBColor[
             0.1858996679095085, 0.31272271606557295`, 0.9338980831223087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.027885652381746694`], {
             RGBColor[
             0.20187169700218524`, 0.3295103313271106, 0.9348076665506371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.027885652381746694`], {
             RGBColor[
             0.24686136029389427`, 0.3767973199561026, 0.9373697613188575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.027885652381746694`], {
             RGBColor[
             0.1911403477299942, 0.3182310028351955, 0.9341965320851944]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.027885652381746694`], {
             RGBColor[
             0.18214142158537838`, 0.30877256089233246`, 0.9336840565539767]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.027885652381746694`], {
             RGBColor[
             0.19529547244710238`, 0.32259830236299947`, 0.9344331602908775]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.027885652381746694`], {
             RGBColor[
             0.8795463410175769, 0.5459298918751729, 0.22120285316675511`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.027885652381746694`], {
             RGBColor[
             0.19529691214488243`, 0.32259981557664835`, 0.9344332422795363]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.027885652381746694`], {
             RGBColor[
             0.17905422337022397`, 0.30552771982853294`, 0.9335082451827241]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.027885652381746694`], {
             RGBColor[
             0.21499276582137244`, 0.3433014065798891, 0.935554892009008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.027885652381746694`], {
             RGBColor[
             0.22554056397195027`, 0.35438781120517543`, 0.9361555735096144]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.027885652381746694`], {
             RGBColor[
             0.2451744333338886, 0.3750242527637898, 0.93727369332407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.027885652381746694`], {
             RGBColor[
             0.2358064817309028, 0.3651779416666145, 0.9367402023389224]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.027885652381746694`], {
             RGBColor[
             0.19796437105250972`, 0.32540348401522773`, 0.9345851501181738]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.027885652381746694`], {
             RGBColor[
             0.45725872125089195`, 0.5702622550389433, 0.9504162280122078]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.027885652381746694`], {
             RGBColor[
             0.23550398192177388`, 0.3648599951876243, 0.9367229754223009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.027885652381746694`], {
             RGBColor[
             0.18805335571358273`, 0.3149863784993486, 0.9340207324566552]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.027885652381746694`], {
             RGBColor[
             0.3796233347917912, 0.5032323849982215, 0.9454102410985666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.027885652381746694`], {
             RGBColor[
             0.17959143492855675`, 0.30609236323752076`, 0.933538838586238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.027885652381746694`], {
             RGBColor[
             0.41783566912403936`, 0.5363299883890472, 0.947845097252377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.027885652381746694`], {
             RGBColor[
             0.19013667027984396`, 0.3171760741982618, 0.9341393741392161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.027885652381746694`], {
             RGBColor[
             0.18620451936940718`, 0.3130431342786254, 0.9339154439619627]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.027885652381746694`], {
             RGBColor[
             0.18139651046953492`, 0.3079896120794884, 0.9336416349679267]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.027885652381746694`], {
             RGBColor[
             0.18300767959384703`, 0.309683052983163, 0.9337333886660452]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.027885652381746694`], {
             RGBColor[
             0.2268131918331927, 0.35572542377660804`, 0.9362280477836279]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.027885652381746694`], {
             RGBColor[
             0.18842432755960442`, 0.31537629343049095`, 0.9340418587544824]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.027885652381746694`], {
             RGBColor[
             0.19212227783830665`, 0.31926307363699663`, 0.9342524515522274]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.027885652381746694`], {
             RGBColor[
             0.24182762690147153`, 0.3715065470035356, 0.9370830976489003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.027885652381746694`], {
             RGBColor[
             0.18868393066647376`, 0.3156491527555983, 0.9340566427673703]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.027885652381746694`], {
             RGBColor[
             0.21355297767290998`, 0.3417880979480139, 0.9354728982039288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.027885652381746694`], {
             RGBColor[
             0.19254963929720473`, 0.31971225762658, 0.9342767891550869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.027885652381746694`], {
             RGBColor[
             0.2065811071166083, 0.33446021995121644`, 0.9350758604897056]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.027885652381746694`], {
             RGBColor[
             0.21634716160662554`, 0.34472496242384276`, 0.9356320228453292]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.027885652381746694`], {
             RGBColor[
             0.27580922111776024`, 0.4072233570823697, 0.9390182991682543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.027885652381746694`], {
             RGBColor[
             0.2331737072204319, 0.36241072872856434`, 0.9365902697253919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.027885652381746694`], {
             RGBColor[
             0.2121526703486752, 0.34031628616563087`, 0.9353931527733826]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.027885652381746694`], {
             RGBColor[
             0.1840091371887301, 0.310735648411464, 0.9337904201945499]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.027885652381746694`], {
             RGBColor[
             0.2582664433427927, 0.3887847853645258, 0.938019263926184]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.027885652381746694`], {
             RGBColor[
             0.8379281346647119, 0.8736051659010814, 0.9844035275832383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.027885652381746694`], {
             RGBColor[
             0.4554399226734993, 0.5687856724178738, 0.9502730455257168]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.027885652381746694`], {
             RGBColor[
             0.42461827381123246`, 0.5422047396654701, 0.9482772788254231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.027885652381746694`], {
             RGBColor[
             0.844124603334554, 0.8785460618197521, 0.9849945522966208]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.027885652381746694`], {
             RGBColor[
             0.19131157595015044`, 0.3184109745510759, 0.9342062832790229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.027885652381746694`], {
             RGBColor[
             0.8287975688378628, 0.8663247005533589, 0.9835326460637211]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.027885652381746694`], {
             RGBColor[
             0.9887357523774989, 0.9896099583772056, 0.8363412642506296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.027885652381746694`], {
             RGBColor[
             0.19404714705117995`, 0.3212862332234835, 0.9343620700063117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.027885652381746694`], {
             RGBColor[
             0.6657140642559093, 0.738780153701779, 0.9673158145395446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.027885652381746694`], {
             RGBColor[
             0.3275914997751332, 0.4581650247028605, 0.9420948185812503]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.027885652381746694`], {
             RGBColor[
             0.3100095560527289, 0.44293642874469996`, 0.9409745126743612]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.027885652381746694`], {
             RGBColor[
             0.17994083687002446`, 0.30645960683136597`, 0.9335587365099107]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.027885652381746694`], {
             RGBColor[
             0.18515378626434187`, 0.3119387471648751, 0.9338556062660495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.027885652381746694`], {
             RGBColor[
             0.4288884024290853, 0.5459033104513494, 0.9485493676450263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.027885652381746694`], {
             RGBColor[
             0.1915172466480543, 0.31862714749484833`, 0.934217995921006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.027885652381746694`], {
             RGBColor[
             0.2944180010032382, 0.4267823646067975, 0.9400780416535094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.027885652381746694`], {
             RGBColor[
             0.2650455441851616, 0.3959100501696741, 0.9384053236903759]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.027885652381746694`], {
             RGBColor[
             0.2456807114445148, 0.37555638315794415`, 0.9373025251134988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.027885652381746694`], {
             RGBColor[
             0.23248905082520588`, 0.3616911114474591, 0.9365512795565422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.027885652381746694`], {
             RGBColor[
             0.5777795176543054, 0.6681064669592394, 0.9599040665873084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.027885652381746694`], {
             RGBColor[
             0.3254133616442444, 0.45627843093029025`, 0.9419560295456021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.027885652381746694`], {
             RGBColor[
             0.8789213821202363, 0.5430920994852084, 0.22068137214366979`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.027885652381746694`], {
             RGBColor[
             0.7060709713767632, 0.7703072762684443, 0.9713382138846121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.027885652381746694`], {
             RGBColor[
             0.21581639795358076`, 0.3441670961721334, 0.9356017966404827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.027885652381746694`], {
             RGBColor[
             0.2082469591636211, 0.3362111360737471, 0.9351707282993756]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.027885652381746694`], {
             RGBColor[
             0.5602763464580424, 0.6538966040732364, 0.9585261528345099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.027885652381746694`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.027885652381746694`], {
             RGBColor[
             0.17970434930417156`, 0.30621104340547683`, 0.9335452688928874]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.027885652381746694`], {
             RGBColor[
             0.36991176607450643`, 0.49482071229294583`, 0.9447914285275043]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.027885652381746694`], {
             RGBColor[
             0.9510874915293103, 0.9630417117862173, 0.9676802978022608]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.027885652381746694`], {
             RGBColor[
             0.8592163258347785, 0.4536160411257659, 0.20423899016395516`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.027885652381746694`], {
             RGBColor[
             0.4977475489543879, 0.6031329093695432, 0.9536036568444898]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.027885652381746694`], {
             RGBColor[
             0.2084820527788493, 0.336458234369148, 0.9351841165329731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.027885652381746694`], {
             RGBColor[
             0.19190461331519068`, 0.3190342944224739, 0.9342400558796418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.027885652381746694`], {
             RGBColor[
             0.2739918424465178, 0.40531317687043084`, 0.9389148021414978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.027885652381746694`], {
             RGBColor[
             0.22400797509009437`, 0.3527769631185974, 0.9360682948400547]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.027885652381746694`], {
             RGBColor[
             0.19792175174780763`, 0.3253586884237658, 0.9345827230118207]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.027885652381746694`], {
             RGBColor[
             0.2211253737681676, 0.3497471663617724, 0.9359041349591976]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.027885652381746694`], {
             RGBColor[
             0.19120668731506069`, 0.31830072994527303`, 0.9342003100264233]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.027885652381746694`], {
             RGBColor[
             0.19035994618760685`, 0.3174107513338308, 0.934152089371856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.027885652381746694`], {
             RGBColor[
             0.9703310152107799, 0.9773935002394792, 0.9351060317243296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.027885652381746694`], {
             RGBColor[
             0.24693624036742998`, 0.3768760236610595, 0.9373740256282702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.027885652381746694`], {
             RGBColor[
             0.19324911536591247`, 0.3204474513241361, 0.9343166232824178]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.027885652381746694`], {
             RGBColor[
             0.5096359477486948, 0.612784447077024, 0.9545395551462174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.027885652381746694`], {
             RGBColor[
             0.18222514168352894`, 0.3088605560236495, 0.9336888242897137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.027885652381746694`], {
             RGBColor[
             0.20088219976865415`, 0.32847030699692126`, 0.9347513161470175]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.027885652381746694`], {
             RGBColor[
             0.5071373117219987, 0.6107559417882819, 0.9543428533653905]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.027885652381746694`], {
             RGBColor[
             0.17933281357579656`, 0.305820535798229, 0.9335241104827943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.027885652381746694`], {
             RGBColor[
             0.28091140737960196`, 0.41258607834085864`, 0.939308861127858]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.027885652381746694`], {
             RGBColor[
             0.3403985574835718, 0.4692578543884732, 0.9429108729735957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.027885652381746694`], {
             RGBColor[
             0.23139395253121084`, 0.36054009370722817`, 0.9364889153287519]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.027885652381746694`], {
             RGBColor[
             0.18235944175044905`, 0.3090017139090986, 0.9336964724798456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.027885652381746694`], {
             RGBColor[
             0.19489410730752896`, 0.3221764421532881, 0.9344103031399453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.027885652381746694`], {
             RGBColor[
             0.2167015948028579, 0.34509749418544555`, 0.9356522072915177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.027885652381746694`], {
             RGBColor[
             0.8173387448883187, 0.1342787678638822, 0.16423690772735258`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.027885652381746694`], {
             RGBColor[
             0.1829127869860106, 0.3095833148357881, 0.9337279846724099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.027885652381746694`], {
             RGBColor[
             0.18362197162651986`, 0.31032871285786656`, 0.9337683716885422]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.027885652381746694`], {
             RGBColor[
             0.19372013073248498`, 0.3209425183385029, 0.9343434469107393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.027885652381746694`], {
             RGBColor[
             0.1849258667142184, 0.3116991892667612, 0.9338426265848467]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.027885652381746694`], {
             RGBColor[
             0.20594129701488287`, 0.33378773896799957`, 0.9350394242509266]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.027885652381746694`], {
             RGBColor[
             0.8251923969012658, 0.19464537872765014`, 0.17175757376438203`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.027885652381746694`], {
             RGBColor[
             0.1870776850955973, 0.3139608868187558, 0.9339651694583363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.027885652381746694`], {
             RGBColor[
             0.37418878878290995`, 0.4985252543935531, 0.9450639566324611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.027885652381746694`], {
             RGBColor[
             0.9923039511135691, 0.9910855002530954, 0.777206976991627]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.027885652381746694`], {
             RGBColor[
             0.9694202648664492, 0.9767142641238943, 0.9366476944955487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.027885652381746694`], {
             RGBColor[
             0.23765262088408304`, 0.3671183509685898, 0.9368453372325779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.027885652381746694`], {
             RGBColor[
             0.8954246210317355, 0.9194513034296, 0.9898875937806444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.027885652381746694`], {
             RGBColor[
             0.1889310324973132, 0.31590887244697147`, 0.9340707148510822]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.027885652381746694`], {
             RGBColor[
             0.18920356017618423`, 0.31619531631671777`, 0.9340862348992254]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.027885652381746694`], {
             RGBColor[
             0.36433321534571095`, 0.4899888520377754, 0.9444359682079841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.027885652381746694`], {
             RGBColor[
             0.30183205672017543`, 0.43457500724358145`, 0.9405002611584765]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.027885652381746694`], {
             RGBColor[
             0.2599789274537134, 0.39058471474286727`, 0.9381167873629076]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.027885652381746694`], {
             RGBColor[
             0.19899652547638796`, 0.32648834375709396`, 0.934643929785678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.027885652381746694`], {
             RGBColor[
             0.6582217134144572, 0.7329270722804612, 0.9665690470276681]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.027885652381746694`], {
             RGBColor[
             0.19756403157199334`, 0.32498270183821587`, 0.9345623513770076]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.027885652381746694`], {
             RGBColor[
             0.187660141527025, 0.31457308545805707`, 0.933998339490439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.027885652381746694`], {
             RGBColor[
             0.3534033382914345, 0.480521941884955, 0.9437395261069965]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.027885652381746694`], {
             RGBColor[
             0.20794500379241626`, 0.3358937618335345, 0.9351535323876885]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.027885652381746694`], {
             RGBColor[
             0.8200027527924696, 0.15475549999089333`, 0.1667879647049341]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.027885652381746694`], {
             RGBColor[
             0.19665135271400355`, 0.3240234184912868, 0.9345103756662324]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.027885652381746694`], {
             RGBColor[
             0.5240458703783706, 0.6244830714274116, 0.9556739570409113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.027885652381746694`], {
             RGBColor[
             0.20313982636998706`, 0.33084321569671615`, 0.9348798846421041]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.027885652381746694`], {
             RGBColor[
             0.194144227344503, 0.3213882707670121, 0.934367598585399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.027885652381746694`], {
             RGBColor[
             0.37904525788294496`, 0.5027316838347692, 0.9453734065491083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.027885652381746694`], {
             RGBColor[
             0.1851145385676597, 0.3118974953472144, 0.9338533711677852]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.027885652381746694`], {
             RGBColor[
             0.1880939032775767, 0.3150289965599703, 0.9340230415804399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.027885652381746694`], {
             RGBColor[
             0.1990369147875074, 0.3265307954839108, 0.9346462298971957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.027885652381746694`], {
             RGBColor[
             0.2089289786028837, 0.3369279817469421, 0.9352095682974844]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.027885652381746694`], {
             RGBColor[
             0.39875120665503094`, 0.5197999862113661, 0.9466290521795794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.027885652381746694`], {
             RGBColor[
             0.31502354175322494`, 0.44727929114822085`, 0.9412939994095033]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.027885652381746694`], {
             RGBColor[
             0.9319225428018962, 0.7678025982169813, 0.26408148383634866`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.027885652381746694`], {
             RGBColor[
             0.7398648594018855, 0.7967073184367315, 0.9747064728211174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.027885652381746694`], {
             RGBColor[
             0.18427610046840573`, 0.31101624374485265`, 0.9338056233583907]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.027885652381746694`], {
             RGBColor[
             0.3212434064694567, 0.45266662534593033`, 0.9416903236892111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.027885652381746694`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.027885652381746694`], {
             RGBColor[
             0.2137339467700851, 0.34197830794324846`, 0.935483204126293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.027885652381746694`], {
             RGBColor[
             0.4742143938317012, 0.5840276338843894, 0.9517510406684443]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.027885652381746694`], {
             RGBColor[
             0.25752973177491306`, 0.38801045479647306`, 0.9379773092922603]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.027885652381746694`], {
             RGBColor[
             0.1954605501868454, 0.3227718095340026, 0.9344425612239453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.027885652381746694`], {
             RGBColor[
             0.8194918846006688, 0.15082874320484374`, 0.1662987567475226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.027885652381746694`], {
             RGBColor[
             0.3141297509318431, 0.44650513446197276`, 0.941237047848713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.027885652381746694`], {
             RGBColor[
             0.20973292712492791`, 0.3377729826168909, 0.9352553519764795]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.027885652381746694`], {
             RGBColor[
             0.18590102371033476`, 0.3127241410982041, 0.9338981603331601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.027885652381746694`], {
             RGBColor[
             0.17907641669607907`, 0.3055510464211448, 0.9335095090597996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.027885652381746694`], {
             RGBColor[
             0.2965600408339725, 0.42903378428206873`, 0.9402000276530058]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.027885652381746694`], {
             RGBColor[
             0.20546571259734456`, 0.33328786959137313`, 0.9350123404219118]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.027885652381746694`], {
             RGBColor[
             0.18838969891108812`, 0.3153398965253172, 0.9340398867041779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.027885652381746694`], {
             RGBColor[
             0.19616100168040002`, 0.3235080284649182, 0.934482450900278]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.027885652381746694`], {
             RGBColor[
             0.24986810421890843`, 0.3799575984598681, 0.937540990937308]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.027885652381746694`], {
             RGBColor[
             0.19470143524485908`, 0.32197393159930776`, 0.9343993307510091]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.027885652381746694`], {
             RGBColor[
             0.8939300581111314, 0.611242991794526, 0.23320497928678602`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.027885652381746694`], {
             RGBColor[
             0.2822705085644714, 0.4140145798581486, 0.9393862599297264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.027885652381746694`], {
             RGBColor[
             0.29805944165302733`, 0.4306097496103981, 0.9402854163114862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.027885652381746694`], {
             RGBColor[
             0.22229995450050422`, 0.350981725184178, 0.9359710255942676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.027885652381746694`], {
             RGBColor[
             0.17902996710188124`, 0.3055022249525685, 0.933506863824126]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.027885652381746694`], {
             RGBColor[
             0.212847764567014, 0.3410468742606238, 0.9354327373608172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.027885652381746694`], {
             RGBColor[
             0.6973666945960665, 0.7635074290924103, 0.9704706529212034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.027885652381746694`], {
             RGBColor[
             0.8265166883216026, 0.20482446289255998`, 0.17302571672406986`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.027885652381746694`], {
             RGBColor[
             0.2025961788233211, 0.3302718076559249, 0.934848924718576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.027885652381746694`], {
             RGBColor[
             0.5478165382686445, 0.6437811704771209, 0.9575452710920592]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.027885652381746694`], {
             RGBColor[
             0.28461757525764775`, 0.41648149576530025`, 0.9395199219057286]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.027885652381746694`], {
             RGBColor[
             0.18275376889499648`, 0.30941617673980293`, 0.9337189288273728]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.027885652381746694`], {
             RGBColor[
             0.1811098371299533, 0.3076883002234485, 0.9336253093453327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.027885652381746694`], {
             RGBColor[
             0.7121412574025138, 0.7750494298476431, 0.9719432432656107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.027885652381746694`], {
             RGBColor[
             0.18850413369751906`, 0.3154601747414406, 0.9340464035959741]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.027885652381746694`], {
             RGBColor[
             0.21345649486519924`, 0.3416866883997466, 0.9354674036507632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.027885652381746694`], {
             RGBColor[
             0.8324443832728455, 0.2503873238203034, 0.17870208410375396`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.027885652381746694`], {
             RGBColor[
             0.18370800885926494`, 0.3104191434445573, 0.9337732713816664]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.027885652381746694`], {
             RGBColor[
             0.18455342051778426`, 0.3113077246998561, 0.9338214163249446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.027885652381746694`], {
             RGBColor[
             0.1951112049063669, 0.3224046254944496, 0.9344226665270321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.027885652381746694`], {
             RGBColor[
             0.42062186552277797`, 0.5387432516713317, 0.9480226312231679]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.027885652381746694`], {
             RGBColor[
             0.1856877903127057, 0.31250001927751764`, 0.9338860170066157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.027885652381746694`], {
             RGBColor[
             0.23827199083861747`, 0.36776934806112876`, 0.9368806094352129]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.027885652381746694`], {
             RGBColor[
             0.24157157412247404`, 0.37123741929812537`, 0.9370685158219325]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.027885652381746694`], {
             RGBColor[
             0.18576331458524015`, 0.3125794000764668, 0.9338903180022083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.027885652381746694`], {
             RGBColor[
             0.2313516506730186, 0.3604956317721754, 0.9364865063005079]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.027885652381746694`], {
             RGBColor[
             0.2623389378177228, 0.3930652352687406, 0.9382511864618155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.027885652381746694`], {
             RGBColor[
             0.18870039039885345`, 0.3156664529779366, 0.9340575801247794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.027885652381746694`], {
             RGBColor[
             0.24096885499463874`, 0.3706039232801706, 0.9370341918592453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.027885652381746694`], {
             RGBColor[
             0.8178049183525352, 0.13786198138836525`, 0.164683315963154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.027885652381746694`], {
             RGBColor[
             0.9537765326908467, 0.9650471942815904, 0.9631284525300384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.027885652381746694`], {
             RGBColor[
             0.9602115875305376, 0.8774464833562946, 0.2999299602777051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.027885652381746694`], {
             RGBColor[
             0.1982643030525542, 0.3257187315640616, 0.9346022308018668]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.027885652381746694`], {
             RGBColor[
             0.23480104226620413`, 0.36412116104067216`, 0.9366829440488222]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.027885652381746694`], {
             RGBColor[
             0.956979221732861, 0.9674357545252026, 0.9577071353769899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.027885652381746694`], {
             RGBColor[
             0.21013611726343454`, 0.33819676101619267`, 0.9352783130584011]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.027885652381746694`], {
             RGBColor[
             0.38195753878243316`, 0.5052541551744117, 0.9455589745127948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.027885652381746694`], {
             RGBColor[
             0.27139200070452485`, 0.4025805783601091, 0.9387667450004126]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.027885652381746694`], {
             RGBColor[
             0.24934350578881678`, 0.3794062122483802, 0.9375111158327881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.027885652381746694`], {
             RGBColor[
             0.18639411010760892`, 0.31324240616522253`, 0.9339262408740289]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.027885652381746694`], {
             RGBColor[
             0.20071986914810575`, 0.3282996872223691, 0.9347420716583239]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.027885652381746694`], {
             RGBColor[
             0.1915625031716876, 0.3186747149706162, 0.9342205732130758]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.027885652381746694`], {
             RGBColor[
             0.8280837295399454, 0.865755504473851, 0.9834645594342339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.027885652381746694`], {
             RGBColor[
             0.20342618893072584`, 0.3311442009044876, 0.9348961925663027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.027885652381746694`], {
             RGBColor[
             0.18432439621433888`, 0.3110670056359555, 0.9338083737296745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.027885652381746694`], {
             RGBColor[
             0.20110409825488346`, 0.3287035363751249, 0.9347639529375389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.027885652381746694`], {
             RGBColor[
             0.19841472542917707`, 0.32587683501922177`, 0.9346107971336854]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.027885652381746694`], {
             RGBColor[
             0.3485452682138572, 0.4763141257574593, 0.943429974177476]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.027885652381746694`], {
             RGBColor[
             0.3095548228305918, 0.44254256168324113`, 0.9409455374755513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.027885652381746694`], {
             RGBColor[
             0.18638553952238943`, 0.3132333979367503, 0.9339257527918797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.027885652381746694`], {
             RGBColor[
             0.9932598001133134, 0.9879917189181485, 0.507749021905247]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.027885652381746694`], {
             RGBColor[
             0.19610120868731518`, 0.3234451822380914, 0.9344790457777777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.027885652381746694`], {
             RGBColor[
             0.2081404760074813, 0.3360992155252221, 0.9351646642411613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.027885652381746694`], {
             RGBColor[
             0.9453835605713274, 0.9587877294170835, 0.9773355650906732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.027885652381746694`], {
             RGBColor[
             0.18600360463112436`, 0.31283196014996, 0.9339040021648441]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.027885652381746694`], {
             RGBColor[
             0.2775970966062373, 0.4091025275786123, 0.9391201160323983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.027885652381746694`], {
             RGBColor[
             0.32568965645452963`, 0.4565177436079784, 0.9419736348065956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.027885652381746694`], {
             RGBColor[
             0.6627555094400547, 0.736468908193784, 0.9670209334447669]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.027885652381746694`], {
             RGBColor[
             0.40957405763887067`, 0.529174195761261, 0.9473186746739982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.027885652381746694`], {
             RGBColor[
             0.7912709059084366, 0.8368661126680731, 0.979830147120073]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.027885652381746694`], {
             RGBColor[
             0.3745258073527012, 0.4988171629396605, 0.9450854311577144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.027885652381746694`], {
             RGBColor[
             0.92133834354613, 0.7258397751431882, 0.2555651886720716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.027885652381746694`], {
             RGBColor[
             0.30601698137869693`, 0.43897362839923615`, 0.940738586426738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.027885652381746694`], {
             RGBColor[
             0.9933000584574108, 0.9880778274454297, 0.5121308942145434]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.027885652381746694`], {
             RGBColor[
             0.1860930553658944, 0.31292597854370746`, 0.9339090962518588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.027885652381746694`], {
             RGBColor[
             0.1838330998850932, 0.3105506220439319, 0.9337803951305317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.027885652381746694`], {
             RGBColor[
             0.1804054273287139, 0.30694792086018496`, 0.933585194249233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.027885652381746694`], {
             RGBColor[
             0.18554668841356567`, 0.31235171223514435`, 0.9338779814622011]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.027885652381746694`], {
             RGBColor[
             0.18003320207443918`, 0.306556688517498, 0.93356399657166]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.027885652381746694`], {
             RGBColor[
             0.179946795179367, 0.3064658693922636, 0.9335590758268132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.027885652381746694`], {
             RGBColor[
             0.19798515205544082`, 0.3254253261669, 0.934586333565548]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.027885652381746694`], {
             RGBColor[
             0.1836365577609456, 0.3103440438099624, 0.9337692023473195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.027885652381746694`], {
             RGBColor[
             0.20279567675606608`, 0.3304814926321394, 0.9348602858307151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.027885652381746694`], {
             RGBColor[
             0.28617898913701123`, 0.4181226407518692, 0.9396088421162536]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.027885652381746694`], {
             RGBColor[
             0.25469411239970985`, 0.38503003904448196`, 0.9378158249637654]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.027885652381746694`], {
             RGBColor[
             0.24023703411797065`, 0.3698347331386689, 0.9369925157429511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.027885652381746694`], {
             RGBColor[
             0.18246816409549027`, 0.30911598798713175`, 0.9337026640565553]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.027885652381746694`], {
             RGBColor[
             0.7203821791624184, 0.7814873005598058, 0.9727646213308456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.027885652381746694`], {
             RGBColor[
             0.1893487791980019, 0.3163479507160659, 0.9340945049076855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.027885652381746694`], {
             RGBColor[
             0.3220959675484921, 0.453405070901625, 0.9417446481272771]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.027885652381746694`], {
             RGBColor[
             0.3583175561905998, 0.4847783904334387, 0.944052655726059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.027885652381746694`], {
             RGBColor[
             0.9335847383251342, 0.7743926495727972, 0.2654189253710895]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.027885652381746694`], {
             RGBColor[
             0.9944175835604394, 0.9904681006416884, 0.633766605113725]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.027885652381746694`], {
             RGBColor[
             0.3419268933615933, 0.4705816221096207, 0.9430082571842888]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.027885652381746694`], {
             RGBColor[
             0.18554205504628538`, 0.3123468422723603, 0.933877717598789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.027885652381746694`], {
             RGBColor[
             0.2707814877613013, 0.40193889054802484`, 0.938731977191469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.027885652381746694`], {
             RGBColor[
             0.9931232770303468, 0.9876997098482838, 0.4928893268471293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.027885652381746694`], {
             RGBColor[
             0.21298290042549683`, 0.3411889106159976, 0.9354404331480423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.027885652381746694`], {
             RGBColor[
             0.8202342132018924, 0.1565346061243149, 0.16700961145439447`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.027885652381746694`], {
             RGBColor[
             0.2030621295519029, 0.3307615514146469, 0.9348754599232564]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.027885652381746694`], {
             RGBColor[
             0.7219717591850786, 0.7827290925547635, 0.9729230558120345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.027885652381746694`], {
             RGBColor[
             0.35762511408731845`, 0.48417863188672844`, 0.9440085339275405]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.027885652381746694`], {
             RGBColor[
             0.4386808762090538, 0.554385059055515, 0.9491733354151413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.027885652381746694`], {
             RGBColor[
             0.18439801323969868`, 0.31114438179719767`, 0.9338125661103621]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.027885652381746694`], {
             RGBColor[
             0.36417957475425095`, 0.48985577627965343`, 0.9444261783653554]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.027885652381746694`], {
             RGBColor[
             0.1808071689883251, 0.3073701768163288, 0.9336080728424244]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.027885652381746694`], {
             RGBColor[
             0.3593758114062829, 0.48569499791180964`, 0.944120086812624]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.027885652381746694`], {
             RGBColor[
             0.8221152183090297, 0.17099283563946593`, 0.16881086406928056`]},
             StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{{3.8349502435193233`*^9, 3.8349502581408367`*^9}, 
   3.834950528174912*^9, 3.8349578088972807`*^9, 3.835023924704108*^9},
 CellLabel->
  "Out[181]=",ExpressionUUID->"38968bc4-a1d2-4c56-85ba-fddeb7d26741"]
}, Open  ]],

Cell["r = 3 :", "Text",
 CellChangeTimes->{{3.834793779215767*^9, 3.8347938725231647`*^9}, {
  3.8347953347101345`*^9, 3.8347953431477337`*^9}, {3.8348851911359825`*^9, 
  3.83488519180678*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"291e414e-9eda-46e5-91b2-b4eff9701f0f"],

Cell["Cubic Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.834795179278664*^9}},ExpressionUUID->"da8e006e-0b54-40c9-9755-\
9ad2384f17c1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c\[Rho]3i4", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"CMDi3400", ",", "kri4"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.834947911760502*^9, 
   3.834947914304406*^9}, {3.834947957535968*^9, 3.8349479704802837`*^9}, {
   3.8349480487781425`*^9, 3.834948105065866*^9}, {3.8349497992119355`*^9, 
   3.83494980454772*^9}, {3.8349578354451995`*^9, 3.83495784069214*^9}},
 CellLabel->
  "In[182]:=",ExpressionUUID->"56812749-a70b-4efe-8f33-93b19bb72d4d"],

Cell[BoxData[
 RowBox[{"-", "0.0413111933018312`"}]], "Output",
 CellChangeTimes->{
  3.834948013482303*^9, {3.834948049945756*^9, 3.834948058990469*^9}, 
   3.8349481059508953`*^9, 3.8349499476386404`*^9, 3.834957841643118*^9, 
   3.835023925264106*^9},
 CellLabel->
  "Out[182]=",ExpressionUUID->"afee4c4b-7847-4332-ae22-3e7631fa84cf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CP3i4", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"CMDi3400", ",", "kri4"}], "}"}], "]"}], ",", "c\[Rho]3i4"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8349481210775223`*^9, 3.834948150679065*^9}, {
  3.8349481924167476`*^9, 3.8349481986802473`*^9}, {3.834949807949147*^9, 
  3.834949815491851*^9}, {3.8349578438231587`*^9, 3.8349578533989754`*^9}},
 CellLabel->
  "In[183]:=",ExpressionUUID->"90afdff8-3c3d-4af7-bf20-530ffdc2874f"],

Cell[BoxData["0.9160883626704704`"], "Output",
 CellChangeTimes->{3.8349481513130674`*^9, 3.8349482002632475`*^9, 
  3.8349499490044084`*^9, 3.8349578559445095`*^9, 3.835023925347106*^9},
 CellLabel->
  "Out[183]=",ExpressionUUID->"9c0f4fa1-70f4-4658-96ca-b2b3c91b6601"]
}, Open  ]],

Cell["Absolute Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.8347951985065947`*^9}},ExpressionUUID->"21bc06ad-cafc-4076-8886-\
537d35c18024"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a\[Rho]3i4", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"AMDi3400", ",", "kri4"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.8348873709111376`*^9, 
   3.8348873755217657`*^9}, {3.8349481641806583`*^9, 
   3.8349481824982553`*^9}, {3.834949818653184*^9, 3.8349498238056817`*^9}, {
   3.834957866337153*^9, 3.834957872254816*^9}},
 CellLabel->
  "In[184]:=",ExpressionUUID->"11cd041e-edd1-4ae1-8c0f-19539578d80c"],

Cell[BoxData[
 RowBox[{"-", "0.015457359500694353`"}]], "Output",
 CellChangeTimes->{3.834948182946122*^9, 3.83494995054953*^9, 
  3.834957874365346*^9, 3.835023925368107*^9},
 CellLabel->
  "Out[184]=",ExpressionUUID->"8605ffbd-9a48-4a51-897b-9846dc765b3f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"aP3i4", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"AMDi3400", ",", "kri4"}], "}"}], "]"}], ",", "a\[Rho]3i4"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8349482041094093`*^9, 
  3.8349482202691827`*^9}, {3.8349498269490285`*^9, 3.8349498405604887`*^9}, {
  3.8349578796796703`*^9, 3.834957886620027*^9}},
 CellLabel->
  "In[185]:=",ExpressionUUID->"c65fce6d-ea46-404e-ad30-246d9eb97c99"],

Cell[BoxData["0.5414972851271779`"], "Output",
 CellChangeTimes->{3.834887440036944*^9, 3.8349482220989213`*^9, 
  3.8349499520491343`*^9, 3.8349578874036503`*^9, 3.8350239253891106`*^9},
 CellLabel->
  "Out[185]=",ExpressionUUID->"5a6707f8-b5ef-40aa-83c6-95b49827cd5c"]
}, Open  ]],

Cell["Max-min Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 3.8347951985065947`*^9}, {
  3.8348543263190746`*^9, 
  3.834854330052075*^9}},ExpressionUUID->"78761bc5-8bc4-402e-be5a-\
142abf550db8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mM\[Rho]3i4", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"mMDi3400", ",", "kri4"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8348874651734295`*^9, 3.8348874872060013`*^9}, {
  3.8349482319487157`*^9, 3.834948245258479*^9}, {3.834949844516972*^9, 
  3.8349498489188633`*^9}, {3.834957895209076*^9, 3.834957899999796*^9}},
 CellLabel->
  "In[186]:=",ExpressionUUID->"d2f3ff85-6b54-4888-9fbf-b8b804617315"],

Cell[BoxData[
 RowBox[{"-", "0.06618448546884725`"}]], "Output",
 CellChangeTimes->{3.834948246413353*^9, 3.834949953689977*^9, 
  3.834957900696502*^9, 3.835023925409108*^9},
 CellLabel->
  "Out[186]=",ExpressionUUID->"e22fd43a-3e7e-4e23-b59b-045c05336247"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mMP3i4", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"mMDi3400", ",", "kri4"}], "}"}], "]"}], ",", "mM\[Rho]3i4"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8348875260806427`*^9, 
  3.8348875488478312`*^9}, {3.8349482525846663`*^9, 3.8349482707073736`*^9}, {
  3.8349498532537427`*^9, 3.834949860995207*^9}, {3.834957902898573*^9, 
  3.8349579090270967`*^9}},
 CellLabel->
  "In[187]:=",ExpressionUUID->"c6e12055-dc4a-4ea8-8d05-7a8196d3db23"],

Cell[BoxData["0.9342694629517283`"], "Output",
 CellChangeTimes->{3.834887440036944*^9, 3.8348875533996215`*^9, 
  3.834948277702903*^9, 3.834949955989804*^9, 3.834957909480212*^9, 
  3.835023925432107*^9},
 CellLabel->
  "Out[187]=",ExpressionUUID->"7fa7dfd0-d0cf-436a-8141-f4e83307f5e1"]
}, Open  ]],

Cell["r = 6 :", "Text",
 CellChangeTimes->{{3.834793779215767*^9, 3.8347938725231647`*^9}, {
  3.8347953347101345`*^9, 3.8347953431477337`*^9}, {3.8348851911359825`*^9, 
  3.83488519180678*^9}, {3.834948305866973*^9, 3.8349483068980722`*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"a5cf2069-f33f-4d6e-b557-565004fbb90c"],

Cell["Cubic Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.834795179278664*^9}},ExpressionUUID->"bf7916ba-5b0b-403e-ba74-\
9adfae02a4a6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c\[Rho]6i4", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"CMDi6400", ",", "kri4"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.834947911760502*^9, 
   3.834947914304406*^9}, {3.834947957535968*^9, 3.8349479704802837`*^9}, {
   3.8349480487781425`*^9, 3.834948105065866*^9}, {3.8349483158342133`*^9, 
   3.8349483193845987`*^9}, {3.834949864783629*^9, 3.834949869574106*^9}, {
   3.834957963470776*^9, 3.834957967378231*^9}},
 CellLabel->
  "In[188]:=",ExpressionUUID->"56e85535-0b0e-4eb9-ba58-e7307baf8997"],

Cell[BoxData[
 RowBox[{"-", "0.0027611896415641684`"}]], "Output",
 CellChangeTimes->{
  3.834948013482303*^9, {3.834948049945756*^9, 3.834948058990469*^9}, 
   3.8349481059508953`*^9, 3.834948360850016*^9, 3.8349499580565577`*^9, 
   3.834957967763415*^9, 3.8350239254521103`*^9},
 CellLabel->
  "Out[188]=",ExpressionUUID->"17c5e1cf-6f67-4fed-a7c2-6b5799e5c62e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CP6i4", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"CMDi6400", ",", "kri4"}], "}"}], "]"}], ",", "c\[Rho]6i4"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8349481210775223`*^9, 3.834948150679065*^9}, {
  3.8349481924167476`*^9, 3.8349481986802473`*^9}, {3.8349483230197706`*^9, 
  3.834948338654296*^9}, {3.8349498724373255`*^9, 3.8349498802583637`*^9}, {
  3.8349579696959915`*^9, 3.834957975592292*^9}},
 CellLabel->
  "In[189]:=",ExpressionUUID->"41b7bad4-ab12-4b87-8c3d-1f9275967685"],

Cell[BoxData["0.5357694186642934`"], "Output",
 CellChangeTimes->{3.8349481513130674`*^9, 3.8349482002632475`*^9, 
  3.834948361143017*^9, 3.8349499593900194`*^9, 3.8349579759739666`*^9, 
  3.8350239254731073`*^9},
 CellLabel->
  "Out[189]=",ExpressionUUID->"83d65a43-3ac8-4f98-8a74-d98fcd1dbc13"]
}, Open  ]],

Cell["Absolute Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.8347951985065947`*^9}},ExpressionUUID->"2c28dd41-0263-46e4-a176-\
6a7f820f3f75"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a\[Rho]6i4", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"AMDi6400", ",", "kri4"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.8348873709111376`*^9, 
   3.8348873755217657`*^9}, {3.8349481641806583`*^9, 
   3.8349481824982553`*^9}, {3.834948329127375*^9, 3.834948332212267*^9}, {
   3.834949883458797*^9, 3.8349498875077024`*^9}, {3.834957978394422*^9, 
   3.8349579827581863`*^9}},
 CellLabel->
  "In[190]:=",ExpressionUUID->"887af302-7d20-45b3-8646-c1088e974021"],

Cell[BoxData[
 RowBox[{"-", "0.02865396390829401`"}]], "Output",
 CellChangeTimes->{3.834948182946122*^9, 3.8349483612910123`*^9, 
  3.8349499607430162`*^9, 3.834957983223776*^9, 3.8350239255021076`*^9},
 CellLabel->
  "Out[190]=",ExpressionUUID->"9d949705-f51f-432e-9567-2ed763a75a9b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"aP6i4", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"AMDi6400", ",", "kri4"}], "}"}], "]"}], ",", "a\[Rho]6i4"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8349482041094093`*^9, 
  3.8349482202691827`*^9}, {3.834948340881687*^9, 3.834948354997751*^9}, {
  3.8349498907390194`*^9, 3.8349498979971194`*^9}, {3.8349579853563895`*^9, 
  3.8349579919125147`*^9}},
 CellLabel->
  "In[191]:=",ExpressionUUID->"053d4b31-9c9b-419a-9983-6863d07cda9b"],

Cell[BoxData["0.10962641994458647`"], "Output",
 CellChangeTimes->{3.834887440036944*^9, 3.8349482220989213`*^9, 
  3.834948361458013*^9, 3.834949962307019*^9, 3.834957992381853*^9, 
  3.835023925524108*^9},
 CellLabel->
  "Out[191]=",ExpressionUUID->"22f5f3fa-384a-461d-ae84-c3d12d1d7158"]
}, Open  ]],

Cell["Max-min Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 3.8347951985065947`*^9}, {
  3.8348543263190746`*^9, 
  3.834854330052075*^9}},ExpressionUUID->"25096255-53d4-496b-9228-\
8574dc081b92"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mM\[Rho]6i4", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"mMDi6400", ",", "kri4"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8348874651734295`*^9, 3.8348874872060013`*^9}, {
   3.8349482319487157`*^9, 3.834948245258479*^9}, 3.8349483527075925`*^9, {
   3.8349499042423377`*^9, 3.8349499090679235`*^9}, {3.834949978751977*^9, 
   3.8349499794842105`*^9}, {3.834957994342047*^9, 3.834957998175455*^9}},
 CellLabel->
  "In[192]:=",ExpressionUUID->"ffd000de-7f55-4fa3-b474-f9991af13257"],

Cell[BoxData[
 RowBox[{"-", "0.002270975696616575`"}]], "Output",
 CellChangeTimes->{
  3.834948246413353*^9, 3.8349483615970154`*^9, {3.834949963955017*^9, 
   3.8349499810066743`*^9}, 3.834957999014784*^9, 3.8350239255481167`*^9},
 CellLabel->
  "Out[192]=",ExpressionUUID->"dd818fa5-a46d-4576-85dd-3e4a3c646f59"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mMP6i4", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"mMDi6400", ",", "kri4"}], "}"}], "]"}], ",", "mM\[Rho]6i4"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8348875260806427`*^9, 
  3.8348875488478312`*^9}, {3.8349482525846663`*^9, 3.8349482707073736`*^9}, {
  3.83494834565068*^9, 3.8349483504716325`*^9}, {3.8349499122654495`*^9, 
  3.83494991854418*^9}, {3.834958000997678*^9, 3.8349580074869604`*^9}},
 CellLabel->
  "In[193]:=",ExpressionUUID->"9f8920c5-87a8-4f82-9ee1-88120dfebced"],

Cell[BoxData["0.6779227720994201`"], "Output",
 CellChangeTimes->{
  3.834887440036944*^9, 3.8348875533996215`*^9, 3.834948277702903*^9, 
   3.8349483617580156`*^9, {3.834949965578516*^9, 3.8349499927811513`*^9}, 
   3.834958007945059*^9, 3.8350239255711184`*^9},
 CellLabel->
  "Out[193]=",ExpressionUUID->"d8128231-c74e-4df3-aff7-4a9304f99d05"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4th-2 imported file", "Subsection",
 CellChangeTimes->{{3.834947473073307*^9, 3.8349474798089457`*^9}, {
   3.8349497159535103`*^9, 3.8349497173354855`*^9}, {3.834956622993673*^9, 
   3.834956623710862*^9}, {3.8349596185756845`*^9, 3.834959618827529*^9}, 
   3.8352016372424865`*^9},
 Background->RGBColor[
  1, 1, 0],ExpressionUUID->"a256f3d2-0eab-4282-a921-ac506bf4db7e"],

Cell["Dividing stuff", "Text",
 CellChangeTimes->{{3.83494752022309*^9, 
  3.834947523245259*^9}},ExpressionUUID->"5ecde3c8-5b5a-4ef2-a20a-\
71778edf6705"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data4b", "=", 
   RowBox[{"StringSplit", "[", 
    RowBox[{
     RowBox[{"Import", "[", "\"\<ariadnaComputation4(2).txt\>\"", "]"}], ",", 
     "\"\<]\n{\>\""}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8349434033501863`*^9, 3.834943479535334*^9}, {
   3.834943567297134*^9, 3.8349435736474867`*^9}, {3.8349441109152327`*^9, 
   3.8349441401892223`*^9}, 3.834944204627252*^9, {3.834949720382628*^9, 
   3.8349497230261507`*^9}, {3.834956627593688*^9, 3.834956631231691*^9}, {
   3.834959622332199*^9, 3.834959633610727*^9}},
 CellLabel->
  "In[194]:=",ExpressionUUID->"5b7e6b7e-783d-4027-94e6-804ff7a93717"],

Cell[BoxData[
 RowBox[{
  RowBox[{"graphi4b", "=", 
   RowBox[{"ToExpression", "@", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
      "data4b", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "<>", 
      "\"\<]\>\""}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834944474381714*^9, 3.83494454689666*^9}, 
   3.8349475108233376`*^9, {3.834949726505718*^9, 3.8349497324197383`*^9}, {
   3.8349566345564103`*^9, 3.834956636582815*^9}, {3.8349596379977646`*^9, 
   3.834959640800048*^9}},
 CellLabel->
  "In[195]:=",ExpressionUUID->"586f7c8e-ef40-4b71-ae81-7bf2df7225ef"],

Cell[BoxData[
 RowBox[{
  RowBox[{"otheri4b", "=", 
   RowBox[{"ToExpression", "@", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "<>", "\"\<}}\>\""}], "&"}], ",", 
      RowBox[{"StringSplit", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\"\<{\>\"", "<>", 
          RowBox[{
          "data4b", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
         ")"}], ",", "\"\<}}\>\""}], "]"}]}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834944518155362*^9, 3.8349445533517303`*^9}, 
   3.8349446259294133`*^9, {3.8349447635371876`*^9, 3.8349447780382657`*^9}, {
   3.834944820013957*^9, 3.8349448816359477`*^9}, {3.834944915595456*^9, 
   3.834944918286141*^9}, {3.8349449615053425`*^9, 3.834944967406804*^9}, {
   3.834945029266304*^9, 3.834945031628281*^9}, {3.834945108799203*^9, 
   3.8349451822852197`*^9}, 3.834945584171259*^9, {3.834949734758335*^9, 
   3.8349497379503355`*^9}, {3.834956638769047*^9, 3.8349566423540664`*^9}, {
   3.834959644822921*^9, 3.83495964757225*^9}},
 CellLabel->
  "In[196]:=",ExpressionUUID->"b79fd439-9c56-447b-9aa3-5dcb90da0ecf"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "CMDi3400b", "}"}], ",", 
     RowBox[{"{", "AMDi3400b", "}"}], ",", 
     RowBox[{"{", "mMDi3400b", "}"}], ",", 
     RowBox[{"{", "CMDi6400b", "}"}], ",", 
     RowBox[{"{", "AMDi6400b", "}"}], ",", 
     RowBox[{"{", "mMDi6400b", "}"}]}], "}"}], "=", "otheri4b"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.834945694541313*^9, 3.834945753140644*^9}, {
  3.8349459487260857`*^9, 3.8349459670133495`*^9}, {3.8349471029719105`*^9, 
  3.8349471182020655`*^9}, {3.83494974203613*^9, 3.8349497544188104`*^9}, {
  3.834956647753375*^9, 3.8349566844693546`*^9}, {3.834959653771965*^9, 
  3.8349596658047967`*^9}},
 CellLabel->
  "In[197]:=",ExpressionUUID->"b0a338f1-807a-4995-965c-a95a66f3f9c3"],

Cell["\[OpenCurlyDoubleQuote]Cleaning\[CloseCurlyDoubleQuote] the graph:", \
"Text",
 CellChangeTimes->{{3.8349477786156034`*^9, 
  3.8349478283202667`*^9}},ExpressionUUID->"71a9a444-89d3-447d-be1a-\
87068970189b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"graphin4b", "=", 
   RowBox[{"IndexGraph", "@", "graphi4b"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834946654863307*^9, 3.834946693639777*^9}, {
  3.834949757637121*^9, 3.834949759707878*^9}, {3.8349566892836237`*^9, 
  3.834956691608691*^9}, {3.8349596804674864`*^9, 3.834959683266321*^9}},
 CellLabel->
  "In[198]:=",ExpressionUUID->"7f944ba6-a0c2-4387-a96f-a16b92f7c14a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pointsi4b", "=", 
   RowBox[{"VertexList", "@", "graphin4b"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834784420352569*^9, 3.8347844264642625`*^9}, {
  3.8348756828269844`*^9, 3.8348756865131674`*^9}, {3.834878831782991*^9, 
  3.8348788488376627`*^9}, {3.8349467020325813`*^9, 3.834946739879963*^9}, {
  3.8349497621629615`*^9, 3.8349497641865125`*^9}, {3.834956695197647*^9, 
  3.834956697830969*^9}, {3.8349596857801237`*^9, 3.8349596879554706`*^9}},
 CellLabel->
  "In[199]:=",ExpressionUUID->"16b3396d-6e01-4b45-b787-53048744a88b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"coordpointsi4b", "=", 
   RowBox[{"VertexList", "@", "graphi4b"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834879134322084*^9, 3.834879146224797*^9}, {
  3.834946724882841*^9, 3.834946736706849*^9}, {3.834949767417904*^9, 
  3.8349497706963253`*^9}, {3.8349567000470257`*^9, 3.8349567019660654`*^9}, {
  3.834959692428914*^9, 3.8349596942408223`*^9}},
 CellLabel->
  "In[200]:=",ExpressionUUID->"9fcd4a67-84aa-423a-aadc-8f9f2d791572"],

Cell["Kretchmann \[OpenCurlyDoubleQuote]real\[CloseCurlyDoubleQuote] \
values:", "Text",
 CellChangeTimes->{
  3.8347933561184683`*^9, {3.8347935444076195`*^9, 
   3.834793546974228*^9}},ExpressionUUID->"cc9c72e7-e6d8-4a74-a215-\
12579fd98188"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rvali4b", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Sinh", "[", "\[Nu]", "]"}], "\[Equal]", "#"}], ",", 
       RowBox[{"{", "\[Nu]", "}"}]}], "]"}], "&"}], "/@", 
    RowBox[{"coordpointsi4b", "\[LeftDoubleBracket]", 
     RowBox[{";;", ",", "3"}], "\[RightDoubleBracket]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834105426841242*^9, 3.8341054487325706`*^9}, {
   3.8341407674337025`*^9, 3.834140799285215*^9}, {3.8341408938375945`*^9, 
   3.834140946496229*^9}, {3.8341410168099756`*^9, 3.8341410671886864`*^9}, {
   3.8341411610986195`*^9, 3.834141210381962*^9}, {3.834141332672348*^9, 
   3.834141336755044*^9}, {3.834141461053176*^9, 3.834141468978607*^9}, {
   3.834141967115094*^9, 3.8341420256686225`*^9}, {3.8341640069512*^9, 
   3.834164012603241*^9}, {3.834164792400744*^9, 3.8341647947633886`*^9}, {
   3.83466546628111*^9, 3.834665483801684*^9}, {3.8347933895124626`*^9, 
   3.834793417249506*^9}, 3.8347960586942053`*^9, 3.834879156483405*^9, {
   3.8348862453609915`*^9, 3.8348862641404076`*^9}, 3.834886374221485*^9, {
   3.834946768449996*^9, 3.8349467823353415`*^9}, {3.8349468446168528`*^9, 
   3.834946857637892*^9}, 3.8349474594107084`*^9, {3.834949773350379*^9, 
   3.8349497766098785`*^9}, {3.8349567056279964`*^9, 
   3.8349567091770997`*^9}, {3.834959698054906*^9, 3.8349597003339357`*^9}},
 CellLabel->
  "In[201]:=",ExpressionUUID->"958da6d9-98e4-4790-8c44-537a0d8993c9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"kri4b", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"KHyperboloid", "/.", "rvali4b"}], ")"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834792366597866*^9, 3.834792376019791*^9}, {
   3.834793346399704*^9, 3.8347933590872536`*^9}, {3.834793445378667*^9, 
   3.8347934527754736`*^9}, {3.834793487784485*^9, 3.834793489659489*^9}, 
   3.8348550102643666`*^9, {3.8348863808528233`*^9, 3.83488645374378*^9}, {
   3.834886485165092*^9, 3.834886521271514*^9}, 3.8348865820814276`*^9, {
   3.83494679091998*^9, 3.8349467979310513`*^9}, {3.8349468742957215`*^9, 
   3.834946904080855*^9}, 3.8349474644429636`*^9, {3.834949779141443*^9, 
   3.834949781745859*^9}, {3.8349567110647635`*^9, 3.8349567138998594`*^9}, {
   3.8349597067890453`*^9, 3.834959709429332*^9}},
 CellLabel->
  "In[202]:=",ExpressionUUID->"0b5a0b4f-a7c5-440b-8d7d-8057ee625e2d"],

Cell["Estimated with cubic Mean Deviation v Calculated: (r=3)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 
  3.8349503319477153`*^9}},ExpressionUUID->"b0283419-5e5b-4d0d-8126-\
4c1eb112ffbc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraphb", "[", 
     RowBox[{"graphin4b", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsi4b", ",", "#"}], "}"}], "]"}], ",", "500", ",", 
      "400"}], "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"CMDi3400b", ",", "kri4b"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349567344957485`*^9, 3.834956749729442*^9}, {
   3.8349587420893497`*^9, 3.834958755264699*^9}, {3.8349597212071047`*^9, 
   3.834959729371503*^9}, {3.834960824145692*^9, 3.8349608438632402`*^9}, {
   3.8349609825994997`*^9, 3.8349610614731703`*^9}, 3.835051849652179*^9, {
   3.8350562904179306`*^9, 3.835056301188969*^9}, {3.8350563531232967`*^9, 
   3.8350563536382933`*^9}},
 Background->RGBColor[1, 1, 0.85],
 CellLabel->
  "In[517]:=",ExpressionUUID->"8142dc30-7c0a-4945-8b15-99ffc8b230a9"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN2wucznW+wPHf/+zadNlSKJUyheimsIbchiJLGlM0NrNmJtWMMW5DaZZc
xiXEpDYnbVorhVi3nLW60EUbOdQepCtJuQyjGrY9Lm05z6ffZ157Xi/ffefx
PP/nd/n+bv//s1cMGHbn0P8IIXx2ZgiYkYqtqeiWikdTke5r6b5eKxVHU/Fw
KhonIWxIuScVO1LRJ/X3fSmHJ/Hzv07Fz1P/PTQVnbV+6rVL/NwxP4uZIb6W
6d8nhXgt7J16/40pl6didCoWpeLJVExNvX6OZTrHcnH9OakYkYq5vn5uEt+D
R/XNlDk6zutPTuJ1cblelXJ9Kloq5Vln7PP1aV6/SRKv3cTrDfB6A7weEly3
id9PnTcbtAWvf287VBnH9A7L82Aq+qciLfX3B6zv/BDbGId63cFJvC7u0WOa
+hOyUv9zm330s1T08vMtk/haS4PrXZJ6/aMQ3/+RuYHdkngd6v+6QRu8bnvU
Nk+uSBnsr20hts82+3SbcVT5fIMk9gtO9frnJLH/z/H6eI5tfo7tTrucMB9P
GORl65SnLd9pg890t62728bdbWfa+IqU2bY15oXY/m2NB5X31fU6dX1fXfuk
rtetaz9SjzzrkWc98LRSpjzrlGed8hw3jYw55nWx1ys2XtejyrWKbc9i+6PY
75kYYm5iA/9OO5PPh41p5sd++3u/fb7f+Ll5VJTEsYYFfIf5fsooNq92GeTp
LvOUfL8qiZHj99dK4vcjQTnahdhmuDPE+WeSeY7kGPL6SYPXTvrv9P/EJOYg
5pt7uFm3KWPlDP/7DN+HG3SzVr/vlFZ/z1TjsJ5Wvrd9iGMNezmef0xFrpaa
N6W2FTIGS223UtuNeahVEqO317khifl4g/mLPyo5eoPl2215dpszu43TSt7s
Nk9ut2y3Wz7m9CEG4+qxlP9heV411uk+3zcwieMQ+cxA54FRIc4Do4zluk2P
KnMmTnacpRmZukH3aJUeU+a7NPuHdiq1nUptp1Lbp9Q2wm7K/FU/5REdGWIe
4iLdreQp6+QXIa6ZuFVph+ZJjD460Pb7XRLbEHuFmN+p5finsYFvKmMEq8dJ
ruXJdbzkOl5yDcqTJHGdSMyVxHzB2kaa9ra+7xnUFxv7+m3mLZLDtxm97M/z
jRt1lC7XbXpUmXfOt3/Pt3/JrxFJbC/cobTXCNtuhG2Hl4fY5pfb5pfb3rRT
J+cXfFNpw05GjvNKRhL7FBcp/dDM/mlm/zQz6KdfhpjzvzTfsbavt1Lak/Wk
3KhS1hemog5JjG6aZX4+EeJ4w1wlGH/0+2JjvdLni/1e5qIHkjgPY7FSjllJ
/H6sUsoyy/rmJzH38q0nso+qkcT5HVkHz0jiGofzdYfSjyOTuJ7gk0pf4wAl
pvq9bf2+tgbfSw6tMndWGaeUa6yynqvMmzohrpHYSFknmS/qGWnaXTO1XKv0
mNI29WwnrlMziZ+paTvUtB1q2g5IG9Q0WirzNetDF8dGF2O5rtJTWmy7vxbi
fP+asUvpB+xs/ja135r6uaUh9tdS4zXlc1jkeJ0XYn9hsY5SYpse1XPNqxLz
qsSgH9gndE/iPgE/0v3KXqG75WthPrWwPEjZWhiUr02IdcPRukh3alPfl6H5
jqsygzGFWcp1zzMXzzMHcZxONY+yzKEsgzziupVet9Lg+pVen3nx0STOhY86
jlsZbfVBZa3BG5R15nrb9nrb9Hqvw5mMuRB3aHNf76MDlfmQeXqj8Z4eUeZz
1v/Hk7j+4249rexR8KEkznPk+dgQ98CYp2MtD55Qch/TbMfxSRyT2Egf0Dl6
RDkTjne8DQ9xjA43yrVKGZc4y+95McTvedF+e9F+e9G+w4tCzFEs1fm6S/cr
uYottbMONW83GeTqpvDv8dQliftxLNZ5+rru1tPKXgvP1SZKsP9iHZkZ4loz
02Dtxtqapq2Udee8EM9cGPx7kdLHrCMzkrhu4Ho9rKwpmKvTlHqmW89065lu
PXGbHlXqlW690o0u1qteEutVz3IjdcPaSrTS6vV0r1GldzheCh1DhUaJPmq5
b0nifIf5Okrn6XLdpkeVcmOzEOdpLPDvxVqizIeclyeEON9NMObqUt2kzH0T
zCfGV5sk5ibuUMYW1tSWSgx1HJzpeDvT8YZZ+oDO0Rf1TMcd7XODka/zdLlu
1m1KezDv9gtxru5njNZF+rruVnIem2iGdtHqc8ffQ9z/4BNKsA9qGmIO42Jd
r4eVHMZcnaYz7KdB5s0g82aQ+TLIKFb69ZoQ50Acq1v1hNb2fWle/2WDz79s
XvD9ay37Wsu+1qC8ax0H2Ep7K+X+WYh7EczWPJ2vZ/i+mtrGvJ9ivk8xr5F1
Dxtouo7Uccp6VmC7Flj+AmOxrlfKyb55lsHeGZvp78zHZ4wjSh6m/oSDIa6z
B41KzbIeL4RYD5yoBHXAATpSJ+sUner3zEzi9+BBrVTWdszSIqVf/2C8rPQr
89kYY5LOVPJijP06xn4dY7+S57cn7vmTmN9IcB+VebarUazMqXiVNtFOyrnm
ipQXJ3GdR2Ki5dxiubZY1i2WdYvBHLzFcm+x3Fss9xbLzX2W8iTeXyl3HJU7
jsodR+WOH/xFiHMF9tK2vp6h+bbHuyG2x7vG35U2weGOszpJHJM4VrfqCaUu
WFsJxif7tWkGZ1jspawXg81J3Kjv6RFlP8W8e2MS511spFn6gM7RF5V590Zj
vOOrMMT6Y64W2haFtkGh7YE/Vn/G7z/bcuMzekSJS3S87+vp+3CjHlHeh/WV
OedAiGcozNQNuln3KHFMB5vHH5i/2E+L9XUlWB8+MM8/ML8xXbto9f6ownyu
MI8rzOMKgxyoMJ8rzGdM01ba2/lhVBLvFyDzIzZQYpwynzB+zk/i/S5cp/uU
+XdBiHM19tc8HavEDj2hzOPYRvs4Ti5M4ljCXkq01QxlPHHu7Gx00eW6Sk9p
seXNsbw5Rp4O17FKu+ZYzhzbk/tR34a49uNuPawE6xzm6jTrNcb64GM6S1lD
xlgvbKZtNV+ZF2Zb/tmWc7btPtuyzzYqlHrMNj+wjlav432TONcj81xfo0AL
dZCW2I49QjzP9DCyNUfzdLiW62ytUtoXOe/UDLHvsZ3u1Kb+e77zUkPnhYbO
Qw2dhxo67hs6DzU0btTqdbhjiOeFjkaZHtRKZa3ELC1S1kvOpWtCvK+HQ3SN
+Y6cZ9eY3zjCfFhtXVdbV+yno3WRrnYcYIbmO299EuK8hZlaqvOV2KUH9Jiy
j8LOOljZd7MfeiTE/dAjxlQ9rN8qeY+5Ok3ZL3Euf9bPPmvs1tPK9+JEfdz8
PG6Qm8fNUyzQQh2kxVqirM+cV7KTeA7BubpJOZtkO76uN3J0jM7U2bpFK5Rx
hrW1jtbTNO1t/y+x/3GkjtZFusS+X2I7L7H/ybvMJOZbpnmFO5ScyzT66EAl
/2qEOJZqWIYa5mANc7CGZanh9+NObernM5Q8JP/Kkph/uEE36x49oMeUPi8z
eH4xNMTnw/iQ4/Rco6OWaaUyPrGbZinjk/sadyXx3giW6nzdpdwTwZbaWQnG
AfvB7cZJ5bkBTlLyjPvyT4V4Xx67KvGmsq/FTprjOPsyxHGGBfqIrlfisLLn
xVydpjOcFy420jRTN+hm/UT36AE9pvTRxfYX/b0yxPxdaQ6tNIdWmkPYS0fr
SvNopXmEzGcrzSdsqxma7/h/2ziujH8s0EIdpMVaog9oue28wnZeYTvjYiXW
6nplXsNWOsPxNySJvwPBX+sQXaM/jVGDccc4fyfE8Y1LdLWS75eFmL+XGR21
TA9qpZL/2E2zdKZ5MDDEdXqguYDdtYdmKjFcy7VKjyn3o5D1+uch7lFxjE7S
mbpWX9V1ukUrtLbXq6ettPp+X+sknvuQhmptFOlEx2l7+7u947K96wCeVMZu
e6NAC3WQFmuJkj+3hni2wGd0ox7Rs31ffe3pvPN+iM8q3jd2KXMNUn72VWcb
2Zqj/TVPx+oC3aEnlH0Vsr+mT3oksQ9wne5T9vI9HB/3JnF84CM6Vb/Uw/qt
MhdhrhLTlPHCc6HfJPF5Ga5SYoBOdt6+1fxFcvtWo5uS3w2C90RCnFfxqJ7n
vzfQkTpKx+kUx/Fbxgll7cRMZd1k/3BPEu934gSdq0t1k7KfwGxlX3FlEp/l
Yob21636hTIWsI5eEOLeAXtotubocC3X2VqhiddJ01l6URKvjT00R4druc7W
CuWaFxlp2kpnWe8BIdZ3gDk8wBirb+lWPaHUfYDtwf3bR5J4zsauWqzzdJt+
oEeVszY20XTtolOU5+t3209320932z932z932yfIOjg9xPUPeymxRFfqan1H
Wf/wEm2rGZrv/PF0iHPO08YzulGPKPMO1teeynmHfcmgENsRa2kD7apEsT6l
8/So0paYrp00R0fpFKVdr0j5V4O5Gy/W1sr8x3rfLonzOL6t2/W4nlSivRZo
oQ7SYi1R5nHOIwtDnNfwWV1oGRdazoWWc6HlXGg58XHz8sIQ79teaNygN2q+
jtJ5uly36VGlXfEWHaDMjzz/fCXE9nnF2Kjv6XY9qeQDsuaxf7svxH3bfebr
fcZK3ankJzbTtpqvP/2uJ+UbIe5/cIgu0DVK7FDWI8zUPjpE2SexP7nXKNcl
+o7uVfYj7HPuT+I+By/WNM3UgbpBP9EDWqXHlLPx/cZgZR9Mf3ewjzsYo3Si
Pqkv6HJdpax5HexfHKnVvwNbFmJ9ME27aw/N1IE6XMt1me2EVUp7LbN+yDzN
PNDI8Yov6JvKmooNlBipo3ScMu5ZLz8N8dyFj+pHSuxXzl7Y3c8V+bkiY4R+
qvuV54p4j/Pb2CSeu7CrPqXfK2cv7KQ5yj7z5iTuZXGMTtKZ+qqu0y3K/gnr
KdFD2b+WhDhmcbue1Mb+ezttr5OU+Yp90d8Mfl+BHfRW7aZZWv37vs/8bnxF
N+p7SjBPfGZ5aI+utgder2N0ks7UFbpWt2iFsk/A2nqR1tNW2tX2ui7EtQA7
axct0bf1uJ7UU9rO67TXAh2kxVqinBM5ZzQ2RuhSfU3fV9aHxuYhtlbOI6k/
YXoSz25Yppv0oFYqn5luzLTffpHE9R8HK79L/IVRX2/TntbjOdvuOdsM/6DE
Kn1Z39ZTyrz0nO3znO3CfPRdiPMqZmqpztdPdJce0GNKMKdiS+2sd+n9Wv27
/P5JnA/6O97xUf1IP9X9ypyC3ZU6/mCu/GBwP/EH8+QH8wT7aoEW6iAt0UeV
8cm57VCI7XTI9sE8LdX5+onu0gN6yLY6ZFsdsr0O2V6HbJ9Dtg/zwrgQf2c1
zvibMk9gB71Vu2mWllr+K0M8L15pZGuO9tc8HasLdIeeUM6f2MdxcbXRWqfq
s7pQX9P3lcH00+d0orL/4v7e5BDzY7LtPNmYr7v0OyU3Jtuek82/yebf5P+X
d38OMd9wgs7VpUpw1sNsZT3qGeKzTizUJ/Rd/bve7vt57stzjdFJfK6BjTRL
H9NZOkdfVJ4j4ZlK8NyI/f7DSVwX8Sn9XlkXsal20hwlWCfZP17g9bCNttN+
OlpX6+v6gfIM9AKjiTbVDO2iPAdl3ultPvQ2SvU1fV8/0V16QL9T+hvZz3E+
nRHiOQ8HKPGWbtUvlHMpXul8+58hzrdYog8r8bZu1+N6Un9Q5iFsrwVaqIO0
WEuU+Sf1JzwU4nyAl2lHJcZpmf5ND2qlMl/grdpNs5T1if3/7w3OB/iQci5g
Hf1tiOe+39pv2FqJqbpQ/6pUBi/W1jrR/Ls2xPPLtUYbbaf9dLSu1J1KTmFT
JbeHhfgMEefoM9rQf79ROU9z7r8uiecPHKnTdZEu0dX6jl6X/Pv5yVfW5yvL
h730Ph2qv9eVulO/sj6Yrw85bv5p+//T9sfemq/P6mbdoweUYLwg8y77kzuT
mOf4ir6nnyn7Eqyvtyn1/TrE/frX1vtr6/m18b1Sr6/tJ9anhiGuKw2NazRb
++sAHasLdIeeUNYpZJ3idzP3G9OUfQL20urfP38e4n1S7KkFWqhP6GJdrwTz
Ps8P/hji+RmHKLFG31DOyz+9R0c47q9J4jjHMt2kB7VSiSKdroxn1v/Lkng/
EOtqPe2uPTRTszVH83SgDtdyXaZVyjngMmOW8+lZSZxHzzK/znKew+16XE/q
D0o01nbaXu/Ucut3aYj1u9RI0+7aQzN1oA7Xcl2me7VKqRPeofcr9ZyQcoox
VzcpfYItNFuLdLr98VKI8w8uUeId3avMNS+Ff///cvqGuD5gRyUe0jI9qJVK
ubCDFul0nen1x4e4Do33e8b7PeO9zni/a7xRpge1Uvm+8X4fZmmRTtfq/P1t
EveDOFnn6wI9pN8pYx9raktto3cpMdT5+kHnL6yl12o77ar9tFg/UPY/eK5e
oE20qRLMe5zHr07ieRwv1+s1XcfoTN2iW7VCOYdjHa2nVypxs3IeZ3573HhV
1+m7uk+Z15D9LPdH+yXxfhleqDdosY7SebpNjyrthOl6i3ZRgvvMPL/6ZRLn
ZXxEF+sKXauH9Vslammu3qvTdIb98U2I34OTdLGu0LX6qq7TffqN34u1tJ62
0q5KP7Ce/zqJ6zm21t46VZ/Vhfq+7tED+k89rcRgnais93eHOGfhFJ2rS/XP
uklb+Llsvcf+6WO79TEKdLGu0LW6Xj/XL/WwfqO0Yx/bEeknfh94i1GiD+sG
3a4nlTUCG2t7LVPuy7EPuSvEfQg2VGKBrtE3dIcy52BLbaN9lLmG83wn43bN
1R+V8z3n1D+FeD/kT8ZH+qlyDwS5D8K+tW4Sz5XYSx/TWco5sq5xoTbTtpqv
o3WM4+Lm4H3UEOcnTFdijE7SmbpFK5R7hlhb6+nVerN2VcYH6+GwJN4vw6f1
Jd2oe/WI8uwML9H6eodyH+5yr4vD9Bk9oux3Lzd6mu/Pm+/Pm6fPm/PPG4t1
ha7Xz/VLnWHefWjefWjefWheYbb217G6QNfoG7pDiRNKfn5oXn5oXt4U4hpw
k3W4yTrg4/q8LtYV+qqu0/X6ue7Tb/R2v4/1I+G1JJ4nsaP21fFappXKB/Ea
ba1EkU7XmY6Lf4WYPzhdX9J3lCBH8DodZjk/DrF82FfHa5lO0U1KHNRKpcwf
Ww8s0ulKec8KsU2wsXbUvjpXl+rHGvx8Db1GW+tNWqR8H+eC/wpxPGMPzdYc
Ha6zlahQxjPW1ov0Mk1T9sc8V7wnxPy+xxiia/QNfUt36Id6Qvk9B2ZqHx2o
nKN4fnRpEs+j2FWf0u+VuEo7aY4+qA8r98t4rnaH8abyLA0baCMdpTxH+1WI
ayZO0Cm6SbN9H3nBfrBjEs/CmK4ZerMO0Bm6Vb9Q+gbr6JV6tRL87oFz8p3G
/TpNeUaBt2kvx0dz41faUfvqeC3TKbpJP9aDWqnkb3Pztrl529x2aW7+Mn//
JcT5G5/WZ5TYqEeUuRzP1vp6ufZUxj/ngt+FeC7Aa7WNttN+SozWlbpadypn
AmyqGUqetQjxOTM+qS/oef57Ax2p/P/CmN8eS2I74NP6kv5FN+pePaL/UtoE
L9E7dJhyDvvvEO/LY5GO0FKdrMSnul+5T48t9S7tr9W/T//fENdX7KOP6GJd
oWv1sH6rBPtHrKW5eq9O0xmOu2uTOEZxgk7RubpU/6yblGih2cr+mPtBvwnx
fhDepcQQ/aOu0Teq/z2JMp9xf+N/Qry/gZdqmt6i3TVTB+oyfUU3KHFAq/SY
cn8Dy3SS4+JXSRwXeK0O1Z36lX6t3yu5j9TjH9bjH5Yb79WBWq7L9CXdq1VK
kLM4TMlb7uPfl8TnpficrtKX9ZTyrPQ+o1h5Xsp6MsH5f4LzOg7Sp/RNZcz+
9H5tpJ00R0fpOCX4vcX/Ab8fSPc=
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[337, 399] -> 
             RGBColor[
              0.3938501177780911, 0.5155549093620503, 0.9463167591302035], 
             UndirectedEdge[15, 92] -> 
             RGBColor[
              0.5165465598161544, 0.616266129067979, 0.9557348329118063], 
             UndirectedEdge[87, 313] -> 
             RGBColor[
              0.9063755986795785, 0.9281833157496207, 0.9909321078047488], 
             UndirectedEdge[35, 214] -> 
             RGBColor[
              0.6562378253599432, 0.7216910392492469, 0.8696731065295088], 
             UndirectedEdge[105, 218] -> 
             RGBColor[
              0.4282231813068001, 0.5453271293502118, 0.9485069803433461], 
             UndirectedEdge[149, 316] -> 
             RGBColor[
              0.7393651261534393, 0.7959788571177282, 0.9751630729273437], 
             UndirectedEdge[160, 348] -> 
             RGBColor[
              0.5039604619006617, 0.6047742521406388, 0.9551827564799646], 
             UndirectedEdge[17, 287] -> 
             RGBColor[
              0.4742897065882273, 0.5833005840788026, 0.9519747493885473], 
             UndirectedEdge[268, 295] -> 
             RGBColor[
              0.49726882203817013`, 0.6012318096472093, 0.9539838634987604], 
             UndirectedEdge[277, 379] -> 
             RGBColor[
              0.5968193671646418, 0.6800147744951707, 0.9632959567216511], 
             UndirectedEdge[10, 37] -> 
             RGBColor[
              0.6368461730626658, 0.6503059508902076, 0.6109959438575627], 
             UndirectedEdge[118, 389] -> 
             RGBColor[
              0.7111919009371273, 0.7735344172175809, 0.972452721882302], 
             UndirectedEdge[127, 313] -> 
             RGBColor[
              0.8588074931240577, 0.8902537995814764, 0.9863950194323141], 
             UndirectedEdge[92, 281] -> 
             RGBColor[
              0.40758839378247225`, 0.527454313531216, 0.9471921499289222], 
             UndirectedEdge[2, 193] -> 
             RGBColor[
              0.45416954338787624`, 0.5645546903040016, 0.951057104187844], 
             UndirectedEdge[265, 378] -> 
             RGBColor[
              0.6037924651155623, 0.688365793003562, 0.9625393111423999], 
             UndirectedEdge[108, 367] -> 
             RGBColor[
              0.4811823412786237, 0.589522331398557, 0.952344398288693], 
             UndirectedEdge[26, 342] -> 
             RGBColor[
              0.26188573609893995`, 0.39258889152765125`, 0.9382253772943827],
              UndirectedEdge[57, 144] -> 
             RGBColor[
              0.6097074953332337, 0.6923540457468367, 0.963561387598239], 
             UndirectedEdge[341, 348] -> 
             RGBColor[
              0.6151381101779749, 0.6980680288777852, 0.9630965568114132], 
             UndirectedEdge[232, 309] -> 
             RGBColor[
              0.5256471563816024, 0.6251136967392534, 0.9559849652879655], 
             UndirectedEdge[23, 202] -> 
             RGBColor[
              0.8344290430168251, 0.8689430941844141, 0.8626487841711258], 
             UndirectedEdge[89, 170] -> 
             RGBColor[
              0.4387094508561902, 0.5520034907175473, 0.9498400290715647], 
             UndirectedEdge[291, 383] -> 
             RGBColor[
              0.8025624527654625, 0.8441319867751713, 0.8829732385125724], 
             UndirectedEdge[45, 140] -> 
             RGBColor[
              0.6388269091921089, 0.7021129119823231, 0.7230071796966454], 
             UndirectedEdge[213, 308] -> 
             RGBColor[
              0.8087187586567215, 0.8159333647450915, 0.6494611266981982], 
             UndirectedEdge[165, 386] -> 
             RGBColor[
              0.7192852929117797, 0.7751812043093721, 0.8245312820333761], 
             UndirectedEdge[347, 381] -> 
             RGBColor[
              0.7407122151502812, 0.7970509439017051, 0.9752939137151251], 
             UndirectedEdge[216, 396] -> 
             RGBColor[
              0.6272722104205875, 0.7082745239760273, 0.9638087499892338], 
             UndirectedEdge[39, 150] -> 
             RGBColor[
              0.871513805682149, 0.41759552728505006`, 0.41577948409959753`], 
             UndirectedEdge[20, 378] -> 
             RGBColor[
              0.34416270483434996`, 0.4590236444939595, 0.9440081201163704], 
             UndirectedEdge[363, 372] -> 
             RGBColor[
              0.5635711041289858, 0.653489384609488, 0.9602155413533728], 
             UndirectedEdge[54, 318] -> 
             RGBColor[
              0.6975233840771489, 0.7595613807215444, 0.937608980751416], 
             UndirectedEdge[40, 246] -> 
             RGBColor[
              0.23740618916561135`, 0.3668593356078027, 0.936831303310774], 
             UndirectedEdge[59, 178] -> 
             RGBColor[
              0.6507898887961578, 0.7169708511418922, 0.869272332744734], 
             UndirectedEdge[172, 357] -> 
             RGBColor[
              0.6953599328208339, 0.7577058221085999, 0.9377384115740345], 
             UndirectedEdge[268, 274] -> 
             RGBColor[
              0.45132251683991087`, 0.5639305292298012, 0.9503668020466919], 
             UndirectedEdge[122, 175] -> 
             RGBColor[
              0.7703733720645172, 0.8200723431068333, 0.9555697119257347], 
             UndirectedEdge[120, 341] -> 
             RGBColor[
              0.5316741515652139, 0.6306760537450422, 0.9562744832792542], 
             UndirectedEdge[220, 366] -> 
             RGBColor[
              0.6629999703018504, 0.7316560931576845, 0.964556541472326], 
             UndirectedEdge[202, 366] -> 
             RGBColor[
              0.5297708124978098, 0.6267491000855356, 0.9569885335414856], 
             UndirectedEdge[17, 61] -> 
             RGBColor[
              0.37171006948305263`, 0.4861656667007677, 0.9457418417133376], 
             UndirectedEdge[112, 279] -> 
             RGBColor[
              0.5705080589039535, 0.66220316917022, 0.9593316307182497], 
             UndirectedEdge[129, 313] -> 
             RGBColor[
              0.9449168014566043, 0.9556565716352569, 0.8640603370095518], 
             UndirectedEdge[204, 318] -> 
             RGBColor[
              0.3943344866020523, 0.5159744452922805, 0.9463476226833557], 
             UndirectedEdge[60, 335] -> 
             RGBColor[
              0.5866857927162822, 0.6732494439720093, 0.9617987388260815], 
             UndirectedEdge[256, 386] -> 
             RGBColor[
              0.76425692832454, 0.8119564727405766, 0.8279983193348575], 
             UndirectedEdge[7, 65] -> 
             RGBColor[
              0.6867544077435792, 0.7533808568606026, 0.9708904391010298], 
             UndirectedEdge[66, 280] -> 
             RGBColor[
              0.47989372795190005`, 0.5826307135762747, 0.9536822778893821], 
             UndirectedEdge[147, 344] -> 
             RGBColor[
              0.9887112868406132, 0.9875568814687817, 0.6882451120719052], 
             UndirectedEdge[329, 349] -> 
             RGBColor[
              0.4886991418835397, 0.5826882901550924, 0.9556398279395887], 
             UndirectedEdge[170, 306] -> 
             RGBColor[
              0.395255159985038, 0.5088018363223259, 0.9472748755552141], 
             UndirectedEdge[175, 178] -> 
             RGBColor[
              0.9759879006536616, 0.9804685274524614, 0.8743056233113375], 
             UndirectedEdge[115, 166] -> 
             RGBColor[
              0.9716716620978334, 0.9746408167003149, 0.6987709194307159], 
             UndirectedEdge[361, 396] -> 
             RGBColor[
              0.46556137065056, 0.5733758429648284, 0.9520719598766819], 
             UndirectedEdge[80, 265] -> 
             RGBColor[
              0.5312666703458688, 0.6270633077934322, 0.9574992356228813], 
             UndirectedEdge[18, 288] -> 
             RGBColor[
              0.7328361627976039, 0.7902351600196793, 0.9697056111396989], 
             UndirectedEdge[225, 240] -> 
             RGBColor[
              0.8040283072650131, 0.8472555694540718, 0.9809893607261546], 
             UndirectedEdge[110, 251] -> 
             RGBColor[
              0.8264603990255699, 0.8620366339229024, 0.8185309631012643], 
             UndirectedEdge[56, 169] -> 
             RGBColor[
              0.7626342871575189, 0.8068675428645251, 0.6877476895308534], 
             UndirectedEdge[87, 231] -> 
             RGBColor[
              0.5806583550600253, 0.6553162926056526, 0.9645961486038584], 
             UndirectedEdge[266, 315] -> 
             RGBColor[
              0.9435909344430307, 0.9572726592791703, 0.9741940477073607], 
             UndirectedEdge[31, 292] -> 
             RGBColor[
              0.743771367779098, 0.7949703927189362, 0.7972915941609648], 
             UndirectedEdge[1, 87] -> 
             RGBColor[
              0.9561892205536575, 0.9642055305599272, 0.8340542526844889], 
             UndirectedEdge[231, 336] -> 
             RGBColor[
              0.25093606157607984`, 0.38108008935466253`, 0.9376018095288976],
              UndirectedEdge[13, 309] -> 
             RGBColor[
              0.6618606555742337, 0.7354675989105133, 0.967138387719443], 
             UndirectedEdge[237, 296] -> 
             RGBColor[
              0.32562131330888977`, 0.45407640943391764`, 0.9420565018115856],
              UndirectedEdge[95, 312] -> 
             RGBColor[
              0.25131303759231916`, 0.38147631504939006`, 0.9376232777553364],
              UndirectedEdge[108, 236] -> 
             RGBColor[
              0.6606605984623791, 0.7321191807150433, 0.9687836236776863], 
             UndirectedEdge[48, 176] -> 
             RGBColor[
              0.5844087214061121, 0.6689398238979268, 0.962642916955366], 
             UndirectedEdge[49, 52] -> 
             RGBColor[
              0.5932032303803267, 0.6662006151839587, 0.9656486213507838], 
             UndirectedEdge[310, 390] -> 
             RGBColor[
              0.8819843165674952, 0.9079565997833978, 0.9526428373019984], 
             UndirectedEdge[343, 358] -> 
             RGBColor[
              0.7139396776968091, 0.7741040420890732, 0.9470264425158779], 
             UndirectedEdge[271, 374] -> 
             RGBColor[
              0.6416856493514145, 0.6045918261137058, 0.5993710374772141], 
             UndirectedEdge[57, 167] -> 
             RGBColor[
              0.6095658062476451, 0.6922433571562979, 0.9635472653543473], 
             UndirectedEdge[34, 214] -> 
             RGBColor[
              0.5800188340719341, 0.6634867649055168, 0.963085673796582], 
             UndirectedEdge[83, 220] -> 
             RGBColor[
              0.7836792791756038, 0.8315055611970406, 0.9735383572468299], 
             UndirectedEdge[9, 347] -> 
             RGBColor[
              0.5647084350991847, 0.6402262755581736, 0.9634341702236906], 
             UndirectedEdge[188, 238] -> 
             RGBColor[
              0.2732458561796262, 0.39936966336094515`, 0.9390612315036447], 
             UndirectedEdge[79, 137] -> 
             RGBColor[
              0.405298706955256, 0.5222799882036537, 0.9475808850925993], 
             UndirectedEdge[115, 197] -> 
             RGBColor[
              0.7049963779919675, 0.7612251030684736, 0.6886007894947765], 
             UndirectedEdge[67, 194] -> 
             RGBColor[
              0.8789346402951476, 0.8334336234891146, 0.6275712641710686], 
             UndirectedEdge[75, 260] -> 
             RGBColor[
              0.796548791428674, 0.8411407731082856, 0.9803159843869597], 
             UndirectedEdge[32, 387] -> 
             RGBColor[
              0.6510556119263317, 0.715639892448513, 0.7910895050372204], 
             UndirectedEdge[76, 144] -> 
             RGBColor[
              0.6090410701333158, 0.6918130117474302, 0.9635089241653055], 
             UndirectedEdge[50, 164] -> 
             RGBColor[
              0.7198494844534205, 0.7810711554045069, 0.9727115273005678], 
             UndirectedEdge[279, 285] -> 
             RGBColor[
              0.7086033354627932, 0.7715490128718273, 0.9721153003679279], 
             UndirectedEdge[137, 352] -> 
             RGBColor[
              0.5316598905104187, 0.6229067804857098, 0.9588678171437802], 
             UndirectedEdge[4, 275] -> 
             RGBColor[
              0.5310570622820397, 0.6183893864025864, 0.9594483468740929], 
             UndirectedEdge[8, 373] -> 
             RGBColor[
              0.4328022406371193, 0.5430978457803007, 0.949883581882228], 
             UndirectedEdge[41, 135] -> 
             RGBColor[
              0.40197733143939995`, 0.5220864902913384, 0.9469749254961535], 
             UndirectedEdge[85, 211] -> 
             RGBColor[
              0.5745019179253128, 0.6652769430896368, 0.9597613288618025], 
             UndirectedEdge[63, 139] -> 
             RGBColor[
              0.2536269286903164, 0.38213109149665003`, 0.9378201249840377], 
             UndirectedEdge[55, 92] -> 
             RGBColor[
              0.33251358281884075`, 0.46017757537562204`, 0.9424908588886789],
              UndirectedEdge[31, 371] -> 
             RGBColor[
              0.3384304523596853, 0.4549226038837315, 0.9435065496362708], 
             UndirectedEdge[99, 169] -> 
             RGBColor[
              0.8454802406646742, 0.8732411440525798, 0.694874347562541], 
             UndirectedEdge[71, 72] -> 
             RGBColor[
              0.6436904525529263, 0.7169412305229985, 0.9679229319553104], 
             UndirectedEdge[104, 112] -> 
             RGBColor[
              0.7698380119370238, 0.8177824385493915, 0.8894947154958537], 
             UndirectedEdge[389, 390] -> 
             RGBColor[
              0.90905701310455, 0.9292861037801607, 0.9552933956377986], 
             UndirectedEdge[260, 349] -> 
             RGBColor[
              0.5412386227150949, 0.6238840680539347, 0.9608362593423885], 
             UndirectedEdge[70, 284] -> 
             RGBColor[
              0.7318919352809299, 0.7886450208202276, 0.9475419258040111], 
             UndirectedEdge[24, 172] -> 
             RGBColor[
              0.7157851559525017, 0.7753000990358923, 0.9390666969575696], 
             UndirectedEdge[343, 362] -> 
             RGBColor[
              0.6969054397208304, 0.7595951098600957, 0.9458732675064203], 
             UndirectedEdge[233, 307] -> 
             RGBColor[
              0.5958313484094236, 0.6760380786563588, 0.9646201975591722], 
             UndirectedEdge[79, 278] -> 
             RGBColor[
              0.6423148648602819, 0.7185880459852145, 0.9662911708349389], 
             UndirectedEdge[1, 216] -> 
             RGBColor[
              0.8189855936374197, 0.8562322482255922, 0.820588391691726], 
             UndirectedEdge[192, 374] -> 
             RGBColor[
              0.3871736416828415, 0.5097720813377908, 0.9458913399771902], 
             UndirectedEdge[152, 383] -> 
             RGBColor[
              0.8262158321076016, 0.8630386817343595, 0.8850378217729247], 
             UndirectedEdge[43, 121] -> 
             RGBColor[
              0.7328409446628167, 0.7907637763566002, 0.9745556101768478], 
             UndirectedEdge[13, 280] -> 
             RGBColor[
              0.4976962253071892, 0.5965381598142178, 0.9554566644519609], 
             UndirectedEdge[246, 272] -> 
             RGBColor[
              0.2606102967945234, 0.3912483239511869, 0.9381527429128396], 
             UndirectedEdge[385, 387] -> 
             RGBColor[
              0.7435265224656331, 0.7947716162633097, 0.7972723190409909], 
             UndirectedEdge[90, 268] -> 
             RGBColor[
              0.31877818446496653`, 0.44416984963169537`, 0.9417661684910332],
              UndirectedEdge[195, 363] -> 
             RGBColor[
              0.6981996302631488, 0.7641581247660806, 0.9705536721642718], 
             UndirectedEdge[88, 109] -> 
             RGBColor[
              0.7950128108612815, 0.8401024938325745, 0.9801199978017605], 
             UndirectedEdge[63, 318] -> 
             RGBColor[
              0.37401607865201775`, 0.49837566155883795`, 0.9450529516956422],
              UndirectedEdge[257, 276] -> 
             RGBColor[
              0.46024657769345334`, 0.5706211120850471, 0.9512225113788031], 
             UndirectedEdge[16, 106] -> 
             RGBColor[
              0.5859154000436164, 0.6463121354297428, 0.701250808021925], 
             UndirectedEdge[100, 227] -> 
             RGBColor[
              0.3167354778749534, 0.440625267048785, 0.9417010111994555], 
             UndirectedEdge[195, 359] -> 
             RGBColor[
              0.46839569011276805`, 0.5711030350012147, 0.9529392230791789], 
             UndirectedEdge[216, 313] -> 
             RGBColor[
              0.7691719717633405, 0.8202100334152855, 0.9774662468119859], 
             UndirectedEdge[12, 47] -> 
             RGBColor[
              0.967066803263236, 0.8980488322783565, 0.5195681449821384], 
             UndirectedEdge[386, 400] -> 
             RGBColor[
              0.7536162424416151, 0.8033178845833818, 0.8271606455640368], 
             UndirectedEdge[180, 262] -> 
             RGBColor[
              0.47555678773550636`, 0.5827425853887902, 0.9525129009271962], 
             UndirectedEdge[247, 359] -> 
             RGBColor[
              0.4341471332996947, 0.5435895210924603, 0.9500440878870087], 
             UndirectedEdge[74, 141] -> 
             RGBColor[
              0.8130167755158317, 0.8547703503302364, 0.9817544411184661], 
             UndirectedEdge[170, 171] -> 
             RGBColor[
              0.5754881599844709, 0.666246239578381, 0.9597236825180193], 
             UndirectedEdge[207, 333] -> 
             RGBColor[
              0.6559299336715587, 0.6144655064674438, 0.5996894886980909], 
             UndirectedEdge[311, 313] -> 
             RGBColor[
              0.7567238666071321, 0.810116441460009, 0.976477849045521], 
             UndirectedEdge[161, 195] -> 
             RGBColor[
              0.6347256687793582, 0.7140469104454299, 0.964586039547745], 
             UndirectedEdge[87, 129] -> 
             RGBColor[
              0.9561130452991864, 0.964584152561389, 0.8651282447422621], 
             UndirectedEdge[198, 367] -> 
             RGBColor[
              0.600027154453292, 0.6855143731495899, 0.9621024391876101], 
             UndirectedEdge[322, 330] -> 
             RGBColor[
              0.599332511634803, 0.6683975706036487, 0.9416648435449289], 
             UndirectedEdge[79, 314] -> 
             RGBColor[
              0.6842490529733485, 0.751597919586455, 0.9704042859952053], 
             UndirectedEdge[56, 274] -> 
             RGBColor[
              0.5197173208056236, 0.6209689598853194, 0.9553331977625451], 
             UndirectedEdge[249, 316] -> 
             RGBColor[
              0.6284572837442863, 0.7032834182164455, 0.9671657117342849], 
             UndirectedEdge[69, 294] -> 
             RGBColor[
              0.5965246264530264, 0.6808665652268485, 0.9628086072419204], 
             UndirectedEdge[6, 300] -> 
             RGBColor[
              0.7457413147677099, 0.8006737317848001, 0.9696912900762822], 
             UndirectedEdge[36, 265] -> 
             RGBColor[
              0.4899425386309087, 0.5887458596016566, 0.9549585350845982], 
             UndirectedEdge[167, 395] -> 
             RGBColor[
              0.5048341124801482, 0.5972677920115501, 0.9569353806662375], 
             UndirectedEdge[261, 306] -> 
             RGBColor[
              0.28415618762559147`, 0.41497980872239987`, 0.9395308743722586],
              UndirectedEdge[35, 211] -> 
             RGBColor[
              0.7433540076559046, 0.7959976283929975, 0.8755415639233866], 
             UndirectedEdge[54, 63] -> 
             RGBColor[
              0.6514760038094585, 0.7196774543422977, 0.9346748823988583], 
             UndirectedEdge[302, 314] -> 
             RGBColor[
              0.9200088830490493, 0.9368745114040098, 0.9085314595286136], 
             UndirectedEdge[54, 224] -> 
             RGBColor[
              0.6938574630099462, 0.7563861441476838, 0.9373753915026606], 
             UndirectedEdge[164, 389] -> 
             RGBColor[
              0.7684353698814181, 0.8192069260691657, 0.9775063192528366], 
             UndirectedEdge[113, 210] -> 
             RGBColor[
              0.8763733076815712, 0.7142402647772274, 0.6025920600596766], 
             UndirectedEdge[307, 348] -> 
             RGBColor[
              0.4930567346618032, 0.5953299916436057, 0.954487980622092], 
             UndirectedEdge[18, 74] -> 
             RGBColor[
              0.8171491228535772, 0.8579131291300754, 0.9768702347292562], 
             UndirectedEdge[41, 328] -> 
             RGBColor[
              0.6097479723269927, 0.6924496410486687, 0.963521682342809], 
             UndirectedEdge[63, 290] -> 
             RGBColor[
              0.5981942002360681, 0.4769490791836163, 0.5770186831239819], 
             UndirectedEdge[45, 288] -> 
             RGBColor[
              0.7586589541196911, 0.8062347882797561, 0.7310911688709603], 
             UndirectedEdge[249, 315] -> 
             RGBColor[
              0.6569551176869133, 0.7254216624243521, 0.9495961685310206], 
             UndirectedEdge[306, 342] -> 
             RGBColor[
              0.24966329213080624`, 0.3797423279694363, 0.937529327191883], 
             UndirectedEdge[163, 395] -> 
             RGBColor[
              0.33649080475826487`, 0.4612165105262305, 0.942832377004927], 
             UndirectedEdge[378, 379] -> 
             RGBColor[
              0.4571134301684871, 0.5688346978811334, 0.9507666374630048], 
             UndirectedEdge[216, 235] -> 
             RGBColor[
              0.45631735926268674`, 0.560862451115197, 0.9518627954247595], 
             UndirectedEdge[220, 321] -> 
             RGBColor[
              0.9376042867805445, 0.8649134858161915, 0.6243462320619797], 
             UndirectedEdge[133, 199] -> 
             RGBColor[
              0.7305042646208766, 0.7879971906209742, 0.9602732374081557], 
             UndirectedEdge[317, 396] -> 
             RGBColor[
              0.6220963859213997, 0.7040848970706306, 0.9633928527953315], 
             UndirectedEdge[177, 197] -> 
             RGBColor[
              0.7031037824660573, 0.7628081299953926, 0.89192478132718], 
             UndirectedEdge[208, 242] -> 
             RGBColor[
              0.8816854934078479, 0.9045036785832945, 0.7699536971702932], 
             UndirectedEdge[51, 163] -> 
             RGBColor[
              0.5545966688351527, 0.6474341898391416, 0.9589165550098548], 
             UndirectedEdge[188, 228] -> 
             RGBColor[
              0.5092364189759263, 0.6098726769076079, 0.9552951835561126], 
             UndirectedEdge[95, 125] -> 
             RGBColor[
              0.587460045028342, 0.6595431044479301, 0.9617618326744516], 
             UndirectedEdge[66, 203] -> 
             RGBColor[
              0.5938942203430669, 0.6808348080452846, 0.9614149122107161], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.37389457876194615`, 0.4982704244608199, 0.945045209830085], 
             UndirectedEdge[151, 265] -> 
             RGBColor[
              0.6470212038880644, 0.7234608305715682, 0.965942435810659], 
             UndirectedEdge[76, 333] -> 
             RGBColor[
              0.6923786354810615, 0.6456773211334561, 0.6021109446899229], 
             UndirectedEdge[119, 336] -> 
             RGBColor[
              0.28795605993494505`, 0.4191547500687165, 0.9397406429144874], 
             UndirectedEdge[183, 395] -> 
             RGBColor[
              0.3300522223086515, 0.45563973402093877`, 0.9424221162246524], 
             UndirectedEdge[42, 204] -> 
             RGBColor[
              0.44708264011217674`, 0.5597007113455008, 0.9502506658818066], 
             UndirectedEdge[12, 107] -> 
             RGBColor[
              0.9143556700557307, 0.9316272210244243, 0.8758774904375424], 
             UndirectedEdge[234, 239] -> 
             RGBColor[
              0.600906823183988, 0.5413794433851246, 0.5904314527031745], 
             UndirectedEdge[164, 287] -> 
             RGBColor[
              0.5594464599018304, 0.6516343546605257, 0.9592257827543638], 
             UndirectedEdge[32, 194] -> 
             RGBColor[
              0.5612709927688859, 0.6480010459717247, 0.9615085858597694], 
             UndirectedEdge[6, 169] -> 
             RGBColor[
              0.7697899514679927, 0.8126768335107712, 0.688311009637436], 
             UndirectedEdge[24, 240] -> 
             RGBColor[
              0.5962975577446532, 0.6817103233306067, 0.9623395205664084], 
             UndirectedEdge[9, 381] -> 
             RGBColor[
              0.401048827422971, 0.5106916601844602, 0.9479870980637257], 
             UndirectedEdge[43, 90] -> 
             RGBColor[
              0.5650333078977281, 0.6423747576608161, 0.9631789201258567], 
             UndirectedEdge[88, 157] -> 
             RGBColor[
              0.9131395531660385, 0.9327554055055032, 0.9631021363342308], 
             UndirectedEdge[100, 314] -> 
             RGBColor[
              0.6318581595367478, 0.7079626166516608, 0.9665843731047952], 
             UndirectedEdge[56, 296] -> 
             RGBColor[
              0.45133341228076845`, 0.5631423389490992, 0.950587883111741], 
             UndirectedEdge[49, 235] -> 
             RGBColor[
              0.6025904369226953, 0.676067164443259, 0.9661832088762441], 
             UndirectedEdge[359, 362] -> 
             RGBColor[
              0.35185905710316623`, 0.47610458334412886`, 0.943753891700144], 
             UndirectedEdge[104, 285] -> 
             RGBColor[
              0.9079332884958635, 0.9271282822509987, 0.9022783851455319], 
             UndirectedEdge[80, 168] -> 
             RGBColor[
              0.6630210437835282, 0.7304612875539882, 0.9468540031177677], 
             UndirectedEdge[311, 386] -> 
             RGBColor[
              0.8066453062043523, 0.8463692674780703, 0.8313352877153006], 
             UndirectedEdge[61, 173] -> 
             RGBColor[
              0.41101979065540706`, 0.518079069231243, 0.9488364469602787], 
             UndirectedEdge[118, 354] -> 
             RGBColor[
              0.6700622275960664, 0.7412234961045479, 0.9684010954685955], 
             UndirectedEdge[154, 180] -> 
             RGBColor[
              0.36542639824481893`, 0.49093571212001264`, 0.9445056248556516],
              UndirectedEdge[17, 158] -> 
             RGBColor[
              0.4129091207470412, 0.5294684817499418, 0.9480880667342874], 
             UndirectedEdge[8, 237] -> 
             RGBColor[
              0.28171720714067633`, 0.4134330249804035, 0.9393547502321773], 
             UndirectedEdge[55, 255] -> 
             RGBColor[
              0.461909755211317, 0.5672010155248717, 0.9521320332579332], 
             UndirectedEdge[93, 214] -> 
             RGBColor[
              0.34865531904616975`, 0.4764094462570928, 0.9434369865191967], 
             UndirectedEdge[129, 235] -> 
             RGBColor[
              0.6320621889559505, 0.6963089893351682, 0.8384568856223253], 
             UndirectedEdge[47, 158] -> 
             RGBColor[
              0.6213876956074609, 0.6195135053158547, 0.6060335915218568], 
             UndirectedEdge[106, 347] -> 
             RGBColor[
              0.9486378114568637, 0.956907915067452, 0.7298708009594699], 
             UndirectedEdge[169, 178] -> 
             RGBColor[
              0.9909701862357685, 0.9857099593592844, 0.6082723104324812], 
             UndirectedEdge[230, 385] -> 
             RGBColor[
              0.6998977100470916, 0.7638952106824114, 0.9721046478645983], 
             UndirectedEdge[304, 383] -> 
             RGBColor[
              0.745165830051344, 0.797534822767463, 0.8784547661217602], 
             UndirectedEdge[100, 352] -> 
             RGBColor[
              0.5914836937770662, 0.6761712100072135, 0.96262671649228], 
             UndirectedEdge[87, 216] -> 
             RGBColor[
              0.7803682156059227, 0.8291376143414176, 0.9785341545446963], 
             UndirectedEdge[79, 277] -> 
             RGBColor[
              0.6530329111925638, 0.7269610652401624, 0.9673594455275031], 
             UndirectedEdge[217, 220] -> 
             RGBColor[
              0.8654878269361064, 0.8956722978609101, 0.9815163667897514], 
             UndirectedEdge[78, 104] -> 
             RGBColor[
              0.6180364536416173, 0.6831637899261797, 0.8793074540098885], 
             UndirectedEdge[170, 353] -> 
             RGBColor[
              0.6284193822349826, 0.7081069867312614, 0.9646503581934158], 
             UndirectedEdge[78, 385] -> 
             RGBColor[
              0.36949676762128647`, 0.4876338424347422, 0.9452703987903358], 
             UndirectedEdge[40, 102] -> 
             RGBColor[
              0.48664024143821094`, 0.5761910815559782, 0.9562085815898634], 
             UndirectedEdge[41, 256] -> 
             RGBColor[
              0.5027558096731803, 0.6071988410406332, 0.9539979254741366], 
             UndirectedEdge[120, 217] -> 
             RGBColor[
              0.6443118886334239, 0.7198713151280598, 0.96667947953552], 
             UndirectedEdge[210, 315] -> 
             RGBColor[
              0.9164067028464477, 0.7455766523792879, 0.5861227889837077], 
             UndirectedEdge[83, 187] -> 
             RGBColor[
              0.6868689409444824, 0.7550492267685365, 0.9696002368977994], 
             UndirectedEdge[2, 305] -> 
             RGBColor[
              0.5820205575997157, 0.6655668358436564, 0.9630538107766937], 
             UndirectedEdge[121, 175] -> 
             RGBColor[
              0.7682273042869372, 0.8183300686057422, 0.9554007656089784], 
             UndirectedEdge[36, 151] -> 
             RGBColor[
              0.43851935702216266`, 0.5478573607583991, 0.9503229038166616], 
             UndirectedEdge[70, 332] -> 
             RGBColor[
              0.9761000377786155, 0.9814524446404015, 0.914432428658175], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.5495108248923639, 0.5127758138373915, 0.5939363421629322], 
             UndirectedEdge[221, 400] -> 
             RGBColor[
              0.4147882814369006, 0.5320914316555678, 0.948092746187938], 
             UndirectedEdge[49, 216] -> 
             RGBColor[
              0.7894376663496934, 0.8363690453351447, 0.9793887070034181], 
             UndirectedEdge[75, 349] -> 
             RGBColor[
              0.4990550363114689, 0.5907783935899034, 0.9566720067148289], 
             UndirectedEdge[62, 87] -> 
             RGBColor[
              0.7966516721184115, 0.841858374327827, 0.9801571373123084], 
             UndirectedEdge[38, 189] -> 
             RGBColor[
              0.3803269445381342, 0.5038418163960497, 0.945455074489426], 
             UndirectedEdge[49, 361] -> 
             RGBColor[
              0.627726826579666, 0.7014703643239457, 0.9676519168908662], 
             UndirectedEdge[107, 270] -> 
             RGBColor[
              0.5421971360992967, 0.6252603381273342, 0.960834972822239], 
             UndirectedEdge[5, 8] -> 
             RGBColor[
              0.46119931577030887`, 0.5661518706470803, 0.9521191036586264], 
             UndirectedEdge[162, 340] -> 
             RGBColor[
              0.5678573705872763, 0.6552581915491634, 0.9613113420441909], 
             UndirectedEdge[34, 85] -> 
             RGBColor[
              0.7459995915463453, 0.801650548232336, 0.9752779263703688], 
             UndirectedEdge[21, 172] -> 
             RGBColor[
              0.8547464609472852, 0.8866988545424408, 0.9509745665104519], 
             UndirectedEdge[298, 393] -> 
             RGBColor[
              0.48803235971882886`, 0.5847033067438214, 0.9551718972589194], 
             UndirectedEdge[164, 371] -> 
             RGBColor[
              0.4392044221786739, 0.5359351343721126, 0.9519870274931403], 
             UndirectedEdge[11, 85] -> 
             RGBColor[
              0.6841322018526023, 0.7531685427753458, 0.9691515623679012], 
             UndirectedEdge[202, 307] -> 
             RGBColor[
              0.497539556547684, 0.598832006171564, 0.9549347864133242], 
             UndirectedEdge[20, 265] -> 
             RGBColor[
              0.43881462521559816`, 0.5350071809052231, 0.952046876052566], 
             UndirectedEdge[195, 247] -> 
             RGBColor[
              0.6271072852576883, 0.7078619634982718, 0.9639862924898608], 
             UndirectedEdge[281, 355] -> 
             RGBColor[
              0.4414103371814343, 0.5567491809630937, 0.9493472542547339], 
             UndirectedEdge[298, 313] -> 
             RGBColor[
              0.8043523183744659, 0.8476931875684339, 0.980972694983152], 
             UndirectedEdge[67, 210] -> 
             RGBColor[
              0.9086870172801733, 0.6670963762374249, 0.24494153595236634`], 
             UndirectedEdge[11, 263] -> 
             RGBColor[
              0.7077639747249695, 0.7716298633513651, 0.9715069566363455], 
             UndirectedEdge[88, 181] -> 
             RGBColor[
              0.690620331790311, 0.7567143586878917, 0.9709703713012292], 
             UndirectedEdge[212, 390] -> 
             RGBColor[
              0.9092624186926106, 0.929449888620494, 0.9553129874061556], 
             UndirectedEdge[13, 203] -> 
             RGBColor[
              0.6116967176983561, 0.6947422542832276, 0.9631892987732948], 
             UndirectedEdge[75, 105] -> 
             RGBColor[
              0.5821974532136336, 0.6688019750660033, 0.9617497198255445], 
             UndirectedEdge[12, 270] -> 
             RGBColor[
              0.6207280000579868, 0.6849595303572051, 0.852509553032991], 
             UndirectedEdge[127, 393] -> 
             RGBColor[
              0.5424875344684206, 0.6272639187568639, 0.9605942217080816], 
             UndirectedEdge[185, 208] -> 
             RGBColor[
              0.8404038708761977, 0.7527891229713028, 0.6125382993314156], 
             UndirectedEdge[246, 355] -> 
             RGBColor[
              0.35778423076544763`, 0.48048448910362773`, 0.9441589795889869],
              UndirectedEdge[62, 336] -> 
             RGBColor[
              0.46692937863446604`, 0.567622171076837, 0.9531627982373475], 
             UndirectedEdge[118, 209] -> 
             RGBColor[
              0.7418626773507158, 0.797990461793729, 0.9753781279167555], 
             UndirectedEdge[178, 352] -> 
             RGBColor[
              0.8806564457047856, 0.9055057397742701, 0.8876361471478678], 
             UndirectedEdge[17, 22] -> 
             RGBColor[
              0.5103522422891851, 0.6133659672536953, 0.9545959444763181], 
             UndirectedEdge[12, 158] -> 
             RGBColor[
              0.6472074263586458, 0.7127910862917934, 0.8540175171880128], 
             UndirectedEdge[200, 333] -> 
             RGBColor[
              0.5782347166751262, 0.5406494895642688, 0.594977559213699], 
             UndirectedEdge[69, 295] -> 
             RGBColor[
              0.5137427283706026, 0.6155006793097548, 0.9550335662429597], 
             UndirectedEdge[181, 340] -> 
             RGBColor[
              0.6516597286744096, 0.7259648628463908, 0.9671702499240948], 
             UndirectedEdge[205, 284] -> 
             RGBColor[
              0.6592156281521288, 0.7314902600140614, 0.968185408638238], 
             UndirectedEdge[283, 373] -> 
             RGBColor[
              0.4167590977724317, 0.526235485435506, 0.948969948629787], 
             UndirectedEdge[302, 379] -> 
             RGBColor[
              0.6970596897062828, 0.7575100217325148, 0.8892233820590656], 
             UndirectedEdge[254, 303] -> 
             RGBColor[
              0.5873451177672102, 0.656853198792293, 0.9470299206323158], 
             UndirectedEdge[38, 254] -> 
             RGBColor[
              0.32277223391105286`, 0.44560799042709176`, 0.9420946756342046],
              UndirectedEdge[158, 209] -> 
             RGBColor[
              0.602568590937233, 0.6801164776429405, 0.9655755889149172], 
             UndirectedEdge[365, 370] -> 
             RGBColor[
              0.5220669796569907, 0.6053414648512048, 0.9595008603043212], 
             UndirectedEdge[61, 164] -> 
             RGBColor[
              0.4568668227966557, 0.5544994372824907, 0.9529928750791542], 
             UndirectedEdge[163, 167] -> 
             RGBColor[
              0.5829445282151479, 0.6695797530385048, 0.9617420047070453], 
             UndirectedEdge[62, 119] -> 
             RGBColor[
              0.49675818301514135`, 0.5981384309717808, 0.9548921037642976], 
             UndirectedEdge[137, 197] -> 
             RGBColor[
              0.35526848580695886`, 0.4806893809541489, 0.9439113921529393], 
             UndirectedEdge[265, 383] -> 
             RGBColor[
              0.8445911416031288, 0.8773936131697899, 0.8868693008964085], 
             UndirectedEdge[19, 338] -> 
             RGBColor[
              0.4696552598499638, 0.5724671254470903, 0.9530045890205902], 
             UndirectedEdge[69, 212] -> 
             RGBColor[
              0.6366208243691108, 0.7123734479169861, 0.9667563453426058], 
             UndirectedEdge[45, 275] -> 
             RGBColor[
              0.6281713000301363, 0.6909131911484478, 0.7224003585184322], 
             UndirectedEdge[248, 360] -> 
             RGBColor[
              0.5479210441964377, 0.6380322096890374, 0.9600232989601212], 
             UndirectedEdge[188, 322] -> 
             RGBColor[
              0.6640371860173253, 0.731246851248264, 0.9455385912054843], 
             UndirectedEdge[167, 183] -> 
             RGBColor[
              0.5765059457655345, 0.664002976533213, 0.9613317439267708], 
             UndirectedEdge[141, 240] -> 
             RGBColor[
              0.8345209379268815, 0.8715695654434361, 0.9838977750597764], 
             UndirectedEdge[23, 220] -> 
             RGBColor[
              0.9676582008208658, 0.973850087256563, 0.8702167921019661], 
             UndirectedEdge[123, 322] -> 
             RGBColor[
              0.9629993043636109, 0.9286976479100049, 0.627673116589561], 
             UndirectedEdge[177, 398] -> 
             RGBColor[
              0.9891135291647636, 0.9897661787871601, 0.8300805252306674], 
             UndirectedEdge[272, 395] -> 
             RGBColor[
              0.25615046843010925`, 0.38656076157073727`, 0.937898762285211], 
             UndirectedEdge[85, 312] -> 
             RGBColor[
              0.4604261015099508, 0.56380447817054, 0.9523147057802824], 
             UndirectedEdge[25, 328] -> 
             RGBColor[
              0.5404372672388515, 0.6329239950171522, 0.9589649580055785], 
             UndirectedEdge[8, 121] -> 
             RGBColor[
              0.4280046088240802, 0.5392029121436254, 0.9495058947316012], 
             UndirectedEdge[169, 319] -> 
             RGBColor[
              0.6690291672261044, 0.7279932036268392, 0.6811749147742727], 
             UndirectedEdge[84, 167] -> 
             RGBColor[
              0.48880202625418007`, 0.580417052895081, 0.9560223770730147], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.9143643030921367, 0.9295791498270195, 0.7266017631353201], 
             UndirectedEdge[43, 213] -> 
             RGBColor[
              0.9294648496663026, 0.9108280601078089, 0.6613455224617916], 
             UndirectedEdge[170, 187] -> 
             RGBColor[
              0.6450573484800497, 0.7211046924151348, 0.9663086751780895], 
             UndirectedEdge[89, 199] -> 
             RGBColor[
              0.643761419714683, 0.7143758104256266, 0.9543285904806736], 
             UndirectedEdge[16, 373] -> 
             RGBColor[
              0.3820390957666856, 0.48974256195219434`, 0.9469926958791999], 
             UndirectedEdge[22, 158] -> 
             RGBColor[
              0.3989714402450145, 0.518153244833045, 0.9469908414697619], 
             UndirectedEdge[233, 264] -> 
             RGBColor[
              0.883088052736327, 0.909614458738067, 0.9887109208836438], 
             UndirectedEdge[274, 296] -> 
             RGBColor[
              0.43664541060214945`, 0.5512179574994612, 0.9494315898156772], 
             UndirectedEdge[97, 211] -> 
             RGBColor[
              0.5867899642073882, 0.6748764582378048, 0.9609860864768784], 
             UndirectedEdge[1, 129] -> 
             RGBColor[
              0.9947304233306834, 0.9916787864455634, 0.7071824818892918], 
             UndirectedEdge[24, 141] -> 
             RGBColor[
              0.6951147271431594, 0.7598232461531593, 0.9719455614557337], 
             UndirectedEdge[347, 384] -> 
             RGBColor[
              0.9466638362259909, 0.9581432667604541, 0.9117173345665679], 
             UndirectedEdge[36, 378] -> 
             RGBColor[
              0.39529061824966055`, 0.5127623231903929, 0.9469197791484025], 
             UndirectedEdge[174, 395] -> 
             RGBColor[
              0.2825095218781172, 0.4142657980051097, 0.9393998713843499], 
             UndirectedEdge[104, 357] -> 
             RGBColor[
              0.7028430359458837, 0.7623807383073214, 0.8845002885765954], 
             UndirectedEdge[47, 173] -> 
             RGBColor[
              0.772078218823986, 0.7466396302669802, 0.6167332997753541], 
             UndirectedEdge[127, 231] -> 
             RGBColor[
              0.5330902495045045, 0.6173867764375084, 0.9600590602314238], 
             UndirectedEdge[252, 367] -> 
             RGBColor[
              0.40179007225904734`, 0.518890395772746, 0.9473539290546775], 
             UndirectedEdge[158, 310] -> 
             RGBColor[
              0.5448251179865897, 0.6343309290700294, 0.9599996245446637], 
             UndirectedEdge[149, 397] -> 
             RGBColor[
              0.4256280549242598, 0.5364921769596878, 0.9493899262811915], 
             UndirectedEdge[204, 345] -> 
             RGBColor[
              0.31349295165383084`, 0.4412969260728762, 0.9413669741413154], 
             UndirectedEdge[231, 396] -> 
             RGBColor[
              0.4275623498746899, 0.5344532022402623, 0.949870744048396], 
             UndirectedEdge[162, 263] -> 
             RGBColor[
              0.5277675550188208, 0.6239397229332027, 0.9573155638889541], 
             UndirectedEdge[14, 196] -> 
             RGBColor[
              0.5784285469957642, 0.6576506931976538, 0.9637604688862567], 
             UndirectedEdge[43, 175] -> 
             RGBColor[
              0.9255123210424608, 0.9427925883313044, 0.97022735832868], 
             UndirectedEdge[113, 397] -> 
             RGBColor[
              0.5761223439232968, 0.6555270791669277, 0.9635836328296105], 
             UndirectedEdge[126, 336] -> 
             RGBColor[
              0.2906767121417326, 0.4215112422662799, 0.9399140004673256], 
             UndirectedEdge[48, 173] -> 
             RGBColor[
              0.48775549193554224`, 0.5928292683516121, 0.9534226018976119], 
             UndirectedEdge[28, 168] -> 
             RGBColor[
              0.9408949586112356, 0.84551594210755, 0.6018223006838481], 
             UndirectedEdge[253, 359] -> 
             RGBColor[
              0.2703850613045633, 0.4015222212071041, 0.938709401291218], 
             UndirectedEdge[41, 187] -> 
             RGBColor[
              0.6100969199101468, 0.6927222415527285, 0.9635564621767971], 
             UndirectedEdge[198, 398] -> 
             RGBColor[
              0.8372532611706179, 0.8718938454409972, 0.8966868255872744], 
             UndirectedEdge[260, 329] -> 
             RGBColor[
              0.7861928970007448, 0.8330506696734746, 0.9792838056117195], 
             UndirectedEdge[60, 82] -> 
             RGBColor[
              0.5731088801015435, 0.6626430566490178, 0.9604455190601063], 
             UndirectedEdge[12, 17] -> 
             RGBColor[
              0.7585882284028163, 0.8080038087124436, 0.861622620194569], 
             UndirectedEdge[268, 351] -> 
             RGBColor[
              0.3734723035753579, 0.4979046709183651, 0.9450183028285988], 
             UndirectedEdge[122, 274] -> 
             RGBColor[
              0.5424386912947289, 0.6394151920344509, 0.95712190727857], 
             UndirectedEdge[150, 384] -> 
             RGBColor[
              0.984429633335967, 0.98711677805032, 0.8757980677784194], 
             UndirectedEdge[179, 232] -> 
             RGBColor[
              0.3466781149751769, 0.4706236726689076, 0.943460141317555], 
             UndirectedEdge[4, 131] -> 
             RGBColor[
              0.5434279344345461, 0.6313919573934674, 0.9601528497421128], 
             UndirectedEdge[128, 155] -> 
             RGBColor[
              0.641629867316192, 0.7059102353680763, 0.8082930793625521], 
             UndirectedEdge[316, 362] -> 
             RGBColor[
              0.6648387762131419, 0.7347952384059881, 0.9694839082635097], 
             UndirectedEdge[283, 320] -> 
             RGBColor[
              0.2417536846399958, 0.3714288289985145, 0.937078886746497], 
             UndirectedEdge[49, 396] -> 
             RGBColor[
              0.773545288080596, 0.8234792373040893, 0.9781291634407185], 
             UndirectedEdge[371, 389] -> 
             RGBColor[
              0.5130363626416741, 0.5937933151072401, 0.9592981102735003], 
             UndirectedEdge[53, 58] -> 
             RGBColor[
              0.5759264206206218, 0.666602039306225, 0.9597581840006988], 
             UndirectedEdge[18, 399] -> 
             RGBColor[
              0.6918506807496205, 0.7566566652043121, 0.9665632551714396], 
             UndirectedEdge[241, 270] -> 
             RGBColor[
              0.4173921349944195, 0.5267736298943013, 0.949017579318364], 
             UndirectedEdge[137, 169] -> 
             RGBColor[
              0.6419736310414015, 0.7031110000707241, 0.6795039804283936], 
             UndirectedEdge[156, 386] -> 
             RGBColor[
              0.9480885622599109, 0.9578909258049614, 0.8450066147042445], 
             UndirectedEdge[19, 262] -> 
             RGBColor[
              0.6231589450508408, 0.7046610873777294, 0.9636723440281303], 
             UndirectedEdge[85, 181] -> 
             RGBColor[
              0.5879381402335868, 0.6761850736544108, 0.9608190775004138], 
             UndirectedEdge[74, 240] -> 
             RGBColor[
              0.7141996061173255, 0.7766574275076837, 0.9721484002291407], 
             UndirectedEdge[72, 88] -> 
             RGBColor[
              0.6290991430668942, 0.7053065164093812, 0.9665311998307169], 
             UndirectedEdge[63, 98] -> 
             RGBColor[
              0.34451438418180375`, 0.4728227766070169, 0.9431731298113243], 
             UndirectedEdge[43, 56] -> 
             RGBColor[
              0.7122656419512915, 0.7740598187085599, 0.9729358469775792], 
             UndirectedEdge[174, 272] -> 
             RGBColor[
              0.2802796012849612, 0.41192201007657114`, 0.9392728807054416], 
             UndirectedEdge[180, 198] -> 
             RGBColor[
              0.5254438187221636, 0.6225893969212104, 0.9568871478843881], 
             UndirectedEdge[126, 289] -> 
             RGBColor[
              0.36698550290677007`, 0.4922861302153159, 0.944604969626049], 
             UndirectedEdge[233, 244] -> 
             RGBColor[
              0.9288859533252503, 0.9445633445949527, 0.9358881070107206], 
             UndirectedEdge[51, 189] -> 
             RGBColor[
              0.5138900271038344, 0.6121761427467765, 0.9563227637942052], 
             UndirectedEdge[199, 306] -> 
             RGBColor[
              0.6003071288435309, 0.6711741560304052, 0.9517634369643231], 
             UndirectedEdge[86, 214] -> 
             RGBColor[
              0.6232271908155047, 0.6979399357132408, 0.9672069254353391], 
             UndirectedEdge[104, 172] -> 
             RGBColor[
              0.9821620680691225, 0.9853111102301761, 0.8745079639553344], 
             UndirectedEdge[67, 293] -> 
             RGBColor[
              0.6682823978334244, 0.6634389106545715, 0.6096285713123275], 
             UndirectedEdge[296, 380] -> 
             RGBColor[
              0.3205617007291119, 0.4487584358146051, 0.9417683643601933], 
             UndirectedEdge[290, 297] -> 
             RGBColor[
              0.6223732417457433, 0.49789174966533506`, 0.5785593502682914], 
             UndirectedEdge[206, 328] -> 
             RGBColor[
              0.5336094285374492, 0.6270100643111489, 0.9585298941611458], 
             UndirectedEdge[5, 319] -> 
             RGBColor[
              0.49457021221058195`, 0.5976719182487668, 0.954149688428322], 
             UndirectedEdge[235, 393] -> 
             RGBColor[
              0.26600478368070535`, 0.3969182716987874, 0.9384599509605794], 
             UndirectedEdge[40, 189] -> 
             RGBColor[
              0.2703501348048784, 0.3992256871619425, 0.9387901555083035], 
             UndirectedEdge[15, 256] -> 
             RGBColor[
              0.5929801066345373, 0.6802921238370876, 0.9612065953873781], 
             UndirectedEdge[71, 365] -> 
             RGBColor[
              0.55299600548287, 0.6300034304987202, 0.9624508983982609], 
             UndirectedEdge[53, 64] -> 
             RGBColor[
              0.5102468141629428, 0.6130606686468041, 0.9546483505708829], 
             UndirectedEdge[231, 298] -> 
             RGBColor[
              0.47863507475491274`, 0.5748261644244659, 0.9546367357822616], 
             UndirectedEdge[81, 382] -> 
             RGBColor[
              0.5319511596256772, 0.6298044906899359, 0.9566335829268546], 
             UndirectedEdge[9, 294] -> 
             RGBColor[
              0.4937653865301225, 0.5841229514728068, 0.9565442319704156], 
             UndirectedEdge[175, 213] -> 
             RGBColor[
              0.9648512092904231, 0.9383943523569509, 0.6421906778939221], 
             UndirectedEdge[174, 189] -> 
             RGBColor[
              0.31991329588179845`, 0.4513197119396991, 0.9416127042095079], 
             UndirectedEdge[14, 127] -> 
             RGBColor[
              0.851563671763016, 0.8844777730564746, 0.9857040972842623], 
             UndirectedEdge[86, 95] -> 
             RGBColor[0.5800948843722843, 0.65377555591891, 0.96470774998418],
              UndirectedEdge[103, 200] -> 
             RGBColor[
              0.30744645087380823`, 0.4341960708481146, 0.9410499349182633], 
             UndirectedEdge[24, 112] -> 
             RGBColor[
              0.5034610998204031, 0.6077714273551076, 0.9540534484980889], 
             UndirectedEdge[109, 360] -> 
             RGBColor[
              0.755559377783978, 0.8089679954795798, 0.9762707557398314], 
             UndirectedEdge[90, 121] -> 
             RGBColor[
              0.4077482911422045, 0.5179122379352539, 0.9483523274061549], 
             UndirectedEdge[75, 202] -> 
             RGBColor[
              0.7148507044853929, 0.7771660705013488, 0.9722132956296095], 
             UndirectedEdge[27, 32] -> 
             RGBColor[
              0.3541126382066727, 0.48103256322782517`, 0.9437885204484614], 
             UndirectedEdge[131, 273] -> 
             RGBColor[
              0.6410261771785397, 0.7049509998851411, 0.7757858182572592], 
             UndirectedEdge[160, 220] -> 
             RGBColor[
              0.641672441590583, 0.7131832597407461, 0.9631975702020372], 
             UndirectedEdge[50, 147] -> 
             RGBColor[
              0.869004701394731, 0.894022680265623, 0.722661876446183], 
             UndirectedEdge[13, 339] -> 
             RGBColor[
              0.8435280413143649, 0.8774408415225705, 0.9265633631443599], 
             UndirectedEdge[17, 209] -> 
             RGBColor[
              0.7139493929814036, 0.7753292000635907, 0.9731806919214735], 
             UndirectedEdge[174, 325] -> 
             RGBColor[
              0.28566464868552677`, 0.41758203632629093`, 0.9395795511884402],
              UndirectedEdge[21, 78] -> 
             RGBColor[
              0.49062084651978, 0.5845515342384443, 0.9557740565650059], 
             UndirectedEdge[274, 373] -> 
             RGBColor[
              0.545090255330188, 0.6415678511700351, 0.9573306481124404], 
             UndirectedEdge[97, 305] -> 
             RGBColor[
              0.753252826511744, 0.8072354415028984, 0.9760224591874309], 
             UndirectedEdge[11, 162] -> 
             RGBColor[
              0.5349014908952932, 0.6295128078598237, 0.9580266079466997], 
             UndirectedEdge[103, 207] -> 
             RGBColor[
              0.38514166787024073`, 0.5080120877512895, 0.9457618644026551], 
             UndirectedEdge[210, 249] -> 
             RGBColor[
              0.6149711762733812, 0.5025099236687047, 0.5804009923181987], 
             UndirectedEdge[52, 299] -> 
             RGBColor[
              0.4554142478457647, 0.5576237414494066, 0.952173823213027], 
             UndirectedEdge[43, 373] -> 
             RGBColor[
              0.7376385764758557, 0.7946587099932756, 0.9749332973274745], 
             UndirectedEdge[1, 336] -> 
             RGBColor[
              0.6264669270697121, 0.6899693273089372, 0.807059913609528], 
             UndirectedEdge[30, 345] -> 
             RGBColor[
              0.3771360423831996, 0.49526539681334436`, 0.9457416551228024], 
             UndirectedEdge[247, 363] -> 
             RGBColor[
              0.6639510734500755, 0.7366446108573261, 0.9676585369721016], 
             UndirectedEdge[14, 119] -> 
             RGBColor[
              0.5992382882152666, 0.6786873458685725, 0.9649761521086861], 
             UndirectedEdge[74, 104] -> 
             RGBColor[
              0.841170307450224, 0.8749221194116908, 0.8956374536228628], 
             UndirectedEdge[258, 277] -> 
             RGBColor[
              0.6801671262055473, 0.7489898433701585, 0.9694955503292297], 
             UndirectedEdge[152, 236] -> 
             RGBColor[
              0.7678352610989689, 0.8189944121693, 0.9773784930347251], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.772179832910779, 0.7863655403822467, 0.6465189297420899], 
             UndirectedEdge[120, 132] -> 
             RGBColor[
              0.3821574200641262, 0.5001184572566213, 0.9460662763439505], 
             UndirectedEdge[212, 270] -> 
             RGBColor[
              0.5456237938110461, 0.6279926619725374, 0.9611618104937991], 
             UndirectedEdge[69, 270] -> 
             RGBColor[
              0.3395664966596175, 0.4629734334045636, 0.9430615702664943], 
             UndirectedEdge[16, 270] -> 
             RGBColor[
              0.2137482330507764, 0.34199332373005753`, 0.9354840177088438], 
             UndirectedEdge[24, 73] -> 
             RGBColor[
              0.7082935314238175, 0.7697128577288088, 0.9517480631560228], 
             UndirectedEdge[56, 178] -> 
             RGBColor[
              0.7627412215624922, 0.8117357578297169, 0.8770141119602367], 
             UndirectedEdge[6, 319] -> 
             RGBColor[
              0.4479558668633019, 0.5598282927435179, 0.9504800364086108], 
             UndirectedEdge[231, 235] -> 
             RGBColor[
              0.2566074987167893, 0.3870411293794318, 0.9379247894839217], 
             UndirectedEdge[18, 86] -> 
             RGBColor[
              0.9333261027384739, 0.9495206733365407, 0.9882243175736111], 
             UndirectedEdge[30, 63] -> 
             RGBColor[
              0.4119301970637306, 0.530058989653502, 0.947788205312285], 
             UndirectedEdge[46, 358] -> 
             RGBColor[
              0.6675277616849988, 0.7378656556796849, 0.969268820282966], 
             UndirectedEdge[241, 389] -> 
             RGBColor[
              0.7142410571158523, 0.7760098595663903, 0.9726927626261184], 
             UndirectedEdge[286, 332] -> 
             RGBColor[
              0.9238745149927925, 0.9406045841475732, 0.9370265255596659], 
             UndirectedEdge[40, 174] -> 
             RGBColor[
              0.2570754936560491, 0.38753302173318693`, 0.937951441103376], 
             UndirectedEdge[157, 365] -> 
             RGBColor[
              0.5928133729456655, 0.6609314145509388, 0.9377735909645559], 
             UndirectedEdge[235, 336] -> 
             RGBColor[
              0.2637986926949792, 0.39459953019854194`, 0.9383343173425615], 
             UndirectedEdge[76, 222] -> 
             RGBColor[
              0.34282057116665837`, 0.462711870510451, 0.9434675545801519], 
             UndirectedEdge[115, 392] -> 
             RGBColor[
              0.5857333973110126, 0.6459228499880025, 0.6814409337686818], 
             UndirectedEdge[76, 77] -> 
             RGBColor[
              0.43185248857248193`, 0.548112434013099, 0.9488372135358969], 
             UndirectedEdge[160, 366] -> 
             RGBColor[
              0.36287789233861434`, 0.4887283243956895, 0.9443432363128637], 
             UndirectedEdge[3, 348] -> 
             RGBColor[
              0.42541321388021613`, 0.5252491018431718, 0.9505985543735882], 
             UndirectedEdge[299, 306] -> 
             RGBColor[
              0.45435112252106535`, 0.5565063293271089, 0.9521132797985383], 
             UndirectedEdge[56, 121] -> 
             RGBColor[
              0.5549806251957679, 0.6495972989829978, 0.9581092542578775], 
             UndirectedEdge[280, 322] -> 
             RGBColor[
              0.6289122614589764, 0.6994877631333156, 0.9433493665380972], 
             UndirectedEdge[81, 271] -> 
             RGBColor[
              0.7838491017020506, 0.7223600632366445, 0.6099467144788709], 
             UndirectedEdge[2, 191] -> 
             RGBColor[
              0.5589227649431827, 0.64745332326302, 0.9607700397433663], 
             UndirectedEdge[146, 377] -> 
             RGBColor[
              0.7662705965087646, 0.8123886315865758, 0.7295896822796293], 
             UndirectedEdge[10, 396] -> 
             RGBColor[
              0.46651133505832665`, 0.5741986543882364, 0.9521324907687243], 
             UndirectedEdge[382, 384] -> 
             RGBColor[
              0.7024983751615411, 0.7622382122156176, 0.8902122097266707], 
             UndirectedEdge[147, 391] -> 
             RGBColor[
              0.7078425915059376, 0.7639283979552948, 0.7091277636535251], 
             UndirectedEdge[133, 216] -> 
             RGBColor[
              0.5760641631729646, 0.6667015243241678, 0.9597774649286432], 
             UndirectedEdge[86, 264] -> 
             RGBColor[
              0.9096528606397531, 0.9307965154777578, 0.9912446959761565], 
             UndirectedEdge[6, 56] -> 
             RGBColor[
              0.5415609867947164, 0.6387026319812037, 0.9570528111651915], 
             UndirectedEdge[43, 308] -> 
             RGBColor[
              0.7693798704087593, 0.8203316007194451, 0.9774978071329561], 
             UndirectedEdge[201, 364] -> 
             RGBColor[
              0.7195486676478225, 0.7808361550296814, 0.9726815446926786], 
             UndirectedEdge[109, 365] -> 
             RGBColor[
              0.4746866306409085, 0.5682785028780101, 0.9547914524320856], 
             UndirectedEdge[229, 349] -> 
             RGBColor[
              0.4304254713195139, 0.5367776132113216, 0.950096139456492], 
             UndirectedEdge[216, 231] -> 
             RGBColor[
              0.4434547281437874, 0.5473430102713175, 0.9511302876110956], 
             UndirectedEdge[114, 353] -> 
             RGBColor[
              0.6982591946605772, 0.7642046569260578, 0.9705596089867465], 
             UndirectedEdge[70, 236] -> 
             RGBColor[
              0.9202593333980197, 0.9384584751976303, 0.9646809369292728], 
             UndirectedEdge[64, 94] -> 
             RGBColor[
              0.45064593487755755`, 0.5646739898539144, 0.9499563510283229], 
             UndirectedEdge[240, 285] -> 
             RGBColor[
              0.780962587162965, 0.8288635903469916, 0.9787893317518098], 
             UndirectedEdge[56, 90] -> 
             RGBColor[
              0.3871729884306793, 0.5012082802872135, 0.9467325642068865], 
             UndirectedEdge[90, 295] -> 
             RGBColor[
              0.41843129195031953`, 0.5265851792549836, 0.9491933323628912], 
             UndirectedEdge[165, 281] -> 
             RGBColor[
              0.4390503051880949, 0.5547050398691201, 0.9491968751030126], 
             UndirectedEdge[54, 345] -> 
             RGBColor[
              0.6166818491289274, 0.68488386150214, 0.9326283322093757], 
             UndirectedEdge[101, 136] -> 
             RGBColor[
              0.553036719353394, 0.642685752061144, 0.9602550496795408], 
             UndirectedEdge[6, 314] -> 
             RGBColor[
              0.6998506766966917, 0.7642640205702042, 0.9716325029653378], 
             UndirectedEdge[125, 276] -> 
             RGBColor[
              0.6584891763623976, 0.7278703118275143, 0.9660385691394611], 
             UndirectedEdge[244, 341] -> 
             RGBColor[
              0.7748788895816285, 0.8226302731574582, 0.9214711989676991], 
             UndirectedEdge[46, 153] -> 
             RGBColor[
              0.8995528510596643, 0.9227430419960516, 0.9902813480460226], 
             UndirectedEdge[14, 336] -> 
             RGBColor[
              0.5694094838345913, 0.6481710859736287, 0.9632468465817361], 
             UndirectedEdge[109, 370] -> 
             RGBColor[
              0.7786750945214341, 0.8270752422986762, 0.9785616918324144], 
             UndirectedEdge[51, 234] -> 
             RGBColor[
              0.496856341733948, 0.5965324835045205, 0.9552699773818962], 
             UndirectedEdge[144, 228] -> 
             RGBColor[
              0.7027471690132583, 0.7677106966002407, 0.971006928327717], 
             UndirectedEdge[320, 347] -> 
             RGBColor[
              0.569756094047497, 0.6455316851529118, 0.9637216269334548], 
             UndirectedEdge[31, 106] -> 
             RGBColor[
              0.7429796449338367, 0.7932769776083808, 0.7111174484012938], 
             UndirectedEdge[77, 103] -> 
             RGBColor[
              0.3869319320938022, 0.5095627246404422, 0.945875938455912], 
             UndirectedEdge[266, 316] -> 
             RGBColor[
              0.9150931005004037, 0.9351344150712635, 0.9917635909106248], 
             UndirectedEdge[109, 334] -> 
             RGBColor[
              0.8108117681269231, 0.8527001535049267, 0.9816269164496532], 
             UndirectedEdge[45, 179] -> 
             RGBColor[
              0.6289695136415687, 0.6917521642637293, 0.722445815602752], 
             UndirectedEdge[181, 191] -> 
             RGBColor[
              0.6524386347029596, 0.7265733501557992, 0.96724788399773], 
             UndirectedEdge[125, 148] -> 
             RGBColor[
              0.5917622961930373, 0.6640650432005035, 0.9620068395136707], 
             UndirectedEdge[18, 112] -> 
             RGBColor[
              0.7458168273403769, 0.8007734482677761, 0.970727496602247], 
             UndirectedEdge[221, 239] -> 
             RGBColor[
              0.6100296960495644, 0.5501711544451446, 0.5909801691379657], 
             UndirectedEdge[57, 76] -> 
             RGBColor[
              0.46717735135834115`, 0.5783146457893649, 0.9511970589074055], 
             UndirectedEdge[222, 333] -> 
             RGBColor[
              0.5686882804892965, 0.5306155798539486, 0.5944339037956028], 
             UndirectedEdge[125, 214] -> 
             RGBColor[
              0.6305923514715626, 0.7037074842422609, 0.9642610081256108], 
             UndirectedEdge[220, 244] -> 
             RGBColor[
              0.9638233192675514, 0.9722642651823068, 0.9337707037957129], 
             UndirectedEdge[143, 379] -> 
             RGBColor[
              0.38413163818626317`, 0.507137250804596, 0.9456975062043262], 
             UndirectedEdge[31, 241] -> 
             RGBColor[
              0.5396351468338635, 0.6371391483428817, 0.956901201988889], 
             UndirectedEdge[81, 374] -> 
             RGBColor[
              0.5056979662031231, 0.6070652940711879, 0.954960752656757], 
             UndirectedEdge[168, 304] -> 
             RGBColor[
              0.7307734473826851, 0.7878885187730547, 0.9515182997988336], 
             UndirectedEdge[156, 328] -> 
             RGBColor[
              0.8243154192068267, 0.8633368116939626, 0.9829496134961768], 
             UndirectedEdge[46, 363] -> 
             RGBColor[
              0.803873944911009, 0.8471378224668478, 0.980973221134784], 
             UndirectedEdge[51, 269] -> 
             RGBColor[
              0.6814357146745429, 0.7510620264977842, 0.9688828017260976], 
             UndirectedEdge[13, 325] -> 
             RGBColor[
              0.48289161416780824`, 0.5809775748401673, 0.9546135637490325], 
             UndirectedEdge[164, 374] -> 
             RGBColor[
              0.5290689716354525, 0.6253229011411436, 0.9572901560637883], 
             UndirectedEdge[49, 199] -> 
             RGBColor[
              0.9438777677976055, 0.957664711631951, 0.9798844794829306], 
             UndirectedEdge[49, 313] -> 
             RGBColor[
              0.9154450494233491, 0.9354147467433476, 0.9917866602634706], 
             UndirectedEdge[176, 388] -> 
             RGBColor[
              0.8513338336734253, 0.8844866157202116, 0.9856311952160306], 
             UndirectedEdge[45, 232] -> 
             RGBColor[
              0.7109569859786612, 0.7668388107909986, 0.7275208443480075], 
             UndirectedEdge[176, 250] -> 
             RGBColor[
              0.888046090121622, 0.8922547428978748, 0.6783234416987336], 
             UndirectedEdge[346, 390] -> 
             RGBColor[
              0.877774244598484, 0.9046676595634743, 0.9522232166734869], 
             UndirectedEdge[331, 335] -> 
             RGBColor[
              0.5984105269214988, 0.6833418037731172, 0.9625632399379056], 
             UndirectedEdge[135, 355] -> 
             RGBColor[
              0.39010154096444216`, 0.5123080805350164, 0.9460779031303741], 
             UndirectedEdge[326, 327] -> 
             RGBColor[
              0.3374032119648188, 0.4643486068726972, 0.9428047694634627], 
             UndirectedEdge[80, 304] -> 
             RGBColor[
              0.43184135879408403`, 0.5472045173911052, 0.949084700848233], 
             UndirectedEdge[65, 173] -> 
             RGBColor[
              0.5453715738542954, 0.6417962382211606, 0.9573527945371618], 
             UndirectedEdge[203, 257] -> 
             RGBColor[
              0.5327976885747383, 0.6315881917041395, 0.9563629322282958], 
             UndirectedEdge[275, 325] -> 
             RGBColor[
              0.263892429026652, 0.3946980530263568, 0.9383396554879797], 
             UndirectedEdge[240, 337] -> 
             RGBColor[
              0.5406527222930976, 0.6336105884010134, 0.9587670726293303], 
             UndirectedEdge[77, 254] -> 
             RGBColor[
              0.30763628338150273`, 0.432497990833389, 0.9411302262506571], 
             UndirectedEdge[32, 364] -> 
             RGBColor[
              0.47743152811334877`, 0.5825050189792875, 0.9531522515472479], 
             UndirectedEdge[38, 53] -> 
             RGBColor[
              0.5013666158476078, 0.6053690871978057, 0.9540825121866808], 
             UndirectedEdge[28, 291] -> 
             RGBColor[
              0.7671118963359099, 0.7088563359523754, 0.6085714708051255], 
             UndirectedEdge[174, 269] -> 
             RGBColor[
              0.48745898345250693`, 0.5902055956907069, 0.9541727421414004], 
             UndirectedEdge[216, 361] -> 
             RGBColor[
              0.48145374891965753`, 0.5862656509958837, 0.9533315034393814], 
             UndirectedEdge[356, 363] -> 
             RGBColor[
              0.6132857611834508, 0.6955122279129733, 0.9636699779973189], 
             UndirectedEdge[151, 383] -> 
             RGBColor[
              0.7931679599943827, 0.8365051143265324, 0.882233669628472], 
             UndirectedEdge[61, 130] -> 
             RGBColor[
              0.4833030820500808, 0.5751516439342783, 0.9556277943406469], 
             UndirectedEdge[331, 338] -> 
             RGBColor[
              0.36694572688436894`, 0.4893693426358141, 0.9447230756622755], 
             UndirectedEdge[239, 246] -> 
             RGBColor[
              0.5849965629146073, 0.5246567510732407, 0.5895253869179542], 
             UndirectedEdge[190, 212] -> 
             RGBColor[
              0.6100606314382541, 0.68936834375439, 0.965063953335308], 
             UndirectedEdge[111, 286] -> 
             RGBColor[
              0.5901740730021212, 0.6714760323544926, 0.9641041204024439], 
             UndirectedEdge[228, 273] -> 
             RGBColor[
              0.8240697592775779, 0.8598033796865123, 0.7890045180870567], 
             UndirectedEdge[199, 299] -> 
             RGBColor[
              0.8060887852630434, 0.849087837897399, 0.9664096813451737], 
             UndirectedEdge[50, 391] -> 
             RGBColor[
              0.5839334295996297, 0.6706992831646474, 0.9616937053360011], 
             UndirectedEdge[358, 362] -> 
             RGBColor[
              0.44531681402753676`, 0.5598875063218318, 0.949663939933419], 
             UndirectedEdge[42, 98] -> 
             RGBColor[
              0.44330991795961866`, 0.556432969039484, 0.9500102713623328], 
             UndirectedEdge[39, 251] -> 
             RGBColor[
              0.7642679138320378, 0.3337124488641496, 0.43166648942331165`], 
             UndirectedEdge[148, 179] -> 
             RGBColor[
              0.25421775511798717`, 0.3845293573385954, 0.9377886971212788], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.828007846093828, 0.8458809691661993, 0.673111245701651], 
             UndirectedEdge[77, 333] -> 
             RGBColor[
              0.6577201978951202, 0.6160161433565965, 0.5998035627513478], 
             UndirectedEdge[173, 354] -> 
             RGBColor[
              0.6814586643991087, 0.7504756369048848, 0.9692982647202546], 
             UndirectedEdge[160, 217] -> 
             RGBColor[
              0.5653657489728702, 0.6527445290989151, 0.9613030616302891], 
             UndirectedEdge[59, 90] -> 
             RGBColor[
              0.2752216556643451, 0.40644337359938887`, 0.9389907849913837], 
             UndirectedEdge[237, 380] -> 
             RGBColor[
              0.2779215119607074, 0.40944350868528184`, 0.9391385910069059], 
             UndirectedEdge[285, 399] -> 
             RGBColor[
              0.6341599826479585, 0.7108079113080286, 0.966339018252683], 
             UndirectedEdge[51, 392] -> 
             RGBColor[
              0.4367595585885205, 0.5333669540625491, 0.9518475544869875], 
             UndirectedEdge[264, 307] -> 
             RGBColor[
              0.6069996134765335, 0.6849433500663928, 0.965685436651301], 
             UndirectedEdge[78, 208] -> 
             RGBColor[
              0.5080191618424055, 0.5981432304005733, 0.9575081580398646], 
             UndirectedEdge[28, 383] -> 
             RGBColor[
              0.9552873412798946, 0.8551622461019582, 0.5287587670067748], 
             UndirectedEdge[255, 268] -> 
             RGBColor[
              0.5185162941593235, 0.6184814647028727, 0.9556565423361925], 
             UndirectedEdge[46, 247] -> 
             RGBColor[
              0.7327815999055486, 0.790841661199039, 0.9744058414603731], 
             UndirectedEdge[272, 392] -> 
             RGBColor[
              0.21642377391847661`, 0.34480548682109935`, 0.9356363858031513],
              UndirectedEdge[316, 359] -> 
             RGBColor[
              0.5884152572647501, 0.6655212476572626, 0.9647270350396924], 
             UndirectedEdge[223, 242] -> 
             RGBColor[
              0.6971436931188326, 0.7552002638485569, 0.7544891743283839], 
             UndirectedEdge[158, 390] -> 
             RGBColor[
              0.6386875172837763, 0.7078814300426599, 0.9331261764850658], 
             UndirectedEdge[26, 128] -> 
             RGBColor[
              0.6339138743199317, 0.6978002375067947, 0.8078536649762038], 
             UndirectedEdge[136, 335] -> 
             RGBColor[
              0.7578824955363926, 0.8107828327241149, 0.9765023024066224], 
             UndirectedEdge[193, 248] -> 
             RGBColor[
              0.44443955863108336`, 0.556127066550921, 0.9504371181630288], 
             UndirectedEdge[281, 386] -> 
             RGBColor[
              0.7147872463077518, 0.7712852224193589, 0.8242446704812338], 
             UndirectedEdge[225, 337] -> 
             RGBColor[
              0.6089772610297353, 0.6874095152342017, 0.965464699185034], 
             UndirectedEdge[30, 297] -> 
             RGBColor[
              0.4361092385734059, 0.5510016601352208, 0.9493288724565947], 
             UndirectedEdge[32, 104] -> 
             RGBColor[
              0.6486345746345401, 0.7153243551226636, 0.8810499717345719], 
             UndirectedEdge[264, 366] -> 
             RGBColor[
              0.6392308694266593, 0.7128604439803645, 0.9677391837794624], 
             UndirectedEdge[2, 97] -> 
             RGBColor[
              0.5067103167558853, 0.6066645619097997, 0.955565990861126], 
             UndirectedEdge[258, 377] -> 
             RGBColor[
              0.7824957950385858, 0.8255609786899487, 0.7308669893427573], 
             UndirectedEdge[134, 135] -> 
             RGBColor[
              0.3493525104846342, 0.4770133184392301, 0.9434814109411536], 
             UndirectedEdge[185, 338] -> 
             RGBColor[
              0.5947248946817458, 0.5477124393881598, 0.5932813988154522], 
             UndirectedEdge[40, 84] -> 
             RGBColor[
              0.216914274575229, 0.34532103411088394`, 0.9356643190899228], 
             UndirectedEdge[217, 242] -> 
             RGBColor[
              0.8914707667691701, 0.9121480085039917, 0.7709290017703712], 
             UndirectedEdge[124, 266] -> 
             RGBColor[
              0.6235242525490562, 0.6980685602587108, 0.9672850902996872], 
             UndirectedEdge[219, 293] -> 
             RGBColor[
              0.5054472787945686, 0.6077627803809249, 0.9546577271131548], 
             UndirectedEdge[37, 170] -> 
             RGBColor[
              0.7469951810143456, 0.7433051670667256, 0.6186794141484759], 
             UndirectedEdge[205, 293] -> 
             RGBColor[
              0.6074014096928364, 0.6878040267231132, 0.9645543228899927], 
             UndirectedEdge[122, 268] -> 
             RGBColor[
              0.4887318890076351, 0.5943011428285707, 0.9533118048587806], 
             UndirectedEdge[246, 392] -> 
             RGBColor[
              0.2231135228760468, 0.35183683713008757`, 0.9360173571096883], 
             UndirectedEdge[282, 398] -> 
             RGBColor[
              0.7705040401563941, 0.8183575484111945, 0.8909851252628751], 
             UndirectedEdge[34, 248] -> 
             RGBColor[
              0.5773253841595998, 0.6611538339681816, 0.9629140495498922], 
             UndirectedEdge[263, 264] -> 
             RGBColor[
              0.797443178325967, 0.8422882542864225, 0.9802860362771861], 
             UndirectedEdge[100, 377] -> 
             RGBColor[
              0.7029706865890015, 0.7598968976251583, 0.7249109716506204], 
             UndirectedEdge[107, 241] -> 
             RGBColor[
              0.7110198049921634, 0.7734413205615205, 0.9723855167229153], 
             UndirectedEdge[11, 95] -> 
             RGBColor[
              0.47501913793497064`, 0.5708403796541958, 0.9544601343429553], 
             UndirectedEdge[7, 96] -> 
             RGBColor[
              0.9401646404953503, 0.9518673274787259, 0.8636070716547632], 
             UndirectedEdge[111, 383] -> 
             RGBColor[
              0.654497589090739, 0.7202590450093853, 0.8723302925477021], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.34707999656479394`, 0.4670293755275545, 0.9437246340590064], 
             UndirectedEdge[121, 122] -> 
             RGBColor[
              0.577701995684873, 0.6680435311321292, 0.9598979637739025], 
             UndirectedEdge[156, 221] -> 
             RGBColor[
              0.6092606012551964, 0.6866644728771474, 0.9659387153281456], 
             UndirectedEdge[61, 176] -> 
             RGBColor[
              0.5076730201259769, 0.5941896247775578, 0.9580567620180328], 
             UndirectedEdge[128, 261] -> 
             RGBColor[
              0.6572781518758368, 0.7213408352108646, 0.8092214538282752], 
             UndirectedEdge[69, 381] -> 
             RGBColor[
              0.5038080673458749, 0.6074352739385019, 0.9542514733352306], 
             UndirectedEdge[166, 178] -> 
             RGBColor[
              0.9709403251071917, 0.9767040538745505, 0.8828498520929664], 
             UndirectedEdge[114, 202] -> 
             RGBColor[
              0.6784783413327251, 0.7487517039662863, 0.9685880383896105], 
             UndirectedEdge[40, 134] -> 
             RGBColor[
              0.28714134369915745`, 0.413769388355469, 0.9398600764911639], 
             UndirectedEdge[84, 234] -> 
             RGBColor[
              0.26271839143109194`, 0.3934640650751402, 0.9382727957837456], 
             UndirectedEdge[236, 367] -> 
             RGBColor[
              0.6944984985084262, 0.7597525084781489, 0.9714026518488289], 
             UndirectedEdge[307, 366] -> 
             RGBColor[
              0.35197416509975593`, 0.4792840638986563, 0.943648460454991], 
             UndirectedEdge[129, 396] -> 
             RGBColor[
              0.8030170401138511, 0.8437210621959986, 0.8504028401867997], 
             UndirectedEdge[67, 208] -> 
             RGBColor[
              0.8562809303615899, 0.8157363731144471, 0.6253133540758471], 
             UndirectedEdge[203, 309] -> 
             RGBColor[
              0.5724647875750577, 0.6637917296550445, 0.9594856715669723], 
             UndirectedEdge[142, 302] -> 
             RGBColor[
              0.6460336874163857, 0.7127857785190478, 0.8859913860803823], 
             UndirectedEdge[93, 248] -> 
             RGBColor[
              0.3459618691338353, 0.4740765153197576, 0.9432653622725071], 
             UndirectedEdge[110, 227] -> 
             RGBColor[
              0.6077471977598151, 0.6702656702802814, 0.8031903043904077], 
             UndirectedEdge[129, 361] -> 
             RGBColor[
              0.6571985786129212, 0.7217121892158549, 0.8399255936369473], 
             UndirectedEdge[236, 332] -> 
             RGBColor[
              0.9298174600727775, 0.9453433272374064, 0.9375933689667246], 
             UndirectedEdge[306, 353] -> 
             RGBColor[
              0.4817336883514973, 0.5778977978690505, 0.9548425180558893], 
             UndirectedEdge[257, 280] -> 
             RGBColor[
              0.41879719618357136`, 0.5333840972351296, 0.9486302979069619], 
             UndirectedEdge[208, 385] -> 
             RGBColor[
              0.6310881933746297, 0.7094355194118538, 0.9654334897683186], 
             UndirectedEdge[79, 302] -> 
             RGBColor[
              0.7532732337342049, 0.8044563124775064, 0.8932868708649175], 
             UndirectedEdge[21, 242] -> 
             RGBColor[
              0.8642871780852224, 0.8909119824211655, 0.7682195956954345], 
             UndirectedEdge[94, 103] -> 
             RGBColor[
              0.41636766713993406`, 0.5349838772154162, 0.9477721701191635], 
             UndirectedEdge[237, 308] -> 
             RGBColor[
              0.46580745196983175`, 0.5700991938306611, 0.9525200699138303], 
             UndirectedEdge[1, 235] -> 
             RGBColor[
              0.6321383642104216, 0.6959303673337065, 0.8073828935645521], 
             UndirectedEdge[31, 374] -> 
             RGBColor[
              0.4282950018164639, 0.5443103706527626, 0.9488096782069189], 
             UndirectedEdge[324, 351] -> 
             RGBColor[
              0.32619155791774374`, 0.4564262217780125, 0.9420248838819525], 
             UndirectedEdge[62, 396] -> 
             RGBColor[
              0.6435556669330762, 0.7209952839624367, 0.965431732756846], 
             UndirectedEdge[13, 123] -> 
             RGBColor[
              0.8317832682118238, 0.8257480445909071, 0.6397804145034247], 
             UndirectedEdge[112, 337] -> 
             RGBColor[
              0.44781626436884747`, 0.5596716924255144, 0.9504810005610109], 
             UndirectedEdge[262, 286] -> 
             RGBColor[
              0.7236754355704054, 0.7835256678438227, 0.9736005742123528], 
             UndirectedEdge[56, 59] -> 
             RGBColor[
              0.4224539897179084, 0.5381284346471327, 0.9487477118431062], 
             UndirectedEdge[61, 118] -> 
             RGBColor[
              0.3996233538523648, 0.508826928430906, 0.9479392777086197], 
             UndirectedEdge[14, 235] -> 
             RGBColor[
              0.5750809209753007, 0.654132125998398, 0.9635698265367602], 
             UndirectedEdge[154, 286] -> 
             RGBColor[
              0.6135450460797178, 0.6917187945750451, 0.9655932981408082], 
             UndirectedEdge[159, 215] -> 
             RGBColor[
              0.8629374379589485, 0.8931725351631574, 0.9555787033928698], 
             UndirectedEdge[25, 385] -> 
             RGBColor[
              0.4129821928529728, 0.5310604814213571, 0.9478302857672423], 
             UndirectedEdge[165, 256] -> 
             RGBColor[
              0.48851998720488304`, 0.5953762901903377, 0.952950523956636], 
             UndirectedEdge[292, 384] -> 
             RGBColor[
              0.9917215477016212, 0.9901590376630434, 0.7370212954106191], 
             UndirectedEdge[1, 49] -> 
             RGBColor[
              0.9652586712974283, 0.9714369615536542, 0.8349088051432106], 
             UndirectedEdge[93, 125] -> 
             RGBColor[
              0.657842692362792, 0.7273103598802866, 0.9659973757506697], 
             UndirectedEdge[15, 37] -> 
             RGBColor[
              0.8022590494057997, 0.7880159990007737, 0.623135871060425], 
             UndirectedEdge[141, 399] -> 
             RGBColor[
              0.687718333411875, 0.753513886404473, 0.9714474615606494], 
             UndirectedEdge[42, 288] -> 
             RGBColor[
              0.5248146447671431, 0.6251071971091087, 0.9557344777769088], 
             UndirectedEdge[26, 218] -> 
             RGBColor[
              0.3597155076246006, 0.4826855908946083, 0.9442626942088452], 
             UndirectedEdge[292, 389] -> 
             RGBColor[
              0.9183772780610868, 0.9338411039424449, 0.8130831547981944], 
             UndirectedEdge[87, 361] -> 
             RGBColor[
              0.6186573758358954, 0.6942389333302187, 0.9667973644321444], 
             UndirectedEdge[3, 11] -> 
             RGBColor[
              0.4496768890939489, 0.5442040693309015, 0.9530169307619565], 
             UndirectedEdge[217, 364] -> 
             RGBColor[
              0.7182101062350915, 0.7797904606806123, 0.9725481294006253], 
             UndirectedEdge[83, 120] -> 
             RGBColor[
              0.5625033408729214, 0.6557045784641903, 0.9587014699925984], 
             UndirectedEdge[251, 380] -> 
             RGBColor[
              0.4655138204385215, 0.568504440829209, 0.9527069609127242], 
             UndirectedEdge[209, 390] -> 
             RGBColor[
              0.9397277895181386, 0.9537421483563089, 0.9582188016722519], 
             UndirectedEdge[149, 315] -> 
             RGBColor[
              0.7678629600960662, 0.818117101325635, 0.9575935297240795], 
             UndirectedEdge[34, 263] -> 
             RGBColor[
              0.7696313644187126, 0.8201118688083553, 0.9776333206388129], 
             UndirectedEdge[327, 376] -> 
             RGBColor[
              0.46382019729602975`, 0.5738997188592574, 0.9513995682017454], 
             UndirectedEdge[113, 316] -> 
             RGBColor[
              0.8898594151524762, 0.9150137593249681, 0.9893567794757627], 
             UndirectedEdge[85, 307] -> 
             RGBColor[
              0.4865547011266964, 0.590250553628695, 0.9538399186842705], 
             UndirectedEdge[140, 257] -> 
             RGBColor[
              0.41384998059473066`, 0.5281842599796729, 0.9483485612979269], 
             UndirectedEdge[228, 330] -> 
             RGBColor[
              0.44453174459340394`, 0.5470233962629926, 0.951421435895557], 
             UndirectedEdge[22, 96] -> 
             RGBColor[
              0.7455344049316853, 0.7970540693919119, 0.8458775965794288], 
             UndirectedEdge[22, 323] -> 
             RGBColor[
              0.685563516656664, 0.7524933639834908, 0.970705384841321], 
             UndirectedEdge[167, 269] -> 
             RGBColor[
              0.709783574054538, 0.7732075896971473, 0.971708251423288], 
             UndirectedEdge[85, 214] -> 
             RGBColor[
              0.4873857356293514, 0.5909703539458863, 0.9538928714679247], 
             UndirectedEdge[89, 155] -> 
             RGBColor[
              0.3119621939370989, 0.44275086327483293`, 0.9411676534228862], 
             UndirectedEdge[1, 396] -> 
             RGBColor[
              0.8030932153683222, 0.8433424401945369, 0.8193288481290264], 
             UndirectedEdge[172, 208] -> 
             RGBColor[
              0.8721447762699106, 0.9002905507045698, 0.9527086679853105], 
             UndirectedEdge[45, 339] -> 
             RGBColor[
              0.9896059407881252, 0.9882154309461326, 0.6943956149980794], 
             UndirectedEdge[250, 363] -> 
             RGBColor[
              0.8574598873108596, 0.8683605687983562, 0.675274894846873], 
             UndirectedEdge[167, 222] -> 
             RGBColor[
              0.4852090260559623, 0.576640581877384, 0.9558177610270937], 
             UndirectedEdge[73, 208] -> 
             RGBColor[
              0.8646531517412264, 0.8947033093974863, 0.9653900341837636], 
             UndirectedEdge[14, 317] -> 
             RGBColor[
              0.7567523259031113, 0.8102443799848869, 0.9763594274700318], 
             UndirectedEdge[157, 334] -> 
             RGBColor[
              0.9289385104316801, 0.9453530651778554, 0.9646090549821233], 
             UndirectedEdge[107, 190] -> 
             RGBColor[
              0.6066339737265046, 0.6866360199091868, 0.9647371156637479], 
             UndirectedEdge[12, 209] -> 
             RGBColor[
              0.9482476985930082, 0.9586518046054424, 0.8791101423751989], 
             UndirectedEdge[185, 219] -> 
             RGBColor[
              0.7642390946031832, 0.6929044584344184, 0.6052095601902426], 
             UndirectedEdge[318, 345] -> 
             RGBColor[
              0.33922192397148676`, 0.4635820687186803, 0.9430064015061596], 
             UndirectedEdge[36, 383] -> 
             RGBColor[
              0.636089294737227, 0.7017901433566209, 0.871249768902411], 
             UndirectedEdge[24, 357] -> 
             RGBColor[
              0.4364661238292631, 0.5523697271130376, 0.9490590215788306], 
             UndirectedEdge[344, 354] -> 
             RGBColor[
              0.872258337021242, 0.9001526162297602, 0.9415542192929434], 
             UndirectedEdge[7, 194] -> 
             RGBColor[
              0.8502965201886763, 0.8835083273187234, 0.9855723692853757], 
             UndirectedEdge[97, 248] -> 
             RGBColor[
              0.4969803319990925, 0.5982369381567192, 0.954946004836311], 
             UndirectedEdge[14, 129] -> 
             RGBColor[
              0.9376729800955625, 0.949880545110255, 0.8633694148614999], 
             UndirectedEdge[160, 307] -> 
             RGBColor[
              0.33064663638848857`, 0.4608112304817179, 0.9422894891847022], 
             UndirectedEdge[165, 400] -> 
             RGBColor[
              0.47787930132195816`, 0.586737702033143, 0.9521128501858156], 
             UndirectedEdge[310, 323] -> 
             RGBColor[
              0.8314171943982391, 0.8686710482204751, 0.9837141679162229], 
             UndirectedEdge[309, 339] -> 
             RGBColor[
              0.8042961111910665, 0.8464903168943875, 0.9228597359380375], 
             UndirectedEdge[355, 395] -> 
             RGBColor[
              0.35332440240103347`, 0.47579692672317814`, 0.9439049989613583],
              UndirectedEdge[32, 240] -> 
             RGBColor[
              0.5216638733016417, 0.6170596632186564, 0.9575609183408498], 
             UndirectedEdge[66, 322] -> 
             RGBColor[
              0.8145061244940301, 0.855460280619851, 0.9569603304493232], 
             UndirectedEdge[28, 267] -> 
             RGBColor[
              0.6206436890219847, 0.5863663376760309, 0.5980302623716978], 
             UndirectedEdge[51, 102] -> 
             RGBColor[
              0.730180133737167, 0.7891415371408121, 0.9737411898757652], 
             UndirectedEdge[244, 321] -> 
             RGBColor[
              0.9596330864942767, 0.8810667224957572, 0.5747060604961931], 
             UndirectedEdge[140, 309] -> 
             RGBColor[
              0.45351707959505017`, 0.5603877979305779, 0.9514713006366033], 
             UndirectedEdge[12, 324] -> 
             RGBColor[
              0.6479703786260049, 0.7135929974987556, 0.8540609661909522], 
             UndirectedEdge[130, 287] -> 
             RGBColor[
              0.5858827191552555, 0.6722865613123132, 0.9618607020158565], 
             UndirectedEdge[267, 367] -> 
             RGBColor[
              0.41823541725914914`, 0.5350008696172811, 0.9483334759519514], 
             UndirectedEdge[138, 229] -> 
             RGBColor[
              0.5831446584640625, 0.6724621299654392, 0.9603264301250108], 
             UndirectedEdge[97, 193] -> 
             RGBColor[
              0.6254018122999044, 0.7062232959632435, 0.9640257525985811], 
             UndirectedEdge[248, 340] -> 
             RGBColor[
              0.5484138741578397, 0.6384172122005312, 0.960072419644916], 
             UndirectedEdge[162, 248] -> 
             RGBColor[
              0.33546157475970795`, 0.464981688093029, 0.9425962928000334], 
             UndirectedEdge[127, 317] -> 
             RGBColor[
              0.7276242855512143, 0.7870184712678767, 0.9735811689783593], 
             UndirectedEdge[269, 355] -> 
             RGBColor[
              0.5582738639754232, 0.6517367244087753, 0.9586778697184087], 
             UndirectedEdge[161, 184] -> 
             RGBColor[
              0.7787382225202508, 0.8272436595289936, 0.9664298398224742], 
             UndirectedEdge[340, 360] -> 
             RGBColor[
              0.7803168400240061, 0.8283087131451717, 0.9787383482042786], 
             UndirectedEdge[19, 185] -> 
             RGBColor[
              0.7861275193248647, 0.7103880246238513, 0.6071285398501218], 
             UndirectedEdge[240, 357] -> 
             RGBColor[
              0.5758723346129853, 0.6641160464033143, 0.9610112351828732], 
             UndirectedEdge[75, 132] -> 
             RGBColor[
              0.5096187011024229, 0.6018814750602282, 0.9572735917971322], 
             UndirectedEdge[89, 353] -> 
             RGBColor[
              0.5251879792226495, 0.6210994522642719, 0.9574076715722399], 
             UndirectedEdge[214, 312] -> 
             RGBColor[
              0.29444534403553957`, 0.4256406948437208, 0.9401224532064956], 
             UndirectedEdge[119, 129] -> 
             RGBColor[
              0.6562195561959163, 0.7208642092053428, 0.8398632111942512], 
             UndirectedEdge[143, 377] -> 
             RGBColor[
              0.6781933585812834, 0.7384360214495884, 0.7233321822196995], 
             UndirectedEdge[5, 122] -> 
             RGBColor[
              0.6108967026311017, 0.6949924896355841, 0.9625111727009277], 
             UndirectedEdge[42, 318] -> 
             RGBColor[
              0.47281161242983266`, 0.581985853991305, 0.9518900932466507], 
             UndirectedEdge[6, 137] -> 
             RGBColor[
              0.4209003306785991, 0.5349460891874028, 0.9488091020627316], 
             UndirectedEdge[113, 149] -> 
             RGBColor[
              0.7278295649311898, 0.7867807137235743, 0.9740628008000485], 
             UndirectedEdge[67, 124] -> 
             RGBColor[
              0.6306042767997309, 0.6308040159726129, 0.6072277547575148], 
             UndirectedEdge[141, 337] -> 
             RGBColor[
              0.6394698916916037, 0.711723511223566, 0.9683731135186556], 
             UndirectedEdge[63, 224] -> 
             RGBColor[
              0.37035015758481504`, 0.4952004249849772, 0.9448193624468868], 
             UndirectedEdge[244, 357] -> 
             RGBColor[
              0.7009465098394394, 0.761596476023809, 0.9159306342126108], 
             UndirectedEdge[9, 192] -> 
             RGBColor[
              0.31792890844253524`, 0.44205704878413066`, 0.9417624794357857],
              UndirectedEdge[46, 369] -> 
             RGBColor[
              0.8175950985274263, 0.8578568919566227, 0.9823408174957977], 
             UndirectedEdge[350, 392] -> 
             RGBColor[
              0.424344586735553, 0.5236682836937301, 0.9506101461171921], 
             UndirectedEdge[275, 339] -> 
             RGBColor[
              0.6245288561732086, 0.69116131970876, 0.9102894548833071], 
             UndirectedEdge[119, 127] -> 
             RGBColor[
              0.5701102478633697, 0.6554614371515624, 0.9621978936170137], 
             UndirectedEdge[152, 398] -> 
             RGBColor[
              0.8255831106325393, 0.862777035144221, 0.8955236540453961], 
             UndirectedEdge[105, 229] -> 
             RGBColor[
              0.5135678882216785, 0.6148011946874214, 0.9551738525672075], 
             UndirectedEdge[181, 365] -> 
             RGBColor[
              0.370294151569938, 0.4848903677333274, 0.9456418259315543], 
             UndirectedEdge[24, 285] -> 
             RGBColor[
              0.6415563763792428, 0.7171172710567149, 0.9668371181477672], 
             UndirectedEdge[167, 189] -> 
             RGBColor[
              0.5422378864838295, 0.6343217059461396, 0.9591482134913956], 
             UndirectedEdge[157, 191] -> 
             RGBColor[
              0.874957856078687, 0.9026143969734106, 0.9593796490307316], 
             UndirectedEdge[78, 194] -> 
             RGBColor[
              0.5306728717759631, 0.6158404807752409, 0.959766068135086], 
             UndirectedEdge[107, 268] -> 
             RGBColor[
              0.6167202603249289, 0.6953722544092371, 0.9653798049268464], 
             UndirectedEdge[5, 274] -> 
             RGBColor[
              0.5734873304633775, 0.6646218760368147, 0.9595661698888389], 
             UndirectedEdge[12, 118] -> 
             RGBColor[
              0.7865015127721285, 0.830665070442582, 0.863820056189851], 
             UndirectedEdge[20, 291] -> 
             RGBColor[
              0.3967859363779319, 0.5017455545106045, 0.9481508136687298], 
             UndirectedEdge[6, 379] -> 
             RGBColor[
              0.4769014833539252, 0.5848995308987093, 0.9523244254957897], 
             UndirectedEdge[97, 181] -> 
             RGBColor[
              0.6002261865156623, 0.6857845888025789, 0.9620438351154897], 
             UndirectedEdge[39, 320] -> 
             RGBColor[
              0.6232594550894999, 0.2109106036768018, 0.4217127559972732], 
             UndirectedEdge[202, 218] -> 
             RGBColor[
              0.5608764325785595, 0.6536912247855574, 0.9589705561474112], 
             UndirectedEdge[61, 344] -> 
             RGBColor[
              0.6018194632775404, 0.6677560485561183, 0.9210924015329676], 
             UndirectedEdge[181, 214] -> 
             RGBColor[
              0.4219573827591756, 0.5380212903275916, 0.948626824926627], 
             UndirectedEdge[274, 324] -> 
             RGBColor[
              0.4040417711822968, 0.5224520800894487, 0.9473733831000455], 
             UndirectedEdge[62, 231] -> 
             RGBColor[
              0.45973818465627614`, 0.5600637702577269, 0.9527532703787077], 
             UndirectedEdge[117, 289] -> 
             RGBColor[
              0.646694243065709, 0.7197241846855587, 0.9680309044840116], 
             UndirectedEdge[14, 396] -> 
             RGBColor[
              0.7460357721332014, 0.8015441988592285, 0.9755157811012345], 
             UndirectedEdge[79, 175] -> 
             RGBColor[
              0.7392060421625427, 0.794769300620199, 0.95311610554616], 
             UndirectedEdge[246, 395] -> 
             RGBColor[
              0.26284021738767943`, 0.3935921118797255, 0.9382797335917479], 
             UndirectedEdge[87, 396] -> 
             RGBColor[
              0.7644758373368252, 0.8162478063103624, 0.9772746109819967], 
             UndirectedEdge[341, 366] -> 
             RGBColor[
              0.4740555406159276, 0.5820221011328358, 0.9522570366443122], 
             UndirectedEdge[40, 226] -> 
             RGBColor[
              0.26445865536703467`, 0.3941227837872487, 0.9384147556481548], 
             UndirectedEdge[67, 316] -> 
             RGBColor[
              0.9221731247510785, 0.8678698707851656, 0.6317062553684525], 
             UndirectedEdge[303, 376] -> 
             RGBColor[
              0.7465774097753053, 0.8008952787068722, 0.9574935025399514], 
             UndirectedEdge[208, 357] -> 
             RGBColor[
              0.592825744146672, 0.6773601787817151, 0.9627009926065713], 
             UndirectedEdge[54, 66] -> 
             RGBColor[
              0.8202354501107717, 0.8597332022839073, 0.9472620766276201], 
             UndirectedEdge[3, 160] -> 
             RGBColor[
              0.26300311560690137`, 0.39073034068128404`, 0.9384000629361984],
              UndirectedEdge[230, 328] -> 
             RGBColor[
              0.8273527844329702, 0.8657587242782065, 0.9832393201029344], 
             UndirectedEdge[282, 383] -> 
             RGBColor[
              0.7711367616314564, 0.8186191950013331, 0.8804992929904036], 
             UndirectedEdge[106, 150] -> 
             RGBColor[
              0.9864036085668397, 0.9858814263573179, 0.6939515341713214], 
             UndirectedEdge[1, 298] -> 
             RGBColor[
              0.8541659402485451, 0.8837154023787406, 0.824094839862892], 
             UndirectedEdge[66, 131] -> 
             RGBColor[
              0.47666177535359294`, 0.5792337264778238, 0.953498222970154], 
             UndirectedEdge[53, 126] -> 
             RGBColor[
              0.4492467241893851, 0.5602254566653769, 0.9507614787780294], 
             UndirectedEdge[182, 281] -> 
             RGBColor[
              0.6868568382130897, 0.7524781617682827, 0.9683891466436878], 
             UndirectedEdge[74, 263] -> 
             RGBColor[
              0.6966627412773865, 0.7629574954096141, 0.9704004894332152], 
             UndirectedEdge[24, 243] -> 
             RGBColor[
              0.5075134079948429, 0.6110612736855208, 0.9543724610416748], 
             UndirectedEdge[177, 252] -> 
             RGBColor[
              0.6386572533818143, 0.7051214431068361, 0.8878866414258451], 
             UndirectedEdge[10, 216] -> 
             RGBColor[
              0.4824037133274241, 0.5870884624192917, 0.9533920343314238], 
             UndirectedEdge[280, 339] -> 
             RGBColor[
              0.6401316809240221, 0.707560877798092, 0.9111780126705553], 
             UndirectedEdge[152, 154] -> 
             RGBColor[
              0.51334649656649, 0.6131025920395432, 0.9556967573447697], 
             UndirectedEdge[36, 304] -> 
             RGBColor[
              0.39051722707912395`, 0.5088870691993297, 0.9465440003099499], 
             UndirectedEdge[128, 299] -> 
             RGBColor[
              0.8274730867713107, 0.8628673558155735, 0.8218038592545549], 
             UndirectedEdge[95, 162] -> 
             RGBColor[
              0.2950227182288219, 0.4231502392360334, 0.940268741595564], 
             UndirectedEdge[215, 329] -> 
             RGBColor[
              0.8520529813920222, 0.8846695149681407, 0.9544938424833083], 
             UndirectedEdge[208, 387] -> 
             RGBColor[
              0.882048916686752, 0.9052810042291408, 0.8095100782905198], 
             UndirectedEdge[178, 197] -> 
             RGBColor[
              0.7042650410013258, 0.7632883402427091, 0.8726797221570268], 
             UndirectedEdge[53, 303] -> 
             RGBColor[
              0.7659394997037651, 0.8166142955630069, 0.9590177571847921], 
             UndirectedEdge[59, 121] -> 
             RGBColor[
              0.44302929242943356`, 0.554832392295173, 0.9503674750423747], 
             UndirectedEdge[134, 269] -> 
             RGBColor[
              0.5175248334956153, 0.616441962312989, 0.9560813775291882], 
             UndirectedEdge[44, 362] -> 
             RGBColor[
              0.6244507716695853, 0.7025909398861343, 0.965631664335348], 
             UndirectedEdge[284, 338] -> 
             RGBColor[
              0.3877472973324236, 0.5062569946256144, 0.9463606514866097], 
             UndirectedEdge[12, 346] -> 
             RGBColor[
              0.8862941536733535, 0.9095773158126077, 0.8731145573764338], 
             UndirectedEdge[113, 387] -> 
             RGBColor[
              0.936405549853991, 0.9482163585057054, 0.8148027074558298], 
             UndirectedEdge[55, 400] -> 
             RGBColor[
              0.39830644375429874`, 0.5155649819875359, 0.94712494759343], 
             UndirectedEdge[25, 201] -> 
             RGBColor[
              0.5626284218481452, 0.6502598936569541, 0.9611767649089025], 
             UndirectedEdge[123, 309] -> 
             RGBColor[
              0.7925513380885254, 0.794797519962724, 0.6360767872971023], 
             UndirectedEdge[35, 162] -> 
             RGBColor[
              0.6729878718770453, 0.7361990876605441, 0.870740404682094], 
             UndirectedEdge[73, 172] -> 
             RGBColor[
              0.9671873404153882, 0.9750489527243713, 0.9404274531512267], 
             UndirectedEdge[137, 282] -> 
             RGBColor[
              0.42230981790273686`, 0.5360903744126337, 0.9489200620601377], 
             UndirectedEdge[37, 114] -> 
             RGBColor[
              0.8168349934399403, 0.799402837261522, 0.6245886649418066], 
             UndirectedEdge[214, 248] -> 
             RGBColor[
              0.31871152824260585`, 0.45047363968173193`, 0.9415289946474482],
              UndirectedEdge[161, 363] -> 
             RGBColor[
              0.6715694569717454, 0.7428295578044843, 0.9682582840299858], 
             UndirectedEdge[51, 84] -> 
             RGBColor[
              0.46045416687418494`, 0.5582714896957178, 0.9531969273758245], 
             UndirectedEdge[56, 278] -> 
             RGBColor[
              0.6507608242731512, 0.7254448563227174, 0.9669560676984887], 
             UndirectedEdge[4, 140] -> 
             RGBColor[
              0.5417126714440124, 0.6295891072364617, 0.9600551680523062], 
             UndirectedEdge[221, 351] -> 
             RGBColor[
              0.3333476023099531, 0.4631506714083961, 0.9424615923448474], 
             UndirectedEdge[54, 204] -> 
             RGBColor[
              0.671794411759493, 0.7372762380757403, 0.9359695533865718], 
             UndirectedEdge[10, 298] -> 
             RGBColor[
              0.5175840599385495, 0.61457161657244, 0.9568984825025899], 
             UndirectedEdge[134, 226] -> 
             RGBColor[
              0.344087666487063, 0.4724531751872874, 0.9431459397371471], 
             UndirectedEdge[35, 98] -> 
             RGBColor[
              0.6760653712721132, 0.7388646629569348, 0.8709365002222218], 
             UndirectedEdge[70, 180] -> 
             RGBColor[
              0.6661977404831357, 0.7329366496527645, 0.9430264202370575], 
             UndirectedEdge[165, 328] -> 
             RGBColor[
              0.5955121498586955, 0.6806270901983733, 0.9624742808253084], 
             UndirectedEdge[162, 214] -> 
             RGBColor[
              0.33815502467204234`, 0.4673146190303642, 0.9427679170467231], 
             UndirectedEdge[211, 370] -> 
             RGBColor[
              0.6608463931421895, 0.7327789765892195, 0.9683543166932718], 
             UndirectedEdge[55, 245] -> 
             RGBColor[
              0.4365133847633868, 0.5465830979017914, 0.9501327379463018], 
             UndirectedEdge[247, 315] -> 
             RGBColor[
              0.7756246863522973, 0.8244184203622265, 0.9582045612471102], 
             UndirectedEdge[16, 268] -> 
             RGBColor[
              0.28827135727640857`, 0.41210524001196047`, 0.9400288498134513],
              UndirectedEdge[154, 291] -> 
             RGBColor[
              0.48969311722435094`, 0.5941958970803551, 0.9536321740844174], 
             UndirectedEdge[296, 373] -> 
             RGBColor[
              0.47670634680533275`, 0.5837412302338149, 0.9525853334616363], 
             UndirectedEdge[101, 394] -> 
             RGBColor[
              0.2833155240918034, 0.4130100560952344, 0.9395227695374184], 
             UndirectedEdge[173, 388] -> 
             RGBColor[
              0.7546806042028553, 0.8083760601738967, 0.9764108801582765], 
             UndirectedEdge[84, 102] -> 
             RGBColor[
              0.4960421834343109, 0.5860731187114319, 0.9567440082776146], 
             UndirectedEdge[216, 298] -> 
             RGBColor[
              0.6783449353008102, 0.748647486160231, 0.9685747417230994], 
             UndirectedEdge[209, 310] -> 
             RGBColor[
              0.8458653902209521, 0.8801916473836785, 0.9850922497318498], 
             UndirectedEdge[34, 93] -> 
             RGBColor[
              0.6072691749631637, 0.6870896405435425, 0.9648220414216409], 
             UndirectedEdge[112, 285] -> 
             RGBColor[
              0.6881261292387149, 0.7549246943714927, 0.9705032596834904], 
             UndirectedEdge[131, 309] -> 
             RGBColor[
              0.45523234258558376`, 0.5621906480875837, 0.9515689823264102], 
             UndirectedEdge[116, 265] -> 
             RGBColor[
              0.5693159839129872, 0.6600197107911643, 0.9599237042376911], 
             UndirectedEdge[49, 129] -> 
             RGBColor[
              0.9651824960429571, 0.9718155835551159, 0.8659827972009839], 
             UndirectedEdge[238, 325] -> 
             RGBColor[
              0.22331632048189634`, 0.3520499902719463, 0.9360289061333292], 
             UndirectedEdge[112, 399] -> 
             RGBColor[
              0.49606470608911873`, 0.6014620676064213, 0.9535553486030048], 
             UndirectedEdge[186, 322] -> 
             RGBColor[
              0.7809227491612303, 0.828550084126641, 0.9540742869255204], 
             UndirectedEdge[180, 332] -> 
             RGBColor[
              0.6757558671578936, 0.7398215016925407, 0.9159388522745093], 
             UndirectedEdge[60, 331] -> 
             RGBColor[
              0.44391408435667623`, 0.5588547852591215, 0.9495242022268067], 
             UndirectedEdge[14, 126] -> 
             RGBColor[
              0.6019589404220541, 0.6810438380661359, 0.9651495096615244], 
             UndirectedEdge[275, 288] -> 
             RGBColor[
              0.3935818695047744, 0.5091806770423837, 0.946985008756188], 
             UndirectedEdge[276, 290] -> 
             RGBColor[
              0.6228091650122095, 0.49826932448860767`, 0.5785871269133589], 
             UndirectedEdge[18, 232] -> 
             RGBColor[
              0.685134194656574, 0.7508391825309217, 0.9661352866167461], 
             UndirectedEdge[4, 325] -> 
             RGBColor[
              0.5318552758934721, 0.619228359517868, 0.9594938039584128], 
             UndirectedEdge[1, 62] -> 
             RGBColor[
              0.8352690501499085, 0.8689530082120016, 0.8222113744593381], 
             UndirectedEdge[20, 304] -> 
             RGBColor[
              0.33938931366381336`, 0.4551483905028961, 0.9436323412779177], 
             UndirectedEdge[255, 328] -> 
             RGBColor[
              0.6934464108455491, 0.7603998040097188, 0.9701107300204723], 
             UndirectedEdge[3, 74] -> 
             RGBColor[
              0.4385756556463658, 0.5355317013891505, 0.9519104635588262], 
             UndirectedEdge[18, 279] -> 
             RGBColor[
              0.7662940335644552, 0.8173977667681107, 0.9723395372866844], 
             UndirectedEdge[163, 226] -> 
             RGBColor[
              0.36800309932410236`, 0.49316752108612616`, 0.9446698099699363],
              UndirectedEdge[145, 254] -> 
             RGBColor[
              0.606211621164407, 0.669237069386553, 0.8395583337587493], 
             UndirectedEdge[23, 348] -> 
             RGBColor[
              0.8299462211309443, 0.8654410796564557, 0.8622019783798935], 
             UndirectedEdge[119, 396] -> 
             RGBColor[
              0.46458234823355515`, 0.5725278629543162, 0.9520095774339858], 
             UndirectedEdge[73, 141] -> 
             RGBColor[
              0.9465169116060458, 0.9595720998416382, 0.9733063176493908], 
             UndirectedEdge[29, 396] -> 
             RGBColor[
              0.7958320113122418, 0.8202704011487347, 0.6702287193713394], 
             UndirectedEdge[160, 312] -> 
             RGBColor[
              0.30451803677174294`, 0.4343651550235629, 0.940764276280714], 
             UndirectedEdge[210, 397] -> 
             RGBColor[
              0.5741717976746412, 0.46395172801334084`, 0.5779191855408197], 
             UndirectedEdge[11, 86] -> 
             RGBColor[
              0.8199736570387556, 0.8601381245427002, 0.9824656163353157], 
             UndirectedEdge[113, 315] -> 
             RGBColor[
              0.9183572490951032, 0.9371520035328749, 0.9717872362724985], 
             UndirectedEdge[120, 160] -> 
             RGBColor[
              0.42049650328790067`, 0.5373822770078959, 0.9483606829478057], 
             UndirectedEdge[5, 308] -> 
             RGBColor[
              0.6452895605994643, 0.7228180394973378, 0.9652844233402795], 
             UndirectedEdge[37, 261] -> 
             RGBColor[
              0.6358962086548992, 0.6494831394667996, 0.6109354129655205], 
             UndirectedEdge[22, 241] -> 
             RGBColor[
              0.5413146828372224, 0.6385026713326432, 0.9570334212154165], 
             UndirectedEdge[55, 165] -> 
             RGBColor[
              0.3639754942244634, 0.4874283017135262, 0.9444955840627693], 
             UndirectedEdge[251, 283] -> 
             RGBColor[
              0.4532663727538028, 0.5556315967795361, 0.9520094868855546], 
             UndirectedEdge[334, 365] -> 
             RGBColor[
              0.5542036532624797, 0.6309663760574552, 0.96256608492156], 
             UndirectedEdge[44, 358] -> 
             RGBColor[
              0.641485009645564, 0.7170998721151118, 0.9667848393448055], 
             UndirectedEdge[225, 367] -> 
             RGBColor[
              0.6936865436631607, 0.7591050777244615, 0.9713252068708469], 
             UndirectedEdge[23, 321] -> 
             RGBColor[
              0.963467968047591, 0.8826525445700133, 0.5111521488024463], 
             UndirectedEdge[234, 269] -> 
             RGBColor[
              0.4836999392314498, 0.5862546018772066, 0.9539586701340188], 
             UndirectedEdge[21, 208] -> 
             RGBColor[
              0.7522122722731233, 0.8063532112155559, 0.9759371475429888], 
             UndirectedEdge[208, 240] -> 
             RGBColor[
              0.7526571780620621, 0.8067007749992842, 0.9759814915941492], 
             UndirectedEdge[15, 313] -> 
             RGBColor[
              0.7738239727442138, 0.8238442119380607, 0.9779299147943386], 
             UndirectedEdge[63, 204] -> 
             RGBColor[
              0.34828710633436183`, 0.4760905189130338, 0.9434135243307981], 
             UndirectedEdge[241, 310] -> 
             RGBColor[
              0.6871683605787975, 0.7546803555696275, 0.9700422042903183], 
             UndirectedEdge[182, 256] -> 
             RGBColor[
              0.7363265202298779, 0.7931494120895004, 0.9721427954973113], 
             UndirectedEdge[373, 380] -> 
             RGBColor[
              0.4290065454571504, 0.5391083294851791, 0.9496674226569566], 
             UndirectedEdge[185, 210] -> 
             RGBColor[
              0.8928099577947812, 0.6041491260942806, 0.23216648120793487`], 
             UndirectedEdge[96, 223] -> 
             RGBColor[
              0.6975906175469653, 0.7566977431776174, 0.8424993386405469], 
             UndirectedEdge[103, 222] -> 
             RGBColor[
              0.29790001468797866`, 0.4241621611377943, 0.940506279500167], 
             UndirectedEdge[146, 375] -> 
             RGBColor[
              0.5580391032270547, 0.6520803092316616, 0.9583500288520745], 
             UndirectedEdge[42, 276] -> 
             RGBColor[
              0.45137919693828377`, 0.5634221729170497, 0.9505244386834701], 
             UndirectedEdge[46, 372] -> 
             RGBColor[
              0.6324016305844589, 0.7076864349512008, 0.9669628458416444], 
             UndirectedEdge[95, 285] -> 
             RGBColor[
              0.530680885533027, 0.6143741745517527, 0.959994598662494], 
             UndirectedEdge[14, 326] -> 
             RGBColor[
              0.5822004206225732, 0.6616151715300307, 0.9639752715093164], 
             UndirectedEdge[22, 310] -> 
             RGBColor[
              0.6422682395287336, 0.7182284145737831, 0.9665075022866945], 
             UndirectedEdge[23, 229] -> 
             RGBColor[
              0.8053139785645251, 0.8458113419487377, 0.8600113530425795], 
             UndirectedEdge[23, 160] -> 
             RGBColor[
              0.6675361228576296, 0.7309223184945679, 0.8500034869425037], 
             UndirectedEdge[165, 311] -> 
             RGBColor[
              0.5309083650846954, 0.6297890849278315, 0.9562874923370792], 
             UndirectedEdge[179, 288] -> 
             RGBColor[
              0.39438008311620687`, 0.5100196501576651, 0.9470304658405079], 
             UndirectedEdge[51, 167] -> 
             RGBColor[
              0.7229399765570361, 0.7834854713244612, 0.9730195586711654], 
             UndirectedEdge[310, 346] -> 
             RGBColor[
              0.7839118453012974, 0.8311171585908439, 0.9790966647330848], 
             UndirectedEdge[79, 379] -> 
             RGBColor[
              0.46129985963058207`, 0.5722334299149601, 0.9510962085256573], 
             UndirectedEdge[78, 264] -> 
             RGBColor[
              0.5703420269462496, 0.6474306417857814, 0.9635606135188273], 
             UndirectedEdge[309, 325] -> 
             RGBColor[
              0.44365968404450995`, 0.5500270502119842, 0.95090993654271], 
             UndirectedEdge[149, 358] -> 
             RGBColor[
              0.5198431639678341, 0.6210711250335719, 0.9553431045972529], 
             UndirectedEdge[6, 79] -> 
             RGBColor[
              0.5331150273818472, 0.6318458216437008, 0.9563879143016416], 
             UndirectedEdge[134, 234] -> 
             RGBColor[
              0.3329454605550204, 0.46191241931972526`, 0.9424685531849868], 
             UndirectedEdge[96, 209] -> 
             RGBColor[
              0.9491315556239038, 0.9590173022018074, 0.8644623440245842], 
             UndirectedEdge[216, 393] -> 
             RGBColor[
              0.4528520131077035, 0.5572201525906731, 0.9516654490877534], 
             UndirectedEdge[164, 388] -> 
             RGBColor[
              0.8005276363441041, 0.8447964282251446, 0.980567308277152], 
             UndirectedEdge[155, 261] -> 
             RGBColor[
              0.3040946245899854, 0.43593637014189646`, 0.9406663388611065], 
             UndirectedEdge[125, 288] -> 
             RGBColor[
              0.731924624191257, 0.7895553360195733, 0.9712486082328999], 
             UndirectedEdge[287, 384] -> 
             RGBColor[
              0.7066226700053649, 0.7658104691162516, 0.8904750061471485], 
             UndirectedEdge[69, 320] -> 
             RGBColor[
              0.33285194624309083`, 0.4559160151897088, 0.9426791865535602], 
             UndirectedEdge[123, 339] -> 
             RGBColor[
              0.9742187238286566, 0.9367707625747814, 0.5955017627220192], 
             UndirectedEdge[132, 202] -> 
             RGBColor[
              0.4701042005627679, 0.5710124469173227, 0.9533351556673416], 
             UndirectedEdge[67, 249] -> 
             RGBColor[
              0.6492354321206389, 0.6469413862824891, 0.6084149154996793], 
             UndirectedEdge[374, 384] -> 
             RGBColor[
              0.6762451817389872, 0.7394990155968696, 0.888539379456573], 
             UndirectedEdge[99, 252] -> 
             RGBColor[
              0.49432856634598865`, 0.5931328380474481, 0.9552436193857518], 
             UndirectedEdge[44, 65] -> 
             RGBColor[
              0.6542263749301412, 0.7274438864450965, 0.9677878862931664], 
             UndirectedEdge[88, 370] -> 
             RGBColor[
              0.8423931598773635, 0.8771654558057691, 0.9848294056739961], 
             UndirectedEdge[13, 275] -> 
             RGBColor[
              0.48209340055637584`, 0.5801386017248857, 0.9545681066647127], 
             UndirectedEdge[183, 269] -> 
             RGBColor[
              0.5350016838830413, 0.631579531706536, 0.9571949869817029], 
             UndirectedEdge[122, 178] -> 
             RGBColor[
              0.7854625920515974, 0.8301819899788483, 0.8788028214762617], 
             UndirectedEdge[199, 216] -> 
             RGBColor[
              0.7976046901375968, 0.842459998303889, 0.965564066031446], 
             UndirectedEdge[107, 295] -> 
             RGBColor[
              0.7163733678102818, 0.7777875840325255, 0.9728069687987043], 
             UndirectedEdge[89, 171] -> 
             RGBColor[
              0.47225675697213787`, 0.5792387051113916, 0.9524809958968434], 
             UndirectedEdge[18, 91] -> 
             RGBColor[
              0.5812115067990424, 0.6526972337186797, 0.959811079797845], 
             UndirectedEdge[194, 357] -> 
             RGBColor[
              0.6154794540802295, 0.6950574291563827, 0.9649589027017929], 
             UndirectedEdge[147, 388] -> 
             RGBColor[
              0.9496828532854145, 0.9577479530862607, 0.7305176574227672], 
             UndirectedEdge[96, 323] -> 
             RGBColor[
              0.934683359801191, 0.9474967030386041, 0.8630842622089572], 
             UndirectedEdge[168, 265] -> 
             RGBColor[
              0.8301987589344699, 0.8677473091753818, 0.9599328345734819], 
             UndirectedEdge[44, 372] -> 
             RGBColor[
              0.606358878545024, 0.6869206513866277, 0.9644788649034839], 
             UndirectedEdge[180, 286] -> 
             RGBColor[
              0.6139722176973128, 0.6920887891599361, 0.9656205171385484], 
             UndirectedEdge[18, 45] -> 
             RGBColor[
              0.9674255933229658, 0.9719676741257435, 0.7451209609019431], 
             UndirectedEdge[83, 217] -> 
             RGBColor[
              0.7073725865578909, 0.7710668305552095, 0.9716438486750818], 
             UndirectedEdge[137, 314] -> 
             RGBColor[
              0.5720343562701005, 0.654698187130157, 0.9628254737562953], 
             UndirectedEdge[205, 338] -> 
             RGBColor[
              0.5497209660265502, 0.6350248055998458, 0.9609822051375487], 
             UndirectedEdge[210, 293] -> 
             RGBColor[
              0.6340181419861666, 0.5190074480407871, 0.581614648130847], 
             UndirectedEdge[295, 324] -> 
             RGBColor[
              0.449988076380556, 0.5597533605068568, 0.950990444552114], 
             UndirectedEdge[270, 346] -> 
             RGBColor[
              0.5141356197169196, 0.6032104329155177, 0.9580720397611304], 
             UndirectedEdge[26, 349] -> 
             RGBColor[
              0.25837961081785504`, 0.38890373155604874`, 0.9380257086464724],
              UndirectedEdge[27, 208] -> 
             RGBColor[
              0.5851059429670931, 0.670673675008453, 0.9622090937017607], 
             UndirectedEdge[139, 193] -> 
             RGBColor[
              0.3760730989641004, 0.48494193608557723`, 0.946519131275145], 
             UndirectedEdge[5, 296] -> 
             RGBColor[
              0.5051034219385223, 0.6067952551005944, 0.9548208552380348], 
             UndirectedEdge[42, 125] -> 
             RGBColor[
              0.7326697453640709, 0.79016025895499, 0.9713072669010926], 
             UndirectedEdge[12, 106] -> 
             RGBColor[
              0.9928951670508268, 0.9892783420568905, 0.6182763433460722], 
             UndirectedEdge[242, 357] -> 
             RGBColor[
              0.7049006499587711, 0.7619189499873247, 0.7549834407590172], 
             UndirectedEdge[148, 279] -> 
             RGBColor[
              0.4173650663629609, 0.5261745881030535, 0.9490679765364725], 
             UndirectedEdge[292, 374] -> 
             RGBColor[
              0.6790108798151212, 0.739957079014423, 0.7928669916091461], 
             UndirectedEdge[195, 369] -> 
             RGBColor[
              0.711920783879566, 0.7748771942558556, 0.9719212685252855], 
             UndirectedEdge[50, 371] -> 
             RGBColor[
              0.4644504772136764, 0.5556575444425814, 0.9545033183212315], 
             UndirectedEdge[29, 127] -> 
             RGBColor[
              0.9013599109420563, 0.9032039753459808, 0.6804170355543671], 
             UndirectedEdge[87, 127] -> 
             RGBColor[
              0.8700037369666398, 0.8991813805076085, 0.9874629271650244], 
             UndirectedEdge[264, 357] -> 
             RGBColor[
              0.6551486092505161, 0.7266475901669232, 0.968753448085534], 
             UndirectedEdge[171, 306] -> 
             RGBColor[
              0.4288024661009857, 0.5360370507161702, 0.9499158423804929], 
             UndirectedEdge[114, 170] -> 
             RGBColor[
              0.6117806662941179, 0.6951086953793331, 0.9629919664860713], 
             UndirectedEdge[57, 222] -> 
             RGBColor[
              0.3434869963665762, 0.46325290450985745`, 0.9435200180130854], 
             UndirectedEdge[38, 102] -> 
             RGBColor[
              0.5966170511714668, 0.6808072107900854, 0.962873500570986], 
             UndirectedEdge[82, 331] -> 
             RGBColor[
              0.5848336143067601, 0.6727354164501257, 0.9612100201719305], 
             UndirectedEdge[90, 324] -> 
             RGBColor[
              0.27149743880735244`, 0.4026914004913428, 0.9387727495443868], 
             UndirectedEdge[160, 341] -> 
             RGBColor[
              0.4527280119046602, 0.5635492677158974, 0.9508980653740233], 
             UndirectedEdge[15, 311] -> 
             RGBColor[
              0.6353684845143497, 0.7147049185745813, 0.9645435637678212], 
             UndirectedEdge[271, 292] -> 
             RGBColor[
              0.9571620153140487, 0.8552518481798794, 0.4478529534312601], 
             UndirectedEdge[41, 156] -> 
             RGBColor[
              0.6865874436085513, 0.753133294105018, 0.9710062208435237], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.4870557143082973, 0.5907226409420668, 0.9538557023137764], 
             UndirectedEdge[129, 317] -> 
             RGBColor[
              0.8137335938837609, 0.8524212433216571, 0.8512464865555969], 
             UndirectedEdge[164, 354] -> 
             RGBColor[
              0.7273056965403573, 0.7868960049561327, 0.9734546928391301], 
             UndirectedEdge[78, 230] -> 
             RGBColor[
              0.5768286785148673, 0.6526029216711309, 0.9641793161361443], 
             UndirectedEdge[315, 363] -> 
             RGBColor[
              0.8467170313577579, 0.8807145816300352, 0.9647719409215211], 
             UndirectedEdge[5, 121] -> 
             RGBColor[
              0.6087506348535217, 0.693250215134493, 0.9623422263841712], 
             UndirectedEdge[43, 380] -> 
             RGBColor[
              0.5814939303996349, 0.6596759155740659, 0.9641163282260314], 
             UndirectedEdge[135, 234] -> 
             RGBColor[
              0.3155276162204688, 0.4468259580034477, 0.941358703545984], 
             UndirectedEdge[344, 356] -> 
             RGBColor[
              0.7380184071457765, 0.7929728257910523, 0.9297541643641143], 
             UndirectedEdge[186, 228] -> 
             RGBColor[
              0.6261219821198313, 0.7071759097859849, 0.9638308792761487], 
             UndirectedEdge[298, 396] -> 
             RGBColor[
              0.6624525570317128, 0.7357576781291757, 0.9673151981603999], 
             UndirectedEdge[86, 93] -> 
             RGBColor[
              0.6504775317067343, 0.7215428113512665, 0.9689432930603981], 
             UndirectedEdge[249, 266] -> 
             RGBColor[
              0.6421554078699643, 0.7142059305685869, 0.9684722510418518], 
             UndirectedEdge[156, 364] -> 
             RGBColor[
              0.7741969843200874, 0.8241839094462288, 0.9779542762900694], 
             UndirectedEdge[10, 311] -> 
             RGBColor[
              0.4699556081712157, 0.5769948704640152, 0.952403636564959], 
             UndirectedEdge[27, 73] -> 
             RGBColor[
              0.6801485071125706, 0.7454320770282544, 0.949927878867677], 
             UndirectedEdge[56, 213] -> 
             RGBColor[
              0.7516045301992538, 0.7696615827342064, 0.6448991665428213], 
             UndirectedEdge[27, 243] -> 
             RGBColor[
              0.47936838368359613`, 0.5867804929849664, 0.952552276753329], 
             UndirectedEdge[109, 157] -> 
             RGBColor[
              0.849421487810109, 0.8826651919984103, 0.956834422492649], 
             UndirectedEdge[12, 241] -> 
             RGBColor[
              0.7895506689508536, 0.8331405127913913, 0.8640600969336674], 
             UndirectedEdge[192, 382] -> 
             RGBColor[
              0.4134268351053956, 0.5325112779565389, 0.9475641702472879], 
             UndirectedEdge[140, 280] -> 
             RGBColor[
              0.28935264932800564`, 0.42145835883428245`, 0.9397895773691212],
              UndirectedEdge[199, 361] -> 
             RGBColor[
              0.6358938503675695, 0.70756131729269, 0.9538272759188939], 
             UndirectedEdge[16, 351] -> 
             RGBColor[
              0.2641279462989493, 0.3911934309064046, 0.9384904530151477], 
             UndirectedEdge[140, 322] -> 
             RGBColor[
              0.6239650458701358, 0.6942879258778588, 0.9430676299290622], 
             UndirectedEdge[57, 238] -> 
             RGBColor[
              0.32489288744198364`, 0.44370931709551276`, 0.9424611110173489],
              UndirectedEdge[49, 127] -> 
             RGBColor[
              0.8790731877104105, 0.9064128115013355, 0.9883174796237462], 
             UndirectedEdge[165, 182] -> 
             RGBColor[
              0.6913548848171176, 0.756374143658296, 0.9686757581958301], 
             UndirectedEdge[253, 343] -> 
             RGBColor[
              0.6154314439222275, 0.685012747723071, 0.9408287770974944], 
             UndirectedEdge[104, 240] -> 
             RGBColor[
              0.8626744698612738, 0.8917213345248906, 0.8977807875641731], 
             UndirectedEdge[312, 348] -> 
             RGBColor[
              0.4669281350450576, 0.5688839161854506, 0.9529627677181038], 
             UndirectedEdge[242, 244] -> 
             RGBColor[
              0.9898062591006153, 0.9887399758253884, 0.7231833387763327], 
             UndirectedEdge[41, 165] -> 
             RGBColor[
              0.45778417426042006`, 0.5704235726094287, 0.9505308881726553], 
             UndirectedEdge[54, 297] -> 
             RGBColor[
              0.6756550453191338, 0.7406201248240165, 0.9362155495431679], 
             UndirectedEdge[77, 145] -> 
             RGBColor[
              0.6957693887694447, 0.7551903347894033, 0.844957939105414], 
             UndirectedEdge[69, 150] -> 
             RGBColor[
              0.7052334721320646, 0.7659434006020812, 0.9337792787070469], 
             UndirectedEdge[106, 241] -> 
             RGBColor[
              0.7895593019872595, 0.8310924415939867, 0.7147843696314451], 
             UndirectedEdge[139, 276] -> 
             RGBColor[
              0.2782418934664579, 0.40345133680164147`, 0.9393885687734147], 
             UndirectedEdge[313, 393] -> 
             RGBColor[
              0.5788593961813592, 0.656265853998876, 0.9640634023478059], 
             UndirectedEdge[209, 323] -> 
             RGBColor[
              0.8891606673488825, 0.9144565967933862, 0.9892901322864764], 
             UndirectedEdge[8, 213] -> 
             RGBColor[
              0.6246285138275661, 0.659267195894834, 0.636295807016545], 
             UndirectedEdge[160, 244] -> 
             RGBColor[
              0.6637012413043153, 0.729336496420312, 0.9135573986362506], 
             UndirectedEdge[180, 284] -> 
             RGBColor[
              0.431547764660208, 0.5470140778723668, 0.9490483494203454], 
             UndirectedEdge[24, 242] -> 
             RGBColor[
              0.725325873090439, 0.779513226914617, 0.7563117261425524], 
             UndirectedEdge[81, 192] -> 
             RGBColor[
              0.5293370940334776, 0.6275403184607296, 0.9564670169788471], 
             UndirectedEdge[124, 249] -> 
             RGBColor[
              0.3368884357929387, 0.46621756340389275`, 0.9426872111233472], 
             UndirectedEdge[195, 253] -> 
             RGBColor[
              0.46334521326255695`, 0.5657946636129156, 0.9526516058940702], 
             UndirectedEdge[31, 81] -> 
             RGBColor[
              0.5704584541671, 0.6620786077757013, 0.9593853552085757], 
             UndirectedEdge[172, 399] -> 
             RGBColor[
              0.7083887622212175, 0.768990739287206, 0.9385685970624855], 
             UndirectedEdge[124, 315] -> 
             RGBColor[
              0.6383239623660052, 0.709284292114476, 0.9484090077888561], 
             UndirectedEdge[181, 370] -> 
             RGBColor[
              0.6742826154504636, 0.7436871071539934, 0.9694120653318831], 
             UndirectedEdge[244, 348] -> 
             RGBColor[
              0.8261113395776299, 0.8638552575821996, 0.9257558900736403], 
             UndirectedEdge[284, 367] -> 
             RGBColor[
              0.5061311003913365, 0.6099390541007463, 0.9542636407235672], 
             UndirectedEdge[148, 232] -> 
             RGBColor[
              0.33620522745507964`, 0.45961600386586465`, 0.9428637258665341],
              UndirectedEdge[34, 211] -> 
             RGBColor[
              0.6671350163678955, 0.7377933540492674, 0.9689541311904597], 
             UndirectedEdge[355, 392] -> 
             RGBColor[
              0.31359770788940083`, 0.4340416519735402, 0.9416426224792986], 
             UndirectedEdge[262, 338] -> 
             RGBColor[
              0.43175632040772194`, 0.5419855021420379, 0.9498252029934606], 
             UndirectedEdge[87, 119] -> 
             RGBColor[
              0.6176783534188905, 0.6933909533197065, 0.9667349819894483], 
             UndirectedEdge[180, 367] -> 
             RGBColor[
              0.4404369055935423, 0.5542306829332831, 0.9497481351566136], 
             UndirectedEdge[69, 380] -> 
             RGBColor[
              0.35171271329930587`, 0.4757398772074908, 0.9437532793354073], 
             UndirectedEdge[124, 338] -> 
             RGBColor[
              0.2982549578394379, 0.42993586665270767`, 0.9403287491835516], 
             UndirectedEdge[249, 293] -> 
             RGBColor[
              0.37456655682663215`, 0.4988524580858514, 0.9450880276781599], 
             UndirectedEdge[212, 373] -> 
             RGBColor[
              0.7139146565269554, 0.7757419001946744, 0.9726704886641551], 
             UndirectedEdge[287, 292] -> 
             RGBColor[
              0.7093883680814991, 0.766268532533805, 0.7948026182997215], 
             UndirectedEdge[12, 323] -> 
             RGBColor[
              0.9337995027702952, 0.9471312054422392, 0.877732060559572], 
             UndirectedEdge[120, 307] -> 
             RGBColor[
              0.4095927760490423, 0.5279380165108627, 0.9476659070899331], 
             UndirectedEdge[99, 398] -> 
             RGBColor[
              0.8447848421289379, 0.8777775737277721, 0.8974375031905741], 
             UndirectedEdge[134, 350] -> 
             RGBColor[
              0.5182662641451459, 0.6170211735714839, 0.95615527640727], 
             UndirectedEdge[45, 280] -> 
             RGBColor[
              0.6437741247809496, 0.7073127492377798, 0.7232889163056804], 
             UndirectedEdge[188, 330] -> 
             RGBColor[
              0.2998450396510218, 0.4273270916750208, 0.940576015652375], 
             UndirectedEdge[236, 284] -> 
             RGBColor[
              0.6856093575750919, 0.7525359034172325, 0.9707028661125607], 
             UndirectedEdge[374, 389] -> 
             RGBColor[
              0.6029009120984526, 0.6831810818762711, 0.9646012388441483], 
             UndirectedEdge[278, 319] -> 
             RGBColor[
              0.5571557043417367, 0.6465705170850314, 0.960383292941908], 
             UndirectedEdge[78, 242] -> 
             RGBColor[
              0.6200940676545046, 0.6827020016061829, 0.7497906061923104], 
             UndirectedEdge[84, 189] -> 
             RGBColor[
              0.27975207680097836`, 0.40910772431739617`, 0.9393255821960547],
              UndirectedEdge[223, 385] -> 
             RGBColor[
              0.44654639308561445`, 0.5601321046771162, 0.9499689669264093], 
             UndirectedEdge[175, 278] -> 
             RGBColor[
              0.8640075033643205, 0.8941776259454618, 0.9642475790495896], 
             UndirectedEdge[151, 168] -> 
             RGBColor[
              0.7787755773257239, 0.8268588103321242, 0.9552972033055455], 
             UndirectedEdge[322, 339] -> 
             RGBColor[
              0.9747440774661521, 0.9803904448416684, 0.9144560652304963], 
             UndirectedEdge[177, 367] -> 
             RGBColor[
              0.7518874224474377, 0.803386706495753, 0.895496138831003], 
             UndirectedEdge[294, 320] -> 
             RGBColor[
              0.49881304547843497`, 0.5894283610675451, 0.9568316886801798], 
             UndirectedEdge[179, 279] -> 
             RGBColor[
              0.42783795388305823`, 0.5371822569060964, 0.9496643919874934], 
             UndirectedEdge[18, 285] -> 
             RGBColor[
              0.8839121038992166, 0.9101192919693833, 0.9835111662519251], 
             UndirectedEdge[121, 296] -> 
             RGBColor[
              0.47190871499229364`, 0.5798462965971395, 0.9522076463110096], 
             UndirectedEdge[212, 351] -> 
             RGBColor[
              0.596003507059219, 0.6771927691488846, 0.9641682458001029], 
             UndirectedEdge[29, 87] -> 
             RGBColor[
              0.9489280164975771, 0.941133491514125, 0.6849541239268018], 
             UndirectedEdge[99, 141] -> 
             RGBColor[
              0.8167176684119706, 0.8576615159885278, 0.9821233115355428], 
             UndirectedEdge[121, 274] -> 
             RGBColor[
              0.5402926235171488, 0.6376729175333598, 0.9569529609618137], 
             UndirectedEdge[138, 218] -> 
             RGBColor[
              0.497799951549184, 0.6029880646282296, 0.9536595579011495], 
             UndirectedEdge[61, 388] -> 
             RGBColor[
              0.5627910297223417, 0.6379471201735973, 0.9633649468838297], 
             UndirectedEdge[283, 347] -> 
             RGBColor[
              0.5763694134189935, 0.6524827031210209, 0.9640982456881322], 
             UndirectedEdge[253, 315] -> 
             RGBColor[
              0.6118626143571659, 0.6823511204768702, 0.9468698746513196], 
             UndirectedEdge[321, 366] -> 
             RGBColor[
              0.6588097375285757, 0.6404585504711349, 0.6054918981728061], 
             UndirectedEdge[164, 391] -> 
             RGBColor[
              0.5586873745646271, 0.6509768730941786, 0.9591774145079099], 
             UndirectedEdge[74, 91] -> 
             RGBColor[
              0.4567578276517409, 0.5546423169830883, 0.9529459113564194], 
             UndirectedEdge[91, 285] -> 
             RGBColor[
              0.5235208086973803, 0.6068484798223963, 0.9595868428790885], 
             UndirectedEdge[51, 183] -> 
             RGBColor[
              0.5481580863855393, 0.6418574133338499, 0.9585062942295803], 
             UndirectedEdge[30, 54] -> 
             RGBColor[
              0.7354375024888617, 0.7912447088162085, 0.9403442343680588], 
             UndirectedEdge[68, 250] -> 
             RGBColor[
              0.703671154105912, 0.7442258104476112, 0.6623913017058249], 
             UndirectedEdge[32, 230] -> 
             RGBColor[
              0.6074267995077901, 0.6847634868676147, 0.9659218338608276], 
             UndirectedEdge[275, 318] -> 
             RGBColor[
              0.3415788371674639, 0.46605933392458, 0.9431406242259299], 
             UndirectedEdge[131, 186] -> 
             RGBColor[
              0.44307840002079313`, 0.5523235299846136, 0.9506121794463512], 
             UndirectedEdge[192, 292] -> 
             RGBColor[
              0.7026500076454756, 0.7604321034039645, 0.7943732559312362], 
             UndirectedEdge[144, 200] -> 
             RGBColor[
              0.4948971513273804, 0.586785180178243, 0.9563755386890818], 
             UndirectedEdge[139, 318] -> 
             RGBColor[
              0.29967430895800684`, 0.42201501787589685`, 0.9407542233365953],
              UndirectedEdge[93, 148] -> 
             RGBColor[
              0.3098252637676446, 0.43676700521533546`, 0.9411828179072568], 
             UndirectedEdge[92, 311] -> 
             RGBColor[
              0.49944645367907275`, 0.6025383585899273, 0.9542827671629889], 
             UndirectedEdge[334, 370] -> 
             RGBColor[
              0.8581921171430054, 0.8897631154781214, 0.9863363243218888], 
             UndirectedEdge[62, 129] -> 
             RGBColor[
              0.8351928748954374, 0.8693316302134633, 0.8532853665171114], 
             UndirectedEdge[97, 191] -> 
             RGBColor[
              0.730155033855211, 0.789121928922262, 0.9737386881541036], 
             UndirectedEdge[120, 366] -> 
             RGBColor[
              0.4418240319991681, 0.5558551104248343, 0.9497196542180946], 
             UndirectedEdge[91, 288] -> 
             RGBColor[
              0.37244486759576767`, 0.4869643478726923, 0.9457812877668622], 
             UndirectedEdge[21, 32] -> 
             RGBColor[
              0.5212189675127028, 0.6167120994349281, 0.9575165742896894], 
             UndirectedEdge[121, 178] -> 
             RGBColor[
              0.7833165242740174, 0.8284397154777572, 0.8786338751595053], 
             UndirectedEdge[294, 381] -> 
             RGBColor[
              0.669769166581219, 0.7409476198163383, 0.9684039754618501], 
             UndirectedEdge[46, 149] -> 
             RGBColor[
              0.7250198736493175, 0.7845403421624475, 0.9737948099373425], 
             UndirectedEdge[66, 232] -> 
             RGBColor[
              0.5470765891496115, 0.6421567751294935, 0.9579142059317093], 
             UndirectedEdge[114, 261] -> 
             RGBColor[
              0.5006816939346713, 0.6012866677794071, 0.9552479653031158], 
             UndirectedEdge[189, 395] -> 
             RGBColor[
              0.29578416302694654`, 0.42595846343386534`, 0.9402385857892773],
              UndirectedEdge[54, 290] -> 
             RGBColor[
              0.9217015056611992, 0.7381347983463228, 0.5695747121797556], 
             UndirectedEdge[4, 309] -> 
             RGBColor[
              0.7108243172998976, 0.7737183835882139, 0.9720186279288232], 
             UndirectedEdge[195, 315] -> 
             RGBColor[
              0.8098732431653707, 0.8519319342709808, 0.9610996964392803], 
             UndirectedEdge[181, 305] -> 
             RGBColor[
              0.6755364273594926, 0.7446868627364356, 0.9695316550310573], 
             UndirectedEdge[153, 372] -> 
             RGBColor[
              0.6592500102776411, 0.7290946041386919, 0.9695236682646116], 
             UndirectedEdge[175, 227] -> 
             RGBColor[
              0.5908190098155927, 0.6598501499438265, 0.9434773323045162], 
             UndirectedEdge[271, 287] -> 
             RGBColor[
              0.6720631376177923, 0.6309032796330878, 0.6013066641677896], 
             UndirectedEdge[232, 297] -> 
             RGBColor[
              0.40249618435797363`, 0.5230436976696028, 0.9468676788472571], 
             UndirectedEdge[21, 25] -> 
             RGBColor[
              0.5341062717514663, 0.6279781732250591, 0.9583339435419125], 
             UndirectedEdge[123, 297] -> 
             RGBColor[
              0.6694003660648966, 0.6927275208930733, 0.6269595008563937], 
             UndirectedEdge[6, 178] -> 
             RGBColor[
              0.769896885872966, 0.8175450484759631, 0.8775774320668193], 
             UndirectedEdge[90, 319] -> 
             RGBColor[
              0.29356786849926475`, 0.4223339410495277, 0.9401597894503058], 
             UndirectedEdge[258, 302] -> 
             RGBColor[
              0.7804074487471884, 0.8264850906075026, 0.8954229756666442], 
             UndirectedEdge[253, 397] -> 
             RGBColor[
              0.26962770918535944`, 0.4007261961109231, 0.9386662712084315], 
             UndirectedEdge[169, 177] -> 
             RGBColor[
              0.9898089277005, 0.9852297491119679, 0.6275173696026343], 
             UndirectedEdge[198, 332] -> 
             RGBColor[
              0.8353461160176434, 0.8711051919088474, 0.9282931563055057], 
             UndirectedEdge[45, 123] -> 
             RGBColor[
              0.9778611676855842, 0.9365226340144691, 0.4076126663571442], 
             UndirectedEdge[223, 245] -> 
             RGBColor[
              0.4945755599438439, 0.5991243460219366, 0.9537499988781244], 
             UndirectedEdge[380, 381] -> 
             RGBColor[
              0.4249572534274985, 0.5358209317969805, 0.949348647555337], 
             UndirectedEdge[277, 378] -> 
             RGBColor[
              0.6488464817304689, 0.7235623332063356, 0.9670298744648506], 
             UndirectedEdge[119, 326] -> 
             RGBColor[
              0.30074699672292693`, 0.43259883562511847`, 0.9404690678420677],
              UndirectedEdge[89, 133] -> 
             RGBColor[
              0.4222208927500507, 0.5386173364459055, 0.9485419893778708], 
             UndirectedEdge[22, 346] -> 
             RGBColor[
              0.6380581675597223, 0.7149394743538595, 0.9660878816581828], 
             UndirectedEdge[73, 243] -> 
             RGBColor[
              0.7589155924577293, 0.8108101273739997, 0.9557332172353319], 
             UndirectedEdge[26, 353] -> 
             RGBColor[
              0.4939561323196311, 0.5907443614272655, 0.955538568158389], 
             UndirectedEdge[21, 230] -> 
             RGBColor[
              0.8210217889455851, 0.8608129024861135, 0.9826083056392684], 
             UndirectedEdge[107, 390] -> 
             RGBColor[
              0.9058357609808612, 0.9267175647752908, 0.9549861497345955], 
             UndirectedEdge[223, 364] -> 
             RGBColor[
              0.5238830325847539, 0.6228427160251777, 0.956108301958638], 
             UndirectedEdge[2, 211] -> 
             RGBColor[
              0.41555769529536, 0.533207852578563, 0.9480174380661411], 
             UndirectedEdge[128, 353] -> 
             RGBColor[
              0.8548556526017427, 0.8842588243575152, 0.8245330975119058], 
             UndirectedEdge[259, 331] -> 
             RGBColor[
              0.4184936278119561, 0.5368368634693808, 0.9479044332142041], 
             UndirectedEdge[2, 334] -> 
             RGBColor[
              0.6129034192961758, 0.6901919914674648, 0.9659994456947582], 
             UndirectedEdge[72, 191] -> 
             RGBColor[
              0.590917445979543, 0.6751655078772887, 0.9628087125272176], 
             UndirectedEdge[247, 301] -> 
             RGBColor[
              0.43488796427835025`, 0.5443681814224243, 0.9500862771152818], 
             UndirectedEdge[247, 397] -> 
             RGBColor[
              0.4333897811804909, 0.5427934959962792, 0.9500009578042221], 
             UndirectedEdge[125, 263] -> 
             RGBColor[
              0.820204881818341, 0.8603325881450994, 0.9788086549678416], 
             UndirectedEdge[123, 325] -> 
             RGBColor[
              0.6135822966821, 0.6403074958923781, 0.6235519633266917], 
             UndirectedEdge[129, 393] -> 
             RGBColor[
              0.6285968428009672, 0.6926666908106444, 0.8382595392853192], 
             UndirectedEdge[19, 205] -> 
             RGBColor[
              0.7411235906696689, 0.7977003908355373, 0.9748293461722184], 
             UndirectedEdge[277, 352] -> 
             RGBColor[
              0.7793940947477265, 0.8275878575222183, 0.978646377578684], 
             UndirectedEdge[139, 224] -> 
             RGBColor[
              0.29600838789080414`, 0.41883978130203614`, 0.9405206340878399],
              UndirectedEdge[65, 250] -> 
             RGBColor[
              0.7338550693694267, 0.7694324163411781, 0.6645735409434157], 
             UndirectedEdge[58, 117] -> 
             RGBColor[
              0.729614605319371, 0.788198631469878, 0.9742393036277457], 
             UndirectedEdge[134, 272] -> 
             RGBColor[
              0.3103454513280695, 0.4381583766988532, 0.9411815160932294], 
             UndirectedEdge[74, 95] -> 
             RGBColor[
              0.46391790448738757`, 0.5621680117124448, 0.9533536671398251], 
             UndirectedEdge[156, 245] -> 
             RGBColor[
              0.7448895116791774, 0.8004655394429877, 0.9755959732095558], 
             UndirectedEdge[221, 324] -> 
             RGBColor[
              0.3102102676297983, 0.44258403137359936`, 0.9410065701965047], 
             UndirectedEdge[227, 375] -> 
             RGBColor[
              0.39874305439694224`, 0.5083047275286658, 0.9478524578718321], 
             UndirectedEdge[132, 348] -> 
             RGBColor[
              0.46562137867688713`, 0.5675104323893643, 0.9528883498761094], 
             UndirectedEdge[137, 319] -> 
             RGBColor[
              0.3201395464367107, 0.45026245930347075`, 0.9416730071995685], 
             UndirectedEdge[128, 170] -> 
             RGBColor[
              0.7683771242352833, 0.8151628628107905, 0.8169654550112306], 
             UndirectedEdge[120, 220] -> 
             RGBColor[
              0.7206185812511368, 0.7803100457698908, 0.9685739881072681], 
             UndirectedEdge[292, 371] -> 
             RGBColor[
              0.5891463303583426, 0.6505693122453919, 0.787563863038498], 
             UndirectedEdge[143, 378] -> 
             RGBColor[
              0.43615875275209026`, 0.5506848095157609, 0.9494314239475257], 
             UndirectedEdge[59, 373] -> 
             RGBColor[
              0.4478269242424727, 0.5587273259318484, 0.9507451621930016], 
             UndirectedEdge[2, 340] -> 
             RGBColor[
              0.5581438589146326, 0.6468448359536116, 0.9606924056697311], 
             UndirectedEdge[131, 322] -> 
             RGBColor[
              0.6256803088606693, 0.6960907760348646, 0.943165311618869], 
             UndirectedEdge[62, 317] -> 
             RGBColor[
              0.654272220702986, 0.7296954650880951, 0.9662753791256432], 
             UndirectedEdge[243, 337] -> 
             RGBColor[
              0.4518685725432873, 0.5629615387559275, 0.9508000131045968], 
             UndirectedEdge[21, 217] -> 
             RGBColor[
              0.7619975456344457, 0.813997541136253, 0.9769124521430668], 
             UndirectedEdge[24, 74] -> 
             RGBColor[
              0.5747933953336033, 0.664911108217407, 0.9601961866250981], 
             UndirectedEdge[1, 127] -> 
             RGBColor[
              0.9086211149981367, 0.926276014391783, 0.8295171643120542], 
             UndirectedEdge[226, 355] -> 
             RGBColor[
              0.38483669696687095`, 0.5077479372830738, 0.9457424319263676], 
             UndirectedEdge[97, 370] -> 
             RGBColor[
              0.7519990146027149, 0.8062356859204562, 0.9759028694882567], 
             UndirectedEdge[148, 257] -> 
             RGBColor[
              0.3935196975240931, 0.5068158434580363, 0.9471907817530126], 
             UndirectedEdge[48, 344] -> 
             RGBColor[
              0.6785551645576755, 0.7425062476764873, 0.9256785564703007], 
             UndirectedEdge[74, 148] -> 
             RGBColor[
              0.4682201556520828, 0.5666899504650182, 0.9535986739790442], 
             UndirectedEdge[266, 293] -> 
             RGBColor[
              0.6612023735827496, 0.7307034549406695, 0.9696859068545], 
             UndirectedEdge[84, 226] -> 
             RGBColor[
              0.27386059736313456`, 0.40400482094270235`, 0.9389501823359059],
              UndirectedEdge[354, 371] -> 
             RGBColor[
              0.4719066893006132, 0.5614823939942072, 0.9552464838597937], 
             UndirectedEdge[57, 188] -> 
             RGBColor[
              0.4161967452959016, 0.5345160260542038, 0.9478496428266348], 
             UndirectedEdge[134, 355] -> 
             RGBColor[
              0.4075193852989937, 0.5273945418512941, 0.9471877527693767], 
             UndirectedEdge[151, 378] -> 
             RGBColor[
              0.5523692835068162, 0.6474772941603044, 0.9579036798744633], 
             UndirectedEdge[167, 238] -> 
             RGBColor[
              0.4666149171313697, 0.5570969944630393, 0.9547588540313573], 
             UndirectedEdge[41, 311] -> 
             RGBColor[
              0.5451441875529927, 0.641611635778127, 0.9573348938545798], 
             UndirectedEdge[212, 295] -> 
             RGBColor[
              0.7198000255220313, 0.7805199078777287, 0.9731338064702644], 
             UndirectedEdge[179, 285] -> 
             RGBColor[
              0.5454560242178195, 0.6299037821073692, 0.9608360209527341], 
             UndirectedEdge[85, 348] -> 
             RGBColor[
              0.6598685266388695, 0.734213575287616, 0.966733185979533], 
             UndirectedEdge[108, 152] -> 
             RGBColor[
              0.5545191038691664, 0.648764235089708, 0.9583202394745891], 
             UndirectedEdge[86, 148] -> 
             RGBColor[
              0.5843971355369796, 0.6582974946714835, 0.9649527568233991], 
             UndirectedEdge[113, 293] -> 
             RGBColor[
              0.6359686882348221, 0.7105827991943741, 0.9672790954196377], 
             UndirectedEdge[229, 260] -> 
             RGBColor[
              0.7279192264367189, 0.7871399927297038, 0.9737401171286227], 
             UndirectedEdge[6, 278] -> 
             RGBColor[
              0.6579164885836251, 0.7312541469689635, 0.9675193878050712], 
             UndirectedEdge[142, 378] -> 
             RGBColor[
              0.40608742787859, 0.5241104546676664, 0.9475346414843215], 
             UndirectedEdge[289, 303] -> 
             RGBColor[
              0.68367827842115, 0.748674969112946, 0.9528612480328117], 
             UndirectedEdge[5, 213] -> 
             RGBColor[
              0.8053745398570076, 0.8133144988857015, 0.6491321386691151], 
             UndirectedEdge[104, 243] -> 
             RGBColor[
              0.7738903201114635, 0.8210722848798047, 0.8898137280394396], 
             UndirectedEdge[121, 373] -> 
             RGBColor[
              0.5803535597203322, 0.6701961902677134, 0.9601067046077728], 
             UndirectedEdge[120, 202] -> 
             RGBColor[
              0.5873894234470962, 0.6754030526977419, 0.9610059801764278], 
             UndirectedEdge[270, 351] -> 
             RGBColor[
              0.29894917934972565`, 0.42779275463646216`, 0.9404734707239915],
              UndirectedEdge[91, 125] -> 
             RGBColor[
              0.5802999681926955, 0.6520174097185737, 0.961354076891046], 
             UndirectedEdge[280, 297] -> 
             RGBColor[
              0.33531332316026213`, 0.46351763611638397`, 0.9426357508049299],
              UndirectedEdge[33, 281] -> 
             RGBColor[
              0.6928348780908695, 0.756936574120989, 0.9582698844531152], 
             UndirectedEdge[16, 241] -> 
             RGBColor[
              0.3825709019436432, 0.49017430616424373`, 0.9470345616095202], 
             UndirectedEdge[89, 342] -> 
             RGBColor[
              0.29311758300195845`, 0.4229439823646577, 0.9400944807082336], 
             UndirectedEdge[157, 370] -> 
             RGBColor[
              0.8968018368261911, 0.9197281539716049, 0.9615438303648847], 
             UndirectedEdge[90, 122] -> 
             RGBColor[
              0.40989435891978454`, 0.519654512436345, 0.9485212737229114], 
             UndirectedEdge[135, 156] -> 
             RGBColor[
              0.6165447783192339, 0.6929736609366322, 0.9664028566495213], 
             UndirectedEdge[12, 22] -> 
             RGBColor[
              0.7446505479007897, 0.796688571795547, 0.8605253949300435], 
             UndirectedEdge[271, 384] -> 
             RGBColor[
              0.9543963172379145, 0.8547937847623261, 0.5435253412786871], 
             UndirectedEdge[158, 324] -> 
             RGBColor[
              0.3022912709702298, 0.43505767053625366`, 0.9405264127306705], 
             UndirectedEdge[301, 397] -> 
             RGBColor[
              0.2754190170142261, 0.40681322782918616`, 0.9389960776218133], 
             UndirectedEdge[95, 233] -> 
             RGBColor[
              0.5535300764688582, 0.6325934991792193, 0.9621739748916672], 
             UndirectedEdge[123, 203] -> 
             RGBColor[
              0.7423874002126478, 0.7540721753354385, 0.6321276983509541], 
             UndirectedEdge[103, 145] -> 
             RGBColor[
              0.6855072698767064, 0.7463018031936062, 0.8443040459640041], 
             UndirectedEdge[20, 80] -> 
             RGBColor[
              0.2716369100646565, 0.3977211592838297, 0.9389680445968517], 
             UndirectedEdge[73, 337] -> 
             RGBColor[
              0.6526486959722618, 0.7216131227992155, 0.9481756152189447], 
             UndirectedEdge[122, 166] -> 
             RGBColor[
              0.7653257965180473, 0.8163078695289225, 0.9641139407073636], 
             UndirectedEdge[62, 216] -> 
             RGBColor[
              0.6594480452021736, 0.7338850919934921, 0.9666912763195455], 
             UndirectedEdge[128, 342] -> 
             RGBColor[
              0.6227852563810515, 0.6861033544579009, 0.8072199066478996], 
             UndirectedEdge[280, 309] -> 
             RGBColor[
              0.45846429518389087`, 0.5655876351860347, 0.9517530372456383], 
             UndirectedEdge[104, 141] -> 
             RGBColor[
              0.9614916392597801, 0.9698342573474432, 0.9073868284534985], 
             UndirectedEdge[148, 276] -> 
             RGBColor[
              0.3104717477672501, 0.4373269571625632, 0.9412240112960482], 
             UndirectedEdge[359, 394] -> 
             RGBColor[
              0.2552879517116369, 0.3856542018129044, 0.937849643234073], 
             UndirectedEdge[8, 43] -> 
             RGBColor[
              0.5852896255796038, 0.6636654318691875, 0.9643324874513028], 
             UndirectedEdge[56, 352] -> 
             RGBColor[
              0.652320546626536, 0.7266633232795106, 0.96711152624624], 
             UndirectedEdge[70, 152] -> 
             RGBColor[
              0.8141178388048069, 0.8551035295722951, 0.9542175527261756], 
             UndirectedEdge[359, 397] -> 
             RGBColor[
              0.2746781860355706, 0.40603456749922223`, 0.93895388839354], 
             UndirectedEdge[118, 241] -> 
             RGBColor[
              0.5831656477085613, 0.672479169979678, 0.9603280824752239], 
             UndirectedEdge[43, 227] -> 
             RGBColor[
              0.5554326501914721, 0.6322838576946845, 0.9626321768723857], 
             UndirectedEdge[234, 246] -> 
             RGBColor[
              0.2832103060214743, 0.41500236657205897`, 0.9394397800045968], 
             UndirectedEdge[196, 317] -> 
             RGBColor[
              0.4544891607839625, 0.5601913914090559, 0.9516375405803537], 
             UndirectedEdge[46, 184] -> 
             RGBColor[
              0.9110427104595147, 0.931551924191357, 0.9791447769272724], 
             UndirectedEdge[136, 331] -> 
             RGBColor[
              0.6151107871767867, 0.696388174011227, 0.9642277658073475], 
             UndirectedEdge[106, 320] -> 
             RGBColor[
              0.6140220826778661, 0.6758540409449456, 0.7028514420178348], 
             UndirectedEdge[68, 161] -> 
             RGBColor[
              0.5177807237667977, 0.6186947994537393, 0.9553746908889379], 
             UndirectedEdge[45, 297] -> 
             RGBColor[
              0.6847875830243655, 0.7441721892644245, 0.7258533531324541], 
             UndirectedEdge[140, 203] -> 
             RGBColor[
              0.40335314171917247`, 0.5196624533032923, 0.9475222116904551], 
             UndirectedEdge[225, 243] -> 
             RGBColor[
              0.7152441575152028, 0.7766065198089859, 0.9730223012014211], 
             UndirectedEdge[107, 373] -> 
             RGBColor[
              0.710487998815206, 0.7730095763494711, 0.9723436509925949], 
             UndirectedEdge[187, 321] -> 
             RGBColor[
              0.8407939485494231, 0.7884571513876875, 0.6204081117129492], 
             UndirectedEdge[297, 322] -> 
             RGBColor[
              0.6699257197023922, 0.7363472031599603, 0.945913803364871], 
             UndirectedEdge[106, 374] -> 
             RGBColor[
              0.6782191569698599, 0.7382636639038674, 0.706692845849475], 
             UndirectedEdge[154, 383] -> 
             RGBColor[
              0.6778685621683356, 0.740501807229938, 0.8738194702860664], 
             UndirectedEdge[111, 151] -> 
             RGBColor[
              0.45692765137567454`, 0.5663262624111636, 0.9514034274619526], 
             UndirectedEdge[79, 227] -> 
             RGBColor[
              0.369126371311554, 0.48426056998357925`, 0.9455209240898657], 
             UndirectedEdge[93, 290] -> 
             RGBColor[
              0.622162681012604, 0.4977093725413799, 0.5785459335245673], 
             UndirectedEdge[150, 283] -> 
             RGBColor[
              0.6141352105289695, 0.6814562144108869, 0.9281789788999836], 
             UndirectedEdge[46, 195] -> 
             RGBColor[
              0.767030156718622, 0.8183551751077933, 0.9773009766525432], 
             UndirectedEdge[73, 177] -> 
             RGBColor[
              0.9742251597284544, 0.9795397326235654, 0.8945688352759252], 
             UndirectedEdge[102, 189] -> 
             RGBColor[
              0.5494780436639604, 0.6399777717624904, 0.9598698446959953], 
             UndirectedEdge[3, 95] -> 
             RGBColor[
              0.20979811642747764`, 0.3378415007071112, 0.9352590644108207], 
             UndirectedEdge[39, 294] -> 
             RGBColor[
              0.7990412418961235, 0.36087763703489495`, 0.4351323697895133], 
             UndirectedEdge[5, 227] -> 
             RGBColor[
              0.4313423403821771, 0.5347702964725773, 0.9504187930797092], 
             UndirectedEdge[166, 169] -> 
             RGBColor[
              0.9708333907022184, 0.9718358389093587, 0.6935834296635831], 
             UndirectedEdge[27, 337] -> 
             RGBColor[
              0.37310148719812863`, 0.4975834884101822, 0.9449946747369419], 
             UndirectedEdge[84, 174] -> 
             RGBColor[
              0.266477435652149, 0.3974150588886406, 0.9384868677911272], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.5859067670072104, 0.6483602066271477, 0.8505265353241472], 
             UndirectedEdge[138, 349] -> 
             RGBColor[
              0.39646405474243845`, 0.5092062052896701, 0.9474225723387766], 
             UndirectedEdge[26, 159] -> 
             RGBColor[
              0.5142183416704311, 0.6065733533706053, 0.9575581158253648], 
             UndirectedEdge[81, 287] -> 
             RGBColor[
              0.536075454469501, 0.6333767475905699, 0.9568963793473324], 
             UndirectedEdge[311, 361] -> 
             RGBColor[
              0.4690056437634491, 0.5761720590406072, 0.9523431056729166], 
             UndirectedEdge[231, 393] -> 
             RGBColor[
              0.253142152561806, 0.383398830854908, 0.9377274431469156], 
             UndirectedEdge[201, 223] -> 
             RGBColor[
              0.5961926220807868, 0.6793315169127133, 0.9633154460680695], 
             UndirectedEdge[180, 267] -> 
             RGBColor[
              0.34365208152802074`, 0.47207589338890155`, 0.9431181846487295],
              UndirectedEdge[217, 264] -> 
             RGBColor[
              0.8417187260609151, 0.87687664868359, 0.9846990090968879], 
             UndirectedEdge[163, 174] -> 
             RGBColor[
              0.36061993761311684`, 0.48657775903206435`, 0.9442064954251577],
              UndirectedEdge[203, 280] -> 
             RGBColor[
              0.40830035730801323`, 0.524862290558749, 0.9478039482994901], 
             UndirectedEdge[40, 163] -> 
             RGBColor[
              0.3110567765361968, 0.43448373425430775`, 0.9413839467239531], 
             UndirectedEdge[14, 62] -> 
             RGBColor[
              0.7782116069147875, 0.827154766876693, 0.9783983074315462], 
             UndirectedEdge[49, 133] -> 
             RGBColor[
              0.7223372408329731, 0.7819062376522299, 0.9740978783801277], 
             UndirectedEdge[276, 288] -> 
             RGBColor[
              0.45063407576546977`, 0.562817249981633, 0.9504657800152774], 
             UndirectedEdge[312, 366] -> 
             RGBColor[
              0.3258455654830103, 0.4528379884405012, 0.9421232475510029], 
             UndirectedEdge[23, 120] -> 
             RGBColor[
              0.7464822625181834, 0.7980491045237127, 0.8553799048477346], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.7462857437068455, 0.8017233620562945, 0.9753464465620605], 
             UndirectedEdge[73, 399] -> 
             RGBColor[
              0.700897137692533, 0.7634034979801225, 0.9512499632609386], 
             UndirectedEdge[269, 272] -> 
             RGBColor[
              0.461099930004499, 0.5625005592563345, 0.9526716330422614], 
             UndirectedEdge[20, 151] -> 
             RGBColor[
              0.38739144360685207`, 0.49411868206196563`, 0.9474112447846295],
              UndirectedEdge[239, 355] -> 
             RGBColor[
              0.6754807479279613, 0.6068615659166934, 0.5951506522875645], 
             UndirectedEdge[274, 319] -> 
             RGBColor[
              0.4261122008742091, 0.5420946206476336, 0.9487604230059645], 
             UndirectedEdge[6, 352] -> 
             RGBColor[
              0.6594762109370099, 0.7324726139257569, 0.9676748463528226], 
             UndirectedEdge[133, 342] -> 
             RGBColor[
              0.379860427908152, 0.4965653625600053, 0.9460391276357156], 
             UndirectedEdge[290, 318] -> 
             RGBColor[
              0.6442415805037585, 0.516833005562863, 0.5799527814765395], 
             UndirectedEdge[87, 298] -> 
             RGBColor[
              0.8155485622170481, 0.8566207684945659, 0.9820406027158624], 
             UndirectedEdge[86, 263] -> 
             RGBColor[
              0.8128397211622832, 0.8545650396160793, 0.98175457227757], 
             UndirectedEdge[109, 191] -> 
             RGBColor[
              0.7568311137739301, 0.809961485300482, 0.9763975104982613], 
             UndirectedEdge[84, 238] -> 
             RGBColor[
              0.20412910744851856`, 0.3318830128342959, 0.9349362227360163], 
             UndirectedEdge[21, 244] -> 
             RGBColor[
              0.8603330379658907, 0.8905895084576498, 0.9291667891490283], 
             UndirectedEdge[137, 175] -> 
             RGBColor[
              0.6269913454592946, 0.6978695681639011, 0.94553729330725], 
             UndirectedEdge[363, 369] -> 
             RGBColor[
              0.7487645720719532, 0.8036598416149099, 0.9755935130075263], 
             UndirectedEdge[98, 290] -> 
             RGBColor[
              0.6147398860335445, 0.49128012061104204`, 0.5780729595922216], 
             UndirectedEdge[175, 352] -> 
             RGBColor[
              0.8655672257177054, 0.8953960929022551, 0.9644030375973409], 
             UndirectedEdge[121, 319] -> 
             RGBColor[
              0.46137550526435334`, 0.570722959745312, 0.9515364795012968], 
             UndirectedEdge[249, 387] -> 
             RGBColor[
              0.6750034184458011, 0.7364860173971828, 0.7926116397143519], 
             UndirectedEdge[310, 389] -> 
             RGBColor[
              0.8151946138073635, 0.8557356028075302, 0.9821668436973965], 
             UndirectedEdge[228, 238] -> 
             RGBColor[
              0.41793256112200833`, 0.5190659679489169, 0.9499066517468268], 
             UndirectedEdge[268, 324] -> 
             RGBColor[
              0.350334968895203, 0.4773380308835684, 0.9435632806802561], 
             UndirectedEdge[144, 368] -> 
             RGBColor[
              0.6415924462647964, 0.7182396853137496, 0.9660714877339953], 
             UndirectedEdge[137, 278] -> 
             RGBColor[
              0.5301001681570339, 0.6216883135289165, 0.9587123585960289], 
             UndirectedEdge[127, 298] -> 
             RGBColor[
              0.7679804566615273, 0.8186912523264218, 0.9775035143434276], 
             UndirectedEdge[131, 228] -> 
             RGBColor[
              0.4708795418192703, 0.5747166016942085, 0.9529219039694972], 
             UndirectedEdge[278, 314] -> 
             RGBColor[
              0.8090505141751263, 0.8510062449117177, 0.9815357594986349], 
             UndirectedEdge[182, 311] -> 
             RGBColor[
              0.7787148981096903, 0.8275622068269941, 0.9754797638777545], 
             UndirectedEdge[77, 94] -> 
             RGBColor[
              0.4266297860326723, 0.5438724088112132, 0.9484260632605733], 
             UndirectedEdge[144, 333] -> 
             RGBColor[
              0.834908779455954, 0.7597167210909277, 0.6144752733807564], 
             UndirectedEdge[166, 197] -> 
             RGBColor[
              0.6841282454677757, 0.7494142197927833, 0.9579908413881288], 
             UndirectedEdge[106, 384] -> 
             RGBColor[
              0.9909298248563598, 0.9884656225524878, 0.650847149650948], 
             UndirectedEdge[28, 265] -> 
             RGBColor[
              0.8091405851735762, 0.742117962346994, 0.6124675331889617], 
             UndirectedEdge[113, 266] -> 
             RGBColor[
              0.9035575392781542, 0.9259362716771096, 0.9906633187833296], 
             UndirectedEdge[164, 292] -> 
             RGBColor[
              0.8445453375980867, 0.8759829232073173, 0.8057720720178344], 
             UndirectedEdge[98, 248] -> 
             RGBColor[
              0.3385390741547758, 0.4676472633894197, 0.9427923883401612], 
             UndirectedEdge[91, 95] -> 
             RGBColor[
              0.22798028843285273`, 0.35695211630104906`, 0.9362945122084139],
              UndirectedEdge[155, 342] -> 
             RGBColor[
              0.2696017290952002, 0.40069888938893283`, 0.9386647916807309], 
             UndirectedEdge[47, 209] -> 
             RGBColor[
              0.9224279678418232, 0.8653742236295037, 0.6311262167090429], 
             UndirectedEdge[2, 360] -> 
             RGBColor[
              0.5576510289532306, 0.6464598334421179, 0.9606432849849365], 
             UndirectedEdge[75, 341] -> 
             RGBColor[
              0.6591354326035107, 0.7324390715486491, 0.967481798732436], 
             UndirectedEdge[12, 390] -> 
             RGBColor[
              0.9843666249395513, 0.9864167570051618, 0.8466607299453475], 
             UndirectedEdge[19, 198] -> 
             RGBColor[
              0.673045976037498, 0.7445078989101495, 0.9680465909853222], 
             UndirectedEdge[8, 56] -> 
             RGBColor[
              0.407429306112555, 0.522498954495585, 0.9478861315323326], 
             UndirectedEdge[70, 154] -> 
             RGBColor[
              0.6657705688655409, 0.7325666550678736, 0.9429992012393174], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.9875453945290741, 0.9682281253982995, 0.5270083610738315], 
             UndirectedEdge[177, 243] -> 
             RGBColor[
              0.7734450362994798, 0.8208881485802774, 0.8971932331615773], 
             UndirectedEdge[109, 340] -> 
             RGBColor[
              0.7560522077453801, 0.8093529979910735, 0.9763198764246261], 
             UndirectedEdge[28, 36] -> 
             RGBColor[
              0.6006387383076744, 0.5665144925338249, 0.5968480011949644], 
             UndirectedEdge[203, 339] -> 
             RGBColor[
              0.7541321733151889, 0.8057649722671019, 0.9189106469918893], 
             UndirectedEdge[247, 369] -> 
             RGBColor[
              0.6776722270664928, 0.7473636803471011, 0.9690261333331154], 
             UndirectedEdge[223, 230] -> 
             RGBColor[
              0.6538783039791952, 0.7251011839135049, 0.9688778842722177], 
             UndirectedEdge[22, 173] -> 
             RGBColor[
              0.5496619634615396, 0.6452793697841706, 0.9576905497232591], 
             UndirectedEdge[69, 283] -> 
             RGBColor[
              0.33946526561458723`, 0.4628670331578178, 0.9430558053082376], 
             UndirectedEdge[59, 274] -> 
             RGBColor[
              0.40776598803928943`, 0.5262040531974947, 0.9475914185470424], 
             UndirectedEdge[31, 164] -> 
             RGBColor[
              0.5938294595994293, 0.680336214845657, 0.9617147586156072], 
             UndirectedEdge[116, 154] -> 
             RGBColor[
              0.402593404478194, 0.5231279048513123, 0.9468738736273492], 
             UndirectedEdge[10, 170] -> 
             RGBColor[
              0.4317918459168433, 0.5460118090080187, 0.9493992454018274], 
             UndirectedEdge[301, 394] -> 
             RGBColor[
              0.2560287826902925, 0.3864328621428683, 0.9378918324623463], 
             UndirectedEdge[90, 351] -> 
             RGBColor[
              0.2946347734875073, 0.42325804052613947`, 0.9402277716927295], 
             UndirectedEdge[4, 203] -> 
             RGBColor[
              0.66066037942402, 0.7329930389609283, 0.968069538982675], 
             UndirectedEdge[274, 351] -> 
             RGBColor[
              0.4271791058624516, 0.5430187201242453, 0.9488284052483882], 
             UndirectedEdge[238, 269] -> 
             RGBColor[
              0.4251106552488765, 0.5246735496363623, 0.9506220970862895], 
             UndirectedEdge[66, 325] -> 
             RGBColor[
              0.4650891168125191, 0.5670701286022243, 0.952839177186454], 
             UndirectedEdge[128, 171] -> 
             RGBColor[
              0.801924430351231, 0.8423980772046349, 0.8196064218365093], 
             UndirectedEdge[198, 205] -> 
             RGBColor[
              0.7531116822140844, 0.8070655790629049, 0.9760242071022809], 
             UndirectedEdge[202, 349] -> 
             RGBColor[
              0.4595405357718139, 0.5599093654469979, 0.9527335705850384], 
             UndirectedEdge[295, 390] -> 
             RGBColor[
              0.7863843226941024, 0.832577120013263, 0.9435902083065095], 
             UndirectedEdge[250, 356] -> 
             RGBColor[
              0.7357022300387746, 0.7709320245861945, 0.6647189561976792], 
             UndirectedEdge[133, 393] -> 
             RGBColor[
              0.38575158759098316`, 0.5027573449077584, 0.9463746204644632], 
             UndirectedEdge[124, 293] -> 
             RGBColor[
              0.3559354015057241, 0.48271508777597516`, 0.9439008669359954], 
             UndirectedEdge[45, 325] -> 
             RGBColor[
              0.6289695136415687, 0.6917521642637293, 0.722445815602752], 
             UndirectedEdge[116, 304] -> 
             RGBColor[
              0.4698906723612024, 0.5801609203888374, 0.9515091694630429], 
             UndirectedEdge[213, 296] -> 
             RGBColor[
              0.6685326199957795, 0.6999105803483481, 0.6389975585959534], 
             UndirectedEdge[248, 276] -> 
             RGBColor[
              0.34660835313344085`, 0.47463646726698533`, 0.9433065556612985],
              UndirectedEdge[209, 346] -> 
             RGBColor[
              0.8416553182519408, 0.876902707163755, 0.9846726291033383], 
             UndirectedEdge[31, 382] -> 
             RGBColor[
              0.4545481952390179, 0.5670495672715106, 0.9504825084770165], 
             UndirectedEdge[69, 373] -> 
             RGBColor[
              0.5078573593755268, 0.6107226716267005, 0.9545702484368503], 
             UndirectedEdge[166, 239] -> 
             RGBColor[
              0.9267483048253813, 0.8069318806554655, 0.6043390154703001], 
             UndirectedEdge[235, 317] -> 
             RGBColor[
              0.4511415347634991, 0.5566728242098001, 0.9514468982308572], 
             UndirectedEdge[43, 59] -> 
             RGBColor[
              0.6003143091849572, 0.6792949120207352, 0.9651940677620765], 
             UndirectedEdge[94, 207] -> 
             RGBColor[
              0.4248395218091109, 0.5423217719220605, 0.9483119892073164], 
             UndirectedEdge[209, 270] -> 
             RGBColor[
              0.5760891646365741, 0.6522849217083523, 0.9640676247598955], 
             UndirectedEdge[23, 341] -> 
             RGBColor[
              0.778713771134943, 0.8242160952317142, 0.8579172872739522], 
             UndirectedEdge[264, 312] -> 
             RGBColor[
              0.5808710138597879, 0.6584972746082378, 0.964160223747313], 
             UndirectedEdge[48, 118] -> 
             RGBColor[
              0.4763590551325, 0.5835771275512751, 0.9525254326459529], 
             UndirectedEdge[106, 310] -> 
             RGBColor[
              0.8905128586787707, 0.9108181848351266, 0.7242584507027232], 
             UndirectedEdge[267, 282] -> 
             RGBColor[
              0.4364931093735467, 0.5498232865754057, 0.9497707883553266], 
             UndirectedEdge[43, 274] -> 
             RGBColor[
              0.6975776402726726, 0.762135437258922, 0.9717795536815154], 
             UndirectedEdge[46, 362] -> 
             RGBColor[
              0.6504935237090201, 0.7233567234507075, 0.9681156452735085], 
             UndirectedEdge[38, 117] -> 
             RGBColor[
              0.6550548005463569, 0.7269656793614587, 0.9685636318137278], 
             UndirectedEdge[252, 300] -> 
             RGBColor[
              0.6156629408118268, 0.6887303366629896, 0.960755440265155], 
             UndirectedEdge[7, 67] -> 
             RGBColor[
              0.9143131530209598, 0.861602542680818, 0.630956564248154], 
             UndirectedEdge[150, 192] -> 
             RGBColor[
              0.6953580932798215, 0.7573898437912414, 0.9331500282990366], 
             UndirectedEdge[239, 272] -> 
             RGBColor[
              0.5783068139570371, 0.5176254007642525, 0.5891444156114172], 
             UndirectedEdge[22, 209] -> 
             RGBColor[
              0.7000117124793769, 0.7640139631466941, 0.972083466656948], 
             UndirectedEdge[167, 246] -> 
             RGBColor[
              0.5092939408445624, 0.6019553543919998, 0.9571893612938661], 
             UndirectedEdge[131, 140] -> 
             RGBColor[
              0.28612069672969853`, 0.41806137173583147`, 0.939605522449893], 
             UndirectedEdge[67, 385] -> 
             RGBColor[
              0.7177585361404709, 0.705226985148616, 0.6130755948263183], 
             UndirectedEdge[60, 101] -> 
             RGBColor[
              0.38184001653328353`, 0.5051523633090383, 0.945551486099], 
             UndirectedEdge[113, 249] -> 
             RGBColor[
              0.6169217225220367, 0.6940852748222915, 0.9660654396069897], 
             UndirectedEdge[52, 393] -> 
             RGBColor[
              0.25661757713833677`, 0.3870517224394871, 0.9379253634351191], 
             UndirectedEdge[99, 367] -> 
             RGBColor[
              0.6075587354116121, 0.6913981014363648, 0.9628531167909097], 
             UndirectedEdge[5, 43] -> 
             RGBColor[
              0.7660356516090454, 0.8177127348600551, 0.977168819103873], 
             UndirectedEdge[26, 105] -> 
             RGBColor[
              0.3415220277200197, 0.4669273130321485, 0.9431034217571879], 
             UndirectedEdge[128, 306] -> 
             RGBColor[
              0.6216914303517981, 0.6849536739485798, 0.8071576148737041], 
             UndirectedEdge[226, 281] -> 
             RGBColor[
              0.37797861836950364`, 0.501807814299087, 0.9453054412225042], 
             UndirectedEdge[63, 345] -> 
             RGBColor[
              0.29317454370379625`, 0.4236981423394335, 0.9400723031536019], 
             UndirectedEdge[4, 280] -> 
             RGBColor[
              0.5466598870328532, 0.6347889444919184, 0.960336904661341], 
             UndirectedEdge[7, 223] -> 
             RGBColor[
              0.6431010099661033, 0.7165076622093182, 0.9678499363482451], 
             UndirectedEdge[155, 361] -> 
             RGBColor[
              0.3040946245899854, 0.43593637014189646`, 0.9406663388611065], 
             UndirectedEdge[252, 398] -> 
             RGBColor[
              0.6390161789763732, 0.7052698680641531, 0.8819383154543419], 
             UndirectedEdge[6, 252] -> 
             RGBColor[
              0.4186382771493071, 0.5325685275056395, 0.9486802814606468], 
             UndirectedEdge[260, 307] -> 
             RGBColor[
              0.5792376434909651, 0.6628067087785008, 0.9630374751706744], 
             UndirectedEdge[21, 357] -> 
             RGBColor[
              0.5754274288240464, 0.6637684826195861, 0.9609668911317127], 
             UndirectedEdge[233, 366] -> 
             RGBColor[
              0.6280626043595494, 0.7039551725703304, 0.9666739446873336], 
             UndirectedEdge[37, 41] -> 
             RGBColor[
              0.7120347524444427, 0.7149227162043192, 0.6159272011471837], 
             UndirectedEdge[173, 176] -> 
             RGBColor[
              0.6995625946064906, 0.7646185647778574, 0.9711026952924797], 
             UndirectedEdge[60, 136] -> 
             RGBColor[
              0.6033860529715701, 0.6862958142101191, 0.9634632646955235], 
             UndirectedEdge[74, 285] -> 
             RGBColor[
              0.7594584247519152, 0.8120643752337919, 0.9766459978104995], 
             UndirectedEdge[234, 395] -> 
             RGBColor[
              0.2787504776570601, 0.4103148041916094, 0.9391857993769683], 
             UndirectedEdge[17, 164] -> 
             RGBColor[
              0.609446676104815, 0.693014974752315, 0.9629442031066602], 
             UndirectedEdge[20, 383] -> 
             RGBColor[
              0.5849613813219166, 0.6480514646601874, 0.8683381098703788], 
             UndirectedEdge[19, 219] -> 
             RGBColor[
              0.6391694597714013, 0.717659144493349, 0.9649327503953806], 
             UndirectedEdge[91, 279] -> 
             RGBColor[
              0.40590273836261903`, 0.5141269546211237, 0.9484152139138478], 
             UndirectedEdge[76, 207] -> 
             RGBColor[
              0.43006222434892044`, 0.5465617971239461, 0.9487231394826401], 
             UndirectedEdge[238, 339] -> 
             RGBColor[
              0.583952747628453, 0.6485132569543495, 0.9079787055286567], 
             UndirectedEdge[142, 379] -> 
             RGBColor[
              0.3540603133127629, 0.4805628959565015, 0.9438007237411221], 
             UndirectedEdge[205, 219] -> 
             RGBColor[
              0.7192351659479875, 0.7802168246461043, 0.9729103665123393], 
             UndirectedEdge[7, 68] -> 
             RGBColor[
              0.6565704924800646, 0.7281742509670357, 0.968708199863439], 
             UndirectedEdge[188, 273] -> 
             RGBColor[
              0.6793830543351957, 0.7401070750985406, 0.7781590978438747], 
             UndirectedEdge[16, 69] -> 
             RGBColor[
              0.30474526360884113`, 0.42637410967450606`, 0.9410785525576505],
              UndirectedEdge[118, 323] -> 
             RGBColor[
              0.7274144815280029, 0.7864698626305258, 0.9740000461011284], 
             UndirectedEdge[211, 263] -> 
             RGBColor[
              0.59813369079768, 0.6837382636656562, 0.9621167231302465], 
             UndirectedEdge[191, 340] -> 
             RGBColor[
              0.7815885760139583, 0.8293022029660739, 0.9788651029627087], 
             UndirectedEdge[33, 182] -> 
             RGBColor[
              0.9451394577198924, 0.9586056779101649, 0.9777487675459327], 
             UndirectedEdge[99, 300] -> 
             RGBColor[
              0.8214316039643914, 0.8612380423266085, 0.9762546280013872], 
             UndirectedEdge[11, 91] -> 
             RGBColor[
              0.467859061099324, 0.5633146849248394, 0.9540523785595496], 
             UndirectedEdge[78, 233] -> 
             RGBColor[
              0.5591737618791397, 0.6385253703757472, 0.9624953744266984], 
             UndirectedEdge[27, 172] -> 
             RGBColor[
              0.687640131641255, 0.751019318335338, 0.9372465126692239], 
             UndirectedEdge[313, 396] -> 
             RGBColor[
              0.7532795934942431, 0.8073202253842303, 0.9762067032492864], 
             UndirectedEdge[74, 172] -> 
             RGBColor[
              0.8336872043251742, 0.8702472032129693, 0.9488755766203021], 
             UndirectedEdge[217, 366] -> 
             RGBColor[
              0.5866932776841376, 0.6712173625158535, 0.9626620329005778], 
             UndirectedEdge[277, 302] -> 
             RGBColor[
              0.8887927412682646, 0.912237657057717, 0.9054866190609112], 
             UndirectedEdge[203, 232] -> 
             RGBColor[
              0.4754832185057247, 0.5843883521119679, 0.9520358763418173], 
             UndirectedEdge[27, 285] -> 
             RGBColor[
              0.613411352067996, 0.6928364903561606, 0.9650169338594214], 
             UndirectedEdge[193, 334] -> 
             RGBColor[
              0.7315949148401948, 0.7897507255209086, 0.9744592074322133], 
             UndirectedEdge[39, 381] -> 
             RGBColor[
              0.7372302024913558, 0.3119234428426639, 0.4294276138517201], 
             UndirectedEdge[270, 390] -> 
             RGBColor[
              0.6122080909831173, 0.6800498741080716, 0.931618212330044], 
             UndirectedEdge[35, 42] -> 
             RGBColor[
              0.7583152192524517, 0.8081438139619761, 0.8767193653049906], 
             UndirectedEdge[41, 245] -> 
             RGBColor[
              0.5303220647993434, 0.6295783687976939, 0.956168042056188], 
             UndirectedEdge[45, 276] -> 
             RGBColor[
              0.6852235062908316, 0.7445497640876971, 0.7258811297775216], 
             UndirectedEdge[17, 241] -> 
             RGBColor[
              0.555252363339249, 0.6498179082495397, 0.958130646479942], 
             UndirectedEdge[69, 347] -> 
             RGBColor[
              0.6674676750220885, 0.7369698893122152, 0.9696985454951954], 
             UndirectedEdge[16, 295] -> 
             RGBColor[
              0.38792446476176157`, 0.4945205696352488, 0.9474560136853092], 
             UndirectedEdge[190, 351] -> 
             RGBColor[
              0.3633860169769336, 0.48916843641831476`, 0.9443756135655004], 
             UndirectedEdge[112, 141] -> 
             RGBColor[
              0.7416844800026314, 0.797630669467937, 0.9756117029914569], 
             UndirectedEdge[135, 400] -> 
             RGBColor[
              0.4220724585009381, 0.5384006197150526, 0.9485568875093136], 
             UndirectedEdge[295, 310] -> 
             RGBColor[
              0.6925219233969159, 0.7590266190406325, 0.9704636563661073], 
             UndirectedEdge[185, 249] -> 
             RGBColor[
              0.6333583726352467, 0.5839941361393448, 0.5956398607552478], 
             UndirectedEdge[93, 98] -> 
             RGBColor[
              0.3684828649583397, 0.4935830699647806, 0.9447003802119098], 
             UndirectedEdge[221, 268] -> 
             RGBColor[
              0.3574910132874124, 0.48406248051395195`, 0.9439999891431511], 
             UndirectedEdge[265, 291] -> 
             RGBColor[
              0.6564156966591441, 0.7310877030202071, 0.9666820046947593], 
             UndirectedEdge[128, 133] -> 
             RGBColor[
              0.7518885661291439, 0.8017767085391487, 0.8156674153175367], 
             UndirectedEdge[57, 333] -> 
             RGBColor[
              0.6930450606809794, 0.6462183551328625, 0.6021634081228563], 
             UndirectedEdge[28, 378] -> 
             RGBColor[
              0.7144886647923281, 0.6661344259357302, 0.6044287772527661], 
             UndirectedEdge[92, 386] -> 
             RGBColor[
              0.687823381506157, 0.7479304779714679, 0.8225265568592857], 
             UndirectedEdge[35, 248] -> 
             RGBColor[
              0.6535443754476089, 0.7193581083119118, 0.8695014822828191], 
             UndirectedEdge[56, 175] -> 
             RGBColor[
              0.747652001575412, 0.8016261109577019, 0.9537810024097098], 
             UndirectedEdge[3, 21] -> 
             RGBColor[
              0.45963491226847686`, 0.551983352718622, 0.954009453448976], 
             UndirectedEdge[98, 204] -> 
             RGBColor[
              0.3648327921318383, 0.4904215603404596, 0.9444678007990378], 
             UndirectedEdge[243, 367] -> 
             RGBColor[
              0.5365778551767127, 0.6346571012461872, 0.9566605207904098], 
             UndirectedEdge[48, 209] -> 
             RGBColor[
              0.6381052409533796, 0.7115638617141355, 0.9678155188313007], 
             UndirectedEdge[116, 291] -> 
             RGBColor[
              0.5272872950753209, 0.6267580843965457, 0.9560276418538549], 
             UndirectedEdge[214, 340] -> 
             RGBColor[
              0.5511073240701742, 0.6407501431378663, 0.9602440438916057], 
             UndirectedEdge[138, 159] -> 
             RGBColor[
              0.6523027855950145, 0.7268758271042266, 0.9669549795176691], 
             UndirectedEdge[22, 48] -> 
             RGBColor[
              0.4345080902611611, 0.5496006289042401, 0.9492307713861454], 
             UndirectedEdge[13, 297] -> 
             RGBColor[
              0.538709683550605, 0.6333975998408625, 0.9580211012787346], 
             UndirectedEdge[192, 347] -> 
             RGBColor[
              0.6575922961698454, 0.7284163325013754, 0.9690692950871851], 
             UndirectedEdge[4, 322] -> 
             RGBColor[
              0.8812722835749832, 0.9076185115354948, 0.963614957221282], 
             UndirectedEdge[111, 304] -> 
             RGBColor[
              0.40892552143263583`, 0.5273559708520941, 0.9476245239552408], 
             UndirectedEdge[133, 361] -> 
             RGBColor[
              0.4143533234029372, 0.5318028433129689, 0.9480406748160912], 
             UndirectedEdge[4, 186] -> 
             RGBColor[
              0.6986703747351071, 0.7638512654852438, 0.9710618250487644], 
             UndirectedEdge[73, 240] -> 
             RGBColor[
              0.8476997422075396, 0.8814591770190856, 0.9637002767600654], 
             UndirectedEdge[82, 335] -> 
             RGBColor[
              0.727605322666366, 0.7871300751630135, 0.9734845567712053], 
             UndirectedEdge[184, 372] -> 
             RGBColor[
              0.6707398696774913, 0.7379034863339973, 0.9583870971458612], 
             UndirectedEdge[85, 340] -> 
             RGBColor[
              0.7170880815445854, 0.7789139264646855, 0.9724362964653925], 
             UndirectedEdge[344, 388] -> 
             RGBColor[
              0.9454802768249887, 0.9580530394987721, 0.9486668347309655], 
             UndirectedEdge[57, 228] -> 
             RGBColor[
              0.5608834502382838, 0.6542123306421754, 0.9586950630698168], 
             UndirectedEdge[36, 80] -> 
             RGBColor[
              0.3227648234799671, 0.4514598379802632, 0.9418797036288838], 
             UndirectedEdge[88, 365] -> 
             RGBColor[
              0.5384046959968379, 0.618368716385103, 0.9610591662736674], 
             UndirectedEdge[209, 241] -> 
             RGBColor[
              0.7449118335294409, 0.8004659041425386, 0.9756181686605718], 
             UndirectedEdge[49, 62] -> 
             RGBColor[
              0.8057211228621821, 0.8490898053215541, 0.9810116897710301], 
             UndirectedEdge[161, 250] -> 
             RGBColor[
              0.7939859258270691, 0.8182493544777055, 0.6693072622303462], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.9266412932659314, 0.9443423276694797, 0.9928545679961809], 
             UndirectedEdge[324, 346] -> 
             RGBColor[
              0.5413779982849376, 0.631843900057068, 0.9596234529190915], 
             UndirectedEdge[142, 258] -> 
             RGBColor[
              0.4374080723536685, 0.5495379648314893, 0.9500003173487008], 
             UndirectedEdge[44, 46] -> 
             RGBColor[
              0.8466617193270474, 0.8805690892439875, 0.985236544684895], 
             UndirectedEdge[85, 191] -> 
             RGBColor[
              0.7178669875731354, 0.7795224137740939, 0.9725139305390277], 
             UndirectedEdge[112, 172] -> 
             RGBColor[
              0.7623549088119739, 0.8131075223506701, 0.9427328384932929], 
             UndirectedEdge[133, 298] -> 
             RGBColor[
              0.61124450978409, 0.6941846784773162, 0.9632839130998092], 
             UndirectedEdge[26, 215] -> 
             RGBColor[
              0.6217334503263376, 0.6908849563690971, 0.936879723190192], 
             UndirectedEdge[127, 129] -> 
             RGBColor[
              0.9085449397436656, 0.9266546363932447, 0.8605911563698274], 
             UndirectedEdge[172, 225] -> 
             RGBColor[
              0.9235159054728617, 0.9408453451593575, 0.957716537117316], 
             UndirectedEdge[38, 376] -> 
             RGBColor[
              0.482004525919148, 0.5896500703416709, 0.9525582575418401], 
             UndirectedEdge[158, 346] -> 
             RGBColor[
              0.5406150460175785, 0.6310419888501059, 0.9595800039161522], 
             UndirectedEdge[340, 370] -> 
             RGBColor[
              0.8034325567614622, 0.8464159599642682, 0.9810292842968618], 
             UndirectedEdge[44, 266] -> 
             RGBColor[
              0.8747050959568471, 0.9029301165514096, 0.9879113469824632], 
             UndirectedEdge[183, 238] -> 
             RGBColor[
              0.291833026959873, 0.4154689364724279, 0.9402455895897723], 
             UndirectedEdge[21, 264] -> 
             RGBColor[
              0.8145351373769674, 0.855640622600764, 0.9819896030219514], 
             UndirectedEdge[13, 140] -> 
             RGBColor[
              0.49274900971834845`, 0.591338322558761, 0.9551749278429259], 
             UndirectedEdge[210, 266] -> 
             RGBColor[
              0.9016069930294986, 0.7343609205235228, 0.6049988714945388], 
             UndirectedEdge[51, 395] -> 
             RGBColor[
              0.47648625310015313`, 0.575122228812187, 0.9541099309690472], 
             UndirectedEdge[358, 372] -> 
             RGBColor[
              0.42722492090297554`, 0.5442172178223251, 0.9485111405015548], 
             UndirectedEdge[174, 309] -> 
             RGBColor[
              0.46463369009195227`, 0.5720720603966368, 0.9521043751588505], 
             UndirectedEdge[65, 363] -> 
             RGBColor[
              0.611438600514103, 0.6940126196679568, 0.9635245627430553], 
             UndirectedEdge[236, 267] -> 
             RGBColor[
              0.5977136744429046, 0.6775977189337674, 0.9647727013409448], 
             UndirectedEdge[227, 352] -> 
             RGBColor[
              0.49548755486671675`, 0.5848873622656352, 0.9568078561410465], 
             UndirectedEdge[2, 370] -> 
             RGBColor[
              0.5807667456906866, 0.6645670802612144, 0.9629342210775194], 
             UndirectedEdge[17, 354] -> 
             RGBColor[
              0.6421489432267542, 0.7185622343744096, 0.9662036594733135], 
             UndirectedEdge[133, 306] -> 
             RGBColor[
              0.37876660187889855`, 0.49541568205068404`, 0.9459768358615203],
              UndirectedEdge[105, 261] -> 
             RGBColor[
              0.3648863052759247, 0.49046791073621837`, 0.9444712106092592], 
             UndirectedEdge[120, 206] -> 
             RGBColor[
              0.4095927760490423, 0.5279380165108627, 0.9476659070899331], 
             UndirectedEdge[361, 393] -> 
             RGBColor[
              0.29114117333767614`, 0.4223214715794742, 0.9399286589752014], 
             UndirectedEdge[270, 295] -> 
             RGBColor[
              0.4227456978125379, 0.5311198933653063, 0.949439031394153], 
             UndirectedEdge[9, 283] -> 
             RGBColor[
              0.23670602569168336`, 0.36612341940377613`, 0.9367914300367328],
              UndirectedEdge[43, 122] -> 
             RGBColor[
              0.7349870124403968, 0.7925060508576913, 0.9747245564936041], 
             UndirectedEdge[127, 336] -> 
             RGBColor[
              0.5402814434826944, 0.6249451772566185, 0.9604685880900636], 
             UndirectedEdge[4, 123] -> 
             RGBColor[
              0.8807469299374877, 0.8639988292686078, 0.6446606547128049], 
             UndirectedEdge[45, 279] -> 
             RGBColor[
              0.7921168248865424, 0.8333973950281874, 0.7337250950179458], 
             UndirectedEdge[135, 255] -> 
             RGBColor[
              0.48567576995795636`, 0.5900366532523884, 0.9535639731738168], 
             UndirectedEdge[152, 180] -> 
             RGBColor[
              0.513773668184085, 0.6134725866244342, 0.9557239763425098], 
             UndirectedEdge[48, 68] -> 
             RGBColor[
              0.40003378539040224`, 0.5209108914476632, 0.9467107769624574], 
             UndirectedEdge[362, 363] -> 
             RGBColor[
              0.581662997253547, 0.6691596731089946, 0.961368340785237], 
             UndirectedEdge[18, 257] -> 
             RGBColor[
              0.7424486647255875, 0.7980390221230934, 0.9704623425032246], 
             UndirectedEdge[72, 109] -> 
             RGBColor[
              0.5653810777109648, 0.6552163029022884, 0.960263485989135], 
             UndirectedEdge[181, 211] -> 
             RGBColor[
              0.509073565055137, 0.612327879471342, 0.9544952823205048], 
             UndirectedEdge[82, 259] -> 
             RGBColor[
              0.5476884235568233, 0.6406251348592771, 0.9588257500475039], 
             UndirectedEdge[282, 367] -> 
             RGBColor[
              0.5332779334390683, 0.6319780761197873, 0.9564007388632108], 
             UndirectedEdge[44, 363] -> 
             RGBColor[
              0.7778311928715742, 0.8263720389022746, 0.9784892401966235], 
             UndirectedEdge[139, 290] -> 
             RGBColor[
              0.5238524305420571, 0.4005884355006752, 0.572719954764935], 
             UndirectedEdge[255, 351] -> 
             RGBColor[
              0.4943728831818643, 0.5975696555973168, 0.9541181455378889], 
             UndirectedEdge[290, 345] -> 
             RGBColor[
              0.563400045555537, 0.44215548634345864`, 0.5749721329344992], 
             UndirectedEdge[145, 200] -> 
             RGBColor[
              0.6162839075494507, 0.6798236809970757, 0.8401319355677652], 
             UndirectedEdge[44, 316] -> 
             RGBColor[
              0.8610069718311691, 0.8920076041992682, 0.9866048076748962], 
             UndirectedEdge[172, 240] -> 
             RGBColor[
              0.855191366736224, 0.887046418326169, 0.9510189105616123], 
             UndirectedEdge[89, 299] -> 
             RGBColor[
              0.4978054133922175, 0.5997079837223303, 0.954678433314889], 
             UndirectedEdge[119, 196] -> 
             RGBColor[
              0.29697512309611795`, 0.4286343572927416, 0.940254265219008], 
             UndirectedEdge[149, 369] -> 
             RGBColor[
              0.6699105008102617, 0.7410623613105096, 0.9684151018100847], 
             UndirectedEdge[32, 385] -> 
             RGBColor[
              0.40009488861420933`, 0.5197944076312261, 0.9470129165150192], 
             UndirectedEdge[149, 253] -> 
             RGBColor[
              0.4213349301932525, 0.5319798306675697, 0.9491454391788694], 
             UndirectedEdge[317, 336] -> 
             RGBColor[
              0.44547009762278966`, 0.5507117841850309, 0.9511239182758331], 
             UndirectedEdge[138, 215] -> 
             RGBColor[
              0.759817894250921, 0.8111874301027184, 0.9462765868824963], 
             UndirectedEdge[157, 181] -> 
             RGBColor[
              0.7450290087391385, 0.7992770568537275, 0.9476847959921177], 
             UndirectedEdge[299, 342] -> 
             RGBColor[
              0.4554449485503188, 0.55765600983643, 0.9521755715727337], 
             UndirectedEdge[108, 198] -> 
             RGBColor[
              0.566189254407245, 0.6578810453864843, 0.9594834110164675], 
             UndirectedEdge[152, 367] -> 
             RGBColor[
              0.5883570039152134, 0.6763975628528137, 0.9609392676457317], 
             UndirectedEdge[17, 118] -> 
             RGBColor[
              0.5522032071605241, 0.6473424659007303, 0.9578906057361256], 
             UndirectedEdge[44, 68] -> 
             RGBColor[
              0.6240424596666266, 0.7022372805515296, 0.9656056470555756], 
             UndirectedEdge[158, 323] -> 
             RGBColor[
              0.5881203951145202, 0.6685958784797372, 0.9641975070992903], 
             UndirectedEdge[343, 359] -> 
             RGBColor[
              0.6204819207724386, 0.6903211191113702, 0.941116394282603], 
             UndirectedEdge[354, 388] -> 
             RGBColor[
              0.8332299034660433, 0.870343687847239, 0.9838267646438055], 
             UndirectedEdge[382, 389] -> 
             RGBColor[
              0.6291541055210067, 0.7059202784950191, 0.966274069114246], 
             UndirectedEdge[178, 319] -> 
             RGBColor[
              0.6691361016310776, 0.732861418592031, 0.8704413372036561], 
             UndirectedEdge[15, 386] -> 
             RGBColor[
              0.8237454123414338, 0.8600970379561219, 0.832787353464118], 
             UndirectedEdge[27, 104] -> 
             RGBColor[
              0.695123234766305, 0.7556942345340594, 0.8840083896717847], 
             UndirectedEdge[236, 398] -> 
             RGBColor[
              0.9317246052257521, 0.9461319807695563, 0.9059870382484934], 
             UndirectedEdge[151, 304] -> 
             RGBColor[
              0.5475958923362796, 0.643602040169241, 0.9575279010360107], 
             UndirectedEdge[21, 233] -> 
             RGBColor[
              0.8033668723098575, 0.8467353511907298, 0.9809243639298225], 
             UndirectedEdge[120, 321] -> 
             RGBColor[
              0.7164283484778622, 0.6891125030833413, 0.6095093448077483], 
             UndirectedEdge[170, 299] -> 
             RGBColor[
              0.6010368164045505, 0.6867155181893196, 0.9619211199360648], 
             UndirectedEdge[97, 109] -> 
             RGBColor[
              0.7046186655866328, 0.7691727239472617, 0.971193461616021], 
             UndirectedEdge[251, 381] -> 
             RGBColor[
              0.6176091744850905, 0.7001998375602203, 0.9632051549125475], 
             UndirectedEdge[134, 392] -> 
             RGBColor[
              0.2728486774095929, 0.39874688987775386`, 0.9390461302900781], 
             UndirectedEdge[132, 220] -> 
             RGBColor[
              0.6033333583668086, 0.6759194399894715, 0.960903163598182], 
             UndirectedEdge[102, 167] -> 
             RGBColor[
              0.758527993117162, 0.8112871003401753, 0.9765666395729555], 
             UndirectedEdge[270, 373] -> 
             RGBColor[
              0.41686032881746204`, 0.5263418856822519, 0.9489757135880437], 
             UndirectedEdge[122, 351] -> 
             RGBColor[
              0.46458847803017583`, 0.5733893337230148, 0.9517734080604769], 
             UndirectedEdge[96, 173] -> 
             RGBColor[
              0.7987818066060666, 0.8402827088392839, 0.8500694270908953], 
             UndirectedEdge[253, 266] -> 
             RGBColor[
              0.5970629045402169, 0.6711353886211049, 0.9657459571621506], 
             UndirectedEdge[217, 230] -> 
             RGBColor[
              0.8482053776295329, 0.8820489285689395, 0.9853177117142049], 
             UndirectedEdge[118, 158] -> 
             RGBColor[
              0.44082240511635346`, 0.55212974348008, 0.9502855027295694], 
             UndirectedEdge[208, 230] -> 
             RGBColor[
              0.8384201042682105, 0.8744045986482425, 0.9843424071141269], 
             UndirectedEdge[86, 179] -> 
             RGBColor[
              0.5948700230570768, 0.6693051634745264, 0.96554917227442], 
             UndirectedEdge[185, 284] -> 
             RGBColor[
              0.7042195568073244, 0.6441778938023753, 0.6004846023161414], 
             UndirectedEdge[279, 399] -> 
             RGBColor[
              0.5165419123131971, 0.618086386106756, 0.9551673892874422], 
             UndirectedEdge[167, 309] -> 
             RGBColor[
              0.6869582806939833, 0.7550740544030773, 0.9696398844407381], 
             UndirectedEdge[174, 183] -> 
             RGBColor[
              0.35418135516350346`, 0.4810009825267726, 0.9437962346448832], 
             UndirectedEdge[149, 247] -> 
             RGBColor[
              0.5850970021883839, 0.6740471305529259, 0.96048012577466], 
             UndirectedEdge[297, 339] -> 
             RGBColor[
              0.6811451391674378, 0.7444203178247368, 0.9137424494973292], 
             UndirectedEdge[28, 282] -> 
             RGBColor[
              0.7356862052019039, 0.6833435441785369, 0.606097525282957], 
             UndirectedEdge[35, 125] -> 
             RGBColor[
              0.9654251986765656, 0.9725919528724407, 0.8922334957609817], 
             UndirectedEdge[119, 231] -> 
             RGBColor[
              0.28076486595675515`, 0.41159634924960636`, 0.9393311150558477],
              UndirectedEdge[257, 309] -> 
             RGBColor[
              0.5829616264506159, 0.6723135363314251, 0.960312021174444], 
             UndirectedEdge[153, 161] -> 
             RGBColor[
              0.7672483631204006, 0.8184347773336882, 0.9775664109412245], 
             UndirectedEdge[315, 369] -> 
             RGBColor[
              0.8604381849741751, 0.8914336511198102, 0.9661395372825348], 
             UndirectedEdge[145, 207] -> 
             RGBColor[
              0.6939791245458833, 0.7536396979002506, 0.844843865052157], 
             UndirectedEdge[75, 215] -> 
             RGBColor[
              0.8624088758199515, 0.8927596184029518, 0.9555260212585486], 
             UndirectedEdge[155, 199] -> 
             RGBColor[
              0.6202455658079248, 0.6921307174499016, 0.952898901453171], 
             UndirectedEdge[28, 151] -> 
             RGBColor[
              0.7577174035648302, 0.7012294635037364, 0.6078319019210252], 
             UndirectedEdge[141, 279] -> 
             RGBColor[
              0.7621616862267098, 0.8142549879682717, 0.9772237436758944], 
             UndirectedEdge[347, 380] -> 
             RGBColor[
              0.5886168611037121, 0.6653555471706938, 0.9647957197153016], 
             UndirectedEdge[107, 346] -> 
             RGBColor[
              0.8077632897146634, 0.8498781235827368, 0.9814399771656817], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.4263222628547974, 0.5431728462715246, 0.948526162998565], 
             UndirectedEdge[171, 299] -> 
             RGBColor[
              0.6345841225204982, 0.713950732583164, 0.9645620867613436], 
             UndirectedEdge[283, 294] -> 
             RGBColor[
              0.5054263648499313, 0.5963793790356542, 0.9572083074348572], 
             UndirectedEdge[83, 244] -> 
             RGBColor[
              0.805708078889336, 0.8476587978766063, 0.9238981856810433], 
             UndirectedEdge[112, 179] -> 
             RGBColor[
              0.4073607476589798, 0.5205579384057619, 0.9480523513030559], 
             UndirectedEdge[42, 93] -> 
             RGBColor[
              0.4507327129386782, 0.5628622209698219, 0.9504832452946785], 
             UndirectedEdge[94, 254] -> 
             RGBColor[
              0.33707201842763457`, 0.4579191434083629, 0.9430264579139087], 
             UndirectedEdge[84, 222] -> 
             RGBColor[
              0.22272321637311115`, 0.3514266002486406, 0.9359951297317528], 
             UndirectedEdge[132, 366] -> 
             RGBColor[
              0.3245388091148398, 0.4514645046444149, 0.9420488297090084], 
             UndirectedEdge[52, 133] -> 
             RGBColor[
              0.37982972720359787`, 0.49653309417298186`, 0.9460373792760088],
              UndirectedEdge[255, 400] -> 
             RGBColor[
              0.5758135623088118, 0.6665104158444886, 0.9597492993809794], 
             UndirectedEdge[276, 318] -> 
             RGBColor[
              0.39863104342815925`, 0.5196959068638294, 0.9466213954850192], 
             UndirectedEdge[235, 313] -> 
             RGBColor[
              0.5823247423363425, 0.6599081525233998, 0.964260748684812], 
             UndirectedEdge[218, 229] -> 
             RGBColor[
              0.5317613681262594, 0.6305594725498811, 0.9563331250188649], 
             UndirectedEdge[202, 260] -> 
             RGBColor[
              0.757034290889019, 0.8102717449653801, 0.976377548257169], 
             UndirectedEdge[129, 216] -> 
             RGBColor[
              0.8189094183829486, 0.8566108702270538, 0.8516623837494992], 
             UndirectedEdge[307, 312] -> 
             RGBColor[
              0.29361430953288453`, 0.42492089452652965`, 0.9400695004228414],
              UndirectedEdge[215, 349] -> 
             RGBColor[
              0.6070987071063725, 0.6755029133486008, 0.9360462962139774], 
             UndirectedEdge[48, 61] -> 
             RGBColor[
              0.2958659174550286, 0.4224003283513125, 0.9403766686231649], 
             UndirectedEdge[198, 284] -> 
             RGBColor[
              0.5911380135199578, 0.6782977680886735, 0.9614026534513418], 
             UndirectedEdge[37, 256] -> 
             RGBColor[
              0.7427705653889056, 0.7398754337852282, 0.6183468369311644], 
             UndirectedEdge[260, 366] -> 
             RGBColor[
              0.6114688994410908, 0.6907238026924725, 0.9650912222988358], 
             UndirectedEdge[35, 263] -> 
             RGBColor[
              0.8458503557067217, 0.8783161431520854, 0.8842207533717397], 
             UndirectedEdge[124, 185] -> 
             RGBColor[
              0.6147272173143388, 0.5678567658294686, 0.5944527000130833], 
             UndirectedEdge[17, 48] -> 
             RGBColor[
              0.4484457707631878, 0.5609158658211367, 0.9503279966506708], 
             UndirectedEdge[98, 139] -> 
             RGBColor[
              0.27017261448779284`, 0.39646213292407584`, 0.9388744014522774],
              UndirectedEdge[98, 125] -> 
             RGBColor[
              0.6504198973837325, 0.7208811079499486, 0.9655244018183238], 
             UndirectedEdge[195, 397] -> 
             RGBColor[
              0.46763833799356425`, 0.5703070099050337, 0.9528960929963922], 
             UndirectedEdge[152, 198] -> 
             RGBColor[
              0.6733639170438348, 0.744756276840741, 0.9680782803735062], 
             UndirectedEdge[29, 129] -> 
             RGBColor[
              0.987469219274603, 0.9686067473997613, 0.5580823531316048], 
             UndirectedEdge[83, 230] -> 
             RGBColor[
              0.7663968298690303, 0.8178821919050699, 0.9773397021712835], 
             UndirectedEdge[10, 155] -> 
             RGBColor[
              0.305044588997752, 0.4367591815653044, 0.9407268697531489], 
             UndirectedEdge[210, 316] -> 
             RGBColor[
              0.8879088689038207, 0.7234384081713813, 0.6036923321869718], 
             UndirectedEdge[6, 175] -> 
             RGBColor[
              0.7548076658858858, 0.8074354016039482, 0.9543443225162924], 
             UndirectedEdge[301, 343] -> 
             RGBColor[
              0.6212227517510942, 0.6910997794413342, 0.9411585835108762], 
             UndirectedEdge[140, 297] -> 
             RGBColor[
              0.3303661075714214, 0.4583177988609272, 0.942354014195895], 
             UndirectedEdge[274, 295] -> 
             RGBColor[
              0.5509756243252639, 0.6463458588530895, 0.9577939659185498], 
             UndirectedEdge[61, 371] -> 
             RGBColor[
              0.2014678155569116, 0.3290858263205654, 0.9347846660998178], 
             UndirectedEdge[266, 397] -> 
             RGBColor[
              0.6013560292712242, 0.675647734913223, 0.9659904442644727], 
             UndirectedEdge[71, 88] -> 
             RGBColor[
              0.8733221857032429, 0.9018274214532846, 0.9877794437679358], 
             UndirectedEdge[156, 255] -> 
             RGBColor[
              0.7702858821271077, 0.8210834570660681, 0.977595268521187], 
             UndirectedEdge[22, 388] -> 
             RGBColor[
              0.7014332025284742, 0.7651474207265249, 0.97221904964681], 
             UndirectedEdge[17, 346] -> 
             RGBColor[
              0.6519958480617489, 0.726254711270756, 0.9671851069227084], 
             UndirectedEdge[72, 365] -> 
             RGBColor[
              0.3087729628465213, 0.4334825254548169, 0.9412026544610419], 
             UndirectedEdge[194, 230] -> 
             RGBColor[
              0.8610738142017682, 0.89210184902291, 0.9866003172093485], 
             UndirectedEdge[95, 264] -> 
             RGBColor[
              0.5646983415359681, 0.6414987705892532, 0.9632392139837961], 
             UndirectedEdge[131, 325] -> 
             RGBColor[
              0.2762633011791583, 0.4077006240172378, 0.9390441583559996], 
             UndirectedEdge[369, 372] -> 
             RGBColor[
              0.577292257745403, 0.664208454099263, 0.9615831377143866], 
             UndirectedEdge[11, 248] -> 
             RGBColor[
              0.5154579944658566, 0.6126718285111914, 0.9567876855474248], 
             UndirectedEdge[32, 223] -> 
             RGBColor[
              0.35407548254631305`, 0.48100038086231944`, 0.9437861529226388],
              UndirectedEdge[75, 229] -> 
             RGBColor[
              0.685735640033093, 0.7540343182656726, 0.9695758645010631], 
             UndirectedEdge[123, 131] -> 
             RGBColor[
              0.6251549552231738, 0.6524710937679776, 0.6242110091103918], 
             UndirectedEdge[35, 340] -> 
             RGBColor[
              0.8859401712751772, 0.9096346117680462, 0.8882165315269765], 
             UndirectedEdge[316, 369] -> 
             RGBColor[
              0.8319403510315482, 0.8692954069119034, 0.983709080485799], 
             UndirectedEdge[232, 280] -> 
             RGBColor[
              0.3614827261145579, 0.48618425764295803`, 0.9443032420204833], 
             UndirectedEdge[30, 318] -> 
             RGBColor[
              0.4579775773314211, 0.5699429160327487, 0.9507223036648427], 
             UndirectedEdge[219, 338] -> 
             RGBColor[
              0.4477668351282824, 0.5549835592576575, 0.951085609360711], 
             UndirectedEdge[124, 397] -> 
             RGBColor[
              0.29608905719419876`, 0.42765936774852886`, 0.940205404345968], 
             UndirectedEdge[131, 280] -> 
             RGBColor[
              0.29106791231853923`, 0.4232612089912882, 0.939887259058928], 
             UndirectedEdge[224, 345] -> 
             RGBColor[
              0.335556002904284, 0.4604068321448196, 0.9427728122574042], 
             UndirectedEdge[44, 195] -> 
             RGBColor[
              0.7409874046791871, 0.7975893915432203, 0.9748169957143827], 
             UndirectedEdge[57, 102] -> 
             RGBColor[
              0.6168059634277759, 0.6978994229726487, 0.9642688965589471], 
             UndirectedEdge[102, 222] -> 
             RGBColor[
              0.4924491832360931, 0.5822966476937348, 0.9565393922316936], 
             UndirectedEdge[86, 285] -> 
             RGBColor[
              0.8756354046368119, 0.9036719194402572, 0.9880000806548546], 
             UndirectedEdge[97, 340] -> 
             RGBColor[
              0.7293761278266608, 0.7885134416128536, 0.9736610540804684], 
             UndirectedEdge[84, 183] -> 
             RGBColor[
              0.3140201360826833, 0.43878899490446965`, 0.9415091126314298], 
             UndirectedEdge[23, 132] -> 
             RGBColor[
              0.6291970396338551, 0.6936584987432933, 0.8477090803386484], 
             UndirectedEdge[124, 210] -> 
             RGBColor[
              0.5963400209524732, 0.48637255335882856`, 0.5792138315760342], 
             UndirectedEdge[257, 288] -> 
             RGBColor[
              0.5336820255223128, 0.6323061362771061, 0.9564325504722417], 
             UndirectedEdge[31, 287] -> 
             RGBColor[
              0.4586724900828417, 0.5706218241721446, 0.9507453048974943], 
             UndirectedEdge[163, 222] -> 
             RGBColor[
              0.31686571833407895`, 0.44058930039206434`, 0.9417147573657833],
              UndirectedEdge[206, 386] -> 
             RGBColor[
              0.6573825715905333, 0.7215641784221478, 0.8205868953692135], 
             UndirectedEdge[95, 263] -> 
             RGBColor[
              0.46788520205849826`, 0.5652672947275748, 0.9537490902852097], 
             UndirectedEdge[103, 333] -> 
             RGBColor[
              0.6474580790023818, 0.6071276117607993, 0.5991496696099379], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.5498117996996602, 0.6454010135923226, 0.9577023453807922], 
             UndirectedEdge[57, 174] -> 
             RGBColor[
              0.3872412156456141, 0.5092413631498575, 0.9460117560724597], 
             UndirectedEdge[32, 208] -> 
             RGBColor[
              0.5386172828353284, 0.6303037955970571, 0.959250675764548], 
             UndirectedEdge[11, 125] -> 
             RGBColor[
              0.8273388176948133, 0.8659056730717204, 0.9795196990255873], 
             UndirectedEdge[82, 136] -> 
             RGBColor[
              0.7443055829216539, 0.8001764454011233, 0.9751490826406473], 
             UndirectedEdge[129, 298] -> 
             RGBColor[
              0.854089764994074, 0.8840940243802022, 0.8551688319206653], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.6641000461830469, 0.7375192705162672, 0.9671549443018981], 
             UndirectedEdge[155, 306] -> 
             RGBColor[
              0.26850790306594674`, 0.39954920887961154`, 0.9386024999065357],
              UndirectedEdge[247, 358] -> 
             RGBColor[
              0.5276048902240652, 0.6273724440701633, 0.9559541361202836], 
             UndirectedEdge[5, 373] -> 
             RGBColor[
              0.6135482666665608, 0.6971451487711683, 0.962719913534798], 
             UndirectedEdge[194, 201] -> 
             RGBColor[
              0.8033881323033598, 0.8463321820221186, 0.9810378790052002], 
             UndirectedEdge[7, 173] -> 
             RGBColor[
              0.7442921990252046, 0.8000926278709846, 0.9754200247985935], 
             UndirectedEdge[25, 364] -> 
             RGBColor[
              0.49031883235211227`, 0.5937710927694184, 0.953969620799471], 
             UndirectedEdge[1, 313] -> 
             RGBColor[
              0.9449929767110754, 0.9552779496337951, 0.8329863449517785], 
             UndirectedEdge[189, 222] -> 
             RGBColor[
              0.2761590766027606, 0.4053312532996991, 0.9391209661501336], 
             UndirectedEdge[232, 275] -> 
             RGBColor[
              0.34587990136374447`, 0.46978469955362606`, 0.9434146842332352],
              UndirectedEdge[289, 376] -> 
             RGBColor[
              0.47364396843850004`, 0.5824085756657709, 0.9520255302121239], 
             UndirectedEdge[194, 208] -> 
             RGBColor[
              0.7922642975293064, 0.8376421577523525, 0.9799291591130688], 
             UndirectedEdge[320, 384] -> 
             RGBColor[
              0.6120481074469932, 0.6770893926379478, 0.8846979756249328], 
             UndirectedEdge[262, 332] -> 
             RGBColor[
              0.7854590850309862, 0.8312583803764273, 0.9239189093483138], 
             UndirectedEdge[39, 237] -> 
             RGBColor[
              0.6392063748468284, 0.22767182743486478`, 0.4226209094860993], 
             UndirectedEdge[105, 353] -> 
             RGBColor[
              0.5624638060018305, 0.653385899882869, 0.9597828542928899], 
             UndirectedEdge[160, 321] -> 
             RGBColor[
              0.6374822088173084, 0.6219857170541965, 0.6041329269025174], 
             UndirectedEdge[22, 354] -> 
             RGBColor[
              0.6282112627247275, 0.7072469974575128, 0.965106434208788], 
             UndirectedEdge[70, 286] -> 
             RGBColor[
              0.9143163883180347, 0.933719732107797, 0.9641140935222141], 
             UndirectedEdge[97, 334] -> 
             RGBColor[
              0.784135688208204, 0.8318605971267068, 0.9789680941054955], 
             UndirectedEdge[301, 362] -> 
             RGBColor[
              0.3525998880818218, 0.4768832436740928, 0.9437960809284173], 
             UndirectedEdge[166, 300] -> 
             RGBColor[
              0.9467847540019356, 0.9598327371833875, 0.9749637101024293], 
             UndirectedEdge[357, 364] -> 
             RGBColor[
              0.5316399894246924, 0.6295614021639455, 0.9566025683892713], 
             UndirectedEdge[13, 66] -> 
             RGBColor[
              0.6832900883422429, 0.7525106773007533, 0.9690676283631868], 
             UndirectedEdge[102, 395] -> 
             RGBColor[
              0.512074269660279, 0.602923857827901, 0.9576570118708373], 
             UndirectedEdge[129, 336] -> 
             RGBColor[
              0.626390751815241, 0.6903479493103989, 0.8381339056673012], 
             UndirectedEdge[257, 275] -> 
             RGBColor[
              0.403194371432758, 0.5169845391457977, 0.9477417401197137], 
             UndirectedEdge[358, 369] -> 
             RGBColor[
              0.6124183888459429, 0.6943876748277471, 0.9638891121557083], 
             UndirectedEdge[42, 139] -> 
             RGBColor[
              0.3524224624681313, 0.4657412839291171, 0.9446572665350462], 
             UndirectedEdge[37, 206] -> 
             RGBColor[
              0.6358962086548992, 0.6494831394667996, 0.6109354129655205], 
             UndirectedEdge[3, 162] -> 
             RGBColor[
              0.26968046938780016`, 0.3965139289127391, 0.9388255380145651], 
             UndirectedEdge[44, 161] -> 
             RGBColor[
              0.7143572313877836, 0.776260824581624, 0.9725216075800969], 
             UndirectedEdge[67, 266] -> 
             RGBColor[
              0.9358712488767564, 0.8787923831373071, 0.6330127946760193], 
             UndirectedEdge[305, 360] -> 
             RGBColor[
              0.8041935387090892, 0.8470307130352166, 0.9810997533112412], 
             UndirectedEdge[51, 174] -> 
             RGBColor[
              0.5006153859550051, 0.6004834773180208, 0.9554840493892778], 
             UndirectedEdge[132, 321] -> 
             RGBColor[
              0.5991431255935339, 0.5847218973029219, 0.6018385202986621], 
             UndirectedEdge[198, 236] -> 
             RGBColor[
              0.7795054116370476, 0.8281112224660762, 0.9785416645766034], 
             UndirectedEdge[153, 356] -> 
             RGBColor[
              0.7089646673321061, 0.7711174474421771, 0.9729781049085575], 
             UndirectedEdge[78, 217] -> 
             RGBColor[
              0.5178044352037279, 0.6057875603212703, 0.9584834626399426], 
             UndirectedEdge[16, 324] -> 
             RGBColor[
              0.24099061161879445`, 0.3706267908716079, 0.937035430866805], 
             UndirectedEdge[263, 312] -> 
             RGBColor[
              0.48405787438231807`, 0.5822657987465594, 0.9546701000487265], 
             UndirectedEdge[49, 231] -> 
             RGBColor[
              0.589727805803796, 0.6625477235993795, 0.9654507010625802], 
             UndirectedEdge[58, 303] -> 
             RGBColor[
              0.766598640674812, 0.8171494158972652, 0.9590696471765459], 
             UndirectedEdge[287, 371] -> 
             RGBColor[
              0.30404745266208627`, 0.4262207436986002, 0.9410175737750275], 
             UndirectedEdge[108, 332] -> 
             RGBColor[
              0.716501302842975, 0.7751131501578146, 0.9185351154065886], 
             UndirectedEdge[55, 135] -> 
             RGBColor[
              0.3081686514034433, 0.43909121939543583`, 0.9409396213862673], 
             UndirectedEdge[38, 145] -> 
             RGBColor[
              0.7109053392989948, 0.7683003343831061, 0.8459223884889613], 
             UndirectedEdge[41, 400] -> 
             RGBColor[
              0.4921151237902554, 0.5985602528834384, 0.9531602517033161], 
             UndirectedEdge[184, 369] -> 
             RGBColor[
              0.8559333376204588, 0.8880739433394191, 0.9737650688000147], 
             UndirectedEdge[68, 363] -> 
             RGBColor[
              0.5812546852505883, 0.6688060137743899, 0.9613423235054646], 
             UndirectedEdge[239, 350] -> 
             RGBColor[
              0.7862276267741135, 0.6964881976368832, 0.6041181759254579], 
             UndirectedEdge[197, 300] -> 
             RGBColor[
              0.6801094698960697, 0.746417023551546, 0.9647935801664899], 
             UndirectedEdge[34, 340] -> 
             RGBColor[
              0.8097211799871681, 0.851430337424316, 0.9816290987940497], 
             UndirectedEdge[99, 225] -> 
             RGBColor[
              0.7862250377501021, 0.8333475199991636, 0.979214897201921], 
             UndirectedEdge[75, 218] -> 
             RGBColor[
              0.6003909331182145, 0.6845602529284629, 0.9629089922772018], 
             UndirectedEdge[33, 256] -> 
             RGBColor[
              0.7423045601076577, 0.7976078244422067, 0.9620235333067387], 
             UndirectedEdge[68, 173] -> 
             RGBColor[
              0.5151876585907808, 0.6165896323275937, 0.9551705552995711], 
             UndirectedEdge[76, 368] -> 
             RGBColor[
              0.499062302289904, 0.604200285356278, 0.9537071590431618], 
             UndirectedEdge[343, 369] -> 
             RGBColor[
              0.8640070145392367, 0.894095278366011, 0.9600984397287096], 
             UndirectedEdge[172, 243] -> 
             RGBColor[
              0.7664072169864137, 0.8163973686810833, 0.9430518510368788], 
             UndirectedEdge[25, 83] -> 
             RGBColor[
              0.4794813126749117, 0.5850474626440156, 0.9530653400739275], 
             UndirectedEdge[176, 372] -> 
             RGBColor[
              0.5941573069397481, 0.6773835587090066, 0.9632640882052335], 
             UndirectedEdge[211, 214] -> 
             RGBColor[
              0.4085211604509016, 0.5271131597628176, 0.9475690762880157], 
             UndirectedEdge[273, 330] -> 
             RGBColor[
              0.6146783799526733, 0.6772577944539252, 0.7742853501833191], 
             UndirectedEdge[247, 266] -> 
             RGBColor[
              0.7608249765353483, 0.8132026885064612, 0.9770806437579412], 
             UndirectedEdge[294, 347] -> 
             RGBColor[
              0.8334287742574327, 0.8704822351900516, 0.983851047621815], 
             UndirectedEdge[247, 343] -> 
             RGBColor[
              0.7791935159173589, 0.8270800476084272, 0.952163463693285], 
             UndirectedEdge[147, 354] -> 
             RGBColor[
              0.8764609134816678, 0.8998475298172488, 0.7234050419847453], 
             UndirectedEdge[83, 206] -> 
             RGBColor[
              0.4726534739735093, 0.5791335319380123, 0.9526302762294949], 
             UndirectedEdge[178, 300] -> 
             RGBColor[
              0.9669215495354857, 0.9737068576333132, 0.8896525908713275], 
             UndirectedEdge[31, 384] -> 
             RGBColor[
              0.7410056697029639, 0.7945123293013829, 0.8929639820083919], 
             UndirectedEdge[325, 339] -> 
             RGBColor[
              0.6253270697846411, 0.6920002928240416, 0.9103349119676271], 
             UndirectedEdge[43, 237] -> 
             RGBColor[
              0.5865535429794129, 0.6649938891933784, 0.9644044656774238], 
             UndirectedEdge[114, 128] -> 
             RGBColor[
              0.8382169366608779, 0.8712605330055869, 0.8228747058045613], 
             UndirectedEdge[131, 188] -> 
             RGBColor[
              0.32619283687688816`, 0.4550202971062367, 0.9420764837263151], 
             UndirectedEdge[8, 352] -> 
             RGBColor[
              0.5253445302548485, 0.6162689364401382, 0.9585081667199638], 
             UndirectedEdge[56, 137] -> 
             RGBColor[
              0.4137446663681253, 0.5291367985411566, 0.9482457819561492], 
             UndirectedEdge[11, 93] -> 
             RGBColor[
              0.5454017852694206, 0.6386076350865523, 0.9586956774191733], 
             UndirectedEdge[232, 325] -> 
             RGBColor[
              0.3466781149751769, 0.4706236726689076, 0.943460141317555], 
             UndirectedEdge[293, 387] -> 
             RGBColor[
              0.6940503841585866, 0.7529835417692652, 0.7938252955270002], 
             UndirectedEdge[100, 175] -> 
             RGBColor[
              0.6868151487259421, 0.7511339976854048, 0.9492961926557498], 
             UndirectedEdge[327, 336] -> 
             RGBColor[
              0.32461227517683694`, 0.4509045213162951, 0.9420763445358824], 
             UndirectedEdge[230, 357] -> 
             RGBColor[
              0.6616352608191337, 0.7318198700522727, 0.969372150702851], 
             UndirectedEdge[151, 291] -> 
             RGBColor[
              0.6049925150503981, 0.6901992041769496, 0.9620463734268229], 
             UndirectedEdge[10, 87] -> 
             RGBColor[
              0.6196073402436619, 0.6950617447536267, 0.9668578953241866], 
             UndirectedEdge[44, 247] -> 
             RGBColor[
              0.7067388478661137, 0.7700758776344658, 0.9719218605222126], 
             UndirectedEdge[191, 334] -> 
             RGBColor[
              0.8363481363955013, 0.8726493584799271, 0.9841721429877357], 
             UndirectedEdge[31, 389] -> 
             RGBColor[
              0.6676614000624295, 0.7381943955807846, 0.9690258413959671], 
             UndirectedEdge[323, 346] -> 
             RGBColor[
              0.8272071224292279, 0.8653821080005516, 0.9832945472877113], 
             UndirectedEdge[91, 257] -> 
             RGBColor[
              0.38205736952375124`, 0.4947682099761064, 0.9465380191303878], 
             UndirectedEdge[25, 217] -> 
             RGBColor[
              0.5612898604354142, 0.6492141993078852, 0.9610433496168491], 
             UndirectedEdge[4, 238] -> 
             RGBColor[
              0.49048095373728406`, 0.5757413236481759, 0.9571375975194424], 
             UndirectedEdge[49, 298] -> 
             RGBColor[
              0.8246180129608187, 0.8638521994882931, 0.9828951551745841], 
             UndirectedEdge[96, 245] -> 
             RGBColor[
              0.791639190473091, 0.8344840112913443, 0.8495071341846425], 
             UndirectedEdge[198, 219] -> 
             RGBColor[
              0.6511575513158165, 0.7270243327207166, 0.966127611325443], 
             UndirectedEdge[69, 106] -> 
             RGBColor[
              0.7117336636524574, 0.767292245104249, 0.7088283605795754], 
             UndirectedEdge[246, 350] -> 
             RGBColor[
              0.4685311096115997, 0.5701111208238177, 0.9531265032268803], 
             UndirectedEdge[91, 263] -> 
             RGBColor[
              0.4607251252228516, 0.5577415999982184, 0.953341334501804], 
             UndirectedEdge[193, 305] -> 
             RGBColor[
              0.7007120531437347, 0.7651255698971002, 0.9715135725141488], 
             UndirectedEdge[217, 244] -> 
             RGBColor[
              0.8875166266498384, 0.9118255345404758, 0.9318761952239648], 
             UndirectedEdge[218, 260] -> 
             RGBColor[
              0.6425745195218405, 0.7176659273924942, 0.9670732449047614], 
             UndirectedEdge[115, 169] -> 
             RGBColor[
              0.9917015232264101, 0.9836467221850489, 0.4241933777702308], 
             UndirectedEdge[152, 332] -> 
             RGBColor[
              0.8236759654795647, 0.8619883816120713, 0.9271299847636274], 
             UndirectedEdge[8, 227] -> 
             RGBColor[
              0.25059631435273566`, 0.3807229934817097, 0.9375824614271391], 
             UndirectedEdge[161, 344] -> 
             RGBColor[
              0.7963021029340711, 0.8402901556825634, 0.9343424703967813], 
             UndirectedEdge[255, 324] -> 
             RGBColor[
              0.47123554850170946`, 0.5770030155625201, 0.9526631233895462], 
             UndirectedEdge[135, 221] -> 
             RGBColor[
              0.32465048908604516`, 0.4556176690634678, 0.9419074199807753], 
             UndirectedEdge[179, 257] -> 
             RGBColor[
              0.40399258504419044`, 0.5178235122610793, 0.9477871972040335], 
             UndirectedEdge[40, 350] -> 
             RGBColor[
              0.43863725302511747`, 0.5386907821714452, 0.9514240923182777], 
             UndirectedEdge[358, 397] -> 
             RGBColor[
              0.3681359429599411, 0.48981749047692524`, 0.944863936626815], 
             UndirectedEdge[44, 149] -> 
             RGBColor[
              0.6989771216098827, 0.7637745585978744, 0.971310828999182], 
             UndirectedEdge[215, 218] -> 
             RGBColor[
              0.708434603913118, 0.7692847726871603, 0.9422832817763502], 
             UndirectedEdge[211, 248] -> 
             RGBColor[
              0.40582771053856714`, 0.5247802288254824, 0.947397452041326], 
             UndirectedEdge[38, 103] -> 
             RGBColor[
              0.40206788262335236`, 0.5226727242341449, 0.9468403878394593], 
             UndirectedEdge[79, 213] -> 
             RGBColor[
              0.7431585707863845, 0.7628047723967035, 0.6442342696792716], 
             UndirectedEdge[116, 383] -> 
             RGBColor[
              0.7154627400193055, 0.7730639945461286, 0.8762149380555041], 
             UndirectedEdge[214, 263] -> 
             RGBColor[
              0.5110175085017187, 0.6094316745219056, 0.9562482657363689], 
             UndirectedEdge[203, 275] -> 
             RGBColor[
              0.39269753255719986`, 0.5084627324694171, 0.946915390512242], 
             UndirectedEdge[235, 396] -> 
             RGBColor[
              0.4404249809935893, 0.5479726430841416, 0.95060325186206], 
             UndirectedEdge[170, 361] -> 
             RGBColor[
              0.43084188150907665`, 0.5451889975846107, 0.949338714509785], 
             UndirectedEdge[190, 255] -> 
             RGBColor[
              0.5084300075608993, 0.6097452302028223, 0.955013853073094], 
             UndirectedEdge[67, 113] -> 
             RGBColor[
              0.9106375635288289, 0.8586717273910117, 0.6306059832411572], 
             UndirectedEdge[244, 307] -> 
             RGBColor[
              0.6527975140654568, 0.7198922359232787, 0.9128626227783779], 
             UndirectedEdge[106, 292] -> 
             RGBColor[
              0.993695522932494, 0.9889236859700412, 0.5551747618035211], 
             UndirectedEdge[119, 126] -> 
             RGBColor[
              0.3205055165224079, 0.4520275021612237, 0.9416433059942757], 
             UndirectedEdge[148, 288] -> 
             RGBColor[
              0.38390719559610953`, 0.4990119813546222, 0.946434050389487], 
             UndirectedEdge[143, 277] -> 
             RGBColor[
              0.5758646897482449, 0.6618648861297982, 0.9619607432061721], 
             UndirectedEdge[245, 364] -> 
             RGBColor[
              0.6179316055108797, 0.7006289841389046, 0.9631160975027335], 
             UndirectedEdge[101, 335] -> 
             RGBColor[
              0.5363364590981061, 0.6296393818230341, 0.9585905238100989], 
             UndirectedEdge[175, 296] -> 
             RGBColor[
              0.6645800913719377, 0.7318751085718437, 0.9478793944628419], 
             UndirectedEdge[106, 158] -> 
             RGBColor[
              0.6472160593950517, 0.7107430150943885, 0.7047417898857905], 
             UndirectedEdge[59, 319] -> 
             RGBColor[
              0.32884886978649386`, 0.45925409540944684`, 0.9421749370865256],
              UndirectedEdge[159, 218] -> 
             RGBColor[
              0.6009194952572116, 0.6849731696886685, 0.962961674411523], 
             UndirectedEdge[126, 326] -> 
             RGBColor[
              0.30346764892971445`, 0.434955327822682, 0.940642425394906], 
             UndirectedEdge[130, 371] -> 
             RGBColor[
              0.46564068143209897`, 0.5565873410239002, 0.9546219467546331], 
             UndirectedEdge[108, 262] -> 
             RGBColor[
              0.5163022234205877, 0.6180342338540641, 0.9551091640592755], 
             UndirectedEdge[34, 91] -> 
             RGBColor[
              0.529726450793067, 0.6117966903818296, 0.9601787425620172], 
             UndirectedEdge[173, 323] -> 
             RGBColor[
              0.7388109183310452, 0.7957220034308627, 0.9748972153527875], 
             UndirectedEdge[104, 208] -> 
             RGBColor[
              0.8796278793949606, 0.9049654669032913, 0.8994705449878713], 
             UndirectedEdge[115, 122] -> 
             RGBColor[
              0.7861939290422392, 0.8281187528046128, 0.6947238888140113], 
             UndirectedEdge[275, 297] -> 
             RGBColor[
              0.31971049840944876`, 0.447118078027052, 0.9417471930176818], 
             UndirectedEdge[185, 293] -> 
             RGBColor[
              0.6524053383480322, 0.6004916605114272, 0.596853516567896], 
             UndirectedEdge[92, 256] -> 
             RGBColor[
              0.4570580757992604, 0.5681255638524336, 0.9509457987825457], 
             UndirectedEdge[135, 165] -> 
             RGBColor[
              0.3877415089711027, 0.5102639394410429, 0.9459275239786529], 
             UndirectedEdge[158, 270] -> 
             RGBColor[
              0.27504889240221175`, 0.40642420339470325`, 0.9389749995727094],
              UndirectedEdge[35, 86] -> 
             RGBColor[
              0.9580600380205078, 0.9668244043434207, 0.89517941307071], 
             UndirectedEdge[124, 387] -> 
             RGBColor[
              0.656372263124893, 0.7203486470873066, 0.7914244789721874], 
             UndirectedEdge[170, 261] -> 
             RGBColor[
              0.43084188150907665`, 0.5451889975846107, 0.949338714509785], 
             UndirectedEdge[78, 244] -> 
             RGBColor[
              0.6161399275351729, 0.6823795276426672, 0.9107377996459041], 
             UndirectedEdge[320, 381] -> 
             RGBColor[
              0.4060964863712835, 0.5159970697791986, 0.9482745547734899], 
             UndirectedEdge[90, 166] -> 
             RGBColor[
              0.5953720919753789, 0.6661765763320473, 0.952568304339616], 
             UndirectedEdge[119, 317] -> 
             RGBColor[
              0.475298902003465, 0.5812280440799746, 0.9528532238027831], 
             UndirectedEdge[173, 250] -> 
             RGBColor[
              0.7913928606510521, 0.81614418735156, 0.6691031266409795], 
             UndirectedEdge[234, 355] -> 
             RGBColor[
              0.3736944910348283, 0.4972071814155116, 0.9450650453742073], 
             UndirectedEdge[203, 297] -> 
             RGBColor[
              0.449313815551429, 0.5617217305853939, 0.9503683851262639], 
             UndirectedEdge[48, 388] -> 
             RGBColor[
              0.6395267310024768, 0.7126973192939663, 0.9679511018211628], 
             UndirectedEdge[34, 95] -> 
             RGBColor[
              0.5368865276287137, 0.619322385111186, 0.9605864983454229], 
             UndirectedEdge[133, 299] -> 
             RGBColor[
              0.5845482582984111, 0.6733293639176778, 0.960623080242371], 
             UndirectedEdge[58, 376] -> 
             RGBColor[
              0.556564330692162, 0.6508830224500902, 0.9582339293558579], 
             UndirectedEdge[239, 392] -> 
             RGBColor[
              0.5408100400385605, 0.47821391394315316`, 0.587009029808266], 
             UndirectedEdge[64, 77] -> 
             RGBColor[
              0.4212101998314257, 0.5392528372789404, 0.9480601193650713], 
             UndirectedEdge[73, 112] -> 
             RGBColor[
              0.7548632842832895, 0.8075202810435866, 0.955414204691746], 
             UndirectedEdge[257, 339] -> 
             RGBColor[
              0.7646290121907471, 0.8142867789434824, 0.9197369965993609], 
             UndirectedEdge[35, 85] -> 
             RGBColor[
              0.8222185828343545, 0.8598548225760662, 0.8818653591032957], 
             UndirectedEdge[37, 187] -> 
             RGBColor[
              0.8501116756258722, 0.8253988342973237, 0.6279053736338249], 
             UndirectedEdge[9, 39] -> 
             RGBColor[
              0.6198943491239581, 0.2073736639469763, 0.42152111819076377`], 
             UndirectedEdge[136, 394] -> 
             RGBColor[
              0.50486156053009, 0.5941535069963151, 0.9574345481339419], 
             UndirectedEdge[287, 389] -> 
             RGBColor[
              0.6332784003648305, 0.7094925353956532, 0.9665368655347237], 
             UndirectedEdge[195, 372] -> 
             RGBColor[
              0.5267273159365986, 0.6247067372504336, 0.956543296871132], 
             UndirectedEdge[149, 362] -> 
             RGBColor[
              0.5028089259918554, 0.6065621928045943, 0.9541899295877955], 
             UndirectedEdge[83, 321] -> 
             RGBColor[
              0.7794890464023292, 0.7403080185104909, 0.6144737139473101], 
             UndirectedEdge[227, 308] -> 
             RGBColor[
              0.43468655918189103`, 0.5373891623319673, 0.9507477811087923], 
             UndirectedEdge[100, 146] -> 
             RGBColor[
              0.4760315267050658, 0.5844008487517809, 0.9521985821796978], 
             UndirectedEdge[100, 278] -> 
             RGBColor[
              0.5899239714236812, 0.6749527430504203, 0.9624712579445287], 
             UndirectedEdge[234, 350] -> 
             RGBColor[
              0.4844413698809804, 0.5868338131357015, 0.9540325690121007], 
             UndirectedEdge[278, 352] -> 
             RGBColor[
              0.7686760484154447, 0.8192148382672705, 0.9775781028861198], 
             UndirectedEdge[342, 353] -> 
             RGBColor[
              0.4828275143807508, 0.5790474783783718, 0.9549048098300847], 
             UndirectedEdge[109, 181] -> 
             RGBColor[
              0.6269022664343815, 0.7066241451807989, 0.9647026574596475], 
             UndirectedEdge[59, 296] -> 
             RGBColor[
              0.3393820795144342, 0.46837743226127443`, 0.9428461038962384], 
             UndirectedEdge[168, 378] -> 
             RGBColor[
              0.7355468385532218, 0.791763772764118, 0.9518940786372863], 
             UndirectedEdge[191, 370] -> 
             RGBColor[
              0.8042114627900123, 0.8470244472736765, 0.9811069183704969], 
             UndirectedEdge[153, 184] -> 
             RGBColor[
              0.9378910901526967, 0.952960093378848, 0.9817055993502397], 
             UndirectedEdge[3, 91] -> 
             RGBColor[
              0.20263803959183097`, 0.3303158059777548, 0.9348513086274152], 
             UndirectedEdge[149, 210] -> 
             RGBColor[
              0.7258790186825342, 0.5952053625699875, 0.5883983535112576], 
             UndirectedEdge[3, 312] -> 
             RGBColor[
              0.2259707887512974, 0.3548400047260958, 0.9361800741743377], 
             UndirectedEdge[17, 388] -> 
             RGBColor[
              0.7153708830305009, 0.7764626576434215, 0.9733162749113355], 
             UndirectedEdge[99, 243] -> 
             RGBColor[
              0.629116349263654, 0.7088995435208894, 0.9645502111214839], 
             UndirectedEdge[108, 398] -> 
             RGBColor[
              0.7184084479959496, 0.7759018036899643, 0.8869287846883573], 
             UndirectedEdge[57, 186] -> 
             RGBColor[
              0.5330823084398066, 0.6318192589325807, 0.9563853385466707], 
             UndirectedEdge[180, 398] -> 
             RGBColor[
              0.6776630123108682, 0.7406101552246904, 0.8843325215562781], 
             UndirectedEdge[66, 318] -> 
             RGBColor[
              0.542775524953331, 0.6384314095004475, 0.9576401459244039], 
             UndirectedEdge[374, 382] -> 
             RGBColor[
              0.3897877072750411, 0.5120362535669972, 0.9460579059251977], 
             UndirectedEdge[190, 270] -> 
             RGBColor[
              0.3130063037287607, 0.43996832924196766`, 0.9413691782591965], 
             UndirectedEdge[47, 96] -> 
             RGBColor[
              0.9679506602941317, 0.8984143298747215, 0.5049203466315237], 
             UndirectedEdge[245, 328] -> 
             RGBColor[
              0.6680500403976188, 0.7397818863866383, 0.9681114347088411], 
             UndirectedEdge[142, 143] -> 
             RGBColor[
              0.33310563589636605`, 0.462413007591129, 0.942465510225643], 
             UndirectedEdge[268, 373] -> 
             RGBColor[
              0.49138345304309416`, 0.5964538019641549, 0.953520545692651], 
             UndirectedEdge[69, 390] -> 
             RGBColor[
              0.7032051215411821, 0.7644306600525202, 0.9372127471788507], 
             UndirectedEdge[91, 112] -> 
             RGBColor[
              0.3854255321385406, 0.49750263612078904`, 0.9468031732294102], 
             UndirectedEdge[16, 190] -> 
             RGBColor[
              0.2781850706779843, 0.40336900551191013`, 0.9393861605503527], 
             UndirectedEdge[40, 395] -> 
             RGBColor[
              0.23294636080119718`, 0.36217177322735306`, 0.9365773226831454],
              UndirectedEdge[84, 246] -> 
             RGBColor[
              0.24680813116171124`, 0.37674137276325637`, 0.9373667299985251],
              UndirectedEdge[196, 376] -> 
             RGBColor[
              0.40635424083463545`, 0.5211132949407601, 0.947848183357921], 
             UndirectedEdge[37, 311] -> 
             RGBColor[
              0.785158943268718, 0.774288228522722, 0.6216838053116076], 
             UndirectedEdge[179, 275] -> 
             RGBColor[
              0.263892429026652, 0.3946980530263568, 0.9383396554879797], 
             UndirectedEdge[334, 340] -> 
             RGBColor[
              0.8355692303669513, 0.8720408711705186, 0.9840945089141004], 
             UndirectedEdge[23, 366] -> 
             RGBColor[
              0.6888636515688971, 0.7493951519115063, 0.8513624582127925], 
             UndirectedEdge[295, 351] -> 
             RGBColor[
              0.4731254110607108, 0.5803200005416534, 0.9524454667004567], 
             UndirectedEdge[358, 363] -> 
             RGBColor[
              0.5986972352295257, 0.6836686053379721, 0.9625215157946945], 
             UndirectedEdge[111, 116] -> 
             RGBColor[
              0.37922243140059736`, 0.5028851426307598, 0.9453846958889847], 
             UndirectedEdge[147, 371] -> 
             RGBColor[
              0.5883596391199843, 0.6488866592332287, 0.7019373766387556], 
             UndirectedEdge[33, 311] -> 
             RGBColor[
              0.7846929379874701, 0.8320206191797004, 0.9653605016871819], 
             UndirectedEdge[137, 178] -> 
             RGBColor[
              0.6420805654463748, 0.7079792150359161, 0.868770402857777], 
             UndirectedEdge[328, 386] -> 
             RGBColor[
              0.8712490909783523, 0.897207272748612, 0.8375220762035298], 
             UndirectedEdge[20, 36] -> 
             RGBColor[
              0.2303127783496964, 0.35940371109205416`, 0.9364273440585685], 
             UndirectedEdge[107, 212] -> 
             RGBColor[
              0.83925146380879, 0.8746603526397566, 0.9845297478983503], 
             UndirectedEdge[21, 27] -> 
             RGBColor[
              0.5677076276444676, 0.657081978846324, 0.9604749922269021], 
             UndirectedEdge[138, 329] -> 
             RGBColor[
              0.6414183290280882, 0.71837280690921, 0.9658701186081076], 
             UndirectedEdge[3, 263] -> 
             RGBColor[
              0.4425429532174765, 0.5386309844042805, 0.9523058867042109], 
             UndirectedEdge[239, 269] -> 
             RGBColor[
              0.7854861961245829, 0.6959089863783883, 0.604044277047376], 
             UndirectedEdge[74, 86] -> 
             RGBColor[
              0.8088724235911724, 0.8514657566009493, 0.9813591491321855], 
             UndirectedEdge[91, 179] -> 
             RGBColor[
              0.24275542711764525`, 0.3724817238566655, 0.937135934498654], 
             UndirectedEdge[316, 358] -> 
             RGBColor[
              0.6818730141891206, 0.7493041706349657, 0.9706370832729672], 
             UndirectedEdge[154, 267] -> 
             RGBColor[
              0.34322490991042576`, 0.4717058988040106, 0.9430909656509894], 
             UndirectedEdge[25, 357] -> 
             RGBColor[
              0.37471974362501503`, 0.49898514079121825`, 0.9450977886054951],
              UndirectedEdge[118, 388] -> 
             RGBColor[
              0.7432841673998132, 0.7991239193735598, 0.9755137109066175], 
             UndirectedEdge[305, 340] -> 
             RGBColor[
              0.8046863686704913, 0.8474157155467104, 0.9811488739960359], 
             UndirectedEdge[100, 213] -> 
             RGBColor[
              0.6907676773497838, 0.7191694694619093, 0.6404143567888614], 
             UndirectedEdge[51, 238] -> 
             RGBColor[
              0.4382670577513746, 0.5349514312636762, 0.951933404334167], 
             UndirectedEdge[104, 242] -> 
             RGBColor[
              0.9917027852070597, 0.9895242381089009, 0.6917529931403171], 
             UndirectedEdge[99, 337] -> 
             RGBColor[
              0.5228494527781866, 0.6197025389461052, 0.9569926091050968], 
             UndirectedEdge[143, 302] -> 
             RGBColor[
              0.676105012289886, 0.7393601333671423, 0.8878881685435864], 
             UndirectedEdge[14, 327] -> 
             RGBColor[
              0.6358945034571585, 0.7104371171161512, 0.9673118537300811], 
             UndirectedEdge[162, 348] -> 
             RGBColor[
              0.5106378156815604, 0.6105578403720939, 0.9556082315583314], 
             UndirectedEdge[130, 391] -> 
             RGBColor[
              0.5851236338180522, 0.6716290797459662, 0.9618123337694027], 
             UndirectedEdge[182, 386] -> 
             RGBColor[
              0.9670918259367745, 0.9729543262085347, 0.8437235535740513], 
             UndirectedEdge[32, 217] -> 
             RGBColor[
              0.5484025561966507, 0.6379481255177541, 0.960225980364626], 
             UndirectedEdge[3, 285] -> 
             RGBColor[
              0.5053386366920052, 0.5877378642284585, 0.9585513950814953], 
             UndirectedEdge[212, 274] -> 
             RGBColor[
              0.673853720323772, 0.7432186274603207, 0.9695167450181958], 
             UndirectedEdge[234, 272] -> 
             RGBColor[
              0.2765205570639041, 0.40797101626307075`, 0.93905880869806], 
             UndirectedEdge[24, 104] -> 
             RGBColor[
              0.7232682590775517, 0.7799750152346138, 0.8858285739601305], 
             UndirectedEdge[317, 327] -> 
             RGBColor[
              0.5119551172453569, 0.6129778153275534, 0.9551889254241781], 
             UndirectedEdge[85, 263] -> 
             RGBColor[
              0.6769982659761299, 0.7475954578487247, 0.9684405183101557], 
             UndirectedEdge[169, 300] -> 
             RGBColor[
              0.9668146151305124, 0.9688386426681214, 0.7003861684419441], 
             UndirectedEdge[34, 162] -> 
             RGBColor[
              0.5967688805890362, 0.6779948133168139, 0.9641529719491673], 
             UndirectedEdge[62, 313] -> 
             RGBColor[
              0.7854554282758293, 0.832930793401695, 0.9790892295795981], 
             UndirectedEdge[337, 367] -> 
             RGBColor[
              0.43031095869124525`, 0.545460096671403, 0.9491029187740225], 
             UndirectedEdge[21, 240] -> 
             RGBColor[
              0.7352588627394365, 0.7931090788371552, 0.9742473901192905], 
             UndirectedEdge[258, 378] -> 
             RGBColor[
              0.5404611892093927, 0.6378097667561212, 0.9569662310705835], 
             UndirectedEdge[240, 242] -> 
             RGBColor[
              0.8647320838741612, 0.8912595462048938, 0.768263939746595], 
             UndirectedEdge[16, 380] -> 
             RGBColor[
              0.22589444969046477`, 0.35475976753298466`, 0.9361757267777568],
              UndirectedEdge[38, 222] -> 
             RGBColor[
              0.32329808411026706`, 0.44616069232729416`, 0.9421246220251243],
              UndirectedEdge[61, 147] -> 
             RGBColor[
              0.6060220397379661, 0.6674509621436069, 0.7029432242247694], 
             UndirectedEdge[279, 288] -> 
             RGBColor[
              0.5575273943611806, 0.6516648809221233, 0.9583097452557017], 
             UndirectedEdge[192, 384] -> 
             RGBColor[
              0.6998843095693414, 0.7599740399864112, 0.8900456437786632], 
             UndirectedEdge[196, 289] -> 
             RGBColor[
              0.3434551094804801, 0.46889298534683377`, 0.9432159288507813], 
             UndirectedEdge[9, 384] -> 
             RGBColor[
              0.6070004484986808, 0.6717839830432094, 0.8844105189151686], 
             UndirectedEdge[114, 187] -> 
             RGBColor[
              0.7148971609056444, 0.7772023626099311, 0.9722179259714203], 
             UndirectedEdge[90, 274] -> 
             RGBColor[
              0.3724849867520603, 0.4892838988375756, 0.9455762709108226], 
             UndirectedEdge[270, 324] -> 
             RGBColor[
              0.27581184466957087`, 0.4072261146016654, 0.9390184485756488], 
             UndirectedEdge[42, 45] -> 
             RGBColor[
              0.7594040752925051, 0.8068397112151728, 0.731149827539153], 
             UndirectedEdge[316, 363] -> 
             RGBColor[
              0.8182191974151309, 0.8585763374221285, 0.9823414841247853], 
             UndirectedEdge[44, 250] -> 
             RGBColor[
              0.900247661726898, 0.9017918355754959, 0.6795382183969839], 
             UndirectedEdge[213, 352] -> 
             RGBColor[
              0.8695197543415472, 0.8634315646787596, 0.6555212017304524], 
             UndirectedEdge[80, 378] -> 
             RGBColor[
              0.4366147499646207, 0.5510797713821685, 0.9494604796866857], 
             UndirectedEdge[238, 272] -> 
             RGBColor[
              0.21793127308133073`, 0.34638996402222644`, 0.9357222356503307],
              UndirectedEdge[126, 196] -> 
             RGBColor[
              0.2996957753029055, 0.4309908494903051, 0.9404276227718462], 
             UndirectedEdge[112, 240] -> 
             RGBColor[
              0.6428673106041253, 0.7195177466453844, 0.9660056621021316], 
             UndirectedEdge[52, 89] -> 
             RGBColor[
              0.2930868822974043, 0.42291171397763416`, 0.9400927323485269], 
             UndirectedEdge[99, 177] -> 
             RGBColor[
              0.844425916534379, 0.8776291487704551, 0.9033858291620773], 
             UndirectedEdge[41, 206] -> 
             RGBColor[
              0.39588145293917376`, 0.5168065467222045, 0.9465865015084927], 
             UndirectedEdge[1, 119] -> 
             RGBColor[
              0.6562957314503874, 0.720485587203881, 0.808789219136478], 
             UndirectedEdge[2, 109] -> 
             RGBColor[
              0.5333863966746046, 0.6275041182880197, 0.9582248132052837], 
             UndirectedEdge[8, 100] -> 
             RGBColor[
              0.3465924532630851, 0.47200684122328795`, 0.9434013217783727], 
             UndirectedEdge[203, 322] -> 
             RGBColor[
              0.7429127538501433, 0.7976918576023254, 0.9510820008594312], 
             UndirectedEdge[98, 193] -> 
             RGBColor[
              0.46696055445558776`, 0.5756336211959441, 0.9518721361024316], 
             UndirectedEdge[141, 285] -> 
             RGBColor[
              0.8797797565614711, 0.9069765131695443, 0.9883953726411352], 
             UndirectedEdge[29, 231] -> 
             RGBColor[
              0.6120145290354417, 0.6593388874440249, 0.6575502569932011], 
             UndirectedEdge[225, 398] -> 
             RGBColor[
              0.9309126503804865, 0.9454845500158686, 0.9059095932705112], 
             UndirectedEdge[149, 359] -> 
             RGBColor[
              0.4263854070434636, 0.5372882020558688, 0.9494330563639781], 
             UndirectedEdge[87, 235] -> 
             RGBColor[
              0.5935209861789246, 0.668835733449532, 0.9653286564175223], 
             UndirectedEdge[162, 312] -> 
             RGBColor[
              0.31119539055264167`, 0.44014874325501796`, 0.9411897513590808],
              UndirectedEdge[392, 395] -> 
             RGBColor[
              0.21865369451163263`, 0.34714927474963797`, 0.9357633764820597],
              UndirectedEdge[212, 268] -> 
             RGBColor[
              0.6201469180366783, 0.6981045782544404, 0.9657066425984064], 
             UndirectedEdge[50, 271] -> 
             RGBColor[
              0.8324661621693825, 0.7603400803770689, 0.6147924087139934], 
             UndirectedEdge[200, 207] -> 
             RGBColor[
              0.31591830554298506`, 0.441533965554759, 0.9415897540064162], 
             UndirectedEdge[360, 370] -> 
             RGBColor[
              0.8029397268000602, 0.8460309574527745, 0.980980163612067], 
             UndirectedEdge[134, 246] -> 
             RGBColor[
              0.3170352002856397, 0.44518972700784143`, 0.9415624873997663], 
             UndirectedEdge[88, 191] -> 
             RGBColor[
              0.8205491791298596, 0.8600516988075748, 0.982665224339843], 
             UndirectedEdge[277, 278] -> 
             RGBColor[
              0.7778343723943416, 0.826369390565425, 0.9784909190309327], 
             UndirectedEdge[233, 242] -> 
             RGBColor[
              0.932840093444582, 0.9448858185584685, 0.774940913557127], 
             UndirectedEdge[66, 123] -> 
             RGBColor[
              0.8139807708565345, 0.8118405983529641, 0.638006027940846], 
             UndirectedEdge[315, 316] -> 
             RGBColor[
              0.9298928103173527, 0.9463501469270288, 0.9728875083997938], 
             UndirectedEdge[127, 216] -> 
             RGBColor[
              0.7328001100504019, 0.7912080981732734, 0.9739970661722617], 
             UndirectedEdge[29, 326] -> 
             RGBColor[
              0.6319966598016136, 0.680341373819537, 0.6586882097794213], 
             UndirectedEdge[76, 145] -> 
             RGBColor[
              0.7304278263553861, 0.784851512566263, 0.847265321043989], 
             UndirectedEdge[21, 104] -> 
             RGBColor[
              0.8622295640723351, 0.8913737707411623, 0.8977364435130126], 
             UndirectedEdge[27, 112] -> 
             RGBColor[
              0.47531607550915633`, 0.5834906466545533, 0.9522332642097432], 
             UndirectedEdge[190, 221] -> 
             RGBColor[
              0.34740472668898814`, 0.4753262460139016, 0.9433572998800526], 
             UndirectedEdge[310, 324] -> 
             RGBColor[
              0.5455880702539488, 0.6351328402769916, 0.9600430735476031], 
             UndirectedEdge[11, 312] -> 
             RGBColor[
              0.49119181025879044`, 0.5878388836731803, 0.9553811441064721], 
             UndirectedEdge[177, 225] -> 
             RGBColor[
              0.9305537247859277, 0.9453361250585516, 0.9118579192420144], 
             UndirectedEdge[253, 316] -> 
             RGBColor[
              0.583364780414539, 0.6602128762689634, 0.9644394178545836], 
             UndirectedEdge[17, 323] -> 
             RGBColor[
              0.6995011971586906, 0.7638086009003875, 0.9718026101058466], 
             UndirectedEdge[315, 397] -> 
             RGBColor[
              0.6161557390881732, 0.6868634667689884, 0.9471143617536415], 
             UndirectedEdge[43, 296] -> 
             RGBColor[
              0.6291937317478173, 0.7043088163227017, 0.9670342390307113], 
             UndirectedEdge[50, 287] -> 
             RGBColor[
              0.5846925149368329, 0.6713567647309944, 0.9617420735824549], 
             UndirectedEdge[253, 369] -> 
             RGBColor[
              0.5139101550713613, 0.6052963804617449, 0.9576914467373248], 
             UndirectedEdge[187, 220] -> 
             RGBColor[
              0.8449841813226977, 0.879654694074237, 0.979472755012469], 
             UndirectedEdge[211, 340] -> 
             RGBColor[
              0.6382235063661355, 0.7150567322816168, 0.9661125012854834], 
             UndirectedEdge[213, 227] -> 
             RGBColor[
              0.5947715384394344, 0.627885621720331, 0.6345954964376278], 
             UndirectedEdge[17, 389] -> 
             RGBColor[
              0.6832786165678151, 0.7508731554874426, 0.9702552858870201], 
             UndirectedEdge[117, 376] -> 
             RGBColor[
              0.7095933744198643, 0.771944494279485, 0.9726631589911512], 
             UndirectedEdge[186, 330] -> 
             RGBColor[
              0.4167306027949268, 0.5246303245533978, 0.9491117113724111], 
             UndirectedEdge[24, 337] -> 
             RGBColor[
              0.4012465115093754, 0.5218642691107366, 0.9468148590252876], 
             UndirectedEdge[73, 99] -> 
             RGBColor[
              0.8298964726926286, 0.8675511275641774, 0.9619258132358319], 
             UndirectedEdge[114, 155] -> 
             RGBColor[
              0.48503340937502654`, 0.5858560679366188, 0.9543195908373928], 
             UndirectedEdge[123, 232] -> 
             RGBColor[
              0.6955697690191924, 0.7153941424196474, 0.6286269920719472], 
             UndirectedEdge[53, 289] -> 
             RGBColor[
              0.49300605836695977`, 0.5981275925219056, 0.9535497848569646], 
             UndirectedEdge[126, 376] -> 
             RGBColor[
              0.4298846342609254, 0.5445064398092422, 0.9492372241331888], 
             UndirectedEdge[207, 254] -> 
             RGBColor[
              0.3058460191579413, 0.4309473539442362, 0.9410161521974003], 
             UndirectedEdge[291, 304] -> 
             RGBColor[
              0.5569903851073594, 0.6512289126178801, 0.958267469920111], 
             UndirectedEdge[333, 368] -> 
             RGBColor[
              0.7249300116125421, 0.6721039946997756, 0.6046735082586127], 
             UndirectedEdge[26, 171] -> 
             RGBColor[
              0.44102491006911937`, 0.5488836142743851, 0.9506118924829925], 
             UndirectedEdge[81, 384] -> 
             RGBColor[
              0.8184086340896232, 0.8572672527198083, 0.89911505645823], 
             UndirectedEdge[120, 233] -> 
             RGBColor[
              0.6856812153088357, 0.7526091251825368, 0.9706913913222758], 
             UndirectedEdge[224, 290] -> 
             RGBColor[
              0.6405756594365557, 0.5136577689890023, 0.579719192227784], 
             UndirectedEdge[393, 396] -> 
             RGBColor[
              0.436959634838606, 0.5443303445596178, 0.9504059055250538], 
             UndirectedEdge[2, 365] -> 
             RGBColor[
              0.27677828181016106`, 0.4057703408405482, 0.9391639816771906], 
             UndirectedEdge[210, 387] -> 
             RGBColor[
              0.9344550036053355, 0.7566410073521186, 0.429138260167039], 
             UndirectedEdge[23, 307] -> 
             RGBColor[
              0.6566323956187713, 0.7214780579975347, 0.8493087110846311], 
             UndirectedEdge[120, 244] -> 
             RGBColor[
              0.742647380964869, 0.7964632824494566, 0.9189338165414815], 
             UndirectedEdge[42, 248] -> 
             RGBColor[
              0.42078892213511426`, 0.536926414394461, 0.94857525342293], 
             UndirectedEdge[49, 393] -> 
             RGBColor[
              0.599125090767712, 0.6724248659187352, 0.965985862539238], 
             UndirectedEdge[375, 377] -> 
             RGBColor[
              0.7849782631109905, 0.827576358105039, 0.7310624183229972], 
             UndirectedEdge[269, 350] -> 
             RGBColor[
              0.6690207428215753, 0.7413633561289652, 0.9676453933563021], 
             UndirectedEdge[77, 207] -> 
             RGBColor[
              0.39540378676297905`, 0.5169006193470866, 0.946415757544065], 
             UndirectedEdge[200, 368] -> 
             RGBColor[
              0.38491838348396856`, 0.4991724537870908, 0.946573773566938], 
             UndirectedEdge[384, 389] -> 
             RGBColor[
              0.9156115799849527, 0.9333830405248915, 0.9087555426456213], 
             UndirectedEdge[1, 361] -> 
             RGBColor[
              0.6572747538673923, 0.7213335672143932, 0.808851601579174], 
             UndirectedEdge[150, 380] -> 
             RGBColor[
              0.6263826582136882, 0.6943290584605598, 0.9288764529271532], 
             UndirectedEdge[150, 381] -> 
             RGBColor[
              0.7784780122602573, 0.826024455191571, 0.9393746469269766], 
             UndirectedEdge[232, 279] -> 
             RGBColor[
              0.5098254262201507, 0.6122689034333657, 0.9547394207327488], 
             UndirectedEdge[132, 341] -> 
             RGBColor[
              0.4143889286808857, 0.5262854479646228, 0.9486036587701681], 
             UndirectedEdge[1, 14] -> 
             RGBColor[
              0.9377491553500337, 0.9495019231087932, 0.8322954228037267], 
             UndirectedEdge[171, 342] -> 
             RGBColor[
              0.42989629213023917`, 0.5371867312254914, 0.9499781341546882], 
             UndirectedEdge[140, 325] -> 
             RGBColor[
              0.27454803818862467`, 0.405897773860232, 0.938946476666193], 
             UndirectedEdge[89, 306] -> 
             RGBColor[
              0.292023756972705, 0.4217943018553364, 0.9400321889340382], 
             UndirectedEdge[130, 147] -> 
             RGBColor[
              0.8701949056131535, 0.8949524768469418, 0.7227805048795846], 
             UndirectedEdge[4, 183] -> 
             RGBColor[
              0.6003719823714488, 0.6826473057183496, 0.9637104874148559], 
             UndirectedEdge[80, 151] -> 
             RGBColor[
              0.4798434887371228, 0.5861748089501746, 0.9528636043549448], 
             UndirectedEdge[236, 286] -> 
             RGBColor[
              0.8680338106121968, 0.897610614704802, 0.9872750338307636], 
             UndirectedEdge[108, 180] -> 
             RGBColor[
              0.40659900554749523`, 0.5265973551701775, 0.947129106985471], 
             UndirectedEdge[9, 320] -> 
             RGBColor[
              0.23009270632018697`, 0.3591724014356672, 0.9364148112820554], 
             UndirectedEdge[35, 97] -> 
             RGBColor[
              0.8345066291164299, 0.8694543377242343, 0.8830901167183716], 
             UndirectedEdge[154, 236] -> 
             RGBColor[
              0.6194879911597029, 0.6964575376648785, 0.9661601415478669], 
             UndirectedEdge[60, 259] -> 
             RGBColor[
              0.4067688936067395, 0.5267445036682727, 0.9471399321023801], 
             UndirectedEdge[179, 399] -> 
             RGBColor[
              0.3533946010682234, 0.4764411553422978, 0.9438881098722485], 
             UndirectedEdge[314, 352] -> 
             RGBColor[
              0.8106102365285113, 0.8522247118685111, 0.9816912180463864], 
             UndirectedEdge[85, 88] -> 
             RGBColor[
              0.7560486846604868, 0.8096634223061865, 0.9762364178425269], 
             UndirectedEdge[70, 267] -> 
             RGBColor[
              0.6439962521487426, 0.7137068363367625, 0.9416117610323953], 
             UndirectedEdge[31, 192] -> 
             RGBColor[
              0.45193412964681834`, 0.5647853950423042, 0.950315942529009], 
             UndirectedEdge[221, 255] -> 
             RGBColor[
              0.47839159289391886`, 0.5837274651929036, 0.9530998318524411], 
             UndirectedEdge[11, 211] -> 
             RGBColor[
              0.6052676266741523, 0.689311348592277, 0.9628277671879922], 
             UndirectedEdge[211, 312] -> 
             RGBColor[
              0.38156152633150087`, 0.49994728398747135`, 0.9459909106003734],
              UndirectedEdge[123, 280] -> 
             RGBColor[
              0.6283869078214809, 0.6558680808664286, 0.6243950640296201], 
             UndirectedEdge[178, 278] -> 
             RGBColor[
              0.8790967233514007, 0.9042872728174767, 0.8874806886001165], 
             UndirectedEdge[83, 364] -> 
             RGBColor[
              0.636401558474589, 0.7156237240167428, 0.9645701198577037], 
             UndirectedEdge[10, 313] -> 
             RGBColor[
              0.6084110964010798, 0.6861341638274946, 0.9657899875914764], 
             UndirectedEdge[32, 242] -> 
             RGBColor[
              0.6506921886474275, 0.7148625668026667, 0.7515331239169938], 
             UndirectedEdge[44, 369] -> 
             RGBColor[
              0.7915523464879914, 0.8370911083920496, 0.9798568365576372], 
             UndirectedEdge[110, 375] -> 
             RGBColor[
              0.7857509131921534, 0.8292289785017404, 0.815160611414018], 
             UndirectedEdge[275, 290] -> 
             RGBColor[
              0.5657569587515141, 0.44463275154935833`, 0.5751063556542695], 
             UndirectedEdge[362, 369] -> 
             RGBColor[
              0.5953841508699642, 0.6798787425987696, 0.9627359371462507], 
             UndirectedEdge[266, 338] -> 
             RGBColor[
              0.6035219299164634, 0.6779242338174019, 0.9661137891020561], 
             UndirectedEdge[350, 395] -> 
             RGBColor[
              0.46407128124718555`, 0.565423558443368, 0.9528725225992516], 
             UndirectedEdge[141, 172] -> 
             RGBColor[
              0.9540085361347301, 0.9651593411487217, 0.9606249514509376], 
             UndirectedEdge[123, 275] -> 
             RGBColor[
              0.6127840830706675, 0.6394685227770966, 0.6235065062423719], 
             UndirectedEdge[46, 315] -> 
             RGBColor[
              0.9155475578132309, 0.934911631971748, 0.9715192454097925], 
             UndirectedEdge[185, 205] -> 
             RGBColor[
              0.8661932255014511, 0.7729457047766066, 0.6151061559670805], 
             UndirectedEdge[3, 86] -> 
             RGBColor[
              0.5547526355312625, 0.6271392455956157, 0.9632645464031813], 
             UndirectedEdge[316, 397] -> 
             RGBColor[
              0.5876579051455463, 0.6647252225610816, 0.9646839049569057], 
             UndirectedEdge[11, 214] -> 
             RGBColor[
              0.518151444378191, 0.6150047594485266, 0.9569593097941145], 
             UndirectedEdge[3, 34] -> 
             RGBColor[
              0.5115442787876919, 0.5926860747878917, 0.9591432947644241], 
             UndirectedEdge[5, 100] -> 
             RGBColor[
              0.5273384792925266, 0.6260541442141556, 0.9562376534309427], 
             UndirectedEdge[25, 245] -> 
             RGBColor[
              0.4610113597112022, 0.5700527227661774, 0.9516113177189574], 
             UndirectedEdge[183, 325] -> 
             RGBColor[
              0.3332073491160611, 0.45895597234212, 0.9426017960287427], 
             UndirectedEdge[149, 266] -> 
             RGBColor[
              0.7530632502791172, 0.8069013694698697, 0.9764696122349106], 
             UndirectedEdge[73, 78] -> 
             RGBColor[
              0.603061725987883, 0.6729016324203747, 0.9452269432057808], 
             UndirectedEdge[40, 167] -> 
             RGBColor[
              0.4794000842580801, 0.5705350157396274, 0.9554869503852637], 
             UndirectedEdge[5, 175] -> 
             RGBColor[
              0.8014220112331658, 0.8452790271091971, 0.9580139745360036], 
             UndirectedEdge[279, 309] -> 
             RGBColor[
              0.6068069952894837, 0.6916722809764424, 0.9621892159579037], 
             UndirectedEdge[66, 257] -> 
             RGBColor[
              0.604391059218625, 0.6893566147216652, 0.9622412618181878], 
             UndirectedEdge[238, 309] -> 
             RGBColor[
              0.4022853618883218, 0.5065400143422921, 0.9485537301037397], 
             UndirectedEdge[40, 355] -> 
             RGBColor[
              0.3278903741789653, 0.44906415045125536`, 0.9424565686803844], 
             UndirectedEdge[31, 271] -> 
             RGBColor[
              0.7064461373153913, 0.659605139818219, 0.6037956400290329], 
             UndirectedEdge[271, 391] -> 
             RGBColor[
              0.6713040522805891, 0.6302457980667406, 0.6012582959213357], 
             UndirectedEdge[264, 348] -> 
             RGBColor[
              0.7803134389887066, 0.8289063717253138, 0.9785787039465634], 
             UndirectedEdge[146, 302] -> 
             RGBColor[
              0.7641822502173672, 0.8133127435041297, 0.8941456686035161], 
             UndirectedEdge[86, 91] -> 
             RGBColor[
              0.5729348075366376, 0.6462498611895535, 0.9642999942007744], 
             UndirectedEdge[232, 257] -> 
             RGBColor[
              0.4859800573812829, 0.5929101587883485, 0.9528622259492889], 
             UndirectedEdge[201, 385] -> 
             RGBColor[
              0.6422120281486832, 0.7181255436816198, 0.96654220966045], 
             UndirectedEdge[204, 297] -> 
             RGBColor[
              0.37246614784403714`, 0.4970331893947526, 0.9449541914751076], 
             UndirectedEdge[241, 323] -> 
             RGBColor[
              0.730463637706728, 0.7889453049793352, 0.9742400868449448], 
             UndirectedEdge[269, 395] -> 
             RGBColor[
              0.46332985059765497`, 0.5648443471848731, 0.9527986237211697], 
             UndirectedEdge[52, 342] -> 
             RGBColor[
              0.2507264174555056, 0.38085974009173407`, 0.9375898706063717], 
             UndirectedEdge[201, 245] -> 
             RGBColor[
              0.6902411950069125, 0.7571177850264403, 0.9703232416121651], 
             UndirectedEdge[131, 330] -> 
             RGBColor[
              0.2614881624943658, 0.39217101646162134`, 0.9382027360657597], 
             UndirectedEdge[159, 349] -> 
             RGBColor[
              0.499583598450466, 0.591191310350109, 0.9567246888491502], 
             UndirectedEdge[15, 33] -> 
             RGBColor[
              0.8017930441245518, 0.845748389657752, 0.9668125674359993], 
             UndirectedEdge[16, 212] -> 
             RGBColor[
              0.5108025607602698, 0.5913933382424799, 0.9591787927849553], 
             UndirectedEdge[246, 269] -> 
             RGBColor[
              0.46778967896206913`, 0.5695319095653226, 0.9530526043487983], 
             UndirectedEdge[150, 294] -> 
             RGBColor[
              0.8711945713674087, 0.8994557464799176, 0.9479317808336664], 
             UndirectedEdge[77, 200] -> 
             RGBColor[
              0.3177085697665465, 0.44308460244391173`, 0.941703828059673], 
             UndirectedEdge[21, 285] -> 
             RGBColor[
              0.7805176813740262, 0.8285160265632634, 0.9787449877006493], 
             UndirectedEdge[275, 280] -> 
             RGBColor[
              0.27869704016603297`, 0.41025863800040724`, 0.9391827561909081],
              UndirectedEdge[171, 353] -> 
             RGBColor[
              0.6619666883509303, 0.7353422011251057, 0.9672913250186945], 
             UndirectedEdge[197, 252] -> 
             RGBColor[
              0.35300643227766687`, 0.4783118192723856, 0.9437825715508544], 
             UndirectedEdge[15, 361] -> 
             RGBColor[
              0.4861057499005307, 0.5898998295186588, 0.9537951714217341], 
             UndirectedEdge[348, 366] -> 
             RGBColor[
              0.525287990611929, 0.6232470855575772, 0.9565417277502534], 
             UndirectedEdge[235, 298] -> 
             RGBColor[
              0.4914977058738121, 0.5883456052683452, 0.9553692435959256], 
             UndirectedEdge[62, 298] -> 
             RGBColor[
              0.6946283918132989, 0.7613682461466403, 0.9701977244907116], 
             UndirectedEdge[110, 308] -> 
             RGBColor[
              0.8216944179771022, 0.8583134133050419, 0.8180559346509781], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.6089744237295536, 0.6705486313502073, 0.7025639853080706], 
             UndirectedEdge[204, 290] -> 
             RGBColor[
              0.6185126081861025, 0.49454786291705893`, 0.5783133541116954], 
             UndirectedEdge[35, 93] -> 
             RGBColor[
              0.6834881662511728, 0.7452939148872726, 0.8714094741545677], 
             UndirectedEdge[162, 211] -> 
             RGBColor[
              0.4252712069680037, 0.5416212081741147, 0.9486363744406009], 
             UndirectedEdge[66, 275] -> 
             RGBColor[
              0.4642909032010867, 0.5662311554869428, 0.952793720102134], 
             UndirectedEdge[36, 277] -> 
             RGBColor[
              0.5349965552458152, 0.6239423998044302, 0.9594490984070487], 
             UndirectedEdge[174, 246] -> 
             RGBColor[
              0.28696935024253134`, 0.4189533603855593, 0.9396538520119786], 
             UndirectedEdge[218, 329] -> 
             RGBColor[
              0.5900350386902853, 0.6764701494936519, 0.9618768135019615], 
             UndirectedEdge[186, 188] -> 
             RGBColor[
              0.48143527717744916`, 0.5874796051980131, 0.9529854590329667], 
             UndirectedEdge[230, 245] -> 
             RGBColor[
              0.7479268769053209, 0.8028874520272318, 0.9758856798163134], 
             UndirectedEdge[57, 368] -> 
             RGBColor[
              0.49972872748982183`, 0.6047413193556844, 0.9537596224760952], 
             UndirectedEdge[293, 316] -> 
             RGBColor[
              0.6475042494570717, 0.719780942588528, 0.968379367546933], 
             UndirectedEdge[8, 308] -> 
             RGBColor[
              0.4645435345700228, 0.5687707365064703, 0.9524480916877095], 
             UndirectedEdge[37, 361] -> 
             RGBColor[
              0.6358962086548992, 0.6494831394667996, 0.6109354129655205], 
             UndirectedEdge[19, 331] -> 
             RGBColor[
              0.5583483515274877, 0.6520449278715057, 0.9585702166969452], 
             UndirectedEdge[98, 276] -> 
             RGBColor[
              0.36912934895794525`, 0.4941430219120083, 0.9447415736007013], 
             UndirectedEdge[326, 336] -> 
             RGBColor[
              0.2709181923422516, 0.4020825757301747, 0.9387397623151177], 
             UndirectedEdge[4, 13] -> 
             RGBColor[
              0.750056247423196, 0.8046689082163969, 0.9757222551351457], 
             UndirectedEdge[137, 300] -> 
             RGBColor[
              0.6179249943411187, 0.691107898344753, 0.9608842608672399], 
             UndirectedEdge[57, 163] -> 
             RGBColor[
              0.4412224985257618, 0.5561920756709783, 0.9494442616930368], 
             UndirectedEdge[28, 304] -> 
             RGBColor[
              0.7097152736217914, 0.6622591719446669, 0.6040529984143135], 
             UndirectedEdge[83, 328] -> 
             RGBColor[
              0.6865199933613283, 0.7547766262644766, 0.9695654570638113], 
             UndirectedEdge[206, 321] -> 
             RGBColor[
              0.6265784815784501, 0.6125414565571633, 0.6034381510446447], 
             UndirectedEdge[295, 373] -> 
             RGBColor[
              0.5910365605284471, 0.6788691315874431, 0.9609477095645089], 
             UndirectedEdge[29, 235] -> 
             RGBColor[
              0.6248771601543411, 0.6728583282879043, 0.658282764806865], 
             UndirectedEdge[234, 392] -> 
             RGBColor[
              0.2390237831454275, 0.36855952944197146`, 0.9369234228949086], 
             UndirectedEdge[42, 275] -> 
             RGBColor[
              0.39432699067758836`, 0.5097855999778003, 0.9470436674243807], 
             UndirectedEdge[107, 324] -> 
             RGBColor[
              0.5694395146673148, 0.6538938052688845, 0.9623863859802], 
             UndirectedEdge[75, 329] -> 
             RGBColor[
              0.7440093105971186, 0.7999449952094433, 0.9751195529841599], 
             UndirectedEdge[267, 383] -> 
             RGBColor[
              0.6560942454515373, 0.721641988498827, 0.8724320300791444], 
             UndirectedEdge[253, 362] -> 
             RGBColor[
              0.34680858025295513`, 0.47079621195582966`, 0.9434662745150355],
              UndirectedEdge[137, 252] -> 
             RGBColor[
              0.29082195672271594`, 0.42300269406559243`, 0.9398732522516045],
              UndirectedEdge[131, 203] -> 
             RGBColor[
              0.4050684047097061, 0.5214653034602981, 0.947619893380262], 
             UndirectedEdge[52, 199] -> 
             RGBColor[
              0.6013702541682302, 0.6722915681527029, 0.9518239803788117], 
             UndirectedEdge[41, 386] -> 
             RGBColor[
              0.7335211153800769, 0.7870037551596676, 0.8255786835508767], 
             UndirectedEdge[59, 122] -> 
             RGBColor[
              0.44517536020701365`, 0.5565746667962641, 0.9505364213591312], 
             UndirectedEdge[32, 172] -> 
             RGBColor[
              0.6411514715094903, 0.710649438923942, 0.9342880947320111], 
             UndirectedEdge[55, 156] -> 
             RGBColor[
              0.5927787635725946, 0.6701380232091154, 0.9649709167336377], 
             UndirectedEdge[97, 214] -> 
             RGBColor[
              0.49967378191142686`, 0.6005698690940544, 0.9551176290830006], 
             UndirectedEdge[133, 155] -> 
             RGBColor[
              0.39870503884329245`, 0.5163722434701806, 0.9471123003503683], 
             UndirectedEdge[186, 273] -> 
             RGBColor[
              0.7962686174791007, 0.8374103079769175, 0.7866947935639108], 
             UndirectedEdge[74, 179] -> 
             RGBColor[
              0.4786930431721801, 0.5776976192680612, 0.954195089430065], 
             UndirectedEdge[10, 62] -> 
             RGBColor[
              0.49868716983991285`, 0.599809222405701, 0.9550150170990359], 
             UndirectedEdge[273, 322] -> 
             RGBColor[
              0.9788705263189769, 0.9811775540271684, 0.7792479257364284], 
             UndirectedEdge[18, 148] -> 
             RGBColor[
              0.5926738347993843, 0.6647448672006095, 0.9604638424204698], 
             UndirectedEdge[78, 172] -> 
             RGBColor[
              0.6105533505165675, 0.6784888737274581, 0.9325455770073277], 
             UndirectedEdge[84, 269] -> 
             RGBColor[
              0.4472977643716868, 0.5479936080684039, 0.9518856201279471], 
             UndirectedEdge[103, 254] -> 
             RGBColor[
              0.29737416448876447`, 0.42360945923759186`, 0.9404763331092474],
              UndirectedEdge[46, 343] -> 
             RGBColor[
              0.9191163873782925, 0.9375732592179489, 0.9654781478559673], 
             UndirectedEdge[1, 317] -> 
             RGBColor[
              0.813809769138232, 0.8520426213201954, 0.8201724944978237], 
             UndirectedEdge[27, 399] -> 
             RGBColor[
              0.42134992891839984`, 0.5393738635910892, 0.9480690227789357], 
             UndirectedEdge[247, 253] -> 
             RGBColor[
              0.4290966564494836, 0.5382811497041612, 0.9497564707019001], 
             UndirectedEdge[27, 357] -> 
             RGBColor[
              0.4083210995180163, 0.5280889464124832, 0.9472388372904847], 
             UndirectedEdge[41, 55] -> 
             RGBColor[
              0.37821131669276065`, 0.4992508525638216, 0.9455429855802698], 
             UndirectedEdge[183, 272] -> 
             RGBColor[
              0.3278223017154955, 0.4532959460924002, 0.9422951255457441], 
             UndirectedEdge[131, 238] -> 
             RGBColor[
              0.23488897902297018`, 0.3642135881475457, 0.9366879519170292], 
             UndirectedEdge[13, 131] -> 
             RGBColor[
              0.4944642727088821, 0.5931411727157667, 0.9552726095327326], 
             UndirectedEdge[55, 328] -> 
             RGBColor[
              0.5159392922910361, 0.6094543701527662, 0.9574863782329229], 
             UndirectedEdge[40, 392] -> 
             RGBColor[
              0.19321966628956455`, 0.32041649847771514`, 0.9343149462010858],
              UndirectedEdge[39, 347] -> 
             RGBColor[
              0.8463366076088316, 0.3982798530918061, 0.43972566195836327`], 
             UndirectedEdge[195, 362] -> 
             RGBColor[
              0.5448192090611599, 0.6403770257499404, 0.9576960963029962], 
             UndirectedEdge[46, 250] -> 
             RGBColor[
              0.9262904137663328, 0.922557619140069, 0.6820221993351444], 
             UndirectedEdge[22, 47] -> 
             RGBColor[
              0.7188308171496047, 0.7034109908196082, 0.6125414692638875], 
             UndirectedEdge[79, 100] -> 
             RGBColor[
              0.46512251022190343`, 0.5755444177251575, 0.9513397844410991], 
             UndirectedEdge[45, 148] -> 
             RGBColor[
              0.6184966261214715, 0.6807444954606864, 0.7218494001517312], 
             UndirectedEdge[65, 68] -> 
             RGBColor[
              0.45764986730915536`, 0.5698778613172117, 0.9506409696020074], 
             UndirectedEdge[86, 162] -> 
             RGBColor[
              0.6399772373326068, 0.7124479841245379, 0.9682742235879244], 
             UndirectedEdge[3, 264] -> 
             RGBColor[
              0.5393560926949464, 0.6148624602659589, 0.9617960104027974], 
             UndirectedEdge[55, 386] -> 
             RGBColor[
              0.6397124353441203, 0.704008484263765, 0.8195433794409905], 
             UndirectedEdge[315, 362] -> 
             RGBColor[
              0.6933366101557689, 0.7569334826138949, 0.9519143650602455], 
             UndirectedEdge[92, 182] -> 
             RGBColor[
              0.659892973411495, 0.7291234173203918, 0.9666710330217396], 
             UndirectedEdge[202, 341] -> 
             RGBColor[
              0.6196209320638557, 0.7015700434057435, 0.9635433626026455], 
             UndirectedEdge[86, 125] -> 
             RGBColor[
              0.9324145641321271, 0.9488408493364346, 0.989767314666812], 
             UndirectedEdge[155, 353] -> 
             RGBColor[
              0.5016721253158913, 0.5988543592885471, 0.9559779825447373], 
             UndirectedEdge[119, 235] -> 
             RGBColor[
              0.2936274970756545, 0.42511579009348577`, 0.9400636228695115], 
             UndirectedEdge[139, 204] -> 
             RGBColor[
              0.2739453366403509, 0.39972987523009273`, 0.9391147959717512], 
             UndirectedEdge[167, 174] -> 
             RGBColor[
              0.5289632453350002, 0.622629040517384, 0.9583094990864682], 
             UndirectedEdge[218, 349] -> 
             RGBColor[
              0.3450807644046355, 0.467303547874112, 0.9434292672326307], 
             UndirectedEdge[362, 397] -> 
             RGBColor[
              0.3511017049839624, 0.4753085582479478, 0.9437107616173575], 
             UndirectedEdge[70, 108] -> 
             RGBColor[
              0.7069431761682171, 0.7682282981180384, 0.9456226833691368], 
             UndirectedEdge[71, 157] -> 
             RGBColor[
              0.9277308626520705, 0.9443901196191204, 0.9644938684588243], 
             UndirectedEdge[186, 238] -> 
             RGBColor[
              0.3901314193235312, 0.4966728962393221, 0.9475969272236808], 
             UndirectedEdge[51, 246] -> 
             RGBColor[
              0.4809460814645673, 0.5798097911926365, 0.9543639115966758], 
             UndirectedEdge[109, 305] -> 
             RGBColor[
              0.7799289064304631, 0.8280749978811184, 0.9786812815315886], 
             UndirectedEdge[125, 248] -> 
             RGBColor[
              0.6278989015592281, 0.7013745533049257, 0.9640893838789211], 
             UndirectedEdge[106, 390] -> 
             RGBColor[
              0.9843752579759573, 0.9843686858077569, 0.6973850026431253], 
             UndirectedEdge[1, 231] -> 
             RGBColor[
              0.6192757330915222, 0.682410926489827, 0.8066503857508882], 
             UndirectedEdge[104, 399] -> 
             RGBColor[
              0.7158718653462673, 0.7736656554859275, 0.8853304740650463], 
             UndirectedEdge[244, 366] -> 
             RGBColor[
              0.6850287700155826, 0.7478093298372502, 0.9149163699065394], 
             UndirectedEdge[64, 289] -> 
             RGBColor[
              0.42798559288032784`, 0.545121342196743, 0.9484918414189025], 
             UndirectedEdge[160, 233] -> 
             RGBColor[
              0.606735075648282, 0.685482339153392, 0.9653149734170449], 
             UndirectedEdge[100, 302] -> 
             RGBColor[
              0.7008823402976042, 0.7608210095427121, 0.8894669579745074], 
             UndirectedEdge[177, 337] -> 
             RGBColor[
              0.6671781398140123, 0.7316911440054932, 0.8896356311451901], 
             UndirectedEdge[124, 219] -> 
             RGBColor[
              0.46776915776087524`, 0.5751278856989663, 0.952256910558342], 
             UndirectedEdge[2, 181] -> 
             RGBColor[
              0.4289939176036341, 0.5441159831433369, 0.9490751867047524], 
             UndirectedEdge[185, 198] -> 
             RGBColor[
              0.7981156108692801, 0.719753212851219, 0.6083234007801842], 
             UndirectedEdge[11, 35] -> 
             RGBColor[
              0.8529842915831941, 0.8838892280787065, 0.8849317974294854], 
             UndirectedEdge[5, 56] -> 
             RGBColor[
              0.5881753321419965, 0.6765462574864527, 0.9607224631849027], 
             UndirectedEdge[69, 107] -> 
             RGBColor[
              0.6331941666573614, 0.7096411240717828, 0.9664295076710456], 
             UndirectedEdge[51, 350] -> 
             RGBColor[
              0.6821771453240735, 0.7516412377562791, 0.9689567006041795], 
             UndirectedEdge[226, 392] -> 
             RGBColor[
              0.2501659890774701, 0.37910028530953355`, 0.9376008094470689], 
             UndirectedEdge[81, 292] -> 
             RGBColor[
              0.8211743321657573, 0.8577253161373617, 0.8034426686108029], 
             UndirectedEdge[51, 272] -> 
             RGBColor[
              0.47425633250699706`, 0.5727784408836484, 0.9539829402901389], 
             UndirectedEdge[10, 261] -> 
             RGBColor[
              0.32069287355739673`, 0.45218978140809274`, 0.9416552442188719],
              UndirectedEdge[132, 244] -> 
             RGBColor[
              0.6253621580805407, 0.6920726766690373, 0.9112629920323954], 
             UndirectedEdge[53, 376] -> 
             RGBColor[
              0.5559051897211151, 0.6503479021158319, 0.9581820393641043], 
             UndirectedEdge[242, 364] -> 
             RGBColor[
              0.8204997386858683, 0.856704901965525, 0.763855272952993], 
             UndirectedEdge[29, 327] -> 
             RGBColor[
              0.6856907426361989, 0.7291633194056575, 0.6620247920001858], 
             UndirectedEdge[328, 364] -> 
             RGBColor[
              0.6973575130385289, 0.7635002563898794, 0.9704697377893546], 
             UndirectedEdge[257, 279] -> 
             RGBColor[
              0.5671398962891642, 0.6594687430255374, 0.9590664766192273], 
             UndirectedEdge[13, 322] -> 
             RGBColor[
              0.8323086218493193, 0.8693677268577942, 0.9587347170119018], 
             UndirectedEdge[21, 24] -> 
             RGBColor[
              0.5958526519557144, 0.6813627595468784, 0.9622951765152479], 
             UndirectedEdge[56, 122] -> 
             RGBColor[
              0.5571266929733478, 0.6513395734840889, 0.9582782005746339], 
             UndirectedEdge[87, 393] -> 
             RGBColor[
              0.5900556400239414, 0.6651934349250082, 0.9651313100805162], 
             UndirectedEdge[27, 74] -> 
             RGBColor[
              0.5466483710223565, 0.6406303275168526, 0.9583760023367524], 
             UndirectedEdge[93, 288] -> 
             RGBColor[
              0.4499875917658642, 0.5622572980344052, 0.9504245866264859], 
             UndirectedEdge[125, 211] -> 
             RGBColor[
              0.7177085337675239, 0.7780140733860115, 0.9701294655194885], 
             UndirectedEdge[265, 304] -> 
             RGBColor[
              0.5990190739450256, 0.6844905390124987, 0.9621635323039472], 
             UndirectedEdge[195, 343] -> 
             RGBColor[
              0.8134420727304322, 0.8545935615171817, 0.9550585988854552], 
             UndirectedEdge[199, 393] -> 
             RGBColor[
              0.6072921145556155, 0.6785158188874795, 0.9521612215672659], 
             UndirectedEdge[24, 208] -> 
             RGBColor[
              0.6132509672783398, 0.6949544557090074, 0.9640292779901065], 
             UndirectedEdge[135, 386] -> 
             RGBColor[
              0.6634784500907596, 0.7268441219912818, 0.8209753193568742], 
             UndirectedEdge[32, 357] -> 
             RGBColor[
              0.36183243938625154`, 0.48771906700108725`, 0.944280419353272], 
             UndirectedEdge[230, 233] -> 
             RGBColor[
              0.8895747043049447, 0.9147867386234164, 0.9893296235009608], 
             UndirectedEdge[46, 161] -> 
             RGBColor[
              0.7403999834272185, 0.7970266081461971, 0.9750055885182574], 
             UndirectedEdge[114, 306] -> 
             RGBColor[
              0.4650949724106326, 0.5648995065171223, 0.9531841263485448], 
             UndirectedEdge[233, 357] -> 
             RGBColor[
              0.6439803441834061, 0.717742318756889, 0.9676882089934051], 
             UndirectedEdge[134, 395] -> 
             RGBColor[
              0.31257537192122553`, 0.4405021646273918, 0.9413085067721377], 
             UndirectedEdge[108, 267] -> 
             RGBColor[
              0.3843975172131021, 0.5073675418541754, 0.9457144477808088], 
             UndirectedEdge[217, 233] -> 
             RGBColor[
              0.8305504609938053, 0.867971377273556, 0.983633770004759], 
             UndirectedEdge[245, 400] -> 
             RGBColor[
              0.5504171918608816, 0.6458924982214082, 0.9577500040693481], 
             UndirectedEdge[269, 392] -> 
             RGBColor[
              0.4236031560860224, 0.5230890724352352, 0.9505362472391101], 
             UndirectedEdge[232, 288] -> 
             RGBColor[
              0.47636755545329934`, 0.5851062966849344, 0.9521054945857632], 
             UndirectedEdge[260, 341] -> 
             RGBColor[
              0.7013190190071368, 0.7655447460126803, 0.9716460513599956], 
             UndirectedEdge[47, 323] -> 
             RGBColor[
              0.9079797720191104, 0.8538536244663004, 0.629748134893416], 
             UndirectedEdge[142, 377] -> 
             RGBColor[
              0.6481220337077831, 0.7118616666014939, 0.7214353997564953], 
             UndirectedEdge[53, 117] -> 
             RGBColor[
              0.728955464348324, 0.7876635111356197, 0.974187413635992], 
             UndirectedEdge[251, 308] -> 
             RGBColor[
              0.6533997604476458, 0.7291601259745883, 0.9660884398196488], 
             UndirectedEdge[85, 162] -> 
             RGBColor[
              0.5041357821464535, 0.6054784023571834, 0.9549601696205099], 
             UndirectedEdge[249, 397] -> 
             RGBColor[
              0.31472021251510673`, 0.443796738058405, 0.9413925650881325], 
             UndirectedEdge[262, 284] -> 
             RGBColor[
              0.5412509825333005, 0.6384509565562534, 0.9570284064941499], 
             UndirectedEdge[307, 341] -> 
             RGBColor[
              0.4418242846658018, 0.5541050072188642, 0.9502032895161507], 
             UndirectedEdge[7, 387] -> 
             RGBColor[
              0.9400811393461219, 0.9511471737955117, 0.8151532884628268], 
             UndirectedEdge[228, 368] -> 
             RGBColor[
              0.5927684011698465, 0.6800979702090886, 0.9612051632055731], 
             UndirectedEdge[240, 399] -> 
             RGBColor[
              0.5889011640133688, 0.6754009635819204, 0.9618414206713242], 
             UndirectedEdge[105, 114] -> 
             RGBColor[
              0.5458250900609658, 0.6403876085309408, 0.9581244625855454], 
             UndirectedEdge[78, 357] -> 
             RGBColor[
              0.3312343183933287, 0.45555850180460344`, 0.9425379016285886], 
             UndirectedEdge[359, 369] -> 
             RGBColor[
              0.5189606319215725, 0.610604751850044, 0.9579790639224333], 
             UndirectedEdge[48, 354] -> 
             RGBColor[
              0.5663047911987302, 0.6547968960249544, 0.9608384863831407], 
             UndirectedEdge[280, 325] -> 
             RGBColor[
              0.2794952537774654, 0.41109761111568877`, 0.9392282132752279], 
             UndirectedEdge[259, 262] -> 
             RGBColor[
              0.48330422133530915`, 0.5894530229756044, 0.9530065605453891], 
             UndirectedEdge[120, 187] -> 
             RGBColor[
              0.6238082430200154, 0.7038537113413867, 0.9646358677582376], 
             UndirectedEdge[70, 198] -> 
             RGBColor[
              0.8257879893428856, 0.8642203398690712, 0.9553807242680539], 
             UndirectedEdge[62, 235] -> 
             RGBColor[
              0.4726008157751755, 0.5735832111016063, 0.9534857781923716], 
             UndirectedEdge[65, 176] -> 
             RGBColor[
              0.6420248033248652, 0.7179067937674755, 0.9665731095949159], 
             UndirectedEdge[199, 342] -> 
             RGBColor[
              0.6014009548727843, 0.6723238365397264, 0.9518257287385183], 
             UndirectedEdge[324, 390] -> 
             RGBColor[
              0.6394504695511354, 0.7086833412496221, 0.9331696254880052], 
             UndirectedEdge[226, 234] -> 
             RGBColor[
              0.3102627722228976, 0.44226581475150495`, 0.9410232323419776], 
             UndirectedEdge[47, 201] -> 
             RGBColor[
              0.8665526648279533, 0.8210481036098174, 0.6257364540590463], 
             UndirectedEdge[160, 264] -> 
             RGBColor[
              0.617903340715392, 0.6943876105634261, 0.9663802125091737], 
             UndirectedEdge[277, 314] -> 
             RGBColor[
              0.8197685605074082, 0.8593792641666655, 0.9826040341911992], 
             UndirectedEdge[4, 66] -> 
             RGBColor[
              0.7322537500679068, 0.790761461978454, 0.9739478685725671], 
             UndirectedEdge[23, 75] -> 
             RGBColor[
              0.8739435435564802, 0.8998121223273196, 0.8665872203009164], 
             UndirectedEdge[287, 391] -> 
             RGBColor[
              0.4235304050480395, 0.5412624824206662, 0.9482079607897971], 
             UndirectedEdge[45, 91] -> 
             RGBColor[
              0.6070342981211295, 0.6686968619787566, 0.7211966375291063], 
             UndirectedEdge[175, 314] -> 
             RGBColor[
              0.9059416914773871, 0.9271874995467024, 0.9683606942098562], 
             UndirectedEdge[195, 358] -> 
             RGBColor[
              0.5618534470371386, 0.6548859579789177, 0.9588492713124537], 
             UndirectedEdge[321, 341] -> 
             RGBColor[
              0.7486598570946217, 0.7152794937913428, 0.612046727233966], 
             UndirectedEdge[91, 148] -> 
             RGBColor[
              0.232282539597548, 0.36147405505362257`, 0.9365395190476331], 
             UndirectedEdge[115, 350] -> 
             RGBColor[
              0.8311509840465656, 0.8641971336817327, 0.6985500798858739], 
             UndirectedEdge[142, 277] -> 
             RGBColor[
              0.5457933648747446, 0.6352905312817037, 0.9600639607429678], 
             UndirectedEdge[45, 66] -> 
             RGBColor[
              0.8293679878160034, 0.8632852667243153, 0.7368998802169063], 
             UndirectedEdge[259, 335] -> 
             RGBColor[
              0.561265336171562, 0.6512315221822685, 0.960178969813479], 
             UndirectedEdge[118, 173] -> 
             RGBColor[
              0.5915129283328785, 0.6792558684312056, 0.9609852109830666], 
             UndirectedEdge[52, 128] -> 
             RGBColor[
              0.6227545556764975, 0.6860710860708774, 0.8072181582881928], 
             UndirectedEdge[27, 225] -> 
             RGBColor[
              0.6364770721700441, 0.7112284694632406, 0.9672169628337661], 
             UndirectedEdge[302, 352] -> 
             RGBColor[
              0.8796344172893675, 0.9050831047595624, 0.9045738029160983], 
             UndirectedEdge[25, 242] -> 
             RGBColor[
              0.6635794928861909, 0.7261286405927978, 0.7523504931692169], 
             UndirectedEdge[30, 224] -> 
             RGBColor[
              0.4543116562642183, 0.5667676794588881, 0.9504887144160873], 
             UndirectedEdge[313, 361] -> 
             RGBColor[
              0.6074611319933132, 0.6853113524040866, 0.965729456699434], 
             UndirectedEdge[270, 310] -> 
             RGBColor[
              0.5183456916859308, 0.6064993731354412, 0.958491660389642], 
             UndirectedEdge[72, 370] -> 
             RGBColor[
              0.6127614267270469, 0.6922792648754831, 0.9649728938613706], 
             UndirectedEdge[283, 380] -> 
             RGBColor[
              0.26061445169621084`, 0.39125269101629634`, 0.938152979528344], 
             UndirectedEdge[34, 35] -> 
             RGBColor[
              0.9148516812769372, 0.9323712335356966, 0.8910581614319528], 
             UndirectedEdge[25, 230] -> 
             RGBColor[
              0.6203141037465536, 0.6960295606577456, 0.9667392031130507], 
             UndirectedEdge[191, 211] -> 
             RGBColor[
              0.6390024123946856, 0.7156652195910251, 0.9661901353591187], 
             UndirectedEdge[17, 173] -> 
             RGBColor[
              0.5635996439635662, 0.6565946067010673, 0.9587877749877847], 
             UndirectedEdge[40, 51] -> 
             RGBColor[
              0.45105222487808505`, 0.5483894525402642, 0.9526615006880733], 
             UndirectedEdge[105, 202] -> 
             RGBColor[
              0.5426829526739785, 0.6379329469230977, 0.957811283695754], 
             UndirectedEdge[183, 309] -> 
             RGBColor[
              0.5121763905224865, 0.6134459964124659, 0.955126619999153], 
             UndirectedEdge[187, 261] -> 
             RGBColor[
              0.5339583761206033, 0.6272826648152088, 0.958564673995134], 
             UndirectedEdge[190, 274] -> 
             RGBColor[
              0.4412362302414866, 0.5551942947297509, 0.9497241127835934], 
             UndirectedEdge[176, 354] -> 
             RGBColor[
              0.7781118938696785, 0.8265861924511997, 0.9785185797780087], 
             UndirectedEdge[42, 148] -> 
             RGBColor[
              0.38465231676892353`, 0.49961690429003885`, 0.9464927090576797],
              UndirectedEdge[320, 380] -> 
             RGBColor[
              0.25400113232471444`, 0.3843016730481874, 0.9377763607736666], 
             UndirectedEdge[51, 222] -> 
             RGBColor[
              0.4568611666759672, 0.5544950186780209, 0.9529923113299035], 
             UndirectedEdge[122, 319] -> 
             RGBColor[
              0.4635215730419333, 0.572465234246403, 0.9517054258180533], 
             UndirectedEdge[27, 78] -> 
             RGBColor[
              0.32351451721374985`, 0.44887199803134137`, 0.942046002723778], 
             UndirectedEdge[5, 178] -> 
             RGBColor[
              0.816511231220246, 0.855388673981212, 0.8812470840865305], 
             UndirectedEdge[196, 336] -> 
             RGBColor[
              0.2671463187154426, 0.3981180973977978, 0.938524959692058], 
             UndirectedEdge[297, 318] -> 
             RGBColor[
              0.39819512016169306`, 0.5193183320405568, 0.9465936188399517], 
             UndirectedEdge[127, 235] -> 
             RGBColor[
              0.5459528806234037, 0.6309062172813877, 0.9607915680450876], 
             UndirectedEdge[45, 203] -> 
             RGBColor[
              0.7577746171721165, 0.8055168437067897, 0.7310215506270143], 
             UndirectedEdge[305, 370] -> 
             RGBColor[
              0.8273092554465453, 0.865137959854313, 0.9833906894038242], 
             UndirectedEdge[122, 169] -> 
             RGBColor[
              0.7853556576466241, 0.8253137750136565, 0.6895363990468784], 
             UndirectedEdge[51, 226] -> 
             RGBColor[
              0.5079985476659906, 0.6070732393720826, 0.9559473639340565], 
             UndirectedEdge[226, 395] -> 
             RGBColor[
              0.28989268358910275`, 0.42085556005917146`, 0.9398631859291287],
              UndirectedEdge[61, 354] -> 
             RGBColor[
              0.489569089918595, 0.5800466969045853, 0.9562523314458076], 
             UndirectedEdge[211, 334] -> 
             RGBColor[
              0.6929830667476786, 0.75840388779547, 0.9714195413105104], 
             UndirectedEdge[10, 361] -> 
             RGBColor[
              0.32069287355739673`, 0.45218978140809274`, 0.9416552442188719],
              UndirectedEdge[44, 249] -> 
             RGBColor[
              0.5880692792007296, 0.6710791196965916, 0.963313467806123], 
             UndirectedEdge[302, 377] -> 
             RGBColor[
              0.991121410101303, 0.9888087923775072, 0.6668580580744388], 
             UndirectedEdge[149, 363] -> 
             RGBColor[
              0.6561893471938445, 0.7303432918207347, 0.967047505449071], 
             UndirectedEdge[358, 359] -> 
             RGBColor[
              0.3688932950791449, 0.4906135155731063, 0.9449070667096016], 
             UndirectedEdge[126, 317] -> 
             RGBColor[
              0.4780195542102525, 0.583584536277538, 0.9530265813556213], 
             UndirectedEdge[194, 364] -> 
             RGBColor[
              0.7310785428073268, 0.7898433811345829, 0.9738307348957687], 
             UndirectedEdge[184, 343] -> 
             RGBColor[
              0.9574546264713248, 0.9677903106007453, 0.9569023991601844], 
             UndirectedEdge[118, 346] -> 
             RGBColor[
              0.6799091324310612, 0.7489159730008944, 0.9693825429179903], 
             UndirectedEdge[169, 239] -> 
             RGBColor[
              0.946778165953958, 0.8159377861401995, 0.32976147380981485`], 
             UndirectedEdge[72, 157] -> 
             RGBColor[
              0.6835078200157217, 0.747869214575217, 0.9432456245216054], 
             UndirectedEdge[162, 191] -> 
             RGBColor[
              0.5686362766158264, 0.6558666788585717, 0.961388976117826], 
             UndirectedEdge[84, 272] -> 
             RGBColor[
              0.24011838220414106`, 0.36971002245426815`, 0.9369857586919883],
              UndirectedEdge[21, 160] -> 
             RGBColor[
              0.5381821602889223, 0.6315085030160891, 0.9585936555553525], 
             UndirectedEdge[29, 336] -> 
             RGBColor[
              0.6192057230136316, 0.666897288263135, 0.6579597848518409], 
             UndirectedEdge[275, 276] -> 
             RGBColor[
              0.320146421675915, 0.4474956528503246, 0.9417749696627493], 
             UndirectedEdge[38, 303] -> 
             RGBColor[
              0.6920388359017979, 0.755916463788846, 0.9533939753625279], 
             UndirectedEdge[172, 285] -> 
             RGBColor[
              0.9004501853708136, 0.9224533660522773, 0.9555165081429711], 
             UndirectedEdge[73, 285] -> 
             RGBColor[
              0.8929585608421292, 0.9168661247451939, 0.9681978743414242], 
             UndirectedEdge[5, 59] -> 
             RGBColor[
              0.4762239993756623, 0.5817813507986279, 0.9529806839693999], 
             UndirectedEdge[73, 225] -> 
             RGBColor[
              0.9160242809441773, 0.9352581038522739, 0.970397903315769], 
             UndirectedEdge[64, 254] -> 
             RGBColor[
              0.33165243222638796`, 0.45329957187609005`, 0.9426605140184067],
              UndirectedEdge[241, 390] -> 
             RGBColor[
              0.781030759875984, 0.8282308565422579, 0.9431687562307205], 
             UndirectedEdge[58, 289] -> 
             RGBColor[
              0.49366519933800673`, 0.5986627128561639, 0.9536016748487184], 
             UndirectedEdge[262, 331] -> 
             RGBColor[
              0.5204494120852459, 0.621563304566453, 0.9553908306698157], 
             UndirectedEdge[22, 118] -> 
             RGBColor[
              0.5382655266584973, 0.6360272289838336, 0.9567933804716001], 
             UndirectedEdge[97, 360] -> 
             RGBColor[
              0.7288832978652589, 0.7881284391013599, 0.9736119333956736], 
             UndirectedEdge[301, 358] -> 
             RGBColor[
              0.3696341260578005, 0.4913921759030702, 0.9449492559378747], 
             UndirectedEdge[16, 274] -> 
             RGBColor[
              0.3419781595635023, 0.4572192892178407, 0.9438389522332407], 
             UndirectedEdge[166, 319] -> 
             RGBColor[
              0.6489993060975277, 0.7189872981421053, 0.9557524564347579], 
             UndirectedEdge[82, 101] -> 
             RGBColor[
              0.5227595464833674, 0.6190329945000427, 0.9572373040441238], 
             UndirectedEdge[24, 399] -> 
             RGBColor[
              0.4494949532296466, 0.5636546442916436, 0.9498892070672815], 
             UndirectedEdge[328, 400] -> 
             RGBColor[
              0.6298430993885309, 0.708763770472383, 0.9651036443559692], 
             UndirectedEdge[17, 371] -> 
             RGBColor[
              0.3540476688650708, 0.4676013637903895, 0.9447359941273238], 
             UndirectedEdge[107, 158] -> 
             RGBColor[
              0.5686765623999557, 0.6530918940619224, 0.9623429369772607], 
             UndirectedEdge[60, 394] -> 
             RGBColor[
              0.33366485770997956`, 0.45662011824420945`, 0.9427309845534011],
              UndirectedEdge[219, 284] -> 
             RGBColor[
              0.557261497253861, 0.651449013671873, 0.9582888128614002], 
             UndirectedEdge[124, 149] -> 
             RGBColor[
              0.4477962782020918, 0.5589130023051755, 0.9506845723164061], 
             UndirectedEdge[227, 296] -> 
             RGBColor[
              0.29450042052094905`, 0.4213663779352238, 0.9402842130065475], 
             UndirectedEdge[202, 229] -> 
             RGBColor[
              0.6462211394934378, 0.723165290122767, 0.9656374283712725], 
             UndirectedEdge[315, 358] -> 
             RGBColor[
              0.7103708481317476, 0.7714424148428723, 0.9530675400697031], 
             UndirectedEdge[145, 222] -> 
             RGBColor[
              0.6067374713636212, 0.6697897712867554, 0.8395882801496689], 
             UndirectedEdge[155, 299] -> 
             RGBColor[
              0.47428955948545926`, 0.5774628907466054, 0.9532487442873863], 
             UndirectedEdge[14, 29] -> 
             RGBColor[
              0.9304879512939532, 0.926429884062991, 0.6831952940460396], 
             UndirectedEdge[116, 151] -> 
             RGBColor[
              0.5178928023042412, 0.6191312119479068, 0.9552880729697546], 
             UndirectedEdge[45, 257] -> 
             RGBColor[
              0.7682714560476747, 0.8140386503831702, 0.731847900234486], 
             UndirectedEdge[27, 240] -> 
             RGBColor[
              0.5681525334334064, 0.6574295426300523, 0.9605193362780626], 
             UndirectedEdge[144, 188] -> 
             RGBColor[
              0.5580604640708762, 0.648014392012269, 0.9601615080845349], 
             UndirectedEdge[76, 200] -> 
             RGBColor[
              0.35236700735248794`, 0.4727457802207713, 0.9440112099982481], 
             UndirectedEdge[90, 221] -> 
             RGBColor[
              0.27865348319956185`, 0.4094158501217263, 0.9392094580072818], 
             UndirectedEdge[271, 382] -> 
             RGBColor[
              0.6679388427739685, 0.6273310227324538, 0.6010438677473118], 
             UndirectedEdge[242, 385] -> 
             RGBColor[
              0.7431630991867288, 0.7939942906174635, 0.7577159379207644], 
             UndirectedEdge[74, 112] -> 
             RGBColor[
              0.6213631481930755, 0.7027185315321847, 0.9638623281608214], 
             UndirectedEdge[237, 251] -> 
             RGBColor[
              0.4705734330182994, 0.5738224144485216, 0.9529950983641164], 
             UndirectedEdge[25, 223] -> 
             RGBColor[
              0.36696278678507654`, 0.49226645465245045`, 0.9446035221748619],
              UndirectedEdge[284, 332] -> 
             RGBColor[
              0.7414500619556877, 0.7955298728600038, 0.9204543578414629], 
             UndirectedEdge[145, 333] -> 
             RGBColor[
              0.9562955356780243, 0.8527552219097605, 0.4982316702594399], 
             UndirectedEdge[146, 227] -> 
             RGBColor[
              0.38003538779471635`, 0.49311700101020256`, 0.9463797218284642],
              UndirectedEdge[108, 286] -> 
             RGBColor[
              0.6547176533823942, 0.72738043762521, 0.9682167802706276], 
             UndirectedEdge[127, 361] -> 
             RGBColor[
              0.5710892702803746, 0.6563094171620745, 0.9622602760597097], 
             UndirectedEdge[143, 258] -> 
             RGBColor[
              0.4674793972271688, 0.5761123196795839, 0.951897099811905], 
             UndirectedEdge[212, 310] -> 
             RGBColor[
              0.8154000193954241, 0.8558993876478637, 0.9821864354657535], 
             UndirectedEdge[107, 310] -> 
             RGBColor[
              0.8119733616836746, 0.8531670638026604, 0.9818595977941933], 
             UndirectedEdge[253, 394] -> 
             RGBColor[
              0.2502374748614258, 0.38034583042460524`, 0.9375620260489645], 
             UndirectedEdge[152, 284] -> 
             RGBColor[
              0.5794678629818791, 0.6691809577918973, 0.9602394819094635], 
             UndirectedEdge[230, 364] -> 
             RGBColor[
              0.7772343495462309, 0.8266058220304728, 0.9782439828968269], 
             UndirectedEdge[158, 241] -> 
             RGBColor[
              0.4438715612950785, 0.5546051858288895, 0.9505255434733857], 
             UndirectedEdge[44, 315] -> 
             RGBColor[
              0.8895048057737961, 0.9141458484071749, 0.969035264471632], 
             UndirectedEdge[357, 385] -> 
             RGBColor[
              0.45430334992555294`, 0.566850790815884, 0.9504632333570426], 
             UndirectedEdge[99, 197] -> 
             RGBColor[
              0.5587750954302315, 0.6508195249360045, 0.9592817592870866], 
             UndirectedEdge[152, 267] -> 
             RGBColor[
              0.4915721798496918, 0.5942427733084321, 0.9543093171378476], 
             UndirectedEdge[169, 197] -> 
             RGBColor[
              0.7041581065963525, 0.7584201252775173, 0.6834132997276436], 
             UndirectedEdge[263, 348] -> 
             RGBColor[
              0.6835002995112367, 0.7526748958636353, 0.9690885802479771], 
             UndirectedEdge[314, 379] -> 
             RGBColor[
              0.6280355089454265, 0.7046516288414635, 0.9663407971893534], 
             UndirectedEdge[300, 319] -> 
             RGBColor[
              0.6449805305258216, 0.7159901019008679, 0.962555195213119], 
             UndirectedEdge[25, 78] -> 
             RGBColor[
              0.28991316132074857`, 0.41976819241007646`, 0.9399049540387883],
              UndirectedEdge[44, 113] -> 
             RGBColor[
              0.8494714106089196, 0.8828094608051142, 0.985504535547601], 
             UndirectedEdge[115, 221] -> 
             RGBColor[
              0.6549530533220165, 0.717880090489994, 0.6854120730983817], 
             UndirectedEdge[175, 319] -> 
             RGBColor[
              0.6540468816439975, 0.722751771720016, 0.9472082276531292], 
             UndirectedEdge[176, 356] -> 
             RGBColor[
              0.6438719639942131, 0.7194064020124918, 0.9667185248491795], 
             UndirectedEdge[84, 395] -> 
             RGBColor[
              0.24234830279729708`, 0.3720538103828067, 0.9371127493708966], 
             UndirectedEdge[301, 359] -> 
             RGBColor[
              0.27617636913342997`, 0.4076092529253672, 0.9390392077045999], 
             UndirectedEdge[238, 280] -> 
             RGBColor[
              0.2381209316212773, 0.3676105752459967, 0.9368720068362575], 
             UndirectedEdge[36, 168] -> 
             RGBColor[
              0.6216969120685681, 0.6921438393622127, 0.9443133025794845], 
             UndirectedEdge[4, 232] -> 
             RGBColor[
              0.6138427482305646, 0.6943150060451373, 0.9645688327036681], 
             UndirectedEdge[140, 339] -> 
             RGBColor[
              0.6351844653351812, 0.7023610405426353, 0.9108962760615205], 
             UndirectedEdge[18, 141] -> 
             RGBColor[
              0.9374704546631332, 0.9528252670658277, 0.9886196095598917], 
             UndirectedEdge[123, 140] -> 
             RGBColor[
              0.6234396922326402, 0.6506682436109719, 0.624113327420585], 
             UndirectedEdge[24, 78] -> 
             RGBColor[
              0.3516595415249966, 0.47315277873189576`, 0.9438661870121238], 
             UndirectedEdge[62, 127] -> 
             RGBColor[
              0.7490835665628907, 0.8039288581596828, 0.9756200489398736], 
             UndirectedEdge[299, 353] -> 
             RGBColor[
              0.6875153447710098, 0.7558114797360443, 0.9694887624367401], 
             UndirectedEdge[256, 311] -> 
             RGBColor[
              0.5758800004974556, 0.666564353359036, 0.9597545296385606], 
             UndirectedEdge[47, 346] -> 
             RGBColor[
              0.8604744229221687, 0.816299734836669, 0.6251306317102778], 
             UndirectedEdge[34, 125] -> 
             RGBColor[
              0.8892062073885565, 0.9143876785287106, 0.9856460630280548], 
             UndirectedEdge[194, 387] -> 
             RGBColor[
              0.9047026266203098, 0.9229782546038083, 0.8117679883857412], 
             UndirectedEdge[117, 303] -> 
             RGBColor[
              0.9196276844025142, 0.93821088772666, 0.9734988768118391], 
             UndirectedEdge[287, 382] -> 
             RGBColor[
              0.42016519554141896`, 0.5383477070863792, 0.9479935326157731], 
             UndirectedEdge[20, 168] -> 
             RGBColor[
              0.5705689986532576, 0.6384051606657792, 0.9414016435474524], 
             UndirectedEdge[51, 355] -> 
             RGBColor[
              0.5714302664779213, 0.6620146060360892, 0.9599891769662862], 
             UndirectedEdge[183, 339] -> 
             RGBColor[
              0.6938437762626177, 0.7554192390245232, 0.9145515954240702], 
             UndirectedEdge[118, 164] -> 
             RGBColor[
              0.6373599604741271, 0.7156762364824534, 0.9651416391019421], 
             UndirectedEdge[51, 134] -> 
             RGBColor[
              0.5306812359981133, 0.6267198439403029, 0.9573926847770656], 
             UndirectedEdge[46, 356] -> 
             RGBColor[
              0.682116287638924, 0.749709278254686, 0.9704172824855903], 
             UndirectedEdge[204, 276] -> 
             RGBColor[
              0.37290207111050333`, 0.4974107642180252, 0.9449819681201751], 
             UndirectedEdge[108, 154] -> 
             RGBColor[
              0.4061718339299003, 0.5262273605852865, 0.947101887987731], 
             UndirectedEdge[29, 119] -> 
             RGBColor[
              0.649034527394307, 0.6974135481580788, 0.659689090378791], 
             UndirectedEdge[244, 264] -> 
             RGBColor[
              0.9400542183923603, 0.9534686160049868, 0.9369533461028494], 
             UndirectedEdge[217, 321] -> 
             RGBColor[
              0.8612975941628316, 0.8044747551743605, 0.6224517234902316], 
             UndirectedEdge[241, 346] -> 
             RGBColor[
              0.6829582886097862, 0.7513914153497039, 0.9696225836618066], 
             UndirectedEdge[108, 284] -> 
             RGBColor[
              0.4722932003452894, 0.5823057263376407, 0.9516446125524247], 
             UndirectedEdge[181, 334] -> 
             RGBColor[
              0.7064192890559526, 0.769312018360244, 0.9724772899491219], 
             UndirectedEdge[8, 59] -> 
             RGBColor[
              0.2954779733462207, 0.4277340478077603, 0.94014435231683], 
             UndirectedEdge[236, 383] -> 
             RGBColor[
              0.9323573267008144, 0.9463936273596947, 0.8955012059760219], 
             UndirectedEdge[42, 290] -> 
             RGBColor[
              0.6969897340138829, 0.5605592716160833, 0.5838558246749903], 
             UndirectedEdge[173, 209] -> 
             RGBColor[
              0.7532591141537581, 0.807242602594066, 0.9762752971684145], 
             UndirectedEdge[154, 332] -> 
             RGBColor[
              0.6753286955402986, 0.7394515071076497, 0.9159116332767692], 
             UndirectedEdge[5, 352] -> 
             RGBColor[
              0.70609055628429, 0.7703162394310058, 0.9713444983725338], 
             UndirectedEdge[189, 226] -> 
             RGBColor[
              0.32729645759278403`, 0.4579094739937609, 0.9420760187542867], 
             UndirectedEdge[16, 390] -> 
             RGBColor[
              0.5773868579323409, 0.6434505503780141, 0.9296351946212003], 
             UndirectedEdge[119, 327] -> 
             RGBColor[
              0.35444107955751225`, 0.48142078121123894`, 0.9438056500628325],
              UndirectedEdge[129, 231] -> 
             RGBColor[
              0.619199557837051, 0.6827895484912888, 0.8377243778086614], 
             UndirectedEdge[79, 352] -> 
             RGBColor[
              0.6438745872136669, 0.7198065129420077, 0.9664466293826902], 
             UndirectedEdge[62, 361] -> 
             RGBColor[
              0.4977372054321463, 0.5989864109822931, 0.9549544862069936], 
             UndirectedEdge[150, 347] -> 
             RGBColor[
              0.9421376199364708, 0.9555590705652843, 0.9548217190869412], 
             UndirectedEdge[5, 90] -> 
             RGBColor[
              0.4409429980884332, 0.5448611964387088, 0.9509655363331802], 
             UndirectedEdge[24, 27] -> 
             RGBColor[
              0.4287463226496842, 0.5456832233397755, 0.94856712267402], 
             UndirectedEdge[62, 393] -> 
             RGBColor[
              0.46913546962019226`, 0.5699409125770825, 0.9532884318553655], 
             UndirectedEdge[199, 353] -> 
             RGBColor[
              0.8334713510934755, 0.8704793064393407, 0.9691389196025247], 
             UndirectedEdge[96, 201] -> 
             RGBColor[
              0.8932562526100338, 0.9146911821821211, 0.8590725813745876], 
             UndirectedEdge[155, 170] -> 
             RGBColor[
              0.4151935969494319, 0.5297583977418224, 0.948410340044062], 
             UndirectedEdge[335, 394] -> 
             RGBColor[
              0.4881613002748021, 0.5811071367582052, 0.9557700222645], 
             UndirectedEdge[16, 310] -> 
             RGBColor[
              0.4835244586351543, 0.5699000494053836, 0.9565086426807982], 
             UndirectedEdge[6, 277] -> 
             RGBColor[
              0.6686345349159069, 0.7396271662239113, 0.9685876624976355], 
             UndirectedEdge[140, 232] -> 
             RGBColor[
              0.35653551052571714`, 0.4809844203875013, 0.9440215054114484], 
             UndirectedEdge[177, 300] -> 
             RGBColor[
              0.9657602910002172, 0.9732266473859965, 0.9088976500414805], 
             UndirectedEdge[24, 32] -> 
             RGBColor[
              0.3822576625179195, 0.5053133439283796, 0.9456087047368071], 
             UndirectedEdge[102, 226] -> 
             RGBColor[
              0.5435865642261165, 0.6348748683877966, 0.9594944448358467], 
             UndirectedEdge[187, 206] -> 
             RGBColor[
              0.5339583761206033, 0.6272826648152088, 0.958564673995134], 
             UndirectedEdge[336, 396] -> 
             RGBColor[
              0.43475354385287984`, 0.5420116030593723, 0.9502802719070358], 
             UndirectedEdge[267, 332] -> 
             RGBColor[
              0.6535543788235005, 0.7205916883765386, 0.9145241930698471], 
             UndirectedEdge[115, 300] -> 
             RGBColor[
              0.9676528865261274, 0.9716436204590776, 0.705573658209077], 
             UndirectedEdge[149, 195] -> 
             RGBColor[
              0.6193455590014573, 0.7015606444616803, 0.9633752609668302], 
             UndirectedEdge[127, 396] -> 
             RGBColor[
              0.7169077317813044, 0.7783182901422182, 0.972737522609562], 
             UndirectedEdge[206, 220] -> 
             RGBColor[
              0.6307687143517247, 0.7037389992437129, 0.9625027943441645], 
             UndirectedEdge[298, 361] -> 
             RGBColor[
              0.5166340955307829, 0.6137488051490321, 0.9568379516105475], 
             UndirectedEdge[27, 141] -> 
             RGBColor[
              0.6669697028319126, 0.7355424654526048, 0.9701253771673879], 
             UndirectedEdge[55, 221] -> 
             RGBColor[
              0.3008844743394058, 0.43278203133595106`, 0.9404754800648918], 
             UndirectedEdge[40, 269] -> 
             RGBColor[
              0.4378958223755869, 0.5381115709129503, 0.9513501934401959], 
             UndirectedEdge[191, 312] -> 
             RGBColor[
              0.5249265959793236, 0.6141927546719284, 0.9587435122775986], 
             UndirectedEdge[78, 240] -> 
             RGBColor[
              0.49106575230871885`, 0.5848990980221725, 0.9558184006161664], 
             UndirectedEdge[183, 246] -> 
             RGBColor[
              0.33451205067306566`, 0.46032729640138836`, 0.9426760968522812],
              UndirectedEdge[130, 164] -> 
             RGBColor[
              0.7210396886718431, 0.7820009519858256, 0.9728301557339694], 
             UndirectedEdge[190, 295] -> 
             RGBColor[
              0.4871825354397459, 0.592495575147159, 0.9533411742356619], 
             UndirectedEdge[18, 179] -> 
             RGBColor[
              0.6031467223194815, 0.6757525360036525, 0.9610602578714906], 
             UndirectedEdge[128, 199] -> 
             RGBColor[
              0.9734290930937761, 0.9775351825188698, 0.8214540164203396], 
             UndirectedEdge[350, 355] -> 
             RGBColor[
              0.5590152946249538, 0.6523159356672703, 0.9587517685964906], 
             UndirectedEdge[233, 348] -> 
             RGBColor[
              0.7691451739215966, 0.8200011003152797, 0.9775134648544346], 
             UndirectedEdge[247, 316] -> 
             RGBColor[
              0.7471268524096704, 0.8022801761543197, 0.9757741044503743], 
             UndirectedEdge[74, 399] -> 
             RGBColor[
              0.567397001602319, 0.6586017484687207, 0.959698086730014], 
             UndirectedEdge[155, 171] -> 
             RGBColor[
              0.4487409030653796, 0.5569936121356668, 0.9510513068693409], 
             UndirectedEdge[21, 95] -> 
             RGBColor[
              0.4849771611094986, 0.5786196630419163, 0.9554526570299748], 
             UndirectedEdge[257, 325] -> 
             RGBColor[
              0.40399258504419044`, 0.5178235122610793, 0.9477871972040335], 
             UndirectedEdge[250, 372] -> 
             RGBColor[
              0.6859875729843095, 0.7289091812827092, 0.6612645195537332], 
             UndirectedEdge[156, 400] -> 
             RGBColor[
              0.7066825706700894, 0.7694474235287323, 0.9725881828566839], 
             UndirectedEdge[193, 360] -> 
             RGBColor[
              0.6763425244972496, 0.7460185674955617, 0.9691030467223916], 
             UndirectedEdge[92, 135] -> 
             RGBColor[
              0.3562795975654801, 0.48301321310313877`, 0.9439227988045624], 
             UndirectedEdge[102, 174] -> 
             RGBColor[
              0.536203402515131, 0.6282851063337348, 0.9590311302910679], 
             UndirectedEdge[140, 275] -> 
             RGBColor[
              0.2737498245771922, 0.4050588007449505, 0.9389010195818731], 
             UndirectedEdge[101, 301] -> 
             RGBColor[
              0.3042039415135965, 0.4349651072076972, 0.9407123340079452], 
             UndirectedEdge[337, 398] -> 
             RGBColor[
              0.667537065408571, 0.7318395689628103, 0.8836873051736869], 
             UndirectedEdge[149, 249] -> 
             RGBColor[
              0.46642743352299976`, 0.5750503726150517, 0.9518717330585706], 
             UndirectedEdge[92, 165] -> 
             RGBColor[
              0.41208644038650016`, 0.5313502954212291, 0.9474787614810645], 
             UndirectedEdge[150, 320] -> 
             RGBColor[
              0.6075218911574731, 0.6745051964427778, 0.9278023601453061], 
             UndirectedEdge[59, 175] -> 
             RGBColor[
              0.6357006688090778, 0.7068612042698772, 0.9460392231942072], 
             UndirectedEdge[278, 379] -> 
             RGBColor[
              0.5861013208323599, 0.6716417552402228, 0.9622276820290869], 
             UndirectedEdge[87, 317] -> 
             RGBColor[
              0.7751923911067351, 0.8249479874360208, 0.9781182573507939], 
             UndirectedEdge[212, 324] -> 
             RGBColor[
              0.5728661723790642, 0.6566261291140878, 0.9627132236517602], 
             UndirectedEdge[135, 328] -> 
             RGBColor[
              0.5397053070376754, 0.6322900078802829, 0.9589183181488066], 
             UndirectedEdge[176, 344] -> 
             RGBColor[
              0.890362267228624, 0.9142955441027326, 0.9433586498651686], 
             UndirectedEdge[59, 213] -> 
             RGBColor[
              0.6396531974329196, 0.6748966760463816, 0.6371573873273186], 
             UndirectedEdge[371, 391] -> 
             RGBColor[
              0.30328836732488307`, 0.42556326213225315`, 0.9409692055285737],
              UndirectedEdge[98, 318] -> 
             RGBColor[
              0.3905617644494942, 0.5127067029862638, 0.9461072281638819], 
             UndirectedEdge[25, 244] -> 
             RGBColor[
              0.6596253527668592, 0.7258061666292819, 0.9132976866228106], 
             UndirectedEdge[204, 224] -> 
             RGBColor[
              0.3906685655348496, 0.5127992087184199, 0.9461140334346003], 
             UndirectedEdge[180, 236] -> 
             RGBColor[
              0.6199151627772979, 0.6968275322497695, 0.966187360545607], 
             UndirectedEdge[102, 163] -> 
             RGBColor[
              0.5901846853952787, 0.6752358188548556, 0.962463635911645], 
             UndirectedEdge[16, 107] -> 
             RGBColor[
              0.5073759030485203, 0.5886610143972766, 0.9588519551133952], 
             UndirectedEdge[194, 223] -> 
             RGBColor[
              0.607722497240291, 0.6883387430176149, 0.9644646362711595], 
             UndirectedEdge[111, 291] -> 
             RGBColor[
              0.4663221441467543, 0.5739531348598025, 0.9521429963460529], 
             UndirectedEdge[108, 205] -> 
             RGBColor[
              0.634266869039416, 0.711073537311872, 0.9662661662033638], 
             UndirectedEdge[66, 297] -> 
             RGBColor[
              0.5209071861953158, 0.6194901536029195, 0.956246714716156], 
             UndirectedEdge[19, 284] -> 
             RGBColor[
              0.5791499219755424, 0.6689325798613059, 0.9602077925212794], 
             UndirectedEdge[23, 260] -> 
             RGBColor[
              0.9161271299601061, 0.9329177967913509, 0.870751472928476], 
             UndirectedEdge[10, 256] -> 
             RGBColor[
              0.4275672302914033, 0.5425820757265214, 0.9490666681845158], 
             UndirectedEdge[230, 242] -> 
             RGBColor[
              0.9504950100803096, 0.9589633698538521, 0.7766248552665729], 
             UndirectedEdge[29, 317] -> 
             RGBColor[
              0.8065485650821516, 0.8289705822743931, 0.6710723657401366], 
             UndirectedEdge[124, 316] -> 
             RGBColor[
              0.6098261284233782, 0.6871460479065693, 0.9659785509921204], 
             UndirectedEdge[306, 361] -> 
             RGBColor[
              0.28415618762559147`, 0.41497980872239987`, 0.9395308743722586],
              UndirectedEdge[1, 393] -> 
             RGBColor[
              0.6286730180554383, 0.6922880688091827, 0.807185547227546], 
             UndirectedEdge[74, 279] -> 
             RGBColor[
              0.6418403544171538, 0.7193428500325194, 0.9654743688452588], 
             UndirectedEdge[40, 234] -> 
             RGBColor[
              0.25331644943499204`, 0.38358202791968654`, 0.9377373690959945],
              UndirectedEdge[195, 316] -> 
             RGBColor[
              0.7813754092227437, 0.8297936900630741, 0.9786692396425445], 
             UndirectedEdge[279, 325] -> 
             RGBColor[
              0.42783795388305823`, 0.5371822569060964, 0.9496643919874934], 
             UndirectedEdge[172, 337] -> 
             RGBColor[
              0.6601403205009462, 0.7272003641062991, 0.9354942490204916], 
             UndirectedEdge[148, 275] -> 
             RGBColor[
              0.25341954150655477`, 0.38369038422331386`, 0.9377432400369589],
              UndirectedEdge[13, 188] -> 
             RGBColor[
              0.5328211498655382, 0.6282972479291662, 0.957645889119348], 
             UndirectedEdge[220, 233] -> 
             RGBColor[
              0.9068571536115182, 0.928410107915387, 0.9855282785765072], 
             UndirectedEdge[230, 244] -> 
             RGBColor[
              0.9465408699609779, 0.9586408958903363, 0.9375720487201664], 
             UndirectedEdge[253, 358] -> 
             RGBColor[
              0.36384281822893383`, 0.4853051441848071, 0.944619449524493], 
             UndirectedEdge[66, 140] -> 
             RGBColor[
              0.4749465123630593, 0.577430876320818, 0.9534005412803472], 
             UndirectedEdge[89, 128] -> 
             RGBColor[
              0.6651457212229503, 0.7281553283438011, 0.8097227683900547], 
             UndirectedEdge[199, 298] -> 
             RGBColor[
              0.8327850367487222, 0.8699431524570373, 0.9690705142026119], 
             UndirectedEdge[367, 398] -> 
             RGBColor[
              0.7522463480419965, 0.80353513145307, 0.8895478128594998], 
             UndirectedEdge[72, 181] -> 
             RGBColor[
              0.4609885986399943, 0.5718281677576056, 0.9511138594886037], 
             UndirectedEdge[229, 329] -> 
             RGBColor[
              0.6753797456051637, 0.7459442148308615, 0.968543685725823], 
             UndirectedEdge[196, 326] -> 
             RGBColor[
              0.2799372555034245, 0.41156218295419983`, 0.9392533846196383], 
             UndirectedEdge[247, 362] -> 
             RGBColor[
              0.5105706522480865, 0.6128635118411858, 0.9548009611108261], 
             UndirectedEdge[276, 297] -> 
             RGBColor[
              0.37676270467014417`, 0.5007546509663013, 0.9452279642767711], 
             UndirectedEdge[7, 201] -> 
             RGBColor[
              0.838766645029172, 0.8745011012138219, 0.9844231790822857], 
             UndirectedEdge[191, 214] -> 
             RGBColor[
              0.5518862300987243, 0.6413586304472747, 0.9603216779652408], 
             UndirectedEdge[25, 32] -> 
             RGBColor[
              0.32051128231367143`, 0.45192875760656026`, 0.9416474717634717],
              UndirectedEdge[190, 324] -> 
             RGBColor[
              0.34024868229677874`, 0.46860179638351807`, 0.9429205914171577],
              UndirectedEdge[8, 296] -> 
             RGBColor[
              0.3243573959090808, 0.4527479521097268, 0.9419845235854647], 
             UndirectedEdge[292, 382] -> 
             RGBColor[
              0.7052640732376753, 0.762696275633171, 0.7945398218792438], 
             UndirectedEdge[223, 328] -> 
             RGBColor[
              0.5740014674714932, 0.6619956182729114, 0.9611036391647454], 
             UndirectedEdge[70, 262] -> 
             RGBColor[
              0.7759009583562283, 0.8243735283366511, 0.951006477310862], 
             UndirectedEdge[78, 285] -> 
             RGBColor[
              0.5363245709433084, 0.6203060457482807, 0.9603159981975252], 
             UndirectedEdge[167, 272] -> 
             RGBColor[
              0.5026041918869922, 0.5949240040830116, 0.9568083899873292], 
             UndirectedEdge[93, 276] -> 
             RGBColor[
              0.3765521439370048, 0.5005722738423461, 0.9452145475330471], 
             UndirectedEdge[56, 319] -> 
             RGBColor[
              0.44080020255282815`, 0.5540190020972716, 0.9499167163020283], 
             UndirectedEdge[93, 162] -> 
             RGBColor[
              0.36540536556327186`, 0.49091749466838985`, 0.9445042846717819],
              UndirectedEdge[106, 389] -> 
             RGBColor[
              0.9175855552158254, 0.9321476888318894, 0.7269090090385233], 
             UndirectedEdge[68, 176] -> 
             RGBColor[
              0.6118408880613506, 0.6927001878739085, 0.9643908703573252], 
             UndirectedEdge[253, 301] -> 
             RGBColor[
              0.2711258922832188, 0.4023008815370681, 0.9387515905194912], 
             UndirectedEdge[217, 357] -> 
             RGBColor[
              0.6026110175079943, 0.6850045087024121, 0.9636762972066493], 
             UndirectedEdge[364, 385] -> 
             RGBColor[
              0.5699024386526501, 0.6616367427940842, 0.9593350655510184], 
             UndirectedEdge[161, 372] -> 
             RGBColor[
              0.5000971426451952, 0.6033781702888373, 0.9542479087368462], 
             UndirectedEdge[4, 339] -> 
             RGBColor[
              0.8924917030400288, 0.9156916262002712, 0.9314436033537402], 
             UndirectedEdge[183, 280] -> 
             RGBColor[
              0.348011960255442, 0.47451655731617043`, 0.9434448967316709], 
             UndirectedEdge[94, 145] -> 
             RGBColor[
              0.7252051238155766, 0.7806114873643772, 0.8468541707686654], 
             UndirectedEdge[107, 351] -> 
             RGBColor[
              0.5925768493474696, 0.6744604453036813, 0.9638414081285427], 
             UndirectedEdge[90, 178] -> 
             RGBColor[
              0.6155088875089288, 0.680050696781973, 0.8672571851085142], 
             UndirectedEdge[113, 124] -> 
             RGBColor[
              0.5982905672011287, 0.6779479045124154, 0.9648782788648251], 
             UndirectedEdge[191, 365] -> 
             RGBColor[
              0.5002229989094866, 0.5882277078530105, 0.9573366789701682], 
             UndirectedEdge[184, 356] -> 
             RGBColor[
              0.7204545267319564, 0.7799263296374825, 0.9618415337898073], 
             UndirectedEdge[196, 327] -> 
             RGBColor[
              0.33363133833800984`, 0.4603841285403203, 0.9425899668404029], 
             UndirectedEdge[140, 288] -> 
             RGBColor[
              0.4042374786667471, 0.5203803978762589, 0.9475918299344013], 
             UndirectedEdge[13, 232] -> 
             RGBColor[
              0.5648790865049007, 0.6560642213674366, 0.959688592494288], 
             UndirectedEdge[34, 86] -> 
             RGBColor[
              0.8818410467324986, 0.9086201299996906, 0.9885919803377832], 
             UndirectedEdge[287, 374] -> 
             RGBColor[
              0.3939120021188649, 0.5156085104676312, 0.9463207023456754], 
             UndirectedEdge[201, 230] -> 
             RGBColor[
              0.8495439390422639, 0.8830946229180086, 0.9854511270062585], 
             UndirectedEdge[71, 138] -> 
             RGBColor[
              0.7185483685381311, 0.7791764288053448, 0.9734120194499124], 
             UndirectedEdge[334, 360] -> 
             RGBColor[
              0.8350764004055492, 0.8716558686590249, 0.9840453882293057], 
             UndirectedEdge[38, 58] -> 
             RGBColor[
              0.5020257568186547, 0.605904207532064, 0.9541344021784346], 
             UndirectedEdge[115, 239] -> 
             RGBColor[
              0.9476164373495731, 0.8187427639311557, 0.3349489635769477], 
             UndirectedEdge[32, 78] -> 
             RGBColor[
              0.27702585708198507`, 0.40850211861994545`, 0.9390875847865652],
              UndirectedEdge[41, 83] -> 
             RGBColor[
              0.5487920177630529, 0.644573108675532, 0.9576220644111582], 
             UndirectedEdge[90, 212] -> 
             RGBColor[
              0.5413093879488278, 0.6234579478622149, 0.9609161114625372], 
             UndirectedEdge[160, 263] -> 
             RGBColor[
              0.521090201237922, 0.6181561347017476, 0.9568900888105873], 
             UndirectedEdge[226, 350] -> 
             RGBColor[
              0.49558357581302304`, 0.5973745690032636, 0.954709955564261], 
             UndirectedEdge[159, 329] -> 
             RGBColor[
              0.7445378727361158, 0.8003579119696489, 0.9751722351184811], 
             UndirectedEdge[132, 260] -> 
             RGBColor[
              0.551802287506049, 0.6349871495242595, 0.9614378444246918], 
             UndirectedEdge[7, 250] -> 
             RGBColor[
              0.9327756945403359, 0.927728805991002, 0.6826407712048473], 
             UndirectedEdge[135, 281] -> 
             RGBColor[
              0.38324346236707485`, 0.5063679575510298, 0.9456409124265106], 
             UndirectedEdge[240, 243] -> 
             RGBColor[
              0.6469196187785651, 0.7228075929757976, 0.9663246746457175], 
             UndirectedEdge[105, 349] -> 
             RGBColor[
              0.32688728450005455`, 0.45154527001165223`, 0.9422699947809734],
              UndirectedEdge[111, 154] -> 
             RGBColor[
              0.34162825354962734`, 0.47032295531456914`, 0.9429892281195471],
              UndirectedEdge[3, 233] -> 
             RGBColor[
              0.5281878276278364, 0.605957188855925, 0.9607307713106685], 
             UndirectedEdge[125, 162] -> 
             RGBColor[
              0.6473423979886647, 0.718215532653558, 0.965328306278196], 
             UndirectedEdge[301, 369] -> 
             RGBColor[
              0.519701462900228, 0.611383412180008, 0.9580212531507065], 
             UndirectedEdge[268, 270] -> 
             RGBColor[
              0.32309259032718496`, 0.448704563742018, 0.942011867522295], 
             UndirectedEdge[4, 188] -> 
             RGBColor[
              0.5817848115912021, 0.6665480326068669, 0.9625261293287283], 
             UndirectedEdge[161, 176] -> 
             RGBColor[
              0.7021556597825076, 0.7667237319040029, 0.9713068308818464], 
             UndirectedEdge[106, 270] -> 
             RGBColor[
              0.6207366330943928, 0.6829114591598003, 0.7032338257307688], 
             UndirectedEdge[190, 268] -> 
             RGBColor[
              0.3875294279543929, 0.5100802455238707, 0.945914010363804], 
             UndirectedEdge[220, 341] -> 
             RGBColor[
              0.7528500898678964, 0.8064770364778924, 0.9711113705334857], 
             UndirectedEdge[76, 103] -> 
             RGBColor[
              0.4215903696797436, 0.5392239024173018, 0.948183320394487], 
             UndirectedEdge[84, 163] -> 
             RGBColor[
              0.3204587185322967, 0.4443657714097614, 0.9419193734117043], 
             UndirectedEdge[356, 372] -> 
             RGBColor[
              0.44181344685690066`, 0.5560608403973263, 0.9496596027041793], 
             UndirectedEdge[243, 398] -> 
             RGBColor[
              0.7738039618940387, 0.8210365735375944, 0.8912449071900741], 
             UndirectedEdge[141, 243] -> 
             RGBColor[
              0.7457367881770712, 0.8009205157983501, 0.9759307155350427], 
             UndirectedEdge[192, 320] -> 
             RGBColor[
              0.3229765673908477, 0.447362458378869, 0.9420499361455499], 
             UndirectedEdge[83, 245] -> 
             RGBColor[
              0.6070940858336791, 0.6919053540135017, 0.9622118167771901], 
             UndirectedEdge[256, 313] -> 
             RGBColor[
              0.7143354887273198, 0.7757036467225153, 0.9731408806650779], 
             UndirectedEdge[144, 186] -> 
             RGBColor[
              0.6749460272147811, 0.7453176248906459, 0.9686972038045709], 
             UndirectedEdge[271, 371] -> 
             RGBColor[
              0.5518210998946358, 0.5152040593446747, 0.5940679089065659], 
             UndirectedEdge[317, 326] -> 
             RGBColor[
              0.45826103441077154`, 0.5641558697414328, 0.9518523432034134], 
             UndirectedEdge[194, 242] -> 
             RGBColor[
              0.9043392033414055, 0.9222009289579621, 0.7722116072655146], 
             UndirectedEdge[305, 334] -> 
             RGBColor[
              0.8594459290520343, 0.8907628710605635, 0.9864559140210629], 
             UndirectedEdge[252, 282] -> 
             RGBColor[
              0.4200477643734449, 0.5337128127308705, 0.9487912414580528], 
             UndirectedEdge[134, 239] -> 
             RGBColor[
              0.6347317174481535, 0.571566803820907, 0.5925541600983439], 
             UndirectedEdge[267, 398] -> 
             RGBColor[
              0.655461523976475, 0.7213803419086884, 0.8829178623516158], 
             UndirectedEdge[4, 297] -> 
             RGBColor[
              0.5876733452762689, 0.6716483845185632, 0.9629013414881149], 
             UndirectedEdge[40, 272] -> 
             RGBColor[
              0.23071644020804116`, 0.3598279852988145, 0.9364503320042371], 
             UndirectedEdge[203, 325] -> 
             RGBColor[
              0.39349574616863225`, 0.5093017055846987, 0.9469608475965618], 
             UndirectedEdge[315, 359] -> 
             RGBColor[
              0.616913091207377, 0.6876594918651694, 0.9471574918364281], 
             UndirectedEdge[132, 160] -> 
             RGBColor[
              0.3032112804035724, 0.43299167122747656`, 0.9406898584387196], 
             UndirectedEdge[283, 381] -> 
             RGBColor[
              0.4127098057427798, 0.5229480877473076, 0.9486511735281673], 
             UndirectedEdge[40, 183] -> 
             RGBColor[
              0.3046181940865834, 0.428906957749016, 0.9409736859436786], 
             UndirectedEdge[131, 339] -> 
             RGBColor[
              0.636899728325715, 0.704163890699641, 0.9109939577513271], 
             UndirectedEdge[156, 165] -> 
             RGBColor[
              0.672351621140254, 0.7413107432547226, 0.9699588193260231], 
             UndirectedEdge[352, 379] -> 
             RGBColor[
              0.5876610431857447, 0.6728602221970161, 0.9623831405768383], 
             UndirectedEdge[25, 194] -> 
             RGBColor[
              0.5741582970076494, 0.6592671197618556, 0.9623259551119925], 
             UndirectedEdge[174, 238] -> 
             RGBColor[
              0.24429032652933869`, 0.3740950004565988, 0.9372233447494698], 
             UndirectedEdge[66, 339] -> 
             RGBColor[
              0.8257255439590757, 0.8635333952846276, 0.9247889765817814], 
             UndirectedEdge[67, 387] -> 
             RGBColor[
              0.9687192594525933, 0.901072469965903, 0.45715218334851954`], 
             UndirectedEdge[90, 190] -> 
             RGBColor[
              0.3086918978665423, 0.435433615131645, 0.9411234792279346], 
             UndirectedEdge[271, 389] -> 
             RGBColor[
              0.8810520475973801, 0.7984758510417277, 0.6195872006662624], 
             UndirectedEdge[19, 293] -> 
             RGBColor[
              0.5273357035162501, 0.6252463465703579, 0.956576706773034], 
             UndirectedEdge[126, 327] -> 
             RGBColor[
              0.3571617317642998, 0.4837772734088024, 0.9439790076156707], 
             UndirectedEdge[12, 310] -> 
             RGBColor[
              0.8905042256423648, 0.9128662560325314, 0.8735341780049454], 
             UndirectedEdge[272, 350] -> 
             RGBColor[
              0.4618413606540296, 0.5630797705148294, 0.9527455319203433], 
             UndirectedEdge[215, 229] -> 
             RGBColor[
              0.7937793108279965, 0.83875883802437, 0.9489501540002117], 
             UndirectedEdge[57, 189] -> 
             RGBColor[
              0.4005158567944434, 0.520934028578613, 0.9468504704773871], 
             UndirectedEdge[104, 337] -> 
             RGBColor[
              0.6676234236259961, 0.7318752803050205, 0.8822561260230524], 
             UndirectedEdge[194, 385] -> 
             RGBColor[
              0.6537419033081874, 0.7271327697865214, 0.96769139986354], 
             UndirectedEdge[56, 166] -> 
             RGBColor[
              0.7426044260289422, 0.7978616373797911, 0.9623252311913386], 
             UndirectedEdge[258, 379] -> 
             RGBColor[
              0.48843407464356564`, 0.5942622080449563, 0.9532323133273841], 
             UndirectedEdge[9, 150] -> 
             RGBColor[
              0.6024742322091607, 0.6691997868480395, 0.927514903435542], 
             UndirectedEdge[294, 380] -> 
             RGBColor[
              0.5176738125346501, 0.6092522230853271, 0.9579057814620268], 
             UndirectedEdge[296, 308] -> 
             RGBColor[
              0.5084476407382362, 0.6094141209599844, 0.9551498432671179], 
             UndirectedEdge[33, 92] -> 
             RGBColor[
              0.6658710132892749, 0.733581829673098, 0.956551770831167], 
             UndirectedEdge[39, 283] -> 
             RGBColor[
              0.6276683346704974, 0.21554461565554112`, 0.42196383516705815`],
              UndirectedEdge[11, 34] -> 
             RGBColor[
              0.776765300295185, 0.8256849537349763, 0.9783443646965586], 
             UndirectedEdge[105, 171] -> 
             RGBColor[
              0.5095325837513189, 0.6115251527299888, 0.9548561786174935], 
             UndirectedEdge[110, 237] -> 
             RGBColor[
              0.6388680905477557, 0.7029757017789752, 0.8049625931954458], 
             UndirectedEdge[8, 175] -> 
             RGBColor[
              0.6206759852037244, 0.6912317241183294, 0.9451776428834335], 
             UndirectedEdge[90, 373] -> 
             RGBColor[
              0.4125459229552436, 0.5218071715719292, 0.9487300145567817], 
             UndirectedEdge[73, 104] -> 
             RGBColor[
              0.9746704435404381, 0.9797238689230927, 0.8871893301537875], 
             UndirectedEdge[232, 339] -> 
             RGBColor[
              0.7073145421217335, 0.7670869393513109, 0.9154099407128824], 
             UndirectedEdge[178, 274] -> 
             RGBColor[
              0.7480532198838732, 0.7998113763800789, 0.8758578186641729], 
             UndirectedEdge[224, 318] -> 
             RGBColor[
              0.4163975378525055, 0.535084351364224, 0.9477534607994444], 
             UndirectedEdge[132, 307] -> 
             RGBColor[
              0.292307553164714, 0.42354741073044333`, 0.939995082580847]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {400}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.994344726552349, 0.9919294133425673, 0.743386046613506], 316 -> 
             RGBColor[
              0.9013949763747258, 0.924211902719122, 0.990457051603058], 308 -> 
             RGBColor[
              0.6486337793991782, 0.7254369053567278, 0.9656134113693626], 
             160 -> RGBColor[
              0.3415503636273469, 0.47025549097875113`, 0.9429842650425748], 
             245 -> RGBColor[
              0.5886241328699696, 0.6769106141356636, 0.96075779442222], 155 -> 
             RGBColor[
              0.28844634003034064`, 0.42050577029910813`, 0.9397379643953836],
              213 -> RGBColor[
              0.9688037379142649, 0.9064298241334553, 0.3333088420270337], 
             352 -> RGBColor[
              0.7702357707688295, 0.8204333052240638, 0.9777335614338711], 27 -> 
             RGBColor[
              0.40060129833843744`, 0.5214024426392211, 0.9467469383856741], 
             367 -> RGBColor[
              0.5150202413246707, 0.6171556591616627, 0.9549634264598355], 19 -> 
             RGBColor[
              0.6610578844930827, 0.7351427106827819, 0.9668517300552598], 
             164 -> RGBColor[
              0.694603429418418, 0.7613487453340381, 0.9701952364724766], 190 -> 
             RGBColor[
              0.3774431413559686, 0.5013440110238203, 0.9452713211007054], 
             103 -> RGBColor[
              0.37666981320106396`, 0.5006741930446451, 0.9452220453145022], 
             138 -> RGBColor[
              0.549183241886987, 0.6448907220437877, 0.9576528630072955], 291 -> 
             RGBColor[
              0.6143870078214779, 0.6978260766255885, 0.9627859423109232], 28 -> 
             RGBColor[
              0.9198367848503419, 0.7198865952791622, 0.25435699929932803`], 
             337 -> RGBColor[
              0.34560167605781983`, 0.47376453418114334`, 0.9432424110882096],
              195 -> RGBColor[
              0.6613558420707617, 0.7353754774070262, 0.966881427682031], 114 -> 
             RGBColor[
              0.6816204787197124, 0.7512063655741295, 0.968901217279402], 93 -> 
             RGBColor[
              0.3759056599373993, 0.5000123218951185, 0.9451733541442556], 34 -> 
             RGBColor[
              0.838632689988928, 0.8741669591919665, 0.9844707286990261], 161 -> 
             RGBColor[
              0.6080954954879547, 0.6927183434838337, 0.9622906514134592], 22 -> 
             RGBColor[
              0.49641456178715837`, 0.6020507303367987, 0.9534987192117926], 
             124 -> RGBColor[
              0.3182572804720307, 0.45008019309401653`, 0.9415000503811827], 
             84 -> RGBColor[
              0.2263162165713289, 0.3552030712663376, 0.9361997457776738], 46 -> 
             RGBColor[
              0.8727044713664822, 0.9013348728085605, 0.9877205256230555], 
             241 -> RGBColor[
              0.5862148038872863, 0.6749546123284875, 0.9605681232190403], 
             185 -> RGBColor[
              0.9111971541566467, 0.6856333385649207, 0.24740534964498392`], 
             390 -> RGBColor[
              0.9758467158646817, 0.9815071007560283, 0.9257693892424006], 
             121 -> RGBColor[
              0.575555927907293, 0.6663012566310381, 0.959729017457146], 322 -> 
             RGBColor[
              0.9635246580011065, 0.9723173301768919, 0.9466274190980382], 
             126 -> RGBColor[
              0.3232261687291954, 0.4543839943587872, 0.9418166635471139], 
             236 -> RGBColor[
              0.8739767556921817, 0.9023493577946352, 0.9878418772378224], 78 -> 
             RGBColor[
              0.24642773608906224`, 0.37634155342346165`, 0.9373450670618818],
              376 -> RGBColor[
              0.5365430997926554, 0.6346288852596972, 0.9566577847192635], 
             254 -> RGBColor[
              0.218078515776465, 0.34654472543053866`, 0.9357306209039925], 
             290 -> RGBColor[
              0.8684197020878087, 0.4954064231876414, 0.21191851290487906`], 
             251 -> RGBColor[
              0.6581657414961135, 0.7328833465924488, 0.9665634682699349], 
             165 -> RGBColor[
              0.4435483517921228, 0.5586010217591333, 0.9494834866551548], 
             100 -> RGBColor[
              0.4127316167853028, 0.5319091147903633, 0.947519871550689], 235 -> 
             RGBColor[
              0.26947012983568863`, 0.4005605702233112, 0.9386572972975855], 
             70 -> RGBColor[
              0.9665419111038577, 0.9745675926006253, 0.9415199966207232], 
             234 -> RGBColor[
              0.299120566290855, 0.43172505888394286`, 0.9403458457898173], 
             257 -> RGBColor[
              0.5432945274502964, 0.6401099983805201, 0.9571892818357675], 
             135 -> RGBColor[
              0.33193466615008266`, 0.46192685712295256`, 0.9423715613021509],
              265 -> RGBColor[
              0.6984443854968104, 0.7643493294148257, 0.9705780670785955], 
             111 -> RGBColor[
              0.3182572804720307, 0.45008019309401653`, 0.9415000503811827], 
             381 -> RGBColor[
              0.5770526074740675, 0.6675163285279917, 0.9598468415551603], 
             182 -> RGBColor[
              0.9391614178421125, 0.9541472655574587, 0.9878680297365052], 
             188 -> RGBColor[
              0.3645497140335442, 0.4901763723196362, 0.9444497633129306], 
             154 -> RGBColor[
              0.36499922662722395`, 0.4905657175351217, 0.9444784058579115], 
             336 -> RGBColor[
              0.25812725555426974`, 0.38863849017377267`, 0.9380113373875374],
              315 -> RGBColor[
              0.9583906442599797, 0.9684883911349355, 0.9553179651965296], 
             368 -> RGBColor[
              0.5316136784213846, 0.6306269589225975, 0.9562697226118516], 
             269 -> RGBColor[
              0.6682793121720447, 0.7407841448704703, 0.9675714944782202], 
             208 -> RGBColor[
              0.7696105875957487, 0.8199449073776849, 0.9776712490178473], 86 -> 
             RGBColor[
              0.9250494034760692, 0.9430733008074145, 0.9927132319765404], 
             119 -> 
             RGBColor[
              0.31778486431562036`, 0.4496710099636603, 0.9414699484414375], 
             377 -> RGBColor[
              0.9932097563927003, 0.9878846804599533, 0.5023020717505519], 
             140 -> RGBColor[
              0.2844054337391649, 0.4162585215788257, 0.9395078407600863], 85 -> 
             RGBColor[
              0.6533664931037626, 0.7291341372727055, 0.9660851240417115], 
             351 -> RGBColor[
              0.34932889259789857`, 0.47699286181280925`, 0.9434799060302952],
              242 -> RGBColor[
              0.993760399219947, 0.9890624497889042, 0.562236145322739], 117 -> 
             RGBColor[
              0.8826436490470732, 0.9092601032992728, 0.9886685332630389], 47 -> 
             RGBColor[
              0.9412470725120512, 0.8047712513024178, 0.2715842193159824], 81 -> 
             RGBColor[
              0.6478614185537592, 0.7248335311941266, 0.9655364296584138], 
             275 -> RGBColor[
              0.2630942154152196, 0.39385907991107527`, 0.9382941984036599], 
             23 -> RGBColor[
              0.9935218820879124, 0.9915891460103847, 0.7570227088424326], 
             328 -> RGBColor[
              0.7474759479252682, 0.8026531586376132, 0.9754650749954621], 
             110 -> RGBColor[
              0.9947550565550263, 0.9911899212533559, 0.6704984579325936], 6 -> 
             RGBColor[
              0.5487166511051903, 0.6445119226274499, 0.957616131271774], 218 -> 
             RGBColor[
              0.446416661211381, 0.5610854072126715, 0.9496662527950035], 108 -> 
             RGBColor[
              0.4473444412325766, 0.5618890036354514, 0.9497253701175504], 
             297 -> RGBColor[
              0.3763267814036779, 0.5003770761430287, 0.9452001876317038], 
             157 -> RGBColor[
              0.9675482301148659, 0.975318103671339, 0.9398165610251193], 354 -> 
             RGBColor[
              0.7600079636622966, 0.8124432645782271, 0.9767141492057835], 
             385 -> RGBColor[
              0.49256579915351073`, 0.5989261314460228, 0.9531957305187898], 
             270 -> RGBColor[
              0.24856946610155278`, 0.378592647460115, 0.9374670354176876], 
             392 -> RGBColor[
              0.17892700000000003`, 0.30539400000000005`, 0.933501], 33 -> 
             RGBColor[
              0.9511174975976722, 0.9630640902628712, 0.9676295053553601], 
             252 -> RGBColor[
              0.28855990319342395`, 0.42062513238382915`, 0.9397444316495196],
              394 -> RGBColor[
              0.2351403652684994, 0.3644778110304055, 0.9367022679918195], 
             260 -> RGBColor[
              0.8387323778323, 0.874246447572317, 0.9844802370145193], 159 -> 
             RGBColor[
              0.7554223293030421, 0.8088609321646656, 0.9762570960280426], 
             183 -> RGBColor[
              0.40172405559403773`, 0.5223749185426017, 0.9468184794851857], 
             99 -> RGBColor[
              0.7000972294985534, 0.7656405437110669, 0.9707428071219839], 
             329 -> RGBColor[
              0.7336534161691894, 0.7918548917746323, 0.9740873742089196], 
             309 -> RGBColor[
              0.6226287254509354, 0.7045170742823301, 0.9634347605131205], 17 -> 
             RGBColor[
              0.5242899227912118, 0.6246812041705919, 0.9556931697408436], 
             349 -> RGBColor[
              0.2437448675978899, 0.37352168853555245`, 0.9371922816702578], 
             347 -> RGBColor[
              0.9043718228264948, 0.9265855592754183, 0.9907409858750899], 
             340 -> RGBColor[
              0.7808096699854081, 0.8286937156566655, 0.9787874688890734], 
             277 -> RGBColor[
              0.7885524187266235, 0.8347424098203728, 0.9795591937234969], 
             104 -> RGBColor[
              0.9896451711941724, 0.9899860264288977, 0.8212698409578952], 79 -> 
             RGBColor[
              0.5175134036585041, 0.6191797206599517, 0.9551596973315093], 
             327 -> RGBColor[
              0.39109729479940414`, 0.5131705524588176, 0.9461413516842273], 
             191 -> RGBColor[
              0.7823674820425083, 0.8299106902754823, 0.9789427370363438], 50 -> 
             RGBColor[
              0.745095539488423, 0.8007935654749756, 0.9752278181286589], 225 -> 
             RGBColor[
              0.8723528460016508, 0.9010544962872601, 0.9876869872818582], 61 -> 
             RGBColor[
              0.21913021617489342`, 0.3476501292309435, 0.9357905136858318], 
             196 -> RGBColor[
              0.2761653818766155, 0.40759770462182293`, 0.9390385819965784], 
             1 -> RGBColor[
              0.9948065985851545, 0.9913001644441017, 0.6761084898315186], 
             263 -> RGBColor[
              0.7006300388484972, 0.7660567784247441, 0.9707959125785998], 
             201 -> RGBColor[
              0.7918582571438555, 0.837324955917217, 0.9798886888021102], 371 -> 
             RGBColor[
              0.18380541493892977`, 0.3105215234101872, 0.933778818513804], 
             293 -> RGBColor[
              0.39361352253941756`, 0.5153499824579338, 0.9463016834908081], 
             362 -> 
             RGBColor[
              0.42828257605155806`, 0.5453785740928544, 0.9485107649239615], 
             184 -> RGBColor[
              0.949380949552547, 0.9617689755741534, 0.9705690282314894], 106 -> 
             RGBColor[
              0.9929038000872327, 0.9872302708594857, 0.46900061604384996`], 
             206 -> RGBColor[
              0.31974290914963016`, 0.45136696998468473`, 0.9415947133268295],
              358 -> RGBColor[
              0.46235105200351545`, 0.5743964385508092, 0.9508171149428765], 
             247 -> RGBColor[
              0.592858728444615, 0.6803484495895173, 0.9610911572976907], 220 -> 
             RGBColor[
              0.9417945195538192, 0.9561110285027411, 0.9834108753614995], 
             107 -> RGBColor[
              0.8358248060970406, 0.8719280287945533, 0.9842029102267903], 
             375 -> RGBColor[
              0.5767467698292806, 0.6672680357501249, 0.9598227648954425], 
             131 -> RGBColor[
              0.2878359597202321, 0.41986422189283723`, 0.9397032041396998], 
             127 -> RGBColor[
              0.822435631411119, 0.8612518643394643, 0.9829258387925898], 210 -> 
             RGBColor[
              0.8744227614329156, 0.5226649136236405, 0.2169276127708858], 
             357 -> RGBColor[
              0.41604090069759514`, 0.5347754501857452, 0.9477307361952954], 
             181 -> RGBColor[
              0.522509787363411, 0.6232360100361161, 0.9555530309591161], 194 -> 
             RGBColor[
              0.814918007462864, 0.85533940812702, 0.9821870692082902], 118 -> 
             RGBColor[
              0.5801164915298362, 0.6700037276308686, 0.9600880417314076], 
             348 -> RGBColor[
              0.6663705601739763, 0.7392930133025266, 0.9673812479173544], 
             276 -> RGBColor[
              0.37719862793661035`, 0.501132225789574, 0.9452557409218386], 
             305 -> RGBColor[
              0.8285630673555743, 0.8661377154367551, 0.9835102791029985], 
             343 -> RGBColor[
              0.9655283033901028, 0.9738116456273371, 0.9432357700888793], 
             280 -> RGBColor[
              0.29429986491684634`, 0.4266581960897392, 0.9400713139781561], 
             189 -> RGBColor[
              0.33318793703062777`, 0.46301237736845474`, 0.9424514186144354],
              168 -> RGBColor[
              0.9619531323721293, 0.9711452889359378, 0.9492876020683684], 
             363 -> RGBColor[
              0.735043418455536, 0.7929407721251349, 0.9742259166465126], 41 -> 
             RGBColor[
              0.4720199967287173, 0.5822461234597242, 0.9515782896901559], 14 -> 
             RGBColor[
              0.8806917121149128, 0.9077036817734847, 0.9884823557759348], 77 -> 
             RGBColor[
              0.3971940509865405, 0.5184512562362393, 0.9465298315973218], 51 -> 
             RGBColor[
              0.694592117177041, 0.7613399081250981, 0.9701941089739751], 179 -> 
             RGBColor[
              0.26469064263808445`, 0.3955370261416383, 0.9383851125722996], 
             223 -> RGBColor[
              0.40052698701771816`, 0.5213380779082096, 0.9467422033340288], 
             323 -> RGBColor[
              0.8747124715261696, 0.902935997630183, 0.9879120504708494], 292 -> 
             RGBColor[
              0.9944872457777554, 0.9906171010805966, 0.6413489075631922], 
             396 -> RGBColor[
              0.6113798321514899, 0.6953847159449721, 0.9625492064265343], 
             321 -> RGBColor[
              0.9334140540072698, 0.7737159431296419, 0.26528158876245994`], 
             143 -> RGBColor[
              0.36317696076986633`, 0.4889873624392236, 0.9443622926888472], 
             112 -> RGBColor[
              0.5500308526798752, 0.6455788506698854, 0.9577195900338122], 
             197 -> RGBColor[
              0.4174529613619098, 0.535998506160942, 0.9478207114521893], 54 -> 
             RGBColor[
              0.9749833092345896, 0.9808631735050042, 0.9272309114546321], 71 -> 
             RGBColor[
              0.8879134951892751, 0.9134621355669018, 0.9891711758925293], 
             177 -> RGBColor[
              0.9887546035702047, 0.9896177538298431, 0.8360288512021706], 
             158 -> RGBColor[
              0.30152831870287067`, 0.4342557593292915, 0.9404829637277311], 
             226 -> RGBColor[
              0.32140497815494024`, 0.4528065706190671, 0.9417006188941379], 
             350 -> RGBColor[
              0.6697621734711059, 0.7419425673874601, 0.967719292234384], 203 -> 
             RGBColor[
              0.5223008496991801, 0.6230663850277589, 0.9555365826208241], 
             115 -> RGBColor[
              0.9925397946220252, 0.9864516999760051, 0.42938086753736365`], 
             173 -> RGBColor[
              0.6029093651359207, 0.6885080092315425, 0.9618823802347256], 
             212 -> RGBColor[
              0.8426781215205394, 0.8773926764849599, 0.9848565855699105], 
             129 -> RGBColor[
              0.9946542480762123, 0.9920574084470252, 0.7382564739470651], 
             279 -> RGBColor[
              0.590985265128032, 0.6788274876705547, 0.9609436714026871], 26 -> 
             RGBColor[
              0.2730143540378202, 0.40428577457654497`, 0.938859135622687], 
             40 -> RGBColor[
              0.20751233257912907`, 0.3354389969554303, 0.9351288924021716], 
             146 -> RGBColor[
              0.5393314366248289, 0.6368925827131984, 0.9568772928087066], 
             386 -> RGBColor[
              0.9950222340314365, 0.9917613868596109, 0.6995790774115974], 
             192 -> RGBColor[
              0.41081276951319595`, 0.5302471057273325, 0.9473976042992803], 
             300 -> RGBColor[
              0.9427659784302296, 0.9568355409421501, 0.9817664488807905], 
             221 -> RGBColor[
              0.31736631202200766`, 0.44930848100398296`, 0.9414432786593997],
              62 -> RGBColor[
              0.6757315017146623, 0.7466058519799014, 0.9683142590871576], 
             286 -> RGBColor[
              0.8620908655322117, 0.8928718716149687, 0.986708190423705], 152 -> 
             RGBColor[
              0.6616937665057561, 0.7356394665439647, 0.9669151088316279], 64 -> 
             RGBColor[
              0.44522634867631095`, 0.5600544183216414, 0.9495904071328208], 
             307 -> RGBColor[
              0.31974290914963016`, 0.45136696998468473`, 0.9415947133268295],
              37 -> RGBColor[
              0.9520495081601681, 0.8475993089489144, 0.2802761126042113], 
             148 -> RGBColor[
              0.2437448675978899, 0.37352168853555245`, 0.9371922816702578], 
             261 -> RGBColor[
              0.31974290914963016`, 0.45136696998468473`, 0.9415947133268295],
              387 -> RGBColor[
              0.9944872457777554, 0.9906171010805966, 0.6413489075631922], 15 -> 
             RGBColor[
              0.6524685906514313, 0.7284326890526329, 0.9659956295166386], 
             136 -> RGBColor[
              0.7745827557916806, 0.8238292029622247, 0.9781668282760643], 
             198 -> RGBColor[
              0.6850340675819134, 0.7538730871375171, 0.9692414519153846], 63 -> 
             RGBColor[
              0.3279686983843273, 0.45849173517959113`, 0.9421188533430845], 
             310 -> RGBColor[
              0.7881219172703087, 0.8344060988107674, 0.9795162853615963], 
             171 -> RGBColor[
              0.6090354661004186, 0.6934814539722254, 0.9623646493432981], 
             395 -> RGBColor[
              0.25838038902326527`, 0.3889045494992759, 0.9380257529641193], 
             311 -> 
             RGBColor[
              0.618268378377268, 0.7009771480965297, 0.9630914980190037], 353 -> 
             RGBColor[
              0.7148979106014419, 0.7772029482779861, 0.972218000694091], 59 -> 
             RGBColor[
              0.31050265695157414`, 0.44336352795930795`, 0.9410059326276036],
              397 -> RGBColor[
              0.27392083391636673`, 0.4052385424030412, 0.9389107583107534], 
             229 -> RGBColor[
              0.6171060750411379, 0.7000335378870908, 0.9629999972427262], 
             102 -> RGBColor[
              0.7657681502972928, 0.8169431661565261, 0.9772882707775553], 
             299 -> RGBColor[
              0.6601327789405779, 0.7344200111941026, 0.966759524179389], 128 -> 
             RGBColor[
              0.9948133946020434, 0.9913147004370444, 0.6768481943297207], 12 -> 
             RGBColor[
              0.9928865340144208, 0.9913264132542953, 0.7675520706482944], 
             222 -> RGBColor[
              0.21913021617489342`, 0.3476501292309435, 0.9357905136858318], 
             92 -> RGBColor[
              0.3806245289808775, 0.504099569083325, 0.945474036306974], 271 -> 
             RGBColor[
              0.9198367848503419, 0.7198865952791622, 0.25435699929932803`], 
             361 -> RGBColor[
              0.31974290914963016`, 0.45136696998468473`, 0.9415947133268295],
              344 -> RGBColor[
              0.9845087103801874, 0.9878619678812931, 0.9063942893801034], 
             132 -> RGBColor[
              0.26487219717979793`, 0.395727851476202, 0.9383954518348643], 
             80 -> RGBColor[
              0.36408895519492723`, 0.48977728617203875`, 0.944420404167167], 
             324 -> RGBColor[
              0.3030542232375889, 0.4358595817432158, 0.9405698617336098], 
             244 -> RGBColor[
              0.9858521189812836, 0.9884175018618726, 0.8841305322299263], 
             150 -> RGBColor[
              0.9799034170464469, 0.9845325818551502, 0.9189024522987927], 
             125 -> RGBColor[
              0.9397797247881848, 0.9546083978654547, 0.9868213973570836], 
             258 -> RGBColor[
              0.5717818336844712, 0.6632372769199442, 0.9594319069349627], 
             133 -> RGBColor[
              0.5089637376562443, 0.6122387166412531, 0.9544866363053529], 
             255 -> RGBColor[
              0.63941687376583, 0.7181464493818244, 0.9647563850454826], 326 -> 
             RGBColor[
              0.2837091291302335, 0.4155266612865767, 0.9394681872426981], 
             176 -> 
             RGBColor[
              0.7962158240770605, 0.8407291203241721, 0.9803230103502338], 
             230 -> RGBColor[
              0.9072296209406723, 0.9288642899188, 0.9910135652104066], 274 -> 
             RGBColor[
              0.5050293191270047, 0.6090445784356815, 0.9541769044664813], 87 -> 
             RGBColor[
              0.9175718425221606, 0.9371108966757526, 0.9920000155374591], 
             130 -> RGBColor[
              0.7474759479252682, 0.8026531586376132, 0.9754650749954621], 35 -> 
             RGBColor[
              0.9910706725649463, 0.9905755078794268, 0.7976455941648797], 
             379 -> RGBColor[
              0.40508631560266006`, 0.5252871391699685, 0.9470327197198054], 
             31 -> RGBColor[
              0.4930554897804407, 0.5993236843572759, 0.9532342807587376], 18 -> 
             RGBColor[
              0.9416028020008786, 0.9559680458656667, 0.9837354031706818], 24 -> 
             RGBColor[
              0.456891346960931, 0.5699640040403299, 0.9503873069623657], 151 -> 
             RGBColor[
              0.5955980222793184, 0.6825723317283106, 0.9613068045427225], 
             137 -> RGBColor[
              0.2930840102520079, 0.4253802557473558, 0.9400020728536893], 
             330 -> RGBColor[
              0.2351403652684994, 0.3644778110304055, 0.9367022679918195], 
             296 -> RGBColor[
              0.36826150207729424`, 0.4933913365632409, 0.9446862751648731], 
             266 -> RGBColor[
              0.9287912246260817, 0.946056927423405, 0.9930701302181918], 302 -> 
             RGBColor[
              0.9890330638099056, 0.9897329042950611, 0.8314140443983257], 
             283 -> RGBColor[
              0.24836700401149217`, 0.3783798469666234, 0.9374555055011744], 
             388 -> RGBColor[
              0.90645184326979, 0.928244111116251, 0.9909393800818275], 284 -> 
             RGBColor[
              0.49724195945800215`, 0.60272244903983, 0.953563854987299], 318 -> 
             RGBColor[
              0.4200634589197082, 0.5382595879380847, 0.9479870500481998], 
             238 -> RGBColor[
              0.18194199832570823`, 0.3085629544022542, 0.9336726996943588], 
             72 -> RGBColor[
              0.3994674099165776, 0.5204203254790952, 0.9466746880180914], 
             288 -> RGBColor[
              0.5240695235943292, 0.624502274173692, 0.9556758191087161], 382 -> 
             RGBColor[
              0.41604090069759514`, 0.5347754501857452, 0.9477307361952954], 
             389 -> RGBColor[
              0.8422673103444183, 0.8770651068042932, 0.9848174020331966], 
             172 -> RGBColor[
              0.9746789649440726, 0.9806361940314547, 0.9277460869527736], 
             243 -> RGBColor[
              0.5581354690287548, 0.6521585433307117, 0.9583576151209839], 88 -> 
             RGBColor[
              0.8587308762172109, 0.8901927073396674, 0.9863877116433423], 
             273 -> RGBColor[
              0.9942163946368472, 0.990037777877445, 0.6118684323748188], 202 -> 
             RGBColor[
              0.6753362039457379, 0.7462970423584433, 0.968274859499819], 393 -> 
             RGBColor[
              0.2625394375257221, 0.3932759731742636, 0.9382626046235734], 98 -> 
             RGBColor[
              0.3610600699792802, 0.4871538180344427, 0.944227406279564], 30 -> 
             RGBColor[
              0.4958916957431339, 0.6016262441274128, 0.9534575572814856], 
             116 -> RGBColor[
              0.440187582329164, 0.555690092167503, 0.9492693413967868], 373 -> 
             RGBColor[
              0.5851511915333713, 0.6740911239043887, 0.9604843917583996], 
             240 -> RGBColor[
              0.7357037685283754, 0.7934566426208834, 0.974291734170451], 317 -> 
             RGBColor[
              0.6328129396913096, 0.712785078196289, 0.9642364991641288], 391 -> 
             RGBColor[
              0.4227713197108363, 0.5406050008543192, 0.9481595925433433], 73 -> 
             RGBColor[
              0.9596957158867039, 0.9694617114172878, 0.9531088193496798], 
             303 -> RGBColor[
              0.9566117197579553, 0.9671616721540472, 0.9583292203606392], 29 -> 
             RGBColor[
              0.9802841904729936, 0.9451560863524973, 0.37790823231614445`], 
             360 -> RGBColor[
              0.779824010062604, 0.827923710633678, 0.978689227519484], 320 -> 
             RGBColor[
              0.2351403652684994, 0.3644778110304055, 0.9367022679918195], 75 -> 
             RGBColor[
              0.7543652050250479, 0.8080350986442544, 0.9761517317594001], 
             200 -> RGBColor[
              0.23822308854655252`, 0.36771794865158414`, 0.9368778245220243],
              301 -> RGBColor[
              0.27691720011208554`, 0.4083879132553312, 0.9390813969328731], 
             156 -> RGBColor[
              0.9011548904883853, 0.9240204647503119, 0.9904341519968916], 25 -> 
             RGBColor[
              0.3333985865524349, 0.46319483139669126`, 0.9424648410156948], 
             38 -> RGBColor[
              0.4274659520456407, 0.5446712554236448, 0.9484587303644166], 
             365 -> 
             RGBColor[
              0.218078515776465, 0.34654472543053866`, 0.9357306209039925], 
             380 -> RGBColor[
              0.27286189938092953`, 0.4041255350659693, 0.9388504535555136], 
             370 -> RGBColor[
              0.8260554435375163, 0.8641382042718709, 0.98327109970465], 3 -> 
             RGBColor[
              0.18445586758645585`, 0.31120519038381694`, 0.933815860829822], 
             57 -> RGBColor[
              0.46784377655825904`, 0.5788556797887714, 0.9512495223403389], 
             227 -> RGBColor[
              0.2207393389646039, 0.34934141930720675`, 0.9358821508482219], 
             39 -> RGBColor[0.817319, 0.134127, 0.164218], 109 -> 
             RGBColor[
              0.731294745505352, 0.7900122803254815, 0.9738522839601788], 256 -> 
             RGBColor[
              0.5334916226176433, 0.6321515586215422, 0.9564175612581174], 
             339 -> RGBColor[
              0.9859634969311977, 0.9884635595064448, 0.8822847113629545], 
             287 -> RGBColor[
              0.4242894903852428, 0.5419199639870133, 0.9482563290362509], 
             239 -> RGBColor[
              0.902693080077121, 0.6510338278863063, 0.2405170596165318], 285 -> 
             RGBColor[
              0.8262214057975545, 0.8642705380731, 0.9832869293331686], 345 -> 
             RGBColor[
              0.25838038902326527`, 0.3889045494992759, 0.9380257529641193], 
             366 -> RGBColor[
              0.3842054210498817, 0.5072011578126279, 0.9457022075831524], 
             216 -> RGBColor[
              0.6431645886896848, 0.7211643320070826, 0.9650682935519335], 21 -> 
             RGBColor[
              0.7348139569504978, 0.792761515053427, 0.9742030460681301], 355 -> 
             RGBColor[
              0.4482684157788016, 0.5626893039470804, 0.9497842449585973], 
             175 -> RGBColor[
              0.9608986806665814, 0.9703588805804464, 0.9510725137608107], 7 -> 
             RGBColor[
              0.8856750329144885, 0.9116772465104267, 0.9889576693624613], 13 -> 
             RGBColor[
              0.7010925856975321, 0.7664181235386963, 0.9708420149257655], 
             294 -> RGBColor[
              0.7624857256883705, 0.8143789111046849, 0.97696110936854], 193 -> 
             RGBColor[
              0.5728610389318953, 0.6641134243574455, 0.9595168659252991], 60 -> 
             RGBColor[
              0.43218935015145965`, 0.5487624254580135, 0.9487597011149825], 
             65 -> RGBColor[
              0.48783378257266996`, 0.5950844672107787, 0.9528232088395981], 
             69 -> 
             RGBColor[
              0.43056352721768226`, 0.5473542193490122, 0.948656105115301], 
             217 -> RGBColor[
              0.7891811343183934, 0.835233567219079, 0.9796218582180033], 214 -> 
             RGBColor[
              0.32140497815494024`, 0.4528065706190671, 0.9417006188941379], 
             170 -> RGBColor[
              0.5419408538685232, 0.6390110251845367, 0.9570827156927405], 
             359 -> RGBColor[
              0.2754355381547744, 0.4068305925954033, 0.9389970184763267], 74 -> 
             RGBColor[
              0.6926954437062757, 0.759858212394484, 0.9700050662878306], 246 -> 
             RGBColor[
              0.2673000457520936, 0.3982796742601751, 0.9385337142193765], 
             264 -> RGBColor[
              0.894256317803437, 0.9185197301481011, 0.9897761599757726], 278 -> 
             RGBColor[
              0.7671163260620597, 0.8179963713104772, 0.9774226443383685], 45 -> 
             RGBColor[
              0.9932483846450529, 0.9879673023858203, 0.5065065186332045], 
             306 -> RGBColor[
              0.24856946610155278`, 0.378592647460115, 0.9374670354176876], 
             237 -> RGBColor[
              0.2829811245404853, 0.41476148230459436`, 0.9394267284582981], 
             228 -> RGBColor[
              0.6539231239183084, 0.7295689814955796, 0.9661406037992947], 
             180 -> RGBColor[
              0.36585356986241385`, 0.4913057067049036, 0.9445328438533918], 
             383 -> RGBColor[
              0.9907378977094471, 0.9904378969247543, 0.8031605347142214], 53 -> 
             RGBColor[
              0.5752672796495748, 0.6660669189719667, 0.959706294008945], 304 -> 
             RGBColor[
              0.4995937623932409, 0.6046317486101717, 0.953748997529299], 48 -> 
             RGBColor[
              0.3726016187351638, 0.49715052747168154`, 0.9449628235604981], 
             5 -> RGBColor[
              0.6419453417997504, 0.7201991736379478, 0.9649554353111964], 
             101 -> RGBColor[
              0.3314906829151074, 0.4615423011600633, 0.9423432710830173], 
             333 -> RGBColor[
              0.9182463448036997, 0.7135810304769536, 0.2530772939053737], 
             267 -> RGBColor[
              0.32145059319362757`, 0.45284608007289956`, 0.9417035254440673],
              120 -> RGBColor[
              0.4994426429484544, 0.6045090630370407, 0.9537371008530366], 
             147 -> RGBColor[
              0.9929138633010389, 0.9872517950562704, 0.4700959347637071], 89 -> 
             RGBColor[
              0.33547804784385715`, 0.4649959562505578, 0.9425973424503888], 
             43 -> RGBColor[
              0.8901259614183403, 0.9152262960821624, 0.9893822028965494], 
             199 -> RGBColor[
              0.9520447915855089, 0.9637556646006953, 0.9660598385109584], 
             268 -> RGBColor[
              0.39761571455281713`, 0.518816480023921, 0.9465566996269025], 
             169 -> RGBColor[
              0.9908632518307952, 0.9808417443940927, 0.4190058880030979], 20 -> 
             RGBColor[
              0.17918486493438585`, 0.30566503239562065`, 0.9335156850265364],
              4 -> RGBColor[
              0.7990199091488599, 0.8429196928940976, 0.9806024953445259], 
             167 -> RGBColor[
              0.7512878359370312, 0.8056310345238245, 0.9758450083683557], 
             142 -> RGBColor[
              0.30303431102286577`, 0.43583865274303446`, 0.9405687277624388],
              16 -> RGBColor[0.178927, 0.305394, 0.933501], 281 -> 
             RGBColor[
              0.434552258584067, 0.550809057979107, 0.9489102635508704], 289 -> 
             RGBColor[
              0.4107448370843447, 0.5301882660718447, 0.9473932757049842], 
             398 -> RGBColor[
              0.9894724547593224, 0.9899146037444773, 0.8241321992591643], 
             178 -> RGBColor[
              0.9910771206407417, 0.9905781743244763, 0.7975387328618645], 58 -> 
             RGBColor[
              0.5765855615916687, 0.6671371596404833, 0.9598100739924524], 
             186 -> RGBColor[
              0.5983208403213541, 0.6847828380763901, 0.9615211547530027], 
             122 -> RGBColor[
              0.5798480634624531, 0.6697858056332203, 0.9600669100906588], 
             249 -> RGBColor[
              0.35551959111384673`, 0.4823549337137689, 0.9438743718655117], 
             113 -> RGBColor[
              0.8783238539302267, 0.9058156159308142, 0.9882565073484675], 52 -> 
             RGBColor[
              0.2506957167509515, 0.3808274717047106, 0.9375881222466649], 
             187 -> RGBColor[
              0.7481738430915763, 0.8031983596457329, 0.9755346346634385], 
             259 -> RGBColor[
              0.3813484370620194, 0.504726581878532, 0.9455201630897776], 42 -> 
             RGBColor[
              0.5255597659399571, 0.6257121200445253, 0.9557931364451016], 
             134 -> RGBColor[
              0.3667703548191858, 0.4920997797555077, 0.9445912605801562], 
             313 -> RGBColor[
              0.8951793548369963, 0.9192557348234885, 0.9898642000720385], 
             248 -> 
             RGBColor[
              0.3160180783302714, 0.4481407087443967, 0.9413573704007585], 
             174 -> RGBColor[
              0.30663865473296914`, 0.43962704651094353`, 0.9407739898045806],
              215 -> RGBColor[
              0.970452546614855, 0.9774841381616491, 0.934900310757697], 399 -> 
             RGBColor[
              0.4420985594983623, 0.5573452845429573, 0.9493911071721973], 83 -> 
             RGBColor[
              0.6255640387973884, 0.7069000938913399, 0.9636658391321603], 95 -> 
             RGBColor[
              0.2351403652684994, 0.3644778110304055, 0.9367022679918195], 
             166 -> RGBColor[
              0.9508035295736417, 0.9628299334246248, 0.9681609713240683], 
             384 -> RGBColor[
              0.9889558496254871, 0.98970097424549, 0.832693683258046], 233 -> 
             RGBColor[
              0.8719197876692171, 0.9007091873280328, 0.9876456817915149], 
             295 -> RGBColor[
              0.5969219295235231, 0.6836471392704976, 0.9614110273706183], 
             141 -> RGBColor[
              0.9333381073253877, 0.9496824882659887, 0.9935038159491016], 
             319 -> RGBColor[
              0.3471950826214136, 0.47514466285958573`, 0.9433439415454477], 
             205 -> RGBColor[
              0.8211892968462553, 0.8602580709882927, 0.9828069622891771], 
             224 -> RGBColor[
              0.4127316167853028, 0.5319091147903633, 0.947519871550689], 231 -> 
             RGBColor[
              0.2437448675978899, 0.37352168853555245`, 0.9371922816702578], 
             332 -> RGBColor[
              0.9856581644533734, 0.9883372966801777, 0.8873448606956268], 68 -> 
             RGBColor[
              0.4274659520456407, 0.5446712554236448, 0.9484587303644166], 10 -> 
             RGBColor[
              0.32164283796516335`, 0.4530125928315007, 0.9417157751109142], 
             250 -> RGBColor[
              0.9798763561661834, 0.9437803654715774, 0.3763238730472333], 
             282 -> RGBColor[
              0.5515356255534658, 0.6468004930779118, 0.9578380512665859], 
             374 -> RGBColor[
              0.3635345138524871, 0.4892970569482492, 0.9443850756551], 232 -> 
             RGBColor[
              0.4286655873122694, 0.5457103191961769, 0.9485351700628104], 
             253 -> RGBColor[
              0.26533458445435215`, 0.396213849818805, 0.9384217841061094], 
             55 -> RGBColor[
              0.284402636656804, 0.4162555816679191, 0.9395076814703838], 325 -> 
             RGBColor[
              0.26469064263808445`, 0.3955370261416383, 0.9383851125722996], 
             91 -> RGBColor[
              0.22082021159720608`, 0.3494264215716927, 0.9358867564250083], 
             105 -> RGBColor[
              0.41002970140221917`, 0.529568851487752, 0.9473477078916889], 
             36 -> RGBColor[
              0.28144069176500697`, 0.4131423897884876, 0.9393390030906007], 
             123 -> RGBColor[
              0.9624739507261154, 0.8850779656431179, 0.30871881408108387`], 
             94 -> RGBColor[
              0.45606552107880416`, 0.5692935613861873, 0.9503222949238248], 
             312 -> RGBColor[
              0.2674857099161389, 0.39847481906837456`, 0.9385442875188533], 
             96 -> RGBColor[
              0.9946542480762123, 0.9920574084470252, 0.7382564739470651], 2 -> 
             RGBColor[
              0.33547804784385715`, 0.4649959562505578, 0.9425973424503888], 
             262 -> RGBColor[
              0.5852600056085989, 0.6741794640726768, 0.9604929580010007], 
             272 -> RGBColor[
              0.2539205478369532, 0.3842169736421987, 0.9377717716063027], 97 -> 
             RGBColor[
              0.6779425856679135, 0.7483331675690417, 0.9685346392718633], 
             372 -> RGBColor[
              0.3920987898024356, 0.514037997093841, 0.9462051660602332], 356 -> 
             RGBColor[
              0.4915281039113657, 0.5980836837008116, 0.9531140393481252], 
             346 -> RGBColor[
              0.7797017733322862, 0.8278282183709202, 0.9786770441045731], 
             341 -> RGBColor[
              0.5639056601819735, 0.6568430444530438, 0.9588118657054719], 
             209 -> RGBColor[
              0.9036088631715954, 0.9259771959565896, 0.9906682141021034], 
             378 -> RGBColor[
              0.5091405447343141, 0.6123822565922983, 0.9545005552062042], 66 -> 
             RGBColor[
              0.6654875909869538, 0.7386032310628102, 0.9672932418006082], 
             139 -> RGBColor[
              0.17928515899630548`, 0.305770447813709, 0.9335213966249909], 
             56 -> RGBColor[
              0.5344053224842427, 0.6328933413349574, 0.9564894910586089], 
             335 -> RGBColor[
              0.7411822352811047, 0.797736462486005, 0.9748377765371804], 314 -> 
             RGBColor[
              0.8509847022881929, 0.8840161185129584, 0.9856488746589015], 
             144 -> RGBColor[
              0.7515712141082083, 0.8058524117049018, 0.9758732528561391], 
             298 -> RGBColor[
              0.7135252819119355, 0.7761306403133793, 0.9720811898942655], 
             204 -> RGBColor[
              0.36860551428439636`, 0.4936893026464765, 0.9447081953185116], 
             207 -> RGBColor[
              0.39361352253941756`, 0.5153499824579338, 0.9463016834908081], 
             334 -> RGBColor[
              0.8903287907484944, 0.9153880266843718, 0.9894015489391275], 
             149 -> RGBColor[
              0.5773352759321528, 0.6677458115163344, 0.9598690942516295], 
             219 -> RGBColor[
              0.6172810350497198, 0.7001755783039161, 0.9630137707355014], 
             400 -> RGBColor[
              0.5122102508517935, 0.6148743823071527, 0.9547422137164763], 9 -> 
             RGBColor[
              0.22504504737187456`, 0.35386699184092885`, 0.9361273545722912],
              11 -> RGBColor[
              0.7148979106014419, 0.7772029482779861, 0.972218000694091], 44 -> 
             RGBColor[
              0.8206189672876125, 0.8598033056794143, 0.9827525637467345], 
             153 -> RGBColor[
              0.9264012307528464, 0.9441512111835426, 0.9928421704689899], 32 -> 
             RGBColor[
              0.30762397807490793`, 0.4406626838164293, 0.9408301025112487], 
             162 -> RGBColor[
              0.35490507118914444`, 0.4818226674416613, 0.9438352151993084], 
             90 -> RGBColor[
              0.23994065437711598`, 0.36952321923946974`, 0.9369756373551639],
              331 -> RGBColor[
              0.45563881856189287`, 0.5689471450602294, 0.9502887033386307], 
             8 -> RGBColor[
              0.28045328974086736`, 0.4121045676562127, 0.9392827720060564], 
             364 -> RGBColor[
              0.6472390781517896, 0.7243473541421457, 0.9654744005832472], 
             342 -> RGBColor[
              0.2507571181600597, 0.38089200847875754`, 0.9375916189660783], 
             163 -> RGBColor[
              0.41460122049326453`, 0.5335284715531852, 0.9476390010457347], 
             49 -> RGBColor[
              0.935710744009702, 0.9515737586632067, 0.9937091204549027], 338 -> 
             RGBColor[
              0.278252635206845, 0.40979154021139885`, 0.9391574479859205], 
             76 -> RGBColor[
              0.4665109261584233, 0.5777736117899585, 0.9511445954744719], 
             369 -> RGBColor[
              0.7624857256883705, 0.8143789111046849, 0.97696110936854], 82 -> 
             RGBColor[
              0.7140284100516273, 0.776523687840022, 0.9721313370052301], 67 -> 
             RGBColor[
              0.9429512731274311, 0.8115278388512093, 0.2729554591338469], 
             211 -> RGBColor[
              0.4956373427468629, 0.6014197489065681, 
               0.9534375336818934]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9l2k4lWvYhs1zWMs8LNZoLbMSqfBetRslSppMScqwSaE2pQyZolBokCJT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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 14}], {
             RGBColor[
             0.9377491553500337, 0.9495019231087932, 0.8322954228037267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.9875453945290741, 0.9682281253982995, 0.5270083610738315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 49}], {
             RGBColor[
             0.9652586712974283, 0.9714369615536542, 0.8349088051432106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 62}], {
             RGBColor[
             0.8352690501499085, 0.8689530082120016, 0.8222113744593381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 87}], {
             RGBColor[
             0.9561892205536575, 0.9642055305599272, 0.8340542526844889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 119}], {
             RGBColor[
             0.6562957314503874, 0.720485587203881, 0.808789219136478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 127}], {
             RGBColor[
             0.9086211149981367, 0.926276014391783, 0.8295171643120542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 129}], {
             RGBColor[
             0.9947304233306834, 0.9916787864455634, 0.7071824818892918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 216}], {
             RGBColor[
             0.8189855936374197, 0.8562322482255922, 0.820588391691726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 231}], {
             RGBColor[
             0.6192757330915222, 0.682410926489827, 0.8066503857508882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 235}], {
             RGBColor[
             0.6321383642104216, 0.6959303673337065, 0.8073828935645521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 298}], {
             RGBColor[
             0.8541659402485451, 0.8837154023787406, 0.824094839862892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 313}], {
             RGBColor[
             0.9449929767110754, 0.9552779496337951, 0.8329863449517785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 317}], {
             RGBColor[
             0.813809769138232, 0.8520426213201954, 0.8201724944978237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 336}], {
             RGBColor[
             0.6264669270697121, 0.6899693273089372, 0.807059913609528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 361}], {
             RGBColor[
             0.6572747538673923, 0.7213335672143932, 0.808851601579174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 393}], {
             RGBColor[
             0.6286730180554383, 0.6922880688091827, 0.807185547227546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 396}], {
             RGBColor[
             0.8030932153683222, 0.8433424401945369, 0.8193288481290264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 97}], {
             RGBColor[
             0.5067103167558853, 0.6066645619097997, 0.955565990861126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 109}], {
             RGBColor[
             0.5333863966746046, 0.6275041182880197, 0.9582248132052837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 181}], {
             RGBColor[
             0.4289939176036341, 0.5441159831433369, 0.9490751867047524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 191}], {
             RGBColor[
             0.5589227649431827, 0.64745332326302, 0.9607700397433663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 193}], {
             RGBColor[
             0.45416954338787624`, 0.5645546903040016, 0.951057104187844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 211}], {
             RGBColor[
             0.41555769529536, 0.533207852578563, 0.9480174380661411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 305}], {
             RGBColor[
             0.5820205575997157, 0.6655668358436564, 0.9630538107766937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 334}], {
             RGBColor[
             0.6129034192961758, 0.6901919914674648, 0.9659994456947582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 340}], {
             RGBColor[
             0.5581438589146326, 0.6468448359536116, 0.9606924056697311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 360}], {
             RGBColor[
             0.5576510289532306, 0.6464598334421179, 0.9606432849849365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 365}], {
             RGBColor[
             0.27677828181016106`, 0.4057703408405482, 0.9391639816771906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 370}], {
             RGBColor[
             0.5807667456906866, 0.6645670802612144, 0.9629342210775194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 11}], {
             RGBColor[
             0.4496768890939489, 0.5442040693309015, 0.9530169307619565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 21}], {
             RGBColor[
             0.45963491226847686`, 0.551983352718622, 0.954009453448976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 34}], {
             RGBColor[
             0.5115442787876919, 0.5926860747878917, 0.9591432947644241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 74}], {
             RGBColor[
             0.4385756556463658, 0.5355317013891505, 0.9519104635588262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 86}], {
             RGBColor[
             0.5547526355312625, 0.6271392455956157, 0.9632645464031813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 91}], {
             RGBColor[
             0.20263803959183097`, 0.3303158059777548, 0.9348513086274152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 95}], {
             RGBColor[
             0.20979811642747764`, 0.3378415007071112, 0.9352590644108207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 160}], {
             RGBColor[
             0.26300311560690137`, 0.39073034068128404`, 0.9384000629361984]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[
             0.26968046938780016`, 0.3965139289127391, 0.9388255380145651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 233}], {
             RGBColor[
             0.5281878276278364, 0.605957188855925, 0.9607307713106685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 263}], {
             RGBColor[
             0.4425429532174765, 0.5386309844042805, 0.9523058867042109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 264}], {
             RGBColor[
             0.5393560926949464, 0.6148624602659589, 0.9617960104027974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 285}], {
             RGBColor[
             0.5053386366920052, 0.5877378642284585, 0.9585513950814953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 312}], {
             RGBColor[
             0.2259707887512974, 0.3548400047260958, 0.9361800741743377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 348}], {
             RGBColor[
             0.42541321388021613`, 0.5252491018431718, 0.9505985543735882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 13}], {
             RGBColor[
             0.750056247423196, 0.8046689082163969, 0.9757222551351457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 66}], {
             RGBColor[
             0.7322537500679068, 0.790761461978454, 0.9739478685725671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 123}], {
             RGBColor[
             0.8807469299374877, 0.8639988292686078, 0.6446606547128049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 131}], {
             RGBColor[
             0.5434279344345461, 0.6313919573934674, 0.9601528497421128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 140}], {
             RGBColor[
             0.5417126714440124, 0.6295891072364617, 0.9600551680523062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 183}], {
             RGBColor[
             0.6003719823714488, 0.6826473057183496, 0.9637104874148559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 186}], {
             RGBColor[
             0.6986703747351071, 0.7638512654852438, 0.9710618250487644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 188}], {
             RGBColor[
             0.5817848115912021, 0.6665480326068669, 0.9625261293287283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 203}], {
             RGBColor[
             0.66066037942402, 0.7329930389609283, 0.968069538982675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 232}], {
             RGBColor[
             0.6138427482305646, 0.6943150060451373, 0.9645688327036681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 238}], {
             RGBColor[
             0.49048095373728406`, 0.5757413236481759, 0.9571375975194424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 275}], {
             RGBColor[
             0.5310570622820397, 0.6183893864025864, 0.9594483468740929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 280}], {
             RGBColor[
             0.5466598870328532, 0.6347889444919184, 0.960336904661341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 297}], {
             RGBColor[
             0.5876733452762689, 0.6716483845185632, 0.9629013414881149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 309}], {
             RGBColor[
             0.7108243172998976, 0.7737183835882139, 0.9720186279288232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 322}], {
             RGBColor[
             0.8812722835749832, 0.9076185115354948, 0.963614957221282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 325}], {
             RGBColor[
             0.5318552758934721, 0.619228359517868, 0.9594938039584128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 339}], {
             RGBColor[
             0.8924917030400288, 0.9156916262002712, 0.9314436033537402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 8}], {
             RGBColor[
             0.46119931577030887`, 0.5661518706470803, 0.9521191036586264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 43}], {
             RGBColor[
             0.7660356516090454, 0.8177127348600551, 0.977168819103873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 56}], {
             RGBColor[
             0.5881753321419965, 0.6765462574864527, 0.9607224631849027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.4762239993756623, 0.5817813507986279, 0.9529806839693999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 90}], {
             RGBColor[
             0.4409429980884332, 0.5448611964387088, 0.9509655363331802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 100}], {
             RGBColor[
             0.5273384792925266, 0.6260541442141556, 0.9562376534309427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 121}], {
             RGBColor[
             0.6087506348535217, 0.693250215134493, 0.9623422263841712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 122}], {
             RGBColor[
             0.6108967026311017, 0.6949924896355841, 0.9625111727009277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 175}], {
             RGBColor[
             0.8014220112331658, 0.8452790271091971, 0.9580139745360036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 178}], {
             RGBColor[
             0.816511231220246, 0.855388673981212, 0.8812470840865305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 213}], {
             RGBColor[
             0.8053745398570076, 0.8133144988857015, 0.6491321386691151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 227}], {
             RGBColor[
             0.4313423403821771, 0.5347702964725773, 0.9504187930797092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 274}], {
             RGBColor[
             0.5734873304633775, 0.6646218760368147, 0.9595661698888389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 296}], {
             RGBColor[
             0.5051034219385223, 0.6067952551005944, 0.9548208552380348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 308}], {
             RGBColor[
             0.6452895605994643, 0.7228180394973378, 0.9652844233402795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 319}], {
             RGBColor[
             0.49457021221058195`, 0.5976719182487668, 0.954149688428322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 352}], {
             RGBColor[
             0.70609055628429, 0.7703162394310058, 0.9713444983725338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 373}], {
             RGBColor[
             0.6135482666665608, 0.6971451487711683, 0.962719913534798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 56}], {
             RGBColor[
             0.5415609867947164, 0.6387026319812037, 0.9570528111651915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 79}], {
             RGBColor[
             0.5331150273818472, 0.6318458216437008, 0.9563879143016416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 137}], {
             RGBColor[
             0.4209003306785991, 0.5349460891874028, 0.9488091020627316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 169}], {
             RGBColor[
             0.7697899514679927, 0.8126768335107712, 0.688311009637436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 175}], {
             RGBColor[
             0.7548076658858858, 0.8074354016039482, 0.9543443225162924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 178}], {
             RGBColor[
             0.769896885872966, 0.8175450484759631, 0.8775774320668193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 252}], {
             RGBColor[
             0.4186382771493071, 0.5325685275056395, 0.9486802814606468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 277}], {
             RGBColor[
             0.6686345349159069, 0.7396271662239113, 0.9685876624976355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 278}], {
             RGBColor[
             0.6579164885836251, 0.7312541469689635, 0.9675193878050712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 300}], {
             RGBColor[
             0.7457413147677099, 0.8006737317848001, 0.9696912900762822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 314}], {
             RGBColor[
             0.6998506766966917, 0.7642640205702042, 0.9716325029653378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 319}], {
             RGBColor[
             0.4479558668633019, 0.5598282927435179, 0.9504800364086108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 352}], {
             RGBColor[
             0.6594762109370099, 0.7324726139257569, 0.9676748463528226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 379}], {
             RGBColor[
             0.4769014833539252, 0.5848995308987093, 0.9523244254957897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 65}], {
             RGBColor[
             0.6867544077435792, 0.7533808568606026, 0.9708904391010298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 67}], {
             RGBColor[
             0.9143131530209598, 0.861602542680818, 0.630956564248154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 68}], {
             RGBColor[
             0.6565704924800646, 0.7281742509670357, 0.968708199863439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 96}], {
             RGBColor[
             0.9401646404953503, 0.9518673274787259, 0.8636070716547632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 173}], {
             RGBColor[
             0.7442921990252046, 0.8000926278709846, 0.9754200247985935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[
             0.8502965201886763, 0.8835083273187234, 0.9855723692853757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 201}], {
             RGBColor[
             0.838766645029172, 0.8745011012138219, 0.9844231790822857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 223}], {
             RGBColor[
             0.6431010099661033, 0.7165076622093182, 0.9678499363482451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 250}], {
             RGBColor[
             0.9327756945403359, 0.927728805991002, 0.6826407712048473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 387}], {
             RGBColor[
             0.9400811393461219, 0.9511471737955117, 0.8151532884628268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 43}], {
             RGBColor[
             0.5852896255796038, 0.6636654318691875, 0.9643324874513028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 56}], {
             RGBColor[
             0.407429306112555, 0.522498954495585, 0.9478861315323326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 59}], {
             RGBColor[
             0.2954779733462207, 0.4277340478077603, 0.94014435231683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 100}], {
             RGBColor[
             0.3465924532630851, 0.47200684122328795`, 0.9434013217783727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 121}], {
             RGBColor[
             0.4280046088240802, 0.5392029121436254, 0.9495058947316012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 175}], {
             RGBColor[
             0.6206759852037244, 0.6912317241183294, 0.9451776428834335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 213}], {
             RGBColor[
             0.6246285138275661, 0.659267195894834, 0.636295807016545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 227}], {
             RGBColor[
             0.25059631435273566`, 0.3807229934817097, 0.9375824614271391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 237}], {
             RGBColor[
             0.28171720714067633`, 0.4134330249804035, 0.9393547502321773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 296}], {
             RGBColor[
             0.3243573959090808, 0.4527479521097268, 0.9419845235854647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 308}], {
             RGBColor[
             0.4645435345700228, 0.5687707365064703, 0.9524480916877095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 352}], {
             RGBColor[
             0.5253445302548485, 0.6162689364401382, 0.9585081667199638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 373}], {
             RGBColor[
             0.4328022406371193, 0.5430978457803007, 0.949883581882228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 39}], {
             RGBColor[
             0.6198943491239581, 0.2073736639469763, 0.42152111819076377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.6089744237295536, 0.6705486313502073, 0.7025639853080706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 150}], {
             RGBColor[
             0.6024742322091607, 0.6691997868480395, 0.927514903435542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 192}], {
             RGBColor[
             0.31792890844253524`, 0.44205704878413066`, 0.9417624794357857]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 283}], {
             RGBColor[
             0.23670602569168336`, 0.36612341940377613`, 0.9367914300367328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 294}], {
             RGBColor[
             0.4937653865301225, 0.5841229514728068, 0.9565442319704156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 320}], {
             RGBColor[
             0.23009270632018697`, 0.3591724014356672, 0.9364148112820554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 347}], {
             RGBColor[
             0.5647084350991847, 0.6402262755581736, 0.9634341702236906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 381}], {
             RGBColor[
             0.401048827422971, 0.5106916601844602, 0.9479870980637257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 384}], {
             RGBColor[
             0.6070004484986808, 0.6717839830432094, 0.8844105189151686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.4870557143082973, 0.5907226409420668, 0.9538557023137764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 37}], {
             RGBColor[
             0.6368461730626658, 0.6503059508902076, 0.6109959438575627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 62}], {
             RGBColor[
             0.49868716983991285`, 0.599809222405701, 0.9550150170990359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 87}], {
             RGBColor[
             0.6196073402436619, 0.6950617447536267, 0.9668578953241866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 155}], {
             RGBColor[
             0.305044588997752, 0.4367591815653044, 0.9407268697531489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 170}], {
             RGBColor[
             0.4317918459168433, 0.5460118090080187, 0.9493992454018274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 216}], {
             RGBColor[
             0.4824037133274241, 0.5870884624192917, 0.9533920343314238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 256}], {
             RGBColor[
             0.4275672302914033, 0.5425820757265214, 0.9490666681845158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 261}], {
             RGBColor[
             0.32069287355739673`, 0.45218978140809274`, 0.9416552442188719]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 298}], {
             RGBColor[
             0.5175840599385495, 0.61457161657244, 0.9568984825025899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 311}], {
             RGBColor[
             0.4699556081712157, 0.5769948704640152, 0.952403636564959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 313}], {
             RGBColor[
             0.6084110964010798, 0.6861341638274946, 0.9657899875914764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 361}], {
             RGBColor[
             0.32069287355739673`, 0.45218978140809274`, 0.9416552442188719]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 396}], {
             RGBColor[
             0.46651133505832665`, 0.5741986543882364, 0.9521324907687243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 34}], {
             RGBColor[
             0.776765300295185, 0.8256849537349763, 0.9783443646965586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 35}], {
             RGBColor[
             0.8529842915831941, 0.8838892280787065, 0.8849317974294854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 85}], {
             RGBColor[
             0.6841322018526023, 0.7531685427753458, 0.9691515623679012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 86}], {
             RGBColor[
             0.8199736570387556, 0.8601381245427002, 0.9824656163353157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 91}], {
             RGBColor[
             0.467859061099324, 0.5633146849248394, 0.9540523785595496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 93}], {
             RGBColor[
             0.5454017852694206, 0.6386076350865523, 0.9586956774191733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 95}], {
             RGBColor[
             0.47501913793497064`, 0.5708403796541958, 0.9544601343429553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 125}], {
             RGBColor[
             0.8273388176948133, 0.8659056730717204, 0.9795196990255873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 162}], {
             RGBColor[
             0.5349014908952932, 0.6295128078598237, 0.9580266079466997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 211}], {
             RGBColor[
             0.6052676266741523, 0.689311348592277, 0.9628277671879922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 214}], {
             RGBColor[
             0.518151444378191, 0.6150047594485266, 0.9569593097941145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 248}], {
             RGBColor[
             0.5154579944658566, 0.6126718285111914, 0.9567876855474248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 263}], {
             RGBColor[
             0.7077639747249695, 0.7716298633513651, 0.9715069566363455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 312}], {
             RGBColor[
             0.49119181025879044`, 0.5878388836731803, 0.9553811441064721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.5859067670072104, 0.6483602066271477, 0.8505265353241472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 17}], {
             RGBColor[
             0.7585882284028163, 0.8080038087124436, 0.861622620194569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 22}], {
             RGBColor[
             0.7446505479007897, 0.796688571795547, 0.8605253949300435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 47}], {
             RGBColor[
             0.967066803263236, 0.8980488322783565, 0.5195681449821384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 106}], {
             RGBColor[
             0.9928951670508268, 0.9892783420568905, 0.6182763433460722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 107}], {
             RGBColor[
             0.9143556700557307, 0.9316272210244243, 0.8758774904375424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 118}], {
             RGBColor[
             0.7865015127721285, 0.830665070442582, 0.863820056189851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 158}], {
             RGBColor[
             0.6472074263586458, 0.7127910862917934, 0.8540175171880128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 209}], {
             RGBColor[
             0.9482476985930082, 0.9586518046054424, 0.8791101423751989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 241}], {
             RGBColor[
             0.7895506689508536, 0.8331405127913913, 0.8640600969336674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 270}], {
             RGBColor[
             0.6207280000579868, 0.6849595303572051, 0.852509553032991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 310}], {
             RGBColor[
             0.8905042256423648, 0.9128662560325314, 0.8735341780049454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 323}], {
             RGBColor[
             0.9337995027702952, 0.9471312054422392, 0.877732060559572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 324}], {
             RGBColor[
             0.6479703786260049, 0.7135929974987556, 0.8540609661909522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 346}], {
             RGBColor[
             0.8862941536733535, 0.9095773158126077, 0.8731145573764338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 390}], {
             RGBColor[
             0.9843666249395513, 0.9864167570051618, 0.8466607299453475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 66}], {
             RGBColor[
             0.6832900883422429, 0.7525106773007533, 0.9690676283631868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 123}], {
             RGBColor[
             0.8317832682118238, 0.8257480445909071, 0.6397804145034247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 131}], {
             RGBColor[
             0.4944642727088821, 0.5931411727157667, 0.9552726095327326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[
             0.49274900971834845`, 0.591338322558761, 0.9551749278429259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 188}], {
             RGBColor[
             0.5328211498655382, 0.6282972479291662, 0.957645889119348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 203}], {
             RGBColor[
             0.6116967176983561, 0.6947422542832276, 0.9631892987732948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 232}], {
             RGBColor[
             0.5648790865049007, 0.6560642213674366, 0.959688592494288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 275}], {
             RGBColor[
             0.48209340055637584`, 0.5801386017248857, 0.9545681066647127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 280}], {
             RGBColor[
             0.4976962253071892, 0.5965381598142178, 0.9554566644519609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 297}], {
             RGBColor[
             0.538709683550605, 0.6333975998408625, 0.9580211012787346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 309}], {
             RGBColor[
             0.6618606555742337, 0.7354675989105133, 0.967138387719443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 322}], {
             RGBColor[
             0.8323086218493193, 0.8693677268577942, 0.9587347170119018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 325}], {
             RGBColor[
             0.48289161416780824`, 0.5809775748401673, 0.9546135637490325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 339}], {
             RGBColor[
             0.8435280413143649, 0.8774408415225705, 0.9265633631443599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 29}], {
             RGBColor[
             0.9304879512939532, 0.926429884062991, 0.6831952940460396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 62}], {
             RGBColor[
             0.7782116069147875, 0.827154766876693, 0.9783983074315462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 119}], {
             RGBColor[
             0.5992382882152666, 0.6786873458685725, 0.9649761521086861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 126}], {
             RGBColor[
             0.6019589404220541, 0.6810438380661359, 0.9651495096615244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 127}], {
             RGBColor[
             0.851563671763016, 0.8844777730564746, 0.9857040972842623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 129}], {
             RGBColor[
             0.9376729800955625, 0.949880545110255, 0.8633694148614999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 196}], {
             RGBColor[
             0.5784285469957642, 0.6576506931976538, 0.9637604688862567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 235}], {
             RGBColor[
             0.5750809209753007, 0.654132125998398, 0.9635698265367602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 317}], {
             RGBColor[
             0.7567523259031113, 0.8102443799848869, 0.9763594274700318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 326}], {
             RGBColor[
             0.5822004206225732, 0.6616151715300307, 0.9639752715093164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 327}], {
             RGBColor[
             0.6358945034571585, 0.7104371171161512, 0.9673118537300811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 336}], {
             RGBColor[
             0.5694094838345913, 0.6481710859736287, 0.9632468465817361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 396}], {
             RGBColor[
             0.7460357721332014, 0.8015441988592285, 0.9755157811012345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 33}], {
             RGBColor[
             0.8017930441245518, 0.845748389657752, 0.9668125674359993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 37}], {
             RGBColor[
             0.8022590494057997, 0.7880159990007737, 0.623135871060425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.6641000461830469, 0.7375192705162672, 0.9671549443018981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 92}], {
             RGBColor[
             0.5165465598161544, 0.616266129067979, 0.9557348329118063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 256}], {
             RGBColor[
             0.5929801066345373, 0.6802921238370876, 0.9612065953873781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 311}], {
             RGBColor[
             0.6353684845143497, 0.7147049185745813, 0.9645435637678212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 313}], {
             RGBColor[
             0.7738239727442138, 0.8238442119380607, 0.9779299147943386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 361}], {
             RGBColor[
             0.4861057499005307, 0.5898998295186588, 0.9537951714217341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 386}], {
             RGBColor[
             0.8237454123414338, 0.8600970379561219, 0.832787353464118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 69}], {
             RGBColor[
             0.30474526360884113`, 0.42637410967450606`, 0.9410785525576505]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 106}], {
             RGBColor[
             0.5859154000436164, 0.6463121354297428, 0.701250808021925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 107}], {
             RGBColor[
             0.5073759030485203, 0.5886610143972766, 0.9588519551133952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 190}], {
             RGBColor[
             0.2781850706779843, 0.40336900551191013`, 0.9393861605503527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 212}], {
             RGBColor[
             0.5108025607602698, 0.5913933382424799, 0.9591787927849553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 241}], {
             RGBColor[
             0.3825709019436432, 0.49017430616424373`, 0.9470345616095202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 268}], {
             RGBColor[
             0.28827135727640857`, 0.41210524001196047`, 0.9400288498134513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 270}], {
             RGBColor[
             0.2137482330507764, 0.34199332373005753`, 0.9354840177088438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 274}], {
             RGBColor[
             0.3419781595635023, 0.4572192892178407, 0.9438389522332407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 295}], {
             RGBColor[
             0.38792446476176157`, 0.4945205696352488, 0.9474560136853092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 310}], {
             RGBColor[
             0.4835244586351543, 0.5699000494053836, 0.9565086426807982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 324}], {
             RGBColor[
             0.24099061161879445`, 0.3706267908716079, 0.937035430866805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 351}], {
             RGBColor[
             0.2641279462989493, 0.3911934309064046, 0.9384904530151477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 373}], {
             RGBColor[
             0.3820390957666856, 0.48974256195219434`, 0.9469926958791999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 380}], {
             RGBColor[
             0.22589444969046477`, 0.35475976753298466`, 0.9361757267777568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 390}], {
             RGBColor[
             0.5773868579323409, 0.6434505503780141, 0.9296351946212003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 22}], {
             RGBColor[
             0.5103522422891851, 0.6133659672536953, 0.9545959444763181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 48}], {
             RGBColor[
             0.4484457707631878, 0.5609158658211367, 0.9503279966506708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 61}], {
             RGBColor[
             0.37171006948305263`, 0.4861656667007677, 0.9457418417133376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 118}], {
             RGBColor[
             0.5522032071605241, 0.6473424659007303, 0.9578906057361256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 158}], {
             RGBColor[
             0.4129091207470412, 0.5294684817499418, 0.9480880667342874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 164}], {
             RGBColor[
             0.609446676104815, 0.693014974752315, 0.9629442031066602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 173}], {
             RGBColor[
             0.5635996439635662, 0.6565946067010673, 0.9587877749877847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 209}], {
             RGBColor[
             0.7139493929814036, 0.7753292000635907, 0.9731806919214735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 241}], {
             RGBColor[
             0.555252363339249, 0.6498179082495397, 0.958130646479942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 287}], {
             RGBColor[
             0.4742897065882273, 0.5833005840788026, 0.9519747493885473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 323}], {
             RGBColor[
             0.6995011971586906, 0.7638086009003875, 0.9718026101058466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 346}], {
             RGBColor[
             0.6519958480617489, 0.726254711270756, 0.9671851069227084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 354}], {
             RGBColor[
             0.6421489432267542, 0.7185622343744096, 0.9662036594733135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 371}], {
             RGBColor[
             0.3540476688650708, 0.4676013637903895, 0.9447359941273238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 388}], {
             RGBColor[
             0.7153708830305009, 0.7764626576434215, 0.9733162749113355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 389}], {
             RGBColor[
             0.6832786165678151, 0.7508731554874426, 0.9702552858870201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 45}], {
             RGBColor[
             0.9674255933229658, 0.9719676741257435, 0.7451209609019431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 74}], {
             RGBColor[
             0.8171491228535772, 0.8579131291300754, 0.9768702347292562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 86}], {
             RGBColor[
             0.9333261027384739, 0.9495206733365407, 0.9882243175736111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 91}], {
             RGBColor[
             0.5812115067990424, 0.6526972337186797, 0.959811079797845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 112}], {
             RGBColor[
             0.7458168273403769, 0.8007734482677761, 0.970727496602247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 141}], {
             RGBColor[
             0.9374704546631332, 0.9528252670658277, 0.9886196095598917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 148}], {
             RGBColor[
             0.5926738347993843, 0.6647448672006095, 0.9604638424204698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 179}], {
             RGBColor[
             0.6031467223194815, 0.6757525360036525, 0.9610602578714906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 232}], {
             RGBColor[
             0.685134194656574, 0.7508391825309217, 0.9661352866167461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 257}], {
             RGBColor[
             0.7424486647255875, 0.7980390221230934, 0.9704623425032246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 279}], {
             RGBColor[
             0.7662940335644552, 0.8173977667681107, 0.9723395372866844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 285}], {
             RGBColor[
             0.8839121038992166, 0.9101192919693833, 0.9835111662519251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 288}], {
             RGBColor[
             0.7328361627976039, 0.7902351600196793, 0.9697056111396989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 399}], {
             RGBColor[
             0.6918506807496205, 0.7566566652043121, 0.9665632551714396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 185}], {
             RGBColor[
             0.7861275193248647, 0.7103880246238513, 0.6071285398501218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 198}], {
             RGBColor[
             0.673045976037498, 0.7445078989101495, 0.9680465909853222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 205}], {
             RGBColor[
             0.7411235906696689, 0.7977003908355373, 0.9748293461722184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 219}], {
             RGBColor[
             0.6391694597714013, 0.717659144493349, 0.9649327503953806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 262}], {
             RGBColor[
             0.6231589450508408, 0.7046610873777294, 0.9636723440281303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 284}], {
             RGBColor[
             0.5791499219755424, 0.6689325798613059, 0.9602077925212794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 293}], {
             RGBColor[
             0.5273357035162501, 0.6252463465703579, 0.956576706773034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 331}], {
             RGBColor[
             0.5583483515274877, 0.6520449278715057, 0.9585702166969452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 338}], {
             RGBColor[
             0.4696552598499638, 0.5724671254470903, 0.9530045890205902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.5495108248923639, 0.5127758138373915, 0.5939363421629322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 36}], {
             RGBColor[
             0.2303127783496964, 0.35940371109205416`, 0.9364273440585685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 80}], {
             RGBColor[
             0.2716369100646565, 0.3977211592838297, 0.9389680445968517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 151}], {
             RGBColor[
             0.38739144360685207`, 0.49411868206196563`, 0.9474112447846295]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 168}], {
             RGBColor[
             0.5705689986532576, 0.6384051606657792, 0.9414016435474524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 265}], {
             RGBColor[
             0.43881462521559816`, 0.5350071809052231, 0.952046876052566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 291}], {
             RGBColor[
             0.3967859363779319, 0.5017455545106045, 0.9481508136687298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 304}], {
             RGBColor[
             0.33938931366381336`, 0.4551483905028961, 0.9436323412779177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 378}], {
             RGBColor[
             0.34416270483434996`, 0.4590236444939595, 0.9440081201163704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 383}], {
             RGBColor[
             0.5849613813219166, 0.6480514646601874, 0.8683381098703788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 24}], {
             RGBColor[
             0.5958526519557144, 0.6813627595468784, 0.9622951765152479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 25}], {
             RGBColor[
             0.5341062717514663, 0.6279781732250591, 0.9583339435419125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 27}], {
             RGBColor[
             0.5677076276444676, 0.657081978846324, 0.9604749922269021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 32}], {
             RGBColor[
             0.5212189675127028, 0.6167120994349281, 0.9575165742896894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 78}], {
             RGBColor[
             0.49062084651978, 0.5845515342384443, 0.9557740565650059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 95}], {
             RGBColor[
             0.4849771611094986, 0.5786196630419163, 0.9554526570299748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 104}], {
             RGBColor[
             0.8622295640723351, 0.8913737707411623, 0.8977364435130126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 160}], {
             RGBColor[
             0.5381821602889223, 0.6315085030160891, 0.9585936555553525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 172}], {
             RGBColor[
             0.8547464609472852, 0.8866988545424408, 0.9509745665104519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 208}], {
             RGBColor[
             0.7522122722731233, 0.8063532112155559, 0.9759371475429888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 217}], {
             RGBColor[
             0.7619975456344457, 0.813997541136253, 0.9769124521430668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 230}], {
             RGBColor[
             0.8210217889455851, 0.8608129024861135, 0.9826083056392684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 233}], {
             RGBColor[
             0.8033668723098575, 0.8467353511907298, 0.9809243639298225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 240}], {
             RGBColor[
             0.7352588627394365, 0.7931090788371552, 0.9742473901192905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 242}], {
             RGBColor[
             0.8642871780852224, 0.8909119824211655, 0.7682195956954345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 244}], {
             RGBColor[
             0.8603330379658907, 0.8905895084576498, 0.9291667891490283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 264}], {
             RGBColor[
             0.8145351373769674, 0.855640622600764, 0.9819896030219514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 285}], {
             RGBColor[
             0.7805176813740262, 0.8285160265632634, 0.9787449877006493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 357}], {
             RGBColor[
             0.5754274288240464, 0.6637684826195861, 0.9609668911317127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 47}], {
             RGBColor[
             0.7188308171496047, 0.7034109908196082, 0.6125414692638875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.4345080902611611, 0.5496006289042401, 0.9492307713861454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 96}], {
             RGBColor[
             0.7455344049316853, 0.7970540693919119, 0.8458775965794288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 118}], {
             RGBColor[
             0.5382655266584973, 0.6360272289838336, 0.9567933804716001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 158}], {
             RGBColor[
             0.3989714402450145, 0.518153244833045, 0.9469908414697619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 173}], {
             RGBColor[
             0.5496619634615396, 0.6452793697841706, 0.9576905497232591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 209}], {
             RGBColor[
             0.7000117124793769, 0.7640139631466941, 0.972083466656948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 241}], {
             RGBColor[
             0.5413146828372224, 0.6385026713326432, 0.9570334212154165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 310}], {
             RGBColor[
             0.6422682395287336, 0.7182284145737831, 0.9665075022866945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 323}], {
             RGBColor[
             0.685563516656664, 0.7524933639834908, 0.970705384841321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 346}], {
             RGBColor[
             0.6380581675597223, 0.7149394743538595, 0.9660878816581828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 354}], {
             RGBColor[
             0.6282112627247275, 0.7072469974575128, 0.965106434208788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 388}], {
             RGBColor[
             0.7014332025284742, 0.7651474207265249, 0.97221904964681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 75}], {
             RGBColor[
             0.8739435435564802, 0.8998121223273196, 0.8665872203009164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 120}], {
             RGBColor[
             0.7464822625181834, 0.7980491045237127, 0.8553799048477346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 132}], {
             RGBColor[
             0.6291970396338551, 0.6936584987432933, 0.8477090803386484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 160}], {
             RGBColor[
             0.6675361228576296, 0.7309223184945679, 0.8500034869425037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 202}], {
             RGBColor[
             0.8344290430168251, 0.8689430941844141, 0.8626487841711258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 220}], {
             RGBColor[
             0.9676582008208658, 0.973850087256563, 0.8702167921019661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 229}], {
             RGBColor[
             0.8053139785645251, 0.8458113419487377, 0.8600113530425795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 260}], {
             RGBColor[
             0.9161271299601061, 0.9329177967913509, 0.870751472928476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 307}], {
             RGBColor[
             0.6566323956187713, 0.7214780579975347, 0.8493087110846311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 321}], {
             RGBColor[
             0.963467968047591, 0.8826525445700133, 0.5111521488024463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 341}], {
             RGBColor[
             0.778713771134943, 0.8242160952317142, 0.8579172872739522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 348}], {
             RGBColor[
             0.8299462211309443, 0.8654410796564557, 0.8622019783798935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 366}], {
             RGBColor[
             0.6888636515688971, 0.7493951519115063, 0.8513624582127925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.4287463226496842, 0.5456832233397755, 0.94856712267402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 32}], {
             RGBColor[
             0.3822576625179195, 0.5053133439283796, 0.9456087047368071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 73}], {
             RGBColor[
             0.7082935314238175, 0.7697128577288088, 0.9517480631560228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.5747933953336033, 0.664911108217407, 0.9601961866250981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 78}], {
             RGBColor[
             0.3516595415249966, 0.47315277873189576`, 0.9438661870121238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 104}], {
             RGBColor[
             0.7232682590775517, 0.7799750152346138, 0.8858285739601305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 112}], {
             RGBColor[
             0.5034610998204031, 0.6077714273551076, 0.9540534484980889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 141}], {
             RGBColor[
             0.6951147271431594, 0.7598232461531593, 0.9719455614557337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 172}], {
             RGBColor[
             0.7157851559525017, 0.7753000990358923, 0.9390666969575696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 208}], {
             RGBColor[
             0.6132509672783398, 0.6949544557090074, 0.9640292779901065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 240}], {
             RGBColor[
             0.5962975577446532, 0.6817103233306067, 0.9623395205664084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 242}], {
             RGBColor[
             0.725325873090439, 0.779513226914617, 0.7563117261425524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 243}], {
             RGBColor[
             0.5075134079948429, 0.6110612736855208, 0.9543724610416748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 285}], {
             RGBColor[
             0.6415563763792428, 0.7171172710567149, 0.9668371181477672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 337}], {
             RGBColor[
             0.4012465115093754, 0.5218642691107366, 0.9468148590252876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 357}], {
             RGBColor[
             0.4364661238292631, 0.5523697271130376, 0.9490590215788306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 399}], {
             RGBColor[
             0.4494949532296466, 0.5636546442916436, 0.9498892070672815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 32}], {
             RGBColor[
             0.32051128231367143`, 0.45192875760656026`, 0.9416474717634717]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 78}], {
             RGBColor[
             0.28991316132074857`, 0.41976819241007646`, 0.9399049540387883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 83}], {
             RGBColor[
             0.4794813126749117, 0.5850474626440156, 0.9530653400739275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 194}], {
             RGBColor[
             0.5741582970076494, 0.6592671197618556, 0.9623259551119925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 201}], {
             RGBColor[
             0.5626284218481452, 0.6502598936569541, 0.9611767649089025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 217}], {
             RGBColor[
             0.5612898604354142, 0.6492141993078852, 0.9610433496168491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 223}], {
             RGBColor[
             0.36696278678507654`, 0.49226645465245045`, 0.9446035221748619]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 230}], {
             RGBColor[
             0.6203141037465536, 0.6960295606577456, 0.9667392031130507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 242}], {
             RGBColor[
             0.6635794928861909, 0.7261286405927978, 0.7523504931692169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 244}], {
             RGBColor[
             0.6596253527668592, 0.7258061666292819, 0.9132976866228106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 245}], {
             RGBColor[
             0.4610113597112022, 0.5700527227661774, 0.9516113177189574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 328}], {
             RGBColor[
             0.5404372672388515, 0.6329239950171522, 0.9589649580055785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 357}], {
             RGBColor[
             0.37471974362501503`, 0.49898514079121825`, 0.9450977886054951]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 364}], {
             RGBColor[
             0.49031883235211227`, 0.5937710927694184, 0.953969620799471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 385}], {
             RGBColor[
             0.4129821928529728, 0.5310604814213571, 0.9478302857672423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 105}], {
             RGBColor[
             0.3415220277200197, 0.4669273130321485, 0.9431034217571879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 128}], {
             RGBColor[
             0.6339138743199317, 0.6978002375067947, 0.8078536649762038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 159}], {
             RGBColor[
             0.5142183416704311, 0.6065733533706053, 0.9575581158253648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 171}], {
             RGBColor[
             0.44102491006911937`, 0.5488836142743851, 0.9506118924829925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 215}], {
             RGBColor[
             0.6217334503263376, 0.6908849563690971, 0.936879723190192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 218}], {
             RGBColor[
             0.3597155076246006, 0.4826855908946083, 0.9442626942088452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 342}], {
             RGBColor[
             0.26188573609893995`, 0.39258889152765125`, 0.9382253772943827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 349}], {
             RGBColor[
             0.25837961081785504`, 0.38890373155604874`, 0.9380257086464724]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 353}], {
             RGBColor[
             0.4939561323196311, 0.5907443614272655, 0.955538568158389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 32}], {
             RGBColor[
             0.3541126382066727, 0.48103256322782517`, 0.9437885204484614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 73}], {
             RGBColor[
             0.6801485071125706, 0.7454320770282544, 0.949927878867677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 74}], {
             RGBColor[
             0.5466483710223565, 0.6406303275168526, 0.9583760023367524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 78}], {
             RGBColor[
             0.32351451721374985`, 0.44887199803134137`, 0.942046002723778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 104}], {
             RGBColor[
             0.695123234766305, 0.7556942345340594, 0.8840083896717847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 112}], {
             RGBColor[
             0.47531607550915633`, 0.5834906466545533, 0.9522332642097432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 141}], {
             RGBColor[
             0.6669697028319126, 0.7355424654526048, 0.9701253771673879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 172}], {
             RGBColor[
             0.687640131641255, 0.751019318335338, 0.9372465126692239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 208}], {
             RGBColor[
             0.5851059429670931, 0.670673675008453, 0.9622090937017607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 225}], {
             RGBColor[
             0.6364770721700441, 0.7112284694632406, 0.9672169628337661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 240}], {
             RGBColor[
             0.5681525334334064, 0.6574295426300523, 0.9605193362780626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 243}], {
             RGBColor[
             0.47936838368359613`, 0.5867804929849664, 0.952552276753329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 285}], {
             RGBColor[
             0.613411352067996, 0.6928364903561606, 0.9650169338594214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 337}], {
             RGBColor[
             0.37310148719812863`, 0.4975834884101822, 0.9449946747369419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 357}], {
             RGBColor[
             0.4083210995180163, 0.5280889464124832, 0.9472388372904847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 399}], {
             RGBColor[
             0.42134992891839984`, 0.5393738635910892, 0.9480690227789357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 36}], {
             RGBColor[
             0.6006387383076744, 0.5665144925338249, 0.5968480011949644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 151}], {
             RGBColor[
             0.7577174035648302, 0.7012294635037364, 0.6078319019210252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 168}], {
             RGBColor[
             0.9408949586112356, 0.84551594210755, 0.6018223006838481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 265}], {
             RGBColor[
             0.8091405851735762, 0.742117962346994, 0.6124675331889617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 267}], {
             RGBColor[
             0.6206436890219847, 0.5863663376760309, 0.5980302623716978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 282}], {
             RGBColor[
             0.7356862052019039, 0.6833435441785369, 0.606097525282957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 291}], {
             RGBColor[
             0.7671118963359099, 0.7088563359523754, 0.6085714708051255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 304}], {
             RGBColor[
             0.7097152736217914, 0.6622591719446669, 0.6040529984143135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 378}], {
             RGBColor[
             0.7144886647923281, 0.6661344259357302, 0.6044287772527661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 383}], {
             RGBColor[
             0.9552873412798946, 0.8551622461019582, 0.5287587670067748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.828007846093828, 0.8458809691661993, 0.673111245701651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 87}], {
             RGBColor[
             0.9489280164975771, 0.941133491514125, 0.6849541239268018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 119}], {
             RGBColor[
             0.649034527394307, 0.6974135481580788, 0.659689090378791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 127}], {
             RGBColor[
             0.9013599109420563, 0.9032039753459808, 0.6804170355543671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 129}], {
             RGBColor[
             0.987469219274603, 0.9686067473997613, 0.5580823531316048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 231}], {
             RGBColor[
             0.6120145290354417, 0.6593388874440249, 0.6575502569932011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 235}], {
             RGBColor[
             0.6248771601543411, 0.6728583282879043, 0.658282764806865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 317}], {
             RGBColor[
             0.8065485650821516, 0.8289705822743931, 0.6710723657401366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 326}], {
             RGBColor[
             0.6319966598016136, 0.680341373819537, 0.6586882097794213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 327}], {
             RGBColor[
             0.6856907426361989, 0.7291633194056575, 0.6620247920001858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 336}], {
             RGBColor[
             0.6192057230136316, 0.666897288263135, 0.6579597848518409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 396}], {
             RGBColor[
             0.7958320113122418, 0.8202704011487347, 0.6702287193713394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 54}], {
             RGBColor[
             0.7354375024888617, 0.7912447088162085, 0.9403442343680588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 63}], {
             RGBColor[
             0.4119301970637306, 0.530058989653502, 0.947788205312285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 224}], {
             RGBColor[
             0.4543116562642183, 0.5667676794588881, 0.9504887144160873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 297}], {
             RGBColor[
             0.4361092385734059, 0.5510016601352208, 0.9493288724565947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 318}], {
             RGBColor[
             0.4579775773314211, 0.5699429160327487, 0.9507223036648427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 345}], {
             RGBColor[
             0.3771360423831996, 0.49526539681334436`, 0.9457416551228024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 81}], {
             RGBColor[
             0.5704584541671, 0.6620786077757013, 0.9593853552085757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 106}], {
             RGBColor[
             0.7429796449338367, 0.7932769776083808, 0.7111174484012938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 164}], {
             RGBColor[
             0.5938294595994293, 0.680336214845657, 0.9617147586156072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 192}], {
             RGBColor[
             0.45193412964681834`, 0.5647853950423042, 0.950315942529009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 241}], {
             RGBColor[
             0.5396351468338635, 0.6371391483428817, 0.956901201988889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 271}], {
             RGBColor[
             0.7064461373153913, 0.659605139818219, 0.6037956400290329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 287}], {
             RGBColor[
             0.4586724900828417, 0.5706218241721446, 0.9507453048974943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 292}], {
             RGBColor[
             0.743771367779098, 0.7949703927189362, 0.7972915941609648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 371}], {
             RGBColor[
             0.3384304523596853, 0.4549226038837315, 0.9435065496362708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 374}], {
             RGBColor[
             0.4282950018164639, 0.5443103706527626, 0.9488096782069189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 382}], {
             RGBColor[
             0.4545481952390179, 0.5670495672715106, 0.9504825084770165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 384}], {
             RGBColor[
             0.7410056697029639, 0.7945123293013829, 0.8929639820083919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 389}], {
             RGBColor[
             0.6676614000624295, 0.7381943955807846, 0.9690258413959671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 78}], {
             RGBColor[
             0.27702585708198507`, 0.40850211861994545`, 0.9390875847865652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 104}], {
             RGBColor[
             0.6486345746345401, 0.7153243551226636, 0.8810499717345719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 172}], {
             RGBColor[
             0.6411514715094903, 0.710649438923942, 0.9342880947320111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 194}], {
             RGBColor[
             0.5612709927688859, 0.6480010459717247, 0.9615085858597694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 208}], {
             RGBColor[
             0.5386172828353284, 0.6303037955970571, 0.959250675764548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 217}], {
             RGBColor[
             0.5484025561966507, 0.6379481255177541, 0.960225980364626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 223}], {
             RGBColor[
             0.35407548254631305`, 0.48100038086231944`, 0.9437861529226388]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 230}], {
             RGBColor[
             0.6074267995077901, 0.6847634868676147, 0.9659218338608276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 240}], {
             RGBColor[
             0.5216638733016417, 0.6170596632186564, 0.9575609183408498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 242}], {
             RGBColor[
             0.6506921886474275, 0.7148625668026667, 0.7515331239169938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 357}], {
             RGBColor[
             0.36183243938625154`, 0.48771906700108725`, 0.944280419353272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 364}], {
             RGBColor[
             0.47743152811334877`, 0.5825050189792875, 0.9531522515472479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 385}], {
             RGBColor[
             0.40009488861420933`, 0.5197944076312261, 0.9470129165150192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 387}], {
             RGBColor[
             0.6510556119263317, 0.715639892448513, 0.7910895050372204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 92}], {
             RGBColor[
             0.6658710132892749, 0.733581829673098, 0.956551770831167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 182}], {
             RGBColor[
             0.9451394577198924, 0.9586056779101649, 0.9777487675459327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 256}], {
             RGBColor[
             0.7423045601076577, 0.7976078244422067, 0.9620235333067387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 281}], {
             RGBColor[
             0.6928348780908695, 0.756936574120989, 0.9582698844531152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 311}], {
             RGBColor[
             0.7846929379874701, 0.8320206191797004, 0.9653605016871819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 35}], {
             RGBColor[
             0.9148516812769372, 0.9323712335356966, 0.8910581614319528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 85}], {
             RGBColor[
             0.7459995915463453, 0.801650548232336, 0.9752779263703688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 86}], {
             RGBColor[
             0.8818410467324986, 0.9086201299996906, 0.9885919803377832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 91}], {
             RGBColor[
             0.529726450793067, 0.6117966903818296, 0.9601787425620172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 93}], {
             RGBColor[
             0.6072691749631637, 0.6870896405435425, 0.9648220414216409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 95}], {
             RGBColor[
             0.5368865276287137, 0.619322385111186, 0.9605864983454229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 125}], {
             RGBColor[
             0.8892062073885565, 0.9143876785287106, 0.9856460630280548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 162}], {
             RGBColor[
             0.5967688805890362, 0.6779948133168139, 0.9641529719491673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 211}], {
             RGBColor[
             0.6671350163678955, 0.7377933540492674, 0.9689541311904597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 214}], {
             RGBColor[
             0.5800188340719341, 0.6634867649055168, 0.963085673796582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 248}], {
             RGBColor[
             0.5773253841595998, 0.6611538339681816, 0.9629140495498922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 263}], {
             RGBColor[
             0.7696313644187126, 0.8201118688083553, 0.9776333206388129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 340}], {
             RGBColor[
             0.8097211799871681, 0.851430337424316, 0.9816290987940497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 42}], {
             RGBColor[
             0.7583152192524517, 0.8081438139619761, 0.8767193653049906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 85}], {
             RGBColor[
             0.8222185828343545, 0.8598548225760662, 0.8818653591032957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 86}], {
             RGBColor[
             0.9580600380205078, 0.9668244043434207, 0.89517941307071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 93}], {
             RGBColor[
             0.6834881662511728, 0.7452939148872726, 0.8714094741545677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 97}], {
             RGBColor[
             0.8345066291164299, 0.8694543377242343, 0.8830901167183716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 98}], {
             RGBColor[
             0.6760653712721132, 0.7388646629569348, 0.8709365002222218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 125}], {
             RGBColor[
             0.9654251986765656, 0.9725919528724407, 0.8922334957609817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 162}], {
             RGBColor[
             0.6729878718770453, 0.7361990876605441, 0.870740404682094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 211}], {
             RGBColor[
             0.7433540076559046, 0.7959976283929975, 0.8755415639233866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 214}], {
             RGBColor[
             0.6562378253599432, 0.7216910392492469, 0.8696731065295088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 248}], {
             RGBColor[
             0.6535443754476089, 0.7193581083119118, 0.8695014822828191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 263}], {
             RGBColor[
             0.8458503557067217, 0.8783161431520854, 0.8842207533717397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 340}], {
             RGBColor[
             0.8859401712751772, 0.9096346117680462, 0.8882165315269765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 80}], {
             RGBColor[
             0.3227648234799671, 0.4514598379802632, 0.9418797036288838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 151}], {
             RGBColor[
             0.43851935702216266`, 0.5478573607583991, 0.9503229038166616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 168}], {
             RGBColor[
             0.6216969120685681, 0.6921438393622127, 0.9443133025794845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 265}], {
             RGBColor[
             0.4899425386309087, 0.5887458596016566, 0.9549585350845982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 277}], {
             RGBColor[
             0.5349965552458152, 0.6239423998044302, 0.9594490984070487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 304}], {
             RGBColor[
             0.39051722707912395`, 0.5088870691993297, 0.9465440003099499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 378}], {
             RGBColor[
             0.39529061824966055`, 0.5127623231903929, 0.9469197791484025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 383}], {
             RGBColor[
             0.636089294737227, 0.7017901433566209, 0.871249768902411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 41}], {
             RGBColor[
             0.7120347524444427, 0.7149227162043192, 0.6159272011471837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 114}], {
             RGBColor[
             0.8168349934399403, 0.799402837261522, 0.6245886649418066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 170}], {
             RGBColor[
             0.7469951810143456, 0.7433051670667256, 0.6186794141484759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 187}], {
             RGBColor[
             0.8501116756258722, 0.8253988342973237, 0.6279053736338249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 206}], {
             RGBColor[
             0.6358962086548992, 0.6494831394667996, 0.6109354129655205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 256}], {
             RGBColor[
             0.7427705653889056, 0.7398754337852282, 0.6183468369311644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 261}], {
             RGBColor[
             0.6358962086548992, 0.6494831394667996, 0.6109354129655205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 311}], {
             RGBColor[
             0.785158943268718, 0.774288228522722, 0.6216838053116076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 361}], {
             RGBColor[
             0.6358962086548992, 0.6494831394667996, 0.6109354129655205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 53}], {
             RGBColor[
             0.5013666158476078, 0.6053690871978057, 0.9540825121866808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 58}], {
             RGBColor[
             0.5020257568186547, 0.605904207532064, 0.9541344021784346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 102}], {
             RGBColor[
             0.5966170511714668, 0.6808072107900854, 0.962873500570986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 103}], {
             RGBColor[
             0.40206788262335236`, 0.5226727242341449, 0.9468403878394593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 117}], {
             RGBColor[
             0.6550548005463569, 0.7269656793614587, 0.9685636318137278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 145}], {
             RGBColor[
             0.7109053392989948, 0.7683003343831061, 0.8459223884889613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 189}], {
             RGBColor[
             0.3803269445381342, 0.5038418163960497, 0.945455074489426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 222}], {
             RGBColor[
             0.32329808411026706`, 0.44616069232729416`, 0.9421246220251243]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 254}], {
             RGBColor[
             0.32277223391105286`, 0.44560799042709176`, 0.9420946756342046]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 303}], {
             RGBColor[
             0.6920388359017979, 0.755916463788846, 0.9533939753625279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 376}], {
             RGBColor[
             0.482004525919148, 0.5896500703416709, 0.9525582575418401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 150}], {
             RGBColor[
             0.871513805682149, 0.41759552728505006`, 0.41577948409959753`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 237}], {
             RGBColor[
             0.6392063748468284, 0.22767182743486478`, 0.4226209094860993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 251}], {
             RGBColor[
             0.7642679138320378, 0.3337124488641496, 0.43166648942331165`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 283}], {
             RGBColor[
             0.6276683346704974, 0.21554461565554112`, 0.42196383516705815`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 294}], {
             RGBColor[
             0.7990412418961235, 0.36087763703489495`, 0.4351323697895133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 320}], {
             RGBColor[
             0.6232594550894999, 0.2109106036768018, 0.4217127559972732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 347}], {
             RGBColor[
             0.8463366076088316, 0.3982798530918061, 0.43972566195836327`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 381}], {
             RGBColor[
             0.7372302024913558, 0.3119234428426639, 0.4294276138517201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 51}], {
             RGBColor[
             0.45105222487808505`, 0.5483894525402642, 0.9526615006880733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 84}], {
             RGBColor[
             0.216914274575229, 0.34532103411088394`, 0.9356643190899228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 102}], {
             RGBColor[
             0.48664024143821094`, 0.5761910815559782, 0.9562085815898634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 134}], {
             RGBColor[
             0.28714134369915745`, 0.413769388355469, 0.9398600764911639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 163}], {
             RGBColor[
             0.3110567765361968, 0.43448373425430775`, 0.9413839467239531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 167}], {
             RGBColor[
             0.4794000842580801, 0.5705350157396274, 0.9554869503852637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 174}], {
             RGBColor[
             0.2570754936560491, 0.38753302173318693`, 0.937951441103376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 183}], {
             RGBColor[
             0.3046181940865834, 0.428906957749016, 0.9409736859436786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 189}], {
             RGBColor[
             0.2703501348048784, 0.3992256871619425, 0.9387901555083035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 226}], {
             RGBColor[
             0.26445865536703467`, 0.3941227837872487, 0.9384147556481548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 234}], {
             RGBColor[
             0.25331644943499204`, 0.38358202791968654`, 0.9377373690959945]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 246}], {
             RGBColor[
             0.23740618916561135`, 0.3668593356078027, 0.936831303310774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 269}], {
             RGBColor[
             0.4378958223755869, 0.5381115709129503, 0.9513501934401959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 272}], {
             RGBColor[
             0.23071644020804116`, 0.3598279852988145, 0.9364503320042371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 350}], {
             RGBColor[
             0.43863725302511747`, 0.5386907821714452, 0.9514240923182777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 355}], {
             RGBColor[
             0.3278903741789653, 0.44906415045125536`, 0.9424565686803844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 392}], {
             RGBColor[
             0.19321966628956455`, 0.32041649847771514`, 0.9343149462010858]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 395}], {
             RGBColor[
             0.23294636080119718`, 0.36217177322735306`, 0.9365773226831454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 55}], {
             RGBColor[
             0.37821131669276065`, 0.4992508525638216, 0.9455429855802698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 83}], {
             RGBColor[
             0.5487920177630529, 0.644573108675532, 0.9576220644111582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.4263222628547974, 0.5431728462715246, 0.948526162998565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 135}], {
             RGBColor[
             0.40197733143939995`, 0.5220864902913384, 0.9469749254961535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 156}], {
             RGBColor[
             0.6865874436085513, 0.753133294105018, 0.9710062208435237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 165}], {
             RGBColor[
             0.45778417426042006`, 0.5704235726094287, 0.9505308881726553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 187}], {
             RGBColor[
             0.6100969199101468, 0.6927222415527285, 0.9635564621767971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 206}], {
             RGBColor[
             0.39588145293917376`, 0.5168065467222045, 0.9465865015084927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 245}], {
             RGBColor[
             0.5303220647993434, 0.6295783687976939, 0.956168042056188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 256}], {
             RGBColor[
             0.5027558096731803, 0.6071988410406332, 0.9539979254741366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 311}], {
             RGBColor[
             0.5451441875529927, 0.641611635778127, 0.9573348938545798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 328}], {
             RGBColor[
             0.6097479723269927, 0.6924496410486687, 0.963521682342809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 386}], {
             RGBColor[
             0.7335211153800769, 0.7870037551596676, 0.8255786835508767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 400}], {
             RGBColor[
             0.4921151237902554, 0.5985602528834384, 0.9531602517033161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 45}], {
             RGBColor[
             0.7594040752925051, 0.8068397112151728, 0.731149827539153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 93}], {
             RGBColor[
             0.4507327129386782, 0.5628622209698219, 0.9504832452946785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 98}], {
             RGBColor[
             0.44330991795961866`, 0.556432969039484, 0.9500102713623328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 125}], {
             RGBColor[
             0.7326697453640709, 0.79016025895499, 0.9713072669010926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 139}], {
             RGBColor[
             0.3524224624681313, 0.4657412839291171, 0.9446572665350462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 148}], {
             RGBColor[
             0.38465231676892353`, 0.49961690429003885`, 0.9464927090576797]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 204}], {
             RGBColor[
             0.44708264011217674`, 0.5597007113455008, 0.9502506658818066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 248}], {
             RGBColor[
             0.42078892213511426`, 0.536926414394461, 0.94857525342293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 275}], {
             RGBColor[
             0.39432699067758836`, 0.5097855999778003, 0.9470436674243807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 276}], {
             RGBColor[
             0.45137919693828377`, 0.5634221729170497, 0.9505244386834701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 288}], {
             RGBColor[
             0.5248146447671431, 0.6251071971091087, 0.9557344777769088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 290}], {
             RGBColor[
             0.6969897340138829, 0.5605592716160833, 0.5838558246749903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 318}], {
             RGBColor[
             0.47281161242983266`, 0.581985853991305, 0.9518900932466507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 56}], {
             RGBColor[
             0.7122656419512915, 0.7740598187085599, 0.9729358469775792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 59}], {
             RGBColor[
             0.6003143091849572, 0.6792949120207352, 0.9651940677620765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[
             0.5650333078977281, 0.6423747576608161, 0.9631789201258567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 121}], {
             RGBColor[
             0.7328409446628167, 0.7907637763566002, 0.9745556101768478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 122}], {
             RGBColor[
             0.7349870124403968, 0.7925060508576913, 0.9747245564936041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 175}], {
             RGBColor[
             0.9255123210424608, 0.9427925883313044, 0.97022735832868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 213}], {
             RGBColor[
             0.9294648496663026, 0.9108280601078089, 0.6613455224617916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 227}], {
             RGBColor[
             0.5554326501914721, 0.6322838576946845, 0.9626321768723857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 237}], {
             RGBColor[
             0.5865535429794129, 0.6649938891933784, 0.9644044656774238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 274}], {
             RGBColor[
             0.6975776402726726, 0.762135437258922, 0.9717795536815154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 296}], {
             RGBColor[
             0.6291937317478173, 0.7043088163227017, 0.9670342390307113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 308}], {
             RGBColor[
             0.7693798704087593, 0.8203316007194451, 0.9774978071329561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 373}], {
             RGBColor[
             0.7376385764758557, 0.7946587099932756, 0.9749332973274745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 380}], {
             RGBColor[
             0.5814939303996349, 0.6596759155740659, 0.9641163282260314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 46}], {
             RGBColor[
             0.8466617193270474, 0.8805690892439875, 0.985236544684895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 65}], {
             RGBColor[
             0.6542263749301412, 0.7274438864450965, 0.9677878862931664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 68}], {
             RGBColor[
             0.6240424596666266, 0.7022372805515296, 0.9656056470555756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 113}], {
             RGBColor[
             0.8494714106089196, 0.8828094608051142, 0.985504535547601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 149}], {
             RGBColor[
             0.6989771216098827, 0.7637745585978744, 0.971310828999182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 161}], {
             RGBColor[
             0.7143572313877836, 0.776260824581624, 0.9725216075800969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 195}], {
             RGBColor[
             0.7409874046791871, 0.7975893915432203, 0.9748169957143827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 247}], {
             RGBColor[
             0.7067388478661137, 0.7700758776344658, 0.9719218605222126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 249}], {
             RGBColor[
             0.5880692792007296, 0.6710791196965916, 0.963313467806123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 250}], {
             RGBColor[
             0.900247661726898, 0.9017918355754959, 0.6795382183969839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 266}], {
             RGBColor[
             0.8747050959568471, 0.9029301165514096, 0.9879113469824632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 315}], {
             RGBColor[
             0.8895048057737961, 0.9141458484071749, 0.969035264471632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 316}], {
             RGBColor[
             0.8610069718311691, 0.8920076041992682, 0.9866048076748962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 358}], {
             RGBColor[
             0.641485009645564, 0.7170998721151118, 0.9667848393448055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 362}], {
             RGBColor[
             0.6244507716695853, 0.7025909398861343, 0.965631664335348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 363}], {
             RGBColor[
             0.7778311928715742, 0.8263720389022746, 0.9784892401966235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 369}], {
             RGBColor[
             0.7915523464879914, 0.8370911083920496, 0.9798568365576372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 372}], {
             RGBColor[
             0.606358878545024, 0.6869206513866277, 0.9644788649034839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 66}], {
             RGBColor[
             0.8293679878160034, 0.8632852667243153, 0.7368998802169063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 91}], {
             RGBColor[
             0.6070342981211295, 0.6686968619787566, 0.7211966375291063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 123}], {
             RGBColor[
             0.9778611676855842, 0.9365226340144691, 0.4076126663571442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 140}], {
             RGBColor[
             0.6388269091921089, 0.7021129119823231, 0.7230071796966454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 148}], {
             RGBColor[
             0.6184966261214715, 0.6807444954606864, 0.7218494001517312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 179}], {
             RGBColor[
             0.6289695136415687, 0.6917521642637293, 0.722445815602752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 203}], {
             RGBColor[
             0.7577746171721165, 0.8055168437067897, 0.7310215506270143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 232}], {
             RGBColor[
             0.7109569859786612, 0.7668388107909986, 0.7275208443480075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 257}], {
             RGBColor[
             0.7682714560476747, 0.8140386503831702, 0.731847900234486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 275}], {
             RGBColor[
             0.6281713000301363, 0.6909131911484478, 0.7224003585184322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 276}], {
             RGBColor[
             0.6852235062908316, 0.7445497640876971, 0.7258811297775216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 279}], {
             RGBColor[
             0.7921168248865424, 0.8333973950281874, 0.7337250950179458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 280}], {
             RGBColor[
             0.6437741247809496, 0.7073127492377798, 0.7232889163056804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 288}], {
             RGBColor[
             0.7586589541196911, 0.8062347882797561, 0.7310911688709603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 297}], {
             RGBColor[
             0.6847875830243655, 0.7441721892644245, 0.7258533531324541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 325}], {
             RGBColor[
             0.6289695136415687, 0.6917521642637293, 0.722445815602752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 339}], {
             RGBColor[
             0.9896059407881252, 0.9882154309461326, 0.6943956149980794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 149}], {
             RGBColor[
             0.7250198736493175, 0.7845403421624475, 0.9737948099373425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 153}], {
             RGBColor[
             0.8995528510596643, 0.9227430419960516, 0.9902813480460226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 161}], {
             RGBColor[
             0.7403999834272185, 0.7970266081461971, 0.9750055885182574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 184}], {
             RGBColor[
             0.9110427104595147, 0.931551924191357, 0.9791447769272724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 195}], {
             RGBColor[
             0.767030156718622, 0.8183551751077933, 0.9773009766525432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 247}], {
             RGBColor[
             0.7327815999055486, 0.790841661199039, 0.9744058414603731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 250}], {
             RGBColor[
             0.9262904137663328, 0.922557619140069, 0.6820221993351444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 315}], {
             RGBColor[
             0.9155475578132309, 0.934911631971748, 0.9715192454097925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 343}], {
             RGBColor[
             0.9191163873782925, 0.9375732592179489, 0.9654781478559673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 356}], {
             RGBColor[
             0.682116287638924, 0.749709278254686, 0.9704172824855903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 358}], {
             RGBColor[
             0.6675277616849988, 0.7378656556796849, 0.969268820282966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 362}], {
             RGBColor[
             0.6504935237090201, 0.7233567234507075, 0.9681156452735085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 363}], {
             RGBColor[
             0.803873944911009, 0.8471378224668478, 0.980973221134784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 369}], {
             RGBColor[
             0.8175950985274263, 0.8578568919566227, 0.9823408174957977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 372}], {
             RGBColor[
             0.6324016305844589, 0.7076864349512008, 0.9669628458416444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.9679506602941317, 0.8984143298747215, 0.5049203466315237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.6213876956074609, 0.6195135053158547, 0.6060335915218568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 173}], {
             RGBColor[
             0.772078218823986, 0.7466396302669802, 0.6167332997753541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 201}], {
             RGBColor[
             0.8665526648279533, 0.8210481036098174, 0.6257364540590463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 209}], {
             RGBColor[
             0.9224279678418232, 0.8653742236295037, 0.6311262167090429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 323}], {
             RGBColor[
             0.9079797720191104, 0.8538536244663004, 0.629748134893416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 346}], {
             RGBColor[
             0.8604744229221687, 0.816299734836669, 0.6251306317102778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 61}], {
             RGBColor[
             0.2958659174550286, 0.4224003283513125, 0.9403766686231649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 68}], {
             RGBColor[
             0.40003378539040224`, 0.5209108914476632, 0.9467107769624574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 118}], {
             RGBColor[
             0.4763590551325, 0.5835771275512751, 0.9525254326459529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 173}], {
             RGBColor[
             0.48775549193554224`, 0.5928292683516121, 0.9534226018976119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 176}], {
             RGBColor[
             0.5844087214061121, 0.6689398238979268, 0.962642916955366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 209}], {
             RGBColor[
             0.6381052409533796, 0.7115638617141355, 0.9678155188313007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 344}], {
             RGBColor[
             0.6785551645576755, 0.7425062476764873, 0.9256785564703007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 354}], {
             RGBColor[
             0.5663047911987302, 0.6547968960249544, 0.9608384863831407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 388}], {
             RGBColor[
             0.6395267310024768, 0.7126973192939663, 0.9679511018211628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 52}], {
             RGBColor[
             0.5932032303803267, 0.6662006151839587, 0.9656486213507838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 62}], {
             RGBColor[
             0.8057211228621821, 0.8490898053215541, 0.9810116897710301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.9266412932659314, 0.9443423276694797, 0.9928545679961809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 127}], {
             RGBColor[
             0.8790731877104105, 0.9064128115013355, 0.9883174796237462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[
             0.9651824960429571, 0.9718155835551159, 0.8659827972009839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 133}], {
             RGBColor[
             0.7223372408329731, 0.7819062376522299, 0.9740978783801277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 199}], {
             RGBColor[
             0.9438777677976055, 0.957664711631951, 0.9798844794829306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 216}], {
             RGBColor[
             0.7894376663496934, 0.8363690453351447, 0.9793887070034181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 231}], {
             RGBColor[
             0.589727805803796, 0.6625477235993795, 0.9654507010625802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 235}], {
             RGBColor[
             0.6025904369226953, 0.676067164443259, 0.9661832088762441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 298}], {
             RGBColor[
             0.8246180129608187, 0.8638521994882931, 0.9828951551745841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 313}], {
             RGBColor[
             0.9154450494233491, 0.9354147467433476, 0.9917866602634706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 361}], {
             RGBColor[
             0.627726826579666, 0.7014703643239457, 0.9676519168908662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 393}], {
             RGBColor[
             0.599125090767712, 0.6724248659187352, 0.965985862539238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 396}], {
             RGBColor[
             0.773545288080596, 0.8234792373040893, 0.9781291634407185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.7462857437068455, 0.8017233620562945, 0.9753464465620605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 147}], {
             RGBColor[
             0.869004701394731, 0.894022680265623, 0.722661876446183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 164}], {
             RGBColor[
             0.7198494844534205, 0.7810711554045069, 0.9727115273005678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 271}], {
             RGBColor[
             0.8324661621693825, 0.7603400803770689, 0.6147924087139934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 287}], {
             RGBColor[
             0.5846925149368329, 0.6713567647309944, 0.9617420735824549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 371}], {
             RGBColor[
             0.4644504772136764, 0.5556575444425814, 0.9545033183212315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 391}], {
             RGBColor[
             0.5839334295996297, 0.6706992831646474, 0.9616937053360011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 84}], {
             RGBColor[
             0.46045416687418494`, 0.5582714896957178, 0.9531969273758245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 102}], {
             RGBColor[
             0.730180133737167, 0.7891415371408121, 0.9737411898757652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 134}], {
             RGBColor[
             0.5306812359981133, 0.6267198439403029, 0.9573926847770656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 163}], {
             RGBColor[
             0.5545966688351527, 0.6474341898391416, 0.9589165550098548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 167}], {
             RGBColor[
             0.7229399765570361, 0.7834854713244612, 0.9730195586711654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 174}], {
             RGBColor[
             0.5006153859550051, 0.6004834773180208, 0.9554840493892778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 183}], {
             RGBColor[
             0.5481580863855393, 0.6418574133338499, 0.9585062942295803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 189}], {
             RGBColor[
             0.5138900271038344, 0.6121761427467765, 0.9563227637942052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 222}], {
             RGBColor[
             0.4568611666759672, 0.5544950186780209, 0.9529923113299035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 226}], {
             RGBColor[
             0.5079985476659906, 0.6070732393720826, 0.9559473639340565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 234}], {
             RGBColor[
             0.496856341733948, 0.5965324835045205, 0.9552699773818962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 238}], {
             RGBColor[
             0.4382670577513746, 0.5349514312636762, 0.951933404334167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 246}], {
             RGBColor[
             0.4809460814645673, 0.5798097911926365, 0.9543639115966758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 269}], {
             RGBColor[
             0.6814357146745429, 0.7510620264977842, 0.9688828017260976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 272}], {
             RGBColor[
             0.47425633250699706`, 0.5727784408836484, 0.9539829402901389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 350}], {
             RGBColor[
             0.6821771453240735, 0.7516412377562791, 0.9689567006041795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 355}], {
             RGBColor[
             0.5714302664779213, 0.6620146060360892, 0.9599891769662862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 392}], {
             RGBColor[
             0.4367595585885205, 0.5333669540625491, 0.9518475544869875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 395}], {
             RGBColor[
             0.47648625310015313`, 0.575122228812187, 0.9541099309690472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 89}], {
             RGBColor[
             0.2930868822974043, 0.42291171397763416`, 0.9400927323485269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 128}], {
             RGBColor[
             0.6227545556764975, 0.6860710860708774, 0.8072181582881928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 133}], {
             RGBColor[
             0.37982972720359787`, 0.49653309417298186`, 0.9460373792760088]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 199}], {
             RGBColor[
             0.6013702541682302, 0.6722915681527029, 0.9518239803788117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 299}], {
             RGBColor[
             0.4554142478457647, 0.5576237414494066, 0.952173823213027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 342}], {
             RGBColor[
             0.2507264174555056, 0.38085974009173407`, 0.9375898706063717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 393}], {
             RGBColor[
             0.25661757713833677`, 0.3870517224394871, 0.9379253634351191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 58}], {
             RGBColor[
             0.5759264206206218, 0.666602039306225, 0.9597581840006988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 64}], {
             RGBColor[
             0.5102468141629428, 0.6130606686468041, 0.9546483505708829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 117}], {
             RGBColor[
             0.728955464348324, 0.7876635111356197, 0.974187413635992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 126}], {
             RGBColor[
             0.4492467241893851, 0.5602254566653769, 0.9507614787780294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 289}], {
             RGBColor[
             0.49300605836695977`, 0.5981275925219056, 0.9535497848569646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 303}], {
             RGBColor[
             0.7659394997037651, 0.8166142955630069, 0.9590177571847921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 376}], {
             RGBColor[
             0.5559051897211151, 0.6503479021158319, 0.9581820393641043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 63}], {
             RGBColor[
             0.6514760038094585, 0.7196774543422977, 0.9346748823988583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 66}], {
             RGBColor[
             0.8202354501107717, 0.8597332022839073, 0.9472620766276201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 204}], {
             RGBColor[
             0.671794411759493, 0.7372762380757403, 0.9359695533865718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 224}], {
             RGBColor[
             0.6938574630099462, 0.7563861441476838, 0.9373753915026606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 290}], {
             RGBColor[
             0.9217015056611992, 0.7381347983463228, 0.5695747121797556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 297}], {
             RGBColor[
             0.6756550453191338, 0.7406201248240165, 0.9362155495431679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 318}], {
             RGBColor[
             0.6975233840771489, 0.7595613807215444, 0.937608980751416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 345}], {
             RGBColor[
             0.6166818491289274, 0.68488386150214, 0.9326283322093757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 92}], {
             RGBColor[
             0.33251358281884075`, 0.46017757537562204`, 0.9424908588886789]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 135}], {
             RGBColor[
             0.3081686514034433, 0.43909121939543583`, 0.9409396213862673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 156}], {
             RGBColor[
             0.5927787635725946, 0.6701380232091154, 0.9649709167336377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.3639754942244634, 0.4874283017135262, 0.9444955840627693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 221}], {
             RGBColor[
             0.3008844743394058, 0.43278203133595106`, 0.9404754800648918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 245}], {
             RGBColor[
             0.4365133847633868, 0.5465830979017914, 0.9501327379463018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 255}], {
             RGBColor[
             0.461909755211317, 0.5672010155248717, 0.9521320332579332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 328}], {
             RGBColor[
             0.5159392922910361, 0.6094543701527662, 0.9574863782329229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 386}], {
             RGBColor[
             0.6397124353441203, 0.704008484263765, 0.8195433794409905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 400}], {
             RGBColor[
             0.39830644375429874`, 0.5155649819875359, 0.94712494759343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 59}], {
             RGBColor[
             0.4224539897179084, 0.5381284346471327, 0.9487477118431062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 90}], {
             RGBColor[
             0.3871729884306793, 0.5012082802872135, 0.9467325642068865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 121}], {
             RGBColor[
             0.5549806251957679, 0.6495972989829978, 0.9581092542578775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 122}], {
             RGBColor[
             0.5571266929733478, 0.6513395734840889, 0.9582782005746339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 137}], {
             RGBColor[
             0.4137446663681253, 0.5291367985411566, 0.9482457819561492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 166}], {
             RGBColor[
             0.7426044260289422, 0.7978616373797911, 0.9623252311913386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 169}], {
             RGBColor[
             0.7626342871575189, 0.8068675428645251, 0.6877476895308534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 175}], {
             RGBColor[
             0.747652001575412, 0.8016261109577019, 0.9537810024097098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 178}], {
             RGBColor[
             0.7627412215624922, 0.8117357578297169, 0.8770141119602367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 213}], {
             RGBColor[
             0.7516045301992538, 0.7696615827342064, 0.6448991665428213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 274}], {
             RGBColor[
             0.5197173208056236, 0.6209689598853194, 0.9553331977625451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 278}], {
             RGBColor[
             0.6507608242731512, 0.7254448563227174, 0.9669560676984887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 296}], {
             RGBColor[
             0.45133341228076845`, 0.5631423389490992, 0.950587883111741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 319}], {
             RGBColor[
             0.44080020255282815`, 0.5540190020972716, 0.9499167163020283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 352}], {
             RGBColor[
             0.652320546626536, 0.7266633232795106, 0.96711152624624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 76}], {
             RGBColor[
             0.46717735135834115`, 0.5783146457893649, 0.9511970589074055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.34707999656479394`, 0.4670293755275545, 0.9437246340590064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 102}], {
             RGBColor[
             0.6168059634277759, 0.6978994229726487, 0.9642688965589471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 144}], {
             RGBColor[
             0.6097074953332337, 0.6923540457468367, 0.963561387598239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 163}], {
             RGBColor[
             0.4412224985257618, 0.5561920756709783, 0.9494442616930368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 167}], {
             RGBColor[
             0.6095658062476451, 0.6922433571562979, 0.9635472653543473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 174}], {
             RGBColor[
             0.3872412156456141, 0.5092413631498575, 0.9460117560724597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 186}], {
             RGBColor[
             0.5330823084398066, 0.6318192589325807, 0.9563853385466707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 188}], {
             RGBColor[
             0.4161967452959016, 0.5345160260542038, 0.9478496428266348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 189}], {
             RGBColor[
             0.4005158567944434, 0.520934028578613, 0.9468504704773871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 222}], {
             RGBColor[
             0.3434869963665762, 0.46325290450985745`, 0.9435200180130854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 228}], {
             RGBColor[
             0.5608834502382838, 0.6542123306421754, 0.9586950630698168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 238}], {
             RGBColor[
             0.32489288744198364`, 0.44370931709551276`, 0.9424611110173489]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 333}], {
             RGBColor[
             0.6930450606809794, 0.6462183551328625, 0.6021634081228563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 368}], {
             RGBColor[
             0.49972872748982183`, 0.6047413193556844, 0.9537596224760952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 117}], {
             RGBColor[
             0.729614605319371, 0.788198631469878, 0.9742393036277457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 289}], {
             RGBColor[
             0.49366519933800673`, 0.5986627128561639, 0.9536016748487184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 303}], {
             RGBColor[
             0.766598640674812, 0.8171494158972652, 0.9590696471765459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 376}], {
             RGBColor[
             0.556564330692162, 0.6508830224500902, 0.9582339293558579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 90}], {
             RGBColor[
             0.2752216556643451, 0.40644337359938887`, 0.9389907849913837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 121}], {
             RGBColor[
             0.44302929242943356`, 0.554832392295173, 0.9503674750423747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 122}], {
             RGBColor[
             0.44517536020701365`, 0.5565746667962641, 0.9505364213591312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 175}], {
             RGBColor[
             0.6357006688090778, 0.7068612042698772, 0.9460392231942072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 178}], {
             RGBColor[
             0.6507898887961578, 0.7169708511418922, 0.869272332744734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 213}], {
             RGBColor[
             0.6396531974329196, 0.6748966760463816, 0.6371573873273186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 274}], {
             RGBColor[
             0.40776598803928943`, 0.5262040531974947, 0.9475914185470424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 296}], {
             RGBColor[
             0.3393820795144342, 0.46837743226127443`, 0.9428461038962384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 319}], {
             RGBColor[
             0.32884886978649386`, 0.45925409540944684`, 0.9421749370865256]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 373}], {
             RGBColor[
             0.4478269242424727, 0.5587273259318484, 0.9507451621930016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.5731088801015435, 0.6626430566490178, 0.9604455190601063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 101}], {
             RGBColor[
             0.38184001653328353`, 0.5051523633090383, 0.945551486099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.6033860529715701, 0.6862958142101191, 0.9634632646955235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 259}], {
             RGBColor[
             0.4067688936067395, 0.5267445036682727, 0.9471399321023801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 331}], {
             RGBColor[
             0.44391408435667623`, 0.5588547852591215, 0.9495242022268067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 335}], {
             RGBColor[
             0.5866857927162822, 0.6732494439720093, 0.9617987388260815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 394}], {
             RGBColor[
             0.33366485770997956`, 0.45662011824420945`, 0.9427309845534011]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 118}], {
             RGBColor[
             0.3996233538523648, 0.508826928430906, 0.9479392777086197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 130}], {
             RGBColor[
             0.4833030820500808, 0.5751516439342783, 0.9556277943406469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 147}], {
             RGBColor[
             0.6060220397379661, 0.6674509621436069, 0.7029432242247694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 164}], {
             RGBColor[
             0.4568668227966557, 0.5544994372824907, 0.9529928750791542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 173}], {
             RGBColor[
             0.41101979065540706`, 0.518079069231243, 0.9488364469602787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 176}], {
             RGBColor[
             0.5076730201259769, 0.5941896247775578, 0.9580567620180328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 344}], {
             RGBColor[
             0.6018194632775404, 0.6677560485561183, 0.9210924015329676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 354}], {
             RGBColor[
             0.489569089918595, 0.5800466969045853, 0.9562523314458076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 371}], {
             RGBColor[
             0.2014678155569116, 0.3290858263205654, 0.9347846660998178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 388}], {
             RGBColor[
             0.5627910297223417, 0.6379471201735973, 0.9633649468838297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 87}], {
             RGBColor[
             0.7966516721184115, 0.841858374327827, 0.9801571373123084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 119}], {
             RGBColor[
             0.49675818301514135`, 0.5981384309717808, 0.9548921037642976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 127}], {
             RGBColor[
             0.7490835665628907, 0.8039288581596828, 0.9756200489398736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 129}], {
             RGBColor[
             0.8351928748954374, 0.8693316302134633, 0.8532853665171114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 216}], {
             RGBColor[
             0.6594480452021736, 0.7338850919934921, 0.9666912763195455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 231}], {
             RGBColor[
             0.45973818465627614`, 0.5600637702577269, 0.9527532703787077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 235}], {
             RGBColor[
             0.4726008157751755, 0.5735832111016063, 0.9534857781923716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 298}], {
             RGBColor[
             0.6946283918132989, 0.7613682461466403, 0.9701977244907116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 313}], {
             RGBColor[
             0.7854554282758293, 0.832930793401695, 0.9790892295795981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 317}], {
             RGBColor[
             0.654272220702986, 0.7296954650880951, 0.9662753791256432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 336}], {
             RGBColor[
             0.46692937863446604`, 0.567622171076837, 0.9531627982373475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 361}], {
             RGBColor[
             0.4977372054321463, 0.5989864109822931, 0.9549544862069936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 393}], {
             RGBColor[
             0.46913546962019226`, 0.5699409125770825, 0.9532884318553655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 396}], {
             RGBColor[
             0.6435556669330762, 0.7209952839624367, 0.965431732756846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 98}], {
             RGBColor[
             0.34451438418180375`, 0.4728227766070169, 0.9431731298113243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 139}], {
             RGBColor[
             0.2536269286903164, 0.38213109149665003`, 0.9378201249840377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 204}], {
             RGBColor[
             0.34828710633436183`, 0.4760905189130338, 0.9434135243307981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 224}], {
             RGBColor[
             0.37035015758481504`, 0.4952004249849772, 0.9448193624468868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 290}], {
             RGBColor[
             0.5981942002360681, 0.4769490791836163, 0.5770186831239819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 318}], {
             RGBColor[
             0.37401607865201775`, 0.49837566155883795`, 0.9450529516956422]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 345}], {
             RGBColor[
             0.29317454370379625`, 0.4236981423394335, 0.9400723031536019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 77}], {
             RGBColor[
             0.4212101998314257, 0.5392528372789404, 0.9480601193650713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 94}], {
             RGBColor[
             0.45064593487755755`, 0.5646739898539144, 0.9499563510283229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 254}], {
             RGBColor[
             0.33165243222638796`, 0.45329957187609005`, 0.9426605140184067]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 289}], {
             RGBColor[
             0.42798559288032784`, 0.545121342196743, 0.9484918414189025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 68}], {
             RGBColor[
             0.45764986730915536`, 0.5698778613172117, 0.9506409696020074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 173}], {
             RGBColor[
             0.5453715738542954, 0.6417962382211606, 0.9573527945371618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 176}], {
             RGBColor[
             0.6420248033248652, 0.7179067937674755, 0.9665731095949159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 250}], {
             RGBColor[
             0.7338550693694267, 0.7694324163411781, 0.6645735409434157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 363}], {
             RGBColor[
             0.611438600514103, 0.6940126196679568, 0.9635245627430553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 123}], {
             RGBColor[
             0.8139807708565345, 0.8118405983529641, 0.638006027940846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 131}], {
             RGBColor[
             0.47666177535359294`, 0.5792337264778238, 0.953498222970154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 140}], {
             RGBColor[
             0.4749465123630593, 0.577430876320818, 0.9534005412803472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 203}], {
             RGBColor[
             0.5938942203430669, 0.6808348080452846, 0.9614149122107161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 232}], {
             RGBColor[
             0.5470765891496115, 0.6421567751294935, 0.9579142059317093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 257}], {
             RGBColor[
             0.604391059218625, 0.6893566147216652, 0.9622412618181878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 275}], {
             RGBColor[
             0.4642909032010867, 0.5662311554869428, 0.952793720102134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 280}], {
             RGBColor[
             0.47989372795190005`, 0.5826307135762747, 0.9536822778893821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 297}], {
             RGBColor[
             0.5209071861953158, 0.6194901536029195, 0.956246714716156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 318}], {
             RGBColor[
             0.542775524953331, 0.6384314095004475, 0.9576401459244039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 322}], {
             RGBColor[
             0.8145061244940301, 0.855460280619851, 0.9569603304493232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 325}], {
             RGBColor[
             0.4650891168125191, 0.5670701286022243, 0.952839177186454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 339}], {
             RGBColor[
             0.8257255439590757, 0.8635333952846276, 0.9247889765817814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 113}], {
             RGBColor[
             0.9106375635288289, 0.8586717273910117, 0.6306059832411572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 124}], {
             RGBColor[
             0.6306042767997309, 0.6308040159726129, 0.6072277547575148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 194}], {
             RGBColor[
             0.8789346402951476, 0.8334336234891146, 0.6275712641710686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 208}], {
             RGBColor[
             0.8562809303615899, 0.8157363731144471, 0.6253133540758471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 210}], {
             RGBColor[
             0.9086870172801733, 0.6670963762374249, 0.24494153595236634`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 249}], {
             RGBColor[
             0.6492354321206389, 0.6469413862824891, 0.6084149154996793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 266}], {
             RGBColor[
             0.9358712488767564, 0.8787923831373071, 0.6330127946760193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 293}], {
             RGBColor[
             0.6682823978334244, 0.6634389106545715, 0.6096285713123275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 316}], {
             RGBColor[
             0.9221731247510785, 0.8678698707851656, 0.6317062553684525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 385}], {
             RGBColor[
             0.7177585361404709, 0.705226985148616, 0.6130755948263183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 387}], {
             RGBColor[
             0.9687192594525933, 0.901072469965903, 0.45715218334851954`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 161}], {
             RGBColor[
             0.5177807237667977, 0.6186947994537393, 0.9553746908889379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 173}], {
             RGBColor[
             0.5151876585907808, 0.6165896323275937, 0.9551705552995711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 176}], {
             RGBColor[
             0.6118408880613506, 0.6927001878739085, 0.9643908703573252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 250}], {
             RGBColor[
             0.703671154105912, 0.7442258104476112, 0.6623913017058249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 363}], {
             RGBColor[
             0.5812546852505883, 0.6688060137743899, 0.9613423235054646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 106}], {
             RGBColor[
             0.7117336636524574, 0.767292245104249, 0.7088283605795754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 107}], {
             RGBColor[
             0.6331941666573614, 0.7096411240717828, 0.9664295076710456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 150}], {
             RGBColor[
             0.7052334721320646, 0.7659434006020812, 0.9337792787070469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 212}], {
             RGBColor[
             0.6366208243691108, 0.7123734479169861, 0.9667563453426058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 270}], {
             RGBColor[
             0.3395664966596175, 0.4629734334045636, 0.9430615702664943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 283}], {
             RGBColor[
             0.33946526561458723`, 0.4628670331578178, 0.9430558053082376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 294}], {
             RGBColor[
             0.5965246264530264, 0.6808665652268485, 0.9628086072419204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 295}], {
             RGBColor[
             0.5137427283706026, 0.6155006793097548, 0.9550335662429597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 320}], {
             RGBColor[
             0.33285194624309083`, 0.4559160151897088, 0.9426791865535602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 347}], {
             RGBColor[
             0.6674676750220885, 0.7369698893122152, 0.9696985454951954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 373}], {
             RGBColor[
             0.5078573593755268, 0.6107226716267005, 0.9545702484368503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 380}], {
             RGBColor[
             0.35171271329930587`, 0.4757398772074908, 0.9437532793354073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 381}], {
             RGBColor[
             0.5038080673458749, 0.6074352739385019, 0.9542514733352306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 390}], {
             RGBColor[
             0.7032051215411821, 0.7644306600525202, 0.9372127471788507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 108}], {
             RGBColor[
             0.7069431761682171, 0.7682282981180384, 0.9456226833691368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 152}], {
             RGBColor[
             0.8141178388048069, 0.8551035295722951, 0.9542175527261756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 154}], {
             RGBColor[
             0.6657705688655409, 0.7325666550678736, 0.9429992012393174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 180}], {
             RGBColor[
             0.6661977404831357, 0.7329366496527645, 0.9430264202370575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 198}], {
             RGBColor[
             0.8257879893428856, 0.8642203398690712, 0.9553807242680539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 236}], {
             RGBColor[
             0.9202593333980197, 0.9384584751976303, 0.9646809369292728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 262}], {
             RGBColor[
             0.7759009583562283, 0.8243735283366511, 0.951006477310862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 267}], {
             RGBColor[
             0.6439962521487426, 0.7137068363367625, 0.9416117610323953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 284}], {
             RGBColor[
             0.7318919352809299, 0.7886450208202276, 0.9475419258040111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 286}], {
             RGBColor[
             0.9143163883180347, 0.933719732107797, 0.9641140935222141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 332}], {
             RGBColor[
             0.9761000377786155, 0.9814524446404015, 0.914432428658175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 72}], {
             RGBColor[
             0.6436904525529263, 0.7169412305229985, 0.9679229319553104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 88}], {
             RGBColor[
             0.8733221857032429, 0.9018274214532846, 0.9877794437679358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 138}], {
             RGBColor[
             0.7185483685381311, 0.7791764288053448, 0.9734120194499124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 157}], {
             RGBColor[
             0.9277308626520705, 0.9443901196191204, 0.9644938684588243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 365}], {
             RGBColor[
             0.55299600548287, 0.6300034304987202, 0.9624508983982609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 88}], {
             RGBColor[
             0.6290991430668942, 0.7053065164093812, 0.9665311998307169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 109}], {
             RGBColor[
             0.5653810777109648, 0.6552163029022884, 0.960263485989135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 157}], {
             RGBColor[
             0.6835078200157217, 0.747869214575217, 0.9432456245216054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 181}], {
             RGBColor[
             0.4609885986399943, 0.5718281677576056, 0.9511138594886037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 191}], {
             RGBColor[
             0.590917445979543, 0.6751655078772887, 0.9628087125272176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 365}], {
             RGBColor[
             0.3087729628465213, 0.4334825254548169, 0.9412026544610419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 370}], {
             RGBColor[
             0.6127614267270469, 0.6922792648754831, 0.9649728938613706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 78}], {
             RGBColor[
             0.603061725987883, 0.6729016324203747, 0.9452269432057808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 99}], {
             RGBColor[
             0.8298964726926286, 0.8675511275641774, 0.9619258132358319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 104}], {
             RGBColor[
             0.9746704435404381, 0.9797238689230927, 0.8871893301537875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 112}], {
             RGBColor[
             0.7548632842832895, 0.8075202810435866, 0.955414204691746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 141}], {
             RGBColor[
             0.9465169116060458, 0.9595720998416382, 0.9733063176493908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 172}], {
             RGBColor[
             0.9671873404153882, 0.9750489527243713, 0.9404274531512267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 177}], {
             RGBColor[
             0.9742251597284544, 0.9795397326235654, 0.8945688352759252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 208}], {
             RGBColor[
             0.8646531517412264, 0.8947033093974863, 0.9653900341837636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 225}], {
             RGBColor[
             0.9160242809441773, 0.9352581038522739, 0.970397903315769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 240}], {
             RGBColor[
             0.8476997422075396, 0.8814591770190856, 0.9637002767600654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 243}], {
             RGBColor[
             0.7589155924577293, 0.8108101273739997, 0.9557332172353319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 285}], {
             RGBColor[
             0.8929585608421292, 0.9168661247451939, 0.9681978743414242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 337}], {
             RGBColor[
             0.6526486959722618, 0.7216131227992155, 0.9481756152189447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 399}], {
             RGBColor[
             0.700897137692533, 0.7634034979801225, 0.9512499632609386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 86}], {
             RGBColor[
             0.8088724235911724, 0.8514657566009493, 0.9813591491321855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 91}], {
             RGBColor[
             0.4567578276517409, 0.5546423169830883, 0.9529459113564194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 95}], {
             RGBColor[
             0.46391790448738757`, 0.5621680117124448, 0.9533536671398251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 104}], {
             RGBColor[
             0.841170307450224, 0.8749221194116908, 0.8956374536228628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 112}], {
             RGBColor[
             0.6213631481930755, 0.7027185315321847, 0.9638623281608214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 141}], {
             RGBColor[
             0.8130167755158317, 0.8547703503302364, 0.9817544411184661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 148}], {
             RGBColor[
             0.4682201556520828, 0.5666899504650182, 0.9535986739790442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 172}], {
             RGBColor[
             0.8336872043251742, 0.8702472032129693, 0.9488755766203021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 179}], {
             RGBColor[
             0.4786930431721801, 0.5776976192680612, 0.954195089430065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 240}], {
             RGBColor[
             0.7141996061173255, 0.7766574275076837, 0.9721484002291407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 263}], {
             RGBColor[
             0.6966627412773865, 0.7629574954096141, 0.9704004894332152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 279}], {
             RGBColor[
             0.6418403544171538, 0.7193428500325194, 0.9654743688452588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 285}], {
             RGBColor[
             0.7594584247519152, 0.8120643752337919, 0.9766459978104995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 399}], {
             RGBColor[
             0.567397001602319, 0.6586017484687207, 0.959698086730014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 105}], {
             RGBColor[
             0.5821974532136336, 0.6688019750660033, 0.9617497198255445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 132}], {
             RGBColor[
             0.5096187011024229, 0.6018814750602282, 0.9572735917971322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 202}], {
             RGBColor[
             0.7148507044853929, 0.7771660705013488, 0.9722132956296095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 215}], {
             RGBColor[
             0.8624088758199515, 0.8927596184029518, 0.9555260212585486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 218}], {
             RGBColor[
             0.6003909331182145, 0.6845602529284629, 0.9629089922772018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 229}], {
             RGBColor[
             0.685735640033093, 0.7540343182656726, 0.9695758645010631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 260}], {
             RGBColor[
             0.796548791428674, 0.8411407731082856, 0.9803159843869597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 329}], {
             RGBColor[
             0.7440093105971186, 0.7999449952094433, 0.9751195529841599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 341}], {
             RGBColor[
             0.6591354326035107, 0.7324390715486491, 0.967481798732436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 349}], {
             RGBColor[
             0.4990550363114689, 0.5907783935899034, 0.9566720067148289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 77}], {
             RGBColor[
             0.43185248857248193`, 0.548112434013099, 0.9488372135358969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 103}], {
             RGBColor[
             0.4215903696797436, 0.5392239024173018, 0.948183320394487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 144}], {
             RGBColor[
             0.6090410701333158, 0.6918130117474302, 0.9635089241653055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 145}], {
             RGBColor[
             0.7304278263553861, 0.784851512566263, 0.847265321043989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 200}], {
             RGBColor[
             0.35236700735248794`, 0.4727457802207713, 0.9440112099982481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 207}], {
             RGBColor[
             0.43006222434892044`, 0.5465617971239461, 0.9487231394826401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 222}], {
             RGBColor[
             0.34282057116665837`, 0.462711870510451, 0.9434675545801519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 333}], {
             RGBColor[
             0.6923786354810615, 0.6456773211334561, 0.6021109446899229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 368}], {
             RGBColor[
             0.499062302289904, 0.604200285356278, 0.9537071590431618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 94}], {
             RGBColor[
             0.4266297860326723, 0.5438724088112132, 0.9484260632605733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 103}], {
             RGBColor[
             0.3869319320938022, 0.5095627246404422, 0.945875938455912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 145}], {
             RGBColor[
             0.6957693887694447, 0.7551903347894033, 0.844957939105414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 200}], {
             RGBColor[
             0.3177085697665465, 0.44308460244391173`, 0.941703828059673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 207}], {
             RGBColor[
             0.39540378676297905`, 0.5169006193470866, 0.946415757544065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 254}], {
             RGBColor[
             0.30763628338150273`, 0.432497990833389, 0.9411302262506571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 333}], {
             RGBColor[
             0.6577201978951202, 0.6160161433565965, 0.5998035627513478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 104}], {
             RGBColor[
             0.6180364536416173, 0.6831637899261797, 0.8793074540098885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 172}], {
             RGBColor[
             0.6105533505165675, 0.6784888737274581, 0.9325455770073277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 194}], {
             RGBColor[
             0.5306728717759631, 0.6158404807752409, 0.959766068135086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 208}], {
             RGBColor[
             0.5080191618424055, 0.5981432304005733, 0.9575081580398646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 217}], {
             RGBColor[
             0.5178044352037279, 0.6057875603212703, 0.9584834626399426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 230}], {
             RGBColor[
             0.5768286785148673, 0.6526029216711309, 0.9641793161361443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 233}], {
             RGBColor[
             0.5591737618791397, 0.6385253703757472, 0.9624953744266984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 240}], {
             RGBColor[
             0.49106575230871885`, 0.5848990980221725, 0.9558184006161664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 242}], {
             RGBColor[
             0.6200940676545046, 0.6827020016061829, 0.7497906061923104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 244}], {
             RGBColor[
             0.6161399275351729, 0.6823795276426672, 0.9107377996459041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 264}], {
             RGBColor[
             0.5703420269462496, 0.6474306417857814, 0.9635606135188273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 285}], {
             RGBColor[
             0.5363245709433084, 0.6203060457482807, 0.9603159981975252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 357}], {
             RGBColor[
             0.3312343183933287, 0.45555850180460344`, 0.9425379016285886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 385}], {
             RGBColor[
             0.36949676762128647`, 0.4876338424347422, 0.9452703987903358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 100}], {
             RGBColor[
             0.46512251022190343`, 0.5755444177251575, 0.9513397844410991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 137}], {
             RGBColor[
             0.405298706955256, 0.5222799882036537, 0.9475808850925993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 175}], {
             RGBColor[
             0.7392060421625427, 0.794769300620199, 0.95311610554616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 213}], {
             RGBColor[
             0.7431585707863845, 0.7628047723967035, 0.6442342696792716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 227}], {
             RGBColor[
             0.369126371311554, 0.48426056998357925`, 0.9455209240898657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[
             0.6530329111925638, 0.7269610652401624, 0.9673594455275031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 278}], {
             RGBColor[
             0.6423148648602819, 0.7185880459852145, 0.9662911708349389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 302}], {
             RGBColor[
             0.7532732337342049, 0.8044563124775064, 0.8932868708649175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 314}], {
             RGBColor[
             0.6842490529733485, 0.751597919586455, 0.9704042859952053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 352}], {
             RGBColor[
             0.6438745872136669, 0.7198065129420077, 0.9664466293826902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 379}], {
             RGBColor[
             0.46129985963058207`, 0.5722334299149601, 0.9510962085256573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 151}], {
             RGBColor[
             0.4798434887371228, 0.5861748089501746, 0.9528636043549448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 168}], {
             RGBColor[
             0.6630210437835282, 0.7304612875539882, 0.9468540031177677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 265}], {
             RGBColor[
             0.5312666703458688, 0.6270633077934322, 0.9574992356228813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 304}], {
             RGBColor[
             0.43184135879408403`, 0.5472045173911052, 0.949084700848233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 378}], {
             RGBColor[
             0.4366147499646207, 0.5510797713821685, 0.9494604796866857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 192}], {
             RGBColor[
             0.5293370940334776, 0.6275403184607296, 0.9564670169788471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 271}], {
             RGBColor[
             0.7838491017020506, 0.7223600632366445, 0.6099467144788709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 287}], {
             RGBColor[
             0.536075454469501, 0.6333767475905699, 0.9568963793473324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 292}], {
             RGBColor[
             0.8211743321657573, 0.8577253161373617, 0.8034426686108029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 374}], {
             RGBColor[
             0.5056979662031231, 0.6070652940711879, 0.954960752656757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 382}], {
             RGBColor[
             0.5319511596256772, 0.6298044906899359, 0.9566335829268546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 384}], {
             RGBColor[
             0.8184086340896232, 0.8572672527198083, 0.89911505645823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 101}], {
             RGBColor[
             0.5227595464833674, 0.6190329945000427, 0.9572373040441238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 136}], {
             RGBColor[
             0.7443055829216539, 0.8001764454011233, 0.9751490826406473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 259}], {
             RGBColor[
             0.5476884235568233, 0.6406251348592771, 0.9588257500475039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 331}], {
             RGBColor[
             0.5848336143067601, 0.6727354164501257, 0.9612100201719305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 335}], {
             RGBColor[
             0.727605322666366, 0.7871300751630135, 0.9734845567712053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 120}], {
             RGBColor[
             0.5625033408729214, 0.6557045784641903, 0.9587014699925984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 187}], {
             RGBColor[
             0.6868689409444824, 0.7550492267685365, 0.9696002368977994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 206}], {
             RGBColor[
             0.4726534739735093, 0.5791335319380123, 0.9526302762294949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 217}], {
             RGBColor[
             0.7073725865578909, 0.7710668305552095, 0.9716438486750818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 220}], {
             RGBColor[
             0.7836792791756038, 0.8315055611970406, 0.9735383572468299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 230}], {
             RGBColor[
             0.7663968298690303, 0.8178821919050699, 0.9773397021712835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 244}], {
             RGBColor[
             0.805708078889336, 0.8476587978766063, 0.9238981856810433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 245}], {
             RGBColor[
             0.6070940858336791, 0.6919053540135017, 0.9622118167771901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 321}], {
             RGBColor[
             0.7794890464023292, 0.7403080185104909, 0.6144737139473101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 328}], {
             RGBColor[
             0.6865199933613283, 0.7547766262644766, 0.9695654570638113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 364}], {
             RGBColor[
             0.636401558474589, 0.7156237240167428, 0.9645701198577037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 102}], {
             RGBColor[
             0.4960421834343109, 0.5860731187114319, 0.9567440082776146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 163}], {
             RGBColor[
             0.3204587185322967, 0.4443657714097614, 0.9419193734117043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 167}], {
             RGBColor[
             0.48880202625418007`, 0.580417052895081, 0.9560223770730147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 174}], {
             RGBColor[
             0.266477435652149, 0.3974150588886406, 0.9384868677911272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 183}], {
             RGBColor[
             0.3140201360826833, 0.43878899490446965`, 0.9415091126314298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 189}], {
             RGBColor[
             0.27975207680097836`, 0.40910772431739617`, 0.9393255821960547]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 222}], {
             RGBColor[
             0.22272321637311115`, 0.3514266002486406, 0.9359951297317528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 226}], {
             RGBColor[
             0.27386059736313456`, 0.40400482094270235`, 0.9389501823359059]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 234}], {
             RGBColor[
             0.26271839143109194`, 0.3934640650751402, 0.9382727957837456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 238}], {
             RGBColor[
             0.20412910744851856`, 0.3318830128342959, 0.9349362227360163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 246}], {
             RGBColor[
             0.24680813116171124`, 0.37674137276325637`, 0.9373667299985251]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 269}], {
             RGBColor[
             0.4472977643716868, 0.5479936080684039, 0.9518856201279471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 272}], {
             RGBColor[
             0.24011838220414106`, 0.36971002245426815`, 0.9369857586919883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 395}], {
             RGBColor[
             0.24234830279729708`, 0.3720538103828067, 0.9371127493708966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 88}], {
             RGBColor[
             0.7560486846604868, 0.8096634223061865, 0.9762364178425269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 162}], {
             RGBColor[
             0.5041357821464535, 0.6054784023571834, 0.9549601696205099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 181}], {
             RGBColor[
             0.5879381402335868, 0.6761850736544108, 0.9608190775004138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 191}], {
             RGBColor[
             0.7178669875731354, 0.7795224137740939, 0.9725139305390277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 211}], {
             RGBColor[
             0.5745019179253128, 0.6652769430896368, 0.9597613288618025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 214}], {
             RGBColor[
             0.4873857356293514, 0.5909703539458863, 0.9538928714679247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 263}], {
             RGBColor[
             0.6769982659761299, 0.7475954578487247, 0.9684405183101557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 307}], {
             RGBColor[
             0.4865547011266964, 0.590250553628695, 0.9538399186842705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 312}], {
             RGBColor[
             0.4604261015099508, 0.56380447817054, 0.9523147057802824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 340}], {
             RGBColor[
             0.7170880815445854, 0.7789139264646855, 0.9724362964653925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 348}], {
             RGBColor[
             0.6598685266388695, 0.734213575287616, 0.966733185979533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 91}], {
             RGBColor[
             0.5729348075366376, 0.6462498611895535, 0.9642999942007744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 93}], {
             RGBColor[
             0.6504775317067343, 0.7215428113512665, 0.9689432930603981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 95}], {
             RGBColor[
             0.5800948843722843, 0.65377555591891, 0.96470774998418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 125}], {
             RGBColor[
             0.9324145641321271, 0.9488408493364346, 0.989767314666812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 148}], {
             RGBColor[
             0.5843971355369796, 0.6582974946714835, 0.9649527568233991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 162}], {
             RGBColor[
             0.6399772373326068, 0.7124479841245379, 0.9682742235879244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 179}], {
             RGBColor[
             0.5948700230570768, 0.6693051634745264, 0.96554917227442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 214}], {
             RGBColor[
             0.6232271908155047, 0.6979399357132408, 0.9672069254353391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 263}], {
             RGBColor[
             0.8128397211622832, 0.8545650396160793, 0.98175457227757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 264}], {
             RGBColor[
             0.9096528606397531, 0.9307965154777578, 0.9912446959761565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 285}], {
             RGBColor[
             0.8756354046368119, 0.9036719194402572, 0.9880000806548546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 119}], {
             RGBColor[
             0.6176783534188905, 0.6933909533197065, 0.9667349819894483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 127}], {
             RGBColor[
             0.8700037369666398, 0.8991813805076085, 0.9874629271650244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 129}], {
             RGBColor[
             0.9561130452991864, 0.964584152561389, 0.8651282447422621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 216}], {
             RGBColor[
             0.7803682156059227, 0.8291376143414176, 0.9785341545446963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 231}], {
             RGBColor[
             0.5806583550600253, 0.6553162926056526, 0.9645961486038584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 235}], {
             RGBColor[
             0.5935209861789246, 0.668835733449532, 0.9653286564175223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 298}], {
             RGBColor[
             0.8155485622170481, 0.8566207684945659, 0.9820406027158624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 313}], {
             RGBColor[
             0.9063755986795785, 0.9281833157496207, 0.9909321078047488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 317}], {
             RGBColor[
             0.7751923911067351, 0.8249479874360208, 0.9781182573507939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 361}], {
             RGBColor[
             0.6186573758358954, 0.6942389333302187, 0.9667973644321444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 393}], {
             RGBColor[
             0.5900556400239414, 0.6651934349250082, 0.9651313100805162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 396}], {
             RGBColor[
             0.7644758373368252, 0.8162478063103624, 0.9772746109819967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 109}], {
             RGBColor[
             0.7950128108612815, 0.8401024938325745, 0.9801199978017605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 157}], {
             RGBColor[
             0.9131395531660385, 0.9327554055055032, 0.9631021363342308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 181}], {
             RGBColor[
             0.690620331790311, 0.7567143586878917, 0.9709703713012292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 191}], {
             RGBColor[
             0.8205491791298596, 0.8600516988075748, 0.982665224339843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 365}], {
             RGBColor[
             0.5384046959968379, 0.618368716385103, 0.9610591662736674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 370}], {
             RGBColor[
             0.8423931598773635, 0.8771654558057691, 0.9848294056739961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 128}], {
             RGBColor[
             0.6651457212229503, 0.7281553283438011, 0.8097227683900547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 133}], {
             RGBColor[
             0.4222208927500507, 0.5386173364459055, 0.9485419893778708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 155}], {
             RGBColor[
             0.3119621939370989, 0.44275086327483293`, 0.9411676534228862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 170}], {
             RGBColor[
             0.4387094508561902, 0.5520034907175473, 0.9498400290715647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 171}], {
             RGBColor[
             0.47225675697213787`, 0.5792387051113916, 0.9524809958968434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 199}], {
             RGBColor[
             0.643761419714683, 0.7143758104256266, 0.9543285904806736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 299}], {
             RGBColor[
             0.4978054133922175, 0.5997079837223303, 0.954678433314889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 306}], {
             RGBColor[
             0.292023756972705, 0.4217943018553364, 0.9400321889340382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 342}], {
             RGBColor[
             0.29311758300195845`, 0.4229439823646577, 0.9400944807082336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 353}], {
             RGBColor[
             0.5251879792226495, 0.6210994522642719, 0.9574076715722399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 121}], {
             RGBColor[
             0.4077482911422045, 0.5179122379352539, 0.9483523274061549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 122}], {
             RGBColor[
             0.40989435891978454`, 0.519654512436345, 0.9485212737229114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.5953720919753789, 0.6661765763320473, 0.952568304339616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 178}], {
             RGBColor[
             0.6155088875089288, 0.680050696781973, 0.8672571851085142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 190}], {
             RGBColor[
             0.3086918978665423, 0.435433615131645, 0.9411234792279346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 212}], {
             RGBColor[
             0.5413093879488278, 0.6234579478622149, 0.9609161114625372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 221}], {
             RGBColor[
             0.27865348319956185`, 0.4094158501217263, 0.9392094580072818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 268}], {
             RGBColor[
             0.31877818446496653`, 0.44416984963169537`, 0.9417661684910332]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 274}], {
             RGBColor[
             0.3724849867520603, 0.4892838988375756, 0.9455762709108226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 295}], {
             RGBColor[
             0.41843129195031953`, 0.5265851792549836, 0.9491933323628912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 319}], {
             RGBColor[
             0.29356786849926475`, 0.4223339410495277, 0.9401597894503058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 324}], {
             RGBColor[
             0.27149743880735244`, 0.4026914004913428, 0.9387727495443868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 351}], {
             RGBColor[
             0.2946347734875073, 0.42325804052613947`, 0.9402277716927295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 373}], {
             RGBColor[
             0.4125459229552436, 0.5218071715719292, 0.9487300145567817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 95}], {
             RGBColor[
             0.22798028843285273`, 0.35695211630104906`, 0.9362945122084139]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 112}], {
             RGBColor[
             0.3854255321385406, 0.49750263612078904`, 0.9468031732294102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 125}], {
             RGBColor[
             0.5802999681926955, 0.6520174097185737, 0.961354076891046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 148}], {
             RGBColor[
             0.232282539597548, 0.36147405505362257`, 0.9365395190476331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 179}], {
             RGBColor[
             0.24275542711764525`, 0.3724817238566655, 0.937135934498654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 257}], {
             RGBColor[
             0.38205736952375124`, 0.4947682099761064, 0.9465380191303878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 263}], {
             RGBColor[
             0.4607251252228516, 0.5577415999982184, 0.953341334501804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 279}], {
             RGBColor[
             0.40590273836261903`, 0.5141269546211237, 0.9484152139138478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 285}], {
             RGBColor[
             0.5235208086973803, 0.6068484798223963, 0.9595868428790885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 288}], {
             RGBColor[
             0.37244486759576767`, 0.4869643478726923, 0.9457812877668622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 135}], {
             RGBColor[
             0.3562795975654801, 0.48301321310313877`, 0.9439227988045624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 165}], {
             RGBColor[
             0.41208644038650016`, 0.5313502954212291, 0.9474787614810645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 182}], {
             RGBColor[
             0.659892973411495, 0.7291234173203918, 0.9666710330217396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 256}], {
             RGBColor[
             0.4570580757992604, 0.5681255638524336, 0.9509457987825457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 281}], {
             RGBColor[
             0.40758839378247225`, 0.527454313531216, 0.9471921499289222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 311}], {
             RGBColor[
             0.49944645367907275`, 0.6025383585899273, 0.9542827671629889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 386}], {
             RGBColor[
             0.687823381506157, 0.7479304779714679, 0.8225265568592857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 98}], {
             RGBColor[
             0.3684828649583397, 0.4935830699647806, 0.9447003802119098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 125}], {
             RGBColor[
             0.657842692362792, 0.7273103598802866, 0.9659973757506697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 148}], {
             RGBColor[
             0.3098252637676446, 0.43676700521533546`, 0.9411828179072568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 162}], {
             RGBColor[
             0.36540536556327186`, 0.49091749466838985`, 0.9445042846717819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 214}], {
             RGBColor[
             0.34865531904616975`, 0.4764094462570928, 0.9434369865191967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 248}], {
             RGBColor[
             0.3459618691338353, 0.4740765153197576, 0.9432653622725071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 276}], {
             RGBColor[
             0.3765521439370048, 0.5005722738423461, 0.9452145475330471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 288}], {
             RGBColor[
             0.4499875917658642, 0.5622572980344052, 0.9504245866264859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 290}], {
             RGBColor[
             0.622162681012604, 0.4977093725413799, 0.5785459335245673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 103}], {
             RGBColor[
             0.41636766713993406`, 0.5349838772154162, 0.9477721701191635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 145}], {
             RGBColor[
             0.7252051238155766, 0.7806114873643772, 0.8468541707686654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 207}], {
             RGBColor[
             0.4248395218091109, 0.5423217719220605, 0.9483119892073164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 254}], {
             RGBColor[
             0.33707201842763457`, 0.4579191434083629, 0.9430264579139087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 125}], {
             RGBColor[
             0.587460045028342, 0.6595431044479301, 0.9617618326744516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 162}], {
             RGBColor[
             0.2950227182288219, 0.4231502392360334, 0.940268741595564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 233}], {
             RGBColor[
             0.5535300764688582, 0.6325934991792193, 0.9621739748916672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 263}], {
             RGBColor[
             0.46788520205849826`, 0.5652672947275748, 0.9537490902852097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 264}], {
             RGBColor[
             0.5646983415359681, 0.6414987705892532, 0.9632392139837961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 285}], {
             RGBColor[
             0.530680885533027, 0.6143741745517527, 0.959994598662494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 312}], {
             RGBColor[
             0.25131303759231916`, 0.38147631504939006`, 0.9376232777553364]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 173}], {
             RGBColor[
             0.7987818066060666, 0.8402827088392839, 0.8500694270908953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 201}], {
             RGBColor[
             0.8932562526100338, 0.9146911821821211, 0.8590725813745876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 209}], {
             RGBColor[
             0.9491315556239038, 0.9590173022018074, 0.8644623440245842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 223}], {
             RGBColor[
             0.6975906175469653, 0.7566977431776174, 0.8424993386405469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 245}], {
             RGBColor[
             0.791639190473091, 0.8344840112913443, 0.8495071341846425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 323}], {
             RGBColor[
             0.934683359801191, 0.9474967030386041, 0.8630842622089572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 109}], {
             RGBColor[
             0.7046186655866328, 0.7691727239472617, 0.971193461616021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 181}], {
             RGBColor[
             0.6002261865156623, 0.6857845888025789, 0.9620438351154897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 191}], {
             RGBColor[
             0.730155033855211, 0.789121928922262, 0.9737386881541036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 193}], {
             RGBColor[
             0.6254018122999044, 0.7062232959632435, 0.9640257525985811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 211}], {
             RGBColor[
             0.5867899642073882, 0.6748764582378048, 0.9609860864768784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 214}], {
             RGBColor[
             0.49967378191142686`, 0.6005698690940544, 0.9551176290830006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 248}], {
             RGBColor[
             0.4969803319990925, 0.5982369381567192, 0.954946004836311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 305}], {
             RGBColor[
             0.753252826511744, 0.8072354415028984, 0.9760224591874309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 334}], {
             RGBColor[
             0.784135688208204, 0.8318605971267068, 0.9789680941054955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 340}], {
             RGBColor[
             0.7293761278266608, 0.7885134416128536, 0.9736610540804684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 360}], {
             RGBColor[
             0.7288832978652589, 0.7881284391013599, 0.9736119333956736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 370}], {
             RGBColor[
             0.7519990146027149, 0.8062356859204562, 0.9759028694882567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 125}], {
             RGBColor[
             0.6504198973837325, 0.7208811079499486, 0.9655244018183238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 139}], {
             RGBColor[
             0.27017261448779284`, 0.39646213292407584`, 0.9388744014522774]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 193}], {
             RGBColor[
             0.46696055445558776`, 0.5756336211959441, 0.9518721361024316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 204}], {
             RGBColor[
             0.3648327921318383, 0.4904215603404596, 0.9444678007990378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 248}], {
             RGBColor[
             0.3385390741547758, 0.4676472633894197, 0.9427923883401612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 276}], {
             RGBColor[
             0.36912934895794525`, 0.4941430219120083, 0.9447415736007013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 290}], {
             RGBColor[
             0.6147398860335445, 0.49128012061104204`, 0.5780729595922216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 318}], {
             RGBColor[
             0.3905617644494942, 0.5127067029862638, 0.9461072281638819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 141}], {
             RGBColor[
             0.8167176684119706, 0.8576615159885278, 0.9821233115355428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 169}], {
             RGBColor[
             0.8454802406646742, 0.8732411440525798, 0.694874347562541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 177}], {
             RGBColor[
             0.844425916534379, 0.8776291487704551, 0.9033858291620773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 197}], {
             RGBColor[
             0.5587750954302315, 0.6508195249360045, 0.9592817592870866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 225}], {
             RGBColor[
             0.7862250377501021, 0.8333475199991636, 0.979214897201921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 243}], {
             RGBColor[
             0.629116349263654, 0.7088995435208894, 0.9645502111214839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 252}], {
             RGBColor[
             0.49432856634598865`, 0.5931328380474481, 0.9552436193857518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 300}], {
             RGBColor[
             0.8214316039643914, 0.8612380423266085, 0.9762546280013872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 337}], {
             RGBColor[
             0.5228494527781866, 0.6197025389461052, 0.9569926091050968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 367}], {
             RGBColor[
             0.6075587354116121, 0.6913981014363648, 0.9628531167909097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 398}], {
             RGBColor[
             0.8447848421289379, 0.8777775737277721, 0.8974375031905741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 146}], {
             RGBColor[
             0.4760315267050658, 0.5844008487517809, 0.9521985821796978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 175}], {
             RGBColor[
             0.6868151487259421, 0.7511339976854048, 0.9492961926557498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 213}], {
             RGBColor[
             0.6907676773497838, 0.7191694694619093, 0.6404143567888614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 227}], {
             RGBColor[
             0.3167354778749534, 0.440625267048785, 0.9417010111994555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 278}], {
             RGBColor[
             0.5899239714236812, 0.6749527430504203, 0.9624712579445287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 302}], {
             RGBColor[
             0.7008823402976042, 0.7608210095427121, 0.8894669579745074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 314}], {
             RGBColor[
             0.6318581595367478, 0.7079626166516608, 0.9665843731047952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 352}], {
             RGBColor[
             0.5914836937770662, 0.6761712100072135, 0.96262671649228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 377}], {
             RGBColor[
             0.7029706865890015, 0.7598968976251583, 0.7249109716506204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 136}], {
             RGBColor[
             0.553036719353394, 0.642685752061144, 0.9602550496795408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 301}], {
             RGBColor[
             0.3042039415135965, 0.4349651072076972, 0.9407123340079452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 335}], {
             RGBColor[
             0.5363364590981061, 0.6296393818230341, 0.9585905238100989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 394}], {
             RGBColor[
             0.2833155240918034, 0.4130100560952344, 0.9395227695374184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 163}], {
             RGBColor[
             0.5901846853952787, 0.6752358188548556, 0.962463635911645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 167}], {
             RGBColor[
             0.758527993117162, 0.8112871003401753, 0.9765666395729555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 174}], {
             RGBColor[
             0.536203402515131, 0.6282851063337348, 0.9590311302910679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 189}], {
             RGBColor[
             0.5494780436639604, 0.6399777717624904, 0.9598698446959953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 222}], {
             RGBColor[
             0.4924491832360931, 0.5822966476937348, 0.9565393922316936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 226}], {
             RGBColor[
             0.5435865642261165, 0.6348748683877966, 0.9594944448358467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 395}], {
             RGBColor[
             0.512074269660279, 0.602923857827901, 0.9576570118708373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 145}], {
             RGBColor[
             0.6855072698767064, 0.7463018031936062, 0.8443040459640041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 200}], {
             RGBColor[
             0.30744645087380823`, 0.4341960708481146, 0.9410499349182633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 207}], {
             RGBColor[
             0.38514166787024073`, 0.5080120877512895, 0.9457618644026551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 222}], {
             RGBColor[
             0.29790001468797866`, 0.4241621611377943, 0.940506279500167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 254}], {
             RGBColor[
             0.29737416448876447`, 0.42360945923759186`, 0.9404763331092474]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 333}], {
             RGBColor[
             0.6474580790023818, 0.6071276117607993, 0.5991496696099379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 112}], {
             RGBColor[
             0.7698380119370238, 0.8177824385493915, 0.8894947154958537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 141}], {
             RGBColor[
             0.9614916392597801, 0.9698342573474432, 0.9073868284534985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 172}], {
             RGBColor[
             0.9821620680691225, 0.9853111102301761, 0.8745079639553344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 208}], {
             RGBColor[
             0.8796278793949606, 0.9049654669032913, 0.8994705449878713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 240}], {
             RGBColor[
             0.8626744698612738, 0.8917213345248906, 0.8977807875641731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 242}], {
             RGBColor[
             0.9917027852070597, 0.9895242381089009, 0.6917529931403171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 243}], {
             RGBColor[
             0.7738903201114635, 0.8210722848798047, 0.8898137280394396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 285}], {
             RGBColor[
             0.9079332884958635, 0.9271282822509987, 0.9022783851455319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 337}], {
             RGBColor[
             0.6676234236259961, 0.7318752803050205, 0.8822561260230524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 357}], {
             RGBColor[
             0.7028430359458837, 0.7623807383073214, 0.8845002885765954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 399}], {
             RGBColor[
             0.7158718653462673, 0.7736656554859275, 0.8853304740650463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 114}], {
             RGBColor[
             0.5458250900609658, 0.6403876085309408, 0.9581244625855454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 171}], {
             RGBColor[
             0.5095325837513189, 0.6115251527299888, 0.9548561786174935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 202}], {
             RGBColor[
             0.5426829526739785, 0.6379329469230977, 0.957811283695754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 218}], {
             RGBColor[
             0.4282231813068001, 0.5453271293502118, 0.9485069803433461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 229}], {
             RGBColor[
             0.5135678882216785, 0.6148011946874214, 0.9551738525672075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 261}], {
             RGBColor[
             0.3648863052759247, 0.49046791073621837`, 0.9444712106092592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 349}], {
             RGBColor[
             0.32688728450005455`, 0.45154527001165223`, 0.9422699947809734]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 353}], {
             RGBColor[
             0.5624638060018305, 0.653385899882869, 0.9597828542928899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.9143643030921367, 0.9295791498270195, 0.7266017631353201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 150}], {
             RGBColor[
             0.9864036085668397, 0.9858814263573179, 0.6939515341713214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 158}], {
             RGBColor[
             0.6472160593950517, 0.7107430150943885, 0.7047417898857905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 241}], {
             RGBColor[
             0.7895593019872595, 0.8310924415939867, 0.7147843696314451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 270}], {
             RGBColor[
             0.6207366330943928, 0.6829114591598003, 0.7032338257307688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 292}], {
             RGBColor[
             0.993695522932494, 0.9889236859700412, 0.5551747618035211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 310}], {
             RGBColor[
             0.8905128586787707, 0.9108181848351266, 0.7242584507027232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 320}], {
             RGBColor[
             0.6140220826778661, 0.6758540409449456, 0.7028514420178348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 347}], {
             RGBColor[
             0.9486378114568637, 0.956907915067452, 0.7298708009594699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 374}], {
             RGBColor[
             0.6782191569698599, 0.7382636639038674, 0.706692845849475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 384}], {
             RGBColor[
             0.9909298248563598, 0.9884656225524878, 0.650847149650948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 389}], {
             RGBColor[
             0.9175855552158254, 0.9321476888318894, 0.7269090090385233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 390}], {
             RGBColor[
             0.9843752579759573, 0.9843686858077569, 0.6973850026431253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 158}], {
             RGBColor[
             0.5686765623999557, 0.6530918940619224, 0.9623429369772607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 190}], {
             RGBColor[
             0.6066339737265046, 0.6866360199091868, 0.9647371156637479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 212}], {
             RGBColor[
             0.83925146380879, 0.8746603526397566, 0.9845297478983503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 241}], {
             RGBColor[
             0.7110198049921634, 0.7734413205615205, 0.9723855167229153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 268}], {
             RGBColor[
             0.6167202603249289, 0.6953722544092371, 0.9653798049268464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 270}], {
             RGBColor[
             0.5421971360992967, 0.6252603381273342, 0.960834972822239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 295}], {
             RGBColor[
             0.7163733678102818, 0.7777875840325255, 0.9728069687987043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 310}], {
             RGBColor[
             0.8119733616836746, 0.8531670638026604, 0.9818595977941933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 324}], {
             RGBColor[
             0.5694395146673148, 0.6538938052688845, 0.9623863859802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 346}], {
             RGBColor[
             0.8077632897146634, 0.8498781235827368, 0.9814399771656817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 351}], {
             RGBColor[
             0.5925768493474696, 0.6744604453036813, 0.9638414081285427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 373}], {
             RGBColor[
             0.710487998815206, 0.7730095763494711, 0.9723436509925949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 390}], {
             RGBColor[
             0.9058357609808612, 0.9267175647752908, 0.9549861497345955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 152}], {
             RGBColor[
             0.5545191038691664, 0.648764235089708, 0.9583202394745891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 154}], {
             RGBColor[
             0.4061718339299003, 0.5262273605852865, 0.947101887987731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 180}], {
             RGBColor[
             0.40659900554749523`, 0.5265973551701775, 0.947129106985471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 198}], {
             RGBColor[
             0.566189254407245, 0.6578810453864843, 0.9594834110164675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 205}], {
             RGBColor[
             0.634266869039416, 0.711073537311872, 0.9662661662033638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 236}], {
             RGBColor[
             0.6606605984623791, 0.7321191807150433, 0.9687836236776863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 262}], {
             RGBColor[
             0.5163022234205877, 0.6180342338540641, 0.9551091640592755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 267}], {
             RGBColor[
             0.3843975172131021, 0.5073675418541754, 0.9457144477808088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 284}], {
             RGBColor[
             0.4722932003452894, 0.5823057263376407, 0.9516446125524247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 286}], {
             RGBColor[
             0.6547176533823942, 0.72738043762521, 0.9682167802706276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 332}], {
             RGBColor[
             0.716501302842975, 0.7751131501578146, 0.9185351154065886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 367}], {
             RGBColor[
             0.4811823412786237, 0.589522331398557, 0.952344398288693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 398}], {
             RGBColor[
             0.7184084479959496, 0.7759018036899643, 0.8869287846883573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 157}], {
             RGBColor[
             0.849421487810109, 0.8826651919984103, 0.956834422492649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 181}], {
             RGBColor[
             0.6269022664343815, 0.7066241451807989, 0.9647026574596475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 191}], {
             RGBColor[
             0.7568311137739301, 0.809961485300482, 0.9763975104982613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 305}], {
             RGBColor[
             0.7799289064304631, 0.8280749978811184, 0.9786812815315886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 334}], {
             RGBColor[
             0.8108117681269231, 0.8527001535049267, 0.9816269164496532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 340}], {
             RGBColor[
             0.7560522077453801, 0.8093529979910735, 0.9763198764246261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 360}], {
             RGBColor[
             0.755559377783978, 0.8089679954795798, 0.9762707557398314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 365}], {
             RGBColor[
             0.4746866306409085, 0.5682785028780101, 0.9547914524320856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 370}], {
             RGBColor[
             0.7786750945214341, 0.8270752422986762, 0.9785616918324144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 227}], {
             RGBColor[
             0.6077471977598151, 0.6702656702802814, 0.8031903043904077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 237}], {
             RGBColor[
             0.6388680905477557, 0.7029757017789752, 0.8049625931954458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 251}], {
             RGBColor[
             0.8264603990255699, 0.8620366339229024, 0.8185309631012643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 308}], {
             RGBColor[
             0.8216944179771022, 0.8583134133050419, 0.8180559346509781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 375}], {
             RGBColor[
             0.7857509131921534, 0.8292289785017404, 0.815160611414018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 116}], {
             RGBColor[
             0.37922243140059736`, 0.5028851426307598, 0.9453846958889847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 151}], {
             RGBColor[
             0.45692765137567454`, 0.5663262624111636, 0.9514034274619526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 154}], {
             RGBColor[
             0.34162825354962734`, 0.47032295531456914`, 0.9429892281195471]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 286}], {
             RGBColor[
             0.5901740730021212, 0.6714760323544926, 0.9641041204024439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 291}], {
             RGBColor[
             0.4663221441467543, 0.5739531348598025, 0.9521429963460529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 304}], {
             RGBColor[
             0.40892552143263583`, 0.5273559708520941, 0.9476245239552408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 383}], {
             RGBColor[
             0.654497589090739, 0.7202590450093853, 0.8723302925477021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 141}], {
             RGBColor[
             0.7416844800026314, 0.797630669467937, 0.9756117029914569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 172}], {
             RGBColor[
             0.7623549088119739, 0.8131075223506701, 0.9427328384932929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 179}], {
             RGBColor[
             0.4073607476589798, 0.5205579384057619, 0.9480523513030559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 240}], {
             RGBColor[
             0.6428673106041253, 0.7195177466453844, 0.9660056621021316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 279}], {
             RGBColor[
             0.5705080589039535, 0.66220316917022, 0.9593316307182497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 285}], {
             RGBColor[
             0.6881261292387149, 0.7549246943714927, 0.9705032596834904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 337}], {
             RGBColor[
             0.44781626436884747`, 0.5596716924255144, 0.9504810005610109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 399}], {
             RGBColor[
             0.49606470608911873`, 0.6014620676064213, 0.9535553486030048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 124}], {
             RGBColor[
             0.5982905672011287, 0.6779479045124154, 0.9648782788648251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 149}], {
             RGBColor[
             0.7278295649311898, 0.7867807137235743, 0.9740628008000485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 210}], {
             RGBColor[
             0.8763733076815712, 0.7142402647772274, 0.6025920600596766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 249}], {
             RGBColor[
             0.6169217225220367, 0.6940852748222915, 0.9660654396069897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 266}], {
             RGBColor[
             0.9035575392781542, 0.9259362716771096, 0.9906633187833296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 293}], {
             RGBColor[
             0.6359686882348221, 0.7105827991943741, 0.9672790954196377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 315}], {
             RGBColor[
             0.9183572490951032, 0.9371520035328749, 0.9717872362724985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 316}], {
             RGBColor[
             0.8898594151524762, 0.9150137593249681, 0.9893567794757627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 387}], {
             RGBColor[
             0.936405549853991, 0.9482163585057054, 0.8148027074558298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 397}], {
             RGBColor[
             0.5761223439232968, 0.6555270791669277, 0.9635836328296105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 128}], {
             RGBColor[
             0.8382169366608779, 0.8712605330055869, 0.8228747058045613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 155}], {
             RGBColor[
             0.48503340937502654`, 0.5858560679366188, 0.9543195908373928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 170}], {
             RGBColor[
             0.6117806662941179, 0.6951086953793331, 0.9629919664860713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 187}], {
             RGBColor[
             0.7148971609056444, 0.7772023626099311, 0.9722179259714203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 202}], {
             RGBColor[
             0.6784783413327251, 0.7487517039662863, 0.9685880383896105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 261}], {
             RGBColor[
             0.5006816939346713, 0.6012866677794071, 0.9552479653031158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 306}], {
             RGBColor[
             0.4650949724106326, 0.5648995065171223, 0.9531841263485448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 353}], {
             RGBColor[
             0.6982591946605772, 0.7642046569260578, 0.9705596089867465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 122}], {
             RGBColor[
             0.7861939290422392, 0.8281187528046128, 0.6947238888140113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 166}], {
             RGBColor[
             0.9716716620978334, 0.9746408167003149, 0.6987709194307159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 169}], {
             RGBColor[
             0.9917015232264101, 0.9836467221850489, 0.4241933777702308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 197}], {
             RGBColor[
             0.7049963779919675, 0.7612251030684736, 0.6886007894947765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 221}], {
             RGBColor[
             0.6549530533220165, 0.717880090489994, 0.6854120730983817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 239}], {
             RGBColor[
             0.9476164373495731, 0.8187427639311557, 0.3349489635769477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 300}], {
             RGBColor[
             0.9676528865261274, 0.9716436204590776, 0.705573658209077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 350}], {
             RGBColor[
             0.8311509840465656, 0.8641971336817327, 0.6985500798858739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 392}], {
             RGBColor[
             0.5857333973110126, 0.6459228499880025, 0.6814409337686818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 151}], {
             RGBColor[
             0.5178928023042412, 0.6191312119479068, 0.9552880729697546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 154}], {
             RGBColor[
             0.402593404478194, 0.5231279048513123, 0.9468738736273492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 265}], {
             RGBColor[
             0.5693159839129872, 0.6600197107911643, 0.9599237042376911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 291}], {
             RGBColor[
             0.5272872950753209, 0.6267580843965457, 0.9560276418538549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 304}], {
             RGBColor[
             0.4698906723612024, 0.5801609203888374, 0.9515091694630429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 383}], {
             RGBColor[
             0.7154627400193055, 0.7730639945461286, 0.8762149380555041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 289}], {
             RGBColor[
             0.646694243065709, 0.7197241846855587, 0.9680309044840116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 303}], {
             RGBColor[
             0.9196276844025142, 0.93821088772666, 0.9734988768118391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 376}], {
             RGBColor[
             0.7095933744198643, 0.771944494279485, 0.9726631589911512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 158}], {
             RGBColor[
             0.44082240511635346`, 0.55212974348008, 0.9502855027295694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 164}], {
             RGBColor[
             0.6373599604741271, 0.7156762364824534, 0.9651416391019421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 173}], {
             RGBColor[
             0.5915129283328785, 0.6792558684312056, 0.9609852109830666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 209}], {
             RGBColor[
             0.7418626773507158, 0.797990461793729, 0.9753781279167555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 241}], {
             RGBColor[
             0.5831656477085613, 0.672479169979678, 0.9603280824752239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 323}], {
             RGBColor[
             0.7274144815280029, 0.7864698626305258, 0.9740000461011284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 346}], {
             RGBColor[
             0.6799091324310612, 0.7489159730008944, 0.9693825429179903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 354}], {
             RGBColor[
             0.6700622275960664, 0.7412234961045479, 0.9684010954685955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 388}], {
             RGBColor[
             0.7432841673998132, 0.7991239193735598, 0.9755137109066175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 389}], {
             RGBColor[
             0.7111919009371273, 0.7735344172175809, 0.972452721882302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 126}], {
             RGBColor[
             0.3205055165224079, 0.4520275021612237, 0.9416433059942757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 127}], {
             RGBColor[
             0.5701102478633697, 0.6554614371515624, 0.9621978936170137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 129}], {
             RGBColor[
             0.6562195561959163, 0.7208642092053428, 0.8398632111942512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 196}], {
             RGBColor[
             0.29697512309611795`, 0.4286343572927416, 0.940254265219008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 231}], {
             RGBColor[
             0.28076486595675515`, 0.41159634924960636`, 0.9393311150558477]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 235}], {
             RGBColor[
             0.2936274970756545, 0.42511579009348577`, 0.9400636228695115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 317}], {
             RGBColor[
             0.475298902003465, 0.5812280440799746, 0.9528532238027831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 326}], {
             RGBColor[
             0.30074699672292693`, 0.43259883562511847`, 0.9404690678420677]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 327}], {
             RGBColor[
             0.35444107955751225`, 0.48142078121123894`, 0.9438056500628325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 336}], {
             RGBColor[
             0.28795605993494505`, 0.4191547500687165, 0.9397406429144874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 396}], {
             RGBColor[
             0.46458234823355515`, 0.5725278629543162, 0.9520095774339858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 132}], {
             RGBColor[
             0.3821574200641262, 0.5001184572566213, 0.9460662763439505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 160}], {
             RGBColor[
             0.42049650328790067`, 0.5373822770078959, 0.9483606829478057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 187}], {
             RGBColor[
             0.6238082430200154, 0.7038537113413867, 0.9646358677582376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 202}], {
             RGBColor[
             0.5873894234470962, 0.6754030526977419, 0.9610059801764278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 206}], {
             RGBColor[
             0.4095927760490423, 0.5279380165108627, 0.9476659070899331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 217}], {
             RGBColor[
             0.6443118886334239, 0.7198713151280598, 0.96667947953552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 220}], {
             RGBColor[
             0.7206185812511368, 0.7803100457698908, 0.9685739881072681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 233}], {
             RGBColor[
             0.6856812153088357, 0.7526091251825368, 0.9706913913222758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 244}], {
             RGBColor[
             0.742647380964869, 0.7964632824494566, 0.9189338165414815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 307}], {
             RGBColor[
             0.4095927760490423, 0.5279380165108627, 0.9476659070899331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 321}], {
             RGBColor[
             0.7164283484778622, 0.6891125030833413, 0.6095093448077483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 341}], {
             RGBColor[
             0.5316741515652139, 0.6306760537450422, 0.9562744832792542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 366}], {
             RGBColor[
             0.4418240319991681, 0.5558551104248343, 0.9497196542180946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 122}], {
             RGBColor[
             0.577701995684873, 0.6680435311321292, 0.9598979637739025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 175}], {
             RGBColor[
             0.7682273042869372, 0.8183300686057422, 0.9554007656089784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 178}], {
             RGBColor[
             0.7833165242740174, 0.8284397154777572, 0.8786338751595053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.772179832910779, 0.7863655403822467, 0.6465189297420899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 274}], {
             RGBColor[
             0.5402926235171488, 0.6376729175333598, 0.9569529609618137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 296}], {
             RGBColor[
             0.47190871499229364`, 0.5798462965971395, 0.9522076463110096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 319}], {
             RGBColor[
             0.46137550526435334`, 0.570722959745312, 0.9515364795012968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 373}], {
             RGBColor[
             0.5803535597203322, 0.6701961902677134, 0.9601067046077728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 166}], {
             RGBColor[
             0.7653257965180473, 0.8163078695289225, 0.9641139407073636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 169}], {
             RGBColor[
             0.7853556576466241, 0.8253137750136565, 0.6895363990468784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 175}], {
             RGBColor[
             0.7703733720645172, 0.8200723431068333, 0.9555697119257347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 178}], {
             RGBColor[
             0.7854625920515974, 0.8301819899788483, 0.8788028214762617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 268}], {
             RGBColor[
             0.4887318890076351, 0.5943011428285707, 0.9533118048587806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 274}], {
             RGBColor[
             0.5424386912947289, 0.6394151920344509, 0.95712190727857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 319}], {
             RGBColor[
             0.4635215730419333, 0.572465234246403, 0.9517054258180533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 351}], {
             RGBColor[
             0.46458847803017583`, 0.5733893337230148, 0.9517734080604769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 131}], {
             RGBColor[
             0.6251549552231738, 0.6524710937679776, 0.6242110091103918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 140}], {
             RGBColor[
             0.6234396922326402, 0.6506682436109719, 0.624113327420585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 203}], {
             RGBColor[
             0.7423874002126478, 0.7540721753354385, 0.6321276983509541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 232}], {
             RGBColor[
             0.6955697690191924, 0.7153941424196474, 0.6286269920719472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 275}], {
             RGBColor[
             0.6127840830706675, 0.6394685227770966, 0.6235065062423719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 280}], {
             RGBColor[
             0.6283869078214809, 0.6558680808664286, 0.6243950640296201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 297}], {
             RGBColor[
             0.6694003660648966, 0.6927275208930733, 0.6269595008563937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 309}], {
             RGBColor[
             0.7925513380885254, 0.794797519962724, 0.6360767872971023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 322}], {
             RGBColor[
             0.9629993043636109, 0.9286976479100049, 0.627673116589561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 325}], {
             RGBColor[
             0.6135822966821, 0.6403074958923781, 0.6235519633266917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 339}], {
             RGBColor[
             0.9742187238286566, 0.9367707625747814, 0.5955017627220192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 149}], {
             RGBColor[
             0.4477962782020918, 0.5589130023051755, 0.9506845723164061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 185}], {
             RGBColor[
             0.6147272173143388, 0.5678567658294686, 0.5944527000130833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 210}], {
             RGBColor[
             0.5963400209524732, 0.48637255335882856`, 0.5792138315760342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 219}], {
             RGBColor[
             0.46776915776087524`, 0.5751278856989663, 0.952256910558342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 249}], {
             RGBColor[
             0.3368884357929387, 0.46621756340389275`, 0.9426872111233472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 266}], {
             RGBColor[
             0.6235242525490562, 0.6980685602587108, 0.9672850902996872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 293}], {
             RGBColor[
             0.3559354015057241, 0.48271508777597516`, 0.9439008669359954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 315}], {
             RGBColor[
             0.6383239623660052, 0.709284292114476, 0.9484090077888561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 316}], {
             RGBColor[
             0.6098261284233782, 0.6871460479065693, 0.9659785509921204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 338}], {
             RGBColor[
             0.2982549578394379, 0.42993586665270767`, 0.9403287491835516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 387}], {
             RGBColor[
             0.656372263124893, 0.7203486470873066, 0.7914244789721874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 397}], {
             RGBColor[
             0.29608905719419876`, 0.42765936774852886`, 0.940205404345968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 148}], {
             RGBColor[
             0.5917622961930373, 0.6640650432005035, 0.9620068395136707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 162}], {
             RGBColor[
             0.6473423979886647, 0.718215532653558, 0.965328306278196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 211}], {
             RGBColor[
             0.7177085337675239, 0.7780140733860115, 0.9701294655194885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 214}], {
             RGBColor[
             0.6305923514715626, 0.7037074842422609, 0.9642610081256108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 248}], {
             RGBColor[
             0.6278989015592281, 0.7013745533049257, 0.9640893838789211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 263}], {
             RGBColor[
             0.820204881818341, 0.8603325881450994, 0.9788086549678416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 276}], {
             RGBColor[
             0.6584891763623976, 0.7278703118275143, 0.9660385691394611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 288}], {
             RGBColor[
             0.731924624191257, 0.7895553360195733, 0.9712486082328999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 196}], {
             RGBColor[
             0.2996957753029055, 0.4309908494903051, 0.9404276227718462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 289}], {
             RGBColor[
             0.36698550290677007`, 0.4922861302153159, 0.944604969626049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 317}], {
             RGBColor[
             0.4780195542102525, 0.583584536277538, 0.9530265813556213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 326}], {
             RGBColor[
             0.30346764892971445`, 0.434955327822682, 0.940642425394906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 327}], {
             RGBColor[
             0.3571617317642998, 0.4837772734088024, 0.9439790076156707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 336}], {
             RGBColor[
             0.2906767121417326, 0.4215112422662799, 0.9399140004673256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 376}], {
             RGBColor[
             0.4298846342609254, 0.5445064398092422, 0.9492372241331888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 129}], {
             RGBColor[
             0.9085449397436656, 0.9266546363932447, 0.8605911563698274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 216}], {
             RGBColor[
             0.7328001100504019, 0.7912080981732734, 0.9739970661722617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 231}], {
             RGBColor[
             0.5330902495045045, 0.6173867764375084, 0.9600590602314238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 235}], {
             RGBColor[
             0.5459528806234037, 0.6309062172813877, 0.9607915680450876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 298}], {
             RGBColor[
             0.7679804566615273, 0.8186912523264218, 0.9775035143434276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 313}], {
             RGBColor[
             0.8588074931240577, 0.8902537995814764, 0.9863950194323141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 317}], {
             RGBColor[
             0.7276242855512143, 0.7870184712678767, 0.9735811689783593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 336}], {
             RGBColor[
             0.5402814434826944, 0.6249451772566185, 0.9604685880900636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 361}], {
             RGBColor[
             0.5710892702803746, 0.6563094171620745, 0.9622602760597097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 393}], {
             RGBColor[
             0.5424875344684206, 0.6272639187568639, 0.9605942217080816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 396}], {
             RGBColor[
             0.7169077317813044, 0.7783182901422182, 0.972737522609562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 133}], {
             RGBColor[
             0.7518885661291439, 0.8017767085391487, 0.8156674153175367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 155}], {
             RGBColor[
             0.641629867316192, 0.7059102353680763, 0.8082930793625521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 170}], {
             RGBColor[
             0.7683771242352833, 0.8151628628107905, 0.8169654550112306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 171}], {
             RGBColor[
             0.801924430351231, 0.8423980772046349, 0.8196064218365093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 199}], {
             RGBColor[
             0.9734290930937761, 0.9775351825188698, 0.8214540164203396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 261}], {
             RGBColor[
             0.6572781518758368, 0.7213408352108646, 0.8092214538282752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 299}], {
             RGBColor[
             0.8274730867713107, 0.8628673558155735, 0.8218038592545549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 306}], {
             RGBColor[
             0.6216914303517981, 0.6849536739485798, 0.8071576148737041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 342}], {
             RGBColor[
             0.6227852563810515, 0.6861033544579009, 0.8072199066478996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 353}], {
             RGBColor[
             0.8548556526017427, 0.8842588243575152, 0.8245330975119058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 216}], {
             RGBColor[
             0.8189094183829486, 0.8566108702270538, 0.8516623837494992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 231}], {
             RGBColor[
             0.619199557837051, 0.6827895484912888, 0.8377243778086614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 235}], {
             RGBColor[
             0.6320621889559505, 0.6963089893351682, 0.8384568856223253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 298}], {
             RGBColor[
             0.854089764994074, 0.8840940243802022, 0.8551688319206653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 313}], {
             RGBColor[
             0.9449168014566043, 0.9556565716352569, 0.8640603370095518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 317}], {
             RGBColor[
             0.8137335938837609, 0.8524212433216571, 0.8512464865555969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 336}], {
             RGBColor[
             0.626390751815241, 0.6903479493103989, 0.8381339056673012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 361}], {
             RGBColor[
             0.6571985786129212, 0.7217121892158549, 0.8399255936369473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 393}], {
             RGBColor[
             0.6285968428009672, 0.6926666908106444, 0.8382595392853192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 396}], {
             RGBColor[
             0.8030170401138511, 0.8437210621959986, 0.8504028401867997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 147}], {
             RGBColor[
             0.8701949056131535, 0.8949524768469418, 0.7227805048795846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 164}], {
             RGBColor[
             0.7210396886718431, 0.7820009519858256, 0.9728301557339694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 287}], {
             RGBColor[
             0.5858827191552555, 0.6722865613123132, 0.9618607020158565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 371}], {
             RGBColor[
             0.46564068143209897`, 0.5565873410239002, 0.9546219467546331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 391}], {
             RGBColor[
             0.5851236338180522, 0.6716290797459662, 0.9618123337694027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 140}], {
             RGBColor[
             0.28612069672969853`, 0.41806137173583147`, 0.939605522449893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 186}], {
             RGBColor[
             0.44307840002079313`, 0.5523235299846136, 0.9506121794463512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 188}], {
             RGBColor[
             0.32619283687688816`, 0.4550202971062367, 0.9420764837263151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 203}], {
             RGBColor[
             0.4050684047097061, 0.5214653034602981, 0.947619893380262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 228}], {
             RGBColor[
             0.4708795418192703, 0.5747166016942085, 0.9529219039694972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 238}], {
             RGBColor[
             0.23488897902297018`, 0.3642135881475457, 0.9366879519170292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 273}], {
             RGBColor[
             0.6410261771785397, 0.7049509998851411, 0.7757858182572592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 280}], {
             RGBColor[
             0.29106791231853923`, 0.4232612089912882, 0.939887259058928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 309}], {
             RGBColor[
             0.45523234258558376`, 0.5621906480875837, 0.9515689823264102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 322}], {
             RGBColor[
             0.6256803088606693, 0.6960907760348646, 0.943165311618869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 325}], {
             RGBColor[
             0.2762633011791583, 0.4077006240172378, 0.9390441583559996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 330}], {
             RGBColor[
             0.2614881624943658, 0.39217101646162134`, 0.9382027360657597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 339}], {
             RGBColor[
             0.636899728325715, 0.704163890699641, 0.9109939577513271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 160}], {
             RGBColor[
             0.3032112804035724, 0.43299167122747656`, 0.9406898584387196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 202}], {
             RGBColor[
             0.4701042005627679, 0.5710124469173227, 0.9533351556673416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 220}], {
             RGBColor[
             0.6033333583668086, 0.6759194399894715, 0.960903163598182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 244}], {
             RGBColor[
             0.6253621580805407, 0.6920726766690373, 0.9112629920323954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 260}], {
             RGBColor[
             0.551802287506049, 0.6349871495242595, 0.9614378444246918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 307}], {
             RGBColor[
             0.292307553164714, 0.42354741073044333`, 0.939995082580847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 321}], {
             RGBColor[
             0.5991431255935339, 0.5847218973029219, 0.6018385202986621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 341}], {
             RGBColor[
             0.4143889286808857, 0.5262854479646228, 0.9486036587701681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 348}], {
             RGBColor[
             0.46562137867688713`, 0.5675104323893643, 0.9528883498761094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 366}], {
             RGBColor[
             0.3245388091148398, 0.4514645046444149, 0.9420488297090084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 155}], {
             RGBColor[
             0.39870503884329245`, 0.5163722434701806, 0.9471123003503683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 199}], {
             RGBColor[
             0.7305042646208766, 0.7879971906209742, 0.9602732374081557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 216}], {
             RGBColor[
             0.5760641631729646, 0.6667015243241678, 0.9597774649286432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 298}], {
             RGBColor[
             0.61124450978409, 0.6941846784773162, 0.9632839130998092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 299}], {
             RGBColor[
             0.5845482582984111, 0.6733293639176778, 0.960623080242371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 306}], {
             RGBColor[
             0.37876660187889855`, 0.49541568205068404`, 0.9459768358615203]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 342}], {
             RGBColor[
             0.379860427908152, 0.4965653625600053, 0.9460391276357156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 361}], {
             RGBColor[
             0.4143533234029372, 0.5318028433129689, 0.9480406748160912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 393}], {
             RGBColor[
             0.38575158759098316`, 0.5027573449077584, 0.9463746204644632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 135}], {
             RGBColor[
             0.3493525104846342, 0.4770133184392301, 0.9434814109411536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 226}], {
             RGBColor[
             0.344087666487063, 0.4724531751872874, 0.9431459397371471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 234}], {
             RGBColor[
             0.3329454605550204, 0.46191241931972526`, 0.9424685531849868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 239}], {
             RGBColor[
             0.6347317174481535, 0.571566803820907, 0.5925541600983439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 246}], {
             RGBColor[
             0.3170352002856397, 0.44518972700784143`, 0.9415624873997663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 269}], {
             RGBColor[
             0.5175248334956153, 0.616441962312989, 0.9560813775291882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 272}], {
             RGBColor[
             0.3103454513280695, 0.4381583766988532, 0.9411815160932294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 350}], {
             RGBColor[
             0.5182662641451459, 0.6170211735714839, 0.95615527640727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 355}], {
             RGBColor[
             0.4075193852989937, 0.5273945418512941, 0.9471877527693767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 392}], {
             RGBColor[
             0.2728486774095929, 0.39874688987775386`, 0.9390461302900781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 395}], {
             RGBColor[
             0.31257537192122553`, 0.4405021646273918, 0.9413085067721377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 156}], {
             RGBColor[
             0.6165447783192339, 0.6929736609366322, 0.9664028566495213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 165}], {
             RGBColor[
             0.3877415089711027, 0.5102639394410429, 0.9459275239786529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 221}], {
             RGBColor[
             0.32465048908604516`, 0.4556176690634678, 0.9419074199807753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 234}], {
             RGBColor[
             0.3155276162204688, 0.4468259580034477, 0.941358703545984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 255}], {
             RGBColor[
             0.48567576995795636`, 0.5900366532523884, 0.9535639731738168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 281}], {
             RGBColor[
             0.38324346236707485`, 0.5063679575510298, 0.9456409124265106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 328}], {
             RGBColor[
             0.5397053070376754, 0.6322900078802829, 0.9589183181488066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 355}], {
             RGBColor[
             0.39010154096444216`, 0.5123080805350164, 0.9460779031303741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 386}], {
             RGBColor[
             0.6634784500907596, 0.7268441219912818, 0.8209753193568742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 400}], {
             RGBColor[
             0.4220724585009381, 0.5384006197150526, 0.9485568875093136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 331}], {
             RGBColor[
             0.6151107871767867, 0.696388174011227, 0.9642277658073475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 335}], {
             RGBColor[
             0.7578824955363926, 0.8107828327241149, 0.9765023024066224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 394}], {
             RGBColor[
             0.50486156053009, 0.5941535069963151, 0.9574345481339419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 169}], {
             RGBColor[
             0.6419736310414015, 0.7031110000707241, 0.6795039804283936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 175}], {
             RGBColor[
             0.6269913454592946, 0.6978695681639011, 0.94553729330725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 178}], {
             RGBColor[
             0.6420805654463748, 0.7079792150359161, 0.868770402857777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 197}], {
             RGBColor[
             0.35526848580695886`, 0.4806893809541489, 0.9439113921529393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 252}], {
             RGBColor[
             0.29082195672271594`, 0.42300269406559243`, 0.9398732522516045]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 278}], {
             RGBColor[
             0.5301001681570339, 0.6216883135289165, 0.9587123585960289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 282}], {
             RGBColor[
             0.42230981790273686`, 0.5360903744126337, 0.9489200620601377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 300}], {
             RGBColor[
             0.6179249943411187, 0.691107898344753, 0.9608842608672399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 314}], {
             RGBColor[
             0.5720343562701005, 0.654698187130157, 0.9628254737562953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 319}], {
             RGBColor[
             0.3201395464367107, 0.45026245930347075`, 0.9416730071995685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 352}], {
             RGBColor[
             0.5316598905104187, 0.6229067804857098, 0.9588678171437802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 159}], {
             RGBColor[
             0.6523027855950145, 0.7268758271042266, 0.9669549795176691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 215}], {
             RGBColor[
             0.759817894250921, 0.8111874301027184, 0.9462765868824963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 218}], {
             RGBColor[
             0.497799951549184, 0.6029880646282296, 0.9536595579011495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 229}], {
             RGBColor[
             0.5831446584640625, 0.6724621299654392, 0.9603264301250108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 329}], {
             RGBColor[
             0.6414183290280882, 0.71837280690921, 0.9658701186081076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 349}], {
             RGBColor[
             0.39646405474243845`, 0.5092062052896701, 0.9474225723387766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 193}], {
             RGBColor[
             0.3760730989641004, 0.48494193608557723`, 0.946519131275145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 204}], {
             RGBColor[
             0.2739453366403509, 0.39972987523009273`, 0.9391147959717512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 224}], {
             RGBColor[
             0.29600838789080414`, 0.41883978130203614`, 0.9405206340878399]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 276}], {
             RGBColor[
             0.2782418934664579, 0.40345133680164147`, 0.9393885687734147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 290}], {
             RGBColor[
             0.5238524305420571, 0.4005884355006752, 0.572719954764935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 318}], {
             RGBColor[
             0.29967430895800684`, 0.42201501787589685`, 0.9407542233365953]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 203}], {
             RGBColor[
             0.40335314171917247`, 0.5196624533032923, 0.9475222116904551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 232}], {
             RGBColor[
             0.35653551052571714`, 0.4809844203875013, 0.9440215054114484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 257}], {
             RGBColor[
             0.41384998059473066`, 0.5281842599796729, 0.9483485612979269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 275}], {
             RGBColor[
             0.2737498245771922, 0.4050588007449505, 0.9389010195818731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 280}], {
             RGBColor[
             0.28935264932800564`, 0.42145835883428245`, 0.9397895773691212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 288}], {
             RGBColor[
             0.4042374786667471, 0.5203803978762589, 0.9475918299344013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 297}], {
             RGBColor[
             0.3303661075714214, 0.4583177988609272, 0.942354014195895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 309}], {
             RGBColor[
             0.45351707959505017`, 0.5603877979305779, 0.9514713006366033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 322}], {
             RGBColor[
             0.6239650458701358, 0.6942879258778588, 0.9430676299290622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 325}], {
             RGBColor[
             0.27454803818862467`, 0.405897773860232, 0.938946476666193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 339}], {
             RGBColor[
             0.6351844653351812, 0.7023610405426353, 0.9108962760615205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 172}], {
             RGBColor[
             0.9540085361347301, 0.9651593411487217, 0.9606249514509376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[
             0.8345209379268815, 0.8715695654434361, 0.9838977750597764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 243}], {
             RGBColor[
             0.7457367881770712, 0.8009205157983501, 0.9759307155350427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 279}], {
             RGBColor[
             0.7621616862267098, 0.8142549879682717, 0.9772237436758944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 285}], {
             RGBColor[
             0.8797797565614711, 0.9069765131695443, 0.9883953726411352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 337}], {
             RGBColor[
             0.6394698916916037, 0.711723511223566, 0.9683731135186556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 399}], {
             RGBColor[
             0.687718333411875, 0.753513886404473, 0.9714474615606494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 143}], {
             RGBColor[
             0.33310563589636605`, 0.462413007591129, 0.942465510225643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 258}], {
             RGBColor[
             0.4374080723536685, 0.5495379648314893, 0.9500003173487008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 277}], {
             RGBColor[
             0.5457933648747446, 0.6352905312817037, 0.9600639607429678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 302}], {
             RGBColor[
             0.6460336874163857, 0.7127857785190478, 0.8859913860803823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 377}], {
             RGBColor[
             0.6481220337077831, 0.7118616666014939, 0.7214353997564953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 378}], {
             RGBColor[
             0.40608742787859, 0.5241104546676664, 0.9475346414843215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 379}], {
             RGBColor[
             0.3540603133127629, 0.4805628959565015, 0.9438007237411221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 258}], {
             RGBColor[
             0.4674793972271688, 0.5761123196795839, 0.951897099811905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 277}], {
             RGBColor[
             0.5758646897482449, 0.6618648861297982, 0.9619607432061721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 302}], {
             RGBColor[
             0.676105012289886, 0.7393601333671423, 0.8878881685435864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 377}], {
             RGBColor[
             0.6781933585812834, 0.7384360214495884, 0.7233321822196995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 378}], {
             RGBColor[
             0.43615875275209026`, 0.5506848095157609, 0.9494314239475257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 379}], {
             RGBColor[
             0.38413163818626317`, 0.507137250804596, 0.9456975062043262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 186}], {
             RGBColor[
             0.6749460272147811, 0.7453176248906459, 0.9686972038045709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 188}], {
             RGBColor[
             0.5580604640708762, 0.648014392012269, 0.9601615080845349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 200}], {
             RGBColor[
             0.4948971513273804, 0.586785180178243, 0.9563755386890818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 228}], {
             RGBColor[
             0.7027471690132583, 0.7677106966002407, 0.971006928327717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 333}], {
             RGBColor[
             0.834908779455954, 0.7597167210909277, 0.6144752733807564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 368}], {
             RGBColor[
             0.6415924462647964, 0.7182396853137496, 0.9660714877339953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 200}], {
             RGBColor[
             0.6162839075494507, 0.6798236809970757, 0.8401319355677652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 207}], {
             RGBColor[
             0.6939791245458833, 0.7536396979002506, 0.844843865052157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 222}], {
             RGBColor[
             0.6067374713636212, 0.6697897712867554, 0.8395882801496689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 254}], {
             RGBColor[
             0.606211621164407, 0.669237069386553, 0.8395583337587493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 333}], {
             RGBColor[
             0.9562955356780243, 0.8527552219097605, 0.4982316702594399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 227}], {
             RGBColor[
             0.38003538779471635`, 0.49311700101020256`, 0.9463797218284642]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 302}], {
             RGBColor[
             0.7641822502173672, 0.8133127435041297, 0.8941456686035161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 375}], {
             RGBColor[
             0.5580391032270547, 0.6520803092316616, 0.9583500288520745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 377}], {
             RGBColor[
             0.7662705965087646, 0.8123886315865758, 0.7295896822796293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 344}], {
             RGBColor[
             0.9887112868406132, 0.9875568814687817, 0.6882451120719052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 354}], {
             RGBColor[
             0.8764609134816678, 0.8998475298172488, 0.7234050419847453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 371}], {
             RGBColor[
             0.5883596391199843, 0.6488866592332287, 0.7019373766387556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 388}], {
             RGBColor[
             0.9496828532854145, 0.9577479530862607, 0.7305176574227672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 391}], {
             RGBColor[
             0.7078425915059376, 0.7639283979552948, 0.7091277636535251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 179}], {
             RGBColor[
             0.25421775511798717`, 0.3845293573385954, 0.9377886971212788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 232}], {
             RGBColor[
             0.33620522745507964`, 0.45961600386586465`, 0.9428637258665341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 257}], {
             RGBColor[
             0.3935196975240931, 0.5068158434580363, 0.9471907817530126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 275}], {
             RGBColor[
             0.25341954150655477`, 0.38369038422331386`, 0.9377432400369589]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 276}], {
             RGBColor[
             0.3104717477672501, 0.4373269571625632, 0.9412240112960482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 279}], {
             RGBColor[
             0.4173650663629609, 0.5261745881030535, 0.9490679765364725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 288}], {
             RGBColor[
             0.38390719559610953`, 0.4990119813546222, 0.946434050389487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 195}], {
             RGBColor[
             0.6193455590014573, 0.7015606444616803, 0.9633752609668302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 210}], {
             RGBColor[
             0.7258790186825342, 0.5952053625699875, 0.5883983535112576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 247}], {
             RGBColor[
             0.5850970021883839, 0.6740471305529259, 0.96048012577466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 249}], {
             RGBColor[
             0.46642743352299976`, 0.5750503726150517, 0.9518717330585706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 253}], {
             RGBColor[
             0.4213349301932525, 0.5319798306675697, 0.9491454391788694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 266}], {
             RGBColor[
             0.7530632502791172, 0.8069013694698697, 0.9764696122349106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 315}], {
             RGBColor[
             0.7678629600960662, 0.818117101325635, 0.9575935297240795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 316}], {
             RGBColor[
             0.7393651261534393, 0.7959788571177282, 0.9751630729273437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 358}], {
             RGBColor[
             0.5198431639678341, 0.6210711250335719, 0.9553431045972529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 359}], {
             RGBColor[
             0.4263854070434636, 0.5372882020558688, 0.9494330563639781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 362}], {
             RGBColor[
             0.5028089259918554, 0.6065621928045943, 0.9541899295877955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 363}], {
             RGBColor[
             0.6561893471938445, 0.7303432918207347, 0.967047505449071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 369}], {
             RGBColor[
             0.6699105008102617, 0.7410623613105096, 0.9684151018100847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 397}], {
             RGBColor[
             0.4256280549242598, 0.5364921769596878, 0.9493899262811915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 192}], {
             RGBColor[
             0.6953580932798215, 0.7573898437912414, 0.9331500282990366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 283}], {
             RGBColor[
             0.6141352105289695, 0.6814562144108869, 0.9281789788999836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 294}], {
             RGBColor[
             0.8711945713674087, 0.8994557464799176, 0.9479317808336664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 320}], {
             RGBColor[
             0.6075218911574731, 0.6745051964427778, 0.9278023601453061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 347}], {
             RGBColor[
             0.9421376199364708, 0.9555590705652843, 0.9548217190869412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 380}], {
             RGBColor[
             0.6263826582136882, 0.6943290584605598, 0.9288764529271532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 381}], {
             RGBColor[
             0.7784780122602573, 0.826024455191571, 0.9393746469269766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 384}], {
             RGBColor[
             0.984429633335967, 0.98711677805032, 0.8757980677784194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 168}], {
             RGBColor[
             0.7787755773257239, 0.8268588103321242, 0.9552972033055455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 265}], {
             RGBColor[
             0.6470212038880644, 0.7234608305715682, 0.965942435810659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 291}], {
             RGBColor[
             0.6049925150503981, 0.6901992041769496, 0.9620463734268229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 304}], {
             RGBColor[
             0.5475958923362796, 0.643602040169241, 0.9575279010360107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 378}], {
             RGBColor[
             0.5523692835068162, 0.6474772941603044, 0.9579036798744633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 383}], {
             RGBColor[
             0.7931679599943827, 0.8365051143265324, 0.882233669628472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 154}], {
             RGBColor[
             0.51334649656649, 0.6131025920395432, 0.9556967573447697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 180}], {
             RGBColor[
             0.513773668184085, 0.6134725866244342, 0.9557239763425098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 198}], {
             RGBColor[
             0.6733639170438348, 0.744756276840741, 0.9680782803735062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 236}], {
             RGBColor[
             0.7678352610989689, 0.8189944121693, 0.9773784930347251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 267}], {
             RGBColor[
             0.4915721798496918, 0.5942427733084321, 0.9543093171378476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 284}], {
             RGBColor[
             0.5794678629818791, 0.6691809577918973, 0.9602394819094635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 332}], {
             RGBColor[
             0.8236759654795647, 0.8619883816120713, 0.9271299847636274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 367}], {
             RGBColor[
             0.5883570039152134, 0.6763975628528137, 0.9609392676457317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 383}], {
             RGBColor[
             0.8262158321076016, 0.8630386817343595, 0.8850378217729247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 398}], {
             RGBColor[
             0.8255831106325393, 0.862777035144221, 0.8955236540453961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 161}], {
             RGBColor[
             0.7672483631204006, 0.8184347773336882, 0.9775664109412245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 184}], {
             RGBColor[
             0.9378910901526967, 0.952960093378848, 0.9817055993502397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[
             0.7089646673321061, 0.7711174474421771, 0.9729781049085575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 372}], {
             RGBColor[
             0.6592500102776411, 0.7290946041386919, 0.9695236682646116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 180}], {
             RGBColor[
             0.36542639824481893`, 0.49093571212001264`, 0.9445056248556516]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 236}], {
             RGBColor[
             0.6194879911597029, 0.6964575376648785, 0.9661601415478669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 267}], {
             RGBColor[
             0.34322490991042576`, 0.4717058988040106, 0.9430909656509894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 286}], {
             RGBColor[
             0.6135450460797178, 0.6917187945750451, 0.9655932981408082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 291}], {
             RGBColor[
             0.48969311722435094`, 0.5941958970803551, 0.9536321740844174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 332}], {
             RGBColor[
             0.6753286955402986, 0.7394515071076497, 0.9159116332767692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 383}], {
             RGBColor[
             0.6778685621683356, 0.740501807229938, 0.8738194702860664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 170}], {
             RGBColor[
             0.4151935969494319, 0.5297583977418224, 0.948410340044062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 171}], {
             RGBColor[
             0.4487409030653796, 0.5569936121356668, 0.9510513068693409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 199}], {
             RGBColor[
             0.6202455658079248, 0.6921307174499016, 0.952898901453171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 261}], {
             RGBColor[
             0.3040946245899854, 0.43593637014189646`, 0.9406663388611065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.47428955948545926`, 0.5774628907466054, 0.9532487442873863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 306}], {
             RGBColor[
             0.26850790306594674`, 0.39954920887961154`, 0.9386024999065357]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 342}], {
             RGBColor[
             0.2696017290952002, 0.40069888938893283`, 0.9386647916807309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 353}], {
             RGBColor[
             0.5016721253158913, 0.5988543592885471, 0.9559779825447373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 361}], {
             RGBColor[
             0.3040946245899854, 0.43593637014189646`, 0.9406663388611065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 165}], {
             RGBColor[
             0.672351621140254, 0.7413107432547226, 0.9699588193260231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 221}], {
             RGBColor[
             0.6092606012551964, 0.6866644728771474, 0.9659387153281456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 245}], {
             RGBColor[
             0.7448895116791774, 0.8004655394429877, 0.9755959732095558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 255}], {
             RGBColor[
             0.7702858821271077, 0.8210834570660681, 0.977595268521187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 328}], {
             RGBColor[
             0.8243154192068267, 0.8633368116939626, 0.9829496134961768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 364}], {
             RGBColor[
             0.7741969843200874, 0.8241839094462288, 0.9779542762900694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 386}], {
             RGBColor[
             0.9480885622599109, 0.9578909258049614, 0.8450066147042445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 400}], {
             RGBColor[
             0.7066825706700894, 0.7694474235287323, 0.9725881828566839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 181}], {
             RGBColor[
             0.7450290087391385, 0.7992770568537275, 0.9476847959921177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 191}], {
             RGBColor[
             0.874957856078687, 0.9026143969734106, 0.9593796490307316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 334}], {
             RGBColor[
             0.9289385104316801, 0.9453530651778554, 0.9646090549821233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 365}], {
             RGBColor[
             0.5928133729456655, 0.6609314145509388, 0.9377735909645559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 370}], {
             RGBColor[
             0.8968018368261911, 0.9197281539716049, 0.9615438303648847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 209}], {
             RGBColor[
             0.602568590937233, 0.6801164776429405, 0.9655755889149172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 241}], {
             RGBColor[
             0.4438715612950785, 0.5546051858288895, 0.9505255434733857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 270}], {
             RGBColor[
             0.27504889240221175`, 0.40642420339470325`, 0.9389749995727094]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 310}], {
             RGBColor[
             0.5448251179865897, 0.6343309290700294, 0.9599996245446637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 323}], {
             RGBColor[
             0.5881203951145202, 0.6685958784797372, 0.9641975070992903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 324}], {
             RGBColor[
             0.3022912709702298, 0.43505767053625366`, 0.9405264127306705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 346}], {
             RGBColor[
             0.5406150460175785, 0.6310419888501059, 0.9595800039161522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 390}], {
             RGBColor[
             0.6386875172837763, 0.7078814300426599, 0.9331261764850658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 215}], {
             RGBColor[
             0.8629374379589485, 0.8931725351631574, 0.9555787033928698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 218}], {
             RGBColor[
             0.6009194952572116, 0.6849731696886685, 0.962961674411523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 329}], {
             RGBColor[
             0.7445378727361158, 0.8003579119696489, 0.9751722351184811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 349}], {
             RGBColor[
             0.499583598450466, 0.591191310350109, 0.9567246888491502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 217}], {
             RGBColor[
             0.5653657489728702, 0.6527445290989151, 0.9613030616302891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 220}], {
             RGBColor[
             0.641672441590583, 0.7131832597407461, 0.9631975702020372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 233}], {
             RGBColor[
             0.606735075648282, 0.685482339153392, 0.9653149734170449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 244}], {
             RGBColor[
             0.6637012413043153, 0.729336496420312, 0.9135573986362506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 263}], {
             RGBColor[
             0.521090201237922, 0.6181561347017476, 0.9568900888105873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 264}], {
             RGBColor[
             0.617903340715392, 0.6943876105634261, 0.9663802125091737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 307}], {
             RGBColor[
             0.33064663638848857`, 0.4608112304817179, 0.9422894891847022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 312}], {
             RGBColor[
             0.30451803677174294`, 0.4343651550235629, 0.940764276280714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 321}], {
             RGBColor[
             0.6374822088173084, 0.6219857170541965, 0.6041329269025174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 341}], {
             RGBColor[
             0.4527280119046602, 0.5635492677158974, 0.9508980653740233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 348}], {
             RGBColor[
             0.5039604619006617, 0.6047742521406388, 0.9551827564799646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 366}], {
             RGBColor[
             0.36287789233861434`, 0.4887283243956895, 0.9443432363128637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 176}], {
             RGBColor[
             0.7021556597825076, 0.7667237319040029, 0.9713068308818464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 184}], {
             RGBColor[
             0.7787382225202508, 0.8272436595289936, 0.9664298398224742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 195}], {
             RGBColor[
             0.6347256687793582, 0.7140469104454299, 0.964586039547745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 250}], {
             RGBColor[
             0.7939859258270691, 0.8182493544777055, 0.6693072622303462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 344}], {
             RGBColor[
             0.7963021029340711, 0.8402901556825634, 0.9343424703967813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.5498117996996602, 0.6454010135923226, 0.9577023453807922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 363}], {
             RGBColor[
             0.6715694569717454, 0.7428295578044843, 0.9682582840299858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 372}], {
             RGBColor[
             0.5000971426451952, 0.6033781702888373, 0.9542479087368462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 191}], {
             RGBColor[
             0.5686362766158264, 0.6558666788585717, 0.961388976117826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 211}], {
             RGBColor[
             0.4252712069680037, 0.5416212081741147, 0.9486363744406009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 214}], {
             RGBColor[
             0.33815502467204234`, 0.4673146190303642, 0.9427679170467231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 248}], {
             RGBColor[
             0.33546157475970795`, 0.464981688093029, 0.9425962928000334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 263}], {
             RGBColor[
             0.5277675550188208, 0.6239397229332027, 0.9573155638889541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 312}], {
             RGBColor[
             0.31119539055264167`, 0.44014874325501796`, 0.9411897513590808]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 340}], {
             RGBColor[
             0.5678573705872763, 0.6552581915491634, 0.9613113420441909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 348}], {
             RGBColor[
             0.5106378156815604, 0.6105578403720939, 0.9556082315583314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 167}], {
             RGBColor[
             0.5829445282151479, 0.6695797530385048, 0.9617420047070453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 174}], {
             RGBColor[
             0.36061993761311684`, 0.48657775903206435`, 0.9442064954251577]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.37389457876194615`, 0.4982704244608199, 0.945045209830085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 222}], {
             RGBColor[
             0.31686571833407895`, 0.44058930039206434`, 0.9417147573657833]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 226}], {
             RGBColor[
             0.36800309932410236`, 0.49316752108612616`, 0.9446698099699363]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 395}], {
             RGBColor[
             0.33649080475826487`, 0.4612165105262305, 0.942832377004927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 287}], {
             RGBColor[
             0.5594464599018304, 0.6516343546605257, 0.9592257827543638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 292}], {
             RGBColor[
             0.8445453375980867, 0.8759829232073173, 0.8057720720178344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 354}], {
             RGBColor[
             0.7273056965403573, 0.7868960049561327, 0.9734546928391301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 371}], {
             RGBColor[
             0.4392044221786739, 0.5359351343721126, 0.9519870274931403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 374}], {
             RGBColor[
             0.5290689716354525, 0.6253229011411436, 0.9572901560637883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 388}], {
             RGBColor[
             0.8005276363441041, 0.8447964282251446, 0.980567308277152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 389}], {
             RGBColor[
             0.7684353698814181, 0.8192069260691657, 0.9775063192528366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 391}], {
             RGBColor[
             0.5586873745646271, 0.6509768730941786, 0.9591774145079099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 182}], {
             RGBColor[
             0.6913548848171176, 0.756374143658296, 0.9686757581958301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 256}], {
             RGBColor[
             0.48851998720488304`, 0.5953762901903377, 0.952950523956636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 281}], {
             RGBColor[
             0.4390503051880949, 0.5547050398691201, 0.9491968751030126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 311}], {
             RGBColor[
             0.5309083650846954, 0.6297890849278315, 0.9562874923370792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 328}], {
             RGBColor[
             0.5955121498586955, 0.6806270901983733, 0.9624742808253084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 386}], {
             RGBColor[
             0.7192852929117797, 0.7751812043093721, 0.8245312820333761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 400}], {
             RGBColor[
             0.47787930132195816`, 0.586737702033143, 0.9521128501858156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 169}], {
             RGBColor[
             0.9708333907022184, 0.9718358389093587, 0.6935834296635831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 178}], {
             RGBColor[
             0.9709403251071917, 0.9767040538745505, 0.8828498520929664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 197}], {
             RGBColor[
             0.6841282454677757, 0.7494142197927833, 0.9579908413881288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.9267483048253813, 0.8069318806554655, 0.6043390154703001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 300}], {
             RGBColor[
             0.9467847540019356, 0.9598327371833875, 0.9749637101024293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 319}], {
             RGBColor[
             0.6489993060975277, 0.7189872981421053, 0.9557524564347579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 174}], {
             RGBColor[
             0.5289632453350002, 0.622629040517384, 0.9583094990864682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 183}], {
             RGBColor[
             0.5765059457655345, 0.664002976533213, 0.9613317439267708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 189}], {
             RGBColor[
             0.5422378864838295, 0.6343217059461396, 0.9591482134913956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 222}], {
             RGBColor[
             0.4852090260559623, 0.576640581877384, 0.9558177610270937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 238}], {
             RGBColor[
             0.4666149171313697, 0.5570969944630393, 0.9547588540313573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 246}], {
             RGBColor[
             0.5092939408445624, 0.6019553543919998, 0.9571893612938661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 269}], {
             RGBColor[
             0.709783574054538, 0.7732075896971473, 0.971708251423288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 272}], {
             RGBColor[
             0.5026041918869922, 0.5949240040830116, 0.9568083899873292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 309}], {
             RGBColor[
             0.6869582806939833, 0.7550740544030773, 0.9696398844407381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 395}], {
             RGBColor[
             0.5048341124801482, 0.5972677920115501, 0.9569353806662375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 265}], {
             RGBColor[
             0.8301987589344699, 0.8677473091753818, 0.9599328345734819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 304}], {
             RGBColor[
             0.7307734473826851, 0.7878885187730547, 0.9515182997988336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 378}], {
             RGBColor[
             0.7355468385532218, 0.791763772764118, 0.9518940786372863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 177}], {
             RGBColor[
             0.9898089277005, 0.9852297491119679, 0.6275173696026343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 178}], {
             RGBColor[
             0.9909701862357685, 0.9857099593592844, 0.6082723104324812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 197}], {
             RGBColor[
             0.7041581065963525, 0.7584201252775173, 0.6834132997276436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 239}], {
             RGBColor[
             0.946778165953958, 0.8159377861401995, 0.32976147380981485`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 300}], {
             RGBColor[
             0.9668146151305124, 0.9688386426681214, 0.7003861684419441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 319}], {
             RGBColor[
             0.6690291672261044, 0.7279932036268392, 0.6811749147742727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 171}], {
             RGBColor[
             0.5754881599844709, 0.666246239578381, 0.9597236825180193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 187}], {
             RGBColor[
             0.6450573484800497, 0.7211046924151348, 0.9663086751780895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 261}], {
             RGBColor[
             0.43084188150907665`, 0.5451889975846107, 0.949338714509785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 299}], {
             RGBColor[
             0.6010368164045505, 0.6867155181893196, 0.9619211199360648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 306}], {
             RGBColor[
             0.395255159985038, 0.5088018363223259, 0.9472748755552141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 353}], {
             RGBColor[
             0.6284193822349826, 0.7081069867312614, 0.9646503581934158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 361}], {
             RGBColor[
             0.43084188150907665`, 0.5451889975846107, 0.949338714509785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 299}], {
             RGBColor[
             0.6345841225204982, 0.713950732583164, 0.9645620867613436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 306}], {
             RGBColor[
             0.4288024661009857, 0.5360370507161702, 0.9499158423804929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 342}], {
             RGBColor[
             0.42989629213023917`, 0.5371867312254914, 0.9499781341546882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 353}], {
             RGBColor[
             0.6619666883509303, 0.7353422011251057, 0.9672913250186945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 208}], {
             RGBColor[
             0.8721447762699106, 0.9002905507045698, 0.9527086679853105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 225}], {
             RGBColor[
             0.9235159054728617, 0.9408453451593575, 0.957716537117316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 240}], {
             RGBColor[
             0.855191366736224, 0.887046418326169, 0.9510189105616123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 243}], {
             RGBColor[
             0.7664072169864137, 0.8163973686810833, 0.9430518510368788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 285}], {
             RGBColor[
             0.9004501853708136, 0.9224533660522773, 0.9555165081429711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 337}], {
             RGBColor[
             0.6601403205009462, 0.7272003641062991, 0.9354942490204916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 357}], {
             RGBColor[
             0.6953599328208339, 0.7577058221085999, 0.9377384115740345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 399}], {
             RGBColor[
             0.7083887622212175, 0.768990739287206, 0.9385685970624855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 176}], {
             RGBColor[
             0.6995625946064906, 0.7646185647778574, 0.9711026952924797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 209}], {
             RGBColor[
             0.7532591141537581, 0.807242602594066, 0.9762752971684145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 250}], {
             RGBColor[
             0.7913928606510521, 0.81614418735156, 0.6691031266409795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 323}], {
             RGBColor[
             0.7388109183310452, 0.7957220034308627, 0.9748972153527875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 354}], {
             RGBColor[
             0.6814586643991087, 0.7504756369048848, 0.9692982647202546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 388}], {
             RGBColor[
             0.7546806042028553, 0.8083760601738967, 0.9764108801582765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 183}], {
             RGBColor[
             0.35418135516350346`, 0.4810009825267726, 0.9437962346448832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 189}], {
             RGBColor[
             0.31991329588179845`, 0.4513197119396991, 0.9416127042095079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 238}], {
             RGBColor[
             0.24429032652933869`, 0.3740950004565988, 0.9372233447494698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 246}], {
             RGBColor[
             0.28696935024253134`, 0.4189533603855593, 0.9396538520119786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 269}], {
             RGBColor[
             0.48745898345250693`, 0.5902055956907069, 0.9541727421414004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 272}], {
             RGBColor[
             0.2802796012849612, 0.41192201007657114`, 0.9392728807054416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 309}], {
             RGBColor[
             0.46463369009195227`, 0.5720720603966368, 0.9521043751588505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 325}], {
             RGBColor[
             0.28566464868552677`, 0.41758203632629093`, 0.9395795511884402]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 395}], {
             RGBColor[
             0.2825095218781172, 0.4142657980051097, 0.9393998713843499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 178}], {
             RGBColor[
             0.9759879006536616, 0.9804685274524614, 0.8743056233113375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 213}], {
             RGBColor[
             0.9648512092904231, 0.9383943523569509, 0.6421906778939221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 227}], {
             RGBColor[
             0.5908190098155927, 0.6598501499438265, 0.9434773323045162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 278}], {
             RGBColor[
             0.8640075033643205, 0.8941776259454618, 0.9642475790495896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 296}], {
             RGBColor[
             0.6645800913719377, 0.7318751085718437, 0.9478793944628419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 314}], {
             RGBColor[
             0.9059416914773871, 0.9271874995467024, 0.9683606942098562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 319}], {
             RGBColor[
             0.6540468816439975, 0.722751771720016, 0.9472082276531292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 352}], {
             RGBColor[
             0.8655672257177054, 0.8953960929022551, 0.9644030375973409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 250}], {
             RGBColor[
             0.888046090121622, 0.8922547428978748, 0.6783234416987336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 344}], {
             RGBColor[
             0.890362267228624, 0.9142955441027326, 0.9433586498651686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 354}], {
             RGBColor[
             0.7781118938696785, 0.8265861924511997, 0.9785185797780087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 356}], {
             RGBColor[
             0.6438719639942131, 0.7194064020124918, 0.9667185248491795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 372}], {
             RGBColor[
             0.5941573069397481, 0.6773835587090066, 0.9632640882052335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 388}], {
             RGBColor[
             0.8513338336734253, 0.8844866157202116, 0.9856311952160306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 197}], {
             RGBColor[
             0.7031037824660573, 0.7628081299953926, 0.89192478132718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 225}], {
             RGBColor[
             0.9305537247859277, 0.9453361250585516, 0.9118579192420144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 243}], {
             RGBColor[
             0.7734450362994798, 0.8208881485802774, 0.8971932331615773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 252}], {
             RGBColor[
             0.6386572533818143, 0.7051214431068361, 0.8878866414258451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 300}], {
             RGBColor[
             0.9657602910002172, 0.9732266473859965, 0.9088976500414805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 337}], {
             RGBColor[
             0.6671781398140123, 0.7316911440054932, 0.8896356311451901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 367}], {
             RGBColor[
             0.7518874224474377, 0.803386706495753, 0.895496138831003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 398}], {
             RGBColor[
             0.9891135291647636, 0.9897661787871601, 0.8300805252306674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 197}], {
             RGBColor[
             0.7042650410013258, 0.7632883402427091, 0.8726797221570268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 274}], {
             RGBColor[
             0.7480532198838732, 0.7998113763800789, 0.8758578186641729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 278}], {
             RGBColor[
             0.8790967233514007, 0.9042872728174767, 0.8874806886001165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 300}], {
             RGBColor[
             0.9669215495354857, 0.9737068576333132, 0.8896525908713275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 319}], {
             RGBColor[
             0.6691361016310776, 0.732861418592031, 0.8704413372036561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 352}], {
             RGBColor[
             0.8806564457047856, 0.9055057397742701, 0.8876361471478678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 232}], {
             RGBColor[
             0.3466781149751769, 0.4706236726689076, 0.943460141317555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 257}], {
             RGBColor[
             0.40399258504419044`, 0.5178235122610793, 0.9477871972040335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 275}], {
             RGBColor[
             0.263892429026652, 0.3946980530263568, 0.9383396554879797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 279}], {
             RGBColor[
             0.42783795388305823`, 0.5371822569060964, 0.9496643919874934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 285}], {
             RGBColor[
             0.5454560242178195, 0.6299037821073692, 0.9608360209527341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 288}], {
             RGBColor[
             0.39438008311620687`, 0.5100196501576651, 0.9470304658405079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 399}], {
             RGBColor[
             0.3533946010682234, 0.4764411553422978, 0.9438881098722485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 198}], {
             RGBColor[
             0.5254438187221636, 0.6225893969212104, 0.9568871478843881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 236}], {
             RGBColor[
             0.6199151627772979, 0.6968275322497695, 0.966187360545607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 262}], {
             RGBColor[
             0.47555678773550636`, 0.5827425853887902, 0.9525129009271962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 267}], {
             RGBColor[
             0.34365208152802074`, 0.47207589338890155`, 0.9431181846487295]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 284}], {
             RGBColor[
             0.431547764660208, 0.5470140778723668, 0.9490483494203454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 286}], {
             RGBColor[
             0.6139722176973128, 0.6920887891599361, 0.9656205171385484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 332}], {
             RGBColor[
             0.6757558671578936, 0.7398215016925407, 0.9159388522745093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 367}], {
             RGBColor[
             0.4404369055935423, 0.5542306829332831, 0.9497481351566136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 398}], {
             RGBColor[
             0.6776630123108682, 0.7406101552246904, 0.8843325215562781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 191}], {
             RGBColor[
             0.6524386347029596, 0.7265733501557992, 0.96724788399773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 211}], {
             RGBColor[
             0.509073565055137, 0.612327879471342, 0.9544952823205048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 214}], {
             RGBColor[
             0.4219573827591756, 0.5380212903275916, 0.948626824926627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 305}], {
             RGBColor[
             0.6755364273594926, 0.7446868627364356, 0.9695316550310573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 334}], {
             RGBColor[
             0.7064192890559526, 0.769312018360244, 0.9724772899491219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 340}], {
             RGBColor[
             0.6516597286744096, 0.7259648628463908, 0.9671702499240948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 365}], {
             RGBColor[
             0.370294151569938, 0.4848903677333274, 0.9456418259315543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 370}], {
             RGBColor[
             0.6742826154504636, 0.7436871071539934, 0.9694120653318831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 256}], {
             RGBColor[
             0.7363265202298779, 0.7931494120895004, 0.9721427954973113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 281}], {
             RGBColor[
             0.6868568382130897, 0.7524781617682827, 0.9683891466436878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 311}], {
             RGBColor[
             0.7787148981096903, 0.8275622068269941, 0.9754797638777545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 386}], {
             RGBColor[
             0.9670918259367745, 0.9729543262085347, 0.8437235535740513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 238}], {
             RGBColor[
             0.291833026959873, 0.4154689364724279, 0.9402455895897723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 246}], {
             RGBColor[
             0.33451205067306566`, 0.46032729640138836`, 0.9426760968522812]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 269}], {
             RGBColor[
             0.5350016838830413, 0.631579531706536, 0.9571949869817029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 272}], {
             RGBColor[
             0.3278223017154955, 0.4532959460924002, 0.9422951255457441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 280}], {
             RGBColor[
             0.348011960255442, 0.47451655731617043`, 0.9434448967316709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 309}], {
             RGBColor[
             0.5121763905224865, 0.6134459964124659, 0.955126619999153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 325}], {
             RGBColor[
             0.3332073491160611, 0.45895597234212, 0.9426017960287427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 339}], {
             RGBColor[
             0.6938437762626177, 0.7554192390245232, 0.9145515954240702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 395}], {
             RGBColor[
             0.3300522223086515, 0.45563973402093877`, 0.9424221162246524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 343}], {
             RGBColor[
             0.9574546264713248, 0.9677903106007453, 0.9569023991601844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 356}], {
             RGBColor[
             0.7204545267319564, 0.7799263296374825, 0.9618415337898073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 369}], {
             RGBColor[
             0.8559333376204588, 0.8880739433394191, 0.9737650688000147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 372}], {
             RGBColor[
             0.6707398696774913, 0.7379034863339973, 0.9583870971458612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 198}], {
             RGBColor[
             0.7981156108692801, 0.719753212851219, 0.6083234007801842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 205}], {
             RGBColor[
             0.8661932255014511, 0.7729457047766066, 0.6151061559670805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 208}], {
             RGBColor[
             0.8404038708761977, 0.7527891229713028, 0.6125382993314156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 210}], {
             RGBColor[
             0.8928099577947812, 0.6041491260942806, 0.23216648120793487`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 219}], {
             RGBColor[
             0.7642390946031832, 0.6929044584344184, 0.6052095601902426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 249}], {
             RGBColor[
             0.6333583726352467, 0.5839941361393448, 0.5956398607552478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 284}], {
             RGBColor[
             0.7042195568073244, 0.6441778938023753, 0.6004846023161414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 293}], {
             RGBColor[
             0.6524053383480322, 0.6004916605114272, 0.596853516567896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 338}], {
             RGBColor[
             0.5947248946817458, 0.5477124393881598, 0.5932813988154522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 188}], {
             RGBColor[
             0.48143527717744916`, 0.5874796051980131, 0.9529854590329667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 228}], {
             RGBColor[
             0.6261219821198313, 0.7071759097859849, 0.9638308792761487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 238}], {
             RGBColor[
             0.3901314193235312, 0.4966728962393221, 0.9475969272236808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 273}], {
             RGBColor[
             0.7962686174791007, 0.8374103079769175, 0.7866947935639108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 322}], {
             RGBColor[
             0.7809227491612303, 0.828550084126641, 0.9540742869255204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 330}], {
             RGBColor[
             0.4167306027949268, 0.5246303245533978, 0.9491117113724111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 206}], {
             RGBColor[
             0.5339583761206033, 0.6272826648152088, 0.958564673995134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 220}], {
             RGBColor[
             0.8449841813226977, 0.879654694074237, 0.979472755012469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 261}], {
             RGBColor[
             0.5339583761206033, 0.6272826648152088, 0.958564673995134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 321}], {
             RGBColor[
             0.8407939485494231, 0.7884571513876875, 0.6204081117129492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 228}], {
             RGBColor[
             0.5092364189759263, 0.6098726769076079, 0.9552951835561126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 238}], {
             RGBColor[
             0.2732458561796262, 0.39936966336094515`, 0.9390612315036447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 273}], {
             RGBColor[
             0.6793830543351957, 0.7401070750985406, 0.7781590978438747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 322}], {
             RGBColor[
             0.6640371860173253, 0.731246851248264, 0.9455385912054843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 330}], {
             RGBColor[
             0.2998450396510218, 0.4273270916750208, 0.940576015652375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 222}], {
             RGBColor[
             0.2761590766027606, 0.4053312532996991, 0.9391209661501336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 226}], {
             RGBColor[
             0.32729645759278403`, 0.4579094739937609, 0.9420760187542867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 395}], {
             RGBColor[
             0.29578416302694654`, 0.42595846343386534`, 0.9402385857892773]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 212}], {
             RGBColor[
             0.6100606314382541, 0.68936834375439, 0.965063953335308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 221}], {
             RGBColor[
             0.34740472668898814`, 0.4753262460139016, 0.9433572998800526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 255}], {
             RGBColor[
             0.5084300075608993, 0.6097452302028223, 0.955013853073094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 268}], {
             RGBColor[
             0.3875294279543929, 0.5100802455238707, 0.945914010363804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 270}], {
             RGBColor[
             0.3130063037287607, 0.43996832924196766`, 0.9413691782591965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 274}], {
             RGBColor[
             0.4412362302414866, 0.5551942947297509, 0.9497241127835934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 295}], {
             RGBColor[
             0.4871825354397459, 0.592495575147159, 0.9533411742356619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 324}], {
             RGBColor[
             0.34024868229677874`, 0.46860179638351807`, 0.9429205914171577]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 351}], {
             RGBColor[
             0.3633860169769336, 0.48916843641831476`, 0.9443756135655004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 211}], {
             RGBColor[
             0.6390024123946856, 0.7156652195910251, 0.9661901353591187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 214}], {
             RGBColor[
             0.5518862300987243, 0.6413586304472747, 0.9603216779652408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 312}], {
             RGBColor[
             0.5249265959793236, 0.6141927546719284, 0.9587435122775986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 334}], {
             RGBColor[
             0.8363481363955013, 0.8726493584799271, 0.9841721429877357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 340}], {
             RGBColor[
             0.7815885760139583, 0.8293022029660739, 0.9788651029627087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 365}], {
             RGBColor[
             0.5002229989094866, 0.5882277078530105, 0.9573366789701682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 370}], {
             RGBColor[
             0.8042114627900123, 0.8470244472736765, 0.9811069183704969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 292}], {
             RGBColor[
             0.7026500076454756, 0.7604321034039645, 0.7943732559312362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 320}], {
             RGBColor[
             0.3229765673908477, 0.447362458378869, 0.9420499361455499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 347}], {
             RGBColor[
             0.6575922961698454, 0.7284163325013754, 0.9690692950871851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 374}], {
             RGBColor[
             0.3871736416828415, 0.5097720813377908, 0.9458913399771902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 382}], {
             RGBColor[
             0.4134268351053956, 0.5325112779565389, 0.9475641702472879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 384}], {
             RGBColor[
             0.6998843095693414, 0.7599740399864112, 0.8900456437786632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 248}], {
             RGBColor[
             0.44443955863108336`, 0.556127066550921, 0.9504371181630288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 305}], {
             RGBColor[
             0.7007120531437347, 0.7651255698971002, 0.9715135725141488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 334}], {
             RGBColor[
             0.7315949148401948, 0.7897507255209086, 0.9744592074322133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 360}], {
             RGBColor[
             0.6763425244972496, 0.7460185674955617, 0.9691030467223916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 201}], {
             RGBColor[
             0.8033881323033598, 0.8463321820221186, 0.9810378790052002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 208}], {
             RGBColor[
             0.7922642975293064, 0.8376421577523525, 0.9799291591130688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 223}], {
             RGBColor[
             0.607722497240291, 0.6883387430176149, 0.9644646362711595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 230}], {
             RGBColor[
             0.8610738142017682, 0.89210184902291, 0.9866003172093485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 242}], {
             RGBColor[
             0.9043392033414055, 0.9222009289579621, 0.7722116072655146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 357}], {
             RGBColor[
             0.6154794540802295, 0.6950574291563827, 0.9649589027017929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 364}], {
             RGBColor[
             0.7310785428073268, 0.7898433811345829, 0.9738307348957687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 385}], {
             RGBColor[
             0.6537419033081874, 0.7271327697865214, 0.96769139986354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 387}], {
             RGBColor[
             0.9047026266203098, 0.9229782546038083, 0.8117679883857412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 247}], {
             RGBColor[
             0.6271072852576883, 0.7078619634982718, 0.9639862924898608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 253}], {
             RGBColor[
             0.46334521326255695`, 0.5657946636129156, 0.9526516058940702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 315}], {
             RGBColor[
             0.8098732431653707, 0.8519319342709808, 0.9610996964392803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 316}], {
             RGBColor[
             0.7813754092227437, 0.8297936900630741, 0.9786692396425445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 343}], {
             RGBColor[
             0.8134420727304322, 0.8545935615171817, 0.9550585988854552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 358}], {
             RGBColor[
             0.5618534470371386, 0.6548859579789177, 0.9588492713124537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 359}], {
             RGBColor[
             0.46839569011276805`, 0.5711030350012147, 0.9529392230791789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 362}], {
             RGBColor[
             0.5448192090611599, 0.6403770257499404, 0.9576960963029962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 363}], {
             RGBColor[
             0.6981996302631488, 0.7641581247660806, 0.9705536721642718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 369}], {
             RGBColor[
             0.711920783879566, 0.7748771942558556, 0.9719212685252855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 372}], {
             RGBColor[
             0.5267273159365986, 0.6247067372504336, 0.956543296871132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 397}], {
             RGBColor[
             0.46763833799356425`, 0.5703070099050337, 0.9528960929963922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 289}], {
             RGBColor[
             0.3434551094804801, 0.46889298534683377`, 0.9432159288507813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 317}], {
             RGBColor[
             0.4544891607839625, 0.5601913914090559, 0.9516375405803537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 326}], {
             RGBColor[
             0.2799372555034245, 0.41156218295419983`, 0.9392533846196383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 327}], {
             RGBColor[
             0.33363133833800984`, 0.4603841285403203, 0.9425899668404029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 336}], {
             RGBColor[
             0.2671463187154426, 0.3981180973977978, 0.938524959692058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 376}], {
             RGBColor[
             0.40635424083463545`, 0.5211132949407601, 0.947848183357921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 252}], {
             RGBColor[
             0.35300643227766687`, 0.4783118192723856, 0.9437825715508544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 300}], {
             RGBColor[
             0.6801094698960697, 0.746417023551546, 0.9647935801664899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 205}], {
             RGBColor[
             0.7531116822140844, 0.8070655790629049, 0.9760242071022809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 219}], {
             RGBColor[
             0.6511575513158165, 0.7270243327207166, 0.966127611325443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 236}], {
             RGBColor[
             0.7795054116370476, 0.8281112224660762, 0.9785416645766034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 284}], {
             RGBColor[
             0.5911380135199578, 0.6782977680886735, 0.9614026534513418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 332}], {
             RGBColor[
             0.8353461160176434, 0.8711051919088474, 0.9282931563055057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 367}], {
             RGBColor[
             0.600027154453292, 0.6855143731495899, 0.9621024391876101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 398}], {
             RGBColor[
             0.8372532611706179, 0.8718938454409972, 0.8966868255872744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 216}], {
             RGBColor[
             0.7976046901375968, 0.842459998303889, 0.965564066031446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 298}], {
             RGBColor[
             0.8327850367487222, 0.8699431524570373, 0.9690705142026119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 299}], {
             RGBColor[
             0.8060887852630434, 0.849087837897399, 0.9664096813451737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 306}], {
             RGBColor[
             0.6003071288435309, 0.6711741560304052, 0.9517634369643231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 342}], {
             RGBColor[
             0.6014009548727843, 0.6723238365397264, 0.9518257287385183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 353}], {
             RGBColor[
             0.8334713510934755, 0.8704793064393407, 0.9691389196025247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 361}], {
             RGBColor[
             0.6358938503675695, 0.70756131729269, 0.9538272759188939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 393}], {
             RGBColor[
             0.6072921145556155, 0.6785158188874795, 0.9521612215672659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 207}], {
             RGBColor[
             0.31591830554298506`, 0.441533965554759, 0.9415897540064162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 333}], {
             RGBColor[
             0.5782347166751262, 0.5406494895642688, 0.594977559213699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 368}], {
             RGBColor[
             0.38491838348396856`, 0.4991724537870908, 0.946573773566938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 223}], {
             RGBColor[
             0.5961926220807868, 0.6793315169127133, 0.9633154460680695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 230}], {
             RGBColor[
             0.8495439390422639, 0.8830946229180086, 0.9854511270062585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 245}], {
             RGBColor[
             0.6902411950069125, 0.7571177850264403, 0.9703232416121651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 364}], {
             RGBColor[
             0.7195486676478225, 0.7808361550296814, 0.9726815446926786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 385}], {
             RGBColor[
             0.6422120281486832, 0.7181255436816198, 0.96654220966045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 218}], {
             RGBColor[
             0.5608764325785595, 0.6536912247855574, 0.9589705561474112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 229}], {
             RGBColor[
             0.6462211394934378, 0.723165290122767, 0.9656374283712725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 260}], {
             RGBColor[
             0.757034290889019, 0.8102717449653801, 0.976377548257169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 307}], {
             RGBColor[
             0.497539556547684, 0.598832006171564, 0.9549347864133242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 341}], {
             RGBColor[
             0.6196209320638557, 0.7015700434057435, 0.9635433626026455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 349}], {
             RGBColor[
             0.4595405357718139, 0.5599093654469979, 0.9527335705850384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 366}], {
             RGBColor[
             0.5297708124978098, 0.6267491000855356, 0.9569885335414856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 232}], {
             RGBColor[
             0.4754832185057247, 0.5843883521119679, 0.9520358763418173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 257}], {
             RGBColor[
             0.5327976885747383, 0.6315881917041395, 0.9563629322282958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 275}], {
             RGBColor[
             0.39269753255719986`, 0.5084627324694171, 0.946915390512242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 280}], {
             RGBColor[
             0.40830035730801323`, 0.524862290558749, 0.9478039482994901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 297}], {
             RGBColor[
             0.449313815551429, 0.5617217305853939, 0.9503683851262639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 309}], {
             RGBColor[
             0.5724647875750577, 0.6637917296550445, 0.9594856715669723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 322}], {
             RGBColor[
             0.7429127538501433, 0.7976918576023254, 0.9510820008594312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 325}], {
             RGBColor[
             0.39349574616863225`, 0.5093017055846987, 0.9469608475965618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 339}], {
             RGBColor[
             0.7541321733151889, 0.8057649722671019, 0.9189106469918893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 224}], {
             RGBColor[
             0.3906685655348496, 0.5127992087184199, 0.9461140334346003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 276}], {
             RGBColor[
             0.37290207111050333`, 0.4974107642180252, 0.9449819681201751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 290}], {
             RGBColor[
             0.6185126081861025, 0.49454786291705893`, 0.5783133541116954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 297}], {
             RGBColor[
             0.37246614784403714`, 0.4970331893947526, 0.9449541914751076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 318}], {
             RGBColor[
             0.3943344866020523, 0.5159744452922805, 0.9463476226833557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 345}], {
             RGBColor[
             0.31349295165383084`, 0.4412969260728762, 0.9413669741413154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 219}], {
             RGBColor[
             0.7192351659479875, 0.7802168246461043, 0.9729103665123393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 284}], {
             RGBColor[
             0.6592156281521288, 0.7314902600140614, 0.968185408638238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 293}], {
             RGBColor[
             0.6074014096928364, 0.6878040267231132, 0.9645543228899927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 338}], {
             RGBColor[
             0.5497209660265502, 0.6350248055998458, 0.9609822051375487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 220}], {
             RGBColor[
             0.6307687143517247, 0.7037389992437129, 0.9625027943441645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 321}], {
             RGBColor[
             0.6265784815784501, 0.6125414565571633, 0.6034381510446447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 328}], {
             RGBColor[
             0.5336094285374492, 0.6270100643111489, 0.9585298941611458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 386}], {
             RGBColor[
             0.6573825715905333, 0.7215641784221478, 0.8205868953692135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 254}], {
             RGBColor[
             0.3058460191579413, 0.4309473539442362, 0.9410161521974003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 333}], {
             RGBColor[
             0.6559299336715587, 0.6144655064674438, 0.5996894886980909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 230}], {
             RGBColor[
             0.8384201042682105, 0.8744045986482425, 0.9843424071141269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 240}], {
             RGBColor[
             0.7526571780620621, 0.8067007749992842, 0.9759814915941492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 242}], {
             RGBColor[
             0.8816854934078479, 0.9045036785832945, 0.7699536971702932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 357}], {
             RGBColor[
             0.592825744146672, 0.6773601787817151, 0.9627009926065713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 385}], {
             RGBColor[
             0.6310881933746297, 0.7094355194118538, 0.9654334897683186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 387}], {
             RGBColor[
             0.882048916686752, 0.9052810042291408, 0.8095100782905198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 241}], {
             RGBColor[
             0.7449118335294409, 0.8004659041425386, 0.9756181686605718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 270}], {
             RGBColor[
             0.5760891646365741, 0.6522849217083523, 0.9640676247598955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 310}], {
             RGBColor[
             0.8458653902209521, 0.8801916473836785, 0.9850922497318498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 323}], {
             RGBColor[
             0.8891606673488825, 0.9144565967933862, 0.9892901322864764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 346}], {
             RGBColor[
             0.8416553182519408, 0.876902707163755, 0.9846726291033383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 390}], {
             RGBColor[
             0.9397277895181386, 0.9537421483563089, 0.9582188016722519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 249}], {
             RGBColor[
             0.6149711762733812, 0.5025099236687047, 0.5804009923181987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 266}], {
             RGBColor[
             0.9016069930294986, 0.7343609205235228, 0.6049988714945388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 293}], {
             RGBColor[
             0.6340181419861666, 0.5190074480407871, 0.581614648130847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 315}], {
             RGBColor[
             0.9164067028464477, 0.7455766523792879, 0.5861227889837077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 316}], {
             RGBColor[
             0.8879088689038207, 0.7234384081713813, 0.6036923321869718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 387}], {
             RGBColor[
             0.9344550036053355, 0.7566410073521186, 0.429138260167039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 397}], {
             RGBColor[
             0.5741717976746412, 0.46395172801334084`, 0.5779191855408197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 214}], {
             RGBColor[
             0.4085211604509016, 0.5271131597628176, 0.9475690762880157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 248}], {
             RGBColor[
             0.40582771053856714`, 0.5247802288254824, 0.947397452041326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 263}], {
             RGBColor[
             0.59813369079768, 0.6837382636656562, 0.9621167231302465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 312}], {
             RGBColor[
             0.38156152633150087`, 0.49994728398747135`, 0.9459909106003734]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 334}], {
             RGBColor[
             0.6929830667476786, 0.75840388779547, 0.9714195413105104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 340}], {
             RGBColor[
             0.6382235063661355, 0.7150567322816168, 0.9661125012854834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 370}], {
             RGBColor[
             0.6608463931421895, 0.7327789765892195, 0.9683543166932718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 268}], {
             RGBColor[
             0.6201469180366783, 0.6981045782544404, 0.9657066425984064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 270}], {
             RGBColor[
             0.5456237938110461, 0.6279926619725374, 0.9611618104937991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 274}], {
             RGBColor[
             0.673853720323772, 0.7432186274603207, 0.9695167450181958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 295}], {
             RGBColor[
             0.7198000255220313, 0.7805199078777287, 0.9731338064702644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 310}], {
             RGBColor[
             0.8154000193954241, 0.8558993876478637, 0.9821864354657535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 324}], {
             RGBColor[
             0.5728661723790642, 0.6566261291140878, 0.9627132236517602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 351}], {
             RGBColor[
             0.596003507059219, 0.6771927691488846, 0.9641682458001029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 373}], {
             RGBColor[
             0.7139146565269554, 0.7757419001946744, 0.9726704886641551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 390}], {
             RGBColor[
             0.9092624186926106, 0.929449888620494, 0.9553129874061556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 227}], {
             RGBColor[
             0.5947715384394344, 0.627885621720331, 0.6345954964376278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 296}], {
             RGBColor[
             0.6685326199957795, 0.6999105803483481, 0.6389975585959534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 308}], {
             RGBColor[
             0.8087187586567215, 0.8159333647450915, 0.6494611266981982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 352}], {
             RGBColor[
             0.8695197543415472, 0.8634315646787596, 0.6555212017304524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 248}], {
             RGBColor[
             0.31871152824260585`, 0.45047363968173193`, 0.9415289946474482]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 263}], {
             RGBColor[
             0.5110175085017187, 0.6094316745219056, 0.9562482657363689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 312}], {
             RGBColor[
             0.29444534403553957`, 0.4256406948437208, 0.9401224532064956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 340}], {
             RGBColor[
             0.5511073240701742, 0.6407501431378663, 0.9602440438916057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 218}], {
             RGBColor[
             0.708434603913118, 0.7692847726871603, 0.9422832817763502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 229}], {
             RGBColor[
             0.7937793108279965, 0.83875883802437, 0.9489501540002117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 329}], {
             RGBColor[
             0.8520529813920222, 0.8846695149681407, 0.9544938424833083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 349}], {
             RGBColor[
             0.6070987071063725, 0.6755029133486008, 0.9360462962139774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 231}], {
             RGBColor[
             0.4434547281437874, 0.5473430102713175, 0.9511302876110956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 235}], {
             RGBColor[
             0.45631735926268674`, 0.560862451115197, 0.9518627954247595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 298}], {
             RGBColor[
             0.6783449353008102, 0.748647486160231, 0.9685747417230994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 313}], {
             RGBColor[
             0.7691719717633405, 0.8202100334152855, 0.9774662468119859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 361}], {
             RGBColor[
             0.48145374891965753`, 0.5862656509958837, 0.9533315034393814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 393}], {
             RGBColor[
             0.4528520131077035, 0.5572201525906731, 0.9516654490877534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 396}], {
             RGBColor[
             0.6272722104205875, 0.7082745239760273, 0.9638087499892338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 220}], {
             RGBColor[
             0.8654878269361064, 0.8956722978609101, 0.9815163667897514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 230}], {
             RGBColor[
             0.8482053776295329, 0.8820489285689395, 0.9853177117142049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 233}], {
             RGBColor[
             0.8305504609938053, 0.867971377273556, 0.983633770004759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 242}], {
             RGBColor[
             0.8914707667691701, 0.9121480085039917, 0.7709290017703712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 244}], {
             RGBColor[
             0.8875166266498384, 0.9118255345404758, 0.9318761952239648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 264}], {
             RGBColor[
             0.8417187260609151, 0.87687664868359, 0.9846990090968879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 321}], {
             RGBColor[
             0.8612975941628316, 0.8044747551743605, 0.6224517234902316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 357}], {
             RGBColor[
             0.6026110175079943, 0.6850045087024121, 0.9636762972066493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 364}], {
             RGBColor[
             0.7182101062350915, 0.7797904606806123, 0.9725481294006253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 366}], {
             RGBColor[
             0.5866932776841376, 0.6712173625158535, 0.9626620329005778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 229}], {
             RGBColor[
             0.5317613681262594, 0.6305594725498811, 0.9563331250188649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 260}], {
             RGBColor[
             0.6425745195218405, 0.7176659273924942, 0.9670732449047614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 329}], {
             RGBColor[
             0.5900350386902853, 0.6764701494936519, 0.9618768135019615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 349}], {
             RGBColor[
             0.3450807644046355, 0.467303547874112, 0.9434292672326307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 284}], {
             RGBColor[
             0.557261497253861, 0.651449013671873, 0.9582888128614002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 293}], {
             RGBColor[
             0.5054472787945686, 0.6077627803809249, 0.9546577271131548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 338}], {
             RGBColor[
             0.4477668351282824, 0.5549835592576575, 0.951085609360711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 233}], {
             RGBColor[
             0.9068571536115182, 0.928410107915387, 0.9855282785765072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 244}], {
             RGBColor[
             0.9638233192675514, 0.9722642651823068, 0.9337707037957129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 321}], {
             RGBColor[
             0.9376042867805445, 0.8649134858161915, 0.6243462320619797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 341}], {
             RGBColor[
             0.7528500898678964, 0.8064770364778924, 0.9711113705334857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 366}], {
             RGBColor[
             0.6629999703018504, 0.7316560931576845, 0.964556541472326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 239}], {
             RGBColor[
             0.6100296960495644, 0.5501711544451446, 0.5909801691379657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 255}], {
             RGBColor[
             0.47839159289391886`, 0.5837274651929036, 0.9530998318524411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 268}], {
             RGBColor[
             0.3574910132874124, 0.48406248051395195`, 0.9439999891431511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 324}], {
             RGBColor[
             0.3102102676297983, 0.44258403137359936`, 0.9410065701965047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 351}], {
             RGBColor[
             0.3333476023099531, 0.4631506714083961, 0.9424615923448474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 400}], {
             RGBColor[
             0.4147882814369006, 0.5320914316555678, 0.948092746187938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 333}], {
             RGBColor[
             0.5686882804892965, 0.5306155798539486, 0.5944339037956028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 230}], {
             RGBColor[
             0.6538783039791952, 0.7251011839135049, 0.9688778842722177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 242}], {
             RGBColor[
             0.6971436931188326, 0.7552002638485569, 0.7544891743283839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 245}], {
             RGBColor[
             0.4945755599438439, 0.5991243460219366, 0.9537499988781244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 328}], {
             RGBColor[
             0.5740014674714932, 0.6619956182729114, 0.9611036391647454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 364}], {
             RGBColor[
             0.5238830325847539, 0.6228427160251777, 0.956108301958638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 385}], {
             RGBColor[
             0.44654639308561445`, 0.5601321046771162, 0.9499689669264093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 290}], {
             RGBColor[
             0.6405756594365557, 0.5136577689890023, 0.579719192227784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 318}], {
             RGBColor[
             0.4163975378525055, 0.535084351364224, 0.9477534607994444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 345}], {
             RGBColor[
             0.335556002904284, 0.4604068321448196, 0.9427728122574042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 240}], {
             RGBColor[
             0.8040283072650131, 0.8472555694540718, 0.9809893607261546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 243}], {
             RGBColor[
             0.7152441575152028, 0.7766065198089859, 0.9730223012014211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 337}], {
             RGBColor[
             0.6089772610297353, 0.6874095152342017, 0.965464699185034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 367}], {
             RGBColor[
             0.6936865436631607, 0.7591050777244615, 0.9713252068708469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 398}], {
             RGBColor[
             0.9309126503804865, 0.9454845500158686, 0.9059095932705112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 234}], {
             RGBColor[
             0.3102627722228976, 0.44226581475150495`, 0.9410232323419776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 281}], {
             RGBColor[
             0.37797861836950364`, 0.501807814299087, 0.9453054412225042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 350}], {
             RGBColor[
             0.49558357581302304`, 0.5973745690032636, 0.954709955564261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 355}], {
             RGBColor[
             0.38483669696687095`, 0.5077479372830738, 0.9457424319263676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 392}], {
             RGBColor[
             0.2501659890774701, 0.37910028530953355`, 0.9376008094470689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 395}], {
             RGBColor[
             0.28989268358910275`, 0.42085556005917146`, 0.9398631859291287]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 296}], {
             RGBColor[
             0.29450042052094905`, 0.4213663779352238, 0.9402842130065475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 308}], {
             RGBColor[
             0.43468655918189103`, 0.5373891623319673, 0.9507477811087923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 352}], {
             RGBColor[
             0.49548755486671675`, 0.5848873622656352, 0.9568078561410465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 375}], {
             RGBColor[
             0.39874305439694224`, 0.5083047275286658, 0.9478524578718321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 238}], {
             RGBColor[
             0.41793256112200833`, 0.5190659679489169, 0.9499066517468268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 273}], {
             RGBColor[
             0.8240697592775779, 0.8598033796865123, 0.7890045180870567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 330}], {
             RGBColor[
             0.44453174459340394`, 0.5470233962629926, 0.951421435895557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 368}], {
             RGBColor[
             0.5927684011698465, 0.6800979702090886, 0.9612051632055731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 260}], {
             RGBColor[
             0.7279192264367189, 0.7871399927297038, 0.9737401171286227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[
             0.6753797456051637, 0.7459442148308615, 0.968543685725823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 349}], {
             RGBColor[
             0.4304254713195139, 0.5367776132113216, 0.950096139456492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 233}], {
             RGBColor[
             0.8895747043049447, 0.9147867386234164, 0.9893296235009608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 242}], {
             RGBColor[
             0.9504950100803096, 0.9589633698538521, 0.7766248552665729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 244}], {
             RGBColor[
             0.9465408699609779, 0.9586408958903363, 0.9375720487201664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 245}], {
             RGBColor[
             0.7479268769053209, 0.8028874520272318, 0.9758856798163134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 328}], {
             RGBColor[
             0.8273527844329702, 0.8657587242782065, 0.9832393201029344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 357}], {
             RGBColor[
             0.6616352608191337, 0.7318198700522727, 0.969372150702851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 364}], {
             RGBColor[
             0.7772343495462309, 0.8266058220304728, 0.9782439828968269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 385}], {
             RGBColor[
             0.6998977100470916, 0.7638952106824114, 0.9721046478645983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 235}], {
             RGBColor[
             0.2566074987167893, 0.3870411293794318, 0.9379247894839217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 298}], {
             RGBColor[
             0.47863507475491274`, 0.5748261644244659, 0.9546367357822616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 336}], {
             RGBColor[
             0.25093606157607984`, 0.38108008935466253`, 0.9376018095288976]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 393}], {
             RGBColor[
             0.253142152561806, 0.383398830854908, 0.9377274431469156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 396}], {
             RGBColor[
             0.4275623498746899, 0.5344532022402623, 0.949870744048396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 257}], {
             RGBColor[
             0.4859800573812829, 0.5929101587883485, 0.9528622259492889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 275}], {
             RGBColor[
             0.34587990136374447`, 0.46978469955362606`, 0.9434146842332352]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 279}], {
             RGBColor[
             0.5098254262201507, 0.6122689034333657, 0.9547394207327488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 280}], {
             RGBColor[
             0.3614827261145579, 0.48618425764295803`, 0.9443032420204833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 288}], {
             RGBColor[
             0.47636755545329934`, 0.5851062966849344, 0.9521054945857632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 297}], {
             RGBColor[
             0.40249618435797363`, 0.5230436976696028, 0.9468676788472571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 309}], {
             RGBColor[
             0.5256471563816024, 0.6251136967392534, 0.9559849652879655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 325}], {
             RGBColor[
             0.3466781149751769, 0.4706236726689076, 0.943460141317555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 339}], {
             RGBColor[
             0.7073145421217335, 0.7670869393513109, 0.9154099407128824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 242}], {
             RGBColor[
             0.932840093444582, 0.9448858185584685, 0.774940913557127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 244}], {
             RGBColor[
             0.9288859533252503, 0.9445633445949527, 0.9358881070107206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 264}], {
             RGBColor[
             0.883088052736327, 0.909614458738067, 0.9887109208836438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 307}], {
             RGBColor[
             0.5958313484094236, 0.6760380786563588, 0.9646201975591722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 348}], {
             RGBColor[
             0.7691451739215966, 0.8200011003152797, 0.9775134648544346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 357}], {
             RGBColor[
             0.6439803441834061, 0.717742318756889, 0.9676882089934051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 366}], {
             RGBColor[
             0.6280626043595494, 0.7039551725703304, 0.9666739446873336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[
             0.600906823183988, 0.5413794433851246, 0.5904314527031745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 246}], {
             RGBColor[
             0.2832103060214743, 0.41500236657205897`, 0.9394397800045968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 269}], {
             RGBColor[
             0.4836999392314498, 0.5862546018772066, 0.9539586701340188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 272}], {
             RGBColor[
             0.2765205570639041, 0.40797101626307075`, 0.93905880869806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 350}], {
             RGBColor[
             0.4844413698809804, 0.5868338131357015, 0.9540325690121007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 355}], {
             RGBColor[
             0.3736944910348283, 0.4972071814155116, 0.9450650453742073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 392}], {
             RGBColor[
             0.2390237831454275, 0.36855952944197146`, 0.9369234228949086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 395}], {
             RGBColor[
             0.2787504776570601, 0.4103148041916094, 0.9391857993769683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 298}], {
             RGBColor[
             0.4914977058738121, 0.5883456052683452, 0.9553692435959256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 313}], {
             RGBColor[
             0.5823247423363425, 0.6599081525233998, 0.964260748684812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 317}], {
             RGBColor[
             0.4511415347634991, 0.5566728242098001, 0.9514468982308572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 336}], {
             RGBColor[
             0.2637986926949792, 0.39459953019854194`, 0.9383343173425615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 393}], {
             RGBColor[
             0.26600478368070535`, 0.3969182716987874, 0.9384599509605794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 396}], {
             RGBColor[
             0.4404249809935893, 0.5479726430841416, 0.95060325186206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 267}], {
             RGBColor[
             0.5977136744429046, 0.6775977189337674, 0.9647727013409448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 284}], {
             RGBColor[
             0.6856093575750919, 0.7525359034172325, 0.9707028661125607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 286}], {
             RGBColor[
             0.8680338106121968, 0.897610614704802, 0.9872750338307636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 332}], {
             RGBColor[
             0.9298174600727775, 0.9453433272374064, 0.9375933689667246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 367}], {
             RGBColor[
             0.6944984985084262, 0.7597525084781489, 0.9714026518488289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 383}], {
             RGBColor[
             0.9323573267008144, 0.9463936273596947, 0.8955012059760219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 398}], {
             RGBColor[
             0.9317246052257521, 0.9461319807695563, 0.9059870382484934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 251}], {
             RGBColor[
             0.4705734330182994, 0.5738224144485216, 0.9529950983641164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 296}], {
             RGBColor[
             0.32562131330888977`, 0.45407640943391764`, 0.9420565018115856]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 308}], {
             RGBColor[
             0.46580745196983175`, 0.5700991938306611, 0.9525200699138303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 380}], {
             RGBColor[
             0.2779215119607074, 0.40944350868528184`, 0.9391385910069059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 269}], {
             RGBColor[
             0.4251106552488765, 0.5246735496363623, 0.9506220970862895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 272}], {
             RGBColor[
             0.21793127308133073`, 0.34638996402222644`, 0.9357222356503307]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 280}], {
             RGBColor[
             0.2381209316212773, 0.3676105752459967, 0.9368720068362575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 309}], {
             RGBColor[
             0.4022853618883218, 0.5065400143422921, 0.9485537301037397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 325}], {
             RGBColor[
             0.22331632048189634`, 0.3520499902719463, 0.9360289061333292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 339}], {
             RGBColor[
             0.583952747628453, 0.6485132569543495, 0.9079787055286567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 246}], {
             RGBColor[
             0.5849965629146073, 0.5246567510732407, 0.5895253869179542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 269}], {
             RGBColor[
             0.7854861961245829, 0.6959089863783883, 0.604044277047376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 272}], {
             RGBColor[
             0.5783068139570371, 0.5176254007642525, 0.5891444156114172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 350}], {
             RGBColor[
             0.7862276267741135, 0.6964881976368832, 0.6041181759254579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 355}], {
             RGBColor[
             0.6754807479279613, 0.6068615659166934, 0.5951506522875645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 392}], {
             RGBColor[
             0.5408100400385605, 0.47821391394315316`, 0.587009029808266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 242}], {
             RGBColor[
             0.8647320838741612, 0.8912595462048938, 0.768263939746595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 243}], {
             RGBColor[
             0.6469196187785651, 0.7228075929757976, 0.9663246746457175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 285}], {
             RGBColor[
             0.780962587162965, 0.8288635903469916, 0.9787893317518098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 337}], {
             RGBColor[
             0.5406527222930976, 0.6336105884010134, 0.9587670726293303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 357}], {
             RGBColor[
             0.5758723346129853, 0.6641160464033143, 0.9610112351828732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 399}], {
             RGBColor[
             0.5889011640133688, 0.6754009635819204, 0.9618414206713242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 270}], {
             RGBColor[
             0.4173921349944195, 0.5267736298943013, 0.949017579318364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 310}], {
             RGBColor[
             0.6871683605787975, 0.7546803555696275, 0.9700422042903183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 323}], {
             RGBColor[
             0.730463637706728, 0.7889453049793352, 0.9742400868449448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 346}], {
             RGBColor[
             0.6829582886097862, 0.7513914153497039, 0.9696225836618066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 389}], {
             RGBColor[
             0.7142410571158523, 0.7760098595663903, 0.9726927626261184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 390}], {
             RGBColor[
             0.781030759875984, 0.8282308565422579, 0.9431687562307205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 244}], {
             RGBColor[
             0.9898062591006153, 0.9887399758253884, 0.7231833387763327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 357}], {
             RGBColor[
             0.7049006499587711, 0.7619189499873247, 0.7549834407590172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 364}], {
             RGBColor[
             0.8204997386858683, 0.856704901965525, 0.763855272952993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 385}], {
             RGBColor[
             0.7431630991867288, 0.7939942906174635, 0.7577159379207644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 337}], {
             RGBColor[
             0.4518685725432873, 0.5629615387559275, 0.9508000131045968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 367}], {
             RGBColor[
             0.5365778551767127, 0.6346571012461872, 0.9566605207904098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 398}], {
             RGBColor[
             0.7738039618940387, 0.8210365735375944, 0.8912449071900741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 264}], {
             RGBColor[
             0.9400542183923603, 0.9534686160049868, 0.9369533461028494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 307}], {
             RGBColor[
             0.6527975140654568, 0.7198922359232787, 0.9128626227783779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 321}], {
             RGBColor[
             0.9596330864942767, 0.8810667224957572, 0.5747060604961931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 341}], {
             RGBColor[
             0.7748788895816285, 0.8226302731574582, 0.9214711989676991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 348}], {
             RGBColor[
             0.8261113395776299, 0.8638552575821996, 0.9257558900736403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 357}], {
             RGBColor[
             0.7009465098394394, 0.761596476023809, 0.9159306342126108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 366}], {
             RGBColor[
             0.6850287700155826, 0.7478093298372502, 0.9149163699065394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 328}], {
             RGBColor[
             0.6680500403976188, 0.7397818863866383, 0.9681114347088411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 364}], {
             RGBColor[
             0.6179316055108797, 0.7006289841389046, 0.9631160975027335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 400}], {
             RGBColor[
             0.5504171918608816, 0.6458924982214082, 0.9577500040693481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 269}], {
             RGBColor[
             0.46778967896206913`, 0.5695319095653226, 0.9530526043487983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 272}], {
             RGBColor[
             0.2606102967945234, 0.3912483239511869, 0.9381527429128396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 350}], {
             RGBColor[
             0.4685311096115997, 0.5701111208238177, 0.9531265032268803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 355}], {
             RGBColor[
             0.35778423076544763`, 0.48048448910362773`, 0.9441589795889869]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 392}], {
             RGBColor[
             0.2231135228760468, 0.35183683713008757`, 0.9360173571096883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 395}], {
             RGBColor[
             0.26284021738767943`, 0.3935921118797255, 0.9382797335917479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 253}], {
             RGBColor[
             0.4290966564494836, 0.5382811497041612, 0.9497564707019001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 266}], {
             RGBColor[
             0.7608249765353483, 0.8132026885064612, 0.9770806437579412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 301}], {
             RGBColor[
             0.43488796427835025`, 0.5443681814224243, 0.9500862771152818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 315}], {
             RGBColor[
             0.7756246863522973, 0.8244184203622265, 0.9582045612471102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 316}], {
             RGBColor[
             0.7471268524096704, 0.8022801761543197, 0.9757741044503743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 343}], {
             RGBColor[
             0.7791935159173589, 0.8270800476084272, 0.952163463693285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 358}], {
             RGBColor[
             0.5276048902240652, 0.6273724440701633, 0.9559541361202836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 359}], {
             RGBColor[
             0.4341471332996947, 0.5435895210924603, 0.9500440878870087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 362}], {
             RGBColor[
             0.5105706522480865, 0.6128635118411858, 0.9548009611108261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 363}], {
             RGBColor[
             0.6639510734500755, 0.7366446108573261, 0.9676585369721016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 369}], {
             RGBColor[
             0.6776722270664928, 0.7473636803471011, 0.9690261333331154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 397}], {
             RGBColor[
             0.4333897811804909, 0.5427934959962792, 0.9500009578042221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 276}], {
             RGBColor[
             0.34660835313344085`, 0.47463646726698533`, 0.9433065556612985]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 340}], {
             RGBColor[
             0.5484138741578397, 0.6384172122005312, 0.960072419644916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 360}], {
             RGBColor[
             0.5479210441964377, 0.6380322096890374, 0.9600232989601212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 266}], {
             RGBColor[
             0.6421554078699643, 0.7142059305685869, 0.9684722510418518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 293}], {
             RGBColor[
             0.37456655682663215`, 0.4988524580858514, 0.9450880276781599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 315}], {
             RGBColor[
             0.6569551176869133, 0.7254216624243521, 0.9495961685310206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 316}], {
             RGBColor[
             0.6284572837442863, 0.7032834182164455, 0.9671657117342849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 387}], {
             RGBColor[
             0.6750034184458011, 0.7364860173971828, 0.7926116397143519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 397}], {
             RGBColor[
             0.31472021251510673`, 0.443796738058405, 0.9413925650881325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 356}], {
             RGBColor[
             0.7357022300387746, 0.7709320245861945, 0.6647189561976792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 363}], {
             RGBColor[
             0.8574598873108596, 0.8683605687983562, 0.675274894846873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 372}], {
             RGBColor[
             0.6859875729843095, 0.7289091812827092, 0.6612645195537332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 283}], {
             RGBColor[
             0.4532663727538028, 0.5556315967795361, 0.9520094868855546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 308}], {
             RGBColor[
             0.6533997604476458, 0.7291601259745883, 0.9660884398196488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 380}], {
             RGBColor[
             0.4655138204385215, 0.568504440829209, 0.9527069609127242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 381}], {
             RGBColor[
             0.6176091744850905, 0.7001998375602203, 0.9632051549125475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 282}], {
             RGBColor[
             0.4200477643734449, 0.5337128127308705, 0.9487912414580528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 300}], {
             RGBColor[
             0.6156629408118268, 0.6887303366629896, 0.960755440265155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 367}], {
             RGBColor[
             0.40179007225904734`, 0.518890395772746, 0.9473539290546775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 398}], {
             RGBColor[
             0.6390161789763732, 0.7052698680641531, 0.8819383154543419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 266}], {
             RGBColor[
             0.5970629045402169, 0.6711353886211049, 0.9657459571621506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 301}], {
             RGBColor[
             0.2711258922832188, 0.4023008815370681, 0.9387515905194912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 315}], {
             RGBColor[
             0.6118626143571659, 0.6823511204768702, 0.9468698746513196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 316}], {
             RGBColor[
             0.583364780414539, 0.6602128762689634, 0.9644394178545836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 343}], {
             RGBColor[
             0.6154314439222275, 0.685012747723071, 0.9408287770974944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 358}], {
             RGBColor[
             0.36384281822893383`, 0.4853051441848071, 0.944619449524493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 359}], {
             RGBColor[
             0.2703850613045633, 0.4015222212071041, 0.938709401291218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 362}], {
             RGBColor[
             0.34680858025295513`, 0.47079621195582966`, 0.9434662745150355]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 369}], {
             RGBColor[
             0.5139101550713613, 0.6052963804617449, 0.9576914467373248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 394}], {
             RGBColor[
             0.2502374748614258, 0.38034583042460524`, 0.9375620260489645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 397}], {
             RGBColor[
             0.26962770918535944`, 0.4007261961109231, 0.9386662712084315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 303}], {
             RGBColor[
             0.5873451177672102, 0.656853198792293, 0.9470299206323158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 268}], {
             RGBColor[
             0.5185162941593235, 0.6184814647028727, 0.9556565423361925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 324}], {
             RGBColor[
             0.47123554850170946`, 0.5770030155625201, 0.9526631233895462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 328}], {
             RGBColor[
             0.6934464108455491, 0.7603998040097188, 0.9701107300204723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 351}], {
             RGBColor[
             0.4943728831818643, 0.5975696555973168, 0.9541181455378889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 400}], {
             RGBColor[
             0.5758135623088118, 0.6665104158444886, 0.9597492993809794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 311}], {
             RGBColor[
             0.5758800004974556, 0.666564353359036, 0.9597545296385606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 313}], {
             RGBColor[
             0.7143354887273198, 0.7757036467225153, 0.9731408806650779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 386}], {
             RGBColor[
             0.76425692832454, 0.8119564727405766, 0.8279983193348575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 275}], {
             RGBColor[
             0.403194371432758, 0.5169845391457977, 0.9477417401197137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 276}], {
             RGBColor[
             0.46024657769345334`, 0.5706211120850471, 0.9512225113788031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 279}], {
             RGBColor[
             0.5671398962891642, 0.6594687430255374, 0.9590664766192273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 280}], {
             RGBColor[
             0.41879719618357136`, 0.5333840972351296, 0.9486302979069619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 288}], {
             RGBColor[
             0.5336820255223128, 0.6323061362771061, 0.9564325504722417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 309}], {
             RGBColor[
             0.5829616264506159, 0.6723135363314251, 0.960312021174444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 325}], {
             RGBColor[
             0.40399258504419044`, 0.5178235122610793, 0.9477871972040335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 339}], {
             RGBColor[
             0.7646290121907471, 0.8142867789434824, 0.9197369965993609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 277}], {
             RGBColor[
             0.6801671262055473, 0.7489898433701585, 0.9694955503292297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 302}], {
             RGBColor[
             0.7804074487471884, 0.8264850906075026, 0.8954229756666442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 377}], {
             RGBColor[
             0.7824957950385858, 0.8255609786899487, 0.7308669893427573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 378}], {
             RGBColor[
             0.5404611892093927, 0.6378097667561212, 0.9569662310705835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 379}], {
             RGBColor[
             0.48843407464356564`, 0.5942622080449563, 0.9532323133273841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 262}], {
             RGBColor[
             0.48330422133530915`, 0.5894530229756044, 0.9530065605453891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 331}], {
             RGBColor[
             0.4184936278119561, 0.5368368634693808, 0.9479044332142041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 335}], {
             RGBColor[
             0.561265336171562, 0.6512315221822685, 0.960178969813479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 307}], {
             RGBColor[
             0.5792376434909651, 0.6628067087785008, 0.9630374751706744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 329}], {
             RGBColor[
             0.7861928970007448, 0.8330506696734746, 0.9792838056117195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 341}], {
             RGBColor[
             0.7013190190071368, 0.7655447460126803, 0.9716460513599956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 349}], {
             RGBColor[
             0.5412386227150949, 0.6238840680539347, 0.9608362593423885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 366}], {
             RGBColor[
             0.6114688994410908, 0.6907238026924725, 0.9650912222988358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 306}], {
             RGBColor[
             0.28415618762559147`, 0.41497980872239987`, 0.9395308743722586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 284}], {
             RGBColor[
             0.5412509825333005, 0.6384509565562534, 0.9570284064941499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 286}], {
             RGBColor[
             0.7236754355704054, 0.7835256678438227, 0.9736005742123528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 331}], {
             RGBColor[
             0.5204494120852459, 0.621563304566453, 0.9553908306698157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 332}], {
             RGBColor[
             0.7854590850309862, 0.8312583803764273, 0.9239189093483138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 338}], {
             RGBColor[
             0.43175632040772194`, 0.5419855021420379, 0.9498252029934606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 264}], {
             RGBColor[
             0.797443178325967, 0.8422882542864225, 0.9802860362771861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 312}], {
             RGBColor[
             0.48405787438231807`, 0.5822657987465594, 0.9546701000487265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 348}], {
             RGBColor[
             0.6835002995112367, 0.7526748958636353, 0.9690885802479771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 307}], {
             RGBColor[
             0.6069996134765335, 0.6849433500663928, 0.965685436651301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 312}], {
             RGBColor[
             0.5808710138597879, 0.6584972746082378, 0.964160223747313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 348}], {
             RGBColor[
             0.7803134389887066, 0.8289063717253138, 0.9785787039465634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 357}], {
             RGBColor[
             0.6551486092505161, 0.7266475901669232, 0.968753448085534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 366}], {
             RGBColor[
             0.6392308694266593, 0.7128604439803645, 0.9677391837794624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 291}], {
             RGBColor[
             0.6564156966591441, 0.7310877030202071, 0.9666820046947593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 304}], {
             RGBColor[
             0.5990190739450256, 0.6844905390124987, 0.9621635323039472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 378}], {
             RGBColor[
             0.6037924651155623, 0.688365793003562, 0.9625393111423999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 383}], {
             RGBColor[
             0.8445911416031288, 0.8773936131697899, 0.8868693008964085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 293}], {
             RGBColor[
             0.6612023735827496, 0.7307034549406695, 0.9696859068545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 315}], {
             RGBColor[
             0.9435909344430307, 0.9572726592791703, 0.9741940477073607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 316}], {
             RGBColor[
             0.9150931005004037, 0.9351344150712635, 0.9917635909106248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 338}], {
             RGBColor[
             0.6035219299164634, 0.6779242338174019, 0.9661137891020561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 397}], {
             RGBColor[
             0.6013560292712242, 0.675647734913223, 0.9659904442644727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 282}], {
             RGBColor[
             0.4364931093735467, 0.5498232865754057, 0.9497707883553266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 332}], {
             RGBColor[
             0.6535543788235005, 0.7205916883765386, 0.9145241930698471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 367}], {
             RGBColor[
             0.41823541725914914`, 0.5350008696172811, 0.9483334759519514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 383}], {
             RGBColor[
             0.6560942454515373, 0.721641988498827, 0.8724320300791444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 398}], {
             RGBColor[
             0.655461523976475, 0.7213803419086884, 0.8829178623516158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 270}], {
             RGBColor[
             0.32309259032718496`, 0.448704563742018, 0.942011867522295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 274}], {
             RGBColor[
             0.45132251683991087`, 0.5639305292298012, 0.9503668020466919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 295}], {
             RGBColor[
             0.49726882203817013`, 0.6012318096472093, 0.9539838634987604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 324}], {
             RGBColor[
             0.350334968895203, 0.4773380308835684, 0.9435632806802561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 351}], {
             RGBColor[
             0.3734723035753579, 0.4979046709183651, 0.9450183028285988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 373}], {
             RGBColor[
             0.49138345304309416`, 0.5964538019641549, 0.953520545692651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 272}], {
             RGBColor[
             0.461099930004499, 0.5625005592563345, 0.9526716330422614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 350}], {
             RGBColor[
             0.6690207428215753, 0.7413633561289652, 0.9676453933563021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 355}], {
             RGBColor[
             0.5582738639754232, 0.6517367244087753, 0.9586778697184087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 392}], {
             RGBColor[
             0.4236031560860224, 0.5230890724352352, 0.9505362472391101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 395}], {
             RGBColor[
             0.46332985059765497`, 0.5648443471848731, 0.9527986237211697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 295}], {
             RGBColor[
             0.4227456978125379, 0.5311198933653063, 0.949439031394153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 310}], {
             RGBColor[
             0.5183456916859308, 0.6064993731354412, 0.958491660389642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 324}], {
             RGBColor[
             0.27581184466957087`, 0.4072261146016654, 0.9390184485756488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 346}], {
             RGBColor[
             0.5141356197169196, 0.6032104329155177, 0.9580720397611304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 351}], {
             RGBColor[
             0.29894917934972565`, 0.42779275463646216`, 0.9404734707239915]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 373}], {
             RGBColor[
             0.41686032881746204`, 0.5263418856822519, 0.9489757135880437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 390}], {
             RGBColor[
             0.6122080909831173, 0.6800498741080716, 0.931618212330044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 287}], {
             RGBColor[
             0.6720631376177923, 0.6309032796330878, 0.6013066641677896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 292}], {
             RGBColor[
             0.9571620153140487, 0.8552518481798794, 0.4478529534312601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 371}], {
             RGBColor[
             0.5518210998946358, 0.5152040593446747, 0.5940679089065659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 374}], {
             RGBColor[
             0.6416856493514145, 0.6045918261137058, 0.5993710374772141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 382}], {
             RGBColor[
             0.6679388427739685, 0.6273310227324538, 0.6010438677473118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 384}], {
             RGBColor[
             0.9543963172379145, 0.8547937847623261, 0.5435253412786871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 389}], {
             RGBColor[
             0.8810520475973801, 0.7984758510417277, 0.6195872006662624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 391}], {
             RGBColor[
             0.6713040522805891, 0.6302457980667406, 0.6012582959213357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 350}], {
             RGBColor[
             0.4618413606540296, 0.5630797705148294, 0.9527455319203433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 392}], {
             RGBColor[
             0.21642377391847661`, 0.34480548682109935`, 0.9356363858031513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 395}], {
             RGBColor[
             0.25615046843010925`, 0.38656076157073727`, 0.937898762285211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 322}], {
             RGBColor[
             0.9788705263189769, 0.9811775540271684, 0.7792479257364284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 330}], {
             RGBColor[
             0.6146783799526733, 0.6772577944539252, 0.7742853501833191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 295}], {
             RGBColor[
             0.5509756243252639, 0.6463458588530895, 0.9577939659185498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 296}], {
             RGBColor[
             0.43664541060214945`, 0.5512179574994612, 0.9494315898156772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 319}], {
             RGBColor[
             0.4261122008742091, 0.5420946206476336, 0.9487604230059645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 324}], {
             RGBColor[
             0.4040417711822968, 0.5224520800894487, 0.9473733831000455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 351}], {
             RGBColor[
             0.4271791058624516, 0.5430187201242453, 0.9488284052483882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 373}], {
             RGBColor[
             0.545090255330188, 0.6415678511700351, 0.9573306481124404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 276}], {
             RGBColor[
             0.320146421675915, 0.4474956528503246, 0.9417749696627493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 280}], {
             RGBColor[
             0.27869704016603297`, 0.41025863800040724`, 0.9391827561909081]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 288}], {
             RGBColor[
             0.3935818695047744, 0.5091806770423837, 0.946985008756188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 290}], {
             RGBColor[
             0.5657569587515141, 0.44463275154935833`, 0.5751063556542695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 297}], {
             RGBColor[
             0.31971049840944876`, 0.447118078027052, 0.9417471930176818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 318}], {
             RGBColor[
             0.3415788371674639, 0.46605933392458, 0.9431406242259299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 325}], {
             RGBColor[
             0.263892429026652, 0.3946980530263568, 0.9383396554879797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 339}], {
             RGBColor[
             0.6245288561732086, 0.69116131970876, 0.9102894548833071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 288}], {
             RGBColor[
             0.45063407576546977`, 0.562817249981633, 0.9504657800152774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 290}], {
             RGBColor[
             0.6228091650122095, 0.49826932448860767`, 0.5785871269133589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 297}], {
             RGBColor[
             0.37676270467014417`, 0.5007546509663013, 0.9452279642767711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 318}], {
             RGBColor[
             0.39863104342815925`, 0.5196959068638294, 0.9466213954850192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 278}], {
             RGBColor[
             0.7778343723943416, 0.826369390565425, 0.9784909190309327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 302}], {
             RGBColor[
             0.8887927412682646, 0.912237657057717, 0.9054866190609112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 314}], {
             RGBColor[
             0.8197685605074082, 0.8593792641666655, 0.9826040341911992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 352}], {
             RGBColor[
             0.7793940947477265, 0.8275878575222183, 0.978646377578684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 378}], {
             RGBColor[
             0.6488464817304689, 0.7235623332063356, 0.9670298744648506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 379}], {
             RGBColor[
             0.5968193671646418, 0.6800147744951707, 0.9632959567216511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 314}], {
             RGBColor[
             0.8090505141751263, 0.8510062449117177, 0.9815357594986349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 319}], {
             RGBColor[
             0.5571557043417367, 0.6465705170850314, 0.960383292941908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 352}], {
             RGBColor[
             0.7686760484154447, 0.8192148382672705, 0.9775781028861198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 379}], {
             RGBColor[
             0.5861013208323599, 0.6716417552402228, 0.9622276820290869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.7086033354627932, 0.7715490128718273, 0.9721153003679279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 288}], {
             RGBColor[
             0.5575273943611806, 0.6516648809221233, 0.9583097452557017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 309}], {
             RGBColor[
             0.6068069952894837, 0.6916722809764424, 0.9621892159579037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 325}], {
             RGBColor[
             0.42783795388305823`, 0.5371822569060964, 0.9496643919874934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 399}], {
             RGBColor[
             0.5165419123131971, 0.618086386106756, 0.9551673892874422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 297}], {
             RGBColor[
             0.33531332316026213`, 0.46351763611638397`, 0.9426357508049299]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 309}], {
             RGBColor[
             0.45846429518389087`, 0.5655876351860347, 0.9517530372456383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 322}], {
             RGBColor[
             0.6289122614589764, 0.6994877631333156, 0.9433493665380972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 325}], {
             RGBColor[
             0.2794952537774654, 0.41109761111568877`, 0.9392282132752279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 339}], {
             RGBColor[
             0.6401316809240221, 0.707560877798092, 0.9111780126705553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 355}], {
             RGBColor[
             0.4414103371814343, 0.5567491809630937, 0.9493472542547339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 386}], {
             RGBColor[
             0.7147872463077518, 0.7712852224193589, 0.8242446704812338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 367}], {
             RGBColor[
             0.5332779334390683, 0.6319780761197873, 0.9564007388632108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 383}], {
             RGBColor[
             0.7711367616314564, 0.8186191950013331, 0.8804992929904036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 398}], {
             RGBColor[
             0.7705040401563941, 0.8183575484111945, 0.8909851252628751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 294}], {
             RGBColor[
             0.5054263648499313, 0.5963793790356542, 0.9572083074348572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 320}], {
             RGBColor[
             0.2417536846399958, 0.3714288289985145, 0.937078886746497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 347}], {
             RGBColor[
             0.5763694134189935, 0.6524827031210209, 0.9640982456881322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 373}], {
             RGBColor[
             0.4167590977724317, 0.526235485435506, 0.948969948629787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 380}], {
             RGBColor[
             0.26061445169621084`, 0.39125269101629634`, 0.938152979528344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 381}], {
             RGBColor[
             0.4127098057427798, 0.5229480877473076, 0.9486511735281673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 332}], {
             RGBColor[
             0.7414500619556877, 0.7955298728600038, 0.9204543578414629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 338}], {
             RGBColor[
             0.3877472973324236, 0.5062569946256144, 0.9463606514866097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 367}], {
             RGBColor[
             0.5061311003913365, 0.6099390541007463, 0.9542636407235672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 399}], {
             RGBColor[
             0.6341599826479585, 0.7108079113080286, 0.966339018252683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 332}], {
             RGBColor[
             0.9238745149927925, 0.9406045841475732, 0.9370265255596659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 292}], {
             RGBColor[
             0.7093883680814991, 0.766268532533805, 0.7948026182997215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 371}], {
             RGBColor[
             0.30404745266208627`, 0.4262207436986002, 0.9410175737750275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 374}], {
             RGBColor[
             0.3939120021188649, 0.5156085104676312, 0.9463207023456754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 382}], {
             RGBColor[
             0.42016519554141896`, 0.5383477070863792, 0.9479935326157731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 384}], {
             RGBColor[
             0.7066226700053649, 0.7658104691162516, 0.8904750061471485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 389}], {
             RGBColor[
             0.6332784003648305, 0.7094925353956532, 0.9665368655347237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 391}], {
             RGBColor[
             0.4235304050480395, 0.5412624824206662, 0.9482079607897971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 303}], {
             RGBColor[
             0.68367827842115, 0.748674969112946, 0.9528612480328117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 376}], {
             RGBColor[
             0.47364396843850004`, 0.5824085756657709, 0.9520255302121239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 297}], {
             RGBColor[
             0.6223732417457433, 0.49789174966533506`, 0.5785593502682914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 318}], {
             RGBColor[
             0.6442415805037585, 0.516833005562863, 0.5799527814765395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 345}], {
             RGBColor[
             0.563400045555537, 0.44215548634345864`, 0.5749721329344992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 304}], {
             RGBColor[
             0.5569903851073594, 0.6512289126178801, 0.958267469920111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 383}], {
             RGBColor[
             0.8025624527654625, 0.8441319867751713, 0.8829732385125724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 371}], {
             RGBColor[
             0.5891463303583426, 0.6505693122453919, 0.787563863038498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 374}], {
             RGBColor[
             0.6790108798151212, 0.739957079014423, 0.7928669916091461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 382}], {
             RGBColor[
             0.7052640732376753, 0.762696275633171, 0.7945398218792438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 384}], {
             RGBColor[
             0.9917215477016212, 0.9901590376630434, 0.7370212954106191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 389}], {
             RGBColor[
             0.9183772780610868, 0.9338411039424449, 0.8130831547981944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 316}], {
             RGBColor[
             0.6475042494570717, 0.719780942588528, 0.968379367546933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 387}], {
             RGBColor[
             0.6940503841585866, 0.7529835417692652, 0.7938252955270002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 320}], {
             RGBColor[
             0.49881304547843497`, 0.5894283610675451, 0.9568316886801798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 347}], {
             RGBColor[
             0.8334287742574327, 0.8704822351900516, 0.983851047621815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 380}], {
             RGBColor[
             0.5176738125346501, 0.6092522230853271, 0.9579057814620268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 381}], {
             RGBColor[
             0.669769166581219, 0.7409476198163383, 0.9684039754618501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 310}], {
             RGBColor[
             0.6925219233969159, 0.7590266190406325, 0.9704636563661073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 324}], {
             RGBColor[
             0.449988076380556, 0.5597533605068568, 0.950990444552114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 351}], {
             RGBColor[
             0.4731254110607108, 0.5803200005416534, 0.9524454667004567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 373}], {
             RGBColor[
             0.5910365605284471, 0.6788691315874431, 0.9609477095645089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 390}], {
             RGBColor[
             0.7863843226941024, 0.832577120013263, 0.9435902083065095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 308}], {
             RGBColor[
             0.5084476407382362, 0.6094141209599844, 0.9551498432671179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 373}], {
             RGBColor[
             0.47670634680533275`, 0.5837412302338149, 0.9525853334616363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 380}], {
             RGBColor[
             0.3205617007291119, 0.4487584358146051, 0.9417683643601933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 318}], {
             RGBColor[
             0.39819512016169306`, 0.5193183320405568, 0.9465936188399517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 322}], {
             RGBColor[
             0.6699257197023922, 0.7363472031599603, 0.945913803364871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 339}], {
             RGBColor[
             0.6811451391674378, 0.7444203178247368, 0.9137424494973292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 313}], {
             RGBColor[
             0.8043523183744659, 0.8476931875684339, 0.980972694983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 361}], {
             RGBColor[
             0.5166340955307829, 0.6137488051490321, 0.9568379516105475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 393}], {
             RGBColor[
             0.48803235971882886`, 0.5847033067438214, 0.9551718972589194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 396}], {
             RGBColor[
             0.6624525570317128, 0.7357576781291757, 0.9673151981603999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 306}], {
             RGBColor[
             0.45435112252106535`, 0.5565063293271089, 0.9521132797985383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 342}], {
             RGBColor[
             0.4554449485503188, 0.55765600983643, 0.9521755715727337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 353}], {
             RGBColor[
             0.6875153447710098, 0.7558114797360443, 0.9694887624367401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 319}], {
             RGBColor[
             0.6449805305258216, 0.7159901019008679, 0.962555195213119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 343}], {
             RGBColor[
             0.6212227517510942, 0.6910997794413342, 0.9411585835108762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 358}], {
             RGBColor[
             0.3696341260578005, 0.4913921759030702, 0.9449492559378747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 359}], {
             RGBColor[
             0.27617636913342997`, 0.4076092529253672, 0.9390392077045999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 362}], {
             RGBColor[
             0.3525998880818218, 0.4768832436740928, 0.9437960809284173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 369}], {
             RGBColor[
             0.519701462900228, 0.611383412180008, 0.9580212531507065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 394}], {
             RGBColor[
             0.2560287826902925, 0.3864328621428683, 0.9378918324623463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 397}], {
             RGBColor[
             0.2754190170142261, 0.40681322782918616`, 0.9389960776218133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 314}], {
             RGBColor[
             0.9200088830490493, 0.9368745114040098, 0.9085314595286136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 352}], {
             RGBColor[
             0.8796344172893675, 0.9050831047595624, 0.9045738029160983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 377}], {
             RGBColor[
             0.991121410101303, 0.9888087923775072, 0.6668580580744388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 379}], {
             RGBColor[
             0.6970596897062828, 0.7575100217325148, 0.8892233820590656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 376}], {
             RGBColor[
             0.7465774097753053, 0.8008952787068722, 0.9574935025399514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 383}], {
             RGBColor[
             0.745165830051344, 0.797534822767463, 0.8784547661217602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 334}], {
             RGBColor[
             0.8594459290520343, 0.8907628710605635, 0.9864559140210629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 340}], {
             RGBColor[
             0.8046863686704913, 0.8474157155467104, 0.9811488739960359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 360}], {
             RGBColor[
             0.8041935387090892, 0.8470307130352166, 0.9810997533112412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 370}], {
             RGBColor[
             0.8273092554465453, 0.865137959854313, 0.9833906894038242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 342}], {
             RGBColor[
             0.24966329213080624`, 0.3797423279694363, 0.937529327191883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 353}], {
             RGBColor[
             0.4817336883514973, 0.5778977978690505, 0.9548425180558893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 361}], {
             RGBColor[
             0.28415618762559147`, 0.41497980872239987`, 0.9395308743722586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 312}], {
             RGBColor[
             0.29361430953288453`, 0.42492089452652965`, 0.9400695004228414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 341}], {
             RGBColor[
             0.4418242846658018, 0.5541050072188642, 0.9502032895161507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 348}], {
             RGBColor[
             0.4930567346618032, 0.5953299916436057, 0.954487980622092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 366}], {
             RGBColor[
             0.35197416509975593`, 0.4792840638986563, 0.943648460454991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 325}], {
             RGBColor[
             0.44365968404450995`, 0.5500270502119842, 0.95090993654271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 339}], {
             RGBColor[
             0.8042961111910665, 0.8464903168943875, 0.9228597359380375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 323}], {
             RGBColor[
             0.8314171943982391, 0.8686710482204751, 0.9837141679162229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 324}], {
             RGBColor[
             0.5455880702539488, 0.6351328402769916, 0.9600430735476031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 346}], {
             RGBColor[
             0.7839118453012974, 0.8311171585908439, 0.9790966647330848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 389}], {
             RGBColor[
             0.8151946138073635, 0.8557356028075302, 0.9821668436973965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 390}], {
             RGBColor[
             0.8819843165674952, 0.9079565997833978, 0.9526428373019984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 313}], {
             RGBColor[
             0.7567238666071321, 0.810116441460009, 0.976477849045521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 361}], {
             RGBColor[
             0.4690056437634491, 0.5761720590406072, 0.9523431056729166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 386}], {
             RGBColor[
             0.8066453062043523, 0.8463692674780703, 0.8313352877153006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 348}], {
             RGBColor[
             0.4669281350450576, 0.5688839161854506, 0.9529627677181038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 366}], {
             RGBColor[
             0.3258455654830103, 0.4528379884405012, 0.9421232475510029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 361}], {
             RGBColor[
             0.6074611319933132, 0.6853113524040866, 0.965729456699434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 393}], {
             RGBColor[
             0.5788593961813592, 0.656265853998876, 0.9640634023478059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 396}], {
             RGBColor[
             0.7532795934942431, 0.8073202253842303, 0.9762067032492864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 352}], {
             RGBColor[
             0.8106102365285113, 0.8522247118685111, 0.9816912180463864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 379}], {
             RGBColor[
             0.6280355089454265, 0.7046516288414635, 0.9663407971893534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 316}], {
             RGBColor[
             0.9298928103173527, 0.9463501469270288, 0.9728875083997938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 358}], {
             RGBColor[
             0.7103708481317476, 0.7714424148428723, 0.9530675400697031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 359}], {
             RGBColor[
             0.616913091207377, 0.6876594918651694, 0.9471574918364281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 362}], {
             RGBColor[
             0.6933366101557689, 0.7569334826138949, 0.9519143650602455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 363}], {
             RGBColor[
             0.8467170313577579, 0.8807145816300352, 0.9647719409215211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 369}], {
             RGBColor[
             0.8604381849741751, 0.8914336511198102, 0.9661395372825348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 397}], {
             RGBColor[
             0.6161557390881732, 0.6868634667689884, 0.9471143617536415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 358}], {
             RGBColor[
             0.6818730141891206, 0.7493041706349657, 0.9706370832729672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 359}], {
             RGBColor[
             0.5884152572647501, 0.6655212476572626, 0.9647270350396924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 362}], {
             RGBColor[
             0.6648387762131419, 0.7347952384059881, 0.9694839082635097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 363}], {
             RGBColor[
             0.8182191974151309, 0.8585763374221285, 0.9823414841247853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 369}], {
             RGBColor[
             0.8319403510315482, 0.8692954069119034, 0.983709080485799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 397}], {
             RGBColor[
             0.5876579051455463, 0.6647252225610816, 0.9646839049569057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 326}], {
             RGBColor[
             0.45826103441077154`, 0.5641558697414328, 0.9518523432034134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 327}], {
             RGBColor[
             0.5119551172453569, 0.6129778153275534, 0.9551889254241781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 336}], {
             RGBColor[
             0.44547009762278966`, 0.5507117841850309, 0.9511239182758331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 396}], {
             RGBColor[
             0.6220963859213997, 0.7040848970706306, 0.9633928527953315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 345}], {
             RGBColor[
             0.33922192397148676`, 0.4635820687186803, 0.9430064015061596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 347}], {
             RGBColor[
             0.569756094047497, 0.6455316851529118, 0.9637216269334548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 380}], {
             RGBColor[
             0.25400113232471444`, 0.3843016730481874, 0.9377763607736666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 381}], {
             RGBColor[
             0.4060964863712835, 0.5159970697791986, 0.9482745547734899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 384}], {
             RGBColor[
             0.6120481074469932, 0.6770893926379478, 0.8846979756249328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 341}], {
             RGBColor[
             0.7486598570946217, 0.7152794937913428, 0.612046727233966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 366}], {
             RGBColor[
             0.6588097375285757, 0.6404585504711349, 0.6054918981728061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 330}], {
             RGBColor[
             0.599332511634803, 0.6683975706036487, 0.9416648435449289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 339}], {
             RGBColor[
             0.9747440774661521, 0.9803904448416684, 0.9144560652304963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 346}], {
             RGBColor[
             0.8272071224292279, 0.8653821080005516, 0.9832945472877113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 346}], {
             RGBColor[
             0.5413779982849376, 0.631843900057068, 0.9596234529190915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 351}], {
             RGBColor[
             0.32619155791774374`, 0.4564262217780125, 0.9420248838819525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 390}], {
             RGBColor[
             0.6394504695511354, 0.7086833412496221, 0.9331696254880052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 339}], {
             RGBColor[
             0.6253270697846411, 0.6920002928240416, 0.9103349119676271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 327}], {
             RGBColor[
             0.3374032119648188, 0.4643486068726972, 0.9428047694634627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 336}], {
             RGBColor[
             0.2709181923422516, 0.4020825757301747, 0.9387397623151177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 336}], {
             RGBColor[
             0.32461227517683694`, 0.4509045213162951, 0.9420763445358824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 376}], {
             RGBColor[
             0.46382019729602975`, 0.5738997188592574, 0.9513995682017454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 364}], {
             RGBColor[
             0.6973575130385289, 0.7635002563898794, 0.9704697377893546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 386}], {
             RGBColor[
             0.8712490909783523, 0.897207272748612, 0.8375220762035298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 400}], {
             RGBColor[
             0.6298430993885309, 0.708763770472383, 0.9651036443559692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 349}], {
             RGBColor[
             0.4886991418835397, 0.5826882901550924, 0.9556398279395887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 335}], {
             RGBColor[
             0.5984105269214988, 0.6833418037731172, 0.9625632399379056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 338}], {
             RGBColor[
             0.36694572688436894`, 0.4893693426358141, 0.9447230756622755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 368}], {
             RGBColor[
             0.7249300116125421, 0.6721039946997756, 0.6046735082586127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 340}], {
             RGBColor[
             0.8355692303669513, 0.8720408711705186, 0.9840945089141004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 360}], {
             RGBColor[
             0.8350764004055492, 0.8716558686590249, 0.9840453882293057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 365}], {
             RGBColor[
             0.5542036532624797, 0.6309663760574552, 0.96256608492156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 370}], {
             RGBColor[
             0.8581921171430054, 0.8897631154781214, 0.9863363243218888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 394}], {
             RGBColor[
             0.4881613002748021, 0.5811071367582052, 0.9557700222645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 396}], {
             RGBColor[
             0.43475354385287984`, 0.5420116030593723, 0.9502802719070358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 367}], {
             RGBColor[
             0.43031095869124525`, 0.545460096671403, 0.9491029187740225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 398}], {
             RGBColor[
             0.667537065408571, 0.7318395689628103, 0.8836873051736869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 399}], {
             RGBColor[
             0.3938501177780911, 0.5155549093620503, 0.9463167591302035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 360}], {
             RGBColor[
             0.7803168400240061, 0.8283087131451717, 0.9787383482042786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 370}], {
             RGBColor[
             0.8034325567614622, 0.8464159599642682, 0.9810292842968618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 348}], {
             RGBColor[
             0.6151381101779749, 0.6980680288777852, 0.9630965568114132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 366}], {
             RGBColor[
             0.4740555406159276, 0.5820221011328358, 0.9522570366443122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 353}], {
             RGBColor[
             0.4828275143807508, 0.5790474783783718, 0.9549048098300847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 358}], {
             RGBColor[
             0.7139396776968091, 0.7741040420890732, 0.9470264425158779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 359}], {
             RGBColor[
             0.6204819207724386, 0.6903211191113702, 0.941116394282603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 362}], {
             RGBColor[
             0.6969054397208304, 0.7595951098600957, 0.9458732675064203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 369}], {
             RGBColor[
             0.8640070145392367, 0.894095278366011, 0.9600984397287096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 354}], {
             RGBColor[
             0.872258337021242, 0.9001526162297602, 0.9415542192929434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 356}], {
             RGBColor[
             0.7380184071457765, 0.7929728257910523, 0.9297541643641143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 388}], {
             RGBColor[
             0.9454802768249887, 0.9580530394987721, 0.9486668347309655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 390}], {
             RGBColor[
             0.877774244598484, 0.9046676595634743, 0.9522232166734869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 380}], {
             RGBColor[
             0.5886168611037121, 0.6653555471706938, 0.9647957197153016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 381}], {
             RGBColor[
             0.7407122151502812, 0.7970509439017051, 0.9752939137151251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 384}], {
             RGBColor[
             0.9466638362259909, 0.9581432667604541, 0.9117173345665679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 366}], {
             RGBColor[
             0.525287990611929, 0.6232470855575772, 0.9565417277502534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 355}], {
             RGBColor[
             0.5590152946249538, 0.6523159356672703, 0.9587517685964906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 392}], {
             RGBColor[
             0.424344586735553, 0.5236682836937301, 0.9506101461171921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 395}], {
             RGBColor[
             0.46407128124718555`, 0.565423558443368, 0.9528725225992516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 379}], {
             RGBColor[
             0.5876610431857447, 0.6728602221970161, 0.9623831405768383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 371}], {
             RGBColor[
             0.4719066893006132, 0.5614823939942072, 0.9552464838597937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 388}], {
             RGBColor[
             0.8332299034660433, 0.870343687847239, 0.9838267646438055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 392}], {
             RGBColor[
             0.31359770788940083`, 0.4340416519735402, 0.9416426224792986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 395}], {
             RGBColor[
             0.35332440240103347`, 0.47579692672317814`, 0.9439049989613583]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 363}], {
             RGBColor[
             0.6132857611834508, 0.6955122279129733, 0.9636699779973189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 372}], {
             RGBColor[
             0.44181344685690066`, 0.5560608403973263, 0.9496596027041793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 364}], {
             RGBColor[
             0.5316399894246924, 0.6295614021639455, 0.9566025683892713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 385}], {
             RGBColor[
             0.45430334992555294`, 0.566850790815884, 0.9504632333570426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 359}], {
             RGBColor[
             0.3688932950791449, 0.4906135155731063, 0.9449070667096016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 362}], {
             RGBColor[
             0.44531681402753676`, 0.5598875063218318, 0.949663939933419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 363}], {
             RGBColor[
             0.5986972352295257, 0.6836686053379721, 0.9625215157946945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 369}], {
             RGBColor[
             0.6124183888459429, 0.6943876748277471, 0.9638891121557083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 372}], {
             RGBColor[
             0.42722492090297554`, 0.5442172178223251, 0.9485111405015548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 397}], {
             RGBColor[
             0.3681359429599411, 0.48981749047692524`, 0.944863936626815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 362}], {
             RGBColor[
             0.35185905710316623`, 0.47610458334412886`, 0.943753891700144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 369}], {
             RGBColor[
             0.5189606319215725, 0.610604751850044, 0.9579790639224333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 394}], {
             RGBColor[
             0.2552879517116369, 0.3856542018129044, 0.937849643234073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 397}], {
             RGBColor[
             0.2746781860355706, 0.40603456749922223`, 0.93895388839354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 370}], {
             RGBColor[
             0.8029397268000602, 0.8460309574527745, 0.980980163612067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 393}], {
             RGBColor[
             0.29114117333767614`, 0.4223214715794742, 0.9399286589752014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 396}], {
             RGBColor[
             0.46556137065056, 0.5733758429648284, 0.9520719598766819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 363}], {
             RGBColor[
             0.581662997253547, 0.6691596731089946, 0.961368340785237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 369}], {
             RGBColor[
             0.5953841508699642, 0.6798787425987696, 0.9627359371462507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 397}], {
             RGBColor[
             0.3511017049839624, 0.4753085582479478, 0.9437107616173575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 369}], {
             RGBColor[
             0.7487645720719532, 0.8036598416149099, 0.9755935130075263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 372}], {
             RGBColor[
             0.5635711041289858, 0.653489384609488, 0.9602155413533728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 385}], {
             RGBColor[
             0.5699024386526501, 0.6616367427940842, 0.9593350655510184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 370}], {
             RGBColor[
             0.5220669796569907, 0.6053414648512048, 0.9595008603043212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 398}], {
             RGBColor[
             0.7522463480419965, 0.80353513145307, 0.8895478128594998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 372}], {
             RGBColor[
             0.577292257745403, 0.664208454099263, 0.9615831377143866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 389}], {
             RGBColor[
             0.5130363626416741, 0.5937933151072401, 0.9592981102735003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 391}], {
             RGBColor[
             0.30328836732488307`, 0.42556326213225315`, 0.9409692055285737]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 380}], {
             RGBColor[
             0.4290065454571504, 0.5391083294851791, 0.9496674226569566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 382}], {
             RGBColor[
             0.3897877072750411, 0.5120362535669972, 0.9460579059251977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 384}], {
             RGBColor[
             0.6762451817389872, 0.7394990155968696, 0.888539379456573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 389}], {
             RGBColor[
             0.6029009120984526, 0.6831810818762711, 0.9646012388441483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 377}], {
             RGBColor[
             0.7849782631109905, 0.827576358105039, 0.7310624183229972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 379}], {
             RGBColor[
             0.4571134301684871, 0.5688346978811334, 0.9507666374630048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 381}], {
             RGBColor[
             0.4249572534274985, 0.5358209317969805, 0.949348647555337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 384}], {
             RGBColor[
             0.7024983751615411, 0.7622382122156176, 0.8902122097266707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 389}], {
             RGBColor[
             0.6291541055210067, 0.7059202784950191, 0.966274069114246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 389}], {
             RGBColor[
             0.9156115799849527, 0.9333830405248915, 0.9087555426456213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 387}], {
             RGBColor[
             0.7435265224656331, 0.7947716162633097, 0.7972723190409909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 400}], {
             RGBColor[
             0.7536162424416151, 0.8033178845833818, 0.8271606455640368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 390}], {
             RGBColor[
             0.90905701310455, 0.9292861037801607, 0.9552933956377986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 395}], {
             RGBColor[
             0.21865369451163263`, 0.34714927474963797`, 0.9357633764820597]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 396}], {
             RGBColor[
             0.436959634838606, 0.5443303445596178, 0.9504059055250538]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.08420038484809576], {
             RGBColor[
             0.9948065985851545, 0.9913001644441017, 0.6761084898315186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.08420038484809576], {
             RGBColor[
             0.33547804784385715`, 0.4649959562505578, 0.9425973424503888]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.08420038484809576], {
             RGBColor[
             0.18445586758645585`, 0.31120519038381694`, 0.933815860829822]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.08420038484809576], {
             RGBColor[
             0.7990199091488599, 0.8429196928940976, 0.9806024953445259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.08420038484809576], {
             RGBColor[
             0.6419453417997504, 0.7201991736379478, 0.9649554353111964]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.08420038484809576], {
             RGBColor[
             0.5487166511051903, 0.6445119226274499, 0.957616131271774]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.08420038484809576], {
             RGBColor[
             0.8856750329144885, 0.9116772465104267, 0.9889576693624613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.08420038484809576], {
             RGBColor[
             0.28045328974086736`, 0.4121045676562127, 0.9392827720060564]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.08420038484809576], {
             RGBColor[
             0.22504504737187456`, 0.35386699184092885`, 0.9361273545722912]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.08420038484809576], {
             RGBColor[
             0.32164283796516335`, 0.4530125928315007, 0.9417157751109142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.08420038484809576], {
             RGBColor[
             0.7148979106014419, 0.7772029482779861, 0.972218000694091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.08420038484809576], {
             RGBColor[
             0.9928865340144208, 0.9913264132542953, 0.7675520706482944]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.08420038484809576], {
             RGBColor[
             0.7010925856975321, 0.7664181235386963, 0.9708420149257655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.08420038484809576], {
             RGBColor[
             0.8806917121149128, 0.9077036817734847, 0.9884823557759348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.08420038484809576], {
             RGBColor[
             0.6524685906514313, 0.7284326890526329, 0.9659956295166386]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.08420038484809576], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.08420038484809576], {
             RGBColor[
             0.5242899227912118, 0.6246812041705919, 0.9556931697408436]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.08420038484809576], {
             RGBColor[
             0.9416028020008786, 0.9559680458656667, 0.9837354031706818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.08420038484809576], {
             RGBColor[
             0.6610578844930827, 0.7351427106827819, 0.9668517300552598]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.08420038484809576], {
             RGBColor[
             0.17918486493438585`, 0.30566503239562065`, 0.9335156850265364]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.08420038484809576], {
             RGBColor[
             0.7348139569504978, 0.792761515053427, 0.9742030460681301]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.08420038484809576], {
             RGBColor[
             0.49641456178715837`, 0.6020507303367987, 0.9534987192117926]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.08420038484809576], {
             RGBColor[
             0.9935218820879124, 0.9915891460103847, 0.7570227088424326]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.08420038484809576], {
             RGBColor[
             0.456891346960931, 0.5699640040403299, 0.9503873069623657]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.08420038484809576], {
             RGBColor[
             0.3333985865524349, 0.46319483139669126`, 0.9424648410156948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.08420038484809576], {
             RGBColor[
             0.2730143540378202, 0.40428577457654497`, 0.938859135622687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.08420038484809576], {
             RGBColor[
             0.40060129833843744`, 0.5214024426392211, 0.9467469383856741]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.08420038484809576], {
             RGBColor[
             0.9198367848503419, 0.7198865952791622, 0.25435699929932803`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.08420038484809576], {
             RGBColor[
             0.9802841904729936, 0.9451560863524973, 0.37790823231614445`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.08420038484809576], {
             RGBColor[
             0.4958916957431339, 0.6016262441274128, 0.9534575572814856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.08420038484809576], {
             RGBColor[
             0.4930554897804407, 0.5993236843572759, 0.9532342807587376]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.08420038484809576], {
             RGBColor[
             0.30762397807490793`, 0.4406626838164293, 0.9408301025112487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.08420038484809576], {
             RGBColor[
             0.9511174975976722, 0.9630640902628712, 0.9676295053553601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.08420038484809576], {
             RGBColor[
             0.838632689988928, 0.8741669591919665, 0.9844707286990261]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.08420038484809576], {
             RGBColor[
             0.9910706725649463, 0.9905755078794268, 0.7976455941648797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.08420038484809576], {
             RGBColor[
             0.28144069176500697`, 0.4131423897884876, 0.9393390030906007]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.08420038484809576], {
             RGBColor[
             0.9520495081601681, 0.8475993089489144, 0.2802761126042113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.08420038484809576], {
             RGBColor[
             0.4274659520456407, 0.5446712554236448, 0.9484587303644166]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.08420038484809576], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.08420038484809576], {
             RGBColor[
             0.20751233257912907`, 0.3354389969554303, 0.9351288924021716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.08420038484809576], {
             RGBColor[
             0.4720199967287173, 0.5822461234597242, 0.9515782896901559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.08420038484809576], {
             RGBColor[
             0.5255597659399571, 0.6257121200445253, 0.9557931364451016]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.08420038484809576], {
             RGBColor[
             0.8901259614183403, 0.9152262960821624, 0.9893822028965494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.08420038484809576], {
             RGBColor[
             0.8206189672876125, 0.8598033056794143, 0.9827525637467345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.08420038484809576], {
             RGBColor[
             0.9932483846450529, 0.9879673023858203, 0.5065065186332045]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.08420038484809576], {
             RGBColor[
             0.8727044713664822, 0.9013348728085605, 0.9877205256230555]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.08420038484809576], {
             RGBColor[
             0.9412470725120512, 0.8047712513024178, 0.2715842193159824]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.08420038484809576], {
             RGBColor[
             0.3726016187351638, 0.49715052747168154`, 0.9449628235604981]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.08420038484809576], {
             RGBColor[
             0.935710744009702, 0.9515737586632067, 0.9937091204549027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.08420038484809576], {
             RGBColor[
             0.745095539488423, 0.8007935654749756, 0.9752278181286589]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.08420038484809576], {
             RGBColor[
             0.694592117177041, 0.7613399081250981, 0.9701941089739751]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.08420038484809576], {
             RGBColor[
             0.2506957167509515, 0.3808274717047106, 0.9375881222466649]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.08420038484809576], {
             RGBColor[
             0.5752672796495748, 0.6660669189719667, 0.959706294008945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.08420038484809576], {
             RGBColor[
             0.9749833092345896, 0.9808631735050042, 0.9272309114546321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.08420038484809576], {
             RGBColor[
             0.284402636656804, 0.4162555816679191, 0.9395076814703838]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.08420038484809576], {
             RGBColor[
             0.5344053224842427, 0.6328933413349574, 0.9564894910586089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.08420038484809576], {
             RGBColor[
             0.46784377655825904`, 0.5788556797887714, 0.9512495223403389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.08420038484809576], {
             RGBColor[
             0.5765855615916687, 0.6671371596404833, 0.9598100739924524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.08420038484809576], {
             RGBColor[
             0.31050265695157414`, 0.44336352795930795`, 0.9410059326276036]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.08420038484809576], {
             RGBColor[
             0.43218935015145965`, 0.5487624254580135, 0.9487597011149825]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.08420038484809576], {
             RGBColor[
             0.21913021617489342`, 0.3476501292309435, 0.9357905136858318]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.08420038484809576], {
             RGBColor[
             0.6757315017146623, 0.7466058519799014, 0.9683142590871576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.08420038484809576], {
             RGBColor[
             0.3279686983843273, 0.45849173517959113`, 0.9421188533430845]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.08420038484809576], {
             RGBColor[
             0.44522634867631095`, 0.5600544183216414, 0.9495904071328208]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.08420038484809576], {
             RGBColor[
             0.48783378257266996`, 0.5950844672107787, 0.9528232088395981]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.08420038484809576], {
             RGBColor[
             0.6654875909869538, 0.7386032310628102, 0.9672932418006082]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.08420038484809576], {
             RGBColor[
             0.9429512731274311, 0.8115278388512093, 0.2729554591338469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.08420038484809576], {
             RGBColor[
             0.4274659520456407, 0.5446712554236448, 0.9484587303644166]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.08420038484809576], {
             RGBColor[
             0.43056352721768226`, 0.5473542193490122, 0.948656105115301]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.08420038484809576], {
             RGBColor[
             0.9665419111038577, 0.9745675926006253, 0.9415199966207232]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.08420038484809576], {
             RGBColor[
             0.8879134951892751, 0.9134621355669018, 0.9891711758925293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.08420038484809576], {
             RGBColor[
             0.3994674099165776, 0.5204203254790952, 0.9466746880180914]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.08420038484809576], {
             RGBColor[
             0.9596957158867039, 0.9694617114172878, 0.9531088193496798]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.08420038484809576], {
             RGBColor[
             0.6926954437062757, 0.759858212394484, 0.9700050662878306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.08420038484809576], {
             RGBColor[
             0.7543652050250479, 0.8080350986442544, 0.9761517317594001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.08420038484809576], {
             RGBColor[
             0.4665109261584233, 0.5777736117899585, 0.9511445954744719]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.08420038484809576], {
             RGBColor[
             0.3971940509865405, 0.5184512562362393, 0.9465298315973218]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.08420038484809576], {
             RGBColor[
             0.24642773608906224`, 0.37634155342346165`, 0.9373450670618818]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.08420038484809576], {
             RGBColor[
             0.5175134036585041, 0.6191797206599517, 0.9551596973315093]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.08420038484809576], {
             RGBColor[
             0.36408895519492723`, 0.48977728617203875`, 0.944420404167167]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.08420038484809576], {
             RGBColor[
             0.6478614185537592, 0.7248335311941266, 0.9655364296584138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.08420038484809576], {
             RGBColor[
             0.7140284100516273, 0.776523687840022, 0.9721313370052301]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.08420038484809576], {
             RGBColor[
             0.6255640387973884, 0.7069000938913399, 0.9636658391321603]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.08420038484809576], {
             RGBColor[
             0.2263162165713289, 0.3552030712663376, 0.9361997457776738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.08420038484809576], {
             RGBColor[
             0.6533664931037626, 0.7291341372727055, 0.9660851240417115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.08420038484809576], {
             RGBColor[
             0.9250494034760692, 0.9430733008074145, 0.9927132319765404]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.08420038484809576], {
             RGBColor[
             0.9175718425221606, 0.9371108966757526, 0.9920000155374591]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.08420038484809576], {
             RGBColor[
             0.8587308762172109, 0.8901927073396674, 0.9863877116433423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.08420038484809576], {
             RGBColor[
             0.33547804784385715`, 0.4649959562505578, 0.9425973424503888]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.08420038484809576], {
             RGBColor[
             0.23994065437711598`, 0.36952321923946974`, 0.9369756373551639]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.08420038484809576], {
             RGBColor[
             0.22082021159720608`, 0.3494264215716927, 0.9358867564250083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.08420038484809576], {
             RGBColor[
             0.3806245289808775, 0.504099569083325, 0.945474036306974]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.08420038484809576], {
             RGBColor[
             0.3759056599373993, 0.5000123218951185, 0.9451733541442556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.08420038484809576], {
             RGBColor[
             0.45606552107880416`, 0.5692935613861873, 0.9503222949238248]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.08420038484809576], {
             RGBColor[
             0.2351403652684994, 0.3644778110304055, 0.9367022679918195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.08420038484809576], {
             RGBColor[
             0.9946542480762123, 0.9920574084470252, 0.7382564739470651]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.08420038484809576], {
             RGBColor[
             0.6779425856679135, 0.7483331675690417, 0.9685346392718633]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.08420038484809576], {
             RGBColor[
             0.3610600699792802, 0.4871538180344427, 0.944227406279564]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.08420038484809576], {
             RGBColor[
             0.7000972294985534, 0.7656405437110669, 0.9707428071219839]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.08420038484809576], {
             RGBColor[
             0.4127316167853028, 0.5319091147903633, 0.947519871550689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.08420038484809576], {
             RGBColor[
             0.3314906829151074, 0.4615423011600633, 0.9423432710830173]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.08420038484809576], {
             RGBColor[
             0.7657681502972928, 0.8169431661565261, 0.9772882707775553]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.08420038484809576], {
             RGBColor[
             0.37666981320106396`, 0.5006741930446451, 0.9452220453145022]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.08420038484809576], {
             RGBColor[
             0.9896451711941724, 0.9899860264288977, 0.8212698409578952]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.08420038484809576], {
             RGBColor[
             0.41002970140221917`, 0.529568851487752, 0.9473477078916889]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.08420038484809576], {
             RGBColor[
             0.9929038000872327, 0.9872302708594857, 0.46900061604384996`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.08420038484809576], {
             RGBColor[
             0.8358248060970406, 0.8719280287945533, 0.9842029102267903]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.08420038484809576], {
             RGBColor[
             0.4473444412325766, 0.5618890036354514, 0.9497253701175504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.08420038484809576], {
             RGBColor[
             0.731294745505352, 0.7900122803254815, 0.9738522839601788]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.08420038484809576], {
             RGBColor[
             0.9947550565550263, 0.9911899212533559, 0.6704984579325936]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.08420038484809576], {
             RGBColor[
             0.3182572804720307, 0.45008019309401653`, 0.9415000503811827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.08420038484809576], {
             RGBColor[
             0.5500308526798752, 0.6455788506698854, 0.9577195900338122]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.08420038484809576], {
             RGBColor[
             0.8783238539302267, 0.9058156159308142, 0.9882565073484675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.08420038484809576], {
             RGBColor[
             0.6816204787197124, 0.7512063655741295, 0.968901217279402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.08420038484809576], {
             RGBColor[
             0.9925397946220252, 0.9864516999760051, 0.42938086753736365`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.08420038484809576], {
             RGBColor[
             0.440187582329164, 0.555690092167503, 0.9492693413967868]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.08420038484809576], {
             RGBColor[
             0.8826436490470732, 0.9092601032992728, 0.9886685332630389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.08420038484809576], {
             RGBColor[
             0.5801164915298362, 0.6700037276308686, 0.9600880417314076]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.08420038484809576], {
             RGBColor[
             0.31778486431562036`, 0.4496710099636603, 0.9414699484414375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.08420038484809576], {
             RGBColor[
             0.4994426429484544, 0.6045090630370407, 0.9537371008530366]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.08420038484809576], {
             RGBColor[
             0.575555927907293, 0.6663012566310381, 0.959729017457146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.08420038484809576], {
             RGBColor[
             0.5798480634624531, 0.6697858056332203, 0.9600669100906588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.08420038484809576], {
             RGBColor[
             0.9624739507261154, 0.8850779656431179, 0.30871881408108387`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.08420038484809576], {
             RGBColor[
             0.3182572804720307, 0.45008019309401653`, 0.9415000503811827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.08420038484809576], {
             RGBColor[
             0.9397797247881848, 0.9546083978654547, 0.9868213973570836]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.08420038484809576], {
             RGBColor[
             0.3232261687291954, 0.4543839943587872, 0.9418166635471139]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.08420038484809576], {
             RGBColor[
             0.822435631411119, 0.8612518643394643, 0.9829258387925898]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.08420038484809576], {
             RGBColor[
             0.9948133946020434, 0.9913147004370444, 0.6768481943297207]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.08420038484809576], {
             RGBColor[
             0.9946542480762123, 0.9920574084470252, 0.7382564739470651]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.08420038484809576], {
             RGBColor[
             0.7474759479252682, 0.8026531586376132, 0.9754650749954621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.08420038484809576], {
             RGBColor[
             0.2878359597202321, 0.41986422189283723`, 0.9397032041396998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.08420038484809576], {
             RGBColor[
             0.26487219717979793`, 0.395727851476202, 0.9383954518348643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.08420038484809576], {
             RGBColor[
             0.5089637376562443, 0.6122387166412531, 0.9544866363053529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.08420038484809576], {
             RGBColor[
             0.3667703548191858, 0.4920997797555077, 0.9445912605801562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.08420038484809576], {
             RGBColor[
             0.33193466615008266`, 0.46192685712295256`, 0.9423715613021509]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.08420038484809576], {
             RGBColor[
             0.7745827557916806, 0.8238292029622247, 0.9781668282760643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.08420038484809576], {
             RGBColor[
             0.2930840102520079, 0.4253802557473558, 0.9400020728536893]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.08420038484809576], {
             RGBColor[
             0.549183241886987, 0.6448907220437877, 0.9576528630072955]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.08420038484809576], {
             RGBColor[
             0.17928515899630548`, 0.305770447813709, 0.9335213966249909]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.08420038484809576], {
             RGBColor[
             0.2844054337391649, 0.4162585215788257, 0.9395078407600863]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.08420038484809576], {
             RGBColor[
             0.9333381073253877, 0.9496824882659887, 0.9935038159491016]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.08420038484809576], {
             RGBColor[
             0.30303431102286577`, 0.43583865274303446`, 0.9405687277624388]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.08420038484809576], {
             RGBColor[
             0.36317696076986633`, 0.4889873624392236, 0.9443622926888472]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.08420038484809576], {
             RGBColor[
             0.7515712141082083, 0.8058524117049018, 0.9758732528561391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.08420038484809576], {
             RGBColor[
             0.994344726552349, 0.9919294133425673, 0.743386046613506]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.08420038484809576], {
             RGBColor[
             0.5393314366248289, 0.6368925827131984, 0.9568772928087066]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.08420038484809576], {
             RGBColor[
             0.9929138633010389, 0.9872517950562704, 0.4700959347637071]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.08420038484809576], {
             RGBColor[
             0.2437448675978899, 0.37352168853555245`, 0.9371922816702578]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.08420038484809576], {
             RGBColor[
             0.5773352759321528, 0.6677458115163344, 0.9598690942516295]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.08420038484809576], {
             RGBColor[
             0.9799034170464469, 0.9845325818551502, 0.9189024522987927]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.08420038484809576], {
             RGBColor[
             0.5955980222793184, 0.6825723317283106, 0.9613068045427225]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.08420038484809576], {
             RGBColor[
             0.6616937665057561, 0.7356394665439647, 0.9669151088316279]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.08420038484809576], {
             RGBColor[
             0.9264012307528464, 0.9441512111835426, 0.9928421704689899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.08420038484809576], {
             RGBColor[
             0.36499922662722395`, 0.4905657175351217, 0.9444784058579115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.08420038484809576], {
             RGBColor[
             0.28844634003034064`, 0.42050577029910813`, 0.9397379643953836]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.08420038484809576], {
             RGBColor[
             0.9011548904883853, 0.9240204647503119, 0.9904341519968916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.08420038484809576], {
             RGBColor[
             0.9675482301148659, 0.975318103671339, 0.9398165610251193]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.08420038484809576], {
             RGBColor[
             0.30152831870287067`, 0.4342557593292915, 0.9404829637277311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.08420038484809576], {
             RGBColor[
             0.7554223293030421, 0.8088609321646656, 0.9762570960280426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.08420038484809576], {
             RGBColor[
             0.3415503636273469, 0.47025549097875113`, 0.9429842650425748]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.08420038484809576], {
             RGBColor[
             0.6080954954879547, 0.6927183434838337, 0.9622906514134592]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.08420038484809576], {
             RGBColor[
             0.35490507118914444`, 0.4818226674416613, 0.9438352151993084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.08420038484809576], {
             RGBColor[
             0.41460122049326453`, 0.5335284715531852, 0.9476390010457347]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.08420038484809576], {
             RGBColor[
             0.694603429418418, 0.7613487453340381, 0.9701952364724766]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.08420038484809576], {
             RGBColor[
             0.4435483517921228, 0.5586010217591333, 0.9494834866551548]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.08420038484809576], {
             RGBColor[
             0.9508035295736417, 0.9628299334246248, 0.9681609713240683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.08420038484809576], {
             RGBColor[
             0.7512878359370312, 0.8056310345238245, 0.9758450083683557]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.08420038484809576], {
             RGBColor[
             0.9619531323721293, 0.9711452889359378, 0.9492876020683684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.08420038484809576], {
             RGBColor[
             0.9908632518307952, 0.9808417443940927, 0.4190058880030979]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.08420038484809576], {
             RGBColor[
             0.5419408538685232, 0.6390110251845367, 0.9570827156927405]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.08420038484809576], {
             RGBColor[
             0.6090354661004186, 0.6934814539722254, 0.9623646493432981]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.08420038484809576], {
             RGBColor[
             0.9746789649440726, 0.9806361940314547, 0.9277460869527736]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.08420038484809576], {
             RGBColor[
             0.6029093651359207, 0.6885080092315425, 0.9618823802347256]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.08420038484809576], {
             RGBColor[
             0.30663865473296914`, 0.43962704651094353`, 0.9407739898045806]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.08420038484809576], {
             RGBColor[
             0.9608986806665814, 0.9703588805804464, 0.9510725137608107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.08420038484809576], {
             RGBColor[
             0.7962158240770605, 0.8407291203241721, 0.9803230103502338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.08420038484809576], {
             RGBColor[
             0.9887546035702047, 0.9896177538298431, 0.8360288512021706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.08420038484809576], {
             RGBColor[
             0.9910771206407417, 0.9905781743244763, 0.7975387328618645]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.08420038484809576], {
             RGBColor[
             0.26469064263808445`, 0.3955370261416383, 0.9383851125722996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.08420038484809576], {
             RGBColor[
             0.36585356986241385`, 0.4913057067049036, 0.9445328438533918]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.08420038484809576], {
             RGBColor[
             0.522509787363411, 0.6232360100361161, 0.9555530309591161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.08420038484809576], {
             RGBColor[
             0.9391614178421125, 0.9541472655574587, 0.9878680297365052]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.08420038484809576], {
             RGBColor[
             0.40172405559403773`, 0.5223749185426017, 0.9468184794851857]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.08420038484809576], {
             RGBColor[
             0.949380949552547, 0.9617689755741534, 0.9705690282314894]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.08420038484809576], {
             RGBColor[
             0.9111971541566467, 0.6856333385649207, 0.24740534964498392`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.08420038484809576], {
             RGBColor[
             0.5983208403213541, 0.6847828380763901, 0.9615211547530027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.08420038484809576], {
             RGBColor[
             0.7481738430915763, 0.8031983596457329, 0.9755346346634385]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.08420038484809576], {
             RGBColor[
             0.3645497140335442, 0.4901763723196362, 0.9444497633129306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.08420038484809576], {
             RGBColor[
             0.33318793703062777`, 0.46301237736845474`, 0.9424514186144354]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.08420038484809576], {
             RGBColor[
             0.3774431413559686, 0.5013440110238203, 0.9452713211007054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.08420038484809576], {
             RGBColor[
             0.7823674820425083, 0.8299106902754823, 0.9789427370363438]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.08420038484809576], {
             RGBColor[
             0.41081276951319595`, 0.5302471057273325, 0.9473976042992803]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.08420038484809576], {
             RGBColor[
             0.5728610389318953, 0.6641134243574455, 0.9595168659252991]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.08420038484809576], {
             RGBColor[
             0.814918007462864, 0.85533940812702, 0.9821870692082902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.08420038484809576], {
             RGBColor[
             0.6613558420707617, 0.7353754774070262, 0.966881427682031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.08420038484809576], {
             RGBColor[
             0.2761653818766155, 0.40759770462182293`, 0.9390385819965784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.08420038484809576], {
             RGBColor[
             0.4174529613619098, 0.535998506160942, 0.9478207114521893]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.08420038484809576], {
             RGBColor[
             0.6850340675819134, 0.7538730871375171, 0.9692414519153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.08420038484809576], {
             RGBColor[
             0.9520447915855089, 0.9637556646006953, 0.9660598385109584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.08420038484809576], {
             RGBColor[
             0.23822308854655252`, 0.36771794865158414`, 0.9368778245220243]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.08420038484809576], {
             RGBColor[
             0.7918582571438555, 0.837324955917217, 0.9798886888021102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.08420038484809576], {
             RGBColor[
             0.6753362039457379, 0.7462970423584433, 0.968274859499819]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.08420038484809576], {
             RGBColor[
             0.5223008496991801, 0.6230663850277589, 0.9555365826208241]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.08420038484809576], {
             RGBColor[
             0.36860551428439636`, 0.4936893026464765, 0.9447081953185116]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.08420038484809576], {
             RGBColor[
             0.8211892968462553, 0.8602580709882927, 0.9828069622891771]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.08420038484809576], {
             RGBColor[
             0.31974290914963016`, 0.45136696998468473`, 0.9415947133268295]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.08420038484809576], {
             RGBColor[
             0.39361352253941756`, 0.5153499824579338, 0.9463016834908081]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.08420038484809576], {
             RGBColor[
             0.7696105875957487, 0.8199449073776849, 0.9776712490178473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.08420038484809576], {
             RGBColor[
             0.9036088631715954, 0.9259771959565896, 0.9906682141021034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.08420038484809576], {
             RGBColor[
             0.8744227614329156, 0.5226649136236405, 0.2169276127708858]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.08420038484809576], {
             RGBColor[
             0.4956373427468629, 0.6014197489065681, 0.9534375336818934]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.08420038484809576], {
             RGBColor[
             0.8426781215205394, 0.8773926764849599, 0.9848565855699105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.08420038484809576], {
             RGBColor[
             0.9688037379142649, 0.9064298241334553, 0.3333088420270337]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.08420038484809576], {
             RGBColor[
             0.32140497815494024`, 0.4528065706190671, 0.9417006188941379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.08420038484809576], {
             RGBColor[
             0.970452546614855, 0.9774841381616491, 0.934900310757697]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.08420038484809576], {
             RGBColor[
             0.6431645886896848, 0.7211643320070826, 0.9650682935519335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.08420038484809576], {
             RGBColor[
             0.7891811343183934, 0.835233567219079, 0.9796218582180033]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.08420038484809576], {
             RGBColor[
             0.446416661211381, 0.5610854072126715, 0.9496662527950035]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.08420038484809576], {
             RGBColor[
             0.6172810350497198, 0.7001755783039161, 0.9630137707355014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.08420038484809576], {
             RGBColor[
             0.9417945195538192, 0.9561110285027411, 0.9834108753614995]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.08420038484809576], {
             RGBColor[
             0.31736631202200766`, 0.44930848100398296`, 0.9414432786593997]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.08420038484809576], {
             RGBColor[
             0.21913021617489342`, 0.3476501292309435, 0.9357905136858318]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.08420038484809576], {
             RGBColor[
             0.40052698701771816`, 0.5213380779082096, 0.9467422033340288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.08420038484809576], {
             RGBColor[
             0.4127316167853028, 0.5319091147903633, 0.947519871550689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.08420038484809576], {
             RGBColor[
             0.8723528460016508, 0.9010544962872601, 0.9876869872818582]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.08420038484809576], {
             RGBColor[
             0.32140497815494024`, 0.4528065706190671, 0.9417006188941379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.08420038484809576], {
             RGBColor[
             0.2207393389646039, 0.34934141930720675`, 0.9358821508482219]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.08420038484809576], {
             RGBColor[
             0.6539231239183084, 0.7295689814955796, 0.9661406037992947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.08420038484809576], {
             RGBColor[
             0.6171060750411379, 0.7000335378870908, 0.9629999972427262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.08420038484809576], {
             RGBColor[
             0.9072296209406723, 0.9288642899188, 0.9910135652104066]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.08420038484809576], {
             RGBColor[
             0.2437448675978899, 0.37352168853555245`, 0.9371922816702578]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.08420038484809576], {
             RGBColor[
             0.4286655873122694, 0.5457103191961769, 0.9485351700628104]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.08420038484809576], {
             RGBColor[
             0.8719197876692171, 0.9007091873280328, 0.9876456817915149]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.08420038484809576], {
             RGBColor[
             0.299120566290855, 0.43172505888394286`, 0.9403458457898173]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.08420038484809576], {
             RGBColor[
             0.26947012983568863`, 0.4005605702233112, 0.9386572972975855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.08420038484809576], {
             RGBColor[
             0.8739767556921817, 0.9023493577946352, 0.9878418772378224]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.08420038484809576], {
             RGBColor[
             0.2829811245404853, 0.41476148230459436`, 0.9394267284582981]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.08420038484809576], {
             RGBColor[
             0.18194199832570823`, 0.3085629544022542, 0.9336726996943588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.08420038484809576], {
             RGBColor[
             0.902693080077121, 0.6510338278863063, 0.2405170596165318]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.08420038484809576], {
             RGBColor[
             0.7357037685283754, 0.7934566426208834, 0.974291734170451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.08420038484809576], {
             RGBColor[
             0.5862148038872863, 0.6749546123284875, 0.9605681232190403]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.08420038484809576], {
             RGBColor[
             0.993760399219947, 0.9890624497889042, 0.562236145322739]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.08420038484809576], {
             RGBColor[
             0.5581354690287548, 0.6521585433307117, 0.9583576151209839]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.08420038484809576], {
             RGBColor[
             0.9858521189812836, 0.9884175018618726, 0.8841305322299263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.08420038484809576], {
             RGBColor[
             0.5886241328699696, 0.6769106141356636, 0.96075779442222]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.08420038484809576], {
             RGBColor[
             0.2673000457520936, 0.3982796742601751, 0.9385337142193765]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.08420038484809576], {
             RGBColor[
             0.592858728444615, 0.6803484495895173, 0.9610911572976907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.08420038484809576], {
             RGBColor[
             0.3160180783302714, 0.4481407087443967, 0.9413573704007585]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.08420038484809576], {
             RGBColor[
             0.35551959111384673`, 0.4823549337137689, 0.9438743718655117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.08420038484809576], {
             RGBColor[
             0.9798763561661834, 0.9437803654715774, 0.3763238730472333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.08420038484809576], {
             RGBColor[
             0.6581657414961135, 0.7328833465924488, 0.9665634682699349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.08420038484809576], {
             RGBColor[
             0.28855990319342395`, 0.42062513238382915`, 0.9397444316495196]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.08420038484809576], {
             RGBColor[
             0.26533458445435215`, 0.396213849818805, 0.9384217841061094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.08420038484809576], {
             RGBColor[
             0.218078515776465, 0.34654472543053866`, 0.9357306209039925]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.08420038484809576], {
             RGBColor[
             0.63941687376583, 0.7181464493818244, 0.9647563850454826]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.08420038484809576], {
             RGBColor[
             0.5334916226176433, 0.6321515586215422, 0.9564175612581174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.08420038484809576], {
             RGBColor[
             0.5432945274502964, 0.6401099983805201, 0.9571892818357675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.08420038484809576], {
             RGBColor[
             0.5717818336844712, 0.6632372769199442, 0.9594319069349627]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.08420038484809576], {
             RGBColor[
             0.3813484370620194, 0.504726581878532, 0.9455201630897776]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.08420038484809576], {
             RGBColor[
             0.8387323778323, 0.874246447572317, 0.9844802370145193]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.08420038484809576], {
             RGBColor[
             0.31974290914963016`, 0.45136696998468473`, 0.9415947133268295]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.08420038484809576], {
             RGBColor[
             0.5852600056085989, 0.6741794640726768, 0.9604929580010007]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.08420038484809576], {
             RGBColor[
             0.7006300388484972, 0.7660567784247441, 0.9707959125785998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.08420038484809576], {
             RGBColor[
             0.894256317803437, 0.9185197301481011, 0.9897761599757726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.08420038484809576], {
             RGBColor[
             0.6984443854968104, 0.7643493294148257, 0.9705780670785955]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.08420038484809576], {
             RGBColor[
             0.9287912246260817, 0.946056927423405, 0.9930701302181918]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.08420038484809576], {
             RGBColor[
             0.32145059319362757`, 0.45284608007289956`, 0.9417035254440673]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.08420038484809576], {
             RGBColor[
             0.39761571455281713`, 0.518816480023921, 0.9465566996269025]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.08420038484809576], {
             RGBColor[
             0.6682793121720447, 0.7407841448704703, 0.9675714944782202]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.08420038484809576], {
             RGBColor[
             0.24856946610155278`, 0.378592647460115, 0.9374670354176876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.08420038484809576], {
             RGBColor[
             0.9198367848503419, 0.7198865952791622, 0.25435699929932803`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.08420038484809576], {
             RGBColor[
             0.2539205478369532, 0.3842169736421987, 0.9377717716063027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.08420038484809576], {
             RGBColor[
             0.9942163946368472, 0.990037777877445, 0.6118684323748188]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.08420038484809576], {
             RGBColor[
             0.5050293191270047, 0.6090445784356815, 0.9541769044664813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.08420038484809576], {
             RGBColor[
             0.2630942154152196, 0.39385907991107527`, 0.9382941984036599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.08420038484809576], {
             RGBColor[
             0.37719862793661035`, 0.501132225789574, 0.9452557409218386]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.08420038484809576], {
             RGBColor[
             0.7885524187266235, 0.8347424098203728, 0.9795591937234969]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.08420038484809576], {
             RGBColor[
             0.7671163260620597, 0.8179963713104772, 0.9774226443383685]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.08420038484809576], {
             RGBColor[
             0.590985265128032, 0.6788274876705547, 0.9609436714026871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.08420038484809576], {
             RGBColor[
             0.29429986491684634`, 0.4266581960897392, 0.9400713139781561]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.08420038484809576], {
             RGBColor[
             0.434552258584067, 0.550809057979107, 0.9489102635508704]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.08420038484809576], {
             RGBColor[
             0.5515356255534658, 0.6468004930779118, 0.9578380512665859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.08420038484809576], {
             RGBColor[
             0.24836700401149217`, 0.3783798469666234, 0.9374555055011744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.08420038484809576], {
             RGBColor[
             0.49724195945800215`, 0.60272244903983, 0.953563854987299]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.08420038484809576], {
             RGBColor[
             0.8262214057975545, 0.8642705380731, 0.9832869293331686]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.08420038484809576], {
             RGBColor[
             0.8620908655322117, 0.8928718716149687, 0.986708190423705]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.08420038484809576], {
             RGBColor[
             0.4242894903852428, 0.5419199639870133, 0.9482563290362509]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.08420038484809576], {
             RGBColor[
             0.5240695235943292, 0.624502274173692, 0.9556758191087161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.08420038484809576], {
             RGBColor[
             0.4107448370843447, 0.5301882660718447, 0.9473932757049842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.08420038484809576], {
             RGBColor[
             0.8684197020878087, 0.4954064231876414, 0.21191851290487906`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.08420038484809576], {
             RGBColor[
             0.6143870078214779, 0.6978260766255885, 0.9627859423109232]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.08420038484809576], {
             RGBColor[
             0.9944872457777554, 0.9906171010805966, 0.6413489075631922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.08420038484809576], {
             RGBColor[
             0.39361352253941756`, 0.5153499824579338, 0.9463016834908081]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.08420038484809576], {
             RGBColor[
             0.7624857256883705, 0.8143789111046849, 0.97696110936854]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.08420038484809576], {
             RGBColor[
             0.5969219295235231, 0.6836471392704976, 0.9614110273706183]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.08420038484809576], {
             RGBColor[
             0.36826150207729424`, 0.4933913365632409, 0.9446862751648731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.08420038484809576], {
             RGBColor[
             0.3763267814036779, 0.5003770761430287, 0.9452001876317038]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.08420038484809576], {
             RGBColor[
             0.7135252819119355, 0.7761306403133793, 0.9720811898942655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.08420038484809576], {
             RGBColor[
             0.6601327789405779, 0.7344200111941026, 0.966759524179389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.08420038484809576], {
             RGBColor[
             0.9427659784302296, 0.9568355409421501, 0.9817664488807905]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.08420038484809576], {
             RGBColor[
             0.27691720011208554`, 0.4083879132553312, 0.9390813969328731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.08420038484809576], {
             RGBColor[
             0.9890330638099056, 0.9897329042950611, 0.8314140443983257]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.08420038484809576], {
             RGBColor[
             0.9566117197579553, 0.9671616721540472, 0.9583292203606392]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.08420038484809576], {
             RGBColor[
             0.4995937623932409, 0.6046317486101717, 0.953748997529299]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.08420038484809576], {
             RGBColor[
             0.8285630673555743, 0.8661377154367551, 0.9835102791029985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.08420038484809576], {
             RGBColor[
             0.24856946610155278`, 0.378592647460115, 0.9374670354176876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.08420038484809576], {
             RGBColor[
             0.31974290914963016`, 0.45136696998468473`, 0.9415947133268295]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.08420038484809576], {
             RGBColor[
             0.6486337793991782, 0.7254369053567278, 0.9656134113693626]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.08420038484809576], {
             RGBColor[
             0.6226287254509354, 0.7045170742823301, 0.9634347605131205]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.08420038484809576], {
             RGBColor[
             0.7881219172703087, 0.8344060988107674, 0.9795162853615963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.08420038484809576], {
             RGBColor[
             0.618268378377268, 0.7009771480965297, 0.9630914980190037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.08420038484809576], {
             RGBColor[
             0.2674857099161389, 0.39847481906837456`, 0.9385442875188533]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.08420038484809576], {
             RGBColor[
             0.8951793548369963, 0.9192557348234885, 0.9898642000720385]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.08420038484809576], {
             RGBColor[
             0.8509847022881929, 0.8840161185129584, 0.9856488746589015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.08420038484809576], {
             RGBColor[
             0.9583906442599797, 0.9684883911349355, 0.9553179651965296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.08420038484809576], {
             RGBColor[
             0.9013949763747258, 0.924211902719122, 0.990457051603058]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.08420038484809576], {
             RGBColor[
             0.6328129396913096, 0.712785078196289, 0.9642364991641288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.08420038484809576], {
             RGBColor[
             0.4200634589197082, 0.5382595879380847, 0.9479870500481998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.08420038484809576], {
             RGBColor[
             0.3471950826214136, 0.47514466285958573`, 0.9433439415454477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.08420038484809576], {
             RGBColor[
             0.2351403652684994, 0.3644778110304055, 0.9367022679918195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.08420038484809576], {
             RGBColor[
             0.9334140540072698, 0.7737159431296419, 0.26528158876245994`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.08420038484809576], {
             RGBColor[
             0.9635246580011065, 0.9723173301768919, 0.9466274190980382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.08420038484809576], {
             RGBColor[
             0.8747124715261696, 0.902935997630183, 0.9879120504708494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.08420038484809576], {
             RGBColor[
             0.3030542232375889, 0.4358595817432158, 0.9405698617336098]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.08420038484809576], {
             RGBColor[
             0.26469064263808445`, 0.3955370261416383, 0.9383851125722996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.08420038484809576], {
             RGBColor[
             0.2837091291302335, 0.4155266612865767, 0.9394681872426981]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.08420038484809576], {
             RGBColor[
             0.39109729479940414`, 0.5131705524588176, 0.9461413516842273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.08420038484809576], {
             RGBColor[
             0.7474759479252682, 0.8026531586376132, 0.9754650749954621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.08420038484809576], {
             RGBColor[
             0.7336534161691894, 0.7918548917746323, 0.9740873742089196]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.08420038484809576], {
             RGBColor[
             0.2351403652684994, 0.3644778110304055, 0.9367022679918195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.08420038484809576], {
             RGBColor[
             0.45563881856189287`, 0.5689471450602294, 0.9502887033386307]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.08420038484809576], {
             RGBColor[
             0.9856581644533734, 0.9883372966801777, 0.8873448606956268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.08420038484809576], {
             RGBColor[
             0.9182463448036997, 0.7135810304769536, 0.2530772939053737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.08420038484809576], {
             RGBColor[
             0.8903287907484944, 0.9153880266843718, 0.9894015489391275]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.08420038484809576], {
             RGBColor[
             0.7411822352811047, 0.797736462486005, 0.9748377765371804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.08420038484809576], {
             RGBColor[
             0.25812725555426974`, 0.38863849017377267`, 0.9380113373875374]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.08420038484809576], {
             RGBColor[
             0.34560167605781983`, 0.47376453418114334`, 0.9432424110882096]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.08420038484809576], {
             RGBColor[
             0.278252635206845, 0.40979154021139885`, 0.9391574479859205]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.08420038484809576], {
             RGBColor[
             0.9859634969311977, 0.9884635595064448, 0.8822847113629545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.08420038484809576], {
             RGBColor[
             0.7808096699854081, 0.8286937156566655, 0.9787874688890734]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.08420038484809576], {
             RGBColor[
             0.5639056601819735, 0.6568430444530438, 0.9588118657054719]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.08420038484809576], {
             RGBColor[
             0.2507571181600597, 0.38089200847875754`, 0.9375916189660783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.08420038484809576], {
             RGBColor[
             0.9655283033901028, 0.9738116456273371, 0.9432357700888793]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.08420038484809576], {
             RGBColor[
             0.9845087103801874, 0.9878619678812931, 0.9063942893801034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.08420038484809576], {
             RGBColor[
             0.25838038902326527`, 0.3889045494992759, 0.9380257529641193]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.08420038484809576], {
             RGBColor[
             0.7797017733322862, 0.8278282183709202, 0.9786770441045731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.08420038484809576], {
             RGBColor[
             0.9043718228264948, 0.9265855592754183, 0.9907409858750899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.08420038484809576], {
             RGBColor[
             0.6663705601739763, 0.7392930133025266, 0.9673812479173544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.08420038484809576], {
             RGBColor[
             0.2437448675978899, 0.37352168853555245`, 0.9371922816702578]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.08420038484809576], {
             RGBColor[
             0.6697621734711059, 0.7419425673874601, 0.967719292234384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.08420038484809576], {
             RGBColor[
             0.34932889259789857`, 0.47699286181280925`, 0.9434799060302952]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.08420038484809576], {
             RGBColor[
             0.7702357707688295, 0.8204333052240638, 0.9777335614338711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.08420038484809576], {
             RGBColor[
             0.7148979106014419, 0.7772029482779861, 0.972218000694091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.08420038484809576], {
             RGBColor[
             0.7600079636622966, 0.8124432645782271, 0.9767141492057835]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.08420038484809576], {
             RGBColor[
             0.4482684157788016, 0.5626893039470804, 0.9497842449585973]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.08420038484809576], {
             RGBColor[
             0.4915281039113657, 0.5980836837008116, 0.9531140393481252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.08420038484809576], {
             RGBColor[
             0.41604090069759514`, 0.5347754501857452, 0.9477307361952954]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.08420038484809576], {
             RGBColor[
             0.46235105200351545`, 0.5743964385508092, 0.9508171149428765]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.08420038484809576], {
             RGBColor[
             0.2754355381547744, 0.4068305925954033, 0.9389970184763267]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.08420038484809576], {
             RGBColor[
             0.779824010062604, 0.827923710633678, 0.978689227519484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.08420038484809576], {
             RGBColor[
             0.31974290914963016`, 0.45136696998468473`, 0.9415947133268295]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.08420038484809576], {
             RGBColor[
             0.42828257605155806`, 0.5453785740928544, 0.9485107649239615]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.08420038484809576], {
             RGBColor[
             0.735043418455536, 0.7929407721251349, 0.9742259166465126]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.08420038484809576], {
             RGBColor[
             0.6472390781517896, 0.7243473541421457, 0.9654744005832472]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.08420038484809576], {
             RGBColor[
             0.218078515776465, 0.34654472543053866`, 0.9357306209039925]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.08420038484809576], {
             RGBColor[
             0.3842054210498817, 0.5072011578126279, 0.9457022075831524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.08420038484809576], {
             RGBColor[
             0.5150202413246707, 0.6171556591616627, 0.9549634264598355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.08420038484809576], {
             RGBColor[
             0.5316136784213846, 0.6306269589225975, 0.9562697226118516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.08420038484809576], {
             RGBColor[
             0.7624857256883705, 0.8143789111046849, 0.97696110936854]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.08420038484809576], {
             RGBColor[
             0.8260554435375163, 0.8641382042718709, 0.98327109970465]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.08420038484809576], {
             RGBColor[
             0.18380541493892977`, 0.3105215234101872, 0.933778818513804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.08420038484809576], {
             RGBColor[
             0.3920987898024356, 0.514037997093841, 0.9462051660602332]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.08420038484809576], {
             RGBColor[
             0.5851511915333713, 0.6740911239043887, 0.9604843917583996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.08420038484809576], {
             RGBColor[
             0.3635345138524871, 0.4892970569482492, 0.9443850756551]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.08420038484809576], {
             RGBColor[
             0.5767467698292806, 0.6672680357501249, 0.9598227648954425]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.08420038484809576], {
             RGBColor[
             0.5365430997926554, 0.6346288852596972, 0.9566577847192635]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.08420038484809576], {
             RGBColor[
             0.9932097563927003, 0.9878846804599533, 0.5023020717505519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.08420038484809576], {
             RGBColor[
             0.5091405447343141, 0.6123822565922983, 0.9545005552062042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.08420038484809576], {
             RGBColor[
             0.40508631560266006`, 0.5252871391699685, 0.9470327197198054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.08420038484809576], {
             RGBColor[
             0.27286189938092953`, 0.4041255350659693, 0.9388504535555136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.08420038484809576], {
             RGBColor[
             0.5770526074740675, 0.6675163285279917, 0.9598468415551603]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.08420038484809576], {
             RGBColor[
             0.41604090069759514`, 0.5347754501857452, 0.9477307361952954]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.08420038484809576], {
             RGBColor[
             0.9907378977094471, 0.9904378969247543, 0.8031605347142214]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.08420038484809576], {
             RGBColor[
             0.9889558496254871, 0.98970097424549, 0.832693683258046]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.08420038484809576], {
             RGBColor[
             0.49256579915351073`, 0.5989261314460228, 0.9531957305187898]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.08420038484809576], {
             RGBColor[
             0.9950222340314365, 0.9917613868596109, 0.6995790774115974]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.08420038484809576], {
             RGBColor[
             0.9944872457777554, 0.9906171010805966, 0.6413489075631922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.08420038484809576], {
             RGBColor[
             0.90645184326979, 0.928244111116251, 0.9909393800818275]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.08420038484809576], {
             RGBColor[
             0.8422673103444183, 0.8770651068042932, 0.9848174020331966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.08420038484809576], {
             RGBColor[
             0.9758467158646817, 0.9815071007560283, 0.9257693892424006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.08420038484809576], {
             RGBColor[
             0.4227713197108363, 0.5406050008543192, 0.9481595925433433]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.08420038484809576], {
             RGBColor[0.17892700000000003`, 0.30539400000000005`, 0.933501]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.08420038484809576], {
             RGBColor[
             0.2625394375257221, 0.3932759731742636, 0.9382626046235734]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.08420038484809576], {
             RGBColor[
             0.2351403652684994, 0.3644778110304055, 0.9367022679918195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.08420038484809576], {
             RGBColor[
             0.25838038902326527`, 0.3889045494992759, 0.9380257529641193]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.08420038484809576], {
             RGBColor[
             0.6113798321514899, 0.6953847159449721, 0.9625492064265343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.08420038484809576], {
             RGBColor[
             0.27392083391636673`, 0.4052385424030412, 0.9389107583107534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.08420038484809576], {
             RGBColor[
             0.9894724547593224, 0.9899146037444773, 0.8241321992591643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.08420038484809576], {
             RGBColor[
             0.4420985594983623, 0.5573452845429573, 0.9493911071721973]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.08420038484809576], {
             RGBColor[
             0.5122102508517935, 0.6148743823071527, 0.9547422137164763]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN2wucznW+wPHf/+zadNlSKJUyheimsIbchiJLGlM0NrNmJtWMMW5DaZZc
xiXEpDYnbVorhVi3nLW60EUbOdQepCtJuQyjGrY9Lm05z6ffZ157Xi/ffefx
PP/nd/n+bv//s1cMGHbn0P8IIXx2ZgiYkYqtqeiWikdTke5r6b5eKxVHU/Fw
KhonIWxIuScVO1LRJ/X3fSmHJ/Hzv07Fz1P/PTQVnbV+6rVL/NwxP4uZIb6W
6d8nhXgt7J16/40pl6didCoWpeLJVExNvX6OZTrHcnH9OakYkYq5vn5uEt+D
R/XNlDk6zutPTuJ1cblelXJ9Kloq5Vln7PP1aV6/SRKv3cTrDfB6A7weEly3
id9PnTcbtAWvf287VBnH9A7L82Aq+qciLfX3B6zv/BDbGId63cFJvC7u0WOa
+hOyUv9zm330s1T08vMtk/haS4PrXZJ6/aMQ3/+RuYHdkngd6v+6QRu8bnvU
Nk+uSBnsr20hts82+3SbcVT5fIMk9gtO9frnJLH/z/H6eI5tfo7tTrucMB9P
GORl65SnLd9pg890t62728bdbWfa+IqU2bY15oXY/m2NB5X31fU6dX1fXfuk
rtetaz9SjzzrkWc98LRSpjzrlGed8hw3jYw55nWx1ys2XtejyrWKbc9i+6PY
75kYYm5iA/9OO5PPh41p5sd++3u/fb7f+Ll5VJTEsYYFfIf5fsooNq92GeTp
LvOUfL8qiZHj99dK4vcjQTnahdhmuDPE+WeSeY7kGPL6SYPXTvrv9P/EJOYg
5pt7uFm3KWPlDP/7DN+HG3SzVr/vlFZ/z1TjsJ5Wvrd9iGMNezmef0xFrpaa
N6W2FTIGS223UtuNeahVEqO317khifl4g/mLPyo5eoPl2215dpszu43TSt7s
Nk9ut2y3Wz7m9CEG4+qxlP9heV411uk+3zcwieMQ+cxA54FRIc4Do4zluk2P
KnMmTnacpRmZukH3aJUeU+a7NPuHdiq1nUptp1Lbp9Q2wm7K/FU/5REdGWIe
4iLdreQp6+QXIa6ZuFVph+ZJjD460Pb7XRLbEHuFmN+p5finsYFvKmMEq8dJ
ruXJdbzkOl5yDcqTJHGdSMyVxHzB2kaa9ra+7xnUFxv7+m3mLZLDtxm97M/z
jRt1lC7XbXpUmXfOt3/Pt3/JrxFJbC/cobTXCNtuhG2Hl4fY5pfb5pfb3rRT
J+cXfFNpw05GjvNKRhL7FBcp/dDM/mlm/zQz6KdfhpjzvzTfsbavt1Lak/Wk
3KhS1hemog5JjG6aZX4+EeJ4w1wlGH/0+2JjvdLni/1e5qIHkjgPY7FSjllJ
/H6sUsoyy/rmJzH38q0nso+qkcT5HVkHz0jiGofzdYfSjyOTuJ7gk0pf4wAl
pvq9bf2+tgbfSw6tMndWGaeUa6yynqvMmzohrpHYSFknmS/qGWnaXTO1XKv0
mNI29WwnrlMziZ+paTvUtB1q2g5IG9Q0WirzNetDF8dGF2O5rtJTWmy7vxbi
fP+asUvpB+xs/ja135r6uaUh9tdS4zXlc1jkeJ0XYn9hsY5SYpse1XPNqxLz
qsSgH9gndE/iPgE/0v3KXqG75WthPrWwPEjZWhiUr02IdcPRukh3alPfl6H5
jqsygzGFWcp1zzMXzzMHcZxONY+yzKEsgzziupVet9Lg+pVen3nx0STOhY86
jlsZbfVBZa3BG5R15nrb9nrb9Hqvw5mMuRB3aHNf76MDlfmQeXqj8Z4eUeZz
1v/Hk7j+4249rexR8KEkznPk+dgQ98CYp2MtD55Qch/TbMfxSRyT2Egf0Dl6
RDkTjne8DQ9xjA43yrVKGZc4y+95McTvedF+e9F+e9G+w4tCzFEs1fm6S/cr
uYottbMONW83GeTqpvDv8dQliftxLNZ5+rru1tPKXgvP1SZKsP9iHZkZ4loz
02Dtxtqapq2Udee8EM9cGPx7kdLHrCMzkrhu4Ho9rKwpmKvTlHqmW89065lu
PXGbHlXqlW690o0u1qteEutVz3IjdcPaSrTS6vV0r1GldzheCh1DhUaJPmq5
b0nifIf5Okrn6XLdpkeVcmOzEOdpLPDvxVqizIeclyeEON9NMObqUt2kzH0T
zCfGV5sk5ibuUMYW1tSWSgx1HJzpeDvT8YZZ+oDO0Rf1TMcd7XODka/zdLlu
1m1KezDv9gtxru5njNZF+rruVnIem2iGdtHqc8ffQ9z/4BNKsA9qGmIO42Jd
r4eVHMZcnaYz7KdB5s0g82aQ+TLIKFb69ZoQ50Acq1v1hNb2fWle/2WDz79s
XvD9ay37Wsu+1qC8ax0H2Ep7K+X+WYh7EczWPJ2vZ/i+mtrGvJ9ivk8xr5F1
Dxtouo7Uccp6VmC7Flj+AmOxrlfKyb55lsHeGZvp78zHZ4wjSh6m/oSDIa6z
B41KzbIeL4RYD5yoBHXAATpSJ+sUner3zEzi9+BBrVTWdszSIqVf/2C8rPQr
89kYY5LOVPJijP06xn4dY7+S57cn7vmTmN9IcB+VebarUazMqXiVNtFOyrnm
ipQXJ3GdR2Ki5dxiubZY1i2WdYvBHLzFcm+x3Fss9xbLzX2W8iTeXyl3HJU7
jsodR+WOH/xFiHMF9tK2vp6h+bbHuyG2x7vG35U2weGOszpJHJM4VrfqCaUu
WFsJxif7tWkGZ1jspawXg81J3Kjv6RFlP8W8e2MS511spFn6gM7RF5V590Zj
vOOrMMT6Y64W2haFtkGh7YE/Vn/G7z/bcuMzekSJS3S87+vp+3CjHlHeh/WV
OedAiGcozNQNuln3KHFMB5vHH5i/2E+L9XUlWB8+MM8/ML8xXbto9f6ownyu
MI8rzOMKgxyoMJ8rzGdM01ba2/lhVBLvFyDzIzZQYpwynzB+zk/i/S5cp/uU
+XdBiHM19tc8HavEDj2hzOPYRvs4Ti5M4ljCXkq01QxlPHHu7Gx00eW6Sk9p
seXNsbw5Rp4O17FKu+ZYzhzbk/tR34a49uNuPawE6xzm6jTrNcb64GM6S1lD
xlgvbKZtNV+ZF2Zb/tmWc7btPtuyzzYqlHrMNj+wjlav432TONcj81xfo0AL
dZCW2I49QjzP9DCyNUfzdLiW62ytUtoXOe/UDLHvsZ3u1Kb+e77zUkPnhYbO
Qw2dhxo67hs6DzU0btTqdbhjiOeFjkaZHtRKZa3ELC1S1kvOpWtCvK+HQ3SN
+Y6cZ9eY3zjCfFhtXVdbV+yno3WRrnYcYIbmO299EuK8hZlaqvOV2KUH9Jiy
j8LOOljZd7MfeiTE/dAjxlQ9rN8qeY+5Ok3ZL3Euf9bPPmvs1tPK9+JEfdz8
PG6Qm8fNUyzQQh2kxVqirM+cV7KTeA7BubpJOZtkO76uN3J0jM7U2bpFK5Rx
hrW1jtbTNO1t/y+x/3GkjtZFusS+X2I7L7H/ybvMJOZbpnmFO5ScyzT66EAl
/2qEOJZqWIYa5mANc7CGZanh9+NObernM5Q8JP/Kkph/uEE36x49oMeUPi8z
eH4xNMTnw/iQ4/Rco6OWaaUyPrGbZinjk/sadyXx3giW6nzdpdwTwZbaWQnG
AfvB7cZJ5bkBTlLyjPvyT4V4Xx67KvGmsq/FTprjOPsyxHGGBfqIrlfisLLn
xVydpjOcFy420jRTN+hm/UT36AE9pvTRxfYX/b0yxPxdaQ6tNIdWmkPYS0fr
SvNopXmEzGcrzSdsqxma7/h/2ziujH8s0EIdpMVaog9oue28wnZeYTvjYiXW
6nplXsNWOsPxNySJvwPBX+sQXaM/jVGDccc4fyfE8Y1LdLWS75eFmL+XGR21
TA9qpZL/2E2zdKZ5MDDEdXqguYDdtYdmKjFcy7VKjyn3o5D1+uch7lFxjE7S
mbpWX9V1ukUrtLbXq6ettPp+X+sknvuQhmptFOlEx2l7+7u947K96wCeVMZu
e6NAC3WQFmuJkj+3hni2wGd0ox7Rs31ffe3pvPN+iM8q3jd2KXMNUn72VWcb
2Zqj/TVPx+oC3aEnlH0Vsr+mT3oksQ9wne5T9vI9HB/3JnF84CM6Vb/Uw/qt
MhdhrhLTlPHCc6HfJPF5Ga5SYoBOdt6+1fxFcvtWo5uS3w2C90RCnFfxqJ7n
vzfQkTpKx+kUx/Fbxgll7cRMZd1k/3BPEu934gSdq0t1k7KfwGxlX3FlEp/l
Yob21636hTIWsI5eEOLeAXtotubocC3X2VqhiddJ01l6URKvjT00R4druc7W
CuWaFxlp2kpnWe8BIdZ3gDk8wBirb+lWPaHUfYDtwf3bR5J4zsauWqzzdJt+
oEeVszY20XTtolOU5+t3209320932z932z932yfIOjg9xPUPeymxRFfqan1H
Wf/wEm2rGZrv/PF0iHPO08YzulGPKPMO1teeynmHfcmgENsRa2kD7apEsT6l
8/So0paYrp00R0fpFKVdr0j5V4O5Gy/W1sr8x3rfLonzOL6t2/W4nlSivRZo
oQ7SYi1R5nHOIwtDnNfwWV1oGRdazoWWc6HlXGg58XHz8sIQ79teaNygN2q+
jtJ5uly36VGlXfEWHaDMjzz/fCXE9nnF2Kjv6XY9qeQDsuaxf7svxH3bfebr
fcZK3ankJzbTtpqvP/2uJ+UbIe5/cIgu0DVK7FDWI8zUPjpE2SexP7nXKNcl
+o7uVfYj7HPuT+I+By/WNM3UgbpBP9EDWqXHlLPx/cZgZR9Mf3ewjzsYo3Si
Pqkv6HJdpax5HexfHKnVvwNbFmJ9ME27aw/N1IE6XMt1me2EVUp7LbN+yDzN
PNDI8Yov6JvKmooNlBipo3ScMu5ZLz8N8dyFj+pHSuxXzl7Y3c8V+bkiY4R+
qvuV54p4j/Pb2CSeu7CrPqXfK2cv7KQ5yj7z5iTuZXGMTtKZ+qqu0y3K/gnr
KdFD2b+WhDhmcbue1Mb+ezttr5OU+Yp90d8Mfl+BHfRW7aZZWv37vs/8bnxF
N+p7SjBPfGZ5aI+utgder2N0ks7UFbpWt2iFsk/A2nqR1tNW2tX2ui7EtQA7
axct0bf1uJ7UU9rO67TXAh2kxVqinBM5ZzQ2RuhSfU3fV9aHxuYhtlbOI6k/
YXoSz25Yppv0oFYqn5luzLTffpHE9R8HK79L/IVRX2/TntbjOdvuOdsM/6DE
Kn1Z39ZTyrz0nO3znO3CfPRdiPMqZmqpztdPdJce0GNKMKdiS+2sd+n9Wv27
/P5JnA/6O97xUf1IP9X9ypyC3ZU6/mCu/GBwP/EH8+QH8wT7aoEW6iAt0UeV
8cm57VCI7XTI9sE8LdX5+onu0gN6yLY6ZFsdsr0O2V6HbJ9Dtg/zwrgQf2c1
zvibMk9gB71Vu2mWllr+K0M8L15pZGuO9tc8HasLdIeeUM6f2MdxcbXRWqfq
s7pQX9P3lcH00+d0orL/4v7e5BDzY7LtPNmYr7v0OyU3Jtuek82/yebf5P+X
d38OMd9wgs7VpUpw1sNsZT3qGeKzTizUJ/Rd/bve7vt57stzjdFJfK6BjTRL
H9NZOkdfVJ4j4ZlK8NyI/f7DSVwX8Sn9XlkXsal20hwlWCfZP17g9bCNttN+
OlpX6+v6gfIM9AKjiTbVDO2iPAdl3ultPvQ2SvU1fV8/0V16QL9T+hvZz3E+
nRHiOQ8HKPGWbtUvlHMpXul8+58hzrdYog8r8bZu1+N6Un9Q5iFsrwVaqIO0
WEuU+Sf1JzwU4nyAl2lHJcZpmf5ND2qlMl/grdpNs5T1if3/7w3OB/iQci5g
Hf1tiOe+39pv2FqJqbpQ/6pUBi/W1jrR/Ls2xPPLtUYbbaf9dLSu1J1KTmFT
JbeHhfgMEefoM9rQf79ROU9z7r8uiecPHKnTdZEu0dX6jl6X/Pv5yVfW5yvL
h730Ph2qv9eVulO/sj6Yrw85bv5p+//T9sfemq/P6mbdoweUYLwg8y77kzuT
mOf4ir6nnyn7Eqyvtyn1/TrE/frX1vtr6/m18b1Sr6/tJ9anhiGuKw2NazRb
++sAHasLdIeeUNYpZJ3idzP3G9OUfQL20urfP38e4n1S7KkFWqhP6GJdrwTz
Ps8P/hji+RmHKLFG31DOyz+9R0c47q9J4jjHMt2kB7VSiSKdroxn1v/Lkng/
EOtqPe2uPTRTszVH83SgDtdyXaZVyjngMmOW8+lZSZxHzzK/znKew+16XE/q
D0o01nbaXu/Ucut3aYj1u9RI0+7aQzN1oA7Xcl2me7VKqRPeofcr9ZyQcoox
VzcpfYItNFuLdLr98VKI8w8uUeId3avMNS+Ff///cvqGuD5gRyUe0jI9qJVK
ubCDFul0nen1x4e4Do33e8b7PeO9zni/a7xRpge1Uvm+8X4fZmmRTtfq/P1t
EveDOFnn6wI9pN8pYx9raktto3cpMdT5+kHnL6yl12o77ar9tFg/UPY/eK5e
oE20qRLMe5zHr07ieRwv1+s1XcfoTN2iW7VCOYdjHa2nVypxs3IeZ3573HhV
1+m7uk+Z15D9LPdH+yXxfhleqDdosY7SebpNjyrthOl6i3ZRgvvMPL/6ZRLn
ZXxEF+sKXauH9Vslammu3qvTdIb98U2I34OTdLGu0LX6qq7TffqN34u1tJ62
0q5KP7Ce/zqJ6zm21t46VZ/Vhfq+7tED+k89rcRgnais93eHOGfhFJ2rS/XP
uklb+Llsvcf+6WO79TEKdLGu0LW6Xj/XL/WwfqO0Yx/bEeknfh94i1GiD+sG
3a4nlTUCG2t7LVPuy7EPuSvEfQg2VGKBrtE3dIcy52BLbaN9lLmG83wn43bN
1R+V8z3n1D+FeD/kT8ZH+qlyDwS5D8K+tW4Sz5XYSx/TWco5sq5xoTbTtpqv
o3WM4+Lm4H3UEOcnTFdijE7SmbpFK5R7hlhb6+nVerN2VcYH6+GwJN4vw6f1
Jd2oe/WI8uwML9H6eodyH+5yr4vD9Bk9oux3Lzd6mu/Pm+/Pm6fPm/PPG4t1
ha7Xz/VLnWHefWjefWjefWheYbb217G6QNfoG7pDiRNKfn5oXn5oXt4U4hpw
k3W4yTrg4/q8LtYV+qqu0/X6ue7Tb/R2v4/1I+G1JJ4nsaP21fFappXKB/Ea
ba1EkU7XmY6Lf4WYPzhdX9J3lCBH8DodZjk/DrF82FfHa5lO0U1KHNRKpcwf
Ww8s0ulKec8KsU2wsXbUvjpXl+rHGvx8Db1GW+tNWqR8H+eC/wpxPGMPzdYc
Ha6zlahQxjPW1ov0Mk1T9sc8V7wnxPy+xxiia/QNfUt36Id6Qvk9B2ZqHx2o
nKN4fnRpEs+j2FWf0u+VuEo7aY4+qA8r98t4rnaH8abyLA0baCMdpTxH+1WI
ayZO0Cm6SbN9H3nBfrBjEs/CmK4ZerMO0Bm6Vb9Q+gbr6JV6tRL87oFz8p3G
/TpNeUaBt2kvx0dz41faUfvqeC3TKbpJP9aDWqnkb3Pztrl529x2aW7+Mn//
JcT5G5/WZ5TYqEeUuRzP1vp6ufZUxj/ngt+FeC7Aa7WNttN+SozWlbpadypn
AmyqGUqetQjxOTM+qS/oef57Ax2p/P/CmN8eS2I74NP6kv5FN+pePaL/UtoE
L9E7dJhyDvvvEO/LY5GO0FKdrMSnul+5T48t9S7tr9W/T//fENdX7KOP6GJd
oWv1sH6rBPtHrKW5eq9O0xmOu2uTOEZxgk7RubpU/6yblGih2cr+mPtBvwnx
fhDepcQQ/aOu0Teq/z2JMp9xf+N/Qry/gZdqmt6i3TVTB+oyfUU3KHFAq/SY
cn8Dy3SS4+JXSRwXeK0O1Z36lX6t3yu5j9TjH9bjH5Yb79WBWq7L9CXdq1VK
kLM4TMlb7uPfl8TnpficrtKX9ZTyrPQ+o1h5Xsp6MsH5f4LzOg7Sp/RNZcz+
9H5tpJ00R0fpOCX4vcX/Ab8fSPc=
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[337, 399] -> 
             RGBColor[
              0.9603114409091467, 0.8681403292906987, 0.42659540071605706`], 
             UndirectedEdge[15, 92] -> 
             RGBColor[
              0.3916080301069964, 0.5102971083648917, 0.9465821312407912], 
             UndirectedEdge[87, 313] -> 
             RGBColor[
              0.2082730893529932, 0.33623860055952687`, 0.9351722163750043], 
             UndirectedEdge[35, 214] -> 
             RGBColor[
              0.23799829524204824`, 0.3674816766358314, 0.9368650228758846], 
             UndirectedEdge[105, 218] -> 
             RGBColor[
              0.20016816814604027`, 0.3277198144893344, 0.9347106531024247], 
             UndirectedEdge[149, 316] -> 
             RGBColor[
              0.2254786330368893, 0.3543227178657783, 0.9361520466344813], 
             UndirectedEdge[160, 348] -> 
             RGBColor[
              0.39638156393997953`, 0.5175763121944144, 0.946525366087156], 
             UndirectedEdge[17, 287] -> 
             RGBColor[
              0.2108043778715786, 0.3388991452855218, 0.9353163695114319], 
             UndirectedEdge[268, 295] -> 
             RGBColor[
              0.5541988760682194, 0.6477364431214906, 0.9586174510059542], 
             UndirectedEdge[277, 379] -> 
             RGBColor[
              0.2074585735841274, 0.33538249284316635`, 0.9351258309069355], 
             UndirectedEdge[10, 37] -> 
             RGBColor[
              0.29314980125126083`, 0.4217462676405007, 0.9401414095988625], 
             UndirectedEdge[118, 389] -> 
             RGBColor[
              0.22076497088432706`, 0.3493683600799934, 0.9358836105481312], 
             UndirectedEdge[127, 313] -> 
             RGBColor[
              0.20658568658737522`, 0.3344650332653477, 0.935076121283791], 
             UndirectedEdge[92, 281] -> 
             RGBColor[
              0.46303919301965735`, 0.5742863383640635, 0.9510560694278913], 
             UndirectedEdge[2, 193] -> 
             RGBColor[
              0.18596534003799042`, 0.3127917416364609, 0.9339018230528726], 
             UndirectedEdge[265, 378] -> 
             RGBColor[
              0.19040066183963522`, 0.31745354606563403`, 0.9341544080680056],
              UndirectedEdge[108, 367] -> 
             RGBColor[
              0.31561783688898226`, 0.44293150514134, 0.9415099085808494], 
             UndirectedEdge[26, 342] -> 
             RGBColor[
              0.18535691671142462`, 0.3121522501439733, 0.9338671742445064], 
             UndirectedEdge[57, 144] -> 
             RGBColor[
              0.20411547873617336`, 0.33186868819351084`, 0.93493544660101], 
             UndirectedEdge[341, 348] -> 
             RGBColor[
              0.33468734849454873`, 0.4643110922158917, 0.9425469597870388], 
             UndirectedEdge[232, 309] -> 
             RGBColor[
              0.2963446868922668, 0.42880743363510754`, 0.9401877635646132], 
             UndirectedEdge[23, 202] -> 
             RGBColor[
              0.2682077809117381, 0.39923376146669465`, 0.9385854083938443], 
             UndirectedEdge[89, 170] -> 
             RGBColor[
              0.21045471282523004`, 0.33853162515176505`, 0.9352964566043255],
              UndirectedEdge[291, 383] -> 
             RGBColor[
              0.1977645203288262, 0.3251934282333686, 0.9345737689151127], 
             UndirectedEdge[45, 140] -> 
             RGBColor[
              0.25525427585226035`, 0.38561880634952683`, 0.9378477254437005],
              UndirectedEdge[213, 308] -> 
             RGBColor[
              0.2120594900785835, 0.3402183477937941, 0.9353878462948488], 
             UndirectedEdge[165, 386] -> 
             RGBColor[
              0.8287550787424094, 0.8667695006906301, 0.9834015662110343], 
             UndirectedEdge[347, 381] -> 
             RGBColor[
              0.1970073353004369, 0.3243975787602278, 0.9345306483479008], 
             UndirectedEdge[216, 396] -> 
             RGBColor[
              0.19963425463605258`, 0.3271586375382656, 0.9346802475178853], 
             UndirectedEdge[39, 150] -> 
             RGBColor[
              0.1883607596919023, 0.31530947957110045`, 0.9340382386584571], 
             UndirectedEdge[20, 378] -> 
             RGBColor[
              0.19055340614426983`, 0.31761409001435326`, 0.9341631066301896],
              UndirectedEdge[363, 372] -> 
             RGBColor[
              0.20698461099735616`, 0.3348843281135061, 0.9350988394387836], 
             UndirectedEdge[54, 318] -> 
             RGBColor[
              0.18950140793350456`, 0.31650837319430003`, 0.9341031968883784],
              UndirectedEdge[40, 246] -> 
             RGBColor[
              0.7206526383610699, 0.7806508133791874, 0.9738469548784772], 
             UndirectedEdge[59, 178] -> 
             RGBColor[
              0.3941011919373124, 0.5157723771794137, 0.9463327573536129], 
             UndirectedEdge[172, 357] -> 
             RGBColor[
              0.8349023138683568, 0.2692800554494574, 0.18105580121785106`], 
             UndirectedEdge[268, 274] -> 
             RGBColor[
              0.5862206904488971, 0.6743925388404906, 0.9609561467561663], 
             UndirectedEdge[122, 175] -> 
             RGBColor[
              0.4398070896700592, 0.5489279977942612, 0.9504219852000314], 
             UndirectedEdge[120, 341] -> 
             RGBColor[
              0.42726711236099996`, 0.542734639248357, 0.9489335670306169], 
             UndirectedEdge[220, 366] -> 
             RGBColor[
              0.5151109603637722, 0.615629530907049, 0.9554125916387102], 
             UndirectedEdge[202, 366] -> 
             RGBColor[
              0.31887937893336776`, 0.4445735814559359, 0.9417610431931018], 
             UndirectedEdge[17, 61] -> 
             RGBColor[
              0.22052046256389546`, 0.34911136633249684`, 0.9358696861610002],
              UndirectedEdge[112, 279] -> 
             RGBColor[
              0.8046710367643358, 0.7661172165820809, 0.618109700945247], 
             UndirectedEdge[129, 313] -> 
             RGBColor[
              0.203727765298821, 0.33146117678840176`, 0.9349133668943235], 
             UndirectedEdge[204, 318] -> 
             RGBColor[
              0.1940125074344074, 0.321249824789977, 0.9343600973313813], 
             UndirectedEdge[60, 335] -> 
             RGBColor[
              0.18275395419094043`, 0.3094163714975885, 0.9337189393797027], 
             UndirectedEdge[256, 386] -> 
             RGBColor[
              0.556034698630532, 0.6458694921919914, 0.9601976146247932], 
             UndirectedEdge[7, 65] -> 
             RGBColor[
              0.36829577629683624`, 0.4914979419428903, 0.9447588725119885], 
             UndirectedEdge[66, 280] -> 
             RGBColor[
              0.23290342941472336`, 0.362126649618162, 0.936574877804197], 
             UndirectedEdge[147, 344] -> 
             RGBColor[
              0.1873628349672718, 0.31426059741343176`, 0.9339814083216866], 
             UndirectedEdge[329, 349] -> 
             RGBColor[
              0.19621450085245074`, 0.32356425948678696`, 0.9344854975989814],
              UndirectedEdge[170, 306] -> 
             RGBColor[
              0.21718838977102684`, 0.3456091465615747, 0.9356799295448063], 
             UndirectedEdge[175, 178] -> 
             RGBColor[
              0.3616708025324146, 0.48517771913218966`, 0.9443580450417194], 
             UndirectedEdge[115, 166] -> 
             RGBColor[
              0.9063036593555713, 0.6487345751416961, 0.4126405920007503], 
             UndirectedEdge[361, 396] -> 
             RGBColor[
              0.20859692759923504`, 0.3365789750888577, 0.935190658484052], 
             UndirectedEdge[80, 265] -> 
             RGBColor[
              0.18489536415726843`, 0.31166712914543293`, 0.933840889509353], 
             UndirectedEdge[18, 288] -> 
             RGBColor[
              0.45525573629442806`, 0.5643070139273578, 0.9513799079587884], 
             UndirectedEdge[225, 240] -> 
             RGBColor[
              0.8493627071457939, 0.4666896772579783, 0.44827431990902944`], 
             UndirectedEdge[110, 251] -> 
             RGBColor[
              0.18685400772656674`, 0.3137257877219404, 0.9339524313630709], 
             UndirectedEdge[56, 169] -> 
             RGBColor[
              0.6387195548301612, 0.7123648726900207, 0.967730862260616], 
             UndirectedEdge[87, 231] -> 
             RGBColor[
              0.19018595982878306`, 0.3172278806393347, 0.9341421811061108], 
             UndirectedEdge[266, 315] -> 
             RGBColor[
              0.22579916171770553`, 0.3546596138320083, 0.9361703002686741], 
             UndirectedEdge[31, 292] -> 
             RGBColor[
              0.19543097961487327`, 0.32274072898797734`, 0.9344408772236172],
              UndirectedEdge[1, 87] -> 
             RGBColor[
              0.19586287681444192`, 0.32319468032858806`, 0.934465473130198], 
             UndirectedEdge[231, 336] -> 
             RGBColor[
              0.1812731232878139, 0.3078599243283004, 0.9336346082504626], 
             UndirectedEdge[13, 309] -> 
             RGBColor[
              0.25587961899129924`, 0.38627608163770166`, 0.9378833378103566],
              UndirectedEdge[237, 296] -> 
             RGBColor[
              0.2211466738327187, 0.34976955408011773`, 0.935905347966363], 
             UndirectedEdge[95, 312] -> 
             RGBColor[
              0.43115946169626646`, 0.5444500738116986, 0.9495097680739197], 
             UndirectedEdge[108, 236] -> 
             RGBColor[
              0.2534644343240474, 0.3837375694208677, 0.9377457966165021], 
             UndirectedEdge[48, 176] -> 
             RGBColor[
              0.2369284794639835, 0.36635723242284735`, 0.9368040984499744], 
             UndirectedEdge[49, 52] -> 
             RGBColor[
              0.1835216269875808, 0.31022324428012404`, 0.9337626572098012], 
             UndirectedEdge[310, 390] -> 
             RGBColor[
              0.27115500533733905`, 0.4023314812028227, 0.9387532484648545], 
             UndirectedEdge[343, 358] -> 
             RGBColor[
              0.18639835798283702`, 0.3132468709514181, 0.933926482784239], 
             UndirectedEdge[271, 374] -> 
             RGBColor[
              0.184659451088446, 0.3114191695523481, 0.9338274546090857], 
             UndirectedEdge[57, 167] -> 
             RGBColor[
              0.2639676028821611, 0.3946376054360735, 0.9383490428444853], 
             UndirectedEdge[34, 214] -> 
             RGBColor[
              0.25149658822823806`, 0.38166923840552336`, 0.9376337306925131],
              UndirectedEdge[83, 220] -> 
             RGBColor[
              0.790428504618827, 0.8368778917698232, 0.9711999364788909], 
             UndirectedEdge[9, 347] -> 
             RGBColor[
              0.19444294915612814`, 0.3217022463310869, 0.9343846103506517], 
             UndirectedEdge[188, 238] -> 
             RGBColor[
              0.2458833929201038, 0.375769414239536, 0.9373140675236933], 
             UndirectedEdge[79, 137] -> 
             RGBColor[
              0.2827537056275888, 0.4121446936308188, 0.939500838618308], 
             UndirectedEdge[115, 197] -> 
             RGBColor[
              0.897842532453212, 0.6430337674437561, 0.45425714111029625`], 
             UndirectedEdge[67, 194] -> 
             RGBColor[
              0.709877099853931, 0.7667201163798876, 0.7972498678529694], 
             UndirectedEdge[75, 260] -> 
             RGBColor[
              0.22127423884363956`, 0.34990363299468435`, 0.9359126126050195],
              UndirectedEdge[32, 387] -> 
             RGBColor[
              0.7455791435710649, 0.7496942133696903, 0.622023162461701], 
             UndirectedEdge[76, 144] -> 
             RGBColor[
              0.19222334020881804`, 0.31936929659612845`, 0.9342582069047196],
              UndirectedEdge[50, 164] -> 
             RGBColor[
              0.18999442899880858`, 0.3170265695932755, 0.9341312737086882], 
             UndirectedEdge[279, 285] -> 
             RGBColor[
              0.8332166202434534, 0.8669371947579207, 0.788972494773293], 
             UndirectedEdge[137, 352] -> 
             RGBColor[
              0.28703295098175935`, 0.4166424518178782, 0.9397445353106518], 
             UndirectedEdge[4, 275] -> 
             RGBColor[
              0.235784586016354, 0.3651549278823552, 0.9367389554103707], 
             UndirectedEdge[8, 373] -> 
             RGBColor[
              0.2548317087924608, 0.38517466157737845`, 0.937823660874777], 
             UndirectedEdge[41, 135] -> 
             RGBColor[
              0.9333566323648748, 0.9460233638065111, 0.83381543555314], 
             UndirectedEdge[85, 211] -> 
             RGBColor[
              0.231317411938528, 0.36045964469136466`, 0.9364845564552302], 
             UndirectedEdge[63, 139] -> 
             RGBColor[
              0.18462055320460163`, 0.31137828541015944`, 0.9338252394321449],
              UndirectedEdge[55, 92] -> 
             RGBColor[
              0.7345108890138425, 0.7594054710903482, 0.6489345144638174], 
             UndirectedEdge[31, 371] -> 
             RGBColor[
              0.1915120199175549, 0.31862165386969954`, 0.9342176982664363], 
             UndirectedEdge[99, 169] -> 
             RGBColor[
              0.9307128082989145, 0.9468171296861931, 0.9664871194315787], 
             UndirectedEdge[71, 72] -> 
             RGBColor[
              0.18087056047954858`, 0.30743680529285733`, 0.9336116828940703],
              UndirectedEdge[104, 112] -> 
             RGBColor[
              0.8583753725290609, 0.36086558387559853`, 0.19997554950264038`],
              UndirectedEdge[389, 390] -> 
             RGBColor[
              0.23267978688900162`, 0.3618915871438733, 0.9365621416932066], 
             UndirectedEdge[260, 349] -> 
             RGBColor[
              0.21328372600725728`, 0.3415050973758713, 0.9354575647198919], 
             UndirectedEdge[70, 284] -> 
             RGBColor[
              0.24975725951810934`, 0.3798410936513683, 0.9375346784955776], 
             UndirectedEdge[24, 172] -> 
             RGBColor[
              0.8217923093699344, 0.16851081603398022`, 0.16850164610452945`],
              UndirectedEdge[343, 362] -> 
             RGBColor[
              0.18559297832352872`, 0.3124003658654654, 0.9338806176040938], 
             UndirectedEdge[233, 307] -> 
             RGBColor[
              0.6538804302709667, 0.7226974017073509, 0.9485082265240019], 
             UndirectedEdge[79, 278] -> 
             RGBColor[
              0.24460490622546205`, 0.37442564366272924`, 0.937241259597785], 
             UndirectedEdge[1, 216] -> 
             RGBColor[
              0.19662871859939152`, 0.3239996286017438, 0.9345090866868895], 
             UndirectedEdge[192, 374] -> 
             RGBColor[
              0.18592011737534742`, 0.3127442097507407, 0.933899247689136], 
             UndirectedEdge[152, 383] -> 
             RGBColor[
              0.2325615956471479, 0.3617673606549275, 0.9365554108768314], 
             UndirectedEdge[43, 121] -> 
             RGBColor[
              0.28563299292961386`, 0.4173490407437973, 0.9395850612911336], 
             UndirectedEdge[13, 280] -> 
             RGBColor[
              0.23284937828008462`, 0.36206983844861684`, 0.9365717996720409],
              UndirectedEdge[246, 272] -> 
             RGBColor[
              0.8305893181173114, 0.8683923303180165, 0.9835339903359117], 
             UndirectedEdge[385, 387] -> 
             RGBColor[
              0.7642756795140044, 0.8115756260652711, 0.7955379877927361], 
             UndirectedEdge[90, 268] -> 
             RGBColor[
              0.6438707815800897, 0.7211954799278018, 0.9654945731092558], 
             UndirectedEdge[195, 363] -> 
             RGBColor[
              0.21087458530257291`, 0.33897293774690507`, 0.9353203677207644],
              UndirectedEdge[88, 109] -> 
             RGBColor[
              0.18639597403767888`, 0.31324436527390603`, 0.9339263470220889],
              UndirectedEdge[63, 318] -> 
             RGBColor[
              0.18778593589765713`, 0.3147053033174152, 0.9340055032937504], 
             UndirectedEdge[257, 276] -> 
             RGBColor[
              0.27298076036949565`, 0.4029229337235066, 0.9389058299544288], 
             UndirectedEdge[16, 106] -> 
             RGBColor[
              0.2722971064429795, 0.4026970623499158, 0.9388488569979281], 
             UndirectedEdge[100, 227] -> 
             RGBColor[
              0.20880854883445307`, 0.33680140242463313`, 0.9352027100003322],
              UndirectedEdge[195, 359] -> 
             RGBColor[
              0.19452611281546262`, 0.321789656609928, 0.9343893463980213], 
             UndirectedEdge[216, 313] -> 
             RGBColor[
              0.2090389311379428, 0.3370435488326826, 0.9352158299316957], 
             UndirectedEdge[12, 47] -> 
             RGBColor[
              0.4262898849714413, 0.5411626092696967, 0.9490658048705467], 
             UndirectedEdge[386, 400] -> 
             RGBColor[
              0.8203725249629105, 0.5288099921038794, 0.4560525726712711], 
             UndirectedEdge[180, 262] -> 
             RGBColor[
              0.23634740435871976`, 0.36574648564492557`, 0.9367710070823533],
              UndirectedEdge[247, 359] -> 
             RGBColor[
              0.1924159607622266, 0.31957175301060936`, 0.9342691763602797], 
             UndirectedEdge[74, 141] -> 
             RGBColor[
              0.8647517069281606, 0.6196093049293407, 0.46864262893452036`], 
             UndirectedEdge[170, 171] -> 
             RGBColor[
              0.21031358554217228`, 0.3383832914292848, 0.9352884196143345], 
             UndirectedEdge[207, 333] -> 
             RGBColor[
              0.18793493502051017`, 0.3148619108426237, 0.9340139885733725], 
             UndirectedEdge[311, 313] -> 
             RGBColor[
              0.2605556138292256, 0.39119084868755866`, 0.938149628798862], 
             UndirectedEdge[161, 195] -> 
             RGBColor[
              0.20065168741435874`, 0.3282280238972294, 0.9347381888094528], 
             UndirectedEdge[87, 129] -> 
             RGBColor[
              0.1936336407966272, 0.32085161193213774`, 0.9343385214368426], 
             UndirectedEdge[198, 367] -> 
             RGBColor[
              0.36419518981338295`, 0.4898693012590379, 0.9444271733431154], 
             UndirectedEdge[322, 330] -> 
             RGBColor[
              0.19291768102176954`, 0.3200990928142907, 0.934297748586832], 
             UndirectedEdge[79, 314] -> 
             RGBColor[
              0.23185910927542647`, 0.36102900293803986`, 0.9365154053171973],
              UndirectedEdge[56, 274] -> 
             RGBColor[
              0.43736444745775693`, 0.5521652442024196, 0.9493877477928349], 
             UndirectedEdge[249, 316] -> 
             RGBColor[
              0.271715102066897, 0.4028896300992718, 0.9387862636671344], 
             UndirectedEdge[69, 294] -> 
             RGBColor[
              0.2158880199071448, 0.3442423753864234, 0.935605875404783], 
             UndirectedEdge[6, 300] -> 
             RGBColor[
              0.6101439916355338, 0.6866719134983721, 0.9662201158700239], 
             UndirectedEdge[36, 265] -> 
             RGBColor[
              0.1914303121066489, 0.318535773779863, 0.934213045127481], 
             UndirectedEdge[167, 395] -> 
             RGBColor[
              0.389446651029121, 0.5113248488468087, 0.9461511158699245], 
             UndirectedEdge[261, 306] -> 
             RGBColor[
              0.2313412040252819, 0.36048465168304844`, 0.9364859113793738], 
             UndirectedEdge[35, 211] -> 
             RGBColor[
              0.22907054143597805`, 0.35809804133336665`, 0.9363566005040571],
              UndirectedEdge[54, 63] -> 
             RGBColor[
              0.18289690010848875`, 0.3095666167202264, 0.9337270799382376], 
             UndirectedEdge[302, 314] -> 
             RGBColor[
              0.21202470254257239`, 0.3401817838877893, 0.9353858651961364], 
             UndirectedEdge[54, 224] -> 
             RGBColor[
              0.18197335735342035`, 0.3085959147286568, 0.9336744855445955], 
             UndirectedEdge[164, 389] -> 
             RGBColor[
              0.20180063292388895`, 0.3294356384750984, 0.934803619556508], 
             UndirectedEdge[113, 210] -> 
             RGBColor[
              0.3065896783902691, 0.43957556926948627`, 0.9407712006743179], 
             UndirectedEdge[307, 348] -> 
             RGBColor[
              0.3407470767330234, 0.4695597242452613, 0.9429330803119872], 
             UndirectedEdge[18, 74] -> 
             RGBColor[
              0.7341001698400949, 0.7919819236306536, 0.974429319456183], 
             UndirectedEdge[41, 328] -> 
             RGBColor[
              0.8707008812978143, 0.7005608755905404, 0.6002433163697872], 
             UndirectedEdge[63, 290] -> 
             RGBColor[
              0.18969933550436535`, 0.3167164076206075, 0.9341144685707314], 
             UndirectedEdge[45, 288] -> 
             RGBColor[
              0.29509029119202934`, 0.4274889842208769, 0.9401163275851969], 
             UndirectedEdge[249, 315] -> 
             RGBColor[
              0.2639611950336743, 0.39473978218125394`, 0.9383446901324698], 
             UndirectedEdge[306, 342] -> 
             RGBColor[
              0.1932134040418383, 0.3204099164583054, 0.934314589575342], 
             UndirectedEdge[163, 395] -> 
             RGBColor[
              0.36771682090515007`, 0.4886248797144314, 0.9449085278741232], 
             UndirectedEdge[378, 379] -> 
             RGBColor[
              0.19896021464386793`, 0.3264501787698757, 0.934641861937483], 
             UndirectedEdge[216, 235] -> 
             RGBColor[
              0.1956123156574894, 0.32293132466613605`, 0.9344512040429815], 
             UndirectedEdge[220, 321] -> 
             RGBColor[
              0.5950920301278422, 0.6821615445050555, 0.961266970987048], 
             UndirectedEdge[133, 199] -> 
             RGBColor[
              0.18613849661309062`, 0.31297374017565216`, 0.9339116840636623],
              UndirectedEdge[317, 396] -> 
             RGBColor[
              0.19745595153076353`, 0.32486910286221293`, 0.9345561963785496],
              UndirectedEdge[177, 197] -> 
             RGBColor[
              0.9295820155952076, 0.9459496447868232, 0.9675642537426303], 
             UndirectedEdge[208, 242] -> 
             RGBColor[
              0.8991873759760702, 0.5989945750982921, 0.3869330957871117], 
             UndirectedEdge[51, 163] -> 
             RGBColor[
              0.3241863421441664, 0.4513369658591039, 0.9420198625128315], 
             UndirectedEdge[188, 228] -> 
             RGBColor[
              0.20268995802939208`, 0.3303703755474506, 0.9348542653056278], 
             UndirectedEdge[95, 125] -> 
             RGBColor[
              0.41046090544111513`, 0.5226945788232695, 0.9483310159159588], 
             UndirectedEdge[66, 203] -> 
             RGBColor[
              0.2200139191384291, 0.3485789570756236, 0.9358408392622837], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.2667189772067604, 0.39766893437715617`, 0.9385006232253336], 
             UndirectedEdge[151, 265] -> 
             RGBColor[
              0.1910010224377346, 0.31808456311929695`, 0.9341885977159134], 
             UndirectedEdge[76, 333] -> 
             RGBColor[
              0.19100459551754329`, 0.3180883186527222, 0.9341888011975227], 
             UndirectedEdge[119, 336] -> 
             RGBColor[
              0.18138462902211405`, 0.30797712392492177`, 0.9336409583370731],
              UndirectedEdge[183, 395] -> 
             RGBColor[
              0.40931291362813915`, 0.5285320070026871, 0.9474169765556877], 
             UndirectedEdge[42, 204] -> 
             RGBColor[
              0.20507426806755127`, 0.33287643657154375`, 0.9349900482350304],
              UndirectedEdge[12, 107] -> 
             RGBColor[
              0.3285473986430889, 0.45896802364421685`, 0.9421566412492507], 
             UndirectedEdge[234, 239] -> 
             RGBColor[
              0.8137495240944908, 0.42044629252070553`, 0.4425717899514292], 
             UndirectedEdge[164, 287] -> 
             RGBColor[
              0.19544251078166353`, 0.3227528489753921, 0.9344415339065071], 
             UndirectedEdge[32, 194] -> 
             RGBColor[
              0.9757819569708761, 0.9287169668940988, 0.4668813870087187], 
             UndirectedEdge[6, 169] -> 
             RGBColor[
              0.6006886092479335, 0.6791324482420171, 0.965318253056975], 
             UndirectedEdge[24, 240] -> 
             RGBColor[
              0.8244208751281166, 0.18871512429622833`, 0.17101876364310512`],
              UndirectedEdge[9, 381] -> 
             RGBColor[
              0.19359903145009902`, 0.3208152353145773, 0.9343365504857577], 
             UndirectedEdge[43, 90] -> 
             RGBColor[
              0.434369237561579, 0.5419666394359329, 0.9502257108546233], 
             UndirectedEdge[88, 157] -> 
             RGBColor[
              0.189431793006949, 0.31643520349264886`, 0.9340992324212971], 
             UndirectedEdge[100, 314] -> 
             RGBColor[
              0.22141089937149833`, 0.35004727187424184`, 0.93592039521991], 
             UndirectedEdge[56, 296] -> 
             RGBColor[
              0.313305483869233, 0.43989379597440015`, 0.9414004589756761], 
             UndirectedEdge[49, 235] -> 
             RGBColor[
              0.18959591922153213`, 0.31660771055037873`, 0.9341085791664148],
              UndirectedEdge[359, 362] -> 
             RGBColor[
              0.18818450229900258`, 0.31512422187579864`, 0.9340282010606809],
              UndirectedEdge[104, 285] -> 
             RGBColor[
              0.8774057615151394, 0.4280789026594918, 0.3138840787213377], 
             UndirectedEdge[80, 168] -> 
             RGBColor[
              0.18200651498987047`, 0.3086307655068815, 0.933676373822939], 
             UndirectedEdge[311, 386] -> 
             RGBColor[
              0.5317523136158948, 0.6242823861276408, 0.958670681032904], 
             UndirectedEdge[61, 173] -> 
             RGBColor[
              0.24592220228648118`, 0.3758102053442546, 0.937316277659695], 
             UndirectedEdge[118, 354] -> 
             RGBColor[
              0.22736699671866945`, 0.3563075078245018, 0.9362595861525749], 
             UndirectedEdge[154, 180] -> 
             RGBColor[
              0.2320279298273124, 0.36120644404191316`, 0.9365250193978796], 
             UndirectedEdge[17, 158] -> 
             RGBColor[
              0.2852162427380673, 0.4143360909345327, 0.9396556083799944], 
             UndirectedEdge[8, 237] -> 
             RGBColor[
              0.2175725261235523, 0.3460128982237305, 0.9357018055418038], 
             UndirectedEdge[55, 255] -> 
             RGBColor[
              0.880784705491405, 0.48719515298926147`, 0.23576144034449814`], 
             UndirectedEdge[93, 214] -> 
             RGBColor[
              0.23703264551730702`, 0.36646671754939963`, 0.9368100305526114],
              UndirectedEdge[129, 235] -> 
             RGBColor[
              0.1903011498183676, 0.3173489526218552, 0.9341487410056093], 
             UndirectedEdge[47, 158] -> 
             RGBColor[
              0.44142989596913074`, 0.5543010784500094, 0.9500295993461311], 
             UndirectedEdge[106, 347] -> 
             RGBColor[
              0.21233497992474068`, 0.3405079050891704, 0.9354035350340366], 
             UndirectedEdge[169, 178] -> 
             RGBColor[
              0.668739474081812, 0.7383666179007873, 0.9696437049697588], 
             UndirectedEdge[230, 385] -> 
             RGBColor[
              0.8766339838226677, 0.4217282490533341, 0.32128251559499077`], 
             UndirectedEdge[304, 383] -> 
             RGBColor[
              0.1946222087294852, 0.32189065950839857`, 0.9343948189181637], 
             UndirectedEdge[100, 352] -> 
             RGBColor[
              0.2248749641652065, 0.3536882236068225, 0.936117668585287], 
             UndirectedEdge[87, 216] -> 
             RGBColor[
              0.198944806635749, 0.32643398397641854`, 0.9346409844742148], 
             UndirectedEdge[79, 277] -> 
             RGBColor[
              0.21942962029019444`, 0.3479648219394422, 0.9358075643072694], 
             UndirectedEdge[217, 220] -> 
             RGBColor[
              0.8144460532518553, 0.851406632354037, 0.7257595325601884], 
             UndirectedEdge[78, 104] -> 
             RGBColor[
              0.8196280933998756, 0.15187570372262318`, 0.16642919044746882`],
              UndirectedEdge[170, 353] -> 
             RGBColor[
              0.2108426436010009, 0.33893936499333205`, 0.9353185486881135], 
             UndirectedEdge[78, 385] -> 
             RGBColor[
              0.8781001584283712, 0.43299790955458023`, 0.3226865260532199], 
             UndirectedEdge[40, 102] -> 
             RGBColor[
              0.39926565859510593`, 0.5155146756656562, 0.9472759248895897], 
             UndirectedEdge[41, 256] -> 
             RGBColor[
              0.6115898950741928, 0.6896890172445088, 0.9656235459657501], 
             UndirectedEdge[120, 217] -> 
             RGBColor[
              0.7556843813439534, 0.80370125991605, 0.7211335984965017], 
             UndirectedEdge[210, 315] -> 
             RGBColor[
              0.26224986664151034`, 0.39297161581510254`, 0.9382461139900993],
              UndirectedEdge[83, 187] -> 
             RGBColor[
              0.6899774075909928, 0.7548276258988081, 0.9634300825559947], 
             UndirectedEdge[2, 305] -> 
             RGBColor[
              0.18360947068078184`, 0.31031557357129014`, 0.9337676597781759],
              UndirectedEdge[121, 175] -> 
             RGBColor[
              0.29627876905743955`, 0.4285384264353338, 0.9401913224925988], 
             UndirectedEdge[36, 151] -> 
             RGBColor[
              0.19244860485001886`, 0.3196060640166337, 0.9342710353927868], 
             UndirectedEdge[70, 332] -> 
             RGBColor[
              0.22563024765380635`, 0.35448207444108004`, 0.936160680862621], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.1986384662361157, 0.32611200079330077`, 0.9346235388416457], 
             UndirectedEdge[221, 400] -> 
             RGBColor[
              0.8675551125355545, 0.47422857106757765`, 0.2105215349800247], 
             UndirectedEdge[49, 216] -> 
             RGBColor[
              0.19369425198474133`, 0.320915318133817, 0.9343419731543394], 
             UndirectedEdge[75, 349] -> 
             RGBColor[
              0.2099761655665867, 0.3380286416412822, 0.935269204045893], 
             UndirectedEdge[62, 87] -> 
             RGBColor[
              0.1996423811721627, 0.3271671790429695, 0.9346807103120945], 
             UndirectedEdge[38, 189] -> 
             RGBColor[
              0.24478652953490182`, 0.3746165412765333, 0.9372516027765698], 
             UndirectedEdge[49, 361] -> 
             RGBColor[
              0.2026569249479238, 0.33033565568440915`, 0.9348523841205063], 
             UndirectedEdge[107, 270] -> 
             RGBColor[
              0.35385896317997434`, 0.4809165812630355, 0.943768558122001], 
             UndirectedEdge[5, 8] -> 
             RGBColor[
              0.2601258969540067, 0.39073918900607996`, 0.9381251570585274], 
             UndirectedEdge[162, 340] -> 
             RGBColor[
              0.23763180163327896`, 0.367096468615978, 0.9368441516070439], 
             UndirectedEdge[34, 85] -> 
             RGBColor[
              0.25199669770088307`, 0.3821948851700452, 0.9376622111871347], 
             UndirectedEdge[21, 172] -> 
             RGBColor[
              0.8702695187872548, 0.4184898017964773, 0.21746738553413028`], 
             UndirectedEdge[298, 393] -> 
             RGBColor[
              0.19018046268844432`, 0.31722210279629987`, 0.9341418680521008],
              UndirectedEdge[164, 371] -> 
             RGBColor[
              0.1937500929349124, 0.3209740105129675, 0.9343451532138425], 
             UndirectedEdge[11, 85] -> 
             RGBColor[
              0.2763549775912347, 0.40749939278433556`, 0.9390602753814483], 
             UndirectedEdge[202, 307] -> 
             RGBColor[
              0.295856931076972, 0.42463269426460054`, 0.9402940731736436], 
             UndirectedEdge[20, 265] -> 
             RGBColor[
              0.19013547399899927`, 0.31717481683124543`, 0.9341393060127917],
              UndirectedEdge[195, 247] -> 
             RGBColor[
              0.1997381438211963, 0.32726783165880646`, 0.9346861638532888], 
             UndirectedEdge[281, 355] -> 
             RGBColor[
              0.5971975343016019, 0.6813125874620714, 0.9629093916561169], 
             UndirectedEdge[298, 313] -> 
             RGBColor[
              0.20768244341745035`, 0.33561779423215604`, 0.9351385799627575],
              UndirectedEdge[67, 210] -> 
             RGBColor[
              0.365438140563206, 0.4906599829992886, 0.9445168412553058], 
             UndirectedEdge[11, 263] -> 
             RGBColor[
              0.35195866140263943`, 0.47927063537545245`, 0.9436474725731201],
              UndirectedEdge[88, 181] -> 
             RGBColor[
              0.19319654196954522`, 0.3203921933512083, 0.9343136293052701], 
             UndirectedEdge[212, 390] -> 
             RGBColor[
              0.3400236714682391, 0.46467688938800766`, 0.9430428280078589], 
             UndirectedEdge[13, 203] -> 
             RGBColor[
              0.21995986800379036`, 0.3485221459060784, 0.9358377611301275], 
             UndirectedEdge[75, 105] -> 
             RGBColor[
              0.21372122175088312`, 0.34196493314125437`, 0.9354824794552745],
              UndirectedEdge[12, 270] -> 
             RGBColor[
              0.3337876806083378, 0.46350689249828564`, 0.9424905473822769], 
             UndirectedEdge[127, 393] -> 
             RGBColor[
              0.1890837058583692, 0.31606934182949153`, 0.9340794093731344], 
             UndirectedEdge[185, 208] -> 
             RGBColor[
              0.6963078073762952, 0.755957556681333, 0.8560508247348155], 
             UndirectedEdge[246, 355] -> 
             RGBColor[
              0.8429762449225704, 0.8780690916824152, 0.9847686034374477], 
             UndirectedEdge[62, 336] -> 
             RGBColor[
              0.19072954463119351`, 0.31779922273193517`, 0.9341731374564464],
              UndirectedEdge[118, 209] -> 
             RGBColor[
              0.2868618960178613, 0.41642761918472027`, 0.9397360770801573], 
             UndirectedEdge[178, 352] -> 
             RGBColor[
              0.3406463330534576, 0.4630796686814488, 0.9431607326078082], 
             UndirectedEdge[17, 22] -> 
             RGBColor[
              0.2739758563683775, 0.40460023321935323`, 0.9389393809000012], 
             UndirectedEdge[12, 158] -> 
             RGBColor[
              0.32361612706914167`, 0.45469680405977975`, 0.941842424985111], 
             UndirectedEdge[200, 333] -> 
             RGBColor[
              0.18616349406283006`, 0.3130000140802582, 0.9339131076314446], 
             UndirectedEdge[69, 295] -> 
             RGBColor[
              0.3354255676488553, 0.4587623903805083, 0.9428205754850394], 
             UndirectedEdge[181, 340] -> 
             RGBColor[
              0.19892920598511726`, 0.3264175867034662, 0.9346400960402405], 
             UndirectedEdge[205, 284] -> 
             RGBColor[
              0.313308210862673, 0.4428213204414291, 0.9412935282095445], 
             UndirectedEdge[283, 373] -> 
             RGBColor[
              0.2404157449182508, 0.3700225695206825, 0.937002693058648], 
             UndirectedEdge[302, 379] -> 
             RGBColor[
              0.199238475276043, 0.32674264833703476`, 0.9346577084688357], 
             UndirectedEdge[254, 303] -> 
             RGBColor[
              0.20024144683233963`, 0.3277968350347721, 0.9347148262152034], 
             UndirectedEdge[38, 254] -> 
             RGBColor[
              0.20508861754811766`, 0.3328915187854286, 0.9349908654167205], 
             UndirectedEdge[158, 209] -> 
             RGBColor[
              0.336799320476102, 0.4661403761955148, 0.94268153277416], 
             UndirectedEdge[365, 370] -> 
             RGBColor[
              0.18400910577117147`, 0.3107356153896179, 0.9337904184053665], 
             UndirectedEdge[61, 164] -> 
             RGBColor[
              0.2051585954739804, 0.3329650700223671, 0.9349948505560753], 
             UndirectedEdge[163, 167] -> 
             RGBColor[
              0.2885245503262027, 0.4204485142001573, 0.9397475246726753], 
             UndirectedEdge[62, 119] -> 
             RGBColor[
              0.1917608818844465, 0.31888322357566273`, 0.9342318705872924], 
             UndirectedEdge[137, 197] -> 
             RGBColor[
              0.6493874970557305, 0.7185106775296126, 0.9439140882472267], 
             UndirectedEdge[265, 383] -> 
             RGBColor[
              0.1991683094404495, 0.3266688995950551, 0.9346537126282998], 
             UndirectedEdge[19, 338] -> 
             RGBColor[
              0.24730224830049347`, 0.3772607212049526, 0.937394869238598], 
             UndirectedEdge[69, 212] -> 
             RGBColor[
              0.32957634955032006`, 0.4536960916538069, 0.9424478684800611], 
             UndirectedEdge[45, 275] -> 
             RGBColor[
              0.261779864050582, 0.3924776132921515, 0.9382193480378523], 
             UndirectedEdge[248, 360] -> 
             RGBColor[
              0.20162405229043762`, 0.3292500410334822, 0.9347935635506606], 
             UndirectedEdge[188, 322] -> 
             RGBColor[
              0.20084485470176572`, 0.3284310549638075, 0.9347491894007052], 
             UndirectedEdge[167, 183] -> 
             RGBColor[
              0.33012064304919175`, 0.46035564148841296`, 0.9422559733542398],
              UndirectedEdge[141, 240] -> 
             RGBColor[
              0.8542946643121351, 0.403254589818024, 0.1990353031720827], 
             UndirectedEdge[23, 220] -> 
             RGBColor[
              0.46443936234214256`, 0.5702897109178078, 0.9522369568394528], 
             UndirectedEdge[123, 322] -> 
             RGBColor[
              0.20580146810397543`, 0.3336407699169709, 0.9350314612013086], 
             UndirectedEdge[177, 398] -> 
             RGBColor[
              0.6604733814795012, 0.7312391377896288, 0.9691021762679148], 
             UndirectedEdge[272, 395] -> 
             RGBColor[
              0.6047861017850406, 0.688521596311049, 0.9630625411341533], 
             UndirectedEdge[85, 312] -> 
             RGBColor[
              0.27182714160879756`, 0.40303793904002655`, 0.9387915256311776],
              UndirectedEdge[25, 328] -> 
             RGBColor[
              0.8347229187599272, 0.2562351535933635, 0.18042720125236386`], 
             UndirectedEdge[8, 121] -> 
             RGBColor[
              0.2743592219367422, 0.4054995926319236, 0.9389430367111391], 
             UndirectedEdge[169, 319] -> 
             RGBColor[
              0.6745752376290368, 0.7434200744106859, 0.9700158830654886], 
             UndirectedEdge[84, 167] -> 
             RGBColor[
              0.32454610124482625`, 0.4555272535620894, 0.9419007684798394], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.2877186940288704, 0.4160544664052851, 0.9398315069221266], 
             UndirectedEdge[43, 213] -> 
             RGBColor[
              0.2414891450614786, 0.3711507811287148, 0.9370638216088516], 
             UndirectedEdge[170, 187] -> 
             RGBColor[
              0.33329236872326556`, 0.45597611149735384`, 0.9427190170162062],
              UndirectedEdge[89, 199] -> 
             RGBColor[
              0.18786740786844439`, 0.3147909355243339, 0.9340101430019597], 
             UndirectedEdge[16, 373] -> 
             RGBColor[
              0.29481332974402036`, 0.42636304065032193`, 0.9401311226051551],
              UndirectedEdge[22, 158] -> 
             RGBColor[
              0.3275157516971413, 0.458099415524913, 0.9420899919807021], 
             UndirectedEdge[233, 264] -> 
             RGBColor[
              0.8413490098710985, 0.8765030596973409, 0.9633266229040078], 
             UndirectedEdge[274, 296] -> 
             RGBColor[
              0.36901952314668135`, 0.4870709060931353, 0.9452488023460986], 
             UndirectedEdge[97, 211] -> 
             RGBColor[
              0.20738956458852648`, 0.33530996001336677`, 0.9351219009467256],
              UndirectedEdge[1, 129] -> 
             RGBColor[
              0.19131755276026974`, 0.31841725655746295`, 0.9342066236495172],
              UndirectedEdge[24, 141] -> 
             RGBColor[
              0.8357237455500708, 0.2680521548465373, 0.1815470877583059], 
             UndirectedEdge[347, 384] -> 
             RGBColor[
              0.19370455937175246`, 0.32092615185109175`, 0.9343425601447813],
              UndirectedEdge[36, 378] -> 
             RGBColor[
              0.1918482442519195, 0.31897504696297085`, 0.934236845744879], 
             UndirectedEdge[174, 395] -> 
             RGBColor[
              0.4063176896518592, 0.5259376945387678, 0.9472261235324917], 
             UndirectedEdge[104, 357] -> 
             RGBColor[
              0.8317062451348429, 0.24471367063742083`, 0.17799524218919488`],
              UndirectedEdge[47, 173] -> 
             RGBColor[
              0.41329174036295263`, 0.5275007351562074, 0.948325579764125], 
             UndirectedEdge[127, 231] -> 
             RGBColor[
              0.1884985570631651, 0.31545431334515556`, 0.9340460860148976], 
             UndirectedEdge[252, 367] -> 
             RGBColor[
              0.372324185998124, 0.4969102291790325, 0.9449451457918181], 
             UndirectedEdge[158, 310] -> 
             RGBColor[
              0.30917761379090525`, 0.4395210111497373, 0.9410201730137817], 
             UndirectedEdge[149, 397] -> 
             RGBColor[
              0.21476341163145843`, 0.34306034078439396`, 0.9355418306271915],
              UndirectedEdge[204, 345] -> 
             RGBColor[
              0.18631088399028722`, 0.3131549302390768, 0.9339215012697695], 
             UndirectedEdge[231, 396] -> 
             RGBColor[
              0.19087540782908663`, 0.31795253420118175`, 0.9341814441497811],
              UndirectedEdge[162, 263] -> 
             RGBColor[
              0.33214075614847005`, 0.45873834938016844`, 0.9425079759974546],
              UndirectedEdge[14, 196] -> 
             RGBColor[
              0.18714224683050756`, 0.3140287452955969, 0.9339688461536289], 
             UndirectedEdge[43, 175] -> 
             RGBColor[
              0.2710055822533935, 0.4021744280676252, 0.9387447390412754], 
             UndirectedEdge[113, 397] -> 
             RGBColor[
              0.2602244815922864, 0.3908428077115391, 0.9381307713078346], 
             UndirectedEdge[126, 336] -> 
             RGBColor[
              0.18346975723563688`, 0.31016872588209876`, 0.9337597033041625],
              UndirectedEdge[48, 173] -> 
             RGBColor[
              0.2613339339978391, 0.3920089125331203, 0.938193952981043], 
             UndirectedEdge[28, 168] -> 
             RGBColor[
              0.19559687276408316`, 0.32291509320603007`, 0.9344503245930478],
              UndirectedEdge[253, 359] -> 
             RGBColor[
              0.18914843365842357`, 0.3161373748513282, 0.9340830955255912], 
             UndirectedEdge[41, 187] -> 
             RGBColor[
              0.6533956652271913, 0.7258990741319324, 0.9682873726725081], 
             UndirectedEdge[198, 398] -> 
             RGBColor[
              0.38970123207440616`, 0.5119613530945772, 0.9460523958018803], 
             UndirectedEdge[260, 329] -> 
             RGBColor[
              0.20751257412950358`, 0.3354392508401891, 0.9351289061581081], 
             UndirectedEdge[60, 82] -> 
             RGBColor[
              0.18336573314646784`, 0.31005938996887394`, 0.9337537792861741],
              UndirectedEdge[12, 17] -> 
             RGBColor[0.2700762317403779, 0.40119762175422, 0.93869181390441],
              UndirectedEdge[268, 351] -> 
             RGBColor[
              0.7945761589543001, 0.8401740652758038, 0.979966961918109], 
             UndirectedEdge[122, 274] -> 
             RGBColor[
              0.5455206538470523, 0.6419172680752578, 0.9573645306602898], 
             UndirectedEdge[150, 384] -> 
             RGBColor[
              0.19155187583051508`, 0.31866354496123156`, 0.9342199680017178],
              UndirectedEdge[179, 232] -> 
             RGBColor[
              0.374520452238133, 0.49753308772821003`, 0.9451360369712756], 
             UndirectedEdge[4, 131] -> 
             RGBColor[
              0.22303764420255517`, 0.35175708383326204`, 0.9360130359314853],
              UndirectedEdge[128, 155] -> 
             RGBColor[
              0.2008465417565683, 0.32843282816537045`, 0.9347492854759805], 
             UndirectedEdge[316, 362] -> 
             RGBColor[
              0.2117594365618467, 0.339902972523212, 0.9353707586909601], 
             UndirectedEdge[283, 320] -> 
             RGBColor[
              0.20238649627655553`, 0.330051418004633, 0.9348369836077353], 
             UndirectedEdge[49, 396] -> 
             RGBColor[
              0.1936178582000953, 0.3208350234225083, 0.9343376226413184], 
             UndirectedEdge[371, 389] -> 
             RGBColor[
              0.194598112629328, 0.3218653329793524, 0.9343934466809067], 
             UndirectedEdge[53, 58] -> 
             RGBColor[
              0.20217788494718347`, 0.3298321542707407, 0.9348251035011402], 
             UndirectedEdge[18, 399] -> 
             RGBColor[
              0.7658581753592988, 0.7184623790314186, 0.610918793426945], 
             UndirectedEdge[241, 270] -> 
             RGBColor[
              0.31115624108701556`, 0.43971981464523346`, 0.9412017203817521],
              UndirectedEdge[137, 169] -> 
             RGBColor[
              0.6151260920101136, 0.6919294010372166, 0.9662275076726026], 
             UndirectedEdge[156, 386] -> 
             RGBColor[
              0.8075774492029875, 0.43046143297516193`, 0.4437999936735976], 
             UndirectedEdge[19, 262] -> 
             RGBColor[
              0.23727783738368446`, 0.36672442974702457`, 0.9368239938666727],
              UndirectedEdge[85, 181] -> 
             RGBColor[
              0.2178344766889036, 0.34628822487653976`, 0.9357167232389794], 
             UndirectedEdge[74, 240] -> 
             RGBColor[
              0.8421459660842523, 0.4609352438287227, 0.4475859807041188], 
             UndirectedEdge[72, 88] -> 
             RGBColor[
              0.18714176336881175`, 0.31402823714670136`, 0.9339688186212005],
              UndirectedEdge[63, 98] -> 
             RGBColor[
              0.19109841618892076`, 0.3181869301269141, 0.9341941441459625], 
             UndirectedEdge[43, 56] -> 
             RGBColor[
              0.3210051071529382, 0.44798658822988663`, 0.9418389411311112], 
             UndirectedEdge[174, 272] -> 
             RGBColor[
              0.5424648698288314, 0.6349580764887339, 0.9589765455952728], 
             UndirectedEdge[180, 198] -> 
             RGBColor[
              0.30592577418738304`, 0.43475768207038135`, 0.9408842486890967],
              UndirectedEdge[126, 289] -> 
             RGBColor[
              0.1863769520635358, 0.31322437197301883`, 0.933925263748802], 
             UndirectedEdge[233, 244] -> 
             RGBColor[
              0.9570858882964418, 0.9675153062736708, 0.9575265767079428], 
             UndirectedEdge[51, 189] -> 
             RGBColor[
              0.324110599148695, 0.45125735516848015`, 0.9420155490612911], 
             UndirectedEdge[199, 306] -> 
             RGBColor[
              0.19460108481424115`, 0.32186845693414357`, 0.9343936159424405],
              UndirectedEdge[86, 214] -> 
             RGBColor[
              0.32538385594789154`, 0.4498732658782442, 0.9421877381945456], 
             UndirectedEdge[104, 172] -> 
             RGBColor[
              0.8206071574601663, 0.15940121911862504`, 0.16736674329729798`],
              UndirectedEdge[67, 293] -> 
             RGBColor[
              0.3870584168095417, 0.509672279343909, 0.9458839979501529], 
             UndirectedEdge[296, 380] -> 
             RGBColor[
              0.23254239925943204`, 0.3617471840343169, 0.9365543176709494], 
             UndirectedEdge[290, 297] -> 
             RGBColor[
              0.20256888353236238`, 0.33024311857450594`, 0.9348473702921356],
              UndirectedEdge[206, 328] -> 
             RGBColor[
              0.7999219852902167, 0.6448484807342735, 0.5933000289298582], 
             UndirectedEdge[5, 319] -> 
             RGBColor[
              0.3679006517731242, 0.4906453846924169, 0.9447526657346955], 
             UndirectedEdge[235, 393] -> 
             RGBColor[
              0.18743861764572758`, 0.31434024981338815`, 0.9339857240331143],
              UndirectedEdge[40, 189] -> 
             RGBColor[
              0.3938515783304093, 0.5098241340349448, 0.9469676010279292], 
             UndirectedEdge[15, 256] -> 
             RGBColor[
              0.31856719551894513`, 0.448229479012007, 0.9415973902435224], 
             UndirectedEdge[71, 365] -> 
             RGBColor[
              0.17992874679989868`, 0.30644689940110903`, 0.9335580479983027],
              UndirectedEdge[53, 64] -> 
             RGBColor[
              0.18652020523185484`, 0.31337494013569756`, 0.9339334218048136],
              UndirectedEdge[231, 298] -> 
             RGBColor[
              0.1895953138932402, 0.3166070743119639, 0.934108544693864], 
             UndirectedEdge[81, 382] -> 
             RGBColor[
              0.18072466475425025`, 0.3072834596352455, 0.9336033743483478], 
             UndirectedEdge[9, 294] -> 
             RGBColor[
              0.1904972038981096, 0.3175550178902107, 0.9341599059954147], 
             UndirectedEdge[175, 213] -> 
             RGBColor[
              0.25213492118930436`, 0.3823401668202513, 0.9376700828103168], 
             UndirectedEdge[174, 189] -> 
             RGBColor[
              0.3053198459534695, 0.4349817492014926, 0.9408182188837021], 
             UndirectedEdge[14, 127] -> 
             RGBColor[
              0.18967658911817914`, 0.3166924997265216, 0.9341131731976884], 
             UndirectedEdge[86, 95] -> 
             RGBColor[
              0.48521628550800544`, 0.5918110474144382, 0.9529344611319093], 
             UndirectedEdge[103, 200] -> 
             RGBColor[
              0.18928086975494526`, 0.31627657358570604`, 0.9340906375653665],
              UndirectedEdge[24, 112] -> 
             RGBColor[
              0.859560524438829, 0.3699751807909537, 0.20111045230987185`], 
             UndirectedEdge[109, 360] -> 
             RGBColor[
              0.18328589355082267`, 0.3099754734917281, 0.9337492325393142], 
             UndirectedEdge[90, 121] -> 
             RGBColor[
              0.4596424243656251, 0.5683306378036415, 0.9516722943059467], 
             UndirectedEdge[75, 202] -> 
             RGBColor[
              0.23066301686818202`, 0.3597718339813871, 0.9364472896240648], 
             UndirectedEdge[27, 32] -> 
             RGBColor[
              0.8663695731727464, 0.3973837278620414, 0.20771263676639312`], 
             UndirectedEdge[131, 273] -> 
             RGBColor[
              0.19754073794696791`, 0.32495821876141306`, 0.9345610248395222],
              UndirectedEdge[160, 220] -> 
             RGBColor[
              0.5477229997143326, 0.6437052316648666, 0.9575379073944208], 
             UndirectedEdge[50, 147] -> 
             RGBColor[
              0.18125622821196816`, 0.30784216653237684`, 0.9336336461008872],
              UndirectedEdge[13, 339] -> 
             RGBColor[
              0.2328552355524508, 0.3620759948132462, 0.936572133235037], 
             UndirectedEdge[17, 209] -> 
             RGBColor[
              0.2832594251473382, 0.412641193889955, 0.9395309216934591], 
             UndirectedEdge[174, 325] -> 
             RGBColor[
              0.31656779052141654`, 0.4468040521032807, 0.9414587726870038], 
             UndirectedEdge[21, 78] -> 
             RGBColor[
              0.8676924203602071, 0.39868109399445717`, 0.21499955316997305`],
              UndirectedEdge[274, 373] -> 
             RGBColor[
              0.38246482009015115`, 0.5012027656617852, 0.9460144921164949], 
             UndirectedEdge[97, 305] -> 
             RGBColor[
              0.18756138502713113`, 0.3144692861151448, 0.9339927154538672], 
             UndirectedEdge[11, 162] -> 
             RGBColor[
              0.29214677471105677`, 0.42409757281503596`, 0.9399595948655519],
              UndirectedEdge[103, 207] -> 
             RGBColor[
              0.19105231071262538`, 0.3181384703480716, 0.9341915185072943], 
             UndirectedEdge[210, 249] -> 
             RGBColor[
              0.3073650774594488, 0.4403600145758346, 0.9408164770263279], 
             UndirectedEdge[52, 299] -> 
             RGBColor[
              0.18351379325327066`, 0.3102150105286766, 0.9337622110902213], 
             UndirectedEdge[43, 373] -> 
             RGBColor[
              0.2661054797853324, 0.3970241096892522, 0.9384656854547713], 
             UndirectedEdge[1, 336] -> 
             RGBColor[
              0.18695004027347276`, 0.31382672401755374`, 0.9339579002745498],
              UndirectedEdge[30, 345] -> 
             RGBColor[
              0.1795989351746539, 0.30610024647171197`, 0.9335392657141575], 
             UndirectedEdge[247, 363] -> 
             RGBColor[
              0.20876443324933688`, 0.3367550341475864, 0.9352001976830229], 
             UndirectedEdge[14, 119] -> 
             RGBColor[
              0.18348249259608096`, 0.310182111553394, 0.9337604285640995], 
             UndirectedEdge[74, 104] -> 
             RGBColor[
              0.833692765834374, 0.39596024249218986`, 0.4394911865983113], 
             UndirectedEdge[258, 277] -> 
             RGBColor[
              0.19561158896014919`, 0.3229305608611562, 0.9344511626586431], 
             UndirectedEdge[152, 236] -> 
             RGBColor[
              0.2537723278978401, 0.38406118508850384`, 0.9377633307000419], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.26676233186552467`, 0.3975147794964234, 0.938510405060175], 
             UndirectedEdge[120, 132] -> 
             RGBColor[
              0.4382862950940797, 0.5522789014915227, 0.9496356996104882], 
             UndirectedEdge[212, 270] -> 
             RGBColor[
              0.38821783346100136`, 0.5106765077734281, 0.9459578749539519], 
             UndirectedEdge[69, 270] -> 
             RGBColor[
              0.300457761234542, 0.4284750339974831, 0.9405924577811364], 
             UndirectedEdge[16, 270] -> 
             RGBColor[
              0.3384373755940835, 0.46755917720766627`, 0.9427859081978025], 
             UndirectedEdge[24, 73] -> 
             RGBColor[
              0.8573963396759665, 0.36139490937802465`, 0.1993690984497273], 
             UndirectedEdge[56, 178] -> 
             RGBColor[
              0.4116703274319593, 0.5309898792944511, 0.9474522471315552], 
             UndirectedEdge[6, 319] -> 
             RGBColor[
              0.37947514539695637`, 0.5028109113563464, 0.945411816023644], 
             UndirectedEdge[231, 235] -> 
             RGBColor[
              0.18685346885052345`, 0.3137252213290522, 0.9339524006748775], 
             UndirectedEdge[18, 86] -> 
             RGBColor[
              0.5080814719938581, 0.6103740358685661, 0.9547344923700136], 
             UndirectedEdge[30, 63] -> 
             RGBColor[
              0.18069605079375822`, 0.30725338454853857`, 0.9336017448256284],
              UndirectedEdge[46, 358] -> 
             RGBColor[
              0.19603463800818394`, 0.3233752122334996, 0.9344752546760837], 
             UndirectedEdge[241, 389] -> 
             RGBColor[
              0.23293094482355622`, 0.362155570057423, 0.9365764447660246], 
             UndirectedEdge[286, 332] -> 
             RGBColor[
              0.2115950206250406, 0.3397301609490563, 0.9353613954465905], 
             UndirectedEdge[40, 174] -> 
             RGBColor[
              0.4325281900725898, 0.5472165595499049, 0.9492895101378381], 
             UndirectedEdge[157, 365] -> 
             RGBColor[
              0.18416233691758455`, 0.3108966710399138, 0.9337991446924696], 
             UndirectedEdge[235, 336] -> 
             RGBColor[
              0.18593363733157064`, 0.312758420081946, 0.9339000176306419], 
             UndirectedEdge[76, 222] -> 
             RGBColor[
              0.21314128516619657`, 0.3413553830206456, 0.9354494529247159], 
             UndirectedEdge[115, 392] -> 
             RGBColor[
              0.9067666664186966, 0.6489260404610371, 0.40496736674089506`], 
             UndirectedEdge[76, 77] -> 
             RGBColor[
              0.1883529029244576, 0.3153012216103682, 0.9340377912271741], 
             UndirectedEdge[160, 366] -> 
             RGBColor[
              0.4270114418839008, 0.5441063729670104, 0.948477074824805], 
             UndirectedEdge[3, 348] -> 
             RGBColor[
              0.45750426505624076`, 0.5671984745069012, 0.9513371690188597], 
             UndirectedEdge[299, 306] -> 
             RGBColor[
              0.19518727715711093`, 0.32248458225324084`, 0.9344269987291731],
              UndirectedEdge[56, 121] -> 
             RGBColor[
              0.3462782939569843, 0.4743505865975952, 0.9432855245824346], 
             UndirectedEdge[280, 322] -> 
             RGBColor[
              0.22572058379982396`, 0.354577023458187, 0.9361658253724963], 
             UndirectedEdge[81, 271] -> 
             RGBColor[
              0.1793288256722832, 0.3058163442587888, 0.9335238833775887], 
             UndirectedEdge[2, 191] -> 
             RGBColor[
              0.19610476461646903`, 0.323448919745091, 0.9344792482826825], 
             UndirectedEdge[146, 377] -> 
             RGBColor[
              0.18543930213235216`, 0.3122388424449055, 0.9338718659723498], 
             UndirectedEdge[10, 396] -> 
             RGBColor[
              0.21852942039278686`, 0.3470186547712968, 0.9357562992548385], 
             UndirectedEdge[382, 384] -> 
             RGBColor[
              0.18572468011707222`, 0.3125387928008556, 0.9338881178264007], 
             UndirectedEdge[147, 391] -> 
             RGBColor[
              0.18230154859335337`, 0.30894086453035285`, 0.9336931755501943],
              UndirectedEdge[133, 216] -> 
             RGBColor[
              0.19274891912622777`, 0.3199217133619542, 0.9342881378465417], 
             UndirectedEdge[86, 264] -> 
             RGBColor[
              0.5671571608223211, 0.6570945561668415, 0.9602327949234224], 
             UndirectedEdge[6, 56] -> 
             RGBColor[
              0.34361946259808085`, 0.47175570963568103`, 0.9431267952187714],
              UndirectedEdge[43, 308] -> 
             RGBColor[
              0.23093015114267265`, 0.3600526090411681, 0.9364625025258073], 
             UndirectedEdge[201, 364] -> 
             RGBColor[
              0.8614660017723598, 0.4117589473533967, 0.4334205555787529], 
             UndirectedEdge[109, 365] -> 
             RGBColor[
              0.1811265179483144, 0.30770583282117103`, 0.9336262592932614], 
             UndirectedEdge[229, 349] -> 
             RGBColor[
              0.20443433824615148`, 0.33220382975535845`, 0.934953605178393], 
             UndirectedEdge[216, 231] -> 
             RGBColor[
              0.19095180161373265`, 0.3180328289124904, 0.9341857946628023], 
             UndirectedEdge[114, 353] -> 
             RGBColor[
              0.2156557406567855, 0.3439982351669406, 0.9355926474451014], 
             UndirectedEdge[70, 236] -> 
             RGBColor[
              0.23684558512377027`, 0.36627010521547854`, 0.9367993777399305],
              UndirectedEdge[64, 94] -> 
             RGBColor[
              0.1809149928406964, 0.30748350652159806`, 0.9336142132513059], 
             UndirectedEdge[240, 285] -> 
             RGBColor[
              0.8858589617650177, 0.49305390399602456`, 0.3219788728271452], 
             UndirectedEdge[56, 90] -> 
             RGBColor[
              0.4950145385889495, 0.5989681852897308, 0.9539261741459244], 
             UndirectedEdge[90, 295] -> 
             RGBColor[
              0.5187067634857201, 0.6194891996894659, 0.9554358217661347], 
             UndirectedEdge[165, 281] -> 
             RGBColor[
              0.6627187385434833, 0.7331187175098175, 0.9692752800168635], 
             UndirectedEdge[54, 345] -> 
             RGBColor[
              0.1817997844893844, 0.30841347864339985`, 0.9336646008267666], 
             UndirectedEdge[101, 136] -> 
             RGBColor[
              0.18384486237801373`, 0.31056298516977654`, 0.9337810649871026],
              UndirectedEdge[6, 314] -> 
             RGBColor[
              0.26913140342587094`, 0.400204547290098, 0.9386380073296472], 
             UndirectedEdge[125, 276] -> 
             RGBColor[
              0.2421845103154749, 0.3718816540993685, 0.9371034216313661], 
             UndirectedEdge[244, 341] -> 
             RGBColor[
              0.6455002366075493, 0.7157181703634723, 0.9520500486891706], 
             UndirectedEdge[46, 153] -> 
             RGBColor[
              0.1918690303202028, 0.3189968944386494, 0.9342380294807175], 
             UndirectedEdge[14, 336] -> 
             RGBColor[
              0.18245115534282794`, 0.3090981107096664, 0.9337016954332534], 
             UndirectedEdge[109, 370] -> 
             RGBColor[
              0.1842051301196885, 0.31094164940857083`, 0.9338015817020224], 
             UndirectedEdge[51, 234] -> 
             RGBColor[
              0.5836503518814267, 0.668728614845342, 0.9624059730547245], 
             UndirectedEdge[144, 228] -> 
             RGBColor[
              0.19707272190642572`, 0.32446630422887235`, 0.934534372018381], 
             UndirectedEdge[320, 347] -> 
             RGBColor[
              0.1968219545840863, 0.324202731873527, 0.9345200911903508], 
             UndirectedEdge[31, 106] -> 
             RGBColor[
              0.21164758701888683`, 0.33978541156189057`, 0.935364389024955], 
             UndirectedEdge[77, 103] -> 
             RGBColor[
              0.18857832587467818`, 0.31553815542369057`, 0.9340506287307058],
              UndirectedEdge[266, 316] -> 
             RGBColor[
              0.23355306875092818`, 0.36280946175002615`, 0.9366118738033387],
              UndirectedEdge[109, 334] -> 
             RGBColor[
              0.18315174728548578`, 0.30983447726149455`, 0.9337415931079549],
              UndirectedEdge[45, 179] -> 
             RGBColor[
              0.3693787364367489, 0.49212881841734446`, 0.9448432238628737], 
             UndirectedEdge[181, 191] -> 
             RGBColor[
              0.2010737277844803, 0.3286716150851321, 0.9347622233841785], 
             UndirectedEdge[125, 148] -> 
             RGBColor[
              0.2977450564931756, 0.4279464199660071, 0.9403529311058223], 
             UndirectedEdge[18, 112] -> 
             RGBColor[
              0.7711240798821252, 0.7393399357057666, 0.6151558638126768], 
             UndirectedEdge[221, 239] -> 
             RGBColor[
              0.8526114029177259, 0.35936467056963683`, 0.1962114217734859], 
             UndirectedEdge[57, 76] -> 
             RGBColor[
              0.20578868678679324`, 0.33362733594223004`, 0.9350307333242034],
              UndirectedEdge[222, 333] -> 
             RGBColor[
              0.21024933242430197`, 0.33831575732852015`, 0.9352847604943257],
              UndirectedEdge[125, 214] -> 
             RGBColor[
              0.25062847588100123`, 0.38075679728707557`, 0.9375842929785951],
              UndirectedEdge[220, 244] -> 
             RGBColor[
              0.7952939705328516, 0.8405065482820335, 0.9629639718031929], 
             UndirectedEdge[143, 379] -> 
             RGBColor[
              0.19607245739300067`, 0.3234149628048294, 0.9344774084341002], 
             UndirectedEdge[31, 241] -> 
             RGBColor[
              0.22984485211178313`, 0.3589118909477702, 0.9364006963515542], 
             UndirectedEdge[81, 374] -> 
             RGBColor[
              0.1848884604275577, 0.3116598728877852, 0.9338404963521592], 
             UndirectedEdge[168, 304] -> 
             RGBColor[
              0.18254777981600245`, 0.3091996691573183, 0.9337071980540577], 
             UndirectedEdge[156, 328] -> 
             RGBColor[
              0.8438341634867396, 0.32626817313654033`, 0.18915213949243842`],
              UndirectedEdge[46, 363] -> 
             RGBColor[
              0.21059715829347625`, 0.33868134437045616`, 0.9353045686630128],
              UndirectedEdge[51, 269] -> 
             RGBColor[
              0.5625797337470475, 0.652268087816136, 0.9603058507552114], 
             UndirectedEdge[13, 325] -> 
             RGBColor[
              0.25165090865355244`, 0.3818314389570088, 0.9376425190124382], 
             UndirectedEdge[164, 374] -> 
             RGBColor[
              0.1955858495365969, 0.322903507095029, 0.9344496968365499], 
             UndirectedEdge[49, 199] -> 
             RGBColor[
              0.18708382947160418`, 0.313967344947515, 0.93396551937146], 
             UndirectedEdge[49, 313] -> 
             RGBColor[
              0.20302253470198556`, 0.3307199347169253, 0.9348732050551289], 
             UndirectedEdge[176, 388] -> 
             RGBColor[
              0.22659156217478169`, 0.35549247695348607`, 0.9362154263024531],
              UndirectedEdge[45, 232] -> 
             RGBColor[
              0.28995111396047296`, 0.4220873831078549, 0.9398236590445912], 
             UndirectedEdge[176, 250] -> 
             RGBColor[
              0.24600820440775967`, 0.3759005990265677, 0.9373211753532731], 
             UndirectedEdge[346, 390] -> 
             RGBColor[
              0.30688867117659013`, 0.43597701754892004`, 0.9409314950894052],
              UndirectedEdge[331, 335] -> 
             RGBColor[
              0.18932527309814626`, 0.31632324431474484`, 0.9340931662700729],
              UndirectedEdge[135, 355] -> 
             RGBColor[
              0.8802746969932166, 0.9041359691009224, 0.8286360157619015], 
             UndirectedEdge[326, 327] -> 
             RGBColor[
              0.19380937140054372`, 0.3210363159388178, 0.9343485290347655], 
             UndirectedEdge[80, 304] -> 
             RGBColor[
              0.18034926344630414`, 0.30688888905877654`, 0.9335819957992169],
              UndirectedEdge[65, 173] -> 
             RGBColor[
              0.2852130264023293, 0.4171073526721437, 0.9395538319675272], 
             UndirectedEdge[203, 257] -> 
             RGBColor[
              0.27443071882287484`, 0.40444693199068393`, 0.9389884029433275],
              UndirectedEdge[275, 325] -> 
             RGBColor[
              0.2639447266446291, 0.3947530211387112, 0.9383426337599561], 
             UndirectedEdge[240, 337] -> 
             RGBColor[
              0.8858082221333453, 0.4929453770544411, 0.3164561770483195], 
             UndirectedEdge[77, 254] -> 
             RGBColor[
              0.18502833391359902`, 0.3118068887901059, 0.9338484619402648], 
             UndirectedEdge[32, 364] -> 
             RGBColor[
              0.8641288289294724, 0.38016038570784827`, 0.2055668975484752], 
             UndirectedEdge[38, 53] -> 
             RGBColor[
              0.2076634431002256, 0.3355978236940631, 0.9351374979228], 
             UndirectedEdge[28, 291] -> 
             RGBColor[
              0.1970819328198578, 0.3244759854828951, 0.9345348965662746], 
             UndirectedEdge[174, 269] -> 
             RGBColor[
              0.543788980551822, 0.6359924818491485, 0.9591085205776222], 
             UndirectedEdge[216, 361] -> 
             RGBColor[
              0.20867332138388106`, 0.3366592698001664, 0.9351950089970731], 
             UndirectedEdge[356, 363] -> 
             RGBColor[
              0.2074463229173425, 0.3353696166156383, 0.9351251332495853], 
             UndirectedEdge[151, 383] -> 
             RGBColor[
              0.20018660218381945`, 0.3277391898318258, 0.9347117028936056], 
             UndirectedEdge[61, 130] -> 
             RGBColor[
              0.19568837198846437`, 0.3230112646922406, 0.9344555353385153], 
             UndirectedEdge[331, 338] -> 
             RGBColor[
              0.2166739251358942, 0.34506841161110846`, 0.9356506315449178], 
             UndirectedEdge[239, 246] -> 
             RGBColor[
              0.8585903956264433, 0.4560165722989594, 0.4468977431895056], 
             UndirectedEdge[190, 212] -> 
             RGBColor[
              0.6867778683351773, 0.7513832913392242, 0.9534033725466657], 
             UndirectedEdge[111, 286] -> 
             RGBColor[
              0.1920478961746871, 0.3191848937924626, 0.934248215626522], 
             UndirectedEdge[228, 273] -> 
             RGBColor[
              0.1927101706170558, 0.31988098622201705`, 0.9342859311762677], 
             UndirectedEdge[199, 299] -> 
             RGBColor[
              0.18707599573729403`, 0.31395911119606756`, 0.93396507325188], 
             UndirectedEdge[50, 391] -> 
             RGBColor[
              0.18008156514952903`, 0.3066075211758136, 0.9335667507772396], 
             UndirectedEdge[358, 362] -> 
             RGBColor[
              0.18997045450082056`, 0.31700137087581914`, 0.9341299083964949],
              UndirectedEdge[42, 98] -> 
             RGBColor[
              0.20876468464708048`, 0.33675529838255447`, 0.9352002119997525],
              UndirectedEdge[39, 251] -> 
             RGBColor[
              0.18672478342346222`, 0.3135899647860835, 0.9339450722301794], 
             UndirectedEdge[148, 179] -> 
             RGBColor[
              0.39396314610535543`, 0.515635700812435, 0.9463286881882242], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.19127206346984504`, 0.31836944442903903`, 0.934204033101723], 
             UndirectedEdge[77, 333] -> 
             RGBColor[
              0.18546095018256298`, 0.31226159591824276`, 0.9338730987967839],
              UndirectedEdge[173, 354] -> 
             RGBColor[
              0.24916626557073213`, 0.3792199215414943, 0.9375010222645717], 
             UndirectedEdge[160, 217] -> 
             RGBColor[
              0.7263465347719837, 0.7798834744139984, 0.7188240157462833], 
             UndirectedEdge[59, 90] -> 
             RGBColor[
              0.47744540309430256`, 0.5837506831746934, 0.9528066843679821], 
             UndirectedEdge[237, 380] -> 
             RGBColor[
              0.20872851353399335`, 0.33671728024931885`, 0.9351981521083725],
              UndirectedEdge[285, 399] -> 
             RGBColor[
              0.9603875503566552, 0.868303119703074, 0.4348794443842956], 
             UndirectedEdge[51, 392] -> 
             RGBColor[
              0.6863309387769014, 0.7477531849917098, 0.8714804732443268], 
             UndirectedEdge[264, 307] -> 
             RGBColor[
              0.5358230864206805, 0.6299545558165122, 0.958236215410184], 
             UndirectedEdge[78, 208] -> 
             RGBColor[
              0.8776301441970267, 0.43329624520536353`, 0.36628986629008864`],
              UndirectedEdge[28, 383] -> 
             RGBColor[
              0.20767130167756592`, 0.3356060835571104, 0.9351379454571538], 
             UndirectedEdge[255, 268] -> 
             RGBColor[
              0.78336189520592, 0.43168674764690385`, 0.44388901313282986`], 
             UndirectedEdge[46, 247] -> 
             RGBColor[
              0.1994607168120997, 0.32697623828235756`, 0.9346703647955372], 
             UndirectedEdge[272, 392] -> 
             RGBColor[
              0.8660085977148573, 0.8940614807970035, 0.8861195606683994], 
             UndirectedEdge[316, 359] -> 
             RGBColor[
              0.21077886401933704`, 0.3388723286091443, 0.9353149165352912], 
             UndirectedEdge[223, 242] -> 
             RGBColor[
              0.8781496673360434, 0.5217988288073361, 0.2192788746878494], 
             UndirectedEdge[158, 390] -> 
             RGBColor[
              0.3007335296132649, 0.43064574329317795`, 0.9405392949117681], 
             UndirectedEdge[26, 128] -> 
             RGBColor[
              0.19080558249119994`, 0.3178791433438807, 0.9341774677000858], 
             UndirectedEdge[136, 335] -> 
             RGBColor[
              0.18204623503960604`, 0.3086725137975501, 0.9336786358210108], 
             UndirectedEdge[193, 248] -> 
             RGBColor[
              0.20247189401375032`, 0.330141176440954, 0.9348418468825339], 
             UndirectedEdge[281, 386] -> 
             RGBColor[
              0.5947242732295994, 0.6793804571151425, 0.9626628801063983], 
             UndirectedEdge[225, 337] -> 
             RGBColor[
              0.9393785469822551, 0.9502915240338172, 0.7911384355526612], 
             UndirectedEdge[30, 297] -> 
             RGBColor[
              0.19356559882175525`, 0.3207800955024369, 0.9343346465470327], 
             UndirectedEdge[32, 104] -> 
             RGBColor[
              0.8650168308266121, 0.38698595741417663`, 0.2064172491680309], 
             UndirectedEdge[264, 366] -> 
             RGBColor[
              0.5588455342770764, 0.6498954430078475, 0.9597031854296422], 
             UndirectedEdge[2, 97] -> 
             RGBColor[
              0.18893766617089083`, 0.31591584485850077`, 0.9340710926289788],
              UndirectedEdge[258, 377] -> 
             RGBColor[
              0.18407204095648846`, 0.3108017642597073, 0.933794002471066], 
             UndirectedEdge[134, 135] -> 
             RGBColor[
              0.9129052217970873, 0.9297159641585085, 0.8318647617559947], 
             UndirectedEdge[185, 338] -> 
             RGBColor[
              0.3169003211264983, 0.4420126040845884, 0.9416659454971446], 
             UndirectedEdge[40, 84] -> 
             RGBColor[
              0.42994887224450423`, 0.5449824840875006, 0.9491251582866337], 
             UndirectedEdge[217, 242] -> 
             RGBColor[
              0.8992054802509515, 0.5977296497457392, 0.29414214565418556`], 
             UndirectedEdge[124, 266] -> 
             RGBColor[
              0.27124098687969256`, 0.402330909521441, 0.9387614748820916], 
             UndirectedEdge[219, 293] -> 
             RGBColor[
              0.34300984476630975`, 0.47151962018566573`, 0.943077261890181], 
             UndirectedEdge[37, 170] -> 
             RGBColor[
              0.29023151793817503`, 0.41867896684859873`, 0.9399752176813956],
              UndirectedEdge[205, 293] -> 
             RGBColor[
              0.3494560104043527, 0.47710296486763304`, 0.9434880058645166], 
             UndirectedEdge[122, 268] -> 
             RGBColor[
              0.638662857560744, 0.7169674525945936, 0.9650845862531987], 
             UndirectedEdge[246, 392] -> 
             RGBColor[
              0.955664633870156, 0.964911832854005, 0.8948405878073766], 
             UndirectedEdge[282, 398] -> 
             RGBColor[
              0.3466184248527956, 0.47079867288483046`, 0.9434480372889362], 
             UndirectedEdge[34, 248] -> 
             RGBColor[
              0.24062348998029212`, 0.37024092275268566`, 0.9370145238326], 
             UndirectedEdge[263, 264] -> 
             RGBColor[
              0.5576221544304325, 0.6488358128735436, 0.9596252327476064], 
             UndirectedEdge[100, 377] -> 
             RGBColor[
              0.19744186238260558`, 0.3248542942741953, 0.9345553940224051], 
             UndirectedEdge[107, 241] -> 
             RGBColor[
              0.30591595912176667`, 0.43518094579116473`, 0.9408678142487259],
              UndirectedEdge[11, 95] -> 
             RGBColor[
              0.43568729767870357`, 0.5489115275560077, 0.9497785178241904], 
             UndirectedEdge[7, 96] -> 
             RGBColor[
              0.5984222253415448, 0.6831169372542267, 0.9626727079088397], 
             UndirectedEdge[111, 383] -> 
             RGBColor[
              0.1988021595169091, 0.3262840528101681, 0.9346328609318244], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.2782593236768137, 0.4070163756656283, 0.939259698655848], 
             UndirectedEdge[121, 122] -> 
             RGBColor[
              0.4544345003462795, 0.5641026104704333, 0.9512623074498896], 
             UndirectedEdge[156, 221] -> 
             RGBColor[
              0.8547600367756315, 0.37588001193886017`, 0.19826895598235128`],
              UndirectedEdge[61, 176] -> 
             RGBColor[
              0.2215167477526256, 0.3501585252339816, 0.9359264231286265], 
             UndirectedEdge[128, 261] -> 
             RGBColor[
              0.22729090761283746`, 0.3562275333499445, 0.9362552529905616], 
             UndirectedEdge[69, 381] -> 
             RGBColor[
              0.21898984745913425`, 0.34750259281079, 0.9357825198951262], 
             UndirectedEdge[166, 178] -> 
             RGBColor[
              0.7156925694809679, 0.7734991059400932, 0.884905461880064], 
             UndirectedEdge[114, 202] -> 
             RGBColor[
              0.2423249813764799, 0.37202929809086444`, 0.937111421250482], 
             UndirectedEdge[40, 134] -> 
             RGBColor[
              0.6760140538149009, 0.745057217744171, 0.9695892868351288], 
             UndirectedEdge[84, 234] -> 
             RGBColor[
              0.5622802808581155, 0.6502189334159502, 0.961044291025931], 
             UndirectedEdge[236, 367] -> 
             RGBColor[
              0.3129287562528536, 0.440105110895209, 0.9413567694167602], 
             UndirectedEdge[307, 366] -> 
             RGBColor[
              0.37137695467694465`, 0.4960897850178574, 0.9448847890496364], 
             UndirectedEdge[129, 396] -> 
             RGBColor[
              0.19432308879693078`, 0.32157626549398477`, 0.934377784480513], 
             UndirectedEdge[67, 208] -> 
             RGBColor[
              0.7091189037719949, 0.7670538844748609, 0.8568671364687419], 
             UndirectedEdge[203, 309] -> 
             RGBColor[
              0.2616767930351678, 0.3923692791198713, 0.9382134782960043], 
             UndirectedEdge[142, 302] -> 
             RGBColor[
              0.18693197467623224`, 0.31380773592942895`, 0.9339568714655127],
              UndirectedEdge[93, 248] -> 
             RGBColor[
              0.22615954726936105`, 0.355038401896562, 0.9361908236926982], 
             UndirectedEdge[110, 227] -> 
             RGBColor[
              0.1954518354139104, 0.3227626497550994, 0.934442064930519], 
             UndirectedEdge[129, 361] -> 
             RGBColor[
              0.20336215554475928`, 0.33107689775588556`, 0.9348925459597008],
              UndirectedEdge[236, 332] -> 
             RGBColor[
              0.2395600162179548, 0.36912314440033817`, 0.9369539605751034], 
             UndirectedEdge[306, 353] -> 
             RGBColor[
              0.19636662006403216`, 0.3237241464230741, 0.9344941605630408], 
             UndirectedEdge[257, 280] -> 
             RGBColor[
              0.2873202290991691, 0.41799462453322234`, 0.9397224414852408], 
             UndirectedEdge[208, 385] -> 
             RGBColor[
              0.9937202968318795, 0.9909321476846529, 0.7000134809555262], 
             UndirectedEdge[79, 302] -> 
             RGBColor[
              0.21120952198211004`, 0.3393249774333106, 0.9353394418691697], 
             UndirectedEdge[21, 242] -> 
             RGBColor[
              0.8892496521392507, 0.5643794238873858, 0.23564278266699612`], 
             UndirectedEdge[94, 103] -> 
             RGBColor[
              0.18776701535974932`, 0.31468541663244265`, 0.934004425797107], 
             UndirectedEdge[237, 308] -> 
             RGBColor[
              0.19941664213352878`, 0.3269299130006835, 0.9346678548077954], 
             UndirectedEdge[1, 235] -> 
             RGBColor[
              0.19253038583618232`, 0.3196920210183055, 0.9342756926989647], 
             UndirectedEdge[31, 374] -> 
             RGBColor[
              0.1933477765192394, 0.32055115045176114`, 0.9343222418891437], 
             UndirectedEdge[324, 351] -> 
             RGBColor[
              0.7714595274314936, 0.8219737948771062, 0.9777595758801894], 
             UndirectedEdge[62, 396] -> 
             RGBColor[
              0.20033182917246628`, 0.3278918326048165, 0.934719973355765], 
             UndirectedEdge[13, 123] -> 
             RGBColor[
              0.2129302625842361, 0.3411335849074007, 0.9354374355008532], 
             UndirectedEdge[112, 337] -> 
             RGBColor[
              0.9655773454319732, 0.8890178859650467, 0.43083247110178885`], 
             UndirectedEdge[262, 286] -> 
             RGBColor[
              0.20449842182687056`, 0.3322711856618279, 0.9349572546435119], 
             UndirectedEdge[56, 59] -> 
             RGBColor[
              0.3640812726856617, 0.4897706319686471, 0.9444199146444701], 
             UndirectedEdge[61, 118] -> 
             RGBColor[
              0.22412293343441853`, 0.3528977916272621, 0.9360748415476985], 
             UndirectedEdge[14, 235] -> 
             RGBColor[
              0.1880315009055375, 0.3149634077104182, 0.9340194878576683], 
             UndirectedEdge[154, 286] -> 
             RGBColor[
              0.2001789472954632, 0.3277311440588154, 0.9347112669590381], 
             UndirectedEdge[159, 215] -> 
             RGBColor[
              0.1817543271405076, 0.3083657000875679, 0.9336620120979963], 
             UndirectedEdge[25, 385] -> 
             RGBColor[
              0.8763544393929654, 0.4195795480694926, 0.3210148235334077], 
             UndirectedEdge[165, 256] -> 
             RGBColor[
              0.624029163944416, 0.6996077525866663, 0.9668100145352584], 
             UndirectedEdge[292, 384] -> 
             RGBColor[
              0.19197167888601352`, 0.3191047845896115, 0.9342438751646855], 
             UndirectedEdge[1, 49] -> 
             RGBColor[
              0.19061232216343427`, 0.3176760144859865, 0.9341664618103227], 
             UndirectedEdge[93, 125] -> 
             RGBColor[
              0.24791606512635506`, 0.37790588160716765`, 0.9374298251987702],
              UndirectedEdge[15, 37] -> 
             RGBColor[
              0.31731211488685307`, 0.44714239125067556`, 0.9415174176154697],
              UndirectedEdge[141, 399] -> 
             RGBColor[
              0.8859237106076299, 0.5705962751965173, 0.2263022782483616], 
             UndirectedEdge[42, 288] -> 
             RGBColor[
              0.26094257460696524`, 0.39159756899969334`, 0.938171665642697], 
             UndirectedEdge[26, 218] -> 
             RGBColor[
              0.188929981383257, 0.31590776765945394`, 0.9340706549916917], 
             UndirectedEdge[292, 389] -> 
             RGBColor[
              0.1985170723266464, 0.32598440809763013`, 0.9346166256380877], 
             UndirectedEdge[87, 361] -> 
             RGBColor[
              0.20790747959893147`, 0.33585432152701067`, 0.9351513954403816],
              UndirectedEdge[3, 11] -> 
             RGBColor[
              0.4469167817161049, 0.5580281285800609, 0.9506625439425702], 
             UndirectedEdge[217, 364] -> 
             RGBColor[
              0.8761412762683021, 0.4204480711364659, 0.27205583787310783`], 
             UndirectedEdge[83, 120] -> 
             RGBColor[
              0.7316668327109251, 0.7891725193318362, 0.9665740024152043], 
             UndirectedEdge[251, 380] -> 
             RGBColor[
              0.20519908617390886`, 0.3330076283152506, 0.9349971564415356], 
             UndirectedEdge[209, 390] -> 
             RGBColor[
              0.2987767120225358, 0.42895084624860025`, 0.9404146082252327], 
             UndirectedEdge[149, 315] -> 
             RGBColor[
              0.21772472600366666`, 0.3461728699477604, 0.9357104730998167], 
             UndirectedEdge[34, 263] -> 
             RGBColor[
              0.3276003815122878, 0.45396612776116196`, 0.9422494083788064], 
             UndirectedEdge[327, 376] -> 
             RGBColor[
              0.2026044968471712, 0.33028055042638454`, 0.9348493984177288], 
             UndirectedEdge[113, 316] -> 
             RGBColor[
              0.2709397029977173, 0.40210518479292345`, 0.9387409873151243], 
             UndirectedEdge[85, 307] -> 
             RGBColor[
              0.294549891018896, 0.4232589122924366, 0.9402196391759287], 
             UndirectedEdge[140, 257] -> 
             RGBColor[
              0.2744017745717613, 0.404416509747592, 0.9389867546110457], 
             UndirectedEdge[228, 330] -> 
             RGBColor[
              0.1947627843493959, 0.3220384133979338, 0.9344028244917546], 
             UndirectedEdge[22, 96] -> 
             RGBColor[
              0.5322372446835262, 0.6257908335621027, 0.9584554594663912], 
             UndirectedEdge[22, 323] -> 
             RGBColor[
              0.35748321527472365`, 0.48405572626730053`, 0.943999492260678], 
             UndirectedEdge[167, 269] -> 
             RGBColor[
              0.5269179419290838, 0.6213796361571894, 0.958033512915055], 
             UndirectedEdge[85, 214] -> 
             RGBColor[
              0.2402451657445982, 0.3698432799938294, 0.9369929788270578], 
             UndirectedEdge[89, 155] -> 
             RGBColor[
              0.19816316122321598`, 0.3256124250886648, 0.9345964709243118], 
             UndirectedEdge[1, 396] -> 
             RGBColor[
              0.1965523248147455, 0.3239193338904351, 0.9345047361738683], 
             UndirectedEdge[172, 208] -> 
             RGBColor[
              0.8802072426240743, 0.4531049530073836, 0.36875769865424585`], 
             UndirectedEdge[45, 339] -> 
             RGBColor[
              0.26817858765203434`, 0.39920307749978645`, 0.9385837458808918],
              UndirectedEdge[250, 363] -> 
             RGBColor[
              0.2391241828797345, 0.3686650559284389, 0.9369291405112493], 
             UndirectedEdge[167, 222] -> 
             RGBColor[
              0.2713202012615644, 0.4023656525144891, 0.9387677624449977], 
             UndirectedEdge[73, 208] -> 
             RGBColor[
              0.9618152962983195, 0.8769997675618114, 0.5142240753361885], 
             UndirectedEdge[14, 317] -> 
             RGBColor[
              0.18995153056345765`, 0.3169814806178038, 0.9341288307062575], 
             UndirectedEdge[157, 334] -> 
             RGBColor[
              0.1861875662547559, 0.3130253154802374, 0.9339144785071631], 
             UndirectedEdge[107, 190] -> 
             RGBColor[
              0.6524189980541504, 0.7216233648288316, 0.9512140557147148], 
             UndirectedEdge[12, 209] -> 
             RGBColor[
              0.3216593094784126, 0.45300190701520204`, 0.9417177382985756], 
             UndirectedEdge[185, 219] -> 
             RGBColor[
              0.36836286362019555`, 0.4934791308371227, 0.9446927338327562], 
             UndirectedEdge[318, 345] -> 
             RGBColor[
              0.18668882027855277`, 0.3135521652405886, 0.9339430241822795], 
             UndirectedEdge[36, 383] -> 
             RGBColor[
              0.20061589185273376`, 0.3281904004923918, 0.9347361503051731], 
             UndirectedEdge[24, 357] -> 
             RGBColor[
              0.832891397044611, 0.253823267552776, 0.17913014499642635`], 
             UndirectedEdge[344, 354] -> 
             RGBColor[
              0.2035510812828702, 0.3312754706852238, 0.9349033050009957], 
             UndirectedEdge[7, 194] -> 
             RGBColor[
              0.7215884971461117, 0.7768639400824314, 0.7979961077324451], 
             UndirectedEdge[97, 248] -> 
             RGBColor[
              0.2054442201466507, 0.3332652796629938, 0.9350111164586401], 
             UndirectedEdge[14, 129] -> 
             RGBColor[
              0.18681866782962492`, 0.3136886432495756, 0.9339504188082208], 
             UndirectedEdge[160, 307] -> 
             RGBColor[
              0.403988994027505, 0.524165485775675, 0.9470101048053469], 
             UndirectedEdge[165, 400] -> 
             RGBColor[
              0.8657021685054997, 0.5646354990336626, 0.4604608392782479], 
             UndirectedEdge[310, 323] -> 
             RGBColor[
              0.33914507736848765`, 0.46547732189212476`, 0.9429296732937578],
              UndirectedEdge[309, 339] -> 
             RGBColor[
              0.27457216058382816`, 0.4059231280270391, 0.9389478504009139], 
             UndirectedEdge[355, 395] -> 
             RGBColor[
              0.6171730285902994, 0.6981983576754478, 0.9642971542356892], 
             UndirectedEdge[32, 240] -> 
             RGBColor[
              0.8734700310764903, 0.45196095875070935`, 0.21451204327383844`],
              UndirectedEdge[66, 322] -> 
             RGBColor[
              0.2070879506142999, 0.33499294460302415`, 0.9351047244770914], 
             UndirectedEdge[28, 267] -> 
             RGBColor[
              0.23148773999796957`, 0.36063867028126045`, 0.9364942563862377],
              UndirectedEdge[51, 102] -> 
             RGBColor[
              0.32952467941339164`, 0.45694789679919157`, 0.9423238729229517],
              UndirectedEdge[244, 321] -> 
             RGBColor[
              0.7545634824664897, 0.8074397031821838, 0.959757518581915], 
             UndirectedEdge[140, 309] -> 
             RGBColor[
              0.2616478487840542, 0.3923388568767794, 0.9382118299637227], 
             UndirectedEdge[12, 324] -> 
             RGBColor[
              0.4708028735942141, 0.577300258720949, 0.9525700303913813], 
             UndirectedEdge[130, 287] -> 
             RGBColor[
              0.1859722872961475, 0.31279904364526556`, 0.9339022186889471], 
             UndirectedEdge[267, 367] -> 
             RGBColor[
              0.315534462322565, 0.44284387318578267`, 0.9415051605226336], 
             UndirectedEdge[138, 229] -> 
             RGBColor[
              0.19456770903936127`, 0.32183337687859837`, 0.9343917152414362],
              UndirectedEdge[97, 193] -> 
             RGBColor[
              0.1899172543843397, 0.31694545418031556`, 0.9341268787285638], 
             UndirectedEdge[248, 340] -> 
             RGBColor[
              0.2104667967928659, 0.33854432616791813`, 0.9352971447684058], 
             UndirectedEdge[162, 248] -> 
             RGBColor[
              0.24516386461647438`, 0.3750131443716921, 0.9372730914512483], 
             UndirectedEdge[127, 317] -> 
             RGBColor[
              0.19507910076484197`, 0.32237088200618674`, 0.9344208382436661],
              UndirectedEdge[269, 355] -> 
             RGBColor[
              0.7546443194902623, 0.8082531449858283, 0.9761795512808198], 
             UndirectedEdge[161, 184] -> 
             RGBColor[
              0.19128276610466352`, 0.31838069357681953`, 0.9342046426009427],
              UndirectedEdge[340, 360] -> 
             RGBColor[
              0.1940919893072422, 0.3213333652777681, 0.9343646237064562], 
             UndirectedEdge[19, 185] -> 
             RGBColor[
              0.330002266441723, 0.4557835793222022, 0.9424120819002554], 
             UndirectedEdge[240, 357] -> 
             RGBColor[
              0.8401594453847212, 0.3096886719739536, 0.1860900362950024], 
             UndirectedEdge[75, 132] -> 
             RGBColor[
              0.28812004710636396`, 0.4155836677571048, 0.9398870475355221], 
             UndirectedEdge[89, 353] -> 
             RGBColor[
              0.18963294311823536`, 0.31664662501326446`, 0.93411068762256], 
             UndirectedEdge[214, 312] -> 
             RGBColor[
              0.2713270321361526, 0.4025122922755047, 0.9387630451365561], 
             UndirectedEdge[119, 129] -> 
             RGBColor[
              0.18575214150891103`, 0.312567656464831, 0.9338896817120405], 
             UndirectedEdge[143, 377] -> 
             RGBColor[
              0.1848896476706373, 0.3116611207555374, 0.933840563963896], 
             UndirectedEdge[5, 122] -> 
             RGBColor[
              0.440201175363544, 0.5493422068445898, 0.9504444277972779], 
             UndirectedEdge[42, 318] -> 
             RGBColor[
              0.2054522043558168, 0.33327367157305554`, 0.9350115711475404], 
             UndirectedEdge[6, 137] -> 
             RGBColor[
              0.32002599977803325`, 0.451320237982877, 0.941623440630758], 
             UndirectedEdge[113, 149] -> 
             RGBColor[
              0.26206453775242544`, 0.39277682340214404`, 0.9382355597840353],
              UndirectedEdge[67, 124] -> 
             RGBColor[
              0.3674760832994186, 0.49271104629414053`, 0.9446362289748654], 
             UndirectedEdge[141, 337] -> 
             RGBColor[
              0.9084139629772536, 0.6516194381550591, 0.33751282527872106`], 
             UndirectedEdge[63, 224] -> 
             RGBColor[
              0.1802578853175729, 0.30679284485177194`, 0.9335767919499673], 
             UndirectedEdge[244, 357] -> 
             RGBColor[
              0.8896554671023064, 0.6151982079777534, 0.4553600391337833], 
             UndirectedEdge[9, 192] -> 
             RGBColor[
              0.1863278971063823, 0.3131728121027866, 0.9339224701415624], 
             UndirectedEdge[46, 369] -> 
             RGBColor[
              0.19594555683555187`, 0.3232815822729907, 0.934470181635086], 
             UndirectedEdge[350, 392] -> 
             RGBColor[
              0.9924671913475096, 0.9911530042849124, 0.7745016638630496], 
             UndirectedEdge[275, 339] -> 
             RGBColor[
              0.24514905354352745`, 0.3749975769949486, 0.9372722479825549], 
             UndirectedEdge[119, 127] -> 
             RGBColor[
              0.18861006279746526`, 0.31557151294177693`, 0.9340524361015079],
              UndirectedEdge[152, 398] -> 
             RGBColor[
              0.3414317727237982, 0.4653471726445155, 0.943152665123154], 
             UndirectedEdge[105, 229] -> 
             RGBColor[
              0.20817939443044792`, 0.33614012125533055`, 0.9351668805877746],
              UndirectedEdge[181, 365] -> 
             RGBColor[
              0.1879270858801807, 0.3148536608984732, 0.9340135415764423], 
             UndirectedEdge[24, 285] -> 
             RGBColor[
              0.8785909134249075, 0.43718849957484696`, 0.31501898152856916`],
              UndirectedEdge[167, 189] -> 
             RGBColor[
              0.2884488073307313, 0.4203689035095335, 0.9397432112211349], 
             UndirectedEdge[157, 191] -> 
             RGBColor[
              0.1973089788218841, 0.3247146252265727, 0.9345478265002056], 
             UndirectedEdge[78, 194] -> 
             RGBColor[
              0.8781356082516507, 0.43307373314204806`, 0.32654502054624035`],
              UndirectedEdge[107, 268] -> 
             RGBColor[
              0.5139907876886572, 0.6129102178843966, 0.9560554271690249], 
             UndirectedEdge[5, 274] -> 
             RGBColor[
              0.38775900825169696`, 0.5067672930904867, 0.9463159883002454], 
             UndirectedEdge[12, 118] -> 
             RGBColor[
              0.27367870261090094`, 0.4049840470489852, 0.9388969692911083], 
             UndirectedEdge[20, 291] -> 
             RGBColor[
              0.18873168488737596`, 0.31569934546955897`, 0.9340593622996046],
              UndirectedEdge[6, 379] -> 
             RGBColor[
              0.25634517615934155`, 0.38676541173934353`, 0.9379098506023464],
              UndirectedEdge[97, 181] -> 
             RGBColor[
              0.19390662933890207`, 0.32113854019854193`, 0.9343540677304747],
              UndirectedEdge[39, 320] -> 
             RGBColor[
              0.18948414481075992`, 0.3164902285577502, 0.9341022137790767], 
             UndirectedEdge[202, 218] -> 
             RGBColor[
              0.2171099632633392, 0.3455267153294672, 0.9356754632712151], 
             UndirectedEdge[61, 344] -> 
             RGBColor[
              0.20030701799861927`, 0.32786575448798405`, 0.9347185603961192],
              UndirectedEdge[181, 214] -> 
             RGBColor[
              0.21733436721625865`, 0.34576257811201794`, 0.9356882427443579],
              UndirectedEdge[274, 324] -> 
             RGBColor[
              0.5631040589260905, 0.6561922684417929, 0.9587487607182468], 
             UndirectedEdge[62, 231] -> 
             RGBColor[
              0.19164937615014635`, 0.31876602397904136`, 0.934225520500682], 
             UndirectedEdge[117, 289] -> 
             RGBColor[
              0.20615434433043495`, 0.33401166520462483`, 0.935051556980372], 
             UndirectedEdge[14, 396] -> 
             RGBColor[
              0.19205343988410067`, 0.31919072058254777`, 0.9342485313325719],
              UndirectedEdge[79, 175] -> 
             RGBColor[
              0.2563476435480917, 0.3867680051213614, 0.9379099911164857], 
             UndirectedEdge[246, 395] -> 
             RGBColor[
              0.6944421379403393, 0.7593719483680503, 0.9717835682731306], 
             UndirectedEdge[87, 396] -> 
             RGBColor[
              0.198868412851103, 0.3263536892651099, 0.9346366339611938], 
             UndirectedEdge[341, 366] -> 
             RGBColor[
              0.36531722643847, 0.49084115298848774`, 0.9444986685246879], 
             UndirectedEdge[40, 226] -> 
             RGBColor[
              0.48315013418370223`, 0.5910627432060597, 0.9525150956533707], 
             UndirectedEdge[67, 316] -> 
             RGBColor[
              0.32978816517065423`, 0.4531895985227258, 0.9424866278961124], 
             UndirectedEdge[303, 376] -> 
             RGBColor[
              0.21141869489039777`, 0.33954483142224945`, 0.9353513539568531],
              UndirectedEdge[208, 357] -> 
             RGBColor[
              0.9024054179734275, 0.6237298560449753, 0.3900146964380397], 
             UndirectedEdge[54, 66] -> 
             RGBColor[
              0.19944158418676777`, 0.3269561286800552, 0.9346692752208288], 
             UndirectedEdge[3, 160] -> 
             RGBColor[
              0.5207461823507223, 0.6218042360373149, 0.9554141935122193], 
             UndirectedEdge[230, 328] -> 
             RGBColor[
              0.8350024631896295, 0.25838385457720503`, 0.18069489331394697`],
              UndirectedEdge[282, 383] -> 
             RGBColor[
              0.23774824777614534`, 0.3672188608952424, 0.9368507830426136], 
             UndirectedEdge[106, 150] -> 
             RGBColor[
              0.2101822963835033, 0.33824529819931026`, 0.9352809428909732], 
             UndirectedEdge[1, 298] -> 
             RGBColor[
              0.19527223087889906`, 0.32257387400121723`, 0.9344318367179512],
              UndirectedEdge[66, 131] -> 
             RGBColor[
              0.2137636212718384, 0.34200949772606326`, 0.9354848940452685], 
             UndirectedEdge[53, 126] -> 
             RGBColor[
              0.1894916420221746, 0.31649810860229766`, 0.9341026407341755], 
             UndirectedEdge[182, 281] -> 
             RGBColor[
              0.38860982761707186`, 0.5110160334092172, 0.94598285247495], 
             UndirectedEdge[74, 263] -> 
             RGBColor[
              0.627506347078178, 0.7037780429959705, 0.9664982429670084], 
             UndirectedEdge[24, 243] -> 
             RGBColor[
              0.8703666327474808, 0.4327860372681659, 0.42384867205099064`], 
             UndirectedEdge[177, 252] -> 
             RGBColor[
              0.6322093663988135, 0.7067582685174405, 0.9673012182198607], 
             UndirectedEdge[10, 216] -> 
             RGBColor[
              0.21860581417743288`, 0.3470989494826055, 0.9357606497678597], 
             UndirectedEdge[280, 339] -> 
             RGBColor[
              0.2515419198726136, 0.3817168848379542, 0.9376363122625981], 
             UndirectedEdge[152, 154] -> 
             RGBColor[
              0.23114091709829876`, 0.3602741374238645, 0.93647450533518], 
             UndirectedEdge[36, 304] -> 
             RGBColor[
              0.18688421139568462`, 0.3137575336932065, 0.933954151417345], 
             UndirectedEdge[128, 299] -> 
             RGBColor[
              0.19113698074466645`, 0.31822746392013684`, 0.934196340340361], 
             UndirectedEdge[95, 162] -> 
             RGBColor[
              0.41586939242453425`, 0.5283792415607237, 0.9486390212485251], 
             UndirectedEdge[215, 329] -> 
             RGBColor[
              0.1867198905000643, 0.313584822013363, 0.9339447935854304], 
             UndirectedEdge[208, 387] -> 
             RGBColor[
              0.7635706581669874, 0.8120231295414462, 0.8609429981480392], 
             UndirectedEdge[178, 197] -> 
             RGBColor[
              0.7030008791274289, 0.7649478943931832, 0.947330285544383], 
             UndirectedEdge[53, 303] -> 
             RGBColor[
              0.20281627238444755`, 0.3305031399434066, 0.9348614587212829], 
             UndirectedEdge[59, 121] -> 
             RGBColor[
              0.3287091584623374, 0.4591330844825578, 0.9421660348044922], 
             UndirectedEdge[134, 269] -> 
             RGBColor[
              0.7872748442941331, 0.8338331400434145, 0.9794082972749127], 
             UndirectedEdge[44, 362] -> 
             RGBColor[
              0.21291981933663207`, 0.3411226083920287, 0.9354368407733515], 
             UndirectedEdge[284, 338] -> 
             RGBColor[
              0.2553995027309328, 0.3857714490069275, 0.9378559958995971], 
             UndirectedEdge[12, 346] -> 
             RGBColor[
              0.329771268632467, 0.46002807831552184`, 0.9422346251627481], 
             UndirectedEdge[113, 387] -> 
             RGBColor[
              0.4208258242811829, 0.5366129491256768, 0.9486460027249637], 
             UndirectedEdge[55, 400] -> 
             RGBColor[
              0.8906627621597499, 0.5631222251341941, 0.24522067856577465`], 
             UndirectedEdge[25, 201] -> 
             RGBColor[
              0.8612272549405598, 0.40992383458465387`, 0.4331919313429953], 
             UndirectedEdge[123, 309] -> 
             RGBColor[
              0.2546471876156135, 0.3849807181211936, 0.93781315266673], 
             UndirectedEdge[35, 162] -> 
             RGBColor[
              0.25429020183451534`, 0.3846055034310536, 0.9377928228546097], 
             UndirectedEdge[73, 172] -> 
             RGBColor[
              0.8594072564997123, 0.3768516972747061, 0.20129475467115204`], 
             UndirectedEdge[137, 282] -> 
             RGBColor[
              0.3008030444529849, 0.4311156931304887, 0.9405287217628104], 
             UndirectedEdge[37, 114] -> 
             RGBColor[
              0.2950446149939596, 0.4237378370222073, 0.9402493164383834], 
             UndirectedEdge[214, 248] -> 
             RGBColor[
              0.22887195802400728`, 0.3578893175764699, 0.9363452914725232], 
             UndirectedEdge[161, 363] -> 
             RGBColor[
              0.20967797684249928`, 0.3377152263860093, 0.9352522226391868], 
             UndirectedEdge[51, 84] -> 
             RGBColor[
              0.36020789306278994`, 0.48641570522103605`, 0.9441731063199956],
              UndirectedEdge[56, 278] -> 
             RGBColor[
              0.3199081459581343, 0.44683361246279085`, 0.9417764708138758], 
             UndirectedEdge[4, 140] -> 
             RGBColor[
              0.22925899781803233`, 0.3582961209397305, 0.9363673328162189], 
             UndirectedEdge[221, 351] -> 
             RGBColor[
              0.9060488999462345, 0.7900961921894157, 0.6157268873569864], 
             UndirectedEdge[54, 204] -> 
             RGBColor[
              0.18912347164523904`, 0.31611113819278824`, 0.9340816739758684],
              UndirectedEdge[10, 298] -> 
             RGBColor[
              0.21724932645694042`, 0.3456731948820789, 0.9356833997989213], 
             UndirectedEdge[134, 226] -> 
             RGBColor[
              0.6381042655490734, 0.7140610165668736, 0.9666654902064342], 
             UndirectedEdge[35, 98] -> 
             RGBColor[
              0.21863346925867172`, 0.3471280167264209, 0.9357622246838242], 
             UndirectedEdge[70, 180] -> 
             RGBColor[
              0.24072957206270523`, 0.3703524217472943, 0.9370205650502591], 
             UndirectedEdge[165, 328] -> 
             RGBColor[
              0.8831401501680374, 0.7104796109326978, 0.6014297849392954], 
             UndirectedEdge[162, 214] -> 
             RGBColor[
              0.25603696286442035`, 0.3864414600245297, 0.9378922983111614], 
             UndirectedEdge[211, 370] -> 
             RGBColor[
              0.20448863330117922`, 0.3322608973006979, 0.9349566972014545], 
             UndirectedEdge[55, 245] -> 
             RGBColor[
              0.869763812018424, 0.4024837363696161, 0.2252078203084527], 
             UndirectedEdge[247, 315] -> 
             RGBColor[
              0.2082369879918481, 0.3362006557400048, 0.9351701604558942], 
             UndirectedEdge[16, 268] -> 
             RGBColor[
              0.49856920010276634`, 0.5995528138290274, 0.9550727772448264], 
             UndirectedEdge[154, 291] -> 
             RGBColor[
              0.1963438417799771, 0.3237002050023056, 0.9344928633734613], 
             UndirectedEdge[296, 373] -> 
             RGBColor[
              0.25840585650162723`, 0.38893131743376574`, 0.9380272032993362],
              UndirectedEdge[101, 394] -> 
             RGBColor[
              0.18176625720560394`, 0.308378239342394, 0.9336626914975545], 
             UndirectedEdge[173, 388] -> 
             RGBColor[
              0.2509970167086373, 0.38114415706375904`, 0.9376052808335218], 
             UndirectedEdge[84, 102] -> 
             RGBColor[
              0.3081546083900806, 0.43843821536979977`, 0.9409621908941581], 
             UndirectedEdge[216, 298] -> 
             RGBColor[
              0.19835416070020614`, 0.3258131776490477, 0.9346073480619681], 
             UndirectedEdge[209, 310] -> 
             RGBColor[
              0.30722079620017617`, 0.4378261141051596, 0.9408954863272463], 
             UndirectedEdge[34, 93] -> 
             RGBColor[
              0.24878417747359188`, 0.37881832272561544`, 0.9374792629126882],
              UndirectedEdge[112, 285] -> 
             RGBColor[
              0.9656534548794817, 0.8891806763774219, 0.4391165147700274], 
             UndirectedEdge[131, 309] -> 
             RGBColor[
              0.255426495168577, 0.38579981977031097`, 0.9378575330789891], 
             UndirectedEdge[116, 265] -> 
             RGBColor[
              0.18666044049465552`, 0.3135223362883303, 0.9339414079955707], 
             UndirectedEdge[49, 129] -> 
             RGBColor[
              0.18838308614561955`, 0.31533294608953616`, 0.9340395101169672],
              UndirectedEdge[238, 325] -> 
             RGBColor[
              0.28956065239162987`, 0.42167698324230746`, 0.9398014228358818],
              UndirectedEdge[112, 399] -> 
             RGBColor[
              0.9318419668775375, 0.7674831415272341, 0.2640166505562497], 
             UndirectedEdge[186, 322] -> 
             RGBColor[
              0.20337835674212623`, 0.3310939262415335, 0.9348934685939234], 
             UndirectedEdge[180, 332] -> 
             RGBColor[
              0.2434440031568898, 0.373205460932154, 0.937175147885432], 
             UndirectedEdge[60, 331] -> 
             RGBColor[
              0.19257622837931382`, 0.31974020443772183`, 0.9342783033639781],
              UndirectedEdge[14, 126] -> 
             RGBColor[
              0.18556762080960376`, 0.31237371351057097`, 0.9338791735311889],
              UndirectedEdge[275, 288] -> 
             RGBColor[
              0.2720607570835225, 0.40328348371603906`, 0.9388048296868601], 
             UndirectedEdge[276, 290] -> 
             RGBColor[
              0.21053718403849497`, 0.33861830762588346`, 0.9353011532179156],
              UndirectedEdge[18, 232] -> 
             RGBColor[
              0.4501165590628717, 0.5589054128143358, 0.9510872394181826], 
             UndirectedEdge[4, 325] -> 
             RGBColor[
              0.26097898271890796`, 0.39163583623375275`, 0.9381737390308114],
              UndirectedEdge[1, 62] -> 
             RGBColor[
              0.19732629313580521`, 0.3247328236682947, 0.9345488125247692], 
             UndirectedEdge[20, 304] -> 
             RGBColor[
              0.185589373288035, 0.312396576744589, 0.9338804123026556], 
             UndirectedEdge[255, 328] -> 
             RGBColor[
              0.8467511825783175, 0.34868966012032526`, 0.19194548026883534`],
              UndirectedEdge[3, 74] -> 
             RGBColor[
              0.7224644673916434, 0.782535536200579, 0.9735133143364585], 
             UndirectedEdge[18, 279] -> 
             RGBColor[
              0.638687245246097, 0.7170964540862654, 0.9650118438159424], 
             UndirectedEdge[163, 226] -> 
             RGBColor[
              0.35601753306005335`, 0.4789075435482711, 0.944048117850775], 
             UndirectedEdge[145, 254] -> 
             RGBColor[
              0.19225246823374995`, 0.31939991199715534`, 0.9342598657026484],
              UndirectedEdge[23, 348] -> 
             RGBColor[
              0.3130979265677895, 0.44416079144735543`, 0.9412244155321879], 
             UndirectedEdge[119, 396] -> 
             RGBColor[
              0.19098691356338682`, 0.3180697337978031, 0.9341877942363916], 
             UndirectedEdge[73, 141] -> 
             RGBColor[
              0.887270128859985, 0.5759343748998204, 0.22738563797870492`], 
             UndirectedEdge[29, 396] -> 
             RGBColor[
              0.19049809514878532`, 0.31755595465117936`, 0.9341599567508221],
              UndirectedEdge[160, 312] -> 
             RGBColor[
              0.38126624461740655`, 0.5039445125232649, 0.9455819912605958], 
             UndirectedEdge[210, 397] -> 
             RGBColor[
              0.25928855226930214`, 0.38985908665173613`, 0.938077471517474], 
             UndirectedEdge[11, 86] -> 
             RGBColor[
              0.361493667794528, 0.48752937866875046`, 0.9442550347489361], 
             UndirectedEdge[113, 315] -> 
             RGBColor[
              0.26318579596449465`, 0.3939553368749055, 0.9382994137804598], 
             UndirectedEdge[120, 160] -> 
             RGBColor[
              0.48896132780643076`, 0.5959998592268796, 0.9529119733307341], 
             UndirectedEdge[5, 308] -> 
             RGBColor[
              0.24197001296398313`, 0.37165620378303305`, 0.9370912063245189],
              UndirectedEdge[37, 261] -> 
             RGBColor[
              0.30438433219243016`, 0.43355447197007246`, 0.940781199515963], 
             UndirectedEdge[22, 241] -> 
             RGBColor[
              0.28974430117812966`, 0.42117386849154814`, 0.9398373705045929],
              UndirectedEdge[55, 165] -> 
             RGBColor[
              0.9341904345376686, 0.918237850236102, 0.6671537250527897], 
             UndirectedEdge[251, 283] -> 
             RGBColor[
              0.19962713488925782`, 0.32715115423296626`, 0.934679842058838], 
             UndirectedEdge[334, 365] -> 
             RGBColor[
              0.18295572293696874`, 0.30962844324254163`, 0.933730429811299], 
             UndirectedEdge[44, 358] -> 
             RGBColor[
              0.21372519899594036`, 0.3419691134779814, 0.9354827059534967], 
             UndirectedEdge[225, 367] -> 
             RGBColor[
              0.6298962166593582, 0.7051035104774022, 0.9669932656124167], 
             UndirectedEdge[23, 321] -> 
             RGBColor[
              0.42370887427578074`, 0.5372228658179581, 0.9490305036181749], 
             UndirectedEdge[234, 269] -> 
             RGBColor[
              0.7646521215423732, 0.8160713160110501, 0.9771770354611466], 
             UndirectedEdge[21, 208] -> 
             RGBColor[
              0.9781086897296334, 0.9394569243444684, 0.5384830216306559], 
             UndirectedEdge[208, 240] -> 
             RGBColor[
              0.8854643741404387, 0.49351356953187997`, 0.37379193373139724`],
              UndirectedEdge[15, 313] -> 
             RGBColor[
              0.25209641053026927`, 0.3822996896758886, 0.9376678896852563], 
             UndirectedEdge[63, 204] -> 
             RGBColor[
              0.18740799960939158`, 0.3143080683159034, 0.9339839803812403], 
             UndirectedEdge[241, 310] -> 
             RGBColor[
              0.2714061632718937, 0.40259546411637237`, 0.9387675515376726], 
             UndirectedEdge[182, 256] -> 
             RGBColor[
              0.34992025301800456`, 0.4775050684860661, 0.9435175869933449], 
             UndirectedEdge[373, 380] -> 
             RGBColor[
              0.24598769620290184`, 0.37587904360296687`, 0.9373200074413457],
              UndirectedEdge[185, 210] -> 
             RGBColor[
              0.35262704416750634`, 0.4795636552057607, 0.9437005295213796], 
             UndirectedEdge[96, 223] -> 
             RGBColor[
              0.8390506368021915, 0.7815052608012159, 0.618996491222558], 
             UndirectedEdge[103, 222] -> 
             RGBColor[
              0.21336670811641717`, 0.34159231683396796`, 0.9354622904282476],
              UndirectedEdge[146, 375] -> 
             RGBColor[
              0.18336952246536248`, 0.3100633727832889, 0.9337539950822794], 
             UndirectedEdge[42, 276] -> 
             RGBColor[
              0.2196855450649306, 0.3482338151042579, 0.9358221388445839], 
             UndirectedEdge[46, 372] -> 
             RGBColor[
              0.19768089456011895`, 0.32510553224827726`, 0.934569006551298], 
             UndirectedEdge[95, 285] -> 
             RGBColor[
              0.7768044768753901, 0.8215969254274786, 0.7842186264026185], 
             UndirectedEdge[14, 326] -> 
             RGBColor[
              0.18828033718868842`, 0.3152249504211414, 0.9340336587158735], 
             UndirectedEdge[22, 310] -> 
             RGBColor[
              0.2979372274212155, 0.4297851534345578, 0.9403039455337885], 
             UndirectedEdge[23, 229] -> 
             RGBColor[
              0.24996961512608984`, 0.38006429285947896`, 0.9375467718333002],
              UndirectedEdge[23, 160] -> 
             RGBColor[
              0.3763398438622711, 0.4987665529777692, 0.9453014400255476], 
             UndirectedEdge[165, 311] -> 
             RGBColor[
              0.5997467789297788, 0.6780206465223158, 0.965283080943369], 
             UndirectedEdge[179, 288] -> 
             RGBColor[
              0.3796596294696894, 0.502934688841232, 0.9454287055118813], 
             UndirectedEdge[51, 167] -> 
             RGBColor[
              0.3459161722681373, 0.47403693499148125`, 0.9432624505086329], 
             UndirectedEdge[310, 346] -> 
             RGBColor[
              0.31533275535423055`, 0.4448522854054794, 0.9414123731914188], 
             UndirectedEdge[79, 379] -> 
             RGBColor[
              0.21907288200889707`, 0.34758986738728526`, 0.9357872485898966],
              UndirectedEdge[78, 264] -> 
             RGBColor[
              0.7877222743756765, 0.3640897660872551, 0.4355019064498754], 
             UndirectedEdge[309, 325] -> 
             RGBColor[
              0.2933678336849298, 0.42567857217080163`, 0.9400182361783151], 
             UndirectedEdge[149, 358] -> 
             RGBColor[
              0.20368965097586314`, 0.3314211162183854, 0.9349111963400162], 
             UndirectedEdge[6, 79] -> 
             RGBColor[
              0.26831622286540857`, 0.39934774083561936`, 0.9385915840026804],
              UndirectedEdge[134, 234] -> 
             RGBColor[
              0.8083454624285121, 0.8502936670726204, 0.9815084195744261], 
             UndirectedEdge[96, 209] -> 
             RGBColor[
              0.5415208134624869, 0.6338317942327045, 0.9590470002598491], 
             UndirectedEdge[216, 393] -> 
             RGBColor[
              0.19153695040893678`, 0.31864785739682644`, 0.9342191180210391],
              UndirectedEdge[164, 388] -> 
             RGBColor[
              0.21023340989613648`, 0.33829902174187165`, 0.935283853729902], 
             UndirectedEdge[155, 261] -> 
             RGBColor[
              0.23352567596023666`, 0.3627806701902061, 0.9366103138244327], 
             UndirectedEdge[125, 288] -> 
             RGBColor[
              0.28344153985750953`, 0.415245407994804, 0.9394529484294792], 
             UndirectedEdge[287, 384] -> 
             RGBColor[
              0.18974513703544627`, 0.3167645479337583, 0.9341170769001692], 
             UndirectedEdge[69, 320] -> 
             RGBColor[
              0.21880446674278364`, 0.34730774592408925`, 0.9357719627375762],
              UndirectedEdge[123, 339] -> 
             RGBColor[
              0.23162280417676506`, 0.3607806312967381, 0.9365019480914105], 
             UndirectedEdge[132, 202] -> 
             RGBColor[
              0.300816385571577, 0.4289283244783967, 0.9406100852285664], 
             UndirectedEdge[67, 249] -> 
             RGBColor[
              0.36714946895537004`, 0.49242814936543994`, 0.9446154173976764],
              UndirectedEdge[374, 384] -> 
             RGBColor[
              0.18988847579037965`, 0.3169152060533953, 0.934125239830212], 
             UndirectedEdge[99, 252] -> 
             RGBColor[
              0.6676015641481373, 0.7342070299092066, 0.9439106644834332], 
             UndirectedEdge[44, 65] -> 
             RGBColor[
              0.2623103948909678, 0.393035234842995, 0.9382495609843622], 
             UndirectedEdge[88, 370] -> 
             RGBColor[
              0.189278561860536, 0.3162741478423529, 0.9340905061341941], 
             UndirectedEdge[13, 275] -> 
             RGBColor[
              0.22645651195099847`, 0.3553505306056112, 0.9362077353919975], 
             UndirectedEdge[183, 269] -> 
             RGBColor[
              0.546784204528102, 0.6385867943130678, 0.9592993736008182], 
             UndirectedEdge[122, 178] -> 
             RGBColor[
              0.5198265338212547, 0.6207419031672892, 0.9554290299990101], 
             UndirectedEdge[199, 216] -> 
             RGBColor[
              0.19310022590756143`, 0.3202909590632723, 0.9343081442480269], 
             UndirectedEdge[107, 295] -> 
             RGBColor[
              0.38882676959428764`, 0.5112039376460608, 0.945996675825904], 
             UndirectedEdge[89, 171] -> 
             RGBColor[
              0.18910388505940673`, 0.3160905514492172, 0.934080558548781], 
             UndirectedEdge[18, 91] -> 
             RGBColor[
              0.5492190587011108, 0.6449197997470224, 0.9576556826381046], 
             UndirectedEdge[194, 357] -> 
             RGBColor[
              0.9029108820280516, 0.6235073439816599, 0.3502698506941914], 
             UndirectedEdge[147, 388] -> 
             RGBColor[
              0.20149520910929605`, 0.3291146186809729, 0.9347862261221009], 
             UndirectedEdge[96, 323] -> 
             RGBColor[
              0.5734450946307983, 0.6614830020196698, 0.9610811872263605], 
             UndirectedEdge[168, 265] -> 
             RGBColor[
              0.18709388052696674`, 0.31397790924397473`, 0.9339660917641938],
              UndirectedEdge[44, 372] -> 
             RGBColor[
              0.21537145554787535`, 0.3436994334927591, 0.9355764578287111], 
             UndirectedEdge[180, 286] -> 
             RGBColor[
              0.22669434503393948`, 0.3556005082552706, 0.9362212796342286], 
             UndirectedEdge[18, 45] -> 
             RGBColor[
              0.4449748432614876, 0.5535011435034702, 0.9507944263097807], 
             UndirectedEdge[83, 217] -> 
             RGBColor[
              0.9690520396764782, 0.9730561345189551, 0.7324860448307533], 
             UndirectedEdge[137, 314] -> 
             RGBColor[
              0.28356888618805115`, 0.41300150008529746`, 0.9395472619452747],
              UndirectedEdge[205, 338] -> 
             RGBColor[
              0.292109011117009, 0.4205396174018403, 0.9400862651454345], 
             UndirectedEdge[210, 293] -> 
             RGBColor[
              0.3272740253136205, 0.45760414455430376`, 0.9420850575788042], 
             UndirectedEdge[295, 324] -> 
             RGBColor[
              0.5310822445454129, 0.6295361727227928, 0.9564100649680346], 
             UndirectedEdge[270, 346] -> 
             RGBColor[
              0.3550828331693524, 0.4819766359343405, 0.9438465420354984], 
             UndirectedEdge[26, 349] -> 
             RGBColor[
              0.19449252215171758`, 0.32175435069256086`, 0.9343874334594139],
              UndirectedEdge[27, 208] -> 
             RGBColor[
              0.8783639162366949, 0.43893633864321185`, 0.3669925272239519], 
             UndirectedEdge[139, 193] -> 
             RGBColor[
              0.18750230329400064`, 0.31440718746762647`, 0.933989350836569], 
             UndirectedEdge[5, 296] -> 
             RGBColor[
              0.26370004466317304`, 0.39449584486246725`, 0.9383286994830867],
              UndirectedEdge[42, 125] -> 
             RGBColor[
              0.23901293023950498`, 0.3685481223497329, 0.9369228048379719], 
             UndirectedEdge[12, 106] -> 
             RGBColor[
              0.2676474114572338, 0.3986447776405352, 0.9385534961824027], 
             UndirectedEdge[242, 357] -> 
             RGBColor[
              0.8538824472203527, 0.4151696775403659, 0.1992311983507169], 
             UndirectedEdge[148, 279] -> 
             RGBColor[
              0.5031062098123048, 0.6037853067748751, 0.9552337277677017], 
             UndirectedEdge[292, 374] -> 
             RGBColor[
              0.19230228893935433`, 0.31945227671756077`, 0.9342627029181295],
              UndirectedEdge[195, 369] -> 
             RGBColor[
              0.19622298384464848`, 0.3235731756494396, 0.9344859806928376], 
             UndirectedEdge[50, 371] -> 
             RGBColor[
              0.1827919087042476, 0.30945626409752947`, 0.9337211008330868], 
             UndirectedEdge[29, 127] -> 
             RGBColor[
              0.18812124438286376`, 0.3150577337951532, 0.9340245986159385], 
             UndirectedEdge[87, 127] -> 
             RGBColor[
              0.19649156208518143`, 0.3238554684090837, 0.93450127582631], 
             UndirectedEdge[264, 357] -> 
             RGBColor[
              0.8124975481520774, 0.5545233769268668, 0.45922673659782653`], 
             UndirectedEdge[171, 306] -> 
             RGBColor[
              0.19583756200520352`, 0.3231680728590269, 0.9344640314892618], 
             UndirectedEdge[114, 170] -> 
             RGBColor[
              0.23647751036378017`, 0.3658832353054412, 0.9367784164268669], 
             UndirectedEdge[57, 222] -> 
             RGBColor[
              0.22503342369355192`, 0.35385477461802795`, 0.9361266926210063],
              UndirectedEdge[38, 102] -> 
             RGBColor[
              0.25020060979959846`, 0.3803070829072448, 0.9375599266382304], 
             UndirectedEdge[82, 331] -> 
             RGBColor[
              0.18993705205367367`, 0.31696626278603024`, 0.9341280061765445],
              UndirectedEdge[90, 324] -> 
             RGBColor[
              0.6207541500572831, 0.7029952095291041, 0.9632871870713362], 
             UndirectedEdge[160, 341] -> 
             RGBColor[
              0.3979292657890303, 0.5189168537463054, 0.9466239842803985], 
             UndirectedEdge[15, 311] -> 
             RGBColor[
              0.2942848105043079, 0.4266423729476564, 0.940070456651633], 
             UndirectedEdge[271, 292] -> 
             RGBColor[
              0.18674265418407987`, 0.3136087480885643, 0.9339460899435592], 
             UndirectedEdge[41, 156] -> 
             RGBColor[
              0.8446142468320946, 0.4596744496768401, 0.44741728123423563`], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.26166329356975937`, 0.3923550903258115, 0.9382127095214201], 
             UndirectedEdge[129, 317] -> 
             RGBColor[
              0.19222117947628775`, 0.3193670255292408, 0.9342580838541985], 
             UndirectedEdge[164, 354] -> 
             RGBColor[
              0.20840265875823133`, 0.3363747862196069, 0.9351795951609518], 
             UndirectedEdge[78, 230] -> 
             RGBColor[
              0.8192044912502568, 0.14861971197700838`, 0.16602354855060375`],
              UndirectedEdge[315, 363] -> 
             RGBColor[
              0.2193734294732247, 0.3479057618281034, 0.9358043643233698], 
             UndirectedEdge[5, 121] -> 
             RGBColor[
              0.2966728547509243, 0.4289526354856623, 0.9402137650898452], 
             UndirectedEdge[43, 380] -> 
             RGBColor[
              0.2402420225431372, 0.36983997628980336`, 0.9369927998263845], 
             UndirectedEdge[135, 234] -> 
             RGBColor[
              0.8902824990453274, 0.9119541401261442, 0.8296334999422285], 
             UndirectedEdge[344, 356] -> 
             RGBColor[
              0.19312061469136133`, 0.3203123889677695, 0.9343093053591018], 
             UndirectedEdge[186, 228] -> 
             RGBColor[
              0.20522346006975262`, 0.3330332468251766, 0.934998544498846], 
             UndirectedEdge[298, 396] -> 
             RGBColor[
              0.19827776691556012`, 0.32573288293773905`, 0.9346029975489469],
              UndirectedEdge[86, 93] -> 
             RGBColor[
              0.32267144519324537`, 0.4470223501983363, 0.9420332704147207], 
             UndirectedEdge[249, 266] -> 
             RGBColor[
              0.270914372535644, 0.40204801259274037`, 0.9387406633049027], 
             UndirectedEdge[156, 364] -> 
             RGBColor[
              0.8265496181427123, 0.20507757592754824`, 0.17305725035795336`],
              UndirectedEdge[10, 311] -> 
             RGBColor[
              0.2701224968687157, 0.40124624933748154`, 0.9386944486350258], 
             UndirectedEdge[27, 73] -> 
             RGBColor[
              0.8575639301123329, 0.3626830829105343, 0.19952958324085807`], 
             UndirectedEdge[56, 213] -> 
             RGBColor[
              0.30213444608884904`, 0.4281523269825127, 0.9407642849001527], 
             UndirectedEdge[27, 243] -> 
             RGBColor[
              0.8705342231838472, 0.43407421080067554`, 0.42400915684212137`],
              UndirectedEdge[109, 157] -> 
             RGBColor[
              0.18435836126610156`, 0.3111027050588667, 0.9338103079891256], 
             UndirectedEdge[12, 241] -> 
             RGBColor[
              0.28584467655013013`, 0.4177712570264148, 0.9395898035090018], 
             UndirectedEdge[192, 382] -> 
             RGBColor[
              0.18175632170203998`, 0.30836779649820095`, 0.9336621256853248],
              UndirectedEdge[140, 280] -> 
             RGBColor[
              0.2386176080728396, 0.36813261368769457`, 0.936900291825407], 
             UndirectedEdge[199, 361] -> 
             RGBColor[
              0.2020628988707439, 0.32971129661386445`, 0.9348185552141937], 
             UndirectedEdge[16, 351] -> 
             RGBColor[
              0.6137824648944775, 0.6902841557450048, 0.9663635368138602], 
             UndirectedEdge[140, 322] -> 
             RGBColor[
              0.21280212927241615`, 0.34099890867255667`, 0.9354301384983013],
              UndirectedEdge[57, 238] -> 
             RGBColor[
              0.2538315033751126, 0.3841233822670593, 0.9377667006559303], 
             UndirectedEdge[49, 127] -> 
             RGBColor[
              0.19124100743417377`, 0.3183368025664821, 0.9342022645064347], 
             UndirectedEdge[165, 182] -> 
             RGBColor[
              0.6226406331298818, 0.6984050769847048, 0.9667215385795859], 
             UndirectedEdge[253, 343] -> 
             RGBColor[
              0.18655690968294972`, 0.31341351884099494`, 0.9339355120690042],
              UndirectedEdge[104, 240] -> 
             RGBColor[
              0.8232357232183486, 0.17960552738087315`, 0.16988386083587365`],
              UndirectedEdge[312, 348] -> 
             RGBColor[
              0.31802432732292496`, 0.44933875099285125`, 0.9415049667672362],
              UndirectedEdge[242, 244] -> 
             RGBColor[
              0.886437425104949, 0.5904629270310702, 0.4522784384828552], 
             UndirectedEdge[41, 165] -> 
             RGBColor[
              0.8843102751860701, 0.9105890257431475, 0.9888274975519911], 
             UndirectedEdge[54, 297] -> 
             RGBColor[
              0.19576644813648575`, 0.3230933276741248, 0.9344599816596418], 
             UndirectedEdge[77, 145] -> 
             RGBColor[
              0.19003339190962826`, 0.3170675220829382, 0.934133492588819], 
             UndirectedEdge[69, 150] -> 
             RGBColor[
              0.217681081623926, 0.3461269969374395, 0.9357079876169566], 
             UndirectedEdge[106, 241] -> 
             RGBColor[
              0.24501597193591163`, 0.37485769978748307`, 0.9372646691818778],
              UndirectedEdge[139, 276] -> 
             RGBColor[
              0.20545840173873126`, 0.33328018541543536`, 0.9350119240793292],
              UndirectedEdge[313, 393] -> 
             RGBColor[
              0.200865233126181, 0.3284524739799347, 0.9347503499218286], 
             UndirectedEdge[209, 323] -> 
             RGBColor[
              0.36676678405368435`, 0.4920966869379023, 0.9445910330541359], 
             UndirectedEdge[8, 213] -> 
             RGBColor[
              0.230215374068607, 0.3593013330168411, 0.9364217970288573], 
             UndirectedEdge[160, 244] -> 
             RGBColor[
              0.7071944520529801, 0.7689833903419949, 0.9560284549892878], 
             UndirectedEdge[180, 284] -> 
             RGBColor[
              0.2675710150211928, 0.3985644801424423, 0.9385491455183885], 
             UndirectedEdge[24, 242] -> 
             RGBColor[
              0.8312823760459324, 0.24145562707943447`, 0.17758934467096238`],
              UndirectedEdge[81, 192] -> 
             RGBColor[
              0.1805894919591846, 0.3071413844571813, 0.9335956764576392], 
             UndirectedEdge[124, 249] -> 
             RGBColor[
              0.30940302019566135`, 0.4424110778706867, 0.9409358647458874], 
             UndirectedEdge[195, 253] -> 
             RGBColor[
              0.1964706167173933, 0.3238334534995253, 0.9345000830186004], 
             UndirectedEdge[31, 81] -> 
             RGBColor[
              0.1880171511030766, 0.3149483251582018, 0.9340186706576468], 
             UndirectedEdge[172, 399] -> 
             RGBColor[
              0.8580608382473571, 0.37151359757140306`, 0.20021139494080872`],
              UndirectedEdge[124, 315] -> 
             RGBColor[
              0.2642878093777229, 0.3950226791099546, 0.9383655017096588], 
             UndirectedEdge[181, 370] -> 
             RGBColor[
              0.19100569805155482`, 0.318089477485873, 0.9341888639852036], 
             UndirectedEdge[244, 348] -> 
             RGBColor[
              0.6439525347584986, 0.7143776288115813, 0.9519514304959281], 
             UndirectedEdge[284, 367] -> 
             RGBColor[
              0.3258404306471927, 0.4536760993310988, 0.9420920701724073], 
             UndirectedEdge[148, 232] -> 
             RGBColor[
              0.3145355236290795, 0.4455942655029455, 0.9413091233699418], 
             UndirectedEdge[34, 211] -> 
             RGBColor[
              0.2425688344221679, 0.3722856031030586, 0.9371253083206856], 
             UndirectedEdge[355, 392] -> 
             RGBColor[
              0.8783955245201162, 0.9037382421614023, 0.8873541737699352], 
             UndirectedEdge[262, 338] -> 
             RGBColor[
              0.22417589206845978`, 0.35295345450941085`, 0.9360778574635618],
              UndirectedEdge[87, 119] -> 
             RGBColor[
              0.19029746556308325`, 0.3173450802359561, 0.9341485311927212], 
             UndirectedEdge[180, 367] -> 
             RGBColor[
              0.31681274319178854`, 0.44418742742702483`, 0.9415779567270888],
              UndirectedEdge[69, 380] -> 
             RGBColor[
              0.2309702581422837, 0.36009476404068996`, 0.9364647865601021], 
             UndirectedEdge[124, 338] -> 
             RGBColor[
              0.2719649687624893, 0.40309186038336303`, 0.9388027045792817], 
             UndirectedEdge[249, 293] -> 
             RGBColor[
              0.3289853537057845, 0.45937231092045516`, 0.9421836337211749], 
             UndirectedEdge[212, 373] -> 
             RGBColor[
              0.34459378761093823`, 0.4694803712160838, 0.9433030893613046], 
             UndirectedEdge[287, 292] -> 
             RGBColor[
              0.19215895018442095`, 0.31930161859792383`, 0.9342545399880867],
              UndirectedEdge[12, 323] -> 
             RGBColor[
              0.35358359064672407`, 0.4806531148021672, 0.943751925265087], 
             UndirectedEdge[120, 307] -> 
             RGBColor[
              0.43332684059947457`, 0.5479832712777266, 0.9493196875555654], 
             UndirectedEdge[99, 398] -> 
             RGBColor[
              0.695865579228825, 0.7586878991813948, 0.9457116225314874], 
             UndirectedEdge[134, 350] -> 
             RGBColor[
              0.9124093272037948, 0.929890258170909, 0.8676584254872136], 
             UndirectedEdge[45, 280] -> 
             RGBColor[
              0.26817273037966816`, 0.3991969211351571, 0.9385834123178955], 
             UndirectedEdge[188, 330] -> 
             RGBColor[
              0.19385743072413472`, 0.32108682933504906`, 0.9343512659421467],
              UndirectedEdge[236, 284] -> 
             RGBColor[
              0.26368702808225786`, 0.3944821636106265, 0.9383279582080599], 
             UndirectedEdge[374, 389] -> 
             RGBColor[
              0.19643386923101253`, 0.3237948295614139, 0.9344979903036141], 
             UndirectedEdge[278, 319] -> 
             RGBColor[
              0.35576382875700985`, 0.4778888141834562, 0.9440614916187484], 
             UndirectedEdge[78, 242] -> 
             RGBColor[
              0.8307161944426305, 0.2371037071740957, 0.17704716852822983`], 
             UndirectedEdge[84, 189] -> 
             RGBColor[
              0.30274052812538393`, 0.4327476737390883, 0.9406538670324976], 
             UndirectedEdge[223, 385] -> 
             RGBColor[
              0.9621637338718393, 0.8751385282482187, 0.44853214930663265`], 
             UndirectedEdge[175, 278] -> 
             RGBColor[
              0.2699086210585896, 0.40102145230052944`, 0.93868226872404], 
             UndirectedEdge[151, 168] -> 
             RGBColor[
              0.18811217327033666`, 0.31504819948074547`, 0.9340240820294996],
              UndirectedEdge[322, 339] -> 
             RGBColor[
              0.22572644107219014`, 0.3545831798228164, 0.9361661589354925], 
             UndirectedEdge[177, 367] -> 
             RGBColor[
              0.6349673392184779, 0.7091470859540894, 0.9674769538091501], 
             UndirectedEdge[294, 320] -> 
             RGBColor[
              0.19287620932606772`, 0.32005550343265077`, 0.9342953868351136],
              UndirectedEdge[179, 279] -> 
             RGBColor[
              0.5630911384213583, 0.6557241290001397, 0.9590606413690353], 
             UndirectedEdge[18, 285] -> 
             RGBColor[
              0.7996696633612428, 0.8401599138816065, 0.7860186576407228], 
             UndirectedEdge[121, 296] -> 
             RGBColor[
              0.27793336964590865`, 0.4092562484883108, 0.9391465791356984], 
             UndirectedEdge[212, 351] -> 
             RGBColor[
              0.6635629227613954, 0.7334014863107667, 0.9695355035700097], 
             UndirectedEdge[29, 87] -> 
             RGBColor[
              0.18980864714848175`, 0.31683130108933233`, 0.9341206937071518],
              UndirectedEdge[99, 141] -> 
             RGBColor[
              0.8989439948619978, 0.6463586296042318, 0.4540597244463016], 
             UndirectedEdge[121, 274] -> 
             RGBColor[
              0.4019923332344326, 0.5215276967163304, 0.9471338679528571], 
             UndirectedEdge[138, 218] -> 
             RGBColor[
              0.18655648275495362`, 0.3134130701126022, 0.9339354877560864], 
             UndirectedEdge[61, 388] -> 
             RGBColor[
              0.2144393921406435, 0.3427197757555252, 0.9355233781965335], 
             UndirectedEdge[283, 347] -> 
             RGBColor[
              0.20341579469893528`, 0.33113327590784336`, 0.9348956006301792],
              UndirectedEdge[253, 315] -> 
             RGBColor[
              0.20496946088804507`, 0.3327662775807237, 0.9349840796212059], 
             UndirectedEdge[321, 366] -> 
             RGBColor[
              0.4743804722974104, 0.5825626858071993, 0.9522061384174323], 
             UndirectedEdge[164, 391] -> 
             RGBColor[
              0.1910397493801938, 0.3181252675912516, 0.9341908031579952], 
             UndirectedEdge[74, 91] -> 
             RGBColor[
              0.6781789401773193, 0.7465825501677249, 0.9700269954109155], 
             UndirectedEdge[91, 285] -> 
             RGBColor[
              0.7437484336984672, 0.7947605404186777, 0.7816163335954551], 
             UndirectedEdge[51, 183] -> 
             RGBColor[
              0.36578243486715545`, 0.4912440931473596, 0.9445283111943961], 
             UndirectedEdge[30, 54] -> 
             RGBColor[
              0.1824115228296057, 0.3090564544254234, 0.9336994384202565], 
             UndirectedEdge[68, 250] -> 
             RGBColor[
              0.2641868760172087, 0.3950075354824494, 0.9383564238084967], 
             UndirectedEdge[32, 230] -> 
             RGBColor[
              0.8641696265273747, 0.38047397392294696`, 0.2056059653743008], 
             UndirectedEdge[275, 318] -> 
             RGBColor[
              0.21657038683237403`, 0.3449595862894012, 0.9356447351917034], 
             UndirectedEdge[131, 186] -> 
             RGBColor[
              0.21005402739966472`, 0.3381104793645726, 0.9352736381621005], 
             UndirectedEdge[192, 292] -> 
             RGBColor[
              0.18800332047098128`, 0.31493378828695684`, 0.9340178830236096],
              UndirectedEdge[144, 200] -> 
             RGBColor[
              0.18738223875410484`, 0.31428099202366444`, 0.9339825133386415],
              UndirectedEdge[139, 318] -> 
             RGBColor[
              0.19122506102961745`, 0.318320041884233, 0.9342013563822857], 
             UndirectedEdge[93, 148] -> 
             RGBColor[
              0.2841492261294814, 0.41365634022833114`, 0.9395786686798384], 
             UndirectedEdge[92, 311] -> 
             RGBColor[
              0.40006723340595274`, 0.5191882673765618, 0.947063870354397], 
             UndirectedEdge[334, 370] -> 
             RGBColor[
              0.18603433510834283`, 0.3128642598299414, 0.93390575222006], 
             UndirectedEdge[62, 129] -> 
             RGBColor[
              0.19509705711799047`, 0.3223897552718444, 0.9344218608314138], 
             UndirectedEdge[97, 191] -> 
             RGBColor[
              0.2000566789628183, 0.32760263228894565`, 0.9347043039583738], 
             UndirectedEdge[120, 366] -> 
             RGBColor[
              0.4563492884558704, 0.567924158469062, 0.9507866575750236], 
             UndirectedEdge[91, 288] -> 
             RGBColor[
              0.3993345066316525, 0.518907640464429, 0.9469775839135208], 
             UndirectedEdge[21, 32] -> 
             RGBColor[
              0.9601171751337108, 0.8771280081727125, 0.29956318594431774`], 
             UndirectedEdge[121, 178] -> 
             RGBColor[
              0.376298213208635, 0.5003523318083618, 0.9451983672915776], 
             UndirectedEdge[294, 381] -> 
             RGBColor[
              0.19306159004241835`, 0.32025035031935156`, 0.9343059439926636],
              UndirectedEdge[46, 149] -> 
             RGBColor[
              0.20894845482391827`, 0.3369484524901131, 0.9352106774394597], 
             UndirectedEdge[66, 232] -> 
             RGBColor[
              0.25468181299552817`, 0.38501711159085983`, 0.9378151245308926],
              UndirectedEdge[114, 261] -> 
             RGBColor[
              0.25063032461803525`, 0.380758740426915, 0.9375843982614342], 
             UndirectedEdge[189, 395] -> 
             RGBColor[
              0.3676410779096787, 0.4885452690238077, 0.9449042144225828], 
             UndirectedEdge[54, 290] -> 
             RGBColor[
              0.19141480754021284`, 0.3185194774974923, 0.9342121621653594], 
             UndirectedEdge[4, 309] -> 
             RGBColor[
              0.2652076930566547, 0.39608047891444564`, 0.9384145578287296], 
             UndirectedEdge[195, 315] -> 
             RGBColor[
              0.21034714004508412`, 0.3384185593393235, 0.9352903304936357], 
             UndirectedEdge[181, 305] -> 
             RGBColor[
              0.18857843384879308`, 0.3155382689113313, 0.9340506348796719], 
             UndirectedEdge[153, 372] -> 
             RGBColor[
              0.18825648302408265`, 0.31519987818169937`, 0.9340323002564883],
              UndirectedEdge[175, 227] -> 
             RGBColor[
              0.24456047357150879`, 0.37437894212623135`, 0.9372387292238745],
              UndirectedEdge[271, 287] -> 
             RGBColor[
              0.18451611233351262`, 0.31126851143271117`, 0.9338192916790429],
              UndirectedEdge[232, 297] -> 
             RGBColor[
              0.25100667694524614`, 0.38115431058492943`, 0.9376058309697055],
              UndirectedEdge[21, 25] -> 
             RGBColor[
              0.8659467013248013, 0.3852627325093696, 0.21332785065016086`], 
             UndirectedEdge[123, 297] -> 
             RGBColor[
              0.20930917766859286`, 0.3373275950710155, 0.9352312200718224], 
             UndirectedEdge[6, 178] -> 
             RGBColor[
              0.37363938184973156`, 0.4977574548464476, 0.9450396379279142], 
             UndirectedEdge[90, 319] -> 
             RGBColor[
              0.530870221387825, 0.6300233870103961, 0.956211194950797], 
             UndirectedEdge[258, 302] -> 
             RGBColor[
              0.18739149065206478`, 0.3142907163550246, 0.9339830402205433], 
             UndirectedEdge[253, 397] -> 
             RGBColor[
              0.20200814651583682`, 0.3296537484173573, 0.9348154371485806], 
             UndirectedEdge[169, 177] -> 
             RGBColor[
              0.8953206105495907, 0.9193683682944271, 0.9898776731680061], 
             UndirectedEdge[198, 332] -> 
             RGBColor[
              0.29082644977848415`, 0.41888733476416706`, 0.9400243645014585],
              UndirectedEdge[45, 123] -> 
             RGBColor[
              0.24825361468381962`, 0.37826066759394095`, 0.9374490481467079],
              UndirectedEdge[223, 245] -> 
             RGBColor[
              0.8558540868670035, 0.35042522733663617`, 0.19792860165144016`],
              UndirectedEdge[380, 381] -> 
             RGBColor[
              0.20814382827755723`, 0.3361027389736181, 0.9351648551479828], 
             UndirectedEdge[277, 378] -> 
             RGBColor[
              0.19931695292516527`, 0.3268251333220326, 0.934662177654856], 
             UndirectedEdge[119, 326] -> 
             RGBColor[
              0.18721381086797456`, 0.3141039636363968, 0.933972921619693], 
             UndirectedEdge[89, 133] -> 
             RGBColor[
              0.1875161010871107, 0.31442168982301577`, 0.9339901366004746], 
             UndirectedEdge[22, 346] -> 
             RGBColor[
              0.3336708932604665, 0.46343068978065516`, 0.9424821921583393], 
             UndirectedEdge[73, 243] -> 
             RGBColor[
              0.9500707567190481, 0.8697065757980069, 0.5997490197634427], 
             UndirectedEdge[26, 353] -> 
             RGBColor[
              0.1885101327336185, 0.315466480108742, 0.9340467452322052], 
             UndirectedEdge[21, 230] -> 
             RGBColor[
              0.8662262457545036, 0.38741143349321117`, 0.21359554271174397`],
              UndirectedEdge[107, 390] -> 
             RGBColor[
              0.30566480118721207`, 0.43491696287761505`, 0.9408535111759078],
              UndirectedEdge[223, 364] -> 
             RGBColor[
              0.855085463353394, 0.3445172501980627, 0.19719256690677167`], 
             UndirectedEdge[2, 211] -> 
             RGBColor[
              0.2034376502421772, 0.3311562474695121, 0.9348968452710344], 
             UndirectedEdge[128, 353] -> 
             RGBColor[
              0.19231632365158768`, 0.3194670280899702, 0.9342635021742287], 
             UndirectedEdge[259, 331] -> 
             RGBColor[
              0.19269223822101744`, 0.31986213813680114`, 0.934284909952842], 
             UndirectedEdge[2, 334] -> 
             RGBColor[
              0.18498335204934083`, 0.3117596099987556, 0.93384590028964], 
             UndirectedEdge[72, 191] -> 
             RGBColor[
              0.19501894918374685`, 0.32230765888062524`, 0.934417412700109], 
             UndirectedEdge[247, 301] -> 
             RGBColor[
              0.1901623548072361, 0.317203070265044, 0.9341408368350541], 
             UndirectedEdge[247, 397] -> 
             RGBColor[
              0.20527567361963986`, 0.3330881265766384, 0.935001517983269], 
             UndirectedEdge[125, 263] -> 
             RGBColor[
              0.326732269165051, 0.4530536866427142, 0.9421999706648885], 
             UndirectedEdge[123, 325] -> 
             RGBColor[
              0.2504184772778667, 0.38053607544050067`, 0.9375723338688118], 
             UndirectedEdge[129, 393] -> 
             RGBColor[
              0.18622578456981498`, 0.3130654853525456, 0.9339166549836668], 
             UndirectedEdge[19, 205] -> 
             RGBColor[
              0.30521095643223367`, 0.4343105926394541, 0.9408324015485454], 
             UndirectedEdge[277, 352] -> 
             RGBColor[
              0.22370886564436498`, 0.3524625801265016, 0.9360512609996132], 
             UndirectedEdge[139, 224] -> 
             RGBColor[
              0.18369701044953324`, 0.3104075834185898, 0.9337726450385029], 
             UndirectedEdge[65, 250] -> 
             RGBColor[
              0.2731468584894696, 0.40442504515649597`, 0.9388666815551856], 
             UndirectedEdge[58, 117] -> 
             RGBColor[
              0.2190498578943207, 0.34756566758305235`, 0.9357859374006325], 
             UndirectedEdge[134, 272] -> 
             RGBColor[0.7859507335711424, 0.832798734683, 0.9792763222925633],
              UndirectedEdge[74, 95] -> 
             RGBColor[
              0.7112349833542422, 0.7734189351765257, 0.9726292882180788], 
             UndirectedEdge[156, 245] -> 
             RGBColor[
              0.826933929899517, 0.208031564496835, 0.1734252677302876], 
             UndirectedEdge[221, 324] -> 
             RGBColor[
              0.7677190036317167, 0.6811645798747406, 0.602228741750033], 
             UndirectedEdge[227, 375] -> 
             RGBColor[
              0.1940331226429612, 0.32127149268124666`, 0.9343612713370109], 
             UndirectedEdge[132, 348] -> 
             RGBColor[
              0.34570653122762846`, 0.47385535445905747`, 0.94324909236691], 
             UndirectedEdge[137, 319] -> 
             RGBColor[
              0.3939126281591366, 0.5156078641515458, 0.9463210706392715], 
             UndirectedEdge[128, 170] -> 
             RGBColor[
              0.21313809335858236`, 0.34135202822847077`, 0.9354492711559941],
              UndirectedEdge[120, 220] -> 
             RGBColor[
              0.5770608462863022, 0.6675230171669182, 0.9598474901446392], 
             UndirectedEdge[292, 371] -> 
             RGBColor[
              0.1904665323376698, 0.31752278013549917`, 0.934158159295422], 
             UndirectedEdge[143, 378] -> 
             RGBColor[
              0.18793083673403851`, 0.31485760328369566`, 0.9340137551820207],
              UndirectedEdge[59, 373] -> 
             RGBColor[
              0.3091816453180559, 0.4388081534280127, 0.9410466589681301], 
             UndirectedEdge[2, 340] -> 
             RGBColor[
              0.19396024281710603`, 0.32119489136342505`, 0.9343571209387445],
              UndirectedEdge[131, 322] -> 
             RGBColor[
              0.206580775656939, 0.33445987156608825`, 0.9350758416135677], 
             UndirectedEdge[62, 317] -> 
             RGBColor[
              0.19822991985182326`, 0.32568259264007254`, 0.9346002727294505],
              UndirectedEdge[243, 337] -> 
             RGBColor[
              0.981786507894951, 0.983234170680865, 0.764939800713467], 
             UndirectedEdge[21, 217] -> 
             RGBColor[
              0.9781358461419554, 0.9375595363156388, 0.3992965964312667], 
             UndirectedEdge[24, 74] -> 
             RGBColor[
              0.8348779177441421, 0.40506983940754504`, 0.4406260894055427], 
             UndirectedEdge[1, 127] -> 
             RGBColor[
              0.19417547404882396`, 0.3214211130344089, 0.9343693780389848], 
             UndirectedEdge[226, 355] -> 
             RGBColor[
              0.6054737407452027, 0.6884810215092875, 0.963436744212341], 
             UndirectedEdge[97, 370] -> 
             RGBColor[
              0.18998864922989284`, 0.31702049468968657`, 0.9341309445593988],
              UndirectedEdge[148, 257] -> 
             RGBColor[
              0.3285413065471964, 0.4589876995901452, 0.9421553394288851], 
             UndirectedEdge[48, 344] -> 
             RGBColor[
              0.21571874970997718`, 0.3440644616768498, 0.9355962357174672], 
             UndirectedEdge[74, 148] -> 
             RGBColor[
              0.5985191344063026, 0.6786707763192633, 0.9646512034079422], 
             UndirectedEdge[266, 293] -> 
             RGBColor[
              0.2908233203898157, 0.4192921425712095, 0.940009243857379], 
             UndirectedEdge[84, 226] -> 
             RGBColor[
              0.39203908397867687`, 0.5139862829102032, 0.9462013616579391], 
             UndirectedEdge[354, 371] -> 
             RGBColor[
              0.20120013846367035`, 0.3288044807238608, 0.9347694222853504], 
             UndirectedEdge[57, 188] -> 
             RGBColor[
              0.20973271485913975`, 0.33777275951208907`, 0.9352553398882568],
              UndirectedEdge[134, 355] -> 
             RGBColor[
              0.7983376603764013, 0.8424754960473988, 0.9805109353940992], 
             UndirectedEdge[151, 378] -> 
             RGBColor[
              0.19141895458300517`, 0.3185238363024048, 0.9342123983333115], 
             UndirectedEdge[167, 238] -> 
             RGBColor[
              0.3001182809431252, 0.43263426016352036`, 0.9404077704799216], 
             UndirectedEdge[41, 311] -> 
             RGBColor[
              0.5873075100595555, 0.6681019111801583, 0.9640966123738608], 
             UndirectedEdge[212, 295] -> 
             RGBColor[
              0.42318563987531466`, 0.5409638641564534, 0.9481859926578549], 
             UndirectedEdge[179, 285] -> 
             RGBColor[
              0.7240735565365042, 0.7787875887954807, 0.7800674551938157], 
             UndirectedEdge[85, 348] -> 
             RGBColor[
              0.28694246093137055`, 0.4166697387111759, 0.9397349004577378], 
             UndirectedEdge[108, 152] -> 
             RGBColor[
              0.2564614085339687, 0.38688757933463486`, 0.9379164698641311], 
             UndirectedEdge[86, 148] -> 
             RGBColor[
              0.37250043656006593`, 0.49706288855717573`, 0.9449563763217728],
              UndirectedEdge[113, 293] -> 
             RGBColor[
              0.32820995463660485`, 0.4585878656141067, 0.9421383573691648], 
             UndirectedEdge[229, 260] -> 
             RGBColor[
              0.21573241152320438`, 0.34407882110876054`, 0.9355970137375196],
              UndirectedEdge[6, 278] -> 
             RGBColor[
              0.28187720037590647`, 0.4136011880147874, 0.9393638616102349], 
             UndirectedEdge[142, 378] -> 
             RGBColor[
              0.18665371404405717`, 0.3135152663622699, 0.93394102493416], 
             UndirectedEdge[289, 303] -> 
             RGBColor[
              0.19970158242580874`, 0.32722940331412775`, 0.9346840817359092],
              UndirectedEdge[5, 213] -> 
             RGBColor[
              0.25252900688278906`, 0.3827543758705798, 0.9376925254075633], 
             UndirectedEdge[104, 243] -> 
             RGBColor[
              0.8691814808377128, 0.4236764403528107, 0.42271376924375914`], 
             UndirectedEdge[121, 373] -> 
             RGBColor[
              0.2913786665893785, 0.4233881080569608, 0.9399122689060947], 
             UndirectedEdge[120, 202] -> 
             RGBColor[
              0.38082926485589774`, 0.49646706771580507`, 0.9461959416990309],
              UndirectedEdge[270, 351] -> 
             RGBColor[
              0.6344443344456173, 0.7081804286544429, 0.9676800928710849], 
             UndirectedEdge[91, 125] -> 
             RGBColor[
              0.37740486226419223`, 0.49585819381446866`, 0.9457287231087954],
              UndirectedEdge[280, 297] -> 
             RGBColor[
              0.22922829336444137`, 0.3582638486122316, 0.9363655842430101], 
             UndirectedEdge[33, 281] -> 
             RGBColor[
              0.3526148324525338, 0.4768614731328931, 0.9437983042422098], 
             UndirectedEdge[16, 241] -> 
             RGBColor[
              0.29049437153587576`, 0.42182354173579545`, 0.9398851643245274],
              UndirectedEdge[89, 342] -> 
             RGBColor[
              0.18647972709604152`, 0.31333239504849575`, 0.9339311166348612],
              UndirectedEdge[157, 370] -> 
             RGBColor[
              0.18724094908895864`, 0.3141324876273136, 0.9339744671012307], 
             UndirectedEdge[90, 122] -> 
             RGBColor[
              0.6031707449782447, 0.6887202091625689, 0.9619029570133792], 
             UndirectedEdge[135, 156] -> 
             RGBColor[
              0.8856046641981132, 0.4899098319471875, 0.34486688561467355`], 
             UndirectedEdge[12, 22] -> 
             RGBColor[
              0.3123757406994519, 0.44496094634460026`, 0.9411261975051177], 
             UndirectedEdge[271, 384] -> 
             RGBColor[
              0.18432884103510522`, 0.31107167742439884`, 0.9338086268556416],
              UndirectedEdge[158, 324] -> 
             RGBColor[
              0.4859428845919035, 0.5904387279012617, 0.9535338248669657], 
             UndirectedEdge[301, 397] -> 
             RGBColor[
              0.19781003665891564`, 0.3252412687821946, 0.934576361002776], 
             UndirectedEdge[95, 233] -> 
             RGBColor[
              0.7594081345567827, 0.8112195509449376, 0.9560282891124947], 
             UndirectedEdge[123, 203] -> 
             RGBColor[
              0.21872743662810462`, 0.3472267823895703, 0.935767575986501], 
             UndirectedEdge[103, 145] -> 
             RGBColor[
              0.1958024601948291, 0.32313117863074003`, 0.9344620324930895], 
             UndirectedEdge[20, 80] -> 
             RGBColor[
              0.18504810846190303`, 0.31182767309415216`, 0.933849588071537], 
             UndirectedEdge[73, 337] -> 
             RGBColor[
              0.9623310682876794, 0.8761474788456531, 0.428220440311572], 
             UndirectedEdge[122, 166] -> 
             RGBColor[
              0.7938288566186125, 0.8372493846021647, 0.890969402038376], 
             UndirectedEdge[62, 216] -> 
             RGBColor[
              0.2004082229571123, 0.32797212731612524`, 0.934724323868786], 
             UndirectedEdge[128, 342] -> 
             RGBColor[
              0.18916310762939384`, 0.3161527981252015, 0.9340839311865298], 
             UndirectedEdge[280, 309] -> 
             RGBColor[
              0.27456630331146203`, 0.4059169716624097, 0.9389475168379178], 
             UndirectedEdge[104, 141] -> 
             RGBColor[
              0.8345385936403027, 0.25894255793118215`, 0.18041218495107442`],
              UndirectedEdge[148, 276] -> 
             RGBColor[
              0.27841767131860123`, 0.407632112720532, 0.9392522651124343], 
             UndirectedEdge[359, 394] -> 
             RGBColor[
              0.18381809529055626`, 0.3105348512637273, 0.9337795406410702], 
             UndirectedEdge[8, 43] -> 
             RGBColor[
              0.24908603513269617`, 0.379135594264215, 0.9374964532598158], 
             UndirectedEdge[56, 352] -> 
             RGBColor[
              0.31062641380180694`, 0.4370779234706822, 0.9412478898986653], 
             UndirectedEdge[70, 152] -> 
             RGBColor[
              0.2398425593336916, 0.3694201151292457, 0.9369700509875596], 
             UndirectedEdge[359, 397] -> 
             RGBColor[
              0.20006364261390616`, 0.32760995152775996`, 0.9347047005280014],
              UndirectedEdge[118, 241] -> 
             RGBColor[
              0.25104726308957875`, 0.38119696919593304`, 0.9376081422905835],
              UndirectedEdge[43, 227] -> 
             RGBColor[
              0.23391469744368304`, 0.36318955643469497`, 0.9366324680224093],
              UndirectedEdge[234, 246] -> 
             RGBColor[
              0.8529840469746812, 0.885887262707637, 0.9857660876177745], 
             UndirectedEdge[196, 317] -> 
             RGBColor[
              0.1925447584771704, 0.3197071275752621, 0.9342765111996065], 
             UndirectedEdge[46, 184] -> 
             RGBColor[
              0.19220194755564052`, 0.3193468115612663, 0.9342569886247687], 
             UndirectedEdge[136, 331] -> 
             RGBColor[
              0.19186850922797938`, 0.3189963467376835, 0.9342379998052863], 
             UndirectedEdge[106, 320] -> 
             RGBColor[
              0.21130568150236095`, 0.33942604718596003`, 0.9353449180115927],
              UndirectedEdge[68, 161] -> 
             RGBColor[
              0.23474066997997348`, 0.36405770594001974`, 0.9366795059364341],
              UndirectedEdge[45, 297] -> 
             RGBColor[
              0.2458649611438621, 0.37575004127406386`, 0.9373130178613036], 
             UndirectedEdge[140, 203] -> 
             RGBColor[
              0.22572809779654535`, 0.3545849211451561, 0.9361662532834936], 
             UndirectedEdge[225, 243] -> 
             RGBColor[
              0.9271182354136238, 0.9438506209861709, 0.9626670150045318], 
             UndirectedEdge[107, 373] -> 
             RGBColor[
              0.31023491732991126`, 0.43972044470569116`, 0.9411137725293536],
              UndirectedEdge[187, 321] -> 
             RGBColor[
              0.494640933100008, 0.6001112786340405, 0.9534971170641517], 
             UndirectedEdge[297, 322] -> 
             RGBColor[
              0.2034128145640179, 0.33113014359709375`, 0.9348954309159043], 
             UndirectedEdge[106, 374] -> 
             RGBColor[
              0.2085188963433679, 0.336496959291474, 0.9351862147194673], 
             UndirectedEdge[154, 383] -> 
             RGBColor[
              0.20693321063768522`, 0.33483030307652095`, 0.9350959122643404],
              UndirectedEdge[111, 151] -> 
             RGBColor[
              0.1906348725141942, 0.31769971633440997`, 0.9341677460194382], 
             UndirectedEdge[79, 227] -> 
             RGBColor[
              0.21925675873838124`, 0.34778313348843115`, 0.9357977200976195],
              UndirectedEdge[93, 290] -> 
             RGBColor[
              0.21626873884937514`, 0.3446425351336826, 0.9356275567853198], 
             UndirectedEdge[150, 283] -> 
             RGBColor[
              0.2012631111576979, 0.32887066901798323`, 0.9347730084871156], 
             UndirectedEdge[46, 195] -> 
             RGBColor[
              0.2015708688653357, 0.3291941418816762, 0.9347905348332788], 
             UndirectedEdge[73, 177] -> 
             RGBColor[
              0.912733918365472, 0.8408075046276462, 0.6264313427993702], 
             UndirectedEdge[102, 189] -> 
             RGBColor[
              0.27205731447598563`, 0.4032798653172439, 0.9388046336354536], 
             UndirectedEdge[3, 95] -> 
             RGBColor[
              0.5706393994295823, 0.6623097973257487, 0.9593419703255434], 
             UndirectedEdge[39, 294] -> 
             RGBColor[
              0.18656769797512113`, 0.31342485802008435`, 0.9339361264462835],
              UndirectedEdge[5, 227] -> 
             RGBColor[
              0.24495455926499354`, 0.3747931511765599, 0.937261171821121], 
             UndirectedEdge[166, 169] -> 
             RGBColor[
              0.9427417968791698, 0.9548740993356628, 0.9051840770091248], 
             UndirectedEdge[27, 337] -> 
             RGBColor[
              0.8787077642296014, 0.4383681461657731, 0.30965677054087426`], 
             UndirectedEdge[84, 174] -> 
             RGBColor[
              0.3414171398675645, 0.4701400992540484, 0.9429757761424066], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.313125811057198, 0.4456106195888476, 0.9411739913250522], 
             UndirectedEdge[138, 349] -> 
             RGBColor[
              0.19211902352341417`, 0.31925965314570914`, 0.9342522662238085],
              UndirectedEdge[26, 159] -> 
             RGBColor[
              0.18375580691440718`, 0.3104693822310835, 0.9337759934101959], 
             UndirectedEdge[81, 287] -> 
             RGBColor[
              0.1847451216726243, 0.31150921476814825`, 0.9338323334221164], 
             UndirectedEdge[311, 361] -> 
             RGBColor[
              0.2601900040751639, 0.39080656965504246`, 0.9381288078642394], 
             UndirectedEdge[231, 393] -> 
             RGBColor[
              0.18277810360197083`, 0.30944175405974256`, 0.933720314652935], 
             UndirectedEdge[201, 223] -> 
             RGBColor[
              0.9394729571932308, 0.8606549580209606, 0.6167978110210142], 
             UndirectedEdge[180, 267] -> 
             RGBColor[
              0.25726504669656514`, 0.3877322539971262, 0.9379622358686148], 
             UndirectedEdge[217, 264] -> 
             RGBColor[
              0.8581806271651595, 0.8856725444548357, 0.7300501263511203], 
             UndirectedEdge[163, 174] -> 
             RGBColor[
              0.3053955889489409, 0.4350613598921163, 0.9408225323352425], 
             UndirectedEdge[203, 280] -> 
             RGBColor[
              0.23864655232395315`, 0.36816303593078636`, 0.9369019401576887],
              UndirectedEdge[40, 163] -> 
             RGBColor[
              0.3939273213258807, 0.5099037447255685, 0.9469719144794696], 
             UndirectedEdge[14, 62] -> 
             RGBColor[
              0.1928274082051604, 0.3200042103604074, 0.9342926076834728], 
             UndirectedEdge[49, 133] -> 
             RGBColor[
              0.18673252269027052`, 0.31359809924619686`, 0.933945512969975], 
             UndirectedEdge[276, 288] -> 
             RGBColor[
              0.2641141546829352, 0.39493110074932897`, 0.9383522824360913], 
             UndirectedEdge[312, 366] -> 
             RGBColor[
              0.3486542052668462, 0.4758688117654473, 0.9434566755048852], 
             UndirectedEdge[23, 120] -> 
             RGBColor[
              0.40567769043424073`, 0.5225843384798207, 0.9476110227757661], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.18052420551329257`, 0.307072764263149, 0.9335919584911282], 
             UndirectedEdge[73, 399] -> 
             RGBColor[
              0.9285956897332439, 0.7546127344078406, 0.2614046197660328], 
             UndirectedEdge[269, 272] -> 
             RGBColor[
              0.7422573926850033, 0.7985763836214297, 0.9749449381792838], 
             UndirectedEdge[20, 151] -> 
             RGBColor[
              0.19115376674236922`, 0.3182451070680162, 0.9341972962780976], 
             UndirectedEdge[239, 355] -> 
             RGBColor[
              0.8070776560597501, 0.415234178503891, 0.4419068004978779], 
             UndirectedEdge[274, 319] -> 
             RGBColor[
              0.47322013025663245`, 0.583220445923085, 0.9516727685977074], 
             UndirectedEdge[6, 352] -> 
             RGBColor[
              0.27259546821957914`, 0.40384549902267874`, 0.9388352806950242],
              UndirectedEdge[133, 342] -> 
             RGBColor[
              0.18475081584068775`, 0.311515199699814, 0.9338326576965637], 
             UndirectedEdge[290, 318] -> 
             RGBColor[
              0.1963038433293812, 0.3236581640946811, 0.9344905855208723], 
             UndirectedEdge[87, 298] -> 
             RGBColor[
              0.19758831891525655`, 0.325008229375892, 0.9345637345052766], 
             UndirectedEdge[86, 263] -> 
             RGBColor[
              0.4014876492319413, 0.5221701552338829, 0.9468034158808389], 
             UndirectedEdge[109, 191] -> 
             RGBColor[
              0.19427315985261398`, 0.3215237870078299, 0.9343749411009974], 
             UndirectedEdge[84, 238] -> 
             RGBColor[
              0.3144100017377778, 0.44501303039307516`, 0.9413184262912844], 
             UndirectedEdge[21, 244] -> 
             RGBColor[
              0.9589837634229517, 0.9266594522436353, 0.6365010356742713], 
             UndirectedEdge[137, 175] -> 
             RGBColor[
              0.3080574204607164, 0.43874050226861905`, 0.940941847744563], 
             UndirectedEdge[363, 369] -> 
             RGBColor[
              0.20524927327278905`, 0.33306037813821954`, 0.9350000145225716],
              UndirectedEdge[98, 290] -> 
             RGBColor[
              0.19961632362064485`, 0.32713979090418005`, 0.9346792263730843],
              UndirectedEdge[175, 352] -> 
             RGBColor[
              0.2606268889022622, 0.3912657633084208, 0.9381536878088295], 
             UndirectedEdge[121, 319] -> 
             RGBColor[
              0.3821339767558598, 0.5054057883182604, 0.9455705453873072], 
             UndirectedEdge[249, 387] -> 
             RGBColor[
              0.4216012233503626, 0.5373973944320252, 0.9486912790769737], 
             UndirectedEdge[310, 389] -> 
             RGBColor[
              0.24112387106664201`, 0.3707668550004327, 0.9370430197952202], 
             UndirectedEdge[228, 238] -> 
             RGBColor[
              0.24678874654536498`, 0.3767209983024208, 0.9373656260733012], 
             UndirectedEdge[268, 324] -> 
             RGBColor[
              0.6562462626397825, 0.7312424529611288, 0.9664688163111557], 
             UndirectedEdge[144, 368] -> 
             RGBColor[
              0.18786109875542928`, 0.31478430424653414`, 0.934009783707307], 
             UndirectedEdge[137, 278] -> 
             RGBColor[
              0.29631468313808673`, 0.42639814080998684`, 0.9402731162258624],
              UndirectedEdge[127, 298] -> 
             RGBColor[
              0.19590091614963856`, 0.32323466208171286`, 0.9344676394140633],
              UndirectedEdge[131, 228] -> 
             RGBColor[
              0.20842587898456535`, 0.33639919214973135`, 0.9351809175184903],
              UndirectedEdge[278, 314] -> 
             RGBColor[
              0.2454200867859244, 0.3752824501172079, 0.9372876829247517], 
             UndirectedEdge[182, 311] -> 
             RGBColor[
              0.32563786800336725`, 0.45591796242171545`, 0.9419906534014555],
              UndirectedEdge[77, 94] -> 
             RGBColor[
              0.18199794707454847`, 0.3086217600846408, 0.9336758858928365], 
             UndirectedEdge[144, 333] -> 
             RGBColor[
              0.1893313874669234, 0.316329670904003, 0.9340935144743294], 
             UndirectedEdge[166, 197] -> 
             RGBColor[
              0.9770032019247867, 0.9814553758280588, 0.8828706575837489], 
             UndirectedEdge[106, 384] -> 
             RGBColor[
              0.2081882862900271, 0.33614946716352473`, 0.9351673869660233], 
             UndirectedEdge[28, 265] -> 
             RGBColor[
              0.1984857219314811, 0.32595145684458154`, 0.9346148402794617], 
             UndirectedEdge[113, 266] -> 
             RGBColor[
              0.2701389734664643, 0.40126356728639195`, 0.9386953869528927], 
             UndirectedEdge[164, 292] -> 
             RGBColor[
              0.19766905263223078`, 0.3250930856312453, 0.9345683321710234], 
             UndirectedEdge[98, 248] -> 
             RGBColor[
              0.2095071320406308, 0.3375356576670594, 0.9352424932804627], 
             UndirectedEdge[91, 95] -> 
             RGBColor[
              0.5263538722152581, 0.6263568112928946, 0.9558556514000003], 
             UndirectedEdge[155, 342] -> 
             RGBColor[
              0.19539787597679303`, 0.32270593496546307`, 0.9344389920204009],
              UndirectedEdge[47, 209] -> 
             RGBColor[
              0.43947307837840166`, 0.5526061814054317, 0.9499049126595958], 
             UndirectedEdge[2, 360] -> 
             RGBColor[
              0.18511749831467772`, 0.3119006062289892, 0.9338535397209994], 
             UndirectedEdge[75, 341] -> 
             RGBColor[
              0.2771008643732843, 0.406039405513939, 0.9391849149556509], 
             UndirectedEdge[12, 390] -> 
             RGBColor[
              0.28559351861557547`, 0.41750727411286515`, 0.9395755004361839],
              UndirectedEdge[19, 198] -> 
             RGBColor[
              0.30685620721234774`, 0.43573562617248035`, 0.9409372354734161],
              UndirectedEdge[8, 56] -> 
             RGBColor[
              0.30973133616006665`, 0.43613714011801286`, 0.9411969165511169],
              UndirectedEdge[70, 154] -> 
             RGBColor[
              0.21421417432422896`, 0.3424830575508392, 0.9355105523750686], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.18749255911212426`, 0.3143969457146576, 0.9339887959198263], 
             UndirectedEdge[177, 243] -> 
             RGBColor[
              0.9321893579727436, 0.9478941964628581, 0.9631507032012652], 
             UndirectedEdge[109, 340] -> 
             RGBColor[
              0.19212863805325098`, 0.319269758626164, 0.9342528137570594], 
             UndirectedEdge[28, 36] -> 
             RGBColor[
              0.19993330434376533`, 0.3274729577419183, 0.9346972779563351], 
             UndirectedEdge[203, 339] -> 
             RGBColor[
              0.23865240959631934`, 0.3681691922954158, 0.9369022737206849], 
             UndirectedEdge[247, 369] -> 
             RGBColor[
              0.19411283179141248`, 0.32135527205012093`, 0.934365810655096], 
             UndirectedEdge[223, 230] -> 
             RGBColor[
              0.8551262609512963, 0.3448308384131614, 0.19723163473259725`], 
             UndirectedEdge[22, 173] -> 
             RGBColor[
              0.2993775960909632, 0.43129907223111097`, 0.940385972398696], 
             UndirectedEdge[69, 283] -> 
             RGBColor[
              0.22539830685763262`, 0.3542382899584056, 0.9361474721774046], 
             UndirectedEdge[59, 274] -> 
             RGBColor[
              0.41979531196311004`, 0.5369477420873823, 0.9482682580148925], 
             UndirectedEdge[31, 164] -> 
             RGBColor[
              0.19871454021211585`, 0.32619195936544565`, 0.9346278711420376],
              UndirectedEdge[116, 154] -> 
             RGBColor[
              0.19442534169189124`, 0.3216837397697962, 0.9343836076316113], 
             UndirectedEdge[10, 170] -> 
             RGBColor[
              0.2345826966210814, 0.3638916659237347, 0.936670509587346], 
             UndirectedEdge[301, 394] -> 
             RGBColor[
              0.18156448933556574`, 0.30816616851816203`, 0.9336512011158447],
              UndirectedEdge[90, 351] -> 
             RGBColor[
              0.7590840463718008, 0.8119268218437792, 0.9767853326782896], 
             UndirectedEdge[4, 203] -> 
             RGBColor[
              0.22928794206914588`, 0.35832654318282237`, 0.9363689811485005],
              UndirectedEdge[274, 351] -> 
             RGBColor[
              0.7014339552406084, 0.7651238807564681, 0.9722469063252], 
             UndirectedEdge[238, 269] -> 
             RGBColor[
              0.5167818424220354, 0.6108654129881752, 0.9574511707265], 
             UndirectedEdge[66, 325] -> 
             RGBColor[
              0.2517049597881912, 0.3818882501265539, 0.9376455971445944], 
             UndirectedEdge[128, 171] -> 
             RGBColor[
              0.19178726559275905`, 0.3189109545259229, 0.9342333731004496], 
             UndirectedEdge[198, 205] -> 
             RGBColor[
              0.35166297002886326`, 0.47901452236936815`, 0.9436286313802527],
              UndirectedEdge[202, 349] -> 
             RGBColor[
              0.22267250403179975`, 0.35137329836257414`, 0.9359922417389372],
              UndirectedEdge[295, 390] -> 
             RGBColor[
              0.34587288956677426`, 0.46974318811470905`, 0.943415535012837], 
             UndirectedEdge[250, 356] -> 
             RGBColor[
              0.22666963106636354`, 0.3555745323083922, 0.9362198722103361], 
             UndirectedEdge[133, 393] -> 
             RGBColor[
              0.18457522111446595`, 0.3113306385092063, 0.9338226578366745], 
             UndirectedEdge[124, 293] -> 
             RGBColor[
              0.3293119680498331, 0.45965520784915576`, 0.9422044452983639], 
             UndirectedEdge[45, 325] -> 
             RGBColor[
              0.2869742607531359, 0.4189585216435491, 0.9396541316582929], 
             UndirectedEdge[116, 304] -> 
             RGBColor[
              0.18211433978369124`, 0.30874409620167387`, 0.9336825142854346],
              UndirectedEdge[213, 296] -> 
             RGBColor[
              0.2337895217777734, 0.3630579888732283, 0.9366253394534165], 
             UndirectedEdge[248, 276] -> 
             RGBColor[
              0.22042799245848094`, 0.3490141743887628, 0.9358644201252941], 
             UndirectedEdge[209, 346] -> 
             RGBColor[
              0.34295446203942725`, 0.47147165045125694`, 0.9430737329517971],
              UndirectedEdge[31, 382] -> 
             RGBColor[
              0.18918398084593196`, 0.3161747371992214, 0.9340851198853325], 
             UndirectedEdge[69, 373] -> 
             RGBColor[
              0.25683371538447886`, 0.38727889744013877`, 0.937937672188489], 
             UndirectedEdge[166, 239] -> 
             RGBColor[
              0.8817402416283486, 0.4729378739656097, 0.3896280153376859], 
             UndirectedEdge[235, 317] -> 
             RGBColor[
              0.19343401255220036`, 0.32064178999008336`, 0.934327152903646], 
             UndirectedEdge[43, 59] -> 
             RGBColor[
              0.3034359716582913, 0.4327690861148492, 0.9407194513531689], 
             UndirectedEdge[94, 207] -> 
             RGBColor[
              0.18447193191249567`, 0.3112220750090219, 0.933816775669425], 
             UndirectedEdge[209, 270] -> 
             RGBColor[
              0.34697087401529814`, 0.4749504646340207, 0.9433296551713259], 
             UndirectedEdge[23, 341] -> 
             RGBColor[
              0.3146456284168403, 0.44550133299924655`, 0.9413230337254305], 
             UndirectedEdge[264, 312] -> 
             RGBColor[
              0.5131003370105822, 0.6097335825641022, 0.9568081018654329], 
             UndirectedEdge[48, 118] -> 
             RGBColor[
              0.23953466514577643`, 0.3690964988161278, 0.9369525168690463], 
             UndirectedEdge[106, 310] -> 
             RGBColor[
              0.2532088981789974, 0.38346898473049273`, 0.9377312442110733], 
             UndirectedEdge[267, 282] -> 
             RGBColor[
              0.2615646860965489, 0.39225144761939246`, 0.9382070939716974], 
             UndirectedEdge[43, 274] -> 
             RGBColor[
              0.3767191464303865, 0.4951636983486218, 0.9456872845015338], 
             UndirectedEdge[46, 362] -> 
             RGBColor[
              0.19522925834887567`, 0.3225287071475469, 0.9344293894959386], 
             UndirectedEdge[38, 117] -> 
             RGBColor[
              0.22453541604736282`, 0.35333133700637476`, 0.9360983318222922],
              UndirectedEdge[252, 300] -> 
             RGBColor[
              0.6421328397168371, 0.7146709767757251, 0.9682477279637229], 
             UndirectedEdge[7, 67] -> 
             RGBColor[
              0.43693392935130804`, 0.5528719414914377, 0.9490620215061302], 
             UndirectedEdge[150, 192] -> 
             RGBColor[
              0.1875835174154828, 0.3144925486585769, 0.9339939758606419], 
             UndirectedEdge[239, 272] -> 
             RGBColor[
              0.7988197048562442, 0.4087830042609585, 0.441083725096854], 
             UndirectedEdge[22, 209] -> 
             RGBColor[
              0.32555893410641223`, 0.4564045184803353, 0.9419653052941668], 
             UndirectedEdge[167, 246] -> 
             RGBColor[
              0.6152498673613919, 0.6911955828537762, 0.9666225650716829], 
             UndirectedEdge[131, 140] -> 
             RGBColor[
              0.21947779992995464`, 0.3480154617955958, 0.9358103080664784], 
             UndirectedEdge[67, 385] -> 
             RGBColor[
              0.7098239251190117, 0.7666063809986858, 0.7914621261134387], 
             UndirectedEdge[60, 101] -> 
             RGBColor[
              0.18455258152934814`, 0.31130684286981486`, 0.9338213685457943],
              UndirectedEdge[113, 249] -> 
             RGBColor[
              0.3083010067824331, 0.4413437356356376, 0.9408697768166884], 
             UndirectedEdge[52, 393] -> 
             RGBColor[
              0.18136432541177624`, 0.30795578354313347`, 0.9336398020765009],
              UndirectedEdge[99, 367] -> 
             RGBColor[
              0.6703595369678017, 0.7365958473458555, 0.9440864000727226], 
             UndirectedEdge[5, 43] -> 
             RGBColor[
              0.2713996679468782, 0.4025886371179538, 0.9387671816385219], 
             UndirectedEdge[26, 105] -> 
             RGBColor[
              0.19823757833601402`, 0.32569064219253296`, 0.9346007088687955],
              UndirectedEdge[128, 306] -> 
             RGBColor[
              0.1986620698216136, 0.3261368096582128, 0.9346248830309214], 
             UndirectedEdge[226, 281] -> 
             RGBColor[
              0.43696413947427415`, 0.552898107981546, 0.9490639464684518], 
             UndirectedEdge[63, 345] -> 
             RGBColor[
              0.18008431245353695`, 0.306610408766515, 0.9335669072321386], 
             UndirectedEdge[4, 280] -> 
             RGBColor[
              0.24217745234544014`, 0.3718742357253608, 0.937103019690414], 
             UndirectedEdge[7, 223] -> 
             RGBColor[
              0.6892737381041355, 0.6614040887409706, 0.6061320446993241], 
             UndirectedEdge[155, 361] -> 
             RGBColor[
              0.21235865222551553`, 0.3405327861781953, 0.9354048831365458], 
             UndirectedEdge[252, 398] -> 
             RGBColor[
              0.39783022825914727`, 0.5190022810145718, 0.9465703682505828], 
             UndirectedEdge[6, 252] -> 
             RGBColor[
              0.3375773650971563, 0.4665223484650306, 0.9427417981088295], 
             UndirectedEdge[260, 307] -> 
             RGBColor[
              0.28646815305242945`, 0.41476449327789777`, 0.9397593961545982],
              UndirectedEdge[21, 357] -> 
             RGBColor[
              0.892467694136608, 0.589114704834069, 0.2387243833179241], 
             UndirectedEdge[233, 366] -> 
             RGBColor[
              0.6769028781273625, 0.7426382888986862, 0.9499751965434602], 
             UndirectedEdge[37, 41] -> 
             RGBColor[
              0.6103348144421008, 0.6886019294831773, 0.9655435733376975], 
             UndirectedEdge[173, 176] -> 
             RGBColor[
              0.25807437232061936`, 0.38858290654221544`, 0.9380083257656147],
              UndirectedEdge[60, 136] -> 
             RGBColor[
              0.18529719032077357`, 0.3120894739205271, 0.933863772914916], 
             UndirectedEdge[74, 285] -> 
             RGBColor[
              0.9286295448374513, 0.9418226643023089, 0.7983899704135337], 
             UndirectedEdge[234, 395] -> 
             RGBColor[
              0.6271808306424103, 0.7060165287006694, 0.9652946384160161], 
             UndirectedEdge[17, 164] -> 
             RGBColor[
              0.21631448031938844`, 0.34469061231884324`, 0.9356301616943686],
              UndirectedEdge[20, 383] -> 
             RGBColor[
              0.1993210537450841, 0.3268294435437743, 0.9346624111904838], 
             UndirectedEdge[19, 219] -> 
             RGBColor[
              0.2987647907941907, 0.4287272479574868, 0.9404216575742097], 
             UndirectedEdge[91, 279] -> 
             RGBColor[
              0.5827660155833214, 0.6716970806233367, 0.9606095197706748], 
             UndirectedEdge[76, 207] -> 
             RGBColor[
              0.1908268877624048, 0.3179015365347492, 0.9341786810037627], 
             UndirectedEdge[238, 339] -> 
             RGBColor[
              0.27076497929052823`, 0.4019215390985449, 0.9387310370584805], 
             UndirectedEdge[142, 379] -> 
             RGBColor[
              0.1947953347030193, 0.32207262588340363`, 0.9344046781862394], 
             UndirectedEdge[205, 219] -> 
             RGBColor[
              0.34357155361070624`, 0.4720061441543746, 0.9431130534810463], 
             UndirectedEdge[7, 68] -> 
             RGBColor[
              0.3593357938245753, 0.4820804322688437, 0.9442486147652995], 
             UndirectedEdge[188, 273] -> 
             RGBColor[
              0.19180481699179464`, 0.3189294021591323, 0.9342343726266598], 
             UndirectedEdge[16, 69] -> 
             RGBColor[
              0.2797958916834022, 0.41057876108804503`, 0.9392759017239116], 
             UndirectedEdge[118, 323] -> 
             RGBColor[
              0.3187861771861727, 0.44407882697168544`, 0.9417702640466686], 
             UndirectedEdge[211, 263] -> 
             RGBColor[
              0.30692109574993276`, 0.4322308872824815, 0.9410717536469021], 
             UndirectedEdge[191, 340] -> 
             RGBColor[
              0.2050792556090335, 0.33288167879387, 0.9349903322681394], 
             UndirectedEdge[33, 182] -> 
             RGBColor[
              0.3125367270389322, 0.44214783260778046`, 0.9412445628049322], 
             UndirectedEdge[99, 300] -> 
             RGBColor[
              0.9401681906865148, 0.9543565949425481, 0.9673889822446275], 
             UndirectedEdge[11, 91] -> 
             RGBColor[
              0.40263125450178067`, 0.5220751425472069, 0.9471762250170271], 
             UndirectedEdge[78, 233] -> 
             RGBColor[
              0.8664271702758672, 0.42591833001448076`, 0.4290165805257541], 
             UndirectedEdge[27, 172] -> 
             RGBColor[
              0.8219598998063007, 0.16979898956648984`, 0.1686621308956602], 
             UndirectedEdge[313, 396] -> 
             RGBColor[
              0.20896253735329678`, 0.3369632541213739, 0.9352114794186747], 
             UndirectedEdge[74, 172] -> 
             RGBColor[
              0.8368888345678879, 0.4205266273042264, 0.4425517456269674], 
             UndirectedEdge[217, 366] -> 
             RGBColor[
              0.6937344954214235, 0.7518077736561808, 0.7166986999905727], 
             UndirectedEdge[277, 302] -> 
             RGBColor[
              0.19959521355734036`, 0.32711760288919167`, 0.9346780241862087],
              UndirectedEdge[203, 232] -> 
             RGBColor[
              0.26042493590475796`, 0.3910534979034842, 0.9381421868843842], 
             UndirectedEdge[27, 285] -> 
             RGBColor[
              0.8787585038612737, 0.43847667310735655`, 0.31517946631969995`],
              UndirectedEdge[193, 334] -> 
             RGBColor[
              0.1859629402627897, 0.3127892193205704, 0.9339016863892251], 
             UndirectedEdge[39, 381] -> 
             RGBColor[
              0.18966952552711056`, 0.31668507544445096`, 0.9341127709366266],
              UndirectedEdge[270, 390] -> 
             RGBColor[
              0.310905083152461, 0.4394558317316838, 0.9411874173089341], 
             UndirectedEdge[35, 42] -> 
             RGBColor[
              0.22638274960055194`, 0.35527300169848874`, 0.9362035347352613],
              UndirectedEdge[41, 245] -> 
             RGBColor[
              0.8365103724506917, 0.3973845200409797, 0.4396570019745871], 
             UndirectedEdge[45, 276] -> 
             RGBColor[
              0.2538332616499947, 0.38412523032544144`, 0.9377668007870836], 
             UndirectedEdge[17, 241] -> 
             RGBColor[
              0.2474447922190557, 0.37741054390116785`, 0.9374029869038852], 
             UndirectedEdge[69, 347] -> 
             RGBColor[
              0.21983376516516337`, 0.34838960382729967`, 0.9358305797600202],
              UndirectedEdge[16, 295] -> 
             RGBColor[
              0.3734051820083968, 0.4978465335906915, 0.9450140259017055], 
             UndirectedEdge[190, 351] -> 
             RGBColor[
              0.9330043693197932, 0.948887212220239, 0.9751255904637988], 
             UndirectedEdge[112, 141] -> 
             RGBColor[
              0.8894343136228475, 0.5845146463127493, 0.22912699183884946`], 
             UndirectedEdge[135, 400] -> 
             RGBColor[
              0.8983997399580361, 0.588258391075905, 0.357119464612347], 
             UndirectedEdge[295, 310] -> 
             RGBColor[
              0.3543169737444146, 0.4786184559712684, 0.9438964131148506], 
             UndirectedEdge[185, 249] -> 
             RGBColor[
              0.35433837255967027`, 0.48133182157191207`, 0.9437991056637501],
              UndirectedEdge[93, 98] -> 
             RGBColor[
              0.21766781953393055`, 0.3461130576399892, 0.9357072323605509], 
             UndirectedEdge[221, 268] -> 
             RGBColor[
              0.7908356351545234, 0.6993648502734382, 0.6044361277879526], 
             UndirectedEdge[265, 291] -> 
             RGBColor[
              0.18857894058274138`, 0.31553880152083974`, 0.9340506637374206],
              UndirectedEdge[128, 133] -> 
             RGBColor[
              0.19019948162046302`, 0.31724209289972144`, 0.9341429511521433],
              UndirectedEdge[57, 333] -> 
             RGBColor[
              0.2028967340448986, 0.3305877102501046, 0.9348660408938132], 
             UndirectedEdge[28, 378] -> 
             RGBColor[
              0.19890365407675165`, 0.32639073002768937`, 0.9346386408968597],
              UndirectedEdge[92, 386] -> 
             RGBColor[
              0.6290755332185833, 0.7079371215448762, 0.9651823556220622], 
             UndirectedEdge[35, 248] -> 
             RGBColor[
              0.22712519699410227`, 0.3560533609829937, 0.9362458160159715], 
             UndirectedEdge[56, 175] -> 
             RGBColor[
              0.331650883280764, 0.45917597392142306`, 0.9424452023325764], 
             UndirectedEdge[3, 21] -> 
             RGBColor[
              0.7725354937206939, 0.7794802979389553, 0.6358867741972027], 
             UndirectedEdge[98, 204] -> 
             RGBColor[
              0.19732498772567109`, 0.3247314515994759, 0.9345487381835933], 
             UndirectedEdge[243, 367] -> 
             RGBColor[
              0.6723041775720541, 0.7380461571244501, 0.9407946307732227], 
             UndirectedEdge[48, 209] -> 
             RGBColor[
              0.2875152720132881, 0.41711435878234465`, 0.9397732858765137], 
             UndirectedEdge[116, 291] -> 
             RGBColor[
              0.1852566513830322, 0.31204686492664385`, 0.9338614642823836], 
             UndirectedEdge[214, 340] -> 
             RGBColor[
              0.22133989504081186`, 0.3499726418207558, 0.9359163516283189], 
             UndirectedEdge[138, 159] -> 
             RGBColor[
              0.18138230828610377`, 0.30797468468423184`, 0.9336408261745905],
              UndirectedEdge[22, 48] -> 
             RGBColor[
              0.27823170323432733`, 0.40907339811174287`, 0.9391817450830557],
              UndirectedEdge[13, 297] -> 
             RGBColor[
              0.2105416090442786, 0.33862295858752356`, 0.9353014052154489], 
             UndirectedEdge[192, 347] -> 
             RGBColor[
              0.18973620095672017`, 0.3167551555484371, 0.9341165680037053], 
             UndirectedEdge[4, 322] -> 
             RGBColor[
              0.21636197354501668`, 0.3447405307102229, 0.9356328663633082], 
             UndirectedEdge[111, 304] -> 
             RGBColor[
              0.18507047905985996`, 0.31185118601098283`, 0.9338508620439963],
              UndirectedEdge[133, 361] -> 
             RGBColor[
              0.20171159208941025`, 0.3293420509125463, 0.9347985488127086], 
             UndirectedEdge[4, 186] -> 
             RGBColor[
              0.2198352252877424, 0.3483911385087073, 0.9358306629118409], 
             UndirectedEdge[73, 240] -> 
             RGBColor[
              0.8646643880160767, 0.41726031379920236`, 0.20632898974830338`],
              UndirectedEdge[82, 335] -> 
             RGBColor[
              0.18011477786530028`, 0.30664242984589696`, 0.933568642192269], 
             UndirectedEdge[184, 372] -> 
             RGBColor[
              0.18858940025952037`, 0.31554979530431626`, 0.9340512594005395],
              UndirectedEdge[85, 340] -> 
             RGBColor[
              0.22184000451345684`, 0.35049828858527765`, 0.9359448321229403],
              UndirectedEdge[344, 388] -> 
             RGBColor[
              0.20538183242077535`, 0.3331997062074885, 0.9350075635699459], 
             UndirectedEdge[57, 228] -> 
             RGBColor[
              0.21063806848440092`, 0.33872434357497383`, 0.9353068984378649],
              UndirectedEdge[36, 80] -> 
             RGBColor[
              0.1863429465695527, 0.31318863004276976`, 0.9339233271862263], 
             UndirectedEdge[88, 365] -> 
             RGBColor[
              0.18619994968916187`, 0.3130383312549531, 0.9339151837254329], 
             UndirectedEdge[209, 241] -> 
             RGBColor[
              0.2990278699570904, 0.4292148291621499, 0.9404289112980508], 
             UndirectedEdge[49, 62] -> 
             RGBColor[
              0.19439182652115503`, 0.3216485132003679, 0.9343816989922191], 
             UndirectedEdge[161, 250] -> 
             RGBColor[
              0.22890128499152032`, 0.3579201420787632, 0.9363469615999377], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.19292841019979173`, 0.32011036986066127`, 0.934298359597648], 
             UndirectedEdge[324, 346] -> 
             RGBColor[
              0.4920980261552287, 0.5957700021570038, 0.9539260250446029], 
             UndirectedEdge[142, 258] -> 
             RGBColor[
              0.18294835007904106`, 0.30962069390139346`, 0.9337300099379471],
              UndirectedEdge[44, 46] -> 
             RGBColor[
              0.2189840028439955, 0.34749644974970917`, 0.9357821870529404], 
             UndirectedEdge[85, 191] -> 
             RGBColor[
              0.22398452631281984`, 0.35275231696694354`, 0.9360669594668783],
              UndirectedEdge[112, 172] -> 
             RGBColor[
              0.8615714412625748, 0.3854319686876351, 0.20303610853129658`], 
             UndirectedEdge[133, 298] -> 
             RGBColor[
              0.1913924314057353, 0.3184959587614276, 0.9342108878776034], 
             UndirectedEdge[26, 215] -> 
             RGBColor[
              0.18499791179933114`, 0.3117749132191369, 0.9338467294458628], 
             UndirectedEdge[127, 129] -> 
             RGBColor[
              0.19194623803100921`, 0.3190780446379586, 0.9342424263456293], 
             UndirectedEdge[172, 225] -> 
             RGBColor[
              0.8441055756294294, 0.42628106073348204`, 0.44324008483187805`],
              UndirectedEdge[38, 376] -> 
             RGBColor[
              0.21626586560617583`, 0.3446395151729059, 0.9356273931583702], 
             UndirectedEdge[158, 346] -> 
             RGBColor[
              0.34491127963015633`, 0.47316654749583464`, 0.9431984196383325],
              UndirectedEdge[340, 370] -> 
             RGBColor[
              0.19501122587610803`, 0.3222995411946109, 0.9344169728691645], 
             UndirectedEdge[44, 266] -> 
             RGBColor[
              0.23471345152571355`, 0.36402909761884283`, 0.9366779558857301],
              UndirectedEdge[183, 238] -> 
             RGBColor[
              0.31998454354214334`, 0.4498414183193987, 0.9416736311656848], 
             UndirectedEdge[21, 264] -> 
             RGBColor[
              0.8432468849976082, 0.8356472056673055, 0.6423010818703361], 
             UndirectedEdge[13, 140] -> 
             RGBColor[
              0.2199309237526768, 0.34849172366298653`, 0.9358361127978458], 
             UndirectedEdge[210, 266] -> 
             RGBColor[
              0.26920304414348, 0.40027984622658896`, 0.9386420871625321], 
             UndirectedEdge[51, 395] -> 
             RGBColor[
              0.4251084428470847, 0.5422133005057554, 0.9484234537100807], 
             UndirectedEdge[358, 372] -> 
             RGBColor[
              0.19242209071206384`, 0.3195781959765495, 0.9342695254518545], 
             UndirectedEdge[174, 309] -> 
             RGBColor[
              0.32079650085916334`, 0.45124869478397367`, 0.9416995914849222],
              UndirectedEdge[65, 363] -> 
             RGBColor[
              0.25392355034044856`, 0.38422012946374207`, 0.9377719425944349],
              UndirectedEdge[236, 267] -> 
             RGBColor[
              0.25338105975763014`, 0.38364993746531034`, 0.9377410485582862],
              UndirectedEdge[227, 352] -> 
             RGBColor[
              0.22353600409255178`, 0.3522808916754905, 0.9360414167899633], 
             UndirectedEdge[2, 370] -> 
             RGBColor[
              0.18603673488354355`, 0.3128667821458319, 0.9339058888837076], 
             UndirectedEdge[17, 354] -> 
             RGBColor[
              0.2237645258481464, 0.35252108252973663`, 0.9360544307658767], 
             UndirectedEdge[133, 306] -> 
             RGBColor[
              0.1942497780329075, 0.32149921123282543`, 0.9343736095409554], 
             UndirectedEdge[105, 261] -> 
             RGBColor[
              0.23472290345765154`, 0.3640390321985968, 0.9366784941592712], 
             UndirectedEdge[120, 206] -> 
             RGBColor[
              0.624306194339526, 0.7045315727086937, 0.9644880050917888], 
             UndirectedEdge[361, 393] -> 
             RGBColor[
              0.20049962337211924`, 0.32806819494741857`, 0.934729528987206], 
             UndirectedEdge[270, 295] -> 
             RGBColor[
              0.3940670515595366, 0.5157428065001295, 0.9463305819589302], 
             UndirectedEdge[9, 283] -> 
             RGBColor[
              0.2000074908485974, 0.3275509324621929, 0.9347015027680361], 
             UndirectedEdge[43, 122] -> 
             RGBColor[
              0.42916131354223347`, 0.5377386121027248, 0.9498157239985662], 
             UndirectedEdge[127, 336] -> 
             RGBColor[
              0.18757872554421223`, 0.31448751209804937`, 0.933993702970662], 
             UndirectedEdge[4, 123] -> 
             RGBColor[
              0.2222583366495916, 0.3509379821841447, 0.9359686555192263], 
             UndirectedEdge[45, 279] -> 
             RGBColor[
              0.4785218001436983, 0.5802784243797845, 0.9537482634423509], 
             UndirectedEdge[135, 255] -> 
             RGBColor[
              0.8885216832896912, 0.5123313189309725, 0.3476602263910705], 
             UndirectedEdge[152, 180] -> 
             RGBColor[
              0.2576563148367751, 0.3881435016203197, 0.9379845180103705], 
             UndirectedEdge[48, 68] -> 
             RGBColor[
              0.2551071510734325, 0.38546416887872903`, 0.937839346905198], 
             UndirectedEdge[362, 363] -> 
             RGBColor[
              0.20453297478611288`, 0.3323075030127757, 0.9349592223834241], 
             UndirectedEdge[18, 257] -> 
             RGBColor[
              0.46412234198098856`, 0.5722988469015355, 0.9519334554771259], 
             UndirectedEdge[72, 109] -> 
             RGBColor[
              0.18206833162796426`, 0.3086957387129193, 0.933679894189029], 
             UndirectedEdge[181, 211] -> 
             RGBColor[
              0.20840661341018846`, 0.33637894280955327`, 0.9351798203725303],
              UndirectedEdge[82, 259] -> 
             RGBColor[
              0.1834817429881715, 0.31018132366795326`, 0.9337603858750381], 
             UndirectedEdge[282, 367] -> 
             RGBColor[
              0.3211123825917724, 0.44870662104929115`, 0.9418228148301714], 
             UndirectedEdge[44, 363] -> 
             RGBColor[
              0.22828771928123268`, 0.35727524561493795`, 0.9363120199404259],
              UndirectedEdge[139, 290] -> 
             RGBColor[
              0.19313846063632573`, 0.32033114618742536`, 0.9343103216592668],
              UndirectedEdge[255, 351] -> 
             RGBColor[
              0.8601707384003942, 0.4921743089242222, 0.4514161861788524], 
             UndirectedEdge[290, 345] -> 
             RGBColor[
              0.18860221988526102`, 0.31556326954378094`, 0.9340519894592605],
              UndirectedEdge[145, 200] -> 
             RGBColor[
              0.19073593578989534`, 0.3178059402449537, 0.9341735014234795], 
             UndirectedEdge[44, 316] -> 
             RGBColor[
              0.23551418105696653`, 0.3648707151253743, 0.9367235562479619], 
             UndirectedEdge[172, 240] -> 
             RGBColor[
              0.8264317919518623, 0.2041719121929097, 0.17294441986452982`], 
             UndirectedEdge[89, 299] -> 
             RGBColor[
              0.18845360021131413`, 0.3154070608434312, 0.9340435257886923], 
             UndirectedEdge[119, 196] -> 
             RGBColor[
              0.18607572050979368`, 0.3129077585108523, 0.9339081090574485], 
             UndirectedEdge[149, 369] -> 
             RGBColor[
              0.20360056980323105`, 0.3313274862578765, 0.9349061232990186], 
             UndirectedEdge[32, 385] -> 
             RGBColor[
              0.9757287822359568, 0.928603231512897, 0.461093645269188], 
             UndirectedEdge[149, 253] -> 
             RGBColor[
              0.20384820267597584`, 0.3315877641079622, 0.9349202256247814], 
             UndirectedEdge[317, 336] -> 
             RGBColor[
              0.1878536669894908, 0.3147764929893316, 0.9340093604792311], 
             UndirectedEdge[138, 215] -> 
             RGBColor[
              0.18262441317102773`, 0.30928021567228525`, 0.9337115622102574],
              UndirectedEdge[157, 181] -> 
             RGBColor[
              0.19115892919796787`, 0.31825053313616897`, 0.9341975902723066],
              UndirectedEdge[299, 342] -> 
             RGBColor[
              0.18568831496489116`, 0.3125005707202294, 0.9338860468847814], 
             UndirectedEdge[108, 198] -> 
             RGBColor[
              0.3047308678845767, 0.4335017597846965, 0.9408162005428573], 
             UndirectedEdge[152, 367] -> 
             RGBColor[
              0.31592573046277495`, 0.4432551208089762, 0.9415274426643891], 
             UndirectedEdge[17, 118] -> 
             RGBColor[
              0.23527881827982655`, 0.36462333392373825`, 0.9367101526859918],
              UndirectedEdge[44, 68] -> 
             RGBColor[
              0.25335041241870687`, 0.38361772516894843`, 0.9377393032376733],
              UndirectedEdge[158, 323] -> 
             RGBColor[
              0.3687236016444134, 0.49379158398248, 0.9447157197406713], 
             UndirectedEdge[343, 359] -> 
             RGBColor[
              0.18461240578101906`, 0.3113697219513976, 0.933824775448425], 
             UndirectedEdge[354, 388] -> 
             RGBColor[
              0.21768345542489445`, 0.346129491952765, 0.93570812280141], 
             UndirectedEdge[382, 389] -> 
             RGBColor[
              0.1922700735577051, 0.31941841630887424`, 0.9342608682998029], 
             UndirectedEdge[178, 319] -> 
             RGBColor[
              0.4475260102308348, 0.5620450810151163, 0.9497372679364278], 
             UndirectedEdge[15, 386] -> 
             RGBColor[
              0.5232931103169385, 0.6153912271159707, 0.9581889419192983], 
             UndirectedEdge[27, 104] -> 
             RGBColor[
              0.8203618654395438, 0.15751579716047157`, 0.16713185138133213`],
              UndirectedEdge[236, 398] -> 
             RGBColor[
              0.3384347985138768, 0.4621971627307483, 0.9429819918755249], 
             UndirectedEdge[151, 304] -> 
             RGBColor[
              0.1864549217267703, 0.3133063230326405, 0.9339297040057775], 
             UndirectedEdge[21, 233] -> 
             RGBColor[
              0.9613042288478943, 0.9283900515581442, 0.6325730929841542], 
             UndirectedEdge[120, 321] -> 
             RGBColor[
              0.5363303582199404, 0.6344561720670685, 0.9566410369233613], 
             UndirectedEdge[170, 299] -> 
             RGBColor[
              0.20966330069407968`, 0.3376998008234987, 0.9352513868542458], 
             UndirectedEdge[97, 109] -> 
             RGBColor[
              0.18710606140703578`, 0.3139907121212397, 0.9339667854472937], 
             UndirectedEdge[251, 381] -> 
             RGBColor[
              0.19321867549075944`, 0.3204154570853507, 0.9343148897765596], 
             UndirectedEdge[134, 392] -> 
             RGBColor[
              0.9110260493239869, 0.9293182372189884, 0.8905829197640283], 
             UndirectedEdge[132, 220] -> 
             RGBColor[
              0.4970479670019815, 0.5999842739295098, 0.9542616336741748], 
             UndirectedEdge[102, 167] -> 
             RGBColor[
              0.29386288759542795`, 0.42605944514024496`, 0.9400515350827954],
              UndirectedEdge[270, 373] -> 
             RGBColor[
              0.31547519929516016`, 0.44425931355976, 0.9414476786623798], 
             UndirectedEdge[122, 351] -> 
             RGBColor[
              0.7538761223524553, 0.8076987945105711, 0.9763753458222324], 
             UndirectedEdge[96, 173] -> 
             RGBColor[
              0.515339475447038, 0.6087263479834802, 0.9574676673643785], 
             UndirectedEdge[253, 266] -> 
             RGBColor[
              0.21192263839001468`, 0.3400745079922101, 0.9353800527936387], 
             UndirectedEdge[217, 230] -> 
             RGBColor[
              0.8761820738662044, 0.4207616593515645, 0.27209490569893346`], 
             UndirectedEdge[118, 158] -> 
             RGBColor[
              0.28881871360859035`, 0.41812251622929797`, 0.9398607637666927],
              UndirectedEdge[208, 230] -> 
             RGBColor[
              0.876163969591323, 0.42202658470411747`, 0.3648858558318596], 
             UndirectedEdge[86, 179] -> 
             RGBColor[
              0.4324853651691194, 0.5490017107824403, 0.9487832899231066], 
             UndirectedEdge[185, 284] -> 
             RGBColor[
              0.33809952087216233`, 0.4642943071241772, 0.9428732085612545], 
             UndirectedEdge[279, 399] -> 
             RGBColor[
              0.7994051322415094, 0.7452396599077329, 0.6138726305595152], 
             UndirectedEdge[167, 309] -> 
             RGBColor[
              0.30392546223642514`, 0.4366358490920146, 0.940624583822355], 
             UndirectedEdge[174, 183] -> 
             RGBColor[
              0.34699168167192995`, 0.474968487180372, 0.943330981016807], 
             UndirectedEdge[149, 247] -> 
             RGBColor[
              0.20711572977977888`, 0.33502214226724336`, 0.9351063064594698],
              UndirectedEdge[297, 339] -> 
             RGBColor[
              0.22923415063680755`, 0.358270004976861, 0.9363659178060062], 
             UndirectedEdge[28, 282] -> 
             RGBColor[
              0.2370656602671769, 0.3665014181447689, 0.9368119106937756], 
             UndirectedEdge[35, 125] -> 
             RGBColor[
              0.24888171485109623`, 0.37892084069359944`, 0.9374848175220434],
              UndirectedEdge[119, 231] -> 
             RGBColor[
              0.18230446054106692`, 0.30894392517202796`, 0.9336933413813087],
              UndirectedEdge[257, 309] -> 
             RGBColor[
              0.31035046981038367`, 0.4422008677223072, 0.9410339796235565], 
             UndirectedEdge[153, 161] -> 
             RGBColor[
              0.1909498488692258, 0.3180307764542026, 0.9341856834568915], 
             UndirectedEdge[315, 369] -> 
             RGBColor[
              0.20472182801530026`, 0.332505999730638, 0.934969977295443], 
             UndirectedEdge[145, 207] -> 
             RGBColor[
              0.19250737674757545`, 0.31966783700731927`, 0.9342743823654074],
              UndirectedEdge[75, 215] -> 
             RGBColor[
              0.20048155521420025`, 0.3280492041678583, 0.9347285000323418], 
             UndirectedEdge[155, 199] -> 
             RGBColor[
              0.1967855567491959, 0.3241644754413012, 0.9345180183874995], 
             UndirectedEdge[28, 151] -> 
             RGBColor[
              0.19950401467485102`, 0.3270217470813523, 0.9346728305447676], 
             UndirectedEdge[141, 279] -> 
             RGBColor[
              0.801143090532162, 0.5696856585664152, 0.46236431184102655`], 
             UndirectedEdge[347, 380] -> 
             RGBColor[
              0.20898774598358635`, 0.3369897499901277, 0.9352129150128767], 
             UndirectedEdge[107, 346] -> 
             RGBColor[
              0.3498425512041035, 0.47743776708027175`, 0.9435126359024721], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.684630729662244, 0.7517566465973935, 0.970608286963019], 
             UndirectedEdge[171, 299] -> 
             RGBColor[
              0.18831247292825637`, 0.31525872712095093`, 0.9340354887987012],
              UndirectedEdge[283, 294] -> 
             RGBColor[
              0.19947004944091673`, 0.32698604746696713`, 0.934670896274942], 
             UndirectedEdge[83, 244] -> 
             RGBColor[
              0.9498999569574745, 0.9621560504469515, 0.9696904840737579], 
             UndirectedEdge[112, 179] -> 
             RGBColor[
              0.6955279730573865, 0.6779676106196408, 0.6092046613657698], 
             UndirectedEdge[42, 93] -> 
             RGBColor[
              0.22541709987581074`, 0.35425804261205696`, 0.936148542411988], 
             UndirectedEdge[94, 254] -> 
             RGBColor[
              0.18421702339867016`, 0.31095414999885795`, 0.9338022590066659],
              UndirectedEdge[84, 222] -> 
             RGBColor[
              0.2856119220562171, 0.4147444227440439, 0.9396784182563604], 
             UndirectedEdge[132, 366] -> 
             RGBColor[
              0.3763364091715497, 0.5003854152316536, 0.9452008011045592], 
             UndirectedEdge[52, 133] -> 
             RGBColor[
              0.18257629412906723`, 0.3092296395082612, 0.9337088219020035], 
             UndirectedEdge[255, 400] -> 
             RGBColor[
              0.840300424061758, 0.3107722958629089, 0.1862250376353455], 
             UndirectedEdge[276, 318] -> 
             RGBColor[
              0.20862378443178675`, 0.3366072033226911, 0.9351921879409346], 
             UndirectedEdge[235, 313] -> 
             RGBColor[
              0.2049405983747336, 0.3327359412492443, 0.9349824359437711], 
             UndirectedEdge[218, 229] -> 
             RGBColor[
              0.19887179747769093`, 0.3263572467222515, 0.9346368267106708], 
             UndirectedEdge[202, 260] -> 
             RGBColor[
              0.23397057730885262`, 0.3632482897159762, 0.9366356502980638], 
             UndirectedEdge[129, 216] -> 
             RGBColor[
              0.1943994825815768, 0.32165656020529343`, 0.9343821349935341], 
             UndirectedEdge[307, 312] -> 
             RGBColor[
              0.32563175741045036`, 0.45592792457411196`, 0.9419897054854269],
              UndirectedEdge[215, 349] -> 
             RGBColor[
              0.192491042377818, 0.3196506685490453, 0.9342734521472142], 
             UndirectedEdge[48, 61] -> 
             RGBColor[
              0.22477630942984533`, 0.3535845312248864, 0.9361120503440548], 
             UndirectedEdge[198, 284] -> 
             RGBColor[
              0.31495346164278715`, 0.44424635397445533`, 0.9413983621344152],
              UndirectedEdge[37, 256] -> 
             RGBColor[
              0.3500537032004466, 0.4776206563266962, 0.9435260903209648], 
             UndirectedEdge[260, 366] -> 
             RGBColor[
              0.3094906009088253, 0.4347053804692331, 0.9412263661740565], 
             UndirectedEdge[35, 263] -> 
             RGBColor[
              0.31410208852609794`, 0.43977856599147, 0.9414807005621779], 
             UndirectedEdge[124, 185] -> 
             RGBColor[
              0.35466498690371884`, 0.48161471850061266`, 0.9438199172409392],
              UndirectedEdge[17, 48] -> 
             RGBColor[
              0.23593219427525336`, 0.3653100735213626, 0.936747361482348], 
             UndirectedEdge[98, 139] -> 
             RGBColor[
              0.19453754132088114`, 0.32180166869373195`, 0.9343899972344978],
              UndirectedEdge[98, 125] -> 
             RGBColor[
              0.23126364989762477`, 0.3604031373776651, 0.9364814947865346], 
             UndirectedEdge[195, 397] -> 
             RGBColor[
              0.2073858256728759, 0.33530603017595706`, 0.9351216880210106], 
             UndirectedEdge[152, 198] -> 
             RGBColor[
              0.3050387614583694, 0.43382537545233274`, 0.9408337346263971], 
             UndirectedEdge[29, 129] -> 
             RGBColor[
              0.18526332309430954`, 0.3120538773182072, 0.933861844226471], 
             UndirectedEdge[83, 230] -> 
             RGBColor[
              0.8601703747775189, 0.411075832295422, 0.43572184164473515`], 
             UndirectedEdge[10, 155] -> 
             RGBColor[
              0.22229114501906733`, 0.3509724658606344, 0.9359705239073323], 
             UndirectedEdge[210, 316] -> 
             RGBColor[
              0.270003773674733, 0.40112146373312046`, 0.9386876875247638], 
             UndirectedEdge[6, 175] -> 
             RGBColor[
              0.2936199376985361, 0.4259435494734196, 0.9400325931289355], 
             UndirectedEdge[301, 343] -> 
             RGBColor[
              0.18235879982602854`, 0.30900103920583233`, 0.9336964359231994],
              UndirectedEdge[140, 297] -> 
             RGBColor[
              0.21630983883703356`, 0.3446857338266013, 0.935629897368815], 
             UndirectedEdge[274, 295] -> 
             RGBColor[
              0.4610566723545275, 0.5726862586021548, 0.9508973954130453], 
             UndirectedEdge[61, 371] -> 
             RGBColor[
              0.19795607517941943`, 0.3253947645266211, 0.934584677680474], 
             UndirectedEdge[266, 397] -> 
             RGBColor[
              0.22283784734549728`, 0.3515470846686418, 0.9360016577960488], 
             UndirectedEdge[71, 88] -> 
             RGBColor[
              0.1851982028892632, 0.3119854318538441, 0.9338581357271303], 
             UndirectedEdge[156, 255] -> 
             RGBColor[
              0.8324443766360075, 0.2503872728066577, 0.17870207774831032`], 
             UndirectedEdge[22, 388] -> 
             RGBColor[
              0.26789478594512556`, 0.39820864264238165`, 0.9385930729355345],
              UndirectedEdge[17, 346] -> 
             RGBColor[
              0.29137138430139253`, 0.41966736519027487`, 0.9400478085576316],
              UndirectedEdge[72, 365] -> 
             RGBColor[
              0.18187230727944725`, 0.30848970469396636`, 0.9336687308923729],
              UndirectedEdge[194, 230] -> 
             RGBColor[
              0.8766694336459471, 0.421804072640802, 0.32514101008801133`], 
             UndirectedEdge[95, 264] -> 
             RGBColor[
              0.6413507907064967, 0.7184767050540989, 0.9657562779986768], 
             UndirectedEdge[131, 325] -> 
             RGBColor[
              0.2511977848308302, 0.381355177089618, 0.9376167142810707], 
             UndirectedEdge[369, 372] -> 
             RGBColor[
              0.19233300953943172`, 0.31948456601604064`, 0.9342644524108568],
              UndirectedEdge[11, 248] -> 
             RGBColor[
              0.2649817698706437, 0.3955454303669761, 0.9384125880269136], 
             UndirectedEdge[32, 223] -> 
             RGBColor[
              0.9434671979288998, 0.8132571155526379, 0.27501732397559764`], 
             UndirectedEdge[75, 229] -> 
             RGBColor[
              0.21242485108253378`, 0.34060236537417143`, 0.9354086530635206],
              UndirectedEdge[123, 131] -> 
             RGBColor[
              0.21247713876151392`, 0.34065732304000995`, 0.9354116307694857],
              UndirectedEdge[35, 340] -> 
             RGBColor[
              0.21959313401090685`, 0.34813668522727964`, 0.9358168761717671],
              UndirectedEdge[316, 369] -> 
             RGBColor[
              0.2124757350485229, 0.34065584764865586`, 0.9354115508301075], 
             UndirectedEdge[232, 280] -> 
             RGBColor[
              0.2733144461810522, 0.4046011904460226, 0.9388762254262976], 
             UndirectedEdge[30, 318] -> 
             RGBColor[
              0.18730055861877407`, 0.31419514102261215`, 0.9339778617757692],
              UndirectedEdge[219, 338] -> 
             RGBColor[
              0.28566284547896603`, 0.414956272719873, 0.9396755211710989], 
             UndirectedEdge[124, 397] -> 
             RGBColor[
              0.26132649500551464`, 0.3919101499465881, 0.9381968592370336], 
             UndirectedEdge[131, 280] -> 
             RGBColor[
              0.23239625445736245`, 0.36159357658122604`, 0.9365459949406734],
              UndirectedEdge[224, 345] -> 
             RGBColor[
              0.17916076969846856`, 0.3056397067749454, 0.9335143128384965], 
             UndirectedEdge[44, 195] -> 
             RGBColor[
              0.2192614298530921, 0.3477880431261581, 0.9357979861106919], 
             UndirectedEdge[57, 102] -> 
             RGBColor[
              0.24757611002741542`, 0.37754856724378383`, 0.937410465258804], 
             UndirectedEdge[102, 222] -> 
             RGBColor[
              0.2549287084068188, 0.3852766143221994, 0.9378291848593165], 
             UndirectedEdge[86, 285] -> 
             RGBColor[
              0.7026108469912147, 0.7602147765402214, 0.7786951433273641], 
             UndirectedEdge[97, 340] -> 
             RGBColor[
              0.1979121571634553, 0.3253486039072797, 0.9345821766144358], 
             UndirectedEdge[84, 183] -> 
             RGBColor[
              0.3444123638438444, 0.47273441171796776`, 0.9431666291656026], 
             UndirectedEdge[23, 132] -> 
             RGBColor[
              0.32566481114992, 0.45504559524241234`, 0.9420251663053016], 
             UndirectedEdge[124, 210] -> 
             RGBColor[
              0.30769169180349737`, 0.4406429115045353, 0.9408372886035168], 
             UndirectedEdge[257, 288] -> 
             RGBColor[
              0.3142377899115303, 0.4462866876189422, 0.9412553567525421], 
             UndirectedEdge[31, 287] -> 
             RGBColor[
              0.19320443776430601`, 0.3204004923321242, 0.9343140789591009], 
             UndirectedEdge[163, 222] -> 
             RGBColor[
              0.24959037113759353`, 0.3796656833821117, 0.9375251744491964], 
             UndirectedEdge[206, 386] -> 
             RGBColor[
              0.7455369138645886, 0.8011383704922057, 0.975271810201597], 
             UndirectedEdge[95, 263] -> 
             RGBColor[
              0.47568127911611685`, 0.5835523041211401, 0.9523268989560933], 
             UndirectedEdge[103, 333] -> 
             RGBColor[
              0.19123001846776383`, 0.3183252524660446, 0.9342016387010543], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.19722342502912832`, 0.3246247027659626, 0.9345429543382737], 
             UndirectedEdge[57, 174] -> 
             RGBColor[
              0.28083864150489934`, 0.40925045112803254`, 0.9394240505070525],
              UndirectedEdge[32, 208] -> 
             RGBColor[0.97502376088894, 0.929050734989072, 0.526498655624491],
              UndirectedEdge[11, 125] -> 
             RGBColor[
              0.2867382877276377, 0.41841291007758175`, 0.9396515895329856], 
             UndirectedEdge[82, 136] -> 
             RGBColor[
              0.18265801399513343`, 0.30931553226883557`, 0.9337134757274823],
              UndirectedEdge[129, 298] -> 
             RGBColor[
              0.19304299486108434`, 0.3202308056047669, 0.9343048850245959], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.24346570234943876`, 0.37322826815933124`, 0.9371763836223466],
              UndirectedEdge[155, 306] -> 
             RGBColor[
              0.20489683816901277`, 0.33268994649847444`, 0.9349799438647926],
              UndirectedEdge[247, 358] -> 
             RGBColor[
              0.19420191296404457`, 0.3214489020106298, 0.9343708836960937], 
             UndirectedEdge[5, 373] -> 
             RGBColor[
              0.27714534160664284`, 0.4086277044311172, 0.939094389253483], 
             UndirectedEdge[194, 201] -> 
             RGBColor[
              0.9717877162352071, 0.9761148093624215, 0.8086618740541351], 
             UndirectedEdge[7, 173] -> 
             RGBColor[
              0.36556257674898185`, 0.48862517592323496`, 0.9446032208411446],
              UndirectedEdge[25, 364] -> 
             RGBColor[
              0.8174383734159, 0.1350445563843714, 0.16433231211787877`], 
             UndirectedEdge[1, 313] -> 
             RGBColor[
              0.20595700131663575`, 0.3338042451848521, 0.935040318587679], 
             UndirectedEdge[189, 222] -> 
             RGBColor[
              0.24951462814212214`, 0.379586072691488, 0.937520860997656], 
             UndirectedEdge[232, 275] -> 
             RGBColor[
              0.2669215798519661, 0.39788188260301705`, 0.9385121611462544], 
             UndirectedEdge[289, 376] -> 
             RGBColor[
              0.19788479388924796`, 0.32531984337115605`, 0.93458061831645], 
             UndirectedEdge[194, 208] -> 
             RGBColor[
              0.9937734715667986, 0.9910458830658546, 0.7058012226950569], 
             UndirectedEdge[320, 384] -> 
             RGBColor[
              0.1926752609493727, 0.31984429394788133`, 0.9342839431223373], 
             UndirectedEdge[262, 332] -> 
             RGBColor[
              0.22124807994982085`, 0.34987613833871123`, 0.9359111228947152],
              UndirectedEdge[39, 237] -> 
             RGBColor[
              0.19025421078354665`, 0.3172996167201517, 0.9341460678970164], 
             UndirectedEdge[105, 353] -> 
             RGBColor[
              0.19974831949640176`, 0.32727852693862247`, 0.9346867433429382],
              UndirectedEdge[160, 321] -> 
             RGBColor[
              0.5069925116479708, 0.6106383865650169, 0.9543314541731429], 
             UndirectedEdge[22, 354] -> 
             RGBColor[
              0.2660640348072204, 0.3962844071201169, 0.9384888143665844], 
             UndirectedEdge[70, 286] -> 
             RGBColor[
              0.20888058953085603`, 0.33687712176419665`, 0.9352068126114177],
              UndirectedEdge[97, 334] -> 
             RGBColor[
              0.1889352663956901, 0.3159133225426103, 0.9340709559653313], 
             UndirectedEdge[301, 362] -> 
             RGBColor[
              0.18593089634401205`, 0.31275553913023335`, 0.9338998615354555],
              UndirectedEdge[166, 300] -> 
             RGBColor[
              0.9521971792667703, 0.9624135645920178, 0.9060859398221737], 
             UndirectedEdge[357, 364] -> 
             RGBColor[
              0.8439593662277066, 0.3388965287090708, 0.18972884478564203`], 
             UndirectedEdge[13, 66] -> 
             RGBColor[
              0.21421674509456057`, 0.34248575959345395`, 0.9355106987766358],
              UndirectedEdge[102, 395] -> 
             RGBColor[
              0.3730551581743753, 0.49423581065451916`, 0.9452125382842432], 
             UndirectedEdge[129, 336] -> 
             RGBColor[
              0.184720804255658, 0.3114836556211034, 0.9338309485811944], 
             UndirectedEdge[257, 275] -> 
             RGBColor[
              0.2809273627700829, 0.4112753166902168, 0.9393583772051975], 
             UndirectedEdge[358, 369] -> 
             RGBColor[
              0.19068675298749674`, 0.31775424600126295`, 0.9341707005356424],
              UndirectedEdge[42, 139] -> 
             RGBColor[
              0.20228682166276132`, 0.3299466536657998, 0.934831307285935], 
             UndirectedEdge[37, 206] -> 
             RGBColor[
              0.5395559184345032, 0.6328895346269106, 0.9586002858977685], 
             UndirectedEdge[3, 162] -> 
             RGBColor[
              0.42709887646193556`, 0.5374958425847769, 0.9495230473669047], 
             UndirectedEdge[44, 161] -> 
             RGBColor[
              0.2180648213930185, 0.34653033176526227`, 0.9357298410291143], 
             UndirectedEdge[67, 266] -> 
             RGBColor[
              0.3289874356394012, 0.4523479810161943, 0.9424410275338806], 
             UndirectedEdge[305, 360] -> 
             RGBColor[
              0.18374121717091801`, 0.3104540474856332, 0.9337751625458877], 
             UndirectedEdge[51, 174] -> 
             RGBColor[
              0.3627872108908755, 0.4886497806834403, 0.9443374581712001], 
             UndirectedEdge[132, 321] -> 
             RGBColor[
              0.4563174789356197, 0.5669174288296601, 0.9510551804528969], 
             UndirectedEdge[198, 236] -> 
             RGBColor[
              0.3020417872484481, 0.43067536553856556`, 0.9406630613787681], 
             UndirectedEdge[153, 356] -> 
             RGBColor[
              0.18871819494406902`, 0.31568516668383156`, 0.9340585940672899],
              UndirectedEdge[78, 217] -> 
             RGBColor[
              0.8776482484719079, 0.43203131985281057`, 0.2734989161571625], 
             UndirectedEdge[16, 324] -> 
             RGBColor[
              0.47545256857995977`, 0.5813525434303296, 0.9528653912069069], 
             UndirectedEdge[263, 312] -> 
             RGBColor[
              0.3474308254202023, 0.4748091816311434, 0.9433787228228494], 
             UndirectedEdge[49, 231] -> 
             RGBColor[
              0.1849354051777754, 0.31170921479673314`, 0.9338431697862355], 
             UndirectedEdge[58, 303] -> 
             RGBColor[
              0.21259709598969448`, 0.3407834056925553, 0.9354184621561699], 
             UndirectedEdge[287, 371] -> 
             RGBColor[
              0.18823999048710255`, 0.315182543479646, 0.9340313610309057], 
             UndirectedEdge[108, 332] -> 
             RGBColor[
              0.24224909685408347`, 0.3719495386464692, 0.9371070997391926], 
             UndirectedEdge[55, 135] -> 
             RGBColor[
              0.9832367917164733, 0.9536721882994657, 0.5121416630539384], 
             UndirectedEdge[38, 145] -> 
             RGBColor[
              0.21009367554414693`, 0.338152152078261, 0.9352758960652745], 
             UndirectedEdge[41, 400] -> 
             RGBColor[
              0.8574093225920176, 0.5580230088055577, 0.4596698602319089], 
             UndirectedEdge[184, 369] -> 
             RGBColor[
              0.1868540625349533, 0.3137258453290297, 0.9339524344843275], 
             UndirectedEdge[68, 363] -> 
             RGBColor[
              0.24496356786818765`, 0.3748026197896954, 0.9372616848477457], 
             UndirectedEdge[239, 350] -> 
             RGBColor[
              0.8831254339446791, 0.4735106865862311, 0.3666717938932875], 
             UndirectedEdge[197, 300] -> 
             RGBColor[
              0.9395054889132312, 0.9538623530451078, 0.9685107634864926], 
             UndirectedEdge[34, 340] -> 
             RGBColor[
              0.23309142699709673`, 0.3623242469969716, 0.9365855839883956], 
             UndirectedEdge[99, 225] -> 
             RGBColor[
              0.9251735948093716, 0.9424003112075763, 0.9659587843040318], 
             UndirectedEdge[75, 218] -> 
             RGBColor[
              0.20441362479812614`, 0.3321820586081753, 0.9349524255781707], 
             UndirectedEdge[33, 256] -> 
             RGBColor[
              0.3139252578534664, 0.443350508209742, 0.9413330387606047], 
             UndirectedEdge[68, 173] -> 
             RGBColor[
              0.2762530439300684, 0.40768984299809713`, 0.9390435742208383], 
             UndirectedEdge[76, 368] -> 
             RGBColor[
              0.18953430680604916`, 0.3165429519952533, 0.9341050704305003], 
             UndirectedEdge[343, 369] -> 
             RGBColor[
              0.18630927681020493`, 0.31315324099090924`, 0.9339214097432413],
              UndirectedEdge[172, 243] -> 
             RGBColor[
              0.8723775495712267, 0.44824282516484726`, 0.42577432827241535`],
              UndirectedEdge[25, 83] -> 
             RGBColor[
              0.8598908303478167, 0.4089271313115804, 0.435454149583152], 
             UndirectedEdge[176, 372] -> 
             RGBColor[
              0.2138686325253813, 0.34211987121163484`, 0.9354908742808075], 
             UndirectedEdge[211, 214] -> 
             RGBColor[
              0.23081730246588306`, 0.35993399792684283`, 0.9364560759606089],
              UndirectedEdge[273, 330] -> 
             RGBColor[
              0.18387764331179846`, 0.31059744000961553`, 0.9337829318127865],
              UndirectedEdge[247, 266] -> 
             RGBColor[
              0.21519016549381775`, 0.3435088861514912, 0.9355661336283271], 
             UndirectedEdge[294, 347] -> 
             RGBColor[
              0.19390550774844745`, 0.3211373613358611, 0.9343540038575576], 
             UndirectedEdge[247, 343] -> 
             RGBColor[
              0.18982443678675276`, 0.31684789700027605`, 0.9341215929036926],
              UndirectedEdge[147, 354] -> 
             RGBColor[
              0.1996644579713909, 0.3271903831587082, 0.9346819675531508], 
             UndirectedEdge[83, 206] -> 
             RGBColor[
              0.8376738526720509, 0.8738864473115988, 0.9758404514260404], 
             UndirectedEdge[178, 300] -> 
             RGBColor[
              0.6781948564694122, 0.7459060831571422, 0.9705455677828076], 
             UndirectedEdge[31, 384] -> 
             RGBColor[
              0.19301716646589862`, 0.32020365832381187`, 0.9343034141356996],
              UndirectedEdge[325, 339] -> 
             RGBColor[
              0.2703434502460814, 0.40147848534634617`, 0.9387070316029955], 
             UndirectedEdge[43, 237] -> 
             RGBColor[
              0.22884629711642387`, 0.3578623463356042, 0.9363438301217982], 
             UndirectedEdge[114, 128] -> 
             RGBColor[
              0.21795119041436695`, 0.34641089840207934`, 0.9357233699129821],
              UndirectedEdge[131, 188] -> 
             RGBColor[
              0.20752052535930418`, 0.3354476080868466, 0.9351293589688823], 
             UndirectedEdge[8, 352] -> 
             RGBColor[
              0.23870734178156489`, 0.36822692950501057`, 0.9369054020273697],
              UndirectedEdge[56, 137] -> 
             RGBColor[
              0.35805694536026106`, 0.48455266243088047`, 0.9440360498343989],
              UndirectedEdge[11, 93] -> 
             RGBColor[
              0.2731424573639435, 0.4041228303399058, 0.9388773271070019], 
             UndirectedEdge[232, 325] -> 
             RGBColor[
              0.29211597655452004`, 0.4243627909544146, 0.9399469447666949], 
             UndirectedEdge[293, 387] -> 
             RGBColor[
              0.4415101712045343, 0.5546415244104943, 0.9499598596294503], 
             UndirectedEdge[100, 175] -> 
             RGBColor[
              0.2458994336441635, 0.3757862740575634, 0.9373149810191983], 
             UndirectedEdge[327, 336] -> 
             RGBColor[
              0.18798018955468324`, 0.3149094762273428, 0.9340165657521455], 
             UndirectedEdge[230, 357] -> 
             RGBColor[
              0.8308590408356056, 0.2382016871461912, 0.17718395839546475`], 
             UndirectedEdge[151, 291] -> 
             RGBColor[
              0.1895972333261113, 0.3166090917576105, 0.9341086540027264], 
             UndirectedEdge[10, 87] -> 
             RGBColor[
              0.2178399723924833, 0.34629400120944975`, 0.9357170362111682], 
             UndirectedEdge[44, 247] -> 
             RGBColor[
              0.2171512777998561, 0.34557013952683935`, 0.9356778160729503], 
             UndirectedEdge[191, 334] -> 
             RGBColor[
              0.1961023648412683, 0.3234463974292005, 0.934479111619035], 
             UndirectedEdge[31, 389] -> 
             RGBColor[
              0.19956255990653143`, 0.3270832818318305, 0.9346761646091019], 
             UndirectedEdge[323, 346] -> 
             RGBColor[
              0.37487874320773873`, 0.4991228582382221, 0.9451079199183084], 
             UndirectedEdge[91, 257] -> 
             RGBColor[
              0.408201112318213, 0.5268994734386068, 0.9475311314318583], 
             UndirectedEdge[25, 217] -> 
             RGBColor[
              0.8759025294365022, 0.41861295836772294`, 0.2718272136373503], 
             UndirectedEdge[4, 238] -> 
             RGBColor[
              0.26140051176335477`, 0.3920788899859515, 0.9381977444862962], 
             UndirectedEdge[49, 298] -> 
             RGBColor[
              0.19233776426424887`, 0.31948956353329044`, 0.9342647231854012],
              UndirectedEdge[96, 245] -> 
             RGBColor[
              0.795286411691943, 0.364900459678807, 0.43562237712445073`], 
             UndirectedEdge[198, 219] -> 
             RGBColor[
              0.34521680439082036`, 0.47343117768740084`, 0.9432178874059169],
              UndirectedEdge[69, 106] -> 
             RGBColor[
              0.23431749208343802`, 0.36361291913973265`, 0.936655406581262], 
             UndirectedEdge[246, 350] -> 
             RGBColor[
              0.9570479117499637, 0.9654838538059254, 0.8719160935305621], 
             UndirectedEdge[91, 263] -> 
             RGBColor[
              0.44262523593919395`, 0.5567159191123393, 0.94972460614893], 
             UndirectedEdge[193, 305] -> 
             RGBColor[
              0.18458905889423072`, 0.311345182893105, 0.933823445877761], 
             UndirectedEdge[217, 244] -> 
             RGBColor[
              0.9739175055905028, 0.9766847910311653, 0.7242500801550553], 
             UndirectedEdge[218, 260] -> 
             RGBColor[
              0.20772118523879674`, 0.3356585143427644, 0.9351407862521698], 
             UndirectedEdge[115, 169] -> 
             RGBColor[
              0.875001595756134, 0.6253129164488254, 0.46913275406054683`], 
             UndirectedEdge[152, 332] -> 
             RGBColor[
              0.24255699042787615`, 0.37227315431410535`, 0.9371246338227324],
              UndirectedEdge[8, 227] -> 
             RGBColor[
              0.22264092645081146`, 0.35134010832282114`, 0.9359904434424149],
              UndirectedEdge[161, 344] -> 
             RGBColor[
              0.1953522686165181, 0.3226579987381405, 0.9344363947487033], 
             UndirectedEdge[255, 324] -> 
             RGBColor[
              0.767950807524049, 0.41955323404777206`, 0.4424174224408835], 
             UndirectedEdge[135, 221] -> 
             RGBColor[
              0.9485753172801801, 0.8203317071995411, 0.46009294767531356`], 
             UndirectedEdge[179, 257] -> 
             RGBColor[
              0.38852623515624984`, 0.5109265218154098, 0.9459822530302189], 
             UndirectedEdge[40, 350] -> 
             RGBColor[
              0.7574551958384235, 0.806891984810095, 0.8535080309341501], 
             UndirectedEdge[358, 397] -> 
             RGBColor[
              0.20184959481572412`, 0.3294871005277804, 0.9348064078638154], 
             UndirectedEdge[44, 149] -> 
             RGBColor[
              0.22663901581167467`, 0.355542353734595, 0.9362181287168728], 
             UndirectedEdge[215, 218] -> 
             RGBColor[
              0.18692850160935742`, 0.31380408551593836`, 0.9339566736794921],
              UndirectedEdge[211, 248] -> 
             RGBColor[
              0.2199442042179371, 0.34850568227400514`, 0.9358368691006957], 
             UndirectedEdge[38, 103] -> 
             RGBColor[
              0.20863860950919683`, 0.3366227854190133, 0.9351930322071614], 
             UndirectedEdge[79, 213] -> 
             RGBColor[
              0.22683120635617676`, 0.355744358182451, 0.9362290736840618], 
             UndirectedEdge[116, 383] -> 
             RGBColor[
              0.19584602024074033`, 0.3231769630008592, 0.9344645131732627], 
             UndirectedEdge[214, 263] -> 
             RGBColor[
              0.315848849556003, 0.4416145225849462, 0.9415801760187297], 
             UndirectedEdge[203, 275] -> 
             RGBColor[
              0.232253685994867, 0.3614437280877808, 0.9365378758776455], 
             UndirectedEdge[235, 396] -> 
             RGBColor[
              0.19553592187284338`, 0.32285102995482734`, 0.9344468535299604],
              UndirectedEdge[170, 361] -> 
             RGBColor[
              0.22465020382752957`, 0.3534519862412956, 0.9361048688165594], 
             UndirectedEdge[190, 255] -> 
             RGBColor[
              0.8756473687829154, 0.5041621789431939, 0.4406614321632898], 
             UndirectedEdge[67, 113] -> 
             RGBColor[
              0.36637406988619037`, 0.4916437040590915, 0.9445701410456664], 
             UndirectedEdge[244, 307] -> 
             RGBColor[
              0.651559964846024, 0.7209668023928419, 0.952436169214119], 
             UndirectedEdge[106, 292] -> 
             RGBColor[
              0.21060209943900177`, 0.3386865378276902, 0.9353048500539408], 
             UndirectedEdge[119, 126] -> 
             RGBColor[
              0.1845010944888899, 0.3112527267258263, 0.9338184364350084], 
             UndirectedEdge[148, 288] -> 
             RGBColor[
              0.3196747008606359, 0.4509958666159675, 0.9416017919105475], 
             UndirectedEdge[143, 277] -> 
             RGBColor[
              0.196429195674298, 0.32378991735698637`, 0.9344977241514731], 
             UndirectedEdge[245, 364] -> 
             RGBColor[
              0.8184457437613093, 0.14278764629168772`, 0.16529697109830485`],
              UndirectedEdge[101, 335] -> 
             RGBColor[
              0.18130162624818058`, 0.3078898827468379, 0.9336362314518891], 
             UndirectedEdge[175, 296] -> 
             RGBColor[
              0.26330595896968834`, 0.39408163581213873`, 0.9383062568858402],
              UndirectedEdge[106, 158] -> 
             RGBColor[
              0.2827874224549232, 0.411783246820848, 0.939517290657987], 
             UndirectedEdge[59, 319] -> 
             RGBColor[
              0.3999369554845372, 0.5208258336893123, 0.9467049354493426], 
             UndirectedEdge[159, 218] -> 
             RGBColor[
              0.18568639672443343`, 0.31249855452788494`, 0.9338859376438252],
              UndirectedEdge[126, 326] -> 
             RGBColor[
              0.18929893908149736`, 0.31629556559357375`, 0.9340916665867824],
              UndirectedEdge[130, 371] -> 
             RGBColor[
              0.18427986944939637`, 0.311020205182841, 0.9338058379962824], 
             UndirectedEdge[108, 262] -> 
             RGBColor[
              0.23515249805591343`, 0.36449056335924074`, 0.936702958936114], 
             UndirectedEdge[34, 91] -> 
             RGBColor[
              0.37827297461142906`, 0.4967706349329164, 0.9457781608227135], 
             UndirectedEdge[173, 323] -> 
             RGBColor[
              0.3405854460382354, 0.4669912406886779, 0.9430117001586653], 
             UndirectedEdge[104, 208] -> 
             RGBColor[
              0.8770111738905605, 0.4285385681953471, 0.3656971396255897], 
             UndirectedEdge[115, 122] -> 
             RGBColor[
              0.7757263022490958, 0.5468964399598267, 0.4596563040800477], 
             UndirectedEdge[275, 297] -> 
             RGBColor[
              0.22283542703535522`, 0.35154454076922603`, 0.9360015199629668],
              UndirectedEdge[185, 293] -> 
             RGBColor[
              0.374247320413842, 0.49857595155038115`, 0.9450676862162266], 
             UndirectedEdge[92, 256] -> 
             RGBColor[
              0.42434961842059, 0.5407753734409124, 0.9485908039462863], 
             UndirectedEdge[135, 165] -> 
             RGBColor[
              0.9457959012350979, 0.9559420991486686, 0.8350019041226482], 
             UndirectedEdge[158, 270] -> 
             RGBColor[
              0.3489276916060272, 0.4766453616785984, 0.9434543418578613], 
             UndirectedEdge[35, 86] -> 
             RGBColor[
              0.32363709491798653`, 0.44803730928476804`, 0.942088262737994], 
             UndirectedEdge[124, 387] -> 
             RGBColor[
              0.42192783769441117`, 0.5376802913607258, 0.9487120906541628], 
             UndirectedEdge[170, 261] -> 
             RGBColor[
              0.2458172275622507, 0.3756998702533064, 0.9373102995044464], 
             UndirectedEdge[78, 244] -> 
             RGBColor[
              0.8648801933259055, 0.4247645971381416, 0.4316352089858322], 
             UndirectedEdge[320, 381] -> 
             RGBColor[
              0.19597803687805715`, 0.32331572085701743`, 0.9344720313254569],
              UndirectedEdge[90, 166] -> 
             RGBColor[
              0.7990367806379581, 0.841477411935373, 0.8913793888944332], 
             UndirectedEdge[119, 317] -> 
             RGBColor[
              0.1888850042427438, 0.31586049383305914`, 0.9340680936100771], 
             UndirectedEdge[173, 250] -> 
             RGBColor[
              0.27041365894161523`, 0.40155227913684066`, 0.9387110298843417],
              UndirectedEdge[234, 355] -> 
             RGBColor[
              0.7757149376246414, 0.8247136720150343, 0.978279673580333], 
             UndirectedEdge[203, 297] -> 
             RGBColor[
              0.2163387830881471, 0.3447161560696932, 0.9356315457010966], 
             UndirectedEdge[48, 388] -> 
             RGBColor[
              0.2298511238520014, 0.358918482944391, 0.9364010535178815], 
             UndirectedEdge[34, 95] -> 
             RGBColor[
              0.41132901778835196`, 0.5236070199417173, 0.9483804536298768], 
             UndirectedEdge[133, 299] -> 
             RGBColor[
              0.18672468895596034`, 0.31358986549474943`, 0.9339450668503949],
              UndirectedEdge[58, 376] -> 
             RGBColor[
              0.2107803074531337, 0.33887384574958357`, 0.9353149987367104], 
             UndirectedEdge[239, 392] -> 
             RGBColor[
              0.8822032486914739, 0.47312933928495077`, 0.3819547900778306], 
             UndirectedEdge[64, 77] -> 
             RGBColor[
              0.18172630335562523`, 0.308336245312846, 0.9336604161849047], 
             UndirectedEdge[73, 112] -> 
             RGBColor[
              0.9338615942560703, 0.7754902910821886, 0.2656416901517646], 
             UndirectedEdge[257, 339] -> 
             RGBColor[
              0.2873260863715352, 0.41800078089785175`, 0.939722775048237], 
             UndirectedEdge[35, 85] -> 
             RGBColor[
              0.2384984047146932, 0.36800732340035325`, 0.9368935033705061], 
             UndirectedEdge[37, 187] -> 
             RGBColor[
              0.39185947335344506`, 0.5138307132141199, 0.9461899170277228], 
             UndirectedEdge[9, 39] -> 
             RGBColor[
              0.1871051393828018, 0.3139897430153101, 0.9339667329393776], 
             UndirectedEdge[136, 394] -> 
             RGBColor[
              0.18251086599702937`, 0.30916087039310625`, 0.9337050958666762],
              UndirectedEdge[287, 389] -> 
             RGBColor[
              0.19629053047607914`, 0.32364417144177693`, 0.9344898273735713],
              UndirectedEdge[195, 372] -> 
             RGBColor[
              0.19795832156921558`, 0.32539712562472617`, 0.9345848056090496],
              UndirectedEdge[149, 362] -> 
             RGBColor[
              0.20288427131655484`, 0.3305746111324327, 0.934865331159871], 
             UndirectedEdge[83, 321] -> 
             RGBColor[
              0.7496980165524652, 0.8038110466699736, 0.967993483257613], 
             UndirectedEdge[227, 308] -> 
             RGBColor[
              0.20448504246078797`, 0.33225712309977423`, 0.9349564927084064],
              UndirectedEdge[100, 146] -> 
             RGBColor[
              0.1981449486568544, 0.3255932825266753, 0.9345954337456006], 
             UndirectedEdge[100, 278] -> 
             RGBColor[
              0.23415669632153385`, 0.3634439125989312, 0.9366462495004977], 
             UndirectedEdge[234, 350] -> 
             RGBColor[
              0.8897866044520348, 0.9121284341385445, 0.8654271636734474], 
             UndirectedEdge[278, 352] -> 
             RGBColor[
              0.24888415157963256`, 0.37892340184978857`, 0.9374849562901288],
              UndirectedEdge[342, 353] -> 
             RGBColor[
              0.1868676578718124, 0.31374013489006275`, 0.9339532087186491], 
             UndirectedEdge[109, 181] -> 
             RGBColor[
              0.18812311022869774`, 0.31505969491742614`, 0.9340247048730984],
              UndirectedEdge[59, 296] -> 
             RGBColor[
              0.2957363483745861, 0.42467629385936273`, 0.9402809691977339], 
             UndirectedEdge[168, 378] -> 
             RGBColor[
              0.18751181267223727`, 0.3144171824270826, 0.9339898923815917], 
             UndirectedEdge[191, 370] -> 
             RGBColor[
              0.19715574767547106`, 0.3245535695762768, 0.9345391002131025], 
             UndirectedEdge[153, 184] -> 
             RGBColor[
              0.18277753601960423`, 0.3094411574946885, 0.933720282329959], 
             UndirectedEdge[3, 91] -> 
             RGBColor[
              0.5375833562526594, 0.6354734123169479, 0.9567396775183801], 
             UndirectedEdge[149, 210] -> 
             RGBColor[
              0.26112860842944113`, 0.3917931023423411, 0.9381822599936748], 
             UndirectedEdge[3, 312] -> 
             RGBColor[
              0.44238894573366777`, 0.553566674835752, 0.9503937941922995], 
             UndirectedEdge[17, 388] -> 
             RGBColor[
              0.22559527698605156`, 0.35444531805200136`, 0.9361586893348268],
              UndirectedEdge[99, 243] -> 
             RGBColor[
              0.9675815557220673, 0.9753429578546242, 0.9397601494648378], 
             UndirectedEdge[108, 398] -> 
             RGBColor[
              0.34112387915000547`, 0.4650235569768793, 0.9431351310396142], 
             UndirectedEdge[57, 186] -> 
             RGBColor[
              0.21226621689950026`, 0.3404356307898151, 0.9353996190814751], 
             UndirectedEdge[180, 398] -> 
             RGBColor[
              0.3423187854528118, 0.46627947926256413`, 0.9432031791858535], 
             UndirectedEdge[66, 318] -> 
             RGBColor[
              0.20433061997593613`, 0.33209481527724394`, 0.9349476985763416],
              UndirectedEdge[374, 382] -> 
             RGBColor[
              0.18605529017041303`, 0.3128862849288049, 0.9339069455798448], 
             UndirectedEdge[190, 270] -> 
             RGBColor[
              0.6576592800193992, 0.7261622336829004, 0.951547961847741], 
             UndirectedEdge[47, 96] -> 
             RGBColor[
              0.6461513889555156, 0.7219924964871992, 0.9663950668318202], 
             UndirectedEdge[245, 328] -> 
             RGBColor[
              0.8357302891053365, 0.26397824350067983`, 0.18139186023278991`],
              UndirectedEdge[142, 143] -> 
             RGBColor[
              0.1837659567931899, 0.3104800503972236, 0.9337765714307771], 
             UndirectedEdge[268, 373] -> 
             RGBColor[
              0.475607023803843, 0.5762529501811211, 0.9537345477094038], 
             UndirectedEdge[69, 390] -> 
             RGBColor[
              0.2522635992417797, 0.3824754156120626, 0.9376774108350432], 
             UndirectedEdge[91, 112] -> 
             RGBColor[
              0.7152028502193496, 0.6939405622428378, 0.6107535397674092], 
             UndirectedEdge[16, 190] -> 
             RGBColor[
              0.6369974104682594, 0.7082659607734624, 0.9502314057905163], 
             UndirectedEdge[40, 395] -> 
             RGBColor[
              0.494849422028799, 0.60078007937222, 0.9533755056767188], 
             UndirectedEdge[84, 246] -> 
             RGBColor[
              0.6295415881560444, 0.703574353083331, 0.9675332208830456], 
             UndirectedEdge[196, 376] -> 
             RGBColor[
              0.19966869054902864`, 0.32719483186616644`, 0.9346822085921858],
              UndirectedEdge[37, 311] -> 
             RGBColor[
              0.3257713181858094, 0.4560335502623456, 0.9419991567290754], 
             UndirectedEdge[179, 275] -> 
             RGBColor[
              0.34634920232824207`, 0.46792331791250663`, 0.9435317259645368],
              UndirectedEdge[334, 340] -> 
             RGBColor[
              0.1939578430419053, 0.32119236904753456`, 0.934356984275097], 
             UndirectedEdge[23, 366] -> 
             RGBColor[
              0.34372780451171075`, 0.47069085221995155`, 0.9431761242698371],
              UndirectedEdge[295, 351] -> 
             RGBColor[
              0.6694121408599306, 0.7384677850374681, 0.9699082105749879], 
             UndirectedEdge[358, 363] -> 
             RGBColor[
              0.20533835444542115`, 0.3331540080987284, 0.9350050875635693], 
             UndirectedEdge[111, 116] -> 
             RGBColor[
              0.1862942905711151, 0.31313748950344333`, 0.9339205562990953], 
             UndirectedEdge[147, 371] -> 
             RGBColor[
              0.18501189214807195`, 0.3117896074520688, 0.9338475256060415], 
             UndirectedEdge[33, 311] -> 
             RGBColor[
              0.28964287283882917`, 0.4217634021453914, 0.9398061051687154], 
             UndirectedEdge[137, 178] -> 
             RGBColor[
              0.3880768646119117, 0.5105544076416471, 0.9459488925435418], 
             UndirectedEdge[328, 386] -> 
             RGBColor[
              0.8151456848541535, 0.6567413505380229, 0.5948173850288303], 
             UndirectedEdge[20, 36] -> 
             RGBColor[
              0.19158305641128354`, 0.3186963177285822, 0.934221743689665], 
             UndirectedEdge[107, 212] -> 
             RGBColor[
              0.3829775514957524, 0.5061376389193594, 0.9456239688209257], 
             UndirectedEdge[21, 27] -> 
             RGBColor[
              0.8684261923998754, 0.40432118743230555`, 0.21570221410383633`],
              UndirectedEdge[138, 329] -> 
             RGBColor[
              0.18634787164566047`, 0.31319380661002694`, 0.9339236076620245],
              UndirectedEdge[3, 263] -> 
             RGBColor[
              0.48691076315351817`, 0.5926689051451934, 0.9532109250744729], 
             UndirectedEdge[239, 269] -> 
             RGBColor[
              0.799702445338238, 0.4094726078345682, 0.44117170841842035`], 
             UndirectedEdge[74, 86] -> 
             RGBColor[
              0.6370413534700665, 0.7120367862892685, 0.9671058051428245], 
             UndirectedEdge[91, 179] -> 
             RGBColor[
              0.47362295187637204`, 0.5835474746608966, 0.9517044801911976], 
             UndirectedEdge[316, 358] -> 
             RGBColor[
              0.212564816221155, 0.34074947760916474`, 0.9354166238711052], 
             UndirectedEdge[154, 267] -> 
             RGBColor[
              0.23074964895808886`, 0.359862889800671, 0.9364522231934242], 
             UndirectedEdge[25, 357] -> 
             RGBColor[
              0.8305794964059033, 0.23605298616234965`, 0.17691626633388163`],
              UndirectedEdge[118, 388] -> 
             RGBColor[
              0.2291977478565746, 0.35823174334676655`, 0.936363844721525], 
             UndirectedEdge[305, 340] -> 
             RGBColor[
              0.19258396167334632`, 0.31974833262006913`, 0.9342787437636328],
              UndirectedEdge[100, 213] -> 
             RGBColor[
              0.21638299645224862`, 0.344762627118653, 0.9356340635867745], 
             UndirectedEdge[51, 238] -> 
             RGBColor[
              0.3357800727610889, 0.463522711822467, 0.942680108320078], 
             UndirectedEdge[104, 242] -> 
             RGBColor[
              0.8300972241361643, 0.2323460301640793, 0.17645444186373088`], 
             UndirectedEdge[99, 337] -> 
             RGBColor[
              0.9798418672906987, 0.9817838609022704, 0.7682315700129669], 
             UndirectedEdge[143, 302] -> 
             RGBColor[
              0.1882090973662136, 0.3151500728508547, 0.9340296017133733], 
             UndirectedEdge[14, 327] -> 
             RGBColor[
              0.19007805312865012`, 0.317114463855815, 0.9341360359791719], 
             UndirectedEdge[162, 348] -> 
             RGBColor[
              0.3027342580511927, 0.4332679187418763, 0.9406342199418414], 
             UndirectedEdge[130, 391] -> 
             RGBColor[
              0.18156952589467779`, 0.3081714622611251, 0.9336514879404352], 
             UndirectedEdge[182, 386] -> 
             RGBColor[
              0.5546461678159978, 0.6446668165900299, 0.9601091386691207], 
             UndirectedEdge[32, 217] -> 
             RGBColor[
              0.975050917301262, 0.9271533469602427, 0.3873122304251019], 
             UndirectedEdge[3, 285] -> 
             RGBColor[
              0.7880339609127915, 0.8307135264515318, 0.7851026525209982], 
             UndirectedEdge[212, 274] -> 
             RGBColor[
              0.45520745425599235`, 0.5676199598754534, 0.950524688408067], 
             UndirectedEdge[234, 272] -> 
             RGBColor[
              0.7633280108193825, 0.8150369106506357, 0.9770450604787972], 
             UndirectedEdge[24, 104] -> 
             RGBColor[
              0.8201942750031774, 0.15622762362796194`, 0.16697136659020134`],
              UndirectedEdge[317, 327] -> 
             RGBColor[
              0.19548056477531295`, 0.3227928461354802, 0.9344437010251496], 
             UndirectedEdge[85, 263] -> 
             RGBColor[
              0.31634895902864796`, 0.44214016934946804`, 0.941608656513351], 
             UndirectedEdge[169, 300] -> 
             RGBColor[
              0.9052440838676142, 0.9272810765527117, 0.9908241829118685], 
             UndirectedEdge[34, 162] -> 
             RGBColor[
              0.2677884948207052, 0.39879306520074553`, 0.9385615306712383], 
             UndirectedEdge[62, 313] -> 
             RGBColor[
              0.20973650567435648`, 0.3377767438992335, 0.9352555557695754], 
             UndirectedEdge[337, 367] -> 
             RGBColor[
              0.6845644891406854, 0.7444870601720963, 0.7692660513213518], 
             UndirectedEdge[21, 240] -> 
             RGBColor[
              0.8755266503036192, 0.45889841832097356`, 0.22250162061128162`],
              UndirectedEdge[258, 378] -> 
             RGBColor[
              0.18711323001988966`, 0.3139982467878655, 0.9339671936891907], 
             UndirectedEdge[240, 242] -> 
             RGBColor[
              0.8385504243860425, 0.29732103150061207`, 0.18454923596953843`],
              UndirectedEdge[16, 380] -> 
             RGBColor[
              0.26894987250182517`, 0.3991789072508731, 0.9386582369767682], 
             UndirectedEdge[38, 222] -> 
             RGBColor[
              0.22765792346573496`, 0.35661329028148886`, 0.9362761540004327],
              UndirectedEdge[61, 147] -> 
             RGBColor[
              0.19642039468713995`, 0.32378066696146846`, 0.9344972229482744],
              UndirectedEdge[279, 288] -> 
             RGBColor[
              0.4888026931766387, 0.5910842948036721, 0.9543337450913586], 
             UndirectedEdge[192, 384] -> 
             RGBColor[
              0.1855895073220066, 0.3123967176227914, 0.933880419935692], 
             UndirectedEdge[196, 289] -> 
             RGBColor[
              0.18795157808443957`, 0.3148794037580448, 0.934014936371242], 
             UndirectedEdge[9, 384] -> 
             RGBColor[
              0.19029625552141455`, 0.3173438084054412, 0.9341484622826384], 
             UndirectedEdge[114, 187] -> 
             RGBColor[
              0.33810546577905015`, 0.4610349816709624, 0.9429931157731941], 
             UndirectedEdge[90, 274] -> 
             RGBColor[
              0.5507285778663977, 0.6461452954084659, 0.9577745175163469], 
             UndirectedEdge[270, 324] -> 
             RGBColor[
              0.49611443813109957`, 0.5992488163397677, 0.9541819472641316], 
             UndirectedEdge[42, 45] -> 
             RGBColor[
              0.2506616815740248, 0.3807916985758058, 0.9375861839936894], 
             UndirectedEdge[316, 363] -> 
             RGBColor[
              0.2271273365064473, 0.3560556097461213, 0.9362459378580343], 
             UndirectedEdge[44, 250] -> 
             RGBColor[
              0.24751102743025372`, 0.3774801613076919, 0.9374067589011768], 
             UndirectedEdge[213, 352] -> 
             RGBColor[
              0.23111045171034733`, 0.3602421163695104, 0.9364727703764056], 
             UndirectedEdge[80, 378] -> 
             RGBColor[
              0.18531329630253898`, 0.3121064023285408, 0.9338646901267509], 
             UndirectedEdge[238, 272] -> 
             RGBColor[
              0.5154577316990447, 0.6098310076277607, 0.9573191957441505], 
             UndirectedEdge[126, 196] -> 
             RGBColor[
              0.1881608487233165, 0.3150993604680292, 0.9340268540245378], 
             UndirectedEdge[112, 240] -> 
             RGBColor[
              0.8668285727789392, 0.4258405852121313, 0.20807034360844792`], 
             UndirectedEdge[52, 89] -> 
             RGBColor[
              0.18430520538442102`, 0.31104683485694296`, 0.933807280840301], 
             UndirectedEdge[99, 177] -> 
             RGBColor[
              0.9302447173684912, 0.9464438866842635, 0.9664424725007652], 
             UndirectedEdge[41, 206] -> 
             RGBColor[
              0.8010921103082493, 0.8449578955447232, 0.9806977415425538], 
             UndirectedEdge[1, 119] -> 
             RGBColor[
              0.18798137752672578`, 0.3149107248612813, 0.9340166334053959], 
             UndirectedEdge[2, 109] -> 
             RGBColor[
              0.1831541470606865, 0.30983699957738503`, 0.9337417297716024], 
             UndirectedEdge[8, 100] -> 
             RGBColor[
              0.22397988652346618`, 0.35274744025415317`, 0.9360666952377386],
              UndirectedEdge[203, 322] -> 
             RGBColor[
              0.2128310735235297, 0.3410293309156486, 0.935431786830583], 
             UndirectedEdge[98, 193] -> 
             RGBColor[
              0.1939801662783198, 0.32121583218438116`, 0.9343582555503864], 
             UndirectedEdge[141, 285] -> 
             RGBColor[
              0.908464702608926, 0.6517279650966425, 0.34303552105754676`], 
             UndirectedEdge[29, 231] -> 
             RGBColor[
              0.1818156421264654, 0.3084301460254042, 0.9336655038957391], 
             UndirectedEdge[225, 398] -> 
             RGBColor[
              0.6554022589203814, 0.7271955623129416, 0.9686184880711814], 
             UndirectedEdge[149, 359] -> 
             RGBColor[
              0.20190369877404518`, 0.3295439672183649, 0.9348094890042022], 
             UndirectedEdge[87, 235] -> 
             RGBColor[
              0.1948464738725398, 0.3221263763929803, 0.9344075904862901], 
             UndirectedEdge[162, 312] -> 
             RGBColor[
              0.28761893872861966`, 0.41963611907072695`, 0.9396908451152812],
              UndirectedEdge[392, 395] -> 
             RGBColor[
              0.729861417537885, 0.7850410988470374, 0.8743691386056183], 
             UndirectedEdge[212, 268] -> 
             RGBColor[
              0.5483496579696843, 0.6426701443947892, 0.9582447440009759], 
             UndirectedEdge[50, 271] -> 
             RGBColor[
              0.17906803055065768`, 0.3055422320505946, 0.933509031481224], 
             UndirectedEdge[200, 207] -> 
             RGBColor[
              0.1859857863076916, 0.31281323196228517`, 0.9339029874376845], 
             UndirectedEdge[360, 370] -> 
             RGBColor[
              0.18616848137367975`, 0.313005256060175, 0.9339133916514194], 
             UndirectedEdge[134, 246] -> 
             RGBColor[
              0.8756067697264411, 0.9036490867400013, 0.9879973494315406], 
             UndirectedEdge[88, 191] -> 
             RGBColor[
              0.19934659159346146`, 0.326856285441612, 0.9346638655331689], 
             UndirectedEdge[277, 278] -> 
             RGBColor[
              0.23299059780069237`, 0.3622182691186103, 0.9365798419148239], 
             UndirectedEdge[233, 242] -> 
             RGBColor[
              0.8879844020549108, 0.5916166599074094, 0.4496598100227772], 
             UndirectedEdge[66, 123] -> 
             RGBColor[
              0.21298431371887483`, 0.3411903960769459, 0.9354405136330093], 
             UndirectedEdge[315, 316] -> 
             RGBColor[
              0.22659989124895852`, 0.3555012313385397, 0.9362159006309058], 
             UndirectedEdge[127, 216] -> 
             RGBColor[
              0.19725740387013102`, 0.32466041668223944`, 0.9345448893830015],
              UndirectedEdge[29, 326] -> 
             RGBColor[
              0.18672499245337307`, 0.31359018448977305`, 0.9339450841341236],
              UndirectedEdge[76, 145] -> 
             RGBColor[
              0.19557703724460856`, 0.3228942448174177, 0.9344491949895577], 
             UndirectedEdge[21, 104] -> 
             RGBColor[
              0.867073450053741, 0.3939234169844408, 0.2144068265054741], 
             UndirectedEdge[27, 112] -> 
             RGBColor[
              0.8597281148751953, 0.37126335432346336`, 0.20127093710100263`],
              UndirectedEdge[190, 221] -> 
             RGBColor[
              0.9292638455200164, 0.8080779972178733, 0.5995947563336426], 
             UndirectedEdge[310, 324] -> 
             RGBColor[
              0.45636436031597766`, 0.5621244658109066, 0.9517477784200521], 
             UndirectedEdge[11, 312] -> 
             RGBColor[
              0.30743684398278903`, 0.44016840506601096`, 0.9408303416909466],
              UndirectedEdge[177, 225] -> 
             RGBColor[
              0.8897813970600477, 0.9149515498158103, 0.9893493380404593], 
             UndirectedEdge[253, 316] -> 
             RGBColor[
              0.2127233679212677, 0.3409161254987416, 0.9354256531558705], 
             UndirectedEdge[17, 323] -> 
             RGBColor[
              0.3151837063156497, 0.44029240167692024`, 0.9415651086599703], 
             UndirectedEdge[315, 397] -> 
             RGBColor[
              0.21588466984352767`, 0.3442388542571554, 0.935605684623616], 
             UndirectedEdge[43, 296] -> 
             RGBColor[
              0.2526601828418626, 0.38289225012060224`, 0.937699995684375], 
             UndirectedEdge[50, 287] -> 
             RGBColor[
              0.18448432655099875`, 0.31123510255995407`, 0.9338174815257515],
              UndirectedEdge[253, 369] -> 
             RGBColor[
              0.19084530468760944`, 0.3179208938908398, 0.9341797298204076], 
             UndirectedEdge[187, 220] -> 
             RGBColor[
              0.5353714211663698, 0.63317812373389, 0.9567035702854296], 
             UndirectedEdge[211, 340] -> 
             RGBColor[
              0.21241214123474167`, 0.34058900651829105`, 0.9354079292564914],
              UndirectedEdge[213, 227] -> 
             RGBColor[
              0.2150440363795939, 0.343355295187321, 0.9355578117914507], 
             UndirectedEdge[17, 389] -> 
             RGBColor[
              0.21716250001380405`, 0.34558193478522814`, 0.9356784551614329],
              UndirectedEdge[117, 376] -> 
             RGBColor[
              0.217871456795024, 0.34632709331274647`, 0.9357188292013159], 
             UndirectedEdge[186, 330] -> 
             RGBColor[
              0.19639093276449526`, 0.3237497006127751, 0.9344955451353647], 
             UndirectedEdge[24, 337] -> 
             RGBColor[
              0.8785401737932351, 0.4370799726332635, 0.30949628574974347`], 
             UndirectedEdge[73, 99] -> 
             RGBColor[
              0.9481261161147958, 0.8682562660194123, 0.6030407890629428], 
             UndirectedEdge[114, 155] -> 
             RGBColor[
              0.2241859587617661, 0.352964035242341, 0.9360784307468533], 
             UndirectedEdge[123, 232] -> 
             RGBColor[
              0.2533953304852037, 0.3836649369048065, 0.9377418612551098], 
             UndirectedEdge[53, 289] -> 
             RGBColor[
              0.18928237138329773`, 0.3162781518923132, 0.9340907230808797], 
             UndirectedEdge[126, 376] -> 
             RGBColor[
              0.19809406452812484`, 0.3255398000811405, 0.9345925359697458], 
             UndirectedEdge[207, 254] -> 
             RGBColor[
              0.18750231875154622`, 0.3144072037144869, 0.9339893517168534], 
             UndirectedEdge[291, 304] -> 
             RGBColor[
              0.1840328398717771, 0.3107605614341833, 0.9337917700272845], 
             UndirectedEdge[333, 368] -> 
             RGBColor[
              0.18664235406415453`, 0.3135033263031278, 0.9339403780001101], 
             UndirectedEdge[26, 171] -> 
             RGBColor[
              0.18798107467478986`, 0.3149104065446947, 0.9340166161584262], 
             UndirectedEdge[81, 384] -> 
             RGBColor[
              0.18455785037421688`, 0.3113123807598359, 0.9338216685987151], 
             UndirectedEdge[120, 233] -> 
             RGBColor[
              0.7388527640498924, 0.7945317751585553, 0.9544100950493892], 
             UndirectedEdge[224, 290] -> 
             RGBColor[
              0.18877579274929696`, 0.3157457056290379, 0.9340618741770893], 
             UndirectedEdge[393, 396] -> 
             RGBColor[
              0.19146055662429076`, 0.3185675626855177, 0.9342147675080179], 
             UndirectedEdge[2, 365] -> 
             RGBColor[
              0.18295812271216946`, 0.3096309655584321, 0.9337305664749465], 
             UndirectedEdge[210, 387] -> 
             RGBColor[
              0.4198898949581986, 0.5356292280658739, 0.9485927029346032], 
             UndirectedEdge[23, 307] -> 
             RGBColor[
              0.32070535665531497`, 0.4507499650286162, 0.9417091542503788], 
             UndirectedEdge[120, 244] -> 
             RGBColor[
              0.7365322986249497, 0.7928011758440465, 0.9583380377395063], 
             UndirectedEdge[42, 248] -> 
             RGBColor[
              0.21725641238251098`, 0.34568064263912723`, 0.9356838033318999],
              UndirectedEdge[49, 393] -> 
             RGBColor[
              0.1855205539729795, 0.3123242432810691, 0.9338764931444723], 
             UndirectedEdge[375, 377] -> 
             RGBColor[
              0.18266643619111367`, 0.3093243845308089, 0.9337139553590839], 
             UndirectedEdge[269, 350] -> 
             RGBColor[
              0.8687159863176557, 0.8956679071093385, 0.8633270413739342], 
             UndirectedEdge[77, 207] -> 
             RGBColor[
              0.18528324242742453`, 0.31207481380026975`, 0.9338629786030239],
              UndirectedEdge[200, 368] -> 
             RGBColor[
              0.18469320535133593`, 0.3114546474227893, 0.9338293768644222], 
             UndirectedEdge[384, 389] -> 
             RGBColor[
              0.1961032591776717, 0.32344733743346465`, 0.93447916255017], 
             UndirectedEdge[1, 361] -> 
             RGBColor[
              0.205591391562574, 0.33341996615233593`, 0.9350194976530564], 
             UndirectedEdge[150, 380] -> 
             RGBColor[
              0.20683506244234898`, 0.3347271431002675, 0.9350903228698133], 
             UndirectedEdge[150, 381] -> 
             RGBColor[
              0.19485465175919953`, 0.32213497187036766`, 0.9344080562048372],
              UndirectedEdge[232, 279] -> 
             RGBColor[
              0.48366351594508233`, 0.5856826936906501, 0.9540410765507529], 
             UndirectedEdge[132, 341] -> 
             RGBColor[
              0.34725423307667924`, 0.4751958960109486, 0.9433477105601525], 
             UndirectedEdge[1, 14] -> 
             RGBColor[
              0.18904790384743964`, 0.31603171164602595`, 0.9340773705015762],
              UndirectedEdge[171, 342] -> 
             RGBColor[
              0.18633859981298379`, 0.3131840613260155, 0.9339230796448701], 
             UndirectedEdge[140, 325] -> 
             RGBColor[
              0.25741913844630737`, 0.3878942141960865, 0.9379710111658044], 
             UndirectedEdge[89, 306] -> 
             RGBColor[
              0.1959786892882613, 0.3233164065815071, 0.9344720684792528], 
             UndirectedEdge[130, 147] -> 
             RGBColor[
              0.18274418895711692`, 0.3094061076176884, 0.9337183832640827], 
             UndirectedEdge[4, 183] -> 
             RGBColor[
              0.2914028738694214, 0.4198002713108441, 0.9400459473606144], 
             UndirectedEdge[80, 151] -> 
             RGBColor[
              0.18591365690063838`, 0.3127374193822037, 0.9338988797746588], 
             UndirectedEdge[236, 286] -> 
             RGBColor[
              0.22281035809500455`, 0.3515181917234548, 0.9360000923239], 
             UndirectedEdge[108, 180] -> 
             RGBColor[
              0.25734842126298235`, 0.38781988595268346`, 0.9379669839268308],
              UndirectedEdge[9, 320] -> 
             RGBColor[
              0.1934136507337484, 0.32062038842787655`, 0.9343259933282078], 
             UndirectedEdge[35, 97] -> 
             RGBColor[
              0.21457055736469166`, 0.3428576387223553, 0.9355308478620015], 
             UndirectedEdge[154, 236] -> 
             RGBColor[
              0.22814394288837742`, 0.3571241275100973, 0.936303832087551], 
             UndirectedEdge[60, 259] -> 
             RGBColor[
              0.18612091931381164`, 0.3129552653196448, 0.9339106830624717], 
             UndirectedEdge[179, 399] -> 
             RGBColor[
              0.6902620685345601, 0.6570900539452929, 0.6049675909800379], 
             UndirectedEdge[314, 352] -> 
             RGBColor[
              0.23613835462959704`, 0.3655267611250992, 0.9367591020095412], 
             UndirectedEdge[85, 88] -> 
             RGBColor[
              0.21610734049788477`, 0.34447289523301966`, 0.9356183653879699],
              UndirectedEdge[70, 267] -> 
             RGBColor[
              0.23945129119348169`, 0.3690088675060522, 0.9369477688458039], 
             UndirectedEdge[31, 192] -> 
             RGBColor[
              0.18904880805086632`, 0.3160326620211572, 0.9340774219946237], 
             UndirectedEdge[221, 255] -> 
             RGBColor[
              0.8576770558672095, 0.3983014989226451, 0.2010622967587482], 
             UndirectedEdge[11, 211] -> 
             RGBColor[
              0.2669271143125195, 0.39759011071734907`, 0.9385233725149993], 
             UndirectedEdge[211, 312] -> 
             RGBColor[
              0.26239927833008236`, 0.39312865697304, 0.9382546227647286], 
             UndirectedEdge[123, 280] -> 
             RGBColor[
              0.23161694690439888`, 0.3607744749321087, 0.9365016145284144], 
             UndirectedEdge[178, 278] -> 
             RGBColor[
              0.349928065209785, 0.47283535767355744`, 0.9436893135230188], 
             UndirectedEdge[83, 364] -> 
             RGBColor[
              0.8601295771796166, 0.41076224408032325`, 0.4356827738189095], 
             UndirectedEdge[10, 313] -> 
             RGBColor[
              0.22793409689467709`, 0.35690356606571383`, 0.9362918816686491],
              UndirectedEdge[32, 242] -> 
             RGBColor[
              0.8871930329121218, 0.5574419643171217, 0.22765320532955294`], 
             UndirectedEdge[44, 369] -> 
             RGBColor[
              0.21363611782330827`, 0.34187548351747254`, 0.9354776329124991],
              UndirectedEdge[110, 375] -> 
             RGBColor[
              0.18201536929507323`, 0.30864007194304494`, 0.9336768780625215],
              UndirectedEdge[275, 290] -> 
             RGBColor[
              0.21848378643908228`, 0.34697069059259356`, 0.9357537004686844],
              UndirectedEdge[362, 369] -> 
             RGBColor[
              0.18988137332818844`, 0.31690774091531027`, 0.9341248353554973],
              UndirectedEdge[266, 338] -> 
             RGBColor[
              0.23347632110247196`, 0.3627287951054168, 0.936607503138297], 
             UndirectedEdge[350, 395] -> 
             RGBColor[
              0.7312446954176929, 0.785613119798958, 0.8514446443288036], 
             UndirectedEdge[141, 172] -> 
             RGBColor[
              0.8516660985539529, 0.38305028155577586`, 0.19651818563350704`],
              UndirectedEdge[123, 275] -> 
             RGBColor[
              0.22522408057531274`, 0.3540551670891031, 0.9361375502483711], 
             UndirectedEdge[46, 315] -> 
             RGBColor[
              0.21006971303598748`, 0.3381269659628746, 0.9352745314358842], 
             UndirectedEdge[185, 205] -> 
             RGBColor[
              0.3748090292582385, 0.49906247551909, 0.9451034778070919], 
             UndirectedEdge[3, 86] -> 
             RGBColor[
              0.49644576954540676`, 0.6009276484384913, 0.9538184872502891], 
             UndirectedEdge[316, 397] -> 
             RGBColor[
              0.2236385768767503, 0.3523887021751733, 0.9360472581582806], 
             UndirectedEdge[11, 214] -> 
             RGBColor[
              0.2758548681185897, 0.40697374601981373`, 0.9390317948868268], 
             UndirectedEdge[3, 34] -> 
             RGBColor[
              0.4225585018257533, 0.5327236209657705, 0.9492644797482566], 
             UndirectedEdge[5, 100] -> 
             RGBColor[
              0.24629351933764826`, 0.37620048310789195`, 0.9373374236164447],
              UndirectedEdge[25, 245] -> 
             RGBColor[
              0.8178226851727047, 0.13799854495365815`, 0.16470032949021304`],
              UndirectedEdge[183, 325] -> 
             RGBColor[
              0.3195630144976964, 0.44939836456720006`, 0.9416496257101998], 
             UndirectedEdge[149, 266] -> 
             RGBColor[
              0.22467790350563632`, 0.35348110035924685`, 0.9361064462722496],
              UndirectedEdge[73, 78] -> 
             RGBColor[
              0.8568301580726646, 0.357042989472686, 0.19882692230699478`], 
             UndirectedEdge[40, 167] -> 
             RGBColor[
              0.4156571514498516, 0.5326037138579458, 0.948214502475271], 
             UndirectedEdge[5, 175] -> 
             RGBColor[
              0.282045444074704, 0.41377802280949016`, 0.9393734428399871], 
             UndirectedEdge[279, 309] -> 
             RGBColor[
              0.48491537307549215`, 0.5869984749070372, 0.9541123679623731], 
             UndirectedEdge[66, 257] -> 
             RGBColor[
              0.268687595913645, 0.3984105456780595, 0.9386613405898359], 
             UndirectedEdge[238, 309] -> 
             RGBColor[
              0.29378936272937667`, 0.4261216259230004, 0.9400422416338], 
             UndirectedEdge[40, 355] -> 
             RGBColor[
              0.6433835290110301, 0.7194772226865849, 0.9663605408410356], 
             UndirectedEdge[31, 271] -> 
             RGBColor[
              0.18778814176396494`, 0.3147076218227647, 0.9340056289145733], 
             UndirectedEdge[271, 391] -> 
             RGBColor[
              0.1801133509320429, 0.3066409300485706, 0.9335685609305309], 
             UndirectedEdge[264, 348] -> 
             RGBColor[
              0.5282156563331551, 0.6233653822352514, 0.957751476691993], 
             UndirectedEdge[146, 302] -> 
             RGBColor[
              0.18875875182792845`, 0.3157277945402228, 0.9340609037218272], 
             UndirectedEdge[86, 91] -> 
             RGBColor[
              0.45216024233108254`, 0.5649746624056373, 0.950332168324746], 
             UndirectedEdge[232, 257] -> 
             RGBColor[
              0.30909861267997385`, 0.4408850865059202, 0.9409626882119364], 
             UndirectedEdge[201, 385] -> 
             RGBColor[
              0.9717345415002878, 0.9760010739812197, 0.8028741323146045], 
             UndirectedEdge[204, 297] -> 
             RGBColor[
              0.2002775476373886, 0.32783477926980176`, 0.9347168821026446], 
             UndirectedEdge[241, 323] -> 
             RGBColor[
              0.3309521511254019, 0.4568660369491151, 0.9424630982645621], 
             UndirectedEdge[269, 395] -> 
             RGBColor[
              0.6061102125080312, 0.6895560016714635, 0.9631945161165028], 
             UndirectedEdge[52, 342] -> 
             RGBColor[
              0.18153992013799802`, 0.30814034473374124`, 0.9336498019363901],
              UndirectedEdge[201, 245] -> 
             RGBColor[
              0.8622346252859692, 0.4176669244919702, 0.43415659032342135`], 
             UndirectedEdge[131, 330] -> 
             RGBColor[
              0.199593351679308, 0.3271156459373298, 0.9346779181550091], 
             UndirectedEdge[159, 349] -> 
             RGBColor[
              0.191248937492894, 0.31834513756099186`, 0.9342027161115474], 
             UndirectedEdge[15, 33] -> 
             RGBColor[
              0.28118366953987284`, 0.41287224313372134`, 0.9393243660551096],
              UndirectedEdge[16, 212] -> 
             RGBColor[
              0.36755596390986156`, 0.4927802348639901, 0.9446413188967272], 
             UndirectedEdge[246, 269] -> 
             RGBColor[
              0.8319134288403021, 0.869426735678431, 0.9836659653182612], 
             UndirectedEdge[150, 294] -> 
             RGBColor[
              0.19175282420721007`, 0.318874754446001, 0.9342314117144941], 
             UndirectedEdge[77, 200] -> 
             RGBColor[
              0.1835118014697444, 0.3102129170379042, 0.9337620976610961], 
             UndirectedEdge[21, 285] -> 
             RGBColor[
              0.9787005711665018, 0.9387674260406853, 0.4607634302742779], 
             UndirectedEdge[275, 280] -> 
             RGBColor[
              0.24514319627116127`, 0.3749914206303192, 0.9372719144195587], 
             UndirectedEdge[171, 353] -> 
             RGBColor[
              0.1894918158351776, 0.3164982912907842, 0.9341026506325689], 
             UndirectedEdge[197, 252] -> 
             RGBColor[
              0.6669388623748537, 0.7337127880117662, 0.9450324457252983], 
             UndirectedEdge[15, 361] -> 
             RGBColor[
              0.2517308007762076, 0.3819154106433724, 0.9376470687506336], 
             UndirectedEdge[348, 366] -> 
             RGBColor[
              0.3637695245894192, 0.4895006114365967, 0.9444000503314454], 
             UndirectedEdge[235, 298] -> 
             RGBColor[
              0.19425582793699694`, 0.3215055700656095, 0.9343739540740432], 
             UndirectedEdge[62, 298] -> 
             RGBColor[
              0.19905173523661984`, 0.32654637271559867`, 0.9346470738998478],
              UndirectedEdge[110, 308] -> 
             RGBColor[
              0.1924672891129, 0.3196257023615725, 0.9342720994339171], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.2089266760744028, 0.33692556164351994`, 0.9352094371718936], 
             UndirectedEdge[204, 290] -> 
             RGBColor[
              0.19592590704111568`, 0.32326092909316934`, 0.9344690626083623],
              UndirectedEdge[35, 93] -> 
             RGBColor[
              0.235285884487402, 0.3646307609559235, 0.9367105550960597], 
             UndirectedEdge[162, 211] -> 
             RGBColor[
              0.24710920905835015`, 0.37705782472206506`, 0.9373838759393338],
              UndirectedEdge[66, 275] -> 
             RGBColor[
              0.22651056308563722`, 0.3554073417751564, 0.9362108135241538], 
             UndirectedEdge[36, 277] -> 
             RGBColor[
              0.20034660319217895`, 0.3279073610362615, 0.9347208147143313], 
             UndirectedEdge[174, 246] -> 
             RGBColor[
              0.6321209059841302, 0.7058084285457353, 0.96769757273425], 
             UndirectedEdge[218, 329] -> 
             RGBColor[
              0.19065196008399016`, 0.31771767645368004`, 0.9341687191312593],
              UndirectedEdge[186, 188] -> 
             RGBColor[
              0.20431810644449144`, 0.33208166276229184`, 0.934946985949238], 
             UndirectedEdge[230, 245] -> 
             RGBColor[
              0.8181022296024069, 0.1401472459374997, 0.16496802155179616`], 
             UndirectedEdge[57, 368] -> 
             RGBColor[
              0.20142644533340448`, 0.3290423435926357, 0.9347823101267909], 
             UndirectedEdge[293, 316] -> 
             RGBColor[
              0.2916240499210687, 0.42013376007774095`, 0.9400548442196108], 
             UndirectedEdge[8, 308] -> 
             RGBColor[
              0.21965638014980107`, 0.34820316092929426`, 0.9358204779458129],
              UndirectedEdge[37, 361] -> 
             RGBColor[
              0.28321730845770904`, 0.41130658795806163`, 0.939575768828076], 
             UndirectedEdge[19, 331] -> 
             RGBColor[
              0.22977587045111889`, 0.35883938684872224`, 0.9363967679480286],
              UndirectedEdge[98, 276] -> 
             RGBColor[
              0.21193626472305038`, 0.34008883013219005`, 0.9353808287931467],
              UndirectedEdge[326, 336] -> 
             RGBColor[
              0.18618247361472157`, 0.3130199627926692, 0.9339141884888471], 
             UndirectedEdge[4, 13] -> 
             RGBColor[
              0.22349076802527734`, 0.3522333457006528, 0.9360388406628528], 
             UndirectedEdge[137, 300] -> 
             RGBColor[
              0.624581474397714, 0.6994688662935715, 0.9671293704856514], 
             UndirectedEdge[57, 163] -> 
             RGBColor[
              0.24223777275819017`, 0.37193763630369614`, 0.9371064548486839],
              UndirectedEdge[28, 304] -> 
             RGBColor[
              0.1939396212205168, 0.3211732167579251, 0.9343559465693256], 
             UndirectedEdge[83, 328] -> 
             RGBColor[
              0.9072826236616158, 0.729489427357416, 0.5953860262532737], 
             UndirectedEdge[206, 321] -> 
             RGBColor[
              0.6423373781810662, 0.7191701000468311, 0.9659074859341975], 
             UndirectedEdge[295, 373] -> 
             RGBColor[
              0.3504430057094734, 0.4745466699427852, 0.9436757963662827], 
             UndirectedEdge[29, 235] -> 
             RGBColor[
              0.18647615617022215`, 0.31332864177904984`, 0.9339309132759184],
              UndirectedEdge[234, 392] -> 
             RGBColor[
              0.888403326572227, 0.9115564131866241, 0.8883516579502622], 
             UndirectedEdge[42, 275] -> 
             RGBColor[
              0.2276321474655179, 0.3565861980709679, 0.9362746860953526], 
             UndirectedEdge[107, 324] -> 
             RGBColor[
              0.4908741561658506, 0.5947099474856988, 0.9538480411311054], 
             UndirectedEdge[75, 329] -> 
             RGBColor[
              0.20420501368883298`, 0.3319627951056, 0.934940545484109], 
             UndirectedEdge[267, 383] -> 
             RGBColor[
              0.23217032750693795`, 0.361356113031734, 0.9365331287350758], 
             UndirectedEdge[253, 362] -> 
             RGBColor[
              0.19012900620093326`, 0.31716801876539596`, 0.9341389376812601],
              UndirectedEdge[137, 252] -> 
             RGBColor[
              0.35201484785933657`, 0.47931930126023004`, 0.943651052724457], 
             UndirectedEdge[131, 203] -> 
             RGBColor[
              0.2195067441810682, 0.34804588403868764`, 0.9358119563987601], 
             UndirectedEdge[52, 199] -> 
             RGBColor[
              0.1829276009104009, 0.30959888520957934`, 0.9337288283034887], 
             UndirectedEdge[41, 386] -> 
             RGBColor[
              0.8163158098721861, 0.8568507653484726, 0.982215097641526], 
             UndirectedEdge[59, 122] -> 
             RGBColor[
              0.472237479074957, 0.5795226558414852, 0.9523966975119249], 
             UndirectedEdge[32, 172] -> 
             RGBColor[
              0.8682128995601259, 0.4115523422262132, 0.2094778081966871], 
             UndirectedEdge[55, 156] -> 
             RGBColor[
              0.8778676863998269, 0.46477366600547654`, 0.23296809956810122`],
              UndirectedEdge[97, 214] -> 
             RGBColor[
              0.21631731839459667`, 0.3446935953158315, 0.9356303233185532], 
             UndirectedEdge[133, 155] -> 
             RGBColor[
              0.1964342499678622, 0.3237952297399831, 0.9344980119860145], 
             UndirectedEdge[186, 273] -> 
             RGBColor[
              0.19433831903215518`, 0.3215922734368583, 0.9343786518198778], 
             UndirectedEdge[74, 179] -> 
             RGBColor[
              0.6585040630153561, 0.7306095985445278, 0.968478117009276], 
             UndirectedEdge[10, 62] -> 
             RGBColor[
              0.21930338871384658`, 0.34783214454915645`, 0.9358003756057394],
              UndirectedEdge[273, 322] -> 
             RGBColor[
              0.19086506728942945`, 0.31794166563837395`, 0.9341808552713451],
              UndirectedEdge[18, 148] -> 
             RGBColor[
              0.46955925293009415`, 0.5770080258985608, 0.9522798906351313], 
             UndirectedEdge[78, 172] -> 
             RGBColor[
              0.8212261277666325, 0.16415889612864146`, 0.16795946996179692`],
              UndirectedEdge[84, 269] -> 
             RGBColor[
              0.5412096627237364, 0.6337584063867442, 0.9589441687264177], 
             UndirectedEdge[103, 254] -> 
             RGBColor[
              0.19079740219879987`, 0.3178705453379077, 0.9341770018445352], 
             UndirectedEdge[46, 343] -> 
             RGBColor[
              0.19165716183089215`, 0.31877420722314587`, 0.9342259638836825],
              UndirectedEdge[1, 317] -> 
             RGBColor[
              0.19445041549410247`, 0.3217100939256911, 0.9343850355475539], 
             UndirectedEdge[27, 399] -> 
             RGBColor[
              0.8562175118599777, 0.35734498320723135`, 0.1984462235105148], 
             UndirectedEdge[247, 253] -> 
             RGBColor[
              0.19436046466415727`, 0.3216155499002067, 0.9343799129808589], 
             UndirectedEdge[27, 357] -> 
             RGBColor[
              0.8330589874809773, 0.2551114410852856, 0.1792906297875571], 
             UndirectedEdge[41, 55] -> 
             RGBColor[
              0.9217511656674453, 0.9083191148939446, 0.6659672564832814], 
             UndirectedEdge[183, 272] -> 
             RGBColor[
              0.5454600938051113, 0.6375523889526532, 0.9591673986184688], 
             UndirectedEdge[131, 238] -> 
             RGBColor[
              0.2516193138752771, 0.38179823084181674`, 0.9376407197365557], 
             UndirectedEdge[13, 131] -> 
             RGBColor[
              0.21370957013719966`, 0.34195268655651806`, 0.9354818159131122],
              UndirectedEdge[55, 328] -> 
             RGBColor[
              0.9205810406494127, 0.7082097000834948, 0.27856954387058575`], 
             UndirectedEdge[40, 392] -> 
             RGBColor[
              0.7560719179586157, 0.8063199638581745, 0.8764325252109648], 
             UndirectedEdge[39, 347] -> 
             RGBColor[
              0.19051344323313968`, 0.3175720864609606, 0.9341608308015206], 
             UndirectedEdge[195, 362] -> 
             RGBColor[
              0.1955066853579723, 0.3228203005239958, 0.9344451885536901], 
             UndirectedEdge[46, 250] -> 
             RGBColor[
              0.22982046644249732`, 0.3588862600632101, 0.9363993076237638], 
             UndirectedEdge[22, 47] -> 
             RGBColor[
              0.4301895095994409, 0.5445652207348299, 0.9493133718661378], 
             UndirectedEdge[79, 100] -> 
             RGBColor[
              0.22059571881103596`, 0.3491904654197632, 0.9358739718929432], 
             UndirectedEdge[45, 148] -> 
             RGBColor[
              0.30939380782769543`, 0.44018999619208, 0.9410163102615399], 
             UndirectedEdge[65, 68] -> 
             RGBColor[
              0.2789862434779228, 0.41056260901775243`, 0.9391992258916821], 
             UndirectedEdge[86, 162] -> 
             RGBColor[
              0.3416757625403587, 0.46699709267346645`, 0.9431155381732708], 
             UndirectedEdge[3, 264] -> 
             RGBColor[
              0.652580274743898, 0.7275933060781521, 0.9666403041170564], 
             UndirectedEdge[55, 386] -> 
             RGBColor[
              0.8661959692237846, 0.8644995898414272, 0.6605413251423246], 
             UndirectedEdge[315, 362] -> 
             RGBColor[
              0.20400552952862408`, 0.3317531246051941, 0.9349291851562955], 
             UndirectedEdge[92, 182] -> 
             RGBColor[
              0.4229610876060558, 0.5395726978389508, 0.9485023279906137], 
             UndirectedEdge[202, 341] -> 
             RGBColor[
              0.2897972028384973, 0.4193840622352309, 0.9399079526486953], 
             UndirectedEdge[86, 125] -> 
             RGBColor[
              0.3362672755569396, 0.46131242993601224`, 0.9428075328407044], 
             UndirectedEdge[155, 353] -> 
             RGBColor[
              0.19855109199898685`, 0.3260201649302318, 0.9346185630080999], 
             UndirectedEdge[119, 235] -> 
             RGBColor[
              0.18696497458482364`, 0.31384242092567355`, 0.9339587507614879],
              UndirectedEdge[139, 204] -> 
             RGBColor[
              0.19084712474135193`, 0.31792280688272123`, 0.9341798334697757],
              UndirectedEdge[167, 174] -> 
             RGBColor[
              0.3271254190729118, 0.4577613290244936, 0.9420651203310438], 
             UndirectedEdge[218, 349] -> 
             RGBColor[
              0.19642311196174383`, 0.3237835229893623, 0.9344973776930432], 
             UndirectedEdge[362, 397] -> 
             RGBColor[
              0.20104421515641585`, 0.32864059544182767`, 0.9347605426836703],
              UndirectedEdge[70, 108] -> 
             RGBColor[
              0.2395346657598989, 0.3690964994616095, 0.9369525169040198], 
             UndirectedEdge[71, 157] -> 
             RGBColor[
              0.18316059011768585`, 0.3098437716388048, 0.933742096694167], 
             UndirectedEdge[186, 238] -> 
             RGBColor[
              0.24841689496046435`, 0.37843228551726205`, 0.9374583467169113],
              UndirectedEdge[51, 246] -> 
             RGBColor[
              0.6509116591793556, 0.7220840345127228, 0.9688949029118392], 
             UndirectedEdge[109, 305] -> 
             RGBColor[
              0.1817778659169268, 0.3083904408340291, 0.9336633525964908], 
             UndirectedEdge[125, 248] -> 
             RGBColor[
              0.2397553776330553, 0.3693284816342379, 0.936965086118682], 
             UndirectedEdge[106, 390] -> 
             RGBColor[
              0.24476481400135702`, 0.3745937168739334, 0.9372503661090598], 
             UndirectedEdge[1, 231] -> 
             RGBColor[
              0.1878698717924256, 0.3147935252646599, 0.9340102833187854], 
             UndirectedEdge[104, 399] -> 
             RGBColor[
              0.8548647695138434, 0.3469472127593665, 0.19715083591215254`], 
             UndirectedEdge[244, 366] -> 
             RGBColor[
              0.6745824127024198, 0.7409076895841773, 0.9539031392335773], 
             UndirectedEdge[64, 289] -> 
             RGBColor[
              0.18340551527321602`, 0.3101012035064188, 0.9337560448194401], 
             UndirectedEdge[160, 233] -> 
             RGBColor[
              0.7095149174779228, 0.7707139896565038, 0.9521005122991707], 
             UndirectedEdge[100, 302] -> 
             RGBColor[
              0.20076131207818187`, 0.3283432463695126, 0.9347444317718824], 
             UndirectedEdge[177, 337] -> 
             RGBColor[
              0.9444496695413749, 0.9543350995105044, 0.7916221237493946], 
             UndirectedEdge[124, 219] -> 
             RGBColor[
              0.32342751125618663`, 0.45455838713589725`, 0.9418294929148936],
              UndirectedEdge[2, 181] -> 
             RGBColor[
              0.1899547149925528, 0.3169848276546873, 0.9341290120547836], 
             UndirectedEdge[185, 198] -> 
             RGBColor[
              0.3764542800383526, 0.5004875090521163, 0.9452083117319626], 
             UndirectedEdge[11, 35] -> 
             RGBColor[
              0.27410810708868466`, 0.4051377894263376, 0.9389323194302751], 
             UndirectedEdge[5, 56] -> 
             RGBColor[
              0.3320449689742487, 0.4595901829717516, 0.9424676449298229], 
             UndirectedEdge[69, 107] -> 
             RGBColor[
              0.2952174792692931, 0.42393616514341426`, 0.9402585516481101], 
             UndirectedEdge[51, 350] -> 
             RGBColor[
              0.6877142166567092, 0.7483252059436304, 0.8485559789675121], 
             UndirectedEdge[226, 392] -> 
             RGBColor[
              0.7181621296927883, 0.7753237626808771, 0.8735087285822702], 
             UndirectedEdge[81, 292] -> 
             RGBColor[
              0.18697166352319156`, 0.31384945142400145`, 0.9339591316866327],
              UndirectedEdge[51, 272] -> 
             RGBColor[
              0.5612556230240568, 0.6512336824557214, 0.9601738757728618], 
             UndirectedEdge[10, 261] -> 
             RGBColor[
              0.24873551087533646`, 0.3787671710452084, 0.9374764914219134], 
             UndirectedEdge[132, 244] -> 
             RGBColor[
              0.656519419340629, 0.7252624326066381, 0.9527521812690418], 
             UndirectedEdge[53, 376] -> 
             RGBColor[
              0.20099948384788677`, 0.3285935800004348, 0.9347579953018235], 
             UndirectedEdge[242, 364] -> 
             RGBColor[
              0.8407413242303493, 0.31416124776238763`, 0.18664724413471406`],
              UndirectedEdge[29, 327] -> 
             RGBColor[
              0.18852270839333474`, 0.31547969792444663`, 0.934047461397422], 
             UndirectedEdge[328, 364] -> 
             RGBColor[
              0.8349616655917271, 0.2580702663621064, 0.18065582548812142`], 
             UndirectedEdge[257, 279] -> 
             RGBColor[
              0.4976692988631992, 0.5990761277778498, 0.9548872926096961], 
             UndirectedEdge[13, 322] -> 
             RGBColor[
              0.20703389947966117`, 0.33493613343347894`, 0.9351016463449351],
              UndirectedEdge[21, 24] -> 
             RGBColor[
              0.868258601963509, 0.40303301389979596`, 0.21554172931270557`], 
             UndirectedEdge[56, 122] -> 
             RGBColor[
              0.48980661456960395`, 0.5947401579565226, 0.9535161872898672], 
             UndirectedEdge[87, 393] -> 
             RGBColor[
              0.1907711086239872, 0.3178429091236707, 0.9341755044643476], 
             UndirectedEdge[27, 74] -> 
             RGBColor[
              0.8350455081805084, 0.40635801294005464`, 0.44078657419667344`],
              UndirectedEdge[93, 288] -> 
             RGBColor[
              0.2698457094938153, 0.4009553282571281, 0.9386786860034955], 
             UndirectedEdge[125, 211] -> 
             RGBColor[
              0.24170072207493107`, 0.37137316198461084`, 0.9370758706067677],
              UndirectedEdge[265, 304] -> 
             RGBColor[
              0.18543662898340038`, 0.31223603279586976`, 0.9338717137404716],
              UndirectedEdge[195, 343] -> 
             RGBColor[
              0.19193458883998876`, 0.3190658005995948, 0.9342417629414341], 
             UndirectedEdge[199, 393] -> 
             RGBColor[
              0.1849265278957996, 0.3116998842105244, 0.9338426642381596], 
             UndirectedEdge[24, 208] -> 
             RGBColor[
              0.8781963258003285, 0.43764816511070226`, 0.36683204243282114`],
              UndirectedEdge[135, 386] -> 
             RGBColor[
              0.8778014359212141, 0.9022038387539937, 0.8283895042121832], 
             UndirectedEdge[32, 357] -> 
             RGBColor[
              0.8904110749094791, 0.5821772452638048, 0.2307348059804809], 
             UndirectedEdge[230, 233] -> 
             RGBColor[
              0.8649609956701637, 0.4146486695132347, 0.42761257006752507`], 
             UndirectedEdge[46, 161] -> 
             RGBColor[
              0.20037426040526207`, 0.3279364305207805, 0.9347223897517012], 
             UndirectedEdge[114, 306] -> 
             RGBColor[
              0.2220014868268114, 0.35066801673518333`, 0.9359540283017942], 
             UndirectedEdge[233, 357] -> 
             RGBColor[
              0.8912024440522681, 0.6163519408540925, 0.4527414106737052], 
             UndirectedEdge[134, 395] -> 
             RGBColor[
              0.6498035533941702, 0.7237783527330339, 0.9675259002297822], 
             UndirectedEdge[108, 267] -> 
             RGBColor[
              0.2560701403937588, 0.38647633171144136`, 0.9378941877223754], 
             UndirectedEdge[217, 233] -> 
             RGBColor[
              0.9762379710154455, 0.9784153903456743, 0.7203221374649382], 
             UndirectedEdge[245, 400] -> 
             RGBColor[
              0.829279530588777, 0.22606087924326346`, 0.17567141759930008`], 
             UndirectedEdge[269, 392] -> 
             RGBColor[
              0.8673327084378479, 0.8950958861574181, 0.8862515356507488], 
             UndirectedEdge[232, 288] -> 
             RGBColor[
              0.30023200699341346`, 0.43289325353174246`, 0.9404091406935988],
              UndirectedEdge[260, 341] -> 
             RGBColor[
              0.2804084248139549, 0.4095158612485281, 0.93937327562965], 
             UndirectedEdge[47, 323] -> 
             RGBColor[
              0.4713973595467131, 0.580257389192397, 0.951939099626107], 
             UndirectedEdge[142, 377] -> 
             RGBColor[
              0.18361252498065594`, 0.31031878383411166`, 0.9337678337160353],
              UndirectedEdge[53, 117] -> 
             RGBColor[
              0.20926903428907379`, 0.33728540183390365`, 0.9352289339657456],
              UndirectedEdge[251, 308] -> 
             RGBColor[
              0.1958872147734443, 0.3232202610666153, 0.9344668591409584], 
             UndirectedEdge[85, 162] -> 
             RGBColor[
              0.2565370723370653, 0.38696710678905155`, 0.9379207788057828], 
             UndirectedEdge[249, 397] -> 
             RGBColor[
              0.26099988066146607`, 0.3916272530178875, 0.9381760476598446], 
             UndirectedEdge[262, 284] -> 
             RGBColor[
              0.24537509181412387`, 0.37523515754899955`, 0.9372851205276718],
              UndirectedEdge[307, 341] -> 
             RGBColor[
              0.3422947785820742, 0.4709002657971524, 0.9430316985052297], 
             UndirectedEdge[7, 387] -> 
             RGBColor[
              0.4913856837463006, 0.597841186558023, 0.9531378831854276], 
             UndirectedEdge[228, 368] -> 
             RGBColor[
              0.19438368850365684`, 0.3216399596279972, 0.9343812355441619], 
             UndirectedEdge[240, 399] -> 
             RGBColor[
              0.8633179697637215, 0.41192221409589935`, 0.20524563001796006`],
              UndirectedEdge[105, 114] -> 
             RGBColor[
              0.22538318625918102`, 0.3542223972507317, 0.9361466110816916], 
             UndirectedEdge[78, 357] -> 
             RGBColor[
              0.8323252154413091, 0.24947134764743728`, 0.17858796885369382`],
              UndirectedEdge[359, 369] -> 
             RGBColor[
              0.18890080078567878`, 0.31587709700124245`, 0.9340689931998285],
              UndirectedEdge[48, 354] -> 
             RGBColor[
              0.22802037271409625`, 0.35699424742212627`, 0.9362967949489314],
              UndirectedEdge[280, 325] -> 
             RGBColor[
              0.2703375929737152, 0.4014723289817168, 0.9387066980399994], 
             UndirectedEdge[259, 262] -> 
             RGBColor[
              0.20019420515358305`, 0.3277471810351035, 0.934712135871486], 
             UndirectedEdge[120, 187] -> 
             RGBColor[
              0.47660974925846794`, 0.585472751295903, 0.952077636221743], 
             UndirectedEdge[70, 198] -> 
             RGBColor[
              0.2881120186842996, 0.4160342955793074, 0.9398697816662858], 
             UndirectedEdge[62, 235] -> 
             RGBColor[
              0.1963098901939031, 0.32366451973268695`, 0.9344909298808612], 
             UndirectedEdge[65, 176] -> 
             RGBColor[
              0.26080757186847375`, 0.39145567256187075`, 0.9381639774364586],
              UndirectedEdge[199, 342] -> 
             RGBColor[
              0.18510212262202141`, 0.31188444540113214`, 0.9338526640980489],
              UndirectedEdge[324, 390] -> 
             RGBColor[
              0.4479202761383373, 0.5532491979543472, 0.9512669003180385], 
             UndirectedEdge[226, 234] -> 
             RGBColor[
              0.6154815427973135, 0.6962991925345092, 0.964434228392668], 
             UndirectedEdge[47, 201] -> 
             RGBColor[
              0.7465737093465549, 0.8011421937069441, 0.9641963866302764], 
             UndirectedEdge[160, 264] -> 
             RGBColor[
              0.5914575736276367, 0.6779711437656651, 0.9618285011853527], 
             UndirectedEdge[277, 314] -> 
             RGBColor[
              0.22024480085065679`, 0.34882162839392095`, 0.9358539876342362],
              UndirectedEdge[4, 66] -> 
             RGBColor[
              0.22354481915991609`, 0.35229015687019793`, 0.9360419187950089],
              UndirectedEdge[23, 75] -> 
             RGBColor[0.255511442446525, 0.3858891047454028, 0.9378623707008],
              UndirectedEdge[287, 391] -> 
             RGBColor[
              0.18552964693238397`, 0.31233380055793014`, 0.9338770109750585],
              UndirectedEdge[45, 91] -> 
             RGBColor[
              0.38905361359871204`, 0.5081017700405416, 0.9463921022645131], 
             UndirectedEdge[175, 314] -> 
             RGBColor[
              0.25716282410855407`, 0.38762481157584006`, 0.9379564144434523],
              UndirectedEdge[195, 358] -> 
             RGBColor[
              0.1963120650172806, 0.3236668056099485, 0.9344910537338352], 
             UndirectedEdge[321, 341] -> 
             RGBColor[
              0.44529829620254, 0.5573731665864943, 0.9503530478730258], 
             UndirectedEdge[91, 148] -> 
             RGBColor[
              0.4136380232673186, 0.5316086524356322, 0.9478775665898638], 
             UndirectedEdge[115, 350] -> 
             RGBColor[
              0.9076888516719018, 0.6493073877623174, 0.38968437055635197`], 
             UndirectedEdge[142, 277] -> 
             RGBColor[
              0.19515207298431664`, 0.32244758043556054`, 0.9344249939036124],
              UndirectedEdge[45, 66] -> 
             RGBColor[
              0.2495400971941441, 0.37961284227999426`, 0.9375223114224907], 
             UndirectedEdge[259, 335] -> 
             RGBColor[
              0.18286996403264408`, 0.3095383051966678, 0.9337255459685665], 
             UndirectedEdge[118, 173] -> 
             RGBColor[
              0.26068055800241224`, 0.3913221729354959, 0.9381567441846866], 
             UndirectedEdge[52, 128] -> 
             RGBColor[
              0.18698858591777334`, 0.3138672379336487, 0.9339600953919696], 
             UndirectedEdge[27, 225] -> 
             RGBColor[
              0.84226224924205, 0.4121124463693103, 0.4414749134015841], 
             UndirectedEdge[302, 352] -> 
             RGBColor[
              0.21548876733628058`, 0.34382273562037, 0.9355831385615135], 
             UndirectedEdge[25, 242] -> 
             RGBColor[
              0.8289704754072247, 0.2236853456890081, 0.17537546600841764`], 
             UndirectedEdge[30, 224] -> 
             RGBColor[
              0.17977250803868983`, 0.30628268255696894`, 0.9335491504319864],
              UndirectedEdge[313, 361] -> 
             RGBColor[
              0.2180016041011253, 0.34646388638327474`, 0.9357262408978626], 
             UndirectedEdge[270, 310] -> 
             RGBColor[
              0.3193491673301014, 0.4483310995882432, 0.9416682954109477], 
             UndirectedEdge[72, 370] -> 
             RGBColor[
              0.18495091945082137`, 0.31172552128136616`, 0.9338440533011341],
              UndirectedEdge[283, 380] -> 
             RGBColor[
              0.2145522876760556, 0.34283843612123366`, 0.9355298074302612], 
             UndirectedEdge[34, 35] -> 
             RGBColor[
              0.24974982719833305`, 0.3798332818120472, 0.9375342552359615], 
             UndirectedEdge[25, 230] -> 
             RGBColor[
              0.8174587722148511, 0.13520135049192075`, 0.16435184603079156`],
              UndirectedEdge[191, 211] -> 
             RGBColor[
              0.2145566630341047, 0.342843034899957, 0.9355300566004294], 
             UndirectedEdge[17, 173] -> 
             RGBColor[
              0.25707808713188923`, 0.38753574764073073`, 0.9379515887979883],
              UndirectedEdge[40, 51] -> 
             RGBColor[
              0.4513189432678153, 0.5634921655168925, 0.9504868403154272], 
             UndirectedEdge[105, 202] -> 
             RGBColor[
              0.2264175602160962, 0.35530958986254624`, 0.9362055171483188], 
             UndirectedEdge[183, 309] -> 
             RGBColor[
              0.3237917248354433, 0.45384300724789295`, 0.9418904445081182], 
             UndirectedEdge[187, 261] -> 
             RGBColor[
              0.3474451829775207, 0.4708516166188276, 0.9435249988507737], 
             UndirectedEdge[190, 274] -> 
             RGBColor[
              0.7246489008143902, 0.7831056857849257, 0.9561147753018562], 
             UndirectedEdge[176, 354] -> 
             RGBColor[
              0.22476081103687653`, 0.35356824143122134`, 0.936111167733503], 
             UndirectedEdge[42, 148] -> 
             RGBColor[
              0.27524609124263133`, 0.40429858097089644`, 0.9390716483190401],
              UndirectedEdge[320, 380] -> 
             RGBColor[
              0.20795844756120663`, 0.3359078920869173, 0.9351542979904328], 
             UndirectedEdge[51, 222] -> 
             RGBColor[
              0.3069819930795281, 0.4332541041734357, 0.9410401002851541], 
             UndirectedEdge[122, 319] -> 
             RGBColor[
              0.5256622973684795, 0.6257953596771879, 0.9558012080947398], 
             UndirectedEdge[27, 78] -> 
             RGBColor[
              0.8206713505927768, 0.15989463566547976`, 0.1674282147135816], 
             UndirectedEdge[5, 178] -> 
             RGBColor[
              0.36206488822589933`, 0.4855919281825182, 0.9443804876389659], 
             UndirectedEdge[196, 336] -> 
             RGBColor[
              0.18504438325654066`, 0.31182375766712467`, 0.9338493759266024],
              UndirectedEdge[297, 318] -> 
             RGBColor[
              0.20065548392565413`, 0.32823201427131354`, 0.9347384050151546],
              UndirectedEdge[127, 235] -> 
             RGBColor[
              0.19315907110692182`, 0.32035280909880115`, 0.9343114953950769],
              UndirectedEdge[45, 203] -> 
             RGBColor[
              0.2552832201033739, 0.38564922859261863`, 0.9378493737759823], 
             UndirectedEdge[305, 370] -> 
             RGBColor[
              0.18466045373978385`, 0.311420223402476, 0.9338275117085959], 
             UndirectedEdge[122, 169] -> 
             RGBColor[
              0.7468757612194565, 0.8021168965628588, 0.9757076451280708], 
             UndirectedEdge[51, 226] -> 
             RGBColor[
              0.41340915500198794`, 0.532495964339595, 0.9475630436867326], 
             UndirectedEdge[226, 395] -> 
             RGBColor[
              0.45693963376297164`, 0.5697838781949226, 0.9504517090480242], 
             UndirectedEdge[61, 354] -> 
             RGBColor[
              0.21260864100273835`, 0.3407955402332605, 0.9354191196275834], 
             UndirectedEdge[211, 334] -> 
             RGBColor[
              0.20343525046697647`, 0.3311537251536216, 0.9348967086073869], 
             UndirectedEdge[10, 361] -> 
             RGBColor[
              0.22756848714061534`, 0.35651928703319763`, 0.9362710607340264],
              UndirectedEdge[44, 249] -> 
             RGBColor[
              0.27287548484168234`, 0.4041092659680885, 0.9388523457495259], 
             UndirectedEdge[302, 377] -> 
             RGBColor[
              0.18805566555367964`, 0.3149888062877428, 0.9340208639986316], 
             UndirectedEdge[149, 363] -> 
             RGBColor[
              0.21825217126115545`, 0.34672724835534197`, 0.9357405103269454],
              UndirectedEdge[358, 359] -> 
             RGBColor[
              0.18898988195831087`, 0.3159707269617513, 0.934074066240826], 
             UndirectedEdge[126, 317] -> 
             RGBColor[
              0.1909701324562666, 0.31805209579023613`, 0.9341868385771666], 
             UndirectedEdge[194, 364] -> 
             RGBColor[
              0.8766286360480449, 0.42149048442570325`, 0.3251019422621857], 
             UndirectedEdge[184, 343] -> 
             RGBColor[
              0.18256566753029357`, 0.30921847027918486`, 0.933708216732924], 
             UndirectedEdge[118, 346] -> 
             RGBColor[
              0.2949738551719156, 0.42345379048504006`, 0.9402529639443298], 
             UndirectedEdge[169, 239] -> 
             RGBColor[
              0.8504381780289113, 0.4495162152727391, 0.44612017739748244`], 
             UndirectedEdge[72, 157] -> 
             RGBColor[
              0.1851041505972344, 0.3118865769316621, 0.9338527795882372], 
             UndirectedEdge[162, 191] -> 
             RGBColor[
              0.239776323432642, 0.3693504969976439, 0.936966278950982], 
             UndirectedEdge[84, 272] -> 
             RGBColor[
              0.5398855520007457, 0.6327240010263296, 0.9588121937440683], 
             UndirectedEdge[21, 160] -> 
             RGBColor[
              0.7114127926044326, 0.7298581356264684, 0.631074971265499], 
             UndirectedEdge[29, 336] -> 
             RGBColor[
              0.18089581060751259`, 0.30746334477829806`, 0.9336131208515035],
              UndirectedEdge[275, 276] -> 
             RGBColor[
              0.2308037275414878, 0.35991972982060355`, 0.9364553028887468], 
             UndirectedEdge[38, 303] -> 
             RGBColor[
              0.21808265414273661`, 0.3465490751158777, 0.9357308565778295], 
             UndirectedEdge[172, 285] -> 
             RGBColor[
              0.8806018302486532, 0.4526452874715283, 0.3169446377499939], 
             UndirectedEdge[73, 285] -> 
             RGBColor[
              0.9624071777351879, 0.8763102692580285, 0.43650448397981056`], 
             UndirectedEdge[5, 59] -> 
             RGBColor[
              0.31447583347960173`, 0.4443726808567142, 0.9413481551518805], 
             UndirectedEdge[73, 225] -> 
             RGBColor[
              0.9076627958063523, 0.836763929150959, 0.6259476546026368], 
             UndirectedEdge[64, 254] -> 
             RGBColor[
              0.1839453796797469, 0.3106686352270631, 0.9337867892987342], 
             UndirectedEdge[241, 390] -> 
             RGBColor[
              0.2629620790942533, 0.393720196259813, 0.938286673435659], 
             UndirectedEdge[58, 289] -> 
             RGBColor[
              0.19906319498854463`, 0.3265584176414619, 0.9346477265157667], 
             UndirectedEdge[262, 331] -> 
             RGBColor[
              0.20664951421908523`, 0.3345321201531805, 0.9350797561729924], 
             UndirectedEdge[22, 118] -> 
             RGBColor[
              0.2775783272389005, 0.4083866585141185, 0.9391445362866995], 
             UndirectedEdge[97, 360] -> 
             RGBColor[
              0.189069412661027, 0.31605431877284385`, 0.9340785953966906], 
             UndirectedEdge[301, 358] -> 
             RGBColor[
              0.18673627600332035`, 0.31360204421618604`, 0.9339457267156006],
              UndirectedEdge[16, 274] -> 
             RGBColor[
              0.4054269963890745, 0.5245026293096915, 0.9473527216519175], 
             UndirectedEdge[166, 319] -> 
             RGBColor[
              0.7215283330281927, 0.7785525624499918, 0.8852776399757938], 
             UndirectedEdge[82, 101] -> 
             RGBColor[
              0.181913405203708, 0.30853290121812327`, 0.9336710713583607], 
             UndirectedEdge[24, 399] -> 
             RGBColor[
              0.8560499214236114, 0.3560568096747217, 0.198285738719384], 
             UndirectedEdge[328, 400] -> 
             RGBColor[
              0.8566292392466625, 0.42461673226525787`, 0.20140471849011185`],
              UndirectedEdge[17, 371] -> 
             RGBColor[
              0.20911196002482746`, 0.33712030682309724`, 0.9352199888187673],
              UndirectedEdge[107, 158] -> 
             RGBColor[
              0.34368740964077826`, 0.4721064928245296, 0.9431204357248351], 
             UndirectedEdge[60, 394] -> 
             RGBColor[
              0.18321858514836378`, 0.3099047280931446, 0.933745399425368], 
             UndirectedEdge[219, 284] -> 
             RGBColor[
              0.3068620452246301, 0.43723797575946177`, 0.9408827842352088], 
             UndirectedEdge[124, 149] -> 
             RGBColor[
              0.2631665511656537, 0.3938441656371931, 0.9383016477132344], 
             UndirectedEdge[227, 296] -> 
             RGBColor[
              0.22621507415997788`, 0.35509676417920844`, 0.9361939858669741],
              UndirectedEdge[202, 229] -> 
             RGBColor[
              0.22512118954774685`, 0.35394702209546336`, 0.9361316907565649],
              UndirectedEdge[315, 358] -> 
             RGBColor[
              0.20481090918793238`, 0.33259962969114687`, 0.9349750503364407],
              UndirectedEdge[145, 222] -> 
             RGBColor[
              0.21482177415136725`, 0.3431216834932156, 0.9355451542863606], 
             UndirectedEdge[155, 299] -> 
             RGBColor[
              0.19737174909206562`, 0.3247806007603985, 0.9345514011742322], 
             UndirectedEdge[14, 29] -> 
             RGBColor[
              0.18299367418147944`, 0.3096683324067703, 0.9337325910785299], 
             UndirectedEdge[116, 151] -> 
             RGBColor[
              0.18767873323802545`, 0.31459262652510106`, 0.9339993982608765],
              UndirectedEdge[45, 257] -> 
             RGBColor[
              0.30395689687858984`, 0.4354808171950546, 0.9406698751035344], 
             UndirectedEdge[27, 240] -> 
             RGBColor[
              0.824588465564483, 0.19000329782873795`, 0.17117924843423588`], 
             UndirectedEdge[144, 188] -> 
             RGBColor[
              0.19616736828116454`, 0.3235147201659876, 0.934482813468773], 
             UndirectedEdge[76, 200] -> 
             RGBColor[
              0.1890554468047247, 0.31603963977238364`, 0.9340778000618348], 
             UndirectedEdge[90, 221] -> 
             RGBColor[
              0.755343522572024, 0.6711176068414135, 0.6012544985481333], 
             UndirectedEdge[271, 382] -> 
             RGBColor[
              0.18049565541513857`, 0.3070427562998084, 0.9335903326052744], 
             UndirectedEdge[242, 385] -> 
             RGBColor[
              0.8996573902074148, 0.5986962394475088, 0.343329755550243], 
             UndirectedEdge[74, 112] -> 
             RGBColor[
              0.9000839613583336, 0.841002686126469, 0.6275271765854877], 
             UndirectedEdge[237, 251] -> 
             RGBColor[
              0.19380336074719554`, 0.32102999836105145`, 0.9343481867369493],
              UndirectedEdge[25, 223] -> 
             RGBColor[
              0.854846716521594, 0.34268213742931986`, 0.19696394267101408`], 
             UndirectedEdge[284, 332] -> 
             RGBColor[
              0.2524716906122939, 0.382694132836228, 0.9376892613307504], 
             UndirectedEdge[145, 333] -> 
             RGBColor[
              0.19268508450271393`, 0.3198546191252922, 0.9342845025591675], 
             UndirectedEdge[146, 227] -> 
             RGBColor[
              0.19680598858419968`, 0.3241859505953433, 0.934519181950277], 
             UndirectedEdge[108, 286] -> 
             RGBColor[
              0.22549943873113315`, 0.3543445859695858, 0.9361532314879892], 
             UndirectedEdge[127, 361] -> 
             RGBColor[
              0.2062200768333135, 0.33408075423283157`, 0.9350553003491684], 
             UndirectedEdge[143, 258] -> 
             RGBColor[
              0.1842254727690224, 0.31096303082281923`, 0.9338027401858078], 
             UndirectedEdge[212, 310] -> 
             RGBColor[
              0.34846775564587945`, 0.473552157244567, 0.9435237061098725], 
             UndirectedEdge[107, 310] -> 
             RGBColor[
              0.3141088853648525, 0.4437922307341744, 0.9413343892779213], 
             UndirectedEdge[253, 394] -> 
             RGBColor[
              0.1857625991924869, 0.31257864815332465`, 0.9338902772616493], 
             UndirectedEdge[152, 284] -> 
             RGBColor[
              0.26668400229217915`, 0.3976321735243937, 0.9384986314556889], 
             UndirectedEdge[230, 364] -> 
             RGBColor[
              0.8177179178456022, 0.13719325736821295`, 0.1646000041794619], 
             UndirectedEdge[158, 241] -> 
             RGBColor[
              0.3009846875478195, 0.43090972620672763`, 0.9405535979845862], 
             UndirectedEdge[44, 315] -> 
             RGBColor[
              0.22776027402374388`, 0.3567208672073564, 0.9362819827132973], 
             UndirectedEdge[357, 385] -> 
             RGBColor[
              0.9028754322047721, 0.6234315203941919, 0.3464113562011709], 
             UndirectedEdge[99, 197] -> 
             RGBColor[
              0.9649742133445314, 0.9733984061785892, 0.9441737000062027], 
             UndirectedEdge[152, 267] -> 
             RGBColor[
              0.25637803396755154`, 0.3867999473790775, 0.9379117218059152], 
             UndirectedEdge[169, 197] -> 
             RGBColor[
              0.9300501065256308, 0.9463228877887528, 0.9676089006734437], 
             UndirectedEdge[263, 348] -> 
             RGBColor[
              0.36254614474277536`, 0.48844098130229274`, 0.9443220976494096],
              UndirectedEdge[314, 379] -> 
             RGBColor[
              0.21988806256935944`, 0.348446673841764, 0.9358336719168633], 
             UndirectedEdge[300, 319] -> 
             RGBColor[
              0.6840306200166372, 0.7509595396670409, 0.9709177458785374], 
             UndirectedEdge[25, 78] -> 
             RGBColor[
              0.8181918595177029, 0.1408361807425438, 0.1650538512599061], 
             UndirectedEdge[44, 113] -> 
             RGBColor[
              0.27210008577250266`, 0.4033248206617401, 0.9388070693975159], 
             UndirectedEdge[115, 221] -> 
             RGBColor[
              0.8771748206449487, 0.5351613717457232, 0.21922399843655038`], 
             UndirectedEdge[175, 319] -> 
             RGBColor[
              0.3675065660796395, 0.49023117564208835`, 0.944730223137449], 
             UndirectedEdge[176, 356] -> 
             RGBColor[
              0.21433034444536764`, 0.34260515971376704`, 0.9355171680916091],
              UndirectedEdge[84, 395] -> 
             RGBColor[
              0.4037383718237736, 0.5237036190763635, 0.9470617716812872], 
             UndirectedEdge[301, 359] -> 
             RGBColor[
              0.1849503238015024, 0.31172489521616553`, 0.9338440193797866], 
             UndirectedEdge[238, 280] -> 
             RGBColor[
              0.2707591220181621, 0.40191538273391547`, 0.9387307034954844], 
             UndirectedEdge[36, 168] -> 
             RGBColor[
              0.18854146293925098`, 0.3154994101413115, 0.9340485294410671], 
             UndirectedEdge[4, 232] -> 
             RGBColor[
              0.26395583592624494`, 0.3947646976980586, 0.9383432664171094], 
             UndirectedEdge[140, 339] -> 
             RGBColor[
              0.2386234653452058, 0.3681387700523239, 0.9369006253884031], 
             UndirectedEdge[18, 141] -> 
             RGBColor[
              0.7787784526106882, 0.5518341379822057, 0.46039508708597976`], 
             UndirectedEdge[123, 140] -> 
             RGBColor[
              0.21869849237699107`, 0.3471963601464784, 0.9357659276542193], 
             UndirectedEdge[24, 78] -> 
             RGBColor[
              0.8205037601564106, 0.15860646213297017`, 0.16726772992245081`],
              UndirectedEdge[62, 127] -> 
             RGBColor[
              0.1979549784065447, 0.32539361174879033`, 0.9345846152208812], 
             UndirectedEdge[299, 353] -> 
             RGBColor[
              0.188841530987085, 0.3158148006849981, 0.9340656178724803], 
             UndirectedEdge[256, 311] -> 
             RGBColor[
              0.32702639881790146`, 0.45712063802367703`, 0.942079129357128], 
             UndirectedEdge[47, 346] -> 
             RGBColor[
              0.44758503753245593`, 0.5596323527057516, 0.9504217995237683], 
             UndirectedEdge[34, 125] -> 
             RGBColor[
              0.2623800078372861, 0.3931084024632914, 0.9382535253386719], 
             UndirectedEdge[194, 387] -> 
             RGBColor[
              0.7643288542489235, 0.8116893614464729, 0.8013257295322668], 
             UndirectedEdge[117, 303] -> 
             RGBColor[
              0.21968824533158482`, 0.34823665325571823`, 0.9358222926207751],
              UndirectedEdge[287, 382] -> 
             RGBColor[
              0.18591195141547964`, 0.3127356268091679, 0.933898782649802], 
             UndirectedEdge[20, 168] -> 
             RGBColor[
              0.18724662483160132`, 0.31413845319269396`, 0.9339747903263778],
              UndirectedEdge[51, 355] -> 
             RGBColor[
              0.5736425498293158, 0.6609104438201203, 0.9614084888743977], 
             UndirectedEdge[183, 339] -> 
             RGBColor[
              0.30076734139659483`, 0.42964292042343744`, 0.9405792399327987],
              UndirectedEdge[118, 164] -> 
             RGBColor[
              0.21991695118991147`, 0.3484770376136085, 0.9358353170810669], 
             UndirectedEdge[51, 134] -> 
             RGBColor[
              0.6062730746331866, 0.6864904388777064, 0.9646372348684907], 
             UndirectedEdge[46, 356] -> 
             RGBColor[
              0.1981426064801053, 0.32559082075040946`, 0.9345953003620997], 
             UndirectedEdge[204, 276] -> 
             RGBColor[
              0.2082458481435212, 0.33620996832117933`, 0.9351706650284246], 
             UndirectedEdge[108, 154] -> 
             RGBColor[
              0.23083302352450608`, 0.3599505217562283, 0.9364569712516402], 
             UndirectedEdge[29, 119] -> 
             RGBColor[
              0.18192714786076558`, 0.30854734562202557`, 0.9336718539823496],
              UndirectedEdge[244, 264] -> 
             RGBColor[
              0.8390285444461558, 0.8747724603828321, 0.9672545655941249], 
             UndirectedEdge[217, 321] -> 
             RGBColor[
              0.7737155651854934, 0.8183397872541874, 0.7225530793389106], 
             UndirectedEdge[241, 346] -> 
             RGBColor[
              0.30713982911114474`, 0.4362410004624697, 0.9409457981622233], 
             UndirectedEdge[108, 284] -> 
             RGBColor[
              0.26637610871838646`, 0.39730855785675745`, 0.9384810973721491],
              UndirectedEdge[181, 334] -> 
             RGBColor[
              0.18995231521735206`, 0.3169823053387968, 0.934128875391136], 
             UndirectedEdge[8, 59] -> 
             RGBColor[
              0.2921622006654197, 0.4209196380029755, 0.9400774267731745], 
             UndirectedEdge[236, 383] -> 
             RGBColor[
              0.22956462143722656`, 0.3586173507411603, 0.9363847376292023], 
             UndirectedEdge[42, 290] -> 
             RGBColor[
              0.20736560396252507`, 0.33528477587624783`, 0.9351205364245214],
              UndirectedEdge[173, 209] -> 
             RGBColor[
              0.3086611648699239, 0.43934003290171275`, 0.940977513192154], 
             UndirectedEdge[154, 332] -> 
             RGBColor[
              0.2169286054184135, 0.3453360967356988, 0.9356651352102414], 
             UndirectedEdge[5, 352] -> 
             RGBColor[
              0.26102097459574697`, 0.3916799723587493, 0.9381761304060758], 
             UndirectedEdge[189, 226] -> 
             RGBColor[
              0.35594179006458193`, 0.47882793285764735`, 0.9440438043992346],
              UndirectedEdge[16, 390] -> 
             RGBColor[
              0.2902432136013212, 0.4215595588222458, 0.9398708612517093], 
             UndirectedEdge[119, 327] -> 
             RGBColor[
              0.18901152680793626`, 0.3159934770710704, 0.9340752988829915], 
             UndirectedEdge[129, 231] -> 
             RGBColor[
              0.18564063577461087`, 0.3124504568682096, 0.93388333162543], 
             UndirectedEdge[79, 352] -> 
             RGBColor[
              0.23532317406913467`, 0.3646699546706205, 0.9367126786825744], 
             UndirectedEdge[62, 361] -> 
             RGBColor[
              0.20937089592029476`, 0.33739246486671737`, 0.9352347348349528],
              UndirectedEdge[150, 347] -> 
             RGBColor[
              0.19569856946522865`, 0.3230219828868772, 0.9344561160697312], 
             UndirectedEdge[5, 90] -> 
             RGBColor[
              0.44540909938288953`, 0.5535702341777979, 0.950854414653335], 
             UndirectedEdge[24, 27] -> 
             RGBColor[
              0.8208706461762446, 0.16142650885189433`, 0.16761906038938248`],
              UndirectedEdge[62, 393] -> 
             RGBColor[
              0.19223452494535048`, 0.31938105246337734`, 0.9342588438589188],
              UndirectedEdge[199, 353] -> 
             RGBColor[
              0.18825533864421526`, 0.31519867536590085`, 0.9340322350857477],
              UndirectedEdge[96, 201] -> 
             RGBColor[
              0.8486214444306401, 0.8823678065342169, 0.9733384742305298], 
             UndirectedEdge[155, 170] -> 
             RGBColor[
              0.21937286170598153`, 0.34790516506873237`, 0.9358043319898652],
              UndirectedEdge[335, 394] -> 
             RGBColor[
              0.17996762986719622`, 0.30648776797016763`, 0.9335602623314629],
              UndirectedEdge[16, 310] -> 
             RGBColor[
              0.2986872977789616, 0.43043482667880517`, 0.9403517393537228], 
             UndirectedEdge[6, 277] -> 
             RGBColor[
              0.2567019144406389, 0.38714036629150045`, 0.9379301663197194], 
             UndirectedEdge[140, 232] -> 
             RGBColor[
              0.2603959916536444, 0.39102307566039235`, 0.9381405385521024], 
             UndirectedEdge[177, 300] -> 
             RGBColor[
              0.904775992937191, 0.9269078335507821, 0.990779535981055], 
             UndirectedEdge[24, 32] -> 
             RGBColor[
              0.8662019827363802, 0.39609555432953175`, 0.20755215197526236`],
              UndirectedEdge[102, 226] -> 
             RGBColor[
              0.3613558703292786, 0.48451847448835883`, 0.9443521282608951], 
             UndirectedEdge[187, 206] -> 
             RGBColor[
              0.5826167692195937, 0.6701866792756657, 0.9613440852325792], 
             UndirectedEdge[336, 396] -> 
             RGBColor[
              0.18995557631013382`, 0.31698573295407556`, 0.9341290611055455],
              UndirectedEdge[267, 332] -> 
             RGBColor[
              0.24216572228766625`, 0.37186190669091185`, 0.9371023516809767],
              UndirectedEdge[115, 300] -> 
             RGBColor[
              0.8813051840145343, 0.6303392266197287, 0.46973399593591275`], 
             UndirectedEdge[149, 195] -> 
             RGBColor[
              0.20922588183301488`, 0.33724004586656203`, 0.9352264764972114],
              UndirectedEdge[127, 396] -> 
             RGBColor[
              0.197181010085485, 0.3245801219709307, 0.9345405388699805], 
             UndirectedEdge[206, 220] -> 
             RGBColor[
              0.6830678662474279, 0.7522369451466808, 0.9691139391554754], 
             UndirectedEdge[298, 361] -> 
             RGBColor[
              0.2073168336633886, 0.33523351519963984`, 0.9351177590281349], 
             UndirectedEdge[27, 141] -> 
             RGBColor[
              0.8358913359864371, 0.269340328379047, 0.18170757254943665`], 
             UndirectedEdge[55, 221] -> 
             RGBColor[
              0.9369698505827507, 0.7826274582869746, 0.292244768605455], 
             UndirectedEdge[40, 269] -> 
             RGBColor[
              0.6323207129287618, 0.7108348666826005, 0.9652579027218493], 
             UndirectedEdge[191, 312] -> 
             RGBColor[
              0.25506639270437426`, 0.3854213292486189, 0.9378370257763766], 
             UndirectedEdge[78, 240] -> 
             RGBColor[
              0.8238546935248147, 0.18436320439088957`, 0.1704765875003726], 
             UndirectedEdge[183, 246] -> 
             RGBColor[
              0.63511612996041, 0.7084027410096546, 0.967888425757446], 
             UndirectedEdge[130, 164] -> 
             RGBColor[
              0.19148238974395732`, 0.318590510678587, 0.9342160108718838], 
             UndirectedEdge[190, 295] -> 
             RGBColor[
              0.6926270864337125, 0.7564495900659256, 0.953776079551644], 
             UndirectedEdge[18, 179] -> 
             RGBColor[
              0.5295441815391476, 0.6289468481238254, 0.9561068042364651], 
             UndirectedEdge[128, 199] -> 
             RGBColor[
              0.1905507884017967, 0.3176113386010396, 0.9341629575536283], 
             UndirectedEdge[350, 355] -> 
             RGBColor[
              0.879778802399924, 0.9043102631133229, 0.8644296794931206], 
             UndirectedEdge[233, 348] -> 
             RGBColor[
              0.6462730001834412, 0.7161082281260901, 0.948023487805811], 
             UndirectedEdge[247, 316] -> 
             RGBColor[
              0.21599089502507074`, 0.3443505036580227, 0.9356117339905587], 
             UndirectedEdge[74, 399] -> 
             RGBColor[
              0.8948180568355072, 0.820125129452121, 0.6232901061997559], 
             UndirectedEdge[155, 171] -> 
             RGBColor[
              0.19802203394015824`, 0.32546409136618454`, 0.9345884339343208],
              UndirectedEdge[21, 95] -> 
             RGBColor[
              0.7613060096832925, 0.7703636969149021, 0.6350027480788232], 
             UndirectedEdge[257, 325] -> 
             RGBColor[
              0.30612175947263687`, 0.43775622504161427`, 0.9407931608256381],
              UndirectedEdge[250, 372] -> 
             RGBColor[
              0.22620791914637717`, 0.35508924380626006`, 0.9361935783995345],
              UndirectedEdge[156, 400] -> 
             RGBColor[
              0.8373834049701799, 0.28835080887912395`, 0.18343169685894858`],
              UndirectedEdge[193, 360] -> 
             RGBColor[
              0.18609708652812662`, 0.31293021555080397`, 0.9339093258205844],
              UndirectedEdge[92, 135] -> 
             RGBColor[
              0.746116355711272, 0.7971097200029147, 0.816782693533676], 
             UndirectedEdge[102, 174] -> 
             RGBColor[
              0.3107339262181662, 0.44067229083220405`, 0.9411265427453626], 
             UndirectedEdge[140, 275] -> 
             RGBColor[
              0.23222474174375346`, 0.36141330584468895`, 0.9365362275453637],
              UndirectedEdge[101, 301] -> 
             RGBColor[
              0.1828984857165501, 0.3095682832948322, 0.9337271702362709], 
             UndirectedEdge[337, 398] -> 
             RGBColor[
              0.7100705314017086, 0.7665791120076357, 0.7708912737801167], 
             UndirectedEdge[149, 249] -> 
             RGBColor[
              0.2628399368216051, 0.3935612687084925, 0.9382808361360453], 
             UndirectedEdge[92, 165] -> 
             RGBColor[
              0.6970699985324673, 0.761675381939551, 0.9717947555325273], 
             UndirectedEdge[150, 320] -> 
             RGBColor[
              0.19466927104284892`, 0.32194012498366686`, 0.9343974990472872],
              UndirectedEdge[59, 175] -> 
             RGBColor[
              0.314081747786117, 0.4439584718063857, 0.9413257125546342], 
             UndirectedEdge[278, 379] -> 
             RGBColor[
              0.232633859519395, 0.36184331456645336`, 0.936559526197451], 
             UndirectedEdge[87, 317] -> 
             RGBColor[
              0.19676650353045996`, 0.3241444493003659, 0.9345169333348793], 
             UndirectedEdge[212, 324] -> 
             RGBColor[
              0.5252330264468776, 0.6244698739960914, 0.9560373579630563], 
             UndirectedEdge[135, 328] -> 
             RGBColor[
              0.932186507346842, 0.7459139489960613, 0.44641772294044424`], 
             UndirectedEdge[176, 344] -> 
             RGBColor[
              0.21245918803275743`, 0.3406384556859449, 0.9354106085020388], 
             UndirectedEdge[59, 213] -> 
             RGBColor[
              0.2845653105942021, 0.4129348248674753, 0.9396447951222104], 
             UndirectedEdge[371, 391] -> 
             RGBColor[
              0.18383722908563283`, 0.3105549620955055, 0.9337806302823939], 
             UndirectedEdge[98, 318] -> 
             RGBColor[
              0.1977029240139366, 0.3251286866009877, 0.9345702610961033], 
             UndirectedEdge[25, 244] -> 
             RGBColor[
              0.8631344742904997, 0.41134623565305395`, 0.42996350646602], 
             UndirectedEdge[204, 224] -> 
             RGBColor[
              0.1864844568543232, 0.3133373663243338, 0.9339313859875982], 
             UndirectedEdge[180, 236] -> 
             RGBColor[
              0.2546593406268537, 0.3849934917065525, 0.9378138447627414], 
             UndirectedEdge[102, 163] -> 
             RGBColor[
              0.272133057471457, 0.4033594760078676, 0.938808947086994], 
             UndirectedEdge[16, 107] -> 
             RGBColor[
              0.33319709362883454`, 0.4630203083535974, 0.9424520020647762], 
             UndirectedEdge[194, 223] -> 
             RGBColor[
              0.9622169086067585, 0.8752522636294204, 0.4543198910461633], 
             UndirectedEdge[111, 291] -> 
             RGBColor[
              0.18821279065920096`, 0.31515395473595276`, 0.9340298120409453],
              UndirectedEdge[108, 205] -> 
             RGBColor[
              0.3030856171044626, 0.43207672625167026`, 0.9407113666179867], 
             UndirectedEdge[66, 297] -> 
             RGBColor[
              0.21059566017891732`, 0.33867976975706876`, 0.935304483347605], 
             UndirectedEdge[19, 284] -> 
             RGBColor[
              0.2685014480461575, 0.3995424242445413, 0.938602132302708], 
             UndirectedEdge[23, 260] -> 
             RGBColor[
              0.2588190028871956, 0.3893655604799919, 0.938050731374799], 
             UndirectedEdge[10, 256] -> 
             RGBColor[
              0.29440488188335295`, 0.4228333554018322, 0.9402213822269152], 
             UndirectedEdge[230, 242] -> 
             RGBColor[
              0.8292500198369269, 0.22583404667284962`, 0.17564315807000078`],
              UndirectedEdge[29, 317] -> 
             RGBColor[
              0.1883961858281423, 0.3153467146864354, 0.9340402561245076], 
             UndirectedEdge[124, 316] -> 
             RGBColor[
              0.27204171641094554`, 0.40317252702797246`, 0.9388070752443234],
              UndirectedEdge[306, 361] -> 
             RGBColor[
              0.21017418029056079`, 0.33823676767103766`, 0.9352804806914867],
              UndirectedEdge[1, 393] -> 
             RGBColor[
              0.1884550205876297, 0.3154085537489959, 0.9340436066770222], 
             UndirectedEdge[74, 279] -> 
             RGBColor[
              0.7676471267223055, 0.8187592045069678, 0.9773831565887533], 
             UndirectedEdge[40, 234] -> 
             RGBColor[
              0.653391331063141, 0.7272953937118065, 0.9673580250213626], 
             UndirectedEdge[195, 316] -> 
             RGBColor[
              0.21810104707830674`, 0.3465684072573414, 0.9357319040283003], 
             UndirectedEdge[279, 325] -> 
             RGBColor[
              0.4806866627377453, 0.5825538322263442, 0.9538715491644547], 
             UndirectedEdge[172, 337] -> 
             RGBColor[
              0.8805510906169809, 0.45253676052994485`, 0.3114219419711682], 
             UndirectedEdge[148, 275] -> 
             RGBColor[
              0.28636427371918854`, 0.4159844956872421, 0.939704812363203], 
             UndirectedEdge[13, 188] -> 
             RGBColor[
              0.20797364918202638`, 0.3359238699542373, 0.9351551637002498], 
             UndirectedEdge[220, 233] -> 
             RGBColor[
              0.7976144359577942, 0.8422371475965424, 0.9590360291130758], 
             UndirectedEdge[230, 244] -> 
             RGBColor[
              0.863414018720202, 0.41349493663689546`, 0.43023119852760305`], 
             UndirectedEdge[253, 358] -> 
             RGBColor[
              0.19093438586024153`, 0.31801452385134865`, 0.9341848028614053],
              UndirectedEdge[66, 140] -> 
             RGBColor[
              0.21998497488731555`, 0.3485485348325317, 0.9358391909300019], 
             UndirectedEdge[89, 128] -> 
             RGBColor[
              0.1919283928758168, 0.31905928824840313`, 0.9342414100904406], 
             UndirectedEdge[199, 298] -> 
             RGBColor[
              0.19174373818706897`, 0.31886520446274574`, 0.9342308942790887],
              UndirectedEdge[367, 398] -> 
             RGBColor[
              0.40058820107881166`, 0.5213910984512207, 0.9467461038398723], 
             UndirectedEdge[72, 181] -> 
             RGBColor[
              0.1888688995598306, 0.3158435667902215, 0.9340671764722099], 
             UndirectedEdge[229, 329] -> 
             RGBColor[
              0.1986631863683978, 0.3261379832196762, 0.934624946616609], 
             UndirectedEdge[196, 326] -> 
             RGBColor[
              0.19087356510240117`, 0.3179505973785997, 0.9341813392092224], 
             UndirectedEdge[247, 362] -> 
             RGBColor[
              0.19339653330473627`, 0.32060239692467707`, 0.9343250185159485],
              UndirectedEdge[276, 297] -> 
             RGBColor[
              0.21488882463476794`, 0.3431921578025159, 0.9355489727121981], 
             UndirectedEdge[7, 201] -> 
             RGBColor[
              0.698844545732584, 0.7622666344739716, 0.960474027707296], 
             UndirectedEdge[191, 214] -> 
             RGBColor[
              0.2234844168401749, 0.3522266702024217, 0.9360384789722569], 
             UndirectedEdge[25, 32] -> 
             RGBColor[
              0.8638900820976725, 0.3783252729391054, 0.20533827331271765`], 
             UndirectedEdge[190, 324] -> 
             RGBColor[
              0.7946744730052755, 0.8399555999055638, 0.9616274448568455], 
             UndirectedEdge[8, 296] -> 
             RGBColor[
              0.241386411848991, 0.3710428020087285, 0.9370579711043807], 
             UndirectedEdge[292, 382] -> 
             RGBColor[
              0.1881384932660469, 0.31507586346502103`, 0.9340255809143183], 
             UndirectedEdge[223, 328] -> 
             RGBColor[
              0.8997164529222819, 0.6301219365340252, 0.23765071588506692`], 
             UndirectedEdge[70, 262] -> 
             RGBColor[
              0.2185336488556363, 0.3470230991538516, 0.9357565400595423], 
             UndirectedEdge[78, 285] -> 
             RGBColor[
              0.8780247318216056, 0.4328365796695082, 0.31447680538583667`], 
             UndirectedEdge[167, 272] -> 
             RGBColor[
              0.5255938312060932, 0.6203452307967748, 0.9579015379327056], 
             UndirectedEdge[93, 276] -> 
             RGBColor[
              0.22858867995178067`, 0.3575915743616926, 0.9363291592053822], 
             UndirectedEdge[56, 319] -> 
             RGBColor[
              0.4175060909791842, 0.5360433358043497, 0.9478244252272849], 
             UndirectedEdge[93, 162] -> 
             RGBColor[
              0.2533245521097741, 0.3835905443446218, 0.9377378305313364], 
             UndirectedEdge[106, 389] -> 
             RGBColor[
              0.21473367973065993`, 0.34302909067154336`, 0.9355401374394254],
              UndirectedEdge[68, 176] -> 
             RGBColor[
              0.2518475893962128, 0.38203816288782416`, 0.9376537196897696], 
             UndirectedEdge[253, 301] -> 
             RGBColor[
              0.18689482770343305`, 0.31376869210576286`, 0.9339547560003658],
              UndirectedEdge[217, 357] -> 
             RGBColor[
              0.9024235222483088, 0.6224649306924224, 0.29722374630511356`], 
             UndirectedEdge[364, 385] -> 
             RGBColor[
              0.8765931862247653, 0.4214146608382354, 0.32124344776916525`], 
             UndirectedEdge[161, 372] -> 
             RGBColor[
              0.19676171310914198`, 0.3241394142638304, 0.934516660527472], 
             UndirectedEdge[4, 339] -> 
             RGBColor[
              0.24218330961780632`, 0.3718803920899902, 0.9371033532534101], 
             UndirectedEdge[183, 280] -> 
             RGBColor[
              0.30076148412422865`, 0.4296367640588081, 0.9405789063698025], 
             UndirectedEdge[94, 145] -> 
             RGBColor[
              0.18922208139469943`, 0.31621478329169034`, 0.9340872896552201],
              UndirectedEdge[107, 351] -> 
             RGBColor[
              0.6292040524803684, 0.703641559800374, 0.9673461867380587], 
             UndirectedEdge[90, 178] -> 
             RGBColor[
              0.5250344578406001, 0.6249699305004974, 0.9558390168550672], 
             UndirectedEdge[113, 124] -> 
             RGBColor[
              0.3086276211264817, 0.4416266325643382, 0.9408905883938774], 
             UndirectedEdge[191, 365] -> 
             RGBColor[
              0.19407713550409694`, 0.321317752988877, 0.9343637778043414], 
             UndirectedEdge[184, 356] -> 
             RGBColor[
              0.18905111217950674`, 0.3160350838064485, 0.9340775532113412], 
             UndirectedEdge[196, 327] -> 
             RGBColor[
              0.19267128104236286`, 0.3198401108132733, 0.9342837164725208], 
             UndirectedEdge[140, 288] -> 
             RGBColor[
              0.2655351688852008, 0.39642467677341436`, 0.9384332070927082], 
             UndirectedEdge[13, 232] -> 
             RGBColor[
              0.2546277618608894, 0.3849603004213146, 0.9378120463987364], 
             UndirectedEdge[34, 86] -> 
             RGBColor[
              0.3371353879041764, 0.46222487105446, 0.9428569705546225], 
             UndirectedEdge[287, 374] -> 
             RGBColor[
              0.19007574708878708`, 0.31711204006170757`, 0.9341359046536132],
              UndirectedEdge[201, 230] -> 
             RGBColor[
              0.861506799370262, 0.41207253556849543`, 0.43345962340457855`], 
             UndirectedEdge[71, 138] -> 
             RGBColor[
              0.18058969715831197`, 0.30714160013447456`, 0.9335956881434259],
              UndirectedEdge[334, 360] -> 
             RGBColor[
              0.185115098539477, 0.3118980839130987, 0.9338534030573518], 
             UndirectedEdge[38, 58] -> 
             RGBColor[
              0.2174442667054725, 0.3458780894432118, 0.935694501357687], 
             UndirectedEdge[115, 239] -> 
             RGBColor[
              0.8523263340305828, 0.3902002184370166, 0.1972316827098783], 
             UndirectedEdge[32, 78] -> 
             RGBColor[
              0.8656358011330783, 0.391743634424193, 0.20700997583252984`], 
             UndirectedEdge[41, 83] -> 
             RGBColor[
              0.9084527486796484, 0.9295988421678656, 0.9827837388659694], 
             UndirectedEdge[90, 212] -> 
             RGBColor[
              0.5128575453871849, 0.6144229009627645, 0.9550631147611566], 
             UndirectedEdge[160, 263] -> 
             RGBColor[
              0.42578806203725694`, 0.5430467428327064, 0.9483991221427692], 
             UndirectedEdge[226, 350] -> 
             RGBColor[
              0.7195454075725961, 0.7758957836327975, 0.8505842343054555], 
             UndirectedEdge[159, 329] -> 
             RGBColor[
              0.18547778561514033`, 0.3122792910253096, 0.9338740575497635], 
             UndirectedEdge[132, 260] -> 
             RGBColor[
              0.29142760754703456`, 0.4190601234916939, 0.9400754082095211], 
             UndirectedEdge[7, 250] -> 
             RGBColor[
              0.35349640883612216`, 0.4759428684075872, 0.943916070428803], 
             UndirectedEdge[135, 281] -> 
             RGBColor[
              0.711765095722288, 0.768553055573181, 0.8142632180180123], 
             UndirectedEdge[240, 243] -> 
             RGBColor[
              0.877634681087591, 0.48865144168934355`, 0.43080856334956663`], 
             UndirectedEdge[105, 349] -> 
             RGBColor[
              0.20573070891450085`, 0.3335663975224413, 0.935027431570147], 
             UndirectedEdge[111, 154] -> 
             RGBColor[
              0.19738148096805996`, 0.3247908295791051, 0.934551955390173], 
             UndirectedEdge[3, 233] -> 
             RGBColor[
              0.7706376185941841, 0.8203361519689907, 0.9569123152308744], 
             UndirectedEdge[125, 162] -> 
             RGBColor[
              0.2669203824734684, 0.39788062408229774`, 0.9385120929573202], 
             UndirectedEdge[301, 369] -> 
             RGBColor[
              0.18664719483068826`, 0.31350841425567716`, 0.9339406536746029],
              UndirectedEdge[268, 270] -> 
             RGBColor[
              0.5192310696539062, 0.6174490867384653, 0.9563893333020512], 
             UndirectedEdge[4, 188] -> 
             RGBColor[
              0.2173017232473819, 0.34572826723098127`, 0.9356863837186229], 
             UndirectedEdge[161, 176] -> 
             RGBColor[
              0.21656199837052442`, 0.34495076948413805`, 0.9356442574812107],
              UndirectedEdge[106, 270] -> 
             RGBColor[
              0.2929589759941193, 0.42059333525935383`, 0.9401654130551529], 
             UndirectedEdge[190, 268] -> 
             RGBColor[
              0.8177911045280821, 0.8581558703042615, 0.9638348308947651], 
             UndirectedEdge[220, 341] -> 
             RGBColor[
              0.4860287842689018, 0.590440011686344, 0.9535595010943037], 
             UndirectedEdge[76, 103] -> 
             RGBColor[
              0.19412197120965846`, 0.32136487815817005`, 0.9343663311314445],
              UndirectedEdge[84, 163] -> 
             RGBColor[
              0.3028162711208553, 0.4328272844297121, 0.940658180484038], 
             UndirectedEdge[356, 372] -> 
             RGBColor[
              0.1945300591839852, 0.3217938044934594, 0.9343895711378705], 
             UndirectedEdge[243, 398] -> 
             RGBColor[
              0.6978102198330773, 0.7601382089599893, 0.9424198532319874], 
             UndirectedEdge[141, 243] -> 
             RGBColor[
              0.9002404219314994, 0.6473255027899616, 0.4518652115799682], 
             UndirectedEdge[192, 320] -> 
             RGBColor[
              0.18870690253434044`, 0.31567329764522667`, 0.9340579509812614],
              UndirectedEdge[83, 245] -> 
             RGBColor[
              0.860898200693226, 0.41667022121889674`, 0.43641880856357806`], 
             UndirectedEdge[256, 313] -> 
             RGBColor[
              0.28483799884386285`, 0.41277795475190926`, 0.9396765623907513],
              UndirectedEdge[144, 186] -> 
             RGBColor[
              0.19870087032152506`, 0.3261775914437136, 0.9346270926619912], 
             UndirectedEdge[271, 371] -> 
             RGBColor[
              0.1828236944867615, 0.3094896729702865, 0.9337229109863782], 
             UndirectedEdge[317, 326] -> 
             RGBColor[
              0.19368284883535128`, 0.3209033327008066, 0.9343413237618512], 
             UndirectedEdge[194, 242] -> 
             RGBColor[
              0.8996928400306943, 0.5987720630349767, 0.3471882500432634], 
             UndirectedEdge[305, 334] -> 
             RGBColor[
              0.18360707090558112`, 0.31031305125539965`, 0.9337675231145284],
              UndirectedEdge[252, 282] -> 
             RGBColor[
              0.31835440977210794`, 0.4463178036126423, 0.941647079240882], 
             UndirectedEdge[134, 239] -> 
             RGBColor[
              0.8288313392623307, 0.4322875085422818, 0.44405929782727327`], 
             UndirectedEdge[267, 398] -> 
             RGBColor[
              0.34104050458358826`, 0.46493592502132197`, 0.9431303829813984],
              UndirectedEdge[4, 297] -> 
             RGBColor[
              0.2198696831096341, 0.34842735586426754`, 0.9358326252338219], 
             UndirectedEdge[40, 272] -> 
             RGBColor[
              0.6309966022057711, 0.7098004613221861, 0.9651259277394999], 
             UndirectedEdge[203, 325] -> 
             RGBColor[
              0.2574480826974209, 0.38792463643917835`, 0.9379726594980861], 
             UndirectedEdge[315, 359] -> 
             RGBColor[
              0.2030249569861144, 0.33072248069112636`, 0.9348733430006266], 
             UndirectedEdge[132, 160] -> 
             RGBColor[
              0.40894844852211004`, 0.5284611159894712, 0.9473261168602697], 
             UndirectedEdge[283, 381] -> 
             RGBColor[
              0.20257187699290616`, 0.3302462648913338, 0.9348475407652852], 
             UndirectedEdge[40, 183] -> 
             RGBColor[
              0.43552341404886974`, 0.5498108720138242, 0.9494803631610341], 
             UndirectedEdge[131, 339] -> 
             RGBColor[
              0.23240211172972863`, 0.36159973294585546`, 0.9365463285036696],
              UndirectedEdge[156, 165] -> 
             RGBColor[
              0.8529070927455767, 0.4662869399049452, 0.44820826028057437`], 
             UndirectedEdge[352, 379] -> 
             RGBColor[
              0.22335212736306764`, 0.3520876255743447, 0.9360309452822404], 
             UndirectedEdge[25, 194] -> 
             RGBColor[
              0.8763898892162449, 0.41965537165696043`, 0.32487331802642816`],
              UndirectedEdge[174, 238] -> 
             RGBColor[
              0.3169893195658634, 0.44724710585547944`, 0.9414827781424888], 
             UndirectedEdge[66, 339] -> 
             RGBColor[
              0.23290928668708955`, 0.3621328059827914, 0.9365752113671932], 
             UndirectedEdge[67, 387] -> 
             RGBColor[
              0.4796742864541198, 0.5876973628554791, 0.9523916433059518], 
             UndirectedEdge[90, 190] -> 
             RGBColor[
              0.7822989919455827, 0.8299086268722369, 0.9606532016549456], 
             UndirectedEdge[271, 389] -> 
             RGBColor[
              0.19087423447573804`, 0.31795130093241747`, 0.9341813773290437],
              UndirectedEdge[19, 293] -> 
             RGBColor[
              0.3046492475878372, 0.4338240686707453, 0.9407966099576801], 
             UndirectedEdge[126, 327] -> 
             RGBColor[
              0.19109665502145906`, 0.31818507902824733`, 0.9341940438500809],
              UndirectedEdge[12, 310] -> 
             RGBColor[
              0.2940376027932159, 0.42638254196942454`, 0.9400563785381975], 
             UndirectedEdge[272, 350] -> 
             RGBColor[
              0.867391875594665, 0.894633501748924, 0.8631950663915847], 
             UndirectedEdge[215, 229] -> 
             RGBColor[
              0.19493972789376507`, 0.3222243922819345, 0.9344129011648419], 
             UndirectedEdge[57, 189] -> 
             RGBColor[
              0.24216202976271878`, 0.3718580256130724, 0.9371021413971435], 
             UndirectedEdge[104, 337] -> 
             RGBColor[
              0.877355021883467, 0.4279703757179083, 0.30836138294251203`], 
             UndirectedEdge[194, 385] -> 
             RGBColor[
              0.9944784929138155, 0.9905983795896796, 0.6403962123397537], 
             UndirectedEdge[56, 166] -> 
             RGBColor[
              0.6856726502293173, 0.7474973607293266, 0.8829926191709212], 
             UndirectedEdge[258, 379] -> 
             RGBColor[
              0.19525485067885182`, 0.32255560630899927`, 0.9344308469412701],
              UndirectedEdge[9, 150] -> 
             RGBColor[
              0.19229026561489077`, 0.3194396394412268, 0.9342620182075883], 
             UndirectedEdge[294, 380] -> 
             RGBColor[
              0.20504200072556777`, 0.3328425215492514, 0.9349882106576397], 
             UndirectedEdge[296, 308] -> 
             RGBColor[
              0.22323052785896746`, 0.35195981678568156`, 0.9360240203703722],
              UndirectedEdge[33, 92] -> 
             RGBColor[
              0.3869660924415177, 0.5054181375626268, 0.9463177797578736], 
             UndirectedEdge[39, 283] -> 
             RGBColor[
              0.19607798492560893`, 0.3234207725920666, 0.934477723218905], 
             UndirectedEdge[11, 34] -> 
             RGBColor[
              0.28760640007487454`, 0.41932535119602954`, 0.9397010272469036],
              UndirectedEdge[105, 171] -> 
             RGBColor[
              0.19921926143757313`, 0.32672245337457523`, 0.9346566142691592],
              UndirectedEdge[110, 237] -> 
             RGBColor[
              0.19038343508665123`, 0.3174354396560086, 0.9341534270299079], 
             UndirectedEdge[8, 175] -> 
             RGBColor[
              0.2597318112605219, 0.39032497995575144`, 0.938102714461281], 
             UndirectedEdge[90, 373] -> 
             RGBColor[
              0.44011491122134366`, 0.5480057067490964, 0.9505529184695845], 
             UndirectedEdge[73, 104] -> 
             RGBColor[
              0.8562111877661985, 0.35228531246266953`, 0.19823419564249584`],
              UndirectedEdge[232, 339] -> 
             RGBColor[
              0.2733203034534184, 0.404607346810652, 0.9388765589892938], 
             UndirectedEdge[178, 274] -> 
             RGBColor[
              0.46738436670940764`, 0.5781669894131862, 0.9513005905019778], 
             UndirectedEdge[224, 318] -> 
             RGBColor[
              0.18686239314258873`, 0.3137346013258456, 0.9339529089001083], 
             UndirectedEdge[132, 307] -> 
             RGBColor[
              0.3533139613151539, 0.48044452804031823`, 0.9437338310851009]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {400}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.1972575262297792, 0.3246605452899877, 0.9345448963512025], 
             316 -> RGBColor[
              0.23435379828218117`, 0.36365107925655765`, 0.9366574741655703],
              308 -> RGBColor[
              0.20150049615977755`, 0.32912017570624735`, 0.9347865272118044],
              160 -> RGBColor[
              0.4596234812344611, 0.572182073724828, 0.9506023905805157], 245 -> 
             RGBColor[
              0.818830055518114, 0.14574163486097447`, 0.1656649884706391], 
             155 -> RGBColor[
              0.2070813101039675, 0.3349859650056321, 0.9351043463098516], 
             213 -> RGBColor[
              0.22261848399738943`, 0.3513165198813409, 0.9359891653778931], 
             352 -> RGBColor[
              0.2396024194233052, 0.3691677128576799, 0.9369563753749182], 27 -> 
             RGBColor[
              0.821038236612611, 0.16271468238440395`, 0.16777954518051325`], 
             367 -> RGBColor[
              0.37508215881778845`, 0.49929904661568136`, 0.9451208813811075],
              19 -> RGBColor[
              0.26040419361571815`, 0.3910316964425663, 0.9381410056417089], 
             164 -> RGBColor[
              0.20095261322947336`, 0.32854431600871353`, 0.9347553260894438],
              190 -> RGBColor[
              0.9562193148935751, 0.9668690172486966, 0.9589934594404549], 
             103 -> RGBColor[
              0.19434739415987903`, 0.3216018119714924, 0.9343791686349763], 
             138 -> RGBColor[
              0.18225239431662393`, 0.3088892002689491, 0.9336903762868517], 
             291 -> RGBColor[
              0.18717515147111807`, 0.3140633301591533, 0.9339707200242335], 
             28 -> RGBColor[
              0.20698871416859752`, 0.3348886408066369, 0.9350990731083157], 
             337 -> RGBColor[
              0.9940468194635823, 0.9896750737285114, 0.5934112212615963], 
             195 -> RGBColor[
              0.20184829587443234`, 0.32948573525812513`, 0.9348063338910304],
              114 -> RGBColor[
              0.24129060741956473`, 0.3709421054790498, 0.9370525151838548], 
             93 -> RGBColor[
              0.2343202347626608, 0.3636158018694917, 0.9366555627727864], 34 -> 
             RGBColor[
              0.2632481201845229, 0.3940208435817391, 0.93830296305259], 161 -> 
             RGBColor[
              0.1994550789542851, 0.32697031253633363`, 0.9346700437278752], 
             22 -> RGBColor[
              0.3162753653274515, 0.4483635578097335, 0.9413737645007089], 
             124 -> 
             RGBColor[
              0.3097296345397099, 0.44269397479938727`, 0.9409566763230764], 
             84 -> RGBColor[
              0.3388378220394789, 0.4679060237916442, 0.9428114242912021], 46 -> 
             RGBColor[
              0.20129344185623907`, 0.3289025485052273, 0.9347747357755273], 
             241 -> RGBColor[
              0.2632132370288079, 0.3939841791733627, 0.938300976508477], 185 -> 
             RGBColor[
              0.3996003392677278, 0.5205354622018381, 0.9466831581588019], 
             390 -> RGBColor[
              0.2627109211596987, 0.39345621334626335`, 0.938272370362841], 
             121 -> RGBColor[
              0.3109061797336599, 0.4437130391115059, 0.9410316447424569], 
             322 -> RGBColor[
              0.1999051049994005, 0.32744331844304914`, 0.9346956720453906], 
             126 -> RGBColor[
              0.1865862227024127, 0.3134443286830033, 0.9339371814020978], 
             236 -> RGBColor[
              0.25077535368791876`, 0.38091117517473666`, 0.9375926574524128],
              78 -> RGBColor[
              0.8199375785531087, 0.1542545422276314, 0.1667255537797183], 
             376 -> RGBColor[
              0.209601906353837, 0.3376352714792777, 0.9352478905373938], 254 -> 
             RGBColor[
              0.18724741023772068`, 0.314139278704323, 0.9339748350540943], 
             290 -> RGBColor[
              0.19821724293608944`, 0.32566926839787347`, 0.9345995507978533],
              251 -> RGBColor[
              0.19027393338711107`, 0.3173203464269832, 0.9341471910701123], 
             165 -> RGBColor[
              0.8967495440562933, 0.920507761085305, 0.9900139661214994], 100 -> 
             RGBColor[
              0.2101475089071078, 0.33820873435596516`, 0.9352789617956558], 
             235 -> RGBColor[
              0.1915139828942802, 0.31862371708269777`, 0.9342178100550568], 
             70 -> RGBColor[
              0.22291581655962178`, 0.35162903525622036`, 0.9360060980274482],
              234 -> RGBColor[
              0.7857227396767522, 0.8325318430402561, 0.9792771577606599], 
             257 -> RGBColor[
              0.32310439559809073`, 0.45427852059311985`, 0.9418089042708796],
              135 -> RGBColor[
              0.9948422584139026, 0.9913764372120322, 0.679989842123797], 265 -> 
             RGBColor[
              0.18998272969436467`, 0.3170142728825262, 0.9341306074506077], 
             111 -> RGBColor[
              0.18925042984728385`, 0.3162445793127523, 0.934088904057657], 
             381 -> 
             RGBColor[
              0.19616341759440778`, 0.32351056774371817`, 0.9344825884830068],
              182 -> RGBColor[
              0.34853172220347034`, 0.47630239288410453`, 0.9434291110376724],
              188 -> RGBColor[
              0.2017846044041309, 0.3294187914845658, 0.9348027067560198], 
             154 -> RGBColor[
              0.2055125320888361, 0.33333707984545796`, 0.935015006722689], 
             336 -> RGBColor[
              0.18035329176886106`, 0.3068931230811942, 0.933582225206227], 
             315 -> RGBColor[
              0.2188459842157359, 0.34735138342052185`, 0.9357743270962412], 
             368 -> RGBColor[
              0.1851720653526604, 0.311957959645659, 0.9338566472330878], 269 -> 
             RGBColor[
              0.743581503407994, 0.7996107889818441, 0.9750769131616334], 208 -> 
             RGBColor[
              0.9930152754848626, 0.9913796511608278, 0.7654184913108293], 86 -> 
             RGBColor[
              0.4110226556238299, 0.5304288985271809, 0.947410978056655], 119 -> 
             RGBColor[
              0.18241596627536708`, 0.30906112476864933`, 0.9336996914679191],
              377 -> RGBColor[
              0.18473621585810335`, 0.3114998541924255, 0.9338318262491543], 
             140 -> RGBColor[
              0.2256991535454318, 0.35455449890206425`, 0.9361646049512119], 
             85 -> RGBColor[
              0.24074527521724318`, 0.3703689267583512, 0.9370214593216792], 
             351 -> RGBColor[
              0.9097894237460113, 0.9309054071917814, 0.9912577214871428], 
             242 -> RGBColor[
              0.852273426221674, 0.40280203706702433`, 0.19769039802525293`], 
             117 -> RGBColor[
              0.22614100723621103`, 0.3550189151462153, 0.9361897678652379], 
             47 -> RGBColor[
              0.5441036538714303, 0.6407668836599264, 0.9572529792315668], 81 -> 
             RGBColor[
              0.17955783501139488`, 0.30605704759422586`, 0.9335369251206622],
              275 -> RGBColor[
              0.23875032994207512`, 0.36827211278731364`, 0.9369078501395155],
              23 -> RGBColor[
              0.2930562064900811, 0.4253510322307103, 0.9400004894705796], 
             328 -> RGBColor[
              0.8695307562797816, 0.5004514607800906, 0.21284560375709155`], 
             110 -> RGBColor[
              0.18343408206602244`, 0.3101312290168976, 0.9337576716560296], 
             6 -> RGBColor[
              0.30558851701585305`, 0.4385232851876776, 0.9407141860151303], 
             218 -> 
             RGBColor[
              0.19086057119328328`, 0.3179369399562554, 0.934180599225321], 
             108 -> RGBColor[
              0.256153514960176, 0.38656396366699863`, 0.9378989357805914], 
             297 -> RGBColor[
              0.20692052412863532`, 0.33481696875113837`, 0.935095189786418], 
             157 -> RGBColor[
              0.1873941802353717, 0.31429354327760956`, 0.9339831933883338], 
             354 -> RGBColor[
              0.2158527042869893, 0.34420525643050026`, 0.9356038642324599], 
             385 -> RGBColor[
              0.9944253181788963, 0.9904846442084778, 0.6346084706002231], 
             270 -> RGBColor[
              0.3590992451452233, 0.4854554501171043, 0.9441024642550272], 
             392 -> RGBColor[
              0.9910839134677017, 0.9905809833329919, 0.7974261581398643], 33 -> 
             RGBColor[
              0.2765417318743941, 0.4079932723314563, 0.939060014572192], 252 -> 
             RGBColor[
              0.3695662131784596, 0.4945214117423836, 0.9447694102025287], 
             394 -> RGBColor[
              0.18043226082461958`, 0.30697612456572376`, 0.9335867223771283],
              260 -> RGBColor[
              0.22458179928431016`, 0.35338008872927346`, 0.9361009732790185],
              159 -> RGBColor[
              0.1805122222555836, 0.3070601690995145, 0.9335912760623294], 
             183 -> RGBColor[
              0.3499869056482099, 0.4775627996442913, 0.943521834040003], 99 -> 
             RGBColor[
              0.965636915117815, 0.9738926480760296, 0.9430519187643377], 329 -> 
             RGBColor[
              0.19044334897469703`, 0.3174984129511047, 0.9341568390371975], 
             309 -> RGBColor[
              0.2975965440226766, 0.4301232148514946, 0.9402590549762334], 17 -> 
             RGBColor[
              0.2316763474093035, 0.360836908628973, 0.9365049972992935], 349 -> 
             RGBColor[
              0.2019856527302044, 0.3296301060224692, 0.9348141561607654], 
             347 -> RGBColor[
              0.19785125300646603`, 0.3252845897767374, 0.9345787082127948], 
             340 -> RGBColor[
              0.2029347338096705, 0.33062765041220404`, 0.9348682049242014], 
             277 -> RGBColor[
              0.20781531186542476`, 0.3357574473953233, 0.9351461466243084], 
             104 -> RGBColor[
              0.8190091230934095, 0.14711802671260676`, 0.16583646378296987`],
              79 -> RGBColor[
              0.23104392871496413`, 0.36017219648356114`, 0.9364689819902305],
              327 -> 
             RGBColor[
              0.19560708734050541`, 0.3229258293734914, 0.9344509062980639], 
             191 -> RGBColor[
              0.20722377740839654`, 0.33513570717553587`, 0.9351124596120775],
              50 -> RGBColor[
              0.1790362447681438, 0.3055088231778375, 0.9335072213279326], 
             225 -> RGBColor[
              0.884710274500928, 0.9109079743391231, 0.9888656498437259], 61 -> 
             RGBColor[
              0.20936457771848743`, 0.3373858240360207, 0.9352343750227069], 
             196 -> RGBColor[
              0.18973547474422028`, 0.3167543922530552, 0.9341165266469779], 
             1 -> RGBColor[
              0.19354678877808446`, 0.32076032495391327`, 0.9343335753428726],
              263 -> RGBColor[
              0.3919526428400527, 0.5139114119405849, 0.9461958537050229], 
             201 -> RGBColor[
              0.9490437648216794, 0.9615175037539616, 0.971139794028986], 371 -> 
             RGBColor[
              0.18654757264035143`, 0.3134037050172214, 0.9339349803382411], 
             293 -> RGBColor[
              0.3488943015599562, 0.47661644089892424`, 0.9434522142736513], 
             362 -> RGBColor[
              0.18916507484151227`, 0.3161548657898664, 0.9340840432163497], 
             184 -> RGBColor[
              0.18311045325504194`, 0.3097910746173054, 0.9337392414740102], 
             106 -> RGBColor[
              0.22681870684301533`, 0.35573122040160343`, 0.9362283618552786],
              206 -> RGBColor[
              0.7303132143006519, 0.7892455006884563, 0.9737544541026248], 
             358 -> RGBColor[
              0.19077583416012883`, 0.31784787596177183`, 0.9341757735766401],
              247 -> RGBColor[
              0.1976279917679603, 0.3250499280594878, 0.9345659938155473], 
             220 -> RGBColor[
              0.635822518194204, 0.7152283896049052, 0.9644734242083259], 107 -> 
             RGBColor[
              0.34861868121472545`, 0.4763777124089667, 0.9434346519889747], 
             375 -> RGBColor[
              0.180596656524124, 0.30714891486919227`, 0.9335960844690134], 
             131 -> RGBColor[
              0.21325644631447746`, 0.3414764246891273, 0.9354560111817448], 
             127 -> RGBColor[
              0.19480415931956344`, 0.32208190111490453`, 0.9344051807350968],
              210 -> RGBColor[
              0.3056537490672848, 0.4385918482096833, 0.9407179008839572], 
             357 -> RGBColor[
              0.85710048921771, 0.439904958487049, 0.20231279900164487`], 181 -> 
             RGBColor[
              0.19492367816056405`, 0.3222075229947284, 0.9344119871562795], 
             194 -> RGBColor[
              0.9945316676487347, 0.9907121149708813, 0.6461839540792844], 
             118 -> RGBColor[
              0.2388812891503496, 0.36840975921850344`, 0.93691530807269], 
             348 -> RGBColor[
              0.33313964664549794`, 0.4629705506640006, 0.9424483415937963], 
             276 -> RGBColor[
              0.22285712514090053`, 0.35156734685389346`, 0.9360027556379781],
              305 -> RGBColor[
              0.18223318953702214`, 0.3088690148279342, 0.9336892826030643], 
             343 -> RGBColor[
              0.1820208818055452, 0.30864586594106436`, 0.9336771919918379], 
             280 -> RGBColor[
              0.2515360626002474, 0.3817107284733248, 0.937635978699602], 189 -> 
             RGBColor[
              0.266643234211289, 0.39758932368653244`, 0.9384963097737932], 
             168 -> RGBColor[
              0.18420503135956878`, 0.31094154560542325`, 0.9338015760777798],
              363 -> RGBColor[
              0.21990087473071346`, 0.348460140235685, 0.9358344015504985], 
             41 -> RGBColor[
              0.8718710063158469, 0.90067029040099, 0.9876410289824828], 14 -> 
             RGBColor[
              0.18454901891679482`, 0.31130309833813863`, 0.9338211656602798],
              77 -> RGBColor[
              0.18280925758947733`, 0.30947449887588874`, 0.9337220888264354],
              51 -> RGBColor[
              0.381577964086101, 0.5049253866504279, 0.9455347883487892], 179 -> 
             RGBColor[
              0.45394807471440896`, 0.5675745230376996, 0.950155601789558], 
             223 -> RGBColor[
              0.9299021495647822, 0.7597924122879596, 0.2624558280130423], 
             323 -> RGBColor[
              0.3986910652219958, 0.5197478947248675, 0.9466252200206473], 
             292 -> RGBColor[
              0.1943854920349882, 0.321641855253777, 0.934381338252603], 396 -> 
             RGBColor[
              0.19955786085140656`, 0.3270783428269569, 0.9346758970048641], 
             321 -> RGBColor[
              0.5543615420614805, 0.6490946994052059, 0.9580605177657702], 
             143 -> RGBColor[
              0.18504307948317125`, 0.3118223873186494, 0.9338493016786379], 
             112 -> RGBColor[
              0.937107871400364, 0.788360698201582, 0.2682537209419814], 197 -> 
             RGBColor[
              0.9643115115712477, 0.9729041642811488, 0.9452954812480678], 54 -> 
             RGBColor[
              0.1846123721443362, 0.31136968659711123`, 0.9338247735328656], 
             71 -> RGBColor[0.178927, 0.305394, 0.933501], 177 -> 
             RGBColor[
              0.8948525196191675, 0.9189951252924975, 0.9898330262371927], 
             158 -> RGBColor[
              0.3387561380668311, 0.4678352732400925, 0.9428062194606953], 
             226 -> RGBColor[
              0.44524034591787487`, 0.5600665420287623, 0.9495912990246761], 
             350 -> RGBColor[
              0.9938504692273173, 0.9917250252368329, 0.751577169586235], 203 -> 
             RGBColor[
              0.2257570420476589, 0.35461534338824796`, 0.9361679016157753], 
             115 -> RGBColor[
              0.8646080428941941, 0.47809856902505976`, 0.2087379710414105], 
             173 -> RGBColor[
              0.2824798268544749, 0.4142345866524884, 0.9393981802966833], 
             212 -> RGBColor[
              0.41733642177677943`, 0.535897565429752, 0.9478132856528767], 
             129 -> RGBColor[
              0.189088316742455, 0.3160741881610126, 0.9340796719561618], 279 -> 
             RGBColor[
              0.6722342021283076, 0.7438737349625797, 0.9679656809485127], 26 -> 
             RGBColor[
              0.18699939157323073`, 0.3138785953626525, 0.9339607107580624], 
             40 -> RGBColor[
              0.5210599224495296, 0.6220589443833571, 0.9554388922820652], 
             146 -> RGBColor[
              0.18614238840660097`, 0.3129778306973855, 0.9339119056955454], 
             386 -> RGBColor[
              0.7607606134285254, 0.8130312402959552, 0.9767891663005692], 
             192 -> RGBColor[
              0.18162114890697434`, 0.30822572132013676`, 0.933654427794616], 
             300 -> RGBColor[
              0.9146994662552146, 0.9348205418090667, 0.9917260457249173], 
             221 -> RGBColor[
              0.9023083761464576, 0.6492869771870501, 0.2401960532268301], 62 -> 
             RGBColor[
              0.20110579749352597`, 0.32870532238267614`, 0.9347640497066657],
              286 -> RGBColor[
              0.1948453625020903, 0.32212520827217295`, 0.9344075271953871], 
             152 -> RGBColor[
              0.25676930210776144`, 0.3872111950022711, 0.9379340039476709], 
             64 -> RGBColor[
              0.18064334912177313`, 0.30719799174980317`, 0.933598743543374], 
             307 -> RGBColor[
              0.3483545068205488, 0.47614889782652203`, 0.9434178190301781], 
             37 -> RGBColor[
              0.34879862256835453`, 0.4765335685653648, 0.9434461176929121], 
             148 -> 
             RGBColor[
              0.33397821749630197`, 0.46369687858717057`, 0.9425017745868906],
              261 -> RGBColor[
              0.2599700418165058, 0.39057537537478015`, 0.9381162813390138], 
             387 -> RGBColor[
              0.5341260408491124, 0.6326666079220644, 0.9564675049852491], 15 -> 
             RGBColor[
              0.28582560720535155`, 0.41775121393598635`, 0.9395887175380273],
              136 -> RGBColor[
              0.18458947116943916`, 0.3113456162204888, 0.9338234693562242], 
             198 -> RGBColor[
              0.3533082208089774, 0.4804395559023944, 0.9437334653051234], 63 -> 
             RGBColor[
              0.1811814280726413, 0.30776354684334156`, 0.9336293863436095], 
             310 -> RGBColor[
              0.27959908951497947`, 0.4112067490593821, 0.9392341265668681], 
             171 -> RGBColor[
              0.188962757776349, 0.315942217726737, 0.93407252155879], 395 -> 
             RGBColor[
              0.46863892160806836`, 0.5795012143610829, 0.9513121190713723], 
             311 -> RGBColor[
              0.3027440138032642, 0.4355335319593264, 0.9405521957652387], 
             353 -> RGBColor[
              0.19002087389400624`, 0.31705436485483146`, 0.934132779706348], 
             59 -> RGBColor[
              0.3465121371910148, 0.4745531298536097, 0.9433004248665277], 
             397 -> RGBColor[
              0.2129233554713194, 0.341126325093789, 0.9354370421509908], 229 -> 
             RGBColor[
              0.20688302376209858`, 0.33477755348824767`, 0.9350930541960206],
              102 -> RGBColor[
              0.2774713947406823, 0.40897040694795533`, 0.9391129574971142], 
             299 -> RGBColor[
              0.18766218808016377`, 0.31457523651516484`, 0.9339984560386126],
              128 -> RGBColor[
              0.19461177340916913`, 0.32187969132510885`, 0.9343942246421093],
              12 -> RGBColor[
              0.3084761160714523, 0.441558334879467, 0.9408786305095267], 222 -> 
             RGBColor[
              0.23238602207295528`, 0.3615828216964435, 0.9365454122215189], 
             92 -> RGBColor[
              0.49739045300864126`, 0.6028430027937971, 0.9535755449435551], 
             271 -> RGBColor[
              0.17909981633317154`, 0.30557564092335165`, 0.9335108416345153],
              361 -> RGBColor[
              0.21763599434706354`, 0.34607960735075854`, 0.93570541996324], 
             344 -> RGBColor[
              0.1912494582787511, 0.31834568493994736`, 0.9342027457695316], 
             132 -> 
             RGBColor[
              0.35827341580975897`, 0.4847401582541144, 0.9440498431400237], 
             80 -> RGBColor[
              0.1798079986201722, 0.3063199854083397, 0.9335511715680982], 
             324 -> RGBColor[
              0.6331296311169758, 0.713042182562431, 0.9642614302732361], 244 -> 
             RGBColor[
              0.9547654228714991, 0.9657847069591619, 0.9614545193980599], 
             150 -> RGBColor[
              0.19354588592399127`, 0.3207593759970171, 0.9343335239266677], 
             125 -> RGBColor[
              0.2615118954900493, 0.3921959613448436, 0.9382040876247539], 
             258 -> RGBColor[
              0.18340786605487358`, 0.31010367432698904`, 0.9337561786929778],
              133 -> RGBColor[
              0.18578718983175693`, 0.312604494474334, 0.9338916776621772], 
             255 -> RGBColor[
              0.8353613957275855, 0.2728087597904426, 0.18149541852470724`], 
             326 -> RGBColor[
              0.19201165546058205`, 0.31914680250414423`, 0.9342461517714671],
              176 -> RGBColor[
              0.23366891778676377`, 0.3629312264319425, 0.9366184712345461], 
             230 -> RGBColor[
              0.8177383166445533, 0.1373500514757623, 0.1646195380923747], 
             274 -> RGBColor[
              0.49307848673520527`, 0.5993423543211548, 0.9532360911632574], 
             87 -> RGBColor[
              0.19817896485079942`, 0.32562903570326285`, 0.9345973709175234],
              130 -> RGBColor[
              0.1820121662584413, 0.30863670534846055`, 0.9336766956543238], 
             35 -> RGBColor[
              0.2362515342121432, 0.36564572004235524`, 0.9367655474193329], 
             379 -> RGBColor[
              0.20710183530283005`, 0.33500753829100943`, 0.9351055151895625],
              31 -> RGBColor[
              0.19647646719475834`, 0.3238396027221777, 0.9345004161946314], 
             18 -> RGBColor[
              0.6051402883638863, 0.6903191732099512, 0.9620580066833722], 24 -> 
             RGBColor[
              0.8207868509580615, 0.16078242208563953`, 0.1675388179938171], 
             151 -> RGBColor[
              0.19201931518110454`, 0.3191548533560677, 0.9342465879812193], 
             137 -> RGBColor[
              0.33446348254021346`, 0.46411719077807645`, 0.9425326952463855],
              330 -> RGBColor[
              0.18593025704413854`, 0.31275486718553225`, 0.9338998251282734],
              296 -> RGBColor[
              0.2449605595581574, 0.37479945786511576`, 0.9372615135289399], 
             266 -> 
             RGBColor[
              0.23275233921967517`, 0.3619678442434947, 0.9365662734411069], 
             302 -> RGBColor[
              0.19137511524925596`, 0.3184777583830601, 0.9342099017481089], 
             283 -> RGBColor[
              0.20898033639140454`, 0.33698196203894937`, 0.9352124930475636],
              388 -> RGBColor[
              0.2195142065627996, 0.3480537274750297, 0.9358123813703602], 
             284 -> RGBColor[
              0.2765987024765969, 0.40805315204651627`, 0.939063258963707], 
             318 -> RGBColor[
              0.19439044372267295`, 0.3216470597914888, 0.9343816202438913], 
             238 -> RGBColor[
              0.28998218143607674`, 0.4221200369945062, 0.9398254282913666], 
             72 -> RGBColor[
              0.18281412095909713`, 0.3094796105857146, 0.9337223657881405], 
             288 -> RGBColor[
              0.30537118422496984`, 0.4382948546447645, 0.9407018092342045], 
             382 -> RGBColor[
              0.1818914944971056, 0.30850987167626515`, 0.9336698235760336], 
             389 -> RGBColor[
              0.20264865261830456`, 0.3303269609414833, 0.9348519130235723], 
             172 -> RGBColor[
              0.8238032261936802, 0.18396760393066158`, 0.17042730232595416`],
              243 -> RGBColor[
              0.9695261963263196, 0.9767932676332187, 0.9364683801653377], 88 -> 
             RGBColor[
              0.19146940577852636`, 0.3185768637076881, 0.9342152714542605], 
             273 -> RGBColor[
              0.1818250295794584, 0.30844001283369876`, 0.9336660384972996], 
             202 -> RGBColor[
              0.2433593553333951, 0.37311649070267905`, 0.9371703273171091], 
             393 -> RGBColor[
              0.18336325239717496`, 0.31005678254407854`, 0.9337536380111718],
              98 -> RGBColor[
              0.20101540430520026`, 0.32861031341048663`, 0.9347589019483153],
              30 -> RGBColor[
              0.18021067351487519`, 0.3067432222537355, 0.9335741033076473], 
             116 -> RGBColor[
              0.18333815129494635`, 0.31003039969413443`, 0.9337522085405336],
              373 -> RGBColor[
              0.271851153445097, 0.4030631770024157, 0.9387928930697325], 240 -> 
             RGBColor[
              0.8316889234682268, 0.24458052871740593`, 0.17797865494168116`],
              317 -> RGBColor[
              0.1953540422101205, 0.32265986289746895`, 0.9344364957522352], 
             391 -> RGBColor[
              0.18112688553091424`, 0.3077062191737896, 0.9336262802265466], 
             73 -> 
             RGBColor[
              0.9306153171117766, 0.762619883962795, 0.26302965936154776`], 
             303 -> RGBColor[
              0.21323548342695858`, 0.34145439136522115`, 0.9354548173763124],
              29 -> RGBColor[
              0.1814383294461641, 0.30803356647540187`, 0.9336440164967801], 
             360 -> RGBColor[
              0.18524924480481392`, 0.31203908014333226`, 0.9338610424887112],
              320 -> RGBColor[
              0.19579265616170655`, 0.32312087397031664`, 0.9344614741679068],
              75 -> RGBColor[
              0.21796667840296896`, 0.34642717726009525`, 0.9357242519310205],
              200 -> RGBColor[
              0.1842143453500115, 0.31095133519991963`, 0.9338021064957567], 
             301 -> RGBColor[
              0.18269671784651187`, 0.30935621247060024`, 0.933715679854561], 
             156 -> RGBColor[
              0.8309858670902185, 0.23917652931476524`, 0.17730540736011186`],
              25 -> RGBColor[0.817319, 0.134127, 0.164218], 38 -> 
             RGBColor[
              0.22292982485851465`, 0.3516437588665342, 0.9360068957793466], 
             365 -> RGBColor[
              0.18093049359979738`, 0.3074997988022181, 0.9336150959966053], 
             380 -> RGBColor[
              0.22012423896070668`, 0.348694910203518, 0.9358471218129588], 
             370 -> RGBColor[
              0.18708771794254558`, 0.3139714319770177, 0.9339657408141276], 
             3 -> RGBColor[
              0.5818688834669836, 0.6714263983498019, 0.960225996443923], 57 -> 
             RGBColor[
              0.21768082531414856`, 0.3461267275396124, 0.9357079730204939], 
             227 -> RGBColor[
              0.20746958876179836`, 0.3353940704933011, 0.9351264582050084], 
             39 -> RGBColor[
              0.18317563345981333`, 0.30985958314518375`, 0.9337429533902465],
              109 -> RGBColor[
              0.18132254229683142`, 0.30791186684012395`, 0.9336374225899173],
              256 -> RGBColor[
              0.3513087838325387, 0.47870774408802763`, 0.9436060629490174], 
             339 -> RGBColor[
              0.2515477771449798, 0.3817230412025836, 0.9376366458255944], 
             287 -> RGBColor[
              0.1899324083338537, 0.31696138194207063`, 0.9341277417235704], 
             239 -> RGBColor[
              0.82776291630336, 0.2144035172609302, 0.17421910604681382`], 
             285 -> RGBColor[
              0.9941990383585994, 0.9900006545532618, 0.6099793085980734], 
             345 -> 
             RGBColor[
              0.1789871968344326, 0.3054572706896884, 0.9335044281206677], 
             366 -> RGBColor[
              0.39439940253334044`, 0.5160306722091927, 0.9463517590690945], 
             216 -> RGBColor[
              0.1997106484206986, 0.3272389322495743, 0.9346845980309063], 21 -> 
             RGBColor[
              0.9632021039744041, 0.8875341975281088, 0.3115475519504825], 
             355 -> RGBColor[
              0.7657071355725306, 0.8168955009898127, 0.9772821894000061], 
             175 -> RGBColor[
              0.28165135838121924`, 0.41336381375916165`, 0.9393510002427407],
              7 -> RGBColor[
              0.4486453266434888, 0.5630157651939816, 0.9498082613856059], 13 -> 
             RGBColor[
              0.21416269395992185`, 0.3424289484239088, 0.9355076206444797], 
             294 -> RGBColor[
              0.1899597624904289, 0.3169901328949849, 0.9341292995023205], 
             193 -> RGBColor[
              0.18694492825143932`, 0.3138213509582757, 0.9339576091524576], 
             60 -> RGBColor[
              0.186004909472108, 0.3128333316205655, 0.9339040764736078], 65 -> 
             RGBColor[
              0.2879462259501837, 0.4199801186917991, 0.9397094836383711], 69 -> 
             RGBColor[
              0.2418162773238607, 0.37149461787786187`, 0.9370824513072455], 
             217 -> RGBColor[
              0.9930695883095065, 0.987584875103169, 0.4870456409120508], 214 -> 
             RGBColor[
              0.23974505627195325`, 0.36931763322930755`, 0.9369644983324363],
              170 -> RGBColor[
              0.2316644133079956, 0.36082436513183264`, 0.936504317669879], 
             359 -> RGBColor[
              0.18720392975649292`, 0.3140935779617309, 0.9339723589050121], 
             74 -> RGBColor[
              0.8630600513163033, 0.8936446740513561, 0.986800632228994], 246 -> 
             RGBColor[
              0.9202453542726101, 0.9392426823750178, 0.9922550174748891], 
             264 -> RGBColor[
              0.7232916660208124, 0.7837602138065023, 0.9730546117901898], 
             278 -> RGBColor[
              0.25816588373595994`, 0.3886790908418973, 0.9380135372053394], 
             45 -> RGBColor[
              0.2848093981590889, 0.41668311379698936`, 0.9395308459361892], 
             306 -> RGBColor[
              0.20271236623405806`, 0.3303939279913168, 0.9348555414197336], 
             237 -> RGBColor[
              0.19733278810728, 0.3247396502951197, 0.9345491824037863], 228 -> 
             RGBColor[
              0.20359531165465325`, 0.33132195961033534`, 0.9349058238552358],
              180 -> RGBColor[
              0.2585433275657887, 0.3890758082383683, 0.93803503207307], 383 -> 
             RGBColor[
              0.20835388918653433`, 0.3363235263075839, 0.9351768178059918], 
             53 -> RGBColor[
              0.19239706134193654`, 0.319551888521592, 0.9342681000662533], 
             304 -> RGBColor[
              0.1808905282724361, 0.3074577927092133, 0.9336128200303355], 48 -> 
             RGBColor[
              0.24018804114120323`, 0.3697832384137522, 0.9369897256654027], 
             5 -> RGBColor[
              0.2824395297681887, 0.41419223185981874`, 0.9393958854372335], 
             101 -> RGBColor[
              0.1831002535865883, 0.30978035411906424`, 0.9337386606179808], 
             333 -> RGBColor[
              0.18811264277564865`, 0.31504869296059673`, 0.9340241087671325],
              267 -> RGBColor[
              0.2559867658273416, 0.386388699755884, 0.9378894396641596], 120 -> 
             RGBColor[
              0.5182991743784003, 0.6198176447289311, 0.9552215560809526], 
             147 -> RGBColor[
              0.1834762116557925, 0.31017550988691617`, 0.9337600708738418], 
             89 -> RGBColor[
              0.1892450123424645, 0.31623888517169746`, 0.934088595538772], 
             43 -> RGBColor[
              0.26035980612556775`, 0.3909850423760888, 0.9381384778398102], 
             199 -> RGBColor[
              0.18648980339442428`, 0.3133429858769703, 0.9339316904651475], 
             268 -> RGBColor[
              0.679362894162589, 0.7494427233598264, 0.9686762023490751], 169 -> 
             RGBColor[
              0.8957887014800139, 0.9197416112963568, 0.9899223200988196], 20 -> 
             RGBColor[
              0.19028821830363388`, 0.31733536077996466`, 0.9341480045749757],
              4 -> RGBColor[
              0.23281884209063286`, 0.36203774297739677`, 0.9365700606812258],
              167 -> RGBColor[
              0.3102543804501736, 0.4431484833325346, 0.9409901126684767], 
             142 -> RGBColor[
              0.18248883410320854`, 0.3091377134757978, 0.9337038411829164], 
             16 -> RGBColor[
              0.3177755060429437, 0.4496629042982282, 0.9414693521405777], 
             281 -> RGBColor[
              0.4286879330306734, 0.5457296739343299, 0.9485365939122276], 
             289 -> RGBColor[
              0.1861676814246589, 0.31300441526303435`, 0.9339133460955061], 
             398 -> 
             RGBColor[
              0.4260942433398349, 0.54348315028676, 0.9483713262986371], 178 -> 
             RGBColor[
              0.44169024668361, 0.5569916245052177, 0.9493650898406981], 58 -> 
             RGBColor[
              0.21195870855243037`, 0.3401124200198894, 0.9353821069360272], 
             186 -> RGBColor[
              0.20685160848485196`, 0.33474453404001786`, 0.9350912651424561],
              122 -> RGBColor[
              0.5979628209588992, 0.6844921818293608, 0.9614929701573222], 
             249 -> RGBColor[
              0.3090764058516128, 0.442128180941986, 0.9409150531686984], 113 -> 
             RGBColor[
              0.30752560771325343`, 0.4405592903292892, 0.9408245004646784], 
             52 -> RGBColor[
              0.17936539842637753`, 0.30585478454218845`, 0.9335259661418299],
              187 -> RGBColor[
              0.43492032413853554`, 0.551127857862875, 0.9489337163625334], 
             259 -> RGBColor[
              0.18623692915551526`, 0.3130771990187241, 0.9339172896513356], 
             42 -> RGBColor[
              0.21651396498896067`, 0.34490028335462225`, 0.9356415220511897],
              134 -> RGBColor[
              0.830968185180272, 0.8680554911049849, 0.9837396813881922], 313 -> 
             RGBColor[
              0.218367213855187, 0.3468481654157909, 0.9357470618324852], 248 -> 
             RGBColor[
              0.21799885977606132`, 0.3464610019236322, 0.9357260846126101], 
             174 -> RGBColor[
              0.34399645769565007`, 0.4723741747164527, 0.943140127993611], 
             215 -> RGBColor[
              0.18299643202543156`, 0.30967123107562133`, 0.9337327481336631],
              399 -> RGBColor[
              0.9265760623547111, 0.7466055848528861, 0.2597795801705179], 83 -> 
             RGBColor[
              0.9450344910434499, 0.9585273939347413, 0.9779264487494559], 95 -> 
             RGBColor[
              0.559409915392181, 0.6531931963016955, 0.9584579442071637], 166 -> 
             RGBColor[
              0.9896948922783259, 0.9900065873749687, 0.82044583391943], 384 -> 
             RGBColor[
              0.18955786573703887`, 0.316567713925446, 0.9341064120767679], 
             233 -> RGBColor[
              0.9594063537213845, 0.9692459055881796, 0.9535986340178257], 
             295 -> RGBColor[
              0.4290348579738498, 0.5460301628831548, 0.9485586996628331], 
             141 -> RGBColor[
              0.8655975347340893, 0.482591620368333, 0.20956362728728348`], 
             319 -> 
             RGBColor[
              0.4533617737780597, 0.567098537525015, 0.9501094460321575], 205 -> 
             RGBColor[
              0.3500177192487492, 0.4775894888363419, 0.943523797455382], 224 -> 
             RGBColor[
              0.1793343425625045, 0.3058221428602024, 0.9335241975563253], 
             231 -> RGBColor[
              0.18219295480676673`, 0.3088267255754066, 0.9336869912946982], 
             332 -> RGBColor[
              0.2283446787479909, 0.35733511362593967`, 0.9363152636977938], 
             68 -> RGBColor[
              0.27002626100566185`, 0.40114509934370585`, 0.9386889681449931],
              10 -> RGBColor[
              0.23750097993416716`, 0.3669589667156367, 0.9368367015048129], 
             250 -> RGBColor[
              0.25834749102875554`, 0.38886997162119286`, 0.9380238794720002],
              282 -> RGBColor[
              0.2671426063657563, 0.39811419548290095`, 0.9385247482792353], 
             374 -> RGBColor[
              0.19021908584372046`, 0.31726269818134456`, 0.934144067583656], 
             232 -> RGBColor[
              0.295092829761857, 0.42749165241872045`, 0.9401164721529931], 
             253 -> RGBColor[
              0.19109293756035423`, 0.31818117174092553`, 0.9341938321461705],
              55 -> RGBColor[
              0.9716313250190438, 0.9159679393868991, 0.3442934839840799], 
             325 -> RGBColor[
              0.289139123347183, 0.42123392949010874`, 0.9397774173803968], 
             91 -> RGBColor[
              0.4932978290383352, 0.5995204262840937, 0.953253358592837], 105 -> 
             RGBColor[
              0.20947576509879728`, 0.3375026890224135, 0.9352407069795285], 
             36 -> RGBColor[
              0.19287789451893317`, 0.32005727467719974`, 0.9342954828043544],
              123 -> RGBColor[
              0.21169783120855037`, 0.3398382213908926, 0.9353672503572267], 
             94 -> RGBColor[
              0.18118663655961964`, 0.30776902129339295`, 0.9336296829592377],
              312 -> RGBColor[
              0.3029090080003519, 0.4357069513217019, 0.9405615919406759], 96 -> 
             RGBColor[
              0.7481991240396009, 0.803218109314472, 0.9755371544320737], 2 -> 
             RGBColor[
              0.18498575182454155`, 0.3117621323146461, 0.9338460369532876], 
             262 -> RGBColor[
              0.2141514811516508, 0.34241716305148284`, 0.9355069820916365], 
             272 -> RGBColor[
              0.7409332819620127, 0.7975419782610151, 0.9748129631969344], 97 -> 
             RGBColor[
              0.19288958051724012`, 0.32006955740235543`, 0.93429614830467], 
             372 -> RGBColor[
              0.19406834726399882`, 0.3213085159913272, 0.9343632773270688], 
             356 -> RGBColor[
              0.19499177110397153`, 0.3222790929955916, 0.9344158649486721], 
             346 -> RGBColor[
              0.3510664211934816, 0.47849782175157674`, 0.9435906198159696], 
             341 -> RGBColor[
              0.3362350503435996, 0.46565163376778274`, 0.9426455779802814], 
             209 -> RGBColor[
              0.33484250288537293`, 0.4644454791509371, 0.9425568460876246], 
             378 -> RGBColor[
              0.19081859398490578`, 0.3178928192487419, 0.9341782086854036], 
             66 -> RGBColor[
              0.2142707962291993, 0.34254257076299915`, 0.935513776908792], 
             139 -> RGBColor[
              0.18805967833656198`, 0.31499302397697726`, 0.9340210925206803],
              56 -> RGBColor[
              0.38165040818030865`, 0.5049881340836845, 0.9455394044224124], 
             335 -> RGBColor[
              0.1795029989097729, 0.3059994113746115, 0.9335338022857975], 
             314 -> RGBColor[
              0.23267428983588884`, 0.3618858093925185, 0.936561828644164], 
             144 -> RGBColor[
              0.1905501321581982, 0.3176106488474093, 0.9341629201815262], 
             298 -> RGBColor[
              0.19699767297971368`, 0.3243874230485212, 0.9345300980930298], 
             204 -> RGBColor[
              0.19363457114614188`, 0.3208525897884652, 0.9343385744188711], 
             207 -> RGBColor[
              0.18775722726537172`, 0.31467512872465075`, 0.9340038683796124],
              334 -> RGBColor[
              0.1849809522741401, 0.31175708768286514`, 0.9338457636259925], 
             149 -> RGBColor[
              0.21660346779159745`, 0.34499435647499893`, 0.9356466191033923],
              219 -> RGBColor[
              0.3371253879726633, 0.4664227994724073, 0.9427023095067106], 
             400 -> RGBColor[
              0.8501784807301029, 0.38669936800784144`, 0.19568427585662201`],
              9 -> RGBColor[
              0.19103464530579026`, 0.3181199028854364, 0.9341905124885087], 
             11 -> RGBColor[
              0.31196467996522614`, 0.44462985881031997`, 0.9410990914412173],
              44 -> RGBColor[
              0.2366745638317519, 0.36609035099419096`, 0.9367896383303533], 
             153 -> RGBColor[
              0.1824446187841665, 0.30909124037207153`, 0.9337013231859077], 
             32 -> 
             RGBColor[
              0.9570322462930174, 0.8667218188173162, 0.28757881993815293`], 
             162 -> RGBColor[
              0.27232886945688745`, 0.40356528681975196`, 0.9388200982898864],
              90 -> RGBColor[
              0.6083786689975903, 0.6929482364957771, 0.9623129438694364], 
             331 -> RGBColor[
              0.19914754728651962`, 0.3266470772548782, 0.9346525302543484], 
             8 -> RGBColor[
              0.2378122641398246, 0.36728614615234123`, 0.9368544286798214], 
             364 -> RGBColor[
              0.8176771202476999, 0.13687966915311423`, 0.16456093635363633`],
              342 -> RGBColor[
              0.18371444184961855`, 0.31042590492529404`, 0.9337736377309502],
              163 -> RGBColor[
              0.26679472020223177`, 0.3977485450677799, 0.938504936676874], 
             49 -> RGBColor[
              0.18767785554878408`, 0.3145917040180597, 0.9339993482777726], 
             338 -> RGBColor[
              0.23420030298526878`, 0.3634897459673388, 0.9366487328354871], 
             76 -> RGBColor[
              0.1938965482594379, 0.32112794434484765`, 0.9343534936279129], 
             369 -> RGBColor[
              0.19059767181486464`, 0.3176606160407541, 0.9341656274946448], 
             82 -> RGBColor[
              0.1807265568208277, 0.30728544831718235`, 0.9336034820987404], 
             67 -> RGBColor[
              0.42522253205912725`, 0.5427281177888938, 0.9483157816266544], 
             211 -> RGBColor[
              0.22188954865981286`, 0.3505503626243781, 
               0.9359476535887813]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9l2k4lWvYhs1zWMs8LNZoLbMSqfBetRslSppMScqwSaE2pQyZolBokCJT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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 14}], {
             RGBColor[
             0.18904790384743964`, 0.31603171164602595`, 0.9340773705015762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.18749255911212426`, 0.3143969457146576, 0.9339887959198263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 49}], {
             RGBColor[
             0.19061232216343427`, 0.3176760144859865, 0.9341664618103227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 62}], {
             RGBColor[
             0.19732629313580521`, 0.3247328236682947, 0.9345488125247692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 87}], {
             RGBColor[
             0.19586287681444192`, 0.32319468032858806`, 0.934465473130198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 119}], {
             RGBColor[
             0.18798137752672578`, 0.3149107248612813, 0.9340166334053959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 127}], {
             RGBColor[
             0.19417547404882396`, 0.3214211130344089, 0.9343693780389848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 129}], {
             RGBColor[
             0.19131755276026974`, 0.31841725655746295`, 0.9342066236495172]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 216}], {
             RGBColor[
             0.19662871859939152`, 0.3239996286017438, 0.9345090866868895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 231}], {
             RGBColor[
             0.1878698717924256, 0.3147935252646599, 0.9340102833187854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 235}], {
             RGBColor[
             0.19253038583618232`, 0.3196920210183055, 0.9342756926989647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 298}], {
             RGBColor[
             0.19527223087889906`, 0.32257387400121723`, 0.9344318367179512]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 313}], {
             RGBColor[
             0.20595700131663575`, 0.3338042451848521, 0.935040318587679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 317}], {
             RGBColor[
             0.19445041549410247`, 0.3217100939256911, 0.9343850355475539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 336}], {
             RGBColor[
             0.18695004027347276`, 0.31382672401755374`, 0.9339579002745498]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 361}], {
             RGBColor[
             0.205591391562574, 0.33341996615233593`, 0.9350194976530564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 393}], {
             RGBColor[
             0.1884550205876297, 0.3154085537489959, 0.9340436066770222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 396}], {
             RGBColor[
             0.1965523248147455, 0.3239193338904351, 0.9345047361738683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 97}], {
             RGBColor[
             0.18893766617089083`, 0.31591584485850077`, 0.9340710926289788]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 109}], {
             RGBColor[
             0.1831541470606865, 0.30983699957738503`, 0.9337417297716024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 181}], {
             RGBColor[
             0.1899547149925528, 0.3169848276546873, 0.9341290120547836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 191}], {
             RGBColor[
             0.19610476461646903`, 0.323448919745091, 0.9344792482826825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 193}], {
             RGBColor[
             0.18596534003799042`, 0.3127917416364609, 0.9339018230528726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 211}], {
             RGBColor[
             0.2034376502421772, 0.3311562474695121, 0.9348968452710344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 305}], {
             RGBColor[
             0.18360947068078184`, 0.31031557357129014`, 0.9337676597781759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 334}], {
             RGBColor[
             0.18498335204934083`, 0.3117596099987556, 0.93384590028964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 340}], {
             RGBColor[
             0.19396024281710603`, 0.32119489136342505`, 0.9343571209387445]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 360}], {
             RGBColor[
             0.18511749831467772`, 0.3119006062289892, 0.9338535397209994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 365}], {
             RGBColor[
             0.18295812271216946`, 0.3096309655584321, 0.9337305664749465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 370}], {
             RGBColor[
             0.18603673488354355`, 0.3128667821458319, 0.9339058888837076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 11}], {
             RGBColor[
             0.4469167817161049, 0.5580281285800609, 0.9506625439425702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 21}], {
             RGBColor[
             0.7725354937206939, 0.7794802979389553, 0.6358867741972027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 34}], {
             RGBColor[
             0.4225585018257533, 0.5327236209657705, 0.9492644797482566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 74}], {
             RGBColor[
             0.7224644673916434, 0.782535536200579, 0.9735133143364585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 86}], {
             RGBColor[
             0.49644576954540676`, 0.6009276484384913, 0.9538184872502891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 91}], {
             RGBColor[
             0.5375833562526594, 0.6354734123169479, 0.9567396775183801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 95}], {
             RGBColor[
             0.5706393994295823, 0.6623097973257487, 0.9593419703255434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 160}], {
             RGBColor[
             0.5207461823507223, 0.6218042360373149, 0.9554141935122193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[
             0.42709887646193556`, 0.5374958425847769, 0.9495230473669047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 233}], {
             RGBColor[
             0.7706376185941841, 0.8203361519689907, 0.9569123152308744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 263}], {
             RGBColor[
             0.48691076315351817`, 0.5926689051451934, 0.9532109250744729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 264}], {
             RGBColor[
             0.652580274743898, 0.7275933060781521, 0.9666403041170564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 285}], {
             RGBColor[
             0.7880339609127915, 0.8307135264515318, 0.7851026525209982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 312}], {
             RGBColor[
             0.44238894573366777`, 0.553566674835752, 0.9503937941922995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 348}], {
             RGBColor[
             0.45750426505624076`, 0.5671984745069012, 0.9513371690188597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 13}], {
             RGBColor[
             0.22349076802527734`, 0.3522333457006528, 0.9360388406628528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 66}], {
             RGBColor[
             0.22354481915991609`, 0.35229015687019793`, 0.9360419187950089]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 123}], {
             RGBColor[
             0.2222583366495916, 0.3509379821841447, 0.9359686555192263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 131}], {
             RGBColor[
             0.22303764420255517`, 0.35175708383326204`, 0.9360130359314853]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 140}], {
             RGBColor[
             0.22925899781803233`, 0.3582961209397305, 0.9363673328162189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 183}], {
             RGBColor[
             0.2914028738694214, 0.4198002713108441, 0.9400459473606144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 186}], {
             RGBColor[
             0.2198352252877424, 0.3483911385087073, 0.9358306629118409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 188}], {
             RGBColor[
             0.2173017232473819, 0.34572826723098127`, 0.9356863837186229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 203}], {
             RGBColor[
             0.22928794206914588`, 0.35832654318282237`, 0.9363689811485005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 232}], {
             RGBColor[
             0.26395583592624494`, 0.3947646976980586, 0.9383432664171094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 238}], {
             RGBColor[
             0.26140051176335477`, 0.3920788899859515, 0.9381977444862962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 275}], {
             RGBColor[
             0.235784586016354, 0.3651549278823552, 0.9367389554103707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 280}], {
             RGBColor[
             0.24217745234544014`, 0.3718742357253608, 0.937103019690414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 297}], {
             RGBColor[
             0.2198696831096341, 0.34842735586426754`, 0.9358326252338219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 309}], {
             RGBColor[
             0.2652076930566547, 0.39608047891444564`, 0.9384145578287296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 322}], {
             RGBColor[
             0.21636197354501668`, 0.3447405307102229, 0.9356328663633082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 325}], {
             RGBColor[
             0.26097898271890796`, 0.39163583623375275`, 0.9381737390308114]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 339}], {
             RGBColor[
             0.24218330961780632`, 0.3718803920899902, 0.9371033532534101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 8}], {
             RGBColor[
             0.2601258969540067, 0.39073918900607996`, 0.9381251570585274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 43}], {
             RGBColor[
             0.2713996679468782, 0.4025886371179538, 0.9387671816385219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 56}], {
             RGBColor[
             0.3320449689742487, 0.4595901829717516, 0.9424676449298229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.31447583347960173`, 0.4443726808567142, 0.9413481551518805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 90}], {
             RGBColor[
             0.44540909938288953`, 0.5535702341777979, 0.950854414653335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 100}], {
             RGBColor[
             0.24629351933764826`, 0.37620048310789195`, 0.9373374236164447]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 121}], {
             RGBColor[
             0.2966728547509243, 0.4289526354856623, 0.9402137650898452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 122}], {
             RGBColor[
             0.440201175363544, 0.5493422068445898, 0.9504444277972779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 175}], {
             RGBColor[
             0.282045444074704, 0.41377802280949016`, 0.9393734428399871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 178}], {
             RGBColor[
             0.36206488822589933`, 0.4855919281825182, 0.9443804876389659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 213}], {
             RGBColor[
             0.25252900688278906`, 0.3827543758705798, 0.9376925254075633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 227}], {
             RGBColor[
             0.24495455926499354`, 0.3747931511765599, 0.937261171821121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 274}], {
             RGBColor[
             0.38775900825169696`, 0.5067672930904867, 0.9463159883002454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 296}], {
             RGBColor[
             0.26370004466317304`, 0.39449584486246725`, 0.9383286994830867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 308}], {
             RGBColor[
             0.24197001296398313`, 0.37165620378303305`, 0.9370912063245189]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 319}], {
             RGBColor[
             0.3679006517731242, 0.4906453846924169, 0.9447526657346955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 352}], {
             RGBColor[
             0.26102097459574697`, 0.3916799723587493, 0.9381761304060758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 373}], {
             RGBColor[
             0.27714534160664284`, 0.4086277044311172, 0.939094389253483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 56}], {
             RGBColor[
             0.34361946259808085`, 0.47175570963568103`, 0.9431267952187714]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 79}], {
             RGBColor[
             0.26831622286540857`, 0.39934774083561936`, 0.9385915840026804]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 137}], {
             RGBColor[
             0.32002599977803325`, 0.451320237982877, 0.941623440630758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 169}], {
             RGBColor[
             0.6006886092479335, 0.6791324482420171, 0.965318253056975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 175}], {
             RGBColor[
             0.2936199376985361, 0.4259435494734196, 0.9400325931289355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 178}], {
             RGBColor[
             0.37363938184973156`, 0.4977574548464476, 0.9450396379279142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 252}], {
             RGBColor[
             0.3375773650971563, 0.4665223484650306, 0.9427417981088295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 277}], {
             RGBColor[
             0.2567019144406389, 0.38714036629150045`, 0.9379301663197194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 278}], {
             RGBColor[
             0.28187720037590647`, 0.4136011880147874, 0.9393638616102349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 300}], {
             RGBColor[
             0.6101439916355338, 0.6866719134983721, 0.9662201158700239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 314}], {
             RGBColor[
             0.26913140342587094`, 0.400204547290098, 0.9386380073296472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 319}], {
             RGBColor[
             0.37947514539695637`, 0.5028109113563464, 0.945411816023644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 352}], {
             RGBColor[
             0.27259546821957914`, 0.40384549902267874`, 0.9388352806950242]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 379}], {
             RGBColor[
             0.25634517615934155`, 0.38676541173934353`, 0.9379098506023464]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 65}], {
             RGBColor[
             0.36829577629683624`, 0.4914979419428903, 0.9447588725119885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 67}], {
             RGBColor[
             0.43693392935130804`, 0.5528719414914377, 0.9490620215061302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 68}], {
             RGBColor[
             0.3593357938245753, 0.4820804322688437, 0.9442486147652995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 96}], {
             RGBColor[
             0.5984222253415448, 0.6831169372542267, 0.9626727079088397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 173}], {
             RGBColor[
             0.36556257674898185`, 0.48862517592323496`, 0.9446032208411446]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[
             0.7215884971461117, 0.7768639400824314, 0.7979961077324451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 201}], {
             RGBColor[
             0.698844545732584, 0.7622666344739716, 0.960474027707296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 223}], {
             RGBColor[
             0.6892737381041355, 0.6614040887409706, 0.6061320446993241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 250}], {
             RGBColor[
             0.35349640883612216`, 0.4759428684075872, 0.943916070428803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 387}], {
             RGBColor[
             0.4913856837463006, 0.597841186558023, 0.9531378831854276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 43}], {
             RGBColor[
             0.24908603513269617`, 0.379135594264215, 0.9374964532598158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 56}], {
             RGBColor[
             0.30973133616006665`, 0.43613714011801286`, 0.9411969165511169]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 59}], {
             RGBColor[
             0.2921622006654197, 0.4209196380029755, 0.9400774267731745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 100}], {
             RGBColor[
             0.22397988652346618`, 0.35274744025415317`, 0.9360666952377386]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 121}], {
             RGBColor[
             0.2743592219367422, 0.4054995926319236, 0.9389430367111391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 175}], {
             RGBColor[
             0.2597318112605219, 0.39032497995575144`, 0.938102714461281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 213}], {
             RGBColor[
             0.230215374068607, 0.3593013330168411, 0.9364217970288573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 227}], {
             RGBColor[
             0.22264092645081146`, 0.35134010832282114`, 0.9359904434424149]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 237}], {
             RGBColor[
             0.2175725261235523, 0.3460128982237305, 0.9357018055418038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 296}], {
             RGBColor[
             0.241386411848991, 0.3710428020087285, 0.9370579711043807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 308}], {
             RGBColor[
             0.21965638014980107`, 0.34820316092929426`, 0.9358204779458129]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 352}], {
             RGBColor[
             0.23870734178156489`, 0.36822692950501057`, 0.9369054020273697]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 373}], {
             RGBColor[
             0.2548317087924608, 0.38517466157737845`, 0.937823660874777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 39}], {
             RGBColor[
             0.1871051393828018, 0.3139897430153101, 0.9339667329393776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.2089266760744028, 0.33692556164351994`, 0.9352094371718936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 150}], {
             RGBColor[
             0.19229026561489077`, 0.3194396394412268, 0.9342620182075883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 192}], {
             RGBColor[
             0.1863278971063823, 0.3131728121027866, 0.9339224701415624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 283}], {
             RGBColor[
             0.2000074908485974, 0.3275509324621929, 0.9347015027680361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 294}], {
             RGBColor[
             0.1904972038981096, 0.3175550178902107, 0.9341599059954147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 320}], {
             RGBColor[
             0.1934136507337484, 0.32062038842787655`, 0.9343259933282078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 347}], {
             RGBColor[
             0.19444294915612814`, 0.3217022463310869, 0.9343846103506517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 381}], {
             RGBColor[
             0.19359903145009902`, 0.3208152353145773, 0.9343365504857577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 384}], {
             RGBColor[
             0.19029625552141455`, 0.3173438084054412, 0.9341484622826384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.26166329356975937`, 0.3923550903258115, 0.9382127095214201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 37}], {
             RGBColor[
             0.29314980125126083`, 0.4217462676405007, 0.9401414095988625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 62}], {
             RGBColor[
             0.21930338871384658`, 0.34783214454915645`, 0.9358003756057394]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 87}], {
             RGBColor[
             0.2178399723924833, 0.34629400120944975`, 0.9357170362111682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 155}], {
             RGBColor[
             0.22229114501906733`, 0.3509724658606344, 0.9359705239073323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 170}], {
             RGBColor[
             0.2345826966210814, 0.3638916659237347, 0.936670509587346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 216}], {
             RGBColor[
             0.21860581417743288`, 0.3470989494826055, 0.9357606497678597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 256}], {
             RGBColor[
             0.29440488188335295`, 0.4228333554018322, 0.9402213822269152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 261}], {
             RGBColor[
             0.24873551087533646`, 0.3787671710452084, 0.9374764914219134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 298}], {
             RGBColor[
             0.21724932645694042`, 0.3456731948820789, 0.9356833997989213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 311}], {
             RGBColor[
             0.2701224968687157, 0.40124624933748154`, 0.9386944486350258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 313}], {
             RGBColor[
             0.22793409689467709`, 0.35690356606571383`, 0.9362918816686491]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 361}], {
             RGBColor[
             0.22756848714061534`, 0.35651928703319763`, 0.9362710607340264]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 396}], {
             RGBColor[
             0.21852942039278686`, 0.3470186547712968, 0.9357562992548385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 34}], {
             RGBColor[
             0.28760640007487454`, 0.41932535119602954`, 0.9397010272469036]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 35}], {
             RGBColor[
             0.27410810708868466`, 0.4051377894263376, 0.9389323194302751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 85}], {
             RGBColor[
             0.2763549775912347, 0.40749939278433556`, 0.9390602753814483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 86}], {
             RGBColor[
             0.361493667794528, 0.48752937866875046`, 0.9442550347489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 91}], {
             RGBColor[
             0.40263125450178067`, 0.5220751425472069, 0.9471762250170271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 93}], {
             RGBColor[
             0.2731424573639435, 0.4041228303399058, 0.9388773271070019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 95}], {
             RGBColor[
             0.43568729767870357`, 0.5489115275560077, 0.9497785178241904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 125}], {
             RGBColor[
             0.2867382877276377, 0.41841291007758175`, 0.9396515895329856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 162}], {
             RGBColor[
             0.29214677471105677`, 0.42409757281503596`, 0.9399595948655519]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 211}], {
             RGBColor[
             0.2669271143125195, 0.39759011071734907`, 0.9385233725149993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 214}], {
             RGBColor[
             0.2758548681185897, 0.40697374601981373`, 0.9390317948868268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 248}], {
             RGBColor[
             0.2649817698706437, 0.3955454303669761, 0.9384125880269136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 263}], {
             RGBColor[
             0.35195866140263943`, 0.47927063537545245`, 0.9436474725731201]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 312}], {
             RGBColor[
             0.30743684398278903`, 0.44016840506601096`, 0.9408303416909466]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.313125811057198, 0.4456106195888476, 0.9411739913250522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 17}], {
             RGBColor[
             0.2700762317403779, 0.40119762175422, 0.93869181390441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 22}], {
             RGBColor[
             0.3123757406994519, 0.44496094634460026`, 0.9411261975051177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 47}], {
             RGBColor[
             0.4262898849714413, 0.5411626092696967, 0.9490658048705467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 106}], {
             RGBColor[
             0.2676474114572338, 0.3986447776405352, 0.9385534961824027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 107}], {
             RGBColor[
             0.3285473986430889, 0.45896802364421685`, 0.9421566412492507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 118}], {
             RGBColor[
             0.27367870261090094`, 0.4049840470489852, 0.9388969692911083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 158}], {
             RGBColor[
             0.32361612706914167`, 0.45469680405977975`, 0.941842424985111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 209}], {
             RGBColor[
             0.3216593094784126, 0.45300190701520204`, 0.9417177382985756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 241}], {
             RGBColor[
             0.28584467655013013`, 0.4177712570264148, 0.9395898035090018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 270}], {
             RGBColor[
             0.3337876806083378, 0.46350689249828564`, 0.9424905473822769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 310}], {
             RGBColor[
             0.2940376027932159, 0.42638254196942454`, 0.9400563785381975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 323}], {
             RGBColor[
             0.35358359064672407`, 0.4806531148021672, 0.943751925265087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 324}], {
             RGBColor[
             0.4708028735942141, 0.577300258720949, 0.9525700303913813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 346}], {
             RGBColor[
             0.329771268632467, 0.46002807831552184`, 0.9422346251627481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 390}], {
             RGBColor[
             0.28559351861557547`, 0.41750727411286515`, 0.9395755004361839]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 66}], {
             RGBColor[
             0.21421674509456057`, 0.34248575959345395`, 0.9355106987766358]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 123}], {
             RGBColor[
             0.2129302625842361, 0.3411335849074007, 0.9354374355008532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 131}], {
             RGBColor[
             0.21370957013719966`, 0.34195268655651806`, 0.9354818159131122]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[
             0.2199309237526768, 0.34849172366298653`, 0.9358361127978458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 188}], {
             RGBColor[
             0.20797364918202638`, 0.3359238699542373, 0.9351551637002498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 203}], {
             RGBColor[
             0.21995986800379036`, 0.3485221459060784, 0.9358377611301275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 232}], {
             RGBColor[
             0.2546277618608894, 0.3849603004213146, 0.9378120463987364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 275}], {
             RGBColor[
             0.22645651195099847`, 0.3553505306056112, 0.9362077353919975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 280}], {
             RGBColor[
             0.23284937828008462`, 0.36206983844861684`, 0.9365717996720409]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 297}], {
             RGBColor[
             0.2105416090442786, 0.33862295858752356`, 0.9353014052154489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 309}], {
             RGBColor[
             0.25587961899129924`, 0.38627608163770166`, 0.9378833378103566]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 322}], {
             RGBColor[
             0.20703389947966117`, 0.33493613343347894`, 0.9351016463449351]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 325}], {
             RGBColor[
             0.25165090865355244`, 0.3818314389570088, 0.9376425190124382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 339}], {
             RGBColor[
             0.2328552355524508, 0.3620759948132462, 0.936572133235037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 29}], {
             RGBColor[
             0.18299367418147944`, 0.3096683324067703, 0.9337325910785299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 62}], {
             RGBColor[
             0.1928274082051604, 0.3200042103604074, 0.9342926076834728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 119}], {
             RGBColor[
             0.18348249259608096`, 0.310182111553394, 0.9337604285640995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 126}], {
             RGBColor[
             0.18556762080960376`, 0.31237371351057097`, 0.9338791735311889]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 127}], {
             RGBColor[
             0.18967658911817914`, 0.3166924997265216, 0.9341131731976884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 129}], {
             RGBColor[
             0.18681866782962492`, 0.3136886432495756, 0.9339504188082208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 196}], {
             RGBColor[
             0.18714224683050756`, 0.3140287452955969, 0.9339688461536289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 235}], {
             RGBColor[
             0.1880315009055375, 0.3149634077104182, 0.9340194878576683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 317}], {
             RGBColor[
             0.18995153056345765`, 0.3169814806178038, 0.9341288307062575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 326}], {
             RGBColor[
             0.18828033718868842`, 0.3152249504211414, 0.9340336587158735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 327}], {
             RGBColor[
             0.19007805312865012`, 0.317114463855815, 0.9341360359791719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 336}], {
             RGBColor[
             0.18245115534282794`, 0.3090981107096664, 0.9337016954332534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 396}], {
             RGBColor[
             0.19205343988410067`, 0.31919072058254777`, 0.9342485313325719]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 33}], {
             RGBColor[
             0.28118366953987284`, 0.41287224313372134`, 0.9393243660551096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 37}], {
             RGBColor[
             0.31731211488685307`, 0.44714239125067556`, 0.9415174176154697]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.24346570234943876`, 0.37322826815933124`, 0.9371763836223466]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 92}], {
             RGBColor[
             0.3916080301069964, 0.5102971083648917, 0.9465821312407912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 256}], {
             RGBColor[
             0.31856719551894513`, 0.448229479012007, 0.9415973902435224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 311}], {
             RGBColor[
             0.2942848105043079, 0.4266423729476564, 0.940070456651633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 313}], {
             RGBColor[
             0.25209641053026927`, 0.3822996896758886, 0.9376678896852563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 361}], {
             RGBColor[
             0.2517308007762076, 0.3819154106433724, 0.9376470687506336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 386}], {
             RGBColor[
             0.5232931103169385, 0.6153912271159707, 0.9581889419192983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 69}], {
             RGBColor[
             0.2797958916834022, 0.41057876108804503`, 0.9392759017239116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 106}], {
             RGBColor[
             0.2722971064429795, 0.4026970623499158, 0.9388488569979281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 107}], {
             RGBColor[
             0.33319709362883454`, 0.4630203083535974, 0.9424520020647762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 190}], {
             RGBColor[
             0.6369974104682594, 0.7082659607734624, 0.9502314057905163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 212}], {
             RGBColor[
             0.36755596390986156`, 0.4927802348639901, 0.9446413188967272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 241}], {
             RGBColor[
             0.29049437153587576`, 0.42182354173579545`, 0.9398851643245274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 268}], {
             RGBColor[
             0.49856920010276634`, 0.5995528138290274, 0.9550727772448264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 270}], {
             RGBColor[
             0.3384373755940835, 0.46755917720766627`, 0.9427859081978025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 274}], {
             RGBColor[
             0.4054269963890745, 0.5245026293096915, 0.9473527216519175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 295}], {
             RGBColor[
             0.3734051820083968, 0.4978465335906915, 0.9450140259017055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 310}], {
             RGBColor[
             0.2986872977789616, 0.43043482667880517`, 0.9403517393537228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 324}], {
             RGBColor[
             0.47545256857995977`, 0.5813525434303296, 0.9528653912069069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 351}], {
             RGBColor[
             0.6137824648944775, 0.6902841557450048, 0.9663635368138602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 373}], {
             RGBColor[
             0.29481332974402036`, 0.42636304065032193`, 0.9401311226051551]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 380}], {
             RGBColor[
             0.26894987250182517`, 0.3991789072508731, 0.9386582369767682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 390}], {
             RGBColor[
             0.2902432136013212, 0.4215595588222458, 0.9398708612517093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 22}], {
             RGBColor[
             0.2739758563683775, 0.40460023321935323`, 0.9389393809000012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 48}], {
             RGBColor[
             0.23593219427525336`, 0.3653100735213626, 0.936747361482348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 61}], {
             RGBColor[
             0.22052046256389546`, 0.34911136633249684`, 0.9358696861610002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 118}], {
             RGBColor[
             0.23527881827982655`, 0.36462333392373825`, 0.9367101526859918]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 158}], {
             RGBColor[
             0.2852162427380673, 0.4143360909345327, 0.9396556083799944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 164}], {
             RGBColor[
             0.21631448031938844`, 0.34469061231884324`, 0.9356301616943686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 173}], {
             RGBColor[
             0.25707808713188923`, 0.38753574764073073`, 0.9379515887979883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 209}], {
             RGBColor[
             0.2832594251473382, 0.412641193889955, 0.9395309216934591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 241}], {
             RGBColor[
             0.2474447922190557, 0.37741054390116785`, 0.9374029869038852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 287}], {
             RGBColor[
             0.2108043778715786, 0.3388991452855218, 0.9353163695114319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 323}], {
             RGBColor[
             0.3151837063156497, 0.44029240167692024`, 0.9415651086599703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 346}], {
             RGBColor[
             0.29137138430139253`, 0.41966736519027487`, 0.9400478085576316]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 354}], {
             RGBColor[
             0.2237645258481464, 0.35252108252973663`, 0.9360544307658767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 371}], {
             RGBColor[
             0.20911196002482746`, 0.33712030682309724`, 0.9352199888187673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 388}], {
             RGBColor[
             0.22559527698605156`, 0.35444531805200136`, 0.9361586893348268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 389}], {
             RGBColor[
             0.21716250001380405`, 0.34558193478522814`, 0.9356784551614329]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 45}], {
             RGBColor[
             0.4449748432614876, 0.5535011435034702, 0.9507944263097807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 74}], {
             RGBColor[
             0.7341001698400949, 0.7919819236306536, 0.974429319456183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 86}], {
             RGBColor[
             0.5080814719938581, 0.6103740358685661, 0.9547344923700136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 91}], {
             RGBColor[
             0.5492190587011108, 0.6449197997470224, 0.9576556826381046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 112}], {
             RGBColor[
             0.7711240798821252, 0.7393399357057666, 0.6151558638126768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 141}], {
             RGBColor[
             0.7787784526106882, 0.5518341379822057, 0.46039508708597976`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 148}], {
             RGBColor[
             0.46955925293009415`, 0.5770080258985608, 0.9522798906351313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 179}], {
             RGBColor[
             0.5295441815391476, 0.6289468481238254, 0.9561068042364651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 232}], {
             RGBColor[
             0.4501165590628717, 0.5589054128143358, 0.9510872394181826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 257}], {
             RGBColor[
             0.46412234198098856`, 0.5722988469015355, 0.9519334554771259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 279}], {
             RGBColor[
             0.638687245246097, 0.7170964540862654, 0.9650118438159424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 285}], {
             RGBColor[
             0.7996696633612428, 0.8401599138816065, 0.7860186576407228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 288}], {
             RGBColor[
             0.45525573629442806`, 0.5643070139273578, 0.9513799079587884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 399}], {
             RGBColor[
             0.7658581753592988, 0.7184623790314186, 0.610918793426945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 185}], {
             RGBColor[
             0.330002266441723, 0.4557835793222022, 0.9424120819002554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 198}], {
             RGBColor[
             0.30685620721234774`, 0.43573562617248035`, 0.9409372354734161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 205}], {
             RGBColor[
             0.30521095643223367`, 0.4343105926394541, 0.9408324015485454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 219}], {
             RGBColor[
             0.2987647907941907, 0.4287272479574868, 0.9404216575742097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 262}], {
             RGBColor[
             0.23727783738368446`, 0.36672442974702457`, 0.9368239938666727]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 284}], {
             RGBColor[
             0.2685014480461575, 0.3995424242445413, 0.938602132302708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 293}], {
             RGBColor[
             0.3046492475878372, 0.4338240686707453, 0.9407966099576801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 331}], {
             RGBColor[
             0.22977587045111889`, 0.35883938684872224`, 0.9363967679480286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 338}], {
             RGBColor[
             0.24730224830049347`, 0.3772607212049526, 0.937394869238598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.1986384662361157, 0.32611200079330077`, 0.9346235388416457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 36}], {
             RGBColor[
             0.19158305641128354`, 0.3186963177285822, 0.934221743689665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 80}], {
             RGBColor[
             0.18504810846190303`, 0.31182767309415216`, 0.933849588071537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 151}], {
             RGBColor[
             0.19115376674236922`, 0.3182451070680162, 0.9341972962780976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 168}], {
             RGBColor[
             0.18724662483160132`, 0.31413845319269396`, 0.9339747903263778]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 265}], {
             RGBColor[
             0.19013547399899927`, 0.31717481683124543`, 0.9341393060127917]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 291}], {
             RGBColor[
             0.18873168488737596`, 0.31569934546955897`, 0.9340593622996046]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 304}], {
             RGBColor[
             0.185589373288035, 0.312396576744589, 0.9338804123026556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 378}], {
             RGBColor[
             0.19055340614426983`, 0.31761409001435326`, 0.9341631066301896]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 383}], {
             RGBColor[
             0.1993210537450841, 0.3268294435437743, 0.9346624111904838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 24}], {
             RGBColor[
             0.868258601963509, 0.40303301389979596`, 0.21554172931270557`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 25}], {
             RGBColor[
             0.8659467013248013, 0.3852627325093696, 0.21332785065016086`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 27}], {
             RGBColor[
             0.8684261923998754, 0.40432118743230555`, 0.21570221410383633`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 32}], {
             RGBColor[
             0.9601171751337108, 0.8771280081727125, 0.29956318594431774`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 78}], {
             RGBColor[
             0.8676924203602071, 0.39868109399445717`, 0.21499955316997305`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 95}], {
             RGBColor[
             0.7613060096832925, 0.7703636969149021, 0.6350027480788232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 104}], {
             RGBColor[
             0.867073450053741, 0.3939234169844408, 0.2144068265054741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 160}], {
             RGBColor[
             0.7114127926044326, 0.7298581356264684, 0.631074971265499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 172}], {
             RGBColor[
             0.8702695187872548, 0.4184898017964773, 0.21746738553413028`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 208}], {
             RGBColor[
             0.9781086897296334, 0.9394569243444684, 0.5384830216306559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 217}], {
             RGBColor[
             0.9781358461419554, 0.9375595363156388, 0.3992965964312667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 230}], {
             RGBColor[
             0.8662262457545036, 0.38741143349321117`, 0.21359554271174397`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 233}], {
             RGBColor[
             0.9613042288478943, 0.9283900515581442, 0.6325730929841542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 240}], {
             RGBColor[
             0.8755266503036192, 0.45889841832097356`, 0.22250162061128162`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 242}], {
             RGBColor[
             0.8892496521392507, 0.5643794238873858, 0.23564278266699612`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 244}], {
             RGBColor[
             0.9589837634229517, 0.9266594522436353, 0.6365010356742713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 264}], {
             RGBColor[
             0.8432468849976082, 0.8356472056673055, 0.6423010818703361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 285}], {
             RGBColor[
             0.9787005711665018, 0.9387674260406853, 0.4607634302742779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 357}], {
             RGBColor[
             0.892467694136608, 0.589114704834069, 0.2387243833179241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 47}], {
             RGBColor[
             0.4301895095994409, 0.5445652207348299, 0.9493133718661378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.27823170323432733`, 0.40907339811174287`, 0.9391817450830557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 96}], {
             RGBColor[
             0.5322372446835262, 0.6257908335621027, 0.9584554594663912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 118}], {
             RGBColor[
             0.2775783272389005, 0.4083866585141185, 0.9391445362866995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 158}], {
             RGBColor[
             0.3275157516971413, 0.458099415524913, 0.9420899919807021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 173}], {
             RGBColor[
             0.2993775960909632, 0.43129907223111097`, 0.940385972398696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 209}], {
             RGBColor[
             0.32555893410641223`, 0.4564045184803353, 0.9419653052941668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 241}], {
             RGBColor[
             0.28974430117812966`, 0.42117386849154814`, 0.9398373705045929]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 310}], {
             RGBColor[
             0.2979372274212155, 0.4297851534345578, 0.9403039455337885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 323}], {
             RGBColor[
             0.35748321527472365`, 0.48405572626730053`, 0.943999492260678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 346}], {
             RGBColor[
             0.3336708932604665, 0.46343068978065516`, 0.9424821921583393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 354}], {
             RGBColor[
             0.2660640348072204, 0.3962844071201169, 0.9384888143665844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 388}], {
             RGBColor[
             0.26789478594512556`, 0.39820864264238165`, 0.9385930729355345]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 75}], {
             RGBColor[
             0.255511442446525, 0.3858891047454028, 0.9378623707008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 120}], {
             RGBColor[
             0.40567769043424073`, 0.5225843384798207, 0.9476110227757661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 132}], {
             RGBColor[
             0.32566481114992, 0.45504559524241234`, 0.9420251663053016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 160}], {
             RGBColor[
             0.3763398438622711, 0.4987665529777692, 0.9453014400255476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 202}], {
             RGBColor[
             0.2682077809117381, 0.39923376146669465`, 0.9385854083938443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 220}], {
             RGBColor[
             0.46443936234214256`, 0.5702897109178078, 0.9522369568394528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 229}], {
             RGBColor[
             0.24996961512608984`, 0.38006429285947896`, 0.9375467718333002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 260}], {
             RGBColor[
             0.2588190028871956, 0.3893655604799919, 0.938050731374799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 307}], {
             RGBColor[
             0.32070535665531497`, 0.4507499650286162, 0.9417091542503788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 321}], {
             RGBColor[
             0.42370887427578074`, 0.5372228658179581, 0.9490305036181749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 341}], {
             RGBColor[
             0.3146456284168403, 0.44550133299924655`, 0.9413230337254305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 348}], {
             RGBColor[
             0.3130979265677895, 0.44416079144735543`, 0.9412244155321879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 366}], {
             RGBColor[
             0.34372780451171075`, 0.47069085221995155`, 0.9431761242698371]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.8208706461762446, 0.16142650885189433`, 0.16761906038938248`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 32}], {
             RGBColor[
             0.8662019827363802, 0.39609555432953175`, 0.20755215197526236`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 73}], {
             RGBColor[
             0.8573963396759665, 0.36139490937802465`, 0.1993690984497273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.8348779177441421, 0.40506983940754504`, 0.4406260894055427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 78}], {
             RGBColor[
             0.8205037601564106, 0.15860646213297017`, 0.16726772992245081`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 104}], {
             RGBColor[
             0.8201942750031774, 0.15622762362796194`, 0.16697136659020134`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 112}], {
             RGBColor[
             0.859560524438829, 0.3699751807909537, 0.20111045230987185`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 141}], {
             RGBColor[
             0.8357237455500708, 0.2680521548465373, 0.1815470877583059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 172}], {
             RGBColor[
             0.8217923093699344, 0.16851081603398022`, 0.16850164610452945`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 208}], {
             RGBColor[
             0.8781963258003285, 0.43764816511070226`, 0.36683204243282114`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 240}], {
             RGBColor[
             0.8244208751281166, 0.18871512429622833`, 0.17101876364310512`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 242}], {
             RGBColor[
             0.8312823760459324, 0.24145562707943447`, 0.17758934467096238`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 243}], {
             RGBColor[
             0.8703666327474808, 0.4327860372681659, 0.42384867205099064`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 285}], {
             RGBColor[
             0.8785909134249075, 0.43718849957484696`, 0.31501898152856916`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 337}], {
             RGBColor[
             0.8785401737932351, 0.4370799726332635, 0.30949628574974347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 357}], {
             RGBColor[
             0.832891397044611, 0.253823267552776, 0.17913014499642635`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 399}], {
             RGBColor[
             0.8560499214236114, 0.3560568096747217, 0.198285738719384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 32}], {
             RGBColor[
             0.8638900820976725, 0.3783252729391054, 0.20533827331271765`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 78}], {
             RGBColor[
             0.8181918595177029, 0.1408361807425438, 0.1650538512599061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 83}], {
             RGBColor[
             0.8598908303478167, 0.4089271313115804, 0.435454149583152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 194}], {
             RGBColor[
             0.8763898892162449, 0.41965537165696043`, 0.32487331802642816`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 201}], {
             RGBColor[
             0.8612272549405598, 0.40992383458465387`, 0.4331919313429953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 217}], {
             RGBColor[
             0.8759025294365022, 0.41861295836772294`, 0.2718272136373503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 223}], {
             RGBColor[
             0.854846716521594, 0.34268213742931986`, 0.19696394267101408`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 230}], {
             RGBColor[
             0.8174587722148511, 0.13520135049192075`, 0.16435184603079156`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 242}], {
             RGBColor[
             0.8289704754072247, 0.2236853456890081, 0.17537546600841764`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 244}], {
             RGBColor[
             0.8631344742904997, 0.41134623565305395`, 0.42996350646602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 245}], {
             RGBColor[
             0.8178226851727047, 0.13799854495365815`, 0.16470032949021304`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 328}], {
             RGBColor[
             0.8347229187599272, 0.2562351535933635, 0.18042720125236386`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 357}], {
             RGBColor[
             0.8305794964059033, 0.23605298616234965`, 0.17691626633388163`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 364}], {
             RGBColor[
             0.8174383734159, 0.1350445563843714, 0.16433231211787877`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 385}], {
             RGBColor[
             0.8763544393929654, 0.4195795480694926, 0.3210148235334077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 105}], {
             RGBColor[
             0.19823757833601402`, 0.32569064219253296`, 0.9346007088687955]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 128}], {
             RGBColor[
             0.19080558249119994`, 0.3178791433438807, 0.9341774677000858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 159}], {
             RGBColor[
             0.18375580691440718`, 0.3104693822310835, 0.9337759934101959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 171}], {
             RGBColor[
             0.18798107467478986`, 0.3149104065446947, 0.9340166161584262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 215}], {
             RGBColor[
             0.18499791179933114`, 0.3117749132191369, 0.9338467294458628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 218}], {
             RGBColor[
             0.188929981383257, 0.31590776765945394`, 0.9340706549916917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 342}], {
             RGBColor[
             0.18535691671142462`, 0.3121522501439733, 0.9338671742445064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 349}], {
             RGBColor[
             0.19449252215171758`, 0.32175435069256086`, 0.9343874334594139]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 353}], {
             RGBColor[
             0.1885101327336185, 0.315466480108742, 0.9340467452322052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 32}], {
             RGBColor[
             0.8663695731727464, 0.3973837278620414, 0.20771263676639312`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 73}], {
             RGBColor[
             0.8575639301123329, 0.3626830829105343, 0.19952958324085807`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 74}], {
             RGBColor[
             0.8350455081805084, 0.40635801294005464`, 0.44078657419667344`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 78}], {
             RGBColor[
             0.8206713505927768, 0.15989463566547976`, 0.1674282147135816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 104}], {
             RGBColor[
             0.8203618654395438, 0.15751579716047157`, 0.16713185138133213`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 112}], {
             RGBColor[
             0.8597281148751953, 0.37126335432346336`, 0.20127093710100263`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 141}], {
             RGBColor[
             0.8358913359864371, 0.269340328379047, 0.18170757254943665`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 172}], {
             RGBColor[
             0.8219598998063007, 0.16979898956648984`, 0.1686621308956602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 208}], {
             RGBColor[
             0.8783639162366949, 0.43893633864321185`, 0.3669925272239519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 225}], {
             RGBColor[
             0.84226224924205, 0.4121124463693103, 0.4414749134015841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 240}], {
             RGBColor[
             0.824588465564483, 0.19000329782873795`, 0.17117924843423588`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 243}], {
             RGBColor[
             0.8705342231838472, 0.43407421080067554`, 0.42400915684212137`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 285}], {
             RGBColor[
             0.8787585038612737, 0.43847667310735655`, 0.31517946631969995`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 337}], {
             RGBColor[
             0.8787077642296014, 0.4383681461657731, 0.30965677054087426`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 357}], {
             RGBColor[
             0.8330589874809773, 0.2551114410852856, 0.1792906297875571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 399}], {
             RGBColor[
             0.8562175118599777, 0.35734498320723135`, 0.1984462235105148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 36}], {
             RGBColor[
             0.19993330434376533`, 0.3274729577419183, 0.9346972779563351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 151}], {
             RGBColor[
             0.19950401467485102`, 0.3270217470813523, 0.9346728305447676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 168}], {
             RGBColor[
             0.19559687276408316`, 0.32291509320603007`, 0.9344503245930478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 265}], {
             RGBColor[
             0.1984857219314811, 0.32595145684458154`, 0.9346148402794617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 267}], {
             RGBColor[
             0.23148773999796957`, 0.36063867028126045`, 0.9364942563862377]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 282}], {
             RGBColor[
             0.2370656602671769, 0.3665014181447689, 0.9368119106937756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 291}], {
             RGBColor[
             0.1970819328198578, 0.3244759854828951, 0.9345348965662746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 304}], {
             RGBColor[
             0.1939396212205168, 0.3211732167579251, 0.9343559465693256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 378}], {
             RGBColor[
             0.19890365407675165`, 0.32639073002768937`, 0.9346386408968597]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 383}], {
             RGBColor[
             0.20767130167756592`, 0.3356060835571104, 0.9351379454571538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.19127206346984504`, 0.31836944442903903`, 0.934204033101723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 87}], {
             RGBColor[
             0.18980864714848175`, 0.31683130108933233`, 0.9341206937071518]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 119}], {
             RGBColor[
             0.18192714786076558`, 0.30854734562202557`, 0.9336718539823496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 127}], {
             RGBColor[
             0.18812124438286376`, 0.3150577337951532, 0.9340245986159385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 129}], {
             RGBColor[
             0.18526332309430954`, 0.3120538773182072, 0.933861844226471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 231}], {
             RGBColor[
             0.1818156421264654, 0.3084301460254042, 0.9336655038957391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 235}], {
             RGBColor[
             0.18647615617022215`, 0.31332864177904984`, 0.9339309132759184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 317}], {
             RGBColor[
             0.1883961858281423, 0.3153467146864354, 0.9340402561245076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 326}], {
             RGBColor[
             0.18672499245337307`, 0.31359018448977305`, 0.9339450841341236]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 327}], {
             RGBColor[
             0.18852270839333474`, 0.31547969792444663`, 0.934047461397422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 336}], {
             RGBColor[
             0.18089581060751259`, 0.30746334477829806`, 0.9336131208515035]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 396}], {
             RGBColor[
             0.19049809514878532`, 0.31755595465117936`, 0.9341599567508221]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 54}], {
             RGBColor[
             0.1824115228296057, 0.3090564544254234, 0.9336994384202565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 63}], {
             RGBColor[
             0.18069605079375822`, 0.30725338454853857`, 0.9336017448256284]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 224}], {
             RGBColor[
             0.17977250803868983`, 0.30628268255696894`, 0.9335491504319864]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 297}], {
             RGBColor[
             0.19356559882175525`, 0.3207800955024369, 0.9343346465470327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 318}], {
             RGBColor[
             0.18730055861877407`, 0.31419514102261215`, 0.9339778617757692]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 345}], {
             RGBColor[
             0.1795989351746539, 0.30610024647171197`, 0.9335392657141575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 81}], {
             RGBColor[
             0.1880171511030766, 0.3149483251582018, 0.9340186706576468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 106}], {
             RGBColor[
             0.21164758701888683`, 0.33978541156189057`, 0.935364389024955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 164}], {
             RGBColor[
             0.19871454021211585`, 0.32619195936544565`, 0.9346278711420376]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 192}], {
             RGBColor[
             0.18904880805086632`, 0.3160326620211572, 0.9340774219946237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 241}], {
             RGBColor[
             0.22984485211178313`, 0.3589118909477702, 0.9364006963515542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 271}], {
             RGBColor[
             0.18778814176396494`, 0.3147076218227647, 0.9340056289145733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 287}], {
             RGBColor[
             0.19320443776430601`, 0.3204004923321242, 0.9343140789591009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 292}], {
             RGBColor[
             0.19543097961487327`, 0.32274072898797734`, 0.9344408772236172]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 371}], {
             RGBColor[
             0.1915120199175549, 0.31862165386969954`, 0.9342176982664363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 374}], {
             RGBColor[
             0.1933477765192394, 0.32055115045176114`, 0.9343222418891437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 382}], {
             RGBColor[
             0.18918398084593196`, 0.3161747371992214, 0.9340851198853325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 384}], {
             RGBColor[
             0.19301716646589862`, 0.32020365832381187`, 0.9343034141356996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 389}], {
             RGBColor[
             0.19956255990653143`, 0.3270832818318305, 0.9346761646091019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 78}], {
             RGBColor[
             0.8656358011330783, 0.391743634424193, 0.20700997583252984`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 104}], {
             RGBColor[
             0.8650168308266121, 0.38698595741417663`, 0.2064172491680309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 172}], {
             RGBColor[
             0.8682128995601259, 0.4115523422262132, 0.2094778081966871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 194}], {
             RGBColor[
             0.9757819569708761, 0.9287169668940988, 0.4668813870087187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 208}], {
             RGBColor[
             0.97502376088894, 0.929050734989072, 0.526498655624491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 217}], {
             RGBColor[
             0.975050917301262, 0.9271533469602427, 0.3873122304251019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 223}], {
             RGBColor[
             0.9434671979288998, 0.8132571155526379, 0.27501732397559764`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 230}], {
             RGBColor[
             0.8641696265273747, 0.38047397392294696`, 0.2056059653743008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 240}], {
             RGBColor[
             0.8734700310764903, 0.45196095875070935`, 0.21451204327383844`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 242}], {
             RGBColor[
             0.8871930329121218, 0.5574419643171217, 0.22765320532955294`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 357}], {
             RGBColor[
             0.8904110749094791, 0.5821772452638048, 0.2307348059804809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 364}], {
             RGBColor[
             0.8641288289294724, 0.38016038570784827`, 0.2055668975484752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 385}], {
             RGBColor[
             0.9757287822359568, 0.928603231512897, 0.461093645269188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 387}], {
             RGBColor[
             0.7455791435710649, 0.7496942133696903, 0.622023162461701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 92}], {
             RGBColor[
             0.3869660924415177, 0.5054181375626268, 0.9463177797578736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 182}], {
             RGBColor[
             0.3125367270389322, 0.44214783260778046`, 0.9412445628049322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 256}], {
             RGBColor[
             0.3139252578534664, 0.443350508209742, 0.9413330387606047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 281}], {
             RGBColor[
             0.3526148324525338, 0.4768614731328931, 0.9437983042422098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 311}], {
             RGBColor[
             0.28964287283882917`, 0.4217634021453914, 0.9398061051687154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 35}], {
             RGBColor[
             0.24974982719833305`, 0.3798332818120472, 0.9375342552359615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 85}], {
             RGBColor[
             0.25199669770088307`, 0.3821948851700452, 0.9376622111871347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 86}], {
             RGBColor[
             0.3371353879041764, 0.46222487105446, 0.9428569705546225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 91}], {
             RGBColor[
             0.37827297461142906`, 0.4967706349329164, 0.9457781608227135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 93}], {
             RGBColor[
             0.24878417747359188`, 0.37881832272561544`, 0.9374792629126882]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 95}], {
             RGBColor[
             0.41132901778835196`, 0.5236070199417173, 0.9483804536298768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 125}], {
             RGBColor[
             0.2623800078372861, 0.3931084024632914, 0.9382535253386719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 162}], {
             RGBColor[
             0.2677884948207052, 0.39879306520074553`, 0.9385615306712383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 211}], {
             RGBColor[
             0.2425688344221679, 0.3722856031030586, 0.9371253083206856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 214}], {
             RGBColor[
             0.25149658822823806`, 0.38166923840552336`, 0.9376337306925131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 248}], {
             RGBColor[
             0.24062348998029212`, 0.37024092275268566`, 0.9370145238326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 263}], {
             RGBColor[
             0.3276003815122878, 0.45396612776116196`, 0.9422494083788064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 340}], {
             RGBColor[
             0.23309142699709673`, 0.3623242469969716, 0.9365855839883956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 42}], {
             RGBColor[
             0.22638274960055194`, 0.35527300169848874`, 0.9362035347352613]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 85}], {
             RGBColor[
             0.2384984047146932, 0.36800732340035325`, 0.9368935033705061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 86}], {
             RGBColor[
             0.32363709491798653`, 0.44803730928476804`, 0.942088262737994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 93}], {
             RGBColor[
             0.235285884487402, 0.3646307609559235, 0.9367105550960597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 97}], {
             RGBColor[
             0.21457055736469166`, 0.3428576387223553, 0.9355308478620015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 98}], {
             RGBColor[
             0.21863346925867172`, 0.3471280167264209, 0.9357622246838242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 125}], {
             RGBColor[
             0.24888171485109623`, 0.37892084069359944`, 0.9374848175220434]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 162}], {
             RGBColor[
             0.25429020183451534`, 0.3846055034310536, 0.9377928228546097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 211}], {
             RGBColor[
             0.22907054143597805`, 0.35809804133336665`, 0.9363566005040571]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 214}], {
             RGBColor[
             0.23799829524204824`, 0.3674816766358314, 0.9368650228758846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 248}], {
             RGBColor[
             0.22712519699410227`, 0.3560533609829937, 0.9362458160159715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 263}], {
             RGBColor[
             0.31410208852609794`, 0.43977856599147, 0.9414807005621779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 340}], {
             RGBColor[
             0.21959313401090685`, 0.34813668522727964`, 0.9358168761717671]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 80}], {
             RGBColor[
             0.1863429465695527, 0.31318863004276976`, 0.9339233271862263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 151}], {
             RGBColor[
             0.19244860485001886`, 0.3196060640166337, 0.9342710353927868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 168}], {
             RGBColor[
             0.18854146293925098`, 0.3154994101413115, 0.9340485294410671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 265}], {
             RGBColor[
             0.1914303121066489, 0.318535773779863, 0.934213045127481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 277}], {
             RGBColor[
             0.20034660319217895`, 0.3279073610362615, 0.9347208147143313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 304}], {
             RGBColor[
             0.18688421139568462`, 0.3137575336932065, 0.933954151417345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 378}], {
             RGBColor[
             0.1918482442519195, 0.31897504696297085`, 0.934236845744879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 383}], {
             RGBColor[
             0.20061589185273376`, 0.3281904004923918, 0.9347361503051731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 41}], {
             RGBColor[
             0.6103348144421008, 0.6886019294831773, 0.9655435733376975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 114}], {
             RGBColor[
             0.2950446149939596, 0.4237378370222073, 0.9402493164383834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 170}], {
             RGBColor[
             0.29023151793817503`, 0.41867896684859873`, 0.9399752176813956]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 187}], {
             RGBColor[
             0.39185947335344506`, 0.5138307132141199, 0.9461899170277228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 206}], {
             RGBColor[
             0.5395559184345032, 0.6328895346269106, 0.9586002858977685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 256}], {
             RGBColor[
             0.3500537032004466, 0.4776206563266962, 0.9435260903209648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 261}], {
             RGBColor[
             0.30438433219243016`, 0.43355447197007246`, 0.940781199515963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 311}], {
             RGBColor[
             0.3257713181858094, 0.4560335502623456, 0.9419991567290754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 361}], {
             RGBColor[
             0.28321730845770904`, 0.41130658795806163`, 0.939575768828076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 53}], {
             RGBColor[
             0.2076634431002256, 0.3355978236940631, 0.9351374979228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 58}], {
             RGBColor[
             0.2174442667054725, 0.3458780894432118, 0.935694501357687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 102}], {
             RGBColor[
             0.25020060979959846`, 0.3803070829072448, 0.9375599266382304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 103}], {
             RGBColor[
             0.20863860950919683`, 0.3366227854190133, 0.9351930322071614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 117}], {
             RGBColor[
             0.22453541604736282`, 0.35333133700637476`, 0.9360983318222922]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 145}], {
             RGBColor[
             0.21009367554414693`, 0.338152152078261, 0.9352758960652745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 189}], {
             RGBColor[
             0.24478652953490182`, 0.3746165412765333, 0.9372516027765698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 222}], {
             RGBColor[
             0.22765792346573496`, 0.35661329028148886`, 0.9362761540004327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 254}], {
             RGBColor[
             0.20508861754811766`, 0.3328915187854286, 0.9349908654167205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 303}], {
             RGBColor[
             0.21808265414273661`, 0.3465490751158777, 0.9357308565778295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 376}], {
             RGBColor[
             0.21626586560617583`, 0.3446395151729059, 0.9356273931583702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 150}], {
             RGBColor[
             0.1883607596919023, 0.31530947957110045`, 0.9340382386584571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 237}], {
             RGBColor[
             0.19025421078354665`, 0.3172996167201517, 0.9341460678970164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 251}], {
             RGBColor[
             0.18672478342346222`, 0.3135899647860835, 0.9339450722301794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 283}], {
             RGBColor[
             0.19607798492560893`, 0.3234207725920666, 0.934477723218905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 294}], {
             RGBColor[
             0.18656769797512113`, 0.31342485802008435`, 0.9339361264462835]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 320}], {
             RGBColor[
             0.18948414481075992`, 0.3164902285577502, 0.9341022137790767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 347}], {
             RGBColor[
             0.19051344323313968`, 0.3175720864609606, 0.9341608308015206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 381}], {
             RGBColor[
             0.18966952552711056`, 0.31668507544445096`, 0.9341127709366266]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 51}], {
             RGBColor[
             0.4513189432678153, 0.5634921655168925, 0.9504868403154272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 84}], {
             RGBColor[
             0.42994887224450423`, 0.5449824840875006, 0.9491251582866337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 102}], {
             RGBColor[
             0.39926565859510593`, 0.5155146756656562, 0.9472759248895897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 134}], {
             RGBColor[
             0.6760140538149009, 0.745057217744171, 0.9695892868351288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 163}], {
             RGBColor[
             0.3939273213258807, 0.5099037447255685, 0.9469719144794696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 167}], {
             RGBColor[
             0.4156571514498516, 0.5326037138579458, 0.948214502475271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 174}], {
             RGBColor[
             0.4325281900725898, 0.5472165595499049, 0.9492895101378381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 183}], {
             RGBColor[
             0.43552341404886974`, 0.5498108720138242, 0.9494803631610341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 189}], {
             RGBColor[
             0.3938515783304093, 0.5098241340349448, 0.9469676010279292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 226}], {
             RGBColor[
             0.48315013418370223`, 0.5910627432060597, 0.9525150956533707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 234}], {
             RGBColor[
             0.653391331063141, 0.7272953937118065, 0.9673580250213626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 246}], {
             RGBColor[
             0.7206526383610699, 0.7806508133791874, 0.9738469548784772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 269}], {
             RGBColor[
             0.6323207129287618, 0.7108348666826005, 0.9652579027218493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 272}], {
             RGBColor[
             0.6309966022057711, 0.7098004613221861, 0.9651259277394999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 350}], {
             RGBColor[
             0.7574551958384235, 0.806891984810095, 0.8535080309341501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 355}], {
             RGBColor[
             0.6433835290110301, 0.7194772226865849, 0.9663605408410356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 392}], {
             RGBColor[
             0.7560719179586157, 0.8063199638581745, 0.8764325252109648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 395}], {
             RGBColor[
             0.494849422028799, 0.60078007937222, 0.9533755056767188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 55}], {
             RGBColor[
             0.9217511656674453, 0.9083191148939446, 0.6659672564832814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 83}], {
             RGBColor[
             0.9084527486796484, 0.9295988421678656, 0.9827837388659694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.684630729662244, 0.7517566465973935, 0.970608286963019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 135}], {
             RGBColor[
             0.9333566323648748, 0.9460233638065111, 0.83381543555314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 156}], {
             RGBColor[
             0.8446142468320946, 0.4596744496768401, 0.44741728123423563`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 165}], {
             RGBColor[
             0.8843102751860701, 0.9105890257431475, 0.9888274975519911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 187}], {
             RGBColor[
             0.6533956652271913, 0.7258990741319324, 0.9682873726725081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 206}], {
             RGBColor[
             0.8010921103082493, 0.8449578955447232, 0.9806977415425538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 245}], {
             RGBColor[
             0.8365103724506917, 0.3973845200409797, 0.4396570019745871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 256}], {
             RGBColor[
             0.6115898950741928, 0.6896890172445088, 0.9656235459657501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 311}], {
             RGBColor[
             0.5873075100595555, 0.6681019111801583, 0.9640966123738608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 328}], {
             RGBColor[
             0.8707008812978143, 0.7005608755905404, 0.6002433163697872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 386}], {
             RGBColor[
             0.8163158098721861, 0.8568507653484726, 0.982215097641526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 400}], {
             RGBColor[
             0.8574093225920176, 0.5580230088055577, 0.4596698602319089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 45}], {
             RGBColor[
             0.2506616815740248, 0.3807916985758058, 0.9375861839936894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 93}], {
             RGBColor[
             0.22541709987581074`, 0.35425804261205696`, 0.936148542411988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 98}], {
             RGBColor[
             0.20876468464708048`, 0.33675529838255447`, 0.9352002119997525]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 125}], {
             RGBColor[
             0.23901293023950498`, 0.3685481223497329, 0.9369228048379719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 139}], {
             RGBColor[
             0.20228682166276132`, 0.3299466536657998, 0.934831307285935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 148}], {
             RGBColor[
             0.27524609124263133`, 0.40429858097089644`, 0.9390716483190401]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 204}], {
             RGBColor[
             0.20507426806755127`, 0.33287643657154375`, 0.9349900482350304]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 248}], {
             RGBColor[
             0.21725641238251098`, 0.34568064263912723`, 0.9356838033318999]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 275}], {
             RGBColor[
             0.2276321474655179, 0.3565861980709679, 0.9362746860953526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 276}], {
             RGBColor[
             0.2196855450649306, 0.3482338151042579, 0.9358221388445839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 288}], {
             RGBColor[
             0.26094257460696524`, 0.39159756899969334`, 0.938171665642697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 290}], {
             RGBColor[
             0.20736560396252507`, 0.33528477587624783`, 0.9351205364245214]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 318}], {
             RGBColor[
             0.2054522043558168, 0.33327367157305554`, 0.9350115711475404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 56}], {
             RGBColor[
             0.3210051071529382, 0.44798658822988663`, 0.9418389411311112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 59}], {
             RGBColor[
             0.3034359716582913, 0.4327690861148492, 0.9407194513531689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[
             0.434369237561579, 0.5419666394359329, 0.9502257108546233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 121}], {
             RGBColor[
             0.28563299292961386`, 0.4173490407437973, 0.9395850612911336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 122}], {
             RGBColor[
             0.42916131354223347`, 0.5377386121027248, 0.9498157239985662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 175}], {
             RGBColor[
             0.2710055822533935, 0.4021744280676252, 0.9387447390412754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 213}], {
             RGBColor[
             0.2414891450614786, 0.3711507811287148, 0.9370638216088516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 227}], {
             RGBColor[
             0.23391469744368304`, 0.36318955643469497`, 0.9366324680224093]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 237}], {
             RGBColor[
             0.22884629711642387`, 0.3578623463356042, 0.9363438301217982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 274}], {
             RGBColor[
             0.3767191464303865, 0.4951636983486218, 0.9456872845015338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 296}], {
             RGBColor[
             0.2526601828418626, 0.38289225012060224`, 0.937699995684375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 308}], {
             RGBColor[
             0.23093015114267265`, 0.3600526090411681, 0.9364625025258073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 373}], {
             RGBColor[
             0.2661054797853324, 0.3970241096892522, 0.9384656854547713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 380}], {
             RGBColor[
             0.2402420225431372, 0.36983997628980336`, 0.9369927998263845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 46}], {
             RGBColor[
             0.2189840028439955, 0.34749644974970917`, 0.9357821870529404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 65}], {
             RGBColor[
             0.2623103948909678, 0.393035234842995, 0.9382495609843622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 68}], {
             RGBColor[
             0.25335041241870687`, 0.38361772516894843`, 0.9377393032376733]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 113}], {
             RGBColor[
             0.27210008577250266`, 0.4033248206617401, 0.9388070693975159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 149}], {
             RGBColor[
             0.22663901581167467`, 0.355542353734595, 0.9362181287168728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 161}], {
             RGBColor[
             0.2180648213930185, 0.34653033176526227`, 0.9357298410291143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 195}], {
             RGBColor[
             0.2192614298530921, 0.3477880431261581, 0.9357979861106919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 247}], {
             RGBColor[
             0.2171512777998561, 0.34557013952683935`, 0.9356778160729503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 249}], {
             RGBColor[
             0.27287548484168234`, 0.4041092659680885, 0.9388523457495259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 250}], {
             RGBColor[
             0.24751102743025372`, 0.3774801613076919, 0.9374067589011768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 266}], {
             RGBColor[
             0.23471345152571355`, 0.36402909761884283`, 0.9366779558857301]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 315}], {
             RGBColor[
             0.22776027402374388`, 0.3567208672073564, 0.9362819827132973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 316}], {
             RGBColor[
             0.23551418105696653`, 0.3648707151253743, 0.9367235562479619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 358}], {
             RGBColor[
             0.21372519899594036`, 0.3419691134779814, 0.9354827059534967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 362}], {
             RGBColor[
             0.21291981933663207`, 0.3411226083920287, 0.9354368407733515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 363}], {
             RGBColor[
             0.22828771928123268`, 0.35727524561493795`, 0.9363120199404259]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 369}], {
             RGBColor[
             0.21363611782330827`, 0.34187548351747254`, 0.9354776329124991]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 372}], {
             RGBColor[
             0.21537145554787535`, 0.3436994334927591, 0.9355764578287111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 66}], {
             RGBColor[
             0.2495400971941441, 0.37961284227999426`, 0.9375223114224907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 91}], {
             RGBColor[
             0.38905361359871204`, 0.5081017700405416, 0.9463921022645131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 123}], {
             RGBColor[
             0.24825361468381962`, 0.37826066759394095`, 0.9374490481467079]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 140}], {
             RGBColor[
             0.25525427585226035`, 0.38561880634952683`, 0.9378477254437005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 148}], {
             RGBColor[
             0.30939380782769543`, 0.44018999619208, 0.9410163102615399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 179}], {
             RGBColor[
             0.3693787364367489, 0.49212881841734446`, 0.9448432238628737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 203}], {
             RGBColor[
             0.2552832201033739, 0.38564922859261863`, 0.9378493737759823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 232}], {
             RGBColor[
             0.28995111396047296`, 0.4220873831078549, 0.9398236590445912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 257}], {
             RGBColor[
             0.30395689687858984`, 0.4354808171950546, 0.9406698751035344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 275}], {
             RGBColor[
             0.261779864050582, 0.3924776132921515, 0.9382193480378523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 276}], {
             RGBColor[
             0.2538332616499947, 0.38412523032544144`, 0.9377668007870836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 279}], {
             RGBColor[
             0.4785218001436983, 0.5802784243797845, 0.9537482634423509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 280}], {
             RGBColor[
             0.26817273037966816`, 0.3991969211351571, 0.9385834123178955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 288}], {
             RGBColor[
             0.29509029119202934`, 0.4274889842208769, 0.9401163275851969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 297}], {
             RGBColor[
             0.2458649611438621, 0.37575004127406386`, 0.9373130178613036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 325}], {
             RGBColor[
             0.2869742607531359, 0.4189585216435491, 0.9396541316582929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 339}], {
             RGBColor[
             0.26817858765203434`, 0.39920307749978645`, 0.9385837458808918]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 149}], {
             RGBColor[
             0.20894845482391827`, 0.3369484524901131, 0.9352106774394597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 153}], {
             RGBColor[
             0.1918690303202028, 0.3189968944386494, 0.9342380294807175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 161}], {
             RGBColor[
             0.20037426040526207`, 0.3279364305207805, 0.9347223897517012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 184}], {
             RGBColor[
             0.19220194755564052`, 0.3193468115612663, 0.9342569886247687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 195}], {
             RGBColor[
             0.2015708688653357, 0.3291941418816762, 0.9347905348332788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 247}], {
             RGBColor[
             0.1994607168120997, 0.32697623828235756`, 0.9346703647955372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 250}], {
             RGBColor[
             0.22982046644249732`, 0.3588862600632101, 0.9363993076237638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 315}], {
             RGBColor[
             0.21006971303598748`, 0.3381269659628746, 0.9352745314358842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 343}], {
             RGBColor[
             0.19165716183089215`, 0.31877420722314587`, 0.9342259638836825]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 356}], {
             RGBColor[
             0.1981426064801053, 0.32559082075040946`, 0.9345953003620997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 358}], {
             RGBColor[
             0.19603463800818394`, 0.3233752122334996, 0.9344752546760837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 362}], {
             RGBColor[
             0.19522925834887567`, 0.3225287071475469, 0.9344293894959386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 363}], {
             RGBColor[
             0.21059715829347625`, 0.33868134437045616`, 0.9353045686630128]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 369}], {
             RGBColor[
             0.19594555683555187`, 0.3232815822729907, 0.934470181635086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 372}], {
             RGBColor[
             0.19768089456011895`, 0.32510553224827726`, 0.934569006551298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.6461513889555156, 0.7219924964871992, 0.9663950668318202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.44142989596913074`, 0.5543010784500094, 0.9500295993461311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 173}], {
             RGBColor[
             0.41329174036295263`, 0.5275007351562074, 0.948325579764125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 201}], {
             RGBColor[
             0.7465737093465549, 0.8011421937069441, 0.9641963866302764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 209}], {
             RGBColor[
             0.43947307837840166`, 0.5526061814054317, 0.9499049126595958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 323}], {
             RGBColor[
             0.4713973595467131, 0.580257389192397, 0.951939099626107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 346}], {
             RGBColor[
             0.44758503753245593`, 0.5596323527057516, 0.9504217995237683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 61}], {
             RGBColor[
             0.22477630942984533`, 0.3535845312248864, 0.9361120503440548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 68}], {
             RGBColor[
             0.2551071510734325, 0.38546416887872903`, 0.937839346905198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 118}], {
             RGBColor[
             0.23953466514577643`, 0.3690964988161278, 0.9369525168690463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 173}], {
             RGBColor[
             0.2613339339978391, 0.3920089125331203, 0.938193952981043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 176}], {
             RGBColor[
             0.2369284794639835, 0.36635723242284735`, 0.9368040984499744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 209}], {
             RGBColor[
             0.2875152720132881, 0.41711435878234465`, 0.9397732858765137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 344}], {
             RGBColor[
             0.21571874970997718`, 0.3440644616768498, 0.9355962357174672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 354}], {
             RGBColor[
             0.22802037271409625`, 0.35699424742212627`, 0.9362967949489314]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 388}], {
             RGBColor[
             0.2298511238520014, 0.358918482944391, 0.9364010535178815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 52}], {
             RGBColor[
             0.1835216269875808, 0.31022324428012404`, 0.9337626572098012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 62}], {
             RGBColor[
             0.19439182652115503`, 0.3216485132003679, 0.9343816989922191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.19292841019979173`, 0.32011036986066127`, 0.934298359597648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 127}], {
             RGBColor[
             0.19124100743417377`, 0.3183368025664821, 0.9342022645064347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[
             0.18838308614561955`, 0.31533294608953616`, 0.9340395101169672]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 133}], {
             RGBColor[
             0.18673252269027052`, 0.31359809924619686`, 0.933945512969975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 199}], {
             RGBColor[
             0.18708382947160418`, 0.313967344947515, 0.93396551937146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 216}], {
             RGBColor[
             0.19369425198474133`, 0.320915318133817, 0.9343419731543394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 231}], {
             RGBColor[
             0.1849354051777754, 0.31170921479673314`, 0.9338431697862355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 235}], {
             RGBColor[
             0.18959591922153213`, 0.31660771055037873`, 0.9341085791664148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 298}], {
             RGBColor[
             0.19233776426424887`, 0.31948956353329044`, 0.9342647231854012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 313}], {
             RGBColor[
             0.20302253470198556`, 0.3307199347169253, 0.9348732050551289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 361}], {
             RGBColor[
             0.2026569249479238, 0.33033565568440915`, 0.9348523841205063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 393}], {
             RGBColor[
             0.1855205539729795, 0.3123242432810691, 0.9338764931444723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 396}], {
             RGBColor[
             0.1936178582000953, 0.3208350234225083, 0.9343376226413184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.18052420551329257`, 0.307072764263149, 0.9335919584911282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 147}], {
             RGBColor[
             0.18125622821196816`, 0.30784216653237684`, 0.9336336461008872]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 164}], {
             RGBColor[
             0.18999442899880858`, 0.3170265695932755, 0.9341312737086882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 271}], {
             RGBColor[
             0.17906803055065768`, 0.3055422320505946, 0.933509031481224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 287}], {
             RGBColor[
             0.18448432655099875`, 0.31123510255995407`, 0.9338174815257515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 371}], {
             RGBColor[
             0.1827919087042476, 0.30945626409752947`, 0.9337211008330868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 391}], {
             RGBColor[
             0.18008156514952903`, 0.3066075211758136, 0.9335667507772396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 84}], {
             RGBColor[
             0.36020789306278994`, 0.48641570522103605`, 0.9441731063199956]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 102}], {
             RGBColor[
             0.32952467941339164`, 0.45694789679919157`, 0.9423238729229517]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 134}], {
             RGBColor[
             0.6062730746331866, 0.6864904388777064, 0.9646372348684907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 163}], {
             RGBColor[
             0.3241863421441664, 0.4513369658591039, 0.9420198625128315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 167}], {
             RGBColor[
             0.3459161722681373, 0.47403693499148125`, 0.9432624505086329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 174}], {
             RGBColor[
             0.3627872108908755, 0.4886497806834403, 0.9443374581712001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 183}], {
             RGBColor[
             0.36578243486715545`, 0.4912440931473596, 0.9445283111943961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 189}], {
             RGBColor[
             0.324110599148695, 0.45125735516848015`, 0.9420155490612911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 222}], {
             RGBColor[
             0.3069819930795281, 0.4332541041734357, 0.9410401002851541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 226}], {
             RGBColor[
             0.41340915500198794`, 0.532495964339595, 0.9475630436867326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 234}], {
             RGBColor[
             0.5836503518814267, 0.668728614845342, 0.9624059730547245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 238}], {
             RGBColor[
             0.3357800727610889, 0.463522711822467, 0.942680108320078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 246}], {
             RGBColor[
             0.6509116591793556, 0.7220840345127228, 0.9688949029118392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 269}], {
             RGBColor[
             0.5625797337470475, 0.652268087816136, 0.9603058507552114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 272}], {
             RGBColor[
             0.5612556230240568, 0.6512336824557214, 0.9601738757728618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 350}], {
             RGBColor[
             0.6877142166567092, 0.7483252059436304, 0.8485559789675121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 355}], {
             RGBColor[
             0.5736425498293158, 0.6609104438201203, 0.9614084888743977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 392}], {
             RGBColor[
             0.6863309387769014, 0.7477531849917098, 0.8714804732443268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 395}], {
             RGBColor[
             0.4251084428470847, 0.5422133005057554, 0.9484234537100807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 89}], {
             RGBColor[
             0.18430520538442102`, 0.31104683485694296`, 0.933807280840301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 128}], {
             RGBColor[
             0.18698858591777334`, 0.3138672379336487, 0.9339600953919696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 133}], {
             RGBColor[
             0.18257629412906723`, 0.3092296395082612, 0.9337088219020035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 199}], {
             RGBColor[
             0.1829276009104009, 0.30959888520957934`, 0.9337288283034887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 299}], {
             RGBColor[
             0.18351379325327066`, 0.3102150105286766, 0.9337622110902213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 342}], {
             RGBColor[
             0.18153992013799802`, 0.30814034473374124`, 0.9336498019363901]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 393}], {
             RGBColor[
             0.18136432541177624`, 0.30795578354313347`, 0.9336398020765009]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 58}], {
             RGBColor[
             0.20217788494718347`, 0.3298321542707407, 0.9348251035011402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 64}], {
             RGBColor[
             0.18652020523185484`, 0.31337494013569756`, 0.9339334218048136]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 117}], {
             RGBColor[
             0.20926903428907379`, 0.33728540183390365`, 0.9352289339657456]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 126}], {
             RGBColor[
             0.1894916420221746, 0.31649810860229766`, 0.9341026407341755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 289}], {
             RGBColor[
             0.18928237138329773`, 0.3162781518923132, 0.9340907230808797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 303}], {
             RGBColor[
             0.20281627238444755`, 0.3305031399434066, 0.9348614587212829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 376}], {
             RGBColor[
             0.20099948384788677`, 0.3285935800004348, 0.9347579953018235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 63}], {
             RGBColor[
             0.18289690010848875`, 0.3095666167202264, 0.9337270799382376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 66}], {
             RGBColor[
             0.19944158418676777`, 0.3269561286800552, 0.9346692752208288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 204}], {
             RGBColor[
             0.18912347164523904`, 0.31611113819278824`, 0.9340816739758684]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 224}], {
             RGBColor[
             0.18197335735342035`, 0.3085959147286568, 0.9336744855445955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 290}], {
             RGBColor[
             0.19141480754021284`, 0.3185194774974923, 0.9342121621653594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 297}], {
             RGBColor[
             0.19576644813648575`, 0.3230933276741248, 0.9344599816596418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 318}], {
             RGBColor[
             0.18950140793350456`, 0.31650837319430003`, 0.9341031968883784]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 345}], {
             RGBColor[
             0.1817997844893844, 0.30841347864339985`, 0.9336646008267666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 92}], {
             RGBColor[
             0.7345108890138425, 0.7594054710903482, 0.6489345144638174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 135}], {
             RGBColor[
             0.9832367917164733, 0.9536721882994657, 0.5121416630539384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 156}], {
             RGBColor[
             0.8778676863998269, 0.46477366600547654`, 0.23296809956810122`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.9341904345376686, 0.918237850236102, 0.6671537250527897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 221}], {
             RGBColor[
             0.9369698505827507, 0.7826274582869746, 0.292244768605455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 245}], {
             RGBColor[
             0.869763812018424, 0.4024837363696161, 0.2252078203084527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 255}], {
             RGBColor[
             0.880784705491405, 0.48719515298926147`, 0.23576144034449814`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 328}], {
             RGBColor[
             0.9205810406494127, 0.7082097000834948, 0.27856954387058575`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 386}], {
             RGBColor[
             0.8661959692237846, 0.8644995898414272, 0.6605413251423246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 400}], {
             RGBColor[
             0.8906627621597499, 0.5631222251341941, 0.24522067856577465`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 59}], {
             RGBColor[
             0.3640812726856617, 0.4897706319686471, 0.9444199146444701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 90}], {
             RGBColor[
             0.4950145385889495, 0.5989681852897308, 0.9539261741459244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 121}], {
             RGBColor[
             0.3462782939569843, 0.4743505865975952, 0.9432855245824346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 122}], {
             RGBColor[
             0.48980661456960395`, 0.5947401579565226, 0.9535161872898672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 137}], {
             RGBColor[
             0.35805694536026106`, 0.48455266243088047`, 0.9440360498343989]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 166}], {
             RGBColor[
             0.6856726502293173, 0.7474973607293266, 0.8829926191709212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 169}], {
             RGBColor[
             0.6387195548301612, 0.7123648726900207, 0.967730862260616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 175}], {
             RGBColor[
             0.331650883280764, 0.45917597392142306`, 0.9424452023325764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 178}], {
             RGBColor[
             0.4116703274319593, 0.5309898792944511, 0.9474522471315552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 213}], {
             RGBColor[
             0.30213444608884904`, 0.4281523269825127, 0.9407642849001527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 274}], {
             RGBColor[
             0.43736444745775693`, 0.5521652442024196, 0.9493877477928349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 278}], {
             RGBColor[
             0.3199081459581343, 0.44683361246279085`, 0.9417764708138758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 296}], {
             RGBColor[
             0.313305483869233, 0.43989379597440015`, 0.9414004589756761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 319}], {
             RGBColor[
             0.4175060909791842, 0.5360433358043497, 0.9478244252272849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 352}], {
             RGBColor[
             0.31062641380180694`, 0.4370779234706822, 0.9412478898986653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 76}], {
             RGBColor[
             0.20578868678679324`, 0.33362733594223004`, 0.9350307333242034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.2782593236768137, 0.4070163756656283, 0.939259698655848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 102}], {
             RGBColor[
             0.24757611002741542`, 0.37754856724378383`, 0.937410465258804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 144}], {
             RGBColor[
             0.20411547873617336`, 0.33186868819351084`, 0.93493544660101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 163}], {
             RGBColor[
             0.24223777275819017`, 0.37193763630369614`, 0.9371064548486839]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 167}], {
             RGBColor[
             0.2639676028821611, 0.3946376054360735, 0.9383490428444853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 174}], {
             RGBColor[
             0.28083864150489934`, 0.40925045112803254`, 0.9394240505070525]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 186}], {
             RGBColor[
             0.21226621689950026`, 0.3404356307898151, 0.9353996190814751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 188}], {
             RGBColor[
             0.20973271485913975`, 0.33777275951208907`, 0.9352553398882568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 189}], {
             RGBColor[
             0.24216202976271878`, 0.3718580256130724, 0.9371021413971435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 222}], {
             RGBColor[
             0.22503342369355192`, 0.35385477461802795`, 0.9361266926210063]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 228}], {
             RGBColor[
             0.21063806848440092`, 0.33872434357497383`, 0.9353068984378649]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 238}], {
             RGBColor[
             0.2538315033751126, 0.3841233822670593, 0.9377667006559303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 333}], {
             RGBColor[
             0.2028967340448986, 0.3305877102501046, 0.9348660408938132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 368}], {
             RGBColor[
             0.20142644533340448`, 0.3290423435926357, 0.9347823101267909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 117}], {
             RGBColor[
             0.2190498578943207, 0.34756566758305235`, 0.9357859374006325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 289}], {
             RGBColor[
             0.19906319498854463`, 0.3265584176414619, 0.9346477265157667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 303}], {
             RGBColor[
             0.21259709598969448`, 0.3407834056925553, 0.9354184621561699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 376}], {
             RGBColor[
             0.2107803074531337, 0.33887384574958357`, 0.9353149987367104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 90}], {
             RGBColor[
             0.47744540309430256`, 0.5837506831746934, 0.9528066843679821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 121}], {
             RGBColor[
             0.3287091584623374, 0.4591330844825578, 0.9421660348044922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 122}], {
             RGBColor[
             0.472237479074957, 0.5795226558414852, 0.9523966975119249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 175}], {
             RGBColor[
             0.314081747786117, 0.4439584718063857, 0.9413257125546342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 178}], {
             RGBColor[
             0.3941011919373124, 0.5157723771794137, 0.9463327573536129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 213}], {
             RGBColor[
             0.2845653105942021, 0.4129348248674753, 0.9396447951222104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 274}], {
             RGBColor[
             0.41979531196311004`, 0.5369477420873823, 0.9482682580148925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 296}], {
             RGBColor[
             0.2957363483745861, 0.42467629385936273`, 0.9402809691977339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 319}], {
             RGBColor[
             0.3999369554845372, 0.5208258336893123, 0.9467049354493426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 373}], {
             RGBColor[
             0.3091816453180559, 0.4388081534280127, 0.9410466589681301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.18336573314646784`, 0.31005938996887394`, 0.9337537792861741]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 101}], {
             RGBColor[
             0.18455258152934814`, 0.31130684286981486`, 0.9338213685457943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.18529719032077357`, 0.3120894739205271, 0.933863772914916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 259}], {
             RGBColor[
             0.18612091931381164`, 0.3129552653196448, 0.9339106830624717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 331}], {
             RGBColor[
             0.19257622837931382`, 0.31974020443772183`, 0.9342783033639781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 335}], {
             RGBColor[
             0.18275395419094043`, 0.3094163714975885, 0.9337189393797027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 394}], {
             RGBColor[
             0.18321858514836378`, 0.3099047280931446, 0.933745399425368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 118}], {
             RGBColor[
             0.22412293343441853`, 0.3528977916272621, 0.9360748415476985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 130}], {
             RGBColor[
             0.19568837198846437`, 0.3230112646922406, 0.9344555353385153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 147}], {
             RGBColor[
             0.19642039468713995`, 0.32378066696146846`, 0.9344972229482744]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 164}], {
             RGBColor[
             0.2051585954739804, 0.3329650700223671, 0.9349948505560753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 173}], {
             RGBColor[
             0.24592220228648118`, 0.3758102053442546, 0.937316277659695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 176}], {
             RGBColor[
             0.2215167477526256, 0.3501585252339816, 0.9359264231286265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 344}], {
             RGBColor[
             0.20030701799861927`, 0.32786575448798405`, 0.9347185603961192]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 354}], {
             RGBColor[
             0.21260864100273835`, 0.3407955402332605, 0.9354191196275834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 371}], {
             RGBColor[
             0.19795607517941943`, 0.3253947645266211, 0.934584677680474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 388}], {
             RGBColor[
             0.2144393921406435, 0.3427197757555252, 0.9355233781965335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 87}], {
             RGBColor[
             0.1996423811721627, 0.3271671790429695, 0.9346807103120945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 119}], {
             RGBColor[
             0.1917608818844465, 0.31888322357566273`, 0.9342318705872924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 127}], {
             RGBColor[
             0.1979549784065447, 0.32539361174879033`, 0.9345846152208812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 129}], {
             RGBColor[
             0.19509705711799047`, 0.3223897552718444, 0.9344218608314138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 216}], {
             RGBColor[
             0.2004082229571123, 0.32797212731612524`, 0.934724323868786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 231}], {
             RGBColor[
             0.19164937615014635`, 0.31876602397904136`, 0.934225520500682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 235}], {
             RGBColor[
             0.1963098901939031, 0.32366451973268695`, 0.9344909298808612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 298}], {
             RGBColor[
             0.19905173523661984`, 0.32654637271559867`, 0.9346470738998478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 313}], {
             RGBColor[
             0.20973650567435648`, 0.3377767438992335, 0.9352555557695754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 317}], {
             RGBColor[
             0.19822991985182326`, 0.32568259264007254`, 0.9346002727294505]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 336}], {
             RGBColor[
             0.19072954463119351`, 0.31779922273193517`, 0.9341731374564464]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 361}], {
             RGBColor[
             0.20937089592029476`, 0.33739246486671737`, 0.9352347348349528]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 393}], {
             RGBColor[
             0.19223452494535048`, 0.31938105246337734`, 0.9342588438589188]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 396}], {
             RGBColor[
             0.20033182917246628`, 0.3278918326048165, 0.934719973355765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 98}], {
             RGBColor[
             0.19109841618892076`, 0.3181869301269141, 0.9341941441459625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 139}], {
             RGBColor[
             0.18462055320460163`, 0.31137828541015944`, 0.9338252394321449]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 204}], {
             RGBColor[
             0.18740799960939158`, 0.3143080683159034, 0.9339839803812403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 224}], {
             RGBColor[
             0.1802578853175729, 0.30679284485177194`, 0.9335767919499673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 290}], {
             RGBColor[
             0.18969933550436535`, 0.3167164076206075, 0.9341144685707314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 318}], {
             RGBColor[
             0.18778593589765713`, 0.3147053033174152, 0.9340055032937504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 345}], {
             RGBColor[
             0.18008431245353695`, 0.306610408766515, 0.9335669072321386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 77}], {
             RGBColor[
             0.18172630335562523`, 0.308336245312846, 0.9336604161849047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 94}], {
             RGBColor[
             0.1809149928406964, 0.30748350652159806`, 0.9336142132513059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 254}], {
             RGBColor[
             0.1839453796797469, 0.3106686352270631, 0.9337867892987342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 289}], {
             RGBColor[
             0.18340551527321602`, 0.3101012035064188, 0.9337560448194401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 68}], {
             RGBColor[
             0.2789862434779228, 0.41056260901775243`, 0.9391992258916821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 173}], {
             RGBColor[
             0.2852130264023293, 0.4171073526721437, 0.9395538319675272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 176}], {
             RGBColor[
             0.26080757186847375`, 0.39145567256187075`, 0.9381639774364586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 250}], {
             RGBColor[
             0.2731468584894696, 0.40442504515649597`, 0.9388666815551856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 363}], {
             RGBColor[
             0.25392355034044856`, 0.38422012946374207`, 0.9377719425944349]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 123}], {
             RGBColor[
             0.21298431371887483`, 0.3411903960769459, 0.9354405136330093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 131}], {
             RGBColor[
             0.2137636212718384, 0.34200949772606326`, 0.9354848940452685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 140}], {
             RGBColor[
             0.21998497488731555`, 0.3485485348325317, 0.9358391909300019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 203}], {
             RGBColor[
             0.2200139191384291, 0.3485789570756236, 0.9358408392622837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 232}], {
             RGBColor[
             0.25468181299552817`, 0.38501711159085983`, 0.9378151245308926]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 257}], {
             RGBColor[
             0.268687595913645, 0.3984105456780595, 0.9386613405898359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 275}], {
             RGBColor[
             0.22651056308563722`, 0.3554073417751564, 0.9362108135241538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 280}], {
             RGBColor[
             0.23290342941472336`, 0.362126649618162, 0.936574877804197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 297}], {
             RGBColor[
             0.21059566017891732`, 0.33867976975706876`, 0.935304483347605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 318}], {
             RGBColor[
             0.20433061997593613`, 0.33209481527724394`, 0.9349476985763416]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 322}], {
             RGBColor[
             0.2070879506142999, 0.33499294460302415`, 0.9351047244770914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 325}], {
             RGBColor[
             0.2517049597881912, 0.3818882501265539, 0.9376455971445944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 339}], {
             RGBColor[
             0.23290928668708955`, 0.3621328059827914, 0.9365752113671932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 113}], {
             RGBColor[
             0.36637406988619037`, 0.4916437040590915, 0.9445701410456664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 124}], {
             RGBColor[
             0.3674760832994186, 0.49271104629414053`, 0.9446362289748654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 194}], {
             RGBColor[
             0.709877099853931, 0.7667201163798876, 0.7972498678529694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 208}], {
             RGBColor[
             0.7091189037719949, 0.7670538844748609, 0.8568671364687419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 210}], {
             RGBColor[
             0.365438140563206, 0.4906599829992886, 0.9445168412553058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 249}], {
             RGBColor[
             0.36714946895537004`, 0.49242814936543994`, 0.9446154173976764]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 266}], {
             RGBColor[
             0.3289874356394012, 0.4523479810161943, 0.9424410275338806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 293}], {
             RGBColor[
             0.3870584168095417, 0.509672279343909, 0.9458839979501529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 316}], {
             RGBColor[
             0.32978816517065423`, 0.4531895985227258, 0.9424866278961124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 385}], {
             RGBColor[
             0.7098239251190117, 0.7666063809986858, 0.7914621261134387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 387}], {
             RGBColor[
             0.4796742864541198, 0.5876973628554791, 0.9523916433059518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 161}], {
             RGBColor[
             0.23474066997997348`, 0.36405770594001974`, 0.9366795059364341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 173}], {
             RGBColor[
             0.2762530439300684, 0.40768984299809713`, 0.9390435742208383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 176}], {
             RGBColor[
             0.2518475893962128, 0.38203816288782416`, 0.9376537196897696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 250}], {
             RGBColor[
             0.2641868760172087, 0.3950075354824494, 0.9383564238084967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 363}], {
             RGBColor[
             0.24496356786818765`, 0.3748026197896954, 0.9372616848477457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 106}], {
             RGBColor[
             0.23431749208343802`, 0.36361291913973265`, 0.936655406581262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 107}], {
             RGBColor[
             0.2952174792692931, 0.42393616514341426`, 0.9402585516481101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 150}], {
             RGBColor[
             0.217681081623926, 0.3461269969374395, 0.9357079876169566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 212}], {
             RGBColor[
             0.32957634955032006`, 0.4536960916538069, 0.9424478684800611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 270}], {
             RGBColor[
             0.300457761234542, 0.4284750339974831, 0.9405924577811364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 283}], {
             RGBColor[
             0.22539830685763262`, 0.3542382899584056, 0.9361474721774046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 294}], {
             RGBColor[
             0.2158880199071448, 0.3442423753864234, 0.935605875404783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 295}], {
             RGBColor[
             0.3354255676488553, 0.4587623903805083, 0.9428205754850394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 320}], {
             RGBColor[
             0.21880446674278364`, 0.34730774592408925`, 0.9357719627375762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 347}], {
             RGBColor[
             0.21983376516516337`, 0.34838960382729967`, 0.9358305797600202]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 373}], {
             RGBColor[
             0.25683371538447886`, 0.38727889744013877`, 0.937937672188489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 380}], {
             RGBColor[
             0.2309702581422837, 0.36009476404068996`, 0.9364647865601021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 381}], {
             RGBColor[
             0.21898984745913425`, 0.34750259281079, 0.9357825198951262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 390}], {
             RGBColor[
             0.2522635992417797, 0.3824754156120626, 0.9376774108350432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 108}], {
             RGBColor[
             0.2395346657598989, 0.3690964994616095, 0.9369525169040198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 152}], {
             RGBColor[
             0.2398425593336916, 0.3694201151292457, 0.9369700509875596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 154}], {
             RGBColor[
             0.21421417432422896`, 0.3424830575508392, 0.9355105523750686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 180}], {
             RGBColor[
             0.24072957206270523`, 0.3703524217472943, 0.9370205650502591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 198}], {
             RGBColor[
             0.2881120186842996, 0.4160342955793074, 0.9398697816662858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 236}], {
             RGBColor[
             0.23684558512377027`, 0.36627010521547854`, 0.9367993777399305]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 262}], {
             RGBColor[
             0.2185336488556363, 0.3470230991538516, 0.9357565400595423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 267}], {
             RGBColor[
             0.23945129119348169`, 0.3690088675060522, 0.9369477688458039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 284}], {
             RGBColor[
             0.24975725951810934`, 0.3798410936513683, 0.9375346784955776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 286}], {
             RGBColor[
             0.20888058953085603`, 0.33687712176419665`, 0.9352068126114177]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 332}], {
             RGBColor[
             0.22563024765380635`, 0.35448207444108004`, 0.936160680862621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 72}], {
             RGBColor[
             0.18087056047954858`, 0.30743680529285733`, 0.9336116828940703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 88}], {
             RGBColor[
             0.1851982028892632, 0.3119854318538441, 0.9338581357271303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 138}], {
             RGBColor[
             0.18058969715831197`, 0.30714160013447456`, 0.9335956881434259]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 157}], {
             RGBColor[
             0.18316059011768585`, 0.3098437716388048, 0.933742096694167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 365}], {
             RGBColor[
             0.17992874679989868`, 0.30644689940110903`, 0.9335580479983027]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 88}], {
             RGBColor[
             0.18714176336881175`, 0.31402823714670136`, 0.9339688186212005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 109}], {
             RGBColor[
             0.18206833162796426`, 0.3086957387129193, 0.933679894189029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 157}], {
             RGBColor[
             0.1851041505972344, 0.3118865769316621, 0.9338527795882372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 181}], {
             RGBColor[
             0.1888688995598306, 0.3158435667902215, 0.9340671764722099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 191}], {
             RGBColor[
             0.19501894918374685`, 0.32230765888062524`, 0.934417412700109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 365}], {
             RGBColor[
             0.18187230727944725`, 0.30848970469396636`, 0.9336687308923729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 370}], {
             RGBColor[
             0.18495091945082137`, 0.31172552128136616`, 0.9338440533011341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 78}], {
             RGBColor[
             0.8568301580726646, 0.357042989472686, 0.19882692230699478`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 99}], {
             RGBColor[
             0.9481261161147958, 0.8682562660194123, 0.6030407890629428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 104}], {
             RGBColor[
             0.8562111877661985, 0.35228531246266953`, 0.19823419564249584`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 112}], {
             RGBColor[
             0.9338615942560703, 0.7754902910821886, 0.2656416901517646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 141}], {
             RGBColor[
             0.887270128859985, 0.5759343748998204, 0.22738563797870492`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 172}], {
             RGBColor[
             0.8594072564997123, 0.3768516972747061, 0.20129475467115204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 177}], {
             RGBColor[
             0.912733918365472, 0.8408075046276462, 0.6264313427993702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 208}], {
             RGBColor[
             0.9618152962983195, 0.8769997675618114, 0.5142240753361885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 225}], {
             RGBColor[
             0.9076627958063523, 0.836763929150959, 0.6259476546026368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 240}], {
             RGBColor[
             0.8646643880160767, 0.41726031379920236`, 0.20632898974830338`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 243}], {
             RGBColor[
             0.9500707567190481, 0.8697065757980069, 0.5997490197634427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 285}], {
             RGBColor[
             0.9624071777351879, 0.8763102692580285, 0.43650448397981056`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 337}], {
             RGBColor[
             0.9623310682876794, 0.8761474788456531, 0.428220440311572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 399}], {
             RGBColor[
             0.9285956897332439, 0.7546127344078406, 0.2614046197660328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 86}], {
             RGBColor[
             0.6370413534700665, 0.7120367862892685, 0.9671058051428245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 91}], {
             RGBColor[
             0.6781789401773193, 0.7465825501677249, 0.9700269954109155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 95}], {
             RGBColor[
             0.7112349833542422, 0.7734189351765257, 0.9726292882180788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 104}], {
             RGBColor[
             0.833692765834374, 0.39596024249218986`, 0.4394911865983113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 112}], {
             RGBColor[
             0.9000839613583336, 0.841002686126469, 0.6275271765854877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 141}], {
             RGBColor[
             0.8647517069281606, 0.6196093049293407, 0.46864262893452036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 148}], {
             RGBColor[
             0.5985191344063026, 0.6786707763192633, 0.9646512034079422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 172}], {
             RGBColor[
             0.8368888345678879, 0.4205266273042264, 0.4425517456269674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 179}], {
             RGBColor[
             0.6585040630153561, 0.7306095985445278, 0.968478117009276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 240}], {
             RGBColor[
             0.8421459660842523, 0.4609352438287227, 0.4475859807041188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 263}], {
             RGBColor[
             0.627506347078178, 0.7037780429959705, 0.9664982429670084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 279}], {
             RGBColor[
             0.7676471267223055, 0.8187592045069678, 0.9773831565887533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 285}], {
             RGBColor[
             0.9286295448374513, 0.9418226643023089, 0.7983899704135337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 399}], {
             RGBColor[
             0.8948180568355072, 0.820125129452121, 0.6232901061997559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 105}], {
             RGBColor[
             0.21372122175088312`, 0.34196493314125437`, 0.9354824794552745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 132}], {
             RGBColor[
             0.28812004710636396`, 0.4155836677571048, 0.9398870475355221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 202}], {
             RGBColor[
             0.23066301686818202`, 0.3597718339813871, 0.9364472896240648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 215}], {
             RGBColor[
             0.20048155521420025`, 0.3280492041678583, 0.9347285000323418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 218}], {
             RGBColor[
             0.20441362479812614`, 0.3321820586081753, 0.9349524255781707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 229}], {
             RGBColor[
             0.21242485108253378`, 0.34060236537417143`, 0.9354086530635206]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 260}], {
             RGBColor[
             0.22127423884363956`, 0.34990363299468435`, 0.9359126126050195]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 329}], {
             RGBColor[
             0.20420501368883298`, 0.3319627951056, 0.934940545484109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 341}], {
             RGBColor[
             0.2771008643732843, 0.406039405513939, 0.9391849149556509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 349}], {
             RGBColor[
             0.2099761655665867, 0.3380286416412822, 0.935269204045893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 77}], {
             RGBColor[
             0.1883529029244576, 0.3153012216103682, 0.9340377912271741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 103}], {
             RGBColor[
             0.19412197120965846`, 0.32136487815817005`, 0.9343663311314445]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 144}], {
             RGBColor[
             0.19222334020881804`, 0.31936929659612845`, 0.9342582069047196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 145}], {
             RGBColor[
             0.19557703724460856`, 0.3228942448174177, 0.9344491949895577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 200}], {
             RGBColor[
             0.1890554468047247, 0.31603963977238364`, 0.9340778000618348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 207}], {
             RGBColor[
             0.1908268877624048, 0.3179015365347492, 0.9341786810037627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 222}], {
             RGBColor[
             0.21314128516619657`, 0.3413553830206456, 0.9354494529247159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 333}], {
             RGBColor[
             0.19100459551754329`, 0.3180883186527222, 0.9341888011975227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 368}], {
             RGBColor[
             0.18953430680604916`, 0.3165429519952533, 0.9341050704305003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 94}], {
             RGBColor[
             0.18199794707454847`, 0.3086217600846408, 0.9336758858928365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 103}], {
             RGBColor[
             0.18857832587467818`, 0.31553815542369057`, 0.9340506287307058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 145}], {
             RGBColor[
             0.19003339190962826`, 0.3170675220829382, 0.934133492588819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 200}], {
             RGBColor[
             0.1835118014697444, 0.3102129170379042, 0.9337620976610961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 207}], {
             RGBColor[
             0.18528324242742453`, 0.31207481380026975`, 0.9338629786030239]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 254}], {
             RGBColor[
             0.18502833391359902`, 0.3118068887901059, 0.9338484619402648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 333}], {
             RGBColor[
             0.18546095018256298`, 0.31226159591824276`, 0.9338730987967839]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 104}], {
             RGBColor[
             0.8196280933998756, 0.15187570372262318`, 0.16642919044746882`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 172}], {
             RGBColor[
             0.8212261277666325, 0.16415889612864146`, 0.16795946996179692`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 194}], {
             RGBColor[
             0.8781356082516507, 0.43307373314204806`, 0.32654502054624035`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 208}], {
             RGBColor[
             0.8776301441970267, 0.43329624520536353`, 0.36628986629008864`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 217}], {
             RGBColor[
             0.8776482484719079, 0.43203131985281057`, 0.2734989161571625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 230}], {
             RGBColor[
             0.8192044912502568, 0.14861971197700838`, 0.16602354855060375`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 233}], {
             RGBColor[
             0.8664271702758672, 0.42591833001448076`, 0.4290165805257541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 240}], {
             RGBColor[
             0.8238546935248147, 0.18436320439088957`, 0.1704765875003726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 242}], {
             RGBColor[
             0.8307161944426305, 0.2371037071740957, 0.17704716852822983`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 244}], {
             RGBColor[
             0.8648801933259055, 0.4247645971381416, 0.4316352089858322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 264}], {
             RGBColor[
             0.7877222743756765, 0.3640897660872551, 0.4355019064498754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 285}], {
             RGBColor[
             0.8780247318216056, 0.4328365796695082, 0.31447680538583667`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 357}], {
             RGBColor[
             0.8323252154413091, 0.24947134764743728`, 0.17858796885369382`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 385}], {
             RGBColor[
             0.8781001584283712, 0.43299790955458023`, 0.3226865260532199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 100}], {
             RGBColor[
             0.22059571881103596`, 0.3491904654197632, 0.9358739718929432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 137}], {
             RGBColor[
             0.2827537056275888, 0.4121446936308188, 0.939500838618308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 175}], {
             RGBColor[
             0.2563476435480917, 0.3867680051213614, 0.9379099911164857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 213}], {
             RGBColor[
             0.22683120635617676`, 0.355744358182451, 0.9362290736840618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 227}], {
             RGBColor[
             0.21925675873838124`, 0.34778313348843115`, 0.9357977200976195]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[
             0.21942962029019444`, 0.3479648219394422, 0.9358075643072694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 278}], {
             RGBColor[
             0.24460490622546205`, 0.37442564366272924`, 0.937241259597785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 302}], {
             RGBColor[
             0.21120952198211004`, 0.3393249774333106, 0.9353394418691697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 314}], {
             RGBColor[
             0.23185910927542647`, 0.36102900293803986`, 0.9365154053171973]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 352}], {
             RGBColor[
             0.23532317406913467`, 0.3646699546706205, 0.9367126786825744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 379}], {
             RGBColor[
             0.21907288200889707`, 0.34758986738728526`, 0.9357872485898966]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 151}], {
             RGBColor[
             0.18591365690063838`, 0.3127374193822037, 0.9338988797746588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 168}], {
             RGBColor[
             0.18200651498987047`, 0.3086307655068815, 0.933676373822939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 265}], {
             RGBColor[
             0.18489536415726843`, 0.31166712914543293`, 0.933840889509353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 304}], {
             RGBColor[
             0.18034926344630414`, 0.30688888905877654`, 0.9335819957992169]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 378}], {
             RGBColor[
             0.18531329630253898`, 0.3121064023285408, 0.9338646901267509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 192}], {
             RGBColor[
             0.1805894919591846, 0.3071413844571813, 0.9335956764576392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 271}], {
             RGBColor[
             0.1793288256722832, 0.3058163442587888, 0.9335238833775887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 287}], {
             RGBColor[
             0.1847451216726243, 0.31150921476814825`, 0.9338323334221164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 292}], {
             RGBColor[
             0.18697166352319156`, 0.31384945142400145`, 0.9339591316866327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 374}], {
             RGBColor[
             0.1848884604275577, 0.3116598728877852, 0.9338404963521592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 382}], {
             RGBColor[
             0.18072466475425025`, 0.3072834596352455, 0.9336033743483478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 384}], {
             RGBColor[
             0.18455785037421688`, 0.3113123807598359, 0.9338216685987151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 101}], {
             RGBColor[
             0.181913405203708, 0.30853290121812327`, 0.9336710713583607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 136}], {
             RGBColor[
             0.18265801399513343`, 0.30931553226883557`, 0.9337134757274823]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 259}], {
             RGBColor[
             0.1834817429881715, 0.31018132366795326`, 0.9337603858750381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 331}], {
             RGBColor[
             0.18993705205367367`, 0.31696626278603024`, 0.9341280061765445]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 335}], {
             RGBColor[
             0.18011477786530028`, 0.30664242984589696`, 0.933568642192269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 120}], {
             RGBColor[
             0.7316668327109251, 0.7891725193318362, 0.9665740024152043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 187}], {
             RGBColor[
             0.6899774075909928, 0.7548276258988081, 0.9634300825559947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 206}], {
             RGBColor[
             0.8376738526720509, 0.8738864473115988, 0.9758404514260404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 217}], {
             RGBColor[
             0.9690520396764782, 0.9730561345189551, 0.7324860448307533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 220}], {
             RGBColor[
             0.790428504618827, 0.8368778917698232, 0.9711999364788909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 230}], {
             RGBColor[
             0.8601703747775189, 0.411075832295422, 0.43572184164473515`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 244}], {
             RGBColor[
             0.9498999569574745, 0.9621560504469515, 0.9696904840737579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 245}], {
             RGBColor[
             0.860898200693226, 0.41667022121889674`, 0.43641880856357806`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 321}], {
             RGBColor[
             0.7496980165524652, 0.8038110466699736, 0.967993483257613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 328}], {
             RGBColor[
             0.9072826236616158, 0.729489427357416, 0.5953860262532737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 364}], {
             RGBColor[
             0.8601295771796166, 0.41076224408032325`, 0.4356827738189095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 102}], {
             RGBColor[
             0.3081546083900806, 0.43843821536979977`, 0.9409621908941581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 163}], {
             RGBColor[
             0.3028162711208553, 0.4328272844297121, 0.940658180484038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 167}], {
             RGBColor[
             0.32454610124482625`, 0.4555272535620894, 0.9419007684798394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 174}], {
             RGBColor[
             0.3414171398675645, 0.4701400992540484, 0.9429757761424066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 183}], {
             RGBColor[
             0.3444123638438444, 0.47273441171796776`, 0.9431666291656026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 189}], {
             RGBColor[
             0.30274052812538393`, 0.4327476737390883, 0.9406538670324976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 222}], {
             RGBColor[
             0.2856119220562171, 0.4147444227440439, 0.9396784182563604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 226}], {
             RGBColor[
             0.39203908397867687`, 0.5139862829102032, 0.9462013616579391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 234}], {
             RGBColor[
             0.5622802808581155, 0.6502189334159502, 0.961044291025931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 238}], {
             RGBColor[
             0.3144100017377778, 0.44501303039307516`, 0.9413184262912844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 246}], {
             RGBColor[
             0.6295415881560444, 0.703574353083331, 0.9675332208830456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 269}], {
             RGBColor[
             0.5412096627237364, 0.6337584063867442, 0.9589441687264177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 272}], {
             RGBColor[
             0.5398855520007457, 0.6327240010263296, 0.9588121937440683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 395}], {
             RGBColor[
             0.4037383718237736, 0.5237036190763635, 0.9470617716812872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 88}], {
             RGBColor[
             0.21610734049788477`, 0.34447289523301966`, 0.9356183653879699]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 162}], {
             RGBColor[
             0.2565370723370653, 0.38696710678905155`, 0.9379207788057828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 181}], {
             RGBColor[
             0.2178344766889036, 0.34628822487653976`, 0.9357167232389794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 191}], {
             RGBColor[
             0.22398452631281984`, 0.35275231696694354`, 0.9360669594668783]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 211}], {
             RGBColor[
             0.231317411938528, 0.36045964469136466`, 0.9364845564552302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 214}], {
             RGBColor[
             0.2402451657445982, 0.3698432799938294, 0.9369929788270578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 263}], {
             RGBColor[
             0.31634895902864796`, 0.44214016934946804`, 0.941608656513351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 307}], {
             RGBColor[
             0.294549891018896, 0.4232589122924366, 0.9402196391759287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 312}], {
             RGBColor[
             0.27182714160879756`, 0.40303793904002655`, 0.9387915256311776]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 340}], {
             RGBColor[
             0.22184000451345684`, 0.35049828858527765`, 0.9359448321229403]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 348}], {
             RGBColor[
             0.28694246093137055`, 0.4166697387111759, 0.9397349004577378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 91}], {
             RGBColor[
             0.45216024233108254`, 0.5649746624056373, 0.950332168324746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 93}], {
             RGBColor[
             0.32267144519324537`, 0.4470223501983363, 0.9420332704147207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 95}], {
             RGBColor[
             0.48521628550800544`, 0.5918110474144382, 0.9529344611319093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 125}], {
             RGBColor[
             0.3362672755569396, 0.46131242993601224`, 0.9428075328407044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 148}], {
             RGBColor[
             0.37250043656006593`, 0.49706288855717573`, 0.9449563763217728]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 162}], {
             RGBColor[
             0.3416757625403587, 0.46699709267346645`, 0.9431155381732708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 179}], {
             RGBColor[
             0.4324853651691194, 0.5490017107824403, 0.9487832899231066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 214}], {
             RGBColor[
             0.32538385594789154`, 0.4498732658782442, 0.9421877381945456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 263}], {
             RGBColor[
             0.4014876492319413, 0.5221701552338829, 0.9468034158808389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 264}], {
             RGBColor[
             0.5671571608223211, 0.6570945561668415, 0.9602327949234224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 285}], {
             RGBColor[
             0.7026108469912147, 0.7602147765402214, 0.7786951433273641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 119}], {
             RGBColor[
             0.19029746556308325`, 0.3173450802359561, 0.9341485311927212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 127}], {
             RGBColor[
             0.19649156208518143`, 0.3238554684090837, 0.93450127582631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 129}], {
             RGBColor[
             0.1936336407966272, 0.32085161193213774`, 0.9343385214368426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 216}], {
             RGBColor[
             0.198944806635749, 0.32643398397641854`, 0.9346409844742148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 231}], {
             RGBColor[
             0.19018595982878306`, 0.3172278806393347, 0.9341421811061108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 235}], {
             RGBColor[
             0.1948464738725398, 0.3221263763929803, 0.9344075904862901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 298}], {
             RGBColor[
             0.19758831891525655`, 0.325008229375892, 0.9345637345052766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 313}], {
             RGBColor[
             0.2082730893529932, 0.33623860055952687`, 0.9351722163750043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 317}], {
             RGBColor[
             0.19676650353045996`, 0.3241444493003659, 0.9345169333348793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 361}], {
             RGBColor[
             0.20790747959893147`, 0.33585432152701067`, 0.9351513954403816]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 393}], {
             RGBColor[
             0.1907711086239872, 0.3178429091236707, 0.9341755044643476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 396}], {
             RGBColor[
             0.198868412851103, 0.3263536892651099, 0.9346366339611938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 109}], {
             RGBColor[
             0.18639597403767888`, 0.31324436527390603`, 0.9339263470220889]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 157}], {
             RGBColor[
             0.189431793006949, 0.31643520349264886`, 0.9340992324212971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 181}], {
             RGBColor[
             0.19319654196954522`, 0.3203921933512083, 0.9343136293052701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 191}], {
             RGBColor[
             0.19934659159346146`, 0.326856285441612, 0.9346638655331689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 365}], {
             RGBColor[
             0.18619994968916187`, 0.3130383312549531, 0.9339151837254329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 370}], {
             RGBColor[
             0.189278561860536, 0.3162741478423529, 0.9340905061341941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 128}], {
             RGBColor[
             0.1919283928758168, 0.31905928824840313`, 0.9342414100904406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 133}], {
             RGBColor[
             0.1875161010871107, 0.31442168982301577`, 0.9339901366004746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 155}], {
             RGBColor[
             0.19816316122321598`, 0.3256124250886648, 0.9345964709243118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 170}], {
             RGBColor[
             0.21045471282523004`, 0.33853162515176505`, 0.9352964566043255]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 171}], {
             RGBColor[
             0.18910388505940673`, 0.3160905514492172, 0.934080558548781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 199}], {
             RGBColor[
             0.18786740786844439`, 0.3147909355243339, 0.9340101430019597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 299}], {
             RGBColor[
             0.18845360021131413`, 0.3154070608434312, 0.9340435257886923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 306}], {
             RGBColor[
             0.1959786892882613, 0.3233164065815071, 0.9344720684792528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 342}], {
             RGBColor[
             0.18647972709604152`, 0.31333239504849575`, 0.9339311166348612]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 353}], {
             RGBColor[
             0.18963294311823536`, 0.31664662501326446`, 0.93411068762256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 121}], {
             RGBColor[
             0.4596424243656251, 0.5683306378036415, 0.9516722943059467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 122}], {
             RGBColor[
             0.6031707449782447, 0.6887202091625689, 0.9619029570133792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.7990367806379581, 0.841477411935373, 0.8913793888944332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 178}], {
             RGBColor[
             0.5250344578406001, 0.6249699305004974, 0.9558390168550672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 190}], {
             RGBColor[
             0.7822989919455827, 0.8299086268722369, 0.9606532016549456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 212}], {
             RGBColor[
             0.5128575453871849, 0.6144229009627645, 0.9550631147611566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 221}], {
             RGBColor[
             0.755343522572024, 0.6711176068414135, 0.6012544985481333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 268}], {
             RGBColor[
             0.6438707815800897, 0.7211954799278018, 0.9654945731092558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 274}], {
             RGBColor[
             0.5507285778663977, 0.6461452954084659, 0.9577745175163469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 295}], {
             RGBColor[
             0.5187067634857201, 0.6194891996894659, 0.9554358217661347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 319}], {
             RGBColor[
             0.530870221387825, 0.6300233870103961, 0.956211194950797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 324}], {
             RGBColor[
             0.6207541500572831, 0.7029952095291041, 0.9632871870713362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 351}], {
             RGBColor[
             0.7590840463718008, 0.8119268218437792, 0.9767853326782896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 373}], {
             RGBColor[
             0.44011491122134366`, 0.5480057067490964, 0.9505529184695845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 95}], {
             RGBColor[
             0.5263538722152581, 0.6263568112928946, 0.9558556514000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 112}], {
             RGBColor[
             0.7152028502193496, 0.6939405622428378, 0.6107535397674092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 125}], {
             RGBColor[
             0.37740486226419223`, 0.49585819381446866`, 0.9457287231087954]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 148}], {
             RGBColor[
             0.4136380232673186, 0.5316086524356322, 0.9478775665898638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 179}], {
             RGBColor[
             0.47362295187637204`, 0.5835474746608966, 0.9517044801911976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 257}], {
             RGBColor[
             0.408201112318213, 0.5268994734386068, 0.9475311314318583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 263}], {
             RGBColor[
             0.44262523593919395`, 0.5567159191123393, 0.94972460614893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 279}], {
             RGBColor[
             0.5827660155833214, 0.6716970806233367, 0.9606095197706748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 285}], {
             RGBColor[
             0.7437484336984672, 0.7947605404186777, 0.7816163335954551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 288}], {
             RGBColor[
             0.3993345066316525, 0.518907640464429, 0.9469775839135208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 135}], {
             RGBColor[
             0.746116355711272, 0.7971097200029147, 0.816782693533676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 165}], {
             RGBColor[
             0.6970699985324673, 0.761675381939551, 0.9717947555325273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 182}], {
             RGBColor[
             0.4229610876060558, 0.5395726978389508, 0.9485023279906137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 256}], {
             RGBColor[
             0.42434961842059, 0.5407753734409124, 0.9485908039462863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 281}], {
             RGBColor[
             0.46303919301965735`, 0.5742863383640635, 0.9510560694278913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 311}], {
             RGBColor[
             0.40006723340595274`, 0.5191882673765618, 0.947063870354397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 386}], {
             RGBColor[
             0.6290755332185833, 0.7079371215448762, 0.9651823556220622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 98}], {
             RGBColor[
             0.21766781953393055`, 0.3461130576399892, 0.9357072323605509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 125}], {
             RGBColor[
             0.24791606512635506`, 0.37790588160716765`, 0.9374298251987702]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 148}], {
             RGBColor[
             0.2841492261294814, 0.41365634022833114`, 0.9395786686798384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 162}], {
             RGBColor[
             0.2533245521097741, 0.3835905443446218, 0.9377378305313364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 214}], {
             RGBColor[
             0.23703264551730702`, 0.36646671754939963`, 0.9368100305526114]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 248}], {
             RGBColor[
             0.22615954726936105`, 0.355038401896562, 0.9361908236926982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 276}], {
             RGBColor[
             0.22858867995178067`, 0.3575915743616926, 0.9363291592053822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 288}], {
             RGBColor[
             0.2698457094938153, 0.4009553282571281, 0.9386786860034955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 290}], {
             RGBColor[
             0.21626873884937514`, 0.3446425351336826, 0.9356275567853198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 103}], {
             RGBColor[
             0.18776701535974932`, 0.31468541663244265`, 0.934004425797107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 145}], {
             RGBColor[
             0.18922208139469943`, 0.31621478329169034`, 0.9340872896552201]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 207}], {
             RGBColor[
             0.18447193191249567`, 0.3112220750090219, 0.933816775669425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 254}], {
             RGBColor[
             0.18421702339867016`, 0.31095414999885795`, 0.9338022590066659]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 125}], {
             RGBColor[
             0.41046090544111513`, 0.5226945788232695, 0.9483310159159588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 162}], {
             RGBColor[
             0.41586939242453425`, 0.5283792415607237, 0.9486390212485251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 233}], {
             RGBColor[
             0.7594081345567827, 0.8112195509449376, 0.9560282891124947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 263}], {
             RGBColor[
             0.47568127911611685`, 0.5835523041211401, 0.9523268989560933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 264}], {
             RGBColor[
             0.6413507907064967, 0.7184767050540989, 0.9657562779986768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 285}], {
             RGBColor[
             0.7768044768753901, 0.8215969254274786, 0.7842186264026185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 312}], {
             RGBColor[
             0.43115946169626646`, 0.5444500738116986, 0.9495097680739197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 173}], {
             RGBColor[
             0.515339475447038, 0.6087263479834802, 0.9574676673643785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 201}], {
             RGBColor[
             0.8486214444306401, 0.8823678065342169, 0.9733384742305298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 209}], {
             RGBColor[
             0.5415208134624869, 0.6338317942327045, 0.9590470002598491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 223}], {
             RGBColor[
             0.8390506368021915, 0.7815052608012159, 0.618996491222558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 245}], {
             RGBColor[
             0.795286411691943, 0.364900459678807, 0.43562237712445073`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 323}], {
             RGBColor[
             0.5734450946307983, 0.6614830020196698, 0.9610811872263605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 109}], {
             RGBColor[
             0.18710606140703578`, 0.3139907121212397, 0.9339667854472937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 181}], {
             RGBColor[
             0.19390662933890207`, 0.32113854019854193`, 0.9343540677304747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 191}], {
             RGBColor[
             0.2000566789628183, 0.32760263228894565`, 0.9347043039583738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 193}], {
             RGBColor[
             0.1899172543843397, 0.31694545418031556`, 0.9341268787285638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 211}], {
             RGBColor[
             0.20738956458852648`, 0.33530996001336677`, 0.9351219009467256]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 214}], {
             RGBColor[
             0.21631731839459667`, 0.3446935953158315, 0.9356303233185532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 248}], {
             RGBColor[
             0.2054442201466507, 0.3332652796629938, 0.9350111164586401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 305}], {
             RGBColor[
             0.18756138502713113`, 0.3144692861151448, 0.9339927154538672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 334}], {
             RGBColor[
             0.1889352663956901, 0.3159133225426103, 0.9340709559653313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 340}], {
             RGBColor[
             0.1979121571634553, 0.3253486039072797, 0.9345821766144358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 360}], {
             RGBColor[
             0.189069412661027, 0.31605431877284385`, 0.9340785953966906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 370}], {
             RGBColor[
             0.18998864922989284`, 0.31702049468968657`, 0.9341309445593988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 125}], {
             RGBColor[
             0.23126364989762477`, 0.3604031373776651, 0.9364814947865346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 139}], {
             RGBColor[
             0.19453754132088114`, 0.32180166869373195`, 0.9343899972344978]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 193}], {
             RGBColor[
             0.1939801662783198, 0.32121583218438116`, 0.9343582555503864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 204}], {
             RGBColor[
             0.19732498772567109`, 0.3247314515994759, 0.9345487381835933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 248}], {
             RGBColor[
             0.2095071320406308, 0.3375356576670594, 0.9352424932804627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 276}], {
             RGBColor[
             0.21193626472305038`, 0.34008883013219005`, 0.9353808287931467]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 290}], {
             RGBColor[
             0.19961632362064485`, 0.32713979090418005`, 0.9346792263730843]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 318}], {
             RGBColor[
             0.1977029240139366, 0.3251286866009877, 0.9345702610961033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 141}], {
             RGBColor[
             0.8989439948619978, 0.6463586296042318, 0.4540597244463016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 169}], {
             RGBColor[
             0.9307128082989145, 0.9468171296861931, 0.9664871194315787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 177}], {
             RGBColor[
             0.9302447173684912, 0.9464438866842635, 0.9664424725007652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 197}], {
             RGBColor[
             0.9649742133445314, 0.9733984061785892, 0.9441737000062027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 225}], {
             RGBColor[
             0.9251735948093716, 0.9424003112075763, 0.9659587843040318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 243}], {
             RGBColor[
             0.9675815557220673, 0.9753429578546242, 0.9397601494648378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 252}], {
             RGBColor[
             0.6676015641481373, 0.7342070299092066, 0.9439106644834332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 300}], {
             RGBColor[
             0.9401681906865148, 0.9543565949425481, 0.9673889822446275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 337}], {
             RGBColor[
             0.9798418672906987, 0.9817838609022704, 0.7682315700129669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 367}], {
             RGBColor[
             0.6703595369678017, 0.7365958473458555, 0.9440864000727226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 398}], {
             RGBColor[
             0.695865579228825, 0.7586878991813948, 0.9457116225314874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 146}], {
             RGBColor[
             0.1981449486568544, 0.3255932825266753, 0.9345954337456006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 175}], {
             RGBColor[
             0.2458994336441635, 0.3757862740575634, 0.9373149810191983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 213}], {
             RGBColor[
             0.21638299645224862`, 0.344762627118653, 0.9356340635867745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 227}], {
             RGBColor[
             0.20880854883445307`, 0.33680140242463313`, 0.9352027100003322]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 278}], {
             RGBColor[
             0.23415669632153385`, 0.3634439125989312, 0.9366462495004977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 302}], {
             RGBColor[
             0.20076131207818187`, 0.3283432463695126, 0.9347444317718824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 314}], {
             RGBColor[
             0.22141089937149833`, 0.35004727187424184`, 0.93592039521991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 352}], {
             RGBColor[
             0.2248749641652065, 0.3536882236068225, 0.936117668585287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 377}], {
             RGBColor[
             0.19744186238260558`, 0.3248542942741953, 0.9345553940224051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 136}], {
             RGBColor[
             0.18384486237801373`, 0.31056298516977654`, 0.9337810649871026]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 301}], {
             RGBColor[
             0.1828984857165501, 0.3095682832948322, 0.9337271702362709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 335}], {
             RGBColor[
             0.18130162624818058`, 0.3078898827468379, 0.9336362314518891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 394}], {
             RGBColor[
             0.18176625720560394`, 0.308378239342394, 0.9336626914975545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 163}], {
             RGBColor[
             0.272133057471457, 0.4033594760078676, 0.938808947086994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 167}], {
             RGBColor[
             0.29386288759542795`, 0.42605944514024496`, 0.9400515350827954]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 174}], {
             RGBColor[
             0.3107339262181662, 0.44067229083220405`, 0.9411265427453626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 189}], {
             RGBColor[
             0.27205731447598563`, 0.4032798653172439, 0.9388046336354536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 222}], {
             RGBColor[
             0.2549287084068188, 0.3852766143221994, 0.9378291848593165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 226}], {
             RGBColor[
             0.3613558703292786, 0.48451847448835883`, 0.9443521282608951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 395}], {
             RGBColor[
             0.3730551581743753, 0.49423581065451916`, 0.9452125382842432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 145}], {
             RGBColor[
             0.1958024601948291, 0.32313117863074003`, 0.9344620324930895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 200}], {
             RGBColor[
             0.18928086975494526`, 0.31627657358570604`, 0.9340906375653665]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 207}], {
             RGBColor[
             0.19105231071262538`, 0.3181384703480716, 0.9341915185072943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 222}], {
             RGBColor[
             0.21336670811641717`, 0.34159231683396796`, 0.9354622904282476]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 254}], {
             RGBColor[
             0.19079740219879987`, 0.3178705453379077, 0.9341770018445352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 333}], {
             RGBColor[
             0.19123001846776383`, 0.3183252524660446, 0.9342016387010543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 112}], {
             RGBColor[
             0.8583753725290609, 0.36086558387559853`, 0.19997554950264038`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 141}], {
             RGBColor[
             0.8345385936403027, 0.25894255793118215`, 0.18041218495107442`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 172}], {
             RGBColor[
             0.8206071574601663, 0.15940121911862504`, 0.16736674329729798`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 208}], {
             RGBColor[
             0.8770111738905605, 0.4285385681953471, 0.3656971396255897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 240}], {
             RGBColor[
             0.8232357232183486, 0.17960552738087315`, 0.16988386083587365`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 242}], {
             RGBColor[
             0.8300972241361643, 0.2323460301640793, 0.17645444186373088`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 243}], {
             RGBColor[
             0.8691814808377128, 0.4236764403528107, 0.42271376924375914`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 285}], {
             RGBColor[
             0.8774057615151394, 0.4280789026594918, 0.3138840787213377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 337}], {
             RGBColor[
             0.877355021883467, 0.4279703757179083, 0.30836138294251203`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 357}], {
             RGBColor[
             0.8317062451348429, 0.24471367063742083`, 0.17799524218919488`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 399}], {
             RGBColor[
             0.8548647695138434, 0.3469472127593665, 0.19715083591215254`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 114}], {
             RGBColor[
             0.22538318625918102`, 0.3542223972507317, 0.9361466110816916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 171}], {
             RGBColor[
             0.19921926143757313`, 0.32672245337457523`, 0.9346566142691592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 202}], {
             RGBColor[
             0.2264175602160962, 0.35530958986254624`, 0.9362055171483188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 218}], {
             RGBColor[
             0.20016816814604027`, 0.3277198144893344, 0.9347106531024247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 229}], {
             RGBColor[
             0.20817939443044792`, 0.33614012125533055`, 0.9351668805877746]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 261}], {
             RGBColor[
             0.23472290345765154`, 0.3640390321985968, 0.9366784941592712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 349}], {
             RGBColor[
             0.20573070891450085`, 0.3335663975224413, 0.935027431570147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 353}], {
             RGBColor[
             0.19974831949640176`, 0.32727852693862247`, 0.9346867433429382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.2877186940288704, 0.4160544664052851, 0.9398315069221266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 150}], {
             RGBColor[
             0.2101822963835033, 0.33824529819931026`, 0.9352809428909732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 158}], {
             RGBColor[
             0.2827874224549232, 0.411783246820848, 0.939517290657987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 241}], {
             RGBColor[
             0.24501597193591163`, 0.37485769978748307`, 0.9372646691818778]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 270}], {
             RGBColor[
             0.2929589759941193, 0.42059333525935383`, 0.9401654130551529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 292}], {
             RGBColor[
             0.21060209943900177`, 0.3386865378276902, 0.9353048500539408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 310}], {
             RGBColor[
             0.2532088981789974, 0.38346898473049273`, 0.9377312442110733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 320}], {
             RGBColor[
             0.21130568150236095`, 0.33942604718596003`, 0.9353449180115927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 347}], {
             RGBColor[
             0.21233497992474068`, 0.3405079050891704, 0.9354035350340366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 374}], {
             RGBColor[
             0.2085188963433679, 0.336496959291474, 0.9351862147194673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 384}], {
             RGBColor[
             0.2081882862900271, 0.33614946716352473`, 0.9351673869660233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 389}], {
             RGBColor[
             0.21473367973065993`, 0.34302909067154336`, 0.9355401374394254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 390}], {
             RGBColor[
             0.24476481400135702`, 0.3745937168739334, 0.9372503661090598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 158}], {
             RGBColor[
             0.34368740964077826`, 0.4721064928245296, 0.9431204357248351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 190}], {
             RGBColor[
             0.6524189980541504, 0.7216233648288316, 0.9512140557147148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 212}], {
             RGBColor[
             0.3829775514957524, 0.5061376389193594, 0.9456239688209257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 241}], {
             RGBColor[
             0.30591595912176667`, 0.43518094579116473`, 0.9408678142487259]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 268}], {
             RGBColor[
             0.5139907876886572, 0.6129102178843966, 0.9560554271690249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 270}], {
             RGBColor[
             0.35385896317997434`, 0.4809165812630355, 0.943768558122001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 295}], {
             RGBColor[
             0.38882676959428764`, 0.5112039376460608, 0.945996675825904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 310}], {
             RGBColor[
             0.3141088853648525, 0.4437922307341744, 0.9413343892779213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 324}], {
             RGBColor[
             0.4908741561658506, 0.5947099474856988, 0.9538480411311054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 346}], {
             RGBColor[
             0.3498425512041035, 0.47743776708027175`, 0.9435126359024721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 351}], {
             RGBColor[
             0.6292040524803684, 0.703641559800374, 0.9673461867380587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 373}], {
             RGBColor[
             0.31023491732991126`, 0.43972044470569116`, 0.9411137725293536]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 390}], {
             RGBColor[
             0.30566480118721207`, 0.43491696287761505`, 0.9408535111759078]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 152}], {
             RGBColor[
             0.2564614085339687, 0.38688757933463486`, 0.9379164698641311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 154}], {
             RGBColor[
             0.23083302352450608`, 0.3599505217562283, 0.9364569712516402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 180}], {
             RGBColor[
             0.25734842126298235`, 0.38781988595268346`, 0.9379669839268308]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 198}], {
             RGBColor[
             0.3047308678845767, 0.4335017597846965, 0.9408162005428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 205}], {
             RGBColor[
             0.3030856171044626, 0.43207672625167026`, 0.9407113666179867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 236}], {
             RGBColor[
             0.2534644343240474, 0.3837375694208677, 0.9377457966165021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 262}], {
             RGBColor[
             0.23515249805591343`, 0.36449056335924074`, 0.936702958936114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 267}], {
             RGBColor[
             0.2560701403937588, 0.38647633171144136`, 0.9378941877223754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 284}], {
             RGBColor[
             0.26637610871838646`, 0.39730855785675745`, 0.9384810973721491]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 286}], {
             RGBColor[
             0.22549943873113315`, 0.3543445859695858, 0.9361532314879892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 332}], {
             RGBColor[
             0.24224909685408347`, 0.3719495386464692, 0.9371070997391926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 367}], {
             RGBColor[
             0.31561783688898226`, 0.44293150514134, 0.9415099085808494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 398}], {
             RGBColor[
             0.34112387915000547`, 0.4650235569768793, 0.9431351310396142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 157}], {
             RGBColor[
             0.18435836126610156`, 0.3111027050588667, 0.9338103079891256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 181}], {
             RGBColor[
             0.18812311022869774`, 0.31505969491742614`, 0.9340247048730984]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 191}], {
             RGBColor[
             0.19427315985261398`, 0.3215237870078299, 0.9343749411009974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 305}], {
             RGBColor[
             0.1817778659169268, 0.3083904408340291, 0.9336633525964908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 334}], {
             RGBColor[
             0.18315174728548578`, 0.30983447726149455`, 0.9337415931079549]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 340}], {
             RGBColor[
             0.19212863805325098`, 0.319269758626164, 0.9342528137570594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 360}], {
             RGBColor[
             0.18328589355082267`, 0.3099754734917281, 0.9337492325393142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 365}], {
             RGBColor[
             0.1811265179483144, 0.30770583282117103`, 0.9336262592932614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 370}], {
             RGBColor[
             0.1842051301196885, 0.31094164940857083`, 0.9338015817020224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 227}], {
             RGBColor[
             0.1954518354139104, 0.3227626497550994, 0.934442064930519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 237}], {
             RGBColor[
             0.19038343508665123`, 0.3174354396560086, 0.9341534270299079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 251}], {
             RGBColor[
             0.18685400772656674`, 0.3137257877219404, 0.9339524313630709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 308}], {
             RGBColor[
             0.1924672891129, 0.3196257023615725, 0.9342720994339171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 375}], {
             RGBColor[
             0.18201536929507323`, 0.30864007194304494`, 0.9336768780625215]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 116}], {
             RGBColor[
             0.1862942905711151, 0.31313748950344333`, 0.9339205562990953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 151}], {
             RGBColor[
             0.1906348725141942, 0.31769971633440997`, 0.9341677460194382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 154}], {
             RGBColor[
             0.19738148096805996`, 0.3247908295791051, 0.934551955390173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 286}], {
             RGBColor[
             0.1920478961746871, 0.3191848937924626, 0.934248215626522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 291}], {
             RGBColor[
             0.18821279065920096`, 0.31515395473595276`, 0.9340298120409453]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 304}], {
             RGBColor[
             0.18507047905985996`, 0.31185118601098283`, 0.9338508620439963]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 383}], {
             RGBColor[
             0.1988021595169091, 0.3262840528101681, 0.9346328609318244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 141}], {
             RGBColor[
             0.8894343136228475, 0.5845146463127493, 0.22912699183884946`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 172}], {
             RGBColor[
             0.8615714412625748, 0.3854319686876351, 0.20303610853129658`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 179}], {
             RGBColor[
             0.6955279730573865, 0.6779676106196408, 0.6092046613657698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 240}], {
             RGBColor[
             0.8668285727789392, 0.4258405852121313, 0.20807034360844792`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 279}], {
             RGBColor[
             0.8046710367643358, 0.7661172165820809, 0.618109700945247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 285}], {
             RGBColor[
             0.9656534548794817, 0.8891806763774219, 0.4391165147700274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 337}], {
             RGBColor[
             0.9655773454319732, 0.8890178859650467, 0.43083247110178885`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 399}], {
             RGBColor[
             0.9318419668775375, 0.7674831415272341, 0.2640166505562497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 124}], {
             RGBColor[
             0.3086276211264817, 0.4416266325643382, 0.9408905883938774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 149}], {
             RGBColor[
             0.26206453775242544`, 0.39277682340214404`, 0.9382355597840353]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 210}], {
             RGBColor[
             0.3065896783902691, 0.43957556926948627`, 0.9407712006743179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 249}], {
             RGBColor[
             0.3083010067824331, 0.4413437356356376, 0.9408697768166884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 266}], {
             RGBColor[
             0.2701389734664643, 0.40126356728639195`, 0.9386953869528927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 293}], {
             RGBColor[
             0.32820995463660485`, 0.4585878656141067, 0.9421383573691648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 315}], {
             RGBColor[
             0.26318579596449465`, 0.3939553368749055, 0.9382994137804598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 316}], {
             RGBColor[
             0.2709397029977173, 0.40210518479292345`, 0.9387409873151243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 387}], {
             RGBColor[
             0.4208258242811829, 0.5366129491256768, 0.9486460027249637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 397}], {
             RGBColor[
             0.2602244815922864, 0.3908428077115391, 0.9381307713078346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 128}], {
             RGBColor[
             0.21795119041436695`, 0.34641089840207934`, 0.9357233699129821]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 155}], {
             RGBColor[
             0.2241859587617661, 0.352964035242341, 0.9360784307468533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 170}], {
             RGBColor[
             0.23647751036378017`, 0.3658832353054412, 0.9367784164268669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 187}], {
             RGBColor[
             0.33810546577905015`, 0.4610349816709624, 0.9429931157731941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 202}], {
             RGBColor[
             0.2423249813764799, 0.37202929809086444`, 0.937111421250482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 261}], {
             RGBColor[
             0.25063032461803525`, 0.380758740426915, 0.9375843982614342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 306}], {
             RGBColor[
             0.2220014868268114, 0.35066801673518333`, 0.9359540283017942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 353}], {
             RGBColor[
             0.2156557406567855, 0.3439982351669406, 0.9355926474451014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 122}], {
             RGBColor[
             0.7757263022490958, 0.5468964399598267, 0.4596563040800477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 166}], {
             RGBColor[
             0.9063036593555713, 0.6487345751416961, 0.4126405920007503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 169}], {
             RGBColor[
             0.875001595756134, 0.6253129164488254, 0.46913275406054683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 197}], {
             RGBColor[
             0.897842532453212, 0.6430337674437561, 0.45425714111029625`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 221}], {
             RGBColor[
             0.8771748206449487, 0.5351613717457232, 0.21922399843655038`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 239}], {
             RGBColor[
             0.8523263340305828, 0.3902002184370166, 0.1972316827098783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 300}], {
             RGBColor[
             0.8813051840145343, 0.6303392266197287, 0.46973399593591275`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 350}], {
             RGBColor[
             0.9076888516719018, 0.6493073877623174, 0.38968437055635197`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 392}], {
             RGBColor[
             0.9067666664186966, 0.6489260404610371, 0.40496736674089506`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 151}], {
             RGBColor[
             0.18767873323802545`, 0.31459262652510106`, 0.9339993982608765]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 154}], {
             RGBColor[
             0.19442534169189124`, 0.3216837397697962, 0.9343836076316113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 265}], {
             RGBColor[
             0.18666044049465552`, 0.3135223362883303, 0.9339414079955707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 291}], {
             RGBColor[
             0.1852566513830322, 0.31204686492664385`, 0.9338614642823836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 304}], {
             RGBColor[
             0.18211433978369124`, 0.30874409620167387`, 0.9336825142854346]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 383}], {
             RGBColor[
             0.19584602024074033`, 0.3231769630008592, 0.9344645131732627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 289}], {
             RGBColor[
             0.20615434433043495`, 0.33401166520462483`, 0.935051556980372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 303}], {
             RGBColor[
             0.21968824533158482`, 0.34823665325571823`, 0.9358222926207751]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 376}], {
             RGBColor[
             0.217871456795024, 0.34632709331274647`, 0.9357188292013159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 158}], {
             RGBColor[
             0.28881871360859035`, 0.41812251622929797`, 0.9398607637666927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 164}], {
             RGBColor[
             0.21991695118991147`, 0.3484770376136085, 0.9358353170810669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 173}], {
             RGBColor[
             0.26068055800241224`, 0.3913221729354959, 0.9381567441846866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 209}], {
             RGBColor[
             0.2868618960178613, 0.41642761918472027`, 0.9397360770801573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 241}], {
             RGBColor[
             0.25104726308957875`, 0.38119696919593304`, 0.9376081422905835]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 323}], {
             RGBColor[
             0.3187861771861727, 0.44407882697168544`, 0.9417702640466686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 346}], {
             RGBColor[
             0.2949738551719156, 0.42345379048504006`, 0.9402529639443298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 354}], {
             RGBColor[
             0.22736699671866945`, 0.3563075078245018, 0.9362595861525749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 388}], {
             RGBColor[
             0.2291977478565746, 0.35823174334676655`, 0.936363844721525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 389}], {
             RGBColor[
             0.22076497088432706`, 0.3493683600799934, 0.9358836105481312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 126}], {
             RGBColor[
             0.1845010944888899, 0.3112527267258263, 0.9338184364350084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 127}], {
             RGBColor[
             0.18861006279746526`, 0.31557151294177693`, 0.9340524361015079]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 129}], {
             RGBColor[
             0.18575214150891103`, 0.312567656464831, 0.9338896817120405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 196}], {
             RGBColor[
             0.18607572050979368`, 0.3129077585108523, 0.9339081090574485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 231}], {
             RGBColor[
             0.18230446054106692`, 0.30894392517202796`, 0.9336933413813087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 235}], {
             RGBColor[
             0.18696497458482364`, 0.31384242092567355`, 0.9339587507614879]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 317}], {
             RGBColor[
             0.1888850042427438, 0.31586049383305914`, 0.9340680936100771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 326}], {
             RGBColor[
             0.18721381086797456`, 0.3141039636363968, 0.933972921619693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 327}], {
             RGBColor[
             0.18901152680793626`, 0.3159934770710704, 0.9340752988829915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 336}], {
             RGBColor[
             0.18138462902211405`, 0.30797712392492177`, 0.9336409583370731]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 396}], {
             RGBColor[
             0.19098691356338682`, 0.3180697337978031, 0.9341877942363916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 132}], {
             RGBColor[
             0.4382862950940797, 0.5522789014915227, 0.9496356996104882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 160}], {
             RGBColor[
             0.48896132780643076`, 0.5959998592268796, 0.9529119733307341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 187}], {
             RGBColor[
             0.47660974925846794`, 0.585472751295903, 0.952077636221743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 202}], {
             RGBColor[
             0.38082926485589774`, 0.49646706771580507`, 0.9461959416990309]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 206}], {
             RGBColor[
             0.624306194339526, 0.7045315727086937, 0.9644880050917888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 217}], {
             RGBColor[
             0.7556843813439534, 0.80370125991605, 0.7211335984965017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 220}], {
             RGBColor[
             0.5770608462863022, 0.6675230171669182, 0.9598474901446392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 233}], {
             RGBColor[
             0.7388527640498924, 0.7945317751585553, 0.9544100950493892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 244}], {
             RGBColor[
             0.7365322986249497, 0.7928011758440465, 0.9583380377395063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 307}], {
             RGBColor[
             0.43332684059947457`, 0.5479832712777266, 0.9493196875555654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 321}], {
             RGBColor[
             0.5363303582199404, 0.6344561720670685, 0.9566410369233613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 341}], {
             RGBColor[
             0.42726711236099996`, 0.542734639248357, 0.9489335670306169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 366}], {
             RGBColor[
             0.4563492884558704, 0.567924158469062, 0.9507866575750236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 122}], {
             RGBColor[
             0.4544345003462795, 0.5641026104704333, 0.9512623074498896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 175}], {
             RGBColor[
             0.29627876905743955`, 0.4285384264353338, 0.9401913224925988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 178}], {
             RGBColor[
             0.376298213208635, 0.5003523318083618, 0.9451983672915776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.26676233186552467`, 0.3975147794964234, 0.938510405060175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 274}], {
             RGBColor[
             0.4019923332344326, 0.5215276967163304, 0.9471338679528571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 296}], {
             RGBColor[
             0.27793336964590865`, 0.4092562484883108, 0.9391465791356984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 319}], {
             RGBColor[
             0.3821339767558598, 0.5054057883182604, 0.9455705453873072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 373}], {
             RGBColor[
             0.2913786665893785, 0.4233881080569608, 0.9399122689060947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 166}], {
             RGBColor[
             0.7938288566186125, 0.8372493846021647, 0.890969402038376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 169}], {
             RGBColor[
             0.7468757612194565, 0.8021168965628588, 0.9757076451280708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 175}], {
             RGBColor[
             0.4398070896700592, 0.5489279977942612, 0.9504219852000314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 178}], {
             RGBColor[
             0.5198265338212547, 0.6207419031672892, 0.9554290299990101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 268}], {
             RGBColor[
             0.638662857560744, 0.7169674525945936, 0.9650845862531987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 274}], {
             RGBColor[
             0.5455206538470523, 0.6419172680752578, 0.9573645306602898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 319}], {
             RGBColor[
             0.5256622973684795, 0.6257953596771879, 0.9558012080947398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 351}], {
             RGBColor[
             0.7538761223524553, 0.8076987945105711, 0.9763753458222324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 131}], {
             RGBColor[
             0.21247713876151392`, 0.34065732304000995`, 0.9354116307694857]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 140}], {
             RGBColor[
             0.21869849237699107`, 0.3471963601464784, 0.9357659276542193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 203}], {
             RGBColor[
             0.21872743662810462`, 0.3472267823895703, 0.935767575986501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 232}], {
             RGBColor[
             0.2533953304852037, 0.3836649369048065, 0.9377418612551098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 275}], {
             RGBColor[
             0.22522408057531274`, 0.3540551670891031, 0.9361375502483711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 280}], {
             RGBColor[
             0.23161694690439888`, 0.3607744749321087, 0.9365016145284144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 297}], {
             RGBColor[
             0.20930917766859286`, 0.3373275950710155, 0.9352312200718224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 309}], {
             RGBColor[
             0.2546471876156135, 0.3849807181211936, 0.93781315266673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 322}], {
             RGBColor[
             0.20580146810397543`, 0.3336407699169709, 0.9350314612013086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 325}], {
             RGBColor[
             0.2504184772778667, 0.38053607544050067`, 0.9375723338688118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 339}], {
             RGBColor[
             0.23162280417676506`, 0.3607806312967381, 0.9365019480914105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 149}], {
             RGBColor[
             0.2631665511656537, 0.3938441656371931, 0.9383016477132344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 185}], {
             RGBColor[
             0.35466498690371884`, 0.48161471850061266`, 0.9438199172409392]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 210}], {
             RGBColor[
             0.30769169180349737`, 0.4406429115045353, 0.9408372886035168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 219}], {
             RGBColor[
             0.32342751125618663`, 0.45455838713589725`, 0.9418294929148936]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 249}], {
             RGBColor[
             0.30940302019566135`, 0.4424110778706867, 0.9409358647458874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 266}], {
             RGBColor[
             0.27124098687969256`, 0.402330909521441, 0.9387614748820916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 293}], {
             RGBColor[
             0.3293119680498331, 0.45965520784915576`, 0.9422044452983639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 315}], {
             RGBColor[
             0.2642878093777229, 0.3950226791099546, 0.9383655017096588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 316}], {
             RGBColor[
             0.27204171641094554`, 0.40317252702797246`, 0.9388070752443234]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 338}], {
             RGBColor[
             0.2719649687624893, 0.40309186038336303`, 0.9388027045792817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 387}], {
             RGBColor[
             0.42192783769441117`, 0.5376802913607258, 0.9487120906541628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 397}], {
             RGBColor[
             0.26132649500551464`, 0.3919101499465881, 0.9381968592370336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 148}], {
             RGBColor[
             0.2977450564931756, 0.4279464199660071, 0.9403529311058223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 162}], {
             RGBColor[
             0.2669203824734684, 0.39788062408229774`, 0.9385120929573202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 211}], {
             RGBColor[
             0.24170072207493107`, 0.37137316198461084`, 0.9370758706067677]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 214}], {
             RGBColor[
             0.25062847588100123`, 0.38075679728707557`, 0.9375842929785951]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 248}], {
             RGBColor[
             0.2397553776330553, 0.3693284816342379, 0.936965086118682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 263}], {
             RGBColor[
             0.326732269165051, 0.4530536866427142, 0.9421999706648885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 276}], {
             RGBColor[
             0.2421845103154749, 0.3718816540993685, 0.9371034216313661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 288}], {
             RGBColor[
             0.28344153985750953`, 0.415245407994804, 0.9394529484294792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 196}], {
             RGBColor[
             0.1881608487233165, 0.3150993604680292, 0.9340268540245378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 289}], {
             RGBColor[
             0.1863769520635358, 0.31322437197301883`, 0.933925263748802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 317}], {
             RGBColor[
             0.1909701324562666, 0.31805209579023613`, 0.9341868385771666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 326}], {
             RGBColor[
             0.18929893908149736`, 0.31629556559357375`, 0.9340916665867824]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 327}], {
             RGBColor[
             0.19109665502145906`, 0.31818507902824733`, 0.9341940438500809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 336}], {
             RGBColor[
             0.18346975723563688`, 0.31016872588209876`, 0.9337597033041625]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 376}], {
             RGBColor[
             0.19809406452812484`, 0.3255398000811405, 0.9345925359697458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 129}], {
             RGBColor[
             0.19194623803100921`, 0.3190780446379586, 0.9342424263456293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 216}], {
             RGBColor[
             0.19725740387013102`, 0.32466041668223944`, 0.9345448893830015]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 231}], {
             RGBColor[
             0.1884985570631651, 0.31545431334515556`, 0.9340460860148976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 235}], {
             RGBColor[
             0.19315907110692182`, 0.32035280909880115`, 0.9343114953950769]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 298}], {
             RGBColor[
             0.19590091614963856`, 0.32323466208171286`, 0.9344676394140633]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 313}], {
             RGBColor[
             0.20658568658737522`, 0.3344650332653477, 0.935076121283791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 317}], {
             RGBColor[
             0.19507910076484197`, 0.32237088200618674`, 0.9344208382436661]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 336}], {
             RGBColor[
             0.18757872554421223`, 0.31448751209804937`, 0.933993702970662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 361}], {
             RGBColor[
             0.2062200768333135, 0.33408075423283157`, 0.9350553003491684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 393}], {
             RGBColor[
             0.1890837058583692, 0.31606934182949153`, 0.9340794093731344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 396}], {
             RGBColor[
             0.197181010085485, 0.3245801219709307, 0.9345405388699805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 133}], {
             RGBColor[
             0.19019948162046302`, 0.31724209289972144`, 0.9341429511521433]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 155}], {
             RGBColor[
             0.2008465417565683, 0.32843282816537045`, 0.9347492854759805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 170}], {
             RGBColor[
             0.21313809335858236`, 0.34135202822847077`, 0.9354492711559941]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 171}], {
             RGBColor[
             0.19178726559275905`, 0.3189109545259229, 0.9342333731004496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 199}], {
             RGBColor[
             0.1905507884017967, 0.3176113386010396, 0.9341629575536283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 261}], {
             RGBColor[
             0.22729090761283746`, 0.3562275333499445, 0.9362552529905616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 299}], {
             RGBColor[
             0.19113698074466645`, 0.31822746392013684`, 0.934196340340361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 306}], {
             RGBColor[
             0.1986620698216136, 0.3261368096582128, 0.9346248830309214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 342}], {
             RGBColor[
             0.18916310762939384`, 0.3161527981252015, 0.9340839311865298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 353}], {
             RGBColor[
             0.19231632365158768`, 0.3194670280899702, 0.9342635021742287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 216}], {
             RGBColor[
             0.1943994825815768, 0.32165656020529343`, 0.9343821349935341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 231}], {
             RGBColor[
             0.18564063577461087`, 0.3124504568682096, 0.93388333162543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 235}], {
             RGBColor[
             0.1903011498183676, 0.3173489526218552, 0.9341487410056093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 298}], {
             RGBColor[
             0.19304299486108434`, 0.3202308056047669, 0.9343048850245959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 313}], {
             RGBColor[
             0.203727765298821, 0.33146117678840176`, 0.9349133668943235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 317}], {
             RGBColor[
             0.19222117947628775`, 0.3193670255292408, 0.9342580838541985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 336}], {
             RGBColor[
             0.184720804255658, 0.3114836556211034, 0.9338309485811944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 361}], {
             RGBColor[
             0.20336215554475928`, 0.33107689775588556`, 0.9348925459597008]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 393}], {
             RGBColor[
             0.18622578456981498`, 0.3130654853525456, 0.9339166549836668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 396}], {
             RGBColor[
             0.19432308879693078`, 0.32157626549398477`, 0.934377784480513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 147}], {
             RGBColor[
             0.18274418895711692`, 0.3094061076176884, 0.9337183832640827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 164}], {
             RGBColor[
             0.19148238974395732`, 0.318590510678587, 0.9342160108718838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 287}], {
             RGBColor[
             0.1859722872961475, 0.31279904364526556`, 0.9339022186889471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 371}], {
             RGBColor[
             0.18427986944939637`, 0.311020205182841, 0.9338058379962824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 391}], {
             RGBColor[
             0.18156952589467779`, 0.3081714622611251, 0.9336514879404352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 140}], {
             RGBColor[
             0.21947779992995464`, 0.3480154617955958, 0.9358103080664784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 186}], {
             RGBColor[
             0.21005402739966472`, 0.3381104793645726, 0.9352736381621005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 188}], {
             RGBColor[
             0.20752052535930418`, 0.3354476080868466, 0.9351293589688823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 203}], {
             RGBColor[
             0.2195067441810682, 0.34804588403868764`, 0.9358119563987601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 228}], {
             RGBColor[
             0.20842587898456535`, 0.33639919214973135`, 0.9351809175184903]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 238}], {
             RGBColor[
             0.2516193138752771, 0.38179823084181674`, 0.9376407197365557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 273}], {
             RGBColor[
             0.19754073794696791`, 0.32495821876141306`, 0.9345610248395222]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 280}], {
             RGBColor[
             0.23239625445736245`, 0.36159357658122604`, 0.9365459949406734]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 309}], {
             RGBColor[
             0.255426495168577, 0.38579981977031097`, 0.9378575330789891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 322}], {
             RGBColor[
             0.206580775656939, 0.33445987156608825`, 0.9350758416135677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 325}], {
             RGBColor[
             0.2511977848308302, 0.381355177089618, 0.9376167142810707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 330}], {
             RGBColor[
             0.199593351679308, 0.3271156459373298, 0.9346779181550091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 339}], {
             RGBColor[
             0.23240211172972863`, 0.36159973294585546`, 0.9365463285036696]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 160}], {
             RGBColor[
             0.40894844852211004`, 0.5284611159894712, 0.9473261168602697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 202}], {
             RGBColor[
             0.300816385571577, 0.4289283244783967, 0.9406100852285664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 220}], {
             RGBColor[
             0.4970479670019815, 0.5999842739295098, 0.9542616336741748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 244}], {
             RGBColor[
             0.656519419340629, 0.7252624326066381, 0.9527521812690418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 260}], {
             RGBColor[
             0.29142760754703456`, 0.4190601234916939, 0.9400754082095211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 307}], {
             RGBColor[
             0.3533139613151539, 0.48044452804031823`, 0.9437338310851009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 321}], {
             RGBColor[
             0.4563174789356197, 0.5669174288296601, 0.9510551804528969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 341}], {
             RGBColor[
             0.34725423307667924`, 0.4751958960109486, 0.9433477105601525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 348}], {
             RGBColor[
             0.34570653122762846`, 0.47385535445905747`, 0.94324909236691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 366}], {
             RGBColor[
             0.3763364091715497, 0.5003854152316536, 0.9452008011045592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 155}], {
             RGBColor[
             0.1964342499678622, 0.3237952297399831, 0.9344980119860145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 199}], {
             RGBColor[
             0.18613849661309062`, 0.31297374017565216`, 0.9339116840636623]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 216}], {
             RGBColor[
             0.19274891912622777`, 0.3199217133619542, 0.9342881378465417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 298}], {
             RGBColor[
             0.1913924314057353, 0.3184959587614276, 0.9342108878776034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 299}], {
             RGBColor[
             0.18672468895596034`, 0.31358986549474943`, 0.9339450668503949]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 306}], {
             RGBColor[
             0.1942497780329075, 0.32149921123282543`, 0.9343736095409554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 342}], {
             RGBColor[
             0.18475081584068775`, 0.311515199699814, 0.9338326576965637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 361}], {
             RGBColor[
             0.20171159208941025`, 0.3293420509125463, 0.9347985488127086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 393}], {
             RGBColor[
             0.18457522111446595`, 0.3113306385092063, 0.9338226578366745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 135}], {
             RGBColor[
             0.9129052217970873, 0.9297159641585085, 0.8318647617559947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 226}], {
             RGBColor[
             0.6381042655490734, 0.7140610165668736, 0.9666654902064342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 234}], {
             RGBColor[
             0.8083454624285121, 0.8502936670726204, 0.9815084195744261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 239}], {
             RGBColor[
             0.8288313392623307, 0.4322875085422818, 0.44405929782727327`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 246}], {
             RGBColor[
             0.8756067697264411, 0.9036490867400013, 0.9879973494315406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 269}], {
             RGBColor[
             0.7872748442941331, 0.8338331400434145, 0.9794082972749127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 272}], {
             RGBColor[
             0.7859507335711424, 0.832798734683, 0.9792763222925633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 350}], {
             RGBColor[
             0.9124093272037948, 0.929890258170909, 0.8676584254872136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 355}], {
             RGBColor[
             0.7983376603764013, 0.8424754960473988, 0.9805109353940992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 392}], {
             RGBColor[
             0.9110260493239869, 0.9293182372189884, 0.8905829197640283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 395}], {
             RGBColor[
             0.6498035533941702, 0.7237783527330339, 0.9675259002297822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 156}], {
             RGBColor[
             0.8856046641981132, 0.4899098319471875, 0.34486688561467355`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 165}], {
             RGBColor[
             0.9457959012350979, 0.9559420991486686, 0.8350019041226482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 221}], {
             RGBColor[
             0.9485753172801801, 0.8203317071995411, 0.46009294767531356`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 234}], {
             RGBColor[
             0.8902824990453274, 0.9119541401261442, 0.8296334999422285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 255}], {
             RGBColor[
             0.8885216832896912, 0.5123313189309725, 0.3476602263910705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 281}], {
             RGBColor[
             0.711765095722288, 0.768553055573181, 0.8142632180180123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 328}], {
             RGBColor[
             0.932186507346842, 0.7459139489960613, 0.44641772294044424`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 355}], {
             RGBColor[
             0.8802746969932166, 0.9041359691009224, 0.8286360157619015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 386}], {
             RGBColor[
             0.8778014359212141, 0.9022038387539937, 0.8283895042121832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 400}], {
             RGBColor[
             0.8983997399580361, 0.588258391075905, 0.357119464612347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 331}], {
             RGBColor[
             0.19186850922797938`, 0.3189963467376835, 0.9342379998052863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 335}], {
             RGBColor[
             0.18204623503960604`, 0.3086725137975501, 0.9336786358210108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 394}], {
             RGBColor[
             0.18251086599702937`, 0.30916087039310625`, 0.9337050958666762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 169}], {
             RGBColor[
             0.6151260920101136, 0.6919294010372166, 0.9662275076726026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 175}], {
             RGBColor[
             0.3080574204607164, 0.43874050226861905`, 0.940941847744563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 178}], {
             RGBColor[
             0.3880768646119117, 0.5105544076416471, 0.9459488925435418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 197}], {
             RGBColor[
             0.6493874970557305, 0.7185106775296126, 0.9439140882472267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 252}], {
             RGBColor[
             0.35201484785933657`, 0.47931930126023004`, 0.943651052724457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 278}], {
             RGBColor[
             0.29631468313808673`, 0.42639814080998684`, 0.9402731162258624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 282}], {
             RGBColor[
             0.3008030444529849, 0.4311156931304887, 0.9405287217628104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 300}], {
             RGBColor[
             0.624581474397714, 0.6994688662935715, 0.9671293704856514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 314}], {
             RGBColor[
             0.28356888618805115`, 0.41300150008529746`, 0.9395472619452747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 319}], {
             RGBColor[
             0.3939126281591366, 0.5156078641515458, 0.9463210706392715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 352}], {
             RGBColor[
             0.28703295098175935`, 0.4166424518178782, 0.9397445353106518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 159}], {
             RGBColor[
             0.18138230828610377`, 0.30797468468423184`, 0.9336408261745905]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 215}], {
             RGBColor[
             0.18262441317102773`, 0.30928021567228525`, 0.9337115622102574]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 218}], {
             RGBColor[
             0.18655648275495362`, 0.3134130701126022, 0.9339354877560864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 229}], {
             RGBColor[
             0.19456770903936127`, 0.32183337687859837`, 0.9343917152414362]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 329}], {
             RGBColor[
             0.18634787164566047`, 0.31319380661002694`, 0.9339236076620245]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 349}], {
             RGBColor[
             0.19211902352341417`, 0.31925965314570914`, 0.9342522662238085]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 193}], {
             RGBColor[
             0.18750230329400064`, 0.31440718746762647`, 0.933989350836569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 204}], {
             RGBColor[
             0.19084712474135193`, 0.31792280688272123`, 0.9341798334697757]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 224}], {
             RGBColor[
             0.18369701044953324`, 0.3104075834185898, 0.9337726450385029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 276}], {
             RGBColor[
             0.20545840173873126`, 0.33328018541543536`, 0.9350119240793292]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 290}], {
             RGBColor[
             0.19313846063632573`, 0.32033114618742536`, 0.9343103216592668]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 318}], {
             RGBColor[
             0.19122506102961745`, 0.318320041884233, 0.9342013563822857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 203}], {
             RGBColor[
             0.22572809779654535`, 0.3545849211451561, 0.9361662532834936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 232}], {
             RGBColor[
             0.2603959916536444, 0.39102307566039235`, 0.9381405385521024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 257}], {
             RGBColor[
             0.2744017745717613, 0.404416509747592, 0.9389867546110457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 275}], {
             RGBColor[
             0.23222474174375346`, 0.36141330584468895`, 0.9365362275453637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 280}], {
             RGBColor[
             0.2386176080728396, 0.36813261368769457`, 0.936900291825407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 288}], {
             RGBColor[
             0.2655351688852008, 0.39642467677341436`, 0.9384332070927082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 297}], {
             RGBColor[
             0.21630983883703356`, 0.3446857338266013, 0.935629897368815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 309}], {
             RGBColor[
             0.2616478487840542, 0.3923388568767794, 0.9382118299637227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 322}], {
             RGBColor[
             0.21280212927241615`, 0.34099890867255667`, 0.9354301384983013]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 325}], {
             RGBColor[
             0.25741913844630737`, 0.3878942141960865, 0.9379710111658044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 339}], {
             RGBColor[
             0.2386234653452058, 0.3681387700523239, 0.9369006253884031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 172}], {
             RGBColor[
             0.8516660985539529, 0.38305028155577586`, 0.19651818563350704`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[
             0.8542946643121351, 0.403254589818024, 0.1990353031720827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 243}], {
             RGBColor[
             0.9002404219314994, 0.6473255027899616, 0.4518652115799682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 279}], {
             RGBColor[
             0.801143090532162, 0.5696856585664152, 0.46236431184102655`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 285}], {
             RGBColor[
             0.908464702608926, 0.6517279650966425, 0.34303552105754676`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 337}], {
             RGBColor[
             0.9084139629772536, 0.6516194381550591, 0.33751282527872106`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 399}], {
             RGBColor[
             0.8859237106076299, 0.5705962751965173, 0.2263022782483616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 143}], {
             RGBColor[
             0.1837659567931899, 0.3104800503972236, 0.9337765714307771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 258}], {
             RGBColor[
             0.18294835007904106`, 0.30962069390139346`, 0.9337300099379471]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 277}], {
             RGBColor[
             0.19515207298431664`, 0.32244758043556054`, 0.9344249939036124]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 302}], {
             RGBColor[
             0.18693197467623224`, 0.31380773592942895`, 0.9339568714655127]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 377}], {
             RGBColor[
             0.18361252498065594`, 0.31031878383411166`, 0.9337678337160353]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 378}], {
             RGBColor[
             0.18665371404405717`, 0.3135152663622699, 0.93394102493416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 379}], {
             RGBColor[
             0.1947953347030193, 0.32207262588340363`, 0.9344046781862394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 258}], {
             RGBColor[
             0.1842254727690224, 0.31096303082281923`, 0.9338027401858078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 277}], {
             RGBColor[
             0.196429195674298, 0.32378991735698637`, 0.9344977241514731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 302}], {
             RGBColor[
             0.1882090973662136, 0.3151500728508547, 0.9340296017133733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 377}], {
             RGBColor[
             0.1848896476706373, 0.3116611207555374, 0.933840563963896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 378}], {
             RGBColor[
             0.18793083673403851`, 0.31485760328369566`, 0.9340137551820207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 379}], {
             RGBColor[
             0.19607245739300067`, 0.3234149628048294, 0.9344774084341002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 186}], {
             RGBColor[
             0.19870087032152506`, 0.3261775914437136, 0.9346270926619912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 188}], {
             RGBColor[
             0.19616736828116454`, 0.3235147201659876, 0.934482813468773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 200}], {
             RGBColor[
             0.18738223875410484`, 0.31428099202366444`, 0.9339825133386415]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 228}], {
             RGBColor[
             0.19707272190642572`, 0.32446630422887235`, 0.934534372018381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 333}], {
             RGBColor[
             0.1893313874669234, 0.316329670904003, 0.9340935144743294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 368}], {
             RGBColor[
             0.18786109875542928`, 0.31478430424653414`, 0.934009783707307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 200}], {
             RGBColor[
             0.19073593578989534`, 0.3178059402449537, 0.9341735014234795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 207}], {
             RGBColor[
             0.19250737674757545`, 0.31966783700731927`, 0.9342743823654074]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 222}], {
             RGBColor[
             0.21482177415136725`, 0.3431216834932156, 0.9355451542863606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 254}], {
             RGBColor[
             0.19225246823374995`, 0.31939991199715534`, 0.9342598657026484]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 333}], {
             RGBColor[
             0.19268508450271393`, 0.3198546191252922, 0.9342845025591675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 227}], {
             RGBColor[
             0.19680598858419968`, 0.3241859505953433, 0.934519181950277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 302}], {
             RGBColor[
             0.18875875182792845`, 0.3157277945402228, 0.9340609037218272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 375}], {
             RGBColor[
             0.18336952246536248`, 0.3100633727832889, 0.9337539950822794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 377}], {
             RGBColor[
             0.18543930213235216`, 0.3122388424449055, 0.9338718659723498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 344}], {
             RGBColor[
             0.1873628349672718, 0.31426059741343176`, 0.9339814083216866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 354}], {
             RGBColor[
             0.1996644579713909, 0.3271903831587082, 0.9346819675531508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 371}], {
             RGBColor[
             0.18501189214807195`, 0.3117896074520688, 0.9338475256060415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 388}], {
             RGBColor[
             0.20149520910929605`, 0.3291146186809729, 0.9347862261221009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 391}], {
             RGBColor[
             0.18230154859335337`, 0.30894086453035285`, 0.9336931755501943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 179}], {
             RGBColor[
             0.39396314610535543`, 0.515635700812435, 0.9463286881882242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 232}], {
             RGBColor[
             0.3145355236290795, 0.4455942655029455, 0.9413091233699418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 257}], {
             RGBColor[
             0.3285413065471964, 0.4589876995901452, 0.9421553394288851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 275}], {
             RGBColor[
             0.28636427371918854`, 0.4159844956872421, 0.939704812363203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 276}], {
             RGBColor[
             0.27841767131860123`, 0.407632112720532, 0.9392522651124343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 279}], {
             RGBColor[
             0.5031062098123048, 0.6037853067748751, 0.9552337277677017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 288}], {
             RGBColor[
             0.3196747008606359, 0.4509958666159675, 0.9416017919105475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 195}], {
             RGBColor[
             0.20922588183301488`, 0.33724004586656203`, 0.9352264764972114]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 210}], {
             RGBColor[
             0.26112860842944113`, 0.3917931023423411, 0.9381822599936748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 247}], {
             RGBColor[
             0.20711572977977888`, 0.33502214226724336`, 0.9351063064594698]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 249}], {
             RGBColor[
             0.2628399368216051, 0.3935612687084925, 0.9382808361360453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 253}], {
             RGBColor[
             0.20384820267597584`, 0.3315877641079622, 0.9349202256247814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 266}], {
             RGBColor[
             0.22467790350563632`, 0.35348110035924685`, 0.9361064462722496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 315}], {
             RGBColor[
             0.21772472600366666`, 0.3461728699477604, 0.9357104730998167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 316}], {
             RGBColor[
             0.2254786330368893, 0.3543227178657783, 0.9361520466344813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 358}], {
             RGBColor[
             0.20368965097586314`, 0.3314211162183854, 0.9349111963400162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 359}], {
             RGBColor[
             0.20190369877404518`, 0.3295439672183649, 0.9348094890042022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 362}], {
             RGBColor[
             0.20288427131655484`, 0.3305746111324327, 0.934865331159871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 363}], {
             RGBColor[
             0.21825217126115545`, 0.34672724835534197`, 0.9357405103269454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 369}], {
             RGBColor[
             0.20360056980323105`, 0.3313274862578765, 0.9349061232990186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 397}], {
             RGBColor[
             0.21476341163145843`, 0.34306034078439396`, 0.9355418306271915]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 192}], {
             RGBColor[
             0.1875835174154828, 0.3144925486585769, 0.9339939758606419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 283}], {
             RGBColor[
             0.2012631111576979, 0.32887066901798323`, 0.9347730084871156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 294}], {
             RGBColor[
             0.19175282420721007`, 0.318874754446001, 0.9342314117144941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 320}], {
             RGBColor[
             0.19466927104284892`, 0.32194012498366686`, 0.9343974990472872]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 347}], {
             RGBColor[
             0.19569856946522865`, 0.3230219828868772, 0.9344561160697312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 380}], {
             RGBColor[
             0.20683506244234898`, 0.3347271431002675, 0.9350903228698133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 381}], {
             RGBColor[
             0.19485465175919953`, 0.32213497187036766`, 0.9344080562048372]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 384}], {
             RGBColor[
             0.19155187583051508`, 0.31866354496123156`, 0.9342199680017178]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 168}], {
             RGBColor[
             0.18811217327033666`, 0.31504819948074547`, 0.9340240820294996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 265}], {
             RGBColor[
             0.1910010224377346, 0.31808456311929695`, 0.9341885977159134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 291}], {
             RGBColor[
             0.1895972333261113, 0.3166090917576105, 0.9341086540027264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 304}], {
             RGBColor[
             0.1864549217267703, 0.3133063230326405, 0.9339297040057775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 378}], {
             RGBColor[
             0.19141895458300517`, 0.3185238363024048, 0.9342123983333115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 383}], {
             RGBColor[
             0.20018660218381945`, 0.3277391898318258, 0.9347117028936056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 154}], {
             RGBColor[
             0.23114091709829876`, 0.3602741374238645, 0.93647450533518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 180}], {
             RGBColor[
             0.2576563148367751, 0.3881435016203197, 0.9379845180103705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 198}], {
             RGBColor[
             0.3050387614583694, 0.43382537545233274`, 0.9408337346263971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 236}], {
             RGBColor[
             0.2537723278978401, 0.38406118508850384`, 0.9377633307000419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 267}], {
             RGBColor[
             0.25637803396755154`, 0.3867999473790775, 0.9379117218059152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 284}], {
             RGBColor[
             0.26668400229217915`, 0.3976321735243937, 0.9384986314556889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 332}], {
             RGBColor[
             0.24255699042787615`, 0.37227315431410535`, 0.9371246338227324]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 367}], {
             RGBColor[
             0.31592573046277495`, 0.4432551208089762, 0.9415274426643891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 383}], {
             RGBColor[
             0.2325615956471479, 0.3617673606549275, 0.9365554108768314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 398}], {
             RGBColor[
             0.3414317727237982, 0.4653471726445155, 0.943152665123154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 161}], {
             RGBColor[
             0.1909498488692258, 0.3180307764542026, 0.9341856834568915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 184}], {
             RGBColor[
             0.18277753601960423`, 0.3094411574946885, 0.933720282329959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[
             0.18871819494406902`, 0.31568516668383156`, 0.9340585940672899]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 372}], {
             RGBColor[
             0.18825648302408265`, 0.31519987818169937`, 0.9340323002564883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 180}], {
             RGBColor[
             0.2320279298273124, 0.36120644404191316`, 0.9365250193978796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 236}], {
             RGBColor[
             0.22814394288837742`, 0.3571241275100973, 0.936303832087551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 267}], {
             RGBColor[
             0.23074964895808886`, 0.359862889800671, 0.9364522231934242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 286}], {
             RGBColor[
             0.2001789472954632, 0.3277311440588154, 0.9347112669590381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 291}], {
             RGBColor[
             0.1963438417799771, 0.3237002050023056, 0.9344928633734613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 332}], {
             RGBColor[
             0.2169286054184135, 0.3453360967356988, 0.9356651352102414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 383}], {
             RGBColor[
             0.20693321063768522`, 0.33483030307652095`, 0.9350959122643404]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 170}], {
             RGBColor[
             0.21937286170598153`, 0.34790516506873237`, 0.9358043319898652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 171}], {
             RGBColor[
             0.19802203394015824`, 0.32546409136618454`, 0.9345884339343208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 199}], {
             RGBColor[
             0.1967855567491959, 0.3241644754413012, 0.9345180183874995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 261}], {
             RGBColor[
             0.23352567596023666`, 0.3627806701902061, 0.9366103138244327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.19737174909206562`, 0.3247806007603985, 0.9345514011742322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 306}], {
             RGBColor[
             0.20489683816901277`, 0.33268994649847444`, 0.9349799438647926]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 342}], {
             RGBColor[
             0.19539787597679303`, 0.32270593496546307`, 0.9344389920204009]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 353}], {
             RGBColor[
             0.19855109199898685`, 0.3260201649302318, 0.9346185630080999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 361}], {
             RGBColor[
             0.21235865222551553`, 0.3405327861781953, 0.9354048831365458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 165}], {
             RGBColor[
             0.8529070927455767, 0.4662869399049452, 0.44820826028057437`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 221}], {
             RGBColor[
             0.8547600367756315, 0.37588001193886017`, 0.19826895598235128`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 245}], {
             RGBColor[
             0.826933929899517, 0.208031564496835, 0.1734252677302876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 255}], {
             RGBColor[
             0.8324443766360075, 0.2503872728066577, 0.17870207774831032`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 328}], {
             RGBColor[
             0.8438341634867396, 0.32626817313654033`, 0.18915213949243842`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 364}], {
             RGBColor[
             0.8265496181427123, 0.20507757592754824`, 0.17305725035795336`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 386}], {
             RGBColor[
             0.8075774492029875, 0.43046143297516193`, 0.4437999936735976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 400}], {
             RGBColor[
             0.8373834049701799, 0.28835080887912395`, 0.18343169685894858`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 181}], {
             RGBColor[
             0.19115892919796787`, 0.31825053313616897`, 0.9341975902723066]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 191}], {
             RGBColor[
             0.1973089788218841, 0.3247146252265727, 0.9345478265002056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 334}], {
             RGBColor[
             0.1861875662547559, 0.3130253154802374, 0.9339144785071631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 365}], {
             RGBColor[
             0.18416233691758455`, 0.3108966710399138, 0.9337991446924696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 370}], {
             RGBColor[
             0.18724094908895864`, 0.3141324876273136, 0.9339744671012307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 209}], {
             RGBColor[
             0.336799320476102, 0.4661403761955148, 0.94268153277416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 241}], {
             RGBColor[
             0.3009846875478195, 0.43090972620672763`, 0.9405535979845862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 270}], {
             RGBColor[
             0.3489276916060272, 0.4766453616785984, 0.9434543418578613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 310}], {
             RGBColor[
             0.30917761379090525`, 0.4395210111497373, 0.9410201730137817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 323}], {
             RGBColor[
             0.3687236016444134, 0.49379158398248, 0.9447157197406713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 324}], {
             RGBColor[
             0.4859428845919035, 0.5904387279012617, 0.9535338248669657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 346}], {
             RGBColor[
             0.34491127963015633`, 0.47316654749583464`, 0.9431984196383325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 390}], {
             RGBColor[
             0.3007335296132649, 0.43064574329317795`, 0.9405392949117681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 215}], {
             RGBColor[
             0.1817543271405076, 0.3083657000875679, 0.9336620120979963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 218}], {
             RGBColor[
             0.18568639672443343`, 0.31249855452788494`, 0.9338859376438252]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 329}], {
             RGBColor[
             0.18547778561514033`, 0.3122792910253096, 0.9338740575497635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 349}], {
             RGBColor[
             0.191248937492894, 0.31834513756099186`, 0.9342027161115474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 217}], {
             RGBColor[
             0.7263465347719837, 0.7798834744139984, 0.7188240157462833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 220}], {
             RGBColor[
             0.5477229997143326, 0.6437052316648666, 0.9575379073944208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 233}], {
             RGBColor[
             0.7095149174779228, 0.7707139896565038, 0.9521005122991707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 244}], {
             RGBColor[
             0.7071944520529801, 0.7689833903419949, 0.9560284549892878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 263}], {
             RGBColor[
             0.42578806203725694`, 0.5430467428327064, 0.9483991221427692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 264}], {
             RGBColor[
             0.5914575736276367, 0.6779711437656651, 0.9618285011853527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 307}], {
             RGBColor[
             0.403988994027505, 0.524165485775675, 0.9470101048053469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 312}], {
             RGBColor[
             0.38126624461740655`, 0.5039445125232649, 0.9455819912605958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 321}], {
             RGBColor[
             0.5069925116479708, 0.6106383865650169, 0.9543314541731429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 341}], {
             RGBColor[
             0.3979292657890303, 0.5189168537463054, 0.9466239842803985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 348}], {
             RGBColor[
             0.39638156393997953`, 0.5175763121944144, 0.946525366087156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 366}], {
             RGBColor[
             0.4270114418839008, 0.5441063729670104, 0.948477074824805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 176}], {
             RGBColor[
             0.21656199837052442`, 0.34495076948413805`, 0.9356442574812107]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 184}], {
             RGBColor[
             0.19128276610466352`, 0.31838069357681953`, 0.9342046426009427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 195}], {
             RGBColor[
             0.20065168741435874`, 0.3282280238972294, 0.9347381888094528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 250}], {
             RGBColor[
             0.22890128499152032`, 0.3579201420787632, 0.9363469615999377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 344}], {
             RGBColor[
             0.1953522686165181, 0.3226579987381405, 0.9344363947487033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.19722342502912832`, 0.3246247027659626, 0.9345429543382737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 363}], {
             RGBColor[
             0.20967797684249928`, 0.3377152263860093, 0.9352522226391868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 372}], {
             RGBColor[
             0.19676171310914198`, 0.3241394142638304, 0.934516660527472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 191}], {
             RGBColor[
             0.239776323432642, 0.3693504969976439, 0.936966278950982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 211}], {
             RGBColor[
             0.24710920905835015`, 0.37705782472206506`, 0.9373838759393338]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 214}], {
             RGBColor[
             0.25603696286442035`, 0.3864414600245297, 0.9378922983111614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 248}], {
             RGBColor[
             0.24516386461647438`, 0.3750131443716921, 0.9372730914512483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 263}], {
             RGBColor[
             0.33214075614847005`, 0.45873834938016844`, 0.9425079759974546]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 312}], {
             RGBColor[
             0.28761893872861966`, 0.41963611907072695`, 0.9396908451152812]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 340}], {
             RGBColor[
             0.23763180163327896`, 0.367096468615978, 0.9368441516070439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 348}], {
             RGBColor[
             0.3027342580511927, 0.4332679187418763, 0.9406342199418414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 167}], {
             RGBColor[
             0.2885245503262027, 0.4204485142001573, 0.9397475246726753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 174}], {
             RGBColor[
             0.3053955889489409, 0.4350613598921163, 0.9408225323352425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.2667189772067604, 0.39766893437715617`, 0.9385006232253336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 222}], {
             RGBColor[
             0.24959037113759353`, 0.3796656833821117, 0.9375251744491964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 226}], {
             RGBColor[
             0.35601753306005335`, 0.4789075435482711, 0.944048117850775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 395}], {
             RGBColor[
             0.36771682090515007`, 0.4886248797144314, 0.9449085278741232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 287}], {
             RGBColor[
             0.19544251078166353`, 0.3227528489753921, 0.9344415339065071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 292}], {
             RGBColor[
             0.19766905263223078`, 0.3250930856312453, 0.9345683321710234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 354}], {
             RGBColor[
             0.20840265875823133`, 0.3363747862196069, 0.9351795951609518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 371}], {
             RGBColor[
             0.1937500929349124, 0.3209740105129675, 0.9343451532138425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 374}], {
             RGBColor[
             0.1955858495365969, 0.322903507095029, 0.9344496968365499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 388}], {
             RGBColor[
             0.21023340989613648`, 0.33829902174187165`, 0.935283853729902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 389}], {
             RGBColor[
             0.20180063292388895`, 0.3294356384750984, 0.934803619556508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 391}], {
             RGBColor[
             0.1910397493801938, 0.3181252675912516, 0.9341908031579952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 182}], {
             RGBColor[
             0.6226406331298818, 0.6984050769847048, 0.9667215385795859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 256}], {
             RGBColor[
             0.624029163944416, 0.6996077525866663, 0.9668100145352584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 281}], {
             RGBColor[
             0.6627187385434833, 0.7331187175098175, 0.9692752800168635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 311}], {
             RGBColor[
             0.5997467789297788, 0.6780206465223158, 0.965283080943369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 328}], {
             RGBColor[
             0.8831401501680374, 0.7104796109326978, 0.6014297849392954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 386}], {
             RGBColor[
             0.8287550787424094, 0.8667695006906301, 0.9834015662110343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 400}], {
             RGBColor[
             0.8657021685054997, 0.5646354990336626, 0.4604608392782479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 169}], {
             RGBColor[
             0.9427417968791698, 0.9548740993356628, 0.9051840770091248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 178}], {
             RGBColor[
             0.7156925694809679, 0.7734991059400932, 0.884905461880064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 197}], {
             RGBColor[
             0.9770032019247867, 0.9814553758280588, 0.8828706575837489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.8817402416283486, 0.4729378739656097, 0.3896280153376859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 300}], {
             RGBColor[
             0.9521971792667703, 0.9624135645920178, 0.9060859398221737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 319}], {
             RGBColor[
             0.7215283330281927, 0.7785525624499918, 0.8852776399757938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 174}], {
             RGBColor[
             0.3271254190729118, 0.4577613290244936, 0.9420651203310438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 183}], {
             RGBColor[
             0.33012064304919175`, 0.46035564148841296`, 0.9422559733542398]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 189}], {
             RGBColor[
             0.2884488073307313, 0.4203689035095335, 0.9397432112211349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 222}], {
             RGBColor[
             0.2713202012615644, 0.4023656525144891, 0.9387677624449977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 238}], {
             RGBColor[
             0.3001182809431252, 0.43263426016352036`, 0.9404077704799216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 246}], {
             RGBColor[
             0.6152498673613919, 0.6911955828537762, 0.9666225650716829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 269}], {
             RGBColor[
             0.5269179419290838, 0.6213796361571894, 0.958033512915055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 272}], {
             RGBColor[
             0.5255938312060932, 0.6203452307967748, 0.9579015379327056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 309}], {
             RGBColor[
             0.30392546223642514`, 0.4366358490920146, 0.940624583822355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 395}], {
             RGBColor[
             0.389446651029121, 0.5113248488468087, 0.9461511158699245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 265}], {
             RGBColor[
             0.18709388052696674`, 0.31397790924397473`, 0.9339660917641938]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 304}], {
             RGBColor[
             0.18254777981600245`, 0.3091996691573183, 0.9337071980540577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 378}], {
             RGBColor[
             0.18751181267223727`, 0.3144171824270826, 0.9339898923815917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 177}], {
             RGBColor[
             0.8953206105495907, 0.9193683682944271, 0.9898776731680061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 178}], {
             RGBColor[
             0.668739474081812, 0.7383666179007873, 0.9696437049697588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 197}], {
             RGBColor[
             0.9300501065256308, 0.9463228877887528, 0.9676089006734437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 239}], {
             RGBColor[
             0.8504381780289113, 0.4495162152727391, 0.44612017739748244`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 300}], {
             RGBColor[
             0.9052440838676142, 0.9272810765527117, 0.9908241829118685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 319}], {
             RGBColor[
             0.6745752376290368, 0.7434200744106859, 0.9700158830654886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 171}], {
             RGBColor[
             0.21031358554217228`, 0.3383832914292848, 0.9352884196143345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 187}], {
             RGBColor[
             0.33329236872326556`, 0.45597611149735384`, 0.9427190170162062]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 261}], {
             RGBColor[
             0.2458172275622507, 0.3756998702533064, 0.9373102995044464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 299}], {
             RGBColor[
             0.20966330069407968`, 0.3376998008234987, 0.9352513868542458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 306}], {
             RGBColor[
             0.21718838977102684`, 0.3456091465615747, 0.9356799295448063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 353}], {
             RGBColor[
             0.2108426436010009, 0.33893936499333205`, 0.9353185486881135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 361}], {
             RGBColor[
             0.22465020382752957`, 0.3534519862412956, 0.9361048688165594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 299}], {
             RGBColor[
             0.18831247292825637`, 0.31525872712095093`, 0.9340354887987012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 306}], {
             RGBColor[
             0.19583756200520352`, 0.3231680728590269, 0.9344640314892618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 342}], {
             RGBColor[
             0.18633859981298379`, 0.3131840613260155, 0.9339230796448701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 353}], {
             RGBColor[
             0.1894918158351776, 0.3164982912907842, 0.9341026506325689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 208}], {
             RGBColor[
             0.8802072426240743, 0.4531049530073836, 0.36875769865424585`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 225}], {
             RGBColor[
             0.8441055756294294, 0.42628106073348204`, 0.44324008483187805`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 240}], {
             RGBColor[
             0.8264317919518623, 0.2041719121929097, 0.17294441986452982`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 243}], {
             RGBColor[
             0.8723775495712267, 0.44824282516484726`, 0.42577432827241535`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 285}], {
             RGBColor[
             0.8806018302486532, 0.4526452874715283, 0.3169446377499939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 337}], {
             RGBColor[
             0.8805510906169809, 0.45253676052994485`, 0.3114219419711682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 357}], {
             RGBColor[
             0.8349023138683568, 0.2692800554494574, 0.18105580121785106`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 399}], {
             RGBColor[
             0.8580608382473571, 0.37151359757140306`, 0.20021139494080872`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 176}], {
             RGBColor[
             0.25807437232061936`, 0.38858290654221544`, 0.9380083257656147]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 209}], {
             RGBColor[
             0.3086611648699239, 0.43934003290171275`, 0.940977513192154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 250}], {
             RGBColor[
             0.27041365894161523`, 0.40155227913684066`, 0.9387110298843417]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 323}], {
             RGBColor[
             0.3405854460382354, 0.4669912406886779, 0.9430117001586653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 354}], {
             RGBColor[
             0.24916626557073213`, 0.3792199215414943, 0.9375010222645717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 388}], {
             RGBColor[
             0.2509970167086373, 0.38114415706375904`, 0.9376052808335218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 183}], {
             RGBColor[
             0.34699168167192995`, 0.474968487180372, 0.943330981016807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 189}], {
             RGBColor[
             0.3053198459534695, 0.4349817492014926, 0.9408182188837021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 238}], {
             RGBColor[
             0.3169893195658634, 0.44724710585547944`, 0.9414827781424888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 246}], {
             RGBColor[
             0.6321209059841302, 0.7058084285457353, 0.96769757273425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 269}], {
             RGBColor[
             0.543788980551822, 0.6359924818491485, 0.9591085205776222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 272}], {
             RGBColor[
             0.5424648698288314, 0.6349580764887339, 0.9589765455952728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 309}], {
             RGBColor[
             0.32079650085916334`, 0.45124869478397367`, 0.9416995914849222]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 325}], {
             RGBColor[
             0.31656779052141654`, 0.4468040521032807, 0.9414587726870038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 395}], {
             RGBColor[
             0.4063176896518592, 0.5259376945387678, 0.9472261235324917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 178}], {
             RGBColor[
             0.3616708025324146, 0.48517771913218966`, 0.9443580450417194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 213}], {
             RGBColor[
             0.25213492118930436`, 0.3823401668202513, 0.9376700828103168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 227}], {
             RGBColor[
             0.24456047357150879`, 0.37437894212623135`, 0.9372387292238745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 278}], {
             RGBColor[
             0.2699086210585896, 0.40102145230052944`, 0.93868226872404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 296}], {
             RGBColor[
             0.26330595896968834`, 0.39408163581213873`, 0.9383062568858402]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 314}], {
             RGBColor[
             0.25716282410855407`, 0.38762481157584006`, 0.9379564144434523]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 319}], {
             RGBColor[
             0.3675065660796395, 0.49023117564208835`, 0.944730223137449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 352}], {
             RGBColor[
             0.2606268889022622, 0.3912657633084208, 0.9381536878088295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 250}], {
             RGBColor[
             0.24600820440775967`, 0.3759005990265677, 0.9373211753532731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 344}], {
             RGBColor[
             0.21245918803275743`, 0.3406384556859449, 0.9354106085020388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 354}], {
             RGBColor[
             0.22476081103687653`, 0.35356824143122134`, 0.936111167733503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 356}], {
             RGBColor[
             0.21433034444536764`, 0.34260515971376704`, 0.9355171680916091]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 372}], {
             RGBColor[
             0.2138686325253813, 0.34211987121163484`, 0.9354908742808075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 388}], {
             RGBColor[
             0.22659156217478169`, 0.35549247695348607`, 0.9362154263024531]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 197}], {
             RGBColor[
             0.9295820155952076, 0.9459496447868232, 0.9675642537426303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 225}], {
             RGBColor[
             0.8897813970600477, 0.9149515498158103, 0.9893493380404593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 243}], {
             RGBColor[
             0.9321893579727436, 0.9478941964628581, 0.9631507032012652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 252}], {
             RGBColor[
             0.6322093663988135, 0.7067582685174405, 0.9673012182198607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 300}], {
             RGBColor[
             0.904775992937191, 0.9269078335507821, 0.990779535981055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 337}], {
             RGBColor[
             0.9444496695413749, 0.9543350995105044, 0.7916221237493946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 367}], {
             RGBColor[
             0.6349673392184779, 0.7091470859540894, 0.9674769538091501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 398}], {
             RGBColor[
             0.6604733814795012, 0.7312391377896288, 0.9691021762679148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 197}], {
             RGBColor[
             0.7030008791274289, 0.7649478943931832, 0.947330285544383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 274}], {
             RGBColor[
             0.46738436670940764`, 0.5781669894131862, 0.9513005905019778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 278}], {
             RGBColor[
             0.349928065209785, 0.47283535767355744`, 0.9436893135230188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 300}], {
             RGBColor[
             0.6781948564694122, 0.7459060831571422, 0.9705455677828076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 319}], {
             RGBColor[
             0.4475260102308348, 0.5620450810151163, 0.9497372679364278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 352}], {
             RGBColor[
             0.3406463330534576, 0.4630796686814488, 0.9431607326078082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 232}], {
             RGBColor[
             0.374520452238133, 0.49753308772821003`, 0.9451360369712756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 257}], {
             RGBColor[
             0.38852623515624984`, 0.5109265218154098, 0.9459822530302189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 275}], {
             RGBColor[
             0.34634920232824207`, 0.46792331791250663`, 0.9435317259645368]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 279}], {
             RGBColor[
             0.5630911384213583, 0.6557241290001397, 0.9590606413690353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 285}], {
             RGBColor[
             0.7240735565365042, 0.7787875887954807, 0.7800674551938157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 288}], {
             RGBColor[
             0.3796596294696894, 0.502934688841232, 0.9454287055118813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 399}], {
             RGBColor[
             0.6902620685345601, 0.6570900539452929, 0.6049675909800379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 198}], {
             RGBColor[
             0.30592577418738304`, 0.43475768207038135`, 0.9408842486890967]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 236}], {
             RGBColor[
             0.2546593406268537, 0.3849934917065525, 0.9378138447627414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 262}], {
             RGBColor[
             0.23634740435871976`, 0.36574648564492557`, 0.9367710070823533]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 267}], {
             RGBColor[
             0.25726504669656514`, 0.3877322539971262, 0.9379622358686148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 284}], {
             RGBColor[
             0.2675710150211928, 0.3985644801424423, 0.9385491455183885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 286}], {
             RGBColor[
             0.22669434503393948`, 0.3556005082552706, 0.9362212796342286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 332}], {
             RGBColor[
             0.2434440031568898, 0.373205460932154, 0.937175147885432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 367}], {
             RGBColor[
             0.31681274319178854`, 0.44418742742702483`, 0.9415779567270888]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 398}], {
             RGBColor[
             0.3423187854528118, 0.46627947926256413`, 0.9432031791858535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 191}], {
             RGBColor[
             0.2010737277844803, 0.3286716150851321, 0.9347622233841785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 211}], {
             RGBColor[
             0.20840661341018846`, 0.33637894280955327`, 0.9351798203725303]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 214}], {
             RGBColor[
             0.21733436721625865`, 0.34576257811201794`, 0.9356882427443579]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 305}], {
             RGBColor[
             0.18857843384879308`, 0.3155382689113313, 0.9340506348796719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 334}], {
             RGBColor[
             0.18995231521735206`, 0.3169823053387968, 0.934128875391136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 340}], {
             RGBColor[
             0.19892920598511726`, 0.3264175867034662, 0.9346400960402405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 365}], {
             RGBColor[
             0.1879270858801807, 0.3148536608984732, 0.9340135415764423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 370}], {
             RGBColor[
             0.19100569805155482`, 0.318089477485873, 0.9341888639852036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 256}], {
             RGBColor[
             0.34992025301800456`, 0.4775050684860661, 0.9435175869933449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 281}], {
             RGBColor[
             0.38860982761707186`, 0.5110160334092172, 0.94598285247495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 311}], {
             RGBColor[
             0.32563786800336725`, 0.45591796242171545`, 0.9419906534014555]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 386}], {
             RGBColor[
             0.5546461678159978, 0.6446668165900299, 0.9601091386691207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 238}], {
             RGBColor[
             0.31998454354214334`, 0.4498414183193987, 0.9416736311656848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 246}], {
             RGBColor[
             0.63511612996041, 0.7084027410096546, 0.967888425757446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 269}], {
             RGBColor[
             0.546784204528102, 0.6385867943130678, 0.9592993736008182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 272}], {
             RGBColor[
             0.5454600938051113, 0.6375523889526532, 0.9591673986184688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 280}], {
             RGBColor[
             0.30076148412422865`, 0.4296367640588081, 0.9405789063698025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 309}], {
             RGBColor[
             0.3237917248354433, 0.45384300724789295`, 0.9418904445081182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 325}], {
             RGBColor[
             0.3195630144976964, 0.44939836456720006`, 0.9416496257101998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 339}], {
             RGBColor[
             0.30076734139659483`, 0.42964292042343744`, 0.9405792399327987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 395}], {
             RGBColor[
             0.40931291362813915`, 0.5285320070026871, 0.9474169765556877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 343}], {
             RGBColor[
             0.18256566753029357`, 0.30921847027918486`, 0.933708216732924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 356}], {
             RGBColor[
             0.18905111217950674`, 0.3160350838064485, 0.9340775532113412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 369}], {
             RGBColor[
             0.1868540625349533, 0.3137258453290297, 0.9339524344843275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 372}], {
             RGBColor[
             0.18858940025952037`, 0.31554979530431626`, 0.9340512594005395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 198}], {
             RGBColor[
             0.3764542800383526, 0.5004875090521163, 0.9452083117319626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 205}], {
             RGBColor[
             0.3748090292582385, 0.49906247551909, 0.9451034778070919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 208}], {
             RGBColor[
             0.6963078073762952, 0.755957556681333, 0.8560508247348155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 210}], {
             RGBColor[
             0.35262704416750634`, 0.4795636552057607, 0.9437005295213796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 219}], {
             RGBColor[
             0.36836286362019555`, 0.4934791308371227, 0.9446927338327562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 249}], {
             RGBColor[
             0.35433837255967027`, 0.48133182157191207`, 0.9437991056637501]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 284}], {
             RGBColor[
             0.33809952087216233`, 0.4642943071241772, 0.9428732085612545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 293}], {
             RGBColor[
             0.374247320413842, 0.49857595155038115`, 0.9450676862162266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 338}], {
             RGBColor[
             0.3169003211264983, 0.4420126040845884, 0.9416659454971446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 188}], {
             RGBColor[
             0.20431810644449144`, 0.33208166276229184`, 0.934946985949238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 228}], {
             RGBColor[
             0.20522346006975262`, 0.3330332468251766, 0.934998544498846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 238}], {
             RGBColor[
             0.24841689496046435`, 0.37843228551726205`, 0.9374583467169113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 273}], {
             RGBColor[
             0.19433831903215518`, 0.3215922734368583, 0.9343786518198778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 322}], {
             RGBColor[
             0.20337835674212623`, 0.3310939262415335, 0.9348934685939234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 330}], {
             RGBColor[
             0.19639093276449526`, 0.3237497006127751, 0.9344955451353647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 206}], {
             RGBColor[
             0.5826167692195937, 0.6701866792756657, 0.9613440852325792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 220}], {
             RGBColor[
             0.5353714211663698, 0.63317812373389, 0.9567035702854296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 261}], {
             RGBColor[
             0.3474451829775207, 0.4708516166188276, 0.9435249988507737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 321}], {
             RGBColor[
             0.494640933100008, 0.6001112786340405, 0.9534971170641517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 228}], {
             RGBColor[
             0.20268995802939208`, 0.3303703755474506, 0.9348542653056278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 238}], {
             RGBColor[
             0.2458833929201038, 0.375769414239536, 0.9373140675236933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 273}], {
             RGBColor[
             0.19180481699179464`, 0.3189294021591323, 0.9342343726266598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 322}], {
             RGBColor[
             0.20084485470176572`, 0.3284310549638075, 0.9347491894007052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 330}], {
             RGBColor[
             0.19385743072413472`, 0.32108682933504906`, 0.9343512659421467]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 222}], {
             RGBColor[
             0.24951462814212214`, 0.379586072691488, 0.937520860997656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 226}], {
             RGBColor[
             0.35594179006458193`, 0.47882793285764735`, 0.9440438043992346]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 395}], {
             RGBColor[
             0.3676410779096787, 0.4885452690238077, 0.9449042144225828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 212}], {
             RGBColor[
             0.6867778683351773, 0.7513832913392242, 0.9534033725466657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 221}], {
             RGBColor[
             0.9292638455200164, 0.8080779972178733, 0.5995947563336426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 255}], {
             RGBColor[
             0.8756473687829154, 0.5041621789431939, 0.4406614321632898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 268}], {
             RGBColor[
             0.8177911045280821, 0.8581558703042615, 0.9638348308947651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 270}], {
             RGBColor[
             0.6576592800193992, 0.7261622336829004, 0.951547961847741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 274}], {
             RGBColor[
             0.7246489008143902, 0.7831056857849257, 0.9561147753018562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 295}], {
             RGBColor[
             0.6926270864337125, 0.7564495900659256, 0.953776079551644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 324}], {
             RGBColor[
             0.7946744730052755, 0.8399555999055638, 0.9616274448568455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 351}], {
             RGBColor[
             0.9330043693197932, 0.948887212220239, 0.9751255904637988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 211}], {
             RGBColor[
             0.2145566630341047, 0.342843034899957, 0.9355300566004294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 214}], {
             RGBColor[
             0.2234844168401749, 0.3522266702024217, 0.9360384789722569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 312}], {
             RGBColor[
             0.25506639270437426`, 0.3854213292486189, 0.9378370257763766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 334}], {
             RGBColor[
             0.1961023648412683, 0.3234463974292005, 0.934479111619035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 340}], {
             RGBColor[
             0.2050792556090335, 0.33288167879387, 0.9349903322681394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 365}], {
             RGBColor[
             0.19407713550409694`, 0.321317752988877, 0.9343637778043414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 370}], {
             RGBColor[
             0.19715574767547106`, 0.3245535695762768, 0.9345391002131025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 292}], {
             RGBColor[
             0.18800332047098128`, 0.31493378828695684`, 0.9340178830236096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 320}], {
             RGBColor[
             0.18870690253434044`, 0.31567329764522667`, 0.9340579509812614]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 347}], {
             RGBColor[
             0.18973620095672017`, 0.3167551555484371, 0.9341165680037053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 374}], {
             RGBColor[
             0.18592011737534742`, 0.3127442097507407, 0.933899247689136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 382}], {
             RGBColor[
             0.18175632170203998`, 0.30836779649820095`, 0.9336621256853248]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 384}], {
             RGBColor[
             0.1855895073220066, 0.3123967176227914, 0.933880419935692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 248}], {
             RGBColor[
             0.20247189401375032`, 0.330141176440954, 0.9348418468825339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 305}], {
             RGBColor[
             0.18458905889423072`, 0.311345182893105, 0.933823445877761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 334}], {
             RGBColor[
             0.1859629402627897, 0.3127892193205704, 0.9339016863892251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 360}], {
             RGBColor[
             0.18609708652812662`, 0.31293021555080397`, 0.9339093258205844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 201}], {
             RGBColor[
             0.9717877162352071, 0.9761148093624215, 0.8086618740541351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 208}], {
             RGBColor[
             0.9937734715667986, 0.9910458830658546, 0.7058012226950569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 223}], {
             RGBColor[
             0.9622169086067585, 0.8752522636294204, 0.4543198910461633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 230}], {
             RGBColor[
             0.8766694336459471, 0.421804072640802, 0.32514101008801133`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 242}], {
             RGBColor[
             0.8996928400306943, 0.5987720630349767, 0.3471882500432634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 357}], {
             RGBColor[
             0.9029108820280516, 0.6235073439816599, 0.3502698506941914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 364}], {
             RGBColor[
             0.8766286360480449, 0.42149048442570325`, 0.3251019422621857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 385}], {
             RGBColor[
             0.9944784929138155, 0.9905983795896796, 0.6403962123397537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 387}], {
             RGBColor[
             0.7643288542489235, 0.8116893614464729, 0.8013257295322668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 247}], {
             RGBColor[
             0.1997381438211963, 0.32726783165880646`, 0.9346861638532888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 253}], {
             RGBColor[
             0.1964706167173933, 0.3238334534995253, 0.9345000830186004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 315}], {
             RGBColor[
             0.21034714004508412`, 0.3384185593393235, 0.9352903304936357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 316}], {
             RGBColor[
             0.21810104707830674`, 0.3465684072573414, 0.9357319040283003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 343}], {
             RGBColor[
             0.19193458883998876`, 0.3190658005995948, 0.9342417629414341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 358}], {
             RGBColor[
             0.1963120650172806, 0.3236668056099485, 0.9344910537338352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 359}], {
             RGBColor[
             0.19452611281546262`, 0.321789656609928, 0.9343893463980213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 362}], {
             RGBColor[
             0.1955066853579723, 0.3228203005239958, 0.9344451885536901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 363}], {
             RGBColor[
             0.21087458530257291`, 0.33897293774690507`, 0.9353203677207644]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 369}], {
             RGBColor[
             0.19622298384464848`, 0.3235731756494396, 0.9344859806928376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 372}], {
             RGBColor[
             0.19795832156921558`, 0.32539712562472617`, 0.9345848056090496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 397}], {
             RGBColor[
             0.2073858256728759, 0.33530603017595706`, 0.9351216880210106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 289}], {
             RGBColor[
             0.18795157808443957`, 0.3148794037580448, 0.934014936371242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 317}], {
             RGBColor[
             0.1925447584771704, 0.3197071275752621, 0.9342765111996065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 326}], {
             RGBColor[
             0.19087356510240117`, 0.3179505973785997, 0.9341813392092224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 327}], {
             RGBColor[
             0.19267128104236286`, 0.3198401108132733, 0.9342837164725208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 336}], {
             RGBColor[
             0.18504438325654066`, 0.31182375766712467`, 0.9338493759266024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 376}], {
             RGBColor[
             0.19966869054902864`, 0.32719483186616644`, 0.9346822085921858]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 252}], {
             RGBColor[
             0.6669388623748537, 0.7337127880117662, 0.9450324457252983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 300}], {
             RGBColor[
             0.9395054889132312, 0.9538623530451078, 0.9685107634864926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 205}], {
             RGBColor[
             0.35166297002886326`, 0.47901452236936815`, 0.9436286313802527]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 219}], {
             RGBColor[
             0.34521680439082036`, 0.47343117768740084`, 0.9432178874059169]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 236}], {
             RGBColor[
             0.3020417872484481, 0.43067536553856556`, 0.9406630613787681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 284}], {
             RGBColor[
             0.31495346164278715`, 0.44424635397445533`, 0.9413983621344152]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 332}], {
             RGBColor[
             0.29082644977848415`, 0.41888733476416706`, 0.9400243645014585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 367}], {
             RGBColor[
             0.36419518981338295`, 0.4898693012590379, 0.9444271733431154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 398}], {
             RGBColor[
             0.38970123207440616`, 0.5119613530945772, 0.9460523958018803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 216}], {
             RGBColor[
             0.19310022590756143`, 0.3202909590632723, 0.9343081442480269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 298}], {
             RGBColor[
             0.19174373818706897`, 0.31886520446274574`, 0.9342308942790887]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 299}], {
             RGBColor[
             0.18707599573729403`, 0.31395911119606756`, 0.93396507325188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 306}], {
             RGBColor[
             0.19460108481424115`, 0.32186845693414357`, 0.9343936159424405]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 342}], {
             RGBColor[
             0.18510212262202141`, 0.31188444540113214`, 0.9338526640980489]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 353}], {
             RGBColor[
             0.18825533864421526`, 0.31519867536590085`, 0.9340322350857477]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 361}], {
             RGBColor[
             0.2020628988707439, 0.32971129661386445`, 0.9348185552141937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 393}], {
             RGBColor[
             0.1849265278957996, 0.3116998842105244, 0.9338426642381596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 207}], {
             RGBColor[
             0.1859857863076916, 0.31281323196228517`, 0.9339029874376845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 333}], {
             RGBColor[
             0.18616349406283006`, 0.3130000140802582, 0.9339131076314446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 368}], {
             RGBColor[
             0.18469320535133593`, 0.3114546474227893, 0.9338293768644222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 223}], {
             RGBColor[
             0.9394729571932308, 0.8606549580209606, 0.6167978110210142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 230}], {
             RGBColor[
             0.861506799370262, 0.41207253556849543`, 0.43345962340457855`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 245}], {
             RGBColor[
             0.8622346252859692, 0.4176669244919702, 0.43415659032342135`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 364}], {
             RGBColor[
             0.8614660017723598, 0.4117589473533967, 0.4334205555787529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 385}], {
             RGBColor[
             0.9717345415002878, 0.9760010739812197, 0.8028741323146045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 218}], {
             RGBColor[
             0.2171099632633392, 0.3455267153294672, 0.9356754632712151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 229}], {
             RGBColor[
             0.22512118954774685`, 0.35394702209546336`, 0.9361316907565649]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 260}], {
             RGBColor[
             0.23397057730885262`, 0.3632482897159762, 0.9366356502980638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 307}], {
             RGBColor[
             0.295856931076972, 0.42463269426460054`, 0.9402940731736436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 341}], {
             RGBColor[
             0.2897972028384973, 0.4193840622352309, 0.9399079526486953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 349}], {
             RGBColor[
             0.22267250403179975`, 0.35137329836257414`, 0.9359922417389372]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 366}], {
             RGBColor[
             0.31887937893336776`, 0.4445735814559359, 0.9417610431931018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 232}], {
             RGBColor[
             0.26042493590475796`, 0.3910534979034842, 0.9381421868843842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 257}], {
             RGBColor[
             0.27443071882287484`, 0.40444693199068393`, 0.9389884029433275]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 275}], {
             RGBColor[
             0.232253685994867, 0.3614437280877808, 0.9365378758776455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 280}], {
             RGBColor[
             0.23864655232395315`, 0.36816303593078636`, 0.9369019401576887]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 297}], {
             RGBColor[
             0.2163387830881471, 0.3447161560696932, 0.9356315457010966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 309}], {
             RGBColor[
             0.2616767930351678, 0.3923692791198713, 0.9382134782960043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 322}], {
             RGBColor[
             0.2128310735235297, 0.3410293309156486, 0.935431786830583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 325}], {
             RGBColor[
             0.2574480826974209, 0.38792463643917835`, 0.9379726594980861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 339}], {
             RGBColor[
             0.23865240959631934`, 0.3681691922954158, 0.9369022737206849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 224}], {
             RGBColor[
             0.1864844568543232, 0.3133373663243338, 0.9339313859875982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 276}], {
             RGBColor[
             0.2082458481435212, 0.33620996832117933`, 0.9351706650284246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 290}], {
             RGBColor[
             0.19592590704111568`, 0.32326092909316934`, 0.9344690626083623]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 297}], {
             RGBColor[
             0.2002775476373886, 0.32783477926980176`, 0.9347168821026446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 318}], {
             RGBColor[
             0.1940125074344074, 0.321249824789977, 0.9343600973313813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 345}], {
             RGBColor[
             0.18631088399028722`, 0.3131549302390768, 0.9339215012697695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 219}], {
             RGBColor[
             0.34357155361070624`, 0.4720061441543746, 0.9431130534810463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 284}], {
             RGBColor[
             0.313308210862673, 0.4428213204414291, 0.9412935282095445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 293}], {
             RGBColor[
             0.3494560104043527, 0.47710296486763304`, 0.9434880058645166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 338}], {
             RGBColor[
             0.292109011117009, 0.4205396174018403, 0.9400862651454345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 220}], {
             RGBColor[
             0.6830678662474279, 0.7522369451466808, 0.9691139391554754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 321}], {
             RGBColor[
             0.6423373781810662, 0.7191701000468311, 0.9659074859341975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 328}], {
             RGBColor[
             0.7999219852902167, 0.6448484807342735, 0.5933000289298582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 386}], {
             RGBColor[
             0.7455369138645886, 0.8011383704922057, 0.975271810201597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 254}], {
             RGBColor[
             0.18750231875154622`, 0.3144072037144869, 0.9339893517168534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 333}], {
             RGBColor[
             0.18793493502051017`, 0.3148619108426237, 0.9340139885733725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 230}], {
             RGBColor[
             0.876163969591323, 0.42202658470411747`, 0.3648858558318596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 240}], {
             RGBColor[
             0.8854643741404387, 0.49351356953187997`, 0.37379193373139724`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 242}], {
             RGBColor[
             0.8991873759760702, 0.5989945750982921, 0.3869330957871117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 357}], {
             RGBColor[
             0.9024054179734275, 0.6237298560449753, 0.3900146964380397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 385}], {
             RGBColor[
             0.9937202968318795, 0.9909321476846529, 0.7000134809555262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 387}], {
             RGBColor[
             0.7635706581669874, 0.8120231295414462, 0.8609429981480392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 241}], {
             RGBColor[
             0.2990278699570904, 0.4292148291621499, 0.9404289112980508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 270}], {
             RGBColor[
             0.34697087401529814`, 0.4749504646340207, 0.9433296551713259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 310}], {
             RGBColor[
             0.30722079620017617`, 0.4378261141051596, 0.9408954863272463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 323}], {
             RGBColor[
             0.36676678405368435`, 0.4920966869379023, 0.9445910330541359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 346}], {
             RGBColor[
             0.34295446203942725`, 0.47147165045125694`, 0.9430737329517971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 390}], {
             RGBColor[
             0.2987767120225358, 0.42895084624860025`, 0.9404146082252327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 249}], {
             RGBColor[
             0.3073650774594488, 0.4403600145758346, 0.9408164770263279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 266}], {
             RGBColor[
             0.26920304414348, 0.40027984622658896`, 0.9386420871625321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 293}], {
             RGBColor[
             0.3272740253136205, 0.45760414455430376`, 0.9420850575788042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 315}], {
             RGBColor[
             0.26224986664151034`, 0.39297161581510254`, 0.9382461139900993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 316}], {
             RGBColor[
             0.270003773674733, 0.40112146373312046`, 0.9386876875247638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 387}], {
             RGBColor[
             0.4198898949581986, 0.5356292280658739, 0.9485927029346032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 397}], {
             RGBColor[
             0.25928855226930214`, 0.38985908665173613`, 0.938077471517474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 214}], {
             RGBColor[
             0.23081730246588306`, 0.35993399792684283`, 0.9364560759606089]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 248}], {
             RGBColor[
             0.2199442042179371, 0.34850568227400514`, 0.9358368691006957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 263}], {
             RGBColor[
             0.30692109574993276`, 0.4322308872824815, 0.9410717536469021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 312}], {
             RGBColor[
             0.26239927833008236`, 0.39312865697304, 0.9382546227647286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 334}], {
             RGBColor[
             0.20343525046697647`, 0.3311537251536216, 0.9348967086073869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 340}], {
             RGBColor[
             0.21241214123474167`, 0.34058900651829105`, 0.9354079292564914]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 370}], {
             RGBColor[
             0.20448863330117922`, 0.3322608973006979, 0.9349566972014545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 268}], {
             RGBColor[
             0.5483496579696843, 0.6426701443947892, 0.9582447440009759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 270}], {
             RGBColor[
             0.38821783346100136`, 0.5106765077734281, 0.9459578749539519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 274}], {
             RGBColor[
             0.45520745425599235`, 0.5676199598754534, 0.950524688408067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 295}], {
             RGBColor[
             0.42318563987531466`, 0.5409638641564534, 0.9481859926578549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 310}], {
             RGBColor[
             0.34846775564587945`, 0.473552157244567, 0.9435237061098725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 324}], {
             RGBColor[
             0.5252330264468776, 0.6244698739960914, 0.9560373579630563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 351}], {
             RGBColor[
             0.6635629227613954, 0.7334014863107667, 0.9695355035700097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 373}], {
             RGBColor[
             0.34459378761093823`, 0.4694803712160838, 0.9433030893613046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 390}], {
             RGBColor[
             0.3400236714682391, 0.46467688938800766`, 0.9430428280078589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 227}], {
             RGBColor[
             0.2150440363795939, 0.343355295187321, 0.9355578117914507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 296}], {
             RGBColor[
             0.2337895217777734, 0.3630579888732283, 0.9366253394534165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 308}], {
             RGBColor[
             0.2120594900785835, 0.3402183477937941, 0.9353878462948488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 352}], {
             RGBColor[
             0.23111045171034733`, 0.3602421163695104, 0.9364727703764056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 248}], {
             RGBColor[
             0.22887195802400728`, 0.3578893175764699, 0.9363452914725232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 263}], {
             RGBColor[
             0.315848849556003, 0.4416145225849462, 0.9415801760187297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 312}], {
             RGBColor[
             0.2713270321361526, 0.4025122922755047, 0.9387630451365561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 340}], {
             RGBColor[
             0.22133989504081186`, 0.3499726418207558, 0.9359163516283189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 218}], {
             RGBColor[
             0.18692850160935742`, 0.31380408551593836`, 0.9339566736794921]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 229}], {
             RGBColor[
             0.19493972789376507`, 0.3222243922819345, 0.9344129011648419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 329}], {
             RGBColor[
             0.1867198905000643, 0.313584822013363, 0.9339447935854304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 349}], {
             RGBColor[
             0.192491042377818, 0.3196506685490453, 0.9342734521472142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 231}], {
             RGBColor[
             0.19095180161373265`, 0.3180328289124904, 0.9341857946628023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 235}], {
             RGBColor[
             0.1956123156574894, 0.32293132466613605`, 0.9344512040429815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 298}], {
             RGBColor[
             0.19835416070020614`, 0.3258131776490477, 0.9346073480619681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 313}], {
             RGBColor[
             0.2090389311379428, 0.3370435488326826, 0.9352158299316957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 361}], {
             RGBColor[
             0.20867332138388106`, 0.3366592698001664, 0.9351950089970731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 393}], {
             RGBColor[
             0.19153695040893678`, 0.31864785739682644`, 0.9342191180210391]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 396}], {
             RGBColor[
             0.19963425463605258`, 0.3271586375382656, 0.9346802475178853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 220}], {
             RGBColor[
             0.8144460532518553, 0.851406632354037, 0.7257595325601884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 230}], {
             RGBColor[
             0.8761820738662044, 0.4207616593515645, 0.27209490569893346`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 233}], {
             RGBColor[
             0.9762379710154455, 0.9784153903456743, 0.7203221374649382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 242}], {
             RGBColor[
             0.8992054802509515, 0.5977296497457392, 0.29414214565418556`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 244}], {
             RGBColor[
             0.9739175055905028, 0.9766847910311653, 0.7242500801550553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 264}], {
             RGBColor[
             0.8581806271651595, 0.8856725444548357, 0.7300501263511203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 321}], {
             RGBColor[
             0.7737155651854934, 0.8183397872541874, 0.7225530793389106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 357}], {
             RGBColor[
             0.9024235222483088, 0.6224649306924224, 0.29722374630511356`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 364}], {
             RGBColor[
             0.8761412762683021, 0.4204480711364659, 0.27205583787310783`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 366}], {
             RGBColor[
             0.6937344954214235, 0.7518077736561808, 0.7166986999905727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 229}], {
             RGBColor[
             0.19887179747769093`, 0.3263572467222515, 0.9346368267106708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 260}], {
             RGBColor[
             0.20772118523879674`, 0.3356585143427644, 0.9351407862521698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 329}], {
             RGBColor[
             0.19065196008399016`, 0.31771767645368004`, 0.9341687191312593]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 349}], {
             RGBColor[
             0.19642311196174383`, 0.3237835229893623, 0.9344973776930432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 284}], {
             RGBColor[
             0.3068620452246301, 0.43723797575946177`, 0.9408827842352088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 293}], {
             RGBColor[
             0.34300984476630975`, 0.47151962018566573`, 0.943077261890181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 338}], {
             RGBColor[
             0.28566284547896603`, 0.414956272719873, 0.9396755211710989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 233}], {
             RGBColor[
             0.7976144359577942, 0.8422371475965424, 0.9590360291130758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 244}], {
             RGBColor[
             0.7952939705328516, 0.8405065482820335, 0.9629639718031929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 321}], {
             RGBColor[
             0.5950920301278422, 0.6821615445050555, 0.961266970987048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 341}], {
             RGBColor[
             0.4860287842689018, 0.590440011686344, 0.9535595010943037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 366}], {
             RGBColor[
             0.5151109603637722, 0.615629530907049, 0.9554125916387102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 239}], {
             RGBColor[
             0.8526114029177259, 0.35936467056963683`, 0.1962114217734859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 255}], {
             RGBColor[
             0.8576770558672095, 0.3983014989226451, 0.2010622967587482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 268}], {
             RGBColor[
             0.7908356351545234, 0.6993648502734382, 0.6044361277879526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 324}], {
             RGBColor[
             0.7677190036317167, 0.6811645798747406, 0.602228741750033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 351}], {
             RGBColor[
             0.9060488999462345, 0.7900961921894157, 0.6157268873569864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 400}], {
             RGBColor[
             0.8675551125355545, 0.47422857106757765`, 0.2105215349800247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 333}], {
             RGBColor[
             0.21024933242430197`, 0.33831575732852015`, 0.9352847604943257]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 230}], {
             RGBColor[
             0.8551262609512963, 0.3448308384131614, 0.19723163473259725`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 242}], {
             RGBColor[
             0.8781496673360434, 0.5217988288073361, 0.2192788746878494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 245}], {
             RGBColor[
             0.8558540868670035, 0.35042522733663617`, 0.19792860165144016`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 328}], {
             RGBColor[
             0.8997164529222819, 0.6301219365340252, 0.23765071588506692`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 364}], {
             RGBColor[
             0.855085463353394, 0.3445172501980627, 0.19719256690677167`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 385}], {
             RGBColor[
             0.9621637338718393, 0.8751385282482187, 0.44853214930663265`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 290}], {
             RGBColor[
             0.18877579274929696`, 0.3157457056290379, 0.9340618741770893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 318}], {
             RGBColor[
             0.18686239314258873`, 0.3137346013258456, 0.9339529089001083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 345}], {
             RGBColor[
             0.17916076969846856`, 0.3056397067749454, 0.9335143128384965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 240}], {
             RGBColor[
             0.8493627071457939, 0.4666896772579783, 0.44827431990902944`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 243}], {
             RGBColor[
             0.9271182354136238, 0.9438506209861709, 0.9626670150045318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 337}], {
             RGBColor[
             0.9393785469822551, 0.9502915240338172, 0.7911384355526612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 367}], {
             RGBColor[
             0.6298962166593582, 0.7051035104774022, 0.9669932656124167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 398}], {
             RGBColor[
             0.6554022589203814, 0.7271955623129416, 0.9686184880711814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 234}], {
             RGBColor[
             0.6154815427973135, 0.6962991925345092, 0.964434228392668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 281}], {
             RGBColor[
             0.43696413947427415`, 0.552898107981546, 0.9490639464684518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 350}], {
             RGBColor[
             0.7195454075725961, 0.7758957836327975, 0.8505842343054555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 355}], {
             RGBColor[
             0.6054737407452027, 0.6884810215092875, 0.963436744212341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 392}], {
             RGBColor[
             0.7181621296927883, 0.7753237626808771, 0.8735087285822702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 395}], {
             RGBColor[
             0.45693963376297164`, 0.5697838781949226, 0.9504517090480242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 296}], {
             RGBColor[
             0.22621507415997788`, 0.35509676417920844`, 0.9361939858669741]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 308}], {
             RGBColor[
             0.20448504246078797`, 0.33225712309977423`, 0.9349564927084064]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 352}], {
             RGBColor[
             0.22353600409255178`, 0.3522808916754905, 0.9360414167899633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 375}], {
             RGBColor[
             0.1940331226429612, 0.32127149268124666`, 0.9343612713370109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 238}], {
             RGBColor[
             0.24678874654536498`, 0.3767209983024208, 0.9373656260733012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 273}], {
             RGBColor[
             0.1927101706170558, 0.31988098622201705`, 0.9342859311762677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 330}], {
             RGBColor[
             0.1947627843493959, 0.3220384133979338, 0.9344028244917546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 368}], {
             RGBColor[
             0.19438368850365684`, 0.3216399596279972, 0.9343812355441619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 260}], {
             RGBColor[
             0.21573241152320438`, 0.34407882110876054`, 0.9355970137375196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[
             0.1986631863683978, 0.3261379832196762, 0.934624946616609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 349}], {
             RGBColor[
             0.20443433824615148`, 0.33220382975535845`, 0.934953605178393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 233}], {
             RGBColor[
             0.8649609956701637, 0.4146486695132347, 0.42761257006752507`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 242}], {
             RGBColor[
             0.8292500198369269, 0.22583404667284962`, 0.17564315807000078`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 244}], {
             RGBColor[
             0.863414018720202, 0.41349493663689546`, 0.43023119852760305`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 245}], {
             RGBColor[
             0.8181022296024069, 0.1401472459374997, 0.16496802155179616`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 328}], {
             RGBColor[
             0.8350024631896295, 0.25838385457720503`, 0.18069489331394697`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 357}], {
             RGBColor[
             0.8308590408356056, 0.2382016871461912, 0.17718395839546475`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 364}], {
             RGBColor[
             0.8177179178456022, 0.13719325736821295`, 0.1646000041794619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 385}], {
             RGBColor[
             0.8766339838226677, 0.4217282490533341, 0.32128251559499077`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 235}], {
             RGBColor[
             0.18685346885052345`, 0.3137252213290522, 0.9339524006748775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 298}], {
             RGBColor[
             0.1895953138932402, 0.3166070743119639, 0.934108544693864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 336}], {
             RGBColor[
             0.1812731232878139, 0.3078599243283004, 0.9336346082504626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 393}], {
             RGBColor[
             0.18277810360197083`, 0.30944175405974256`, 0.933720314652935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 396}], {
             RGBColor[
             0.19087540782908663`, 0.31795253420118175`, 0.9341814441497811]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 257}], {
             RGBColor[
             0.30909861267997385`, 0.4408850865059202, 0.9409626882119364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 275}], {
             RGBColor[
             0.2669215798519661, 0.39788188260301705`, 0.9385121611462544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 279}], {
             RGBColor[
             0.48366351594508233`, 0.5856826936906501, 0.9540410765507529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 280}], {
             RGBColor[
             0.2733144461810522, 0.4046011904460226, 0.9388762254262976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 288}], {
             RGBColor[
             0.30023200699341346`, 0.43289325353174246`, 0.9404091406935988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 297}], {
             RGBColor[
             0.25100667694524614`, 0.38115431058492943`, 0.9376058309697055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 309}], {
             RGBColor[
             0.2963446868922668, 0.42880743363510754`, 0.9401877635646132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 325}], {
             RGBColor[
             0.29211597655452004`, 0.4243627909544146, 0.9399469447666949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 339}], {
             RGBColor[
             0.2733203034534184, 0.404607346810652, 0.9388765589892938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 242}], {
             RGBColor[
             0.8879844020549108, 0.5916166599074094, 0.4496598100227772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 244}], {
             RGBColor[
             0.9570858882964418, 0.9675153062736708, 0.9575265767079428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 264}], {
             RGBColor[
             0.8413490098710985, 0.8765030596973409, 0.9633266229040078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 307}], {
             RGBColor[
             0.6538804302709667, 0.7226974017073509, 0.9485082265240019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 348}], {
             RGBColor[
             0.6462730001834412, 0.7161082281260901, 0.948023487805811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 357}], {
             RGBColor[
             0.8912024440522681, 0.6163519408540925, 0.4527414106737052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 366}], {
             RGBColor[
             0.6769028781273625, 0.7426382888986862, 0.9499751965434602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[
             0.8137495240944908, 0.42044629252070553`, 0.4425717899514292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 246}], {
             RGBColor[
             0.8529840469746812, 0.885887262707637, 0.9857660876177745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 269}], {
             RGBColor[
             0.7646521215423732, 0.8160713160110501, 0.9771770354611466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 272}], {
             RGBColor[
             0.7633280108193825, 0.8150369106506357, 0.9770450604787972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 350}], {
             RGBColor[
             0.8897866044520348, 0.9121284341385445, 0.8654271636734474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 355}], {
             RGBColor[
             0.7757149376246414, 0.8247136720150343, 0.978279673580333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 392}], {
             RGBColor[
             0.888403326572227, 0.9115564131866241, 0.8883516579502622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 395}], {
             RGBColor[
             0.6271808306424103, 0.7060165287006694, 0.9652946384160161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 298}], {
             RGBColor[
             0.19425582793699694`, 0.3215055700656095, 0.9343739540740432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 313}], {
             RGBColor[
             0.2049405983747336, 0.3327359412492443, 0.9349824359437711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 317}], {
             RGBColor[
             0.19343401255220036`, 0.32064178999008336`, 0.934327152903646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 336}], {
             RGBColor[
             0.18593363733157064`, 0.312758420081946, 0.9339000176306419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 393}], {
             RGBColor[
             0.18743861764572758`, 0.31434024981338815`, 0.9339857240331143]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 396}], {
             RGBColor[
             0.19553592187284338`, 0.32285102995482734`, 0.9344468535299604]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 267}], {
             RGBColor[
             0.25338105975763014`, 0.38364993746531034`, 0.9377410485582862]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 284}], {
             RGBColor[
             0.26368702808225786`, 0.3944821636106265, 0.9383279582080599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 286}], {
             RGBColor[
             0.22281035809500455`, 0.3515181917234548, 0.9360000923239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 332}], {
             RGBColor[
             0.2395600162179548, 0.36912314440033817`, 0.9369539605751034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 367}], {
             RGBColor[
             0.3129287562528536, 0.440105110895209, 0.9413567694167602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 383}], {
             RGBColor[
             0.22956462143722656`, 0.3586173507411603, 0.9363847376292023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 398}], {
             RGBColor[
             0.3384347985138768, 0.4621971627307483, 0.9429819918755249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 251}], {
             RGBColor[
             0.19380336074719554`, 0.32102999836105145`, 0.9343481867369493]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 296}], {
             RGBColor[
             0.2211466738327187, 0.34976955408011773`, 0.935905347966363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 308}], {
             RGBColor[
             0.19941664213352878`, 0.3269299130006835, 0.9346678548077954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 380}], {
             RGBColor[
             0.20872851353399335`, 0.33671728024931885`, 0.9351981521083725]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 269}], {
             RGBColor[
             0.5167818424220354, 0.6108654129881752, 0.9574511707265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 272}], {
             RGBColor[
             0.5154577316990447, 0.6098310076277607, 0.9573191957441505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 280}], {
             RGBColor[
             0.2707591220181621, 0.40191538273391547`, 0.9387307034954844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 309}], {
             RGBColor[
             0.29378936272937667`, 0.4261216259230004, 0.9400422416338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 325}], {
             RGBColor[
             0.28956065239162987`, 0.42167698324230746`, 0.9398014228358818]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 339}], {
             RGBColor[
             0.27076497929052823`, 0.4019215390985449, 0.9387310370584805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 246}], {
             RGBColor[
             0.8585903956264433, 0.4560165722989594, 0.4468977431895056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 269}], {
             RGBColor[
             0.799702445338238, 0.4094726078345682, 0.44117170841842035`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 272}], {
             RGBColor[
             0.7988197048562442, 0.4087830042609585, 0.441083725096854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 350}], {
             RGBColor[
             0.8831254339446791, 0.4735106865862311, 0.3666717938932875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 355}], {
             RGBColor[
             0.8070776560597501, 0.415234178503891, 0.4419068004978779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 392}], {
             RGBColor[
             0.8822032486914739, 0.47312933928495077`, 0.3819547900778306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 242}], {
             RGBColor[
             0.8385504243860425, 0.29732103150061207`, 0.18454923596953843`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 243}], {
             RGBColor[
             0.877634681087591, 0.48865144168934355`, 0.43080856334956663`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 285}], {
             RGBColor[
             0.8858589617650177, 0.49305390399602456`, 0.3219788728271452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 337}], {
             RGBColor[
             0.8858082221333453, 0.4929453770544411, 0.3164561770483195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 357}], {
             RGBColor[
             0.8401594453847212, 0.3096886719739536, 0.1860900362950024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 399}], {
             RGBColor[
             0.8633179697637215, 0.41192221409589935`, 0.20524563001796006`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 270}], {
             RGBColor[
             0.31115624108701556`, 0.43971981464523346`, 0.9412017203817521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 310}], {
             RGBColor[
             0.2714061632718937, 0.40259546411637237`, 0.9387675515376726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 323}], {
             RGBColor[
             0.3309521511254019, 0.4568660369491151, 0.9424630982645621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 346}], {
             RGBColor[
             0.30713982911114474`, 0.4362410004624697, 0.9409457981622233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 389}], {
             RGBColor[
             0.23293094482355622`, 0.362155570057423, 0.9365764447660246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 390}], {
             RGBColor[
             0.2629620790942533, 0.393720196259813, 0.938286673435659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 244}], {
             RGBColor[
             0.886437425104949, 0.5904629270310702, 0.4522784384828552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 357}], {
             RGBColor[
             0.8538824472203527, 0.4151696775403659, 0.1992311983507169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 364}], {
             RGBColor[
             0.8407413242303493, 0.31416124776238763`, 0.18664724413471406`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 385}], {
             RGBColor[
             0.8996573902074148, 0.5986962394475088, 0.343329755550243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 337}], {
             RGBColor[
             0.981786507894951, 0.983234170680865, 0.764939800713467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 367}], {
             RGBColor[
             0.6723041775720541, 0.7380461571244501, 0.9407946307732227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 398}], {
             RGBColor[
             0.6978102198330773, 0.7601382089599893, 0.9424198532319874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 264}], {
             RGBColor[
             0.8390285444461558, 0.8747724603828321, 0.9672545655941249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 307}], {
             RGBColor[
             0.651559964846024, 0.7209668023928419, 0.952436169214119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 321}], {
             RGBColor[
             0.7545634824664897, 0.8074397031821838, 0.959757518581915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 341}], {
             RGBColor[
             0.6455002366075493, 0.7157181703634723, 0.9520500486891706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 348}], {
             RGBColor[
             0.6439525347584986, 0.7143776288115813, 0.9519514304959281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 357}], {
             RGBColor[
             0.8896554671023064, 0.6151982079777534, 0.4553600391337833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 366}], {
             RGBColor[
             0.6745824127024198, 0.7409076895841773, 0.9539031392335773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 328}], {
             RGBColor[
             0.8357302891053365, 0.26397824350067983`, 0.18139186023278991`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 364}], {
             RGBColor[
             0.8184457437613093, 0.14278764629168772`, 0.16529697109830485`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 400}], {
             RGBColor[
             0.829279530588777, 0.22606087924326346`, 0.17567141759930008`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 269}], {
             RGBColor[
             0.8319134288403021, 0.869426735678431, 0.9836659653182612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 272}], {
             RGBColor[
             0.8305893181173114, 0.8683923303180165, 0.9835339903359117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 350}], {
             RGBColor[
             0.9570479117499637, 0.9654838538059254, 0.8719160935305621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 355}], {
             RGBColor[
             0.8429762449225704, 0.8780690916824152, 0.9847686034374477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 392}], {
             RGBColor[
             0.955664633870156, 0.964911832854005, 0.8948405878073766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 395}], {
             RGBColor[
             0.6944421379403393, 0.7593719483680503, 0.9717835682731306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 253}], {
             RGBColor[
             0.19436046466415727`, 0.3216155499002067, 0.9343799129808589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 266}], {
             RGBColor[
             0.21519016549381775`, 0.3435088861514912, 0.9355661336283271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 301}], {
             RGBColor[
             0.1901623548072361, 0.317203070265044, 0.9341408368350541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 315}], {
             RGBColor[
             0.2082369879918481, 0.3362006557400048, 0.9351701604558942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 316}], {
             RGBColor[
             0.21599089502507074`, 0.3443505036580227, 0.9356117339905587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 343}], {
             RGBColor[
             0.18982443678675276`, 0.31684789700027605`, 0.9341215929036926]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 358}], {
             RGBColor[
             0.19420191296404457`, 0.3214489020106298, 0.9343708836960937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 359}], {
             RGBColor[
             0.1924159607622266, 0.31957175301060936`, 0.9342691763602797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 362}], {
             RGBColor[
             0.19339653330473627`, 0.32060239692467707`, 0.9343250185159485]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 363}], {
             RGBColor[
             0.20876443324933688`, 0.3367550341475864, 0.9352001976830229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 369}], {
             RGBColor[
             0.19411283179141248`, 0.32135527205012093`, 0.934365810655096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 397}], {
             RGBColor[
             0.20527567361963986`, 0.3330881265766384, 0.935001517983269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 276}], {
             RGBColor[
             0.22042799245848094`, 0.3490141743887628, 0.9358644201252941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 340}], {
             RGBColor[
             0.2104667967928659, 0.33854432616791813`, 0.9352971447684058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 360}], {
             RGBColor[
             0.20162405229043762`, 0.3292500410334822, 0.9347935635506606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 266}], {
             RGBColor[
             0.270914372535644, 0.40204801259274037`, 0.9387406633049027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 293}], {
             RGBColor[
             0.3289853537057845, 0.45937231092045516`, 0.9421836337211749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 315}], {
             RGBColor[
             0.2639611950336743, 0.39473978218125394`, 0.9383446901324698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 316}], {
             RGBColor[
             0.271715102066897, 0.4028896300992718, 0.9387862636671344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 387}], {
             RGBColor[
             0.4216012233503626, 0.5373973944320252, 0.9486912790769737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 397}], {
             RGBColor[
             0.26099988066146607`, 0.3916272530178875, 0.9381760476598446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 356}], {
             RGBColor[
             0.22666963106636354`, 0.3555745323083922, 0.9362198722103361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 363}], {
             RGBColor[
             0.2391241828797345, 0.3686650559284389, 0.9369291405112493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 372}], {
             RGBColor[
             0.22620791914637717`, 0.35508924380626006`, 0.9361935783995345]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 283}], {
             RGBColor[
             0.19962713488925782`, 0.32715115423296626`, 0.934679842058838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 308}], {
             RGBColor[
             0.1958872147734443, 0.3232202610666153, 0.9344668591409584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 380}], {
             RGBColor[
             0.20519908617390886`, 0.3330076283152506, 0.9349971564415356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 381}], {
             RGBColor[
             0.19321867549075944`, 0.3204154570853507, 0.9343148897765596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 282}], {
             RGBColor[
             0.31835440977210794`, 0.4463178036126423, 0.941647079240882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 300}], {
             RGBColor[
             0.6421328397168371, 0.7146709767757251, 0.9682477279637229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 367}], {
             RGBColor[
             0.372324185998124, 0.4969102291790325, 0.9449451457918181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 398}], {
             RGBColor[
             0.39783022825914727`, 0.5190022810145718, 0.9465703682505828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 266}], {
             RGBColor[
             0.21192263839001468`, 0.3400745079922101, 0.9353800527936387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 301}], {
             RGBColor[
             0.18689482770343305`, 0.31376869210576286`, 0.9339547560003658]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 315}], {
             RGBColor[
             0.20496946088804507`, 0.3327662775807237, 0.9349840796212059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 316}], {
             RGBColor[
             0.2127233679212677, 0.3409161254987416, 0.9354256531558705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 343}], {
             RGBColor[
             0.18655690968294972`, 0.31341351884099494`, 0.9339355120690042]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 358}], {
             RGBColor[
             0.19093438586024153`, 0.31801452385134865`, 0.9341848028614053]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 359}], {
             RGBColor[
             0.18914843365842357`, 0.3161373748513282, 0.9340830955255912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 362}], {
             RGBColor[
             0.19012900620093326`, 0.31716801876539596`, 0.9341389376812601]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 369}], {
             RGBColor[
             0.19084530468760944`, 0.3179208938908398, 0.9341797298204076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 394}], {
             RGBColor[
             0.1857625991924869, 0.31257864815332465`, 0.9338902772616493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 397}], {
             RGBColor[
             0.20200814651583682`, 0.3296537484173573, 0.9348154371485806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 303}], {
             RGBColor[
             0.20024144683233963`, 0.3277968350347721, 0.9347148262152034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 268}], {
             RGBColor[
             0.78336189520592, 0.43168674764690385`, 0.44388901313282986`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 324}], {
             RGBColor[
             0.767950807524049, 0.41955323404777206`, 0.4424174224408835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 328}], {
             RGBColor[
             0.8467511825783175, 0.34868966012032526`, 0.19194548026883534`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 351}], {
             RGBColor[
             0.8601707384003942, 0.4921743089242222, 0.4514161861788524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 400}], {
             RGBColor[
             0.840300424061758, 0.3107722958629089, 0.1862250376353455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 311}], {
             RGBColor[
             0.32702639881790146`, 0.45712063802367703`, 0.942079129357128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 313}], {
             RGBColor[
             0.28483799884386285`, 0.41277795475190926`, 0.9396765623907513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 386}], {
             RGBColor[
             0.556034698630532, 0.6458694921919914, 0.9601976146247932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 275}], {
             RGBColor[
             0.2809273627700829, 0.4112753166902168, 0.9393583772051975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 276}], {
             RGBColor[
             0.27298076036949565`, 0.4029229337235066, 0.9389058299544288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 279}], {
             RGBColor[
             0.4976692988631992, 0.5990761277778498, 0.9548872926096961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 280}], {
             RGBColor[
             0.2873202290991691, 0.41799462453322234`, 0.9397224414852408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 288}], {
             RGBColor[
             0.3142377899115303, 0.4462866876189422, 0.9412553567525421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 309}], {
             RGBColor[
             0.31035046981038367`, 0.4422008677223072, 0.9410339796235565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 325}], {
             RGBColor[
             0.30612175947263687`, 0.43775622504161427`, 0.9407931608256381]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 339}], {
             RGBColor[
             0.2873260863715352, 0.41800078089785175`, 0.939722775048237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 277}], {
             RGBColor[
             0.19561158896014919`, 0.3229305608611562, 0.9344511626586431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 302}], {
             RGBColor[
             0.18739149065206478`, 0.3142907163550246, 0.9339830402205433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 377}], {
             RGBColor[
             0.18407204095648846`, 0.3108017642597073, 0.933794002471066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 378}], {
             RGBColor[
             0.18711323001988966`, 0.3139982467878655, 0.9339671936891907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 379}], {
             RGBColor[
             0.19525485067885182`, 0.32255560630899927`, 0.9344308469412701]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 262}], {
             RGBColor[
             0.20019420515358305`, 0.3277471810351035, 0.934712135871486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 331}], {
             RGBColor[
             0.19269223822101744`, 0.31986213813680114`, 0.934284909952842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 335}], {
             RGBColor[
             0.18286996403264408`, 0.3095383051966678, 0.9337255459685665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 307}], {
             RGBColor[
             0.28646815305242945`, 0.41476449327789777`, 0.9397593961545982]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 329}], {
             RGBColor[
             0.20751257412950358`, 0.3354392508401891, 0.9351289061581081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 341}], {
             RGBColor[
             0.2804084248139549, 0.4095158612485281, 0.93937327562965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 349}], {
             RGBColor[
             0.21328372600725728`, 0.3415050973758713, 0.9354575647198919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 366}], {
             RGBColor[
             0.3094906009088253, 0.4347053804692331, 0.9412263661740565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 306}], {
             RGBColor[
             0.2313412040252819, 0.36048465168304844`, 0.9364859113793738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 284}], {
             RGBColor[
             0.24537509181412387`, 0.37523515754899955`, 0.9372851205276718]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 286}], {
             RGBColor[
             0.20449842182687056`, 0.3322711856618279, 0.9349572546435119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 331}], {
             RGBColor[
             0.20664951421908523`, 0.3345321201531805, 0.9350797561729924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 332}], {
             RGBColor[
             0.22124807994982085`, 0.34987613833871123`, 0.9359111228947152]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 338}], {
             RGBColor[
             0.22417589206845978`, 0.35295345450941085`, 0.9360778574635618]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 264}], {
             RGBColor[
             0.5576221544304325, 0.6488358128735436, 0.9596252327476064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 312}], {
             RGBColor[
             0.3474308254202023, 0.4748091816311434, 0.9433787228228494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 348}], {
             RGBColor[
             0.36254614474277536`, 0.48844098130229274`, 0.9443220976494096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 307}], {
             RGBColor[
             0.5358230864206805, 0.6299545558165122, 0.958236215410184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 312}], {
             RGBColor[
             0.5131003370105822, 0.6097335825641022, 0.9568081018654329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 348}], {
             RGBColor[
             0.5282156563331551, 0.6233653822352514, 0.957751476691993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 357}], {
             RGBColor[
             0.8124975481520774, 0.5545233769268668, 0.45922673659782653`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 366}], {
             RGBColor[
             0.5588455342770764, 0.6498954430078475, 0.9597031854296422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 291}], {
             RGBColor[
             0.18857894058274138`, 0.31553880152083974`, 0.9340506637374206]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 304}], {
             RGBColor[
             0.18543662898340038`, 0.31223603279586976`, 0.9338717137404716]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 378}], {
             RGBColor[
             0.19040066183963522`, 0.31745354606563403`, 0.9341544080680056]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 383}], {
             RGBColor[
             0.1991683094404495, 0.3266688995950551, 0.9346537126282998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 293}], {
             RGBColor[
             0.2908233203898157, 0.4192921425712095, 0.940009243857379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 315}], {
             RGBColor[
             0.22579916171770553`, 0.3546596138320083, 0.9361703002686741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 316}], {
             RGBColor[
             0.23355306875092818`, 0.36280946175002615`, 0.9366118738033387]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 338}], {
             RGBColor[
             0.23347632110247196`, 0.3627287951054168, 0.936607503138297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 397}], {
             RGBColor[
             0.22283784734549728`, 0.3515470846686418, 0.9360016577960488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 282}], {
             RGBColor[
             0.2615646860965489, 0.39225144761939246`, 0.9382070939716974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 332}], {
             RGBColor[
             0.24216572228766625`, 0.37186190669091185`, 0.9371023516809767]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 367}], {
             RGBColor[
             0.315534462322565, 0.44284387318578267`, 0.9415051605226336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 383}], {
             RGBColor[
             0.23217032750693795`, 0.361356113031734, 0.9365331287350758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 398}], {
             RGBColor[
             0.34104050458358826`, 0.46493592502132197`, 0.9431303829813984]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 270}], {
             RGBColor[
             0.5192310696539062, 0.6174490867384653, 0.9563893333020512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 274}], {
             RGBColor[
             0.5862206904488971, 0.6743925388404906, 0.9609561467561663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 295}], {
             RGBColor[
             0.5541988760682194, 0.6477364431214906, 0.9586174510059542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 324}], {
             RGBColor[
             0.6562462626397825, 0.7312424529611288, 0.9664688163111557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 351}], {
             RGBColor[
             0.7945761589543001, 0.8401740652758038, 0.979966961918109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 373}], {
             RGBColor[
             0.475607023803843, 0.5762529501811211, 0.9537345477094038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 272}], {
             RGBColor[
             0.7422573926850033, 0.7985763836214297, 0.9749449381792838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 350}], {
             RGBColor[
             0.8687159863176557, 0.8956679071093385, 0.8633270413739342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 355}], {
             RGBColor[
             0.7546443194902623, 0.8082531449858283, 0.9761795512808198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 392}], {
             RGBColor[
             0.8673327084378479, 0.8950958861574181, 0.8862515356507488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 395}], {
             RGBColor[
             0.6061102125080312, 0.6895560016714635, 0.9631945161165028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 295}], {
             RGBColor[
             0.3940670515595366, 0.5157428065001295, 0.9463305819589302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 310}], {
             RGBColor[
             0.3193491673301014, 0.4483310995882432, 0.9416682954109477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 324}], {
             RGBColor[
             0.49611443813109957`, 0.5992488163397677, 0.9541819472641316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 346}], {
             RGBColor[
             0.3550828331693524, 0.4819766359343405, 0.9438465420354984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 351}], {
             RGBColor[
             0.6344443344456173, 0.7081804286544429, 0.9676800928710849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 373}], {
             RGBColor[
             0.31547519929516016`, 0.44425931355976, 0.9414476786623798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 390}], {
             RGBColor[
             0.310905083152461, 0.4394558317316838, 0.9411874173089341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 287}], {
             RGBColor[
             0.18451611233351262`, 0.31126851143271117`, 0.9338192916790429]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 292}], {
             RGBColor[
             0.18674265418407987`, 0.3136087480885643, 0.9339460899435592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 371}], {
             RGBColor[
             0.1828236944867615, 0.3094896729702865, 0.9337229109863782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 374}], {
             RGBColor[
             0.184659451088446, 0.3114191695523481, 0.9338274546090857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 382}], {
             RGBColor[
             0.18049565541513857`, 0.3070427562998084, 0.9335903326052744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 384}], {
             RGBColor[
             0.18432884103510522`, 0.31107167742439884`, 0.9338086268556416]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 389}], {
             RGBColor[
             0.19087423447573804`, 0.31795130093241747`, 0.9341813773290437]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 391}], {
             RGBColor[
             0.1801133509320429, 0.3066409300485706, 0.9335685609305309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 350}], {
             RGBColor[
             0.867391875594665, 0.894633501748924, 0.8631950663915847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 392}], {
             RGBColor[
             0.8660085977148573, 0.8940614807970035, 0.8861195606683994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 395}], {
             RGBColor[
             0.6047861017850406, 0.688521596311049, 0.9630625411341533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 322}], {
             RGBColor[
             0.19086506728942945`, 0.31794166563837395`, 0.9341808552713451]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 330}], {
             RGBColor[
             0.18387764331179846`, 0.31059744000961553`, 0.9337829318127865]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 295}], {
             RGBColor[
             0.4610566723545275, 0.5726862586021548, 0.9508973954130453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 296}], {
             RGBColor[
             0.36901952314668135`, 0.4870709060931353, 0.9452488023460986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 319}], {
             RGBColor[
             0.47322013025663245`, 0.583220445923085, 0.9516727685977074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 324}], {
             RGBColor[
             0.5631040589260905, 0.6561922684417929, 0.9587487607182468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 351}], {
             RGBColor[
             0.7014339552406084, 0.7651238807564681, 0.9722469063252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 373}], {
             RGBColor[
             0.38246482009015115`, 0.5012027656617852, 0.9460144921164949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 276}], {
             RGBColor[
             0.2308037275414878, 0.35991972982060355`, 0.9364553028887468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 280}], {
             RGBColor[
             0.24514319627116127`, 0.3749914206303192, 0.9372719144195587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 288}], {
             RGBColor[
             0.2720607570835225, 0.40328348371603906`, 0.9388048296868601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 290}], {
             RGBColor[
             0.21848378643908228`, 0.34697069059259356`, 0.9357537004686844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 297}], {
             RGBColor[
             0.22283542703535522`, 0.35154454076922603`, 0.9360015199629668]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 318}], {
             RGBColor[
             0.21657038683237403`, 0.3449595862894012, 0.9356447351917034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 325}], {
             RGBColor[
             0.2639447266446291, 0.3947530211387112, 0.9383426337599561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 339}], {
             RGBColor[
             0.24514905354352745`, 0.3749975769949486, 0.9372722479825549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 288}], {
             RGBColor[
             0.2641141546829352, 0.39493110074932897`, 0.9383522824360913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 290}], {
             RGBColor[
             0.21053718403849497`, 0.33861830762588346`, 0.9353011532179156]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 297}], {
             RGBColor[
             0.21488882463476794`, 0.3431921578025159, 0.9355489727121981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 318}], {
             RGBColor[
             0.20862378443178675`, 0.3366072033226911, 0.9351921879409346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 278}], {
             RGBColor[
             0.23299059780069237`, 0.3622182691186103, 0.9365798419148239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 302}], {
             RGBColor[
             0.19959521355734036`, 0.32711760288919167`, 0.9346780241862087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 314}], {
             RGBColor[
             0.22024480085065679`, 0.34882162839392095`, 0.9358539876342362]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 352}], {
             RGBColor[
             0.22370886564436498`, 0.3524625801265016, 0.9360512609996132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 378}], {
             RGBColor[
             0.19931695292516527`, 0.3268251333220326, 0.934662177654856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 379}], {
             RGBColor[
             0.2074585735841274, 0.33538249284316635`, 0.9351258309069355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 314}], {
             RGBColor[
             0.2454200867859244, 0.3752824501172079, 0.9372876829247517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 319}], {
             RGBColor[
             0.35576382875700985`, 0.4778888141834562, 0.9440614916187484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 352}], {
             RGBColor[
             0.24888415157963256`, 0.37892340184978857`, 0.9374849562901288]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 379}], {
             RGBColor[
             0.232633859519395, 0.36184331456645336`, 0.936559526197451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.8332166202434534, 0.8669371947579207, 0.788972494773293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 288}], {
             RGBColor[
             0.4888026931766387, 0.5910842948036721, 0.9543337450913586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 309}], {
             RGBColor[
             0.48491537307549215`, 0.5869984749070372, 0.9541123679623731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 325}], {
             RGBColor[
             0.4806866627377453, 0.5825538322263442, 0.9538715491644547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 399}], {
             RGBColor[
             0.7994051322415094, 0.7452396599077329, 0.6138726305595152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 297}], {
             RGBColor[
             0.22922829336444137`, 0.3582638486122316, 0.9363655842430101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 309}], {
             RGBColor[
             0.27456630331146203`, 0.4059169716624097, 0.9389475168379178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 322}], {
             RGBColor[
             0.22572058379982396`, 0.354577023458187, 0.9361658253724963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 325}], {
             RGBColor[
             0.2703375929737152, 0.4014723289817168, 0.9387066980399994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 339}], {
             RGBColor[
             0.2515419198726136, 0.3817168848379542, 0.9376363122625981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 355}], {
             RGBColor[
             0.5971975343016019, 0.6813125874620714, 0.9629093916561169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 386}], {
             RGBColor[
             0.5947242732295994, 0.6793804571151425, 0.9626628801063983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 367}], {
             RGBColor[
             0.3211123825917724, 0.44870662104929115`, 0.9418228148301714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 383}], {
             RGBColor[
             0.23774824777614534`, 0.3672188608952424, 0.9368507830426136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 398}], {
             RGBColor[
             0.3466184248527956, 0.47079867288483046`, 0.9434480372889362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 294}], {
             RGBColor[
             0.19947004944091673`, 0.32698604746696713`, 0.934670896274942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 320}], {
             RGBColor[
             0.20238649627655553`, 0.330051418004633, 0.9348369836077353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 347}], {
             RGBColor[
             0.20341579469893528`, 0.33113327590784336`, 0.9348956006301792]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 373}], {
             RGBColor[
             0.2404157449182508, 0.3700225695206825, 0.937002693058648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 380}], {
             RGBColor[
             0.2145522876760556, 0.34283843612123366`, 0.9355298074302612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 381}], {
             RGBColor[
             0.20257187699290616`, 0.3302462648913338, 0.9348475407652852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 332}], {
             RGBColor[
             0.2524716906122939, 0.382694132836228, 0.9376892613307504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 338}], {
             RGBColor[
             0.2553995027309328, 0.3857714490069275, 0.9378559958995971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 367}], {
             RGBColor[
             0.3258404306471927, 0.4536760993310988, 0.9420920701724073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 399}], {
             RGBColor[
             0.9603875503566552, 0.868303119703074, 0.4348794443842956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 332}], {
             RGBColor[
             0.2115950206250406, 0.3397301609490563, 0.9353613954465905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 292}], {
             RGBColor[
             0.19215895018442095`, 0.31930161859792383`, 0.9342545399880867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 371}], {
             RGBColor[
             0.18823999048710255`, 0.315182543479646, 0.9340313610309057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 374}], {
             RGBColor[
             0.19007574708878708`, 0.31711204006170757`, 0.9341359046536132]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 382}], {
             RGBColor[
             0.18591195141547964`, 0.3127356268091679, 0.933898782649802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 384}], {
             RGBColor[
             0.18974513703544627`, 0.3167645479337583, 0.9341170769001692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 389}], {
             RGBColor[
             0.19629053047607914`, 0.32364417144177693`, 0.9344898273735713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 391}], {
             RGBColor[
             0.18552964693238397`, 0.31233380055793014`, 0.9338770109750585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 303}], {
             RGBColor[
             0.19970158242580874`, 0.32722940331412775`, 0.9346840817359092]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 376}], {
             RGBColor[
             0.19788479388924796`, 0.32531984337115605`, 0.93458061831645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 297}], {
             RGBColor[
             0.20256888353236238`, 0.33024311857450594`, 0.9348473702921356]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 318}], {
             RGBColor[
             0.1963038433293812, 0.3236581640946811, 0.9344905855208723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 345}], {
             RGBColor[
             0.18860221988526102`, 0.31556326954378094`, 0.9340519894592605]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 304}], {
             RGBColor[
             0.1840328398717771, 0.3107605614341833, 0.9337917700272845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 383}], {
             RGBColor[
             0.1977645203288262, 0.3251934282333686, 0.9345737689151127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 371}], {
             RGBColor[
             0.1904665323376698, 0.31752278013549917`, 0.934158159295422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 374}], {
             RGBColor[
             0.19230228893935433`, 0.31945227671756077`, 0.9342627029181295]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 382}], {
             RGBColor[
             0.1881384932660469, 0.31507586346502103`, 0.9340255809143183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 384}], {
             RGBColor[
             0.19197167888601352`, 0.3191047845896115, 0.9342438751646855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 389}], {
             RGBColor[
             0.1985170723266464, 0.32598440809763013`, 0.9346166256380877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 316}], {
             RGBColor[
             0.2916240499210687, 0.42013376007774095`, 0.9400548442196108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 387}], {
             RGBColor[
             0.4415101712045343, 0.5546415244104943, 0.9499598596294503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 320}], {
             RGBColor[
             0.19287620932606772`, 0.32005550343265077`, 0.9342953868351136]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 347}], {
             RGBColor[
             0.19390550774844745`, 0.3211373613358611, 0.9343540038575576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 380}], {
             RGBColor[
             0.20504200072556777`, 0.3328425215492514, 0.9349882106576397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 381}], {
             RGBColor[
             0.19306159004241835`, 0.32025035031935156`, 0.9343059439926636]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 310}], {
             RGBColor[
             0.3543169737444146, 0.4786184559712684, 0.9438964131148506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 324}], {
             RGBColor[
             0.5310822445454129, 0.6295361727227928, 0.9564100649680346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 351}], {
             RGBColor[
             0.6694121408599306, 0.7384677850374681, 0.9699082105749879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 373}], {
             RGBColor[
             0.3504430057094734, 0.4745466699427852, 0.9436757963662827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 390}], {
             RGBColor[
             0.34587288956677426`, 0.46974318811470905`, 0.943415535012837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 308}], {
             RGBColor[
             0.22323052785896746`, 0.35195981678568156`, 0.9360240203703722]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 373}], {
             RGBColor[
             0.25840585650162723`, 0.38893131743376574`, 0.9380272032993362]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 380}], {
             RGBColor[
             0.23254239925943204`, 0.3617471840343169, 0.9365543176709494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 318}], {
             RGBColor[
             0.20065548392565413`, 0.32823201427131354`, 0.9347384050151546]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 322}], {
             RGBColor[
             0.2034128145640179, 0.33113014359709375`, 0.9348954309159043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 339}], {
             RGBColor[
             0.22923415063680755`, 0.358270004976861, 0.9363659178060062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 313}], {
             RGBColor[
             0.20768244341745035`, 0.33561779423215604`, 0.9351385799627575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 361}], {
             RGBColor[
             0.2073168336633886, 0.33523351519963984`, 0.9351177590281349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 393}], {
             RGBColor[
             0.19018046268844432`, 0.31722210279629987`, 0.9341418680521008]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 396}], {
             RGBColor[
             0.19827776691556012`, 0.32573288293773905`, 0.9346029975489469]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 306}], {
             RGBColor[
             0.19518727715711093`, 0.32248458225324084`, 0.9344269987291731]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 342}], {
             RGBColor[
             0.18568831496489116`, 0.3125005707202294, 0.9338860468847814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 353}], {
             RGBColor[
             0.188841530987085, 0.3158148006849981, 0.9340656178724803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 319}], {
             RGBColor[
             0.6840306200166372, 0.7509595396670409, 0.9709177458785374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 343}], {
             RGBColor[
             0.18235879982602854`, 0.30900103920583233`, 0.9336964359231994]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 358}], {
             RGBColor[
             0.18673627600332035`, 0.31360204421618604`, 0.9339457267156006]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 359}], {
             RGBColor[
             0.1849503238015024, 0.31172489521616553`, 0.9338440193797866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 362}], {
             RGBColor[
             0.18593089634401205`, 0.31275553913023335`, 0.9338998615354555]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 369}], {
             RGBColor[
             0.18664719483068826`, 0.31350841425567716`, 0.9339406536746029]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 394}], {
             RGBColor[
             0.18156448933556574`, 0.30816616851816203`, 0.9336512011158447]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 397}], {
             RGBColor[
             0.19781003665891564`, 0.3252412687821946, 0.934576361002776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 314}], {
             RGBColor[
             0.21202470254257239`, 0.3401817838877893, 0.9353858651961364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 352}], {
             RGBColor[
             0.21548876733628058`, 0.34382273562037, 0.9355831385615135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 377}], {
             RGBColor[
             0.18805566555367964`, 0.3149888062877428, 0.9340208639986316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 379}], {
             RGBColor[
             0.199238475276043, 0.32674264833703476`, 0.9346577084688357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 376}], {
             RGBColor[
             0.21141869489039777`, 0.33954483142224945`, 0.9353513539568531]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 383}], {
             RGBColor[
             0.1946222087294852, 0.32189065950839857`, 0.9343948189181637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 334}], {
             RGBColor[
             0.18360707090558112`, 0.31031305125539965`, 0.9337675231145284]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 340}], {
             RGBColor[
             0.19258396167334632`, 0.31974833262006913`, 0.9342787437636328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 360}], {
             RGBColor[
             0.18374121717091801`, 0.3104540474856332, 0.9337751625458877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 370}], {
             RGBColor[
             0.18466045373978385`, 0.311420223402476, 0.9338275117085959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 342}], {
             RGBColor[
             0.1932134040418383, 0.3204099164583054, 0.934314589575342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 353}], {
             RGBColor[
             0.19636662006403216`, 0.3237241464230741, 0.9344941605630408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 361}], {
             RGBColor[
             0.21017418029056079`, 0.33823676767103766`, 0.9352804806914867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 312}], {
             RGBColor[
             0.32563175741045036`, 0.45592792457411196`, 0.9419897054854269]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 341}], {
             RGBColor[
             0.3422947785820742, 0.4709002657971524, 0.9430316985052297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 348}], {
             RGBColor[
             0.3407470767330234, 0.4695597242452613, 0.9429330803119872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 366}], {
             RGBColor[
             0.37137695467694465`, 0.4960897850178574, 0.9448847890496364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 325}], {
             RGBColor[
             0.2933678336849298, 0.42567857217080163`, 0.9400182361783151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 339}], {
             RGBColor[
             0.27457216058382816`, 0.4059231280270391, 0.9389478504009139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 323}], {
             RGBColor[
             0.33914507736848765`, 0.46547732189212476`, 0.9429296732937578]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 324}], {
             RGBColor[
             0.45636436031597766`, 0.5621244658109066, 0.9517477784200521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 346}], {
             RGBColor[
             0.31533275535423055`, 0.4448522854054794, 0.9414123731914188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 389}], {
             RGBColor[
             0.24112387106664201`, 0.3707668550004327, 0.9370430197952202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 390}], {
             RGBColor[
             0.27115500533733905`, 0.4023314812028227, 0.9387532484648545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 313}], {
             RGBColor[
             0.2605556138292256, 0.39119084868755866`, 0.938149628798862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 361}], {
             RGBColor[
             0.2601900040751639, 0.39080656965504246`, 0.9381288078642394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 386}], {
             RGBColor[
             0.5317523136158948, 0.6242823861276408, 0.958670681032904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 348}], {
             RGBColor[
             0.31802432732292496`, 0.44933875099285125`, 0.9415049667672362]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 366}], {
             RGBColor[
             0.3486542052668462, 0.4758688117654473, 0.9434566755048852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 361}], {
             RGBColor[
             0.2180016041011253, 0.34646388638327474`, 0.9357262408978626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 393}], {
             RGBColor[
             0.200865233126181, 0.3284524739799347, 0.9347503499218286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 396}], {
             RGBColor[
             0.20896253735329678`, 0.3369632541213739, 0.9352114794186747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 352}], {
             RGBColor[
             0.23613835462959704`, 0.3655267611250992, 0.9367591020095412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 379}], {
             RGBColor[
             0.21988806256935944`, 0.348446673841764, 0.9358336719168633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 316}], {
             RGBColor[
             0.22659989124895852`, 0.3555012313385397, 0.9362159006309058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 358}], {
             RGBColor[
             0.20481090918793238`, 0.33259962969114687`, 0.9349750503364407]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 359}], {
             RGBColor[
             0.2030249569861144, 0.33072248069112636`, 0.9348733430006266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 362}], {
             RGBColor[
             0.20400552952862408`, 0.3317531246051941, 0.9349291851562955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 363}], {
             RGBColor[
             0.2193734294732247, 0.3479057618281034, 0.9358043643233698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 369}], {
             RGBColor[
             0.20472182801530026`, 0.332505999730638, 0.934969977295443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 397}], {
             RGBColor[
             0.21588466984352767`, 0.3442388542571554, 0.935605684623616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 358}], {
             RGBColor[
             0.212564816221155, 0.34074947760916474`, 0.9354166238711052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 359}], {
             RGBColor[
             0.21077886401933704`, 0.3388723286091443, 0.9353149165352912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 362}], {
             RGBColor[
             0.2117594365618467, 0.339902972523212, 0.9353707586909601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 363}], {
             RGBColor[
             0.2271273365064473, 0.3560556097461213, 0.9362459378580343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 369}], {
             RGBColor[
             0.2124757350485229, 0.34065584764865586`, 0.9354115508301075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 397}], {
             RGBColor[
             0.2236385768767503, 0.3523887021751733, 0.9360472581582806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 326}], {
             RGBColor[
             0.19368284883535128`, 0.3209033327008066, 0.9343413237618512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 327}], {
             RGBColor[
             0.19548056477531295`, 0.3227928461354802, 0.9344437010251496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 336}], {
             RGBColor[
             0.1878536669894908, 0.3147764929893316, 0.9340093604792311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 396}], {
             RGBColor[
             0.19745595153076353`, 0.32486910286221293`, 0.9345561963785496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 345}], {
             RGBColor[
             0.18668882027855277`, 0.3135521652405886, 0.9339430241822795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 347}], {
             RGBColor[
             0.1968219545840863, 0.324202731873527, 0.9345200911903508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 380}], {
             RGBColor[
             0.20795844756120663`, 0.3359078920869173, 0.9351542979904328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 381}], {
             RGBColor[
             0.19597803687805715`, 0.32331572085701743`, 0.9344720313254569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 384}], {
             RGBColor[
             0.1926752609493727, 0.31984429394788133`, 0.9342839431223373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 341}], {
             RGBColor[
             0.44529829620254, 0.5573731665864943, 0.9503530478730258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 366}], {
             RGBColor[
             0.4743804722974104, 0.5825626858071993, 0.9522061384174323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 330}], {
             RGBColor[
             0.19291768102176954`, 0.3200990928142907, 0.934297748586832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 339}], {
             RGBColor[
             0.22572644107219014`, 0.3545831798228164, 0.9361661589354925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 346}], {
             RGBColor[
             0.37487874320773873`, 0.4991228582382221, 0.9451079199183084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 346}], {
             RGBColor[
             0.4920980261552287, 0.5957700021570038, 0.9539260250446029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 351}], {
             RGBColor[
             0.7714595274314936, 0.8219737948771062, 0.9777595758801894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 390}], {
             RGBColor[
             0.4479202761383373, 0.5532491979543472, 0.9512669003180385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 339}], {
             RGBColor[
             0.2703434502460814, 0.40147848534634617`, 0.9387070316029955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 327}], {
             RGBColor[
             0.19380937140054372`, 0.3210363159388178, 0.9343485290347655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 336}], {
             RGBColor[
             0.18618247361472157`, 0.3130199627926692, 0.9339141884888471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 336}], {
             RGBColor[
             0.18798018955468324`, 0.3149094762273428, 0.9340165657521455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 376}], {
             RGBColor[
             0.2026044968471712, 0.33028055042638454`, 0.9348493984177288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 364}], {
             RGBColor[
             0.8349616655917271, 0.2580702663621064, 0.18065582548812142`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 386}], {
             RGBColor[
             0.8151456848541535, 0.6567413505380229, 0.5948173850288303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 400}], {
             RGBColor[
             0.8566292392466625, 0.42461673226525787`, 0.20140471849011185`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 349}], {
             RGBColor[
             0.19621450085245074`, 0.32356425948678696`, 0.9344854975989814]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 335}], {
             RGBColor[
             0.18932527309814626`, 0.31632324431474484`, 0.9340931662700729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 338}], {
             RGBColor[
             0.2166739251358942, 0.34506841161110846`, 0.9356506315449178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 368}], {
             RGBColor[
             0.18664235406415453`, 0.3135033263031278, 0.9339403780001101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 340}], {
             RGBColor[
             0.1939578430419053, 0.32119236904753456`, 0.934356984275097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 360}], {
             RGBColor[
             0.185115098539477, 0.3118980839130987, 0.9338534030573518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 365}], {
             RGBColor[
             0.18295572293696874`, 0.30962844324254163`, 0.933730429811299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 370}], {
             RGBColor[
             0.18603433510834283`, 0.3128642598299414, 0.93390575222006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 394}], {
             RGBColor[
             0.17996762986719622`, 0.30648776797016763`, 0.9335602623314629]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 396}], {
             RGBColor[
             0.18995557631013382`, 0.31698573295407556`, 0.9341290611055455]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 367}], {
             RGBColor[
             0.6845644891406854, 0.7444870601720963, 0.7692660513213518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 398}], {
             RGBColor[
             0.7100705314017086, 0.7665791120076357, 0.7708912737801167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 399}], {
             RGBColor[
             0.9603114409091467, 0.8681403292906987, 0.42659540071605706`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 360}], {
             RGBColor[
             0.1940919893072422, 0.3213333652777681, 0.9343646237064562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 370}], {
             RGBColor[
             0.19501122587610803`, 0.3222995411946109, 0.9344169728691645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 348}], {
             RGBColor[
             0.33468734849454873`, 0.4643110922158917, 0.9425469597870388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 366}], {
             RGBColor[
             0.36531722643847, 0.49084115298848774`, 0.9444986685246879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 353}], {
             RGBColor[
             0.1868676578718124, 0.31374013489006275`, 0.9339532087186491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 358}], {
             RGBColor[
             0.18639835798283702`, 0.3132468709514181, 0.933926482784239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 359}], {
             RGBColor[
             0.18461240578101906`, 0.3113697219513976, 0.933824775448425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 362}], {
             RGBColor[
             0.18559297832352872`, 0.3124003658654654, 0.9338806176040938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 369}], {
             RGBColor[
             0.18630927681020493`, 0.31315324099090924`, 0.9339214097432413]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 354}], {
             RGBColor[
             0.2035510812828702, 0.3312754706852238, 0.9349033050009957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 356}], {
             RGBColor[
             0.19312061469136133`, 0.3203123889677695, 0.9343093053591018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 388}], {
             RGBColor[
             0.20538183242077535`, 0.3331997062074885, 0.9350075635699459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 390}], {
             RGBColor[
             0.30688867117659013`, 0.43597701754892004`, 0.9409314950894052]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 380}], {
             RGBColor[
             0.20898774598358635`, 0.3369897499901277, 0.9352129150128767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 381}], {
             RGBColor[
             0.1970073353004369, 0.3243975787602278, 0.9345306483479008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 384}], {
             RGBColor[
             0.19370455937175246`, 0.32092615185109175`, 0.9343425601447813]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 366}], {
             RGBColor[
             0.3637695245894192, 0.4895006114365967, 0.9444000503314454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 355}], {
             RGBColor[
             0.879778802399924, 0.9043102631133229, 0.8644296794931206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 392}], {
             RGBColor[
             0.9924671913475096, 0.9911530042849124, 0.7745016638630496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 395}], {
             RGBColor[
             0.7312446954176929, 0.785613119798958, 0.8514446443288036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 379}], {
             RGBColor[
             0.22335212736306764`, 0.3520876255743447, 0.9360309452822404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 371}], {
             RGBColor[
             0.20120013846367035`, 0.3288044807238608, 0.9347694222853504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 388}], {
             RGBColor[
             0.21768345542489445`, 0.346129491952765, 0.93570812280141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 392}], {
             RGBColor[
             0.8783955245201162, 0.9037382421614023, 0.8873541737699352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 395}], {
             RGBColor[
             0.6171730285902994, 0.6981983576754478, 0.9642971542356892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 363}], {
             RGBColor[
             0.2074463229173425, 0.3353696166156383, 0.9351251332495853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 372}], {
             RGBColor[
             0.1945300591839852, 0.3217938044934594, 0.9343895711378705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 364}], {
             RGBColor[
             0.8439593662277066, 0.3388965287090708, 0.18972884478564203`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 385}], {
             RGBColor[
             0.9028754322047721, 0.6234315203941919, 0.3464113562011709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 359}], {
             RGBColor[
             0.18898988195831087`, 0.3159707269617513, 0.934074066240826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 362}], {
             RGBColor[
             0.18997045450082056`, 0.31700137087581914`, 0.9341299083964949]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 363}], {
             RGBColor[
             0.20533835444542115`, 0.3331540080987284, 0.9350050875635693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 369}], {
             RGBColor[
             0.19068675298749674`, 0.31775424600126295`, 0.9341707005356424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 372}], {
             RGBColor[
             0.19242209071206384`, 0.3195781959765495, 0.9342695254518545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 397}], {
             RGBColor[
             0.20184959481572412`, 0.3294871005277804, 0.9348064078638154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 362}], {
             RGBColor[
             0.18818450229900258`, 0.31512422187579864`, 0.9340282010606809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 369}], {
             RGBColor[
             0.18890080078567878`, 0.31587709700124245`, 0.9340689931998285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 394}], {
             RGBColor[
             0.18381809529055626`, 0.3105348512637273, 0.9337795406410702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 397}], {
             RGBColor[
             0.20006364261390616`, 0.32760995152775996`, 0.9347047005280014]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 370}], {
             RGBColor[
             0.18616848137367975`, 0.313005256060175, 0.9339133916514194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 393}], {
             RGBColor[
             0.20049962337211924`, 0.32806819494741857`, 0.934729528987206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 396}], {
             RGBColor[
             0.20859692759923504`, 0.3365789750888577, 0.935190658484052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 363}], {
             RGBColor[
             0.20453297478611288`, 0.3323075030127757, 0.9349592223834241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 369}], {
             RGBColor[
             0.18988137332818844`, 0.31690774091531027`, 0.9341248353554973]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 397}], {
             RGBColor[
             0.20104421515641585`, 0.32864059544182767`, 0.9347605426836703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 369}], {
             RGBColor[
             0.20524927327278905`, 0.33306037813821954`, 0.9350000145225716]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 372}], {
             RGBColor[
             0.20698461099735616`, 0.3348843281135061, 0.9350988394387836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 385}], {
             RGBColor[
             0.8765931862247653, 0.4214146608382354, 0.32124344776916525`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 370}], {
             RGBColor[
             0.18400910577117147`, 0.3107356153896179, 0.9337904184053665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 398}], {
             RGBColor[
             0.40058820107881166`, 0.5213910984512207, 0.9467461038398723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 372}], {
             RGBColor[
             0.19233300953943172`, 0.31948456601604064`, 0.9342644524108568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 389}], {
             RGBColor[
             0.194598112629328, 0.3218653329793524, 0.9343934466809067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 391}], {
             RGBColor[
             0.18383722908563283`, 0.3105549620955055, 0.9337806302823939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 380}], {
             RGBColor[
             0.24598769620290184`, 0.37587904360296687`, 0.9373200074413457]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 382}], {
             RGBColor[
             0.18605529017041303`, 0.3128862849288049, 0.9339069455798448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 384}], {
             RGBColor[
             0.18988847579037965`, 0.3169152060533953, 0.934125239830212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 389}], {
             RGBColor[
             0.19643386923101253`, 0.3237948295614139, 0.9344979903036141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 377}], {
             RGBColor[
             0.18266643619111367`, 0.3093243845308089, 0.9337139553590839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 379}], {
             RGBColor[
             0.19896021464386793`, 0.3264501787698757, 0.934641861937483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 381}], {
             RGBColor[
             0.20814382827755723`, 0.3361027389736181, 0.9351648551479828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 384}], {
             RGBColor[
             0.18572468011707222`, 0.3125387928008556, 0.9338881178264007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 389}], {
             RGBColor[
             0.1922700735577051, 0.31941841630887424`, 0.9342608682998029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 389}], {
             RGBColor[
             0.1961032591776717, 0.32344733743346465`, 0.93447916255017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 387}], {
             RGBColor[
             0.7642756795140044, 0.8115756260652711, 0.7955379877927361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 400}], {
             RGBColor[
             0.8203725249629105, 0.5288099921038794, 0.4560525726712711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 390}], {
             RGBColor[
             0.23267978688900162`, 0.3618915871438733, 0.9365621416932066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 395}], {
             RGBColor[
             0.729861417537885, 0.7850410988470374, 0.8743691386056183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 396}], {
             RGBColor[
             0.19146055662429076`, 0.3185675626855177, 0.9342147675080179]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.08420038484809576], {
             RGBColor[
             0.19354678877808446`, 0.32076032495391327`, 0.9343335753428726]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.08420038484809576], {
             RGBColor[
             0.18498575182454155`, 0.3117621323146461, 0.9338460369532876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.08420038484809576], {
             RGBColor[
             0.5818688834669836, 0.6714263983498019, 0.960225996443923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.08420038484809576], {
             RGBColor[
             0.23281884209063286`, 0.36203774297739677`, 0.9365700606812258]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.08420038484809576], {
             RGBColor[
             0.2824395297681887, 0.41419223185981874`, 0.9393958854372335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.08420038484809576], {
             RGBColor[
             0.30558851701585305`, 0.4385232851876776, 0.9407141860151303]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.08420038484809576], {
             RGBColor[
             0.4486453266434888, 0.5630157651939816, 0.9498082613856059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.08420038484809576], {
             RGBColor[
             0.2378122641398246, 0.36728614615234123`, 0.9368544286798214]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.08420038484809576], {
             RGBColor[
             0.19103464530579026`, 0.3181199028854364, 0.9341905124885087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.08420038484809576], {
             RGBColor[
             0.23750097993416716`, 0.3669589667156367, 0.9368367015048129]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.08420038484809576], {
             RGBColor[
             0.31196467996522614`, 0.44462985881031997`, 0.9410990914412173]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.08420038484809576], {
             RGBColor[
             0.3084761160714523, 0.441558334879467, 0.9408786305095267]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.08420038484809576], {
             RGBColor[
             0.21416269395992185`, 0.3424289484239088, 0.9355076206444797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.08420038484809576], {
             RGBColor[
             0.18454901891679482`, 0.31130309833813863`, 0.9338211656602798]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.08420038484809576], {
             RGBColor[
             0.28582560720535155`, 0.41775121393598635`, 0.9395887175380273]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.08420038484809576], {
             RGBColor[
             0.3177755060429437, 0.4496629042982282, 0.9414693521405777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.08420038484809576], {
             RGBColor[
             0.2316763474093035, 0.360836908628973, 0.9365049972992935]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.08420038484809576], {
             RGBColor[
             0.6051402883638863, 0.6903191732099512, 0.9620580066833722]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.08420038484809576], {
             RGBColor[
             0.26040419361571815`, 0.3910316964425663, 0.9381410056417089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.08420038484809576], {
             RGBColor[
             0.19028821830363388`, 0.31733536077996466`, 0.9341480045749757]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.08420038484809576], {
             RGBColor[
             0.9632021039744041, 0.8875341975281088, 0.3115475519504825]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.08420038484809576], {
             RGBColor[
             0.3162753653274515, 0.4483635578097335, 0.9413737645007089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.08420038484809576], {
             RGBColor[
             0.2930562064900811, 0.4253510322307103, 0.9400004894705796]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.08420038484809576], {
             RGBColor[
             0.8207868509580615, 0.16078242208563953`, 0.1675388179938171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.08420038484809576], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.08420038484809576], {
             RGBColor[
             0.18699939157323073`, 0.3138785953626525, 0.9339607107580624]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.08420038484809576], {
             RGBColor[
             0.821038236612611, 0.16271468238440395`, 0.16777954518051325`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.08420038484809576], {
             RGBColor[
             0.20698871416859752`, 0.3348886408066369, 0.9350990731083157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.08420038484809576], {
             RGBColor[
             0.1814383294461641, 0.30803356647540187`, 0.9336440164967801]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.08420038484809576], {
             RGBColor[
             0.18021067351487519`, 0.3067432222537355, 0.9335741033076473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.08420038484809576], {
             RGBColor[
             0.19647646719475834`, 0.3238396027221777, 0.9345004161946314]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.08420038484809576], {
             RGBColor[
             0.9570322462930174, 0.8667218188173162, 0.28757881993815293`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.08420038484809576], {
             RGBColor[
             0.2765417318743941, 0.4079932723314563, 0.939060014572192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.08420038484809576], {
             RGBColor[
             0.2632481201845229, 0.3940208435817391, 0.93830296305259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.08420038484809576], {
             RGBColor[
             0.2362515342121432, 0.36564572004235524`, 0.9367655474193329]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.08420038484809576], {
             RGBColor[
             0.19287789451893317`, 0.32005727467719974`, 0.9342954828043544]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.08420038484809576], {
             RGBColor[
             0.34879862256835453`, 0.4765335685653648, 0.9434461176929121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.08420038484809576], {
             RGBColor[
             0.22292982485851465`, 0.3516437588665342, 0.9360068957793466]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.08420038484809576], {
             RGBColor[
             0.18317563345981333`, 0.30985958314518375`, 0.9337429533902465]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.08420038484809576], {
             RGBColor[
             0.5210599224495296, 0.6220589443833571, 0.9554388922820652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.08420038484809576], {
             RGBColor[
             0.8718710063158469, 0.90067029040099, 0.9876410289824828]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.08420038484809576], {
             RGBColor[
             0.21651396498896067`, 0.34490028335462225`, 0.9356415220511897]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.08420038484809576], {
             RGBColor[
             0.26035980612556775`, 0.3909850423760888, 0.9381384778398102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.08420038484809576], {
             RGBColor[
             0.2366745638317519, 0.36609035099419096`, 0.9367896383303533]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.08420038484809576], {
             RGBColor[
             0.2848093981590889, 0.41668311379698936`, 0.9395308459361892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.08420038484809576], {
             RGBColor[
             0.20129344185623907`, 0.3289025485052273, 0.9347747357755273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.08420038484809576], {
             RGBColor[
             0.5441036538714303, 0.6407668836599264, 0.9572529792315668]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.08420038484809576], {
             RGBColor[
             0.24018804114120323`, 0.3697832384137522, 0.9369897256654027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.08420038484809576], {
             RGBColor[
             0.18767785554878408`, 0.3145917040180597, 0.9339993482777726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.08420038484809576], {
             RGBColor[
             0.1790362447681438, 0.3055088231778375, 0.9335072213279326]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.08420038484809576], {
             RGBColor[
             0.381577964086101, 0.5049253866504279, 0.9455347883487892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.08420038484809576], {
             RGBColor[
             0.17936539842637753`, 0.30585478454218845`, 0.9335259661418299]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.08420038484809576], {
             RGBColor[
             0.19239706134193654`, 0.319551888521592, 0.9342681000662533]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.08420038484809576], {
             RGBColor[
             0.1846123721443362, 0.31136968659711123`, 0.9338247735328656]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.08420038484809576], {
             RGBColor[
             0.9716313250190438, 0.9159679393868991, 0.3442934839840799]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.08420038484809576], {
             RGBColor[
             0.38165040818030865`, 0.5049881340836845, 0.9455394044224124]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.08420038484809576], {
             RGBColor[
             0.21768082531414856`, 0.3461267275396124, 0.9357079730204939]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.08420038484809576], {
             RGBColor[
             0.21195870855243037`, 0.3401124200198894, 0.9353821069360272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.08420038484809576], {
             RGBColor[
             0.3465121371910148, 0.4745531298536097, 0.9433004248665277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.08420038484809576], {
             RGBColor[
             0.186004909472108, 0.3128333316205655, 0.9339040764736078]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.08420038484809576], {
             RGBColor[
             0.20936457771848743`, 0.3373858240360207, 0.9352343750227069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.08420038484809576], {
             RGBColor[
             0.20110579749352597`, 0.32870532238267614`, 0.9347640497066657]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.08420038484809576], {
             RGBColor[
             0.1811814280726413, 0.30776354684334156`, 0.9336293863436095]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.08420038484809576], {
             RGBColor[
             0.18064334912177313`, 0.30719799174980317`, 0.933598743543374]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.08420038484809576], {
             RGBColor[
             0.2879462259501837, 0.4199801186917991, 0.9397094836383711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.08420038484809576], {
             RGBColor[
             0.2142707962291993, 0.34254257076299915`, 0.935513776908792]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.08420038484809576], {
             RGBColor[
             0.42522253205912725`, 0.5427281177888938, 0.9483157816266544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.08420038484809576], {
             RGBColor[
             0.27002626100566185`, 0.40114509934370585`, 0.9386889681449931]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.08420038484809576], {
             RGBColor[
             0.2418162773238607, 0.37149461787786187`, 0.9370824513072455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.08420038484809576], {
             RGBColor[
             0.22291581655962178`, 0.35162903525622036`, 0.9360060980274482]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.08420038484809576], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.08420038484809576], {
             RGBColor[
             0.18281412095909713`, 0.3094796105857146, 0.9337223657881405]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.08420038484809576], {
             RGBColor[
             0.9306153171117766, 0.762619883962795, 0.26302965936154776`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.08420038484809576], {
             RGBColor[
             0.8630600513163033, 0.8936446740513561, 0.986800632228994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.08420038484809576], {
             RGBColor[
             0.21796667840296896`, 0.34642717726009525`, 0.9357242519310205]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.08420038484809576], {
             RGBColor[
             0.1938965482594379, 0.32112794434484765`, 0.9343534936279129]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.08420038484809576], {
             RGBColor[
             0.18280925758947733`, 0.30947449887588874`, 0.9337220888264354]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.08420038484809576], {
             RGBColor[
             0.8199375785531087, 0.1542545422276314, 0.1667255537797183]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.08420038484809576], {
             RGBColor[
             0.23104392871496413`, 0.36017219648356114`, 0.9364689819902305]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.08420038484809576], {
             RGBColor[
             0.1798079986201722, 0.3063199854083397, 0.9335511715680982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.08420038484809576], {
             RGBColor[
             0.17955783501139488`, 0.30605704759422586`, 0.9335369251206622]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.08420038484809576], {
             RGBColor[
             0.1807265568208277, 0.30728544831718235`, 0.9336034820987404]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.08420038484809576], {
             RGBColor[
             0.9450344910434499, 0.9585273939347413, 0.9779264487494559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.08420038484809576], {
             RGBColor[
             0.3388378220394789, 0.4679060237916442, 0.9428114242912021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.08420038484809576], {
             RGBColor[
             0.24074527521724318`, 0.3703689267583512, 0.9370214593216792]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.08420038484809576], {
             RGBColor[
             0.4110226556238299, 0.5304288985271809, 0.947410978056655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.08420038484809576], {
             RGBColor[
             0.19817896485079942`, 0.32562903570326285`, 0.9345973709175234]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.08420038484809576], {
             RGBColor[
             0.19146940577852636`, 0.3185768637076881, 0.9342152714542605]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.08420038484809576], {
             RGBColor[
             0.1892450123424645, 0.31623888517169746`, 0.934088595538772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.08420038484809576], {
             RGBColor[
             0.6083786689975903, 0.6929482364957771, 0.9623129438694364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.08420038484809576], {
             RGBColor[
             0.4932978290383352, 0.5995204262840937, 0.953253358592837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.08420038484809576], {
             RGBColor[
             0.49739045300864126`, 0.6028430027937971, 0.9535755449435551]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.08420038484809576], {
             RGBColor[
             0.2343202347626608, 0.3636158018694917, 0.9366555627727864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.08420038484809576], {
             RGBColor[
             0.18118663655961964`, 0.30776902129339295`, 0.9336296829592377]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.08420038484809576], {
             RGBColor[
             0.559409915392181, 0.6531931963016955, 0.9584579442071637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.08420038484809576], {
             RGBColor[
             0.7481991240396009, 0.803218109314472, 0.9755371544320737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.08420038484809576], {
             RGBColor[
             0.19288958051724012`, 0.32006955740235543`, 0.93429614830467]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.08420038484809576], {
             RGBColor[
             0.20101540430520026`, 0.32861031341048663`, 0.9347589019483153]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.08420038484809576], {
             RGBColor[
             0.965636915117815, 0.9738926480760296, 0.9430519187643377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.08420038484809576], {
             RGBColor[
             0.2101475089071078, 0.33820873435596516`, 0.9352789617956558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.08420038484809576], {
             RGBColor[
             0.1831002535865883, 0.30978035411906424`, 0.9337386606179808]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.08420038484809576], {
             RGBColor[
             0.2774713947406823, 0.40897040694795533`, 0.9391129574971142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.08420038484809576], {
             RGBColor[
             0.19434739415987903`, 0.3216018119714924, 0.9343791686349763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.08420038484809576], {
             RGBColor[
             0.8190091230934095, 0.14711802671260676`, 0.16583646378296987`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.08420038484809576], {
             RGBColor[
             0.20947576509879728`, 0.3375026890224135, 0.9352407069795285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.08420038484809576], {
             RGBColor[
             0.22681870684301533`, 0.35573122040160343`, 0.9362283618552786]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.08420038484809576], {
             RGBColor[
             0.34861868121472545`, 0.4763777124089667, 0.9434346519889747]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.08420038484809576], {
             RGBColor[
             0.256153514960176, 0.38656396366699863`, 0.9378989357805914]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.08420038484809576], {
             RGBColor[
             0.18132254229683142`, 0.30791186684012395`, 0.9336374225899173]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.08420038484809576], {
             RGBColor[
             0.18343408206602244`, 0.3101312290168976, 0.9337576716560296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.08420038484809576], {
             RGBColor[
             0.18925042984728385`, 0.3162445793127523, 0.934088904057657]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.08420038484809576], {
             RGBColor[
             0.937107871400364, 0.788360698201582, 0.2682537209419814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.08420038484809576], {
             RGBColor[
             0.30752560771325343`, 0.4405592903292892, 0.9408245004646784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.08420038484809576], {
             RGBColor[
             0.24129060741956473`, 0.3709421054790498, 0.9370525151838548]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.08420038484809576], {
             RGBColor[
             0.8646080428941941, 0.47809856902505976`, 0.2087379710414105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.08420038484809576], {
             RGBColor[
             0.18333815129494635`, 0.31003039969413443`, 0.9337522085405336]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.08420038484809576], {
             RGBColor[
             0.22614100723621103`, 0.3550189151462153, 0.9361897678652379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.08420038484809576], {
             RGBColor[
             0.2388812891503496, 0.36840975921850344`, 0.93691530807269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.08420038484809576], {
             RGBColor[
             0.18241596627536708`, 0.30906112476864933`, 0.9336996914679191]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.08420038484809576], {
             RGBColor[
             0.5182991743784003, 0.6198176447289311, 0.9552215560809526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.08420038484809576], {
             RGBColor[
             0.3109061797336599, 0.4437130391115059, 0.9410316447424569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.08420038484809576], {
             RGBColor[
             0.5979628209588992, 0.6844921818293608, 0.9614929701573222]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.08420038484809576], {
             RGBColor[
             0.21169783120855037`, 0.3398382213908926, 0.9353672503572267]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.08420038484809576], {
             RGBColor[
             0.3097296345397099, 0.44269397479938727`, 0.9409566763230764]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.08420038484809576], {
             RGBColor[
             0.2615118954900493, 0.3921959613448436, 0.9382040876247539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.08420038484809576], {
             RGBColor[
             0.1865862227024127, 0.3134443286830033, 0.9339371814020978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.08420038484809576], {
             RGBColor[
             0.19480415931956344`, 0.32208190111490453`, 0.9344051807350968]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.08420038484809576], {
             RGBColor[
             0.19461177340916913`, 0.32187969132510885`, 0.9343942246421093]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.08420038484809576], {
             RGBColor[
             0.189088316742455, 0.3160741881610126, 0.9340796719561618]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.08420038484809576], {
             RGBColor[
             0.1820121662584413, 0.30863670534846055`, 0.9336766956543238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.08420038484809576], {
             RGBColor[
             0.21325644631447746`, 0.3414764246891273, 0.9354560111817448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.08420038484809576], {
             RGBColor[
             0.35827341580975897`, 0.4847401582541144, 0.9440498431400237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.08420038484809576], {
             RGBColor[
             0.18578718983175693`, 0.312604494474334, 0.9338916776621772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.08420038484809576], {
             RGBColor[
             0.830968185180272, 0.8680554911049849, 0.9837396813881922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.08420038484809576], {
             RGBColor[
             0.9948422584139026, 0.9913764372120322, 0.679989842123797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.08420038484809576], {
             RGBColor[
             0.18458947116943916`, 0.3113456162204888, 0.9338234693562242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.08420038484809576], {
             RGBColor[
             0.33446348254021346`, 0.46411719077807645`, 0.9425326952463855]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.08420038484809576], {
             RGBColor[
             0.18225239431662393`, 0.3088892002689491, 0.9336903762868517]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.08420038484809576], {
             RGBColor[
             0.18805967833656198`, 0.31499302397697726`, 0.9340210925206803]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.08420038484809576], {
             RGBColor[
             0.2256991535454318, 0.35455449890206425`, 0.9361646049512119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.08420038484809576], {
             RGBColor[
             0.8655975347340893, 0.482591620368333, 0.20956362728728348`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.08420038484809576], {
             RGBColor[
             0.18248883410320854`, 0.3091377134757978, 0.9337038411829164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.08420038484809576], {
             RGBColor[
             0.18504307948317125`, 0.3118223873186494, 0.9338493016786379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.08420038484809576], {
             RGBColor[
             0.1905501321581982, 0.3176106488474093, 0.9341629201815262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.08420038484809576], {
             RGBColor[
             0.1972575262297792, 0.3246605452899877, 0.9345448963512025]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.08420038484809576], {
             RGBColor[
             0.18614238840660097`, 0.3129778306973855, 0.9339119056955454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.08420038484809576], {
             RGBColor[
             0.1834762116557925, 0.31017550988691617`, 0.9337600708738418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.08420038484809576], {
             RGBColor[
             0.33397821749630197`, 0.46369687858717057`, 0.9425017745868906]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.08420038484809576], {
             RGBColor[
             0.21660346779159745`, 0.34499435647499893`, 0.9356466191033923]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.08420038484809576], {
             RGBColor[
             0.19354588592399127`, 0.3207593759970171, 0.9343335239266677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.08420038484809576], {
             RGBColor[
             0.19201931518110454`, 0.3191548533560677, 0.9342465879812193]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.08420038484809576], {
             RGBColor[
             0.25676930210776144`, 0.3872111950022711, 0.9379340039476709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.08420038484809576], {
             RGBColor[
             0.1824446187841665, 0.30909124037207153`, 0.9337013231859077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.08420038484809576], {
             RGBColor[
             0.2055125320888361, 0.33333707984545796`, 0.935015006722689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.08420038484809576], {
             RGBColor[
             0.2070813101039675, 0.3349859650056321, 0.9351043463098516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.08420038484809576], {
             RGBColor[
             0.8309858670902185, 0.23917652931476524`, 0.17730540736011186`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.08420038484809576], {
             RGBColor[
             0.1873941802353717, 0.31429354327760956`, 0.9339831933883338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.08420038484809576], {
             RGBColor[
             0.3387561380668311, 0.4678352732400925, 0.9428062194606953]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.08420038484809576], {
             RGBColor[
             0.1805122222555836, 0.3070601690995145, 0.9335912760623294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.08420038484809576], {
             RGBColor[
             0.4596234812344611, 0.572182073724828, 0.9506023905805157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.08420038484809576], {
             RGBColor[
             0.1994550789542851, 0.32697031253633363`, 0.9346700437278752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.08420038484809576], {
             RGBColor[
             0.27232886945688745`, 0.40356528681975196`, 0.9388200982898864]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.08420038484809576], {
             RGBColor[
             0.26679472020223177`, 0.3977485450677799, 0.938504936676874]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.08420038484809576], {
             RGBColor[
             0.20095261322947336`, 0.32854431600871353`, 0.9347553260894438]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.08420038484809576], {
             RGBColor[
             0.8967495440562933, 0.920507761085305, 0.9900139661214994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.08420038484809576], {
             RGBColor[
             0.9896948922783259, 0.9900065873749687, 0.82044583391943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.08420038484809576], {
             RGBColor[
             0.3102543804501736, 0.4431484833325346, 0.9409901126684767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.08420038484809576], {
             RGBColor[
             0.18420503135956878`, 0.31094154560542325`, 0.9338015760777798]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.08420038484809576], {
             RGBColor[
             0.8957887014800139, 0.9197416112963568, 0.9899223200988196]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.08420038484809576], {
             RGBColor[
             0.2316644133079956, 0.36082436513183264`, 0.936504317669879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.08420038484809576], {
             RGBColor[
             0.188962757776349, 0.315942217726737, 0.93407252155879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.08420038484809576], {
             RGBColor[
             0.8238032261936802, 0.18396760393066158`, 0.17042730232595416`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.08420038484809576], {
             RGBColor[
             0.2824798268544749, 0.4142345866524884, 0.9393981802966833]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.08420038484809576], {
             RGBColor[
             0.34399645769565007`, 0.4723741747164527, 0.943140127993611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.08420038484809576], {
             RGBColor[
             0.28165135838121924`, 0.41336381375916165`, 0.9393510002427407]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.08420038484809576], {
             RGBColor[
             0.23366891778676377`, 0.3629312264319425, 0.9366184712345461]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.08420038484809576], {
             RGBColor[
             0.8948525196191675, 0.9189951252924975, 0.9898330262371927]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.08420038484809576], {
             RGBColor[
             0.44169024668361, 0.5569916245052177, 0.9493650898406981]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.08420038484809576], {
             RGBColor[
             0.45394807471440896`, 0.5675745230376996, 0.950155601789558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.08420038484809576], {
             RGBColor[
             0.2585433275657887, 0.3890758082383683, 0.93803503207307]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.08420038484809576], {
             RGBColor[
             0.19492367816056405`, 0.3222075229947284, 0.9344119871562795]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.08420038484809576], {
             RGBColor[
             0.34853172220347034`, 0.47630239288410453`, 0.9434291110376724]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.08420038484809576], {
             RGBColor[
             0.3499869056482099, 0.4775627996442913, 0.943521834040003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.08420038484809576], {
             RGBColor[
             0.18311045325504194`, 0.3097910746173054, 0.9337392414740102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.08420038484809576], {
             RGBColor[
             0.3996003392677278, 0.5205354622018381, 0.9466831581588019]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.08420038484809576], {
             RGBColor[
             0.20685160848485196`, 0.33474453404001786`, 0.9350912651424561]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.08420038484809576], {
             RGBColor[
             0.43492032413853554`, 0.551127857862875, 0.9489337163625334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.08420038484809576], {
             RGBColor[
             0.2017846044041309, 0.3294187914845658, 0.9348027067560198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.08420038484809576], {
             RGBColor[
             0.266643234211289, 0.39758932368653244`, 0.9384963097737932]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.08420038484809576], {
             RGBColor[
             0.9562193148935751, 0.9668690172486966, 0.9589934594404549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.08420038484809576], {
             RGBColor[
             0.20722377740839654`, 0.33513570717553587`, 0.9351124596120775]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.08420038484809576], {
             RGBColor[
             0.18162114890697434`, 0.30822572132013676`, 0.933654427794616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.08420038484809576], {
             RGBColor[
             0.18694492825143932`, 0.3138213509582757, 0.9339576091524576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.08420038484809576], {
             RGBColor[
             0.9945316676487347, 0.9907121149708813, 0.6461839540792844]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.08420038484809576], {
             RGBColor[
             0.20184829587443234`, 0.32948573525812513`, 0.9348063338910304]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.08420038484809576], {
             RGBColor[
             0.18973547474422028`, 0.3167543922530552, 0.9341165266469779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.08420038484809576], {
             RGBColor[
             0.9643115115712477, 0.9729041642811488, 0.9452954812480678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.08420038484809576], {
             RGBColor[
             0.3533082208089774, 0.4804395559023944, 0.9437334653051234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.08420038484809576], {
             RGBColor[
             0.18648980339442428`, 0.3133429858769703, 0.9339316904651475]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.08420038484809576], {
             RGBColor[
             0.1842143453500115, 0.31095133519991963`, 0.9338021064957567]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.08420038484809576], {
             RGBColor[
             0.9490437648216794, 0.9615175037539616, 0.971139794028986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.08420038484809576], {
             RGBColor[
             0.2433593553333951, 0.37311649070267905`, 0.9371703273171091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.08420038484809576], {
             RGBColor[
             0.2257570420476589, 0.35461534338824796`, 0.9361679016157753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.08420038484809576], {
             RGBColor[
             0.19363457114614188`, 0.3208525897884652, 0.9343385744188711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.08420038484809576], {
             RGBColor[
             0.3500177192487492, 0.4775894888363419, 0.943523797455382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.08420038484809576], {
             RGBColor[
             0.7303132143006519, 0.7892455006884563, 0.9737544541026248]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.08420038484809576], {
             RGBColor[
             0.18775722726537172`, 0.31467512872465075`, 0.9340038683796124]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.08420038484809576], {
             RGBColor[
             0.9930152754848626, 0.9913796511608278, 0.7654184913108293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.08420038484809576], {
             RGBColor[
             0.33484250288537293`, 0.4644454791509371, 0.9425568460876246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.08420038484809576], {
             RGBColor[
             0.3056537490672848, 0.4385918482096833, 0.9407179008839572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.08420038484809576], {
             RGBColor[
             0.22188954865981286`, 0.3505503626243781, 0.9359476535887813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.08420038484809576], {
             RGBColor[
             0.41733642177677943`, 0.535897565429752, 0.9478132856528767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.08420038484809576], {
             RGBColor[
             0.22261848399738943`, 0.3513165198813409, 0.9359891653778931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.08420038484809576], {
             RGBColor[
             0.23974505627195325`, 0.36931763322930755`, 0.9369644983324363]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.08420038484809576], {
             RGBColor[
             0.18299643202543156`, 0.30967123107562133`, 0.9337327481336631]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.08420038484809576], {
             RGBColor[
             0.1997106484206986, 0.3272389322495743, 0.9346845980309063]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.08420038484809576], {
             RGBColor[
             0.9930695883095065, 0.987584875103169, 0.4870456409120508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.08420038484809576], {
             RGBColor[
             0.19086057119328328`, 0.3179369399562554, 0.934180599225321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.08420038484809576], {
             RGBColor[
             0.3371253879726633, 0.4664227994724073, 0.9427023095067106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.08420038484809576], {
             RGBColor[
             0.635822518194204, 0.7152283896049052, 0.9644734242083259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.08420038484809576], {
             RGBColor[
             0.9023083761464576, 0.6492869771870501, 0.2401960532268301]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.08420038484809576], {
             RGBColor[
             0.23238602207295528`, 0.3615828216964435, 0.9365454122215189]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.08420038484809576], {
             RGBColor[
             0.9299021495647822, 0.7597924122879596, 0.2624558280130423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.08420038484809576], {
             RGBColor[
             0.1793343425625045, 0.3058221428602024, 0.9335241975563253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.08420038484809576], {
             RGBColor[
             0.884710274500928, 0.9109079743391231, 0.9888656498437259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.08420038484809576], {
             RGBColor[
             0.44524034591787487`, 0.5600665420287623, 0.9495912990246761]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.08420038484809576], {
             RGBColor[
             0.20746958876179836`, 0.3353940704933011, 0.9351264582050084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.08420038484809576], {
             RGBColor[
             0.20359531165465325`, 0.33132195961033534`, 0.9349058238552358]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.08420038484809576], {
             RGBColor[
             0.20688302376209858`, 0.33477755348824767`, 0.9350930541960206]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.08420038484809576], {
             RGBColor[
             0.8177383166445533, 0.1373500514757623, 0.1646195380923747]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.08420038484809576], {
             RGBColor[
             0.18219295480676673`, 0.3088267255754066, 0.9336869912946982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.08420038484809576], {
             RGBColor[
             0.295092829761857, 0.42749165241872045`, 0.9401164721529931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.08420038484809576], {
             RGBColor[
             0.9594063537213845, 0.9692459055881796, 0.9535986340178257]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.08420038484809576], {
             RGBColor[
             0.7857227396767522, 0.8325318430402561, 0.9792771577606599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.08420038484809576], {
             RGBColor[
             0.1915139828942802, 0.31862371708269777`, 0.9342178100550568]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.08420038484809576], {
             RGBColor[
             0.25077535368791876`, 0.38091117517473666`, 0.9375926574524128]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.08420038484809576], {
             RGBColor[
             0.19733278810728, 0.3247396502951197, 0.9345491824037863]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.08420038484809576], {
             RGBColor[
             0.28998218143607674`, 0.4221200369945062, 0.9398254282913666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.08420038484809576], {
             RGBColor[
             0.82776291630336, 0.2144035172609302, 0.17421910604681382`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.08420038484809576], {
             RGBColor[
             0.8316889234682268, 0.24458052871740593`, 0.17797865494168116`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.08420038484809576], {
             RGBColor[
             0.2632132370288079, 0.3939841791733627, 0.938300976508477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.08420038484809576], {
             RGBColor[
             0.852273426221674, 0.40280203706702433`, 0.19769039802525293`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.08420038484809576], {
             RGBColor[
             0.9695261963263196, 0.9767932676332187, 0.9364683801653377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.08420038484809576], {
             RGBColor[
             0.9547654228714991, 0.9657847069591619, 0.9614545193980599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.08420038484809576], {
             RGBColor[
             0.818830055518114, 0.14574163486097447`, 0.1656649884706391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.08420038484809576], {
             RGBColor[
             0.9202453542726101, 0.9392426823750178, 0.9922550174748891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.08420038484809576], {
             RGBColor[
             0.1976279917679603, 0.3250499280594878, 0.9345659938155473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.08420038484809576], {
             RGBColor[
             0.21799885977606132`, 0.3464610019236322, 0.9357260846126101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.08420038484809576], {
             RGBColor[
             0.3090764058516128, 0.442128180941986, 0.9409150531686984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.08420038484809576], {
             RGBColor[
             0.25834749102875554`, 0.38886997162119286`, 0.9380238794720002]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.08420038484809576], {
             RGBColor[
             0.19027393338711107`, 0.3173203464269832, 0.9341471910701123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.08420038484809576], {
             RGBColor[
             0.3695662131784596, 0.4945214117423836, 0.9447694102025287]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.08420038484809576], {
             RGBColor[
             0.19109293756035423`, 0.31818117174092553`, 0.9341938321461705]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.08420038484809576], {
             RGBColor[
             0.18724741023772068`, 0.314139278704323, 0.9339748350540943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.08420038484809576], {
             RGBColor[
             0.8353613957275855, 0.2728087597904426, 0.18149541852470724`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.08420038484809576], {
             RGBColor[
             0.3513087838325387, 0.47870774408802763`, 0.9436060629490174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.08420038484809576], {
             RGBColor[
             0.32310439559809073`, 0.45427852059311985`, 0.9418089042708796]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.08420038484809576], {
             RGBColor[
             0.18340786605487358`, 0.31010367432698904`, 0.9337561786929778]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.08420038484809576], {
             RGBColor[
             0.18623692915551526`, 0.3130771990187241, 0.9339172896513356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.08420038484809576], {
             RGBColor[
             0.22458179928431016`, 0.35338008872927346`, 0.9361009732790185]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.08420038484809576], {
             RGBColor[
             0.2599700418165058, 0.39057537537478015`, 0.9381162813390138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.08420038484809576], {
             RGBColor[
             0.2141514811516508, 0.34241716305148284`, 0.9355069820916365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.08420038484809576], {
             RGBColor[
             0.3919526428400527, 0.5139114119405849, 0.9461958537050229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.08420038484809576], {
             RGBColor[
             0.7232916660208124, 0.7837602138065023, 0.9730546117901898]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.08420038484809576], {
             RGBColor[
             0.18998272969436467`, 0.3170142728825262, 0.9341306074506077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.08420038484809576], {
             RGBColor[
             0.23275233921967517`, 0.3619678442434947, 0.9365662734411069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.08420038484809576], {
             RGBColor[
             0.2559867658273416, 0.386388699755884, 0.9378894396641596]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.08420038484809576], {
             RGBColor[
             0.679362894162589, 0.7494427233598264, 0.9686762023490751]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.08420038484809576], {
             RGBColor[
             0.743581503407994, 0.7996107889818441, 0.9750769131616334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.08420038484809576], {
             RGBColor[
             0.3590992451452233, 0.4854554501171043, 0.9441024642550272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.08420038484809576], {
             RGBColor[
             0.17909981633317154`, 0.30557564092335165`, 0.9335108416345153]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.08420038484809576], {
             RGBColor[
             0.7409332819620127, 0.7975419782610151, 0.9748129631969344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.08420038484809576], {
             RGBColor[
             0.1818250295794584, 0.30844001283369876`, 0.9336660384972996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.08420038484809576], {
             RGBColor[
             0.49307848673520527`, 0.5993423543211548, 0.9532360911632574]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.08420038484809576], {
             RGBColor[
             0.23875032994207512`, 0.36827211278731364`, 0.9369078501395155]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.08420038484809576], {
             RGBColor[
             0.22285712514090053`, 0.35156734685389346`, 0.9360027556379781]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.08420038484809576], {
             RGBColor[
             0.20781531186542476`, 0.3357574473953233, 0.9351461466243084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.08420038484809576], {
             RGBColor[
             0.25816588373595994`, 0.3886790908418973, 0.9380135372053394]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.08420038484809576], {
             RGBColor[
             0.6722342021283076, 0.7438737349625797, 0.9679656809485127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.08420038484809576], {
             RGBColor[
             0.2515360626002474, 0.3817107284733248, 0.937635978699602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.08420038484809576], {
             RGBColor[
             0.4286879330306734, 0.5457296739343299, 0.9485365939122276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.08420038484809576], {
             RGBColor[
             0.2671426063657563, 0.39811419548290095`, 0.9385247482792353]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.08420038484809576], {
             RGBColor[
             0.20898033639140454`, 0.33698196203894937`, 0.9352124930475636]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.08420038484809576], {
             RGBColor[
             0.2765987024765969, 0.40805315204651627`, 0.939063258963707]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.08420038484809576], {
             RGBColor[
             0.9941990383585994, 0.9900006545532618, 0.6099793085980734]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.08420038484809576], {
             RGBColor[
             0.1948453625020903, 0.32212520827217295`, 0.9344075271953871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.08420038484809576], {
             RGBColor[
             0.1899324083338537, 0.31696138194207063`, 0.9341277417235704]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.08420038484809576], {
             RGBColor[
             0.30537118422496984`, 0.4382948546447645, 0.9407018092342045]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.08420038484809576], {
             RGBColor[
             0.1861676814246589, 0.31300441526303435`, 0.9339133460955061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.08420038484809576], {
             RGBColor[
             0.19821724293608944`, 0.32566926839787347`, 0.9345995507978533]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.08420038484809576], {
             RGBColor[
             0.18717515147111807`, 0.3140633301591533, 0.9339707200242335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.08420038484809576], {
             RGBColor[
             0.1943854920349882, 0.321641855253777, 0.934381338252603]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.08420038484809576], {
             RGBColor[
             0.3488943015599562, 0.47661644089892424`, 0.9434522142736513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.08420038484809576], {
             RGBColor[
             0.1899597624904289, 0.3169901328949849, 0.9341292995023205]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.08420038484809576], {
             RGBColor[
             0.4290348579738498, 0.5460301628831548, 0.9485586996628331]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.08420038484809576], {
             RGBColor[
             0.2449605595581574, 0.37479945786511576`, 0.9372615135289399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.08420038484809576], {
             RGBColor[
             0.20692052412863532`, 0.33481696875113837`, 0.935095189786418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.08420038484809576], {
             RGBColor[
             0.19699767297971368`, 0.3243874230485212, 0.9345300980930298]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.08420038484809576], {
             RGBColor[
             0.18766218808016377`, 0.31457523651516484`, 0.9339984560386126]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.08420038484809576], {
             RGBColor[
             0.9146994662552146, 0.9348205418090667, 0.9917260457249173]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.08420038484809576], {
             RGBColor[
             0.18269671784651187`, 0.30935621247060024`, 0.933715679854561]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.08420038484809576], {
             RGBColor[
             0.19137511524925596`, 0.3184777583830601, 0.9342099017481089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.08420038484809576], {
             RGBColor[
             0.21323548342695858`, 0.34145439136522115`, 0.9354548173763124]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.08420038484809576], {
             RGBColor[
             0.1808905282724361, 0.3074577927092133, 0.9336128200303355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.08420038484809576], {
             RGBColor[
             0.18223318953702214`, 0.3088690148279342, 0.9336892826030643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.08420038484809576], {
             RGBColor[
             0.20271236623405806`, 0.3303939279913168, 0.9348555414197336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.08420038484809576], {
             RGBColor[
             0.3483545068205488, 0.47614889782652203`, 0.9434178190301781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.08420038484809576], {
             RGBColor[
             0.20150049615977755`, 0.32912017570624735`, 0.9347865272118044]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.08420038484809576], {
             RGBColor[
             0.2975965440226766, 0.4301232148514946, 0.9402590549762334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.08420038484809576], {
             RGBColor[
             0.27959908951497947`, 0.4112067490593821, 0.9392341265668681]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.08420038484809576], {
             RGBColor[
             0.3027440138032642, 0.4355335319593264, 0.9405521957652387]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.08420038484809576], {
             RGBColor[
             0.3029090080003519, 0.4357069513217019, 0.9405615919406759]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.08420038484809576], {
             RGBColor[
             0.218367213855187, 0.3468481654157909, 0.9357470618324852]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.08420038484809576], {
             RGBColor[
             0.23267428983588884`, 0.3618858093925185, 0.936561828644164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.08420038484809576], {
             RGBColor[
             0.2188459842157359, 0.34735138342052185`, 0.9357743270962412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.08420038484809576], {
             RGBColor[
             0.23435379828218117`, 0.36365107925655765`, 0.9366574741655703]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.08420038484809576], {
             RGBColor[
             0.1953540422101205, 0.32265986289746895`, 0.9344364957522352]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.08420038484809576], {
             RGBColor[
             0.19439044372267295`, 0.3216470597914888, 0.9343816202438913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.08420038484809576], {
             RGBColor[
             0.4533617737780597, 0.567098537525015, 0.9501094460321575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.08420038484809576], {
             RGBColor[
             0.19579265616170655`, 0.32312087397031664`, 0.9344614741679068]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.08420038484809576], {
             RGBColor[
             0.5543615420614805, 0.6490946994052059, 0.9580605177657702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.08420038484809576], {
             RGBColor[
             0.1999051049994005, 0.32744331844304914`, 0.9346956720453906]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.08420038484809576], {
             RGBColor[
             0.3986910652219958, 0.5197478947248675, 0.9466252200206473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.08420038484809576], {
             RGBColor[
             0.6331296311169758, 0.713042182562431, 0.9642614302732361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.08420038484809576], {
             RGBColor[
             0.289139123347183, 0.42123392949010874`, 0.9397774173803968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.08420038484809576], {
             RGBColor[
             0.19201165546058205`, 0.31914680250414423`, 0.9342461517714671]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.08420038484809576], {
             RGBColor[
             0.19560708734050541`, 0.3229258293734914, 0.9344509062980639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.08420038484809576], {
             RGBColor[
             0.8695307562797816, 0.5004514607800906, 0.21284560375709155`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.08420038484809576], {
             RGBColor[
             0.19044334897469703`, 0.3174984129511047, 0.9341568390371975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.08420038484809576], {
             RGBColor[
             0.18593025704413854`, 0.31275486718553225`, 0.9338998251282734]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.08420038484809576], {
             RGBColor[
             0.19914754728651962`, 0.3266470772548782, 0.9346525302543484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.08420038484809576], {
             RGBColor[
             0.2283446787479909, 0.35733511362593967`, 0.9363152636977938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.08420038484809576], {
             RGBColor[
             0.18811264277564865`, 0.31504869296059673`, 0.9340241087671325]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.08420038484809576], {
             RGBColor[
             0.1849809522741401, 0.31175708768286514`, 0.9338457636259925]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.08420038484809576], {
             RGBColor[
             0.1795029989097729, 0.3059994113746115, 0.9335338022857975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.08420038484809576], {
             RGBColor[
             0.18035329176886106`, 0.3068931230811942, 0.933582225206227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.08420038484809576], {
             RGBColor[
             0.9940468194635823, 0.9896750737285114, 0.5934112212615963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.08420038484809576], {
             RGBColor[
             0.23420030298526878`, 0.3634897459673388, 0.9366487328354871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.08420038484809576], {
             RGBColor[
             0.2515477771449798, 0.3817230412025836, 0.9376366458255944]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.08420038484809576], {
             RGBColor[
             0.2029347338096705, 0.33062765041220404`, 0.9348682049242014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.08420038484809576], {
             RGBColor[
             0.3362350503435996, 0.46565163376778274`, 0.9426455779802814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.08420038484809576], {
             RGBColor[
             0.18371444184961855`, 0.31042590492529404`, 0.9337736377309502]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.08420038484809576], {
             RGBColor[
             0.1820208818055452, 0.30864586594106436`, 0.9336771919918379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.08420038484809576], {
             RGBColor[
             0.1912494582787511, 0.31834568493994736`, 0.9342027457695316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.08420038484809576], {
             RGBColor[
             0.1789871968344326, 0.3054572706896884, 0.9335044281206677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.08420038484809576], {
             RGBColor[
             0.3510664211934816, 0.47849782175157674`, 0.9435906198159696]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.08420038484809576], {
             RGBColor[
             0.19785125300646603`, 0.3252845897767374, 0.9345787082127948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.08420038484809576], {
             RGBColor[
             0.33313964664549794`, 0.4629705506640006, 0.9424483415937963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.08420038484809576], {
             RGBColor[
             0.2019856527302044, 0.3296301060224692, 0.9348141561607654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.08420038484809576], {
             RGBColor[
             0.9938504692273173, 0.9917250252368329, 0.751577169586235]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.08420038484809576], {
             RGBColor[
             0.9097894237460113, 0.9309054071917814, 0.9912577214871428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.08420038484809576], {
             RGBColor[
             0.2396024194233052, 0.3691677128576799, 0.9369563753749182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.08420038484809576], {
             RGBColor[
             0.19002087389400624`, 0.31705436485483146`, 0.934132779706348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.08420038484809576], {
             RGBColor[
             0.2158527042869893, 0.34420525643050026`, 0.9356038642324599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.08420038484809576], {
             RGBColor[
             0.7657071355725306, 0.8168955009898127, 0.9772821894000061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.08420038484809576], {
             RGBColor[
             0.19499177110397153`, 0.3222790929955916, 0.9344158649486721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.08420038484809576], {
             RGBColor[
             0.85710048921771, 0.439904958487049, 0.20231279900164487`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.08420038484809576], {
             RGBColor[
             0.19077583416012883`, 0.31784787596177183`, 0.9341757735766401]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.08420038484809576], {
             RGBColor[
             0.18720392975649292`, 0.3140935779617309, 0.9339723589050121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.08420038484809576], {
             RGBColor[
             0.18524924480481392`, 0.31203908014333226`, 0.9338610424887112]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.08420038484809576], {
             RGBColor[
             0.21763599434706354`, 0.34607960735075854`, 0.93570541996324]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.08420038484809576], {
             RGBColor[
             0.18916507484151227`, 0.3161548657898664, 0.9340840432163497]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.08420038484809576], {
             RGBColor[
             0.21990087473071346`, 0.348460140235685, 0.9358344015504985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.08420038484809576], {
             RGBColor[
             0.8176771202476999, 0.13687966915311423`, 0.16456093635363633`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.08420038484809576], {
             RGBColor[
             0.18093049359979738`, 0.3074997988022181, 0.9336150959966053]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.08420038484809576], {
             RGBColor[
             0.39439940253334044`, 0.5160306722091927, 0.9463517590690945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.08420038484809576], {
             RGBColor[
             0.37508215881778845`, 0.49929904661568136`, 0.9451208813811075]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.08420038484809576], {
             RGBColor[
             0.1851720653526604, 0.311957959645659, 0.9338566472330878]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.08420038484809576], {
             RGBColor[
             0.19059767181486464`, 0.3176606160407541, 0.9341656274946448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.08420038484809576], {
             RGBColor[
             0.18708771794254558`, 0.3139714319770177, 0.9339657408141276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.08420038484809576], {
             RGBColor[
             0.18654757264035143`, 0.3134037050172214, 0.9339349803382411]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.08420038484809576], {
             RGBColor[
             0.19406834726399882`, 0.3213085159913272, 0.9343632773270688]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.08420038484809576], {
             RGBColor[
             0.271851153445097, 0.4030631770024157, 0.9387928930697325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.08420038484809576], {
             RGBColor[
             0.19021908584372046`, 0.31726269818134456`, 0.934144067583656]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.08420038484809576], {
             RGBColor[
             0.180596656524124, 0.30714891486919227`, 0.9335960844690134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.08420038484809576], {
             RGBColor[
             0.209601906353837, 0.3376352714792777, 0.9352478905373938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.08420038484809576], {
             RGBColor[
             0.18473621585810335`, 0.3114998541924255, 0.9338318262491543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.08420038484809576], {
             RGBColor[
             0.19081859398490578`, 0.3178928192487419, 0.9341782086854036]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.08420038484809576], {
             RGBColor[
             0.20710183530283005`, 0.33500753829100943`, 0.9351055151895625]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.08420038484809576], {
             RGBColor[
             0.22012423896070668`, 0.348694910203518, 0.9358471218129588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.08420038484809576], {
             RGBColor[
             0.19616341759440778`, 0.32351056774371817`, 0.9344825884830068]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.08420038484809576], {
             RGBColor[
             0.1818914944971056, 0.30850987167626515`, 0.9336698235760336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.08420038484809576], {
             RGBColor[
             0.20835388918653433`, 0.3363235263075839, 0.9351768178059918]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.08420038484809576], {
             RGBColor[
             0.18955786573703887`, 0.316567713925446, 0.9341064120767679]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.08420038484809576], {
             RGBColor[
             0.9944253181788963, 0.9904846442084778, 0.6346084706002231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.08420038484809576], {
             RGBColor[
             0.7607606134285254, 0.8130312402959552, 0.9767891663005692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.08420038484809576], {
             RGBColor[
             0.5341260408491124, 0.6326666079220644, 0.9564675049852491]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.08420038484809576], {
             RGBColor[
             0.2195142065627996, 0.3480537274750297, 0.9358123813703602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.08420038484809576], {
             RGBColor[
             0.20264865261830456`, 0.3303269609414833, 0.9348519130235723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.08420038484809576], {
             RGBColor[
             0.2627109211596987, 0.39345621334626335`, 0.938272370362841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.08420038484809576], {
             RGBColor[
             0.18112688553091424`, 0.3077062191737896, 0.9336262802265466]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.08420038484809576], {
             RGBColor[
             0.9910839134677017, 0.9905809833329919, 0.7974261581398643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.08420038484809576], {
             RGBColor[
             0.18336325239717496`, 0.31005678254407854`, 0.9337536380111718]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.08420038484809576], {
             RGBColor[
             0.18043226082461958`, 0.30697612456572376`, 0.9335867223771283]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.08420038484809576], {
             RGBColor[
             0.46863892160806836`, 0.5795012143610829, 0.9513121190713723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.08420038484809576], {
             RGBColor[
             0.19955786085140656`, 0.3270783428269569, 0.9346758970048641]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.08420038484809576], {
             RGBColor[
             0.2129233554713194, 0.341126325093789, 0.9354370421509908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.08420038484809576], {
             RGBColor[
             0.4260942433398349, 0.54348315028676, 0.9483713262986371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.08420038484809576], {
             RGBColor[
             0.9265760623547111, 0.7466055848528861, 0.2597795801705179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.08420038484809576], {
             RGBColor[
             0.8501784807301029, 0.38669936800784144`, 0.19568427585662201`]},
             StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{{3.834946926643799*^9, 3.8349469478612347`*^9}, 
   3.834947050298876*^9, {3.8349471234738255`*^9, 3.8349471300172663`*^9}, {
   3.8349471617829676`*^9, 3.834947218900016*^9}, {3.8349472753220577`*^9, 
   3.834947307624898*^9}, 3.83494993428115*^9, 3.8349573375769677`*^9, {
   3.8349587473655295`*^9, 3.83495875945916*^9}, 3.8349597347259407`*^9, {
   3.8349608302048492`*^9, 3.8349608506752334`*^9}, {3.8349609902768755`*^9, 
   3.8349610664164815`*^9}, 3.8350239302838287`*^9, 3.8350518533754606`*^9, {
   3.8350562889758463`*^9, 3.835056304979375*^9}, 3.835056357550311*^9},
 Background->RGBColor[1, 1, 0.85],
 CellLabel->
  "Out[517]=",ExpressionUUID->"161c8605-f21a-4f54-bc7b-addd583912c3"]
}, Open  ]],

Cell["Estimated with cubic Mean Deviation v Calculated: (r=6)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 
  3.834950339812094*^9}},ExpressionUUID->"6ffc44da-2ba7-475e-ae41-\
f5e60dd8b2eb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraphb", "[", 
     RowBox[{"graphin4b", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsi4b", ",", "#"}], "}"}], "]"}], ",", "500", ",", 
      "400"}], "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"CMDi6400b", ",", "kri4b"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.834950273560528*^9, 3.834950273964845*^9}, {
   3.834957360267254*^9, 3.8349573712318316`*^9}, {3.8349587856645794`*^9, 
   3.83495878977224*^9}, {3.8349597483561287`*^9, 3.8349597561065383`*^9}, {
   3.8349611299039555`*^9, 3.8349611318954377`*^9}, 3.8350518701390076`*^9, {
   3.835056131233512*^9, 3.835056135529297*^9}, {3.8350562612719*^9, 
   3.8350562733815536`*^9}},
 CellLabel->
  "In[513]:=",ExpressionUUID->"dcc4e408-7e69-4eac-b934-f65849810ae9"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN2wucznW+wPHf/+zadNlSKJUyheimsIbchiJLGlM0NrNmJtWMMW5DaZZc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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[337, 399] -> 
             RGBColor[
              0.550240981151457, 0.6414624732103333, 0.9595697519196393], 
             UndirectedEdge[15, 92] -> 
             RGBColor[
              0.7764056453605941, 0.8255256626904539, 0.9782762290825093], 
             UndirectedEdge[87, 313] -> 
             RGBColor[
              0.7509645480082079, 0.8055883411400291, 0.9758545994520711], 
             UndirectedEdge[35, 214] -> 
             RGBColor[
              0.7016471325581453, 0.7198222042768123, 0.6277403103976471], 
             UndirectedEdge[105, 218] -> 
             RGBColor[
              0.6406695211034406, 0.7151813770677267, 0.9673360430545583], 
             UndirectedEdge[149, 316] -> 
             RGBColor[
              0.597453689214301, 0.6656125422325776, 0.936913640579905], 
             UndirectedEdge[160, 348] -> 
             RGBColor[
              0.7204216506396295, 0.7784200232022906, 0.917208785292715], 
             UndirectedEdge[17, 287] -> 
             RGBColor[
              0.703857535163733, 0.7616744024363535, 0.8112361826510528], 
             UndirectedEdge[268, 295] -> 
             RGBColor[
              0.6017752653159024, 0.6826916314265781, 0.9643059983190168], 
             UndirectedEdge[277, 379] -> 
             RGBColor[
              0.7249316145854172, 0.7846683749863977, 0.9735580275031597], 
             UndirectedEdge[10, 37] -> 
             RGBColor[
              0.4857475528256592, 0.588606413137615, 0.9540436728290641], 
             UndirectedEdge[118, 389] -> 
             RGBColor[
              0.8300411402954624, 0.8680577357311171, 0.9818638322236213], 
             UndirectedEdge[127, 313] -> 
             RGBColor[
              0.7824247086599694, 0.8303983339620308, 0.9788308987729388], 
             UndirectedEdge[92, 281] -> 
             RGBColor[
              0.8182726100446016, 0.8582324537023174, 0.9824491368531817], 
             UndirectedEdge[2, 193] -> 
             RGBColor[
              0.9196562997734311, 0.9337810213707347, 0.7256617313958362], 
             UndirectedEdge[265, 378] -> 
             RGBColor[
              0.7284524051874748, 0.7871829490137747, 0.9742308612461021], 
             UndirectedEdge[108, 367] -> 
             RGBColor[
              0.40121350303389725`, 0.5219327035761256, 0.9467859475275175], 
             UndirectedEdge[26, 342] -> 
             RGBColor[
              0.5030322436862208, 0.5999244034871805, 0.9561123575861538], 
             UndirectedEdge[57, 144] -> 
             RGBColor[
              0.6899952107787769, 0.7559693894531594, 0.9711944806094046], 
             UndirectedEdge[341, 348] -> 
             RGBColor[
              0.8544320725571748, 0.8859801739476242, 0.9286033267440322], 
             UndirectedEdge[232, 309] -> 
             RGBColor[
              0.5564724711352325, 0.6482441016284035, 0.959380947326801], 
             UndirectedEdge[23, 202] -> 
             RGBColor[
              0.6920295743158277, 0.7581320593692067, 0.9707663872087928], 
             UndirectedEdge[89, 170] -> 
             RGBColor[
              0.8112081550288142, 0.8526550397911754, 0.9817605707491033], 
             UndirectedEdge[291, 383] -> 
             RGBColor[
              0.6582577646183305, 0.7316757708421647, 0.9674474174234057], 
             UndirectedEdge[45, 140] -> 
             RGBColor[
              0.5869335728545162, 0.6731511842362005, 0.9619469504480949], 
             UndirectedEdge[213, 308] -> 
             RGBColor[
              0.8145178551614193, 0.8519404784491684, 0.7647415152309259], 
             UndirectedEdge[165, 386] -> 
             RGBColor[
              0.7476213099625231, 0.8013919496816593, 0.9481663630302922], 
             UndirectedEdge[347, 381] -> 
             RGBColor[
              0.5374446382154473, 0.6349556525986704, 0.9568406991140734], 
             UndirectedEdge[216, 396] -> 
             RGBColor[
              0.6014337655200893, 0.6873100509884055, 0.9617662156276678], 
             UndirectedEdge[39, 150] -> 
             RGBColor[
              0.8748128430672324, 0.9024899441017729, 0.9587998931544672], 
             UndirectedEdge[20, 378] -> 
             RGBColor[
              0.5867582037641814, 0.6648932363115894, 0.9644639569311502], 
             UndirectedEdge[363, 372] -> 
             RGBColor[
              0.9502218638491944, 0.9596225297271181, 0.8476879624969685], 
             UndirectedEdge[54, 318] -> 
             RGBColor[
              0.688706550030508, 0.7221257206488776, 0.6475096203775186], 
             UndirectedEdge[40, 246] -> 
             RGBColor[
              0.36772903632270354`, 0.48490461348478037`, 0.9452490339974988],
              UndirectedEdge[59, 178] -> 
             RGBColor[
              0.7058181966128774, 0.7691621057185469, 0.9720408443946633], 
             UndirectedEdge[172, 357] -> 
             RGBColor[
              0.8577323464741345, 0.8890416877190768, 0.951790352233833], 
             UndirectedEdge[268, 274] -> 
             RGBColor[
              0.8365783837252436, 0.8725289111399626, 0.984274787133695], 
             UndirectedEdge[122, 175] -> 
             RGBColor[
              0.8032354079784385, 0.8467916315455626, 0.9808690720478103], 
             UndirectedEdge[120, 341] -> 
             RGBColor[
              0.7822217176963554, 0.829970145545203, 0.9788822128234342], 
             UndirectedEdge[220, 366] -> 
             RGBColor[
              0.7373239635812449, 0.7947223513101236, 0.9744532200717374], 
             UndirectedEdge[202, 366] -> 
             RGBColor[
              0.611943235529995, 0.6955604497224105, 0.9627861337707897], 
             UndirectedEdge[17, 61] -> 
             RGBColor[
              0.9944822631443075, 0.9906064437314732, 0.6408065786616468], 
             UndirectedEdge[112, 279] -> 
             RGBColor[
              0.8061355122240128, 0.8492998587185725, 0.9752989988933082], 
             UndirectedEdge[129, 313] -> 
             RGBColor[
              0.7414569848176231, 0.7978696730310717, 0.9751061292503568], 
             UndirectedEdge[204, 318] -> 
             RGBColor[
              0.40769262808478357`, 0.5275445960449097, 0.9471987916464947], 
             UndirectedEdge[60, 335] -> 
             RGBColor[
              0.7169759695019617, 0.7770036393376897, 0.958922006442777], 
             UndirectedEdge[256, 386] -> 
             RGBColor[
              0.5268205132124719, 0.6267356514763702, 0.9558923870886633], 
             UndirectedEdge[7, 65] -> 
             RGBColor[
              0.5999894578068625, 0.6803170859749524, 0.9645732756649572], 
             UndirectedEdge[66, 280] -> 
             RGBColor[
              0.6660671829643523, 0.7367822981000101, 0.9690359707203096], 
             UndirectedEdge[147, 344] -> 
             RGBColor[
              0.7042434813977922, 0.7688351007101917, 0.9711865097717189], 
             UndirectedEdge[329, 349] -> 
             RGBColor[
              0.4890052262642882, 0.5944582631438093, 0.9533512238607029], 
             UndirectedEdge[170, 306] -> 
             RGBColor[
              0.7550195273949196, 0.8085462602526324, 0.9762169484982388], 
             UndirectedEdge[175, 178] -> 
             RGBColor[
              0.8675982931564137, 0.897263344907367, 0.9872334937870401], 
             UndirectedEdge[115, 166] -> 
             RGBColor[
              0.8688625474390186, 0.89778248969357, 0.9552183172744528], 
             UndirectedEdge[361, 396] -> 
             RGBColor[
              0.49632536981482767`, 0.599648713724611, 0.9541353749241173], 
             UndirectedEdge[80, 265] -> 
             RGBColor[
              0.4637789981044924, 0.5731106548417999, 0.9516051039843716], 
             UndirectedEdge[18, 288] -> 
             RGBColor[
              0.7339038833782691, 0.7920505586619866, 0.9741123384395713], 
             UndirectedEdge[225, 240] -> 
             RGBColor[
              0.7999168887649251, 0.8443390848403217, 0.9694786054638429], 
             UndirectedEdge[110, 251] -> 
             RGBColor[
              0.6787872784451698, 0.7468449144241862, 0.9703413522717208], 
             UndirectedEdge[56, 169] -> 
             RGBColor[
              0.8026753207207385, 0.5491568053936592, 0.45853433234890983`], 
             UndirectedEdge[87, 231] -> 
             RGBColor[
              0.5111867667646964, 0.6124662369890528, 0.9550974359825551], 
             UndirectedEdge[266, 315] -> 
             RGBColor[
              0.6480912895523244, 0.7164263838148396, 0.9297977374143932], 
             UndirectedEdge[31, 292] -> 
             RGBColor[
              0.5922445102883733, 0.6798497996200678, 0.9610428037944762], 
             UndirectedEdge[1, 87] -> 
             RGBColor[
              0.8107085286684994, 0.8491709544481362, 0.7909194794538341], 
             UndirectedEdge[231, 336] -> 
             RGBColor[
              0.3792090515347164, 0.5028735536634252, 0.9453838433357622], 
             UndirectedEdge[13, 309] -> 
             RGBColor[
              0.5749172812380847, 0.6626533274665005, 0.961219353621303], 
             UndirectedEdge[237, 296] -> 
             RGBColor[
              0.44703185727724754`, 0.5563407125198454, 0.9508498984159531], 
             UndirectedEdge[95, 312] -> 
             RGBColor[
              0.6744364623355104, 0.7440551301146154, 0.9692374230074808], 
             UndirectedEdge[108, 236] -> 
             RGBColor[
              0.48907390782130467`, 0.5934043913861208, 0.9536632249487375], 
             UndirectedEdge[48, 176] -> 
             RGBColor[
              0.4870870967992743, 0.5922099212274918, 0.953391179647087], 
             UndirectedEdge[49, 52] -> 
             RGBColor[
              0.7316842698124587, 0.7849742986932484, 0.7813214575864709], 
             UndirectedEdge[310, 390] -> 
             RGBColor[
              0.9140861208492821, 0.9335423714542975, 0.9643087655113634], 
             UndirectedEdge[343, 358] -> 
             RGBColor[
              0.8997427003252413, 0.9199792637335347, 0.8697319743986782], 
             UndirectedEdge[271, 374] -> 
             RGBColor[
              0.7281019734183005, 0.7871899551385411, 0.9738677600325154], 
             UndirectedEdge[57, 167] -> 
             RGBColor[
              0.5625036877124867, 0.6557048600441743, 0.9587014972970795], 
             UndirectedEdge[34, 214] -> 
             RGBColor[
              0.45097925234740005`, 0.5648430626419833, 0.9500106438623683], 
             UndirectedEdge[83, 220] -> 
             RGBColor[
              0.8924511385275986, 0.9162191670898593, 0.9580295802660157], 
             UndirectedEdge[9, 347] -> 
             RGBColor[
              0.5365751344751415, 0.6342025321613461, 0.9567852951046131], 
             UndirectedEdge[188, 238] -> 
             RGBColor[
              0.36833803034592205`, 0.4934576215031037, 0.9446911514784788], 
             UndirectedEdge[79, 137] -> 
             RGBColor[
              0.587670647692549, 0.6631023935168989, 0.9649325070391445], 
             UndirectedEdge[115, 197] -> 
             RGBColor[
              0.7926559604218686, 0.8378118111285922, 0.9479218873064672], 
             UndirectedEdge[67, 194] -> 
             RGBColor[
              0.665815425390837, 0.7373515960894211, 0.9683567685059362], 
             UndirectedEdge[75, 260] -> 
             RGBColor[
              0.6141215208405386, 0.6919210988952904, 0.9657667602256741], 
             UndirectedEdge[32, 387] -> 
             RGBColor[
              0.7184751528995892, 0.7792297298212871, 0.9732764930885544], 
             UndirectedEdge[76, 144] -> 
             RGBColor[
              0.9173874328406538, 0.9367697302918329, 0.9852520563075895], 
             UndirectedEdge[50, 164] -> 
             RGBColor[
              0.7835953710182283, 0.8300140319466123, 0.9350048451580517], 
             UndirectedEdge[279, 285] -> 
             RGBColor[
              0.8589230477636677, 0.40820536064492063`, 0.43709235305999306`],
              UndirectedEdge[137, 352] -> 
             RGBColor[
              0.5111437735970235, 0.6025567425457752, 0.9575073078409111], 
             UndirectedEdge[4, 275] -> 
             RGBColor[
              0.5960832901511294, 0.6793948165722092, 0.963241607511626], 
             UndirectedEdge[8, 373] -> 
             RGBColor[
              0.7905487041991222, 0.8364861737636305, 0.9580856626002052], 
             UndirectedEdge[41, 135] -> 
             RGBColor[
              0.5614349466322691, 0.6521045103189779, 0.9598824657394931], 
             UndirectedEdge[85, 211] -> 
             RGBColor[
              0.814526147910722, 0.8557310578490184, 0.9698772071921482], 
             UndirectedEdge[63, 139] -> 
             RGBColor[
              0.4867163351522188, 0.5922359858545324, 0.9532716227227143], 
             UndirectedEdge[55, 92] -> 
             RGBColor[
              0.8638220037021929, 0.894252234201218, 0.986873307927763], 
             UndirectedEdge[31, 371] -> 
             RGBColor[
              0.6014851412270099, 0.6873517601017327, 0.9617702601115121], 
             UndirectedEdge[99, 169] -> 
             RGBColor[
              0.8643030890164517, 0.5976119175654889, 0.46459427423367394`], 
             UndirectedEdge[71, 72] -> 
             RGBColor[
              0.4557791878286006, 0.5671687651789806, 0.9508226123423578], 
             UndirectedEdge[104, 112] -> 
             RGBColor[
              0.6763394131923488, 0.7470807570465684, 0.9683748500219977], 
             UndirectedEdge[389, 390] -> 
             RGBColor[
              0.8444586237373177, 0.8788102712755903, 0.9574587934384744], 
             UndirectedEdge[260, 349] -> 
             RGBColor[
              0.37637246986096473`, 0.5004166491883619, 0.9452030988598014], 
             UndirectedEdge[70, 284] -> 
             RGBColor[
              0.6988670753009798, 0.763002980181245, 0.9720874090210554], 
             UndirectedEdge[24, 172] -> 
             RGBColor[
              0.8428115452441585, 0.8779137785923302, 0.9770473767479653], 
             UndirectedEdge[343, 362] -> 
             RGBColor[
              0.7237977231542768, 0.7796464711771458, 0.8541667097334438], 
             UndirectedEdge[233, 307] -> 
             RGBColor[
              0.4090347327407802, 0.5287070596417927, 0.9472843093683982], 
             UndirectedEdge[79, 278] -> 
             RGBColor[
              0.719161988667535, 0.7794836989803546, 0.9736800417001032], 
             UndirectedEdge[1, 216] -> 
             RGBColor[
              0.7860051735323033, 0.8291156578751054, 0.7889747408461413], 
             UndirectedEdge[192, 374] -> 
             RGBColor[
              0.6054368587942212, 0.6850315221833084, 0.9649221418148282], 
             UndirectedEdge[152, 383] -> 
             RGBColor[
              0.7009470789847995, 0.7652114870183049, 0.9716527981340275], 
             UndirectedEdge[43, 121] -> 
             RGBColor[
              0.6931942707063745, 0.7587025000858297, 0.971289823732021], 
             UndirectedEdge[13, 280] -> 
             RGBColor[
              0.6121244455336619, 0.6943300879157134, 0.9637421873220309], 
             UndirectedEdge[246, 272] -> 
             RGBColor[
              0.3469121985753021, 0.4680045668135863, 0.9436102562754343], 
             UndirectedEdge[385, 387] -> 
             RGBColor[
              0.5210034630750824, 0.6220131081197149, 0.9554344475932912], 
             UndirectedEdge[90, 268] -> 
             RGBColor[
              0.6498696584443268, 0.7238524242179497, 0.9675076191400079], 
             UndirectedEdge[195, 363] -> 
             RGBColor[
              0.9324736043449815, 0.945470549362129, 0.8459951176613985], 
             UndirectedEdge[88, 109] -> 
             RGBColor[
              0.8887712182349439, 0.911392230013232, 0.8679116382179449], 
             UndirectedEdge[63, 318] -> 
             RGBColor[
              0.4982188360990746, 0.6021988740421913, 0.9540045519117857], 
             UndirectedEdge[257, 276] -> 
             RGBColor[
              0.43634389313642963`, 0.544606785525875, 0.9502867658960369], 
             UndirectedEdge[16, 106] -> 
             RGBColor[
              0.47881664908449867`, 0.5842982093334685, 0.9530709420932044], 
             UndirectedEdge[100, 227] -> 
             RGBColor[
              0.6820381866236844, 0.7493745523880195, 0.9707234183669872], 
             UndirectedEdge[195, 359] -> 
             RGBColor[
              0.8297179523915241, 0.8673045235641927, 0.9835551697075313], 
             UndirectedEdge[216, 313] -> 
             RGBColor[
              0.7262611928720117, 0.7855330445669984, 0.9739098608443783], 
             UndirectedEdge[12, 47] -> 
             RGBColor[
              0.7551388528045335, 0.8086394781695295, 0.9762288417399096], 
             UndirectedEdge[386, 400] -> 
             RGBColor[
              0.6733215256502096, 0.7429714439936991, 0.9692717132434672], 
             UndirectedEdge[180, 262] -> 
             RGBColor[
              0.6925947934866915, 0.7558425031962613, 0.9453221559679248], 
             UndirectedEdge[247, 359] -> 
             RGBColor[
              0.5830131000457074, 0.6680138353996141, 0.962434282737498], 
             UndirectedEdge[74, 141] -> 
             RGBColor[
              0.45475269888607367`, 0.5596333908620897, 0.9517285551967672], 
             UndirectedEdge[170, 171] -> 
             RGBColor[
              0.8588124672367791, 0.8904601211081067, 0.9809859301166002], 
             UndirectedEdge[207, 333] -> 
             RGBColor[
              0.2900239008777401, 0.4136232051940313, 0.9401405203420147], 
             UndirectedEdge[311, 313] -> 
             RGBColor[
              0.6963705813559715, 0.7612664995815734, 0.9715567624129178], 
             UndirectedEdge[161, 195] -> 
             RGBColor[
              0.6364412148114803, 0.711282469438358, 0.96717552124938], 
             UndirectedEdge[87, 129] -> 
             RGBColor[
              0.6176363180044238, 0.7004640130118596, 0.9630417399111401], 
             UndirectedEdge[198, 367] -> 
             RGBColor[
              0.5106599424295108, 0.6134731189518972, 0.9546595832454194], 
             UndirectedEdge[322, 330] -> 
             RGBColor[
              0.7685327568859874, 0.8191028978354025, 0.977563820925599], 
             UndirectedEdge[79, 314] -> 
             RGBColor[
              0.9288037563040457, 0.9458705710847778, 0.9862637907858274], 
             UndirectedEdge[56, 274] -> 
             RGBColor[
              0.7689156277505127, 0.8196042623212433, 0.9775483075721285], 
             UndirectedEdge[249, 316] -> 
             RGBColor[
              0.756518466802214, 0.8085622801785932, 0.9474510877196075], 
             UndirectedEdge[69, 294] -> 
             RGBColor[
              0.4971284582684924, 0.6020482098290373, 0.9537157540180174], 
             UndirectedEdge[6, 300] -> 
             RGBColor[
              0.8491592778071708, 0.882560574581619, 0.9854747640423259], 
             UndirectedEdge[36, 265] -> 
             RGBColor[
              0.5392178814807211, 0.6368003935316109, 0.9568683533317962], 
             UndirectedEdge[167, 395] -> 
             RGBColor[
              0.565175765585671, 0.6578741732373616, 0.9589118530554004], 
             UndirectedEdge[261, 306] -> 
             RGBColor[
              0.5507892474402771, 0.6424602296560491, 0.9593833811666707], 
             UndirectedEdge[35, 211] -> 
             RGBColor[
              0.8208727181824115, 0.8163604758747576, 0.637431012933031], 
             UndirectedEdge[54, 63] -> 
             RGBColor[
              0.7820985011930566, 0.7992621613247414, 0.6544979832621394], 
             UndirectedEdge[302, 314] -> 
             RGBColor[
              0.7106748450746947, 0.7721871215084835, 0.9664460547677458], 
             UndirectedEdge[54, 224] -> 
             RGBColor[
              0.9413930154034285, 0.9252108252567334, 0.6696499583821329], 
             UndirectedEdge[164, 389] -> 
             RGBColor[
              0.8534633221043734, 0.8855065221313982, 0.9413456947342161], 
             UndirectedEdge[113, 210] -> 
             RGBColor[
              0.8866339768485434, 0.8987961779807565, 0.6893460976943503], 
             UndirectedEdge[307, 348] -> 
             RGBColor[
              0.6766847683028088, 0.7405828452461669, 0.914409334932789], 
             UndirectedEdge[18, 74] -> 
             RGBColor[
              0.5325740441587834, 0.6204673101759673, 0.9594581948258788], 
             UndirectedEdge[41, 328] -> 
             RGBColor[
              0.6735546010678215, 0.7446090353649915, 0.968299803145739], 
             UndirectedEdge[63, 290] -> 
             RGBColor[
              0.7687811270788336, 0.8192732938711256, 0.9686835813065129], 
             UndirectedEdge[45, 288] -> 
             RGBColor[
              0.5488446230685248, 0.6433958071766439, 0.9581505998949003], 
             UndirectedEdge[249, 315] -> 
             RGBColor[
              0.4300475612276472, 0.5444395567004389, 0.9493050773391849], 
             UndirectedEdge[306, 342] -> 
             RGBColor[
              0.7258103039365063, 0.7857277928885995, 0.9733056460796166], 
             UndirectedEdge[163, 395] -> 
             RGBColor[
              0.579969906908794, 0.6695202263833853, 0.9603257108126237], 
             UndirectedEdge[378, 379] -> 
             RGBColor[
              0.8688620253747728, 0.8982710106751893, 0.9873540296941742], 
             UndirectedEdge[216, 235] -> 
             RGBColor[
              0.49312663719442495`, 0.5981649685030006, 0.9535759978335494], 
             UndirectedEdge[220, 321] -> 
             RGBColor[
              0.9035395392545895, 0.9211801604864814, 0.740409129897113], 
             UndirectedEdge[133, 199] -> 
             RGBColor[
              0.5675452916978789, 0.659797861281187, 0.9590983908308136], 
             UndirectedEdge[317, 396] -> 
             RGBColor[
              0.7400777204805107, 0.7968929103509143, 0.9748329739651291], 
             UndirectedEdge[177, 197] -> 
             RGBColor[
              0.7624805336869749, 0.8146743055624535, 0.9770641547047743], 
             UndirectedEdge[208, 242] -> 
             RGBColor[
              0.5888016184250872, 0.6770547049049411, 0.9607717667352698], 
             UndirectedEdge[51, 163] -> 
             RGBColor[
              0.7310166211098976, 0.7897950074339288, 0.97382456311966], 
             UndirectedEdge[188, 228] -> 
             RGBColor[
              0.48121285485622733`, 0.5879300510375824, 0.9527935968966843], 
             UndirectedEdge[95, 125] -> 
             RGBColor[
              0.6676997205564968, 0.7385859396516536, 0.9687070820171386], 
             UndirectedEdge[66, 203] -> 
             RGBColor[
              0.9233759239492215, 0.9397192819531597, 0.9157996481756185], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.5461916322846151, 0.6413619995937369, 0.9578697826268705], 
             UndirectedEdge[151, 265] -> 
             RGBColor[
              0.7259056771108969, 0.7851522571746037, 0.9739879520486672], 
             UndirectedEdge[76, 333] -> 
             RGBColor[
              0.5610769363566706, 0.6312866375719247, 0.9572436375399819], 
             UndirectedEdge[119, 336] -> 
             RGBColor[
              0.5558919410456059, 0.6462625110358898, 0.9599698397304772], 
             UndirectedEdge[183, 395] -> 
             RGBColor[
              0.5715274541250837, 0.6629249181037331, 0.9594842460183504], 
             UndirectedEdge[42, 204] -> 
             RGBColor[
              0.4220899039241341, 0.540014792748831, 0.948116173331967], 
             UndirectedEdge[12, 107] -> 
             RGBColor[
              0.8835404094718571, 0.908991936406996, 0.9438431253133389], 
             UndirectedEdge[234, 239] -> 
             RGBColor[
              0.6626142715383792, 0.7332813244816513, 0.9691521117635777], 
             UndirectedEdge[164, 287] -> 
             RGBColor[
              0.698614102601584, 0.7599254878083526, 0.9286178912492853], 
             UndirectedEdge[32, 194] -> 
             RGBColor[
              0.8300148855409866, 0.8675563228444845, 0.9835795022010407], 
             UndirectedEdge[6, 169] -> 
             RGBColor[
              0.8564583879594447, 0.5913567658813692, 0.4638460396438093], 
             UndirectedEdge[24, 240] -> 
             RGBColor[
              0.798079455842891, 0.8429687303755888, 0.9725889001215893], 
             UndirectedEdge[9, 381] -> 
             RGBColor[
              0.43752742135565803`, 0.5533859944358303, 0.949099838291843], 
             UndirectedEdge[43, 90] -> 
             RGBColor[
              0.6721742325307236, 0.7416374861529077, 0.9696350493278968], 
             UndirectedEdge[88, 157] -> 
             RGBColor[
              0.9477365621273508, 0.9581187667197077, 0.8736129821509762], 
             UndirectedEdge[100, 314] -> 
             RGBColor[
              0.9267564982607662, 0.9442381430924058, 0.9860685214860506], 
             UndirectedEdge[56, 296] -> 
             RGBColor[
              0.4937053551387346, 0.5934593186964433, 0.955052740178694], 
             UndirectedEdge[49, 235] -> 
             RGBColor[
              0.701363591769605, 0.7591421297969778, 0.7792706188323953], 
             UndirectedEdge[359, 362] -> 
             RGBColor[
              0.621849421101456, 0.7016295219268066, 0.9649150832081782], 
             UndirectedEdge[104, 285] -> 
             RGBColor[
              0.7723923150758917, 0.3400592928635846, 0.4324762538124528], 
             UndirectedEdge[80, 168] -> 
             RGBColor[
              0.5001456638517392, 0.6026347523950368, 0.954468021127481], 
             UndirectedEdge[311, 386] -> 
             RGBColor[
              0.5229818142998774, 0.6236192227677108, 0.9555901906486465], 
             UndirectedEdge[61, 173] -> 
             RGBColor[
              0.7643959888597809, 0.8115029978106483, 0.7815896344674036], 
             UndirectedEdge[118, 354] -> 
             RGBColor[
              0.9065640986864121, 0.928288089561377, 0.9893714995489508], 
             UndirectedEdge[154, 180] -> 
             RGBColor[
              0.5174597145690796, 0.61821372791092, 0.9554103341252971], 
             UndirectedEdge[17, 158] -> 
             RGBColor[
              0.8468678943866246, 0.8780068291300722, 0.8227839991837228], 
             UndirectedEdge[8, 237] -> 
             RGBColor[
              0.7796635963128269, 0.827649152813014, 0.957228747033932], 
             UndirectedEdge[55, 255] -> 
             RGBColor[
              0.7047364603348795, 0.7680642861908801, 0.9722084616200051], 
             UndirectedEdge[93, 214] -> 
             RGBColor[
              0.6251769440106045, 0.7037139093123657, 0.9654680428476183], 
             UndirectedEdge[129, 235] -> 
             RGBColor[
              0.5083224291400363, 0.6105015969670738, 0.9547722662395279], 
             UndirectedEdge[47, 158] -> 
             RGBColor[
              0.7132529174318032, 0.7759178671114533, 0.9720540431482767], 
             UndirectedEdge[106, 347] -> 
             RGBColor[
              0.6342241458859628, 0.713930758959223, 0.9643475944851905], 
             UndirectedEdge[169, 178] -> 
             RGBColor[
              0.8529367977952227, 0.588548745475437, 0.46351014723018513`], 
             UndirectedEdge[230, 385] -> 
             RGBColor[
              0.7095428716771801, 0.7713215406560057, 0.967789367848253], 
             UndirectedEdge[304, 383] -> 
             RGBColor[
              0.7489848108498164, 0.8034269025738917, 0.9731639757430828], 
             UndirectedEdge[100, 352] -> 
             RGBColor[
              0.8357201996301211, 0.8723194196032873, 0.984066935137937], 
             UndirectedEdge[87, 216] -> 
             RGBColor[
              0.6024405260588124, 0.6881273845477863, 0.9618454715051615], 
             UndirectedEdge[79, 277] -> 
             RGBColor[
              0.7595244189246761, 0.8122517381698636, 0.9768575200623991], 
             UndirectedEdge[217, 220] -> 
             RGBColor[
              0.9045839254625339, 0.9234139969816313, 0.8540841234273004], 
             UndirectedEdge[78, 104] -> 
             RGBColor[
              0.8254090941471912, 0.8638935852623262, 0.9537859541068614], 
             UndirectedEdge[170, 353] -> 
             RGBColor[
              0.6826259019845556, 0.7511785673434679, 0.9695574468312267], 
             UndirectedEdge[78, 385] -> 
             RGBColor[
              0.7228345148349925, 0.7812344263600339, 0.9452900829978171], 
             UndirectedEdge[40, 102] -> 
             RGBColor[
              0.5141837510743367, 0.616476558692985, 0.9548975748831643], 
             UndirectedEdge[41, 256] -> 
             RGBColor[
              0.6248598530975819, 0.7050764452893536, 0.9644663742107826], 
             UndirectedEdge[120, 217] -> 
             RGBColor[
              0.9183470901610364, 0.9343392133328129, 0.8554099112752303], 
             UndirectedEdge[210, 315] -> 
             RGBColor[
              0.6508331779186651, 0.7058542825722345, 0.6702939456388204], 
             UndirectedEdge[83, 187] -> 
             RGBColor[
              0.91495529828532, 0.9341142156332718, 0.9601890920258722], 
             UndirectedEdge[2, 305] -> 
             RGBColor[
              0.6980259480740647, 0.7628155430758485, 0.97145096401306], 
             UndirectedEdge[121, 175] -> 
             RGBColor[
              0.7026101561824372, 0.7662104715770396, 0.9721879192943881], 
             UndirectedEdge[36, 151] -> 
             RGBColor[
              0.700834075875806, 0.7647980018291924, 0.9720142237591394], 
             UndirectedEdge[70, 332] -> 
             RGBColor[
              0.6817605722249386, 0.748987577758438, 0.9707759711214753], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.44238709101877904`, 0.550932818921482, 0.9506332610678112], 
             UndirectedEdge[221, 400] -> 
             RGBColor[
              0.6933941548197858, 0.7592673086152002, 0.9708519041401595], 
             UndirectedEdge[49, 216] -> 
             RGBColor[
              0.7859741254977963, 0.8290492492687328, 0.7855953538963147], 
             UndirectedEdge[75, 349] -> 
             RGBColor[
              0.6329787033139581, 0.7082542425642171, 0.9669683232181285], 
             UndirectedEdge[62, 87] -> 
             RGBColor[
              0.7354366268080275, 0.7932067982691978, 0.974373532466059], 
             UndirectedEdge[38, 189] -> 
             RGBColor[
              0.3980731093231872, 0.519212652384686, 0.9465858444172122], 
             UndirectedEdge[49, 361] -> 
             RGBColor[
              0.6808657297925346, 0.7413879120049384, 0.777964513192764], 
             UndirectedEdge[107, 270] -> 
             RGBColor[
              0.8592135714385953, 0.8899876256445952, 0.94141845344541], 
             UndirectedEdge[5, 8] -> 
             RGBColor[
              0.8512334601808822, 0.8842169893333328, 0.9639130258904394], 
             UndirectedEdge[162, 340] -> 
             RGBColor[
              0.6796005690430253, 0.7496283967828193, 0.968699891559959], 
             UndirectedEdge[34, 85] -> 
             RGBColor[
              0.7047927139489283, 0.7672201792414829, 0.9608450029618356], 
             UndirectedEdge[21, 172] -> 
             RGBColor[
              0.733337822129366, 0.7916083473121188, 0.974055918744424], 
             UndirectedEdge[298, 393] -> 
             RGBColor[
              0.4966186332983669, 0.6022164047829146, 0.9535147844686935], 
             UndirectedEdge[164, 371] -> 
             RGBColor[
              0.7837037021917935, 0.8301019800735763, 0.9350133733848649], 
             UndirectedEdge[11, 85] -> 
             RGBColor[
              0.7691924442178586, 0.8195027814485876, 0.9659147856325907], 
             UndirectedEdge[202, 307] -> 
             RGBColor[
              0.465330520692237, 0.574485698904851, 0.9516953468633136], 
             UndirectedEdge[20, 265] -> 
             RGBColor[
              0.4225952812925188, 0.5348649361748365, 0.9490751773063721], 
             UndirectedEdge[195, 247] -> 
             RGBColor[
              0.6231745516101879, 0.6997915525752793, 0.9663301812014433], 
             UndirectedEdge[281, 355] -> 
             RGBColor[
              0.6567659509844009, 0.7300789349024746, 0.9675936914492407], 
             UndirectedEdge[298, 313] -> 
             RGBColor[
              0.6835597303393957, 0.7508660736040558, 0.9705482452931995], 
             UndirectedEdge[67, 210] -> 
             RGBColor[
              0.7648545712952058, 0.8021534391033905, 0.6782391158777774], 
             UndirectedEdge[11, 263] -> 
             RGBColor[
              0.7756995048170303, 0.824355736589116, 0.9549000293514036], 
             UndirectedEdge[88, 181] -> 
             RGBColor[
              0.8921248795242336, 0.914012135701195, 0.8682458998335147], 
             UndirectedEdge[212, 390] -> 
             RGBColor[
              0.7890625462455975, 0.8350667000252344, 0.9522572227638828], 
             UndirectedEdge[13, 203] -> 
             RGBColor[
              0.8694331865185311, 0.897267071768863, 0.9105058647773399], 
             UndirectedEdge[75, 105] -> 
             RGBColor[
              0.8668640333000341, 0.8966778660288428, 0.987163459426457], 
             UndirectedEdge[12, 270] -> 
             RGBColor[
              0.7583849534017231, 0.8111753566273323, 0.9765523827109028], 
             UndirectedEdge[127, 393] -> 
             RGBColor[
              0.5954836116189406, 0.6817486651408897, 0.9617974379484329], 
             UndirectedEdge[185, 208] -> 
             RGBColor[
              0.7752506772880643, 0.8210765150971246, 0.8439294389354455], 
             UndirectedEdge[246, 355] -> 
             RGBColor[
              0.3831407224261292, 0.49741651455208824`, 0.9464622983824269], 
             UndirectedEdge[62, 336] -> 
             RGBColor[
              0.6034589115780474, 0.6836141149435703, 0.964659939819266], 
             UndirectedEdge[118, 209] -> 
             RGBColor[
              0.8105339401477889, 0.8528185627155422, 0.9799195368180511], 
             UndirectedEdge[178, 352] -> 
             RGBColor[
              0.8024239384044123, 0.8457698847048409, 0.9808911080183056], 
             UndirectedEdge[17, 22] -> 
             RGBColor[
              0.8382360987366039, 0.8712636047641993, 0.8219236624620453], 
             UndirectedEdge[12, 158] -> 
             RGBColor[
              0.7408258560622545, 0.7974580563316569, 0.9748022559871986], 
             UndirectedEdge[200, 333] -> 
             RGBColor[
              0.28512754910395577`, 0.4093822313853751, 0.939828529136663], 
             UndirectedEdge[69, 295] -> 
             RGBColor[
              0.4688895710418067, 0.5775891050410229, 0.9519163970946005], 
             UndirectedEdge[181, 340] -> 
             RGBColor[
              0.7333714548791745, 0.7916346214718876, 0.9740592709426089], 
             UndirectedEdge[205, 284] -> 
             RGBColor[
              0.6561873682634705, 0.7289713402993204, 0.9680165804631935], 
             UndirectedEdge[283, 373] -> 
             RGBColor[
              0.6696295658594305, 0.7415155503378406, 0.967927201201681], 
             UndirectedEdge[302, 379] -> 
             RGBColor[
              0.6615726162003162, 0.7332306858070227, 0.9685701750586261], 
             UndirectedEdge[254, 303] -> 
             RGBColor[
              0.5284518585527099, 0.6273856978993034, 0.9562071383723527], 
             UndirectedEdge[38, 254] -> 
             RGBColor[
              0.4991689058956915, 0.6020222761117893, 0.9543412545229457], 
             UndirectedEdge[158, 209] -> 
             RGBColor[
              0.6912715808217484, 0.7587458798873328, 0.969863148942256], 
             UndirectedEdge[365, 370] -> 
             RGBColor[
              0.6536644372294975, 0.7291533907284006, 0.9662607933306312], 
             UndirectedEdge[61, 164] -> 
             RGBColor[
              0.9892388305821584, 0.9888575291034722, 0.7581882872598794], 
             UndirectedEdge[163, 167] -> 
             RGBColor[
              0.6513590881585093, 0.7274771797678696, 0.9659457286677888], 
             UndirectedEdge[62, 119] -> 
             RGBColor[
              0.7961624018886049, 0.8408793115098983, 0.9802667547304749], 
             UndirectedEdge[137, 197] -> 
             RGBColor[
              0.4374226286122936, 0.5445277101865831, 0.9504586035069407], 
             UndirectedEdge[265, 383] -> 
             RGBColor[
              0.5615627714589236, 0.6549409818417378, 0.9586274249229093], 
             UndirectedEdge[19, 338] -> 
             RGBColor[
              0.3722679180409021, 0.4968614927025966, 0.9449415604473397], 
             UndirectedEdge[69, 212] -> 
             RGBColor[
              0.5871012358373235, 0.6756742577188319, 0.9606379063892544], 
             UndirectedEdge[45, 275] -> 
             RGBColor[
              0.41467329377410156`, 0.5335908978065377, 0.9476435934914578], 
             UndirectedEdge[248, 360] -> 
             RGBColor[
              0.7197693551081722, 0.7787560874306461, 0.9453195661690021], 
             UndirectedEdge[188, 322] -> 
             RGBColor[
              0.5589370801270774, 0.6496862353638524, 0.9598311255482443], 
             UndirectedEdge[167, 183] -> 
             RGBColor[
              0.6429166353747989, 0.7208818714882175, 0.9651042638735154], 
             UndirectedEdge[141, 240] -> 
             RGBColor[
              0.645846858882023, 0.723220448944639, 0.9653625019633185], 
             UndirectedEdge[23, 220] -> 
             RGBColor[
              0.8174103023670776, 0.8572939609569197, 0.9824334735097404], 
             UndirectedEdge[123, 322] -> 
             RGBColor[
              0.8618735061911773, 0.888959935373872, 0.7626552575675152], 
             UndirectedEdge[177, 398] -> 
             RGBColor[
              0.8439860153535247, 0.8787845209006334, 0.9848887289704262], 
             UndirectedEdge[272, 395] -> 
             RGBColor[
              0.4760013457563527, 0.5854783619580882, 0.9518917160697734], 
             UndirectedEdge[85, 312] -> 
             RGBColor[
              0.7455029807735529, 0.8002706078263337, 0.9640498642928912], 
             UndirectedEdge[25, 328] -> 
             RGBColor[
              0.7384254876076415, 0.7955602144989885, 0.974692935228187], 
             UndirectedEdge[8, 121] -> 
             RGBColor[
              0.7367411728120639, 0.7928027957819512, 0.953849736625934], 
             UndirectedEdge[169, 319] -> 
             RGBColor[
              0.7521609669299537, 0.5086623386769114, 0.45420530201803855`], 
             UndirectedEdge[84, 167] -> 
             RGBColor[
              0.5755462074709694, 0.6662933651429299, 0.9597282522287914], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.8081624839728621, 0.8499467665092594, 0.9364391145456918], 
             UndirectedEdge[43, 213] -> 
             RGBColor[
              0.9332719084813919, 0.9452475059670055, 0.7763901543249878], 
             UndirectedEdge[170, 187] -> 
             RGBColor[
              0.8174456884558506, 0.85762867963256, 0.9823555122556858], 
             UndirectedEdge[89, 199] -> 
             RGBColor[
              0.7115821014734156, 0.7738210391031929, 0.9725181540664831], 
             UndirectedEdge[16, 373] -> 
             RGBColor[
              0.47346171989455804`, 0.5799508365802638, 0.9526493824516203], 
             UndirectedEdge[22, 158] -> 
             RGBColor[
              0.6903081250395036, 0.7579932209077078, 0.969767120673888], 
             UndirectedEdge[233, 264] -> 
             RGBColor[
              0.47171283147173015`, 0.5819215703587448, 0.9515748816668319], 
             UndirectedEdge[274, 296] -> 
             RGBColor[
              0.5697981208817502, 0.6531058284778736, 0.9625832815975179], 
             UndirectedEdge[97, 211] -> 
             RGBColor[
              0.532444507096899, 0.6288694652158279, 0.9572416247098428], 
             UndirectedEdge[1, 129] -> 
             RGBColor[
              0.8012009654779146, 0.8414522863391787, 0.7901710092521198], 
             UndirectedEdge[24, 141] -> 
             RGBColor[
              0.7920265712341109, 0.8382008779928765, 0.9720124699370616], 
             UndirectedEdge[347, 384] -> 
             RGBColor[
              0.569918627693792, 0.6617246423602374, 0.959285228534228], 
             UndirectedEdge[36, 378] -> 
             RGBColor[
              0.7033808039523839, 0.7668286936683636, 0.9722571329565743], 
             UndirectedEdge[174, 395] -> 
             RGBColor[
              0.521450376081851, 0.6223759322318112, 0.9554696302222803], 
             UndirectedEdge[104, 357] -> 
             RGBColor[
              0.8283198579413031, 0.8660644281340366, 0.948858790252213], 
             UndirectedEdge[47, 173] -> 
             RGBColor[
              0.631094616844377, 0.7100848050471199, 0.9649936407421907], 
             UndirectedEdge[127, 231] -> 
             RGBColor[
              0.5426469274164578, 0.6372762298110545, 0.9580737353034228], 
             UndirectedEdge[252, 367] -> 
             RGBColor[
              0.5733574216274447, 0.6635114407890819, 0.9601849288162003], 
             UndirectedEdge[158, 310] -> 
             RGBColor[
              0.7804062780813865, 0.8287171530816148, 0.9786574164207151], 
             UndirectedEdge[149, 397] -> 
             RGBColor[
              0.41344827374932813`, 0.5208811744054272, 0.9489520239274248], 
             UndirectedEdge[204, 345] -> 
             RGBColor[
              0.45217247778449843`, 0.5649719892881846, 0.9503366147330299], 
             UndirectedEdge[231, 396] -> 
             RGBColor[
              0.5101800062259734, 0.6116489034296719, 0.9550181801050615], 
             UndirectedEdge[162, 263] -> 
             RGBColor[
              0.8226479203083149, 0.8618454381187377, 0.9590233902926879], 
             UndirectedEdge[14, 196] -> 
             RGBColor[
              0.6148790353326674, 0.6946840689718852, 0.9648585573922963], 
             UndirectedEdge[43, 175] -> 
             RGBColor[
              0.8821734076058152, 0.9088851455383775, 0.9886236812145822], 
             UndirectedEdge[113, 397] -> 
             RGBColor[
              0.6941577482383832, 0.7603642886764006, 0.9705858481251453], 
             UndirectedEdge[126, 336] -> 
             RGBColor[
              0.3604885763375184, 0.48665881896605423`, 0.944190991210063], 
             UndirectedEdge[48, 173] -> 
             RGBColor[
              0.4521998131834253, 0.5638868527339291, 0.9506447248845167], 
             UndirectedEdge[28, 168] -> 
             RGBColor[
              0.6204479581893191, 0.7027466291769044, 0.9632630825258723], 
             UndirectedEdge[253, 359] -> 
             RGBColor[
              0.8736273344099984, 0.9017493749286702, 0.9680747090667278], 
             UndirectedEdge[41, 187] -> 
             RGBColor[
              0.7914983989848812, 0.8373584598911347, 0.9797693289324259], 
             UndirectedEdge[198, 398] -> 
             RGBColor[
              0.6750324736583591, 0.7450011913802392, 0.9689683397177078], 
             UndirectedEdge[260, 329] -> 
             RGBColor[
              0.47014804379086866`, 0.5781251194748828, 0.9521496608682483], 
             UndirectedEdge[60, 82] -> 
             RGBColor[
              0.9066962451689276, 0.9280091441617512, 0.9760596470089649], 
             UndirectedEdge[12, 17] -> 
             RGBColor[
              0.8887538297593549, 0.9107284401881485, 0.8269587977753559], 
             UndirectedEdge[268, 351] -> 
             RGBColor[
              0.7075237563557252, 0.7706586181899353, 0.9720463609215126], 
             UndirectedEdge[122, 274] -> 
             RGBColor[
              0.7799449581842637, 0.8282204590821056, 0.9786476081548119], 
             UndirectedEdge[150, 384] -> 
             RGBColor[
              0.7357619538499451, 0.7917328139676365, 0.9463965635542564], 
             UndirectedEdge[179, 232] -> 
             RGBColor[
              0.7519786935353365, 0.8061707377303329, 0.9759138665973235], 
             UndirectedEdge[4, 131] -> 
             RGBColor[
              0.82929848862703, 0.8669815186515903, 0.9835121186576616], 
             UndirectedEdge[128, 155] -> 
             RGBColor[
              0.6012195877117081, 0.6850187522066205, 0.963071515934927], 
             UndirectedEdge[316, 362] -> 
             RGBColor[
              0.7114878058619564, 0.7720043610191345, 0.9439061091376443], 
             UndirectedEdge[283, 320] -> 
             RGBColor[
              0.7624970183368233, 0.8143877330074836, 0.976962234914202], 
             UndirectedEdge[49, 396] -> 
             RGBColor[
              0.8096707200952693, 0.8482872122823827, 0.7874608366265139], 
             UndirectedEdge[371, 389] -> 
             RGBColor[
              0.6528580213367401, 0.7278291184744126, 0.9666551099507359], 
             UndirectedEdge[53, 58] -> 
             RGBColor[
              0.6940534584760119, 0.7575398037824078, 0.9517473018477396], 
             UndirectedEdge[18, 399] -> 
             RGBColor[
              0.7709030597497932, 0.8209545964475766, 0.9778000705633235], 
             UndirectedEdge[241, 270] -> 
             RGBColor[
              0.7737669213639803, 0.823191866906734, 0.9780855135247173], 
             UndirectedEdge[137, 169] -> 
             RGBColor[
              0.6587500212569635, 0.4264066507027265, 0.44792094711192215`], 
             UndirectedEdge[156, 386] -> 
             RGBColor[
              0.5584386982554702, 0.6524047184772803, 0.9583814864364762], 
             UndirectedEdge[19, 262] -> 
             RGBColor[
              0.6695700672312475, 0.735899642570186, 0.9438550407708939], 
             UndirectedEdge[85, 181] -> 
             RGBColor[
              0.8699117455452925, 0.8989987076672774, 0.9753975259565251], 
             UndirectedEdge[74, 240] -> 
             RGBColor[
              0.4608055834948537, 0.5644012432448022, 0.9523049853812948], 
             UndirectedEdge[72, 88] -> 
             RGBColor[
              0.6885824686182389, 0.7491474390228047, 0.8511914062909574], 
             UndirectedEdge[63, 98] -> 
             RGBColor[
              0.48888370994798935`, 0.5941132569672042, 0.9534097259281664], 
             UndirectedEdge[43, 56] -> 
             RGBColor[
              0.7827901920686248, 0.8306674632934903, 0.9788716759027598], 
             UndirectedEdge[174, 272] -> 
             RGBColor[
              0.503665137502248, 0.607937074337022, 0.9540695110918185], 
             UndirectedEdge[180, 198] -> 
             RGBColor[
              0.4963011015313157, 0.6010362126622084, 0.9537446506004109], 
             UndirectedEdge[126, 289] -> 
             RGBColor[
              0.41991979232511434`, 0.5373549860241674, 0.9481934576899125], 
             UndirectedEdge[233, 244] -> 
             RGBColor[
              0.7029195601326734, 0.7654203335684553, 0.9552480281717933], 
             UndirectedEdge[51, 189] -> 
             RGBColor[
              0.6110550239128804, 0.6920337741137725, 0.9643347593215182], 
             UndirectedEdge[199, 306] -> 
             RGBColor[
              0.6553934738395211, 0.7297122595646499, 0.9669745318156185], 
             UndirectedEdge[86, 214] -> 
             RGBColor[
              0.633854116078256, 0.7105429944922957, 0.9663195243625049], 
             UndirectedEdge[104, 172] -> 
             RGBColor[
              0.7119514337605065, 0.774901138175794, 0.9719243234189783], 
             UndirectedEdge[67, 293] -> 
             RGBColor[
              0.4725275238537363, 0.5812408805336248, 0.9520098417518081], 
             UndirectedEdge[296, 380] -> 
             RGBColor[
              0.5758488466537839, 0.6579305129659174, 0.9631604052232012], 
             UndirectedEdge[290, 297] -> 
             RGBColor[
              0.8172228616067625, 0.8578937429501733, 0.9729802895039315], 
             UndirectedEdge[206, 328] -> 
             RGBColor[
              0.4952716105841485, 0.5987932245098333, 0.9540524191374309], 
             UndirectedEdge[5, 319] -> 
             RGBColor[
              0.6419476973278881, 0.7186652828084121, 0.9660056577507643], 
             UndirectedEdge[235, 393] -> 
             RGBColor[
              0.4547095621027917, 0.5669762562741023, 0.950551664955953], 
             UndirectedEdge[40, 189] -> 
             RGBColor[
              0.4630399088795752, 0.5742201818396339, 0.9510745656060847], 
             UndirectedEdge[15, 256] -> 
             RGBColor[
              0.6123790817190539, 0.695326371831072, 0.9632224075592107], 
             UndirectedEdge[71, 365] -> 
             RGBColor[
              0.5781776792495981, 0.6684297124792734, 0.9599354113266039], 
             UndirectedEdge[53, 64] -> 
             RGBColor[
              0.5903070268399927, 0.6759630572565544, 0.9622084794791631], 
             UndirectedEdge[231, 298] -> 
             RGBColor[
              0.4437819490958842, 0.5577439694530795, 0.9497910818236834], 
             UndirectedEdge[81, 382] -> 
             RGBColor[
              0.7791111162213993, 0.8267300602927559, 0.9445640733639386], 
             UndirectedEdge[9, 294] -> 
             RGBColor[
              0.43426892437178477`, 0.5505636481252196, 0.9488922097454062], 
             UndirectedEdge[175, 213] -> 
             RGBColor[
              0.9426877939574545, 0.9527554774582153, 0.7772882498873548], 
             UndirectedEdge[174, 189] -> 
             RGBColor[
              0.487672101457672, 0.5942177054421628, 0.953013702036527], 
             UndirectedEdge[14, 127] -> 
             RGBColor[
              0.7507641369560262, 0.8052219168996037, 0.9757928109481744], 
             UndirectedEdge[86, 95] -> 
             RGBColor[
              0.8166010592417419, 0.8567046333800772, 0.9823414421765619], 
             UndirectedEdge[103, 200] -> 
             RGBColor[
              0.6585806104251254, 0.7285343399839291, 0.9694720210417898], 
             UndirectedEdge[24, 112] -> 
             RGBColor[
              0.8071995246760008, 0.8500933974631046, 0.9734979033509847], 
             UndirectedEdge[109, 360] -> 
             RGBColor[
              0.8759878349935348, 0.9034114946395662, 0.9591011560151955], 
             UndirectedEdge[90, 121] -> 
             RGBColor[
              0.4926109811073456, 0.5989628121915698, 0.9531992874077027], 
             UndirectedEdge[75, 202] -> 
             RGBColor[
              0.7169342080829565, 0.7779903383168405, 0.9731418134101305], 
             UndirectedEdge[27, 32] -> 
             RGBColor[
              0.8592255950728968, 0.8905871827264057, 0.9864348983694384], 
             UndirectedEdge[131, 273] -> 
             RGBColor[
              0.9113410441481729, 0.9317165123259619, 0.9766320468425096], 
             UndirectedEdge[160, 220] -> 
             RGBColor[
              0.6344481310803076, 0.7114847784486877, 0.9661618835241872], 
             UndirectedEdge[50, 147] -> 
             RGBColor[
              0.6111670338856642, 0.6952119567263222, 0.9625324541675427], 
             UndirectedEdge[13, 339] -> 
             RGBColor[
              0.8726929486241355, 0.8981293821026635, 0.8211789933344598], 
             UndirectedEdge[17, 209] -> 
             RGBColor[
              0.8391995545188489, 0.8720162637438242, 0.8220196907304134], 
             UndirectedEdge[174, 325] -> 
             RGBColor[
              0.6696471432648619, 0.7404243130114212, 0.9686844264448222], 
             UndirectedEdge[21, 78] -> 
             RGBColor[
              0.8467954825160509, 0.8806007943986511, 0.9559175494323071], 
             UndirectedEdge[274, 373] -> 
             RGBColor[
              0.7331272377753209, 0.7913226770952619, 0.9742023813756608], 
             UndirectedEdge[97, 305] -> 
             RGBColor[
              0.46728363388610844`, 0.5765445993969358, 0.9517183357365191], 
             UndirectedEdge[11, 162] -> 
             RGBColor[
              0.6362192800390178, 0.7149253615762239, 0.964932068450234], 
             UndirectedEdge[103, 207] -> 
             RGBColor[
              0.6634769621989098, 0.7327753137925854, 0.9697840122471415], 
             UndirectedEdge[210, 249] -> 
             RGBColor[
              0.7649892799474014, 0.8022628016557987, 0.6782497206363323], 
             UndirectedEdge[52, 299] -> 
             RGBColor[
              0.6006002441916674, 0.685259515885368, 0.9626399030633972], 
             UndirectedEdge[43, 373] -> 
             RGBColor[
              0.747001802093433, 0.802385878067509, 0.9755257497062921], 
             UndirectedEdge[1, 336] -> 
             RGBColor[
              0.6787308134385194, 0.7395782711225086, 0.7812058868070411], 
             UndirectedEdge[30, 345] -> 
             RGBColor[
              0.6630227435734689, 0.7345009470804968, 0.9685773131941409], 
             UndirectedEdge[247, 363] -> 
             RGBColor[
              0.6857687519991648, 0.7461798611975505, 0.824874230691365], 
             UndirectedEdge[14, 119] -> 
             RGBColor[
              0.7800297513848422, 0.8280844373183024, 0.9787097338917227], 
             UndirectedEdge[74, 104] -> 
             RGBColor[
              0.47612518436328977`, 0.5763690318765033, 0.9538319000260509], 
             UndirectedEdge[258, 277] -> 
             RGBColor[
              0.7436888482283532, 0.7996248839417313, 0.975347109192803], 
             UndirectedEdge[152, 236] -> 
             RGBColor[
              0.7334215509130986, 0.7915757262879868, 0.9742093075221335], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.7537086570580138, 0.8025728320056675, 0.7599543924047936], 
             UndirectedEdge[120, 132] -> 
             RGBColor[
              0.7421248716469105, 0.7986461846640598, 0.9748857339355561], 
             UndirectedEdge[212, 270] -> 
             RGBColor[
              0.6729418008171704, 0.743958781948227, 0.9683560003969389], 
             UndirectedEdge[69, 270] -> 
             RGBColor[
              0.6482175503886144, 0.7238865216355364, 0.9664096168352894], 
             UndirectedEdge[16, 270] -> 
             RGBColor[
              0.529867736550232, 0.6243390684688044, 0.9580502809929227], 
             UndirectedEdge[24, 73] -> 
             RGBColor[
              0.9643993425019892, 0.9729119332775611, 0.9425613076127679], 
             UndirectedEdge[56, 178] -> 
             RGBColor[
              0.7682150776192231, 0.8190456626624798, 0.9774814884752177], 
             UndirectedEdge[6, 319] -> 
             RGBColor[
              0.6977259321793792, 0.7625159931962564, 0.9714917815993471], 
             UndirectedEdge[231, 235] -> 
             RGBColor[
              0.401872877900309, 0.5225038209442672, 0.946827962310943], 
             UndirectedEdge[18, 86] -> 
             RGBColor[
              0.8108288981451236, 0.8521953772613499, 0.9817661271023633], 
             UndirectedEdge[30, 63] -> 
             RGBColor[
              0.7119348450363026, 0.7742099945130857, 0.9724278529922266], 
             UndirectedEdge[46, 358] -> 
             RGBColor[
              0.6657999455549188, 0.7370581494621513, 0.9685475886557445], 
             UndirectedEdge[241, 389] -> 
             RGBColor[
              0.7680466843044096, 0.8187231742403855, 0.9775153737532738], 
             UndirectedEdge[286, 332] -> 
             RGBColor[
              0.4412931982397156, 0.5566477210993513, 0.9493397902649494], 
             UndirectedEdge[40, 174] -> 
             RGBColor[
              0.5244819752496493, 0.6248371210082161, 0.955708288813883], 
             UndirectedEdge[157, 365] -> 
             RGBColor[
              0.7651772303207209, 0.8169303941243975, 0.9771995759159684], 
             UndirectedEdge[235, 336] -> 
             RGBColor[
              0.3858522771006411, 0.5086275817504038, 0.9458071437944492], 
             UndirectedEdge[76, 222] -> 
             RGBColor[
              0.9686977654591156, 0.9735574748101161, 0.7938294457156887], 
             UndirectedEdge[115, 392] -> 
             RGBColor[
              0.6069839658108138, 0.6752203575623886, 0.9351114820229851], 
             UndirectedEdge[76, 77] -> 
             RGBColor[
              0.5844498340689124, 0.655853034994798, 0.9585746894875905], 
             UndirectedEdge[160, 366] -> 
             RGBColor[
              0.5578699766866715, 0.6516613422208498, 0.9585292887577697], 
             UndirectedEdge[3, 348] -> 
             RGBColor[
              0.7401758645796147, 0.7944573839959672, 0.9187639093761406], 
             UndirectedEdge[299, 306] -> 
             RGBColor[
              0.7330505720999275, 0.7913839454059403, 0.9740272883459936], 
             UndirectedEdge[56, 121] -> 
             RGBColor[
              0.6032269406452468, 0.6879927893321525, 0.9624359139825658], 
             UndirectedEdge[280, 322] -> 
             RGBColor[
              0.6018332646264998, 0.6862905391751666, 0.9627164585857584], 
             UndirectedEdge[81, 271] -> 
             RGBColor[
              0.5939972819781001, 0.6812727786392527, 0.9611807884025056], 
             UndirectedEdge[2, 191] -> 
             RGBColor[
              0.7420199340079059, 0.7985318427634216, 0.9749143317410525], 
             UndirectedEdge[146, 377] -> 
             RGBColor[
              0.45582337339620443`, 0.5660495115733444, 0.9511452553928542], 
             UndirectedEdge[10, 396] -> 
             RGBColor[
              0.6459650353171276, 0.7230881414069877, 0.9655278599853727], 
             UndirectedEdge[382, 384] -> 
             RGBColor[
              0.7387228373537922, 0.7939410360368039, 0.9413845601043402], 
             UndirectedEdge[147, 391] -> 
             RGBColor[
              0.7160989419170956, 0.7780966765727086, 0.9723681512807056], 
             UndirectedEdge[133, 216] -> 
             RGBColor[
              0.5680494610038966, 0.6602071686363806, 0.9591380808854164], 
             UndirectedEdge[86, 264] -> 
             RGBColor[
              0.6595488542227887, 0.7317243771070445, 0.9682535496274738], 
             UndirectedEdge[6, 56] -> 
             RGBColor[
              0.7734974628655563, 0.8232576932713781, 0.977985327095654], 
             UndirectedEdge[43, 308] -> 
             RGBColor[
              0.75400346880978, 0.8080701465293305, 0.9760769465581534], 
             UndirectedEdge[201, 364] -> 
             RGBColor[
              0.8280891485346101, 0.8664172427337189, 0.9832906179649288], 
             UndirectedEdge[109, 365] -> 
             RGBColor[
              0.706211886428314, 0.7702038574179215, 0.9714982319829372], 
             UndirectedEdge[229, 349] -> 
             RGBColor[
              0.6855745580953033, 0.7491555744731471, 0.9360254538603466], 
             UndirectedEdge[216, 231] -> 
             RGBColor[
              0.4864834116285003, 0.592410940416022, 0.9531526973748623], 
             UndirectedEdge[114, 353] -> 
             RGBColor[
              0.7396989114612272, 0.7963313755373606, 0.9750955027480444], 
             UndirectedEdge[70, 236] -> 
             RGBColor[
              0.7693432744563455, 0.8202187335721618, 0.9776355535813896], 
             UndirectedEdge[64, 94] -> 
             RGBColor[
              0.6013846430894131, 0.6855579316746205, 0.9629143353910248], 
             UndirectedEdge[240, 285] -> 
             RGBColor[
              0.7621792478302677, 0.33208076710911716`, 0.43145831071594876`],
              UndirectedEdge[56, 90] -> 
             RGBColor[
              0.5822069024695957, 0.6709277753992304, 0.9607811395784416], 
             UndirectedEdge[90, 295] -> 
             RGBColor[
              0.42349654980327023`, 0.5407370054672762, 0.9483428921825874], 
             UndirectedEdge[165, 281] -> 
             RGBColor[
              0.8750468431531124, 0.9026894610482245, 0.9596692912715119], 
             UndirectedEdge[54, 345] -> 
             RGBColor[
              0.7331863997302228, 0.7595531138921525, 0.6506474434640538], 
             UndirectedEdge[101, 136] -> 
             RGBColor[
              0.6819323201409786, 0.751449978462505, 0.9689322987179501], 
             UndirectedEdge[6, 314] -> 
             RGBColor[
              0.8987426222813905, 0.9219006388028579, 0.9833965329868555], 
             UndirectedEdge[125, 276] -> 
             RGBColor[
              0.39872421443674433`, 0.5140654356102582, 0.947325206983374], 
             UndirectedEdge[244, 341] -> 
             RGBColor[
              0.839152511158352, 0.8748600160752866, 0.9667967621050058], 
             UndirectedEdge[46, 153] -> 
             RGBColor[
              0.6348145138011947, 0.7128520946781385, 0.9654592503938562], 
             UndirectedEdge[14, 336] -> 
             RGBColor[
              0.5873262610742847, 0.6708192407519744, 0.9631029189805138], 
             UndirectedEdge[109, 370] -> 
             RGBColor[
              0.731454695425205, 0.7901372344185351, 0.9738682262733727], 
             UndirectedEdge[51, 234] -> 
             RGBColor[
              0.6158593911929559, 0.6961950755772532, 0.9646408893562695], 
             UndirectedEdge[144, 228] -> 
             RGBColor[
              0.7330920345931711, 0.7909573325154724, 0.974587220448941], 
             UndirectedEdge[320, 347] -> 
             RGBColor[
              0.7217366691734148, 0.7824555688756614, 0.9729610685561274], 
             UndirectedEdge[31, 106] -> 
             RGBColor[
              0.6259139107334271, 0.7071841356905673, 0.9636933823325885], 
             UndirectedEdge[77, 103] -> 
             RGBColor[
              0.5757529590334115, 0.6491125060214272, 0.9644755438527355], 
             UndirectedEdge[266, 316] -> 
             RGBColor[
              0.9745621951268912, 0.9805491072929938, 0.9279437477948158], 
             UndirectedEdge[109, 334] -> 
             RGBColor[
              0.6504975658935268, 0.7249724621062439, 0.967112196582158], 
             UndirectedEdge[45, 179] -> 
             RGBColor[
              0.6077491314505757, 0.6894124568155469, 0.9640216507964954], 
             UndirectedEdge[181, 191] -> 
             RGBColor[
              0.7141569822910812, 0.7765512965344039, 0.9721939481471102], 
             UndirectedEdge[125, 148] -> 
             RGBColor[
              0.46182405321773956`, 0.5723913623667297, 0.951211422350561], 
             UndirectedEdge[18, 112] -> 
             RGBColor[
              0.7327882729878425, 0.7911790353460324, 0.9740011448218255], 
             UndirectedEdge[221, 239] -> 
             RGBColor[
              0.7287713562386906, 0.7874652282686394, 0.9742291058425272], 
             UndirectedEdge[57, 76] -> 
             RGBColor[
              0.7158346506514641, 0.776378934305176, 0.9669286993817787], 
             UndirectedEdge[222, 333] -> 
             RGBColor[
              0.5865478291024451, 0.6476648372381913, 0.7700868081757068], 
             UndirectedEdge[125, 214] -> 
             RGBColor[
              0.48495277739301107`, 0.5924243007638722, 0.9526851642030816], 
             UndirectedEdge[220, 244] -> 
             RGBColor[
              0.8845960761353799, 0.9103608744192269, 0.9713261519676564], 
             UndirectedEdge[143, 379] -> 
             RGBColor[
              0.7718951742423859, 0.8219327176128677, 0.9778450657259594], 
             UndirectedEdge[31, 241] -> 
             RGBColor[
              0.7166738041946794, 0.7782458158677057, 0.9726305239140501], 
             UndirectedEdge[81, 374] -> 
             RGBColor[
              0.7182261532280679, 0.7791723194074808, 0.9730902992908189], 
             UndirectedEdge[168, 304] -> 
             RGBColor[
              0.7880781878539516, 0.8351646671624129, 0.9762415495846067], 
             UndirectedEdge[156, 328] -> 
             RGBColor[
              0.6059462787289627, 0.6909735124977723, 0.9621214571973509], 
             UndirectedEdge[46, 363] -> 
             RGBColor[
              0.7603177000629994, 0.8087886671654198, 0.8301664599797849], 
             UndirectedEdge[51, 269] -> 
             RGBColor[
              0.614169111527276, 0.6947310402867676, 0.964533186230628], 
             UndirectedEdge[13, 325] -> 
             RGBColor[
              0.7704235036381888, 0.8205799635684299, 0.9777522728918254], 
             UndirectedEdge[164, 374] -> 
             RGBColor[
              0.9183199238138475, 0.9364344398186655, 0.9477406145445869], 
             UndirectedEdge[49, 199] -> 
             RGBColor[
              0.7854699561917786, 0.8286399419135392, 0.7855556638417119], 
             UndirectedEdge[49, 313] -> 
             RGBColor[
              0.9344981474471918, 0.9465102058609756, 0.7996044818432242], 
             UndirectedEdge[176, 388] -> 
             RGBColor[
              0.7154284970039215, 0.7770882664501169, 0.9726545818097652], 
             UndirectedEdge[45, 232] -> 
             RGBColor[
              0.5695477062839346, 0.6595692131337823, 0.9602140897484999], 
             UndirectedEdge[176, 250] -> 
             RGBColor[
              0.6451985573497687, 0.7221717679435353, 0.9656686060948946], 
             UndirectedEdge[346, 390] -> 
             RGBColor[
              0.8280964266541075, 0.8660279985568828, 0.9558279625466453], 
             UndirectedEdge[331, 335] -> 
             RGBColor[
              0.6649966898087157, 0.7359866190450148, 0.9688672206873672], 
             UndirectedEdge[135, 355] -> 
             RGBColor[
              0.46472834383175154`, 0.5748456925103879, 0.9514133965626497], 
             UndirectedEdge[326, 327] -> 
             RGBColor[
              0.44461399142239666`, 0.5534112617022594, 0.9507475336746101], 
             UndirectedEdge[80, 304] -> 
             RGBColor[
              0.6512010374953852, 0.721596575573954, 0.9661416548045451], 
             UndirectedEdge[65, 173] -> 
             RGBColor[
              0.44119136411767246`, 0.5543518874539121, 0.9499432762444362], 
             UndirectedEdge[203, 257] -> 
             RGBColor[
              0.7959286479815638, 0.8392519147601841, 0.9035849560452699], 
             UndirectedEdge[275, 325] -> 
             RGBColor[
              0.5971042810255034, 0.6801924224030882, 0.9633433703402814], 
             UndirectedEdge[240, 337] -> 
             RGBColor[
              0.5030061255563965, 0.6045622450212733, 0.9548618229487459], 
             UndirectedEdge[77, 254] -> 
             RGBColor[
              0.4270472118285451, 0.5318734042867668, 0.9500269514677064], 
             UndirectedEdge[32, 364] -> 
             RGBColor[
              0.8054900454101188, 0.8483973313385621, 0.9811350953344573], 
             UndirectedEdge[38, 53] -> 
             RGBColor[
              0.39969510930537283`, 0.5206175472451656, 0.9466891968217988], 
             UndirectedEdge[28, 291] -> 
             RGBColor[
              0.6807762856014792, 0.7499573206240946, 0.9692201578832594], 
             UndirectedEdge[174, 269] -> 
             RGBColor[
              0.49078618907206767`, 0.5969149716151578, 0.9532121289456368], 
             UndirectedEdge[216, 361] -> 
             RGBColor[
              0.4726287752173546, 0.5804107507109612, 0.9522698921939181], 
             UndirectedEdge[356, 363] -> 
             RGBColor[
              0.6547562391469783, 0.7193183812992048, 0.8228981407957121], 
             UndirectedEdge[151, 383] -> 
             RGBColor[
              0.7231789658540085, 0.7829385901393193, 0.9737732953502525], 
             UndirectedEdge[61, 130] -> 
             RGBColor[
              0.8085957499305472, 0.8473863550244413, 0.785069201567954], 
             UndirectedEdge[331, 338] -> 
             RGBColor[
              0.6098240846477871, 0.6889663693067896, 0.9651396119088538], 
             UndirectedEdge[239, 246] -> 
             RGBColor[
              0.562499031701432, 0.6398044546633171, 0.9630204501202406], 
             UndirectedEdge[190, 212] -> 
             RGBColor[
              0.5146461477098087, 0.6158785092268679, 0.9552029418860717], 
             UndirectedEdge[111, 286] -> 
             RGBColor[
              0.6251333274686065, 0.7033604403956454, 0.9655988788050338], 
             UndirectedEdge[228, 273] -> 
             RGBColor[
              0.7634296621069453, 0.8147216183451054, 0.9627071808601855], 
             UndirectedEdge[199, 299] -> 
             RGBColor[
              0.6543859305709873, 0.7289251591056587, 0.9668741093186383], 
             UndirectedEdge[50, 391] -> 
             RGBColor[
              0.687813647108461, 0.7551334000090492, 0.9701414292609211], 
             UndirectedEdge[358, 362] -> 
             RGBColor[
              0.6300873185468328, 0.7080650300214745, 0.9657361598380048], 
             UndirectedEdge[42, 98] -> 
             RGBColor[
              0.40988903462479126`, 0.5294470129952618, 0.9473387447290179], 
             UndirectedEdge[39, 251] -> 
             RGBColor[
              0.6219835614805063, 0.7018626552031993, 0.9648407050828904], 
             UndirectedEdge[148, 179] -> 
             RGBColor[
              0.592704885518181, 0.676381887134693, 0.9630630447487876], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.8039184309186448, 0.8469383803361692, 0.9810398032199772], 
             UndirectedEdge[77, 333] -> 
             RGBColor[
              0.20229989771224183`, 0.3299603974228732, 0.9348320519476087], 
             UndirectedEdge[173, 354] -> 
             RGBColor[
              0.7051434387729454, 0.768382344668834, 0.9722547092670698], 
             UndirectedEdge[160, 217] -> 
             RGBColor[
              0.7251299385679606, 0.7803529878923575, 0.8381601921133326], 
             UndirectedEdge[59, 90] -> 
             RGBColor[
              0.51981002146325, 0.6210442184552976, 0.9553404954978871], 
             UndirectedEdge[237, 380] -> 
             RGBColor[
              0.7282928556610593, 0.7873103406326892, 0.9739225894350709], 
             UndirectedEdge[285, 399] -> 
             RGBColor[
              0.793669151560308, 0.35668091923515716`, 0.43459693002987765`], 
             UndirectedEdge[51, 392] -> 
             RGBColor[
              0.5191671585622344, 0.6063160033638543, 0.9587041629094416], 
             UndirectedEdge[264, 307] -> 
             RGBColor[
              0.4301984782430428, 0.545963924164119, 0.9489296237888012], 
             UndirectedEdge[78, 208] -> 
             RGBColor[
              0.761805685669765, 0.8128729784749413, 0.948358036322033], 
             UndirectedEdge[28, 383] -> 
             RGBColor[
              0.5813545811851839, 0.6710088645883832, 0.9601855086843484], 
             UndirectedEdge[255, 268] -> 
             RGBColor[
              0.6818318801105686, 0.7498007956482822, 0.9700238023110502], 
             UndirectedEdge[46, 247] -> 
             RGBColor[
              0.45101864732820574`, 0.56310967037857, 0.9505015235198297], 
             UndirectedEdge[272, 392] -> 
             RGBColor[
              0.3503352057815278, 0.47160236441852155`, 0.9438051914719434], 
             UndirectedEdge[316, 359] -> 
             RGBColor[
              0.879194885587544, 0.9059016454808555, 0.9586502971730522], 
             UndirectedEdge[223, 242] -> 
             RGBColor[
              0.5534915139016118, 0.6483883713507026, 0.9579920259620072], 
             UndirectedEdge[158, 390] -> 
             RGBColor[
              0.8326197634574197, 0.8695616636462634, 0.9562788064862137], 
             UndirectedEdge[26, 128] -> 
             RGBColor[
              0.524485556097506, 0.6166838941940898, 0.9582506232747077], 
             UndirectedEdge[136, 335] -> 
             RGBColor[
              0.5946315687118894, 0.6807870997768553, 0.9619148520986411], 
             UndirectedEdge[193, 248] -> 
             RGBColor[
              0.732221206881954, 0.7845251622448338, 0.7088254963401308], 
             UndirectedEdge[281, 386] -> 
             RGBColor[
              0.6554332138998086, 0.7289969588980811, 0.9674887735039648], 
             UndirectedEdge[225, 337] -> 
             RGBColor[
              0.6510232708305186, 0.7209130285342435, 0.9584014962647427], 
             UndirectedEdge[30, 297] -> 
             RGBColor[
              0.7603765795642314, 0.8128304435921334, 0.9767245611896451], 
             UndirectedEdge[32, 104] -> 
             RGBColor[
              0.7774360557399833, 0.8264813413900337, 0.9783389358235771], 
             UndirectedEdge[264, 366] -> 
             RGBColor[
              0.5768111930808008, 0.6670386749816783, 0.9600204106962773], 
             UndirectedEdge[2, 97] -> 
             RGBColor[
              0.6156930564482942, 0.6941176612631046, 0.9654823270681621], 
             UndirectedEdge[258, 377] -> 
             RGBColor[
              0.6118527263874622, 0.6895469176662095, 0.9658105099714812], 
             UndirectedEdge[134, 135] -> 
             RGBColor[
              0.6193909608052803, 0.6975419579268919, 0.9656160511226154], 
             UndirectedEdge[185, 338] -> 
             RGBColor[
              0.683204001104285, 0.74412023334458, 0.8372989682118406], 
             UndirectedEdge[40, 84] -> 
             RGBColor[
              0.5071886253890525, 0.6107976005348505, 0.9543468929652291], 
             UndirectedEdge[217, 242] -> 
             RGBColor[
              0.8087684207637693, 0.8482544756095997, 0.8447445198096419], 
             UndirectedEdge[124, 266] -> 
             RGBColor[
              0.8982954889796697, 0.920620325161881, 0.9502854858240801], 
             UndirectedEdge[219, 293] -> 
             RGBColor[
              0.6959686183795875, 0.7561613922511523, 0.874319504592282], 
             UndirectedEdge[37, 170] -> 
             RGBColor[
              0.5403381672780019, 0.6312530160518216, 0.9594847550993768], 
             UndirectedEdge[205, 293] -> 
             RGBColor[
              0.6153314662672598, 0.69438540221136, 0.9651918518651891], 
             UndirectedEdge[122, 268] -> 
             RGBColor[
              0.7715149484159791, 0.8214985981193947, 0.9778435462975543], 
             UndirectedEdge[246, 392] -> 
             RGBColor[
              0.2390312971800802, 0.36856742716880875`, 0.9369238508080662], 
             UndirectedEdge[282, 398] -> 
             RGBColor[
              0.7496829795795523, 0.8043773085400019, 0.9756850512848776], 
             UndirectedEdge[34, 248] -> 
             RGBColor[
              0.4660182944315845, 0.5773736711613043, 0.9511058137003657], 
             UndirectedEdge[263, 264] -> 
             RGBColor[
              0.7275023610301601, 0.7852271240063504, 0.9511057736405462], 
             UndirectedEdge[100, 377] -> 
             RGBColor[
              0.6256410390405057, 0.7005413439019699, 0.9671256515413005], 
             UndirectedEdge[107, 241] -> 
             RGBColor[
              0.8989223774341144, 0.9210084466863978, 0.9453762561271535], 
             UndirectedEdge[11, 95] -> 
             RGBColor[
              0.6981259257798161, 0.7632873037368693, 0.9711023443471805], 
             UndirectedEdge[7, 96] -> 
             RGBColor[
              0.7301741308534453, 0.7888730315449484, 0.9740299605669309], 
             UndirectedEdge[111, 383] -> 
             RGBColor[
              0.6875679591278183, 0.7545731175587054, 0.9703687836927708], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.5014849483480699, 0.6061670985652582, 0.9538978786153056], 
             UndirectedEdge[121, 122] -> 
             RGBColor[
              0.6142562710789978, 0.6966089860930147, 0.963535214565249], 
             UndirectedEdge[156, 221] -> 
             RGBColor[
              0.5785113274250464, 0.6687005830987814, 0.9599616773331687], 
             UndirectedEdge[61, 176] -> 
             RGBColor[
              0.7992832724756298, 0.839826066304211, 0.784336089229974], 
             UndirectedEdge[128, 261] -> 
             RGBColor[
              0.5639947484196073, 0.6527764673866264, 0.9606995820918673], 
             UndirectedEdge[69, 381] -> 
             RGBColor[
              0.5003869552523657, 0.6048705561396479, 0.9539233825644542], 
             UndirectedEdge[166, 178] -> 
             RGBColor[
              0.8049093804368324, 0.8477115309106267, 0.9811388336523208], 
             UndirectedEdge[114, 202] -> 
             RGBColor[
              0.7266338101235511, 0.7857245376953271, 0.9740669701116994], 
             UndirectedEdge[40, 134] -> 
             RGBColor[
              0.669924085748507, 0.7400477638894991, 0.9691850713283345], 
             UndirectedEdge[84, 234] -> 
             RGBColor[
              0.4751831188771507, 0.5843394864322778, 0.9519584362226242], 
             UndirectedEdge[236, 367] -> 
             RGBColor[
              0.5359245992712259, 0.633984105535822, 0.9566485095794867], 
             UndirectedEdge[307, 366] -> 
             RGBColor[
              0.5141330943498509, 0.6138241642647262, 0.9557298383978436], 
             UndirectedEdge[129, 396] -> 
             RGBColor[
              0.6166295574657007, 0.6996466794524787, 0.9629624840336464], 
             UndirectedEdge[67, 208] -> 
             RGBColor[
              0.5496331871124074, 0.6452560078475855, 0.9576882843436442], 
             UndirectedEdge[203, 309] -> 
             RGBColor[
              0.6936835791822159, 0.7547744535106014, 0.895942100260311], 
             UndirectedEdge[142, 302] -> 
             RGBColor[
              0.662549041463606, 0.7340092608076124, 0.9686633073719038], 
             UndirectedEdge[93, 248] -> 
             RGBColor[
              0.640215986094789, 0.7162445178316867, 0.9665632126856158], 
             UndirectedEdge[110, 227] -> 
             RGBColor[
              0.6744653369907783, 0.7433361676502674, 0.9700011132086379], 
             UndirectedEdge[129, 361] -> 
             RGBColor[
              0.48782456716296596`, 0.5927473791750344, 0.9534661605998966], 
             UndirectedEdge[236, 332] -> 
             RGBColor[
              0.5362023018272264, 0.6342246375320932, 0.9566662045407923], 
             UndirectedEdge[306, 353] -> 
             RGBColor[
              0.6616644899580973, 0.7348033529557668, 0.9674682091759619], 
             UndirectedEdge[257, 280] -> 
             RGBColor[
              0.5386199069966946, 0.6363149309070345, 0.9568212785899609], 
             UndirectedEdge[208, 385] -> 
             RGBColor[
              0.5163609574380501, 0.6182441129010766, 0.9550689725434856], 
             UndirectedEdge[79, 302] -> 
             RGBColor[
              0.6961654205395751, 0.7608140489904885, 0.9718696676178655], 
             UndirectedEdge[21, 242] -> 
             RGBColor[
              0.6737914152713731, 0.7447825208286509, 0.9683312798455439], 
             UndirectedEdge[94, 103] -> 
             RGBColor[
              0.6887311950965747, 0.7546492610138902, 0.9713931896359393], 
             UndirectedEdge[237, 308] -> 
             RGBColor[
              0.6173626408871651, 0.7002418295990553, 0.9630201950459572], 
             UndirectedEdge[1, 235] -> 
             RGBColor[
              0.701394639804112, 0.7592085384033505, 0.7826500057822219], 
             UndirectedEdge[31, 374] -> 
             RGBColor[
              0.7361013628490639, 0.7936842198468219, 0.974497501271234], 
             UndirectedEdge[324, 351] -> 
             RGBColor[
              0.5219694512868503, 0.6227973408673013, 0.955510493723853], 
             UndirectedEdge[62, 396] -> 
             RGBColor[
              0.7344298662693044, 0.792389464709817, 0.9742942765885654], 
             UndirectedEdge[13, 123] -> 
             RGBColor[
              0.8721646870983394, 0.8969994841144188, 0.7636809863037877], 
             UndirectedEdge[112, 337] -> 
             RGBColor[
              0.5121261943895064, 0.6116869121087891, 0.9557708261781415], 
             UndirectedEdge[262, 286] -> 
             RGBColor[
              0.6999049355847833, 0.7621741808632034, 0.9457879517583103], 
             UndirectedEdge[56, 59] -> 
             RGBColor[
              0.6304259810011511, 0.7100741955958801, 0.9645771220727501], 
             UndirectedEdge[61, 118] -> 
             RGBColor[
              0.9658166487732476, 0.9714087427031912, 0.7987064247492845], 
             UndirectedEdge[14, 235] -> 
             RGBColor[
              0.6099900874398774, 0.6904495080328164, 0.9645470379556946], 
             UndirectedEdge[154, 286] -> 
             RGBColor[
              0.5247698566671712, 0.6245454055778621, 0.9558761299156826], 
             UndirectedEdge[159, 215] -> 
             RGBColor[
              0.6012632089777314, 0.6871382512898909, 0.9617755795760125], 
             UndirectedEdge[25, 385] -> 
             RGBColor[
              0.6656089600811782, 0.7364444771058232, 0.9689605514455747], 
             UndirectedEdge[165, 256] -> 
             RGBColor[
              0.7464341424657759, 0.8004281536265135, 0.9480729048562104], 
             UndirectedEdge[292, 384] -> 
             RGBColor[
              0.53398102179977, 0.6325488749247745, 0.9564560885544626], 
             UndirectedEdge[1, 49] -> 
             RGBColor[
              0.9942421281074834, 0.9900928191690826, 0.6146693618449872], 
             UndirectedEdge[93, 125] -> 
             RGBColor[
              0.6686426207186883, 0.7393225404246642, 0.9688010614934028], 
             UndirectedEdge[15, 37] -> 
             RGBColor[
              0.5019101064285043, 0.6012327228521146, 0.9556546051245449], 
             UndirectedEdge[141, 399] -> 
             RGBColor[
              0.6930817144770836, 0.760120677133699, 0.970070430934212], 
             UndirectedEdge[42, 288] -> 
             RGBColor[
              0.5529962692765513, 0.6469917544542307, 0.9584151391201191], 
             UndirectedEdge[26, 218] -> 
             RGBColor[
              0.35342036238411756`, 0.4786649907055033, 0.9438091428481261], 
             UndirectedEdge[292, 389] -> 
             RGBColor[
              0.6436173903981035, 0.7203271579927475, 0.9659276536336998], 
             UndirectedEdge[87, 361] -> 
             RGBColor[
              0.4973321303535507, 0.6004660472839919, 0.9542146308016108], 
             UndirectedEdge[3, 11] -> 
             RGBColor[
              0.5418867183067191, 0.6389670754966847, 0.9570784539430102], 
             UndirectedEdge[217, 364] -> 
             RGBColor[
              0.8669563287590667, 0.8940190324565558, 0.8503337562377822], 
             UndirectedEdge[83, 120] -> 
             RGBColor[
              0.9062143032261012, 0.9271443834410409, 0.9593553681139455], 
             UndirectedEdge[251, 380] -> 
             RGBColor[
              0.6598151427556902, 0.7317170484102994, 0.9685317730330327], 
             UndirectedEdge[209, 390] -> 
             RGBColor[
              0.8249514235896441, 0.8635710982600155, 0.9555144980329042], 
             UndirectedEdge[149, 315] -> 
             RGBColor[
              0.2709827836397342, 0.4014898187544234, 0.9387676301994825], 
             UndirectedEdge[34, 263] -> 
             RGBColor[
              0.7112997745481, 0.7720731343820113, 0.9498302466806484], 
             UndirectedEdge[327, 376] -> 
             RGBColor[
              0.6865970970063668, 0.7544869305049279, 0.9698123908905361], 
             UndirectedEdge[113, 316] -> 
             RGBColor[
              0.878163163703356, 0.9050956565035511, 0.9585474647776255], 
             UndirectedEdge[85, 307] -> 
             RGBColor[
              0.6583172017000384, 0.7271596581488697, 0.9578299576232996], 
             UndirectedEdge[140, 257] -> 
             RGBColor[
              0.676103406505162, 0.7463035339804045, 0.9687566638113551], 
             UndirectedEdge[228, 330] -> 
             RGBColor[
              0.6908085316151372, 0.7573467135091325, 0.970526292274039], 
             UndirectedEdge[22, 96] -> 
             RGBColor[
              0.644902542101661, 0.7219976707223685, 0.9656000268308181], 
             UndirectedEdge[22, 323] -> 
             RGBColor[
              0.6967521645654131, 0.7630273535618628, 0.9704094023108576], 
             UndirectedEdge[167, 269] -> 
             RGBColor[
              0.5345115785758877, 0.6324132126207083, 0.9566543517787568], 
             UndirectedEdge[85, 214] -> 
             RGBColor[
              0.6953005622864556, 0.7591927862510732, 0.9601865046567644], 
             UndirectedEdge[89, 155] -> 
             RGBColor[
              0.6442027143662725, 0.7188112940145861, 0.9672989372605949], 
             UndirectedEdge[1, 396] -> 
             RGBColor[
              0.8097017681297763, 0.8483536208887553, 0.7908402235763405], 
             UndirectedEdge[172, 208] -> 
             RGBColor[
              0.6483480252830802, 0.7238805313884091, 0.9664964056341498], 
             UndirectedEdge[45, 339] -> 
             RGBColor[
              0.7100185764365226, 0.7669618753497807, 0.8074483712391297], 
             UndirectedEdge[250, 363] -> 
             RGBColor[
              0.8405335163435631, 0.8732429678697159, 0.8369384086162874], 
             UndirectedEdge[167, 222] -> 
             RGBColor[
              0.8153668025201382, 0.8528834005491144, 0.7856022436309895], 
             UndirectedEdge[73, 208] -> 
             RGBColor[
              0.769935822540911, 0.81887868607364, 0.9320103364989525], 
             UndirectedEdge[14, 317] -> 
             RGBColor[
              0.8332445761284899, 0.86993948686708, 0.9839385313570752], 
             UndirectedEdge[157, 334] -> 
             RGBColor[
              0.7094629097859337, 0.7716989988127197, 0.9728135405151892], 
             UndirectedEdge[107, 190] -> 
             RGBColor[
              0.7009179183312336, 0.7619073529232361, 0.9282653949345427], 
             UndirectedEdge[12, 209] -> 
             RGBColor[
              0.7331575161944788, 0.7914674909454089, 0.9740379475338892], 
             UndirectedEdge[185, 219] -> 
             RGBColor[
              0.9929928306535004, 0.9913703696462537, 0.7657904602518621], 
             UndirectedEdge[318, 345] -> 
             RGBColor[
              0.4493067346362409, 0.5624898266096026, 0.9501540121137001], 
             UndirectedEdge[36, 383] -> 
             RGBColor[
              0.5364911702238327, 0.6345867264963265, 0.9566536966333815], 
             UndirectedEdge[24, 357] -> 
             RGBColor[
              0.959179969424955, 0.9690770685505727, 0.9539818435812002], 
             UndirectedEdge[344, 354] -> 
             RGBColor[
              0.8223490960662525, 0.8615946681615779, 0.9828083046534283], 
             UndirectedEdge[7, 194] -> 
             RGBColor[
              0.8199580558613667, 0.8595372798433251, 0.9826202728083606], 
             UndirectedEdge[97, 248] -> 
             RGBColor[
              0.4282579635568171, 0.5448618021372038, 0.9486460920124565], 
             UndirectedEdge[14, 129] -> 
             RGBColor[
              0.70979641311368, 0.7726932559686446, 0.9720680414255924], 
             UndirectedEdge[160, 307] -> 
             RGBColor[
              0.41125726184891354`, 0.5305865914032903, 0.9474385018502934], 
             UndirectedEdge[165, 400] -> 
             RGBColor[
              0.8929351549035135, 0.9166639461438424, 0.9614522310110143], 
             UndirectedEdge[310, 323] -> 
             RGBColor[
              0.7868503176072961, 0.8337512857357697, 0.9792996980576847], 
             UndirectedEdge[309, 339] -> 
             RGBColor[
              0.6969433412878203, 0.7556367638444018, 0.8066152288174309], 
             UndirectedEdge[355, 395] -> 
             RGBColor[
              0.5122298696071798, 0.6148903096965901, 0.9547437581767662], 
             UndirectedEdge[32, 240] -> 
             RGBColor[
              0.7621164548715471, 0.8145135527583325, 0.976812021178821], 
             UndirectedEdge[66, 322] -> 
             RGBColor[
              0.7943184450979284, 0.839558607168512, 0.980051172800338], 
             UndirectedEdge[28, 267] -> 
             RGBColor[
              0.6665514849651415, 0.7388447982544986, 0.9678023626941491], 
             UndirectedEdge[51, 102] -> 
             RGBColor[
              0.6621988661076419, 0.7342901509671238, 0.9681577685985978], 
             UndirectedEdge[244, 321] -> 
             RGBColor[
              0.9742334974150887, 0.9769952473677468, 0.7296494670266143], 
             UndirectedEdge[140, 309] -> 
             RGBColor[
              0.5738583377058141, 0.6618260727308216, 0.9611138080263961], 
             UndirectedEdge[12, 324] -> 
             RGBColor[
              0.6198757776270971, 0.7001320814608583, 0.964688022729975], 
             UndirectedEdge[130, 287] -> 
             RGBColor[
              0.5179710219499725, 0.6184543137293215, 0.9554988055573599], 
             UndirectedEdge[267, 367] -> 
             RGBColor[
              0.5886470311228844, 0.6754557999322555, 0.9617088542011814], 
             UndirectedEdge[138, 229] -> 
             RGBColor[
              0.7768114662829593, 0.8248030415445226, 0.9427721628021248], 
             UndirectedEdge[97, 193] -> 
             RGBColor[
              0.6889139855854749, 0.7475100776918219, 0.7059291031192954], 
             UndirectedEdge[248, 340] -> 
             RGBColor[
              0.5737993137045223, 0.6643593085750044, 0.9599434194808458], 
             UndirectedEdge[162, 248] -> 
             RGBColor[
              0.5773664401917994, 0.6671459748980306, 0.9602989573124052], 
             UndirectedEdge[127, 317] -> 
             RGBColor[
              0.7725446416709951, 0.8225202367322968, 0.9778885291634904], 
             UndirectedEdge[269, 355] -> 
             RGBColor[
              0.4815656825973965, 0.5894293490799367, 0.9524862569001225], 
             UndirectedEdge[161, 184] -> 
             RGBColor[
              0.6557128071255125, 0.7266491140361295, 0.969013662928246], 
             UndirectedEdge[340, 360] -> 
             RGBColor[
              0.8220034839593982, 0.8612385093154347, 0.953720500416556], 
             UndirectedEdge[19, 185] -> 
             RGBColor[
              0.6842331432399231, 0.7450116245362819, 0.8373645442386888], 
             UndirectedEdge[240, 357] -> 
             RGBColor[
              0.813000257072867, 0.8540966395023354, 0.9473318756074569], 
             UndirectedEdge[75, 132] -> 
             RGBColor[
              0.7567745251077335, 0.8103274206794702, 0.9762830309605494], 
             UndirectedEdge[89, 353] -> 
             RGBColor[
              0.7178531175919919, 0.7789121324943098, 0.9730118314268263], 
             UndirectedEdge[214, 312] -> 
             RGBColor[
              0.49168951917202464`, 0.5978934912268341, 0.9532155051934238], 
             UndirectedEdge[119, 129] -> 
             RGBColor[
              0.6783620930850012, 0.7481365262525599, 0.968934962175556], 
             UndirectedEdge[143, 377] -> 
             RGBColor[
              0.5198819438965039, 0.6171923541238924, 0.9567780754903291], 
             UndirectedEdge[5, 122] -> 
             RGBColor[
              0.7287485584478164, 0.7880231796443963, 0.9735985038297544], 
             UndirectedEdge[42, 318] -> 
             RGBColor[
              0.41922416077587654`, 0.537532630070249, 0.9479335707126371], 
             UndirectedEdge[6, 137] -> 
             RGBColor[
              0.5576095136698938, 0.6391324612349791, 0.9620652492401724], 
             UndirectedEdge[113, 149] -> 
             RGBColor[
              0.5067835825696125, 0.5944317141629454, 0.9578197822550123], 
             UndirectedEdge[67, 124] -> 
             RGBColor[
              0.6801170520027968, 0.7485241354950722, 0.9697822209903169], 
             UndirectedEdge[141, 337] -> 
             RGBColor[
              0.4969532409476165, 0.5997943926385609, 0.9542853927642183], 
             UndirectedEdge[63, 224] -> 
             RGBColor[
              0.7509053014719952, 0.8052839786500471, 0.9761448899164], 
             UndirectedEdge[244, 357] -> 
             RGBColor[
              0.9646954024754051, 0.9731904694889058, 0.9446456540821127], 
             UndirectedEdge[9, 192] -> 
             RGBColor[
              0.3976003952677631, 0.5188032112291769, 0.9465557234956052], 
             UndirectedEdge[46, 369] -> 
             RGBColor[
              0.4787237632601288, 0.5871064492991862, 0.9522668690083398], 
             UndirectedEdge[350, 392] -> 
             RGBColor[
              0.5973452543473297, 0.6680318223348636, 0.9514273063520958], 
             UndirectedEdge[275, 339] -> 
             RGBColor[
              0.6993737260114501, 0.757741840937322, 0.8067700907829158], 
             UndirectedEdge[119, 127] -> 
             RGBColor[
              0.7193298169273474, 0.7806651871835191, 0.972659731698138], 
             UndirectedEdge[152, 398] -> 
             RGBColor[
              0.8099336773545394, 0.8516321109063337, 0.981640786573202], 
             UndirectedEdge[105, 229] -> 
             RGBColor[
              0.9194598880813794, 0.9375791979377728, 0.9562205900686751], 
             UndirectedEdge[181, 365] -> 
             RGBColor[
              0.7095655477176037, 0.7728237631058845, 0.971832493598507], 
             UndirectedEdge[24, 285] -> 
             RGBColor[
              0.8596323893983263, 0.4087343864746088, 0.43589162269844417`], 
             UndirectedEdge[167, 189] -> 
             RGBColor[
              0.531397490961492, 0.6297159464477133, 0.956455924869647], 
             UndirectedEdge[157, 191] -> 
             RGBColor[
              0.7697686648941984, 0.8206579275529168, 0.9775610304645715], 
             UndirectedEdge[78, 194] -> 
             RGBColor[
              0.8779879239481946, 0.9049685667167771, 0.9590265204843249], 
             UndirectedEdge[107, 268] -> 
             RGBColor[
              0.9062587007328442, 0.9268056278007554, 0.9460899606621418], 
             UndirectedEdge[5, 274] -> 
             RGBColor[
              0.7938119937570809, 0.8390534926649642, 0.9800297446658951], 
             UndirectedEdge[12, 118] -> 
             RGBColor[
              0.8600882153882948, 0.8915307391598665, 0.9848586438629936], 
             UndirectedEdge[20, 291] -> 
             RGBColor[
              0.5192902744519257, 0.6115997251752635, 0.9578951698068685], 
             UndirectedEdge[6, 379] -> 
             RGBColor[
              0.8496403934070119, 0.8829442031013972, 0.9855206532777357], 
             UndirectedEdge[97, 181] -> 
             RGBColor[
              0.5878301047314695, 0.6721371150340869, 0.9627619434742196], 
             UndirectedEdge[39, 320] -> 
             RGBColor[
              0.7942138347495633, 0.8391651510458488, 0.9801234707637227], 
             UndirectedEdge[202, 218] -> 
             RGBColor[
              0.4907396958863629, 0.5964938493557242, 0.9533143970382318], 
             UndirectedEdge[61, 344] -> 
             RGBColor[
              0.881601646153088, 0.9047153213033923, 0.7921432298537621], 
             UndirectedEdge[181, 214] -> 
             RGBColor[
              0.6160982839437641, 0.6966215910677778, 0.9645631668570577], 
             UndirectedEdge[274, 324] -> 
             RGBColor[
              0.6510240786563688, 0.7246676338173286, 0.9677389199360353], 
             UndirectedEdge[62, 231] -> 
             RGBColor[
              0.6194795123777154, 0.6974903541374335, 0.9656807583357598], 
             UndirectedEdge[117, 289] -> 
             RGBColor[
              0.6608449315489257, 0.7326794982133197, 0.968467333677273], 
             UndirectedEdge[14, 396] -> 
             RGBColor[
              0.7182972157655416, 0.7795945905182211, 0.9727372557498131], 
             UndirectedEdge[79, 175] -> 
             RGBColor[
              0.902941812425402, 0.9254453077981851, 0.9906045902064482], 
             UndirectedEdge[246, 395] -> 
             RGBColor[
              0.3646974371549051, 0.4824434247083755, 0.945010375405896], 
             UndirectedEdge[87, 396] -> 
             RGBColor[
              0.6261371206562856, 0.7073653475614362, 0.9637109542353608], 
             UndirectedEdge[341, 366] -> 
             RGBColor[
              0.6918803986042168, 0.7592214929661834, 0.9699238302090869], 
             UndirectedEdge[40, 226] -> 
             RGBColor[
              0.47066844167823996`, 0.5808276335286304, 0.951560648970369], 
             UndirectedEdge[67, 316] -> 
             RGBColor[
              0.7563837581500183, 0.8084529176261851, 0.9474404829610525], 
             UndirectedEdge[303, 376] -> 
             RGBColor[
              0.5994777554418, 0.6830851711256585, 0.9631403629966009], 
             UndirectedEdge[208, 357] -> 
             RGBColor[
              0.7647164494638768, 0.8150438213466517, 0.9434308724673846], 
             UndirectedEdge[54, 66] -> 
             RGBColor[
              0.9155692892801353, 0.9046196870123915, 0.6671868683313807], 
             UndirectedEdge[3, 160] -> 
             RGBColor[
              0.47474835812571947`, 0.5844611301530906, 0.9517930762936451], 
             UndirectedEdge[230, 328] -> 
             RGBColor[
              0.7823593992036434, 0.830437278049171, 0.9735217516308654], 
             UndirectedEdge[282, 383] -> 
             RGBColor[
              0.6406963812098123, 0.7179566846519732, 0.9656970628457031], 
             UndirectedEdge[106, 150] -> 
             RGBColor[
              0.8000674720421159, 0.8439389305666222, 0.9514589295052187], 
             UndirectedEdge[1, 298] -> 
             RGBColor[
              0.7433037109996872, 0.7944486869121627, 0.7856131252949625], 
             UndirectedEdge[66, 131] -> 
             RGBColor[
              0.8645056018683057, 0.8947973168230984, 0.9869385101311021], 
             UndirectedEdge[53, 126] -> 
             RGBColor[
              0.39363136849597874`, 0.5153654397285432, 0.9463028206193796], 
             UndirectedEdge[182, 281] -> 
             RGBColor[
              0.872061232577128, 0.8556450184809136, 0.6415044952333295], 
             UndirectedEdge[74, 263] -> 
             RGBColor[
              0.6159197842926158, 0.6860449991469413, 0.9438311949043006], 
             UndirectedEdge[24, 243] -> 
             RGBColor[
              0.704767847222017, 0.7673603148791388, 0.9651431435435915], 
             UndirectedEdge[177, 252] -> 
             RGBColor[
              0.8049067112683026, 0.8482554715355464, 0.9809936691560714], 
             UndirectedEdge[10, 216] -> 
             RGBColor[
              0.6222684407196544, 0.7038501783933379, 0.9636623772551736], 
             UndirectedEdge[280, 339] -> 
             RGBColor[
              0.7341505055833975, 0.7873135242936147, 0.8091380625181588], 
             UndirectedEdge[152, 154] -> 
             RGBColor[
              0.7293155071091473, 0.7882422549527737, 0.9738860647129525], 
             UndirectedEdge[36, 304] -> 
             RGBColor[
              0.7266399208716139, 0.7852863142637648, 0.9714049041519697], 
             UndirectedEdge[128, 299] -> 
             RGBColor[
              0.7462560730792577, 0.8017001831365176, 0.9753434892711903], 
             UndirectedEdge[95, 162] -> 
             RGBColor[
              0.7450743412711007, 0.800777005266491, 0.9752257052884648], 
             UndirectedEdge[215, 329] -> 
             RGBColor[
              0.6136579219399243, 0.6972008376480547, 0.9627513367837258], 
             UndirectedEdge[208, 387] -> 
             RGBColor[
              0.5599746339098548, 0.6536516602346223, 0.958502400917507], 
             UndirectedEdge[178, 197] -> 
             RGBColor[
              0.7287027934196824, 0.7877408523456488, 0.9738424036843352], 
             UndirectedEdge[53, 303] -> 
             RGBColor[
              0.42897806196239124`, 0.5459809690326798, 0.9485550806712058], 
             UndirectedEdge[59, 121] -> 
             RGBColor[
              0.5408300596389009, 0.6381092323882196, 0.9569952699020113], 
             UndirectedEdge[134, 269] -> 
             RGBColor[
              0.6362282995709254, 0.7121256144964407, 0.9666889114600883], 
             UndirectedEdge[44, 362] -> 
             RGBColor[
              0.49901388493026094`, 0.6041609779625425, 0.9537033474512521], 
             UndirectedEdge[284, 338] -> 
             RGBColor[
              0.42703569082658294`, 0.5434971940374391, 0.9486527411502648], 
             UndirectedEdge[12, 346] -> 
             RGBColor[
              0.7363025192589423, 0.7939243912422764, 0.9743514120476302], 
             UndirectedEdge[113, 387] -> 
             RGBColor[
              0.6760550983027773, 0.7456677419435898, 0.9691607412100227], 
             UndirectedEdge[55, 400] -> 
             RGBColor[
              0.8462964524983904, 0.8802887358591649, 0.9851988125592682], 
             UndirectedEdge[25, 201] -> 
             RGBColor[
              0.8856797530301763, 0.9116810102025521, 0.9889581195713093], 
             UndirectedEdge[123, 309] -> 
             RGBColor[
              0.6964150797620242, 0.7545068658561571, 0.7491172217867589], 
             UndirectedEdge[35, 162] -> 
             RGBColor[
              0.8224874299808327, 0.8176219010039484, 0.6375919523147577], 
             UndirectedEdge[73, 172] -> 
             RGBColor[
              0.8629517195511687, 0.8928765524460651, 0.9403698162654008], 
             UndirectedEdge[137, 282] -> 
             RGBColor[
              0.4918018329168807, 0.5874466714822539, 0.9555794839546268], 
             UndirectedEdge[37, 114] -> 
             RGBColor[
              0.5974111767546735, 0.6764058242457143, 0.9650228110161945], 
             UndirectedEdge[214, 248] -> 
             RGBColor[
              0.45652614276911185`, 0.5693462781708947, 0.9504473153952946], 
             UndirectedEdge[161, 363] -> 
             RGBColor[
              0.6990354152004572, 0.7576707780606293, 0.8257195707393017], 
             UndirectedEdge[51, 84] -> 
             RGBColor[
              0.6552037404223577, 0.7286111928089891, 0.9676070866806626], 
             UndirectedEdge[56, 278] -> 
             RGBColor[
              0.6084262537868205, 0.6922138259668698, 0.962845222958782], 
             UndirectedEdge[4, 140] -> 
             RGBColor[
              0.7683435692315441, 0.818955103001872, 0.9775449644682632], 
             UndirectedEdge[221, 351] -> 
             RGBColor[
              0.5775260389014315, 0.6679006814885686, 0.9598841118113589], 
             UndirectedEdge[54, 204] -> 
             RGBColor[
              0.6915722931787656, 0.7246078833274596, 0.6476922229968484], 
             UndirectedEdge[10, 298] -> 
             RGBColor[
              0.5795669781870384, 0.6691832074303952, 0.9603007617039947], 
             UndirectedEdge[134, 226] -> 
             RGBColor[
              0.6407427447551944, 0.7160358000124423, 0.9669765679152627], 
             UndirectedEdge[35, 98] -> 
             RGBColor[
              0.6739818985328593, 0.6958599690592022, 0.6259775061489619], 
             UndirectedEdge[70, 180] -> 
             RGBColor[
              0.6671240287707431, 0.736310139472478, 0.9698433435151612], 
             UndirectedEdge[165, 328] -> 
             RGBColor[
              0.7951288904360154, 0.8399607437021512, 0.9519063337911668], 
             UndirectedEdge[162, 214] -> 
             RGBColor[
              0.5623273981076149, 0.6546153663787095, 0.9592037874744077], 
             UndirectedEdge[211, 370] -> 
             RGBColor[
              0.6794227590799242, 0.749489490288239, 0.9686821691245656], 
             UndirectedEdge[55, 245] -> 
             RGBColor[
              0.6298211968955174, 0.7054083021013078, 0.9668182599900133], 
             UndirectedEdge[247, 315] -> 
             RGBColor[
              0.34618057923164103`, 0.47426595101378777`, 0.9432792982865414],
              UndirectedEdge[16, 268] -> 
             RGBColor[
              0.5769128658444809, 0.6611570706249645, 0.9627217882096544], 
             UndirectedEdge[154, 291] -> 
             RGBColor[
              0.6866261927426782, 0.7547065387766334, 0.9696806840023307], 
             UndirectedEdge[296, 373] -> 
             RGBColor[
              0.4579169651635428, 0.565177733470462, 0.9517068139822263], 
             UndirectedEdge[101, 394] -> 
             RGBColor[
              0.7315832380485991, 0.7902376528928907, 0.9738810382007735], 
             UndirectedEdge[173, 388] -> 
             RGBColor[
              0.6805412133880726, 0.7487651979565543, 0.9699081270471948], 
             UndirectedEdge[84, 102] -> 
             RGBColor[
              0.5215225937918366, 0.6224345618221484, 0.9554753154649527], 
             UndirectedEdge[216, 298] -> 
             RGBColor[
              0.5350357083900001, 0.6334051170118129, 0.9565391173462898], 
             UndirectedEdge[209, 310] -> 
             RGBColor[
              0.7727379382136108, 0.8227265876953669, 0.9778931079674057], 
             UndirectedEdge[34, 93] -> 
             RGBColor[
              0.6346690956730773, 0.7117413023027752, 0.9661265411526896], 
             UndirectedEdge[112, 285] -> 
             RGBColor[
              0.7682592937190076, 0.336830545167461, 0.43206431286887903`], 
             UndirectedEdge[131, 309] -> 
             RGBColor[
              0.6348132571013001, 0.70985248838054, 0.9670809622157945], 
             UndirectedEdge[116, 265] -> 
             RGBColor[
              0.6572038941972049, 0.7309360187370997, 0.9672852610717004], 
             UndirectedEdge[49, 129] -> 
             RGBColor[
              0.8011699174434077, 0.841385877732806, 0.7867916223022933], 
             UndirectedEdge[238, 325] -> 
             RGBColor[
              0.5695332729498713, 0.6563118009671343, 0.9615865700857873], 
             UndirectedEdge[112, 399] -> 
             RGBColor[
              0.7082546679189734, 0.7720131966039272, 0.9715558643481351], 
             UndirectedEdge[186, 322] -> 
             RGBColor[
              0.6823072861402713, 0.7516229751534017, 0.9690516683453763], 
             UndirectedEdge[180, 332] -> 
             RGBColor[
              0.4339830561416238, 0.5503160434324093, 0.9488739944745639], 
             UndirectedEdge[60, 331] -> 
             RGBColor[
              0.9003886730835564, 0.9229796573953593, 0.975458025152626], 
             UndirectedEdge[14, 126] -> 
             RGBColor[
              0.5846263866767547, 0.6684807452484668, 0.9629308853713083], 
             UndirectedEdge[275, 288] -> 
             RGBColor[
              0.5381997726434524, 0.6341757727641852, 0.9574723194386863], 
             UndirectedEdge[276, 290] -> 
             RGBColor[
              0.6074907208342191, 0.6796546061842708, 0.9575032394672505], 
             UndirectedEdge[18, 232] -> 
             RGBColor[
              0.754606966593679, 0.8082239646191249, 0.976175828293171], 
             UndirectedEdge[4, 325] -> 
             RGBColor[
              0.7891591278276036, 0.8352163755812184, 0.9796196648166637], 
             UndirectedEdge[1, 62] -> 
             RGBColor[
              0.9190012742815183, 0.9341950715965169, 0.8015028018070387], 
             UndirectedEdge[20, 304] -> 
             RGBColor[
              0.6100173206834115, 0.6833508569069906, 0.9636117281265455], 
             UndirectedEdge[255, 328] -> 
             RGBColor[
              0.5792691139601911, 0.6693157883459062, 0.9600213330650788], 
             UndirectedEdge[3, 74] -> 
             RGBColor[
              0.3821069977823046, 0.5006563380545102, 0.9460096194959071], 
             UndirectedEdge[18, 279] -> 
             RGBColor[
              0.8687839040548326, 0.8982412585622219, 0.9815432051084966], 
             UndirectedEdge[163, 226] -> 
             RGBColor[
              0.5538201650832799, 0.6479694512827334, 0.9583558659911546], 
             UndirectedEdge[145, 254] -> 
             RGBColor[
              0.7592725801615621, 0.812222186364943, 0.9766363851126444], 
             UndirectedEdge[23, 348] -> 
             RGBColor[
              0.9033838219263994, 0.9242292057105226, 0.9334803752782681], 
             UndirectedEdge[119, 396] -> 
             RGBColor[
              0.6868628957368629, 0.7550378608021366, 0.9696041764997767], 
             UndirectedEdge[73, 141] -> 
             RGBColor[
              0.8121667455411212, 0.8531636518466112, 0.9353349094544972], 
             UndirectedEdge[29, 396] -> 
             RGBColor[
              0.6946189247669028, 0.7610969296284076, 0.9703772249892788], 
             UndirectedEdge[160, 312] -> 
             RGBColor[
              0.4984430409224281, 0.6036975410807544, 0.9536584085198849], 
             UndirectedEdge[210, 397] -> 
             RGBColor[
              0.793298668028259, 0.8252456382232383, 0.6804783393667628], 
             UndirectedEdge[11, 86] -> 
             RGBColor[
              0.707745998009659, 0.7708529896898101, 0.9720478053383312], 
             UndirectedEdge[113, 315] -> 
             RGBColor[
              0.5516922581287892, 0.6409729330253967, 0.9604014543972029], 
             UndirectedEdge[120, 160] -> 
             RGBColor[
              0.6482112957788102, 0.7224099947998694, 0.967487671372117], 
             UndirectedEdge[5, 308] -> 
             RGBColor[
              0.6889325047552204, 0.7568096661193742, 0.9697044739024645], 
             UndirectedEdge[37, 261] -> 
             RGBColor[
              0.3361078873233593, 0.46516698545523827`, 0.9426511877678087], 
             UndirectedEdge[22, 241] -> 
             RGBColor[
              0.747576028374491, 0.8027313422451857, 0.9754750500793357], 
             UndirectedEdge[55, 165] -> 
             RGBColor[
              0.9205962368107038, 0.9387092415471251, 0.9640934623460933], 
             UndirectedEdge[251, 283] -> 
             RGBColor[
              0.5902667450677662, 0.6770852371648342, 0.9616794692333697], 
             UndirectedEdge[334, 365] -> 
             RGBColor[
              0.5727073076978193, 0.6639886184161095, 0.9595047636394165], 
             UndirectedEdge[44, 358] -> 
             RGBColor[
              0.6749588621012255, 0.7444937705189314, 0.9692686121164866], 
             UndirectedEdge[225, 367] -> 
             RGBColor[
              0.6979991142614329, 0.7616011430395594, 0.9613947554690532], 
             UndirectedEdge[23, 321] -> 
             RGBColor[
              0.9070477236467862, 0.9239283339054396, 0.7407567885686984], 
             UndirectedEdge[234, 269] -> 
             RGBColor[
              0.434148489982069, 0.5504593339100563, 0.9488845357725896], 
             UndirectedEdge[21, 208] -> 
             RGBColor[
              0.6403219251191083, 0.7176104809396937, 0.9656964389779755], 
             UndirectedEdge[208, 240] -> 
             RGBColor[
              0.6036159358818127, 0.6889354831716678, 0.9620379290077737], 
             UndirectedEdge[15, 313] -> 
             RGBColor[
              0.7869550162718951, 0.8339374447000804, 0.9792824374975639], 
             UndirectedEdge[63, 204] -> 
             RGBColor[
              0.5010845792473322, 0.6046810367207733, 0.9541871545311155], 
             UndirectedEdge[241, 310] -> 
             RGBColor[
              0.837674181416374, 0.8734552744190927, 0.9843653458261628], 
             UndirectedEdge[182, 256] -> 
             RGBColor[
              0.7434485318897912, 0.7533837110592027, 0.6299081088180281], 
             UndirectedEdge[373, 380] -> 
             RGBColor[
              0.7391779635473545, 0.7961473615833058, 0.9747795050013441], 
             UndirectedEdge[185, 210] -> 
             RGBColor[
              0.9904720614708626, 0.9779739463529298, 0.5644802704695787], 
             UndirectedEdge[96, 223] -> 
             RGBColor[
              0.5464203370198554, 0.6426476714052045, 0.9574353570153009], 
             UndirectedEdge[103, 222] -> 
             RGBColor[
              0.9600008904236148, 0.9668169458367454, 0.7997303000808336], 
             UndirectedEdge[146, 375] -> 
             RGBColor[
              0.6866884645073017, 0.7540657141769662, 0.9701582862883074], 
             UndirectedEdge[42, 276] -> 
             RGBColor[
              0.3513257056938105, 0.47505038305925795`, 0.9437415917579957], 
             UndirectedEdge[46, 372] -> 
             RGBColor[
              0.7154717591782354, 0.7765523389081376, 0.9733152553254334], 
             UndirectedEdge[95, 285] -> 
             RGBColor[
              0.813872995670633, 0.3724643158090455, 0.4366106603951371], 
             UndirectedEdge[14, 326] -> 
             RGBColor[
              0.5489856411281837, 0.6355543948047735, 0.9607351734992997], 
             UndirectedEdge[22, 310] -> 
             RGBColor[
              0.7717744824313658, 0.8219739287157419, 0.9777970796990376], 
             UndirectedEdge[23, 229] -> 
             RGBColor[
              0.8984189753077483, 0.9208017452324416, 0.9542136890248816], 
             UndirectedEdge[23, 160] -> 
             RGBColor[
              0.6379563154725043, 0.714232951867646, 0.9665095421957726], 
             UndirectedEdge[165, 311] -> 
             RGBColor[
              0.7425954435531814, 0.7973117249178541, 0.9477707084161936], 
             UndirectedEdge[179, 288] -> 
             RGBColor[
              0.7312756103199267, 0.7899973317731944, 0.973850376743724], 
             UndirectedEdge[51, 167] -> 
             RGBColor[
              0.7162224797867746, 0.7781489542879052, 0.9724107053624367], 
             UndirectedEdge[310, 346] -> 
             RGBColor[
              0.7758829412780742, 0.8251834879922342, 0.9782065724811468], 
             UndirectedEdge[79, 379] -> 
             RGBColor[
              0.8797015274296671, 0.906914135383317, 0.9883879110767078], 
             UndirectedEdge[78, 264] -> 
             RGBColor[
              0.73057791002035, 0.787520863407485, 0.9458996714317998], 
             UndirectedEdge[309, 325] -> 
             RGBColor[
              0.5946738963018736, 0.6780873453101681, 0.9631885083747966], 
             UndirectedEdge[149, 358] -> 
             RGBColor[
              0.5160532018991774, 0.6016732112349177, 0.9587436912802656], 
             UndirectedEdge[6, 79] -> 
             RGBColor[
              0.8842331977462708, 0.9105275662848631, 0.9888201458369752], 
             UndirectedEdge[134, 234] -> 
             RGBColor[
              0.6379185792366051, 0.7135896497869264, 0.9667966145857296], 
             UndirectedEdge[96, 209] -> 
             RGBColor[
              0.6458659978839059, 0.7227503297019935, 0.9656960550991862], 
             UndirectedEdge[216, 393] -> 
             RGBColor[
              0.539320095830983, 0.6368833757458574, 0.9568764000198724], 
             UndirectedEdge[164, 388] -> 
             RGBColor[
              0.9053840551104502, 0.9261197292493784, 0.9465067798396706], 
             UndirectedEdge[155, 261] -> 
             RGBColor[
              0.4047452188041938, 0.5249916982671607, 0.9470109853334272], 
             UndirectedEdge[125, 288] -> 
             RGBColor[
              0.6003947780194852, 0.6860068070052311, 0.9619987543454975], 
             UndirectedEdge[287, 384] -> 
             RGBColor[
              0.45813205314819705`, 0.5698743431412159, 0.950788062735919], 
             UndirectedEdge[69, 320] -> 
             RGBColor[
              0.6846789862103332, 0.7523704724166389, 0.970043752006508], 
             UndirectedEdge[123, 339] -> 
             RGBColor[
              0.994190747148075, 0.9899829204923201, 0.6090768614999158], 
             UndirectedEdge[132, 202] -> 
             RGBColor[
              0.6029809788971581, 0.6885590667251651, 0.9618928597866786], 
             UndirectedEdge[67, 249] -> 
             RGBColor[
              0.5440689546041879, 0.6407387132315949, 0.9572502475781419], 
             UndirectedEdge[374, 384] -> 
             RGBColor[
              0.6778378743604607, 0.7463832951515288, 0.9699107860312206], 
             UndirectedEdge[99, 252] -> 
             RGBColor[
              0.7881784078328536, 0.8349167764538197, 0.9793981086408655], 
             UndirectedEdge[44, 65] -> 
             RGBColor[
              0.44582241860266353`, 0.5581115861114548, 0.9503078498176062], 
             UndirectedEdge[88, 370] -> 
             RGBColor[
              0.8362237690361274, 0.8703417633237109, 0.862674199565639], 
             UndirectedEdge[13, 275] -> 
             RGBColor[
              0.5773476659617145, 0.6647584045594206, 0.9613742155867877], 
             UndirectedEdge[183, 269] -> 
             RGBColor[
              0.5408632671153004, 0.6374639574870797, 0.9572267447417069], 
             UndirectedEdge[122, 178] -> 
             RGBColor[
              0.7792444080529743, 0.8276618594233421, 0.978580789057901], 
             UndirectedEdge[199, 216] -> 
             RGBColor[
              0.5772330016165985, 0.667662780619562, 0.959861042842866], 
             UndirectedEdge[107, 295] -> 
             RGBColor[
              0.6798855920917877, 0.7436902090500819, 0.9269252337047211], 
             UndirectedEdge[89, 171] -> 
             RGBColor[
              0.8940396828442153, 0.9181936862589487, 0.9844403147121998], 
             UndirectedEdge[18, 91] -> 
             RGBColor[
              0.6784977899006858, 0.7475291430851481, 0.9694362361819944], 
             UndirectedEdge[194, 357] -> 
             RGBColor[
              0.8808986877423064, 0.9071394095884873, 0.9540993566296766], 
             UndirectedEdge[147, 388] -> 
             RGBColor[
              0.7329557179778861, 0.791317654029088, 0.9740343888491616], 
             UndirectedEdge[96, 323] -> 
             RGBColor[
              0.6599783772775912, 0.7337750277423963, 0.9671026451894651], 
             UndirectedEdge[168, 265] -> 
             RGBColor[
              0.6006561484630588, 0.686678746430259, 0.9617049987644333], 
             UndirectedEdge[44, 372] -> 
             RGBColor[
              0.724630675724542, 0.7839879599649178, 0.9740362787861754], 
             UndirectedEdge[180, 286] -> 
             RGBColor[
              0.42665665478552006`, 0.5439702828133912, 0.9484071626586352], 
             UndirectedEdge[18, 45] -> 
             RGBColor[
              0.6103774045089182, 0.6914656837043391, 0.9642836124923428], 
             UndirectedEdge[83, 217] -> 
             RGBColor[
              0.9831329460152517, 0.9850873765335291, 0.830027888855161], 
             UndirectedEdge[137, 314] -> 
             RGBColor[
              0.6021800722276686, 0.6744754660348938, 0.9595088941890246], 
             UndirectedEdge[205, 338] -> 
             RGBColor[
              0.6003904533421516, 0.681444247772776, 0.9642398237334202], 
             UndirectedEdge[210, 293] -> 
             RGBColor[
              0.6934478491969498, 0.7427649689578284, 0.6730093148099985], 
             UndirectedEdge[295, 324] -> 
             RGBColor[
              0.4162209602470276, 0.5348303541039441, 0.9477701311213572], 
             UndirectedEdge[270, 346] -> 
             RGBColor[
              0.7119756812256806, 0.7749200804798755, 0.9719267401797014], 
             UndirectedEdge[26, 349] -> 
             RGBColor[
              0.3418658236011374, 0.46865702995969105`, 0.943072897854152], 
             UndirectedEdge[27, 208] -> 
             RGBColor[
              0.7007250760831623, 0.765009113139741, 0.9716608061983911], 
             UndirectedEdge[139, 193] -> 
             RGBColor[
              0.6873495559767131, 0.7461550473952308, 0.7058294190479958], 
             UndirectedEdge[5, 296] -> 
             RGBColor[
              0.5186017211453029, 0.6129085490401642, 0.9575341772724606], 
             UndirectedEdge[42, 125] -> 
             RGBColor[
              0.4810199453581609, 0.5890178793251706, 0.9524345676234878], 
             UndirectedEdge[12, 106] -> 
             RGBColor[
              0.7073338659359898, 0.7711344974919965, 0.9715730438111845], 
             UndirectedEdge[242, 357] -> 
             RGBColor[
              0.7981859396161415, 0.8422158612356088, 0.946065713334953], 
             UndirectedEdge[148, 279] -> 
             RGBColor[
              0.6686803978126936, 0.7365559373960253, 0.9646228605161176], 
             UndirectedEdge[292, 374] -> 
             RGBColor[
              0.7084739921075778, 0.771255075680015, 0.9723225734440706], 
             UndirectedEdge[195, 369] -> 
             RGBColor[
              0.650879667542111, 0.7237883314958955, 0.9680955266899534], 
             UndirectedEdge[50, 371] -> 
             RGBColor[
              0.582990070250595, 0.6723366282896267, 0.9603142603745713], 
             UndirectedEdge[29, 127] -> 
             RGBColor[
              0.7270858459573872, 0.7867242560097901, 0.9734327801876401], 
             UndirectedEdge[87, 127] -> 
             RGBColor[
              0.65860404184677, 0.7329926739428188, 0.9667665094337221], 
             UndirectedEdge[264, 357] -> 
             RGBColor[
              0.7334886738144619, 0.7896917062791953, 0.9409725075771513], 
             UndirectedEdge[171, 306] -> 
             RGBColor[
              0.8378510552103208, 0.8740849067204057, 0.9788966924613354], 
             UndirectedEdge[114, 170] -> 
             RGBColor[
              0.8330539488980495, 0.8700742828342262, 0.9838442420703213], 
             UndirectedEdge[57, 222] -> 
             RGBColor[
              0.7413055433972386, 0.7927571339714425, 0.7797718700175036], 
             UndirectedEdge[38, 102] -> 
             RGBColor[
              0.44921695151794866`, 0.5614690292380372, 0.9504088536942918], 
             UndirectedEdge[82, 331] -> 
             RGBColor[
              0.8547169654756814, 0.8869921238690763, 0.9860048612535548], 
             UndirectedEdge[90, 324] -> 
             RGBColor[
              0.46431535337545193`, 0.5759911468953156, 0.9509717519423484], 
             UndirectedEdge[160, 341] -> 
             RGBColor[
              0.5890045661032794, 0.6759839201047476, 0.9616324936615367], 
             UndirectedEdge[15, 311] -> 
             RGBColor[
              0.6085403828064595, 0.6922099431224126, 0.9629202111191939], 
             UndirectedEdge[271, 292] -> 
             RGBColor[
              0.5842451208576098, 0.6733555349117868, 0.9604130625557574], 
             UndirectedEdge[41, 156] -> 
             RGBColor[
              0.6564780381405801, 0.7307455122902637, 0.9669554735585956], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.6829622641195379, 0.7522545785264199, 0.9690349539083591], 
             UndirectedEdge[129, 317] -> 
             RGBColor[
              0.7315769178286489, 0.7899915758013376, 0.9741637596409085], 
             UndirectedEdge[164, 354] -> 
             RGBColor[
              0.929986280495323, 0.945736875961658, 0.9488533620595456], 
             UndirectedEdge[78, 230] -> 
             RGBColor[
              0.954987599908895, 0.9659504062298704, 0.9610784316268004], 
             UndirectedEdge[315, 363] -> 
             RGBColor[
              0.6554796319664347, 0.7199449478006374, 0.8229442347464966], 
             UndirectedEdge[5, 121] -> 
             RGBColor[
              0.628123306651815, 0.7074420196758733, 0.9649173510763323], 
             UndirectedEdge[43, 380] -> 
             RGBColor[
              0.8649336835836741, 0.8951386575629645, 0.9869793409472671], 
             UndirectedEdge[135, 234] -> 
             RGBColor[
              0.41731115121642404`, 0.5358756773405073, 0.9478116754351167], 
             UndirectedEdge[344, 356] -> 
             RGBColor[
              0.541739653830642, 0.6331364363722055, 0.9594354788981073], 
             UndirectedEdge[186, 228] -> 
             RGBColor[
              0.604583060869421, 0.6898667908271316, 0.9620141396938162], 
             UndirectedEdge[298, 396] -> 
             RGBColor[
              0.5587323029874733, 0.6526430800254628, 0.9584046000764891], 
             UndirectedEdge[86, 93] -> 
             RGBColor[
              0.8175439594039333, 0.8574412341530877, 0.9824354216528262], 
             UndirectedEdge[249, 266] -> 
             RGBColor[
              0.7622473915810608, 0.8128349028984037, 0.937753512411905], 
             UndirectedEdge[156, 364] -> 
             RGBColor[
              0.6637583201848338, 0.7364329239554277, 0.9676811040346629], 
             UndirectedEdge[10, 311] -> 
             RGBColor[
              0.5923778292036143, 0.6795836334079128, 0.9613092788237131], 
             UndirectedEdge[27, 73] -> 
             RGBColor[
              0.9153287703512508, 0.934005134197397, 0.9455342168296421], 
             UndirectedEdge[56, 213] -> 
             RGBColor[
              0.8433045784202641, 0.8745377952133282, 0.7675362445755325], 
             UndirectedEdge[27, 243] -> 
             RGBColor[
              0.6556972750712786, 0.7284535157989744, 0.9681160527604658], 
             UndirectedEdge[109, 157] -> 
             RGBColor[
              0.8429674885164284, 0.8779142378145319, 0.9848070088587098], 
             UndirectedEdge[12, 241] -> 
             RGBColor[
              0.798093759397242, 0.8421961776691349, 0.9805101853926461], 
             UndirectedEdge[192, 382] -> 
             RGBColor[
              0.6663218217875526, 0.7325892630685835, 0.9363959158879478], 
             UndirectedEdge[140, 280] -> 
             RGBColor[
              0.6110655020013911, 0.6935028331800346, 0.963636641727124], 
             UndirectedEdge[199, 361] -> 
             RGBColor[
              0.47212460591133687`, 0.5800014433557675, 0.9522302021393153], 
             UndirectedEdge[16, 351] -> 
             RGBColor[
              0.45628824824324704`, 0.5660086386376482, 0.9512974238547296], 
             UndirectedEdge[140, 322] -> 
             RGBColor[
              0.7393167641349672, 0.7962791422485367, 0.9746518438071525], 
             UndirectedEdge[57, 238] -> 
             RGBColor[
              0.4186644278936761, 0.5360941069943368, 0.9481614181049246], 
             UndirectedEdge[49, 127] -> 
             RGBColor[
              0.8421376412857539, 0.8739145386637652, 0.7905163918248752], 
             UndirectedEdge[165, 182] -> 
             RGBColor[
              0.9642493286398424, 0.9280400092644917, 0.622182084759657], 
             UndirectedEdge[253, 343] -> 
             RGBColor[
              0.9755756364628192, 0.9797663241790096, 0.8573263355919933], 
             UndirectedEdge[104, 240] -> 
             RGBColor[
              0.667219344359239, 0.7399560899590527, 0.9674658467926022], 
             UndirectedEdge[312, 348] -> 
             RGBColor[
              0.7638705473763233, 0.8136937949236309, 0.9206292416023805], 
             UndirectedEdge[242, 244] -> 
             RGBColor[
              0.7887805714366154, 0.8352013530471952, 0.9619865483499979], 
             UndirectedEdge[41, 165] -> 
             RGBColor[
              0.8456606498476329, 0.8797327434946427, 0.9567403501524115], 
             UndirectedEdge[54, 297] -> 
             RGBColor[
              0.8305402357209852, 0.8378826104037891, 0.6587946914595579], 
             UndirectedEdge[77, 145] -> 
             RGBColor[
              0.5578981637575006, 0.6348755769239226, 0.9627725375401552], 
             UndirectedEdge[69, 150] -> 
             RGBColor[
              0.7652779945280024, 0.815695265472563, 0.9487201743972525], 
             UndirectedEdge[106, 241] -> 
             RGBColor[
              0.7227158338982469, 0.7831510077713981, 0.973106174624999], 
             UndirectedEdge[139, 276] -> 
             RGBColor[
              0.32542592890760413`, 0.4526172981676777, 0.9420912808834518], 
             UndirectedEdge[313, 393] -> 
             RGBColor[
              0.6878441177803785, 0.7543443323381002, 0.9708855279667818], 
             UndirectedEdge[209, 323] -> 
             RGBColor[
              0.6977156203476582, 0.7637800125414878, 0.9705054305792256], 
             UndirectedEdge[8, 213] -> 
             RGBColor[
              0.9768188105870811, 0.979347801663127, 0.7589500672189008], 
             UndirectedEdge[160, 244] -> 
             RGBColor[
              0.7051420892408067, 0.7672998653299531, 0.9554022206536885], 
             UndirectedEdge[180, 284] -> 
             RGBColor[
              0.451089559217665, 0.5643314458552163, 0.9501854323741439], 
             UndirectedEdge[24, 242] -> 
             RGBColor[
              0.7832651383861653, 0.8310879521088623, 0.9713227378490854], 
             UndirectedEdge[81, 192] -> 
             RGBColor[
              0.4713321673540207, 0.5791143456840201, 0.9522351701848185], 
             UndirectedEdge[124, 249] -> 
             RGBColor[
              0.6802517606549925, 0.7486334980474803, 0.9697928257488718], 
             UndirectedEdge[195, 253] -> 
             RGBColor[
              0.9137887859744789, 0.9335270921043354, 0.9719706075306731], 
             UndirectedEdge[31, 81] -> 
             RGBColor[
              0.6019966714088635, 0.6877670433475336, 0.9618105296412245], 
             UndirectedEdge[172, 399] -> 
             RGBColor[
              0.743866688487131, 0.7998335777331529, 0.9751053377451157], 
             UndirectedEdge[124, 315] -> 
             RGBColor[
              0.5660956586262561, 0.6522249789639161, 0.9618370507513601], 
             UndirectedEdge[181, 370] -> 
             RGBColor[
              0.7348083567144947, 0.7927571401064981, 0.9742024878889425], 
             UndirectedEdge[244, 348] -> 
             RGBColor[
              0.9705695956947019, 0.9772961191728297, 0.9223730537361841], 
             UndirectedEdge[284, 367] -> 
             RGBColor[
              0.4654484001158602, 0.5767683521449052, 0.9511003650191524], 
             UndirectedEdge[148, 232] -> 
             RGBColor[
              0.5545034603515399, 0.6465386434529283, 0.9592554837007919], 
             UndirectedEdge[34, 211] -> 
             RGBColor[
              0.5702048379716663, 0.6613813342399284, 0.959701346397752], 
             UndirectedEdge[355, 392] -> 
             RGBColor[
              0.38656372963235486`, 0.5010143121570234, 0.946657233578936], 
             UndirectedEdge[262, 338] -> 
             RGBColor[
              0.6685409250956094, 0.7350082513784841, 0.9437894647440457], 
             UndirectedEdge[87, 119] -> 
             RGBColor[
              0.6878696562755859, 0.7558551943615175, 0.9696834323772703], 
             UndirectedEdge[180, 367] -> 
             RGBColor[
              0.43370535358562345`, 0.550075511436138, 0.9488562995132582], 
             UndirectedEdge[69, 380] -> 
             RGBColor[
              0.7097434152231815, 0.7722510692424513, 0.972462309534962], 
             UndirectedEdge[124, 338] -> 
             RGBColor[
              0.5937693169794327, 0.6761945109109261, 0.9636003917907692], 
             UndirectedEdge[249, 293] -> 
             RGBColor[
              0.4726622325059319, 0.5813502430860329, 0.952020446510363], 
             UndirectedEdge[212, 373] -> 
             RGBColor[
              0.6165357841614965, 0.6995705500596865, 0.9629551018556366], 
             UndirectedEdge[287, 292] -> 
             RGBColor[
              0.48876817089531405`, 0.5947461236697019, 0.9531998501487691], 
             UndirectedEdge[12, 323] -> 
             RGBColor[
              0.7472698955881641, 0.8024921889858119, 0.975444537624168], 
             UndirectedEdge[120, 307] -> 
             RGBColor[
              0.6044744134419895, 0.6845728168437457, 0.964688221012191], 
             UndirectedEdge[99, 398] -> 
             RGBColor[
              0.8272577119180757, 0.8654458258189066, 0.9832931684552204], 
             UndirectedEdge[134, 350] -> 
             RGBColor[
              0.8961172965669075, 0.9195771751346471, 0.9751684084864223], 
             UndirectedEdge[45, 280] -> 
             RGBColor[
              0.4494500733460488, 0.5631625811628305, 0.9500115652267007], 
             UndirectedEdge[188, 330] -> 
             RGBColor[
              0.597385310252989, 0.6797222849555863, 0.9636632858080566], 
             UndirectedEdge[236, 284] -> 
             RGBColor[
              0.5533088049032676, 0.6482400399549002, 0.9579776424403723], 
             UndirectedEdge[374, 389] -> 
             RGBColor[
              0.7874742429587942, 0.8341615782195018, 0.9793823511104578], 
             UndirectedEdge[278, 319] -> 
             RGBColor[
              0.5326547231006433, 0.631472125891748, 0.9563516774624752], 
             UndirectedEdge[78, 242] -> 
             RGBColor[
              0.7952751758220296, 0.8400450183638986, 0.9509928771896015], 
             UndirectedEdge[84, 189] -> 
             RGBColor[
              0.4703787515970752, 0.5801781849687973, 0.951652306187873], 
             UndirectedEdge[223, 385] -> 
             RGBColor[
              0.48105085291457467`, 0.589577779346838, 0.9522892317702228], 
             UndirectedEdge[175, 278] -> 
             RGBColor[
              0.7078094693240109, 0.7704315082117569, 0.9725972282706044], 
             UndirectedEdge[151, 168] -> 
             RGBColor[
              0.7622723428581437, 0.8146763547278406, 0.9768508691917764], 
             UndirectedEdge[322, 339] -> 
             RGBColor[
              0.8624017677169735, 0.8900898333621168, 0.8201532645981873], 
             UndirectedEdge[177, 367] -> 
             RGBColor[
              0.6796134841246765, 0.7472564484722913, 0.9705799724981379], 
             UndirectedEdge[294, 320] -> 
             RGBColor[
              0.6194304590700581, 0.6988166848395347, 0.9650679831969206], 
             UndirectedEdge[179, 279] -> 
             RGBColor[
              0.8661556309964903, 0.8961880316734296, 0.9812812434126492], 
             UndirectedEdge[18, 285] -> 
             RGBColor[
              0.8100248882728875, 0.3694581450632273, 0.43622711701233796`], 
             UndirectedEdge[121, 296] -> 
             RGBColor[
              0.4041094337764844, 0.5214943554887828, 0.9474708880079552], 
             UndirectedEdge[212, 351] -> 
             RGBColor[
              0.5993623125101855, 0.6856283521170708, 0.9616031432587459], 
             UndirectedEdge[29, 87] -> 
             RGBColor[
              0.695625685305626, 0.7619142631877884, 0.9704564808667725], 
             UndirectedEdge[99, 141] -> 
             RGBColor[
              0.7587500705839396, 0.8118878428086145, 0.976491831793194], 
             UndirectedEdge[121, 274] -> 
             RGBColor[
              0.6793197063882624, 0.7476392991135827, 0.9699664554013897], 
             UndirectedEdge[138, 218] -> 
             RGBColor[
              0.4980210993050205, 0.6024052206744763, 0.9538876157880082], 
             UndirectedEdge[61, 388] -> 
             RGBColor[
              0.9103138827331819, 0.9271978746222886, 0.7949911089312047], 
             UndirectedEdge[283, 347] -> 
             RGBColor[
              0.6772527004983392, 0.7477043544560085, 0.9685273222849181], 
             UndirectedEdge[253, 315] -> 
             RGBColor[
              0.636794813595932, 0.7080014905428439, 0.9489197246157712], 
             UndirectedEdge[321, 366] -> 
             RGBColor[
              0.8269613848609536, 0.8613567242586435, 0.7327765351306954], 
             UndirectedEdge[164, 391] -> 
             RGBColor[
              0.8885272790496597, 0.9128987517929987, 0.9448405422712146], 
             UndirectedEdge[74, 91] -> 
             RGBColor[
              0.41563516924080673`, 0.5278760180714337, 0.9486490799708593], 
             UndirectedEdge[91, 285] -> 
             RGBColor[
              0.7320656383275697, 0.30773061699353815`, 0.42902104044232503`],
              UndirectedEdge[51, 183] -> 
             RGBColor[
              0.7225741683261873, 0.7831996991542767, 0.9729830983253867], 
             UndirectedEdge[30, 54] -> 
             RGBColor[
              0.9024225589677359, 0.894136841119772, 0.6659329214579595], 
             UndirectedEdge[68, 250] -> 
             RGBColor[
              0.5279577057559721, 0.6247258081254115, 0.9570646800434752], 
             UndirectedEdge[32, 230] -> 
             RGBColor[
              0.9070145615016871, 0.9285381623575779, 0.9856314133435161], 
             UndirectedEdge[275, 318] -> 
             RGBColor[
              0.40442766414277764`, 0.5247166483802033, 0.9469907510312043], 
             UndirectedEdge[131, 186] -> 
             RGBColor[
              0.7524944429106486, 0.806861684807988, 0.9759390056761406], 
             UndirectedEdge[192, 292] -> 
             RGBColor[
              0.4615800062335305, 0.5711971019565543, 0.9514674443380702], 
             UndirectedEdge[144, 200] -> 
             RGBColor[
              0.641438045587939, 0.7148653241052831, 0.9678369479042707], 
             UndirectedEdge[139, 318] -> 
             RGBColor[
              0.3933243839896702, 0.5150995451786686, 0.9462832598380935], 
             UndirectedEdge[93, 148] -> 
             RGBColor[
              0.6020482198353331, 0.6836809709152232, 0.9639943009950978], 
             UndirectedEdge[92, 311] -> 
             RGBColor[
              0.6858212104446705, 0.752854717571947, 0.9705505539978634], 
             UndirectedEdge[334, 370] -> 
             RGBColor[
              0.5979501166947103, 0.6839219954167228, 0.961874757929852], 
             UndirectedEdge[62, 129] -> 
             RGBColor[
              0.7259290636174427, 0.7854881301602403, 0.9736250622643448], 
             UndirectedEdge[97, 191] -> 
             RGBColor[
              0.5112776198199497, 0.6122608990845089, 0.9551817034645116], 
             UndirectedEdge[120, 366] -> 
             RGBColor[
              0.7510871282797474, 0.8056475676613052, 0.9757790079196672], 
             UndirectedEdge[91, 288] -> 
             RGBColor[
              0.6169650084602923, 0.6994592665574528, 0.9633032235845519], 
             UndirectedEdge[21, 32] -> 
             RGBColor[
              0.7988224441088428, 0.8431885505263585, 0.9804705311490228], 
             UndirectedEdge[121, 178] -> 
             RGBColor[
              0.678619156256973, 0.7470806994548191, 0.9698996363044788], 
             UndirectedEdge[294, 381] -> 
             RGBColor[
              0.4351384281120906, 0.5513167685625439, 0.9489476137548667], 
             UndirectedEdge[46, 149] -> 
             RGBColor[
              0.375820851736299, 0.49033353811920566`, 0.9459898554327708], 
             UndirectedEdge[66, 232] -> 
             RGBColor[
              0.7861648159022381, 0.8331889300709618, 0.9792384952421086], 
             UndirectedEdge[114, 261] -> 
             RGBColor[
              0.628823668943407, 0.7039882522376428, 0.9670106747387532], 
             UndirectedEdge[189, 395] -> 
             RGBColor[
              0.46000830971177675`, 0.571758993063229, 0.950835907014482], 
             UndirectedEdge[54, 290] -> 
             RGBColor[
              0.959268841010267, 0.9392001404778119, 0.6621886497722458], 
             UndirectedEdge[4, 309] -> 
             RGBColor[
              0.5936529054274995, 0.677289739479289, 0.9630867455461412], 
             UndirectedEdge[195, 315] -> 
             RGBColor[
              0.5928854315774578, 0.6735566391783663, 0.9644001852565749], 
             UndirectedEdge[181, 305] -> 
             RGBColor[
              0.67016299635724, 0.7408349968468309, 0.9687305804191177], 
             UndirectedEdge[153, 372] -> 
             RGBColor[
              0.8247186775873898, 0.863685957239837, 0.9829807529110397], 
             UndirectedEdge[175, 227] -> 
             RGBColor[
              0.6727329253234398, 0.7419547896117937, 0.969835874237265], 
             UndirectedEdge[271, 287] -> 
             RGBColor[
              0.5083961522060367, 0.6106810031282282, 0.9547450367372138], 
             UndirectedEdge[232, 297] -> 
             RGBColor[
              0.701135762343088, 0.7664518534623594, 0.9708463183702858], 
             UndirectedEdge[21, 25] -> 
             RGBColor[
              0.7895699277622366, 0.8358108451444404, 0.9795880178800647], 
             UndirectedEdge[123, 297] -> 
             RGBColor[
              0.8410783709698798, 0.872714617690113, 0.7605825928302437], 
             UndirectedEdge[6, 178] -> 
             RGBColor[
              0.8488896784772826, 0.8823456033940449, 0.9854490494175671], 
             UndirectedEdge[90, 319] -> 
             RGBColor[
              0.5064353717834187, 0.6101860753241086, 0.9542875940821347], 
             UndirectedEdge[258, 302] -> 
             RGBColor[
              0.6803298498432522, 0.7481871947623562, 0.9703592567482695], 
             UndirectedEdge[253, 397] -> 
             RGBColor[
              0.7792603037055259, 0.8273928461938478, 0.9591041183437137], 
             UndirectedEdge[169, 177] -> 
             RGBColor[
              0.8754552913067509, 0.6065043809533067, 0.4656579812438112], 
             UndirectedEdge[198, 332] -> 
             RGBColor[
              0.5109376449855112, 0.6137136509481684, 0.954677278206725], 
             UndirectedEdge[45, 123] -> 
             RGBColor[
              0.7094903149107263, 0.7658319773615359, 0.7499503642084577], 
             UndirectedEdge[223, 245] -> 
             RGBColor[
              0.435198389305663, 0.5505162854238375, 0.9491869602034275], 
             UndirectedEdge[380, 381] -> 
             RGBColor[
              0.6477533850667797, 0.7215196279759579, 0.9676941692718112], 
             UndirectedEdge[277, 378] -> 
             RGBColor[
              0.7486849168697818, 0.803608613461736, 0.9758236386798655], 
             UndirectedEdge[119, 326] -> 
             RGBColor[
              0.5175513210995049, 0.6109976650886889, 0.9576020942492633], 
             UndirectedEdge[89, 133] -> 
             RGBColor[
              0.7023985608607137, 0.7663654271200115, 0.9717951921090335], 
             UndirectedEdge[22, 346] -> 
             RGBColor[
              0.6857847882361913, 0.7544595558183272, 0.9693162767343196], 
             UndirectedEdge[73, 243] -> 
             RGBColor[
              0.7249080215290273, 0.7823230887328736, 0.9284655830610271], 
             UndirectedEdge[26, 353] -> 
             RGBColor[
              0.4388864297078119, 0.5489999635543479, 0.950274920682499], 
             UndirectedEdge[21, 230] -> 
             RGBColor[
              0.8335038393582386, 0.8706879086946229, 0.978416834282743], 
             UndirectedEdge[107, 390] -> 
             RGBColor[
              0.9753343168670224, 0.9810955437216027, 0.925319675812354], 
             UndirectedEdge[223, 364] -> 
             RGBColor[
              0.611679421896909, 0.6941529281976587, 0.9635812623901472], 
             UndirectedEdge[2, 211] -> 
             RGBColor[
              0.7631868212848552, 0.8151404088947407, 0.9769742529863837], 
             UndirectedEdge[128, 353] -> 
             RGBColor[
              0.6748699909374275, 0.7451195906863441, 0.9687844101011585], 
             UndirectedEdge[259, 331] -> 
             RGBColor[
              0.6438961231905317, 0.7184778565820642, 0.9673106520760768], 
             UndirectedEdge[2, 334] -> 
             RGBColor[
              0.6817141788996413, 0.7495729140232246, 0.9701668417916701], 
             UndirectedEdge[72, 191] -> 
             RGBColor[
              0.5106145713850865, 0.6116865998560137, 0.9551394546045529], 
             UndirectedEdge[247, 301] -> 
             RGBColor[
              0.45465500359949657`, 0.5660618282155871, 0.9507877908059177], 
             UndirectedEdge[247, 397] -> 
             RGBColor[
              0.48864606934123495`, 0.5936573066647917, 0.9534636920144839], 
             UndirectedEdge[125, 263] -> 
             RGBColor[
              0.745273299593711, 0.7996543725039003, 0.9525047670213618], 
             UndirectedEdge[123, 325] -> 
             RGBColor[
              0.8919213021621283, 0.9124335019580865, 0.7656501410572814], 
             UndirectedEdge[129, 393] -> 
             RGBColor[
              0.5545158877765943, 0.6492200042099305, 0.9580726684258509], 
             UndirectedEdge[19, 205] -> 
             RGBColor[
              0.6014195954777897, 0.682335638964478, 0.9643053997602684], 
             UndirectedEdge[277, 352] -> 
             RGBColor[
              0.6829975448291506, 0.7517060871987399, 0.9694323208641658], 
             UndirectedEdge[139, 224] -> 
             RGBColor[
              0.6460108493625908, 0.7181846497865244, 0.9684235978427078], 
             UndirectedEdge[65, 250] -> 
             RGBColor[
              0.5168793183369207, 0.6151302657589708, 0.9563587749933666], 
             UndirectedEdge[58, 117] -> 
             RGBColor[
              0.8991359311438328, 0.9218191997055634, 0.969737314816578], 
             UndirectedEdge[134, 272] -> 
             RGBColor[
              0.6491072480011056, 0.723147717218305, 0.96754629360627], 
             UndirectedEdge[74, 95] -> 
             RGBColor[
              0.5383462052554017, 0.6249765662946947, 0.9600335099000774], 
             UndirectedEdge[156, 245] -> 
             RGBColor[
              0.4872772875935878, 0.5927962811816063, 0.9532868018479432], 
             UndirectedEdge[221, 324] -> 
             RGBColor[
              0.5125963514337905, 0.6151878361532508, 0.9547726089686241], 
             UndirectedEdge[227, 375] -> 
             RGBColor[
              0.6283445010929202, 0.7066994563115723, 0.9655652357673472], 
             UndirectedEdge[132, 348] -> 
             RGBColor[
              0.8143352265077299, 0.854656213066481, 0.924606847856154], 
             UndirectedEdge[137, 319] -> 
             RGBColor[
              0.4011633821256573, 0.5150908204282922, 0.9476041428015163], 
             UndirectedEdge[128, 170] -> 
             RGBColor[
              0.7682250283742498, 0.8188624979832098, 0.9775331494234354], 
             UndirectedEdge[120, 220] -> 
             RGBColor[
              0.8276652826733835, 0.8654710038891431, 0.9834116026860849], 
             UndirectedEdge[292, 371] -> 
             RGBColor[
              0.5738577704855237, 0.6649226159349257, 0.9595953322843487], 
             UndirectedEdge[143, 378] -> 
             RGBColor[
              0.7956484765267504, 0.8408729560882058, 0.9801106769026655], 
             UndirectedEdge[59, 373] -> 
             RGBColor[
              0.5946375910259594, 0.6817926103698988, 0.9612311958762825], 
             UndirectedEdge[2, 340] -> 
             RGBColor[
              0.7612344065959993, 0.8136151677009053, 0.9767796545365512], 
             UndirectedEdge[131, 322] -> 
             RGBColor[
              0.8002716835304533, 0.844305557898255, 0.980618997996551], 
             UndirectedEdge[62, 317] -> 
             RGBColor[
              0.8493772266322526, 0.8827343610586759, 0.9854955521958275], 
             UndirectedEdge[243, 337] -> 
             RGBColor[
              0.4096945169355226, 0.5289538295248233, 0.9474160663707482], 
             UndirectedEdge[21, 217] -> 
             RGBColor[
              0.8602887274577906, 0.8888102516443522, 0.8496691920523477], 
             UndirectedEdge[24, 74] -> 
             RGBColor[
              0.6069852958469417, 0.6793816722930396, 0.9589549533550381], 
             UndirectedEdge[1, 127] -> 
             RGBColor[
              0.8421686893202609, 0.8739809472701379, 0.7938957787747019], 
             UndirectedEdge[226, 355] -> 
             RGBColor[
              0.4860801277816656, 0.5933395345959382, 0.952773913355297], 
             UndirectedEdge[97, 370] -> 
             RGBColor[
              0.5319289942433632, 0.628466742656603, 0.9571902432063439], 
             UndirectedEdge[148, 257] -> 
             RGBColor[
              0.49944373191742486`, 0.6029327122823465, 0.9541729812632239], 
             UndirectedEdge[48, 344] -> 
             RGBColor[
              0.5694054704767325, 0.6570991762266731, 0.9611983202708752], 
             UndirectedEdge[74, 148] -> 
             RGBColor[
              0.3324705379166444, 0.45878198900977074`, 0.9425378502334998], 
             UndirectedEdge[266, 293] -> 
             RGBColor[
              0.6907059608306092, 0.7533370702004335, 0.9325131065855713], 
             UndirectedEdge[84, 226] -> 
             RGBColor[
              0.47800728439574, 0.5867856366577937, 0.9521383895521572], 
             UndirectedEdge[354, 371] -> 
             RGBColor[
              0.7293809797276898, 0.7880594723046723, 0.9741627772760653], 
             UndirectedEdge[57, 188] -> 
             RGBColor[
              0.43811603104183316`, 0.5529421079752694, 0.9494008570571479], 
             UndirectedEdge[134, 355] -> 
             RGBColor[
              0.6853357718519326, 0.7525596649568069, 0.9703983357132626], 
             UndirectedEdge[151, 378] -> 
             RGBColor[
              0.8900685995825597, 0.9151805573113565, 0.9893767316734452], 
             UndirectedEdge[167, 238] -> 
             RGBColor[
              0.4927256870165756, 0.5962203735720086, 0.9539917917184104], 
             UndirectedEdge[41, 311] -> 
             RGBColor[
              0.6210211541849875, 0.7019600165806943, 0.9641641777707658], 
             UndirectedEdge[212, 295] -> 
             RGBColor[
              0.4936138214703627, 0.5976613653537136, 0.9538627806562501], 
             UndirectedEdge[179, 285] -> 
             RGBColor[
              0.8082727062339926, 0.36808932713736586`, 0.4360524758817731], 
             UndirectedEdge[85, 348] -> 
             RGBColor[
              0.9674815904907543, 0.97499308994787, 0.9276002410657211], 
             UndirectedEdge[108, 152] -> 
             RGBColor[
              0.5987104546757698, 0.6795243243282905, 0.9643467454701644], 
             UndirectedEdge[86, 148] -> 
             RGBColor[
              0.6107253919029845, 0.6905100560951533, 0.9648457825099843], 
             UndirectedEdge[113, 293] -> 
             RGBColor[
              0.594306929407074, 0.6778836194109907, 0.963116823568381], 
             UndirectedEdge[229, 260] -> 
             RGBColor[
              0.6667173756218838, 0.7328224308042204, 0.9348238908678921], 
             UndirectedEdge[6, 278] -> 
             RGBColor[
              0.6891008546448798, 0.7555137666984348, 0.9708127839011313], 
             UndirectedEdge[142, 378] -> 
             RGBColor[
              0.8698384506380628, 0.8990495856757791, 0.9874471620074519], 
             UndirectedEdge[289, 303] -> 
             RGBColor[
              0.45526648579152684`, 0.567970515328304, 0.9504457177417386], 
             UndirectedEdge[5, 213] -> 
             RGBColor[
              0.8682009444268324, 0.893987025557049, 0.770017681669299], 
             UndirectedEdge[104, 243] -> 
             RGBColor[
              0.5739077357383651, 0.6643476744626025, 0.9600200902146044], 
             UndirectedEdge[121, 373] -> 
             RGBColor[
              0.567438550670055, 0.659711204106171, 0.9590899877860981], 
             UndirectedEdge[120, 202] -> 
             RGBColor[
              0.7022845546221336, 0.7663091023014301, 0.9717445163851373], 
             UndirectedEdge[270, 351] -> 
             RGBColor[
              0.6604786270614764, 0.7338406160337752, 0.9673748537047808], 
             UndirectedEdge[91, 125] -> 
             RGBColor[
              0.5449886845419019, 0.6414853914283927, 0.9573226520879206], 
             UndirectedEdge[280, 297] -> 
             RGBColor[
              0.5810381294052023, 0.6700452214914077, 0.9606437938484869], 
             UndirectedEdge[33, 281] -> 
             RGBColor[
              0.8275336145598282, 0.8656169273194882, 0.9833324597312403], 
             UndirectedEdge[16, 241] -> 
             RGBColor[
              0.569576542545751, 0.655359889510607, 0.9620080836746661], 
             UndirectedEdge[89, 342] -> 
             RGBColor[
              0.7819989315704008, 0.8298365724271425, 0.9788492683304811], 
             UndirectedEdge[157, 370] -> 
             RGBColor[
              0.7904200393176118, 0.8368637711250109, 0.9795695702064038], 
             UndirectedEdge[90, 122] -> 
             RGBColor[
              0.5932362329033469, 0.6795439721600927, 0.9618804401611248], 
             UndirectedEdge[135, 156] -> 
             RGBColor[
              0.4938266242934103, 0.5984689874517588, 0.9537041197911049], 
             UndirectedEdge[12, 22] -> 
             RGBColor[
              0.7321940604122339, 0.790714831965784, 0.9739419192655211], 
             UndirectedEdge[271, 384] -> 
             RGBColor[
              0.5536090031104928, 0.6484837543833007, 0.9580012751429073], 
             UndirectedEdge[158, 324] -> 
             RGBColor[
              0.5779898422543668, 0.6674104704027821, 0.9605132241383418], 
             UndirectedEdge[301, 397] -> 
             RGBColor[
              0.5668313736763604, 0.659218270469678, 0.9590421885889917], 
             UndirectedEdge[95, 233] -> 
             RGBColor[
              0.6287650364906833, 0.7069018266317775, 0.9656627742159201], 
             UndirectedEdge[123, 203] -> 
             RGBColor[
              0.9909309850424706, 0.9891206101585196, 0.6984037329427958], 
             UndirectedEdge[103, 145] -> 
             RGBColor[
              0.9079783273664284, 0.9294612880996035, 0.9910849774976733], 
             UndirectedEdge[20, 80] -> 
             RGBColor[
              0.32208479668119916`, 0.45082094213961443`, 0.9418381996694198],
              UndirectedEdge[73, 337] -> 
             RGBColor[
              0.6693260122154948, 0.7345054479232456, 0.9248342304399246], 
             UndirectedEdge[122, 166] -> 
             RGBColor[
              0.7405464952588572, 0.7972398175488222, 0.974774411913091], 
             UndirectedEdge[62, 216] -> 
             RGBColor[
              0.7107332716718313, 0.7731515016961671, 0.9724287938583662], 
             UndirectedEdge[128, 342] -> 
             RGBColor[
              0.7390158049158364, 0.7960440306191768, 0.9746218470048134], 
             UndirectedEdge[280, 309] -> 
             RGBColor[
              0.4363748381973466, 0.5518374696574517, 0.949178422805002], 
             UndirectedEdge[104, 141] -> 
             RGBColor[
              0.661166459750459, 0.7351882375763401, 0.9668894166080746], 
             UndirectedEdge[148, 276] -> 
             RGBColor[
              0.3321298135533891, 0.4584238661008171, 0.9425184464850689], 
             UndirectedEdge[359, 394] -> 
             RGBColor[
              0.7982687439194713, 0.842332876907832, 0.9805276262144986], 
             UndirectedEdge[8, 43] -> 
             RGBColor[
              0.9163044242354418, 0.9354774697432893, 0.9702854985461282], 
             UndirectedEdge[56, 352] -> 
             RGBColor[
              0.727031722792686, 0.7866819745821743, 0.9734273856963924], 
             UndirectedEdge[70, 152] -> 
             RGBColor[
              0.8789798213108108, 0.9063386665143316, 0.9883190741028165], 
             UndirectedEdge[359, 397] -> 
             RGBColor[
              0.6951894701225712, 0.761170277653705, 0.970688680520572], 
             UndirectedEdge[118, 241] -> 
             RGBColor[
              0.875470183350552, 0.9035472494392682, 0.9863917746768082], 
             UndirectedEdge[43, 227] -> 
             RGBColor[
              0.6633170398473771, 0.7344468181205839, 0.9689377786748979], 
             UndirectedEdge[234, 246] -> 
             RGBColor[
              0.33572352981080167`, 0.4584464993822077, 0.9428605772548939], 
             UndirectedEdge[196, 317] -> 
             RGBColor[
              0.6366595400476365, 0.7119823888045783, 0.9669542756076124], 
             UndirectedEdge[46, 184] -> 
             RGBColor[
              0.7169950919880547, 0.7777670031409198, 0.9734605521687292], 
             UndirectedEdge[136, 331] -> 
             RGBColor[
              0.7780442722934839, 0.8267631178345248, 0.9784508708084901], 
             UndirectedEdge[106, 320] -> 
             RGBColor[
              0.7194684637244468, 0.7806141375106981, 0.9727825071144742], 
             UndirectedEdge[68, 161] -> 
             RGBColor[
              0.3864596046128662, 0.5091536183163249, 0.9458458421664895], 
             UndirectedEdge[45, 297] -> 
             RGBColor[
              0.5569062002583273, 0.6496935725475734, 0.9589541025694577], 
             UndirectedEdge[140, 203] -> 
             RGBColor[
              0.8683742429862604, 0.8964398170331842, 0.910400319182433], 
             UndirectedEdge[225, 243] -> 
             RGBColor[
              0.7066052801440512, 0.7687306693438716, 0.9620328488858452], 
             UndirectedEdge[107, 373] -> 
             RGBColor[
              0.8028075547829214, 0.8455993937560546, 0.9360175549041077], 
             UndirectedEdge[187, 321] -> 
             RGBColor[
              0.9260436990123109, 0.9390752090298939, 0.7425686416569696], 
             UndirectedEdge[297, 322] -> 
             RGBColor[
              0.7092893915387783, 0.7728215305599097, 0.9716589959285152], 
             UndirectedEdge[106, 374] -> 
             RGBColor[
              0.7421433925526315, 0.7985894117505143, 0.9749731519821829], 
             UndirectedEdge[154, 383] -> 
             RGBColor[
              0.587204488326383, 0.6757580827409221, 0.9606460348034196], 
             UndirectedEdge[111, 151] -> 
             RGBColor[
              0.8519108647797915, 0.8847843928915714, 0.9857293108185285], 
             UndirectedEdge[79, 227] -> 
             RGBColor[
              0.6840854446669639, 0.7510069803803914, 0.9709186876667639], 
             UndirectedEdge[93, 290] -> 
             RGBColor[
              0.877409127116163, 0.9049117109986768, 0.9789790939772794], 
             UndirectedEdge[150, 283] -> 
             RGBColor[
              0.8430960266544925, 0.8777125260634077, 0.9556386573049465], 
             UndirectedEdge[46, 195] -> 
             RGBColor[
              0.6977234996740225, 0.7624003585431485, 0.9716224104898632], 
             UndirectedEdge[73, 177] -> 
             RGBColor[
              0.9478511452872669, 0.9599375931750259, 0.9486362299841062], 
             UndirectedEdge[102, 189] -> 
             RGBColor[
              0.4773738772823593, 0.5858571431269317, 0.9522029881058083], 
             UndirectedEdge[3, 95] -> 
             RGBColor[
              0.6507417795388019, 0.7248187191869518, 0.9673720907812409], 
             UndirectedEdge[39, 294] -> 
             RGBColor[
              0.6066633068077225, 0.6888428884582471, 0.9637954727752323], 
             UndirectedEdge[5, 227] -> 
             RGBColor[
              0.5982460757928176, 0.6831863377106274, 0.9625653060192092], 
             UndirectedEdge[166, 169] -> 
             RGBColor[
              0.8271381892658113, 0.5682673842257571, 0.4609725624669786], 
             UndirectedEdge[27, 337] -> 
             RGBColor[
              0.6001152657577461, 0.6806358749893465, 0.9644847001393633], 
             UndirectedEdge[84, 174] -> 
             RGBColor[
              0.5318208179671493, 0.6307951241373795, 0.9562860293956714], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.5541945745834937, 0.6433433792312052, 0.9604749528608516], 
             UndirectedEdge[138, 349] -> 
             RGBColor[
              0.4864665605220403, 0.5923972599286642, 0.9531513707940341], 
             UndirectedEdge[26, 159] -> 
             RGBColor[
              0.42324668456884845`, 0.536302913888048, 0.9490437026548857], 
             UndirectedEdge[81, 287] -> 
             RGBColor[
              0.49852033201580426`, 0.6026633673971677, 0.9539675759955173], 
             UndirectedEdge[311, 361] -> 
             RGBColor[
              0.44273816370131436`, 0.5561442057255361, 0.9499167937624576], 
             UndirectedEdge[231, 393] -> 
             RGBColor[
              0.448066336536867, 0.5612222281871239, 0.950128364497266], 
             UndirectedEdge[201, 223] -> 
             RGBColor[
              0.7011216458635728, 0.7648143124435669, 0.9722867998959575], 
             UndirectedEdge[180, 267] -> 
             RGBColor[
              0.5742881902246892, 0.6630188936425666, 0.9607939215561729], 
             UndirectedEdge[217, 264] -> 
             RGBColor[
              0.7440711549620898, 0.795730320653186, 0.8396513140518402], 
             UndirectedEdge[163, 174] -> 
             RGBColor[
              0.6076336986546893, 0.6919789387623191, 0.9625035058346688], 
             UndirectedEdge[203, 280] -> 
             RGBColor[
              0.7308907434777929, 0.7864512139598142, 0.8984649339610389], 
             UndirectedEdge[40, 163] -> 
             RGBColor[
              0.5830015060765925, 0.6719814151597902, 0.9605643694042265], 
             UndirectedEdge[14, 62] -> 
             RGBColor[
              0.8275967219172837, 0.8654360412259827, 0.9833998339805115], 
             UndirectedEdge[49, 133] -> 
             RGBColor[
              0.7762864155790766, 0.8211843299303578, 0.7848327018842624], 
             UndirectedEdge[276, 288] -> 
             RGBColor[
              0.4707005383551348, 0.5720393107393185, 0.9533057784800054], 
             UndirectedEdge[312, 366] -> 
             RGBColor[
              0.6013188734233654, 0.68693511394219, 0.9619497450674351], 
             UndirectedEdge[23, 120] -> 
             RGBColor[
              0.8311734670655802, 0.8682191773081014, 0.9837592613576702], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.6029522903666169, 0.6885428578675813, 0.9618857594661263], 
             UndirectedEdge[73, 399] -> 
             RGBColor[
              0.8654544857449618, 0.8948317324183838, 0.9406192686099183], 
             UndirectedEdge[269, 272] -> 
             RGBColor[
              0.44533715874656943`, 0.5600174013414349, 0.9496342147931298], 
             UndirectedEdge[20, 151] -> 
             RGBColor[
              0.5842114756876037, 0.6628625444724181, 0.9642210477337152], 
             UndirectedEdge[239, 355] -> 
             RGBColor[
              0.7100314641537067, 0.7722513396515318, 0.9727538328911106], 
             UndirectedEdge[274, 319] -> 
             RGBColor[
              0.6931440970643354, 0.7588625622461216, 0.9710547620758218], 
             UndirectedEdge[6, 352] -> 
             RGBColor[
              0.8077063236507454, 0.8499819153137393, 0.9813949466387418], 
             UndirectedEdge[133, 342] -> 
             RGBColor[
              0.6379621217948641, 0.7158133946051366, 0.9654295050948116], 
             UndirectedEdge[290, 318] -> 
             RGBColor[
              0.6753891759162851, 0.7421368531952618, 0.9616952184218921], 
             UndirectedEdge[87, 298] -> 
             RGBColor[
              0.5597390635261964, 0.6534604135848436, 0.9584838559539828], 
             UndirectedEdge[86, 263] -> 
             RGBColor[
              0.894174638278956, 0.9177730662323238, 0.9661391271807851], 
             UndirectedEdge[109, 191] -> 
             RGBColor[
              0.7108033210017914, 0.7739313908464409, 0.9718596865315403], 
             UndirectedEdge[84, 238] -> 
             RGBColor[
              0.4317069476521588, 0.5466826120930925, 0.9491881730366365], 
             UndirectedEdge[21, 244] -> 
             RGBColor[
              0.8403008781306367, 0.8757571290819478, 0.9669112205927036], 
             UndirectedEdge[137, 175] -> 
             RGBColor[
              0.5763181283490248, 0.6540502027483012, 0.9638496936096455], 
             UndirectedEdge[363, 369] -> 
             RGBColor[
              0.7134738679310878, 0.7701766401181668, 0.826639576179875], 
             UndirectedEdge[98, 290] -> 
             RGBColor[
              0.6660540497651999, 0.7340512361202747, 0.9611003924382728], 
             UndirectedEdge[175, 352] -> 
             RGBColor[
              0.8264149383298764, 0.8648996568270614, 0.9831793910082148], 
             UndirectedEdge[121, 319] -> 
             RGBColor[
              0.5274554099590696, 0.6272510892570307, 0.9559423684862589], 
             UndirectedEdge[249, 387] -> 
             RGBColor[
              0.5544104014016353, 0.6491343656186319, 0.9580643641520048], 
             UndirectedEdge[310, 389] -> 
             RGBColor[
              0.7922451383612843, 0.8379657607109416, 0.979837403372976], 
             UndirectedEdge[228, 238] -> 
             RGBColor[
              0.46176125170807025`, 0.5710820500566498, 0.9515541579444611], 
             UndirectedEdge[268, 324] -> 
             RGBColor[
              0.6425940688880841, 0.7179457728546176, 0.9669348580787778], 
             UndirectedEdge[144, 368] -> 
             RGBColor[
              0.822171064959784, 0.8615839768822673, 0.9827564899557601], 
             UndirectedEdge[137, 278] -> 
             RGBColor[
              0.3925383045911579, 0.5080885939304707, 0.9469251451033005], 
             UndirectedEdge[127, 298] -> 
             RGBColor[
              0.5911992241779578, 0.6782704064068452, 0.9614601552748504], 
             UndirectedEdge[131, 228] -> 
             RGBColor[
              0.7225474582596031, 0.782549373571985, 0.9735814693449909], 
             UndirectedEdge[278, 314] -> 
             RGBColor[
              0.7336714132026546, 0.7908567714983495, 0.9682564288499835], 
             UndirectedEdge[182, 311] -> 
             RGBColor[
              0.7396098329771968, 0.7502672823505432, 0.6296059123780112], 
             UndirectedEdge[77, 94] -> 
             RGBColor[
              0.33865103148764675`, 0.46006354983820935`, 0.9430807496784213],
              UndirectedEdge[144, 333] -> 
             RGBColor[
              0.5352374964839833, 0.6108770927199081, 0.9615094187676076], 
             UndirectedEdge[166, 197] -> 
             RGBColor[
              0.6900048806255653, 0.757318810471129, 0.9700360265395253], 
             UndirectedEdge[106, 384] -> 
             RGBColor[
              0.5676504222448239, 0.6598832109952741, 0.959106667092575], 
             UndirectedEdge[28, 265] -> 
             RGBColor[
              0.5840812924420723, 0.6732225316236675, 0.9604001653827631], 
             UndirectedEdge[113, 266] -> 
             RGBColor[
              0.8838920884822028, 0.9093682792233615, 0.948849889469923], 
             UndirectedEdge[164, 292] -> 
             RGBColor[
              0.7744630712531569, 0.8226000195919113, 0.934285917067829], 
             UndirectedEdge[98, 248] -> 
             RGBColor[
              0.4288609087438259, 0.5453840429532846, 0.9486845111466092], 
             UndirectedEdge[91, 95] -> 
             RGBColor[
              0.684269950997304, 0.7520383992038754, 0.9700115512561931], 
             UndirectedEdge[155, 342] -> 
             RGBColor[
              0.5797662753004229, 0.6682592614997112, 0.9609332502463731], 
             UndirectedEdge[47, 209] -> 
             RGBColor[
              0.7055845775640276, 0.7699273017252053, 0.9712897346949672], 
             UndirectedEdge[2, 360] -> 
             RGBColor[
              0.9072044479996493, 0.9280119465565468, 0.9621558012247077], 
             UndirectedEdge[75, 341] -> 
             RGBColor[
              0.7968713711571783, 0.8416513815606133, 0.9802795098484276], 
             UndirectedEdge[12, 390] -> 
             RGBColor[
              0.8745056988301501, 0.9022832747043397, 0.9604536050778467], 
             UndirectedEdge[19, 198] -> 
             RGBColor[
              0.47327637527587163`, 0.5810933520361331, 0.95227753540338], 
             UndirectedEdge[8, 56] -> 
             RGBColor[
              0.826337094174314, 0.8647677589896119, 0.9614315887966729], 
             UndirectedEdge[70, 154] -> 
             RGBColor[
              0.7652372306523942, 0.8168852622369487, 0.9773123107722086], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.8791903327791167, 0.9029025365151075, 0.7975857502077522], 
             UndirectedEdge[177, 243] -> 
             RGBColor[
              0.6882196500072948, 0.7543859747766035, 0.9712180659149298], 
             UndirectedEdge[109, 340] -> 
             RGBColor[
              0.7300177935898848, 0.7890147157839246, 0.9737250093270391], 
             UndirectedEdge[28, 36] -> 
             RGBColor[
              0.5590096912069814, 0.6528682762782563, 0.9584264370932353], 
             UndirectedEdge[203, 339] -> 
             RGBColor[
              0.9914592465682667, 0.9902505081467643, 0.7559017399734678], 
             UndirectedEdge[247, 369] -> 
             RGBColor[
              0.40417481519629417`, 0.524497643331317, 0.9469746397199199], 
             UndirectedEdge[223, 230] -> 
             RGBColor[
              0.7132039379884773, 0.7742937592166745, 0.9680775803992061], 
             UndirectedEdge[22, 173] -> 
             RGBColor[
              0.6081498244520771, 0.6921601588433743, 0.9627067182678022], 
             UndirectedEdge[69, 283] -> 
             RGBColor[
              0.6401950175352575, 0.717619257996986, 0.9656100057352988], 
             UndirectedEdge[59, 274] -> 
             RGBColor[
              0.7065187467441667, 0.7697207053773104, 0.9721076634915742], 
             UndirectedEdge[31, 164] -> 
             RGBColor[
              0.8020904419946431, 0.8450291637587184, 0.9364608448949925], 
             UndirectedEdge[116, 154] -> 
             RGBColor[
              0.6828456110646643, 0.751753119636284, 0.9693038709522106], 
             UndirectedEdge[10, 170] -> 
             RGBColor[
              0.7213903249690352, 0.7822748717261268, 0.972865103883191], 
             UndirectedEdge[301, 394] -> 
             RGBColor[
              0.6699106474732605, 0.7403808697238049, 0.9688811342829184], 
             UndirectedEdge[90, 351] -> 
             RGBColor[
              0.529245040843093, 0.6287039922306334, 0.9560832547850832], 
             UndirectedEdge[4, 203] -> 
             RGBColor[
              0.888168810707946, 0.9119034837816515, 0.9123732567021781], 
             UndirectedEdge[274, 351] -> 
             RGBColor[
              0.7159537661240098, 0.7773804791526463, 0.9728504227787702], 
             UndirectedEdge[238, 269] -> 
             RGBColor[
              0.3906723187570771, 0.5128024595708709, 0.9461142725866019], 
             UndirectedEdge[66, 325] -> 
             RGBColor[
              0.8243662410688792, 0.8630321737527265, 0.9830460562901042], 
             UndirectedEdge[128, 171] -> 
             RGBColor[
              0.8510565561896509, 0.8844011444509831, 0.980212893386532], 
             UndirectedEdge[198, 205] -> 
             RGBColor[
              0.7013989105771211, 0.7656761071063125, 0.9715757986894604], 
             UndirectedEdge[202, 349] -> 
             RGBColor[
              0.4791851571033827, 0.586485888609912, 0.9525781520442578], 
             UndirectedEdge[295, 390] -> 
             RGBColor[
              0.6708508814500806, 0.7369815473474254, 0.943535713469229], 
             UndirectedEdge[250, 356] -> 
             RGBColor[
              0.500221950756583, 0.6007024911845203, 0.9552973822606794], 
             UndirectedEdge[133, 393] -> 
             RGBColor[
              0.5296323859122634, 0.6290184564074823, 0.95611374800782], 
             UndirectedEdge[124, 293] -> 
             RGBColor[
              0.6087103299045408, 0.68913566534951, 0.9645524199225382], 
             UndirectedEdge[45, 325] -> 
             RGBColor[
              0.6077491314505757, 0.6894124568155469, 0.9640216507964954], 
             UndirectedEdge[116, 304] -> 
             RGBColor[
              0.8446259335880977, 0.8794219394692536, 0.9818218118918738], 
             UndirectedEdge[213, 296] -> 
             RGBColor[
              0.6441870715515017, 0.7080393613699585, 0.7525712186009219], 
             UndirectedEdge[248, 276] -> 
             RGBColor[
              0.3702975798128451, 0.49098741301728066`, 0.945087358175587], 
             UndirectedEdge[209, 346] -> 
             RGBColor[
              0.6867482440184363, 0.7552122147979522, 0.9694123050026877], 
             UndirectedEdge[31, 382] -> 
             RGBColor[
              0.7969863258423953, 0.8412419607320971, 0.9459712753443537], 
             UndirectedEdge[69, 373] -> 
             RGBColor[
              0.5918115337329404, 0.6794982897469959, 0.961008718293987], 
             UndirectedEdge[166, 239] -> 
             RGBColor[
              0.8278006205358625, 0.8659643843994338, 0.9833222205682176], 
             UndirectedEdge[235, 317] -> 
             RGBColor[
              0.6317705921548462, 0.7077478278655094, 0.9666427561710107], 
             UndirectedEdge[43, 59] -> 
             RGBColor[
              0.7203933110622789, 0.7807839063495574, 0.9734310318222055], 
             UndirectedEdge[94, 207] -> 
             RGBColor[
              0.4263750346531451, 0.5437263576093675, 0.9483892180728273], 
             UndirectedEdge[209, 270] -> 
             RGBColor[
              0.708830678161217, 0.7724631801830081, 0.9716132756659602], 
             UndirectedEdge[23, 341] -> 
             RGBColor[
              0.7719667373900495, 0.8217931026129794, 0.9779040836470898], 
             UndirectedEdge[264, 312] -> 
             RGBColor[
              0.5173842573165572, 0.6190748738415829, 0.9551495304583927], 
             UndirectedEdge[48, 118] -> 
             RGBColor[
              0.653620473096892, 0.7237925976264721, 0.9677615151663976], 
             UndirectedEdge[106, 310] -> 
             RGBColor[
              0.7469142879551217, 0.8023935942419542, 0.9754282042447011], 
             UndirectedEdge[267, 282] -> 
             RGBColor[
              0.7258932849897699, 0.7857926183180883, 0.9733139168555038], 
             UndirectedEdge[43, 274] -> 
             RGBColor[
              0.8588829578116404, 0.8903139730749206, 0.9864022173215838], 
             UndirectedEdge[46, 362] -> 
             RGBColor[
              0.4898549683839543, 0.5967253569057624, 0.95298232399051], 
             UndirectedEdge[38, 117] -> 
             RGBColor[
              0.6047775819731938, 0.6848969431683213, 0.9646792097906371], 
             UndirectedEdge[252, 300] -> 
             RGBColor[
              0.7713985703308983, 0.8215369895063158, 0.9777976327603912], 
             UndirectedEdge[7, 67] -> 
             RGBColor[
              0.698076876422522, 0.7628150344330908, 0.9715031471220115], 
             UndirectedEdge[150, 192] -> 
             RGBColor[
              0.6633609382837056, 0.7303810409994163, 0.9414079193378639], 
             UndirectedEdge[239, 272] -> 
             RGBColor[
              0.6738029403028797, 0.7428393919130298, 0.9699017907841179], 
             UndirectedEdge[22, 209] -> 
             RGBColor[
              0.6826397851717279, 0.7520026555214598, 0.9690028122205785], 
             UndirectedEdge[167, 246] -> 
             RGBColor[
              0.4360866184046204, 0.5404003780928598, 0.9506303932610611], 
             UndirectedEdge[131, 140] -> 
             RGBColor[
              0.8095039209053446, 0.851517851903123, 0.9815391811379166], 
             UndirectedEdge[67, 385] -> 
             RGBColor[
              0.510662016277635, 0.6136174557326781, 0.9546203310194283], 
             UndirectedEdge[60, 101] -> 
             RGBColor[
              0.804276720931051, 0.8476665180233396, 0.965939453062086], 
             UndirectedEdge[113, 249] -> 
             RGBColor[
              0.6658483601575256, 0.7373814521089609, 0.9683572293947147], 
             UndirectedEdge[52, 393] -> 
             RGBColor[
              0.48503024014564533`, 0.5928084251703729, 0.9526025037100285], 
             UndirectedEdge[99, 367] -> 
             RGBColor[
              0.6628851806892275, 0.7339177533905645, 0.968984411982932], 
             UndirectedEdge[5, 43] -> 
             RGBColor[
              0.8076865580751931, 0.8501166936372113, 0.9813531129965264], 
             UndirectedEdge[26, 105] -> 
             RGBColor[
              0.5757511535872134, 0.6570806534243169, 0.9632680340624804], 
             UndirectedEdge[128, 306] -> 
             RGBColor[
              0.7472636163477915, 0.8024872835955088, 0.9754439117681706], 
             UndirectedEdge[226, 281] -> 
             RGBColor[
              0.6121729238876628, 0.6935550699581099, 0.9641719236512408], 
             UndirectedEdge[63, 345] -> 
             RGBColor[
              0.5426986857987894, 0.6396262672854662, 0.9571423749983209], 
             UndirectedEdge[4, 280] -> 
             RGBColor[
              0.6308600697230766, 0.7089664999285019, 0.9656095792468691], 
             UndirectedEdge[7, 223] -> 
             RGBColor[
              0.6684657130594618, 0.7387753580472508, 0.969172047872806], 
             UndirectedEdge[155, 361] -> 
             RGBColor[
              0.4047452188041938, 0.5249916982671607, 0.9470109853334272], 
             UndirectedEdge[252, 398] -> 
             RGBColor[
              0.737729952856293, 0.7950395132174239, 0.9744936852884887], 
             UndirectedEdge[6, 252] -> 
             RGBColor[
              0.7764113562473433, 0.82553404892764, 0.9782757567560686], 
             UndirectedEdge[260, 307] -> 
             RGBColor[
              0.362517833449819, 0.48841645948330104`, 0.9443202936788571], 
             UndirectedEdge[21, 357] -> 
             RGBColor[
              0.8497062463101628, 0.8827716372703613, 0.9509903855776587], 
             UndirectedEdge[233, 366] -> 
             RGBColor[
              0.5556474475785382, 0.649781810459352, 0.9583750962758744], 
             UndirectedEdge[37, 41] -> 
             RGBColor[
              0.5143908778070323, 0.6109827963103963, 0.9568985717761168], 
             UndirectedEdge[173, 176] -> 
             RGBColor[
              0.5695106031305205, 0.6613933896384765, 0.959253107345964], 
             UndirectedEdge[60, 136] -> 
             RGBColor[
              0.8300235519867301, 0.8677801381271997, 0.9685056565639001], 
             UndirectedEdge[74, 285] -> 
             RGBColor[
              0.6347831411663014, 0.22302272838741766`, 0.42236901287158124`],
              UndirectedEdge[234, 395] -> 
             RGBColor[
              0.46481267699185225`, 0.5759202945267097, 0.9511420370492332], 
             UndirectedEdge[17, 164] -> 
             RGBColor[
              0.9895524355215759, 0.9895282983585629, 0.7923222495701127], 
             UndirectedEdge[20, 383] -> 
             RGBColor[
              0.4198685700356304, 0.5326512691395522, 0.9488605206079574], 
             UndirectedEdge[19, 219] -> 
             RGBColor[
              0.6820567475901174, 0.7441116290042703, 0.8734330524873613], 
             UndirectedEdge[91, 279] -> 
             RGBColor[
              0.7518450291368559, 0.8056499664576882, 0.9707340902534771], 
             UndirectedEdge[76, 207] -> 
             RGBColor[
              0.6721738372344106, 0.739515842765956, 0.9638831578819965], 
             UndirectedEdge[238, 339] -> 
             RGBColor[
              0.671802717935818, 0.7338612195013681, 0.8050132905284216], 
             UndirectedEdge[142, 379] -> 
             RGBColor[
              0.8460851483536982, 0.8801093472004409, 0.985181550830746], 
             UndirectedEdge[205, 219] -> 
             RGBColor[
              0.910179282891367, 0.9286943840744497, 0.8927313157734418], 
             UndirectedEdge[7, 68] -> 
             RGBColor[
              0.6110678452259142, 0.6899126283413931, 0.9652791807150658], 
             UndirectedEdge[188, 273] -> 
             RGBColor[
              0.6700064407447971, 0.7370971897915592, 0.9558441743942031], 
             UndirectedEdge[16, 69] -> 
             RGBColor[
              0.44402717157038507`, 0.5560545442394094, 0.9503321869852381], 
             UndirectedEdge[118, 323] -> 
             RGBColor[
              0.8246463195414742, 0.8638432607559452, 0.9813261269083301], 
             UndirectedEdge[211, 263] -> 
             RGBColor[
              0.8210332085098937, 0.8605840129895468, 0.9588624509109609], 
             UndirectedEdge[191, 340] -> 
             RGBColor[
              0.6568189699676548, 0.7317584055223094, 0.9664790309329008], 
             UndirectedEdge[33, 182] -> 
             RGBColor[
              0.9167361000465581, 0.8909674755357555, 0.6458452532193854], 
             UndirectedEdge[99, 300] -> 
             RGBColor[
              0.8609263293926812, 0.8919433021077985, 0.9865971159271228], 
             UndirectedEdge[11, 91] -> 
             RGBColor[
              0.5754148897652211, 0.6661867555136083, 0.9597179144179624], 
             UndirectedEdge[78, 233] -> 
             RGBColor[
              0.7094141645180875, 0.7702639988851585, 0.9442543570113968], 
             UndirectedEdge[27, 172] -> 
             RGBColor[
              0.79374097309342, 0.839006979512166, 0.9800202859648395], 
             UndirectedEdge[313, 396] -> 
             RGBColor[
              0.7499577874694848, 0.8047710075806482, 0.9757753435745775], 
             UndirectedEdge[74, 172] -> 
             RGBColor[
              0.5055376728961212, 0.5993462914615435, 0.9567634620076709], 
             UndirectedEdge[217, 366] -> 
             RGBColor[
              0.8280057710688979, 0.8635905607537933, 0.8464515286608827], 
             UndirectedEdge[277, 302] -> 
             RGBColor[
              0.5413955076953252, 0.6385682885935693, 0.9570397840443174], 
             UndirectedEdge[203, 232] -> 
             RGBColor[
              0.8509883764156788, 0.882857845930766, 0.9086674584828379], 
             UndirectedEdge[27, 285] -> 
             RGBColor[
              0.8269186746311674, 0.38279652042116596`, 0.4378735621763603], 
             UndirectedEdge[193, 334] -> 
             RGBColor[
              0.7549351080368221, 0.8029653304519417, 0.7106136178428034], 
             UndirectedEdge[39, 381] -> 
             RGBColor[
              0.6099218037915958, 0.6916652347688579, 0.9640031013216689], 
             UndirectedEdge[270, 390] -> 
             RGBColor[
              0.8501788607968883, 0.8832789639419387, 0.9580289332099179], 
             UndirectedEdge[35, 42] -> 
             RGBColor[
              0.6977143005232951, 0.7164157828381107, 0.6274897138180533], 
             UndirectedEdge[41, 245] -> 
             RGBColor[
              0.5548856099324466, 0.6464318040488255, 0.9594651477963314], 
             UndirectedEdge[45, 276] -> 
             RGBColor[
              0.3471740594857839, 0.471454435781671, 0.9434770525327767], 
             UndirectedEdge[17, 241] -> 
             RGBColor[
              0.904135797721612, 0.9227449504675502, 0.8284919285891703], 
             UndirectedEdge[69, 347] -> 
             RGBColor[
              0.5994346683718491, 0.6856870938651638, 0.9616088393772242], 
             UndirectedEdge[16, 295] -> 
             RGBColor[
              0.3505397572034243, 0.47804165187429093`, 0.9435570612522338], 
             UndirectedEdge[190, 351] -> 
             RGBColor[
              0.5021829739541146, 0.6057603433124161, 0.9542217951939136], 
             UndirectedEdge[112, 141] -> 
             RGBColor[
              0.6549669277151328, 0.7303451160321548, 0.966271505192714], 
             UndirectedEdge[135, 400] -> 
             RGBColor[
              0.6087094516881497, 0.6890357129681776, 0.9645943465980958], 
             UndirectedEdge[295, 310] -> 
             RGBColor[
              0.6186373960740473, 0.6961370367827767, 0.9659143234037305], 
             UndirectedEdge[185, 249] -> 
             RGBColor[
              0.7696864447798448, 0.8165592204811342, 0.8434914021699432], 
             UndirectedEdge[93, 98] -> 
             RGBColor[
              0.5975117099853187, 0.6797516740947555, 0.9637052385989331], 
             UndirectedEdge[221, 268] -> 
             RGBColor[
              0.6981506565026653, 0.763049113475885, 0.9713084761662837], 
             UndirectedEdge[265, 291] -> 
             RGBColor[
              0.6609844758752189, 0.733889437877449, 0.9676620741218204], 
             UndirectedEdge[128, 133] -> 
             RGBColor[
              0.6594154342061493, 0.7325728853120459, 0.9675677707833656], 
             UndirectedEdge[57, 333] -> 
             RGBColor[
              0.33368471429479357`, 0.45048629673325125`, 0.9431860618417969],
              UndirectedEdge[28, 378] -> 
             RGBColor[
              0.7482442149137349, 0.8032508317604203, 0.9757889450075412], 
             UndirectedEdge[92, 386] -> 
             RGBColor[
              0.690847076854012, 0.7569349423357521, 0.970946208611962], 
             UndirectedEdge[35, 248] -> 
             RGBColor[
              0.7166861746423296, 0.7323528127961334, 0.6288354802356446], 
             UndirectedEdge[56, 175] -> 
             RGBColor[
              0.7922060775446874, 0.8381754347847001, 0.979769771465127], 
             UndirectedEdge[3, 21] -> 
             RGBColor[
              0.6099071470155495, 0.6929183939050854, 0.9633020762326602], 
             UndirectedEdge[98, 204] -> 
             RGBColor[
              0.39835750193369834`, 0.5194589789699224, 0.9466039656628755], 
             UndirectedEdge[243, 367] -> 
             RGBColor[
              0.4566703603664368, 0.569641944030139, 0.9504093255750587], 
             UndirectedEdge[48, 209] -> 
             RGBColor[
              0.526689773903076, 0.6237293494120146, 0.956940818837293], 
             UndirectedEdge[116, 291] -> 
             RGBColor[
              0.7538988873566119, 0.8076708077375266, 0.9761052535721968], 
             UndirectedEdge[214, 340] -> 
             RGBColor[
              0.5587602716203378, 0.6518287000556833, 0.9588482496428483], 
             UndirectedEdge[138, 159] -> 
             RGBColor[
              0.5678474214897513, 0.6600431438570211, 0.9591221755947676], 
             UndirectedEdge[22, 48] -> 
             RGBColor[
              0.525726318120831, 0.6229766904323897, 0.956844790568925], 
             UndirectedEdge[13, 297] -> 
             RGBColor[
              0.7195805724459403, 0.7808610793004565, 0.9726847246647877], 
             UndirectedEdge[192, 347] -> 
             RGBColor[
              0.49751761212755236`, 0.600372869392017, 0.9542965843178357], 
             UndirectedEdge[4, 322] -> 
             RGBColor[
              0.7591113318566527, 0.811742808997004, 0.9766247813268976], 
             UndirectedEdge[111, 304] -> 
             RGBColor[
              0.8777167097755993, 0.9052727053261438, 0.9851199912113588], 
             UndirectedEdge[133, 361] -> 
             RGBColor[
              0.4629410652986349, 0.5725458313725862, 0.9515072401818657], 
             UndirectedEdge[4, 186] -> 
             RGBColor[
              0.711334091236848, 0.774298935906737, 0.9719447890064871], 
             UndirectedEdge[73, 240] -> 
             RGBColor[
              0.8182196301499012, 0.8579315042293237, 0.9359113396390248], 
             UndirectedEdge[82, 335] -> 
             RGBColor[
              0.6713042618940869, 0.7410161058114068, 0.9694688425437059], 
             UndirectedEdge[184, 372] -> 
             RGBColor[
              0.9068992557742497, 0.9286008657026183, 0.9909820546859127], 
             UndirectedEdge[85, 340] -> 
             RGBColor[
              0.8125737332218661, 0.8542058166551829, 0.9696826087423156], 
             UndirectedEdge[344, 388] -> 
             RGBColor[
              0.7977468706813797, 0.8419775214492982, 0.9804617224335532], 
             UndirectedEdge[57, 228] -> 
             RGBColor[
              0.5315392524039814, 0.6305665365288156, 0.9562638635231302], 
             UndirectedEdge[36, 80] -> 
             RGBColor[
              0.4387073968694015, 0.5527563994963888, 0.9496313756948438], 
             UndirectedEdge[88, 365] -> 
             RGBColor[
              0.8109809600392364, 0.8504083863230975, 0.8603042052752035], 
             UndirectedEdge[209, 241] -> 
             RGBColor[
              0.7485394841567361, 0.8034840012248107, 0.9755710783477036], 
             UndirectedEdge[49, 62] -> 
             RGBColor[
              0.9189702262470114, 0.9341286629901443, 0.7981234148572122], 
             UndirectedEdge[161, 250] -> 
             RGBColor[
              0.5445011268100619, 0.6390548879459449, 0.958118812204269], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.8106774806339925, 0.8491045458417635, 0.7875400925040075], 
             UndirectedEdge[324, 346] -> 
             RGBColor[
              0.5734665054510545, 0.6638768053134015, 0.9600623801987735], 
             UndirectedEdge[142, 258] -> 
             RGBColor[
              0.8648423819966342, 0.8950658561557745, 0.9869706325203893], 
             UndirectedEdge[44, 46] -> 
             RGBColor[
              0.534726511938347, 0.6331540974032193, 0.9565147762689918], 
             UndirectedEdge[85, 191] -> 
             RGBColor[
              0.7933592606337727, 0.8391224917176994, 0.9678172859468169], 
             UndirectedEdge[112, 172] -> 
             RGBColor[
              0.7057519017251803, 0.7700580166316086, 0.9713064120036177], 
             UndirectedEdge[133, 298] -> 
             RGBColor[
              0.5253479984712806, 0.6255401976734379, 0.9557764653342375], 
             UndirectedEdge[26, 215] -> 
             RGBColor[
              0.4665185192767734, 0.5713996044639365, 0.952473010777175], 
             UndirectedEdge[127, 129] -> 
             RGBColor[
              0.6490964786561852, 0.7252740058338611, 0.9660180392320077], 
             UndirectedEdge[172, 225] -> 
             RGBColor[
              0.8446489781661926, 0.8792841330570631, 0.9739370820902189], 
             UndirectedEdge[38, 376] -> 
             RGBColor[
              0.5701948027847816, 0.6577217493381442, 0.961274479147194], 
             UndirectedEdge[158, 346] -> 
             RGBColor[
              0.694416583886212, 0.7612027801842001, 0.9701766134559971], 
             UndirectedEdge[340, 370] -> 
             RGBColor[
              0.6774703443910683, 0.7479642490944036, 0.9684875706747331], 
             UndirectedEdge[44, 266] -> 
             RGBColor[
              0.7620882741951958, 0.812705724236402, 0.9377409861084236], 
             UndirectedEdge[183, 238] -> 
             RGBColor[
              0.4990773755559883, 0.60127111843838, 0.9545641846813605], 
             UndirectedEdge[21, 264] -> 
             RGBColor[
              0.6090941494696935, 0.6922583658722374, 0.9632380740877422], 
             UndirectedEdge[13, 140] -> 
             RGBColor[
              0.7496079450421292, 0.8043186909890834, 0.975677572543425], 
             UndirectedEdge[210, 266] -> 
             RGBColor[
              0.9830330082720786, 0.9742496287701993, 0.6587423807115405], 
             UndirectedEdge[51, 395] -> 
             RGBColor[
              0.6448332985370593, 0.720192000903421, 0.9667906875072716], 
             UndirectedEdge[358, 372] -> 
             RGBColor[
              0.8557041093411137, 0.8878920120238496, 0.9860690911729282], 
             UndirectedEdge[174, 309] -> 
             RGBColor[
              0.47414092086475784`, 0.5824976769094918, 0.9521515071742996], 
             UndirectedEdge[65, 363] -> 
             RGBColor[
              0.671413606727316, 0.7337461558736553, 0.8239595335283993], 
             UndirectedEdge[236, 267] -> 
             RGBColor[
              0.6765074359102918, 0.7469274877422505, 0.9685861316224014], 
             UndirectedEdge[227, 352] -> 
             RGBColor[
              0.6075585705714384, 0.6904613294092676, 0.9634934884685306], 
             UndirectedEdge[2, 370] -> 
             RGBColor[
              0.7626713084313195, 0.8147376863355158, 0.9769228714828848], 
             UndirectedEdge[17, 354] -> 
             RGBColor[
              0.935229713057472, 0.947485790589659, 0.8314716534613129], 
             UndirectedEdge[133, 306] -> 
             RGBColor[
              0.6462099332268192, 0.7222566475814685, 0.966251569858169], 
             UndirectedEdge[105, 261] -> 
             RGBColor[
              0.6152603459093147, 0.6931732266168535, 0.9657169928796401], 
             UndirectedEdge[120, 206] -> 
             RGBColor[
              0.6044744134419895, 0.6845728168437457, 0.964688221012191], 
             UndirectedEdge[361, 393] -> 
             RGBColor[
              0.4342117001257213, 0.549222038482063, 0.9492455593163217], 
             UndirectedEdge[270, 295] -> 
             RGBColor[
              0.5547301360216537, 0.6458736292704179, 0.959634491102285], 
             UndirectedEdge[9, 283] -> 
             RGBColor[
              0.5773354836385499, 0.6661346962931683, 0.9607864614626876], 
             UndirectedEdge[43, 122] -> 
             RGBColor[
              0.7938195225023759, 0.8392836600543527, 0.9799709764854432], 
             UndirectedEdge[127, 336] -> 
             RGBColor[
              0.5266263266167899, 0.6233999906171911, 0.957052916786929], 
             UndirectedEdge[4, 123] -> 
             RGBColor[
              0.8909003112877543, 0.9116358961272073, 0.765548378228626], 
             UndirectedEdge[45, 279] -> 
             RGBColor[
              0.6837246437450883, 0.7495865070768791, 0.9655814665638254], 
             UndirectedEdge[135, 255] -> 
             RGBColor[
              0.46714945952463877`, 0.5768112632998927, 0.9516039956588327], 
             UndirectedEdge[152, 180] -> 
             RGBColor[
              0.631202305227496, 0.7076671321883028, 0.9664170974559051], 
             UndirectedEdge[48, 68] -> 
             RGBColor[
              0.3698462452054778, 0.49476396140936796`, 0.9447872535956676], 
             UndirectedEdge[362, 363] -> 
             RGBColor[
              0.7246050730549134, 0.7797955477247429, 0.8273550311620452], 
             UndirectedEdge[18, 257] -> 
             RGBColor[
              0.699547238159564, 0.7646180334485431, 0.9710933258556029], 
             UndirectedEdge[72, 109] -> 
             RGBColor[
              0.5838133950073165, 0.6689429101176287, 0.9623854329986911], 
             UndirectedEdge[181, 211] -> 
             RGBColor[
              0.7353238695680304, 0.793159862665723, 0.9742538693924414], 
             UndirectedEdge[82, 259] -> 
             RGBColor[
              0.6502036952759028, 0.7235073433484561, 0.9679122739324155], 
             UndirectedEdge[282, 367] -> 
             RGBColor[
              0.585310448350704, 0.6728492361116598, 0.9613762948125892], 
             UndirectedEdge[44, 363] -> 
             RGBColor[0.769476616609306, 0.8162242882222, 0.830887483440527], 
             UndirectedEdge[139, 290] -> 
             RGBColor[
              0.6638866749694292, 0.7321739650076029, 0.9609622892328206], 
             UndirectedEdge[255, 351] -> 
             RGBColor[
              0.5612072625093348, 0.6546523636609658, 0.9585994379561255], 
             UndirectedEdge[290, 345] -> 
             RGBColor[0.719869025616, 0.7795642464385366, 0.9648330415084272],
              UndirectedEdge[145, 200] -> 
             RGBColor[
              0.6407258151492146, 0.7142974108864245, 0.9677690147292095], 
             UndirectedEdge[44, 316] -> 
             RGBColor[
              0.756359349416349, 0.8084331015165913, 0.947438561416126], 
             UndirectedEdge[172, 240] -> 
             RGBColor[
              0.6966318328920704, 0.7629333495440929, 0.9703974087742222], 
             UndirectedEdge[89, 299] -> 
             RGBColor[
              0.7892391997338221, 0.8354927249444832, 0.9795709105968582], 
             UndirectedEdge[119, 196] -> 
             RGBColor[
              0.5834447153039887, 0.6701273392558007, 0.9617254781422597], 
             UndirectedEdge[149, 369] -> 
             RGBColor[
              0.3289770196043874, 0.4517215110719527, 0.9424629716328609], 
             UndirectedEdge[32, 385] -> 
             RGBColor[
              0.6748614764277845, 0.7438221824877413, 0.9698430647145329], 
             UndirectedEdge[149, 253] -> 
             RGBColor[
              0.5918861380367554, 0.6614602716803926, 0.9463380524735806], 
             UndirectedEdge[317, 336] -> 
             RGBColor[
              0.6091067657892537, 0.6881175605846676, 0.9651986371958299], 
             UndirectedEdge[138, 215] -> 
             RGBColor[
              0.6111192561976764, 0.6951398344329096, 0.962551483717057], 
             UndirectedEdge[157, 181] -> 
             RGBColor[
              0.8463211498057182, 0.8805341435024949, 0.9851412704742797], 
             UndirectedEdge[299, 342] -> 
             RGBColor[
              0.7248027606679724, 0.7849406924296083, 0.9732052235826363], 
             UndirectedEdge[108, 198] -> 
             RGBColor[
              0.46380925097958947`, 0.5728934048021961, 0.9516742986146702], 
             UndirectedEdge[152, 367] -> 
             RGBColor[
              0.6455611461256912, 0.7201040384779916, 0.9673320301009136], 
             UndirectedEdge[17, 118] -> 
             RGBColor[
              0.9661302537126648, 0.9720795119582818, 0.8328403870595178], 
             UndirectedEdge[44, 68] -> 
             RGBColor[
              0.45690080602171507`, 0.5677071284778954, 0.9510137548677148], 
             UndirectedEdge[158, 323] -> 
             RGBColor[
              0.7053839602154338, 0.7697705779277356, 0.9712697390325351], 
             UndirectedEdge[343, 359] -> 
             RGBColor[
              0.8915048028798644, 0.9135437556388668, 0.8689108977688517], 
             UndirectedEdge[354, 388] -> 
             RGBColor[
              0.8510613326463464, 0.8840772214804744, 0.9856561837308708], 
             UndirectedEdge[382, 389] -> 
             RGBColor[
              0.8483592059521256, 0.8817193191047769, 0.9508561251835774], 
             UndirectedEdge[178, 319] -> 
             RGBColor[
              0.6924435469330461, 0.758303962587358, 0.9709879429789109], 
             UndirectedEdge[15, 386] -> 
             RGBColor[
              0.613566249215801, 0.6962901678862177, 0.9633158657332925], 
             UndirectedEdge[27, 104] -> 
             RGBColor[
              0.7643284845605887, 0.8160297199271258, 0.9770887239832196], 
             UndirectedEdge[236, 398] -> 
             RGBColor[
              0.7002971305000742, 0.765512177964164, 0.9709572660517751], 
             UndirectedEdge[151, 304] -> 
             RGBColor[
              0.9133277165017897, 0.9336381779067577, 0.9885245028688405], 
             UndirectedEdge[21, 233] -> 
             RGBColor[
              0.5879304039674309, 0.675001501349911, 0.9615927596673394], 
             UndirectedEdge[120, 321] -> 
             RGBColor[
              0.9173027039530921, 0.932105376837663, 0.7417349177450429], 
             UndirectedEdge[170, 299] -> 
             RGBColor[
              0.7540119841263858, 0.8077591597936413, 0.9761165260012585], 
             UndirectedEdge[97, 109] -> 
             RGBColor[
              0.5844764434421797, 0.6695172093461239, 0.9624276818586499], 
             UndirectedEdge[251, 381] -> 
             RGBColor[
              0.45045868278487433`, 0.5643365353074961, 0.9499928460625249], 
             UndirectedEdge[134, 392] -> 
             RGBColor[
              0.5412263466058838, 0.6237105775735274, 0.9608598881389019], 
             UndirectedEdge[132, 220] -> 
             RGBColor[
              0.728361706948408, 0.7877209683128782, 0.9735599460876263], 
             UndirectedEdge[102, 167] -> 
             RGBColor[
              0.5825413331562534, 0.6719723233010645, 0.9602789341467266], 
             UndirectedEdge[270, 373] -> 
             RGBColor[
              0.6776520987127874, 0.7477828139763909, 0.9687268123016716], 
             UndirectedEdge[122, 351] -> 
             RGBColor[
              0.6508903308147453, 0.7263501661320784, 0.9664191819426295], 
             UndirectedEdge[96, 173] -> 
             RGBColor[
              0.5713760371642552, 0.662907833023908, 0.9593999611464097], 
             UndirectedEdge[253, 266] -> 
             RGBColor[
              0.9689946439493455, 0.9763968367408087, 0.9373681596884913], 
             UndirectedEdge[217, 230] -> 
             RGBColor[
              0.9684808448506348, 0.9741598634755715, 0.854830074246841], 
             UndirectedEdge[118, 158] -> 
             RGBColor[
              0.8182022800155645, 0.8588091281017902, 0.9806838452713607], 
             UndirectedEdge[208, 230] -> 
             RGBColor[
              0.7485140425119526, 0.8029600927709131, 0.9708573211724688], 
             UndirectedEdge[86, 179] -> 
             RGBColor[
              0.8082006250867813, 0.8501421503725577, 0.981504165406516], 
             UndirectedEdge[185, 284] -> 
             RGBColor[
              0.7390009160256039, 0.7916473258711243, 0.8410757249416139], 
             UndirectedEdge[279, 399] -> 
             RGBColor[
              0.8442502989859635, 0.8790754198201167, 0.9790979246348062], 
             UndirectedEdge[167, 309] -> 
             RGBColor[
              0.5178663103685779, 0.6179959179150424, 0.9555937300074198], 
             UndirectedEdge[174, 183] -> 
             RGBColor[
              0.5991912458709789, 0.6853836304826669, 0.9616620410403954], 
             UndirectedEdge[149, 247] -> 
             RGBColor[
              0.30127190367246437`, 0.42772473215133644`, 0.9406976261443508],
              UndirectedEdge[297, 339] -> 
             RGBColor[
              0.8416066324956759, 0.8738445156783577, 0.8180805998609157], 
             UndirectedEdge[28, 282] -> 
             RGBColor[
              0.663214902192961, 0.7362382344339029, 0.9674698033055569], 
             UndirectedEdge[35, 125] -> 
             RGBColor[
              0.7451128092662289, 0.755430835389111, 0.6310733290434316], 
             UndirectedEdge[119, 231] -> 
             RGBColor[
              0.5719125418452738, 0.6601387502297532, 0.960990658246971], 
             UndirectedEdge[257, 309] -> 
             RGBColor[
              0.5014127427011175, 0.6046381704578216, 0.954298444889233], 
             UndirectedEdge[153, 161] -> 
             RGBColor[
              0.5735322289386525, 0.6617342055733482, 0.9610123611533729], 
             UndirectedEdge[315, 369] -> 
             RGBColor[
              0.37388569516356407`, 0.498262729934404, 0.9450446437750515], 
             UndirectedEdge[145, 207] -> 
             RGBColor[
              0.6456221669229989, 0.7185383846950808, 0.9680810059345613], 
             UndirectedEdge[75, 215] -> 
             RGBColor[
              0.7576313989895942, 0.8109968170684625, 0.9763684361411515], 
             UndirectedEdge[155, 199] -> 
             RGBColor[
              0.5093494452034377, 0.6122437281757616, 0.9546021359823751], 
             UndirectedEdge[28, 151] -> 
             RGBColor[
              0.7456974868371572, 0.8012201399212492, 0.9755460358101062], 
             UndirectedEdge[141, 279] -> 
             RGBColor[
              0.790962558782123, 0.8374073392483442, 0.973813565479385], 
             UndirectedEdge[347, 380] -> 
             RGBColor[
              0.7468010981862632, 0.8023361657014738, 0.9753796260845813], 
             UndirectedEdge[107, 346] -> 
             RGBColor[
              0.8371311372958146, 0.8727366602595393, 0.9392174827821375], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.7888864167391221, 0.8352757361487356, 0.9795201957340813], 
             UndirectedEdge[171, 299] -> 
             RGBColor[
              0.836843511941787, 0.8732978062614145, 0.9787962699643551], 
             UndirectedEdge[283, 294] -> 
             RGBColor[
              0.5749464903949825, 0.664065470419882, 0.9606342369257113], 
             UndirectedEdge[83, 244] -> 
             RGBColor[
              0.9631450966880978, 0.9720342539711246, 0.9472699173955169], 
             UndirectedEdge[112, 179] -> 
             RGBColor[
              0.7301599999295001, 0.7891258084572402, 0.9737391831259781], 
             UndirectedEdge[42, 93] -> 
             RGBColor[
              0.6212441119757544, 0.7003074878736639, 0.9652174462680245], 
             UndirectedEdge[94, 254] -> 
             RGBColor[
              0.5400254478917081, 0.6374101592792297, 0.9569445972509104], 
             UndirectedEdge[84, 222] -> 
             RGBColor[
              0.7543480631557213, 0.8033456390701983, 0.7807986249492155], 
             UndirectedEdge[132, 366] -> 
             RGBColor[
              0.6517835525547719, 0.7278975320850403, 0.9659273513212085], 
             UndirectedEdge[52, 133] -> 
             RGBColor[
              0.513759605318559, 0.6161322180608962, 0.9548641845755725], 
             UndirectedEdge[255, 400] -> 
             RGBColor[
              0.6770753784276892, 0.7460189907875974, 0.9695672302849261], 
             UndirectedEdge[276, 318] -> 
             RGBColor[
              0.33692842985446, 0.4625801863553366, 0.9428242100725234], 
             UndirectedEdge[235, 313] -> 
             RGBColor[
              0.6416506591438205, 0.7156259250952435, 0.9675851257804589], 
             UndirectedEdge[218, 229] -> 
             RGBColor[
              0.6971290968782835, 0.7591635352189592, 0.9367616988543207], 
             UndirectedEdge[202, 260] -> 
             RGBColor[
              0.46032797462996317`, 0.5701527449409853, 0.9513765890518033], 
             UndirectedEdge[129, 216] -> 
             RGBColor[
              0.5929329628682276, 0.6804087164388288, 0.9610970013034472], 
             UndirectedEdge[307, 312] -> 
             RGBColor[
              0.45470615858560737`, 0.5658603631246306, 0.9508589581599589], 
             UndirectedEdge[215, 349] -> 
             RGBColor[
              0.5198823480100203, 0.619492367361534, 0.9558047747752789], 
             UndirectedEdge[48, 61] -> 
             RGBColor[
              0.6819724825285347, 0.7423195293996636, 0.7757277067685265], 
             UndirectedEdge[198, 284] -> 
             RGBColor[
              0.5280441480615524, 0.6277290533709755, 0.9559887161063051], 
             UndirectedEdge[37, 256] -> 
             RGBColor[
              0.41516437042517523`, 0.5316782064422672, 0.9482311264799157], 
             UndirectedEdge[260, 366] -> 
             RGBColor[
              0.509130548287577, 0.6094912103008605, 0.9554110805863333], 
             UndirectedEdge[35, 263] -> 
             RGBColor[
              0.9619676547588452, 0.9270522760168405, 0.6275599132159273], 
             UndirectedEdge[124, 185] -> 
             RGBColor[
              0.9057345421784537, 0.9243446427446114, 0.8560233755821183], 
             UndirectedEdge[17, 48] -> 
             RGBColor[
              0.682286087467952, 0.7429902986547541, 0.8098616690787598], 
             UndirectedEdge[98, 139] -> 
             RGBColor[
              0.38398925783858495`, 0.5070139281036815, 0.9456884338544742], 
             UndirectedEdge[98, 125] -> 
             RGBColor[
              0.45728754336772515`, 0.568462065546262, 0.9509223599543963], 
             UndirectedEdge[195, 397] -> 
             RGBColor[
              0.7353509216870517, 0.7929479948293701, 0.9745845789845173], 
             UndirectedEdge[152, 198] -> 
             RGBColor[
              0.7081568940713834, 0.771064739704062, 0.9722203811880663], 
             UndirectedEdge[29, 129] -> 
             RGBColor[
              0.6861181221150411, 0.754195595078831, 0.9697080106650582], 
             UndirectedEdge[83, 230] -> 
             RGBColor[
              0.9563480579156995, 0.9669650335837996, 0.9587755310855562], 
             UndirectedEdge[10, 155] -> 
             RGBColor[
              0.5543848843064937, 0.6484311259495374, 0.9584034703946827], 
             UndirectedEdge[210, 316] -> 
             RGBColor[
              0.9773040834932318, 0.9699770060503887, 0.6684399560192431], 
             UndirectedEdge[6, 175] -> 
             RGBColor[
              0.8728806784027467, 0.9014753755162652, 0.9877373324074763], 
             UndirectedEdge[301, 343] -> 
             RGBColor[
              0.7631467064336537, 0.8115917484548397, 0.8572644058372714], 
             UndirectedEdge[140, 297] -> 
             RGBColor[
              0.7185216289136697, 0.7800338245647775, 0.972579179069881], 
             UndirectedEdge[274, 295] -> 
             RGBColor[
              0.6102052750841871, 0.6894134923892891, 0.9651100601762743], 
             UndirectedEdge[61, 371] -> 
             RGBColor[
              0.7886335298145253, 0.8311801254464867, 0.7834977024763992], 
             UndirectedEdge[266, 397] -> 
             RGBColor[
              0.7905567796619184, 0.8358177394658435, 0.9399821311423355], 
             UndirectedEdge[71, 88] -> 
             RGBColor[
              0.7607370110562279, 0.8096180850745838, 0.8563488175616116], 
             UndirectedEdge[156, 255] -> 
             RGBColor[
              0.5621925510329497, 0.6554522652711786, 0.9586770034779353], 
             UndirectedEdge[22, 388] -> 
             RGBColor[
              0.7540677183254783, 0.8078550356550147, 0.9761081927316032], 
             UndirectedEdge[17, 346] -> 
             RGBColor[
              0.8423445575833123, 0.8744731640406918, 0.8223331552441544], 
             UndirectedEdge[72, 365] -> 
             RGBColor[
              0.506023136811609, 0.6079590664274943, 0.9547780000559496], 
             UndirectedEdge[194, 230] -> 
             RGBColor[
              0.8646962807903822, 0.8950556810127488, 0.9815258053347609], 
             UndirectedEdge[95, 264] -> 
             RGBColor[
              0.6499287819929458, 0.7241586911541038, 0.967308088636323], 
             UndirectedEdge[131, 325] -> 
             RGBColor[
              0.8303194795014042, 0.8677791244824694, 0.9836138814863171], 
             UndirectedEdge[369, 372] -> 
             RGBColor[
              0.6686279270463238, 0.7379403118608846, 0.9697883715255234], 
             UndirectedEdge[11, 248] -> 
             RGBColor[
              0.5304180247005148, 0.629656273368409, 0.9561755963711209], 
             UndirectedEdge[32, 223] -> 
             RGBColor[
              0.6785225427390815, 0.7467944010484102, 0.970131277265486], 
             UndirectedEdge[75, 229] -> 
             RGBColor[
              0.9233236090748771, 0.9406600241800754, 0.9565891152262194], 
             UndirectedEdge[123, 131] -> 
             RGBColor[
              0.9320606629615548, 0.9441986450284583, 0.7695425948982795], 
             UndirectedEdge[35, 340] -> 
             RGBColor[
              0.8189203034935557, 0.8148352346809221, 0.6372364144831983], 
             UndirectedEdge[316, 369] -> 
             RGBColor[
              0.7003566007381309, 0.7623854534125583, 0.9431906541554741], 
             UndirectedEdge[232, 280] -> 
             RGBColor[
              0.5936796354308096, 0.6799208620776164, 0.9619037810275289], 
             UndirectedEdge[30, 318] -> 
             RGBColor[
              0.618542893873754, 0.6970735538372219, 0.9654394901076058], 
             UndirectedEdge[219, 338] -> 
             RGBColor[
              0.6810276054544794, 0.7432202378125684, 0.873367476460513], 
             UndirectedEdge[124, 397] -> 
             RGBColor[
              0.7085611487358501, 0.77161633461492, 0.9720214444793024], 
             UndirectedEdge[131, 280] -> 
             RGBColor[
              0.6720204213968772, 0.7415292488297529, 0.9696037959165225], 
             UndirectedEdge[224, 345] -> 
             RGBColor[
              0.7019932000091614, 0.7655749312174582, 0.9722943501183144], 
             UndirectedEdge[44, 195] -> 
             RGBColor[
              0.7068824162203291, 0.7698359795999286, 0.9723434339506052], 
             UndirectedEdge[57, 102] -> 
             RGBColor[
              0.5084800740333539, 0.6118460567233928, 0.9544485605332408], 
             UndirectedEdge[102, 222] -> 
             RGBColor[
              0.7613431888410055, 0.8090245972283328, 0.7813493068671507], 
             UndirectedEdge[86, 285] -> 
             RGBColor[
              0.8202863771571949, 0.3775081064443393, 0.43724096772257093`], 
             UndirectedEdge[97, 340] -> 
             RGBColor[
              0.5304920924080432, 0.6273442240219924, 0.9570470262600104], 
             UndirectedEdge[84, 183] -> 
             RGBColor[
              0.5818978960103821, 0.6713441100093014, 0.9603006451917415], 
             UndirectedEdge[23, 132] -> 
             RGBColor[
              0.7318698913406047, 0.7904691417318364, 0.9739076047592117], 
             UndirectedEdge[124, 210] -> 
             RGBColor[
              0.9010373773460103, 0.9100482239192758, 0.6907816940485073], 
             UndirectedEdge[257, 288] -> 
             RGBColor[
              0.6380144567191706, 0.7165481569208478, 0.9649603132581603], 
             UndirectedEdge[31, 287] -> 
             RGBColor[
              0.5163955416368002, 0.617175267836509, 0.9553747779759325], 
             UndirectedEdge[163, 222] -> 
             RGBColor[
              0.8301609438432613, 0.8645294536951379, 0.7870161013882129], 
             UndirectedEdge[206, 386] -> 
             RGBColor[
              0.447764030110656, 0.5602244304893413, 0.9503124483765563], 
             UndirectedEdge[95, 263] -> 
             RGBColor[
              0.8845545660491132, 0.9102073802793831, 0.9651936661896343], 
             UndirectedEdge[103, 333] -> 
             RGBColor[
              0.5523800613211697, 0.6245461085985541, 0.9631444919051269], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.35872384961347703`, 0.4851303013754338, 0.9440785443836937], 
             UndirectedEdge[57, 174] -> 
             RGBColor[
              0.5187782982086666, 0.6202066190386237, 0.9552592744639595], 
             UndirectedEdge[32, 208] -> 
             RGBColor[
              0.7138326472625569, 0.7754607346026487, 0.9729110180387487], 
             UndirectedEdge[11, 125] -> 
             RGBColor[
              0.5588446593244141, 0.6527342959613865, 0.9584134451789079], 
             UndirectedEdge[82, 136] -> 
             RGBColor[
              0.7843518443788551, 0.8317926046009168, 0.979052492664829], 
             UndirectedEdge[129, 298] -> 
             RGBColor[
              0.5502315003356115, 0.6457417454758861, 0.9577353857522684], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.7714270950717147, 0.8215559018292491, 0.9778013705115518], 
             UndirectedEdge[155, 306] -> 
             RGBColor[
              0.588014086732378, 0.674702514476043, 0.9617553150097304], 
             UndirectedEdge[247, 358] -> 
             RGBColor[
              0.5912509974910842, 0.674449343494282, 0.9632553593673245], 
             UndirectedEdge[5, 373] -> 
             RGBColor[
              0.6819308380388734, 0.7511253976575526, 0.9691532770506035], 
             UndirectedEdge[194, 201] -> 
             RGBColor[
              0.8526139886654778, 0.8855762342396412, 0.9857350248315122], 
             UndirectedEdge[7, 173] -> 
             RGBColor[
              0.6934214132038616, 0.7590355196659544, 0.9711366520039149], 
             UndirectedEdge[25, 364] -> 
             RGBColor[
              0.7962375290635126, 0.8410196259566438, 0.980252582065499], 
             UndirectedEdge[1, 313] -> 
             RGBColor[
              0.9345291954816988, 0.9465766144673482, 0.8029838687930508], 
             UndirectedEdge[189, 222] -> 
             RGBColor[
              0.710199346646244, 0.7667682203749816, 0.7775262975900711], 
             UndirectedEdge[232, 275] -> 
             RGBColor[
              0.5589028558588622, 0.6503491787213236, 0.9595358092922859], 
             UndirectedEdge[289, 376] -> 
             RGBColor[
              0.6262621523605135, 0.7055043043831426, 0.9650626030338298], 
             UndirectedEdge[194, 208] -> 
             RGBColor[
              0.6715143665512522, 0.7419782532578196, 0.9688054100299934], 
             UndirectedEdge[320, 384] -> 
             RGBColor[
              0.655162945532276, 0.7284080209117124, 0.9677201411635119], 
             UndirectedEdge[262, 332] -> 
             RGBColor[
              0.707231336940887, 0.7685199414822215, 0.9462547835742389], 
             UndirectedEdge[39, 237] -> 
             RGBColor[
              0.6904612743858753, 0.7574559474255892, 0.9702315214849286], 
             UndirectedEdge[105, 353] -> 
             RGBColor[
              0.7261355884271349, 0.7855163499165713, 0.9738018208889312], 
             UndirectedEdge[160, 321] -> 
             RGBColor[
              0.7240855523600163, 0.7781191513972077, 0.7244851985831452], 
             UndirectedEdge[22, 354] -> 
             RGBColor[
              0.778669943710351, 0.8274721823672945, 0.9784547749514783], 
             UndirectedEdge[70, 286] -> 
             RGBColor[
              0.6744341708688348, 0.74264181713942, 0.9703091393055467], 
             UndirectedEdge[97, 334] -> 
             RGBColor[
              0.4509718647116851, 0.5633019703443118, 0.9504342135151291], 
             UndirectedEdge[301, 362] -> 
             RGBColor[
              0.49349132465524514`, 0.5996775147427795, 0.9532685912765979], 
             UndirectedEdge[166, 300] -> 
             RGBColor[
              0.8051789797667206, 0.8479265020982008, 0.9811645482770797], 
             UndirectedEdge[357, 364] -> 
             RGBColor[
              0.8563738476114388, 0.887980418082565, 0.9516549497630932], 
             UndirectedEdge[13, 66] -> 
             RGBColor[
              0.8046096260050903, 0.8475981559090588, 0.9810769015366105], 
             UndirectedEdge[102, 395] -> 
             RGBColor[
              0.5111521519065383, 0.6140153699165802, 0.9546589162915615], 
             UndirectedEdge[129, 336] -> 
             RGBColor[
              0.4856586027744437, 0.590871329686232, 0.9533281472643471], 
             UndirectedEdge[257, 275] -> 
             RGBColor[
              0.5038431274247472, 0.6067432475507417, 0.9544533068547179], 
             UndirectedEdge[358, 369] -> 
             RGBColor[
              0.6189561134230073, 0.6984461224148983, 0.9650207048558346], 
             UndirectedEdge[42, 139] -> 
             RGBColor[
              0.4077216598290207, 0.52756974188259, 0.9472006415235656], 
             UndirectedEdge[37, 206] -> 
             RGBColor[
              0.3361078873233593, 0.46516698545523827`, 0.9426511877678087], 
             UndirectedEdge[3, 162] -> 
             RGBColor[
              0.5888351337980036, 0.6764567770263065, 0.9612018148842946], 
             UndirectedEdge[44, 161] -> 
             RGBColor[
              0.47344422707580475`, 0.582036208298429, 0.9520678870285085], 
             UndirectedEdge[67, 266] -> 
             RGBColor[
              0.7621126829288651, 0.8127255403459956, 0.9377429076533501], 
             UndirectedEdge[305, 360] -> 
             RGBColor[
              0.7587950254374636, 0.8104388846903781, 0.9483918098930648], 
             UndirectedEdge[51, 174] -> 
             RGBColor[
              0.6724970902829546, 0.7426507132823548, 0.9689684825293166], 
             UndirectedEdge[132, 321] -> 
             RGBColor[
              0.8179991282281167, 0.8543553412613981, 0.7318832611465842], 
             UndirectedEdge[198, 236] -> 
             RGBColor[
              0.5985203472169183, 0.6849448067618923, 0.9615368606666393], 
             UndirectedEdge[153, 356] -> 
             RGBColor[
              0.5292530528851737, 0.6233818088119235, 0.9581909312097832], 
             UndirectedEdge[78, 217] -> 
             RGBColor[
              0.9817724880084472, 0.9840727491795997, 0.8323307893964051], 
             UndirectedEdge[16, 324] -> 
             RGBColor[
              0.391358560775606, 0.5132957933023304, 0.9461859210119948], 
             UndirectedEdge[263, 312] -> 
             RGBColor[
              0.7520100413727246, 0.805123562966862, 0.9530351080117039], 
             UndirectedEdge[49, 231] -> 
             RGBColor[
              0.6947203662036803, 0.7533881017099993, 0.7788473183737084], 
             UndirectedEdge[58, 303] -> 
             RGBColor[
              0.693557485386434, 0.7571102168205477, 0.9517156988810436], 
             UndirectedEdge[287, 371] -> 
             RGBColor[
              0.49800880183395063`, 0.6022480841513669, 0.953927306465805], 
             UndirectedEdge[108, 332] -> 
             RGBColor[
              0.40149120558989765`, 0.5221732355723969, 0.9468036424888231], 
             UndirectedEdge[55, 135] -> 
             RGBColor[
              0.63637053359534, 0.7110810083714603, 0.9672355779331748], 
             UndirectedEdge[38, 145] -> 
             RGBColor[
              0.630019857824647, 0.7050244487489451, 0.9670868405953944], 
             UndirectedEdge[41, 400] -> 
             RGBColor[
              0.7713608655353195, 0.8213122378066826, 0.9778457003655865], 
             UndirectedEdge[184, 369] -> 
             RGBColor[
              0.6701512598561431, 0.7391549760936669, 0.9699336683688193], 
             UndirectedEdge[68, 363] -> 
             RGBColor[
              0.6824919941463674, 0.7433416982400959, 0.8246654385785079], 
             UndirectedEdge[239, 350] -> 
             RGBColor[
              0.9208129888686816, 0.939268849829372, 0.9775239056642704], 
             UndirectedEdge[197, 300] -> 
             RGBColor[
              0.7289723927495706, 0.7879558235332229, 0.973868118309094], 
             UndirectedEdge[34, 340] -> 
             RGBColor[
              0.5682524232828106, 0.659856093046093, 0.9595067479479196], 
             UndirectedEdge[99, 225] -> 
             RGBColor[
              0.9128201004668418, 0.9330064787042971, 0.9806079352937184], 
             UndirectedEdge[75, 218] -> 
             RGBColor[
              0.6445332420969383, 0.7182622033100292, 0.9677045682121026], 
             UndirectedEdge[33, 256] -> 
             RGBColor[
              0.6989209138724916, 0.7633556198977773, 0.9717360733159388], 
             UndirectedEdge[68, 173] -> 
             RGBColor[
              0.452269751536724, 0.5639474298203526, 0.9506491812945448], 
             UndirectedEdge[76, 368] -> 
             RGBColor[
              0.8480105048324711, 0.8819935217342839, 0.9784907087281343], 
             UndirectedEdge[343, 369] -> 
             RGBColor[
              0.7126665180304513, 0.7700275635705696, 0.8534512547512736], 
             UndirectedEdge[172, 243] -> 
             RGBColor[
              0.6033202242711966, 0.6873249340476426, 0.9629516521962245], 
             UndirectedEdge[25, 83] -> 
             RGBColor[
              0.9124141463196976, 0.9320879700336171, 0.959946714682878], 
             UndirectedEdge[176, 372] -> 
             RGBColor[
              0.7548869048553999, 0.8085513298009376, 0.9764181599755757], 
             UndirectedEdge[211, 214] -> 
             RGBColor[
              0.5607126863091936, 0.6533539412495187, 0.9590428480926808], 
             UndirectedEdge[273, 330] -> 
             RGBColor[
              0.879602117503707, 0.9065138522631093, 0.9735768697715577], 
             UndirectedEdge[247, 266] -> 
             RGBColor[
              0.6783804095850545, 0.7426612972117526, 0.9317277333592615], 
             UndirectedEdge[294, 347] -> 
             RGBColor[
              0.534186141231574, 0.6321333062880597, 0.9566330705676367], 
             UndirectedEdge[247, 343] -> 
             RGBColor[
              0.6849614020985282, 0.7460307846499534, 0.8516859092627636], 
             UndirectedEdge[147, 354] -> 
             RGBColor[
              0.7575579433627588, 0.8109348007413678, 0.9763809710690365], 
             UndirectedEdge[83, 206] -> 
             RGBColor[
              0.6692602692962046, 0.7353209800444619, 0.9393061985921218], 
             UndirectedEdge[178, 300] -> 
             RGBColor[
              0.8438768925608376, 0.8783485439727206, 0.9849709254218897], 
             UndirectedEdge[31, 384] -> 
             RGBColor[
              0.5616083925412563, 0.6549780190915817, 0.9586310163816261], 
             UndirectedEdge[325, 339] -> 
             RGBColor[
              0.8924495636879244, 0.9135633999463312, 0.8231481480879534], 
             UndirectedEdge[43, 237] -> 
             RGBColor[
              0.7361166942071378, 0.7935488571168925, 0.9746688341400189], 
             UndirectedEdge[114, 128] -> 
             RGBColor[
              0.8252980378509214, 0.8640153061771025, 0.9830712053402532], 
             UndirectedEdge[131, 188] -> 
             RGBColor[
              0.6291242368974549, 0.7049249450184387, 0.9667184628790086], 
             UndirectedEdge[8, 352] -> 
             RGBColor[
              0.860545954959503, 0.891491981031973, 0.9648412083397608], 
             UndirectedEdge[56, 137] -> 
             RGBColor[
              0.4769349128118344, 0.575832520503414, 0.9540976882978232], 
             UndirectedEdge[11, 93] -> 
             RGBColor[
              0.6990688259420076, 0.76402390450988, 0.9711963238234447], 
             UndirectedEdge[232, 325] -> 
             RGBColor[
              0.7519786935353365, 0.8061707377303329, 0.9759138665973235], 
             UndirectedEdge[293, 387] -> 
             RGBColor[
              0.48286897065118367`, 0.5896365329206616, 0.952823958325671], 
             UndirectedEdge[100, 175] -> 
             RGBColor[
              0.9008945543821225, 0.9238128798058132, 0.9904093209066714], 
             UndirectedEdge[327, 336] -> 
             RGBColor[
              0.48295461136849765`, 0.5886761076494603, 0.9531152791558241], 
             UndirectedEdge[230, 357] -> 
             RGBColor[
              0.957898363703007, 0.9681212491015807, 0.956151267772152], 
             UndirectedEdge[151, 291] -> 
             RGBColor[
              0.8226006702703038, 0.8618870461750308, 0.9828079445491635], 
             UndirectedEdge[10, 87] -> 
             RGBColor[
              0.6469717958558506, 0.7239054749663686, 0.9656071158628663], 
             UndirectedEdge[44, 247] -> 
             RGBColor[
              0.46017756387451236`, 0.5705452914353502, 0.9512225469805718], 
             UndirectedEdge[191, 334] -> 
             RGBColor[
              0.5772987422712967, 0.6677161518446287, 0.9598662181880198], 
             UndirectedEdge[31, 389] -> 
             RGBColor[
              0.6712447611395898, 0.7427563021595547, 0.9681025814608633], 
             UndirectedEdge[323, 346] -> 
             RGBColor[
              0.7008606234121215, 0.766236912838355, 0.9708188950929666], 
             UndirectedEdge[91, 257] -> 
             RGBColor[
              0.5826083632415873, 0.6720267413440094, 0.9602842110005834], 
             UndirectedEdge[25, 217] -> 
             RGBColor[
              0.9245469332546329, 0.939282799925389, 0.8560012578441627], 
             UndirectedEdge[4, 238] -> 
             RGBColor[
              0.5685122820754973, 0.6555141951362553, 0.9614848072571318], 
             UndirectedEdge[49, 298] -> 
             RGBColor[
              0.7432726629651802, 0.7943822783057901, 0.7822337383451359], 
             UndirectedEdge[96, 245] -> 
             RGBColor[
              0.49690680709964663`, 0.6006139589215351, 0.9540448728975525], 
             UndirectedEdge[198, 219] -> 
             RGBColor[
              0.7820360626894489, 0.8274520971461048, 0.8807034514165535], 
             UndirectedEdge[69, 106] -> 
             RGBColor[
              0.597166462922881, 0.6838456625002005, 0.9614302779355712], 
             UndirectedEdge[246, 350] -> 
             RGBColor[
              0.593922247141104, 0.6644340247299283, 0.9512323711555866], 
             UndirectedEdge[91, 263] -> 
             RGBColor[
              0.7618435300345182, 0.8131068320561221, 0.9538092362604161], 
             UndirectedEdge[193, 305] -> 
             RGBColor[
              0.7712468772112453, 0.8162079595045658, 0.7118977400641934], 
             UndirectedEdge[217, 244] -> 
             RGBColor[
              0.975277883623033, 0.9792290838628965, 0.8433244605568017], 
             UndirectedEdge[218, 260] -> 
             RGBColor[
              0.38792700864394497`, 0.5104246099341743, 0.9459393438537754], 
             UndirectedEdge[115, 169] -> 
             RGBColor[
              0.8955722424633468, 0.6219293846640659, 0.4462298029782732], 
             UndirectedEdge[152, 332] -> 
             RGBColor[
              0.6458388486816915, 0.7203445704742629, 0.9673497250622192], 
             UndirectedEdge[8, 227] -> 
             RGBColor[
              0.7068639419530663, 0.7685471138167054, 0.9514976915688109], 
             UndirectedEdge[161, 344] -> 
             RGBColor[
              0.5860188298841209, 0.6714888331336301, 0.962256908841697], 
             UndirectedEdge[255, 324] -> 
             RGBColor[
              0.4962775750416938, 0.601939518325648, 0.9534879351133907], 
             UndirectedEdge[135, 221] -> 
             RGBColor[
              0.48346823591673543`, 0.5900595811274956, 0.9528886695140661], 
             UndirectedEdge[179, 257] -> 
             RGBColor[
              0.6969189651012215, 0.762564806559751, 0.9708313641597555], 
             UndirectedEdge[40, 350] -> 
             RGBColor[
              0.726042993489953, 0.7843690086508351, 0.9597524895415286], 
             UndirectedEdge[358, 397] -> 
             RGBColor[
              0.703427367567948, 0.7676057857483729, 0.9715097571503986], 
             UndirectedEdge[44, 149] -> 
             RGBColor[
              0.3849797682826056, 0.49776915917598574`, 0.9467108788935128], 
             UndirectedEdge[215, 218] -> 
             RGBColor[
              0.5314368867930006, 0.6295003281073462, 0.956541019769253], 
             UndirectedEdge[211, 248] -> 
             RGBColor[
              0.5757517283933781, 0.6658845497688398, 0.9601380179306782], 
             UndirectedEdge[38, 103] -> 
             RGBColor[
              0.6478746531005579, 0.7192613778464497, 0.9687898469079746], 
             UndirectedEdge[79, 213] -> 
             RGBColor[
              0.9540403133009786, 0.9618076682268131, 0.7783710633168538], 
             UndirectedEdge[116, 383] -> 
             RGBColor[
              0.6544771829403166, 0.7287223517018153, 0.9670706043732857], 
             UndirectedEdge[214, 263] -> 
             RGBColor[
              0.7018076228856274, 0.7640457413916016, 0.9491717483755773], 
             UndirectedEdge[203, 275] -> 
             RGBColor[
              0.6961139639058458, 0.7568795306035214, 0.8960969622257958], 
             UndirectedEdge[235, 396] -> 
             RGBColor[
              0.516823231791898, 0.6174029315166505, 0.9554414805637486], 
             UndirectedEdge[170, 361] -> 
             RGBColor[
              0.5717506594667354, 0.65883544404375, 0.9614726188219356], 
             UndirectedEdge[190, 255] -> 
             RGBColor[
              0.47649109770895803`, 0.5849025207707629, 0.9521992365834513], 
             UndirectedEdge[67, 113] -> 
             RGBColor[
              0.6657136515053299, 0.7372720895565528, 0.9683466246361598], 
             UndirectedEdge[244, 307] -> 
             RGBColor[
              0.661405206903986, 0.7294626873738295, 0.9526027702937625], 
             UndirectedEdge[106, 292] -> 
             RGBColor[
              0.5982865399919408, 0.6847549915237602, 0.9615184545054251], 
             UndirectedEdge[119, 126] -> 
             RGBColor[
              0.5531920666480759, 0.6439240155323822, 0.9597978061212719], 
             UndirectedEdge[148, 288] -> 
             RGBColor[
              0.5338003771361299, 0.63036523749579, 0.9571919938471924], 
             UndirectedEdge[143, 277] -> 
             RGBColor[
              0.6517180657373949, 0.7272703203994142, 0.9663146747116509], 
             UndirectedEdge[245, 364] -> 
             RGBColor[
              0.5621658919767003, 0.6521192157139893, 0.9601907782723988], 
             UndirectedEdge[101, 335] -> 
             RGBColor[
              0.5688847376562103, 0.6606734796729952, 0.959348648596827], 
             UndirectedEdge[175, 296] -> 
             RGBColor[
              0.593088570675925, 0.6716770009413305, 0.9648047454905164], 
             UndirectedEdge[106, 158] -> 
             RGBColor[
              0.6654479305632595, 0.7384128864339201, 0.9673982452195515], 
             UndirectedEdge[59, 319] -> 
             RGBColor[
              0.554654450314974, 0.6493324955207584, 0.9580835765764434], 
             UndirectedEdge[159, 218] -> 
             RGBColor[
              0.4881650520850756, 0.5944036375314579, 0.9531117116469636], 
             UndirectedEdge[126, 326] -> 
             RGBColor[
              0.32214795639141736`, 0.4513939730188533, 0.9418232457288489], 
             UndirectedEdge[130, 371] -> 
             RGBColor[
              0.6030606215401821, 0.6886308059945453, 0.9618942876929395], 
             UndirectedEdge[108, 262] -> 
             RGBColor[
              0.6601029429349654, 0.727699695336249, 0.943251803982184], 
             UndirectedEdge[34, 91] -> 
             RGBColor[
              0.5110151594962908, 0.6139041533065037, 0.9546481317472072], 
             UndirectedEdge[173, 323] -> 
             RGBColor[
              0.6232256596280075, 0.7039375158634023, 0.9642093366264491], 
             UndirectedEdge[104, 208] -> 
             RGBColor[
              0.6189355367502488, 0.700903271803369, 0.9635648436525298], 
             UndirectedEdge[115, 122] -> 
             RGBColor[
              0.8431975750551606, 0.8777328182062855, 0.9526602726800331], 
             UndirectedEdge[275, 297] -> 
             RGBColor[
              0.5462613498332549, 0.6404735381351148, 0.9582758221132437], 
             UndirectedEdge[185, 293] -> 
             RGBColor[
              0.6981450140293932, 0.757061387783164, 0.8382509963436096], 
             UndirectedEdge[92, 256] -> 
             RGBColor[
              0.6896599093572648, 0.7559711462806065, 0.9708527504378801], 
             UndirectedEdge[135, 165] -> 
             RGBColor[
              0.6830092360004631, 0.7474562186561378, 0.9434889963849209], 
             UndirectedEdge[158, 270] -> 
             RGBColor[
              0.7164990180289927, 0.778453745569256, 0.9723775841192697], 
             UndirectedEdge[35, 86] -> 
             RGBColor[
              0.8940141479514738, 0.8735495291175346, 0.6447076892028549], 
             UndirectedEdge[124, 387] -> 
             RGBColor[
              0.6904584988002442, 0.756919787882109, 0.9705963375641797], 
             UndirectedEdge[170, 261] -> 
             RGBColor[
              0.5717506594667354, 0.65883544404375, 0.9614726188219356], 
             UndirectedEdge[78, 244] -> 
             RGBColor[
              0.9617846386812933, 0.9710196266171953, 0.9495728179367611], 
             UndirectedEdge[320, 381] -> 
             RGBColor[
              0.6226889560539314, 0.7016390311501455, 0.9652756117433572], 
             UndirectedEdge[90, 166] -> 
             RGBColor[
              0.6189012052872049, 0.6995936436473773, 0.9644384847555447], 
             UndirectedEdge[119, 317] -> 
             RGBColor[
              0.801810256099811, 0.8453827571509955, 0.9808054521070387], 
             UndirectedEdge[173, 250] -> 
             RGBColor[
              0.6103112737339196, 0.6938486994499726, 0.9629221513323243], 
             UndirectedEdge[234, 355] -> 
             RGBColor[
              0.4832559622630763, 0.5908933843704224, 0.952593960025764], 
             UndirectedEdge[203, 297] -> 
             RGBColor[
              0.8383468703900715, 0.8729822053445573, 0.9074074713037958], 
             UndirectedEdge[48, 388] -> 
             RGBColor[
              0.5981177070568264, 0.6795817295455695, 0.9640461993483177], 
             UndirectedEdge[34, 95] -> 
             RGBColor[
              0.6337261955108858, 0.7110047015297647, 0.9660325616764254], 
             UndirectedEdge[133, 299] -> 
             RGBColor[
              0.6452023899582853, 0.7214695471224775, 0.9661511473611887], 
             UndirectedEdge[58, 376] -> 
             RGBColor[
              0.8645531519554207, 0.8946440058753864, 0.966332584173135], 
             UndirectedEdge[239, 392] -> 
             RGBColor[
              0.5659220389076578, 0.6434022522682523, 0.9632153853167498], 
             UndirectedEdge[64, 77] -> 
             RGBColor[
              0.48840640702624993`, 0.5800211766821576, 0.9559966896078209], 
             UndirectedEdge[73, 112] -> 
             RGBColor[
              0.8273396989830111, 0.8650561713168394, 0.9368203428684203], 
             UndirectedEdge[257, 339] -> 
             RGBColor[
              0.7991884100871682, 0.8401142250939846, 0.8142580846023899], 
             UndirectedEdge[35, 85] -> 
             RGBColor[
              0.9554605941596734, 0.922199320876312, 0.6385746694971144], 
             UndirectedEdge[37, 187] -> 
             RGBColor[
              0.5818029163124745, 0.6639602210440481, 0.9635340812015589], 
             UndirectedEdge[9, 39] -> 
             RGBColor[
              0.60905230005129, 0.6909121143315335, 0.9639476973122085], 
             UndirectedEdge[136, 394] -> 
             RGBColor[
              0.7573300691042782, 0.8103512729967508, 0.9764472417025877], 
             UndirectedEdge[287, 389] -> 
             RGBColor[
              0.5677684217465304, 0.6576526262091889, 0.9602596278151563], 
             UndirectedEdge[195, 372] -> 
             RGBColor[
              0.8876276634602176, 0.9132342211048469, 0.9891439130070467], 
             UndirectedEdge[149, 362] -> 
             RGBColor[
              0.34010822472821295`, 0.4613404186785288, 0.943178426615031], 
             UndirectedEdge[83, 321] -> 
             RGBColor[
              0.9820885598073074, 0.9828535400383792, 0.7163528953249736], 
             UndirectedEdge[227, 308] -> 
             RGBColor[
              0.5445629865274045, 0.6411397906027467, 0.9572891395808361], 
             UndirectedEdge[100, 146] -> 
             RGBColor[
              0.7403821500380658, 0.7967408102534135, 0.9753164688879472], 
             UndirectedEdge[100, 278] -> 
             RGBColor[
              0.7171147306242556, 0.7778512709879828, 0.9734847724003265], 
             UndirectedEdge[234, 350] -> 
             RGBColor[
              0.694037486978051, 0.7579108945482624, 0.9573640327989237], 
             UndirectedEdge[278, 352] -> 
             RGBColor[
              0.6426351145720095, 0.7189380480092309, 0.9662548425018699], 
             UndirectedEdge[342, 353] -> 
             RGBColor[
              0.6534166785261423, 0.7283600999794348, 0.9666461444126045], 
             UndirectedEdge[109, 181] -> 
             RGBColor[
              0.7873558059133112, 0.8338076067960191, 0.9794399265412485], 
             UndirectedEdge[59, 296] -> 
             RGBColor[
              0.4313084741323887, 0.5435757617525104, 0.9496120960981396], 
             UndirectedEdge[168, 378] -> 
             RGBColor[
              0.7648190709347216, 0.8167070465670117, 0.9770937783892114], 
             UndirectedEdge[191, 370] -> 
             RGBColor[
              0.658255871802975, 0.7328809241569199, 0.9666222478792343], 
             UndirectedEdge[153, 184] -> 
             RGBColor[
              0.826242010397209, 0.8649006214726193, 0.9831260497543355], 
             UndirectedEdge[3, 91] -> 
             RGBColor[
              0.5280307435242069, 0.6277181709636909, 0.9559876608520228], 
             UndirectedEdge[149, 210] -> 
             RGBColor[
              0.6059245023594885, 0.659313063709783, 0.6677122734966298], 
             UndirectedEdge[3, 312] -> 
             RGBColor[
              0.5181972548624133, 0.6197349018744309, 0.9552135326033107], 
             UndirectedEdge[17, 388] -> 
             RGBColor[
              0.9106274876725993, 0.9278686438773792, 0.829125071241438], 
             UndirectedEdge[99, 243] -> 
             RGBColor[
              0.6714913465718457, 0.7410472796948768, 0.9696225053997238], 
             UndirectedEdge[108, 398] -> 
             RGBColor[
              0.5655860342627455, 0.6534607760044677, 0.9610947039998059], 
             UndirectedEdge[57, 186] -> 
             RGBColor[
              0.5614862370550269, 0.6548788477648186, 0.9586213998542799], 
             UndirectedEdge[180, 398] -> 
             RGBColor[
              0.5980778848144717, 0.6816035838644801, 0.9631650559855467], 
             UndirectedEdge[66, 318] -> 
             RGBColor[
              0.6316896241861534, 0.7075563997298415, 0.966693436981027], 
             UndirectedEdge[374, 382] -> 
             RGBColor[
              0.9132158076615997, 0.9326472367920442, 0.9572510449939482], 
             UndirectedEdge[190, 270] -> 
             RGBColor[
              0.5757624622610996, 0.6640907731435723, 0.9609746523321067], 
             UndirectedEdge[47, 96] -> 
             RGBColor[
              0.6678473344939606, 0.739922316926114, 0.9678869493052067], 
             UndirectedEdge[245, 328] -> 
             RGBColor[
              0.5043538505208292, 0.606659804256334, 0.9546311314350868], 
             UndirectedEdge[142, 143] -> 
             RGBColor[
              0.7728715995056759, 0.8227112926134574, 0.9779381980392372], 
             UndirectedEdge[268, 373] -> 
             RGBColor[
              0.7246972280070362, 0.7846008161325511, 0.9733983195184033], 
             UndirectedEdge[69, 390] -> 
             RGBColor[
              0.7643382958170415, 0.8149944397125437, 0.9503108392022334], 
             UndirectedEdge[91, 112] -> 
             RGBColor[
              0.6158493980698658, 0.6985877432414986, 0.963192029966806], 
             UndirectedEdge[16, 190] -> 
             RGBColor[
              0.3715720834428703, 0.49625879574744525`, 0.9448972224820554], 
             UndirectedEdge[40, 395] -> 
             RGBColor[
              0.4968181835037542, 0.6023784086292823, 0.9535304937918381], 
             UndirectedEdge[84, 246] -> 
             RGBColor[
              0.37506787904020356`, 0.4908626166139437, 0.9458267745792872], 
             UndirectedEdge[196, 376] -> 
             RGBColor[
              0.5943837106313004, 0.6786729655449403, 0.9628157749657629], 
             UndirectedEdge[37, 311] -> 
             RGBColor[
              0.4113256715125808, 0.5285617777336077, 0.9479289300398989], 
             UndirectedEdge[179, 275] -> 
             RGBColor[
              0.5971042810255034, 0.6801924224030882, 0.9633433703402814], 
             UndirectedEdge[334, 340] -> 
             RGBColor[
              0.5965132148593902, 0.6827994767821124, 0.9617315409835184], 
             UndirectedEdge[23, 366] -> 
             RGBColor[
              0.7408321479734415, 0.7974705247290816, 0.9748008787433228], 
             UndirectedEdge[295, 351] -> 
             RGBColor[
              0.48115064771466864`, 0.5875431994392618, 0.952881633964092], 
             UndirectedEdge[358, 363] -> 
             RGBColor[
              0.9005500502258779, 0.9201283402811318, 0.8429202958272797], 
             UndirectedEdge[111, 116] -> 
             RGBColor[
              0.7832090818660996, 0.8305681544540673, 0.9790266198415618], 
             UndirectedEdge[147, 371] -> 
             RGBColor[
              0.6112753650592294, 0.6952999048532862, 0.962540982394356], 
             UndirectedEdge[33, 311] -> 
             RGBColor[
              0.6950822149598972, 0.7602391911891179, 0.971433876875922], 
             UndirectedEdge[137, 178] -> 
             RGBColor[
              0.5523271284235607, 0.6349204306260807, 0.9615614106197363], 
             UndirectedEdge[328, 386] -> 
             RGBColor[
              0.5755152611827116, 0.6662682415520078, 0.9597258160236197], 
             UndirectedEdge[20, 36] -> 
             RGBColor[
              0.3975236800574279, 0.5145106808294253, 0.9471014490168443], 
             UndirectedEdge[107, 212] -> 
             RGBColor[
              0.7980972568873045, 0.8417753617278909, 0.935646742999375], 
             UndirectedEdge[21, 27] -> 
             RGBColor[
              0.7857148729294482, 0.8327369290634506, 0.9792203193086653], 
             UndirectedEdge[138, 329] -> 
             RGBColor[
              0.5802421344519442, 0.6701057302151849, 0.960097932802481], 
             UndirectedEdge[3, 263] -> 
             RGBColor[
              0.728315358576016, 0.7858871520391986, 0.951169775785464], 
             UndirectedEdge[239, 269] -> 
             RGBColor[
              0.6609239918726995, 0.7318172891911656, 0.9690444086379362], 
             UndirectedEdge[74, 86] -> 
             RGBColor[
              0.5479662774852445, 0.6325422522476354, 0.9609789708912282], 
             UndirectedEdge[91, 179] -> 
             RGBColor[
              0.6758695168423434, 0.745475916196356, 0.969174274486147], 
             UndirectedEdge[316, 358] -> 
             RGBColor[
              0.8874327830329208, 0.9123371535755234, 0.9594713738028788], 
             UndirectedEdge[154, 267] -> 
             RGBColor[
              0.6724013921063405, 0.7435940164070374, 0.9682628888132203], 
             UndirectedEdge[25, 357] -> 
             RGBColor[
              0.9139644521070049, 0.9332441855513982, 0.9573224513694738], 
             UndirectedEdge[118, 388] -> 
             RGBColor[
              0.8819618733015393, 0.9086709428490972, 0.9870249173290757], 
             UndirectedEdge[305, 340] -> 
             RGBColor[
              0.6128249840338136, 0.6960421058347364, 0.9630156632049083], 
             UndirectedEdge[100, 213] -> 
             RGBColor[
              0.9519930552576992, 0.9601752402344412, 0.778175794017077], 
             UndirectedEdge[51, 238] -> 
             RGBColor[
              0.5723832199679639, 0.6585382012380678, 0.9618706261702816], 
             UndirectedEdge[104, 242] -> 
             RGBColor[
              0.6524050269025135, 0.7280753116923261, 0.9661996845200982], 
             UndirectedEdge[99, 337] -> 
             RGBColor[
              0.6159093372583132, 0.6932296388852488, 0.9659911527786214], 
             UndirectedEdge[143, 302] -> 
             RGBColor[
              0.5883590673522938, 0.6758326312200391, 0.9613268222671174], 
             UndirectedEdge[14, 327] -> 
             RGBColor[
              0.7070924217077339, 0.7704980339318728, 0.9718551733170695], 
             UndirectedEdge[162, 348] -> 
             RGBColor[
              0.8345084263119136, 0.8704156700755064, 0.9266175238833645], 
             UndirectedEdge[130, 391] -> 
             RGBColor[
              0.7078841983980482, 0.7714275777139677, 0.9717214565792892], 
             UndirectedEdge[182, 386] -> 
             RGBColor[
              0.7446356993865384, 0.7543475071143484, 0.6300015669921099], 
             UndirectedEdge[32, 217] -> 
             RGBColor[
              0.9337994496012392, 0.9466605053073073, 0.8568837711131209], 
             UndirectedEdge[3, 285] -> 
             RGBColor[
              0.7097135240219016, 0.2895841636489225, 0.42726140012569025`], 
             UndirectedEdge[212, 274] -> 
             RGBColor[
              0.7284169398797039, 0.7874986450670981, 0.9738315694709282], 
             UndirectedEdge[234, 272] -> 
             RGBColor[
              0.44702743841224923`, 0.5614814366319205, 0.9497419179187713], 
             UndirectedEdge[24, 104] -> 
             RGBColor[
              0.813399056711327, 0.8549365190072901, 0.9741158147663453], 
             UndirectedEdge[317, 327] -> 
             RGBColor[
              0.7288729264227028, 0.7877963537645659, 0.9739508915323856], 
             UndirectedEdge[85, 263] -> 
             RGBColor[
              0.9556210844871557, 0.9664228579911013, 0.9600061074750446], 
             UndirectedEdge[169, 300] -> 
             RGBColor[
              0.8531165306818148, 0.5886920596004863, 0.4635272903133577], 
             UndirectedEdge[34, 162] -> 
             RGBColor[
              0.5718195497700875, 0.6626427593691193, 0.959862285779479], 
             UndirectedEdge[62, 313] -> 
             RGBColor[
              0.8592572936212268, 0.8906124582884098, 0.9864379218052757], 
             UndirectedEdge[337, 367] -> 
             RGBColor[
              0.4010883510529043, 0.521824303220511, 0.9467779729539563], 
             UndirectedEdge[21, 240] -> 
             RGBColor[
              0.6886057327280986, 0.7566632990953774, 0.9695974421180479], 
             UndirectedEdge[258, 378] -> 
             RGBColor[
              0.8876192590177088, 0.9132275196305228, 0.9891431113838176], 
             UndirectedEdge[240, 242] -> 
             RGBColor[
              0.6370854260340774, 0.7161075230606249, 0.9646727698753421], 
             UndirectedEdge[16, 380] -> 
             RGBColor[
              0.5913936013847991, 0.6727036160757193, 0.9641029736925952], 
             UndirectedEdge[38, 222] -> 
             RGBColor[
              0.6820424208818334, 0.742380106486087, 0.7757321631785546], 
             UndirectedEdge[61, 147] -> 
             RGBColor[
              0.8168104934495943, 0.8540554538831822, 0.7857158962693704], 
             UndirectedEdge[279, 288] -> 
             RGBColor[
              0.8072511226144392, 0.8501713820345267, 0.9754101925110541], 
             UndirectedEdge[192, 384] -> 
             RGBColor[
              0.4309438884864135, 0.5463253214280681, 0.9490556569252202], 
             UndirectedEdge[196, 289] -> 
             RGBColor[
              0.45017244098102716`, 0.5635583097475858, 0.9501211297109005], 
             UndirectedEdge[9, 384] -> 
             RGBColor[
              0.47000141083400265`, 0.5801549841973972, 0.9515443677119976], 
             UndirectedEdge[114, 187] -> 
             RGBColor[
              0.8745186979325222, 0.9027814878264526, 0.9878935681725036], 
             UndirectedEdge[90, 274] -> 
             RGBColor[
              0.6582996682126114, 0.7305742851806607, 0.9683116809972655], 
             UndirectedEdge[270, 324] -> 
             RGBColor[
              0.5955489395938354, 0.6811277706984574, 0.9622633508620461], 
             UndirectedEdge[42, 45] -> 
             RGBColor[
              0.42946979040720046`, 0.5464068794965833, 0.9485864131728905], 
             UndirectedEdge[316, 363] -> 
             RGBColor[
              0.9819505375410014, 0.9840676712787918, 0.8210902451269192], 
             UndirectedEdge[44, 250] -> 
             RGBColor[
              0.6149423282189107, 0.6976083981075154, 0.9632867249054943], 
             UndirectedEdge[213, 352] -> 
             RGBColor[
              0.8775134392054531, 0.9012620172556893, 0.7709458641186204], 
             UndirectedEdge[80, 378] -> 
             RGBColor[
              0.6279419205761552, 0.7031389549785527, 0.9669938836091497], 
             UndirectedEdge[238, 272] -> 
             RGBColor[
              0.4035512671872573, 0.5238245622927351, 0.9469716547327836], 
             UndirectedEdge[126, 196] -> 
             RGBColor[
              0.38804135059590117`, 0.510523647185965, 0.9459466296218455], 
             UndirectedEdge[112, 240] -> 
             RGBColor[
              0.6610198123239128, 0.7351129684148672, 0.9668479353772417], 
             UndirectedEdge[52, 89] -> 
             RGBColor[
              0.6577964150940957, 0.7301553958829021, 0.9682839478112419], 
             UndirectedEdge[99, 177] -> 
             RGBColor[
              0.8944344703300854, 0.918661784137029, 0.989793152322803], 
             UndirectedEdge[41, 206] -> 
             RGBColor[
              0.545803369995766, 0.6385652243023248, 0.9588864354986756], 
             UndirectedEdge[1, 119] -> 
             RGBColor[
              0.8714343037490768, 0.8968434676888366, 0.79681270171825], 
             UndirectedEdge[2, 109] -> 
             RGBColor[
              0.815218757630136, 0.8557881530250367, 0.9821603101351908], 
             UndirectedEdge[8, 100] -> 
             RGBColor[
              0.9350255710117491, 0.9504052040107249, 0.9720711382382174], 
             UndirectedEdge[203, 322] -> 
             RGBColor[
              0.859142005611369, 0.8892275230283162, 0.9094801360410674], 
             UndirectedEdge[98, 193] -> 
             RGBColor[
              0.6895169307724837, 0.7480323185079025, 0.705967522253448], 
             UndirectedEdge[141, 285] -> 
             RGBColor[
              0.7581439914244144, 0.32890219885397554`, 0.4310740239262636], 
             UndirectedEdge[29, 231] -> 
             RGBColor[
              0.5796685708753138, 0.6661978190560243, 0.9617637067364733], 
             UndirectedEdge[225, 398] -> 
             RGBColor[
              0.8623716454902811, 0.8931292154679015, 0.9757035119413415], 
             UndirectedEdge[149, 359] -> 
             RGBColor[
              0.5078153044538006, 0.5952377031402498, 0.9579226146504389], 
             UndirectedEdge[87, 235] -> 
             RGBColor[
              0.5178299923306211, 0.6182202650760313, 0.9555207364412421], 
             UndirectedEdge[162, 312] -> 
             RGBColor[
              0.6125298165947122, 0.6956931879539701, 0.9630671471105345], 
             UndirectedEdge[392, 395] -> 
             RGBColor[
              0.3681204443611308, 0.4860412223133107, 0.9452053106024053], 
             UndirectedEdge[212, 268] -> 
             RGBColor[
              0.7199869301114192, 0.7807767841043871, 0.9730275076136706], 
             UndirectedEdge[50, 271] -> 
             RGBColor[
              0.5933774206226812, 0.6807695472664879, 0.9611319906459801], 
             UndirectedEdge[200, 207] -> 
             RGBColor[
              0.3962244499816959, 0.5176114365794064, 0.9464680494786777], 
             UndirectedEdge[360, 370] -> 
             RGBColor[
              0.8234403857947183, 0.8623610279500452, 0.9538637173628896], 
             UndirectedEdge[134, 246] -> 
             RGBColor[
              0.537803339399658, 0.6201127799685923, 0.9606649529423926], 
             UndirectedEdge[88, 191] -> 
             RGBColor[
              0.8155723946127138, 0.8541359197516167, 0.8606656598238067], 
             UndirectedEdge[277, 278] -> 
             RGBColor[
              0.5643920758232851, 0.6572379385834354, 0.9588501581265552], 
             UndirectedEdge[233, 242] -> 
             RGBColor[
              0.5364100972734097, 0.6344457253151584, 0.9566680874246336], 
             UndirectedEdge[66, 123] -> 
             RGBColor[
              0.9261074245290298, 0.9394516942987154, 0.7689747697020665], 
             UndirectedEdge[315, 316] -> 
             RGBColor[
              0.6423623647734777, 0.712153761095029, 0.9394953127220957], 
             UndirectedEdge[127, 216] -> 
             RGBColor[
              0.6339006867105739, 0.712937377369788, 0.9648217708260292], 
             UndirectedEdge[29, 326] -> 
             RGBColor[
              0.5253073501295448, 0.61705673391496, 0.9583751427387655], 
             UndirectedEdge[76, 145] -> 
             RGBColor[
              0.9166752024019293, 0.9362018170729742, 0.9851841231325285], 
             UndirectedEdge[21, 104] -> 
             RGBColor[
              0.7039253335965348, 0.7686310877270787, 0.971124356762804], 
             UndirectedEdge[27, 112] -> 
             RGBColor[
              0.7581289525252624, 0.8111865983829404, 0.976470812567859], 
             UndirectedEdge[190, 221] -> 
             RGBColor[
              0.4928098741010547, 0.5981508385983657, 0.9534839104386847], 
             UndirectedEdge[310, 324] -> 
             RGBColor[
              0.659456199646229, 0.7313911782108162, 0.9685431831634915], 
             UndirectedEdge[11, 312] -> 
             RGBColor[
              0.5655814011034277, 0.6582034864243484, 0.9589437861692501], 
             UndirectedEdge[177, 225] -> 
             RGBColor[
              0.9295484039022908, 0.9463451737860239, 0.9822034958089243], 
             UndirectedEdge[253, 316] -> 
             RGBColor[
              0.9632657191704987, 0.9721242140209981, 0.9470657349961938], 
             UndirectedEdge[17, 323] -> 
             RGBColor[
              0.8533119339125341, 0.8830409617842272, 0.8234262808206922], 
             UndirectedEdge[315, 397] -> 
             RGBColor[
              0.4583569493085048, 0.5674223932678786, 0.9515336960696155], 
             UndirectedEdge[43, 296] -> 
             RGBColor[
              0.5836726851998624, 0.6641690294501207, 0.9639066499281492], 
             UndirectedEdge[50, 287] -> 
             RGBColor[
              0.4979004706603854, 0.6021601360244029, 0.9539187782389917], 
             UndirectedEdge[253, 369] -> 
             RGBColor[
              0.6947890495605852, 0.7582331828603731, 0.9526150660491497], 
             UndirectedEdge[187, 220] -> 
             RGBColor[
              0.8364062777326021, 0.872440836081374, 0.9842453265980116], 
             UndirectedEdge[211, 340] -> 
             RGBColor[
              0.677985857244604, 0.7483669716536285, 0.968538952178232], 
             UndirectedEdge[213, 227] -> 
             RGBColor[
              0.7238314261990164, 0.7783171500404216, 0.7576023473476705], 
             UndirectedEdge[17, 389] -> 
             RGBColor[
              0.8587067546665224, 0.8872554367593991, 0.8239639861359835], 
             UndirectedEdge[117, 376] -> 
             RGBColor[
              0.8050562011991989, 0.8477941540106742, 0.9811619789321353], 
             UndirectedEdge[186, 330] -> 
             RGBColor[
              0.7207555162661827, 0.7816590247451356, 0.9728838286051885], 
             UndirectedEdge[24, 337] -> 
             RGBColor[
              0.6491858379084845, 0.7195426740695108, 0.9615117909224891], 
             UndirectedEdge[73, 99] -> 
             RGBColor[
              0.931122841851818, 0.9465988980932991, 0.9470406694689003], 
             UndirectedEdge[114, 155] -> 
             RGBColor[
              0.6660485082355079, 0.7362305370576367, 0.9693826085818129], 
             UndirectedEdge[123, 232] -> 
             RGBColor[
              0.8537198769954871, 0.8825902582763218, 0.7618425800092858], 
             UndirectedEdge[53, 289] -> 
             RGBColor[
              0.45576245888110467`, 0.5684001022901641, 0.9504773207084347], 
             UndirectedEdge[126, 376] -> 
             RGBColor[
              0.5641310619753875, 0.6524696418215218, 0.9608881029447749], 
             UndirectedEdge[207, 254] -> 
             RGBColor[
              0.5147712149940433, 0.6155362120579249, 0.9553354198621125], 
             UndirectedEdge[291, 304] -> 
             RGBColor[
              0.8484065152661117, 0.882375358609603, 0.9821986249419938], 
             UndirectedEdge[333, 368] -> 
             RGBColor[
              0.46586056847580065`, 0.5561008841623591, 0.9547480711881524], 
             UndirectedEdge[26, 171] -> 
             RGBColor[
              0.6150729949600353, 0.6882815173189867, 0.9617034039678725], 
             UndirectedEdge[81, 384] -> 
             RGBColor[
              0.5437331829202603, 0.6404661186522405, 0.9572238144012108], 
             UndirectedEdge[120, 233] -> 
             RGBColor[
              0.6459887666706768, 0.7205304630383716, 0.9673334788902219], 
             UndirectedEdge[224, 290] -> 
             RGBColor[
              0.9280756412892057, 0.9452219578031176, 0.9838355564265064], 
             UndirectedEdge[393, 396] -> 
             RGBColor[
              0.563016690428456, 0.6561213387595073, 0.9587418827500716], 
             UndirectedEdge[2, 365] -> 
             RGBColor[
              0.7374284994344285, 0.7948043093349022, 0.9745528771924493], 
             UndirectedEdge[210, 387] -> 
             RGBColor[
              0.7751960180926531, 0.8105490914904274, 0.6790532324516403], 
             UndirectedEdge[23, 307] -> 
             RGBColor[
              0.5942194331356836, 0.6763957739115223, 0.9637100918358465], 
             UndirectedEdge[120, 244] -> 
             RGBColor[
              0.8983592408338825, 0.9212860907704085, 0.9726519398155862], 
             UndirectedEdge[42, 248] -> 
             RGBColor[
              0.4525933107342617, 0.5659398567321929, 0.9501967188157007], 
             UndirectedEdge[49, 393] -> 
             RGBColor[
              0.747557050406163, 0.7978605370398346, 0.7825710210187183], 
             UndirectedEdge[375, 377] -> 
             RGBColor[
              0.5719473535097415, 0.6578662478255226, 0.9619674689416606], 
             UndirectedEdge[269, 350] -> 
             RGBColor[
              0.6923472073123713, 0.7564468592577769, 0.9572563296732822], 
             UndirectedEdge[77, 207] -> 
             RGBColor[
              0.31339679858998193`, 0.4381896026169045, 0.9414715722896233], 
             UndirectedEdge[200, 368] -> 
             RGBColor[
              0.5720611175797564, 0.6600891155477342, 0.9610756003248153], 
             UndirectedEdge[384, 389] -> 
             RGBColor[
              0.6129812726509865, 0.6954553774642614, 0.9635158662208498], 
             UndirectedEdge[1, 361] -> 
             RGBColor[
              0.6808967778270416, 0.741454320611311, 0.7813439001425906], 
             UndirectedEdge[150, 380] -> 
             RGBColor[
              0.9126444243424163, 0.9323443373088729, 0.9624909611046095], 
             UndirectedEdge[150, 381] -> 
             RGBColor[
              0.7032879643716006, 0.7649638242060696, 0.9439520341341017], 
             UndirectedEdge[232, 279] -> 
             RGBColor[
              0.8279542058298491, 0.866344787991665, 0.9774736823646536], 
             UndirectedEdge[132, 341] -> 
             RGBColor[
              0.6829181419713799, 0.7522201099689381, 0.9690305562249757], 
             UndirectedEdge[1, 14] -> 
             RGBColor[
              0.9028686237777557, 0.9214001974049211, 0.7999457809682865], 
             UndirectedEdge[171, 342] -> 
             RGBColor[
              0.8296032437783657, 0.8676416537440738, 0.978074627697978], 
             UndirectedEdge[140, 325] -> 
             RGBColor[
              0.7693645601059181, 0.819752708832751, 0.9776467272969187], 
             UndirectedEdge[89, 306] -> 
             RGBColor[
              0.7902467430023559, 0.8362798254034745, 0.9796713330938385], 
             UndirectedEdge[130, 147] -> 
             RGBColor[
              0.6312375851752513, 0.7115061344312408, 0.9641124814859109], 
             UndirectedEdge[4, 183] -> 
             RGBColor[
              0.7187032304337206, 0.7801756930524641, 0.9725972794122368], 
             UndirectedEdge[80, 151] -> 
             RGBColor[
              0.6253951924995773, 0.7011082631393817, 0.9667509744117148], 
             UndirectedEdge[236, 286] -> 
             RGBColor[
              0.5288759004711225, 0.6278788769130752, 0.9561993727248637], 
             UndirectedEdge[108, 180] -> 
             RGBColor[
              0.3868546621357021, 0.5094957972864369, 0.945871014882509], 
             UndirectedEdge[9, 320] -> 
             RGBColor[
              0.6218194523136256, 0.7008859107128211, 0.9652202077338969], 
             UndirectedEdge[35, 97] -> 
             RGBColor[
              0.6733789533458505, 0.6953377282431215, 0.6259390870148092], 
             UndirectedEdge[154, 236] -> 
             RGBColor[
              0.619678960254682, 0.7021223220106039, 0.9632025441915255], 
             UndirectedEdge[60, 259] -> 
             RGBColor[
              0.6958754028837777, 0.759494876874739, 0.9573654378314866], 
             UndirectedEdge[179, 399] -> 
             RGBColor[
              0.7682747866914509, 0.8189013695587846, 0.9775381088674762], 
             UndirectedEdge[314, 352] -> 
             RGBColor[
              0.8522768822085202, 0.885324920113654, 0.978838591587594], 
             UndirectedEdge[85, 88] -> 
             RGBColor[
              0.9713271578669251, 0.9765833308844903, 0.8638692376332215], 
             UndirectedEdge[70, 267] -> 
             RGBColor[
              0.8220657063080041, 0.8616904279685953, 0.9826958982030843], 
             UndirectedEdge[31, 192] -> 
             RGBColor[
              0.4892073769750167, 0.5936262461233612, 0.9536423721652336], 
             UndirectedEdge[221, 255] -> 
             RGBColor[
              0.5518341626562749, 0.6470428589469154, 0.9578615532008965], 
             UndirectedEdge[11, 211] -> 
             RGBColor[
              0.6346045682405966, 0.7136639364470331, 0.9647711290685071], 
             UndirectedEdge[211, 312] -> 
             RGBColor[
              0.6109151047962909, 0.6944317628247791, 0.9629062077288075], 
             UndirectedEdge[123, 280] -> 
             RGBColor[
              0.7336222440576012, 0.78618362630537, 0.7516400554874868], 
             UndirectedEdge[178, 278] -> 
             RGBColor[
              0.6838184693985467, 0.7513017360895364, 0.9703089452806951], 
             UndirectedEdge[83, 364] -> 
             RGBColor[
              0.8548235418241314, 0.8868242025647839, 0.9542792130764974], 
             UndirectedEdge[10, 313] -> 
             RGBColor[
              0.7707924626690499, 0.8213111349855806, 0.977671505202083], 
             UndirectedEdge[32, 242] -> 
             RGBColor[
              0.7473021374148217, 0.802632774491606, 0.9755458589063171], 
             UndirectedEdge[44, 369] -> 
             RGBColor[
              0.4878826798064354, 0.5945420703559663, 0.9529878924690819], 
             UndirectedEdge[110, 375] -> 
             RGBColor[
              0.8489332805186968, 0.8825191617678397, 0.9854163772784044], 
             UndirectedEdge[275, 290] -> 
             RGBColor[
              0.6749899551225367, 0.7417910682091375, 0.9616697804259315], 
             UndirectedEdge[362, 369] -> 
             RGBColor[
              0.4430111362520428, 0.5581133298585095, 0.9494554401906001], 
             UndirectedEdge[266, 338] -> 
             RGBColor[
              0.675764947905501, 0.7403959157618496, 0.9315610784538024], 
             UndirectedEdge[350, 395] -> 
             RGBColor[
              0.7230113943221546, 0.7819078198744303, 0.9595138309499258], 
             UndirectedEdge[141, 172] -> 
             RGBColor[
              0.6905789482832905, 0.7581654971613803, 0.9698209785896945], 
             UndirectedEdge[123, 275] -> 
             RGBColor[
              0.6988454644856541, 0.7566119429490772, 0.7492720837522437], 
             UndirectedEdge[46, 315] -> 
             RGBColor[
              0.42072952729547564`, 0.536874756981657, 0.9485715275749614], 
             UndirectedEdge[185, 205] -> 
             RGBColor[
              0.9123556785411726, 0.9295943796064614, 0.8566628075247693], 
             UndirectedEdge[3, 86] -> 
             RGBColor[
              0.6603618517686447, 0.7323844051398927, 0.9683175517723916], 
             UndirectedEdge[316, 397] -> 
             RGBColor[
              0.7848278548830716, 0.8315451167460328, 0.9496797064500381], 
             UndirectedEdge[11, 214] -> 
             RGBColor[
              0.5153789826163304, 0.6171256648490879, 0.9550804265331234], 
             UndirectedEdge[3, 34] -> 
             RGBColor[
              0.4774869880377888, 0.5866844732895802, 0.9520086712722551], 
             UndirectedEdge[5, 100] -> 
             RGBColor[
              0.8264077048515004, 0.865044427904647, 0.9831387526886156], 
             UndirectedEdge[25, 245] -> 
             RGBColor[
              0.6197564964722666, 0.6973829831828227, 0.9658582798787794], 
             UndirectedEdge[183, 325] -> 
             RGBColor[
              0.7197242213080947, 0.7809732988833431, 0.9726990422408923], 
             UndirectedEdge[149, 266] -> 
             RGBColor[
              0.6031826139931478, 0.6698851649523883, 0.9272160652722026], 
             UndirectedEdge[73, 78] -> 
             RGBColor[
              0.9764093799378535, 0.9818689995325973, 0.922231446953284], 
             UndirectedEdge[40, 167] -> 
             RGBColor[
              0.5682073647534693, 0.6603353620137666, 0.9591505116470032], 
             UndirectedEdge[5, 175] -> 
             RGBColor[
              0.8171024435512557, 0.8576246651284212, 0.9822512085588935], 
             UndirectedEdge[279, 309] -> 
             RGBColor[
              0.6706494085963862, 0.7382613955715003, 0.9647483241421266], 
             UndirectedEdge[66, 257] -> 
             RGBColor[
              0.7311050874681231, 0.78958299890038, 0.9741559928045406], 
             UndirectedEdge[238, 309] -> 
             RGBColor[
              0.37402705054976726`, 0.49838516486520495`, 0.9450536508152647],
              UndirectedEdge[40, 355] -> 
             RGBColor[
              0.5152614687749781, 0.6173514984729951, 0.9549824167683689], 
             UndirectedEdge[31, 271] -> 
             RGBColor[
              0.6118724915990961, 0.695784679078594, 0.9625879903829209], 
             UndirectedEdge[271, 391] -> 
             RGBColor[
              0.6983093286541124, 0.7636542671128743, 0.9709676877591431], 
             UndirectedEdge[264, 348] -> 
             RGBColor[
              0.7393628670337586, 0.7937973559631193, 0.9186999072312227], 
             UndirectedEdge[146, 302] -> 
             RGBColor[
              0.5243004968519943, 0.6246897886694911, 0.9556940021696425], 
             UndirectedEdge[86, 91] -> 
             RGBColor[
              0.6938900232271469, 0.7596040851568162, 0.9709570122473439], 
             UndirectedEdge[232, 257] -> 
             RGBColor[
              0.6587175399345804, 0.7327215628779863, 0.96702380311176], 
             UndirectedEdge[201, 385] -> 
             RGBColor[
              0.6974605795522757, 0.7618420938828981, 0.9719985873450043], 
             UndirectedEdge[204, 297] -> 
             RGBColor[
              0.549526313775261, 0.6433014857998212, 0.9584838627285341], 
             UndirectedEdge[241, 323] -> 
             RGBColor[
              0.7626518635504214, 0.8145086992652135, 0.9769776684379826], 
             UndirectedEdge[269, 395] -> 
             RGBColor[
              0.46312239732617244`, 0.574456259236224, 0.9510343339235917], 
             UndirectedEdge[52, 342] -> 
             RGBColor[
              0.5933599760282461, 0.6796033633680272, 0.9619182607970201], 
             UndirectedEdge[201, 245] -> 
             RGBColor[
              0.6516081159433641, 0.7227805999598975, 0.9688963157782091], 
             UndirectedEdge[131, 330] -> 
             RGBColor[
              0.8387199136563648, 0.8743416074899888, 0.9844511582563631], 
             UndirectedEdge[159, 349] -> 
             RGBColor[
              0.47661051330209536`, 0.5843956767856455, 0.9523754666529896], 
             UndirectedEdge[15, 33] -> 
             RGBColor[
              0.7856666498758207, 0.8329101363076248, 0.979159551960568], 
             UndirectedEdge[16, 212] -> 
             RGBColor[
              0.4687514219989411, 0.5761268045521, 0.9522785705468877], 
             UndirectedEdge[246, 269] -> 
             RGBColor[
              0.33403325014512186`, 0.4569824640917221, 0.9427528741292526], 
             UndirectedEdge[150, 294] -> 
             RGBColor[
              0.7000294673877272, 0.7621414778954589, 0.943744405587665], 
             UndirectedEdge[77, 200] -> 
             RGBColor[
              0.3085004468161976, 0.43394862880824825`, 0.9411595810842717], 
             UndirectedEdge[21, 285] -> 
             RGBColor[
              0.7866499073217981, 0.3511974322878012, 0.43389731736274995`], 
             UndirectedEdge[275, 280] -> 
             RGBColor[
              0.43880522292097646`, 0.5539425467503718, 0.9493332847704868], 
             UndirectedEdge[171, 353] -> 
             RGBColor[
              0.7654574297999568, 0.8167172138112411, 0.9722371907943232], 
             UndirectedEdge[197, 252] -> 
             RGBColor[
              0.6562244711897431, 0.7309292978792441, 0.9666691110228367], 
             UndirectedEdge[15, 361] -> 
             RGBColor[
              0.533322598617238, 0.6288151508440432, 0.9576424688471037], 
             UndirectedEdge[348, 366] -> 
             RGBColor[
              0.8232974831405668, 0.8616575960637264, 0.9255001218402652], 
             UndirectedEdge[235, 298] -> 
             RGBColor[
              0.4504251746618089, 0.5634979975400579, 0.9502143822823705], 
             UndirectedEdge[62, 298] -> 
             RGBColor[
              0.6680318091392152, 0.7384845307332244, 0.9690671783071874], 
             UndirectedEdge[110, 308] -> 
             RGBColor[
              0.7651517659531811, 0.8169594960590142, 0.9771402810918932], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.5343069290261735, 0.6323611007963829, 0.95660673366296], 
             UndirectedEdge[204, 290] -> 
             RGBColor[
              0.6782549190645426, 0.7446190158738438, 0.9618778210412218], 
             UndirectedEdge[35, 93] -> 
             RGBColor[
              0.8853369758838224, 0.8667204439376044, 0.6438562076879684], 
             UndirectedEdge[162, 211] -> 
             RGBColor[
              0.6815529837318812, 0.7511536379766548, 0.9688944900097916], 
             UndirectedEdge[66, 275] -> 
             RGBColor[
              0.6312904033924049, 0.7072106147437172, 0.9666679989850665], 
             UndirectedEdge[36, 277] -> 
             RGBColor[
              0.5594503931630282, 0.653226057979572, 0.9584611307655597], 
             UndirectedEdge[174, 246] -> 
             RGBColor[
              0.39236122890080033`, 0.5049021370873092, 0.9471881704279411], 
             UndirectedEdge[218, 329] -> 
             RGBColor[
              0.5005597650472684, 0.6044662238896217, 0.954087468854677], 
             UndirectedEdge[186, 188] -> 
             RGBColor[
              0.5111598395072728, 0.6122423622735855, 0.955151133227834], 
             UndirectedEdge[230, 245] -> 
             RGBColor[
              0.6636904080682685, 0.7322600467330052, 0.9646870962814578], 
             UndirectedEdge[57, 368] -> 
             RGBColor[
              0.6206182827705942, 0.7011931808956104, 0.9644331330299493], 
             UndirectedEdge[293, 316] -> 
             RGBColor[
              0.6849770360517624, 0.749064447480623, 0.9422106818932738], 
             UndirectedEdge[8, 308] -> 
             RGBColor[
              0.7975503709154692, 0.8421704422254521, 0.9586368594520663], 
             UndirectedEdge[37, 361] -> 
             RGBColor[
              0.3361078873233593, 0.46516698545523827`, 0.9426511877678087], 
             UndirectedEdge[19, 331] -> 
             RGBColor[
              0.6108532267834252, 0.6898577604984916, 0.965205187935702], 
             UndirectedEdge[98, 276] -> 
             RGBColor[
              0.3275933037033747, 0.4544945692803495, 0.9422293840889042], 
             UndirectedEdge[326, 336] -> 
             RGBColor[
              0.3248478307889474, 0.453732468522361, 0.9419952793380544], 
             UndirectedEdge[4, 13] -> 
             RGBColor[
              0.7694025127638147, 0.8197823577375507, 0.97765051006317], 
             UndirectedEdge[137, 300] -> 
             RGBColor[
              0.5525967277534489, 0.6351354018136548, 0.9615871252444952], 
             UndirectedEdge[57, 163] -> 
             RGBColor[
              0.5772978290356098, 0.6673509131901978, 0.960115355054303], 
             UndirectedEdge[28, 304] -> 
             RGBColor[
              0.771503331832965, 0.8217084523558216, 0.9749367162029365], 
             UndirectedEdge[83, 328] -> 
             RGBColor[
              0.7970115003682603, 0.8413647911071285, 0.9487195662391854], 
             UndirectedEdge[206, 321] -> 
             RGBColor[
              0.6803486700231955, 0.740281973441084, 0.7216857482232192], 
             UndirectedEdge[295, 373] -> 
             RGBColor[
              0.49832411936597965`, 0.6014853973818775, 0.9542335925609827], 
             UndirectedEdge[29, 235] -> 
             RGBColor[
              0.5863117964412384, 0.6719518471430028, 0.9621870071951604], 
             UndirectedEdge[234, 392] -> 
             RGBColor[
              0.33914653701702735`, 0.4620442969871429, 0.9430555124514032], 
             UndirectedEdge[42, 275] -> 
             RGBColor[
              0.4188249399821281, 0.5371868450841246, 0.9479081327166765], 
             UndirectedEdge[107, 324] -> 
             RGBColor[
              0.7207043956639694, 0.7789443504781213, 0.9295540934644821], 
             UndirectedEdge[75, 329] -> 
             RGBColor[
              0.726754277243862, 0.7859627128507378, 0.9739148852265755], 
             UndirectedEdge[267, 383] -> 
             RGBColor[
              0.6440329639819928, 0.7205632484725687, 0.9660296222342953], 
             UndirectedEdge[253, 362] -> 
             RGBColor[
              0.7059202546844108, 0.7678520904669492, 0.9533305210313199], 
             UndirectedEdge[137, 252] -> 
             RGBColor[
              0.47984880619362136`, 0.578108876159676, 0.9543881179582379], 
             UndirectedEdge[131, 203] -> 
             RGBColor[
              0.9293291623817465, 0.9444662326829025, 0.9163674733718314], 
             UndirectedEdge[52, 199] -> 
             RGBColor[
              0.5229431459312609, 0.6235878300440776, 0.9555871465330221], 
             UndirectedEdge[41, 386] -> 
             RGBColor[
              0.626047020594329, 0.7060402413444994, 0.9645598323848644], 
             UndirectedEdge[59, 122] -> 
             RGBColor[
              0.6414553114349022, 0.7186903923567425, 0.9656764226554335], 
             UndirectedEdge[32, 172] -> 
             RGBColor[
              0.8068485442728146, 0.8494586009750739, 0.9812704978051972], 
             UndirectedEdge[55, 156] -> 
             RGBColor[
              0.7314136251036509, 0.7897220103427461, 0.9743085857522773], 
             UndirectedEdge[97, 214] -> 
             RGBColor[
              0.41321892147263267`, 0.5323311936178827, 0.9475509221744591], 
             UndirectedEdge[133, 155] -> 
             RGBColor[
              0.5001659045907358, 0.6047881161925801, 0.9538791740249255], 
             UndirectedEdge[186, 273] -> 
             RGBColor[
              0.7933766467579908, 0.8390339295811085, 0.965064717191335], 
             UndirectedEdge[74, 179] -> 
             RGBColor[
              0.529945771100441, 0.6184140832871752, 0.9591962331300314], 
             UndirectedEdge[10, 62] -> 
             RGBColor[
              0.7552645414688695, 0.8089295921147494, 0.976190438216071], 
             UndirectedEdge[273, 322] -> 
             RGBColor[
              0.8411538873777955, 0.8764778026713755, 0.9697447095117455], 
             UndirectedEdge[18, 148] -> 
             RGBColor[
              0.5953331585765234, 0.6784351140234852, 0.9633250064446349], 
             UndirectedEdge[78, 172] -> 
             RGBColor[
              0.8548215826800227, 0.8868708448473663, 0.9567175160884813], 
             UndirectedEdge[84, 269] -> 
             RGBColor[
              0.4734928392114709, 0.5828754511417922, 0.9518507330969828], 
             UndirectedEdge[103, 254] -> 
             RGBColor[
              0.7771273754374729, 0.8264591154624477, 0.9783393914252246], 
             UndirectedEdge[46, 343] -> 
             RGBColor[
              0.7595103501623628, 0.8086395906178225, 0.8569781385511834], 
             UndirectedEdge[1, 317] -> 
             RGBColor[
              0.9246491284927245, 0.9386985172376142, 0.8020414991836026], 
             UndirectedEdge[27, 399] -> 
             RGBColor[
              0.796243739287213, 0.8409621594844847, 0.9802697383093569], 
             UndirectedEdge[247, 253] -> 
             RGBColor[
              0.6670839336286621, 0.7342364039397569, 0.9508497205606397], 
             UndirectedEdge[27, 357] -> 
             RGBColor[
              0.9101093972742167, 0.9301702694704086, 0.9569547527980743], 
             UndirectedEdge[41, 55] -> 
             RGBColor[
              0.7990219474425098, 0.8433575332099652, 0.9804869317006655], 
             UndirectedEdge[183, 272] -> 
             RGBColor[
              0.5537422155454806, 0.648486060208944, 0.9580841268878886], 
             UndirectedEdge[131, 238] -> 
             RGBColor[
              0.6096726337492978, 0.6880769440375063, 0.9654790239267853], 
             UndirectedEdge[13, 131] -> 
             RGBColor[
              0.8105628644376153, 0.8523451066388017, 0.9816447267328234], 
             UndirectedEdge[55, 328] -> 
             RGBColor[
              0.7484901880308923, 0.8035855334174737, 0.9756529153394209], 
             UndirectedEdge[40, 392] -> 
             RGBColor[
              0.3711520435289292, 0.4885024110897156, 0.9454439691940081], 
             UndirectedEdge[39, 347] -> 
             RGBColor[
              0.7089695169110792, 0.7724817724943738, 0.971688558134439], 
             UndirectedEdge[195, 362] -> 
             RGBColor[
              0.6620108726659365, 0.7334072391024717, 0.9688109816721235], 
             UndirectedEdge[46, 250] -> 
             RGBColor[
              0.6057834116726041, 0.6901727770507353, 0.9625657014447522], 
             UndirectedEdge[22, 47] -> 
             RGBColor[
              0.7046211217817826, 0.7691746427455803, 0.9711937064265992], 
             UndirectedEdge[79, 100] -> 
             RGBColor[
              0.9122470737256466, 0.932865070574411, 0.9914921343361704], 
             UndirectedEdge[45, 148] -> 
             RGBColor[
              0.41027389826677907`, 0.5297803625381425, 0.9473632678999637], 
             UndirectedEdge[65, 68] -> 
             RGBColor[
              0.358837796139725, 0.4852289961293508, 0.9440858049555871], 
             UndirectedEdge[86, 162] -> 
             RGBColor[
              0.7546944135009436, 0.8083426912194318, 0.9761711662796155], 
             UndirectedEdge[3, 264] -> 
             RGBColor[
              0.49368957451984874`, 0.5998384629139193, 0.9532841982321527], 
             UndirectedEdge[55, 386] -> 
             RGBColor[
              0.7009826075573999, 0.7650167393969818, 0.9719129445785462], 
             UndirectedEdge[315, 362] -> 
             RGBColor[
              0.38501690028738955`, 0.5078816375409801, 0.9457600987572217], 
             UndirectedEdge[92, 182] -> 
             RGBColor[
              0.9074750955313314, 0.8835830019185846, 0.6449619303413268], 
             UndirectedEdge[202, 341] -> 
             RGBColor[
              0.6430778249466029, 0.7198830276063083, 0.9658893386745568], 
             UndirectedEdge[86, 125] -> 
             RGBColor[
              0.6773197927863397, 0.7461516256045944, 0.9696525430082894], 
             UndirectedEdge[155, 353] -> 
             RGBColor[
              0.515620461322014, 0.6173348215668785, 0.9550958133427183], 
             UndirectedEdge[119, 235] -> 
             RGBColor[
              0.5785557674111985, 0.6658927783167317, 0.961413958705658], 
             UndirectedEdge[139, 204] -> 
             RGBColor[
              0.3961901271379278, 0.5175817078572507, 0.9464658624574231], 
             UndirectedEdge[167, 174] -> 
             RGBColor[
              0.5928395573315661, 0.6803328856162956, 0.9610896480774453], 
             UndirectedEdge[218, 349] -> 
             RGBColor[
              0.4067841911173645, 0.5267577536031008, 0.94714090684623], 
             UndirectedEdge[362, 397] -> 
             RGBColor[
              0.5274823903969835, 0.627272993191984, 0.9559444924851641], 
             UndirectedEdge[70, 108] -> 
             RGBColor[
              0.6346321782190169, 0.7081673316124657, 0.9677729915294204], 
             UndirectedEdge[71, 157] -> 
             RGBColor[
              0.7149332813377125, 0.7761400928758837, 0.9732441882023765], 
             UndirectedEdge[186, 238] -> 
             RGBColor[
              0.49170823635911576`, 0.5953943612926529, 0.9539116942756107], 
             UndirectedEdge[51, 246] -> 
             RGBColor[
              0.5157441513560087, 0.6027182057589191, 0.9585092277129323], 
             UndirectedEdge[109, 305] -> 
             RGBColor[
              0.6668093350679503, 0.7382150911588679, 0.9683963188035478], 
             UndirectedEdge[125, 248] -> 
             RGBColor[
              0.4999918194771955, 0.6049549092831933, 0.9537803340410791], 
             UndirectedEdge[106, 390] -> 
             RGBColor[
              0.799127773331155, 0.8432381048066029, 0.9530495943101995], 
             UndirectedEdge[1, 231] -> 
             RGBColor[
              0.6947514142381873, 0.7534545103163719, 0.7822267053235349], 
             UndirectedEdge[104, 399] -> 
             RGBColor[
              0.7144541999542996, 0.7768563181481127, 0.9721737757634956], 
             UndirectedEdge[244, 366] -> 
             RGBColor[
              0.808017921741744, 0.8505374381913888, 0.9636935572012386], 
             UndirectedEdge[64, 289] -> 
             RGBColor[
              0.6165954506691282, 0.6979526035521786, 0.9640991165496959], 
             UndirectedEdge[160, 233] -> 
             RGBColor[
              0.4527716150776009, 0.5665442375979163, 0.9500837597283243], 
             UndirectedEdge[100, 302] -> 
             RGBColor[
              0.6941181624962955, 0.7591816209981166, 0.9716743983180888], 
             UndirectedEdge[177, 337] -> 
             RGBColor[
              0.6326376406937622, 0.7065683339669755, 0.9675867132938273], 
             UndirectedEdge[124, 219] -> 
             RGBColor[
              0.903558146528648, 0.9234446472125998, 0.8920918838307907], 
             UndirectedEdge[2, 181] -> 
             RGBColor[
              0.8185724189194257, 0.8584080587129997, 0.9824945717507606], 
             UndirectedEdge[185, 198] -> 
             RGBColor[
              0.7842124583392546, 0.8283520926781165, 0.8446349431678809], 
             UndirectedEdge[11, 35] -> 
             RGBColor[
              0.7755390144895482, 0.7801321994743267, 0.6334685913734734], 
             UndirectedEdge[5, 56] -> 
             RGBColor[
              0.7177192280140652, 0.7794069828835339, 0.9724992032470712], 
             UndirectedEdge[69, 107] -> 
             RGBColor[
              0.7733730064587485, 0.8217031014152002, 0.9337003594377256], 
             UndirectedEdge[51, 350] -> 
             RGBColor[
              0.8740581085232582, 0.9021826009249738, 0.9730126832569621], 
             UndirectedEdge[226, 392] -> 
             RGBColor[
              0.3419707025356166, 0.46449044721265875`, 0.9432354657809362], 
             UndirectedEdge[81, 292] -> 
             RGBColor[
              0.5743693006673773, 0.6653378991807266, 0.959635601814061], 
             UndirectedEdge[51, 272] -> 
             RGBColor[
              0.6270480599574563, 0.7057531430086318, 0.9653905683768097], 
             UndirectedEdge[10, 261] -> 
             RGBColor[
              0.5171600450143927, 0.6161888411295434, 0.9560315365516229], 
             UndirectedEdge[132, 244] -> 
             RGBColor[
              0.7990556651089071, 0.8435360551941435, 0.9628002832171275], 
             UndirectedEdge[53, 376] -> 
             RGBColor[
              0.599973728531378, 0.6835147580875185, 0.963171965963297], 
             UndirectedEdge[242, 364] -> 
             RGBColor[
              0.6804590165726491, 0.7499913016408545, 0.9689958440309784], 
             UndirectedEdge[29, 327] -> 
             RGBColor[
              0.6834141307090951, 0.7520003730420592, 0.9694951425565352], 
             UndirectedEdge[328, 364] -> 
             RGBColor[
              0.6808348831120752, 0.7502964470301552, 0.9690254336218065], 
             UndirectedEdge[257, 279] -> 
             RGBColor[
              0.7728944773957341, 0.8227388568210832, 0.9723911799270856], 
             UndirectedEdge[13, 322] -> 
             RGBColor[
              0.7403757076672379, 0.7971063969842154, 0.9747573894020592], 
             UndirectedEdge[21, 24] -> 
             RGBColor[
              0.8347854450801866, 0.8716437281436149, 0.9762474100917911], 
             UndirectedEdge[56, 122] -> 
             RGBColor[
              0.7038521924412481, 0.7685739493006754, 0.9711170667359879], 
             UndirectedEdge[87, 393] -> 
             RGBColor[
              0.5640234509671791, 0.6569386723188881, 0.9588211386275651], 
             UndirectedEdge[27, 74] -> 
             RGBColor[
              0.5579147236962032, 0.6404748732128753, 0.9619278625719122], 
             UndirectedEdge[93, 288] -> 
             RGBColor[
              0.7406189446370788, 0.7972964155537245, 0.9747816329900343], 
             UndirectedEdge[125, 211] -> 
             RGBColor[
              0.6041783630172773, 0.6889625723618173, 0.9623758667384653], 
             UndirectedEdge[265, 304] -> 
             RGBColor[
              0.7517115221067048, 0.805640569609176, 0.9733786324414975], 
             UndirectedEdge[195, 343] -> 
             RGBColor[
              0.931666254444345, 0.9453214728145318, 0.872806796232797], 
             UndirectedEdge[199, 393] -> 
             RGBColor[
              0.5388159265249652, 0.6364740683906638, 0.9568367099652696], 
             UndirectedEdge[24, 208] -> 
             RGBColor[
              0.7497956482339008, 0.8039159122199051, 0.9686878969815169], 
             UndirectedEdge[135, 386] -> 
             RGBColor[
              0.4633956067471592, 0.5737637165059943, 0.9513084786173738], 
             UndirectedEdge[32, 357] -> 
             RGBColor[
              0.9232169684536113, 0.9406218909333164, 0.9582049646384319], 
             UndirectedEdge[230, 233] -> 
             RGBColor[
              0.6961225213602752, 0.7603511131811302, 0.9667536418618327], 
             UndirectedEdge[46, 161] -> 
             RGBColor[
              0.4642853105294981, 0.5746005872416488, 0.9513468635677664], 
             UndirectedEdge[114, 306] -> 
             RGBColor[
              0.8120925368715912, 0.8536990684465251, 0.9817550044150565], 
             UndirectedEdge[233, 357] -> 
             RGBColor[
              0.7123249283121993, 0.7724348417568689, 0.9393271931567484], 
             UndirectedEdge[134, 395] -> 
             RGBColor[
              0.6668924865807087, 0.7375865751130941, 0.9689464127367318], 
             UndirectedEdge[108, 267] -> 
             RGBColor[
              0.5417963396729631, 0.6348760857825543, 0.9587235695704321], 
             UndirectedEdge[217, 233] -> 
             RGBColor[
              0.7229074094598272, 0.7784734561308597, 0.8380059996314374], 
             UndirectedEdge[245, 400] -> 
             RGBColor[
              0.6021601149883271, 0.6833630066980252, 0.9641770286549343], 
             UndirectedEdge[269, 392] -> 
             RGBColor[
              0.33745625735134754`, 0.46058026169665733`, 0.9429478093257617],
              UndirectedEdge[232, 288] -> 
             RGBColor[
              0.6930741851532856, 0.7601540880914297, 0.9700428156957284], 
             UndirectedEdge[260, 341] -> 
             RGBColor[
              0.5402651377041849, 0.6338137881847583, 0.9585142854901003], 
             UndirectedEdge[47, 323] -> 
             RGBColor[
              0.719696956957713, 0.7809519997656083, 0.9726963247852461], 
             UndirectedEdge[142, 377] -> 
             RGBColor[
              0.5940719180078162, 0.6753689837114657, 0.9641145605951156], 
             UndirectedEdge[53, 117] -> 
             RGBColor[
              0.6345565077197901, 0.7106899519176955, 0.9665766966067402], 
             UndirectedEdge[251, 308] -> 
             RGBColor[
              0.5488849279817961, 0.6446485373766655, 0.957629378643919], 
             UndirectedEdge[85, 162] -> 
             RGBColor[
              0.8161408597091432, 0.8569924829782092, 0.9700381465738751], 
             UndirectedEdge[249, 397] -> 
             RGBColor[
              0.5725130513372412, 0.6638309123514428, 0.9594894710671273], 
             UndirectedEdge[262, 284] -> 
             RGBColor[
              0.7243378400169282, 0.7825353439050284, 0.947566221473819], 
             UndirectedEdge[307, 341] -> 
             RGBColor[
              0.5452676837664588, 0.638146742148624, 0.9588330433016107], 
             UndirectedEdge[7, 387] -> 
             RGBColor[
              0.7084183232199694, 0.7712106868201277, 0.9723172636958743], 
             UndirectedEdge[228, 368] -> 
             RGBColor[
              0.6637151065849884, 0.7361811239579235, 0.9678258728694857], 
             UndirectedEdge[240, 399] -> 
             RGBColor[
              0.6991345990858635, 0.7648885295164115, 0.9706468611187395], 
             UndirectedEdge[105, 114] -> 
             RGBColor[
              0.8765636353406288, 0.9044120654073295, 0.9880886161280259], 
             UndirectedEdge[78, 357] -> 
             RGBColor[
              0.9711900068608192, 0.978034134805609, 0.9336519829217163], 
             UndirectedEdge[359, 369] -> 
             RGBColor[
              0.6107182159776304, 0.6920106143202305, 0.964199628226008], 
             UndirectedEdge[48, 354] -> 
             RGBColor[
              0.6227199324416992, 0.6991988762578493, 0.9663927815681927], 
             UndirectedEdge[280, 325] -> 
             RGBColor[
              0.6318810605974507, 0.7097641057593811, 0.9657113420755246], 
             UndirectedEdge[259, 262] -> 
             RGBColor[
              0.7026129636383538, 0.7645197386537588, 0.9459605049112686], 
             UndirectedEdge[120, 187] -> 
             RGBColor[
              0.8501694424311047, 0.8833660524325556, 0.9855711144459414], 
             UndirectedEdge[70, 198] -> 
             RGBColor[
              0.7440786176146305, 0.7997077469882372, 0.9756466272473223], 
             UndirectedEdge[62, 235] -> 
             RGBColor[
              0.62612273794364, 0.7032443822244121, 0.9661040587944468], 
             UndirectedEdge[65, 176] -> 
             RGBColor[
              0.4760786477335215, 0.5826749559474746, 0.9526897310070065], 
             UndirectedEdge[199, 342] -> 
             RGBColor[
              0.647145662407566, 0.7232690065883179, 0.9661524670522612], 
             UndirectedEdge[324, 390] -> 
             RGBColor[
              0.7116696850222624, 0.7722356887754649, 0.9461645732289901], 
             UndirectedEdge[226, 234] -> 
             RGBColor[
              0.43866293516633803`, 0.5543695194260577, 0.9491721922277641], 
             UndirectedEdge[47, 201] -> 
             RGBColor[
              0.8225486433376781, 0.8620889579644765, 0.9827383921858633], 
             UndirectedEdge[160, 264] -> 
             RGBColor[
              0.47393536057986346`, 0.5838011021202427, 0.9517290741487272], 
             UndirectedEdge[277, 314] -> 
             RGBColor[
              0.7740338434597958, 0.8236248106878585, 0.9714339072122793], 
             UndirectedEdge[4, 66] -> 
             RGBColor[
              0.8233452501945051, 0.8622345679218474, 0.9829442934614487], 
             UndirectedEdge[23, 75] -> 
             RGBColor[
              0.8458231205264031, 0.8799004133235117, 0.9851565583826636], 
             UndirectedEdge[287, 391] -> 
             RGBColor[
              0.6028323786918167, 0.6850448558707893, 0.9637544753521547], 
             UndirectedEdge[45, 91] -> 
             RGBColor[
              0.4934385295909415, 0.5988743915998054, 0.9534744976373233], 
             UndirectedEdge[175, 314] -> 
             RGBColor[
              0.9174512369605216, 0.93681838031618, 0.9851809773563285], 
             UndirectedEdge[195, 358] -> 
             RGBColor[
              0.837955849836901, 0.8737400316588606, 0.984376246337358], 
             UndirectedEdge[321, 341] -> 
             RGBColor[
              0.8580959742775616, 0.8856793021425413, 0.7358797400344624], 
             UndirectedEdge[91, 148] -> 
             RGBColor[
              0.47839428365854664`, 0.5858438219189515, 0.9525158915896155], 
             UndirectedEdge[115, 350] -> 
             RGBColor[
              0.9618749157718376, 0.9710869551235082, 0.9494200023705056], 
             UndirectedEdge[142, 277] -> 
             RGBColor[
              0.7259080398487072, 0.7854469499869875, 0.9736511598164374], 
             UndirectedEdge[45, 66] -> 
             RGBColor[
              0.6419352538174773, 0.7164306491561758, 0.9673462794412804], 
             UndirectedEdge[259, 335] -> 
             RGBColor[
              0.4604834196089371, 0.5725018385243946, 0.9507746333662278], 
             UndirectedEdge[118, 173] -> 
             RGBColor[
              0.7360439794281382, 0.7929760660374569, 0.9736234428652747], 
             UndirectedEdge[52, 128] -> 
             RGBColor[
              0.6148132884395313, 0.6963628540749365, 0.964056526485574], 
             UndirectedEdge[27, 225] -> 
             RGBColor[
              0.8970260289662746, 0.9204127148083949, 0.9791014826544602], 
             UndirectedEdge[302, 352] -> 
             RGBColor[
              0.6196385464440495, 0.7002683980193648, 0.9644444684196322], 
             UndirectedEdge[25, 242] -> 
             RGBColor[
              0.7380496210682153, 0.7952550691096878, 0.974663345637359], 
             UndirectedEdge[30, 224] -> 
             RGBColor[
              0.8712293592466747, 0.9001586584450777, 0.9875798281122201], 
             UndirectedEdge[313, 361] -> 
             RGBColor[
              0.6211527971667501, 0.6978717073032039, 0.9662790201408276], 
             UndirectedEdge[270, 310] -> 
             RGBColor[
              0.7979653754208551, 0.8424344533772901, 0.9804075431444194], 
             UndirectedEdge[72, 370] -> 
             RGBColor[
              0.5312659458085001, 0.6278924434281078, 0.9571479943463851], 
             UndirectedEdge[283, 380] -> 
             RGBColor[
              0.7875614473496716, 0.834268329833296, 0.9793807924426559], 
             UndirectedEdge[34, 35] -> 
             RGBColor[
              0.7111392842206179, 0.7278495972672221, 0.6283988087027184], 
             UndirectedEdge[25, 230] -> 
             RGBColor[
              0.8977620451550807, 0.9211604569756596, 0.984748900074558], 
             UndirectedEdge[191, 211] -> 
             RGBColor[
              0.6587713846565106, 0.7332836467161448, 0.9666736293827334], 
             UndirectedEdge[17, 173] -> 
             RGBColor[
              0.7647095937991981, 0.8121737670657388, 0.8157235967776368], 
             UndirectedEdge[40, 51] -> 
             RGBColor[
              0.6478648977048578, 0.7226531896798258, 0.9670293460988744], 
             UndirectedEdge[105, 202] -> 
             RGBColor[
              0.7130704870894587, 0.7749095120745378, 0.9727732882525862], 
             UndirectedEdge[183, 309] -> 
             RGBColor[
              0.5242179989079906, 0.6230466627814137, 0.9561661229703697], 
             UndirectedEdge[187, 261] -> 
             RGBColor[
              0.6132154085012081, 0.6915426490359766, 0.9655219449241177], 
             UndirectedEdge[190, 274] -> 
             RGBColor[
              0.631237601323633, 0.7076306362624434, 0.9664502214060959], 
             UndirectedEdge[176, 354] -> 
             RGBColor[
              0.7400307223887943, 0.7967054131623966, 0.9750011640296401], 
             UndirectedEdge[42, 148] -> 
             RGBColor[
              0.4144255444748056, 0.5333763098157294, 0.9476278071251827], 
             UndirectedEdge[320, 380] -> 
             RGBColor[
              0.8320454160247472, 0.8690195442529488, 0.983814538713865], 
             UndirectedEdge[51, 222] -> 
             RGBColor[
              0.8950243354715266, 0.9152012282151736, 0.7934810780828607], 
             UndirectedEdge[122, 319] -> 
             RGBColor[
              0.6280806617550709, 0.7078322492255535, 0.9646235212396811], 
             UndirectedEdge[27, 78] -> 
             RGBColor[
              0.9071986334801048, 0.9279994265986982, 0.9618819166527226], 
             UndirectedEdge[5, 178] -> 
             RGBColor[
              0.7931114436257914, 0.8384948930062007, 0.9799629255689842], 
             UndirectedEdge[196, 336] -> 
             RGBColor[
              0.3907412249934312, 0.5128621426894727, 0.9461186632310509], 
             UndirectedEdge[297, 318] -> 
             RGBColor[
              0.5466605706270034, 0.6408193231212391, 0.9583012601092042], 
             UndirectedEdge[127, 235] -> 
             RGBColor[
              0.5492901529823826, 0.6430302578980329, 0.9584970357621099], 
             UndirectedEdge[45, 203] -> 
             RGBColor[
              0.706758814330918, 0.7660995650159801, 0.8967752426820097], 
             UndirectedEdge[305, 370] -> 
             RGBColor[
              0.6142618858691337, 0.6971646244693469, 0.9631588801512418], 
             UndirectedEdge[122, 169] -> 
             RGBColor[
              0.8100282076765726, 0.5549009365675674, 0.45926719940403204`], 
             UndirectedEdge[51, 226] -> 
             RGBColor[
              0.6186835567115452, 0.698641225802769, 0.9648208426858025], 
             UndirectedEdge[226, 395] -> 
             RGBColor[
              0.4676368425104416, 0.5783664447522254, 0.9513219903787662], 
             UndirectedEdge[61, 354] -> 
             RGBColor[
              0.9349161081180547, 0.9468150213345683, 0.7973376911510797], 
             UndirectedEdge[211, 334] -> 
             RGBColor[
              0.598465629548246, 0.6843247179759477, 0.9619261394333509], 
             UndirectedEdge[10, 361] -> 
             RGBColor[
              0.5171600450143927, 0.6161888411295434, 0.9560315365516229], 
             UndirectedEdge[44, 249] -> 
             RGBColor[
              0.5440445458705185, 0.6407188971220013, 0.9572483260332153], 
             UndirectedEdge[302, 377] -> 
             RGBColor[
              0.40955938585443413`, 0.5284903223180475, 0.9475031848229958], 
             UndirectedEdge[149, 363] -> 
             RGBColor[
              0.610570956407258, 0.6734037289381862, 0.820362562604306], 
             UndirectedEdge[358, 359] -> 
             RGBColor[
              0.7977943982724205, 0.8419623144831955, 0.9804803478734128], 
             UndirectedEdge[126, 317] -> 
             RGBColor[
              0.6064068913917235, 0.6857790650811598, 0.9650266035866244], 
             UndirectedEdge[194, 364] -> 
             RGBColor[
              0.7631717646988141, 0.814914849993733, 0.9770294873257019], 
             UndirectedEdge[184, 343] -> 
             RGBColor[
              0.9509378467583771, 0.9606881174123033, 0.874644937911663], 
             UndirectedEdge[118, 346] -> 
             RGBColor[
              0.8136789432122522, 0.8552754630124098, 0.9802330013317921], 
             UndirectedEdge[169, 239] -> 
             RGBColor[
              0.8681976245279094, 0.600717314467975, 0.4649657385074496], 
             UndirectedEdge[72, 157] -> 
             RGBColor[
              0.6427787388997235, 0.7156694468241047, 0.9680867769317223], 
             UndirectedEdge[162, 191] -> 
             RGBColor[
              0.660386096454932, 0.7345450718453357, 0.9668345687644603], 
             UndirectedEdge[84, 272] -> 
             RGBColor[
              0.4863717876416511, 0.5938975538636564, 0.9527081152431645], 
             UndirectedEdge[21, 160] -> 
             RGBColor[
              0.5901529330755643, 0.6768810331114088, 0.9617469521492346], 
             UndirectedEdge[29, 336] -> 
             RGBColor[
              0.5636479700756458, 0.6523215798621609, 0.9607428882199796], 
             UndirectedEdge[275, 276] -> 
             RGBColor[
              0.3365292090607116, 0.46223440136921234`, 0.9427987720765628], 
             UndirectedEdge[38, 303] -> 
             RGBColor[
              0.39919913621579495`, 0.5201879602833056, 0.9466575938551027], 
             UndirectedEdge[172, 285] -> 
             RGBColor[
              0.792000640764446, 0.3553774659202781, 0.4344306284668661], 
             UndirectedEdge[73, 285] -> 
             RGBColor[
              0.8730591722696666, 0.41870956904376533`, 0.4114399157100678], 
             UndirectedEdge[5, 59] -> 
             RGBColor[
              0.6553223470077194, 0.7295234259396011, 0.9670585591665167], 
             UndirectedEdge[73, 225] -> 
             RGBColor[
              0.9662367754240233, 0.974282287742294, 0.9394510129550215], 
             UndirectedEdge[64, 254] -> 
             RGBColor[
              0.6897808234303113, 0.757367786123178, 0.9698605371803101], 
             UndirectedEdge[241, 390] -> 
             RGBColor[
              0.8898876667924074, 0.9142997849837413, 0.9619867358916612], 
             UndirectedEdge[58, 289] -> 
             RGBColor[
              0.7203418823051475, 0.779529350078032, 0.9536379389182725], 
             UndirectedEdge[262, 331] -> 
             RGBColor[
              0.9071262338381325, 0.928004519174379, 0.964053092232408], 
             UndirectedEdge[22, 118] -> 
             RGBColor[
              0.8095704843655438, 0.8520659037359173, 0.9798235085496831], 
             UndirectedEdge[97, 360] -> 
             RGBColor[
              0.6764621338116931, 0.7417410028776341, 0.9424231729481667], 
             UndirectedEdge[301, 358] -> 
             RGBColor[
              0.6694363018262096, 0.7400103072991684, 0.9688338559418325], 
             UndirectedEdge[16, 274] -> 
             RGBColor[
              0.5853428756127654, 0.6678789315876754, 0.9635258500669119], 
             UndirectedEdge[166, 319] -> 
             RGBColor[
              0.6537456341389289, 0.7278819207128382, 0.967181565834101], 
             UndirectedEdge[82, 101] -> 
             RGBColor[
              0.7586050133231761, 0.8116789844970567, 0.9764862891630148], 
             UndirectedEdge[24, 399] -> 
             RGBColor[
              0.8453143114379515, 0.8798689585646489, 0.9772968290924828], 
             UndirectedEdge[328, 400] -> 
             RGBColor[
              0.720829106123702, 0.7815402380141911, 0.9730116840043419], 
             UndirectedEdge[17, 371] -> 
             RGBColor[
              0.7889471347539425, 0.8318508947015772, 0.8176316647866324], 
             UndirectedEdge[107, 158] -> 
             RGBColor[
              0.8416544740991267, 0.8762703253489199, 0.9396683267217059], 
             UndirectedEdge[60, 394] -> 
             RGBColor[
              0.8796744698943506, 0.9065678125575852, 0.9734543960467236], 
             UndirectedEdge[219, 284] -> 
             RGBColor[
              0.7368245203757983, 0.7907473303391128, 0.8771442331902863], 
             UndirectedEdge[124, 149] -> 
             RGBColor[
              0.5211869830670794, 0.6056837601014647, 0.9592553786091693], 
             UndirectedEdge[227, 296] -> 
             RGBColor[
              0.37423220291748693`, 0.4972386735235368, 0.9451188429508321], 
             UndirectedEdge[202, 229] -> 
             RGBColor[
              0.7695300628643017, 0.8188916702257705, 0.9421989440523486], 
             UndirectedEdge[315, 358] -> 
             RGBColor[
              0.560961877458354, 0.648214430097369, 0.9613253634224562], 
             UndirectedEdge[145, 222] -> 
             RGBColor[
              0.9421460951477039, 0.9525800167392408, 0.7980272937682533], 
             UndirectedEdge[155, 299] -> 
             RGBColor[
              0.5870065434638442, 0.6739154140170519, 0.9616548925127502], 
             UndirectedEdge[14, 29] -> 
             RGBColor[
              0.787785780414882, 0.8341435061445734, 0.9794827823812249], 
             UndirectedEdge[116, 151] -> 
             RGBColor[
              0.8188200885922898, 0.8589336270346812, 0.9824311314990435], 
             UndirectedEdge[45, 257] -> 
             RGBColor[
              0.5144879778498196, 0.6159632819632004, 0.9551315873109318], 
             UndirectedEdge[27, 240] -> 
             RGBColor[
              0.7490088836921525, 0.8040619312954247, 0.9755618093384635], 
             UndirectedEdge[144, 188] -> 
             RGBColor[
              0.6396688132310229, 0.7133329039619263, 0.9677242139829587], 
             UndirectedEdge[76, 200] -> 
             RGBColor[
              0.6672774854606263, 0.7352748689572999, 0.9635711666766449], 
             UndirectedEdge[90, 221] -> 
             RGBColor[
              0.5198719409900331, 0.6210944875165829, 0.9553453700298542], 
             UndirectedEdge[271, 382] -> 
             RGBColor[
              0.7889869364116319, 0.8347476960238162, 0.945341534105635], 
             UndirectedEdge[242, 385] -> 
             RGBColor[
              0.5498304475903146, 0.6454161527900337, 0.957703813411054], 
             UndirectedEdge[74, 112] -> 
             RGBColor[
              0.4699256523279635, 0.5715259103323179, 0.9532139886106904], 
             UndirectedEdge[237, 251] -> 
             RGBColor[
              0.5309981533791539, 0.6301272479642274, 0.9562212662257847], 
             UndirectedEdge[25, 223] -> 
             RGBColor[
              0.6692700263924753, 0.739416695666492, 0.9692487639965278], 
             UndirectedEdge[284, 332] -> 
             RGBColor[
              0.4657261026718606, 0.5770088841411765, 0.9511180599804581], 
             UndirectedEdge[145, 333] -> 
             RGBColor[
              0.5345252660452587, 0.6103091795010495, 0.9614414855925466], 
             UndirectedEdge[146, 227] -> 
             RGBColor[
              0.5122205209793832, 0.614882720059394, 0.9547430222185409], 
             UndirectedEdge[108, 286] -> 
             RGBColor[
              0.39416480423379385`, 0.5158274749533789, 0.9463368106728945], 
             UndirectedEdge[127, 361] -> 
             RGBColor[
              0.5287922910053121, 0.6252760401059936, 0.9571909301224786], 
             UndirectedEdge[143, 258] -> 
             RGBColor[
              0.7906524078853219, 0.8368892265682012, 0.9796341474156028], 
             UndirectedEdge[212, 310] -> 
             RGBColor[
              0.7368490608695641, 0.7942221894605858, 0.9746358326983844], 
             UndirectedEdge[107, 310] -> 
             RGBColor[
              0.9231208314909891, 0.940251033156954, 0.9476982857468554], 
             UndirectedEdge[253, 394] -> 
             RGBColor[
              0.8823395775024261, 0.9085554454479747, 0.9689430640376403], 
             UndirectedEdge[152, 284] -> 
             RGBColor[
              0.6629453517577327, 0.73435997289707, 0.9686611629617993], 
             UndirectedEdge[230, 364] -> 
             RGBColor[
              0.8401714406595145, 0.8758966895068263, 0.9790813984681774], 
             UndirectedEdge[158, 241] -> 
             RGBColor[
              0.7562078240245117, 0.8094745666110585, 0.9763353868010132], 
             UndirectedEdge[44, 315] -> 
             RGBColor[
              0.42988844384178226`, 0.5443103780384371, 0.9492925510357035], 
             UndirectedEdge[357, 385] -> 
             RGBColor[
              0.7257452786291043, 0.7834052692317443, 0.9403629191431688], 
             UndirectedEdge[99, 197] -> 
             RGBColor[
              0.7457522302515258, 0.8013356104807268, 0.9754685941895684], 
             UndirectedEdge[152, 267] -> 
             RGBColor[
              0.7861439827647569, 0.8330474206844203, 0.9792696521438282], 
             UndirectedEdge[169, 197] -> 
             RGBColor[
              0.7763337979210446, 0.5282869318491052, 0.4561082758216547], 
             UndirectedEdge[263, 348] -> 
             RGBColor[
              0.973988651089926, 0.9798460450883985, 0.9165854847845339], 
             UndirectedEdge[314, 379] -> 
             RGBColor[
              0.8942109519647867, 0.9182872079013119, 0.9829642982265879], 
             UndirectedEdge[300, 319] -> 
             RGBColor[
              0.6927131462629343, 0.7585189337749321, 0.9710136576036698], 
             UndirectedEdge[25, 78] -> 
             RGBColor[
              0.9110536883128931, 0.9310733426796879, 0.9622496152241221], 
             UndirectedEdge[44, 113] -> 
             RGBColor[
              0.6656892427716605, 0.7372522734469591, 0.9683447030912333], 
             UndirectedEdge[115, 221] -> 
             RGBColor[
              0.7698332831418467, 0.8192833335627757, 0.9461252025487624], 
             UndirectedEdge[175, 319] -> 
             RGBColor[
              0.7164345468585103, 0.7774337347095784, 0.9732762259688201], 
             UndirectedEdge[176, 356] -> 
             RGBColor[
              0.45942128015318384`, 0.5682471813730242, 0.9516283382743191], 
             UndirectedEdge[84, 395] -> 
             RGBColor[
              0.5041570262212541, 0.6083364117584455, 0.9541082343736264], 
             UndirectedEdge[301, 359] -> 
             RGBColor[
              0.6611984043808328, 0.7335747992045005, 0.9680127793120059], 
             UndirectedEdge[238, 280] -> 
             RGBColor[
              0.41123421484534434`, 0.5300619253144179, 0.9475764845159926], 
             UndirectedEdge[36, 168] -> 
             RGBColor[
              0.5755845472279679, 0.6663244910848478, 0.9597312704749055], 
             UndirectedEdge[4, 232] -> 
             RGBColor[
              0.7509577026609624, 0.8053731318994537, 0.9758121037686681], 
             UndirectedEdge[140, 339] -> 
             RGBColor[
              0.8716340050918648, 0.8973021273669848, 0.8210734477395529], 
             UndirectedEdge[18, 141] -> 
             RGBColor[
              0.7176153195459527, 0.7792865158758042, 0.9725157114079024], 
             UndirectedEdge[123, 140] -> 
             RGBColor[
              0.8711057435660687, 0.89617222937874, 0.763575440708881], 
             UndirectedEdge[24, 78] -> 
             RGBColor[
              0.9562692056308432, 0.9669062256788625, 0.9589090074358485], 
             UndirectedEdge[62, 127] -> 
             RGBColor[
              0.766896787459789, 0.8180167910911995, 0.9773498317869267], 
             UndirectedEdge[299, 353] -> 
             RGBColor[
              0.6606569466895635, 0.7340162524967757, 0.9673677866789816], 
             UndirectedEdge[256, 311] -> 
             RGBColor[
              0.5217946468031303, 0.622655426712565, 0.9554967324745647], 
             UndirectedEdge[47, 346] -> 
             RGBColor[
              0.708729580628491, 0.7723842020220728, 0.9716031992087082], 
             UndirectedEdge[34, 125] -> 
             RGBColor[
              0.49444492905548376`, 0.6004516937542819, 0.9533436625081528], 
             UndirectedEdge[194, 387] -> 
             RGBColor[
              0.6761568721882845, 0.745747248476458, 0.9691708850797991], 
             UndirectedEdge[117, 303] -> 
             RGBColor[
              0.6340605346302122, 0.7102603649558354, 0.966545093640044], 
             UndirectedEdge[287, 382] -> 
             RGBColor[
              0.6935099864493361, 0.7561382847817313, 0.9381283216986467], 
             UndirectedEdge[20, 168] -> 
             RGBColor[
              0.45896194703976556`, 0.5643890337280735, 0.9519380944494815], 
             UndirectedEdge[51, 355] -> 
             RGBColor[
              0.6632765838082834, 0.7351650907471337, 0.9682426104838024], 
             UndirectedEdge[183, 339] -> 
             RGBColor[
              0.8219936662940414, 0.8585227174175769, 0.8161257626835267], 
             UndirectedEdge[118, 164] -> 
             RGBColor[
              0.9608868211505158, 0.9703305973302809, 0.9502220956577505], 
             UndirectedEdge[51, 134] -> 
             RGBColor[
              0.8179392007818123, 0.8578613561636377, 0.9824452650437681], 
             UndirectedEdge[46, 356] -> 
             RGBColor[
              0.4200061344760193, 0.5362481904802242, 0.9485254336241769], 
             UndirectedEdge[204, 276] -> 
             RGBColor[
              0.3397941730027175, 0.46506234903391863`, 0.9430068126918532], 
             UndirectedEdge[108, 154] -> 
             RGBColor[
              0.48496786401735337`, 0.5900709200509077, 0.9533399821395564], 
             UndirectedEdge[29, 119] -> 
             RGBColor[
              0.7563514603862033, 0.8095867764284889, 0.9763497031311884], 
             UndirectedEdge[244, 264] -> 
             RGBColor[
              0.7240833056349358, 0.7826771980907816, 0.9568933425921962], 
             UndirectedEdge[217, 321] -> 
             RGBColor[
              0.9942213467422426, 0.9900483699301512, 0.6124074384862583], 
             UndirectedEdge[241, 346] -> 
             RGBColor[
              0.7516844872211994, 0.8059409015216781, 0.9758845428614447], 
             UndirectedEdge[108, 284] -> 
             RGBColor[
              0.4185977086659389, 0.536188637995204, 0.9481150803884032], 
             UndirectedEdge[181, 334] -> 
             RGBColor[
              0.6538512271828165, 0.7275923677942069, 0.9674464581977278], 
             UndirectedEdge[8, 59] -> 
             RGBColor[
              0.7639402131679681, 0.814884202045679, 0.9559909447161186], 
             UndirectedEdge[236, 383] -> 
             RGBColor[
              0.5913105321303342, 0.6790915540761352, 0.9609692776126006], 
             UndirectedEdge[42, 290] -> 
             RGBColor[
              0.6897864517556356, 0.754607049899183, 0.9626126001073643], 
             UndirectedEdge[173, 209] -> 
             RGBColor[
              0.6091132802343222, 0.6929128178229993, 0.9628027465361702], 
             UndirectedEdge[154, 332] -> 
             RGBColor[
              0.5320962580232751, 0.6308911661968801, 0.9563429617316113], 
             UndirectedEdge[5, 352] -> 
             RGBColor[
              0.7519280887992543, 0.8061312049258951, 0.975908822790159], 
             UndirectedEdge[189, 226] -> 
             RGBColor[
              0.4338585678862626, 0.5502082179625771, 0.9488660621930128], 
             UndirectedEdge[16, 390] -> 
             RGBColor[
              0.645988481978659, 0.7154469865458117, 0.9419515033598667], 
             UndirectedEdge[119, 327] -> 
             RGBColor[
              0.675658101679055, 0.7459413042157883, 0.9687220940670329], 
             UndirectedEdge[129, 231] -> 
             RGBColor[
              0.5016792035741117, 0.6047475688800954, 0.9543489657808408], 
             UndirectedEdge[79, 352] -> 
             RGBColor[
              0.8377674576734006, 0.8739518475956591, 0.9842622044377138], 
             UndirectedEdge[62, 361] -> 
             RGBColor[
              0.6056248759665697, 0.6854901644323727, 0.9647979531548155], 
             UndirectedEdge[150, 347] -> 
             RGBColor[
              0.8023356774910839, 0.8457803619315855, 0.9516374909468719], 
             UndirectedEdge[5, 90] -> 
             RGBColor[
              0.607103268476164, 0.6903770057429512, 0.963262576672208], 
             UndirectedEdge[24, 27] -> 
             RGBColor[
              0.8951885960442405, 0.919042360343662, 0.9822117773122065], 
             UndirectedEdge[62, 393] -> 
             RGBColor[
              0.672316196580198, 0.7419627894672689, 0.9694044609807698], 
             UndirectedEdge[199, 353] -> 
             RGBColor[
              0.5829998484291571, 0.6723445666554853, 0.9603150301486065], 
             UndirectedEdge[96, 201] -> 
             RGBColor[
              0.7628300636575565, 0.8149119859412646, 0.9771447125900823], 
             UndirectedEdge[155, 170] -> 
             RGBColor[
              0.6089754987588363, 0.6910777288637441, 0.9638445526649952], 
             UndirectedEdge[335, 394] -> 
             RGBColor[
              0.64428248661951, 0.7195747742072408, 0.9668635915814647], 
             UndirectedEdge[16, 310] -> 
             RGBColor[
              0.5937749966026258, 0.6746024759811631, 0.9643301132943681], 
             UndirectedEdge[6, 277] -> 
             RGBColor[
              0.729463284902021, 0.7882818058879437, 0.9739902622634271], 
             UndirectedEdge[140, 232] -> 
             RGBColor[
              0.731163134939277, 0.7899094651509864, 0.9738391662489231], 
             UndirectedEdge[177, 300] -> 
             RGBColor[
              0.87765463282813, 0.9052819971895252, 0.9881926764423288], 
             UndirectedEdge[24, 32] -> 
             RGBColor[
              0.9082961672236352, 0.92949398180657, 0.9834619891525642], 
             UndirectedEdge[102, 226] -> 
             RGBColor[
              0.48500241008102407`, 0.5924645948159283, 0.9526890714700924], 
             UndirectedEdge[187, 206] -> 
             RGBColor[
              0.6132154085012081, 0.6915426490359766, 0.9655219449241177], 
             UndirectedEdge[336, 396] -> 
             RGBColor[
              0.49415940542630543`, 0.5977726642358087, 0.9539973615885677], 
             UndirectedEdge[267, 332] -> 
             RGBColor[
              0.5889247336788849, 0.6756963319285267, 0.961726549162487], 
             UndirectedEdge[115, 300] -> 
             RGBColor[
              0.9078300595630239, 0.9284195027556639, 0.9590504090440217], 
             UndirectedEdge[149, 195] -> 
             RGBColor[
              0.5479767560182811, 0.6270154203159148, 0.9618185131143842], 
             UndirectedEdge[127, 396] -> 
             RGBColor[
              0.6575972813080468, 0.7321753403834379, 0.9666872535562284], 
             UndirectedEdge[206, 220] -> 
             RGBColor[
              0.5907112487434869, 0.6736476004925641, 0.9633624331642612], 
             UndirectedEdge[298, 361] -> 
             RGBColor[
              0.4299273126847385, 0.5457437797480185, 0.9489082766427392], 
             UndirectedEdge[27, 141] -> 
             RGBColor[
              0.7429559990833725, 0.7992940789127121, 0.9749853791539358], 
             UndirectedEdge[55, 221] -> 
             RGBColor[
              0.7210552367269761, 0.7813126040184829, 0.9734931354752385], 
             UndirectedEdge[40, 269] -> 
             RGBColor[
              0.4661539964939709, 0.5769174480126289, 0.9512729925151945], 
             UndirectedEdge[191, 312] -> 
             RGBColor[
              0.5897482175193416, 0.6778231966934601, 0.9608462864834764], 
             UndirectedEdge[78, 240] -> 
             RGBColor[
              0.8100894932787552, 0.8519257966306251, 0.9522590394621053], 
             UndirectedEdge[183, 246] -> 
             RGBColor[
              0.4424383069440331, 0.5454511229592311, 0.9512027862240112], 
             UndirectedEdge[130, 164] -> 
             RGBColor[
              0.8036659223078154, 0.8463082096515309, 0.9365848724764199], 
             UndirectedEdge[190, 295] -> 
             RGBColor[
              0.39643448291429184`, 0.5177933565490589, 0.9464814325914178], 
             UndirectedEdge[18, 179] -> 
             RGBColor[
              0.7928083917603201, 0.8380672083008897, 0.9799833893411665], 
             UndirectedEdge[128, 199] -> 
             RGBColor[
              0.6685989748188512, 0.7400284972952272, 0.9682907327408152], 
             UndirectedEdge[350, 355] -> 
             RGBColor[
              0.7414546795933786, 0.7968809097181431, 0.9609657539264567], 
             UndirectedEdge[233, 348] -> 
             RGBColor[
              0.7181991215314962, 0.7765404914407928, 0.9170545928108198], 
             UndirectedEdge[247, 316] -> 
             RGBColor[
              0.6726514848062077, 0.738388674491942, 0.9414253086669641], 
             UndirectedEdge[74, 399] -> 
             RGBColor[
              0.5080404390899143, 0.6013014714338623, 0.9570129143521884], 
             UndirectedEdge[155, 171] -> 
             RGBColor[
              0.6918070265742374, 0.7566163753315174, 0.9665242966280918], 
             UndirectedEdge[21, 95] -> 
             RGBColor[
              0.7661463544886467, 0.8172386221452699, 0.9773259666368304], 
             UndirectedEdge[257, 325] -> 
             RGBColor[
              0.6969189651012215, 0.762564806559751, 0.9708313641597555], 
             UndirectedEdge[250, 372] -> 
             RGBColor[
              0.7956875754587991, 0.8410066396124337, 0.9800872039619358], 
             UndirectedEdge[156, 400] -> 
             RGBColor[
              0.7037525431964606, 0.7676767149394634, 0.9716673544171983], 
             UndirectedEdge[193, 360] -> 
             RGBColor[
              0.98042537713683, 0.9814043629852641, 0.702602577275841], 
             UndirectedEdge[92, 135] -> 
             RGBColor[
              0.6262350028919521, 0.7029992113102306, 0.9662688419665906], 
             UndirectedEdge[102, 174] -> 
             RGBColor[
              0.5388159436524335, 0.6364740822955139, 0.9568367113136066], 
             UndirectedEdge[140, 275] -> 
             RGBColor[
              0.576288722429444, 0.6639311498237418, 0.961268669991881], 
             UndirectedEdge[101, 301] -> 
             RGBColor[
              0.5945128985099608, 0.6814795751895593, 0.9613661912982807], 
             UndirectedEdge[337, 398] -> 
             RGBColor[
              0.5654608822817525, 0.6533523756488531, 0.9610867294262446], 
             UndirectedEdge[149, 249] -> 
             RGBColor[
              0.38513888566847054`, 0.49789833783798754`, 0.9467234051969943],
              UndirectedEdge[92, 165] -> 
             RGBColor[
              0.910460706107316, 0.9306274444858955, 0.9631267263795091], 
             UndirectedEdge[150, 320] -> 
             RGBColor[
              0.887579995329568, 0.9124637404830604, 0.9600724035761556], 
             UndirectedEdge[59, 175] -> 
             RGBColor[
              0.7298091965383415, 0.7882918778407673, 0.9743291273845726], 
             UndirectedEdge[278, 379] -> 
             RGBColor[
              0.6845691843282761, 0.7519003357968888, 0.9703805491408638], 
             UndirectedEdge[87, 317] -> 
             RGBColor[
              0.7410844810192337, 0.7977102439102951, 0.9749122298426228], 
             UndirectedEdge[212, 324] -> 
             RGBColor[
              0.5344326250425444, 0.6329155067817531, 0.9564916404160111], 
             UndirectedEdge[135, 328] -> 
             RGBColor[
              0.5109031872206516, 0.6123325105264863, 0.9550484493782485], 
             UndirectedEdge[176, 344] -> 
             RGBColor[
              0.6867162604238277, 0.7546057131312205, 0.9698067027323225], 
             UndirectedEdge[59, 213] -> 
             RGBColor[
              0.7809076974139182, 0.8246542382693953, 0.7620956004949782], 
             UndirectedEdge[371, 391] -> 
             RGBColor[
              0.6879219782820263, 0.7552213481360132, 0.9701499574877344], 
             UndirectedEdge[98, 318] -> 
             RGBColor[
              0.39549175878544074`, 0.5169768162913404, 0.9464213630435456], 
             UndirectedEdge[25, 244] -> 
             RGBColor[
              0.904559083927479, 0.9262296773629846, 0.9732432863845186], 
             UndirectedEdge[204, 224] -> 
             RGBColor[
              0.6603790934577042, 0.7306297006527653, 0.969339129651109], 
             UndirectedEdge[180, 236] -> 
             RGBColor[
              0.5215657583730309, 0.6215471992461331, 0.9557335769344781], 
             UndirectedEdge[102, 163] -> 
             RGBColor[
              0.5973354744793766, 0.683618376447088, 0.9616927919039501], 
             UndirectedEdge[16, 107] -> 
             RGBColor[
              0.655023192620366, 0.7221556482484681, 0.9253410235953587], 
             UndirectedEdge[194, 223] -> 
             RGBColor[
              0.6362042620277768, 0.7133119197035811, 0.9660256692567306], 
             UndirectedEdge[111, 291] -> 
             RGBColor[
              0.7869896635441136, 0.8335215735944168, 0.9794034328916819], 
             UndirectedEdge[108, 205] -> 
             RGBColor[
              0.5919524711815075, 0.674135691730541, 0.9637021629715585], 
             UndirectedEdge[66, 297] -> 
             RGBColor[
              0.7735233098766308, 0.823313289484753, 0.9779785080630665], 
             UndirectedEdge[19, 284] -> 
             RGBColor[
              0.428064832962221, 0.544388585229141, 0.948718317177113], 
             UndirectedEdge[23, 260] -> 
             RGBColor[
              0.5892168870734098, 0.6720628199476566, 0.9633913340243363], 
             UndirectedEdge[10, 256] -> 
             RGBColor[
              0.5962165281162086, 0.6827000621165723, 0.9616114752637299], 
             UndirectedEdge[230, 242] -> 
             RGBColor[
              0.7819835326642173, 0.8301321326598703, 0.9734921620400372], 
             UndirectedEdge[29, 317] -> 
             RGBColor[
              0.8095662851298511, 0.8514418259772665, 0.981578500596541], 
             UndirectedEdge[124, 316] -> 
             RGBColor[
              0.8925665642008229, 0.9163477024420703, 0.9599830611317826], 
             UndirectedEdge[306, 361] -> 
             RGBColor[
              0.5507892474402771, 0.6424602296560491, 0.9593833811666707], 
             UndirectedEdge[1, 393] -> 
             RGBColor[
              0.74758809844067, 0.7979269456462073, 0.7859504079685449], 
             UndirectedEdge[74, 279] -> 
             RGBColor[
              0.6059212833949537, 0.6785881335485073, 0.9607560488973614], 
             UndirectedEdge[40, 234] -> 
             RGBColor[
              0.46784427615965063`, 0.5783814833031145, 0.9513806956408359], 
             UndirectedEdge[195, 316] -> 
             RGBColor[
              0.9193563371520246, 0.9376793626565205, 0.9625461956369974], 
             UndirectedEdge[279, 325] -> 
             RGBColor[
              0.8661556309964903, 0.8961880316734296, 0.9812812434126492], 
             UndirectedEdge[172, 337] -> 
             RGBColor[
              0.547738214957664, 0.6395072932380147, 0.959320299575122], 
             UndirectedEdge[148, 275] -> 
             RGBColor[
              0.3996290478417067, 0.5205603281256839, 0.9466849874437498], 
             UndirectedEdge[13, 188] -> 
             RGBColor[
              0.5692282610342395, 0.6577257841043992, 0.9608568542845168], 
             UndirectedEdge[220, 233] -> 
             RGBColor[
              0.6322256019721743, 0.70960524668719, 0.9660076910422921], 
             UndirectedEdge[230, 244] -> 
             RGBColor[
              0.9484929955234809, 0.9611067409131671, 0.9720721027871969], 
             UndirectedEdge[253, 358] -> 
             RGBColor[
              0.8818652318553752, 0.9081848830233381, 0.9688957856965543], 
             UndirectedEdge[66, 140] -> 
             RGBColor[
              0.8035506824728197, 0.8467709011733799, 0.9809713559417037], 
             UndirectedEdge[89, 128] -> 
             RGBColor[
              0.803452243981686, 0.8465960631340518, 0.980987534019035], 
             UndirectedEdge[199, 298] -> 
             RGBColor[
              0.5345315390839824, 0.6329958096566193, 0.9564994272916871], 
             UndirectedEdge[367, 398] -> 
             RGBColor[
              0.6124367257126668, 0.6940404901541689, 0.9640799886305551], 
             UndirectedEdge[72, 181] -> 
             RGBColor[
              0.5871670562966063, 0.6715628158055917, 0.9627196946142609], 
             UndirectedEdge[229, 329] -> 
             RGBColor[
              0.7793501320252072, 0.8268640447596678, 0.9429720158687935], 
             UndirectedEdge[196, 326] -> 
             RGBColor[
              0.3524006050473302, 0.4775972967422718, 0.9437509177498369], 
             UndirectedEdge[247, 362] -> 
             RGBColor[
              0.4153060203201197, 0.5341165509378931, 0.9476900947020901], 
             UndirectedEdge[276, 297] -> 
             RGBColor[
              0.4787621155449373, 0.5783370761102481, 0.9541092811545628], 
             UndirectedEdge[7, 201] -> 
             RGBColor[
              0.8848754396971628, 0.911039672583311, 0.9888814034475875], 
             UndirectedEdge[191, 214] -> 
             RGBColor[
              0.5395457990322443, 0.6367453751181997, 0.9569829268473495], 
             UndirectedEdge[25, 32] -> 
             RGBColor[
              0.8630806499056851, 0.8936610988073954, 0.9868025969408378], 
             UndirectedEdge[190, 324] -> 
             RGBColor[
              0.43725328648647355`, 0.5530474979770983, 0.9491102923511788], 
             UndirectedEdge[8, 296] -> 
             RGBColor[
              0.6272195873055516, 0.6982693251462422, 0.9464665628220623], 
             UndirectedEdge[292, 382] -> 
             RGBColor[
              0.7693589551009091, 0.8188128165652899, 0.9437963475171902], 
             UndirectedEdge[223, 328] -> 
             RGBColor[
              0.5538673804410379, 0.6486935167400034, 0.9580216155528352], 
             UndirectedEdge[70, 262] -> 
             RGBColor[
              0.9403723095700063, 0.95451403752229, 0.9672241326148362], 
             UndirectedEdge[78, 285] -> 
             RGBColor[
              0.8676390810222359, 0.4147057639779662, 0.42233838225878817`], 
             UndirectedEdge[167, 272] -> 
             RGBColor[
              0.5473905270060679, 0.6434353153425725, 0.9575117339249385], 
             UndirectedEdge[93, 276] -> 
             RGBColor[
              0.5389483810543378, 0.6253550441587516, 0.9601080856279107], 
             UndirectedEdge[56, 319] -> 
             RGBColor[
              0.6170513313213198, 0.6992160524646913, 0.9635242206569978], 
             UndirectedEdge[93, 162] -> 
             RGBColor[
              0.7460172414332922, 0.8015136060395016, 0.9753196847647291], 
             UndirectedEdge[106, 389] -> 
             RGBColor[
              0.6772867908431572, 0.7476614940632471, 0.9685782321718122], 
             UndirectedEdge[68, 176] -> 
             RGBColor[
              0.487157035152573, 0.5922704983139153, 0.9533956360571151], 
             UndirectedEdge[253, 301] -> 
             RGBColor[
              0.7452692379637875, 0.7997973677446433, 0.9564282171351475], 
             UndirectedEdge[217, 357] -> 
             RGBColor[
              0.984683251802559, 0.9862435920513102, 0.8274036255417567], 
             UndirectedEdge[364, 385] -> 
             RGBColor[
              0.608018355585612, 0.69118070963699, 0.9632930498391941], 
             UndirectedEdge[161, 372] -> 
             RGBColor[
              0.6541894743156931, 0.7254344498033471, 0.9688683660849501], 
             UndirectedEdge[4, 339] -> 
             RGBColor[
              0.8914285728135503, 0.9127657941154521, 0.823046385259298], 
             UndirectedEdge[183, 280] -> 
             RGBColor[
              0.5614251632035676, 0.6547234232306267, 0.9586889566710977], 
             UndirectedEdge[94, 145] -> 
             RGBColor[
              0.6708763998206637, 0.7404123319163856, 0.9696901833233591], 
             UndirectedEdge[107, 351] -> 
             RGBColor[
              0.7856340831316104, 0.8316571958134391, 0.934665596307217], 
             UndirectedEdge[90, 178] -> 
             RGBColor[
              0.657599118081322, 0.7300156855218971, 0.9682448619003546], 
             UndirectedEdge[113, 124] -> 
             RGBColor[
              0.8018964575561345, 0.8451668743724381, 0.9808892028068898], 
             UndirectedEdge[191, 365] -> 
             RGBColor[
              0.6330130628060839, 0.7129475471563065, 0.964252253588799], 
             UndirectedEdge[184, 356] -> 
             RGBColor[
              0.6114336310720336, 0.6882967172747049, 0.9661922329846563], 
             UndirectedEdge[196, 327] -> 
             RGBColor[
              0.5105073856268805, 0.6125409358693711, 0.9548709175676066], 
             UndirectedEdge[140, 288] -> 
             RGBColor[
              0.7104600517238671, 0.773736059193848, 0.9717756763953236], 
             UndirectedEdge[13, 232] -> 
             RGBColor[
              0.7322220784715476, 0.7907367198866652, 0.9739447118438298], 
             UndirectedEdge[34, 86] -> 
             RGBColor[
              0.6433462677407287, 0.7185703874827054, 0.9669780226675762], 
             UndirectedEdge[287, 374] -> 
             RGBColor[
              0.6326250234560047, 0.7085805438964561, 0.966654547625527], 
             UndirectedEdge[201, 230] -> 
             RGBColor[
              0.9296136646261783, 0.9465580737527346, 0.9877869359739876], 
             UndirectedEdge[71, 138] -> 
             RGBColor[
              0.5528185994881429, 0.6478420691153997, 0.9579390516744122], 
             UndirectedEdge[334, 360] -> 
             RGBColor[
              0.7424832562630401, 0.7971962556377541, 0.9471076876716749], 
             UndirectedEdge[38, 58] -> 
             RGBColor[
              0.6642745327294156, 0.7317467950330335, 0.9498498150316366], 
             UndirectedEdge[115, 239] -> 
             RGBColor[
              0.9304517003321657, 0.9464573850568969, 0.9612080813351596], 
             UndirectedEdge[32, 78] -> 
             RGBColor[
              0.9203062046594994, 0.9384510480616062, 0.9631321284930803], 
             UndirectedEdge[41, 83] -> 
             RGBColor[
              0.8475432597798778, 0.8811367908996199, 0.95355358260043], 
             UndirectedEdge[90, 212] -> 
             RGBColor[
              0.541708214598787, 0.6388221581450853, 0.9570644014772411], 
             UndirectedEdge[160, 263] -> 
             RGBColor[
              0.7085611446360308, 0.7698497912455219, 0.9496146517020384], 
             UndirectedEdge[226, 350] -> 
             RGBColor[
              0.6968616524966404, 0.7603570447737784, 0.9575439861284567], 
             UndirectedEdge[159, 329] -> 
             RGBColor[
              0.5703860872319992, 0.6621041470721664, 0.9593220286614365], 
             UndirectedEdge[132, 260] -> 
             RGBColor[
              0.5001682916547401, 0.6024898273036151, 0.9545178066022222], 
             UndirectedEdge[7, 250] -> 
             RGBColor[
              0.7691093674231098, 0.8198138979710131, 0.9775521507528453], 
             UndirectedEdge[135, 281] -> 
             RGBColor[
              0.5908211399377487, 0.6750612278725596, 0.9628114068585936], 
             UndirectedEdge[240, 243] -> 
             RGBColor[
              0.5585881348699291, 0.6523798858309013, 0.9584931755698484], 
             UndirectedEdge[105, 349] -> 
             RGBColor[
              0.6291149823204604, 0.7051734163219144, 0.9665997980605843], 
             UndirectedEdge[111, 154] -> 
             RGBColor[
              0.715936387252166, 0.7776038854931742, 0.9726020502716957], 
             UndirectedEdge[3, 233] -> 
             RGBColor[
              0.47252582901758616`, 0.582581598391593, 0.9516388838117499], 
             UndirectedEdge[125, 162] -> 
             RGBColor[
              0.6057930748156986, 0.6902239974910083, 0.9625368061201922], 
             UndirectedEdge[301, 369] -> 
             RGBColor[
              0.48236011953141966`, 0.5900586071362033, 0.9525531362944277], 
             UndirectedEdge[268, 270] -> 
             RGBColor[
              0.7811032446627102, 0.8289890480210915, 0.9787992180597056], 
             UndirectedEdge[4, 188] -> 
             RGBColor[
              0.5879638852236544, 0.6723621961171877, 0.9627242462093552], 
             UndirectedEdge[161, 176] -> 
             RGBColor[
              0.5037004562066627, 0.6065995781344488, 0.9544497682179088], 
             UndirectedEdge[106, 270] -> 
             RGBColor[
              0.683007027902728, 0.7521301867295955, 0.9691483719432556], 
             UndirectedEdge[190, 268] -> 
             RGBColor[
              0.6228075915553484, 0.7009087752997325, 0.9656461595488384], 
             UndirectedEdge[220, 341] -> 
             RGBColor[
              0.7684585529978528, 0.8190449291940214, 0.9775564249755044], 
             UndirectedEdge[76, 103] -> 
             RGBColor[
              0.9345299976778402, 0.9504387461704789, 0.9868871294451087], 
             UndirectedEdge[84, 163] -> 
             RGBColor[
              0.5903403487940925, 0.6779394182889535, 0.9611421099860149], 
             UndirectedEdge[356, 372] -> 
             RGBColor[
              0.6099102982622142, 0.6870820530419226, 0.9660469361413604], 
             UndirectedEdge[243, 398] -> 
             RGBColor[
              0.621042891595285, 0.7011700164584811, 0.9647180820473471], 
             UndirectedEdge[141, 243] -> 
             RGBColor[
              0.552535250261149, 0.6476120334481889, 0.9579167453853208], 
             UndirectedEdge[192, 320] -> 
             RGBColor[
              0.5827619299660365, 0.667056247943492, 0.9627314969471195], 
             UndirectedEdge[83, 245] -> 
             RGBColor[
              0.6783425092328854, 0.7431875597909625, 0.9398849108897778], 
             UndirectedEdge[256, 313] -> 
             RGBColor[
              0.700209280268566, 0.7643829282902328, 0.9718589588529347], 
             UndirectedEdge[144, 186] -> 
             RGBColor[
              0.7630390192442166, 0.8152696437514755, 0.9769447567800906], 
             UndirectedEdge[271, 371] -> 
             RGBColor[
              0.5934857517962464, 0.6808574953934519, 0.9611405188727934], 
             UndirectedEdge[317, 326] -> 
             RGBColor[
              0.5707661458431527, 0.6528527146374666, 0.9628308917146158], 
             UndirectedEdge[194, 242] -> 
             RGBColor[
              0.7049838567035167, 0.7691502931467769, 0.9714402508975618], 
             UndirectedEdge[305, 334] -> 
             RGBColor[
              0.5333047563374556, 0.6319998521570558, 0.9564028504600273], 
             UndirectedEdge[252, 282] -> 
             RGBColor[
              0.7106036754943301, 0.7738482591749148, 0.9717899914705228], 
             UndirectedEdge[134, 239] -> 
             RGBColor[
              0.8646940811272356, 0.8949476050680358, 0.9869564874510763], 
             UndirectedEdge[267, 398] -> 
             RGBColor[
              0.7530195623517326, 0.8069838723605975, 0.9760176106734698], 
             UndirectedEdge[4, 297] -> 
             RGBColor[
              0.7383161966353551, 0.795497491313245, 0.974552116589626], 
             UndirectedEdge[40, 272] -> 
             RGBColor[
              0.47903294492415116`, 0.5879395507344931, 0.9521303746613762], 
             UndirectedEdge[203, 325] -> 
             RGBColor[
              0.88918980158232, 0.9127010896125307, 0.9124750195308335], 
             UndirectedEdge[315, 359] -> 
             RGBColor[
              0.5527239800129773, 0.6417789220027011, 0.9605042867926297], 
             UndirectedEdge[132, 160] -> 
             RGBColor[
              0.5489077200538346, 0.6446599592236044, 0.9576360147736585], 
             UndirectedEdge[283, 381] -> 
             RGBColor[
              0.5782049873788557, 0.6668878167304926, 0.960841865472148], 
             UndirectedEdge[40, 183] -> 
             RGBColor[
              0.5745590532928821, 0.665386106880138, 0.9597229046099531], 
             UndirectedEdge[131, 339] -> 
             RGBColor[
              0.9325889244873509, 0.9453285430167031, 0.8270406019289515], 
             UndirectedEdge[156, 165] -> 
             RGBColor[
              0.7780523275087741, 0.8260972206274236, 0.9505620042040234], 
             UndirectedEdge[352, 379] -> 
             RGBColor[
              0.8031746533341416, 0.8463684844121933, 0.9809627118784743], 
             UndirectedEdge[25, 194] -> 
             RGBColor[
              0.8207623691943803, 0.8601786174625663, 0.9826969889320825], 
             UndirectedEdge[174, 238] -> 
             RGBColor[
              0.44900029751275555`, 0.5607221325664581, 0.9505495688852904], 
             UndirectedEdge[66, 339] -> 
             RGBColor[
              0.9266356860548259, 0.9405815922869601, 0.8264727767327384], 
             UndirectedEdge[67, 387] -> 
             RGBColor[
              0.5542756927494397, 0.6490250030662238, 0.9580537593934498], 
             UndirectedEdge[90, 190] -> 
             RGBColor[
              0.4445288760427162, 0.5589541493404304, 0.949683053412409], 
             UndirectedEdge[271, 389] -> 
             RGBColor[
              0.6632453717088262, 0.7362620374512737, 0.9674728402221446], 
             UndirectedEdge[19, 293] -> 
             RGBColor[
              0.38720893096601017`, 0.5098026471411806, 0.9458935885791087], 
             UndirectedEdge[126, 327] -> 
             RGBColor[
              0.4802547369709676, 0.5863376121459526, 0.9529432455466187], 
             UndirectedEdge[12, 310] -> 
             RGBColor[
              0.8222922134541168, 0.861438764139691, 0.9828322150123483], 
             UndirectedEdge[272, 350] -> 
             RGBColor[
              0.7052261557425515, 0.7674689619796411, 0.9581137118194639], 
             UndirectedEdge[215, 229] -> 
             RGBColor[
              0.8102272537709394, 0.8518981489773925, 0.9454255667833695], 
             UndirectedEdge[57, 189] -> 
             RGBColor[
              0.4573362318385925, 0.5695896798700415, 0.9506255512561612], 
             UndirectedEdge[104, 337] -> 
             RGBColor[
              0.5183257264248325, 0.6165300336529745, 0.956388737593502], 
             UndirectedEdge[194, 385] -> 
             RGBColor[
              0.6325431957164797, 0.7103397011429122, 0.9657374567057775], 
             UndirectedEdge[56, 166] -> 
             RGBColor[
              0.7295171648251062, 0.7886236207879599, 0.9736751113304077], 
             UndirectedEdge[258, 379] -> 
             RGBColor[
              0.8638659567333442, 0.8942872811551847, 0.9868775002071115], 
             UndirectedEdge[9, 150] -> 
             RGBColor[
              0.7024184606312946, 0.7642107037687453, 0.9438966301246414], 
             UndirectedEdge[294, 380] -> 
             RGBColor[
              0.6444948880829064, 0.7186972816653472, 0.9674865407253745], 
             UndirectedEdge[296, 308] -> 
             RGBColor[
              0.4649186318798898, 0.5708620019322835, 0.9522580108340875], 
             UndirectedEdge[33, 92] -> 
             RGBColor[
              0.8629474775140318, 0.8935549107571592, 0.9867898948392375], 
             UndirectedEdge[39, 283] -> 
             RGBColor[
              0.7497298660744877, 0.804413936626196, 0.9756897244925136], 
             UndirectedEdge[11, 34] -> 
             RGBColor[
              0.524871134278803, 0.6251530578394976, 0.9557389248381947], 
             UndirectedEdge[105, 171] -> 
             RGBColor[
              0.9023221536793583, 0.9247979036812102, 0.9852303041743047], 
             UndirectedEdge[110, 237] -> 
             RGBColor[
              0.7472649913505389, 0.8024382066465761, 0.975732168673759], 
             UndirectedEdge[8, 175] -> 
             RGBColor[
              0.9257203097115044, 0.9429854412344991, 0.9711835941084952], 
             UndirectedEdge[90, 373] -> 
             RGBColor[
              0.546418512494404, 0.642646190173249, 0.9574352133819739], 
             UndirectedEdge[73, 104] -> 
             RGBColor[
              0.8335392310183374, 0.869899292861025, 0.9374382542837809], 
             UndirectedEdge[232, 339] -> 
             RGBColor[
              0.8542481385212832, 0.8837201562645665, 0.8193405870399579], 
             UndirectedEdge[178, 274] -> 
             RGBColor[
              0.8443078433622389, 0.8786921724439101, 0.9850120298940417], 
             UndirectedEdge[224, 318] -> 
             RGBColor[
              0.6575133503094466, 0.7281475379741833, 0.9691565270317792], 
             UndirectedEdge[132, 307] -> 
             RGBColor[
              0.505170837717014, 0.6068227812674808, 0.9548365644137324]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {400}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.8901235320905175, 0.9152243590020989, 0.9893819711850931], 
             316 -> RGBColor[
              0.9688332703480445, 0.9762764845731833, 0.9376413231025182], 
             308 -> RGBColor[
              0.6352494154898074, 0.7147631190114935, 0.9644283074640915], 
             160 -> 
             RGBColor[
              0.45499414418573425`, 0.5684237693594141, 0.9502379522102194], 
             245 -> RGBColor[
              0.38568485938545427`, 0.5084825729401681, 0.9457964760856792], 
             155 -> RGBColor[
              0.4419700580962947, 0.5572339830871547, 0.9493829191764869], 
             213 -> RGBColor[
              0.9937862948330312, 0.9891178378868433, 0.5650547229977604], 
             352 -> RGBColor[
              0.761240583577875, 0.8134061966245354, 0.9768370052394804], 27 -> 
             RGBColor[
              0.8461180238935021, 0.8801355612634978, 0.9851846865290808], 
             367 -> RGBColor[
              0.44806419448381857`, 0.5625124177258268, 0.9497712321582668], 
             19 -> RGBColor[
              0.37329706017654013`, 0.49775288389429856`, 0.9450071364741879],
              164 -> RGBColor[
              0.9843090029594268, 0.987779383730562, 0.9097039581683453], 190 -> 
             RGBColor[
              0.41746680915373785`, 0.5360105004222132, 0.9478215938212394], 
             103 -> RGBColor[
              0.9258331226423393, 0.9436982171971081, 0.9927879838102536], 
             138 -> RGBColor[
              0.5777034687096962, 0.6680447270000397, 0.9598980797358123], 
             291 -> RGBColor[
              0.7576794690346258, 0.810624226877876, 0.9764820666223167], 28 -> 
             RGBColor[
              0.6038731021683326, 0.689290414370313, 0.9619582491442021], 337 -> 
             RGBColor[
              0.35411250762199004`, 0.48113618871519526`, 0.9437847137496457],
              195 -> RGBColor[
              0.8698794039560047, 0.8990822407398578, 0.9874510681714767], 
             114 -> RGBColor[
              0.8901269583747211, 0.9152270910281188, 0.9893822979871391], 93 -> 
             RGBColor[
              0.8088667873362818, 0.8506121489731576, 0.9815839401379397], 34 -> 
             RGBColor[
              0.46047140400987274`, 0.5728704556323929, 0.9506691421674395], 
             161 -> RGBColor[
              0.4030030256669559, 0.5234826981368583, 0.9468999743272832], 22 -> 
             RGBColor[
              0.6816763293894829, 0.7512499965418349, 0.9689067839522105], 
             124 -> RGBColor[
              0.8162998580536013, 0.8564189203109575, 0.9823247991610469], 84 -> 
             RGBColor[
              0.5145274681065526, 0.6167556036640138, 0.9549246335470174], 46 -> 
             RGBColor[
              0.5255675953920403, 0.6257184763464392, 0.9557937528082497], 
             241 -> 
             RGBColor[
              0.8134757273594992, 0.8542126879485366, 0.9820433162064607], 
             185 -> RGBColor[
              0.9951692263033061, 0.9922703651782653, 0.7297219520031897], 
             390 -> RGBColor[
              0.9662996062253154, 0.9743868820189462, 0.9419301555768618], 
             121 -> RGBColor[
              0.5136310192829966, 0.6160278261244918, 0.9548540618118269], 
             322 -> RGBColor[
              0.7300845267600758, 0.7890668482436687, 0.9737316606657868], 
             126 -> RGBColor[
              0.35778870193998835`, 0.48432032346254655`, 0.9440189576008575],
              236 -> RGBColor[
              0.6237850040586334, 0.705455793345817, 0.9635257870007066], 78 -> 
             RGBColor[
              0.9682792430667074, 0.9758632919338986, 0.9385791467763646], 
             376 -> RGBColor[
              0.7704734220107867, 0.8206189601804971, 0.9777572482886923], 
             254 -> RGBColor[
              0.6284216282326065, 0.7092200137277871, 0.9638907990401957], 
             290 -> RGBColor[
              0.9459514668960441, 0.959211273024196, 0.9763742478166192], 251 -> 
             RGBColor[
              0.4625204404737849, 0.5745339557418375, 0.9508304498237465], 
             165 -> RGBColor[
              0.9672349392158269, 0.9750844518318026, 0.9403468807978393], 
             100 -> RGBColor[
              0.9101998156823672, 0.9312326425820391, 0.9912968650363936], 
             235 -> RGBColor[
              0.4085161034662337, 0.5282578490312456, 0.94725126276963], 70 -> 
             RGBColor[
              0.9149015448540578, 0.9349816737985067, 0.9917453201620726], 
             234 -> RGBColor[
              0.43583876964774876`, 0.5519233692005419, 0.948992238898231], 
             257 -> RGBColor[
              0.6036578115004654, 0.6891156317074044, 0.9619413006741919], 
             135 -> RGBColor[
              0.39878353278509926`, 0.5198279854804728, 0.9466311119720024], 
             265 -> RGBColor[
              0.564289482715812, 0.657154648877022, 0.958842081621324], 111 -> 
             RGBColor[
              0.8162998580536013, 0.8564189203109575, 0.9823247991610469], 
             381 -> RGBColor[
              0.43839692509596384`, 0.5541391148731545, 0.9491552423013033], 
             182 -> RGBColor[
              0.9612637180638578, 0.8809955666971808, 0.3040172887214746], 
             188 -> RGBColor[
              0.38778963349407913`, 0.5103056224840362, 0.945930590430702], 
             154 -> 
             RGBColor[
              0.6155729164507308, 0.6987888506753908, 0.9628793013823445], 
             336 -> RGBColor[
              0.36318845073504846`, 0.4889973144695619, 0.9443630248192684], 
             315 -> RGBColor[
              0.3158914591989109, 0.44803103761687474`, 0.9413493023416731], 
             368 -> RGBColor[
              0.7527941369516012, 0.8068077683247183, 0.9759951423763048], 
             269 -> RGBColor[
              0.4324582103163892, 0.5489952986195706, 0.9487768326469481], 
             208 -> RGBColor[
              0.5553321282728225, 0.649882665015984, 0.9581369258677014], 86 -> 
             RGBColor[
              0.8262211314715847, 0.8642703193330179, 0.9832869031677127], 
             119 -> RGBColor[
              0.7485954313561634, 0.8035277076022178, 0.9755766546416862], 
             377 -> RGBColor[
              0.34108226239864425`, 0.4698500452219007, 0.9429544380462075], 
             140 -> RGBColor[
              0.7485490015098586, 0.8034914362534046, 0.9755720269485182], 85 -> 
             RGBColor[
              0.9491140238879839, 0.9615699028505729, 0.9710208637562318], 
             351 -> RGBColor[
              0.5868991387544914, 0.675510186202619, 0.9606219965665879], 242 -> 
             RGBColor[
              0.6222711085773518, 0.7042267447938984, 0.9634066076028382], 
             117 -> RGBColor[
              0.839638980387611, 0.8749693478408511, 0.9845667095755785], 47 -> 
             RGBColor[
              0.7275659141740823, 0.7870992889493259, 0.9734806289009877], 81 -> 
             RGBColor[
              0.5841214617878675, 0.6732551429081924, 0.9604033276608093], 
             275 -> RGBColor[
              0.4040284433490292, 0.524370863394079, 0.9469653130352438], 23 -> 
             RGBColor[
              0.8209184867592743, 0.8600421343758778, 0.9827811321813258], 
             328 -> RGBColor[
              0.623022841656204, 0.7048370355724999, 0.9634657867844945], 110 -> 
             RGBColor[
              0.8950541164165549, 0.9191558731065349, 0.9898522547196951], 6 -> 
             RGBColor[
              0.8541720637236156, 0.8865576340029432, 0.9859528880380033], 
             218 -> RGBColor[
              0.4183387299003447, 0.5367657143489131, 0.947877151840204], 108 -> 
             RGBColor[
              0.3543628115839759, 0.48135298942642457`, 0.9438006628967683], 
             297 -> RGBColor[
              0.6884942563174807, 0.7565762128761506, 0.9695863311912437], 
             157 -> RGBColor[
              0.9019328324088353, 0.9246407745210078, 0.990508352791741], 354 -> 
             RGBColor[
              0.8756635580312192, 0.9036943681927541, 0.9880027659507459], 
             385 -> RGBColor[
              0.4773897866032776, 0.5866055607861692, 0.9520010192192697], 
             270 -> RGBColor[
              0.7340581153684613, 0.7921710458649314, 0.9741277108429739], 
             392 -> RGBColor[
              0.2424543043863059, 0.372165224773744, 0.9371187860045753], 33 -> 
             RGBColor[
              0.8722084820292584, 0.9009393843743301, 0.9876732177172961], 
             252 -> RGBColor[
              0.6986506487710709, 0.7645104638523369, 0.9705986254741339], 
             394 -> RGBColor[
              0.8069809870118989, 0.8491389474271364, 0.9813959811854112], 
             260 -> RGBColor[
              0.35751528738754523`, 0.48408350551943535`, 0.9440015358673468],
              159 -> RGBColor[
              0.5579913742698065, 0.6520415607140025, 0.9583462714537231], 
             183 -> RGBColor[
              0.6492683239142116, 0.7259326163545888, 0.9656766568364655], 99 -> 
             RGBColor[
              0.8777061668946364, 0.9053230890553023, 0.9881975918075971], 
             329 -> RGBColor[
              0.5827808001941921, 0.6721667334303302, 0.9602977858691498], 
             309 -> RGBColor[
              0.39916767390176955`, 0.5201607092082388, 0.946655589104274], 
             17 -> RGBColor[
              0.9947958680837249, 0.9912772129865638, 0.67494054097188], 349 -> 
             RGBColor[
              0.3952296523343843, 0.5167497928572886, 0.9464046618522559], 
             347 -> RGBColor[
              0.6364923513349308, 0.7157721903241863, 0.9645261559268435], 
             340 -> RGBColor[
              0.6760334425557483, 0.7468417304597931, 0.9683443537283996], 
             277 -> RGBColor[
              0.6047545060804262, 0.6900059777729444, 0.962027636488851], 104 -> 
             RGBColor[
              0.6825389452276751, 0.7519238785907538, 0.9689927614373582], 79 -> 
             RGBColor[
              0.914294331768926, 0.9344974985667829, 0.9916874036359472], 327 -> 
             RGBColor[
              0.6027207720019468, 0.6883549008293587, 0.9618675334923797], 
             191 -> RGBColor[
              0.6376044973795614, 0.7166750805848258, 0.9646137081374021], 50 -> 
             RGBColor[
              0.5828817390770298, 0.6722486801626627, 0.9603057321477582], 
             225 -> RGBColor[
              0.9479340340390472, 0.960689868353292, 0.9730182787798396], 61 -> 
             RGBColor[
              0.9941686582048902, 0.9899356744763826, 0.6066726163514136], 
             196 -> RGBColor[
              0.418293999251814, 0.5367269709093835, 0.9478743016428334], 1 -> 
             RGBColor[
              0.9942731761419903, 0.9901592277754553, 0.6180487487948139], 
             263 -> RGBColor[
              0.9621281450863274, 0.9712758131316297, 0.9489913511938574], 
             201 -> RGBColor[
              0.9175313725012739, 0.9370786269796271, 0.9919961554707389], 
             371 -> RGBColor[
              0.5830984014241603, 0.6724245764165907, 0.9603227886013846], 
             293 -> RGBColor[
              0.40112080175548026`, 0.5218524103880626, 0.9467800406840293], 
             362 -> RGBColor[
              0.4541423413758683, 0.5677322374650856, 0.9501708951727703], 
             184 -> RGBColor[
              0.908422588584069, 0.9298155299354006, 0.9911273515292086], 106 -> 
             RGBColor[
              0.6319559404369947, 0.7120893275942597, 0.9641690330435374], 
             206 -> RGBColor[
              0.3675203795120929, 0.4927494134471667, 0.9446390514903674], 
             358 -> RGBColor[
              0.8060322957177972, 0.8483978225778633, 0.9813014245032393], 
             247 -> RGBColor[
              0.3764696992643711, 0.5005008644107007, 0.9452092942314099], 
             220 -> RGBColor[
              0.8139021179748809, 0.8545457875379615, 0.982085814838155], 107 -> 
             RGBColor[
              0.9843690275087295, 0.9878042054242591, 0.9087091960478462], 
             375 -> RGBColor[
              0.8028124446208387, 0.8458824504291446, 0.9809804998371138], 
             131 -> RGBColor[
              0.8704588403008306, 0.8995442675528413, 0.9875063353273151], 
             127 -> RGBColor[
              0.6900642024985314, 0.7578026667648203, 0.9697428087545897], 
             210 -> RGBColor[
              0.9857748966384193, 0.9636775275275942, 0.3992385889359678], 
             357 -> RGBColor[
              0.9741007706549312, 0.9802049776773193, 0.9287248190670678], 
             181 -> RGBColor[
              0.7907094672026009, 0.8364275124839821, 0.9797741881568183], 
             194 -> RGBColor[
              0.7876966048296817, 0.8340738414996554, 0.9794738941922854], 
             118 -> RGBColor[
              0.9374646393416048, 0.9528818109299998, 0.9907402331471556], 
             348 -> RGBColor[
              0.9858491570935247, 0.9884162770451672, 0.8841796183752105], 
             276 -> RGBColor[
              0.26902997477239393`, 0.4000979393443456, 0.9386322311178819], 
             305 -> RGBColor[
              0.5496165255118789, 0.6452424812096798, 0.9576869726814171], 
             343 -> RGBColor[
              0.9934531049326853, 0.991560704889206, 0.7581625242941172], 280 -> 
             RGBColor[
              0.4735820024929237, 0.5835142301066646, 0.9517012565057299], 
             189 -> RGBColor[
              0.4262300350875978, 0.5436007662735806, 0.9483799788287286], 
             168 -> RGBColor[
              0.6370228142103056, 0.7162028439834959, 0.9645679159075427], 
             363 -> RGBColor[
              0.9950678047339584, 0.9918588579844003, 0.7045391671513201], 41 -> 
             RGBColor[
              0.724086360479439, 0.7843810351574829, 0.9731338195069837], 14 -> 
             RGBColor[
              0.811464071413521, 0.852641167034387, 0.9818428131417591], 77 -> 
             RGBColor[
              0.22567279542448362`, 0.35452679484574634`, 0.9361631038952173],
              51 -> RGBColor[
              0.7958800127381629, 0.8404667819539645, 0.9802895398143079], 
             179 -> RGBColor[
              0.7901801187019777, 0.8360139814120975, 0.9797214276453191], 
             223 -> RGBColor[
              0.48471191922587176`, 0.5925499979075068, 0.952577444321176], 
             323 -> RGBColor[
              0.7118279997413435, 0.7748047105818906, 0.9719120206695046], 
             292 -> RGBColor[
              0.5646171395468871, 0.6574206554532607, 0.9588678759673127], 
             396 -> RGBColor[
              0.6251303601175624, 0.7065480140020554, 0.9636316983578671], 
             321 -> RGBColor[
              0.9931769605342983, 0.9878145334350014, 0.498732444956071], 143 -> 
             RGBColor[
              0.6986816253943635, 0.7645346630258841, 0.9706017129344507], 
             112 -> RGBColor[
              0.6701398811570226, 0.742237635502383, 0.9677569386066371], 197 -> 
             RGBColor[
              0.6137982936084153, 0.6973481319061512, 0.9627395965715396], 54 -> 
             RGBColor[
              0.9725862151244898, 0.9191890079314277, 0.34800305172787227`], 
             71 -> RGBColor[
              0.5279337302665896, 0.6276394112307597, 0.9559800236130119], 
             177 -> RGBColor[
              0.9111627737655343, 0.9320004792187558, 0.9913887128380089], 
             158 -> RGBColor[
              0.6989399206895242, 0.7647364452735806, 0.9706274573955656], 
             226 -> RGBColor[
              0.44148710068492736`, 0.5568156696515736, 0.9493521455572971], 
             350 -> 
             RGBColor[
              0.9522362043083534, 0.9638984198959831, 0.9657358266996163], 
             203 -> RGBColor[
              0.9881994844626623, 0.9893881978129638, 0.8452286114163479], 
             115 -> RGBColor[
              0.9715136272353219, 0.9782754903510332, 0.9331041780413949], 
             173 -> RGBColor[
              0.5346233195146715, 0.6330703211449139, 0.9565066525833937], 
             212 -> RGBColor[
              0.6118254862658795, 0.6957465180315227, 0.9625842899509038], 
             129 -> RGBColor[
              0.608128754813839, 0.6927453449029021, 0.9622932697094257], 279 -> 
             RGBColor[
              0.9421311432910029, 0.9563620819347619, 0.9828410591799792], 26 -> 
             RGBColor[
              0.2885019948678904, 0.42056426706209343`, 0.9397411338560482], 
             40 -> RGBColor[
              0.49984978267155256`, 0.6048395974056872, 0.9537691523834408], 
             146 -> RGBColor[
              0.5705644843937646, 0.662248977924788, 0.959336072739501], 386 -> 
             RGBColor[
              0.5280076807092191, 0.6276994475315159, 0.9559858452627451], 
             192 -> RGBColor[
              0.35854287292017395`, 0.48497354845984775`, 0.9440670127088278],
              300 -> RGBColor[
              0.8441464918907259, 0.8785635151602946, 0.9849966400466486], 
             221 -> RGBColor[
              0.5681529390483716, 0.6602911767745182, 0.95914622705613], 62 -> 
             RGBColor[
              0.8437293724210464, 0.8782309154175786, 0.9849568548192636], 
             286 -> RGBColor[
              0.4339667968836118, 0.5503019604803333, 0.9488729584490208], 
             152 -> RGBColor[
              0.8430580977675637, 0.8776956592301565, 0.9848928280435605], 64 -> 
             RGBColor[
              0.7511400186280163, 0.8055155585185688, 0.9758302753204244], 
             307 -> RGBColor[
              0.3675203795120929, 0.4927494134471667, 0.9446390514903674], 37 -> 
             RGBColor[
              0.30469539513462573`, 0.43758455746330976`, 0.9406633240452499],
              148 -> RGBColor[
              0.3952296523343843, 0.5167497928572886, 0.9464046618522559], 
             261 -> RGBColor[
              0.3675203795120929, 0.4927494134471667, 0.9446390514903674], 
             387 -> RGBColor[
              0.5646171395468871, 0.6574206554532607, 0.9588678759673127], 15 -> 
             RGBColor[
              0.699124817722383, 0.7648808882409195, 0.97064588620384], 136 -> 
             RGBColor[
              0.7076791511966576, 0.7715635985663651, 0.9714985022197642], 
             198 -> RGBColor[
              0.5732556903752031, 0.6644338201779676, 0.9595479343325721], 63 -> 
             RGBColor[
              0.5916107872616232, 0.6793353147180551, 0.9609929147964065], 
             310 -> RGBColor[
              0.8618726354732488, 0.8926978608896489, 0.9866873754458648], 
             171 -> RGBColor[
              0.9416439950521802, 0.95599876757588, 0.9836656740796967], 395 -> 
             RGBColor[
              0.49378658433595574`, 0.5999172198528774, 0.9532918352002353], 
             311 -> RGBColor[
              0.5179559478905359, 0.6195389980039057, 0.9551945360345478], 
             353 -> RGBColor[
              0.5892708645477334, 0.6774356600466023, 0.9608087075089498], 59 -> 
             RGBColor[
              0.5680290999948052, 0.6601906386519473, 0.9591364779921958], 
             397 -> RGBColor[
              0.6008224394180988, 0.6868137489188825, 0.9617180897975579], 
             229 -> RGBColor[
              0.9759194638562223, 0.9815613560890054, 0.9256462458684374], 
             102 -> RGBColor[
              0.5285177194771208, 0.628113519980283, 0.9560259973828878], 299 -> 
             RGBColor[
              0.7320430288313937, 0.7905968449469492, 0.9739268658490133], 
             128 -> RGBColor[
              0.7604691173271216, 0.8128035213260861, 0.9767601126933673], 12 -> 
             RGBColor[
              0.7827117914349848, 0.8301796673897331, 0.9789770545788317], 
             222 -> RGBColor[
              0.9941686582048902, 0.9899356744763826, 0.6066726163514136], 92 -> 
             RGBColor[
              0.8536864729988051, 0.8861704371399883, 0.9859065719611788], 
             271 -> RGBColor[
              0.6038731021683326, 0.689290414370313, 0.9619582491442021], 361 -> 
             RGBColor[
              0.3675203795120929, 0.4927494134471667, 0.9446390514903674], 
             344 -> RGBColor[
              0.7690346341012859, 0.8194949681304018, 0.9776138433561107], 
             132 -> RGBColor[
              0.642821295921935, 0.7208961490877949, 0.9650340773370975], 80 -> 
             RGBColor[
              0.36326851349317274`, 0.4890666608065779, 0.9443681263474193], 
             324 -> RGBColor[
              0.4570397638192093, 0.5700844955319835, 0.9503989908811182], 
             244 -> RGBColor[
              0.9552900342958791, 0.9661759613004921, 0.9605664890971576], 
             150 -> RGBColor[
              0.9681790036472372, 0.9757885335389846, 0.9387488259669001], 
             125 -> RGBColor[
              0.5284184541010948, 0.6280329318761708, 0.9560181828488661], 
             258 -> RGBColor[
              0.8826231903762802, 0.9092437901105183, 0.9886665818967549], 
             133 -> RGBColor[
              0.5583617510851769, 0.6523422492980057, 0.958375428873364], 255 -> 
             RGBColor[
              0.5355153862641783, 0.6337945411193125, 0.956576879345663], 326 -> 
             RGBColor[
              0.2865072108428464, 0.41846762257516007`, 0.9396275338568404], 
             176 -> RGBColor[
              0.6043978867463695, 0.6897164581320392, 0.9619995621085344], 
             230 -> RGBColor[
              0.9416959567510828, 0.9560375205258421, 0.9835777164772362], 
             274 -> RGBColor[
              0.8450083934935283, 0.8792507721026736, 0.9850788489909525], 87 -> 
             RGBColor[
              0.6271438811950086, 0.7081826811208171, 0.9637902101128544], 
             130 -> RGBColor[
              0.623022841656204, 0.7048370355724999, 0.9634657867844945], 35 -> 
             RGBColor[
              0.961807164431363, 0.8828287389020512, 0.3061284752379972], 379 -> 
             RGBColor[
              0.8451087230904082, 0.8793307721998511, 0.9850884185174682], 31 -> 
             RGBColor[
              0.6198718810298595, 0.7022789437868748, 0.9632177316216396], 18 -> 
             RGBColor[
              0.7954366648186625, 0.8401204351896818, 0.9802453510370139], 24 -> 
             RGBColor[
              0.9442591681949789, 0.9579491594238263, 0.9792388680953324], 
             151 -> RGBColor[
              0.8875218715059818, 0.9131498654721854, 0.9891338224760102], 
             137 -> RGBColor[
              0.26104696361617186`, 0.39170728846701497`, 0.9381776104423417],
              330 -> RGBColor[
              0.8069809870118989, 0.8491389474271364, 0.9813959811854112], 
             296 -> RGBColor[
              0.2945878482699722, 0.42696088485307365`, 0.9400877142040834], 
             266 -> RGBColor[
              0.980291119905738, 0.9848217300128044, 0.9182461724871133], 302 -> 
             RGBColor[
              0.478036509310224, 0.5871305994141942, 0.952051931599784], 283 -> 
             RGBColor[
              0.7180130496617476, 0.7796365185878307, 0.9725284886429927], 
             388 -> RGBColor[
              0.8264591072614736, 0.8644600747681946, 0.9833096015109959], 
             284 -> RGBColor[
              0.4828326057479018, 0.5910242865639834, 0.9524294978800381], 
             318 -> 
             RGBColor[
              0.404826884936526, 0.5250624333663276, 0.9470161890271649], 238 -> 
             RGBColor[
              0.34888642719776497`, 0.47660962052217115`, 0.9434517125262555],
              72 -> RGBColor[
              0.3836246453906116, 0.5066981191272015, 0.9456652010717035], 
             288 -> RGBColor[
              0.6723711019378756, 0.7439806821342914, 0.9679793258421289], 
             382 -> RGBColor[
              0.9741007706549312, 0.9802049776773193, 0.9287248190670678], 
             389 -> RGBColor[
              0.7226176412493199, 0.7832336605322344, 0.972987431300087], 172 -> 
             RGBColor[
              0.7413639222933379, 0.7978783977608341, 0.9748558854005982], 
             243 -> RGBColor[
              0.46527652624905513`, 0.5767714703344512, 0.9510474189918506], 
             88 -> RGBColor[
              0.9935402918458662, 0.9915967589184078, 0.7567176115102112], 
             273 -> RGBColor[
              0.952223247995515, 0.9638887570990823, 0.9657577583577042], 202 -> 
             RGBColor[
              0.5631406618723811, 0.6562219843625354, 0.9587516422362597], 
             393 -> RGBColor[
              0.5009030207393497, 0.6056946635169591, 0.953852067142276], 98 -> 
             RGBColor[
              0.3861566326343555, 0.5088911992163533, 0.9458265370599265], 30 -> 
             RGBColor[
              0.832258902810982, 0.8690846743081163, 0.9838627911880465], 116 -> 
             RGBColor[
              0.7501183056785979, 0.8047173885971772, 0.9757284405220769], 
             373 -> RGBColor[
              0.6212460820571134, 0.7033945820878503, 0.9633259137603692], 
             240 -> RGBColor[
              0.6518997434908029, 0.7279883013273515, 0.9659389321478461], 
             317 -> RGBColor[
              0.8550250808434589, 0.8872378066997731, 0.9860342495723913], 
             391 -> RGBColor[
              0.7927455551398924, 0.8380181198554356, 0.979977126374084], 73 -> 
             RGBColor[
              0.9845395168089995, 0.987874707131296, 0.9058837471302035], 303 -> 
             RGBColor[
              0.42848208887281336`, 0.5455513820708198, 0.9485234777045096], 
             29 -> RGBColor[
              0.7641074894162432, 0.8156458452547599, 0.9771227516206906], 
             360 -> RGBColor[
              0.9679735253630481, 0.9756352881710764, 0.9390966471047124], 
             320 -> RGBColor[
              0.8069809870118989, 0.8491389474271364, 0.9813959811854112], 75 -> 
             RGBColor[
              0.8707277542935319, 0.8997586922711455, 0.9875319845840013], 
             200 -> RGBColor[
              0.39132809820791153`, 0.5133704627707502, 0.9461560582733259], 
             301 -> RGBColor[
              0.532840307934622, 0.6316227920204734, 0.9563662873804256], 156 -> 
             RGBColor[
              0.5888697158017213, 0.6771099894230447, 0.9607771276102074], 25 -> 
             RGBColor[
              0.8538281335590788, 0.8862833934254771, 0.9859200836718797], 38 -> 
             RGBColor[
              0.36991618355877653`, 0.4948245384957914, 0.9447917100056957], 
             365 -> RGBColor[
              0.6284216282326065, 0.7092200137277871, 0.9638907990401957], 
             380 -> RGBColor[
              0.8571098450375956, 0.8889001410787613, 0.986233096242319], 370 -> 
             RGBColor[
              0.6789072462263884, 0.7490867677290141, 0.9686307876210667], 3 -> 
             RGBColor[
              0.49450257206570475`, 0.6004984909467673, 0.9533482003770707], 
             57 -> RGBColor[
              0.48844242858958714`, 0.5955785934665025, 0.9528711236835937], 
             227 -> RGBColor[
              0.4538765575650017, 0.567516462194, 0.9501499716975808], 39 -> 
             RGBColor[
              0.7814466824872277, 0.8291913546645612, 0.9788509603420344], 
             109 -> RGBColor[
              0.7840021446240215, 0.8311877011080561, 0.9791056649256786], 
             256 -> RGBColor[
              0.5256333457157247, 0.6257718554212245, 0.9557989289145815], 
             339 -> RGBColor[
              0.9947190086738711, 0.9911128184805649, 0.6665748685305878], 
             287 -> RGBColor[
              0.412919202243741, 0.5320715918861432, 0.9475318243302254], 239 -> 
             RGBColor[
              0.8893897734290096, 0.9146392797627607, 0.9893119846289243], 
             285 -> RGBColor[0.817319, 0.134127, 0.164218], 345 -> 
             RGBColor[
              0.49378658433595574`, 0.5999172198528774, 0.9532918352002353], 
             366 -> RGBColor[
              0.6607458091876088, 0.7348989150822856, 0.9668206253053198], 
             216 -> RGBColor[
              0.5777371709226162, 0.6680720879747556, 0.9599007328974687], 21 -> 
             RGBColor[
              0.7253117219653943, 0.7853382968634035, 0.9732559520882497], 
             355 -> RGBColor[
              0.5306731548784038, 0.6298633995403029, 0.9561956811532969], 
             175 -> RGBColor[
              0.8915892930818778, 0.9163931170295874, 0.9895217767769493], 7 -> 
             RGBColor[
              0.8522195068930517, 0.8850007181869948, 0.985766651424436], 13 -> 
             RGBColor[
              0.7506668885743999, 0.8051459457247622, 0.9757831181383317], 
             294 -> RGBColor[
              0.43187993112821726`, 0.5484944222519332, 0.94873998520843], 
             193 -> RGBColor[
              0.9928772289106118, 0.9871734377994519, 0.4661085074469696], 60 -> 
             RGBColor[
              0.9523679527768024, 0.9639966776880341, 0.965512810908036], 65 -> 
             RGBColor[
              0.34775940872067346`, 0.47563345376291016`, 0.9433798999054785],
              69 -> RGBColor[
              0.5623769854087675, 0.6556019974061413, 0.958691522827605], 217 -> 
             RGBColor[
              0.9952657329501869, 0.992282206425301, 0.7260824320164457], 214 -> 
             RGBColor[
              0.44148710068492736`, 0.5568156696515736, 0.9493521455572971], 
             170 -> RGBColor[
              0.7759809394213779, 0.8249214746403335, 0.9783061861535036], 
             359 -> RGBColor[
              0.7895565008270437, 0.8355268063885276, 0.9796592712435861], 74 -> 
             RGBColor[
              0.2697114234989044, 0.4008141851622529, 0.9386710386147437], 
             246 -> RGBColor[
              0.23560828997385452`, 0.3649696295638736, 0.9367289156115569], 
             264 -> RGBColor[
              0.4928765769739927, 0.5991784348810713, 0.9532201960872349], 
             278 -> RGBColor[
              0.524029645566144, 0.6244698993939264, 0.9556726797642594], 45 -> 
             RGBColor[
              0.42531814419917385`, 0.5428109322189963, 0.9483218739476716], 
             306 -> RGBColor[
              0.7340581153684613, 0.7921710458649314, 0.9741277108429739], 
             237 -> RGBColor[
              0.5994758662845229, 0.6857205401866172, 0.9616120826278228], 
             228 -> RGBColor[
              0.5746360762183755, 0.6655544795911286, 0.9596566033626667], 
             180 -> RGBColor[
              0.4193465126874283, 0.5376386051464492, 0.9479413668682497], 
             383 -> RGBColor[
              0.5588360602020352, 0.6527273148064534, 0.9584127682244946], 53 -> 
             RGBColor[
              0.4294740350519691, 0.5464105559945399, 0.9485866836379018], 
             304 -> RGBColor[
              0.9391335614975975, 0.95412649034133, 0.9879151832616708], 48 -> 
             RGBColor[
              0.36977630685217916`, 0.4947033843229445, 0.9447827971856395], 
             5 -> RGBColor[
              0.7426155940206335, 0.7988562132272549, 0.9749806403408376], 
             101 -> RGBColor[
              0.6561854890852995, 0.7313363583586451, 0.9663660952161359], 
             333 -> RGBColor[0.178927, 0.305394, 0.933501], 267 -> 
             RGBColor[
              0.7292298677619503, 0.788399182138684, 0.9736464762440961], 120 -> 
             RGBColor[
              0.841428447371886, 0.8763962202403248, 0.9847373905340147], 147 -> 
             RGBColor[
              0.6394523286942986, 0.7181752332899816, 0.9647591761873273], 89 -> 
             RGBColor[
              0.8464353706362504, 0.8803886049420174, 0.9852149553447029], 43 -> 
             RGBColor[
              0.8727575221297525, 0.9013771740471677, 0.9877255856522151], 
             199 -> RGBColor[
              0.5767288323105808, 0.6672534732643683, 0.9598213527882632], 
             268 -> RGBColor[
              0.828148373956959, 0.8658070501772517, 0.9834707252764374], 169 -> 
             RGBColor[
              0.8576015500773593, 0.4437563318205822, 0.20279261544671232`], 
             20 -> RGBColor[
              0.2809010798692255, 0.412575223472651, 0.9393082729914203], 4 -> 
             RGBColor[
              0.7881381369532295, 0.8344187697503394, 0.9795179019880083], 
             167 -> RGBColor[
              0.6365649468353862, 0.715831126621846, 0.9645318709105655], 142 -> 
             RGBColor[
              0.8470615736169881, 0.8808879222010306, 0.9852746831440237], 16 -> 
             RGBColor[
              0.3256773577320027, 0.45650709107267734`, 0.9419728511428714], 
             281 -> RGBColor[
              0.782858747090398, 0.8302944702646463, 0.9789917017451846], 289 -> 
             RGBColor[
              0.48205088271024027`, 0.5903896485857882, 0.9523679577789675], 
             398 -> RGBColor[
              0.776809256941515, 0.825568562582511, 0.9783887451028436], 178 -> 
             RGBColor[
              0.8436072932309494, 0.8781335727851466, 0.9849452107971308], 58 -> 
             RGBColor[
              0.9586328819000547, 0.9686690515702757, 0.9549079200575775], 
             186 -> RGBColor[
              0.6345300455204665, 0.7141791020631347, 0.9643716760249659], 
             122 -> RGBColor[
              0.7148815228749992, 0.7771901460615377, 0.9722163673186712], 
             249 -> RGBColor[
              0.5442036632563836, 0.640848075784003, 0.9572608523366968], 113 -> 
             RGBColor[
              0.7874930570586676, 0.8339148284339187, 0.9794536064527327], 52 -> 
             RGBColor[
              0.46915745955194105`, 0.5799221868237868, 0.951352940277781], 
             187 -> RGBColor[
              0.8589104374903234, 0.8903358846247864, 0.9864048383578681], 
             259 -> RGBColor[
              0.439382852990753, 0.554993076061444, 0.9492180647549374], 42 -> 
             RGBColor[
              0.433621436615227, 0.5500028267741702, 0.9488509523981093], 134 -> 
             RGBColor[
              0.8399983888254615, 0.875255930373311, 0.9846009902732283], 313 -> 
             RGBColor[
              0.8747852148214073, 0.9029940011592412, 0.9879189887912878], 
             248 -> RGBColor[
              0.4715651848532963, 0.5818768866902158, 0.951542485233292], 174 -> 
             RGBColor[
              0.5491141678277461, 0.644834644610745, 0.9576474252443253], 215 -> 
             RGBColor[
              0.6445350436856564, 0.7222349418657794, 0.9652048876983018], 
             399 -> RGBColor[
              0.7463694546809241, 0.8017887577054715, 0.9753547900896331], 83 -> 
             RGBColor[
              0.9710001590803164, 0.9778925466417571, 0.9339733456938762], 95 -> 
             RGBColor[
              0.8069809870118989, 0.8491389474271364, 0.9813959811854112], 
             166 -> RGBColor[
              0.7662114676427153, 0.8172894890361068, 0.9773324565075109], 
             384 -> RGBColor[
              0.5033449040526531, 0.6076770943962885, 0.9540443011416125], 
             233 -> RGBColor[
              0.4505490859694676, 0.5646647058364185, 0.9499295672464291], 
             295 -> RGBColor[
              0.3754021566748459, 0.4995762126759046, 0.9451412713615962], 
             141 -> RGBColor[
              0.6397939742732429, 0.7184525965619265, 0.9647860717787908], 
             319 -> RGBColor[
              0.5412798006351427, 0.6384743523895695, 0.957030675160691], 205 -> 
             RGBColor[
              0.8295421307790392, 0.8669183940346574, 0.9836036630463488], 
             224 -> RGBColor[
              0.9101998156823672, 0.9312326425820391, 0.9912968650363936], 
             231 -> RGBColor[
              0.3952296523343843, 0.5167497928572886, 0.9464046618522559], 
             332 -> RGBColor[
              0.4486195995958194, 0.5629934817183694, 0.949806622080878], 68 -> 
             RGBColor[
              0.36991618355877653`, 0.4948245384957914, 0.9447917100056957], 
             10 -> RGBColor[
              0.6667997105166926, 0.7396282688119201, 0.9674240216128783], 
             250 -> RGBColor[
              0.6859992279531678, 0.7546270777550315, 0.9693376500812547], 
             282 -> 
             RGBColor[
              0.7225567022175895, 0.7831860544974928, 0.9729813574669117], 
             374 -> RGBColor[
              0.8523308446682684, 0.8850894959067691, 0.9857772709208286], 
             232 -> RGBColor[
              0.7137772683686954, 0.7763274940485682, 0.972106305549328], 253 -> 
             RGBColor[
              0.9576981679929532, 0.967971943468813, 0.9564901468898694], 55 -> 
             RGBColor[
              0.8739575344055807, 0.9023340312624476, 0.9878400438943472], 
             325 -> RGBColor[
              0.7901801187019777, 0.8360139814120975, 0.9797214276453191], 91 -> 
             RGBColor[
              0.561558914982709, 0.6549378509806144, 0.9586271213269749], 105 -> 
             RGBColor[
              0.8630003123065364, 0.8935970397865403, 0.9867949342689127], 36 -> 
             RGBColor[
              0.5141462802456302, 0.6164461381861996, 0.9548946250422684], 
             123 -> RGBColor[
              0.9936624856222789, 0.9888530225040754, 0.5515788544692437], 94 -> 
             RGBColor[
              0.4516292675508099, 0.5656003048306724, 0.9499983954616251], 
             312 -> RGBColor[
              0.5418919376591219, 0.6389713128020945, 0.9570788648295505], 96 -> 
             RGBColor[
              0.608128754813839, 0.6927453449029021, 0.9622932697094257], 2 -> 
             RGBColor[
              0.8464353706362504, 0.8803886049420174, 0.9852149553447029], 
             262 -> RGBColor[
              0.9658430742859547, 0.9740464012460734, 0.9427029450675998], 
             272 -> RGBColor[
              0.4582161071767497, 0.5710395040632991, 0.9504915969393115], 97 -> 
             RGBColor[
              0.384950742260338, 0.5078467175841919, 0.9457496987916211], 372 -> 
             RGBColor[
              0.9053759229644304, 0.927386201469836, 0.9908367578426169], 356 -> 
             RGBColor[
              0.3144446735599982, 0.4467779046140092, 0.941257114440104], 346 -> 
             RGBColor[
              0.6898932470828997, 0.7576691150948196, 0.9697257695164287], 
             341 -> RGBColor[
              0.7230149880208248, 0.7835440708500812, 0.9730270351128539], 
             209 -> RGBColor[
              0.6836032409539728, 0.7527553145010848, 0.9690988404889466], 
             378 -> RGBColor[
              0.8926153276591374, 0.9172112491505275, 0.9896196408708802], 66 -> 
             RGBColor[
              0.8585523634357808, 0.8900503660933554, 0.9863706849348892], 
             139 -> RGBColor[
              0.3818218830428144, 0.5051366569910097, 0.9455503306490219], 
             56 -> 
             RGBColor[
              0.692822862007497, 0.759957752539813, 0.9700177661533046], 335 -> 
             RGBColor[
              0.4815839862271211, 0.5900106009873453, 0.9523312019775182], 
             314 -> RGBColor[
              0.9433131808391653, 0.9572436436027727, 0.9808401779357077], 
             144 -> RGBColor[
              0.8915479929679666, 0.9163601854398162, 0.9895178375352154], 
             298 -> RGBColor[
              0.49233424585738417`, 0.5987381460488702, 0.9531775017951111], 
             204 -> RGBColor[
              0.4105583712330412, 0.5300267587234917, 0.9473813942658245], 
             207 -> RGBColor[
              0.40112080175548026`, 0.5218524103880626, 0.9467800406840293], 
             334 -> RGBColor[
              0.5169929871630322, 0.6187572231044317, 0.9551187282386373], 
             149 -> RGBColor[
              0.22607410808055758`, 0.3549485998919721, 0.9361859580572918], 
             219 -> RGBColor[
              0.9908164350036948, 0.9904703741142421, 0.8018589685005347], 
             400 -> RGBColor[
              0.8186353705912001, 0.8582434404558823, 0.9825575812241892], 9 -> 
             RGBColor[
              0.4366579176153522, 0.552632873998506, 0.9490444342823826], 11 -> 
             RGBColor[
              0.5892708645477334, 0.6774356600466023, 0.9608087075089498], 44 -> 
             RGBColor[
              0.5438854284846536, 0.6405897184599995, 0.9572357997297338], 
             153 -> RGBColor[
              0.7440614322103491, 0.7999857130098379, 0.9751247479794625], 32 -> 
             RGBColor[
              0.8723331662522914, 0.9010388041893136, 0.987685110209796], 162 -> 
             RGBColor[
              0.6831676955303024, 0.7524150631058456, 0.9690554293915185], 90 -> 
             RGBColor[
              0.47159094293169457`, 0.5818977982586477, 0.9515445130035785], 
             331 -> RGBColor[
              0.8484093933903103, 0.8819626371026845, 0.9854032393972161], 8 -> 
             RGBColor[
              0.959851326341131, 0.9695777654394108, 0.9528454114400412], 364 -> 
             RGBColor[
              0.7386469245679463, 0.7957558584878106, 0.9745850804591185], 
             342 -> RGBColor[
              0.7175624925045512, 0.7792845399122675, 0.9724835813162593], 
             163 -> RGBColor[
              0.6661532294816324, 0.7391232329138931, 0.9673595864250123], 49 -> 
             RGBColor[
              0.9942110800729763, 0.99002641056271, 0.6112899748951607], 338 -> 
             RGBColor[
              0.37123877590526405`, 0.4959701015108947, 0.9448759844204915], 
             76 -> RGBColor[
              0.943226872713341, 0.9571792751438495, 0.9809862750799637], 369 -> 
             RGBColor[
              0.43187993112821726`, 0.5484944222519332, 0.94873998520843], 82 -> 
             RGBColor[
              0.8610245375610527, 0.8920216106354683, 0.9866064831098936], 67 -> 
             RGBColor[
              0.5439342459519924, 0.6406293506791869, 0.957239642819587], 211 -> 
             RGBColor[
              0.6799382719334599, 0.7498922128474639, 
               0.9687335506280645]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9l2k4lWvYhs1zWMs8LNZoLbMSqfBetRslSppMScqwSaE2pQyZolBokCJT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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 14}], {
             RGBColor[
             0.9028686237777557, 0.9214001974049211, 0.7999457809682865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.8791903327791167, 0.9029025365151075, 0.7975857502077522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 49}], {
             RGBColor[
             0.9942421281074834, 0.9900928191690826, 0.6146693618449872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 62}], {
             RGBColor[
             0.9190012742815183, 0.9341950715965169, 0.8015028018070387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 87}], {
             RGBColor[
             0.8107085286684994, 0.8491709544481362, 0.7909194794538341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 119}], {
             RGBColor[
             0.8714343037490768, 0.8968434676888366, 0.79681270171825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 127}], {
             RGBColor[
             0.8421686893202609, 0.8739809472701379, 0.7938957787747019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 129}], {
             RGBColor[
             0.8012009654779146, 0.8414522863391787, 0.7901710092521198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 216}], {
             RGBColor[
             0.7860051735323033, 0.8291156578751054, 0.7889747408461413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 231}], {
             RGBColor[
             0.6947514142381873, 0.7534545103163719, 0.7822267053235349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 235}], {
             RGBColor[
             0.701394639804112, 0.7592085384033505, 0.7826500057822219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 298}], {
             RGBColor[
             0.7433037109996872, 0.7944486869121627, 0.7856131252949625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 313}], {
             RGBColor[
             0.9345291954816988, 0.9465766144673482, 0.8029838687930508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 317}], {
             RGBColor[
             0.9246491284927245, 0.9386985172376142, 0.8020414991836026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 336}], {
             RGBColor[
             0.6787308134385194, 0.7395782711225086, 0.7812058868070411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 361}], {
             RGBColor[
             0.6808967778270416, 0.741454320611311, 0.7813439001425906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 393}], {
             RGBColor[
             0.74758809844067, 0.7979269456462073, 0.7859504079685449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 396}], {
             RGBColor[
             0.8097017681297763, 0.8483536208887553, 0.7908402235763405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 97}], {
             RGBColor[
             0.6156930564482942, 0.6941176612631046, 0.9654823270681621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 109}], {
             RGBColor[
             0.815218757630136, 0.8557881530250367, 0.9821603101351908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 181}], {
             RGBColor[
             0.8185724189194257, 0.8584080587129997, 0.9824945717507606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 191}], {
             RGBColor[
             0.7420199340079059, 0.7985318427634216, 0.9749143317410525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 193}], {
             RGBColor[
             0.9196562997734311, 0.9337810213707347, 0.7256617313958362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 211}], {
             RGBColor[
             0.7631868212848552, 0.8151404088947407, 0.9769742529863837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 305}], {
             RGBColor[
             0.6980259480740647, 0.7628155430758485, 0.97145096401306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 334}], {
             RGBColor[
             0.6817141788996413, 0.7495729140232246, 0.9701668417916701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 340}], {
             RGBColor[
             0.7612344065959993, 0.8136151677009053, 0.9767796545365512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 360}], {
             RGBColor[
             0.9072044479996493, 0.9280119465565468, 0.9621558012247077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 365}], {
             RGBColor[
             0.7374284994344285, 0.7948043093349022, 0.9745528771924493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 370}], {
             RGBColor[
             0.7626713084313195, 0.8147376863355158, 0.9769228714828848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 11}], {
             RGBColor[
             0.5418867183067191, 0.6389670754966847, 0.9570784539430102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 21}], {
             RGBColor[
             0.6099071470155495, 0.6929183939050854, 0.9633020762326602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 34}], {
             RGBColor[
             0.4774869880377888, 0.5866844732895802, 0.9520086712722551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 74}], {
             RGBColor[
             0.3821069977823046, 0.5006563380545102, 0.9460096194959071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 86}], {
             RGBColor[
             0.6603618517686447, 0.7323844051398927, 0.9683175517723916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 91}], {
             RGBColor[
             0.5280307435242069, 0.6277181709636909, 0.9559876608520228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 95}], {
             RGBColor[
             0.6507417795388019, 0.7248187191869518, 0.9673720907812409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 160}], {
             RGBColor[
             0.47474835812571947`, 0.5844611301530906, 0.9517930762936451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[
             0.5888351337980036, 0.6764567770263065, 0.9612018148842946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 233}], {
             RGBColor[
             0.47252582901758616`, 0.582581598391593, 0.9516388838117499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 263}], {
             RGBColor[
             0.728315358576016, 0.7858871520391986, 0.951169775785464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 264}], {
             RGBColor[
             0.49368957451984874`, 0.5998384629139193, 0.9532841982321527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 285}], {
             RGBColor[
             0.7097135240219016, 0.2895841636489225, 0.42726140012569025`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 312}], {
             RGBColor[
             0.5181972548624133, 0.6197349018744309, 0.9552135326033107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 348}], {
             RGBColor[
             0.7401758645796147, 0.7944573839959672, 0.9187639093761406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 13}], {
             RGBColor[
             0.7694025127638147, 0.8197823577375507, 0.97765051006317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 66}], {
             RGBColor[
             0.8233452501945051, 0.8622345679218474, 0.9829442934614487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 123}], {
             RGBColor[
             0.8909003112877543, 0.9116358961272073, 0.765548378228626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 131}], {
             RGBColor[
             0.82929848862703, 0.8669815186515903, 0.9835121186576616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 140}], {
             RGBColor[
             0.7683435692315441, 0.818955103001872, 0.9775449644682632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 183}], {
             RGBColor[
             0.7187032304337206, 0.7801756930524641, 0.9725972794122368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 186}], {
             RGBColor[
             0.711334091236848, 0.774298935906737, 0.9719447890064871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 188}], {
             RGBColor[
             0.5879638852236544, 0.6723621961171877, 0.9627242462093552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 203}], {
             RGBColor[
             0.888168810707946, 0.9119034837816515, 0.9123732567021781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 232}], {
             RGBColor[
             0.7509577026609624, 0.8053731318994537, 0.9758121037686681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 238}], {
             RGBColor[
             0.5685122820754973, 0.6555141951362553, 0.9614848072571318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 275}], {
             RGBColor[
             0.5960832901511294, 0.6793948165722092, 0.963241607511626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 280}], {
             RGBColor[
             0.6308600697230766, 0.7089664999285019, 0.9656095792468691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 297}], {
             RGBColor[
             0.7383161966353551, 0.795497491313245, 0.974552116589626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 309}], {
             RGBColor[
             0.5936529054274995, 0.677289739479289, 0.9630867455461412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 322}], {
             RGBColor[
             0.7591113318566527, 0.811742808997004, 0.9766247813268976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 325}], {
             RGBColor[
             0.7891591278276036, 0.8352163755812184, 0.9796196648166637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 339}], {
             RGBColor[
             0.8914285728135503, 0.9127657941154521, 0.823046385259298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 8}], {
             RGBColor[
             0.8512334601808822, 0.8842169893333328, 0.9639130258904394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 43}], {
             RGBColor[
             0.8076865580751931, 0.8501166936372113, 0.9813531129965264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 56}], {
             RGBColor[
             0.7177192280140652, 0.7794069828835339, 0.9724992032470712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.6553223470077194, 0.7295234259396011, 0.9670585591665167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 90}], {
             RGBColor[
             0.607103268476164, 0.6903770057429512, 0.963262576672208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 100}], {
             RGBColor[
             0.8264077048515004, 0.865044427904647, 0.9831387526886156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 121}], {
             RGBColor[
             0.628123306651815, 0.7074420196758733, 0.9649173510763323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 122}], {
             RGBColor[
             0.7287485584478164, 0.7880231796443963, 0.9735985038297544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 175}], {
             RGBColor[
             0.8171024435512557, 0.8576246651284212, 0.9822512085588935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 178}], {
             RGBColor[
             0.7931114436257914, 0.8384948930062007, 0.9799629255689842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 213}], {
             RGBColor[
             0.8682009444268324, 0.893987025557049, 0.770017681669299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 227}], {
             RGBColor[
             0.5982460757928176, 0.6831863377106274, 0.9625653060192092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 274}], {
             RGBColor[
             0.7938119937570809, 0.8390534926649642, 0.9800297446658951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 296}], {
             RGBColor[
             0.5186017211453029, 0.6129085490401642, 0.9575341772724606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 308}], {
             RGBColor[
             0.6889325047552204, 0.7568096661193742, 0.9697044739024645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 319}], {
             RGBColor[
             0.6419476973278881, 0.7186652828084121, 0.9660056577507643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 352}], {
             RGBColor[
             0.7519280887992543, 0.8061312049258951, 0.975908822790159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 373}], {
             RGBColor[
             0.6819308380388734, 0.7511253976575526, 0.9691532770506035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 56}], {
             RGBColor[
             0.7734974628655563, 0.8232576932713781, 0.977985327095654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 79}], {
             RGBColor[
             0.8842331977462708, 0.9105275662848631, 0.9888201458369752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 137}], {
             RGBColor[
             0.5576095136698938, 0.6391324612349791, 0.9620652492401724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 169}], {
             RGBColor[
             0.8564583879594447, 0.5913567658813692, 0.4638460396438093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 175}], {
             RGBColor[
             0.8728806784027467, 0.9014753755162652, 0.9877373324074763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 178}], {
             RGBColor[
             0.8488896784772826, 0.8823456033940449, 0.9854490494175671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 252}], {
             RGBColor[
             0.7764113562473433, 0.82553404892764, 0.9782757567560686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 277}], {
             RGBColor[
             0.729463284902021, 0.7882818058879437, 0.9739902622634271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 278}], {
             RGBColor[
             0.6891008546448798, 0.7555137666984348, 0.9708127839011313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 300}], {
             RGBColor[
             0.8491592778071708, 0.882560574581619, 0.9854747640423259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 314}], {
             RGBColor[
             0.8987426222813905, 0.9219006388028579, 0.9833965329868555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 319}], {
             RGBColor[
             0.6977259321793792, 0.7625159931962564, 0.9714917815993471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 352}], {
             RGBColor[
             0.8077063236507454, 0.8499819153137393, 0.9813949466387418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 379}], {
             RGBColor[
             0.8496403934070119, 0.8829442031013972, 0.9855206532777357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 65}], {
             RGBColor[
             0.5999894578068625, 0.6803170859749524, 0.9645732756649572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 67}], {
             RGBColor[
             0.698076876422522, 0.7628150344330908, 0.9715031471220115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 68}], {
             RGBColor[
             0.6110678452259142, 0.6899126283413931, 0.9652791807150658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 96}], {
             RGBColor[
             0.7301741308534453, 0.7888730315449484, 0.9740299605669309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 173}], {
             RGBColor[
             0.6934214132038616, 0.7590355196659544, 0.9711366520039149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[
             0.8199580558613667, 0.8595372798433251, 0.9826202728083606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 201}], {
             RGBColor[
             0.8848754396971628, 0.911039672583311, 0.9888814034475875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 223}], {
             RGBColor[
             0.6684657130594618, 0.7387753580472508, 0.969172047872806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 250}], {
             RGBColor[
             0.7691093674231098, 0.8198138979710131, 0.9775521507528453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 387}], {
             RGBColor[
             0.7084183232199694, 0.7712106868201277, 0.9723172636958743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 43}], {
             RGBColor[
             0.9163044242354418, 0.9354774697432893, 0.9702854985461282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 56}], {
             RGBColor[
             0.826337094174314, 0.8647677589896119, 0.9614315887966729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 59}], {
             RGBColor[
             0.7639402131679681, 0.814884202045679, 0.9559909447161186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 100}], {
             RGBColor[
             0.9350255710117491, 0.9504052040107249, 0.9720711382382174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 121}], {
             RGBColor[
             0.7367411728120639, 0.7928027957819512, 0.953849736625934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 175}], {
             RGBColor[
             0.9257203097115044, 0.9429854412344991, 0.9711835941084952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 213}], {
             RGBColor[
             0.9768188105870811, 0.979347801663127, 0.7589500672189008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 227}], {
             RGBColor[
             0.7068639419530663, 0.7685471138167054, 0.9514976915688109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 237}], {
             RGBColor[
             0.7796635963128269, 0.827649152813014, 0.957228747033932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 296}], {
             RGBColor[
             0.6272195873055516, 0.6982693251462422, 0.9464665628220623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 308}], {
             RGBColor[
             0.7975503709154692, 0.8421704422254521, 0.9586368594520663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 352}], {
             RGBColor[
             0.860545954959503, 0.891491981031973, 0.9648412083397608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 373}], {
             RGBColor[
             0.7905487041991222, 0.8364861737636305, 0.9580856626002052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 39}], {
             RGBColor[
             0.60905230005129, 0.6909121143315335, 0.9639476973122085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.5343069290261735, 0.6323611007963829, 0.95660673366296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 150}], {
             RGBColor[
             0.7024184606312946, 0.7642107037687453, 0.9438966301246414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 192}], {
             RGBColor[
             0.3976003952677631, 0.5188032112291769, 0.9465557234956052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 283}], {
             RGBColor[
             0.5773354836385499, 0.6661346962931683, 0.9607864614626876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 294}], {
             RGBColor[
             0.43426892437178477`, 0.5505636481252196, 0.9488922097454062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 320}], {
             RGBColor[
             0.6218194523136256, 0.7008859107128211, 0.9652202077338969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 347}], {
             RGBColor[
             0.5365751344751415, 0.6342025321613461, 0.9567852951046131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 381}], {
             RGBColor[
             0.43752742135565803`, 0.5533859944358303, 0.949099838291843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 384}], {
             RGBColor[
             0.47000141083400265`, 0.5801549841973972, 0.9515443677119976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.6829622641195379, 0.7522545785264199, 0.9690349539083591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 37}], {
             RGBColor[
             0.4857475528256592, 0.588606413137615, 0.9540436728290641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 62}], {
             RGBColor[
             0.7552645414688695, 0.8089295921147494, 0.976190438216071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 87}], {
             RGBColor[
             0.6469717958558506, 0.7239054749663686, 0.9656071158628663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 155}], {
             RGBColor[
             0.5543848843064937, 0.6484311259495374, 0.9584034703946827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 170}], {
             RGBColor[
             0.7213903249690352, 0.7822748717261268, 0.972865103883191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 216}], {
             RGBColor[
             0.6222684407196544, 0.7038501783933379, 0.9636623772551736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 256}], {
             RGBColor[
             0.5962165281162086, 0.6827000621165723, 0.9616114752637299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 261}], {
             RGBColor[
             0.5171600450143927, 0.6161888411295434, 0.9560315365516229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 298}], {
             RGBColor[
             0.5795669781870384, 0.6691832074303952, 0.9603007617039947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 311}], {
             RGBColor[
             0.5923778292036143, 0.6795836334079128, 0.9613092788237131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 313}], {
             RGBColor[
             0.7707924626690499, 0.8213111349855806, 0.977671505202083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 361}], {
             RGBColor[
             0.5171600450143927, 0.6161888411295434, 0.9560315365516229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 396}], {
             RGBColor[
             0.6459650353171276, 0.7230881414069877, 0.9655278599853727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 34}], {
             RGBColor[
             0.524871134278803, 0.6251530578394976, 0.9557389248381947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 35}], {
             RGBColor[
             0.7755390144895482, 0.7801321994743267, 0.6334685913734734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 85}], {
             RGBColor[
             0.7691924442178586, 0.8195027814485876, 0.9659147856325907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 86}], {
             RGBColor[
             0.707745998009659, 0.7708529896898101, 0.9720478053383312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 91}], {
             RGBColor[
             0.5754148897652211, 0.6661867555136083, 0.9597179144179624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 93}], {
             RGBColor[
             0.6990688259420076, 0.76402390450988, 0.9711963238234447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 95}], {
             RGBColor[
             0.6981259257798161, 0.7632873037368693, 0.9711023443471805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 125}], {
             RGBColor[
             0.5588446593244141, 0.6527342959613865, 0.9584134451789079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 162}], {
             RGBColor[
             0.6362192800390178, 0.7149253615762239, 0.964932068450234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 211}], {
             RGBColor[
             0.6346045682405966, 0.7136639364470331, 0.9647711290685071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 214}], {
             RGBColor[
             0.5153789826163304, 0.6171256648490879, 0.9550804265331234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 248}], {
             RGBColor[
             0.5304180247005148, 0.629656273368409, 0.9561755963711209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 263}], {
             RGBColor[
             0.7756995048170303, 0.824355736589116, 0.9549000293514036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 312}], {
             RGBColor[
             0.5655814011034277, 0.6582034864243484, 0.9589437861692501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.5541945745834937, 0.6433433792312052, 0.9604749528608516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 17}], {
             RGBColor[
             0.8887538297593549, 0.9107284401881485, 0.8269587977753559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 22}], {
             RGBColor[
             0.7321940604122339, 0.790714831965784, 0.9739419192655211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 47}], {
             RGBColor[
             0.7551388528045335, 0.8086394781695295, 0.9762288417399096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 106}], {
             RGBColor[
             0.7073338659359898, 0.7711344974919965, 0.9715730438111845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 107}], {
             RGBColor[
             0.8835404094718571, 0.908991936406996, 0.9438431253133389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 118}], {
             RGBColor[
             0.8600882153882948, 0.8915307391598665, 0.9848586438629936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 158}], {
             RGBColor[
             0.7408258560622545, 0.7974580563316569, 0.9748022559871986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 209}], {
             RGBColor[
             0.7331575161944788, 0.7914674909454089, 0.9740379475338892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 241}], {
             RGBColor[
             0.798093759397242, 0.8421961776691349, 0.9805101853926461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 270}], {
             RGBColor[
             0.7583849534017231, 0.8111753566273323, 0.9765523827109028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 310}], {
             RGBColor[
             0.8222922134541168, 0.861438764139691, 0.9828322150123483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 323}], {
             RGBColor[
             0.7472698955881641, 0.8024921889858119, 0.975444537624168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 324}], {
             RGBColor[
             0.6198757776270971, 0.7001320814608583, 0.964688022729975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 346}], {
             RGBColor[
             0.7363025192589423, 0.7939243912422764, 0.9743514120476302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 390}], {
             RGBColor[
             0.8745056988301501, 0.9022832747043397, 0.9604536050778467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 66}], {
             RGBColor[
             0.8046096260050903, 0.8475981559090588, 0.9810769015366105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 123}], {
             RGBColor[
             0.8721646870983394, 0.8969994841144188, 0.7636809863037877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 131}], {
             RGBColor[
             0.8105628644376153, 0.8523451066388017, 0.9816447267328234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[
             0.7496079450421292, 0.8043186909890834, 0.975677572543425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 188}], {
             RGBColor[
             0.5692282610342395, 0.6577257841043992, 0.9608568542845168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 203}], {
             RGBColor[
             0.8694331865185311, 0.897267071768863, 0.9105058647773399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 232}], {
             RGBColor[
             0.7322220784715476, 0.7907367198866652, 0.9739447118438298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 275}], {
             RGBColor[
             0.5773476659617145, 0.6647584045594206, 0.9613742155867877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 280}], {
             RGBColor[
             0.6121244455336619, 0.6943300879157134, 0.9637421873220309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 297}], {
             RGBColor[
             0.7195805724459403, 0.7808610793004565, 0.9726847246647877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 309}], {
             RGBColor[
             0.5749172812380847, 0.6626533274665005, 0.961219353621303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 322}], {
             RGBColor[
             0.7403757076672379, 0.7971063969842154, 0.9747573894020592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 325}], {
             RGBColor[
             0.7704235036381888, 0.8205799635684299, 0.9777522728918254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 339}], {
             RGBColor[
             0.8726929486241355, 0.8981293821026635, 0.8211789933344598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 29}], {
             RGBColor[
             0.787785780414882, 0.8341435061445734, 0.9794827823812249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 62}], {
             RGBColor[
             0.8275967219172837, 0.8654360412259827, 0.9833998339805115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 119}], {
             RGBColor[
             0.7800297513848422, 0.8280844373183024, 0.9787097338917227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 126}], {
             RGBColor[
             0.5846263866767547, 0.6684807452484668, 0.9629308853713083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 127}], {
             RGBColor[
             0.7507641369560262, 0.8052219168996037, 0.9757928109481744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 129}], {
             RGBColor[
             0.70979641311368, 0.7726932559686446, 0.9720680414255924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 196}], {
             RGBColor[
             0.6148790353326674, 0.6946840689718852, 0.9648585573922963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 235}], {
             RGBColor[
             0.6099900874398774, 0.6904495080328164, 0.9645470379556946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 317}], {
             RGBColor[
             0.8332445761284899, 0.86993948686708, 0.9839385313570752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 326}], {
             RGBColor[
             0.5489856411281837, 0.6355543948047735, 0.9607351734992997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 327}], {
             RGBColor[
             0.7070924217077339, 0.7704980339318728, 0.9718551733170695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 336}], {
             RGBColor[
             0.5873262610742847, 0.6708192407519744, 0.9631029189805138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 396}], {
             RGBColor[
             0.7182972157655416, 0.7795945905182211, 0.9727372557498131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 33}], {
             RGBColor[
             0.7856666498758207, 0.8329101363076248, 0.979159551960568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 37}], {
             RGBColor[
             0.5019101064285043, 0.6012327228521146, 0.9556546051245449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.7714270950717147, 0.8215559018292491, 0.9778013705115518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 92}], {
             RGBColor[
             0.7764056453605941, 0.8255256626904539, 0.9782762290825093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 256}], {
             RGBColor[
             0.6123790817190539, 0.695326371831072, 0.9632224075592107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 311}], {
             RGBColor[
             0.6085403828064595, 0.6922099431224126, 0.9629202111191939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 313}], {
             RGBColor[
             0.7869550162718951, 0.8339374447000804, 0.9792824374975639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 361}], {
             RGBColor[
             0.533322598617238, 0.6288151508440432, 0.9576424688471037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 386}], {
             RGBColor[
             0.613566249215801, 0.6962901678862177, 0.9633158657332925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 69}], {
             RGBColor[
             0.44402717157038507`, 0.5560545442394094, 0.9503321869852381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 106}], {
             RGBColor[
             0.47881664908449867`, 0.5842982093334685, 0.9530709420932044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 107}], {
             RGBColor[
             0.655023192620366, 0.7221556482484681, 0.9253410235953587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 190}], {
             RGBColor[
             0.3715720834428703, 0.49625879574744525`, 0.9448972224820554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 212}], {
             RGBColor[
             0.4687514219989411, 0.5761268045521, 0.9522785705468877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 241}], {
             RGBColor[
             0.569576542545751, 0.655359889510607, 0.9620080836746661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 268}], {
             RGBColor[
             0.5769128658444809, 0.6611570706249645, 0.9627217882096544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 270}], {
             RGBColor[
             0.529867736550232, 0.6243390684688044, 0.9580502809929227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 274}], {
             RGBColor[
             0.5853428756127654, 0.6678789315876754, 0.9635258500669119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 295}], {
             RGBColor[
             0.3505397572034243, 0.47804165187429093`, 0.9435570612522338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 310}], {
             RGBColor[
             0.5937749966026258, 0.6746024759811631, 0.9643301132943681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 324}], {
             RGBColor[
             0.391358560775606, 0.5132957933023304, 0.9461859210119948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 351}], {
             RGBColor[
             0.45628824824324704`, 0.5660086386376482, 0.9512974238547296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 373}], {
             RGBColor[
             0.47346171989455804`, 0.5799508365802638, 0.9526493824516203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 380}], {
             RGBColor[
             0.5913936013847991, 0.6727036160757193, 0.9641029736925952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 390}], {
             RGBColor[
             0.645988481978659, 0.7154469865458117, 0.9419515033598667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 22}], {
             RGBColor[
             0.8382360987366039, 0.8712636047641993, 0.8219236624620453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 48}], {
             RGBColor[
             0.682286087467952, 0.7429902986547541, 0.8098616690787598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 61}], {
             RGBColor[
             0.9944822631443075, 0.9906064437314732, 0.6408065786616468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 118}], {
             RGBColor[
             0.9661302537126648, 0.9720795119582818, 0.8328403870595178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 158}], {
             RGBColor[
             0.8468678943866246, 0.8780068291300722, 0.8227839991837228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 164}], {
             RGBColor[
             0.9895524355215759, 0.9895282983585629, 0.7923222495701127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 173}], {
             RGBColor[
             0.7647095937991981, 0.8121737670657388, 0.8157235967776368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 209}], {
             RGBColor[
             0.8391995545188489, 0.8720162637438242, 0.8220196907304134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 241}], {
             RGBColor[
             0.904135797721612, 0.9227449504675502, 0.8284919285891703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 287}], {
             RGBColor[
             0.703857535163733, 0.7616744024363535, 0.8112361826510528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 323}], {
             RGBColor[
             0.8533119339125341, 0.8830409617842272, 0.8234262808206922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 346}], {
             RGBColor[
             0.8423445575833123, 0.8744731640406918, 0.8223331552441544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 354}], {
             RGBColor[
             0.935229713057472, 0.947485790589659, 0.8314716534613129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 371}], {
             RGBColor[
             0.7889471347539425, 0.8318508947015772, 0.8176316647866324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 388}], {
             RGBColor[
             0.9106274876725993, 0.9278686438773792, 0.829125071241438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 389}], {
             RGBColor[
             0.8587067546665224, 0.8872554367593991, 0.8239639861359835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 45}], {
             RGBColor[
             0.6103774045089182, 0.6914656837043391, 0.9642836124923428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 74}], {
             RGBColor[
             0.5325740441587834, 0.6204673101759673, 0.9594581948258788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 86}], {
             RGBColor[
             0.8108288981451236, 0.8521953772613499, 0.9817661271023633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 91}], {
             RGBColor[
             0.6784977899006858, 0.7475291430851481, 0.9694362361819944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 112}], {
             RGBColor[
             0.7327882729878425, 0.7911790353460324, 0.9740011448218255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 141}], {
             RGBColor[
             0.7176153195459527, 0.7792865158758042, 0.9725157114079024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 148}], {
             RGBColor[
             0.5953331585765234, 0.6784351140234852, 0.9633250064446349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 179}], {
             RGBColor[
             0.7928083917603201, 0.8380672083008897, 0.9799833893411665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 232}], {
             RGBColor[
             0.754606966593679, 0.8082239646191249, 0.976175828293171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 257}], {
             RGBColor[
             0.699547238159564, 0.7646180334485431, 0.9710933258556029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 279}], {
             RGBColor[
             0.8687839040548326, 0.8982412585622219, 0.9815432051084966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 285}], {
             RGBColor[
             0.8100248882728875, 0.3694581450632273, 0.43622711701233796`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 288}], {
             RGBColor[
             0.7339038833782691, 0.7920505586619866, 0.9741123384395713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 399}], {
             RGBColor[
             0.7709030597497932, 0.8209545964475766, 0.9778000705633235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 185}], {
             RGBColor[
             0.6842331432399231, 0.7450116245362819, 0.8373645442386888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 198}], {
             RGBColor[
             0.47327637527587163`, 0.5810933520361331, 0.95227753540338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 205}], {
             RGBColor[
             0.6014195954777897, 0.682335638964478, 0.9643053997602684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 219}], {
             RGBColor[
             0.6820567475901174, 0.7441116290042703, 0.8734330524873613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 262}], {
             RGBColor[
             0.6695700672312475, 0.735899642570186, 0.9438550407708939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 284}], {
             RGBColor[
             0.428064832962221, 0.544388585229141, 0.948718317177113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 293}], {
             RGBColor[
             0.38720893096601017`, 0.5098026471411806, 0.9458935885791087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 331}], {
             RGBColor[
             0.6108532267834252, 0.6898577604984916, 0.965205187935702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 338}], {
             RGBColor[
             0.3722679180409021, 0.4968614927025966, 0.9449415604473397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.44238709101877904`, 0.550932818921482, 0.9506332610678112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 36}], {
             RGBColor[
             0.3975236800574279, 0.5145106808294253, 0.9471014490168443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 80}], {
             RGBColor[
             0.32208479668119916`, 0.45082094213961443`, 0.9418381996694198]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 151}], {
             RGBColor[
             0.5842114756876037, 0.6628625444724181, 0.9642210477337152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 168}], {
             RGBColor[
             0.45896194703976556`, 0.5643890337280735, 0.9519380944494815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 265}], {
             RGBColor[
             0.4225952812925188, 0.5348649361748365, 0.9490751773063721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 291}], {
             RGBColor[
             0.5192902744519257, 0.6115997251752635, 0.9578951698068685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 304}], {
             RGBColor[
             0.6100173206834115, 0.6833508569069906, 0.9636117281265455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 378}], {
             RGBColor[
             0.5867582037641814, 0.6648932363115894, 0.9644639569311502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 383}], {
             RGBColor[
             0.4198685700356304, 0.5326512691395522, 0.9488605206079574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 24}], {
             RGBColor[
             0.8347854450801866, 0.8716437281436149, 0.9762474100917911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 25}], {
             RGBColor[
             0.7895699277622366, 0.8358108451444404, 0.9795880178800647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 27}], {
             RGBColor[
             0.7857148729294482, 0.8327369290634506, 0.9792203193086653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 32}], {
             RGBColor[
             0.7988224441088428, 0.8431885505263585, 0.9804705311490228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 78}], {
             RGBColor[
             0.8467954825160509, 0.8806007943986511, 0.9559175494323071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 95}], {
             RGBColor[
             0.7661463544886467, 0.8172386221452699, 0.9773259666368304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 104}], {
             RGBColor[
             0.7039253335965348, 0.7686310877270787, 0.971124356762804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 160}], {
             RGBColor[
             0.5901529330755643, 0.6768810331114088, 0.9617469521492346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 172}], {
             RGBColor[
             0.733337822129366, 0.7916083473121188, 0.974055918744424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 208}], {
             RGBColor[
             0.6403219251191083, 0.7176104809396937, 0.9656964389779755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 217}], {
             RGBColor[
             0.8602887274577906, 0.8888102516443522, 0.8496691920523477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 230}], {
             RGBColor[
             0.8335038393582386, 0.8706879086946229, 0.978416834282743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 233}], {
             RGBColor[
             0.5879304039674309, 0.675001501349911, 0.9615927596673394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 240}], {
             RGBColor[
             0.6886057327280986, 0.7566632990953774, 0.9695974421180479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 242}], {
             RGBColor[
             0.6737914152713731, 0.7447825208286509, 0.9683312798455439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 244}], {
             RGBColor[
             0.8403008781306367, 0.8757571290819478, 0.9669112205927036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 264}], {
             RGBColor[
             0.6090941494696935, 0.6922583658722374, 0.9632380740877422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 285}], {
             RGBColor[
             0.7866499073217981, 0.3511974322878012, 0.43389731736274995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 357}], {
             RGBColor[
             0.8497062463101628, 0.8827716372703613, 0.9509903855776587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 47}], {
             RGBColor[
             0.7046211217817826, 0.7691746427455803, 0.9711937064265992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.525726318120831, 0.6229766904323897, 0.956844790568925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 96}], {
             RGBColor[
             0.644902542101661, 0.7219976707223685, 0.9656000268308181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 118}], {
             RGBColor[
             0.8095704843655438, 0.8520659037359173, 0.9798235085496831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 158}], {
             RGBColor[
             0.6903081250395036, 0.7579932209077078, 0.969767120673888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 173}], {
             RGBColor[
             0.6081498244520771, 0.6921601588433743, 0.9627067182678022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 209}], {
             RGBColor[
             0.6826397851717279, 0.7520026555214598, 0.9690028122205785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 241}], {
             RGBColor[
             0.747576028374491, 0.8027313422451857, 0.9754750500793357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 310}], {
             RGBColor[
             0.7717744824313658, 0.8219739287157419, 0.9777970796990376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 323}], {
             RGBColor[
             0.6967521645654131, 0.7630273535618628, 0.9704094023108576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 346}], {
             RGBColor[
             0.6857847882361913, 0.7544595558183272, 0.9693162767343196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 354}], {
             RGBColor[
             0.778669943710351, 0.8274721823672945, 0.9784547749514783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 388}], {
             RGBColor[
             0.7540677183254783, 0.8078550356550147, 0.9761081927316032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 75}], {
             RGBColor[
             0.8458231205264031, 0.8799004133235117, 0.9851565583826636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 120}], {
             RGBColor[
             0.8311734670655802, 0.8682191773081014, 0.9837592613576702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 132}], {
             RGBColor[
             0.7318698913406047, 0.7904691417318364, 0.9739076047592117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 160}], {
             RGBColor[
             0.6379563154725043, 0.714232951867646, 0.9665095421957726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 202}], {
             RGBColor[
             0.6920295743158277, 0.7581320593692067, 0.9707663872087928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 220}], {
             RGBColor[
             0.8174103023670776, 0.8572939609569197, 0.9824334735097404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 229}], {
             RGBColor[
             0.8984189753077483, 0.9208017452324416, 0.9542136890248816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 260}], {
             RGBColor[
             0.5892168870734098, 0.6720628199476566, 0.9633913340243363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 307}], {
             RGBColor[
             0.5942194331356836, 0.6763957739115223, 0.9637100918358465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 321}], {
             RGBColor[
             0.9070477236467862, 0.9239283339054396, 0.7407567885686984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 341}], {
             RGBColor[
             0.7719667373900495, 0.8217931026129794, 0.9779040836470898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 348}], {
             RGBColor[
             0.9033838219263994, 0.9242292057105226, 0.9334803752782681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 366}], {
             RGBColor[
             0.7408321479734415, 0.7974705247290816, 0.9748008787433228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.8951885960442405, 0.919042360343662, 0.9822117773122065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 32}], {
             RGBColor[
             0.9082961672236352, 0.92949398180657, 0.9834619891525642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 73}], {
             RGBColor[
             0.9643993425019892, 0.9729119332775611, 0.9425613076127679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.6069852958469417, 0.6793816722930396, 0.9589549533550381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 78}], {
             RGBColor[
             0.9562692056308432, 0.9669062256788625, 0.9589090074358485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 104}], {
             RGBColor[
             0.813399056711327, 0.8549365190072901, 0.9741158147663453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 112}], {
             RGBColor[
             0.8071995246760008, 0.8500933974631046, 0.9734979033509847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 141}], {
             RGBColor[
             0.7920265712341109, 0.8382008779928765, 0.9720124699370616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 172}], {
             RGBColor[
             0.8428115452441585, 0.8779137785923302, 0.9770473767479653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 208}], {
             RGBColor[
             0.7497956482339008, 0.8039159122199051, 0.9686878969815169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 240}], {
             RGBColor[
             0.798079455842891, 0.8429687303755888, 0.9725889001215893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 242}], {
             RGBColor[
             0.7832651383861653, 0.8310879521088623, 0.9713227378490854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 243}], {
             RGBColor[
             0.704767847222017, 0.7673603148791388, 0.9651431435435915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 285}], {
             RGBColor[
             0.8596323893983263, 0.4087343864746088, 0.43589162269844417`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 337}], {
             RGBColor[
             0.6491858379084845, 0.7195426740695108, 0.9615117909224891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 357}], {
             RGBColor[
             0.959179969424955, 0.9690770685505727, 0.9539818435812002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 399}], {
             RGBColor[
             0.8453143114379515, 0.8798689585646489, 0.9772968290924828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 32}], {
             RGBColor[
             0.8630806499056851, 0.8936610988073954, 0.9868025969408378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 78}], {
             RGBColor[
             0.9110536883128931, 0.9310733426796879, 0.9622496152241221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 83}], {
             RGBColor[
             0.9124141463196976, 0.9320879700336171, 0.959946714682878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 194}], {
             RGBColor[
             0.8207623691943803, 0.8601786174625663, 0.9826969889320825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 201}], {
             RGBColor[
             0.8856797530301763, 0.9116810102025521, 0.9889581195713093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 217}], {
             RGBColor[
             0.9245469332546329, 0.939282799925389, 0.8560012578441627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 223}], {
             RGBColor[
             0.6692700263924753, 0.739416695666492, 0.9692487639965278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 230}], {
             RGBColor[
             0.8977620451550807, 0.9211604569756596, 0.984748900074558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 242}], {
             RGBColor[
             0.7380496210682153, 0.7952550691096878, 0.974663345637359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 244}], {
             RGBColor[
             0.904559083927479, 0.9262296773629846, 0.9732432863845186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 245}], {
             RGBColor[
             0.6197564964722666, 0.6973829831828227, 0.9658582798787794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 328}], {
             RGBColor[
             0.7384254876076415, 0.7955602144989885, 0.974692935228187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 357}], {
             RGBColor[
             0.9139644521070049, 0.9332441855513982, 0.9573224513694738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 364}], {
             RGBColor[
             0.7962375290635126, 0.8410196259566438, 0.980252582065499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 385}], {
             RGBColor[
             0.6656089600811782, 0.7364444771058232, 0.9689605514455747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 105}], {
             RGBColor[
             0.5757511535872134, 0.6570806534243169, 0.9632680340624804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 128}], {
             RGBColor[
             0.524485556097506, 0.6166838941940898, 0.9582506232747077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 159}], {
             RGBColor[
             0.42324668456884845`, 0.536302913888048, 0.9490437026548857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 171}], {
             RGBColor[
             0.6150729949600353, 0.6882815173189867, 0.9617034039678725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 215}], {
             RGBColor[
             0.4665185192767734, 0.5713996044639365, 0.952473010777175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 218}], {
             RGBColor[
             0.35342036238411756`, 0.4786649907055033, 0.9438091428481261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 342}], {
             RGBColor[
             0.5030322436862208, 0.5999244034871805, 0.9561123575861538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 349}], {
             RGBColor[
             0.3418658236011374, 0.46865702995969105`, 0.943072897854152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 353}], {
             RGBColor[
             0.4388864297078119, 0.5489999635543479, 0.950274920682499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 32}], {
             RGBColor[
             0.8592255950728968, 0.8905871827264057, 0.9864348983694384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 73}], {
             RGBColor[
             0.9153287703512508, 0.934005134197397, 0.9455342168296421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 74}], {
             RGBColor[
             0.5579147236962032, 0.6404748732128753, 0.9619278625719122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 78}], {
             RGBColor[
             0.9071986334801048, 0.9279994265986982, 0.9618819166527226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 104}], {
             RGBColor[
             0.7643284845605887, 0.8160297199271258, 0.9770887239832196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 112}], {
             RGBColor[
             0.7581289525252624, 0.8111865983829404, 0.976470812567859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 141}], {
             RGBColor[
             0.7429559990833725, 0.7992940789127121, 0.9749853791539358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 172}], {
             RGBColor[
             0.79374097309342, 0.839006979512166, 0.9800202859648395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 208}], {
             RGBColor[
             0.7007250760831623, 0.765009113139741, 0.9716608061983911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 225}], {
             RGBColor[
             0.8970260289662746, 0.9204127148083949, 0.9791014826544602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 240}], {
             RGBColor[
             0.7490088836921525, 0.8040619312954247, 0.9755618093384635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 243}], {
             RGBColor[
             0.6556972750712786, 0.7284535157989744, 0.9681160527604658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 285}], {
             RGBColor[
             0.8269186746311674, 0.38279652042116596`, 0.4378735621763603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 337}], {
             RGBColor[
             0.6001152657577461, 0.6806358749893465, 0.9644847001393633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 357}], {
             RGBColor[
             0.9101093972742167, 0.9301702694704086, 0.9569547527980743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 399}], {
             RGBColor[
             0.796243739287213, 0.8409621594844847, 0.9802697383093569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 36}], {
             RGBColor[
             0.5590096912069814, 0.6528682762782563, 0.9584264370932353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 151}], {
             RGBColor[
             0.7456974868371572, 0.8012201399212492, 0.9755460358101062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 168}], {
             RGBColor[
             0.6204479581893191, 0.7027466291769044, 0.9632630825258723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 265}], {
             RGBColor[
             0.5840812924420723, 0.6732225316236675, 0.9604001653827631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 267}], {
             RGBColor[
             0.6665514849651415, 0.7388447982544986, 0.9678023626941491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 282}], {
             RGBColor[
             0.663214902192961, 0.7362382344339029, 0.9674698033055569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 291}], {
             RGBColor[
             0.6807762856014792, 0.7499573206240946, 0.9692201578832594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 304}], {
             RGBColor[
             0.771503331832965, 0.8217084523558216, 0.9749367162029365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 378}], {
             RGBColor[
             0.7482442149137349, 0.8032508317604203, 0.9757889450075412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 383}], {
             RGBColor[
             0.5813545811851839, 0.6710088645883832, 0.9601855086843484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.8039184309186448, 0.8469383803361692, 0.9810398032199772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 87}], {
             RGBColor[
             0.695625685305626, 0.7619142631877884, 0.9704564808667725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 119}], {
             RGBColor[
             0.7563514603862033, 0.8095867764284889, 0.9763497031311884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 127}], {
             RGBColor[
             0.7270858459573872, 0.7867242560097901, 0.9734327801876401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 129}], {
             RGBColor[
             0.6861181221150411, 0.754195595078831, 0.9697080106650582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 231}], {
             RGBColor[
             0.5796685708753138, 0.6661978190560243, 0.9617637067364733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 235}], {
             RGBColor[
             0.5863117964412384, 0.6719518471430028, 0.9621870071951604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 317}], {
             RGBColor[
             0.8095662851298511, 0.8514418259772665, 0.981578500596541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 326}], {
             RGBColor[
             0.5253073501295448, 0.61705673391496, 0.9583751427387655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 327}], {
             RGBColor[
             0.6834141307090951, 0.7520003730420592, 0.9694951425565352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 336}], {
             RGBColor[
             0.5636479700756458, 0.6523215798621609, 0.9607428882199796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 396}], {
             RGBColor[
             0.6946189247669028, 0.7610969296284076, 0.9703772249892788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 54}], {
             RGBColor[
             0.9024225589677359, 0.894136841119772, 0.6659329214579595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 63}], {
             RGBColor[
             0.7119348450363026, 0.7742099945130857, 0.9724278529922266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 224}], {
             RGBColor[
             0.8712293592466747, 0.9001586584450777, 0.9875798281122201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 297}], {
             RGBColor[
             0.7603765795642314, 0.8128304435921334, 0.9767245611896451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 318}], {
             RGBColor[
             0.618542893873754, 0.6970735538372219, 0.9654394901076058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 345}], {
             RGBColor[
             0.6630227435734689, 0.7345009470804968, 0.9685773131941409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 81}], {
             RGBColor[
             0.6019966714088635, 0.6877670433475336, 0.9618105296412245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 106}], {
             RGBColor[
             0.6259139107334271, 0.7071841356905673, 0.9636933823325885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 164}], {
             RGBColor[
             0.8020904419946431, 0.8450291637587184, 0.9364608448949925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 192}], {
             RGBColor[
             0.4892073769750167, 0.5936262461233612, 0.9536423721652336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 241}], {
             RGBColor[
             0.7166738041946794, 0.7782458158677057, 0.9726305239140501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 271}], {
             RGBColor[
             0.6118724915990961, 0.695784679078594, 0.9625879903829209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 287}], {
             RGBColor[
             0.5163955416368002, 0.617175267836509, 0.9553747779759325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 292}], {
             RGBColor[
             0.5922445102883733, 0.6798497996200678, 0.9610428037944762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 371}], {
             RGBColor[
             0.6014851412270099, 0.6873517601017327, 0.9617702601115121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 374}], {
             RGBColor[
             0.7361013628490639, 0.7936842198468219, 0.974497501271234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 382}], {
             RGBColor[
             0.7969863258423953, 0.8412419607320971, 0.9459712753443537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 384}], {
             RGBColor[
             0.5616083925412563, 0.6549780190915817, 0.9586310163816261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 389}], {
             RGBColor[
             0.6712447611395898, 0.7427563021595547, 0.9681025814608633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 78}], {
             RGBColor[
             0.9203062046594994, 0.9384510480616062, 0.9631321284930803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 104}], {
             RGBColor[
             0.7774360557399833, 0.8264813413900337, 0.9783389358235771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 172}], {
             RGBColor[
             0.8068485442728146, 0.8494586009750739, 0.9812704978051972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 194}], {
             RGBColor[
             0.8300148855409866, 0.8675563228444845, 0.9835795022010407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 208}], {
             RGBColor[
             0.7138326472625569, 0.7754607346026487, 0.9729110180387487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 217}], {
             RGBColor[
             0.9337994496012392, 0.9466605053073073, 0.8568837711131209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 223}], {
             RGBColor[
             0.6785225427390815, 0.7467944010484102, 0.970131277265486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 230}], {
             RGBColor[
             0.9070145615016871, 0.9285381623575779, 0.9856314133435161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 240}], {
             RGBColor[
             0.7621164548715471, 0.8145135527583325, 0.976812021178821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 242}], {
             RGBColor[
             0.7473021374148217, 0.802632774491606, 0.9755458589063171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 357}], {
             RGBColor[
             0.9232169684536113, 0.9406218909333164, 0.9582049646384319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 364}], {
             RGBColor[
             0.8054900454101188, 0.8483973313385621, 0.9811350953344573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 385}], {
             RGBColor[
             0.6748614764277845, 0.7438221824877413, 0.9698430647145329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 387}], {
             RGBColor[
             0.7184751528995892, 0.7792297298212871, 0.9732764930885544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 92}], {
             RGBColor[
             0.8629474775140318, 0.8935549107571592, 0.9867898948392375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 182}], {
             RGBColor[
             0.9167361000465581, 0.8909674755357555, 0.6458452532193854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 256}], {
             RGBColor[
             0.6989209138724916, 0.7633556198977773, 0.9717360733159388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 281}], {
             RGBColor[
             0.8275336145598282, 0.8656169273194882, 0.9833324597312403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 311}], {
             RGBColor[
             0.6950822149598972, 0.7602391911891179, 0.971433876875922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 35}], {
             RGBColor[
             0.7111392842206179, 0.7278495972672221, 0.6283988087027184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 85}], {
             RGBColor[
             0.7047927139489283, 0.7672201792414829, 0.9608450029618356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 86}], {
             RGBColor[
             0.6433462677407287, 0.7185703874827054, 0.9669780226675762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 91}], {
             RGBColor[
             0.5110151594962908, 0.6139041533065037, 0.9546481317472072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 93}], {
             RGBColor[
             0.6346690956730773, 0.7117413023027752, 0.9661265411526896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 95}], {
             RGBColor[
             0.6337261955108858, 0.7110047015297647, 0.9660325616764254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 125}], {
             RGBColor[
             0.49444492905548376`, 0.6004516937542819, 0.9533436625081528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 162}], {
             RGBColor[
             0.5718195497700875, 0.6626427593691193, 0.959862285779479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 211}], {
             RGBColor[
             0.5702048379716663, 0.6613813342399284, 0.959701346397752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 214}], {
             RGBColor[
             0.45097925234740005`, 0.5648430626419833, 0.9500106438623683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 248}], {
             RGBColor[
             0.4660182944315845, 0.5773736711613043, 0.9511058137003657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 263}], {
             RGBColor[
             0.7112997745481, 0.7720731343820113, 0.9498302466806484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 340}], {
             RGBColor[
             0.5682524232828106, 0.659856093046093, 0.9595067479479196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 42}], {
             RGBColor[
             0.6977143005232951, 0.7164157828381107, 0.6274897138180533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 85}], {
             RGBColor[
             0.9554605941596734, 0.922199320876312, 0.6385746694971144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 86}], {
             RGBColor[
             0.8940141479514738, 0.8735495291175346, 0.6447076892028549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 93}], {
             RGBColor[
             0.8853369758838224, 0.8667204439376044, 0.6438562076879684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 97}], {
             RGBColor[
             0.6733789533458505, 0.6953377282431215, 0.6259390870148092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 98}], {
             RGBColor[
             0.6739818985328593, 0.6958599690592022, 0.6259775061489619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 125}], {
             RGBColor[
             0.7451128092662289, 0.755430835389111, 0.6310733290434316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 162}], {
             RGBColor[
             0.8224874299808327, 0.8176219010039484, 0.6375919523147577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 211}], {
             RGBColor[
             0.8208727181824115, 0.8163604758747576, 0.637431012933031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 214}], {
             RGBColor[
             0.7016471325581453, 0.7198222042768123, 0.6277403103976471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 248}], {
             RGBColor[
             0.7166861746423296, 0.7323528127961334, 0.6288354802356446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 263}], {
             RGBColor[
             0.9619676547588452, 0.9270522760168405, 0.6275599132159273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 340}], {
             RGBColor[
             0.8189203034935557, 0.8148352346809221, 0.6372364144831983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 80}], {
             RGBColor[
             0.4387073968694015, 0.5527563994963888, 0.9496313756948438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 151}], {
             RGBColor[
             0.700834075875806, 0.7647980018291924, 0.9720142237591394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 168}], {
             RGBColor[
             0.5755845472279679, 0.6663244910848478, 0.9597312704749055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 265}], {
             RGBColor[
             0.5392178814807211, 0.6368003935316109, 0.9568683533317962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 277}], {
             RGBColor[
             0.5594503931630282, 0.653226057979572, 0.9584611307655597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 304}], {
             RGBColor[
             0.7266399208716139, 0.7852863142637648, 0.9714049041519697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 378}], {
             RGBColor[
             0.7033808039523839, 0.7668286936683636, 0.9722571329565743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 383}], {
             RGBColor[
             0.5364911702238327, 0.6345867264963265, 0.9566536966333815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 41}], {
             RGBColor[
             0.5143908778070323, 0.6109827963103963, 0.9568985717761168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 114}], {
             RGBColor[
             0.5974111767546735, 0.6764058242457143, 0.9650228110161945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 170}], {
             RGBColor[
             0.5403381672780019, 0.6312530160518216, 0.9594847550993768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 187}], {
             RGBColor[
             0.5818029163124745, 0.6639602210440481, 0.9635340812015589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 206}], {
             RGBColor[
             0.3361078873233593, 0.46516698545523827`, 0.9426511877678087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 256}], {
             RGBColor[
             0.41516437042517523`, 0.5316782064422672, 0.9482311264799157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 261}], {
             RGBColor[
             0.3361078873233593, 0.46516698545523827`, 0.9426511877678087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 311}], {
             RGBColor[
             0.4113256715125808, 0.5285617777336077, 0.9479289300398989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 361}], {
             RGBColor[
             0.3361078873233593, 0.46516698545523827`, 0.9426511877678087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 53}], {
             RGBColor[
             0.39969510930537283`, 0.5206175472451656, 0.9466891968217988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 58}], {
             RGBColor[
             0.6642745327294156, 0.7317467950330335, 0.9498498150316366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 102}], {
             RGBColor[
             0.44921695151794866`, 0.5614690292380372, 0.9504088536942918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 103}], {
             RGBColor[
             0.6478746531005579, 0.7192613778464497, 0.9687898469079746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 117}], {
             RGBColor[
             0.6047775819731938, 0.6848969431683213, 0.9646792097906371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 145}], {
             RGBColor[
             0.630019857824647, 0.7050244487489451, 0.9670868405953944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 189}], {
             RGBColor[
             0.3980731093231872, 0.519212652384686, 0.9465858444172122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 222}], {
             RGBColor[
             0.6820424208818334, 0.742380106486087, 0.7757321631785546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 254}], {
             RGBColor[
             0.4991689058956915, 0.6020222761117893, 0.9543412545229457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 303}], {
             RGBColor[
             0.39919913621579495`, 0.5201879602833056, 0.9466575938551027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 376}], {
             RGBColor[
             0.5701948027847816, 0.6577217493381442, 0.961274479147194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 150}], {
             RGBColor[
             0.8748128430672324, 0.9024899441017729, 0.9587998931544672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 237}], {
             RGBColor[
             0.6904612743858753, 0.7574559474255892, 0.9702315214849286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 251}], {
             RGBColor[
             0.6219835614805063, 0.7018626552031993, 0.9648407050828904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 283}], {
             RGBColor[
             0.7497298660744877, 0.804413936626196, 0.9756897244925136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 294}], {
             RGBColor[
             0.6066633068077225, 0.6888428884582471, 0.9637954727752323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 320}], {
             RGBColor[
             0.7942138347495633, 0.8391651510458488, 0.9801234707637227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 347}], {
             RGBColor[
             0.7089695169110792, 0.7724817724943738, 0.971688558134439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 381}], {
             RGBColor[
             0.6099218037915958, 0.6916652347688579, 0.9640031013216689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 51}], {
             RGBColor[
             0.6478648977048578, 0.7226531896798258, 0.9670293460988744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 84}], {
             RGBColor[
             0.5071886253890525, 0.6107976005348505, 0.9543468929652291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 102}], {
             RGBColor[
             0.5141837510743367, 0.616476558692985, 0.9548975748831643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 134}], {
             RGBColor[
             0.669924085748507, 0.7400477638894991, 0.9691850713283345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 163}], {
             RGBColor[
             0.5830015060765925, 0.6719814151597902, 0.9605643694042265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 167}], {
             RGBColor[
             0.5682073647534693, 0.6603353620137666, 0.9591505116470032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 174}], {
             RGBColor[
             0.5244819752496493, 0.6248371210082161, 0.955708288813883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 183}], {
             RGBColor[
             0.5745590532928821, 0.665386106880138, 0.9597229046099531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 189}], {
             RGBColor[
             0.4630399088795752, 0.5742201818396339, 0.9510745656060847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 226}], {
             RGBColor[
             0.47066844167823996`, 0.5808276335286304, 0.951560648970369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 234}], {
             RGBColor[
             0.46784427615965063`, 0.5783814833031145, 0.9513806956408359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 246}], {
             RGBColor[
             0.36772903632270354`, 0.48490461348478037`, 0.9452490339974988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 269}], {
             RGBColor[
             0.4661539964939709, 0.5769174480126289, 0.9512729925151945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 272}], {
             RGBColor[
             0.47903294492415116`, 0.5879395507344931, 0.9521303746613762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 350}], {
             RGBColor[
             0.726042993489953, 0.7843690086508351, 0.9597524895415286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 355}], {
             RGBColor[
             0.5152614687749781, 0.6173514984729951, 0.9549824167683689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 392}], {
             RGBColor[
             0.3711520435289292, 0.4885024110897156, 0.9454439691940081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 395}], {
             RGBColor[
             0.4968181835037542, 0.6023784086292823, 0.9535304937918381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 55}], {
             RGBColor[
             0.7990219474425098, 0.8433575332099652, 0.9804869317006655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 83}], {
             RGBColor[
             0.8475432597798778, 0.8811367908996199, 0.95355358260043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.7888864167391221, 0.8352757361487356, 0.9795201957340813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 135}], {
             RGBColor[
             0.5614349466322691, 0.6521045103189779, 0.9598824657394931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 156}], {
             RGBColor[
             0.6564780381405801, 0.7307455122902637, 0.9669554735585956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 165}], {
             RGBColor[
             0.8456606498476329, 0.8797327434946427, 0.9567403501524115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 187}], {
             RGBColor[
             0.7914983989848812, 0.8373584598911347, 0.9797693289324259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 206}], {
             RGBColor[
             0.545803369995766, 0.6385652243023248, 0.9588864354986756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 245}], {
             RGBColor[
             0.5548856099324466, 0.6464318040488255, 0.9594651477963314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 256}], {
             RGBColor[
             0.6248598530975819, 0.7050764452893536, 0.9644663742107826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 311}], {
             RGBColor[
             0.6210211541849875, 0.7019600165806943, 0.9641641777707658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 328}], {
             RGBColor[
             0.6735546010678215, 0.7446090353649915, 0.968299803145739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 386}], {
             RGBColor[
             0.626047020594329, 0.7060402413444994, 0.9645598323848644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 400}], {
             RGBColor[
             0.7713608655353195, 0.8213122378066826, 0.9778457003655865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 45}], {
             RGBColor[
             0.42946979040720046`, 0.5464068794965833, 0.9485864131728905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 93}], {
             RGBColor[
             0.6212441119757544, 0.7003074878736639, 0.9652174462680245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 98}], {
             RGBColor[
             0.40988903462479126`, 0.5294470129952618, 0.9473387447290179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 125}], {
             RGBColor[
             0.4810199453581609, 0.5890178793251706, 0.9524345676234878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 139}], {
             RGBColor[
             0.4077216598290207, 0.52756974188259, 0.9472006415235656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 148}], {
             RGBColor[
             0.4144255444748056, 0.5333763098157294, 0.9476278071251827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 204}], {
             RGBColor[
             0.4220899039241341, 0.540014792748831, 0.948116173331967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 248}], {
             RGBColor[
             0.4525933107342617, 0.5659398567321929, 0.9501967188157007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 275}], {
             RGBColor[
             0.4188249399821281, 0.5371868450841246, 0.9479081327166765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 276}], {
             RGBColor[
             0.3513257056938105, 0.47505038305925795`, 0.9437415917579957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 288}], {
             RGBColor[
             0.5529962692765513, 0.6469917544542307, 0.9584151391201191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 290}], {
             RGBColor[
             0.6897864517556356, 0.754607049899183, 0.9626126001073643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 318}], {
             RGBColor[
             0.41922416077587654`, 0.537532630070249, 0.9479335707126371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 56}], {
             RGBColor[
             0.7827901920686248, 0.8306674632934903, 0.9788716759027598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 59}], {
             RGBColor[
             0.7203933110622789, 0.7807839063495574, 0.9734310318222055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[
             0.6721742325307236, 0.7416374861529077, 0.9696350493278968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 121}], {
             RGBColor[
             0.6931942707063745, 0.7587025000858297, 0.971289823732021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 122}], {
             RGBColor[
             0.7938195225023759, 0.8392836600543527, 0.9799709764854432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 175}], {
             RGBColor[
             0.8821734076058152, 0.9088851455383775, 0.9886236812145822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 213}], {
             RGBColor[
             0.9332719084813919, 0.9452475059670055, 0.7763901543249878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 227}], {
             RGBColor[
             0.6633170398473771, 0.7344468181205839, 0.9689377786748979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 237}], {
             RGBColor[
             0.7361166942071378, 0.7935488571168925, 0.9746688341400189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 274}], {
             RGBColor[
             0.8588829578116404, 0.8903139730749206, 0.9864022173215838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 296}], {
             RGBColor[
             0.5836726851998624, 0.6641690294501207, 0.9639066499281492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 308}], {
             RGBColor[
             0.75400346880978, 0.8080701465293305, 0.9760769465581534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 373}], {
             RGBColor[
             0.747001802093433, 0.802385878067509, 0.9755257497062921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 380}], {
             RGBColor[
             0.8649336835836741, 0.8951386575629645, 0.9869793409472671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 46}], {
             RGBColor[
             0.534726511938347, 0.6331540974032193, 0.9565147762689918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 65}], {
             RGBColor[
             0.44582241860266353`, 0.5581115861114548, 0.9503078498176062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 68}], {
             RGBColor[
             0.45690080602171507`, 0.5677071284778954, 0.9510137548677148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 113}], {
             RGBColor[
             0.6656892427716605, 0.7372522734469591, 0.9683447030912333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 149}], {
             RGBColor[
             0.3849797682826056, 0.49776915917598574`, 0.9467108788935128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 161}], {
             RGBColor[
             0.47344422707580475`, 0.582036208298429, 0.9520678870285085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 195}], {
             RGBColor[
             0.7068824162203291, 0.7698359795999286, 0.9723434339506052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 247}], {
             RGBColor[
             0.46017756387451236`, 0.5705452914353502, 0.9512225469805718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 249}], {
             RGBColor[
             0.5440445458705185, 0.6407188971220013, 0.9572483260332153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 250}], {
             RGBColor[
             0.6149423282189107, 0.6976083981075154, 0.9632867249054943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 266}], {
             RGBColor[
             0.7620882741951958, 0.812705724236402, 0.9377409861084236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 315}], {
             RGBColor[
             0.42988844384178226`, 0.5443103780384371, 0.9492925510357035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 316}], {
             RGBColor[
             0.756359349416349, 0.8084331015165913, 0.947438561416126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 358}], {
             RGBColor[
             0.6749588621012255, 0.7444937705189314, 0.9692686121164866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 362}], {
             RGBColor[
             0.49901388493026094`, 0.6041609779625425, 0.9537033474512521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 363}], {
             RGBColor[0.769476616609306, 0.8162242882222, 0.830887483440527]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 369}], {
             RGBColor[
             0.4878826798064354, 0.5945420703559663, 0.9529878924690819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 372}], {
             RGBColor[
             0.724630675724542, 0.7839879599649178, 0.9740362787861754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 66}], {
             RGBColor[
             0.6419352538174773, 0.7164306491561758, 0.9673462794412804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 91}], {
             RGBColor[
             0.4934385295909415, 0.5988743915998054, 0.9534744976373233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 123}], {
             RGBColor[
             0.7094903149107263, 0.7658319773615359, 0.7499503642084577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 140}], {
             RGBColor[
             0.5869335728545162, 0.6731511842362005, 0.9619469504480949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 148}], {
             RGBColor[
             0.41027389826677907`, 0.5297803625381425, 0.9473632678999637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 179}], {
             RGBColor[
             0.6077491314505757, 0.6894124568155469, 0.9640216507964954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 203}], {
             RGBColor[
             0.706758814330918, 0.7660995650159801, 0.8967752426820097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 232}], {
             RGBColor[
             0.5695477062839346, 0.6595692131337823, 0.9602140897484999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 257}], {
             RGBColor[
             0.5144879778498196, 0.6159632819632004, 0.9551315873109318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 275}], {
             RGBColor[
             0.41467329377410156`, 0.5335908978065377, 0.9476435934914578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 276}], {
             RGBColor[
             0.3471740594857839, 0.471454435781671, 0.9434770525327767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 279}], {
             RGBColor[
             0.6837246437450883, 0.7495865070768791, 0.9655814665638254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 280}], {
             RGBColor[
             0.4494500733460488, 0.5631625811628305, 0.9500115652267007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 288}], {
             RGBColor[
             0.5488446230685248, 0.6433958071766439, 0.9581505998949003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 297}], {
             RGBColor[
             0.5569062002583273, 0.6496935725475734, 0.9589541025694577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 325}], {
             RGBColor[
             0.6077491314505757, 0.6894124568155469, 0.9640216507964954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 339}], {
             RGBColor[
             0.7100185764365226, 0.7669618753497807, 0.8074483712391297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 149}], {
             RGBColor[
             0.375820851736299, 0.49033353811920566`, 0.9459898554327708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 153}], {
             RGBColor[
             0.6348145138011947, 0.7128520946781385, 0.9654592503938562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 161}], {
             RGBColor[
             0.4642853105294981, 0.5746005872416488, 0.9513468635677664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 184}], {
             RGBColor[
             0.7169950919880547, 0.7777670031409198, 0.9734605521687292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 195}], {
             RGBColor[
             0.6977234996740225, 0.7624003585431485, 0.9716224104898632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 247}], {
             RGBColor[
             0.45101864732820574`, 0.56310967037857, 0.9505015235198297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 250}], {
             RGBColor[
             0.6057834116726041, 0.6901727770507353, 0.9625657014447522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 315}], {
             RGBColor[
             0.42072952729547564`, 0.536874756981657, 0.9485715275749614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 343}], {
             RGBColor[
             0.7595103501623628, 0.8086395906178225, 0.8569781385511834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 356}], {
             RGBColor[
             0.4200061344760193, 0.5362481904802242, 0.9485254336241769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 358}], {
             RGBColor[
             0.6657999455549188, 0.7370581494621513, 0.9685475886557445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 362}], {
             RGBColor[
             0.4898549683839543, 0.5967253569057624, 0.95298232399051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 363}], {
             RGBColor[
             0.7603177000629994, 0.8087886671654198, 0.8301664599797849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 369}], {
             RGBColor[
             0.4787237632601288, 0.5871064492991862, 0.9522668690083398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 372}], {
             RGBColor[
             0.7154717591782354, 0.7765523389081376, 0.9733152553254334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.6678473344939606, 0.739922316926114, 0.9678869493052067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.7132529174318032, 0.7759178671114533, 0.9720540431482767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 173}], {
             RGBColor[
             0.631094616844377, 0.7100848050471199, 0.9649936407421907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 201}], {
             RGBColor[
             0.8225486433376781, 0.8620889579644765, 0.9827383921858633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 209}], {
             RGBColor[
             0.7055845775640276, 0.7699273017252053, 0.9712897346949672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 323}], {
             RGBColor[
             0.719696956957713, 0.7809519997656083, 0.9726963247852461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 346}], {
             RGBColor[
             0.708729580628491, 0.7723842020220728, 0.9716031992087082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 61}], {
             RGBColor[
             0.6819724825285347, 0.7423195293996636, 0.7757277067685265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 68}], {
             RGBColor[
             0.3698462452054778, 0.49476396140936796`, 0.9447872535956676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 118}], {
             RGBColor[
             0.653620473096892, 0.7237925976264721, 0.9677615151663976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 173}], {
             RGBColor[
             0.4521998131834253, 0.5638868527339291, 0.9506447248845167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 176}], {
             RGBColor[
             0.4870870967992743, 0.5922099212274918, 0.953391179647087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 209}], {
             RGBColor[
             0.526689773903076, 0.6237293494120146, 0.956940818837293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 344}], {
             RGBColor[
             0.5694054704767325, 0.6570991762266731, 0.9611983202708752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 354}], {
             RGBColor[
             0.6227199324416992, 0.6991988762578493, 0.9663927815681927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 388}], {
             RGBColor[
             0.5981177070568264, 0.6795817295455695, 0.9640461993483177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 52}], {
             RGBColor[
             0.7316842698124587, 0.7849742986932484, 0.7813214575864709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 62}], {
             RGBColor[
             0.9189702262470114, 0.9341286629901443, 0.7981234148572122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.8106774806339925, 0.8491045458417635, 0.7875400925040075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 127}], {
             RGBColor[
             0.8421376412857539, 0.8739145386637652, 0.7905163918248752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[
             0.8011699174434077, 0.841385877732806, 0.7867916223022933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 133}], {
             RGBColor[
             0.7762864155790766, 0.8211843299303578, 0.7848327018842624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 199}], {
             RGBColor[
             0.7854699561917786, 0.8286399419135392, 0.7855556638417119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 216}], {
             RGBColor[
             0.7859741254977963, 0.8290492492687328, 0.7855953538963147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 231}], {
             RGBColor[
             0.6947203662036803, 0.7533881017099993, 0.7788473183737084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 235}], {
             RGBColor[
             0.701363591769605, 0.7591421297969778, 0.7792706188323953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 298}], {
             RGBColor[
             0.7432726629651802, 0.7943822783057901, 0.7822337383451359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 313}], {
             RGBColor[
             0.9344981474471918, 0.9465102058609756, 0.7996044818432242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 361}], {
             RGBColor[
             0.6808657297925346, 0.7413879120049384, 0.777964513192764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 393}], {
             RGBColor[
             0.747557050406163, 0.7978605370398346, 0.7825710210187183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 396}], {
             RGBColor[
             0.8096707200952693, 0.8482872122823827, 0.7874608366265139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.6029522903666169, 0.6885428578675813, 0.9618857594661263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 147}], {
             RGBColor[
             0.6111670338856642, 0.6952119567263222, 0.9625324541675427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 164}], {
             RGBColor[
             0.7835953710182283, 0.8300140319466123, 0.9350048451580517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 271}], {
             RGBColor[
             0.5933774206226812, 0.6807695472664879, 0.9611319906459801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 287}], {
             RGBColor[
             0.4979004706603854, 0.6021601360244029, 0.9539187782389917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 371}], {
             RGBColor[
             0.582990070250595, 0.6723366282896267, 0.9603142603745713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 391}], {
             RGBColor[
             0.687813647108461, 0.7551334000090492, 0.9701414292609211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 84}], {
             RGBColor[
             0.6552037404223577, 0.7286111928089891, 0.9676070866806626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 102}], {
             RGBColor[
             0.6621988661076419, 0.7342901509671238, 0.9681577685985978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 134}], {
             RGBColor[
             0.8179392007818123, 0.8578613561636377, 0.9824452650437681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 163}], {
             RGBColor[
             0.7310166211098976, 0.7897950074339288, 0.97382456311966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 167}], {
             RGBColor[
             0.7162224797867746, 0.7781489542879052, 0.9724107053624367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 174}], {
             RGBColor[
             0.6724970902829546, 0.7426507132823548, 0.9689684825293166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 183}], {
             RGBColor[
             0.7225741683261873, 0.7831996991542767, 0.9729830983253867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 189}], {
             RGBColor[
             0.6110550239128804, 0.6920337741137725, 0.9643347593215182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 222}], {
             RGBColor[
             0.8950243354715266, 0.9152012282151736, 0.7934810780828607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 226}], {
             RGBColor[
             0.6186835567115452, 0.698641225802769, 0.9648208426858025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 234}], {
             RGBColor[
             0.6158593911929559, 0.6961950755772532, 0.9646408893562695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 238}], {
             RGBColor[
             0.5723832199679639, 0.6585382012380678, 0.9618706261702816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 246}], {
             RGBColor[
             0.5157441513560087, 0.6027182057589191, 0.9585092277129323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 269}], {
             RGBColor[
             0.614169111527276, 0.6947310402867676, 0.964533186230628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 272}], {
             RGBColor[
             0.6270480599574563, 0.7057531430086318, 0.9653905683768097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 350}], {
             RGBColor[
             0.8740581085232582, 0.9021826009249738, 0.9730126832569621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 355}], {
             RGBColor[
             0.6632765838082834, 0.7351650907471337, 0.9682426104838024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 392}], {
             RGBColor[
             0.5191671585622344, 0.6063160033638543, 0.9587041629094416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 395}], {
             RGBColor[
             0.6448332985370593, 0.720192000903421, 0.9667906875072716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 89}], {
             RGBColor[
             0.6577964150940957, 0.7301553958829021, 0.9682839478112419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 128}], {
             RGBColor[
             0.6148132884395313, 0.6963628540749365, 0.964056526485574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 133}], {
             RGBColor[
             0.513759605318559, 0.6161322180608962, 0.9548641845755725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 199}], {
             RGBColor[
             0.5229431459312609, 0.6235878300440776, 0.9555871465330221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 299}], {
             RGBColor[
             0.6006002441916674, 0.685259515885368, 0.9626399030633972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 342}], {
             RGBColor[
             0.5933599760282461, 0.6796033633680272, 0.9619182607970201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 393}], {
             RGBColor[
             0.48503024014564533`, 0.5928084251703729, 0.9526025037100285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 58}], {
             RGBColor[
             0.6940534584760119, 0.7575398037824078, 0.9517473018477396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 64}], {
             RGBColor[
             0.5903070268399927, 0.6759630572565544, 0.9622084794791631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 117}], {
             RGBColor[
             0.6345565077197901, 0.7106899519176955, 0.9665766966067402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 126}], {
             RGBColor[
             0.39363136849597874`, 0.5153654397285432, 0.9463028206193796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 289}], {
             RGBColor[
             0.45576245888110467`, 0.5684001022901641, 0.9504773207084347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 303}], {
             RGBColor[
             0.42897806196239124`, 0.5459809690326798, 0.9485550806712058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 376}], {
             RGBColor[
             0.599973728531378, 0.6835147580875185, 0.963171965963297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 63}], {
             RGBColor[
             0.7820985011930566, 0.7992621613247414, 0.6544979832621394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 66}], {
             RGBColor[
             0.9155692892801353, 0.9046196870123915, 0.6671868683313807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 204}], {
             RGBColor[
             0.6915722931787656, 0.7246078833274596, 0.6476922229968484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 224}], {
             RGBColor[
             0.9413930154034285, 0.9252108252567334, 0.6696499583821329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 290}], {
             RGBColor[
             0.959268841010267, 0.9392001404778119, 0.6621886497722458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 297}], {
             RGBColor[
             0.8305402357209852, 0.8378826104037891, 0.6587946914595579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 318}], {
             RGBColor[
             0.688706550030508, 0.7221257206488776, 0.6475096203775186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 345}], {
             RGBColor[
             0.7331863997302228, 0.7595531138921525, 0.6506474434640538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 92}], {
             RGBColor[
             0.8638220037021929, 0.894252234201218, 0.986873307927763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 135}], {
             RGBColor[
             0.63637053359534, 0.7110810083714603, 0.9672355779331748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 156}], {
             RGBColor[
             0.7314136251036509, 0.7897220103427461, 0.9743085857522773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.9205962368107038, 0.9387092415471251, 0.9640934623460933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 221}], {
             RGBColor[
             0.7210552367269761, 0.7813126040184829, 0.9734931354752385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 245}], {
             RGBColor[
             0.6298211968955174, 0.7054083021013078, 0.9668182599900133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 255}], {
             RGBColor[
             0.7047364603348795, 0.7680642861908801, 0.9722084616200051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 328}], {
             RGBColor[
             0.7484901880308923, 0.8035855334174737, 0.9756529153394209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 386}], {
             RGBColor[
             0.7009826075573999, 0.7650167393969818, 0.9719129445785462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 400}], {
             RGBColor[
             0.8462964524983904, 0.8802887358591649, 0.9851988125592682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 59}], {
             RGBColor[
             0.6304259810011511, 0.7100741955958801, 0.9645771220727501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 90}], {
             RGBColor[
             0.5822069024695957, 0.6709277753992304, 0.9607811395784416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 121}], {
             RGBColor[
             0.6032269406452468, 0.6879927893321525, 0.9624359139825658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 122}], {
             RGBColor[
             0.7038521924412481, 0.7685739493006754, 0.9711170667359879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 137}], {
             RGBColor[
             0.4769349128118344, 0.575832520503414, 0.9540976882978232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 166}], {
             RGBColor[
             0.7295171648251062, 0.7886236207879599, 0.9736751113304077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 169}], {
             RGBColor[
             0.8026753207207385, 0.5491568053936592, 0.45853433234890983`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 175}], {
             RGBColor[
             0.7922060775446874, 0.8381754347847001, 0.979769771465127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 178}], {
             RGBColor[
             0.7682150776192231, 0.8190456626624798, 0.9774814884752177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 213}], {
             RGBColor[
             0.8433045784202641, 0.8745377952133282, 0.7675362445755325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 274}], {
             RGBColor[
             0.7689156277505127, 0.8196042623212433, 0.9775483075721285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 278}], {
             RGBColor[
             0.6084262537868205, 0.6922138259668698, 0.962845222958782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 296}], {
             RGBColor[
             0.4937053551387346, 0.5934593186964433, 0.955052740178694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 319}], {
             RGBColor[
             0.6170513313213198, 0.6992160524646913, 0.9635242206569978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 352}], {
             RGBColor[
             0.727031722792686, 0.7866819745821743, 0.9734273856963924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 76}], {
             RGBColor[
             0.7158346506514641, 0.776378934305176, 0.9669286993817787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.5014849483480699, 0.6061670985652582, 0.9538978786153056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 102}], {
             RGBColor[
             0.5084800740333539, 0.6118460567233928, 0.9544485605332408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 144}], {
             RGBColor[
             0.6899952107787769, 0.7559693894531594, 0.9711944806094046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 163}], {
             RGBColor[
             0.5772978290356098, 0.6673509131901978, 0.960115355054303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 167}], {
             RGBColor[
             0.5625036877124867, 0.6557048600441743, 0.9587014972970795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 174}], {
             RGBColor[
             0.5187782982086666, 0.6202066190386237, 0.9552592744639595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 186}], {
             RGBColor[
             0.5614862370550269, 0.6548788477648186, 0.9586213998542799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 188}], {
             RGBColor[
             0.43811603104183316`, 0.5529421079752694, 0.9494008570571479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 189}], {
             RGBColor[
             0.4573362318385925, 0.5695896798700415, 0.9506255512561612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 222}], {
             RGBColor[
             0.7413055433972386, 0.7927571339714425, 0.7797718700175036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 228}], {
             RGBColor[
             0.5315392524039814, 0.6305665365288156, 0.9562638635231302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 238}], {
             RGBColor[
             0.4186644278936761, 0.5360941069943368, 0.9481614181049246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 333}], {
             RGBColor[
             0.33368471429479357`, 0.45048629673325125`, 0.9431860618417969]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 368}], {
             RGBColor[
             0.6206182827705942, 0.7011931808956104, 0.9644331330299493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 117}], {
             RGBColor[
             0.8991359311438328, 0.9218191997055634, 0.969737314816578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 289}], {
             RGBColor[
             0.7203418823051475, 0.779529350078032, 0.9536379389182725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 303}], {
             RGBColor[
             0.693557485386434, 0.7571102168205477, 0.9517156988810436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 376}], {
             RGBColor[
             0.8645531519554207, 0.8946440058753864, 0.966332584173135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 90}], {
             RGBColor[
             0.51981002146325, 0.6210442184552976, 0.9553404954978871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 121}], {
             RGBColor[
             0.5408300596389009, 0.6381092323882196, 0.9569952699020113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 122}], {
             RGBColor[
             0.6414553114349022, 0.7186903923567425, 0.9656764226554335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 175}], {
             RGBColor[
             0.7298091965383415, 0.7882918778407673, 0.9743291273845726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 178}], {
             RGBColor[
             0.7058181966128774, 0.7691621057185469, 0.9720408443946633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 213}], {
             RGBColor[
             0.7809076974139182, 0.8246542382693953, 0.7620956004949782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 274}], {
             RGBColor[
             0.7065187467441667, 0.7697207053773104, 0.9721076634915742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 296}], {
             RGBColor[
             0.4313084741323887, 0.5435757617525104, 0.9496120960981396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 319}], {
             RGBColor[
             0.554654450314974, 0.6493324955207584, 0.9580835765764434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 373}], {
             RGBColor[
             0.5946375910259594, 0.6817926103698988, 0.9612311958762825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.9066962451689276, 0.9280091441617512, 0.9760596470089649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 101}], {
             RGBColor[
             0.804276720931051, 0.8476665180233396, 0.965939453062086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.8300235519867301, 0.8677801381271997, 0.9685056565639001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 259}], {
             RGBColor[
             0.6958754028837777, 0.759494876874739, 0.9573654378314866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 331}], {
             RGBColor[
             0.9003886730835564, 0.9229796573953593, 0.975458025152626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 335}], {
             RGBColor[
             0.7169759695019617, 0.7770036393376897, 0.958922006442777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 394}], {
             RGBColor[
             0.8796744698943506, 0.9065678125575852, 0.9734543960467236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 118}], {
             RGBColor[
             0.9658166487732476, 0.9714087427031912, 0.7987064247492845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 130}], {
             RGBColor[
             0.8085957499305472, 0.8473863550244413, 0.785069201567954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 147}], {
             RGBColor[
             0.8168104934495943, 0.8540554538831822, 0.7857158962693704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 164}], {
             RGBColor[
             0.9892388305821584, 0.9888575291034722, 0.7581882872598794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 173}], {
             RGBColor[
             0.7643959888597809, 0.8115029978106483, 0.7815896344674036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 176}], {
             RGBColor[
             0.7992832724756298, 0.839826066304211, 0.784336089229974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 344}], {
             RGBColor[
             0.881601646153088, 0.9047153213033923, 0.7921432298537621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 354}], {
             RGBColor[
             0.9349161081180547, 0.9468150213345683, 0.7973376911510797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 371}], {
             RGBColor[
             0.7886335298145253, 0.8311801254464867, 0.7834977024763992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 388}], {
             RGBColor[
             0.9103138827331819, 0.9271978746222886, 0.7949911089312047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 87}], {
             RGBColor[
             0.7354366268080275, 0.7932067982691978, 0.974373532466059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 119}], {
             RGBColor[
             0.7961624018886049, 0.8408793115098983, 0.9802667547304749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 127}], {
             RGBColor[
             0.766896787459789, 0.8180167910911995, 0.9773498317869267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 129}], {
             RGBColor[
             0.7259290636174427, 0.7854881301602403, 0.9736250622643448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 216}], {
             RGBColor[
             0.7107332716718313, 0.7731515016961671, 0.9724287938583662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 231}], {
             RGBColor[
             0.6194795123777154, 0.6974903541374335, 0.9656807583357598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 235}], {
             RGBColor[
             0.62612273794364, 0.7032443822244121, 0.9661040587944468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 298}], {
             RGBColor[
             0.6680318091392152, 0.7384845307332244, 0.9690671783071874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 313}], {
             RGBColor[
             0.8592572936212268, 0.8906124582884098, 0.9864379218052757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 317}], {
             RGBColor[
             0.8493772266322526, 0.8827343610586759, 0.9854955521958275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 336}], {
             RGBColor[
             0.6034589115780474, 0.6836141149435703, 0.964659939819266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 361}], {
             RGBColor[
             0.6056248759665697, 0.6854901644323727, 0.9647979531548155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 393}], {
             RGBColor[
             0.672316196580198, 0.7419627894672689, 0.9694044609807698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 396}], {
             RGBColor[
             0.7344298662693044, 0.792389464709817, 0.9742942765885654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 98}], {
             RGBColor[
             0.48888370994798935`, 0.5941132569672042, 0.9534097259281664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 139}], {
             RGBColor[
             0.4867163351522188, 0.5922359858545324, 0.9532716227227143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 204}], {
             RGBColor[
             0.5010845792473322, 0.6046810367207733, 0.9541871545311155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 224}], {
             RGBColor[
             0.7509053014719952, 0.8052839786500471, 0.9761448899164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 290}], {
             RGBColor[
             0.7687811270788336, 0.8192732938711256, 0.9686835813065129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 318}], {
             RGBColor[
             0.4982188360990746, 0.6021988740421913, 0.9540045519117857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 345}], {
             RGBColor[
             0.5426986857987894, 0.6396262672854662, 0.9571423749983209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 77}], {
             RGBColor[
             0.48840640702624993`, 0.5800211766821576, 0.9559966896078209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 94}], {
             RGBColor[
             0.6013846430894131, 0.6855579316746205, 0.9629143353910248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 254}], {
             RGBColor[
             0.6897808234303113, 0.757367786123178, 0.9698605371803101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 289}], {
             RGBColor[
             0.6165954506691282, 0.6979526035521786, 0.9640991165496959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 68}], {
             RGBColor[
             0.358837796139725, 0.4852289961293508, 0.9440858049555871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 173}], {
             RGBColor[
             0.44119136411767246`, 0.5543518874539121, 0.9499432762444362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 176}], {
             RGBColor[
             0.4760786477335215, 0.5826749559474746, 0.9526897310070065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 250}], {
             RGBColor[
             0.5168793183369207, 0.6151302657589708, 0.9563587749933666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 363}], {
             RGBColor[
             0.671413606727316, 0.7337461558736553, 0.8239595335283993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 123}], {
             RGBColor[
             0.9261074245290298, 0.9394516942987154, 0.7689747697020665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 131}], {
             RGBColor[
             0.8645056018683057, 0.8947973168230984, 0.9869385101311021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 140}], {
             RGBColor[
             0.8035506824728197, 0.8467709011733799, 0.9809713559417037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 203}], {
             RGBColor[
             0.9233759239492215, 0.9397192819531597, 0.9157996481756185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 232}], {
             RGBColor[
             0.7861648159022381, 0.8331889300709618, 0.9792384952421086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 257}], {
             RGBColor[
             0.7311050874681231, 0.78958299890038, 0.9741559928045406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 275}], {
             RGBColor[
             0.6312904033924049, 0.7072106147437172, 0.9666679989850665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 280}], {
             RGBColor[
             0.6660671829643523, 0.7367822981000101, 0.9690359707203096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 297}], {
             RGBColor[
             0.7735233098766308, 0.823313289484753, 0.9779785080630665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 318}], {
             RGBColor[
             0.6316896241861534, 0.7075563997298415, 0.966693436981027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 322}], {
             RGBColor[
             0.7943184450979284, 0.839558607168512, 0.980051172800338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 325}], {
             RGBColor[
             0.8243662410688792, 0.8630321737527265, 0.9830460562901042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 339}], {
             RGBColor[
             0.9266356860548259, 0.9405815922869601, 0.8264727767327384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 113}], {
             RGBColor[
             0.6657136515053299, 0.7372720895565528, 0.9683466246361598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 124}], {
             RGBColor[
             0.6801170520027968, 0.7485241354950722, 0.9697822209903169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 194}], {
             RGBColor[
             0.665815425390837, 0.7373515960894211, 0.9683567685059362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 208}], {
             RGBColor[
             0.5496331871124074, 0.6452560078475855, 0.9576882843436442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 210}], {
             RGBColor[
             0.7648545712952058, 0.8021534391033905, 0.6782391158777774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 249}], {
             RGBColor[
             0.5440689546041879, 0.6407387132315949, 0.9572502475781419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 266}], {
             RGBColor[
             0.7621126829288651, 0.8127255403459956, 0.9377429076533501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 293}], {
             RGBColor[
             0.4725275238537363, 0.5812408805336248, 0.9520098417518081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 316}], {
             RGBColor[
             0.7563837581500183, 0.8084529176261851, 0.9474404829610525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 385}], {
             RGBColor[
             0.510662016277635, 0.6136174557326781, 0.9546203310194283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 387}], {
             RGBColor[
             0.5542756927494397, 0.6490250030662238, 0.9580537593934498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 161}], {
             RGBColor[
             0.3864596046128662, 0.5091536183163249, 0.9458458421664895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 173}], {
             RGBColor[
             0.452269751536724, 0.5639474298203526, 0.9506491812945448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 176}], {
             RGBColor[
             0.487157035152573, 0.5922704983139153, 0.9533956360571151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 250}], {
             RGBColor[
             0.5279577057559721, 0.6247258081254115, 0.9570646800434752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 363}], {
             RGBColor[
             0.6824919941463674, 0.7433416982400959, 0.8246654385785079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 106}], {
             RGBColor[
             0.597166462922881, 0.6838456625002005, 0.9614302779355712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 107}], {
             RGBColor[
             0.7733730064587485, 0.8217031014152002, 0.9337003594377256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 150}], {
             RGBColor[
             0.7652779945280024, 0.815695265472563, 0.9487201743972525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 212}], {
             RGBColor[
             0.5871012358373235, 0.6756742577188319, 0.9606379063892544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 270}], {
             RGBColor[
             0.6482175503886144, 0.7238865216355364, 0.9664096168352894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 283}], {
             RGBColor[
             0.6401950175352575, 0.717619257996986, 0.9656100057352988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 294}], {
             RGBColor[
             0.4971284582684924, 0.6020482098290373, 0.9537157540180174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 295}], {
             RGBColor[
             0.4688895710418067, 0.5775891050410229, 0.9519163970946005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 320}], {
             RGBColor[
             0.6846789862103332, 0.7523704724166389, 0.970043752006508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 347}], {
             RGBColor[
             0.5994346683718491, 0.6856870938651638, 0.9616088393772242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 373}], {
             RGBColor[
             0.5918115337329404, 0.6794982897469959, 0.961008718293987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 380}], {
             RGBColor[
             0.7097434152231815, 0.7722510692424513, 0.972462309534962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 381}], {
             RGBColor[
             0.5003869552523657, 0.6048705561396479, 0.9539233825644542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 390}], {
             RGBColor[
             0.7643382958170415, 0.8149944397125437, 0.9503108392022334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 108}], {
             RGBColor[
             0.6346321782190169, 0.7081673316124657, 0.9677729915294204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 152}], {
             RGBColor[
             0.8789798213108108, 0.9063386665143316, 0.9883190741028165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 154}], {
             RGBColor[
             0.7652372306523942, 0.8168852622369487, 0.9773123107722086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 180}], {
             RGBColor[
             0.6671240287707431, 0.736310139472478, 0.9698433435151612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 198}], {
             RGBColor[
             0.7440786176146305, 0.7997077469882372, 0.9756466272473223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 236}], {
             RGBColor[
             0.7693432744563455, 0.8202187335721618, 0.9776355535813896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 262}], {
             RGBColor[
             0.9403723095700063, 0.95451403752229, 0.9672241326148362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 267}], {
             RGBColor[
             0.8220657063080041, 0.8616904279685953, 0.9826958982030843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 284}], {
             RGBColor[
             0.6988670753009798, 0.763002980181245, 0.9720874090210554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 286}], {
             RGBColor[
             0.6744341708688348, 0.74264181713942, 0.9703091393055467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 332}], {
             RGBColor[
             0.6817605722249386, 0.748987577758438, 0.9707759711214753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 72}], {
             RGBColor[
             0.4557791878286006, 0.5671687651789806, 0.9508226123423578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 88}], {
             RGBColor[
             0.7607370110562279, 0.8096180850745838, 0.8563488175616116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 138}], {
             RGBColor[
             0.5528185994881429, 0.6478420691153997, 0.9579390516744122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 157}], {
             RGBColor[
             0.7149332813377125, 0.7761400928758837, 0.9732441882023765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 365}], {
             RGBColor[
             0.5781776792495981, 0.6684297124792734, 0.9599354113266039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 88}], {
             RGBColor[
             0.6885824686182389, 0.7491474390228047, 0.8511914062909574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 109}], {
             RGBColor[
             0.5838133950073165, 0.6689429101176287, 0.9623854329986911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 157}], {
             RGBColor[
             0.6427787388997235, 0.7156694468241047, 0.9680867769317223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 181}], {
             RGBColor[
             0.5871670562966063, 0.6715628158055917, 0.9627196946142609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 191}], {
             RGBColor[
             0.5106145713850865, 0.6116865998560137, 0.9551394546045529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 365}], {
             RGBColor[
             0.506023136811609, 0.6079590664274943, 0.9547780000559496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 370}], {
             RGBColor[
             0.5312659458085001, 0.6278924434281078, 0.9571479943463851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 78}], {
             RGBColor[
             0.9764093799378535, 0.9818689995325973, 0.922231446953284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 99}], {
             RGBColor[
             0.931122841851818, 0.9465988980932991, 0.9470406694689003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 104}], {
             RGBColor[
             0.8335392310183374, 0.869899292861025, 0.9374382542837809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 112}], {
             RGBColor[
             0.8273396989830111, 0.8650561713168394, 0.9368203428684203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 141}], {
             RGBColor[
             0.8121667455411212, 0.8531636518466112, 0.9353349094544972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 172}], {
             RGBColor[
             0.8629517195511687, 0.8928765524460651, 0.9403698162654008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 177}], {
             RGBColor[
             0.9478511452872669, 0.9599375931750259, 0.9486362299841062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 208}], {
             RGBColor[
             0.769935822540911, 0.81887868607364, 0.9320103364989525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 225}], {
             RGBColor[
             0.9662367754240233, 0.974282287742294, 0.9394510129550215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 240}], {
             RGBColor[
             0.8182196301499012, 0.8579315042293237, 0.9359113396390248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 243}], {
             RGBColor[
             0.7249080215290273, 0.7823230887328736, 0.9284655830610271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 285}], {
             RGBColor[
             0.8730591722696666, 0.41870956904376533`, 0.4114399157100678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 337}], {
             RGBColor[
             0.6693260122154948, 0.7345054479232456, 0.9248342304399246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 399}], {
             RGBColor[
             0.8654544857449618, 0.8948317324183838, 0.9406192686099183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 86}], {
             RGBColor[
             0.5479662774852445, 0.6325422522476354, 0.9609789708912282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 91}], {
             RGBColor[
             0.41563516924080673`, 0.5278760180714337, 0.9486490799708593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 95}], {
             RGBColor[
             0.5383462052554017, 0.6249765662946947, 0.9600335099000774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 104}], {
             RGBColor[
             0.47612518436328977`, 0.5763690318765033, 0.9538319000260509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 112}], {
             RGBColor[
             0.4699256523279635, 0.5715259103323179, 0.9532139886106904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 141}], {
             RGBColor[
             0.45475269888607367`, 0.5596333908620897, 0.9517285551967672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 148}], {
             RGBColor[
             0.3324705379166444, 0.45878198900977074`, 0.9425378502334998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 172}], {
             RGBColor[
             0.5055376728961212, 0.5993462914615435, 0.9567634620076709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 179}], {
             RGBColor[
             0.529945771100441, 0.6184140832871752, 0.9591962331300314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 240}], {
             RGBColor[
             0.4608055834948537, 0.5644012432448022, 0.9523049853812948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 263}], {
             RGBColor[
             0.6159197842926158, 0.6860449991469413, 0.9438311949043006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 279}], {
             RGBColor[
             0.6059212833949537, 0.6785881335485073, 0.9607560488973614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 285}], {
             RGBColor[
             0.6347831411663014, 0.22302272838741766`, 0.42236901287158124`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 399}], {
             RGBColor[
             0.5080404390899143, 0.6013014714338623, 0.9570129143521884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 105}], {
             RGBColor[
             0.8668640333000341, 0.8966778660288428, 0.987163459426457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 132}], {
             RGBColor[
             0.7567745251077335, 0.8103274206794702, 0.9762830309605494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 202}], {
             RGBColor[
             0.7169342080829565, 0.7779903383168405, 0.9731418134101305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 215}], {
             RGBColor[
             0.7576313989895942, 0.8109968170684625, 0.9763684361411515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 218}], {
             RGBColor[
             0.6445332420969383, 0.7182622033100292, 0.9677045682121026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 229}], {
             RGBColor[
             0.9233236090748771, 0.9406600241800754, 0.9565891152262194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 260}], {
             RGBColor[
             0.6141215208405386, 0.6919210988952904, 0.9657667602256741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 329}], {
             RGBColor[
             0.726754277243862, 0.7859627128507378, 0.9739148852265755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 341}], {
             RGBColor[
             0.7968713711571783, 0.8416513815606133, 0.9802795098484276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 349}], {
             RGBColor[
             0.6329787033139581, 0.7082542425642171, 0.9669683232181285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 77}], {
             RGBColor[
             0.5844498340689124, 0.655853034994798, 0.9585746894875905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 103}], {
             RGBColor[
             0.9345299976778402, 0.9504387461704789, 0.9868871294451087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 144}], {
             RGBColor[
             0.9173874328406538, 0.9367697302918329, 0.9852520563075895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 145}], {
             RGBColor[
             0.9166752024019293, 0.9362018170729742, 0.9851841231325285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 200}], {
             RGBColor[
             0.6672774854606263, 0.7352748689572999, 0.9635711666766449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 207}], {
             RGBColor[
             0.6721738372344106, 0.739515842765956, 0.9638831578819965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 222}], {
             RGBColor[
             0.9686977654591156, 0.9735574748101161, 0.7938294457156887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 333}], {
             RGBColor[
             0.5610769363566706, 0.6312866375719247, 0.9572436375399819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 368}], {
             RGBColor[
             0.8480105048324711, 0.8819935217342839, 0.9784907087281343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 94}], {
             RGBColor[
             0.33865103148764675`, 0.46006354983820935`, 0.9430807496784213]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 103}], {
             RGBColor[
             0.5757529590334115, 0.6491125060214272, 0.9644755438527355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 145}], {
             RGBColor[
             0.5578981637575006, 0.6348755769239226, 0.9627725375401552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 200}], {
             RGBColor[
             0.3085004468161976, 0.43394862880824825`, 0.9411595810842717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 207}], {
             RGBColor[
             0.31339679858998193`, 0.4381896026169045, 0.9414715722896233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 254}], {
             RGBColor[
             0.4270472118285451, 0.5318734042867668, 0.9500269514677064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 333}], {
             RGBColor[
             0.20229989771224183`, 0.3299603974228732, 0.9348320519476087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 104}], {
             RGBColor[
             0.8254090941471912, 0.8638935852623262, 0.9537859541068614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 172}], {
             RGBColor[
             0.8548215826800227, 0.8868708448473663, 0.9567175160884813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 194}], {
             RGBColor[
             0.8779879239481946, 0.9049685667167771, 0.9590265204843249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 208}], {
             RGBColor[
             0.761805685669765, 0.8128729784749413, 0.948358036322033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 217}], {
             RGBColor[
             0.9817724880084472, 0.9840727491795997, 0.8323307893964051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 230}], {
             RGBColor[
             0.954987599908895, 0.9659504062298704, 0.9610784316268004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 233}], {
             RGBColor[
             0.7094141645180875, 0.7702639988851585, 0.9442543570113968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 240}], {
             RGBColor[
             0.8100894932787552, 0.8519257966306251, 0.9522590394621053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 242}], {
             RGBColor[
             0.7952751758220296, 0.8400450183638986, 0.9509928771896015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 244}], {
             RGBColor[
             0.9617846386812933, 0.9710196266171953, 0.9495728179367611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 264}], {
             RGBColor[
             0.73057791002035, 0.787520863407485, 0.9458996714317998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 285}], {
             RGBColor[
             0.8676390810222359, 0.4147057639779662, 0.42233838225878817`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 357}], {
             RGBColor[
             0.9711900068608192, 0.978034134805609, 0.9336519829217163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 385}], {
             RGBColor[
             0.7228345148349925, 0.7812344263600339, 0.9452900829978171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 100}], {
             RGBColor[
             0.9122470737256466, 0.932865070574411, 0.9914921343361704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 137}], {
             RGBColor[
             0.587670647692549, 0.6631023935168989, 0.9649325070391445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 175}], {
             RGBColor[
             0.902941812425402, 0.9254453077981851, 0.9906045902064482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 213}], {
             RGBColor[
             0.9540403133009786, 0.9618076682268131, 0.7783710633168538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 227}], {
             RGBColor[
             0.6840854446669639, 0.7510069803803914, 0.9709186876667639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[
             0.7595244189246761, 0.8122517381698636, 0.9768575200623991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 278}], {
             RGBColor[
             0.719161988667535, 0.7794836989803546, 0.9736800417001032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 302}], {
             RGBColor[
             0.6961654205395751, 0.7608140489904885, 0.9718696676178655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 314}], {
             RGBColor[
             0.9288037563040457, 0.9458705710847778, 0.9862637907858274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 352}], {
             RGBColor[
             0.8377674576734006, 0.8739518475956591, 0.9842622044377138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 379}], {
             RGBColor[
             0.8797015274296671, 0.906914135383317, 0.9883879110767078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 151}], {
             RGBColor[
             0.6253951924995773, 0.7011082631393817, 0.9667509744117148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 168}], {
             RGBColor[
             0.5001456638517392, 0.6026347523950368, 0.954468021127481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 265}], {
             RGBColor[
             0.4637789981044924, 0.5731106548417999, 0.9516051039843716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 304}], {
             RGBColor[
             0.6512010374953852, 0.721596575573954, 0.9661416548045451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 378}], {
             RGBColor[
             0.6279419205761552, 0.7031389549785527, 0.9669938836091497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 192}], {
             RGBColor[
             0.4713321673540207, 0.5791143456840201, 0.9522351701848185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 271}], {
             RGBColor[
             0.5939972819781001, 0.6812727786392527, 0.9611807884025056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 287}], {
             RGBColor[
             0.49852033201580426`, 0.6026633673971677, 0.9539675759955173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 292}], {
             RGBColor[
             0.5743693006673773, 0.6653378991807266, 0.959635601814061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 374}], {
             RGBColor[
             0.7182261532280679, 0.7791723194074808, 0.9730902992908189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 382}], {
             RGBColor[
             0.7791111162213993, 0.8267300602927559, 0.9445640733639386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 384}], {
             RGBColor[
             0.5437331829202603, 0.6404661186522405, 0.9572238144012108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 101}], {
             RGBColor[
             0.7586050133231761, 0.8116789844970567, 0.9764862891630148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 136}], {
             RGBColor[
             0.7843518443788551, 0.8317926046009168, 0.979052492664829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 259}], {
             RGBColor[
             0.6502036952759028, 0.7235073433484561, 0.9679122739324155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 331}], {
             RGBColor[
             0.8547169654756814, 0.8869921238690763, 0.9860048612535548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 335}], {
             RGBColor[
             0.6713042618940869, 0.7410161058114068, 0.9694688425437059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 120}], {
             RGBColor[
             0.9062143032261012, 0.9271443834410409, 0.9593553681139455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 187}], {
             RGBColor[
             0.91495529828532, 0.9341142156332718, 0.9601890920258722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 206}], {
             RGBColor[
             0.6692602692962046, 0.7353209800444619, 0.9393061985921218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 217}], {
             RGBColor[
             0.9831329460152517, 0.9850873765335291, 0.830027888855161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 220}], {
             RGBColor[
             0.8924511385275986, 0.9162191670898593, 0.9580295802660157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 230}], {
             RGBColor[
             0.9563480579156995, 0.9669650335837996, 0.9587755310855562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 244}], {
             RGBColor[
             0.9631450966880978, 0.9720342539711246, 0.9472699173955169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 245}], {
             RGBColor[
             0.6783425092328854, 0.7431875597909625, 0.9398849108897778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 321}], {
             RGBColor[
             0.9820885598073074, 0.9828535400383792, 0.7163528953249736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 328}], {
             RGBColor[
             0.7970115003682603, 0.8413647911071285, 0.9487195662391854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 364}], {
             RGBColor[
             0.8548235418241314, 0.8868242025647839, 0.9542792130764974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 102}], {
             RGBColor[
             0.5215225937918366, 0.6224345618221484, 0.9554753154649527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 163}], {
             RGBColor[
             0.5903403487940925, 0.6779394182889535, 0.9611421099860149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 167}], {
             RGBColor[
             0.5755462074709694, 0.6662933651429299, 0.9597282522287914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 174}], {
             RGBColor[
             0.5318208179671493, 0.6307951241373795, 0.9562860293956714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 183}], {
             RGBColor[
             0.5818978960103821, 0.6713441100093014, 0.9603006451917415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 189}], {
             RGBColor[
             0.4703787515970752, 0.5801781849687973, 0.951652306187873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 222}], {
             RGBColor[
             0.7543480631557213, 0.8033456390701983, 0.7807986249492155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 226}], {
             RGBColor[
             0.47800728439574, 0.5867856366577937, 0.9521383895521572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 234}], {
             RGBColor[
             0.4751831188771507, 0.5843394864322778, 0.9519584362226242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 238}], {
             RGBColor[
             0.4317069476521588, 0.5466826120930925, 0.9491881730366365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 246}], {
             RGBColor[
             0.37506787904020356`, 0.4908626166139437, 0.9458267745792872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 269}], {
             RGBColor[
             0.4734928392114709, 0.5828754511417922, 0.9518507330969828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 272}], {
             RGBColor[
             0.4863717876416511, 0.5938975538636564, 0.9527081152431645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 395}], {
             RGBColor[
             0.5041570262212541, 0.6083364117584455, 0.9541082343736264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 88}], {
             RGBColor[
             0.9713271578669251, 0.9765833308844903, 0.8638692376332215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 162}], {
             RGBColor[
             0.8161408597091432, 0.8569924829782092, 0.9700381465738751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 181}], {
             RGBColor[
             0.8699117455452925, 0.8989987076672774, 0.9753975259565251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 191}], {
             RGBColor[
             0.7933592606337727, 0.8391224917176994, 0.9678172859468169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 211}], {
             RGBColor[
             0.814526147910722, 0.8557310578490184, 0.9698772071921482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 214}], {
             RGBColor[
             0.6953005622864556, 0.7591927862510732, 0.9601865046567644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 263}], {
             RGBColor[
             0.9556210844871557, 0.9664228579911013, 0.9600061074750446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 307}], {
             RGBColor[
             0.6583172017000384, 0.7271596581488697, 0.9578299576232996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 312}], {
             RGBColor[
             0.7455029807735529, 0.8002706078263337, 0.9640498642928912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 340}], {
             RGBColor[
             0.8125737332218661, 0.8542058166551829, 0.9696826087423156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 348}], {
             RGBColor[
             0.9674815904907543, 0.97499308994787, 0.9276002410657211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 91}], {
             RGBColor[
             0.6938900232271469, 0.7596040851568162, 0.9709570122473439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 93}], {
             RGBColor[
             0.8175439594039333, 0.8574412341530877, 0.9824354216528262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 95}], {
             RGBColor[
             0.8166010592417419, 0.8567046333800772, 0.9823414421765619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 125}], {
             RGBColor[
             0.6773197927863397, 0.7461516256045944, 0.9696525430082894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 148}], {
             RGBColor[
             0.6107253919029845, 0.6905100560951533, 0.9648457825099843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 162}], {
             RGBColor[
             0.7546944135009436, 0.8083426912194318, 0.9761711662796155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 179}], {
             RGBColor[
             0.8082006250867813, 0.8501421503725577, 0.981504165406516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 214}], {
             RGBColor[
             0.633854116078256, 0.7105429944922957, 0.9663195243625049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 263}], {
             RGBColor[
             0.894174638278956, 0.9177730662323238, 0.9661391271807851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 264}], {
             RGBColor[
             0.6595488542227887, 0.7317243771070445, 0.9682535496274738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 285}], {
             RGBColor[
             0.8202863771571949, 0.3775081064443393, 0.43724096772257093`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 119}], {
             RGBColor[
             0.6878696562755859, 0.7558551943615175, 0.9696834323772703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 127}], {
             RGBColor[
             0.65860404184677, 0.7329926739428188, 0.9667665094337221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 129}], {
             RGBColor[
             0.6176363180044238, 0.7004640130118596, 0.9630417399111401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 216}], {
             RGBColor[
             0.6024405260588124, 0.6881273845477863, 0.9618454715051615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 231}], {
             RGBColor[
             0.5111867667646964, 0.6124662369890528, 0.9550974359825551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 235}], {
             RGBColor[
             0.5178299923306211, 0.6182202650760313, 0.9555207364412421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 298}], {
             RGBColor[
             0.5597390635261964, 0.6534604135848436, 0.9584838559539828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 313}], {
             RGBColor[
             0.7509645480082079, 0.8055883411400291, 0.9758545994520711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 317}], {
             RGBColor[
             0.7410844810192337, 0.7977102439102951, 0.9749122298426228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 361}], {
             RGBColor[
             0.4973321303535507, 0.6004660472839919, 0.9542146308016108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 393}], {
             RGBColor[
             0.5640234509671791, 0.6569386723188881, 0.9588211386275651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 396}], {
             RGBColor[
             0.6261371206562856, 0.7073653475614362, 0.9637109542353608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 109}], {
             RGBColor[
             0.8887712182349439, 0.911392230013232, 0.8679116382179449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 157}], {
             RGBColor[
             0.9477365621273508, 0.9581187667197077, 0.8736129821509762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 181}], {
             RGBColor[
             0.8921248795242336, 0.914012135701195, 0.8682458998335147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 191}], {
             RGBColor[
             0.8155723946127138, 0.8541359197516167, 0.8606656598238067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 365}], {
             RGBColor[
             0.8109809600392364, 0.8504083863230975, 0.8603042052752035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 370}], {
             RGBColor[
             0.8362237690361274, 0.8703417633237109, 0.862674199565639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 128}], {
             RGBColor[
             0.803452243981686, 0.8465960631340518, 0.980987534019035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 133}], {
             RGBColor[
             0.7023985608607137, 0.7663654271200115, 0.9717951921090335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 155}], {
             RGBColor[
             0.6442027143662725, 0.7188112940145861, 0.9672989372605949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 170}], {
             RGBColor[
             0.8112081550288142, 0.8526550397911754, 0.9817605707491033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 171}], {
             RGBColor[
             0.8940396828442153, 0.9181936862589487, 0.9844403147121998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 199}], {
             RGBColor[
             0.7115821014734156, 0.7738210391031929, 0.9725181540664831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 299}], {
             RGBColor[
             0.7892391997338221, 0.8354927249444832, 0.9795709105968582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 306}], {
             RGBColor[
             0.7902467430023559, 0.8362798254034745, 0.9796713330938385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 342}], {
             RGBColor[
             0.7819989315704008, 0.8298365724271425, 0.9788492683304811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 353}], {
             RGBColor[
             0.7178531175919919, 0.7789121324943098, 0.9730118314268263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 121}], {
             RGBColor[
             0.4926109811073456, 0.5989628121915698, 0.9531992874077027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 122}], {
             RGBColor[
             0.5932362329033469, 0.6795439721600927, 0.9618804401611248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.6189012052872049, 0.6995936436473773, 0.9644384847555447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 178}], {
             RGBColor[
             0.657599118081322, 0.7300156855218971, 0.9682448619003546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 190}], {
             RGBColor[
             0.4445288760427162, 0.5589541493404304, 0.949683053412409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 212}], {
             RGBColor[
             0.541708214598787, 0.6388221581450853, 0.9570644014772411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 221}], {
             RGBColor[
             0.5198719409900331, 0.6210944875165829, 0.9553453700298542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 268}], {
             RGBColor[
             0.6498696584443268, 0.7238524242179497, 0.9675076191400079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 274}], {
             RGBColor[
             0.6582996682126114, 0.7305742851806607, 0.9683116809972655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 295}], {
             RGBColor[
             0.42349654980327023`, 0.5407370054672762, 0.9483428921825874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 319}], {
             RGBColor[
             0.5064353717834187, 0.6101860753241086, 0.9542875940821347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 324}], {
             RGBColor[
             0.46431535337545193`, 0.5759911468953156, 0.9509717519423484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 351}], {
             RGBColor[
             0.529245040843093, 0.6287039922306334, 0.9560832547850832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 373}], {
             RGBColor[
             0.546418512494404, 0.642646190173249, 0.9574352133819739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 95}], {
             RGBColor[
             0.684269950997304, 0.7520383992038754, 0.9700115512561931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 112}], {
             RGBColor[
             0.6158493980698658, 0.6985877432414986, 0.963192029966806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 125}], {
             RGBColor[
             0.5449886845419019, 0.6414853914283927, 0.9573226520879206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 148}], {
             RGBColor[
             0.47839428365854664`, 0.5858438219189515, 0.9525158915896155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 179}], {
             RGBColor[
             0.6758695168423434, 0.745475916196356, 0.969174274486147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 257}], {
             RGBColor[
             0.5826083632415873, 0.6720267413440094, 0.9602842110005834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 263}], {
             RGBColor[
             0.7618435300345182, 0.8131068320561221, 0.9538092362604161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 279}], {
             RGBColor[
             0.7518450291368559, 0.8056499664576882, 0.9707340902534771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 285}], {
             RGBColor[
             0.7320656383275697, 0.30773061699353815`, 0.42902104044232503`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 288}], {
             RGBColor[
             0.6169650084602923, 0.6994592665574528, 0.9633032235845519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 135}], {
             RGBColor[
             0.6262350028919521, 0.7029992113102306, 0.9662688419665906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 165}], {
             RGBColor[
             0.910460706107316, 0.9306274444858955, 0.9631267263795091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 182}], {
             RGBColor[
             0.9074750955313314, 0.8835830019185846, 0.6449619303413268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 256}], {
             RGBColor[
             0.6896599093572648, 0.7559711462806065, 0.9708527504378801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 281}], {
             RGBColor[
             0.8182726100446016, 0.8582324537023174, 0.9824491368531817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 311}], {
             RGBColor[
             0.6858212104446705, 0.752854717571947, 0.9705505539978634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 386}], {
             RGBColor[
             0.690847076854012, 0.7569349423357521, 0.970946208611962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 98}], {
             RGBColor[
             0.5975117099853187, 0.6797516740947555, 0.9637052385989331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 125}], {
             RGBColor[
             0.6686426207186883, 0.7393225404246642, 0.9688010614934028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 148}], {
             RGBColor[
             0.6020482198353331, 0.6836809709152232, 0.9639943009950978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 162}], {
             RGBColor[
             0.7460172414332922, 0.8015136060395016, 0.9753196847647291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 214}], {
             RGBColor[
             0.6251769440106045, 0.7037139093123657, 0.9654680428476183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 248}], {
             RGBColor[
             0.640215986094789, 0.7162445178316867, 0.9665632126856158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 276}], {
             RGBColor[
             0.5389483810543378, 0.6253550441587516, 0.9601080856279107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 288}], {
             RGBColor[
             0.7406189446370788, 0.7972964155537245, 0.9747816329900343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 290}], {
             RGBColor[
             0.877409127116163, 0.9049117109986768, 0.9789790939772794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 103}], {
             RGBColor[
             0.6887311950965747, 0.7546492610138902, 0.9713931896359393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 145}], {
             RGBColor[
             0.6708763998206637, 0.7404123319163856, 0.9696901833233591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 207}], {
             RGBColor[
             0.4263750346531451, 0.5437263576093675, 0.9483892180728273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 254}], {
             RGBColor[
             0.5400254478917081, 0.6374101592792297, 0.9569445972509104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 125}], {
             RGBColor[
             0.6676997205564968, 0.7385859396516536, 0.9687070820171386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 162}], {
             RGBColor[
             0.7450743412711007, 0.800777005266491, 0.9752257052884648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 233}], {
             RGBColor[
             0.6287650364906833, 0.7069018266317775, 0.9656627742159201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 263}], {
             RGBColor[
             0.8845545660491132, 0.9102073802793831, 0.9651936661896343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 264}], {
             RGBColor[
             0.6499287819929458, 0.7241586911541038, 0.967308088636323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 285}], {
             RGBColor[
             0.813872995670633, 0.3724643158090455, 0.4366106603951371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 312}], {
             RGBColor[
             0.6744364623355104, 0.7440551301146154, 0.9692374230074808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 173}], {
             RGBColor[
             0.5713760371642552, 0.662907833023908, 0.9593999611464097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 201}], {
             RGBColor[
             0.7628300636575565, 0.8149119859412646, 0.9771447125900823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 209}], {
             RGBColor[
             0.6458659978839059, 0.7227503297019935, 0.9656960550991862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 223}], {
             RGBColor[
             0.5464203370198554, 0.6426476714052045, 0.9574353570153009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 245}], {
             RGBColor[
             0.49690680709964663`, 0.6006139589215351, 0.9540448728975525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 323}], {
             RGBColor[
             0.6599783772775912, 0.7337750277423963, 0.9671026451894651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 109}], {
             RGBColor[
             0.5844764434421797, 0.6695172093461239, 0.9624276818586499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 181}], {
             RGBColor[
             0.5878301047314695, 0.6721371150340869, 0.9627619434742196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 191}], {
             RGBColor[
             0.5112776198199497, 0.6122608990845089, 0.9551817034645116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 193}], {
             RGBColor[
             0.6889139855854749, 0.7475100776918219, 0.7059291031192954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 211}], {
             RGBColor[
             0.532444507096899, 0.6288694652158279, 0.9572416247098428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 214}], {
             RGBColor[
             0.41321892147263267`, 0.5323311936178827, 0.9475509221744591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 248}], {
             RGBColor[
             0.4282579635568171, 0.5448618021372038, 0.9486460920124565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 305}], {
             RGBColor[
             0.46728363388610844`, 0.5765445993969358, 0.9517183357365191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 334}], {
             RGBColor[
             0.4509718647116851, 0.5633019703443118, 0.9504342135151291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 340}], {
             RGBColor[
             0.5304920924080432, 0.6273442240219924, 0.9570470262600104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 360}], {
             RGBColor[
             0.6764621338116931, 0.7417410028776341, 0.9424231729481667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 370}], {
             RGBColor[
             0.5319289942433632, 0.628466742656603, 0.9571902432063439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 125}], {
             RGBColor[
             0.45728754336772515`, 0.568462065546262, 0.9509223599543963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 139}], {
             RGBColor[
             0.38398925783858495`, 0.5070139281036815, 0.9456884338544742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 193}], {
             RGBColor[
             0.6895169307724837, 0.7480323185079025, 0.705967522253448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 204}], {
             RGBColor[
             0.39835750193369834`, 0.5194589789699224, 0.9466039656628755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 248}], {
             RGBColor[
             0.4288609087438259, 0.5453840429532846, 0.9486845111466092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 276}], {
             RGBColor[
             0.3275933037033747, 0.4544945692803495, 0.9422293840889042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 290}], {
             RGBColor[
             0.6660540497651999, 0.7340512361202747, 0.9611003924382728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 318}], {
             RGBColor[
             0.39549175878544074`, 0.5169768162913404, 0.9464213630435456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 141}], {
             RGBColor[
             0.7587500705839396, 0.8118878428086145, 0.976491831793194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 169}], {
             RGBColor[
             0.8643030890164517, 0.5976119175654889, 0.46459427423367394`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 177}], {
             RGBColor[
             0.8944344703300854, 0.918661784137029, 0.989793152322803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 197}], {
             RGBColor[
             0.7457522302515258, 0.8013356104807268, 0.9754685941895684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 225}], {
             RGBColor[
             0.9128201004668418, 0.9330064787042971, 0.9806079352937184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 243}], {
             RGBColor[
             0.6714913465718457, 0.7410472796948768, 0.9696225053997238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 252}], {
             RGBColor[
             0.7881784078328536, 0.8349167764538197, 0.9793981086408655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 300}], {
             RGBColor[
             0.8609263293926812, 0.8919433021077985, 0.9865971159271228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 337}], {
             RGBColor[
             0.6159093372583132, 0.6932296388852488, 0.9659911527786214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 367}], {
             RGBColor[
             0.6628851806892275, 0.7339177533905645, 0.968984411982932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 398}], {
             RGBColor[
             0.8272577119180757, 0.8654458258189066, 0.9832931684552204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 146}], {
             RGBColor[
             0.7403821500380658, 0.7967408102534135, 0.9753164688879472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 175}], {
             RGBColor[
             0.9008945543821225, 0.9238128798058132, 0.9904093209066714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 213}], {
             RGBColor[
             0.9519930552576992, 0.9601752402344412, 0.778175794017077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 227}], {
             RGBColor[
             0.6820381866236844, 0.7493745523880195, 0.9707234183669872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 278}], {
             RGBColor[
             0.7171147306242556, 0.7778512709879828, 0.9734847724003265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 302}], {
             RGBColor[
             0.6941181624962955, 0.7591816209981166, 0.9716743983180888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 314}], {
             RGBColor[
             0.9267564982607662, 0.9442381430924058, 0.9860685214860506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 352}], {
             RGBColor[
             0.8357201996301211, 0.8723194196032873, 0.984066935137937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 377}], {
             RGBColor[
             0.6256410390405057, 0.7005413439019699, 0.9671256515413005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 136}], {
             RGBColor[
             0.6819323201409786, 0.751449978462505, 0.9689322987179501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 301}], {
             RGBColor[
             0.5945128985099608, 0.6814795751895593, 0.9613661912982807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 335}], {
             RGBColor[
             0.5688847376562103, 0.6606734796729952, 0.959348648596827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 394}], {
             RGBColor[
             0.7315832380485991, 0.7902376528928907, 0.9738810382007735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 163}], {
             RGBColor[
             0.5973354744793766, 0.683618376447088, 0.9616927919039501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 167}], {
             RGBColor[
             0.5825413331562534, 0.6719723233010645, 0.9602789341467266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 174}], {
             RGBColor[
             0.5388159436524335, 0.6364740822955139, 0.9568367113136066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 189}], {
             RGBColor[
             0.4773738772823593, 0.5858571431269317, 0.9522029881058083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 222}], {
             RGBColor[
             0.7613431888410055, 0.8090245972283328, 0.7813493068671507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 226}], {
             RGBColor[
             0.48500241008102407`, 0.5924645948159283, 0.9526890714700924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 395}], {
             RGBColor[
             0.5111521519065383, 0.6140153699165802, 0.9546589162915615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 145}], {
             RGBColor[
             0.9079783273664284, 0.9294612880996035, 0.9910849774976733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 200}], {
             RGBColor[
             0.6585806104251254, 0.7285343399839291, 0.9694720210417898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 207}], {
             RGBColor[
             0.6634769621989098, 0.7327753137925854, 0.9697840122471415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 222}], {
             RGBColor[
             0.9600008904236148, 0.9668169458367454, 0.7997303000808336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 254}], {
             RGBColor[
             0.7771273754374729, 0.8264591154624477, 0.9783393914252246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 333}], {
             RGBColor[
             0.5523800613211697, 0.6245461085985541, 0.9631444919051269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 112}], {
             RGBColor[
             0.6763394131923488, 0.7470807570465684, 0.9683748500219977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 141}], {
             RGBColor[
             0.661166459750459, 0.7351882375763401, 0.9668894166080746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 172}], {
             RGBColor[
             0.7119514337605065, 0.774901138175794, 0.9719243234189783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 208}], {
             RGBColor[
             0.6189355367502488, 0.700903271803369, 0.9635648436525298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 240}], {
             RGBColor[
             0.667219344359239, 0.7399560899590527, 0.9674658467926022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 242}], {
             RGBColor[
             0.6524050269025135, 0.7280753116923261, 0.9661996845200982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 243}], {
             RGBColor[
             0.5739077357383651, 0.6643476744626025, 0.9600200902146044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 285}], {
             RGBColor[
             0.7723923150758917, 0.3400592928635846, 0.4324762538124528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 337}], {
             RGBColor[
             0.5183257264248325, 0.6165300336529745, 0.956388737593502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 357}], {
             RGBColor[
             0.8283198579413031, 0.8660644281340366, 0.948858790252213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 399}], {
             RGBColor[
             0.7144541999542996, 0.7768563181481127, 0.9721737757634956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 114}], {
             RGBColor[
             0.8765636353406288, 0.9044120654073295, 0.9880886161280259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 171}], {
             RGBColor[
             0.9023221536793583, 0.9247979036812102, 0.9852303041743047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 202}], {
             RGBColor[
             0.7130704870894587, 0.7749095120745378, 0.9727732882525862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 218}], {
             RGBColor[
             0.6406695211034406, 0.7151813770677267, 0.9673360430545583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 229}], {
             RGBColor[
             0.9194598880813794, 0.9375791979377728, 0.9562205900686751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 261}], {
             RGBColor[
             0.6152603459093147, 0.6931732266168535, 0.9657169928796401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 349}], {
             RGBColor[
             0.6291149823204604, 0.7051734163219144, 0.9665997980605843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 353}], {
             RGBColor[
             0.7261355884271349, 0.7855163499165713, 0.9738018208889312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.8081624839728621, 0.8499467665092594, 0.9364391145456918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 150}], {
             RGBColor[
             0.8000674720421159, 0.8439389305666222, 0.9514589295052187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 158}], {
             RGBColor[
             0.6654479305632595, 0.7384128864339201, 0.9673982452195515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 241}], {
             RGBColor[
             0.7227158338982469, 0.7831510077713981, 0.973106174624999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 270}], {
             RGBColor[
             0.683007027902728, 0.7521301867295955, 0.9691483719432556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 292}], {
             RGBColor[
             0.5982865399919408, 0.6847549915237602, 0.9615184545054251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 310}], {
             RGBColor[
             0.7469142879551217, 0.8023935942419542, 0.9754282042447011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 320}], {
             RGBColor[
             0.7194684637244468, 0.7806141375106981, 0.9727825071144742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 347}], {
             RGBColor[
             0.6342241458859628, 0.713930758959223, 0.9643475944851905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 374}], {
             RGBColor[
             0.7421433925526315, 0.7985894117505143, 0.9749731519821829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 384}], {
             RGBColor[
             0.5676504222448239, 0.6598832109952741, 0.959106667092575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 389}], {
             RGBColor[
             0.6772867908431572, 0.7476614940632471, 0.9685782321718122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 390}], {
             RGBColor[
             0.799127773331155, 0.8432381048066029, 0.9530495943101995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 158}], {
             RGBColor[
             0.8416544740991267, 0.8762703253489199, 0.9396683267217059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 190}], {
             RGBColor[
             0.7009179183312336, 0.7619073529232361, 0.9282653949345427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 212}], {
             RGBColor[
             0.7980972568873045, 0.8417753617278909, 0.935646742999375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 241}], {
             RGBColor[
             0.8989223774341144, 0.9210084466863978, 0.9453762561271535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 268}], {
             RGBColor[
             0.9062587007328442, 0.9268056278007554, 0.9460899606621418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 270}], {
             RGBColor[
             0.8592135714385953, 0.8899876256445952, 0.94141845344541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 295}], {
             RGBColor[
             0.6798855920917877, 0.7436902090500819, 0.9269252337047211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 310}], {
             RGBColor[
             0.9231208314909891, 0.940251033156954, 0.9476982857468554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 324}], {
             RGBColor[
             0.7207043956639694, 0.7789443504781213, 0.9295540934644821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 346}], {
             RGBColor[
             0.8371311372958146, 0.8727366602595393, 0.9392174827821375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 351}], {
             RGBColor[
             0.7856340831316104, 0.8316571958134391, 0.934665596307217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 373}], {
             RGBColor[
             0.8028075547829214, 0.8455993937560546, 0.9360175549041077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 390}], {
             RGBColor[
             0.9753343168670224, 0.9810955437216027, 0.925319675812354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 152}], {
             RGBColor[
             0.5987104546757698, 0.6795243243282905, 0.9643467454701644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 154}], {
             RGBColor[
             0.48496786401735337`, 0.5900709200509077, 0.9533399821395564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 180}], {
             RGBColor[
             0.3868546621357021, 0.5094957972864369, 0.945871014882509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 198}], {
             RGBColor[
             0.46380925097958947`, 0.5728934048021961, 0.9516742986146702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 205}], {
             RGBColor[
             0.5919524711815075, 0.674135691730541, 0.9637021629715585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 236}], {
             RGBColor[
             0.48907390782130467`, 0.5934043913861208, 0.9536632249487375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 262}], {
             RGBColor[
             0.6601029429349654, 0.727699695336249, 0.943251803982184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 267}], {
             RGBColor[
             0.5417963396729631, 0.6348760857825543, 0.9587235695704321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 284}], {
             RGBColor[
             0.4185977086659389, 0.536188637995204, 0.9481150803884032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 286}], {
             RGBColor[
             0.39416480423379385`, 0.5158274749533789, 0.9463368106728945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 332}], {
             RGBColor[
             0.40149120558989765`, 0.5221732355723969, 0.9468036424888231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 367}], {
             RGBColor[
             0.40121350303389725`, 0.5219327035761256, 0.9467859475275175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 398}], {
             RGBColor[
             0.5655860342627455, 0.6534607760044677, 0.9610947039998059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 157}], {
             RGBColor[
             0.8429674885164284, 0.8779142378145319, 0.9848070088587098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 181}], {
             RGBColor[
             0.7873558059133112, 0.8338076067960191, 0.9794399265412485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 191}], {
             RGBColor[
             0.7108033210017914, 0.7739313908464409, 0.9718596865315403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 305}], {
             RGBColor[
             0.6668093350679503, 0.7382150911588679, 0.9683963188035478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 334}], {
             RGBColor[
             0.6504975658935268, 0.7249724621062439, 0.967112196582158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 340}], {
             RGBColor[
             0.7300177935898848, 0.7890147157839246, 0.9737250093270391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 360}], {
             RGBColor[
             0.8759878349935348, 0.9034114946395662, 0.9591011560151955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 365}], {
             RGBColor[
             0.706211886428314, 0.7702038574179215, 0.9714982319829372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 370}], {
             RGBColor[
             0.731454695425205, 0.7901372344185351, 0.9738682262733727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 227}], {
             RGBColor[
             0.6744653369907783, 0.7433361676502674, 0.9700011132086379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 237}], {
             RGBColor[
             0.7472649913505389, 0.8024382066465761, 0.975732168673759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 251}], {
             RGBColor[
             0.6787872784451698, 0.7468449144241862, 0.9703413522717208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 308}], {
             RGBColor[
             0.7651517659531811, 0.8169594960590142, 0.9771402810918932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 375}], {
             RGBColor[
             0.8489332805186968, 0.8825191617678397, 0.9854163772784044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 116}], {
             RGBColor[
             0.7832090818660996, 0.8305681544540673, 0.9790266198415618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 151}], {
             RGBColor[
             0.8519108647797915, 0.8847843928915714, 0.9857293108185285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 154}], {
             RGBColor[
             0.715936387252166, 0.7776038854931742, 0.9726020502716957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 286}], {
             RGBColor[
             0.6251333274686065, 0.7033604403956454, 0.9655988788050338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 291}], {
             RGBColor[
             0.7869896635441136, 0.8335215735944168, 0.9794034328916819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 304}], {
             RGBColor[
             0.8777167097755993, 0.9052727053261438, 0.9851199912113588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 383}], {
             RGBColor[
             0.6875679591278183, 0.7545731175587054, 0.9703687836927708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 141}], {
             RGBColor[
             0.6549669277151328, 0.7303451160321548, 0.966271505192714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 172}], {
             RGBColor[
             0.7057519017251803, 0.7700580166316086, 0.9713064120036177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 179}], {
             RGBColor[
             0.7301599999295001, 0.7891258084572402, 0.9737391831259781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 240}], {
             RGBColor[
             0.6610198123239128, 0.7351129684148672, 0.9668479353772417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 279}], {
             RGBColor[
             0.8061355122240128, 0.8492998587185725, 0.9752989988933082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 285}], {
             RGBColor[
             0.7682592937190076, 0.336830545167461, 0.43206431286887903`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 337}], {
             RGBColor[
             0.5121261943895064, 0.6116869121087891, 0.9557708261781415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 399}], {
             RGBColor[
             0.7082546679189734, 0.7720131966039272, 0.9715558643481351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 124}], {
             RGBColor[
             0.8018964575561345, 0.8451668743724381, 0.9808892028068898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 149}], {
             RGBColor[
             0.5067835825696125, 0.5944317141629454, 0.9578197822550123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 210}], {
             RGBColor[
             0.8866339768485434, 0.8987961779807565, 0.6893460976943503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 249}], {
             RGBColor[
             0.6658483601575256, 0.7373814521089609, 0.9683572293947147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 266}], {
             RGBColor[
             0.8838920884822028, 0.9093682792233615, 0.948849889469923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 293}], {
             RGBColor[
             0.594306929407074, 0.6778836194109907, 0.963116823568381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 315}], {
             RGBColor[
             0.5516922581287892, 0.6409729330253967, 0.9604014543972029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 316}], {
             RGBColor[
             0.878163163703356, 0.9050956565035511, 0.9585474647776255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 387}], {
             RGBColor[
             0.6760550983027773, 0.7456677419435898, 0.9691607412100227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 397}], {
             RGBColor[
             0.6941577482383832, 0.7603642886764006, 0.9705858481251453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 128}], {
             RGBColor[
             0.8252980378509214, 0.8640153061771025, 0.9830712053402532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 155}], {
             RGBColor[
             0.6660485082355079, 0.7362305370576367, 0.9693826085818129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 170}], {
             RGBColor[
             0.8330539488980495, 0.8700742828342262, 0.9838442420703213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 187}], {
             RGBColor[
             0.8745186979325222, 0.9027814878264526, 0.9878935681725036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 202}], {
             RGBColor[
             0.7266338101235511, 0.7857245376953271, 0.9740669701116994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 261}], {
             RGBColor[
             0.628823668943407, 0.7039882522376428, 0.9670106747387532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 306}], {
             RGBColor[
             0.8120925368715912, 0.8536990684465251, 0.9817550044150565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 353}], {
             RGBColor[
             0.7396989114612272, 0.7963313755373606, 0.9750955027480444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 122}], {
             RGBColor[
             0.8431975750551606, 0.8777328182062855, 0.9526602726800331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 166}], {
             RGBColor[
             0.8688625474390186, 0.89778248969357, 0.9552183172744528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 169}], {
             RGBColor[
             0.8955722424633468, 0.6219293846640659, 0.4462298029782732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 197}], {
             RGBColor[
             0.7926559604218686, 0.8378118111285922, 0.9479218873064672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 221}], {
             RGBColor[
             0.7698332831418467, 0.8192833335627757, 0.9461252025487624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 239}], {
             RGBColor[
             0.9304517003321657, 0.9464573850568969, 0.9612080813351596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 300}], {
             RGBColor[
             0.9078300595630239, 0.9284195027556639, 0.9590504090440217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 350}], {
             RGBColor[
             0.9618749157718376, 0.9710869551235082, 0.9494200023705056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 392}], {
             RGBColor[
             0.6069839658108138, 0.6752203575623886, 0.9351114820229851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 151}], {
             RGBColor[
             0.8188200885922898, 0.8589336270346812, 0.9824311314990435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 154}], {
             RGBColor[
             0.6828456110646643, 0.751753119636284, 0.9693038709522106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 265}], {
             RGBColor[
             0.6572038941972049, 0.7309360187370997, 0.9672852610717004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 291}], {
             RGBColor[
             0.7538988873566119, 0.8076708077375266, 0.9761052535721968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 304}], {
             RGBColor[
             0.8446259335880977, 0.8794219394692536, 0.9818218118918738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 383}], {
             RGBColor[
             0.6544771829403166, 0.7287223517018153, 0.9670706043732857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 289}], {
             RGBColor[
             0.6608449315489257, 0.7326794982133197, 0.968467333677273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 303}], {
             RGBColor[
             0.6340605346302122, 0.7102603649558354, 0.966545093640044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 376}], {
             RGBColor[
             0.8050562011991989, 0.8477941540106742, 0.9811619789321353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 158}], {
             RGBColor[
             0.8182022800155645, 0.8588091281017902, 0.9806838452713607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 164}], {
             RGBColor[
             0.9608868211505158, 0.9703305973302809, 0.9502220956577505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 173}], {
             RGBColor[
             0.7360439794281382, 0.7929760660374569, 0.9736234428652747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 209}], {
             RGBColor[
             0.8105339401477889, 0.8528185627155422, 0.9799195368180511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 241}], {
             RGBColor[
             0.875470183350552, 0.9035472494392682, 0.9863917746768082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 323}], {
             RGBColor[
             0.8246463195414742, 0.8638432607559452, 0.9813261269083301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 346}], {
             RGBColor[
             0.8136789432122522, 0.8552754630124098, 0.9802330013317921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 354}], {
             RGBColor[
             0.9065640986864121, 0.928288089561377, 0.9893714995489508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 388}], {
             RGBColor[
             0.8819618733015393, 0.9086709428490972, 0.9870249173290757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 389}], {
             RGBColor[
             0.8300411402954624, 0.8680577357311171, 0.9818638322236213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 126}], {
             RGBColor[
             0.5531920666480759, 0.6439240155323822, 0.9597978061212719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 127}], {
             RGBColor[
             0.7193298169273474, 0.7806651871835191, 0.972659731698138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 129}], {
             RGBColor[
             0.6783620930850012, 0.7481365262525599, 0.968934962175556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 196}], {
             RGBColor[
             0.5834447153039887, 0.6701273392558007, 0.9617254781422597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 231}], {
             RGBColor[
             0.5719125418452738, 0.6601387502297532, 0.960990658246971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 235}], {
             RGBColor[
             0.5785557674111985, 0.6658927783167317, 0.961413958705658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 317}], {
             RGBColor[
             0.801810256099811, 0.8453827571509955, 0.9808054521070387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 326}], {
             RGBColor[
             0.5175513210995049, 0.6109976650886889, 0.9576020942492633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 327}], {
             RGBColor[
             0.675658101679055, 0.7459413042157883, 0.9687220940670329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 336}], {
             RGBColor[
             0.5558919410456059, 0.6462625110358898, 0.9599698397304772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 396}], {
             RGBColor[
             0.6868628957368629, 0.7550378608021366, 0.9696041764997767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 132}], {
             RGBColor[
             0.7421248716469105, 0.7986461846640598, 0.9748857339355561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 160}], {
             RGBColor[
             0.6482112957788102, 0.7224099947998694, 0.967487671372117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 187}], {
             RGBColor[
             0.8501694424311047, 0.8833660524325556, 0.9855711144459414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 202}], {
             RGBColor[
             0.7022845546221336, 0.7663091023014301, 0.9717445163851373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 206}], {
             RGBColor[
             0.6044744134419895, 0.6845728168437457, 0.964688221012191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 217}], {
             RGBColor[
             0.9183470901610364, 0.9343392133328129, 0.8554099112752303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 220}], {
             RGBColor[
             0.8276652826733835, 0.8654710038891431, 0.9834116026860849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 233}], {
             RGBColor[
             0.6459887666706768, 0.7205304630383716, 0.9673334788902219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 244}], {
             RGBColor[
             0.8983592408338825, 0.9212860907704085, 0.9726519398155862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 307}], {
             RGBColor[
             0.6044744134419895, 0.6845728168437457, 0.964688221012191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 321}], {
             RGBColor[
             0.9173027039530921, 0.932105376837663, 0.7417349177450429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 341}], {
             RGBColor[
             0.7822217176963554, 0.829970145545203, 0.9788822128234342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 366}], {
             RGBColor[
             0.7510871282797474, 0.8056475676613052, 0.9757790079196672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 122}], {
             RGBColor[
             0.6142562710789978, 0.6966089860930147, 0.963535214565249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 175}], {
             RGBColor[
             0.7026101561824372, 0.7662104715770396, 0.9721879192943881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 178}], {
             RGBColor[
             0.678619156256973, 0.7470806994548191, 0.9698996363044788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.7537086570580138, 0.8025728320056675, 0.7599543924047936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 274}], {
             RGBColor[
             0.6793197063882624, 0.7476392991135827, 0.9699664554013897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 296}], {
             RGBColor[
             0.4041094337764844, 0.5214943554887828, 0.9474708880079552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 319}], {
             RGBColor[
             0.5274554099590696, 0.6272510892570307, 0.9559423684862589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 373}], {
             RGBColor[
             0.567438550670055, 0.659711204106171, 0.9590899877860981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 166}], {
             RGBColor[
             0.7405464952588572, 0.7972398175488222, 0.974774411913091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 169}], {
             RGBColor[
             0.8100282076765726, 0.5549009365675674, 0.45926719940403204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 175}], {
             RGBColor[
             0.8032354079784385, 0.8467916315455626, 0.9808690720478103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 178}], {
             RGBColor[
             0.7792444080529743, 0.8276618594233421, 0.978580789057901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 268}], {
             RGBColor[
             0.7715149484159791, 0.8214985981193947, 0.9778435462975543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 274}], {
             RGBColor[
             0.7799449581842637, 0.8282204590821056, 0.9786476081548119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 319}], {
             RGBColor[
             0.6280806617550709, 0.7078322492255535, 0.9646235212396811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 351}], {
             RGBColor[
             0.6508903308147453, 0.7263501661320784, 0.9664191819426295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 131}], {
             RGBColor[
             0.9320606629615548, 0.9441986450284583, 0.7695425948982795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 140}], {
             RGBColor[
             0.8711057435660687, 0.89617222937874, 0.763575440708881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 203}], {
             RGBColor[
             0.9909309850424706, 0.9891206101585196, 0.6984037329427958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 232}], {
             RGBColor[
             0.8537198769954871, 0.8825902582763218, 0.7618425800092858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 275}], {
             RGBColor[
             0.6988454644856541, 0.7566119429490772, 0.7492720837522437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 280}], {
             RGBColor[
             0.7336222440576012, 0.78618362630537, 0.7516400554874868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 297}], {
             RGBColor[
             0.8410783709698798, 0.872714617690113, 0.7605825928302437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 309}], {
             RGBColor[
             0.6964150797620242, 0.7545068658561571, 0.7491172217867589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 322}], {
             RGBColor[
             0.8618735061911773, 0.888959935373872, 0.7626552575675152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 325}], {
             RGBColor[
             0.8919213021621283, 0.9124335019580865, 0.7656501410572814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 339}], {
             RGBColor[
             0.994190747148075, 0.9899829204923201, 0.6090768614999158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 149}], {
             RGBColor[
             0.5211869830670794, 0.6056837601014647, 0.9592553786091693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 185}], {
             RGBColor[
             0.9057345421784537, 0.9243446427446114, 0.8560233755821183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 210}], {
             RGBColor[
             0.9010373773460103, 0.9100482239192758, 0.6907816940485073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 219}], {
             RGBColor[
             0.903558146528648, 0.9234446472125998, 0.8920918838307907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 249}], {
             RGBColor[
             0.6802517606549925, 0.7486334980474803, 0.9697928257488718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 266}], {
             RGBColor[
             0.8982954889796697, 0.920620325161881, 0.9502854858240801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 293}], {
             RGBColor[
             0.6087103299045408, 0.68913566534951, 0.9645524199225382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 315}], {
             RGBColor[
             0.5660956586262561, 0.6522249789639161, 0.9618370507513601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 316}], {
             RGBColor[
             0.8925665642008229, 0.9163477024420703, 0.9599830611317826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 338}], {
             RGBColor[
             0.5937693169794327, 0.6761945109109261, 0.9636003917907692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 387}], {
             RGBColor[
             0.6904584988002442, 0.756919787882109, 0.9705963375641797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 397}], {
             RGBColor[
             0.7085611487358501, 0.77161633461492, 0.9720214444793024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 148}], {
             RGBColor[
             0.46182405321773956`, 0.5723913623667297, 0.951211422350561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 162}], {
             RGBColor[
             0.6057930748156986, 0.6902239974910083, 0.9625368061201922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 211}], {
             RGBColor[
             0.6041783630172773, 0.6889625723618173, 0.9623758667384653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 214}], {
             RGBColor[
             0.48495277739301107`, 0.5924243007638722, 0.9526851642030816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 248}], {
             RGBColor[
             0.4999918194771955, 0.6049549092831933, 0.9537803340410791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 263}], {
             RGBColor[
             0.745273299593711, 0.7996543725039003, 0.9525047670213618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 276}], {
             RGBColor[
             0.39872421443674433`, 0.5140654356102582, 0.947325206983374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 288}], {
             RGBColor[
             0.6003947780194852, 0.6860068070052311, 0.9619987543454975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 196}], {
             RGBColor[
             0.38804135059590117`, 0.510523647185965, 0.9459466296218455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 289}], {
             RGBColor[
             0.41991979232511434`, 0.5373549860241674, 0.9481934576899125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 317}], {
             RGBColor[
             0.6064068913917235, 0.6857790650811598, 0.9650266035866244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 326}], {
             RGBColor[
             0.32214795639141736`, 0.4513939730188533, 0.9418232457288489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 327}], {
             RGBColor[
             0.4802547369709676, 0.5863376121459526, 0.9529432455466187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 336}], {
             RGBColor[
             0.3604885763375184, 0.48665881896605423`, 0.944190991210063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 376}], {
             RGBColor[
             0.5641310619753875, 0.6524696418215218, 0.9608881029447749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 129}], {
             RGBColor[
             0.6490964786561852, 0.7252740058338611, 0.9660180392320077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 216}], {
             RGBColor[
             0.6339006867105739, 0.712937377369788, 0.9648217708260292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 231}], {
             RGBColor[
             0.5426469274164578, 0.6372762298110545, 0.9580737353034228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 235}], {
             RGBColor[
             0.5492901529823826, 0.6430302578980329, 0.9584970357621099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 298}], {
             RGBColor[
             0.5911992241779578, 0.6782704064068452, 0.9614601552748504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 313}], {
             RGBColor[
             0.7824247086599694, 0.8303983339620308, 0.9788308987729388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 317}], {
             RGBColor[
             0.7725446416709951, 0.8225202367322968, 0.9778885291634904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 336}], {
             RGBColor[
             0.5266263266167899, 0.6233999906171911, 0.957052916786929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 361}], {
             RGBColor[
             0.5287922910053121, 0.6252760401059936, 0.9571909301224786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 393}], {
             RGBColor[
             0.5954836116189406, 0.6817486651408897, 0.9617974379484329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 396}], {
             RGBColor[
             0.6575972813080468, 0.7321753403834379, 0.9666872535562284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 133}], {
             RGBColor[
             0.6594154342061493, 0.7325728853120459, 0.9675677707833656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 155}], {
             RGBColor[
             0.6012195877117081, 0.6850187522066205, 0.963071515934927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 170}], {
             RGBColor[
             0.7682250283742498, 0.8188624979832098, 0.9775331494234354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 171}], {
             RGBColor[
             0.8510565561896509, 0.8844011444509831, 0.980212893386532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 199}], {
             RGBColor[
             0.6685989748188512, 0.7400284972952272, 0.9682907327408152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 261}], {
             RGBColor[
             0.5639947484196073, 0.6527764673866264, 0.9606995820918673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 299}], {
             RGBColor[
             0.7462560730792577, 0.8017001831365176, 0.9753434892711903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 306}], {
             RGBColor[
             0.7472636163477915, 0.8024872835955088, 0.9754439117681706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 342}], {
             RGBColor[
             0.7390158049158364, 0.7960440306191768, 0.9746218470048134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 353}], {
             RGBColor[
             0.6748699909374275, 0.7451195906863441, 0.9687844101011585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 216}], {
             RGBColor[
             0.5929329628682276, 0.6804087164388288, 0.9610970013034472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 231}], {
             RGBColor[
             0.5016792035741117, 0.6047475688800954, 0.9543489657808408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 235}], {
             RGBColor[
             0.5083224291400363, 0.6105015969670738, 0.9547722662395279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 298}], {
             RGBColor[
             0.5502315003356115, 0.6457417454758861, 0.9577353857522684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 313}], {
             RGBColor[
             0.7414569848176231, 0.7978696730310717, 0.9751061292503568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 317}], {
             RGBColor[
             0.7315769178286489, 0.7899915758013376, 0.9741637596409085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 336}], {
             RGBColor[
             0.4856586027744437, 0.590871329686232, 0.9533281472643471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 361}], {
             RGBColor[
             0.48782456716296596`, 0.5927473791750344, 0.9534661605998966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 393}], {
             RGBColor[
             0.5545158877765943, 0.6492200042099305, 0.9580726684258509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 396}], {
             RGBColor[
             0.6166295574657007, 0.6996466794524787, 0.9629624840336464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 147}], {
             RGBColor[
             0.6312375851752513, 0.7115061344312408, 0.9641124814859109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 164}], {
             RGBColor[
             0.8036659223078154, 0.8463082096515309, 0.9365848724764199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 287}], {
             RGBColor[
             0.5179710219499725, 0.6184543137293215, 0.9554988055573599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 371}], {
             RGBColor[
             0.6030606215401821, 0.6886308059945453, 0.9618942876929395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 391}], {
             RGBColor[
             0.7078841983980482, 0.7714275777139677, 0.9717214565792892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 140}], {
             RGBColor[
             0.8095039209053446, 0.851517851903123, 0.9815391811379166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 186}], {
             RGBColor[
             0.7524944429106486, 0.806861684807988, 0.9759390056761406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 188}], {
             RGBColor[
             0.6291242368974549, 0.7049249450184387, 0.9667184628790086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 203}], {
             RGBColor[
             0.9293291623817465, 0.9444662326829025, 0.9163674733718314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 228}], {
             RGBColor[
             0.7225474582596031, 0.782549373571985, 0.9735814693449909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 238}], {
             RGBColor[
             0.6096726337492978, 0.6880769440375063, 0.9654790239267853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 273}], {
             RGBColor[
             0.9113410441481729, 0.9317165123259619, 0.9766320468425096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 280}], {
             RGBColor[
             0.6720204213968772, 0.7415292488297529, 0.9696037959165225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 309}], {
             RGBColor[
             0.6348132571013001, 0.70985248838054, 0.9670809622157945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 322}], {
             RGBColor[
             0.8002716835304533, 0.844305557898255, 0.980618997996551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 325}], {
             RGBColor[
             0.8303194795014042, 0.8677791244824694, 0.9836138814863171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 330}], {
             RGBColor[
             0.8387199136563648, 0.8743416074899888, 0.9844511582563631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 339}], {
             RGBColor[
             0.9325889244873509, 0.9453285430167031, 0.8270406019289515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 160}], {
             RGBColor[
             0.5489077200538346, 0.6446599592236044, 0.9576360147736585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 202}], {
             RGBColor[
             0.6029809788971581, 0.6885590667251651, 0.9618928597866786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 220}], {
             RGBColor[
             0.728361706948408, 0.7877209683128782, 0.9735599460876263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 244}], {
             RGBColor[
             0.7990556651089071, 0.8435360551941435, 0.9628002832171275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 260}], {
             RGBColor[
             0.5001682916547401, 0.6024898273036151, 0.9545178066022222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 307}], {
             RGBColor[
             0.505170837717014, 0.6068227812674808, 0.9548365644137324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 321}], {
             RGBColor[
             0.8179991282281167, 0.8543553412613981, 0.7318832611465842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 341}], {
             RGBColor[
             0.6829181419713799, 0.7522201099689381, 0.9690305562249757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 348}], {
             RGBColor[
             0.8143352265077299, 0.854656213066481, 0.924606847856154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 366}], {
             RGBColor[
             0.6517835525547719, 0.7278975320850403, 0.9659273513212085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 155}], {
             RGBColor[
             0.5001659045907358, 0.6047881161925801, 0.9538791740249255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 199}], {
             RGBColor[
             0.5675452916978789, 0.659797861281187, 0.9590983908308136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 216}], {
             RGBColor[
             0.5680494610038966, 0.6602071686363806, 0.9591380808854164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 298}], {
             RGBColor[
             0.5253479984712806, 0.6255401976734379, 0.9557764653342375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 299}], {
             RGBColor[
             0.6452023899582853, 0.7214695471224775, 0.9661511473611887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 306}], {
             RGBColor[
             0.6462099332268192, 0.7222566475814685, 0.966251569858169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 342}], {
             RGBColor[
             0.6379621217948641, 0.7158133946051366, 0.9654295050948116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 361}], {
             RGBColor[
             0.4629410652986349, 0.5725458313725862, 0.9515072401818657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 393}], {
             RGBColor[
             0.5296323859122634, 0.6290184564074823, 0.95611374800782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 135}], {
             RGBColor[
             0.6193909608052803, 0.6975419579268919, 0.9656160511226154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 226}], {
             RGBColor[
             0.6407427447551944, 0.7160358000124423, 0.9669765679152627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 234}], {
             RGBColor[
             0.6379185792366051, 0.7135896497869264, 0.9667966145857296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 239}], {
             RGBColor[
             0.8646940811272356, 0.8949476050680358, 0.9869564874510763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 246}], {
             RGBColor[
             0.537803339399658, 0.6201127799685923, 0.9606649529423926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 269}], {
             RGBColor[
             0.6362282995709254, 0.7121256144964407, 0.9666889114600883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 272}], {
             RGBColor[
             0.6491072480011056, 0.723147717218305, 0.96754629360627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 350}], {
             RGBColor[
             0.8961172965669075, 0.9195771751346471, 0.9751684084864223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 355}], {
             RGBColor[
             0.6853357718519326, 0.7525596649568069, 0.9703983357132626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 392}], {
             RGBColor[
             0.5412263466058838, 0.6237105775735274, 0.9608598881389019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 395}], {
             RGBColor[
             0.6668924865807087, 0.7375865751130941, 0.9689464127367318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 156}], {
             RGBColor[
             0.4938266242934103, 0.5984689874517588, 0.9537041197911049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 165}], {
             RGBColor[
             0.6830092360004631, 0.7474562186561378, 0.9434889963849209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 221}], {
             RGBColor[
             0.48346823591673543`, 0.5900595811274956, 0.9528886695140661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 234}], {
             RGBColor[
             0.41731115121642404`, 0.5358756773405073, 0.9478116754351167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 255}], {
             RGBColor[
             0.46714945952463877`, 0.5768112632998927, 0.9516039956588327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 281}], {
             RGBColor[
             0.5908211399377487, 0.6750612278725596, 0.9628114068585936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 328}], {
             RGBColor[
             0.5109031872206516, 0.6123325105264863, 0.9550484493782485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 355}], {
             RGBColor[
             0.46472834383175154`, 0.5748456925103879, 0.9514133965626497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 386}], {
             RGBColor[
             0.4633956067471592, 0.5737637165059943, 0.9513084786173738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 400}], {
             RGBColor[
             0.6087094516881497, 0.6890357129681776, 0.9645943465980958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 331}], {
             RGBColor[
             0.7780442722934839, 0.8267631178345248, 0.9784508708084901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 335}], {
             RGBColor[
             0.5946315687118894, 0.6807870997768553, 0.9619148520986411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 394}], {
             RGBColor[
             0.7573300691042782, 0.8103512729967508, 0.9764472417025877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 169}], {
             RGBColor[
             0.6587500212569635, 0.4264066507027265, 0.44792094711192215`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 175}], {
             RGBColor[
             0.5763181283490248, 0.6540502027483012, 0.9638496936096455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 178}], {
             RGBColor[
             0.5523271284235607, 0.6349204306260807, 0.9615614106197363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 197}], {
             RGBColor[
             0.4374226286122936, 0.5445277101865831, 0.9504586035069407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 252}], {
             RGBColor[
             0.47984880619362136`, 0.578108876159676, 0.9543881179582379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 278}], {
             RGBColor[
             0.3925383045911579, 0.5080885939304707, 0.9469251451033005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 282}], {
             RGBColor[
             0.4918018329168807, 0.5874466714822539, 0.9555794839546268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 300}], {
             RGBColor[
             0.5525967277534489, 0.6351354018136548, 0.9615871252444952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 314}], {
             RGBColor[
             0.6021800722276686, 0.6744754660348938, 0.9595088941890246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 319}], {
             RGBColor[
             0.4011633821256573, 0.5150908204282922, 0.9476041428015163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 352}], {
             RGBColor[
             0.5111437735970235, 0.6025567425457752, 0.9575073078409111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 159}], {
             RGBColor[
             0.5678474214897513, 0.6600431438570211, 0.9591221755947676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 215}], {
             RGBColor[
             0.6111192561976764, 0.6951398344329096, 0.962551483717057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 218}], {
             RGBColor[
             0.4980210993050205, 0.6024052206744763, 0.9538876157880082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 229}], {
             RGBColor[
             0.7768114662829593, 0.8248030415445226, 0.9427721628021248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 329}], {
             RGBColor[
             0.5802421344519442, 0.6701057302151849, 0.960097932802481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 349}], {
             RGBColor[
             0.4864665605220403, 0.5923972599286642, 0.9531513707940341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 193}], {
             RGBColor[
             0.6873495559767131, 0.7461550473952308, 0.7058294190479958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 204}], {
             RGBColor[
             0.3961901271379278, 0.5175817078572507, 0.9464658624574231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 224}], {
             RGBColor[
             0.6460108493625908, 0.7181846497865244, 0.9684235978427078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 276}], {
             RGBColor[
             0.32542592890760413`, 0.4526172981676777, 0.9420912808834518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 290}], {
             RGBColor[
             0.6638866749694292, 0.7321739650076029, 0.9609622892328206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 318}], {
             RGBColor[
             0.3933243839896702, 0.5150995451786686, 0.9462832598380935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 203}], {
             RGBColor[
             0.8683742429862604, 0.8964398170331842, 0.910400319182433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 232}], {
             RGBColor[
             0.731163134939277, 0.7899094651509864, 0.9738391662489231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 257}], {
             RGBColor[
             0.676103406505162, 0.7463035339804045, 0.9687566638113551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 275}], {
             RGBColor[
             0.576288722429444, 0.6639311498237418, 0.961268669991881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 280}], {
             RGBColor[
             0.6110655020013911, 0.6935028331800346, 0.963636641727124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 288}], {
             RGBColor[
             0.7104600517238671, 0.773736059193848, 0.9717756763953236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 297}], {
             RGBColor[
             0.7185216289136697, 0.7800338245647775, 0.972579179069881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 309}], {
             RGBColor[
             0.5738583377058141, 0.6618260727308216, 0.9611138080263961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 322}], {
             RGBColor[
             0.7393167641349672, 0.7962791422485367, 0.9746518438071525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 325}], {
             RGBColor[
             0.7693645601059181, 0.819752708832751, 0.9776467272969187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 339}], {
             RGBColor[
             0.8716340050918648, 0.8973021273669848, 0.8210734477395529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 172}], {
             RGBColor[
             0.6905789482832905, 0.7581654971613803, 0.9698209785896945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[
             0.645846858882023, 0.723220448944639, 0.9653625019633185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 243}], {
             RGBColor[
             0.552535250261149, 0.6476120334481889, 0.9579167453853208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 279}], {
             RGBColor[
             0.790962558782123, 0.8374073392483442, 0.973813565479385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 285}], {
             RGBColor[
             0.7581439914244144, 0.32890219885397554`, 0.4310740239262636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 337}], {
             RGBColor[
             0.4969532409476165, 0.5997943926385609, 0.9542853927642183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 399}], {
             RGBColor[
             0.6930817144770836, 0.760120677133699, 0.970070430934212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 143}], {
             RGBColor[
             0.7728715995056759, 0.8227112926134574, 0.9779381980392372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 258}], {
             RGBColor[
             0.8648423819966342, 0.8950658561557745, 0.9869706325203893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 277}], {
             RGBColor[
             0.7259080398487072, 0.7854469499869875, 0.9736511598164374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 302}], {
             RGBColor[
             0.662549041463606, 0.7340092608076124, 0.9686633073719038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 377}], {
             RGBColor[
             0.5940719180078162, 0.6753689837114657, 0.9641145605951156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 378}], {
             RGBColor[
             0.8698384506380628, 0.8990495856757791, 0.9874471620074519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 379}], {
             RGBColor[
             0.8460851483536982, 0.8801093472004409, 0.985181550830746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 258}], {
             RGBColor[
             0.7906524078853219, 0.8368892265682012, 0.9796341474156028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 277}], {
             RGBColor[
             0.6517180657373949, 0.7272703203994142, 0.9663146747116509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 302}], {
             RGBColor[
             0.5883590673522938, 0.6758326312200391, 0.9613268222671174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 377}], {
             RGBColor[
             0.5198819438965039, 0.6171923541238924, 0.9567780754903291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 378}], {
             RGBColor[
             0.7956484765267504, 0.8408729560882058, 0.9801106769026655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 379}], {
             RGBColor[
             0.7718951742423859, 0.8219327176128677, 0.9778450657259594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 186}], {
             RGBColor[
             0.7630390192442166, 0.8152696437514755, 0.9769447567800906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 188}], {
             RGBColor[
             0.6396688132310229, 0.7133329039619263, 0.9677242139829587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 200}], {
             RGBColor[
             0.641438045587939, 0.7148653241052831, 0.9678369479042707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 228}], {
             RGBColor[
             0.7330920345931711, 0.7909573325154724, 0.974587220448941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 333}], {
             RGBColor[
             0.5352374964839833, 0.6108770927199081, 0.9615094187676076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 368}], {
             RGBColor[
             0.822171064959784, 0.8615839768822673, 0.9827564899557601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 200}], {
             RGBColor[
             0.6407258151492146, 0.7142974108864245, 0.9677690147292095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 207}], {
             RGBColor[
             0.6456221669229989, 0.7185383846950808, 0.9680810059345613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 222}], {
             RGBColor[
             0.9421460951477039, 0.9525800167392408, 0.7980272937682533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 254}], {
             RGBColor[
             0.7592725801615621, 0.812222186364943, 0.9766363851126444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 333}], {
             RGBColor[
             0.5345252660452587, 0.6103091795010495, 0.9614414855925466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 227}], {
             RGBColor[
             0.5122205209793832, 0.614882720059394, 0.9547430222185409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 302}], {
             RGBColor[
             0.5243004968519943, 0.6246897886694911, 0.9556940021696425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 375}], {
             RGBColor[
             0.6866884645073017, 0.7540657141769662, 0.9701582862883074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 377}], {
             RGBColor[
             0.45582337339620443`, 0.5660495115733444, 0.9511452553928542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 344}], {
             RGBColor[
             0.7042434813977922, 0.7688351007101917, 0.9711865097717189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 354}], {
             RGBColor[
             0.7575579433627588, 0.8109348007413678, 0.9763809710690365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 371}], {
             RGBColor[
             0.6112753650592294, 0.6952999048532862, 0.962540982394356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 388}], {
             RGBColor[
             0.7329557179778861, 0.791317654029088, 0.9740343888491616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 391}], {
             RGBColor[
             0.7160989419170956, 0.7780966765727086, 0.9723681512807056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 179}], {
             RGBColor[
             0.592704885518181, 0.676381887134693, 0.9630630447487876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 232}], {
             RGBColor[
             0.5545034603515399, 0.6465386434529283, 0.9592554837007919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 257}], {
             RGBColor[
             0.49944373191742486`, 0.6029327122823465, 0.9541729812632239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 275}], {
             RGBColor[
             0.3996290478417067, 0.5205603281256839, 0.9466849874437498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 276}], {
             RGBColor[
             0.3321298135533891, 0.4584238661008171, 0.9425184464850689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 279}], {
             RGBColor[
             0.6686803978126936, 0.7365559373960253, 0.9646228605161176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 288}], {
             RGBColor[
             0.5338003771361299, 0.63036523749579, 0.9571919938471924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 195}], {
             RGBColor[
             0.5479767560182811, 0.6270154203159148, 0.9618185131143842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 210}], {
             RGBColor[
             0.6059245023594885, 0.659313063709783, 0.6677122734966298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 247}], {
             RGBColor[
             0.30127190367246437`, 0.42772473215133644`, 0.9406976261443508]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 249}], {
             RGBColor[
             0.38513888566847054`, 0.49789833783798754`, 0.9467234051969943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 253}], {
             RGBColor[
             0.5918861380367554, 0.6614602716803926, 0.9463380524735806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 266}], {
             RGBColor[
             0.6031826139931478, 0.6698851649523883, 0.9272160652722026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 315}], {
             RGBColor[
             0.2709827836397342, 0.4014898187544234, 0.9387676301994825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 316}], {
             RGBColor[
             0.597453689214301, 0.6656125422325776, 0.936913640579905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 358}], {
             RGBColor[
             0.5160532018991774, 0.6016732112349177, 0.9587436912802656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 359}], {
             RGBColor[
             0.5078153044538006, 0.5952377031402498, 0.9579226146504389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 362}], {
             RGBColor[
             0.34010822472821295`, 0.4613404186785288, 0.943178426615031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 363}], {
             RGBColor[
             0.610570956407258, 0.6734037289381862, 0.820362562604306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 369}], {
             RGBColor[
             0.3289770196043874, 0.4517215110719527, 0.9424629716328609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 397}], {
             RGBColor[
             0.41344827374932813`, 0.5208811744054272, 0.9489520239274248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 192}], {
             RGBColor[
             0.6633609382837056, 0.7303810409994163, 0.9414079193378639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 283}], {
             RGBColor[
             0.8430960266544925, 0.8777125260634077, 0.9556386573049465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 294}], {
             RGBColor[
             0.7000294673877272, 0.7621414778954589, 0.943744405587665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 320}], {
             RGBColor[
             0.887579995329568, 0.9124637404830604, 0.9600724035761556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 347}], {
             RGBColor[
             0.8023356774910839, 0.8457803619315855, 0.9516374909468719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 380}], {
             RGBColor[
             0.9126444243424163, 0.9323443373088729, 0.9624909611046095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 381}], {
             RGBColor[
             0.7032879643716006, 0.7649638242060696, 0.9439520341341017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 384}], {
             RGBColor[
             0.7357619538499451, 0.7917328139676365, 0.9463965635542564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 168}], {
             RGBColor[
             0.7622723428581437, 0.8146763547278406, 0.9768508691917764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 265}], {
             RGBColor[
             0.7259056771108969, 0.7851522571746037, 0.9739879520486672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 291}], {
             RGBColor[
             0.8226006702703038, 0.8618870461750308, 0.9828079445491635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 304}], {
             RGBColor[
             0.9133277165017897, 0.9336381779067577, 0.9885245028688405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 378}], {
             RGBColor[
             0.8900685995825597, 0.9151805573113565, 0.9893767316734452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 383}], {
             RGBColor[
             0.7231789658540085, 0.7829385901393193, 0.9737732953502525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 154}], {
             RGBColor[
             0.7293155071091473, 0.7882422549527737, 0.9738860647129525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 180}], {
             RGBColor[
             0.631202305227496, 0.7076671321883028, 0.9664170974559051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 198}], {
             RGBColor[
             0.7081568940713834, 0.771064739704062, 0.9722203811880663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 236}], {
             RGBColor[
             0.7334215509130986, 0.7915757262879868, 0.9742093075221335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 267}], {
             RGBColor[
             0.7861439827647569, 0.8330474206844203, 0.9792696521438282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 284}], {
             RGBColor[
             0.6629453517577327, 0.73435997289707, 0.9686611629617993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 332}], {
             RGBColor[
             0.6458388486816915, 0.7203445704742629, 0.9673497250622192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 367}], {
             RGBColor[
             0.6455611461256912, 0.7201040384779916, 0.9673320301009136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 383}], {
             RGBColor[
             0.7009470789847995, 0.7652114870183049, 0.9716527981340275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 398}], {
             RGBColor[
             0.8099336773545394, 0.8516321109063337, 0.981640786573202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 161}], {
             RGBColor[
             0.5735322289386525, 0.6617342055733482, 0.9610123611533729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 184}], {
             RGBColor[
             0.826242010397209, 0.8649006214726193, 0.9831260497543355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[
             0.5292530528851737, 0.6233818088119235, 0.9581909312097832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 372}], {
             RGBColor[
             0.8247186775873898, 0.863685957239837, 0.9829807529110397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 180}], {
             RGBColor[
             0.5174597145690796, 0.61821372791092, 0.9554103341252971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 236}], {
             RGBColor[
             0.619678960254682, 0.7021223220106039, 0.9632025441915255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 267}], {
             RGBColor[
             0.6724013921063405, 0.7435940164070374, 0.9682628888132203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 286}], {
             RGBColor[
             0.5247698566671712, 0.6245454055778621, 0.9558761299156826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 291}], {
             RGBColor[
             0.6866261927426782, 0.7547065387766334, 0.9696806840023307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 332}], {
             RGBColor[
             0.5320962580232751, 0.6308911661968801, 0.9563429617316113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 383}], {
             RGBColor[
             0.587204488326383, 0.6757580827409221, 0.9606460348034196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 170}], {
             RGBColor[
             0.6089754987588363, 0.6910777288637441, 0.9638445526649952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 171}], {
             RGBColor[
             0.6918070265742374, 0.7566163753315174, 0.9665242966280918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 199}], {
             RGBColor[
             0.5093494452034377, 0.6122437281757616, 0.9546021359823751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 261}], {
             RGBColor[
             0.4047452188041938, 0.5249916982671607, 0.9470109853334272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.5870065434638442, 0.6739154140170519, 0.9616548925127502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 306}], {
             RGBColor[
             0.588014086732378, 0.674702514476043, 0.9617553150097304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 342}], {
             RGBColor[
             0.5797662753004229, 0.6682592614997112, 0.9609332502463731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 353}], {
             RGBColor[
             0.515620461322014, 0.6173348215668785, 0.9550958133427183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 361}], {
             RGBColor[
             0.4047452188041938, 0.5249916982671607, 0.9470109853334272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 165}], {
             RGBColor[
             0.7780523275087741, 0.8260972206274236, 0.9505620042040234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 221}], {
             RGBColor[
             0.5785113274250464, 0.6687005830987814, 0.9599616773331687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 245}], {
             RGBColor[
             0.4872772875935878, 0.5927962811816063, 0.9532868018479432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 255}], {
             RGBColor[
             0.5621925510329497, 0.6554522652711786, 0.9586770034779353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 328}], {
             RGBColor[
             0.6059462787289627, 0.6909735124977723, 0.9621214571973509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 364}], {
             RGBColor[
             0.6637583201848338, 0.7364329239554277, 0.9676811040346629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 386}], {
             RGBColor[
             0.5584386982554702, 0.6524047184772803, 0.9583814864364762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 400}], {
             RGBColor[
             0.7037525431964606, 0.7676767149394634, 0.9716673544171983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 181}], {
             RGBColor[
             0.8463211498057182, 0.8805341435024949, 0.9851412704742797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 191}], {
             RGBColor[
             0.7697686648941984, 0.8206579275529168, 0.9775610304645715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 334}], {
             RGBColor[
             0.7094629097859337, 0.7716989988127197, 0.9728135405151892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 365}], {
             RGBColor[
             0.7651772303207209, 0.8169303941243975, 0.9771995759159684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 370}], {
             RGBColor[
             0.7904200393176118, 0.8368637711250109, 0.9795695702064038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 209}], {
             RGBColor[
             0.6912715808217484, 0.7587458798873328, 0.969863148942256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 241}], {
             RGBColor[
             0.7562078240245117, 0.8094745666110585, 0.9763353868010132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 270}], {
             RGBColor[
             0.7164990180289927, 0.778453745569256, 0.9723775841192697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 310}], {
             RGBColor[
             0.7804062780813865, 0.8287171530816148, 0.9786574164207151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 323}], {
             RGBColor[
             0.7053839602154338, 0.7697705779277356, 0.9712697390325351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 324}], {
             RGBColor[
             0.5779898422543668, 0.6674104704027821, 0.9605132241383418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 346}], {
             RGBColor[
             0.694416583886212, 0.7612027801842001, 0.9701766134559971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 390}], {
             RGBColor[
             0.8326197634574197, 0.8695616636462634, 0.9562788064862137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 215}], {
             RGBColor[
             0.6012632089777314, 0.6871382512898909, 0.9617755795760125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 218}], {
             RGBColor[
             0.4881650520850756, 0.5944036375314579, 0.9531117116469636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 329}], {
             RGBColor[
             0.5703860872319992, 0.6621041470721664, 0.9593220286614365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 349}], {
             RGBColor[
             0.47661051330209536`, 0.5843956767856455, 0.9523754666529896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 217}], {
             RGBColor[
             0.7251299385679606, 0.7803529878923575, 0.8381601921133326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 220}], {
             RGBColor[
             0.6344481310803076, 0.7114847784486877, 0.9661618835241872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 233}], {
             RGBColor[
             0.4527716150776009, 0.5665442375979163, 0.9500837597283243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 244}], {
             RGBColor[
             0.7051420892408067, 0.7672998653299531, 0.9554022206536885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 263}], {
             RGBColor[
             0.7085611446360308, 0.7698497912455219, 0.9496146517020384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 264}], {
             RGBColor[
             0.47393536057986346`, 0.5838011021202427, 0.9517290741487272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 307}], {
             RGBColor[
             0.41125726184891354`, 0.5305865914032903, 0.9474385018502934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 312}], {
             RGBColor[
             0.4984430409224281, 0.6036975410807544, 0.9536584085198849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 321}], {
             RGBColor[
             0.7240855523600163, 0.7781191513972077, 0.7244851985831452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 341}], {
             RGBColor[
             0.5890045661032794, 0.6759839201047476, 0.9616324936615367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 348}], {
             RGBColor[
             0.7204216506396295, 0.7784200232022906, 0.917208785292715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 366}], {
             RGBColor[
             0.5578699766866715, 0.6516613422208498, 0.9585292887577697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 176}], {
             RGBColor[
             0.5037004562066627, 0.6065995781344488, 0.9544497682179088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 184}], {
             RGBColor[
             0.6557128071255125, 0.7266491140361295, 0.969013662928246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 195}], {
             RGBColor[
             0.6364412148114803, 0.711282469438358, 0.96717552124938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 250}], {
             RGBColor[
             0.5445011268100619, 0.6390548879459449, 0.958118812204269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 344}], {
             RGBColor[
             0.5860188298841209, 0.6714888331336301, 0.962256908841697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.35872384961347703`, 0.4851303013754338, 0.9440785443836937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 363}], {
             RGBColor[
             0.6990354152004572, 0.7576707780606293, 0.8257195707393017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 372}], {
             RGBColor[
             0.6541894743156931, 0.7254344498033471, 0.9688683660849501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 191}], {
             RGBColor[
             0.660386096454932, 0.7345450718453357, 0.9668345687644603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 211}], {
             RGBColor[
             0.6815529837318812, 0.7511536379766548, 0.9688944900097916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 214}], {
             RGBColor[
             0.5623273981076149, 0.6546153663787095, 0.9592037874744077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 248}], {
             RGBColor[
             0.5773664401917994, 0.6671459748980306, 0.9602989573124052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 263}], {
             RGBColor[
             0.8226479203083149, 0.8618454381187377, 0.9590233902926879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 312}], {
             RGBColor[
             0.6125298165947122, 0.6956931879539701, 0.9630671471105345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 340}], {
             RGBColor[
             0.6796005690430253, 0.7496283967828193, 0.968699891559959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 348}], {
             RGBColor[
             0.8345084263119136, 0.8704156700755064, 0.9266175238833645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 167}], {
             RGBColor[
             0.6513590881585093, 0.7274771797678696, 0.9659457286677888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 174}], {
             RGBColor[
             0.6076336986546893, 0.6919789387623191, 0.9625035058346688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.5461916322846151, 0.6413619995937369, 0.9578697826268705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 222}], {
             RGBColor[
             0.8301609438432613, 0.8645294536951379, 0.7870161013882129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 226}], {
             RGBColor[
             0.5538201650832799, 0.6479694512827334, 0.9583558659911546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 395}], {
             RGBColor[
             0.579969906908794, 0.6695202263833853, 0.9603257108126237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 287}], {
             RGBColor[
             0.698614102601584, 0.7599254878083526, 0.9286178912492853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 292}], {
             RGBColor[
             0.7744630712531569, 0.8226000195919113, 0.934285917067829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 354}], {
             RGBColor[
             0.929986280495323, 0.945736875961658, 0.9488533620595456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 371}], {
             RGBColor[
             0.7837037021917935, 0.8301019800735763, 0.9350133733848649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 374}], {
             RGBColor[
             0.9183199238138475, 0.9364344398186655, 0.9477406145445869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 388}], {
             RGBColor[
             0.9053840551104502, 0.9261197292493784, 0.9465067798396706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 389}], {
             RGBColor[
             0.8534633221043734, 0.8855065221313982, 0.9413456947342161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 391}], {
             RGBColor[
             0.8885272790496597, 0.9128987517929987, 0.9448405422712146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 182}], {
             RGBColor[
             0.9642493286398424, 0.9280400092644917, 0.622182084759657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 256}], {
             RGBColor[
             0.7464341424657759, 0.8004281536265135, 0.9480729048562104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 281}], {
             RGBColor[
             0.8750468431531124, 0.9026894610482245, 0.9596692912715119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 311}], {
             RGBColor[
             0.7425954435531814, 0.7973117249178541, 0.9477707084161936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 328}], {
             RGBColor[
             0.7951288904360154, 0.8399607437021512, 0.9519063337911668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 386}], {
             RGBColor[
             0.7476213099625231, 0.8013919496816593, 0.9481663630302922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 400}], {
             RGBColor[
             0.8929351549035135, 0.9166639461438424, 0.9614522310110143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 169}], {
             RGBColor[
             0.8271381892658113, 0.5682673842257571, 0.4609725624669786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 178}], {
             RGBColor[
             0.8049093804368324, 0.8477115309106267, 0.9811388336523208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 197}], {
             RGBColor[
             0.6900048806255653, 0.757318810471129, 0.9700360265395253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.8278006205358625, 0.8659643843994338, 0.9833222205682176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 300}], {
             RGBColor[
             0.8051789797667206, 0.8479265020982008, 0.9811645482770797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 319}], {
             RGBColor[
             0.6537456341389289, 0.7278819207128382, 0.967181565834101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 174}], {
             RGBColor[
             0.5928395573315661, 0.6803328856162956, 0.9610896480774453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 183}], {
             RGBColor[
             0.6429166353747989, 0.7208818714882175, 0.9651042638735154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 189}], {
             RGBColor[
             0.531397490961492, 0.6297159464477133, 0.956455924869647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 222}], {
             RGBColor[
             0.8153668025201382, 0.8528834005491144, 0.7856022436309895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 238}], {
             RGBColor[
             0.4927256870165756, 0.5962203735720086, 0.9539917917184104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 246}], {
             RGBColor[
             0.4360866184046204, 0.5404003780928598, 0.9506303932610611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 269}], {
             RGBColor[
             0.5345115785758877, 0.6324132126207083, 0.9566543517787568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 272}], {
             RGBColor[
             0.5473905270060679, 0.6434353153425725, 0.9575117339249385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 309}], {
             RGBColor[
             0.5178663103685779, 0.6179959179150424, 0.9555937300074198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 395}], {
             RGBColor[
             0.565175765585671, 0.6578741732373616, 0.9589118530554004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 265}], {
             RGBColor[
             0.6006561484630588, 0.686678746430259, 0.9617049987644333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 304}], {
             RGBColor[
             0.7880781878539516, 0.8351646671624129, 0.9762415495846067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 378}], {
             RGBColor[
             0.7648190709347216, 0.8167070465670117, 0.9770937783892114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 177}], {
             RGBColor[
             0.8754552913067509, 0.6065043809533067, 0.4656579812438112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 178}], {
             RGBColor[
             0.8529367977952227, 0.588548745475437, 0.46351014723018513`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 197}], {
             RGBColor[
             0.7763337979210446, 0.5282869318491052, 0.4561082758216547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 239}], {
             RGBColor[
             0.8681976245279094, 0.600717314467975, 0.4649657385074496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 300}], {
             RGBColor[
             0.8531165306818148, 0.5886920596004863, 0.4635272903133577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 319}], {
             RGBColor[
             0.7521609669299537, 0.5086623386769114, 0.45420530201803855`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 171}], {
             RGBColor[
             0.8588124672367791, 0.8904601211081067, 0.9809859301166002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 187}], {
             RGBColor[
             0.8174456884558506, 0.85762867963256, 0.9823555122556858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 261}], {
             RGBColor[
             0.5717506594667354, 0.65883544404375, 0.9614726188219356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 299}], {
             RGBColor[
             0.7540119841263858, 0.8077591597936413, 0.9761165260012585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 306}], {
             RGBColor[
             0.7550195273949196, 0.8085462602526324, 0.9762169484982388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 353}], {
             RGBColor[
             0.6826259019845556, 0.7511785673434679, 0.9695574468312267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 361}], {
             RGBColor[
             0.5717506594667354, 0.65883544404375, 0.9614726188219356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 299}], {
             RGBColor[
             0.836843511941787, 0.8732978062614145, 0.9787962699643551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 306}], {
             RGBColor[
             0.8378510552103208, 0.8740849067204057, 0.9788966924613354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 342}], {
             RGBColor[
             0.8296032437783657, 0.8676416537440738, 0.978074627697978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 353}], {
             RGBColor[
             0.7654574297999568, 0.8167172138112411, 0.9722371907943232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 208}], {
             RGBColor[
             0.6483480252830802, 0.7238805313884091, 0.9664964056341498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 225}], {
             RGBColor[
             0.8446489781661926, 0.8792841330570631, 0.9739370820902189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 240}], {
             RGBColor[
             0.6966318328920704, 0.7629333495440929, 0.9703974087742222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 243}], {
             RGBColor[
             0.6033202242711966, 0.6873249340476426, 0.9629516521962245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 285}], {
             RGBColor[
             0.792000640764446, 0.3553774659202781, 0.4344306284668661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 337}], {
             RGBColor[
             0.547738214957664, 0.6395072932380147, 0.959320299575122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 357}], {
             RGBColor[
             0.8577323464741345, 0.8890416877190768, 0.951790352233833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 399}], {
             RGBColor[
             0.743866688487131, 0.7998335777331529, 0.9751053377451157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 176}], {
             RGBColor[
             0.5695106031305205, 0.6613933896384765, 0.959253107345964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 209}], {
             RGBColor[
             0.6091132802343222, 0.6929128178229993, 0.9628027465361702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 250}], {
             RGBColor[
             0.6103112737339196, 0.6938486994499726, 0.9629221513323243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 323}], {
             RGBColor[
             0.6232256596280075, 0.7039375158634023, 0.9642093366264491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 354}], {
             RGBColor[
             0.7051434387729454, 0.768382344668834, 0.9722547092670698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 388}], {
             RGBColor[
             0.6805412133880726, 0.7487651979565543, 0.9699081270471948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 183}], {
             RGBColor[
             0.5991912458709789, 0.6853836304826669, 0.9616620410403954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 189}], {
             RGBColor[
             0.487672101457672, 0.5942177054421628, 0.953013702036527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 238}], {
             RGBColor[
             0.44900029751275555`, 0.5607221325664581, 0.9505495688852904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 246}], {
             RGBColor[
             0.39236122890080033`, 0.5049021370873092, 0.9471881704279411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 269}], {
             RGBColor[
             0.49078618907206767`, 0.5969149716151578, 0.9532121289456368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 272}], {
             RGBColor[
             0.503665137502248, 0.607937074337022, 0.9540695110918185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 309}], {
             RGBColor[
             0.47414092086475784`, 0.5824976769094918, 0.9521515071742996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 325}], {
             RGBColor[
             0.6696471432648619, 0.7404243130114212, 0.9686844264448222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 395}], {
             RGBColor[
             0.521450376081851, 0.6223759322318112, 0.9554696302222803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 178}], {
             RGBColor[
             0.8675982931564137, 0.897263344907367, 0.9872334937870401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 213}], {
             RGBColor[
             0.9426877939574545, 0.9527554774582153, 0.7772882498873548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 227}], {
             RGBColor[
             0.6727329253234398, 0.7419547896117937, 0.969835874237265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 278}], {
             RGBColor[
             0.7078094693240109, 0.7704315082117569, 0.9725972282706044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 296}], {
             RGBColor[
             0.593088570675925, 0.6716770009413305, 0.9648047454905164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 314}], {
             RGBColor[
             0.9174512369605216, 0.93681838031618, 0.9851809773563285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 319}], {
             RGBColor[
             0.7164345468585103, 0.7774337347095784, 0.9732762259688201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 352}], {
             RGBColor[
             0.8264149383298764, 0.8648996568270614, 0.9831793910082148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 250}], {
             RGBColor[
             0.6451985573497687, 0.7221717679435353, 0.9656686060948946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 344}], {
             RGBColor[
             0.6867162604238277, 0.7546057131312205, 0.9698067027323225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 354}], {
             RGBColor[
             0.7400307223887943, 0.7967054131623966, 0.9750011640296401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 356}], {
             RGBColor[
             0.45942128015318384`, 0.5682471813730242, 0.9516283382743191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 372}], {
             RGBColor[
             0.7548869048553999, 0.8085513298009376, 0.9764181599755757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 388}], {
             RGBColor[
             0.7154284970039215, 0.7770882664501169, 0.9726545818097652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 197}], {
             RGBColor[
             0.7624805336869749, 0.8146743055624535, 0.9770641547047743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 225}], {
             RGBColor[
             0.9295484039022908, 0.9463451737860239, 0.9822034958089243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 243}], {
             RGBColor[
             0.6882196500072948, 0.7543859747766035, 0.9712180659149298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 252}], {
             RGBColor[
             0.8049067112683026, 0.8482554715355464, 0.9809936691560714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 300}], {
             RGBColor[
             0.87765463282813, 0.9052819971895252, 0.9881926764423288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 337}], {
             RGBColor[
             0.6326376406937622, 0.7065683339669755, 0.9675867132938273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 367}], {
             RGBColor[
             0.6796134841246765, 0.7472564484722913, 0.9705799724981379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 398}], {
             RGBColor[
             0.8439860153535247, 0.8787845209006334, 0.9848887289704262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 197}], {
             RGBColor[
             0.7287027934196824, 0.7877408523456488, 0.9738424036843352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 274}], {
             RGBColor[
             0.8443078433622389, 0.8786921724439101, 0.9850120298940417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 278}], {
             RGBColor[
             0.6838184693985467, 0.7513017360895364, 0.9703089452806951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 300}], {
             RGBColor[
             0.8438768925608376, 0.8783485439727206, 0.9849709254218897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 319}], {
             RGBColor[
             0.6924435469330461, 0.758303962587358, 0.9709879429789109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 352}], {
             RGBColor[
             0.8024239384044123, 0.8457698847048409, 0.9808911080183056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 232}], {
             RGBColor[
             0.7519786935353365, 0.8061707377303329, 0.9759138665973235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 257}], {
             RGBColor[
             0.6969189651012215, 0.762564806559751, 0.9708313641597555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 275}], {
             RGBColor[
             0.5971042810255034, 0.6801924224030882, 0.9633433703402814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 279}], {
             RGBColor[
             0.8661556309964903, 0.8961880316734296, 0.9812812434126492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 285}], {
             RGBColor[
             0.8082727062339926, 0.36808932713736586`, 0.4360524758817731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 288}], {
             RGBColor[
             0.7312756103199267, 0.7899973317731944, 0.973850376743724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 399}], {
             RGBColor[
             0.7682747866914509, 0.8189013695587846, 0.9775381088674762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 198}], {
             RGBColor[
             0.4963011015313157, 0.6010362126622084, 0.9537446506004109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 236}], {
             RGBColor[
             0.5215657583730309, 0.6215471992461331, 0.9557335769344781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 262}], {
             RGBColor[
             0.6925947934866915, 0.7558425031962613, 0.9453221559679248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 267}], {
             RGBColor[
             0.5742881902246892, 0.6630188936425666, 0.9607939215561729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 284}], {
             RGBColor[
             0.451089559217665, 0.5643314458552163, 0.9501854323741439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 286}], {
             RGBColor[
             0.42665665478552006`, 0.5439702828133912, 0.9484071626586352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 332}], {
             RGBColor[
             0.4339830561416238, 0.5503160434324093, 0.9488739944745639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 367}], {
             RGBColor[
             0.43370535358562345`, 0.550075511436138, 0.9488562995132582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 398}], {
             RGBColor[
             0.5980778848144717, 0.6816035838644801, 0.9631650559855467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 191}], {
             RGBColor[
             0.7141569822910812, 0.7765512965344039, 0.9721939481471102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 211}], {
             RGBColor[
             0.7353238695680304, 0.793159862665723, 0.9742538693924414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 214}], {
             RGBColor[
             0.6160982839437641, 0.6966215910677778, 0.9645631668570577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 305}], {
             RGBColor[
             0.67016299635724, 0.7408349968468309, 0.9687305804191177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 334}], {
             RGBColor[
             0.6538512271828165, 0.7275923677942069, 0.9674464581977278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 340}], {
             RGBColor[
             0.7333714548791745, 0.7916346214718876, 0.9740592709426089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 365}], {
             RGBColor[
             0.7095655477176037, 0.7728237631058845, 0.971832493598507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 370}], {
             RGBColor[
             0.7348083567144947, 0.7927571401064981, 0.9742024878889425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 256}], {
             RGBColor[
             0.7434485318897912, 0.7533837110592027, 0.6299081088180281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 281}], {
             RGBColor[
             0.872061232577128, 0.8556450184809136, 0.6415044952333295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 311}], {
             RGBColor[
             0.7396098329771968, 0.7502672823505432, 0.6296059123780112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 386}], {
             RGBColor[
             0.7446356993865384, 0.7543475071143484, 0.6300015669921099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 238}], {
             RGBColor[
             0.4990773755559883, 0.60127111843838, 0.9545641846813605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 246}], {
             RGBColor[
             0.4424383069440331, 0.5454511229592311, 0.9512027862240112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 269}], {
             RGBColor[
             0.5408632671153004, 0.6374639574870797, 0.9572267447417069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 272}], {
             RGBColor[
             0.5537422155454806, 0.648486060208944, 0.9580841268878886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 280}], {
             RGBColor[
             0.5614251632035676, 0.6547234232306267, 0.9586889566710977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 309}], {
             RGBColor[
             0.5242179989079906, 0.6230466627814137, 0.9561661229703697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 325}], {
             RGBColor[
             0.7197242213080947, 0.7809732988833431, 0.9726990422408923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 339}], {
             RGBColor[
             0.8219936662940414, 0.8585227174175769, 0.8161257626835267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 395}], {
             RGBColor[
             0.5715274541250837, 0.6629249181037331, 0.9594842460183504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 343}], {
             RGBColor[
             0.9509378467583771, 0.9606881174123033, 0.874644937911663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 356}], {
             RGBColor[
             0.6114336310720336, 0.6882967172747049, 0.9661922329846563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 369}], {
             RGBColor[
             0.6701512598561431, 0.7391549760936669, 0.9699336683688193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 372}], {
             RGBColor[
             0.9068992557742497, 0.9286008657026183, 0.9909820546859127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 198}], {
             RGBColor[
             0.7842124583392546, 0.8283520926781165, 0.8446349431678809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 205}], {
             RGBColor[
             0.9123556785411726, 0.9295943796064614, 0.8566628075247693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 208}], {
             RGBColor[
             0.7752506772880643, 0.8210765150971246, 0.8439294389354455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 210}], {
             RGBColor[
             0.9904720614708626, 0.9779739463529298, 0.5644802704695787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 219}], {
             RGBColor[
             0.9929928306535004, 0.9913703696462537, 0.7657904602518621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 249}], {
             RGBColor[
             0.7696864447798448, 0.8165592204811342, 0.8434914021699432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 284}], {
             RGBColor[
             0.7390009160256039, 0.7916473258711243, 0.8410757249416139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 293}], {
             RGBColor[
             0.6981450140293932, 0.757061387783164, 0.8382509963436096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 338}], {
             RGBColor[
             0.683204001104285, 0.74412023334458, 0.8372989682118406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 188}], {
             RGBColor[
             0.5111598395072728, 0.6122423622735855, 0.955151133227834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 228}], {
             RGBColor[
             0.604583060869421, 0.6898667908271316, 0.9620141396938162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 238}], {
             RGBColor[
             0.49170823635911576`, 0.5953943612926529, 0.9539116942756107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 273}], {
             RGBColor[
             0.7933766467579908, 0.8390339295811085, 0.965064717191335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 322}], {
             RGBColor[
             0.6823072861402713, 0.7516229751534017, 0.9690516683453763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 330}], {
             RGBColor[
             0.7207555162661827, 0.7816590247451356, 0.9728838286051885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 206}], {
             RGBColor[
             0.6132154085012081, 0.6915426490359766, 0.9655219449241177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 220}], {
             RGBColor[
             0.8364062777326021, 0.872440836081374, 0.9842453265980116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 261}], {
             RGBColor[
             0.6132154085012081, 0.6915426490359766, 0.9655219449241177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 321}], {
             RGBColor[
             0.9260436990123109, 0.9390752090298939, 0.7425686416569696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 228}], {
             RGBColor[
             0.48121285485622733`, 0.5879300510375824, 0.9527935968966843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 238}], {
             RGBColor[
             0.36833803034592205`, 0.4934576215031037, 0.9446911514784788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 273}], {
             RGBColor[
             0.6700064407447971, 0.7370971897915592, 0.9558441743942031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 322}], {
             RGBColor[
             0.5589370801270774, 0.6496862353638524, 0.9598311255482443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 330}], {
             RGBColor[
             0.597385310252989, 0.6797222849555863, 0.9636632858080566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 222}], {
             RGBColor[
             0.710199346646244, 0.7667682203749816, 0.7775262975900711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 226}], {
             RGBColor[
             0.4338585678862626, 0.5502082179625771, 0.9488660621930128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 395}], {
             RGBColor[
             0.46000830971177675`, 0.571758993063229, 0.950835907014482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 212}], {
             RGBColor[
             0.5146461477098087, 0.6158785092268679, 0.9552029418860717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 221}], {
             RGBColor[
             0.4928098741010547, 0.5981508385983657, 0.9534839104386847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 255}], {
             RGBColor[
             0.47649109770895803`, 0.5849025207707629, 0.9521992365834513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 268}], {
             RGBColor[
             0.6228075915553484, 0.7009087752997325, 0.9656461595488384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 270}], {
             RGBColor[
             0.5757624622610996, 0.6640907731435723, 0.9609746523321067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 274}], {
             RGBColor[
             0.631237601323633, 0.7076306362624434, 0.9664502214060959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 295}], {
             RGBColor[
             0.39643448291429184`, 0.5177933565490589, 0.9464814325914178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 324}], {
             RGBColor[
             0.43725328648647355`, 0.5530474979770983, 0.9491102923511788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 351}], {
             RGBColor[
             0.5021829739541146, 0.6057603433124161, 0.9542217951939136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 211}], {
             RGBColor[
             0.6587713846565106, 0.7332836467161448, 0.9666736293827334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 214}], {
             RGBColor[
             0.5395457990322443, 0.6367453751181997, 0.9569829268473495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 312}], {
             RGBColor[
             0.5897482175193416, 0.6778231966934601, 0.9608462864834764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 334}], {
             RGBColor[
             0.5772987422712967, 0.6677161518446287, 0.9598662181880198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 340}], {
             RGBColor[
             0.6568189699676548, 0.7317584055223094, 0.9664790309329008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 365}], {
             RGBColor[
             0.6330130628060839, 0.7129475471563065, 0.964252253588799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 370}], {
             RGBColor[
             0.658255871802975, 0.7328809241569199, 0.9666222478792343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 292}], {
             RGBColor[
             0.4615800062335305, 0.5711971019565543, 0.9514674443380702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 320}], {
             RGBColor[
             0.5827619299660365, 0.667056247943492, 0.9627314969471195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 347}], {
             RGBColor[
             0.49751761212755236`, 0.600372869392017, 0.9542965843178357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 374}], {
             RGBColor[
             0.6054368587942212, 0.6850315221833084, 0.9649221418148282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 382}], {
             RGBColor[
             0.6663218217875526, 0.7325892630685835, 0.9363959158879478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 384}], {
             RGBColor[
             0.4309438884864135, 0.5463253214280681, 0.9490556569252202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 248}], {
             RGBColor[
             0.732221206881954, 0.7845251622448338, 0.7088254963401308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 305}], {
             RGBColor[
             0.7712468772112453, 0.8162079595045658, 0.7118977400641934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 334}], {
             RGBColor[
             0.7549351080368221, 0.8029653304519417, 0.7106136178428034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 360}], {
             RGBColor[
             0.98042537713683, 0.9814043629852641, 0.702602577275841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 201}], {
             RGBColor[
             0.8526139886654778, 0.8855762342396412, 0.9857350248315122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 208}], {
             RGBColor[
             0.6715143665512522, 0.7419782532578196, 0.9688054100299934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 223}], {
             RGBColor[
             0.6362042620277768, 0.7133119197035811, 0.9660256692567306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 230}], {
             RGBColor[
             0.8646962807903822, 0.8950556810127488, 0.9815258053347609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 242}], {
             RGBColor[
             0.7049838567035167, 0.7691502931467769, 0.9714402508975618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 357}], {
             RGBColor[
             0.8808986877423064, 0.9071394095884873, 0.9540993566296766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 364}], {
             RGBColor[
             0.7631717646988141, 0.814914849993733, 0.9770294873257019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 385}], {
             RGBColor[
             0.6325431957164797, 0.7103397011429122, 0.9657374567057775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 387}], {
             RGBColor[
             0.6761568721882845, 0.745747248476458, 0.9691708850797991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 247}], {
             RGBColor[
             0.6231745516101879, 0.6997915525752793, 0.9663301812014433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 253}], {
             RGBColor[
             0.9137887859744789, 0.9335270921043354, 0.9719706075306731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 315}], {
             RGBColor[
             0.5928854315774578, 0.6735566391783663, 0.9644001852565749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 316}], {
             RGBColor[
             0.9193563371520246, 0.9376793626565205, 0.9625461956369974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 343}], {
             RGBColor[
             0.931666254444345, 0.9453214728145318, 0.872806796232797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 358}], {
             RGBColor[
             0.837955849836901, 0.8737400316588606, 0.984376246337358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 359}], {
             RGBColor[
             0.8297179523915241, 0.8673045235641927, 0.9835551697075313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 362}], {
             RGBColor[
             0.6620108726659365, 0.7334072391024717, 0.9688109816721235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 363}], {
             RGBColor[
             0.9324736043449815, 0.945470549362129, 0.8459951176613985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 369}], {
             RGBColor[
             0.650879667542111, 0.7237883314958955, 0.9680955266899534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 372}], {
             RGBColor[
             0.8876276634602176, 0.9132342211048469, 0.9891439130070467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 397}], {
             RGBColor[
             0.7353509216870517, 0.7929479948293701, 0.9745845789845173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 289}], {
             RGBColor[
             0.45017244098102716`, 0.5635583097475858, 0.9501211297109005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 317}], {
             RGBColor[
             0.6366595400476365, 0.7119823888045783, 0.9669542756076124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 326}], {
             RGBColor[
             0.3524006050473302, 0.4775972967422718, 0.9437509177498369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 327}], {
             RGBColor[
             0.5105073856268805, 0.6125409358693711, 0.9548709175676066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 336}], {
             RGBColor[
             0.3907412249934312, 0.5128621426894727, 0.9461186632310509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 376}], {
             RGBColor[
             0.5943837106313004, 0.6786729655449403, 0.9628157749657629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 252}], {
             RGBColor[
             0.6562244711897431, 0.7309292978792441, 0.9666691110228367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 300}], {
             RGBColor[
             0.7289723927495706, 0.7879558235332229, 0.973868118309094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 205}], {
             RGBColor[
             0.7013989105771211, 0.7656761071063125, 0.9715757986894604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 219}], {
             RGBColor[
             0.7820360626894489, 0.8274520971461048, 0.8807034514165535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 236}], {
             RGBColor[
             0.5985203472169183, 0.6849448067618923, 0.9615368606666393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 284}], {
             RGBColor[
             0.5280441480615524, 0.6277290533709755, 0.9559887161063051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 332}], {
             RGBColor[
             0.5109376449855112, 0.6137136509481684, 0.954677278206725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 367}], {
             RGBColor[
             0.5106599424295108, 0.6134731189518972, 0.9546595832454194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 398}], {
             RGBColor[
             0.6750324736583591, 0.7450011913802392, 0.9689683397177078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 216}], {
             RGBColor[
             0.5772330016165985, 0.667662780619562, 0.959861042842866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 298}], {
             RGBColor[
             0.5345315390839824, 0.6329958096566193, 0.9564994272916871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 299}], {
             RGBColor[
             0.6543859305709873, 0.7289251591056587, 0.9668741093186383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 306}], {
             RGBColor[
             0.6553934738395211, 0.7297122595646499, 0.9669745318156185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 342}], {
             RGBColor[
             0.647145662407566, 0.7232690065883179, 0.9661524670522612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 353}], {
             RGBColor[
             0.5829998484291571, 0.6723445666554853, 0.9603150301486065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 361}], {
             RGBColor[
             0.47212460591133687`, 0.5800014433557675, 0.9522302021393153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 393}], {
             RGBColor[
             0.5388159265249652, 0.6364740683906638, 0.9568367099652696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 207}], {
             RGBColor[
             0.3962244499816959, 0.5176114365794064, 0.9464680494786777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 333}], {
             RGBColor[
             0.28512754910395577`, 0.4093822313853751, 0.939828529136663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 368}], {
             RGBColor[
             0.5720611175797564, 0.6600891155477342, 0.9610756003248153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 223}], {
             RGBColor[
             0.7011216458635728, 0.7648143124435669, 0.9722867998959575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 230}], {
             RGBColor[
             0.9296136646261783, 0.9465580737527346, 0.9877869359739876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 245}], {
             RGBColor[
             0.6516081159433641, 0.7227805999598975, 0.9688963157782091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 364}], {
             RGBColor[
             0.8280891485346101, 0.8664172427337189, 0.9832906179649288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 385}], {
             RGBColor[
             0.6974605795522757, 0.7618420938828981, 0.9719985873450043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 218}], {
             RGBColor[
             0.4907396958863629, 0.5964938493557242, 0.9533143970382318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 229}], {
             RGBColor[
             0.7695300628643017, 0.8188916702257705, 0.9421989440523486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 260}], {
             RGBColor[
             0.46032797462996317`, 0.5701527449409853, 0.9513765890518033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 307}], {
             RGBColor[
             0.465330520692237, 0.574485698904851, 0.9516953468633136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 341}], {
             RGBColor[
             0.6430778249466029, 0.7198830276063083, 0.9658893386745568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 349}], {
             RGBColor[
             0.4791851571033827, 0.586485888609912, 0.9525781520442578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 366}], {
             RGBColor[
             0.611943235529995, 0.6955604497224105, 0.9627861337707897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 232}], {
             RGBColor[
             0.8509883764156788, 0.882857845930766, 0.9086674584828379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 257}], {
             RGBColor[
             0.7959286479815638, 0.8392519147601841, 0.9035849560452699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 275}], {
             RGBColor[
             0.6961139639058458, 0.7568795306035214, 0.8960969622257958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 280}], {
             RGBColor[
             0.7308907434777929, 0.7864512139598142, 0.8984649339610389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 297}], {
             RGBColor[
             0.8383468703900715, 0.8729822053445573, 0.9074074713037958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 309}], {
             RGBColor[
             0.6936835791822159, 0.7547744535106014, 0.895942100260311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 322}], {
             RGBColor[
             0.859142005611369, 0.8892275230283162, 0.9094801360410674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 325}], {
             RGBColor[
             0.88918980158232, 0.9127010896125307, 0.9124750195308335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 339}], {
             RGBColor[
             0.9914592465682667, 0.9902505081467643, 0.7559017399734678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 224}], {
             RGBColor[
             0.6603790934577042, 0.7306297006527653, 0.969339129651109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 276}], {
             RGBColor[
             0.3397941730027175, 0.46506234903391863`, 0.9430068126918532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 290}], {
             RGBColor[
             0.6782549190645426, 0.7446190158738438, 0.9618778210412218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 297}], {
             RGBColor[
             0.549526313775261, 0.6433014857998212, 0.9584838627285341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 318}], {
             RGBColor[
             0.40769262808478357`, 0.5275445960449097, 0.9471987916464947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 345}], {
             RGBColor[
             0.45217247778449843`, 0.5649719892881846, 0.9503366147330299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 219}], {
             RGBColor[
             0.910179282891367, 0.9286943840744497, 0.8927313157734418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 284}], {
             RGBColor[
             0.6561873682634705, 0.7289713402993204, 0.9680165804631935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 293}], {
             RGBColor[
             0.6153314662672598, 0.69438540221136, 0.9651918518651891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 338}], {
             RGBColor[
             0.6003904533421516, 0.681444247772776, 0.9642398237334202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 220}], {
             RGBColor[
             0.5907112487434869, 0.6736476004925641, 0.9633624331642612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 321}], {
             RGBColor[
             0.6803486700231955, 0.740281973441084, 0.7216857482232192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 328}], {
             RGBColor[
             0.4952716105841485, 0.5987932245098333, 0.9540524191374309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 386}], {
             RGBColor[
             0.447764030110656, 0.5602244304893413, 0.9503124483765563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 254}], {
             RGBColor[
             0.5147712149940433, 0.6155362120579249, 0.9553354198621125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 333}], {
             RGBColor[
             0.2900239008777401, 0.4136232051940313, 0.9401405203420147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 230}], {
             RGBColor[
             0.7485140425119526, 0.8029600927709131, 0.9708573211724688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 240}], {
             RGBColor[
             0.6036159358818127, 0.6889354831716678, 0.9620379290077737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 242}], {
             RGBColor[
             0.5888016184250872, 0.6770547049049411, 0.9607717667352698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 357}], {
             RGBColor[
             0.7647164494638768, 0.8150438213466517, 0.9434308724673846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 385}], {
             RGBColor[
             0.5163609574380501, 0.6182441129010766, 0.9550689725434856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 387}], {
             RGBColor[
             0.5599746339098548, 0.6536516602346223, 0.958502400917507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 241}], {
             RGBColor[
             0.7485394841567361, 0.8034840012248107, 0.9755710783477036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 270}], {
             RGBColor[
             0.708830678161217, 0.7724631801830081, 0.9716132756659602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 310}], {
             RGBColor[
             0.7727379382136108, 0.8227265876953669, 0.9778931079674057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 323}], {
             RGBColor[
             0.6977156203476582, 0.7637800125414878, 0.9705054305792256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 346}], {
             RGBColor[
             0.6867482440184363, 0.7552122147979522, 0.9694123050026877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 390}], {
             RGBColor[
             0.8249514235896441, 0.8635710982600155, 0.9555144980329042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 249}], {
             RGBColor[
             0.7649892799474014, 0.8022628016557987, 0.6782497206363323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 266}], {
             RGBColor[
             0.9830330082720786, 0.9742496287701993, 0.6587423807115405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 293}], {
             RGBColor[
             0.6934478491969498, 0.7427649689578284, 0.6730093148099985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 315}], {
             RGBColor[
             0.6508331779186651, 0.7058542825722345, 0.6702939456388204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 316}], {
             RGBColor[
             0.9773040834932318, 0.9699770060503887, 0.6684399560192431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 387}], {
             RGBColor[
             0.7751960180926531, 0.8105490914904274, 0.6790532324516403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 397}], {
             RGBColor[
             0.793298668028259, 0.8252456382232383, 0.6804783393667628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 214}], {
             RGBColor[
             0.5607126863091936, 0.6533539412495187, 0.9590428480926808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 248}], {
             RGBColor[
             0.5757517283933781, 0.6658845497688398, 0.9601380179306782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 263}], {
             RGBColor[
             0.8210332085098937, 0.8605840129895468, 0.9588624509109609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 312}], {
             RGBColor[
             0.6109151047962909, 0.6944317628247791, 0.9629062077288075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 334}], {
             RGBColor[
             0.598465629548246, 0.6843247179759477, 0.9619261394333509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 340}], {
             RGBColor[
             0.677985857244604, 0.7483669716536285, 0.968538952178232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 370}], {
             RGBColor[
             0.6794227590799242, 0.749489490288239, 0.9686821691245656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 268}], {
             RGBColor[
             0.7199869301114192, 0.7807767841043871, 0.9730275076136706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 270}], {
             RGBColor[
             0.6729418008171704, 0.743958781948227, 0.9683560003969389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 274}], {
             RGBColor[
             0.7284169398797039, 0.7874986450670981, 0.9738315694709282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 295}], {
             RGBColor[
             0.4936138214703627, 0.5976613653537136, 0.9538627806562501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 310}], {
             RGBColor[
             0.7368490608695641, 0.7942221894605858, 0.9746358326983844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 324}], {
             RGBColor[
             0.5344326250425444, 0.6329155067817531, 0.9564916404160111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 351}], {
             RGBColor[
             0.5993623125101855, 0.6856283521170708, 0.9616031432587459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 373}], {
             RGBColor[
             0.6165357841614965, 0.6995705500596865, 0.9629551018556366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 390}], {
             RGBColor[
             0.7890625462455975, 0.8350667000252344, 0.9522572227638828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 227}], {
             RGBColor[
             0.7238314261990164, 0.7783171500404216, 0.7576023473476705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 296}], {
             RGBColor[
             0.6441870715515017, 0.7080393613699585, 0.7525712186009219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 308}], {
             RGBColor[
             0.8145178551614193, 0.8519404784491684, 0.7647415152309259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 352}], {
             RGBColor[
             0.8775134392054531, 0.9012620172556893, 0.7709458641186204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 248}], {
             RGBColor[
             0.45652614276911185`, 0.5693462781708947, 0.9504473153952946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 263}], {
             RGBColor[
             0.7018076228856274, 0.7640457413916016, 0.9491717483755773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 312}], {
             RGBColor[
             0.49168951917202464`, 0.5978934912268341, 0.9532155051934238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 340}], {
             RGBColor[
             0.5587602716203378, 0.6518287000556833, 0.9588482496428483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 218}], {
             RGBColor[
             0.5314368867930006, 0.6295003281073462, 0.956541019769253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 229}], {
             RGBColor[
             0.8102272537709394, 0.8518981489773925, 0.9454255667833695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 329}], {
             RGBColor[
             0.6136579219399243, 0.6972008376480547, 0.9627513367837258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 349}], {
             RGBColor[
             0.5198823480100203, 0.619492367361534, 0.9558047747752789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 231}], {
             RGBColor[
             0.4864834116285003, 0.592410940416022, 0.9531526973748623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 235}], {
             RGBColor[
             0.49312663719442495`, 0.5981649685030006, 0.9535759978335494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 298}], {
             RGBColor[
             0.5350357083900001, 0.6334051170118129, 0.9565391173462898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 313}], {
             RGBColor[
             0.7262611928720117, 0.7855330445669984, 0.9739098608443783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 361}], {
             RGBColor[
             0.4726287752173546, 0.5804107507109612, 0.9522698921939181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 393}], {
             RGBColor[
             0.539320095830983, 0.6368833757458574, 0.9568764000198724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 396}], {
             RGBColor[
             0.6014337655200893, 0.6873100509884055, 0.9617662156276678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 220}], {
             RGBColor[
             0.9045839254625339, 0.9234139969816313, 0.8540841234273004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 230}], {
             RGBColor[
             0.9684808448506348, 0.9741598634755715, 0.854830074246841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 233}], {
             RGBColor[
             0.7229074094598272, 0.7784734561308597, 0.8380059996314374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 242}], {
             RGBColor[
             0.8087684207637693, 0.8482544756095997, 0.8447445198096419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 244}], {
             RGBColor[
             0.975277883623033, 0.9792290838628965, 0.8433244605568017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 264}], {
             RGBColor[
             0.7440711549620898, 0.795730320653186, 0.8396513140518402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 321}], {
             RGBColor[
             0.9942213467422426, 0.9900483699301512, 0.6124074384862583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 357}], {
             RGBColor[
             0.984683251802559, 0.9862435920513102, 0.8274036255417567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 364}], {
             RGBColor[
             0.8669563287590667, 0.8940190324565558, 0.8503337562377822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 366}], {
             RGBColor[
             0.8280057710688979, 0.8635905607537933, 0.8464515286608827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 229}], {
             RGBColor[
             0.6971290968782835, 0.7591635352189592, 0.9367616988543207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 260}], {
             RGBColor[
             0.38792700864394497`, 0.5104246099341743, 0.9459393438537754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 329}], {
             RGBColor[
             0.5005597650472684, 0.6044662238896217, 0.954087468854677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 349}], {
             RGBColor[
             0.4067841911173645, 0.5267577536031008, 0.94714090684623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 284}], {
             RGBColor[
             0.7368245203757983, 0.7907473303391128, 0.8771442331902863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 293}], {
             RGBColor[
             0.6959686183795875, 0.7561613922511523, 0.874319504592282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 338}], {
             RGBColor[
             0.6810276054544794, 0.7432202378125684, 0.873367476460513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 233}], {
             RGBColor[
             0.6322256019721743, 0.70960524668719, 0.9660076910422921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 244}], {
             RGBColor[
             0.8845960761353799, 0.9103608744192269, 0.9713261519676564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 321}], {
             RGBColor[
             0.9035395392545895, 0.9211801604864814, 0.740409129897113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 341}], {
             RGBColor[
             0.7684585529978528, 0.8190449291940214, 0.9775564249755044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 366}], {
             RGBColor[
             0.7373239635812449, 0.7947223513101236, 0.9744532200717374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 239}], {
             RGBColor[
             0.7287713562386906, 0.7874652282686394, 0.9742291058425272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 255}], {
             RGBColor[
             0.5518341626562749, 0.6470428589469154, 0.9578615532008965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 268}], {
             RGBColor[
             0.6981506565026653, 0.763049113475885, 0.9713084761662837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 324}], {
             RGBColor[
             0.5125963514337905, 0.6151878361532508, 0.9547726089686241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 351}], {
             RGBColor[
             0.5775260389014315, 0.6679006814885686, 0.9598841118113589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 400}], {
             RGBColor[
             0.6933941548197858, 0.7592673086152002, 0.9708519041401595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 333}], {
             RGBColor[
             0.5865478291024451, 0.6476648372381913, 0.7700868081757068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 230}], {
             RGBColor[
             0.7132039379884773, 0.7742937592166745, 0.9680775803992061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 242}], {
             RGBColor[
             0.5534915139016118, 0.6483883713507026, 0.9579920259620072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 245}], {
             RGBColor[
             0.435198389305663, 0.5505162854238375, 0.9491869602034275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 328}], {
             RGBColor[
             0.5538673804410379, 0.6486935167400034, 0.9580216155528352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 364}], {
             RGBColor[
             0.611679421896909, 0.6941529281976587, 0.9635812623901472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 385}], {
             RGBColor[
             0.48105085291457467`, 0.589577779346838, 0.9522892317702228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 290}], {
             RGBColor[
             0.9280756412892057, 0.9452219578031176, 0.9838355564265064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 318}], {
             RGBColor[
             0.6575133503094466, 0.7281475379741833, 0.9691565270317792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 345}], {
             RGBColor[
             0.7019932000091614, 0.7655749312174582, 0.9722943501183144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 240}], {
             RGBColor[
             0.7999168887649251, 0.8443390848403217, 0.9694786054638429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 243}], {
             RGBColor[
             0.7066052801440512, 0.7687306693438716, 0.9620328488858452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 337}], {
             RGBColor[
             0.6510232708305186, 0.7209130285342435, 0.9584014962647427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 367}], {
             RGBColor[
             0.6979991142614329, 0.7616011430395594, 0.9613947554690532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 398}], {
             RGBColor[
             0.8623716454902811, 0.8931292154679015, 0.9757035119413415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 234}], {
             RGBColor[
             0.43866293516633803`, 0.5543695194260577, 0.9491721922277641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 281}], {
             RGBColor[
             0.6121729238876628, 0.6935550699581099, 0.9641719236512408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 350}], {
             RGBColor[
             0.6968616524966404, 0.7603570447737784, 0.9575439861284567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 355}], {
             RGBColor[
             0.4860801277816656, 0.5933395345959382, 0.952773913355297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 392}], {
             RGBColor[
             0.3419707025356166, 0.46449044721265875`, 0.9432354657809362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 395}], {
             RGBColor[
             0.4676368425104416, 0.5783664447522254, 0.9513219903787662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 296}], {
             RGBColor[
             0.37423220291748693`, 0.4972386735235368, 0.9451188429508321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 308}], {
             RGBColor[
             0.5445629865274045, 0.6411397906027467, 0.9572891395808361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 352}], {
             RGBColor[
             0.6075585705714384, 0.6904613294092676, 0.9634934884685306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 375}], {
             RGBColor[
             0.6283445010929202, 0.7066994563115723, 0.9655652357673472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 238}], {
             RGBColor[
             0.46176125170807025`, 0.5710820500566498, 0.9515541579444611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 273}], {
             RGBColor[
             0.7634296621069453, 0.8147216183451054, 0.9627071808601855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 330}], {
             RGBColor[
             0.6908085316151372, 0.7573467135091325, 0.970526292274039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 368}], {
             RGBColor[
             0.6637151065849884, 0.7361811239579235, 0.9678258728694857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 260}], {
             RGBColor[
             0.6667173756218838, 0.7328224308042204, 0.9348238908678921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[
             0.7793501320252072, 0.8268640447596678, 0.9429720158687935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 349}], {
             RGBColor[
             0.6855745580953033, 0.7491555744731471, 0.9360254538603466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 233}], {
             RGBColor[
             0.6961225213602752, 0.7603511131811302, 0.9667536418618327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 242}], {
             RGBColor[
             0.7819835326642173, 0.8301321326598703, 0.9734921620400372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 244}], {
             RGBColor[
             0.9484929955234809, 0.9611067409131671, 0.9720721027871969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 245}], {
             RGBColor[
             0.6636904080682685, 0.7322600467330052, 0.9646870962814578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 328}], {
             RGBColor[
             0.7823593992036434, 0.830437278049171, 0.9735217516308654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 357}], {
             RGBColor[
             0.957898363703007, 0.9681212491015807, 0.956151267772152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 364}], {
             RGBColor[
             0.8401714406595145, 0.8758966895068263, 0.9790813984681774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 385}], {
             RGBColor[
             0.7095428716771801, 0.7713215406560057, 0.967789367848253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 235}], {
             RGBColor[
             0.401872877900309, 0.5225038209442672, 0.946827962310943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 298}], {
             RGBColor[
             0.4437819490958842, 0.5577439694530795, 0.9497910818236834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 336}], {
             RGBColor[
             0.3792090515347164, 0.5028735536634252, 0.9453838433357622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 393}], {
             RGBColor[
             0.448066336536867, 0.5612222281871239, 0.950128364497266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 396}], {
             RGBColor[
             0.5101800062259734, 0.6116489034296719, 0.9550181801050615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 257}], {
             RGBColor[
             0.6587175399345804, 0.7327215628779863, 0.96702380311176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 275}], {
             RGBColor[
             0.5589028558588622, 0.6503491787213236, 0.9595358092922859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 279}], {
             RGBColor[
             0.8279542058298491, 0.866344787991665, 0.9774736823646536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 280}], {
             RGBColor[
             0.5936796354308096, 0.6799208620776164, 0.9619037810275289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 288}], {
             RGBColor[
             0.6930741851532856, 0.7601540880914297, 0.9700428156957284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 297}], {
             RGBColor[
             0.701135762343088, 0.7664518534623594, 0.9708463183702858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 309}], {
             RGBColor[
             0.5564724711352325, 0.6482441016284035, 0.959380947326801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 325}], {
             RGBColor[
             0.7519786935353365, 0.8061707377303329, 0.9759138665973235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 339}], {
             RGBColor[
             0.8542481385212832, 0.8837201562645665, 0.8193405870399579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 242}], {
             RGBColor[
             0.5364100972734097, 0.6344457253151584, 0.9566680874246336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 244}], {
             RGBColor[
             0.7029195601326734, 0.7654203335684553, 0.9552480281717933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 264}], {
             RGBColor[
             0.47171283147173015`, 0.5819215703587448, 0.9515748816668319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 307}], {
             RGBColor[
             0.4090347327407802, 0.5287070596417927, 0.9472843093683982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 348}], {
             RGBColor[
             0.7181991215314962, 0.7765404914407928, 0.9170545928108198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 357}], {
             RGBColor[
             0.7123249283121993, 0.7724348417568689, 0.9393271931567484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 366}], {
             RGBColor[
             0.5556474475785382, 0.649781810459352, 0.9583750962758744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[
             0.6626142715383792, 0.7332813244816513, 0.9691521117635777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 246}], {
             RGBColor[
             0.33572352981080167`, 0.4584464993822077, 0.9428605772548939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 269}], {
             RGBColor[
             0.434148489982069, 0.5504593339100563, 0.9488845357725896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 272}], {
             RGBColor[
             0.44702743841224923`, 0.5614814366319205, 0.9497419179187713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 350}], {
             RGBColor[
             0.694037486978051, 0.7579108945482624, 0.9573640327989237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 355}], {
             RGBColor[
             0.4832559622630763, 0.5908933843704224, 0.952593960025764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 392}], {
             RGBColor[
             0.33914653701702735`, 0.4620442969871429, 0.9430555124514032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 395}], {
             RGBColor[
             0.46481267699185225`, 0.5759202945267097, 0.9511420370492332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 298}], {
             RGBColor[
             0.4504251746618089, 0.5634979975400579, 0.9502143822823705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 313}], {
             RGBColor[
             0.6416506591438205, 0.7156259250952435, 0.9675851257804589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 317}], {
             RGBColor[
             0.6317705921548462, 0.7077478278655094, 0.9666427561710107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 336}], {
             RGBColor[
             0.3858522771006411, 0.5086275817504038, 0.9458071437944492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 393}], {
             RGBColor[
             0.4547095621027917, 0.5669762562741023, 0.950551664955953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 396}], {
             RGBColor[
             0.516823231791898, 0.6174029315166505, 0.9554414805637486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 267}], {
             RGBColor[
             0.6765074359102918, 0.7469274877422505, 0.9685861316224014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 284}], {
             RGBColor[
             0.5533088049032676, 0.6482400399549002, 0.9579776424403723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 286}], {
             RGBColor[
             0.5288759004711225, 0.6278788769130752, 0.9561993727248637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 332}], {
             RGBColor[
             0.5362023018272264, 0.6342246375320932, 0.9566662045407923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 367}], {
             RGBColor[
             0.5359245992712259, 0.633984105535822, 0.9566485095794867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 383}], {
             RGBColor[
             0.5913105321303342, 0.6790915540761352, 0.9609692776126006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 398}], {
             RGBColor[
             0.7002971305000742, 0.765512177964164, 0.9709572660517751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 251}], {
             RGBColor[
             0.5309981533791539, 0.6301272479642274, 0.9562212662257847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 296}], {
             RGBColor[
             0.44703185727724754`, 0.5563407125198454, 0.9508498984159531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 308}], {
             RGBColor[
             0.6173626408871651, 0.7002418295990553, 0.9630201950459572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 380}], {
             RGBColor[
             0.7282928556610593, 0.7873103406326892, 0.9739225894350709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 269}], {
             RGBColor[
             0.3906723187570771, 0.5128024595708709, 0.9461142725866019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 272}], {
             RGBColor[
             0.4035512671872573, 0.5238245622927351, 0.9469716547327836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 280}], {
             RGBColor[
             0.41123421484534434`, 0.5300619253144179, 0.9475764845159926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 309}], {
             RGBColor[
             0.37402705054976726`, 0.49838516486520495`, 0.9450536508152647]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 325}], {
             RGBColor[
             0.5695332729498713, 0.6563118009671343, 0.9615865700857873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 339}], {
             RGBColor[
             0.671802717935818, 0.7338612195013681, 0.8050132905284216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 246}], {
             RGBColor[
             0.562499031701432, 0.6398044546633171, 0.9630204501202406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 269}], {
             RGBColor[
             0.6609239918726995, 0.7318172891911656, 0.9690444086379362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 272}], {
             RGBColor[
             0.6738029403028797, 0.7428393919130298, 0.9699017907841179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 350}], {
             RGBColor[
             0.9208129888686816, 0.939268849829372, 0.9775239056642704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 355}], {
             RGBColor[
             0.7100314641537067, 0.7722513396515318, 0.9727538328911106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 392}], {
             RGBColor[
             0.5659220389076578, 0.6434022522682523, 0.9632153853167498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 242}], {
             RGBColor[
             0.6370854260340774, 0.7161075230606249, 0.9646727698753421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 243}], {
             RGBColor[
             0.5585881348699291, 0.6523798858309013, 0.9584931755698484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 285}], {
             RGBColor[
             0.7621792478302677, 0.33208076710911716`, 0.43145831071594876`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 337}], {
             RGBColor[
             0.5030061255563965, 0.6045622450212733, 0.9548618229487459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 357}], {
             RGBColor[
             0.813000257072867, 0.8540966395023354, 0.9473318756074569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 399}], {
             RGBColor[
             0.6991345990858635, 0.7648885295164115, 0.9706468611187395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 270}], {
             RGBColor[
             0.7737669213639803, 0.823191866906734, 0.9780855135247173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 310}], {
             RGBColor[
             0.837674181416374, 0.8734552744190927, 0.9843653458261628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 323}], {
             RGBColor[
             0.7626518635504214, 0.8145086992652135, 0.9769776684379826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 346}], {
             RGBColor[
             0.7516844872211994, 0.8059409015216781, 0.9758845428614447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 389}], {
             RGBColor[
             0.7680466843044096, 0.8187231742403855, 0.9775153737532738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 390}], {
             RGBColor[
             0.8898876667924074, 0.9142997849837413, 0.9619867358916612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 244}], {
             RGBColor[
             0.7887805714366154, 0.8352013530471952, 0.9619865483499979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 357}], {
             RGBColor[
             0.7981859396161415, 0.8422158612356088, 0.946065713334953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 364}], {
             RGBColor[
             0.6804590165726491, 0.7499913016408545, 0.9689958440309784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 385}], {
             RGBColor[
             0.5498304475903146, 0.6454161527900337, 0.957703813411054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 337}], {
             RGBColor[
             0.4096945169355226, 0.5289538295248233, 0.9474160663707482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 367}], {
             RGBColor[
             0.4566703603664368, 0.569641944030139, 0.9504093255750587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 398}], {
             RGBColor[
             0.621042891595285, 0.7011700164584811, 0.9647180820473471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 264}], {
             RGBColor[
             0.7240833056349358, 0.7826771980907816, 0.9568933425921962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 307}], {
             RGBColor[
             0.661405206903986, 0.7294626873738295, 0.9526027702937625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 321}], {
             RGBColor[
             0.9742334974150887, 0.9769952473677468, 0.7296494670266143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 341}], {
             RGBColor[
             0.839152511158352, 0.8748600160752866, 0.9667967621050058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 348}], {
             RGBColor[
             0.9705695956947019, 0.9772961191728297, 0.9223730537361841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 357}], {
             RGBColor[
             0.9646954024754051, 0.9731904694889058, 0.9446456540821127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 366}], {
             RGBColor[
             0.808017921741744, 0.8505374381913888, 0.9636935572012386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 328}], {
             RGBColor[
             0.5043538505208292, 0.606659804256334, 0.9546311314350868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 364}], {
             RGBColor[
             0.5621658919767003, 0.6521192157139893, 0.9601907782723988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 400}], {
             RGBColor[
             0.6021601149883271, 0.6833630066980252, 0.9641770286549343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 269}], {
             RGBColor[
             0.33403325014512186`, 0.4569824640917221, 0.9427528741292526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 272}], {
             RGBColor[
             0.3469121985753021, 0.4680045668135863, 0.9436102562754343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 350}], {
             RGBColor[
             0.593922247141104, 0.6644340247299283, 0.9512323711555866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 355}], {
             RGBColor[
             0.3831407224261292, 0.49741651455208824`, 0.9464622983824269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 392}], {
             RGBColor[
             0.2390312971800802, 0.36856742716880875`, 0.9369238508080662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 395}], {
             RGBColor[
             0.3646974371549051, 0.4824434247083755, 0.945010375405896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 253}], {
             RGBColor[
             0.6670839336286621, 0.7342364039397569, 0.9508497205606397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 266}], {
             RGBColor[
             0.6783804095850545, 0.7426612972117526, 0.9317277333592615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 301}], {
             RGBColor[
             0.45465500359949657`, 0.5660618282155871, 0.9507877908059177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 315}], {
             RGBColor[
             0.34618057923164103`, 0.47426595101378777`, 0.9432792982865414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 316}], {
             RGBColor[
             0.6726514848062077, 0.738388674491942, 0.9414253086669641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 343}], {
             RGBColor[
             0.6849614020985282, 0.7460307846499534, 0.8516859092627636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 358}], {
             RGBColor[
             0.5912509974910842, 0.674449343494282, 0.9632553593673245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 359}], {
             RGBColor[
             0.5830131000457074, 0.6680138353996141, 0.962434282737498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 362}], {
             RGBColor[
             0.4153060203201197, 0.5341165509378931, 0.9476900947020901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 363}], {
             RGBColor[
             0.6857687519991648, 0.7461798611975505, 0.824874230691365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 369}], {
             RGBColor[
             0.40417481519629417`, 0.524497643331317, 0.9469746397199199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 397}], {
             RGBColor[
             0.48864606934123495`, 0.5936573066647917, 0.9534636920144839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 276}], {
             RGBColor[
             0.3702975798128451, 0.49098741301728066`, 0.945087358175587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 340}], {
             RGBColor[
             0.5737993137045223, 0.6643593085750044, 0.9599434194808458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 360}], {
             RGBColor[
             0.7197693551081722, 0.7787560874306461, 0.9453195661690021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 266}], {
             RGBColor[
             0.7622473915810608, 0.8128349028984037, 0.937753512411905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 293}], {
             RGBColor[
             0.4726622325059319, 0.5813502430860329, 0.952020446510363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 315}], {
             RGBColor[
             0.4300475612276472, 0.5444395567004389, 0.9493050773391849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 316}], {
             RGBColor[
             0.756518466802214, 0.8085622801785932, 0.9474510877196075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 387}], {
             RGBColor[
             0.5544104014016353, 0.6491343656186319, 0.9580643641520048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 397}], {
             RGBColor[
             0.5725130513372412, 0.6638309123514428, 0.9594894710671273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 356}], {
             RGBColor[
             0.500221950756583, 0.6007024911845203, 0.9552973822606794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 363}], {
             RGBColor[
             0.8405335163435631, 0.8732429678697159, 0.8369384086162874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 372}], {
             RGBColor[
             0.7956875754587991, 0.8410066396124337, 0.9800872039619358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 283}], {
             RGBColor[
             0.5902667450677662, 0.6770852371648342, 0.9616794692333697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 308}], {
             RGBColor[
             0.5488849279817961, 0.6446485373766655, 0.957629378643919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 380}], {
             RGBColor[
             0.6598151427556902, 0.7317170484102994, 0.9685317730330327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 381}], {
             RGBColor[
             0.45045868278487433`, 0.5643365353074961, 0.9499928460625249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 282}], {
             RGBColor[
             0.7106036754943301, 0.7738482591749148, 0.9717899914705228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 300}], {
             RGBColor[
             0.7713985703308983, 0.8215369895063158, 0.9777976327603912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 367}], {
             RGBColor[
             0.5733574216274447, 0.6635114407890819, 0.9601849288162003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 398}], {
             RGBColor[
             0.737729952856293, 0.7950395132174239, 0.9744936852884887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 266}], {
             RGBColor[
             0.9689946439493455, 0.9763968367408087, 0.9373681596884913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 301}], {
             RGBColor[
             0.7452692379637875, 0.7997973677446433, 0.9564282171351475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 315}], {
             RGBColor[
             0.636794813595932, 0.7080014905428439, 0.9489197246157712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 316}], {
             RGBColor[
             0.9632657191704987, 0.9721242140209981, 0.9470657349961938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 343}], {
             RGBColor[
             0.9755756364628192, 0.9797663241790096, 0.8573263355919933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 358}], {
             RGBColor[
             0.8818652318553752, 0.9081848830233381, 0.9688957856965543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 359}], {
             RGBColor[
             0.8736273344099984, 0.9017493749286702, 0.9680747090667278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 362}], {
             RGBColor[
             0.7059202546844108, 0.7678520904669492, 0.9533305210313199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 369}], {
             RGBColor[
             0.6947890495605852, 0.7582331828603731, 0.9526150660491497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 394}], {
             RGBColor[
             0.8823395775024261, 0.9085554454479747, 0.9689430640376403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 397}], {
             RGBColor[
             0.7792603037055259, 0.8273928461938478, 0.9591041183437137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 303}], {
             RGBColor[
             0.5284518585527099, 0.6273856978993034, 0.9562071383723527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 268}], {
             RGBColor[
             0.6818318801105686, 0.7498007956482822, 0.9700238023110502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 324}], {
             RGBColor[
             0.4962775750416938, 0.601939518325648, 0.9534879351133907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 328}], {
             RGBColor[
             0.5792691139601911, 0.6693157883459062, 0.9600213330650788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 351}], {
             RGBColor[
             0.5612072625093348, 0.6546523636609658, 0.9585994379561255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 400}], {
             RGBColor[
             0.6770753784276892, 0.7460189907875974, 0.9695672302849261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 311}], {
             RGBColor[
             0.5217946468031303, 0.622655426712565, 0.9554967324745647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 313}], {
             RGBColor[
             0.700209280268566, 0.7643829282902328, 0.9718589588529347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 386}], {
             RGBColor[
             0.5268205132124719, 0.6267356514763702, 0.9558923870886633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 275}], {
             RGBColor[
             0.5038431274247472, 0.6067432475507417, 0.9544533068547179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 276}], {
             RGBColor[
             0.43634389313642963`, 0.544606785525875, 0.9502867658960369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 279}], {
             RGBColor[
             0.7728944773957341, 0.8227388568210832, 0.9723911799270856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 280}], {
             RGBColor[
             0.5386199069966946, 0.6363149309070345, 0.9568212785899609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 288}], {
             RGBColor[
             0.6380144567191706, 0.7165481569208478, 0.9649603132581603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 309}], {
             RGBColor[
             0.5014127427011175, 0.6046381704578216, 0.954298444889233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 325}], {
             RGBColor[
             0.6969189651012215, 0.762564806559751, 0.9708313641597555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 339}], {
             RGBColor[
             0.7991884100871682, 0.8401142250939846, 0.8142580846023899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 277}], {
             RGBColor[
             0.7436888482283532, 0.7996248839417313, 0.975347109192803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 302}], {
             RGBColor[
             0.6803298498432522, 0.7481871947623562, 0.9703592567482695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 377}], {
             RGBColor[
             0.6118527263874622, 0.6895469176662095, 0.9658105099714812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 378}], {
             RGBColor[
             0.8876192590177088, 0.9132275196305228, 0.9891431113838176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 379}], {
             RGBColor[
             0.8638659567333442, 0.8942872811551847, 0.9868775002071115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 262}], {
             RGBColor[
             0.7026129636383538, 0.7645197386537588, 0.9459605049112686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 331}], {
             RGBColor[
             0.6438961231905317, 0.7184778565820642, 0.9673106520760768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 335}], {
             RGBColor[
             0.4604834196089371, 0.5725018385243946, 0.9507746333662278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 307}], {
             RGBColor[
             0.362517833449819, 0.48841645948330104`, 0.9443202936788571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 329}], {
             RGBColor[
             0.47014804379086866`, 0.5781251194748828, 0.9521496608682483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 341}], {
             RGBColor[
             0.5402651377041849, 0.6338137881847583, 0.9585142854901003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 349}], {
             RGBColor[
             0.37637246986096473`, 0.5004166491883619, 0.9452030988598014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 366}], {
             RGBColor[
             0.509130548287577, 0.6094912103008605, 0.9554110805863333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 306}], {
             RGBColor[
             0.5507892474402771, 0.6424602296560491, 0.9593833811666707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 284}], {
             RGBColor[
             0.7243378400169282, 0.7825353439050284, 0.947566221473819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 286}], {
             RGBColor[
             0.6999049355847833, 0.7621741808632034, 0.9457879517583103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 331}], {
             RGBColor[
             0.9071262338381325, 0.928004519174379, 0.964053092232408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 332}], {
             RGBColor[
             0.707231336940887, 0.7685199414822215, 0.9462547835742389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 338}], {
             RGBColor[
             0.6685409250956094, 0.7350082513784841, 0.9437894647440457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 264}], {
             RGBColor[
             0.7275023610301601, 0.7852271240063504, 0.9511057736405462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 312}], {
             RGBColor[
             0.7520100413727246, 0.805123562966862, 0.9530351080117039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 348}], {
             RGBColor[
             0.973988651089926, 0.9798460450883985, 0.9165854847845339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 307}], {
             RGBColor[
             0.4301984782430428, 0.545963924164119, 0.9489296237888012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 312}], {
             RGBColor[
             0.5173842573165572, 0.6190748738415829, 0.9551495304583927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 348}], {
             RGBColor[
             0.7393628670337586, 0.7937973559631193, 0.9186999072312227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 357}], {
             RGBColor[
             0.7334886738144619, 0.7896917062791953, 0.9409725075771513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 366}], {
             RGBColor[
             0.5768111930808008, 0.6670386749816783, 0.9600204106962773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 291}], {
             RGBColor[
             0.6609844758752189, 0.733889437877449, 0.9676620741218204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 304}], {
             RGBColor[
             0.7517115221067048, 0.805640569609176, 0.9733786324414975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 378}], {
             RGBColor[
             0.7284524051874748, 0.7871829490137747, 0.9742308612461021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 383}], {
             RGBColor[
             0.5615627714589236, 0.6549409818417378, 0.9586274249229093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 293}], {
             RGBColor[
             0.6907059608306092, 0.7533370702004335, 0.9325131065855713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 315}], {
             RGBColor[
             0.6480912895523244, 0.7164263838148396, 0.9297977374143932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 316}], {
             RGBColor[
             0.9745621951268912, 0.9805491072929938, 0.9279437477948158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 338}], {
             RGBColor[
             0.675764947905501, 0.7403959157618496, 0.9315610784538024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 397}], {
             RGBColor[
             0.7905567796619184, 0.8358177394658435, 0.9399821311423355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 282}], {
             RGBColor[
             0.7258932849897699, 0.7857926183180883, 0.9733139168555038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 332}], {
             RGBColor[
             0.5889247336788849, 0.6756963319285267, 0.961726549162487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 367}], {
             RGBColor[
             0.5886470311228844, 0.6754557999322555, 0.9617088542011814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 383}], {
             RGBColor[
             0.6440329639819928, 0.7205632484725687, 0.9660296222342953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 398}], {
             RGBColor[
             0.7530195623517326, 0.8069838723605975, 0.9760176106734698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 270}], {
             RGBColor[
             0.7811032446627102, 0.8289890480210915, 0.9787992180597056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 274}], {
             RGBColor[
             0.8365783837252436, 0.8725289111399626, 0.984274787133695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 295}], {
             RGBColor[
             0.6017752653159024, 0.6826916314265781, 0.9643059983190168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 324}], {
             RGBColor[
             0.6425940688880841, 0.7179457728546176, 0.9669348580787778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 351}], {
             RGBColor[
             0.7075237563557252, 0.7706586181899353, 0.9720463609215126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 373}], {
             RGBColor[
             0.7246972280070362, 0.7846008161325511, 0.9733983195184033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 272}], {
             RGBColor[
             0.44533715874656943`, 0.5600174013414349, 0.9496342147931298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 350}], {
             RGBColor[
             0.6923472073123713, 0.7564468592577769, 0.9572563296732822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 355}], {
             RGBColor[
             0.4815656825973965, 0.5894293490799367, 0.9524862569001225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 392}], {
             RGBColor[
             0.33745625735134754`, 0.46058026169665733`, 0.9429478093257617]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 395}], {
             RGBColor[
             0.46312239732617244`, 0.574456259236224, 0.9510343339235917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 295}], {
             RGBColor[
             0.5547301360216537, 0.6458736292704179, 0.959634491102285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 310}], {
             RGBColor[
             0.7979653754208551, 0.8424344533772901, 0.9804075431444194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 324}], {
             RGBColor[
             0.5955489395938354, 0.6811277706984574, 0.9622633508620461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 346}], {
             RGBColor[
             0.7119756812256806, 0.7749200804798755, 0.9719267401797014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 351}], {
             RGBColor[
             0.6604786270614764, 0.7338406160337752, 0.9673748537047808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 373}], {
             RGBColor[
             0.6776520987127874, 0.7477828139763909, 0.9687268123016716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 390}], {
             RGBColor[
             0.8501788607968883, 0.8832789639419387, 0.9580289332099179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 287}], {
             RGBColor[
             0.5083961522060367, 0.6106810031282282, 0.9547450367372138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 292}], {
             RGBColor[
             0.5842451208576098, 0.6733555349117868, 0.9604130625557574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 371}], {
             RGBColor[
             0.5934857517962464, 0.6808574953934519, 0.9611405188727934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 374}], {
             RGBColor[
             0.7281019734183005, 0.7871899551385411, 0.9738677600325154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 382}], {
             RGBColor[
             0.7889869364116319, 0.8347476960238162, 0.945341534105635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 384}], {
             RGBColor[
             0.5536090031104928, 0.6484837543833007, 0.9580012751429073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 389}], {
             RGBColor[
             0.6632453717088262, 0.7362620374512737, 0.9674728402221446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 391}], {
             RGBColor[
             0.6983093286541124, 0.7636542671128743, 0.9709676877591431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 350}], {
             RGBColor[
             0.7052261557425515, 0.7674689619796411, 0.9581137118194639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 392}], {
             RGBColor[
             0.3503352057815278, 0.47160236441852155`, 0.9438051914719434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 395}], {
             RGBColor[
             0.4760013457563527, 0.5854783619580882, 0.9518917160697734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 322}], {
             RGBColor[
             0.8411538873777955, 0.8764778026713755, 0.9697447095117455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 330}], {
             RGBColor[
             0.879602117503707, 0.9065138522631093, 0.9735768697715577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 295}], {
             RGBColor[
             0.6102052750841871, 0.6894134923892891, 0.9651100601762743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 296}], {
             RGBColor[
             0.5697981208817502, 0.6531058284778736, 0.9625832815975179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 319}], {
             RGBColor[
             0.6931440970643354, 0.7588625622461216, 0.9710547620758218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 324}], {
             RGBColor[
             0.6510240786563688, 0.7246676338173286, 0.9677389199360353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 351}], {
             RGBColor[
             0.7159537661240098, 0.7773804791526463, 0.9728504227787702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 373}], {
             RGBColor[
             0.7331272377753209, 0.7913226770952619, 0.9742023813756608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 276}], {
             RGBColor[
             0.3365292090607116, 0.46223440136921234`, 0.9427987720765628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 280}], {
             RGBColor[
             0.43880522292097646`, 0.5539425467503718, 0.9493332847704868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 288}], {
             RGBColor[
             0.5381997726434524, 0.6341757727641852, 0.9574723194386863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 290}], {
             RGBColor[
             0.6749899551225367, 0.7417910682091375, 0.9616697804259315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 297}], {
             RGBColor[
             0.5462613498332549, 0.6404735381351148, 0.9582758221132437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 318}], {
             RGBColor[
             0.40442766414277764`, 0.5247166483802033, 0.9469907510312043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 325}], {
             RGBColor[
             0.5971042810255034, 0.6801924224030882, 0.9633433703402814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 339}], {
             RGBColor[
             0.6993737260114501, 0.757741840937322, 0.8067700907829158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 288}], {
             RGBColor[
             0.4707005383551348, 0.5720393107393185, 0.9533057784800054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 290}], {
             RGBColor[
             0.6074907208342191, 0.6796546061842708, 0.9575032394672505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 297}], {
             RGBColor[
             0.4787621155449373, 0.5783370761102481, 0.9541092811545628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 318}], {
             RGBColor[
             0.33692842985446, 0.4625801863553366, 0.9428242100725234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 278}], {
             RGBColor[
             0.5643920758232851, 0.6572379385834354, 0.9588501581265552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 302}], {
             RGBColor[
             0.5413955076953252, 0.6385682885935693, 0.9570397840443174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 314}], {
             RGBColor[
             0.7740338434597958, 0.8236248106878585, 0.9714339072122793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 352}], {
             RGBColor[
             0.6829975448291506, 0.7517060871987399, 0.9694323208641658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 378}], {
             RGBColor[
             0.7486849168697818, 0.803608613461736, 0.9758236386798655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 379}], {
             RGBColor[
             0.7249316145854172, 0.7846683749863977, 0.9735580275031597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 314}], {
             RGBColor[
             0.7336714132026546, 0.7908567714983495, 0.9682564288499835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 319}], {
             RGBColor[
             0.5326547231006433, 0.631472125891748, 0.9563516774624752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 352}], {
             RGBColor[
             0.6426351145720095, 0.7189380480092309, 0.9662548425018699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 379}], {
             RGBColor[
             0.6845691843282761, 0.7519003357968888, 0.9703805491408638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.8589230477636677, 0.40820536064492063`, 0.43709235305999306`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 288}], {
             RGBColor[
             0.8072511226144392, 0.8501713820345267, 0.9754101925110541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 309}], {
             RGBColor[
             0.6706494085963862, 0.7382613955715003, 0.9647483241421266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 325}], {
             RGBColor[
             0.8661556309964903, 0.8961880316734296, 0.9812812434126492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 399}], {
             RGBColor[
             0.8442502989859635, 0.8790754198201167, 0.9790979246348062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 297}], {
             RGBColor[
             0.5810381294052023, 0.6700452214914077, 0.9606437938484869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 309}], {
             RGBColor[
             0.4363748381973466, 0.5518374696574517, 0.949178422805002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 322}], {
             RGBColor[
             0.6018332646264998, 0.6862905391751666, 0.9627164585857584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 325}], {
             RGBColor[
             0.6318810605974507, 0.7097641057593811, 0.9657113420755246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 339}], {
             RGBColor[
             0.7341505055833975, 0.7873135242936147, 0.8091380625181588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 355}], {
             RGBColor[
             0.6567659509844009, 0.7300789349024746, 0.9675936914492407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 386}], {
             RGBColor[
             0.6554332138998086, 0.7289969588980811, 0.9674887735039648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 367}], {
             RGBColor[
             0.585310448350704, 0.6728492361116598, 0.9613762948125892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 383}], {
             RGBColor[
             0.6406963812098123, 0.7179566846519732, 0.9656970628457031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 398}], {
             RGBColor[
             0.7496829795795523, 0.8043773085400019, 0.9756850512848776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 294}], {
             RGBColor[
             0.5749464903949825, 0.664065470419882, 0.9606342369257113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 320}], {
             RGBColor[
             0.7624970183368233, 0.8143877330074836, 0.976962234914202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 347}], {
             RGBColor[
             0.6772527004983392, 0.7477043544560085, 0.9685273222849181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 373}], {
             RGBColor[
             0.6696295658594305, 0.7415155503378406, 0.967927201201681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 380}], {
             RGBColor[
             0.7875614473496716, 0.834268329833296, 0.9793807924426559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 381}], {
             RGBColor[
             0.5782049873788557, 0.6668878167304926, 0.960841865472148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 332}], {
             RGBColor[
             0.4657261026718606, 0.5770088841411765, 0.9511180599804581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 338}], {
             RGBColor[
             0.42703569082658294`, 0.5434971940374391, 0.9486527411502648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 367}], {
             RGBColor[
             0.4654484001158602, 0.5767683521449052, 0.9511003650191524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 399}], {
             RGBColor[
             0.793669151560308, 0.35668091923515716`, 0.43459693002987765`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 332}], {
             RGBColor[
             0.4412931982397156, 0.5566477210993513, 0.9493397902649494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 292}], {
             RGBColor[
             0.48876817089531405`, 0.5947461236697019, 0.9531998501487691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 371}], {
             RGBColor[
             0.49800880183395063`, 0.6022480841513669, 0.953927306465805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 374}], {
             RGBColor[
             0.6326250234560047, 0.7085805438964561, 0.966654547625527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 382}], {
             RGBColor[
             0.6935099864493361, 0.7561382847817313, 0.9381283216986467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 384}], {
             RGBColor[
             0.45813205314819705`, 0.5698743431412159, 0.950788062735919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 389}], {
             RGBColor[
             0.5677684217465304, 0.6576526262091889, 0.9602596278151563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 391}], {
             RGBColor[
             0.6028323786918167, 0.6850448558707893, 0.9637544753521547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 303}], {
             RGBColor[
             0.45526648579152684`, 0.567970515328304, 0.9504457177417386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 376}], {
             RGBColor[
             0.6262621523605135, 0.7055043043831426, 0.9650626030338298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 297}], {
             RGBColor[
             0.8172228616067625, 0.8578937429501733, 0.9729802895039315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 318}], {
             RGBColor[
             0.6753891759162851, 0.7421368531952618, 0.9616952184218921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 345}], {
             RGBColor[
             0.719869025616, 0.7795642464385366, 0.9648330415084272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 304}], {
             RGBColor[
             0.8484065152661117, 0.882375358609603, 0.9821986249419938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 383}], {
             RGBColor[
             0.6582577646183305, 0.7316757708421647, 0.9674474174234057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 371}], {
             RGBColor[
             0.5738577704855237, 0.6649226159349257, 0.9595953322843487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 374}], {
             RGBColor[
             0.7084739921075778, 0.771255075680015, 0.9723225734440706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 382}], {
             RGBColor[
             0.7693589551009091, 0.8188128165652899, 0.9437963475171902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 384}], {
             RGBColor[
             0.53398102179977, 0.6325488749247745, 0.9564560885544626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 389}], {
             RGBColor[
             0.6436173903981035, 0.7203271579927475, 0.9659276536336998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 316}], {
             RGBColor[
             0.6849770360517624, 0.749064447480623, 0.9422106818932738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 387}], {
             RGBColor[
             0.48286897065118367`, 0.5896365329206616, 0.952823958325671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 320}], {
             RGBColor[
             0.6194304590700581, 0.6988166848395347, 0.9650679831969206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 347}], {
             RGBColor[
             0.534186141231574, 0.6321333062880597, 0.9566330705676367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 380}], {
             RGBColor[
             0.6444948880829064, 0.7186972816653472, 0.9674865407253745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 381}], {
             RGBColor[
             0.4351384281120906, 0.5513167685625439, 0.9489476137548667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 310}], {
             RGBColor[
             0.6186373960740473, 0.6961370367827767, 0.9659143234037305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 324}], {
             RGBColor[
             0.4162209602470276, 0.5348303541039441, 0.9477701311213572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 351}], {
             RGBColor[
             0.48115064771466864`, 0.5875431994392618, 0.952881633964092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 373}], {
             RGBColor[
             0.49832411936597965`, 0.6014853973818775, 0.9542335925609827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 390}], {
             RGBColor[
             0.6708508814500806, 0.7369815473474254, 0.943535713469229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 308}], {
             RGBColor[
             0.4649186318798898, 0.5708620019322835, 0.9522580108340875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 373}], {
             RGBColor[
             0.4579169651635428, 0.565177733470462, 0.9517068139822263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 380}], {
             RGBColor[
             0.5758488466537839, 0.6579305129659174, 0.9631604052232012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 318}], {
             RGBColor[
             0.5466605706270034, 0.6408193231212391, 0.9583012601092042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 322}], {
             RGBColor[
             0.7092893915387783, 0.7728215305599097, 0.9716589959285152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 339}], {
             RGBColor[
             0.8416066324956759, 0.8738445156783577, 0.8180805998609157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 313}], {
             RGBColor[
             0.6835597303393957, 0.7508660736040558, 0.9705482452931995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 361}], {
             RGBColor[
             0.4299273126847385, 0.5457437797480185, 0.9489082766427392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 393}], {
             RGBColor[
             0.4966186332983669, 0.6022164047829146, 0.9535147844686935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 396}], {
             RGBColor[
             0.5587323029874733, 0.6526430800254628, 0.9584046000764891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 306}], {
             RGBColor[
             0.7330505720999275, 0.7913839454059403, 0.9740272883459936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 342}], {
             RGBColor[
             0.7248027606679724, 0.7849406924296083, 0.9732052235826363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 353}], {
             RGBColor[
             0.6606569466895635, 0.7340162524967757, 0.9673677866789816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 319}], {
             RGBColor[
             0.6927131462629343, 0.7585189337749321, 0.9710136576036698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 343}], {
             RGBColor[
             0.7631467064336537, 0.8115917484548397, 0.8572644058372714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 358}], {
             RGBColor[
             0.6694363018262096, 0.7400103072991684, 0.9688338559418325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 359}], {
             RGBColor[
             0.6611984043808328, 0.7335747992045005, 0.9680127793120059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 362}], {
             RGBColor[
             0.49349132465524514`, 0.5996775147427795, 0.9532685912765979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 369}], {
             RGBColor[
             0.48236011953141966`, 0.5900586071362033, 0.9525531362944277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 394}], {
             RGBColor[
             0.6699106474732605, 0.7403808697238049, 0.9688811342829184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 397}], {
             RGBColor[
             0.5668313736763604, 0.659218270469678, 0.9590421885889917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 314}], {
             RGBColor[
             0.7106748450746947, 0.7721871215084835, 0.9664460547677458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 352}], {
             RGBColor[
             0.6196385464440495, 0.7002683980193648, 0.9644444684196322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 377}], {
             RGBColor[
             0.40955938585443413`, 0.5284903223180475, 0.9475031848229958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 379}], {
             RGBColor[
             0.6615726162003162, 0.7332306858070227, 0.9685701750586261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 376}], {
             RGBColor[
             0.5994777554418, 0.6830851711256585, 0.9631403629966009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 383}], {
             RGBColor[
             0.7489848108498164, 0.8034269025738917, 0.9731639757430828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 334}], {
             RGBColor[
             0.5333047563374556, 0.6319998521570558, 0.9564028504600273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 340}], {
             RGBColor[
             0.6128249840338136, 0.6960421058347364, 0.9630156632049083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 360}], {
             RGBColor[
             0.7587950254374636, 0.8104388846903781, 0.9483918098930648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 370}], {
             RGBColor[
             0.6142618858691337, 0.6971646244693469, 0.9631588801512418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 342}], {
             RGBColor[
             0.7258103039365063, 0.7857277928885995, 0.9733056460796166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 353}], {
             RGBColor[
             0.6616644899580973, 0.7348033529557668, 0.9674682091759619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 361}], {
             RGBColor[
             0.5507892474402771, 0.6424602296560491, 0.9593833811666707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 312}], {
             RGBColor[
             0.45470615858560737`, 0.5658603631246306, 0.9508589581599589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 341}], {
             RGBColor[
             0.5452676837664588, 0.638146742148624, 0.9588330433016107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 348}], {
             RGBColor[
             0.6766847683028088, 0.7405828452461669, 0.914409334932789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 366}], {
             RGBColor[
             0.5141330943498509, 0.6138241642647262, 0.9557298383978436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 325}], {
             RGBColor[
             0.5946738963018736, 0.6780873453101681, 0.9631885083747966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 339}], {
             RGBColor[
             0.6969433412878203, 0.7556367638444018, 0.8066152288174309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 323}], {
             RGBColor[
             0.7868503176072961, 0.8337512857357697, 0.9792996980576847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 324}], {
             RGBColor[
             0.659456199646229, 0.7313911782108162, 0.9685431831634915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 346}], {
             RGBColor[
             0.7758829412780742, 0.8251834879922342, 0.9782065724811468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 389}], {
             RGBColor[
             0.7922451383612843, 0.8379657607109416, 0.979837403372976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 390}], {
             RGBColor[
             0.9140861208492821, 0.9335423714542975, 0.9643087655113634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 313}], {
             RGBColor[
             0.6963705813559715, 0.7612664995815734, 0.9715567624129178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 361}], {
             RGBColor[
             0.44273816370131436`, 0.5561442057255361, 0.9499167937624576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 386}], {
             RGBColor[
             0.5229818142998774, 0.6236192227677108, 0.9555901906486465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 348}], {
             RGBColor[
             0.7638705473763233, 0.8136937949236309, 0.9206292416023805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 366}], {
             RGBColor[
             0.6013188734233654, 0.68693511394219, 0.9619497450674351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 361}], {
             RGBColor[
             0.6211527971667501, 0.6978717073032039, 0.9662790201408276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 393}], {
             RGBColor[
             0.6878441177803785, 0.7543443323381002, 0.9708855279667818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 396}], {
             RGBColor[
             0.7499577874694848, 0.8047710075806482, 0.9757753435745775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 352}], {
             RGBColor[
             0.8522768822085202, 0.885324920113654, 0.978838591587594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 379}], {
             RGBColor[
             0.8942109519647867, 0.9182872079013119, 0.9829642982265879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 316}], {
             RGBColor[
             0.6423623647734777, 0.712153761095029, 0.9394953127220957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 358}], {
             RGBColor[
             0.560961877458354, 0.648214430097369, 0.9613253634224562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 359}], {
             RGBColor[
             0.5527239800129773, 0.6417789220027011, 0.9605042867926297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 362}], {
             RGBColor[
             0.38501690028738955`, 0.5078816375409801, 0.9457600987572217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 363}], {
             RGBColor[
             0.6554796319664347, 0.7199449478006374, 0.8229442347464966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 369}], {
             RGBColor[
             0.37388569516356407`, 0.498262729934404, 0.9450446437750515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 397}], {
             RGBColor[
             0.4583569493085048, 0.5674223932678786, 0.9515336960696155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 358}], {
             RGBColor[
             0.8874327830329208, 0.9123371535755234, 0.9594713738028788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 359}], {
             RGBColor[
             0.879194885587544, 0.9059016454808555, 0.9586502971730522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 362}], {
             RGBColor[
             0.7114878058619564, 0.7720043610191345, 0.9439061091376443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 363}], {
             RGBColor[
             0.9819505375410014, 0.9840676712787918, 0.8210902451269192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 369}], {
             RGBColor[
             0.7003566007381309, 0.7623854534125583, 0.9431906541554741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 397}], {
             RGBColor[
             0.7848278548830716, 0.8315451167460328, 0.9496797064500381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 326}], {
             RGBColor[
             0.5707661458431527, 0.6528527146374666, 0.9628308917146158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 327}], {
             RGBColor[
             0.7288729264227028, 0.7877963537645659, 0.9739508915323856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 336}], {
             RGBColor[
             0.6091067657892537, 0.6881175605846676, 0.9651986371958299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 396}], {
             RGBColor[
             0.7400777204805107, 0.7968929103509143, 0.9748329739651291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 345}], {
             RGBColor[
             0.4493067346362409, 0.5624898266096026, 0.9501540121137001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 347}], {
             RGBColor[
             0.7217366691734148, 0.7824555688756614, 0.9729610685561274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 380}], {
             RGBColor[
             0.8320454160247472, 0.8690195442529488, 0.983814538713865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 381}], {
             RGBColor[
             0.6226889560539314, 0.7016390311501455, 0.9652756117433572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 384}], {
             RGBColor[
             0.655162945532276, 0.7284080209117124, 0.9677201411635119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 341}], {
             RGBColor[
             0.8580959742775616, 0.8856793021425413, 0.7358797400344624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 366}], {
             RGBColor[
             0.8269613848609536, 0.8613567242586435, 0.7327765351306954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 330}], {
             RGBColor[
             0.7685327568859874, 0.8191028978354025, 0.977563820925599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 339}], {
             RGBColor[
             0.8624017677169735, 0.8900898333621168, 0.8201532645981873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 346}], {
             RGBColor[
             0.7008606234121215, 0.766236912838355, 0.9708188950929666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 346}], {
             RGBColor[
             0.5734665054510545, 0.6638768053134015, 0.9600623801987735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 351}], {
             RGBColor[
             0.5219694512868503, 0.6227973408673013, 0.955510493723853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 390}], {
             RGBColor[
             0.7116696850222624, 0.7722356887754649, 0.9461645732289901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 339}], {
             RGBColor[
             0.8924495636879244, 0.9135633999463312, 0.8231481480879534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 327}], {
             RGBColor[
             0.44461399142239666`, 0.5534112617022594, 0.9507475336746101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 336}], {
             RGBColor[
             0.3248478307889474, 0.453732468522361, 0.9419952793380544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 336}], {
             RGBColor[
             0.48295461136849765`, 0.5886761076494603, 0.9531152791558241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 376}], {
             RGBColor[
             0.6865970970063668, 0.7544869305049279, 0.9698123908905361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 364}], {
             RGBColor[
             0.6808348831120752, 0.7502964470301552, 0.9690254336218065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 386}], {
             RGBColor[
             0.5755152611827116, 0.6662682415520078, 0.9597258160236197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 400}], {
             RGBColor[
             0.720829106123702, 0.7815402380141911, 0.9730116840043419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 349}], {
             RGBColor[
             0.4890052262642882, 0.5944582631438093, 0.9533512238607029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 335}], {
             RGBColor[
             0.6649966898087157, 0.7359866190450148, 0.9688672206873672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 338}], {
             RGBColor[
             0.6098240846477871, 0.6889663693067896, 0.9651396119088538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 368}], {
             RGBColor[
             0.46586056847580065`, 0.5561008841623591, 0.9547480711881524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 340}], {
             RGBColor[
             0.5965132148593902, 0.6827994767821124, 0.9617315409835184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 360}], {
             RGBColor[
             0.7424832562630401, 0.7971962556377541, 0.9471076876716749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 365}], {
             RGBColor[
             0.5727073076978193, 0.6639886184161095, 0.9595047636394165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 370}], {
             RGBColor[
             0.5979501166947103, 0.6839219954167228, 0.961874757929852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 394}], {
             RGBColor[
             0.64428248661951, 0.7195747742072408, 0.9668635915814647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 396}], {
             RGBColor[
             0.49415940542630543`, 0.5977726642358087, 0.9539973615885677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 367}], {
             RGBColor[
             0.4010883510529043, 0.521824303220511, 0.9467779729539563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 398}], {
             RGBColor[
             0.5654608822817525, 0.6533523756488531, 0.9610867294262446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 399}], {
             RGBColor[
             0.550240981151457, 0.6414624732103333, 0.9595697519196393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 360}], {
             RGBColor[
             0.8220034839593982, 0.8612385093154347, 0.953720500416556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 370}], {
             RGBColor[
             0.6774703443910683, 0.7479642490944036, 0.9684875706747331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 348}], {
             RGBColor[
             0.8544320725571748, 0.8859801739476242, 0.9286033267440322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 366}], {
             RGBColor[
             0.6918803986042168, 0.7592214929661834, 0.9699238302090869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 353}], {
             RGBColor[
             0.6534166785261423, 0.7283600999794348, 0.9666461444126045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 358}], {
             RGBColor[
             0.8997427003252413, 0.9199792637335347, 0.8697319743986782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 359}], {
             RGBColor[
             0.8915048028798644, 0.9135437556388668, 0.8689108977688517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 362}], {
             RGBColor[
             0.7237977231542768, 0.7796464711771458, 0.8541667097334438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 369}], {
             RGBColor[
             0.7126665180304513, 0.7700275635705696, 0.8534512547512736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 354}], {
             RGBColor[
             0.8223490960662525, 0.8615946681615779, 0.9828083046534283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 356}], {
             RGBColor[
             0.541739653830642, 0.6331364363722055, 0.9594354788981073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 388}], {
             RGBColor[
             0.7977468706813797, 0.8419775214492982, 0.9804617224335532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 390}], {
             RGBColor[
             0.8280964266541075, 0.8660279985568828, 0.9558279625466453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 380}], {
             RGBColor[
             0.7468010981862632, 0.8023361657014738, 0.9753796260845813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 381}], {
             RGBColor[
             0.5374446382154473, 0.6349556525986704, 0.9568406991140734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 384}], {
             RGBColor[
             0.569918627693792, 0.6617246423602374, 0.959285228534228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 366}], {
             RGBColor[
             0.8232974831405668, 0.8616575960637264, 0.9255001218402652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 355}], {
             RGBColor[
             0.7414546795933786, 0.7968809097181431, 0.9609657539264567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 392}], {
             RGBColor[
             0.5973452543473297, 0.6680318223348636, 0.9514273063520958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 395}], {
             RGBColor[
             0.7230113943221546, 0.7819078198744303, 0.9595138309499258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 379}], {
             RGBColor[
             0.8031746533341416, 0.8463684844121933, 0.9809627118784743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 371}], {
             RGBColor[
             0.7293809797276898, 0.7880594723046723, 0.9741627772760653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 388}], {
             RGBColor[
             0.8510613326463464, 0.8840772214804744, 0.9856561837308708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 392}], {
             RGBColor[
             0.38656372963235486`, 0.5010143121570234, 0.946657233578936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 395}], {
             RGBColor[
             0.5122298696071798, 0.6148903096965901, 0.9547437581767662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 363}], {
             RGBColor[
             0.6547562391469783, 0.7193183812992048, 0.8228981407957121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 372}], {
             RGBColor[
             0.6099102982622142, 0.6870820530419226, 0.9660469361413604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 364}], {
             RGBColor[
             0.8563738476114388, 0.887980418082565, 0.9516549497630932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 385}], {
             RGBColor[
             0.7257452786291043, 0.7834052692317443, 0.9403629191431688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 359}], {
             RGBColor[
             0.7977943982724205, 0.8419623144831955, 0.9804803478734128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 362}], {
             RGBColor[
             0.6300873185468328, 0.7080650300214745, 0.9657361598380048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 363}], {
             RGBColor[
             0.9005500502258779, 0.9201283402811318, 0.8429202958272797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 369}], {
             RGBColor[
             0.6189561134230073, 0.6984461224148983, 0.9650207048558346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 372}], {
             RGBColor[
             0.8557041093411137, 0.8878920120238496, 0.9860690911729282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 397}], {
             RGBColor[
             0.703427367567948, 0.7676057857483729, 0.9715097571503986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 362}], {
             RGBColor[
             0.621849421101456, 0.7016295219268066, 0.9649150832081782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 369}], {
             RGBColor[
             0.6107182159776304, 0.6920106143202305, 0.964199628226008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 394}], {
             RGBColor[
             0.7982687439194713, 0.842332876907832, 0.9805276262144986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 397}], {
             RGBColor[
             0.6951894701225712, 0.761170277653705, 0.970688680520572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 370}], {
             RGBColor[
             0.8234403857947183, 0.8623610279500452, 0.9538637173628896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 393}], {
             RGBColor[
             0.4342117001257213, 0.549222038482063, 0.9492455593163217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 396}], {
             RGBColor[
             0.49632536981482767`, 0.599648713724611, 0.9541353749241173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 363}], {
             RGBColor[
             0.7246050730549134, 0.7797955477247429, 0.8273550311620452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 369}], {
             RGBColor[
             0.4430111362520428, 0.5581133298585095, 0.9494554401906001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 397}], {
             RGBColor[
             0.5274823903969835, 0.627272993191984, 0.9559444924851641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 369}], {
             RGBColor[
             0.7134738679310878, 0.7701766401181668, 0.826639576179875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 372}], {
             RGBColor[
             0.9502218638491944, 0.9596225297271181, 0.8476879624969685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 385}], {
             RGBColor[
             0.608018355585612, 0.69118070963699, 0.9632930498391941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 370}], {
             RGBColor[
             0.6536644372294975, 0.7291533907284006, 0.9662607933306312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 398}], {
             RGBColor[
             0.6124367257126668, 0.6940404901541689, 0.9640799886305551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 372}], {
             RGBColor[
             0.6686279270463238, 0.7379403118608846, 0.9697883715255234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 389}], {
             RGBColor[
             0.6528580213367401, 0.7278291184744126, 0.9666551099507359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 391}], {
             RGBColor[
             0.6879219782820263, 0.7552213481360132, 0.9701499574877344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 380}], {
             RGBColor[
             0.7391779635473545, 0.7961473615833058, 0.9747795050013441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 382}], {
             RGBColor[
             0.9132158076615997, 0.9326472367920442, 0.9572510449939482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 384}], {
             RGBColor[
             0.6778378743604607, 0.7463832951515288, 0.9699107860312206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 389}], {
             RGBColor[
             0.7874742429587942, 0.8341615782195018, 0.9793823511104578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 377}], {
             RGBColor[
             0.5719473535097415, 0.6578662478255226, 0.9619674689416606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 379}], {
             RGBColor[
             0.8688620253747728, 0.8982710106751893, 0.9873540296941742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 381}], {
             RGBColor[
             0.6477533850667797, 0.7215196279759579, 0.9676941692718112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 384}], {
             RGBColor[
             0.7387228373537922, 0.7939410360368039, 0.9413845601043402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 389}], {
             RGBColor[
             0.8483592059521256, 0.8817193191047769, 0.9508561251835774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 389}], {
             RGBColor[
             0.6129812726509865, 0.6954553774642614, 0.9635158662208498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 387}], {
             RGBColor[
             0.5210034630750824, 0.6220131081197149, 0.9554344475932912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 400}], {
             RGBColor[
             0.6733215256502096, 0.7429714439936991, 0.9692717132434672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 390}], {
             RGBColor[
             0.8444586237373177, 0.8788102712755903, 0.9574587934384744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 395}], {
             RGBColor[
             0.3681204443611308, 0.4860412223133107, 0.9452053106024053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 396}], {
             RGBColor[
             0.563016690428456, 0.6561213387595073, 0.9587418827500716]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.08420038484809576], {
             RGBColor[
             0.9942731761419903, 0.9901592277754553, 0.6180487487948139]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.08420038484809576], {
             RGBColor[
             0.8464353706362504, 0.8803886049420174, 0.9852149553447029]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.08420038484809576], {
             RGBColor[
             0.49450257206570475`, 0.6004984909467673, 0.9533482003770707]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.08420038484809576], {
             RGBColor[
             0.7881381369532295, 0.8344187697503394, 0.9795179019880083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.08420038484809576], {
             RGBColor[
             0.7426155940206335, 0.7988562132272549, 0.9749806403408376]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.08420038484809576], {
             RGBColor[
             0.8541720637236156, 0.8865576340029432, 0.9859528880380033]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.08420038484809576], {
             RGBColor[
             0.8522195068930517, 0.8850007181869948, 0.985766651424436]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.08420038484809576], {
             RGBColor[
             0.959851326341131, 0.9695777654394108, 0.9528454114400412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.08420038484809576], {
             RGBColor[
             0.4366579176153522, 0.552632873998506, 0.9490444342823826]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.08420038484809576], {
             RGBColor[
             0.6667997105166926, 0.7396282688119201, 0.9674240216128783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.08420038484809576], {
             RGBColor[
             0.5892708645477334, 0.6774356600466023, 0.9608087075089498]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.08420038484809576], {
             RGBColor[
             0.7827117914349848, 0.8301796673897331, 0.9789770545788317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.08420038484809576], {
             RGBColor[
             0.7506668885743999, 0.8051459457247622, 0.9757831181383317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.08420038484809576], {
             RGBColor[
             0.811464071413521, 0.852641167034387, 0.9818428131417591]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.08420038484809576], {
             RGBColor[
             0.699124817722383, 0.7648808882409195, 0.97064588620384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.08420038484809576], {
             RGBColor[
             0.3256773577320027, 0.45650709107267734`, 0.9419728511428714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.08420038484809576], {
             RGBColor[
             0.9947958680837249, 0.9912772129865638, 0.67494054097188]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.08420038484809576], {
             RGBColor[
             0.7954366648186625, 0.8401204351896818, 0.9802453510370139]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.08420038484809576], {
             RGBColor[
             0.37329706017654013`, 0.49775288389429856`, 0.9450071364741879]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.08420038484809576], {
             RGBColor[
             0.2809010798692255, 0.412575223472651, 0.9393082729914203]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.08420038484809576], {
             RGBColor[
             0.7253117219653943, 0.7853382968634035, 0.9732559520882497]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.08420038484809576], {
             RGBColor[
             0.6816763293894829, 0.7512499965418349, 0.9689067839522105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.08420038484809576], {
             RGBColor[
             0.8209184867592743, 0.8600421343758778, 0.9827811321813258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.08420038484809576], {
             RGBColor[
             0.9442591681949789, 0.9579491594238263, 0.9792388680953324]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.08420038484809576], {
             RGBColor[
             0.8538281335590788, 0.8862833934254771, 0.9859200836718797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.08420038484809576], {
             RGBColor[
             0.2885019948678904, 0.42056426706209343`, 0.9397411338560482]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.08420038484809576], {
             RGBColor[
             0.8461180238935021, 0.8801355612634978, 0.9851846865290808]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.08420038484809576], {
             RGBColor[
             0.6038731021683326, 0.689290414370313, 0.9619582491442021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.08420038484809576], {
             RGBColor[
             0.7641074894162432, 0.8156458452547599, 0.9771227516206906]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.08420038484809576], {
             RGBColor[
             0.832258902810982, 0.8690846743081163, 0.9838627911880465]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.08420038484809576], {
             RGBColor[
             0.6198718810298595, 0.7022789437868748, 0.9632177316216396]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.08420038484809576], {
             RGBColor[
             0.8723331662522914, 0.9010388041893136, 0.987685110209796]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.08420038484809576], {
             RGBColor[
             0.8722084820292584, 0.9009393843743301, 0.9876732177172961]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.08420038484809576], {
             RGBColor[
             0.46047140400987274`, 0.5728704556323929, 0.9506691421674395]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.08420038484809576], {
             RGBColor[
             0.961807164431363, 0.8828287389020512, 0.3061284752379972]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.08420038484809576], {
             RGBColor[
             0.5141462802456302, 0.6164461381861996, 0.9548946250422684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.08420038484809576], {
             RGBColor[
             0.30469539513462573`, 0.43758455746330976`, 0.9406633240452499]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.08420038484809576], {
             RGBColor[
             0.36991618355877653`, 0.4948245384957914, 0.9447917100056957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.08420038484809576], {
             RGBColor[
             0.7814466824872277, 0.8291913546645612, 0.9788509603420344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.08420038484809576], {
             RGBColor[
             0.49984978267155256`, 0.6048395974056872, 0.9537691523834408]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.08420038484809576], {
             RGBColor[
             0.724086360479439, 0.7843810351574829, 0.9731338195069837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.08420038484809576], {
             RGBColor[
             0.433621436615227, 0.5500028267741702, 0.9488509523981093]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.08420038484809576], {
             RGBColor[
             0.8727575221297525, 0.9013771740471677, 0.9877255856522151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.08420038484809576], {
             RGBColor[
             0.5438854284846536, 0.6405897184599995, 0.9572357997297338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.08420038484809576], {
             RGBColor[
             0.42531814419917385`, 0.5428109322189963, 0.9483218739476716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.08420038484809576], {
             RGBColor[
             0.5255675953920403, 0.6257184763464392, 0.9557937528082497]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.08420038484809576], {
             RGBColor[
             0.7275659141740823, 0.7870992889493259, 0.9734806289009877]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.08420038484809576], {
             RGBColor[
             0.36977630685217916`, 0.4947033843229445, 0.9447827971856395]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.08420038484809576], {
             RGBColor[
             0.9942110800729763, 0.99002641056271, 0.6112899748951607]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.08420038484809576], {
             RGBColor[
             0.5828817390770298, 0.6722486801626627, 0.9603057321477582]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.08420038484809576], {
             RGBColor[
             0.7958800127381629, 0.8404667819539645, 0.9802895398143079]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.08420038484809576], {
             RGBColor[
             0.46915745955194105`, 0.5799221868237868, 0.951352940277781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.08420038484809576], {
             RGBColor[
             0.4294740350519691, 0.5464105559945399, 0.9485866836379018]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.08420038484809576], {
             RGBColor[
             0.9725862151244898, 0.9191890079314277, 0.34800305172787227`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.08420038484809576], {
             RGBColor[
             0.8739575344055807, 0.9023340312624476, 0.9878400438943472]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.08420038484809576], {
             RGBColor[
             0.692822862007497, 0.759957752539813, 0.9700177661533046]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.08420038484809576], {
             RGBColor[
             0.48844242858958714`, 0.5955785934665025, 0.9528711236835937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.08420038484809576], {
             RGBColor[
             0.9586328819000547, 0.9686690515702757, 0.9549079200575775]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.08420038484809576], {
             RGBColor[
             0.5680290999948052, 0.6601906386519473, 0.9591364779921958]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.08420038484809576], {
             RGBColor[
             0.9523679527768024, 0.9639966776880341, 0.965512810908036]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.08420038484809576], {
             RGBColor[
             0.9941686582048902, 0.9899356744763826, 0.6066726163514136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.08420038484809576], {
             RGBColor[
             0.8437293724210464, 0.8782309154175786, 0.9849568548192636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.08420038484809576], {
             RGBColor[
             0.5916107872616232, 0.6793353147180551, 0.9609929147964065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.08420038484809576], {
             RGBColor[
             0.7511400186280163, 0.8055155585185688, 0.9758302753204244]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.08420038484809576], {
             RGBColor[
             0.34775940872067346`, 0.47563345376291016`, 0.9433798999054785]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.08420038484809576], {
             RGBColor[
             0.8585523634357808, 0.8900503660933554, 0.9863706849348892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.08420038484809576], {
             RGBColor[
             0.5439342459519924, 0.6406293506791869, 0.957239642819587]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.08420038484809576], {
             RGBColor[
             0.36991618355877653`, 0.4948245384957914, 0.9447917100056957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.08420038484809576], {
             RGBColor[
             0.5623769854087675, 0.6556019974061413, 0.958691522827605]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.08420038484809576], {
             RGBColor[
             0.9149015448540578, 0.9349816737985067, 0.9917453201620726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.08420038484809576], {
             RGBColor[
             0.5279337302665896, 0.6276394112307597, 0.9559800236130119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.08420038484809576], {
             RGBColor[
             0.3836246453906116, 0.5066981191272015, 0.9456652010717035]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.08420038484809576], {
             RGBColor[
             0.9845395168089995, 0.987874707131296, 0.9058837471302035]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.08420038484809576], {
             RGBColor[
             0.2697114234989044, 0.4008141851622529, 0.9386710386147437]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.08420038484809576], {
             RGBColor[
             0.8707277542935319, 0.8997586922711455, 0.9875319845840013]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.08420038484809576], {
             RGBColor[
             0.943226872713341, 0.9571792751438495, 0.9809862750799637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.08420038484809576], {
             RGBColor[
             0.22567279542448362`, 0.35452679484574634`, 0.9361631038952173]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.08420038484809576], {
             RGBColor[
             0.9682792430667074, 0.9758632919338986, 0.9385791467763646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.08420038484809576], {
             RGBColor[
             0.914294331768926, 0.9344974985667829, 0.9916874036359472]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.08420038484809576], {
             RGBColor[
             0.36326851349317274`, 0.4890666608065779, 0.9443681263474193]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.08420038484809576], {
             RGBColor[
             0.5841214617878675, 0.6732551429081924, 0.9604033276608093]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.08420038484809576], {
             RGBColor[
             0.8610245375610527, 0.8920216106354683, 0.9866064831098936]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.08420038484809576], {
             RGBColor[
             0.9710001590803164, 0.9778925466417571, 0.9339733456938762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.08420038484809576], {
             RGBColor[
             0.5145274681065526, 0.6167556036640138, 0.9549246335470174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.08420038484809576], {
             RGBColor[
             0.9491140238879839, 0.9615699028505729, 0.9710208637562318]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.08420038484809576], {
             RGBColor[
             0.8262211314715847, 0.8642703193330179, 0.9832869031677127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.08420038484809576], {
             RGBColor[
             0.6271438811950086, 0.7081826811208171, 0.9637902101128544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.08420038484809576], {
             RGBColor[
             0.9935402918458662, 0.9915967589184078, 0.7567176115102112]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.08420038484809576], {
             RGBColor[
             0.8464353706362504, 0.8803886049420174, 0.9852149553447029]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.08420038484809576], {
             RGBColor[
             0.47159094293169457`, 0.5818977982586477, 0.9515445130035785]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.08420038484809576], {
             RGBColor[
             0.561558914982709, 0.6549378509806144, 0.9586271213269749]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.08420038484809576], {
             RGBColor[
             0.8536864729988051, 0.8861704371399883, 0.9859065719611788]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.08420038484809576], {
             RGBColor[
             0.8088667873362818, 0.8506121489731576, 0.9815839401379397]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.08420038484809576], {
             RGBColor[
             0.4516292675508099, 0.5656003048306724, 0.9499983954616251]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.08420038484809576], {
             RGBColor[
             0.8069809870118989, 0.8491389474271364, 0.9813959811854112]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.08420038484809576], {
             RGBColor[
             0.608128754813839, 0.6927453449029021, 0.9622932697094257]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.08420038484809576], {
             RGBColor[
             0.384950742260338, 0.5078467175841919, 0.9457496987916211]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.08420038484809576], {
             RGBColor[
             0.3861566326343555, 0.5088911992163533, 0.9458265370599265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.08420038484809576], {
             RGBColor[
             0.8777061668946364, 0.9053230890553023, 0.9881975918075971]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.08420038484809576], {
             RGBColor[
             0.9101998156823672, 0.9312326425820391, 0.9912968650363936]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.08420038484809576], {
             RGBColor[
             0.6561854890852995, 0.7313363583586451, 0.9663660952161359]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.08420038484809576], {
             RGBColor[
             0.5285177194771208, 0.628113519980283, 0.9560259973828878]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.08420038484809576], {
             RGBColor[
             0.9258331226423393, 0.9436982171971081, 0.9927879838102536]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.08420038484809576], {
             RGBColor[
             0.6825389452276751, 0.7519238785907538, 0.9689927614373582]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.08420038484809576], {
             RGBColor[
             0.8630003123065364, 0.8935970397865403, 0.9867949342689127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.08420038484809576], {
             RGBColor[
             0.6319559404369947, 0.7120893275942597, 0.9641690330435374]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.08420038484809576], {
             RGBColor[
             0.9843690275087295, 0.9878042054242591, 0.9087091960478462]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.08420038484809576], {
             RGBColor[
             0.3543628115839759, 0.48135298942642457`, 0.9438006628967683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.08420038484809576], {
             RGBColor[
             0.7840021446240215, 0.8311877011080561, 0.9791056649256786]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.08420038484809576], {
             RGBColor[
             0.8950541164165549, 0.9191558731065349, 0.9898522547196951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.08420038484809576], {
             RGBColor[
             0.8162998580536013, 0.8564189203109575, 0.9823247991610469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.08420038484809576], {
             RGBColor[
             0.6701398811570226, 0.742237635502383, 0.9677569386066371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.08420038484809576], {
             RGBColor[
             0.7874930570586676, 0.8339148284339187, 0.9794536064527327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.08420038484809576], {
             RGBColor[
             0.8901269583747211, 0.9152270910281188, 0.9893822979871391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.08420038484809576], {
             RGBColor[
             0.9715136272353219, 0.9782754903510332, 0.9331041780413949]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.08420038484809576], {
             RGBColor[
             0.7501183056785979, 0.8047173885971772, 0.9757284405220769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.08420038484809576], {
             RGBColor[
             0.839638980387611, 0.8749693478408511, 0.9845667095755785]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.08420038484809576], {
             RGBColor[
             0.9374646393416048, 0.9528818109299998, 0.9907402331471556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.08420038484809576], {
             RGBColor[
             0.7485954313561634, 0.8035277076022178, 0.9755766546416862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.08420038484809576], {
             RGBColor[
             0.841428447371886, 0.8763962202403248, 0.9847373905340147]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.08420038484809576], {
             RGBColor[
             0.5136310192829966, 0.6160278261244918, 0.9548540618118269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.08420038484809576], {
             RGBColor[
             0.7148815228749992, 0.7771901460615377, 0.9722163673186712]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.08420038484809576], {
             RGBColor[
             0.9936624856222789, 0.9888530225040754, 0.5515788544692437]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.08420038484809576], {
             RGBColor[
             0.8162998580536013, 0.8564189203109575, 0.9823247991610469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.08420038484809576], {
             RGBColor[
             0.5284184541010948, 0.6280329318761708, 0.9560181828488661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.08420038484809576], {
             RGBColor[
             0.35778870193998835`, 0.48432032346254655`, 0.9440189576008575]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.08420038484809576], {
             RGBColor[
             0.6900642024985314, 0.7578026667648203, 0.9697428087545897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.08420038484809576], {
             RGBColor[
             0.7604691173271216, 0.8128035213260861, 0.9767601126933673]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.08420038484809576], {
             RGBColor[
             0.608128754813839, 0.6927453449029021, 0.9622932697094257]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.08420038484809576], {
             RGBColor[
             0.623022841656204, 0.7048370355724999, 0.9634657867844945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.08420038484809576], {
             RGBColor[
             0.8704588403008306, 0.8995442675528413, 0.9875063353273151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.08420038484809576], {
             RGBColor[
             0.642821295921935, 0.7208961490877949, 0.9650340773370975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.08420038484809576], {
             RGBColor[
             0.5583617510851769, 0.6523422492980057, 0.958375428873364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.08420038484809576], {
             RGBColor[
             0.8399983888254615, 0.875255930373311, 0.9846009902732283]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.08420038484809576], {
             RGBColor[
             0.39878353278509926`, 0.5198279854804728, 0.9466311119720024]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.08420038484809576], {
             RGBColor[
             0.7076791511966576, 0.7715635985663651, 0.9714985022197642]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.08420038484809576], {
             RGBColor[
             0.26104696361617186`, 0.39170728846701497`, 0.9381776104423417]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.08420038484809576], {
             RGBColor[
             0.5777034687096962, 0.6680447270000397, 0.9598980797358123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.08420038484809576], {
             RGBColor[
             0.3818218830428144, 0.5051366569910097, 0.9455503306490219]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.08420038484809576], {
             RGBColor[
             0.7485490015098586, 0.8034914362534046, 0.9755720269485182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.08420038484809576], {
             RGBColor[
             0.6397939742732429, 0.7184525965619265, 0.9647860717787908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.08420038484809576], {
             RGBColor[
             0.8470615736169881, 0.8808879222010306, 0.9852746831440237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.08420038484809576], {
             RGBColor[
             0.6986816253943635, 0.7645346630258841, 0.9706017129344507]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.08420038484809576], {
             RGBColor[
             0.8915479929679666, 0.9163601854398162, 0.9895178375352154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.08420038484809576], {
             RGBColor[
             0.8901235320905175, 0.9152243590020989, 0.9893819711850931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.08420038484809576], {
             RGBColor[
             0.5705644843937646, 0.662248977924788, 0.959336072739501]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.08420038484809576], {
             RGBColor[
             0.6394523286942986, 0.7181752332899816, 0.9647591761873273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.08420038484809576], {
             RGBColor[
             0.3952296523343843, 0.5167497928572886, 0.9464046618522559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.08420038484809576], {
             RGBColor[
             0.22607410808055758`, 0.3549485998919721, 0.9361859580572918]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.08420038484809576], {
             RGBColor[
             0.9681790036472372, 0.9757885335389846, 0.9387488259669001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.08420038484809576], {
             RGBColor[
             0.8875218715059818, 0.9131498654721854, 0.9891338224760102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.08420038484809576], {
             RGBColor[
             0.8430580977675637, 0.8776956592301565, 0.9848928280435605]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.08420038484809576], {
             RGBColor[
             0.7440614322103491, 0.7999857130098379, 0.9751247479794625]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.08420038484809576], {
             RGBColor[
             0.6155729164507308, 0.6987888506753908, 0.9628793013823445]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.08420038484809576], {
             RGBColor[
             0.4419700580962947, 0.5572339830871547, 0.9493829191764869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.08420038484809576], {
             RGBColor[
             0.5888697158017213, 0.6771099894230447, 0.9607771276102074]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.08420038484809576], {
             RGBColor[
             0.9019328324088353, 0.9246407745210078, 0.990508352791741]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.08420038484809576], {
             RGBColor[
             0.6989399206895242, 0.7647364452735806, 0.9706274573955656]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.08420038484809576], {
             RGBColor[
             0.5579913742698065, 0.6520415607140025, 0.9583462714537231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.08420038484809576], {
             RGBColor[
             0.45499414418573425`, 0.5684237693594141, 0.9502379522102194]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.08420038484809576], {
             RGBColor[
             0.4030030256669559, 0.5234826981368583, 0.9468999743272832]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.08420038484809576], {
             RGBColor[
             0.6831676955303024, 0.7524150631058456, 0.9690554293915185]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.08420038484809576], {
             RGBColor[
             0.6661532294816324, 0.7391232329138931, 0.9673595864250123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.08420038484809576], {
             RGBColor[
             0.9843090029594268, 0.987779383730562, 0.9097039581683453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.08420038484809576], {
             RGBColor[
             0.9672349392158269, 0.9750844518318026, 0.9403468807978393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.08420038484809576], {
             RGBColor[
             0.7662114676427153, 0.8172894890361068, 0.9773324565075109]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.08420038484809576], {
             RGBColor[
             0.6365649468353862, 0.715831126621846, 0.9645318709105655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.08420038484809576], {
             RGBColor[
             0.6370228142103056, 0.7162028439834959, 0.9645679159075427]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.08420038484809576], {
             RGBColor[
             0.8576015500773593, 0.4437563318205822, 0.20279261544671232`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.08420038484809576], {
             RGBColor[
             0.7759809394213779, 0.8249214746403335, 0.9783061861535036]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.08420038484809576], {
             RGBColor[
             0.9416439950521802, 0.95599876757588, 0.9836656740796967]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.08420038484809576], {
             RGBColor[
             0.7413639222933379, 0.7978783977608341, 0.9748558854005982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.08420038484809576], {
             RGBColor[
             0.5346233195146715, 0.6330703211449139, 0.9565066525833937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.08420038484809576], {
             RGBColor[
             0.5491141678277461, 0.644834644610745, 0.9576474252443253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.08420038484809576], {
             RGBColor[
             0.8915892930818778, 0.9163931170295874, 0.9895217767769493]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.08420038484809576], {
             RGBColor[
             0.6043978867463695, 0.6897164581320392, 0.9619995621085344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.08420038484809576], {
             RGBColor[
             0.9111627737655343, 0.9320004792187558, 0.9913887128380089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.08420038484809576], {
             RGBColor[
             0.8436072932309494, 0.8781335727851466, 0.9849452107971308]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.08420038484809576], {
             RGBColor[
             0.7901801187019777, 0.8360139814120975, 0.9797214276453191]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.08420038484809576], {
             RGBColor[
             0.4193465126874283, 0.5376386051464492, 0.9479413668682497]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.08420038484809576], {
             RGBColor[
             0.7907094672026009, 0.8364275124839821, 0.9797741881568183]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.08420038484809576], {
             RGBColor[
             0.9612637180638578, 0.8809955666971808, 0.3040172887214746]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.08420038484809576], {
             RGBColor[
             0.6492683239142116, 0.7259326163545888, 0.9656766568364655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.08420038484809576], {
             RGBColor[
             0.908422588584069, 0.9298155299354006, 0.9911273515292086]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.08420038484809576], {
             RGBColor[
             0.9951692263033061, 0.9922703651782653, 0.7297219520031897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.08420038484809576], {
             RGBColor[
             0.6345300455204665, 0.7141791020631347, 0.9643716760249659]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.08420038484809576], {
             RGBColor[
             0.8589104374903234, 0.8903358846247864, 0.9864048383578681]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.08420038484809576], {
             RGBColor[
             0.38778963349407913`, 0.5103056224840362, 0.945930590430702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.08420038484809576], {
             RGBColor[
             0.4262300350875978, 0.5436007662735806, 0.9483799788287286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.08420038484809576], {
             RGBColor[
             0.41746680915373785`, 0.5360105004222132, 0.9478215938212394]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.08420038484809576], {
             RGBColor[
             0.6376044973795614, 0.7166750805848258, 0.9646137081374021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.08420038484809576], {
             RGBColor[
             0.35854287292017395`, 0.48497354845984775`, 0.9440670127088278]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.08420038484809576], {
             RGBColor[
             0.9928772289106118, 0.9871734377994519, 0.4661085074469696]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.08420038484809576], {
             RGBColor[
             0.7876966048296817, 0.8340738414996554, 0.9794738941922854]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.08420038484809576], {
             RGBColor[
             0.8698794039560047, 0.8990822407398578, 0.9874510681714767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.08420038484809576], {
             RGBColor[
             0.418293999251814, 0.5367269709093835, 0.9478743016428334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.08420038484809576], {
             RGBColor[
             0.6137982936084153, 0.6973481319061512, 0.9627395965715396]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.08420038484809576], {
             RGBColor[
             0.5732556903752031, 0.6644338201779676, 0.9595479343325721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.08420038484809576], {
             RGBColor[
             0.5767288323105808, 0.6672534732643683, 0.9598213527882632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.08420038484809576], {
             RGBColor[
             0.39132809820791153`, 0.5133704627707502, 0.9461560582733259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.08420038484809576], {
             RGBColor[
             0.9175313725012739, 0.9370786269796271, 0.9919961554707389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.08420038484809576], {
             RGBColor[
             0.5631406618723811, 0.6562219843625354, 0.9587516422362597]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.08420038484809576], {
             RGBColor[
             0.9881994844626623, 0.9893881978129638, 0.8452286114163479]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.08420038484809576], {
             RGBColor[
             0.4105583712330412, 0.5300267587234917, 0.9473813942658245]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.08420038484809576], {
             RGBColor[
             0.8295421307790392, 0.8669183940346574, 0.9836036630463488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.08420038484809576], {
             RGBColor[
             0.3675203795120929, 0.4927494134471667, 0.9446390514903674]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.08420038484809576], {
             RGBColor[
             0.40112080175548026`, 0.5218524103880626, 0.9467800406840293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.08420038484809576], {
             RGBColor[
             0.5553321282728225, 0.649882665015984, 0.9581369258677014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.08420038484809576], {
             RGBColor[
             0.6836032409539728, 0.7527553145010848, 0.9690988404889466]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.08420038484809576], {
             RGBColor[
             0.9857748966384193, 0.9636775275275942, 0.3992385889359678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.08420038484809576], {
             RGBColor[
             0.6799382719334599, 0.7498922128474639, 0.9687335506280645]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.08420038484809576], {
             RGBColor[
             0.6118254862658795, 0.6957465180315227, 0.9625842899509038]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.08420038484809576], {
             RGBColor[
             0.9937862948330312, 0.9891178378868433, 0.5650547229977604]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.08420038484809576], {
             RGBColor[
             0.44148710068492736`, 0.5568156696515736, 0.9493521455572971]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.08420038484809576], {
             RGBColor[
             0.6445350436856564, 0.7222349418657794, 0.9652048876983018]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.08420038484809576], {
             RGBColor[
             0.5777371709226162, 0.6680720879747556, 0.9599007328974687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.08420038484809576], {
             RGBColor[
             0.9952657329501869, 0.992282206425301, 0.7260824320164457]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.08420038484809576], {
             RGBColor[
             0.4183387299003447, 0.5367657143489131, 0.947877151840204]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.08420038484809576], {
             RGBColor[
             0.9908164350036948, 0.9904703741142421, 0.8018589685005347]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.08420038484809576], {
             RGBColor[
             0.8139021179748809, 0.8545457875379615, 0.982085814838155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.08420038484809576], {
             RGBColor[
             0.5681529390483716, 0.6602911767745182, 0.95914622705613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.08420038484809576], {
             RGBColor[
             0.9941686582048902, 0.9899356744763826, 0.6066726163514136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.08420038484809576], {
             RGBColor[
             0.48471191922587176`, 0.5925499979075068, 0.952577444321176]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.08420038484809576], {
             RGBColor[
             0.9101998156823672, 0.9312326425820391, 0.9912968650363936]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.08420038484809576], {
             RGBColor[
             0.9479340340390472, 0.960689868353292, 0.9730182787798396]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.08420038484809576], {
             RGBColor[
             0.44148710068492736`, 0.5568156696515736, 0.9493521455572971]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.08420038484809576], {
             RGBColor[
             0.4538765575650017, 0.567516462194, 0.9501499716975808]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.08420038484809576], {
             RGBColor[
             0.5746360762183755, 0.6655544795911286, 0.9596566033626667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.08420038484809576], {
             RGBColor[
             0.9759194638562223, 0.9815613560890054, 0.9256462458684374]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.08420038484809576], {
             RGBColor[
             0.9416959567510828, 0.9560375205258421, 0.9835777164772362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.08420038484809576], {
             RGBColor[
             0.3952296523343843, 0.5167497928572886, 0.9464046618522559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.08420038484809576], {
             RGBColor[
             0.7137772683686954, 0.7763274940485682, 0.972106305549328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.08420038484809576], {
             RGBColor[
             0.4505490859694676, 0.5646647058364185, 0.9499295672464291]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.08420038484809576], {
             RGBColor[
             0.43583876964774876`, 0.5519233692005419, 0.948992238898231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.08420038484809576], {
             RGBColor[
             0.4085161034662337, 0.5282578490312456, 0.94725126276963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.08420038484809576], {
             RGBColor[
             0.6237850040586334, 0.705455793345817, 0.9635257870007066]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.08420038484809576], {
             RGBColor[
             0.5994758662845229, 0.6857205401866172, 0.9616120826278228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.08420038484809576], {
             RGBColor[
             0.34888642719776497`, 0.47660962052217115`, 0.9434517125262555]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.08420038484809576], {
             RGBColor[
             0.8893897734290096, 0.9146392797627607, 0.9893119846289243]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.08420038484809576], {
             RGBColor[
             0.6518997434908029, 0.7279883013273515, 0.9659389321478461]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.08420038484809576], {
             RGBColor[
             0.8134757273594992, 0.8542126879485366, 0.9820433162064607]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.08420038484809576], {
             RGBColor[
             0.6222711085773518, 0.7042267447938984, 0.9634066076028382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.08420038484809576], {
             RGBColor[
             0.46527652624905513`, 0.5767714703344512, 0.9510474189918506]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.08420038484809576], {
             RGBColor[
             0.9552900342958791, 0.9661759613004921, 0.9605664890971576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.08420038484809576], {
             RGBColor[
             0.38568485938545427`, 0.5084825729401681, 0.9457964760856792]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.08420038484809576], {
             RGBColor[
             0.23560828997385452`, 0.3649696295638736, 0.9367289156115569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.08420038484809576], {
             RGBColor[
             0.3764696992643711, 0.5005008644107007, 0.9452092942314099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.08420038484809576], {
             RGBColor[
             0.4715651848532963, 0.5818768866902158, 0.951542485233292]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.08420038484809576], {
             RGBColor[
             0.5442036632563836, 0.640848075784003, 0.9572608523366968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.08420038484809576], {
             RGBColor[
             0.6859992279531678, 0.7546270777550315, 0.9693376500812547]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.08420038484809576], {
             RGBColor[
             0.4625204404737849, 0.5745339557418375, 0.9508304498237465]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.08420038484809576], {
             RGBColor[
             0.6986506487710709, 0.7645104638523369, 0.9705986254741339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.08420038484809576], {
             RGBColor[
             0.9576981679929532, 0.967971943468813, 0.9564901468898694]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.08420038484809576], {
             RGBColor[
             0.6284216282326065, 0.7092200137277871, 0.9638907990401957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.08420038484809576], {
             RGBColor[
             0.5355153862641783, 0.6337945411193125, 0.956576879345663]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.08420038484809576], {
             RGBColor[
             0.5256333457157247, 0.6257718554212245, 0.9557989289145815]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.08420038484809576], {
             RGBColor[
             0.6036578115004654, 0.6891156317074044, 0.9619413006741919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.08420038484809576], {
             RGBColor[
             0.8826231903762802, 0.9092437901105183, 0.9886665818967549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.08420038484809576], {
             RGBColor[
             0.439382852990753, 0.554993076061444, 0.9492180647549374]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.08420038484809576], {
             RGBColor[
             0.35751528738754523`, 0.48408350551943535`, 0.9440015358673468]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.08420038484809576], {
             RGBColor[
             0.3675203795120929, 0.4927494134471667, 0.9446390514903674]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.08420038484809576], {
             RGBColor[
             0.9658430742859547, 0.9740464012460734, 0.9427029450675998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.08420038484809576], {
             RGBColor[
             0.9621281450863274, 0.9712758131316297, 0.9489913511938574]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.08420038484809576], {
             RGBColor[
             0.4928765769739927, 0.5991784348810713, 0.9532201960872349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.08420038484809576], {
             RGBColor[
             0.564289482715812, 0.657154648877022, 0.958842081621324]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.08420038484809576], {
             RGBColor[
             0.980291119905738, 0.9848217300128044, 0.9182461724871133]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.08420038484809576], {
             RGBColor[
             0.7292298677619503, 0.788399182138684, 0.9736464762440961]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.08420038484809576], {
             RGBColor[
             0.828148373956959, 0.8658070501772517, 0.9834707252764374]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.08420038484809576], {
             RGBColor[
             0.4324582103163892, 0.5489952986195706, 0.9487768326469481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.08420038484809576], {
             RGBColor[
             0.7340581153684613, 0.7921710458649314, 0.9741277108429739]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.08420038484809576], {
             RGBColor[
             0.6038731021683326, 0.689290414370313, 0.9619582491442021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.08420038484809576], {
             RGBColor[
             0.4582161071767497, 0.5710395040632991, 0.9504915969393115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.08420038484809576], {
             RGBColor[
             0.952223247995515, 0.9638887570990823, 0.9657577583577042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.08420038484809576], {
             RGBColor[
             0.8450083934935283, 0.8792507721026736, 0.9850788489909525]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.08420038484809576], {
             RGBColor[
             0.4040284433490292, 0.524370863394079, 0.9469653130352438]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.08420038484809576], {
             RGBColor[
             0.26902997477239393`, 0.4000979393443456, 0.9386322311178819]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.08420038484809576], {
             RGBColor[
             0.6047545060804262, 0.6900059777729444, 0.962027636488851]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.08420038484809576], {
             RGBColor[
             0.524029645566144, 0.6244698993939264, 0.9556726797642594]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.08420038484809576], {
             RGBColor[
             0.9421311432910029, 0.9563620819347619, 0.9828410591799792]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.08420038484809576], {
             RGBColor[
             0.4735820024929237, 0.5835142301066646, 0.9517012565057299]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.08420038484809576], {
             RGBColor[
             0.782858747090398, 0.8302944702646463, 0.9789917017451846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.08420038484809576], {
             RGBColor[
             0.7225567022175895, 0.7831860544974928, 0.9729813574669117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.08420038484809576], {
             RGBColor[
             0.7180130496617476, 0.7796365185878307, 0.9725284886429927]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.08420038484809576], {
             RGBColor[
             0.4828326057479018, 0.5910242865639834, 0.9524294978800381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.08420038484809576], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.08420038484809576], {
             RGBColor[
             0.4339667968836118, 0.5503019604803333, 0.9488729584490208]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.08420038484809576], {
             RGBColor[
             0.412919202243741, 0.5320715918861432, 0.9475318243302254]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.08420038484809576], {
             RGBColor[
             0.6723711019378756, 0.7439806821342914, 0.9679793258421289]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.08420038484809576], {
             RGBColor[
             0.48205088271024027`, 0.5903896485857882, 0.9523679577789675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.08420038484809576], {
             RGBColor[
             0.9459514668960441, 0.959211273024196, 0.9763742478166192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.08420038484809576], {
             RGBColor[
             0.7576794690346258, 0.810624226877876, 0.9764820666223167]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.08420038484809576], {
             RGBColor[
             0.5646171395468871, 0.6574206554532607, 0.9588678759673127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.08420038484809576], {
             RGBColor[
             0.40112080175548026`, 0.5218524103880626, 0.9467800406840293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.08420038484809576], {
             RGBColor[
             0.43187993112821726`, 0.5484944222519332, 0.94873998520843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.08420038484809576], {
             RGBColor[
             0.3754021566748459, 0.4995762126759046, 0.9451412713615962]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.08420038484809576], {
             RGBColor[
             0.2945878482699722, 0.42696088485307365`, 0.9400877142040834]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.08420038484809576], {
             RGBColor[
             0.6884942563174807, 0.7565762128761506, 0.9695863311912437]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.08420038484809576], {
             RGBColor[
             0.49233424585738417`, 0.5987381460488702, 0.9531775017951111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.08420038484809576], {
             RGBColor[
             0.7320430288313937, 0.7905968449469492, 0.9739268658490133]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.08420038484809576], {
             RGBColor[
             0.8441464918907259, 0.8785635151602946, 0.9849966400466486]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.08420038484809576], {
             RGBColor[
             0.532840307934622, 0.6316227920204734, 0.9563662873804256]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.08420038484809576], {
             RGBColor[
             0.478036509310224, 0.5871305994141942, 0.952051931599784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.08420038484809576], {
             RGBColor[
             0.42848208887281336`, 0.5455513820708198, 0.9485234777045096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.08420038484809576], {
             RGBColor[
             0.9391335614975975, 0.95412649034133, 0.9879151832616708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.08420038484809576], {
             RGBColor[
             0.5496165255118789, 0.6452424812096798, 0.9576869726814171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.08420038484809576], {
             RGBColor[
             0.7340581153684613, 0.7921710458649314, 0.9741277108429739]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.08420038484809576], {
             RGBColor[
             0.3675203795120929, 0.4927494134471667, 0.9446390514903674]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.08420038484809576], {
             RGBColor[
             0.6352494154898074, 0.7147631190114935, 0.9644283074640915]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.08420038484809576], {
             RGBColor[
             0.39916767390176955`, 0.5201607092082388, 0.946655589104274]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.08420038484809576], {
             RGBColor[
             0.8618726354732488, 0.8926978608896489, 0.9866873754458648]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.08420038484809576], {
             RGBColor[
             0.5179559478905359, 0.6195389980039057, 0.9551945360345478]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.08420038484809576], {
             RGBColor[
             0.5418919376591219, 0.6389713128020945, 0.9570788648295505]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.08420038484809576], {
             RGBColor[
             0.8747852148214073, 0.9029940011592412, 0.9879189887912878]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.08420038484809576], {
             RGBColor[
             0.9433131808391653, 0.9572436436027727, 0.9808401779357077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.08420038484809576], {
             RGBColor[
             0.3158914591989109, 0.44803103761687474`, 0.9413493023416731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.08420038484809576], {
             RGBColor[
             0.9688332703480445, 0.9762764845731833, 0.9376413231025182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.08420038484809576], {
             RGBColor[
             0.8550250808434589, 0.8872378066997731, 0.9860342495723913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.08420038484809576], {
             RGBColor[
             0.404826884936526, 0.5250624333663276, 0.9470161890271649]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.08420038484809576], {
             RGBColor[
             0.5412798006351427, 0.6384743523895695, 0.957030675160691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.08420038484809576], {
             RGBColor[
             0.8069809870118989, 0.8491389474271364, 0.9813959811854112]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.08420038484809576], {
             RGBColor[
             0.9931769605342983, 0.9878145334350014, 0.498732444956071]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.08420038484809576], {
             RGBColor[
             0.7300845267600758, 0.7890668482436687, 0.9737316606657868]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.08420038484809576], {
             RGBColor[
             0.7118279997413435, 0.7748047105818906, 0.9719120206695046]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.08420038484809576], {
             RGBColor[
             0.4570397638192093, 0.5700844955319835, 0.9503989908811182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.08420038484809576], {
             RGBColor[
             0.7901801187019777, 0.8360139814120975, 0.9797214276453191]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.08420038484809576], {
             RGBColor[
             0.2865072108428464, 0.41846762257516007`, 0.9396275338568404]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.08420038484809576], {
             RGBColor[
             0.6027207720019468, 0.6883549008293587, 0.9618675334923797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.08420038484809576], {
             RGBColor[
             0.623022841656204, 0.7048370355724999, 0.9634657867844945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.08420038484809576], {
             RGBColor[
             0.5827808001941921, 0.6721667334303302, 0.9602977858691498]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.08420038484809576], {
             RGBColor[
             0.8069809870118989, 0.8491389474271364, 0.9813959811854112]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.08420038484809576], {
             RGBColor[
             0.8484093933903103, 0.8819626371026845, 0.9854032393972161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.08420038484809576], {
             RGBColor[
             0.4486195995958194, 0.5629934817183694, 0.949806622080878]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.08420038484809576], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.08420038484809576], {
             RGBColor[
             0.5169929871630322, 0.6187572231044317, 0.9551187282386373]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.08420038484809576], {
             RGBColor[
             0.4815839862271211, 0.5900106009873453, 0.9523312019775182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.08420038484809576], {
             RGBColor[
             0.36318845073504846`, 0.4889973144695619, 0.9443630248192684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.08420038484809576], {
             RGBColor[
             0.35411250762199004`, 0.48113618871519526`, 0.9437847137496457]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.08420038484809576], {
             RGBColor[
             0.37123877590526405`, 0.4959701015108947, 0.9448759844204915]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.08420038484809576], {
             RGBColor[
             0.9947190086738711, 0.9911128184805649, 0.6665748685305878]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.08420038484809576], {
             RGBColor[
             0.6760334425557483, 0.7468417304597931, 0.9683443537283996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.08420038484809576], {
             RGBColor[
             0.7230149880208248, 0.7835440708500812, 0.9730270351128539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.08420038484809576], {
             RGBColor[
             0.7175624925045512, 0.7792845399122675, 0.9724835813162593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.08420038484809576], {
             RGBColor[
             0.9934531049326853, 0.991560704889206, 0.7581625242941172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.08420038484809576], {
             RGBColor[
             0.7690346341012859, 0.8194949681304018, 0.9776138433561107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.08420038484809576], {
             RGBColor[
             0.49378658433595574`, 0.5999172198528774, 0.9532918352002353]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.08420038484809576], {
             RGBColor[
             0.6898932470828997, 0.7576691150948196, 0.9697257695164287]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.08420038484809576], {
             RGBColor[
             0.6364923513349308, 0.7157721903241863, 0.9645261559268435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.08420038484809576], {
             RGBColor[
             0.9858491570935247, 0.9884162770451672, 0.8841796183752105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.08420038484809576], {
             RGBColor[
             0.3952296523343843, 0.5167497928572886, 0.9464046618522559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.08420038484809576], {
             RGBColor[
             0.9522362043083534, 0.9638984198959831, 0.9657358266996163]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.08420038484809576], {
             RGBColor[
             0.5868991387544914, 0.675510186202619, 0.9606219965665879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.08420038484809576], {
             RGBColor[
             0.761240583577875, 0.8134061966245354, 0.9768370052394804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.08420038484809576], {
             RGBColor[
             0.5892708645477334, 0.6774356600466023, 0.9608087075089498]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.08420038484809576], {
             RGBColor[
             0.8756635580312192, 0.9036943681927541, 0.9880027659507459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.08420038484809576], {
             RGBColor[
             0.5306731548784038, 0.6298633995403029, 0.9561956811532969]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.08420038484809576], {
             RGBColor[
             0.3144446735599982, 0.4467779046140092, 0.941257114440104]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.08420038484809576], {
             RGBColor[
             0.9741007706549312, 0.9802049776773193, 0.9287248190670678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.08420038484809576], {
             RGBColor[
             0.8060322957177972, 0.8483978225778633, 0.9813014245032393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.08420038484809576], {
             RGBColor[
             0.7895565008270437, 0.8355268063885276, 0.9796592712435861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.08420038484809576], {
             RGBColor[
             0.9679735253630481, 0.9756352881710764, 0.9390966471047124]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.08420038484809576], {
             RGBColor[
             0.3675203795120929, 0.4927494134471667, 0.9446390514903674]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.08420038484809576], {
             RGBColor[
             0.4541423413758683, 0.5677322374650856, 0.9501708951727703]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.08420038484809576], {
             RGBColor[
             0.9950678047339584, 0.9918588579844003, 0.7045391671513201]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.08420038484809576], {
             RGBColor[
             0.7386469245679463, 0.7957558584878106, 0.9745850804591185]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.08420038484809576], {
             RGBColor[
             0.6284216282326065, 0.7092200137277871, 0.9638907990401957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.08420038484809576], {
             RGBColor[
             0.6607458091876088, 0.7348989150822856, 0.9668206253053198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.08420038484809576], {
             RGBColor[
             0.44806419448381857`, 0.5625124177258268, 0.9497712321582668]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.08420038484809576], {
             RGBColor[
             0.7527941369516012, 0.8068077683247183, 0.9759951423763048]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.08420038484809576], {
             RGBColor[
             0.43187993112821726`, 0.5484944222519332, 0.94873998520843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.08420038484809576], {
             RGBColor[
             0.6789072462263884, 0.7490867677290141, 0.9686307876210667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.08420038484809576], {
             RGBColor[
             0.5830984014241603, 0.6724245764165907, 0.9603227886013846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.08420038484809576], {
             RGBColor[
             0.9053759229644304, 0.927386201469836, 0.9908367578426169]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.08420038484809576], {
             RGBColor[
             0.6212460820571134, 0.7033945820878503, 0.9633259137603692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.08420038484809576], {
             RGBColor[
             0.8523308446682684, 0.8850894959067691, 0.9857772709208286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.08420038484809576], {
             RGBColor[
             0.8028124446208387, 0.8458824504291446, 0.9809804998371138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.08420038484809576], {
             RGBColor[
             0.7704734220107867, 0.8206189601804971, 0.9777572482886923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.08420038484809576], {
             RGBColor[
             0.34108226239864425`, 0.4698500452219007, 0.9429544380462075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.08420038484809576], {
             RGBColor[
             0.8926153276591374, 0.9172112491505275, 0.9896196408708802]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.08420038484809576], {
             RGBColor[
             0.8451087230904082, 0.8793307721998511, 0.9850884185174682]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.08420038484809576], {
             RGBColor[
             0.8571098450375956, 0.8889001410787613, 0.986233096242319]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.08420038484809576], {
             RGBColor[
             0.43839692509596384`, 0.5541391148731545, 0.9491552423013033]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.08420038484809576], {
             RGBColor[
             0.9741007706549312, 0.9802049776773193, 0.9287248190670678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.08420038484809576], {
             RGBColor[
             0.5588360602020352, 0.6527273148064534, 0.9584127682244946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.08420038484809576], {
             RGBColor[
             0.5033449040526531, 0.6076770943962885, 0.9540443011416125]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.08420038484809576], {
             RGBColor[
             0.4773897866032776, 0.5866055607861692, 0.9520010192192697]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.08420038484809576], {
             RGBColor[
             0.5280076807092191, 0.6276994475315159, 0.9559858452627451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.08420038484809576], {
             RGBColor[
             0.5646171395468871, 0.6574206554532607, 0.9588678759673127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.08420038484809576], {
             RGBColor[
             0.8264591072614736, 0.8644600747681946, 0.9833096015109959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.08420038484809576], {
             RGBColor[
             0.7226176412493199, 0.7832336605322344, 0.972987431300087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.08420038484809576], {
             RGBColor[
             0.9662996062253154, 0.9743868820189462, 0.9419301555768618]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.08420038484809576], {
             RGBColor[
             0.7927455551398924, 0.8380181198554356, 0.979977126374084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.08420038484809576], {
             RGBColor[
             0.2424543043863059, 0.372165224773744, 0.9371187860045753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.08420038484809576], {
             RGBColor[
             0.5009030207393497, 0.6056946635169591, 0.953852067142276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.08420038484809576], {
             RGBColor[
             0.8069809870118989, 0.8491389474271364, 0.9813959811854112]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.08420038484809576], {
             RGBColor[
             0.49378658433595574`, 0.5999172198528774, 0.9532918352002353]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.08420038484809576], {
             RGBColor[
             0.6251303601175624, 0.7065480140020554, 0.9636316983578671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.08420038484809576], {
             RGBColor[
             0.6008224394180988, 0.6868137489188825, 0.9617180897975579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.08420038484809576], {
             RGBColor[
             0.776809256941515, 0.825568562582511, 0.9783887451028436]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.08420038484809576], {
             RGBColor[
             0.7463694546809241, 0.8017887577054715, 0.9753547900896331]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.08420038484809576], {
             RGBColor[
             0.8186353705912001, 0.8582434404558823, 0.9825575812241892]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN2wucznW+wPHf/+zadNlSKJUyheimsIbchiJLGlM0NrNmJtWMMW5DaZZc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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[337, 399] -> 
             RGBColor[
              0.9603114409091467, 0.8681403292906987, 0.42659540071605706`], 
             UndirectedEdge[15, 92] -> 
             RGBColor[
              0.3916080301069964, 0.5102971083648917, 0.9465821312407912], 
             UndirectedEdge[87, 313] -> 
             RGBColor[
              0.2082730893529932, 0.33623860055952687`, 0.9351722163750043], 
             UndirectedEdge[35, 214] -> 
             RGBColor[
              0.23799829524204824`, 0.3674816766358314, 0.9368650228758846], 
             UndirectedEdge[105, 218] -> 
             RGBColor[
              0.20016816814604027`, 0.3277198144893344, 0.9347106531024247], 
             UndirectedEdge[149, 316] -> 
             RGBColor[
              0.2254786330368893, 0.3543227178657783, 0.9361520466344813], 
             UndirectedEdge[160, 348] -> 
             RGBColor[
              0.39638156393997953`, 0.5175763121944144, 0.946525366087156], 
             UndirectedEdge[17, 287] -> 
             RGBColor[
              0.2108043778715786, 0.3388991452855218, 0.9353163695114319], 
             UndirectedEdge[268, 295] -> 
             RGBColor[
              0.5541988760682194, 0.6477364431214906, 0.9586174510059542], 
             UndirectedEdge[277, 379] -> 
             RGBColor[
              0.2074585735841274, 0.33538249284316635`, 0.9351258309069355], 
             UndirectedEdge[10, 37] -> 
             RGBColor[
              0.29314980125126083`, 0.4217462676405007, 0.9401414095988625], 
             UndirectedEdge[118, 389] -> 
             RGBColor[
              0.22076497088432706`, 0.3493683600799934, 0.9358836105481312], 
             UndirectedEdge[127, 313] -> 
             RGBColor[
              0.20658568658737522`, 0.3344650332653477, 0.935076121283791], 
             UndirectedEdge[92, 281] -> 
             RGBColor[
              0.46303919301965735`, 0.5742863383640635, 0.9510560694278913], 
             UndirectedEdge[2, 193] -> 
             RGBColor[
              0.18596534003799042`, 0.3127917416364609, 0.9339018230528726], 
             UndirectedEdge[265, 378] -> 
             RGBColor[
              0.19040066183963522`, 0.31745354606563403`, 0.9341544080680056],
              UndirectedEdge[108, 367] -> 
             RGBColor[
              0.31561783688898226`, 0.44293150514134, 0.9415099085808494], 
             UndirectedEdge[26, 342] -> 
             RGBColor[
              0.18535691671142462`, 0.3121522501439733, 0.9338671742445064], 
             UndirectedEdge[57, 144] -> 
             RGBColor[
              0.20411547873617336`, 0.33186868819351084`, 0.93493544660101], 
             UndirectedEdge[341, 348] -> 
             RGBColor[
              0.33468734849454873`, 0.4643110922158917, 0.9425469597870388], 
             UndirectedEdge[232, 309] -> 
             RGBColor[
              0.2963446868922668, 0.42880743363510754`, 0.9401877635646132], 
             UndirectedEdge[23, 202] -> 
             RGBColor[
              0.2682077809117381, 0.39923376146669465`, 0.9385854083938443], 
             UndirectedEdge[89, 170] -> 
             RGBColor[
              0.21045471282523004`, 0.33853162515176505`, 0.9352964566043255],
              UndirectedEdge[291, 383] -> 
             RGBColor[
              0.1977645203288262, 0.3251934282333686, 0.9345737689151127], 
             UndirectedEdge[45, 140] -> 
             RGBColor[
              0.25525427585226035`, 0.38561880634952683`, 0.9378477254437005],
              UndirectedEdge[213, 308] -> 
             RGBColor[
              0.2120594900785835, 0.3402183477937941, 0.9353878462948488], 
             UndirectedEdge[165, 386] -> 
             RGBColor[
              0.8287550787424094, 0.8667695006906301, 0.9834015662110343], 
             UndirectedEdge[347, 381] -> 
             RGBColor[
              0.1970073353004369, 0.3243975787602278, 0.9345306483479008], 
             UndirectedEdge[216, 396] -> 
             RGBColor[
              0.19963425463605258`, 0.3271586375382656, 0.9346802475178853], 
             UndirectedEdge[39, 150] -> 
             RGBColor[
              0.1883607596919023, 0.31530947957110045`, 0.9340382386584571], 
             UndirectedEdge[20, 378] -> 
             RGBColor[
              0.19055340614426983`, 0.31761409001435326`, 0.9341631066301896],
              UndirectedEdge[363, 372] -> 
             RGBColor[
              0.20698461099735616`, 0.3348843281135061, 0.9350988394387836], 
             UndirectedEdge[54, 318] -> 
             RGBColor[
              0.18950140793350456`, 0.31650837319430003`, 0.9341031968883784],
              UndirectedEdge[40, 246] -> 
             RGBColor[
              0.7206526383610699, 0.7806508133791874, 0.9738469548784772], 
             UndirectedEdge[59, 178] -> 
             RGBColor[
              0.3941011919373124, 0.5157723771794137, 0.9463327573536129], 
             UndirectedEdge[172, 357] -> 
             RGBColor[
              0.8349023138683568, 0.2692800554494574, 0.18105580121785106`], 
             UndirectedEdge[268, 274] -> 
             RGBColor[
              0.5862206904488971, 0.6743925388404906, 0.9609561467561663], 
             UndirectedEdge[122, 175] -> 
             RGBColor[
              0.4398070896700592, 0.5489279977942612, 0.9504219852000314], 
             UndirectedEdge[120, 341] -> 
             RGBColor[
              0.42726711236099996`, 0.542734639248357, 0.9489335670306169], 
             UndirectedEdge[220, 366] -> 
             RGBColor[
              0.5151109603637722, 0.615629530907049, 0.9554125916387102], 
             UndirectedEdge[202, 366] -> 
             RGBColor[
              0.31887937893336776`, 0.4445735814559359, 0.9417610431931018], 
             UndirectedEdge[17, 61] -> 
             RGBColor[
              0.22052046256389546`, 0.34911136633249684`, 0.9358696861610002],
              UndirectedEdge[112, 279] -> 
             RGBColor[
              0.8046710367643358, 0.7661172165820809, 0.618109700945247], 
             UndirectedEdge[129, 313] -> 
             RGBColor[
              0.203727765298821, 0.33146117678840176`, 0.9349133668943235], 
             UndirectedEdge[204, 318] -> 
             RGBColor[
              0.1940125074344074, 0.321249824789977, 0.9343600973313813], 
             UndirectedEdge[60, 335] -> 
             RGBColor[
              0.18275395419094043`, 0.3094163714975885, 0.9337189393797027], 
             UndirectedEdge[256, 386] -> 
             RGBColor[
              0.556034698630532, 0.6458694921919914, 0.9601976146247932], 
             UndirectedEdge[7, 65] -> 
             RGBColor[
              0.36829577629683624`, 0.4914979419428903, 0.9447588725119885], 
             UndirectedEdge[66, 280] -> 
             RGBColor[
              0.23290342941472336`, 0.362126649618162, 0.936574877804197], 
             UndirectedEdge[147, 344] -> 
             RGBColor[
              0.1873628349672718, 0.31426059741343176`, 0.9339814083216866], 
             UndirectedEdge[329, 349] -> 
             RGBColor[
              0.19621450085245074`, 0.32356425948678696`, 0.9344854975989814],
              UndirectedEdge[170, 306] -> 
             RGBColor[
              0.21718838977102684`, 0.3456091465615747, 0.9356799295448063], 
             UndirectedEdge[175, 178] -> 
             RGBColor[
              0.3616708025324146, 0.48517771913218966`, 0.9443580450417194], 
             UndirectedEdge[115, 166] -> 
             RGBColor[
              0.9063036593555713, 0.6487345751416961, 0.4126405920007503], 
             UndirectedEdge[361, 396] -> 
             RGBColor[
              0.20859692759923504`, 0.3365789750888577, 0.935190658484052], 
             UndirectedEdge[80, 265] -> 
             RGBColor[
              0.18489536415726843`, 0.31166712914543293`, 0.933840889509353], 
             UndirectedEdge[18, 288] -> 
             RGBColor[
              0.45525573629442806`, 0.5643070139273578, 0.9513799079587884], 
             UndirectedEdge[225, 240] -> 
             RGBColor[
              0.8493627071457939, 0.4666896772579783, 0.44827431990902944`], 
             UndirectedEdge[110, 251] -> 
             RGBColor[
              0.18685400772656674`, 0.3137257877219404, 0.9339524313630709], 
             UndirectedEdge[56, 169] -> 
             RGBColor[
              0.6387195548301612, 0.7123648726900207, 0.967730862260616], 
             UndirectedEdge[87, 231] -> 
             RGBColor[
              0.19018595982878306`, 0.3172278806393347, 0.9341421811061108], 
             UndirectedEdge[266, 315] -> 
             RGBColor[
              0.22579916171770553`, 0.3546596138320083, 0.9361703002686741], 
             UndirectedEdge[31, 292] -> 
             RGBColor[
              0.19543097961487327`, 0.32274072898797734`, 0.9344408772236172],
              UndirectedEdge[1, 87] -> 
             RGBColor[
              0.19586287681444192`, 0.32319468032858806`, 0.934465473130198], 
             UndirectedEdge[231, 336] -> 
             RGBColor[
              0.1812731232878139, 0.3078599243283004, 0.9336346082504626], 
             UndirectedEdge[13, 309] -> 
             RGBColor[
              0.25587961899129924`, 0.38627608163770166`, 0.9378833378103566],
              UndirectedEdge[237, 296] -> 
             RGBColor[
              0.2211466738327187, 0.34976955408011773`, 0.935905347966363], 
             UndirectedEdge[95, 312] -> 
             RGBColor[
              0.43115946169626646`, 0.5444500738116986, 0.9495097680739197], 
             UndirectedEdge[108, 236] -> 
             RGBColor[
              0.2534644343240474, 0.3837375694208677, 0.9377457966165021], 
             UndirectedEdge[48, 176] -> 
             RGBColor[
              0.2369284794639835, 0.36635723242284735`, 0.9368040984499744], 
             UndirectedEdge[49, 52] -> 
             RGBColor[
              0.1835216269875808, 0.31022324428012404`, 0.9337626572098012], 
             UndirectedEdge[310, 390] -> 
             RGBColor[
              0.27115500533733905`, 0.4023314812028227, 0.9387532484648545], 
             UndirectedEdge[343, 358] -> 
             RGBColor[
              0.18639835798283702`, 0.3132468709514181, 0.933926482784239], 
             UndirectedEdge[271, 374] -> 
             RGBColor[
              0.184659451088446, 0.3114191695523481, 0.9338274546090857], 
             UndirectedEdge[57, 167] -> 
             RGBColor[
              0.2639676028821611, 0.3946376054360735, 0.9383490428444853], 
             UndirectedEdge[34, 214] -> 
             RGBColor[
              0.25149658822823806`, 0.38166923840552336`, 0.9376337306925131],
              UndirectedEdge[83, 220] -> 
             RGBColor[
              0.790428504618827, 0.8368778917698232, 0.9711999364788909], 
             UndirectedEdge[9, 347] -> 
             RGBColor[
              0.19444294915612814`, 0.3217022463310869, 0.9343846103506517], 
             UndirectedEdge[188, 238] -> 
             RGBColor[
              0.2458833929201038, 0.375769414239536, 0.9373140675236933], 
             UndirectedEdge[79, 137] -> 
             RGBColor[
              0.2827537056275888, 0.4121446936308188, 0.939500838618308], 
             UndirectedEdge[115, 197] -> 
             RGBColor[
              0.897842532453212, 0.6430337674437561, 0.45425714111029625`], 
             UndirectedEdge[67, 194] -> 
             RGBColor[
              0.709877099853931, 0.7667201163798876, 0.7972498678529694], 
             UndirectedEdge[75, 260] -> 
             RGBColor[
              0.22127423884363956`, 0.34990363299468435`, 0.9359126126050195],
              UndirectedEdge[32, 387] -> 
             RGBColor[
              0.7455791435710649, 0.7496942133696903, 0.622023162461701], 
             UndirectedEdge[76, 144] -> 
             RGBColor[
              0.19222334020881804`, 0.31936929659612845`, 0.9342582069047196],
              UndirectedEdge[50, 164] -> 
             RGBColor[
              0.18999442899880858`, 0.3170265695932755, 0.9341312737086882], 
             UndirectedEdge[279, 285] -> 
             RGBColor[
              0.8332166202434534, 0.8669371947579207, 0.788972494773293], 
             UndirectedEdge[137, 352] -> 
             RGBColor[
              0.28703295098175935`, 0.4166424518178782, 0.9397445353106518], 
             UndirectedEdge[4, 275] -> 
             RGBColor[
              0.235784586016354, 0.3651549278823552, 0.9367389554103707], 
             UndirectedEdge[8, 373] -> 
             RGBColor[
              0.2548317087924608, 0.38517466157737845`, 0.937823660874777], 
             UndirectedEdge[41, 135] -> 
             RGBColor[
              0.9333566323648748, 0.9460233638065111, 0.83381543555314], 
             UndirectedEdge[85, 211] -> 
             RGBColor[
              0.231317411938528, 0.36045964469136466`, 0.9364845564552302], 
             UndirectedEdge[63, 139] -> 
             RGBColor[
              0.18462055320460163`, 0.31137828541015944`, 0.9338252394321449],
              UndirectedEdge[55, 92] -> 
             RGBColor[
              0.7345108890138425, 0.7594054710903482, 0.6489345144638174], 
             UndirectedEdge[31, 371] -> 
             RGBColor[
              0.1915120199175549, 0.31862165386969954`, 0.9342176982664363], 
             UndirectedEdge[99, 169] -> 
             RGBColor[
              0.9307128082989145, 0.9468171296861931, 0.9664871194315787], 
             UndirectedEdge[71, 72] -> 
             RGBColor[
              0.18087056047954858`, 0.30743680529285733`, 0.9336116828940703],
              UndirectedEdge[104, 112] -> 
             RGBColor[
              0.8583753725290609, 0.36086558387559853`, 0.19997554950264038`],
              UndirectedEdge[389, 390] -> 
             RGBColor[
              0.23267978688900162`, 0.3618915871438733, 0.9365621416932066], 
             UndirectedEdge[260, 349] -> 
             RGBColor[
              0.21328372600725728`, 0.3415050973758713, 0.9354575647198919], 
             UndirectedEdge[70, 284] -> 
             RGBColor[
              0.24975725951810934`, 0.3798410936513683, 0.9375346784955776], 
             UndirectedEdge[24, 172] -> 
             RGBColor[
              0.8217923093699344, 0.16851081603398022`, 0.16850164610452945`],
              UndirectedEdge[343, 362] -> 
             RGBColor[
              0.18559297832352872`, 0.3124003658654654, 0.9338806176040938], 
             UndirectedEdge[233, 307] -> 
             RGBColor[
              0.6538804302709667, 0.7226974017073509, 0.9485082265240019], 
             UndirectedEdge[79, 278] -> 
             RGBColor[
              0.24460490622546205`, 0.37442564366272924`, 0.937241259597785], 
             UndirectedEdge[1, 216] -> 
             RGBColor[
              0.19662871859939152`, 0.3239996286017438, 0.9345090866868895], 
             UndirectedEdge[192, 374] -> 
             RGBColor[
              0.18592011737534742`, 0.3127442097507407, 0.933899247689136], 
             UndirectedEdge[152, 383] -> 
             RGBColor[
              0.2325615956471479, 0.3617673606549275, 0.9365554108768314], 
             UndirectedEdge[43, 121] -> 
             RGBColor[
              0.28563299292961386`, 0.4173490407437973, 0.9395850612911336], 
             UndirectedEdge[13, 280] -> 
             RGBColor[
              0.23284937828008462`, 0.36206983844861684`, 0.9365717996720409],
              UndirectedEdge[246, 272] -> 
             RGBColor[
              0.8305893181173114, 0.8683923303180165, 0.9835339903359117], 
             UndirectedEdge[385, 387] -> 
             RGBColor[
              0.7642756795140044, 0.8115756260652711, 0.7955379877927361], 
             UndirectedEdge[90, 268] -> 
             RGBColor[
              0.6438707815800897, 0.7211954799278018, 0.9654945731092558], 
             UndirectedEdge[195, 363] -> 
             RGBColor[
              0.21087458530257291`, 0.33897293774690507`, 0.9353203677207644],
              UndirectedEdge[88, 109] -> 
             RGBColor[
              0.18639597403767888`, 0.31324436527390603`, 0.9339263470220889],
              UndirectedEdge[63, 318] -> 
             RGBColor[
              0.18778593589765713`, 0.3147053033174152, 0.9340055032937504], 
             UndirectedEdge[257, 276] -> 
             RGBColor[
              0.27298076036949565`, 0.4029229337235066, 0.9389058299544288], 
             UndirectedEdge[16, 106] -> 
             RGBColor[
              0.2722971064429795, 0.4026970623499158, 0.9388488569979281], 
             UndirectedEdge[100, 227] -> 
             RGBColor[
              0.20880854883445307`, 0.33680140242463313`, 0.9352027100003322],
              UndirectedEdge[195, 359] -> 
             RGBColor[
              0.19452611281546262`, 0.321789656609928, 0.9343893463980213], 
             UndirectedEdge[216, 313] -> 
             RGBColor[
              0.2090389311379428, 0.3370435488326826, 0.9352158299316957], 
             UndirectedEdge[12, 47] -> 
             RGBColor[
              0.4262898849714413, 0.5411626092696967, 0.9490658048705467], 
             UndirectedEdge[386, 400] -> 
             RGBColor[
              0.8203725249629105, 0.5288099921038794, 0.4560525726712711], 
             UndirectedEdge[180, 262] -> 
             RGBColor[
              0.23634740435871976`, 0.36574648564492557`, 0.9367710070823533],
              UndirectedEdge[247, 359] -> 
             RGBColor[
              0.1924159607622266, 0.31957175301060936`, 0.9342691763602797], 
             UndirectedEdge[74, 141] -> 
             RGBColor[
              0.8647517069281606, 0.6196093049293407, 0.46864262893452036`], 
             UndirectedEdge[170, 171] -> 
             RGBColor[
              0.21031358554217228`, 0.3383832914292848, 0.9352884196143345], 
             UndirectedEdge[207, 333] -> 
             RGBColor[
              0.18793493502051017`, 0.3148619108426237, 0.9340139885733725], 
             UndirectedEdge[311, 313] -> 
             RGBColor[
              0.2605556138292256, 0.39119084868755866`, 0.938149628798862], 
             UndirectedEdge[161, 195] -> 
             RGBColor[
              0.20065168741435874`, 0.3282280238972294, 0.9347381888094528], 
             UndirectedEdge[87, 129] -> 
             RGBColor[
              0.1936336407966272, 0.32085161193213774`, 0.9343385214368426], 
             UndirectedEdge[198, 367] -> 
             RGBColor[
              0.36419518981338295`, 0.4898693012590379, 0.9444271733431154], 
             UndirectedEdge[322, 330] -> 
             RGBColor[
              0.19291768102176954`, 0.3200990928142907, 0.934297748586832], 
             UndirectedEdge[79, 314] -> 
             RGBColor[
              0.23185910927542647`, 0.36102900293803986`, 0.9365154053171973],
              UndirectedEdge[56, 274] -> 
             RGBColor[
              0.43736444745775693`, 0.5521652442024196, 0.9493877477928349], 
             UndirectedEdge[249, 316] -> 
             RGBColor[
              0.271715102066897, 0.4028896300992718, 0.9387862636671344], 
             UndirectedEdge[69, 294] -> 
             RGBColor[
              0.2158880199071448, 0.3442423753864234, 0.935605875404783], 
             UndirectedEdge[6, 300] -> 
             RGBColor[
              0.6101439916355338, 0.6866719134983721, 0.9662201158700239], 
             UndirectedEdge[36, 265] -> 
             RGBColor[
              0.1914303121066489, 0.318535773779863, 0.934213045127481], 
             UndirectedEdge[167, 395] -> 
             RGBColor[
              0.389446651029121, 0.5113248488468087, 0.9461511158699245], 
             UndirectedEdge[261, 306] -> 
             RGBColor[
              0.2313412040252819, 0.36048465168304844`, 0.9364859113793738], 
             UndirectedEdge[35, 211] -> 
             RGBColor[
              0.22907054143597805`, 0.35809804133336665`, 0.9363566005040571],
              UndirectedEdge[54, 63] -> 
             RGBColor[
              0.18289690010848875`, 0.3095666167202264, 0.9337270799382376], 
             UndirectedEdge[302, 314] -> 
             RGBColor[
              0.21202470254257239`, 0.3401817838877893, 0.9353858651961364], 
             UndirectedEdge[54, 224] -> 
             RGBColor[
              0.18197335735342035`, 0.3085959147286568, 0.9336744855445955], 
             UndirectedEdge[164, 389] -> 
             RGBColor[
              0.20180063292388895`, 0.3294356384750984, 0.934803619556508], 
             UndirectedEdge[113, 210] -> 
             RGBColor[
              0.3065896783902691, 0.43957556926948627`, 0.9407712006743179], 
             UndirectedEdge[307, 348] -> 
             RGBColor[
              0.3407470767330234, 0.4695597242452613, 0.9429330803119872], 
             UndirectedEdge[18, 74] -> 
             RGBColor[
              0.7341001698400949, 0.7919819236306536, 0.974429319456183], 
             UndirectedEdge[41, 328] -> 
             RGBColor[
              0.8707008812978143, 0.7005608755905404, 0.6002433163697872], 
             UndirectedEdge[63, 290] -> 
             RGBColor[
              0.18969933550436535`, 0.3167164076206075, 0.9341144685707314], 
             UndirectedEdge[45, 288] -> 
             RGBColor[
              0.29509029119202934`, 0.4274889842208769, 0.9401163275851969], 
             UndirectedEdge[249, 315] -> 
             RGBColor[
              0.2639611950336743, 0.39473978218125394`, 0.9383446901324698], 
             UndirectedEdge[306, 342] -> 
             RGBColor[
              0.1932134040418383, 0.3204099164583054, 0.934314589575342], 
             UndirectedEdge[163, 395] -> 
             RGBColor[
              0.36771682090515007`, 0.4886248797144314, 0.9449085278741232], 
             UndirectedEdge[378, 379] -> 
             RGBColor[
              0.19896021464386793`, 0.3264501787698757, 0.934641861937483], 
             UndirectedEdge[216, 235] -> 
             RGBColor[
              0.1956123156574894, 0.32293132466613605`, 0.9344512040429815], 
             UndirectedEdge[220, 321] -> 
             RGBColor[
              0.5950920301278422, 0.6821615445050555, 0.961266970987048], 
             UndirectedEdge[133, 199] -> 
             RGBColor[
              0.18613849661309062`, 0.31297374017565216`, 0.9339116840636623],
              UndirectedEdge[317, 396] -> 
             RGBColor[
              0.19745595153076353`, 0.32486910286221293`, 0.9345561963785496],
              UndirectedEdge[177, 197] -> 
             RGBColor[
              0.9295820155952076, 0.9459496447868232, 0.9675642537426303], 
             UndirectedEdge[208, 242] -> 
             RGBColor[
              0.8991873759760702, 0.5989945750982921, 0.3869330957871117], 
             UndirectedEdge[51, 163] -> 
             RGBColor[
              0.3241863421441664, 0.4513369658591039, 0.9420198625128315], 
             UndirectedEdge[188, 228] -> 
             RGBColor[
              0.20268995802939208`, 0.3303703755474506, 0.9348542653056278], 
             UndirectedEdge[95, 125] -> 
             RGBColor[
              0.41046090544111513`, 0.5226945788232695, 0.9483310159159588], 
             UndirectedEdge[66, 203] -> 
             RGBColor[
              0.2200139191384291, 0.3485789570756236, 0.9358408392622837], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.2667189772067604, 0.39766893437715617`, 0.9385006232253336], 
             UndirectedEdge[151, 265] -> 
             RGBColor[
              0.1910010224377346, 0.31808456311929695`, 0.9341885977159134], 
             UndirectedEdge[76, 333] -> 
             RGBColor[
              0.19100459551754329`, 0.3180883186527222, 0.9341888011975227], 
             UndirectedEdge[119, 336] -> 
             RGBColor[
              0.18138462902211405`, 0.30797712392492177`, 0.9336409583370731],
              UndirectedEdge[183, 395] -> 
             RGBColor[
              0.40931291362813915`, 0.5285320070026871, 0.9474169765556877], 
             UndirectedEdge[42, 204] -> 
             RGBColor[
              0.20507426806755127`, 0.33287643657154375`, 0.9349900482350304],
              UndirectedEdge[12, 107] -> 
             RGBColor[
              0.3285473986430889, 0.45896802364421685`, 0.9421566412492507], 
             UndirectedEdge[234, 239] -> 
             RGBColor[
              0.8137495240944908, 0.42044629252070553`, 0.4425717899514292], 
             UndirectedEdge[164, 287] -> 
             RGBColor[
              0.19544251078166353`, 0.3227528489753921, 0.9344415339065071], 
             UndirectedEdge[32, 194] -> 
             RGBColor[
              0.9757819569708761, 0.9287169668940988, 0.4668813870087187], 
             UndirectedEdge[6, 169] -> 
             RGBColor[
              0.6006886092479335, 0.6791324482420171, 0.965318253056975], 
             UndirectedEdge[24, 240] -> 
             RGBColor[
              0.8244208751281166, 0.18871512429622833`, 0.17101876364310512`],
              UndirectedEdge[9, 381] -> 
             RGBColor[
              0.19359903145009902`, 0.3208152353145773, 0.9343365504857577], 
             UndirectedEdge[43, 90] -> 
             RGBColor[
              0.434369237561579, 0.5419666394359329, 0.9502257108546233], 
             UndirectedEdge[88, 157] -> 
             RGBColor[
              0.189431793006949, 0.31643520349264886`, 0.9340992324212971], 
             UndirectedEdge[100, 314] -> 
             RGBColor[
              0.22141089937149833`, 0.35004727187424184`, 0.93592039521991], 
             UndirectedEdge[56, 296] -> 
             RGBColor[
              0.313305483869233, 0.43989379597440015`, 0.9414004589756761], 
             UndirectedEdge[49, 235] -> 
             RGBColor[
              0.18959591922153213`, 0.31660771055037873`, 0.9341085791664148],
              UndirectedEdge[359, 362] -> 
             RGBColor[
              0.18818450229900258`, 0.31512422187579864`, 0.9340282010606809],
              UndirectedEdge[104, 285] -> 
             RGBColor[
              0.8774057615151394, 0.4280789026594918, 0.3138840787213377], 
             UndirectedEdge[80, 168] -> 
             RGBColor[
              0.18200651498987047`, 0.3086307655068815, 0.933676373822939], 
             UndirectedEdge[311, 386] -> 
             RGBColor[
              0.5317523136158948, 0.6242823861276408, 0.958670681032904], 
             UndirectedEdge[61, 173] -> 
             RGBColor[
              0.24592220228648118`, 0.3758102053442546, 0.937316277659695], 
             UndirectedEdge[118, 354] -> 
             RGBColor[
              0.22736699671866945`, 0.3563075078245018, 0.9362595861525749], 
             UndirectedEdge[154, 180] -> 
             RGBColor[
              0.2320279298273124, 0.36120644404191316`, 0.9365250193978796], 
             UndirectedEdge[17, 158] -> 
             RGBColor[
              0.2852162427380673, 0.4143360909345327, 0.9396556083799944], 
             UndirectedEdge[8, 237] -> 
             RGBColor[
              0.2175725261235523, 0.3460128982237305, 0.9357018055418038], 
             UndirectedEdge[55, 255] -> 
             RGBColor[
              0.880784705491405, 0.48719515298926147`, 0.23576144034449814`], 
             UndirectedEdge[93, 214] -> 
             RGBColor[
              0.23703264551730702`, 0.36646671754939963`, 0.9368100305526114],
              UndirectedEdge[129, 235] -> 
             RGBColor[
              0.1903011498183676, 0.3173489526218552, 0.9341487410056093], 
             UndirectedEdge[47, 158] -> 
             RGBColor[
              0.44142989596913074`, 0.5543010784500094, 0.9500295993461311], 
             UndirectedEdge[106, 347] -> 
             RGBColor[
              0.21233497992474068`, 0.3405079050891704, 0.9354035350340366], 
             UndirectedEdge[169, 178] -> 
             RGBColor[
              0.668739474081812, 0.7383666179007873, 0.9696437049697588], 
             UndirectedEdge[230, 385] -> 
             RGBColor[
              0.8766339838226677, 0.4217282490533341, 0.32128251559499077`], 
             UndirectedEdge[304, 383] -> 
             RGBColor[
              0.1946222087294852, 0.32189065950839857`, 0.9343948189181637], 
             UndirectedEdge[100, 352] -> 
             RGBColor[
              0.2248749641652065, 0.3536882236068225, 0.936117668585287], 
             UndirectedEdge[87, 216] -> 
             RGBColor[
              0.198944806635749, 0.32643398397641854`, 0.9346409844742148], 
             UndirectedEdge[79, 277] -> 
             RGBColor[
              0.21942962029019444`, 0.3479648219394422, 0.9358075643072694], 
             UndirectedEdge[217, 220] -> 
             RGBColor[
              0.8144460532518553, 0.851406632354037, 0.7257595325601884], 
             UndirectedEdge[78, 104] -> 
             RGBColor[
              0.8196280933998756, 0.15187570372262318`, 0.16642919044746882`],
              UndirectedEdge[170, 353] -> 
             RGBColor[
              0.2108426436010009, 0.33893936499333205`, 0.9353185486881135], 
             UndirectedEdge[78, 385] -> 
             RGBColor[
              0.8781001584283712, 0.43299790955458023`, 0.3226865260532199], 
             UndirectedEdge[40, 102] -> 
             RGBColor[
              0.39926565859510593`, 0.5155146756656562, 0.9472759248895897], 
             UndirectedEdge[41, 256] -> 
             RGBColor[
              0.6115898950741928, 0.6896890172445088, 0.9656235459657501], 
             UndirectedEdge[120, 217] -> 
             RGBColor[
              0.7556843813439534, 0.80370125991605, 0.7211335984965017], 
             UndirectedEdge[210, 315] -> 
             RGBColor[
              0.26224986664151034`, 0.39297161581510254`, 0.9382461139900993],
              UndirectedEdge[83, 187] -> 
             RGBColor[
              0.6899774075909928, 0.7548276258988081, 0.9634300825559947], 
             UndirectedEdge[2, 305] -> 
             RGBColor[
              0.18360947068078184`, 0.31031557357129014`, 0.9337676597781759],
              UndirectedEdge[121, 175] -> 
             RGBColor[
              0.29627876905743955`, 0.4285384264353338, 0.9401913224925988], 
             UndirectedEdge[36, 151] -> 
             RGBColor[
              0.19244860485001886`, 0.3196060640166337, 0.9342710353927868], 
             UndirectedEdge[70, 332] -> 
             RGBColor[
              0.22563024765380635`, 0.35448207444108004`, 0.936160680862621], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.1986384662361157, 0.32611200079330077`, 0.9346235388416457], 
             UndirectedEdge[221, 400] -> 
             RGBColor[
              0.8675551125355545, 0.47422857106757765`, 0.2105215349800247], 
             UndirectedEdge[49, 216] -> 
             RGBColor[
              0.19369425198474133`, 0.320915318133817, 0.9343419731543394], 
             UndirectedEdge[75, 349] -> 
             RGBColor[
              0.2099761655665867, 0.3380286416412822, 0.935269204045893], 
             UndirectedEdge[62, 87] -> 
             RGBColor[
              0.1996423811721627, 0.3271671790429695, 0.9346807103120945], 
             UndirectedEdge[38, 189] -> 
             RGBColor[
              0.24478652953490182`, 0.3746165412765333, 0.9372516027765698], 
             UndirectedEdge[49, 361] -> 
             RGBColor[
              0.2026569249479238, 0.33033565568440915`, 0.9348523841205063], 
             UndirectedEdge[107, 270] -> 
             RGBColor[
              0.35385896317997434`, 0.4809165812630355, 0.943768558122001], 
             UndirectedEdge[5, 8] -> 
             RGBColor[
              0.2601258969540067, 0.39073918900607996`, 0.9381251570585274], 
             UndirectedEdge[162, 340] -> 
             RGBColor[
              0.23763180163327896`, 0.367096468615978, 0.9368441516070439], 
             UndirectedEdge[34, 85] -> 
             RGBColor[
              0.25199669770088307`, 0.3821948851700452, 0.9376622111871347], 
             UndirectedEdge[21, 172] -> 
             RGBColor[
              0.8702695187872548, 0.4184898017964773, 0.21746738553413028`], 
             UndirectedEdge[298, 393] -> 
             RGBColor[
              0.19018046268844432`, 0.31722210279629987`, 0.9341418680521008],
              UndirectedEdge[164, 371] -> 
             RGBColor[
              0.1937500929349124, 0.3209740105129675, 0.9343451532138425], 
             UndirectedEdge[11, 85] -> 
             RGBColor[
              0.2763549775912347, 0.40749939278433556`, 0.9390602753814483], 
             UndirectedEdge[202, 307] -> 
             RGBColor[
              0.295856931076972, 0.42463269426460054`, 0.9402940731736436], 
             UndirectedEdge[20, 265] -> 
             RGBColor[
              0.19013547399899927`, 0.31717481683124543`, 0.9341393060127917],
              UndirectedEdge[195, 247] -> 
             RGBColor[
              0.1997381438211963, 0.32726783165880646`, 0.9346861638532888], 
             UndirectedEdge[281, 355] -> 
             RGBColor[
              0.5971975343016019, 0.6813125874620714, 0.9629093916561169], 
             UndirectedEdge[298, 313] -> 
             RGBColor[
              0.20768244341745035`, 0.33561779423215604`, 0.9351385799627575],
              UndirectedEdge[67, 210] -> 
             RGBColor[
              0.365438140563206, 0.4906599829992886, 0.9445168412553058], 
             UndirectedEdge[11, 263] -> 
             RGBColor[
              0.35195866140263943`, 0.47927063537545245`, 0.9436474725731201],
              UndirectedEdge[88, 181] -> 
             RGBColor[
              0.19319654196954522`, 0.3203921933512083, 0.9343136293052701], 
             UndirectedEdge[212, 390] -> 
             RGBColor[
              0.3400236714682391, 0.46467688938800766`, 0.9430428280078589], 
             UndirectedEdge[13, 203] -> 
             RGBColor[
              0.21995986800379036`, 0.3485221459060784, 0.9358377611301275], 
             UndirectedEdge[75, 105] -> 
             RGBColor[
              0.21372122175088312`, 0.34196493314125437`, 0.9354824794552745],
              UndirectedEdge[12, 270] -> 
             RGBColor[
              0.3337876806083378, 0.46350689249828564`, 0.9424905473822769], 
             UndirectedEdge[127, 393] -> 
             RGBColor[
              0.1890837058583692, 0.31606934182949153`, 0.9340794093731344], 
             UndirectedEdge[185, 208] -> 
             RGBColor[
              0.6963078073762952, 0.755957556681333, 0.8560508247348155], 
             UndirectedEdge[246, 355] -> 
             RGBColor[
              0.8429762449225704, 0.8780690916824152, 0.9847686034374477], 
             UndirectedEdge[62, 336] -> 
             RGBColor[
              0.19072954463119351`, 0.31779922273193517`, 0.9341731374564464],
              UndirectedEdge[118, 209] -> 
             RGBColor[
              0.2868618960178613, 0.41642761918472027`, 0.9397360770801573], 
             UndirectedEdge[178, 352] -> 
             RGBColor[
              0.3406463330534576, 0.4630796686814488, 0.9431607326078082], 
             UndirectedEdge[17, 22] -> 
             RGBColor[
              0.2739758563683775, 0.40460023321935323`, 0.9389393809000012], 
             UndirectedEdge[12, 158] -> 
             RGBColor[
              0.32361612706914167`, 0.45469680405977975`, 0.941842424985111], 
             UndirectedEdge[200, 333] -> 
             RGBColor[
              0.18616349406283006`, 0.3130000140802582, 0.9339131076314446], 
             UndirectedEdge[69, 295] -> 
             RGBColor[
              0.3354255676488553, 0.4587623903805083, 0.9428205754850394], 
             UndirectedEdge[181, 340] -> 
             RGBColor[
              0.19892920598511726`, 0.3264175867034662, 0.9346400960402405], 
             UndirectedEdge[205, 284] -> 
             RGBColor[
              0.313308210862673, 0.4428213204414291, 0.9412935282095445], 
             UndirectedEdge[283, 373] -> 
             RGBColor[
              0.2404157449182508, 0.3700225695206825, 0.937002693058648], 
             UndirectedEdge[302, 379] -> 
             RGBColor[
              0.199238475276043, 0.32674264833703476`, 0.9346577084688357], 
             UndirectedEdge[254, 303] -> 
             RGBColor[
              0.20024144683233963`, 0.3277968350347721, 0.9347148262152034], 
             UndirectedEdge[38, 254] -> 
             RGBColor[
              0.20508861754811766`, 0.3328915187854286, 0.9349908654167205], 
             UndirectedEdge[158, 209] -> 
             RGBColor[
              0.336799320476102, 0.4661403761955148, 0.94268153277416], 
             UndirectedEdge[365, 370] -> 
             RGBColor[
              0.18400910577117147`, 0.3107356153896179, 0.9337904184053665], 
             UndirectedEdge[61, 164] -> 
             RGBColor[
              0.2051585954739804, 0.3329650700223671, 0.9349948505560753], 
             UndirectedEdge[163, 167] -> 
             RGBColor[
              0.2885245503262027, 0.4204485142001573, 0.9397475246726753], 
             UndirectedEdge[62, 119] -> 
             RGBColor[
              0.1917608818844465, 0.31888322357566273`, 0.9342318705872924], 
             UndirectedEdge[137, 197] -> 
             RGBColor[
              0.6493874970557305, 0.7185106775296126, 0.9439140882472267], 
             UndirectedEdge[265, 383] -> 
             RGBColor[
              0.1991683094404495, 0.3266688995950551, 0.9346537126282998], 
             UndirectedEdge[19, 338] -> 
             RGBColor[
              0.24730224830049347`, 0.3772607212049526, 0.937394869238598], 
             UndirectedEdge[69, 212] -> 
             RGBColor[
              0.32957634955032006`, 0.4536960916538069, 0.9424478684800611], 
             UndirectedEdge[45, 275] -> 
             RGBColor[
              0.261779864050582, 0.3924776132921515, 0.9382193480378523], 
             UndirectedEdge[248, 360] -> 
             RGBColor[
              0.20162405229043762`, 0.3292500410334822, 0.9347935635506606], 
             UndirectedEdge[188, 322] -> 
             RGBColor[
              0.20084485470176572`, 0.3284310549638075, 0.9347491894007052], 
             UndirectedEdge[167, 183] -> 
             RGBColor[
              0.33012064304919175`, 0.46035564148841296`, 0.9422559733542398],
              UndirectedEdge[141, 240] -> 
             RGBColor[
              0.8542946643121351, 0.403254589818024, 0.1990353031720827], 
             UndirectedEdge[23, 220] -> 
             RGBColor[
              0.46443936234214256`, 0.5702897109178078, 0.9522369568394528], 
             UndirectedEdge[123, 322] -> 
             RGBColor[
              0.20580146810397543`, 0.3336407699169709, 0.9350314612013086], 
             UndirectedEdge[177, 398] -> 
             RGBColor[
              0.6604733814795012, 0.7312391377896288, 0.9691021762679148], 
             UndirectedEdge[272, 395] -> 
             RGBColor[
              0.6047861017850406, 0.688521596311049, 0.9630625411341533], 
             UndirectedEdge[85, 312] -> 
             RGBColor[
              0.27182714160879756`, 0.40303793904002655`, 0.9387915256311776],
              UndirectedEdge[25, 328] -> 
             RGBColor[
              0.8347229187599272, 0.2562351535933635, 0.18042720125236386`], 
             UndirectedEdge[8, 121] -> 
             RGBColor[
              0.2743592219367422, 0.4054995926319236, 0.9389430367111391], 
             UndirectedEdge[169, 319] -> 
             RGBColor[
              0.6745752376290368, 0.7434200744106859, 0.9700158830654886], 
             UndirectedEdge[84, 167] -> 
             RGBColor[
              0.32454610124482625`, 0.4555272535620894, 0.9419007684798394], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.2877186940288704, 0.4160544664052851, 0.9398315069221266], 
             UndirectedEdge[43, 213] -> 
             RGBColor[
              0.2414891450614786, 0.3711507811287148, 0.9370638216088516], 
             UndirectedEdge[170, 187] -> 
             RGBColor[
              0.33329236872326556`, 0.45597611149735384`, 0.9427190170162062],
              UndirectedEdge[89, 199] -> 
             RGBColor[
              0.18786740786844439`, 0.3147909355243339, 0.9340101430019597], 
             UndirectedEdge[16, 373] -> 
             RGBColor[
              0.29481332974402036`, 0.42636304065032193`, 0.9401311226051551],
              UndirectedEdge[22, 158] -> 
             RGBColor[
              0.3275157516971413, 0.458099415524913, 0.9420899919807021], 
             UndirectedEdge[233, 264] -> 
             RGBColor[
              0.8413490098710985, 0.8765030596973409, 0.9633266229040078], 
             UndirectedEdge[274, 296] -> 
             RGBColor[
              0.36901952314668135`, 0.4870709060931353, 0.9452488023460986], 
             UndirectedEdge[97, 211] -> 
             RGBColor[
              0.20738956458852648`, 0.33530996001336677`, 0.9351219009467256],
              UndirectedEdge[1, 129] -> 
             RGBColor[
              0.19131755276026974`, 0.31841725655746295`, 0.9342066236495172],
              UndirectedEdge[24, 141] -> 
             RGBColor[
              0.8357237455500708, 0.2680521548465373, 0.1815470877583059], 
             UndirectedEdge[347, 384] -> 
             RGBColor[
              0.19370455937175246`, 0.32092615185109175`, 0.9343425601447813],
              UndirectedEdge[36, 378] -> 
             RGBColor[
              0.1918482442519195, 0.31897504696297085`, 0.934236845744879], 
             UndirectedEdge[174, 395] -> 
             RGBColor[
              0.4063176896518592, 0.5259376945387678, 0.9472261235324917], 
             UndirectedEdge[104, 357] -> 
             RGBColor[
              0.8317062451348429, 0.24471367063742083`, 0.17799524218919488`],
              UndirectedEdge[47, 173] -> 
             RGBColor[
              0.41329174036295263`, 0.5275007351562074, 0.948325579764125], 
             UndirectedEdge[127, 231] -> 
             RGBColor[
              0.1884985570631651, 0.31545431334515556`, 0.9340460860148976], 
             UndirectedEdge[252, 367] -> 
             RGBColor[
              0.372324185998124, 0.4969102291790325, 0.9449451457918181], 
             UndirectedEdge[158, 310] -> 
             RGBColor[
              0.30917761379090525`, 0.4395210111497373, 0.9410201730137817], 
             UndirectedEdge[149, 397] -> 
             RGBColor[
              0.21476341163145843`, 0.34306034078439396`, 0.9355418306271915],
              UndirectedEdge[204, 345] -> 
             RGBColor[
              0.18631088399028722`, 0.3131549302390768, 0.9339215012697695], 
             UndirectedEdge[231, 396] -> 
             RGBColor[
              0.19087540782908663`, 0.31795253420118175`, 0.9341814441497811],
              UndirectedEdge[162, 263] -> 
             RGBColor[
              0.33214075614847005`, 0.45873834938016844`, 0.9425079759974546],
              UndirectedEdge[14, 196] -> 
             RGBColor[
              0.18714224683050756`, 0.3140287452955969, 0.9339688461536289], 
             UndirectedEdge[43, 175] -> 
             RGBColor[
              0.2710055822533935, 0.4021744280676252, 0.9387447390412754], 
             UndirectedEdge[113, 397] -> 
             RGBColor[
              0.2602244815922864, 0.3908428077115391, 0.9381307713078346], 
             UndirectedEdge[126, 336] -> 
             RGBColor[
              0.18346975723563688`, 0.31016872588209876`, 0.9337597033041625],
              UndirectedEdge[48, 173] -> 
             RGBColor[
              0.2613339339978391, 0.3920089125331203, 0.938193952981043], 
             UndirectedEdge[28, 168] -> 
             RGBColor[
              0.19559687276408316`, 0.32291509320603007`, 0.9344503245930478],
              UndirectedEdge[253, 359] -> 
             RGBColor[
              0.18914843365842357`, 0.3161373748513282, 0.9340830955255912], 
             UndirectedEdge[41, 187] -> 
             RGBColor[
              0.6533956652271913, 0.7258990741319324, 0.9682873726725081], 
             UndirectedEdge[198, 398] -> 
             RGBColor[
              0.38970123207440616`, 0.5119613530945772, 0.9460523958018803], 
             UndirectedEdge[260, 329] -> 
             RGBColor[
              0.20751257412950358`, 0.3354392508401891, 0.9351289061581081], 
             UndirectedEdge[60, 82] -> 
             RGBColor[
              0.18336573314646784`, 0.31005938996887394`, 0.9337537792861741],
              UndirectedEdge[12, 17] -> 
             RGBColor[0.2700762317403779, 0.40119762175422, 0.93869181390441],
              UndirectedEdge[268, 351] -> 
             RGBColor[
              0.7945761589543001, 0.8401740652758038, 0.979966961918109], 
             UndirectedEdge[122, 274] -> 
             RGBColor[
              0.5455206538470523, 0.6419172680752578, 0.9573645306602898], 
             UndirectedEdge[150, 384] -> 
             RGBColor[
              0.19155187583051508`, 0.31866354496123156`, 0.9342199680017178],
              UndirectedEdge[179, 232] -> 
             RGBColor[
              0.374520452238133, 0.49753308772821003`, 0.9451360369712756], 
             UndirectedEdge[4, 131] -> 
             RGBColor[
              0.22303764420255517`, 0.35175708383326204`, 0.9360130359314853],
              UndirectedEdge[128, 155] -> 
             RGBColor[
              0.2008465417565683, 0.32843282816537045`, 0.9347492854759805], 
             UndirectedEdge[316, 362] -> 
             RGBColor[
              0.2117594365618467, 0.339902972523212, 0.9353707586909601], 
             UndirectedEdge[283, 320] -> 
             RGBColor[
              0.20238649627655553`, 0.330051418004633, 0.9348369836077353], 
             UndirectedEdge[49, 396] -> 
             RGBColor[
              0.1936178582000953, 0.3208350234225083, 0.9343376226413184], 
             UndirectedEdge[371, 389] -> 
             RGBColor[
              0.194598112629328, 0.3218653329793524, 0.9343934466809067], 
             UndirectedEdge[53, 58] -> 
             RGBColor[
              0.20217788494718347`, 0.3298321542707407, 0.9348251035011402], 
             UndirectedEdge[18, 399] -> 
             RGBColor[
              0.7658581753592988, 0.7184623790314186, 0.610918793426945], 
             UndirectedEdge[241, 270] -> 
             RGBColor[
              0.31115624108701556`, 0.43971981464523346`, 0.9412017203817521],
              UndirectedEdge[137, 169] -> 
             RGBColor[
              0.6151260920101136, 0.6919294010372166, 0.9662275076726026], 
             UndirectedEdge[156, 386] -> 
             RGBColor[
              0.8075774492029875, 0.43046143297516193`, 0.4437999936735976], 
             UndirectedEdge[19, 262] -> 
             RGBColor[
              0.23727783738368446`, 0.36672442974702457`, 0.9368239938666727],
              UndirectedEdge[85, 181] -> 
             RGBColor[
              0.2178344766889036, 0.34628822487653976`, 0.9357167232389794], 
             UndirectedEdge[74, 240] -> 
             RGBColor[
              0.8421459660842523, 0.4609352438287227, 0.4475859807041188], 
             UndirectedEdge[72, 88] -> 
             RGBColor[
              0.18714176336881175`, 0.31402823714670136`, 0.9339688186212005],
              UndirectedEdge[63, 98] -> 
             RGBColor[
              0.19109841618892076`, 0.3181869301269141, 0.9341941441459625], 
             UndirectedEdge[43, 56] -> 
             RGBColor[
              0.3210051071529382, 0.44798658822988663`, 0.9418389411311112], 
             UndirectedEdge[174, 272] -> 
             RGBColor[
              0.5424648698288314, 0.6349580764887339, 0.9589765455952728], 
             UndirectedEdge[180, 198] -> 
             RGBColor[
              0.30592577418738304`, 0.43475768207038135`, 0.9408842486890967],
              UndirectedEdge[126, 289] -> 
             RGBColor[
              0.1863769520635358, 0.31322437197301883`, 0.933925263748802], 
             UndirectedEdge[233, 244] -> 
             RGBColor[
              0.9570858882964418, 0.9675153062736708, 0.9575265767079428], 
             UndirectedEdge[51, 189] -> 
             RGBColor[
              0.324110599148695, 0.45125735516848015`, 0.9420155490612911], 
             UndirectedEdge[199, 306] -> 
             RGBColor[
              0.19460108481424115`, 0.32186845693414357`, 0.9343936159424405],
              UndirectedEdge[86, 214] -> 
             RGBColor[
              0.32538385594789154`, 0.4498732658782442, 0.9421877381945456], 
             UndirectedEdge[104, 172] -> 
             RGBColor[
              0.8206071574601663, 0.15940121911862504`, 0.16736674329729798`],
              UndirectedEdge[67, 293] -> 
             RGBColor[
              0.3870584168095417, 0.509672279343909, 0.9458839979501529], 
             UndirectedEdge[296, 380] -> 
             RGBColor[
              0.23254239925943204`, 0.3617471840343169, 0.9365543176709494], 
             UndirectedEdge[290, 297] -> 
             RGBColor[
              0.20256888353236238`, 0.33024311857450594`, 0.9348473702921356],
              UndirectedEdge[206, 328] -> 
             RGBColor[
              0.7999219852902167, 0.6448484807342735, 0.5933000289298582], 
             UndirectedEdge[5, 319] -> 
             RGBColor[
              0.3679006517731242, 0.4906453846924169, 0.9447526657346955], 
             UndirectedEdge[235, 393] -> 
             RGBColor[
              0.18743861764572758`, 0.31434024981338815`, 0.9339857240331143],
              UndirectedEdge[40, 189] -> 
             RGBColor[
              0.3938515783304093, 0.5098241340349448, 0.9469676010279292], 
             UndirectedEdge[15, 256] -> 
             RGBColor[
              0.31856719551894513`, 0.448229479012007, 0.9415973902435224], 
             UndirectedEdge[71, 365] -> 
             RGBColor[
              0.17992874679989868`, 0.30644689940110903`, 0.9335580479983027],
              UndirectedEdge[53, 64] -> 
             RGBColor[
              0.18652020523185484`, 0.31337494013569756`, 0.9339334218048136],
              UndirectedEdge[231, 298] -> 
             RGBColor[
              0.1895953138932402, 0.3166070743119639, 0.934108544693864], 
             UndirectedEdge[81, 382] -> 
             RGBColor[
              0.18072466475425025`, 0.3072834596352455, 0.9336033743483478], 
             UndirectedEdge[9, 294] -> 
             RGBColor[
              0.1904972038981096, 0.3175550178902107, 0.9341599059954147], 
             UndirectedEdge[175, 213] -> 
             RGBColor[
              0.25213492118930436`, 0.3823401668202513, 0.9376700828103168], 
             UndirectedEdge[174, 189] -> 
             RGBColor[
              0.3053198459534695, 0.4349817492014926, 0.9408182188837021], 
             UndirectedEdge[14, 127] -> 
             RGBColor[
              0.18967658911817914`, 0.3166924997265216, 0.9341131731976884], 
             UndirectedEdge[86, 95] -> 
             RGBColor[
              0.48521628550800544`, 0.5918110474144382, 0.9529344611319093], 
             UndirectedEdge[103, 200] -> 
             RGBColor[
              0.18928086975494526`, 0.31627657358570604`, 0.9340906375653665],
              UndirectedEdge[24, 112] -> 
             RGBColor[
              0.859560524438829, 0.3699751807909537, 0.20111045230987185`], 
             UndirectedEdge[109, 360] -> 
             RGBColor[
              0.18328589355082267`, 0.3099754734917281, 0.9337492325393142], 
             UndirectedEdge[90, 121] -> 
             RGBColor[
              0.4596424243656251, 0.5683306378036415, 0.9516722943059467], 
             UndirectedEdge[75, 202] -> 
             RGBColor[
              0.23066301686818202`, 0.3597718339813871, 0.9364472896240648], 
             UndirectedEdge[27, 32] -> 
             RGBColor[
              0.8663695731727464, 0.3973837278620414, 0.20771263676639312`], 
             UndirectedEdge[131, 273] -> 
             RGBColor[
              0.19754073794696791`, 0.32495821876141306`, 0.9345610248395222],
              UndirectedEdge[160, 220] -> 
             RGBColor[
              0.5477229997143326, 0.6437052316648666, 0.9575379073944208], 
             UndirectedEdge[50, 147] -> 
             RGBColor[
              0.18125622821196816`, 0.30784216653237684`, 0.9336336461008872],
              UndirectedEdge[13, 339] -> 
             RGBColor[
              0.2328552355524508, 0.3620759948132462, 0.936572133235037], 
             UndirectedEdge[17, 209] -> 
             RGBColor[
              0.2832594251473382, 0.412641193889955, 0.9395309216934591], 
             UndirectedEdge[174, 325] -> 
             RGBColor[
              0.31656779052141654`, 0.4468040521032807, 0.9414587726870038], 
             UndirectedEdge[21, 78] -> 
             RGBColor[
              0.8676924203602071, 0.39868109399445717`, 0.21499955316997305`],
              UndirectedEdge[274, 373] -> 
             RGBColor[
              0.38246482009015115`, 0.5012027656617852, 0.9460144921164949], 
             UndirectedEdge[97, 305] -> 
             RGBColor[
              0.18756138502713113`, 0.3144692861151448, 0.9339927154538672], 
             UndirectedEdge[11, 162] -> 
             RGBColor[
              0.29214677471105677`, 0.42409757281503596`, 0.9399595948655519],
              UndirectedEdge[103, 207] -> 
             RGBColor[
              0.19105231071262538`, 0.3181384703480716, 0.9341915185072943], 
             UndirectedEdge[210, 249] -> 
             RGBColor[
              0.3073650774594488, 0.4403600145758346, 0.9408164770263279], 
             UndirectedEdge[52, 299] -> 
             RGBColor[
              0.18351379325327066`, 0.3102150105286766, 0.9337622110902213], 
             UndirectedEdge[43, 373] -> 
             RGBColor[
              0.2661054797853324, 0.3970241096892522, 0.9384656854547713], 
             UndirectedEdge[1, 336] -> 
             RGBColor[
              0.18695004027347276`, 0.31382672401755374`, 0.9339579002745498],
              UndirectedEdge[30, 345] -> 
             RGBColor[
              0.1795989351746539, 0.30610024647171197`, 0.9335392657141575], 
             UndirectedEdge[247, 363] -> 
             RGBColor[
              0.20876443324933688`, 0.3367550341475864, 0.9352001976830229], 
             UndirectedEdge[14, 119] -> 
             RGBColor[
              0.18348249259608096`, 0.310182111553394, 0.9337604285640995], 
             UndirectedEdge[74, 104] -> 
             RGBColor[
              0.833692765834374, 0.39596024249218986`, 0.4394911865983113], 
             UndirectedEdge[258, 277] -> 
             RGBColor[
              0.19561158896014919`, 0.3229305608611562, 0.9344511626586431], 
             UndirectedEdge[152, 236] -> 
             RGBColor[
              0.2537723278978401, 0.38406118508850384`, 0.9377633307000419], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.26676233186552467`, 0.3975147794964234, 0.938510405060175], 
             UndirectedEdge[120, 132] -> 
             RGBColor[
              0.4382862950940797, 0.5522789014915227, 0.9496356996104882], 
             UndirectedEdge[212, 270] -> 
             RGBColor[
              0.38821783346100136`, 0.5106765077734281, 0.9459578749539519], 
             UndirectedEdge[69, 270] -> 
             RGBColor[
              0.300457761234542, 0.4284750339974831, 0.9405924577811364], 
             UndirectedEdge[16, 270] -> 
             RGBColor[
              0.3384373755940835, 0.46755917720766627`, 0.9427859081978025], 
             UndirectedEdge[24, 73] -> 
             RGBColor[
              0.8573963396759665, 0.36139490937802465`, 0.1993690984497273], 
             UndirectedEdge[56, 178] -> 
             RGBColor[
              0.4116703274319593, 0.5309898792944511, 0.9474522471315552], 
             UndirectedEdge[6, 319] -> 
             RGBColor[
              0.37947514539695637`, 0.5028109113563464, 0.945411816023644], 
             UndirectedEdge[231, 235] -> 
             RGBColor[
              0.18685346885052345`, 0.3137252213290522, 0.9339524006748775], 
             UndirectedEdge[18, 86] -> 
             RGBColor[
              0.5080814719938581, 0.6103740358685661, 0.9547344923700136], 
             UndirectedEdge[30, 63] -> 
             RGBColor[
              0.18069605079375822`, 0.30725338454853857`, 0.9336017448256284],
              UndirectedEdge[46, 358] -> 
             RGBColor[
              0.19603463800818394`, 0.3233752122334996, 0.9344752546760837], 
             UndirectedEdge[241, 389] -> 
             RGBColor[
              0.23293094482355622`, 0.362155570057423, 0.9365764447660246], 
             UndirectedEdge[286, 332] -> 
             RGBColor[
              0.2115950206250406, 0.3397301609490563, 0.9353613954465905], 
             UndirectedEdge[40, 174] -> 
             RGBColor[
              0.4325281900725898, 0.5472165595499049, 0.9492895101378381], 
             UndirectedEdge[157, 365] -> 
             RGBColor[
              0.18416233691758455`, 0.3108966710399138, 0.9337991446924696], 
             UndirectedEdge[235, 336] -> 
             RGBColor[
              0.18593363733157064`, 0.312758420081946, 0.9339000176306419], 
             UndirectedEdge[76, 222] -> 
             RGBColor[
              0.21314128516619657`, 0.3413553830206456, 0.9354494529247159], 
             UndirectedEdge[115, 392] -> 
             RGBColor[
              0.9067666664186966, 0.6489260404610371, 0.40496736674089506`], 
             UndirectedEdge[76, 77] -> 
             RGBColor[
              0.1883529029244576, 0.3153012216103682, 0.9340377912271741], 
             UndirectedEdge[160, 366] -> 
             RGBColor[
              0.4270114418839008, 0.5441063729670104, 0.948477074824805], 
             UndirectedEdge[3, 348] -> 
             RGBColor[
              0.45750426505624076`, 0.5671984745069012, 0.9513371690188597], 
             UndirectedEdge[299, 306] -> 
             RGBColor[
              0.19518727715711093`, 0.32248458225324084`, 0.9344269987291731],
              UndirectedEdge[56, 121] -> 
             RGBColor[
              0.3462782939569843, 0.4743505865975952, 0.9432855245824346], 
             UndirectedEdge[280, 322] -> 
             RGBColor[
              0.22572058379982396`, 0.354577023458187, 0.9361658253724963], 
             UndirectedEdge[81, 271] -> 
             RGBColor[
              0.1793288256722832, 0.3058163442587888, 0.9335238833775887], 
             UndirectedEdge[2, 191] -> 
             RGBColor[
              0.19610476461646903`, 0.323448919745091, 0.9344792482826825], 
             UndirectedEdge[146, 377] -> 
             RGBColor[
              0.18543930213235216`, 0.3122388424449055, 0.9338718659723498], 
             UndirectedEdge[10, 396] -> 
             RGBColor[
              0.21852942039278686`, 0.3470186547712968, 0.9357562992548385], 
             UndirectedEdge[382, 384] -> 
             RGBColor[
              0.18572468011707222`, 0.3125387928008556, 0.9338881178264007], 
             UndirectedEdge[147, 391] -> 
             RGBColor[
              0.18230154859335337`, 0.30894086453035285`, 0.9336931755501943],
              UndirectedEdge[133, 216] -> 
             RGBColor[
              0.19274891912622777`, 0.3199217133619542, 0.9342881378465417], 
             UndirectedEdge[86, 264] -> 
             RGBColor[
              0.5671571608223211, 0.6570945561668415, 0.9602327949234224], 
             UndirectedEdge[6, 56] -> 
             RGBColor[
              0.34361946259808085`, 0.47175570963568103`, 0.9431267952187714],
              UndirectedEdge[43, 308] -> 
             RGBColor[
              0.23093015114267265`, 0.3600526090411681, 0.9364625025258073], 
             UndirectedEdge[201, 364] -> 
             RGBColor[
              0.8614660017723598, 0.4117589473533967, 0.4334205555787529], 
             UndirectedEdge[109, 365] -> 
             RGBColor[
              0.1811265179483144, 0.30770583282117103`, 0.9336262592932614], 
             UndirectedEdge[229, 349] -> 
             RGBColor[
              0.20443433824615148`, 0.33220382975535845`, 0.934953605178393], 
             UndirectedEdge[216, 231] -> 
             RGBColor[
              0.19095180161373265`, 0.3180328289124904, 0.9341857946628023], 
             UndirectedEdge[114, 353] -> 
             RGBColor[
              0.2156557406567855, 0.3439982351669406, 0.9355926474451014], 
             UndirectedEdge[70, 236] -> 
             RGBColor[
              0.23684558512377027`, 0.36627010521547854`, 0.9367993777399305],
              UndirectedEdge[64, 94] -> 
             RGBColor[
              0.1809149928406964, 0.30748350652159806`, 0.9336142132513059], 
             UndirectedEdge[240, 285] -> 
             RGBColor[
              0.8858589617650177, 0.49305390399602456`, 0.3219788728271452], 
             UndirectedEdge[56, 90] -> 
             RGBColor[
              0.4950145385889495, 0.5989681852897308, 0.9539261741459244], 
             UndirectedEdge[90, 295] -> 
             RGBColor[
              0.5187067634857201, 0.6194891996894659, 0.9554358217661347], 
             UndirectedEdge[165, 281] -> 
             RGBColor[
              0.6627187385434833, 0.7331187175098175, 0.9692752800168635], 
             UndirectedEdge[54, 345] -> 
             RGBColor[
              0.1817997844893844, 0.30841347864339985`, 0.9336646008267666], 
             UndirectedEdge[101, 136] -> 
             RGBColor[
              0.18384486237801373`, 0.31056298516977654`, 0.9337810649871026],
              UndirectedEdge[6, 314] -> 
             RGBColor[
              0.26913140342587094`, 0.400204547290098, 0.9386380073296472], 
             UndirectedEdge[125, 276] -> 
             RGBColor[
              0.2421845103154749, 0.3718816540993685, 0.9371034216313661], 
             UndirectedEdge[244, 341] -> 
             RGBColor[
              0.6455002366075493, 0.7157181703634723, 0.9520500486891706], 
             UndirectedEdge[46, 153] -> 
             RGBColor[
              0.1918690303202028, 0.3189968944386494, 0.9342380294807175], 
             UndirectedEdge[14, 336] -> 
             RGBColor[
              0.18245115534282794`, 0.3090981107096664, 0.9337016954332534], 
             UndirectedEdge[109, 370] -> 
             RGBColor[
              0.1842051301196885, 0.31094164940857083`, 0.9338015817020224], 
             UndirectedEdge[51, 234] -> 
             RGBColor[
              0.5836503518814267, 0.668728614845342, 0.9624059730547245], 
             UndirectedEdge[144, 228] -> 
             RGBColor[
              0.19707272190642572`, 0.32446630422887235`, 0.934534372018381], 
             UndirectedEdge[320, 347] -> 
             RGBColor[
              0.1968219545840863, 0.324202731873527, 0.9345200911903508], 
             UndirectedEdge[31, 106] -> 
             RGBColor[
              0.21164758701888683`, 0.33978541156189057`, 0.935364389024955], 
             UndirectedEdge[77, 103] -> 
             RGBColor[
              0.18857832587467818`, 0.31553815542369057`, 0.9340506287307058],
              UndirectedEdge[266, 316] -> 
             RGBColor[
              0.23355306875092818`, 0.36280946175002615`, 0.9366118738033387],
              UndirectedEdge[109, 334] -> 
             RGBColor[
              0.18315174728548578`, 0.30983447726149455`, 0.9337415931079549],
              UndirectedEdge[45, 179] -> 
             RGBColor[
              0.3693787364367489, 0.49212881841734446`, 0.9448432238628737], 
             UndirectedEdge[181, 191] -> 
             RGBColor[
              0.2010737277844803, 0.3286716150851321, 0.9347622233841785], 
             UndirectedEdge[125, 148] -> 
             RGBColor[
              0.2977450564931756, 0.4279464199660071, 0.9403529311058223], 
             UndirectedEdge[18, 112] -> 
             RGBColor[
              0.7711240798821252, 0.7393399357057666, 0.6151558638126768], 
             UndirectedEdge[221, 239] -> 
             RGBColor[
              0.8526114029177259, 0.35936467056963683`, 0.1962114217734859], 
             UndirectedEdge[57, 76] -> 
             RGBColor[
              0.20578868678679324`, 0.33362733594223004`, 0.9350307333242034],
              UndirectedEdge[222, 333] -> 
             RGBColor[
              0.21024933242430197`, 0.33831575732852015`, 0.9352847604943257],
              UndirectedEdge[125, 214] -> 
             RGBColor[
              0.25062847588100123`, 0.38075679728707557`, 0.9375842929785951],
              UndirectedEdge[220, 244] -> 
             RGBColor[
              0.7952939705328516, 0.8405065482820335, 0.9629639718031929], 
             UndirectedEdge[143, 379] -> 
             RGBColor[
              0.19607245739300067`, 0.3234149628048294, 0.9344774084341002], 
             UndirectedEdge[31, 241] -> 
             RGBColor[
              0.22984485211178313`, 0.3589118909477702, 0.9364006963515542], 
             UndirectedEdge[81, 374] -> 
             RGBColor[
              0.1848884604275577, 0.3116598728877852, 0.9338404963521592], 
             UndirectedEdge[168, 304] -> 
             RGBColor[
              0.18254777981600245`, 0.3091996691573183, 0.9337071980540577], 
             UndirectedEdge[156, 328] -> 
             RGBColor[
              0.8438341634867396, 0.32626817313654033`, 0.18915213949243842`],
              UndirectedEdge[46, 363] -> 
             RGBColor[
              0.21059715829347625`, 0.33868134437045616`, 0.9353045686630128],
              UndirectedEdge[51, 269] -> 
             RGBColor[
              0.5625797337470475, 0.652268087816136, 0.9603058507552114], 
             UndirectedEdge[13, 325] -> 
             RGBColor[
              0.25165090865355244`, 0.3818314389570088, 0.9376425190124382], 
             UndirectedEdge[164, 374] -> 
             RGBColor[
              0.1955858495365969, 0.322903507095029, 0.9344496968365499], 
             UndirectedEdge[49, 199] -> 
             RGBColor[
              0.18708382947160418`, 0.313967344947515, 0.93396551937146], 
             UndirectedEdge[49, 313] -> 
             RGBColor[
              0.20302253470198556`, 0.3307199347169253, 0.9348732050551289], 
             UndirectedEdge[176, 388] -> 
             RGBColor[
              0.22659156217478169`, 0.35549247695348607`, 0.9362154263024531],
              UndirectedEdge[45, 232] -> 
             RGBColor[
              0.28995111396047296`, 0.4220873831078549, 0.9398236590445912], 
             UndirectedEdge[176, 250] -> 
             RGBColor[
              0.24600820440775967`, 0.3759005990265677, 0.9373211753532731], 
             UndirectedEdge[346, 390] -> 
             RGBColor[
              0.30688867117659013`, 0.43597701754892004`, 0.9409314950894052],
              UndirectedEdge[331, 335] -> 
             RGBColor[
              0.18932527309814626`, 0.31632324431474484`, 0.9340931662700729],
              UndirectedEdge[135, 355] -> 
             RGBColor[
              0.8802746969932166, 0.9041359691009224, 0.8286360157619015], 
             UndirectedEdge[326, 327] -> 
             RGBColor[
              0.19380937140054372`, 0.3210363159388178, 0.9343485290347655], 
             UndirectedEdge[80, 304] -> 
             RGBColor[
              0.18034926344630414`, 0.30688888905877654`, 0.9335819957992169],
              UndirectedEdge[65, 173] -> 
             RGBColor[
              0.2852130264023293, 0.4171073526721437, 0.9395538319675272], 
             UndirectedEdge[203, 257] -> 
             RGBColor[
              0.27443071882287484`, 0.40444693199068393`, 0.9389884029433275],
              UndirectedEdge[275, 325] -> 
             RGBColor[
              0.2639447266446291, 0.3947530211387112, 0.9383426337599561], 
             UndirectedEdge[240, 337] -> 
             RGBColor[
              0.8858082221333453, 0.4929453770544411, 0.3164561770483195], 
             UndirectedEdge[77, 254] -> 
             RGBColor[
              0.18502833391359902`, 0.3118068887901059, 0.9338484619402648], 
             UndirectedEdge[32, 364] -> 
             RGBColor[
              0.8641288289294724, 0.38016038570784827`, 0.2055668975484752], 
             UndirectedEdge[38, 53] -> 
             RGBColor[
              0.2076634431002256, 0.3355978236940631, 0.9351374979228], 
             UndirectedEdge[28, 291] -> 
             RGBColor[
              0.1970819328198578, 0.3244759854828951, 0.9345348965662746], 
             UndirectedEdge[174, 269] -> 
             RGBColor[
              0.543788980551822, 0.6359924818491485, 0.9591085205776222], 
             UndirectedEdge[216, 361] -> 
             RGBColor[
              0.20867332138388106`, 0.3366592698001664, 0.9351950089970731], 
             UndirectedEdge[356, 363] -> 
             RGBColor[
              0.2074463229173425, 0.3353696166156383, 0.9351251332495853], 
             UndirectedEdge[151, 383] -> 
             RGBColor[
              0.20018660218381945`, 0.3277391898318258, 0.9347117028936056], 
             UndirectedEdge[61, 130] -> 
             RGBColor[
              0.19568837198846437`, 0.3230112646922406, 0.9344555353385153], 
             UndirectedEdge[331, 338] -> 
             RGBColor[
              0.2166739251358942, 0.34506841161110846`, 0.9356506315449178], 
             UndirectedEdge[239, 246] -> 
             RGBColor[
              0.8585903956264433, 0.4560165722989594, 0.4468977431895056], 
             UndirectedEdge[190, 212] -> 
             RGBColor[
              0.6867778683351773, 0.7513832913392242, 0.9534033725466657], 
             UndirectedEdge[111, 286] -> 
             RGBColor[
              0.1920478961746871, 0.3191848937924626, 0.934248215626522], 
             UndirectedEdge[228, 273] -> 
             RGBColor[
              0.1927101706170558, 0.31988098622201705`, 0.9342859311762677], 
             UndirectedEdge[199, 299] -> 
             RGBColor[
              0.18707599573729403`, 0.31395911119606756`, 0.93396507325188], 
             UndirectedEdge[50, 391] -> 
             RGBColor[
              0.18008156514952903`, 0.3066075211758136, 0.9335667507772396], 
             UndirectedEdge[358, 362] -> 
             RGBColor[
              0.18997045450082056`, 0.31700137087581914`, 0.9341299083964949],
              UndirectedEdge[42, 98] -> 
             RGBColor[
              0.20876468464708048`, 0.33675529838255447`, 0.9352002119997525],
              UndirectedEdge[39, 251] -> 
             RGBColor[
              0.18672478342346222`, 0.3135899647860835, 0.9339450722301794], 
             UndirectedEdge[148, 179] -> 
             RGBColor[
              0.39396314610535543`, 0.515635700812435, 0.9463286881882242], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.19127206346984504`, 0.31836944442903903`, 0.934204033101723], 
             UndirectedEdge[77, 333] -> 
             RGBColor[
              0.18546095018256298`, 0.31226159591824276`, 0.9338730987967839],
              UndirectedEdge[173, 354] -> 
             RGBColor[
              0.24916626557073213`, 0.3792199215414943, 0.9375010222645717], 
             UndirectedEdge[160, 217] -> 
             RGBColor[
              0.7263465347719837, 0.7798834744139984, 0.7188240157462833], 
             UndirectedEdge[59, 90] -> 
             RGBColor[
              0.47744540309430256`, 0.5837506831746934, 0.9528066843679821], 
             UndirectedEdge[237, 380] -> 
             RGBColor[
              0.20872851353399335`, 0.33671728024931885`, 0.9351981521083725],
              UndirectedEdge[285, 399] -> 
             RGBColor[
              0.9603875503566552, 0.868303119703074, 0.4348794443842956], 
             UndirectedEdge[51, 392] -> 
             RGBColor[
              0.6863309387769014, 0.7477531849917098, 0.8714804732443268], 
             UndirectedEdge[264, 307] -> 
             RGBColor[
              0.5358230864206805, 0.6299545558165122, 0.958236215410184], 
             UndirectedEdge[78, 208] -> 
             RGBColor[
              0.8776301441970267, 0.43329624520536353`, 0.36628986629008864`],
              UndirectedEdge[28, 383] -> 
             RGBColor[
              0.20767130167756592`, 0.3356060835571104, 0.9351379454571538], 
             UndirectedEdge[255, 268] -> 
             RGBColor[
              0.78336189520592, 0.43168674764690385`, 0.44388901313282986`], 
             UndirectedEdge[46, 247] -> 
             RGBColor[
              0.1994607168120997, 0.32697623828235756`, 0.9346703647955372], 
             UndirectedEdge[272, 392] -> 
             RGBColor[
              0.8660085977148573, 0.8940614807970035, 0.8861195606683994], 
             UndirectedEdge[316, 359] -> 
             RGBColor[
              0.21077886401933704`, 0.3388723286091443, 0.9353149165352912], 
             UndirectedEdge[223, 242] -> 
             RGBColor[
              0.8781496673360434, 0.5217988288073361, 0.2192788746878494], 
             UndirectedEdge[158, 390] -> 
             RGBColor[
              0.3007335296132649, 0.43064574329317795`, 0.9405392949117681], 
             UndirectedEdge[26, 128] -> 
             RGBColor[
              0.19080558249119994`, 0.3178791433438807, 0.9341774677000858], 
             UndirectedEdge[136, 335] -> 
             RGBColor[
              0.18204623503960604`, 0.3086725137975501, 0.9336786358210108], 
             UndirectedEdge[193, 248] -> 
             RGBColor[
              0.20247189401375032`, 0.330141176440954, 0.9348418468825339], 
             UndirectedEdge[281, 386] -> 
             RGBColor[
              0.5947242732295994, 0.6793804571151425, 0.9626628801063983], 
             UndirectedEdge[225, 337] -> 
             RGBColor[
              0.9393785469822551, 0.9502915240338172, 0.7911384355526612], 
             UndirectedEdge[30, 297] -> 
             RGBColor[
              0.19356559882175525`, 0.3207800955024369, 0.9343346465470327], 
             UndirectedEdge[32, 104] -> 
             RGBColor[
              0.8650168308266121, 0.38698595741417663`, 0.2064172491680309], 
             UndirectedEdge[264, 366] -> 
             RGBColor[
              0.5588455342770764, 0.6498954430078475, 0.9597031854296422], 
             UndirectedEdge[2, 97] -> 
             RGBColor[
              0.18893766617089083`, 0.31591584485850077`, 0.9340710926289788],
              UndirectedEdge[258, 377] -> 
             RGBColor[
              0.18407204095648846`, 0.3108017642597073, 0.933794002471066], 
             UndirectedEdge[134, 135] -> 
             RGBColor[
              0.9129052217970873, 0.9297159641585085, 0.8318647617559947], 
             UndirectedEdge[185, 338] -> 
             RGBColor[
              0.3169003211264983, 0.4420126040845884, 0.9416659454971446], 
             UndirectedEdge[40, 84] -> 
             RGBColor[
              0.42994887224450423`, 0.5449824840875006, 0.9491251582866337], 
             UndirectedEdge[217, 242] -> 
             RGBColor[
              0.8992054802509515, 0.5977296497457392, 0.29414214565418556`], 
             UndirectedEdge[124, 266] -> 
             RGBColor[
              0.27124098687969256`, 0.402330909521441, 0.9387614748820916], 
             UndirectedEdge[219, 293] -> 
             RGBColor[
              0.34300984476630975`, 0.47151962018566573`, 0.943077261890181], 
             UndirectedEdge[37, 170] -> 
             RGBColor[
              0.29023151793817503`, 0.41867896684859873`, 0.9399752176813956],
              UndirectedEdge[205, 293] -> 
             RGBColor[
              0.3494560104043527, 0.47710296486763304`, 0.9434880058645166], 
             UndirectedEdge[122, 268] -> 
             RGBColor[
              0.638662857560744, 0.7169674525945936, 0.9650845862531987], 
             UndirectedEdge[246, 392] -> 
             RGBColor[
              0.955664633870156, 0.964911832854005, 0.8948405878073766], 
             UndirectedEdge[282, 398] -> 
             RGBColor[
              0.3466184248527956, 0.47079867288483046`, 0.9434480372889362], 
             UndirectedEdge[34, 248] -> 
             RGBColor[
              0.24062348998029212`, 0.37024092275268566`, 0.9370145238326], 
             UndirectedEdge[263, 264] -> 
             RGBColor[
              0.5576221544304325, 0.6488358128735436, 0.9596252327476064], 
             UndirectedEdge[100, 377] -> 
             RGBColor[
              0.19744186238260558`, 0.3248542942741953, 0.9345553940224051], 
             UndirectedEdge[107, 241] -> 
             RGBColor[
              0.30591595912176667`, 0.43518094579116473`, 0.9408678142487259],
              UndirectedEdge[11, 95] -> 
             RGBColor[
              0.43568729767870357`, 0.5489115275560077, 0.9497785178241904], 
             UndirectedEdge[7, 96] -> 
             RGBColor[
              0.5984222253415448, 0.6831169372542267, 0.9626727079088397], 
             UndirectedEdge[111, 383] -> 
             RGBColor[
              0.1988021595169091, 0.3262840528101681, 0.9346328609318244], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.2782593236768137, 0.4070163756656283, 0.939259698655848], 
             UndirectedEdge[121, 122] -> 
             RGBColor[
              0.4544345003462795, 0.5641026104704333, 0.9512623074498896], 
             UndirectedEdge[156, 221] -> 
             RGBColor[
              0.8547600367756315, 0.37588001193886017`, 0.19826895598235128`],
              UndirectedEdge[61, 176] -> 
             RGBColor[
              0.2215167477526256, 0.3501585252339816, 0.9359264231286265], 
             UndirectedEdge[128, 261] -> 
             RGBColor[
              0.22729090761283746`, 0.3562275333499445, 0.9362552529905616], 
             UndirectedEdge[69, 381] -> 
             RGBColor[
              0.21898984745913425`, 0.34750259281079, 0.9357825198951262], 
             UndirectedEdge[166, 178] -> 
             RGBColor[
              0.7156925694809679, 0.7734991059400932, 0.884905461880064], 
             UndirectedEdge[114, 202] -> 
             RGBColor[
              0.2423249813764799, 0.37202929809086444`, 0.937111421250482], 
             UndirectedEdge[40, 134] -> 
             RGBColor[
              0.6760140538149009, 0.745057217744171, 0.9695892868351288], 
             UndirectedEdge[84, 234] -> 
             RGBColor[
              0.5622802808581155, 0.6502189334159502, 0.961044291025931], 
             UndirectedEdge[236, 367] -> 
             RGBColor[
              0.3129287562528536, 0.440105110895209, 0.9413567694167602], 
             UndirectedEdge[307, 366] -> 
             RGBColor[
              0.37137695467694465`, 0.4960897850178574, 0.9448847890496364], 
             UndirectedEdge[129, 396] -> 
             RGBColor[
              0.19432308879693078`, 0.32157626549398477`, 0.934377784480513], 
             UndirectedEdge[67, 208] -> 
             RGBColor[
              0.7091189037719949, 0.7670538844748609, 0.8568671364687419], 
             UndirectedEdge[203, 309] -> 
             RGBColor[
              0.2616767930351678, 0.3923692791198713, 0.9382134782960043], 
             UndirectedEdge[142, 302] -> 
             RGBColor[
              0.18693197467623224`, 0.31380773592942895`, 0.9339568714655127],
              UndirectedEdge[93, 248] -> 
             RGBColor[
              0.22615954726936105`, 0.355038401896562, 0.9361908236926982], 
             UndirectedEdge[110, 227] -> 
             RGBColor[
              0.1954518354139104, 0.3227626497550994, 0.934442064930519], 
             UndirectedEdge[129, 361] -> 
             RGBColor[
              0.20336215554475928`, 0.33107689775588556`, 0.9348925459597008],
              UndirectedEdge[236, 332] -> 
             RGBColor[
              0.2395600162179548, 0.36912314440033817`, 0.9369539605751034], 
             UndirectedEdge[306, 353] -> 
             RGBColor[
              0.19636662006403216`, 0.3237241464230741, 0.9344941605630408], 
             UndirectedEdge[257, 280] -> 
             RGBColor[
              0.2873202290991691, 0.41799462453322234`, 0.9397224414852408], 
             UndirectedEdge[208, 385] -> 
             RGBColor[
              0.9937202968318795, 0.9909321476846529, 0.7000134809555262], 
             UndirectedEdge[79, 302] -> 
             RGBColor[
              0.21120952198211004`, 0.3393249774333106, 0.9353394418691697], 
             UndirectedEdge[21, 242] -> 
             RGBColor[
              0.8892496521392507, 0.5643794238873858, 0.23564278266699612`], 
             UndirectedEdge[94, 103] -> 
             RGBColor[
              0.18776701535974932`, 0.31468541663244265`, 0.934004425797107], 
             UndirectedEdge[237, 308] -> 
             RGBColor[
              0.19941664213352878`, 0.3269299130006835, 0.9346678548077954], 
             UndirectedEdge[1, 235] -> 
             RGBColor[
              0.19253038583618232`, 0.3196920210183055, 0.9342756926989647], 
             UndirectedEdge[31, 374] -> 
             RGBColor[
              0.1933477765192394, 0.32055115045176114`, 0.9343222418891437], 
             UndirectedEdge[324, 351] -> 
             RGBColor[
              0.7714595274314936, 0.8219737948771062, 0.9777595758801894], 
             UndirectedEdge[62, 396] -> 
             RGBColor[
              0.20033182917246628`, 0.3278918326048165, 0.934719973355765], 
             UndirectedEdge[13, 123] -> 
             RGBColor[
              0.2129302625842361, 0.3411335849074007, 0.9354374355008532], 
             UndirectedEdge[112, 337] -> 
             RGBColor[
              0.9655773454319732, 0.8890178859650467, 0.43083247110178885`], 
             UndirectedEdge[262, 286] -> 
             RGBColor[
              0.20449842182687056`, 0.3322711856618279, 0.9349572546435119], 
             UndirectedEdge[56, 59] -> 
             RGBColor[
              0.3640812726856617, 0.4897706319686471, 0.9444199146444701], 
             UndirectedEdge[61, 118] -> 
             RGBColor[
              0.22412293343441853`, 0.3528977916272621, 0.9360748415476985], 
             UndirectedEdge[14, 235] -> 
             RGBColor[
              0.1880315009055375, 0.3149634077104182, 0.9340194878576683], 
             UndirectedEdge[154, 286] -> 
             RGBColor[
              0.2001789472954632, 0.3277311440588154, 0.9347112669590381], 
             UndirectedEdge[159, 215] -> 
             RGBColor[
              0.1817543271405076, 0.3083657000875679, 0.9336620120979963], 
             UndirectedEdge[25, 385] -> 
             RGBColor[
              0.8763544393929654, 0.4195795480694926, 0.3210148235334077], 
             UndirectedEdge[165, 256] -> 
             RGBColor[
              0.624029163944416, 0.6996077525866663, 0.9668100145352584], 
             UndirectedEdge[292, 384] -> 
             RGBColor[
              0.19197167888601352`, 0.3191047845896115, 0.9342438751646855], 
             UndirectedEdge[1, 49] -> 
             RGBColor[
              0.19061232216343427`, 0.3176760144859865, 0.9341664618103227], 
             UndirectedEdge[93, 125] -> 
             RGBColor[
              0.24791606512635506`, 0.37790588160716765`, 0.9374298251987702],
              UndirectedEdge[15, 37] -> 
             RGBColor[
              0.31731211488685307`, 0.44714239125067556`, 0.9415174176154697],
              UndirectedEdge[141, 399] -> 
             RGBColor[
              0.8859237106076299, 0.5705962751965173, 0.2263022782483616], 
             UndirectedEdge[42, 288] -> 
             RGBColor[
              0.26094257460696524`, 0.39159756899969334`, 0.938171665642697], 
             UndirectedEdge[26, 218] -> 
             RGBColor[
              0.188929981383257, 0.31590776765945394`, 0.9340706549916917], 
             UndirectedEdge[292, 389] -> 
             RGBColor[
              0.1985170723266464, 0.32598440809763013`, 0.9346166256380877], 
             UndirectedEdge[87, 361] -> 
             RGBColor[
              0.20790747959893147`, 0.33585432152701067`, 0.9351513954403816],
              UndirectedEdge[3, 11] -> 
             RGBColor[
              0.4469167817161049, 0.5580281285800609, 0.9506625439425702], 
             UndirectedEdge[217, 364] -> 
             RGBColor[
              0.8761412762683021, 0.4204480711364659, 0.27205583787310783`], 
             UndirectedEdge[83, 120] -> 
             RGBColor[
              0.7316668327109251, 0.7891725193318362, 0.9665740024152043], 
             UndirectedEdge[251, 380] -> 
             RGBColor[
              0.20519908617390886`, 0.3330076283152506, 0.9349971564415356], 
             UndirectedEdge[209, 390] -> 
             RGBColor[
              0.2987767120225358, 0.42895084624860025`, 0.9404146082252327], 
             UndirectedEdge[149, 315] -> 
             RGBColor[
              0.21772472600366666`, 0.3461728699477604, 0.9357104730998167], 
             UndirectedEdge[34, 263] -> 
             RGBColor[
              0.3276003815122878, 0.45396612776116196`, 0.9422494083788064], 
             UndirectedEdge[327, 376] -> 
             RGBColor[
              0.2026044968471712, 0.33028055042638454`, 0.9348493984177288], 
             UndirectedEdge[113, 316] -> 
             RGBColor[
              0.2709397029977173, 0.40210518479292345`, 0.9387409873151243], 
             UndirectedEdge[85, 307] -> 
             RGBColor[
              0.294549891018896, 0.4232589122924366, 0.9402196391759287], 
             UndirectedEdge[140, 257] -> 
             RGBColor[
              0.2744017745717613, 0.404416509747592, 0.9389867546110457], 
             UndirectedEdge[228, 330] -> 
             RGBColor[
              0.1947627843493959, 0.3220384133979338, 0.9344028244917546], 
             UndirectedEdge[22, 96] -> 
             RGBColor[
              0.5322372446835262, 0.6257908335621027, 0.9584554594663912], 
             UndirectedEdge[22, 323] -> 
             RGBColor[
              0.35748321527472365`, 0.48405572626730053`, 0.943999492260678], 
             UndirectedEdge[167, 269] -> 
             RGBColor[
              0.5269179419290838, 0.6213796361571894, 0.958033512915055], 
             UndirectedEdge[85, 214] -> 
             RGBColor[
              0.2402451657445982, 0.3698432799938294, 0.9369929788270578], 
             UndirectedEdge[89, 155] -> 
             RGBColor[
              0.19816316122321598`, 0.3256124250886648, 0.9345964709243118], 
             UndirectedEdge[1, 396] -> 
             RGBColor[
              0.1965523248147455, 0.3239193338904351, 0.9345047361738683], 
             UndirectedEdge[172, 208] -> 
             RGBColor[
              0.8802072426240743, 0.4531049530073836, 0.36875769865424585`], 
             UndirectedEdge[45, 339] -> 
             RGBColor[
              0.26817858765203434`, 0.39920307749978645`, 0.9385837458808918],
              UndirectedEdge[250, 363] -> 
             RGBColor[
              0.2391241828797345, 0.3686650559284389, 0.9369291405112493], 
             UndirectedEdge[167, 222] -> 
             RGBColor[
              0.2713202012615644, 0.4023656525144891, 0.9387677624449977], 
             UndirectedEdge[73, 208] -> 
             RGBColor[
              0.9618152962983195, 0.8769997675618114, 0.5142240753361885], 
             UndirectedEdge[14, 317] -> 
             RGBColor[
              0.18995153056345765`, 0.3169814806178038, 0.9341288307062575], 
             UndirectedEdge[157, 334] -> 
             RGBColor[
              0.1861875662547559, 0.3130253154802374, 0.9339144785071631], 
             UndirectedEdge[107, 190] -> 
             RGBColor[
              0.6524189980541504, 0.7216233648288316, 0.9512140557147148], 
             UndirectedEdge[12, 209] -> 
             RGBColor[
              0.3216593094784126, 0.45300190701520204`, 0.9417177382985756], 
             UndirectedEdge[185, 219] -> 
             RGBColor[
              0.36836286362019555`, 0.4934791308371227, 0.9446927338327562], 
             UndirectedEdge[318, 345] -> 
             RGBColor[
              0.18668882027855277`, 0.3135521652405886, 0.9339430241822795], 
             UndirectedEdge[36, 383] -> 
             RGBColor[
              0.20061589185273376`, 0.3281904004923918, 0.9347361503051731], 
             UndirectedEdge[24, 357] -> 
             RGBColor[
              0.832891397044611, 0.253823267552776, 0.17913014499642635`], 
             UndirectedEdge[344, 354] -> 
             RGBColor[
              0.2035510812828702, 0.3312754706852238, 0.9349033050009957], 
             UndirectedEdge[7, 194] -> 
             RGBColor[
              0.7215884971461117, 0.7768639400824314, 0.7979961077324451], 
             UndirectedEdge[97, 248] -> 
             RGBColor[
              0.2054442201466507, 0.3332652796629938, 0.9350111164586401], 
             UndirectedEdge[14, 129] -> 
             RGBColor[
              0.18681866782962492`, 0.3136886432495756, 0.9339504188082208], 
             UndirectedEdge[160, 307] -> 
             RGBColor[
              0.403988994027505, 0.524165485775675, 0.9470101048053469], 
             UndirectedEdge[165, 400] -> 
             RGBColor[
              0.8657021685054997, 0.5646354990336626, 0.4604608392782479], 
             UndirectedEdge[310, 323] -> 
             RGBColor[
              0.33914507736848765`, 0.46547732189212476`, 0.9429296732937578],
              UndirectedEdge[309, 339] -> 
             RGBColor[
              0.27457216058382816`, 0.4059231280270391, 0.9389478504009139], 
             UndirectedEdge[355, 395] -> 
             RGBColor[
              0.6171730285902994, 0.6981983576754478, 0.9642971542356892], 
             UndirectedEdge[32, 240] -> 
             RGBColor[
              0.8734700310764903, 0.45196095875070935`, 0.21451204327383844`],
              UndirectedEdge[66, 322] -> 
             RGBColor[
              0.2070879506142999, 0.33499294460302415`, 0.9351047244770914], 
             UndirectedEdge[28, 267] -> 
             RGBColor[
              0.23148773999796957`, 0.36063867028126045`, 0.9364942563862377],
              UndirectedEdge[51, 102] -> 
             RGBColor[
              0.32952467941339164`, 0.45694789679919157`, 0.9423238729229517],
              UndirectedEdge[244, 321] -> 
             RGBColor[
              0.7545634824664897, 0.8074397031821838, 0.959757518581915], 
             UndirectedEdge[140, 309] -> 
             RGBColor[
              0.2616478487840542, 0.3923388568767794, 0.9382118299637227], 
             UndirectedEdge[12, 324] -> 
             RGBColor[
              0.4708028735942141, 0.577300258720949, 0.9525700303913813], 
             UndirectedEdge[130, 287] -> 
             RGBColor[
              0.1859722872961475, 0.31279904364526556`, 0.9339022186889471], 
             UndirectedEdge[267, 367] -> 
             RGBColor[
              0.315534462322565, 0.44284387318578267`, 0.9415051605226336], 
             UndirectedEdge[138, 229] -> 
             RGBColor[
              0.19456770903936127`, 0.32183337687859837`, 0.9343917152414362],
              UndirectedEdge[97, 193] -> 
             RGBColor[
              0.1899172543843397, 0.31694545418031556`, 0.9341268787285638], 
             UndirectedEdge[248, 340] -> 
             RGBColor[
              0.2104667967928659, 0.33854432616791813`, 0.9352971447684058], 
             UndirectedEdge[162, 248] -> 
             RGBColor[
              0.24516386461647438`, 0.3750131443716921, 0.9372730914512483], 
             UndirectedEdge[127, 317] -> 
             RGBColor[
              0.19507910076484197`, 0.32237088200618674`, 0.9344208382436661],
              UndirectedEdge[269, 355] -> 
             RGBColor[
              0.7546443194902623, 0.8082531449858283, 0.9761795512808198], 
             UndirectedEdge[161, 184] -> 
             RGBColor[
              0.19128276610466352`, 0.31838069357681953`, 0.9342046426009427],
              UndirectedEdge[340, 360] -> 
             RGBColor[
              0.1940919893072422, 0.3213333652777681, 0.9343646237064562], 
             UndirectedEdge[19, 185] -> 
             RGBColor[
              0.330002266441723, 0.4557835793222022, 0.9424120819002554], 
             UndirectedEdge[240, 357] -> 
             RGBColor[
              0.8401594453847212, 0.3096886719739536, 0.1860900362950024], 
             UndirectedEdge[75, 132] -> 
             RGBColor[
              0.28812004710636396`, 0.4155836677571048, 0.9398870475355221], 
             UndirectedEdge[89, 353] -> 
             RGBColor[
              0.18963294311823536`, 0.31664662501326446`, 0.93411068762256], 
             UndirectedEdge[214, 312] -> 
             RGBColor[
              0.2713270321361526, 0.4025122922755047, 0.9387630451365561], 
             UndirectedEdge[119, 129] -> 
             RGBColor[
              0.18575214150891103`, 0.312567656464831, 0.9338896817120405], 
             UndirectedEdge[143, 377] -> 
             RGBColor[
              0.1848896476706373, 0.3116611207555374, 0.933840563963896], 
             UndirectedEdge[5, 122] -> 
             RGBColor[
              0.440201175363544, 0.5493422068445898, 0.9504444277972779], 
             UndirectedEdge[42, 318] -> 
             RGBColor[
              0.2054522043558168, 0.33327367157305554`, 0.9350115711475404], 
             UndirectedEdge[6, 137] -> 
             RGBColor[
              0.32002599977803325`, 0.451320237982877, 0.941623440630758], 
             UndirectedEdge[113, 149] -> 
             RGBColor[
              0.26206453775242544`, 0.39277682340214404`, 0.9382355597840353],
              UndirectedEdge[67, 124] -> 
             RGBColor[
              0.3674760832994186, 0.49271104629414053`, 0.9446362289748654], 
             UndirectedEdge[141, 337] -> 
             RGBColor[
              0.9084139629772536, 0.6516194381550591, 0.33751282527872106`], 
             UndirectedEdge[63, 224] -> 
             RGBColor[
              0.1802578853175729, 0.30679284485177194`, 0.9335767919499673], 
             UndirectedEdge[244, 357] -> 
             RGBColor[
              0.8896554671023064, 0.6151982079777534, 0.4553600391337833], 
             UndirectedEdge[9, 192] -> 
             RGBColor[
              0.1863278971063823, 0.3131728121027866, 0.9339224701415624], 
             UndirectedEdge[46, 369] -> 
             RGBColor[
              0.19594555683555187`, 0.3232815822729907, 0.934470181635086], 
             UndirectedEdge[350, 392] -> 
             RGBColor[
              0.9924671913475096, 0.9911530042849124, 0.7745016638630496], 
             UndirectedEdge[275, 339] -> 
             RGBColor[
              0.24514905354352745`, 0.3749975769949486, 0.9372722479825549], 
             UndirectedEdge[119, 127] -> 
             RGBColor[
              0.18861006279746526`, 0.31557151294177693`, 0.9340524361015079],
              UndirectedEdge[152, 398] -> 
             RGBColor[
              0.3414317727237982, 0.4653471726445155, 0.943152665123154], 
             UndirectedEdge[105, 229] -> 
             RGBColor[
              0.20817939443044792`, 0.33614012125533055`, 0.9351668805877746],
              UndirectedEdge[181, 365] -> 
             RGBColor[
              0.1879270858801807, 0.3148536608984732, 0.9340135415764423], 
             UndirectedEdge[24, 285] -> 
             RGBColor[
              0.8785909134249075, 0.43718849957484696`, 0.31501898152856916`],
              UndirectedEdge[167, 189] -> 
             RGBColor[
              0.2884488073307313, 0.4203689035095335, 0.9397432112211349], 
             UndirectedEdge[157, 191] -> 
             RGBColor[
              0.1973089788218841, 0.3247146252265727, 0.9345478265002056], 
             UndirectedEdge[78, 194] -> 
             RGBColor[
              0.8781356082516507, 0.43307373314204806`, 0.32654502054624035`],
              UndirectedEdge[107, 268] -> 
             RGBColor[
              0.5139907876886572, 0.6129102178843966, 0.9560554271690249], 
             UndirectedEdge[5, 274] -> 
             RGBColor[
              0.38775900825169696`, 0.5067672930904867, 0.9463159883002454], 
             UndirectedEdge[12, 118] -> 
             RGBColor[
              0.27367870261090094`, 0.4049840470489852, 0.9388969692911083], 
             UndirectedEdge[20, 291] -> 
             RGBColor[
              0.18873168488737596`, 0.31569934546955897`, 0.9340593622996046],
              UndirectedEdge[6, 379] -> 
             RGBColor[
              0.25634517615934155`, 0.38676541173934353`, 0.9379098506023464],
              UndirectedEdge[97, 181] -> 
             RGBColor[
              0.19390662933890207`, 0.32113854019854193`, 0.9343540677304747],
              UndirectedEdge[39, 320] -> 
             RGBColor[
              0.18948414481075992`, 0.3164902285577502, 0.9341022137790767], 
             UndirectedEdge[202, 218] -> 
             RGBColor[
              0.2171099632633392, 0.3455267153294672, 0.9356754632712151], 
             UndirectedEdge[61, 344] -> 
             RGBColor[
              0.20030701799861927`, 0.32786575448798405`, 0.9347185603961192],
              UndirectedEdge[181, 214] -> 
             RGBColor[
              0.21733436721625865`, 0.34576257811201794`, 0.9356882427443579],
              UndirectedEdge[274, 324] -> 
             RGBColor[
              0.5631040589260905, 0.6561922684417929, 0.9587487607182468], 
             UndirectedEdge[62, 231] -> 
             RGBColor[
              0.19164937615014635`, 0.31876602397904136`, 0.934225520500682], 
             UndirectedEdge[117, 289] -> 
             RGBColor[
              0.20615434433043495`, 0.33401166520462483`, 0.935051556980372], 
             UndirectedEdge[14, 396] -> 
             RGBColor[
              0.19205343988410067`, 0.31919072058254777`, 0.9342485313325719],
              UndirectedEdge[79, 175] -> 
             RGBColor[
              0.2563476435480917, 0.3867680051213614, 0.9379099911164857], 
             UndirectedEdge[246, 395] -> 
             RGBColor[
              0.6944421379403393, 0.7593719483680503, 0.9717835682731306], 
             UndirectedEdge[87, 396] -> 
             RGBColor[
              0.198868412851103, 0.3263536892651099, 0.9346366339611938], 
             UndirectedEdge[341, 366] -> 
             RGBColor[
              0.36531722643847, 0.49084115298848774`, 0.9444986685246879], 
             UndirectedEdge[40, 226] -> 
             RGBColor[
              0.48315013418370223`, 0.5910627432060597, 0.9525150956533707], 
             UndirectedEdge[67, 316] -> 
             RGBColor[
              0.32978816517065423`, 0.4531895985227258, 0.9424866278961124], 
             UndirectedEdge[303, 376] -> 
             RGBColor[
              0.21141869489039777`, 0.33954483142224945`, 0.9353513539568531],
              UndirectedEdge[208, 357] -> 
             RGBColor[
              0.9024054179734275, 0.6237298560449753, 0.3900146964380397], 
             UndirectedEdge[54, 66] -> 
             RGBColor[
              0.19944158418676777`, 0.3269561286800552, 0.9346692752208288], 
             UndirectedEdge[3, 160] -> 
             RGBColor[
              0.5207461823507223, 0.6218042360373149, 0.9554141935122193], 
             UndirectedEdge[230, 328] -> 
             RGBColor[
              0.8350024631896295, 0.25838385457720503`, 0.18069489331394697`],
              UndirectedEdge[282, 383] -> 
             RGBColor[
              0.23774824777614534`, 0.3672188608952424, 0.9368507830426136], 
             UndirectedEdge[106, 150] -> 
             RGBColor[
              0.2101822963835033, 0.33824529819931026`, 0.9352809428909732], 
             UndirectedEdge[1, 298] -> 
             RGBColor[
              0.19527223087889906`, 0.32257387400121723`, 0.9344318367179512],
              UndirectedEdge[66, 131] -> 
             RGBColor[
              0.2137636212718384, 0.34200949772606326`, 0.9354848940452685], 
             UndirectedEdge[53, 126] -> 
             RGBColor[
              0.1894916420221746, 0.31649810860229766`, 0.9341026407341755], 
             UndirectedEdge[182, 281] -> 
             RGBColor[
              0.38860982761707186`, 0.5110160334092172, 0.94598285247495], 
             UndirectedEdge[74, 263] -> 
             RGBColor[
              0.627506347078178, 0.7037780429959705, 0.9664982429670084], 
             UndirectedEdge[24, 243] -> 
             RGBColor[
              0.8703666327474808, 0.4327860372681659, 0.42384867205099064`], 
             UndirectedEdge[177, 252] -> 
             RGBColor[
              0.6322093663988135, 0.7067582685174405, 0.9673012182198607], 
             UndirectedEdge[10, 216] -> 
             RGBColor[
              0.21860581417743288`, 0.3470989494826055, 0.9357606497678597], 
             UndirectedEdge[280, 339] -> 
             RGBColor[
              0.2515419198726136, 0.3817168848379542, 0.9376363122625981], 
             UndirectedEdge[152, 154] -> 
             RGBColor[
              0.23114091709829876`, 0.3602741374238645, 0.93647450533518], 
             UndirectedEdge[36, 304] -> 
             RGBColor[
              0.18688421139568462`, 0.3137575336932065, 0.933954151417345], 
             UndirectedEdge[128, 299] -> 
             RGBColor[
              0.19113698074466645`, 0.31822746392013684`, 0.934196340340361], 
             UndirectedEdge[95, 162] -> 
             RGBColor[
              0.41586939242453425`, 0.5283792415607237, 0.9486390212485251], 
             UndirectedEdge[215, 329] -> 
             RGBColor[
              0.1867198905000643, 0.313584822013363, 0.9339447935854304], 
             UndirectedEdge[208, 387] -> 
             RGBColor[
              0.7635706581669874, 0.8120231295414462, 0.8609429981480392], 
             UndirectedEdge[178, 197] -> 
             RGBColor[
              0.7030008791274289, 0.7649478943931832, 0.947330285544383], 
             UndirectedEdge[53, 303] -> 
             RGBColor[
              0.20281627238444755`, 0.3305031399434066, 0.9348614587212829], 
             UndirectedEdge[59, 121] -> 
             RGBColor[
              0.3287091584623374, 0.4591330844825578, 0.9421660348044922], 
             UndirectedEdge[134, 269] -> 
             RGBColor[
              0.7872748442941331, 0.8338331400434145, 0.9794082972749127], 
             UndirectedEdge[44, 362] -> 
             RGBColor[
              0.21291981933663207`, 0.3411226083920287, 0.9354368407733515], 
             UndirectedEdge[284, 338] -> 
             RGBColor[
              0.2553995027309328, 0.3857714490069275, 0.9378559958995971], 
             UndirectedEdge[12, 346] -> 
             RGBColor[
              0.329771268632467, 0.46002807831552184`, 0.9422346251627481], 
             UndirectedEdge[113, 387] -> 
             RGBColor[
              0.4208258242811829, 0.5366129491256768, 0.9486460027249637], 
             UndirectedEdge[55, 400] -> 
             RGBColor[
              0.8906627621597499, 0.5631222251341941, 0.24522067856577465`], 
             UndirectedEdge[25, 201] -> 
             RGBColor[
              0.8612272549405598, 0.40992383458465387`, 0.4331919313429953], 
             UndirectedEdge[123, 309] -> 
             RGBColor[
              0.2546471876156135, 0.3849807181211936, 0.93781315266673], 
             UndirectedEdge[35, 162] -> 
             RGBColor[
              0.25429020183451534`, 0.3846055034310536, 0.9377928228546097], 
             UndirectedEdge[73, 172] -> 
             RGBColor[
              0.8594072564997123, 0.3768516972747061, 0.20129475467115204`], 
             UndirectedEdge[137, 282] -> 
             RGBColor[
              0.3008030444529849, 0.4311156931304887, 0.9405287217628104], 
             UndirectedEdge[37, 114] -> 
             RGBColor[
              0.2950446149939596, 0.4237378370222073, 0.9402493164383834], 
             UndirectedEdge[214, 248] -> 
             RGBColor[
              0.22887195802400728`, 0.3578893175764699, 0.9363452914725232], 
             UndirectedEdge[161, 363] -> 
             RGBColor[
              0.20967797684249928`, 0.3377152263860093, 0.9352522226391868], 
             UndirectedEdge[51, 84] -> 
             RGBColor[
              0.36020789306278994`, 0.48641570522103605`, 0.9441731063199956],
              UndirectedEdge[56, 278] -> 
             RGBColor[
              0.3199081459581343, 0.44683361246279085`, 0.9417764708138758], 
             UndirectedEdge[4, 140] -> 
             RGBColor[
              0.22925899781803233`, 0.3582961209397305, 0.9363673328162189], 
             UndirectedEdge[221, 351] -> 
             RGBColor[
              0.9060488999462345, 0.7900961921894157, 0.6157268873569864], 
             UndirectedEdge[54, 204] -> 
             RGBColor[
              0.18912347164523904`, 0.31611113819278824`, 0.9340816739758684],
              UndirectedEdge[10, 298] -> 
             RGBColor[
              0.21724932645694042`, 0.3456731948820789, 0.9356833997989213], 
             UndirectedEdge[134, 226] -> 
             RGBColor[
              0.6381042655490734, 0.7140610165668736, 0.9666654902064342], 
             UndirectedEdge[35, 98] -> 
             RGBColor[
              0.21863346925867172`, 0.3471280167264209, 0.9357622246838242], 
             UndirectedEdge[70, 180] -> 
             RGBColor[
              0.24072957206270523`, 0.3703524217472943, 0.9370205650502591], 
             UndirectedEdge[165, 328] -> 
             RGBColor[
              0.8831401501680374, 0.7104796109326978, 0.6014297849392954], 
             UndirectedEdge[162, 214] -> 
             RGBColor[
              0.25603696286442035`, 0.3864414600245297, 0.9378922983111614], 
             UndirectedEdge[211, 370] -> 
             RGBColor[
              0.20448863330117922`, 0.3322608973006979, 0.9349566972014545], 
             UndirectedEdge[55, 245] -> 
             RGBColor[
              0.869763812018424, 0.4024837363696161, 0.2252078203084527], 
             UndirectedEdge[247, 315] -> 
             RGBColor[
              0.2082369879918481, 0.3362006557400048, 0.9351701604558942], 
             UndirectedEdge[16, 268] -> 
             RGBColor[
              0.49856920010276634`, 0.5995528138290274, 0.9550727772448264], 
             UndirectedEdge[154, 291] -> 
             RGBColor[
              0.1963438417799771, 0.3237002050023056, 0.9344928633734613], 
             UndirectedEdge[296, 373] -> 
             RGBColor[
              0.25840585650162723`, 0.38893131743376574`, 0.9380272032993362],
              UndirectedEdge[101, 394] -> 
             RGBColor[
              0.18176625720560394`, 0.308378239342394, 0.9336626914975545], 
             UndirectedEdge[173, 388] -> 
             RGBColor[
              0.2509970167086373, 0.38114415706375904`, 0.9376052808335218], 
             UndirectedEdge[84, 102] -> 
             RGBColor[
              0.3081546083900806, 0.43843821536979977`, 0.9409621908941581], 
             UndirectedEdge[216, 298] -> 
             RGBColor[
              0.19835416070020614`, 0.3258131776490477, 0.9346073480619681], 
             UndirectedEdge[209, 310] -> 
             RGBColor[
              0.30722079620017617`, 0.4378261141051596, 0.9408954863272463], 
             UndirectedEdge[34, 93] -> 
             RGBColor[
              0.24878417747359188`, 0.37881832272561544`, 0.9374792629126882],
              UndirectedEdge[112, 285] -> 
             RGBColor[
              0.9656534548794817, 0.8891806763774219, 0.4391165147700274], 
             UndirectedEdge[131, 309] -> 
             RGBColor[
              0.255426495168577, 0.38579981977031097`, 0.9378575330789891], 
             UndirectedEdge[116, 265] -> 
             RGBColor[
              0.18666044049465552`, 0.3135223362883303, 0.9339414079955707], 
             UndirectedEdge[49, 129] -> 
             RGBColor[
              0.18838308614561955`, 0.31533294608953616`, 0.9340395101169672],
              UndirectedEdge[238, 325] -> 
             RGBColor[
              0.28956065239162987`, 0.42167698324230746`, 0.9398014228358818],
              UndirectedEdge[112, 399] -> 
             RGBColor[
              0.9318419668775375, 0.7674831415272341, 0.2640166505562497], 
             UndirectedEdge[186, 322] -> 
             RGBColor[
              0.20337835674212623`, 0.3310939262415335, 0.9348934685939234], 
             UndirectedEdge[180, 332] -> 
             RGBColor[
              0.2434440031568898, 0.373205460932154, 0.937175147885432], 
             UndirectedEdge[60, 331] -> 
             RGBColor[
              0.19257622837931382`, 0.31974020443772183`, 0.9342783033639781],
              UndirectedEdge[14, 126] -> 
             RGBColor[
              0.18556762080960376`, 0.31237371351057097`, 0.9338791735311889],
              UndirectedEdge[275, 288] -> 
             RGBColor[
              0.2720607570835225, 0.40328348371603906`, 0.9388048296868601], 
             UndirectedEdge[276, 290] -> 
             RGBColor[
              0.21053718403849497`, 0.33861830762588346`, 0.9353011532179156],
              UndirectedEdge[18, 232] -> 
             RGBColor[
              0.4501165590628717, 0.5589054128143358, 0.9510872394181826], 
             UndirectedEdge[4, 325] -> 
             RGBColor[
              0.26097898271890796`, 0.39163583623375275`, 0.9381737390308114],
              UndirectedEdge[1, 62] -> 
             RGBColor[
              0.19732629313580521`, 0.3247328236682947, 0.9345488125247692], 
             UndirectedEdge[20, 304] -> 
             RGBColor[
              0.185589373288035, 0.312396576744589, 0.9338804123026556], 
             UndirectedEdge[255, 328] -> 
             RGBColor[
              0.8467511825783175, 0.34868966012032526`, 0.19194548026883534`],
              UndirectedEdge[3, 74] -> 
             RGBColor[
              0.7224644673916434, 0.782535536200579, 0.9735133143364585], 
             UndirectedEdge[18, 279] -> 
             RGBColor[
              0.638687245246097, 0.7170964540862654, 0.9650118438159424], 
             UndirectedEdge[163, 226] -> 
             RGBColor[
              0.35601753306005335`, 0.4789075435482711, 0.944048117850775], 
             UndirectedEdge[145, 254] -> 
             RGBColor[
              0.19225246823374995`, 0.31939991199715534`, 0.9342598657026484],
              UndirectedEdge[23, 348] -> 
             RGBColor[
              0.3130979265677895, 0.44416079144735543`, 0.9412244155321879], 
             UndirectedEdge[119, 396] -> 
             RGBColor[
              0.19098691356338682`, 0.3180697337978031, 0.9341877942363916], 
             UndirectedEdge[73, 141] -> 
             RGBColor[
              0.887270128859985, 0.5759343748998204, 0.22738563797870492`], 
             UndirectedEdge[29, 396] -> 
             RGBColor[
              0.19049809514878532`, 0.31755595465117936`, 0.9341599567508221],
              UndirectedEdge[160, 312] -> 
             RGBColor[
              0.38126624461740655`, 0.5039445125232649, 0.9455819912605958], 
             UndirectedEdge[210, 397] -> 
             RGBColor[
              0.25928855226930214`, 0.38985908665173613`, 0.938077471517474], 
             UndirectedEdge[11, 86] -> 
             RGBColor[
              0.361493667794528, 0.48752937866875046`, 0.9442550347489361], 
             UndirectedEdge[113, 315] -> 
             RGBColor[
              0.26318579596449465`, 0.3939553368749055, 0.9382994137804598], 
             UndirectedEdge[120, 160] -> 
             RGBColor[
              0.48896132780643076`, 0.5959998592268796, 0.9529119733307341], 
             UndirectedEdge[5, 308] -> 
             RGBColor[
              0.24197001296398313`, 0.37165620378303305`, 0.9370912063245189],
              UndirectedEdge[37, 261] -> 
             RGBColor[
              0.30438433219243016`, 0.43355447197007246`, 0.940781199515963], 
             UndirectedEdge[22, 241] -> 
             RGBColor[
              0.28974430117812966`, 0.42117386849154814`, 0.9398373705045929],
              UndirectedEdge[55, 165] -> 
             RGBColor[
              0.9341904345376686, 0.918237850236102, 0.6671537250527897], 
             UndirectedEdge[251, 283] -> 
             RGBColor[
              0.19962713488925782`, 0.32715115423296626`, 0.934679842058838], 
             UndirectedEdge[334, 365] -> 
             RGBColor[
              0.18295572293696874`, 0.30962844324254163`, 0.933730429811299], 
             UndirectedEdge[44, 358] -> 
             RGBColor[
              0.21372519899594036`, 0.3419691134779814, 0.9354827059534967], 
             UndirectedEdge[225, 367] -> 
             RGBColor[
              0.6298962166593582, 0.7051035104774022, 0.9669932656124167], 
             UndirectedEdge[23, 321] -> 
             RGBColor[
              0.42370887427578074`, 0.5372228658179581, 0.9490305036181749], 
             UndirectedEdge[234, 269] -> 
             RGBColor[
              0.7646521215423732, 0.8160713160110501, 0.9771770354611466], 
             UndirectedEdge[21, 208] -> 
             RGBColor[
              0.9781086897296334, 0.9394569243444684, 0.5384830216306559], 
             UndirectedEdge[208, 240] -> 
             RGBColor[
              0.8854643741404387, 0.49351356953187997`, 0.37379193373139724`],
              UndirectedEdge[15, 313] -> 
             RGBColor[
              0.25209641053026927`, 0.3822996896758886, 0.9376678896852563], 
             UndirectedEdge[63, 204] -> 
             RGBColor[
              0.18740799960939158`, 0.3143080683159034, 0.9339839803812403], 
             UndirectedEdge[241, 310] -> 
             RGBColor[
              0.2714061632718937, 0.40259546411637237`, 0.9387675515376726], 
             UndirectedEdge[182, 256] -> 
             RGBColor[
              0.34992025301800456`, 0.4775050684860661, 0.9435175869933449], 
             UndirectedEdge[373, 380] -> 
             RGBColor[
              0.24598769620290184`, 0.37587904360296687`, 0.9373200074413457],
              UndirectedEdge[185, 210] -> 
             RGBColor[
              0.35262704416750634`, 0.4795636552057607, 0.9437005295213796], 
             UndirectedEdge[96, 223] -> 
             RGBColor[
              0.8390506368021915, 0.7815052608012159, 0.618996491222558], 
             UndirectedEdge[103, 222] -> 
             RGBColor[
              0.21336670811641717`, 0.34159231683396796`, 0.9354622904282476],
              UndirectedEdge[146, 375] -> 
             RGBColor[
              0.18336952246536248`, 0.3100633727832889, 0.9337539950822794], 
             UndirectedEdge[42, 276] -> 
             RGBColor[
              0.2196855450649306, 0.3482338151042579, 0.9358221388445839], 
             UndirectedEdge[46, 372] -> 
             RGBColor[
              0.19768089456011895`, 0.32510553224827726`, 0.934569006551298], 
             UndirectedEdge[95, 285] -> 
             RGBColor[
              0.7768044768753901, 0.8215969254274786, 0.7842186264026185], 
             UndirectedEdge[14, 326] -> 
             RGBColor[
              0.18828033718868842`, 0.3152249504211414, 0.9340336587158735], 
             UndirectedEdge[22, 310] -> 
             RGBColor[
              0.2979372274212155, 0.4297851534345578, 0.9403039455337885], 
             UndirectedEdge[23, 229] -> 
             RGBColor[
              0.24996961512608984`, 0.38006429285947896`, 0.9375467718333002],
              UndirectedEdge[23, 160] -> 
             RGBColor[
              0.3763398438622711, 0.4987665529777692, 0.9453014400255476], 
             UndirectedEdge[165, 311] -> 
             RGBColor[
              0.5997467789297788, 0.6780206465223158, 0.965283080943369], 
             UndirectedEdge[179, 288] -> 
             RGBColor[
              0.3796596294696894, 0.502934688841232, 0.9454287055118813], 
             UndirectedEdge[51, 167] -> 
             RGBColor[
              0.3459161722681373, 0.47403693499148125`, 0.9432624505086329], 
             UndirectedEdge[310, 346] -> 
             RGBColor[
              0.31533275535423055`, 0.4448522854054794, 0.9414123731914188], 
             UndirectedEdge[79, 379] -> 
             RGBColor[
              0.21907288200889707`, 0.34758986738728526`, 0.9357872485898966],
              UndirectedEdge[78, 264] -> 
             RGBColor[
              0.7877222743756765, 0.3640897660872551, 0.4355019064498754], 
             UndirectedEdge[309, 325] -> 
             RGBColor[
              0.2933678336849298, 0.42567857217080163`, 0.9400182361783151], 
             UndirectedEdge[149, 358] -> 
             RGBColor[
              0.20368965097586314`, 0.3314211162183854, 0.9349111963400162], 
             UndirectedEdge[6, 79] -> 
             RGBColor[
              0.26831622286540857`, 0.39934774083561936`, 0.9385915840026804],
              UndirectedEdge[134, 234] -> 
             RGBColor[
              0.8083454624285121, 0.8502936670726204, 0.9815084195744261], 
             UndirectedEdge[96, 209] -> 
             RGBColor[
              0.5415208134624869, 0.6338317942327045, 0.9590470002598491], 
             UndirectedEdge[216, 393] -> 
             RGBColor[
              0.19153695040893678`, 0.31864785739682644`, 0.9342191180210391],
              UndirectedEdge[164, 388] -> 
             RGBColor[
              0.21023340989613648`, 0.33829902174187165`, 0.935283853729902], 
             UndirectedEdge[155, 261] -> 
             RGBColor[
              0.23352567596023666`, 0.3627806701902061, 0.9366103138244327], 
             UndirectedEdge[125, 288] -> 
             RGBColor[
              0.28344153985750953`, 0.415245407994804, 0.9394529484294792], 
             UndirectedEdge[287, 384] -> 
             RGBColor[
              0.18974513703544627`, 0.3167645479337583, 0.9341170769001692], 
             UndirectedEdge[69, 320] -> 
             RGBColor[
              0.21880446674278364`, 0.34730774592408925`, 0.9357719627375762],
              UndirectedEdge[123, 339] -> 
             RGBColor[
              0.23162280417676506`, 0.3607806312967381, 0.9365019480914105], 
             UndirectedEdge[132, 202] -> 
             RGBColor[
              0.300816385571577, 0.4289283244783967, 0.9406100852285664], 
             UndirectedEdge[67, 249] -> 
             RGBColor[
              0.36714946895537004`, 0.49242814936543994`, 0.9446154173976764],
              UndirectedEdge[374, 384] -> 
             RGBColor[
              0.18988847579037965`, 0.3169152060533953, 0.934125239830212], 
             UndirectedEdge[99, 252] -> 
             RGBColor[
              0.6676015641481373, 0.7342070299092066, 0.9439106644834332], 
             UndirectedEdge[44, 65] -> 
             RGBColor[
              0.2623103948909678, 0.393035234842995, 0.9382495609843622], 
             UndirectedEdge[88, 370] -> 
             RGBColor[
              0.189278561860536, 0.3162741478423529, 0.9340905061341941], 
             UndirectedEdge[13, 275] -> 
             RGBColor[
              0.22645651195099847`, 0.3553505306056112, 0.9362077353919975], 
             UndirectedEdge[183, 269] -> 
             RGBColor[
              0.546784204528102, 0.6385867943130678, 0.9592993736008182], 
             UndirectedEdge[122, 178] -> 
             RGBColor[
              0.5198265338212547, 0.6207419031672892, 0.9554290299990101], 
             UndirectedEdge[199, 216] -> 
             RGBColor[
              0.19310022590756143`, 0.3202909590632723, 0.9343081442480269], 
             UndirectedEdge[107, 295] -> 
             RGBColor[
              0.38882676959428764`, 0.5112039376460608, 0.945996675825904], 
             UndirectedEdge[89, 171] -> 
             RGBColor[
              0.18910388505940673`, 0.3160905514492172, 0.934080558548781], 
             UndirectedEdge[18, 91] -> 
             RGBColor[
              0.5492190587011108, 0.6449197997470224, 0.9576556826381046], 
             UndirectedEdge[194, 357] -> 
             RGBColor[
              0.9029108820280516, 0.6235073439816599, 0.3502698506941914], 
             UndirectedEdge[147, 388] -> 
             RGBColor[
              0.20149520910929605`, 0.3291146186809729, 0.9347862261221009], 
             UndirectedEdge[96, 323] -> 
             RGBColor[
              0.5734450946307983, 0.6614830020196698, 0.9610811872263605], 
             UndirectedEdge[168, 265] -> 
             RGBColor[
              0.18709388052696674`, 0.31397790924397473`, 0.9339660917641938],
              UndirectedEdge[44, 372] -> 
             RGBColor[
              0.21537145554787535`, 0.3436994334927591, 0.9355764578287111], 
             UndirectedEdge[180, 286] -> 
             RGBColor[
              0.22669434503393948`, 0.3556005082552706, 0.9362212796342286], 
             UndirectedEdge[18, 45] -> 
             RGBColor[
              0.4449748432614876, 0.5535011435034702, 0.9507944263097807], 
             UndirectedEdge[83, 217] -> 
             RGBColor[
              0.9690520396764782, 0.9730561345189551, 0.7324860448307533], 
             UndirectedEdge[137, 314] -> 
             RGBColor[
              0.28356888618805115`, 0.41300150008529746`, 0.9395472619452747],
              UndirectedEdge[205, 338] -> 
             RGBColor[
              0.292109011117009, 0.4205396174018403, 0.9400862651454345], 
             UndirectedEdge[210, 293] -> 
             RGBColor[
              0.3272740253136205, 0.45760414455430376`, 0.9420850575788042], 
             UndirectedEdge[295, 324] -> 
             RGBColor[
              0.5310822445454129, 0.6295361727227928, 0.9564100649680346], 
             UndirectedEdge[270, 346] -> 
             RGBColor[
              0.3550828331693524, 0.4819766359343405, 0.9438465420354984], 
             UndirectedEdge[26, 349] -> 
             RGBColor[
              0.19449252215171758`, 0.32175435069256086`, 0.9343874334594139],
              UndirectedEdge[27, 208] -> 
             RGBColor[
              0.8783639162366949, 0.43893633864321185`, 0.3669925272239519], 
             UndirectedEdge[139, 193] -> 
             RGBColor[
              0.18750230329400064`, 0.31440718746762647`, 0.933989350836569], 
             UndirectedEdge[5, 296] -> 
             RGBColor[
              0.26370004466317304`, 0.39449584486246725`, 0.9383286994830867],
              UndirectedEdge[42, 125] -> 
             RGBColor[
              0.23901293023950498`, 0.3685481223497329, 0.9369228048379719], 
             UndirectedEdge[12, 106] -> 
             RGBColor[
              0.2676474114572338, 0.3986447776405352, 0.9385534961824027], 
             UndirectedEdge[242, 357] -> 
             RGBColor[
              0.8538824472203527, 0.4151696775403659, 0.1992311983507169], 
             UndirectedEdge[148, 279] -> 
             RGBColor[
              0.5031062098123048, 0.6037853067748751, 0.9552337277677017], 
             UndirectedEdge[292, 374] -> 
             RGBColor[
              0.19230228893935433`, 0.31945227671756077`, 0.9342627029181295],
              UndirectedEdge[195, 369] -> 
             RGBColor[
              0.19622298384464848`, 0.3235731756494396, 0.9344859806928376], 
             UndirectedEdge[50, 371] -> 
             RGBColor[
              0.1827919087042476, 0.30945626409752947`, 0.9337211008330868], 
             UndirectedEdge[29, 127] -> 
             RGBColor[
              0.18812124438286376`, 0.3150577337951532, 0.9340245986159385], 
             UndirectedEdge[87, 127] -> 
             RGBColor[
              0.19649156208518143`, 0.3238554684090837, 0.93450127582631], 
             UndirectedEdge[264, 357] -> 
             RGBColor[
              0.8124975481520774, 0.5545233769268668, 0.45922673659782653`], 
             UndirectedEdge[171, 306] -> 
             RGBColor[
              0.19583756200520352`, 0.3231680728590269, 0.9344640314892618], 
             UndirectedEdge[114, 170] -> 
             RGBColor[
              0.23647751036378017`, 0.3658832353054412, 0.9367784164268669], 
             UndirectedEdge[57, 222] -> 
             RGBColor[
              0.22503342369355192`, 0.35385477461802795`, 0.9361266926210063],
              UndirectedEdge[38, 102] -> 
             RGBColor[
              0.25020060979959846`, 0.3803070829072448, 0.9375599266382304], 
             UndirectedEdge[82, 331] -> 
             RGBColor[
              0.18993705205367367`, 0.31696626278603024`, 0.9341280061765445],
              UndirectedEdge[90, 324] -> 
             RGBColor[
              0.6207541500572831, 0.7029952095291041, 0.9632871870713362], 
             UndirectedEdge[160, 341] -> 
             RGBColor[
              0.3979292657890303, 0.5189168537463054, 0.9466239842803985], 
             UndirectedEdge[15, 311] -> 
             RGBColor[
              0.2942848105043079, 0.4266423729476564, 0.940070456651633], 
             UndirectedEdge[271, 292] -> 
             RGBColor[
              0.18674265418407987`, 0.3136087480885643, 0.9339460899435592], 
             UndirectedEdge[41, 156] -> 
             RGBColor[
              0.8446142468320946, 0.4596744496768401, 0.44741728123423563`], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.26166329356975937`, 0.3923550903258115, 0.9382127095214201], 
             UndirectedEdge[129, 317] -> 
             RGBColor[
              0.19222117947628775`, 0.3193670255292408, 0.9342580838541985], 
             UndirectedEdge[164, 354] -> 
             RGBColor[
              0.20840265875823133`, 0.3363747862196069, 0.9351795951609518], 
             UndirectedEdge[78, 230] -> 
             RGBColor[
              0.8192044912502568, 0.14861971197700838`, 0.16602354855060375`],
              UndirectedEdge[315, 363] -> 
             RGBColor[
              0.2193734294732247, 0.3479057618281034, 0.9358043643233698], 
             UndirectedEdge[5, 121] -> 
             RGBColor[
              0.2966728547509243, 0.4289526354856623, 0.9402137650898452], 
             UndirectedEdge[43, 380] -> 
             RGBColor[
              0.2402420225431372, 0.36983997628980336`, 0.9369927998263845], 
             UndirectedEdge[135, 234] -> 
             RGBColor[
              0.8902824990453274, 0.9119541401261442, 0.8296334999422285], 
             UndirectedEdge[344, 356] -> 
             RGBColor[
              0.19312061469136133`, 0.3203123889677695, 0.9343093053591018], 
             UndirectedEdge[186, 228] -> 
             RGBColor[
              0.20522346006975262`, 0.3330332468251766, 0.934998544498846], 
             UndirectedEdge[298, 396] -> 
             RGBColor[
              0.19827776691556012`, 0.32573288293773905`, 0.9346029975489469],
              UndirectedEdge[86, 93] -> 
             RGBColor[
              0.32267144519324537`, 0.4470223501983363, 0.9420332704147207], 
             UndirectedEdge[249, 266] -> 
             RGBColor[
              0.270914372535644, 0.40204801259274037`, 0.9387406633049027], 
             UndirectedEdge[156, 364] -> 
             RGBColor[
              0.8265496181427123, 0.20507757592754824`, 0.17305725035795336`],
              UndirectedEdge[10, 311] -> 
             RGBColor[
              0.2701224968687157, 0.40124624933748154`, 0.9386944486350258], 
             UndirectedEdge[27, 73] -> 
             RGBColor[
              0.8575639301123329, 0.3626830829105343, 0.19952958324085807`], 
             UndirectedEdge[56, 213] -> 
             RGBColor[
              0.30213444608884904`, 0.4281523269825127, 0.9407642849001527], 
             UndirectedEdge[27, 243] -> 
             RGBColor[
              0.8705342231838472, 0.43407421080067554`, 0.42400915684212137`],
              UndirectedEdge[109, 157] -> 
             RGBColor[
              0.18435836126610156`, 0.3111027050588667, 0.9338103079891256], 
             UndirectedEdge[12, 241] -> 
             RGBColor[
              0.28584467655013013`, 0.4177712570264148, 0.9395898035090018], 
             UndirectedEdge[192, 382] -> 
             RGBColor[
              0.18175632170203998`, 0.30836779649820095`, 0.9336621256853248],
              UndirectedEdge[140, 280] -> 
             RGBColor[
              0.2386176080728396, 0.36813261368769457`, 0.936900291825407], 
             UndirectedEdge[199, 361] -> 
             RGBColor[
              0.2020628988707439, 0.32971129661386445`, 0.9348185552141937], 
             UndirectedEdge[16, 351] -> 
             RGBColor[
              0.6137824648944775, 0.6902841557450048, 0.9663635368138602], 
             UndirectedEdge[140, 322] -> 
             RGBColor[
              0.21280212927241615`, 0.34099890867255667`, 0.9354301384983013],
              UndirectedEdge[57, 238] -> 
             RGBColor[
              0.2538315033751126, 0.3841233822670593, 0.9377667006559303], 
             UndirectedEdge[49, 127] -> 
             RGBColor[
              0.19124100743417377`, 0.3183368025664821, 0.9342022645064347], 
             UndirectedEdge[165, 182] -> 
             RGBColor[
              0.6226406331298818, 0.6984050769847048, 0.9667215385795859], 
             UndirectedEdge[253, 343] -> 
             RGBColor[
              0.18655690968294972`, 0.31341351884099494`, 0.9339355120690042],
              UndirectedEdge[104, 240] -> 
             RGBColor[
              0.8232357232183486, 0.17960552738087315`, 0.16988386083587365`],
              UndirectedEdge[312, 348] -> 
             RGBColor[
              0.31802432732292496`, 0.44933875099285125`, 0.9415049667672362],
              UndirectedEdge[242, 244] -> 
             RGBColor[
              0.886437425104949, 0.5904629270310702, 0.4522784384828552], 
             UndirectedEdge[41, 165] -> 
             RGBColor[
              0.8843102751860701, 0.9105890257431475, 0.9888274975519911], 
             UndirectedEdge[54, 297] -> 
             RGBColor[
              0.19576644813648575`, 0.3230933276741248, 0.9344599816596418], 
             UndirectedEdge[77, 145] -> 
             RGBColor[
              0.19003339190962826`, 0.3170675220829382, 0.934133492588819], 
             UndirectedEdge[69, 150] -> 
             RGBColor[
              0.217681081623926, 0.3461269969374395, 0.9357079876169566], 
             UndirectedEdge[106, 241] -> 
             RGBColor[
              0.24501597193591163`, 0.37485769978748307`, 0.9372646691818778],
              UndirectedEdge[139, 276] -> 
             RGBColor[
              0.20545840173873126`, 0.33328018541543536`, 0.9350119240793292],
              UndirectedEdge[313, 393] -> 
             RGBColor[
              0.200865233126181, 0.3284524739799347, 0.9347503499218286], 
             UndirectedEdge[209, 323] -> 
             RGBColor[
              0.36676678405368435`, 0.4920966869379023, 0.9445910330541359], 
             UndirectedEdge[8, 213] -> 
             RGBColor[
              0.230215374068607, 0.3593013330168411, 0.9364217970288573], 
             UndirectedEdge[160, 244] -> 
             RGBColor[
              0.7071944520529801, 0.7689833903419949, 0.9560284549892878], 
             UndirectedEdge[180, 284] -> 
             RGBColor[
              0.2675710150211928, 0.3985644801424423, 0.9385491455183885], 
             UndirectedEdge[24, 242] -> 
             RGBColor[
              0.8312823760459324, 0.24145562707943447`, 0.17758934467096238`],
              UndirectedEdge[81, 192] -> 
             RGBColor[
              0.1805894919591846, 0.3071413844571813, 0.9335956764576392], 
             UndirectedEdge[124, 249] -> 
             RGBColor[
              0.30940302019566135`, 0.4424110778706867, 0.9409358647458874], 
             UndirectedEdge[195, 253] -> 
             RGBColor[
              0.1964706167173933, 0.3238334534995253, 0.9345000830186004], 
             UndirectedEdge[31, 81] -> 
             RGBColor[
              0.1880171511030766, 0.3149483251582018, 0.9340186706576468], 
             UndirectedEdge[172, 399] -> 
             RGBColor[
              0.8580608382473571, 0.37151359757140306`, 0.20021139494080872`],
              UndirectedEdge[124, 315] -> 
             RGBColor[
              0.2642878093777229, 0.3950226791099546, 0.9383655017096588], 
             UndirectedEdge[181, 370] -> 
             RGBColor[
              0.19100569805155482`, 0.318089477485873, 0.9341888639852036], 
             UndirectedEdge[244, 348] -> 
             RGBColor[
              0.6439525347584986, 0.7143776288115813, 0.9519514304959281], 
             UndirectedEdge[284, 367] -> 
             RGBColor[
              0.3258404306471927, 0.4536760993310988, 0.9420920701724073], 
             UndirectedEdge[148, 232] -> 
             RGBColor[
              0.3145355236290795, 0.4455942655029455, 0.9413091233699418], 
             UndirectedEdge[34, 211] -> 
             RGBColor[
              0.2425688344221679, 0.3722856031030586, 0.9371253083206856], 
             UndirectedEdge[355, 392] -> 
             RGBColor[
              0.8783955245201162, 0.9037382421614023, 0.8873541737699352], 
             UndirectedEdge[262, 338] -> 
             RGBColor[
              0.22417589206845978`, 0.35295345450941085`, 0.9360778574635618],
              UndirectedEdge[87, 119] -> 
             RGBColor[
              0.19029746556308325`, 0.3173450802359561, 0.9341485311927212], 
             UndirectedEdge[180, 367] -> 
             RGBColor[
              0.31681274319178854`, 0.44418742742702483`, 0.9415779567270888],
              UndirectedEdge[69, 380] -> 
             RGBColor[
              0.2309702581422837, 0.36009476404068996`, 0.9364647865601021], 
             UndirectedEdge[124, 338] -> 
             RGBColor[
              0.2719649687624893, 0.40309186038336303`, 0.9388027045792817], 
             UndirectedEdge[249, 293] -> 
             RGBColor[
              0.3289853537057845, 0.45937231092045516`, 0.9421836337211749], 
             UndirectedEdge[212, 373] -> 
             RGBColor[
              0.34459378761093823`, 0.4694803712160838, 0.9433030893613046], 
             UndirectedEdge[287, 292] -> 
             RGBColor[
              0.19215895018442095`, 0.31930161859792383`, 0.9342545399880867],
              UndirectedEdge[12, 323] -> 
             RGBColor[
              0.35358359064672407`, 0.4806531148021672, 0.943751925265087], 
             UndirectedEdge[120, 307] -> 
             RGBColor[
              0.43332684059947457`, 0.5479832712777266, 0.9493196875555654], 
             UndirectedEdge[99, 398] -> 
             RGBColor[
              0.695865579228825, 0.7586878991813948, 0.9457116225314874], 
             UndirectedEdge[134, 350] -> 
             RGBColor[
              0.9124093272037948, 0.929890258170909, 0.8676584254872136], 
             UndirectedEdge[45, 280] -> 
             RGBColor[
              0.26817273037966816`, 0.3991969211351571, 0.9385834123178955], 
             UndirectedEdge[188, 330] -> 
             RGBColor[
              0.19385743072413472`, 0.32108682933504906`, 0.9343512659421467],
              UndirectedEdge[236, 284] -> 
             RGBColor[
              0.26368702808225786`, 0.3944821636106265, 0.9383279582080599], 
             UndirectedEdge[374, 389] -> 
             RGBColor[
              0.19643386923101253`, 0.3237948295614139, 0.9344979903036141], 
             UndirectedEdge[278, 319] -> 
             RGBColor[
              0.35576382875700985`, 0.4778888141834562, 0.9440614916187484], 
             UndirectedEdge[78, 242] -> 
             RGBColor[
              0.8307161944426305, 0.2371037071740957, 0.17704716852822983`], 
             UndirectedEdge[84, 189] -> 
             RGBColor[
              0.30274052812538393`, 0.4327476737390883, 0.9406538670324976], 
             UndirectedEdge[223, 385] -> 
             RGBColor[
              0.9621637338718393, 0.8751385282482187, 0.44853214930663265`], 
             UndirectedEdge[175, 278] -> 
             RGBColor[
              0.2699086210585896, 0.40102145230052944`, 0.93868226872404], 
             UndirectedEdge[151, 168] -> 
             RGBColor[
              0.18811217327033666`, 0.31504819948074547`, 0.9340240820294996],
              UndirectedEdge[322, 339] -> 
             RGBColor[
              0.22572644107219014`, 0.3545831798228164, 0.9361661589354925], 
             UndirectedEdge[177, 367] -> 
             RGBColor[
              0.6349673392184779, 0.7091470859540894, 0.9674769538091501], 
             UndirectedEdge[294, 320] -> 
             RGBColor[
              0.19287620932606772`, 0.32005550343265077`, 0.9342953868351136],
              UndirectedEdge[179, 279] -> 
             RGBColor[
              0.5630911384213583, 0.6557241290001397, 0.9590606413690353], 
             UndirectedEdge[18, 285] -> 
             RGBColor[
              0.7996696633612428, 0.8401599138816065, 0.7860186576407228], 
             UndirectedEdge[121, 296] -> 
             RGBColor[
              0.27793336964590865`, 0.4092562484883108, 0.9391465791356984], 
             UndirectedEdge[212, 351] -> 
             RGBColor[
              0.6635629227613954, 0.7334014863107667, 0.9695355035700097], 
             UndirectedEdge[29, 87] -> 
             RGBColor[
              0.18980864714848175`, 0.31683130108933233`, 0.9341206937071518],
              UndirectedEdge[99, 141] -> 
             RGBColor[
              0.8989439948619978, 0.6463586296042318, 0.4540597244463016], 
             UndirectedEdge[121, 274] -> 
             RGBColor[
              0.4019923332344326, 0.5215276967163304, 0.9471338679528571], 
             UndirectedEdge[138, 218] -> 
             RGBColor[
              0.18655648275495362`, 0.3134130701126022, 0.9339354877560864], 
             UndirectedEdge[61, 388] -> 
             RGBColor[
              0.2144393921406435, 0.3427197757555252, 0.9355233781965335], 
             UndirectedEdge[283, 347] -> 
             RGBColor[
              0.20341579469893528`, 0.33113327590784336`, 0.9348956006301792],
              UndirectedEdge[253, 315] -> 
             RGBColor[
              0.20496946088804507`, 0.3327662775807237, 0.9349840796212059], 
             UndirectedEdge[321, 366] -> 
             RGBColor[
              0.4743804722974104, 0.5825626858071993, 0.9522061384174323], 
             UndirectedEdge[164, 391] -> 
             RGBColor[
              0.1910397493801938, 0.3181252675912516, 0.9341908031579952], 
             UndirectedEdge[74, 91] -> 
             RGBColor[
              0.6781789401773193, 0.7465825501677249, 0.9700269954109155], 
             UndirectedEdge[91, 285] -> 
             RGBColor[
              0.7437484336984672, 0.7947605404186777, 0.7816163335954551], 
             UndirectedEdge[51, 183] -> 
             RGBColor[
              0.36578243486715545`, 0.4912440931473596, 0.9445283111943961], 
             UndirectedEdge[30, 54] -> 
             RGBColor[
              0.1824115228296057, 0.3090564544254234, 0.9336994384202565], 
             UndirectedEdge[68, 250] -> 
             RGBColor[
              0.2641868760172087, 0.3950075354824494, 0.9383564238084967], 
             UndirectedEdge[32, 230] -> 
             RGBColor[
              0.8641696265273747, 0.38047397392294696`, 0.2056059653743008], 
             UndirectedEdge[275, 318] -> 
             RGBColor[
              0.21657038683237403`, 0.3449595862894012, 0.9356447351917034], 
             UndirectedEdge[131, 186] -> 
             RGBColor[
              0.21005402739966472`, 0.3381104793645726, 0.9352736381621005], 
             UndirectedEdge[192, 292] -> 
             RGBColor[
              0.18800332047098128`, 0.31493378828695684`, 0.9340178830236096],
              UndirectedEdge[144, 200] -> 
             RGBColor[
              0.18738223875410484`, 0.31428099202366444`, 0.9339825133386415],
              UndirectedEdge[139, 318] -> 
             RGBColor[
              0.19122506102961745`, 0.318320041884233, 0.9342013563822857], 
             UndirectedEdge[93, 148] -> 
             RGBColor[
              0.2841492261294814, 0.41365634022833114`, 0.9395786686798384], 
             UndirectedEdge[92, 311] -> 
             RGBColor[
              0.40006723340595274`, 0.5191882673765618, 0.947063870354397], 
             UndirectedEdge[334, 370] -> 
             RGBColor[
              0.18603433510834283`, 0.3128642598299414, 0.93390575222006], 
             UndirectedEdge[62, 129] -> 
             RGBColor[
              0.19509705711799047`, 0.3223897552718444, 0.9344218608314138], 
             UndirectedEdge[97, 191] -> 
             RGBColor[
              0.2000566789628183, 0.32760263228894565`, 0.9347043039583738], 
             UndirectedEdge[120, 366] -> 
             RGBColor[
              0.4563492884558704, 0.567924158469062, 0.9507866575750236], 
             UndirectedEdge[91, 288] -> 
             RGBColor[
              0.3993345066316525, 0.518907640464429, 0.9469775839135208], 
             UndirectedEdge[21, 32] -> 
             RGBColor[
              0.9601171751337108, 0.8771280081727125, 0.29956318594431774`], 
             UndirectedEdge[121, 178] -> 
             RGBColor[
              0.376298213208635, 0.5003523318083618, 0.9451983672915776], 
             UndirectedEdge[294, 381] -> 
             RGBColor[
              0.19306159004241835`, 0.32025035031935156`, 0.9343059439926636],
              UndirectedEdge[46, 149] -> 
             RGBColor[
              0.20894845482391827`, 0.3369484524901131, 0.9352106774394597], 
             UndirectedEdge[66, 232] -> 
             RGBColor[
              0.25468181299552817`, 0.38501711159085983`, 0.9378151245308926],
              UndirectedEdge[114, 261] -> 
             RGBColor[
              0.25063032461803525`, 0.380758740426915, 0.9375843982614342], 
             UndirectedEdge[189, 395] -> 
             RGBColor[
              0.3676410779096787, 0.4885452690238077, 0.9449042144225828], 
             UndirectedEdge[54, 290] -> 
             RGBColor[
              0.19141480754021284`, 0.3185194774974923, 0.9342121621653594], 
             UndirectedEdge[4, 309] -> 
             RGBColor[
              0.2652076930566547, 0.39608047891444564`, 0.9384145578287296], 
             UndirectedEdge[195, 315] -> 
             RGBColor[
              0.21034714004508412`, 0.3384185593393235, 0.9352903304936357], 
             UndirectedEdge[181, 305] -> 
             RGBColor[
              0.18857843384879308`, 0.3155382689113313, 0.9340506348796719], 
             UndirectedEdge[153, 372] -> 
             RGBColor[
              0.18825648302408265`, 0.31519987818169937`, 0.9340323002564883],
              UndirectedEdge[175, 227] -> 
             RGBColor[
              0.24456047357150879`, 0.37437894212623135`, 0.9372387292238745],
              UndirectedEdge[271, 287] -> 
             RGBColor[
              0.18451611233351262`, 0.31126851143271117`, 0.9338192916790429],
              UndirectedEdge[232, 297] -> 
             RGBColor[
              0.25100667694524614`, 0.38115431058492943`, 0.9376058309697055],
              UndirectedEdge[21, 25] -> 
             RGBColor[
              0.8659467013248013, 0.3852627325093696, 0.21332785065016086`], 
             UndirectedEdge[123, 297] -> 
             RGBColor[
              0.20930917766859286`, 0.3373275950710155, 0.9352312200718224], 
             UndirectedEdge[6, 178] -> 
             RGBColor[
              0.37363938184973156`, 0.4977574548464476, 0.9450396379279142], 
             UndirectedEdge[90, 319] -> 
             RGBColor[
              0.530870221387825, 0.6300233870103961, 0.956211194950797], 
             UndirectedEdge[258, 302] -> 
             RGBColor[
              0.18739149065206478`, 0.3142907163550246, 0.9339830402205433], 
             UndirectedEdge[253, 397] -> 
             RGBColor[
              0.20200814651583682`, 0.3296537484173573, 0.9348154371485806], 
             UndirectedEdge[169, 177] -> 
             RGBColor[
              0.8953206105495907, 0.9193683682944271, 0.9898776731680061], 
             UndirectedEdge[198, 332] -> 
             RGBColor[
              0.29082644977848415`, 0.41888733476416706`, 0.9400243645014585],
              UndirectedEdge[45, 123] -> 
             RGBColor[
              0.24825361468381962`, 0.37826066759394095`, 0.9374490481467079],
              UndirectedEdge[223, 245] -> 
             RGBColor[
              0.8558540868670035, 0.35042522733663617`, 0.19792860165144016`],
              UndirectedEdge[380, 381] -> 
             RGBColor[
              0.20814382827755723`, 0.3361027389736181, 0.9351648551479828], 
             UndirectedEdge[277, 378] -> 
             RGBColor[
              0.19931695292516527`, 0.3268251333220326, 0.934662177654856], 
             UndirectedEdge[119, 326] -> 
             RGBColor[
              0.18721381086797456`, 0.3141039636363968, 0.933972921619693], 
             UndirectedEdge[89, 133] -> 
             RGBColor[
              0.1875161010871107, 0.31442168982301577`, 0.9339901366004746], 
             UndirectedEdge[22, 346] -> 
             RGBColor[
              0.3336708932604665, 0.46343068978065516`, 0.9424821921583393], 
             UndirectedEdge[73, 243] -> 
             RGBColor[
              0.9500707567190481, 0.8697065757980069, 0.5997490197634427], 
             UndirectedEdge[26, 353] -> 
             RGBColor[
              0.1885101327336185, 0.315466480108742, 0.9340467452322052], 
             UndirectedEdge[21, 230] -> 
             RGBColor[
              0.8662262457545036, 0.38741143349321117`, 0.21359554271174397`],
              UndirectedEdge[107, 390] -> 
             RGBColor[
              0.30566480118721207`, 0.43491696287761505`, 0.9408535111759078],
              UndirectedEdge[223, 364] -> 
             RGBColor[
              0.855085463353394, 0.3445172501980627, 0.19719256690677167`], 
             UndirectedEdge[2, 211] -> 
             RGBColor[
              0.2034376502421772, 0.3311562474695121, 0.9348968452710344], 
             UndirectedEdge[128, 353] -> 
             RGBColor[
              0.19231632365158768`, 0.3194670280899702, 0.9342635021742287], 
             UndirectedEdge[259, 331] -> 
             RGBColor[
              0.19269223822101744`, 0.31986213813680114`, 0.934284909952842], 
             UndirectedEdge[2, 334] -> 
             RGBColor[
              0.18498335204934083`, 0.3117596099987556, 0.93384590028964], 
             UndirectedEdge[72, 191] -> 
             RGBColor[
              0.19501894918374685`, 0.32230765888062524`, 0.934417412700109], 
             UndirectedEdge[247, 301] -> 
             RGBColor[
              0.1901623548072361, 0.317203070265044, 0.9341408368350541], 
             UndirectedEdge[247, 397] -> 
             RGBColor[
              0.20527567361963986`, 0.3330881265766384, 0.935001517983269], 
             UndirectedEdge[125, 263] -> 
             RGBColor[
              0.326732269165051, 0.4530536866427142, 0.9421999706648885], 
             UndirectedEdge[123, 325] -> 
             RGBColor[
              0.2504184772778667, 0.38053607544050067`, 0.9375723338688118], 
             UndirectedEdge[129, 393] -> 
             RGBColor[
              0.18622578456981498`, 0.3130654853525456, 0.9339166549836668], 
             UndirectedEdge[19, 205] -> 
             RGBColor[
              0.30521095643223367`, 0.4343105926394541, 0.9408324015485454], 
             UndirectedEdge[277, 352] -> 
             RGBColor[
              0.22370886564436498`, 0.3524625801265016, 0.9360512609996132], 
             UndirectedEdge[139, 224] -> 
             RGBColor[
              0.18369701044953324`, 0.3104075834185898, 0.9337726450385029], 
             UndirectedEdge[65, 250] -> 
             RGBColor[
              0.2731468584894696, 0.40442504515649597`, 0.9388666815551856], 
             UndirectedEdge[58, 117] -> 
             RGBColor[
              0.2190498578943207, 0.34756566758305235`, 0.9357859374006325], 
             UndirectedEdge[134, 272] -> 
             RGBColor[0.7859507335711424, 0.832798734683, 0.9792763222925633],
              UndirectedEdge[74, 95] -> 
             RGBColor[
              0.7112349833542422, 0.7734189351765257, 0.9726292882180788], 
             UndirectedEdge[156, 245] -> 
             RGBColor[
              0.826933929899517, 0.208031564496835, 0.1734252677302876], 
             UndirectedEdge[221, 324] -> 
             RGBColor[
              0.7677190036317167, 0.6811645798747406, 0.602228741750033], 
             UndirectedEdge[227, 375] -> 
             RGBColor[
              0.1940331226429612, 0.32127149268124666`, 0.9343612713370109], 
             UndirectedEdge[132, 348] -> 
             RGBColor[
              0.34570653122762846`, 0.47385535445905747`, 0.94324909236691], 
             UndirectedEdge[137, 319] -> 
             RGBColor[
              0.3939126281591366, 0.5156078641515458, 0.9463210706392715], 
             UndirectedEdge[128, 170] -> 
             RGBColor[
              0.21313809335858236`, 0.34135202822847077`, 0.9354492711559941],
              UndirectedEdge[120, 220] -> 
             RGBColor[
              0.5770608462863022, 0.6675230171669182, 0.9598474901446392], 
             UndirectedEdge[292, 371] -> 
             RGBColor[
              0.1904665323376698, 0.31752278013549917`, 0.934158159295422], 
             UndirectedEdge[143, 378] -> 
             RGBColor[
              0.18793083673403851`, 0.31485760328369566`, 0.9340137551820207],
              UndirectedEdge[59, 373] -> 
             RGBColor[
              0.3091816453180559, 0.4388081534280127, 0.9410466589681301], 
             UndirectedEdge[2, 340] -> 
             RGBColor[
              0.19396024281710603`, 0.32119489136342505`, 0.9343571209387445],
              UndirectedEdge[131, 322] -> 
             RGBColor[
              0.206580775656939, 0.33445987156608825`, 0.9350758416135677], 
             UndirectedEdge[62, 317] -> 
             RGBColor[
              0.19822991985182326`, 0.32568259264007254`, 0.9346002727294505],
              UndirectedEdge[243, 337] -> 
             RGBColor[
              0.981786507894951, 0.983234170680865, 0.764939800713467], 
             UndirectedEdge[21, 217] -> 
             RGBColor[
              0.9781358461419554, 0.9375595363156388, 0.3992965964312667], 
             UndirectedEdge[24, 74] -> 
             RGBColor[
              0.8348779177441421, 0.40506983940754504`, 0.4406260894055427], 
             UndirectedEdge[1, 127] -> 
             RGBColor[
              0.19417547404882396`, 0.3214211130344089, 0.9343693780389848], 
             UndirectedEdge[226, 355] -> 
             RGBColor[
              0.6054737407452027, 0.6884810215092875, 0.963436744212341], 
             UndirectedEdge[97, 370] -> 
             RGBColor[
              0.18998864922989284`, 0.31702049468968657`, 0.9341309445593988],
              UndirectedEdge[148, 257] -> 
             RGBColor[
              0.3285413065471964, 0.4589876995901452, 0.9421553394288851], 
             UndirectedEdge[48, 344] -> 
             RGBColor[
              0.21571874970997718`, 0.3440644616768498, 0.9355962357174672], 
             UndirectedEdge[74, 148] -> 
             RGBColor[
              0.5985191344063026, 0.6786707763192633, 0.9646512034079422], 
             UndirectedEdge[266, 293] -> 
             RGBColor[
              0.2908233203898157, 0.4192921425712095, 0.940009243857379], 
             UndirectedEdge[84, 226] -> 
             RGBColor[
              0.39203908397867687`, 0.5139862829102032, 0.9462013616579391], 
             UndirectedEdge[354, 371] -> 
             RGBColor[
              0.20120013846367035`, 0.3288044807238608, 0.9347694222853504], 
             UndirectedEdge[57, 188] -> 
             RGBColor[
              0.20973271485913975`, 0.33777275951208907`, 0.9352553398882568],
              UndirectedEdge[134, 355] -> 
             RGBColor[
              0.7983376603764013, 0.8424754960473988, 0.9805109353940992], 
             UndirectedEdge[151, 378] -> 
             RGBColor[
              0.19141895458300517`, 0.3185238363024048, 0.9342123983333115], 
             UndirectedEdge[167, 238] -> 
             RGBColor[
              0.3001182809431252, 0.43263426016352036`, 0.9404077704799216], 
             UndirectedEdge[41, 311] -> 
             RGBColor[
              0.5873075100595555, 0.6681019111801583, 0.9640966123738608], 
             UndirectedEdge[212, 295] -> 
             RGBColor[
              0.42318563987531466`, 0.5409638641564534, 0.9481859926578549], 
             UndirectedEdge[179, 285] -> 
             RGBColor[
              0.7240735565365042, 0.7787875887954807, 0.7800674551938157], 
             UndirectedEdge[85, 348] -> 
             RGBColor[
              0.28694246093137055`, 0.4166697387111759, 0.9397349004577378], 
             UndirectedEdge[108, 152] -> 
             RGBColor[
              0.2564614085339687, 0.38688757933463486`, 0.9379164698641311], 
             UndirectedEdge[86, 148] -> 
             RGBColor[
              0.37250043656006593`, 0.49706288855717573`, 0.9449563763217728],
              UndirectedEdge[113, 293] -> 
             RGBColor[
              0.32820995463660485`, 0.4585878656141067, 0.9421383573691648], 
             UndirectedEdge[229, 260] -> 
             RGBColor[
              0.21573241152320438`, 0.34407882110876054`, 0.9355970137375196],
              UndirectedEdge[6, 278] -> 
             RGBColor[
              0.28187720037590647`, 0.4136011880147874, 0.9393638616102349], 
             UndirectedEdge[142, 378] -> 
             RGBColor[
              0.18665371404405717`, 0.3135152663622699, 0.93394102493416], 
             UndirectedEdge[289, 303] -> 
             RGBColor[
              0.19970158242580874`, 0.32722940331412775`, 0.9346840817359092],
              UndirectedEdge[5, 213] -> 
             RGBColor[
              0.25252900688278906`, 0.3827543758705798, 0.9376925254075633], 
             UndirectedEdge[104, 243] -> 
             RGBColor[
              0.8691814808377128, 0.4236764403528107, 0.42271376924375914`], 
             UndirectedEdge[121, 373] -> 
             RGBColor[
              0.2913786665893785, 0.4233881080569608, 0.9399122689060947], 
             UndirectedEdge[120, 202] -> 
             RGBColor[
              0.38082926485589774`, 0.49646706771580507`, 0.9461959416990309],
              UndirectedEdge[270, 351] -> 
             RGBColor[
              0.6344443344456173, 0.7081804286544429, 0.9676800928710849], 
             UndirectedEdge[91, 125] -> 
             RGBColor[
              0.37740486226419223`, 0.49585819381446866`, 0.9457287231087954],
              UndirectedEdge[280, 297] -> 
             RGBColor[
              0.22922829336444137`, 0.3582638486122316, 0.9363655842430101], 
             UndirectedEdge[33, 281] -> 
             RGBColor[
              0.3526148324525338, 0.4768614731328931, 0.9437983042422098], 
             UndirectedEdge[16, 241] -> 
             RGBColor[
              0.29049437153587576`, 0.42182354173579545`, 0.9398851643245274],
              UndirectedEdge[89, 342] -> 
             RGBColor[
              0.18647972709604152`, 0.31333239504849575`, 0.9339311166348612],
              UndirectedEdge[157, 370] -> 
             RGBColor[
              0.18724094908895864`, 0.3141324876273136, 0.9339744671012307], 
             UndirectedEdge[90, 122] -> 
             RGBColor[
              0.6031707449782447, 0.6887202091625689, 0.9619029570133792], 
             UndirectedEdge[135, 156] -> 
             RGBColor[
              0.8856046641981132, 0.4899098319471875, 0.34486688561467355`], 
             UndirectedEdge[12, 22] -> 
             RGBColor[
              0.3123757406994519, 0.44496094634460026`, 0.9411261975051177], 
             UndirectedEdge[271, 384] -> 
             RGBColor[
              0.18432884103510522`, 0.31107167742439884`, 0.9338086268556416],
              UndirectedEdge[158, 324] -> 
             RGBColor[
              0.4859428845919035, 0.5904387279012617, 0.9535338248669657], 
             UndirectedEdge[301, 397] -> 
             RGBColor[
              0.19781003665891564`, 0.3252412687821946, 0.934576361002776], 
             UndirectedEdge[95, 233] -> 
             RGBColor[
              0.7594081345567827, 0.8112195509449376, 0.9560282891124947], 
             UndirectedEdge[123, 203] -> 
             RGBColor[
              0.21872743662810462`, 0.3472267823895703, 0.935767575986501], 
             UndirectedEdge[103, 145] -> 
             RGBColor[
              0.1958024601948291, 0.32313117863074003`, 0.9344620324930895], 
             UndirectedEdge[20, 80] -> 
             RGBColor[
              0.18504810846190303`, 0.31182767309415216`, 0.933849588071537], 
             UndirectedEdge[73, 337] -> 
             RGBColor[
              0.9623310682876794, 0.8761474788456531, 0.428220440311572], 
             UndirectedEdge[122, 166] -> 
             RGBColor[
              0.7938288566186125, 0.8372493846021647, 0.890969402038376], 
             UndirectedEdge[62, 216] -> 
             RGBColor[
              0.2004082229571123, 0.32797212731612524`, 0.934724323868786], 
             UndirectedEdge[128, 342] -> 
             RGBColor[
              0.18916310762939384`, 0.3161527981252015, 0.9340839311865298], 
             UndirectedEdge[280, 309] -> 
             RGBColor[
              0.27456630331146203`, 0.4059169716624097, 0.9389475168379178], 
             UndirectedEdge[104, 141] -> 
             RGBColor[
              0.8345385936403027, 0.25894255793118215`, 0.18041218495107442`],
              UndirectedEdge[148, 276] -> 
             RGBColor[
              0.27841767131860123`, 0.407632112720532, 0.9392522651124343], 
             UndirectedEdge[359, 394] -> 
             RGBColor[
              0.18381809529055626`, 0.3105348512637273, 0.9337795406410702], 
             UndirectedEdge[8, 43] -> 
             RGBColor[
              0.24908603513269617`, 0.379135594264215, 0.9374964532598158], 
             UndirectedEdge[56, 352] -> 
             RGBColor[
              0.31062641380180694`, 0.4370779234706822, 0.9412478898986653], 
             UndirectedEdge[70, 152] -> 
             RGBColor[
              0.2398425593336916, 0.3694201151292457, 0.9369700509875596], 
             UndirectedEdge[359, 397] -> 
             RGBColor[
              0.20006364261390616`, 0.32760995152775996`, 0.9347047005280014],
              UndirectedEdge[118, 241] -> 
             RGBColor[
              0.25104726308957875`, 0.38119696919593304`, 0.9376081422905835],
              UndirectedEdge[43, 227] -> 
             RGBColor[
              0.23391469744368304`, 0.36318955643469497`, 0.9366324680224093],
              UndirectedEdge[234, 246] -> 
             RGBColor[
              0.8529840469746812, 0.885887262707637, 0.9857660876177745], 
             UndirectedEdge[196, 317] -> 
             RGBColor[
              0.1925447584771704, 0.3197071275752621, 0.9342765111996065], 
             UndirectedEdge[46, 184] -> 
             RGBColor[
              0.19220194755564052`, 0.3193468115612663, 0.9342569886247687], 
             UndirectedEdge[136, 331] -> 
             RGBColor[
              0.19186850922797938`, 0.3189963467376835, 0.9342379998052863], 
             UndirectedEdge[106, 320] -> 
             RGBColor[
              0.21130568150236095`, 0.33942604718596003`, 0.9353449180115927],
              UndirectedEdge[68, 161] -> 
             RGBColor[
              0.23474066997997348`, 0.36405770594001974`, 0.9366795059364341],
              UndirectedEdge[45, 297] -> 
             RGBColor[
              0.2458649611438621, 0.37575004127406386`, 0.9373130178613036], 
             UndirectedEdge[140, 203] -> 
             RGBColor[
              0.22572809779654535`, 0.3545849211451561, 0.9361662532834936], 
             UndirectedEdge[225, 243] -> 
             RGBColor[
              0.9271182354136238, 0.9438506209861709, 0.9626670150045318], 
             UndirectedEdge[107, 373] -> 
             RGBColor[
              0.31023491732991126`, 0.43972044470569116`, 0.9411137725293536],
              UndirectedEdge[187, 321] -> 
             RGBColor[
              0.494640933100008, 0.6001112786340405, 0.9534971170641517], 
             UndirectedEdge[297, 322] -> 
             RGBColor[
              0.2034128145640179, 0.33113014359709375`, 0.9348954309159043], 
             UndirectedEdge[106, 374] -> 
             RGBColor[
              0.2085188963433679, 0.336496959291474, 0.9351862147194673], 
             UndirectedEdge[154, 383] -> 
             RGBColor[
              0.20693321063768522`, 0.33483030307652095`, 0.9350959122643404],
              UndirectedEdge[111, 151] -> 
             RGBColor[
              0.1906348725141942, 0.31769971633440997`, 0.9341677460194382], 
             UndirectedEdge[79, 227] -> 
             RGBColor[
              0.21925675873838124`, 0.34778313348843115`, 0.9357977200976195],
              UndirectedEdge[93, 290] -> 
             RGBColor[
              0.21626873884937514`, 0.3446425351336826, 0.9356275567853198], 
             UndirectedEdge[150, 283] -> 
             RGBColor[
              0.2012631111576979, 0.32887066901798323`, 0.9347730084871156], 
             UndirectedEdge[46, 195] -> 
             RGBColor[
              0.2015708688653357, 0.3291941418816762, 0.9347905348332788], 
             UndirectedEdge[73, 177] -> 
             RGBColor[
              0.912733918365472, 0.8408075046276462, 0.6264313427993702], 
             UndirectedEdge[102, 189] -> 
             RGBColor[
              0.27205731447598563`, 0.4032798653172439, 0.9388046336354536], 
             UndirectedEdge[3, 95] -> 
             RGBColor[
              0.5706393994295823, 0.6623097973257487, 0.9593419703255434], 
             UndirectedEdge[39, 294] -> 
             RGBColor[
              0.18656769797512113`, 0.31342485802008435`, 0.9339361264462835],
              UndirectedEdge[5, 227] -> 
             RGBColor[
              0.24495455926499354`, 0.3747931511765599, 0.937261171821121], 
             UndirectedEdge[166, 169] -> 
             RGBColor[
              0.9427417968791698, 0.9548740993356628, 0.9051840770091248], 
             UndirectedEdge[27, 337] -> 
             RGBColor[
              0.8787077642296014, 0.4383681461657731, 0.30965677054087426`], 
             UndirectedEdge[84, 174] -> 
             RGBColor[
              0.3414171398675645, 0.4701400992540484, 0.9429757761424066], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.313125811057198, 0.4456106195888476, 0.9411739913250522], 
             UndirectedEdge[138, 349] -> 
             RGBColor[
              0.19211902352341417`, 0.31925965314570914`, 0.9342522662238085],
              UndirectedEdge[26, 159] -> 
             RGBColor[
              0.18375580691440718`, 0.3104693822310835, 0.9337759934101959], 
             UndirectedEdge[81, 287] -> 
             RGBColor[
              0.1847451216726243, 0.31150921476814825`, 0.9338323334221164], 
             UndirectedEdge[311, 361] -> 
             RGBColor[
              0.2601900040751639, 0.39080656965504246`, 0.9381288078642394], 
             UndirectedEdge[231, 393] -> 
             RGBColor[
              0.18277810360197083`, 0.30944175405974256`, 0.933720314652935], 
             UndirectedEdge[201, 223] -> 
             RGBColor[
              0.9394729571932308, 0.8606549580209606, 0.6167978110210142], 
             UndirectedEdge[180, 267] -> 
             RGBColor[
              0.25726504669656514`, 0.3877322539971262, 0.9379622358686148], 
             UndirectedEdge[217, 264] -> 
             RGBColor[
              0.8581806271651595, 0.8856725444548357, 0.7300501263511203], 
             UndirectedEdge[163, 174] -> 
             RGBColor[
              0.3053955889489409, 0.4350613598921163, 0.9408225323352425], 
             UndirectedEdge[203, 280] -> 
             RGBColor[
              0.23864655232395315`, 0.36816303593078636`, 0.9369019401576887],
              UndirectedEdge[40, 163] -> 
             RGBColor[
              0.3939273213258807, 0.5099037447255685, 0.9469719144794696], 
             UndirectedEdge[14, 62] -> 
             RGBColor[
              0.1928274082051604, 0.3200042103604074, 0.9342926076834728], 
             UndirectedEdge[49, 133] -> 
             RGBColor[
              0.18673252269027052`, 0.31359809924619686`, 0.933945512969975], 
             UndirectedEdge[276, 288] -> 
             RGBColor[
              0.2641141546829352, 0.39493110074932897`, 0.9383522824360913], 
             UndirectedEdge[312, 366] -> 
             RGBColor[
              0.3486542052668462, 0.4758688117654473, 0.9434566755048852], 
             UndirectedEdge[23, 120] -> 
             RGBColor[
              0.40567769043424073`, 0.5225843384798207, 0.9476110227757661], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.18052420551329257`, 0.307072764263149, 0.9335919584911282], 
             UndirectedEdge[73, 399] -> 
             RGBColor[
              0.9285956897332439, 0.7546127344078406, 0.2614046197660328], 
             UndirectedEdge[269, 272] -> 
             RGBColor[
              0.7422573926850033, 0.7985763836214297, 0.9749449381792838], 
             UndirectedEdge[20, 151] -> 
             RGBColor[
              0.19115376674236922`, 0.3182451070680162, 0.9341972962780976], 
             UndirectedEdge[239, 355] -> 
             RGBColor[
              0.8070776560597501, 0.415234178503891, 0.4419068004978779], 
             UndirectedEdge[274, 319] -> 
             RGBColor[
              0.47322013025663245`, 0.583220445923085, 0.9516727685977074], 
             UndirectedEdge[6, 352] -> 
             RGBColor[
              0.27259546821957914`, 0.40384549902267874`, 0.9388352806950242],
              UndirectedEdge[133, 342] -> 
             RGBColor[
              0.18475081584068775`, 0.311515199699814, 0.9338326576965637], 
             UndirectedEdge[290, 318] -> 
             RGBColor[
              0.1963038433293812, 0.3236581640946811, 0.9344905855208723], 
             UndirectedEdge[87, 298] -> 
             RGBColor[
              0.19758831891525655`, 0.325008229375892, 0.9345637345052766], 
             UndirectedEdge[86, 263] -> 
             RGBColor[
              0.4014876492319413, 0.5221701552338829, 0.9468034158808389], 
             UndirectedEdge[109, 191] -> 
             RGBColor[
              0.19427315985261398`, 0.3215237870078299, 0.9343749411009974], 
             UndirectedEdge[84, 238] -> 
             RGBColor[
              0.3144100017377778, 0.44501303039307516`, 0.9413184262912844], 
             UndirectedEdge[21, 244] -> 
             RGBColor[
              0.9589837634229517, 0.9266594522436353, 0.6365010356742713], 
             UndirectedEdge[137, 175] -> 
             RGBColor[
              0.3080574204607164, 0.43874050226861905`, 0.940941847744563], 
             UndirectedEdge[363, 369] -> 
             RGBColor[
              0.20524927327278905`, 0.33306037813821954`, 0.9350000145225716],
              UndirectedEdge[98, 290] -> 
             RGBColor[
              0.19961632362064485`, 0.32713979090418005`, 0.9346792263730843],
              UndirectedEdge[175, 352] -> 
             RGBColor[
              0.2606268889022622, 0.3912657633084208, 0.9381536878088295], 
             UndirectedEdge[121, 319] -> 
             RGBColor[
              0.3821339767558598, 0.5054057883182604, 0.9455705453873072], 
             UndirectedEdge[249, 387] -> 
             RGBColor[
              0.4216012233503626, 0.5373973944320252, 0.9486912790769737], 
             UndirectedEdge[310, 389] -> 
             RGBColor[
              0.24112387106664201`, 0.3707668550004327, 0.9370430197952202], 
             UndirectedEdge[228, 238] -> 
             RGBColor[
              0.24678874654536498`, 0.3767209983024208, 0.9373656260733012], 
             UndirectedEdge[268, 324] -> 
             RGBColor[
              0.6562462626397825, 0.7312424529611288, 0.9664688163111557], 
             UndirectedEdge[144, 368] -> 
             RGBColor[
              0.18786109875542928`, 0.31478430424653414`, 0.934009783707307], 
             UndirectedEdge[137, 278] -> 
             RGBColor[
              0.29631468313808673`, 0.42639814080998684`, 0.9402731162258624],
              UndirectedEdge[127, 298] -> 
             RGBColor[
              0.19590091614963856`, 0.32323466208171286`, 0.9344676394140633],
              UndirectedEdge[131, 228] -> 
             RGBColor[
              0.20842587898456535`, 0.33639919214973135`, 0.9351809175184903],
              UndirectedEdge[278, 314] -> 
             RGBColor[
              0.2454200867859244, 0.3752824501172079, 0.9372876829247517], 
             UndirectedEdge[182, 311] -> 
             RGBColor[
              0.32563786800336725`, 0.45591796242171545`, 0.9419906534014555],
              UndirectedEdge[77, 94] -> 
             RGBColor[
              0.18199794707454847`, 0.3086217600846408, 0.9336758858928365], 
             UndirectedEdge[144, 333] -> 
             RGBColor[
              0.1893313874669234, 0.316329670904003, 0.9340935144743294], 
             UndirectedEdge[166, 197] -> 
             RGBColor[
              0.9770032019247867, 0.9814553758280588, 0.8828706575837489], 
             UndirectedEdge[106, 384] -> 
             RGBColor[
              0.2081882862900271, 0.33614946716352473`, 0.9351673869660233], 
             UndirectedEdge[28, 265] -> 
             RGBColor[
              0.1984857219314811, 0.32595145684458154`, 0.9346148402794617], 
             UndirectedEdge[113, 266] -> 
             RGBColor[
              0.2701389734664643, 0.40126356728639195`, 0.9386953869528927], 
             UndirectedEdge[164, 292] -> 
             RGBColor[
              0.19766905263223078`, 0.3250930856312453, 0.9345683321710234], 
             UndirectedEdge[98, 248] -> 
             RGBColor[
              0.2095071320406308, 0.3375356576670594, 0.9352424932804627], 
             UndirectedEdge[91, 95] -> 
             RGBColor[
              0.5263538722152581, 0.6263568112928946, 0.9558556514000003], 
             UndirectedEdge[155, 342] -> 
             RGBColor[
              0.19539787597679303`, 0.32270593496546307`, 0.9344389920204009],
              UndirectedEdge[47, 209] -> 
             RGBColor[
              0.43947307837840166`, 0.5526061814054317, 0.9499049126595958], 
             UndirectedEdge[2, 360] -> 
             RGBColor[
              0.18511749831467772`, 0.3119006062289892, 0.9338535397209994], 
             UndirectedEdge[75, 341] -> 
             RGBColor[
              0.2771008643732843, 0.406039405513939, 0.9391849149556509], 
             UndirectedEdge[12, 390] -> 
             RGBColor[
              0.28559351861557547`, 0.41750727411286515`, 0.9395755004361839],
              UndirectedEdge[19, 198] -> 
             RGBColor[
              0.30685620721234774`, 0.43573562617248035`, 0.9409372354734161],
              UndirectedEdge[8, 56] -> 
             RGBColor[
              0.30973133616006665`, 0.43613714011801286`, 0.9411969165511169],
              UndirectedEdge[70, 154] -> 
             RGBColor[
              0.21421417432422896`, 0.3424830575508392, 0.9355105523750686], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.18749255911212426`, 0.3143969457146576, 0.9339887959198263], 
             UndirectedEdge[177, 243] -> 
             RGBColor[
              0.9321893579727436, 0.9478941964628581, 0.9631507032012652], 
             UndirectedEdge[109, 340] -> 
             RGBColor[
              0.19212863805325098`, 0.319269758626164, 0.9342528137570594], 
             UndirectedEdge[28, 36] -> 
             RGBColor[
              0.19993330434376533`, 0.3274729577419183, 0.9346972779563351], 
             UndirectedEdge[203, 339] -> 
             RGBColor[
              0.23865240959631934`, 0.3681691922954158, 0.9369022737206849], 
             UndirectedEdge[247, 369] -> 
             RGBColor[
              0.19411283179141248`, 0.32135527205012093`, 0.934365810655096], 
             UndirectedEdge[223, 230] -> 
             RGBColor[
              0.8551262609512963, 0.3448308384131614, 0.19723163473259725`], 
             UndirectedEdge[22, 173] -> 
             RGBColor[
              0.2993775960909632, 0.43129907223111097`, 0.940385972398696], 
             UndirectedEdge[69, 283] -> 
             RGBColor[
              0.22539830685763262`, 0.3542382899584056, 0.9361474721774046], 
             UndirectedEdge[59, 274] -> 
             RGBColor[
              0.41979531196311004`, 0.5369477420873823, 0.9482682580148925], 
             UndirectedEdge[31, 164] -> 
             RGBColor[
              0.19871454021211585`, 0.32619195936544565`, 0.9346278711420376],
              UndirectedEdge[116, 154] -> 
             RGBColor[
              0.19442534169189124`, 0.3216837397697962, 0.9343836076316113], 
             UndirectedEdge[10, 170] -> 
             RGBColor[
              0.2345826966210814, 0.3638916659237347, 0.936670509587346], 
             UndirectedEdge[301, 394] -> 
             RGBColor[
              0.18156448933556574`, 0.30816616851816203`, 0.9336512011158447],
              UndirectedEdge[90, 351] -> 
             RGBColor[
              0.7590840463718008, 0.8119268218437792, 0.9767853326782896], 
             UndirectedEdge[4, 203] -> 
             RGBColor[
              0.22928794206914588`, 0.35832654318282237`, 0.9363689811485005],
              UndirectedEdge[274, 351] -> 
             RGBColor[
              0.7014339552406084, 0.7651238807564681, 0.9722469063252], 
             UndirectedEdge[238, 269] -> 
             RGBColor[
              0.5167818424220354, 0.6108654129881752, 0.9574511707265], 
             UndirectedEdge[66, 325] -> 
             RGBColor[
              0.2517049597881912, 0.3818882501265539, 0.9376455971445944], 
             UndirectedEdge[128, 171] -> 
             RGBColor[
              0.19178726559275905`, 0.3189109545259229, 0.9342333731004496], 
             UndirectedEdge[198, 205] -> 
             RGBColor[
              0.35166297002886326`, 0.47901452236936815`, 0.9436286313802527],
              UndirectedEdge[202, 349] -> 
             RGBColor[
              0.22267250403179975`, 0.35137329836257414`, 0.9359922417389372],
              UndirectedEdge[295, 390] -> 
             RGBColor[
              0.34587288956677426`, 0.46974318811470905`, 0.943415535012837], 
             UndirectedEdge[250, 356] -> 
             RGBColor[
              0.22666963106636354`, 0.3555745323083922, 0.9362198722103361], 
             UndirectedEdge[133, 393] -> 
             RGBColor[
              0.18457522111446595`, 0.3113306385092063, 0.9338226578366745], 
             UndirectedEdge[124, 293] -> 
             RGBColor[
              0.3293119680498331, 0.45965520784915576`, 0.9422044452983639], 
             UndirectedEdge[45, 325] -> 
             RGBColor[
              0.2869742607531359, 0.4189585216435491, 0.9396541316582929], 
             UndirectedEdge[116, 304] -> 
             RGBColor[
              0.18211433978369124`, 0.30874409620167387`, 0.9336825142854346],
              UndirectedEdge[213, 296] -> 
             RGBColor[
              0.2337895217777734, 0.3630579888732283, 0.9366253394534165], 
             UndirectedEdge[248, 276] -> 
             RGBColor[
              0.22042799245848094`, 0.3490141743887628, 0.9358644201252941], 
             UndirectedEdge[209, 346] -> 
             RGBColor[
              0.34295446203942725`, 0.47147165045125694`, 0.9430737329517971],
              UndirectedEdge[31, 382] -> 
             RGBColor[
              0.18918398084593196`, 0.3161747371992214, 0.9340851198853325], 
             UndirectedEdge[69, 373] -> 
             RGBColor[
              0.25683371538447886`, 0.38727889744013877`, 0.937937672188489], 
             UndirectedEdge[166, 239] -> 
             RGBColor[
              0.8817402416283486, 0.4729378739656097, 0.3896280153376859], 
             UndirectedEdge[235, 317] -> 
             RGBColor[
              0.19343401255220036`, 0.32064178999008336`, 0.934327152903646], 
             UndirectedEdge[43, 59] -> 
             RGBColor[
              0.3034359716582913, 0.4327690861148492, 0.9407194513531689], 
             UndirectedEdge[94, 207] -> 
             RGBColor[
              0.18447193191249567`, 0.3112220750090219, 0.933816775669425], 
             UndirectedEdge[209, 270] -> 
             RGBColor[
              0.34697087401529814`, 0.4749504646340207, 0.9433296551713259], 
             UndirectedEdge[23, 341] -> 
             RGBColor[
              0.3146456284168403, 0.44550133299924655`, 0.9413230337254305], 
             UndirectedEdge[264, 312] -> 
             RGBColor[
              0.5131003370105822, 0.6097335825641022, 0.9568081018654329], 
             UndirectedEdge[48, 118] -> 
             RGBColor[
              0.23953466514577643`, 0.3690964988161278, 0.9369525168690463], 
             UndirectedEdge[106, 310] -> 
             RGBColor[
              0.2532088981789974, 0.38346898473049273`, 0.9377312442110733], 
             UndirectedEdge[267, 282] -> 
             RGBColor[
              0.2615646860965489, 0.39225144761939246`, 0.9382070939716974], 
             UndirectedEdge[43, 274] -> 
             RGBColor[
              0.3767191464303865, 0.4951636983486218, 0.9456872845015338], 
             UndirectedEdge[46, 362] -> 
             RGBColor[
              0.19522925834887567`, 0.3225287071475469, 0.9344293894959386], 
             UndirectedEdge[38, 117] -> 
             RGBColor[
              0.22453541604736282`, 0.35333133700637476`, 0.9360983318222922],
              UndirectedEdge[252, 300] -> 
             RGBColor[
              0.6421328397168371, 0.7146709767757251, 0.9682477279637229], 
             UndirectedEdge[7, 67] -> 
             RGBColor[
              0.43693392935130804`, 0.5528719414914377, 0.9490620215061302], 
             UndirectedEdge[150, 192] -> 
             RGBColor[
              0.1875835174154828, 0.3144925486585769, 0.9339939758606419], 
             UndirectedEdge[239, 272] -> 
             RGBColor[
              0.7988197048562442, 0.4087830042609585, 0.441083725096854], 
             UndirectedEdge[22, 209] -> 
             RGBColor[
              0.32555893410641223`, 0.4564045184803353, 0.9419653052941668], 
             UndirectedEdge[167, 246] -> 
             RGBColor[
              0.6152498673613919, 0.6911955828537762, 0.9666225650716829], 
             UndirectedEdge[131, 140] -> 
             RGBColor[
              0.21947779992995464`, 0.3480154617955958, 0.9358103080664784], 
             UndirectedEdge[67, 385] -> 
             RGBColor[
              0.7098239251190117, 0.7666063809986858, 0.7914621261134387], 
             UndirectedEdge[60, 101] -> 
             RGBColor[
              0.18455258152934814`, 0.31130684286981486`, 0.9338213685457943],
              UndirectedEdge[113, 249] -> 
             RGBColor[
              0.3083010067824331, 0.4413437356356376, 0.9408697768166884], 
             UndirectedEdge[52, 393] -> 
             RGBColor[
              0.18136432541177624`, 0.30795578354313347`, 0.9336398020765009],
              UndirectedEdge[99, 367] -> 
             RGBColor[
              0.6703595369678017, 0.7365958473458555, 0.9440864000727226], 
             UndirectedEdge[5, 43] -> 
             RGBColor[
              0.2713996679468782, 0.4025886371179538, 0.9387671816385219], 
             UndirectedEdge[26, 105] -> 
             RGBColor[
              0.19823757833601402`, 0.32569064219253296`, 0.9346007088687955],
              UndirectedEdge[128, 306] -> 
             RGBColor[
              0.1986620698216136, 0.3261368096582128, 0.9346248830309214], 
             UndirectedEdge[226, 281] -> 
             RGBColor[
              0.43696413947427415`, 0.552898107981546, 0.9490639464684518], 
             UndirectedEdge[63, 345] -> 
             RGBColor[
              0.18008431245353695`, 0.306610408766515, 0.9335669072321386], 
             UndirectedEdge[4, 280] -> 
             RGBColor[
              0.24217745234544014`, 0.3718742357253608, 0.937103019690414], 
             UndirectedEdge[7, 223] -> 
             RGBColor[
              0.6892737381041355, 0.6614040887409706, 0.6061320446993241], 
             UndirectedEdge[155, 361] -> 
             RGBColor[
              0.21235865222551553`, 0.3405327861781953, 0.9354048831365458], 
             UndirectedEdge[252, 398] -> 
             RGBColor[
              0.39783022825914727`, 0.5190022810145718, 0.9465703682505828], 
             UndirectedEdge[6, 252] -> 
             RGBColor[
              0.3375773650971563, 0.4665223484650306, 0.9427417981088295], 
             UndirectedEdge[260, 307] -> 
             RGBColor[
              0.28646815305242945`, 0.41476449327789777`, 0.9397593961545982],
              UndirectedEdge[21, 357] -> 
             RGBColor[
              0.892467694136608, 0.589114704834069, 0.2387243833179241], 
             UndirectedEdge[233, 366] -> 
             RGBColor[
              0.6769028781273625, 0.7426382888986862, 0.9499751965434602], 
             UndirectedEdge[37, 41] -> 
             RGBColor[
              0.6103348144421008, 0.6886019294831773, 0.9655435733376975], 
             UndirectedEdge[173, 176] -> 
             RGBColor[
              0.25807437232061936`, 0.38858290654221544`, 0.9380083257656147],
              UndirectedEdge[60, 136] -> 
             RGBColor[
              0.18529719032077357`, 0.3120894739205271, 0.933863772914916], 
             UndirectedEdge[74, 285] -> 
             RGBColor[
              0.9286295448374513, 0.9418226643023089, 0.7983899704135337], 
             UndirectedEdge[234, 395] -> 
             RGBColor[
              0.6271808306424103, 0.7060165287006694, 0.9652946384160161], 
             UndirectedEdge[17, 164] -> 
             RGBColor[
              0.21631448031938844`, 0.34469061231884324`, 0.9356301616943686],
              UndirectedEdge[20, 383] -> 
             RGBColor[
              0.1993210537450841, 0.3268294435437743, 0.9346624111904838], 
             UndirectedEdge[19, 219] -> 
             RGBColor[
              0.2987647907941907, 0.4287272479574868, 0.9404216575742097], 
             UndirectedEdge[91, 279] -> 
             RGBColor[
              0.5827660155833214, 0.6716970806233367, 0.9606095197706748], 
             UndirectedEdge[76, 207] -> 
             RGBColor[
              0.1908268877624048, 0.3179015365347492, 0.9341786810037627], 
             UndirectedEdge[238, 339] -> 
             RGBColor[
              0.27076497929052823`, 0.4019215390985449, 0.9387310370584805], 
             UndirectedEdge[142, 379] -> 
             RGBColor[
              0.1947953347030193, 0.32207262588340363`, 0.9344046781862394], 
             UndirectedEdge[205, 219] -> 
             RGBColor[
              0.34357155361070624`, 0.4720061441543746, 0.9431130534810463], 
             UndirectedEdge[7, 68] -> 
             RGBColor[
              0.3593357938245753, 0.4820804322688437, 0.9442486147652995], 
             UndirectedEdge[188, 273] -> 
             RGBColor[
              0.19180481699179464`, 0.3189294021591323, 0.9342343726266598], 
             UndirectedEdge[16, 69] -> 
             RGBColor[
              0.2797958916834022, 0.41057876108804503`, 0.9392759017239116], 
             UndirectedEdge[118, 323] -> 
             RGBColor[
              0.3187861771861727, 0.44407882697168544`, 0.9417702640466686], 
             UndirectedEdge[211, 263] -> 
             RGBColor[
              0.30692109574993276`, 0.4322308872824815, 0.9410717536469021], 
             UndirectedEdge[191, 340] -> 
             RGBColor[
              0.2050792556090335, 0.33288167879387, 0.9349903322681394], 
             UndirectedEdge[33, 182] -> 
             RGBColor[
              0.3125367270389322, 0.44214783260778046`, 0.9412445628049322], 
             UndirectedEdge[99, 300] -> 
             RGBColor[
              0.9401681906865148, 0.9543565949425481, 0.9673889822446275], 
             UndirectedEdge[11, 91] -> 
             RGBColor[
              0.40263125450178067`, 0.5220751425472069, 0.9471762250170271], 
             UndirectedEdge[78, 233] -> 
             RGBColor[
              0.8664271702758672, 0.42591833001448076`, 0.4290165805257541], 
             UndirectedEdge[27, 172] -> 
             RGBColor[
              0.8219598998063007, 0.16979898956648984`, 0.1686621308956602], 
             UndirectedEdge[313, 396] -> 
             RGBColor[
              0.20896253735329678`, 0.3369632541213739, 0.9352114794186747], 
             UndirectedEdge[74, 172] -> 
             RGBColor[
              0.8368888345678879, 0.4205266273042264, 0.4425517456269674], 
             UndirectedEdge[217, 366] -> 
             RGBColor[
              0.6937344954214235, 0.7518077736561808, 0.7166986999905727], 
             UndirectedEdge[277, 302] -> 
             RGBColor[
              0.19959521355734036`, 0.32711760288919167`, 0.9346780241862087],
              UndirectedEdge[203, 232] -> 
             RGBColor[
              0.26042493590475796`, 0.3910534979034842, 0.9381421868843842], 
             UndirectedEdge[27, 285] -> 
             RGBColor[
              0.8787585038612737, 0.43847667310735655`, 0.31517946631969995`],
              UndirectedEdge[193, 334] -> 
             RGBColor[
              0.1859629402627897, 0.3127892193205704, 0.9339016863892251], 
             UndirectedEdge[39, 381] -> 
             RGBColor[
              0.18966952552711056`, 0.31668507544445096`, 0.9341127709366266],
              UndirectedEdge[270, 390] -> 
             RGBColor[
              0.310905083152461, 0.4394558317316838, 0.9411874173089341], 
             UndirectedEdge[35, 42] -> 
             RGBColor[
              0.22638274960055194`, 0.35527300169848874`, 0.9362035347352613],
              UndirectedEdge[41, 245] -> 
             RGBColor[
              0.8365103724506917, 0.3973845200409797, 0.4396570019745871], 
             UndirectedEdge[45, 276] -> 
             RGBColor[
              0.2538332616499947, 0.38412523032544144`, 0.9377668007870836], 
             UndirectedEdge[17, 241] -> 
             RGBColor[
              0.2474447922190557, 0.37741054390116785`, 0.9374029869038852], 
             UndirectedEdge[69, 347] -> 
             RGBColor[
              0.21983376516516337`, 0.34838960382729967`, 0.9358305797600202],
              UndirectedEdge[16, 295] -> 
             RGBColor[
              0.3734051820083968, 0.4978465335906915, 0.9450140259017055], 
             UndirectedEdge[190, 351] -> 
             RGBColor[
              0.9330043693197932, 0.948887212220239, 0.9751255904637988], 
             UndirectedEdge[112, 141] -> 
             RGBColor[
              0.8894343136228475, 0.5845146463127493, 0.22912699183884946`], 
             UndirectedEdge[135, 400] -> 
             RGBColor[
              0.8983997399580361, 0.588258391075905, 0.357119464612347], 
             UndirectedEdge[295, 310] -> 
             RGBColor[
              0.3543169737444146, 0.4786184559712684, 0.9438964131148506], 
             UndirectedEdge[185, 249] -> 
             RGBColor[
              0.35433837255967027`, 0.48133182157191207`, 0.9437991056637501],
              UndirectedEdge[93, 98] -> 
             RGBColor[
              0.21766781953393055`, 0.3461130576399892, 0.9357072323605509], 
             UndirectedEdge[221, 268] -> 
             RGBColor[
              0.7908356351545234, 0.6993648502734382, 0.6044361277879526], 
             UndirectedEdge[265, 291] -> 
             RGBColor[
              0.18857894058274138`, 0.31553880152083974`, 0.9340506637374206],
              UndirectedEdge[128, 133] -> 
             RGBColor[
              0.19019948162046302`, 0.31724209289972144`, 0.9341429511521433],
              UndirectedEdge[57, 333] -> 
             RGBColor[
              0.2028967340448986, 0.3305877102501046, 0.9348660408938132], 
             UndirectedEdge[28, 378] -> 
             RGBColor[
              0.19890365407675165`, 0.32639073002768937`, 0.9346386408968597],
              UndirectedEdge[92, 386] -> 
             RGBColor[
              0.6290755332185833, 0.7079371215448762, 0.9651823556220622], 
             UndirectedEdge[35, 248] -> 
             RGBColor[
              0.22712519699410227`, 0.3560533609829937, 0.9362458160159715], 
             UndirectedEdge[56, 175] -> 
             RGBColor[
              0.331650883280764, 0.45917597392142306`, 0.9424452023325764], 
             UndirectedEdge[3, 21] -> 
             RGBColor[
              0.7725354937206939, 0.7794802979389553, 0.6358867741972027], 
             UndirectedEdge[98, 204] -> 
             RGBColor[
              0.19732498772567109`, 0.3247314515994759, 0.9345487381835933], 
             UndirectedEdge[243, 367] -> 
             RGBColor[
              0.6723041775720541, 0.7380461571244501, 0.9407946307732227], 
             UndirectedEdge[48, 209] -> 
             RGBColor[
              0.2875152720132881, 0.41711435878234465`, 0.9397732858765137], 
             UndirectedEdge[116, 291] -> 
             RGBColor[
              0.1852566513830322, 0.31204686492664385`, 0.9338614642823836], 
             UndirectedEdge[214, 340] -> 
             RGBColor[
              0.22133989504081186`, 0.3499726418207558, 0.9359163516283189], 
             UndirectedEdge[138, 159] -> 
             RGBColor[
              0.18138230828610377`, 0.30797468468423184`, 0.9336408261745905],
              UndirectedEdge[22, 48] -> 
             RGBColor[
              0.27823170323432733`, 0.40907339811174287`, 0.9391817450830557],
              UndirectedEdge[13, 297] -> 
             RGBColor[
              0.2105416090442786, 0.33862295858752356`, 0.9353014052154489], 
             UndirectedEdge[192, 347] -> 
             RGBColor[
              0.18973620095672017`, 0.3167551555484371, 0.9341165680037053], 
             UndirectedEdge[4, 322] -> 
             RGBColor[
              0.21636197354501668`, 0.3447405307102229, 0.9356328663633082], 
             UndirectedEdge[111, 304] -> 
             RGBColor[
              0.18507047905985996`, 0.31185118601098283`, 0.9338508620439963],
              UndirectedEdge[133, 361] -> 
             RGBColor[
              0.20171159208941025`, 0.3293420509125463, 0.9347985488127086], 
             UndirectedEdge[4, 186] -> 
             RGBColor[
              0.2198352252877424, 0.3483911385087073, 0.9358306629118409], 
             UndirectedEdge[73, 240] -> 
             RGBColor[
              0.8646643880160767, 0.41726031379920236`, 0.20632898974830338`],
              UndirectedEdge[82, 335] -> 
             RGBColor[
              0.18011477786530028`, 0.30664242984589696`, 0.933568642192269], 
             UndirectedEdge[184, 372] -> 
             RGBColor[
              0.18858940025952037`, 0.31554979530431626`, 0.9340512594005395],
              UndirectedEdge[85, 340] -> 
             RGBColor[
              0.22184000451345684`, 0.35049828858527765`, 0.9359448321229403],
              UndirectedEdge[344, 388] -> 
             RGBColor[
              0.20538183242077535`, 0.3331997062074885, 0.9350075635699459], 
             UndirectedEdge[57, 228] -> 
             RGBColor[
              0.21063806848440092`, 0.33872434357497383`, 0.9353068984378649],
              UndirectedEdge[36, 80] -> 
             RGBColor[
              0.1863429465695527, 0.31318863004276976`, 0.9339233271862263], 
             UndirectedEdge[88, 365] -> 
             RGBColor[
              0.18619994968916187`, 0.3130383312549531, 0.9339151837254329], 
             UndirectedEdge[209, 241] -> 
             RGBColor[
              0.2990278699570904, 0.4292148291621499, 0.9404289112980508], 
             UndirectedEdge[49, 62] -> 
             RGBColor[
              0.19439182652115503`, 0.3216485132003679, 0.9343816989922191], 
             UndirectedEdge[161, 250] -> 
             RGBColor[
              0.22890128499152032`, 0.3579201420787632, 0.9363469615999377], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.19292841019979173`, 0.32011036986066127`, 0.934298359597648], 
             UndirectedEdge[324, 346] -> 
             RGBColor[
              0.4920980261552287, 0.5957700021570038, 0.9539260250446029], 
             UndirectedEdge[142, 258] -> 
             RGBColor[
              0.18294835007904106`, 0.30962069390139346`, 0.9337300099379471],
              UndirectedEdge[44, 46] -> 
             RGBColor[
              0.2189840028439955, 0.34749644974970917`, 0.9357821870529404], 
             UndirectedEdge[85, 191] -> 
             RGBColor[
              0.22398452631281984`, 0.35275231696694354`, 0.9360669594668783],
              UndirectedEdge[112, 172] -> 
             RGBColor[
              0.8615714412625748, 0.3854319686876351, 0.20303610853129658`], 
             UndirectedEdge[133, 298] -> 
             RGBColor[
              0.1913924314057353, 0.3184959587614276, 0.9342108878776034], 
             UndirectedEdge[26, 215] -> 
             RGBColor[
              0.18499791179933114`, 0.3117749132191369, 0.9338467294458628], 
             UndirectedEdge[127, 129] -> 
             RGBColor[
              0.19194623803100921`, 0.3190780446379586, 0.9342424263456293], 
             UndirectedEdge[172, 225] -> 
             RGBColor[
              0.8441055756294294, 0.42628106073348204`, 0.44324008483187805`],
              UndirectedEdge[38, 376] -> 
             RGBColor[
              0.21626586560617583`, 0.3446395151729059, 0.9356273931583702], 
             UndirectedEdge[158, 346] -> 
             RGBColor[
              0.34491127963015633`, 0.47316654749583464`, 0.9431984196383325],
              UndirectedEdge[340, 370] -> 
             RGBColor[
              0.19501122587610803`, 0.3222995411946109, 0.9344169728691645], 
             UndirectedEdge[44, 266] -> 
             RGBColor[
              0.23471345152571355`, 0.36402909761884283`, 0.9366779558857301],
              UndirectedEdge[183, 238] -> 
             RGBColor[
              0.31998454354214334`, 0.4498414183193987, 0.9416736311656848], 
             UndirectedEdge[21, 264] -> 
             RGBColor[
              0.8432468849976082, 0.8356472056673055, 0.6423010818703361], 
             UndirectedEdge[13, 140] -> 
             RGBColor[
              0.2199309237526768, 0.34849172366298653`, 0.9358361127978458], 
             UndirectedEdge[210, 266] -> 
             RGBColor[
              0.26920304414348, 0.40027984622658896`, 0.9386420871625321], 
             UndirectedEdge[51, 395] -> 
             RGBColor[
              0.4251084428470847, 0.5422133005057554, 0.9484234537100807], 
             UndirectedEdge[358, 372] -> 
             RGBColor[
              0.19242209071206384`, 0.3195781959765495, 0.9342695254518545], 
             UndirectedEdge[174, 309] -> 
             RGBColor[
              0.32079650085916334`, 0.45124869478397367`, 0.9416995914849222],
              UndirectedEdge[65, 363] -> 
             RGBColor[
              0.25392355034044856`, 0.38422012946374207`, 0.9377719425944349],
              UndirectedEdge[236, 267] -> 
             RGBColor[
              0.25338105975763014`, 0.38364993746531034`, 0.9377410485582862],
              UndirectedEdge[227, 352] -> 
             RGBColor[
              0.22353600409255178`, 0.3522808916754905, 0.9360414167899633], 
             UndirectedEdge[2, 370] -> 
             RGBColor[
              0.18603673488354355`, 0.3128667821458319, 0.9339058888837076], 
             UndirectedEdge[17, 354] -> 
             RGBColor[
              0.2237645258481464, 0.35252108252973663`, 0.9360544307658767], 
             UndirectedEdge[133, 306] -> 
             RGBColor[
              0.1942497780329075, 0.32149921123282543`, 0.9343736095409554], 
             UndirectedEdge[105, 261] -> 
             RGBColor[
              0.23472290345765154`, 0.3640390321985968, 0.9366784941592712], 
             UndirectedEdge[120, 206] -> 
             RGBColor[
              0.624306194339526, 0.7045315727086937, 0.9644880050917888], 
             UndirectedEdge[361, 393] -> 
             RGBColor[
              0.20049962337211924`, 0.32806819494741857`, 0.934729528987206], 
             UndirectedEdge[270, 295] -> 
             RGBColor[
              0.3940670515595366, 0.5157428065001295, 0.9463305819589302], 
             UndirectedEdge[9, 283] -> 
             RGBColor[
              0.2000074908485974, 0.3275509324621929, 0.9347015027680361], 
             UndirectedEdge[43, 122] -> 
             RGBColor[
              0.42916131354223347`, 0.5377386121027248, 0.9498157239985662], 
             UndirectedEdge[127, 336] -> 
             RGBColor[
              0.18757872554421223`, 0.31448751209804937`, 0.933993702970662], 
             UndirectedEdge[4, 123] -> 
             RGBColor[
              0.2222583366495916, 0.3509379821841447, 0.9359686555192263], 
             UndirectedEdge[45, 279] -> 
             RGBColor[
              0.4785218001436983, 0.5802784243797845, 0.9537482634423509], 
             UndirectedEdge[135, 255] -> 
             RGBColor[
              0.8885216832896912, 0.5123313189309725, 0.3476602263910705], 
             UndirectedEdge[152, 180] -> 
             RGBColor[
              0.2576563148367751, 0.3881435016203197, 0.9379845180103705], 
             UndirectedEdge[48, 68] -> 
             RGBColor[
              0.2551071510734325, 0.38546416887872903`, 0.937839346905198], 
             UndirectedEdge[362, 363] -> 
             RGBColor[
              0.20453297478611288`, 0.3323075030127757, 0.9349592223834241], 
             UndirectedEdge[18, 257] -> 
             RGBColor[
              0.46412234198098856`, 0.5722988469015355, 0.9519334554771259], 
             UndirectedEdge[72, 109] -> 
             RGBColor[
              0.18206833162796426`, 0.3086957387129193, 0.933679894189029], 
             UndirectedEdge[181, 211] -> 
             RGBColor[
              0.20840661341018846`, 0.33637894280955327`, 0.9351798203725303],
              UndirectedEdge[82, 259] -> 
             RGBColor[
              0.1834817429881715, 0.31018132366795326`, 0.9337603858750381], 
             UndirectedEdge[282, 367] -> 
             RGBColor[
              0.3211123825917724, 0.44870662104929115`, 0.9418228148301714], 
             UndirectedEdge[44, 363] -> 
             RGBColor[
              0.22828771928123268`, 0.35727524561493795`, 0.9363120199404259],
              UndirectedEdge[139, 290] -> 
             RGBColor[
              0.19313846063632573`, 0.32033114618742536`, 0.9343103216592668],
              UndirectedEdge[255, 351] -> 
             RGBColor[
              0.8601707384003942, 0.4921743089242222, 0.4514161861788524], 
             UndirectedEdge[290, 345] -> 
             RGBColor[
              0.18860221988526102`, 0.31556326954378094`, 0.9340519894592605],
              UndirectedEdge[145, 200] -> 
             RGBColor[
              0.19073593578989534`, 0.3178059402449537, 0.9341735014234795], 
             UndirectedEdge[44, 316] -> 
             RGBColor[
              0.23551418105696653`, 0.3648707151253743, 0.9367235562479619], 
             UndirectedEdge[172, 240] -> 
             RGBColor[
              0.8264317919518623, 0.2041719121929097, 0.17294441986452982`], 
             UndirectedEdge[89, 299] -> 
             RGBColor[
              0.18845360021131413`, 0.3154070608434312, 0.9340435257886923], 
             UndirectedEdge[119, 196] -> 
             RGBColor[
              0.18607572050979368`, 0.3129077585108523, 0.9339081090574485], 
             UndirectedEdge[149, 369] -> 
             RGBColor[
              0.20360056980323105`, 0.3313274862578765, 0.9349061232990186], 
             UndirectedEdge[32, 385] -> 
             RGBColor[
              0.9757287822359568, 0.928603231512897, 0.461093645269188], 
             UndirectedEdge[149, 253] -> 
             RGBColor[
              0.20384820267597584`, 0.3315877641079622, 0.9349202256247814], 
             UndirectedEdge[317, 336] -> 
             RGBColor[
              0.1878536669894908, 0.3147764929893316, 0.9340093604792311], 
             UndirectedEdge[138, 215] -> 
             RGBColor[
              0.18262441317102773`, 0.30928021567228525`, 0.9337115622102574],
              UndirectedEdge[157, 181] -> 
             RGBColor[
              0.19115892919796787`, 0.31825053313616897`, 0.9341975902723066],
              UndirectedEdge[299, 342] -> 
             RGBColor[
              0.18568831496489116`, 0.3125005707202294, 0.9338860468847814], 
             UndirectedEdge[108, 198] -> 
             RGBColor[
              0.3047308678845767, 0.4335017597846965, 0.9408162005428573], 
             UndirectedEdge[152, 367] -> 
             RGBColor[
              0.31592573046277495`, 0.4432551208089762, 0.9415274426643891], 
             UndirectedEdge[17, 118] -> 
             RGBColor[
              0.23527881827982655`, 0.36462333392373825`, 0.9367101526859918],
              UndirectedEdge[44, 68] -> 
             RGBColor[
              0.25335041241870687`, 0.38361772516894843`, 0.9377393032376733],
              UndirectedEdge[158, 323] -> 
             RGBColor[
              0.3687236016444134, 0.49379158398248, 0.9447157197406713], 
             UndirectedEdge[343, 359] -> 
             RGBColor[
              0.18461240578101906`, 0.3113697219513976, 0.933824775448425], 
             UndirectedEdge[354, 388] -> 
             RGBColor[
              0.21768345542489445`, 0.346129491952765, 0.93570812280141], 
             UndirectedEdge[382, 389] -> 
             RGBColor[
              0.1922700735577051, 0.31941841630887424`, 0.9342608682998029], 
             UndirectedEdge[178, 319] -> 
             RGBColor[
              0.4475260102308348, 0.5620450810151163, 0.9497372679364278], 
             UndirectedEdge[15, 386] -> 
             RGBColor[
              0.5232931103169385, 0.6153912271159707, 0.9581889419192983], 
             UndirectedEdge[27, 104] -> 
             RGBColor[
              0.8203618654395438, 0.15751579716047157`, 0.16713185138133213`],
              UndirectedEdge[236, 398] -> 
             RGBColor[
              0.3384347985138768, 0.4621971627307483, 0.9429819918755249], 
             UndirectedEdge[151, 304] -> 
             RGBColor[
              0.1864549217267703, 0.3133063230326405, 0.9339297040057775], 
             UndirectedEdge[21, 233] -> 
             RGBColor[
              0.9613042288478943, 0.9283900515581442, 0.6325730929841542], 
             UndirectedEdge[120, 321] -> 
             RGBColor[
              0.5363303582199404, 0.6344561720670685, 0.9566410369233613], 
             UndirectedEdge[170, 299] -> 
             RGBColor[
              0.20966330069407968`, 0.3376998008234987, 0.9352513868542458], 
             UndirectedEdge[97, 109] -> 
             RGBColor[
              0.18710606140703578`, 0.3139907121212397, 0.9339667854472937], 
             UndirectedEdge[251, 381] -> 
             RGBColor[
              0.19321867549075944`, 0.3204154570853507, 0.9343148897765596], 
             UndirectedEdge[134, 392] -> 
             RGBColor[
              0.9110260493239869, 0.9293182372189884, 0.8905829197640283], 
             UndirectedEdge[132, 220] -> 
             RGBColor[
              0.4970479670019815, 0.5999842739295098, 0.9542616336741748], 
             UndirectedEdge[102, 167] -> 
             RGBColor[
              0.29386288759542795`, 0.42605944514024496`, 0.9400515350827954],
              UndirectedEdge[270, 373] -> 
             RGBColor[
              0.31547519929516016`, 0.44425931355976, 0.9414476786623798], 
             UndirectedEdge[122, 351] -> 
             RGBColor[
              0.7538761223524553, 0.8076987945105711, 0.9763753458222324], 
             UndirectedEdge[96, 173] -> 
             RGBColor[
              0.515339475447038, 0.6087263479834802, 0.9574676673643785], 
             UndirectedEdge[253, 266] -> 
             RGBColor[
              0.21192263839001468`, 0.3400745079922101, 0.9353800527936387], 
             UndirectedEdge[217, 230] -> 
             RGBColor[
              0.8761820738662044, 0.4207616593515645, 0.27209490569893346`], 
             UndirectedEdge[118, 158] -> 
             RGBColor[
              0.28881871360859035`, 0.41812251622929797`, 0.9398607637666927],
              UndirectedEdge[208, 230] -> 
             RGBColor[
              0.876163969591323, 0.42202658470411747`, 0.3648858558318596], 
             UndirectedEdge[86, 179] -> 
             RGBColor[
              0.4324853651691194, 0.5490017107824403, 0.9487832899231066], 
             UndirectedEdge[185, 284] -> 
             RGBColor[
              0.33809952087216233`, 0.4642943071241772, 0.9428732085612545], 
             UndirectedEdge[279, 399] -> 
             RGBColor[
              0.7994051322415094, 0.7452396599077329, 0.6138726305595152], 
             UndirectedEdge[167, 309] -> 
             RGBColor[
              0.30392546223642514`, 0.4366358490920146, 0.940624583822355], 
             UndirectedEdge[174, 183] -> 
             RGBColor[
              0.34699168167192995`, 0.474968487180372, 0.943330981016807], 
             UndirectedEdge[149, 247] -> 
             RGBColor[
              0.20711572977977888`, 0.33502214226724336`, 0.9351063064594698],
              UndirectedEdge[297, 339] -> 
             RGBColor[
              0.22923415063680755`, 0.358270004976861, 0.9363659178060062], 
             UndirectedEdge[28, 282] -> 
             RGBColor[
              0.2370656602671769, 0.3665014181447689, 0.9368119106937756], 
             UndirectedEdge[35, 125] -> 
             RGBColor[
              0.24888171485109623`, 0.37892084069359944`, 0.9374848175220434],
              UndirectedEdge[119, 231] -> 
             RGBColor[
              0.18230446054106692`, 0.30894392517202796`, 0.9336933413813087],
              UndirectedEdge[257, 309] -> 
             RGBColor[
              0.31035046981038367`, 0.4422008677223072, 0.9410339796235565], 
             UndirectedEdge[153, 161] -> 
             RGBColor[
              0.1909498488692258, 0.3180307764542026, 0.9341856834568915], 
             UndirectedEdge[315, 369] -> 
             RGBColor[
              0.20472182801530026`, 0.332505999730638, 0.934969977295443], 
             UndirectedEdge[145, 207] -> 
             RGBColor[
              0.19250737674757545`, 0.31966783700731927`, 0.9342743823654074],
              UndirectedEdge[75, 215] -> 
             RGBColor[
              0.20048155521420025`, 0.3280492041678583, 0.9347285000323418], 
             UndirectedEdge[155, 199] -> 
             RGBColor[
              0.1967855567491959, 0.3241644754413012, 0.9345180183874995], 
             UndirectedEdge[28, 151] -> 
             RGBColor[
              0.19950401467485102`, 0.3270217470813523, 0.9346728305447676], 
             UndirectedEdge[141, 279] -> 
             RGBColor[
              0.801143090532162, 0.5696856585664152, 0.46236431184102655`], 
             UndirectedEdge[347, 380] -> 
             RGBColor[
              0.20898774598358635`, 0.3369897499901277, 0.9352129150128767], 
             UndirectedEdge[107, 346] -> 
             RGBColor[
              0.3498425512041035, 0.47743776708027175`, 0.9435126359024721], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.684630729662244, 0.7517566465973935, 0.970608286963019], 
             UndirectedEdge[171, 299] -> 
             RGBColor[
              0.18831247292825637`, 0.31525872712095093`, 0.9340354887987012],
              UndirectedEdge[283, 294] -> 
             RGBColor[
              0.19947004944091673`, 0.32698604746696713`, 0.934670896274942], 
             UndirectedEdge[83, 244] -> 
             RGBColor[
              0.9498999569574745, 0.9621560504469515, 0.9696904840737579], 
             UndirectedEdge[112, 179] -> 
             RGBColor[
              0.6955279730573865, 0.6779676106196408, 0.6092046613657698], 
             UndirectedEdge[42, 93] -> 
             RGBColor[
              0.22541709987581074`, 0.35425804261205696`, 0.936148542411988], 
             UndirectedEdge[94, 254] -> 
             RGBColor[
              0.18421702339867016`, 0.31095414999885795`, 0.9338022590066659],
              UndirectedEdge[84, 222] -> 
             RGBColor[
              0.2856119220562171, 0.4147444227440439, 0.9396784182563604], 
             UndirectedEdge[132, 366] -> 
             RGBColor[
              0.3763364091715497, 0.5003854152316536, 0.9452008011045592], 
             UndirectedEdge[52, 133] -> 
             RGBColor[
              0.18257629412906723`, 0.3092296395082612, 0.9337088219020035], 
             UndirectedEdge[255, 400] -> 
             RGBColor[
              0.840300424061758, 0.3107722958629089, 0.1862250376353455], 
             UndirectedEdge[276, 318] -> 
             RGBColor[
              0.20862378443178675`, 0.3366072033226911, 0.9351921879409346], 
             UndirectedEdge[235, 313] -> 
             RGBColor[
              0.2049405983747336, 0.3327359412492443, 0.9349824359437711], 
             UndirectedEdge[218, 229] -> 
             RGBColor[
              0.19887179747769093`, 0.3263572467222515, 0.9346368267106708], 
             UndirectedEdge[202, 260] -> 
             RGBColor[
              0.23397057730885262`, 0.3632482897159762, 0.9366356502980638], 
             UndirectedEdge[129, 216] -> 
             RGBColor[
              0.1943994825815768, 0.32165656020529343`, 0.9343821349935341], 
             UndirectedEdge[307, 312] -> 
             RGBColor[
              0.32563175741045036`, 0.45592792457411196`, 0.9419897054854269],
              UndirectedEdge[215, 349] -> 
             RGBColor[
              0.192491042377818, 0.3196506685490453, 0.9342734521472142], 
             UndirectedEdge[48, 61] -> 
             RGBColor[
              0.22477630942984533`, 0.3535845312248864, 0.9361120503440548], 
             UndirectedEdge[198, 284] -> 
             RGBColor[
              0.31495346164278715`, 0.44424635397445533`, 0.9413983621344152],
              UndirectedEdge[37, 256] -> 
             RGBColor[
              0.3500537032004466, 0.4776206563266962, 0.9435260903209648], 
             UndirectedEdge[260, 366] -> 
             RGBColor[
              0.3094906009088253, 0.4347053804692331, 0.9412263661740565], 
             UndirectedEdge[35, 263] -> 
             RGBColor[
              0.31410208852609794`, 0.43977856599147, 0.9414807005621779], 
             UndirectedEdge[124, 185] -> 
             RGBColor[
              0.35466498690371884`, 0.48161471850061266`, 0.9438199172409392],
              UndirectedEdge[17, 48] -> 
             RGBColor[
              0.23593219427525336`, 0.3653100735213626, 0.936747361482348], 
             UndirectedEdge[98, 139] -> 
             RGBColor[
              0.19453754132088114`, 0.32180166869373195`, 0.9343899972344978],
              UndirectedEdge[98, 125] -> 
             RGBColor[
              0.23126364989762477`, 0.3604031373776651, 0.9364814947865346], 
             UndirectedEdge[195, 397] -> 
             RGBColor[
              0.2073858256728759, 0.33530603017595706`, 0.9351216880210106], 
             UndirectedEdge[152, 198] -> 
             RGBColor[
              0.3050387614583694, 0.43382537545233274`, 0.9408337346263971], 
             UndirectedEdge[29, 129] -> 
             RGBColor[
              0.18526332309430954`, 0.3120538773182072, 0.933861844226471], 
             UndirectedEdge[83, 230] -> 
             RGBColor[
              0.8601703747775189, 0.411075832295422, 0.43572184164473515`], 
             UndirectedEdge[10, 155] -> 
             RGBColor[
              0.22229114501906733`, 0.3509724658606344, 0.9359705239073323], 
             UndirectedEdge[210, 316] -> 
             RGBColor[
              0.270003773674733, 0.40112146373312046`, 0.9386876875247638], 
             UndirectedEdge[6, 175] -> 
             RGBColor[
              0.2936199376985361, 0.4259435494734196, 0.9400325931289355], 
             UndirectedEdge[301, 343] -> 
             RGBColor[
              0.18235879982602854`, 0.30900103920583233`, 0.9336964359231994],
              UndirectedEdge[140, 297] -> 
             RGBColor[
              0.21630983883703356`, 0.3446857338266013, 0.935629897368815], 
             UndirectedEdge[274, 295] -> 
             RGBColor[
              0.4610566723545275, 0.5726862586021548, 0.9508973954130453], 
             UndirectedEdge[61, 371] -> 
             RGBColor[
              0.19795607517941943`, 0.3253947645266211, 0.934584677680474], 
             UndirectedEdge[266, 397] -> 
             RGBColor[
              0.22283784734549728`, 0.3515470846686418, 0.9360016577960488], 
             UndirectedEdge[71, 88] -> 
             RGBColor[
              0.1851982028892632, 0.3119854318538441, 0.9338581357271303], 
             UndirectedEdge[156, 255] -> 
             RGBColor[
              0.8324443766360075, 0.2503872728066577, 0.17870207774831032`], 
             UndirectedEdge[22, 388] -> 
             RGBColor[
              0.26789478594512556`, 0.39820864264238165`, 0.9385930729355345],
              UndirectedEdge[17, 346] -> 
             RGBColor[
              0.29137138430139253`, 0.41966736519027487`, 0.9400478085576316],
              UndirectedEdge[72, 365] -> 
             RGBColor[
              0.18187230727944725`, 0.30848970469396636`, 0.9336687308923729],
              UndirectedEdge[194, 230] -> 
             RGBColor[
              0.8766694336459471, 0.421804072640802, 0.32514101008801133`], 
             UndirectedEdge[95, 264] -> 
             RGBColor[
              0.6413507907064967, 0.7184767050540989, 0.9657562779986768], 
             UndirectedEdge[131, 325] -> 
             RGBColor[
              0.2511977848308302, 0.381355177089618, 0.9376167142810707], 
             UndirectedEdge[369, 372] -> 
             RGBColor[
              0.19233300953943172`, 0.31948456601604064`, 0.9342644524108568],
              UndirectedEdge[11, 248] -> 
             RGBColor[
              0.2649817698706437, 0.3955454303669761, 0.9384125880269136], 
             UndirectedEdge[32, 223] -> 
             RGBColor[
              0.9434671979288998, 0.8132571155526379, 0.27501732397559764`], 
             UndirectedEdge[75, 229] -> 
             RGBColor[
              0.21242485108253378`, 0.34060236537417143`, 0.9354086530635206],
              UndirectedEdge[123, 131] -> 
             RGBColor[
              0.21247713876151392`, 0.34065732304000995`, 0.9354116307694857],
              UndirectedEdge[35, 340] -> 
             RGBColor[
              0.21959313401090685`, 0.34813668522727964`, 0.9358168761717671],
              UndirectedEdge[316, 369] -> 
             RGBColor[
              0.2124757350485229, 0.34065584764865586`, 0.9354115508301075], 
             UndirectedEdge[232, 280] -> 
             RGBColor[
              0.2733144461810522, 0.4046011904460226, 0.9388762254262976], 
             UndirectedEdge[30, 318] -> 
             RGBColor[
              0.18730055861877407`, 0.31419514102261215`, 0.9339778617757692],
              UndirectedEdge[219, 338] -> 
             RGBColor[
              0.28566284547896603`, 0.414956272719873, 0.9396755211710989], 
             UndirectedEdge[124, 397] -> 
             RGBColor[
              0.26132649500551464`, 0.3919101499465881, 0.9381968592370336], 
             UndirectedEdge[131, 280] -> 
             RGBColor[
              0.23239625445736245`, 0.36159357658122604`, 0.9365459949406734],
              UndirectedEdge[224, 345] -> 
             RGBColor[
              0.17916076969846856`, 0.3056397067749454, 0.9335143128384965], 
             UndirectedEdge[44, 195] -> 
             RGBColor[
              0.2192614298530921, 0.3477880431261581, 0.9357979861106919], 
             UndirectedEdge[57, 102] -> 
             RGBColor[
              0.24757611002741542`, 0.37754856724378383`, 0.937410465258804], 
             UndirectedEdge[102, 222] -> 
             RGBColor[
              0.2549287084068188, 0.3852766143221994, 0.9378291848593165], 
             UndirectedEdge[86, 285] -> 
             RGBColor[
              0.7026108469912147, 0.7602147765402214, 0.7786951433273641], 
             UndirectedEdge[97, 340] -> 
             RGBColor[
              0.1979121571634553, 0.3253486039072797, 0.9345821766144358], 
             UndirectedEdge[84, 183] -> 
             RGBColor[
              0.3444123638438444, 0.47273441171796776`, 0.9431666291656026], 
             UndirectedEdge[23, 132] -> 
             RGBColor[
              0.32566481114992, 0.45504559524241234`, 0.9420251663053016], 
             UndirectedEdge[124, 210] -> 
             RGBColor[
              0.30769169180349737`, 0.4406429115045353, 0.9408372886035168], 
             UndirectedEdge[257, 288] -> 
             RGBColor[
              0.3142377899115303, 0.4462866876189422, 0.9412553567525421], 
             UndirectedEdge[31, 287] -> 
             RGBColor[
              0.19320443776430601`, 0.3204004923321242, 0.9343140789591009], 
             UndirectedEdge[163, 222] -> 
             RGBColor[
              0.24959037113759353`, 0.3796656833821117, 0.9375251744491964], 
             UndirectedEdge[206, 386] -> 
             RGBColor[
              0.7455369138645886, 0.8011383704922057, 0.975271810201597], 
             UndirectedEdge[95, 263] -> 
             RGBColor[
              0.47568127911611685`, 0.5835523041211401, 0.9523268989560933], 
             UndirectedEdge[103, 333] -> 
             RGBColor[
              0.19123001846776383`, 0.3183252524660446, 0.9342016387010543], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.19722342502912832`, 0.3246247027659626, 0.9345429543382737], 
             UndirectedEdge[57, 174] -> 
             RGBColor[
              0.28083864150489934`, 0.40925045112803254`, 0.9394240505070525],
              UndirectedEdge[32, 208] -> 
             RGBColor[0.97502376088894, 0.929050734989072, 0.526498655624491],
              UndirectedEdge[11, 125] -> 
             RGBColor[
              0.2867382877276377, 0.41841291007758175`, 0.9396515895329856], 
             UndirectedEdge[82, 136] -> 
             RGBColor[
              0.18265801399513343`, 0.30931553226883557`, 0.9337134757274823],
              UndirectedEdge[129, 298] -> 
             RGBColor[
              0.19304299486108434`, 0.3202308056047669, 0.9343048850245959], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.24346570234943876`, 0.37322826815933124`, 0.9371763836223466],
              UndirectedEdge[155, 306] -> 
             RGBColor[
              0.20489683816901277`, 0.33268994649847444`, 0.9349799438647926],
              UndirectedEdge[247, 358] -> 
             RGBColor[
              0.19420191296404457`, 0.3214489020106298, 0.9343708836960937], 
             UndirectedEdge[5, 373] -> 
             RGBColor[
              0.27714534160664284`, 0.4086277044311172, 0.939094389253483], 
             UndirectedEdge[194, 201] -> 
             RGBColor[
              0.9717877162352071, 0.9761148093624215, 0.8086618740541351], 
             UndirectedEdge[7, 173] -> 
             RGBColor[
              0.36556257674898185`, 0.48862517592323496`, 0.9446032208411446],
              UndirectedEdge[25, 364] -> 
             RGBColor[
              0.8174383734159, 0.1350445563843714, 0.16433231211787877`], 
             UndirectedEdge[1, 313] -> 
             RGBColor[
              0.20595700131663575`, 0.3338042451848521, 0.935040318587679], 
             UndirectedEdge[189, 222] -> 
             RGBColor[
              0.24951462814212214`, 0.379586072691488, 0.937520860997656], 
             UndirectedEdge[232, 275] -> 
             RGBColor[
              0.2669215798519661, 0.39788188260301705`, 0.9385121611462544], 
             UndirectedEdge[289, 376] -> 
             RGBColor[
              0.19788479388924796`, 0.32531984337115605`, 0.93458061831645], 
             UndirectedEdge[194, 208] -> 
             RGBColor[
              0.9937734715667986, 0.9910458830658546, 0.7058012226950569], 
             UndirectedEdge[320, 384] -> 
             RGBColor[
              0.1926752609493727, 0.31984429394788133`, 0.9342839431223373], 
             UndirectedEdge[262, 332] -> 
             RGBColor[
              0.22124807994982085`, 0.34987613833871123`, 0.9359111228947152],
              UndirectedEdge[39, 237] -> 
             RGBColor[
              0.19025421078354665`, 0.3172996167201517, 0.9341460678970164], 
             UndirectedEdge[105, 353] -> 
             RGBColor[
              0.19974831949640176`, 0.32727852693862247`, 0.9346867433429382],
              UndirectedEdge[160, 321] -> 
             RGBColor[
              0.5069925116479708, 0.6106383865650169, 0.9543314541731429], 
             UndirectedEdge[22, 354] -> 
             RGBColor[
              0.2660640348072204, 0.3962844071201169, 0.9384888143665844], 
             UndirectedEdge[70, 286] -> 
             RGBColor[
              0.20888058953085603`, 0.33687712176419665`, 0.9352068126114177],
              UndirectedEdge[97, 334] -> 
             RGBColor[
              0.1889352663956901, 0.3159133225426103, 0.9340709559653313], 
             UndirectedEdge[301, 362] -> 
             RGBColor[
              0.18593089634401205`, 0.31275553913023335`, 0.9338998615354555],
              UndirectedEdge[166, 300] -> 
             RGBColor[
              0.9521971792667703, 0.9624135645920178, 0.9060859398221737], 
             UndirectedEdge[357, 364] -> 
             RGBColor[
              0.8439593662277066, 0.3388965287090708, 0.18972884478564203`], 
             UndirectedEdge[13, 66] -> 
             RGBColor[
              0.21421674509456057`, 0.34248575959345395`, 0.9355106987766358],
              UndirectedEdge[102, 395] -> 
             RGBColor[
              0.3730551581743753, 0.49423581065451916`, 0.9452125382842432], 
             UndirectedEdge[129, 336] -> 
             RGBColor[
              0.184720804255658, 0.3114836556211034, 0.9338309485811944], 
             UndirectedEdge[257, 275] -> 
             RGBColor[
              0.2809273627700829, 0.4112753166902168, 0.9393583772051975], 
             UndirectedEdge[358, 369] -> 
             RGBColor[
              0.19068675298749674`, 0.31775424600126295`, 0.9341707005356424],
              UndirectedEdge[42, 139] -> 
             RGBColor[
              0.20228682166276132`, 0.3299466536657998, 0.934831307285935], 
             UndirectedEdge[37, 206] -> 
             RGBColor[
              0.5395559184345032, 0.6328895346269106, 0.9586002858977685], 
             UndirectedEdge[3, 162] -> 
             RGBColor[
              0.42709887646193556`, 0.5374958425847769, 0.9495230473669047], 
             UndirectedEdge[44, 161] -> 
             RGBColor[
              0.2180648213930185, 0.34653033176526227`, 0.9357298410291143], 
             UndirectedEdge[67, 266] -> 
             RGBColor[
              0.3289874356394012, 0.4523479810161943, 0.9424410275338806], 
             UndirectedEdge[305, 360] -> 
             RGBColor[
              0.18374121717091801`, 0.3104540474856332, 0.9337751625458877], 
             UndirectedEdge[51, 174] -> 
             RGBColor[
              0.3627872108908755, 0.4886497806834403, 0.9443374581712001], 
             UndirectedEdge[132, 321] -> 
             RGBColor[
              0.4563174789356197, 0.5669174288296601, 0.9510551804528969], 
             UndirectedEdge[198, 236] -> 
             RGBColor[
              0.3020417872484481, 0.43067536553856556`, 0.9406630613787681], 
             UndirectedEdge[153, 356] -> 
             RGBColor[
              0.18871819494406902`, 0.31568516668383156`, 0.9340585940672899],
              UndirectedEdge[78, 217] -> 
             RGBColor[
              0.8776482484719079, 0.43203131985281057`, 0.2734989161571625], 
             UndirectedEdge[16, 324] -> 
             RGBColor[
              0.47545256857995977`, 0.5813525434303296, 0.9528653912069069], 
             UndirectedEdge[263, 312] -> 
             RGBColor[
              0.3474308254202023, 0.4748091816311434, 0.9433787228228494], 
             UndirectedEdge[49, 231] -> 
             RGBColor[
              0.1849354051777754, 0.31170921479673314`, 0.9338431697862355], 
             UndirectedEdge[58, 303] -> 
             RGBColor[
              0.21259709598969448`, 0.3407834056925553, 0.9354184621561699], 
             UndirectedEdge[287, 371] -> 
             RGBColor[
              0.18823999048710255`, 0.315182543479646, 0.9340313610309057], 
             UndirectedEdge[108, 332] -> 
             RGBColor[
              0.24224909685408347`, 0.3719495386464692, 0.9371070997391926], 
             UndirectedEdge[55, 135] -> 
             RGBColor[
              0.9832367917164733, 0.9536721882994657, 0.5121416630539384], 
             UndirectedEdge[38, 145] -> 
             RGBColor[
              0.21009367554414693`, 0.338152152078261, 0.9352758960652745], 
             UndirectedEdge[41, 400] -> 
             RGBColor[
              0.8574093225920176, 0.5580230088055577, 0.4596698602319089], 
             UndirectedEdge[184, 369] -> 
             RGBColor[
              0.1868540625349533, 0.3137258453290297, 0.9339524344843275], 
             UndirectedEdge[68, 363] -> 
             RGBColor[
              0.24496356786818765`, 0.3748026197896954, 0.9372616848477457], 
             UndirectedEdge[239, 350] -> 
             RGBColor[
              0.8831254339446791, 0.4735106865862311, 0.3666717938932875], 
             UndirectedEdge[197, 300] -> 
             RGBColor[
              0.9395054889132312, 0.9538623530451078, 0.9685107634864926], 
             UndirectedEdge[34, 340] -> 
             RGBColor[
              0.23309142699709673`, 0.3623242469969716, 0.9365855839883956], 
             UndirectedEdge[99, 225] -> 
             RGBColor[
              0.9251735948093716, 0.9424003112075763, 0.9659587843040318], 
             UndirectedEdge[75, 218] -> 
             RGBColor[
              0.20441362479812614`, 0.3321820586081753, 0.9349524255781707], 
             UndirectedEdge[33, 256] -> 
             RGBColor[
              0.3139252578534664, 0.443350508209742, 0.9413330387606047], 
             UndirectedEdge[68, 173] -> 
             RGBColor[
              0.2762530439300684, 0.40768984299809713`, 0.9390435742208383], 
             UndirectedEdge[76, 368] -> 
             RGBColor[
              0.18953430680604916`, 0.3165429519952533, 0.9341050704305003], 
             UndirectedEdge[343, 369] -> 
             RGBColor[
              0.18630927681020493`, 0.31315324099090924`, 0.9339214097432413],
              UndirectedEdge[172, 243] -> 
             RGBColor[
              0.8723775495712267, 0.44824282516484726`, 0.42577432827241535`],
              UndirectedEdge[25, 83] -> 
             RGBColor[
              0.8598908303478167, 0.4089271313115804, 0.435454149583152], 
             UndirectedEdge[176, 372] -> 
             RGBColor[
              0.2138686325253813, 0.34211987121163484`, 0.9354908742808075], 
             UndirectedEdge[211, 214] -> 
             RGBColor[
              0.23081730246588306`, 0.35993399792684283`, 0.9364560759606089],
              UndirectedEdge[273, 330] -> 
             RGBColor[
              0.18387764331179846`, 0.31059744000961553`, 0.9337829318127865],
              UndirectedEdge[247, 266] -> 
             RGBColor[
              0.21519016549381775`, 0.3435088861514912, 0.9355661336283271], 
             UndirectedEdge[294, 347] -> 
             RGBColor[
              0.19390550774844745`, 0.3211373613358611, 0.9343540038575576], 
             UndirectedEdge[247, 343] -> 
             RGBColor[
              0.18982443678675276`, 0.31684789700027605`, 0.9341215929036926],
              UndirectedEdge[147, 354] -> 
             RGBColor[
              0.1996644579713909, 0.3271903831587082, 0.9346819675531508], 
             UndirectedEdge[83, 206] -> 
             RGBColor[
              0.8376738526720509, 0.8738864473115988, 0.9758404514260404], 
             UndirectedEdge[178, 300] -> 
             RGBColor[
              0.6781948564694122, 0.7459060831571422, 0.9705455677828076], 
             UndirectedEdge[31, 384] -> 
             RGBColor[
              0.19301716646589862`, 0.32020365832381187`, 0.9343034141356996],
              UndirectedEdge[325, 339] -> 
             RGBColor[
              0.2703434502460814, 0.40147848534634617`, 0.9387070316029955], 
             UndirectedEdge[43, 237] -> 
             RGBColor[
              0.22884629711642387`, 0.3578623463356042, 0.9363438301217982], 
             UndirectedEdge[114, 128] -> 
             RGBColor[
              0.21795119041436695`, 0.34641089840207934`, 0.9357233699129821],
              UndirectedEdge[131, 188] -> 
             RGBColor[
              0.20752052535930418`, 0.3354476080868466, 0.9351293589688823], 
             UndirectedEdge[8, 352] -> 
             RGBColor[
              0.23870734178156489`, 0.36822692950501057`, 0.9369054020273697],
              UndirectedEdge[56, 137] -> 
             RGBColor[
              0.35805694536026106`, 0.48455266243088047`, 0.9440360498343989],
              UndirectedEdge[11, 93] -> 
             RGBColor[
              0.2731424573639435, 0.4041228303399058, 0.9388773271070019], 
             UndirectedEdge[232, 325] -> 
             RGBColor[
              0.29211597655452004`, 0.4243627909544146, 0.9399469447666949], 
             UndirectedEdge[293, 387] -> 
             RGBColor[
              0.4415101712045343, 0.5546415244104943, 0.9499598596294503], 
             UndirectedEdge[100, 175] -> 
             RGBColor[
              0.2458994336441635, 0.3757862740575634, 0.9373149810191983], 
             UndirectedEdge[327, 336] -> 
             RGBColor[
              0.18798018955468324`, 0.3149094762273428, 0.9340165657521455], 
             UndirectedEdge[230, 357] -> 
             RGBColor[
              0.8308590408356056, 0.2382016871461912, 0.17718395839546475`], 
             UndirectedEdge[151, 291] -> 
             RGBColor[
              0.1895972333261113, 0.3166090917576105, 0.9341086540027264], 
             UndirectedEdge[10, 87] -> 
             RGBColor[
              0.2178399723924833, 0.34629400120944975`, 0.9357170362111682], 
             UndirectedEdge[44, 247] -> 
             RGBColor[
              0.2171512777998561, 0.34557013952683935`, 0.9356778160729503], 
             UndirectedEdge[191, 334] -> 
             RGBColor[
              0.1961023648412683, 0.3234463974292005, 0.934479111619035], 
             UndirectedEdge[31, 389] -> 
             RGBColor[
              0.19956255990653143`, 0.3270832818318305, 0.9346761646091019], 
             UndirectedEdge[323, 346] -> 
             RGBColor[
              0.37487874320773873`, 0.4991228582382221, 0.9451079199183084], 
             UndirectedEdge[91, 257] -> 
             RGBColor[
              0.408201112318213, 0.5268994734386068, 0.9475311314318583], 
             UndirectedEdge[25, 217] -> 
             RGBColor[
              0.8759025294365022, 0.41861295836772294`, 0.2718272136373503], 
             UndirectedEdge[4, 238] -> 
             RGBColor[
              0.26140051176335477`, 0.3920788899859515, 0.9381977444862962], 
             UndirectedEdge[49, 298] -> 
             RGBColor[
              0.19233776426424887`, 0.31948956353329044`, 0.9342647231854012],
              UndirectedEdge[96, 245] -> 
             RGBColor[
              0.795286411691943, 0.364900459678807, 0.43562237712445073`], 
             UndirectedEdge[198, 219] -> 
             RGBColor[
              0.34521680439082036`, 0.47343117768740084`, 0.9432178874059169],
              UndirectedEdge[69, 106] -> 
             RGBColor[
              0.23431749208343802`, 0.36361291913973265`, 0.936655406581262], 
             UndirectedEdge[246, 350] -> 
             RGBColor[
              0.9570479117499637, 0.9654838538059254, 0.8719160935305621], 
             UndirectedEdge[91, 263] -> 
             RGBColor[
              0.44262523593919395`, 0.5567159191123393, 0.94972460614893], 
             UndirectedEdge[193, 305] -> 
             RGBColor[
              0.18458905889423072`, 0.311345182893105, 0.933823445877761], 
             UndirectedEdge[217, 244] -> 
             RGBColor[
              0.9739175055905028, 0.9766847910311653, 0.7242500801550553], 
             UndirectedEdge[218, 260] -> 
             RGBColor[
              0.20772118523879674`, 0.3356585143427644, 0.9351407862521698], 
             UndirectedEdge[115, 169] -> 
             RGBColor[
              0.875001595756134, 0.6253129164488254, 0.46913275406054683`], 
             UndirectedEdge[152, 332] -> 
             RGBColor[
              0.24255699042787615`, 0.37227315431410535`, 0.9371246338227324],
              UndirectedEdge[8, 227] -> 
             RGBColor[
              0.22264092645081146`, 0.35134010832282114`, 0.9359904434424149],
              UndirectedEdge[161, 344] -> 
             RGBColor[
              0.1953522686165181, 0.3226579987381405, 0.9344363947487033], 
             UndirectedEdge[255, 324] -> 
             RGBColor[
              0.767950807524049, 0.41955323404777206`, 0.4424174224408835], 
             UndirectedEdge[135, 221] -> 
             RGBColor[
              0.9485753172801801, 0.8203317071995411, 0.46009294767531356`], 
             UndirectedEdge[179, 257] -> 
             RGBColor[
              0.38852623515624984`, 0.5109265218154098, 0.9459822530302189], 
             UndirectedEdge[40, 350] -> 
             RGBColor[
              0.7574551958384235, 0.806891984810095, 0.8535080309341501], 
             UndirectedEdge[358, 397] -> 
             RGBColor[
              0.20184959481572412`, 0.3294871005277804, 0.9348064078638154], 
             UndirectedEdge[44, 149] -> 
             RGBColor[
              0.22663901581167467`, 0.355542353734595, 0.9362181287168728], 
             UndirectedEdge[215, 218] -> 
             RGBColor[
              0.18692850160935742`, 0.31380408551593836`, 0.9339566736794921],
              UndirectedEdge[211, 248] -> 
             RGBColor[
              0.2199442042179371, 0.34850568227400514`, 0.9358368691006957], 
             UndirectedEdge[38, 103] -> 
             RGBColor[
              0.20863860950919683`, 0.3366227854190133, 0.9351930322071614], 
             UndirectedEdge[79, 213] -> 
             RGBColor[
              0.22683120635617676`, 0.355744358182451, 0.9362290736840618], 
             UndirectedEdge[116, 383] -> 
             RGBColor[
              0.19584602024074033`, 0.3231769630008592, 0.9344645131732627], 
             UndirectedEdge[214, 263] -> 
             RGBColor[
              0.315848849556003, 0.4416145225849462, 0.9415801760187297], 
             UndirectedEdge[203, 275] -> 
             RGBColor[
              0.232253685994867, 0.3614437280877808, 0.9365378758776455], 
             UndirectedEdge[235, 396] -> 
             RGBColor[
              0.19553592187284338`, 0.32285102995482734`, 0.9344468535299604],
              UndirectedEdge[170, 361] -> 
             RGBColor[
              0.22465020382752957`, 0.3534519862412956, 0.9361048688165594], 
             UndirectedEdge[190, 255] -> 
             RGBColor[
              0.8756473687829154, 0.5041621789431939, 0.4406614321632898], 
             UndirectedEdge[67, 113] -> 
             RGBColor[
              0.36637406988619037`, 0.4916437040590915, 0.9445701410456664], 
             UndirectedEdge[244, 307] -> 
             RGBColor[
              0.651559964846024, 0.7209668023928419, 0.952436169214119], 
             UndirectedEdge[106, 292] -> 
             RGBColor[
              0.21060209943900177`, 0.3386865378276902, 0.9353048500539408], 
             UndirectedEdge[119, 126] -> 
             RGBColor[
              0.1845010944888899, 0.3112527267258263, 0.9338184364350084], 
             UndirectedEdge[148, 288] -> 
             RGBColor[
              0.3196747008606359, 0.4509958666159675, 0.9416017919105475], 
             UndirectedEdge[143, 277] -> 
             RGBColor[
              0.196429195674298, 0.32378991735698637`, 0.9344977241514731], 
             UndirectedEdge[245, 364] -> 
             RGBColor[
              0.8184457437613093, 0.14278764629168772`, 0.16529697109830485`],
              UndirectedEdge[101, 335] -> 
             RGBColor[
              0.18130162624818058`, 0.3078898827468379, 0.9336362314518891], 
             UndirectedEdge[175, 296] -> 
             RGBColor[
              0.26330595896968834`, 0.39408163581213873`, 0.9383062568858402],
              UndirectedEdge[106, 158] -> 
             RGBColor[
              0.2827874224549232, 0.411783246820848, 0.939517290657987], 
             UndirectedEdge[59, 319] -> 
             RGBColor[
              0.3999369554845372, 0.5208258336893123, 0.9467049354493426], 
             UndirectedEdge[159, 218] -> 
             RGBColor[
              0.18568639672443343`, 0.31249855452788494`, 0.9338859376438252],
              UndirectedEdge[126, 326] -> 
             RGBColor[
              0.18929893908149736`, 0.31629556559357375`, 0.9340916665867824],
              UndirectedEdge[130, 371] -> 
             RGBColor[
              0.18427986944939637`, 0.311020205182841, 0.9338058379962824], 
             UndirectedEdge[108, 262] -> 
             RGBColor[
              0.23515249805591343`, 0.36449056335924074`, 0.936702958936114], 
             UndirectedEdge[34, 91] -> 
             RGBColor[
              0.37827297461142906`, 0.4967706349329164, 0.9457781608227135], 
             UndirectedEdge[173, 323] -> 
             RGBColor[
              0.3405854460382354, 0.4669912406886779, 0.9430117001586653], 
             UndirectedEdge[104, 208] -> 
             RGBColor[
              0.8770111738905605, 0.4285385681953471, 0.3656971396255897], 
             UndirectedEdge[115, 122] -> 
             RGBColor[
              0.7757263022490958, 0.5468964399598267, 0.4596563040800477], 
             UndirectedEdge[275, 297] -> 
             RGBColor[
              0.22283542703535522`, 0.35154454076922603`, 0.9360015199629668],
              UndirectedEdge[185, 293] -> 
             RGBColor[
              0.374247320413842, 0.49857595155038115`, 0.9450676862162266], 
             UndirectedEdge[92, 256] -> 
             RGBColor[
              0.42434961842059, 0.5407753734409124, 0.9485908039462863], 
             UndirectedEdge[135, 165] -> 
             RGBColor[
              0.9457959012350979, 0.9559420991486686, 0.8350019041226482], 
             UndirectedEdge[158, 270] -> 
             RGBColor[
              0.3489276916060272, 0.4766453616785984, 0.9434543418578613], 
             UndirectedEdge[35, 86] -> 
             RGBColor[
              0.32363709491798653`, 0.44803730928476804`, 0.942088262737994], 
             UndirectedEdge[124, 387] -> 
             RGBColor[
              0.42192783769441117`, 0.5376802913607258, 0.9487120906541628], 
             UndirectedEdge[170, 261] -> 
             RGBColor[
              0.2458172275622507, 0.3756998702533064, 0.9373102995044464], 
             UndirectedEdge[78, 244] -> 
             RGBColor[
              0.8648801933259055, 0.4247645971381416, 0.4316352089858322], 
             UndirectedEdge[320, 381] -> 
             RGBColor[
              0.19597803687805715`, 0.32331572085701743`, 0.9344720313254569],
              UndirectedEdge[90, 166] -> 
             RGBColor[
              0.7990367806379581, 0.841477411935373, 0.8913793888944332], 
             UndirectedEdge[119, 317] -> 
             RGBColor[
              0.1888850042427438, 0.31586049383305914`, 0.9340680936100771], 
             UndirectedEdge[173, 250] -> 
             RGBColor[
              0.27041365894161523`, 0.40155227913684066`, 0.9387110298843417],
              UndirectedEdge[234, 355] -> 
             RGBColor[
              0.7757149376246414, 0.8247136720150343, 0.978279673580333], 
             UndirectedEdge[203, 297] -> 
             RGBColor[
              0.2163387830881471, 0.3447161560696932, 0.9356315457010966], 
             UndirectedEdge[48, 388] -> 
             RGBColor[
              0.2298511238520014, 0.358918482944391, 0.9364010535178815], 
             UndirectedEdge[34, 95] -> 
             RGBColor[
              0.41132901778835196`, 0.5236070199417173, 0.9483804536298768], 
             UndirectedEdge[133, 299] -> 
             RGBColor[
              0.18672468895596034`, 0.31358986549474943`, 0.9339450668503949],
              UndirectedEdge[58, 376] -> 
             RGBColor[
              0.2107803074531337, 0.33887384574958357`, 0.9353149987367104], 
             UndirectedEdge[239, 392] -> 
             RGBColor[
              0.8822032486914739, 0.47312933928495077`, 0.3819547900778306], 
             UndirectedEdge[64, 77] -> 
             RGBColor[
              0.18172630335562523`, 0.308336245312846, 0.9336604161849047], 
             UndirectedEdge[73, 112] -> 
             RGBColor[
              0.9338615942560703, 0.7754902910821886, 0.2656416901517646], 
             UndirectedEdge[257, 339] -> 
             RGBColor[
              0.2873260863715352, 0.41800078089785175`, 0.939722775048237], 
             UndirectedEdge[35, 85] -> 
             RGBColor[
              0.2384984047146932, 0.36800732340035325`, 0.9368935033705061], 
             UndirectedEdge[37, 187] -> 
             RGBColor[
              0.39185947335344506`, 0.5138307132141199, 0.9461899170277228], 
             UndirectedEdge[9, 39] -> 
             RGBColor[
              0.1871051393828018, 0.3139897430153101, 0.9339667329393776], 
             UndirectedEdge[136, 394] -> 
             RGBColor[
              0.18251086599702937`, 0.30916087039310625`, 0.9337050958666762],
              UndirectedEdge[287, 389] -> 
             RGBColor[
              0.19629053047607914`, 0.32364417144177693`, 0.9344898273735713],
              UndirectedEdge[195, 372] -> 
             RGBColor[
              0.19795832156921558`, 0.32539712562472617`, 0.9345848056090496],
              UndirectedEdge[149, 362] -> 
             RGBColor[
              0.20288427131655484`, 0.3305746111324327, 0.934865331159871], 
             UndirectedEdge[83, 321] -> 
             RGBColor[
              0.7496980165524652, 0.8038110466699736, 0.967993483257613], 
             UndirectedEdge[227, 308] -> 
             RGBColor[
              0.20448504246078797`, 0.33225712309977423`, 0.9349564927084064],
              UndirectedEdge[100, 146] -> 
             RGBColor[
              0.1981449486568544, 0.3255932825266753, 0.9345954337456006], 
             UndirectedEdge[100, 278] -> 
             RGBColor[
              0.23415669632153385`, 0.3634439125989312, 0.9366462495004977], 
             UndirectedEdge[234, 350] -> 
             RGBColor[
              0.8897866044520348, 0.9121284341385445, 0.8654271636734474], 
             UndirectedEdge[278, 352] -> 
             RGBColor[
              0.24888415157963256`, 0.37892340184978857`, 0.9374849562901288],
              UndirectedEdge[342, 353] -> 
             RGBColor[
              0.1868676578718124, 0.31374013489006275`, 0.9339532087186491], 
             UndirectedEdge[109, 181] -> 
             RGBColor[
              0.18812311022869774`, 0.31505969491742614`, 0.9340247048730984],
              UndirectedEdge[59, 296] -> 
             RGBColor[
              0.2957363483745861, 0.42467629385936273`, 0.9402809691977339], 
             UndirectedEdge[168, 378] -> 
             RGBColor[
              0.18751181267223727`, 0.3144171824270826, 0.9339898923815917], 
             UndirectedEdge[191, 370] -> 
             RGBColor[
              0.19715574767547106`, 0.3245535695762768, 0.9345391002131025], 
             UndirectedEdge[153, 184] -> 
             RGBColor[
              0.18277753601960423`, 0.3094411574946885, 0.933720282329959], 
             UndirectedEdge[3, 91] -> 
             RGBColor[
              0.5375833562526594, 0.6354734123169479, 0.9567396775183801], 
             UndirectedEdge[149, 210] -> 
             RGBColor[
              0.26112860842944113`, 0.3917931023423411, 0.9381822599936748], 
             UndirectedEdge[3, 312] -> 
             RGBColor[
              0.44238894573366777`, 0.553566674835752, 0.9503937941922995], 
             UndirectedEdge[17, 388] -> 
             RGBColor[
              0.22559527698605156`, 0.35444531805200136`, 0.9361586893348268],
              UndirectedEdge[99, 243] -> 
             RGBColor[
              0.9675815557220673, 0.9753429578546242, 0.9397601494648378], 
             UndirectedEdge[108, 398] -> 
             RGBColor[
              0.34112387915000547`, 0.4650235569768793, 0.9431351310396142], 
             UndirectedEdge[57, 186] -> 
             RGBColor[
              0.21226621689950026`, 0.3404356307898151, 0.9353996190814751], 
             UndirectedEdge[180, 398] -> 
             RGBColor[
              0.3423187854528118, 0.46627947926256413`, 0.9432031791858535], 
             UndirectedEdge[66, 318] -> 
             RGBColor[
              0.20433061997593613`, 0.33209481527724394`, 0.9349476985763416],
              UndirectedEdge[374, 382] -> 
             RGBColor[
              0.18605529017041303`, 0.3128862849288049, 0.9339069455798448], 
             UndirectedEdge[190, 270] -> 
             RGBColor[
              0.6576592800193992, 0.7261622336829004, 0.951547961847741], 
             UndirectedEdge[47, 96] -> 
             RGBColor[
              0.6461513889555156, 0.7219924964871992, 0.9663950668318202], 
             UndirectedEdge[245, 328] -> 
             RGBColor[
              0.8357302891053365, 0.26397824350067983`, 0.18139186023278991`],
              UndirectedEdge[142, 143] -> 
             RGBColor[
              0.1837659567931899, 0.3104800503972236, 0.9337765714307771], 
             UndirectedEdge[268, 373] -> 
             RGBColor[
              0.475607023803843, 0.5762529501811211, 0.9537345477094038], 
             UndirectedEdge[69, 390] -> 
             RGBColor[
              0.2522635992417797, 0.3824754156120626, 0.9376774108350432], 
             UndirectedEdge[91, 112] -> 
             RGBColor[
              0.7152028502193496, 0.6939405622428378, 0.6107535397674092], 
             UndirectedEdge[16, 190] -> 
             RGBColor[
              0.6369974104682594, 0.7082659607734624, 0.9502314057905163], 
             UndirectedEdge[40, 395] -> 
             RGBColor[
              0.494849422028799, 0.60078007937222, 0.9533755056767188], 
             UndirectedEdge[84, 246] -> 
             RGBColor[
              0.6295415881560444, 0.703574353083331, 0.9675332208830456], 
             UndirectedEdge[196, 376] -> 
             RGBColor[
              0.19966869054902864`, 0.32719483186616644`, 0.9346822085921858],
              UndirectedEdge[37, 311] -> 
             RGBColor[
              0.3257713181858094, 0.4560335502623456, 0.9419991567290754], 
             UndirectedEdge[179, 275] -> 
             RGBColor[
              0.34634920232824207`, 0.46792331791250663`, 0.9435317259645368],
              UndirectedEdge[334, 340] -> 
             RGBColor[
              0.1939578430419053, 0.32119236904753456`, 0.934356984275097], 
             UndirectedEdge[23, 366] -> 
             RGBColor[
              0.34372780451171075`, 0.47069085221995155`, 0.9431761242698371],
              UndirectedEdge[295, 351] -> 
             RGBColor[
              0.6694121408599306, 0.7384677850374681, 0.9699082105749879], 
             UndirectedEdge[358, 363] -> 
             RGBColor[
              0.20533835444542115`, 0.3331540080987284, 0.9350050875635693], 
             UndirectedEdge[111, 116] -> 
             RGBColor[
              0.1862942905711151, 0.31313748950344333`, 0.9339205562990953], 
             UndirectedEdge[147, 371] -> 
             RGBColor[
              0.18501189214807195`, 0.3117896074520688, 0.9338475256060415], 
             UndirectedEdge[33, 311] -> 
             RGBColor[
              0.28964287283882917`, 0.4217634021453914, 0.9398061051687154], 
             UndirectedEdge[137, 178] -> 
             RGBColor[
              0.3880768646119117, 0.5105544076416471, 0.9459488925435418], 
             UndirectedEdge[328, 386] -> 
             RGBColor[
              0.8151456848541535, 0.6567413505380229, 0.5948173850288303], 
             UndirectedEdge[20, 36] -> 
             RGBColor[
              0.19158305641128354`, 0.3186963177285822, 0.934221743689665], 
             UndirectedEdge[107, 212] -> 
             RGBColor[
              0.3829775514957524, 0.5061376389193594, 0.9456239688209257], 
             UndirectedEdge[21, 27] -> 
             RGBColor[
              0.8684261923998754, 0.40432118743230555`, 0.21570221410383633`],
              UndirectedEdge[138, 329] -> 
             RGBColor[
              0.18634787164566047`, 0.31319380661002694`, 0.9339236076620245],
              UndirectedEdge[3, 263] -> 
             RGBColor[
              0.48691076315351817`, 0.5926689051451934, 0.9532109250744729], 
             UndirectedEdge[239, 269] -> 
             RGBColor[
              0.799702445338238, 0.4094726078345682, 0.44117170841842035`], 
             UndirectedEdge[74, 86] -> 
             RGBColor[
              0.6370413534700665, 0.7120367862892685, 0.9671058051428245], 
             UndirectedEdge[91, 179] -> 
             RGBColor[
              0.47362295187637204`, 0.5835474746608966, 0.9517044801911976], 
             UndirectedEdge[316, 358] -> 
             RGBColor[
              0.212564816221155, 0.34074947760916474`, 0.9354166238711052], 
             UndirectedEdge[154, 267] -> 
             RGBColor[
              0.23074964895808886`, 0.359862889800671, 0.9364522231934242], 
             UndirectedEdge[25, 357] -> 
             RGBColor[
              0.8305794964059033, 0.23605298616234965`, 0.17691626633388163`],
              UndirectedEdge[118, 388] -> 
             RGBColor[
              0.2291977478565746, 0.35823174334676655`, 0.936363844721525], 
             UndirectedEdge[305, 340] -> 
             RGBColor[
              0.19258396167334632`, 0.31974833262006913`, 0.9342787437636328],
              UndirectedEdge[100, 213] -> 
             RGBColor[
              0.21638299645224862`, 0.344762627118653, 0.9356340635867745], 
             UndirectedEdge[51, 238] -> 
             RGBColor[
              0.3357800727610889, 0.463522711822467, 0.942680108320078], 
             UndirectedEdge[104, 242] -> 
             RGBColor[
              0.8300972241361643, 0.2323460301640793, 0.17645444186373088`], 
             UndirectedEdge[99, 337] -> 
             RGBColor[
              0.9798418672906987, 0.9817838609022704, 0.7682315700129669], 
             UndirectedEdge[143, 302] -> 
             RGBColor[
              0.1882090973662136, 0.3151500728508547, 0.9340296017133733], 
             UndirectedEdge[14, 327] -> 
             RGBColor[
              0.19007805312865012`, 0.317114463855815, 0.9341360359791719], 
             UndirectedEdge[162, 348] -> 
             RGBColor[
              0.3027342580511927, 0.4332679187418763, 0.9406342199418414], 
             UndirectedEdge[130, 391] -> 
             RGBColor[
              0.18156952589467779`, 0.3081714622611251, 0.9336514879404352], 
             UndirectedEdge[182, 386] -> 
             RGBColor[
              0.5546461678159978, 0.6446668165900299, 0.9601091386691207], 
             UndirectedEdge[32, 217] -> 
             RGBColor[
              0.975050917301262, 0.9271533469602427, 0.3873122304251019], 
             UndirectedEdge[3, 285] -> 
             RGBColor[
              0.7880339609127915, 0.8307135264515318, 0.7851026525209982], 
             UndirectedEdge[212, 274] -> 
             RGBColor[
              0.45520745425599235`, 0.5676199598754534, 0.950524688408067], 
             UndirectedEdge[234, 272] -> 
             RGBColor[
              0.7633280108193825, 0.8150369106506357, 0.9770450604787972], 
             UndirectedEdge[24, 104] -> 
             RGBColor[
              0.8201942750031774, 0.15622762362796194`, 0.16697136659020134`],
              UndirectedEdge[317, 327] -> 
             RGBColor[
              0.19548056477531295`, 0.3227928461354802, 0.9344437010251496], 
             UndirectedEdge[85, 263] -> 
             RGBColor[
              0.31634895902864796`, 0.44214016934946804`, 0.941608656513351], 
             UndirectedEdge[169, 300] -> 
             RGBColor[
              0.9052440838676142, 0.9272810765527117, 0.9908241829118685], 
             UndirectedEdge[34, 162] -> 
             RGBColor[
              0.2677884948207052, 0.39879306520074553`, 0.9385615306712383], 
             UndirectedEdge[62, 313] -> 
             RGBColor[
              0.20973650567435648`, 0.3377767438992335, 0.9352555557695754], 
             UndirectedEdge[337, 367] -> 
             RGBColor[
              0.6845644891406854, 0.7444870601720963, 0.7692660513213518], 
             UndirectedEdge[21, 240] -> 
             RGBColor[
              0.8755266503036192, 0.45889841832097356`, 0.22250162061128162`],
              UndirectedEdge[258, 378] -> 
             RGBColor[
              0.18711323001988966`, 0.3139982467878655, 0.9339671936891907], 
             UndirectedEdge[240, 242] -> 
             RGBColor[
              0.8385504243860425, 0.29732103150061207`, 0.18454923596953843`],
              UndirectedEdge[16, 380] -> 
             RGBColor[
              0.26894987250182517`, 0.3991789072508731, 0.9386582369767682], 
             UndirectedEdge[38, 222] -> 
             RGBColor[
              0.22765792346573496`, 0.35661329028148886`, 0.9362761540004327],
              UndirectedEdge[61, 147] -> 
             RGBColor[
              0.19642039468713995`, 0.32378066696146846`, 0.9344972229482744],
              UndirectedEdge[279, 288] -> 
             RGBColor[
              0.4888026931766387, 0.5910842948036721, 0.9543337450913586], 
             UndirectedEdge[192, 384] -> 
             RGBColor[
              0.1855895073220066, 0.3123967176227914, 0.933880419935692], 
             UndirectedEdge[196, 289] -> 
             RGBColor[
              0.18795157808443957`, 0.3148794037580448, 0.934014936371242], 
             UndirectedEdge[9, 384] -> 
             RGBColor[
              0.19029625552141455`, 0.3173438084054412, 0.9341484622826384], 
             UndirectedEdge[114, 187] -> 
             RGBColor[
              0.33810546577905015`, 0.4610349816709624, 0.9429931157731941], 
             UndirectedEdge[90, 274] -> 
             RGBColor[
              0.5507285778663977, 0.6461452954084659, 0.9577745175163469], 
             UndirectedEdge[270, 324] -> 
             RGBColor[
              0.49611443813109957`, 0.5992488163397677, 0.9541819472641316], 
             UndirectedEdge[42, 45] -> 
             RGBColor[
              0.2506616815740248, 0.3807916985758058, 0.9375861839936894], 
             UndirectedEdge[316, 363] -> 
             RGBColor[
              0.2271273365064473, 0.3560556097461213, 0.9362459378580343], 
             UndirectedEdge[44, 250] -> 
             RGBColor[
              0.24751102743025372`, 0.3774801613076919, 0.9374067589011768], 
             UndirectedEdge[213, 352] -> 
             RGBColor[
              0.23111045171034733`, 0.3602421163695104, 0.9364727703764056], 
             UndirectedEdge[80, 378] -> 
             RGBColor[
              0.18531329630253898`, 0.3121064023285408, 0.9338646901267509], 
             UndirectedEdge[238, 272] -> 
             RGBColor[
              0.5154577316990447, 0.6098310076277607, 0.9573191957441505], 
             UndirectedEdge[126, 196] -> 
             RGBColor[
              0.1881608487233165, 0.3150993604680292, 0.9340268540245378], 
             UndirectedEdge[112, 240] -> 
             RGBColor[
              0.8668285727789392, 0.4258405852121313, 0.20807034360844792`], 
             UndirectedEdge[52, 89] -> 
             RGBColor[
              0.18430520538442102`, 0.31104683485694296`, 0.933807280840301], 
             UndirectedEdge[99, 177] -> 
             RGBColor[
              0.9302447173684912, 0.9464438866842635, 0.9664424725007652], 
             UndirectedEdge[41, 206] -> 
             RGBColor[
              0.8010921103082493, 0.8449578955447232, 0.9806977415425538], 
             UndirectedEdge[1, 119] -> 
             RGBColor[
              0.18798137752672578`, 0.3149107248612813, 0.9340166334053959], 
             UndirectedEdge[2, 109] -> 
             RGBColor[
              0.1831541470606865, 0.30983699957738503`, 0.9337417297716024], 
             UndirectedEdge[8, 100] -> 
             RGBColor[
              0.22397988652346618`, 0.35274744025415317`, 0.9360666952377386],
              UndirectedEdge[203, 322] -> 
             RGBColor[
              0.2128310735235297, 0.3410293309156486, 0.935431786830583], 
             UndirectedEdge[98, 193] -> 
             RGBColor[
              0.1939801662783198, 0.32121583218438116`, 0.9343582555503864], 
             UndirectedEdge[141, 285] -> 
             RGBColor[
              0.908464702608926, 0.6517279650966425, 0.34303552105754676`], 
             UndirectedEdge[29, 231] -> 
             RGBColor[
              0.1818156421264654, 0.3084301460254042, 0.9336655038957391], 
             UndirectedEdge[225, 398] -> 
             RGBColor[
              0.6554022589203814, 0.7271955623129416, 0.9686184880711814], 
             UndirectedEdge[149, 359] -> 
             RGBColor[
              0.20190369877404518`, 0.3295439672183649, 0.9348094890042022], 
             UndirectedEdge[87, 235] -> 
             RGBColor[
              0.1948464738725398, 0.3221263763929803, 0.9344075904862901], 
             UndirectedEdge[162, 312] -> 
             RGBColor[
              0.28761893872861966`, 0.41963611907072695`, 0.9396908451152812],
              UndirectedEdge[392, 395] -> 
             RGBColor[
              0.729861417537885, 0.7850410988470374, 0.8743691386056183], 
             UndirectedEdge[212, 268] -> 
             RGBColor[
              0.5483496579696843, 0.6426701443947892, 0.9582447440009759], 
             UndirectedEdge[50, 271] -> 
             RGBColor[
              0.17906803055065768`, 0.3055422320505946, 0.933509031481224], 
             UndirectedEdge[200, 207] -> 
             RGBColor[
              0.1859857863076916, 0.31281323196228517`, 0.9339029874376845], 
             UndirectedEdge[360, 370] -> 
             RGBColor[
              0.18616848137367975`, 0.313005256060175, 0.9339133916514194], 
             UndirectedEdge[134, 246] -> 
             RGBColor[
              0.8756067697264411, 0.9036490867400013, 0.9879973494315406], 
             UndirectedEdge[88, 191] -> 
             RGBColor[
              0.19934659159346146`, 0.326856285441612, 0.9346638655331689], 
             UndirectedEdge[277, 278] -> 
             RGBColor[
              0.23299059780069237`, 0.3622182691186103, 0.9365798419148239], 
             UndirectedEdge[233, 242] -> 
             RGBColor[
              0.8879844020549108, 0.5916166599074094, 0.4496598100227772], 
             UndirectedEdge[66, 123] -> 
             RGBColor[
              0.21298431371887483`, 0.3411903960769459, 0.9354405136330093], 
             UndirectedEdge[315, 316] -> 
             RGBColor[
              0.22659989124895852`, 0.3555012313385397, 0.9362159006309058], 
             UndirectedEdge[127, 216] -> 
             RGBColor[
              0.19725740387013102`, 0.32466041668223944`, 0.9345448893830015],
              UndirectedEdge[29, 326] -> 
             RGBColor[
              0.18672499245337307`, 0.31359018448977305`, 0.9339450841341236],
              UndirectedEdge[76, 145] -> 
             RGBColor[
              0.19557703724460856`, 0.3228942448174177, 0.9344491949895577], 
             UndirectedEdge[21, 104] -> 
             RGBColor[
              0.867073450053741, 0.3939234169844408, 0.2144068265054741], 
             UndirectedEdge[27, 112] -> 
             RGBColor[
              0.8597281148751953, 0.37126335432346336`, 0.20127093710100263`],
              UndirectedEdge[190, 221] -> 
             RGBColor[
              0.9292638455200164, 0.8080779972178733, 0.5995947563336426], 
             UndirectedEdge[310, 324] -> 
             RGBColor[
              0.45636436031597766`, 0.5621244658109066, 0.9517477784200521], 
             UndirectedEdge[11, 312] -> 
             RGBColor[
              0.30743684398278903`, 0.44016840506601096`, 0.9408303416909466],
              UndirectedEdge[177, 225] -> 
             RGBColor[
              0.8897813970600477, 0.9149515498158103, 0.9893493380404593], 
             UndirectedEdge[253, 316] -> 
             RGBColor[
              0.2127233679212677, 0.3409161254987416, 0.9354256531558705], 
             UndirectedEdge[17, 323] -> 
             RGBColor[
              0.3151837063156497, 0.44029240167692024`, 0.9415651086599703], 
             UndirectedEdge[315, 397] -> 
             RGBColor[
              0.21588466984352767`, 0.3442388542571554, 0.935605684623616], 
             UndirectedEdge[43, 296] -> 
             RGBColor[
              0.2526601828418626, 0.38289225012060224`, 0.937699995684375], 
             UndirectedEdge[50, 287] -> 
             RGBColor[
              0.18448432655099875`, 0.31123510255995407`, 0.9338174815257515],
              UndirectedEdge[253, 369] -> 
             RGBColor[
              0.19084530468760944`, 0.3179208938908398, 0.9341797298204076], 
             UndirectedEdge[187, 220] -> 
             RGBColor[
              0.5353714211663698, 0.63317812373389, 0.9567035702854296], 
             UndirectedEdge[211, 340] -> 
             RGBColor[
              0.21241214123474167`, 0.34058900651829105`, 0.9354079292564914],
              UndirectedEdge[213, 227] -> 
             RGBColor[
              0.2150440363795939, 0.343355295187321, 0.9355578117914507], 
             UndirectedEdge[17, 389] -> 
             RGBColor[
              0.21716250001380405`, 0.34558193478522814`, 0.9356784551614329],
              UndirectedEdge[117, 376] -> 
             RGBColor[
              0.217871456795024, 0.34632709331274647`, 0.9357188292013159], 
             UndirectedEdge[186, 330] -> 
             RGBColor[
              0.19639093276449526`, 0.3237497006127751, 0.9344955451353647], 
             UndirectedEdge[24, 337] -> 
             RGBColor[
              0.8785401737932351, 0.4370799726332635, 0.30949628574974347`], 
             UndirectedEdge[73, 99] -> 
             RGBColor[
              0.9481261161147958, 0.8682562660194123, 0.6030407890629428], 
             UndirectedEdge[114, 155] -> 
             RGBColor[
              0.2241859587617661, 0.352964035242341, 0.9360784307468533], 
             UndirectedEdge[123, 232] -> 
             RGBColor[
              0.2533953304852037, 0.3836649369048065, 0.9377418612551098], 
             UndirectedEdge[53, 289] -> 
             RGBColor[
              0.18928237138329773`, 0.3162781518923132, 0.9340907230808797], 
             UndirectedEdge[126, 376] -> 
             RGBColor[
              0.19809406452812484`, 0.3255398000811405, 0.9345925359697458], 
             UndirectedEdge[207, 254] -> 
             RGBColor[
              0.18750231875154622`, 0.3144072037144869, 0.9339893517168534], 
             UndirectedEdge[291, 304] -> 
             RGBColor[
              0.1840328398717771, 0.3107605614341833, 0.9337917700272845], 
             UndirectedEdge[333, 368] -> 
             RGBColor[
              0.18664235406415453`, 0.3135033263031278, 0.9339403780001101], 
             UndirectedEdge[26, 171] -> 
             RGBColor[
              0.18798107467478986`, 0.3149104065446947, 0.9340166161584262], 
             UndirectedEdge[81, 384] -> 
             RGBColor[
              0.18455785037421688`, 0.3113123807598359, 0.9338216685987151], 
             UndirectedEdge[120, 233] -> 
             RGBColor[
              0.7388527640498924, 0.7945317751585553, 0.9544100950493892], 
             UndirectedEdge[224, 290] -> 
             RGBColor[
              0.18877579274929696`, 0.3157457056290379, 0.9340618741770893], 
             UndirectedEdge[393, 396] -> 
             RGBColor[
              0.19146055662429076`, 0.3185675626855177, 0.9342147675080179], 
             UndirectedEdge[2, 365] -> 
             RGBColor[
              0.18295812271216946`, 0.3096309655584321, 0.9337305664749465], 
             UndirectedEdge[210, 387] -> 
             RGBColor[
              0.4198898949581986, 0.5356292280658739, 0.9485927029346032], 
             UndirectedEdge[23, 307] -> 
             RGBColor[
              0.32070535665531497`, 0.4507499650286162, 0.9417091542503788], 
             UndirectedEdge[120, 244] -> 
             RGBColor[
              0.7365322986249497, 0.7928011758440465, 0.9583380377395063], 
             UndirectedEdge[42, 248] -> 
             RGBColor[
              0.21725641238251098`, 0.34568064263912723`, 0.9356838033318999],
              UndirectedEdge[49, 393] -> 
             RGBColor[
              0.1855205539729795, 0.3123242432810691, 0.9338764931444723], 
             UndirectedEdge[375, 377] -> 
             RGBColor[
              0.18266643619111367`, 0.3093243845308089, 0.9337139553590839], 
             UndirectedEdge[269, 350] -> 
             RGBColor[
              0.8687159863176557, 0.8956679071093385, 0.8633270413739342], 
             UndirectedEdge[77, 207] -> 
             RGBColor[
              0.18528324242742453`, 0.31207481380026975`, 0.9338629786030239],
              UndirectedEdge[200, 368] -> 
             RGBColor[
              0.18469320535133593`, 0.3114546474227893, 0.9338293768644222], 
             UndirectedEdge[384, 389] -> 
             RGBColor[
              0.1961032591776717, 0.32344733743346465`, 0.93447916255017], 
             UndirectedEdge[1, 361] -> 
             RGBColor[
              0.205591391562574, 0.33341996615233593`, 0.9350194976530564], 
             UndirectedEdge[150, 380] -> 
             RGBColor[
              0.20683506244234898`, 0.3347271431002675, 0.9350903228698133], 
             UndirectedEdge[150, 381] -> 
             RGBColor[
              0.19485465175919953`, 0.32213497187036766`, 0.9344080562048372],
              UndirectedEdge[232, 279] -> 
             RGBColor[
              0.48366351594508233`, 0.5856826936906501, 0.9540410765507529], 
             UndirectedEdge[132, 341] -> 
             RGBColor[
              0.34725423307667924`, 0.4751958960109486, 0.9433477105601525], 
             UndirectedEdge[1, 14] -> 
             RGBColor[
              0.18904790384743964`, 0.31603171164602595`, 0.9340773705015762],
              UndirectedEdge[171, 342] -> 
             RGBColor[
              0.18633859981298379`, 0.3131840613260155, 0.9339230796448701], 
             UndirectedEdge[140, 325] -> 
             RGBColor[
              0.25741913844630737`, 0.3878942141960865, 0.9379710111658044], 
             UndirectedEdge[89, 306] -> 
             RGBColor[
              0.1959786892882613, 0.3233164065815071, 0.9344720684792528], 
             UndirectedEdge[130, 147] -> 
             RGBColor[
              0.18274418895711692`, 0.3094061076176884, 0.9337183832640827], 
             UndirectedEdge[4, 183] -> 
             RGBColor[
              0.2914028738694214, 0.4198002713108441, 0.9400459473606144], 
             UndirectedEdge[80, 151] -> 
             RGBColor[
              0.18591365690063838`, 0.3127374193822037, 0.9338988797746588], 
             UndirectedEdge[236, 286] -> 
             RGBColor[
              0.22281035809500455`, 0.3515181917234548, 0.9360000923239], 
             UndirectedEdge[108, 180] -> 
             RGBColor[
              0.25734842126298235`, 0.38781988595268346`, 0.9379669839268308],
              UndirectedEdge[9, 320] -> 
             RGBColor[
              0.1934136507337484, 0.32062038842787655`, 0.9343259933282078], 
             UndirectedEdge[35, 97] -> 
             RGBColor[
              0.21457055736469166`, 0.3428576387223553, 0.9355308478620015], 
             UndirectedEdge[154, 236] -> 
             RGBColor[
              0.22814394288837742`, 0.3571241275100973, 0.936303832087551], 
             UndirectedEdge[60, 259] -> 
             RGBColor[
              0.18612091931381164`, 0.3129552653196448, 0.9339106830624717], 
             UndirectedEdge[179, 399] -> 
             RGBColor[
              0.6902620685345601, 0.6570900539452929, 0.6049675909800379], 
             UndirectedEdge[314, 352] -> 
             RGBColor[
              0.23613835462959704`, 0.3655267611250992, 0.9367591020095412], 
             UndirectedEdge[85, 88] -> 
             RGBColor[
              0.21610734049788477`, 0.34447289523301966`, 0.9356183653879699],
              UndirectedEdge[70, 267] -> 
             RGBColor[
              0.23945129119348169`, 0.3690088675060522, 0.9369477688458039], 
             UndirectedEdge[31, 192] -> 
             RGBColor[
              0.18904880805086632`, 0.3160326620211572, 0.9340774219946237], 
             UndirectedEdge[221, 255] -> 
             RGBColor[
              0.8576770558672095, 0.3983014989226451, 0.2010622967587482], 
             UndirectedEdge[11, 211] -> 
             RGBColor[
              0.2669271143125195, 0.39759011071734907`, 0.9385233725149993], 
             UndirectedEdge[211, 312] -> 
             RGBColor[
              0.26239927833008236`, 0.39312865697304, 0.9382546227647286], 
             UndirectedEdge[123, 280] -> 
             RGBColor[
              0.23161694690439888`, 0.3607744749321087, 0.9365016145284144], 
             UndirectedEdge[178, 278] -> 
             RGBColor[
              0.349928065209785, 0.47283535767355744`, 0.9436893135230188], 
             UndirectedEdge[83, 364] -> 
             RGBColor[
              0.8601295771796166, 0.41076224408032325`, 0.4356827738189095], 
             UndirectedEdge[10, 313] -> 
             RGBColor[
              0.22793409689467709`, 0.35690356606571383`, 0.9362918816686491],
              UndirectedEdge[32, 242] -> 
             RGBColor[
              0.8871930329121218, 0.5574419643171217, 0.22765320532955294`], 
             UndirectedEdge[44, 369] -> 
             RGBColor[
              0.21363611782330827`, 0.34187548351747254`, 0.9354776329124991],
              UndirectedEdge[110, 375] -> 
             RGBColor[
              0.18201536929507323`, 0.30864007194304494`, 0.9336768780625215],
              UndirectedEdge[275, 290] -> 
             RGBColor[
              0.21848378643908228`, 0.34697069059259356`, 0.9357537004686844],
              UndirectedEdge[362, 369] -> 
             RGBColor[
              0.18988137332818844`, 0.31690774091531027`, 0.9341248353554973],
              UndirectedEdge[266, 338] -> 
             RGBColor[
              0.23347632110247196`, 0.3627287951054168, 0.936607503138297], 
             UndirectedEdge[350, 395] -> 
             RGBColor[
              0.7312446954176929, 0.785613119798958, 0.8514446443288036], 
             UndirectedEdge[141, 172] -> 
             RGBColor[
              0.8516660985539529, 0.38305028155577586`, 0.19651818563350704`],
              UndirectedEdge[123, 275] -> 
             RGBColor[
              0.22522408057531274`, 0.3540551670891031, 0.9361375502483711], 
             UndirectedEdge[46, 315] -> 
             RGBColor[
              0.21006971303598748`, 0.3381269659628746, 0.9352745314358842], 
             UndirectedEdge[185, 205] -> 
             RGBColor[
              0.3748090292582385, 0.49906247551909, 0.9451034778070919], 
             UndirectedEdge[3, 86] -> 
             RGBColor[
              0.49644576954540676`, 0.6009276484384913, 0.9538184872502891], 
             UndirectedEdge[316, 397] -> 
             RGBColor[
              0.2236385768767503, 0.3523887021751733, 0.9360472581582806], 
             UndirectedEdge[11, 214] -> 
             RGBColor[
              0.2758548681185897, 0.40697374601981373`, 0.9390317948868268], 
             UndirectedEdge[3, 34] -> 
             RGBColor[
              0.4225585018257533, 0.5327236209657705, 0.9492644797482566], 
             UndirectedEdge[5, 100] -> 
             RGBColor[
              0.24629351933764826`, 0.37620048310789195`, 0.9373374236164447],
              UndirectedEdge[25, 245] -> 
             RGBColor[
              0.8178226851727047, 0.13799854495365815`, 0.16470032949021304`],
              UndirectedEdge[183, 325] -> 
             RGBColor[
              0.3195630144976964, 0.44939836456720006`, 0.9416496257101998], 
             UndirectedEdge[149, 266] -> 
             RGBColor[
              0.22467790350563632`, 0.35348110035924685`, 0.9361064462722496],
              UndirectedEdge[73, 78] -> 
             RGBColor[
              0.8568301580726646, 0.357042989472686, 0.19882692230699478`], 
             UndirectedEdge[40, 167] -> 
             RGBColor[
              0.4156571514498516, 0.5326037138579458, 0.948214502475271], 
             UndirectedEdge[5, 175] -> 
             RGBColor[
              0.282045444074704, 0.41377802280949016`, 0.9393734428399871], 
             UndirectedEdge[279, 309] -> 
             RGBColor[
              0.48491537307549215`, 0.5869984749070372, 0.9541123679623731], 
             UndirectedEdge[66, 257] -> 
             RGBColor[
              0.268687595913645, 0.3984105456780595, 0.9386613405898359], 
             UndirectedEdge[238, 309] -> 
             RGBColor[
              0.29378936272937667`, 0.4261216259230004, 0.9400422416338], 
             UndirectedEdge[40, 355] -> 
             RGBColor[
              0.6433835290110301, 0.7194772226865849, 0.9663605408410356], 
             UndirectedEdge[31, 271] -> 
             RGBColor[
              0.18778814176396494`, 0.3147076218227647, 0.9340056289145733], 
             UndirectedEdge[271, 391] -> 
             RGBColor[
              0.1801133509320429, 0.3066409300485706, 0.9335685609305309], 
             UndirectedEdge[264, 348] -> 
             RGBColor[
              0.5282156563331551, 0.6233653822352514, 0.957751476691993], 
             UndirectedEdge[146, 302] -> 
             RGBColor[
              0.18875875182792845`, 0.3157277945402228, 0.9340609037218272], 
             UndirectedEdge[86, 91] -> 
             RGBColor[
              0.45216024233108254`, 0.5649746624056373, 0.950332168324746], 
             UndirectedEdge[232, 257] -> 
             RGBColor[
              0.30909861267997385`, 0.4408850865059202, 0.9409626882119364], 
             UndirectedEdge[201, 385] -> 
             RGBColor[
              0.9717345415002878, 0.9760010739812197, 0.8028741323146045], 
             UndirectedEdge[204, 297] -> 
             RGBColor[
              0.2002775476373886, 0.32783477926980176`, 0.9347168821026446], 
             UndirectedEdge[241, 323] -> 
             RGBColor[
              0.3309521511254019, 0.4568660369491151, 0.9424630982645621], 
             UndirectedEdge[269, 395] -> 
             RGBColor[
              0.6061102125080312, 0.6895560016714635, 0.9631945161165028], 
             UndirectedEdge[52, 342] -> 
             RGBColor[
              0.18153992013799802`, 0.30814034473374124`, 0.9336498019363901],
              UndirectedEdge[201, 245] -> 
             RGBColor[
              0.8622346252859692, 0.4176669244919702, 0.43415659032342135`], 
             UndirectedEdge[131, 330] -> 
             RGBColor[
              0.199593351679308, 0.3271156459373298, 0.9346779181550091], 
             UndirectedEdge[159, 349] -> 
             RGBColor[
              0.191248937492894, 0.31834513756099186`, 0.9342027161115474], 
             UndirectedEdge[15, 33] -> 
             RGBColor[
              0.28118366953987284`, 0.41287224313372134`, 0.9393243660551096],
              UndirectedEdge[16, 212] -> 
             RGBColor[
              0.36755596390986156`, 0.4927802348639901, 0.9446413188967272], 
             UndirectedEdge[246, 269] -> 
             RGBColor[
              0.8319134288403021, 0.869426735678431, 0.9836659653182612], 
             UndirectedEdge[150, 294] -> 
             RGBColor[
              0.19175282420721007`, 0.318874754446001, 0.9342314117144941], 
             UndirectedEdge[77, 200] -> 
             RGBColor[
              0.1835118014697444, 0.3102129170379042, 0.9337620976610961], 
             UndirectedEdge[21, 285] -> 
             RGBColor[
              0.9787005711665018, 0.9387674260406853, 0.4607634302742779], 
             UndirectedEdge[275, 280] -> 
             RGBColor[
              0.24514319627116127`, 0.3749914206303192, 0.9372719144195587], 
             UndirectedEdge[171, 353] -> 
             RGBColor[
              0.1894918158351776, 0.3164982912907842, 0.9341026506325689], 
             UndirectedEdge[197, 252] -> 
             RGBColor[
              0.6669388623748537, 0.7337127880117662, 0.9450324457252983], 
             UndirectedEdge[15, 361] -> 
             RGBColor[
              0.2517308007762076, 0.3819154106433724, 0.9376470687506336], 
             UndirectedEdge[348, 366] -> 
             RGBColor[
              0.3637695245894192, 0.4895006114365967, 0.9444000503314454], 
             UndirectedEdge[235, 298] -> 
             RGBColor[
              0.19425582793699694`, 0.3215055700656095, 0.9343739540740432], 
             UndirectedEdge[62, 298] -> 
             RGBColor[
              0.19905173523661984`, 0.32654637271559867`, 0.9346470738998478],
              UndirectedEdge[110, 308] -> 
             RGBColor[
              0.1924672891129, 0.3196257023615725, 0.9342720994339171], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.2089266760744028, 0.33692556164351994`, 0.9352094371718936], 
             UndirectedEdge[204, 290] -> 
             RGBColor[
              0.19592590704111568`, 0.32326092909316934`, 0.9344690626083623],
              UndirectedEdge[35, 93] -> 
             RGBColor[
              0.235285884487402, 0.3646307609559235, 0.9367105550960597], 
             UndirectedEdge[162, 211] -> 
             RGBColor[
              0.24710920905835015`, 0.37705782472206506`, 0.9373838759393338],
              UndirectedEdge[66, 275] -> 
             RGBColor[
              0.22651056308563722`, 0.3554073417751564, 0.9362108135241538], 
             UndirectedEdge[36, 277] -> 
             RGBColor[
              0.20034660319217895`, 0.3279073610362615, 0.9347208147143313], 
             UndirectedEdge[174, 246] -> 
             RGBColor[
              0.6321209059841302, 0.7058084285457353, 0.96769757273425], 
             UndirectedEdge[218, 329] -> 
             RGBColor[
              0.19065196008399016`, 0.31771767645368004`, 0.9341687191312593],
              UndirectedEdge[186, 188] -> 
             RGBColor[
              0.20431810644449144`, 0.33208166276229184`, 0.934946985949238], 
             UndirectedEdge[230, 245] -> 
             RGBColor[
              0.8181022296024069, 0.1401472459374997, 0.16496802155179616`], 
             UndirectedEdge[57, 368] -> 
             RGBColor[
              0.20142644533340448`, 0.3290423435926357, 0.9347823101267909], 
             UndirectedEdge[293, 316] -> 
             RGBColor[
              0.2916240499210687, 0.42013376007774095`, 0.9400548442196108], 
             UndirectedEdge[8, 308] -> 
             RGBColor[
              0.21965638014980107`, 0.34820316092929426`, 0.9358204779458129],
              UndirectedEdge[37, 361] -> 
             RGBColor[
              0.28321730845770904`, 0.41130658795806163`, 0.939575768828076], 
             UndirectedEdge[19, 331] -> 
             RGBColor[
              0.22977587045111889`, 0.35883938684872224`, 0.9363967679480286],
              UndirectedEdge[98, 276] -> 
             RGBColor[
              0.21193626472305038`, 0.34008883013219005`, 0.9353808287931467],
              UndirectedEdge[326, 336] -> 
             RGBColor[
              0.18618247361472157`, 0.3130199627926692, 0.9339141884888471], 
             UndirectedEdge[4, 13] -> 
             RGBColor[
              0.22349076802527734`, 0.3522333457006528, 0.9360388406628528], 
             UndirectedEdge[137, 300] -> 
             RGBColor[
              0.624581474397714, 0.6994688662935715, 0.9671293704856514], 
             UndirectedEdge[57, 163] -> 
             RGBColor[
              0.24223777275819017`, 0.37193763630369614`, 0.9371064548486839],
              UndirectedEdge[28, 304] -> 
             RGBColor[
              0.1939396212205168, 0.3211732167579251, 0.9343559465693256], 
             UndirectedEdge[83, 328] -> 
             RGBColor[
              0.9072826236616158, 0.729489427357416, 0.5953860262532737], 
             UndirectedEdge[206, 321] -> 
             RGBColor[
              0.6423373781810662, 0.7191701000468311, 0.9659074859341975], 
             UndirectedEdge[295, 373] -> 
             RGBColor[
              0.3504430057094734, 0.4745466699427852, 0.9436757963662827], 
             UndirectedEdge[29, 235] -> 
             RGBColor[
              0.18647615617022215`, 0.31332864177904984`, 0.9339309132759184],
              UndirectedEdge[234, 392] -> 
             RGBColor[
              0.888403326572227, 0.9115564131866241, 0.8883516579502622], 
             UndirectedEdge[42, 275] -> 
             RGBColor[
              0.2276321474655179, 0.3565861980709679, 0.9362746860953526], 
             UndirectedEdge[107, 324] -> 
             RGBColor[
              0.4908741561658506, 0.5947099474856988, 0.9538480411311054], 
             UndirectedEdge[75, 329] -> 
             RGBColor[
              0.20420501368883298`, 0.3319627951056, 0.934940545484109], 
             UndirectedEdge[267, 383] -> 
             RGBColor[
              0.23217032750693795`, 0.361356113031734, 0.9365331287350758], 
             UndirectedEdge[253, 362] -> 
             RGBColor[
              0.19012900620093326`, 0.31716801876539596`, 0.9341389376812601],
              UndirectedEdge[137, 252] -> 
             RGBColor[
              0.35201484785933657`, 0.47931930126023004`, 0.943651052724457], 
             UndirectedEdge[131, 203] -> 
             RGBColor[
              0.2195067441810682, 0.34804588403868764`, 0.9358119563987601], 
             UndirectedEdge[52, 199] -> 
             RGBColor[
              0.1829276009104009, 0.30959888520957934`, 0.9337288283034887], 
             UndirectedEdge[41, 386] -> 
             RGBColor[
              0.8163158098721861, 0.8568507653484726, 0.982215097641526], 
             UndirectedEdge[59, 122] -> 
             RGBColor[
              0.472237479074957, 0.5795226558414852, 0.9523966975119249], 
             UndirectedEdge[32, 172] -> 
             RGBColor[
              0.8682128995601259, 0.4115523422262132, 0.2094778081966871], 
             UndirectedEdge[55, 156] -> 
             RGBColor[
              0.8778676863998269, 0.46477366600547654`, 0.23296809956810122`],
              UndirectedEdge[97, 214] -> 
             RGBColor[
              0.21631731839459667`, 0.3446935953158315, 0.9356303233185532], 
             UndirectedEdge[133, 155] -> 
             RGBColor[
              0.1964342499678622, 0.3237952297399831, 0.9344980119860145], 
             UndirectedEdge[186, 273] -> 
             RGBColor[
              0.19433831903215518`, 0.3215922734368583, 0.9343786518198778], 
             UndirectedEdge[74, 179] -> 
             RGBColor[
              0.6585040630153561, 0.7306095985445278, 0.968478117009276], 
             UndirectedEdge[10, 62] -> 
             RGBColor[
              0.21930338871384658`, 0.34783214454915645`, 0.9358003756057394],
              UndirectedEdge[273, 322] -> 
             RGBColor[
              0.19086506728942945`, 0.31794166563837395`, 0.9341808552713451],
              UndirectedEdge[18, 148] -> 
             RGBColor[
              0.46955925293009415`, 0.5770080258985608, 0.9522798906351313], 
             UndirectedEdge[78, 172] -> 
             RGBColor[
              0.8212261277666325, 0.16415889612864146`, 0.16795946996179692`],
              UndirectedEdge[84, 269] -> 
             RGBColor[
              0.5412096627237364, 0.6337584063867442, 0.9589441687264177], 
             UndirectedEdge[103, 254] -> 
             RGBColor[
              0.19079740219879987`, 0.3178705453379077, 0.9341770018445352], 
             UndirectedEdge[46, 343] -> 
             RGBColor[
              0.19165716183089215`, 0.31877420722314587`, 0.9342259638836825],
              UndirectedEdge[1, 317] -> 
             RGBColor[
              0.19445041549410247`, 0.3217100939256911, 0.9343850355475539], 
             UndirectedEdge[27, 399] -> 
             RGBColor[
              0.8562175118599777, 0.35734498320723135`, 0.1984462235105148], 
             UndirectedEdge[247, 253] -> 
             RGBColor[
              0.19436046466415727`, 0.3216155499002067, 0.9343799129808589], 
             UndirectedEdge[27, 357] -> 
             RGBColor[
              0.8330589874809773, 0.2551114410852856, 0.1792906297875571], 
             UndirectedEdge[41, 55] -> 
             RGBColor[
              0.9217511656674453, 0.9083191148939446, 0.6659672564832814], 
             UndirectedEdge[183, 272] -> 
             RGBColor[
              0.5454600938051113, 0.6375523889526532, 0.9591673986184688], 
             UndirectedEdge[131, 238] -> 
             RGBColor[
              0.2516193138752771, 0.38179823084181674`, 0.9376407197365557], 
             UndirectedEdge[13, 131] -> 
             RGBColor[
              0.21370957013719966`, 0.34195268655651806`, 0.9354818159131122],
              UndirectedEdge[55, 328] -> 
             RGBColor[
              0.9205810406494127, 0.7082097000834948, 0.27856954387058575`], 
             UndirectedEdge[40, 392] -> 
             RGBColor[
              0.7560719179586157, 0.8063199638581745, 0.8764325252109648], 
             UndirectedEdge[39, 347] -> 
             RGBColor[
              0.19051344323313968`, 0.3175720864609606, 0.9341608308015206], 
             UndirectedEdge[195, 362] -> 
             RGBColor[
              0.1955066853579723, 0.3228203005239958, 0.9344451885536901], 
             UndirectedEdge[46, 250] -> 
             RGBColor[
              0.22982046644249732`, 0.3588862600632101, 0.9363993076237638], 
             UndirectedEdge[22, 47] -> 
             RGBColor[
              0.4301895095994409, 0.5445652207348299, 0.9493133718661378], 
             UndirectedEdge[79, 100] -> 
             RGBColor[
              0.22059571881103596`, 0.3491904654197632, 0.9358739718929432], 
             UndirectedEdge[45, 148] -> 
             RGBColor[
              0.30939380782769543`, 0.44018999619208, 0.9410163102615399], 
             UndirectedEdge[65, 68] -> 
             RGBColor[
              0.2789862434779228, 0.41056260901775243`, 0.9391992258916821], 
             UndirectedEdge[86, 162] -> 
             RGBColor[
              0.3416757625403587, 0.46699709267346645`, 0.9431155381732708], 
             UndirectedEdge[3, 264] -> 
             RGBColor[
              0.652580274743898, 0.7275933060781521, 0.9666403041170564], 
             UndirectedEdge[55, 386] -> 
             RGBColor[
              0.8661959692237846, 0.8644995898414272, 0.6605413251423246], 
             UndirectedEdge[315, 362] -> 
             RGBColor[
              0.20400552952862408`, 0.3317531246051941, 0.9349291851562955], 
             UndirectedEdge[92, 182] -> 
             RGBColor[
              0.4229610876060558, 0.5395726978389508, 0.9485023279906137], 
             UndirectedEdge[202, 341] -> 
             RGBColor[
              0.2897972028384973, 0.4193840622352309, 0.9399079526486953], 
             UndirectedEdge[86, 125] -> 
             RGBColor[
              0.3362672755569396, 0.46131242993601224`, 0.9428075328407044], 
             UndirectedEdge[155, 353] -> 
             RGBColor[
              0.19855109199898685`, 0.3260201649302318, 0.9346185630080999], 
             UndirectedEdge[119, 235] -> 
             RGBColor[
              0.18696497458482364`, 0.31384242092567355`, 0.9339587507614879],
              UndirectedEdge[139, 204] -> 
             RGBColor[
              0.19084712474135193`, 0.31792280688272123`, 0.9341798334697757],
              UndirectedEdge[167, 174] -> 
             RGBColor[
              0.3271254190729118, 0.4577613290244936, 0.9420651203310438], 
             UndirectedEdge[218, 349] -> 
             RGBColor[
              0.19642311196174383`, 0.3237835229893623, 0.9344973776930432], 
             UndirectedEdge[362, 397] -> 
             RGBColor[
              0.20104421515641585`, 0.32864059544182767`, 0.9347605426836703],
              UndirectedEdge[70, 108] -> 
             RGBColor[
              0.2395346657598989, 0.3690964994616095, 0.9369525169040198], 
             UndirectedEdge[71, 157] -> 
             RGBColor[
              0.18316059011768585`, 0.3098437716388048, 0.933742096694167], 
             UndirectedEdge[186, 238] -> 
             RGBColor[
              0.24841689496046435`, 0.37843228551726205`, 0.9374583467169113],
              UndirectedEdge[51, 246] -> 
             RGBColor[
              0.6509116591793556, 0.7220840345127228, 0.9688949029118392], 
             UndirectedEdge[109, 305] -> 
             RGBColor[
              0.1817778659169268, 0.3083904408340291, 0.9336633525964908], 
             UndirectedEdge[125, 248] -> 
             RGBColor[
              0.2397553776330553, 0.3693284816342379, 0.936965086118682], 
             UndirectedEdge[106, 390] -> 
             RGBColor[
              0.24476481400135702`, 0.3745937168739334, 0.9372503661090598], 
             UndirectedEdge[1, 231] -> 
             RGBColor[
              0.1878698717924256, 0.3147935252646599, 0.9340102833187854], 
             UndirectedEdge[104, 399] -> 
             RGBColor[
              0.8548647695138434, 0.3469472127593665, 0.19715083591215254`], 
             UndirectedEdge[244, 366] -> 
             RGBColor[
              0.6745824127024198, 0.7409076895841773, 0.9539031392335773], 
             UndirectedEdge[64, 289] -> 
             RGBColor[
              0.18340551527321602`, 0.3101012035064188, 0.9337560448194401], 
             UndirectedEdge[160, 233] -> 
             RGBColor[
              0.7095149174779228, 0.7707139896565038, 0.9521005122991707], 
             UndirectedEdge[100, 302] -> 
             RGBColor[
              0.20076131207818187`, 0.3283432463695126, 0.9347444317718824], 
             UndirectedEdge[177, 337] -> 
             RGBColor[
              0.9444496695413749, 0.9543350995105044, 0.7916221237493946], 
             UndirectedEdge[124, 219] -> 
             RGBColor[
              0.32342751125618663`, 0.45455838713589725`, 0.9418294929148936],
              UndirectedEdge[2, 181] -> 
             RGBColor[
              0.1899547149925528, 0.3169848276546873, 0.9341290120547836], 
             UndirectedEdge[185, 198] -> 
             RGBColor[
              0.3764542800383526, 0.5004875090521163, 0.9452083117319626], 
             UndirectedEdge[11, 35] -> 
             RGBColor[
              0.27410810708868466`, 0.4051377894263376, 0.9389323194302751], 
             UndirectedEdge[5, 56] -> 
             RGBColor[
              0.3320449689742487, 0.4595901829717516, 0.9424676449298229], 
             UndirectedEdge[69, 107] -> 
             RGBColor[
              0.2952174792692931, 0.42393616514341426`, 0.9402585516481101], 
             UndirectedEdge[51, 350] -> 
             RGBColor[
              0.6877142166567092, 0.7483252059436304, 0.8485559789675121], 
             UndirectedEdge[226, 392] -> 
             RGBColor[
              0.7181621296927883, 0.7753237626808771, 0.8735087285822702], 
             UndirectedEdge[81, 292] -> 
             RGBColor[
              0.18697166352319156`, 0.31384945142400145`, 0.9339591316866327],
              UndirectedEdge[51, 272] -> 
             RGBColor[
              0.5612556230240568, 0.6512336824557214, 0.9601738757728618], 
             UndirectedEdge[10, 261] -> 
             RGBColor[
              0.24873551087533646`, 0.3787671710452084, 0.9374764914219134], 
             UndirectedEdge[132, 244] -> 
             RGBColor[
              0.656519419340629, 0.7252624326066381, 0.9527521812690418], 
             UndirectedEdge[53, 376] -> 
             RGBColor[
              0.20099948384788677`, 0.3285935800004348, 0.9347579953018235], 
             UndirectedEdge[242, 364] -> 
             RGBColor[
              0.8407413242303493, 0.31416124776238763`, 0.18664724413471406`],
              UndirectedEdge[29, 327] -> 
             RGBColor[
              0.18852270839333474`, 0.31547969792444663`, 0.934047461397422], 
             UndirectedEdge[328, 364] -> 
             RGBColor[
              0.8349616655917271, 0.2580702663621064, 0.18065582548812142`], 
             UndirectedEdge[257, 279] -> 
             RGBColor[
              0.4976692988631992, 0.5990761277778498, 0.9548872926096961], 
             UndirectedEdge[13, 322] -> 
             RGBColor[
              0.20703389947966117`, 0.33493613343347894`, 0.9351016463449351],
              UndirectedEdge[21, 24] -> 
             RGBColor[
              0.868258601963509, 0.40303301389979596`, 0.21554172931270557`], 
             UndirectedEdge[56, 122] -> 
             RGBColor[
              0.48980661456960395`, 0.5947401579565226, 0.9535161872898672], 
             UndirectedEdge[87, 393] -> 
             RGBColor[
              0.1907711086239872, 0.3178429091236707, 0.9341755044643476], 
             UndirectedEdge[27, 74] -> 
             RGBColor[
              0.8350455081805084, 0.40635801294005464`, 0.44078657419667344`],
              UndirectedEdge[93, 288] -> 
             RGBColor[
              0.2698457094938153, 0.4009553282571281, 0.9386786860034955], 
             UndirectedEdge[125, 211] -> 
             RGBColor[
              0.24170072207493107`, 0.37137316198461084`, 0.9370758706067677],
              UndirectedEdge[265, 304] -> 
             RGBColor[
              0.18543662898340038`, 0.31223603279586976`, 0.9338717137404716],
              UndirectedEdge[195, 343] -> 
             RGBColor[
              0.19193458883998876`, 0.3190658005995948, 0.9342417629414341], 
             UndirectedEdge[199, 393] -> 
             RGBColor[
              0.1849265278957996, 0.3116998842105244, 0.9338426642381596], 
             UndirectedEdge[24, 208] -> 
             RGBColor[
              0.8781963258003285, 0.43764816511070226`, 0.36683204243282114`],
              UndirectedEdge[135, 386] -> 
             RGBColor[
              0.8778014359212141, 0.9022038387539937, 0.8283895042121832], 
             UndirectedEdge[32, 357] -> 
             RGBColor[
              0.8904110749094791, 0.5821772452638048, 0.2307348059804809], 
             UndirectedEdge[230, 233] -> 
             RGBColor[
              0.8649609956701637, 0.4146486695132347, 0.42761257006752507`], 
             UndirectedEdge[46, 161] -> 
             RGBColor[
              0.20037426040526207`, 0.3279364305207805, 0.9347223897517012], 
             UndirectedEdge[114, 306] -> 
             RGBColor[
              0.2220014868268114, 0.35066801673518333`, 0.9359540283017942], 
             UndirectedEdge[233, 357] -> 
             RGBColor[
              0.8912024440522681, 0.6163519408540925, 0.4527414106737052], 
             UndirectedEdge[134, 395] -> 
             RGBColor[
              0.6498035533941702, 0.7237783527330339, 0.9675259002297822], 
             UndirectedEdge[108, 267] -> 
             RGBColor[
              0.2560701403937588, 0.38647633171144136`, 0.9378941877223754], 
             UndirectedEdge[217, 233] -> 
             RGBColor[
              0.9762379710154455, 0.9784153903456743, 0.7203221374649382], 
             UndirectedEdge[245, 400] -> 
             RGBColor[
              0.829279530588777, 0.22606087924326346`, 0.17567141759930008`], 
             UndirectedEdge[269, 392] -> 
             RGBColor[
              0.8673327084378479, 0.8950958861574181, 0.8862515356507488], 
             UndirectedEdge[232, 288] -> 
             RGBColor[
              0.30023200699341346`, 0.43289325353174246`, 0.9404091406935988],
              UndirectedEdge[260, 341] -> 
             RGBColor[
              0.2804084248139549, 0.4095158612485281, 0.93937327562965], 
             UndirectedEdge[47, 323] -> 
             RGBColor[
              0.4713973595467131, 0.580257389192397, 0.951939099626107], 
             UndirectedEdge[142, 377] -> 
             RGBColor[
              0.18361252498065594`, 0.31031878383411166`, 0.9337678337160353],
              UndirectedEdge[53, 117] -> 
             RGBColor[
              0.20926903428907379`, 0.33728540183390365`, 0.9352289339657456],
              UndirectedEdge[251, 308] -> 
             RGBColor[
              0.1958872147734443, 0.3232202610666153, 0.9344668591409584], 
             UndirectedEdge[85, 162] -> 
             RGBColor[
              0.2565370723370653, 0.38696710678905155`, 0.9379207788057828], 
             UndirectedEdge[249, 397] -> 
             RGBColor[
              0.26099988066146607`, 0.3916272530178875, 0.9381760476598446], 
             UndirectedEdge[262, 284] -> 
             RGBColor[
              0.24537509181412387`, 0.37523515754899955`, 0.9372851205276718],
              UndirectedEdge[307, 341] -> 
             RGBColor[
              0.3422947785820742, 0.4709002657971524, 0.9430316985052297], 
             UndirectedEdge[7, 387] -> 
             RGBColor[
              0.4913856837463006, 0.597841186558023, 0.9531378831854276], 
             UndirectedEdge[228, 368] -> 
             RGBColor[
              0.19438368850365684`, 0.3216399596279972, 0.9343812355441619], 
             UndirectedEdge[240, 399] -> 
             RGBColor[
              0.8633179697637215, 0.41192221409589935`, 0.20524563001796006`],
              UndirectedEdge[105, 114] -> 
             RGBColor[
              0.22538318625918102`, 0.3542223972507317, 0.9361466110816916], 
             UndirectedEdge[78, 357] -> 
             RGBColor[
              0.8323252154413091, 0.24947134764743728`, 0.17858796885369382`],
              UndirectedEdge[359, 369] -> 
             RGBColor[
              0.18890080078567878`, 0.31587709700124245`, 0.9340689931998285],
              UndirectedEdge[48, 354] -> 
             RGBColor[
              0.22802037271409625`, 0.35699424742212627`, 0.9362967949489314],
              UndirectedEdge[280, 325] -> 
             RGBColor[
              0.2703375929737152, 0.4014723289817168, 0.9387066980399994], 
             UndirectedEdge[259, 262] -> 
             RGBColor[
              0.20019420515358305`, 0.3277471810351035, 0.934712135871486], 
             UndirectedEdge[120, 187] -> 
             RGBColor[
              0.47660974925846794`, 0.585472751295903, 0.952077636221743], 
             UndirectedEdge[70, 198] -> 
             RGBColor[
              0.2881120186842996, 0.4160342955793074, 0.9398697816662858], 
             UndirectedEdge[62, 235] -> 
             RGBColor[
              0.1963098901939031, 0.32366451973268695`, 0.9344909298808612], 
             UndirectedEdge[65, 176] -> 
             RGBColor[
              0.26080757186847375`, 0.39145567256187075`, 0.9381639774364586],
              UndirectedEdge[199, 342] -> 
             RGBColor[
              0.18510212262202141`, 0.31188444540113214`, 0.9338526640980489],
              UndirectedEdge[324, 390] -> 
             RGBColor[
              0.4479202761383373, 0.5532491979543472, 0.9512669003180385], 
             UndirectedEdge[226, 234] -> 
             RGBColor[
              0.6154815427973135, 0.6962991925345092, 0.964434228392668], 
             UndirectedEdge[47, 201] -> 
             RGBColor[
              0.7465737093465549, 0.8011421937069441, 0.9641963866302764], 
             UndirectedEdge[160, 264] -> 
             RGBColor[
              0.5914575736276367, 0.6779711437656651, 0.9618285011853527], 
             UndirectedEdge[277, 314] -> 
             RGBColor[
              0.22024480085065679`, 0.34882162839392095`, 0.9358539876342362],
              UndirectedEdge[4, 66] -> 
             RGBColor[
              0.22354481915991609`, 0.35229015687019793`, 0.9360419187950089],
              UndirectedEdge[23, 75] -> 
             RGBColor[0.255511442446525, 0.3858891047454028, 0.9378623707008],
              UndirectedEdge[287, 391] -> 
             RGBColor[
              0.18552964693238397`, 0.31233380055793014`, 0.9338770109750585],
              UndirectedEdge[45, 91] -> 
             RGBColor[
              0.38905361359871204`, 0.5081017700405416, 0.9463921022645131], 
             UndirectedEdge[175, 314] -> 
             RGBColor[
              0.25716282410855407`, 0.38762481157584006`, 0.9379564144434523],
              UndirectedEdge[195, 358] -> 
             RGBColor[
              0.1963120650172806, 0.3236668056099485, 0.9344910537338352], 
             UndirectedEdge[321, 341] -> 
             RGBColor[
              0.44529829620254, 0.5573731665864943, 0.9503530478730258], 
             UndirectedEdge[91, 148] -> 
             RGBColor[
              0.4136380232673186, 0.5316086524356322, 0.9478775665898638], 
             UndirectedEdge[115, 350] -> 
             RGBColor[
              0.9076888516719018, 0.6493073877623174, 0.38968437055635197`], 
             UndirectedEdge[142, 277] -> 
             RGBColor[
              0.19515207298431664`, 0.32244758043556054`, 0.9344249939036124],
              UndirectedEdge[45, 66] -> 
             RGBColor[
              0.2495400971941441, 0.37961284227999426`, 0.9375223114224907], 
             UndirectedEdge[259, 335] -> 
             RGBColor[
              0.18286996403264408`, 0.3095383051966678, 0.9337255459685665], 
             UndirectedEdge[118, 173] -> 
             RGBColor[
              0.26068055800241224`, 0.3913221729354959, 0.9381567441846866], 
             UndirectedEdge[52, 128] -> 
             RGBColor[
              0.18698858591777334`, 0.3138672379336487, 0.9339600953919696], 
             UndirectedEdge[27, 225] -> 
             RGBColor[
              0.84226224924205, 0.4121124463693103, 0.4414749134015841], 
             UndirectedEdge[302, 352] -> 
             RGBColor[
              0.21548876733628058`, 0.34382273562037, 0.9355831385615135], 
             UndirectedEdge[25, 242] -> 
             RGBColor[
              0.8289704754072247, 0.2236853456890081, 0.17537546600841764`], 
             UndirectedEdge[30, 224] -> 
             RGBColor[
              0.17977250803868983`, 0.30628268255696894`, 0.9335491504319864],
              UndirectedEdge[313, 361] -> 
             RGBColor[
              0.2180016041011253, 0.34646388638327474`, 0.9357262408978626], 
             UndirectedEdge[270, 310] -> 
             RGBColor[
              0.3193491673301014, 0.4483310995882432, 0.9416682954109477], 
             UndirectedEdge[72, 370] -> 
             RGBColor[
              0.18495091945082137`, 0.31172552128136616`, 0.9338440533011341],
              UndirectedEdge[283, 380] -> 
             RGBColor[
              0.2145522876760556, 0.34283843612123366`, 0.9355298074302612], 
             UndirectedEdge[34, 35] -> 
             RGBColor[
              0.24974982719833305`, 0.3798332818120472, 0.9375342552359615], 
             UndirectedEdge[25, 230] -> 
             RGBColor[
              0.8174587722148511, 0.13520135049192075`, 0.16435184603079156`],
              UndirectedEdge[191, 211] -> 
             RGBColor[
              0.2145566630341047, 0.342843034899957, 0.9355300566004294], 
             UndirectedEdge[17, 173] -> 
             RGBColor[
              0.25707808713188923`, 0.38753574764073073`, 0.9379515887979883],
              UndirectedEdge[40, 51] -> 
             RGBColor[
              0.4513189432678153, 0.5634921655168925, 0.9504868403154272], 
             UndirectedEdge[105, 202] -> 
             RGBColor[
              0.2264175602160962, 0.35530958986254624`, 0.9362055171483188], 
             UndirectedEdge[183, 309] -> 
             RGBColor[
              0.3237917248354433, 0.45384300724789295`, 0.9418904445081182], 
             UndirectedEdge[187, 261] -> 
             RGBColor[
              0.3474451829775207, 0.4708516166188276, 0.9435249988507737], 
             UndirectedEdge[190, 274] -> 
             RGBColor[
              0.7246489008143902, 0.7831056857849257, 0.9561147753018562], 
             UndirectedEdge[176, 354] -> 
             RGBColor[
              0.22476081103687653`, 0.35356824143122134`, 0.936111167733503], 
             UndirectedEdge[42, 148] -> 
             RGBColor[
              0.27524609124263133`, 0.40429858097089644`, 0.9390716483190401],
              UndirectedEdge[320, 380] -> 
             RGBColor[
              0.20795844756120663`, 0.3359078920869173, 0.9351542979904328], 
             UndirectedEdge[51, 222] -> 
             RGBColor[
              0.3069819930795281, 0.4332541041734357, 0.9410401002851541], 
             UndirectedEdge[122, 319] -> 
             RGBColor[
              0.5256622973684795, 0.6257953596771879, 0.9558012080947398], 
             UndirectedEdge[27, 78] -> 
             RGBColor[
              0.8206713505927768, 0.15989463566547976`, 0.1674282147135816], 
             UndirectedEdge[5, 178] -> 
             RGBColor[
              0.36206488822589933`, 0.4855919281825182, 0.9443804876389659], 
             UndirectedEdge[196, 336] -> 
             RGBColor[
              0.18504438325654066`, 0.31182375766712467`, 0.9338493759266024],
              UndirectedEdge[297, 318] -> 
             RGBColor[
              0.20065548392565413`, 0.32823201427131354`, 0.9347384050151546],
              UndirectedEdge[127, 235] -> 
             RGBColor[
              0.19315907110692182`, 0.32035280909880115`, 0.9343114953950769],
              UndirectedEdge[45, 203] -> 
             RGBColor[
              0.2552832201033739, 0.38564922859261863`, 0.9378493737759823], 
             UndirectedEdge[305, 370] -> 
             RGBColor[
              0.18466045373978385`, 0.311420223402476, 0.9338275117085959], 
             UndirectedEdge[122, 169] -> 
             RGBColor[
              0.7468757612194565, 0.8021168965628588, 0.9757076451280708], 
             UndirectedEdge[51, 226] -> 
             RGBColor[
              0.41340915500198794`, 0.532495964339595, 0.9475630436867326], 
             UndirectedEdge[226, 395] -> 
             RGBColor[
              0.45693963376297164`, 0.5697838781949226, 0.9504517090480242], 
             UndirectedEdge[61, 354] -> 
             RGBColor[
              0.21260864100273835`, 0.3407955402332605, 0.9354191196275834], 
             UndirectedEdge[211, 334] -> 
             RGBColor[
              0.20343525046697647`, 0.3311537251536216, 0.9348967086073869], 
             UndirectedEdge[10, 361] -> 
             RGBColor[
              0.22756848714061534`, 0.35651928703319763`, 0.9362710607340264],
              UndirectedEdge[44, 249] -> 
             RGBColor[
              0.27287548484168234`, 0.4041092659680885, 0.9388523457495259], 
             UndirectedEdge[302, 377] -> 
             RGBColor[
              0.18805566555367964`, 0.3149888062877428, 0.9340208639986316], 
             UndirectedEdge[149, 363] -> 
             RGBColor[
              0.21825217126115545`, 0.34672724835534197`, 0.9357405103269454],
              UndirectedEdge[358, 359] -> 
             RGBColor[
              0.18898988195831087`, 0.3159707269617513, 0.934074066240826], 
             UndirectedEdge[126, 317] -> 
             RGBColor[
              0.1909701324562666, 0.31805209579023613`, 0.9341868385771666], 
             UndirectedEdge[194, 364] -> 
             RGBColor[
              0.8766286360480449, 0.42149048442570325`, 0.3251019422621857], 
             UndirectedEdge[184, 343] -> 
             RGBColor[
              0.18256566753029357`, 0.30921847027918486`, 0.933708216732924], 
             UndirectedEdge[118, 346] -> 
             RGBColor[
              0.2949738551719156, 0.42345379048504006`, 0.9402529639443298], 
             UndirectedEdge[169, 239] -> 
             RGBColor[
              0.8504381780289113, 0.4495162152727391, 0.44612017739748244`], 
             UndirectedEdge[72, 157] -> 
             RGBColor[
              0.1851041505972344, 0.3118865769316621, 0.9338527795882372], 
             UndirectedEdge[162, 191] -> 
             RGBColor[
              0.239776323432642, 0.3693504969976439, 0.936966278950982], 
             UndirectedEdge[84, 272] -> 
             RGBColor[
              0.5398855520007457, 0.6327240010263296, 0.9588121937440683], 
             UndirectedEdge[21, 160] -> 
             RGBColor[
              0.7114127926044326, 0.7298581356264684, 0.631074971265499], 
             UndirectedEdge[29, 336] -> 
             RGBColor[
              0.18089581060751259`, 0.30746334477829806`, 0.9336131208515035],
              UndirectedEdge[275, 276] -> 
             RGBColor[
              0.2308037275414878, 0.35991972982060355`, 0.9364553028887468], 
             UndirectedEdge[38, 303] -> 
             RGBColor[
              0.21808265414273661`, 0.3465490751158777, 0.9357308565778295], 
             UndirectedEdge[172, 285] -> 
             RGBColor[
              0.8806018302486532, 0.4526452874715283, 0.3169446377499939], 
             UndirectedEdge[73, 285] -> 
             RGBColor[
              0.9624071777351879, 0.8763102692580285, 0.43650448397981056`], 
             UndirectedEdge[5, 59] -> 
             RGBColor[
              0.31447583347960173`, 0.4443726808567142, 0.9413481551518805], 
             UndirectedEdge[73, 225] -> 
             RGBColor[
              0.9076627958063523, 0.836763929150959, 0.6259476546026368], 
             UndirectedEdge[64, 254] -> 
             RGBColor[
              0.1839453796797469, 0.3106686352270631, 0.9337867892987342], 
             UndirectedEdge[241, 390] -> 
             RGBColor[
              0.2629620790942533, 0.393720196259813, 0.938286673435659], 
             UndirectedEdge[58, 289] -> 
             RGBColor[
              0.19906319498854463`, 0.3265584176414619, 0.9346477265157667], 
             UndirectedEdge[262, 331] -> 
             RGBColor[
              0.20664951421908523`, 0.3345321201531805, 0.9350797561729924], 
             UndirectedEdge[22, 118] -> 
             RGBColor[
              0.2775783272389005, 0.4083866585141185, 0.9391445362866995], 
             UndirectedEdge[97, 360] -> 
             RGBColor[
              0.189069412661027, 0.31605431877284385`, 0.9340785953966906], 
             UndirectedEdge[301, 358] -> 
             RGBColor[
              0.18673627600332035`, 0.31360204421618604`, 0.9339457267156006],
              UndirectedEdge[16, 274] -> 
             RGBColor[
              0.4054269963890745, 0.5245026293096915, 0.9473527216519175], 
             UndirectedEdge[166, 319] -> 
             RGBColor[
              0.7215283330281927, 0.7785525624499918, 0.8852776399757938], 
             UndirectedEdge[82, 101] -> 
             RGBColor[
              0.181913405203708, 0.30853290121812327`, 0.9336710713583607], 
             UndirectedEdge[24, 399] -> 
             RGBColor[
              0.8560499214236114, 0.3560568096747217, 0.198285738719384], 
             UndirectedEdge[328, 400] -> 
             RGBColor[
              0.8566292392466625, 0.42461673226525787`, 0.20140471849011185`],
              UndirectedEdge[17, 371] -> 
             RGBColor[
              0.20911196002482746`, 0.33712030682309724`, 0.9352199888187673],
              UndirectedEdge[107, 158] -> 
             RGBColor[
              0.34368740964077826`, 0.4721064928245296, 0.9431204357248351], 
             UndirectedEdge[60, 394] -> 
             RGBColor[
              0.18321858514836378`, 0.3099047280931446, 0.933745399425368], 
             UndirectedEdge[219, 284] -> 
             RGBColor[
              0.3068620452246301, 0.43723797575946177`, 0.9408827842352088], 
             UndirectedEdge[124, 149] -> 
             RGBColor[
              0.2631665511656537, 0.3938441656371931, 0.9383016477132344], 
             UndirectedEdge[227, 296] -> 
             RGBColor[
              0.22621507415997788`, 0.35509676417920844`, 0.9361939858669741],
              UndirectedEdge[202, 229] -> 
             RGBColor[
              0.22512118954774685`, 0.35394702209546336`, 0.9361316907565649],
              UndirectedEdge[315, 358] -> 
             RGBColor[
              0.20481090918793238`, 0.33259962969114687`, 0.9349750503364407],
              UndirectedEdge[145, 222] -> 
             RGBColor[
              0.21482177415136725`, 0.3431216834932156, 0.9355451542863606], 
             UndirectedEdge[155, 299] -> 
             RGBColor[
              0.19737174909206562`, 0.3247806007603985, 0.9345514011742322], 
             UndirectedEdge[14, 29] -> 
             RGBColor[
              0.18299367418147944`, 0.3096683324067703, 0.9337325910785299], 
             UndirectedEdge[116, 151] -> 
             RGBColor[
              0.18767873323802545`, 0.31459262652510106`, 0.9339993982608765],
              UndirectedEdge[45, 257] -> 
             RGBColor[
              0.30395689687858984`, 0.4354808171950546, 0.9406698751035344], 
             UndirectedEdge[27, 240] -> 
             RGBColor[
              0.824588465564483, 0.19000329782873795`, 0.17117924843423588`], 
             UndirectedEdge[144, 188] -> 
             RGBColor[
              0.19616736828116454`, 0.3235147201659876, 0.934482813468773], 
             UndirectedEdge[76, 200] -> 
             RGBColor[
              0.1890554468047247, 0.31603963977238364`, 0.9340778000618348], 
             UndirectedEdge[90, 221] -> 
             RGBColor[
              0.755343522572024, 0.6711176068414135, 0.6012544985481333], 
             UndirectedEdge[271, 382] -> 
             RGBColor[
              0.18049565541513857`, 0.3070427562998084, 0.9335903326052744], 
             UndirectedEdge[242, 385] -> 
             RGBColor[
              0.8996573902074148, 0.5986962394475088, 0.343329755550243], 
             UndirectedEdge[74, 112] -> 
             RGBColor[
              0.9000839613583336, 0.841002686126469, 0.6275271765854877], 
             UndirectedEdge[237, 251] -> 
             RGBColor[
              0.19380336074719554`, 0.32102999836105145`, 0.9343481867369493],
              UndirectedEdge[25, 223] -> 
             RGBColor[
              0.854846716521594, 0.34268213742931986`, 0.19696394267101408`], 
             UndirectedEdge[284, 332] -> 
             RGBColor[
              0.2524716906122939, 0.382694132836228, 0.9376892613307504], 
             UndirectedEdge[145, 333] -> 
             RGBColor[
              0.19268508450271393`, 0.3198546191252922, 0.9342845025591675], 
             UndirectedEdge[146, 227] -> 
             RGBColor[
              0.19680598858419968`, 0.3241859505953433, 0.934519181950277], 
             UndirectedEdge[108, 286] -> 
             RGBColor[
              0.22549943873113315`, 0.3543445859695858, 0.9361532314879892], 
             UndirectedEdge[127, 361] -> 
             RGBColor[
              0.2062200768333135, 0.33408075423283157`, 0.9350553003491684], 
             UndirectedEdge[143, 258] -> 
             RGBColor[
              0.1842254727690224, 0.31096303082281923`, 0.9338027401858078], 
             UndirectedEdge[212, 310] -> 
             RGBColor[
              0.34846775564587945`, 0.473552157244567, 0.9435237061098725], 
             UndirectedEdge[107, 310] -> 
             RGBColor[
              0.3141088853648525, 0.4437922307341744, 0.9413343892779213], 
             UndirectedEdge[253, 394] -> 
             RGBColor[
              0.1857625991924869, 0.31257864815332465`, 0.9338902772616493], 
             UndirectedEdge[152, 284] -> 
             RGBColor[
              0.26668400229217915`, 0.3976321735243937, 0.9384986314556889], 
             UndirectedEdge[230, 364] -> 
             RGBColor[
              0.8177179178456022, 0.13719325736821295`, 0.1646000041794619], 
             UndirectedEdge[158, 241] -> 
             RGBColor[
              0.3009846875478195, 0.43090972620672763`, 0.9405535979845862], 
             UndirectedEdge[44, 315] -> 
             RGBColor[
              0.22776027402374388`, 0.3567208672073564, 0.9362819827132973], 
             UndirectedEdge[357, 385] -> 
             RGBColor[
              0.9028754322047721, 0.6234315203941919, 0.3464113562011709], 
             UndirectedEdge[99, 197] -> 
             RGBColor[
              0.9649742133445314, 0.9733984061785892, 0.9441737000062027], 
             UndirectedEdge[152, 267] -> 
             RGBColor[
              0.25637803396755154`, 0.3867999473790775, 0.9379117218059152], 
             UndirectedEdge[169, 197] -> 
             RGBColor[
              0.9300501065256308, 0.9463228877887528, 0.9676089006734437], 
             UndirectedEdge[263, 348] -> 
             RGBColor[
              0.36254614474277536`, 0.48844098130229274`, 0.9443220976494096],
              UndirectedEdge[314, 379] -> 
             RGBColor[
              0.21988806256935944`, 0.348446673841764, 0.9358336719168633], 
             UndirectedEdge[300, 319] -> 
             RGBColor[
              0.6840306200166372, 0.7509595396670409, 0.9709177458785374], 
             UndirectedEdge[25, 78] -> 
             RGBColor[
              0.8181918595177029, 0.1408361807425438, 0.1650538512599061], 
             UndirectedEdge[44, 113] -> 
             RGBColor[
              0.27210008577250266`, 0.4033248206617401, 0.9388070693975159], 
             UndirectedEdge[115, 221] -> 
             RGBColor[
              0.8771748206449487, 0.5351613717457232, 0.21922399843655038`], 
             UndirectedEdge[175, 319] -> 
             RGBColor[
              0.3675065660796395, 0.49023117564208835`, 0.944730223137449], 
             UndirectedEdge[176, 356] -> 
             RGBColor[
              0.21433034444536764`, 0.34260515971376704`, 0.9355171680916091],
              UndirectedEdge[84, 395] -> 
             RGBColor[
              0.4037383718237736, 0.5237036190763635, 0.9470617716812872], 
             UndirectedEdge[301, 359] -> 
             RGBColor[
              0.1849503238015024, 0.31172489521616553`, 0.9338440193797866], 
             UndirectedEdge[238, 280] -> 
             RGBColor[
              0.2707591220181621, 0.40191538273391547`, 0.9387307034954844], 
             UndirectedEdge[36, 168] -> 
             RGBColor[
              0.18854146293925098`, 0.3154994101413115, 0.9340485294410671], 
             UndirectedEdge[4, 232] -> 
             RGBColor[
              0.26395583592624494`, 0.3947646976980586, 0.9383432664171094], 
             UndirectedEdge[140, 339] -> 
             RGBColor[
              0.2386234653452058, 0.3681387700523239, 0.9369006253884031], 
             UndirectedEdge[18, 141] -> 
             RGBColor[
              0.7787784526106882, 0.5518341379822057, 0.46039508708597976`], 
             UndirectedEdge[123, 140] -> 
             RGBColor[
              0.21869849237699107`, 0.3471963601464784, 0.9357659276542193], 
             UndirectedEdge[24, 78] -> 
             RGBColor[
              0.8205037601564106, 0.15860646213297017`, 0.16726772992245081`],
              UndirectedEdge[62, 127] -> 
             RGBColor[
              0.1979549784065447, 0.32539361174879033`, 0.9345846152208812], 
             UndirectedEdge[299, 353] -> 
             RGBColor[
              0.188841530987085, 0.3158148006849981, 0.9340656178724803], 
             UndirectedEdge[256, 311] -> 
             RGBColor[
              0.32702639881790146`, 0.45712063802367703`, 0.942079129357128], 
             UndirectedEdge[47, 346] -> 
             RGBColor[
              0.44758503753245593`, 0.5596323527057516, 0.9504217995237683], 
             UndirectedEdge[34, 125] -> 
             RGBColor[
              0.2623800078372861, 0.3931084024632914, 0.9382535253386719], 
             UndirectedEdge[194, 387] -> 
             RGBColor[
              0.7643288542489235, 0.8116893614464729, 0.8013257295322668], 
             UndirectedEdge[117, 303] -> 
             RGBColor[
              0.21968824533158482`, 0.34823665325571823`, 0.9358222926207751],
              UndirectedEdge[287, 382] -> 
             RGBColor[
              0.18591195141547964`, 0.3127356268091679, 0.933898782649802], 
             UndirectedEdge[20, 168] -> 
             RGBColor[
              0.18724662483160132`, 0.31413845319269396`, 0.9339747903263778],
              UndirectedEdge[51, 355] -> 
             RGBColor[
              0.5736425498293158, 0.6609104438201203, 0.9614084888743977], 
             UndirectedEdge[183, 339] -> 
             RGBColor[
              0.30076734139659483`, 0.42964292042343744`, 0.9405792399327987],
              UndirectedEdge[118, 164] -> 
             RGBColor[
              0.21991695118991147`, 0.3484770376136085, 0.9358353170810669], 
             UndirectedEdge[51, 134] -> 
             RGBColor[
              0.6062730746331866, 0.6864904388777064, 0.9646372348684907], 
             UndirectedEdge[46, 356] -> 
             RGBColor[
              0.1981426064801053, 0.32559082075040946`, 0.9345953003620997], 
             UndirectedEdge[204, 276] -> 
             RGBColor[
              0.2082458481435212, 0.33620996832117933`, 0.9351706650284246], 
             UndirectedEdge[108, 154] -> 
             RGBColor[
              0.23083302352450608`, 0.3599505217562283, 0.9364569712516402], 
             UndirectedEdge[29, 119] -> 
             RGBColor[
              0.18192714786076558`, 0.30854734562202557`, 0.9336718539823496],
              UndirectedEdge[244, 264] -> 
             RGBColor[
              0.8390285444461558, 0.8747724603828321, 0.9672545655941249], 
             UndirectedEdge[217, 321] -> 
             RGBColor[
              0.7737155651854934, 0.8183397872541874, 0.7225530793389106], 
             UndirectedEdge[241, 346] -> 
             RGBColor[
              0.30713982911114474`, 0.4362410004624697, 0.9409457981622233], 
             UndirectedEdge[108, 284] -> 
             RGBColor[
              0.26637610871838646`, 0.39730855785675745`, 0.9384810973721491],
              UndirectedEdge[181, 334] -> 
             RGBColor[
              0.18995231521735206`, 0.3169823053387968, 0.934128875391136], 
             UndirectedEdge[8, 59] -> 
             RGBColor[
              0.2921622006654197, 0.4209196380029755, 0.9400774267731745], 
             UndirectedEdge[236, 383] -> 
             RGBColor[
              0.22956462143722656`, 0.3586173507411603, 0.9363847376292023], 
             UndirectedEdge[42, 290] -> 
             RGBColor[
              0.20736560396252507`, 0.33528477587624783`, 0.9351205364245214],
              UndirectedEdge[173, 209] -> 
             RGBColor[
              0.3086611648699239, 0.43934003290171275`, 0.940977513192154], 
             UndirectedEdge[154, 332] -> 
             RGBColor[
              0.2169286054184135, 0.3453360967356988, 0.9356651352102414], 
             UndirectedEdge[5, 352] -> 
             RGBColor[
              0.26102097459574697`, 0.3916799723587493, 0.9381761304060758], 
             UndirectedEdge[189, 226] -> 
             RGBColor[
              0.35594179006458193`, 0.47882793285764735`, 0.9440438043992346],
              UndirectedEdge[16, 390] -> 
             RGBColor[
              0.2902432136013212, 0.4215595588222458, 0.9398708612517093], 
             UndirectedEdge[119, 327] -> 
             RGBColor[
              0.18901152680793626`, 0.3159934770710704, 0.9340752988829915], 
             UndirectedEdge[129, 231] -> 
             RGBColor[
              0.18564063577461087`, 0.3124504568682096, 0.93388333162543], 
             UndirectedEdge[79, 352] -> 
             RGBColor[
              0.23532317406913467`, 0.3646699546706205, 0.9367126786825744], 
             UndirectedEdge[62, 361] -> 
             RGBColor[
              0.20937089592029476`, 0.33739246486671737`, 0.9352347348349528],
              UndirectedEdge[150, 347] -> 
             RGBColor[
              0.19569856946522865`, 0.3230219828868772, 0.9344561160697312], 
             UndirectedEdge[5, 90] -> 
             RGBColor[
              0.44540909938288953`, 0.5535702341777979, 0.950854414653335], 
             UndirectedEdge[24, 27] -> 
             RGBColor[
              0.8208706461762446, 0.16142650885189433`, 0.16761906038938248`],
              UndirectedEdge[62, 393] -> 
             RGBColor[
              0.19223452494535048`, 0.31938105246337734`, 0.9342588438589188],
              UndirectedEdge[199, 353] -> 
             RGBColor[
              0.18825533864421526`, 0.31519867536590085`, 0.9340322350857477],
              UndirectedEdge[96, 201] -> 
             RGBColor[
              0.8486214444306401, 0.8823678065342169, 0.9733384742305298], 
             UndirectedEdge[155, 170] -> 
             RGBColor[
              0.21937286170598153`, 0.34790516506873237`, 0.9358043319898652],
              UndirectedEdge[335, 394] -> 
             RGBColor[
              0.17996762986719622`, 0.30648776797016763`, 0.9335602623314629],
              UndirectedEdge[16, 310] -> 
             RGBColor[
              0.2986872977789616, 0.43043482667880517`, 0.9403517393537228], 
             UndirectedEdge[6, 277] -> 
             RGBColor[
              0.2567019144406389, 0.38714036629150045`, 0.9379301663197194], 
             UndirectedEdge[140, 232] -> 
             RGBColor[
              0.2603959916536444, 0.39102307566039235`, 0.9381405385521024], 
             UndirectedEdge[177, 300] -> 
             RGBColor[
              0.904775992937191, 0.9269078335507821, 0.990779535981055], 
             UndirectedEdge[24, 32] -> 
             RGBColor[
              0.8662019827363802, 0.39609555432953175`, 0.20755215197526236`],
              UndirectedEdge[102, 226] -> 
             RGBColor[
              0.3613558703292786, 0.48451847448835883`, 0.9443521282608951], 
             UndirectedEdge[187, 206] -> 
             RGBColor[
              0.5826167692195937, 0.6701866792756657, 0.9613440852325792], 
             UndirectedEdge[336, 396] -> 
             RGBColor[
              0.18995557631013382`, 0.31698573295407556`, 0.9341290611055455],
              UndirectedEdge[267, 332] -> 
             RGBColor[
              0.24216572228766625`, 0.37186190669091185`, 0.9371023516809767],
              UndirectedEdge[115, 300] -> 
             RGBColor[
              0.8813051840145343, 0.6303392266197287, 0.46973399593591275`], 
             UndirectedEdge[149, 195] -> 
             RGBColor[
              0.20922588183301488`, 0.33724004586656203`, 0.9352264764972114],
              UndirectedEdge[127, 396] -> 
             RGBColor[
              0.197181010085485, 0.3245801219709307, 0.9345405388699805], 
             UndirectedEdge[206, 220] -> 
             RGBColor[
              0.6830678662474279, 0.7522369451466808, 0.9691139391554754], 
             UndirectedEdge[298, 361] -> 
             RGBColor[
              0.2073168336633886, 0.33523351519963984`, 0.9351177590281349], 
             UndirectedEdge[27, 141] -> 
             RGBColor[
              0.8358913359864371, 0.269340328379047, 0.18170757254943665`], 
             UndirectedEdge[55, 221] -> 
             RGBColor[
              0.9369698505827507, 0.7826274582869746, 0.292244768605455], 
             UndirectedEdge[40, 269] -> 
             RGBColor[
              0.6323207129287618, 0.7108348666826005, 0.9652579027218493], 
             UndirectedEdge[191, 312] -> 
             RGBColor[
              0.25506639270437426`, 0.3854213292486189, 0.9378370257763766], 
             UndirectedEdge[78, 240] -> 
             RGBColor[
              0.8238546935248147, 0.18436320439088957`, 0.1704765875003726], 
             UndirectedEdge[183, 246] -> 
             RGBColor[
              0.63511612996041, 0.7084027410096546, 0.967888425757446], 
             UndirectedEdge[130, 164] -> 
             RGBColor[
              0.19148238974395732`, 0.318590510678587, 0.9342160108718838], 
             UndirectedEdge[190, 295] -> 
             RGBColor[
              0.6926270864337125, 0.7564495900659256, 0.953776079551644], 
             UndirectedEdge[18, 179] -> 
             RGBColor[
              0.5295441815391476, 0.6289468481238254, 0.9561068042364651], 
             UndirectedEdge[128, 199] -> 
             RGBColor[
              0.1905507884017967, 0.3176113386010396, 0.9341629575536283], 
             UndirectedEdge[350, 355] -> 
             RGBColor[
              0.879778802399924, 0.9043102631133229, 0.8644296794931206], 
             UndirectedEdge[233, 348] -> 
             RGBColor[
              0.6462730001834412, 0.7161082281260901, 0.948023487805811], 
             UndirectedEdge[247, 316] -> 
             RGBColor[
              0.21599089502507074`, 0.3443505036580227, 0.9356117339905587], 
             UndirectedEdge[74, 399] -> 
             RGBColor[
              0.8948180568355072, 0.820125129452121, 0.6232901061997559], 
             UndirectedEdge[155, 171] -> 
             RGBColor[
              0.19802203394015824`, 0.32546409136618454`, 0.9345884339343208],
              UndirectedEdge[21, 95] -> 
             RGBColor[
              0.7613060096832925, 0.7703636969149021, 0.6350027480788232], 
             UndirectedEdge[257, 325] -> 
             RGBColor[
              0.30612175947263687`, 0.43775622504161427`, 0.9407931608256381],
              UndirectedEdge[250, 372] -> 
             RGBColor[
              0.22620791914637717`, 0.35508924380626006`, 0.9361935783995345],
              UndirectedEdge[156, 400] -> 
             RGBColor[
              0.8373834049701799, 0.28835080887912395`, 0.18343169685894858`],
              UndirectedEdge[193, 360] -> 
             RGBColor[
              0.18609708652812662`, 0.31293021555080397`, 0.9339093258205844],
              UndirectedEdge[92, 135] -> 
             RGBColor[
              0.746116355711272, 0.7971097200029147, 0.816782693533676], 
             UndirectedEdge[102, 174] -> 
             RGBColor[
              0.3107339262181662, 0.44067229083220405`, 0.9411265427453626], 
             UndirectedEdge[140, 275] -> 
             RGBColor[
              0.23222474174375346`, 0.36141330584468895`, 0.9365362275453637],
              UndirectedEdge[101, 301] -> 
             RGBColor[
              0.1828984857165501, 0.3095682832948322, 0.9337271702362709], 
             UndirectedEdge[337, 398] -> 
             RGBColor[
              0.7100705314017086, 0.7665791120076357, 0.7708912737801167], 
             UndirectedEdge[149, 249] -> 
             RGBColor[
              0.2628399368216051, 0.3935612687084925, 0.9382808361360453], 
             UndirectedEdge[92, 165] -> 
             RGBColor[
              0.6970699985324673, 0.761675381939551, 0.9717947555325273], 
             UndirectedEdge[150, 320] -> 
             RGBColor[
              0.19466927104284892`, 0.32194012498366686`, 0.9343974990472872],
              UndirectedEdge[59, 175] -> 
             RGBColor[
              0.314081747786117, 0.4439584718063857, 0.9413257125546342], 
             UndirectedEdge[278, 379] -> 
             RGBColor[
              0.232633859519395, 0.36184331456645336`, 0.936559526197451], 
             UndirectedEdge[87, 317] -> 
             RGBColor[
              0.19676650353045996`, 0.3241444493003659, 0.9345169333348793], 
             UndirectedEdge[212, 324] -> 
             RGBColor[
              0.5252330264468776, 0.6244698739960914, 0.9560373579630563], 
             UndirectedEdge[135, 328] -> 
             RGBColor[
              0.932186507346842, 0.7459139489960613, 0.44641772294044424`], 
             UndirectedEdge[176, 344] -> 
             RGBColor[
              0.21245918803275743`, 0.3406384556859449, 0.9354106085020388], 
             UndirectedEdge[59, 213] -> 
             RGBColor[
              0.2845653105942021, 0.4129348248674753, 0.9396447951222104], 
             UndirectedEdge[371, 391] -> 
             RGBColor[
              0.18383722908563283`, 0.3105549620955055, 0.9337806302823939], 
             UndirectedEdge[98, 318] -> 
             RGBColor[
              0.1977029240139366, 0.3251286866009877, 0.9345702610961033], 
             UndirectedEdge[25, 244] -> 
             RGBColor[
              0.8631344742904997, 0.41134623565305395`, 0.42996350646602], 
             UndirectedEdge[204, 224] -> 
             RGBColor[
              0.1864844568543232, 0.3133373663243338, 0.9339313859875982], 
             UndirectedEdge[180, 236] -> 
             RGBColor[
              0.2546593406268537, 0.3849934917065525, 0.9378138447627414], 
             UndirectedEdge[102, 163] -> 
             RGBColor[
              0.272133057471457, 0.4033594760078676, 0.938808947086994], 
             UndirectedEdge[16, 107] -> 
             RGBColor[
              0.33319709362883454`, 0.4630203083535974, 0.9424520020647762], 
             UndirectedEdge[194, 223] -> 
             RGBColor[
              0.9622169086067585, 0.8752522636294204, 0.4543198910461633], 
             UndirectedEdge[111, 291] -> 
             RGBColor[
              0.18821279065920096`, 0.31515395473595276`, 0.9340298120409453],
              UndirectedEdge[108, 205] -> 
             RGBColor[
              0.3030856171044626, 0.43207672625167026`, 0.9407113666179867], 
             UndirectedEdge[66, 297] -> 
             RGBColor[
              0.21059566017891732`, 0.33867976975706876`, 0.935304483347605], 
             UndirectedEdge[19, 284] -> 
             RGBColor[
              0.2685014480461575, 0.3995424242445413, 0.938602132302708], 
             UndirectedEdge[23, 260] -> 
             RGBColor[
              0.2588190028871956, 0.3893655604799919, 0.938050731374799], 
             UndirectedEdge[10, 256] -> 
             RGBColor[
              0.29440488188335295`, 0.4228333554018322, 0.9402213822269152], 
             UndirectedEdge[230, 242] -> 
             RGBColor[
              0.8292500198369269, 0.22583404667284962`, 0.17564315807000078`],
              UndirectedEdge[29, 317] -> 
             RGBColor[
              0.1883961858281423, 0.3153467146864354, 0.9340402561245076], 
             UndirectedEdge[124, 316] -> 
             RGBColor[
              0.27204171641094554`, 0.40317252702797246`, 0.9388070752443234],
              UndirectedEdge[306, 361] -> 
             RGBColor[
              0.21017418029056079`, 0.33823676767103766`, 0.9352804806914867],
              UndirectedEdge[1, 393] -> 
             RGBColor[
              0.1884550205876297, 0.3154085537489959, 0.9340436066770222], 
             UndirectedEdge[74, 279] -> 
             RGBColor[
              0.7676471267223055, 0.8187592045069678, 0.9773831565887533], 
             UndirectedEdge[40, 234] -> 
             RGBColor[
              0.653391331063141, 0.7272953937118065, 0.9673580250213626], 
             UndirectedEdge[195, 316] -> 
             RGBColor[
              0.21810104707830674`, 0.3465684072573414, 0.9357319040283003], 
             UndirectedEdge[279, 325] -> 
             RGBColor[
              0.4806866627377453, 0.5825538322263442, 0.9538715491644547], 
             UndirectedEdge[172, 337] -> 
             RGBColor[
              0.8805510906169809, 0.45253676052994485`, 0.3114219419711682], 
             UndirectedEdge[148, 275] -> 
             RGBColor[
              0.28636427371918854`, 0.4159844956872421, 0.939704812363203], 
             UndirectedEdge[13, 188] -> 
             RGBColor[
              0.20797364918202638`, 0.3359238699542373, 0.9351551637002498], 
             UndirectedEdge[220, 233] -> 
             RGBColor[
              0.7976144359577942, 0.8422371475965424, 0.9590360291130758], 
             UndirectedEdge[230, 244] -> 
             RGBColor[
              0.863414018720202, 0.41349493663689546`, 0.43023119852760305`], 
             UndirectedEdge[253, 358] -> 
             RGBColor[
              0.19093438586024153`, 0.31801452385134865`, 0.9341848028614053],
              UndirectedEdge[66, 140] -> 
             RGBColor[
              0.21998497488731555`, 0.3485485348325317, 0.9358391909300019], 
             UndirectedEdge[89, 128] -> 
             RGBColor[
              0.1919283928758168, 0.31905928824840313`, 0.9342414100904406], 
             UndirectedEdge[199, 298] -> 
             RGBColor[
              0.19174373818706897`, 0.31886520446274574`, 0.9342308942790887],
              UndirectedEdge[367, 398] -> 
             RGBColor[
              0.40058820107881166`, 0.5213910984512207, 0.9467461038398723], 
             UndirectedEdge[72, 181] -> 
             RGBColor[
              0.1888688995598306, 0.3158435667902215, 0.9340671764722099], 
             UndirectedEdge[229, 329] -> 
             RGBColor[
              0.1986631863683978, 0.3261379832196762, 0.934624946616609], 
             UndirectedEdge[196, 326] -> 
             RGBColor[
              0.19087356510240117`, 0.3179505973785997, 0.9341813392092224], 
             UndirectedEdge[247, 362] -> 
             RGBColor[
              0.19339653330473627`, 0.32060239692467707`, 0.9343250185159485],
              UndirectedEdge[276, 297] -> 
             RGBColor[
              0.21488882463476794`, 0.3431921578025159, 0.9355489727121981], 
             UndirectedEdge[7, 201] -> 
             RGBColor[
              0.698844545732584, 0.7622666344739716, 0.960474027707296], 
             UndirectedEdge[191, 214] -> 
             RGBColor[
              0.2234844168401749, 0.3522266702024217, 0.9360384789722569], 
             UndirectedEdge[25, 32] -> 
             RGBColor[
              0.8638900820976725, 0.3783252729391054, 0.20533827331271765`], 
             UndirectedEdge[190, 324] -> 
             RGBColor[
              0.7946744730052755, 0.8399555999055638, 0.9616274448568455], 
             UndirectedEdge[8, 296] -> 
             RGBColor[
              0.241386411848991, 0.3710428020087285, 0.9370579711043807], 
             UndirectedEdge[292, 382] -> 
             RGBColor[
              0.1881384932660469, 0.31507586346502103`, 0.9340255809143183], 
             UndirectedEdge[223, 328] -> 
             RGBColor[
              0.8997164529222819, 0.6301219365340252, 0.23765071588506692`], 
             UndirectedEdge[70, 262] -> 
             RGBColor[
              0.2185336488556363, 0.3470230991538516, 0.9357565400595423], 
             UndirectedEdge[78, 285] -> 
             RGBColor[
              0.8780247318216056, 0.4328365796695082, 0.31447680538583667`], 
             UndirectedEdge[167, 272] -> 
             RGBColor[
              0.5255938312060932, 0.6203452307967748, 0.9579015379327056], 
             UndirectedEdge[93, 276] -> 
             RGBColor[
              0.22858867995178067`, 0.3575915743616926, 0.9363291592053822], 
             UndirectedEdge[56, 319] -> 
             RGBColor[
              0.4175060909791842, 0.5360433358043497, 0.9478244252272849], 
             UndirectedEdge[93, 162] -> 
             RGBColor[
              0.2533245521097741, 0.3835905443446218, 0.9377378305313364], 
             UndirectedEdge[106, 389] -> 
             RGBColor[
              0.21473367973065993`, 0.34302909067154336`, 0.9355401374394254],
              UndirectedEdge[68, 176] -> 
             RGBColor[
              0.2518475893962128, 0.38203816288782416`, 0.9376537196897696], 
             UndirectedEdge[253, 301] -> 
             RGBColor[
              0.18689482770343305`, 0.31376869210576286`, 0.9339547560003658],
              UndirectedEdge[217, 357] -> 
             RGBColor[
              0.9024235222483088, 0.6224649306924224, 0.29722374630511356`], 
             UndirectedEdge[364, 385] -> 
             RGBColor[
              0.8765931862247653, 0.4214146608382354, 0.32124344776916525`], 
             UndirectedEdge[161, 372] -> 
             RGBColor[
              0.19676171310914198`, 0.3241394142638304, 0.934516660527472], 
             UndirectedEdge[4, 339] -> 
             RGBColor[
              0.24218330961780632`, 0.3718803920899902, 0.9371033532534101], 
             UndirectedEdge[183, 280] -> 
             RGBColor[
              0.30076148412422865`, 0.4296367640588081, 0.9405789063698025], 
             UndirectedEdge[94, 145] -> 
             RGBColor[
              0.18922208139469943`, 0.31621478329169034`, 0.9340872896552201],
              UndirectedEdge[107, 351] -> 
             RGBColor[
              0.6292040524803684, 0.703641559800374, 0.9673461867380587], 
             UndirectedEdge[90, 178] -> 
             RGBColor[
              0.5250344578406001, 0.6249699305004974, 0.9558390168550672], 
             UndirectedEdge[113, 124] -> 
             RGBColor[
              0.3086276211264817, 0.4416266325643382, 0.9408905883938774], 
             UndirectedEdge[191, 365] -> 
             RGBColor[
              0.19407713550409694`, 0.321317752988877, 0.9343637778043414], 
             UndirectedEdge[184, 356] -> 
             RGBColor[
              0.18905111217950674`, 0.3160350838064485, 0.9340775532113412], 
             UndirectedEdge[196, 327] -> 
             RGBColor[
              0.19267128104236286`, 0.3198401108132733, 0.9342837164725208], 
             UndirectedEdge[140, 288] -> 
             RGBColor[
              0.2655351688852008, 0.39642467677341436`, 0.9384332070927082], 
             UndirectedEdge[13, 232] -> 
             RGBColor[
              0.2546277618608894, 0.3849603004213146, 0.9378120463987364], 
             UndirectedEdge[34, 86] -> 
             RGBColor[
              0.3371353879041764, 0.46222487105446, 0.9428569705546225], 
             UndirectedEdge[287, 374] -> 
             RGBColor[
              0.19007574708878708`, 0.31711204006170757`, 0.9341359046536132],
              UndirectedEdge[201, 230] -> 
             RGBColor[
              0.861506799370262, 0.41207253556849543`, 0.43345962340457855`], 
             UndirectedEdge[71, 138] -> 
             RGBColor[
              0.18058969715831197`, 0.30714160013447456`, 0.9335956881434259],
              UndirectedEdge[334, 360] -> 
             RGBColor[
              0.185115098539477, 0.3118980839130987, 0.9338534030573518], 
             UndirectedEdge[38, 58] -> 
             RGBColor[
              0.2174442667054725, 0.3458780894432118, 0.935694501357687], 
             UndirectedEdge[115, 239] -> 
             RGBColor[
              0.8523263340305828, 0.3902002184370166, 0.1972316827098783], 
             UndirectedEdge[32, 78] -> 
             RGBColor[
              0.8656358011330783, 0.391743634424193, 0.20700997583252984`], 
             UndirectedEdge[41, 83] -> 
             RGBColor[
              0.9084527486796484, 0.9295988421678656, 0.9827837388659694], 
             UndirectedEdge[90, 212] -> 
             RGBColor[
              0.5128575453871849, 0.6144229009627645, 0.9550631147611566], 
             UndirectedEdge[160, 263] -> 
             RGBColor[
              0.42578806203725694`, 0.5430467428327064, 0.9483991221427692], 
             UndirectedEdge[226, 350] -> 
             RGBColor[
              0.7195454075725961, 0.7758957836327975, 0.8505842343054555], 
             UndirectedEdge[159, 329] -> 
             RGBColor[
              0.18547778561514033`, 0.3122792910253096, 0.9338740575497635], 
             UndirectedEdge[132, 260] -> 
             RGBColor[
              0.29142760754703456`, 0.4190601234916939, 0.9400754082095211], 
             UndirectedEdge[7, 250] -> 
             RGBColor[
              0.35349640883612216`, 0.4759428684075872, 0.943916070428803], 
             UndirectedEdge[135, 281] -> 
             RGBColor[
              0.711765095722288, 0.768553055573181, 0.8142632180180123], 
             UndirectedEdge[240, 243] -> 
             RGBColor[
              0.877634681087591, 0.48865144168934355`, 0.43080856334956663`], 
             UndirectedEdge[105, 349] -> 
             RGBColor[
              0.20573070891450085`, 0.3335663975224413, 0.935027431570147], 
             UndirectedEdge[111, 154] -> 
             RGBColor[
              0.19738148096805996`, 0.3247908295791051, 0.934551955390173], 
             UndirectedEdge[3, 233] -> 
             RGBColor[
              0.7706376185941841, 0.8203361519689907, 0.9569123152308744], 
             UndirectedEdge[125, 162] -> 
             RGBColor[
              0.2669203824734684, 0.39788062408229774`, 0.9385120929573202], 
             UndirectedEdge[301, 369] -> 
             RGBColor[
              0.18664719483068826`, 0.31350841425567716`, 0.9339406536746029],
              UndirectedEdge[268, 270] -> 
             RGBColor[
              0.5192310696539062, 0.6174490867384653, 0.9563893333020512], 
             UndirectedEdge[4, 188] -> 
             RGBColor[
              0.2173017232473819, 0.34572826723098127`, 0.9356863837186229], 
             UndirectedEdge[161, 176] -> 
             RGBColor[
              0.21656199837052442`, 0.34495076948413805`, 0.9356442574812107],
              UndirectedEdge[106, 270] -> 
             RGBColor[
              0.2929589759941193, 0.42059333525935383`, 0.9401654130551529], 
             UndirectedEdge[190, 268] -> 
             RGBColor[
              0.8177911045280821, 0.8581558703042615, 0.9638348308947651], 
             UndirectedEdge[220, 341] -> 
             RGBColor[
              0.4860287842689018, 0.590440011686344, 0.9535595010943037], 
             UndirectedEdge[76, 103] -> 
             RGBColor[
              0.19412197120965846`, 0.32136487815817005`, 0.9343663311314445],
              UndirectedEdge[84, 163] -> 
             RGBColor[
              0.3028162711208553, 0.4328272844297121, 0.940658180484038], 
             UndirectedEdge[356, 372] -> 
             RGBColor[
              0.1945300591839852, 0.3217938044934594, 0.9343895711378705], 
             UndirectedEdge[243, 398] -> 
             RGBColor[
              0.6978102198330773, 0.7601382089599893, 0.9424198532319874], 
             UndirectedEdge[141, 243] -> 
             RGBColor[
              0.9002404219314994, 0.6473255027899616, 0.4518652115799682], 
             UndirectedEdge[192, 320] -> 
             RGBColor[
              0.18870690253434044`, 0.31567329764522667`, 0.9340579509812614],
              UndirectedEdge[83, 245] -> 
             RGBColor[
              0.860898200693226, 0.41667022121889674`, 0.43641880856357806`], 
             UndirectedEdge[256, 313] -> 
             RGBColor[
              0.28483799884386285`, 0.41277795475190926`, 0.9396765623907513],
              UndirectedEdge[144, 186] -> 
             RGBColor[
              0.19870087032152506`, 0.3261775914437136, 0.9346270926619912], 
             UndirectedEdge[271, 371] -> 
             RGBColor[
              0.1828236944867615, 0.3094896729702865, 0.9337229109863782], 
             UndirectedEdge[317, 326] -> 
             RGBColor[
              0.19368284883535128`, 0.3209033327008066, 0.9343413237618512], 
             UndirectedEdge[194, 242] -> 
             RGBColor[
              0.8996928400306943, 0.5987720630349767, 0.3471882500432634], 
             UndirectedEdge[305, 334] -> 
             RGBColor[
              0.18360707090558112`, 0.31031305125539965`, 0.9337675231145284],
              UndirectedEdge[252, 282] -> 
             RGBColor[
              0.31835440977210794`, 0.4463178036126423, 0.941647079240882], 
             UndirectedEdge[134, 239] -> 
             RGBColor[
              0.8288313392623307, 0.4322875085422818, 0.44405929782727327`], 
             UndirectedEdge[267, 398] -> 
             RGBColor[
              0.34104050458358826`, 0.46493592502132197`, 0.9431303829813984],
              UndirectedEdge[4, 297] -> 
             RGBColor[
              0.2198696831096341, 0.34842735586426754`, 0.9358326252338219], 
             UndirectedEdge[40, 272] -> 
             RGBColor[
              0.6309966022057711, 0.7098004613221861, 0.9651259277394999], 
             UndirectedEdge[203, 325] -> 
             RGBColor[
              0.2574480826974209, 0.38792463643917835`, 0.9379726594980861], 
             UndirectedEdge[315, 359] -> 
             RGBColor[
              0.2030249569861144, 0.33072248069112636`, 0.9348733430006266], 
             UndirectedEdge[132, 160] -> 
             RGBColor[
              0.40894844852211004`, 0.5284611159894712, 0.9473261168602697], 
             UndirectedEdge[283, 381] -> 
             RGBColor[
              0.20257187699290616`, 0.3302462648913338, 0.9348475407652852], 
             UndirectedEdge[40, 183] -> 
             RGBColor[
              0.43552341404886974`, 0.5498108720138242, 0.9494803631610341], 
             UndirectedEdge[131, 339] -> 
             RGBColor[
              0.23240211172972863`, 0.36159973294585546`, 0.9365463285036696],
              UndirectedEdge[156, 165] -> 
             RGBColor[
              0.8529070927455767, 0.4662869399049452, 0.44820826028057437`], 
             UndirectedEdge[352, 379] -> 
             RGBColor[
              0.22335212736306764`, 0.3520876255743447, 0.9360309452822404], 
             UndirectedEdge[25, 194] -> 
             RGBColor[
              0.8763898892162449, 0.41965537165696043`, 0.32487331802642816`],
              UndirectedEdge[174, 238] -> 
             RGBColor[
              0.3169893195658634, 0.44724710585547944`, 0.9414827781424888], 
             UndirectedEdge[66, 339] -> 
             RGBColor[
              0.23290928668708955`, 0.3621328059827914, 0.9365752113671932], 
             UndirectedEdge[67, 387] -> 
             RGBColor[
              0.4796742864541198, 0.5876973628554791, 0.9523916433059518], 
             UndirectedEdge[90, 190] -> 
             RGBColor[
              0.7822989919455827, 0.8299086268722369, 0.9606532016549456], 
             UndirectedEdge[271, 389] -> 
             RGBColor[
              0.19087423447573804`, 0.31795130093241747`, 0.9341813773290437],
              UndirectedEdge[19, 293] -> 
             RGBColor[
              0.3046492475878372, 0.4338240686707453, 0.9407966099576801], 
             UndirectedEdge[126, 327] -> 
             RGBColor[
              0.19109665502145906`, 0.31818507902824733`, 0.9341940438500809],
              UndirectedEdge[12, 310] -> 
             RGBColor[
              0.2940376027932159, 0.42638254196942454`, 0.9400563785381975], 
             UndirectedEdge[272, 350] -> 
             RGBColor[
              0.867391875594665, 0.894633501748924, 0.8631950663915847], 
             UndirectedEdge[215, 229] -> 
             RGBColor[
              0.19493972789376507`, 0.3222243922819345, 0.9344129011648419], 
             UndirectedEdge[57, 189] -> 
             RGBColor[
              0.24216202976271878`, 0.3718580256130724, 0.9371021413971435], 
             UndirectedEdge[104, 337] -> 
             RGBColor[
              0.877355021883467, 0.4279703757179083, 0.30836138294251203`], 
             UndirectedEdge[194, 385] -> 
             RGBColor[
              0.9944784929138155, 0.9905983795896796, 0.6403962123397537], 
             UndirectedEdge[56, 166] -> 
             RGBColor[
              0.6856726502293173, 0.7474973607293266, 0.8829926191709212], 
             UndirectedEdge[258, 379] -> 
             RGBColor[
              0.19525485067885182`, 0.32255560630899927`, 0.9344308469412701],
              UndirectedEdge[9, 150] -> 
             RGBColor[
              0.19229026561489077`, 0.3194396394412268, 0.9342620182075883], 
             UndirectedEdge[294, 380] -> 
             RGBColor[
              0.20504200072556777`, 0.3328425215492514, 0.9349882106576397], 
             UndirectedEdge[296, 308] -> 
             RGBColor[
              0.22323052785896746`, 0.35195981678568156`, 0.9360240203703722],
              UndirectedEdge[33, 92] -> 
             RGBColor[
              0.3869660924415177, 0.5054181375626268, 0.9463177797578736], 
             UndirectedEdge[39, 283] -> 
             RGBColor[
              0.19607798492560893`, 0.3234207725920666, 0.934477723218905], 
             UndirectedEdge[11, 34] -> 
             RGBColor[
              0.28760640007487454`, 0.41932535119602954`, 0.9397010272469036],
              UndirectedEdge[105, 171] -> 
             RGBColor[
              0.19921926143757313`, 0.32672245337457523`, 0.9346566142691592],
              UndirectedEdge[110, 237] -> 
             RGBColor[
              0.19038343508665123`, 0.3174354396560086, 0.9341534270299079], 
             UndirectedEdge[8, 175] -> 
             RGBColor[
              0.2597318112605219, 0.39032497995575144`, 0.938102714461281], 
             UndirectedEdge[90, 373] -> 
             RGBColor[
              0.44011491122134366`, 0.5480057067490964, 0.9505529184695845], 
             UndirectedEdge[73, 104] -> 
             RGBColor[
              0.8562111877661985, 0.35228531246266953`, 0.19823419564249584`],
              UndirectedEdge[232, 339] -> 
             RGBColor[
              0.2733203034534184, 0.404607346810652, 0.9388765589892938], 
             UndirectedEdge[178, 274] -> 
             RGBColor[
              0.46738436670940764`, 0.5781669894131862, 0.9513005905019778], 
             UndirectedEdge[224, 318] -> 
             RGBColor[
              0.18686239314258873`, 0.3137346013258456, 0.9339529089001083], 
             UndirectedEdge[132, 307] -> 
             RGBColor[
              0.3533139613151539, 0.48044452804031823`, 0.9437338310851009]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {400}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.1972575262297792, 0.3246605452899877, 0.9345448963512025], 
             316 -> RGBColor[
              0.23435379828218117`, 0.36365107925655765`, 0.9366574741655703],
              308 -> RGBColor[
              0.20150049615977755`, 0.32912017570624735`, 0.9347865272118044],
              160 -> RGBColor[
              0.4596234812344611, 0.572182073724828, 0.9506023905805157], 245 -> 
             RGBColor[
              0.818830055518114, 0.14574163486097447`, 0.1656649884706391], 
             155 -> RGBColor[
              0.2070813101039675, 0.3349859650056321, 0.9351043463098516], 
             213 -> RGBColor[
              0.22261848399738943`, 0.3513165198813409, 0.9359891653778931], 
             352 -> RGBColor[
              0.2396024194233052, 0.3691677128576799, 0.9369563753749182], 27 -> 
             RGBColor[
              0.821038236612611, 0.16271468238440395`, 0.16777954518051325`], 
             367 -> RGBColor[
              0.37508215881778845`, 0.49929904661568136`, 0.9451208813811075],
              19 -> RGBColor[
              0.26040419361571815`, 0.3910316964425663, 0.9381410056417089], 
             164 -> RGBColor[
              0.20095261322947336`, 0.32854431600871353`, 0.9347553260894438],
              190 -> RGBColor[
              0.9562193148935751, 0.9668690172486966, 0.9589934594404549], 
             103 -> RGBColor[
              0.19434739415987903`, 0.3216018119714924, 0.9343791686349763], 
             138 -> RGBColor[
              0.18225239431662393`, 0.3088892002689491, 0.9336903762868517], 
             291 -> RGBColor[
              0.18717515147111807`, 0.3140633301591533, 0.9339707200242335], 
             28 -> RGBColor[
              0.20698871416859752`, 0.3348886408066369, 0.9350990731083157], 
             337 -> RGBColor[
              0.9940468194635823, 0.9896750737285114, 0.5934112212615963], 
             195 -> RGBColor[
              0.20184829587443234`, 0.32948573525812513`, 0.9348063338910304],
              114 -> RGBColor[
              0.24129060741956473`, 0.3709421054790498, 0.9370525151838548], 
             93 -> RGBColor[
              0.2343202347626608, 0.3636158018694917, 0.9366555627727864], 34 -> 
             RGBColor[
              0.2632481201845229, 0.3940208435817391, 0.93830296305259], 161 -> 
             RGBColor[
              0.1994550789542851, 0.32697031253633363`, 0.9346700437278752], 
             22 -> RGBColor[
              0.3162753653274515, 0.4483635578097335, 0.9413737645007089], 
             124 -> RGBColor[
              0.3097296345397099, 0.44269397479938727`, 0.9409566763230764], 
             84 -> RGBColor[
              0.3388378220394789, 0.4679060237916442, 0.9428114242912021], 46 -> 
             RGBColor[
              0.20129344185623907`, 0.3289025485052273, 0.9347747357755273], 
             241 -> RGBColor[
              0.2632132370288079, 0.3939841791733627, 0.938300976508477], 185 -> 
             RGBColor[
              0.3996003392677278, 0.5205354622018381, 0.9466831581588019], 
             390 -> RGBColor[
              0.2627109211596987, 0.39345621334626335`, 0.938272370362841], 
             121 -> RGBColor[
              0.3109061797336599, 0.4437130391115059, 0.9410316447424569], 
             322 -> RGBColor[
              0.1999051049994005, 0.32744331844304914`, 0.9346956720453906], 
             126 -> RGBColor[
              0.1865862227024127, 0.3134443286830033, 0.9339371814020978], 
             236 -> RGBColor[
              0.25077535368791876`, 0.38091117517473666`, 0.9375926574524128],
              78 -> RGBColor[
              0.8199375785531087, 0.1542545422276314, 0.1667255537797183], 
             376 -> RGBColor[
              0.209601906353837, 0.3376352714792777, 0.9352478905373938], 254 -> 
             RGBColor[
              0.18724741023772068`, 0.314139278704323, 0.9339748350540943], 
             290 -> 
             RGBColor[
              0.19821724293608944`, 0.32566926839787347`, 0.9345995507978533],
              251 -> RGBColor[
              0.19027393338711107`, 0.3173203464269832, 0.9341471910701123], 
             165 -> RGBColor[
              0.8967495440562933, 0.920507761085305, 0.9900139661214994], 100 -> 
             RGBColor[
              0.2101475089071078, 0.33820873435596516`, 0.9352789617956558], 
             235 -> RGBColor[
              0.1915139828942802, 0.31862371708269777`, 0.9342178100550568], 
             70 -> RGBColor[
              0.22291581655962178`, 0.35162903525622036`, 0.9360060980274482],
              234 -> RGBColor[
              0.7857227396767522, 0.8325318430402561, 0.9792771577606599], 
             257 -> RGBColor[
              0.32310439559809073`, 0.45427852059311985`, 0.9418089042708796],
              135 -> RGBColor[
              0.9948422584139026, 0.9913764372120322, 0.679989842123797], 265 -> 
             RGBColor[
              0.18998272969436467`, 0.3170142728825262, 0.9341306074506077], 
             111 -> RGBColor[
              0.18925042984728385`, 0.3162445793127523, 0.934088904057657], 
             381 -> RGBColor[
              0.19616341759440778`, 0.32351056774371817`, 0.9344825884830068],
              182 -> RGBColor[
              0.34853172220347034`, 0.47630239288410453`, 0.9434291110376724],
              188 -> RGBColor[
              0.2017846044041309, 0.3294187914845658, 0.9348027067560198], 
             154 -> RGBColor[
              0.2055125320888361, 0.33333707984545796`, 0.935015006722689], 
             336 -> RGBColor[
              0.18035329176886106`, 0.3068931230811942, 0.933582225206227], 
             315 -> RGBColor[
              0.2188459842157359, 0.34735138342052185`, 0.9357743270962412], 
             368 -> RGBColor[
              0.1851720653526604, 0.311957959645659, 0.9338566472330878], 269 -> 
             RGBColor[
              0.743581503407994, 0.7996107889818441, 0.9750769131616334], 208 -> 
             RGBColor[
              0.9930152754848626, 0.9913796511608278, 0.7654184913108293], 86 -> 
             RGBColor[
              0.4110226556238299, 0.5304288985271809, 0.947410978056655], 119 -> 
             RGBColor[
              0.18241596627536708`, 0.30906112476864933`, 0.9336996914679191],
              377 -> RGBColor[
              0.18473621585810335`, 0.3114998541924255, 0.9338318262491543], 
             140 -> RGBColor[
              0.2256991535454318, 0.35455449890206425`, 0.9361646049512119], 
             85 -> 
             RGBColor[
              0.24074527521724318`, 0.3703689267583512, 0.9370214593216792], 
             351 -> RGBColor[
              0.9097894237460113, 0.9309054071917814, 0.9912577214871428], 
             242 -> RGBColor[
              0.852273426221674, 0.40280203706702433`, 0.19769039802525293`], 
             117 -> RGBColor[
              0.22614100723621103`, 0.3550189151462153, 0.9361897678652379], 
             47 -> RGBColor[
              0.5441036538714303, 0.6407668836599264, 0.9572529792315668], 81 -> 
             RGBColor[
              0.17955783501139488`, 0.30605704759422586`, 0.9335369251206622],
              275 -> RGBColor[
              0.23875032994207512`, 0.36827211278731364`, 0.9369078501395155],
              23 -> RGBColor[
              0.2930562064900811, 0.4253510322307103, 0.9400004894705796], 
             328 -> RGBColor[
              0.8695307562797816, 0.5004514607800906, 0.21284560375709155`], 
             110 -> RGBColor[
              0.18343408206602244`, 0.3101312290168976, 0.9337576716560296], 
             6 -> RGBColor[
              0.30558851701585305`, 0.4385232851876776, 0.9407141860151303], 
             218 -> RGBColor[
              0.19086057119328328`, 0.3179369399562554, 0.934180599225321], 
             108 -> RGBColor[
              0.256153514960176, 0.38656396366699863`, 0.9378989357805914], 
             297 -> RGBColor[
              0.20692052412863532`, 0.33481696875113837`, 0.935095189786418], 
             157 -> RGBColor[
              0.1873941802353717, 0.31429354327760956`, 0.9339831933883338], 
             354 -> RGBColor[
              0.2158527042869893, 0.34420525643050026`, 0.9356038642324599], 
             385 -> RGBColor[
              0.9944253181788963, 0.9904846442084778, 0.6346084706002231], 
             270 -> RGBColor[
              0.3590992451452233, 0.4854554501171043, 0.9441024642550272], 
             392 -> RGBColor[
              0.9910839134677017, 0.9905809833329919, 0.7974261581398643], 33 -> 
             RGBColor[
              0.2765417318743941, 0.4079932723314563, 0.939060014572192], 252 -> 
             RGBColor[
              0.3695662131784596, 0.4945214117423836, 0.9447694102025287], 
             394 -> RGBColor[
              0.18043226082461958`, 0.30697612456572376`, 0.9335867223771283],
              260 -> RGBColor[
              0.22458179928431016`, 0.35338008872927346`, 0.9361009732790185],
              159 -> RGBColor[
              0.1805122222555836, 0.3070601690995145, 0.9335912760623294], 
             183 -> 
             RGBColor[
              0.3499869056482099, 0.4775627996442913, 0.943521834040003], 99 -> 
             RGBColor[
              0.965636915117815, 0.9738926480760296, 0.9430519187643377], 329 -> 
             RGBColor[
              0.19044334897469703`, 0.3174984129511047, 0.9341568390371975], 
             309 -> RGBColor[
              0.2975965440226766, 0.4301232148514946, 0.9402590549762334], 17 -> 
             RGBColor[
              0.2316763474093035, 0.360836908628973, 0.9365049972992935], 349 -> 
             RGBColor[
              0.2019856527302044, 0.3296301060224692, 0.9348141561607654], 
             347 -> RGBColor[
              0.19785125300646603`, 0.3252845897767374, 0.9345787082127948], 
             340 -> RGBColor[
              0.2029347338096705, 0.33062765041220404`, 0.9348682049242014], 
             277 -> RGBColor[
              0.20781531186542476`, 0.3357574473953233, 0.9351461466243084], 
             104 -> RGBColor[
              0.8190091230934095, 0.14711802671260676`, 0.16583646378296987`],
              79 -> RGBColor[
              0.23104392871496413`, 0.36017219648356114`, 0.9364689819902305],
              327 -> RGBColor[
              0.19560708734050541`, 0.3229258293734914, 0.9344509062980639], 
             191 -> RGBColor[
              0.20722377740839654`, 0.33513570717553587`, 0.9351124596120775],
              50 -> RGBColor[
              0.1790362447681438, 0.3055088231778375, 0.9335072213279326], 
             225 -> RGBColor[
              0.884710274500928, 0.9109079743391231, 0.9888656498437259], 61 -> 
             RGBColor[
              0.20936457771848743`, 0.3373858240360207, 0.9352343750227069], 
             196 -> RGBColor[
              0.18973547474422028`, 0.3167543922530552, 0.9341165266469779], 
             1 -> RGBColor[
              0.19354678877808446`, 0.32076032495391327`, 0.9343335753428726],
              263 -> RGBColor[
              0.3919526428400527, 0.5139114119405849, 0.9461958537050229], 
             201 -> RGBColor[
              0.9490437648216794, 0.9615175037539616, 0.971139794028986], 371 -> 
             RGBColor[
              0.18654757264035143`, 0.3134037050172214, 0.9339349803382411], 
             293 -> RGBColor[
              0.3488943015599562, 0.47661644089892424`, 0.9434522142736513], 
             362 -> RGBColor[
              0.18916507484151227`, 0.3161548657898664, 0.9340840432163497], 
             184 -> RGBColor[
              0.18311045325504194`, 0.3097910746173054, 0.9337392414740102], 
             106 -> 
             RGBColor[
              0.22681870684301533`, 0.35573122040160343`, 0.9362283618552786],
              206 -> RGBColor[
              0.7303132143006519, 0.7892455006884563, 0.9737544541026248], 
             358 -> RGBColor[
              0.19077583416012883`, 0.31784787596177183`, 0.9341757735766401],
              247 -> RGBColor[
              0.1976279917679603, 0.3250499280594878, 0.9345659938155473], 
             220 -> RGBColor[
              0.635822518194204, 0.7152283896049052, 0.9644734242083259], 107 -> 
             RGBColor[
              0.34861868121472545`, 0.4763777124089667, 0.9434346519889747], 
             375 -> RGBColor[
              0.180596656524124, 0.30714891486919227`, 0.9335960844690134], 
             131 -> RGBColor[
              0.21325644631447746`, 0.3414764246891273, 0.9354560111817448], 
             127 -> RGBColor[
              0.19480415931956344`, 0.32208190111490453`, 0.9344051807350968],
              210 -> RGBColor[
              0.3056537490672848, 0.4385918482096833, 0.9407179008839572], 
             357 -> RGBColor[
              0.85710048921771, 0.439904958487049, 0.20231279900164487`], 181 -> 
             RGBColor[
              0.19492367816056405`, 0.3222075229947284, 0.9344119871562795], 
             194 -> RGBColor[
              0.9945316676487347, 0.9907121149708813, 0.6461839540792844], 
             118 -> RGBColor[
              0.2388812891503496, 0.36840975921850344`, 0.93691530807269], 
             348 -> RGBColor[
              0.33313964664549794`, 0.4629705506640006, 0.9424483415937963], 
             276 -> RGBColor[
              0.22285712514090053`, 0.35156734685389346`, 0.9360027556379781],
              305 -> RGBColor[
              0.18223318953702214`, 0.3088690148279342, 0.9336892826030643], 
             343 -> RGBColor[
              0.1820208818055452, 0.30864586594106436`, 0.9336771919918379], 
             280 -> RGBColor[
              0.2515360626002474, 0.3817107284733248, 0.937635978699602], 189 -> 
             RGBColor[
              0.266643234211289, 0.39758932368653244`, 0.9384963097737932], 
             168 -> RGBColor[
              0.18420503135956878`, 0.31094154560542325`, 0.9338015760777798],
              363 -> RGBColor[
              0.21990087473071346`, 0.348460140235685, 0.9358344015504985], 
             41 -> RGBColor[
              0.8718710063158469, 0.90067029040099, 0.9876410289824828], 14 -> 
             RGBColor[
              0.18454901891679482`, 0.31130309833813863`, 0.9338211656602798],
              77 -> 
             RGBColor[
              0.18280925758947733`, 0.30947449887588874`, 0.9337220888264354],
              51 -> RGBColor[
              0.381577964086101, 0.5049253866504279, 0.9455347883487892], 179 -> 
             RGBColor[
              0.45394807471440896`, 0.5675745230376996, 0.950155601789558], 
             223 -> RGBColor[
              0.9299021495647822, 0.7597924122879596, 0.2624558280130423], 
             323 -> RGBColor[
              0.3986910652219958, 0.5197478947248675, 0.9466252200206473], 
             292 -> RGBColor[
              0.1943854920349882, 0.321641855253777, 0.934381338252603], 396 -> 
             RGBColor[
              0.19955786085140656`, 0.3270783428269569, 0.9346758970048641], 
             321 -> RGBColor[
              0.5543615420614805, 0.6490946994052059, 0.9580605177657702], 
             143 -> RGBColor[
              0.18504307948317125`, 0.3118223873186494, 0.9338493016786379], 
             112 -> RGBColor[
              0.937107871400364, 0.788360698201582, 0.2682537209419814], 197 -> 
             RGBColor[
              0.9643115115712477, 0.9729041642811488, 0.9452954812480678], 54 -> 
             RGBColor[
              0.1846123721443362, 0.31136968659711123`, 0.9338247735328656], 
             71 -> RGBColor[0.178927, 0.305394, 0.933501], 177 -> 
             RGBColor[
              0.8948525196191675, 0.9189951252924975, 0.9898330262371927], 
             158 -> RGBColor[
              0.3387561380668311, 0.4678352732400925, 0.9428062194606953], 
             226 -> RGBColor[
              0.44524034591787487`, 0.5600665420287623, 0.9495912990246761], 
             350 -> RGBColor[
              0.9938504692273173, 0.9917250252368329, 0.751577169586235], 203 -> 
             RGBColor[
              0.2257570420476589, 0.35461534338824796`, 0.9361679016157753], 
             115 -> RGBColor[
              0.8646080428941941, 0.47809856902505976`, 0.2087379710414105], 
             173 -> RGBColor[
              0.2824798268544749, 0.4142345866524884, 0.9393981802966833], 
             212 -> RGBColor[
              0.41733642177677943`, 0.535897565429752, 0.9478132856528767], 
             129 -> RGBColor[
              0.189088316742455, 0.3160741881610126, 0.9340796719561618], 279 -> 
             RGBColor[
              0.6722342021283076, 0.7438737349625797, 0.9679656809485127], 26 -> 
             RGBColor[
              0.18699939157323073`, 0.3138785953626525, 0.9339607107580624], 
             40 -> RGBColor[
              0.5210599224495296, 0.6220589443833571, 0.9554388922820652], 
             146 -> 
             RGBColor[
              0.18614238840660097`, 0.3129778306973855, 0.9339119056955454], 
             386 -> RGBColor[
              0.7607606134285254, 0.8130312402959552, 0.9767891663005692], 
             192 -> RGBColor[
              0.18162114890697434`, 0.30822572132013676`, 0.933654427794616], 
             300 -> RGBColor[
              0.9146994662552146, 0.9348205418090667, 0.9917260457249173], 
             221 -> RGBColor[
              0.9023083761464576, 0.6492869771870501, 0.2401960532268301], 62 -> 
             RGBColor[
              0.20110579749352597`, 0.32870532238267614`, 0.9347640497066657],
              286 -> RGBColor[
              0.1948453625020903, 0.32212520827217295`, 0.9344075271953871], 
             152 -> RGBColor[
              0.25676930210776144`, 0.3872111950022711, 0.9379340039476709], 
             64 -> RGBColor[
              0.18064334912177313`, 0.30719799174980317`, 0.933598743543374], 
             307 -> RGBColor[
              0.3483545068205488, 0.47614889782652203`, 0.9434178190301781], 
             37 -> RGBColor[
              0.34879862256835453`, 0.4765335685653648, 0.9434461176929121], 
             148 -> RGBColor[
              0.33397821749630197`, 0.46369687858717057`, 0.9425017745868906],
              261 -> RGBColor[
              0.2599700418165058, 0.39057537537478015`, 0.9381162813390138], 
             387 -> RGBColor[
              0.5341260408491124, 0.6326666079220644, 0.9564675049852491], 15 -> 
             RGBColor[
              0.28582560720535155`, 0.41775121393598635`, 0.9395887175380273],
              136 -> RGBColor[
              0.18458947116943916`, 0.3113456162204888, 0.9338234693562242], 
             198 -> RGBColor[
              0.3533082208089774, 0.4804395559023944, 0.9437334653051234], 63 -> 
             RGBColor[
              0.1811814280726413, 0.30776354684334156`, 0.9336293863436095], 
             310 -> RGBColor[
              0.27959908951497947`, 0.4112067490593821, 0.9392341265668681], 
             171 -> RGBColor[
              0.188962757776349, 0.315942217726737, 0.93407252155879], 395 -> 
             RGBColor[
              0.46863892160806836`, 0.5795012143610829, 0.9513121190713723], 
             311 -> RGBColor[
              0.3027440138032642, 0.4355335319593264, 0.9405521957652387], 
             353 -> RGBColor[
              0.19002087389400624`, 0.31705436485483146`, 0.934132779706348], 
             59 -> RGBColor[
              0.3465121371910148, 0.4745531298536097, 0.9433004248665277], 
             397 -> 
             RGBColor[
              0.2129233554713194, 0.341126325093789, 0.9354370421509908], 229 -> 
             RGBColor[
              0.20688302376209858`, 0.33477755348824767`, 0.9350930541960206],
              102 -> RGBColor[
              0.2774713947406823, 0.40897040694795533`, 0.9391129574971142], 
             299 -> RGBColor[
              0.18766218808016377`, 0.31457523651516484`, 0.9339984560386126],
              128 -> RGBColor[
              0.19461177340916913`, 0.32187969132510885`, 0.9343942246421093],
              12 -> RGBColor[
              0.3084761160714523, 0.441558334879467, 0.9408786305095267], 222 -> 
             RGBColor[
              0.23238602207295528`, 0.3615828216964435, 0.9365454122215189], 
             92 -> RGBColor[
              0.49739045300864126`, 0.6028430027937971, 0.9535755449435551], 
             271 -> RGBColor[
              0.17909981633317154`, 0.30557564092335165`, 0.9335108416345153],
              361 -> RGBColor[
              0.21763599434706354`, 0.34607960735075854`, 0.93570541996324], 
             344 -> RGBColor[
              0.1912494582787511, 0.31834568493994736`, 0.9342027457695316], 
             132 -> RGBColor[
              0.35827341580975897`, 0.4847401582541144, 0.9440498431400237], 
             80 -> RGBColor[
              0.1798079986201722, 0.3063199854083397, 0.9335511715680982], 
             324 -> RGBColor[
              0.6331296311169758, 0.713042182562431, 0.9642614302732361], 244 -> 
             RGBColor[
              0.9547654228714991, 0.9657847069591619, 0.9614545193980599], 
             150 -> RGBColor[
              0.19354588592399127`, 0.3207593759970171, 0.9343335239266677], 
             125 -> RGBColor[
              0.2615118954900493, 0.3921959613448436, 0.9382040876247539], 
             258 -> RGBColor[
              0.18340786605487358`, 0.31010367432698904`, 0.9337561786929778],
              133 -> RGBColor[
              0.18578718983175693`, 0.312604494474334, 0.9338916776621772], 
             255 -> RGBColor[
              0.8353613957275855, 0.2728087597904426, 0.18149541852470724`], 
             326 -> RGBColor[
              0.19201165546058205`, 0.31914680250414423`, 0.9342461517714671],
              176 -> RGBColor[
              0.23366891778676377`, 0.3629312264319425, 0.9366184712345461], 
             230 -> RGBColor[
              0.8177383166445533, 0.1373500514757623, 0.1646195380923747], 
             274 -> RGBColor[
              0.49307848673520527`, 0.5993423543211548, 0.9532360911632574], 
             87 -> 
             RGBColor[
              0.19817896485079942`, 0.32562903570326285`, 0.9345973709175234],
              130 -> RGBColor[
              0.1820121662584413, 0.30863670534846055`, 0.9336766956543238], 
             35 -> RGBColor[
              0.2362515342121432, 0.36564572004235524`, 0.9367655474193329], 
             379 -> RGBColor[
              0.20710183530283005`, 0.33500753829100943`, 0.9351055151895625],
              31 -> RGBColor[
              0.19647646719475834`, 0.3238396027221777, 0.9345004161946314], 
             18 -> RGBColor[
              0.6051402883638863, 0.6903191732099512, 0.9620580066833722], 24 -> 
             RGBColor[
              0.8207868509580615, 0.16078242208563953`, 0.1675388179938171], 
             151 -> RGBColor[
              0.19201931518110454`, 0.3191548533560677, 0.9342465879812193], 
             137 -> RGBColor[
              0.33446348254021346`, 0.46411719077807645`, 0.9425326952463855],
              330 -> RGBColor[
              0.18593025704413854`, 0.31275486718553225`, 0.9338998251282734],
              296 -> RGBColor[
              0.2449605595581574, 0.37479945786511576`, 0.9372615135289399], 
             266 -> RGBColor[
              0.23275233921967517`, 0.3619678442434947, 0.9365662734411069], 
             302 -> RGBColor[
              0.19137511524925596`, 0.3184777583830601, 0.9342099017481089], 
             283 -> RGBColor[
              0.20898033639140454`, 0.33698196203894937`, 0.9352124930475636],
              388 -> RGBColor[
              0.2195142065627996, 0.3480537274750297, 0.9358123813703602], 
             284 -> RGBColor[
              0.2765987024765969, 0.40805315204651627`, 0.939063258963707], 
             318 -> RGBColor[
              0.19439044372267295`, 0.3216470597914888, 0.9343816202438913], 
             238 -> RGBColor[
              0.28998218143607674`, 0.4221200369945062, 0.9398254282913666], 
             72 -> RGBColor[
              0.18281412095909713`, 0.3094796105857146, 0.9337223657881405], 
             288 -> RGBColor[
              0.30537118422496984`, 0.4382948546447645, 0.9407018092342045], 
             382 -> RGBColor[
              0.1818914944971056, 0.30850987167626515`, 0.9336698235760336], 
             389 -> RGBColor[
              0.20264865261830456`, 0.3303269609414833, 0.9348519130235723], 
             172 -> RGBColor[
              0.8238032261936802, 0.18396760393066158`, 0.17042730232595416`],
              243 -> RGBColor[
              0.9695261963263196, 0.9767932676332187, 0.9364683801653377], 88 -> 
             RGBColor[
              0.19146940577852636`, 0.3185768637076881, 0.9342152714542605], 
             273 -> RGBColor[
              0.1818250295794584, 0.30844001283369876`, 0.9336660384972996], 
             202 -> RGBColor[
              0.2433593553333951, 0.37311649070267905`, 0.9371703273171091], 
             393 -> RGBColor[
              0.18336325239717496`, 0.31005678254407854`, 0.9337536380111718],
              98 -> RGBColor[
              0.20101540430520026`, 0.32861031341048663`, 0.9347589019483153],
              30 -> RGBColor[
              0.18021067351487519`, 0.3067432222537355, 0.9335741033076473], 
             116 -> RGBColor[
              0.18333815129494635`, 0.31003039969413443`, 0.9337522085405336],
              373 -> RGBColor[
              0.271851153445097, 0.4030631770024157, 0.9387928930697325], 240 -> 
             RGBColor[
              0.8316889234682268, 0.24458052871740593`, 0.17797865494168116`],
              317 -> RGBColor[
              0.1953540422101205, 0.32265986289746895`, 0.9344364957522352], 
             391 -> RGBColor[
              0.18112688553091424`, 0.3077062191737896, 0.9336262802265466], 
             73 -> RGBColor[
              0.9306153171117766, 0.762619883962795, 0.26302965936154776`], 
             303 -> RGBColor[
              0.21323548342695858`, 0.34145439136522115`, 0.9354548173763124],
              29 -> RGBColor[
              0.1814383294461641, 0.30803356647540187`, 0.9336440164967801], 
             360 -> RGBColor[
              0.18524924480481392`, 0.31203908014333226`, 0.9338610424887112],
              320 -> RGBColor[
              0.19579265616170655`, 0.32312087397031664`, 0.9344614741679068],
              75 -> RGBColor[
              0.21796667840296896`, 0.34642717726009525`, 0.9357242519310205],
              200 -> RGBColor[
              0.1842143453500115, 0.31095133519991963`, 0.9338021064957567], 
             301 -> RGBColor[
              0.18269671784651187`, 0.30935621247060024`, 0.933715679854561], 
             156 -> RGBColor[
              0.8309858670902185, 0.23917652931476524`, 0.17730540736011186`],
              25 -> RGBColor[0.817319, 0.134127, 0.164218], 38 -> 
             RGBColor[
              0.22292982485851465`, 0.3516437588665342, 0.9360068957793466], 
             365 -> RGBColor[
              0.18093049359979738`, 0.3074997988022181, 0.9336150959966053], 
             380 -> RGBColor[
              0.22012423896070668`, 0.348694910203518, 0.9358471218129588], 
             370 -> 
             RGBColor[
              0.18708771794254558`, 0.3139714319770177, 0.9339657408141276], 
             3 -> RGBColor[
              0.5818688834669836, 0.6714263983498019, 0.960225996443923], 57 -> 
             RGBColor[
              0.21768082531414856`, 0.3461267275396124, 0.9357079730204939], 
             227 -> RGBColor[
              0.20746958876179836`, 0.3353940704933011, 0.9351264582050084], 
             39 -> RGBColor[
              0.18317563345981333`, 0.30985958314518375`, 0.9337429533902465],
              109 -> RGBColor[
              0.18132254229683142`, 0.30791186684012395`, 0.9336374225899173],
              256 -> RGBColor[
              0.3513087838325387, 0.47870774408802763`, 0.9436060629490174], 
             339 -> RGBColor[
              0.2515477771449798, 0.3817230412025836, 0.9376366458255944], 
             287 -> RGBColor[
              0.1899324083338537, 0.31696138194207063`, 0.9341277417235704], 
             239 -> RGBColor[
              0.82776291630336, 0.2144035172609302, 0.17421910604681382`], 
             285 -> RGBColor[
              0.9941990383585994, 0.9900006545532618, 0.6099793085980734], 
             345 -> RGBColor[
              0.1789871968344326, 0.3054572706896884, 0.9335044281206677], 
             366 -> RGBColor[
              0.39439940253334044`, 0.5160306722091927, 0.9463517590690945], 
             216 -> RGBColor[
              0.1997106484206986, 0.3272389322495743, 0.9346845980309063], 21 -> 
             RGBColor[
              0.9632021039744041, 0.8875341975281088, 0.3115475519504825], 
             355 -> RGBColor[
              0.7657071355725306, 0.8168955009898127, 0.9772821894000061], 
             175 -> RGBColor[
              0.28165135838121924`, 0.41336381375916165`, 0.9393510002427407],
              7 -> RGBColor[
              0.4486453266434888, 0.5630157651939816, 0.9498082613856059], 13 -> 
             RGBColor[
              0.21416269395992185`, 0.3424289484239088, 0.9355076206444797], 
             294 -> RGBColor[
              0.1899597624904289, 0.3169901328949849, 0.9341292995023205], 
             193 -> RGBColor[
              0.18694492825143932`, 0.3138213509582757, 0.9339576091524576], 
             60 -> RGBColor[
              0.186004909472108, 0.3128333316205655, 0.9339040764736078], 65 -> 
             RGBColor[
              0.2879462259501837, 0.4199801186917991, 0.9397094836383711], 69 -> 
             RGBColor[
              0.2418162773238607, 0.37149461787786187`, 0.9370824513072455], 
             217 -> 
             RGBColor[
              0.9930695883095065, 0.987584875103169, 0.4870456409120508], 214 -> 
             RGBColor[
              0.23974505627195325`, 0.36931763322930755`, 0.9369644983324363],
              170 -> RGBColor[
              0.2316644133079956, 0.36082436513183264`, 0.936504317669879], 
             359 -> RGBColor[
              0.18720392975649292`, 0.3140935779617309, 0.9339723589050121], 
             74 -> RGBColor[
              0.8630600513163033, 0.8936446740513561, 0.986800632228994], 246 -> 
             RGBColor[
              0.9202453542726101, 0.9392426823750178, 0.9922550174748891], 
             264 -> RGBColor[
              0.7232916660208124, 0.7837602138065023, 0.9730546117901898], 
             278 -> RGBColor[
              0.25816588373595994`, 0.3886790908418973, 0.9380135372053394], 
             45 -> RGBColor[
              0.2848093981590889, 0.41668311379698936`, 0.9395308459361892], 
             306 -> RGBColor[
              0.20271236623405806`, 0.3303939279913168, 0.9348555414197336], 
             237 -> RGBColor[
              0.19733278810728, 0.3247396502951197, 0.9345491824037863], 228 -> 
             RGBColor[
              0.20359531165465325`, 0.33132195961033534`, 0.9349058238552358],
              180 -> RGBColor[
              0.2585433275657887, 0.3890758082383683, 0.93803503207307], 383 -> 
             RGBColor[
              0.20835388918653433`, 0.3363235263075839, 0.9351768178059918], 
             53 -> RGBColor[
              0.19239706134193654`, 0.319551888521592, 0.9342681000662533], 
             304 -> RGBColor[
              0.1808905282724361, 0.3074577927092133, 0.9336128200303355], 48 -> 
             RGBColor[
              0.24018804114120323`, 0.3697832384137522, 0.9369897256654027], 
             5 -> RGBColor[
              0.2824395297681887, 0.41419223185981874`, 0.9393958854372335], 
             101 -> RGBColor[
              0.1831002535865883, 0.30978035411906424`, 0.9337386606179808], 
             333 -> RGBColor[
              0.18811264277564865`, 0.31504869296059673`, 0.9340241087671325],
              267 -> RGBColor[
              0.2559867658273416, 0.386388699755884, 0.9378894396641596], 120 -> 
             RGBColor[
              0.5182991743784003, 0.6198176447289311, 0.9552215560809526], 
             147 -> RGBColor[
              0.1834762116557925, 0.31017550988691617`, 0.9337600708738418], 
             89 -> RGBColor[
              0.1892450123424645, 0.31623888517169746`, 0.934088595538772], 
             43 -> 
             RGBColor[
              0.26035980612556775`, 0.3909850423760888, 0.9381384778398102], 
             199 -> RGBColor[
              0.18648980339442428`, 0.3133429858769703, 0.9339316904651475], 
             268 -> RGBColor[
              0.679362894162589, 0.7494427233598264, 0.9686762023490751], 169 -> 
             RGBColor[
              0.8957887014800139, 0.9197416112963568, 0.9899223200988196], 20 -> 
             RGBColor[
              0.19028821830363388`, 0.31733536077996466`, 0.9341480045749757],
              4 -> RGBColor[
              0.23281884209063286`, 0.36203774297739677`, 0.9365700606812258],
              167 -> RGBColor[
              0.3102543804501736, 0.4431484833325346, 0.9409901126684767], 
             142 -> RGBColor[
              0.18248883410320854`, 0.3091377134757978, 0.9337038411829164], 
             16 -> RGBColor[
              0.3177755060429437, 0.4496629042982282, 0.9414693521405777], 
             281 -> RGBColor[
              0.4286879330306734, 0.5457296739343299, 0.9485365939122276], 
             289 -> RGBColor[
              0.1861676814246589, 0.31300441526303435`, 0.9339133460955061], 
             398 -> RGBColor[
              0.4260942433398349, 0.54348315028676, 0.9483713262986371], 178 -> 
             RGBColor[
              0.44169024668361, 0.5569916245052177, 0.9493650898406981], 58 -> 
             RGBColor[
              0.21195870855243037`, 0.3401124200198894, 0.9353821069360272], 
             186 -> RGBColor[
              0.20685160848485196`, 0.33474453404001786`, 0.9350912651424561],
              122 -> RGBColor[
              0.5979628209588992, 0.6844921818293608, 0.9614929701573222], 
             249 -> RGBColor[
              0.3090764058516128, 0.442128180941986, 0.9409150531686984], 113 -> 
             RGBColor[
              0.30752560771325343`, 0.4405592903292892, 0.9408245004646784], 
             52 -> RGBColor[
              0.17936539842637753`, 0.30585478454218845`, 0.9335259661418299],
              187 -> RGBColor[
              0.43492032413853554`, 0.551127857862875, 0.9489337163625334], 
             259 -> RGBColor[
              0.18623692915551526`, 0.3130771990187241, 0.9339172896513356], 
             42 -> RGBColor[
              0.21651396498896067`, 0.34490028335462225`, 0.9356415220511897],
              134 -> RGBColor[
              0.830968185180272, 0.8680554911049849, 0.9837396813881922], 313 -> 
             RGBColor[
              0.218367213855187, 0.3468481654157909, 0.9357470618324852], 248 -> 
             RGBColor[
              0.21799885977606132`, 0.3464610019236322, 0.9357260846126101], 
             174 -> RGBColor[
              0.34399645769565007`, 0.4723741747164527, 0.943140127993611], 
             215 -> RGBColor[
              0.18299643202543156`, 0.30967123107562133`, 0.9337327481336631],
              399 -> RGBColor[
              0.9265760623547111, 0.7466055848528861, 0.2597795801705179], 83 -> 
             RGBColor[
              0.9450344910434499, 0.9585273939347413, 0.9779264487494559], 95 -> 
             RGBColor[
              0.559409915392181, 0.6531931963016955, 0.9584579442071637], 166 -> 
             RGBColor[
              0.9896948922783259, 0.9900065873749687, 0.82044583391943], 384 -> 
             RGBColor[
              0.18955786573703887`, 0.316567713925446, 0.9341064120767679], 
             233 -> RGBColor[
              0.9594063537213845, 0.9692459055881796, 0.9535986340178257], 
             295 -> RGBColor[
              0.4290348579738498, 0.5460301628831548, 0.9485586996628331], 
             141 -> RGBColor[
              0.8655975347340893, 0.482591620368333, 0.20956362728728348`], 
             319 -> RGBColor[
              0.4533617737780597, 0.567098537525015, 0.9501094460321575], 205 -> 
             RGBColor[
              0.3500177192487492, 0.4775894888363419, 0.943523797455382], 224 -> 
             RGBColor[
              0.1793343425625045, 0.3058221428602024, 0.9335241975563253], 
             231 -> RGBColor[
              0.18219295480676673`, 0.3088267255754066, 0.9336869912946982], 
             332 -> RGBColor[
              0.2283446787479909, 0.35733511362593967`, 0.9363152636977938], 
             68 -> RGBColor[
              0.27002626100566185`, 0.40114509934370585`, 0.9386889681449931],
              10 -> RGBColor[
              0.23750097993416716`, 0.3669589667156367, 0.9368367015048129], 
             250 -> RGBColor[
              0.25834749102875554`, 0.38886997162119286`, 0.9380238794720002],
              282 -> RGBColor[
              0.2671426063657563, 0.39811419548290095`, 0.9385247482792353], 
             374 -> RGBColor[
              0.19021908584372046`, 0.31726269818134456`, 0.934144067583656], 
             232 -> RGBColor[
              0.295092829761857, 0.42749165241872045`, 0.9401164721529931], 
             253 -> RGBColor[
              0.19109293756035423`, 0.31818117174092553`, 0.9341938321461705],
              55 -> RGBColor[
              0.9716313250190438, 0.9159679393868991, 0.3442934839840799], 
             325 -> 
             RGBColor[
              0.289139123347183, 0.42123392949010874`, 0.9397774173803968], 
             91 -> RGBColor[
              0.4932978290383352, 0.5995204262840937, 0.953253358592837], 105 -> 
             RGBColor[
              0.20947576509879728`, 0.3375026890224135, 0.9352407069795285], 
             36 -> RGBColor[
              0.19287789451893317`, 0.32005727467719974`, 0.9342954828043544],
              123 -> RGBColor[
              0.21169783120855037`, 0.3398382213908926, 0.9353672503572267], 
             94 -> RGBColor[
              0.18118663655961964`, 0.30776902129339295`, 0.9336296829592377],
              312 -> RGBColor[
              0.3029090080003519, 0.4357069513217019, 0.9405615919406759], 96 -> 
             RGBColor[
              0.7481991240396009, 0.803218109314472, 0.9755371544320737], 2 -> 
             RGBColor[
              0.18498575182454155`, 0.3117621323146461, 0.9338460369532876], 
             262 -> RGBColor[
              0.2141514811516508, 0.34241716305148284`, 0.9355069820916365], 
             272 -> RGBColor[
              0.7409332819620127, 0.7975419782610151, 0.9748129631969344], 97 -> 
             RGBColor[
              0.19288958051724012`, 0.32006955740235543`, 0.93429614830467], 
             372 -> RGBColor[
              0.19406834726399882`, 0.3213085159913272, 0.9343632773270688], 
             356 -> RGBColor[
              0.19499177110397153`, 0.3222790929955916, 0.9344158649486721], 
             346 -> RGBColor[
              0.3510664211934816, 0.47849782175157674`, 0.9435906198159696], 
             341 -> RGBColor[
              0.3362350503435996, 0.46565163376778274`, 0.9426455779802814], 
             209 -> RGBColor[
              0.33484250288537293`, 0.4644454791509371, 0.9425568460876246], 
             378 -> RGBColor[
              0.19081859398490578`, 0.3178928192487419, 0.9341782086854036], 
             66 -> RGBColor[
              0.2142707962291993, 0.34254257076299915`, 0.935513776908792], 
             139 -> RGBColor[
              0.18805967833656198`, 0.31499302397697726`, 0.9340210925206803],
              56 -> RGBColor[
              0.38165040818030865`, 0.5049881340836845, 0.9455394044224124], 
             335 -> RGBColor[
              0.1795029989097729, 0.3059994113746115, 0.9335338022857975], 
             314 -> RGBColor[
              0.23267428983588884`, 0.3618858093925185, 0.936561828644164], 
             144 -> RGBColor[
              0.1905501321581982, 0.3176106488474093, 0.9341629201815262], 
             298 -> 
             RGBColor[
              0.19699767297971368`, 0.3243874230485212, 0.9345300980930298], 
             204 -> RGBColor[
              0.19363457114614188`, 0.3208525897884652, 0.9343385744188711], 
             207 -> RGBColor[
              0.18775722726537172`, 0.31467512872465075`, 0.9340038683796124],
              334 -> RGBColor[
              0.1849809522741401, 0.31175708768286514`, 0.9338457636259925], 
             149 -> RGBColor[
              0.21660346779159745`, 0.34499435647499893`, 0.9356466191033923],
              219 -> RGBColor[
              0.3371253879726633, 0.4664227994724073, 0.9427023095067106], 
             400 -> RGBColor[
              0.8501784807301029, 0.38669936800784144`, 0.19568427585662201`],
              9 -> RGBColor[
              0.19103464530579026`, 0.3181199028854364, 0.9341905124885087], 
             11 -> RGBColor[
              0.31196467996522614`, 0.44462985881031997`, 0.9410990914412173],
              44 -> RGBColor[
              0.2366745638317519, 0.36609035099419096`, 0.9367896383303533], 
             153 -> RGBColor[
              0.1824446187841665, 0.30909124037207153`, 0.9337013231859077], 
             32 -> RGBColor[
              0.9570322462930174, 0.8667218188173162, 0.28757881993815293`], 
             162 -> RGBColor[
              0.27232886945688745`, 0.40356528681975196`, 0.9388200982898864],
              90 -> RGBColor[
              0.6083786689975903, 0.6929482364957771, 0.9623129438694364], 
             331 -> RGBColor[
              0.19914754728651962`, 0.3266470772548782, 0.9346525302543484], 
             8 -> RGBColor[
              0.2378122641398246, 0.36728614615234123`, 0.9368544286798214], 
             364 -> RGBColor[
              0.8176771202476999, 0.13687966915311423`, 0.16456093635363633`],
              342 -> RGBColor[
              0.18371444184961855`, 0.31042590492529404`, 0.9337736377309502],
              163 -> RGBColor[
              0.26679472020223177`, 0.3977485450677799, 0.938504936676874], 
             49 -> RGBColor[
              0.18767785554878408`, 0.3145917040180597, 0.9339993482777726], 
             338 -> RGBColor[
              0.23420030298526878`, 0.3634897459673388, 0.9366487328354871], 
             76 -> RGBColor[
              0.1938965482594379, 0.32112794434484765`, 0.9343534936279129], 
             369 -> RGBColor[
              0.19059767181486464`, 0.3176606160407541, 0.9341656274946448], 
             82 -> RGBColor[
              0.1807265568208277, 0.30728544831718235`, 0.9336034820987404], 
             67 -> 
             RGBColor[
              0.42522253205912725`, 0.5427281177888938, 0.9483157816266544], 
             211 -> RGBColor[
              0.22188954865981286`, 0.3505503626243781, 
               0.9359476535887813]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9l2k4lWvYhs1zWMs8LNZoLbMSqfBetRslSppMScqwSaE2pQyZolBokCJT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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 14}], {
             RGBColor[
             0.18904790384743964`, 0.31603171164602595`, 0.9340773705015762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.18749255911212426`, 0.3143969457146576, 0.9339887959198263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 49}], {
             RGBColor[
             0.19061232216343427`, 0.3176760144859865, 0.9341664618103227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 62}], {
             RGBColor[
             0.19732629313580521`, 0.3247328236682947, 0.9345488125247692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 87}], {
             RGBColor[
             0.19586287681444192`, 0.32319468032858806`, 0.934465473130198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 119}], {
             RGBColor[
             0.18798137752672578`, 0.3149107248612813, 0.9340166334053959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 127}], {
             RGBColor[
             0.19417547404882396`, 0.3214211130344089, 0.9343693780389848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 129}], {
             RGBColor[
             0.19131755276026974`, 0.31841725655746295`, 0.9342066236495172]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 216}], {
             RGBColor[
             0.19662871859939152`, 0.3239996286017438, 0.9345090866868895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 231}], {
             RGBColor[
             0.1878698717924256, 0.3147935252646599, 0.9340102833187854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 235}], {
             RGBColor[
             0.19253038583618232`, 0.3196920210183055, 0.9342756926989647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 298}], {
             RGBColor[
             0.19527223087889906`, 0.32257387400121723`, 0.9344318367179512]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 313}], {
             RGBColor[
             0.20595700131663575`, 0.3338042451848521, 0.935040318587679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 317}], {
             RGBColor[
             0.19445041549410247`, 0.3217100939256911, 0.9343850355475539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 336}], {
             RGBColor[
             0.18695004027347276`, 0.31382672401755374`, 0.9339579002745498]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 361}], {
             RGBColor[
             0.205591391562574, 0.33341996615233593`, 0.9350194976530564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 393}], {
             RGBColor[
             0.1884550205876297, 0.3154085537489959, 0.9340436066770222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 396}], {
             RGBColor[
             0.1965523248147455, 0.3239193338904351, 0.9345047361738683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 97}], {
             RGBColor[
             0.18893766617089083`, 0.31591584485850077`, 0.9340710926289788]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 109}], {
             RGBColor[
             0.1831541470606865, 0.30983699957738503`, 0.9337417297716024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 181}], {
             RGBColor[
             0.1899547149925528, 0.3169848276546873, 0.9341290120547836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 191}], {
             RGBColor[
             0.19610476461646903`, 0.323448919745091, 0.9344792482826825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 193}], {
             RGBColor[
             0.18596534003799042`, 0.3127917416364609, 0.9339018230528726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 211}], {
             RGBColor[
             0.2034376502421772, 0.3311562474695121, 0.9348968452710344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 305}], {
             RGBColor[
             0.18360947068078184`, 0.31031557357129014`, 0.9337676597781759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 334}], {
             RGBColor[
             0.18498335204934083`, 0.3117596099987556, 0.93384590028964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 340}], {
             RGBColor[
             0.19396024281710603`, 0.32119489136342505`, 0.9343571209387445]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 360}], {
             RGBColor[
             0.18511749831467772`, 0.3119006062289892, 0.9338535397209994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 365}], {
             RGBColor[
             0.18295812271216946`, 0.3096309655584321, 0.9337305664749465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 370}], {
             RGBColor[
             0.18603673488354355`, 0.3128667821458319, 0.9339058888837076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 11}], {
             RGBColor[
             0.4469167817161049, 0.5580281285800609, 0.9506625439425702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 21}], {
             RGBColor[
             0.7725354937206939, 0.7794802979389553, 0.6358867741972027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 34}], {
             RGBColor[
             0.4225585018257533, 0.5327236209657705, 0.9492644797482566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 74}], {
             RGBColor[
             0.7224644673916434, 0.782535536200579, 0.9735133143364585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 86}], {
             RGBColor[
             0.49644576954540676`, 0.6009276484384913, 0.9538184872502891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 91}], {
             RGBColor[
             0.5375833562526594, 0.6354734123169479, 0.9567396775183801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 95}], {
             RGBColor[
             0.5706393994295823, 0.6623097973257487, 0.9593419703255434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 160}], {
             RGBColor[
             0.5207461823507223, 0.6218042360373149, 0.9554141935122193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[
             0.42709887646193556`, 0.5374958425847769, 0.9495230473669047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 233}], {
             RGBColor[
             0.7706376185941841, 0.8203361519689907, 0.9569123152308744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 263}], {
             RGBColor[
             0.48691076315351817`, 0.5926689051451934, 0.9532109250744729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 264}], {
             RGBColor[
             0.652580274743898, 0.7275933060781521, 0.9666403041170564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 285}], {
             RGBColor[
             0.7880339609127915, 0.8307135264515318, 0.7851026525209982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 312}], {
             RGBColor[
             0.44238894573366777`, 0.553566674835752, 0.9503937941922995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 348}], {
             RGBColor[
             0.45750426505624076`, 0.5671984745069012, 0.9513371690188597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 13}], {
             RGBColor[
             0.22349076802527734`, 0.3522333457006528, 0.9360388406628528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 66}], {
             RGBColor[
             0.22354481915991609`, 0.35229015687019793`, 0.9360419187950089]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 123}], {
             RGBColor[
             0.2222583366495916, 0.3509379821841447, 0.9359686555192263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 131}], {
             RGBColor[
             0.22303764420255517`, 0.35175708383326204`, 0.9360130359314853]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 140}], {
             RGBColor[
             0.22925899781803233`, 0.3582961209397305, 0.9363673328162189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 183}], {
             RGBColor[
             0.2914028738694214, 0.4198002713108441, 0.9400459473606144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 186}], {
             RGBColor[
             0.2198352252877424, 0.3483911385087073, 0.9358306629118409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 188}], {
             RGBColor[
             0.2173017232473819, 0.34572826723098127`, 0.9356863837186229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 203}], {
             RGBColor[
             0.22928794206914588`, 0.35832654318282237`, 0.9363689811485005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 232}], {
             RGBColor[
             0.26395583592624494`, 0.3947646976980586, 0.9383432664171094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 238}], {
             RGBColor[
             0.26140051176335477`, 0.3920788899859515, 0.9381977444862962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 275}], {
             RGBColor[
             0.235784586016354, 0.3651549278823552, 0.9367389554103707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 280}], {
             RGBColor[
             0.24217745234544014`, 0.3718742357253608, 0.937103019690414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 297}], {
             RGBColor[
             0.2198696831096341, 0.34842735586426754`, 0.9358326252338219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 309}], {
             RGBColor[
             0.2652076930566547, 0.39608047891444564`, 0.9384145578287296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 322}], {
             RGBColor[
             0.21636197354501668`, 0.3447405307102229, 0.9356328663633082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 325}], {
             RGBColor[
             0.26097898271890796`, 0.39163583623375275`, 0.9381737390308114]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 339}], {
             RGBColor[
             0.24218330961780632`, 0.3718803920899902, 0.9371033532534101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 8}], {
             RGBColor[
             0.2601258969540067, 0.39073918900607996`, 0.9381251570585274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 43}], {
             RGBColor[
             0.2713996679468782, 0.4025886371179538, 0.9387671816385219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 56}], {
             RGBColor[
             0.3320449689742487, 0.4595901829717516, 0.9424676449298229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.31447583347960173`, 0.4443726808567142, 0.9413481551518805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 90}], {
             RGBColor[
             0.44540909938288953`, 0.5535702341777979, 0.950854414653335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 100}], {
             RGBColor[
             0.24629351933764826`, 0.37620048310789195`, 0.9373374236164447]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 121}], {
             RGBColor[
             0.2966728547509243, 0.4289526354856623, 0.9402137650898452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 122}], {
             RGBColor[
             0.440201175363544, 0.5493422068445898, 0.9504444277972779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 175}], {
             RGBColor[
             0.282045444074704, 0.41377802280949016`, 0.9393734428399871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 178}], {
             RGBColor[
             0.36206488822589933`, 0.4855919281825182, 0.9443804876389659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 213}], {
             RGBColor[
             0.25252900688278906`, 0.3827543758705798, 0.9376925254075633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 227}], {
             RGBColor[
             0.24495455926499354`, 0.3747931511765599, 0.937261171821121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 274}], {
             RGBColor[
             0.38775900825169696`, 0.5067672930904867, 0.9463159883002454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 296}], {
             RGBColor[
             0.26370004466317304`, 0.39449584486246725`, 0.9383286994830867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 308}], {
             RGBColor[
             0.24197001296398313`, 0.37165620378303305`, 0.9370912063245189]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 319}], {
             RGBColor[
             0.3679006517731242, 0.4906453846924169, 0.9447526657346955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 352}], {
             RGBColor[
             0.26102097459574697`, 0.3916799723587493, 0.9381761304060758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 373}], {
             RGBColor[
             0.27714534160664284`, 0.4086277044311172, 0.939094389253483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 56}], {
             RGBColor[
             0.34361946259808085`, 0.47175570963568103`, 0.9431267952187714]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 79}], {
             RGBColor[
             0.26831622286540857`, 0.39934774083561936`, 0.9385915840026804]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 137}], {
             RGBColor[
             0.32002599977803325`, 0.451320237982877, 0.941623440630758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 169}], {
             RGBColor[
             0.6006886092479335, 0.6791324482420171, 0.965318253056975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 175}], {
             RGBColor[
             0.2936199376985361, 0.4259435494734196, 0.9400325931289355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 178}], {
             RGBColor[
             0.37363938184973156`, 0.4977574548464476, 0.9450396379279142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 252}], {
             RGBColor[
             0.3375773650971563, 0.4665223484650306, 0.9427417981088295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 277}], {
             RGBColor[
             0.2567019144406389, 0.38714036629150045`, 0.9379301663197194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 278}], {
             RGBColor[
             0.28187720037590647`, 0.4136011880147874, 0.9393638616102349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 300}], {
             RGBColor[
             0.6101439916355338, 0.6866719134983721, 0.9662201158700239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 314}], {
             RGBColor[
             0.26913140342587094`, 0.400204547290098, 0.9386380073296472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 319}], {
             RGBColor[
             0.37947514539695637`, 0.5028109113563464, 0.945411816023644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 352}], {
             RGBColor[
             0.27259546821957914`, 0.40384549902267874`, 0.9388352806950242]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 379}], {
             RGBColor[
             0.25634517615934155`, 0.38676541173934353`, 0.9379098506023464]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 65}], {
             RGBColor[
             0.36829577629683624`, 0.4914979419428903, 0.9447588725119885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 67}], {
             RGBColor[
             0.43693392935130804`, 0.5528719414914377, 0.9490620215061302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 68}], {
             RGBColor[
             0.3593357938245753, 0.4820804322688437, 0.9442486147652995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 96}], {
             RGBColor[
             0.5984222253415448, 0.6831169372542267, 0.9626727079088397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 173}], {
             RGBColor[
             0.36556257674898185`, 0.48862517592323496`, 0.9446032208411446]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[
             0.7215884971461117, 0.7768639400824314, 0.7979961077324451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 201}], {
             RGBColor[
             0.698844545732584, 0.7622666344739716, 0.960474027707296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 223}], {
             RGBColor[
             0.6892737381041355, 0.6614040887409706, 0.6061320446993241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 250}], {
             RGBColor[
             0.35349640883612216`, 0.4759428684075872, 0.943916070428803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 387}], {
             RGBColor[
             0.4913856837463006, 0.597841186558023, 0.9531378831854276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 43}], {
             RGBColor[
             0.24908603513269617`, 0.379135594264215, 0.9374964532598158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 56}], {
             RGBColor[
             0.30973133616006665`, 0.43613714011801286`, 0.9411969165511169]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 59}], {
             RGBColor[
             0.2921622006654197, 0.4209196380029755, 0.9400774267731745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 100}], {
             RGBColor[
             0.22397988652346618`, 0.35274744025415317`, 0.9360666952377386]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 121}], {
             RGBColor[
             0.2743592219367422, 0.4054995926319236, 0.9389430367111391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 175}], {
             RGBColor[
             0.2597318112605219, 0.39032497995575144`, 0.938102714461281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 213}], {
             RGBColor[
             0.230215374068607, 0.3593013330168411, 0.9364217970288573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 227}], {
             RGBColor[
             0.22264092645081146`, 0.35134010832282114`, 0.9359904434424149]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 237}], {
             RGBColor[
             0.2175725261235523, 0.3460128982237305, 0.9357018055418038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 296}], {
             RGBColor[
             0.241386411848991, 0.3710428020087285, 0.9370579711043807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 308}], {
             RGBColor[
             0.21965638014980107`, 0.34820316092929426`, 0.9358204779458129]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 352}], {
             RGBColor[
             0.23870734178156489`, 0.36822692950501057`, 0.9369054020273697]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 373}], {
             RGBColor[
             0.2548317087924608, 0.38517466157737845`, 0.937823660874777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 39}], {
             RGBColor[
             0.1871051393828018, 0.3139897430153101, 0.9339667329393776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.2089266760744028, 0.33692556164351994`, 0.9352094371718936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 150}], {
             RGBColor[
             0.19229026561489077`, 0.3194396394412268, 0.9342620182075883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 192}], {
             RGBColor[
             0.1863278971063823, 0.3131728121027866, 0.9339224701415624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 283}], {
             RGBColor[
             0.2000074908485974, 0.3275509324621929, 0.9347015027680361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 294}], {
             RGBColor[
             0.1904972038981096, 0.3175550178902107, 0.9341599059954147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 320}], {
             RGBColor[
             0.1934136507337484, 0.32062038842787655`, 0.9343259933282078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 347}], {
             RGBColor[
             0.19444294915612814`, 0.3217022463310869, 0.9343846103506517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 381}], {
             RGBColor[
             0.19359903145009902`, 0.3208152353145773, 0.9343365504857577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 384}], {
             RGBColor[
             0.19029625552141455`, 0.3173438084054412, 0.9341484622826384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.26166329356975937`, 0.3923550903258115, 0.9382127095214201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 37}], {
             RGBColor[
             0.29314980125126083`, 0.4217462676405007, 0.9401414095988625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 62}], {
             RGBColor[
             0.21930338871384658`, 0.34783214454915645`, 0.9358003756057394]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 87}], {
             RGBColor[
             0.2178399723924833, 0.34629400120944975`, 0.9357170362111682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 155}], {
             RGBColor[
             0.22229114501906733`, 0.3509724658606344, 0.9359705239073323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 170}], {
             RGBColor[
             0.2345826966210814, 0.3638916659237347, 0.936670509587346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 216}], {
             RGBColor[
             0.21860581417743288`, 0.3470989494826055, 0.9357606497678597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 256}], {
             RGBColor[
             0.29440488188335295`, 0.4228333554018322, 0.9402213822269152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 261}], {
             RGBColor[
             0.24873551087533646`, 0.3787671710452084, 0.9374764914219134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 298}], {
             RGBColor[
             0.21724932645694042`, 0.3456731948820789, 0.9356833997989213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 311}], {
             RGBColor[
             0.2701224968687157, 0.40124624933748154`, 0.9386944486350258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 313}], {
             RGBColor[
             0.22793409689467709`, 0.35690356606571383`, 0.9362918816686491]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 361}], {
             RGBColor[
             0.22756848714061534`, 0.35651928703319763`, 0.9362710607340264]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 396}], {
             RGBColor[
             0.21852942039278686`, 0.3470186547712968, 0.9357562992548385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 34}], {
             RGBColor[
             0.28760640007487454`, 0.41932535119602954`, 0.9397010272469036]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 35}], {
             RGBColor[
             0.27410810708868466`, 0.4051377894263376, 0.9389323194302751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 85}], {
             RGBColor[
             0.2763549775912347, 0.40749939278433556`, 0.9390602753814483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 86}], {
             RGBColor[
             0.361493667794528, 0.48752937866875046`, 0.9442550347489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 91}], {
             RGBColor[
             0.40263125450178067`, 0.5220751425472069, 0.9471762250170271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 93}], {
             RGBColor[
             0.2731424573639435, 0.4041228303399058, 0.9388773271070019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 95}], {
             RGBColor[
             0.43568729767870357`, 0.5489115275560077, 0.9497785178241904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 125}], {
             RGBColor[
             0.2867382877276377, 0.41841291007758175`, 0.9396515895329856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 162}], {
             RGBColor[
             0.29214677471105677`, 0.42409757281503596`, 0.9399595948655519]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 211}], {
             RGBColor[
             0.2669271143125195, 0.39759011071734907`, 0.9385233725149993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 214}], {
             RGBColor[
             0.2758548681185897, 0.40697374601981373`, 0.9390317948868268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 248}], {
             RGBColor[
             0.2649817698706437, 0.3955454303669761, 0.9384125880269136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 263}], {
             RGBColor[
             0.35195866140263943`, 0.47927063537545245`, 0.9436474725731201]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 312}], {
             RGBColor[
             0.30743684398278903`, 0.44016840506601096`, 0.9408303416909466]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.313125811057198, 0.4456106195888476, 0.9411739913250522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 17}], {
             RGBColor[
             0.2700762317403779, 0.40119762175422, 0.93869181390441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 22}], {
             RGBColor[
             0.3123757406994519, 0.44496094634460026`, 0.9411261975051177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 47}], {
             RGBColor[
             0.4262898849714413, 0.5411626092696967, 0.9490658048705467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 106}], {
             RGBColor[
             0.2676474114572338, 0.3986447776405352, 0.9385534961824027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 107}], {
             RGBColor[
             0.3285473986430889, 0.45896802364421685`, 0.9421566412492507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 118}], {
             RGBColor[
             0.27367870261090094`, 0.4049840470489852, 0.9388969692911083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 158}], {
             RGBColor[
             0.32361612706914167`, 0.45469680405977975`, 0.941842424985111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 209}], {
             RGBColor[
             0.3216593094784126, 0.45300190701520204`, 0.9417177382985756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 241}], {
             RGBColor[
             0.28584467655013013`, 0.4177712570264148, 0.9395898035090018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 270}], {
             RGBColor[
             0.3337876806083378, 0.46350689249828564`, 0.9424905473822769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 310}], {
             RGBColor[
             0.2940376027932159, 0.42638254196942454`, 0.9400563785381975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 323}], {
             RGBColor[
             0.35358359064672407`, 0.4806531148021672, 0.943751925265087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 324}], {
             RGBColor[
             0.4708028735942141, 0.577300258720949, 0.9525700303913813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 346}], {
             RGBColor[
             0.329771268632467, 0.46002807831552184`, 0.9422346251627481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 390}], {
             RGBColor[
             0.28559351861557547`, 0.41750727411286515`, 0.9395755004361839]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 66}], {
             RGBColor[
             0.21421674509456057`, 0.34248575959345395`, 0.9355106987766358]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 123}], {
             RGBColor[
             0.2129302625842361, 0.3411335849074007, 0.9354374355008532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 131}], {
             RGBColor[
             0.21370957013719966`, 0.34195268655651806`, 0.9354818159131122]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[
             0.2199309237526768, 0.34849172366298653`, 0.9358361127978458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 188}], {
             RGBColor[
             0.20797364918202638`, 0.3359238699542373, 0.9351551637002498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 203}], {
             RGBColor[
             0.21995986800379036`, 0.3485221459060784, 0.9358377611301275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 232}], {
             RGBColor[
             0.2546277618608894, 0.3849603004213146, 0.9378120463987364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 275}], {
             RGBColor[
             0.22645651195099847`, 0.3553505306056112, 0.9362077353919975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 280}], {
             RGBColor[
             0.23284937828008462`, 0.36206983844861684`, 0.9365717996720409]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 297}], {
             RGBColor[
             0.2105416090442786, 0.33862295858752356`, 0.9353014052154489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 309}], {
             RGBColor[
             0.25587961899129924`, 0.38627608163770166`, 0.9378833378103566]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 322}], {
             RGBColor[
             0.20703389947966117`, 0.33493613343347894`, 0.9351016463449351]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 325}], {
             RGBColor[
             0.25165090865355244`, 0.3818314389570088, 0.9376425190124382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 339}], {
             RGBColor[
             0.2328552355524508, 0.3620759948132462, 0.936572133235037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 29}], {
             RGBColor[
             0.18299367418147944`, 0.3096683324067703, 0.9337325910785299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 62}], {
             RGBColor[
             0.1928274082051604, 0.3200042103604074, 0.9342926076834728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 119}], {
             RGBColor[
             0.18348249259608096`, 0.310182111553394, 0.9337604285640995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 126}], {
             RGBColor[
             0.18556762080960376`, 0.31237371351057097`, 0.9338791735311889]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 127}], {
             RGBColor[
             0.18967658911817914`, 0.3166924997265216, 0.9341131731976884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 129}], {
             RGBColor[
             0.18681866782962492`, 0.3136886432495756, 0.9339504188082208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 196}], {
             RGBColor[
             0.18714224683050756`, 0.3140287452955969, 0.9339688461536289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 235}], {
             RGBColor[
             0.1880315009055375, 0.3149634077104182, 0.9340194878576683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 317}], {
             RGBColor[
             0.18995153056345765`, 0.3169814806178038, 0.9341288307062575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 326}], {
             RGBColor[
             0.18828033718868842`, 0.3152249504211414, 0.9340336587158735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 327}], {
             RGBColor[
             0.19007805312865012`, 0.317114463855815, 0.9341360359791719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 336}], {
             RGBColor[
             0.18245115534282794`, 0.3090981107096664, 0.9337016954332534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 396}], {
             RGBColor[
             0.19205343988410067`, 0.31919072058254777`, 0.9342485313325719]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 33}], {
             RGBColor[
             0.28118366953987284`, 0.41287224313372134`, 0.9393243660551096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 37}], {
             RGBColor[
             0.31731211488685307`, 0.44714239125067556`, 0.9415174176154697]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.24346570234943876`, 0.37322826815933124`, 0.9371763836223466]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 92}], {
             RGBColor[
             0.3916080301069964, 0.5102971083648917, 0.9465821312407912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 256}], {
             RGBColor[
             0.31856719551894513`, 0.448229479012007, 0.9415973902435224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 311}], {
             RGBColor[
             0.2942848105043079, 0.4266423729476564, 0.940070456651633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 313}], {
             RGBColor[
             0.25209641053026927`, 0.3822996896758886, 0.9376678896852563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 361}], {
             RGBColor[
             0.2517308007762076, 0.3819154106433724, 0.9376470687506336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 386}], {
             RGBColor[
             0.5232931103169385, 0.6153912271159707, 0.9581889419192983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 69}], {
             RGBColor[
             0.2797958916834022, 0.41057876108804503`, 0.9392759017239116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 106}], {
             RGBColor[
             0.2722971064429795, 0.4026970623499158, 0.9388488569979281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 107}], {
             RGBColor[
             0.33319709362883454`, 0.4630203083535974, 0.9424520020647762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 190}], {
             RGBColor[
             0.6369974104682594, 0.7082659607734624, 0.9502314057905163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 212}], {
             RGBColor[
             0.36755596390986156`, 0.4927802348639901, 0.9446413188967272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 241}], {
             RGBColor[
             0.29049437153587576`, 0.42182354173579545`, 0.9398851643245274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 268}], {
             RGBColor[
             0.49856920010276634`, 0.5995528138290274, 0.9550727772448264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 270}], {
             RGBColor[
             0.3384373755940835, 0.46755917720766627`, 0.9427859081978025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 274}], {
             RGBColor[
             0.4054269963890745, 0.5245026293096915, 0.9473527216519175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 295}], {
             RGBColor[
             0.3734051820083968, 0.4978465335906915, 0.9450140259017055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 310}], {
             RGBColor[
             0.2986872977789616, 0.43043482667880517`, 0.9403517393537228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 324}], {
             RGBColor[
             0.47545256857995977`, 0.5813525434303296, 0.9528653912069069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 351}], {
             RGBColor[
             0.6137824648944775, 0.6902841557450048, 0.9663635368138602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 373}], {
             RGBColor[
             0.29481332974402036`, 0.42636304065032193`, 0.9401311226051551]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 380}], {
             RGBColor[
             0.26894987250182517`, 0.3991789072508731, 0.9386582369767682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 390}], {
             RGBColor[
             0.2902432136013212, 0.4215595588222458, 0.9398708612517093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 22}], {
             RGBColor[
             0.2739758563683775, 0.40460023321935323`, 0.9389393809000012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 48}], {
             RGBColor[
             0.23593219427525336`, 0.3653100735213626, 0.936747361482348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 61}], {
             RGBColor[
             0.22052046256389546`, 0.34911136633249684`, 0.9358696861610002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 118}], {
             RGBColor[
             0.23527881827982655`, 0.36462333392373825`, 0.9367101526859918]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 158}], {
             RGBColor[
             0.2852162427380673, 0.4143360909345327, 0.9396556083799944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 164}], {
             RGBColor[
             0.21631448031938844`, 0.34469061231884324`, 0.9356301616943686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 173}], {
             RGBColor[
             0.25707808713188923`, 0.38753574764073073`, 0.9379515887979883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 209}], {
             RGBColor[
             0.2832594251473382, 0.412641193889955, 0.9395309216934591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 241}], {
             RGBColor[
             0.2474447922190557, 0.37741054390116785`, 0.9374029869038852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 287}], {
             RGBColor[
             0.2108043778715786, 0.3388991452855218, 0.9353163695114319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 323}], {
             RGBColor[
             0.3151837063156497, 0.44029240167692024`, 0.9415651086599703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 346}], {
             RGBColor[
             0.29137138430139253`, 0.41966736519027487`, 0.9400478085576316]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 354}], {
             RGBColor[
             0.2237645258481464, 0.35252108252973663`, 0.9360544307658767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 371}], {
             RGBColor[
             0.20911196002482746`, 0.33712030682309724`, 0.9352199888187673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 388}], {
             RGBColor[
             0.22559527698605156`, 0.35444531805200136`, 0.9361586893348268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 389}], {
             RGBColor[
             0.21716250001380405`, 0.34558193478522814`, 0.9356784551614329]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 45}], {
             RGBColor[
             0.4449748432614876, 0.5535011435034702, 0.9507944263097807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 74}], {
             RGBColor[
             0.7341001698400949, 0.7919819236306536, 0.974429319456183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 86}], {
             RGBColor[
             0.5080814719938581, 0.6103740358685661, 0.9547344923700136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 91}], {
             RGBColor[
             0.5492190587011108, 0.6449197997470224, 0.9576556826381046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 112}], {
             RGBColor[
             0.7711240798821252, 0.7393399357057666, 0.6151558638126768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 141}], {
             RGBColor[
             0.7787784526106882, 0.5518341379822057, 0.46039508708597976`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 148}], {
             RGBColor[
             0.46955925293009415`, 0.5770080258985608, 0.9522798906351313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 179}], {
             RGBColor[
             0.5295441815391476, 0.6289468481238254, 0.9561068042364651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 232}], {
             RGBColor[
             0.4501165590628717, 0.5589054128143358, 0.9510872394181826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 257}], {
             RGBColor[
             0.46412234198098856`, 0.5722988469015355, 0.9519334554771259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 279}], {
             RGBColor[
             0.638687245246097, 0.7170964540862654, 0.9650118438159424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 285}], {
             RGBColor[
             0.7996696633612428, 0.8401599138816065, 0.7860186576407228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 288}], {
             RGBColor[
             0.45525573629442806`, 0.5643070139273578, 0.9513799079587884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 399}], {
             RGBColor[
             0.7658581753592988, 0.7184623790314186, 0.610918793426945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 185}], {
             RGBColor[
             0.330002266441723, 0.4557835793222022, 0.9424120819002554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 198}], {
             RGBColor[
             0.30685620721234774`, 0.43573562617248035`, 0.9409372354734161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 205}], {
             RGBColor[
             0.30521095643223367`, 0.4343105926394541, 0.9408324015485454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 219}], {
             RGBColor[
             0.2987647907941907, 0.4287272479574868, 0.9404216575742097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 262}], {
             RGBColor[
             0.23727783738368446`, 0.36672442974702457`, 0.9368239938666727]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 284}], {
             RGBColor[
             0.2685014480461575, 0.3995424242445413, 0.938602132302708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 293}], {
             RGBColor[
             0.3046492475878372, 0.4338240686707453, 0.9407966099576801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 331}], {
             RGBColor[
             0.22977587045111889`, 0.35883938684872224`, 0.9363967679480286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 338}], {
             RGBColor[
             0.24730224830049347`, 0.3772607212049526, 0.937394869238598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.1986384662361157, 0.32611200079330077`, 0.9346235388416457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 36}], {
             RGBColor[
             0.19158305641128354`, 0.3186963177285822, 0.934221743689665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 80}], {
             RGBColor[
             0.18504810846190303`, 0.31182767309415216`, 0.933849588071537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 151}], {
             RGBColor[
             0.19115376674236922`, 0.3182451070680162, 0.9341972962780976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 168}], {
             RGBColor[
             0.18724662483160132`, 0.31413845319269396`, 0.9339747903263778]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 265}], {
             RGBColor[
             0.19013547399899927`, 0.31717481683124543`, 0.9341393060127917]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 291}], {
             RGBColor[
             0.18873168488737596`, 0.31569934546955897`, 0.9340593622996046]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 304}], {
             RGBColor[
             0.185589373288035, 0.312396576744589, 0.9338804123026556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 378}], {
             RGBColor[
             0.19055340614426983`, 0.31761409001435326`, 0.9341631066301896]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 383}], {
             RGBColor[
             0.1993210537450841, 0.3268294435437743, 0.9346624111904838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 24}], {
             RGBColor[
             0.868258601963509, 0.40303301389979596`, 0.21554172931270557`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 25}], {
             RGBColor[
             0.8659467013248013, 0.3852627325093696, 0.21332785065016086`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 27}], {
             RGBColor[
             0.8684261923998754, 0.40432118743230555`, 0.21570221410383633`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 32}], {
             RGBColor[
             0.9601171751337108, 0.8771280081727125, 0.29956318594431774`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 78}], {
             RGBColor[
             0.8676924203602071, 0.39868109399445717`, 0.21499955316997305`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 95}], {
             RGBColor[
             0.7613060096832925, 0.7703636969149021, 0.6350027480788232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 104}], {
             RGBColor[
             0.867073450053741, 0.3939234169844408, 0.2144068265054741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 160}], {
             RGBColor[
             0.7114127926044326, 0.7298581356264684, 0.631074971265499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 172}], {
             RGBColor[
             0.8702695187872548, 0.4184898017964773, 0.21746738553413028`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 208}], {
             RGBColor[
             0.9781086897296334, 0.9394569243444684, 0.5384830216306559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 217}], {
             RGBColor[
             0.9781358461419554, 0.9375595363156388, 0.3992965964312667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 230}], {
             RGBColor[
             0.8662262457545036, 0.38741143349321117`, 0.21359554271174397`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 233}], {
             RGBColor[
             0.9613042288478943, 0.9283900515581442, 0.6325730929841542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 240}], {
             RGBColor[
             0.8755266503036192, 0.45889841832097356`, 0.22250162061128162`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 242}], {
             RGBColor[
             0.8892496521392507, 0.5643794238873858, 0.23564278266699612`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 244}], {
             RGBColor[
             0.9589837634229517, 0.9266594522436353, 0.6365010356742713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 264}], {
             RGBColor[
             0.8432468849976082, 0.8356472056673055, 0.6423010818703361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 285}], {
             RGBColor[
             0.9787005711665018, 0.9387674260406853, 0.4607634302742779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 357}], {
             RGBColor[
             0.892467694136608, 0.589114704834069, 0.2387243833179241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 47}], {
             RGBColor[
             0.4301895095994409, 0.5445652207348299, 0.9493133718661378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.27823170323432733`, 0.40907339811174287`, 0.9391817450830557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 96}], {
             RGBColor[
             0.5322372446835262, 0.6257908335621027, 0.9584554594663912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 118}], {
             RGBColor[
             0.2775783272389005, 0.4083866585141185, 0.9391445362866995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 158}], {
             RGBColor[
             0.3275157516971413, 0.458099415524913, 0.9420899919807021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 173}], {
             RGBColor[
             0.2993775960909632, 0.43129907223111097`, 0.940385972398696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 209}], {
             RGBColor[
             0.32555893410641223`, 0.4564045184803353, 0.9419653052941668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 241}], {
             RGBColor[
             0.28974430117812966`, 0.42117386849154814`, 0.9398373705045929]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 310}], {
             RGBColor[
             0.2979372274212155, 0.4297851534345578, 0.9403039455337885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 323}], {
             RGBColor[
             0.35748321527472365`, 0.48405572626730053`, 0.943999492260678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 346}], {
             RGBColor[
             0.3336708932604665, 0.46343068978065516`, 0.9424821921583393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 354}], {
             RGBColor[
             0.2660640348072204, 0.3962844071201169, 0.9384888143665844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 388}], {
             RGBColor[
             0.26789478594512556`, 0.39820864264238165`, 0.9385930729355345]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 75}], {
             RGBColor[
             0.255511442446525, 0.3858891047454028, 0.9378623707008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 120}], {
             RGBColor[
             0.40567769043424073`, 0.5225843384798207, 0.9476110227757661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 132}], {
             RGBColor[
             0.32566481114992, 0.45504559524241234`, 0.9420251663053016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 160}], {
             RGBColor[
             0.3763398438622711, 0.4987665529777692, 0.9453014400255476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 202}], {
             RGBColor[
             0.2682077809117381, 0.39923376146669465`, 0.9385854083938443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 220}], {
             RGBColor[
             0.46443936234214256`, 0.5702897109178078, 0.9522369568394528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 229}], {
             RGBColor[
             0.24996961512608984`, 0.38006429285947896`, 0.9375467718333002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 260}], {
             RGBColor[
             0.2588190028871956, 0.3893655604799919, 0.938050731374799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 307}], {
             RGBColor[
             0.32070535665531497`, 0.4507499650286162, 0.9417091542503788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 321}], {
             RGBColor[
             0.42370887427578074`, 0.5372228658179581, 0.9490305036181749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 341}], {
             RGBColor[
             0.3146456284168403, 0.44550133299924655`, 0.9413230337254305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 348}], {
             RGBColor[
             0.3130979265677895, 0.44416079144735543`, 0.9412244155321879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 366}], {
             RGBColor[
             0.34372780451171075`, 0.47069085221995155`, 0.9431761242698371]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.8208706461762446, 0.16142650885189433`, 0.16761906038938248`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 32}], {
             RGBColor[
             0.8662019827363802, 0.39609555432953175`, 0.20755215197526236`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 73}], {
             RGBColor[
             0.8573963396759665, 0.36139490937802465`, 0.1993690984497273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.8348779177441421, 0.40506983940754504`, 0.4406260894055427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 78}], {
             RGBColor[
             0.8205037601564106, 0.15860646213297017`, 0.16726772992245081`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 104}], {
             RGBColor[
             0.8201942750031774, 0.15622762362796194`, 0.16697136659020134`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 112}], {
             RGBColor[
             0.859560524438829, 0.3699751807909537, 0.20111045230987185`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 141}], {
             RGBColor[
             0.8357237455500708, 0.2680521548465373, 0.1815470877583059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 172}], {
             RGBColor[
             0.8217923093699344, 0.16851081603398022`, 0.16850164610452945`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 208}], {
             RGBColor[
             0.8781963258003285, 0.43764816511070226`, 0.36683204243282114`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 240}], {
             RGBColor[
             0.8244208751281166, 0.18871512429622833`, 0.17101876364310512`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 242}], {
             RGBColor[
             0.8312823760459324, 0.24145562707943447`, 0.17758934467096238`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 243}], {
             RGBColor[
             0.8703666327474808, 0.4327860372681659, 0.42384867205099064`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 285}], {
             RGBColor[
             0.8785909134249075, 0.43718849957484696`, 0.31501898152856916`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 337}], {
             RGBColor[
             0.8785401737932351, 0.4370799726332635, 0.30949628574974347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 357}], {
             RGBColor[
             0.832891397044611, 0.253823267552776, 0.17913014499642635`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 399}], {
             RGBColor[
             0.8560499214236114, 0.3560568096747217, 0.198285738719384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 32}], {
             RGBColor[
             0.8638900820976725, 0.3783252729391054, 0.20533827331271765`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 78}], {
             RGBColor[
             0.8181918595177029, 0.1408361807425438, 0.1650538512599061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 83}], {
             RGBColor[
             0.8598908303478167, 0.4089271313115804, 0.435454149583152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 194}], {
             RGBColor[
             0.8763898892162449, 0.41965537165696043`, 0.32487331802642816`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 201}], {
             RGBColor[
             0.8612272549405598, 0.40992383458465387`, 0.4331919313429953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 217}], {
             RGBColor[
             0.8759025294365022, 0.41861295836772294`, 0.2718272136373503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 223}], {
             RGBColor[
             0.854846716521594, 0.34268213742931986`, 0.19696394267101408`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 230}], {
             RGBColor[
             0.8174587722148511, 0.13520135049192075`, 0.16435184603079156`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 242}], {
             RGBColor[
             0.8289704754072247, 0.2236853456890081, 0.17537546600841764`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 244}], {
             RGBColor[
             0.8631344742904997, 0.41134623565305395`, 0.42996350646602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 245}], {
             RGBColor[
             0.8178226851727047, 0.13799854495365815`, 0.16470032949021304`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 328}], {
             RGBColor[
             0.8347229187599272, 0.2562351535933635, 0.18042720125236386`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 357}], {
             RGBColor[
             0.8305794964059033, 0.23605298616234965`, 0.17691626633388163`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 364}], {
             RGBColor[
             0.8174383734159, 0.1350445563843714, 0.16433231211787877`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 385}], {
             RGBColor[
             0.8763544393929654, 0.4195795480694926, 0.3210148235334077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 105}], {
             RGBColor[
             0.19823757833601402`, 0.32569064219253296`, 0.9346007088687955]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 128}], {
             RGBColor[
             0.19080558249119994`, 0.3178791433438807, 0.9341774677000858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 159}], {
             RGBColor[
             0.18375580691440718`, 0.3104693822310835, 0.9337759934101959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 171}], {
             RGBColor[
             0.18798107467478986`, 0.3149104065446947, 0.9340166161584262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 215}], {
             RGBColor[
             0.18499791179933114`, 0.3117749132191369, 0.9338467294458628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 218}], {
             RGBColor[
             0.188929981383257, 0.31590776765945394`, 0.9340706549916917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 342}], {
             RGBColor[
             0.18535691671142462`, 0.3121522501439733, 0.9338671742445064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 349}], {
             RGBColor[
             0.19449252215171758`, 0.32175435069256086`, 0.9343874334594139]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 353}], {
             RGBColor[
             0.1885101327336185, 0.315466480108742, 0.9340467452322052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 32}], {
             RGBColor[
             0.8663695731727464, 0.3973837278620414, 0.20771263676639312`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 73}], {
             RGBColor[
             0.8575639301123329, 0.3626830829105343, 0.19952958324085807`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 74}], {
             RGBColor[
             0.8350455081805084, 0.40635801294005464`, 0.44078657419667344`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 78}], {
             RGBColor[
             0.8206713505927768, 0.15989463566547976`, 0.1674282147135816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 104}], {
             RGBColor[
             0.8203618654395438, 0.15751579716047157`, 0.16713185138133213`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 112}], {
             RGBColor[
             0.8597281148751953, 0.37126335432346336`, 0.20127093710100263`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 141}], {
             RGBColor[
             0.8358913359864371, 0.269340328379047, 0.18170757254943665`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 172}], {
             RGBColor[
             0.8219598998063007, 0.16979898956648984`, 0.1686621308956602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 208}], {
             RGBColor[
             0.8783639162366949, 0.43893633864321185`, 0.3669925272239519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 225}], {
             RGBColor[
             0.84226224924205, 0.4121124463693103, 0.4414749134015841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 240}], {
             RGBColor[
             0.824588465564483, 0.19000329782873795`, 0.17117924843423588`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 243}], {
             RGBColor[
             0.8705342231838472, 0.43407421080067554`, 0.42400915684212137`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 285}], {
             RGBColor[
             0.8787585038612737, 0.43847667310735655`, 0.31517946631969995`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 337}], {
             RGBColor[
             0.8787077642296014, 0.4383681461657731, 0.30965677054087426`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 357}], {
             RGBColor[
             0.8330589874809773, 0.2551114410852856, 0.1792906297875571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 399}], {
             RGBColor[
             0.8562175118599777, 0.35734498320723135`, 0.1984462235105148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 36}], {
             RGBColor[
             0.19993330434376533`, 0.3274729577419183, 0.9346972779563351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 151}], {
             RGBColor[
             0.19950401467485102`, 0.3270217470813523, 0.9346728305447676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 168}], {
             RGBColor[
             0.19559687276408316`, 0.32291509320603007`, 0.9344503245930478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 265}], {
             RGBColor[
             0.1984857219314811, 0.32595145684458154`, 0.9346148402794617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 267}], {
             RGBColor[
             0.23148773999796957`, 0.36063867028126045`, 0.9364942563862377]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 282}], {
             RGBColor[
             0.2370656602671769, 0.3665014181447689, 0.9368119106937756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 291}], {
             RGBColor[
             0.1970819328198578, 0.3244759854828951, 0.9345348965662746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 304}], {
             RGBColor[
             0.1939396212205168, 0.3211732167579251, 0.9343559465693256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 378}], {
             RGBColor[
             0.19890365407675165`, 0.32639073002768937`, 0.9346386408968597]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 383}], {
             RGBColor[
             0.20767130167756592`, 0.3356060835571104, 0.9351379454571538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.19127206346984504`, 0.31836944442903903`, 0.934204033101723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 87}], {
             RGBColor[
             0.18980864714848175`, 0.31683130108933233`, 0.9341206937071518]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 119}], {
             RGBColor[
             0.18192714786076558`, 0.30854734562202557`, 0.9336718539823496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 127}], {
             RGBColor[
             0.18812124438286376`, 0.3150577337951532, 0.9340245986159385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 129}], {
             RGBColor[
             0.18526332309430954`, 0.3120538773182072, 0.933861844226471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 231}], {
             RGBColor[
             0.1818156421264654, 0.3084301460254042, 0.9336655038957391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 235}], {
             RGBColor[
             0.18647615617022215`, 0.31332864177904984`, 0.9339309132759184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 317}], {
             RGBColor[
             0.1883961858281423, 0.3153467146864354, 0.9340402561245076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 326}], {
             RGBColor[
             0.18672499245337307`, 0.31359018448977305`, 0.9339450841341236]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 327}], {
             RGBColor[
             0.18852270839333474`, 0.31547969792444663`, 0.934047461397422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 336}], {
             RGBColor[
             0.18089581060751259`, 0.30746334477829806`, 0.9336131208515035]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 396}], {
             RGBColor[
             0.19049809514878532`, 0.31755595465117936`, 0.9341599567508221]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 54}], {
             RGBColor[
             0.1824115228296057, 0.3090564544254234, 0.9336994384202565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 63}], {
             RGBColor[
             0.18069605079375822`, 0.30725338454853857`, 0.9336017448256284]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 224}], {
             RGBColor[
             0.17977250803868983`, 0.30628268255696894`, 0.9335491504319864]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 297}], {
             RGBColor[
             0.19356559882175525`, 0.3207800955024369, 0.9343346465470327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 318}], {
             RGBColor[
             0.18730055861877407`, 0.31419514102261215`, 0.9339778617757692]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 345}], {
             RGBColor[
             0.1795989351746539, 0.30610024647171197`, 0.9335392657141575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 81}], {
             RGBColor[
             0.1880171511030766, 0.3149483251582018, 0.9340186706576468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 106}], {
             RGBColor[
             0.21164758701888683`, 0.33978541156189057`, 0.935364389024955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 164}], {
             RGBColor[
             0.19871454021211585`, 0.32619195936544565`, 0.9346278711420376]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 192}], {
             RGBColor[
             0.18904880805086632`, 0.3160326620211572, 0.9340774219946237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 241}], {
             RGBColor[
             0.22984485211178313`, 0.3589118909477702, 0.9364006963515542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 271}], {
             RGBColor[
             0.18778814176396494`, 0.3147076218227647, 0.9340056289145733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 287}], {
             RGBColor[
             0.19320443776430601`, 0.3204004923321242, 0.9343140789591009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 292}], {
             RGBColor[
             0.19543097961487327`, 0.32274072898797734`, 0.9344408772236172]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 371}], {
             RGBColor[
             0.1915120199175549, 0.31862165386969954`, 0.9342176982664363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 374}], {
             RGBColor[
             0.1933477765192394, 0.32055115045176114`, 0.9343222418891437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 382}], {
             RGBColor[
             0.18918398084593196`, 0.3161747371992214, 0.9340851198853325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 384}], {
             RGBColor[
             0.19301716646589862`, 0.32020365832381187`, 0.9343034141356996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 389}], {
             RGBColor[
             0.19956255990653143`, 0.3270832818318305, 0.9346761646091019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 78}], {
             RGBColor[
             0.8656358011330783, 0.391743634424193, 0.20700997583252984`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 104}], {
             RGBColor[
             0.8650168308266121, 0.38698595741417663`, 0.2064172491680309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 172}], {
             RGBColor[
             0.8682128995601259, 0.4115523422262132, 0.2094778081966871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 194}], {
             RGBColor[
             0.9757819569708761, 0.9287169668940988, 0.4668813870087187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 208}], {
             RGBColor[
             0.97502376088894, 0.929050734989072, 0.526498655624491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 217}], {
             RGBColor[
             0.975050917301262, 0.9271533469602427, 0.3873122304251019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 223}], {
             RGBColor[
             0.9434671979288998, 0.8132571155526379, 0.27501732397559764`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 230}], {
             RGBColor[
             0.8641696265273747, 0.38047397392294696`, 0.2056059653743008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 240}], {
             RGBColor[
             0.8734700310764903, 0.45196095875070935`, 0.21451204327383844`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 242}], {
             RGBColor[
             0.8871930329121218, 0.5574419643171217, 0.22765320532955294`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 357}], {
             RGBColor[
             0.8904110749094791, 0.5821772452638048, 0.2307348059804809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 364}], {
             RGBColor[
             0.8641288289294724, 0.38016038570784827`, 0.2055668975484752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 385}], {
             RGBColor[
             0.9757287822359568, 0.928603231512897, 0.461093645269188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 387}], {
             RGBColor[
             0.7455791435710649, 0.7496942133696903, 0.622023162461701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 92}], {
             RGBColor[
             0.3869660924415177, 0.5054181375626268, 0.9463177797578736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 182}], {
             RGBColor[
             0.3125367270389322, 0.44214783260778046`, 0.9412445628049322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 256}], {
             RGBColor[
             0.3139252578534664, 0.443350508209742, 0.9413330387606047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 281}], {
             RGBColor[
             0.3526148324525338, 0.4768614731328931, 0.9437983042422098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 311}], {
             RGBColor[
             0.28964287283882917`, 0.4217634021453914, 0.9398061051687154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 35}], {
             RGBColor[
             0.24974982719833305`, 0.3798332818120472, 0.9375342552359615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 85}], {
             RGBColor[
             0.25199669770088307`, 0.3821948851700452, 0.9376622111871347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 86}], {
             RGBColor[
             0.3371353879041764, 0.46222487105446, 0.9428569705546225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 91}], {
             RGBColor[
             0.37827297461142906`, 0.4967706349329164, 0.9457781608227135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 93}], {
             RGBColor[
             0.24878417747359188`, 0.37881832272561544`, 0.9374792629126882]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 95}], {
             RGBColor[
             0.41132901778835196`, 0.5236070199417173, 0.9483804536298768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 125}], {
             RGBColor[
             0.2623800078372861, 0.3931084024632914, 0.9382535253386719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 162}], {
             RGBColor[
             0.2677884948207052, 0.39879306520074553`, 0.9385615306712383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 211}], {
             RGBColor[
             0.2425688344221679, 0.3722856031030586, 0.9371253083206856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 214}], {
             RGBColor[
             0.25149658822823806`, 0.38166923840552336`, 0.9376337306925131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 248}], {
             RGBColor[
             0.24062348998029212`, 0.37024092275268566`, 0.9370145238326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 263}], {
             RGBColor[
             0.3276003815122878, 0.45396612776116196`, 0.9422494083788064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 340}], {
             RGBColor[
             0.23309142699709673`, 0.3623242469969716, 0.9365855839883956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 42}], {
             RGBColor[
             0.22638274960055194`, 0.35527300169848874`, 0.9362035347352613]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 85}], {
             RGBColor[
             0.2384984047146932, 0.36800732340035325`, 0.9368935033705061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 86}], {
             RGBColor[
             0.32363709491798653`, 0.44803730928476804`, 0.942088262737994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 93}], {
             RGBColor[
             0.235285884487402, 0.3646307609559235, 0.9367105550960597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 97}], {
             RGBColor[
             0.21457055736469166`, 0.3428576387223553, 0.9355308478620015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 98}], {
             RGBColor[
             0.21863346925867172`, 0.3471280167264209, 0.9357622246838242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 125}], {
             RGBColor[
             0.24888171485109623`, 0.37892084069359944`, 0.9374848175220434]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 162}], {
             RGBColor[
             0.25429020183451534`, 0.3846055034310536, 0.9377928228546097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 211}], {
             RGBColor[
             0.22907054143597805`, 0.35809804133336665`, 0.9363566005040571]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 214}], {
             RGBColor[
             0.23799829524204824`, 0.3674816766358314, 0.9368650228758846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 248}], {
             RGBColor[
             0.22712519699410227`, 0.3560533609829937, 0.9362458160159715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 263}], {
             RGBColor[
             0.31410208852609794`, 0.43977856599147, 0.9414807005621779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 340}], {
             RGBColor[
             0.21959313401090685`, 0.34813668522727964`, 0.9358168761717671]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 80}], {
             RGBColor[
             0.1863429465695527, 0.31318863004276976`, 0.9339233271862263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 151}], {
             RGBColor[
             0.19244860485001886`, 0.3196060640166337, 0.9342710353927868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 168}], {
             RGBColor[
             0.18854146293925098`, 0.3154994101413115, 0.9340485294410671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 265}], {
             RGBColor[
             0.1914303121066489, 0.318535773779863, 0.934213045127481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 277}], {
             RGBColor[
             0.20034660319217895`, 0.3279073610362615, 0.9347208147143313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 304}], {
             RGBColor[
             0.18688421139568462`, 0.3137575336932065, 0.933954151417345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 378}], {
             RGBColor[
             0.1918482442519195, 0.31897504696297085`, 0.934236845744879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 383}], {
             RGBColor[
             0.20061589185273376`, 0.3281904004923918, 0.9347361503051731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 41}], {
             RGBColor[
             0.6103348144421008, 0.6886019294831773, 0.9655435733376975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 114}], {
             RGBColor[
             0.2950446149939596, 0.4237378370222073, 0.9402493164383834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 170}], {
             RGBColor[
             0.29023151793817503`, 0.41867896684859873`, 0.9399752176813956]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 187}], {
             RGBColor[
             0.39185947335344506`, 0.5138307132141199, 0.9461899170277228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 206}], {
             RGBColor[
             0.5395559184345032, 0.6328895346269106, 0.9586002858977685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 256}], {
             RGBColor[
             0.3500537032004466, 0.4776206563266962, 0.9435260903209648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 261}], {
             RGBColor[
             0.30438433219243016`, 0.43355447197007246`, 0.940781199515963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 311}], {
             RGBColor[
             0.3257713181858094, 0.4560335502623456, 0.9419991567290754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 361}], {
             RGBColor[
             0.28321730845770904`, 0.41130658795806163`, 0.939575768828076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 53}], {
             RGBColor[
             0.2076634431002256, 0.3355978236940631, 0.9351374979228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 58}], {
             RGBColor[
             0.2174442667054725, 0.3458780894432118, 0.935694501357687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 102}], {
             RGBColor[
             0.25020060979959846`, 0.3803070829072448, 0.9375599266382304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 103}], {
             RGBColor[
             0.20863860950919683`, 0.3366227854190133, 0.9351930322071614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 117}], {
             RGBColor[
             0.22453541604736282`, 0.35333133700637476`, 0.9360983318222922]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 145}], {
             RGBColor[
             0.21009367554414693`, 0.338152152078261, 0.9352758960652745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 189}], {
             RGBColor[
             0.24478652953490182`, 0.3746165412765333, 0.9372516027765698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 222}], {
             RGBColor[
             0.22765792346573496`, 0.35661329028148886`, 0.9362761540004327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 254}], {
             RGBColor[
             0.20508861754811766`, 0.3328915187854286, 0.9349908654167205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 303}], {
             RGBColor[
             0.21808265414273661`, 0.3465490751158777, 0.9357308565778295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 376}], {
             RGBColor[
             0.21626586560617583`, 0.3446395151729059, 0.9356273931583702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 150}], {
             RGBColor[
             0.1883607596919023, 0.31530947957110045`, 0.9340382386584571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 237}], {
             RGBColor[
             0.19025421078354665`, 0.3172996167201517, 0.9341460678970164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 251}], {
             RGBColor[
             0.18672478342346222`, 0.3135899647860835, 0.9339450722301794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 283}], {
             RGBColor[
             0.19607798492560893`, 0.3234207725920666, 0.934477723218905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 294}], {
             RGBColor[
             0.18656769797512113`, 0.31342485802008435`, 0.9339361264462835]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 320}], {
             RGBColor[
             0.18948414481075992`, 0.3164902285577502, 0.9341022137790767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 347}], {
             RGBColor[
             0.19051344323313968`, 0.3175720864609606, 0.9341608308015206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 381}], {
             RGBColor[
             0.18966952552711056`, 0.31668507544445096`, 0.9341127709366266]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 51}], {
             RGBColor[
             0.4513189432678153, 0.5634921655168925, 0.9504868403154272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 84}], {
             RGBColor[
             0.42994887224450423`, 0.5449824840875006, 0.9491251582866337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 102}], {
             RGBColor[
             0.39926565859510593`, 0.5155146756656562, 0.9472759248895897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 134}], {
             RGBColor[
             0.6760140538149009, 0.745057217744171, 0.9695892868351288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 163}], {
             RGBColor[
             0.3939273213258807, 0.5099037447255685, 0.9469719144794696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 167}], {
             RGBColor[
             0.4156571514498516, 0.5326037138579458, 0.948214502475271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 174}], {
             RGBColor[
             0.4325281900725898, 0.5472165595499049, 0.9492895101378381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 183}], {
             RGBColor[
             0.43552341404886974`, 0.5498108720138242, 0.9494803631610341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 189}], {
             RGBColor[
             0.3938515783304093, 0.5098241340349448, 0.9469676010279292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 226}], {
             RGBColor[
             0.48315013418370223`, 0.5910627432060597, 0.9525150956533707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 234}], {
             RGBColor[
             0.653391331063141, 0.7272953937118065, 0.9673580250213626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 246}], {
             RGBColor[
             0.7206526383610699, 0.7806508133791874, 0.9738469548784772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 269}], {
             RGBColor[
             0.6323207129287618, 0.7108348666826005, 0.9652579027218493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 272}], {
             RGBColor[
             0.6309966022057711, 0.7098004613221861, 0.9651259277394999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 350}], {
             RGBColor[
             0.7574551958384235, 0.806891984810095, 0.8535080309341501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 355}], {
             RGBColor[
             0.6433835290110301, 0.7194772226865849, 0.9663605408410356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 392}], {
             RGBColor[
             0.7560719179586157, 0.8063199638581745, 0.8764325252109648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 395}], {
             RGBColor[
             0.494849422028799, 0.60078007937222, 0.9533755056767188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 55}], {
             RGBColor[
             0.9217511656674453, 0.9083191148939446, 0.6659672564832814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 83}], {
             RGBColor[
             0.9084527486796484, 0.9295988421678656, 0.9827837388659694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.684630729662244, 0.7517566465973935, 0.970608286963019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 135}], {
             RGBColor[
             0.9333566323648748, 0.9460233638065111, 0.83381543555314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 156}], {
             RGBColor[
             0.8446142468320946, 0.4596744496768401, 0.44741728123423563`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 165}], {
             RGBColor[
             0.8843102751860701, 0.9105890257431475, 0.9888274975519911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 187}], {
             RGBColor[
             0.6533956652271913, 0.7258990741319324, 0.9682873726725081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 206}], {
             RGBColor[
             0.8010921103082493, 0.8449578955447232, 0.9806977415425538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 245}], {
             RGBColor[
             0.8365103724506917, 0.3973845200409797, 0.4396570019745871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 256}], {
             RGBColor[
             0.6115898950741928, 0.6896890172445088, 0.9656235459657501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 311}], {
             RGBColor[
             0.5873075100595555, 0.6681019111801583, 0.9640966123738608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 328}], {
             RGBColor[
             0.8707008812978143, 0.7005608755905404, 0.6002433163697872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 386}], {
             RGBColor[
             0.8163158098721861, 0.8568507653484726, 0.982215097641526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 400}], {
             RGBColor[
             0.8574093225920176, 0.5580230088055577, 0.4596698602319089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 45}], {
             RGBColor[
             0.2506616815740248, 0.3807916985758058, 0.9375861839936894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 93}], {
             RGBColor[
             0.22541709987581074`, 0.35425804261205696`, 0.936148542411988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 98}], {
             RGBColor[
             0.20876468464708048`, 0.33675529838255447`, 0.9352002119997525]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 125}], {
             RGBColor[
             0.23901293023950498`, 0.3685481223497329, 0.9369228048379719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 139}], {
             RGBColor[
             0.20228682166276132`, 0.3299466536657998, 0.934831307285935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 148}], {
             RGBColor[
             0.27524609124263133`, 0.40429858097089644`, 0.9390716483190401]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 204}], {
             RGBColor[
             0.20507426806755127`, 0.33287643657154375`, 0.9349900482350304]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 248}], {
             RGBColor[
             0.21725641238251098`, 0.34568064263912723`, 0.9356838033318999]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 275}], {
             RGBColor[
             0.2276321474655179, 0.3565861980709679, 0.9362746860953526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 276}], {
             RGBColor[
             0.2196855450649306, 0.3482338151042579, 0.9358221388445839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 288}], {
             RGBColor[
             0.26094257460696524`, 0.39159756899969334`, 0.938171665642697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 290}], {
             RGBColor[
             0.20736560396252507`, 0.33528477587624783`, 0.9351205364245214]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 318}], {
             RGBColor[
             0.2054522043558168, 0.33327367157305554`, 0.9350115711475404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 56}], {
             RGBColor[
             0.3210051071529382, 0.44798658822988663`, 0.9418389411311112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 59}], {
             RGBColor[
             0.3034359716582913, 0.4327690861148492, 0.9407194513531689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[
             0.434369237561579, 0.5419666394359329, 0.9502257108546233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 121}], {
             RGBColor[
             0.28563299292961386`, 0.4173490407437973, 0.9395850612911336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 122}], {
             RGBColor[
             0.42916131354223347`, 0.5377386121027248, 0.9498157239985662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 175}], {
             RGBColor[
             0.2710055822533935, 0.4021744280676252, 0.9387447390412754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 213}], {
             RGBColor[
             0.2414891450614786, 0.3711507811287148, 0.9370638216088516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 227}], {
             RGBColor[
             0.23391469744368304`, 0.36318955643469497`, 0.9366324680224093]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 237}], {
             RGBColor[
             0.22884629711642387`, 0.3578623463356042, 0.9363438301217982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 274}], {
             RGBColor[
             0.3767191464303865, 0.4951636983486218, 0.9456872845015338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 296}], {
             RGBColor[
             0.2526601828418626, 0.38289225012060224`, 0.937699995684375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 308}], {
             RGBColor[
             0.23093015114267265`, 0.3600526090411681, 0.9364625025258073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 373}], {
             RGBColor[
             0.2661054797853324, 0.3970241096892522, 0.9384656854547713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 380}], {
             RGBColor[
             0.2402420225431372, 0.36983997628980336`, 0.9369927998263845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 46}], {
             RGBColor[
             0.2189840028439955, 0.34749644974970917`, 0.9357821870529404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 65}], {
             RGBColor[
             0.2623103948909678, 0.393035234842995, 0.9382495609843622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 68}], {
             RGBColor[
             0.25335041241870687`, 0.38361772516894843`, 0.9377393032376733]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 113}], {
             RGBColor[
             0.27210008577250266`, 0.4033248206617401, 0.9388070693975159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 149}], {
             RGBColor[
             0.22663901581167467`, 0.355542353734595, 0.9362181287168728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 161}], {
             RGBColor[
             0.2180648213930185, 0.34653033176526227`, 0.9357298410291143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 195}], {
             RGBColor[
             0.2192614298530921, 0.3477880431261581, 0.9357979861106919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 247}], {
             RGBColor[
             0.2171512777998561, 0.34557013952683935`, 0.9356778160729503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 249}], {
             RGBColor[
             0.27287548484168234`, 0.4041092659680885, 0.9388523457495259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 250}], {
             RGBColor[
             0.24751102743025372`, 0.3774801613076919, 0.9374067589011768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 266}], {
             RGBColor[
             0.23471345152571355`, 0.36402909761884283`, 0.9366779558857301]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 315}], {
             RGBColor[
             0.22776027402374388`, 0.3567208672073564, 0.9362819827132973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 316}], {
             RGBColor[
             0.23551418105696653`, 0.3648707151253743, 0.9367235562479619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 358}], {
             RGBColor[
             0.21372519899594036`, 0.3419691134779814, 0.9354827059534967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 362}], {
             RGBColor[
             0.21291981933663207`, 0.3411226083920287, 0.9354368407733515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 363}], {
             RGBColor[
             0.22828771928123268`, 0.35727524561493795`, 0.9363120199404259]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 369}], {
             RGBColor[
             0.21363611782330827`, 0.34187548351747254`, 0.9354776329124991]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 372}], {
             RGBColor[
             0.21537145554787535`, 0.3436994334927591, 0.9355764578287111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 66}], {
             RGBColor[
             0.2495400971941441, 0.37961284227999426`, 0.9375223114224907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 91}], {
             RGBColor[
             0.38905361359871204`, 0.5081017700405416, 0.9463921022645131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 123}], {
             RGBColor[
             0.24825361468381962`, 0.37826066759394095`, 0.9374490481467079]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 140}], {
             RGBColor[
             0.25525427585226035`, 0.38561880634952683`, 0.9378477254437005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 148}], {
             RGBColor[
             0.30939380782769543`, 0.44018999619208, 0.9410163102615399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 179}], {
             RGBColor[
             0.3693787364367489, 0.49212881841734446`, 0.9448432238628737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 203}], {
             RGBColor[
             0.2552832201033739, 0.38564922859261863`, 0.9378493737759823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 232}], {
             RGBColor[
             0.28995111396047296`, 0.4220873831078549, 0.9398236590445912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 257}], {
             RGBColor[
             0.30395689687858984`, 0.4354808171950546, 0.9406698751035344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 275}], {
             RGBColor[
             0.261779864050582, 0.3924776132921515, 0.9382193480378523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 276}], {
             RGBColor[
             0.2538332616499947, 0.38412523032544144`, 0.9377668007870836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 279}], {
             RGBColor[
             0.4785218001436983, 0.5802784243797845, 0.9537482634423509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 280}], {
             RGBColor[
             0.26817273037966816`, 0.3991969211351571, 0.9385834123178955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 288}], {
             RGBColor[
             0.29509029119202934`, 0.4274889842208769, 0.9401163275851969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 297}], {
             RGBColor[
             0.2458649611438621, 0.37575004127406386`, 0.9373130178613036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 325}], {
             RGBColor[
             0.2869742607531359, 0.4189585216435491, 0.9396541316582929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 339}], {
             RGBColor[
             0.26817858765203434`, 0.39920307749978645`, 0.9385837458808918]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 149}], {
             RGBColor[
             0.20894845482391827`, 0.3369484524901131, 0.9352106774394597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 153}], {
             RGBColor[
             0.1918690303202028, 0.3189968944386494, 0.9342380294807175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 161}], {
             RGBColor[
             0.20037426040526207`, 0.3279364305207805, 0.9347223897517012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 184}], {
             RGBColor[
             0.19220194755564052`, 0.3193468115612663, 0.9342569886247687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 195}], {
             RGBColor[
             0.2015708688653357, 0.3291941418816762, 0.9347905348332788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 247}], {
             RGBColor[
             0.1994607168120997, 0.32697623828235756`, 0.9346703647955372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 250}], {
             RGBColor[
             0.22982046644249732`, 0.3588862600632101, 0.9363993076237638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 315}], {
             RGBColor[
             0.21006971303598748`, 0.3381269659628746, 0.9352745314358842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 343}], {
             RGBColor[
             0.19165716183089215`, 0.31877420722314587`, 0.9342259638836825]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 356}], {
             RGBColor[
             0.1981426064801053, 0.32559082075040946`, 0.9345953003620997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 358}], {
             RGBColor[
             0.19603463800818394`, 0.3233752122334996, 0.9344752546760837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 362}], {
             RGBColor[
             0.19522925834887567`, 0.3225287071475469, 0.9344293894959386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 363}], {
             RGBColor[
             0.21059715829347625`, 0.33868134437045616`, 0.9353045686630128]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 369}], {
             RGBColor[
             0.19594555683555187`, 0.3232815822729907, 0.934470181635086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 372}], {
             RGBColor[
             0.19768089456011895`, 0.32510553224827726`, 0.934569006551298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.6461513889555156, 0.7219924964871992, 0.9663950668318202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.44142989596913074`, 0.5543010784500094, 0.9500295993461311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 173}], {
             RGBColor[
             0.41329174036295263`, 0.5275007351562074, 0.948325579764125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 201}], {
             RGBColor[
             0.7465737093465549, 0.8011421937069441, 0.9641963866302764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 209}], {
             RGBColor[
             0.43947307837840166`, 0.5526061814054317, 0.9499049126595958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 323}], {
             RGBColor[
             0.4713973595467131, 0.580257389192397, 0.951939099626107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 346}], {
             RGBColor[
             0.44758503753245593`, 0.5596323527057516, 0.9504217995237683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 61}], {
             RGBColor[
             0.22477630942984533`, 0.3535845312248864, 0.9361120503440548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 68}], {
             RGBColor[
             0.2551071510734325, 0.38546416887872903`, 0.937839346905198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 118}], {
             RGBColor[
             0.23953466514577643`, 0.3690964988161278, 0.9369525168690463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 173}], {
             RGBColor[
             0.2613339339978391, 0.3920089125331203, 0.938193952981043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 176}], {
             RGBColor[
             0.2369284794639835, 0.36635723242284735`, 0.9368040984499744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 209}], {
             RGBColor[
             0.2875152720132881, 0.41711435878234465`, 0.9397732858765137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 344}], {
             RGBColor[
             0.21571874970997718`, 0.3440644616768498, 0.9355962357174672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 354}], {
             RGBColor[
             0.22802037271409625`, 0.35699424742212627`, 0.9362967949489314]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 388}], {
             RGBColor[
             0.2298511238520014, 0.358918482944391, 0.9364010535178815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 52}], {
             RGBColor[
             0.1835216269875808, 0.31022324428012404`, 0.9337626572098012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 62}], {
             RGBColor[
             0.19439182652115503`, 0.3216485132003679, 0.9343816989922191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.19292841019979173`, 0.32011036986066127`, 0.934298359597648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 127}], {
             RGBColor[
             0.19124100743417377`, 0.3183368025664821, 0.9342022645064347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[
             0.18838308614561955`, 0.31533294608953616`, 0.9340395101169672]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 133}], {
             RGBColor[
             0.18673252269027052`, 0.31359809924619686`, 0.933945512969975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 199}], {
             RGBColor[
             0.18708382947160418`, 0.313967344947515, 0.93396551937146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 216}], {
             RGBColor[
             0.19369425198474133`, 0.320915318133817, 0.9343419731543394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 231}], {
             RGBColor[
             0.1849354051777754, 0.31170921479673314`, 0.9338431697862355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 235}], {
             RGBColor[
             0.18959591922153213`, 0.31660771055037873`, 0.9341085791664148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 298}], {
             RGBColor[
             0.19233776426424887`, 0.31948956353329044`, 0.9342647231854012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 313}], {
             RGBColor[
             0.20302253470198556`, 0.3307199347169253, 0.9348732050551289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 361}], {
             RGBColor[
             0.2026569249479238, 0.33033565568440915`, 0.9348523841205063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 393}], {
             RGBColor[
             0.1855205539729795, 0.3123242432810691, 0.9338764931444723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 396}], {
             RGBColor[
             0.1936178582000953, 0.3208350234225083, 0.9343376226413184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.18052420551329257`, 0.307072764263149, 0.9335919584911282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 147}], {
             RGBColor[
             0.18125622821196816`, 0.30784216653237684`, 0.9336336461008872]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 164}], {
             RGBColor[
             0.18999442899880858`, 0.3170265695932755, 0.9341312737086882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 271}], {
             RGBColor[
             0.17906803055065768`, 0.3055422320505946, 0.933509031481224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 287}], {
             RGBColor[
             0.18448432655099875`, 0.31123510255995407`, 0.9338174815257515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 371}], {
             RGBColor[
             0.1827919087042476, 0.30945626409752947`, 0.9337211008330868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 391}], {
             RGBColor[
             0.18008156514952903`, 0.3066075211758136, 0.9335667507772396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 84}], {
             RGBColor[
             0.36020789306278994`, 0.48641570522103605`, 0.9441731063199956]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 102}], {
             RGBColor[
             0.32952467941339164`, 0.45694789679919157`, 0.9423238729229517]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 134}], {
             RGBColor[
             0.6062730746331866, 0.6864904388777064, 0.9646372348684907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 163}], {
             RGBColor[
             0.3241863421441664, 0.4513369658591039, 0.9420198625128315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 167}], {
             RGBColor[
             0.3459161722681373, 0.47403693499148125`, 0.9432624505086329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 174}], {
             RGBColor[
             0.3627872108908755, 0.4886497806834403, 0.9443374581712001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 183}], {
             RGBColor[
             0.36578243486715545`, 0.4912440931473596, 0.9445283111943961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 189}], {
             RGBColor[
             0.324110599148695, 0.45125735516848015`, 0.9420155490612911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 222}], {
             RGBColor[
             0.3069819930795281, 0.4332541041734357, 0.9410401002851541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 226}], {
             RGBColor[
             0.41340915500198794`, 0.532495964339595, 0.9475630436867326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 234}], {
             RGBColor[
             0.5836503518814267, 0.668728614845342, 0.9624059730547245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 238}], {
             RGBColor[
             0.3357800727610889, 0.463522711822467, 0.942680108320078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 246}], {
             RGBColor[
             0.6509116591793556, 0.7220840345127228, 0.9688949029118392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 269}], {
             RGBColor[
             0.5625797337470475, 0.652268087816136, 0.9603058507552114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 272}], {
             RGBColor[
             0.5612556230240568, 0.6512336824557214, 0.9601738757728618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 350}], {
             RGBColor[
             0.6877142166567092, 0.7483252059436304, 0.8485559789675121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 355}], {
             RGBColor[
             0.5736425498293158, 0.6609104438201203, 0.9614084888743977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 392}], {
             RGBColor[
             0.6863309387769014, 0.7477531849917098, 0.8714804732443268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 395}], {
             RGBColor[
             0.4251084428470847, 0.5422133005057554, 0.9484234537100807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 89}], {
             RGBColor[
             0.18430520538442102`, 0.31104683485694296`, 0.933807280840301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 128}], {
             RGBColor[
             0.18698858591777334`, 0.3138672379336487, 0.9339600953919696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 133}], {
             RGBColor[
             0.18257629412906723`, 0.3092296395082612, 0.9337088219020035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 199}], {
             RGBColor[
             0.1829276009104009, 0.30959888520957934`, 0.9337288283034887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 299}], {
             RGBColor[
             0.18351379325327066`, 0.3102150105286766, 0.9337622110902213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 342}], {
             RGBColor[
             0.18153992013799802`, 0.30814034473374124`, 0.9336498019363901]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 393}], {
             RGBColor[
             0.18136432541177624`, 0.30795578354313347`, 0.9336398020765009]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 58}], {
             RGBColor[
             0.20217788494718347`, 0.3298321542707407, 0.9348251035011402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 64}], {
             RGBColor[
             0.18652020523185484`, 0.31337494013569756`, 0.9339334218048136]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 117}], {
             RGBColor[
             0.20926903428907379`, 0.33728540183390365`, 0.9352289339657456]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 126}], {
             RGBColor[
             0.1894916420221746, 0.31649810860229766`, 0.9341026407341755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 289}], {
             RGBColor[
             0.18928237138329773`, 0.3162781518923132, 0.9340907230808797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 303}], {
             RGBColor[
             0.20281627238444755`, 0.3305031399434066, 0.9348614587212829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 376}], {
             RGBColor[
             0.20099948384788677`, 0.3285935800004348, 0.9347579953018235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 63}], {
             RGBColor[
             0.18289690010848875`, 0.3095666167202264, 0.9337270799382376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 66}], {
             RGBColor[
             0.19944158418676777`, 0.3269561286800552, 0.9346692752208288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 204}], {
             RGBColor[
             0.18912347164523904`, 0.31611113819278824`, 0.9340816739758684]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 224}], {
             RGBColor[
             0.18197335735342035`, 0.3085959147286568, 0.9336744855445955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 290}], {
             RGBColor[
             0.19141480754021284`, 0.3185194774974923, 0.9342121621653594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 297}], {
             RGBColor[
             0.19576644813648575`, 0.3230933276741248, 0.9344599816596418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 318}], {
             RGBColor[
             0.18950140793350456`, 0.31650837319430003`, 0.9341031968883784]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 345}], {
             RGBColor[
             0.1817997844893844, 0.30841347864339985`, 0.9336646008267666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 92}], {
             RGBColor[
             0.7345108890138425, 0.7594054710903482, 0.6489345144638174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 135}], {
             RGBColor[
             0.9832367917164733, 0.9536721882994657, 0.5121416630539384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 156}], {
             RGBColor[
             0.8778676863998269, 0.46477366600547654`, 0.23296809956810122`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.9341904345376686, 0.918237850236102, 0.6671537250527897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 221}], {
             RGBColor[
             0.9369698505827507, 0.7826274582869746, 0.292244768605455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 245}], {
             RGBColor[
             0.869763812018424, 0.4024837363696161, 0.2252078203084527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 255}], {
             RGBColor[
             0.880784705491405, 0.48719515298926147`, 0.23576144034449814`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 328}], {
             RGBColor[
             0.9205810406494127, 0.7082097000834948, 0.27856954387058575`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 386}], {
             RGBColor[
             0.8661959692237846, 0.8644995898414272, 0.6605413251423246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 400}], {
             RGBColor[
             0.8906627621597499, 0.5631222251341941, 0.24522067856577465`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 59}], {
             RGBColor[
             0.3640812726856617, 0.4897706319686471, 0.9444199146444701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 90}], {
             RGBColor[
             0.4950145385889495, 0.5989681852897308, 0.9539261741459244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 121}], {
             RGBColor[
             0.3462782939569843, 0.4743505865975952, 0.9432855245824346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 122}], {
             RGBColor[
             0.48980661456960395`, 0.5947401579565226, 0.9535161872898672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 137}], {
             RGBColor[
             0.35805694536026106`, 0.48455266243088047`, 0.9440360498343989]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 166}], {
             RGBColor[
             0.6856726502293173, 0.7474973607293266, 0.8829926191709212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 169}], {
             RGBColor[
             0.6387195548301612, 0.7123648726900207, 0.967730862260616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 175}], {
             RGBColor[
             0.331650883280764, 0.45917597392142306`, 0.9424452023325764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 178}], {
             RGBColor[
             0.4116703274319593, 0.5309898792944511, 0.9474522471315552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 213}], {
             RGBColor[
             0.30213444608884904`, 0.4281523269825127, 0.9407642849001527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 274}], {
             RGBColor[
             0.43736444745775693`, 0.5521652442024196, 0.9493877477928349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 278}], {
             RGBColor[
             0.3199081459581343, 0.44683361246279085`, 0.9417764708138758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 296}], {
             RGBColor[
             0.313305483869233, 0.43989379597440015`, 0.9414004589756761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 319}], {
             RGBColor[
             0.4175060909791842, 0.5360433358043497, 0.9478244252272849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 352}], {
             RGBColor[
             0.31062641380180694`, 0.4370779234706822, 0.9412478898986653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 76}], {
             RGBColor[
             0.20578868678679324`, 0.33362733594223004`, 0.9350307333242034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.2782593236768137, 0.4070163756656283, 0.939259698655848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 102}], {
             RGBColor[
             0.24757611002741542`, 0.37754856724378383`, 0.937410465258804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 144}], {
             RGBColor[
             0.20411547873617336`, 0.33186868819351084`, 0.93493544660101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 163}], {
             RGBColor[
             0.24223777275819017`, 0.37193763630369614`, 0.9371064548486839]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 167}], {
             RGBColor[
             0.2639676028821611, 0.3946376054360735, 0.9383490428444853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 174}], {
             RGBColor[
             0.28083864150489934`, 0.40925045112803254`, 0.9394240505070525]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 186}], {
             RGBColor[
             0.21226621689950026`, 0.3404356307898151, 0.9353996190814751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 188}], {
             RGBColor[
             0.20973271485913975`, 0.33777275951208907`, 0.9352553398882568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 189}], {
             RGBColor[
             0.24216202976271878`, 0.3718580256130724, 0.9371021413971435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 222}], {
             RGBColor[
             0.22503342369355192`, 0.35385477461802795`, 0.9361266926210063]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 228}], {
             RGBColor[
             0.21063806848440092`, 0.33872434357497383`, 0.9353068984378649]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 238}], {
             RGBColor[
             0.2538315033751126, 0.3841233822670593, 0.9377667006559303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 333}], {
             RGBColor[
             0.2028967340448986, 0.3305877102501046, 0.9348660408938132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 368}], {
             RGBColor[
             0.20142644533340448`, 0.3290423435926357, 0.9347823101267909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 117}], {
             RGBColor[
             0.2190498578943207, 0.34756566758305235`, 0.9357859374006325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 289}], {
             RGBColor[
             0.19906319498854463`, 0.3265584176414619, 0.9346477265157667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 303}], {
             RGBColor[
             0.21259709598969448`, 0.3407834056925553, 0.9354184621561699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 376}], {
             RGBColor[
             0.2107803074531337, 0.33887384574958357`, 0.9353149987367104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 90}], {
             RGBColor[
             0.47744540309430256`, 0.5837506831746934, 0.9528066843679821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 121}], {
             RGBColor[
             0.3287091584623374, 0.4591330844825578, 0.9421660348044922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 122}], {
             RGBColor[
             0.472237479074957, 0.5795226558414852, 0.9523966975119249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 175}], {
             RGBColor[
             0.314081747786117, 0.4439584718063857, 0.9413257125546342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 178}], {
             RGBColor[
             0.3941011919373124, 0.5157723771794137, 0.9463327573536129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 213}], {
             RGBColor[
             0.2845653105942021, 0.4129348248674753, 0.9396447951222104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 274}], {
             RGBColor[
             0.41979531196311004`, 0.5369477420873823, 0.9482682580148925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 296}], {
             RGBColor[
             0.2957363483745861, 0.42467629385936273`, 0.9402809691977339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 319}], {
             RGBColor[
             0.3999369554845372, 0.5208258336893123, 0.9467049354493426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 373}], {
             RGBColor[
             0.3091816453180559, 0.4388081534280127, 0.9410466589681301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.18336573314646784`, 0.31005938996887394`, 0.9337537792861741]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 101}], {
             RGBColor[
             0.18455258152934814`, 0.31130684286981486`, 0.9338213685457943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.18529719032077357`, 0.3120894739205271, 0.933863772914916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 259}], {
             RGBColor[
             0.18612091931381164`, 0.3129552653196448, 0.9339106830624717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 331}], {
             RGBColor[
             0.19257622837931382`, 0.31974020443772183`, 0.9342783033639781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 335}], {
             RGBColor[
             0.18275395419094043`, 0.3094163714975885, 0.9337189393797027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 394}], {
             RGBColor[
             0.18321858514836378`, 0.3099047280931446, 0.933745399425368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 118}], {
             RGBColor[
             0.22412293343441853`, 0.3528977916272621, 0.9360748415476985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 130}], {
             RGBColor[
             0.19568837198846437`, 0.3230112646922406, 0.9344555353385153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 147}], {
             RGBColor[
             0.19642039468713995`, 0.32378066696146846`, 0.9344972229482744]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 164}], {
             RGBColor[
             0.2051585954739804, 0.3329650700223671, 0.9349948505560753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 173}], {
             RGBColor[
             0.24592220228648118`, 0.3758102053442546, 0.937316277659695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 176}], {
             RGBColor[
             0.2215167477526256, 0.3501585252339816, 0.9359264231286265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 344}], {
             RGBColor[
             0.20030701799861927`, 0.32786575448798405`, 0.9347185603961192]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 354}], {
             RGBColor[
             0.21260864100273835`, 0.3407955402332605, 0.9354191196275834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 371}], {
             RGBColor[
             0.19795607517941943`, 0.3253947645266211, 0.934584677680474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 388}], {
             RGBColor[
             0.2144393921406435, 0.3427197757555252, 0.9355233781965335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 87}], {
             RGBColor[
             0.1996423811721627, 0.3271671790429695, 0.9346807103120945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 119}], {
             RGBColor[
             0.1917608818844465, 0.31888322357566273`, 0.9342318705872924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 127}], {
             RGBColor[
             0.1979549784065447, 0.32539361174879033`, 0.9345846152208812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 129}], {
             RGBColor[
             0.19509705711799047`, 0.3223897552718444, 0.9344218608314138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 216}], {
             RGBColor[
             0.2004082229571123, 0.32797212731612524`, 0.934724323868786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 231}], {
             RGBColor[
             0.19164937615014635`, 0.31876602397904136`, 0.934225520500682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 235}], {
             RGBColor[
             0.1963098901939031, 0.32366451973268695`, 0.9344909298808612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 298}], {
             RGBColor[
             0.19905173523661984`, 0.32654637271559867`, 0.9346470738998478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 313}], {
             RGBColor[
             0.20973650567435648`, 0.3377767438992335, 0.9352555557695754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 317}], {
             RGBColor[
             0.19822991985182326`, 0.32568259264007254`, 0.9346002727294505]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 336}], {
             RGBColor[
             0.19072954463119351`, 0.31779922273193517`, 0.9341731374564464]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 361}], {
             RGBColor[
             0.20937089592029476`, 0.33739246486671737`, 0.9352347348349528]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 393}], {
             RGBColor[
             0.19223452494535048`, 0.31938105246337734`, 0.9342588438589188]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 396}], {
             RGBColor[
             0.20033182917246628`, 0.3278918326048165, 0.934719973355765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 98}], {
             RGBColor[
             0.19109841618892076`, 0.3181869301269141, 0.9341941441459625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 139}], {
             RGBColor[
             0.18462055320460163`, 0.31137828541015944`, 0.9338252394321449]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 204}], {
             RGBColor[
             0.18740799960939158`, 0.3143080683159034, 0.9339839803812403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 224}], {
             RGBColor[
             0.1802578853175729, 0.30679284485177194`, 0.9335767919499673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 290}], {
             RGBColor[
             0.18969933550436535`, 0.3167164076206075, 0.9341144685707314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 318}], {
             RGBColor[
             0.18778593589765713`, 0.3147053033174152, 0.9340055032937504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 345}], {
             RGBColor[
             0.18008431245353695`, 0.306610408766515, 0.9335669072321386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 77}], {
             RGBColor[
             0.18172630335562523`, 0.308336245312846, 0.9336604161849047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 94}], {
             RGBColor[
             0.1809149928406964, 0.30748350652159806`, 0.9336142132513059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 254}], {
             RGBColor[
             0.1839453796797469, 0.3106686352270631, 0.9337867892987342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 289}], {
             RGBColor[
             0.18340551527321602`, 0.3101012035064188, 0.9337560448194401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 68}], {
             RGBColor[
             0.2789862434779228, 0.41056260901775243`, 0.9391992258916821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 173}], {
             RGBColor[
             0.2852130264023293, 0.4171073526721437, 0.9395538319675272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 176}], {
             RGBColor[
             0.26080757186847375`, 0.39145567256187075`, 0.9381639774364586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 250}], {
             RGBColor[
             0.2731468584894696, 0.40442504515649597`, 0.9388666815551856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 363}], {
             RGBColor[
             0.25392355034044856`, 0.38422012946374207`, 0.9377719425944349]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 123}], {
             RGBColor[
             0.21298431371887483`, 0.3411903960769459, 0.9354405136330093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 131}], {
             RGBColor[
             0.2137636212718384, 0.34200949772606326`, 0.9354848940452685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 140}], {
             RGBColor[
             0.21998497488731555`, 0.3485485348325317, 0.9358391909300019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 203}], {
             RGBColor[
             0.2200139191384291, 0.3485789570756236, 0.9358408392622837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 232}], {
             RGBColor[
             0.25468181299552817`, 0.38501711159085983`, 0.9378151245308926]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 257}], {
             RGBColor[
             0.268687595913645, 0.3984105456780595, 0.9386613405898359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 275}], {
             RGBColor[
             0.22651056308563722`, 0.3554073417751564, 0.9362108135241538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 280}], {
             RGBColor[
             0.23290342941472336`, 0.362126649618162, 0.936574877804197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 297}], {
             RGBColor[
             0.21059566017891732`, 0.33867976975706876`, 0.935304483347605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 318}], {
             RGBColor[
             0.20433061997593613`, 0.33209481527724394`, 0.9349476985763416]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 322}], {
             RGBColor[
             0.2070879506142999, 0.33499294460302415`, 0.9351047244770914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 325}], {
             RGBColor[
             0.2517049597881912, 0.3818882501265539, 0.9376455971445944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 339}], {
             RGBColor[
             0.23290928668708955`, 0.3621328059827914, 0.9365752113671932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 113}], {
             RGBColor[
             0.36637406988619037`, 0.4916437040590915, 0.9445701410456664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 124}], {
             RGBColor[
             0.3674760832994186, 0.49271104629414053`, 0.9446362289748654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 194}], {
             RGBColor[
             0.709877099853931, 0.7667201163798876, 0.7972498678529694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 208}], {
             RGBColor[
             0.7091189037719949, 0.7670538844748609, 0.8568671364687419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 210}], {
             RGBColor[
             0.365438140563206, 0.4906599829992886, 0.9445168412553058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 249}], {
             RGBColor[
             0.36714946895537004`, 0.49242814936543994`, 0.9446154173976764]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 266}], {
             RGBColor[
             0.3289874356394012, 0.4523479810161943, 0.9424410275338806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 293}], {
             RGBColor[
             0.3870584168095417, 0.509672279343909, 0.9458839979501529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 316}], {
             RGBColor[
             0.32978816517065423`, 0.4531895985227258, 0.9424866278961124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 385}], {
             RGBColor[
             0.7098239251190117, 0.7666063809986858, 0.7914621261134387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 387}], {
             RGBColor[
             0.4796742864541198, 0.5876973628554791, 0.9523916433059518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 161}], {
             RGBColor[
             0.23474066997997348`, 0.36405770594001974`, 0.9366795059364341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 173}], {
             RGBColor[
             0.2762530439300684, 0.40768984299809713`, 0.9390435742208383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 176}], {
             RGBColor[
             0.2518475893962128, 0.38203816288782416`, 0.9376537196897696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 250}], {
             RGBColor[
             0.2641868760172087, 0.3950075354824494, 0.9383564238084967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 363}], {
             RGBColor[
             0.24496356786818765`, 0.3748026197896954, 0.9372616848477457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 106}], {
             RGBColor[
             0.23431749208343802`, 0.36361291913973265`, 0.936655406581262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 107}], {
             RGBColor[
             0.2952174792692931, 0.42393616514341426`, 0.9402585516481101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 150}], {
             RGBColor[
             0.217681081623926, 0.3461269969374395, 0.9357079876169566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 212}], {
             RGBColor[
             0.32957634955032006`, 0.4536960916538069, 0.9424478684800611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 270}], {
             RGBColor[
             0.300457761234542, 0.4284750339974831, 0.9405924577811364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 283}], {
             RGBColor[
             0.22539830685763262`, 0.3542382899584056, 0.9361474721774046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 294}], {
             RGBColor[
             0.2158880199071448, 0.3442423753864234, 0.935605875404783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 295}], {
             RGBColor[
             0.3354255676488553, 0.4587623903805083, 0.9428205754850394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 320}], {
             RGBColor[
             0.21880446674278364`, 0.34730774592408925`, 0.9357719627375762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 347}], {
             RGBColor[
             0.21983376516516337`, 0.34838960382729967`, 0.9358305797600202]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 373}], {
             RGBColor[
             0.25683371538447886`, 0.38727889744013877`, 0.937937672188489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 380}], {
             RGBColor[
             0.2309702581422837, 0.36009476404068996`, 0.9364647865601021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 381}], {
             RGBColor[
             0.21898984745913425`, 0.34750259281079, 0.9357825198951262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 390}], {
             RGBColor[
             0.2522635992417797, 0.3824754156120626, 0.9376774108350432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 108}], {
             RGBColor[
             0.2395346657598989, 0.3690964994616095, 0.9369525169040198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 152}], {
             RGBColor[
             0.2398425593336916, 0.3694201151292457, 0.9369700509875596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 154}], {
             RGBColor[
             0.21421417432422896`, 0.3424830575508392, 0.9355105523750686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 180}], {
             RGBColor[
             0.24072957206270523`, 0.3703524217472943, 0.9370205650502591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 198}], {
             RGBColor[
             0.2881120186842996, 0.4160342955793074, 0.9398697816662858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 236}], {
             RGBColor[
             0.23684558512377027`, 0.36627010521547854`, 0.9367993777399305]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 262}], {
             RGBColor[
             0.2185336488556363, 0.3470230991538516, 0.9357565400595423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 267}], {
             RGBColor[
             0.23945129119348169`, 0.3690088675060522, 0.9369477688458039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 284}], {
             RGBColor[
             0.24975725951810934`, 0.3798410936513683, 0.9375346784955776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 286}], {
             RGBColor[
             0.20888058953085603`, 0.33687712176419665`, 0.9352068126114177]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 332}], {
             RGBColor[
             0.22563024765380635`, 0.35448207444108004`, 0.936160680862621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 72}], {
             RGBColor[
             0.18087056047954858`, 0.30743680529285733`, 0.9336116828940703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 88}], {
             RGBColor[
             0.1851982028892632, 0.3119854318538441, 0.9338581357271303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 138}], {
             RGBColor[
             0.18058969715831197`, 0.30714160013447456`, 0.9335956881434259]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 157}], {
             RGBColor[
             0.18316059011768585`, 0.3098437716388048, 0.933742096694167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 365}], {
             RGBColor[
             0.17992874679989868`, 0.30644689940110903`, 0.9335580479983027]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 88}], {
             RGBColor[
             0.18714176336881175`, 0.31402823714670136`, 0.9339688186212005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 109}], {
             RGBColor[
             0.18206833162796426`, 0.3086957387129193, 0.933679894189029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 157}], {
             RGBColor[
             0.1851041505972344, 0.3118865769316621, 0.9338527795882372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 181}], {
             RGBColor[
             0.1888688995598306, 0.3158435667902215, 0.9340671764722099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 191}], {
             RGBColor[
             0.19501894918374685`, 0.32230765888062524`, 0.934417412700109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 365}], {
             RGBColor[
             0.18187230727944725`, 0.30848970469396636`, 0.9336687308923729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 370}], {
             RGBColor[
             0.18495091945082137`, 0.31172552128136616`, 0.9338440533011341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 78}], {
             RGBColor[
             0.8568301580726646, 0.357042989472686, 0.19882692230699478`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 99}], {
             RGBColor[
             0.9481261161147958, 0.8682562660194123, 0.6030407890629428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 104}], {
             RGBColor[
             0.8562111877661985, 0.35228531246266953`, 0.19823419564249584`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 112}], {
             RGBColor[
             0.9338615942560703, 0.7754902910821886, 0.2656416901517646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 141}], {
             RGBColor[
             0.887270128859985, 0.5759343748998204, 0.22738563797870492`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 172}], {
             RGBColor[
             0.8594072564997123, 0.3768516972747061, 0.20129475467115204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 177}], {
             RGBColor[
             0.912733918365472, 0.8408075046276462, 0.6264313427993702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 208}], {
             RGBColor[
             0.9618152962983195, 0.8769997675618114, 0.5142240753361885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 225}], {
             RGBColor[
             0.9076627958063523, 0.836763929150959, 0.6259476546026368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 240}], {
             RGBColor[
             0.8646643880160767, 0.41726031379920236`, 0.20632898974830338`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 243}], {
             RGBColor[
             0.9500707567190481, 0.8697065757980069, 0.5997490197634427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 285}], {
             RGBColor[
             0.9624071777351879, 0.8763102692580285, 0.43650448397981056`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 337}], {
             RGBColor[
             0.9623310682876794, 0.8761474788456531, 0.428220440311572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 399}], {
             RGBColor[
             0.9285956897332439, 0.7546127344078406, 0.2614046197660328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 86}], {
             RGBColor[
             0.6370413534700665, 0.7120367862892685, 0.9671058051428245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 91}], {
             RGBColor[
             0.6781789401773193, 0.7465825501677249, 0.9700269954109155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 95}], {
             RGBColor[
             0.7112349833542422, 0.7734189351765257, 0.9726292882180788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 104}], {
             RGBColor[
             0.833692765834374, 0.39596024249218986`, 0.4394911865983113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 112}], {
             RGBColor[
             0.9000839613583336, 0.841002686126469, 0.6275271765854877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 141}], {
             RGBColor[
             0.8647517069281606, 0.6196093049293407, 0.46864262893452036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 148}], {
             RGBColor[
             0.5985191344063026, 0.6786707763192633, 0.9646512034079422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 172}], {
             RGBColor[
             0.8368888345678879, 0.4205266273042264, 0.4425517456269674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 179}], {
             RGBColor[
             0.6585040630153561, 0.7306095985445278, 0.968478117009276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 240}], {
             RGBColor[
             0.8421459660842523, 0.4609352438287227, 0.4475859807041188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 263}], {
             RGBColor[
             0.627506347078178, 0.7037780429959705, 0.9664982429670084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 279}], {
             RGBColor[
             0.7676471267223055, 0.8187592045069678, 0.9773831565887533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 285}], {
             RGBColor[
             0.9286295448374513, 0.9418226643023089, 0.7983899704135337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 399}], {
             RGBColor[
             0.8948180568355072, 0.820125129452121, 0.6232901061997559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 105}], {
             RGBColor[
             0.21372122175088312`, 0.34196493314125437`, 0.9354824794552745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 132}], {
             RGBColor[
             0.28812004710636396`, 0.4155836677571048, 0.9398870475355221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 202}], {
             RGBColor[
             0.23066301686818202`, 0.3597718339813871, 0.9364472896240648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 215}], {
             RGBColor[
             0.20048155521420025`, 0.3280492041678583, 0.9347285000323418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 218}], {
             RGBColor[
             0.20441362479812614`, 0.3321820586081753, 0.9349524255781707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 229}], {
             RGBColor[
             0.21242485108253378`, 0.34060236537417143`, 0.9354086530635206]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 260}], {
             RGBColor[
             0.22127423884363956`, 0.34990363299468435`, 0.9359126126050195]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 329}], {
             RGBColor[
             0.20420501368883298`, 0.3319627951056, 0.934940545484109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 341}], {
             RGBColor[
             0.2771008643732843, 0.406039405513939, 0.9391849149556509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 349}], {
             RGBColor[
             0.2099761655665867, 0.3380286416412822, 0.935269204045893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 77}], {
             RGBColor[
             0.1883529029244576, 0.3153012216103682, 0.9340377912271741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 103}], {
             RGBColor[
             0.19412197120965846`, 0.32136487815817005`, 0.9343663311314445]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 144}], {
             RGBColor[
             0.19222334020881804`, 0.31936929659612845`, 0.9342582069047196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 145}], {
             RGBColor[
             0.19557703724460856`, 0.3228942448174177, 0.9344491949895577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 200}], {
             RGBColor[
             0.1890554468047247, 0.31603963977238364`, 0.9340778000618348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 207}], {
             RGBColor[
             0.1908268877624048, 0.3179015365347492, 0.9341786810037627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 222}], {
             RGBColor[
             0.21314128516619657`, 0.3413553830206456, 0.9354494529247159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 333}], {
             RGBColor[
             0.19100459551754329`, 0.3180883186527222, 0.9341888011975227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 368}], {
             RGBColor[
             0.18953430680604916`, 0.3165429519952533, 0.9341050704305003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 94}], {
             RGBColor[
             0.18199794707454847`, 0.3086217600846408, 0.9336758858928365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 103}], {
             RGBColor[
             0.18857832587467818`, 0.31553815542369057`, 0.9340506287307058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 145}], {
             RGBColor[
             0.19003339190962826`, 0.3170675220829382, 0.934133492588819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 200}], {
             RGBColor[
             0.1835118014697444, 0.3102129170379042, 0.9337620976610961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 207}], {
             RGBColor[
             0.18528324242742453`, 0.31207481380026975`, 0.9338629786030239]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 254}], {
             RGBColor[
             0.18502833391359902`, 0.3118068887901059, 0.9338484619402648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 333}], {
             RGBColor[
             0.18546095018256298`, 0.31226159591824276`, 0.9338730987967839]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 104}], {
             RGBColor[
             0.8196280933998756, 0.15187570372262318`, 0.16642919044746882`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 172}], {
             RGBColor[
             0.8212261277666325, 0.16415889612864146`, 0.16795946996179692`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 194}], {
             RGBColor[
             0.8781356082516507, 0.43307373314204806`, 0.32654502054624035`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 208}], {
             RGBColor[
             0.8776301441970267, 0.43329624520536353`, 0.36628986629008864`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 217}], {
             RGBColor[
             0.8776482484719079, 0.43203131985281057`, 0.2734989161571625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 230}], {
             RGBColor[
             0.8192044912502568, 0.14861971197700838`, 0.16602354855060375`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 233}], {
             RGBColor[
             0.8664271702758672, 0.42591833001448076`, 0.4290165805257541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 240}], {
             RGBColor[
             0.8238546935248147, 0.18436320439088957`, 0.1704765875003726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 242}], {
             RGBColor[
             0.8307161944426305, 0.2371037071740957, 0.17704716852822983`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 244}], {
             RGBColor[
             0.8648801933259055, 0.4247645971381416, 0.4316352089858322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 264}], {
             RGBColor[
             0.7877222743756765, 0.3640897660872551, 0.4355019064498754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 285}], {
             RGBColor[
             0.8780247318216056, 0.4328365796695082, 0.31447680538583667`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 357}], {
             RGBColor[
             0.8323252154413091, 0.24947134764743728`, 0.17858796885369382`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 385}], {
             RGBColor[
             0.8781001584283712, 0.43299790955458023`, 0.3226865260532199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 100}], {
             RGBColor[
             0.22059571881103596`, 0.3491904654197632, 0.9358739718929432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 137}], {
             RGBColor[
             0.2827537056275888, 0.4121446936308188, 0.939500838618308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 175}], {
             RGBColor[
             0.2563476435480917, 0.3867680051213614, 0.9379099911164857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 213}], {
             RGBColor[
             0.22683120635617676`, 0.355744358182451, 0.9362290736840618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 227}], {
             RGBColor[
             0.21925675873838124`, 0.34778313348843115`, 0.9357977200976195]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[
             0.21942962029019444`, 0.3479648219394422, 0.9358075643072694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 278}], {
             RGBColor[
             0.24460490622546205`, 0.37442564366272924`, 0.937241259597785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 302}], {
             RGBColor[
             0.21120952198211004`, 0.3393249774333106, 0.9353394418691697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 314}], {
             RGBColor[
             0.23185910927542647`, 0.36102900293803986`, 0.9365154053171973]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 352}], {
             RGBColor[
             0.23532317406913467`, 0.3646699546706205, 0.9367126786825744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 379}], {
             RGBColor[
             0.21907288200889707`, 0.34758986738728526`, 0.9357872485898966]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 151}], {
             RGBColor[
             0.18591365690063838`, 0.3127374193822037, 0.9338988797746588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 168}], {
             RGBColor[
             0.18200651498987047`, 0.3086307655068815, 0.933676373822939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 265}], {
             RGBColor[
             0.18489536415726843`, 0.31166712914543293`, 0.933840889509353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 304}], {
             RGBColor[
             0.18034926344630414`, 0.30688888905877654`, 0.9335819957992169]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 378}], {
             RGBColor[
             0.18531329630253898`, 0.3121064023285408, 0.9338646901267509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 192}], {
             RGBColor[
             0.1805894919591846, 0.3071413844571813, 0.9335956764576392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 271}], {
             RGBColor[
             0.1793288256722832, 0.3058163442587888, 0.9335238833775887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 287}], {
             RGBColor[
             0.1847451216726243, 0.31150921476814825`, 0.9338323334221164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 292}], {
             RGBColor[
             0.18697166352319156`, 0.31384945142400145`, 0.9339591316866327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 374}], {
             RGBColor[
             0.1848884604275577, 0.3116598728877852, 0.9338404963521592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 382}], {
             RGBColor[
             0.18072466475425025`, 0.3072834596352455, 0.9336033743483478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 384}], {
             RGBColor[
             0.18455785037421688`, 0.3113123807598359, 0.9338216685987151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 101}], {
             RGBColor[
             0.181913405203708, 0.30853290121812327`, 0.9336710713583607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 136}], {
             RGBColor[
             0.18265801399513343`, 0.30931553226883557`, 0.9337134757274823]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 259}], {
             RGBColor[
             0.1834817429881715, 0.31018132366795326`, 0.9337603858750381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 331}], {
             RGBColor[
             0.18993705205367367`, 0.31696626278603024`, 0.9341280061765445]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 335}], {
             RGBColor[
             0.18011477786530028`, 0.30664242984589696`, 0.933568642192269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 120}], {
             RGBColor[
             0.7316668327109251, 0.7891725193318362, 0.9665740024152043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 187}], {
             RGBColor[
             0.6899774075909928, 0.7548276258988081, 0.9634300825559947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 206}], {
             RGBColor[
             0.8376738526720509, 0.8738864473115988, 0.9758404514260404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 217}], {
             RGBColor[
             0.9690520396764782, 0.9730561345189551, 0.7324860448307533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 220}], {
             RGBColor[
             0.790428504618827, 0.8368778917698232, 0.9711999364788909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 230}], {
             RGBColor[
             0.8601703747775189, 0.411075832295422, 0.43572184164473515`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 244}], {
             RGBColor[
             0.9498999569574745, 0.9621560504469515, 0.9696904840737579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 245}], {
             RGBColor[
             0.860898200693226, 0.41667022121889674`, 0.43641880856357806`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 321}], {
             RGBColor[
             0.7496980165524652, 0.8038110466699736, 0.967993483257613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 328}], {
             RGBColor[
             0.9072826236616158, 0.729489427357416, 0.5953860262532737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 364}], {
             RGBColor[
             0.8601295771796166, 0.41076224408032325`, 0.4356827738189095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 102}], {
             RGBColor[
             0.3081546083900806, 0.43843821536979977`, 0.9409621908941581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 163}], {
             RGBColor[
             0.3028162711208553, 0.4328272844297121, 0.940658180484038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 167}], {
             RGBColor[
             0.32454610124482625`, 0.4555272535620894, 0.9419007684798394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 174}], {
             RGBColor[
             0.3414171398675645, 0.4701400992540484, 0.9429757761424066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 183}], {
             RGBColor[
             0.3444123638438444, 0.47273441171796776`, 0.9431666291656026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 189}], {
             RGBColor[
             0.30274052812538393`, 0.4327476737390883, 0.9406538670324976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 222}], {
             RGBColor[
             0.2856119220562171, 0.4147444227440439, 0.9396784182563604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 226}], {
             RGBColor[
             0.39203908397867687`, 0.5139862829102032, 0.9462013616579391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 234}], {
             RGBColor[
             0.5622802808581155, 0.6502189334159502, 0.961044291025931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 238}], {
             RGBColor[
             0.3144100017377778, 0.44501303039307516`, 0.9413184262912844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 246}], {
             RGBColor[
             0.6295415881560444, 0.703574353083331, 0.9675332208830456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 269}], {
             RGBColor[
             0.5412096627237364, 0.6337584063867442, 0.9589441687264177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 272}], {
             RGBColor[
             0.5398855520007457, 0.6327240010263296, 0.9588121937440683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 395}], {
             RGBColor[
             0.4037383718237736, 0.5237036190763635, 0.9470617716812872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 88}], {
             RGBColor[
             0.21610734049788477`, 0.34447289523301966`, 0.9356183653879699]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 162}], {
             RGBColor[
             0.2565370723370653, 0.38696710678905155`, 0.9379207788057828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 181}], {
             RGBColor[
             0.2178344766889036, 0.34628822487653976`, 0.9357167232389794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 191}], {
             RGBColor[
             0.22398452631281984`, 0.35275231696694354`, 0.9360669594668783]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 211}], {
             RGBColor[
             0.231317411938528, 0.36045964469136466`, 0.9364845564552302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 214}], {
             RGBColor[
             0.2402451657445982, 0.3698432799938294, 0.9369929788270578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 263}], {
             RGBColor[
             0.31634895902864796`, 0.44214016934946804`, 0.941608656513351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 307}], {
             RGBColor[
             0.294549891018896, 0.4232589122924366, 0.9402196391759287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 312}], {
             RGBColor[
             0.27182714160879756`, 0.40303793904002655`, 0.9387915256311776]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 340}], {
             RGBColor[
             0.22184000451345684`, 0.35049828858527765`, 0.9359448321229403]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 348}], {
             RGBColor[
             0.28694246093137055`, 0.4166697387111759, 0.9397349004577378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 91}], {
             RGBColor[
             0.45216024233108254`, 0.5649746624056373, 0.950332168324746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 93}], {
             RGBColor[
             0.32267144519324537`, 0.4470223501983363, 0.9420332704147207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 95}], {
             RGBColor[
             0.48521628550800544`, 0.5918110474144382, 0.9529344611319093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 125}], {
             RGBColor[
             0.3362672755569396, 0.46131242993601224`, 0.9428075328407044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 148}], {
             RGBColor[
             0.37250043656006593`, 0.49706288855717573`, 0.9449563763217728]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 162}], {
             RGBColor[
             0.3416757625403587, 0.46699709267346645`, 0.9431155381732708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 179}], {
             RGBColor[
             0.4324853651691194, 0.5490017107824403, 0.9487832899231066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 214}], {
             RGBColor[
             0.32538385594789154`, 0.4498732658782442, 0.9421877381945456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 263}], {
             RGBColor[
             0.4014876492319413, 0.5221701552338829, 0.9468034158808389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 264}], {
             RGBColor[
             0.5671571608223211, 0.6570945561668415, 0.9602327949234224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 285}], {
             RGBColor[
             0.7026108469912147, 0.7602147765402214, 0.7786951433273641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 119}], {
             RGBColor[
             0.19029746556308325`, 0.3173450802359561, 0.9341485311927212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 127}], {
             RGBColor[
             0.19649156208518143`, 0.3238554684090837, 0.93450127582631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 129}], {
             RGBColor[
             0.1936336407966272, 0.32085161193213774`, 0.9343385214368426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 216}], {
             RGBColor[
             0.198944806635749, 0.32643398397641854`, 0.9346409844742148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 231}], {
             RGBColor[
             0.19018595982878306`, 0.3172278806393347, 0.9341421811061108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 235}], {
             RGBColor[
             0.1948464738725398, 0.3221263763929803, 0.9344075904862901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 298}], {
             RGBColor[
             0.19758831891525655`, 0.325008229375892, 0.9345637345052766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 313}], {
             RGBColor[
             0.2082730893529932, 0.33623860055952687`, 0.9351722163750043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 317}], {
             RGBColor[
             0.19676650353045996`, 0.3241444493003659, 0.9345169333348793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 361}], {
             RGBColor[
             0.20790747959893147`, 0.33585432152701067`, 0.9351513954403816]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 393}], {
             RGBColor[
             0.1907711086239872, 0.3178429091236707, 0.9341755044643476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 396}], {
             RGBColor[
             0.198868412851103, 0.3263536892651099, 0.9346366339611938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 109}], {
             RGBColor[
             0.18639597403767888`, 0.31324436527390603`, 0.9339263470220889]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 157}], {
             RGBColor[
             0.189431793006949, 0.31643520349264886`, 0.9340992324212971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 181}], {
             RGBColor[
             0.19319654196954522`, 0.3203921933512083, 0.9343136293052701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 191}], {
             RGBColor[
             0.19934659159346146`, 0.326856285441612, 0.9346638655331689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 365}], {
             RGBColor[
             0.18619994968916187`, 0.3130383312549531, 0.9339151837254329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 370}], {
             RGBColor[
             0.189278561860536, 0.3162741478423529, 0.9340905061341941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 128}], {
             RGBColor[
             0.1919283928758168, 0.31905928824840313`, 0.9342414100904406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 133}], {
             RGBColor[
             0.1875161010871107, 0.31442168982301577`, 0.9339901366004746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 155}], {
             RGBColor[
             0.19816316122321598`, 0.3256124250886648, 0.9345964709243118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 170}], {
             RGBColor[
             0.21045471282523004`, 0.33853162515176505`, 0.9352964566043255]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 171}], {
             RGBColor[
             0.18910388505940673`, 0.3160905514492172, 0.934080558548781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 199}], {
             RGBColor[
             0.18786740786844439`, 0.3147909355243339, 0.9340101430019597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 299}], {
             RGBColor[
             0.18845360021131413`, 0.3154070608434312, 0.9340435257886923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 306}], {
             RGBColor[
             0.1959786892882613, 0.3233164065815071, 0.9344720684792528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 342}], {
             RGBColor[
             0.18647972709604152`, 0.31333239504849575`, 0.9339311166348612]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 353}], {
             RGBColor[
             0.18963294311823536`, 0.31664662501326446`, 0.93411068762256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 121}], {
             RGBColor[
             0.4596424243656251, 0.5683306378036415, 0.9516722943059467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 122}], {
             RGBColor[
             0.6031707449782447, 0.6887202091625689, 0.9619029570133792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.7990367806379581, 0.841477411935373, 0.8913793888944332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 178}], {
             RGBColor[
             0.5250344578406001, 0.6249699305004974, 0.9558390168550672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 190}], {
             RGBColor[
             0.7822989919455827, 0.8299086268722369, 0.9606532016549456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 212}], {
             RGBColor[
             0.5128575453871849, 0.6144229009627645, 0.9550631147611566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 221}], {
             RGBColor[
             0.755343522572024, 0.6711176068414135, 0.6012544985481333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 268}], {
             RGBColor[
             0.6438707815800897, 0.7211954799278018, 0.9654945731092558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 274}], {
             RGBColor[
             0.5507285778663977, 0.6461452954084659, 0.9577745175163469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 295}], {
             RGBColor[
             0.5187067634857201, 0.6194891996894659, 0.9554358217661347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 319}], {
             RGBColor[
             0.530870221387825, 0.6300233870103961, 0.956211194950797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 324}], {
             RGBColor[
             0.6207541500572831, 0.7029952095291041, 0.9632871870713362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 351}], {
             RGBColor[
             0.7590840463718008, 0.8119268218437792, 0.9767853326782896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 373}], {
             RGBColor[
             0.44011491122134366`, 0.5480057067490964, 0.9505529184695845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 95}], {
             RGBColor[
             0.5263538722152581, 0.6263568112928946, 0.9558556514000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 112}], {
             RGBColor[
             0.7152028502193496, 0.6939405622428378, 0.6107535397674092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 125}], {
             RGBColor[
             0.37740486226419223`, 0.49585819381446866`, 0.9457287231087954]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 148}], {
             RGBColor[
             0.4136380232673186, 0.5316086524356322, 0.9478775665898638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 179}], {
             RGBColor[
             0.47362295187637204`, 0.5835474746608966, 0.9517044801911976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 257}], {
             RGBColor[
             0.408201112318213, 0.5268994734386068, 0.9475311314318583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 263}], {
             RGBColor[
             0.44262523593919395`, 0.5567159191123393, 0.94972460614893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 279}], {
             RGBColor[
             0.5827660155833214, 0.6716970806233367, 0.9606095197706748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 285}], {
             RGBColor[
             0.7437484336984672, 0.7947605404186777, 0.7816163335954551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 288}], {
             RGBColor[
             0.3993345066316525, 0.518907640464429, 0.9469775839135208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 135}], {
             RGBColor[
             0.746116355711272, 0.7971097200029147, 0.816782693533676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 165}], {
             RGBColor[
             0.6970699985324673, 0.761675381939551, 0.9717947555325273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 182}], {
             RGBColor[
             0.4229610876060558, 0.5395726978389508, 0.9485023279906137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 256}], {
             RGBColor[
             0.42434961842059, 0.5407753734409124, 0.9485908039462863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 281}], {
             RGBColor[
             0.46303919301965735`, 0.5742863383640635, 0.9510560694278913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 311}], {
             RGBColor[
             0.40006723340595274`, 0.5191882673765618, 0.947063870354397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 386}], {
             RGBColor[
             0.6290755332185833, 0.7079371215448762, 0.9651823556220622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 98}], {
             RGBColor[
             0.21766781953393055`, 0.3461130576399892, 0.9357072323605509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 125}], {
             RGBColor[
             0.24791606512635506`, 0.37790588160716765`, 0.9374298251987702]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 148}], {
             RGBColor[
             0.2841492261294814, 0.41365634022833114`, 0.9395786686798384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 162}], {
             RGBColor[
             0.2533245521097741, 0.3835905443446218, 0.9377378305313364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 214}], {
             RGBColor[
             0.23703264551730702`, 0.36646671754939963`, 0.9368100305526114]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 248}], {
             RGBColor[
             0.22615954726936105`, 0.355038401896562, 0.9361908236926982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 276}], {
             RGBColor[
             0.22858867995178067`, 0.3575915743616926, 0.9363291592053822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 288}], {
             RGBColor[
             0.2698457094938153, 0.4009553282571281, 0.9386786860034955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 290}], {
             RGBColor[
             0.21626873884937514`, 0.3446425351336826, 0.9356275567853198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 103}], {
             RGBColor[
             0.18776701535974932`, 0.31468541663244265`, 0.934004425797107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 145}], {
             RGBColor[
             0.18922208139469943`, 0.31621478329169034`, 0.9340872896552201]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 207}], {
             RGBColor[
             0.18447193191249567`, 0.3112220750090219, 0.933816775669425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 254}], {
             RGBColor[
             0.18421702339867016`, 0.31095414999885795`, 0.9338022590066659]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 125}], {
             RGBColor[
             0.41046090544111513`, 0.5226945788232695, 0.9483310159159588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 162}], {
             RGBColor[
             0.41586939242453425`, 0.5283792415607237, 0.9486390212485251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 233}], {
             RGBColor[
             0.7594081345567827, 0.8112195509449376, 0.9560282891124947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 263}], {
             RGBColor[
             0.47568127911611685`, 0.5835523041211401, 0.9523268989560933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 264}], {
             RGBColor[
             0.6413507907064967, 0.7184767050540989, 0.9657562779986768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 285}], {
             RGBColor[
             0.7768044768753901, 0.8215969254274786, 0.7842186264026185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 312}], {
             RGBColor[
             0.43115946169626646`, 0.5444500738116986, 0.9495097680739197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 173}], {
             RGBColor[
             0.515339475447038, 0.6087263479834802, 0.9574676673643785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 201}], {
             RGBColor[
             0.8486214444306401, 0.8823678065342169, 0.9733384742305298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 209}], {
             RGBColor[
             0.5415208134624869, 0.6338317942327045, 0.9590470002598491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 223}], {
             RGBColor[
             0.8390506368021915, 0.7815052608012159, 0.618996491222558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 245}], {
             RGBColor[
             0.795286411691943, 0.364900459678807, 0.43562237712445073`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 323}], {
             RGBColor[
             0.5734450946307983, 0.6614830020196698, 0.9610811872263605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 109}], {
             RGBColor[
             0.18710606140703578`, 0.3139907121212397, 0.9339667854472937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 181}], {
             RGBColor[
             0.19390662933890207`, 0.32113854019854193`, 0.9343540677304747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 191}], {
             RGBColor[
             0.2000566789628183, 0.32760263228894565`, 0.9347043039583738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 193}], {
             RGBColor[
             0.1899172543843397, 0.31694545418031556`, 0.9341268787285638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 211}], {
             RGBColor[
             0.20738956458852648`, 0.33530996001336677`, 0.9351219009467256]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 214}], {
             RGBColor[
             0.21631731839459667`, 0.3446935953158315, 0.9356303233185532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 248}], {
             RGBColor[
             0.2054442201466507, 0.3332652796629938, 0.9350111164586401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 305}], {
             RGBColor[
             0.18756138502713113`, 0.3144692861151448, 0.9339927154538672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 334}], {
             RGBColor[
             0.1889352663956901, 0.3159133225426103, 0.9340709559653313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 340}], {
             RGBColor[
             0.1979121571634553, 0.3253486039072797, 0.9345821766144358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 360}], {
             RGBColor[
             0.189069412661027, 0.31605431877284385`, 0.9340785953966906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 370}], {
             RGBColor[
             0.18998864922989284`, 0.31702049468968657`, 0.9341309445593988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 125}], {
             RGBColor[
             0.23126364989762477`, 0.3604031373776651, 0.9364814947865346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 139}], {
             RGBColor[
             0.19453754132088114`, 0.32180166869373195`, 0.9343899972344978]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 193}], {
             RGBColor[
             0.1939801662783198, 0.32121583218438116`, 0.9343582555503864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 204}], {
             RGBColor[
             0.19732498772567109`, 0.3247314515994759, 0.9345487381835933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 248}], {
             RGBColor[
             0.2095071320406308, 0.3375356576670594, 0.9352424932804627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 276}], {
             RGBColor[
             0.21193626472305038`, 0.34008883013219005`, 0.9353808287931467]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 290}], {
             RGBColor[
             0.19961632362064485`, 0.32713979090418005`, 0.9346792263730843]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 318}], {
             RGBColor[
             0.1977029240139366, 0.3251286866009877, 0.9345702610961033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 141}], {
             RGBColor[
             0.8989439948619978, 0.6463586296042318, 0.4540597244463016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 169}], {
             RGBColor[
             0.9307128082989145, 0.9468171296861931, 0.9664871194315787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 177}], {
             RGBColor[
             0.9302447173684912, 0.9464438866842635, 0.9664424725007652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 197}], {
             RGBColor[
             0.9649742133445314, 0.9733984061785892, 0.9441737000062027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 225}], {
             RGBColor[
             0.9251735948093716, 0.9424003112075763, 0.9659587843040318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 243}], {
             RGBColor[
             0.9675815557220673, 0.9753429578546242, 0.9397601494648378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 252}], {
             RGBColor[
             0.6676015641481373, 0.7342070299092066, 0.9439106644834332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 300}], {
             RGBColor[
             0.9401681906865148, 0.9543565949425481, 0.9673889822446275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 337}], {
             RGBColor[
             0.9798418672906987, 0.9817838609022704, 0.7682315700129669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 367}], {
             RGBColor[
             0.6703595369678017, 0.7365958473458555, 0.9440864000727226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 398}], {
             RGBColor[
             0.695865579228825, 0.7586878991813948, 0.9457116225314874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 146}], {
             RGBColor[
             0.1981449486568544, 0.3255932825266753, 0.9345954337456006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 175}], {
             RGBColor[
             0.2458994336441635, 0.3757862740575634, 0.9373149810191983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 213}], {
             RGBColor[
             0.21638299645224862`, 0.344762627118653, 0.9356340635867745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 227}], {
             RGBColor[
             0.20880854883445307`, 0.33680140242463313`, 0.9352027100003322]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 278}], {
             RGBColor[
             0.23415669632153385`, 0.3634439125989312, 0.9366462495004977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 302}], {
             RGBColor[
             0.20076131207818187`, 0.3283432463695126, 0.9347444317718824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 314}], {
             RGBColor[
             0.22141089937149833`, 0.35004727187424184`, 0.93592039521991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 352}], {
             RGBColor[
             0.2248749641652065, 0.3536882236068225, 0.936117668585287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 377}], {
             RGBColor[
             0.19744186238260558`, 0.3248542942741953, 0.9345553940224051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 136}], {
             RGBColor[
             0.18384486237801373`, 0.31056298516977654`, 0.9337810649871026]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 301}], {
             RGBColor[
             0.1828984857165501, 0.3095682832948322, 0.9337271702362709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 335}], {
             RGBColor[
             0.18130162624818058`, 0.3078898827468379, 0.9336362314518891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 394}], {
             RGBColor[
             0.18176625720560394`, 0.308378239342394, 0.9336626914975545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 163}], {
             RGBColor[
             0.272133057471457, 0.4033594760078676, 0.938808947086994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 167}], {
             RGBColor[
             0.29386288759542795`, 0.42605944514024496`, 0.9400515350827954]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 174}], {
             RGBColor[
             0.3107339262181662, 0.44067229083220405`, 0.9411265427453626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 189}], {
             RGBColor[
             0.27205731447598563`, 0.4032798653172439, 0.9388046336354536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 222}], {
             RGBColor[
             0.2549287084068188, 0.3852766143221994, 0.9378291848593165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 226}], {
             RGBColor[
             0.3613558703292786, 0.48451847448835883`, 0.9443521282608951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 395}], {
             RGBColor[
             0.3730551581743753, 0.49423581065451916`, 0.9452125382842432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 145}], {
             RGBColor[
             0.1958024601948291, 0.32313117863074003`, 0.9344620324930895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 200}], {
             RGBColor[
             0.18928086975494526`, 0.31627657358570604`, 0.9340906375653665]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 207}], {
             RGBColor[
             0.19105231071262538`, 0.3181384703480716, 0.9341915185072943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 222}], {
             RGBColor[
             0.21336670811641717`, 0.34159231683396796`, 0.9354622904282476]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 254}], {
             RGBColor[
             0.19079740219879987`, 0.3178705453379077, 0.9341770018445352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 333}], {
             RGBColor[
             0.19123001846776383`, 0.3183252524660446, 0.9342016387010543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 112}], {
             RGBColor[
             0.8583753725290609, 0.36086558387559853`, 0.19997554950264038`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 141}], {
             RGBColor[
             0.8345385936403027, 0.25894255793118215`, 0.18041218495107442`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 172}], {
             RGBColor[
             0.8206071574601663, 0.15940121911862504`, 0.16736674329729798`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 208}], {
             RGBColor[
             0.8770111738905605, 0.4285385681953471, 0.3656971396255897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 240}], {
             RGBColor[
             0.8232357232183486, 0.17960552738087315`, 0.16988386083587365`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 242}], {
             RGBColor[
             0.8300972241361643, 0.2323460301640793, 0.17645444186373088`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 243}], {
             RGBColor[
             0.8691814808377128, 0.4236764403528107, 0.42271376924375914`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 285}], {
             RGBColor[
             0.8774057615151394, 0.4280789026594918, 0.3138840787213377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 337}], {
             RGBColor[
             0.877355021883467, 0.4279703757179083, 0.30836138294251203`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 357}], {
             RGBColor[
             0.8317062451348429, 0.24471367063742083`, 0.17799524218919488`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 399}], {
             RGBColor[
             0.8548647695138434, 0.3469472127593665, 0.19715083591215254`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 114}], {
             RGBColor[
             0.22538318625918102`, 0.3542223972507317, 0.9361466110816916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 171}], {
             RGBColor[
             0.19921926143757313`, 0.32672245337457523`, 0.9346566142691592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 202}], {
             RGBColor[
             0.2264175602160962, 0.35530958986254624`, 0.9362055171483188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 218}], {
             RGBColor[
             0.20016816814604027`, 0.3277198144893344, 0.9347106531024247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 229}], {
             RGBColor[
             0.20817939443044792`, 0.33614012125533055`, 0.9351668805877746]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 261}], {
             RGBColor[
             0.23472290345765154`, 0.3640390321985968, 0.9366784941592712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 349}], {
             RGBColor[
             0.20573070891450085`, 0.3335663975224413, 0.935027431570147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 353}], {
             RGBColor[
             0.19974831949640176`, 0.32727852693862247`, 0.9346867433429382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.2877186940288704, 0.4160544664052851, 0.9398315069221266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 150}], {
             RGBColor[
             0.2101822963835033, 0.33824529819931026`, 0.9352809428909732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 158}], {
             RGBColor[
             0.2827874224549232, 0.411783246820848, 0.939517290657987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 241}], {
             RGBColor[
             0.24501597193591163`, 0.37485769978748307`, 0.9372646691818778]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 270}], {
             RGBColor[
             0.2929589759941193, 0.42059333525935383`, 0.9401654130551529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 292}], {
             RGBColor[
             0.21060209943900177`, 0.3386865378276902, 0.9353048500539408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 310}], {
             RGBColor[
             0.2532088981789974, 0.38346898473049273`, 0.9377312442110733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 320}], {
             RGBColor[
             0.21130568150236095`, 0.33942604718596003`, 0.9353449180115927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 347}], {
             RGBColor[
             0.21233497992474068`, 0.3405079050891704, 0.9354035350340366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 374}], {
             RGBColor[
             0.2085188963433679, 0.336496959291474, 0.9351862147194673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 384}], {
             RGBColor[
             0.2081882862900271, 0.33614946716352473`, 0.9351673869660233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 389}], {
             RGBColor[
             0.21473367973065993`, 0.34302909067154336`, 0.9355401374394254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 390}], {
             RGBColor[
             0.24476481400135702`, 0.3745937168739334, 0.9372503661090598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 158}], {
             RGBColor[
             0.34368740964077826`, 0.4721064928245296, 0.9431204357248351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 190}], {
             RGBColor[
             0.6524189980541504, 0.7216233648288316, 0.9512140557147148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 212}], {
             RGBColor[
             0.3829775514957524, 0.5061376389193594, 0.9456239688209257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 241}], {
             RGBColor[
             0.30591595912176667`, 0.43518094579116473`, 0.9408678142487259]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 268}], {
             RGBColor[
             0.5139907876886572, 0.6129102178843966, 0.9560554271690249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 270}], {
             RGBColor[
             0.35385896317997434`, 0.4809165812630355, 0.943768558122001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 295}], {
             RGBColor[
             0.38882676959428764`, 0.5112039376460608, 0.945996675825904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 310}], {
             RGBColor[
             0.3141088853648525, 0.4437922307341744, 0.9413343892779213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 324}], {
             RGBColor[
             0.4908741561658506, 0.5947099474856988, 0.9538480411311054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 346}], {
             RGBColor[
             0.3498425512041035, 0.47743776708027175`, 0.9435126359024721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 351}], {
             RGBColor[
             0.6292040524803684, 0.703641559800374, 0.9673461867380587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 373}], {
             RGBColor[
             0.31023491732991126`, 0.43972044470569116`, 0.9411137725293536]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 390}], {
             RGBColor[
             0.30566480118721207`, 0.43491696287761505`, 0.9408535111759078]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 152}], {
             RGBColor[
             0.2564614085339687, 0.38688757933463486`, 0.9379164698641311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 154}], {
             RGBColor[
             0.23083302352450608`, 0.3599505217562283, 0.9364569712516402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 180}], {
             RGBColor[
             0.25734842126298235`, 0.38781988595268346`, 0.9379669839268308]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 198}], {
             RGBColor[
             0.3047308678845767, 0.4335017597846965, 0.9408162005428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 205}], {
             RGBColor[
             0.3030856171044626, 0.43207672625167026`, 0.9407113666179867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 236}], {
             RGBColor[
             0.2534644343240474, 0.3837375694208677, 0.9377457966165021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 262}], {
             RGBColor[
             0.23515249805591343`, 0.36449056335924074`, 0.936702958936114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 267}], {
             RGBColor[
             0.2560701403937588, 0.38647633171144136`, 0.9378941877223754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 284}], {
             RGBColor[
             0.26637610871838646`, 0.39730855785675745`, 0.9384810973721491]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 286}], {
             RGBColor[
             0.22549943873113315`, 0.3543445859695858, 0.9361532314879892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 332}], {
             RGBColor[
             0.24224909685408347`, 0.3719495386464692, 0.9371070997391926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 367}], {
             RGBColor[
             0.31561783688898226`, 0.44293150514134, 0.9415099085808494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 398}], {
             RGBColor[
             0.34112387915000547`, 0.4650235569768793, 0.9431351310396142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 157}], {
             RGBColor[
             0.18435836126610156`, 0.3111027050588667, 0.9338103079891256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 181}], {
             RGBColor[
             0.18812311022869774`, 0.31505969491742614`, 0.9340247048730984]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 191}], {
             RGBColor[
             0.19427315985261398`, 0.3215237870078299, 0.9343749411009974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 305}], {
             RGBColor[
             0.1817778659169268, 0.3083904408340291, 0.9336633525964908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 334}], {
             RGBColor[
             0.18315174728548578`, 0.30983447726149455`, 0.9337415931079549]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 340}], {
             RGBColor[
             0.19212863805325098`, 0.319269758626164, 0.9342528137570594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 360}], {
             RGBColor[
             0.18328589355082267`, 0.3099754734917281, 0.9337492325393142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 365}], {
             RGBColor[
             0.1811265179483144, 0.30770583282117103`, 0.9336262592932614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 370}], {
             RGBColor[
             0.1842051301196885, 0.31094164940857083`, 0.9338015817020224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 227}], {
             RGBColor[
             0.1954518354139104, 0.3227626497550994, 0.934442064930519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 237}], {
             RGBColor[
             0.19038343508665123`, 0.3174354396560086, 0.9341534270299079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 251}], {
             RGBColor[
             0.18685400772656674`, 0.3137257877219404, 0.9339524313630709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 308}], {
             RGBColor[
             0.1924672891129, 0.3196257023615725, 0.9342720994339171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 375}], {
             RGBColor[
             0.18201536929507323`, 0.30864007194304494`, 0.9336768780625215]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 116}], {
             RGBColor[
             0.1862942905711151, 0.31313748950344333`, 0.9339205562990953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 151}], {
             RGBColor[
             0.1906348725141942, 0.31769971633440997`, 0.9341677460194382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 154}], {
             RGBColor[
             0.19738148096805996`, 0.3247908295791051, 0.934551955390173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 286}], {
             RGBColor[
             0.1920478961746871, 0.3191848937924626, 0.934248215626522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 291}], {
             RGBColor[
             0.18821279065920096`, 0.31515395473595276`, 0.9340298120409453]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 304}], {
             RGBColor[
             0.18507047905985996`, 0.31185118601098283`, 0.9338508620439963]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 383}], {
             RGBColor[
             0.1988021595169091, 0.3262840528101681, 0.9346328609318244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 141}], {
             RGBColor[
             0.8894343136228475, 0.5845146463127493, 0.22912699183884946`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 172}], {
             RGBColor[
             0.8615714412625748, 0.3854319686876351, 0.20303610853129658`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 179}], {
             RGBColor[
             0.6955279730573865, 0.6779676106196408, 0.6092046613657698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 240}], {
             RGBColor[
             0.8668285727789392, 0.4258405852121313, 0.20807034360844792`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 279}], {
             RGBColor[
             0.8046710367643358, 0.7661172165820809, 0.618109700945247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 285}], {
             RGBColor[
             0.9656534548794817, 0.8891806763774219, 0.4391165147700274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 337}], {
             RGBColor[
             0.9655773454319732, 0.8890178859650467, 0.43083247110178885`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 399}], {
             RGBColor[
             0.9318419668775375, 0.7674831415272341, 0.2640166505562497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 124}], {
             RGBColor[
             0.3086276211264817, 0.4416266325643382, 0.9408905883938774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 149}], {
             RGBColor[
             0.26206453775242544`, 0.39277682340214404`, 0.9382355597840353]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 210}], {
             RGBColor[
             0.3065896783902691, 0.43957556926948627`, 0.9407712006743179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 249}], {
             RGBColor[
             0.3083010067824331, 0.4413437356356376, 0.9408697768166884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 266}], {
             RGBColor[
             0.2701389734664643, 0.40126356728639195`, 0.9386953869528927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 293}], {
             RGBColor[
             0.32820995463660485`, 0.4585878656141067, 0.9421383573691648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 315}], {
             RGBColor[
             0.26318579596449465`, 0.3939553368749055, 0.9382994137804598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 316}], {
             RGBColor[
             0.2709397029977173, 0.40210518479292345`, 0.9387409873151243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 387}], {
             RGBColor[
             0.4208258242811829, 0.5366129491256768, 0.9486460027249637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 397}], {
             RGBColor[
             0.2602244815922864, 0.3908428077115391, 0.9381307713078346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 128}], {
             RGBColor[
             0.21795119041436695`, 0.34641089840207934`, 0.9357233699129821]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 155}], {
             RGBColor[
             0.2241859587617661, 0.352964035242341, 0.9360784307468533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 170}], {
             RGBColor[
             0.23647751036378017`, 0.3658832353054412, 0.9367784164268669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 187}], {
             RGBColor[
             0.33810546577905015`, 0.4610349816709624, 0.9429931157731941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 202}], {
             RGBColor[
             0.2423249813764799, 0.37202929809086444`, 0.937111421250482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 261}], {
             RGBColor[
             0.25063032461803525`, 0.380758740426915, 0.9375843982614342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 306}], {
             RGBColor[
             0.2220014868268114, 0.35066801673518333`, 0.9359540283017942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 353}], {
             RGBColor[
             0.2156557406567855, 0.3439982351669406, 0.9355926474451014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 122}], {
             RGBColor[
             0.7757263022490958, 0.5468964399598267, 0.4596563040800477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 166}], {
             RGBColor[
             0.9063036593555713, 0.6487345751416961, 0.4126405920007503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 169}], {
             RGBColor[
             0.875001595756134, 0.6253129164488254, 0.46913275406054683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 197}], {
             RGBColor[
             0.897842532453212, 0.6430337674437561, 0.45425714111029625`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 221}], {
             RGBColor[
             0.8771748206449487, 0.5351613717457232, 0.21922399843655038`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 239}], {
             RGBColor[
             0.8523263340305828, 0.3902002184370166, 0.1972316827098783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 300}], {
             RGBColor[
             0.8813051840145343, 0.6303392266197287, 0.46973399593591275`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 350}], {
             RGBColor[
             0.9076888516719018, 0.6493073877623174, 0.38968437055635197`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 392}], {
             RGBColor[
             0.9067666664186966, 0.6489260404610371, 0.40496736674089506`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 151}], {
             RGBColor[
             0.18767873323802545`, 0.31459262652510106`, 0.9339993982608765]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 154}], {
             RGBColor[
             0.19442534169189124`, 0.3216837397697962, 0.9343836076316113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 265}], {
             RGBColor[
             0.18666044049465552`, 0.3135223362883303, 0.9339414079955707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 291}], {
             RGBColor[
             0.1852566513830322, 0.31204686492664385`, 0.9338614642823836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 304}], {
             RGBColor[
             0.18211433978369124`, 0.30874409620167387`, 0.9336825142854346]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 383}], {
             RGBColor[
             0.19584602024074033`, 0.3231769630008592, 0.9344645131732627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 289}], {
             RGBColor[
             0.20615434433043495`, 0.33401166520462483`, 0.935051556980372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 303}], {
             RGBColor[
             0.21968824533158482`, 0.34823665325571823`, 0.9358222926207751]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 376}], {
             RGBColor[
             0.217871456795024, 0.34632709331274647`, 0.9357188292013159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 158}], {
             RGBColor[
             0.28881871360859035`, 0.41812251622929797`, 0.9398607637666927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 164}], {
             RGBColor[
             0.21991695118991147`, 0.3484770376136085, 0.9358353170810669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 173}], {
             RGBColor[
             0.26068055800241224`, 0.3913221729354959, 0.9381567441846866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 209}], {
             RGBColor[
             0.2868618960178613, 0.41642761918472027`, 0.9397360770801573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 241}], {
             RGBColor[
             0.25104726308957875`, 0.38119696919593304`, 0.9376081422905835]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 323}], {
             RGBColor[
             0.3187861771861727, 0.44407882697168544`, 0.9417702640466686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 346}], {
             RGBColor[
             0.2949738551719156, 0.42345379048504006`, 0.9402529639443298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 354}], {
             RGBColor[
             0.22736699671866945`, 0.3563075078245018, 0.9362595861525749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 388}], {
             RGBColor[
             0.2291977478565746, 0.35823174334676655`, 0.936363844721525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 389}], {
             RGBColor[
             0.22076497088432706`, 0.3493683600799934, 0.9358836105481312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 126}], {
             RGBColor[
             0.1845010944888899, 0.3112527267258263, 0.9338184364350084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 127}], {
             RGBColor[
             0.18861006279746526`, 0.31557151294177693`, 0.9340524361015079]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 129}], {
             RGBColor[
             0.18575214150891103`, 0.312567656464831, 0.9338896817120405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 196}], {
             RGBColor[
             0.18607572050979368`, 0.3129077585108523, 0.9339081090574485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 231}], {
             RGBColor[
             0.18230446054106692`, 0.30894392517202796`, 0.9336933413813087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 235}], {
             RGBColor[
             0.18696497458482364`, 0.31384242092567355`, 0.9339587507614879]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 317}], {
             RGBColor[
             0.1888850042427438, 0.31586049383305914`, 0.9340680936100771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 326}], {
             RGBColor[
             0.18721381086797456`, 0.3141039636363968, 0.933972921619693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 327}], {
             RGBColor[
             0.18901152680793626`, 0.3159934770710704, 0.9340752988829915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 336}], {
             RGBColor[
             0.18138462902211405`, 0.30797712392492177`, 0.9336409583370731]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 396}], {
             RGBColor[
             0.19098691356338682`, 0.3180697337978031, 0.9341877942363916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 132}], {
             RGBColor[
             0.4382862950940797, 0.5522789014915227, 0.9496356996104882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 160}], {
             RGBColor[
             0.48896132780643076`, 0.5959998592268796, 0.9529119733307341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 187}], {
             RGBColor[
             0.47660974925846794`, 0.585472751295903, 0.952077636221743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 202}], {
             RGBColor[
             0.38082926485589774`, 0.49646706771580507`, 0.9461959416990309]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 206}], {
             RGBColor[
             0.624306194339526, 0.7045315727086937, 0.9644880050917888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 217}], {
             RGBColor[
             0.7556843813439534, 0.80370125991605, 0.7211335984965017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 220}], {
             RGBColor[
             0.5770608462863022, 0.6675230171669182, 0.9598474901446392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 233}], {
             RGBColor[
             0.7388527640498924, 0.7945317751585553, 0.9544100950493892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 244}], {
             RGBColor[
             0.7365322986249497, 0.7928011758440465, 0.9583380377395063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 307}], {
             RGBColor[
             0.43332684059947457`, 0.5479832712777266, 0.9493196875555654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 321}], {
             RGBColor[
             0.5363303582199404, 0.6344561720670685, 0.9566410369233613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 341}], {
             RGBColor[
             0.42726711236099996`, 0.542734639248357, 0.9489335670306169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 366}], {
             RGBColor[
             0.4563492884558704, 0.567924158469062, 0.9507866575750236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 122}], {
             RGBColor[
             0.4544345003462795, 0.5641026104704333, 0.9512623074498896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 175}], {
             RGBColor[
             0.29627876905743955`, 0.4285384264353338, 0.9401913224925988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 178}], {
             RGBColor[
             0.376298213208635, 0.5003523318083618, 0.9451983672915776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.26676233186552467`, 0.3975147794964234, 0.938510405060175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 274}], {
             RGBColor[
             0.4019923332344326, 0.5215276967163304, 0.9471338679528571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 296}], {
             RGBColor[
             0.27793336964590865`, 0.4092562484883108, 0.9391465791356984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 319}], {
             RGBColor[
             0.3821339767558598, 0.5054057883182604, 0.9455705453873072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 373}], {
             RGBColor[
             0.2913786665893785, 0.4233881080569608, 0.9399122689060947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 166}], {
             RGBColor[
             0.7938288566186125, 0.8372493846021647, 0.890969402038376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 169}], {
             RGBColor[
             0.7468757612194565, 0.8021168965628588, 0.9757076451280708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 175}], {
             RGBColor[
             0.4398070896700592, 0.5489279977942612, 0.9504219852000314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 178}], {
             RGBColor[
             0.5198265338212547, 0.6207419031672892, 0.9554290299990101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 268}], {
             RGBColor[
             0.638662857560744, 0.7169674525945936, 0.9650845862531987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 274}], {
             RGBColor[
             0.5455206538470523, 0.6419172680752578, 0.9573645306602898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 319}], {
             RGBColor[
             0.5256622973684795, 0.6257953596771879, 0.9558012080947398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 351}], {
             RGBColor[
             0.7538761223524553, 0.8076987945105711, 0.9763753458222324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 131}], {
             RGBColor[
             0.21247713876151392`, 0.34065732304000995`, 0.9354116307694857]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 140}], {
             RGBColor[
             0.21869849237699107`, 0.3471963601464784, 0.9357659276542193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 203}], {
             RGBColor[
             0.21872743662810462`, 0.3472267823895703, 0.935767575986501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 232}], {
             RGBColor[
             0.2533953304852037, 0.3836649369048065, 0.9377418612551098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 275}], {
             RGBColor[
             0.22522408057531274`, 0.3540551670891031, 0.9361375502483711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 280}], {
             RGBColor[
             0.23161694690439888`, 0.3607744749321087, 0.9365016145284144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 297}], {
             RGBColor[
             0.20930917766859286`, 0.3373275950710155, 0.9352312200718224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 309}], {
             RGBColor[
             0.2546471876156135, 0.3849807181211936, 0.93781315266673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 322}], {
             RGBColor[
             0.20580146810397543`, 0.3336407699169709, 0.9350314612013086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 325}], {
             RGBColor[
             0.2504184772778667, 0.38053607544050067`, 0.9375723338688118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 339}], {
             RGBColor[
             0.23162280417676506`, 0.3607806312967381, 0.9365019480914105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 149}], {
             RGBColor[
             0.2631665511656537, 0.3938441656371931, 0.9383016477132344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 185}], {
             RGBColor[
             0.35466498690371884`, 0.48161471850061266`, 0.9438199172409392]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 210}], {
             RGBColor[
             0.30769169180349737`, 0.4406429115045353, 0.9408372886035168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 219}], {
             RGBColor[
             0.32342751125618663`, 0.45455838713589725`, 0.9418294929148936]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 249}], {
             RGBColor[
             0.30940302019566135`, 0.4424110778706867, 0.9409358647458874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 266}], {
             RGBColor[
             0.27124098687969256`, 0.402330909521441, 0.9387614748820916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 293}], {
             RGBColor[
             0.3293119680498331, 0.45965520784915576`, 0.9422044452983639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 315}], {
             RGBColor[
             0.2642878093777229, 0.3950226791099546, 0.9383655017096588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 316}], {
             RGBColor[
             0.27204171641094554`, 0.40317252702797246`, 0.9388070752443234]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 338}], {
             RGBColor[
             0.2719649687624893, 0.40309186038336303`, 0.9388027045792817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 387}], {
             RGBColor[
             0.42192783769441117`, 0.5376802913607258, 0.9487120906541628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 397}], {
             RGBColor[
             0.26132649500551464`, 0.3919101499465881, 0.9381968592370336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 148}], {
             RGBColor[
             0.2977450564931756, 0.4279464199660071, 0.9403529311058223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 162}], {
             RGBColor[
             0.2669203824734684, 0.39788062408229774`, 0.9385120929573202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 211}], {
             RGBColor[
             0.24170072207493107`, 0.37137316198461084`, 0.9370758706067677]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 214}], {
             RGBColor[
             0.25062847588100123`, 0.38075679728707557`, 0.9375842929785951]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 248}], {
             RGBColor[
             0.2397553776330553, 0.3693284816342379, 0.936965086118682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 263}], {
             RGBColor[
             0.326732269165051, 0.4530536866427142, 0.9421999706648885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 276}], {
             RGBColor[
             0.2421845103154749, 0.3718816540993685, 0.9371034216313661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 288}], {
             RGBColor[
             0.28344153985750953`, 0.415245407994804, 0.9394529484294792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 196}], {
             RGBColor[
             0.1881608487233165, 0.3150993604680292, 0.9340268540245378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 289}], {
             RGBColor[
             0.1863769520635358, 0.31322437197301883`, 0.933925263748802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 317}], {
             RGBColor[
             0.1909701324562666, 0.31805209579023613`, 0.9341868385771666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 326}], {
             RGBColor[
             0.18929893908149736`, 0.31629556559357375`, 0.9340916665867824]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 327}], {
             RGBColor[
             0.19109665502145906`, 0.31818507902824733`, 0.9341940438500809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 336}], {
             RGBColor[
             0.18346975723563688`, 0.31016872588209876`, 0.9337597033041625]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 376}], {
             RGBColor[
             0.19809406452812484`, 0.3255398000811405, 0.9345925359697458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 129}], {
             RGBColor[
             0.19194623803100921`, 0.3190780446379586, 0.9342424263456293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 216}], {
             RGBColor[
             0.19725740387013102`, 0.32466041668223944`, 0.9345448893830015]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 231}], {
             RGBColor[
             0.1884985570631651, 0.31545431334515556`, 0.9340460860148976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 235}], {
             RGBColor[
             0.19315907110692182`, 0.32035280909880115`, 0.9343114953950769]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 298}], {
             RGBColor[
             0.19590091614963856`, 0.32323466208171286`, 0.9344676394140633]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 313}], {
             RGBColor[
             0.20658568658737522`, 0.3344650332653477, 0.935076121283791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 317}], {
             RGBColor[
             0.19507910076484197`, 0.32237088200618674`, 0.9344208382436661]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 336}], {
             RGBColor[
             0.18757872554421223`, 0.31448751209804937`, 0.933993702970662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 361}], {
             RGBColor[
             0.2062200768333135, 0.33408075423283157`, 0.9350553003491684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 393}], {
             RGBColor[
             0.1890837058583692, 0.31606934182949153`, 0.9340794093731344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 396}], {
             RGBColor[
             0.197181010085485, 0.3245801219709307, 0.9345405388699805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 133}], {
             RGBColor[
             0.19019948162046302`, 0.31724209289972144`, 0.9341429511521433]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 155}], {
             RGBColor[
             0.2008465417565683, 0.32843282816537045`, 0.9347492854759805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 170}], {
             RGBColor[
             0.21313809335858236`, 0.34135202822847077`, 0.9354492711559941]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 171}], {
             RGBColor[
             0.19178726559275905`, 0.3189109545259229, 0.9342333731004496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 199}], {
             RGBColor[
             0.1905507884017967, 0.3176113386010396, 0.9341629575536283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 261}], {
             RGBColor[
             0.22729090761283746`, 0.3562275333499445, 0.9362552529905616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 299}], {
             RGBColor[
             0.19113698074466645`, 0.31822746392013684`, 0.934196340340361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 306}], {
             RGBColor[
             0.1986620698216136, 0.3261368096582128, 0.9346248830309214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 342}], {
             RGBColor[
             0.18916310762939384`, 0.3161527981252015, 0.9340839311865298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 353}], {
             RGBColor[
             0.19231632365158768`, 0.3194670280899702, 0.9342635021742287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 216}], {
             RGBColor[
             0.1943994825815768, 0.32165656020529343`, 0.9343821349935341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 231}], {
             RGBColor[
             0.18564063577461087`, 0.3124504568682096, 0.93388333162543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 235}], {
             RGBColor[
             0.1903011498183676, 0.3173489526218552, 0.9341487410056093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 298}], {
             RGBColor[
             0.19304299486108434`, 0.3202308056047669, 0.9343048850245959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 313}], {
             RGBColor[
             0.203727765298821, 0.33146117678840176`, 0.9349133668943235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 317}], {
             RGBColor[
             0.19222117947628775`, 0.3193670255292408, 0.9342580838541985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 336}], {
             RGBColor[
             0.184720804255658, 0.3114836556211034, 0.9338309485811944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 361}], {
             RGBColor[
             0.20336215554475928`, 0.33107689775588556`, 0.9348925459597008]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 393}], {
             RGBColor[
             0.18622578456981498`, 0.3130654853525456, 0.9339166549836668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 396}], {
             RGBColor[
             0.19432308879693078`, 0.32157626549398477`, 0.934377784480513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 147}], {
             RGBColor[
             0.18274418895711692`, 0.3094061076176884, 0.9337183832640827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 164}], {
             RGBColor[
             0.19148238974395732`, 0.318590510678587, 0.9342160108718838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 287}], {
             RGBColor[
             0.1859722872961475, 0.31279904364526556`, 0.9339022186889471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 371}], {
             RGBColor[
             0.18427986944939637`, 0.311020205182841, 0.9338058379962824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 391}], {
             RGBColor[
             0.18156952589467779`, 0.3081714622611251, 0.9336514879404352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 140}], {
             RGBColor[
             0.21947779992995464`, 0.3480154617955958, 0.9358103080664784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 186}], {
             RGBColor[
             0.21005402739966472`, 0.3381104793645726, 0.9352736381621005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 188}], {
             RGBColor[
             0.20752052535930418`, 0.3354476080868466, 0.9351293589688823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 203}], {
             RGBColor[
             0.2195067441810682, 0.34804588403868764`, 0.9358119563987601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 228}], {
             RGBColor[
             0.20842587898456535`, 0.33639919214973135`, 0.9351809175184903]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 238}], {
             RGBColor[
             0.2516193138752771, 0.38179823084181674`, 0.9376407197365557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 273}], {
             RGBColor[
             0.19754073794696791`, 0.32495821876141306`, 0.9345610248395222]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 280}], {
             RGBColor[
             0.23239625445736245`, 0.36159357658122604`, 0.9365459949406734]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 309}], {
             RGBColor[
             0.255426495168577, 0.38579981977031097`, 0.9378575330789891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 322}], {
             RGBColor[
             0.206580775656939, 0.33445987156608825`, 0.9350758416135677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 325}], {
             RGBColor[
             0.2511977848308302, 0.381355177089618, 0.9376167142810707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 330}], {
             RGBColor[
             0.199593351679308, 0.3271156459373298, 0.9346779181550091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 339}], {
             RGBColor[
             0.23240211172972863`, 0.36159973294585546`, 0.9365463285036696]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 160}], {
             RGBColor[
             0.40894844852211004`, 0.5284611159894712, 0.9473261168602697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 202}], {
             RGBColor[
             0.300816385571577, 0.4289283244783967, 0.9406100852285664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 220}], {
             RGBColor[
             0.4970479670019815, 0.5999842739295098, 0.9542616336741748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 244}], {
             RGBColor[
             0.656519419340629, 0.7252624326066381, 0.9527521812690418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 260}], {
             RGBColor[
             0.29142760754703456`, 0.4190601234916939, 0.9400754082095211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 307}], {
             RGBColor[
             0.3533139613151539, 0.48044452804031823`, 0.9437338310851009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 321}], {
             RGBColor[
             0.4563174789356197, 0.5669174288296601, 0.9510551804528969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 341}], {
             RGBColor[
             0.34725423307667924`, 0.4751958960109486, 0.9433477105601525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 348}], {
             RGBColor[
             0.34570653122762846`, 0.47385535445905747`, 0.94324909236691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 366}], {
             RGBColor[
             0.3763364091715497, 0.5003854152316536, 0.9452008011045592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 155}], {
             RGBColor[
             0.1964342499678622, 0.3237952297399831, 0.9344980119860145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 199}], {
             RGBColor[
             0.18613849661309062`, 0.31297374017565216`, 0.9339116840636623]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 216}], {
             RGBColor[
             0.19274891912622777`, 0.3199217133619542, 0.9342881378465417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 298}], {
             RGBColor[
             0.1913924314057353, 0.3184959587614276, 0.9342108878776034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 299}], {
             RGBColor[
             0.18672468895596034`, 0.31358986549474943`, 0.9339450668503949]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 306}], {
             RGBColor[
             0.1942497780329075, 0.32149921123282543`, 0.9343736095409554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 342}], {
             RGBColor[
             0.18475081584068775`, 0.311515199699814, 0.9338326576965637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 361}], {
             RGBColor[
             0.20171159208941025`, 0.3293420509125463, 0.9347985488127086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 393}], {
             RGBColor[
             0.18457522111446595`, 0.3113306385092063, 0.9338226578366745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 135}], {
             RGBColor[
             0.9129052217970873, 0.9297159641585085, 0.8318647617559947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 226}], {
             RGBColor[
             0.6381042655490734, 0.7140610165668736, 0.9666654902064342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 234}], {
             RGBColor[
             0.8083454624285121, 0.8502936670726204, 0.9815084195744261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 239}], {
             RGBColor[
             0.8288313392623307, 0.4322875085422818, 0.44405929782727327`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 246}], {
             RGBColor[
             0.8756067697264411, 0.9036490867400013, 0.9879973494315406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 269}], {
             RGBColor[
             0.7872748442941331, 0.8338331400434145, 0.9794082972749127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 272}], {
             RGBColor[
             0.7859507335711424, 0.832798734683, 0.9792763222925633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 350}], {
             RGBColor[
             0.9124093272037948, 0.929890258170909, 0.8676584254872136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 355}], {
             RGBColor[
             0.7983376603764013, 0.8424754960473988, 0.9805109353940992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 392}], {
             RGBColor[
             0.9110260493239869, 0.9293182372189884, 0.8905829197640283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 395}], {
             RGBColor[
             0.6498035533941702, 0.7237783527330339, 0.9675259002297822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 156}], {
             RGBColor[
             0.8856046641981132, 0.4899098319471875, 0.34486688561467355`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 165}], {
             RGBColor[
             0.9457959012350979, 0.9559420991486686, 0.8350019041226482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 221}], {
             RGBColor[
             0.9485753172801801, 0.8203317071995411, 0.46009294767531356`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 234}], {
             RGBColor[
             0.8902824990453274, 0.9119541401261442, 0.8296334999422285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 255}], {
             RGBColor[
             0.8885216832896912, 0.5123313189309725, 0.3476602263910705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 281}], {
             RGBColor[
             0.711765095722288, 0.768553055573181, 0.8142632180180123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 328}], {
             RGBColor[
             0.932186507346842, 0.7459139489960613, 0.44641772294044424`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 355}], {
             RGBColor[
             0.8802746969932166, 0.9041359691009224, 0.8286360157619015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 386}], {
             RGBColor[
             0.8778014359212141, 0.9022038387539937, 0.8283895042121832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 400}], {
             RGBColor[
             0.8983997399580361, 0.588258391075905, 0.357119464612347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 331}], {
             RGBColor[
             0.19186850922797938`, 0.3189963467376835, 0.9342379998052863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 335}], {
             RGBColor[
             0.18204623503960604`, 0.3086725137975501, 0.9336786358210108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 394}], {
             RGBColor[
             0.18251086599702937`, 0.30916087039310625`, 0.9337050958666762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 169}], {
             RGBColor[
             0.6151260920101136, 0.6919294010372166, 0.9662275076726026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 175}], {
             RGBColor[
             0.3080574204607164, 0.43874050226861905`, 0.940941847744563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 178}], {
             RGBColor[
             0.3880768646119117, 0.5105544076416471, 0.9459488925435418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 197}], {
             RGBColor[
             0.6493874970557305, 0.7185106775296126, 0.9439140882472267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 252}], {
             RGBColor[
             0.35201484785933657`, 0.47931930126023004`, 0.943651052724457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 278}], {
             RGBColor[
             0.29631468313808673`, 0.42639814080998684`, 0.9402731162258624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 282}], {
             RGBColor[
             0.3008030444529849, 0.4311156931304887, 0.9405287217628104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 300}], {
             RGBColor[
             0.624581474397714, 0.6994688662935715, 0.9671293704856514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 314}], {
             RGBColor[
             0.28356888618805115`, 0.41300150008529746`, 0.9395472619452747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 319}], {
             RGBColor[
             0.3939126281591366, 0.5156078641515458, 0.9463210706392715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 352}], {
             RGBColor[
             0.28703295098175935`, 0.4166424518178782, 0.9397445353106518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 159}], {
             RGBColor[
             0.18138230828610377`, 0.30797468468423184`, 0.9336408261745905]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 215}], {
             RGBColor[
             0.18262441317102773`, 0.30928021567228525`, 0.9337115622102574]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 218}], {
             RGBColor[
             0.18655648275495362`, 0.3134130701126022, 0.9339354877560864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 229}], {
             RGBColor[
             0.19456770903936127`, 0.32183337687859837`, 0.9343917152414362]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 329}], {
             RGBColor[
             0.18634787164566047`, 0.31319380661002694`, 0.9339236076620245]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 349}], {
             RGBColor[
             0.19211902352341417`, 0.31925965314570914`, 0.9342522662238085]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 193}], {
             RGBColor[
             0.18750230329400064`, 0.31440718746762647`, 0.933989350836569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 204}], {
             RGBColor[
             0.19084712474135193`, 0.31792280688272123`, 0.9341798334697757]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 224}], {
             RGBColor[
             0.18369701044953324`, 0.3104075834185898, 0.9337726450385029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 276}], {
             RGBColor[
             0.20545840173873126`, 0.33328018541543536`, 0.9350119240793292]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 290}], {
             RGBColor[
             0.19313846063632573`, 0.32033114618742536`, 0.9343103216592668]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 318}], {
             RGBColor[
             0.19122506102961745`, 0.318320041884233, 0.9342013563822857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 203}], {
             RGBColor[
             0.22572809779654535`, 0.3545849211451561, 0.9361662532834936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 232}], {
             RGBColor[
             0.2603959916536444, 0.39102307566039235`, 0.9381405385521024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 257}], {
             RGBColor[
             0.2744017745717613, 0.404416509747592, 0.9389867546110457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 275}], {
             RGBColor[
             0.23222474174375346`, 0.36141330584468895`, 0.9365362275453637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 280}], {
             RGBColor[
             0.2386176080728396, 0.36813261368769457`, 0.936900291825407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 288}], {
             RGBColor[
             0.2655351688852008, 0.39642467677341436`, 0.9384332070927082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 297}], {
             RGBColor[
             0.21630983883703356`, 0.3446857338266013, 0.935629897368815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 309}], {
             RGBColor[
             0.2616478487840542, 0.3923388568767794, 0.9382118299637227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 322}], {
             RGBColor[
             0.21280212927241615`, 0.34099890867255667`, 0.9354301384983013]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 325}], {
             RGBColor[
             0.25741913844630737`, 0.3878942141960865, 0.9379710111658044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 339}], {
             RGBColor[
             0.2386234653452058, 0.3681387700523239, 0.9369006253884031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 172}], {
             RGBColor[
             0.8516660985539529, 0.38305028155577586`, 0.19651818563350704`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[
             0.8542946643121351, 0.403254589818024, 0.1990353031720827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 243}], {
             RGBColor[
             0.9002404219314994, 0.6473255027899616, 0.4518652115799682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 279}], {
             RGBColor[
             0.801143090532162, 0.5696856585664152, 0.46236431184102655`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 285}], {
             RGBColor[
             0.908464702608926, 0.6517279650966425, 0.34303552105754676`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 337}], {
             RGBColor[
             0.9084139629772536, 0.6516194381550591, 0.33751282527872106`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 399}], {
             RGBColor[
             0.8859237106076299, 0.5705962751965173, 0.2263022782483616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 143}], {
             RGBColor[
             0.1837659567931899, 0.3104800503972236, 0.9337765714307771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 258}], {
             RGBColor[
             0.18294835007904106`, 0.30962069390139346`, 0.9337300099379471]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 277}], {
             RGBColor[
             0.19515207298431664`, 0.32244758043556054`, 0.9344249939036124]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 302}], {
             RGBColor[
             0.18693197467623224`, 0.31380773592942895`, 0.9339568714655127]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 377}], {
             RGBColor[
             0.18361252498065594`, 0.31031878383411166`, 0.9337678337160353]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 378}], {
             RGBColor[
             0.18665371404405717`, 0.3135152663622699, 0.93394102493416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 379}], {
             RGBColor[
             0.1947953347030193, 0.32207262588340363`, 0.9344046781862394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 258}], {
             RGBColor[
             0.1842254727690224, 0.31096303082281923`, 0.9338027401858078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 277}], {
             RGBColor[
             0.196429195674298, 0.32378991735698637`, 0.9344977241514731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 302}], {
             RGBColor[
             0.1882090973662136, 0.3151500728508547, 0.9340296017133733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 377}], {
             RGBColor[
             0.1848896476706373, 0.3116611207555374, 0.933840563963896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 378}], {
             RGBColor[
             0.18793083673403851`, 0.31485760328369566`, 0.9340137551820207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 379}], {
             RGBColor[
             0.19607245739300067`, 0.3234149628048294, 0.9344774084341002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 186}], {
             RGBColor[
             0.19870087032152506`, 0.3261775914437136, 0.9346270926619912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 188}], {
             RGBColor[
             0.19616736828116454`, 0.3235147201659876, 0.934482813468773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 200}], {
             RGBColor[
             0.18738223875410484`, 0.31428099202366444`, 0.9339825133386415]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 228}], {
             RGBColor[
             0.19707272190642572`, 0.32446630422887235`, 0.934534372018381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 333}], {
             RGBColor[
             0.1893313874669234, 0.316329670904003, 0.9340935144743294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 368}], {
             RGBColor[
             0.18786109875542928`, 0.31478430424653414`, 0.934009783707307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 200}], {
             RGBColor[
             0.19073593578989534`, 0.3178059402449537, 0.9341735014234795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 207}], {
             RGBColor[
             0.19250737674757545`, 0.31966783700731927`, 0.9342743823654074]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 222}], {
             RGBColor[
             0.21482177415136725`, 0.3431216834932156, 0.9355451542863606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 254}], {
             RGBColor[
             0.19225246823374995`, 0.31939991199715534`, 0.9342598657026484]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 333}], {
             RGBColor[
             0.19268508450271393`, 0.3198546191252922, 0.9342845025591675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 227}], {
             RGBColor[
             0.19680598858419968`, 0.3241859505953433, 0.934519181950277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 302}], {
             RGBColor[
             0.18875875182792845`, 0.3157277945402228, 0.9340609037218272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 375}], {
             RGBColor[
             0.18336952246536248`, 0.3100633727832889, 0.9337539950822794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 377}], {
             RGBColor[
             0.18543930213235216`, 0.3122388424449055, 0.9338718659723498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 344}], {
             RGBColor[
             0.1873628349672718, 0.31426059741343176`, 0.9339814083216866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 354}], {
             RGBColor[
             0.1996644579713909, 0.3271903831587082, 0.9346819675531508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 371}], {
             RGBColor[
             0.18501189214807195`, 0.3117896074520688, 0.9338475256060415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 388}], {
             RGBColor[
             0.20149520910929605`, 0.3291146186809729, 0.9347862261221009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 391}], {
             RGBColor[
             0.18230154859335337`, 0.30894086453035285`, 0.9336931755501943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 179}], {
             RGBColor[
             0.39396314610535543`, 0.515635700812435, 0.9463286881882242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 232}], {
             RGBColor[
             0.3145355236290795, 0.4455942655029455, 0.9413091233699418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 257}], {
             RGBColor[
             0.3285413065471964, 0.4589876995901452, 0.9421553394288851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 275}], {
             RGBColor[
             0.28636427371918854`, 0.4159844956872421, 0.939704812363203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 276}], {
             RGBColor[
             0.27841767131860123`, 0.407632112720532, 0.9392522651124343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 279}], {
             RGBColor[
             0.5031062098123048, 0.6037853067748751, 0.9552337277677017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 288}], {
             RGBColor[
             0.3196747008606359, 0.4509958666159675, 0.9416017919105475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 195}], {
             RGBColor[
             0.20922588183301488`, 0.33724004586656203`, 0.9352264764972114]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 210}], {
             RGBColor[
             0.26112860842944113`, 0.3917931023423411, 0.9381822599936748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 247}], {
             RGBColor[
             0.20711572977977888`, 0.33502214226724336`, 0.9351063064594698]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 249}], {
             RGBColor[
             0.2628399368216051, 0.3935612687084925, 0.9382808361360453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 253}], {
             RGBColor[
             0.20384820267597584`, 0.3315877641079622, 0.9349202256247814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 266}], {
             RGBColor[
             0.22467790350563632`, 0.35348110035924685`, 0.9361064462722496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 315}], {
             RGBColor[
             0.21772472600366666`, 0.3461728699477604, 0.9357104730998167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 316}], {
             RGBColor[
             0.2254786330368893, 0.3543227178657783, 0.9361520466344813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 358}], {
             RGBColor[
             0.20368965097586314`, 0.3314211162183854, 0.9349111963400162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 359}], {
             RGBColor[
             0.20190369877404518`, 0.3295439672183649, 0.9348094890042022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 362}], {
             RGBColor[
             0.20288427131655484`, 0.3305746111324327, 0.934865331159871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 363}], {
             RGBColor[
             0.21825217126115545`, 0.34672724835534197`, 0.9357405103269454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 369}], {
             RGBColor[
             0.20360056980323105`, 0.3313274862578765, 0.9349061232990186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 397}], {
             RGBColor[
             0.21476341163145843`, 0.34306034078439396`, 0.9355418306271915]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 192}], {
             RGBColor[
             0.1875835174154828, 0.3144925486585769, 0.9339939758606419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 283}], {
             RGBColor[
             0.2012631111576979, 0.32887066901798323`, 0.9347730084871156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 294}], {
             RGBColor[
             0.19175282420721007`, 0.318874754446001, 0.9342314117144941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 320}], {
             RGBColor[
             0.19466927104284892`, 0.32194012498366686`, 0.9343974990472872]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 347}], {
             RGBColor[
             0.19569856946522865`, 0.3230219828868772, 0.9344561160697312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 380}], {
             RGBColor[
             0.20683506244234898`, 0.3347271431002675, 0.9350903228698133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 381}], {
             RGBColor[
             0.19485465175919953`, 0.32213497187036766`, 0.9344080562048372]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 384}], {
             RGBColor[
             0.19155187583051508`, 0.31866354496123156`, 0.9342199680017178]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 168}], {
             RGBColor[
             0.18811217327033666`, 0.31504819948074547`, 0.9340240820294996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 265}], {
             RGBColor[
             0.1910010224377346, 0.31808456311929695`, 0.9341885977159134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 291}], {
             RGBColor[
             0.1895972333261113, 0.3166090917576105, 0.9341086540027264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 304}], {
             RGBColor[
             0.1864549217267703, 0.3133063230326405, 0.9339297040057775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 378}], {
             RGBColor[
             0.19141895458300517`, 0.3185238363024048, 0.9342123983333115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 383}], {
             RGBColor[
             0.20018660218381945`, 0.3277391898318258, 0.9347117028936056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 154}], {
             RGBColor[
             0.23114091709829876`, 0.3602741374238645, 0.93647450533518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 180}], {
             RGBColor[
             0.2576563148367751, 0.3881435016203197, 0.9379845180103705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 198}], {
             RGBColor[
             0.3050387614583694, 0.43382537545233274`, 0.9408337346263971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 236}], {
             RGBColor[
             0.2537723278978401, 0.38406118508850384`, 0.9377633307000419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 267}], {
             RGBColor[
             0.25637803396755154`, 0.3867999473790775, 0.9379117218059152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 284}], {
             RGBColor[
             0.26668400229217915`, 0.3976321735243937, 0.9384986314556889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 332}], {
             RGBColor[
             0.24255699042787615`, 0.37227315431410535`, 0.9371246338227324]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 367}], {
             RGBColor[
             0.31592573046277495`, 0.4432551208089762, 0.9415274426643891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 383}], {
             RGBColor[
             0.2325615956471479, 0.3617673606549275, 0.9365554108768314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 398}], {
             RGBColor[
             0.3414317727237982, 0.4653471726445155, 0.943152665123154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 161}], {
             RGBColor[
             0.1909498488692258, 0.3180307764542026, 0.9341856834568915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 184}], {
             RGBColor[
             0.18277753601960423`, 0.3094411574946885, 0.933720282329959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[
             0.18871819494406902`, 0.31568516668383156`, 0.9340585940672899]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 372}], {
             RGBColor[
             0.18825648302408265`, 0.31519987818169937`, 0.9340323002564883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 180}], {
             RGBColor[
             0.2320279298273124, 0.36120644404191316`, 0.9365250193978796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 236}], {
             RGBColor[
             0.22814394288837742`, 0.3571241275100973, 0.936303832087551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 267}], {
             RGBColor[
             0.23074964895808886`, 0.359862889800671, 0.9364522231934242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 286}], {
             RGBColor[
             0.2001789472954632, 0.3277311440588154, 0.9347112669590381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 291}], {
             RGBColor[
             0.1963438417799771, 0.3237002050023056, 0.9344928633734613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 332}], {
             RGBColor[
             0.2169286054184135, 0.3453360967356988, 0.9356651352102414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 383}], {
             RGBColor[
             0.20693321063768522`, 0.33483030307652095`, 0.9350959122643404]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 170}], {
             RGBColor[
             0.21937286170598153`, 0.34790516506873237`, 0.9358043319898652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 171}], {
             RGBColor[
             0.19802203394015824`, 0.32546409136618454`, 0.9345884339343208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 199}], {
             RGBColor[
             0.1967855567491959, 0.3241644754413012, 0.9345180183874995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 261}], {
             RGBColor[
             0.23352567596023666`, 0.3627806701902061, 0.9366103138244327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.19737174909206562`, 0.3247806007603985, 0.9345514011742322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 306}], {
             RGBColor[
             0.20489683816901277`, 0.33268994649847444`, 0.9349799438647926]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 342}], {
             RGBColor[
             0.19539787597679303`, 0.32270593496546307`, 0.9344389920204009]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 353}], {
             RGBColor[
             0.19855109199898685`, 0.3260201649302318, 0.9346185630080999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 361}], {
             RGBColor[
             0.21235865222551553`, 0.3405327861781953, 0.9354048831365458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 165}], {
             RGBColor[
             0.8529070927455767, 0.4662869399049452, 0.44820826028057437`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 221}], {
             RGBColor[
             0.8547600367756315, 0.37588001193886017`, 0.19826895598235128`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 245}], {
             RGBColor[
             0.826933929899517, 0.208031564496835, 0.1734252677302876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 255}], {
             RGBColor[
             0.8324443766360075, 0.2503872728066577, 0.17870207774831032`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 328}], {
             RGBColor[
             0.8438341634867396, 0.32626817313654033`, 0.18915213949243842`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 364}], {
             RGBColor[
             0.8265496181427123, 0.20507757592754824`, 0.17305725035795336`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 386}], {
             RGBColor[
             0.8075774492029875, 0.43046143297516193`, 0.4437999936735976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 400}], {
             RGBColor[
             0.8373834049701799, 0.28835080887912395`, 0.18343169685894858`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 181}], {
             RGBColor[
             0.19115892919796787`, 0.31825053313616897`, 0.9341975902723066]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 191}], {
             RGBColor[
             0.1973089788218841, 0.3247146252265727, 0.9345478265002056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 334}], {
             RGBColor[
             0.1861875662547559, 0.3130253154802374, 0.9339144785071631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 365}], {
             RGBColor[
             0.18416233691758455`, 0.3108966710399138, 0.9337991446924696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 370}], {
             RGBColor[
             0.18724094908895864`, 0.3141324876273136, 0.9339744671012307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 209}], {
             RGBColor[
             0.336799320476102, 0.4661403761955148, 0.94268153277416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 241}], {
             RGBColor[
             0.3009846875478195, 0.43090972620672763`, 0.9405535979845862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 270}], {
             RGBColor[
             0.3489276916060272, 0.4766453616785984, 0.9434543418578613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 310}], {
             RGBColor[
             0.30917761379090525`, 0.4395210111497373, 0.9410201730137817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 323}], {
             RGBColor[
             0.3687236016444134, 0.49379158398248, 0.9447157197406713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 324}], {
             RGBColor[
             0.4859428845919035, 0.5904387279012617, 0.9535338248669657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 346}], {
             RGBColor[
             0.34491127963015633`, 0.47316654749583464`, 0.9431984196383325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 390}], {
             RGBColor[
             0.3007335296132649, 0.43064574329317795`, 0.9405392949117681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 215}], {
             RGBColor[
             0.1817543271405076, 0.3083657000875679, 0.9336620120979963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 218}], {
             RGBColor[
             0.18568639672443343`, 0.31249855452788494`, 0.9338859376438252]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 329}], {
             RGBColor[
             0.18547778561514033`, 0.3122792910253096, 0.9338740575497635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 349}], {
             RGBColor[
             0.191248937492894, 0.31834513756099186`, 0.9342027161115474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 217}], {
             RGBColor[
             0.7263465347719837, 0.7798834744139984, 0.7188240157462833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 220}], {
             RGBColor[
             0.5477229997143326, 0.6437052316648666, 0.9575379073944208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 233}], {
             RGBColor[
             0.7095149174779228, 0.7707139896565038, 0.9521005122991707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 244}], {
             RGBColor[
             0.7071944520529801, 0.7689833903419949, 0.9560284549892878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 263}], {
             RGBColor[
             0.42578806203725694`, 0.5430467428327064, 0.9483991221427692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 264}], {
             RGBColor[
             0.5914575736276367, 0.6779711437656651, 0.9618285011853527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 307}], {
             RGBColor[
             0.403988994027505, 0.524165485775675, 0.9470101048053469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 312}], {
             RGBColor[
             0.38126624461740655`, 0.5039445125232649, 0.9455819912605958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 321}], {
             RGBColor[
             0.5069925116479708, 0.6106383865650169, 0.9543314541731429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 341}], {
             RGBColor[
             0.3979292657890303, 0.5189168537463054, 0.9466239842803985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 348}], {
             RGBColor[
             0.39638156393997953`, 0.5175763121944144, 0.946525366087156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 366}], {
             RGBColor[
             0.4270114418839008, 0.5441063729670104, 0.948477074824805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 176}], {
             RGBColor[
             0.21656199837052442`, 0.34495076948413805`, 0.9356442574812107]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 184}], {
             RGBColor[
             0.19128276610466352`, 0.31838069357681953`, 0.9342046426009427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 195}], {
             RGBColor[
             0.20065168741435874`, 0.3282280238972294, 0.9347381888094528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 250}], {
             RGBColor[
             0.22890128499152032`, 0.3579201420787632, 0.9363469615999377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 344}], {
             RGBColor[
             0.1953522686165181, 0.3226579987381405, 0.9344363947487033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.19722342502912832`, 0.3246247027659626, 0.9345429543382737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 363}], {
             RGBColor[
             0.20967797684249928`, 0.3377152263860093, 0.9352522226391868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 372}], {
             RGBColor[
             0.19676171310914198`, 0.3241394142638304, 0.934516660527472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 191}], {
             RGBColor[
             0.239776323432642, 0.3693504969976439, 0.936966278950982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 211}], {
             RGBColor[
             0.24710920905835015`, 0.37705782472206506`, 0.9373838759393338]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 214}], {
             RGBColor[
             0.25603696286442035`, 0.3864414600245297, 0.9378922983111614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 248}], {
             RGBColor[
             0.24516386461647438`, 0.3750131443716921, 0.9372730914512483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 263}], {
             RGBColor[
             0.33214075614847005`, 0.45873834938016844`, 0.9425079759974546]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 312}], {
             RGBColor[
             0.28761893872861966`, 0.41963611907072695`, 0.9396908451152812]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 340}], {
             RGBColor[
             0.23763180163327896`, 0.367096468615978, 0.9368441516070439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 348}], {
             RGBColor[
             0.3027342580511927, 0.4332679187418763, 0.9406342199418414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 167}], {
             RGBColor[
             0.2885245503262027, 0.4204485142001573, 0.9397475246726753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 174}], {
             RGBColor[
             0.3053955889489409, 0.4350613598921163, 0.9408225323352425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.2667189772067604, 0.39766893437715617`, 0.9385006232253336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 222}], {
             RGBColor[
             0.24959037113759353`, 0.3796656833821117, 0.9375251744491964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 226}], {
             RGBColor[
             0.35601753306005335`, 0.4789075435482711, 0.944048117850775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 395}], {
             RGBColor[
             0.36771682090515007`, 0.4886248797144314, 0.9449085278741232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 287}], {
             RGBColor[
             0.19544251078166353`, 0.3227528489753921, 0.9344415339065071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 292}], {
             RGBColor[
             0.19766905263223078`, 0.3250930856312453, 0.9345683321710234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 354}], {
             RGBColor[
             0.20840265875823133`, 0.3363747862196069, 0.9351795951609518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 371}], {
             RGBColor[
             0.1937500929349124, 0.3209740105129675, 0.9343451532138425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 374}], {
             RGBColor[
             0.1955858495365969, 0.322903507095029, 0.9344496968365499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 388}], {
             RGBColor[
             0.21023340989613648`, 0.33829902174187165`, 0.935283853729902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 389}], {
             RGBColor[
             0.20180063292388895`, 0.3294356384750984, 0.934803619556508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 391}], {
             RGBColor[
             0.1910397493801938, 0.3181252675912516, 0.9341908031579952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 182}], {
             RGBColor[
             0.6226406331298818, 0.6984050769847048, 0.9667215385795859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 256}], {
             RGBColor[
             0.624029163944416, 0.6996077525866663, 0.9668100145352584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 281}], {
             RGBColor[
             0.6627187385434833, 0.7331187175098175, 0.9692752800168635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 311}], {
             RGBColor[
             0.5997467789297788, 0.6780206465223158, 0.965283080943369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 328}], {
             RGBColor[
             0.8831401501680374, 0.7104796109326978, 0.6014297849392954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 386}], {
             RGBColor[
             0.8287550787424094, 0.8667695006906301, 0.9834015662110343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 400}], {
             RGBColor[
             0.8657021685054997, 0.5646354990336626, 0.4604608392782479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 169}], {
             RGBColor[
             0.9427417968791698, 0.9548740993356628, 0.9051840770091248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 178}], {
             RGBColor[
             0.7156925694809679, 0.7734991059400932, 0.884905461880064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 197}], {
             RGBColor[
             0.9770032019247867, 0.9814553758280588, 0.8828706575837489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.8817402416283486, 0.4729378739656097, 0.3896280153376859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 300}], {
             RGBColor[
             0.9521971792667703, 0.9624135645920178, 0.9060859398221737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 319}], {
             RGBColor[
             0.7215283330281927, 0.7785525624499918, 0.8852776399757938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 174}], {
             RGBColor[
             0.3271254190729118, 0.4577613290244936, 0.9420651203310438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 183}], {
             RGBColor[
             0.33012064304919175`, 0.46035564148841296`, 0.9422559733542398]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 189}], {
             RGBColor[
             0.2884488073307313, 0.4203689035095335, 0.9397432112211349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 222}], {
             RGBColor[
             0.2713202012615644, 0.4023656525144891, 0.9387677624449977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 238}], {
             RGBColor[
             0.3001182809431252, 0.43263426016352036`, 0.9404077704799216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 246}], {
             RGBColor[
             0.6152498673613919, 0.6911955828537762, 0.9666225650716829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 269}], {
             RGBColor[
             0.5269179419290838, 0.6213796361571894, 0.958033512915055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 272}], {
             RGBColor[
             0.5255938312060932, 0.6203452307967748, 0.9579015379327056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 309}], {
             RGBColor[
             0.30392546223642514`, 0.4366358490920146, 0.940624583822355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 395}], {
             RGBColor[
             0.389446651029121, 0.5113248488468087, 0.9461511158699245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 265}], {
             RGBColor[
             0.18709388052696674`, 0.31397790924397473`, 0.9339660917641938]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 304}], {
             RGBColor[
             0.18254777981600245`, 0.3091996691573183, 0.9337071980540577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 378}], {
             RGBColor[
             0.18751181267223727`, 0.3144171824270826, 0.9339898923815917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 177}], {
             RGBColor[
             0.8953206105495907, 0.9193683682944271, 0.9898776731680061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 178}], {
             RGBColor[
             0.668739474081812, 0.7383666179007873, 0.9696437049697588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 197}], {
             RGBColor[
             0.9300501065256308, 0.9463228877887528, 0.9676089006734437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 239}], {
             RGBColor[
             0.8504381780289113, 0.4495162152727391, 0.44612017739748244`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 300}], {
             RGBColor[
             0.9052440838676142, 0.9272810765527117, 0.9908241829118685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 319}], {
             RGBColor[
             0.6745752376290368, 0.7434200744106859, 0.9700158830654886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 171}], {
             RGBColor[
             0.21031358554217228`, 0.3383832914292848, 0.9352884196143345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 187}], {
             RGBColor[
             0.33329236872326556`, 0.45597611149735384`, 0.9427190170162062]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 261}], {
             RGBColor[
             0.2458172275622507, 0.3756998702533064, 0.9373102995044464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 299}], {
             RGBColor[
             0.20966330069407968`, 0.3376998008234987, 0.9352513868542458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 306}], {
             RGBColor[
             0.21718838977102684`, 0.3456091465615747, 0.9356799295448063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 353}], {
             RGBColor[
             0.2108426436010009, 0.33893936499333205`, 0.9353185486881135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 361}], {
             RGBColor[
             0.22465020382752957`, 0.3534519862412956, 0.9361048688165594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 299}], {
             RGBColor[
             0.18831247292825637`, 0.31525872712095093`, 0.9340354887987012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 306}], {
             RGBColor[
             0.19583756200520352`, 0.3231680728590269, 0.9344640314892618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 342}], {
             RGBColor[
             0.18633859981298379`, 0.3131840613260155, 0.9339230796448701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 353}], {
             RGBColor[
             0.1894918158351776, 0.3164982912907842, 0.9341026506325689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 208}], {
             RGBColor[
             0.8802072426240743, 0.4531049530073836, 0.36875769865424585`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 225}], {
             RGBColor[
             0.8441055756294294, 0.42628106073348204`, 0.44324008483187805`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 240}], {
             RGBColor[
             0.8264317919518623, 0.2041719121929097, 0.17294441986452982`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 243}], {
             RGBColor[
             0.8723775495712267, 0.44824282516484726`, 0.42577432827241535`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 285}], {
             RGBColor[
             0.8806018302486532, 0.4526452874715283, 0.3169446377499939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 337}], {
             RGBColor[
             0.8805510906169809, 0.45253676052994485`, 0.3114219419711682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 357}], {
             RGBColor[
             0.8349023138683568, 0.2692800554494574, 0.18105580121785106`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 399}], {
             RGBColor[
             0.8580608382473571, 0.37151359757140306`, 0.20021139494080872`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 176}], {
             RGBColor[
             0.25807437232061936`, 0.38858290654221544`, 0.9380083257656147]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 209}], {
             RGBColor[
             0.3086611648699239, 0.43934003290171275`, 0.940977513192154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 250}], {
             RGBColor[
             0.27041365894161523`, 0.40155227913684066`, 0.9387110298843417]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 323}], {
             RGBColor[
             0.3405854460382354, 0.4669912406886779, 0.9430117001586653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 354}], {
             RGBColor[
             0.24916626557073213`, 0.3792199215414943, 0.9375010222645717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 388}], {
             RGBColor[
             0.2509970167086373, 0.38114415706375904`, 0.9376052808335218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 183}], {
             RGBColor[
             0.34699168167192995`, 0.474968487180372, 0.943330981016807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 189}], {
             RGBColor[
             0.3053198459534695, 0.4349817492014926, 0.9408182188837021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 238}], {
             RGBColor[
             0.3169893195658634, 0.44724710585547944`, 0.9414827781424888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 246}], {
             RGBColor[
             0.6321209059841302, 0.7058084285457353, 0.96769757273425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 269}], {
             RGBColor[
             0.543788980551822, 0.6359924818491485, 0.9591085205776222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 272}], {
             RGBColor[
             0.5424648698288314, 0.6349580764887339, 0.9589765455952728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 309}], {
             RGBColor[
             0.32079650085916334`, 0.45124869478397367`, 0.9416995914849222]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 325}], {
             RGBColor[
             0.31656779052141654`, 0.4468040521032807, 0.9414587726870038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 395}], {
             RGBColor[
             0.4063176896518592, 0.5259376945387678, 0.9472261235324917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 178}], {
             RGBColor[
             0.3616708025324146, 0.48517771913218966`, 0.9443580450417194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 213}], {
             RGBColor[
             0.25213492118930436`, 0.3823401668202513, 0.9376700828103168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 227}], {
             RGBColor[
             0.24456047357150879`, 0.37437894212623135`, 0.9372387292238745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 278}], {
             RGBColor[
             0.2699086210585896, 0.40102145230052944`, 0.93868226872404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 296}], {
             RGBColor[
             0.26330595896968834`, 0.39408163581213873`, 0.9383062568858402]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 314}], {
             RGBColor[
             0.25716282410855407`, 0.38762481157584006`, 0.9379564144434523]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 319}], {
             RGBColor[
             0.3675065660796395, 0.49023117564208835`, 0.944730223137449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 352}], {
             RGBColor[
             0.2606268889022622, 0.3912657633084208, 0.9381536878088295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 250}], {
             RGBColor[
             0.24600820440775967`, 0.3759005990265677, 0.9373211753532731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 344}], {
             RGBColor[
             0.21245918803275743`, 0.3406384556859449, 0.9354106085020388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 354}], {
             RGBColor[
             0.22476081103687653`, 0.35356824143122134`, 0.936111167733503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 356}], {
             RGBColor[
             0.21433034444536764`, 0.34260515971376704`, 0.9355171680916091]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 372}], {
             RGBColor[
             0.2138686325253813, 0.34211987121163484`, 0.9354908742808075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 388}], {
             RGBColor[
             0.22659156217478169`, 0.35549247695348607`, 0.9362154263024531]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 197}], {
             RGBColor[
             0.9295820155952076, 0.9459496447868232, 0.9675642537426303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 225}], {
             RGBColor[
             0.8897813970600477, 0.9149515498158103, 0.9893493380404593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 243}], {
             RGBColor[
             0.9321893579727436, 0.9478941964628581, 0.9631507032012652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 252}], {
             RGBColor[
             0.6322093663988135, 0.7067582685174405, 0.9673012182198607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 300}], {
             RGBColor[
             0.904775992937191, 0.9269078335507821, 0.990779535981055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 337}], {
             RGBColor[
             0.9444496695413749, 0.9543350995105044, 0.7916221237493946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 367}], {
             RGBColor[
             0.6349673392184779, 0.7091470859540894, 0.9674769538091501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 398}], {
             RGBColor[
             0.6604733814795012, 0.7312391377896288, 0.9691021762679148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 197}], {
             RGBColor[
             0.7030008791274289, 0.7649478943931832, 0.947330285544383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 274}], {
             RGBColor[
             0.46738436670940764`, 0.5781669894131862, 0.9513005905019778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 278}], {
             RGBColor[
             0.349928065209785, 0.47283535767355744`, 0.9436893135230188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 300}], {
             RGBColor[
             0.6781948564694122, 0.7459060831571422, 0.9705455677828076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 319}], {
             RGBColor[
             0.4475260102308348, 0.5620450810151163, 0.9497372679364278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 352}], {
             RGBColor[
             0.3406463330534576, 0.4630796686814488, 0.9431607326078082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 232}], {
             RGBColor[
             0.374520452238133, 0.49753308772821003`, 0.9451360369712756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 257}], {
             RGBColor[
             0.38852623515624984`, 0.5109265218154098, 0.9459822530302189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 275}], {
             RGBColor[
             0.34634920232824207`, 0.46792331791250663`, 0.9435317259645368]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 279}], {
             RGBColor[
             0.5630911384213583, 0.6557241290001397, 0.9590606413690353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 285}], {
             RGBColor[
             0.7240735565365042, 0.7787875887954807, 0.7800674551938157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 288}], {
             RGBColor[
             0.3796596294696894, 0.502934688841232, 0.9454287055118813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 399}], {
             RGBColor[
             0.6902620685345601, 0.6570900539452929, 0.6049675909800379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 198}], {
             RGBColor[
             0.30592577418738304`, 0.43475768207038135`, 0.9408842486890967]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 236}], {
             RGBColor[
             0.2546593406268537, 0.3849934917065525, 0.9378138447627414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 262}], {
             RGBColor[
             0.23634740435871976`, 0.36574648564492557`, 0.9367710070823533]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 267}], {
             RGBColor[
             0.25726504669656514`, 0.3877322539971262, 0.9379622358686148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 284}], {
             RGBColor[
             0.2675710150211928, 0.3985644801424423, 0.9385491455183885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 286}], {
             RGBColor[
             0.22669434503393948`, 0.3556005082552706, 0.9362212796342286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 332}], {
             RGBColor[
             0.2434440031568898, 0.373205460932154, 0.937175147885432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 367}], {
             RGBColor[
             0.31681274319178854`, 0.44418742742702483`, 0.9415779567270888]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 398}], {
             RGBColor[
             0.3423187854528118, 0.46627947926256413`, 0.9432031791858535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 191}], {
             RGBColor[
             0.2010737277844803, 0.3286716150851321, 0.9347622233841785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 211}], {
             RGBColor[
             0.20840661341018846`, 0.33637894280955327`, 0.9351798203725303]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 214}], {
             RGBColor[
             0.21733436721625865`, 0.34576257811201794`, 0.9356882427443579]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 305}], {
             RGBColor[
             0.18857843384879308`, 0.3155382689113313, 0.9340506348796719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 334}], {
             RGBColor[
             0.18995231521735206`, 0.3169823053387968, 0.934128875391136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 340}], {
             RGBColor[
             0.19892920598511726`, 0.3264175867034662, 0.9346400960402405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 365}], {
             RGBColor[
             0.1879270858801807, 0.3148536608984732, 0.9340135415764423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 370}], {
             RGBColor[
             0.19100569805155482`, 0.318089477485873, 0.9341888639852036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 256}], {
             RGBColor[
             0.34992025301800456`, 0.4775050684860661, 0.9435175869933449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 281}], {
             RGBColor[
             0.38860982761707186`, 0.5110160334092172, 0.94598285247495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 311}], {
             RGBColor[
             0.32563786800336725`, 0.45591796242171545`, 0.9419906534014555]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 386}], {
             RGBColor[
             0.5546461678159978, 0.6446668165900299, 0.9601091386691207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 238}], {
             RGBColor[
             0.31998454354214334`, 0.4498414183193987, 0.9416736311656848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 246}], {
             RGBColor[
             0.63511612996041, 0.7084027410096546, 0.967888425757446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 269}], {
             RGBColor[
             0.546784204528102, 0.6385867943130678, 0.9592993736008182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 272}], {
             RGBColor[
             0.5454600938051113, 0.6375523889526532, 0.9591673986184688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 280}], {
             RGBColor[
             0.30076148412422865`, 0.4296367640588081, 0.9405789063698025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 309}], {
             RGBColor[
             0.3237917248354433, 0.45384300724789295`, 0.9418904445081182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 325}], {
             RGBColor[
             0.3195630144976964, 0.44939836456720006`, 0.9416496257101998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 339}], {
             RGBColor[
             0.30076734139659483`, 0.42964292042343744`, 0.9405792399327987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 395}], {
             RGBColor[
             0.40931291362813915`, 0.5285320070026871, 0.9474169765556877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 343}], {
             RGBColor[
             0.18256566753029357`, 0.30921847027918486`, 0.933708216732924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 356}], {
             RGBColor[
             0.18905111217950674`, 0.3160350838064485, 0.9340775532113412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 369}], {
             RGBColor[
             0.1868540625349533, 0.3137258453290297, 0.9339524344843275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 372}], {
             RGBColor[
             0.18858940025952037`, 0.31554979530431626`, 0.9340512594005395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 198}], {
             RGBColor[
             0.3764542800383526, 0.5004875090521163, 0.9452083117319626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 205}], {
             RGBColor[
             0.3748090292582385, 0.49906247551909, 0.9451034778070919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 208}], {
             RGBColor[
             0.6963078073762952, 0.755957556681333, 0.8560508247348155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 210}], {
             RGBColor[
             0.35262704416750634`, 0.4795636552057607, 0.9437005295213796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 219}], {
             RGBColor[
             0.36836286362019555`, 0.4934791308371227, 0.9446927338327562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 249}], {
             RGBColor[
             0.35433837255967027`, 0.48133182157191207`, 0.9437991056637501]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 284}], {
             RGBColor[
             0.33809952087216233`, 0.4642943071241772, 0.9428732085612545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 293}], {
             RGBColor[
             0.374247320413842, 0.49857595155038115`, 0.9450676862162266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 338}], {
             RGBColor[
             0.3169003211264983, 0.4420126040845884, 0.9416659454971446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 188}], {
             RGBColor[
             0.20431810644449144`, 0.33208166276229184`, 0.934946985949238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 228}], {
             RGBColor[
             0.20522346006975262`, 0.3330332468251766, 0.934998544498846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 238}], {
             RGBColor[
             0.24841689496046435`, 0.37843228551726205`, 0.9374583467169113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 273}], {
             RGBColor[
             0.19433831903215518`, 0.3215922734368583, 0.9343786518198778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 322}], {
             RGBColor[
             0.20337835674212623`, 0.3310939262415335, 0.9348934685939234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 330}], {
             RGBColor[
             0.19639093276449526`, 0.3237497006127751, 0.9344955451353647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 206}], {
             RGBColor[
             0.5826167692195937, 0.6701866792756657, 0.9613440852325792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 220}], {
             RGBColor[
             0.5353714211663698, 0.63317812373389, 0.9567035702854296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 261}], {
             RGBColor[
             0.3474451829775207, 0.4708516166188276, 0.9435249988507737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 321}], {
             RGBColor[
             0.494640933100008, 0.6001112786340405, 0.9534971170641517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 228}], {
             RGBColor[
             0.20268995802939208`, 0.3303703755474506, 0.9348542653056278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 238}], {
             RGBColor[
             0.2458833929201038, 0.375769414239536, 0.9373140675236933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 273}], {
             RGBColor[
             0.19180481699179464`, 0.3189294021591323, 0.9342343726266598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 322}], {
             RGBColor[
             0.20084485470176572`, 0.3284310549638075, 0.9347491894007052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 330}], {
             RGBColor[
             0.19385743072413472`, 0.32108682933504906`, 0.9343512659421467]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 222}], {
             RGBColor[
             0.24951462814212214`, 0.379586072691488, 0.937520860997656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 226}], {
             RGBColor[
             0.35594179006458193`, 0.47882793285764735`, 0.9440438043992346]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 395}], {
             RGBColor[
             0.3676410779096787, 0.4885452690238077, 0.9449042144225828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 212}], {
             RGBColor[
             0.6867778683351773, 0.7513832913392242, 0.9534033725466657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 221}], {
             RGBColor[
             0.9292638455200164, 0.8080779972178733, 0.5995947563336426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 255}], {
             RGBColor[
             0.8756473687829154, 0.5041621789431939, 0.4406614321632898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 268}], {
             RGBColor[
             0.8177911045280821, 0.8581558703042615, 0.9638348308947651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 270}], {
             RGBColor[
             0.6576592800193992, 0.7261622336829004, 0.951547961847741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 274}], {
             RGBColor[
             0.7246489008143902, 0.7831056857849257, 0.9561147753018562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 295}], {
             RGBColor[
             0.6926270864337125, 0.7564495900659256, 0.953776079551644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 324}], {
             RGBColor[
             0.7946744730052755, 0.8399555999055638, 0.9616274448568455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 351}], {
             RGBColor[
             0.9330043693197932, 0.948887212220239, 0.9751255904637988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 211}], {
             RGBColor[
             0.2145566630341047, 0.342843034899957, 0.9355300566004294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 214}], {
             RGBColor[
             0.2234844168401749, 0.3522266702024217, 0.9360384789722569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 312}], {
             RGBColor[
             0.25506639270437426`, 0.3854213292486189, 0.9378370257763766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 334}], {
             RGBColor[
             0.1961023648412683, 0.3234463974292005, 0.934479111619035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 340}], {
             RGBColor[
             0.2050792556090335, 0.33288167879387, 0.9349903322681394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 365}], {
             RGBColor[
             0.19407713550409694`, 0.321317752988877, 0.9343637778043414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 370}], {
             RGBColor[
             0.19715574767547106`, 0.3245535695762768, 0.9345391002131025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 292}], {
             RGBColor[
             0.18800332047098128`, 0.31493378828695684`, 0.9340178830236096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 320}], {
             RGBColor[
             0.18870690253434044`, 0.31567329764522667`, 0.9340579509812614]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 347}], {
             RGBColor[
             0.18973620095672017`, 0.3167551555484371, 0.9341165680037053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 374}], {
             RGBColor[
             0.18592011737534742`, 0.3127442097507407, 0.933899247689136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 382}], {
             RGBColor[
             0.18175632170203998`, 0.30836779649820095`, 0.9336621256853248]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 384}], {
             RGBColor[
             0.1855895073220066, 0.3123967176227914, 0.933880419935692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 248}], {
             RGBColor[
             0.20247189401375032`, 0.330141176440954, 0.9348418468825339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 305}], {
             RGBColor[
             0.18458905889423072`, 0.311345182893105, 0.933823445877761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 334}], {
             RGBColor[
             0.1859629402627897, 0.3127892193205704, 0.9339016863892251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 360}], {
             RGBColor[
             0.18609708652812662`, 0.31293021555080397`, 0.9339093258205844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 201}], {
             RGBColor[
             0.9717877162352071, 0.9761148093624215, 0.8086618740541351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 208}], {
             RGBColor[
             0.9937734715667986, 0.9910458830658546, 0.7058012226950569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 223}], {
             RGBColor[
             0.9622169086067585, 0.8752522636294204, 0.4543198910461633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 230}], {
             RGBColor[
             0.8766694336459471, 0.421804072640802, 0.32514101008801133`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 242}], {
             RGBColor[
             0.8996928400306943, 0.5987720630349767, 0.3471882500432634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 357}], {
             RGBColor[
             0.9029108820280516, 0.6235073439816599, 0.3502698506941914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 364}], {
             RGBColor[
             0.8766286360480449, 0.42149048442570325`, 0.3251019422621857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 385}], {
             RGBColor[
             0.9944784929138155, 0.9905983795896796, 0.6403962123397537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 387}], {
             RGBColor[
             0.7643288542489235, 0.8116893614464729, 0.8013257295322668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 247}], {
             RGBColor[
             0.1997381438211963, 0.32726783165880646`, 0.9346861638532888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 253}], {
             RGBColor[
             0.1964706167173933, 0.3238334534995253, 0.9345000830186004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 315}], {
             RGBColor[
             0.21034714004508412`, 0.3384185593393235, 0.9352903304936357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 316}], {
             RGBColor[
             0.21810104707830674`, 0.3465684072573414, 0.9357319040283003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 343}], {
             RGBColor[
             0.19193458883998876`, 0.3190658005995948, 0.9342417629414341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 358}], {
             RGBColor[
             0.1963120650172806, 0.3236668056099485, 0.9344910537338352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 359}], {
             RGBColor[
             0.19452611281546262`, 0.321789656609928, 0.9343893463980213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 362}], {
             RGBColor[
             0.1955066853579723, 0.3228203005239958, 0.9344451885536901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 363}], {
             RGBColor[
             0.21087458530257291`, 0.33897293774690507`, 0.9353203677207644]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 369}], {
             RGBColor[
             0.19622298384464848`, 0.3235731756494396, 0.9344859806928376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 372}], {
             RGBColor[
             0.19795832156921558`, 0.32539712562472617`, 0.9345848056090496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 397}], {
             RGBColor[
             0.2073858256728759, 0.33530603017595706`, 0.9351216880210106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 289}], {
             RGBColor[
             0.18795157808443957`, 0.3148794037580448, 0.934014936371242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 317}], {
             RGBColor[
             0.1925447584771704, 0.3197071275752621, 0.9342765111996065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 326}], {
             RGBColor[
             0.19087356510240117`, 0.3179505973785997, 0.9341813392092224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 327}], {
             RGBColor[
             0.19267128104236286`, 0.3198401108132733, 0.9342837164725208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 336}], {
             RGBColor[
             0.18504438325654066`, 0.31182375766712467`, 0.9338493759266024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 376}], {
             RGBColor[
             0.19966869054902864`, 0.32719483186616644`, 0.9346822085921858]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 252}], {
             RGBColor[
             0.6669388623748537, 0.7337127880117662, 0.9450324457252983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 300}], {
             RGBColor[
             0.9395054889132312, 0.9538623530451078, 0.9685107634864926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 205}], {
             RGBColor[
             0.35166297002886326`, 0.47901452236936815`, 0.9436286313802527]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 219}], {
             RGBColor[
             0.34521680439082036`, 0.47343117768740084`, 0.9432178874059169]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 236}], {
             RGBColor[
             0.3020417872484481, 0.43067536553856556`, 0.9406630613787681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 284}], {
             RGBColor[
             0.31495346164278715`, 0.44424635397445533`, 0.9413983621344152]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 332}], {
             RGBColor[
             0.29082644977848415`, 0.41888733476416706`, 0.9400243645014585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 367}], {
             RGBColor[
             0.36419518981338295`, 0.4898693012590379, 0.9444271733431154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 398}], {
             RGBColor[
             0.38970123207440616`, 0.5119613530945772, 0.9460523958018803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 216}], {
             RGBColor[
             0.19310022590756143`, 0.3202909590632723, 0.9343081442480269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 298}], {
             RGBColor[
             0.19174373818706897`, 0.31886520446274574`, 0.9342308942790887]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 299}], {
             RGBColor[
             0.18707599573729403`, 0.31395911119606756`, 0.93396507325188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 306}], {
             RGBColor[
             0.19460108481424115`, 0.32186845693414357`, 0.9343936159424405]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 342}], {
             RGBColor[
             0.18510212262202141`, 0.31188444540113214`, 0.9338526640980489]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 353}], {
             RGBColor[
             0.18825533864421526`, 0.31519867536590085`, 0.9340322350857477]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 361}], {
             RGBColor[
             0.2020628988707439, 0.32971129661386445`, 0.9348185552141937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 393}], {
             RGBColor[
             0.1849265278957996, 0.3116998842105244, 0.9338426642381596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 207}], {
             RGBColor[
             0.1859857863076916, 0.31281323196228517`, 0.9339029874376845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 333}], {
             RGBColor[
             0.18616349406283006`, 0.3130000140802582, 0.9339131076314446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 368}], {
             RGBColor[
             0.18469320535133593`, 0.3114546474227893, 0.9338293768644222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 223}], {
             RGBColor[
             0.9394729571932308, 0.8606549580209606, 0.6167978110210142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 230}], {
             RGBColor[
             0.861506799370262, 0.41207253556849543`, 0.43345962340457855`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 245}], {
             RGBColor[
             0.8622346252859692, 0.4176669244919702, 0.43415659032342135`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 364}], {
             RGBColor[
             0.8614660017723598, 0.4117589473533967, 0.4334205555787529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 385}], {
             RGBColor[
             0.9717345415002878, 0.9760010739812197, 0.8028741323146045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 218}], {
             RGBColor[
             0.2171099632633392, 0.3455267153294672, 0.9356754632712151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 229}], {
             RGBColor[
             0.22512118954774685`, 0.35394702209546336`, 0.9361316907565649]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 260}], {
             RGBColor[
             0.23397057730885262`, 0.3632482897159762, 0.9366356502980638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 307}], {
             RGBColor[
             0.295856931076972, 0.42463269426460054`, 0.9402940731736436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 341}], {
             RGBColor[
             0.2897972028384973, 0.4193840622352309, 0.9399079526486953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 349}], {
             RGBColor[
             0.22267250403179975`, 0.35137329836257414`, 0.9359922417389372]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 366}], {
             RGBColor[
             0.31887937893336776`, 0.4445735814559359, 0.9417610431931018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 232}], {
             RGBColor[
             0.26042493590475796`, 0.3910534979034842, 0.9381421868843842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 257}], {
             RGBColor[
             0.27443071882287484`, 0.40444693199068393`, 0.9389884029433275]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 275}], {
             RGBColor[
             0.232253685994867, 0.3614437280877808, 0.9365378758776455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 280}], {
             RGBColor[
             0.23864655232395315`, 0.36816303593078636`, 0.9369019401576887]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 297}], {
             RGBColor[
             0.2163387830881471, 0.3447161560696932, 0.9356315457010966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 309}], {
             RGBColor[
             0.2616767930351678, 0.3923692791198713, 0.9382134782960043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 322}], {
             RGBColor[
             0.2128310735235297, 0.3410293309156486, 0.935431786830583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 325}], {
             RGBColor[
             0.2574480826974209, 0.38792463643917835`, 0.9379726594980861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 339}], {
             RGBColor[
             0.23865240959631934`, 0.3681691922954158, 0.9369022737206849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 224}], {
             RGBColor[
             0.1864844568543232, 0.3133373663243338, 0.9339313859875982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 276}], {
             RGBColor[
             0.2082458481435212, 0.33620996832117933`, 0.9351706650284246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 290}], {
             RGBColor[
             0.19592590704111568`, 0.32326092909316934`, 0.9344690626083623]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 297}], {
             RGBColor[
             0.2002775476373886, 0.32783477926980176`, 0.9347168821026446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 318}], {
             RGBColor[
             0.1940125074344074, 0.321249824789977, 0.9343600973313813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 345}], {
             RGBColor[
             0.18631088399028722`, 0.3131549302390768, 0.9339215012697695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 219}], {
             RGBColor[
             0.34357155361070624`, 0.4720061441543746, 0.9431130534810463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 284}], {
             RGBColor[
             0.313308210862673, 0.4428213204414291, 0.9412935282095445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 293}], {
             RGBColor[
             0.3494560104043527, 0.47710296486763304`, 0.9434880058645166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 338}], {
             RGBColor[
             0.292109011117009, 0.4205396174018403, 0.9400862651454345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 220}], {
             RGBColor[
             0.6830678662474279, 0.7522369451466808, 0.9691139391554754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 321}], {
             RGBColor[
             0.6423373781810662, 0.7191701000468311, 0.9659074859341975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 328}], {
             RGBColor[
             0.7999219852902167, 0.6448484807342735, 0.5933000289298582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 386}], {
             RGBColor[
             0.7455369138645886, 0.8011383704922057, 0.975271810201597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 254}], {
             RGBColor[
             0.18750231875154622`, 0.3144072037144869, 0.9339893517168534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 333}], {
             RGBColor[
             0.18793493502051017`, 0.3148619108426237, 0.9340139885733725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 230}], {
             RGBColor[
             0.876163969591323, 0.42202658470411747`, 0.3648858558318596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 240}], {
             RGBColor[
             0.8854643741404387, 0.49351356953187997`, 0.37379193373139724`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 242}], {
             RGBColor[
             0.8991873759760702, 0.5989945750982921, 0.3869330957871117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 357}], {
             RGBColor[
             0.9024054179734275, 0.6237298560449753, 0.3900146964380397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 385}], {
             RGBColor[
             0.9937202968318795, 0.9909321476846529, 0.7000134809555262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 387}], {
             RGBColor[
             0.7635706581669874, 0.8120231295414462, 0.8609429981480392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 241}], {
             RGBColor[
             0.2990278699570904, 0.4292148291621499, 0.9404289112980508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 270}], {
             RGBColor[
             0.34697087401529814`, 0.4749504646340207, 0.9433296551713259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 310}], {
             RGBColor[
             0.30722079620017617`, 0.4378261141051596, 0.9408954863272463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 323}], {
             RGBColor[
             0.36676678405368435`, 0.4920966869379023, 0.9445910330541359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 346}], {
             RGBColor[
             0.34295446203942725`, 0.47147165045125694`, 0.9430737329517971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 390}], {
             RGBColor[
             0.2987767120225358, 0.42895084624860025`, 0.9404146082252327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 249}], {
             RGBColor[
             0.3073650774594488, 0.4403600145758346, 0.9408164770263279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 266}], {
             RGBColor[
             0.26920304414348, 0.40027984622658896`, 0.9386420871625321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 293}], {
             RGBColor[
             0.3272740253136205, 0.45760414455430376`, 0.9420850575788042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 315}], {
             RGBColor[
             0.26224986664151034`, 0.39297161581510254`, 0.9382461139900993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 316}], {
             RGBColor[
             0.270003773674733, 0.40112146373312046`, 0.9386876875247638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 387}], {
             RGBColor[
             0.4198898949581986, 0.5356292280658739, 0.9485927029346032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 397}], {
             RGBColor[
             0.25928855226930214`, 0.38985908665173613`, 0.938077471517474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 214}], {
             RGBColor[
             0.23081730246588306`, 0.35993399792684283`, 0.9364560759606089]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 248}], {
             RGBColor[
             0.2199442042179371, 0.34850568227400514`, 0.9358368691006957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 263}], {
             RGBColor[
             0.30692109574993276`, 0.4322308872824815, 0.9410717536469021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 312}], {
             RGBColor[
             0.26239927833008236`, 0.39312865697304, 0.9382546227647286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 334}], {
             RGBColor[
             0.20343525046697647`, 0.3311537251536216, 0.9348967086073869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 340}], {
             RGBColor[
             0.21241214123474167`, 0.34058900651829105`, 0.9354079292564914]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 370}], {
             RGBColor[
             0.20448863330117922`, 0.3322608973006979, 0.9349566972014545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 268}], {
             RGBColor[
             0.5483496579696843, 0.6426701443947892, 0.9582447440009759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 270}], {
             RGBColor[
             0.38821783346100136`, 0.5106765077734281, 0.9459578749539519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 274}], {
             RGBColor[
             0.45520745425599235`, 0.5676199598754534, 0.950524688408067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 295}], {
             RGBColor[
             0.42318563987531466`, 0.5409638641564534, 0.9481859926578549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 310}], {
             RGBColor[
             0.34846775564587945`, 0.473552157244567, 0.9435237061098725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 324}], {
             RGBColor[
             0.5252330264468776, 0.6244698739960914, 0.9560373579630563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 351}], {
             RGBColor[
             0.6635629227613954, 0.7334014863107667, 0.9695355035700097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 373}], {
             RGBColor[
             0.34459378761093823`, 0.4694803712160838, 0.9433030893613046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 390}], {
             RGBColor[
             0.3400236714682391, 0.46467688938800766`, 0.9430428280078589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 227}], {
             RGBColor[
             0.2150440363795939, 0.343355295187321, 0.9355578117914507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 296}], {
             RGBColor[
             0.2337895217777734, 0.3630579888732283, 0.9366253394534165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 308}], {
             RGBColor[
             0.2120594900785835, 0.3402183477937941, 0.9353878462948488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 352}], {
             RGBColor[
             0.23111045171034733`, 0.3602421163695104, 0.9364727703764056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 248}], {
             RGBColor[
             0.22887195802400728`, 0.3578893175764699, 0.9363452914725232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 263}], {
             RGBColor[
             0.315848849556003, 0.4416145225849462, 0.9415801760187297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 312}], {
             RGBColor[
             0.2713270321361526, 0.4025122922755047, 0.9387630451365561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 340}], {
             RGBColor[
             0.22133989504081186`, 0.3499726418207558, 0.9359163516283189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 218}], {
             RGBColor[
             0.18692850160935742`, 0.31380408551593836`, 0.9339566736794921]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 229}], {
             RGBColor[
             0.19493972789376507`, 0.3222243922819345, 0.9344129011648419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 329}], {
             RGBColor[
             0.1867198905000643, 0.313584822013363, 0.9339447935854304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 349}], {
             RGBColor[
             0.192491042377818, 0.3196506685490453, 0.9342734521472142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 231}], {
             RGBColor[
             0.19095180161373265`, 0.3180328289124904, 0.9341857946628023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 235}], {
             RGBColor[
             0.1956123156574894, 0.32293132466613605`, 0.9344512040429815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 298}], {
             RGBColor[
             0.19835416070020614`, 0.3258131776490477, 0.9346073480619681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 313}], {
             RGBColor[
             0.2090389311379428, 0.3370435488326826, 0.9352158299316957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 361}], {
             RGBColor[
             0.20867332138388106`, 0.3366592698001664, 0.9351950089970731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 393}], {
             RGBColor[
             0.19153695040893678`, 0.31864785739682644`, 0.9342191180210391]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 396}], {
             RGBColor[
             0.19963425463605258`, 0.3271586375382656, 0.9346802475178853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 220}], {
             RGBColor[
             0.8144460532518553, 0.851406632354037, 0.7257595325601884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 230}], {
             RGBColor[
             0.8761820738662044, 0.4207616593515645, 0.27209490569893346`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 233}], {
             RGBColor[
             0.9762379710154455, 0.9784153903456743, 0.7203221374649382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 242}], {
             RGBColor[
             0.8992054802509515, 0.5977296497457392, 0.29414214565418556`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 244}], {
             RGBColor[
             0.9739175055905028, 0.9766847910311653, 0.7242500801550553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 264}], {
             RGBColor[
             0.8581806271651595, 0.8856725444548357, 0.7300501263511203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 321}], {
             RGBColor[
             0.7737155651854934, 0.8183397872541874, 0.7225530793389106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 357}], {
             RGBColor[
             0.9024235222483088, 0.6224649306924224, 0.29722374630511356`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 364}], {
             RGBColor[
             0.8761412762683021, 0.4204480711364659, 0.27205583787310783`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 366}], {
             RGBColor[
             0.6937344954214235, 0.7518077736561808, 0.7166986999905727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 229}], {
             RGBColor[
             0.19887179747769093`, 0.3263572467222515, 0.9346368267106708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 260}], {
             RGBColor[
             0.20772118523879674`, 0.3356585143427644, 0.9351407862521698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 329}], {
             RGBColor[
             0.19065196008399016`, 0.31771767645368004`, 0.9341687191312593]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 349}], {
             RGBColor[
             0.19642311196174383`, 0.3237835229893623, 0.9344973776930432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 284}], {
             RGBColor[
             0.3068620452246301, 0.43723797575946177`, 0.9408827842352088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 293}], {
             RGBColor[
             0.34300984476630975`, 0.47151962018566573`, 0.943077261890181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 338}], {
             RGBColor[
             0.28566284547896603`, 0.414956272719873, 0.9396755211710989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 233}], {
             RGBColor[
             0.7976144359577942, 0.8422371475965424, 0.9590360291130758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 244}], {
             RGBColor[
             0.7952939705328516, 0.8405065482820335, 0.9629639718031929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 321}], {
             RGBColor[
             0.5950920301278422, 0.6821615445050555, 0.961266970987048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 341}], {
             RGBColor[
             0.4860287842689018, 0.590440011686344, 0.9535595010943037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 366}], {
             RGBColor[
             0.5151109603637722, 0.615629530907049, 0.9554125916387102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 239}], {
             RGBColor[
             0.8526114029177259, 0.35936467056963683`, 0.1962114217734859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 255}], {
             RGBColor[
             0.8576770558672095, 0.3983014989226451, 0.2010622967587482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 268}], {
             RGBColor[
             0.7908356351545234, 0.6993648502734382, 0.6044361277879526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 324}], {
             RGBColor[
             0.7677190036317167, 0.6811645798747406, 0.602228741750033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 351}], {
             RGBColor[
             0.9060488999462345, 0.7900961921894157, 0.6157268873569864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 400}], {
             RGBColor[
             0.8675551125355545, 0.47422857106757765`, 0.2105215349800247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 333}], {
             RGBColor[
             0.21024933242430197`, 0.33831575732852015`, 0.9352847604943257]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 230}], {
             RGBColor[
             0.8551262609512963, 0.3448308384131614, 0.19723163473259725`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 242}], {
             RGBColor[
             0.8781496673360434, 0.5217988288073361, 0.2192788746878494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 245}], {
             RGBColor[
             0.8558540868670035, 0.35042522733663617`, 0.19792860165144016`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 328}], {
             RGBColor[
             0.8997164529222819, 0.6301219365340252, 0.23765071588506692`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 364}], {
             RGBColor[
             0.855085463353394, 0.3445172501980627, 0.19719256690677167`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 385}], {
             RGBColor[
             0.9621637338718393, 0.8751385282482187, 0.44853214930663265`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 290}], {
             RGBColor[
             0.18877579274929696`, 0.3157457056290379, 0.9340618741770893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 318}], {
             RGBColor[
             0.18686239314258873`, 0.3137346013258456, 0.9339529089001083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 345}], {
             RGBColor[
             0.17916076969846856`, 0.3056397067749454, 0.9335143128384965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 240}], {
             RGBColor[
             0.8493627071457939, 0.4666896772579783, 0.44827431990902944`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 243}], {
             RGBColor[
             0.9271182354136238, 0.9438506209861709, 0.9626670150045318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 337}], {
             RGBColor[
             0.9393785469822551, 0.9502915240338172, 0.7911384355526612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 367}], {
             RGBColor[
             0.6298962166593582, 0.7051035104774022, 0.9669932656124167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 398}], {
             RGBColor[
             0.6554022589203814, 0.7271955623129416, 0.9686184880711814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 234}], {
             RGBColor[
             0.6154815427973135, 0.6962991925345092, 0.964434228392668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 281}], {
             RGBColor[
             0.43696413947427415`, 0.552898107981546, 0.9490639464684518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 350}], {
             RGBColor[
             0.7195454075725961, 0.7758957836327975, 0.8505842343054555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 355}], {
             RGBColor[
             0.6054737407452027, 0.6884810215092875, 0.963436744212341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 392}], {
             RGBColor[
             0.7181621296927883, 0.7753237626808771, 0.8735087285822702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 395}], {
             RGBColor[
             0.45693963376297164`, 0.5697838781949226, 0.9504517090480242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 296}], {
             RGBColor[
             0.22621507415997788`, 0.35509676417920844`, 0.9361939858669741]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 308}], {
             RGBColor[
             0.20448504246078797`, 0.33225712309977423`, 0.9349564927084064]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 352}], {
             RGBColor[
             0.22353600409255178`, 0.3522808916754905, 0.9360414167899633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 375}], {
             RGBColor[
             0.1940331226429612, 0.32127149268124666`, 0.9343612713370109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 238}], {
             RGBColor[
             0.24678874654536498`, 0.3767209983024208, 0.9373656260733012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 273}], {
             RGBColor[
             0.1927101706170558, 0.31988098622201705`, 0.9342859311762677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 330}], {
             RGBColor[
             0.1947627843493959, 0.3220384133979338, 0.9344028244917546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 368}], {
             RGBColor[
             0.19438368850365684`, 0.3216399596279972, 0.9343812355441619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 260}], {
             RGBColor[
             0.21573241152320438`, 0.34407882110876054`, 0.9355970137375196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[
             0.1986631863683978, 0.3261379832196762, 0.934624946616609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 349}], {
             RGBColor[
             0.20443433824615148`, 0.33220382975535845`, 0.934953605178393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 233}], {
             RGBColor[
             0.8649609956701637, 0.4146486695132347, 0.42761257006752507`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 242}], {
             RGBColor[
             0.8292500198369269, 0.22583404667284962`, 0.17564315807000078`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 244}], {
             RGBColor[
             0.863414018720202, 0.41349493663689546`, 0.43023119852760305`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 245}], {
             RGBColor[
             0.8181022296024069, 0.1401472459374997, 0.16496802155179616`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 328}], {
             RGBColor[
             0.8350024631896295, 0.25838385457720503`, 0.18069489331394697`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 357}], {
             RGBColor[
             0.8308590408356056, 0.2382016871461912, 0.17718395839546475`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 364}], {
             RGBColor[
             0.8177179178456022, 0.13719325736821295`, 0.1646000041794619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 385}], {
             RGBColor[
             0.8766339838226677, 0.4217282490533341, 0.32128251559499077`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 235}], {
             RGBColor[
             0.18685346885052345`, 0.3137252213290522, 0.9339524006748775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 298}], {
             RGBColor[
             0.1895953138932402, 0.3166070743119639, 0.934108544693864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 336}], {
             RGBColor[
             0.1812731232878139, 0.3078599243283004, 0.9336346082504626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 393}], {
             RGBColor[
             0.18277810360197083`, 0.30944175405974256`, 0.933720314652935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 396}], {
             RGBColor[
             0.19087540782908663`, 0.31795253420118175`, 0.9341814441497811]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 257}], {
             RGBColor[
             0.30909861267997385`, 0.4408850865059202, 0.9409626882119364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 275}], {
             RGBColor[
             0.2669215798519661, 0.39788188260301705`, 0.9385121611462544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 279}], {
             RGBColor[
             0.48366351594508233`, 0.5856826936906501, 0.9540410765507529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 280}], {
             RGBColor[
             0.2733144461810522, 0.4046011904460226, 0.9388762254262976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 288}], {
             RGBColor[
             0.30023200699341346`, 0.43289325353174246`, 0.9404091406935988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 297}], {
             RGBColor[
             0.25100667694524614`, 0.38115431058492943`, 0.9376058309697055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 309}], {
             RGBColor[
             0.2963446868922668, 0.42880743363510754`, 0.9401877635646132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 325}], {
             RGBColor[
             0.29211597655452004`, 0.4243627909544146, 0.9399469447666949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 339}], {
             RGBColor[
             0.2733203034534184, 0.404607346810652, 0.9388765589892938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 242}], {
             RGBColor[
             0.8879844020549108, 0.5916166599074094, 0.4496598100227772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 244}], {
             RGBColor[
             0.9570858882964418, 0.9675153062736708, 0.9575265767079428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 264}], {
             RGBColor[
             0.8413490098710985, 0.8765030596973409, 0.9633266229040078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 307}], {
             RGBColor[
             0.6538804302709667, 0.7226974017073509, 0.9485082265240019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 348}], {
             RGBColor[
             0.6462730001834412, 0.7161082281260901, 0.948023487805811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 357}], {
             RGBColor[
             0.8912024440522681, 0.6163519408540925, 0.4527414106737052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 366}], {
             RGBColor[
             0.6769028781273625, 0.7426382888986862, 0.9499751965434602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[
             0.8137495240944908, 0.42044629252070553`, 0.4425717899514292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 246}], {
             RGBColor[
             0.8529840469746812, 0.885887262707637, 0.9857660876177745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 269}], {
             RGBColor[
             0.7646521215423732, 0.8160713160110501, 0.9771770354611466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 272}], {
             RGBColor[
             0.7633280108193825, 0.8150369106506357, 0.9770450604787972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 350}], {
             RGBColor[
             0.8897866044520348, 0.9121284341385445, 0.8654271636734474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 355}], {
             RGBColor[
             0.7757149376246414, 0.8247136720150343, 0.978279673580333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 392}], {
             RGBColor[
             0.888403326572227, 0.9115564131866241, 0.8883516579502622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 395}], {
             RGBColor[
             0.6271808306424103, 0.7060165287006694, 0.9652946384160161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 298}], {
             RGBColor[
             0.19425582793699694`, 0.3215055700656095, 0.9343739540740432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 313}], {
             RGBColor[
             0.2049405983747336, 0.3327359412492443, 0.9349824359437711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 317}], {
             RGBColor[
             0.19343401255220036`, 0.32064178999008336`, 0.934327152903646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 336}], {
             RGBColor[
             0.18593363733157064`, 0.312758420081946, 0.9339000176306419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 393}], {
             RGBColor[
             0.18743861764572758`, 0.31434024981338815`, 0.9339857240331143]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 396}], {
             RGBColor[
             0.19553592187284338`, 0.32285102995482734`, 0.9344468535299604]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 267}], {
             RGBColor[
             0.25338105975763014`, 0.38364993746531034`, 0.9377410485582862]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 284}], {
             RGBColor[
             0.26368702808225786`, 0.3944821636106265, 0.9383279582080599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 286}], {
             RGBColor[
             0.22281035809500455`, 0.3515181917234548, 0.9360000923239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 332}], {
             RGBColor[
             0.2395600162179548, 0.36912314440033817`, 0.9369539605751034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 367}], {
             RGBColor[
             0.3129287562528536, 0.440105110895209, 0.9413567694167602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 383}], {
             RGBColor[
             0.22956462143722656`, 0.3586173507411603, 0.9363847376292023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 398}], {
             RGBColor[
             0.3384347985138768, 0.4621971627307483, 0.9429819918755249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 251}], {
             RGBColor[
             0.19380336074719554`, 0.32102999836105145`, 0.9343481867369493]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 296}], {
             RGBColor[
             0.2211466738327187, 0.34976955408011773`, 0.935905347966363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 308}], {
             RGBColor[
             0.19941664213352878`, 0.3269299130006835, 0.9346678548077954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 380}], {
             RGBColor[
             0.20872851353399335`, 0.33671728024931885`, 0.9351981521083725]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 269}], {
             RGBColor[
             0.5167818424220354, 0.6108654129881752, 0.9574511707265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 272}], {
             RGBColor[
             0.5154577316990447, 0.6098310076277607, 0.9573191957441505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 280}], {
             RGBColor[
             0.2707591220181621, 0.40191538273391547`, 0.9387307034954844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 309}], {
             RGBColor[
             0.29378936272937667`, 0.4261216259230004, 0.9400422416338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 325}], {
             RGBColor[
             0.28956065239162987`, 0.42167698324230746`, 0.9398014228358818]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 339}], {
             RGBColor[
             0.27076497929052823`, 0.4019215390985449, 0.9387310370584805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 246}], {
             RGBColor[
             0.8585903956264433, 0.4560165722989594, 0.4468977431895056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 269}], {
             RGBColor[
             0.799702445338238, 0.4094726078345682, 0.44117170841842035`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 272}], {
             RGBColor[
             0.7988197048562442, 0.4087830042609585, 0.441083725096854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 350}], {
             RGBColor[
             0.8831254339446791, 0.4735106865862311, 0.3666717938932875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 355}], {
             RGBColor[
             0.8070776560597501, 0.415234178503891, 0.4419068004978779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 392}], {
             RGBColor[
             0.8822032486914739, 0.47312933928495077`, 0.3819547900778306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 242}], {
             RGBColor[
             0.8385504243860425, 0.29732103150061207`, 0.18454923596953843`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 243}], {
             RGBColor[
             0.877634681087591, 0.48865144168934355`, 0.43080856334956663`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 285}], {
             RGBColor[
             0.8858589617650177, 0.49305390399602456`, 0.3219788728271452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 337}], {
             RGBColor[
             0.8858082221333453, 0.4929453770544411, 0.3164561770483195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 357}], {
             RGBColor[
             0.8401594453847212, 0.3096886719739536, 0.1860900362950024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 399}], {
             RGBColor[
             0.8633179697637215, 0.41192221409589935`, 0.20524563001796006`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 270}], {
             RGBColor[
             0.31115624108701556`, 0.43971981464523346`, 0.9412017203817521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 310}], {
             RGBColor[
             0.2714061632718937, 0.40259546411637237`, 0.9387675515376726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 323}], {
             RGBColor[
             0.3309521511254019, 0.4568660369491151, 0.9424630982645621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 346}], {
             RGBColor[
             0.30713982911114474`, 0.4362410004624697, 0.9409457981622233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 389}], {
             RGBColor[
             0.23293094482355622`, 0.362155570057423, 0.9365764447660246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 390}], {
             RGBColor[
             0.2629620790942533, 0.393720196259813, 0.938286673435659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 244}], {
             RGBColor[
             0.886437425104949, 0.5904629270310702, 0.4522784384828552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 357}], {
             RGBColor[
             0.8538824472203527, 0.4151696775403659, 0.1992311983507169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 364}], {
             RGBColor[
             0.8407413242303493, 0.31416124776238763`, 0.18664724413471406`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 385}], {
             RGBColor[
             0.8996573902074148, 0.5986962394475088, 0.343329755550243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 337}], {
             RGBColor[
             0.981786507894951, 0.983234170680865, 0.764939800713467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 367}], {
             RGBColor[
             0.6723041775720541, 0.7380461571244501, 0.9407946307732227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 398}], {
             RGBColor[
             0.6978102198330773, 0.7601382089599893, 0.9424198532319874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 264}], {
             RGBColor[
             0.8390285444461558, 0.8747724603828321, 0.9672545655941249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 307}], {
             RGBColor[
             0.651559964846024, 0.7209668023928419, 0.952436169214119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 321}], {
             RGBColor[
             0.7545634824664897, 0.8074397031821838, 0.959757518581915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 341}], {
             RGBColor[
             0.6455002366075493, 0.7157181703634723, 0.9520500486891706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 348}], {
             RGBColor[
             0.6439525347584986, 0.7143776288115813, 0.9519514304959281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 357}], {
             RGBColor[
             0.8896554671023064, 0.6151982079777534, 0.4553600391337833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 366}], {
             RGBColor[
             0.6745824127024198, 0.7409076895841773, 0.9539031392335773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 328}], {
             RGBColor[
             0.8357302891053365, 0.26397824350067983`, 0.18139186023278991`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 364}], {
             RGBColor[
             0.8184457437613093, 0.14278764629168772`, 0.16529697109830485`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 400}], {
             RGBColor[
             0.829279530588777, 0.22606087924326346`, 0.17567141759930008`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 269}], {
             RGBColor[
             0.8319134288403021, 0.869426735678431, 0.9836659653182612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 272}], {
             RGBColor[
             0.8305893181173114, 0.8683923303180165, 0.9835339903359117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 350}], {
             RGBColor[
             0.9570479117499637, 0.9654838538059254, 0.8719160935305621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 355}], {
             RGBColor[
             0.8429762449225704, 0.8780690916824152, 0.9847686034374477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 392}], {
             RGBColor[
             0.955664633870156, 0.964911832854005, 0.8948405878073766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 395}], {
             RGBColor[
             0.6944421379403393, 0.7593719483680503, 0.9717835682731306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 253}], {
             RGBColor[
             0.19436046466415727`, 0.3216155499002067, 0.9343799129808589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 266}], {
             RGBColor[
             0.21519016549381775`, 0.3435088861514912, 0.9355661336283271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 301}], {
             RGBColor[
             0.1901623548072361, 0.317203070265044, 0.9341408368350541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 315}], {
             RGBColor[
             0.2082369879918481, 0.3362006557400048, 0.9351701604558942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 316}], {
             RGBColor[
             0.21599089502507074`, 0.3443505036580227, 0.9356117339905587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 343}], {
             RGBColor[
             0.18982443678675276`, 0.31684789700027605`, 0.9341215929036926]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 358}], {
             RGBColor[
             0.19420191296404457`, 0.3214489020106298, 0.9343708836960937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 359}], {
             RGBColor[
             0.1924159607622266, 0.31957175301060936`, 0.9342691763602797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 362}], {
             RGBColor[
             0.19339653330473627`, 0.32060239692467707`, 0.9343250185159485]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 363}], {
             RGBColor[
             0.20876443324933688`, 0.3367550341475864, 0.9352001976830229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 369}], {
             RGBColor[
             0.19411283179141248`, 0.32135527205012093`, 0.934365810655096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 397}], {
             RGBColor[
             0.20527567361963986`, 0.3330881265766384, 0.935001517983269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 276}], {
             RGBColor[
             0.22042799245848094`, 0.3490141743887628, 0.9358644201252941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 340}], {
             RGBColor[
             0.2104667967928659, 0.33854432616791813`, 0.9352971447684058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 360}], {
             RGBColor[
             0.20162405229043762`, 0.3292500410334822, 0.9347935635506606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 266}], {
             RGBColor[
             0.270914372535644, 0.40204801259274037`, 0.9387406633049027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 293}], {
             RGBColor[
             0.3289853537057845, 0.45937231092045516`, 0.9421836337211749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 315}], {
             RGBColor[
             0.2639611950336743, 0.39473978218125394`, 0.9383446901324698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 316}], {
             RGBColor[
             0.271715102066897, 0.4028896300992718, 0.9387862636671344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 387}], {
             RGBColor[
             0.4216012233503626, 0.5373973944320252, 0.9486912790769737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 397}], {
             RGBColor[
             0.26099988066146607`, 0.3916272530178875, 0.9381760476598446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 356}], {
             RGBColor[
             0.22666963106636354`, 0.3555745323083922, 0.9362198722103361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 363}], {
             RGBColor[
             0.2391241828797345, 0.3686650559284389, 0.9369291405112493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 372}], {
             RGBColor[
             0.22620791914637717`, 0.35508924380626006`, 0.9361935783995345]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 283}], {
             RGBColor[
             0.19962713488925782`, 0.32715115423296626`, 0.934679842058838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 308}], {
             RGBColor[
             0.1958872147734443, 0.3232202610666153, 0.9344668591409584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 380}], {
             RGBColor[
             0.20519908617390886`, 0.3330076283152506, 0.9349971564415356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 381}], {
             RGBColor[
             0.19321867549075944`, 0.3204154570853507, 0.9343148897765596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 282}], {
             RGBColor[
             0.31835440977210794`, 0.4463178036126423, 0.941647079240882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 300}], {
             RGBColor[
             0.6421328397168371, 0.7146709767757251, 0.9682477279637229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 367}], {
             RGBColor[
             0.372324185998124, 0.4969102291790325, 0.9449451457918181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 398}], {
             RGBColor[
             0.39783022825914727`, 0.5190022810145718, 0.9465703682505828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 266}], {
             RGBColor[
             0.21192263839001468`, 0.3400745079922101, 0.9353800527936387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 301}], {
             RGBColor[
             0.18689482770343305`, 0.31376869210576286`, 0.9339547560003658]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 315}], {
             RGBColor[
             0.20496946088804507`, 0.3327662775807237, 0.9349840796212059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 316}], {
             RGBColor[
             0.2127233679212677, 0.3409161254987416, 0.9354256531558705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 343}], {
             RGBColor[
             0.18655690968294972`, 0.31341351884099494`, 0.9339355120690042]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 358}], {
             RGBColor[
             0.19093438586024153`, 0.31801452385134865`, 0.9341848028614053]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 359}], {
             RGBColor[
             0.18914843365842357`, 0.3161373748513282, 0.9340830955255912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 362}], {
             RGBColor[
             0.19012900620093326`, 0.31716801876539596`, 0.9341389376812601]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 369}], {
             RGBColor[
             0.19084530468760944`, 0.3179208938908398, 0.9341797298204076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 394}], {
             RGBColor[
             0.1857625991924869, 0.31257864815332465`, 0.9338902772616493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 397}], {
             RGBColor[
             0.20200814651583682`, 0.3296537484173573, 0.9348154371485806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 303}], {
             RGBColor[
             0.20024144683233963`, 0.3277968350347721, 0.9347148262152034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 268}], {
             RGBColor[
             0.78336189520592, 0.43168674764690385`, 0.44388901313282986`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 324}], {
             RGBColor[
             0.767950807524049, 0.41955323404777206`, 0.4424174224408835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 328}], {
             RGBColor[
             0.8467511825783175, 0.34868966012032526`, 0.19194548026883534`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 351}], {
             RGBColor[
             0.8601707384003942, 0.4921743089242222, 0.4514161861788524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 400}], {
             RGBColor[
             0.840300424061758, 0.3107722958629089, 0.1862250376353455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 311}], {
             RGBColor[
             0.32702639881790146`, 0.45712063802367703`, 0.942079129357128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 313}], {
             RGBColor[
             0.28483799884386285`, 0.41277795475190926`, 0.9396765623907513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 386}], {
             RGBColor[
             0.556034698630532, 0.6458694921919914, 0.9601976146247932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 275}], {
             RGBColor[
             0.2809273627700829, 0.4112753166902168, 0.9393583772051975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 276}], {
             RGBColor[
             0.27298076036949565`, 0.4029229337235066, 0.9389058299544288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 279}], {
             RGBColor[
             0.4976692988631992, 0.5990761277778498, 0.9548872926096961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 280}], {
             RGBColor[
             0.2873202290991691, 0.41799462453322234`, 0.9397224414852408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 288}], {
             RGBColor[
             0.3142377899115303, 0.4462866876189422, 0.9412553567525421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 309}], {
             RGBColor[
             0.31035046981038367`, 0.4422008677223072, 0.9410339796235565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 325}], {
             RGBColor[
             0.30612175947263687`, 0.43775622504161427`, 0.9407931608256381]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 339}], {
             RGBColor[
             0.2873260863715352, 0.41800078089785175`, 0.939722775048237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 277}], {
             RGBColor[
             0.19561158896014919`, 0.3229305608611562, 0.9344511626586431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 302}], {
             RGBColor[
             0.18739149065206478`, 0.3142907163550246, 0.9339830402205433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 377}], {
             RGBColor[
             0.18407204095648846`, 0.3108017642597073, 0.933794002471066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 378}], {
             RGBColor[
             0.18711323001988966`, 0.3139982467878655, 0.9339671936891907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 379}], {
             RGBColor[
             0.19525485067885182`, 0.32255560630899927`, 0.9344308469412701]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 262}], {
             RGBColor[
             0.20019420515358305`, 0.3277471810351035, 0.934712135871486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 331}], {
             RGBColor[
             0.19269223822101744`, 0.31986213813680114`, 0.934284909952842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 335}], {
             RGBColor[
             0.18286996403264408`, 0.3095383051966678, 0.9337255459685665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 307}], {
             RGBColor[
             0.28646815305242945`, 0.41476449327789777`, 0.9397593961545982]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 329}], {
             RGBColor[
             0.20751257412950358`, 0.3354392508401891, 0.9351289061581081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 341}], {
             RGBColor[
             0.2804084248139549, 0.4095158612485281, 0.93937327562965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 349}], {
             RGBColor[
             0.21328372600725728`, 0.3415050973758713, 0.9354575647198919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 366}], {
             RGBColor[
             0.3094906009088253, 0.4347053804692331, 0.9412263661740565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 306}], {
             RGBColor[
             0.2313412040252819, 0.36048465168304844`, 0.9364859113793738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 284}], {
             RGBColor[
             0.24537509181412387`, 0.37523515754899955`, 0.9372851205276718]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 286}], {
             RGBColor[
             0.20449842182687056`, 0.3322711856618279, 0.9349572546435119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 331}], {
             RGBColor[
             0.20664951421908523`, 0.3345321201531805, 0.9350797561729924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 332}], {
             RGBColor[
             0.22124807994982085`, 0.34987613833871123`, 0.9359111228947152]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 338}], {
             RGBColor[
             0.22417589206845978`, 0.35295345450941085`, 0.9360778574635618]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 264}], {
             RGBColor[
             0.5576221544304325, 0.6488358128735436, 0.9596252327476064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 312}], {
             RGBColor[
             0.3474308254202023, 0.4748091816311434, 0.9433787228228494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 348}], {
             RGBColor[
             0.36254614474277536`, 0.48844098130229274`, 0.9443220976494096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 307}], {
             RGBColor[
             0.5358230864206805, 0.6299545558165122, 0.958236215410184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 312}], {
             RGBColor[
             0.5131003370105822, 0.6097335825641022, 0.9568081018654329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 348}], {
             RGBColor[
             0.5282156563331551, 0.6233653822352514, 0.957751476691993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 357}], {
             RGBColor[
             0.8124975481520774, 0.5545233769268668, 0.45922673659782653`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 366}], {
             RGBColor[
             0.5588455342770764, 0.6498954430078475, 0.9597031854296422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 291}], {
             RGBColor[
             0.18857894058274138`, 0.31553880152083974`, 0.9340506637374206]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 304}], {
             RGBColor[
             0.18543662898340038`, 0.31223603279586976`, 0.9338717137404716]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 378}], {
             RGBColor[
             0.19040066183963522`, 0.31745354606563403`, 0.9341544080680056]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 383}], {
             RGBColor[
             0.1991683094404495, 0.3266688995950551, 0.9346537126282998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 293}], {
             RGBColor[
             0.2908233203898157, 0.4192921425712095, 0.940009243857379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 315}], {
             RGBColor[
             0.22579916171770553`, 0.3546596138320083, 0.9361703002686741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 316}], {
             RGBColor[
             0.23355306875092818`, 0.36280946175002615`, 0.9366118738033387]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 338}], {
             RGBColor[
             0.23347632110247196`, 0.3627287951054168, 0.936607503138297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 397}], {
             RGBColor[
             0.22283784734549728`, 0.3515470846686418, 0.9360016577960488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 282}], {
             RGBColor[
             0.2615646860965489, 0.39225144761939246`, 0.9382070939716974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 332}], {
             RGBColor[
             0.24216572228766625`, 0.37186190669091185`, 0.9371023516809767]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 367}], {
             RGBColor[
             0.315534462322565, 0.44284387318578267`, 0.9415051605226336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 383}], {
             RGBColor[
             0.23217032750693795`, 0.361356113031734, 0.9365331287350758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 398}], {
             RGBColor[
             0.34104050458358826`, 0.46493592502132197`, 0.9431303829813984]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 270}], {
             RGBColor[
             0.5192310696539062, 0.6174490867384653, 0.9563893333020512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 274}], {
             RGBColor[
             0.5862206904488971, 0.6743925388404906, 0.9609561467561663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 295}], {
             RGBColor[
             0.5541988760682194, 0.6477364431214906, 0.9586174510059542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 324}], {
             RGBColor[
             0.6562462626397825, 0.7312424529611288, 0.9664688163111557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 351}], {
             RGBColor[
             0.7945761589543001, 0.8401740652758038, 0.979966961918109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 373}], {
             RGBColor[
             0.475607023803843, 0.5762529501811211, 0.9537345477094038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 272}], {
             RGBColor[
             0.7422573926850033, 0.7985763836214297, 0.9749449381792838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 350}], {
             RGBColor[
             0.8687159863176557, 0.8956679071093385, 0.8633270413739342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 355}], {
             RGBColor[
             0.7546443194902623, 0.8082531449858283, 0.9761795512808198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 392}], {
             RGBColor[
             0.8673327084378479, 0.8950958861574181, 0.8862515356507488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 395}], {
             RGBColor[
             0.6061102125080312, 0.6895560016714635, 0.9631945161165028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 295}], {
             RGBColor[
             0.3940670515595366, 0.5157428065001295, 0.9463305819589302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 310}], {
             RGBColor[
             0.3193491673301014, 0.4483310995882432, 0.9416682954109477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 324}], {
             RGBColor[
             0.49611443813109957`, 0.5992488163397677, 0.9541819472641316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 346}], {
             RGBColor[
             0.3550828331693524, 0.4819766359343405, 0.9438465420354984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 351}], {
             RGBColor[
             0.6344443344456173, 0.7081804286544429, 0.9676800928710849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 373}], {
             RGBColor[
             0.31547519929516016`, 0.44425931355976, 0.9414476786623798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 390}], {
             RGBColor[
             0.310905083152461, 0.4394558317316838, 0.9411874173089341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 287}], {
             RGBColor[
             0.18451611233351262`, 0.31126851143271117`, 0.9338192916790429]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 292}], {
             RGBColor[
             0.18674265418407987`, 0.3136087480885643, 0.9339460899435592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 371}], {
             RGBColor[
             0.1828236944867615, 0.3094896729702865, 0.9337229109863782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 374}], {
             RGBColor[
             0.184659451088446, 0.3114191695523481, 0.9338274546090857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 382}], {
             RGBColor[
             0.18049565541513857`, 0.3070427562998084, 0.9335903326052744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 384}], {
             RGBColor[
             0.18432884103510522`, 0.31107167742439884`, 0.9338086268556416]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 389}], {
             RGBColor[
             0.19087423447573804`, 0.31795130093241747`, 0.9341813773290437]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 391}], {
             RGBColor[
             0.1801133509320429, 0.3066409300485706, 0.9335685609305309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 350}], {
             RGBColor[
             0.867391875594665, 0.894633501748924, 0.8631950663915847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 392}], {
             RGBColor[
             0.8660085977148573, 0.8940614807970035, 0.8861195606683994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 395}], {
             RGBColor[
             0.6047861017850406, 0.688521596311049, 0.9630625411341533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 322}], {
             RGBColor[
             0.19086506728942945`, 0.31794166563837395`, 0.9341808552713451]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 330}], {
             RGBColor[
             0.18387764331179846`, 0.31059744000961553`, 0.9337829318127865]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 295}], {
             RGBColor[
             0.4610566723545275, 0.5726862586021548, 0.9508973954130453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 296}], {
             RGBColor[
             0.36901952314668135`, 0.4870709060931353, 0.9452488023460986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 319}], {
             RGBColor[
             0.47322013025663245`, 0.583220445923085, 0.9516727685977074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 324}], {
             RGBColor[
             0.5631040589260905, 0.6561922684417929, 0.9587487607182468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 351}], {
             RGBColor[
             0.7014339552406084, 0.7651238807564681, 0.9722469063252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 373}], {
             RGBColor[
             0.38246482009015115`, 0.5012027656617852, 0.9460144921164949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 276}], {
             RGBColor[
             0.2308037275414878, 0.35991972982060355`, 0.9364553028887468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 280}], {
             RGBColor[
             0.24514319627116127`, 0.3749914206303192, 0.9372719144195587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 288}], {
             RGBColor[
             0.2720607570835225, 0.40328348371603906`, 0.9388048296868601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 290}], {
             RGBColor[
             0.21848378643908228`, 0.34697069059259356`, 0.9357537004686844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 297}], {
             RGBColor[
             0.22283542703535522`, 0.35154454076922603`, 0.9360015199629668]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 318}], {
             RGBColor[
             0.21657038683237403`, 0.3449595862894012, 0.9356447351917034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 325}], {
             RGBColor[
             0.2639447266446291, 0.3947530211387112, 0.9383426337599561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 339}], {
             RGBColor[
             0.24514905354352745`, 0.3749975769949486, 0.9372722479825549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 288}], {
             RGBColor[
             0.2641141546829352, 0.39493110074932897`, 0.9383522824360913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 290}], {
             RGBColor[
             0.21053718403849497`, 0.33861830762588346`, 0.9353011532179156]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 297}], {
             RGBColor[
             0.21488882463476794`, 0.3431921578025159, 0.9355489727121981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 318}], {
             RGBColor[
             0.20862378443178675`, 0.3366072033226911, 0.9351921879409346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 278}], {
             RGBColor[
             0.23299059780069237`, 0.3622182691186103, 0.9365798419148239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 302}], {
             RGBColor[
             0.19959521355734036`, 0.32711760288919167`, 0.9346780241862087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 314}], {
             RGBColor[
             0.22024480085065679`, 0.34882162839392095`, 0.9358539876342362]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 352}], {
             RGBColor[
             0.22370886564436498`, 0.3524625801265016, 0.9360512609996132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 378}], {
             RGBColor[
             0.19931695292516527`, 0.3268251333220326, 0.934662177654856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 379}], {
             RGBColor[
             0.2074585735841274, 0.33538249284316635`, 0.9351258309069355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 314}], {
             RGBColor[
             0.2454200867859244, 0.3752824501172079, 0.9372876829247517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 319}], {
             RGBColor[
             0.35576382875700985`, 0.4778888141834562, 0.9440614916187484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 352}], {
             RGBColor[
             0.24888415157963256`, 0.37892340184978857`, 0.9374849562901288]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 379}], {
             RGBColor[
             0.232633859519395, 0.36184331456645336`, 0.936559526197451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.8332166202434534, 0.8669371947579207, 0.788972494773293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 288}], {
             RGBColor[
             0.4888026931766387, 0.5910842948036721, 0.9543337450913586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 309}], {
             RGBColor[
             0.48491537307549215`, 0.5869984749070372, 0.9541123679623731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 325}], {
             RGBColor[
             0.4806866627377453, 0.5825538322263442, 0.9538715491644547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 399}], {
             RGBColor[
             0.7994051322415094, 0.7452396599077329, 0.6138726305595152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 297}], {
             RGBColor[
             0.22922829336444137`, 0.3582638486122316, 0.9363655842430101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 309}], {
             RGBColor[
             0.27456630331146203`, 0.4059169716624097, 0.9389475168379178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 322}], {
             RGBColor[
             0.22572058379982396`, 0.354577023458187, 0.9361658253724963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 325}], {
             RGBColor[
             0.2703375929737152, 0.4014723289817168, 0.9387066980399994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 339}], {
             RGBColor[
             0.2515419198726136, 0.3817168848379542, 0.9376363122625981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 355}], {
             RGBColor[
             0.5971975343016019, 0.6813125874620714, 0.9629093916561169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 386}], {
             RGBColor[
             0.5947242732295994, 0.6793804571151425, 0.9626628801063983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 367}], {
             RGBColor[
             0.3211123825917724, 0.44870662104929115`, 0.9418228148301714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 383}], {
             RGBColor[
             0.23774824777614534`, 0.3672188608952424, 0.9368507830426136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 398}], {
             RGBColor[
             0.3466184248527956, 0.47079867288483046`, 0.9434480372889362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 294}], {
             RGBColor[
             0.19947004944091673`, 0.32698604746696713`, 0.934670896274942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 320}], {
             RGBColor[
             0.20238649627655553`, 0.330051418004633, 0.9348369836077353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 347}], {
             RGBColor[
             0.20341579469893528`, 0.33113327590784336`, 0.9348956006301792]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 373}], {
             RGBColor[
             0.2404157449182508, 0.3700225695206825, 0.937002693058648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 380}], {
             RGBColor[
             0.2145522876760556, 0.34283843612123366`, 0.9355298074302612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 381}], {
             RGBColor[
             0.20257187699290616`, 0.3302462648913338, 0.9348475407652852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 332}], {
             RGBColor[
             0.2524716906122939, 0.382694132836228, 0.9376892613307504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 338}], {
             RGBColor[
             0.2553995027309328, 0.3857714490069275, 0.9378559958995971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 367}], {
             RGBColor[
             0.3258404306471927, 0.4536760993310988, 0.9420920701724073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 399}], {
             RGBColor[
             0.9603875503566552, 0.868303119703074, 0.4348794443842956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 332}], {
             RGBColor[
             0.2115950206250406, 0.3397301609490563, 0.9353613954465905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 292}], {
             RGBColor[
             0.19215895018442095`, 0.31930161859792383`, 0.9342545399880867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 371}], {
             RGBColor[
             0.18823999048710255`, 0.315182543479646, 0.9340313610309057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 374}], {
             RGBColor[
             0.19007574708878708`, 0.31711204006170757`, 0.9341359046536132]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 382}], {
             RGBColor[
             0.18591195141547964`, 0.3127356268091679, 0.933898782649802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 384}], {
             RGBColor[
             0.18974513703544627`, 0.3167645479337583, 0.9341170769001692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 389}], {
             RGBColor[
             0.19629053047607914`, 0.32364417144177693`, 0.9344898273735713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 391}], {
             RGBColor[
             0.18552964693238397`, 0.31233380055793014`, 0.9338770109750585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 303}], {
             RGBColor[
             0.19970158242580874`, 0.32722940331412775`, 0.9346840817359092]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 376}], {
             RGBColor[
             0.19788479388924796`, 0.32531984337115605`, 0.93458061831645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 297}], {
             RGBColor[
             0.20256888353236238`, 0.33024311857450594`, 0.9348473702921356]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 318}], {
             RGBColor[
             0.1963038433293812, 0.3236581640946811, 0.9344905855208723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 345}], {
             RGBColor[
             0.18860221988526102`, 0.31556326954378094`, 0.9340519894592605]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 304}], {
             RGBColor[
             0.1840328398717771, 0.3107605614341833, 0.9337917700272845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 383}], {
             RGBColor[
             0.1977645203288262, 0.3251934282333686, 0.9345737689151127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 371}], {
             RGBColor[
             0.1904665323376698, 0.31752278013549917`, 0.934158159295422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 374}], {
             RGBColor[
             0.19230228893935433`, 0.31945227671756077`, 0.9342627029181295]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 382}], {
             RGBColor[
             0.1881384932660469, 0.31507586346502103`, 0.9340255809143183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 384}], {
             RGBColor[
             0.19197167888601352`, 0.3191047845896115, 0.9342438751646855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 389}], {
             RGBColor[
             0.1985170723266464, 0.32598440809763013`, 0.9346166256380877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 316}], {
             RGBColor[
             0.2916240499210687, 0.42013376007774095`, 0.9400548442196108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 387}], {
             RGBColor[
             0.4415101712045343, 0.5546415244104943, 0.9499598596294503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 320}], {
             RGBColor[
             0.19287620932606772`, 0.32005550343265077`, 0.9342953868351136]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 347}], {
             RGBColor[
             0.19390550774844745`, 0.3211373613358611, 0.9343540038575576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 380}], {
             RGBColor[
             0.20504200072556777`, 0.3328425215492514, 0.9349882106576397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 381}], {
             RGBColor[
             0.19306159004241835`, 0.32025035031935156`, 0.9343059439926636]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 310}], {
             RGBColor[
             0.3543169737444146, 0.4786184559712684, 0.9438964131148506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 324}], {
             RGBColor[
             0.5310822445454129, 0.6295361727227928, 0.9564100649680346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 351}], {
             RGBColor[
             0.6694121408599306, 0.7384677850374681, 0.9699082105749879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 373}], {
             RGBColor[
             0.3504430057094734, 0.4745466699427852, 0.9436757963662827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 390}], {
             RGBColor[
             0.34587288956677426`, 0.46974318811470905`, 0.943415535012837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 308}], {
             RGBColor[
             0.22323052785896746`, 0.35195981678568156`, 0.9360240203703722]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 373}], {
             RGBColor[
             0.25840585650162723`, 0.38893131743376574`, 0.9380272032993362]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 380}], {
             RGBColor[
             0.23254239925943204`, 0.3617471840343169, 0.9365543176709494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 318}], {
             RGBColor[
             0.20065548392565413`, 0.32823201427131354`, 0.9347384050151546]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 322}], {
             RGBColor[
             0.2034128145640179, 0.33113014359709375`, 0.9348954309159043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 339}], {
             RGBColor[
             0.22923415063680755`, 0.358270004976861, 0.9363659178060062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 313}], {
             RGBColor[
             0.20768244341745035`, 0.33561779423215604`, 0.9351385799627575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 361}], {
             RGBColor[
             0.2073168336633886, 0.33523351519963984`, 0.9351177590281349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 393}], {
             RGBColor[
             0.19018046268844432`, 0.31722210279629987`, 0.9341418680521008]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 396}], {
             RGBColor[
             0.19827776691556012`, 0.32573288293773905`, 0.9346029975489469]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 306}], {
             RGBColor[
             0.19518727715711093`, 0.32248458225324084`, 0.9344269987291731]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 342}], {
             RGBColor[
             0.18568831496489116`, 0.3125005707202294, 0.9338860468847814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 353}], {
             RGBColor[
             0.188841530987085, 0.3158148006849981, 0.9340656178724803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 319}], {
             RGBColor[
             0.6840306200166372, 0.7509595396670409, 0.9709177458785374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 343}], {
             RGBColor[
             0.18235879982602854`, 0.30900103920583233`, 0.9336964359231994]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 358}], {
             RGBColor[
             0.18673627600332035`, 0.31360204421618604`, 0.9339457267156006]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 359}], {
             RGBColor[
             0.1849503238015024, 0.31172489521616553`, 0.9338440193797866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 362}], {
             RGBColor[
             0.18593089634401205`, 0.31275553913023335`, 0.9338998615354555]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 369}], {
             RGBColor[
             0.18664719483068826`, 0.31350841425567716`, 0.9339406536746029]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 394}], {
             RGBColor[
             0.18156448933556574`, 0.30816616851816203`, 0.9336512011158447]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 397}], {
             RGBColor[
             0.19781003665891564`, 0.3252412687821946, 0.934576361002776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 314}], {
             RGBColor[
             0.21202470254257239`, 0.3401817838877893, 0.9353858651961364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 352}], {
             RGBColor[
             0.21548876733628058`, 0.34382273562037, 0.9355831385615135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 377}], {
             RGBColor[
             0.18805566555367964`, 0.3149888062877428, 0.9340208639986316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 379}], {
             RGBColor[
             0.199238475276043, 0.32674264833703476`, 0.9346577084688357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 376}], {
             RGBColor[
             0.21141869489039777`, 0.33954483142224945`, 0.9353513539568531]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 383}], {
             RGBColor[
             0.1946222087294852, 0.32189065950839857`, 0.9343948189181637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 334}], {
             RGBColor[
             0.18360707090558112`, 0.31031305125539965`, 0.9337675231145284]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 340}], {
             RGBColor[
             0.19258396167334632`, 0.31974833262006913`, 0.9342787437636328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 360}], {
             RGBColor[
             0.18374121717091801`, 0.3104540474856332, 0.9337751625458877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 370}], {
             RGBColor[
             0.18466045373978385`, 0.311420223402476, 0.9338275117085959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 342}], {
             RGBColor[
             0.1932134040418383, 0.3204099164583054, 0.934314589575342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 353}], {
             RGBColor[
             0.19636662006403216`, 0.3237241464230741, 0.9344941605630408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 361}], {
             RGBColor[
             0.21017418029056079`, 0.33823676767103766`, 0.9352804806914867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 312}], {
             RGBColor[
             0.32563175741045036`, 0.45592792457411196`, 0.9419897054854269]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 341}], {
             RGBColor[
             0.3422947785820742, 0.4709002657971524, 0.9430316985052297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 348}], {
             RGBColor[
             0.3407470767330234, 0.4695597242452613, 0.9429330803119872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 366}], {
             RGBColor[
             0.37137695467694465`, 0.4960897850178574, 0.9448847890496364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 325}], {
             RGBColor[
             0.2933678336849298, 0.42567857217080163`, 0.9400182361783151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 339}], {
             RGBColor[
             0.27457216058382816`, 0.4059231280270391, 0.9389478504009139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 323}], {
             RGBColor[
             0.33914507736848765`, 0.46547732189212476`, 0.9429296732937578]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 324}], {
             RGBColor[
             0.45636436031597766`, 0.5621244658109066, 0.9517477784200521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 346}], {
             RGBColor[
             0.31533275535423055`, 0.4448522854054794, 0.9414123731914188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 389}], {
             RGBColor[
             0.24112387106664201`, 0.3707668550004327, 0.9370430197952202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 390}], {
             RGBColor[
             0.27115500533733905`, 0.4023314812028227, 0.9387532484648545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 313}], {
             RGBColor[
             0.2605556138292256, 0.39119084868755866`, 0.938149628798862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 361}], {
             RGBColor[
             0.2601900040751639, 0.39080656965504246`, 0.9381288078642394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 386}], {
             RGBColor[
             0.5317523136158948, 0.6242823861276408, 0.958670681032904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 348}], {
             RGBColor[
             0.31802432732292496`, 0.44933875099285125`, 0.9415049667672362]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 366}], {
             RGBColor[
             0.3486542052668462, 0.4758688117654473, 0.9434566755048852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 361}], {
             RGBColor[
             0.2180016041011253, 0.34646388638327474`, 0.9357262408978626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 393}], {
             RGBColor[
             0.200865233126181, 0.3284524739799347, 0.9347503499218286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 396}], {
             RGBColor[
             0.20896253735329678`, 0.3369632541213739, 0.9352114794186747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 352}], {
             RGBColor[
             0.23613835462959704`, 0.3655267611250992, 0.9367591020095412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 379}], {
             RGBColor[
             0.21988806256935944`, 0.348446673841764, 0.9358336719168633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 316}], {
             RGBColor[
             0.22659989124895852`, 0.3555012313385397, 0.9362159006309058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 358}], {
             RGBColor[
             0.20481090918793238`, 0.33259962969114687`, 0.9349750503364407]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 359}], {
             RGBColor[
             0.2030249569861144, 0.33072248069112636`, 0.9348733430006266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 362}], {
             RGBColor[
             0.20400552952862408`, 0.3317531246051941, 0.9349291851562955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 363}], {
             RGBColor[
             0.2193734294732247, 0.3479057618281034, 0.9358043643233698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 369}], {
             RGBColor[
             0.20472182801530026`, 0.332505999730638, 0.934969977295443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 397}], {
             RGBColor[
             0.21588466984352767`, 0.3442388542571554, 0.935605684623616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 358}], {
             RGBColor[
             0.212564816221155, 0.34074947760916474`, 0.9354166238711052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 359}], {
             RGBColor[
             0.21077886401933704`, 0.3388723286091443, 0.9353149165352912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 362}], {
             RGBColor[
             0.2117594365618467, 0.339902972523212, 0.9353707586909601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 363}], {
             RGBColor[
             0.2271273365064473, 0.3560556097461213, 0.9362459378580343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 369}], {
             RGBColor[
             0.2124757350485229, 0.34065584764865586`, 0.9354115508301075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 397}], {
             RGBColor[
             0.2236385768767503, 0.3523887021751733, 0.9360472581582806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 326}], {
             RGBColor[
             0.19368284883535128`, 0.3209033327008066, 0.9343413237618512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 327}], {
             RGBColor[
             0.19548056477531295`, 0.3227928461354802, 0.9344437010251496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 336}], {
             RGBColor[
             0.1878536669894908, 0.3147764929893316, 0.9340093604792311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 396}], {
             RGBColor[
             0.19745595153076353`, 0.32486910286221293`, 0.9345561963785496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 345}], {
             RGBColor[
             0.18668882027855277`, 0.3135521652405886, 0.9339430241822795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 347}], {
             RGBColor[
             0.1968219545840863, 0.324202731873527, 0.9345200911903508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 380}], {
             RGBColor[
             0.20795844756120663`, 0.3359078920869173, 0.9351542979904328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 381}], {
             RGBColor[
             0.19597803687805715`, 0.32331572085701743`, 0.9344720313254569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 384}], {
             RGBColor[
             0.1926752609493727, 0.31984429394788133`, 0.9342839431223373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 341}], {
             RGBColor[
             0.44529829620254, 0.5573731665864943, 0.9503530478730258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 366}], {
             RGBColor[
             0.4743804722974104, 0.5825626858071993, 0.9522061384174323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 330}], {
             RGBColor[
             0.19291768102176954`, 0.3200990928142907, 0.934297748586832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 339}], {
             RGBColor[
             0.22572644107219014`, 0.3545831798228164, 0.9361661589354925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 346}], {
             RGBColor[
             0.37487874320773873`, 0.4991228582382221, 0.9451079199183084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 346}], {
             RGBColor[
             0.4920980261552287, 0.5957700021570038, 0.9539260250446029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 351}], {
             RGBColor[
             0.7714595274314936, 0.8219737948771062, 0.9777595758801894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 390}], {
             RGBColor[
             0.4479202761383373, 0.5532491979543472, 0.9512669003180385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 339}], {
             RGBColor[
             0.2703434502460814, 0.40147848534634617`, 0.9387070316029955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 327}], {
             RGBColor[
             0.19380937140054372`, 0.3210363159388178, 0.9343485290347655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 336}], {
             RGBColor[
             0.18618247361472157`, 0.3130199627926692, 0.9339141884888471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 336}], {
             RGBColor[
             0.18798018955468324`, 0.3149094762273428, 0.9340165657521455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 376}], {
             RGBColor[
             0.2026044968471712, 0.33028055042638454`, 0.9348493984177288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 364}], {
             RGBColor[
             0.8349616655917271, 0.2580702663621064, 0.18065582548812142`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 386}], {
             RGBColor[
             0.8151456848541535, 0.6567413505380229, 0.5948173850288303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 400}], {
             RGBColor[
             0.8566292392466625, 0.42461673226525787`, 0.20140471849011185`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 349}], {
             RGBColor[
             0.19621450085245074`, 0.32356425948678696`, 0.9344854975989814]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 335}], {
             RGBColor[
             0.18932527309814626`, 0.31632324431474484`, 0.9340931662700729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 338}], {
             RGBColor[
             0.2166739251358942, 0.34506841161110846`, 0.9356506315449178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 368}], {
             RGBColor[
             0.18664235406415453`, 0.3135033263031278, 0.9339403780001101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 340}], {
             RGBColor[
             0.1939578430419053, 0.32119236904753456`, 0.934356984275097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 360}], {
             RGBColor[
             0.185115098539477, 0.3118980839130987, 0.9338534030573518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 365}], {
             RGBColor[
             0.18295572293696874`, 0.30962844324254163`, 0.933730429811299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 370}], {
             RGBColor[
             0.18603433510834283`, 0.3128642598299414, 0.93390575222006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 394}], {
             RGBColor[
             0.17996762986719622`, 0.30648776797016763`, 0.9335602623314629]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 396}], {
             RGBColor[
             0.18995557631013382`, 0.31698573295407556`, 0.9341290611055455]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 367}], {
             RGBColor[
             0.6845644891406854, 0.7444870601720963, 0.7692660513213518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 398}], {
             RGBColor[
             0.7100705314017086, 0.7665791120076357, 0.7708912737801167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 399}], {
             RGBColor[
             0.9603114409091467, 0.8681403292906987, 0.42659540071605706`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 360}], {
             RGBColor[
             0.1940919893072422, 0.3213333652777681, 0.9343646237064562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 370}], {
             RGBColor[
             0.19501122587610803`, 0.3222995411946109, 0.9344169728691645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 348}], {
             RGBColor[
             0.33468734849454873`, 0.4643110922158917, 0.9425469597870388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 366}], {
             RGBColor[
             0.36531722643847, 0.49084115298848774`, 0.9444986685246879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 353}], {
             RGBColor[
             0.1868676578718124, 0.31374013489006275`, 0.9339532087186491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 358}], {
             RGBColor[
             0.18639835798283702`, 0.3132468709514181, 0.933926482784239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 359}], {
             RGBColor[
             0.18461240578101906`, 0.3113697219513976, 0.933824775448425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 362}], {
             RGBColor[
             0.18559297832352872`, 0.3124003658654654, 0.9338806176040938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 369}], {
             RGBColor[
             0.18630927681020493`, 0.31315324099090924`, 0.9339214097432413]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 354}], {
             RGBColor[
             0.2035510812828702, 0.3312754706852238, 0.9349033050009957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 356}], {
             RGBColor[
             0.19312061469136133`, 0.3203123889677695, 0.9343093053591018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 388}], {
             RGBColor[
             0.20538183242077535`, 0.3331997062074885, 0.9350075635699459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 390}], {
             RGBColor[
             0.30688867117659013`, 0.43597701754892004`, 0.9409314950894052]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 380}], {
             RGBColor[
             0.20898774598358635`, 0.3369897499901277, 0.9352129150128767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 381}], {
             RGBColor[
             0.1970073353004369, 0.3243975787602278, 0.9345306483479008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 384}], {
             RGBColor[
             0.19370455937175246`, 0.32092615185109175`, 0.9343425601447813]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 366}], {
             RGBColor[
             0.3637695245894192, 0.4895006114365967, 0.9444000503314454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 355}], {
             RGBColor[
             0.879778802399924, 0.9043102631133229, 0.8644296794931206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 392}], {
             RGBColor[
             0.9924671913475096, 0.9911530042849124, 0.7745016638630496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 395}], {
             RGBColor[
             0.7312446954176929, 0.785613119798958, 0.8514446443288036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 379}], {
             RGBColor[
             0.22335212736306764`, 0.3520876255743447, 0.9360309452822404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 371}], {
             RGBColor[
             0.20120013846367035`, 0.3288044807238608, 0.9347694222853504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 388}], {
             RGBColor[
             0.21768345542489445`, 0.346129491952765, 0.93570812280141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 392}], {
             RGBColor[
             0.8783955245201162, 0.9037382421614023, 0.8873541737699352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 395}], {
             RGBColor[
             0.6171730285902994, 0.6981983576754478, 0.9642971542356892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 363}], {
             RGBColor[
             0.2074463229173425, 0.3353696166156383, 0.9351251332495853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 372}], {
             RGBColor[
             0.1945300591839852, 0.3217938044934594, 0.9343895711378705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 364}], {
             RGBColor[
             0.8439593662277066, 0.3388965287090708, 0.18972884478564203`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 385}], {
             RGBColor[
             0.9028754322047721, 0.6234315203941919, 0.3464113562011709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 359}], {
             RGBColor[
             0.18898988195831087`, 0.3159707269617513, 0.934074066240826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 362}], {
             RGBColor[
             0.18997045450082056`, 0.31700137087581914`, 0.9341299083964949]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 363}], {
             RGBColor[
             0.20533835444542115`, 0.3331540080987284, 0.9350050875635693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 369}], {
             RGBColor[
             0.19068675298749674`, 0.31775424600126295`, 0.9341707005356424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 372}], {
             RGBColor[
             0.19242209071206384`, 0.3195781959765495, 0.9342695254518545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 397}], {
             RGBColor[
             0.20184959481572412`, 0.3294871005277804, 0.9348064078638154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 362}], {
             RGBColor[
             0.18818450229900258`, 0.31512422187579864`, 0.9340282010606809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 369}], {
             RGBColor[
             0.18890080078567878`, 0.31587709700124245`, 0.9340689931998285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 394}], {
             RGBColor[
             0.18381809529055626`, 0.3105348512637273, 0.9337795406410702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 397}], {
             RGBColor[
             0.20006364261390616`, 0.32760995152775996`, 0.9347047005280014]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 370}], {
             RGBColor[
             0.18616848137367975`, 0.313005256060175, 0.9339133916514194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 393}], {
             RGBColor[
             0.20049962337211924`, 0.32806819494741857`, 0.934729528987206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 396}], {
             RGBColor[
             0.20859692759923504`, 0.3365789750888577, 0.935190658484052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 363}], {
             RGBColor[
             0.20453297478611288`, 0.3323075030127757, 0.9349592223834241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 369}], {
             RGBColor[
             0.18988137332818844`, 0.31690774091531027`, 0.9341248353554973]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 397}], {
             RGBColor[
             0.20104421515641585`, 0.32864059544182767`, 0.9347605426836703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 369}], {
             RGBColor[
             0.20524927327278905`, 0.33306037813821954`, 0.9350000145225716]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 372}], {
             RGBColor[
             0.20698461099735616`, 0.3348843281135061, 0.9350988394387836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 385}], {
             RGBColor[
             0.8765931862247653, 0.4214146608382354, 0.32124344776916525`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 370}], {
             RGBColor[
             0.18400910577117147`, 0.3107356153896179, 0.9337904184053665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 398}], {
             RGBColor[
             0.40058820107881166`, 0.5213910984512207, 0.9467461038398723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 372}], {
             RGBColor[
             0.19233300953943172`, 0.31948456601604064`, 0.9342644524108568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 389}], {
             RGBColor[
             0.194598112629328, 0.3218653329793524, 0.9343934466809067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 391}], {
             RGBColor[
             0.18383722908563283`, 0.3105549620955055, 0.9337806302823939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 380}], {
             RGBColor[
             0.24598769620290184`, 0.37587904360296687`, 0.9373200074413457]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 382}], {
             RGBColor[
             0.18605529017041303`, 0.3128862849288049, 0.9339069455798448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 384}], {
             RGBColor[
             0.18988847579037965`, 0.3169152060533953, 0.934125239830212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 389}], {
             RGBColor[
             0.19643386923101253`, 0.3237948295614139, 0.9344979903036141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 377}], {
             RGBColor[
             0.18266643619111367`, 0.3093243845308089, 0.9337139553590839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 379}], {
             RGBColor[
             0.19896021464386793`, 0.3264501787698757, 0.934641861937483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 381}], {
             RGBColor[
             0.20814382827755723`, 0.3361027389736181, 0.9351648551479828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 384}], {
             RGBColor[
             0.18572468011707222`, 0.3125387928008556, 0.9338881178264007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 389}], {
             RGBColor[
             0.1922700735577051, 0.31941841630887424`, 0.9342608682998029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 389}], {
             RGBColor[
             0.1961032591776717, 0.32344733743346465`, 0.93447916255017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 387}], {
             RGBColor[
             0.7642756795140044, 0.8115756260652711, 0.7955379877927361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 400}], {
             RGBColor[
             0.8203725249629105, 0.5288099921038794, 0.4560525726712711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 390}], {
             RGBColor[
             0.23267978688900162`, 0.3618915871438733, 0.9365621416932066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 395}], {
             RGBColor[
             0.729861417537885, 0.7850410988470374, 0.8743691386056183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 396}], {
             RGBColor[
             0.19146055662429076`, 0.3185675626855177, 0.9342147675080179]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.08420038484809576], {
             RGBColor[
             0.19354678877808446`, 0.32076032495391327`, 0.9343335753428726]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.08420038484809576], {
             RGBColor[
             0.18498575182454155`, 0.3117621323146461, 0.9338460369532876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.08420038484809576], {
             RGBColor[
             0.5818688834669836, 0.6714263983498019, 0.960225996443923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.08420038484809576], {
             RGBColor[
             0.23281884209063286`, 0.36203774297739677`, 0.9365700606812258]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.08420038484809576], {
             RGBColor[
             0.2824395297681887, 0.41419223185981874`, 0.9393958854372335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.08420038484809576], {
             RGBColor[
             0.30558851701585305`, 0.4385232851876776, 0.9407141860151303]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.08420038484809576], {
             RGBColor[
             0.4486453266434888, 0.5630157651939816, 0.9498082613856059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.08420038484809576], {
             RGBColor[
             0.2378122641398246, 0.36728614615234123`, 0.9368544286798214]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.08420038484809576], {
             RGBColor[
             0.19103464530579026`, 0.3181199028854364, 0.9341905124885087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.08420038484809576], {
             RGBColor[
             0.23750097993416716`, 0.3669589667156367, 0.9368367015048129]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.08420038484809576], {
             RGBColor[
             0.31196467996522614`, 0.44462985881031997`, 0.9410990914412173]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.08420038484809576], {
             RGBColor[
             0.3084761160714523, 0.441558334879467, 0.9408786305095267]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.08420038484809576], {
             RGBColor[
             0.21416269395992185`, 0.3424289484239088, 0.9355076206444797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.08420038484809576], {
             RGBColor[
             0.18454901891679482`, 0.31130309833813863`, 0.9338211656602798]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.08420038484809576], {
             RGBColor[
             0.28582560720535155`, 0.41775121393598635`, 0.9395887175380273]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.08420038484809576], {
             RGBColor[
             0.3177755060429437, 0.4496629042982282, 0.9414693521405777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.08420038484809576], {
             RGBColor[
             0.2316763474093035, 0.360836908628973, 0.9365049972992935]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.08420038484809576], {
             RGBColor[
             0.6051402883638863, 0.6903191732099512, 0.9620580066833722]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.08420038484809576], {
             RGBColor[
             0.26040419361571815`, 0.3910316964425663, 0.9381410056417089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.08420038484809576], {
             RGBColor[
             0.19028821830363388`, 0.31733536077996466`, 0.9341480045749757]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.08420038484809576], {
             RGBColor[
             0.9632021039744041, 0.8875341975281088, 0.3115475519504825]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.08420038484809576], {
             RGBColor[
             0.3162753653274515, 0.4483635578097335, 0.9413737645007089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.08420038484809576], {
             RGBColor[
             0.2930562064900811, 0.4253510322307103, 0.9400004894705796]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.08420038484809576], {
             RGBColor[
             0.8207868509580615, 0.16078242208563953`, 0.1675388179938171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.08420038484809576], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.08420038484809576], {
             RGBColor[
             0.18699939157323073`, 0.3138785953626525, 0.9339607107580624]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.08420038484809576], {
             RGBColor[
             0.821038236612611, 0.16271468238440395`, 0.16777954518051325`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.08420038484809576], {
             RGBColor[
             0.20698871416859752`, 0.3348886408066369, 0.9350990731083157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.08420038484809576], {
             RGBColor[
             0.1814383294461641, 0.30803356647540187`, 0.9336440164967801]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.08420038484809576], {
             RGBColor[
             0.18021067351487519`, 0.3067432222537355, 0.9335741033076473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.08420038484809576], {
             RGBColor[
             0.19647646719475834`, 0.3238396027221777, 0.9345004161946314]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.08420038484809576], {
             RGBColor[
             0.9570322462930174, 0.8667218188173162, 0.28757881993815293`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.08420038484809576], {
             RGBColor[
             0.2765417318743941, 0.4079932723314563, 0.939060014572192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.08420038484809576], {
             RGBColor[
             0.2632481201845229, 0.3940208435817391, 0.93830296305259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.08420038484809576], {
             RGBColor[
             0.2362515342121432, 0.36564572004235524`, 0.9367655474193329]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.08420038484809576], {
             RGBColor[
             0.19287789451893317`, 0.32005727467719974`, 0.9342954828043544]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.08420038484809576], {
             RGBColor[
             0.34879862256835453`, 0.4765335685653648, 0.9434461176929121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.08420038484809576], {
             RGBColor[
             0.22292982485851465`, 0.3516437588665342, 0.9360068957793466]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.08420038484809576], {
             RGBColor[
             0.18317563345981333`, 0.30985958314518375`, 0.9337429533902465]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.08420038484809576], {
             RGBColor[
             0.5210599224495296, 0.6220589443833571, 0.9554388922820652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.08420038484809576], {
             RGBColor[
             0.8718710063158469, 0.90067029040099, 0.9876410289824828]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.08420038484809576], {
             RGBColor[
             0.21651396498896067`, 0.34490028335462225`, 0.9356415220511897]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.08420038484809576], {
             RGBColor[
             0.26035980612556775`, 0.3909850423760888, 0.9381384778398102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.08420038484809576], {
             RGBColor[
             0.2366745638317519, 0.36609035099419096`, 0.9367896383303533]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.08420038484809576], {
             RGBColor[
             0.2848093981590889, 0.41668311379698936`, 0.9395308459361892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.08420038484809576], {
             RGBColor[
             0.20129344185623907`, 0.3289025485052273, 0.9347747357755273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.08420038484809576], {
             RGBColor[
             0.5441036538714303, 0.6407668836599264, 0.9572529792315668]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.08420038484809576], {
             RGBColor[
             0.24018804114120323`, 0.3697832384137522, 0.9369897256654027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.08420038484809576], {
             RGBColor[
             0.18767785554878408`, 0.3145917040180597, 0.9339993482777726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.08420038484809576], {
             RGBColor[
             0.1790362447681438, 0.3055088231778375, 0.9335072213279326]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.08420038484809576], {
             RGBColor[
             0.381577964086101, 0.5049253866504279, 0.9455347883487892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.08420038484809576], {
             RGBColor[
             0.17936539842637753`, 0.30585478454218845`, 0.9335259661418299]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.08420038484809576], {
             RGBColor[
             0.19239706134193654`, 0.319551888521592, 0.9342681000662533]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.08420038484809576], {
             RGBColor[
             0.1846123721443362, 0.31136968659711123`, 0.9338247735328656]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.08420038484809576], {
             RGBColor[
             0.9716313250190438, 0.9159679393868991, 0.3442934839840799]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.08420038484809576], {
             RGBColor[
             0.38165040818030865`, 0.5049881340836845, 0.9455394044224124]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.08420038484809576], {
             RGBColor[
             0.21768082531414856`, 0.3461267275396124, 0.9357079730204939]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.08420038484809576], {
             RGBColor[
             0.21195870855243037`, 0.3401124200198894, 0.9353821069360272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.08420038484809576], {
             RGBColor[
             0.3465121371910148, 0.4745531298536097, 0.9433004248665277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.08420038484809576], {
             RGBColor[
             0.186004909472108, 0.3128333316205655, 0.9339040764736078]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.08420038484809576], {
             RGBColor[
             0.20936457771848743`, 0.3373858240360207, 0.9352343750227069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.08420038484809576], {
             RGBColor[
             0.20110579749352597`, 0.32870532238267614`, 0.9347640497066657]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.08420038484809576], {
             RGBColor[
             0.1811814280726413, 0.30776354684334156`, 0.9336293863436095]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.08420038484809576], {
             RGBColor[
             0.18064334912177313`, 0.30719799174980317`, 0.933598743543374]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.08420038484809576], {
             RGBColor[
             0.2879462259501837, 0.4199801186917991, 0.9397094836383711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.08420038484809576], {
             RGBColor[
             0.2142707962291993, 0.34254257076299915`, 0.935513776908792]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.08420038484809576], {
             RGBColor[
             0.42522253205912725`, 0.5427281177888938, 0.9483157816266544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.08420038484809576], {
             RGBColor[
             0.27002626100566185`, 0.40114509934370585`, 0.9386889681449931]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.08420038484809576], {
             RGBColor[
             0.2418162773238607, 0.37149461787786187`, 0.9370824513072455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.08420038484809576], {
             RGBColor[
             0.22291581655962178`, 0.35162903525622036`, 0.9360060980274482]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.08420038484809576], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.08420038484809576], {
             RGBColor[
             0.18281412095909713`, 0.3094796105857146, 0.9337223657881405]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.08420038484809576], {
             RGBColor[
             0.9306153171117766, 0.762619883962795, 0.26302965936154776`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.08420038484809576], {
             RGBColor[
             0.8630600513163033, 0.8936446740513561, 0.986800632228994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.08420038484809576], {
             RGBColor[
             0.21796667840296896`, 0.34642717726009525`, 0.9357242519310205]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.08420038484809576], {
             RGBColor[
             0.1938965482594379, 0.32112794434484765`, 0.9343534936279129]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.08420038484809576], {
             RGBColor[
             0.18280925758947733`, 0.30947449887588874`, 0.9337220888264354]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.08420038484809576], {
             RGBColor[
             0.8199375785531087, 0.1542545422276314, 0.1667255537797183]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.08420038484809576], {
             RGBColor[
             0.23104392871496413`, 0.36017219648356114`, 0.9364689819902305]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.08420038484809576], {
             RGBColor[
             0.1798079986201722, 0.3063199854083397, 0.9335511715680982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.08420038484809576], {
             RGBColor[
             0.17955783501139488`, 0.30605704759422586`, 0.9335369251206622]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.08420038484809576], {
             RGBColor[
             0.1807265568208277, 0.30728544831718235`, 0.9336034820987404]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.08420038484809576], {
             RGBColor[
             0.9450344910434499, 0.9585273939347413, 0.9779264487494559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.08420038484809576], {
             RGBColor[
             0.3388378220394789, 0.4679060237916442, 0.9428114242912021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.08420038484809576], {
             RGBColor[
             0.24074527521724318`, 0.3703689267583512, 0.9370214593216792]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.08420038484809576], {
             RGBColor[
             0.4110226556238299, 0.5304288985271809, 0.947410978056655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.08420038484809576], {
             RGBColor[
             0.19817896485079942`, 0.32562903570326285`, 0.9345973709175234]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.08420038484809576], {
             RGBColor[
             0.19146940577852636`, 0.3185768637076881, 0.9342152714542605]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.08420038484809576], {
             RGBColor[
             0.1892450123424645, 0.31623888517169746`, 0.934088595538772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.08420038484809576], {
             RGBColor[
             0.6083786689975903, 0.6929482364957771, 0.9623129438694364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.08420038484809576], {
             RGBColor[
             0.4932978290383352, 0.5995204262840937, 0.953253358592837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.08420038484809576], {
             RGBColor[
             0.49739045300864126`, 0.6028430027937971, 0.9535755449435551]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.08420038484809576], {
             RGBColor[
             0.2343202347626608, 0.3636158018694917, 0.9366555627727864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.08420038484809576], {
             RGBColor[
             0.18118663655961964`, 0.30776902129339295`, 0.9336296829592377]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.08420038484809576], {
             RGBColor[
             0.559409915392181, 0.6531931963016955, 0.9584579442071637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.08420038484809576], {
             RGBColor[
             0.7481991240396009, 0.803218109314472, 0.9755371544320737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.08420038484809576], {
             RGBColor[
             0.19288958051724012`, 0.32006955740235543`, 0.93429614830467]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.08420038484809576], {
             RGBColor[
             0.20101540430520026`, 0.32861031341048663`, 0.9347589019483153]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.08420038484809576], {
             RGBColor[
             0.965636915117815, 0.9738926480760296, 0.9430519187643377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.08420038484809576], {
             RGBColor[
             0.2101475089071078, 0.33820873435596516`, 0.9352789617956558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.08420038484809576], {
             RGBColor[
             0.1831002535865883, 0.30978035411906424`, 0.9337386606179808]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.08420038484809576], {
             RGBColor[
             0.2774713947406823, 0.40897040694795533`, 0.9391129574971142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.08420038484809576], {
             RGBColor[
             0.19434739415987903`, 0.3216018119714924, 0.9343791686349763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.08420038484809576], {
             RGBColor[
             0.8190091230934095, 0.14711802671260676`, 0.16583646378296987`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.08420038484809576], {
             RGBColor[
             0.20947576509879728`, 0.3375026890224135, 0.9352407069795285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.08420038484809576], {
             RGBColor[
             0.22681870684301533`, 0.35573122040160343`, 0.9362283618552786]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.08420038484809576], {
             RGBColor[
             0.34861868121472545`, 0.4763777124089667, 0.9434346519889747]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.08420038484809576], {
             RGBColor[
             0.256153514960176, 0.38656396366699863`, 0.9378989357805914]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.08420038484809576], {
             RGBColor[
             0.18132254229683142`, 0.30791186684012395`, 0.9336374225899173]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.08420038484809576], {
             RGBColor[
             0.18343408206602244`, 0.3101312290168976, 0.9337576716560296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.08420038484809576], {
             RGBColor[
             0.18925042984728385`, 0.3162445793127523, 0.934088904057657]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.08420038484809576], {
             RGBColor[
             0.937107871400364, 0.788360698201582, 0.2682537209419814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.08420038484809576], {
             RGBColor[
             0.30752560771325343`, 0.4405592903292892, 0.9408245004646784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.08420038484809576], {
             RGBColor[
             0.24129060741956473`, 0.3709421054790498, 0.9370525151838548]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.08420038484809576], {
             RGBColor[
             0.8646080428941941, 0.47809856902505976`, 0.2087379710414105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.08420038484809576], {
             RGBColor[
             0.18333815129494635`, 0.31003039969413443`, 0.9337522085405336]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.08420038484809576], {
             RGBColor[
             0.22614100723621103`, 0.3550189151462153, 0.9361897678652379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.08420038484809576], {
             RGBColor[
             0.2388812891503496, 0.36840975921850344`, 0.93691530807269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.08420038484809576], {
             RGBColor[
             0.18241596627536708`, 0.30906112476864933`, 0.9336996914679191]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.08420038484809576], {
             RGBColor[
             0.5182991743784003, 0.6198176447289311, 0.9552215560809526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.08420038484809576], {
             RGBColor[
             0.3109061797336599, 0.4437130391115059, 0.9410316447424569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.08420038484809576], {
             RGBColor[
             0.5979628209588992, 0.6844921818293608, 0.9614929701573222]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.08420038484809576], {
             RGBColor[
             0.21169783120855037`, 0.3398382213908926, 0.9353672503572267]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.08420038484809576], {
             RGBColor[
             0.3097296345397099, 0.44269397479938727`, 0.9409566763230764]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.08420038484809576], {
             RGBColor[
             0.2615118954900493, 0.3921959613448436, 0.9382040876247539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.08420038484809576], {
             RGBColor[
             0.1865862227024127, 0.3134443286830033, 0.9339371814020978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.08420038484809576], {
             RGBColor[
             0.19480415931956344`, 0.32208190111490453`, 0.9344051807350968]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.08420038484809576], {
             RGBColor[
             0.19461177340916913`, 0.32187969132510885`, 0.9343942246421093]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.08420038484809576], {
             RGBColor[
             0.189088316742455, 0.3160741881610126, 0.9340796719561618]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.08420038484809576], {
             RGBColor[
             0.1820121662584413, 0.30863670534846055`, 0.9336766956543238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.08420038484809576], {
             RGBColor[
             0.21325644631447746`, 0.3414764246891273, 0.9354560111817448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.08420038484809576], {
             RGBColor[
             0.35827341580975897`, 0.4847401582541144, 0.9440498431400237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.08420038484809576], {
             RGBColor[
             0.18578718983175693`, 0.312604494474334, 0.9338916776621772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.08420038484809576], {
             RGBColor[
             0.830968185180272, 0.8680554911049849, 0.9837396813881922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.08420038484809576], {
             RGBColor[
             0.9948422584139026, 0.9913764372120322, 0.679989842123797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.08420038484809576], {
             RGBColor[
             0.18458947116943916`, 0.3113456162204888, 0.9338234693562242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.08420038484809576], {
             RGBColor[
             0.33446348254021346`, 0.46411719077807645`, 0.9425326952463855]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.08420038484809576], {
             RGBColor[
             0.18225239431662393`, 0.3088892002689491, 0.9336903762868517]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.08420038484809576], {
             RGBColor[
             0.18805967833656198`, 0.31499302397697726`, 0.9340210925206803]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.08420038484809576], {
             RGBColor[
             0.2256991535454318, 0.35455449890206425`, 0.9361646049512119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.08420038484809576], {
             RGBColor[
             0.8655975347340893, 0.482591620368333, 0.20956362728728348`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.08420038484809576], {
             RGBColor[
             0.18248883410320854`, 0.3091377134757978, 0.9337038411829164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.08420038484809576], {
             RGBColor[
             0.18504307948317125`, 0.3118223873186494, 0.9338493016786379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.08420038484809576], {
             RGBColor[
             0.1905501321581982, 0.3176106488474093, 0.9341629201815262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.08420038484809576], {
             RGBColor[
             0.1972575262297792, 0.3246605452899877, 0.9345448963512025]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.08420038484809576], {
             RGBColor[
             0.18614238840660097`, 0.3129778306973855, 0.9339119056955454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.08420038484809576], {
             RGBColor[
             0.1834762116557925, 0.31017550988691617`, 0.9337600708738418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.08420038484809576], {
             RGBColor[
             0.33397821749630197`, 0.46369687858717057`, 0.9425017745868906]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.08420038484809576], {
             RGBColor[
             0.21660346779159745`, 0.34499435647499893`, 0.9356466191033923]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.08420038484809576], {
             RGBColor[
             0.19354588592399127`, 0.3207593759970171, 0.9343335239266677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.08420038484809576], {
             RGBColor[
             0.19201931518110454`, 0.3191548533560677, 0.9342465879812193]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.08420038484809576], {
             RGBColor[
             0.25676930210776144`, 0.3872111950022711, 0.9379340039476709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.08420038484809576], {
             RGBColor[
             0.1824446187841665, 0.30909124037207153`, 0.9337013231859077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.08420038484809576], {
             RGBColor[
             0.2055125320888361, 0.33333707984545796`, 0.935015006722689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.08420038484809576], {
             RGBColor[
             0.2070813101039675, 0.3349859650056321, 0.9351043463098516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.08420038484809576], {
             RGBColor[
             0.8309858670902185, 0.23917652931476524`, 0.17730540736011186`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.08420038484809576], {
             RGBColor[
             0.1873941802353717, 0.31429354327760956`, 0.9339831933883338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.08420038484809576], {
             RGBColor[
             0.3387561380668311, 0.4678352732400925, 0.9428062194606953]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.08420038484809576], {
             RGBColor[
             0.1805122222555836, 0.3070601690995145, 0.9335912760623294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.08420038484809576], {
             RGBColor[
             0.4596234812344611, 0.572182073724828, 0.9506023905805157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.08420038484809576], {
             RGBColor[
             0.1994550789542851, 0.32697031253633363`, 0.9346700437278752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.08420038484809576], {
             RGBColor[
             0.27232886945688745`, 0.40356528681975196`, 0.9388200982898864]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.08420038484809576], {
             RGBColor[
             0.26679472020223177`, 0.3977485450677799, 0.938504936676874]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.08420038484809576], {
             RGBColor[
             0.20095261322947336`, 0.32854431600871353`, 0.9347553260894438]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.08420038484809576], {
             RGBColor[
             0.8967495440562933, 0.920507761085305, 0.9900139661214994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.08420038484809576], {
             RGBColor[
             0.9896948922783259, 0.9900065873749687, 0.82044583391943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.08420038484809576], {
             RGBColor[
             0.3102543804501736, 0.4431484833325346, 0.9409901126684767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.08420038484809576], {
             RGBColor[
             0.18420503135956878`, 0.31094154560542325`, 0.9338015760777798]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.08420038484809576], {
             RGBColor[
             0.8957887014800139, 0.9197416112963568, 0.9899223200988196]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.08420038484809576], {
             RGBColor[
             0.2316644133079956, 0.36082436513183264`, 0.936504317669879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.08420038484809576], {
             RGBColor[
             0.188962757776349, 0.315942217726737, 0.93407252155879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.08420038484809576], {
             RGBColor[
             0.8238032261936802, 0.18396760393066158`, 0.17042730232595416`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.08420038484809576], {
             RGBColor[
             0.2824798268544749, 0.4142345866524884, 0.9393981802966833]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.08420038484809576], {
             RGBColor[
             0.34399645769565007`, 0.4723741747164527, 0.943140127993611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.08420038484809576], {
             RGBColor[
             0.28165135838121924`, 0.41336381375916165`, 0.9393510002427407]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.08420038484809576], {
             RGBColor[
             0.23366891778676377`, 0.3629312264319425, 0.9366184712345461]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.08420038484809576], {
             RGBColor[
             0.8948525196191675, 0.9189951252924975, 0.9898330262371927]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.08420038484809576], {
             RGBColor[
             0.44169024668361, 0.5569916245052177, 0.9493650898406981]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.08420038484809576], {
             RGBColor[
             0.45394807471440896`, 0.5675745230376996, 0.950155601789558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.08420038484809576], {
             RGBColor[
             0.2585433275657887, 0.3890758082383683, 0.93803503207307]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.08420038484809576], {
             RGBColor[
             0.19492367816056405`, 0.3222075229947284, 0.9344119871562795]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.08420038484809576], {
             RGBColor[
             0.34853172220347034`, 0.47630239288410453`, 0.9434291110376724]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.08420038484809576], {
             RGBColor[
             0.3499869056482099, 0.4775627996442913, 0.943521834040003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.08420038484809576], {
             RGBColor[
             0.18311045325504194`, 0.3097910746173054, 0.9337392414740102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.08420038484809576], {
             RGBColor[
             0.3996003392677278, 0.5205354622018381, 0.9466831581588019]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.08420038484809576], {
             RGBColor[
             0.20685160848485196`, 0.33474453404001786`, 0.9350912651424561]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.08420038484809576], {
             RGBColor[
             0.43492032413853554`, 0.551127857862875, 0.9489337163625334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.08420038484809576], {
             RGBColor[
             0.2017846044041309, 0.3294187914845658, 0.9348027067560198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.08420038484809576], {
             RGBColor[
             0.266643234211289, 0.39758932368653244`, 0.9384963097737932]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.08420038484809576], {
             RGBColor[
             0.9562193148935751, 0.9668690172486966, 0.9589934594404549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.08420038484809576], {
             RGBColor[
             0.20722377740839654`, 0.33513570717553587`, 0.9351124596120775]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.08420038484809576], {
             RGBColor[
             0.18162114890697434`, 0.30822572132013676`, 0.933654427794616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.08420038484809576], {
             RGBColor[
             0.18694492825143932`, 0.3138213509582757, 0.9339576091524576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.08420038484809576], {
             RGBColor[
             0.9945316676487347, 0.9907121149708813, 0.6461839540792844]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.08420038484809576], {
             RGBColor[
             0.20184829587443234`, 0.32948573525812513`, 0.9348063338910304]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.08420038484809576], {
             RGBColor[
             0.18973547474422028`, 0.3167543922530552, 0.9341165266469779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.08420038484809576], {
             RGBColor[
             0.9643115115712477, 0.9729041642811488, 0.9452954812480678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.08420038484809576], {
             RGBColor[
             0.3533082208089774, 0.4804395559023944, 0.9437334653051234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.08420038484809576], {
             RGBColor[
             0.18648980339442428`, 0.3133429858769703, 0.9339316904651475]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.08420038484809576], {
             RGBColor[
             0.1842143453500115, 0.31095133519991963`, 0.9338021064957567]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.08420038484809576], {
             RGBColor[
             0.9490437648216794, 0.9615175037539616, 0.971139794028986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.08420038484809576], {
             RGBColor[
             0.2433593553333951, 0.37311649070267905`, 0.9371703273171091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.08420038484809576], {
             RGBColor[
             0.2257570420476589, 0.35461534338824796`, 0.9361679016157753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.08420038484809576], {
             RGBColor[
             0.19363457114614188`, 0.3208525897884652, 0.9343385744188711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.08420038484809576], {
             RGBColor[
             0.3500177192487492, 0.4775894888363419, 0.943523797455382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.08420038484809576], {
             RGBColor[
             0.7303132143006519, 0.7892455006884563, 0.9737544541026248]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.08420038484809576], {
             RGBColor[
             0.18775722726537172`, 0.31467512872465075`, 0.9340038683796124]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.08420038484809576], {
             RGBColor[
             0.9930152754848626, 0.9913796511608278, 0.7654184913108293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.08420038484809576], {
             RGBColor[
             0.33484250288537293`, 0.4644454791509371, 0.9425568460876246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.08420038484809576], {
             RGBColor[
             0.3056537490672848, 0.4385918482096833, 0.9407179008839572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.08420038484809576], {
             RGBColor[
             0.22188954865981286`, 0.3505503626243781, 0.9359476535887813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.08420038484809576], {
             RGBColor[
             0.41733642177677943`, 0.535897565429752, 0.9478132856528767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.08420038484809576], {
             RGBColor[
             0.22261848399738943`, 0.3513165198813409, 0.9359891653778931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.08420038484809576], {
             RGBColor[
             0.23974505627195325`, 0.36931763322930755`, 0.9369644983324363]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.08420038484809576], {
             RGBColor[
             0.18299643202543156`, 0.30967123107562133`, 0.9337327481336631]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.08420038484809576], {
             RGBColor[
             0.1997106484206986, 0.3272389322495743, 0.9346845980309063]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.08420038484809576], {
             RGBColor[
             0.9930695883095065, 0.987584875103169, 0.4870456409120508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.08420038484809576], {
             RGBColor[
             0.19086057119328328`, 0.3179369399562554, 0.934180599225321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.08420038484809576], {
             RGBColor[
             0.3371253879726633, 0.4664227994724073, 0.9427023095067106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.08420038484809576], {
             RGBColor[
             0.635822518194204, 0.7152283896049052, 0.9644734242083259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.08420038484809576], {
             RGBColor[
             0.9023083761464576, 0.6492869771870501, 0.2401960532268301]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.08420038484809576], {
             RGBColor[
             0.23238602207295528`, 0.3615828216964435, 0.9365454122215189]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.08420038484809576], {
             RGBColor[
             0.9299021495647822, 0.7597924122879596, 0.2624558280130423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.08420038484809576], {
             RGBColor[
             0.1793343425625045, 0.3058221428602024, 0.9335241975563253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.08420038484809576], {
             RGBColor[
             0.884710274500928, 0.9109079743391231, 0.9888656498437259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.08420038484809576], {
             RGBColor[
             0.44524034591787487`, 0.5600665420287623, 0.9495912990246761]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.08420038484809576], {
             RGBColor[
             0.20746958876179836`, 0.3353940704933011, 0.9351264582050084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.08420038484809576], {
             RGBColor[
             0.20359531165465325`, 0.33132195961033534`, 0.9349058238552358]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.08420038484809576], {
             RGBColor[
             0.20688302376209858`, 0.33477755348824767`, 0.9350930541960206]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.08420038484809576], {
             RGBColor[
             0.8177383166445533, 0.1373500514757623, 0.1646195380923747]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.08420038484809576], {
             RGBColor[
             0.18219295480676673`, 0.3088267255754066, 0.9336869912946982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.08420038484809576], {
             RGBColor[
             0.295092829761857, 0.42749165241872045`, 0.9401164721529931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.08420038484809576], {
             RGBColor[
             0.9594063537213845, 0.9692459055881796, 0.9535986340178257]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.08420038484809576], {
             RGBColor[
             0.7857227396767522, 0.8325318430402561, 0.9792771577606599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.08420038484809576], {
             RGBColor[
             0.1915139828942802, 0.31862371708269777`, 0.9342178100550568]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.08420038484809576], {
             RGBColor[
             0.25077535368791876`, 0.38091117517473666`, 0.9375926574524128]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.08420038484809576], {
             RGBColor[
             0.19733278810728, 0.3247396502951197, 0.9345491824037863]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.08420038484809576], {
             RGBColor[
             0.28998218143607674`, 0.4221200369945062, 0.9398254282913666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.08420038484809576], {
             RGBColor[
             0.82776291630336, 0.2144035172609302, 0.17421910604681382`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.08420038484809576], {
             RGBColor[
             0.8316889234682268, 0.24458052871740593`, 0.17797865494168116`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.08420038484809576], {
             RGBColor[
             0.2632132370288079, 0.3939841791733627, 0.938300976508477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.08420038484809576], {
             RGBColor[
             0.852273426221674, 0.40280203706702433`, 0.19769039802525293`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.08420038484809576], {
             RGBColor[
             0.9695261963263196, 0.9767932676332187, 0.9364683801653377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.08420038484809576], {
             RGBColor[
             0.9547654228714991, 0.9657847069591619, 0.9614545193980599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.08420038484809576], {
             RGBColor[
             0.818830055518114, 0.14574163486097447`, 0.1656649884706391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.08420038484809576], {
             RGBColor[
             0.9202453542726101, 0.9392426823750178, 0.9922550174748891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.08420038484809576], {
             RGBColor[
             0.1976279917679603, 0.3250499280594878, 0.9345659938155473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.08420038484809576], {
             RGBColor[
             0.21799885977606132`, 0.3464610019236322, 0.9357260846126101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.08420038484809576], {
             RGBColor[
             0.3090764058516128, 0.442128180941986, 0.9409150531686984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.08420038484809576], {
             RGBColor[
             0.25834749102875554`, 0.38886997162119286`, 0.9380238794720002]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.08420038484809576], {
             RGBColor[
             0.19027393338711107`, 0.3173203464269832, 0.9341471910701123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.08420038484809576], {
             RGBColor[
             0.3695662131784596, 0.4945214117423836, 0.9447694102025287]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.08420038484809576], {
             RGBColor[
             0.19109293756035423`, 0.31818117174092553`, 0.9341938321461705]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.08420038484809576], {
             RGBColor[
             0.18724741023772068`, 0.314139278704323, 0.9339748350540943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.08420038484809576], {
             RGBColor[
             0.8353613957275855, 0.2728087597904426, 0.18149541852470724`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.08420038484809576], {
             RGBColor[
             0.3513087838325387, 0.47870774408802763`, 0.9436060629490174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.08420038484809576], {
             RGBColor[
             0.32310439559809073`, 0.45427852059311985`, 0.9418089042708796]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.08420038484809576], {
             RGBColor[
             0.18340786605487358`, 0.31010367432698904`, 0.9337561786929778]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.08420038484809576], {
             RGBColor[
             0.18623692915551526`, 0.3130771990187241, 0.9339172896513356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.08420038484809576], {
             RGBColor[
             0.22458179928431016`, 0.35338008872927346`, 0.9361009732790185]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.08420038484809576], {
             RGBColor[
             0.2599700418165058, 0.39057537537478015`, 0.9381162813390138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.08420038484809576], {
             RGBColor[
             0.2141514811516508, 0.34241716305148284`, 0.9355069820916365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.08420038484809576], {
             RGBColor[
             0.3919526428400527, 0.5139114119405849, 0.9461958537050229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.08420038484809576], {
             RGBColor[
             0.7232916660208124, 0.7837602138065023, 0.9730546117901898]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.08420038484809576], {
             RGBColor[
             0.18998272969436467`, 0.3170142728825262, 0.9341306074506077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.08420038484809576], {
             RGBColor[
             0.23275233921967517`, 0.3619678442434947, 0.9365662734411069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.08420038484809576], {
             RGBColor[
             0.2559867658273416, 0.386388699755884, 0.9378894396641596]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.08420038484809576], {
             RGBColor[
             0.679362894162589, 0.7494427233598264, 0.9686762023490751]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.08420038484809576], {
             RGBColor[
             0.743581503407994, 0.7996107889818441, 0.9750769131616334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.08420038484809576], {
             RGBColor[
             0.3590992451452233, 0.4854554501171043, 0.9441024642550272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.08420038484809576], {
             RGBColor[
             0.17909981633317154`, 0.30557564092335165`, 0.9335108416345153]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.08420038484809576], {
             RGBColor[
             0.7409332819620127, 0.7975419782610151, 0.9748129631969344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.08420038484809576], {
             RGBColor[
             0.1818250295794584, 0.30844001283369876`, 0.9336660384972996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.08420038484809576], {
             RGBColor[
             0.49307848673520527`, 0.5993423543211548, 0.9532360911632574]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.08420038484809576], {
             RGBColor[
             0.23875032994207512`, 0.36827211278731364`, 0.9369078501395155]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.08420038484809576], {
             RGBColor[
             0.22285712514090053`, 0.35156734685389346`, 0.9360027556379781]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.08420038484809576], {
             RGBColor[
             0.20781531186542476`, 0.3357574473953233, 0.9351461466243084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.08420038484809576], {
             RGBColor[
             0.25816588373595994`, 0.3886790908418973, 0.9380135372053394]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.08420038484809576], {
             RGBColor[
             0.6722342021283076, 0.7438737349625797, 0.9679656809485127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.08420038484809576], {
             RGBColor[
             0.2515360626002474, 0.3817107284733248, 0.937635978699602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.08420038484809576], {
             RGBColor[
             0.4286879330306734, 0.5457296739343299, 0.9485365939122276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.08420038484809576], {
             RGBColor[
             0.2671426063657563, 0.39811419548290095`, 0.9385247482792353]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.08420038484809576], {
             RGBColor[
             0.20898033639140454`, 0.33698196203894937`, 0.9352124930475636]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.08420038484809576], {
             RGBColor[
             0.2765987024765969, 0.40805315204651627`, 0.939063258963707]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.08420038484809576], {
             RGBColor[
             0.9941990383585994, 0.9900006545532618, 0.6099793085980734]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.08420038484809576], {
             RGBColor[
             0.1948453625020903, 0.32212520827217295`, 0.9344075271953871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.08420038484809576], {
             RGBColor[
             0.1899324083338537, 0.31696138194207063`, 0.9341277417235704]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.08420038484809576], {
             RGBColor[
             0.30537118422496984`, 0.4382948546447645, 0.9407018092342045]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.08420038484809576], {
             RGBColor[
             0.1861676814246589, 0.31300441526303435`, 0.9339133460955061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.08420038484809576], {
             RGBColor[
             0.19821724293608944`, 0.32566926839787347`, 0.9345995507978533]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.08420038484809576], {
             RGBColor[
             0.18717515147111807`, 0.3140633301591533, 0.9339707200242335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.08420038484809576], {
             RGBColor[
             0.1943854920349882, 0.321641855253777, 0.934381338252603]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.08420038484809576], {
             RGBColor[
             0.3488943015599562, 0.47661644089892424`, 0.9434522142736513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.08420038484809576], {
             RGBColor[
             0.1899597624904289, 0.3169901328949849, 0.9341292995023205]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.08420038484809576], {
             RGBColor[
             0.4290348579738498, 0.5460301628831548, 0.9485586996628331]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.08420038484809576], {
             RGBColor[
             0.2449605595581574, 0.37479945786511576`, 0.9372615135289399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.08420038484809576], {
             RGBColor[
             0.20692052412863532`, 0.33481696875113837`, 0.935095189786418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.08420038484809576], {
             RGBColor[
             0.19699767297971368`, 0.3243874230485212, 0.9345300980930298]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.08420038484809576], {
             RGBColor[
             0.18766218808016377`, 0.31457523651516484`, 0.9339984560386126]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.08420038484809576], {
             RGBColor[
             0.9146994662552146, 0.9348205418090667, 0.9917260457249173]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.08420038484809576], {
             RGBColor[
             0.18269671784651187`, 0.30935621247060024`, 0.933715679854561]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.08420038484809576], {
             RGBColor[
             0.19137511524925596`, 0.3184777583830601, 0.9342099017481089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.08420038484809576], {
             RGBColor[
             0.21323548342695858`, 0.34145439136522115`, 0.9354548173763124]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.08420038484809576], {
             RGBColor[
             0.1808905282724361, 0.3074577927092133, 0.9336128200303355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.08420038484809576], {
             RGBColor[
             0.18223318953702214`, 0.3088690148279342, 0.9336892826030643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.08420038484809576], {
             RGBColor[
             0.20271236623405806`, 0.3303939279913168, 0.9348555414197336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.08420038484809576], {
             RGBColor[
             0.3483545068205488, 0.47614889782652203`, 0.9434178190301781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.08420038484809576], {
             RGBColor[
             0.20150049615977755`, 0.32912017570624735`, 0.9347865272118044]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.08420038484809576], {
             RGBColor[
             0.2975965440226766, 0.4301232148514946, 0.9402590549762334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.08420038484809576], {
             RGBColor[
             0.27959908951497947`, 0.4112067490593821, 0.9392341265668681]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.08420038484809576], {
             RGBColor[
             0.3027440138032642, 0.4355335319593264, 0.9405521957652387]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.08420038484809576], {
             RGBColor[
             0.3029090080003519, 0.4357069513217019, 0.9405615919406759]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.08420038484809576], {
             RGBColor[
             0.218367213855187, 0.3468481654157909, 0.9357470618324852]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.08420038484809576], {
             RGBColor[
             0.23267428983588884`, 0.3618858093925185, 0.936561828644164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.08420038484809576], {
             RGBColor[
             0.2188459842157359, 0.34735138342052185`, 0.9357743270962412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.08420038484809576], {
             RGBColor[
             0.23435379828218117`, 0.36365107925655765`, 0.9366574741655703]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.08420038484809576], {
             RGBColor[
             0.1953540422101205, 0.32265986289746895`, 0.9344364957522352]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.08420038484809576], {
             RGBColor[
             0.19439044372267295`, 0.3216470597914888, 0.9343816202438913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.08420038484809576], {
             RGBColor[
             0.4533617737780597, 0.567098537525015, 0.9501094460321575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.08420038484809576], {
             RGBColor[
             0.19579265616170655`, 0.32312087397031664`, 0.9344614741679068]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.08420038484809576], {
             RGBColor[
             0.5543615420614805, 0.6490946994052059, 0.9580605177657702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.08420038484809576], {
             RGBColor[
             0.1999051049994005, 0.32744331844304914`, 0.9346956720453906]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.08420038484809576], {
             RGBColor[
             0.3986910652219958, 0.5197478947248675, 0.9466252200206473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.08420038484809576], {
             RGBColor[
             0.6331296311169758, 0.713042182562431, 0.9642614302732361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.08420038484809576], {
             RGBColor[
             0.289139123347183, 0.42123392949010874`, 0.9397774173803968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.08420038484809576], {
             RGBColor[
             0.19201165546058205`, 0.31914680250414423`, 0.9342461517714671]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.08420038484809576], {
             RGBColor[
             0.19560708734050541`, 0.3229258293734914, 0.9344509062980639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.08420038484809576], {
             RGBColor[
             0.8695307562797816, 0.5004514607800906, 0.21284560375709155`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.08420038484809576], {
             RGBColor[
             0.19044334897469703`, 0.3174984129511047, 0.9341568390371975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.08420038484809576], {
             RGBColor[
             0.18593025704413854`, 0.31275486718553225`, 0.9338998251282734]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.08420038484809576], {
             RGBColor[
             0.19914754728651962`, 0.3266470772548782, 0.9346525302543484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.08420038484809576], {
             RGBColor[
             0.2283446787479909, 0.35733511362593967`, 0.9363152636977938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.08420038484809576], {
             RGBColor[
             0.18811264277564865`, 0.31504869296059673`, 0.9340241087671325]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.08420038484809576], {
             RGBColor[
             0.1849809522741401, 0.31175708768286514`, 0.9338457636259925]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.08420038484809576], {
             RGBColor[
             0.1795029989097729, 0.3059994113746115, 0.9335338022857975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.08420038484809576], {
             RGBColor[
             0.18035329176886106`, 0.3068931230811942, 0.933582225206227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.08420038484809576], {
             RGBColor[
             0.9940468194635823, 0.9896750737285114, 0.5934112212615963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.08420038484809576], {
             RGBColor[
             0.23420030298526878`, 0.3634897459673388, 0.9366487328354871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.08420038484809576], {
             RGBColor[
             0.2515477771449798, 0.3817230412025836, 0.9376366458255944]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.08420038484809576], {
             RGBColor[
             0.2029347338096705, 0.33062765041220404`, 0.9348682049242014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.08420038484809576], {
             RGBColor[
             0.3362350503435996, 0.46565163376778274`, 0.9426455779802814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.08420038484809576], {
             RGBColor[
             0.18371444184961855`, 0.31042590492529404`, 0.9337736377309502]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.08420038484809576], {
             RGBColor[
             0.1820208818055452, 0.30864586594106436`, 0.9336771919918379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.08420038484809576], {
             RGBColor[
             0.1912494582787511, 0.31834568493994736`, 0.9342027457695316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.08420038484809576], {
             RGBColor[
             0.1789871968344326, 0.3054572706896884, 0.9335044281206677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.08420038484809576], {
             RGBColor[
             0.3510664211934816, 0.47849782175157674`, 0.9435906198159696]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.08420038484809576], {
             RGBColor[
             0.19785125300646603`, 0.3252845897767374, 0.9345787082127948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.08420038484809576], {
             RGBColor[
             0.33313964664549794`, 0.4629705506640006, 0.9424483415937963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.08420038484809576], {
             RGBColor[
             0.2019856527302044, 0.3296301060224692, 0.9348141561607654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.08420038484809576], {
             RGBColor[
             0.9938504692273173, 0.9917250252368329, 0.751577169586235]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.08420038484809576], {
             RGBColor[
             0.9097894237460113, 0.9309054071917814, 0.9912577214871428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.08420038484809576], {
             RGBColor[
             0.2396024194233052, 0.3691677128576799, 0.9369563753749182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.08420038484809576], {
             RGBColor[
             0.19002087389400624`, 0.31705436485483146`, 0.934132779706348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.08420038484809576], {
             RGBColor[
             0.2158527042869893, 0.34420525643050026`, 0.9356038642324599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.08420038484809576], {
             RGBColor[
             0.7657071355725306, 0.8168955009898127, 0.9772821894000061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.08420038484809576], {
             RGBColor[
             0.19499177110397153`, 0.3222790929955916, 0.9344158649486721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.08420038484809576], {
             RGBColor[
             0.85710048921771, 0.439904958487049, 0.20231279900164487`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.08420038484809576], {
             RGBColor[
             0.19077583416012883`, 0.31784787596177183`, 0.9341757735766401]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.08420038484809576], {
             RGBColor[
             0.18720392975649292`, 0.3140935779617309, 0.9339723589050121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.08420038484809576], {
             RGBColor[
             0.18524924480481392`, 0.31203908014333226`, 0.9338610424887112]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.08420038484809576], {
             RGBColor[
             0.21763599434706354`, 0.34607960735075854`, 0.93570541996324]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.08420038484809576], {
             RGBColor[
             0.18916507484151227`, 0.3161548657898664, 0.9340840432163497]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.08420038484809576], {
             RGBColor[
             0.21990087473071346`, 0.348460140235685, 0.9358344015504985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.08420038484809576], {
             RGBColor[
             0.8176771202476999, 0.13687966915311423`, 0.16456093635363633`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.08420038484809576], {
             RGBColor[
             0.18093049359979738`, 0.3074997988022181, 0.9336150959966053]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.08420038484809576], {
             RGBColor[
             0.39439940253334044`, 0.5160306722091927, 0.9463517590690945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.08420038484809576], {
             RGBColor[
             0.37508215881778845`, 0.49929904661568136`, 0.9451208813811075]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.08420038484809576], {
             RGBColor[
             0.1851720653526604, 0.311957959645659, 0.9338566472330878]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.08420038484809576], {
             RGBColor[
             0.19059767181486464`, 0.3176606160407541, 0.9341656274946448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.08420038484809576], {
             RGBColor[
             0.18708771794254558`, 0.3139714319770177, 0.9339657408141276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.08420038484809576], {
             RGBColor[
             0.18654757264035143`, 0.3134037050172214, 0.9339349803382411]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.08420038484809576], {
             RGBColor[
             0.19406834726399882`, 0.3213085159913272, 0.9343632773270688]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.08420038484809576], {
             RGBColor[
             0.271851153445097, 0.4030631770024157, 0.9387928930697325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.08420038484809576], {
             RGBColor[
             0.19021908584372046`, 0.31726269818134456`, 0.934144067583656]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.08420038484809576], {
             RGBColor[
             0.180596656524124, 0.30714891486919227`, 0.9335960844690134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.08420038484809576], {
             RGBColor[
             0.209601906353837, 0.3376352714792777, 0.9352478905373938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.08420038484809576], {
             RGBColor[
             0.18473621585810335`, 0.3114998541924255, 0.9338318262491543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.08420038484809576], {
             RGBColor[
             0.19081859398490578`, 0.3178928192487419, 0.9341782086854036]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.08420038484809576], {
             RGBColor[
             0.20710183530283005`, 0.33500753829100943`, 0.9351055151895625]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.08420038484809576], {
             RGBColor[
             0.22012423896070668`, 0.348694910203518, 0.9358471218129588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.08420038484809576], {
             RGBColor[
             0.19616341759440778`, 0.32351056774371817`, 0.9344825884830068]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.08420038484809576], {
             RGBColor[
             0.1818914944971056, 0.30850987167626515`, 0.9336698235760336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.08420038484809576], {
             RGBColor[
             0.20835388918653433`, 0.3363235263075839, 0.9351768178059918]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.08420038484809576], {
             RGBColor[
             0.18955786573703887`, 0.316567713925446, 0.9341064120767679]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.08420038484809576], {
             RGBColor[
             0.9944253181788963, 0.9904846442084778, 0.6346084706002231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.08420038484809576], {
             RGBColor[
             0.7607606134285254, 0.8130312402959552, 0.9767891663005692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.08420038484809576], {
             RGBColor[
             0.5341260408491124, 0.6326666079220644, 0.9564675049852491]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.08420038484809576], {
             RGBColor[
             0.2195142065627996, 0.3480537274750297, 0.9358123813703602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.08420038484809576], {
             RGBColor[
             0.20264865261830456`, 0.3303269609414833, 0.9348519130235723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.08420038484809576], {
             RGBColor[
             0.2627109211596987, 0.39345621334626335`, 0.938272370362841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.08420038484809576], {
             RGBColor[
             0.18112688553091424`, 0.3077062191737896, 0.9336262802265466]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.08420038484809576], {
             RGBColor[
             0.9910839134677017, 0.9905809833329919, 0.7974261581398643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.08420038484809576], {
             RGBColor[
             0.18336325239717496`, 0.31005678254407854`, 0.9337536380111718]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.08420038484809576], {
             RGBColor[
             0.18043226082461958`, 0.30697612456572376`, 0.9335867223771283]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.08420038484809576], {
             RGBColor[
             0.46863892160806836`, 0.5795012143610829, 0.9513121190713723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.08420038484809576], {
             RGBColor[
             0.19955786085140656`, 0.3270783428269569, 0.9346758970048641]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.08420038484809576], {
             RGBColor[
             0.2129233554713194, 0.341126325093789, 0.9354370421509908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.08420038484809576], {
             RGBColor[
             0.4260942433398349, 0.54348315028676, 0.9483713262986371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.08420038484809576], {
             RGBColor[
             0.9265760623547111, 0.7466055848528861, 0.2597795801705179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.08420038484809576], {
             RGBColor[
             0.8501784807301029, 0.38669936800784144`, 0.19568427585662201`]},
             StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{
  3.8350561391154623`*^9, {3.835056265887759*^9, 3.835056277027934*^9}},
 CellLabel->
  "Out[513]=",ExpressionUUID->"e1a00a34-2f6b-44a0-a459-e046193434e7"]
}, Open  ]],

Cell["Estimated with absolute Mean Deviation v Calculated: (r=3)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 
  3.8349503756793146`*^9}},ExpressionUUID->"24b7344a-a514-4246-9557-\
1ec153e9f73e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphin4b", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsi4b", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}],
      "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"AMDi3400b", ",", "kri4b"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502409842243`*^9}, {3.834957391671958*^9, 3.8349574025038147`*^9}, {
   3.8349597972565393`*^9, 3.834959804676405*^9}},
 CellLabel->
  "In[205]:=",ExpressionUUID->"6a90ed87-42be-4058-a9ab-84cc4a517c73"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN2wucznW+wPHf/+zadNlSKJUyheimsIbchiJLGlM0NrNmJtWMMW5DaZZc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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[337, 399] -> 
             RGBColor[
              0.9835252249492582, 0.9870773781176663, 0.9057703557279276], 
             UndirectedEdge[15, 92] -> 
             RGBColor[
              0.9903278815815131, 0.9901133236482198, 0.7986871676875478], 
             UndirectedEdge[87, 313] -> 
             RGBColor[
              0.9538030032453856, 0.8430625058342902, 0.3783999365037054], 
             UndirectedEdge[35, 214] -> 
             RGBColor[
              0.908755097702811, 0.8937151935859862, 0.6584883053395683], 
             UndirectedEdge[105, 218] -> 
             RGBColor[
              0.9688307662568596, 0.9289782492447551, 0.6091653311948191], 
             UndirectedEdge[149, 316] -> 
             RGBColor[
              0.9903074471996669, 0.9898920727385873, 0.7835574489118495], 
             UndirectedEdge[160, 348] -> 
             RGBColor[
              0.9724194460685741, 0.9155796699346075, 0.46976348725628], 
             UndirectedEdge[17, 287] -> 
             RGBColor[
              0.9897235922626937, 0.9900184555560607, 0.8199702009052765], 
             UndirectedEdge[268, 295] -> 
             RGBColor[
              0.9826195715802815, 0.9666542269826095, 0.6388194405316381], 
             UndirectedEdge[277, 379] -> 
             RGBColor[
              0.9753828792425154, 0.9397619016028287, 0.5935558608591855], 
             UndirectedEdge[10, 37] -> 
             RGBColor[
              0.8863246565686079, 0.5501665005972053, 0.5623581537625894], 
             UndirectedEdge[118, 389] -> 
             RGBColor[
              0.9935539530223072, 0.988620882247065, 0.5397657507478939], 
             UndirectedEdge[127, 313] -> 
             RGBColor[
              0.9836406574134159, 0.9560162390576152, 0.43023248348617815`], 
             UndirectedEdge[92, 281] -> 
             RGBColor[
              0.9864293766512778, 0.9886562127432607, 0.8745638787431592], 
             UndirectedEdge[2, 193] -> 
             RGBColor[
              0.9689702842653545, 0.9561752636852765, 0.6664423947328779], 
             UndirectedEdge[265, 378] -> 
             RGBColor[
              0.9943051564218568, 0.9906333722863663, 0.6510227596880129], 
             UndirectedEdge[108, 367] -> 
             RGBColor[
              0.9856994407108284, 0.9879217277689022, 0.867286405952605], 
             UndirectedEdge[26, 342] -> 
             RGBColor[
              0.9456723264697023, 0.9590030905512807, 0.9768467597469326], 
             UndirectedEdge[57, 144] -> 
             RGBColor[
              0.9921993210660804, 0.9898417871615961, 0.6916812248732145], 
             UndirectedEdge[341, 348] -> 
             RGBColor[
              0.9468495447119849, 0.8269831866619667, 0.2760920999549735], 
             UndirectedEdge[232, 309] -> 
             RGBColor[
              0.9517152785000558, 0.8422230011674544, 0.5318682398422095], 
             UndirectedEdge[23, 202] -> 
             RGBColor[
              0.9519443230893609, 0.8351489001084618, 0.40912845303038115`], 
             UndirectedEdge[89, 170] -> 
             RGBColor[
              0.9752369129805842, 0.9796665022881975, 0.8647422915651077], 
             UndirectedEdge[291, 383] -> 
             RGBColor[
              0.9300733603841933, 0.7391852966666352, 0.31817364409817217`], 
             UndirectedEdge[45, 140] -> 
             RGBColor[
              0.9173653991698905, 0.7606163864731359, 0.5940391669290312], 
             UndirectedEdge[213, 308] -> 
             RGBColor[
              0.9448555671038052, 0.8056155945934653, 0.3592084768163469], 
             UndirectedEdge[165, 386] -> 
             RGBColor[
              0.9361589080551, 0.7713622338358829, 0.5069624459677511], 
             UndirectedEdge[347, 381] -> 
             RGBColor[
              0.9802387596283778, 0.9509873876229695, 0.5767920595547136], 
             UndirectedEdge[216, 396] -> 
             RGBColor[
              0.9821276040843236, 0.9836678202250008, 0.7785859729088622], 
             UndirectedEdge[39, 150] -> 
             RGBColor[
              0.9120528681493447, 0.619284167706095, 0.48009913593841963`], 
             UndirectedEdge[20, 378] -> 
             RGBColor[
              0.6194402913341277, 0.682992391436887, 0.8364291077990591], 
             UndirectedEdge[363, 372] -> 
             RGBColor[
              0.9687560611765791, 0.9563647801946786, 0.6675464818163765], 
             UndirectedEdge[54, 318] -> 
             RGBColor[
              0.9918847117782195, 0.9909121340139688, 0.7841548577349888], 
             UndirectedEdge[40, 246] -> 
             RGBColor[
              0.9392654152425547, 0.9520194892958913, 0.9012640829610403], 
             UndirectedEdge[59, 178] -> 
             RGBColor[
              0.9359442198932715, 0.8689727040488813, 0.6308078343580066], 
             UndirectedEdge[172, 357] -> 
             RGBColor[
              0.9757356602987648, 0.9294672936974018, 0.3896196268855282], 
             UndirectedEdge[268, 274] -> 
             RGBColor[
              0.9871482434227313, 0.98895348262729, 0.862650395972606], 
             UndirectedEdge[122, 175] -> 
             RGBColor[
              0.9908521203815402, 0.9899309272610889, 0.76098281281301], 
             UndirectedEdge[120, 341] -> 
             RGBColor[
              0.9683351187630012, 0.9007752959971844, 0.38430585045086496`], 
             UndirectedEdge[220, 366] -> 
             RGBColor[
              0.9704967157031614, 0.9078669943487128, 0.4735238126945574], 
             UndirectedEdge[202, 366] -> 
             RGBColor[
              0.9943059710599951, 0.9902293727889928, 0.6216182732328703], 
             UndirectedEdge[17, 61] -> 
             RGBColor[
              0.9838630461258622, 0.9865583805799087, 0.8706740643306683], 
             UndirectedEdge[112, 279] -> 
             RGBColor[
              0.9887300355956581, 0.9896075943409999, 0.8364360061202889], 
             UndirectedEdge[129, 313] -> 
             RGBColor[
              0.9437900775432562, 0.8005133528981538, 0.37019580980396016`], 
             UndirectedEdge[204, 318] -> 
             RGBColor[
              0.9909207316930347, 0.9905135034755868, 0.8001305024469919], 
             UndirectedEdge[60, 335] -> 
             RGBColor[
              0.9933967688812755, 0.9898350142324217, 0.6353500677436936], 
             UndirectedEdge[256, 386] -> 
             RGBColor[
              0.9380821441284044, 0.772157130337488, 0.4750595688165551], 
             UndirectedEdge[7, 65] -> 
             RGBColor[
              0.9852051439989307, 0.9608450741993231, 0.5484268917775218], 
             UndirectedEdge[66, 280] -> 
             RGBColor[
              0.8886003206212851, 0.9095424836740902, 0.7415596019142245], 
             UndirectedEdge[147, 344] -> 
             RGBColor[
              0.8443833685228422, 0.342155596148474, 0.19013486986230604`], 
             UndirectedEdge[329, 349] -> 
             RGBColor[
              0.989954123377795, 0.9884146124839528, 0.6926377194864892], 
             UndirectedEdge[170, 306] -> 
             RGBColor[
              0.9022618601617655, 0.9221163312167836, 0.8776498963138211], 
             UndirectedEdge[175, 178] -> 
             RGBColor[
              0.9618892571595283, 0.8878587409929732, 0.5659861656585168], 
             UndirectedEdge[115, 166] -> 
             RGBColor[
              0.9833177225475536, 0.9541274483313361, 0.49695787570153765`], 
             UndirectedEdge[361, 396] -> 
             RGBColor[
              0.9657855686089488, 0.9740035136063194, 0.9428002871788882], 
             UndirectedEdge[80, 265] -> 
             RGBColor[
              0.9937172554560907, 0.9889701696405194, 0.5575402128794378], 
             UndirectedEdge[18, 288] -> 
             RGBColor[
              0.9659559120306508, 0.9109740511309712, 0.5956854085277961], 
             UndirectedEdge[225, 240] -> 
             RGBColor[
              0.9881149179492041, 0.9706709562980267, 0.48485970269352185`], 
             UndirectedEdge[110, 251] -> 
             RGBColor[
              0.9753005808943324, 0.9512246197799603, 0.6351955190878995], 
             UndirectedEdge[56, 169] -> 
             RGBColor[
              0.9824377031626117, 0.9598351818516646, 0.5952203148674393], 
             UndirectedEdge[87, 231] -> 
             RGBColor[
              0.9504751527003938, 0.8434379718637468, 0.5608751517646535], 
             UndirectedEdge[266, 315] -> 
             RGBColor[
              0.9451234061859375, 0.820139622607754, 0.274703208379237], 
             UndirectedEdge[31, 292] -> 
             RGBColor[
              0.9797301963845478, 0.9575867298221509, 0.6322882891714463], 
             UndirectedEdge[1, 87] -> 
             RGBColor[
              0.9486212021709388, 0.8260450724862713, 0.318984606908414], 
             UndirectedEdge[231, 336] -> 
             RGBColor[
              0.94488360199505, 0.9571766906974385, 0.9312155092168725], 
             UndirectedEdge[13, 309] -> 
             RGBColor[
              0.9542610348103087, 0.8431538684101346, 0.4808199223448841], 
             UndirectedEdge[237, 296] -> 
             RGBColor[
              0.9642070924114874, 0.9726118146274596, 0.9358676510469577], 
             UndirectedEdge[95, 312] -> 
             RGBColor[
              0.930171763229374, 0.9470561117773422, 0.989678590005237], 
             UndirectedEdge[108, 236] -> 
             RGBColor[
              0.9914755713461508, 0.9888951975610953, 0.6566237182348962], 
             UndirectedEdge[48, 176] -> 
             RGBColor[
              0.9942661541663125, 0.9915968650062899, 0.7228772445518307], 
             UndirectedEdge[49, 52] -> 
             RGBColor[
              0.9662764654639235, 0.9615321257291927, 0.6866387553037037], 
             UndirectedEdge[310, 390] -> 
             RGBColor[
              0.984626742396357, 0.9661962196208124, 0.5966526513048543], 
             UndirectedEdge[343, 358] -> 
             RGBColor[
              0.9799502736279009, 0.9434368645661855, 0.4270220209997979], 
             UndirectedEdge[271, 374] -> 
             RGBColor[
              0.9221678718554358, 0.7942801977727019, 0.6059422755701058], 
             UndirectedEdge[57, 167] -> 
             RGBColor[
              0.9864263159633486, 0.971224393425011, 0.5964399353667998], 
             UndirectedEdge[34, 214] -> 
             RGBColor[
              0.9191570694497702, 0.936174347268367, 0.9075404439748316], 
             UndirectedEdge[83, 220] -> 
             RGBColor[
              0.9347271010649734, 0.8830717713616778, 0.6340662267117632], 
             UndirectedEdge[9, 347] -> 
             RGBColor[
              0.931173956894806, 0.9142448038273341, 0.6645301651412112], 
             UndirectedEdge[188, 238] -> 
             RGBColor[
              0.6224464166261138, 0.6870482970607787, 0.8599788045331735], 
             UndirectedEdge[79, 137] -> 
             RGBColor[
              0.9128836848979311, 0.9308620791392475, 0.8934790073753993], 
             UndirectedEdge[115, 197] -> 
             RGBColor[
              0.9810832488325009, 0.9538375628127223, 0.5800832109459604], 
             UndirectedEdge[67, 194] -> 
             RGBColor[
              0.9718310062190374, 0.9236369927157144, 0.5561858735507004], 
             UndirectedEdge[75, 260] -> 
             RGBColor[
              0.994531013330227, 0.990710715449755, 0.6461127355476987], 
             UndirectedEdge[32, 387] -> 
             RGBColor[
              0.9451226842915308, 0.9312936378727539, 0.6745792610958381], 
             UndirectedEdge[76, 144] -> 
             RGBColor[
              0.9937382828722772, 0.9904781874179729, 0.6661766450390503], 
             UndirectedEdge[50, 164] -> 
             RGBColor[
              0.9836020435458154, 0.9804117754089996, 0.669959333257415], 
             UndirectedEdge[279, 285] -> 
             RGBColor[
              0.9749174039697639, 0.9302565619174473, 0.5368998930487463], 
             UndirectedEdge[137, 352] -> 
             RGBColor[
              0.9144258160207498, 0.9302574631866367, 0.777617859863521], 
             UndirectedEdge[4, 275] -> 
             RGBColor[
              0.9498735523017048, 0.898288236721765, 0.6223720568914377], 
             UndirectedEdge[8, 373] -> 
             RGBColor[
              0.9475728639033358, 0.9569064625152188, 0.7984871605206056], 
             UndirectedEdge[41, 135] -> 
             RGBColor[
              0.9749414110951162, 0.9493846807595472, 0.6324662911446477], 
             UndirectedEdge[85, 211] -> 
             RGBColor[
              0.9907536799298298, 0.9888153353029595, 0.6844814841869444], 
             UndirectedEdge[63, 139] -> 
             RGBColor[
              0.5733469298046324, 0.6404375785951444, 0.9364737391594034], 
             UndirectedEdge[55, 92] -> 
             RGBColor[
              0.9460367674059662, 0.9582962581152117, 0.9400129957410013], 
             UndirectedEdge[31, 371] -> 
             RGBColor[
              0.9782224168853917, 0.9832343161932038, 0.9197516310461773], 
             UndirectedEdge[99, 169] -> 
             RGBColor[
              0.9827897053528593, 0.953607776365154, 0.3876416844976388], 
             UndirectedEdge[71, 72] -> 
             RGBColor[
              0.9804070416816647, 0.9817578941618692, 0.7317698184154774], 
             UndirectedEdge[104, 112] -> 
             RGBColor[
              0.9253884285854235, 0.7346994489819865, 0.5496131424352348], 
             UndirectedEdge[389, 390] -> 
             RGBColor[
              0.992061300851407, 0.9901541362179239, 0.7208217992188741], 
             UndirectedEdge[260, 349] -> 
             RGBColor[
              0.9904727442768941, 0.9895238901465097, 0.7490864037962522], 
             UndirectedEdge[70, 284] -> 
             RGBColor[
              0.9470678577867169, 0.8254529988854354, 0.5362297305247369], 
             UndirectedEdge[24, 172] -> 
             RGBColor[
              0.9905610174955269, 0.9884503366209627, 0.6669340792979306], 
             UndirectedEdge[343, 362] -> 
             RGBColor[
              0.9651114247606404, 0.9354791452236333, 0.6351497977398894], 
             UndirectedEdge[233, 307] -> 
             RGBColor[
              0.9777258760836622, 0.9813070794716481, 0.8508702027565923], 
             UndirectedEdge[79, 278] -> 
             RGBColor[
              0.9901292694270887, 0.9901862134889656, 0.8132470804324055], 
             UndirectedEdge[1, 216] -> 
             RGBColor[
              0.9885960751151708, 0.972082397911818, 0.5047230760207365], 
             UndirectedEdge[192, 374] -> 
             RGBColor[
              0.9672490422048976, 0.9744642944332733, 0.9120800758443965], 
             UndirectedEdge[152, 383] -> 
             RGBColor[
              0.9308009340421314, 0.7408021452428857, 0.39220898101563456`], 
             UndirectedEdge[43, 121] -> 
             RGBColor[
              0.9545923582638605, 0.8561544633310421, 0.5465381012687569], 
             UndirectedEdge[13, 280] -> 
             RGBColor[
              0.889557934952037, 0.9115907238979077, 0.845790012105961], 
             UndirectedEdge[246, 272] -> 
             RGBColor[
              0.9091456657300341, 0.9280028186134279, 0.8983912343643183], 
             UndirectedEdge[385, 387] -> 
             RGBColor[
              0.9786486097218623, 0.9568246627542722, 0.6361154493186154], 
             UndirectedEdge[90, 268] -> 
             RGBColor[
              0.9448126514871296, 0.9574419137505912, 0.9451822813631309], 
             UndirectedEdge[195, 363] -> 
             RGBColor[
              0.9875740537189732, 0.9686231946405208, 0.5561590122111004], 
             UndirectedEdge[88, 109] -> 
             RGBColor[
              0.9910937917645737, 0.9811010933253171, 0.4639753773632888], 
             UndirectedEdge[63, 318] -> 
             RGBColor[
              0.9789539417701674, 0.9828361157343638, 0.87624937810028], 
             UndirectedEdge[257, 276] -> 
             RGBColor[
              0.9741525287334958, 0.9244725515225292, 0.3540878843253545], 
             UndirectedEdge[16, 106] -> 
             RGBColor[
              0.8901817615191161, 0.810707304039934, 0.6215668127836396], 
             UndirectedEdge[100, 227] -> 
             RGBColor[
              0.9103612316457851, 0.9292960875348304, 0.9125767940475813], 
             UndirectedEdge[195, 359] -> 
             RGBColor[
              0.9084391339724399, 0.9265265400732108, 0.8586821712665091], 
             UndirectedEdge[216, 313] -> 
             RGBColor[
              0.9937778761896175, 0.9890998312598369, 0.5641384056160279], 
             UndirectedEdge[12, 47] -> 
             RGBColor[
              0.8865511222737135, 0.5293434211568182, 0.22502662646724386`], 
             UndirectedEdge[386, 400] -> 
             RGBColor[
              0.9362680947232132, 0.771407385329117, 0.5051529403110775], 
             UndirectedEdge[180, 262] -> 
             RGBColor[
              0.9747075648665218, 0.9660582761208589, 0.6686272419243227], 
             UndirectedEdge[247, 359] -> 
             RGBColor[
              0.9073907026173766, 0.9260929867644353, 0.8760573920732798], 
             UndirectedEdge[74, 141] -> 
             RGBColor[
              0.9169762830216447, 0.6653088206080249, 0.29798976209129957`], 
             UndirectedEdge[170, 171] -> 
             RGBColor[
              0.9934016011009064, 0.9906662030962203, 0.6955433898191563], 
             UndirectedEdge[207, 333] -> 
             RGBColor[
              0.9161718590039261, 0.6744843511305074, 0.5407824340314192], 
             UndirectedEdge[311, 313] -> 
             RGBColor[
              0.993654412823199, 0.9888357556031288, 0.5507001801089444], 
             UndirectedEdge[161, 195] -> 
             RGBColor[
              0.995034973891181, 0.9921336266866263, 0.726042903982492], 
             UndirectedEdge[87, 129] -> 
             RGBColor[
              0.9043415026895079, 0.6556017258712523, 0.2417416399054634], 
             UndirectedEdge[198, 367] -> 
             RGBColor[
              0.9801828946453928, 0.9629319390939375, 0.6440538343110552], 
             UndirectedEdge[322, 330] -> 
             RGBColor[
              0.947874137692438, 0.9090550213124171, 0.6355244938259683], 
             UndirectedEdge[79, 314] -> 
             RGBColor[
              0.9765794081984898, 0.9376392258243673, 0.5556344158002482], 
             UndirectedEdge[56, 274] -> 
             RGBColor[
              0.9892449225279651, 0.9898205133194994, 0.8279029971672933], 
             UndirectedEdge[249, 316] -> 
             RGBColor[
              0.9926102521556159, 0.9908443417672601, 0.7453940113235829], 
             UndirectedEdge[69, 294] -> 
             RGBColor[
              0.9929836955083535, 0.9910501382536296, 0.742939004436378], 
             UndirectedEdge[6, 300] -> 
             RGBColor[
              0.9813185867656364, 0.9470654553704, 0.5162693263658635], 
             UndirectedEdge[36, 265] -> 
             RGBColor[
              0.9501973195481489, 0.9587516476677576, 0.7786755845503804], 
             UndirectedEdge[167, 395] -> 
             RGBColor[
              0.9693313828230204, 0.9595243643320905, 0.6723689687185412], 
             UndirectedEdge[261, 306] -> 
             RGBColor[
              0.8868052152082214, 0.9119745991936952, 0.9658732993795338], 
             UndirectedEdge[35, 211] -> 
             RGBColor[
              0.9782260165119435, 0.9471062414623737, 0.5890750559451037], 
             UndirectedEdge[54, 63] -> 
             RGBColor[
              0.9806976296173169, 0.9835571754698937, 0.8473519579535155], 
             UndirectedEdge[302, 314] -> 
             RGBColor[
              0.9284632126533492, 0.7493890652157729, 0.27106881395689625`], 
             UndirectedEdge[54, 224] -> 
             RGBColor[
              0.9910328228254954, 0.9905598560394699, 0.7982728622995672], 
             UndirectedEdge[164, 389] -> 
             RGBColor[
              0.9856901607795614, 0.9863348903625561, 0.773358566617375], 
             UndirectedEdge[113, 210] -> 
             RGBColor[
              0.9476861562333083, 0.8172465159857254, 0.4165279368289595], 
             UndirectedEdge[307, 348] -> 
             RGBColor[
              0.9558967030767682, 0.9055288482106123, 0.6143089035602927], 
             UndirectedEdge[18, 74] -> 
             RGBColor[
              0.9678428340379746, 0.901098423718178, 0.3404609070613354], 
             UndirectedEdge[41, 328] -> 
             RGBColor[
              0.9780993427610563, 0.9377860819934939, 0.3694205115291377], 
             UndirectedEdge[63, 290] -> 
             RGBColor[
              0.9162391704928918, 0.7270247081024572, 0.5741353804826892], 
             UndirectedEdge[45, 288] -> 
             RGBColor[
              0.93249433350677, 0.7718995209302244, 0.5684298273547195], 
             UndirectedEdge[249, 315] -> 
             RGBColor[
              0.9727684988983996, 0.925131543959675, 0.546065588559095], 
             UndirectedEdge[306, 342] -> 
             RGBColor[
              0.8760415639362104, 0.9039470856988908, 0.9840933533731884], 
             UndirectedEdge[163, 395] -> 
             RGBColor[
              0.974717324388835, 0.9791821432270742, 0.8612846454991834], 
             UndirectedEdge[378, 379] -> 
             RGBColor[
              0.9907037766686603, 0.9904237869975181, 0.8037260086624816], 
             UndirectedEdge[216, 235] -> 
             RGBColor[
              0.9907669207612165, 0.9896063415638368, 0.7413618486967941], 
             UndirectedEdge[220, 321] -> 
             RGBColor[
              0.9417118697247581, 0.8066140173663112, 0.27195820606351917`], 
             UndirectedEdge[133, 199] -> 
             RGBColor[
              0.9521239893786214, 0.9058511529408246, 0.6231281838780798], 
             UndirectedEdge[317, 396] -> 
             RGBColor[
              0.9713264514546475, 0.9483446232359276, 0.642100793131652], 
             UndirectedEdge[177, 197] -> 
             RGBColor[
              0.9686869266118536, 0.9094588456980811, 0.5452740472642668], 
             UndirectedEdge[208, 242] -> 
             RGBColor[
              0.8953095921907421, 0.6136482418144217, 0.23415647985159416`], 
             UndirectedEdge[51, 163] -> 
             RGBColor[
              0.9939110356290118, 0.9917500710004192, 0.7505734275693341], 
             UndirectedEdge[188, 228] -> 
             RGBColor[
              0.9902321031941198, 0.9902287378943403, 0.8115428587874409], 
             UndirectedEdge[95, 125] -> 
             RGBColor[
              0.9439085528810709, 0.8933758496507773, 0.6321094826198029], 
             UndirectedEdge[66, 203] -> 
             RGBColor[
              0.9864101890948992, 0.965374611102048, 0.4396232974870134], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.992643565945739, 0.9912259397139007, 0.7715786803275595], 
             UndirectedEdge[151, 265] -> 
             RGBColor[
              0.9937905801974998, 0.9891270038481249, 0.5655211584739672], 
             UndirectedEdge[76, 333] -> 
             RGBColor[
              0.9201894576106995, 0.676145731401983, 0.47420042790527756`], 
             UndirectedEdge[119, 336] -> 
             RGBColor[
              0.9484314813012947, 0.95864382996691, 0.8724179674950762], 
             UndirectedEdge[183, 395] -> 
             RGBColor[
              0.9684059238420151, 0.9759577702487023, 0.9383647092674064], 
             UndirectedEdge[42, 204] -> 
             RGBColor[
              0.991719642341866, 0.9873156295985883, 0.6048080650121881], 
             UndirectedEdge[12, 107] -> 
             RGBColor[
              0.9624498003488406, 0.8922956789032634, 0.5772740093421105], 
             UndirectedEdge[234, 239] -> 
             RGBColor[
              0.9537246653321387, 0.8577864921123333, 0.5706600377653159], 
             UndirectedEdge[164, 287] -> 
             RGBColor[
              0.9833676620459118, 0.9862054993666372, 0.8722549016435303], 
             UndirectedEdge[32, 194] -> 
             RGBColor[
              0.9521792889879452, 0.962510924980927, 0.9109314028829065], 
             UndirectedEdge[6, 169] -> 
             RGBColor[
              0.9854128859022073, 0.9608764877452071, 0.5321749053679262], 
             UndirectedEdge[24, 240] -> 
             RGBColor[
              0.9910102308986577, 0.9894111586678176, 0.7158281860049472], 
             UndirectedEdge[9, 381] -> 
             RGBColor[
              0.941014213017031, 0.9534228485066427, 0.9018180194906189], 
             UndirectedEdge[43, 90] -> 
             RGBColor[
              0.9126317901348749, 0.8247979764360513, 0.6228548716531495], 
             UndirectedEdge[88, 157] -> 
             RGBColor[
              0.9894926265664943, 0.9762183035394898, 0.4136812676721519], 
             UndirectedEdge[100, 314] -> 
             RGBColor[
              0.9754191960133147, 0.9371594482697043, 0.5748621342414848], 
             UndirectedEdge[56, 296] -> 
             RGBColor[
              0.9660218871960774, 0.9733622789089862, 0.9057918049279485], 
             UndirectedEdge[49, 235] -> 
             RGBColor[
              0.9864183595105372, 0.9760492504366245, 0.6299437679573503], 
             UndirectedEdge[359, 362] -> 
             RGBColor[
              0.8928910285261207, 0.9167068020696726, 0.9645345749412714], 
             UndirectedEdge[104, 285] -> 
             RGBColor[
              0.9115757969595293, 0.675348416558434, 0.25007702936369225`], 
             UndirectedEdge[80, 168] -> 
             RGBColor[
              0.9786384191936369, 0.9389053395976636, 0.43096741351274814`], 
             UndirectedEdge[311, 386] -> 
             RGBColor[
              0.9374700061343344, 0.7708478290648172, 0.40843212583982913`], 
             UndirectedEdge[61, 173] -> 
             RGBColor[
              0.9678495121575797, 0.9755427993254909, 0.9393065691137463], 
             UndirectedEdge[118, 354] -> 
             RGBColor[
              0.993122139859744, 0.9876972775553501, 0.4927655528448205], 
             UndirectedEdge[154, 180] -> 
             RGBColor[
              0.979159323172535, 0.9806637427337552, 0.7209005228595415], 
             UndirectedEdge[17, 158] -> 
             RGBColor[
              0.9874022200588285, 0.989058508493218, 0.858441345842011], 
             UndirectedEdge[8, 237] -> 
             RGBColor[
              0.9432305417372381, 0.9560721818862005, 0.9403329392583726], 
             UndirectedEdge[55, 255] -> 
             RGBColor[
              0.9507807874214549, 0.9600505552271854, 0.846310913464133], 
             UndirectedEdge[93, 214] -> 
             RGBColor[
              0.9180523757569723, 0.9357175280370621, 0.9258480773201281], 
             UndirectedEdge[129, 235] -> 
             RGBColor[
              0.9407791221148551, 0.8010198632021538, 0.5474192528847264], 
             UndirectedEdge[47, 158] -> 
             RGBColor[
              0.9095255093809946, 0.6252882834324345, 0.5389750821782741], 
             UndirectedEdge[106, 347] -> 
             RGBColor[
              0.9466810188036843, 0.8220462285375578, 0.29818853017306246`], 
             UndirectedEdge[169, 178] -> 
             RGBColor[
              0.9562383611979084, 0.8583515789687384, 0.31414021208975496`], 
             UndirectedEdge[230, 385] -> 
             RGBColor[
              0.9883666369441395, 0.9884127892392239, 0.7753174658569986], 
             UndirectedEdge[304, 383] -> 
             RGBColor[
              0.9312768278732793, 0.7422257759534427, 0.47350024244893835`], 
             UndirectedEdge[100, 352] -> 
             RGBColor[
              0.9911395893336152, 0.9893616799314933, 0.7061994210577953], 
             UndirectedEdge[87, 216] -> 
             RGBColor[
              0.9543293013358692, 0.8441882042329354, 0.4356842357175311], 
             UndirectedEdge[79, 277] -> 
             RGBColor[
              0.9774637759359261, 0.9406224058621597, 0.5590700174613548], 
             UndirectedEdge[217, 220] -> 
             RGBColor[
              0.9701171226988665, 0.9070550832952657, 0.43220745675352357`], 
             UndirectedEdge[78, 104] -> 
             RGBColor[
              0.9004373594928496, 0.716306075650005, 0.601506939390633], 
             UndirectedEdge[170, 353] -> 
             RGBColor[
              0.9834054811982115, 0.9580373613546279, 0.5639890850044177], 
             UndirectedEdge[78, 385] -> 
             RGBColor[
              0.9589485354198488, 0.9689019104323353, 0.9542850169697357], 
             UndirectedEdge[40, 102] -> 
             RGBColor[
              0.9390824261380151, 0.9519438185985588, 0.9042966859838832], 
             UndirectedEdge[41, 256] -> 
             RGBColor[
              0.9833614342375905, 0.9538215364302476, 0.5356782935099969], 
             UndirectedEdge[120, 217] -> 
             RGBColor[
              0.9935745518696903, 0.9886649410987547, 0.5420078081642008], 
             UndirectedEdge[210, 315] -> 
             RGBColor[
              0.9282475652504516, 0.7523960415170369, 0.26108123959936713`], 
             UndirectedEdge[83, 187] -> 
             RGBColor[
              0.9575828139772841, 0.9662768389563412, 0.8878804463226627], 
             UndirectedEdge[2, 305] -> 
             RGBColor[
              0.9764577323681287, 0.9799065253104917, 0.8252607423667282], 
             UndirectedEdge[121, 175] -> 
             RGBColor[
              0.987845956364538, 0.9892420048591317, 0.8510874869036569], 
             UndirectedEdge[36, 151] -> 
             RGBColor[
              0.9501892632301054, 0.9587344160180813, 0.7777987040491866], 
             UndirectedEdge[70, 332] -> 
             RGBColor[
              0.8952912711704268, 0.6171958486609732, 0.23432900977823617`], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.5709473486362611, 0.5013974392317, 0.5868332047216434], 
             UndirectedEdge[221, 400] -> 
             RGBColor[
              0.9802710468340787, 0.9835671458141805, 0.8627677152447397], 
             UndirectedEdge[49, 216] -> 
             RGBColor[
              0.9899556130294219, 0.9766684385312698, 0.5100046240904098], 
             UndirectedEdge[75, 349] -> 
             RGBColor[
              0.990654146062483, 0.9899118902233502, 0.7688308686755448], 
             UndirectedEdge[62, 87] -> 
             RGBColor[
              0.9536206168468683, 0.8447387021230554, 0.508746670657301], 
             UndirectedEdge[38, 189] -> 
             RGBColor[
              0.9908687739797504, 0.9904920176258913, 0.8009915762183671], 
             UndirectedEdge[49, 361] -> 
             RGBColor[
              0.9736135775540471, 0.9670041319125884, 0.6742189383604358], 
             UndirectedEdge[107, 270] -> 
             RGBColor[
              0.8989038695730943, 0.9207277158119463, 0.933300490569174], 
             UndirectedEdge[5, 8] -> 
             RGBColor[
              0.9430925664847336, 0.9560151255734877, 0.9426195462608788], 
             UndirectedEdge[162, 340] -> 
             RGBColor[
              0.9675269289073593, 0.9723739029829112, 0.7711853230558119], 
             UndirectedEdge[34, 85] -> 
             RGBColor[
              0.9912679192094963, 0.9890279864604483, 0.6759592085142753], 
             UndirectedEdge[21, 172] -> 
             RGBColor[
              0.993229364646623, 0.9879266205323955, 0.5044363091819287], 
             UndirectedEdge[298, 393] -> 
             RGBColor[
              0.9808062936405562, 0.9832543787214307, 0.8262075400127218], 
             UndirectedEdge[164, 371] -> 
             RGBColor[
              0.97452306291235, 0.980519922551462, 0.9280099884267181], 
             UndirectedEdge[11, 85] -> 
             RGBColor[
              0.9838355900202034, 0.9565861344303066, 0.438443570445604], 
             UndirectedEdge[202, 307] -> 
             RGBColor[
              0.9777341033137941, 0.9800734781826212, 0.7608167631838199], 
             UndirectedEdge[20, 265] -> 
             RGBColor[
              0.6189337714278141, 0.6815032546483217, 0.7518043870862072], 
             UndirectedEdge[195, 247] -> 
             RGBColor[
              0.993833666110127, 0.9917180767160544, 0.7518556407231504], 
             UndirectedEdge[281, 355] -> 
             RGBColor[
              0.9757065844226482, 0.9808853596375684, 0.9028439200165659], 
             UndirectedEdge[298, 313] -> 
             RGBColor[
              0.9941884636906464, 0.9899780364077733, 0.6088283212506747], 
             UndirectedEdge[67, 210] -> 
             RGBColor[
              0.9279358699653377, 0.7511602735778575, 0.26083044225653595`], 
             UndirectedEdge[11, 263] -> 
             RGBColor[
              0.984488802246819, 0.9584853424483082, 0.5460356516839873], 
             UndirectedEdge[88, 181] -> 
             RGBColor[
              0.9495180031511462, 0.9526293447276448, 0.7012302250802359], 
             UndirectedEdge[212, 390] -> 
             RGBColor[
              0.9671086190557129, 0.903688057460607, 0.5463856086898773], 
             UndirectedEdge[13, 203] -> 
             RGBColor[
              0.987367803425651, 0.9674228513258656, 0.5438537076787499], 
             UndirectedEdge[75, 105] -> 
             RGBColor[
              0.9864984634581196, 0.9872119602499878, 0.793750018514595], 
             UndirectedEdge[12, 270] -> 
             RGBColor[
              0.8755362578628376, 0.8246202450575884, 0.6258687841620985], 
             UndirectedEdge[127, 393] -> 
             RGBColor[
              0.9702584873633258, 0.9492925813712727, 0.6476117022482254], 
             UndirectedEdge[185, 208] -> 
             RGBColor[
              0.8991455987367283, 0.6310666516176536, 0.2373573377426897], 
             UndirectedEdge[246, 355] -> 
             RGBColor[
              0.9771166713414725, 0.9814684668160831, 0.8794751305836795], 
             UndirectedEdge[62, 336] -> 
             RGBColor[
              0.9480290661415245, 0.958477420956747, 0.87908702810952], 
             UndirectedEdge[118, 209] -> 
             RGBColor[
              0.9816031770883478, 0.9494287036353013, 0.39805195074442046`], 
             UndirectedEdge[178, 352] -> 
             RGBColor[
              0.9652778950966223, 0.888017703061126, 0.41952362162764073`], 
             UndirectedEdge[17, 22] -> 
             RGBColor[
              0.9920030191422484, 0.9900557202113027, 0.7163857603695443], 
             UndirectedEdge[12, 158] -> 
             RGBColor[
              0.9620565757458652, 0.8921330704245218, 0.5837907586460651], 
             UndirectedEdge[200, 333] -> 
             RGBColor[
              0.6704984403364774, 0.4804659526472852, 0.5728834359394974], 
             UndirectedEdge[69, 295] -> 
             RGBColor[
              0.9856860872380981, 0.9679223100129744, 0.5879993401934858], 
             UndirectedEdge[181, 340] -> 
             RGBColor[
              0.9519571692782194, 0.9601042271878439, 0.7747354080594053], 
             UndirectedEdge[205, 284] -> 
             RGBColor[
              0.9916671906615749, 0.9899038715024436, 0.7210081617378659], 
             UndirectedEdge[283, 373] -> 
             RGBColor[
              0.9845594771419222, 0.985386373702889, 0.766921012480841], 
             UndirectedEdge[302, 379] -> 
             RGBColor[
              0.9405605781574204, 0.8013354085708415, 0.5527530916829158], 
             UndirectedEdge[254, 303] -> 
             RGBColor[
              0.9411490910641375, 0.9241248857318183, 0.6683152663857663], 
             UndirectedEdge[38, 254] -> 
             RGBColor[
              0.9499854426526202, 0.9606745757823031, 0.9069427620865493], 
             UndirectedEdge[158, 209] -> 
             RGBColor[
              0.9777240578567021, 0.9499750921471359, 0.6186579343907321], 
             UndirectedEdge[365, 370] -> 
             RGBColor[
              0.9526320970857087, 0.9614050486028833, 0.8366228506396789], 
             UndirectedEdge[61, 164] -> 
             RGBColor[
              0.9775071159090802, 0.9827454243904852, 0.922958765068922], 
             UndirectedEdge[163, 167] -> 
             RGBColor[
              0.9877304110933518, 0.9717636702749834, 0.5748277041726356], 
             UndirectedEdge[62, 119] -> 
             RGBColor[
              0.9932892204618695, 0.991492934448885, 0.7608785140949497], 
             UndirectedEdge[137, 197] -> 
             RGBColor[
              0.9125438457652366, 0.9307215469244109, 0.8991110212796325], 
             UndirectedEdge[265, 383] -> 
             RGBColor[
              0.9307703079669658, 0.7407366391648776, 0.38887552173608647`], 
             UndirectedEdge[19, 338] -> 
             RGBColor[
              0.9822678301497985, 0.9676467101923214, 0.6472323025943725], 
             UndirectedEdge[69, 212] -> 
             RGBColor[
              0.9677327778614981, 0.9039461631669488, 0.5360416820068066], 
             UndirectedEdge[45, 275] -> 
             RGBColor[
              0.9166268371298887, 0.7600655681129871, 0.5952893598149236], 
             UndirectedEdge[248, 360] -> 
             RGBColor[
              0.9815830636641945, 0.95783120565309, 0.5979752883363864], 
             UndirectedEdge[188, 322] -> 
             RGBColor[
              0.9740542866275788, 0.9272829423487876, 0.5331174594935237], 
             UndirectedEdge[167, 183] -> 
             RGBColor[
              0.9814190105465319, 0.9685392972966115, 0.6519077679408587], 
             UndirectedEdge[141, 240] -> 
             RGBColor[
              0.9205617221945764, 0.6765033362654995, 0.38844908906586606`], 
             UndirectedEdge[23, 220] -> 
             RGBColor[
              0.9281350677325272, 0.7527865216681816, 0.2610339924920682], 
             UndirectedEdge[123, 322] -> 
             RGBColor[
              0.9332783876815123, 0.7731350206935074, 0.26539663703495786`], 
             UndirectedEdge[177, 398] -> 
             RGBColor[
              0.9551624688773273, 0.8578516090800536, 0.29366329505253147`], 
             UndirectedEdge[272, 395] -> 
             RGBColor[
              0.8922420796504189, 0.9163819164475074, 0.9711491517297278], 
             UndirectedEdge[85, 312] -> 
             RGBColor[
              0.9570487215357304, 0.9639430934203866, 0.7573061228144449], 
             UndirectedEdge[25, 328] -> 
             RGBColor[
              0.9633037867641994, 0.9581988257381773, 0.6893010714641152], 
             UndirectedEdge[8, 121] -> 
             RGBColor[
              0.9448026937621345, 0.9567223071509592, 0.914278311606819], 
             UndirectedEdge[169, 319] -> 
             RGBColor[
              0.9806882200467131, 0.9591117256235753, 0.6242137776150496], 
             UndirectedEdge[84, 167] -> 
             RGBColor[
              0.9042777728983653, 0.908184096483786, 0.6845989857427629], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.9543904730801566, 0.860343131894538, 0.5707892854450025], 
             UndirectedEdge[43, 213] -> 
             RGBColor[
              0.9086184654625983, 0.6732356325061037, 0.2452180140787053], 
             UndirectedEdge[170, 187] -> 
             RGBColor[
              0.9922372058228153, 0.9910578993600929, 0.7783131191906937], 
             UndirectedEdge[89, 199] -> 
             RGBColor[
              0.9550311196022473, 0.908019285901616, 0.6182071707104773], 
             UndirectedEdge[16, 373] -> 
             RGBColor[
              0.9257837925905372, 0.939532448498978, 0.7964088994474574], 
             UndirectedEdge[22, 158] -> 
             RGBColor[
              0.9896317619365664, 0.9890751444182228, 0.7556836288846287], 
             UndirectedEdge[233, 264] -> 
             RGBColor[
              0.993685916207195, 0.9916569783341926, 0.7543042389792269], 
             UndirectedEdge[274, 296] -> 
             RGBColor[
              0.9661542682430001, 0.9734170218739264, 0.903597908389272], 
             UndirectedEdge[97, 211] -> 
             RGBColor[
              0.9899357207285597, 0.9866058233543187, 0.6345650456345638], 
             UndirectedEdge[1, 129] -> 
             RGBColor[
              0.9386082764688095, 0.7834959195501351, 0.3107804802086688], 
             UndirectedEdge[24, 141] -> 
             RGBColor[
              0.9176106587107626, 0.6764223507053893, 0.5201749310884962], 
             UndirectedEdge[347, 384] -> 
             RGBColor[
              0.9444400973072622, 0.8131617215470657, 0.2963854321358532], 
             UndirectedEdge[36, 378] -> 
             RGBColor[
              0.9507038394544625, 0.9602407844563227, 0.8633003052632323], 
             UndirectedEdge[174, 395] -> 
             RGBColor[
              0.9705195270472862, 0.977446246147873, 0.9308530109999247], 
             UndirectedEdge[104, 357] -> 
             RGBColor[
              0.9118416263094901, 0.6762451213755509, 0.251109726190629], 
             UndirectedEdge[47, 173] -> 
             RGBColor[
              0.8958832326183942, 0.6152532779710966, 0.5683097184462677], 
             UndirectedEdge[127, 231] -> 
             RGBColor[
              0.9803128068684241, 0.9563917050870718, 0.6127076987471263], 
             UndirectedEdge[252, 367] -> 
             RGBColor[
              0.922373960608273, 0.9397566272332596, 0.9514306259518679], 
             UndirectedEdge[158, 310] -> 
             RGBColor[
              0.9822402753356114, 0.9652093541617881, 0.636202586480186], 
             UndirectedEdge[149, 397] -> 
             RGBColor[
              0.9550659878273455, 0.965456414862763, 0.9391590485273427], 
             UndirectedEdge[204, 345] -> 
             RGBColor[
              0.9740093677867516, 0.978889384978458, 0.8730173185286598], 
             UndirectedEdge[231, 396] -> 
             RGBColor[
              0.9782734554488481, 0.9829175878558123, 0.9037768889559845], 
             UndirectedEdge[162, 263] -> 
             RGBColor[
              0.9680154038673447, 0.9739207546450837, 0.8608467694620769], 
             UndirectedEdge[14, 196] -> 
             RGBColor[
              0.9624914166916099, 0.880575287945101, 0.5191473544881845], 
             UndirectedEdge[43, 175] -> 
             RGBColor[
              0.9538110586667432, 0.8558313758691503, 0.5594862575315326], 
             UndirectedEdge[113, 397] -> 
             RGBColor[
              0.9592110104911594, 0.9661070610405232, 0.7931653635219593], 
             UndirectedEdge[126, 336] -> 
             RGBColor[
              0.944207825179935, 0.9568972396177164, 0.9424148798976653], 
             UndirectedEdge[48, 173] -> 
             RGBColor[
              0.9756722670826716, 0.9798142980620543, 0.8560838280333158], 
             UndirectedEdge[28, 168] -> 
             RGBColor[
              0.9307333774615363, 0.7589735900383237, 0.27485405724390743`], 
             UndirectedEdge[253, 359] -> 
             RGBColor[
              0.8896279039392432, 0.9142731690956555, 0.9700581937076589], 
             UndirectedEdge[41, 187] -> 
             RGBColor[
              0.9816911816744838, 0.9531312551114888, 0.5633885791968811], 
             UndirectedEdge[198, 398] -> 
             RGBColor[
              0.970903489243765, 0.9135127784129171, 0.3414659794373751], 
             UndirectedEdge[260, 329] -> 
             RGBColor[
              0.9938309906455389, 0.9892134377103574, 0.569919586358643], 
             UndirectedEdge[60, 82] -> 
             RGBColor[
              0.9938373287399014, 0.9907773272225883, 0.6833022895348453], 
             UndirectedEdge[12, 17] -> 
             RGBColor[
              0.9644278329515472, 0.8931136462176018, 0.5444928901309809], 
             UndirectedEdge[268, 351] -> 
             RGBColor[
              0.9240043700462497, 0.9408499549553866, 0.9431975689035277], 
             UndirectedEdge[122, 274] -> 
             RGBColor[
              0.9920084437852739, 0.9904090967046887, 0.741819541544102], 
             UndirectedEdge[150, 384] -> 
             RGBColor[
              0.95525293204808, 0.8527419524792929, 0.5175551418223953], 
             UndirectedEdge[179, 232] -> 
             RGBColor[
              0.9114339042649231, 0.9298420315151208, 0.8992449303185057], 
             UndirectedEdge[4, 131] -> 
             RGBColor[
              0.9005408741198218, 0.85935353005267, 0.631598423224058], 
             UndirectedEdge[128, 155] -> 
             RGBColor[
              0.8942522624448418, 0.8539018999413279, 0.6309006950977936], 
             UndirectedEdge[316, 362] -> 
             RGBColor[
              0.9793207593551962, 0.9819585981364988, 0.8138153583536328], 
             UndirectedEdge[283, 320] -> 
             RGBColor[
              0.9572955261537487, 0.9676716538443997, 0.9571717144978322], 
             UndirectedEdge[49, 396] -> 
             RGBColor[
              0.9777790428336444, 0.9701107290977886, 0.6671678921694184], 
             UndirectedEdge[371, 389] -> 
             RGBColor[
              0.9831516068609649, 0.9844416410065673, 0.777655676240659], 
             UndirectedEdge[53, 58] -> 
             RGBColor[
              0.9079024323678707, 0.6345157276263174, 0.2628650261038608], 
             UndirectedEdge[18, 399] -> 
             RGBColor[
              0.9654063273350076, 0.9105641717648228, 0.5966157120628746], 
             UndirectedEdge[241, 270] -> 
             RGBColor[
              0.9031704563185765, 0.9224920590774812, 0.8625921066239814], 
             UndirectedEdge[137, 169] -> 
             RGBColor[
              0.9053862821220359, 0.900591339094249, 0.6722344503256353], 
             UndirectedEdge[156, 386] -> 
             RGBColor[
              0.9275533515972176, 0.7383558565631763, 0.28834164777141025`], 
             UndirectedEdge[19, 262] -> 
             RGBColor[
              0.9827245847723372, 0.9533881093560135, 0.3873887033393002], 
             UndirectedEdge[85, 181] -> 
             RGBColor[
              0.9517924320115894, 0.9597518708320149, 0.7568047732272871], 
             UndirectedEdge[74, 240] -> 
             RGBColor[
              0.9903758552095399, 0.9782976285704532, 0.4936430170077506], 
             UndirectedEdge[72, 88] -> 
             RGBColor[
              0.9781272149815674, 0.9746238226242843, 0.6756077487336778], 
             UndirectedEdge[63, 98] -> 
             RGBColor[
              0.9739715193185735, 0.9601364477880658, 0.6584675532834716], 
             UndirectedEdge[43, 56] -> 
             RGBColor[
              0.954835001023554, 0.8562548023478098, 0.5425168828013012], 
             UndirectedEdge[174, 272] -> 
             RGBColor[
              0.9064433105792016, 0.9268853253111992, 0.9431762526845634], 
             UndirectedEdge[180, 198] -> 
             RGBColor[
              0.9719635102900364, 0.9568019356997193, 0.6579671080659022], 
             UndirectedEdge[126, 289] -> 
             RGBColor[
              0.9892188790201671, 0.9880079663438865, 0.6973644151558881], 
             UndirectedEdge[233, 244] -> 
             RGBColor[
              0.929116587174539, 0.7344390321719948, 0.48022736000901783`], 
             UndirectedEdge[51, 189] -> 
             RGBColor[
              0.9934382489155846, 0.9915545615443526, 0.7584087269436158], 
             UndirectedEdge[199, 306] -> 
             RGBColor[
              0.8820560667834285, 0.850469114830202, 0.6311147754591906], 
             UndirectedEdge[86, 214] -> 
             RGBColor[
              0.9164609261572938, 0.9197087623775199, 0.6884239937616343], 
             UndirectedEdge[104, 172] -> 
             RGBColor[
              0.9291688335869352, 0.7343483278123673, 0.34780422987338444`], 
             UndirectedEdge[67, 293] -> 
             RGBColor[
              0.970049811925593, 0.9229004231007698, 0.5857048725761425], 
             UndirectedEdge[296, 380] -> 
             RGBColor[
              0.9299418968291063, 0.9467879428308443, 0.9867138320194209], 
             UndirectedEdge[290, 297] -> 
             RGBColor[
              0.9054450220304071, 0.6514456127641541, 0.24218824735604672`], 
             UndirectedEdge[206, 328] -> 
             RGBColor[
              0.9731887219558437, 0.9655709942190096, 0.6725684545886629], 
             UndirectedEdge[5, 319] -> 
             RGBColor[
              0.9854102883280493, 0.9882347935322304, 0.8914528095750955], 
             UndirectedEdge[235, 393] -> 
             RGBColor[
              0.9768584526206427, 0.981756985478849, 0.9014567682450156], 
             UndirectedEdge[40, 189] -> 
             RGBColor[
              0.9402880707198435, 0.9524423836167972, 0.8843160351548258], 
             UndirectedEdge[15, 256] -> 
             RGBColor[
              0.99519191391798, 0.9921243149796592, 0.7180476859189793], 
             UndirectedEdge[71, 365] -> 
             RGBColor[
              0.9519042615688915, 0.9598482820278704, 0.7574024463142774], 
             UndirectedEdge[53, 64] -> 
             RGBColor[
              0.9806039846974576, 0.9486669588148018, 0.5536567041437677], 
             UndirectedEdge[231, 298] -> 
             RGBColor[
              0.9908606131456545, 0.9903535024372299, 0.7913035365116228], 
             UndirectedEdge[81, 382] -> 
             RGBColor[
              0.9764553334345207, 0.9310066017646682, 0.4679516064048011], 
             UndirectedEdge[9, 294] -> 
             RGBColor[
              0.943432293356979, 0.9541063330936983, 0.838741321654791], 
             UndirectedEdge[175, 213] -> 
             RGBColor[
              0.9418720635632758, 0.8063231740341936, 0.5497673997136054], 
             UndirectedEdge[174, 189] -> 
             RGBColor[
              0.9884457686041903, 0.9894900426346995, 0.8411470458283008], 
             UndirectedEdge[14, 127] -> 
             RGBColor[
              0.9532506587960365, 0.8470188482163304, 0.3090670566595766], 
             UndirectedEdge[86, 95] -> 
             RGBColor[
              0.9616948176106637, 0.9556754199265566, 0.68921522549187], 
             UndirectedEdge[103, 200] -> 
             RGBColor[
              0.7304319506234433, 0.7874558447741914, 0.947322528470335], 
             UndirectedEdge[24, 112] -> 
             RGBColor[
              0.986780612494015, 0.9888014577905819, 0.8687429918597809], 
             UndirectedEdge[109, 360] -> 
             RGBColor[
              0.9839951709095929, 0.9571557783460277, 0.43639857580375424`], 
             UndirectedEdge[90, 121] -> 
             RGBColor[
              0.9466666878326697, 0.9582086054260328, 0.9144561010252739], 
             UndirectedEdge[75, 202] -> 
             RGBColor[
              0.9942802592070261, 0.9901743777353593, 0.6188196967123626], 
             UndirectedEdge[27, 32] -> 
             RGBColor[
              0.9520881976424316, 0.9624732563686164, 0.9124410222149133], 
             UndirectedEdge[131, 273] -> 
             RGBColor[
              0.9197914062987129, 0.9265072183947047, 0.6948362909861967], 
             UndirectedEdge[160, 220] -> 
             RGBColor[
              0.9704475909487664, 0.9077619214663362, 0.46817688634149424`], 
             UndirectedEdge[50, 147] -> 
             RGBColor[
              0.9116748444752278, 0.6173305950109769, 0.29781918193594864`], 
             UndirectedEdge[13, 339] -> 
             RGBColor[
              0.9901839454833594, 0.9769223597481158, 0.554793887789143], 
             UndirectedEdge[17, 209] -> 
             RGBColor[
              0.9800953150623841, 0.9509556679402159, 0.5793600658756478], 
             UndirectedEdge[174, 325] -> 
             RGBColor[
              0.9087696726387532, 0.9287403032700698, 0.9433981431745714], 
             UndirectedEdge[21, 78] -> 
             RGBColor[
              0.9644978905525373, 0.9698843683700332, 0.7581390186991772], 
             UndirectedEdge[274, 373] -> 
             RGBColor[
              0.9917724499094728, 0.9899043296669912, 0.7161330645485355], 
             UndirectedEdge[97, 305] -> 
             RGBColor[
              0.9933663622447059, 0.9877596646166279, 0.5584610249289064], 
             UndirectedEdge[11, 162] -> 
             RGBColor[
              0.9578041707805091, 0.9403297544387355, 0.6693847605484449], 
             UndirectedEdge[103, 207] -> 
             RGBColor[
              0.9761053692908919, 0.9814742432574137, 0.915221526562257], 
             UndirectedEdge[210, 249] -> 
             RGBColor[
              0.9458439385254436, 0.8175481388366381, 0.524358184246076], 
             UndirectedEdge[52, 299] -> 
             RGBColor[
              0.9709552928019256, 0.9757956226221649, 0.834004261482209], 
             UndirectedEdge[43, 373] -> 
             RGBColor[
              0.9573625284050616, 0.8563386186953015, 0.4307469501825435], 
             UndirectedEdge[1, 336] -> 
             RGBColor[
              0.9430296514655949, 0.9397837913199631, 0.689324964360633], 
             UndirectedEdge[30, 345] -> 
             RGBColor[
              0.9714244545007893, 0.9778204569054713, 0.9158560212182015], 
             UndirectedEdge[247, 363] -> 
             RGBColor[
              0.98652562236391, 0.9681896413317452, 0.573534233017871], 
             UndirectedEdge[14, 119] -> 
             RGBColor[
              0.9630816082430076, 0.8808193473188349, 0.5093663531147524], 
             UndirectedEdge[74, 104] -> 
             RGBColor[
              0.9260326078171344, 0.7241146342017475, 0.3062390096058347], 
             UndirectedEdge[258, 277] -> 
             RGBColor[
              0.9795496989656443, 0.9414849886407248, 0.5245008746631673], 
             UndirectedEdge[152, 236] -> 
             RGBColor[
              0.9935000187006524, 0.9885055221866418, 0.5338953326798161], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.942653363160393, 0.8066462614960853, 0.5368192434508297], 
             UndirectedEdge[120, 132] -> 
             RGBColor[
              0.9940925773915922, 0.9897729453096882, 0.5983916893402699], 
             UndirectedEdge[212, 270] -> 
             RGBColor[
              0.8782018341119396, 0.8351883666346493, 0.6280135693812421], 
             UndirectedEdge[69, 270] -> 
             RGBColor[
              0.9015212708366496, 0.9218100784985708, 0.8899233780147262], 
             UndirectedEdge[16, 270] -> 
             RGBColor[
              0.8346951580120539, 0.8710918879573423, 0.984078017907811], 
             UndirectedEdge[24, 73] -> 
             RGBColor[
              0.9905429562886505, 0.988411705525722, 0.6649682283902745], 
             UndirectedEdge[56, 178] -> 
             RGBColor[
              0.9629131995163391, 0.8882821674716328, 0.5490167909282855], 
             UndirectedEdge[6, 319] -> 
             RGBColor[
              0.9903382411047394, 0.9900836200200123, 0.7960449469540669], 
             UndirectedEdge[231, 235] -> 
             RGBColor[
              0.9869127721257411, 0.9888561091946482, 0.8665527647439165], 
             UndirectedEdge[18, 86] -> 
             RGBColor[
              0.9663225964964788, 0.8959703055219632, 0.33455507128539486`], 
             UndirectedEdge[30, 63] -> 
             RGBColor[
              0.9771487362461698, 0.9820896168585249, 0.9061663053550604], 
             UndirectedEdge[46, 358] -> 
             RGBColor[
              0.9863985157124078, 0.9651882992364688, 0.45207222384976614`], 
             UndirectedEdge[241, 389] -> 
             RGBColor[
              0.9943346451391192, 0.9910942225031762, 0.6831466011450587], 
             UndirectedEdge[286, 332] -> 
             RGBColor[
              0.937877467985907, 0.7817325497219467, 0.5192218991509046], 
             UndirectedEdge[40, 174] -> 
             RGBColor[
              0.9365630600917221, 0.9509019959936625, 0.9460491012812854], 
             UndirectedEdge[157, 365] -> 
             RGBColor[
              0.9502723082757514, 0.9548996396198619, 0.7037572424778795], 
             UndirectedEdge[235, 336] -> 
             RGBColor[
              0.9452004971116408, 0.9573077349719818, 0.9259637370366905], 
             UndirectedEdge[76, 222] -> 
             RGBColor[
              0.9857693504993835, 0.9873466864281477, 0.8390816675038438], 
             UndirectedEdge[115, 392] -> 
             RGBColor[
              0.6012091525957872, 0.6384658590908785, 0.6412489286759326], 
             UndirectedEdge[76, 77] -> 
             RGBColor[
              0.978267146023611, 0.9817515546138489, 0.851780942793025], 
             UndirectedEdge[160, 366] -> 
             RGBColor[
              0.9947147140673587, 0.9911036327514859, 0.6661074271149436], 
             UndirectedEdge[3, 348] -> 
             RGBColor[
              0.835370473888349, 0.8108964839223628, 0.6257747902891027], 
             UndirectedEdge[299, 306] -> 
             RGBColor[
              0.903477516770919, 0.9223453115781366, 0.8376064105485692], 
             UndirectedEdge[56, 121] -> 
             RGBColor[
              0.9888698987213489, 0.9896654313377913, 0.8341181121734256], 
             UndirectedEdge[280, 322] -> 
             RGBColor[
              0.8700418585861623, 0.8473863405505293, 0.6315467640567218], 
             UndirectedEdge[81, 271] -> 
             RGBColor[
              0.9461640023900795, 0.8097908604666544, 0.43971688192643127`], 
             UndirectedEdge[2, 191] -> 
             RGBColor[
              0.960604699048327, 0.970139629570903, 0.9515701479578293], 
             UndirectedEdge[146, 377] -> 
             RGBColor[
              0.9296171492542165, 0.7520269699644349, 0.5452374534511737], 
             UndirectedEdge[10, 396] -> 
             RGBColor[
              0.962640673512881, 0.9716580559929651, 0.9481237742565247], 
             UndirectedEdge[382, 384] -> 
             RGBColor[
              0.9384450720648455, 0.792939093705528, 0.27309589113458654`], 
             UndirectedEdge[147, 391] -> 
             RGBColor[
              0.9095528636458687, 0.6223437481367946, 0.5313971561616138], 
             UndirectedEdge[133, 216] -> 
             RGBColor[
              0.973215173278789, 0.9770209439229992, 0.7936723935283969], 
             UndirectedEdge[86, 264] -> 
             RGBColor[
              0.9886450622650168, 0.9742217953333786, 0.5740457121482389], 
             UndirectedEdge[6, 56] -> 
             RGBColor[
              0.9920877242206381, 0.9908070762481016, 0.7670514842064566], 
             UndirectedEdge[43, 308] -> 
             RGBColor[
              0.9567945622072727, 0.8551237964284221, 0.3689273346342741], 
             UndirectedEdge[201, 364] -> 
             RGBColor[
              0.9942980653222566, 0.9902124632153629, 0.620757782468596], 
             UndirectedEdge[109, 365] -> 
             RGBColor[
              0.9518734734738309, 0.9597824294056894, 0.7540513521690164], 
             UndirectedEdge[229, 349] -> 
             RGBColor[
              0.9908366450733349, 0.9903022371540819, 0.7886947597534273], 
             UndirectedEdge[216, 231] -> 
             RGBColor[
              0.9904500256446258, 0.9894752972892935, 0.746613620876976], 
             UndirectedEdge[114, 353] -> 
             RGBColor[
              0.9817099623922976, 0.9573362207555367, 0.5920882194804244], 
             UndirectedEdge[70, 236] -> 
             RGBColor[
              0.9490795018896304, 0.824437119049102, 0.3685799264904339], 
             UndirectedEdge[64, 94] -> 
             RGBColor[
              0.9936418965934557, 0.991638775092659, 0.7550337578979951], 
             UndirectedEdge[240, 285] -> 
             RGBColor[
              0.9759190443519348, 0.9295314109271395, 0.4374810367656081], 
             UndirectedEdge[56, 90] -> 
             RGBColor[
              0.9469093305923634, 0.9583089444428006, 0.9104348825578181], 
             UndirectedEdge[90, 295] -> 
             RGBColor[
              0.9425130397968362, 0.9360644317630603, 0.6844100305781737], 
             UndirectedEdge[165, 281] -> 
             RGBColor[
              0.9893701729144405, 0.9898723075730951, 0.8258272741257866], 
             UndirectedEdge[54, 345] -> 
             RGBColor[
              0.9749733478719363, 0.9792880155168401, 0.8570416738166566], 
             UndirectedEdge[101, 136] -> 
             RGBColor[
              0.9909650873440383, 0.990434576158394, 0.7923249473357066], 
             UndirectedEdge[6, 314] -> 
             RGBColor[
              0.9787320264806207, 0.9383403801758059, 0.5062210280895015], 
             UndirectedEdge[125, 276] -> 
             RGBColor[
              0.9538892745774716, 0.853817514286622, 0.2873595052718053], 
             UndirectedEdge[244, 341] -> 
             RGBColor[
              0.9039636560554452, 0.6454832075728203, 0.24099168701701207`], 
             UndirectedEdge[46, 153] -> 
             RGBColor[
              0.9790750810766609, 0.9410774764462799, 0.3732110706325421], 
             UndirectedEdge[14, 336] -> 
             RGBColor[
              0.9178214539226623, 0.8478038338266971, 0.6275748671293228], 
             UndirectedEdge[109, 370] -> 
             RGBColor[
              0.9941014539814882, 0.9897919314379149, 0.5993578513704898], 
             UndirectedEdge[51, 234] -> 
             RGBColor[
              0.9902381739542764, 0.9902312483096765, 0.8114422505810228], 
             UndirectedEdge[144, 228] -> 
             RGBColor[
              0.9911773469916243, 0.9894191746182728, 0.7086179800710786], 
             UndirectedEdge[320, 347] -> 
             RGBColor[
              0.9550190988869318, 0.9331566531381126, 0.6632813188538715], 
             UndirectedEdge[31, 106] -> 
             RGBColor[
              0.9537119294391228, 0.8600625366611945, 0.5820345095915856], 
             UndirectedEdge[77, 103] -> 
             RGBColor[
              0.9648040279097234, 0.9732714821599624, 0.9444617795558625], 
             UndirectedEdge[266, 316] -> 
             RGBColor[
              0.9649651594431539, 0.8858524204153391, 0.4740316311437247], 
             UndirectedEdge[109, 334] -> 
             RGBColor[
              0.9941149356712262, 0.9898207674090569, 0.6008252500991381], 
             UndirectedEdge[45, 179] -> 
             RGBColor[
              0.8573953411465085, 0.7132378128252292, 0.6035715680688581], 
             UndirectedEdge[181, 191] -> 
             RGBColor[
              0.9367301092573403, 0.9516762250390417, 0.9691781441788225], 
             UndirectedEdge[125, 148] -> 
             RGBColor[
              0.9673866442517907, 0.9104864004445478, 0.5744825348306337], 
             UndirectedEdge[18, 112] -> 
             RGBColor[
              0.9671986548062637, 0.9116832384984169, 0.5838350398907355], 
             UndirectedEdge[221, 239] -> 
             RGBColor[
              0.945283685148859, 0.8517534905954401, 0.5966932981426365], 
             UndirectedEdge[57, 76] -> 
             RGBColor[
              0.9920471242053565, 0.990979295726399, 0.7814632635074419], 
             UndirectedEdge[222, 333] -> 
             RGBColor[
              0.91237272209853, 0.6718767218473549, 0.5573234117358437], 
             UndirectedEdge[125, 214] -> 
             RGBColor[
              0.898674661427701, 0.8574091921017406, 0.6313182508895672], 
             UndirectedEdge[220, 244] -> 
             RGBColor[
              0.9053155590478371, 0.6508430524426878, 0.2420794598979324], 
             UndirectedEdge[143, 379] -> 
             RGBColor[
              0.9875164446822158, 0.9891057433104276, 0.8565483482286342], 
             UndirectedEdge[31, 241] -> 
             RGBColor[
              0.9894054551635458, 0.9898868976898125, 0.8252425559505768], 
             UndirectedEdge[81, 374] -> 
             RGBColor[
              0.9705060833130783, 0.9751384535747986, 0.809203483250504], 
             UndirectedEdge[168, 304] -> 
             RGBColor[
              0.9792263201594029, 0.9405685422435105, 0.5244499603213233], 
             UndirectedEdge[156, 328] -> 
             RGBColor[
              0.979490639527683, 0.942479252679342, 0.3748254367431345], 
             UndirectedEdge[46, 363] -> 
             RGBColor[
              0.9797997285452493, 0.9435218825131457, 0.37602618920981623`], 
             UndirectedEdge[51, 269] -> 
             RGBColor[
              0.981123058916088, 0.9471234894737328, 0.5329022419992194], 
             UndirectedEdge[13, 325] -> 
             RGBColor[
              0.913979660575176, 0.930772898757801, 0.8481966128211803], 
             UndirectedEdge[164, 374] -> 
             RGBColor[
              0.9617857848046906, 0.9710204813941485, 0.9495708778488063], 
             UndirectedEdge[49, 199] -> 
             RGBColor[
              0.9688644291292543, 0.9054986475490951, 0.3394604144400927], 
             UndirectedEdge[49, 313] -> 
             RGBColor[
              0.9894293149389383, 0.9755427401326247, 0.4527203248765841], 
             UndirectedEdge[176, 388] -> 
             RGBColor[
              0.9518181723222854, 0.8336572891820156, 0.4676965698182037], 
             UndirectedEdge[45, 232] -> 
             RGBColor[
              0.9360106581099941, 0.7735488928117752, 0.5189003239929815], 
             UndirectedEdge[176, 250] -> 
             RGBColor[
              0.9896000972370991, 0.975080378780504, 0.5416860865041355], 
             UndirectedEdge[346, 390] -> 
             RGBColor[
              0.9922473049045326, 0.9905519800796652, 0.7410671925176423], 
             UndirectedEdge[331, 335] -> 
             RGBColor[
              0.9836916304964021, 0.984140826447637, 0.7209168183335903], 
             UndirectedEdge[135, 355] -> 
             RGBColor[
              0.9712746758278334, 0.9780972807825754, 0.9335086604457645], 
             UndirectedEdge[326, 327] -> 
             RGBColor[
              0.9907179182582997, 0.9892495162610355, 0.7177094782377161], 
             UndirectedEdge[80, 304] -> 
             RGBColor[
              0.9942237753624042, 0.9904593064290845, 0.6421649335922897], 
             UndirectedEdge[65, 173] -> 
             RGBColor[
              0.9762423651525265, 0.9800500482647914, 0.8466358276493094], 
             UndirectedEdge[203, 257] -> 
             RGBColor[
              0.9841493964044334, 0.9581943335527545, 0.3929238274768944], 
             UndirectedEdge[275, 325] -> 
             RGBColor[
              0.8920500832848177, 0.9163587068163326, 0.975633966140448], 
             UndirectedEdge[240, 337] -> 
             RGBColor[
              0.9895471708251569, 0.988806145728496, 0.740074877700955], 
             UndirectedEdge[77, 254] -> 
             RGBColor[
              0.9366761613068602, 0.9516414799077899, 0.9694597766754889], 
             UndirectedEdge[32, 364] -> 
             RGBColor[
              0.9552079678614173, 0.9636672885499293, 0.8537548646280491], 
             UndirectedEdge[38, 53] -> 
             RGBColor[
              0.979147601771645, 0.9480647070476443, 0.5777927382226784], 
             UndirectedEdge[28, 291] -> 
             RGBColor[
              0.9451152661412177, 0.8074870775829369, 0.3307249789726827], 
             UndirectedEdge[174, 269] -> 
             RGBColor[
              0.9761305786046937, 0.9450589705640797, 0.6156405608839043], 
             UndirectedEdge[216, 361] -> 
             RGBColor[
              0.9779621388047264, 0.9805612230398006, 0.7856370190998796], 
             UndirectedEdge[356, 363] -> 
             RGBColor[
              0.9874677158967594, 0.9680507582359887, 0.5195076250450714], 
             UndirectedEdge[151, 383] -> 
             RGBColor[
              0.9307622516489223, 0.7407194075152015, 0.38799864123489264`], 
             UndirectedEdge[61, 130] -> 
             RGBColor[
              0.9813549777847748, 0.9716613744452098, 0.658745113570915], 
             UndirectedEdge[331, 338] -> 
             RGBColor[
              0.9787135631235049, 0.9836451907476271, 0.9209165646267291], 
             UndirectedEdge[239, 246] -> 
             RGBColor[
              0.9559020848161581, 0.8586869110261035, 0.5345745619341234], 
             UndirectedEdge[190, 212] -> 
             RGBColor[
              0.9539458909968077, 0.8948036564046948, 0.6104187630206317], 
             UndirectedEdge[111, 286] -> 
             RGBColor[
              0.9318177852818259, 0.9460683265165413, 0.900005508563591], 
             UndirectedEdge[228, 273] -> 
             RGBColor[
              0.9877154019716206, 0.9785975292034423, 0.6223547225789868], 
             UndirectedEdge[199, 299] -> 
             RGBColor[
              0.9735432564672564, 0.9197621444420674, 0.486825920618598], 
             UndirectedEdge[50, 391] -> 
             RGBColor[
              0.9880204894313253, 0.983423532036366, 0.649783761937061], 
             UndirectedEdge[358, 362] -> 
             RGBColor[
              0.9786247354398125, 0.9804698733603057, 0.7380574505258125], 
             UndirectedEdge[42, 98] -> 
             RGBColor[
              0.9859575121283074, 0.9642935324551425, 0.3999480156301411], 
             UndirectedEdge[39, 251] -> 
             RGBColor[
              0.9050223613274968, 0.6153420357208448, 0.5502707248935359], 
             UndirectedEdge[148, 179] -> 
             RGBColor[
              0.9097072321552939, 0.9291280082243398, 0.9278603556592404], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.9753565107880462, 0.9303632957174429, 0.5291054090474934], 
             UndirectedEdge[77, 333] -> 
             RGBColor[
              0.9048705176227575, 0.6662815900330562, 0.5700226870250249], 
             UndirectedEdge[173, 354] -> 
             RGBColor[
              0.9756007438654978, 0.9782086606058469, 0.7427061727591259], 
             UndirectedEdge[160, 217] -> 
             RGBColor[
              0.9943351210630637, 0.9902917216980389, 0.6247910711739098], 
             UndirectedEdge[59, 90] -> 
             RGBColor[
              0.9199403509692958, 0.938999481020049, 0.9922259259875393], 
             UndirectedEdge[237, 380] -> 
             RGBColor[
              0.9512177563294812, 0.9624409699948908, 0.9410947669164513], 
             UndirectedEdge[285, 399] -> 
             RGBColor[
              0.9698970984760362, 0.9278026433163098, 0.6031765147925807], 
             UndirectedEdge[51, 392] -> 
             RGBColor[
              0.6125177591280064, 0.6757501471981389, 0.836915893791119], 
             UndirectedEdge[264, 307] -> 
             RGBColor[
              0.9775801434528844, 0.9812468152836638, 0.8532853695925402], 
             UndirectedEdge[78, 208] -> 
             RGBColor[
              0.926611765923501, 0.8312990500264101, 0.6231478892230864], 
             UndirectedEdge[28, 383] -> 
             RGBColor[
              0.8827838851754126, 0.560630823748256, 0.2239043393715225], 
             UndirectedEdge[255, 268] -> 
             RGBColor[
              0.9899803410820112, 0.9899171507108082, 0.8006338150345673], 
             UndirectedEdge[46, 247] -> 
             RGBColor[
              0.9860593409364031, 0.9666167645886793, 0.5717228177218663], 
             UndirectedEdge[272, 392] -> 
             RGBColor[
              0.5292478314197447, 0.6126212985881201, 0.9599503534056071], 
             UndirectedEdge[316, 359] -> 
             RGBColor[
              0.9084259013087649, 0.9261532461884179, 0.8321647060290001], 
             UndirectedEdge[223, 242] -> 
             RGBColor[
              0.9329619809453777, 0.7537640505761815, 0.49129757001683083`], 
             UndirectedEdge[158, 390] -> 
             RGBColor[
              0.987417429913892, 0.9890647981591623, 0.8581892791817638], 
             UndirectedEdge[26, 128] -> 
             RGBColor[
              0.9497206333972719, 0.8977298080571345, 0.6222861344434355], 
             UndirectedEdge[136, 335] -> 
             RGBColor[
              0.9942389423093618, 0.9900860050690343, 0.614322607379926], 
             UndirectedEdge[193, 248] -> 
             RGBColor[
              0.984259375842397, 0.9668590350581499, 0.6083722557695561], 
             UndirectedEdge[281, 386] -> 
             RGBColor[
              0.9340940295807452, 0.7705083535217808, 0.5411828260220072], 
             UndirectedEdge[225, 337] -> 
             RGBColor[
              0.9837007943918894, 0.9699849577985951, 0.6408322364121599], 
             UndirectedEdge[30, 297] -> 
             RGBColor[
              0.966354587783685, 0.9065105215202219, 0.5742191722284179], 
             UndirectedEdge[32, 104] -> 
             RGBColor[
              0.8902600500943281, 0.7081909653913283, 0.6005362185348107], 
             UndirectedEdge[264, 366] -> 
             RGBColor[
              0.9941520111990854, 0.9914027098900353, 0.7140868796415908], 
             UndirectedEdge[2, 97] -> 
             RGBColor[
              0.974849062601306, 0.9760057634152353, 0.6892803384539133], 
             UndirectedEdge[258, 377] -> 
             RGBColor[
              0.9338767951931961, 0.7537884430281103, 0.4746440966319599], 
             UndirectedEdge[134, 135] -> 
             RGBColor[
              0.968527442309512, 0.9760483985227932, 0.9381590101990265], 
             UndirectedEdge[185, 338] -> 
             RGBColor[
              0.9320100433741934, 0.7690630512798355, 0.5676012491151452], 
             UndirectedEdge[40, 84] -> 
             RGBColor[
              0.8573082192382844, 0.8890583192816663, 0.9862520173506715], 
             UndirectedEdge[217, 242] -> 
             RGBColor[
              0.9335001123678424, 0.7528846314562425, 0.4022791862228677], 
             UndirectedEdge[124, 266] -> 
             RGBColor[
              0.9042595043186643, 0.8411123040539161, 0.6272044330362201], 
             UndirectedEdge[219, 293] -> 
             RGBColor[
              0.9897309084799388, 0.9888386757073476, 0.733871493809932], 
             UndirectedEdge[37, 170] -> 
             RGBColor[
              0.9049261966182198, 0.562653690233648, 0.4688112636192401], 
             UndirectedEdge[205, 293] -> 
             RGBColor[
              0.9898842047957764, 0.9891665610262892, 0.750556851753656], 
             UndirectedEdge[122, 268] -> 
             RGBColor[
              0.9897793836331172, 0.9894873230475391, 0.7787608368880912], 
             UndirectedEdge[246, 392] -> 
             RGBColor[
              0.6102276339674446, 0.6748031215907144, 0.8748691943555589], 
             UndirectedEdge[282, 398] -> 
             RGBColor[
              0.9769812589376989, 0.9340145227187437, 0.36507696700780795`], 
             UndirectedEdge[34, 248] -> 
             RGBColor[
              0.9888304217086914, 0.9896491065785444, 0.8347723484363947], 
             UndirectedEdge[263, 264] -> 
             RGBColor[
              0.9941201094550359, 0.9918365284004323, 0.7471085332063971], 
             UndirectedEdge[100, 377] -> 
             RGBColor[
              0.930630659978303, 0.7524460826948821, 0.528440957871384], 
             UndirectedEdge[107, 241] -> 
             RGBColor[
              0.9900839988045798, 0.9901674929231563, 0.8139973318039937], 
             UndirectedEdge[11, 95] -> 
             RGBColor[
              0.956958631713847, 0.939699152787262, 0.6708160376363961], 
             UndirectedEdge[7, 96] -> 
             RGBColor[
              0.9350002720040661, 0.7713252732908209, 0.29676406417761275`], 
             UndirectedEdge[111, 383] -> 
             RGBColor[
              0.8705931506536246, 0.6971269261821761, 0.599572048861682], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.9083596193341766, 0.9273025985287973, 0.8951268937175693], 
             UndirectedEdge[121, 122] -> 
             RGBColor[
              0.9916334199786575, 0.9902540147229806, 0.7480346565502343], 
             UndirectedEdge[156, 221] -> 
             RGBColor[
              0.9715563037080832, 0.9505156170482396, 0.6459564227050725], 
             UndirectedEdge[61, 176] -> 
             RGBColor[
              0.9864433992412205, 0.9873253662697266, 0.8060999856322612], 
             UndirectedEdge[128, 261] -> 
             RGBColor[
              0.95490475898491, 0.9015961204321685, 0.6135107620600633], 
             UndirectedEdge[69, 381] -> 
             RGBColor[
              0.9905656151684055, 0.9903666536665742, 0.8060157022722059], 
             UndirectedEdge[166, 178] -> 
             RGBColor[
              0.9656303985561618, 0.8887716723175141, 0.45789144779932933`], 
             UndirectedEdge[114, 202] -> 
             RGBColor[
              0.9914952294614242, 0.9895140696066185, 0.7006924945941139], 
             UndirectedEdge[40, 134] -> 
             RGBColor[
              0.9235093847879717, 0.94125443223617, 0.9720794879837117], 
             UndirectedEdge[84, 234] -> 
             RGBColor[
              0.9059908527894444, 0.9263230526880271, 0.9343834855350938], 
             UndirectedEdge[236, 367] -> 
             RGBColor[
              0.9873640181001078, 0.9867623269272732, 0.7053883955430837], 
             UndirectedEdge[307, 366] -> 
             RGBColor[
              0.9781919710755527, 0.9810528110274909, 0.8106528434189562], 
             UndirectedEdge[129, 396] -> 
             RGBColor[
              0.9321398054379623, 0.7950813418633178, 0.5846433770967945], 
             UndirectedEdge[67, 208] -> 
             RGBColor[
              0.9360861737560717, 0.7843100075025208, 0.2674316390350579], 
             UndirectedEdge[203, 309] -> 
             RGBColor[
              0.9464881043870452, 0.8185618737489732, 0.3121965787756558], 
             UndirectedEdge[142, 302] -> 
             RGBColor[
              0.9387207932218687, 0.8003626712869444, 0.5737520308515172], 
             UndirectedEdge[93, 248] -> 
             RGBColor[
              0.9877257280158933, 0.9891922873472396, 0.853079981781691], 
             UndirectedEdge[110, 227] -> 
             RGBColor[
              0.9024616098552602, 0.8942346777312626, 0.6660347683857144], 
             UndirectedEdge[129, 361] -> 
             RGBColor[
              0.9279743401583651, 0.7919747446781176, 0.591694423287812], 
             UndirectedEdge[236, 332] -> 
             RGBColor[
              0.9393519180162266, 0.7804945263313376, 0.3604747911131772], 
             UndirectedEdge[306, 353] -> 
             RGBColor[
              0.8931339481235372, 0.8889733121041156, 0.6682344540797585], 
             UndirectedEdge[257, 280] -> 
             RGBColor[
              0.8863395279308193, 0.9023622061247967, 0.6948601319041057], 
             UndirectedEdge[208, 385] -> 
             RGBColor[
              0.9499603819553111, 0.8487149646492518, 0.5837133565900412], 
             UndirectedEdge[79, 302] -> 
             RGBColor[
              0.9426414748508312, 0.8021959128301726, 0.5182672482850849], 
             UndirectedEdge[21, 242] -> 
             RGBColor[
              0.9331957168197784, 0.7522335601580448, 0.36914760932768503`], 
             UndirectedEdge[94, 103] -> 
             RGBColor[
              0.9807320541959375, 0.9833874963660285, 0.8385453842089358], 
             UndirectedEdge[237, 308] -> 
             RGBColor[
              0.989257307880171, 0.9878843001536448, 0.6865831916579519], 
             UndirectedEdge[1, 235] -> 
             RGBColor[
              0.9850588215962861, 0.9714632098171728, 0.624662219887677], 
             UndirectedEdge[31, 374] -> 
             RGBColor[
              0.9654851387777323, 0.9737348750358901, 0.9413125204682655], 
             UndirectedEdge[324, 351] -> 
             RGBColor[
              0.9119369975132674, 0.931970939839998, 0.9690346714700908], 
             UndirectedEdge[62, 396] -> 
             RGBColor[
              0.9814189195953227, 0.9842183181151207, 0.851648407848632], 
             UndirectedEdge[13, 123] -> 
             RGBColor[
              0.952794464047387, 0.8373394040408858, 0.47963988508419697`], 
             UndirectedEdge[112, 337] -> 
             RGBColor[
              0.9853175524205142, 0.9881964448512603, 0.8929896835557887], 
             UndirectedEdge[262, 286] -> 
             RGBColor[
              0.9872286298268809, 0.9743997726978795, 0.6027983884894943], 
             UndirectedEdge[56, 59] -> 
             RGBColor[
              0.9621435618579748, 0.9704563069318076, 0.9118879371356909], 
             UndirectedEdge[61, 118] -> 
             RGBColor[
              0.9853709081518259, 0.9850314162749941, 0.6893659491994409], 
             UndirectedEdge[14, 235] -> 
             RGBColor[
              0.9598506240533535, 0.8794832523239068, 0.5629121226563668], 
             UndirectedEdge[154, 286] -> 
             RGBColor[
              0.9916803881328942, 0.9890052393107758, 0.6550716694247131], 
             UndirectedEdge[159, 215] -> 
             RGBColor[
              0.9263954334399781, 0.7194177497470691, 0.4694658794137721], 
             UndirectedEdge[25, 385] -> 
             RGBColor[
              0.9620736921988611, 0.9712352022573156, 0.9490835257287504], 
             UndirectedEdge[165, 256] -> 
             RGBColor[
              0.9933582874620999, 0.9915210843888023, 0.7597040169203346], 
             UndirectedEdge[292, 384] -> 
             RGBColor[
              0.9467408795502187, 0.8209228003019191, 0.30532353668347034`], 
             UndirectedEdge[1, 49] -> 
             RGBColor[
              0.9842475138644915, 0.9585253067846058, 0.3933049952812927], 
             UndirectedEdge[93, 125] -> 
             RGBColor[
              0.9675551258237021, 0.910556071904312, 0.5716903591677297], 
             UndirectedEdge[15, 37] -> 
             RGBColor[
              0.906210652150278, 0.5630298245344556, 0.4362561160344099], 
             UndirectedEdge[141, 399] -> 
             RGBColor[
              0.9145397763186778, 0.6747745686546698, 0.5541445670928387], 
             UndirectedEdge[42, 288] -> 
             RGBColor[
              0.9873777086253466, 0.9853248471315035, 0.6680200479891255], 
             UndirectedEdge[26, 218] -> 
             RGBColor[
              0.9553144364336854, 0.9188977925935907, 0.6320449519620448], 
             UndirectedEdge[292, 389] -> 
             RGBColor[
              0.9846593863601212, 0.9587940546355145, 0.49019233436592813`], 
             UndirectedEdge[87, 361] -> 
             RGBColor[
              0.9379872658604944, 0.8345238976142539, 0.5998985499875572], 
             UndirectedEdge[3, 11] -> 
             RGBColor[
              0.8474226070562483, 0.8532632650432901, 0.6636783747989405], 
             UndirectedEdge[217, 364] -> 
             RGBColor[
              0.9945876439725013, 0.9908318426673435, 0.6522766314754506], 
             UndirectedEdge[83, 120] -> 
             RGBColor[
              0.9581845302357972, 0.9646816291651668, 0.7438665781224404], 
             UndirectedEdge[251, 380] -> 
             RGBColor[
              0.9474578600455965, 0.9598513195179452, 0.9570638751887687], 
             UndirectedEdge[209, 390] -> 
             RGBColor[
              0.9801105249174478, 0.9509619576061601, 0.5791079992154006], 
             UndirectedEdge[149, 315] -> 
             RGBColor[
              0.9704656939424505, 0.924179274931002, 0.5842290261473619], 
             UndirectedEdge[34, 263] -> 
             RGBColor[
              0.9919211314361119, 0.9909271944784499, 0.7835512897526585], 
             UndirectedEdge[327, 376] -> 
             RGBColor[
              0.9926441027553392, 0.990046043051245, 0.6857876163160836], 
             UndirectedEdge[113, 316] -> 
             RGBColor[
              0.9944524698634807, 0.9905427189163475, 0.6375637639064662], 
             UndirectedEdge[85, 307] -> 
             RGBColor[
              0.9775068571048875, 0.9795874215198862, 0.7360824157453792], 
             UndirectedEdge[140, 257] -> 
             RGBColor[
              0.9707313115773403, 0.9689229546325965, 0.6877343314794979], 
             UndirectedEdge[228, 330] -> 
             RGBColor[
              0.9640519542589792, 0.9720008168579699, 0.9139498931198857], 
             UndirectedEdge[22, 96] -> 
             RGBColor[
              0.9442805690036824, 0.8015624645357118, 0.4235827783089401], 
             UndirectedEdge[22, 323] -> 
             RGBColor[
              0.9934423333535449, 0.9883821390620622, 0.5276166386398712], 
             UndirectedEdge[167, 269] -> 
             RGBColor[
              0.9749424343804278, 0.9271370887482971, 0.35715651860252096`], 
             UndirectedEdge[85, 214] -> 
             RGBColor[
              0.9212827611206973, 0.9354242874265719, 0.7538947335814092], 
             UndirectedEdge[89, 155] -> 
             RGBColor[
              0.8991277714869719, 0.9218305497742686, 0.9703556276685508], 
             UndirectedEdge[1, 396] -> 
             RGBColor[
              0.9764195049193931, 0.9655246884783368, 0.6618863440997451], 
             UndirectedEdge[172, 208] -> 
             RGBColor[
              0.9553432400175867, 0.8493413021887724, 0.36944517970583785`], 
             UndirectedEdge[45, 339] -> 
             RGBColor[
              0.9335996260546919, 0.7593872738155442, 0.31016884303682085`], 
             UndirectedEdge[250, 363] -> 
             RGBColor[
              0.9822660104758636, 0.951841230575643, 0.3856072287919899], 
             UndirectedEdge[167, 222] -> 
             RGBColor[
              0.9801485422573757, 0.9675917841267596, 0.6540583393632018], 
             UndirectedEdge[73, 208] -> 
             RGBColor[
              0.9553251788107102, 0.8493026710935316, 0.3674793287981818], 
             UndirectedEdge[14, 317] -> 
             RGBColor[
              0.9525867249425621, 0.844779243429479, 0.3064877990122161], 
             UndirectedEdge[157, 334] -> 
             RGBColor[
              0.9925137704731468, 0.9849379776232294, 0.5505311404080012], 
             UndirectedEdge[107, 190] -> 
             RGBColor[
              0.9746479264579624, 0.9803430055819918, 0.9157056842085635], 
             UndirectedEdge[12, 209] -> 
             RGBColor[
              0.9547496707494209, 0.8540302298715197, 0.304709478679702], 
             UndirectedEdge[185, 219] -> 
             RGBColor[
              0.9372892565881824, 0.7702028074834256, 0.4003793691681451], 
             UndirectedEdge[318, 345] -> 
             RGBColor[
              0.9732296600247867, 0.9785669557813101, 0.8859390939634212], 
             UndirectedEdge[36, 383] -> 
             RGBColor[
              0.8871689909995715, 0.710344051334834, 0.6011530673113059], 
             UndirectedEdge[24, 357] -> 
             RGBColor[
              0.9732338102180818, 0.9303471301841464, 0.570239575615175], 
             UndirectedEdge[344, 354] -> 
             RGBColor[
              0.9245072983794816, 0.7082348903098871, 0.3649205110946399], 
             UndirectedEdge[7, 194] -> 
             RGBColor[
              0.9823926222028243, 0.9596820241581199, 0.5950376565120922], 
             UndirectedEdge[97, 248] -> 
             RGBColor[
              0.9901381541783483, 0.9866895347881086, 0.6312101994905915], 
             UndirectedEdge[14, 129] -> 
             RGBColor[
              0.9134000789258769, 0.691515962056869, 0.24903038297735858`], 
             UndirectedEdge[160, 307] -> 
             RGBColor[
              0.9781428463211577, 0.9809477381451144, 0.805305917065893], 
             UndirectedEdge[165, 400] -> 
             RGBColor[
              0.9915442380569086, 0.9907713393804313, 0.7897973884148569], 
             UndirectedEdge[310, 323] -> 
             RGBColor[
              0.9860508467525899, 0.9645163488056276, 0.4081355962354285], 
             UndirectedEdge[309, 339] -> 
             RGBColor[
              0.9493042464447536, 0.8280613821712234, 0.323136758886049], 
             UndirectedEdge[355, 395] -> 
             RGBColor[
              0.9602130852618573, 0.9698475646501625, 0.952233047949089], 
             UndirectedEdge[32, 240] -> 
             RGBColor[
              0.9546032974867336, 0.9623739597600339, 0.7879402259367265], 
             UndirectedEdge[66, 322] -> 
             RGBColor[
              0.974667043152288, 0.9257622224158311, 0.3940033930070025], 
             UndirectedEdge[28, 267] -> 
             RGBColor[
              0.9427919871675783, 0.8090691565741577, 0.544498893138082], 
             UndirectedEdge[51, 102] -> 
             RGBColor[
              0.9922326043337562, 0.9910559965261142, 0.7783893777726731], 
             UndirectedEdge[244, 321] -> 
             RGBColor[
              0.900797836188026, 0.6329317867454359, 0.2384443940403435], 
             UndirectedEdge[140, 309] -> 
             RGBColor[
              0.9330700195599522, 0.8292904948288151, 0.6070070827782594], 
             UndirectedEdge[12, 324] -> 
             RGBColor[
              0.9499333134215971, 0.8832309434441343, 0.6105540996923784], 
             UndirectedEdge[130, 287] -> 
             RGBColor[
              0.9872155239216063, 0.9751214494213618, 0.6080412501455232], 
             UndirectedEdge[267, 367] -> 
             RGBColor[
              0.9846730354337525, 0.9874972828094188, 0.8842965976454618], 
             UndirectedEdge[138, 229] -> 
             RGBColor[
              0.991166744153117, 0.9904387416067313, 0.7832241637324044], 
             UndirectedEdge[97, 193] -> 
             RGBColor[
              0.9858789141419317, 0.9640284029914128, 0.3996426772950561], 
             UndirectedEdge[248, 340] -> 
             RGBColor[
              0.9911208506462486, 0.9892514030925785, 0.6990572728750903], 
             UndirectedEdge[162, 248] -> 
             RGBColor[
              0.9649246941399242, 0.9726426667451783, 0.912067828145813], 
             UndirectedEdge[127, 317] -> 
             RGBColor[
              0.9733658028742234, 0.9218187404671874, 0.35103160292279373`], 
             UndirectedEdge[269, 355] -> 
             RGBColor[
              0.9658241368192647, 0.9374602890663692, 0.6370205978330687], 
             UndirectedEdge[161, 184] -> 
             RGBColor[
              0.9726175082088067, 0.9158881566357294, 0.4981351846152754], 
             UndirectedEdge[340, 360] -> 
             RGBColor[
              0.9841852984316295, 0.9575624418908228, 0.4570927832463852], 
             UndirectedEdge[19, 185] -> 
             RGBColor[
              0.9309253717900982, 0.7496048579044666, 0.3017695001212145], 
             UndirectedEdge[240, 357] -> 
             RGBColor[
              0.9761848737018956, 0.9304281157442567, 0.4385137335925449], 
             UndirectedEdge[75, 132] -> 
             RGBColor[
              0.9948765594863915, 0.9914498037377155, 0.6837233021825343], 
             UndirectedEdge[89, 353] -> 
             RGBColor[
              0.966109000942356, 0.9465234831755295, 0.6553268493310451], 
             UndirectedEdge[214, 312] -> 
             RGBColor[
              0.8849378717760042, 0.9110894542283055, 0.9888873582750012], 
             UndirectedEdge[119, 129] -> 
             RGBColor[
              0.9440101063045092, 0.8023559581970819, 0.493873483343112], 
             UndirectedEdge[143, 377] -> 
             RGBColor[
              0.9306305431431328, 0.7524460343805367, 0.528442894132514], 
             UndirectedEdge[5, 122] -> 
             RGBColor[
              0.9899232927012566, 0.9895468331455091, 0.776375891204294], 
             UndirectedEdge[42, 318] -> 
             RGBColor[
              0.9909399345799013, 0.9869932004014405, 0.6177298404469496], 
             UndirectedEdge[6, 137] -> 
             RGBColor[
              0.9150363031800622, 0.931563233490686, 0.8440656196646527], 
             UndirectedEdge[113, 149] -> 
             RGBColor[
              0.9899042849253072, 0.9890297493996907, 0.7396757233769542], 
             UndirectedEdge[67, 124] -> 
             RGBColor[
              0.9139965284710205, 0.8797163601470565, 0.635039071226538], 
             UndirectedEdge[141, 337] -> 
             RGBColor[
              0.9161475986372617, 0.6758173377660677, 0.544421622784504], 
             UndirectedEdge[63, 224] -> 
             RGBColor[
              0.9781020528174432, 0.9824838377598648, 0.8903673826648584], 
             UndirectedEdge[244, 357] -> 
             RGBColor[
              0.9114049892662123, 0.674262454541199, 0.25074538553876474`], 
             UndirectedEdge[9, 192] -> 
             RGBColor[
              0.9399687709574098, 0.9529905313483539, 0.9191436999358656], 
             UndirectedEdge[46, 369] -> 
             RGBColor[
              0.9871243117741206, 0.9667407036232345, 0.5310706460731384], 
             UndirectedEdge[350, 392] -> 
             RGBColor[
              0.5959516420760571, 0.620731041585654, 0.6208244931043336], 
             UndirectedEdge[275, 339] -> 
             RGBColor[
              0.9682543681930011, 0.9625081678066474, 0.6822312411084106], 
             UndirectedEdge[119, 127] -> 
             RGBColor[
              0.9838606861746688, 0.9578588443565433, 0.55391015702533], 
             UndirectedEdge[152, 398] -> 
             RGBColor[
              0.9784444826637022, 0.938112891713428, 0.4419701655238448], 
             UndirectedEdge[105, 229] -> 
             RGBColor[
              0.9866809624689715, 0.9876023071807195, 0.8136139095924775], 
             UndirectedEdge[181, 365] -> 
             RGBColor[
              0.9102976848604034, 0.9313106808080172, 0.9913061998859636], 
             UndirectedEdge[24, 285] -> 
             RGBColor[
              0.972967980868121, 0.9294504253670294, 0.5692068787882383], 
             UndirectedEdge[167, 189] -> 
             RGBColor[
              0.9872576243799245, 0.971568160818917, 0.5826630035469174], 
             UndirectedEdge[157, 191] -> 
             RGBColor[
              0.9767047326726883, 0.9752651838508866, 0.6816291867707386], 
             UndirectedEdge[78, 194] -> 
             RGBColor[
              0.9623565983864668, 0.9706260352396038, 0.9119021237387288], 
             UndirectedEdge[107, 268] -> 
             RGBColor[
              0.9853682976648361, 0.9882174293138809, 0.8921487035328907], 
             UndirectedEdge[5, 274] -> 
             RGBColor[
              0.9872921524908707, 0.98901299272526, 0.8602654502888087], 
             UndirectedEdge[12, 118] -> 
             RGBColor[
              0.9659356949775109, 0.8915866819126872, 0.36318477499975343`], 
             UndirectedEdge[20, 291] -> 
             RGBColor[
              0.6182368238450417, 0.6799519121500792, 0.681102509448293], 
             UndirectedEdge[6, 379] -> 
             RGBColor[
              0.990829391984692, 0.9902867235308745, 0.787905305815521], 
             UndirectedEdge[97, 181] -> 
             RGBColor[
              0.9509744728103192, 0.957542358883374, 0.7068883346749065], 
             UndirectedEdge[39, 320] -> 
             RGBColor[
              0.8858606287893058, 0.6010512469683194, 0.582706539900443], 
             UndirectedEdge[202, 218] -> 
             RGBColor[
              0.9766125620057662, 0.9319406667301268, 0.4342350093925867], 
             UndirectedEdge[61, 344] -> 
             RGBColor[
              0.9167560666715636, 0.7055690290295311, 0.5615209074492604], 
             UndirectedEdge[181, 214] -> 
             RGBColor[
              0.8796815822518633, 0.9068982316399337, 0.9883860086878435], 
             UndirectedEdge[274, 324] -> 
             RGBColor[
              0.9750808708897492, 0.9800744675119014, 0.8884874985391692], 
             UndirectedEdge[62, 231] -> 
             RGBColor[
              0.9897413411556248, 0.9900257951794135, 0.819676055816746], 
             UndirectedEdge[117, 289] -> 
             RGBColor[
              0.9595167443041318, 0.8657686633515451, 0.3798564612776534], 
             UndirectedEdge[14, 396] -> 
             RGBColor[
              0.9512113073764605, 0.8735447309850708, 0.6001362468684348], 
             UndirectedEdge[79, 175] -> 
             RGBColor[
              0.9889111635816962, 0.9896824954180035, 0.8334342466474347], 
             UndirectedEdge[246, 395] -> 
             RGBColor[
              0.9732218821981189, 0.9785637394501019, 0.8860679926796796], 
             UndirectedEdge[87, 396] -> 
             RGBColor[
              0.9421527311400917, 0.8376304947994542, 0.5928475037965397], 
             UndirectedEdge[341, 366] -> 
             RGBColor[
              0.9691448127107695, 0.9025071494788452, 0.47243603981363713`], 
             UndirectedEdge[40, 226] -> 
             RGBColor[
              0.8687886367841733, 0.8982124926051256, 0.9873470298248881], 
             UndirectedEdge[67, 316] -> 
             RGBColor[
              0.9747021835955102, 0.9244564765084795, 0.48186626933404264`], 
             UndirectedEdge[303, 376] -> 
             RGBColor[
              0.9816341143108256, 0.9537776169480929, 0.5689650761987793], 
             UndirectedEdge[208, 357] -> 
             RGBColor[
              0.9380160327401414, 0.791238095751956, 0.2727506760230824], 
             UndirectedEdge[54, 66] -> 
             RGBColor[
              0.9934269524063899, 0.9897757796444453, 0.6296368342263647], 
             UndirectedEdge[3, 160] -> 
             RGBColor[
              0.8576166171327384, 0.8863153738568648, 0.8167718037947032], 
             UndirectedEdge[230, 328] -> 
             RGBColor[
              0.9895967315094778, 0.9753764127200855, 0.5155350115923634], 
             UndirectedEdge[282, 383] -> 
             RGBColor[
              0.9293377103161282, 0.7367037762482014, 0.3153157824995977], 
             UndirectedEdge[106, 150] -> 
             RGBColor[
              0.9574938535445021, 0.861626459469785, 0.5193582398596046], 
             UndirectedEdge[1, 298] -> 
             RGBColor[
              0.9890066626161995, 0.9729606030597544, 0.5494129916553833], 
             UndirectedEdge[66, 131] -> 
             RGBColor[
              0.9229208640459214, 0.936617707152646, 0.7449103607081295], 
             UndirectedEdge[53, 126] -> 
             RGBColor[
              0.9769863790975106, 0.9471709859310005, 0.613609790998074], 
             UndirectedEdge[182, 281] -> 
             RGBColor[
              0.969231921121456, 0.9165426876429936, 0.5698034395836047], 
             UndirectedEdge[74, 263] -> 
             RGBColor[
              0.9907452256851315, 0.9795897277838175, 0.5703406753154017], 
             UndirectedEdge[24, 243] -> 
             RGBColor[
              0.991188649948212, 0.989792778973881, 0.7352479984741851], 
             UndirectedEdge[177, 252] -> 
             RGBColor[
              0.9052279474224427, 0.8612385398592537, 0.6316306926172868], 
             UndirectedEdge[10, 216] -> 
             RGBColor[
              0.9748172437086585, 0.9782157654264463, 0.7909605061775162], 
             UndirectedEdge[280, 339] -> 
             RGBColor[
              0.8846011465864819, 0.8964982376589965, 0.688106848647126], 
             UndirectedEdge[152, 154] -> 
             RGBColor[
              0.993514708128436, 0.988536941387342, 0.5354941862414269], 
             UndirectedEdge[36, 304] -> 
             RGBColor[
              0.9507038394544625, 0.9602407844563227, 0.8633003052632323], 
             UndirectedEdge[128, 299] -> 
             RGBColor[
              0.9715770605476077, 0.91196683281661, 0.4852438732290987], 
             UndirectedEdge[95, 162] -> 
             RGBColor[
              0.940485233334373, 0.9551345649840375, 0.9856271554144858], 
             UndirectedEdge[215, 329] -> 
             RGBColor[
              0.9256494890091493, 0.7174101089424422, 0.3583161248287532], 
             UndirectedEdge[208, 387] -> 
             RGBColor[
              0.9463118402255146, 0.8192218023483471, 0.30497832157196614`], 
             UndirectedEdge[178, 197] -> 
             RGBColor[
              0.9633959248411091, 0.8884817867989002, 0.5410167830437521], 
             UndirectedEdge[53, 303] -> 
             RGBColor[
              0.9703112501831622, 0.9115150169971595, 0.3391652425218954], 
             UndirectedEdge[59, 121] -> 
             RGBColor[
              0.9619009190982812, 0.9703559679150398, 0.9159091556031467], 
             UndirectedEdge[134, 269] -> 
             RGBColor[
              0.9630769033009433, 0.9354114068065871, 0.6416709475863306], 
             UndirectedEdge[44, 362] -> 
             RGBColor[
              0.9765484651976709, 0.9811800050959514, 0.886496211730764], 
             UndirectedEdge[284, 338] -> 
             RGBColor[
              0.9862346811317484, 0.9884362299799119, 0.871544683741142], 
             UndirectedEdge[12, 346] -> 
             RGBColor[
              0.9668864507365058, 0.8936202523450246, 0.46666867198194373`], 
             UndirectedEdge[113, 387] -> 
             RGBColor[
              0.9845246877905935, 0.9585059480154092, 0.47553122633605555`], 
             UndirectedEdge[55, 400] -> 
             RGBColor[
              0.949086750337242, 0.9595575044382803, 0.889466885466955], 
             UndirectedEdge[25, 201] -> 
             RGBColor[
              0.9676378642293688, 0.9722493520412308, 0.7545502553465202], 
             UndirectedEdge[123, 309] -> 
             RGBColor[
              0.9119147650087811, 0.6884784264639934, 0.24798275618110296`], 
             UndirectedEdge[35, 162] -> 
             RGBColor[
              0.9548345282228429, 0.9303124527864962, 0.6578482599818528], 
             UndirectedEdge[73, 172] -> 
             RGBColor[
              0.9930448063693336, 0.9875318690389774, 0.48434827966062766`], 
             UndirectedEdge[137, 282] -> 
             RGBColor[
              0.9129715703068795, 0.9261782972520882, 0.7017018625622726], 
             UndirectedEdge[37, 114] -> 
             RGBColor[
              0.9032306778123059, 0.5619525496345568, 0.49691039809524695`], 
             UndirectedEdge[214, 248] -> 
             RGBColor[
              0.9188452636198924, 0.9360454075446683, 0.9127078735035286], 
             UndirectedEdge[161, 363] -> 
             RGBColor[
              0.9877269301449638, 0.9686051913023173, 0.5477214962772127], 
             UndirectedEdge[51, 84] -> 
             RGBColor[
              0.9104583974340255, 0.9281704972092217, 0.8603447091394614], 
             UndirectedEdge[56, 278] -> 
             RGBColor[
              0.989306704969624, 0.9898460619468616, 0.826879102221172], 
             UndirectedEdge[4, 140] -> 
             RGBColor[
              0.9506121143417064, 0.8988390550819139, 0.6211218640055454], 
             UndirectedEdge[221, 351] -> 
             RGBColor[
              0.9159891128825302, 0.9349930008476641, 0.9621754971108781], 
             UndirectedEdge[54, 204] -> 
             RGBColor[
              0.9926644195401844, 0.9912345632111168, 0.7712330823002274], 
             UndirectedEdge[10, 298] -> 
             RGBColor[
              0.9752278312096874, 0.9790939705743826, 0.835650421812163], 
             UndirectedEdge[134, 226] -> 
             RGBColor[
              0.9038926593647697, 0.9256125878655352, 0.9702084272007891], 
             UndirectedEdge[35, 98] -> 
             RGBColor[
              0.9742572315362665, 0.9248257386616623, 0.35449463494265376`], 
             UndirectedEdge[70, 180] -> 
             RGBColor[
              0.9350839868989516, 0.8173336458626905, 0.5931558879629898], 
             UndirectedEdge[165, 328] -> 
             RGBColor[
              0.9880961959855656, 0.9754856299520487, 0.5934462349394753], 
             UndirectedEdge[162, 214] -> 
             RGBColor[
              0.8952513418810031, 0.9191679074350008, 0.9848359236842501], 
             UndirectedEdge[211, 370] -> 
             RGBColor[
              0.9914869132863011, 0.9903836473111873, 0.7642894100470942], 
             UndirectedEdge[55, 245] -> 
             RGBColor[
              0.9503575544288809, 0.9600830145883483, 0.8684063729329314], 
             UndirectedEdge[247, 315] -> 
             RGBColor[
              0.9739786801892356, 0.9256319850236763, 0.5260097527211536], 
             UndirectedEdge[16, 268] -> 
             RGBColor[
              0.9211595861037958, 0.9385816014592768, 0.9429262308715278], 
             UndirectedEdge[154, 291] -> 
             RGBColor[
              0.9927871344704979, 0.9869200928110915, 0.4614588493239644], 
             UndirectedEdge[296, 373] -> 
             RGBColor[
              0.968549414577585, 0.9734460952564779, 0.794021872309191], 
             UndirectedEdge[101, 394] -> 
             RGBColor[
              0.9632003104083762, 0.9716486402394968, 0.9280638357080119], 
             UndirectedEdge[173, 388] -> 
             RGBColor[
              0.9332242852386445, 0.82187472223778, 0.6009031532996889], 
             UndirectedEdge[84, 102] -> 
             RGBColor[
              0.9079852831689241, 0.9271478009044648, 0.9013306127267442], 
             UndirectedEdge[216, 298] -> 
             RGBColor[
              0.99471476178113, 0.9911037348064183, 0.6661126204645004], 
             UndirectedEdge[209, 310] -> 
             RGBColor[
              0.9749333703391669, 0.9271065136087859, 0.3571213065138228], 
             UndirectedEdge[34, 93] -> 
             RGBColor[
              0.9880375338457712, 0.9893212270709384, 0.8479125522529941], 
             UndirectedEdge[112, 285] -> 
             RGBColor[
              0.9716894259472921, 0.9289217100499039, 0.5903958426204418], 
             UndirectedEdge[131, 309] -> 
             RGBColor[
              0.8829987793380675, 0.7898049697995712, 0.617483641996772], 
             UndirectedEdge[116, 265] -> 
             RGBColor[
              0.9921370982682265, 0.989736824523287, 0.6869530940483106], 
             UndirectedEdge[49, 129] -> 
             RGBColor[
              0.9399678143830605, 0.7880819601695868, 0.3160620282783421], 
             UndirectedEdge[238, 325] -> 
             RGBColor[
              0.5428557142078363, 0.6263338701224136, 0.9608147098115911], 
             UndirectedEdge[112, 399] -> 
             RGBColor[
              0.9837097301019302, 0.9871536757398623, 0.9027126278641233], 
             UndirectedEdge[186, 322] -> 
             RGBColor[
              0.9619364197746868, 0.88326474752568, 0.3066306078389865], 
             UndirectedEdge[180, 332] -> 
             RGBColor[
              0.9253564030255478, 0.7733910531449262, 0.585050752585733], 
             UndirectedEdge[60, 331] -> 
             RGBColor[
              0.9837797628979893, 0.9858796657123485, 0.8432023270752584], 
             UndirectedEdge[14, 126] -> 
             RGBColor[
              0.9588579521216478, 0.8790727569696415, 0.5793632655173415], 
             UndirectedEdge[275, 288] -> 
             RGBColor[
              0.9671490756450793, 0.9750204149213276, 0.9404922254263093], 
             UndirectedEdge[276, 290] -> 
             RGBColor[
              0.9121563095185157, 0.6769777758094396, 0.25319138022650667`], 
             UndirectedEdge[18, 232] -> 
             RGBColor[
              0.9694722366338748, 0.9126234230125221, 0.5461559051660578], 
             UndirectedEdge[4, 325] -> 
             RGBColor[
              0.8906420563183246, 0.8514604814340073, 0.6306542651453723], 
             UndirectedEdge[1, 62] -> 
             RGBColor[
              0.9878873906261698, 0.9726328958019381, 0.5777855109605063], 
             UndirectedEdge[20, 304] -> 
             RGBColor[
              0.6194402913341277, 0.682992391436887, 0.8364291077990591], 
             UndirectedEdge[255, 328] -> 
             RGBColor[
              0.9898994197378916, 0.9760238322341881, 0.5484807572799797], 
             UndirectedEdge[3, 74] -> 
             RGBColor[
              0.8536790304945607, 0.8743676503787994, 0.6879833984303549], 
             UndirectedEdge[18, 279] -> 
             RGBColor[
              0.9704266328287354, 0.9130180903659604, 0.5303390903190401], 
             UndirectedEdge[163, 226] -> 
             RGBColor[
              0.9211441320100687, 0.936996048702229, 0.8746096749976217], 
             UndirectedEdge[145, 254] -> 
             RGBColor[
              0.9423579763020892, 0.9282027394991814, 0.6730115572563871], 
             UndirectedEdge[23, 348] -> 
             RGBColor[
              0.9301069228523349, 0.7606042701364528, 0.26262059340685395`], 
             UndirectedEdge[119, 396] -> 
             RGBColor[
              0.9818213347550929, 0.9843847271252837, 0.8449793472341882], 
             UndirectedEdge[73, 141] -> 
             RGBColor[
              0.9200944475845692, 0.6755038831234039, 0.33758913145119335`], 
             UndirectedEdge[29, 396] -> 
             RGBColor[
              0.9638886250812695, 0.9232550883938417, 0.6132062421867319], 
             UndirectedEdge[160, 312] -> 
             RGBColor[
              0.9576847107520003, 0.9653034100456148, 0.8265296241349587], 
             UndirectedEdge[210, 397] -> 
             RGBColor[
              0.9128478591353466, 0.7936731814487978, 0.616011261979348], 
             UndirectedEdge[11, 86] -> 
             RGBColor[
              0.9790137550567999, 0.9408706093812544, 0.3729728306258291], 
             UndirectedEdge[113, 315] -> 
             RGBColor[
              0.9746107166062643, 0.9248299211087623, 0.4382353411419785], 
             UndirectedEdge[120, 160] -> 
             RGBColor[
              0.9939050201195903, 0.9893717792698251, 0.5779772377521715], 
             UndirectedEdge[5, 308] -> 
             RGBColor[
              0.9891193326276665, 0.9878272438409319, 0.6888697986604582], 
             UndirectedEdge[37, 261] -> 
             RGBColor[
              0.8894695516646758, 0.5525119582105595, 0.5570346666849528], 
             UndirectedEdge[22, 241] -> 
             RGBColor[
              0.9942915732850242, 0.9910020961624992, 0.6784584956354816], 
             UndirectedEdge[55, 165] -> 
             RGBColor[
              0.9489775636691289, 0.959512352945046, 0.8912763911236287], 
             UndirectedEdge[251, 283] -> 
             RGBColor[
              0.9764572586919397, 0.9819624425969251, 0.9247358994909252], 
             UndirectedEdge[334, 365] -> 
             RGBColor[
              0.9526455787754469, 0.9614338845740251, 0.8380902493683272], 
             UndirectedEdge[44, 358] -> 
             RGBColor[
              0.9913873140649314, 0.9891377244385036, 0.6783684349906723], 
             UndirectedEdge[225, 367] -> 
             RGBColor[
              0.9819282144903609, 0.9688193127516028, 0.6508340723327597], 
             UndirectedEdge[23, 321] -> 
             RGBColor[
              0.9236173448727161, 0.7348752559709297, 0.2573989266344794], 
             UndirectedEdge[234, 269] -> 
             RGBColor[
              0.9766555142715069, 0.9452760449525381, 0.6069410183948518], 
             UndirectedEdge[21, 208] -> 
             RGBColor[
              0.9555097370879997, 0.8496974225869498, 0.3875673583194829], 
             UndirectedEdge[208, 240] -> 
             RGBColor[
              0.9557924534207175, 0.8503021242356272, 0.41833928641285456`], 
             UndirectedEdge[15, 313] -> 
             RGBColor[
              0.9941769411998449, 0.9899533909650515, 0.607574169235511], 
             UndirectedEdge[63, 204] -> 
             RGBColor[
              0.9797336495321322, 0.9831585449315117, 0.8633276026655186], 
             UndirectedEdge[241, 310] -> 
             RGBColor[
              0.9869000866840691, 0.9671363059060647, 0.5589774532310389], 
             UndirectedEdge[182, 256] -> 
             RGBColor[
              0.9732200356691153, 0.9181914644587008, 0.5036801823781527], 
             UndirectedEdge[373, 380] -> 
             RGBColor[
              0.955560078495579, 0.9632752506239091, 0.7992489881786845], 
             UndirectedEdge[185, 210] -> 
             RGBColor[
              0.8909952949459943, 0.5979169176929904, 0.23075614096416774`], 
             UndirectedEdge[96, 223] -> 
             RGBColor[
              0.9436284834778066, 0.8021981473509812, 0.5001979611897918], 
             UndirectedEdge[103, 222] -> 
             RGBColor[
              0.9723062323854958, 0.9788666139742611, 0.9317625042666814], 
             UndirectedEdge[146, 375] -> 
             RGBColor[
              0.9684043280483577, 0.9148508165624815, 0.5769144478768411], 
             UndirectedEdge[42, 276] -> 
             RGBColor[
              0.9756699914446225, 0.9295913095643478, 0.35998294040929374`], 
             UndirectedEdge[46, 372] -> 
             RGBColor[
              0.9682897797490723, 0.9547919034516126, 0.6657350665203717], 
             UndirectedEdge[95, 285] -> 
             RGBColor[
              0.9487582442945545, 0.9120373204794578, 0.638959081025668], 
             UndirectedEdge[14, 326] -> 
             RGBColor[
              0.9599966874708619, 0.879543653300705, 0.5604914738282478], 
             UndirectedEdge[22, 310] -> 
             RGBColor[
              0.9868410744190312, 0.9662065658798729, 0.49414700100771936`], 
             UndirectedEdge[23, 229] -> 
             RGBColor[
              0.9525589780090024, 0.8364635848304296, 0.4760298478228922], 
             UndirectedEdge[23, 160] -> 
             RGBColor[
              0.9523530660967243, 0.8360231600709549, 0.4536176069124544], 
             UndirectedEdge[165, 311] -> 
             RGBColor[
              0.9927461494680299, 0.9902117831161314, 0.6930765739436087], 
             UndirectedEdge[179, 288] -> 
             RGBColor[
              0.9079175796616991, 0.9281926596335699, 0.948774433680244], 
             UndirectedEdge[51, 167] -> 
             RGBColor[
              0.9885250940631973, 0.9720922921054354, 0.561657750788692], 
             UndirectedEdge[310, 346] -> 
             RGBColor[
              0.987070150326252, 0.966696536082291, 0.5190804998160645], 
             UndirectedEdge[79, 379] -> 
             RGBColor[
              0.988676773702561, 0.989585569179436, 0.8373186935262675], 
             UndirectedEdge[78, 264] -> 
             RGBColor[
              0.964570051482228, 0.9715413549778509, 0.8752194777089778], 
             UndirectedEdge[309, 325] -> 
             RGBColor[
              0.8730999615365702, 0.7819119211809085, 0.6165394839180862], 
             UndirectedEdge[149, 358] -> 
             RGBColor[
              0.9896114232842832, 0.9884033479623942, 0.7077995410840292], 
             UndirectedEdge[6, 79] -> 
             RGBColor[
              0.9929102886781027, 0.9911472277902056, 0.7534194624176902], 
             UndirectedEdge[134, 234] -> 
             RGBColor[
              0.9721920183391317, 0.9785191656425307, 0.920210956168134], 
             UndirectedEdge[96, 209] -> 
             RGBColor[
              0.9323728649238181, 0.7624624122646249, 0.2865570838150436], 
             UndirectedEdge[216, 393] -> 
             RGBColor[
              0.9803957061395274, 0.9823761735734944, 0.781517624378075], 
             UndirectedEdge[164, 388] -> 
             RGBColor[
              0.942881888990145, 0.8290773473027743, 0.5845553492548645], 
             UndirectedEdge[155, 261] -> 
             RGBColor[
              0.9009676067892833, 0.9232026959302786, 0.9672412664076361], 
             UndirectedEdge[125, 288] -> 
             RGBColor[
              0.9655969917581957, 0.9095510518537777, 0.595396612851637], 
             UndirectedEdge[287, 384] -> 
             RGBColor[
              0.9540776991846243, 0.852255963488147, 0.5370317917750134], 
             UndirectedEdge[69, 320] -> 
             RGBColor[
              0.9653459544269595, 0.9725359191817171, 0.8925049615713638], 
             UndirectedEdge[123, 339] -> 
             RGBColor[
              0.9478376756818319, 0.8222469178019746, 0.32195672162536193`], 
             UndirectedEdge[132, 202] -> 
             RGBColor[
              0.994444403577602, 0.9905254659464794, 0.6366857984679056], 
             UndirectedEdge[67, 249] -> 
             RGBColor[
              0.9724568036132858, 0.9238957760204956, 0.5458147912162639], 
             UndirectedEdge[374, 384] -> 
             RGBColor[
              0.9324958219434032, 0.8370709455156583, 0.6143477679802894], 
             UndirectedEdge[99, 252] -> 
             RGBColor[
              0.9264882898066491, 0.9355176783564885, 0.700874900804656], 
             UndirectedEdge[44, 65] -> 
             RGBColor[
              0.9920246823999487, 0.9909700154631348, 0.78183518230058], 
             UndirectedEdge[88, 370] -> 
             RGBColor[
              0.9918524153764516, 0.982723712522511, 0.5465468758339512], 
             UndirectedEdge[13, 275] -> 
             RGBColor[
              0.9732111565585563, 0.9776006540455586, 0.8399144045672458], 
             UndirectedEdge[183, 269] -> 
             RGBColor[
              0.9740169753994226, 0.9435704946649089, 0.6231522591513861], 
             UndirectedEdge[122, 178] -> 
             RGBColor[
              0.9656767207736479, 0.8888707508568221, 0.4629333353050941], 
             UndirectedEdge[199, 216] -> 
             RGBColor[
              0.9732129903799336, 0.9190557386763074, 0.4508784951795365], 
             UndirectedEdge[107, 295] -> 
             RGBColor[
              0.9830686859745428, 0.96683994732635, 0.6313764527479335], 
             UndirectedEdge[89, 171] -> 
             RGBColor[
              0.9761051208450509, 0.9791523249171219, 0.7868811541457837], 
             UndirectedEdge[18, 91] -> 
             RGBColor[
              0.8870541133486809, 0.8492800884894736, 0.6304644341801648], 
             UndirectedEdge[194, 357] -> 
             RGBColor[
              0.9737608652031071, 0.9305650809651498, 0.5615049105387249], 
             UndirectedEdge[147, 388] -> 
             RGBColor[
              0.8709546899195575, 0.46599616690475154`, 0.2124151979333982], 
             UndirectedEdge[96, 323] -> 
             RGBColor[
              0.9434903413372411, 0.7998722474614666, 0.3375713735366493], 
             UndirectedEdge[168, 265] -> 
             RGBColor[
              0.9787198002530895, 0.9390794054549454, 0.4398252396084714], 
             UndirectedEdge[44, 372] -> 
             RGBColor[
              0.9732785781015959, 0.9787413286536473, 0.892031277661278], 
             UndirectedEdge[180, 286] -> 
             RGBColor[
              0.9776701837144316, 0.981870346923664, 0.8780487773356582], 
             UndirectedEdge[18, 45] -> 
             RGBColor[
              0.9154336735154602, 0.6960192043226305, 0.25048254291641026`], 
             UndirectedEdge[83, 217] -> 
             RGBColor[
              0.9586146311792706, 0.9656015715933804, 0.7906804115441787], 
             UndirectedEdge[137, 314] -> 
             RGBColor[
              0.8987054227004493, 0.8780552315248478, 0.6462805730472106], 
             UndirectedEdge[205, 338] -> 
             RGBColor[
              0.9887850112637203, 0.9885725450902221, 0.7625275295850271], 
             UndirectedEdge[210, 293] -> 
             RGBColor[
              0.9434369468377508, 0.8165527859169124, 0.5642482656059545], 
             UndirectedEdge[295, 324] -> 
             RGBColor[
              0.9705521990472993, 0.9577752118672209, 0.6646565430982012], 
             UndirectedEdge[270, 346] -> 
             RGBColor[
              0.9033405199607594, 0.9220522892537075, 0.8226951532090072], 
             UndirectedEdge[26, 349] -> 
             RGBColor[
              0.9689238645816127, 0.9759446782955781, 0.9196033075303743], 
             UndirectedEdge[27, 208] -> 
             RGBColor[
              0.9532773535764154, 0.8504014208442097, 0.5428400826910413], 
             UndirectedEdge[139, 193] -> 
             RGBColor[
              0.5794635679029903, 0.6247959516307269, 0.6551528667870103], 
             UndirectedEdge[5, 296] -> 
             RGBColor[
              0.9640691171589828, 0.9725547583147467, 0.938154258049464], 
             UndirectedEdge[42, 125] -> 
             RGBColor[
              0.9699581283615817, 0.9080215312467164, 0.3497839678746573], 
             UndirectedEdge[12, 106] -> 
             RGBColor[
              0.9310228613698999, 0.7642356611401802, 0.26335757903792695`], 
             UndirectedEdge[242, 357] -> 
             RGBColor[
              0.9157020124719202, 0.6937742333230511, 0.2543309270312845], 
             UndirectedEdge[148, 279] -> 
             RGBColor[
              0.9892769453136401, 0.9898337555643241, 0.8273722967363459], 
             UndirectedEdge[292, 374] -> 
             RGBColor[
              0.9607550103852502, 0.9434796456671068, 0.6664046455973593], 
             UndirectedEdge[195, 369] -> 
             RGBColor[
              0.9948986369478446, 0.9918420157506096, 0.7112034690744224], 
             UndirectedEdge[50, 371] -> 
             RGBColor[
              0.981063489627219, 0.9785185260530109, 0.674256442880699], 
             UndirectedEdge[29, 127] -> 
             RGBColor[
              0.9659279765008455, 0.8967292056251013, 0.3221370519778738], 
             UndirectedEdge[87, 127] -> 
             RGBColor[
              0.9441920825596676, 0.8111046120307137, 0.3017783135876814], 
             UndirectedEdge[264, 357] -> 
             RGBColor[
              0.9759743182988683, 0.9314804007033968, 0.5248222645089737], 
             UndirectedEdge[171, 306] -> 
             RGBColor[
              0.9031300680262321, 0.921602153845708, 0.7997887588944971], 
             UndirectedEdge[114, 170] -> 
             RGBColor[
              0.9908378744305257, 0.9904792398682047, 0.8015036617144871], 
             UndirectedEdge[57, 222] -> 
             RGBColor[
              0.9842303886931869, 0.9867102861717709, 0.8645862473380082], 
             UndirectedEdge[38, 102] -> 
             RGBColor[
              0.9896631293979219, 0.9899934526076528, 0.8209722270474245], 
             UndirectedEdge[82, 331] -> 
             RGBColor[
              0.984132190355028, 0.9850831394378035, 0.7688690401247419], 
             UndirectedEdge[90, 324] -> 
             RGBColor[
              0.9327452789541473, 0.9485628986352026, 0.9710193839296941], 
             UndirectedEdge[160, 341] -> 
             RGBColor[
              0.9690956879563744, 0.9024020765964686, 0.4670891134605739], 
             UndirectedEdge[15, 311] -> 
             RGBColor[
              0.99457977592391, 0.9908150137069884, 0.6514202429422532], 
             UndirectedEdge[271, 292] -> 
             RGBColor[
              0.9364129294622514, 0.7781320525589627, 0.29691804427328666`], 
             UndirectedEdge[41, 156] -> 
             RGBColor[
              0.9728326417064036, 0.9200202626559357, 0.348960372464852], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.9752163087188859, 0.9790693251316609, 0.8343962697969993], 
             UndirectedEdge[129, 317] -> 
             RGBColor[
              0.9335152230040638, 0.766315854307726, 0.2909949292405757], 
             UndirectedEdge[164, 354] -> 
             RGBColor[
              0.9852583476169983, 0.9854112856708411, 0.7263583687143016], 
             UndirectedEdge[78, 230] -> 
             RGBColor[
              0.9650180209123294, 0.9709968746163822, 0.8147519984900438], 
             UndirectedEdge[315, 363] -> 
             RGBColor[
              0.9677190677980818, 0.9025371029481427, 0.3303131242091036], 
             UndirectedEdge[5, 121] -> 
             RGBColor[
              0.9869171286842543, 0.9888579107435519, 0.866480565294941], 
             UndirectedEdge[43, 380] -> 
             RGBColor[
              0.9187550106565829, 0.829680466269668, 0.6234389098927735], 
             UndirectedEdge[135, 234] -> 
             RGBColor[
              0.9821060532800756, 0.9859130366687443, 0.9034290810075476], 
             UndirectedEdge[344, 356] -> 
             RGBColor[
              0.925114470088338, 0.7095335692006544, 0.4310074045742162], 
             UndirectedEdge[186, 228] -> 
             RGBColor[
              0.9781142363412278, 0.9462105430712326, 0.5850560071329038], 
             UndirectedEdge[298, 396] -> 
             RGBColor[
              0.9825381915853524, 0.9845460253729371, 0.823275888543509], 
             UndirectedEdge[86, 93] -> 
             RGBColor[
              0.9853413905532948, 0.9728556421800912, 0.6287961020397967], 
             UndirectedEdge[249, 266] -> 
             RGBColor[
              0.9627197794609295, 0.8852917199273552, 0.537980153025946], 
             UndirectedEdge[156, 364] -> 
             RGBColor[
              0.9846972868024346, 0.9583961175747513, 0.5350484595219054], 
             UndirectedEdge[10, 311] -> 
             RGBColor[
              0.97469378034224, 0.9779516897697382, 0.7775222806704327], 
             UndirectedEdge[27, 73] -> 
             RGBColor[
              0.9909789199281622, 0.9885919876944147, 0.6577431826458311], 
             UndirectedEdge[56, 213] -> 
             RGBColor[
              0.9428960059200867, 0.8067466005128532, 0.5327980249833739], 
             UndirectedEdge[27, 243] -> 
             RGBColor[
              0.9916246135877238, 0.9899730611425737, 0.7280229527297417], 
             UndirectedEdge[109, 157] -> 
             RGBColor[
              0.991741665171531, 0.9832865224548937, 0.4664922432086904], 
             UndirectedEdge[12, 241] -> 
             RGBColor[
              0.966716387094323, 0.8940600221687983, 0.5065656253969181], 
             UndirectedEdge[192, 382] -> 
             RGBColor[
              0.9731982923263399, 0.930332442623143, 0.5708281989986937], 
             UndirectedEdge[140, 280] -> 
             RGBColor[
              0.8683669197016803, 0.8977273503165882, 0.9719771725393364], 
             UndirectedEdge[199, 361] -> 
             RGBColor[
              0.9568709549045588, 0.909391432057626, 0.6150928094495625], 
             UndirectedEdge[16, 351] -> 
             RGBColor[
              0.8602447728794705, 0.891399847444523, 0.9865321084584602], 
             UndirectedEdge[140, 322] -> 
             RGBColor[
              0.9544336422326833, 0.9139470890583291, 0.6244209636321143], 
             UndirectedEdge[57, 238] -> 
             RGBColor[
              0.6217005017566976, 0.6867398420931373, 0.8723405442852029], 
             UndirectedEdge[49, 127] -> 
             RGBColor[
              0.9798183942532203, 0.9435848463290482, 0.37609870196056017`], 
             UndirectedEdge[165, 182] -> 
             RGBColor[
              0.9712967995958111, 0.9173965679570957, 0.5355830595293487], 
             UndirectedEdge[253, 343] -> 
             RGBColor[
              0.9618483001737629, 0.9330455122496162, 0.640673416506277], 
             UndirectedEdge[104, 240] -> 
             RGBColor[
              0.9296180469900661, 0.7353091498592221, 0.3966983365804012], 
             UndirectedEdge[312, 348] -> 
             RGBColor[
              0.9354385675076109, 0.8898845201111127, 0.6355326106293582], 
             UndirectedEdge[242, 244] -> 
             RGBColor[
              0.868698548716813, 0.4966726006036647, 0.2121511893672765], 
             UndirectedEdge[41, 165] -> 
             RGBColor[
              0.9814381981642861, 0.9530266399286424, 0.5675811706611928], 
             UndirectedEdge[54, 297] -> 
             RGBColor[
              0.9699034811548322, 0.9079780801315908, 0.515404824826873], 
             UndirectedEdge[77, 145] -> 
             RGBColor[
              0.968630021030898, 0.9484486728363137, 0.6511549824936704], 
             UndirectedEdge[69, 150] -> 
             RGBColor[
              0.9915381937869983, 0.9907688399194927, 0.7898975576093403], 
             UndirectedEdge[106, 241] -> 
             RGBColor[
              0.9586570598256388, 0.8621074751600729, 0.50008090149981], 
             UndirectedEdge[139, 276] -> 
             RGBColor[
              0.5692640688302562, 0.5903906463021267, 0.6155297389032208], 
             UndirectedEdge[313, 393] -> 
             RGBColor[
              0.9798694080490438, 0.9812504751748492, 0.7242333251642493], 
             UndirectedEdge[209, 323] -> 
             RGBColor[
              0.9815346292736806, 0.9492820867909754, 0.39059094414597473`], 
             UndirectedEdge[8, 213] -> 
             RGBColor[
              0.8988288009608725, 0.7738034763260211, 0.6129582244167675], 
             UndirectedEdge[160, 244] -> 
             RGBColor[
              0.9295335574120343, 0.734079690845461, 0.4346630743183186], 
             UndirectedEdge[180, 284] -> 
             RGBColor[
              0.9771329896418377, 0.9816482033693885, 0.8869514733322337], 
             UndirectedEdge[24, 242] -> 
             RGBColor[
              0.9305273696686824, 0.752757276246612, 0.5316453794436868], 
             UndirectedEdge[81, 192] -> 
             RGBColor[
              0.991245172739541, 0.9899749571272257, 0.7458546822007222], 
             UndirectedEdge[124, 249] -> 
             RGBColor[
              0.9319045970311264, 0.9461042254058372, 0.8985668132160782], 
             UndirectedEdge[195, 253] -> 
             RGBColor[
              0.9760708674319938, 0.9798982590472746, 0.8458564423575294], 
             UndirectedEdge[31, 81] -> 
             RGBColor[
              0.9894812693123758, 0.9892455377298426, 0.7750871268245909], 
             UndirectedEdge[172, 399] -> 
             RGBColor[
              0.9874901351034422, 0.9868025545702432, 0.700903715302273], 
             UndirectedEdge[124, 315] -> 
             RGBColor[
              0.9143082237561344, 0.8809521280862358, 0.6352898685693692], 
             UndirectedEdge[181, 370] -> 
             RGBColor[
              0.9525256653680607, 0.9613201828402427, 0.8366126990874369], 
             UndirectedEdge[244, 348] -> 
             RGBColor[
              0.9072874141676448, 0.658660800910959, 0.24366606081271813`], 
             UndirectedEdge[284, 367] -> 
             RGBColor[
              0.9853523739971942, 0.9877782067636067, 0.8730381995773868], 
             UndirectedEdge[148, 232] -> 
             RGBColor[
              0.9883225491187795, 0.9894390882108858, 0.8431891115833637], 
             UndirectedEdge[34, 211] -> 
             RGBColor[
              0.9886279882589026, 0.9895653951447545, 0.838127194580367], 
             UndirectedEdge[355, 392] -> 
             RGBColor[
              0.5972188370311831, 0.6660869467907753, 0.9410342496249682], 
             UndirectedEdge[262, 338] -> 
             RGBColor[
              0.9838092563564325, 0.9728463027313823, 0.653220452333231], 
             UndirectedEdge[87, 119] -> 
             RGBColor[
              0.9540230320066385, 0.8449051111332182, 0.5020776100428572], 
             UndirectedEdge[180, 367] -> 
             RGBColor[
              0.9733685031094289, 0.9796588537408617, 0.9299643570156396], 
             UndirectedEdge[69, 380] -> 
             RGBColor[
              0.9540023876666541, 0.9635924866145729, 0.8949462192646025], 
             UndirectedEdge[124, 338] -> 
             RGBColor[
              0.9283984118113775, 0.9445148565500441, 0.9504275724073277], 
             UndirectedEdge[249, 293] -> 
             RGBColor[
              0.9879578804856988, 0.9892882883595504, 0.8492326145656826], 
             UndirectedEdge[212, 373] -> 
             RGBColor[
              0.9692904686904229, 0.903628927176285, 0.4403444509208885], 
             UndirectedEdge[287, 292] -> 
             RGBColor[
              0.9823368876264714, 0.9586646636395956, 0.5890886693920834], 
             UndirectedEdge[12, 323] -> 
             RGBColor[
              0.9658671471628437, 0.8914400650683613, 0.3557237684013077], 
             UndirectedEdge[120, 307] -> 
             RGBColor[
              0.9773822771277842, 0.97932095754583, 0.7225226540561841], 
             UndirectedEdge[99, 398] -> 
             RGBColor[
              0.9764228112615336, 0.9321307475772884, 0.3629075032399006], 
             UndirectedEdge[134, 350] -> 
             RGBColor[
              0.9600934459317635, 0.9253475045512405, 0.6300807790857164], 
             UndirectedEdge[45, 280] -> 
             RGBColor[
              0.8329736155233695, 0.6940556379653361, 0.6011649673536389], 
             UndirectedEdge[188, 330] -> 
             RGBColor[
              0.9658198432028515, 0.9727318843689345, 0.8846513981699923], 
             UndirectedEdge[236, 284] -> 
             RGBColor[
              0.9911285046325167, 0.9887516765558, 0.6623755118596779], 
             UndirectedEdge[374, 389] -> 
             RGBColor[
              0.9704143287533056, 0.9749421998492538, 0.7992165656627472], 
             UndirectedEdge[278, 319] -> 
             RGBColor[
              0.9875572218537254, 0.9891226057187723, 0.8558725649687822], 
             UndirectedEdge[78, 242] -> 
             RGBColor[
              0.9042977456552798, 0.7338351875975051, 0.6047281402312885], 
             UndirectedEdge[84, 189] -> 
             RGBColor[
              0.9091909277507526, 0.9276463659227032, 0.8813499618976868], 
             UndirectedEdge[223, 385] -> 
             RGBColor[
              0.9876127707099467, 0.9888307734110116, 0.8408544467552779], 
             UndirectedEdge[175, 278] -> 
             RGBColor[
              0.9882827626128132, 0.9894226354682021, 0.8438484769514034], 
             UndirectedEdge[151, 168] -> 
             RGBColor[
              0.978711743935046, 0.9390621738052691, 0.4389483591072776], 
             UndirectedEdge[322, 339] -> 
             RGBColor[
              0.9706678691174848, 0.9127179764007374, 0.34055063973990385`], 
             UndirectedEdge[177, 367] -> 
             RGBColor[
              0.9644418742789551, 0.9072707697610742, 0.5962511499262115], 
             UndirectedEdge[294, 320] -> 
             RGBColor[
              0.9672774353491049, 0.9730181824044767, 0.8374924753674511], 
             UndirectedEdge[179, 279] -> 
             RGBColor[
              0.9123883004597837, 0.9302366988685591, 0.883428115471488], 
             UndirectedEdge[18, 285] -> 
             RGBColor[
              0.9533860231803695, 0.8523322060748644, 0.28429892681919294`], 
             UndirectedEdge[121, 296] -> 
             RGBColor[
              0.9657792444363837, 0.9732619398922183, 0.9098130233954043], 
             UndirectedEdge[212, 351] -> 
             RGBColor[
              0.9037514489793563, 0.8554963261218301, 0.6304676599318912], 
             UndirectedEdge[29, 87] -> 
             RGBColor[
              0.9360903223328152, 0.7837754724017763, 0.270304504995401], 
             UndirectedEdge[99, 141] -> 
             RGBColor[
              0.9184893479341094, 0.6704127438423045, 0.3038677335578919], 
             UndirectedEdge[121, 274] -> 
             RGBColor[
              0.9890022797682716, 0.9897201743027315, 0.8319242156347489], 
             UndirectedEdge[138, 218] -> 
             RGBColor[
              0.9733165479410051, 0.9318146836707669, 0.578775585334746], 
             UndirectedEdge[61, 388] -> 
             RGBColor[
              0.9433273880682789, 0.8294095997858086, 0.5838012355203526], 
             UndirectedEdge[283, 347] -> 
             RGBColor[
              0.9726749307729696, 0.9463243436499481, 0.6333946008492668], 
             UndirectedEdge[253, 315] -> 
             RGBColor[
              0.9562158815111024, 0.9138121673548965, 0.6200105543555325], 
             UndirectedEdge[321, 366] -> 
             RGBColor[
              0.9659789928433503, 0.889955728651461, 0.4698887468369686], 
             UndirectedEdge[164, 391] -> 
             RGBColor[
              0.9814800627164563, 0.9854249285348173, 0.9035373074830801], 
             UndirectedEdge[74, 91] -> 
             RGBColor[
              0.9060016953473145, 0.9152847776842741, 0.6931872171520135], 
             UndirectedEdge[91, 285] -> 
             RGBColor[
              0.8915448844897094, 0.8665185600409606, 0.637025236909871], 
             UndirectedEdge[51, 183] -> 
             RGBColor[
              0.9875996350821921, 0.9885256980220472, 0.8276534913375571], 
             UndirectedEdge[30, 54] -> 
             RGBColor[
              0.990079506254222, 0.99016563513813, 0.8140717849897692], 
             UndirectedEdge[68, 250] -> 
             RGBColor[
              0.98691638985308, 0.9742706534445114, 0.607973012906526], 
             UndirectedEdge[32, 230] -> 
             RGBColor[
              0.9548407115138078, 0.9628817643577054, 0.8137812776342214], 
             UndirectedEdge[275, 318] -> 
             RGBColor[
              0.970711301599634, 0.9766887681912646, 0.8902020178841333], 
             UndirectedEdge[131, 186] -> 
             RGBColor[
              0.9101902406683202, 0.8941202322624949, 0.6575375755401136], 
             UndirectedEdge[192, 292] -> 
             RGBColor[
              0.9814940998117131, 0.958316149219534, 0.6030558445475775], 
             UndirectedEdge[144, 200] -> 
             RGBColor[
              0.744047265598055, 0.794798408663275, 0.7648596530732701], 
             UndirectedEdge[139, 318] -> 
             RGBColor[
              0.5845340119655349, 0.6477925371392195, 0.8732766389408766], 
             UndirectedEdge[93, 148] -> 
             RGBColor[
              0.9867643585810617, 0.9887947363798693, 0.8690123612611944], 
             UndirectedEdge[92, 311] -> 
             RGBColor[
              0.9898053532048672, 0.988995688286297, 0.7418131785609812], 
             UndirectedEdge[334, 370] -> 
             RGBColor[
              0.9948735592831042, 0.9914433866062508, 0.6833967485698005], 
             UndirectedEdge[62, 129] -> 
             RGBColor[
              0.9436076911447389, 0.8021895491869191, 0.5005425439575557], 
             UndirectedEdge[97, 191] -> 
             RGBColor[
              0.9775133289249043, 0.9779927688770392, 0.6847704305200075], 
             UndirectedEdge[120, 366] -> 
             RGBColor[
              0.9939541448739853, 0.9894768521522017, 0.5833241641052346], 
             UndirectedEdge[91, 288] -> 
             RGBColor[
              0.9041147733399906, 0.9251604050970673, 0.9484117186184741], 
             UndirectedEdge[21, 32] -> 
             RGBColor[
              0.9543205811540159, 0.9617692581113565, 0.7571682978433549], 
             UndirectedEdge[121, 178] -> 
             RGBColor[
              0.9626705567566456, 0.888181828454865, 0.5530380093957411], 
             UndirectedEdge[294, 381] -> 
             RGBColor[
              0.9924970960905508, 0.9908489168893337, 0.7510032160682933], 
             UndirectedEdge[46, 149] -> 
             RGBColor[
              0.9825463546896179, 0.9651640544960051, 0.6299420911480745], 
             UndirectedEdge[66, 232] -> 
             RGBColor[
              0.9916373632079098, 0.9890357385205293, 0.6592949585535671], 
             UndirectedEdge[114, 261] -> 
             RGBColor[
              0.9753812294769817, 0.9803375078451164, 0.8897270647801998], 
             UndirectedEdge[189, 395] -> 
             RGBColor[
              0.9742445376754076, 0.9789866337710078, 0.8691199448734652], 
             UndirectedEdge[54, 290] -> 
             RGBColor[
              0.929169940500944, 0.7351007263820624, 0.48204086011739794`], 
             UndirectedEdge[4, 309] -> 
             RGBColor[
              0.9309234305534573, 0.7638414510863409, 0.26327757466907603`], 
             UndirectedEdge[195, 315] -> 
             RGBColor[
              0.975027111544299, 0.9260655383324519, 0.5086345319143829], 
             UndirectedEdge[181, 305] -> 
             RGBColor[
              0.9525831425771419, 0.9614431207786304, 0.8428687385877214], 
             UndirectedEdge[153, 372] -> 
             RGBColor[
              0.9680314137079906, 0.9539203741278128, 0.6647313632391023], 
             UndirectedEdge[175, 227] -> 
             RGBColor[
              0.9096749370166846, 0.9290122870687298, 0.9239504721253426], 
             UndirectedEdge[271, 287] -> 
             RGBColor[
              0.943749749096657, 0.8094652157451906, 0.5286262993648297], 
             UndirectedEdge[232, 297] -> 
             RGBColor[
              0.9681138919563519, 0.9072380390076746, 0.5450629491540755], 
             UndirectedEdge[21, 25] -> 
             RGBColor[
              0.9676230473315496, 0.9722176601950137, 0.752937527458192], 
             UndirectedEdge[123, 297] -> 
             RGBColor[
              0.9283133784650772, 0.7534934643042136, 0.26117746549296883`], 
             UndirectedEdge[6, 178] -> 
             RGBColor[
              0.9658883822559348, 0.8893234733651754, 0.4859713814287723], 
             UndirectedEdge[90, 319] -> 
             RGBColor[
              0.9451598474764649, 0.9575854882147112, 0.9394283453054284], 
             UndirectedEdge[258, 302] -> 
             RGBColor[
              0.9447273978805493, 0.8030584956087377, 0.4836981054868974], 
             UndirectedEdge[253, 397] -> 
             RGBColor[
              0.9408161753959974, 0.9550893072866574, 0.9749405767355135], 
             UndirectedEdge[169, 177] -> 
             RGBColor[
              0.9615293629686528, 0.8793286378679193, 0.3183974763102697], 
             UndirectedEdge[198, 332] -> 
             RGBColor[
              0.9321707945615116, 0.756664138498002, 0.29914022988114863`], 
             UndirectedEdge[45, 123] -> 
             RGBColor[
              0.8962101446187194, 0.6198043181083142, 0.23501484033187484`], 
             UndirectedEdge[223, 245] -> 
             RGBColor[
              0.9935617114382671, 0.991605616470324, 0.7563626334320008], 
             UndirectedEdge[380, 381] -> 
             RGBColor[
              0.9535157882488516, 0.9633912652502769, 0.9030104308965179], 
             UndirectedEdge[277, 378] -> 
             RGBColor[
              0.9794907789020254, 0.9414606236802419, 0.5254773325975688], 
             UndirectedEdge[119, 326] -> 
             RGBColor[
              0.9906067148494941, 0.990383649440918, 0.8053345741940012], 
             UndirectedEdge[89, 133] -> 
             RGBColor[
              0.9550333025011029, 0.9659844911483078, 0.9610010690593378], 
             UndirectedEdge[22, 346] -> 
             RGBColor[
              0.994461636927207, 0.9905623263387255, 0.6385615422205073], 
             UndirectedEdge[73, 243] -> 
             RGBColor[
              0.9936724388220186, 0.9888743113918956, 0.5526621988368822], 
             UndirectedEdge[26, 353] -> 
             RGBColor[
              0.9627647106570292, 0.9440293169565055, 0.6609878604535027], 
             UndirectedEdge[21, 230] -> 
             RGBColor[
              0.993915992076828, 0.9893952471769218, 0.5791714675864402], 
             UndirectedEdge[107, 390] -> 
             RGBColor[
              0.9878106545168676, 0.989227406637904, 0.8516725298778092], 
             UndirectedEdge[223, 364] -> 
             RGBColor[
              0.9940495125500367, 0.9917112617872824, 0.7412950152694138], 
             UndirectedEdge[2, 211] -> 
             RGBColor[
              0.9730270908519825, 0.9787526840481824, 0.9013647630723857], 
             UndirectedEdge[128, 353] -> 
             RGBColor[
              0.9612334919002259, 0.8785948333425888, 0.3158719167602879], 
             UndirectedEdge[259, 331] -> 
             RGBColor[
              0.9837623210685926, 0.9858724530676585, 0.8434913833263693], 
             UndirectedEdge[2, 334] -> 
             RGBColor[
              0.9764137368487855, 0.9798124233432459, 0.820472101595092], 
             UndirectedEdge[72, 191] -> 
             RGBColor[
              0.9653393210877614, 0.9736707029356811, 0.9435556678322645], 
             UndirectedEdge[247, 301] -> 
             RGBColor[
              0.9473399479073561, 0.9579474305652895, 0.8798677867521503], 
             UndirectedEdge[247, 397] -> 
             RGBColor[
              0.9585789740741307, 0.9669091249554372, 0.8809397751011344], 
             UndirectedEdge[125, 263] -> 
             RGBColor[
              0.9714387234140428, 0.9121620393118235, 0.5073290966673941], 
             UndirectedEdge[123, 325] -> 
             RGBColor[
              0.8716333907736484, 0.7760974568116596, 0.6153594466573993], 
             UndirectedEdge[129, 393] -> 
             RGBColor[
              0.930407907493166, 0.7937896952118113, 0.5875750285660074], 
             UndirectedEdge[19, 205] -> 
             RGBColor[
              0.9877003396796251, 0.9691143517148533, 0.4966957805910963], 
             UndirectedEdge[277, 352] -> 
             RGBColor[
              0.9790059070587447, 0.940017789909549, 0.44320886994947656`], 
             UndirectedEdge[139, 224] -> 
             RGBColor[
              0.5836821230128109, 0.6474402591647206, 0.887394643505455], 
             UndirectedEdge[65, 250] -> 
             RGBColor[
              0.9895021659780393, 0.9753399383235974, 0.5651200107418475], 
             UndirectedEdge[58, 117] -> 
             RGBColor[
              0.8864582419332451, 0.5532716014636363, 0.22595055951323634`], 
             UndirectedEdge[134, 272] -> 
             RGBColor[
              0.8933896352754511, 0.9172377615537066, 0.9692066393869897], 
             UndirectedEdge[74, 95] -> 
             RGBColor[
              0.9632150551521594, 0.9608035381227713, 0.6951210612678105], 
             UndirectedEdge[156, 245] -> 
             RGBColor[
              0.984209485690665, 0.9582904722577927, 0.5501160776844926], 
             UndirectedEdge[221, 324] -> 
             RGBColor[
              0.9648365535738731, 0.9732957397470294, 0.944406722090509], 
             UndirectedEdge[227, 375] -> 
             RGBColor[
              0.8913418243926077, 0.8550794984983181, 0.6314064593337225], 
             UndirectedEdge[132, 348] -> 
             RGBColor[
              0.972607003340576, 0.9159808359744706, 0.49017793884437844`], 
             UndirectedEdge[137, 319] -> 
             RGBColor[
              0.9103116373245681, 0.9297984713690541, 0.936104491911776], 
             UndirectedEdge[128, 170] -> 
             RGBColor[
              0.970361403938454, 0.9117378524552568, 0.5252873589943504], 
             UndirectedEdge[120, 220] -> 
             RGBColor[
              0.969687021755393, 0.9061351408670519, 0.3853936233317853], 
             UndirectedEdge[292, 371] -> 
             RGBColor[
              0.9734922884929097, 0.9529790868244206, 0.6448437561752711], 
             UndirectedEdge[143, 378] -> 
             RGBColor[
              0.9916243443417257, 0.9908044653878407, 0.7884698199670175], 
             UndirectedEdge[59, 373] -> 
             RGBColor[
              0.9646710892394825, 0.9705401232792994, 0.8001180045169334], 
             UndirectedEdge[2, 340] -> 
             RGBColor[
              0.9758317590692062, 0.9785676317197052, 0.7571274118384121], 
             UndirectedEdge[131, 322] -> 
             RGBColor[
              0.9043624020107986, 0.8744615640290851, 0.6348975228506268], 
             UndirectedEdge[62, 317] -> 
             RGBColor[
              0.9827943371614241, 0.9554528305595289, 0.5579999599924133], 
             UndirectedEdge[243, 337] -> 
             RGBColor[
              0.989725589874711, 0.9891877660345595, 0.7594946901701929], 
             UndirectedEdge[21, 217] -> 
             RGBColor[
              0.9937002572650999, 0.9889338122287706, 0.5556900646907564], 
             UndirectedEdge[24, 74] -> 
             RGBColor[
              0.987424791725726, 0.978216643010343, 0.6253688590303808], 
             UndirectedEdge[1, 127] -> 
             RGBColor[
              0.9784588563389691, 0.9389988057095965, 0.37081715389088676`], 
             UndirectedEdge[226, 355] -> 
             RGBColor[
              0.9066398928830911, 0.9276614701253173, 0.9655580774475272], 
             UndirectedEdge[97, 370] -> 
             RGBColor[
              0.9933088850356246, 0.9876367266782402, 0.5522049854286218], 
             UndirectedEdge[148, 257] -> 
             RGBColor[
              0.9876498984078148, 0.9811414376804549, 0.6412109138841828], 
             UndirectedEdge[48, 344] -> 
             RGBColor[
              0.9245788215966555, 0.7098405277660944, 0.4782981663688299], 
             UndirectedEdge[74, 148] -> 
             RGBColor[
              0.9866931465228792, 0.9779140889165417, 0.6374941134786413], 
             UndirectedEdge[266, 293] -> 
             RGBColor[
              0.9603127877732367, 0.8842963670076294, 0.5778702343858244], 
             UndirectedEdge[84, 226] -> 
             RGBColor[
              0.8376914938150823, 0.8734164749110316, 0.9843809565677489], 
             UndirectedEdge[354, 371] -> 
             RGBColor[
              0.9827197936984018, 0.9835180363148524, 0.7306554783375856], 
             UndirectedEdge[57, 188] -> 
             RGBColor[
              0.9912540772685761, 0.9906513504376637, 0.7946061035895768], 
             UndirectedEdge[134, 355] -> 
             RGBColor[
              0.9613606408868896, 0.9707034097563618, 0.9502905356063509], 
             UndirectedEdge[151, 378] -> 
             RGBColor[
              0.9942971001038133, 0.99061614063669, 0.6501458791868191], 
             UndirectedEdge[167, 238] -> 
             RGBColor[
              0.6176186553208862, 0.667621340048126, 0.6618126363103966], 
             UndirectedEdge[41, 311] -> 
             RGBColor[
              0.9827492962435205, 0.9525122351575768, 0.4690508505332709], 
             UndirectedEdge[212, 295] -> 
             RGBColor[
              0.9623666505133881, 0.8813005981490529, 0.32608953156000164`], 
             UndirectedEdge[179, 285] -> 
             RGBColor[
              0.8953476908114177, 0.8695508145774631, 0.6373879519716408], 
             UndirectedEdge[85, 348] -> 
             RGBColor[
              0.971783456852304, 0.9142193533093793, 0.4005399859357662], 
             UndirectedEdge[108, 152] -> 
             RGBColor[
              0.991835441311373, 0.9896649230282708, 0.6957933430893373], 
             UndirectedEdge[86, 148] -> 
             RGBColor[
              0.9851729089813834, 0.972785970720327, 0.6315882777027007], 
             UndirectedEdge[113, 293] -> 
             RGBColor[
              0.9898000981935635, 0.9889866655086378, 0.7414023671485659], 
             UndirectedEdge[229, 260] -> 
             RGBColor[
              0.9947135123410789, 0.9911010623804867, 0.6659766266255811], 
             UndirectedEdge[6, 278] -> 
             RGBColor[
              0.9922818877092197, 0.9908873678404042, 0.7638336927216589], 
             UndirectedEdge[142, 378] -> 
             RGBColor[
              0.9888639917331086, 0.9894510497136211, 0.8247249478310831], 
             UndirectedEdge[289, 303] -> 
             RGBColor[
              0.9825437501058187, 0.9523519974100454, 0.42291986667970954`], 
             UndirectedEdge[5, 213] -> 
             RGBColor[
              0.9409432358829921, 0.8059390799186137, 0.5651604781048893], 
             UndirectedEdge[104, 243] -> 
             RGBColor[
              0.9297964660396203, 0.7356907701652855, 0.41611814904963906`], 
             UndirectedEdge[121, 373] -> 
             RGBColor[
              0.9913974261028564, 0.989749247685283, 0.7223481795546678], 
             UndirectedEdge[120, 202] -> 
             RGBColor[
              0.9934962771122268, 0.988497519307332, 0.5334880838700982], 
             UndirectedEdge[270, 351] -> 
             RGBColor[
              0.8375399419545078, 0.873360241453452, 0.9843493559398109], 
             UndirectedEdge[91, 125] -> 
             RGBColor[
              0.8866951930762258, 0.8478570892122801, 0.6301756385040058], 
             UndirectedEdge[280, 297] -> 
             RGBColor[
              0.8650768493697273, 0.8277447841612355, 0.6273275925147329], 
             UndirectedEdge[33, 281] -> 
             RGBColor[
              0.9399101490374571, 0.7969179935854989, 0.5460359386628212], 
             UndirectedEdge[16, 241] -> 
             RGBColor[
              0.9258752872435393, 0.9405316650685522, 0.8647748591426307], 
             UndirectedEdge[89, 342] -> 
             RGBColor[
              0.9490166167550291, 0.9614972567703047, 0.971185748624475], 
             UndirectedEdge[157, 370] -> 
             RGBColor[
              0.9925002887834087, 0.9849091416520875, 0.5490637416793529], 
             UndirectedEdge[90, 122] -> 
             RGBColor[
              0.949672851849672, 0.9588975278279899, 0.8243514269346268], 
             UndirectedEdge[135, 156] -> 
             RGBColor[
              0.9763327078617432, 0.9540778514453954, 0.6378712163586444], 
             UndirectedEdge[12, 22] -> 
             RGBColor[
              0.9666573748292852, 0.8931302821426066, 0.44173517317359856`], 
             UndirectedEdge[271, 384] -> 
             RGBColor[
              0.9081537410204042, 0.6717233524075141, 0.24486116665621674`], 
             UndirectedEdge[158, 324] -> 
             RGBColor[
              0.9729077005288784, 0.9791758057197506, 0.9245025554034085], 
             UndirectedEdge[301, 397] -> 
             RGBColor[
              0.9131336872264231, 0.9335720321134477, 0.9915767003233638], 
             UndirectedEdge[95, 233] -> 
             RGBColor[
              0.9667356715528419, 0.9731106029273706, 0.869473752322858], 
             UndirectedEdge[123, 203] -> 
             RGBColor[
              0.9450215336241234, 0.8127474093797243, 0.3110165415149687], 
             UndirectedEdge[103, 145] -> 
             RGBColor[
              0.9704858429049523, 0.9498327417513539, 0.6480135601367607], 
             UndirectedEdge[20, 80] -> 
             RGBColor[
              0.6188523903683616, 0.6813291887910401, 0.7429465609904841], 
             UndirectedEdge[73, 337] -> 
             RGBColor[
              0.9890798962151496, 0.9878066925864006, 0.6892149200862823], 
             UndirectedEdge[122, 166] -> 
             RGBColor[
              0.9945932617781738, 0.9908438585856297, 0.6528880949538225], 
             UndirectedEdge[62, 216] -> 
             RGBColor[
              0.9935954897911002, 0.990776027548602, 0.6944851397696234], 
             UndirectedEdge[128, 342] -> 
             RGBColor[
              0.9441411077128989, 0.8935686069373641, 0.6317308160537178], 
             UndirectedEdge[280, 309] -> 
             RGBColor[
              0.8486782359134312, 0.7627297463210153, 0.614132883202867], 
             UndirectedEdge[104, 141] -> 
             RGBColor[
              0.856218474802171, 0.4223203418967938, 0.2010450816639502], 
             UndirectedEdge[148, 276] -> 
             RGBColor[
              0.9730985073348313, 0.9320561787621793, 0.58468150736527], 
             UndirectedEdge[359, 394] -> 
             RGBColor[
              0.8808179323737002, 0.907702706727078, 0.9849711775595378], 
             UndirectedEdge[8, 43] -> 
             RGBColor[
              0.9107677960643397, 0.8233116781609777, 0.6226770822346948], 
             UndirectedEdge[56, 352] -> 
             RGBColor[
              0.9914772370613256, 0.9895013059440523, 0.7006037244053251], 
             UndirectedEdge[70, 152] -> 
             RGBColor[
              0.9494393718548526, 0.8252068445162772, 0.4077495513448751], 
             UndirectedEdge[359, 397] -> 
             RGBColor[
              0.8731844419364436, 0.9017175883125936, 0.9877663056444932], 
             UndirectedEdge[118, 241] -> 
             RGBColor[
              0.99356989343325, 0.9894584959325798, 0.5999080974616365], 
             UndirectedEdge[43, 227] -> 
             RGBColor[
              0.876421338916007, 0.7959247455406402, 0.6194010864904425], 
             UndirectedEdge[234, 246] -> 
             RGBColor[
              0.9879480487937147, 0.989284222702252, 0.8493955511454627], 
             UndirectedEdge[196, 317] -> 
             RGBColor[
              0.9826065607697968, 0.9553751801959578, 0.5611119007514016], 
             UndirectedEdge[46, 184] -> 
             RGBColor[
              0.9646903066090922, 0.8908048478465578, 0.32643987754787895`], 
             UndirectedEdge[136, 331] -> 
             RGBColor[
              0.9846219363260756, 0.9861306565489611, 0.8221748667114908], 
             UndirectedEdge[106, 320] -> 
             RGBColor[
              0.9313016141844632, 0.8433935387320095, 0.6219656438216279], 
             UndirectedEdge[68, 161] -> 
             RGBColor[
              0.9923773095221802, 0.9910346141711857, 0.7700872803917487], 
             UndirectedEdge[45, 297] -> 
             RGBColor[
              0.9140753288379373, 0.6906338203177832, 0.2493895869044278], 
             UndirectedEdge[140, 203] -> 
             RGBColor[
              0.9661767881752945, 0.9535594777445461, 0.6700408681121252], 
             UndirectedEdge[225, 243] -> 
             RGBColor[
              0.9882933369987583, 0.9710525766040901, 0.5042795151627597], 
             UndirectedEdge[107, 373] -> 
             RGBColor[
              0.9899925041515776, 0.9891682763535821, 0.7456313721088204], 
             UndirectedEdge[187, 321] -> 
             RGBColor[
              0.9645675826370688, 0.8898190849609746, 0.5257724256744187], 
             UndirectedEdge[297, 322] -> 
             RGBColor[
              0.9511435719007302, 0.8439645229029764, 0.2797713836075108], 
             UndirectedEdge[106, 374] -> 
             RGBColor[
              0.9347367434398253, 0.8459554525061505, 0.6161508660174986], 
             UndirectedEdge[154, 383] -> 
             RGBColor[
              0.9304557535046929, 0.7400638389764106, 0.35463820972280413`], 
             UndirectedEdge[111, 151] -> 
             RGBColor[
              0.9336134228841588, 0.9455172908654234, 0.7762176855995628], 
             UndirectedEdge[79, 227] -> 
             RGBColor[
              0.91152144383096, 0.9297758650894934, 0.8933490756063447], 
             UndirectedEdge[93, 290] -> 
             RGBColor[
              0.9258221607647461, 0.7337163334271296, 0.537522234122431], 
             UndirectedEdge[150, 283] -> 
             RGBColor[
              0.9834877655137875, 0.9859045745821753, 0.8545643105358088], 
             UndirectedEdge[46, 195] -> 
             RGBColor[
              0.9871077722914665, 0.9670503178974548, 0.5543475969150955], 
             UndirectedEdge[73, 177] -> 
             RGBColor[
              0.9701613031277909, 0.9081229601654026, 0.37941682267230104`], 
             UndirectedEdge[102, 189] -> 
             RGBColor[
              0.9909651346504833, 0.9905318652395958, 0.7993946305308985], 
             UndirectedEdge[3, 95] -> 
             RGBColor[
              0.8301036696101121, 0.8680680755885921, 0.9799207696649814], 
             UndirectedEdge[39, 294] -> 
             RGBColor[
              0.9134983698706998, 0.6195654660402319, 0.4331405827654572], 
             UndirectedEdge[5, 227] -> 
             RGBColor[
              0.9087461093364009, 0.92862819295315, 0.9393435505166265], 
             UndirectedEdge[166, 169] -> 
             RGBColor[
              0.9851549022024344, 0.9603246866975459, 0.5040949717384833], 
             UndirectedEdge[27, 337] -> 
             RGBColor[
              0.9870320709808549, 0.9889054423370784, 0.8645756739791417], 
             UndirectedEdge[84, 174] -> 
             RGBColor[
              0.9054659171226311, 0.9261059782995685, 0.9430830280241462], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.8982410887878003, 0.8426598510486594, 0.6280515366807478], 
             UndirectedEdge[138, 349] -> 
             RGBColor[
              0.9869259760889324, 0.9888615693727543, 0.8663339409030756], 
             UndirectedEdge[26, 159] -> 
             RGBColor[
              0.9730280553810862, 0.9776418666640527, 0.8515862446777841], 
             UndirectedEdge[81, 287] -> 
             RGBColor[
              0.9920879605542994, 0.9903234715472873, 0.731887507045228], 
             UndirectedEdge[311, 361] -> 
             RGBColor[
              0.9778386754383079, 0.9802971473830925, 0.7721987935927961], 
             UndirectedEdge[231, 393] -> 
             RGBColor[
              0.9765415575040519, 0.9816259412043058, 0.9067085404251976], 
             UndirectedEdge[201, 223] -> 
             RGBColor[
              0.9931769427404544, 0.9898449231949267, 0.6463211763730476], 
             UndirectedEdge[180, 267] -> 
             RGBColor[
              0.976453651078396, 0.9813672794152006, 0.8982098714003087], 
             UndirectedEdge[217, 264] -> 
             RGBColor[
              0.9937724181947905, 0.9905907988365883, 0.672770523700557], 
             UndirectedEdge[163, 174] -> 
             RGBColor[
              0.9889185553176175, 0.9896855520907659, 0.833311746454019], 
             UndirectedEdge[203, 280] -> 
             RGBColor[
              0.8817850045287735, 0.8869987292367463, 0.6771666685367328], 
             UndirectedEdge[40, 163] -> 
             RGBColor[
              0.9407608574332708, 0.9526378930728638, 0.8764807357805442], 
             UndirectedEdge[14, 62] -> 
             RGBColor[
              0.9626791930832372, 0.8806529383086721, 0.5160354137291963], 
             UndirectedEdge[49, 133] -> 
             RGBColor[
              0.9688666120281098, 0.9634638527957871, 0.6822543127889531], 
             UndirectedEdge[276, 288] -> 
             RGBColor[
              0.9713088548412365, 0.9311208301714092, 0.6055955853862736], 
             UndirectedEdge[312, 366] -> 
             RGBColor[
              0.9577338355063955, 0.9654084829279913, 0.8318765504880218], 
             UndirectedEdge[23, 120] -> 
             RGBColor[
              0.9515924969033511, 0.8343963794716706, 0.3708343439027454], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.98744990542151, 0.9693277254637243, 0.40574568175940806`], 
             UndirectedEdge[73, 399] -> 
             RGBColor[
              0.9874720738965657, 0.9867639234750025, 0.6989378643946169], 
             UndirectedEdge[269, 272] -> 
             RGBColor[
              0.8978531312078264, 0.883994640863714, 0.6559367016137074], 
             UndirectedEdge[20, 151] -> 
             RGBColor[
              0.6189257151097707, 0.6814860229986456, 0.7509275065850134], 
             UndirectedEdge[239, 355] -> 
             RGBColor[
              0.9428932878798966, 0.8499707362261644, 0.6007396172035329], 
             UndirectedEdge[274, 319] -> 
             RGBColor[
              0.9874954394120665, 0.98909705709141, 0.8568964599149035], 
             UndirectedEdge[6, 352] -> 
             RGBColor[
              0.9944524198009213, 0.9905426118375947, 0.6375583149058119], 
             UndirectedEdge[133, 342] -> 
             RGBColor[
              0.9461094865314033, 0.9593291238095134, 0.9761067617920777], 
             UndirectedEdge[290, 318] -> 
             RGBColor[
              0.9274262526537944, 0.7343796666465323, 0.5109382802641624], 
             UndirectedEdge[87, 298] -> 
             RGBColor[
              0.9547398888368981, 0.8450664093808717, 0.48037415135217787`], 
             UndirectedEdge[86, 263] -> 
             RGBColor[
              0.9892249881436356, 0.9744616095876028, 0.5644348395394612], 
             UndirectedEdge[109, 191] -> 
             RGBColor[
              0.9783058978707678, 0.980147973636714, 0.7319232964618755], 
             UndirectedEdge[84, 238] -> 
             RGBColor[
              0.5395519586917144, 0.6236995451519123, 0.960499594661166], 
             UndirectedEdge[21, 244] -> 
             RGBColor[
              0.9288986936140705, 0.7327217813761927, 0.36556206783516526`], 
             UndirectedEdge[137, 175] -> 
             RGBColor[
              0.9110371780836557, 0.9300985011184839, 0.9240804038943973], 
             UndirectedEdge[363, 369] -> 
             RGBColor[
              0.9875905932016276, 0.9683135803663004, 0.5328820613691432], 
             UndirectedEdge[98, 290] -> 
             RGBColor[
              0.9224438302022007, 0.7116799987002345, 0.293156455447354], 
             UndirectedEdge[175, 352] -> 
             RGBColor[
              0.9904532947045148, 0.9890778794653927, 0.7175730991355566], 
             UndirectedEdge[121, 319] -> 
             RGBColor[
              0.9871204156054503, 0.9889419751097019, 0.8631115749210357], 
             UndirectedEdge[249, 387] -> 
             RGBColor[
              0.9826824700827287, 0.958807570866322, 0.5833614737531722], 
             UndirectedEdge[310, 389] -> 
             RGBColor[
              0.9868841462731264, 0.9662986922205498, 0.49883510651729634`], 
             UndirectedEdge[228, 238] -> 
             RGBColor[
              0.6206785276822413, 0.6863172295498139, 0.889277299483067], 
             UndirectedEdge[268, 324] -> 
             RGBColor[
              0.9728518107375925, 0.9791526938547518, 0.9254287938831585], 
             UndirectedEdge[144, 368] -> 
             RGBColor[
              0.9769759258711816, 0.9795375480040147, 0.7644422326586162], 
             UndirectedEdge[137, 278] -> 
             RGBColor[
              0.9122552839290482, 0.9306022191894461, 0.903893237679368], 
             UndirectedEdge[127, 298] -> 
             RGBColor[
              0.9845775430049284, 0.9580201426041968, 0.5322066983346507], 
             UndirectedEdge[131, 228] -> 
             RGBColor[
              0.9205402185773397, 0.9374073595746378, 0.9133229221445442], 
             UndirectedEdge[278, 314] -> 
             RGBColor[
              0.9759510072296067, 0.9373793658745659, 0.5660486461042169], 
             UndirectedEdge[182, 311] -> 
             RGBColor[
              0.9726078976750453, 0.91688216318603, 0.4370527394014267], 
             UndirectedEdge[77, 94] -> 
             RGBColor[
              0.9788762323218831, 0.9820034274509883, 0.8416868065658456], 
             UndirectedEdge[144, 333] -> 
             RGBColor[
              0.9203416544714236, 0.6750082228371801, 0.3844183892710501], 
             UndirectedEdge[166, 197] -> 
             RGBColor[
              0.992312465845635, 0.9904548945277079, 0.7309715426924804], 
             UndirectedEdge[106, 384] -> 
             RGBColor[
              0.9207226126047936, 0.7233986071409626, 0.25506975710360963`], 
             UndirectedEdge[28, 265] -> 
             RGBColor[
              0.9458122137239902, 0.8090384200811793, 0.40142685661059707`], 
             UndirectedEdge[113, 266] -> 
             RGBColor[
              0.9645619971687943, 0.8849900970764426, 0.4301499056088294], 
             UndirectedEdge[164, 292] -> 
             RGBColor[
              0.9760308424115061, 0.9548723361804092, 0.6405466465519871], 
             UndirectedEdge[98, 248] -> 
             RGBColor[
              0.9843473974533479, 0.9671559526203444, 0.608714203106614], 
             UndirectedEdge[91, 95] -> 
             RGBColor[
              0.8824263344628658, 0.9089852028940669, 0.98512458838664], 
             UndirectedEdge[155, 342] -> 
             RGBColor[
              0.8902039555172723, 0.9151751824354742, 0.9854613204012908], 
             UndirectedEdge[47, 209] -> 
             RGBColor[
              0.9022186043845504, 0.5871854428794323, 0.2598938022119109], 
             UndirectedEdge[2, 360] -> 
             RGBColor[
              0.9662939720871521, 0.9471474342802167, 0.6560454272997082], 
             UndirectedEdge[75, 341] -> 
             RGBColor[
              0.9691191008578005, 0.9024521544252118, 0.4696374632931294], 
             UndirectedEdge[12, 390] -> 
             RGBColor[
              0.9644430428066109, 0.893119935883546, 0.5442408234707337], 
             UndirectedEdge[19, 198] -> 
             RGBColor[
              0.9799805301958517, 0.9441317689348738, 0.37672856948087974`], 
             UndirectedEdge[8, 56] -> 
             RGBColor[
              0.9450453365218281, 0.956822646167727, 0.9102570931393634], 
             UndirectedEdge[70, 154] -> 
             RGBColor[
              0.949094191317414, 0.8244685382498023, 0.37017878005204463`], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.9703570961121166, 0.9116696660806589, 0.3393433452986063], 
             UndirectedEdge[177, 243] -> 
             RGBColor[
              0.9708069967873524, 0.9095040336135615, 0.44969659275621165`], 
             UndirectedEdge[109, 340] -> 
             RGBColor[
              0.993532957891647, 0.9885759757855161, 0.5374805603424583], 
             UndirectedEdge[28, 36] -> 
             RGBColor[
              0.9022108967565958, 0.7786458322511358, 0.6137044021858165], 
             UndirectedEdge[203, 339] -> 
             RGBColor[
              0.982411015060096, 0.9523303650869543, 0.38617054421991476`], 
             UndirectedEdge[247, 369] -> 
             RGBColor[
              0.9938502055927814, 0.991408462441834, 0.7285786898811932], 
             UndirectedEdge[223, 230] -> 
             RGBColor[
              0.9936822562024272, 0.9909257375950585, 0.701321428275586], 
             UndirectedEdge[22, 173] -> 
             RGBColor[
              0.9759894851739659, 0.9790401389568849, 0.7850182651526223], 
             UndirectedEdge[69, 283] -> 
             RGBColor[
              0.9830017863129973, 0.9857036096935528, 0.8626182435667591], 
             UndirectedEdge[59, 274] -> 
             RGBColor[
              0.9622759429048975, 0.9705110498967479, 0.9096940405970144], 
             UndirectedEdge[31, 164] -> 
             RGBColor[
              0.9807609708039882, 0.9851275655491925, 0.9154545214228933], 
             UndirectedEdge[116, 154] -> 
             RGBColor[
              0.9918225438059536, 0.98906402433482, 0.6527157820350282], 
             UndirectedEdge[10, 170] -> 
             RGBColor[
              0.9739318531868277, 0.9786931908308533, 0.8669514173818295], 
             UndirectedEdge[301, 394] -> 
             RGBColor[
              0.9207671776636797, 0.9395571505279321, 0.9887815722384083], 
             UndirectedEdge[90, 351] -> 
             RGBColor[
              0.8838978382628044, 0.9102601597358375, 0.9887881589500633], 
             UndirectedEdge[4, 203] -> 
             RGBColor[
              0.9640301991687996, 0.888110434002072, 0.3263113600029418], 
             UndirectedEdge[274, 351] -> 
             RGBColor[
              0.9262334301984061, 0.9417717286125362, 0.9062562735595383], 
             UndirectedEdge[238, 269] -> 
             RGBColor[
              0.6102166201737769, 0.6426525374164235, 0.633057127520924], 
             UndirectedEdge[66, 325] -> 
             RGBColor[
              0.9130220462444242, 0.9287246585339833, 0.7439662026294438], 
             UndirectedEdge[128, 171] -> 
             RGBColor[
              0.9712296118029207, 0.9112236750841813, 0.44742622157502654`], 
             UndirectedEdge[198, 205] -> 
             RGBColor[
              0.9864977113097735, 0.9650576038327745, 0.4920237964715344], 
             UndirectedEdge[202, 349] -> 
             RGBColor[
              0.9902219901536935, 0.9889875524321141, 0.7217933649609162], 
             UndirectedEdge[295, 390] -> 
             RGBColor[
              0.985061928432313, 0.9676642043066326, 0.5983432668765565], 
             UndirectedEdge[250, 356] -> 
             RGBColor[
              0.9894677163998669, 0.9747972295554201, 0.5272772493312402], 
             UndirectedEdge[133, 393] -> 
             RGBColor[
              0.9593067051382153, 0.9691715878380116, 0.9537673130766184], 
             UndirectedEdge[124, 293] -> 
             RGBColor[
              0.9294976053434336, 0.9451088724861113, 0.9384568945759566], 
             UndirectedEdge[45, 325] -> 
             RGBColor[
              0.8573953411465085, 0.7132378128252292, 0.6035715680688581], 
             UndirectedEdge[116, 304] -> 
             RGBColor[
              0.9926436181745399, 0.9912259613118521, 0.7715778147611625], 
             UndirectedEdge[213, 296] -> 
             RGBColor[
              0.9198053516351217, 0.7903431090672801, 0.6084929362053527], 
             UndirectedEdge[248, 276] -> 
             RGBColor[
              0.9740598767696629, 0.9324537297295497, 0.5687491278857666], 
             UndirectedEdge[209, 346] -> 
             RGBColor[
              0.9825539328473427, 0.9514622740676387, 0.5015358477266108], 
             UndirectedEdge[31, 382] -> 
             RGBColor[
              0.9714343888991747, 0.9296030232257597, 0.6000606436225626], 
             UndirectedEdge[69, 373] -> 
             RGBColor[
              0.9926099054151329, 0.9902506390402064, 0.7022542595543726], 
             UndirectedEdge[166, 239] -> 
             RGBColor[
              0.9581128204576349, 0.8589669802412532, 0.4518426280010172], 
             UndirectedEdge[235, 317] -> 
             RGBColor[
              0.9799657681315403, 0.9542831445747637, 0.6048766689195839], 
             UndirectedEdge[43, 59] -> 
             RGBColor[
              0.9278660214004864, 0.8369453389250583, 0.6243079262310223], 
             UndirectedEdge[94, 207] -> 
             RGBColor[
              0.9901775737030516, 0.9902061885484396, 0.8124465535722398], 
             UndirectedEdge[209, 270] -> 
             RGBColor[
              0.8912037399736745, 0.8824622667802025, 0.6607359599067655], 
             UndirectedEdge[23, 341] -> 
             RGBColor[
              0.9267831647401352, 0.7474266767983141, 0.25994621961114794`], 
             UndirectedEdge[264, 312] -> 
             RGBColor[
              0.9571220078837273, 0.9656024871841642, 0.8745090766616058], 
             UndirectedEdge[48, 118] -> 
             RGBColor[
              0.9931936630769178, 0.9893029150115575, 0.6061432081190105], 
             UndirectedEdge[106, 310] -> 
             RGBColor[
              0.951206560959646, 0.8373119448774464, 0.31576940687204774`], 
             UndirectedEdge[267, 282] -> 
             RGBColor[
              0.9893458123082939, 0.985142109074103, 0.6359103362661571], 
             UndirectedEdge[43, 274] -> 
             RGBColor[
              0.9549673820704767, 0.85630954531275, 0.5403229862626246], 
             UndirectedEdge[46, 362] -> 
             RGBColor[
              0.9715596668451473, 0.9572305798939166, 0.6602000005898578], 
             UndirectedEdge[38, 117] -> 
             RGBColor[
              0.9577034113370193, 0.8668205808849633, 0.5408782716320539], 
             UndirectedEdge[252, 300] -> 
             RGBColor[
              0.9153671501614, 0.8980034629652975, 0.6576713733338635], 
             UndirectedEdge[7, 67] -> 
             RGBColor[
              0.9651103510369669, 0.8935529422041204, 0.32113883218811556`], 
             UndirectedEdge[150, 192] -> 
             RGBColor[
              0.9900061523095744, 0.9901353013969079, 0.8152874496865025], 
             UndirectedEdge[239, 272] -> 
             RGBColor[
              0.8749222822684581, 0.7965050880235092, 0.6196557209841717], 
             UndirectedEdge[22, 209] -> 
             RGBColor[
              0.9823248569401221, 0.9509723038652207, 0.47660234891826553`], 
             UndirectedEdge[167, 246] -> 
             RGBColor[
              0.9862349689026357, 0.971145266498011, 0.5996110513531319], 
             UndirectedEdge[131, 140] -> 
             RGBColor[
              0.9026874631263166, 0.9248025737951441, 0.9753279313332414], 
             UndirectedEdge[67, 385] -> 
             RGBColor[
              0.9684229432524194, 0.921912867908446, 0.5985687667817071], 
             UndirectedEdge[60, 101] -> 
             RGBColor[
              0.990122913915952, 0.9901835853217815, 0.8133524076994743], 
             UndirectedEdge[113, 249] -> 
             RGBColor[
              0.9922070898812563, 0.9899820184283636, 0.7015122857886875], 
             UndirectedEdge[52, 393] -> 
             RGBColor[
              0.9567165585740289, 0.9672398607714172, 0.9581517555913689], 
             UndirectedEdge[99, 367] -> 
             RGBColor[
              0.9857022166631615, 0.981549908258309, 0.6654953581135807], 
             UndirectedEdge[5, 43] -> 
             RGBColor[
              0.9528822309864595, 0.8554472817535703, 0.5748793359228166], 
             UndirectedEdge[26, 105] -> 
             RGBColor[
              0.9647681819772493, 0.9732447483222155, 0.9445224573694245], 
             UndirectedEdge[128, 306] -> 
             RGBColor[
              0.8800898708637799, 0.8426738032047445, 0.6295327280696912], 
             UndirectedEdge[226, 281] -> 
             RGBColor[
              0.9182386029005284, 0.9357945377467418, 0.9227618116110041], 
             UndirectedEdge[63, 345] -> 
             RGBColor[
              0.9620425778638841, 0.9712119972372351, 0.9491361941819478], 
             UndirectedEdge[4, 280] -> 
             RGBColor[
              0.8662203306951854, 0.8322783065741142, 0.628247664430153], 
             UndirectedEdge[7, 223] -> 
             RGBColor[
              0.984300178494494, 0.9604708477066859, 0.5634245121616863], 
             UndirectedEdge[155, 361] -> 
             RGBColor[
              0.9009676067892833, 0.9232026959302786, 0.9672412664076361], 
             UndirectedEdge[252, 398] -> 
             RGBColor[
              0.9130945552066453, 0.890337466552239, 0.6488427710781879], 
             UndirectedEdge[6, 252] -> 
             RGBColor[
              0.9291114703559973, 0.9427863897365416, 0.8454081216749434], 
             UndirectedEdge[260, 307] -> 
             RGBColor[
              0.9779848574369949, 0.9806098158970168, 0.7881098020191559], 
             UndirectedEdge[21, 357] -> 
             RGBColor[
              0.9759021573691777, 0.9298234140955792, 0.40774180549917327`], 
             UndirectedEdge[233, 366] -> 
             RGBColor[
              0.9942977438298632, 0.9914629740780199, 0.7116717128056429], 
             UndirectedEdge[37, 41] -> 
             RGBColor[
              0.8943801724698883, 0.5247270459850438, 0.2538867236254276], 
             UndirectedEdge[173, 176] -> 
             RGBColor[
              0.9763402964115863, 0.9797904887216979, 0.8232019034115975], 
             UndirectedEdge[60, 136] -> 
             RGBColor[
              0.994327074710949, 0.9918248443337458, 0.7366081161215942], 
             UndirectedEdge[74, 285] -> 
             RGBColor[
              0.972333605179003, 0.918336895269665, 0.34702170979104163`], 
             UndirectedEdge[234, 395] -> 
             RGBColor[
              0.9710444627140995, 0.9776633205363315, 0.9221534685108721], 
             UndirectedEdge[17, 164] -> 
             RGBColor[
              0.9834175470477284, 0.9862261280968745, 0.8714281780651804], 
             UndirectedEdge[20, 383] -> 
             RGBColor[
              0.5559054428792367, 0.4330956583153983, 0.5742818698471327], 
             UndirectedEdge[19, 219] -> 
             RGBColor[
              0.9875470433637875, 0.9687864663959116, 0.48001042264737226`], 
             UndirectedEdge[91, 279] -> 
             RGBColor[
              0.9085854941380753, 0.9272044443320564, 0.8830654004097183], 
             UndirectedEdge[76, 207] -> 
             RGBColor[
              0.9895684874047795, 0.9899543157113002, 0.8225406897994194], 
             UndirectedEdge[238, 339] -> 
             RGBColor[
              0.6190599991160197, 0.6724833311127285, 0.6674119847795538], 
             UndirectedEdge[142, 379] -> 
             RGBColor[
              0.9847560920735985, 0.9877523276362078, 0.8928034760926999], 
             UndirectedEdge[205, 219] -> 
             RGBColor[
              0.9940642244777094, 0.9897123012938123, 0.5953056496380269], 
             UndirectedEdge[7, 68] -> 
             RGBColor[
              0.9826193678739712, 0.9597757893202371, 0.5912798939422002], 
             UndirectedEdge[188, 273] -> 
             RGBColor[
              0.989483290915493, 0.9793285967144072, 0.5930562276290934], 
             UndirectedEdge[16, 69] -> 
             RGBColor[
              0.9242261017616124, 0.9398496844896418, 0.8921061305333755], 
             UndirectedEdge[118, 323] -> 
             RGBColor[
              0.9927206535017707, 0.9868385388321428, 0.44906624046602617`], 
             UndirectedEdge[211, 263] -> 
             RGBColor[
              0.9914068921564454, 0.9907145433209612, 0.7920735654253277], 
             UndirectedEdge[191, 340] -> 
             RGBColor[
              0.9784960253928044, 0.9805546371815091, 0.7526175039045064], 
             UndirectedEdge[33, 182] -> 
             RGBColor[
              0.9218367757188275, 0.7244422539694995, 0.2557917240663833], 
             UndirectedEdge[99, 300] -> 
             RGBColor[
              0.9786954062162885, 0.939796743990347, 0.3717361054955762], 
             UndirectedEdge[11, 91] -> 
             RGBColor[
              0.899745271909002, 0.8941803923487648, 0.6688821935205991], 
             UndirectedEdge[78, 233] -> 
             RGBColor[
              0.9647157841130058, 0.9716016191658353, 0.8728043108730299], 
             UndirectedEdge[27, 172] -> 
             RGBColor[
              0.9909969811350388, 0.9886306187896554, 0.6597090335534871], 
             UndirectedEdge[313, 396] -> 
             RGBColor[
              0.98160130599384, 0.9825421218263557, 0.7213016736950364], 
             UndirectedEdge[74, 172] -> 
             RGBColor[
              0.989926641806409, 0.9773368065235983, 0.4447489103007339], 
             UndirectedEdge[217, 366] -> 
             RGBColor[
              0.9943842458174588, 0.9903967945804155, 0.630137997526973], 
             UndirectedEdge[277, 302] -> 
             RGBColor[
              0.9293475803907856, 0.7523722452535653, 0.27450441561800276`], 
             UndirectedEdge[203, 232] -> 
             RGBColor[
              0.9848220471153981, 0.9664919840831854, 0.5949020251760753], 
             UndirectedEdge[27, 285] -> 
             RGBColor[
              0.9734039445076328, 0.929630707535722, 0.5619818330437949], 
             UndirectedEdge[193, 334] -> 
             RGBColor[
              0.9874435883894113, 0.9678350629194232, 0.5308344404362348], 
             UndirectedEdge[39, 381] -> 
             RGBColor[
              0.9110802895307518, 0.6188819814531764, 0.49621728060128517`], 
             UndirectedEdge[270, 390] -> 
             RGBColor[
              0.9008971120308644, 0.9215519727922289, 0.9002673046977969], 
             UndirectedEdge[35, 42] -> 
             RGBColor[
              0.9800385646366917, 0.9443275327309617, 0.3769540223246584], 
             UndirectedEdge[41, 245] -> 
             RGBColor[
              0.9828181889240382, 0.9535973015719448, 0.5447111524704957], 
             UndirectedEdge[45, 276] -> 
             RGBColor[
              0.9207866163260459, 0.7161659833630687, 0.26039271977488776`], 
             UndirectedEdge[17, 241] -> 
             RGBColor[
              0.9920620314072862, 0.9909854602374946, 0.7812162125928639], 
             UndirectedEdge[69, 347] -> 
             RGBColor[
              0.9807253590461804, 0.9511886089872655, 0.5687278479227983], 
             UndirectedEdge[16, 295] -> 
             RGBColor[
              0.9188599744135024, 0.917204119471746, 0.6821539800865706], 
             UndirectedEdge[190, 351] -> 
             RGBColor[
              0.9132839988393759, 0.9329755312234975, 0.9667545495792005], 
             UndirectedEdge[112, 141] -> 
             RGBColor[
              0.9163321037899337, 0.6758936353882637, 0.5413638949206997], 
             UndirectedEdge[135, 400] -> 
             RGBColor[
              0.9850474509877387, 0.9871293802113361, 0.8546825088983117], 
             UndirectedEdge[295, 310] -> 
             RGBColor[
              0.9798847738540322, 0.9438087603092584, 0.3763565741749787], 
             UndirectedEdge[185, 249] -> 
             RGBColor[
              0.9355162285939422, 0.7706524201356284, 0.5157404899238958], 
             UndirectedEdge[93, 98] -> 
             RGBColor[
              0.9835545095904277, 0.9668280731127383, 0.6218544069232135], 
             UndirectedEdge[221, 268] -> 
             RGBColor[
              0.9769039261068553, 0.982174754862418, 0.9185696195239457], 
             UndirectedEdge[265, 291] -> 
             RGBColor[
              0.9931016889327708, 0.9875928929995585, 0.4956961613372467], 
             UndirectedEdge[128, 133] -> 
             RGBColor[
              0.9501577934589727, 0.8980558413153672, 0.6215461364885806], 
             UndirectedEdge[57, 333] -> 
             RGBColor[
              0.918650495804503, 0.6755093311456063, 0.4997050077394418], 
             UndirectedEdge[28, 378] -> 
             RGBColor[
              0.9463187336303036, 0.8105275568697445, 0.48605157732344895`], 
             UndirectedEdge[92, 386] -> 
             RGBColor[
              0.9332181117919374, 0.7701461390060484, 0.5556990505851237], 
             UndirectedEdge[35, 248] -> 
             RGBColor[
              0.9784284499617322, 0.9471899528961636, 0.5857202098011314], 
             UndirectedEdge[56, 175] -> 
             RGBColor[
              0.9880885991242316, 0.9893423438758996, 0.8470662684362013], 
             UndirectedEdge[3, 21] -> 
             RGBColor[
              0.8569817533347747, 0.8849574643875966, 0.7476707973115498], 
             UndirectedEdge[98, 204] -> 
             RGBColor[
              0.9859383092414409, 0.9678138355292889, 0.5823486776301835], 
             UndirectedEdge[243, 367] -> 
             RGBColor[
              0.9879530099731828, 0.9880221209875673, 0.7694965260907927], 
             UndirectedEdge[48, 209] -> 
             RGBColor[
              0.9820076388488278, 0.95174646297039, 0.547667911798959], 
             UndirectedEdge[116, 291] -> 
             RGBColor[
              0.991440150685454, 0.9881854820250446, 0.6162512164103963], 
             UndirectedEdge[214, 340] -> 
             RGBColor[
              0.9214474983873274, 0.9357766437824011, 0.7718253684135274], 
             UndirectedEdge[138, 159] -> 
             RGBColor[
              0.9910301668884058, 0.9905587577412289, 0.7983168780504853], 
             UndirectedEdge[22, 48] -> 
             RGBColor[
              0.9939153429286921, 0.9908465152414769, 0.6846936062928555], 
             UndirectedEdge[13, 297] -> 
             RGBColor[
              0.9706596482666048, 0.9081689062503548, 0.49401463165674997`], 
             UndirectedEdge[192, 347] -> 
             RGBColor[
              0.9791933175687566, 0.9505550704646807, 0.5941177399999604], 
             UndirectedEdge[4, 322] -> 
             RGBColor[
              0.9522870532261885, 0.848498045315855, 0.2806914555229309], 
             UndirectedEdge[111, 304] -> 
             RGBColor[
              0.9341279991085156, 0.9470236593036647, 0.8617192868136085], 
             UndirectedEdge[133, 361] -> 
             RGBColor[
              0.9568731378034143, 0.9673566373043179, 0.957886707798423], 
             UndirectedEdge[4, 186] -> 
             RGBColor[
              0.9581148918837099, 0.8681567135492647, 0.3033315082124176], 
             UndirectedEdge[73, 240] -> 
             RGBColor[
              0.9934940197724643, 0.9884926910858323, 0.5332423863676443], 
             UndirectedEdge[82, 335] -> 
             RGBColor[
              0.993749196338314, 0.9890384879578766, 0.5610167807931772], 
             UndirectedEdge[184, 372] -> 
             RGBColor[
              0.9536466392404219, 0.9036477455280907, 0.6179601701544393], 
             UndirectedEdge[85, 340] -> 
             RGBColor[
              0.9935583481470536, 0.9886302829744823, 0.540244132952971], 
             UndirectedEdge[344, 388] -> 
             RGBColor[
              0.8821308397526284, 0.5519009519418202, 0.2231174916352029], 
             UndirectedEdge[57, 228] -> 
             RGBColor[
              0.9894861883247036, 0.9899202829266989, 0.8239045985394703], 
             UndirectedEdge[36, 80] -> 
             RGBColor[
              0.9501159384886964, 0.9585775818104758, 0.7698177584546573], 
             UndirectedEdge[88, 365] -> 
             RGBColor[
              0.9496244348687943, 0.9527142104902855, 0.701240376632478], 
             UndirectedEdge[209, 241] -> 
             RGBColor[
              0.9823838692051599, 0.9519020438914124, 0.5414328011415851], 
             UndirectedEdge[49, 62] -> 
             RGBColor[
              0.989246928540421, 0.9772189364213898, 0.5830670590301797], 
             UndirectedEdge[161, 250] -> 
             RGBColor[
              0.9897269306480713, 0.9753516626217487, 0.5554911205633815], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.94998074008519, 0.8306311131057231, 0.32426615497808736`], 
             UndirectedEdge[324, 346] -> 
             RGBColor[
              0.977737575519519, 0.9806629876402535, 0.8073804687392871], 
             UndirectedEdge[142, 258] -> 
             RGBColor[
              0.9889229117967273, 0.989475414674104, 0.8237484898966816], 
             UndirectedEdge[44, 46] -> 
             RGBColor[
              0.9843222454702661, 0.9658984309721144, 0.6005109850547177], 
             UndirectedEdge[85, 191] -> 
             RGBColor[
              0.9783312881261743, 0.9802022808256801, 0.7346868690723882], 
             UndirectedEdge[112, 172] -> 
             RGBColor[
              0.9892824625746981, 0.9879216213038373, 0.688123043130134], 
             UndirectedEdge[133, 298] -> 
             RGBColor[
              0.9736257607798179, 0.9778991490709356, 0.8383623091630437], 
             UndirectedEdge[26, 215] -> 
             RGBColor[
              0.904619230212967, 0.7049401747540675, 0.5852817128726382], 
             UndirectedEdge[127, 129] -> 
             RGBColor[
              0.9341791568575382, 0.7685554590945775, 0.2935741868879362], 
             UndirectedEdge[172, 225] -> 
             RGBColor[
              0.9876657045460733, 0.9697101342511718, 0.4359655959865052], 
             UndirectedEdge[38, 376] -> 
             RGBColor[
              0.9904704658993082, 0.9903273069985778, 0.8075925718995624], 
             UndirectedEdge[158, 346] -> 
             RGBColor[
              0.9898608378437871, 0.9895651146206408, 0.7806171276929739], 
             UndirectedEdge[340, 370] -> 
             RGBColor[
              0.9942915815035248, 0.9901985949827101, 0.6200520588131206], 
             UndirectedEdge[44, 266] -> 
             RGBColor[
              0.9621928652856286, 0.8850738273747917, 0.5467124845208559], 
             UndirectedEdge[183, 238] -> 
             RGBColor[
              0.616693196339881, 0.6840547459647378, 0.9278083768592618], 
             UndirectedEdge[21, 264] -> 
             RGBColor[
              0.9934680226467265, 0.9899397275383905, 0.6396389468053743], 
             UndirectedEdge[13, 140] -> 
             RGBColor[
              0.973949718598558, 0.9781514724057075, 0.8386642116813534], 
             UndirectedEdge[210, 266] -> 
             RGBColor[
              0.9181988458129815, 0.7125562174847171, 0.252995804066218], 
             UndirectedEdge[51, 395] -> 
             RGBColor[
              0.9755120073586805, 0.9795107650575262, 0.8481146921152398], 
             UndirectedEdge[358, 372] -> 
             RGBColor[
              0.9753548483437375, 0.9780311969180017, 0.7435925164563264], 
             UndirectedEdge[174, 309] -> 
             RGBColor[
              0.9490510468738859, 0.8411212729224035, 0.5760214526982752], 
             UndirectedEdge[65, 363] -> 
             RGBColor[
              0.9875021654749319, 0.968593467004166, 0.5573503864556786], 
             UndirectedEdge[236, 267] -> 
             RGBColor[
              0.9904491660690748, 0.9884707526016121, 0.6736339099277528], 
             UndirectedEdge[227, 352] -> 
             RGBColor[
              0.9130635749537787, 0.9291712491368826, 0.7774879280944664], 
             UndirectedEdge[2, 370] -> 
             RGBColor[
              0.9764002551590474, 0.9797835873721039, 0.8190047028664437], 
             UndirectedEdge[17, 354] -> 
             RGBColor[
              0.9916142778337802, 0.9892242418602648, 0.6740736679760478], 
             UndirectedEdge[133, 306] -> 
             RGBColor[
              0.8820582496822841, 0.9084343200768938, 0.9739086738080511], 
             UndirectedEdge[105, 261] -> 
             RGBColor[
              0.9699523075648876, 0.9771110606972496, 0.9357470849860523], 
             UndirectedEdge[120, 206] -> 
             RGBColor[
              0.9773822771277842, 0.97932095754583, 0.7225226540561841], 
             UndirectedEdge[361, 393] -> 
             RGBColor[
              0.9640536706641526, 0.9727118669548129, 0.9457319386481011], 
             UndirectedEdge[270, 295] -> 
             RGBColor[
              0.8961551434885398, 0.8991645134806749, 0.6799712275679213], 
             UndirectedEdge[9, 283] -> 
             RGBColor[
              0.9334503841616228, 0.9487598045336213, 0.958420560785172], 
             UndirectedEdge[43, 122] -> 
             RGBColor[
              0.9575985222808627, 0.8568433857329991, 0.45643342717810986`], 
             UndirectedEdge[127, 336] -> 
             RGBColor[
              0.9386005318543238, 0.9248433308644055, 0.6721186710399003], 
             UndirectedEdge[4, 123] -> 
             RGBColor[
              0.9294568597905355, 0.7580269867170921, 0.2620975374083889], 
             UndirectedEdge[45, 279] -> 
             RGBColor[
              0.9369650543048547, 0.7739435601652135, 0.5030835091459637], 
             UndirectedEdge[135, 255] -> 
             RGBColor[
              0.9867414880719516, 0.9876224310002414, 0.8115265368954897], 
             UndirectedEdge[152, 180] -> 
             RGBColor[
              0.9795045037099734, 0.9814020490002303, 0.7584712941523719], 
             UndirectedEdge[48, 68] -> 
             RGBColor[
              0.9915824467822933, 0.9907871396702974, 0.789164170954221], 
             UndirectedEdge[362, 363] -> 
             RGBColor[
              0.9720259482726541, 0.9588034566369825, 0.6620114158858625], 
             UndirectedEdge[18, 257] -> 
             RGBColor[
              0.9687995859229102, 0.9043257724820912, 0.344177707466877], 
             UndirectedEdge[72, 109] -> 
             RGBColor[
              0.9803762535866041, 0.9816920415396881, 0.7284187242702164], 
             UndirectedEdge[181, 211] -> 
             RGBColor[
              0.9491525010609958, 0.9602892795163211, 0.9189727592933788], 
             UndirectedEdge[82, 259] -> 
             RGBColor[
              0.9938198869105046, 0.9907701145778982, 0.6835913457859562], 
             UndirectedEdge[282, 367] -> 
             RGBColor[
              0.9862606643393268, 0.9834336833997643, 0.667664821881488], 
             UndirectedEdge[44, 363] -> 
             RGBColor[
              0.984788526897773, 0.9674713077151804, 0.6023224003507224], 
             UndirectedEdge[139, 290] -> 
             RGBColor[
              0.5218192406882596, 0.3919811295073129, 0.5711626413232858], 
             UndirectedEdge[255, 351] -> 
             RGBColor[
              0.929065527857686, 0.9427353966960543, 0.8442396926214997], 
             UndirectedEdge[290, 345] -> 
             RGBColor[
              0.9105148887475113, 0.7227555481494035, 0.5838250963458304], 
             UndirectedEdge[145, 200] -> 
             RGBColor[
              0.734257943744618, 0.7626330354505426, 0.654015731408143], 
             UndirectedEdge[44, 316] -> 
             RGBColor[
              0.9920833379803151, 0.9906264492146966, 0.7541263428184927], 
             UndirectedEdge[172, 240] -> 
             RGBColor[
              0.9935120809793407, 0.988531322181073, 0.5352082372753004], 
             UndirectedEdge[89, 299] -> 
             RGBColor[
              0.9764525695897378, 0.9798954826495505, 0.8246988057998559], 
             UndirectedEdge[119, 196] -> 
             RGBColor[
              0.9931014440702423, 0.9914152840853139, 0.7639904548539379], 
             UndirectedEdge[149, 369] -> 
             RGBColor[
              0.9903372193459961, 0.9899557523491598, 0.7867979633074015], 
             UndirectedEdge[32, 385] -> 
             RGBColor[
              0.9487712260213272, 0.9607868001736586, 0.9533142961139133], 
             UndirectedEdge[149, 253] -> 
             RGBColor[
              0.9715094498301452, 0.9780119956458249, 0.9214509365905084], 
             UndirectedEdge[317, 336] -> 
             RGBColor[
              0.9379365980008493, 0.9226037260775539, 0.6695394133925399], 
             UndirectedEdge[138, 215] -> 
             RGBColor[
              0.9226213417202866, 0.7178570658312436, 0.5320123462453394], 
             UndirectedEdge[157, 181] -> 
             RGBColor[
              0.9501658765581034, 0.9548147738572214, 0.7037470909256376], 
             UndirectedEdge[299, 342] -> 
             RGBColor[
              0.9675287536200382, 0.9732401153107562, 0.8398044985325959], 
             UndirectedEdge[108, 198] -> 
             RGBColor[
              0.9842944478914358, 0.9650648097277597, 0.5952891570028676], 
             UndirectedEdge[152, 367] -> 
             RGBColor[
              0.98772388806533, 0.9875320523944486, 0.7445580203975249], 
             UndirectedEdge[17, 118] -> 
             RGBColor[
              0.9912813392904742, 0.9885121199813833, 0.6378353621956993], 
             UndirectedEdge[44, 68] -> 
             RGBColor[
              0.9894389062749893, 0.9899007305840488, 0.8246881844652585], 
             UndirectedEdge[158, 323] -> 
             RGBColor[
              0.988841534270125, 0.9873849273439774, 0.6696722241123378], 
             UndirectedEdge[343, 359] -> 
             RGBColor[
              0.894216566714209, 0.8796737932755523, 0.6534991454152568], 
             UndirectedEdge[354, 388] -> 
             RGBColor[
              0.9510786197761969, 0.8320754610661646, 0.38720083916573206`], 
             UndirectedEdge[382, 389] -> 
             RGBColor[
              0.976363578874748, 0.9308103480391234, 0.4579646888170444], 
             UndirectedEdge[178, 319] -> 
             RGBColor[
              0.9611637164004405, 0.8875587112435435, 0.5780102536758956], 
             UndirectedEdge[15, 386] -> 
             RGBColor[
              0.9379925345109803, 0.77196546442674, 0.46530611496639573`], 
             UndirectedEdge[27, 104] -> 
             RGBColor[
              0.9271029471457641, 0.7354084464678046, 0.5211991328585879], 
             UndirectedEdge[236, 398] -> 
             RGBColor[
              0.97808461269848, 0.9373431662462528, 0.40280054066940374`], 
             UndirectedEdge[151, 304] -> 
             RGBColor[
              0.9942971001038133, 0.99061614063669, 0.6501458791868191], 
             UndirectedEdge[21, 233] -> 
             RGBColor[
              0.9936137552775044, 0.989999991726375, 0.6372237799694264], 
             UndirectedEdge[120, 321] -> 
             RGBColor[
              0.965169298895582, 0.8882238751698002, 0.3817585574741964], 
             UndirectedEdge[170, 299] -> 
             RGBColor[
              0.9937490498455933, 0.991409360828649, 0.7333610414732283], 
             UndirectedEdge[97, 109] -> 
             RGBColor[
              0.9925502614237467, 0.9860141074810462, 0.4696334869579594], 
             UndirectedEdge[251, 381] -> 
             RGBColor[
              0.9840210875473479, 0.9866254865699466, 0.868133358196372], 
             UndirectedEdge[134, 392] -> 
             RGBColor[
              0.5944716035128617, 0.6640380645309931, 0.9456845993782301], 
             UndirectedEdge[132, 220] -> 
             RGBColor[
              0.9706351482207682, 0.9081630875061992, 0.4885913379295927], 
             UndirectedEdge[102, 167] -> 
             RGBColor[
              0.9860519797980961, 0.9710695958006785, 0.6026436543759748], 
             UndirectedEdge[270, 373] -> 
             RGBColor[
              0.9030789616655744, 0.921492842507907, 0.7942261469288081], 
             UndirectedEdge[122, 351] -> 
             RGBColor[
              0.9288645704087921, 0.9423055690327853, 0.8223667144750236], 
             UndirectedEdge[96, 173] -> 
             RGBColor[
              0.926037493157662, 0.7905302473562892, 0.5949730000494005], 
             UndirectedEdge[253, 266] -> 
             RGBColor[
              0.9461671620736323, 0.8739723433225768, 0.6119251188223835], 
             UndirectedEdge[217, 230] -> 
             RGBColor[
              0.9942203876248918, 0.9900463184751196, 0.6123030444816229], 
             UndirectedEdge[118, 158] -> 
             RGBColor[
              0.9889100820847923, 0.9875315441883034, 0.6771332307107836], 
             UndirectedEdge[208, 230] -> 
             RGBColor[
              0.9560298674477917, 0.8508099288332988, 0.44418033811034935`], 
             UndirectedEdge[86, 179] -> 
             RGBColor[
              0.908284264127527, 0.9131889140245619, 0.6876440964378427], 
             UndirectedEdge[185, 284] -> 
             RGBColor[
              0.934892222772048, 0.770394377692057, 0.5260818812679842], 
             UndirectedEdge[279, 399] -> 
             RGBColor[
              0.9869377081244021, 0.9884885276074058, 0.849216678292428], 
             UndirectedEdge[167, 309] -> 
             RGBColor[
              0.9478629026496201, 0.8231993911066209, 0.31753741041689176`], 
             UndirectedEdge[174, 183] -> 
             RGBColor[
              0.9826071547707977, 0.9864611791123941, 0.910391810222242], 
             UndirectedEdge[149, 247] -> 
             RGBColor[
              0.9892722485082786, 0.9898318133146047, 0.8274501349561294], 
             UndirectedEdge[297, 339] -> 
             RGBColor[
              0.9657028599010498, 0.8930764200114436, 0.3363314681979149], 
             UndirectedEdge[28, 282] -> 
             RGBColor[
              0.9443796160731526, 0.8050055571645032, 0.32786711737410823`], 
             UndirectedEdge[35, 125] -> 
             RGBColor[
              0.9582578477695409, 0.868553737453236, 0.30433058718717], 
             UndirectedEdge[119, 231] -> 
             RGBColor[
              0.9901437563153951, 0.9901922041895763, 0.8130069952023021], 
             UndirectedEdge[257, 309] -> 
             RGBColor[
              0.9510426277890911, 0.8339253506370236, 0.32989004214302864`], 
             UndirectedEdge[153, 161] -> 
             RGBColor[
              0.9870022826763754, 0.9661607852354515, 0.5449063776999385], 
             UndirectedEdge[315, 369] -> 
             RGBColor[
              0.9750436510269532, 0.9257559240582315, 0.4853575810724257], 
             UndirectedEdge[145, 207] -> 
             RGBColor[
              0.9799313624120665, 0.956651433933765, 0.6219147295000649], 
             UndirectedEdge[75, 215] -> 
             RGBColor[
              0.9263495116938374, 0.7189073866818396, 0.43450927401780876`], 
             UndirectedEdge[155, 199] -> 
             RGBColor[
              0.8962184583644905, 0.8616972115667855, 0.632482742487293], 
             UndirectedEdge[28, 151] -> 
             RGBColor[
              0.9458041574059467, 0.8090211884315033, 0.40054997610940324`], 
             UndirectedEdge[141, 279] -> 
             RGBColor[
              0.9195600818124056, 0.6772284872558072, 0.4878679453490043], 
             UndirectedEdge[347, 380] -> 
             RGBColor[
              0.9436755321266266, 0.9242132205709682, 0.6657225765471102], 
             UndirectedEdge[107, 346] -> 
             RGBColor[
              0.9902540624467626, 0.9897277230993826, 0.7741003783890192], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.9784974019011234, 0.9518105450988079, 0.6163177752785655], 
             UndirectedEdge[171, 299] -> 
             RGBColor[
              0.9946172577100599, 0.9908951834575733, 0.6554999040539045], 
             UndirectedEdge[283, 294] -> 
             RGBColor[
              0.9849332672351427, 0.9861858729163122, 0.8076057573628463], 
             UndirectedEdge[83, 244] -> 
             RGBColor[
              0.8938130675282412, 0.7093895407408025, 0.6005524146885874], 
             UndirectedEdge[112, 179] -> 
             RGBColor[
              0.9091603224373119, 0.9289018470010156, 0.9369240650431834], 
             UndirectedEdge[42, 93] -> 
             RGBColor[
              0.989335842690853, 0.9863298671820377, 0.6443137943052182], 
             UndirectedEdge[94, 254] -> 
             RGBColor[
              0.9526041875930744, 0.961757494113856, 0.8635433813285621], 
             UndirectedEdge[84, 222] -> 
             RGBColor[
              0.9020818456282037, 0.923669989230546, 0.9527452977139712], 
             UndirectedEdge[132, 366] -> 
             RGBColor[
              0.9949022713393605, 0.991504798791349, 0.686521878703042], 
             UndirectedEdge[52, 133] -> 
             RGBColor[
              0.9495360257132908, 0.9618846311209222, 0.9703065247416908], 
             UndirectedEdge[255, 400] -> 
             RGBColor[
              0.9933474618092346, 0.9913095416625707, 0.7448319107553613], 
             UndirectedEdge[276, 318] -> 
             RGBColor[
              0.9748710807957912, 0.9327891834413462, 0.5553053778440975], 
             UndirectedEdge[235, 313] -> 
             RGBColor[
              0.9902406226707329, 0.9884806431651916, 0.6840775494829683], 
             UndirectedEdge[218, 229] -> 
             RGBColor[
              0.9772272169254076, 0.9332553514520947, 0.5011364041850978], 
             UndirectedEdge[202, 260] -> 
             RGBColor[
              0.9940988574214373, 0.9897863776585187, 0.59907523183307], 
             UndirectedEdge[129, 216] -> 
             RGBColor[
              0.9443163756337398, 0.801639051296799, 0.4274801090177859], 
             UndirectedEdge[307, 312] -> 
             RGBColor[
              0.9411619677601945, 0.9552525883216196, 0.9710750404389712], 
             UndirectedEdge[215, 349] -> 
             RGBColor[
              0.9222912426405045, 0.7177205613785944, 0.5374829422663624], 
             UndirectedEdge[48, 61] -> 
             RGBColor[
              0.985775369912306, 0.987349175610083, 0.8389819102539795], 
             UndirectedEdge[198, 284] -> 
             RGBColor[
              0.9839473811778017, 0.9649212887224643, 0.6010409506276493], 
             UndirectedEdge[37, 256] -> 
             RGBColor[
              0.9063002617677021, 0.5632214904452038, 0.4460095698845693], 
             UndirectedEdge[260, 366] -> 
             RGBColor[
              0.9945567251831959, 0.9907657105033885, 0.6489113120682064], 
             UndirectedEdge[35, 263] -> 
             RGBColor[
              0.9815191596891528, 0.9484680407960691, 0.5344991511173952], 
             UndirectedEdge[124, 185] -> 
             RGBColor[
              0.8770559534516771, 0.7264730042621893, 0.6049647699341698], 
             UndirectedEdge[17, 48] -> 
             RGBColor[
              0.9916858010509542, 0.9908298793164722, 0.7874513232502378], 
             UndirectedEdge[98, 139] -> 
             RGBColor[
              0.5795515895139411, 0.6250928691929215, 0.6554948141240682], 
             UndirectedEdge[98, 125] -> 
             RGBColor[
              0.9641767952611566, 0.8885197371774168, 0.3273245804926527], 
             UndirectedEdge[195, 397] -> 
             RGBColor[
              0.959627405429194, 0.9673426782642127, 0.8635645542943637], 
             UndirectedEdge[152, 198] -> 
             RGBColor[
              0.9863188952459374, 0.9646751343533061, 0.4725607714477875], 
             UndirectedEdge[29, 129] -> 
             RGBColor[
              0.9260773966306858, 0.7412263194656399, 0.26210037829565574`], 
             UndirectedEdge[83, 230] -> 
             RGBColor[
              0.9588303659909987, 0.9660630065415317, 0.8141618144398625], 
             UndirectedEdge[10, 155] -> 
             RGBColor[
              0.8978227116932155, 0.9208572383169243, 0.9725647534852726], 
             UndirectedEdge[210, 316] -> 
             RGBColor[
              0.948089318507668, 0.8181088393246221, 0.46040966236385483`], 
             UndirectedEdge[6, 175] -> 
             RGBColor[
              0.9910637818638273, 0.990383649769442, 0.7840208589366882], 
             UndirectedEdge[301, 343] -> 
             RGBColor[
              0.9341658120041887, 0.9115282370764065, 0.6573095400941272], 
             UndirectedEdge[140, 297] -> 
             RGBColor[
              0.9494686330162483, 0.8943055326690353, 0.6202017920901253], 
             UndirectedEdge[274, 295] -> 
             RGBColor[
              0.9848486317324381, 0.9675760006397591, 0.6018781451876487], 
             UndirectedEdge[61, 371] -> 
             RGBColor[
              0.9749685619904838, 0.9808521750344965, 0.9272558746922059], 
             UndirectedEdge[266, 397] -> 
             RGBColor[
              0.9297237000708326, 0.8614167625395148, 0.6296332307592178], 
             UndirectedEdge[71, 88] -> 
             RGBColor[
              0.9911245798596344, 0.9811669459474981, 0.46732647150854983`], 
             UndirectedEdge[156, 255] -> 
             RGBColor[
              0.984632718683239, 0.9582580128966298, 0.5280206182156941], 
             UndirectedEdge[22, 388] -> 
             RGBColor[
              0.951467361084665, 0.8329069394172026, 0.42951293155922854`], 
             UndirectedEdge[17, 346] -> 
             RGBColor[
              0.9922320950494691, 0.9905456904137209, 0.7413192591778895], 
             UndirectedEdge[72, 365] -> 
             RGBColor[
              0.9389068966908245, 0.9533051587046566, 0.9656837235394055], 
             UndirectedEdge[194, 230] -> 
             RGBColor[
              0.9917746999107575, 0.9901369140464924, 0.7329345726259918], 
             UndirectedEdge[95, 264] -> 
             RGBColor[
              0.966589938922064, 0.9730503387393862, 0.871888919158806], 
             UndirectedEdge[131, 325] -> 
             RGBColor[
              0.8427174051029348, 0.8774240001472375, 0.9848603324730683], 
             UndirectedEdge[369, 372] -> 
             RGBColor[
              0.9760806444054504, 0.9795836013047674, 0.8225909386796987], 
             UndirectedEdge[11, 248] -> 
             RGBColor[
              0.9813980925193984, 0.9572072545484027, 0.5972567103677233], 
             UndirectedEdge[32, 223] -> 
             RGBColor[
              0.9540868452796151, 0.9632997485294932, 0.8793182585325008], 
             UndirectedEdge[75, 229] -> 
             RGBColor[
              0.9948949141266676, 0.9914890624573273, 0.6857210915048737], 
             UndirectedEdge[123, 131] -> 
             RGBColor[
              0.8815322085751458, 0.7839905054303223, 0.616303604736085], 
             UndirectedEdge[35, 340] -> 
             RGBColor[
              0.9810306847291672, 0.9469211891338964, 0.44483770471113016`], 
             UndirectedEdge[316, 369] -> 
             RGBColor[
              0.9948854042841696, 0.9914687218658167, 0.6846860038369134], 
             UndirectedEdge[232, 280] -> 
             RGBColor[
              0.8870121786417842, 0.9106598566552275, 0.8968383296032865], 
             UndirectedEdge[30, 318] -> 
             RGBColor[
              0.9883358184070724, 0.9894445754026, 0.8429692051365336], 
             UndirectedEdge[219, 338] -> 
             RGBColor[
              0.9886317149478827, 0.9882446597712804, 0.7458421716413031], 
             UndirectedEdge[124, 397] -> 
             RGBColor[
              0.8989085176410294, 0.9222292680179968, 0.99021989094935], 
             UndirectedEdge[131, 280] -> 
             RGBColor[
              0.8182956794797958, 0.8582418252873443, 0.982453731757849], 
             UndirectedEdge[224, 345] -> 
             RGBColor[
              0.9723777710720627, 0.9782146778068112, 0.9000570985279996], 
             UndirectedEdge[44, 195] -> 
             RGBColor[
              0.9920965706439901, 0.9909997430994895, 0.7806438080560018], 
             UndirectedEdge[57, 102] -> 
             RGBColor[
              0.9901338262339074, 0.9901880978456898, 0.8131715623507811], 
             UndirectedEdge[102, 222] -> 
             RGBColor[
              0.9838560525279345, 0.9865554885474384, 0.870789966347183], 
             UndirectedEdge[86, 285] -> 
             RGBColor[
              0.9708133676375073, 0.9132087770734503, 0.341115874015101], 
             UndirectedEdge[97, 340] -> 
             RGBColor[
              0.9927403889457833, 0.9864207710258415, 0.4903276944005904], 
             UndirectedEdge[84, 183] -> 
             RGBColor[
              0.90335231391736, 0.9246175024003978, 0.9505947262916281], 
             UndirectedEdge[23, 132] -> 
             RGBColor[
              0.9525406233687264, 0.836424326110818, 0.47403205850055286`], 
             UndirectedEdge[124, 210] -> 
             RGBColor[
              0.8873836633831783, 0.7733687229631989, 0.6135824642563502], 
             UndirectedEdge[257, 288] -> 
             RGBColor[
              0.9858602459142198, 0.9802060890896849, 0.6621249919051863], 
             UndirectedEdge[31, 287] -> 
             RGBColor[
              0.9870670160189534, 0.9889198930083788, 0.8639965442629894], 
             UndirectedEdge[163, 222] -> 
             RGBColor[
              0.9855344838231901, 0.9872495630217434, 0.8429740161438439], 
             UndirectedEdge[206, 386] -> 
             RGBColor[
              0.9212514340253781, 0.7614475981028439, 0.5860846656169386], 
             UndirectedEdge[95, 263] -> 
             RGBColor[
              0.9671698648006828, 0.9732901529936103, 0.8622780465500282], 
             UndirectedEdge[103, 333] -> 
             RGBColor[
              0.9067263394968119, 0.6676656589480965, 0.5668812646681152], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.9949286360689671, 0.9915611902820944, 0.689391516816463], 
             UndirectedEdge[57, 174] -> 
             RGBColor[
              0.9876144601876143, 0.9891462752407936, 0.8549239776481832], 
             UndirectedEdge[32, 208] -> 
             RGBColor[
              0.9164344565249796, 0.8231839397677334, 0.6221771683672641], 
             UndirectedEdge[11, 125] -> 
             RGBColor[
              0.9612274903272071, 0.8785710391054753, 0.31586708775376204`], 
             UndirectedEdge[82, 136] -> 
             RGBColor[
              0.9946795021679877, 0.9910283180592008, 0.6622748291710776], 
             UndirectedEdge[129, 298] -> 
             RGBColor[
              0.9447269631347687, 0.8025172564447354, 0.47217002465243263`], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.9939945548013276, 0.9916295872538166, 0.7379209033891065], 
             UndirectedEdge[155, 306] -> 
             RGBColor[
              0.8261527186681532, 0.8642803787028547, 0.9832632324172641], 
             UndirectedEdge[247, 358] -> 
             RGBColor[
              0.9931244095310684, 0.9898560580550684, 0.649580267657821], 
             UndirectedEdge[5, 373] -> 
             RGBColor[
              0.9896872988254555, 0.9890420661078114, 0.7506894142087276], 
             UndirectedEdge[194, 201] -> 
             RGBColor[
              0.9912693864487847, 0.9890560996463607, 0.6779343207234535], 
             UndirectedEdge[7, 173] -> 
             RGBColor[
              0.9667091881743496, 0.948802947711994, 0.658199551021295], 
             UndirectedEdge[25, 364] -> 
             RGBColor[
              0.968510434038951, 0.9741156906335866, 0.8495240942428861], 
             UndirectedEdge[1, 313] -> 
             RGBColor[
              0.9880697770246871, 0.9709566995131729, 0.4474387768069107], 
             UndirectedEdge[189, 222] -> 
             RGBColor[
              0.9850616971097629, 0.9870540535656769, 0.8508093155181256], 
             UndirectedEdge[232, 275] -> 
             RGBColor[
              0.9706654002483034, 0.9766697868028784, 0.8909627220645713], 
             UndirectedEdge[289, 376] -> 
             RGBColor[
              0.9922837988664208, 0.9892753894651596, 0.6465707615451619], 
             UndirectedEdge[194, 208] -> 
             RGBColor[
              0.9533684449219291, 0.8504390894565204, 0.5413304633590346], 
             UndirectedEdge[320, 384] -> 
             RGBColor[
              0.9290606926880411, 0.8345090317415174, 0.6201625457844187], 
             UndirectedEdge[262, 332] -> 
             RGBColor[
              0.934914849137997, 0.7659204789191416, 0.3098003637395691], 
             UndirectedEdge[39, 237] -> 
             RGBColor[
              0.9087822576113815, 0.6179316861977903, 0.5343016166212187], 
             UndirectedEdge[105, 353] -> 
             RGBColor[
              0.9762810404802034, 0.95410977360767, 0.638108239686277], 
             UndirectedEdge[160, 321] -> 
             RGBColor[
              0.9659298680889552, 0.8898506557690844, 0.46454182048390535`], 
             UndirectedEdge[22, 354] -> 
             RGBColor[
              0.9938438197115183, 0.9892408777852695, 0.5713159510186656], 
             UndirectedEdge[70, 286] -> 
             RGBColor[
              0.9476050518593107, 0.825675142439711, 0.5273270345281613], 
             UndirectedEdge[97, 334] -> 
             RGBColor[
              0.9933223667253627, 0.9876655626493821, 0.5536723841572702], 
             UndirectedEdge[301, 362] -> 
             RGBColor[
              0.9328402738161004, 0.9485612458705268, 0.9683449696201418], 
             UndirectedEdge[166, 300] -> 
             RGBColor[
              0.9810606030658635, 0.9465136543227388, 0.48818939273642065`], 
             UndirectedEdge[357, 364] -> 
             RGBColor[
              0.9767895440765793, 0.9317214445341521, 0.5043283722838674], 
             UndirectedEdge[13, 66] -> 
             RGBColor[
              0.9941831195181627, 0.9899666057632095, 0.6082466410562417], 
             UndirectedEdge[102, 395] -> 
             RGBColor[
              0.9730388930935793, 0.9784880687527693, 0.8891005957025225], 
             UndirectedEdge[129, 336] -> 
             RGBColor[
              0.8987499519841641, 0.7693404447049441, 0.6120819973576823], 
             UndirectedEdge[257, 275] -> 
             RGBColor[
              0.9699927495373386, 0.9683721362724476, 0.6889845243653903], 
             UndirectedEdge[358, 369] -> 
             RGBColor[
              0.994189380368786, 0.9899799970896235, 0.608928096009093], 
             UndirectedEdge[42, 139] -> 
             RGBColor[
              0.5853329226143663, 0.644594663262221, 0.6779542015060729], 
             UndirectedEdge[37, 206] -> 
             RGBColor[
              0.8894695516646758, 0.5525119582105595, 0.5570346666849528], 
             UndirectedEdge[3, 162] -> 
             RGBColor[
              0.8309492086767741, 0.8686986772400656, 0.9784894925770302], 
             UndirectedEdge[44, 161] -> 
             RGBColor[
              0.9922494470699806, 0.990981739761286, 0.772206292122114], 
             UndirectedEdge[67, 266] -> 
             RGBColor[
              0.9448117109008238, 0.8189038546685745, 0.27445241103640583`], 
             UndirectedEdge[305, 360] -> 
             RGBColor[
              0.9848112717305519, 0.9589013354816094, 0.5252261137747012], 
             UndirectedEdge[51, 174] -> 
             RGBColor[
              0.9897132382874632, 0.9900141739212179, 0.8201417930700754], 
             UndirectedEdge[132, 321] -> 
             RGBColor[
              0.9661174253609572, 0.8902518218089475, 0.48495627207200387`], 
             UndirectedEdge[198, 236] -> 
             RGBColor[
              0.9859590252807152, 0.9639054088861307, 0.4333911465933464], 
             UndirectedEdge[153, 356] -> 
             RGBColor[
              0.9867430684281709, 0.965606352169123, 0.5166925064677972], 
             UndirectedEdge[78, 217] -> 
             RGBColor[
              0.9648022861006011, 0.970535439668231, 0.79127059559436], 
             UndirectedEdge[16, 324] -> 
             RGBColor[
              0.9090922135708135, 0.9297025863438882, 0.968763333438091], 
             UndirectedEdge[263, 312] -> 
             RGBColor[
              0.957701933762346, 0.9658423014383883, 0.8648982040528281], 
             UndirectedEdge[49, 231] -> 
             RGBColor[
              0.9861014643939465, 0.9759182061620812, 0.6351955401375322], 
             UndirectedEdge[58, 303] -> 
             RGBColor[
              0.909485247734932, 0.6398549355221366, 0.26901396491529245`], 
             UndirectedEdge[287, 371] -> 
             RGBColor[
              0.9808291081273153, 0.9843122500106485, 0.8765520112668141], 
             UndirectedEdge[108, 332] -> 
             RGBColor[
              0.9376873406269473, 0.7816539271729666, 0.5223728015226984], 
             UndirectedEdge[55, 135] -> 
             RGBColor[
              0.942480776599959, 0.955870393775951, 0.9561615116070834], 
             UndirectedEdge[38, 145] -> 
             RGBColor[
              0.9819393023766578, 0.9574817687108268, 0.5886379679047309], 
             UndirectedEdge[41, 400] -> 
             RGBColor[
              0.9815473848323992, 0.9530717914218765, 0.5657716650045193], 
             UndirectedEdge[184, 369] -> 
             RGBColor[
              0.9724811712654703, 0.9155965456997126, 0.4832957497072059], 
             UndirectedEdge[68, 363] -> 
             RGBColor[
              0.9849163893499725, 0.9675241821250801, 0.600203388620357], 
             UndirectedEdge[239, 350] -> 
             RGBColor[
              0.9416260929247704, 0.804614831021043, 0.2805298606828983], 
             UndirectedEdge[197, 300] -> 
             RGBColor[
              0.9788261293508109, 0.9462237688041248, 0.5713147279808435], 
             UndirectedEdge[34, 340] -> 
             RGBColor[
              0.9914326564761264, 0.9893803428162773, 0.6938898433463935], 
             UndirectedEdge[99, 225] -> 
             RGBColor[
              0.986042543688737, 0.9645803638748318, 0.40027834718554767`], 
             UndirectedEdge[75, 218] -> 
             RGBColor[
              0.9770447179145557, 0.9328650045213629, 0.48127251310721536`], 
             UndirectedEdge[33, 256] -> 
             RGBColor[
              0.9438982635851163, 0.798566770401206, 0.4799126814573692], 
             UndirectedEdge[68, 173] -> 
             RGBColor[
              0.9736565890275672, 0.9789807633857054, 0.8894888298139878], 
             UndirectedEdge[76, 368] -> 
             RGBColor[
              0.9768237290104577, 0.9806750565688176, 0.8542242712928436], 
             UndirectedEdge[343, 369] -> 
             RGBColor[
              0.9806760696896137, 0.9449892689529511, 0.5060204432231701], 
             UndirectedEdge[172, 243] -> 
             RGBColor[
              0.993690500028895, 0.9889129424871363, 0.5546280497445382], 
             UndirectedEdge[25, 83] -> 
             RGBColor[
              0.9325374212457203, 0.9488854195596235, 0.9879278743116142], 
             UndirectedEdge[176, 372] -> 
             RGBColor[
              0.9760901479378146, 0.9796039283995395, 0.8236253395285222], 
             UndirectedEdge[211, 214] -> 
             RGBColor[
              0.9186428301701037, 0.9359616961108783, 0.9160627196475009], 
             UndirectedEdge[273, 330] -> 
             RGBColor[
              0.9633031419803524, 0.9611006756780367, 0.6954632619615382], 
             UndirectedEdge[247, 266] -> 
             RGBColor[
              0.9639299607517656, 0.8857921609913566, 0.5179243171880045], 
             UndirectedEdge[294, 347] -> 
             RGBColor[
              0.9826568399683258, 0.9516708722100251, 0.5137153617188857], 
             UndirectedEdge[247, 343] -> 
             RGBColor[
              0.9796110988518962, 0.944865329918396, 0.546672614871898], 
             UndirectedEdge[147, 354] -> 
             RGBColor[
              0.9133311485464106, 0.6223301052728183, 0.3542182173928352], 
             UndirectedEdge[83, 206] -> 
             RGBColor[
              0.9424223564373646, 0.9562575880404558, 0.971195257436162], 
             UndirectedEdge[178, 300] -> 
             RGBColor[
              0.9521440620613375, 0.8445405465939313, 0.2982346330876923], 
             UndirectedEdge[31, 384] -> 
             RGBColor[
              0.9514710079427007, 0.8511780296707023, 0.5802314115543764], 
             UndirectedEdge[325, 339] -> 
             RGBColor[
              0.909022872209621, 0.9156804125188898, 0.6905134493623453], 
             UndirectedEdge[43, 237] -> 
             RGBColor[
              0.9530202062389639, 0.8555043380662832, 0.5725927289203103], 
             UndirectedEdge[114, 128] -> 
             RGBColor[
              0.9686658851325401, 0.9110367118561657, 0.5533864934703573], 
             UndirectedEdge[131, 188] -> 
             RGBColor[
              0.9223081075212122, 0.9381384270856026, 0.8840244271946508], 
             UndirectedEdge[8, 352] -> 
             RGBColor[
              0.9474100321021113, 0.9565581817572202, 0.7807639238387187], 
             UndirectedEdge[56, 137] -> 
             RGBColor[
              0.9120611204404666, 0.9305219275971435, 0.9071110291641657], 
             UndirectedEdge[11, 93] -> 
             RGBColor[
              0.9806052046564782, 0.9568793750407967, 0.6103969141843228], 
             UndirectedEdge[232, 325] -> 
             RGBColor[
              0.9114339042649231, 0.9298420315151208, 0.8992449303185057], 
             UndirectedEdge[293, 387] -> 
             RGBColor[
              0.9802754783950359, 0.9578122179465962, 0.6232515551130506], 
             UndirectedEdge[100, 175] -> 
             RGBColor[
              0.9877509513965212, 0.9892027178633405, 0.8526619650886713], 
             UndirectedEdge[327, 336] -> 
             RGBColor[
              0.9485426847101002, 0.9575096967870276, 0.7847928715387911], 
             UndirectedEdge[230, 357] -> 
             RGBColor[
              0.9764222877289698, 0.9309359203419282, 0.4643547852900397], 
             UndirectedEdge[151, 291] -> 
             RGBColor[
              0.9930936326147274, 0.9875756613498825, 0.49481928083605287`], 
             UndirectedEdge[10, 87] -> 
             RGBColor[
              0.9348423707644266, 0.8321784400008996, 0.6052220370651937], 
             UndirectedEdge[44, 247] -> 
             RGBColor[
              0.9910481392889268, 0.9905661897907141, 0.7980190288627724], 
             UndirectedEdge[191, 334] -> 
             RGBColor[
              0.9790780031723838, 0.9817994288050498, 0.8159621936611863], 
             UndirectedEdge[31, 389] -> 
             RGBColor[
              0.9893895147526031, 0.9890492840042977, 0.7651002092368342], 
             UndirectedEdge[323, 346] -> 
             RGBColor[
              0.9936714092607656, 0.9888721092644803, 0.5525501374482165], 
             UndirectedEdge[91, 257] -> 
             RGBColor[
              0.9069584472322499, 0.9185121264481872, 0.696904017557555], 
             UndirectedEdge[25, 217] -> 
             RGBColor[
              0.9679274428796134, 0.9728687314932114, 0.7860691043533747], 
             UndirectedEdge[4, 238] -> 
             RGBColor[
              0.6006791832247234, 0.6082634000278461, 0.6075528005625808], 
             UndirectedEdge[49, 298] -> 
             RGBColor[
              0.9903662005304508, 0.9775466436792062, 0.5546945397250566], 
             UndirectedEdge[96, 245] -> 
             RGBColor[
              0.9442618049478391, 0.802460042054459, 0.4897021854479272], 
             UndirectedEdge[198, 219] -> 
             RGBColor[
              0.986344414993936, 0.9647297185138328, 0.4753384385278103], 
             UndirectedEdge[69, 106] -> 
             RGBColor[
              0.9570078743437118, 0.8614254945811625, 0.5274121728905548], 
             UndirectedEdge[246, 350] -> 
             RGBColor[
              0.9758494763863464, 0.9361125616109618, 0.559265374063045], 
             UndirectedEdge[91, 263] -> 
             RGBColor[
              0.9099565049958377, 0.9277713925551131, 0.8603442024342312], 
             UndirectedEdge[193, 305] -> 
             RGBColor[
              0.9874875839087545, 0.967929164886669, 0.5356230812078708], 
             UndirectedEdge[217, 244] -> 
             RGBColor[
              0.9292030891621343, 0.7333728526743905, 0.3986936447303479], 
             UndirectedEdge[218, 260] -> 
             RGBColor[
              0.9768633161289668, 0.9324770044445223, 0.46152804822792276`], 
             UndirectedEdge[115, 169] -> 
             RGBColor[
              0.9739256851893001, 0.9237073549825603, 0.3532066399919633], 
             UndirectedEdge[152, 332] -> 
             RGBColor[
              0.9397117879814488, 0.781264251798513, 0.39964441596761835`], 
             UndirectedEdge[8, 227] -> 
             RGBColor[
              0.8666316744142812, 0.8964925893605573, 0.9871412968285047], 
             UndirectedEdge[161, 344] -> 
             RGBColor[
              0.9253736843365423, 0.7100880022669828, 0.4592212758063575], 
             UndirectedEdge[255, 324] -> 
             RGBColor[
              0.9779129685490289, 0.9810381355954196, 0.8264709176011305], 
             UndirectedEdge[135, 221] -> 
             RGBColor[
              0.9736650730967958, 0.9798800351518512, 0.9294623413848682], 
             UndirectedEdge[179, 257] -> 
             RGBColor[
              0.9107612535539584, 0.9215443809846899, 0.6972667326193249], 
             UndirectedEdge[40, 350] -> 
             RGBColor[
              0.9249894233511671, 0.8979474092908308, 0.6472193817098152], 
             UndirectedEdge[358, 397] -> 
             RGBColor[
              0.9589181488501354, 0.9654806596032267, 0.7612891812290343], 
             UndirectedEdge[44, 149] -> 
             RGBColor[
              0.9875351530421416, 0.9891134796980399, 0.8562383022889808], 
             UndirectedEdge[215, 218] -> 
             RGBColor[
              0.9086818144925772, 0.6606736756766071, 0.24992458669803286`], 
             UndirectedEdge[211, 248] -> 
             RGBColor[
              0.9883161824290249, 0.9894364554210557, 0.8432946241090639], 
             UndirectedEdge[38, 103] -> 
             RGBColor[
              0.9781133092554832, 0.9823045780344756, 0.881944764966923], 
             UndirectedEdge[79, 213] -> 
             RGBColor[
              0.9437185703775512, 0.8070867520549571, 0.5191660031946075], 
             UndirectedEdge[116, 383] -> 
             RGBColor[
              0.929108769719649, 0.7413292281903636, 0.509430576809236], 
             UndirectedEdge[214, 263] -> 
             RGBColor[
              0.9219359733473129, 0.9373234954445736, 0.8614868148197925], 
             UndirectedEdge[203, 275] -> 
             RGBColor[
              0.9654382261352927, 0.9530086593843972, 0.6712910609980175], 
             UndirectedEdge[235, 396] -> 
             RGBColor[
              0.978590350565439, 0.9830486321303555, 0.8985251167758026], 
             UndirectedEdge[170, 361] -> 
             RGBColor[
              0.9770767482828957, 0.9810386484442075, 0.8616279303041929], 
             UndirectedEdge[190, 255] -> 
             RGBColor[
              0.9792599698751374, 0.9820427269789191, 0.8241907957102401], 
             UndirectedEdge[67, 113] -> 
             RGBColor[
              0.9742990213211506, 0.9235941531695829, 0.4379845437991473], 
             UndirectedEdge[244, 307] -> 
             RGBColor[
              0.9130108144202284, 0.7240288691214659, 0.5792084906223312], 
             UndirectedEdge[106, 292] -> 
             RGBColor[
              0.9489818010466408, 0.8298073072924113, 0.3071266347206796], 
             UndirectedEdge[119, 126] -> 
             RGBColor[
              0.9894679795002801, 0.9899127531098544, 0.8242063658830949], 
             UndirectedEdge[148, 288] -> 
             RGBColor[
              0.9848062245155554, 0.987789716329335, 0.8927186149451019], 
             UndirectedEdge[143, 277] -> 
             RGBColor[
              0.9763034469155809, 0.9401425799931513, 0.5782996721637215], 
             UndirectedEdge[245, 364] -> 
             RGBColor[
              0.9946828340200693, 0.9919731564907602, 0.7307992395275491], 
             UndirectedEdge[101, 335] -> 
             RGBColor[
              0.9900347815143647, 0.9884447460570698, 0.6910668989578062], 
             UndirectedEdge[175, 296] -> 
             RGBColor[
              0.9649979448392665, 0.9729388524303266, 0.92276117965818], 
             UndirectedEdge[106, 158] -> 
             RGBColor[
              0.953997248477181, 0.8601805234157964, 0.5773060347489571], 
             UndirectedEdge[59, 319] -> 
             RGBColor[
              0.9603940787420763, 0.9697328507037183, 0.9408813998833012], 
             UndirectedEdge[159, 218] -> 
             RGBColor[
              0.9770906396606964, 0.9333753675865923, 0.5162291185031787], 
             UndirectedEdge[126, 326] -> 
             RGBColor[
              0.9863830587281344, 0.9886370590917244, 0.8753314865965904], 
             UndirectedEdge[130, 371] -> 
             RGBColor[
              0.9783709247880445, 0.9694358726061867, 0.663796336928711], 
             UndirectedEdge[108, 262] -> 
             RGBColor[
              0.9870385024679212, 0.9743211501488993, 0.605949290861288], 
             UndirectedEdge[34, 91] -> 
             RGBColor[
              0.9071776010982949, 0.9266222443789065, 0.9063978315892702], 
             UndirectedEdge[173, 323] -> 
             RGBColor[
              0.9751992575075246, 0.9773499218826396, 0.6990068603803316], 
             UndirectedEdge[104, 208] -> 
             RGBColor[
              0.891449206028312, 0.5961191298669215, 0.23093527901093866`], 
             UndirectedEdge[115, 122] -> 
             RGBColor[
              0.9833640447650396, 0.9542265268706441, 0.5019997632073024], 
             UndirectedEdge[275, 297] -> 
             RGBColor[
              0.9487300709762465, 0.8937547143088864, 0.6214519849760176], 
             UndirectedEdge[185, 293] -> 
             RGBColor[
              0.9331092369062495, 0.7696570672159027, 0.5556305712837741], 
             UndirectedEdge[92, 256] -> 
             RGBColor[
              0.9904174911989372, 0.9903049895589678, 0.8084406215377071], 
             UndirectedEdge[135, 165] -> 
             RGBColor[
              0.9849382643196256, 0.987084228718102, 0.8564920145549854], 
             UndirectedEdge[158, 270] -> 
             RGBColor[
              0.8985106449701188, 0.9205651073332046, 0.9398172398731286], 
             UndirectedEdge[35, 86] -> 
             RGBColor[
              0.9760441124991337, 0.9308533077290153, 0.36143633005923703`], 
             UndirectedEdge[124, 387] -> 
             RGBColor[
              0.9242221949404634, 0.9146281549928827, 0.6725857537634463], 
             UndirectedEdge[170, 261] -> 
             RGBColor[
              0.9770767482828957, 0.9810386484442075, 0.8616279303041929], 
             UndirectedEdge[78, 244] -> 
             RGBColor[
              0.9000007224495719, 0.714323408815653, 0.6011425987387687], 
             UndirectedEdge[320, 381] -> 
             RGBColor[
              0.9648593550091569, 0.9723346978174212, 0.9005691732032791], 
             UndirectedEdge[90, 166] -> 
             RGBColor[
              0.949626529632186, 0.9587984492886819, 0.8193095394288621], 
             UndirectedEdge[119, 317] -> 
             RGBColor[
              0.9831967523211944, 0.9556192395696919, 0.5513308993779695], 
             UndirectedEdge[173, 250] -> 
             RGBColor[
              0.9710062101534582, 0.9632978118362683, 0.6748926699856207], 
             UndirectedEdge[234, 355] -> 
             RGBColor[
              0.9749392518574531, 0.9805680479023129, 0.915560606414872], 
             UndirectedEdge[203, 297] -> 
             RGBColor[
              0.9628867178433413, 0.8835769115891934, 0.3253912880875217], 
             UndirectedEdge[48, 388] -> 
             RGBColor[
              0.9511501429933708, 0.8336810985223719, 0.5005784944399221], 
             UndirectedEdge[34, 95] -> 
             RGBColor[
              0.96439096090314, 0.9721410048174037, 0.9083316757050673], 
             UndirectedEdge[133, 299] -> 
             RGBColor[
              0.9735454393661119, 0.9777273496887592, 0.8296198189674584], 
             UndirectedEdge[58, 376] -> 
             RGBColor[
              0.9192252964955341, 0.6767783275772508, 0.4926648597807448], 
             UndirectedEdge[239, 392] -> 
             RGBColor[
              0.5760042505058687, 0.5433053910007957, 0.5961336809754121], 
             UndirectedEdge[64, 77] -> 
             RGBColor[
              0.9777138703072417, 0.9815227608865928, 0.860950153244922], 
             UndirectedEdge[73, 112] -> 
             RGBColor[
              0.9892644013678216, 0.9878829902085966, 0.686157192222478], 
             UndirectedEdge[257, 339] -> 
             RGBColor[
              0.9869655384621419, 0.9676938419750047, 0.4038640075872876], 
             UndirectedEdge[35, 85] -> 
             RGBColor[
              0.9808659474625372, 0.9465688327780674, 0.42690706987901195`], 
             UndirectedEdge[37, 187] -> 
             RGBColor[
              0.9046300092045954, 0.5625312091264449, 0.4737198555714536], 
             UndirectedEdge[9, 39] -> 
             RGBColor[
              0.86201548679718, 0.582139397657541, 0.5839553861877829], 
             UndirectedEdge[136, 394] -> 
             RGBColor[
              0.9674044712033731, 0.9732898992514614, 0.8513195441301318], 
             UndirectedEdge[287, 389] -> 
             RGBColor[
              0.9919962059945266, 0.9901272178217424, 0.7219005894574713], 
             UndirectedEdge[195, 372] -> 
             RGBColor[
              0.9760641049227963, 0.9798932155789877, 0.8458678895216558], 
             UndirectedEdge[149, 362] -> 
             RGBColor[
              0.9747725744170227, 0.980445628619842, 0.915927317824121], 
             UndirectedEdge[83, 321] -> 
             RGBColor[
              0.9302093782051621, 0.8651605056644259, 0.6304311608541743], 
             UndirectedEdge[227, 308] -> 
             RGBColor[
              0.912658440557214, 0.9283047076280018, 0.733391549228084], 
             UndirectedEdge[100, 146] -> 
             RGBColor[
              0.9874237353015352, 0.9890674055989936, 0.8580847825906999], 
             UndirectedEdge[100, 278] -> 
             RGBColor[
              0.9889690572419136, 0.9897064359343026, 0.8324747988736421], 
             UndirectedEdge[234, 350] -> 
             RGBColor[
              0.973672056902327, 0.9352121426971916, 0.5953508498942375], 
             UndirectedEdge[278, 352] -> 
             RGBColor[
              0.9916714005499072, 0.9895815975363549, 0.6973859329205273], 
             UndirectedEdge[342, 353] -> 
             RGBColor[
              0.9571851849726564, 0.9398681158367351, 0.6704325420637851], 
             UndirectedEdge[109, 181] -> 
             RGBColor[
              0.9517670417561828, 0.9596975636430487, 0.7540412006167745], 
             UndirectedEdge[59, 296] -> 
             RGBColor[
              0.9390529075730099, 0.9540528154862347, 0.9875828483576697], 
             UndirectedEdge[168, 378] -> 
             RGBColor[
              0.9792263201594029, 0.9405685422435105, 0.5244499603213233], 
             UndirectedEdge[191, 370] -> 
             RGBColor[
              0.9790645214826457, 0.9817705928339079, 0.8144947949325378], 
             UndirectedEdge[153, 184] -> 
             RGBColor[
              0.9644319405680104, 0.889933318522758, 0.32543617426660965`], 
             UndirectedEdge[3, 91] -> 
             RGBColor[
              0.7728903098052671, 0.8225493151500949, 0.9779869255491844], 
             UndirectedEdge[149, 210] -> 
             RGBColor[
              0.9435411335694944, 0.8165958698079652, 0.562521621834343], 
             UndirectedEdge[3, 312] -> 
             RGBColor[
              0.8206357385717753, 0.8606202240333701, 0.9825409271677814], 
             UndirectedEdge[17, 388] -> 
             RGBColor[
              0.9492378192069271, 0.832890303492198, 0.5322706485166109], 
             UndirectedEdge[99, 243] -> 
             RGBColor[
              0.9920673391715589, 0.9837831721107962, 0.5189408009435807], 
             UndirectedEdge[108, 398] -> 
             RGBColor[
              0.9764200353092006, 0.9385025670878817, 0.5646985510789249], 
             UndirectedEdge[57, 186] -> 
             RGBColor[
              0.9791362104156841, 0.946633155614556, 0.5681192519350398], 
             UndirectedEdge[180, 398] -> 
             RGBColor[
              0.9640890977078012, 0.9302396930598413, 0.6273765021419595], 
             UndirectedEdge[66, 318] -> 
             RGBColor[
              0.9916832645592404, 0.9890547199089154, 0.6585342543731292], 
             UndirectedEdge[374, 382] -> 
             RGBColor[
              0.9524592028998771, 0.9154959390707158, 0.6341770000484757], 
             UndirectedEdge[190, 270] -> 
             RGBColor[
              0.8877343839719594, 0.9126675717363167, 0.9643004590285513], 
             UndirectedEdge[47, 96] -> 
             RGBColor[
              0.8641743164481107, 0.4377756035499234, 0.20687423160258545`], 
             UndirectedEdge[245, 328] -> 
             RGBColor[
              0.9894761867453177, 0.976056291595351, 0.5705762167487782], 
             UndirectedEdge[142, 143] -> 
             RGBColor[
              0.985676659746664, 0.9881330060265304, 0.8775472873972358], 
             UndirectedEdge[268, 373] -> 
             RGBColor[
              0.9895433897573163, 0.9889825560098415, 0.7530743598925249], 
             UndirectedEdge[69, 390] -> 
             RGBColor[
              0.9904280557804228, 0.9903097693245284, 0.8082954173233614], 
             UndirectedEdge[91, 112] -> 
             RGBColor[
              0.9053575161156034, 0.9258695924645131, 0.9365613499814136], 
             UndirectedEdge[16, 190] -> 
             RGBColor[
              0.910439214896922, 0.9307071777273878, 0.9664832115472006], 
             UndirectedEdge[40, 395] -> 
             RGBColor[
              0.9223618291629394, 0.9403985871299708, 0.9740220003264498], 
             UndirectedEdge[84, 246] -> 
             RGBColor[
              0.9081682722734638, 0.9272234716017973, 0.8982980097039013], 
             UndirectedEdge[196, 376] -> 
             RGBColor[
              0.9919427077951362, 0.9909361168573936, 0.7831937136458008], 
             UndirectedEdge[37, 311] -> 
             RGBColor[
              0.9056881237736321, 0.5619121891725329, 0.37938212690784334`], 
             UndirectedEdge[179, 275] -> 
             RGBColor[
              0.8920500832848177, 0.9163587068163326, 0.975633966140448], 
             UndirectedEdge[334, 340] -> 
             RGBColor[
              0.9943050631932628, 0.990227430953852, 0.6215194575417691], 
             UndirectedEdge[23, 366] -> 
             RGBColor[
              0.9524021908511194, 0.8361282329533314, 0.45896453326551756`], 
             UndirectedEdge[295, 351] -> 
             RGBColor[
              0.9217047583559563, 0.9194724729678556, 0.6824253181185704], 
             UndirectedEdge[358, 363] -> 
             RGBColor[
              0.9868647971399146, 0.9667611759795347, 0.45388363914577096`], 
             UndirectedEdge[111, 116] -> 
             RGBColor[
              0.9319599409548854, 0.9461271115405855, 0.8976496211739062], 
             UndirectedEdge[147, 371] -> 
             RGBColor[
              0.9025958638417624, 0.6174387421534393, 0.5558698371052517], 
             UndirectedEdge[33, 311] -> 
             RGBColor[
              0.9432861255910463, 0.7972574691285352, 0.41328523848064314`], 
             UndirectedEdge[137, 178] -> 
             RGBColor[
              0.8858617784757633, 0.8290383247142172, 0.6260309263864814], 
             UndirectedEdge[328, 386] -> 
             RGBColor[
              0.9328200526518702, 0.7561216759007343, 0.30880178683569587`], 
             UndirectedEdge[20, 36] -> 
             RGBColor[
              0.5753324544604198, 0.6511106668182782, 0.9640819326614267], 
             UndirectedEdge[107, 212] -> 
             RGBColor[
              0.9651153765979428, 0.9028638004803244, 0.5794187945612543], 
             UndirectedEdge[21, 27] -> 
             RGBColor[
              0.9911634782054517, 0.9889867391878328, 0.6778312121671322], 
             UndirectedEdge[138, 329] -> 
             RGBColor[
              0.9902842224575771, 0.988551116936602, 0.6871671234654664], 
             UndirectedEdge[3, 263] -> 
             RGBColor[
              0.8576338401430841, 0.8868542652496383, 0.8551403837125726], 
             UndirectedEdge[239, 269] -> 
             RGBColor[
              0.9446095502939502, 0.8146787332763896, 0.29212002918351254`], 
             UndirectedEdge[74, 86] -> 
             RGBColor[
              0.9852701784951123, 0.9619749947167637, 0.3972778542572435], 
             UndirectedEdge[91, 179] -> 
             RGBColor[
              0.8290157809797292, 0.8664986969920723, 0.9835534593326127], 
             UndirectedEdge[316, 358] -> 
             RGBColor[
              0.9941596082224566, 0.989916317479051, 0.6056875816135412], 
             UndirectedEdge[154, 267] -> 
             RGBColor[
              0.9904638554968586, 0.9885021718023124, 0.6752327634893636], 
             UndirectedEdge[25, 357] -> 
             RGBColor[
              0.9501293429836913, 0.9137583333600199, 0.6381208451617915], 
             UndirectedEdge[118, 388] -> 
             RGBColor[
              0.9507456812328907, 0.8313633391872832, 0.35096253338538347`], 
             UndirectedEdge[305, 340] -> 
             RGBColor[
              0.994349058712606, 0.9903215329210978, 0.6263080983134052], 
             UndirectedEdge[100, 213] -> 
             RGBColor[
              0.9425583581923763, 0.8066069745002941, 0.5383937216358441], 
             UndirectedEdge[51, 238] -> 
             RGBColor[
              0.6237992798565464, 0.6876077407735617, 0.837558359707095], 
             UndirectedEdge[104, 242] -> 
             RGBColor[
              0.8691351857600907, 0.49865526743801664`, 0.21251553001914078`],
              UndirectedEdge[99, 337] -> 
             RGBColor[
              0.9874747965646898, 0.9827155533053011, 0.6554935221929808], 
             UndirectedEdge[143, 302] -> 
             RGBColor[
              0.9414811458304859, 0.8017160869611641, 0.5374969029874516], 
             UndirectedEdge[14, 327] -> 
             RGBColor[
              0.963192811651813, 0.8796852141389525, 0.4217412571584673], 
             UndirectedEdge[162, 348] -> 
             RGBColor[
              0.9457520376126098, 0.8979629733178082, 0.631481176038607], 
             UndirectedEdge[130, 391] -> 
             RGBColor[
              0.9853279245921509, 0.974340878589542, 0.6393236559850731], 
             UndirectedEdge[182, 386] -> 
             RGBColor[
              0.9160206562621156, 0.6980326139057813, 0.25093861142556917`], 
             UndirectedEdge[32, 217] -> 
             RGBColor[
              0.9546249767020797, 0.9624203294095542, 0.7902998747385376], 
             UndirectedEdge[3, 285] -> 
             RGBColor[
              0.8392222196369556, 0.8256014327354858, 0.6318214181882125], 
             UndirectedEdge[212, 274] -> 
             RGBColor[
              0.966895322355838, 0.9035998537937335, 0.5499204870009695], 
             UndirectedEdge[234, 272] -> 
             RGBColor[
              0.9069682462460147, 0.9271023996996577, 0.9344767101955109], 
             UndirectedEdge[24, 104] -> 
             RGBColor[
              0.9266669835062522, 0.7352281642991119, 0.5284241786030314], 
             UndirectedEdge[317, 327] -> 
             RGBColor[0.98330795573, 0.9544851063898094, 0.4637058034216844], 
             UndirectedEdge[85, 263] -> 
             RGBColor[
              0.9940468231070391, 0.9901771346366548, 0.6299055793592361], 
             UndirectedEdge[169, 300] -> 
             RGBColor[
              0.9716685657076101, 0.916093560973963, 0.34443815702684627`], 
             UndirectedEdge[34, 162] -> 
             RGBColor[
              0.965236499969802, 0.9727716064688772, 0.9069003986171161], 
             UndirectedEdge[62, 313] -> 
             RGBColor[
              0.9930691917006166, 0.9896503291499569, 0.6372008405557977], 
             UndirectedEdge[337, 367] -> 
             RGBColor[
              0.9833604673663138, 0.9869545021820723, 0.9060492473401929], 
             UndirectedEdge[21, 240] -> 
             RGBColor[
              0.9936785780497538, 0.9888874425792503, 0.5533304158889454], 
             UndirectedEdge[258, 378] -> 
             RGBColor[
              0.9948705963917891, 0.9921468740354144, 0.7346710224664634], 
             UndirectedEdge[240, 242] -> 
             RGBColor[
              0.9334784331524962, 0.7528382618067222, 0.3999195374210567], 
             UndirectedEdge[16, 380] -> 
             RGBColor[
              0.8871762748420584, 0.9128742960733445, 0.9891008591576874], 
             UndirectedEdge[38, 222] -> 
             RGBColor[
              0.9837596918572014, 0.986515640933734, 0.8723869120346515], 
             UndirectedEdge[61, 147] -> 
             RGBColor[
              0.9055799168384926, 0.6196642439924624, 0.5508186137474557], 
             UndirectedEdge[279, 288] -> 
             RGBColor[
              0.9874872928200452, 0.988898406973554, 0.8482863747573495], 
             UndirectedEdge[192, 384] -> 
             RGBColor[
              0.9532349113698659, 0.8519074490680855, 0.5509989669305075], 
             UndirectedEdge[196, 289] -> 
             RGBColor[
              0.9928523435901293, 0.989510497319346, 0.6371485041267311], 
             UndirectedEdge[9, 384] -> 
             RGBColor[
              0.9052155506959154, 0.8155971824307389, 0.6214113920717584], 
             UndirectedEdge[114, 187] -> 
             RGBColor[
              0.9905416870169013, 0.9903567587610018, 0.8064122536667004], 
             UndirectedEdge[90, 274] -> 
             RGBColor[
              0.9470417116392861, 0.9583636874077408, 0.9082409860191416], 
             UndirectedEdge[270, 324] -> 
             RGBColor[
              0.8863873826458508, 0.9116629803528172, 0.9665805809194418], 
             UndirectedEdge[42, 45] -> 
             RGBColor[
              0.936855470110156, 0.7703700003231628, 0.32281718237773976`], 
             UndirectedEdge[316, 363] -> 
             RGBColor[
              0.9875608210552982, 0.9682499007557279, 0.5296415469735913], 
             UndirectedEdge[44, 250] -> 
             RGBColor[
              0.9867885274008804, 0.9742177790346118, 0.6100920246368913], 
             UndirectedEdge[213, 352] -> 
             RGBColor[
              0.9452607015003699, 0.8064821361023462, 0.4033048556827292], 
             UndirectedEdge[80, 378] -> 
             RGBColor[
              0.9942237753624042, 0.9904593064290845, 0.6421649335922897], 
             UndirectedEdge[238, 272] -> 
             RGBColor[
              0.5405293521482848, 0.6244788921635429, 0.9605928193215831], 
             UndirectedEdge[126, 196] -> 
             RGBColor[
              0.9888777879488825, 0.9896686937361203, 0.833987367256527], 
             UndirectedEdge[112, 240] -> 
             RGBColor[
              0.989731675977829, 0.9888824433506921, 0.7370171498371507], 
             UndirectedEdge[52, 89] -> 
             RGBColor[
              0.9524431559369166, 0.9640527640817134, 0.9653855115740881], 
             UndirectedEdge[99, 177] -> 
             RGBColor[
              0.9685562034773312, 0.9030318208843031, 0.3456954247789996], 
             UndirectedEdge[41, 206] -> 
             RGBColor[
              0.9665307241345642, 0.9431120041956034, 0.6467033903103805], 
             UndirectedEdge[1, 119] -> 
             RGBColor[
              0.9882898057859402, 0.972799304812101, 0.5711164503460626], 
             UndirectedEdge[2, 109] -> 
             RGBColor[
              0.9756416315471695, 0.97816096817491, 0.7364332043957813], 
             UndirectedEdge[8, 100] -> 
             RGBColor[
              0.9447076887941177, 0.9566830201551679, 0.9158527897918335], 
             UndirectedEdge[203, 322] -> 
             RGBColor[
              0.9678517270597764, 0.9032184679784871, 0.3296104596295107], 
             UndirectedEdge[98, 193] -> 
             RGBColor[
              0.9800881574169313, 0.9444948208236486, 0.37714668091107856`], 
             UndirectedEdge[141, 285] -> 
             RGBColor[
              0.9025194721640397, 0.6165426029647112, 0.24182778184915713`], 
             UndirectedEdge[29, 231] -> 
             RGBColor[
              0.9722110466415717, 0.9290625654581344, 0.581233890154846], 
             UndirectedEdge[225, 398] -> 
             RGBColor[
              0.9726488090887332, 0.9194001520705823, 0.3482462174590796], 
             UndirectedEdge[149, 359] -> 
             RGBColor[
              0.9038777163705913, 0.9246402766717611, 0.9342766654994881], 
             UndirectedEdge[87, 235] -> 
             RGBColor[
              0.9507920478169846, 0.84356901613829, 0.5556233795844716], 
             UndirectedEdge[162, 312] -> 
             RGBColor[
              0.9310173022960361, 0.9476867134288155, 0.9882473129172857], 
             UndirectedEdge[392, 395] -> 
             RGBColor[
              0.5933240478878294, 0.6631822194247939, 0.9476271117209683], 
             UndirectedEdge[212, 268] -> 
             RGBColor[
              0.9646662622036815, 0.9026780801365839, 0.5868617823449589], 
             UndirectedEdge[50, 271] -> 
             RGBColor[
              0.9439841305965606, 0.803671491787553, 0.3263307309787145], 
             UndirectedEdge[200, 207] -> 
             RGBColor[
              0.7398774701305575, 0.7942745369566024, 0.9212236978336392], 
             UndirectedEdge[360, 370] -> 
             RGBColor[
              0.9847537945214707, 0.9587783975432216, 0.5189700742744167], 
             UndirectedEdge[134, 246] -> 
             RGBColor[
              0.9743694378231511, 0.979419584556301, 0.8841254803369415], 
             UndirectedEdge[88, 191] -> 
             RGBColor[
              0.9760568592657313, 0.9730797547213101, 0.6791123209253369], 
             UndirectedEdge[277, 278] -> 
             RGBColor[
              0.9768353749670431, 0.9403625459123583, 0.5694842477653235], 
             UndirectedEdge[233, 242] -> 
             RGBColor[
              0.9334136103802468, 0.7539508109538469, 0.4838129015015376], 
             UndirectedEdge[66, 123] -> 
             RGBColor[
              0.9518368497166352, 0.8352911638170681, 0.37540947489246057`], 
             UndirectedEdge[315, 316] -> 
             RGBColor[
              0.975013878880624, 0.925692244447659, 0.4821170666768738], 
             UndirectedEdge[127, 216] -> 
             RGBColor[
              0.9841669555038995, 0.9571419374562604, 0.4875167827000039], 
             UndirectedEdge[29, 326] -> 
             RGBColor[
              0.9726740051756707, 0.929254010709476, 0.5735614691465449], 
             UndirectedEdge[76, 145] -> 
             RGBColor[
              0.98394896101884, 0.9583128142052405, 0.5553327233739231], 
             UndirectedEdge[21, 104] -> 
             RGBColor[
              0.9293353306573483, 0.7347044482105447, 0.3659264084870295], 
             UndirectedEdge[27, 112] -> 
             RGBColor[
              0.9872165761335269, 0.9889817399592745, 0.8615179461153375], 
             UndirectedEdge[190, 221] -> 
             RGBColor[
              0.9661835548999816, 0.9743003311305289, 0.9421266001996185], 
             UndirectedEdge[310, 324] -> 
             RGBColor[
              0.9701170130113432, 0.9563072271814007, 0.6629659275264992], 
             UndirectedEdge[11, 312] -> 
             RGBColor[
              0.9474907006755102, 0.9322513012320399, 0.6734361951391961], 
             UndirectedEdge[177, 225] -> 
             RGBColor[
              0.9647822013045306, 0.890301225377597, 0.3310341389981786], 
             UndirectedEdge[253, 316] -> 
             RGBColor[
              0.9760576347683187, 0.9795249651624817, 0.8193389771200204], 
             UndirectedEdge[17, 323] -> 
             RGBColor[
              0.991212791475807, 0.9883655031370575, 0.6303743555972535], 
             UndirectedEdge[315, 397] -> 
             RGBColor[
              0.9397724195083026, 0.9012565865718347, 0.637718666292367], 
             UndirectedEdge[43, 296] -> 
             RGBColor[
              0.931744346738589, 0.8398513109022367, 0.6182117940232799], 
             UndirectedEdge[50, 287] -> 
             RGBColor[
              0.9899080887607807, 0.9842041028681859, 0.6185013560975112], 
             UndirectedEdge[253, 369] -> 
             RGBColor[
              0.9760874069146479, 0.9795886447730542, 0.8225794915155722], 
             UndirectedEdge[187, 220] -> 
             RGBColor[
              0.96908530549688, 0.9077303506582264, 0.5294074915320076], 
             UndirectedEdge[211, 340] -> 
             RGBColor[
              0.9909184171964599, 0.9891676916587886, 0.7024121190190626], 
             UndirectedEdge[213, 227] -> 
             RGBColor[
              0.8644823438125397, 0.7464165437056834, 0.6096822286725153], 
             UndirectedEdge[17, 389] -> 
             RGBColor[
              0.9920460909963434, 0.9901478465519797, 0.7210738658791214], 
             UndirectedEdge[117, 376] -> 
             RGBColor[
              0.9586071085091386, 0.8671942828895927, 0.5259016707967232], 
             UndirectedEdge[186, 330] -> 
             RGBColor[
              0.9537019763499597, 0.928713689545827, 0.6581645465154551], 
             UndirectedEdge[24, 337] -> 
             RGBColor[
              0.986596107341343, 0.9887251601683859, 0.8718007197235852], 
             UndirectedEdge[73, 99] -> 
             RGBColor[
              0.9914216455119973, 0.9824020986626374, 0.44866103085967013`], 
             UndirectedEdge[114, 155] -> 
             RGBColor[
              0.9147287329369135, 0.9326432873542758, 0.9071169978179301], 
             UndirectedEdge[123, 232] -> 
             RGBColor[
              0.9502487077371341, 0.8364085367982056, 0.5306882025815225], 
             UndirectedEdge[53, 289] -> 
             RGBColor[
              0.9809609347387575, 0.9470127895142262, 0.4167709278682779], 
             UndirectedEdge[126, 376] -> 
             RGBColor[
              0.9883092432251739, 0.989433585881934, 0.8434096246749578], 
             UndirectedEdge[207, 254] -> 
             RGBColor[
              0.9479775026880287, 0.9598442410052412, 0.9402195236818833], 
             UndirectedEdge[291, 304] -> 
             RGBColor[
              0.9936082088390843, 0.9890820297881238, 0.5803208820500986], 
             UndirectedEdge[333, 368] -> 
             RGBColor[
              0.9034271006096042, 0.6652050919880248, 0.5724660155248436], 
             UndirectedEdge[26, 171] -> 
             RGBColor[
              0.9727608305597241, 0.9766581586980979, 0.7925421652682413], 
             UndirectedEdge[81, 384] -> 
             RGBColor[
              0.9564919524780466, 0.8525816082096107, 0.44812237433661495`], 
             UndirectedEdge[120, 233] -> 
             RGBColor[
              0.9934880498820949, 0.989731120596359, 0.6235415234428707], 
             UndirectedEdge[224, 290] -> 
             RGBColor[
              0.9265743637010704, 0.7340273886720334, 0.5250562848287408], 
             UndirectedEdge[393, 396] -> 
             RGBColor[
              0.9682191359437498, 0.9758184641400132, 0.9386808924570836], 
             UndirectedEdge[2, 365] -> 
             RGBColor[
              0.9341722746513901, 0.9497740853398784, 0.9736982036649704], 
             UndirectedEdge[210, 387] -> 
             RGBColor[
              0.9381615364347806, 0.7860720684236838, 0.2983771247934442], 
             UndirectedEdge[23, 307] -> 
             RGBColor[
              0.9358303231049184, 0.8259723383469597, 0.598163023216467], 
             UndirectedEdge[120, 244] -> 
             RGBColor[
              0.928772988218661, 0.7324529102461768, 0.35187981130860957`], 
             UndirectedEdge[42, 248] -> 
             RGBColor[
              0.990128730553773, 0.9866577466896438, 0.6311735904886187], 
             UndirectedEdge[49, 393] -> 
             RGBColor[
              0.9760471448888481, 0.9688190824462821, 0.6700995436386312], 
             UndirectedEdge[375, 377] -> 
             RGBColor[
              0.9116112527251257, 0.6782294936583699, 0.24727062315752513`], 
             UndirectedEdge[269, 350] -> 
             RGBColor[
              0.9645569418641387, 0.8921043838612479, 0.3168108413124341], 
             UndirectedEdge[77, 207] -> 
             RGBColor[
              0.9742495474168376, 0.9800901743423733, 0.9183629489191667], 
             UndirectedEdge[200, 368] -> 
             RGBColor[
              0.7271327117362356, 0.7849952778141198, 0.9529072793270634], 
             UndirectedEdge[384, 389] -> 
             RGBColor[
              0.9564001979182739, 0.8523853544840658, 0.43813545674885823`], 
             UndirectedEdge[1, 361] -> 
             RGBColor[
              0.9722540396397961, 0.9624180912931366, 0.6689373902907625], 
             UndirectedEdge[150, 380] -> 
             RGBColor[
              0.9544883668674444, 0.9637934515031954, 0.8868922862336523], 
             UndirectedEdge[150, 381] -> 
             RGBColor[
              0.9910515943691958, 0.9905676185551967, 0.7979617692412557], 
             UndirectedEdge[232, 279] -> 
             RGBColor[
              0.9910036174232693, 0.9905477788551049, 0.7987568713956112], 
             UndirectedEdge[132, 341] -> 
             RGBColor[
              0.9692832452283764, 0.9028032426363317, 0.4875035650486724], 
             UndirectedEdge[1, 14] -> 
             RGBColor[
              0.9576797784073078, 0.8619593086718881, 0.3262733499803092], 
             UndirectedEdge[171, 342] -> 
             RGBColor[
              0.9671813048753513, 0.9724969575783275, 0.8019868468785236], 
             UndirectedEdge[140, 325] -> 
             RGBColor[
              0.8927886453248195, 0.9169095251764814, 0.9743837732545556], 
             UndirectedEdge[89, 306] -> 
             RGBColor[
              0.88496537990591, 0.9106024530376852, 0.9689876606404485], 
             UndirectedEdge[130, 147] -> 
             RGBColor[
              0.9089822796360534, 0.6082479415641527, 0.2873590759839607], 
             UndirectedEdge[4, 183] -> 
             RGBColor[
              0.964479538450369, 0.9091813572763315, 0.5976479321930429], 
             UndirectedEdge[80, 151] -> 
             RGBColor[
              0.9937091991380473, 0.9889529379908433, 0.556663332378244], 
             UndirectedEdge[236, 286] -> 
             RGBColor[
              0.9916656987051105, 0.9889738201100755, 0.6534728158631024], 
             UndirectedEdge[108, 180] -> 
             RGBColor[
              0.977480056355472, 0.9817917243746839, 0.8811996797074519], 
             UndirectedEdge[9, 320] -> 
             RGBColor[
              0.915794552275585, 0.9355921140217858, 0.9883072787897768], 
             UndirectedEdge[35, 97] -> 
             RGBColor[
              0.9800479882612669, 0.9443593208294265, 0.3769906313266313], 
             UndirectedEdge[154, 236] -> 
             RGBColor[
              0.9931548381632138, 0.9877672159201667, 0.49632456138698566`], 
             UndirectedEdge[60, 259] -> 
             RGBColor[
              0.993467459453466, 0.9915666408524433, 0.7579246327364726], 
             UndirectedEdge[179, 399] -> 
             RGBColor[
              0.9073679949660559, 0.9277827802674216, 0.9497047372153224], 
             UndirectedEdge[314, 352] -> 
             RGBColor[
              0.9781215393213083, 0.9370346098717566, 0.43977326828837005`], 
             UndirectedEdge[85, 88] -> 
             RGBColor[
              0.9911191820199803, 0.9811554005142833, 0.46673894997380155`], 
             UndirectedEdge[70, 267] -> 
             RGBColor[
              0.946388519223275, 0.8251720749312476, 0.5474881285928119], 
             UndirectedEdge[31, 192] -> 
             RGBColor[
              0.9862242282041951, 0.9885713785883172, 0.8779637194184836], 
             UndirectedEdge[221, 255] -> 
             RGBColor[
              0.9819650839182916, 0.9840601966030857, 0.8196117432419178], 
             UndirectedEdge[11, 211] -> 
             RGBColor[
              0.9811956590696097, 0.9571235431146128, 0.6006115565116956], 
             UndirectedEdge[211, 312] -> 
             RGBColor[
              0.9544087905851367, 0.9644805021046929, 0.9194741088805365], 
             UndirectedEdge[123, 280] -> 
             RGBColor[
              0.8472116651505095, 0.7569152819517665, 0.61295284594218], 
             UndirectedEdge[178, 278] -> 
             RGBColor[
              0.9631073630049207, 0.8883624590639354, 0.5457989994434875], 
             UndirectedEdge[83, 364] -> 
             RGBColor[
              0.9591976223386082, 0.9668485307337555, 0.8541354014336902], 
             UndirectedEdge[10, 313] -> 
             RGBColor[
              0.9742909456181749, 0.9770900670278011, 0.7336762069636904], 
             UndirectedEdge[32, 242] -> 
             RGBColor[
              0.8941204362567583, 0.7257200773388284, 0.6037574193754662], 
             UndirectedEdge[44, 369] -> 
             RGBColor[
              0.9921131101266443, 0.9906901288252692, 0.7573668572140446], 
             UndirectedEdge[110, 375] -> 
             RGBColor[
              0.9615182169819194, 0.880208519489361, 0.3135759266351844], 
             UndirectedEdge[275, 290] -> 
             RGBColor[
              0.9079965303223585, 0.720877360559358, 0.5880880202665425], 
             UndirectedEdge[362, 369] -> 
             RGBColor[
              0.9793505315015254, 0.9820222777470713, 0.8170558727491848], 
             UndirectedEdge[266, 338] -> 
             RGBColor[
              0.9592135942411806, 0.8837023510715623, 0.5898409122171955], 
             UndirectedEdge[350, 395] -> 
             RGBColor[
              0.9589458903067312, 0.9244916594450413, 0.6320232914284545], 
             UndirectedEdge[141, 172] -> 
             RGBColor[
              0.9201125087914457, 0.6755425142186446, 0.3395549823588494], 
             UndirectedEdge[123, 275] -> 
             RGBColor[
              0.9308648867570287, 0.8229252120994175, 0.6070772384034646], 
             UndirectedEdge[46, 315] -> 
             RGBColor[
              0.9672527863705751, 0.9009642262050768, 0.32850170891309877`], 
             UndirectedEdge[185, 205] -> 
             RGBColor[
              0.93744255290402, 0.7705306928023672, 0.41706472711186915`], 
             UndirectedEdge[3, 86] -> 
             RGBColor[
              0.852158792953065, 0.8692395321825845, 0.6820775626544144], 
             UndirectedEdge[316, 397] -> 
             RGBColor[
              0.959614172765519, 0.9669693843794198, 0.8370470890568547], 
             UndirectedEdge[11, 214] -> 
             RGBColor[
              0.9117247402604772, 0.9037324952382253, 0.6700248059061604], 
             UndirectedEdge[3, 34] -> 
             RGBColor[
              0.8548549362455413, 0.8857051170734318, 0.9011940128676118], 
             UndirectedEdge[5, 100] -> 
             RGBColor[
              0.9868221237162376, 0.9888186237477606, 0.8680550434799554], 
             UndirectedEdge[25, 245] -> 
             RGBColor[
              0.9680226329271814, 0.974010045316628, 0.8645917124054733], 
             UndirectedEdge[183, 325] -> 
             RGBColor[
              0.9066560694334821, 0.9272518273708991, 0.9509098414420531], 
             UndirectedEdge[149, 266] -> 
             RGBColor[
              0.9604169745049804, 0.8843394508986824, 0.5761435906142128], 
             UndirectedEdge[73, 78] -> 
             RGBColor[
              0.9643133322752478, 0.9694896168766152, 0.7380509891778761], 
             UndirectedEdge[40, 167] -> 
             RGBColor[
              0.9353749158674562, 0.93298011417788, 0.6875650589999021], 
             UndirectedEdge[5, 175] -> 
             RGBColor[
              0.986135829087137, 0.9885348232816602, 0.8794287215577167], 
             UndirectedEdge[279, 309] -> 
             RGBColor[
              0.9526696746949164, 0.8426176685208927, 0.5160514249951917], 
             UndirectedEdge[66, 257] -> 
             RGBColor[
              0.990964712496945, 0.9807380879900984, 0.4573167608543862], 
             UndirectedEdge[238, 309] -> 
             RGBColor[
              0.583137088442969, 0.5387148397747472, 0.5934380193352948], 
             UndirectedEdge[40, 355] -> 
             RGBColor[
              0.9262566183062931, 0.9433033144959522, 0.9674291382304497], 
             UndirectedEdge[31, 271] -> 
             RGBColor[
              0.9411430578547334, 0.8083872819277459, 0.5718259191441928], 
             UndirectedEdge[271, 391] -> 
             RGBColor[
              0.9418621497672015, 0.8086846449133707, 0.5599087052043796], 
             UndirectedEdge[264, 348] -> 
             RGBColor[
              0.9718567432003009, 0.9158787470731569, 0.5177429397829272], 
             UndirectedEdge[146, 302] -> 
             RGBColor[
              0.9404677519415696, 0.8012970225450622, 0.5542914623061113], 
             UndirectedEdge[86, 91] -> 
             RGBColor[
              0.9044814578058186, 0.9101566594880593, 0.687281381376073], 
             UndirectedEdge[232, 257] -> 
             RGBColor[
              0.989376570517444, 0.9818554609712358, 0.6125954885434481], 
             UndirectedEdge[201, 385] -> 
             RGBColor[
              0.9878613234821667, 0.9873319748390921, 0.7203172139544602], 
             UndirectedEdge[204, 297] -> 
             RGBColor[
              0.9689395010696473, 0.9075794495932087, 0.5313804695388762], 
             UndirectedEdge[241, 323] -> 
             RGBColor[
              0.9935013456185827, 0.989311879088254, 0.5924470908631908], 
             UndirectedEdge[269, 395] -> 
             RGBColor[
              0.961929347675911, 0.934555561700388, 0.6436134599290688], 
             UndirectedEdge[52, 342] -> 
             RGBColor[
              0.943519339967217, 0.957397396742919, 0.9804912043068281], 
             UndirectedEdge[201, 245] -> 
             RGBColor[
              0.993810264210487, 0.9901068178984045, 0.6358254006311832], 
             UndirectedEdge[131, 330] -> 
             RGBColor[
              0.8961279585860715, 0.9199105060492321, 0.9864314615270955], 
             UndirectedEdge[159, 349] -> 
             RGBColor[
              0.9907000678086237, 0.9904222532885797, 0.8037874740715082], 
             UndirectedEdge[15, 33] -> 
             RGBColor[
              0.9438086539676922, 0.798375104490458, 0.4701592276072098], 
             UndirectedEdge[16, 212] -> 
             RGBColor[
              0.9009066650369024, 0.8532279726257204, 0.6301963218998914], 
             UndirectedEdge[246, 269] -> 
             RGBColor[
              0.9788329337555263, 0.9461764638663085, 0.5708555425636592], 
             UndirectedEdge[150, 294] -> 
             RGBColor[
              0.9934696747091437, 0.9912511031422522, 0.7348850714054278], 
             UndirectedEdge[77, 200] -> 
             RGBColor[
              0.7285761287493889, 0.7860717758591511, 0.9504639508272448], 
             UndirectedEdge[21, 285] -> 
             RGBColor[
              0.9756363280192171, 0.9289267092784621, 0.4067091086722365], 
             UndirectedEdge[275, 280] -> 
             RGBColor[
              0.8676283576616788, 0.8971765319564393, 0.9732273654252287], 
             UndirectedEdge[171, 353] -> 
             RGBColor[
              0.9842736890626781, 0.9575231839835523, 0.48612794758509376`], 
             UndirectedEdge[197, 252] -> 
             RGBColor[
              0.9266190129411715, 0.9419447031702665, 0.9004535232899232], 
             UndirectedEdge[15, 361] -> 
             RGBColor[
              0.9783612038149538, 0.9814147827450153, 0.8290727827193627], 
             UndirectedEdge[348, 366] -> 
             RGBColor[
              0.9724685708229692, 0.915684742816984, 0.47511041360934314`], 
             UndirectedEdge[235, 298] -> 
             RGBColor[
              0.9911775082622454, 0.9904845467117731, 0.7860517643314409], 
             UndirectedEdge[62, 298] -> 
             RGBColor[
              0.9940060772921291, 0.9916542326965383, 0.7391750554042702], 
             UndirectedEdge[110, 308] -> 
             RGBColor[
              0.9828348331465258, 0.9534337286190446, 0.41556101652954597`], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.9074564721923375, 0.824481689421231, 0.6232144901089677], 
             UndirectedEdge[204, 290] -> 
             RGBColor[
              0.9282059604157593, 0.7347020958436803, 0.4980165048294011], 
             UndirectedEdge[35, 93] -> 
             RGBColor[
              0.977635562098812, 0.9468620733885575, 0.5988604136177308], 
             UndirectedEdge[162, 211] -> 
             RGBColor[
              0.9647222606901356, 0.9725589553113884, 0.9154226742897853], 
             UndirectedEdge[66, 275] -> 
             RGBColor[
              0.9722535422278045, 0.9755524138217411, 0.7356839943755094], 
             UndirectedEdge[36, 277] -> 
             RGBColor[
              0.9353829420283175, 0.9095788990616331, 0.6531301574599362], 
             UndirectedEdge[174, 246] -> 
             RGBColor[
              0.9874231131269015, 0.9890671483137936, 0.8580950936345152], 
             UndirectedEdge[218, 329] -> 
             RGBColor[
              0.9763446952298677, 0.9313677267819654, 0.40507936391815974`], 
             UndirectedEdge[186, 188] -> 
             RGBColor[
              0.9798821252851003, 0.9469416105821974, 0.5557575121830104], 
             UndirectedEdge[230, 245] -> 
             RGBColor[
              0.9943155776724598, 0.9911876322985363, 0.6908256525337215], 
             UndirectedEdge[57, 368] -> 
             RGBColor[
              0.975284767204261, 0.9800386563124408, 0.8797288511270079], 
             UndirectedEdge[293, 316] -> 
             RGBColor[
              0.9902032604679232, 0.9898489888475344, 0.7852840926834612], 
             UndirectedEdge[8, 308] -> 
             RGBColor[
              0.9470048977055467, 0.9556916402483393, 0.7366675449723363], 
             UndirectedEdge[37, 361] -> 
             RGBColor[
              0.8894695516646758, 0.5525119582105595, 0.5570346666849528], 
             UndirectedEdge[19, 331] -> 
             RGBColor[
              0.9776288915394096, 0.9641869973722582, 0.6550848156327984], 
             UndirectedEdge[98, 276] -> 
             RGBColor[
              0.9698886583441972, 0.9100895154950484, 0.3375235530272891], 
             UndirectedEdge[326, 336] -> 
             RGBColor[
              0.945346560529149, 0.95736813594878, 0.9235430882085716], 
             UndirectedEdge[4, 13] -> 
             RGBColor[
              0.971803129592063, 0.9127024286632335, 0.49493470357217006`], 
             UndirectedEdge[137, 300] -> 
             RGBColor[
              0.9012919829854651, 0.886780306719442, 0.6563288713235726], 
             UndirectedEdge[57, 163] -> 
             RGBColor[
              0.991812257529163, 0.9908821723199948, 0.785355612147442], 
             UndirectedEdge[28, 304] -> 
             RGBColor[
              0.9463187336303036, 0.8105275568697445, 0.48605157732344895`], 
             UndirectedEdge[83, 328] -> 
             RGBColor[
              0.9539909750638565, 0.9509316658383463, 0.6939123786549192], 
             UndirectedEdge[206, 321] -> 
             RGBColor[
              0.9494071250971493, 0.8797998340450892, 0.609087236787918], 
             UndirectedEdge[295, 373] -> 
             RGBColor[
              0.9872437780670229, 0.9676050740223106, 0.49230210910756766`], 
             UndirectedEdge[29, 235] -> 
             RGBColor[
              0.9725279417581625, 0.9291936097326776, 0.575982117974664], 
             UndirectedEdge[234, 392] -> 
             RGBColor[
              0.6080502144834252, 0.6739027026769442, 0.9109546701867514], 
             UndirectedEdge[42, 275] -> 
             RGBColor[
              0.9715102122484653, 0.9734908943142662, 0.6948795804493295], 
             UndirectedEdge[107, 324] -> 
             RGBColor[
              0.9733009251318538, 0.9793384141984923, 0.9179858060994539], 
             UndirectedEdge[75, 329] -> 
             RGBColor[
              0.9940123924311277, 0.989601437787198, 0.5896640512379356], 
             UndirectedEdge[267, 383] -> 
             RGBColor[
              0.9277500814105539, 0.7407673756578559, 0.5319475582635713], 
             UndirectedEdge[253, 362] -> 
             RGBColor[
              0.9605227619856745, 0.9700785210437364, 0.9517088460322916], 
             UndirectedEdge[137, 252] -> 
             RGBColor[
              0.8490848665758257, 0.8825012410855835, 0.9854676666326525], 
             UndirectedEdge[131, 203] -> 
             RGBColor[
              0.9161055479534098, 0.9140739527153021, 0.6805174273306378], 
             UndirectedEdge[52, 199] -> 
             RGBColor[
              0.9495338428144351, 0.9039194258742302, 0.6275126263928303], 
             UndirectedEdge[41, 386] -> 
             RGBColor[
              0.9261620548305907, 0.7336626858773281, 0.2829367225574134], 
             UndirectedEdge[59, 122] -> 
             RGBColor[
              0.9649070831152835, 0.9710448903169969, 0.8258044815124996], 
             UndirectedEdge[32, 172] -> 
             RGBColor[
              0.9541540840836028, 0.9614131377131792, 0.7390461192297099], 
             UndirectedEdge[55, 156] -> 
             RGBColor[
              0.9403720072112464, 0.9265059756723394, 0.6726555929272877], 
             UndirectedEdge[97, 214] -> 
             RGBColor[
              0.9204648019194273, 0.9332147754779312, 0.7039782950290285], 
             UndirectedEdge[133, 155] -> 
             RGBColor[
              0.896220641263346, 0.9196624168134773, 0.9752766408361534], 
             UndirectedEdge[186, 273] -> 
             RGBColor[
              0.9773654240626011, 0.9353104018912994, 0.36656937597455624`], 
             UndirectedEdge[74, 179] -> 
             RGBColor[
              0.9098045016690228, 0.9183170322207768, 0.6935499322137832], 
             UndirectedEdge[10, 62] -> 
             RGBColor[
              0.9741085592196576, 0.9787662633165664, 0.8640229411172861], 
             UndirectedEdge[273, 322] -> 
             RGBColor[
              0.9715375854050795, 0.9156517336578898, 0.34392932328506953`], 
             UndirectedEdge[18, 148] -> 
             RGBColor[
              0.9677455645242456, 0.9119093997217411, 0.5747713305067925], 
             UndirectedEdge[78, 172] -> 
             RGBColor[
              0.9643313934821243, 0.9695282479718559, 0.7400168400855323], 
             UndirectedEdge[84, 269] -> 
             RGBColor[
              0.896875737751256, 0.8832152938520834, 0.6558434769532904], 
             UndirectedEdge[103, 254] -> 
             RGBColor[
              0.9385319831809146, 0.9530255488228302, 0.9663183543185792], 
             UndirectedEdge[46, 343] -> 
             RGBColor[
              0.9728852050332356, 0.9201975710997963, 0.34916457106384313`], 
             UndirectedEdge[1, 317] -> 
             RGBColor[
              0.9777949224854947, 0.936759200922745, 0.3682378962435263], 
             UndirectedEdge[27, 399] -> 
             RGBColor[
              0.9854242486622709, 0.9878626732256804, 0.8742986182874763], 
             UndirectedEdge[247, 253] -> 
             RGBColor[
              0.9750224360769304, 0.9794647057384991, 0.8632316631643], 
             UndirectedEdge[27, 357] -> 
             RGBColor[
              0.9736697738575935, 0.9305274123528391, 0.5630145298707316], 
             UndirectedEdge[41, 55] -> 
             RGBColor[
              0.9389807104446195, 0.9218128049864913, 0.667250667713291], 
             UndirectedEdge[183, 272] -> 
             RGBColor[
              0.9043297073739305, 0.9253968494120284, 0.9506879509520452], 
             UndirectedEdge[131, 238] -> 
             RGBColor[
              0.5527545320093337, 0.6342269187410763, 0.9617588678902769], 
             UndirectedEdge[13, 131] -> 
             RGBColor[
              0.9238784783766734, 0.9386659473764636, 0.8491407708998661], 
             UndirectedEdge[55, 328] -> 
             RGBColor[
              0.945638708265899, 0.9442717950098976, 0.6931157319915734], 
             UndirectedEdge[40, 392] -> 
             RGBColor[
              0.5593675809322654, 0.6366379692705835, 0.9628232020023291], 
             UndirectedEdge[39, 347] -> 
             RGBColor[
              0.9012400334085268, 0.5797039367738678, 0.25892942625187754`], 
             UndirectedEdge[195, 362] -> 
             RGBColor[
              0.9793339920188713, 0.9823318920212917, 0.8403328235911419], 
             UndirectedEdge[46, 250] -> 
             RGBColor[
              0.9817997290483568, 0.950268353832577, 0.38379581349598507`], 
             UndirectedEdge[22, 47] -> 
             RGBColor[
              0.9141263084644147, 0.6262854951505191, 0.3969194967058074], 
             UndirectedEdge[79, 100] -> 
             RGBColor[
              0.9895974582107967, 0.989966295884104, 0.8220605685696734], 
             UndirectedEdge[45, 148] -> 
             RGBColor[
              0.9342839860003649, 0.7728348695209943, 0.5475157493337162], 
             UndirectedEdge[65, 68] -> 
             RGBColor[
              0.9921525448521482, 0.9910228898730344, 0.7797161705702147], 
             UndirectedEdge[86, 162] -> 
             RGBColor[
              0.9625403566773256, 0.9563060215780299, 0.6877839484039188], 
             UndirectedEdge[3, 264] -> 
             RGBColor[
              0.8570539142644653, 0.8866144509954141, 0.8647512563213504], 
             UndirectedEdge[55, 386] -> 
             RGBColor[
              0.8937014203354334, 0.7401483988937319, 0.6066319430198491], 
             UndirectedEdge[315, 362] -> 
             RGBColor[
              0.9594790060979799, 0.9162458003289136, 0.6144869355891451], 
             UndirectedEdge[92, 182] -> 
             RGBColor[
              0.9683560033326484, 0.9161804731272611, 0.5843196641467212], 
             UndirectedEdge[202, 341] -> 
             RGBColor[
              0.968686944949011, 0.9015278166339755, 0.4225999595785007], 
             UndirectedEdge[86, 125] -> 
             RGBColor[
              0.9659636762240237, 0.8945473062447697, 0.33426627560923594`], 
             UndirectedEdge[155, 353] -> 
             RGBColor[
              0.9072963397045992, 0.900201408840699, 0.6696024211078608], 
             UndirectedEdge[119, 235] -> 
             RGBColor[
              0.9904606514319858, 0.9903232484641197, 0.8077552230221202], 
             UndirectedEdge[139, 204] -> 
             RGBColor[
              0.5853137197274998, 0.6481149663363674, 0.8603548635061153], 
             UndirectedEdge[167, 174] -> 
             RGBColor[
              0.983532613751803, 0.9700277731957823, 0.6443960696733768], 
             UndirectedEdge[218, 349] -> 
             RGBColor[
              0.972986448861223, 0.9316781792181177, 0.5842461813557689], 
             UndirectedEdge[362, 397] -> 
             RGBColor[
              0.9440792999828749, 0.9575229402606745, 0.969416957969126], 
             UndirectedEdge[70, 108] -> 
             RGBColor[
              0.947414924500351, 0.8255965198907309, 0.5304779368999551], 
             UndirectedEdge[71, 157] -> 
             RGBColor[
              0.9917724532665916, 0.9833523750770746, 0.46984333735395145`], 
             UndirectedEdge[186, 238] -> 
             RGBColor[
              0.6103285497732218, 0.643030102237671, 0.6334919528786365], 
             UndirectedEdge[51, 246] -> 
             RGBColor[
              0.9924155934382958, 0.9911316672234467, 0.7753567747498302], 
             UndirectedEdge[109, 305] -> 
             RGBColor[
              0.9941589311905694, 0.9899148693763027, 0.6056138908707742], 
             UndirectedEdge[125, 248] -> 
             RGBColor[
              0.9683480136866223, 0.9108839514119181, 0.5585501553511303], 
             UndirectedEdge[106, 390] -> 
             RGBColor[
              0.9563837155379267, 0.8611673888748206, 0.5377560995736255], 
             UndirectedEdge[1, 231] -> 
             RGBColor[
              0.9847419264796953, 0.9713321655426295, 0.6299139920678589], 
             UndirectedEdge[104, 399] -> 
             RGBColor[
              0.9235961011141675, 0.7335803822483924, 0.5623938146073737], 
             UndirectedEdge[244, 366] -> 
             RGBColor[
              0.9295826821664294, 0.7341847637278376, 0.44001000067138174`], 
             UndirectedEdge[64, 289] -> 
             RGBColor[
              0.9928364846201141, 0.9895039392276879, 0.6374113283015819], 
             UndirectedEdge[160, 233] -> 
             RGBColor[
              0.9942486190754682, 0.9913579011956433, 0.7063247864525797], 
             UndirectedEdge[100, 302] -> 
             RGBColor[
              0.9414812626656561, 0.8017161352755096, 0.5374949667263215], 
             UndirectedEdge[177, 337] -> 
             RGBColor[
              0.9662144541804834, 0.9084364148080664, 0.5862493140056118], 
             UndirectedEdge[124, 219] -> 
             RGBColor[
              0.9336776250253664, 0.9456546127536343, 0.7832056924603276], 
             UndirectedEdge[2, 181] -> 
             RGBColor[
              0.9340658429337421, 0.9496892195772377, 0.9736880521127284], 
             UndirectedEdge[185, 198] -> 
             RGBColor[
              0.9297227434202466, 0.7455481100223879, 0.2970975160016526], 
             UndirectedEdge[11, 35] -> 
             RGBColor[
              0.971307926602317, 0.9148770405897206, 0.34303714220376313`], 
             UndirectedEdge[5, 56] -> 
             RGBColor[
              0.987159771443948, 0.9889582497603198, 0.8624593468274853], 
             UndirectedEdge[69, 107] -> 
             RGBColor[
              0.9884348133226528, 0.9894855123442459, 0.8413286031947383], 
             UndirectedEdge[51, 350] -> 
             RGBColor[
              0.9781396015469082, 0.9370595872183862, 0.5213120734986052], 
             UndirectedEdge[226, 392] -> 
             RGBColor[
              0.5397508555090633, 0.6209961248999487, 0.9609521412194065], 
             UndirectedEdge[81, 292] -> 
             RGBColor[
              0.9847511409198939, 0.9589903083610594, 0.5001792519536848], 
             UndirectedEdge[51, 272] -> 
             RGBColor[
              0.9114357908905959, 0.9289498442208524, 0.8604379337998784], 
             UndirectedEdge[10, 261] -> 
             RGBColor[
              0.9584752082332837, 0.9685514588077648, 0.9551748204475422], 
             UndirectedEdge[132, 244] -> 
             RGBColor[
              0.9297211146840363, 0.734480856885324, 0.45507752590641704`], 
             UndirectedEdge[53, 376] -> 
             RGBColor[
              0.9800512989437642, 0.9484384090522737, 0.5628161373873477], 
             UndirectedEdge[242, 364] -> 
             RGBColor[
              0.9340831035271799, 0.7541315905966177, 0.46573417611237916`], 
             UndirectedEdge[29, 327] -> 
             RGBColor[
              0.9758701293566219, 0.9293955715477233, 0.43481125247676444`], 
             UndirectedEdge[328, 364] -> 
             RGBColor[
              0.9899639878570873, 0.9761619369123093, 0.5555085985861911], 
             UndirectedEdge[257, 279] -> 
             RGBColor[
              0.9903309667123046, 0.9822501283246741, 0.5967786736964305], 
             UndirectedEdge[13, 322] -> 
             RGBColor[
              0.9756246574830398, 0.9278104626396486, 0.49823380319873894`], 
             UndirectedEdge[21, 24] -> 
             RGBColor[
              0.99072751456594, 0.9888064570191402, 0.6850562579115755], 
             UndirectedEdge[56, 122] -> 
             RGBColor[
              0.9918760627383512, 0.9903543537397484, 0.7440134380827785], 
             UndirectedEdge[87, 393] -> 
             RGBColor[
              0.9404208331952955, 0.8363388481479477, 0.5957791552657526], 
             UndirectedEdge[27, 74] -> 
             RGBColor[
              0.9878607553652379, 0.9783969251790356, 0.6181438132859374], 
             UndirectedEdge[93, 288] -> 
             RGBColor[
              0.984974706087467, 0.9878593877890992, 0.889926439282198], 
             UndirectedEdge[125, 211] -> 
             RGBColor[
              0.9681455802368335, 0.9108002399781282, 0.5619050014951026], 
             UndirectedEdge[265, 304] -> 
             RGBColor[
              0.9943051564218568, 0.9906333722863663, 0.6510227596880129], 
             UndirectedEdge[195, 343] -> 
             RGBColor[
              0.9806595302069596, 0.9452988832271714, 0.5292973940651273], 
             UndirectedEdge[199, 393] -> 
             RGBColor[
              0.9593045222393597, 0.9112063825913197, 0.6109734147277579], 
             UndirectedEdge[24, 208] -> 
             RGBColor[
              0.9528413899369037, 0.850221138675517, 0.5500651284354847], 
             UndirectedEdge[135, 386] -> 
             RGBColor[
              0.9296621209859303, 0.7677202746667877, 0.5718475664512058], 
             UndirectedEdge[32, 357] -> 
             RGBColor[
              0.9368268768061576, 0.9033099312763628, 0.6423516155469544], 
             UndirectedEdge[230, 233] -> 
             RGBColor[
              0.9941338856372965, 0.9911124979727239, 0.6938367597602928], 
             UndirectedEdge[46, 161] -> 
             RGBColor[
              0.987260648717457, 0.9670323145592512, 0.5459100809812079], 
             UndirectedEdge[114, 306] -> 
             RGBColor[
              0.9005663413558516, 0.9214151906176924, 0.9057490307898278], 
             UndirectedEdge[233, 357] -> 
             RGBColor[
              0.9761200509296462, 0.9315406648913813, 0.5224070976730258], 
             UndirectedEdge[134, 395] -> 
             RGBColor[
              0.9574658517435359, 0.9677986823903805, 0.956883397702351], 
             UndirectedEdge[108, 267] -> 
             RGBColor[
              0.9887845886797955, 0.989630153443241, 0.8355319203372741], 
             UndirectedEdge[217, 233] -> 
             RGBColor[
              0.9939181508255683, 0.9906510630245727, 0.670355356864609], 
             UndirectedEdge[245, 400] -> 
             RGBColor[
              0.9929242288166606, 0.9913420010237336, 0.7669273702241597], 
             UndirectedEdge[269, 392] -> 
             RGBColor[
              0.5989350994452369, 0.6307949438410005, 0.632414661604948], 
             UndirectedEdge[232, 288] -> 
             RGBColor[
              0.9865328966251847, 0.9885037396201157, 0.8641031896043672], 
             UndirectedEdge[260, 341] -> 
             RGBColor[
              0.9689376990722116, 0.9020641543483712, 0.4498929984138368], 
             UndirectedEdge[47, 323] -> 
             RGBColor[
              0.9133360807979731, 0.6245952780762738, 0.31090809193351654`], 
             UndirectedEdge[142, 377] -> 
             RGBColor[
              0.9278701905345156, 0.7510926187063169, 0.5646980219965796], 
             UndirectedEdge[53, 117] -> 
             RGBColor[
              0.9472842443814753, 0.8249316829386591, 0.2961018371198393], 
             UndirectedEdge[251, 308] -> 
             RGBColor[
              0.9854974115962862, 0.9852946496766993, 0.7025522999302692], 
             UndirectedEdge[85, 162] -> 
             RGBColor[
              0.9673621916407291, 0.9720215466270821, 0.7532546882236937], 
             UndirectedEdge[249, 397] -> 
             RGBColor[
              0.9573687927832946, 0.9664086838914359, 0.900995610939076], 
             UndirectedEdge[262, 284] -> 
             RGBColor[
              0.9866914357542871, 0.974177629143604, 0.6117010844860697], 
             UndirectedEdge[307, 341] -> 
             RGBColor[
              0.9525729449645685, 0.8923512548724736, 0.6116345297645865], 
             UndirectedEdge[7, 387] -> 
             RGBColor[
              0.9753360175064097, 0.9284647370499467, 0.35868551472502375`], 
             UndirectedEdge[228, 368] -> 
             RGBColor[
              0.9742627931298048, 0.9796160437691175, 0.896665606324872], 
             UndirectedEdge[240, 399] -> 
             RGBColor[
              0.987939348506573, 0.987763376617098, 0.7497978220092897], 
             UndirectedEdge[105, 114] -> 
             RGBColor[
              0.9837134337125177, 0.9865516521212468, 0.8756228163963463], 
             UndirectedEdge[78, 357] -> 
             RGBColor[
              0.9470041862046791, 0.9114250415350396, 0.6433223364027767], 
             UndirectedEdge[359, 369] -> 
             RGBColor[
              0.9084556734550941, 0.9262169257989905, 0.8354052204245519], 
             UndirectedEdge[48, 354] -> 
             RGBColor[
              0.993526601620224, 0.9900150368904388, 0.642381513899359], 
             UndirectedEdge[280, 325] -> 
             RGBColor[
              0.8083968616782985, 0.8503487766686817, 0.9815095736791632], 
             UndirectedEdge[259, 262] -> 
             RGBColor[
              0.9888580143015202, 0.9750735650514137, 0.5757952710328711], 
             UndirectedEdge[120, 187] -> 
             RGBColor[
              0.9925427346677038, 0.9893402084617153, 0.6392078429426848], 
             UndirectedEdge[70, 198] -> 
             RGBColor[
              0.9418983784349154, 0.8006067312157663, 0.30724536525840535`], 
             UndirectedEdge[62, 235] -> 
             RGBColor[
              0.9900582362722156, 0.9901568394539568, 0.814424283636564], 
             UndirectedEdge[65, 176] -> 
             RGBColor[
              0.9948362522361673, 0.991832615209027, 0.7134292441678243], 
             UndirectedEdge[199, 342] -> 
             RGBColor[
              0.9461073036325477, 0.9013639185628216, 0.6333128634432172], 
             UndirectedEdge[324, 390] -> 
             RGBColor[
              0.9752941675896241, 0.9801626711787749, 0.8849526202280769], 
             UndirectedEdge[226, 234] -> 
             RGBColor[
              0.9174712703353333, 0.9354772260114863, 0.9354784980093104], 
             UndirectedEdge[47, 201] -> 
             RGBColor[
              0.9137227757107587, 0.6254223793938689, 0.35299744678584133`], 
             UndirectedEdge[160, 264] -> 
             RGBColor[
              0.9941028864446904, 0.9912976370076588, 0.7087399532885277], 
             UndirectedEdge[277, 314] -> 
             RGBColor[
              0.9632855137384442, 0.88781555824776, 0.3118715831331661], 
             UndirectedEdge[4, 66] -> 
             RGBColor[
              0.9708455152613111, 0.9106541884394158, 0.3907042933804336], 
             UndirectedEdge[23, 75] -> 
             RGBColor[
              0.9523764789981505, 0.8360732378996979, 0.4561659567450098], 
             UndirectedEdge[287, 391] -> 
             RGBColor[
              0.9877861079314216, 0.9892172559940036, 0.8520793303231763], 
             UndirectedEdge[45, 91] -> 
             RGBColor[
              0.8535925348248001, 0.7102055582887268, 0.6032088530070883], 
             UndirectedEdge[175, 314] -> 
             RGBColor[
              0.9747329013842143, 0.9368756478036038, 0.5862358123192462], 
             UndirectedEdge[195, 358] -> 
             RGBColor[
              0.9941728408861317, 0.9902896113638439, 0.6322050468510503], 
             UndirectedEdge[321, 341] -> 
             RGBColor[
              0.9403599667323661, 0.8012541724964437, 0.2708704331825989], 
             UndirectedEdge[91, 148] -> 
             RGBColor[
              0.9059044258335855, 0.9260957536878374, 0.9274976405974706], 
             UndirectedEdge[115, 350] -> 
             RGBColor[
              0.966830995014689, 0.8997752991111259, 0.32564510838341876`], 
             UndirectedEdge[142, 277] -> 
             RGBColor[
              0.9735430943069636, 0.9387891643189316, 0.614554800027787], 
             UndirectedEdge[45, 66] -> 
             RGBColor[
              0.9375988000894951, 0.7724315198306377, 0.3636215963039195], 
             UndirectedEdge[259, 335] -> 
             RGBColor[
              0.9933793270518787, 0.9898278015877315, 0.6356391239948045], 
             UndirectedEdge[118, 173] -> 
             RGBColor[
              0.9752678053221917, 0.9774965387269655, 0.7064678669787773], 
             UndirectedEdge[52, 128] -> 
             RGBColor[
              0.9475676468947865, 0.8961241142487728, 0.6259305790033309], 
             UndirectedEdge[27, 225] -> 
             RGBColor[
              0.985599818104902, 0.9707702529066091, 0.6093604989717086], 
             UndirectedEdge[302, 352] -> 
             RGBColor[
              0.9441836059736497, 0.8015912968775618, 0.4024061007732067], 
             UndirectedEdge[25, 242] -> 
             RGBColor[
              0.907422902434292, 0.7361684794224856, 0.5995266489903033], 
             UndirectedEdge[30, 224] -> 
             RGBColor[
              0.9874839294543483, 0.9890922974281011, 0.857087209701112], 
             UndirectedEdge[313, 361] -> 
             RGBColor[
              0.9774358407142427, 0.9794355246411555, 0.7283527198860539], 
             UndirectedEdge[270, 310] -> 
             RGBColor[
              0.8957199574525837, 0.8976965287948547, 0.6782806119962193], 
             UndirectedEdge[72, 370] -> 
             RGBColor[
              0.9811348771984818, 0.9833146607368821, 0.8109902227408787], 
             UndirectedEdge[283, 380] -> 
             RGBColor[
              0.9459519593934433, 0.9587282212772554, 0.959612972191071], 
             UndirectedEdge[34, 35] -> 
             RGBColor[
              0.9787402557916101, 0.9473188926198624, 0.5805527802724344], 
             UndirectedEdge[25, 230] -> 
             RGBColor[
              0.9681431776913416, 0.9733301664413627, 0.8095505072490585], 
             UndirectedEdge[191, 211] -> 
             RGBColor[
              0.9756913571755808, 0.9807396895099864, 0.8968548551384798], 
             UndirectedEdge[17, 173] -> 
             RGBColor[
              0.9737599432962281, 0.9790235030318801, 0.8877759821100046], 
             UndirectedEdge[40, 51] -> 
             RGBColor[
              0.9415555404031164, 0.9529665149033157, 0.8633107823966004], 
             UndirectedEdge[105, 202] -> 
             RGBColor[
              0.9860663075493301, 0.9862876224587516, 0.7467125147999664], 
             UndirectedEdge[183, 309] -> 
             RGBColor[
              0.9469374436686148, 0.8396327970232327, 0.5835331509657569], 
             UndirectedEdge[187, 261] -> 
             RGBColor[
              0.9767805608692712, 0.9809161673370046, 0.8665365222564064], 
             UndirectedEdge[190, 274] -> 
             RGBColor[
              0.9764278722158577, 0.9810790588954009, 0.8862073766482788], 
             UndirectedEdge[176, 354] -> 
             RGBColor[
              0.9941946309491385, 0.9899912275500825, 0.6094995892776407], 
             UndirectedEdge[42, 148] -> 
             RGBColor[
              0.9891673611189414, 0.9862601957222734, 0.6471059699681221], 
             UndirectedEdge[320, 380] -> 
             RGBColor[
              0.9282961275074055, 0.9455605307654198, 0.9894996901956757], 
             UndirectedEdge[51, 222] -> 
             RGBColor[
              0.9863291667930357, 0.9875781848521954, 0.8298040627599002], 
             UndirectedEdge[122, 319] -> 
             RGBColor[
              0.9901265796224525, 0.9896308975116591, 0.7730069008303888], 
             UndirectedEdge[27, 78] -> 
             RGBColor[
              0.9622655070409531, 0.9705883666272931, 0.9134117430707356], 
             UndirectedEdge[5, 178] -> 
             RGBColor[
              0.9609604294792446, 0.8874746468773934, 0.5813792440498009], 
             UndirectedEdge[196, 336] -> 
             RGBColor[
              0.9478412897498971, 0.9583997705931759, 0.8821989688685082], 
             UndirectedEdge[297, 318] -> 
             RGBColor[
              0.9681597933076825, 0.9072570203960608, 0.5443022449736376], 
             UndirectedEdge[127, 235] -> 
             RGBColor[
              0.9806297019850149, 0.9565227493616152, 0.6074559265669444], 
             UndirectedEdge[45, 203] -> 
             RGBColor[
              0.9307834839969835, 0.7498877653932939, 0.2992286629264277], 
             UndirectedEdge[305, 370] -> 
             RGBColor[
              0.9949175548024474, 0.9915374885734966, 0.6881853893414367], 
             UndirectedEdge[122, 169] -> 
             RGBColor[
              0.9852012244199204, 0.9604237652368539, 0.509136859244248], 
             UndirectedEdge[51, 226] -> 
             RGBColor[
              0.9219388149799144, 0.937324670532681, 0.861439721613678], 
             UndirectedEdge[226, 395] -> 
             RGBColor[
              0.9027451037397374, 0.924756742759336, 0.9721509395435273], 
             UndirectedEdge[61, 354] -> 
             RGBColor[
              0.985703846695132, 0.9857435381538755, 0.7256042549797895], 
             UndirectedEdge[211, 334] -> 
             RGBColor[
              0.9915003949760393, 0.9904124832823292, 0.7657568087757425], 
             UndirectedEdge[10, 361] -> 
             RGBColor[
              0.9584752082332837, 0.9685514588077648, 0.9551748204475422], 
             UndirectedEdge[44, 249] -> 
             RGBColor[
              0.9898379579980907, 0.9900657487267127, 0.8180748647007139], 
             UndirectedEdge[302, 377] -> 
             RGBColor[
              0.8836746766183375, 0.5646756996409507, 0.22464763758679535`], 
             UndirectedEdge[149, 363] -> 
             RGBColor[
              0.9830126361171247, 0.966736931239071, 0.6317535064440793], 
             UndirectedEdge[358, 359] -> 
             RGBColor[
              0.9077298773933813, 0.9246645214122248, 0.7564067982011797], 
             UndirectedEdge[126, 317] -> 
             RGBColor[
              0.9789730961998346, 0.9538726492204983, 0.6213278117805587], 
             UndirectedEdge[194, 364] -> 
             RGBColor[
              0.9921419562583669, 0.9909224382387163, 0.7729081596198195], 
             UndirectedEdge[184, 343] -> 
             RGBColor[
              0.9582420645245853, 0.8690534131762745, 0.3013896746979107], 
             UndirectedEdge[118, 346] -> 
             RGBColor[
              0.9937399570754328, 0.9890187261088061, 0.5600111440466622], 
             UndirectedEdge[169, 239] -> 
             RGBColor[
              0.9487207830993816, 0.8285468868924775, 0.30809139229144283`], 
             UndirectedEdge[72, 157] -> 
             RGBColor[
              0.9787750883885246, 0.9768092517538608, 0.6781246145790795], 
             UndirectedEdge[162, 191] -> 
             RGBColor[
              0.9522998688864801, 0.9639459008341089, 0.9656280591752291], 
             UndirectedEdge[84, 272] -> 
             RGBColor[
              0.8271884697257639, 0.865041648599203, 0.9833791687539495], 
             UndirectedEdge[21, 160] -> 
             RGBColor[
              0.9940307255149998, 0.9896406503998412, 0.5916594942787271], 
             UndirectedEdge[29, 336] -> 
             RGBColor[
              0.9304987716274713, 0.8975141912354679, 0.64064486244762], 
             UndirectedEdge[275, 276] -> 
             RGBColor[
              0.9554413584643552, 0.9192868773541719, 0.6324551178464776], 
             UndirectedEdge[38, 303] -> 
             RGBColor[
              0.9807304171387061, 0.9534039149434637, 0.58394167703411], 
             UndirectedEdge[172, 285] -> 
             RGBColor[
              0.975469830948804, 0.9285705888802848, 0.3885869300585914], 
             UndirectedEdge[73, 285] -> 
             RGBColor[
              0.9754517697419276, 0.9285319577850442, 0.38662107915093535`], 
             UndirectedEdge[5, 59] -> 
             RGBColor[
              0.9601907918208803, 0.9696487863375682, 0.9442503902572064], 
             UndirectedEdge[73, 225] -> 
             RGBColor[
              0.9876476433391967, 0.9696715031559312, 0.43399974507884914`], 
             UndirectedEdge[64, 254] -> 
             RGBColor[
              0.9514418255784328, 0.9612768275494605, 0.8828067280076386], 
             UndirectedEdge[241, 390] -> 
             RGBColor[
              0.9920772412623498, 0.9909917499034389, 0.7809641459326166], 
             UndirectedEdge[58, 289] -> 
             RGBColor[
              0.9201349322905272, 0.6753527080392032, 0.34661965026167496`], 
             UndirectedEdge[262, 331] -> 
             RGBColor[
              0.9791703177460435, 0.9693865899113191, 0.6610729653716569], 
             UndirectedEdge[22, 118] -> 
             RGBColor[
              0.9935108811682121, 0.9885287559063881, 0.535077645238317], 
             UndirectedEdge[97, 360] -> 
             RGBColor[
              0.9832026019637292, 0.9550005735863529, 0.38924570986188634`], 
             UndirectedEdge[301, 358] -> 
             RGBColor[
              0.9476791226833607, 0.956518965213079, 0.7602171928800503], 
             UndirectedEdge[16, 274] -> 
             RGBColor[
              0.9233886462559522, 0.9395033751164265, 0.9059849355275384], 
             UndirectedEdge[166, 319] -> 
             RGBColor[
              0.9900802574049665, 0.9895318189723511, 0.767965013324624], 
             UndirectedEdge[82, 101] -> 
             RGBColor[
              0.9904753413729908, 0.9893870590472365, 0.7390191207489578], 
             UndirectedEdge[24, 399] -> 
             RGBColor[
              0.9849882850227591, 0.9876823910569879, 0.8815236640319198], 
             UndirectedEdge[328, 400] -> 
             RGBColor[
              0.9882053826536787, 0.9755307814452827, 0.5916367292828016], 
             UndirectedEdge[17, 371] -> 
             RGBColor[
              0.980878993129132, 0.9843328787408857, 0.8757252876884642], 
             UndirectedEdge[107, 158] -> 
             RGBColor[
              0.985424187456122, 0.9882405411788797, 0.8912224650531407], 
             UndirectedEdge[60, 394] -> 
             RGBColor[
              0.9665622977752868, 0.9730389084148487, 0.8723470044938995], 
             UndirectedEdge[219, 284] -> 
             RGBColor[
              0.9915138943457373, 0.9895759861835021, 0.7043228037941418], 
             UndirectedEdge[124, 149] -> 
             RGBColor[
              0.9296017920751772, 0.9451519563771642, 0.9367302508043449], 
             UndirectedEdge[227, 296] -> 
             RGBColor[
              0.8876082250885304, 0.9130322221018164, 0.9826760086170899], 
             UndirectedEdge[202, 229] -> 
             RGBColor[
              0.994462758217878, 0.9905647246660911, 0.638683587790245], 
             UndirectedEdge[315, 358] -> 
             RGBColor[
              0.9743178549652403, 0.9242035196714657, 0.4063591588490535], 
             UndirectedEdge[145, 222] -> 
             RGBColor[
              0.9761322255066704, 0.9540438046506123, 0.6384557072044893], 
             UndirectedEdge[155, 299] -> 
             RGBColor[
              0.9176399083519811, 0.93357340831472, 0.8389743775766716], 
             UndirectedEdge[14, 29] -> 
             RGBColor[
              0.945148898569184, 0.8196897085873929, 0.27759324806729613`], 
             UndirectedEdge[116, 151] -> 
             RGBColor[
              0.9921290419501831, 0.9897195928736109, 0.6860762135471168], 
             UndirectedEdge[45, 257] -> 
             RGBColor[
              0.9353380073990294, 0.7652512422813443, 0.3169221262938005], 
             UndirectedEdge[27, 240] -> 
             RGBColor[
              0.9914461945381696, 0.9895914408365102, 0.7086031402605037], 
             UndirectedEdge[144, 188] -> 
             RGBColor[
              0.9929452359354967, 0.9901502421292374, 0.6793194851211852], 
             UndirectedEdge[76, 200] -> 
             RGBColor[
              0.743895068737331, 0.795935917228078, 0.8546416917074975], 
             UndirectedEdge[90, 221] -> 
             RGBColor[
              0.93679739432341, 0.9515849596428688, 0.9641602095704813], 
             UndirectedEdge[271, 382] -> 
             RGBColor[
              0.9281171219768782, 0.7501483459625715, 0.2646903987244029], 
             UndirectedEdge[242, 385] -> 
             RGBColor[
              0.9276463616870898, 0.7512511022203469, 0.5652936075982433], 
             UndirectedEdge[74, 112] -> 
             RGBColor[
              0.9861462368048972, 0.9776879276932176, 0.6465578228625842], 
             UndirectedEdge[237, 251] -> 
             RGBColor[
              0.9817230556279776, 0.9856751913145605, 0.9062176942163055], 
             UndirectedEdge[25, 223] -> 
             RGBColor[
              0.9673893114571488, 0.9737481506131502, 0.8750874881473378], 
             UndirectedEdge[284, 332] -> 
             RGBColor[
              0.9373402739133131, 0.7815104061676712, 0.5281245951474802], 
             UndirectedEdge[145, 333] -> 
             RGBColor[
              0.9105523326179865, 0.6428428496244478, 0.273574467605923], 
             UndirectedEdge[146, 227] -> 
             RGBColor[
              0.9093477209216985, 0.928876974804383, 0.9293732896273711], 
             UndirectedEdge[108, 286] -> 
             RGBColor[
              0.9900011213158311, 0.9901332209517044, 0.8153708262726236], 
             UndirectedEdge[127, 361] -> 
             RGBColor[
              0.9678249200285247, 0.947477630837579, 0.65173109697003], 
             UndirectedEdge[143, 258] -> 
             RGBColor[
              0.9916832644053446, 0.9908288303483237, 0.7874933620326161], 
             UndirectedEdge[212, 310] -> 
             RGBColor[
              0.9619314644774322, 0.8798326134632328, 0.32439891598829956`], 
             UndirectedEdge[107, 310] -> 
             RGBColor[
              0.9826334999385868, 0.9653719626405298, 0.6296858371762314], 
             UndirectedEdge[253, 394] -> 
             RGBColor[
              0.948449665833254, 0.9610744257011417, 0.9721454486505581], 
             UndirectedEdge[152, 284] -> 
             RGBColor[
              0.9914883745977388, 0.9895214020229752, 0.701545136714119], 
             UndirectedEdge[230, 364] -> 
             RGBColor[
              0.9948033787842294, 0.9912932776154948, 0.6757580343711344], 
             UndirectedEdge[158, 241] -> 
             RGBColor[
              0.9896907742016042, 0.9900048844444145, 0.8205140811079483], 
             UndirectedEdge[44, 315] -> 
             RGBColor[
              0.9722415847230987, 0.9249136514071115, 0.554797920054005], 
             UndirectedEdge[357, 385] -> 
             RGBColor[
              0.9703528022364891, 0.9288409561578812, 0.6038878037697316], 
             UndirectedEdge[99, 197] -> 
             RGBColor[
              0.98994726899606, 0.9837379841953159, 0.614518255451636], 
             UndirectedEdge[152, 267] -> 
             RGBColor[
              0.990809036034297, 0.9892404780687873, 0.712803534782194], 
             UndirectedEdge[169, 197] -> 
             RGBColor[
              0.9829204284873817, 0.9600348011789319, 0.5872203069829061], 
             UndirectedEdge[263, 348] -> 
             RGBColor[
              0.9724366690789197, 0.916118561327381, 0.5081320671741494], 
             UndirectedEdge[314, 379] -> 
             RGBColor[
              0.974498511505079, 0.9367787215650363, 0.590120259198079], 
             UndirectedEdge[300, 319] -> 
             RGBColor[
              0.9765939209101423, 0.9453006932487682, 0.608308198612987], 
             UndirectedEdge[25, 78] -> 
             RGBColor[
              0.9387250761670509, 0.953819287634474, 0.9885180583617955], 
             UndirectedEdge[44, 113] -> 
             RGBColor[
              0.9916801757059555, 0.9897641258758001, 0.7102446172835973], 
             UndirectedEdge[115, 221] -> 
             RGBColor[
              0.9704885872387776, 0.9469139586855231, 0.6418085458431569], 
             UndirectedEdge[175, 319] -> 
             RGBColor[
              0.986339116008333, 0.9886188876478103, 0.8760597311838114], 
             UndirectedEdge[176, 356] -> 
             RGBColor[
              0.9948018026579948, 0.9912899064408498, 0.675586482757217], 
             UndirectedEdge[84, 395] -> 
             RGBColor[
              0.8912646861938485, 0.9156025694358768, 0.9710559270693107], 
             UndirectedEdge[301, 359] -> 
             RGBColor[
              0.861945415769669, 0.8927558939224458, 0.9866943172955092], 
             UndirectedEdge[238, 280] -> 
             RGBColor[
              0.5184339885846974, 0.6071516952625204, 0.9584081090963719], 
             UndirectedEdge[36, 168] -> 
             RGBColor[
              0.9351184832856951, 0.9086868176249018, 0.6521027851836908], 
             UndirectedEdge[4, 232] -> 
             RGBColor[
              0.9692573732818102, 0.9117715614205533, 0.5459830210694956], 
             UndirectedEdge[140, 339] -> 
             RGBColor[
              0.9689929302330029, 0.9630589861667963, 0.6809810482225183], 
             UndirectedEdge[18, 141] -> 
             RGBColor[
              0.8980287010230111, 0.5993041314132243, 0.2352669791194509], 
             UndirectedEdge[123, 140] -> 
             RGBColor[
              0.9316034487970304, 0.8234760304595663, 0.6058270455175723], 
             UndirectedEdge[24, 78] -> 
             RGBColor[
              0.9618295434014412, 0.9704080844586005, 0.9206367888151791], 
             UndirectedEdge[62, 127] -> 
             RGBColor[
              0.9834582710148986, 0.9576924353463805, 0.5605792176397738], 
             UndirectedEdge[299, 353] -> 
             RGBColor[
              0.984621137807365, 0.9582663417159809, 0.523945599239166], 
             UndirectedEdge[256, 311] -> 
             RGBColor[
              0.9946693855413341, 0.9910066796177366, 0.6611736967924127], 
             UndirectedEdge[47, 346] -> 
             RGBColor[
              0.9143553843716352, 0.6267754653529372, 0.42185299551415256`], 
             UndirectedEdge[34, 125] -> 
             RGBColor[0.9686598195165, 0.911012891135617, 0.5533827258224333],
              UndirectedEdge[194, 387] -> 
             RGBColor[
              0.9820566726884803, 0.9585487875615408, 0.5937325560876086], 
             UndirectedEdge[117, 303] -> 
             RGBColor[
              0.9488670597485366, 0.8302708908344785, 0.3022507759312709], 
             UndirectedEdge[287, 382] -> 
             RGBColor[
              0.9740410801410982, 0.9306809570432044, 0.5568610238431996], 
             UndirectedEdge[20, 168] -> 
             RGBColor[
              0.6038549351653604, 0.6314384246054661, 0.6252315877195176], 
             UndirectedEdge[51, 355] -> 
             RGBColor[
              0.9794067965020342, 0.9824154924235076, 0.8415218300192397], 
             UndirectedEdge[183, 339] -> 
             RGBColor[
              0.9828603543416655, 0.973401288361214, 0.6575071164100159], 
             UndirectedEdge[118, 164] -> 
             RGBColor[
              0.9849254090736921, 0.9846991637919598, 0.690120062933953], 
             UndirectedEdge[51, 134] -> 
             RGBColor[
              0.9766595629837128, 0.9803666101637254, 0.8461721797725017], 
             UndirectedEdge[46, 356] -> 
             RGBColor[
              0.9870014344692526, 0.9664778814929228, 0.5176962097490665], 
             UndirectedEdge[204, 276] -> 
             RGBColor[
              0.9756507885577559, 0.9331116126384942, 0.5423836024093361], 
             UndirectedEdge[108, 154] -> 
             RGBColor[
              0.9914902607739344, 0.9889266167617956, 0.6582225717965069], 
             UndirectedEdge[29, 119] -> 
             RGBColor[
              0.9757589259478164, 0.9305297047276058, 0.5224363484330495], 
             UndirectedEdge[244, 264] -> 
             RGBColor[
              0.9289708545437612, 0.7343787679840104, 0.4826425268449658], 
             UndirectedEdge[217, 321] -> 
             RGBColor[
              0.9655993998390553, 0.8891438175980139, 0.4285723908959347], 
             UndirectedEdge[241, 346] -> 
             RGBColor[
              0.9945206491922448, 0.9914920663649174, 0.7033919944438268], 
             UndirectedEdge[108, 284] -> 
             RGBColor[
              0.9894639272432373, 0.9899110773974289, 0.824273522269199], 
             UndirectedEdge[181, 334] -> 
             RGBColor[
              0.9525391470577987, 0.9613490188113846, 0.8380800978160852], 
             UndirectedEdge[8, 59] -> 
             RGBColor[
              0.9180763568987605, 0.9375131827449755, 0.9920481365690845], 
             UndirectedEdge[236, 383] -> 
             RGBColor[
              0.9304410640769092, 0.7400324197757103, 0.3530393561611934], 
             UndirectedEdge[42, 290] -> 
             RGBColor[
              0.9282251633026257, 0.7311817927695339, 0.3156158428293587], 
             UndirectedEdge[173, 209] -> 
             RGBColor[
              0.9640817810941016, 0.9399400866857981, 0.6479925706587258], 
             UndirectedEdge[154, 332] -> 
             RGBColor[
              0.9393666074440103, 0.7805259455320379, 0.3620736446747879], 
             UndirectedEdge[5, 352] -> 
             RGBColor[
              0.9895244670242311, 0.9886937853498128, 0.7329661775268406], 
             UndirectedEdge[189, 226] -> 
             RGBColor[
              0.9206713452966415, 0.9368005392461625, 0.8824449743719034], 
             UndirectedEdge[16, 390] -> 
             RGBColor[
              0.9236019429558271, 0.9395915787832999, 0.9024500572164462], 
             UndirectedEdge[119, 327] -> 
             RGBColor[
              0.9938028390304454, 0.9905252102791654, 0.6665843575242207], 
             UndirectedEdge[129, 231] -> 
             RGBColor[
              0.9404622269982644, 0.8008888189276104, 0.5526710250649083], 
             UndirectedEdge[79, 352] -> 
             RGBColor[
              0.9922998015187903, 0.9898414574861563, 0.6869717026165586], 
             UndirectedEdge[62, 361] -> 
             RGBColor[
              0.9772534543157254, 0.9811117209299206, 0.8586994540396495], 
             UndirectedEdge[150, 347] -> 
             RGBColor[
              0.9812113382469707, 0.9513895738758881, 0.560673914891848], 
             UndirectedEdge[5, 90] -> 
             RGBColor[
              0.9449565605552688, 0.9575014238485612, 0.9427973356793335], 
             UndirectedEdge[24, 27] -> 
             RGBColor[
              0.9884951310543557, 0.9895104552764, 0.8403289822831339], 
             UndirectedEdge[62, 393] -> 
             RGBColor[
              0.9796870216505265, 0.9829266714636143, 0.854580059317845], 
             UndirectedEdge[199, 353] -> 
             RGBColor[
              0.9631996878198745, 0.8863901449680464, 0.31745396414978727`], 
             UndirectedEdge[96, 201] -> 
             RGBColor[
              0.9438770362500265, 0.8006993487790617, 0.37966072838897413`], 
             UndirectedEdge[155, 170] -> 
             RGBColor[
              0.9164242517428274, 0.933344427953367, 0.8790178633419233], 
             UndirectedEdge[335, 394] -> 
             RGBColor[
              0.9664741653736995, 0.9713000691501371, 0.7500614957522312], 
             UndirectedEdge[16, 310] -> 
             RGBColor[
              0.9184247883775465, 0.9157361347859257, 0.6804633645148684], 
             UndirectedEdge[6, 277] -> 
             RGBColor[
              0.9796163942180571, 0.9413235602135983, 0.5096566297506081], 
             UndirectedEdge[140, 232] -> 
             RGBColor[
              0.9714039622883051, 0.9772206051630273, 0.8897125291786789], 
             UndirectedEdge[177, 300] -> 
             RGBColor[
              0.957435063832082, 0.8655176054931122, 0.302491897308207], 
             UndirectedEdge[24, 32] -> 
             RGBColor[
              0.9516522340029198, 0.9622929741999238, 0.9196660679593567], 
             UndirectedEdge[102, 226] -> 
             RGBColor[
              0.919465700714813, 0.9363019742279239, 0.9024256252009608], 
             UndirectedEdge[187, 206] -> 
             RGBColor[
              0.9767805608692712, 0.9809161673370046, 0.8665365222564064], 
             UndirectedEdge[336, 396] -> 
             RGBColor[
              0.9365611804347478, 0.9513692136331457, 0.9631878612487585], 
             UndirectedEdge[267, 332] -> 
             RGBColor[
              0.9366609353498714, 0.7812294822134833, 0.5393829932155552], 
             UndirectedEdge[115, 300] -> 
             RGBColor[
              0.9698313860527292, 0.9098963226077532, 0.33730106098990065`], 
             UndirectedEdge[149, 195] -> 
             RGBColor[
              0.9903206798633419, 0.9902653666233802, 0.8100749141493586], 
             UndirectedEdge[127, 396] -> 
             RGBColor[
              0.971990385308122, 0.9505842280227792, 0.6446800507790125], 
             UndirectedEdge[206, 220] -> 
             RGBColor[
              0.9539248479569604, 0.8977110997423411, 0.6127223026455069], 
             UndirectedEdge[298, 361] -> 
             RGBColor[
              0.9783727263057552, 0.981439428187737, 0.8303269347345263], 
             UndirectedEdge[27, 141] -> 
             RGBColor[
              0.9180466223502743, 0.6766026328740818, 0.5129498853440528], 
             UndirectedEdge[55, 221] -> 
             RGBColor[
              0.937704372446299, 0.9523081593787952, 0.9642467179535115], 
             UndirectedEdge[40, 269] -> 
             RGBColor[
              0.9279728807203469, 0.9080113115461774, 0.6588095502104294], 
             UndirectedEdge[191, 312] -> 
             RGBColor[
              0.9419863987814813, 0.9558674476274135, 0.9696794937659803], 
             UndirectedEdge[78, 240] -> 
             RGBColor[
              0.9647806068852551, 0.9704890700187107, 0.7889109467925489], 
             UndirectedEdge[183, 246] -> 
             RGBColor[
              0.9853095099216304, 0.9875786724146228, 0.865606791901997], 
             UndirectedEdge[130, 164] -> 
             RGBColor[
              0.980909478706641, 0.9713291219621755, 0.6594992273054272], 
             UndirectedEdge[190, 295] -> 
             RGBColor[
              0.9718992003734078, 0.9587798032507204, 0.6623764212073109], 
             UndirectedEdge[18, 179] -> 
             RGBColor[
              0.8908569196703893, 0.8523123430259761, 0.6308271492419346], 
             UndirectedEdge[128, 199] -> 
             RGBColor[
              0.9501556105601172, 0.8400906360686753, 0.27875223813972005`], 
             UndirectedEdge[350, 355] -> 
             RGBColor[
              0.9628406794500849, 0.9273963868110227, 0.6254304293324544], 
             UndirectedEdge[233, 348] -> 
             RGBColor[
              0.9720024758310788, 0.9159390112611412, 0.5153277729469792], 
             UndirectedEdge[247, 316] -> 
             RGBColor[
              0.993820433446452, 0.9913447828312615, 0.7253381754856413], 
             UndirectedEdge[74, 399] -> 
             RGBColor[
              0.9843539093336412, 0.9765688609596235, 0.6593384950347232], 
             UndirectedEdge[155, 171] -> 
             RGBColor[
              0.917292459607294, 0.9328302505822914, 0.8011567259225993], 
             UndirectedEdge[21, 95] -> 
             RGBColor[
              0.9665177779923735, 0.9713933521315685, 0.7548084601490054], 
             UndirectedEdge[257, 325] -> 
             RGBColor[
              0.9107612535539584, 0.9215443809846899, 0.6972667326193249], 
             UndirectedEdge[250, 372] -> 
             RGBColor[
              0.9707560616796865, 0.9631112515141099, 0.6753161061025454], 
             UndirectedEdge[156, 400] -> 
             RGBColor[
              0.9829386815990261, 0.9577649621077247, 0.571176590218516], 
             UndirectedEdge[193, 360] -> 
             RGBColor[
              0.9773238236277779, 0.9351700738563942, 0.3664077661408509], 
             UndirectedEdge[92, 135] -> 
             RGBColor[
              0.9819974680564629, 0.9858681338882676, 0.905228619172358], 
             UndirectedEdge[102, 174] -> 
             RGBColor[
              0.9872401240223618, 0.988991477616461, 0.8611276966573581], 
             UndirectedEdge[140, 275] -> 
             RGBColor[
              0.9520201413081997, 0.9637372804642392, 0.966101565000621], 
             UndirectedEdge[101, 301] -> 
             RGBColor[
              0.944327793804345, 0.9567018274348649, 0.9297869754439831], 
             UndirectedEdge[337, 398] -> 
             RGBColor[
              0.974081061964686, 0.9375353415010517, 0.6034613924665128], 
             UndirectedEdge[149, 249] -> 
             RGBColor[
              0.9880620672174425, 0.9893313722506034, 0.8475059707940709], 
             UndirectedEdge[92, 165] -> 
             RGBColor[
              0.9884942551256328, 0.9895100930573627, 0.8403434986889031], 
             UndirectedEdge[150, 320] -> 
             RGBColor[
              0.9658319336277497, 0.9727368840703396, 0.8844510285404136], 
             UndirectedEdge[59, 175] -> 
             RGBColor[
              0.961119619501164, 0.9700328804531481, 0.9288573118659225], 
             UndirectedEdge[278, 379] -> 
             RGBColor[
              0.988048372733678, 0.9893257092296346, 0.8477329238302362], 
             UndirectedEdge[87, 317] -> 
             RGBColor[
              0.9435281487061931, 0.8088650072438622, 0.2991990559403209], 
             UndirectedEdge[212, 324] -> 
             RGBColor[
              0.9525988896706992, 0.8937990650211953, 0.612698884911522], 
             UndirectedEdge[135, 328] -> 
             RGBColor[
              0.9815994089163957, 0.9718436707829534, 0.6583313554229301], 
             UndirectedEdge[176, 344] -> 
             RGBColor[
              0.9252468509255701, 0.7098167184257381, 0.44541624174711153`], 
             UndirectedEdge[59, 213] -> 
             RGBColor[
              0.9159270262970192, 0.7874371370901017, 0.6145890684130951], 
             UndirectedEdge[371, 391] -> 
             RGBColor[
              0.9789415087978599, 0.9835316791788286, 0.9078344171063641], 
             UndirectedEdge[98, 318] -> 
             RGBColor[
              0.9851586014794761, 0.9674914063321409, 0.5952704530649449], 
             UndirectedEdge[25, 244] -> 
             RGBColor[
              0.9031258792285841, 0.7166567006406335, 0.5959411074977835], 
             UndirectedEdge[204, 224] -> 
             RGBColor[
              0.9900688427403106, 0.9901612255010879, 0.8142485070115704], 
             UndirectedEdge[180, 236] -> 
             RGBColor[
              0.9791446337447514, 0.980632323533055, 0.7193016692979308], 
             UndirectedEdge[102, 163] -> 
             RGBColor[
              0.9914379213639106, 0.9907273746956622, 0.7915593311566169], 
             UndirectedEdge[16, 107] -> 
             RGBColor[
              0.9216087004980571, 0.9387673218030174, 0.9354832430878233], 
             UndirectedEdge[194, 223] -> 
             RGBColor[
              0.9910208336765647, 0.9905548982182801, 0.7984715535242712], 
             UndirectedEdge[111, 291] -> 
             RGBColor[
              0.9329245316194297, 0.943983180016857, 0.7063926884628423], 
             UndirectedEdge[108, 205] -> 
             RGBColor[
              0.9920142573752091, 0.9900473925077391, 0.7152563681130841], 
             UndirectedEdge[66, 297] -> 
             RGBColor[
              0.969702033935853, 0.9061206660265373, 0.3897842214650135], 
             UndirectedEdge[19, 284] -> 
             RGBColor[
              0.9851500095476531, 0.9689780366045431, 0.6057129347472112], 
             UndirectedEdge[23, 260] -> 
             RGBColor[
              0.9521950772125616, 0.8356852378228573, 0.4364214918657172], 
             UndirectedEdge[10, 256] -> 
             RGBColor[
              0.97530591833631, 0.979260991042409, 0.8441497236471587], 
             UndirectedEdge[230, 242] -> 
             RGBColor[
              0.9337158471795705, 0.7533460664043938, 0.42576058911855147`], 
             UndirectedEdge[29, 317] -> 
             RGBColor[
              0.965264042647371, 0.8944896008382498, 0.31955779433051323`], 
             UndirectedEdge[124, 316] -> 
             RGBColor[
              0.9341499770133508, 0.946664925893821, 0.8346182913338569], 
             UndirectedEdge[306, 361] -> 
             RGBColor[
              0.8868052152082214, 0.9119745991936952, 0.9658732993795338], 
             UndirectedEdge[1, 393] -> 
             RGBColor[
              0.9746876069745969, 0.9642330418268303, 0.6648179955689579], 
             UndirectedEdge[74, 279] -> 
             RGBColor[
              0.989374214827369, 0.9790227795607609, 0.5930618732908888], 
             UndirectedEdge[40, 234] -> 
             RGBColor[
              0.9370879957585353, 0.9511190703821211, 0.9373495587922329], 
             UndirectedEdge[195, 316] -> 
             RGBColor[
              0.9948688648015154, 0.991778336140037, 0.7079629546788706], 
             UndirectedEdge[279, 325] -> 
             RGBColor[
              0.9123883004597837, 0.9302366988685591, 0.883428115471488], 
             UndirectedEdge[172, 337] -> 
             RGBColor[
              0.989097957422026, 0.9878453236816412, 0.6911807709939384], 
             UndirectedEdge[148, 275] -> 
             RGBColor[
              0.9689387281386741, 0.9759557635120977, 0.919578147405306], 
             UndirectedEdge[13, 188] -> 
             RGBColor[
              0.9935703629934534, 0.991487325696166, 0.7473607075427628], 
             UndirectedEdge[220, 233] -> 
             RGBColor[
              0.970030620711271, 0.9081212627928701, 0.5137411720321935], 
             UndirectedEdge[230, 244] -> 
             RGBColor[
              0.9294188239738626, 0.7338342876225418, 0.4221750476260317], 
             UndirectedEdge[253, 358] -> 
             RGBColor[0.975361610852935, 0.9780362403862886, 0.7435810692922],
              UndirectedEdge[66, 140] -> 
             RGBColor[
              0.972992104267806, 0.9761032321818899, 0.734433801489617], 
             UndirectedEdge[89, 128] -> 
             RGBColor[
              0.9530649236825985, 0.9002239742761584, 0.616625123320978], 
             UndirectedEdge[199, 298] -> 
             RGBColor[
              0.9736235778809623, 0.9199339438242438, 0.49556841081418324`], 
             UndirectedEdge[367, 398] -> 
             RGBColor[
              0.9723084820631576, 0.9363696964540595, 0.6134632283871125], 
             UndirectedEdge[72, 181] -> 
             RGBColor[
              0.9388004649731765, 0.9532202929420159, 0.9656735719871634], 
             UndirectedEdge[229, 329] -> 
             RGBColor[
              0.9941948914419796, 0.9899917847179298, 0.609527942315818], 
             UndirectedEdge[196, 326] -> 
             RGBColor[
              0.9900165232980965, 0.990139590067184, 0.8151155755674333], 
             UndirectedEdge[247, 362] -> 
             RGBColor[
              0.9782855606638079, 0.9818983387125162, 0.8577080443979126], 
             UndirectedEdge[276, 297] -> 
             RGBColor[
              0.9528898501724037, 0.849855129558968, 0.2865553449359818], 
             UndirectedEdge[7, 201] -> 
             RGBColor[
              0.984548731266714, 0.9589720491347664, 0.4428872793608687], 
             UndirectedEdge[191, 214] -> 
             RGBColor[
              0.9062204383664483, 0.9273486416335988, 0.9662681045329446], 
             UndirectedEdge[25, 32] -> 
             RGBColor[
              0.9285477667685293, 0.9457041773757973, 0.9875473375059731], 
             UndirectedEdge[190, 324] -> 
             RGBColor[
              0.9621314395307189, 0.9712782701228627, 0.9489857745588313], 
             UndirectedEdge[8, 296] -> 
             RGBColor[
              0.9219546822368632, 0.9404191547221541, 0.9859520043613421], 
             UndirectedEdge[292, 382] -> 
             RGBColor[
              0.9667042605066927, 0.8993477938569765, 0.3251527687516565], 
             UndirectedEdge[223, 328] -> 
             RGBColor[
              0.9888428652752851, 0.9757943968918732, 0.5810719924906428], 
             UndirectedEdge[70, 262] -> 
             RGBColor[
              0.9446424330114008, 0.809863071636906, 0.3179054991168258], 
             UndirectedEdge[78, 285] -> 
             RGBColor[
              0.9467383568547183, 0.9105283367179224, 0.64228963957584], 
             UndirectedEdge[167, 272] -> 
             RGBColor[
              0.9052551663549357, 0.9089634434954166, 0.6846922104031801], 
             UndirectedEdge[93, 276] -> 
             RGBColor[
              0.9732669889067428, 0.9321258502219435, 0.5818893317023661], 
             UndirectedEdge[56, 319] -> 
             RGBColor[
              0.9873630583651438, 0.9890423141264698, 0.8590903564535801], 
             UndirectedEdge[93, 162] -> 
             RGBColor[
              0.9641318062770041, 0.9723147872375721, 0.9252080319624125], 
             UndirectedEdge[106, 389] -> 
             RGBColor[
              0.958641119414696, 0.861269861474558, 0.43993855478606747`], 
             UndirectedEdge[68, 176] -> 
             RGBColor[
              0.9922504761112079, 0.990763330329941, 0.7562822463325027], 
             UndirectedEdge[253, 301] -> 
             RGBColor[
              0.9295771492292229, 0.9461276128965097, 0.9738685883865293], 
             UndirectedEdge[217, 357] -> 
             RGBColor[
              0.9762065529172417, 0.930474485393777, 0.4408733823943559], 
             UndirectedEdge[364, 385] -> 
             RGBColor[
              0.9887338932917489, 0.9891983134314478, 0.8152910528508263], 
             UndirectedEdge[161, 372] -> 
             RGBColor[
              0.9762169813487868, 0.9798752122407841, 0.8374303735877682], 
             UndirectedEdge[4, 339] -> 
             RGBColor[
              0.966846341226508, 0.8976099424243222, 0.33725154011333497`], 
             UndirectedEdge[183, 280] -> 
             RGBColor[
              0.882234343810343, 0.9080696525110059, 0.9485032407268339], 
             UndirectedEdge[94, 145] -> 
             RGBColor[
              0.984558047317112, 0.9585646870423798, 0.5452385871467437], 
             UndirectedEdge[107, 351] -> 
             RGBColor[
              0.924453484440511, 0.9410356752991271, 0.9357545811198231], 
             UndirectedEdge[90, 178] -> 
             RGBColor[
              0.9207099886276601, 0.8568253415598743, 0.6293547797801338], 
             UndirectedEdge[113, 124] -> 
             RGBColor[
              0.9337468147389911, 0.9458026025549244, 0.7907365657989616], 
             UndirectedEdge[191, 365] -> 
             RGBColor[
              0.9368365409749884, 0.9517610908016823, 0.9691882957310646], 
             UndirectedEdge[184, 356] -> 
             RGBColor[
              0.9723582939606021, 0.915333723569401, 0.46992131338313414`], 
             UndirectedEdge[196, 327] -> 
             RGBColor[
              0.9932126474790477, 0.9902811509054315, 0.6763653588976528], 
             UndirectedEdge[140, 288] -> 
             RGBColor[
              0.9678876376850809, 0.9755712332814765, 0.9392420325404169], 
             UndirectedEdge[13, 232] -> 
             RGBColor[
              0.9925949775386617, 0.9910839787443468, 0.7635253687453036], 
             UndirectedEdge[34, 86] -> 
             RGBColor[
              0.9864460842460928, 0.9733124614113962, 0.6104884686945004], 
             UndirectedEdge[287, 374] -> 
             RGBColor[
              0.9680918300196559, 0.9748128088533348, 0.8981129006889024], 
             UndirectedEdge[201, 230] -> 
             RGBColor[
              0.9939308089746473, 0.989426939023139, 0.5807841954747683], 
             UndirectedEdge[71, 138] -> 
             RGBColor[
              0.9903302408642232, 0.9886495456552433, 0.6921759430362011], 
             UndirectedEdge[334, 360] -> 
             RGBColor[
              0.9847672762112087, 0.9588072335143636, 0.520437473003065], 
             UndirectedEdge[38, 58] -> 
             RGBColor[
              0.9183215993234146, 0.6764046255726215, 0.5076414606160755], 
             UndirectedEdge[115, 239] -> 
             RGBColor[
              0.9468836034445007, 0.8223496485262676, 0.3009542962544972], 
             UndirectedEdge[32, 78] -> 
             RGBColor[
              0.9254226099895171, 0.9433708855508168, 0.9927488287469584], 
             UndirectedEdge[41, 83] -> 
             RGBColor[
              0.9473329772425771, 0.9284726758149401, 0.6680473143766368], 
             UndirectedEdge[90, 212] -> 
             RGBColor[
              0.9245597304202362, 0.8720882849170348, 0.6324523723914945], 
             UndirectedEdge[160, 263] -> 
             RGBColor[
              0.9946828123233091, 0.991537451261883, 0.6991290806797499], 
             UndirectedEdge[226, 350] -> 
             RGBColor[
              0.905372697927965, 0.8823055649201961, 0.6453483209268926], 
             UndirectedEdge[159, 329] -> 
             RGBColor[
              0.9940583141772685, 0.9901118008524274, 0.624620656633899], 
             UndirectedEdge[132, 260] -> 
             RGBColor[
              0.9946951577008027, 0.9910618036608749, 0.6639788373032417], 
             UndirectedEdge[7, 250] -> 
             RGBColor[
              0.9799689889998624, 0.9440928377708, 0.37668373411383305`], 
             UndirectedEdge[135, 281] -> 
             RGBColor[
              0.9828733858452707, 0.9862303484039999, 0.8907123946092415], 
             UndirectedEdge[240, 243] -> 
             RGBColor[
              0.9941397134320258, 0.9898737645339912, 0.6035221564515549], 
             UndirectedEdge[105, 349] -> 
             RGBColor[
              0.9824401944047869, 0.9860251349467425, 0.8967236867631486], 
             UndirectedEdge[111, 154] -> 
             RGBColor[
              0.9333069247399293, 0.9448617223266325, 0.7428572540874743], 
             UndirectedEdge[3, 233] -> 
             RGBColor[
              0.8571996468952432, 0.8866747151833987, 0.8623360894854024], 
             UndirectedEdge[125, 162] -> 
             RGBColor[
              0.9447540919477329, 0.8940064513022508, 0.6306782055318517], 
             UndirectedEdge[301, 369] -> 
             RGBColor[
              0.9484049187450737, 0.9580713695998446, 0.8392156151034225], 
             UndirectedEdge[268, 270] -> 
             RGBColor[
              0.898454755178833, 0.9205419954682058, 0.9407434783528785], 
             UndirectedEdge[4, 188] -> 
             RGBColor[
              0.970232758736602, 0.9121749083723725, 0.5298183598669548], 
             UndirectedEdge[161, 176] -> 
             RGBColor[
              0.9950610169061993, 0.9918443395071782, 0.7038003539893583], 
             UndirectedEdge[106, 270] -> 
             RGBColor[
              0.8674769305941534, 0.792667698048863, 0.6193840602649903], 
             UndirectedEdge[190, 268] -> 
             RGBColor[
              0.9741988120637011, 0.9801572852382513, 0.923148671992268], 
             UndirectedEdge[220, 341] -> 
             RGBColor[
              0.9448776895921772, 0.8191654381936955, 0.27450549904018773`], 
             UndirectedEdge[76, 103] -> 
             RGBColor[
              0.9801229678976654, 0.9831356235288893, 0.8486395204361152], 
             UndirectedEdge[84, 163] -> 
             RGBColor[
              0.9096637144641798, 0.9278418753787698, 0.873514662523405], 
             UndirectedEdge[356, 372] -> 
             RGBColor[
              0.9759577671005824, 0.9793207791744557, 0.8092165023556268], 
             UndirectedEdge[243, 398] -> 
             RGBColor[
              0.978673604571555, 0.9386029603065469, 0.46690867121711266`], 
             UndirectedEdge[141, 243] -> 
             RGBColor[
              0.9207401412441307, 0.6768849565715629, 0.4078689015351039], 
             UndirectedEdge[192, 320] -> 
             RGBColor[
              0.9638139129495356, 0.9719023806591323, 0.9178948536485259], 
             UndirectedEdge[83, 245] -> 
             RGBColor[
              0.9587098212268386, 0.9667428854167972, 0.8692030195962772], 
             UndirectedEdge[256, 313] -> 
             RGBColor[
              0.994266550817269, 0.9901450568757996, 0.6173276230856704], 
             UndirectedEdge[144, 186] -> 
             RGBColor[
              0.9808273690826048, 0.9461320473061299, 0.452832633466648], 
             UndirectedEdge[271, 371] -> 
             RGBColor[
              0.9349051499630953, 0.8037796389300156, 0.5843813861480176], 
             UndirectedEdge[317, 326] -> 
             RGBColor[
              0.9801118315490487, 0.9543435455515619, 0.602456020091465], 
             UndirectedEdge[194, 242] -> 
             RGBColor[
              0.9310544246537078, 0.7529752270276153, 0.5229107143672367], 
             UndirectedEdge[305, 334] -> 
             RGBColor[
              0.9949310364921854, 0.9915663245446384, 0.689652788070085], 
             UndirectedEdge[252, 282] -> 
             RGBColor[
              0.9270467374828144, 0.9374014534979438, 0.7030443645725634], 
             UndirectedEdge[134, 239] -> 
             RGBColor[
              0.9401460543615752, 0.8479218539663822, 0.6053899669567948], 
             UndirectedEdge[267, 398] -> 
             RGBColor[
              0.9753936300321246, 0.9380781221283984, 0.5817087427717816], 
             UndirectedEdge[4, 297] -> 
             RGBColor[
              0.9473220440097534, 0.8288564889265613, 0.2764722839809419], 
             UndirectedEdge[40, 272] -> 
             RGBColor[
              0.8582856126948548, 0.889837666293297, 0.9863452420110885], 
             UndirectedEdge[203, 325] -> 
             RGBColor[
              0.9062067301519126, 0.9061809040966395, 0.679573269251952], 
             UndirectedEdge[315, 359] -> 
             RGBColor[
              0.8885841480515485, 0.8604404483808328, 0.6328362832645124], 
             UndirectedEdge[132, 160] -> 
             RGBColor[
              0.9948531465849655, 0.9913997259089725, 0.6811749523499788], 
             UndirectedEdge[283, 381] -> 
             RGBColor[
              0.9825151868951947, 0.9855023883292567, 0.8706824551986744], 
             UndirectedEdge[40, 183] -> 
             RGBColor[
              0.934449456886451, 0.9494135200944918, 0.9535607995487672], 
             UndirectedEdge[131, 339] -> 
             RGBColor[
              0.9189216900111182, 0.9235734611375523, 0.691457607441031], 
             UndirectedEdge[156, 165] -> 
             RGBColor[
              0.982829494930913, 0.9577198106144904, 0.5729860958751898], 
             UndirectedEdge[352, 379] -> 
             RGBColor[
              0.9902189048253796, 0.9889809532268252, 0.7214575460143895], 
             UndirectedEdge[25, 194] -> 
             RGBColor[
              0.9654817551654791, 0.9729593270645842, 0.9067006324977436], 
             UndirectedEdge[174, 238] -> 
             RGBColor[
              0.618806799545152, 0.6855432218639086, 0.9202966785917799], 
             UndirectedEdge[66, 339] -> 
             RGBColor[
              0.9892263311526076, 0.9748741195242983, 0.45056347759740656`], 
             UndirectedEdge[67, 387] -> 
             RGBColor[
              0.964774401522623, 0.8924197056075414, 0.319833731763632], 
             UndirectedEdge[90, 190] -> 
             RGBColor[
              0.9340922802802558, 0.9495674900187021, 0.9687392620388037], 
             UndirectedEdge[271, 389] -> 
             RGBColor[
              0.9460722478303067, 0.8095946067411095, 0.42972996433867455`], 
             UndirectedEdge[19, 293] -> 
             RGBColor[
              0.9833670236818546, 0.9682407261283886, 0.6352616247630014], 
             UndirectedEdge[126, 327] -> 
             RGBColor[
              0.9895791829090856, 0.988778619929972, 0.7365812699268098], 
             UndirectedEdge[12, 310] -> 
             RGBColor[
              0.95926588822833, 0.8692644918861718, 0.3222541307691558], 
             UndirectedEdge[272, 350] -> 
             RGBColor[
              0.8948696738386466, 0.8739307386083675, 0.6443465331130932], 
             UndirectedEdge[215, 229] -> 
             RGBColor[
              0.9265320107046893, 0.7192977336125714, 0.45437316509569114`], 
             UndirectedEdge[57, 189] -> 
             RGBColor[
              0.9913394708157358, 0.9906866628639283, 0.7931909115217237], 
             UndirectedEdge[104, 337] -> 
             RGBColor[
              0.9252039234327514, 0.7346231513597905, 0.552670870299039], 
             UndirectedEdge[194, 385] -> 
             RGBColor[
              0.9857052144182769, 0.9880419498624455, 0.8724675911056837], 
             UndirectedEdge[56, 166] -> 
             RGBColor[
              0.9918297405208651, 0.9902552752004404, 0.7389715505770138], 
             UndirectedEdge[258, 379] -> 
             RGBColor[
              0.9907626967322791, 0.9904481519580011, 0.8027495507280802], 
             UndirectedEdge[9, 150] -> 
             RGBColor[
              0.9419867916356239, 0.9538250347595613, 0.8856998748277534], 
             UndirectedEdge[294, 380] -> 
             RGBColor[
              0.9559338685887996, 0.9640747498373323, 0.83993373306069], 
             UndirectedEdge[296, 308] -> 
             RGBColor[
              0.9679814483797959, 0.9722312729895983, 0.7322022567609214], 
             UndirectedEdge[33, 92] -> 
             RGBColor[
              0.9390342312486494, 0.7965557790697666, 0.5605521632259377], 
             UndirectedEdge[39, 283] -> 
             RGBColor[
              0.9035164606753436, 0.614218937480155, 0.5528198218958382], 
             UndirectedEdge[11, 34] -> 
             RGBColor[
              0.9817098983492762, 0.9573361942721016, 0.5920892808390265], 
             UndirectedEdge[105, 171] -> 
             RGBColor[
              0.9862771603828983, 0.9867386153492623, 0.7696625445010156], 
             UndirectedEdge[110, 237] -> 
             RGBColor[
              0.9790604771782171, 0.9538142702569057, 0.6192264108155823], 
             UndirectedEdge[8, 175] -> 
             RGBColor[
              0.9440213941650173, 0.9563992196890675, 0.9272264678695947], 
             UndirectedEdge[90, 373] -> 
             RGBColor[
              0.949436857973871, 0.9583927607902923, 0.7986649499390606], 
             UndirectedEdge[73, 104] -> 
             RGBColor[
              0.9291507723800588, 0.7343096967171266, 0.34583837896572844`], 
             UndirectedEdge[232, 339] -> 
             RGBColor[
              0.9876381891731065, 0.9759914925054356, 0.6058422052864685], 
             UndirectedEdge[178, 274] -> 
             RGBColor[
              0.9630455805632618, 0.888336910436573, 0.5468228943896088], 
             UndirectedEdge[224, 318] -> 
             RGBColor[
              0.9892891349783458, 0.9898387963039399, 0.8271702824463316], 
             UndirectedEdge[132, 307] -> 
             RGBColor[
              0.9783304035931595, 0.9813489041849774, 0.8257203686539916]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.9743118360261269, 0.9250099324277052, 0.3547067630745686], 
             316 -> RGBColor[
              0.9948556321378403, 0.9914050422552441, 0.6814454894413615], 
             308 -> RGBColor[
              0.9930316638484796, 0.9875037585157836, 0.48291779737191565`], 
             160 -> 
             RGBColor[
              0.9946655893129636, 0.9909985598691095, 0.6607605007618804], 
             245 -> RGBColor[
              0.9941950329082996, 0.9918675111738018, 0.7458668576901363], 
             155 -> RGBColor[
              0.8403151102492151, 0.8755084754394381, 0.9846311994453665], 
             213 -> RGBColor[
              0.896679470359131, 0.6237274306711471, 0.23549915626077808`], 
             352 -> RGBColor[
              0.9938419326416088, 0.9892368415335454, 0.5711105551046805], 27 -> 
             RGBColor[
              0.9889310946938675, 0.9896907374450926, 0.8331039365386905], 
             367 -> RGBColor[
              0.9815878874647854, 0.98578885713508, 0.9160510832607927], 19 -> 
             RGBColor[
              0.9811831585657033, 0.9481885168169526, 0.38140055360044167`], 
             164 -> RGBColor[
              0.9770616168309464, 0.9824131719074508, 0.9237128788034341], 
             190 -> RGBColor[
              0.9634784408568274, 0.9722828615063622, 0.9467056526679408], 
             103 -> RGBColor[
              0.9666598497837777, 0.9746555510750027, 0.9413203571989528], 
             138 -> RGBColor[
              0.9872560751687145, 0.9889980738254035, 0.8608633448820527], 
             291 -> RGBColor[
              0.9924047413499983, 0.9860415505013161, 0.4249942836993324], 28 -> 
             RGBColor[
              0.897825790932437, 0.6289326046645577, 0.2364556742460331], 337 -> 
             RGBColor[
              0.9851330472678421, 0.9881201472290644, 0.896047411419593], 195 -> 
             RGBColor[
              0.9948820974651904, 0.9921516300248299, 0.7344804199163797], 
             114 -> RGBColor[
              0.9891423556246118, 0.9897780992691136, 0.8296027961904938], 93 -> 
             RGBColor[
              0.9869328401529732, 0.9888644078396335, 0.8662201855982905], 34 -> 
             RGBColor[
              0.9891422275385692, 0.9897780463022433, 0.8296049189076977], 
             161 -> RGBColor[
              0.9951878503171715, 0.9921156233484228, 0.7176053880486043], 22 -> 
             RGBColor[
              0.9942325610199864, 0.9900723561363075, 0.613628043412162], 124 -> 
             RGBColor[
              0.8734443218888611, 0.901924809532398, 0.9877910932263523], 84 -> 
             RGBColor[
              0.8262110762691934, 0.8642623015875723, 0.9832859440935323], 46 -> 
             RGBColor[
              0.9793334471177425, 0.9419490057700797, 0.3742147739138114], 
             241 -> RGBColor[
              0.994350585550062, 0.9919318361886911, 0.7432889478588012], 185 -> 
             RGBColor[
              0.880667585014493, 0.5510211989919807, 0.22213844664198734`], 
             390 -> RGBColor[
              0.9898038969746377, 0.9900516636181865, 0.8186393440064321], 
             121 -> RGBColor[
              0.9886272559616552, 0.9895650923210235, 0.8381393306408812], 
             322 -> RGBColor[
              0.9561085811171652, 0.8636060792922702, 0.2839905551494998], 
             126 -> RGBColor[
              0.9852443233789203, 0.9881661627606608, 0.8942032782856841], 
             236 -> RGBColor[
              0.9931401487354302, 0.9877357967194664, 0.49472570782537495`], 
             78 -> RGBColor[
              0.9355999193880387, 0.9514859958094936, 0.9937195496027807], 
             376 -> RGBColor[
              0.9913741630714276, 0.9907010090032071, 0.7926159710642317], 
             254 -> RGBColor[
              0.9104041165780514, 0.9313955465706577, 0.9913163514382055], 
             290 -> RGBColor[
              0.864711481376519, 0.47856825901462574`, 0.2088242826465716], 
             251 -> RGBColor[
              0.9779631593440928, 0.983085540837615, 0.9221868024886228], 165 -> 
             RGBColor[
              0.9914350513887955, 0.9907261878871971, 0.7916068940715306], 
             100 -> RGBColor[
              0.9884372460256217, 0.989486518329441, 0.8412882870109101], 235 -> 
             RGBColor[
              0.9872296672423319, 0.9889871534691915, 0.8613009925637346], 70 -> 
             RGBColor[
              0.9050188550438306, 0.6611384413787375, 0.24243414515549291`], 
             234 -> RGBColor[
              0.9857706293096953, 0.9883838037884818, 0.8854810269766552], 
             257 -> RGBColor[
              0.9887039198064792, 0.9735578104408049, 0.41061729084426724`], 
             135 -> RGBColor[
              0.9784414772504558, 0.9834422695490068, 0.9213771350384401], 
             265 -> RGBColor[
              0.9937986365155432, 0.9891442354978011, 0.5663980389751611], 
             111 -> RGBColor[
              0.8734443218888611, 0.901924809532398, 0.9877910932263523], 381 -> 
             RGBColor[
              0.9900790157506029, 0.9901654323022782, 0.8140799139041213], 
             182 -> RGBColor[
              0.9511585478028265, 0.8440669480269941, 0.2795592249871668], 
             188 -> RGBColor[
              0.9919999921379923, 0.990959805405305, 0.7822443638375476], 154 -> 
             RGBColor[
              0.9931695275909975, 0.987798635120867, 0.4979234149485964], 336 -> 
             RGBColor[
              0.9031713269809496, 0.9256283164747721, 0.9906264815096465], 
             315 -> RGBColor[
              0.9551721256234076, 0.8599794466400738, 0.2827886439123861], 
             368 -> RGBColor[
              0.9600613720093623, 0.9697344171548594, 0.9524898589124097], 
             269 -> RGBColor[
              0.9675403992333185, 0.9021682861165946, 0.3284010098130484], 
             208 -> RGBColor[
              0.9176236124589634, 0.7111121042433266, 0.25257622884339204`], 
             86 -> RGBColor[
              0.9837499409536165, 0.956846876520549, 0.39137201848130293`], 
             119 -> RGBColor[
              0.9936916356216399, 0.9916593434590478, 0.7542094534805058], 
             377 -> RGBColor[
              0.8728240739309844, 0.5154056470603232, 0.2155936287318578], 
             140 -> RGBColor[
              0.9527587033482013, 0.964288098824388, 0.9648513721147287], 85 -> 
             RGBColor[
              0.9933936108804234, 0.9882779266186532, 0.5223134981208528], 
             351 -> RGBColor[
              0.8630895568219245, 0.8936682009406328, 0.98680344649046], 242 -> 
             RGBColor[
              0.8729955719225209, 0.5161843793855168, 0.21573673085979628`], 
             117 -> RGBColor[
              0.9258400539468497, 0.7436875567759781, 0.25918737052921476`], 
             47 -> RGBColor[
              0.8340200559088429, 0.2624986341647308, 0.18021094999945272`], 
             81 -> RGBColor[
              0.9945022138477219, 0.990649116268751, 0.6429780896068295], 275 -> 
             RGBColor[
              0.951281579268198, 0.9631864621040903, 0.9673517578865134], 23 -> 
             RGBColor[
              0.9100405428804852, 0.6810477602728002, 0.24647471306302837`], 
             328 -> RGBColor[
              0.9847573405823357, 0.9602450720169001, 0.39528557580742013`], 
             110 -> RGBColor[
              0.9726380024445719, 0.9193636987223055, 0.3482042356871763], 6 -> 
             RGBColor[
              0.9950629069602337, 0.9918483821416441, 0.7040060747069435], 
             218 -> RGBColor[
              0.9593770207132957, 0.8746312935161303, 0.29668782578743946`], 
             108 -> RGBColor[
              0.9898109939568714, 0.9900545984027244, 0.8185217286444173], 
             297 -> RGBColor[
              0.9461785626842951, 0.8243229665136826, 0.27555221206552183`], 
             157 -> RGBColor[
              0.9901404999734514, 0.9784037326690662, 0.4161981335175535], 
             354 -> RGBColor[
              0.99345507840305, 0.9884093994342315, 0.5290038586251691], 385 -> 
             RGBColor[
              0.9822971514516589, 0.986317825055177, 0.9148504843366905], 270 -> 
             RGBColor[
              0.8119903270870912, 0.8530522819662713, 0.9818952653891618], 
             392 -> RGBColor[
              0.23032979965715525`, 0.3594216015654066, 0.9364283133968475], 
             33 -> RGBColor[
              0.8925150036348286, 0.6048175599120048, 0.23202422314559976`], 
             252 -> RGBColor[
              0.8631600337517608, 0.893724397331439, 0.9868101686429432], 394 -> 
             RGBColor[
              0.9396396942677109, 0.9545039633325642, 0.987058432502437], 260 -> 
             RGBColor[
              0.9943496115446381, 0.9903227153729144, 0.6263682706684061], 
             159 -> RGBColor[
              0.9948042586080973, 0.9921194416570545, 0.735770411218918], 183 -> 
             RGBColor[
              0.9804935515655266, 0.9849727032132233, 0.9179035084897238], 99 -> 
             RGBColor[
              0.9898165458615376, 0.9773109593815379, 0.4149396329663687], 
             329 -> RGBColor[
              0.9933123697464397, 0.9881041600478006, 0.51347090204888], 309 -> 
             RGBColor[
              0.9133813357717029, 0.6942928908332422, 0.24916279344179004`], 
             17 -> RGBColor[
              0.9897734772645105, 0.990039084286298, 0.8191434773269266], 349 -> 
             RGBColor[
              0.9865958770091503, 0.9887250649201049, 0.8718045369240984], 
             347 -> RGBColor[
              0.9703985035061528, 0.9118093429436609, 0.339504205205306], 340 -> 
             RGBColor[
              0.9937230854136836, 0.9889826393303114, 0.5581747677850892], 
             277 -> RGBColor[
              0.9641698814758806, 0.8907987382855524, 0.31530718479427267`], 
             104 -> RGBColor[
              0.8652747995976606, 0.4811261554905165, 0.20929432917848528`], 
             79 -> RGBColor[
              0.9907576703959716, 0.990446073438767, 0.8028328501284367], 327 -> 
             RGBColor[
              0.9939140424392509, 0.989391077099283, 0.5789592615679355], 191 -> 
             RGBColor[
              0.9632689653719253, 0.9721266350327069, 0.9470602400239236], 50 -> 
             RGBColor[
              0.9901424702606844, 0.9784103789105484, 0.41620578771139594`], 
             225 -> RGBColor[
              0.9822685415159366, 0.9518497683681256, 0.3856170614047267], 61 -> 
             RGBColor[
              0.977952614987214, 0.9830776768735195, 0.92220465133441], 196 -> 
             RGBColor[
              0.9925112525188446, 0.9911712247115799, 0.77377145622737], 1 -> 
             RGBColor[
              0.9828879759502404, 0.9539392661651541, 0.38802344721161935`], 
             263 -> RGBColor[
              0.9947000353336547, 0.9920763426546565, 0.7374976605976193], 
             201 -> RGBColor[
              0.9934254955126745, 0.9883461246230072, 0.52578394357223], 371 -> 
             RGBColor[
              0.9719845089937535, 0.9786266731954734, 0.932307098050002], 293 -> 
             RGBColor[
              0.985550888798006, 0.9882929354398247, 0.889122695925561], 362 -> 
             RGBColor[
              0.963785886572552, 0.9725121540177535, 0.9461852272659041], 184 -> 
             RGBColor[
              0.9500471661004417, 0.839660689923036, 0.27866498118194655`], 
             106 -> RGBColor[
              0.9229635341012157, 0.7322831141314547, 0.25687285514081887`], 
             206 -> RGBColor[
              0.9616201033293517, 0.9708969164211192, 0.9498513333699057], 
             358 -> RGBColor[
              0.993463584307073, 0.9884275927028578, 0.5299296737857209], 247 -> 
             RGBColor[
              0.9927852347550638, 0.9912845234072789, 0.769230861529921], 220 -> 
             RGBColor[
              0.9462295925845692, 0.824525283063563, 0.27559327192110805`], 
             107 -> RGBColor[
              0.9858174120590975, 0.9884031496576214, 0.8847057157491861], 
             375 -> RGBColor[
              0.950398431519267, 0.8410533402564165, 0.2789476175831925], 131 -> 
             RGBColor[
              0.8526162229044321, 0.8853170487659001, 0.985804490551754], 127 -> 
             RGBColor[
              0.9740297367276979, 0.9240583452540388, 0.35361086057015423`], 
             210 -> RGBColor[
              0.9013230048774955, 0.644812636394, 0.23937383528634812`], 357 -> 
             RGBColor[
              0.9584084530213195, 0.8713640872605855, 0.29292512320277275`], 
             181 -> RGBColor[
              0.9101912531427553, 0.9312258150453765, 0.9912960483337215], 
             194 -> RGBColor[
              0.9891132773848949, 0.989766074669714, 0.830084697874677], 118 -> 
             RGBColor[
              0.9927892013164379, 0.9869851556764687, 0.4565272470644719], 
             348 -> RGBColor[
              0.9501733028241847, 0.8401607800001054, 0.27876647375067953`], 
             276 -> RGBColor[
              0.9596011376605124, 0.8753872926042535, 0.29755847780644173`], 
             305 -> 
             RGBColor[
              0.9949750320115286, 0.9916604265118842, 0.6944414288417211], 
             343 -> RGBColor[
              0.9664369629487287, 0.898446136429513, 0.3241143682138749], 280 -> 
             RGBColor[
              0.7839751360551594, 0.8311666018087884, 0.979102972963944], 189 -> 
             RGBColor[
              0.9921707792323118, 0.9910304302578342, 0.7794139797018412], 
             168 -> RGBColor[
              0.9636409639906356, 0.8890145754120896, 0.3132524402417817], 
             363 -> RGBColor[
              0.9802660099727561, 0.9450947592562117, 0.37783760450582105`], 
             41 -> RGBColor[
              0.9714413449397767, 0.9153270919700877, 0.3435554472508552], 14 -> 
             RGBColor[
              0.9324715808643752, 0.769979351178622, 0.264523252748999], 77 -> 
             RGBColor[
              0.962948206035669, 0.9718874132449221, 0.9476032019127724], 51 -> 
             RGBColor[
              0.9947057185988575, 0.9920786928308711, 0.7374034741853904], 
             179 -> RGBColor[
              0.8328185873014375, 0.8695309515285748, 0.9839161743943825], 
             223 -> RGBColor[
              0.9929283899682345, 0.9913437217668462, 0.7668584091738654], 
             323 -> RGBColor[
              0.9926521056871035, 0.986691921987817, 0.4416052338675804], 292 -> 
             RGBColor[
              0.9750000679920658, 0.9273315004533677, 0.35738041430054024`], 
             396 -> RGBColor[
              0.969951033888546, 0.9771101107915195, 0.9357492409878707], 321 -> 
             RGBColor[
              0.937194146864947, 0.7887027516690593, 0.26832314020593034`], 
             143 -> RGBColor[
              0.9884370123552813, 0.9894864217007502, 0.8412921595331702], 
             112 -> RGBColor[
              0.9855020575731862, 0.9882727424734564, 0.8899319556919844], 
             197 -> RGBColor[
              0.9900779921305825, 0.9901650090090939, 0.8140968779369032], 54 -> 
             RGBColor[
              0.9936283996253691, 0.9916331937494989, 0.7552574375882243], 71 -> 
             RGBColor[
              0.9934044065597317, 0.988301017485083, 0.5234885411903494], 177 -> 
             RGBColor[
              0.9472958610931247, 0.8287526823870683, 0.27645121659163047`], 
             158 -> RGBColor[
              0.9850309628531465, 0.988077932700138, 0.8977392143570954], 226 -> 
             RGBColor[
              0.8491719113609713, 0.8825706482344907, 0.9854759690419655], 
             350 -> RGBColor[
              0.9615734844949588, 0.8820404816059013, 0.30522067281181986`], 
             203 -> RGBColor[
              0.9795948730023876, 0.9428308566647041, 0.3752303641095216], 
             115 -> RGBColor[
              0.9720885055344193, 0.9175101166163505, 0.34606954395501766`], 
             173 -> RGBColor[
              0.9577464093279455, 0.9680079217774623, 0.9564084868930827], 
             212 -> RGBColor[
              0.9444133411367881, 0.8173244513030274, 0.2741318733733225], 
             129 -> RGBColor[
              0.8943285769873786, 0.6130525729351161, 0.23353751320571817`], 
             279 -> RGBColor[
              0.9919580136181299, 0.9909424462085432, 0.7829400565485936], 26 -> 
             RGBColor[
              0.9512518521540752, 0.9631642916710511, 0.9674020781366502], 40 -> 
             RGBColor[
              0.8884053622073753, 0.9138543369757604, 0.9892180906078105], 
             146 -> RGBColor[
              0.9864102245774485, 0.9886482928685464, 0.8748812781704897], 
             386 -> RGBColor[
              0.8808827647214047, 0.5519982797845686, 0.2223179978639716], 
             192 -> RGBColor[
              0.9879881316313603, 0.9893007979857005, 0.8487312747946147], 
             300 -> RGBColor[
              0.9675742665710393, 0.9022825285991559, 0.32853257802478364`], 
             221 -> RGBColor[
              0.9688886689431359, 0.9763178007546955, 0.9375475477312962], 62 -> 
             RGBColor[
              0.9928868053020993, 0.991326525438722, 0.7675475747093934], 286 -> 
             RGBColor[
              0.9901912486747908, 0.9902118435006845, 0.8122199239008298], 
             152 -> RGBColor[
              0.9938598886658745, 0.9892752476538171, 0.5730649575342572], 64 -> 
             RGBColor[
              0.9924795345788142, 0.9911581085282635, 0.7742971045770716], 
             307 -> RGBColor[
              0.9616201033293517, 0.9708969164211192, 0.9498513333699057], 37 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 148 -> 
             RGBColor[
              0.9865958770091503, 0.9887250649201049, 0.8718045369240984], 
             261 -> RGBColor[
              0.9616201033293517, 0.9708969164211192, 0.9498513333699057], 
             387 -> RGBColor[
              0.9750000679920658, 0.9273315004533677, 0.35738041430054024`], 
             15 -> RGBColor[
              0.9951023043005559, 0.9919326490689112, 0.7082942320688198], 
             136 -> RGBColor[
              0.9951692481390354, 0.9920758351703585, 0.7155806557578265], 
             198 -> 
             RGBColor[
              0.9787779018260002, 0.9400750210527951, 0.3720565853613178], 63 -> 
             RGBColor[
              0.9677668596092648, 0.9754811571902887, 0.9394464783188067], 
             310 -> RGBColor[
              0.9794495878180762, 0.9423407756234382, 0.3746659586032766], 
             171 -> RGBColor[
              0.994269808965373, 0.9901520257251447, 0.6176822523998323], 395 -> 
             RGBColor[
              0.9563182961185036, 0.9669428372841813, 0.9588259100450891], 
             311 -> RGBColor[
              0.9940572475472641, 0.9896973783450658, 0.5945462538156866], 
             353 -> RGBColor[
              0.9742775691599832, 0.9248943422419599, 0.3545736427703552], 59 -> 
             RGBColor[
              0.9351745822349072, 0.9511468435090561, 0.9936789805654122], 
             397 -> RGBColor[
              0.9243727133931977, 0.9425337265035956, 0.9926486886723478], 
             229 -> RGBColor[
              0.9950774131375195, 0.991879409388059, 0.705584982582756], 102 -> 
             RGBColor[
              0.9897594900686549, 0.9900333002213573, 0.819375281359956], 299 -> 
             RGBColor[
              0.9949647064547469, 0.9916383411900019, 0.6933175557079766], 
             128 -> RGBColor[
              0.9481894146404685, 0.8322953244432179, 0.2771701907502207], 12 -> 
             RGBColor[
              0.939082188638584, 0.7961882081489056, 0.269842302935035], 222 -> 
             RGBColor[
              0.977952614987214, 0.9830776768735195, 0.92220465133441], 92 -> 
             RGBColor[
              0.9855534588624701, 0.9882939982275283, 0.8890801033062757], 
             271 -> RGBColor[
              0.897825790932437, 0.6289326046645577, 0.2364556742460331], 361 -> 
             RGBColor[
              0.9616201033293517, 0.9708969164211192, 0.9498513333699057], 
             344 -> RGBColor[
              0.8555595183559133, 0.4280603811855427, 0.20083716356411074`], 
             132 -> RGBColor[
              0.9950407038569674, 0.9918008919488356, 0.7015894039380773], 80 -> 
             RGBColor[
              0.9936358743966383, 0.9887961037832378, 0.5486823867837146], 
             324 -> RGBColor[
              0.9607844382046103, 0.9702736787393632, 0.9512658964497217], 
             244 -> RGBColor[
              0.864401525511105, 0.4771608218218126, 0.2085656478747567], 150 -> 
             RGBColor[
              0.9920241729877886, 0.9909698048081153, 0.7818436245783902], 
             125 -> RGBColor[
              0.9481774114944309, 0.8322477359689906, 0.2771605327371689], 
             258 -> RGBColor[
              0.994929516455408, 0.9921712389958973, 0.7336945645320619], 133 -> 
             RGBColor[
              0.952126172277477, 0.9638163581875164, 0.9659220822269403], 255 -> 
             RGBColor[
              0.9950414988934475, 0.991802592451476, 0.7016759387525393], 326 -> 
             RGBColor[
              0.9875217940773484, 0.9891079554227881, 0.8564596949074967], 
             176 -> RGBColor[
              0.994934183495227, 0.9915730556659336, 0.6899953199301123], 230 -> 
             RGBColor[
              0.99443612243662, 0.9905077534232709, 0.6357844473773067], 274 -> 
             RGBColor[
              0.9893773035748878, 0.9898752562844396, 0.8257091006286167], 87 -> 
             RGBColor[
              0.9143544283916373, 0.6981508788073887, 0.24994576660520865`], 
             130 -> RGBColor[
              0.9847573405823357, 0.9602450720169001, 0.39528557580742013`], 
             35 -> RGBColor[
              0.9683382840446508, 0.9048597389374815, 0.3315006416371711], 
             379 -> RGBColor[
              0.9865958770091503, 0.9887250649201049, 0.8718045369240984], 31 -> 
             RGBColor[
              0.9844603247770298, 0.9878419591909341, 0.9071961640423525], 18 -> 
             RGBColor[
              0.948895252039341, 0.8350937345233774, 0.2777381240894867], 24 -> 
             RGBColor[
              0.9880591674148439, 0.9893301731077073, 0.8475540280275774], 
             151 -> RGBColor[
              0.9937825238794564, 0.9891097721984488, 0.5646442779727734], 
             137 -> RGBColor[
              0.8350096993998908, 0.8712780848397279, 0.9841251646223618], 
             330 -> RGBColor[
              0.9396396942677109, 0.9545039633325642, 0.987058432502437], 296 -> 
             RGBColor[
              0.9429312329111124, 0.9569587874634131, 0.9814867161499273], 
             266 -> RGBColor[
              0.9350746867484675, 0.7802997985754342, 0.26661777284608795`], 
             302 -> RGBColor[
              0.8945252793056907, 0.6139457522215781, 0.2337016464417329], 
             283 -> RGBColor[
              0.9749513580397865, 0.9808393443562353, 0.9272849964932275], 
             388 -> RGBColor[
              0.9087021611493437, 0.6757415226980977, 0.24539781970629504`], 
             284 -> RGBColor[
              0.989116860529603, 0.9897675563921334, 0.8300253158939809], 318 -> 
             RGBColor[
              0.99014102393107, 0.9901910742784389, 0.8130522778817533], 238 -> 
             RGBColor[
              0.2528928411142352, 0.38313678871625234`, 0.9377132452287996], 
             72 -> RGBColor[
              0.9674096768035977, 0.9752147708386554, 0.9400510956406054], 
             288 -> RGBColor[
              0.9830165720219606, 0.9868543677385649, 0.9136326929661053], 
             382 -> RGBColor[
              0.9584084530213195, 0.8713640872605855, 0.29292512320277275`], 
             389 -> RGBColor[
              0.9943187047281764, 0.9902566088176613, 0.623004254431316], 172 -> 
             RGBColor[
              0.99306286757621, 0.9875705001342181, 0.48631413056828365`], 
             243 -> RGBColor[
              0.9943181324815801, 0.9902553848400546, 0.6229419689207928], 88 -> 
             RGBColor[
              0.9888447531595371, 0.9740328744099133, 0.4111644018267503], 
             273 -> RGBColor[
              0.9869665896929938, 0.9676973880235092, 0.4038680914206393], 
             202 -> RGBColor[
              0.9938481032982366, 0.9892500399441232, 0.5717821929977339], 
             393 -> RGBColor[
              0.9664872379989535, 0.9745268174885067, 0.9416125439262966], 98 -> 
             RGBColor[
              0.9801761790278822, 0.9447917383858431, 0.37748862824813645`], 
             30 -> RGBColor[
              0.9865306128830749, 0.9886980765267612, 0.872886132391314], 116 -> 
             RGBColor[
              0.9904755600209098, 0.990329413548773, 0.8075081491214602], 373 -> 
             RGBColor[
              0.9941675962440577, 0.9899334030495426, 0.6065570284684545], 
             240 -> RGBColor[
              0.9939612943824716, 0.9894921442279278, 0.5841023439823171], 
             317 -> RGBColor[
              0.972701869020749, 0.9195791356803358, 0.34845234527543323`], 
             391 -> RGBColor[
              0.9858985086019662, 0.9884366851621837, 0.8833617361627262], 73 -> 
             RGBColor[
              0.993026745162457, 0.9874932379437368, 0.4823824287529716], 303 -> 
             RGBColor[
              0.9718940655502235, 0.9168542248929787, 0.34531418133332703`], 
             29 -> RGBColor[
              0.957826216273993, 0.8694000659961638, 0.2906632433855933], 360 -> 
             RGBColor[
              0.9746475114495754, 0.9261422444513344, 0.35601079870768115`], 
             320 -> RGBColor[
              0.9396396942677109, 0.9545039633325642, 0.987058432502437], 75 -> 
             RGBColor[
              0.9947124151158158, 0.9910987155265956, 0.6658572004269913], 
             200 -> RGBColor[
              0.4942040514631089, 0.6002561384733801, 0.9533246997417173], 
             301 -> RGBColor[
              0.9018946610596486, 0.9246103377233, 0.9905047119743796], 156 -> 
             RGBColor[
              0.9742239384730305, 0.9247134333417838, 0.35436529767884883`], 
             25 -> RGBColor[
              0.9418502329460632, 0.9561525794594544, 0.9833165671208103], 38 -> 
             RGBColor[
              0.9895667687271889, 0.9899536049939485, 0.822569172734893], 365 -> 
             RGBColor[
              0.9104041165780514, 0.9313955465706577, 0.9913163514382055], 
             380 -> RGBColor[
              0.9169525607471003, 0.9366170981982755, 0.9919409478889145], 
             370 -> RGBColor[
              0.994860077593366, 0.9914145506351089, 0.6819293498411522], 3 -> 
             RGBColor[
              0.7205676449525134, 0.7816321878446202, 0.9727831068275259], 57 -> 
             RGBColor[
              0.9905081623991598, 0.9903428954700223, 0.8069678433416062], 
             227 -> RGBColor[
              0.8322852172659485, 0.8691056567402198, 0.9838653010842525], 39 -> 
             RGBColor[
              0.8320815633109008, 0.24759853060407463`, 0.17835464729844908`],
              109 -> RGBColor[
              0.9933428303696104, 0.988169312240721, 0.5167863528998273], 256 -> 
             RGBColor[
              0.9952815235354041, 0.9923159808904074, 0.7278011397691386], 
             339 -> RGBColor[
              0.9852271571178044, 0.9618298735092046, 0.3971107243303079], 
             287 -> RGBColor[
              0.989673707260877, 0.9899978268258235, 0.8207969244836264], 239 -> 
             RGBColor[
              0.9216787013545821, 0.7271891804361847, 0.25583904855397677`], 
             285 -> RGBColor[
              0.957876794321398, 0.8695706776263514, 0.29085972954889916`], 
             345 -> RGBColor[
              0.9563182961185036, 0.9669428372841813, 0.9588259100450891], 
             366 -> RGBColor[
              0.9947638388217537, 0.9912087056338625, 0.6714543534680067], 
             216 -> RGBColor[
              0.9943041742801012, 0.990225529658482, 0.6214227048298536], 21 -> 
             RGBColor[
              0.993395861717036, 0.9882827409305729, 0.5225584877955738], 355 -> 
             RGBColor[
              0.964107874405211, 0.9727522920161439, 0.945640185853089], 175 -> 
             RGBColor[
              0.9870646567674207, 0.98891891739724, 0.8640356431664327], 7 -> 
             RGBColor[
              0.9756719670207536, 0.9295979736465257, 0.3599906151495073], 13 -> 
             RGBColor[
              0.9951407338489145, 0.992014845987027, 0.7124770512479781], 294 -> 
             RGBColor[
              0.9949151764304989, 0.9915324014763892, 0.6879265182324653], 
             193 -> RGBColor[
              0.9800001358059803, 0.9441979032614539, 0.37680473357402067`], 
             60 -> RGBColor[
              0.9934849012828627, 0.9915738534971333, 0.7576355764853618], 65 -> 
             RGBColor[
              0.9947383209771076, 0.9920921747521204, 0.7368631684055362], 69 -> 
             RGBColor[
              0.9910522145862081, 0.9905678750308702, 0.7979514906402906], 
             217 -> RGBColor[
              0.9940046528131637, 0.9895848835269684, 0.5888216415859391], 
             214 -> RGBColor[
              0.8491719113609713, 0.8825706482344907, 0.9854759690419655], 
             170 -> RGBColor[
              0.9925333932364397, 0.991180380467296, 0.7734045272384802], 359 -> 
             RGBColor[
              0.8219961704796894, 0.8609014501215917, 0.9828839226166386], 74 -> 
             RGBColor[
              0.9867904160366081, 0.9671031129129786, 0.4031836900331841], 
             246 -> RGBColor[
              0.9901254682777341, 0.9901846416160224, 0.8133100753142701], 
             264 -> RGBColor[
              0.9935401835764172, 0.9915967141462082, 0.7567194058151748], 
             278 -> RGBColor[
              0.9895008684582056, 0.9899263535391642, 0.8236613107363742], 45 -> 
             RGBColor[
              0.8819720949915795, 0.5569446741218838, 0.22322696174333378`], 
             306 -> RGBColor[
              0.8119903270870912, 0.8530522819662713, 0.9818952653891618], 
             237 -> RGBColor[
              0.9854829519118623, 0.988264841791506, 0.8902485859439881], 228 -> 
             RGBColor[
              0.9884642142502473, 0.9894976703833755, 0.8408413537373344], 
             180 -> RGBColor[
              0.9651491187540724, 0.9735288503466435, 0.9438776307704866], 
             383 -> RGBColor[
              0.8677419794183883, 0.4923290428319542, 0.2113530044970119], 53 -> 
             RGBColor[
              0.9687284348161009, 0.9061758091013402, 0.33301630371046376`], 
             304 -> RGBColor[
              0.9948116763281702, 0.9921225090749314, 0.7356474804008648], 48 -> 
             RGBColor[
              0.9935981248373978, 0.9916206743466462, 0.755759169173549], 5 -> 
             RGBColor[
              0.9852070014068534, 0.9881507291660803, 0.8948217999490007], 
             101 -> RGBColor[
              0.9867609265490414, 0.9887933171464296, 0.8690692389135868], 
             333 -> RGBColor[
              0.846792829209846, 0.3606757668211903, 0.19244217213727746`], 
             267 -> RGBColor[
              0.9877581834027196, 0.9892057084837577, 0.8525421120301309], 
             120 -> RGBColor[
              0.993144450926217, 0.9877449986705409, 0.49519397474246246`], 
             147 -> RGBColor[
              0.8332072186897712, 0.2562508111114053, 0.17943257616050134`], 
             89 -> RGBColor[
              0.9579404327247287, 0.9681526241090991, 0.9560800558917352], 43 -> 
             RGBColor[
              0.9205574605660656, 0.7227438343410605, 0.2549368718966325], 
             199 -> RGBColor[
              0.9521218064797659, 0.8478859476941328, 0.28033428552921935`], 
             268 -> RGBColor[
              0.9849191832705748, 0.9880317089701404, 0.8995916913165952], 
             169 -> RGBColor[
              0.975762864844181, 0.9299045933487701, 0.3603437360289089], 20 -> 
             RGBColor[
              0.24406890634008505`, 0.3738622737988424, 0.9372107351972535], 
             4 -> RGBColor[
              0.9484655253352116, 0.8333900113394398, 0.277392355896362], 167 -> 
             RGBColor[
              0.9823444695275373, 0.9521058913799997, 0.3859120273919935], 
             142 -> RGBColor[
              0.9829163071380468, 0.9867795903523107, 0.9138024152613013], 16 -> 
             RGBColor[
              0.8573999889370166, 0.8891314939484133, 0.9862607704264603], 
             281 -> RGBColor[
              0.9873052944400855, 0.989018427258993, 0.8600476541800427], 289 -> 
             RGBColor[
              0.993193434661414, 0.9878497699271122, 0.5005255520260921], 398 -> 
             RGBColor[
              0.9630290766615298, 0.8869505357730391, 0.3108753735134325], 
             178 -> RGBColor[
              0.9367138575516358, 0.7867985645887066, 0.267936688150601], 58 -> 
             RGBColor[
              0.8470764299196405, 0.36285564615129445`, 0.1927137484972579], 
             186 -> RGBColor[
              0.9677642584322084, 0.9029234157590897, 0.3292706605284732], 
             122 -> RGBColor[
              0.9946395839956598, 0.9909429371249378, 0.6579299824595872], 
             249 -> RGBColor[
              0.9903648721733915, 0.9902836412792763, 0.8093425332058041], 
             113 -> RGBColor[
              0.9940493075891211, 0.9896803955774509, 0.5936820383715709], 52 -> 
             RGBColor[
              0.9469458791491044, 0.9599529040543278, 0.9746909672564412], 
             187 -> 
             RGBColor[
              0.9919410184091907, 0.9909354182528899, 0.7832217111429072], 
             259 -> RGBColor[
              0.9934500176240693, 0.9915594282077531, 0.7582136889875835], 42 -> 
             RGBColor[
              0.9917388452287326, 0.983795326524442, 0.42240740301214574`], 
             134 -> RGBColor[
              0.9586134073685681, 0.9686545274965797, 0.9549408853596129], 
             313 -> RGBColor[
              0.9932515780991339, 0.9879741328611917, 0.5068541064022021], 
             248 -> RGBColor[
              0.9885186158788135, 0.9895201668548457, 0.8399397779650916], 
             174 -> RGBColor[
              0.9847207579760688, 0.9879496550115647, 0.9028801119547603], 
             215 -> RGBColor[
              0.8579866082718589, 0.4467160578370838, 0.20316134760862628`], 
             399 -> RGBColor[
              0.9819174026306743, 0.9860346090062683, 0.9154933000362623], 83 -> 
             RGBColor[
              0.9232246095453774, 0.9416182596597925, 0.9925391815024183], 95 -> 
             RGBColor[
              0.9396396942677109, 0.9545039633325642, 0.987058432502437], 166 -> 
             RGBColor[
              0.9945469395606877, 0.9907447800463217, 0.6478462074480577], 
             384 -> RGBColor[
              0.9184816911083715, 0.7145141001504705, 0.2532666590664004], 
             233 -> RGBColor[
              0.9938316488379729, 0.9917172425221771, 0.7518890721432789], 
             295 -> RGBColor[
              0.9803199598899882, 0.9452767449950785, 0.37804718974668083`], 
             141 -> RGBColor[
              0.8471621500066813, 0.3635145283030711, 0.1927958341494151], 
             319 -> RGBColor[
              0.9856135752492453, 0.9883188578983805, 0.8880838192011903], 
             205 -> RGBColor[
              0.9942175207935469, 0.9900401866127538, 0.611991007581751], 224 -> 
             RGBColor[
              0.9884372460256217, 0.989486518329441, 0.8412882870109101], 231 -> 
             RGBColor[
              0.9865958770091503, 0.9887250649201049, 0.8718045369240984], 
             332 -> RGBColor[
              0.8855636872970232, 0.5732532559432089, 0.22622387440097944`], 
             68 -> RGBColor[
              0.9895667687271889, 0.9899536049939485, 0.822569172734893], 10 -> 
             RGBColor[
              0.9553303131372158, 0.9662060011944106, 0.9604983075251787], 
             250 -> RGBColor[
              0.984266010978971, 0.9585877018950744, 0.39337685307815873`], 
             282 -> RGBColor[
              0.9909334412138681, 0.9810785096644485, 0.41927856050218343`], 
             374 -> RGBColor[
              0.9465099527784347, 0.9596277908808462, 0.9754288768941785], 
             232 -> RGBColor[
              0.9900492212284088, 0.9901531115016666, 0.814573686242629], 253 -> 
             RGBColor[
              0.957259637398797, 0.9676448880697193, 0.9572324647986791], 55 -> 
             RGBColor[
              0.9065200759494623, 0.928298518002895, 0.9909458881757267], 325 -> 
             RGBColor[
              0.8328185873014375, 0.8695309515285748, 0.9839161743943825], 91 -> 
             RGBColor[
              0.8252129746580207, 0.8634664424555697, 0.9831907442708429], 
             105 -> RGBColor[
              0.9782845118004235, 0.98332520497338, 0.9216428366021988], 36 -> 
             RGBColor[
              0.9065960025807546, 0.9283590598377139, 0.9909531301255998], 
             123 -> RGBColor[
              0.9104481942458594, 0.6826639620947446, 0.2468027189204159], 94 -> 
             RGBColor[
              0.9948042586080973, 0.9921194416570545, 0.7357704112189187], 
             312 -> RGBColor[
              0.9207038321910372, 0.9396082602221201, 0.9922987475080368], 96 -> 
             RGBColor[
              0.8943285769873786, 0.6130525729351161, 0.23353751320571817`], 
             2 -> RGBColor[
              0.9579404327247287, 0.9681526241090991, 0.9560800558917352], 
             262 -> RGBColor[
              0.984266010978971, 0.9585877018950744, 0.39337685307815873`], 
             272 -> RGBColor[
              0.8281658631823342, 0.8658209956108336, 0.9834723934143665], 97 -> 
             RGBColor[
              0.9917576924778831, 0.9838589027213716, 0.4224806210160915], 
             372 -> RGBColor[
              0.957246112380402, 0.9676348011331455, 0.957255359126932], 356 -> 
             RGBColor[
              0.9946694218207627, 0.9910067572157659, 0.6611776455843217], 
             346 -> RGBColor[
              0.9946907128344277, 0.9910522965411437, 0.6634950410288525], 
             341 -> RGBColor[
              0.9435257865997853, 0.813805593323828, 0.27341772615926746`], 
             209 -> RGBColor[
              0.9704171528602578, 0.9118722515941338, 0.339576654424369], 378 -> 
             RGBColor[
              0.9948116763281702, 0.9921225090749314, 0.7356474804008648], 66 -> 
             RGBColor[
              0.9932255051874108, 0.9879183655393918, 0.5040162308645052], 
             139 -> RGBColor[0.178927, 0.305394, 0.933501], 56 -> 
             RGBColor[
              0.9891125414810424, 0.9897657703545591, 0.8300968937059698], 
             335 -> RGBColor[
              0.9933086364796881, 0.9880961749677101, 0.5130645590020255], 
             314 -> RGBColor[
              0.9624011460010078, 0.8848323782099676, 0.3084359814720596], 
             144 -> RGBColor[
              0.9938904797330012, 0.9893406788531699, 0.5763946064048228], 
             298 -> RGBColor[
              0.9951253492821588, 0.9919819399543547, 0.7108025360991471], 
             204 -> RGBColor[
              0.9917004394549995, 0.9908359326727347, 0.7872087270122305], 
             207 -> RGBColor[
              0.985550888798006, 0.9882929354398247, 0.889122695925561], 334 -> 
             RGBColor[
              0.9948870409728422, 0.9914722225773926, 0.6848641472984489], 
             149 -> RGBColor[
              0.9857592622614934, 0.9883791032219305, 0.8856694083823377], 
             219 -> RGBColor[
              0.9939109281618718, 0.9893844159748706, 0.5786202916943028], 
             400 -> RGBColor[
              0.9916534247250217, 0.9908164908736654, 0.7879878827581832], 9 -> 
             RGBColor[
              0.8919494102834592, 0.9166802647110073, 0.9895561250771165], 11 -> 
             RGBColor[
              0.9742775691599832, 0.9248943422419599, 0.3545736427703552], 44 -> 
             RGBColor[
              0.9893110438227898, 0.9898478561741492, 0.8268071961956238], 
             153 -> RGBColor[
              0.9788167150355792, 0.9402059471224802, 0.37220736735127274`], 
             32 -> RGBColor[
              0.9152453005909956, 0.9352557752921401, 0.9917781078911361], 
             162 -> RGBColor[
              0.9413307724010349, 0.9557651666355109, 0.9841958783265345], 90 -> 
             RGBColor[
              0.9047061197036843, 0.9268521185310421, 0.9907728714096665], 
             331 -> RGBColor[
              0.9740746245131159, 0.9801854779275638, 0.928769077665155], 8 -> 
             RGBColor[
              0.9009781315626139, 0.923879521980895, 0.9904172925727569], 364 -> 
             RGBColor[
              0.9951706351318389, 0.9920788018077187, 0.715731621364962], 342 -> 
             RGBColor[
              0.9400928007853295, 0.9548418894315104, 0.986291441357215], 163 -> 
             RGBColor[
              0.9931163526591662, 0.9914214491699672, 0.7637433809532778], 49 -> 
             RGBColor[
              0.9856070517787426, 0.9631113474040576, 0.39858654335096605`], 
             338 -> RGBColor[
              0.9833525017338938, 0.9871049035676903, 0.9130640515883032], 76 -> R\
GBColor[0.9935860860115531, 0.9916156959827758, 0.7559586836732777], 369 -> 
             RGBColor[
              0.9949151764304989, 0.9915324014763892, 0.6879265182324653], 82 -> 
             RGBColor[
              0.99418975619694, 0.9899808009480432, 0.6089690025843287], 67 -> 
             RGBColor[
              0.95454873505318, 0.857507910761715, 0.28228704922672376`], 211 -> 
             RGBColor[
              0.9881137489792362, 0.9893527439872658, 
               0.8466494702530362]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9l2k4lWvYhs1zWMs8LNZoLbMSqfBetRslSppMScqwSaE2pQyZolBokCJT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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 14}], {
             RGBColor[
             0.9576797784073078, 0.8619593086718881, 0.3262733499803092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.9703570961121166, 0.9116696660806589, 0.3393433452986063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 49}], {
             RGBColor[
             0.9842475138644915, 0.9585253067846058, 0.3933049952812927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 62}], {
             RGBColor[
             0.9878873906261698, 0.9726328958019381, 0.5777855109605063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 87}], {
             RGBColor[
             0.9486212021709388, 0.8260450724862713, 0.318984606908414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 119}], {
             RGBColor[
             0.9882898057859402, 0.972799304812101, 0.5711164503460626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 127}], {
             RGBColor[
             0.9784588563389691, 0.9389988057095965, 0.37081715389088676`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 129}], {
             RGBColor[
             0.9386082764688095, 0.7834959195501351, 0.3107804802086688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 216}], {
             RGBColor[
             0.9885960751151708, 0.972082397911818, 0.5047230760207365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 231}], {
             RGBColor[
             0.9847419264796953, 0.9713321655426295, 0.6299139920678589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 235}], {
             RGBColor[
             0.9850588215962861, 0.9714632098171728, 0.624662219887677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 298}], {
             RGBColor[
             0.9890066626161995, 0.9729606030597544, 0.5494129916553833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 313}], {
             RGBColor[
             0.9880697770246871, 0.9709566995131729, 0.4474387768069107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 317}], {
             RGBColor[
             0.9777949224854947, 0.936759200922745, 0.3682378962435263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 336}], {
             RGBColor[
             0.9430296514655949, 0.9397837913199631, 0.689324964360633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 361}], {
             RGBColor[
             0.9722540396397961, 0.9624180912931366, 0.6689373902907625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 393}], {
             RGBColor[
             0.9746876069745969, 0.9642330418268303, 0.6648179955689579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 396}], {
             RGBColor[
             0.9764195049193931, 0.9655246884783368, 0.6618863440997451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 97}], {
             RGBColor[
             0.974849062601306, 0.9760057634152353, 0.6892803384539133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 109}], {
             RGBColor[
             0.9756416315471695, 0.97816096817491, 0.7364332043957813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 181}], {
             RGBColor[
             0.9340658429337421, 0.9496892195772377, 0.9736880521127284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 191}], {
             RGBColor[
             0.960604699048327, 0.970139629570903, 0.9515701479578293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 193}], {
             RGBColor[
             0.9689702842653545, 0.9561752636852765, 0.6664423947328779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 211}], {
             RGBColor[
             0.9730270908519825, 0.9787526840481824, 0.9013647630723857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 305}], {
             RGBColor[
             0.9764577323681287, 0.9799065253104917, 0.8252607423667282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 334}], {
             RGBColor[
             0.9764137368487855, 0.9798124233432459, 0.820472101595092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 340}], {
             RGBColor[
             0.9758317590692062, 0.9785676317197052, 0.7571274118384121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 360}], {
             RGBColor[
             0.9662939720871521, 0.9471474342802167, 0.6560454272997082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 365}], {
             RGBColor[
             0.9341722746513901, 0.9497740853398784, 0.9736982036649704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 370}], {
             RGBColor[
             0.9764002551590474, 0.9797835873721039, 0.8190047028664437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 11}], {
             RGBColor[
             0.8474226070562483, 0.8532632650432901, 0.6636783747989405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 21}], {
             RGBColor[
             0.8569817533347747, 0.8849574643875966, 0.7476707973115498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 34}], {
             RGBColor[
             0.8548549362455413, 0.8857051170734318, 0.9011940128676118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 74}], {
             RGBColor[
             0.8536790304945607, 0.8743676503787994, 0.6879833984303549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 86}], {
             RGBColor[
             0.852158792953065, 0.8692395321825845, 0.6820775626544144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 91}], {
             RGBColor[
             0.7728903098052671, 0.8225493151500949, 0.9779869255491844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 95}], {
             RGBColor[
             0.8301036696101121, 0.8680680755885921, 0.9799207696649814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 160}], {
             RGBColor[
             0.8576166171327384, 0.8863153738568648, 0.8167718037947032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[
             0.8309492086767741, 0.8686986772400656, 0.9784894925770302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 233}], {
             RGBColor[
             0.8571996468952432, 0.8866747151833987, 0.8623360894854024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 263}], {
             RGBColor[
             0.8576338401430841, 0.8868542652496383, 0.8551403837125726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 264}], {
             RGBColor[
             0.8570539142644653, 0.8866144509954141, 0.8647512563213504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 285}], {
             RGBColor[
             0.8392222196369556, 0.8256014327354858, 0.6318214181882125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 312}], {
             RGBColor[
             0.8206357385717753, 0.8606202240333701, 0.9825409271677814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 348}], {
             RGBColor[
             0.835370473888349, 0.8108964839223628, 0.6257747902891027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 13}], {
             RGBColor[
             0.971803129592063, 0.9127024286632335, 0.49493470357217006`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 66}], {
             RGBColor[
             0.9708455152613111, 0.9106541884394158, 0.3907042933804336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 123}], {
             RGBColor[
             0.9294568597905355, 0.7580269867170921, 0.2620975374083889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 131}], {
             RGBColor[
             0.9005408741198218, 0.85935353005267, 0.631598423224058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 140}], {
             RGBColor[
             0.9506121143417064, 0.8988390550819139, 0.6211218640055454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 183}], {
             RGBColor[
             0.964479538450369, 0.9091813572763315, 0.5976479321930429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 186}], {
             RGBColor[
             0.9581148918837099, 0.8681567135492647, 0.3033315082124176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 188}], {
             RGBColor[
             0.970232758736602, 0.9121749083723725, 0.5298183598669548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 203}], {
             RGBColor[
             0.9640301991687996, 0.888110434002072, 0.3263113600029418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 232}], {
             RGBColor[
             0.9692573732818102, 0.9117715614205533, 0.5459830210694956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 238}], {
             RGBColor[
             0.6006791832247234, 0.6082634000278461, 0.6075528005625808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 275}], {
             RGBColor[
             0.9498735523017048, 0.898288236721765, 0.6223720568914377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 280}], {
             RGBColor[
             0.8662203306951854, 0.8322783065741142, 0.628247664430153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 297}], {
             RGBColor[
             0.9473220440097534, 0.8288564889265613, 0.2764722839809419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 309}], {
             RGBColor[
             0.9309234305534573, 0.7638414510863409, 0.26327757466907603`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 322}], {
             RGBColor[
             0.9522870532261885, 0.848498045315855, 0.2806914555229309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 325}], {
             RGBColor[
             0.8906420563183246, 0.8514604814340073, 0.6306542651453723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 339}], {
             RGBColor[
             0.966846341226508, 0.8976099424243222, 0.33725154011333497`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 8}], {
             RGBColor[
             0.9430925664847336, 0.9560151255734877, 0.9426195462608788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 43}], {
             RGBColor[
             0.9528822309864595, 0.8554472817535703, 0.5748793359228166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 56}], {
             RGBColor[
             0.987159771443948, 0.9889582497603198, 0.8624593468274853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.9601907918208803, 0.9696487863375682, 0.9442503902572064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 90}], {
             RGBColor[
             0.9449565605552688, 0.9575014238485612, 0.9427973356793335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 100}], {
             RGBColor[
             0.9868221237162376, 0.9888186237477606, 0.8680550434799554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 121}], {
             RGBColor[
             0.9869171286842543, 0.9888579107435519, 0.866480565294941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 122}], {
             RGBColor[
             0.9899232927012566, 0.9895468331455091, 0.776375891204294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 175}], {
             RGBColor[
             0.986135829087137, 0.9885348232816602, 0.8794287215577167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 178}], {
             RGBColor[
             0.9609604294792446, 0.8874746468773934, 0.5813792440498009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 213}], {
             RGBColor[
             0.9409432358829921, 0.8059390799186137, 0.5651604781048893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 227}], {
             RGBColor[
             0.9087461093364009, 0.92862819295315, 0.9393435505166265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 274}], {
             RGBColor[
             0.9872921524908707, 0.98901299272526, 0.8602654502888087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 296}], {
             RGBColor[
             0.9640691171589828, 0.9725547583147467, 0.938154258049464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 308}], {
             RGBColor[
             0.9891193326276665, 0.9878272438409319, 0.6888697986604582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 319}], {
             RGBColor[
             0.9854102883280493, 0.9882347935322304, 0.8914528095750955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 352}], {
             RGBColor[
             0.9895244670242311, 0.9886937853498128, 0.7329661775268406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 373}], {
             RGBColor[
             0.9896872988254555, 0.9890420661078114, 0.7506894142087276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 56}], {
             RGBColor[
             0.9920877242206381, 0.9908070762481016, 0.7670514842064566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 79}], {
             RGBColor[
             0.9929102886781027, 0.9911472277902056, 0.7534194624176902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 137}], {
             RGBColor[
             0.9150363031800622, 0.931563233490686, 0.8440656196646527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 169}], {
             RGBColor[
             0.9854128859022073, 0.9608764877452071, 0.5321749053679262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 175}], {
             RGBColor[
             0.9910637818638273, 0.990383649769442, 0.7840208589366882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 178}], {
             RGBColor[
             0.9658883822559348, 0.8893234733651754, 0.4859713814287723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 252}], {
             RGBColor[
             0.9291114703559973, 0.9427863897365416, 0.8454081216749434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 277}], {
             RGBColor[
             0.9796163942180571, 0.9413235602135983, 0.5096566297506081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 278}], {
             RGBColor[
             0.9922818877092197, 0.9908873678404042, 0.7638336927216589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 300}], {
             RGBColor[
             0.9813185867656364, 0.9470654553704, 0.5162693263658635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 314}], {
             RGBColor[
             0.9787320264806207, 0.9383403801758059, 0.5062210280895015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 319}], {
             RGBColor[
             0.9903382411047394, 0.9900836200200123, 0.7960449469540669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 352}], {
             RGBColor[
             0.9944524198009213, 0.9905426118375947, 0.6375583149058119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 379}], {
             RGBColor[
             0.990829391984692, 0.9902867235308745, 0.787905305815521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 65}], {
             RGBColor[
             0.9852051439989307, 0.9608450741993231, 0.5484268917775218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 67}], {
             RGBColor[
             0.9651103510369669, 0.8935529422041204, 0.32113883218811556`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 68}], {
             RGBColor[
             0.9826193678739712, 0.9597757893202371, 0.5912798939422002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 96}], {
             RGBColor[
             0.9350002720040661, 0.7713252732908209, 0.29676406417761275`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 173}], {
             RGBColor[
             0.9667091881743496, 0.948802947711994, 0.658199551021295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[
             0.9823926222028243, 0.9596820241581199, 0.5950376565120922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 201}], {
             RGBColor[
             0.984548731266714, 0.9589720491347664, 0.4428872793608687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 223}], {
             RGBColor[
             0.984300178494494, 0.9604708477066859, 0.5634245121616863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 250}], {
             RGBColor[
             0.9799689889998624, 0.9440928377708, 0.37668373411383305`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 387}], {
             RGBColor[
             0.9753360175064097, 0.9284647370499467, 0.35868551472502375`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 43}], {
             RGBColor[
             0.9107677960643397, 0.8233116781609777, 0.6226770822346948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 56}], {
             RGBColor[
             0.9450453365218281, 0.956822646167727, 0.9102570931393634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 59}], {
             RGBColor[
             0.9180763568987605, 0.9375131827449755, 0.9920481365690845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 100}], {
             RGBColor[
             0.9447076887941177, 0.9566830201551679, 0.9158527897918335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 121}], {
             RGBColor[
             0.9448026937621345, 0.9567223071509592, 0.914278311606819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 175}], {
             RGBColor[
             0.9440213941650173, 0.9563992196890675, 0.9272264678695947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 213}], {
             RGBColor[
             0.8988288009608725, 0.7738034763260211, 0.6129582244167675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 227}], {
             RGBColor[
             0.8666316744142812, 0.8964925893605573, 0.9871412968285047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 237}], {
             RGBColor[
             0.9432305417372381, 0.9560721818862005, 0.9403329392583726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 296}], {
             RGBColor[
             0.9219546822368632, 0.9404191547221541, 0.9859520043613421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 308}], {
             RGBColor[
             0.9470048977055467, 0.9556916402483393, 0.7366675449723363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 352}], {
             RGBColor[
             0.9474100321021113, 0.9565581817572202, 0.7807639238387187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 373}], {
             RGBColor[
             0.9475728639033358, 0.9569064625152188, 0.7984871605206056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 39}], {
             RGBColor[
             0.86201548679718, 0.582139397657541, 0.5839553861877829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.9074564721923375, 0.824481689421231, 0.6232144901089677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 150}], {
             RGBColor[
             0.9419867916356239, 0.9538250347595613, 0.8856998748277534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 192}], {
             RGBColor[
             0.9399687709574098, 0.9529905313483539, 0.9191436999358656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 283}], {
             RGBColor[
             0.9334503841616228, 0.9487598045336213, 0.958420560785172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 294}], {
             RGBColor[
             0.943432293356979, 0.9541063330936983, 0.838741321654791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 320}], {
             RGBColor[
             0.915794552275585, 0.9355921140217858, 0.9883072787897768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 347}], {
             RGBColor[
             0.931173956894806, 0.9142448038273341, 0.6645301651412112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 381}], {
             RGBColor[
             0.941014213017031, 0.9534228485066427, 0.9018180194906189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 384}], {
             RGBColor[
             0.9052155506959154, 0.8155971824307389, 0.6214113920717584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.9752163087188859, 0.9790693251316609, 0.8343962697969993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 37}], {
             RGBColor[
             0.8863246565686079, 0.5501665005972053, 0.5623581537625894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 62}], {
             RGBColor[
             0.9741085592196576, 0.9787662633165664, 0.8640229411172861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 87}], {
             RGBColor[
             0.9348423707644266, 0.8321784400008996, 0.6052220370651937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 155}], {
             RGBColor[
             0.8978227116932155, 0.9208572383169243, 0.9725647534852726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 170}], {
             RGBColor[
             0.9739318531868277, 0.9786931908308533, 0.8669514173818295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 216}], {
             RGBColor[
             0.9748172437086585, 0.9782157654264463, 0.7909605061775162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 256}], {
             RGBColor[
             0.97530591833631, 0.979260991042409, 0.8441497236471587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 261}], {
             RGBColor[
             0.9584752082332837, 0.9685514588077648, 0.9551748204475422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 298}], {
             RGBColor[
             0.9752278312096874, 0.9790939705743826, 0.835650421812163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 311}], {
             RGBColor[
             0.97469378034224, 0.9779516897697382, 0.7775222806704327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 313}], {
             RGBColor[
             0.9742909456181749, 0.9770900670278011, 0.7336762069636904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 361}], {
             RGBColor[
             0.9584752082332837, 0.9685514588077648, 0.9551748204475422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 396}], {
             RGBColor[
             0.962640673512881, 0.9716580559929651, 0.9481237742565247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 34}], {
             RGBColor[
             0.9817098983492762, 0.9573361942721016, 0.5920892808390265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 35}], {
             RGBColor[
             0.971307926602317, 0.9148770405897206, 0.34303714220376313`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 85}], {
             RGBColor[
             0.9838355900202034, 0.9565861344303066, 0.438443570445604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 86}], {
             RGBColor[
             0.9790137550567999, 0.9408706093812544, 0.3729728306258291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 91}], {
             RGBColor[
             0.899745271909002, 0.8941803923487648, 0.6688821935205991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 93}], {
             RGBColor[
             0.9806052046564782, 0.9568793750407967, 0.6103969141843228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 95}], {
             RGBColor[
             0.956958631713847, 0.939699152787262, 0.6708160376363961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 125}], {
             RGBColor[
             0.9612274903272071, 0.8785710391054753, 0.31586708775376204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 162}], {
             RGBColor[
             0.9578041707805091, 0.9403297544387355, 0.6693847605484449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 211}], {
             RGBColor[
             0.9811956590696097, 0.9571235431146128, 0.6006115565116956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 214}], {
             RGBColor[
             0.9117247402604772, 0.9037324952382253, 0.6700248059061604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 248}], {
             RGBColor[
             0.9813980925193984, 0.9572072545484027, 0.5972567103677233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 263}], {
             RGBColor[
             0.984488802246819, 0.9584853424483082, 0.5460356516839873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 312}], {
             RGBColor[
             0.9474907006755102, 0.9322513012320399, 0.6734361951391961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.8982410887878003, 0.8426598510486594, 0.6280515366807478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 17}], {
             RGBColor[
             0.9644278329515472, 0.8931136462176018, 0.5444928901309809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 22}], {
             RGBColor[
             0.9666573748292852, 0.8931302821426066, 0.44173517317359856`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 47}], {
             RGBColor[
             0.8865511222737135, 0.5293434211568182, 0.22502662646724386`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 106}], {
             RGBColor[
             0.9310228613698999, 0.7642356611401802, 0.26335757903792695`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 107}], {
             RGBColor[
             0.9624498003488406, 0.8922956789032634, 0.5772740093421105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 118}], {
             RGBColor[
             0.9659356949775109, 0.8915866819126872, 0.36318477499975343`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 158}], {
             RGBColor[
             0.9620565757458652, 0.8921330704245218, 0.5837907586460651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 209}], {
             RGBColor[
             0.9547496707494209, 0.8540302298715197, 0.304709478679702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 241}], {
             RGBColor[
             0.966716387094323, 0.8940600221687983, 0.5065656253969181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 270}], {
             RGBColor[
             0.8755362578628376, 0.8246202450575884, 0.6258687841620985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 310}], {
             RGBColor[
             0.95926588822833, 0.8692644918861718, 0.3222541307691558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 323}], {
             RGBColor[
             0.9658671471628437, 0.8914400650683613, 0.3557237684013077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 324}], {
             RGBColor[
             0.9499333134215971, 0.8832309434441343, 0.6105540996923784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 346}], {
             RGBColor[
             0.9668864507365058, 0.8936202523450246, 0.46666867198194373`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 390}], {
             RGBColor[
             0.9644430428066109, 0.893119935883546, 0.5442408234707337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 66}], {
             RGBColor[
             0.9941831195181627, 0.9899666057632095, 0.6082466410562417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 123}], {
             RGBColor[
             0.952794464047387, 0.8373394040408858, 0.47963988508419697`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 131}], {
             RGBColor[
             0.9238784783766734, 0.9386659473764636, 0.8491407708998661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[
             0.973949718598558, 0.9781514724057075, 0.8386642116813534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 188}], {
             RGBColor[
             0.9935703629934534, 0.991487325696166, 0.7473607075427628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 203}], {
             RGBColor[
             0.987367803425651, 0.9674228513258656, 0.5438537076787499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 232}], {
             RGBColor[
             0.9925949775386617, 0.9910839787443468, 0.7635253687453036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 275}], {
             RGBColor[
             0.9732111565585563, 0.9776006540455586, 0.8399144045672458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 280}], {
             RGBColor[
             0.889557934952037, 0.9115907238979077, 0.845790012105961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 297}], {
             RGBColor[
             0.9706596482666048, 0.9081689062503548, 0.49401463165674997`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 309}], {
             RGBColor[
             0.9542610348103087, 0.8431538684101346, 0.4808199223448841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 322}], {
             RGBColor[
             0.9756246574830398, 0.9278104626396486, 0.49823380319873894`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 325}], {
             RGBColor[
             0.913979660575176, 0.930772898757801, 0.8481966128211803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 339}], {
             RGBColor[
             0.9901839454833594, 0.9769223597481158, 0.554793887789143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 29}], {
             RGBColor[
             0.945148898569184, 0.8196897085873929, 0.27759324806729613`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 62}], {
             RGBColor[
             0.9626791930832372, 0.8806529383086721, 0.5160354137291963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 119}], {
             RGBColor[
             0.9630816082430076, 0.8808193473188349, 0.5093663531147524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 126}], {
             RGBColor[
             0.9588579521216478, 0.8790727569696415, 0.5793632655173415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 127}], {
             RGBColor[
             0.9532506587960365, 0.8470188482163304, 0.3090670566595766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 129}], {
             RGBColor[
             0.9134000789258769, 0.691515962056869, 0.24903038297735858`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 196}], {
             RGBColor[
             0.9624914166916099, 0.880575287945101, 0.5191473544881845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 235}], {
             RGBColor[
             0.9598506240533535, 0.8794832523239068, 0.5629121226563668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 317}], {
             RGBColor[
             0.9525867249425621, 0.844779243429479, 0.3064877990122161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 326}], {
             RGBColor[
             0.9599966874708619, 0.879543653300705, 0.5604914738282478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 327}], {
             RGBColor[
             0.963192811651813, 0.8796852141389525, 0.4217412571584673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 336}], {
             RGBColor[
             0.9178214539226623, 0.8478038338266971, 0.6275748671293228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 396}], {
             RGBColor[
             0.9512113073764605, 0.8735447309850708, 0.6001362468684348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 33}], {
             RGBColor[
             0.9438086539676922, 0.798375104490458, 0.4701592276072098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 37}], {
             RGBColor[
             0.906210652150278, 0.5630298245344556, 0.4362561160344099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.9939945548013276, 0.9916295872538166, 0.7379209033891065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 92}], {
             RGBColor[
             0.9903278815815131, 0.9901133236482198, 0.7986871676875478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 256}], {
             RGBColor[
             0.99519191391798, 0.9921243149796592, 0.7180476859189793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 311}], {
             RGBColor[
             0.99457977592391, 0.9908150137069884, 0.6514202429422532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 313}], {
             RGBColor[
             0.9941769411998449, 0.9899533909650515, 0.607574169235511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 361}], {
             RGBColor[
             0.9783612038149538, 0.9814147827450153, 0.8290727827193627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 386}], {
             RGBColor[
             0.9379925345109803, 0.77196546442674, 0.46530611496639573`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 69}], {
             RGBColor[
             0.9242261017616124, 0.9398496844896418, 0.8921061305333755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 106}], {
             RGBColor[
             0.8901817615191161, 0.810707304039934, 0.6215668127836396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 107}], {
             RGBColor[
             0.9216087004980571, 0.9387673218030174, 0.9354832430878233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 190}], {
             RGBColor[
             0.910439214896922, 0.9307071777273878, 0.9664832115472006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 212}], {
             RGBColor[
             0.9009066650369024, 0.8532279726257204, 0.6301963218998914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 241}], {
             RGBColor[
             0.9258752872435393, 0.9405316650685522, 0.8647748591426307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 268}], {
             RGBColor[
             0.9211595861037958, 0.9385816014592768, 0.9429262308715278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 270}], {
             RGBColor[
             0.8346951580120539, 0.8710918879573423, 0.984078017907811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 274}], {
             RGBColor[
             0.9233886462559522, 0.9395033751164265, 0.9059849355275384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 295}], {
             RGBColor[
             0.9188599744135024, 0.917204119471746, 0.6821539800865706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 310}], {
             RGBColor[
             0.9184247883775465, 0.9157361347859257, 0.6804633645148684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 324}], {
             RGBColor[
             0.9090922135708135, 0.9297025863438882, 0.968763333438091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 351}], {
             RGBColor[
             0.8602447728794705, 0.891399847444523, 0.9865321084584602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 373}], {
             RGBColor[
             0.9257837925905372, 0.939532448498978, 0.7964088994474574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 380}], {
             RGBColor[
             0.8871762748420584, 0.9128742960733445, 0.9891008591576874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 390}], {
             RGBColor[
             0.9236019429558271, 0.9395915787832999, 0.9024500572164462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 22}], {
             RGBColor[
             0.9920030191422484, 0.9900557202113027, 0.7163857603695443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 48}], {
             RGBColor[
             0.9916858010509542, 0.9908298793164722, 0.7874513232502378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 61}], {
             RGBColor[
             0.9838630461258622, 0.9865583805799087, 0.8706740643306683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 118}], {
             RGBColor[
             0.9912813392904742, 0.9885121199813833, 0.6378353621956993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 158}], {
             RGBColor[
             0.9874022200588285, 0.989058508493218, 0.858441345842011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 164}], {
             RGBColor[
             0.9834175470477284, 0.9862261280968745, 0.8714281780651804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 173}], {
             RGBColor[
             0.9737599432962281, 0.9790235030318801, 0.8877759821100046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 209}], {
             RGBColor[
             0.9800953150623841, 0.9509556679402159, 0.5793600658756478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 241}], {
             RGBColor[
             0.9920620314072862, 0.9909854602374946, 0.7812162125928639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 287}], {
             RGBColor[
             0.9897235922626937, 0.9900184555560607, 0.8199702009052765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 323}], {
             RGBColor[
             0.991212791475807, 0.9883655031370575, 0.6303743555972535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 346}], {
             RGBColor[
             0.9922320950494691, 0.9905456904137209, 0.7413192591778895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 354}], {
             RGBColor[
             0.9916142778337802, 0.9892242418602648, 0.6740736679760478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 371}], {
             RGBColor[
             0.980878993129132, 0.9843328787408857, 0.8757252876884642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 388}], {
             RGBColor[
             0.9492378192069271, 0.832890303492198, 0.5322706485166109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 389}], {
             RGBColor[
             0.9920460909963434, 0.9901478465519797, 0.7210738658791214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 45}], {
             RGBColor[
             0.9154336735154602, 0.6960192043226305, 0.25048254291641026`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 74}], {
             RGBColor[
             0.9678428340379746, 0.901098423718178, 0.3404609070613354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 86}], {
             RGBColor[
             0.9663225964964788, 0.8959703055219632, 0.33455507128539486`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 91}], {
             RGBColor[
             0.8870541133486809, 0.8492800884894736, 0.6304644341801648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 112}], {
             RGBColor[
             0.9671986548062637, 0.9116832384984169, 0.5838350398907355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 141}], {
             RGBColor[
             0.8980287010230111, 0.5993041314132243, 0.2352669791194509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 148}], {
             RGBColor[
             0.9677455645242456, 0.9119093997217411, 0.5747713305067925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 179}], {
             RGBColor[
             0.8908569196703893, 0.8523123430259761, 0.6308271492419346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 232}], {
             RGBColor[
             0.9694722366338748, 0.9126234230125221, 0.5461559051660578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 257}], {
             RGBColor[
             0.9687995859229102, 0.9043257724820912, 0.344177707466877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 279}], {
             RGBColor[
             0.9704266328287354, 0.9130180903659604, 0.5303390903190401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 285}], {
             RGBColor[
             0.9533860231803695, 0.8523322060748644, 0.28429892681919294`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 288}], {
             RGBColor[
             0.9659559120306508, 0.9109740511309712, 0.5956854085277961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 399}], {
             RGBColor[
             0.9654063273350076, 0.9105641717648228, 0.5966157120628746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 185}], {
             RGBColor[
             0.9309253717900982, 0.7496048579044666, 0.3017695001212145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 198}], {
             RGBColor[
             0.9799805301958517, 0.9441317689348738, 0.37672856948087974`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 205}], {
             RGBColor[
             0.9877003396796251, 0.9691143517148533, 0.4966957805910963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 219}], {
             RGBColor[
             0.9875470433637875, 0.9687864663959116, 0.48001042264737226`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 262}], {
             RGBColor[
             0.9827245847723372, 0.9533881093560135, 0.3873887033393002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 284}], {
             RGBColor[
             0.9851500095476531, 0.9689780366045431, 0.6057129347472112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 293}], {
             RGBColor[
             0.9833670236818546, 0.9682407261283886, 0.6352616247630014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 331}], {
             RGBColor[
             0.9776288915394096, 0.9641869973722582, 0.6550848156327984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 338}], {
             RGBColor[
             0.9822678301497985, 0.9676467101923214, 0.6472323025943725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.5709473486362611, 0.5013974392317, 0.5868332047216434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 36}], {
             RGBColor[
             0.5753324544604198, 0.6511106668182782, 0.9640819326614267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 80}], {
             RGBColor[
             0.6188523903683616, 0.6813291887910401, 0.7429465609904841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 151}], {
             RGBColor[
             0.6189257151097707, 0.6814860229986456, 0.7509275065850134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 168}], {
             RGBColor[
             0.6038549351653604, 0.6314384246054661, 0.6252315877195176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 265}], {
             RGBColor[
             0.6189337714278141, 0.6815032546483217, 0.7518043870862072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 291}], {
             RGBColor[
             0.6182368238450417, 0.6799519121500792, 0.681102509448293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 304}], {
             RGBColor[
             0.6194402913341277, 0.682992391436887, 0.8364291077990591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 378}], {
             RGBColor[
             0.6194402913341277, 0.682992391436887, 0.8364291077990591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 383}], {
             RGBColor[
             0.5559054428792367, 0.4330956583153983, 0.5742818698471327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 24}], {
             RGBColor[
             0.99072751456594, 0.9888064570191402, 0.6850562579115755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 25}], {
             RGBColor[
             0.9676230473315496, 0.9722176601950137, 0.752937527458192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 27}], {
             RGBColor[
             0.9911634782054517, 0.9889867391878328, 0.6778312121671322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 32}], {
             RGBColor[
             0.9543205811540159, 0.9617692581113565, 0.7571682978433549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 78}], {
             RGBColor[
             0.9644978905525373, 0.9698843683700332, 0.7581390186991772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 95}], {
             RGBColor[
             0.9665177779923735, 0.9713933521315685, 0.7548084601490054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 104}], {
             RGBColor[
             0.9293353306573483, 0.7347044482105447, 0.3659264084870295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 160}], {
             RGBColor[
             0.9940307255149998, 0.9896406503998412, 0.5916594942787271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 172}], {
             RGBColor[
             0.993229364646623, 0.9879266205323955, 0.5044363091819287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 208}], {
             RGBColor[
             0.9555097370879997, 0.8496974225869498, 0.3875673583194829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 217}], {
             RGBColor[
             0.9937002572650999, 0.9889338122287706, 0.5556900646907564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 230}], {
             RGBColor[
             0.993915992076828, 0.9893952471769218, 0.5791714675864402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 233}], {
             RGBColor[
             0.9936137552775044, 0.989999991726375, 0.6372237799694264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 240}], {
             RGBColor[
             0.9936785780497538, 0.9888874425792503, 0.5533304158889454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 242}], {
             RGBColor[
             0.9331957168197784, 0.7522335601580448, 0.36914760932768503`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 244}], {
             RGBColor[
             0.9288986936140705, 0.7327217813761927, 0.36556206783516526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 264}], {
             RGBColor[
             0.9934680226467265, 0.9899397275383905, 0.6396389468053743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 285}], {
             RGBColor[
             0.9756363280192171, 0.9289267092784621, 0.4067091086722365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 357}], {
             RGBColor[
             0.9759021573691777, 0.9298234140955792, 0.40774180549917327`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 47}], {
             RGBColor[
             0.9141263084644147, 0.6262854951505191, 0.3969194967058074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.9939153429286921, 0.9908465152414769, 0.6846936062928555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 96}], {
             RGBColor[
             0.9442805690036824, 0.8015624645357118, 0.4235827783089401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 118}], {
             RGBColor[
             0.9935108811682121, 0.9885287559063881, 0.535077645238317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 158}], {
             RGBColor[
             0.9896317619365664, 0.9890751444182228, 0.7556836288846287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 173}], {
             RGBColor[
             0.9759894851739659, 0.9790401389568849, 0.7850182651526223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 209}], {
             RGBColor[
             0.9823248569401221, 0.9509723038652207, 0.47660234891826553`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 241}], {
             RGBColor[
             0.9942915732850242, 0.9910020961624992, 0.6784584956354816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 310}], {
             RGBColor[
             0.9868410744190312, 0.9662065658798729, 0.49414700100771936`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 323}], {
             RGBColor[
             0.9934423333535449, 0.9883821390620622, 0.5276166386398712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 346}], {
             RGBColor[
             0.994461636927207, 0.9905623263387255, 0.6385615422205073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 354}], {
             RGBColor[
             0.9938438197115183, 0.9892408777852695, 0.5713159510186656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 388}], {
             RGBColor[
             0.951467361084665, 0.8329069394172026, 0.42951293155922854`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 75}], {
             RGBColor[
             0.9523764789981505, 0.8360732378996979, 0.4561659567450098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 120}], {
             RGBColor[
             0.9515924969033511, 0.8343963794716706, 0.3708343439027454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 132}], {
             RGBColor[
             0.9525406233687264, 0.836424326110818, 0.47403205850055286`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 160}], {
             RGBColor[
             0.9523530660967243, 0.8360231600709549, 0.4536176069124544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 202}], {
             RGBColor[
             0.9519443230893609, 0.8351489001084618, 0.40912845303038115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 220}], {
             RGBColor[
             0.9281350677325272, 0.7527865216681816, 0.2610339924920682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 229}], {
             RGBColor[
             0.9525589780090024, 0.8364635848304296, 0.4760298478228922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 260}], {
             RGBColor[
             0.9521950772125616, 0.8356852378228573, 0.4364214918657172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 307}], {
             RGBColor[
             0.9358303231049184, 0.8259723383469597, 0.598163023216467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 321}], {
             RGBColor[
             0.9236173448727161, 0.7348752559709297, 0.2573989266344794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 341}], {
             RGBColor[
             0.9267831647401352, 0.7474266767983141, 0.25994621961114794`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 348}], {
             RGBColor[
             0.9301069228523349, 0.7606042701364528, 0.26262059340685395`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 366}], {
             RGBColor[
             0.9524021908511194, 0.8361282329533314, 0.45896453326551756`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.9884951310543557, 0.9895104552764, 0.8403289822831339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 32}], {
             RGBColor[
             0.9516522340029198, 0.9622929741999238, 0.9196660679593567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 73}], {
             RGBColor[
             0.9905429562886505, 0.988411705525722, 0.6649682283902745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.987424791725726, 0.978216643010343, 0.6253688590303808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 78}], {
             RGBColor[
             0.9618295434014412, 0.9704080844586005, 0.9206367888151791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 104}], {
             RGBColor[
             0.9266669835062522, 0.7352281642991119, 0.5284241786030314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 112}], {
             RGBColor[
             0.986780612494015, 0.9888014577905819, 0.8687429918597809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 141}], {
             RGBColor[
             0.9176106587107626, 0.6764223507053893, 0.5201749310884962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 172}], {
             RGBColor[
             0.9905610174955269, 0.9884503366209627, 0.6669340792979306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 208}], {
             RGBColor[
             0.9528413899369037, 0.850221138675517, 0.5500651284354847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 240}], {
             RGBColor[
             0.9910102308986577, 0.9894111586678176, 0.7158281860049472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 242}], {
             RGBColor[
             0.9305273696686824, 0.752757276246612, 0.5316453794436868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 243}], {
             RGBColor[
             0.991188649948212, 0.989792778973881, 0.7352479984741851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 285}], {
             RGBColor[
             0.972967980868121, 0.9294504253670294, 0.5692068787882383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 337}], {
             RGBColor[
             0.986596107341343, 0.9887251601683859, 0.8718007197235852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 357}], {
             RGBColor[
             0.9732338102180818, 0.9303471301841464, 0.570239575615175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 399}], {
             RGBColor[
             0.9849882850227591, 0.9876823910569879, 0.8815236640319198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 32}], {
             RGBColor[
             0.9285477667685293, 0.9457041773757973, 0.9875473375059731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 78}], {
             RGBColor[
             0.9387250761670509, 0.953819287634474, 0.9885180583617955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 83}], {
             RGBColor[
             0.9325374212457203, 0.9488854195596235, 0.9879278743116142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 194}], {
             RGBColor[
             0.9654817551654791, 0.9729593270645842, 0.9067006324977436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 201}], {
             RGBColor[
             0.9676378642293688, 0.9722493520412308, 0.7545502553465202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 217}], {
             RGBColor[
             0.9679274428796134, 0.9728687314932114, 0.7860691043533747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 223}], {
             RGBColor[
             0.9673893114571488, 0.9737481506131502, 0.8750874881473378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 230}], {
             RGBColor[
             0.9681431776913416, 0.9733301664413627, 0.8095505072490585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 242}], {
             RGBColor[
             0.907422902434292, 0.7361684794224856, 0.5995266489903033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 244}], {
             RGBColor[
             0.9031258792285841, 0.7166567006406335, 0.5959411074977835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 245}], {
             RGBColor[
             0.9680226329271814, 0.974010045316628, 0.8645917124054733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 328}], {
             RGBColor[
             0.9633037867641994, 0.9581988257381773, 0.6893010714641152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 357}], {
             RGBColor[
             0.9501293429836913, 0.9137583333600199, 0.6381208451617915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 364}], {
             RGBColor[
             0.968510434038951, 0.9741156906335866, 0.8495240942428861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 385}], {
             RGBColor[
             0.9620736921988611, 0.9712352022573156, 0.9490835257287504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 105}], {
             RGBColor[
             0.9647681819772493, 0.9732447483222155, 0.9445224573694245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 128}], {
             RGBColor[
             0.9497206333972719, 0.8977298080571345, 0.6222861344434355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 159}], {
             RGBColor[
             0.9730280553810862, 0.9776418666640527, 0.8515862446777841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 171}], {
             RGBColor[
             0.9727608305597241, 0.9766581586980979, 0.7925421652682413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 215}], {
             RGBColor[
             0.904619230212967, 0.7049401747540675, 0.5852817128726382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 218}], {
             RGBColor[
             0.9553144364336854, 0.9188977925935907, 0.6320449519620448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 342}], {
             RGBColor[
             0.9456723264697023, 0.9590030905512807, 0.9768467597469326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 349}], {
             RGBColor[
             0.9689238645816127, 0.9759446782955781, 0.9196033075303743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 353}], {
             RGBColor[
             0.9627647106570292, 0.9440293169565055, 0.6609878604535027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 32}], {
             RGBColor[
             0.9520881976424316, 0.9624732563686164, 0.9124410222149133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 73}], {
             RGBColor[
             0.9909789199281622, 0.9885919876944147, 0.6577431826458311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 74}], {
             RGBColor[
             0.9878607553652379, 0.9783969251790356, 0.6181438132859374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 78}], {
             RGBColor[
             0.9622655070409531, 0.9705883666272931, 0.9134117430707356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 104}], {
             RGBColor[
             0.9271029471457641, 0.7354084464678046, 0.5211991328585879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 112}], {
             RGBColor[
             0.9872165761335269, 0.9889817399592745, 0.8615179461153375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 141}], {
             RGBColor[
             0.9180466223502743, 0.6766026328740818, 0.5129498853440528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 172}], {
             RGBColor[
             0.9909969811350388, 0.9886306187896554, 0.6597090335534871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 208}], {
             RGBColor[
             0.9532773535764154, 0.8504014208442097, 0.5428400826910413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 225}], {
             RGBColor[
             0.985599818104902, 0.9707702529066091, 0.6093604989717086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 240}], {
             RGBColor[
             0.9914461945381696, 0.9895914408365102, 0.7086031402605037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 243}], {
             RGBColor[
             0.9916246135877238, 0.9899730611425737, 0.7280229527297417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 285}], {
             RGBColor[
             0.9734039445076328, 0.929630707535722, 0.5619818330437949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 337}], {
             RGBColor[
             0.9870320709808549, 0.9889054423370784, 0.8645756739791417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 357}], {
             RGBColor[
             0.9736697738575935, 0.9305274123528391, 0.5630145298707316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 399}], {
             RGBColor[
             0.9854242486622709, 0.9878626732256804, 0.8742986182874763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 36}], {
             RGBColor[
             0.9022108967565958, 0.7786458322511358, 0.6137044021858165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 151}], {
             RGBColor[
             0.9458041574059467, 0.8090211884315033, 0.40054997610940324`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 168}], {
             RGBColor[
             0.9307333774615363, 0.7589735900383237, 0.27485405724390743`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 265}], {
             RGBColor[
             0.9458122137239902, 0.8090384200811793, 0.40142685661059707`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 267}], {
             RGBColor[
             0.9427919871675783, 0.8090691565741577, 0.544498893138082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 282}], {
             RGBColor[
             0.9443796160731526, 0.8050055571645032, 0.32786711737410823`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 291}], {
             RGBColor[
             0.9451152661412177, 0.8074870775829369, 0.3307249789726827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 304}], {
             RGBColor[
             0.9463187336303036, 0.8105275568697445, 0.48605157732344895`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 378}], {
             RGBColor[
             0.9463187336303036, 0.8105275568697445, 0.48605157732344895`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 383}], {
             RGBColor[
             0.8827838851754126, 0.560630823748256, 0.2239043393715225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.9753565107880462, 0.9303632957174429, 0.5291054090474934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 87}], {
             RGBColor[
             0.9360903223328152, 0.7837754724017763, 0.270304504995401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 119}], {
             RGBColor[
             0.9757589259478164, 0.9305297047276058, 0.5224363484330495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 127}], {
             RGBColor[
             0.9659279765008455, 0.8967292056251013, 0.3221370519778738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 129}], {
             RGBColor[
             0.9260773966306858, 0.7412263194656399, 0.26210037829565574`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 231}], {
             RGBColor[
             0.9722110466415717, 0.9290625654581344, 0.581233890154846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 235}], {
             RGBColor[
             0.9725279417581625, 0.9291936097326776, 0.575982117974664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 317}], {
             RGBColor[
             0.965264042647371, 0.8944896008382498, 0.31955779433051323`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 326}], {
             RGBColor[
             0.9726740051756707, 0.929254010709476, 0.5735614691465449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 327}], {
             RGBColor[
             0.9758701293566219, 0.9293955715477233, 0.43481125247676444`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 336}], {
             RGBColor[
             0.9304987716274713, 0.8975141912354679, 0.64064486244762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 396}], {
             RGBColor[
             0.9638886250812695, 0.9232550883938417, 0.6132062421867319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 54}], {
             RGBColor[
             0.990079506254222, 0.99016563513813, 0.8140717849897692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 63}], {
             RGBColor[
             0.9771487362461698, 0.9820896168585249, 0.9061663053550604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 224}], {
             RGBColor[
             0.9874839294543483, 0.9890922974281011, 0.857087209701112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 297}], {
             RGBColor[
             0.966354587783685, 0.9065105215202219, 0.5742191722284179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 318}], {
             RGBColor[
             0.9883358184070724, 0.9894445754026, 0.8429692051365336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 345}], {
             RGBColor[
             0.9714244545007893, 0.9778204569054713, 0.9158560212182015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 81}], {
             RGBColor[
             0.9894812693123758, 0.9892455377298426, 0.7750871268245909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 106}], {
             RGBColor[
             0.9537119294391228, 0.8600625366611945, 0.5820345095915856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 164}], {
             RGBColor[
             0.9807609708039882, 0.9851275655491925, 0.9154545214228933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 192}], {
             RGBColor[
             0.9862242282041951, 0.9885713785883172, 0.8779637194184836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 241}], {
             RGBColor[
             0.9894054551635458, 0.9898868976898125, 0.8252425559505768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 271}], {
             RGBColor[
             0.9411430578547334, 0.8083872819277459, 0.5718259191441928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 287}], {
             RGBColor[
             0.9870670160189534, 0.9889198930083788, 0.8639965442629894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 292}], {
             RGBColor[
             0.9797301963845478, 0.9575867298221509, 0.6322882891714463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 371}], {
             RGBColor[
             0.9782224168853917, 0.9832343161932038, 0.9197516310461773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 374}], {
             RGBColor[
             0.9654851387777323, 0.9737348750358901, 0.9413125204682655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 382}], {
             RGBColor[
             0.9714343888991747, 0.9296030232257597, 0.6000606436225626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 384}], {
             RGBColor[
             0.9514710079427007, 0.8511780296707023, 0.5802314115543764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 389}], {
             RGBColor[
             0.9893895147526031, 0.9890492840042977, 0.7651002092368342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 78}], {
             RGBColor[
             0.9254226099895171, 0.9433708855508168, 0.9927488287469584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 104}], {
             RGBColor[
             0.8902600500943281, 0.7081909653913283, 0.6005362185348107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 172}], {
             RGBColor[
             0.9541540840836028, 0.9614131377131792, 0.7390461192297099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 194}], {
             RGBColor[
             0.9521792889879452, 0.962510924980927, 0.9109314028829065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 208}], {
             RGBColor[
             0.9164344565249796, 0.8231839397677334, 0.6221771683672641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 217}], {
             RGBColor[
             0.9546249767020797, 0.9624203294095542, 0.7902998747385376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 223}], {
             RGBColor[
             0.9540868452796151, 0.9632997485294932, 0.8793182585325008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 230}], {
             RGBColor[
             0.9548407115138078, 0.9628817643577054, 0.8137812776342214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 240}], {
             RGBColor[
             0.9546032974867336, 0.9623739597600339, 0.7879402259367265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 242}], {
             RGBColor[
             0.8941204362567583, 0.7257200773388284, 0.6037574193754662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 357}], {
             RGBColor[
             0.9368268768061576, 0.9033099312763628, 0.6423516155469544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 364}], {
             RGBColor[
             0.9552079678614173, 0.9636672885499293, 0.8537548646280491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 385}], {
             RGBColor[
             0.9487712260213272, 0.9607868001736586, 0.9533142961139133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 387}], {
             RGBColor[
             0.9451226842915308, 0.9312936378727539, 0.6745792610958381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 92}], {
             RGBColor[
             0.9390342312486494, 0.7965557790697666, 0.5605521632259377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 182}], {
             RGBColor[
             0.9218367757188275, 0.7244422539694995, 0.2557917240663833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 256}], {
             RGBColor[
             0.9438982635851163, 0.798566770401206, 0.4799126814573692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 281}], {
             RGBColor[
             0.9399101490374571, 0.7969179935854989, 0.5460359386628212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 311}], {
             RGBColor[
             0.9432861255910463, 0.7972574691285352, 0.41328523848064314`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 35}], {
             RGBColor[
             0.9787402557916101, 0.9473188926198624, 0.5805527802724344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 85}], {
             RGBColor[
             0.9912679192094963, 0.9890279864604483, 0.6759592085142753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 86}], {
             RGBColor[
             0.9864460842460928, 0.9733124614113962, 0.6104884686945004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 91}], {
             RGBColor[
             0.9071776010982949, 0.9266222443789065, 0.9063978315892702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 93}], {
             RGBColor[
             0.9880375338457712, 0.9893212270709384, 0.8479125522529941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 95}], {
             RGBColor[
             0.96439096090314, 0.9721410048174037, 0.9083316757050673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 125}], {
             RGBColor[
             0.9686598195165, 0.911012891135617, 0.5533827258224333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 162}], {
             RGBColor[
             0.965236499969802, 0.9727716064688772, 0.9069003986171161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 211}], {
             RGBColor[
             0.9886279882589026, 0.9895653951447545, 0.838127194580367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 214}], {
             RGBColor[
             0.9191570694497702, 0.936174347268367, 0.9075404439748316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 248}], {
             RGBColor[
             0.9888304217086914, 0.9896491065785444, 0.8347723484363947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 263}], {
             RGBColor[
             0.9919211314361119, 0.9909271944784499, 0.7835512897526585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 340}], {
             RGBColor[
             0.9914326564761264, 0.9893803428162773, 0.6938898433463935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 42}], {
             RGBColor[
             0.9800385646366917, 0.9443275327309617, 0.3769540223246584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 85}], {
             RGBColor[
             0.9808659474625372, 0.9465688327780674, 0.42690706987901195`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 86}], {
             RGBColor[
             0.9760441124991337, 0.9308533077290153, 0.36143633005923703`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 93}], {
             RGBColor[
             0.977635562098812, 0.9468620733885575, 0.5988604136177308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 97}], {
             RGBColor[
             0.9800479882612669, 0.9443593208294265, 0.3769906313266313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 98}], {
             RGBColor[
             0.9742572315362665, 0.9248257386616623, 0.35449463494265376`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 125}], {
             RGBColor[
             0.9582578477695409, 0.868553737453236, 0.30433058718717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 162}], {
             RGBColor[
             0.9548345282228429, 0.9303124527864962, 0.6578482599818528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 211}], {
             RGBColor[
             0.9782260165119435, 0.9471062414623737, 0.5890750559451037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 214}], {
             RGBColor[
             0.908755097702811, 0.8937151935859862, 0.6584883053395683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 248}], {
             RGBColor[
             0.9784284499617322, 0.9471899528961636, 0.5857202098011314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 263}], {
             RGBColor[
             0.9815191596891528, 0.9484680407960691, 0.5344991511173952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 340}], {
             RGBColor[
             0.9810306847291672, 0.9469211891338964, 0.44483770471113016`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 80}], {
             RGBColor[
             0.9501159384886964, 0.9585775818104758, 0.7698177584546573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 151}], {
             RGBColor[
             0.9501892632301054, 0.9587344160180813, 0.7777987040491866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 168}], {
             RGBColor[
             0.9351184832856951, 0.9086868176249018, 0.6521027851836908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 265}], {
             RGBColor[
             0.9501973195481489, 0.9587516476677576, 0.7786755845503804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 277}], {
             RGBColor[
             0.9353829420283175, 0.9095788990616331, 0.6531301574599362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 304}], {
             RGBColor[
             0.9507038394544625, 0.9602407844563227, 0.8633003052632323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 378}], {
             RGBColor[
             0.9507038394544625, 0.9602407844563227, 0.8633003052632323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 383}], {
             RGBColor[
             0.8871689909995715, 0.710344051334834, 0.6011530673113059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 41}], {
             RGBColor[
             0.8943801724698883, 0.5247270459850438, 0.2538867236254276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 114}], {
             RGBColor[
             0.9032306778123059, 0.5619525496345568, 0.49691039809524695`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 170}], {
             RGBColor[
             0.9049261966182198, 0.562653690233648, 0.4688112636192401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 187}], {
             RGBColor[
             0.9046300092045954, 0.5625312091264449, 0.4737198555714536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 206}], {
             RGBColor[
             0.8894695516646758, 0.5525119582105595, 0.5570346666849528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 256}], {
             RGBColor[
             0.9063002617677021, 0.5632214904452038, 0.4460095698845693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 261}], {
             RGBColor[
             0.8894695516646758, 0.5525119582105595, 0.5570346666849528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 311}], {
             RGBColor[
             0.9056881237736321, 0.5619121891725329, 0.37938212690784334`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 361}], {
             RGBColor[
             0.8894695516646758, 0.5525119582105595, 0.5570346666849528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 53}], {
             RGBColor[
             0.979147601771645, 0.9480647070476443, 0.5777927382226784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 58}], {
             RGBColor[
             0.9183215993234146, 0.6764046255726215, 0.5076414606160755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 102}], {
             RGBColor[
             0.9896631293979219, 0.9899934526076528, 0.8209722270474245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 103}], {
             RGBColor[
             0.9781133092554832, 0.9823045780344756, 0.881944764966923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 117}], {
             RGBColor[
             0.9577034113370193, 0.8668205808849633, 0.5408782716320539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 145}], {
             RGBColor[
             0.9819393023766578, 0.9574817687108268, 0.5886379679047309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 189}], {
             RGBColor[
             0.9908687739797504, 0.9904920176258913, 0.8009915762183671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 222}], {
             RGBColor[
             0.9837596918572014, 0.986515640933734, 0.8723869120346515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 254}], {
             RGBColor[
             0.9499854426526202, 0.9606745757823031, 0.9069427620865493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 303}], {
             RGBColor[
             0.9807304171387061, 0.9534039149434637, 0.58394167703411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 376}], {
             RGBColor[
             0.9904704658993082, 0.9903273069985778, 0.8075925718995624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 150}], {
             RGBColor[
             0.9120528681493447, 0.619284167706095, 0.48009913593841963`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 237}], {
             RGBColor[
             0.9087822576113815, 0.6179316861977903, 0.5343016166212187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 251}], {
             RGBColor[
             0.9050223613274968, 0.6153420357208448, 0.5502707248935359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 283}], {
             RGBColor[
             0.9035164606753436, 0.614218937480155, 0.5528198218958382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 294}], {
             RGBColor[
             0.9134983698706998, 0.6195654660402319, 0.4331405827654572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 320}], {
             RGBColor[
             0.8858606287893058, 0.6010512469683194, 0.582706539900443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 347}], {
             RGBColor[
             0.9012400334085268, 0.5797039367738678, 0.25892942625187754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 381}], {
             RGBColor[
             0.9110802895307518, 0.6188819814531764, 0.49621728060128517`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 51}], {
             RGBColor[
             0.9415555404031164, 0.9529665149033157, 0.8633107823966004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 84}], {
             RGBColor[
             0.8573082192382844, 0.8890583192816663, 0.9862520173506715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 102}], {
             RGBColor[
             0.9390824261380151, 0.9519438185985588, 0.9042966859838832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 134}], {
             RGBColor[
             0.9235093847879717, 0.94125443223617, 0.9720794879837117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 163}], {
             RGBColor[
             0.9407608574332708, 0.9526378930728638, 0.8764807357805442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 167}], {
             RGBColor[
             0.9353749158674562, 0.93298011417788, 0.6875650589999021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 174}], {
             RGBColor[
             0.9365630600917221, 0.9509019959936625, 0.9460491012812854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 183}], {
             RGBColor[
             0.934449456886451, 0.9494135200944918, 0.9535607995487672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 189}], {
             RGBColor[
             0.9402880707198435, 0.9524423836167972, 0.8843160351548258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 226}], {
             RGBColor[
             0.8687886367841733, 0.8982124926051256, 0.9873470298248881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 234}], {
             RGBColor[
             0.9370879957585353, 0.9511190703821211, 0.9373495587922329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 246}], {
             RGBColor[
             0.9392654152425547, 0.9520194892958913, 0.9012640829610403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 269}], {
             RGBColor[
             0.9279728807203469, 0.9080113115461774, 0.6588095502104294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 272}], {
             RGBColor[
             0.8582856126948548, 0.889837666293297, 0.9863452420110885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 350}], {
             RGBColor[
             0.9249894233511671, 0.8979474092908308, 0.6472193817098152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 355}], {
             RGBColor[
             0.9262566183062931, 0.9433033144959522, 0.9674291382304497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 392}], {
             RGBColor[
             0.5593675809322654, 0.6366379692705835, 0.9628232020023291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 395}], {
             RGBColor[
             0.9223618291629394, 0.9403985871299708, 0.9740220003264498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 55}], {
             RGBColor[
             0.9389807104446195, 0.9218128049864913, 0.667250667713291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 83}], {
             RGBColor[
             0.9473329772425771, 0.9284726758149401, 0.6680473143766368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.9784974019011234, 0.9518105450988079, 0.6163177752785655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 135}], {
             RGBColor[
             0.9749414110951162, 0.9493846807595472, 0.6324662911446477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 156}], {
             RGBColor[
             0.9728326417064036, 0.9200202626559357, 0.348960372464852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 165}], {
             RGBColor[
             0.9814381981642861, 0.9530266399286424, 0.5675811706611928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 187}], {
             RGBColor[
             0.9816911816744838, 0.9531312551114888, 0.5633885791968811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 206}], {
             RGBColor[
             0.9665307241345642, 0.9431120041956034, 0.6467033903103805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 245}], {
             RGBColor[
             0.9828181889240382, 0.9535973015719448, 0.5447111524704957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 256}], {
             RGBColor[
             0.9833614342375905, 0.9538215364302476, 0.5356782935099969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 311}], {
             RGBColor[
             0.9827492962435205, 0.9525122351575768, 0.4690508505332709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 328}], {
             RGBColor[
             0.9780993427610563, 0.9377860819934939, 0.3694205115291377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 386}], {
             RGBColor[
             0.9261620548305907, 0.7336626858773281, 0.2829367225574134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 400}], {
             RGBColor[
             0.9815473848323992, 0.9530717914218765, 0.5657716650045193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 45}], {
             RGBColor[
             0.936855470110156, 0.7703700003231628, 0.32281718237773976`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 93}], {
             RGBColor[
             0.989335842690853, 0.9863298671820377, 0.6443137943052182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 98}], {
             RGBColor[
             0.9859575121283074, 0.9642935324551425, 0.3999480156301411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 125}], {
             RGBColor[
             0.9699581283615817, 0.9080215312467164, 0.3497839678746573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 139}], {
             RGBColor[
             0.5853329226143663, 0.644594663262221, 0.6779542015060729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 148}], {
             RGBColor[
             0.9891673611189414, 0.9862601957222734, 0.6471059699681221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 204}], {
             RGBColor[
             0.991719642341866, 0.9873156295985883, 0.6048080650121881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 248}], {
             RGBColor[
             0.990128730553773, 0.9866577466896438, 0.6311735904886187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 275}], {
             RGBColor[
             0.9715102122484653, 0.9734908943142662, 0.6948795804493295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 276}], {
             RGBColor[
             0.9756699914446225, 0.9295913095643478, 0.35998294040929374`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 288}], {
             RGBColor[
             0.9873777086253466, 0.9853248471315035, 0.6680200479891255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 290}], {
             RGBColor[
             0.9282251633026257, 0.7311817927695339, 0.3156158428293587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 318}], {
             RGBColor[
             0.9909399345799013, 0.9869932004014405, 0.6177298404469496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 56}], {
             RGBColor[
             0.954835001023554, 0.8562548023478098, 0.5425168828013012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 59}], {
             RGBColor[
             0.9278660214004864, 0.8369453389250583, 0.6243079262310223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[
             0.9126317901348749, 0.8247979764360513, 0.6228548716531495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 121}], {
             RGBColor[
             0.9545923582638605, 0.8561544633310421, 0.5465381012687569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 122}], {
             RGBColor[
             0.9575985222808627, 0.8568433857329991, 0.45643342717810986`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 175}], {
             RGBColor[
             0.9538110586667432, 0.8558313758691503, 0.5594862575315326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 213}], {
             RGBColor[
             0.9086184654625983, 0.6732356325061037, 0.2452180140787053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 227}], {
             RGBColor[
             0.876421338916007, 0.7959247455406402, 0.6194010864904425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 237}], {
             RGBColor[
             0.9530202062389639, 0.8555043380662832, 0.5725927289203103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 274}], {
             RGBColor[
             0.9549673820704767, 0.85630954531275, 0.5403229862626246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 296}], {
             RGBColor[
             0.931744346738589, 0.8398513109022367, 0.6182117940232799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 308}], {
             RGBColor[
             0.9567945622072727, 0.8551237964284221, 0.3689273346342741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 373}], {
             RGBColor[
             0.9573625284050616, 0.8563386186953015, 0.4307469501825435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 380}], {
             RGBColor[
             0.9187550106565829, 0.829680466269668, 0.6234389098927735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 46}], {
             RGBColor[
             0.9843222454702661, 0.9658984309721144, 0.6005109850547177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 65}], {
             RGBColor[
             0.9920246823999487, 0.9909700154631348, 0.78183518230058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 68}], {
             RGBColor[
             0.9894389062749893, 0.9899007305840488, 0.8246881844652585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 113}], {
             RGBColor[
             0.9916801757059555, 0.9897641258758001, 0.7102446172835973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 149}], {
             RGBColor[
             0.9875351530421416, 0.9891134796980399, 0.8562383022889808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 161}], {
             RGBColor[
             0.9922494470699806, 0.990981739761286, 0.772206292122114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 195}], {
             RGBColor[
             0.9920965706439901, 0.9909997430994895, 0.7806438080560018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 247}], {
             RGBColor[
             0.9910481392889268, 0.9905661897907141, 0.7980190288627724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 249}], {
             RGBColor[
             0.9898379579980907, 0.9900657487267127, 0.8180748647007139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 250}], {
             RGBColor[
             0.9867885274008804, 0.9742177790346118, 0.6100920246368913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 266}], {
             RGBColor[
             0.9621928652856286, 0.8850738273747917, 0.5467124845208559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 315}], {
             RGBColor[
             0.9722415847230987, 0.9249136514071115, 0.554797920054005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 316}], {
             RGBColor[
             0.9920833379803151, 0.9906264492146966, 0.7541263428184927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 358}], {
             RGBColor[
             0.9913873140649314, 0.9891377244385036, 0.6783684349906723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 362}], {
             RGBColor[
             0.9765484651976709, 0.9811800050959514, 0.886496211730764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 363}], {
             RGBColor[
             0.984788526897773, 0.9674713077151804, 0.6023224003507224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 369}], {
             RGBColor[
             0.9921131101266443, 0.9906901288252692, 0.7573668572140446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 372}], {
             RGBColor[
             0.9732785781015959, 0.9787413286536473, 0.892031277661278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 66}], {
             RGBColor[
             0.9375988000894951, 0.7724315198306377, 0.3636215963039195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 91}], {
             RGBColor[
             0.8535925348248001, 0.7102055582887268, 0.6032088530070883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 123}], {
             RGBColor[
             0.8962101446187194, 0.6198043181083142, 0.23501484033187484`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 140}], {
             RGBColor[
             0.9173653991698905, 0.7606163864731359, 0.5940391669290312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 148}], {
             RGBColor[
             0.9342839860003649, 0.7728348695209943, 0.5475157493337162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 179}], {
             RGBColor[
             0.8573953411465085, 0.7132378128252292, 0.6035715680688581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 203}], {
             RGBColor[
             0.9307834839969835, 0.7498877653932939, 0.2992286629264277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 232}], {
             RGBColor[
             0.9360106581099941, 0.7735488928117752, 0.5189003239929815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 257}], {
             RGBColor[
             0.9353380073990294, 0.7652512422813443, 0.3169221262938005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 275}], {
             RGBColor[
             0.9166268371298887, 0.7600655681129871, 0.5952893598149236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 276}], {
             RGBColor[
             0.9207866163260459, 0.7161659833630687, 0.26039271977488776`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 279}], {
             RGBColor[
             0.9369650543048547, 0.7739435601652135, 0.5030835091459637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 280}], {
             RGBColor[
             0.8329736155233695, 0.6940556379653361, 0.6011649673536389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 288}], {
             RGBColor[
             0.93249433350677, 0.7718995209302244, 0.5684298273547195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 297}], {
             RGBColor[
             0.9140753288379373, 0.6906338203177832, 0.2493895869044278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 325}], {
             RGBColor[
             0.8573953411465085, 0.7132378128252292, 0.6035715680688581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 339}], {
             RGBColor[
             0.9335996260546919, 0.7593872738155442, 0.31016884303682085`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 149}], {
             RGBColor[
             0.9825463546896179, 0.9651640544960051, 0.6299420911480745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 153}], {
             RGBColor[
             0.9790750810766609, 0.9410774764462799, 0.3732110706325421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 161}], {
             RGBColor[
             0.987260648717457, 0.9670323145592512, 0.5459100809812079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 184}], {
             RGBColor[
             0.9646903066090922, 0.8908048478465578, 0.32643987754787895`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 195}], {
             RGBColor[
             0.9871077722914665, 0.9670503178974548, 0.5543475969150955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 247}], {
             RGBColor[
             0.9860593409364031, 0.9666167645886793, 0.5717228177218663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 250}], {
             RGBColor[
             0.9817997290483568, 0.950268353832577, 0.38379581349598507`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 315}], {
             RGBColor[
             0.9672527863705751, 0.9009642262050768, 0.32850170891309877`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 343}], {
             RGBColor[
             0.9728852050332356, 0.9201975710997963, 0.34916457106384313`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 356}], {
             RGBColor[
             0.9870014344692526, 0.9664778814929228, 0.5176962097490665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 358}], {
             RGBColor[
             0.9863985157124078, 0.9651882992364688, 0.45207222384976614`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 362}], {
             RGBColor[
             0.9715596668451473, 0.9572305798939166, 0.6602000005898578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 363}], {
             RGBColor[
             0.9797997285452493, 0.9435218825131457, 0.37602618920981623`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 369}], {
             RGBColor[
             0.9871243117741206, 0.9667407036232345, 0.5310706460731384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 372}], {
             RGBColor[
             0.9682897797490723, 0.9547919034516126, 0.6657350665203717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.8641743164481107, 0.4377756035499234, 0.20687423160258545`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.9095255093809946, 0.6252882834324345, 0.5389750821782741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 173}], {
             RGBColor[
             0.8958832326183942, 0.6152532779710966, 0.5683097184462677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 201}], {
             RGBColor[
             0.9137227757107587, 0.6254223793938689, 0.35299744678584133`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 209}], {
             RGBColor[
             0.9022186043845504, 0.5871854428794323, 0.2598938022119109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 323}], {
             RGBColor[
             0.9133360807979731, 0.6245952780762738, 0.31090809193351654`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 346}], {
             RGBColor[
             0.9143553843716352, 0.6267754653529372, 0.42185299551415256`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 61}], {
             RGBColor[
             0.985775369912306, 0.987349175610083, 0.8389819102539795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 68}], {
             RGBColor[
             0.9915824467822933, 0.9907871396702974, 0.789164170954221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 118}], {
             RGBColor[
             0.9931936630769178, 0.9893029150115575, 0.6061432081190105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 173}], {
             RGBColor[
             0.9756722670826716, 0.9798142980620543, 0.8560838280333158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 176}], {
             RGBColor[
             0.9942661541663125, 0.9915968650062899, 0.7228772445518307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 209}], {
             RGBColor[
             0.9820076388488278, 0.95174646297039, 0.547667911798959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 344}], {
             RGBColor[
             0.9245788215966555, 0.7098405277660944, 0.4782981663688299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 354}], {
             RGBColor[
             0.993526601620224, 0.9900150368904388, 0.642381513899359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 388}], {
             RGBColor[
             0.9511501429933708, 0.8336810985223719, 0.5005784944399221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 52}], {
             RGBColor[
             0.9662764654639235, 0.9615321257291927, 0.6866387553037037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 62}], {
             RGBColor[
             0.989246928540421, 0.9772189364213898, 0.5830670590301797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.94998074008519, 0.8306311131057231, 0.32426615497808736`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 127}], {
             RGBColor[
             0.9798183942532203, 0.9435848463290482, 0.37609870196056017`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[
             0.9399678143830605, 0.7880819601695868, 0.3160620282783421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 133}], {
             RGBColor[
             0.9688666120281098, 0.9634638527957871, 0.6822543127889531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 199}], {
             RGBColor[
             0.9688644291292543, 0.9054986475490951, 0.3394604144400927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 216}], {
             RGBColor[
             0.9899556130294219, 0.9766684385312698, 0.5100046240904098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 231}], {
             RGBColor[
             0.9861014643939465, 0.9759182061620812, 0.6351955401375322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 235}], {
             RGBColor[
             0.9864183595105372, 0.9760492504366245, 0.6299437679573503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 298}], {
             RGBColor[
             0.9903662005304508, 0.9775466436792062, 0.5546945397250566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 313}], {
             RGBColor[
             0.9894293149389383, 0.9755427401326247, 0.4527203248765841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 361}], {
             RGBColor[
             0.9736135775540471, 0.9670041319125884, 0.6742189383604358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 393}], {
             RGBColor[
             0.9760471448888481, 0.9688190824462821, 0.6700995436386312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 396}], {
             RGBColor[
             0.9777790428336444, 0.9701107290977886, 0.6671678921694184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.98744990542151, 0.9693277254637243, 0.40574568175940806`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 147}], {
             RGBColor[
             0.9116748444752278, 0.6173305950109769, 0.29781918193594864`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 164}], {
             RGBColor[
             0.9836020435458154, 0.9804117754089996, 0.669959333257415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 271}], {
             RGBColor[
             0.9439841305965606, 0.803671491787553, 0.3263307309787145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 287}], {
             RGBColor[
             0.9899080887607807, 0.9842041028681859, 0.6185013560975112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 371}], {
             RGBColor[
             0.981063489627219, 0.9785185260530109, 0.674256442880699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 391}], {
             RGBColor[
             0.9880204894313253, 0.983423532036366, 0.649783761937061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 84}], {
             RGBColor[
             0.9104583974340255, 0.9281704972092217, 0.8603447091394614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 102}], {
             RGBColor[
             0.9922326043337562, 0.9910559965261142, 0.7783893777726731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 134}], {
             RGBColor[
             0.9766595629837128, 0.9803666101637254, 0.8461721797725017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 163}], {
             RGBColor[
             0.9939110356290118, 0.9917500710004192, 0.7505734275693341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 167}], {
             RGBColor[
             0.9885250940631973, 0.9720922921054354, 0.561657750788692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 174}], {
             RGBColor[
             0.9897132382874632, 0.9900141739212179, 0.8201417930700754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 183}], {
             RGBColor[
             0.9875996350821921, 0.9885256980220472, 0.8276534913375571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 189}], {
             RGBColor[
             0.9934382489155846, 0.9915545615443526, 0.7584087269436158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 222}], {
             RGBColor[
             0.9863291667930357, 0.9875781848521954, 0.8298040627599002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 226}], {
             RGBColor[
             0.9219388149799144, 0.937324670532681, 0.861439721613678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 234}], {
             RGBColor[
             0.9902381739542764, 0.9902312483096765, 0.8114422505810228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 238}], {
             RGBColor[
             0.6237992798565464, 0.6876077407735617, 0.837558359707095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 246}], {
             RGBColor[
             0.9924155934382958, 0.9911316672234467, 0.7753567747498302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 269}], {
             RGBColor[
             0.981123058916088, 0.9471234894737328, 0.5329022419992194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 272}], {
             RGBColor[
             0.9114357908905959, 0.9289498442208524, 0.8604379337998784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 350}], {
             RGBColor[
             0.9781396015469082, 0.9370595872183862, 0.5213120734986052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 355}], {
             RGBColor[
             0.9794067965020342, 0.9824154924235076, 0.8415218300192397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 392}], {
             RGBColor[
             0.6125177591280064, 0.6757501471981389, 0.836915893791119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 395}], {
             RGBColor[
             0.9755120073586805, 0.9795107650575262, 0.8481146921152398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 89}], {
             RGBColor[
             0.9524431559369166, 0.9640527640817134, 0.9653855115740881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 128}], {
             RGBColor[
             0.9475676468947865, 0.8961241142487728, 0.6259305790033309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 133}], {
             RGBColor[
             0.9495360257132908, 0.9618846311209222, 0.9703065247416908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 199}], {
             RGBColor[
             0.9495338428144351, 0.9039194258742302, 0.6275126263928303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 299}], {
             RGBColor[
             0.9709552928019256, 0.9757956226221649, 0.834004261482209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 342}], {
             RGBColor[
             0.943519339967217, 0.957397396742919, 0.9804912043068281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 393}], {
             RGBColor[
             0.9567165585740289, 0.9672398607714172, 0.9581517555913689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 58}], {
             RGBColor[
             0.9079024323678707, 0.6345157276263174, 0.2628650261038608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 64}], {
             RGBColor[
             0.9806039846974576, 0.9486669588148018, 0.5536567041437677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 117}], {
             RGBColor[
             0.9472842443814753, 0.8249316829386591, 0.2961018371198393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 126}], {
             RGBColor[
             0.9769863790975106, 0.9471709859310005, 0.613609790998074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 289}], {
             RGBColor[
             0.9809609347387575, 0.9470127895142262, 0.4167709278682779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 303}], {
             RGBColor[
             0.9703112501831622, 0.9115150169971595, 0.3391652425218954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 376}], {
             RGBColor[
             0.9800512989437642, 0.9484384090522737, 0.5628161373873477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 63}], {
             RGBColor[
             0.9806976296173169, 0.9835571754698937, 0.8473519579535155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 66}], {
             RGBColor[
             0.9934269524063899, 0.9897757796444453, 0.6296368342263647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 204}], {
             RGBColor[
             0.9926644195401844, 0.9912345632111168, 0.7712330823002274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 224}], {
             RGBColor[
             0.9910328228254954, 0.9905598560394699, 0.7982728622995672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 290}], {
             RGBColor[
             0.929169940500944, 0.7351007263820624, 0.48204086011739794`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 297}], {
             RGBColor[
             0.9699034811548322, 0.9079780801315908, 0.515404824826873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 318}], {
             RGBColor[
             0.9918847117782195, 0.9909121340139688, 0.7841548577349888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 345}], {
             RGBColor[
             0.9749733478719363, 0.9792880155168401, 0.8570416738166566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 92}], {
             RGBColor[
             0.9460367674059662, 0.9582962581152117, 0.9400129957410013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 135}], {
             RGBColor[
             0.942480776599959, 0.955870393775951, 0.9561615116070834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 156}], {
             RGBColor[
             0.9403720072112464, 0.9265059756723394, 0.6726555929272877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.9489775636691289, 0.959512352945046, 0.8912763911236287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 221}], {
             RGBColor[
             0.937704372446299, 0.9523081593787952, 0.9642467179535115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 245}], {
             RGBColor[
             0.9503575544288809, 0.9600830145883483, 0.8684063729329314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 255}], {
             RGBColor[
             0.9507807874214549, 0.9600505552271854, 0.846310913464133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 328}], {
             RGBColor[
             0.945638708265899, 0.9442717950098976, 0.6931157319915734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 386}], {
             RGBColor[
             0.8937014203354334, 0.7401483988937319, 0.6066319430198491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 400}], {
             RGBColor[
             0.949086750337242, 0.9595575044382803, 0.889466885466955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 59}], {
             RGBColor[
             0.9621435618579748, 0.9704563069318076, 0.9118879371356909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 90}], {
             RGBColor[
             0.9469093305923634, 0.9583089444428006, 0.9104348825578181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 121}], {
             RGBColor[
             0.9888698987213489, 0.9896654313377913, 0.8341181121734256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 122}], {
             RGBColor[
             0.9918760627383512, 0.9903543537397484, 0.7440134380827785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 137}], {
             RGBColor[
             0.9120611204404666, 0.9305219275971435, 0.9071110291641657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 166}], {
             RGBColor[
             0.9918297405208651, 0.9902552752004404, 0.7389715505770138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 169}], {
             RGBColor[
             0.9824377031626117, 0.9598351818516646, 0.5952203148674393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 175}], {
             RGBColor[
             0.9880885991242316, 0.9893423438758996, 0.8470662684362013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 178}], {
             RGBColor[
             0.9629131995163391, 0.8882821674716328, 0.5490167909282855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 213}], {
             RGBColor[
             0.9428960059200867, 0.8067466005128532, 0.5327980249833739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 274}], {
             RGBColor[
             0.9892449225279651, 0.9898205133194994, 0.8279029971672933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 278}], {
             RGBColor[
             0.989306704969624, 0.9898460619468616, 0.826879102221172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 296}], {
             RGBColor[
             0.9660218871960774, 0.9733622789089862, 0.9057918049279485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 319}], {
             RGBColor[
             0.9873630583651438, 0.9890423141264698, 0.8590903564535801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 352}], {
             RGBColor[
             0.9914772370613256, 0.9895013059440523, 0.7006037244053251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 76}], {
             RGBColor[
             0.9920471242053565, 0.990979295726399, 0.7814632635074419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.9083596193341766, 0.9273025985287973, 0.8951268937175693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 102}], {
             RGBColor[
             0.9901338262339074, 0.9901880978456898, 0.8131715623507811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 144}], {
             RGBColor[
             0.9921993210660804, 0.9898417871615961, 0.6916812248732145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 163}], {
             RGBColor[
             0.991812257529163, 0.9908821723199948, 0.785355612147442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 167}], {
             RGBColor[
             0.9864263159633486, 0.971224393425011, 0.5964399353667998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 174}], {
             RGBColor[
             0.9876144601876143, 0.9891462752407936, 0.8549239776481832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 186}], {
             RGBColor[
             0.9791362104156841, 0.946633155614556, 0.5681192519350398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 188}], {
             RGBColor[
             0.9912540772685761, 0.9906513504376637, 0.7946061035895768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 189}], {
             RGBColor[
             0.9913394708157358, 0.9906866628639283, 0.7931909115217237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 222}], {
             RGBColor[
             0.9842303886931869, 0.9867102861717709, 0.8645862473380082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 228}], {
             RGBColor[
             0.9894861883247036, 0.9899202829266989, 0.8239045985394703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 238}], {
             RGBColor[
             0.6217005017566976, 0.6867398420931373, 0.8723405442852029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 333}], {
             RGBColor[
             0.918650495804503, 0.6755093311456063, 0.4997050077394418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 368}], {
             RGBColor[
             0.975284767204261, 0.9800386563124408, 0.8797288511270079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 117}], {
             RGBColor[
             0.8864582419332451, 0.5532716014636363, 0.22595055951323634`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 289}], {
             RGBColor[
             0.9201349322905272, 0.6753527080392032, 0.34661965026167496`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 303}], {
             RGBColor[
             0.909485247734932, 0.6398549355221366, 0.26901396491529245`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 376}], {
             RGBColor[
             0.9192252964955341, 0.6767783275772508, 0.4926648597807448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 90}], {
             RGBColor[
             0.9199403509692958, 0.938999481020049, 0.9922259259875393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 121}], {
             RGBColor[
             0.9619009190982812, 0.9703559679150398, 0.9159091556031467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 122}], {
             RGBColor[
             0.9649070831152835, 0.9710448903169969, 0.8258044815124996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 175}], {
             RGBColor[
             0.961119619501164, 0.9700328804531481, 0.9288573118659225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 178}], {
             RGBColor[
             0.9359442198932715, 0.8689727040488813, 0.6308078343580066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 213}], {
             RGBColor[
             0.9159270262970192, 0.7874371370901017, 0.6145890684130951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 274}], {
             RGBColor[
             0.9622759429048975, 0.9705110498967479, 0.9096940405970144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 296}], {
             RGBColor[
             0.9390529075730099, 0.9540528154862347, 0.9875828483576697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 319}], {
             RGBColor[
             0.9603940787420763, 0.9697328507037183, 0.9408813998833012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 373}], {
             RGBColor[
             0.9646710892394825, 0.9705401232792994, 0.8001180045169334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.9938373287399014, 0.9907773272225883, 0.6833022895348453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 101}], {
             RGBColor[
             0.990122913915952, 0.9901835853217815, 0.8133524076994743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.994327074710949, 0.9918248443337458, 0.7366081161215942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 259}], {
             RGBColor[
             0.993467459453466, 0.9915666408524433, 0.7579246327364726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 331}], {
             RGBColor[
             0.9837797628979893, 0.9858796657123485, 0.8432023270752584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 335}], {
             RGBColor[
             0.9933967688812755, 0.9898350142324217, 0.6353500677436936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 394}], {
             RGBColor[
             0.9665622977752868, 0.9730389084148487, 0.8723470044938995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 118}], {
             RGBColor[
             0.9853709081518259, 0.9850314162749941, 0.6893659491994409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 130}], {
             RGBColor[
             0.9813549777847748, 0.9716613744452098, 0.658745113570915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 147}], {
             RGBColor[
             0.9055799168384926, 0.6196642439924624, 0.5508186137474557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 164}], {
             RGBColor[
             0.9775071159090802, 0.9827454243904852, 0.922958765068922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 173}], {
             RGBColor[
             0.9678495121575797, 0.9755427993254909, 0.9393065691137463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 176}], {
             RGBColor[
             0.9864433992412205, 0.9873253662697266, 0.8060999856322612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 344}], {
             RGBColor[
             0.9167560666715636, 0.7055690290295311, 0.5615209074492604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 354}], {
             RGBColor[
             0.985703846695132, 0.9857435381538755, 0.7256042549797895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 371}], {
             RGBColor[
             0.9749685619904838, 0.9808521750344965, 0.9272558746922059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 388}], {
             RGBColor[
             0.9433273880682789, 0.8294095997858086, 0.5838012355203526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 87}], {
             RGBColor[
             0.9536206168468683, 0.8447387021230554, 0.508746670657301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 119}], {
             RGBColor[
             0.9932892204618695, 0.991492934448885, 0.7608785140949497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 127}], {
             RGBColor[
             0.9834582710148986, 0.9576924353463805, 0.5605792176397738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 129}], {
             RGBColor[
             0.9436076911447389, 0.8021895491869191, 0.5005425439575557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 216}], {
             RGBColor[
             0.9935954897911002, 0.990776027548602, 0.6944851397696234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 231}], {
             RGBColor[
             0.9897413411556248, 0.9900257951794135, 0.819676055816746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 235}], {
             RGBColor[
             0.9900582362722156, 0.9901568394539568, 0.814424283636564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 298}], {
             RGBColor[
             0.9940060772921291, 0.9916542326965383, 0.7391750554042702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 313}], {
             RGBColor[
             0.9930691917006166, 0.9896503291499569, 0.6372008405557977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 317}], {
             RGBColor[
             0.9827943371614241, 0.9554528305595289, 0.5579999599924133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 336}], {
             RGBColor[
             0.9480290661415245, 0.958477420956747, 0.87908702810952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 361}], {
             RGBColor[
             0.9772534543157254, 0.9811117209299206, 0.8586994540396495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 393}], {
             RGBColor[
             0.9796870216505265, 0.9829266714636143, 0.854580059317845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 396}], {
             RGBColor[
             0.9814189195953227, 0.9842183181151207, 0.851648407848632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 98}], {
             RGBColor[
             0.9739715193185735, 0.9601364477880658, 0.6584675532834716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 139}], {
             RGBColor[
             0.5733469298046324, 0.6404375785951444, 0.9364737391594034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 204}], {
             RGBColor[
             0.9797336495321322, 0.9831585449315117, 0.8633276026655186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 224}], {
             RGBColor[
             0.9781020528174432, 0.9824838377598648, 0.8903673826648584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 290}], {
             RGBColor[
             0.9162391704928918, 0.7270247081024572, 0.5741353804826892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 318}], {
             RGBColor[
             0.9789539417701674, 0.9828361157343638, 0.87624937810028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 345}], {
             RGBColor[
             0.9620425778638841, 0.9712119972372351, 0.9491361941819478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 77}], {
             RGBColor[
             0.9777138703072417, 0.9815227608865928, 0.860950153244922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 94}], {
             RGBColor[
             0.9936418965934557, 0.991638775092659, 0.7550337578979951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 254}], {
             RGBColor[
             0.9514418255784328, 0.9612768275494605, 0.8828067280076386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 289}], {
             RGBColor[
             0.9928364846201141, 0.9895039392276879, 0.6374113283015819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 68}], {
             RGBColor[
             0.9921525448521482, 0.9910228898730344, 0.7797161705702147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 173}], {
             RGBColor[
             0.9762423651525265, 0.9800500482647914, 0.8466358276493094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 176}], {
             RGBColor[
             0.9948362522361673, 0.991832615209027, 0.7134292441678243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 250}], {
             RGBColor[
             0.9895021659780393, 0.9753399383235974, 0.5651200107418475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 363}], {
             RGBColor[
             0.9875021654749319, 0.968593467004166, 0.5573503864556786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 123}], {
             RGBColor[
             0.9518368497166352, 0.8352911638170681, 0.37540947489246057`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 131}], {
             RGBColor[
             0.9229208640459214, 0.936617707152646, 0.7449103607081295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 140}], {
             RGBColor[
             0.972992104267806, 0.9761032321818899, 0.734433801489617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 203}], {
             RGBColor[
             0.9864101890948992, 0.965374611102048, 0.4396232974870134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 232}], {
             RGBColor[
             0.9916373632079098, 0.9890357385205293, 0.6592949585535671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 257}], {
             RGBColor[
             0.990964712496945, 0.9807380879900984, 0.4573167608543862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 275}], {
             RGBColor[
             0.9722535422278045, 0.9755524138217411, 0.7356839943755094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 280}], {
             RGBColor[
             0.8886003206212851, 0.9095424836740902, 0.7415596019142245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 297}], {
             RGBColor[
             0.969702033935853, 0.9061206660265373, 0.3897842214650135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 318}], {
             RGBColor[
             0.9916832645592404, 0.9890547199089154, 0.6585342543731292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 322}], {
             RGBColor[
             0.974667043152288, 0.9257622224158311, 0.3940033930070025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 325}], {
             RGBColor[
             0.9130220462444242, 0.9287246585339833, 0.7439662026294438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 339}], {
             RGBColor[
             0.9892263311526076, 0.9748741195242983, 0.45056347759740656`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 113}], {
             RGBColor[
             0.9742990213211506, 0.9235941531695829, 0.4379845437991473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 124}], {
             RGBColor[
             0.9139965284710205, 0.8797163601470565, 0.635039071226538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 194}], {
             RGBColor[
             0.9718310062190374, 0.9236369927157144, 0.5561858735507004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 208}], {
             RGBColor[
             0.9360861737560717, 0.7843100075025208, 0.2674316390350579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 210}], {
             RGBColor[
             0.9279358699653377, 0.7511602735778575, 0.26083044225653595`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 249}], {
             RGBColor[
             0.9724568036132858, 0.9238957760204956, 0.5458147912162639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 266}], {
             RGBColor[
             0.9448117109008238, 0.8189038546685745, 0.27445241103640583`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 293}], {
             RGBColor[
             0.970049811925593, 0.9229004231007698, 0.5857048725761425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 316}], {
             RGBColor[
             0.9747021835955102, 0.9244564765084795, 0.48186626933404264`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 385}], {
             RGBColor[
             0.9684229432524194, 0.921912867908446, 0.5985687667817071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 387}], {
             RGBColor[
             0.964774401522623, 0.8924197056075414, 0.319833731763632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 161}], {
             RGBColor[
             0.9923773095221802, 0.9910346141711857, 0.7700872803917487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 173}], {
             RGBColor[
             0.9736565890275672, 0.9789807633857054, 0.8894888298139878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 176}], {
             RGBColor[
             0.9922504761112079, 0.990763330329941, 0.7562822463325027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 250}], {
             RGBColor[
             0.98691638985308, 0.9742706534445114, 0.607973012906526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 363}], {
             RGBColor[
             0.9849163893499725, 0.9675241821250801, 0.600203388620357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 106}], {
             RGBColor[
             0.9570078743437118, 0.8614254945811625, 0.5274121728905548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 107}], {
             RGBColor[
             0.9884348133226528, 0.9894855123442459, 0.8413286031947383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 150}], {
             RGBColor[
             0.9915381937869983, 0.9907688399194927, 0.7898975576093403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 212}], {
             RGBColor[
             0.9677327778614981, 0.9039461631669488, 0.5360416820068066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 270}], {
             RGBColor[
             0.9015212708366496, 0.9218100784985708, 0.8899233780147262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 283}], {
             RGBColor[
             0.9830017863129973, 0.9857036096935528, 0.8626182435667591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 294}], {
             RGBColor[
             0.9929836955083535, 0.9910501382536296, 0.742939004436378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 295}], {
             RGBColor[
             0.9856860872380981, 0.9679223100129744, 0.5879993401934858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 320}], {
             RGBColor[
             0.9653459544269595, 0.9725359191817171, 0.8925049615713638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 347}], {
             RGBColor[
             0.9807253590461804, 0.9511886089872655, 0.5687278479227983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 373}], {
             RGBColor[
             0.9926099054151329, 0.9902506390402064, 0.7022542595543726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 380}], {
             RGBColor[
             0.9540023876666541, 0.9635924866145729, 0.8949462192646025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 381}], {
             RGBColor[
             0.9905656151684055, 0.9903666536665742, 0.8060157022722059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 390}], {
             RGBColor[
             0.9904280557804228, 0.9903097693245284, 0.8082954173233614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 108}], {
             RGBColor[
             0.947414924500351, 0.8255965198907309, 0.5304779368999551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 152}], {
             RGBColor[
             0.9494393718548526, 0.8252068445162772, 0.4077495513448751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 154}], {
             RGBColor[
             0.949094191317414, 0.8244685382498023, 0.37017878005204463`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 180}], {
             RGBColor[
             0.9350839868989516, 0.8173336458626905, 0.5931558879629898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 198}], {
             RGBColor[
             0.9418983784349154, 0.8006067312157663, 0.30724536525840535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 236}], {
             RGBColor[
             0.9490795018896304, 0.824437119049102, 0.3685799264904339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 262}], {
             RGBColor[
             0.9446424330114008, 0.809863071636906, 0.3179054991168258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 267}], {
             RGBColor[
             0.946388519223275, 0.8251720749312476, 0.5474881285928119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 284}], {
             RGBColor[
             0.9470678577867169, 0.8254529988854354, 0.5362297305247369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 286}], {
             RGBColor[
             0.9476050518593107, 0.825675142439711, 0.5273270345281613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 332}], {
             RGBColor[
             0.8952912711704268, 0.6171958486609732, 0.23432900977823617`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 72}], {
             RGBColor[
             0.9804070416816647, 0.9817578941618692, 0.7317698184154774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 88}], {
             RGBColor[
             0.9911245798596344, 0.9811669459474981, 0.46732647150854983`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 138}], {
             RGBColor[
             0.9903302408642232, 0.9886495456552433, 0.6921759430362011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 157}], {
             RGBColor[
             0.9917724532665916, 0.9833523750770746, 0.46984333735395145`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 365}], {
             RGBColor[
             0.9519042615688915, 0.9598482820278704, 0.7574024463142774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 88}], {
             RGBColor[
             0.9781272149815674, 0.9746238226242843, 0.6756077487336778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 109}], {
             RGBColor[
             0.9803762535866041, 0.9816920415396881, 0.7284187242702164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 157}], {
             RGBColor[
             0.9787750883885246, 0.9768092517538608, 0.6781246145790795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 181}], {
             RGBColor[
             0.9388004649731765, 0.9532202929420159, 0.9656735719871634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 191}], {
             RGBColor[
             0.9653393210877614, 0.9736707029356811, 0.9435556678322645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 365}], {
             RGBColor[
             0.9389068966908245, 0.9533051587046566, 0.9656837235394055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 370}], {
             RGBColor[
             0.9811348771984818, 0.9833146607368821, 0.8109902227408787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 78}], {
             RGBColor[
             0.9643133322752478, 0.9694896168766152, 0.7380509891778761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 99}], {
             RGBColor[
             0.9914216455119973, 0.9824020986626374, 0.44866103085967013`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 104}], {
             RGBColor[
             0.9291507723800588, 0.7343096967171266, 0.34583837896572844`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 112}], {
             RGBColor[
             0.9892644013678216, 0.9878829902085966, 0.686157192222478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 141}], {
             RGBColor[
             0.9200944475845692, 0.6755038831234039, 0.33758913145119335`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 172}], {
             RGBColor[
             0.9930448063693336, 0.9875318690389774, 0.48434827966062766`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 177}], {
             RGBColor[
             0.9701613031277909, 0.9081229601654026, 0.37941682267230104`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 208}], {
             RGBColor[
             0.9553251788107102, 0.8493026710935316, 0.3674793287981818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 225}], {
             RGBColor[
             0.9876476433391967, 0.9696715031559312, 0.43399974507884914`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 240}], {
             RGBColor[
             0.9934940197724643, 0.9884926910858323, 0.5332423863676443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 243}], {
             RGBColor[
             0.9936724388220186, 0.9888743113918956, 0.5526621988368822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 285}], {
             RGBColor[
             0.9754517697419276, 0.9285319577850442, 0.38662107915093535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 337}], {
             RGBColor[
             0.9890798962151496, 0.9878066925864006, 0.6892149200862823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 399}], {
             RGBColor[
             0.9874720738965657, 0.9867639234750025, 0.6989378643946169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 86}], {
             RGBColor[
             0.9852701784951123, 0.9619749947167637, 0.3972778542572435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 91}], {
             RGBColor[
             0.9060016953473145, 0.9152847776842741, 0.6931872171520135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 95}], {
             RGBColor[
             0.9632150551521594, 0.9608035381227713, 0.6951210612678105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 104}], {
             RGBColor[
             0.9260326078171344, 0.7241146342017475, 0.3062390096058347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 112}], {
             RGBColor[
             0.9861462368048972, 0.9776879276932176, 0.6465578228625842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 141}], {
             RGBColor[
             0.9169762830216447, 0.6653088206080249, 0.29798976209129957`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 148}], {
             RGBColor[
             0.9866931465228792, 0.9779140889165417, 0.6374941134786413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 172}], {
             RGBColor[
             0.989926641806409, 0.9773368065235983, 0.4447489103007339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 179}], {
             RGBColor[
             0.9098045016690228, 0.9183170322207768, 0.6935499322137832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 240}], {
             RGBColor[
             0.9903758552095399, 0.9782976285704532, 0.4936430170077506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 263}], {
             RGBColor[
             0.9907452256851315, 0.9795897277838175, 0.5703406753154017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 279}], {
             RGBColor[
             0.989374214827369, 0.9790227795607609, 0.5930618732908888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 285}], {
             RGBColor[
             0.972333605179003, 0.918336895269665, 0.34702170979104163`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 399}], {
             RGBColor[
             0.9843539093336412, 0.9765688609596235, 0.6593384950347232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 105}], {
             RGBColor[
             0.9864984634581196, 0.9872119602499878, 0.793750018514595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 132}], {
             RGBColor[
             0.9948765594863915, 0.9914498037377155, 0.6837233021825343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 202}], {
             RGBColor[
             0.9942802592070261, 0.9901743777353593, 0.6188196967123626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 215}], {
             RGBColor[
             0.9263495116938374, 0.7189073866818396, 0.43450927401780876`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 218}], {
             RGBColor[
             0.9770447179145557, 0.9328650045213629, 0.48127251310721536`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 229}], {
             RGBColor[
             0.9948949141266676, 0.9914890624573273, 0.6857210915048737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 260}], {
             RGBColor[
             0.994531013330227, 0.990710715449755, 0.6461127355476987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 329}], {
             RGBColor[
             0.9940123924311277, 0.989601437787198, 0.5896640512379356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 341}], {
             RGBColor[
             0.9691191008578005, 0.9024521544252118, 0.4696374632931294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 349}], {
             RGBColor[
             0.990654146062483, 0.9899118902233502, 0.7688308686755448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 77}], {
             RGBColor[
             0.978267146023611, 0.9817515546138489, 0.851780942793025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 103}], {
             RGBColor[
             0.9801229678976654, 0.9831356235288893, 0.8486395204361152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 144}], {
             RGBColor[
             0.9937382828722772, 0.9904781874179729, 0.6661766450390503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 145}], {
             RGBColor[
             0.98394896101884, 0.9583128142052405, 0.5553327233739231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 200}], {
             RGBColor[
             0.743895068737331, 0.795935917228078, 0.8546416917074975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 207}], {
             RGBColor[
             0.9895684874047795, 0.9899543157113002, 0.8225406897994194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 222}], {
             RGBColor[
             0.9857693504993835, 0.9873466864281477, 0.8390816675038438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 333}], {
             RGBColor[
             0.9201894576106995, 0.676145731401983, 0.47420042790527756`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 368}], {
             RGBColor[
             0.9768237290104577, 0.9806750565688176, 0.8542242712928436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 94}], {
             RGBColor[
             0.9788762323218831, 0.9820034274509883, 0.8416868065658456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 103}], {
             RGBColor[
             0.9648040279097234, 0.9732714821599624, 0.9444617795558625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 145}], {
             RGBColor[
             0.968630021030898, 0.9484486728363137, 0.6511549824936704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 200}], {
             RGBColor[
             0.7285761287493889, 0.7860717758591511, 0.9504639508272448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 207}], {
             RGBColor[
             0.9742495474168376, 0.9800901743423733, 0.9183629489191667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 254}], {
             RGBColor[
             0.9366761613068602, 0.9516414799077899, 0.9694597766754889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 333}], {
             RGBColor[
             0.9048705176227575, 0.6662815900330562, 0.5700226870250249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 104}], {
             RGBColor[
             0.9004373594928496, 0.716306075650005, 0.601506939390633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 172}], {
             RGBColor[
             0.9643313934821243, 0.9695282479718559, 0.7400168400855323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 194}], {
             RGBColor[
             0.9623565983864668, 0.9706260352396038, 0.9119021237387288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 208}], {
             RGBColor[
             0.926611765923501, 0.8312990500264101, 0.6231478892230864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 217}], {
             RGBColor[
             0.9648022861006011, 0.970535439668231, 0.79127059559436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 230}], {
             RGBColor[
             0.9650180209123294, 0.9709968746163822, 0.8147519984900438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 233}], {
             RGBColor[
             0.9647157841130058, 0.9716016191658353, 0.8728043108730299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 240}], {
             RGBColor[
             0.9647806068852551, 0.9704890700187107, 0.7889109467925489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 242}], {
             RGBColor[
             0.9042977456552798, 0.7338351875975051, 0.6047281402312885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 244}], {
             RGBColor[
             0.9000007224495719, 0.714323408815653, 0.6011425987387687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 264}], {
             RGBColor[
             0.964570051482228, 0.9715413549778509, 0.8752194777089778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 285}], {
             RGBColor[
             0.9467383568547183, 0.9105283367179224, 0.64228963957584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 357}], {
             RGBColor[
             0.9470041862046791, 0.9114250415350396, 0.6433223364027767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 385}], {
             RGBColor[
             0.9589485354198488, 0.9689019104323353, 0.9542850169697357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 100}], {
             RGBColor[
             0.9895974582107967, 0.989966295884104, 0.8220605685696734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 137}], {
             RGBColor[
             0.9128836848979311, 0.9308620791392475, 0.8934790073753993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 175}], {
             RGBColor[
             0.9889111635816962, 0.9896824954180035, 0.8334342466474347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 213}], {
             RGBColor[
             0.9437185703775512, 0.8070867520549571, 0.5191660031946075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 227}], {
             RGBColor[
             0.91152144383096, 0.9297758650894934, 0.8933490756063447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[
             0.9774637759359261, 0.9406224058621597, 0.5590700174613548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 278}], {
             RGBColor[
             0.9901292694270887, 0.9901862134889656, 0.8132470804324055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 302}], {
             RGBColor[
             0.9426414748508312, 0.8021959128301726, 0.5182672482850849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 314}], {
             RGBColor[
             0.9765794081984898, 0.9376392258243673, 0.5556344158002482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 352}], {
             RGBColor[
             0.9922998015187903, 0.9898414574861563, 0.6869717026165586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 379}], {
             RGBColor[
             0.988676773702561, 0.989585569179436, 0.8373186935262675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 151}], {
             RGBColor[
             0.9937091991380473, 0.9889529379908433, 0.556663332378244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 168}], {
             RGBColor[
             0.9786384191936369, 0.9389053395976636, 0.43096741351274814`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 265}], {
             RGBColor[
             0.9937172554560907, 0.9889701696405194, 0.5575402128794378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 304}], {
             RGBColor[
             0.9942237753624042, 0.9904593064290845, 0.6421649335922897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 378}], {
             RGBColor[
             0.9942237753624042, 0.9904593064290845, 0.6421649335922897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 192}], {
             RGBColor[
             0.991245172739541, 0.9899749571272257, 0.7458546822007222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 271}], {
             RGBColor[
             0.9461640023900795, 0.8097908604666544, 0.43971688192643127`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 287}], {
             RGBColor[
             0.9920879605542994, 0.9903234715472873, 0.731887507045228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 292}], {
             RGBColor[
             0.9847511409198939, 0.9589903083610594, 0.5001792519536848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 374}], {
             RGBColor[
             0.9705060833130783, 0.9751384535747986, 0.809203483250504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 382}], {
             RGBColor[
             0.9764553334345207, 0.9310066017646682, 0.4679516064048011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 384}], {
             RGBColor[
             0.9564919524780466, 0.8525816082096107, 0.44812237433661495`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 101}], {
             RGBColor[
             0.9904753413729908, 0.9893870590472365, 0.7390191207489578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 136}], {
             RGBColor[
             0.9946795021679877, 0.9910283180592008, 0.6622748291710776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 259}], {
             RGBColor[
             0.9938198869105046, 0.9907701145778982, 0.6835913457859562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 331}], {
             RGBColor[
             0.984132190355028, 0.9850831394378035, 0.7688690401247419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 335}], {
             RGBColor[
             0.993749196338314, 0.9890384879578766, 0.5610167807931772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 120}], {
             RGBColor[
             0.9581845302357972, 0.9646816291651668, 0.7438665781224404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 187}], {
             RGBColor[
             0.9575828139772841, 0.9662768389563412, 0.8878804463226627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 206}], {
             RGBColor[
             0.9424223564373646, 0.9562575880404558, 0.971195257436162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 217}], {
             RGBColor[
             0.9586146311792706, 0.9656015715933804, 0.7906804115441787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 220}], {
             RGBColor[
             0.9347271010649734, 0.8830717713616778, 0.6340662267117632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 230}], {
             RGBColor[
             0.9588303659909987, 0.9660630065415317, 0.8141618144398625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 244}], {
             RGBColor[
             0.8938130675282412, 0.7093895407408025, 0.6005524146885874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 245}], {
             RGBColor[
             0.9587098212268386, 0.9667428854167972, 0.8692030195962772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 321}], {
             RGBColor[
             0.9302093782051621, 0.8651605056644259, 0.6304311608541743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 328}], {
             RGBColor[
             0.9539909750638565, 0.9509316658383463, 0.6939123786549192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 364}], {
             RGBColor[
             0.9591976223386082, 0.9668485307337555, 0.8541354014336902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 102}], {
             RGBColor[
             0.9079852831689241, 0.9271478009044648, 0.9013306127267442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 163}], {
             RGBColor[
             0.9096637144641798, 0.9278418753787698, 0.873514662523405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 167}], {
             RGBColor[
             0.9042777728983653, 0.908184096483786, 0.6845989857427629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 174}], {
             RGBColor[
             0.9054659171226311, 0.9261059782995685, 0.9430830280241462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 183}], {
             RGBColor[
             0.90335231391736, 0.9246175024003978, 0.9505947262916281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 189}], {
             RGBColor[
             0.9091909277507526, 0.9276463659227032, 0.8813499618976868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 222}], {
             RGBColor[
             0.9020818456282037, 0.923669989230546, 0.9527452977139712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 226}], {
             RGBColor[
             0.8376914938150823, 0.8734164749110316, 0.9843809565677489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 234}], {
             RGBColor[
             0.9059908527894444, 0.9263230526880271, 0.9343834855350938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 238}], {
             RGBColor[
             0.5395519586917144, 0.6236995451519123, 0.960499594661166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 246}], {
             RGBColor[
             0.9081682722734638, 0.9272234716017973, 0.8982980097039013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 269}], {
             RGBColor[
             0.896875737751256, 0.8832152938520834, 0.6558434769532904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 272}], {
             RGBColor[
             0.8271884697257639, 0.865041648599203, 0.9833791687539495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 395}], {
             RGBColor[
             0.8912646861938485, 0.9156025694358768, 0.9710559270693107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 88}], {
             RGBColor[
             0.9911191820199803, 0.9811554005142833, 0.46673894997380155`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 162}], {
             RGBColor[
             0.9673621916407291, 0.9720215466270821, 0.7532546882236937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 181}], {
             RGBColor[
             0.9517924320115894, 0.9597518708320149, 0.7568047732272871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 191}], {
             RGBColor[
             0.9783312881261743, 0.9802022808256801, 0.7346868690723882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 211}], {
             RGBColor[
             0.9907536799298298, 0.9888153353029595, 0.6844814841869444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 214}], {
             RGBColor[
             0.9212827611206973, 0.9354242874265719, 0.7538947335814092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 263}], {
             RGBColor[
             0.9940468231070391, 0.9901771346366548, 0.6299055793592361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 307}], {
             RGBColor[
             0.9775068571048875, 0.9795874215198862, 0.7360824157453792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 312}], {
             RGBColor[
             0.9570487215357304, 0.9639430934203866, 0.7573061228144449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 340}], {
             RGBColor[
             0.9935583481470536, 0.9886302829744823, 0.540244132952971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 348}], {
             RGBColor[
             0.971783456852304, 0.9142193533093793, 0.4005399859357662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 91}], {
             RGBColor[
             0.9044814578058186, 0.9101566594880593, 0.687281381376073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 93}], {
             RGBColor[
             0.9853413905532948, 0.9728556421800912, 0.6287961020397967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 95}], {
             RGBColor[
             0.9616948176106637, 0.9556754199265566, 0.68921522549187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 125}], {
             RGBColor[
             0.9659636762240237, 0.8945473062447697, 0.33426627560923594`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 148}], {
             RGBColor[
             0.9851729089813834, 0.972785970720327, 0.6315882777027007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 162}], {
             RGBColor[
             0.9625403566773256, 0.9563060215780299, 0.6877839484039188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 179}], {
             RGBColor[
             0.908284264127527, 0.9131889140245619, 0.6876440964378427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 214}], {
             RGBColor[
             0.9164609261572938, 0.9197087623775199, 0.6884239937616343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 263}], {
             RGBColor[
             0.9892249881436356, 0.9744616095876028, 0.5644348395394612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 264}], {
             RGBColor[
             0.9886450622650168, 0.9742217953333786, 0.5740457121482389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 285}], {
             RGBColor[
             0.9708133676375073, 0.9132087770734503, 0.341115874015101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 119}], {
             RGBColor[
             0.9540230320066385, 0.8449051111332182, 0.5020776100428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 127}], {
             RGBColor[
             0.9441920825596676, 0.8111046120307137, 0.3017783135876814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 129}], {
             RGBColor[
             0.9043415026895079, 0.6556017258712523, 0.2417416399054634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 216}], {
             RGBColor[
             0.9543293013358692, 0.8441882042329354, 0.4356842357175311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 231}], {
             RGBColor[
             0.9504751527003938, 0.8434379718637468, 0.5608751517646535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 235}], {
             RGBColor[
             0.9507920478169846, 0.84356901613829, 0.5556233795844716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 298}], {
             RGBColor[
             0.9547398888368981, 0.8450664093808717, 0.48037415135217787`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 313}], {
             RGBColor[
             0.9538030032453856, 0.8430625058342902, 0.3783999365037054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 317}], {
             RGBColor[
             0.9435281487061931, 0.8088650072438622, 0.2991990559403209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 361}], {
             RGBColor[
             0.9379872658604944, 0.8345238976142539, 0.5998985499875572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 393}], {
             RGBColor[
             0.9404208331952955, 0.8363388481479477, 0.5957791552657526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 396}], {
             RGBColor[
             0.9421527311400917, 0.8376304947994542, 0.5928475037965397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 109}], {
             RGBColor[
             0.9910937917645737, 0.9811010933253171, 0.4639753773632888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 157}], {
             RGBColor[
             0.9894926265664943, 0.9762183035394898, 0.4136812676721519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 181}], {
             RGBColor[
             0.9495180031511462, 0.9526293447276448, 0.7012302250802359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 191}], {
             RGBColor[
             0.9760568592657313, 0.9730797547213101, 0.6791123209253369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 365}], {
             RGBColor[
             0.9496244348687943, 0.9527142104902855, 0.701240376632478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 370}], {
             RGBColor[
             0.9918524153764516, 0.982723712522511, 0.5465468758339512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 128}], {
             RGBColor[
             0.9530649236825985, 0.9002239742761584, 0.616625123320978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 133}], {
             RGBColor[
             0.9550333025011029, 0.9659844911483078, 0.9610010690593378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 155}], {
             RGBColor[
             0.8991277714869719, 0.9218305497742686, 0.9703556276685508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 170}], {
             RGBColor[
             0.9752369129805842, 0.9796665022881975, 0.8647422915651077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 171}], {
             RGBColor[
             0.9761051208450509, 0.9791523249171219, 0.7868811541457837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 199}], {
             RGBColor[
             0.9550311196022473, 0.908019285901616, 0.6182071707104773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 299}], {
             RGBColor[
             0.9764525695897378, 0.9798954826495505, 0.8246988057998559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 306}], {
             RGBColor[
             0.88496537990591, 0.9106024530376852, 0.9689876606404485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 342}], {
             RGBColor[
             0.9490166167550291, 0.9614972567703047, 0.971185748624475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 353}], {
             RGBColor[
             0.966109000942356, 0.9465234831755295, 0.6553268493310451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 121}], {
             RGBColor[
             0.9466666878326697, 0.9582086054260328, 0.9144561010252739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 122}], {
             RGBColor[
             0.949672851849672, 0.9588975278279899, 0.8243514269346268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.949626529632186, 0.9587984492886819, 0.8193095394288621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 178}], {
             RGBColor[
             0.9207099886276601, 0.8568253415598743, 0.6293547797801338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 190}], {
             RGBColor[
             0.9340922802802558, 0.9495674900187021, 0.9687392620388037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 212}], {
             RGBColor[
             0.9245597304202362, 0.8720882849170348, 0.6324523723914945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 221}], {
             RGBColor[
             0.93679739432341, 0.9515849596428688, 0.9641602095704813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 268}], {
             RGBColor[
             0.9448126514871296, 0.9574419137505912, 0.9451822813631309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 274}], {
             RGBColor[
             0.9470417116392861, 0.9583636874077408, 0.9082409860191416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 295}], {
             RGBColor[
             0.9425130397968362, 0.9360644317630603, 0.6844100305781737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 319}], {
             RGBColor[
             0.9451598474764649, 0.9575854882147112, 0.9394283453054284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 324}], {
             RGBColor[
             0.9327452789541473, 0.9485628986352026, 0.9710193839296941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 351}], {
             RGBColor[
             0.8838978382628044, 0.9102601597358375, 0.9887881589500633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 373}], {
             RGBColor[
             0.949436857973871, 0.9583927607902923, 0.7986649499390606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 95}], {
             RGBColor[
             0.8824263344628658, 0.9089852028940669, 0.98512458838664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 112}], {
             RGBColor[
             0.9053575161156034, 0.9258695924645131, 0.9365613499814136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 125}], {
             RGBColor[
             0.8866951930762258, 0.8478570892122801, 0.6301756385040058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 148}], {
             RGBColor[
             0.9059044258335855, 0.9260957536878374, 0.9274976405974706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 179}], {
             RGBColor[
             0.8290157809797292, 0.8664986969920723, 0.9835534593326127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 257}], {
             RGBColor[
             0.9069584472322499, 0.9185121264481872, 0.696904017557555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 263}], {
             RGBColor[
             0.9099565049958377, 0.9277713925551131, 0.8603442024342312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 279}], {
             RGBColor[
             0.9085854941380753, 0.9272044443320564, 0.8830654004097183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 285}], {
             RGBColor[
             0.8915448844897094, 0.8665185600409606, 0.637025236909871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 288}], {
             RGBColor[
             0.9041147733399906, 0.9251604050970673, 0.9484117186184741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 135}], {
             RGBColor[
             0.9819974680564629, 0.9858681338882676, 0.905228619172358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 165}], {
             RGBColor[
             0.9884942551256328, 0.9895100930573627, 0.8403434986889031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 182}], {
             RGBColor[
             0.9683560033326484, 0.9161804731272611, 0.5843196641467212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 256}], {
             RGBColor[
             0.9904174911989372, 0.9903049895589678, 0.8084406215377071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 281}], {
             RGBColor[
             0.9864293766512778, 0.9886562127432607, 0.8745638787431592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 311}], {
             RGBColor[
             0.9898053532048672, 0.988995688286297, 0.7418131785609812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 386}], {
             RGBColor[
             0.9332181117919374, 0.7701461390060484, 0.5556990505851237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 98}], {
             RGBColor[
             0.9835545095904277, 0.9668280731127383, 0.6218544069232135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 125}], {
             RGBColor[
             0.9675551258237021, 0.910556071904312, 0.5716903591677297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 148}], {
             RGBColor[
             0.9867643585810617, 0.9887947363798693, 0.8690123612611944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 162}], {
             RGBColor[
             0.9641318062770041, 0.9723147872375721, 0.9252080319624125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 214}], {
             RGBColor[
             0.9180523757569723, 0.9357175280370621, 0.9258480773201281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 248}], {
             RGBColor[
             0.9877257280158933, 0.9891922873472396, 0.853079981781691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 276}], {
             RGBColor[
             0.9732669889067428, 0.9321258502219435, 0.5818893317023661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 288}], {
             RGBColor[
             0.984974706087467, 0.9878593877890992, 0.889926439282198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 290}], {
             RGBColor[
             0.9258221607647461, 0.7337163334271296, 0.537522234122431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 103}], {
             RGBColor[
             0.9807320541959375, 0.9833874963660285, 0.8385453842089358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 145}], {
             RGBColor[
             0.984558047317112, 0.9585646870423798, 0.5452385871467437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 207}], {
             RGBColor[
             0.9901775737030516, 0.9902061885484396, 0.8124465535722398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 254}], {
             RGBColor[
             0.9526041875930744, 0.961757494113856, 0.8635433813285621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 125}], {
             RGBColor[
             0.9439085528810709, 0.8933758496507773, 0.6321094826198029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 162}], {
             RGBColor[
             0.940485233334373, 0.9551345649840375, 0.9856271554144858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 233}], {
             RGBColor[
             0.9667356715528419, 0.9731106029273706, 0.869473752322858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 263}], {
             RGBColor[
             0.9671698648006828, 0.9732901529936103, 0.8622780465500282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 264}], {
             RGBColor[
             0.966589938922064, 0.9730503387393862, 0.871888919158806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 285}], {
             RGBColor[
             0.9487582442945545, 0.9120373204794578, 0.638959081025668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 312}], {
             RGBColor[
             0.930171763229374, 0.9470561117773422, 0.989678590005237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 173}], {
             RGBColor[
             0.926037493157662, 0.7905302473562892, 0.5949730000494005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 201}], {
             RGBColor[
             0.9438770362500265, 0.8006993487790617, 0.37966072838897413`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 209}], {
             RGBColor[
             0.9323728649238181, 0.7624624122646249, 0.2865570838150436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 223}], {
             RGBColor[
             0.9436284834778066, 0.8021981473509812, 0.5001979611897918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 245}], {
             RGBColor[
             0.9442618049478391, 0.802460042054459, 0.4897021854479272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 323}], {
             RGBColor[
             0.9434903413372411, 0.7998722474614666, 0.3375713735366493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 109}], {
             RGBColor[
             0.9925502614237467, 0.9860141074810462, 0.4696334869579594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 181}], {
             RGBColor[
             0.9509744728103192, 0.957542358883374, 0.7068883346749065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 191}], {
             RGBColor[
             0.9775133289249043, 0.9779927688770392, 0.6847704305200075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 193}], {
             RGBColor[
             0.9858789141419317, 0.9640284029914128, 0.3996426772950561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 211}], {
             RGBColor[
             0.9899357207285597, 0.9866058233543187, 0.6345650456345638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 214}], {
             RGBColor[
             0.9204648019194273, 0.9332147754779312, 0.7039782950290285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 248}], {
             RGBColor[
             0.9901381541783483, 0.9866895347881086, 0.6312101994905915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 305}], {
             RGBColor[
             0.9933663622447059, 0.9877596646166279, 0.5584610249289064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 334}], {
             RGBColor[
             0.9933223667253627, 0.9876655626493821, 0.5536723841572702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 340}], {
             RGBColor[
             0.9927403889457833, 0.9864207710258415, 0.4903276944005904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 360}], {
             RGBColor[
             0.9832026019637292, 0.9550005735863529, 0.38924570986188634`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 370}], {
             RGBColor[
             0.9933088850356246, 0.9876367266782402, 0.5522049854286218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 125}], {
             RGBColor[
             0.9641767952611566, 0.8885197371774168, 0.3273245804926527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 139}], {
             RGBColor[
             0.5795515895139411, 0.6250928691929215, 0.6554948141240682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 193}], {
             RGBColor[
             0.9800881574169313, 0.9444948208236486, 0.37714668091107856`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 204}], {
             RGBColor[
             0.9859383092414409, 0.9678138355292889, 0.5823486776301835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 248}], {
             RGBColor[
             0.9843473974533479, 0.9671559526203444, 0.608714203106614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 276}], {
             RGBColor[
             0.9698886583441972, 0.9100895154950484, 0.3375235530272891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 290}], {
             RGBColor[
             0.9224438302022007, 0.7116799987002345, 0.293156455447354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 318}], {
             RGBColor[
             0.9851586014794761, 0.9674914063321409, 0.5952704530649449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 141}], {
             RGBColor[
             0.9184893479341094, 0.6704127438423045, 0.3038677335578919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 169}], {
             RGBColor[
             0.9827897053528593, 0.953607776365154, 0.3876416844976388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 177}], {
             RGBColor[
             0.9685562034773312, 0.9030318208843031, 0.3456954247789996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 197}], {
             RGBColor[
             0.98994726899606, 0.9837379841953159, 0.614518255451636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 225}], {
             RGBColor[
             0.986042543688737, 0.9645803638748318, 0.40027834718554767`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 243}], {
             RGBColor[
             0.9920673391715589, 0.9837831721107962, 0.5189408009435807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 252}], {
             RGBColor[
             0.9264882898066491, 0.9355176783564885, 0.700874900804656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 300}], {
             RGBColor[
             0.9786954062162885, 0.939796743990347, 0.3717361054955762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 337}], {
             RGBColor[
             0.9874747965646898, 0.9827155533053011, 0.6554935221929808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 367}], {
             RGBColor[
             0.9857022166631615, 0.981549908258309, 0.6654953581135807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 398}], {
             RGBColor[
             0.9764228112615336, 0.9321307475772884, 0.3629075032399006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 146}], {
             RGBColor[
             0.9874237353015352, 0.9890674055989936, 0.8580847825906999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 175}], {
             RGBColor[
             0.9877509513965212, 0.9892027178633405, 0.8526619650886713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 213}], {
             RGBColor[
             0.9425583581923763, 0.8066069745002941, 0.5383937216358441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 227}], {
             RGBColor[
             0.9103612316457851, 0.9292960875348304, 0.9125767940475813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 278}], {
             RGBColor[
             0.9889690572419136, 0.9897064359343026, 0.8324747988736421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 302}], {
             RGBColor[
             0.9414812626656561, 0.8017161352755096, 0.5374949667263215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 314}], {
             RGBColor[
             0.9754191960133147, 0.9371594482697043, 0.5748621342414848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 352}], {
             RGBColor[
             0.9911395893336152, 0.9893616799314933, 0.7061994210577953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 377}], {
             RGBColor[
             0.930630659978303, 0.7524460826948821, 0.528440957871384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 136}], {
             RGBColor[
             0.9909650873440383, 0.990434576158394, 0.7923249473357066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 301}], {
             RGBColor[
             0.944327793804345, 0.9567018274348649, 0.9297869754439831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 335}], {
             RGBColor[
             0.9900347815143647, 0.9884447460570698, 0.6910668989578062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 394}], {
             RGBColor[
             0.9632003104083762, 0.9716486402394968, 0.9280638357080119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 163}], {
             RGBColor[
             0.9914379213639106, 0.9907273746956622, 0.7915593311566169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 167}], {
             RGBColor[
             0.9860519797980961, 0.9710695958006785, 0.6026436543759748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 174}], {
             RGBColor[
             0.9872401240223618, 0.988991477616461, 0.8611276966573581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 189}], {
             RGBColor[
             0.9909651346504833, 0.9905318652395958, 0.7993946305308985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 222}], {
             RGBColor[
             0.9838560525279345, 0.9865554885474384, 0.870789966347183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 226}], {
             RGBColor[
             0.919465700714813, 0.9363019742279239, 0.9024256252009608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 395}], {
             RGBColor[
             0.9730388930935793, 0.9784880687527693, 0.8891005957025225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 145}], {
             RGBColor[
             0.9704858429049523, 0.9498327417513539, 0.6480135601367607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 200}], {
             RGBColor[
             0.7304319506234433, 0.7874558447741914, 0.947322528470335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 207}], {
             RGBColor[
             0.9761053692908919, 0.9814742432574137, 0.915221526562257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 222}], {
             RGBColor[
             0.9723062323854958, 0.9788666139742611, 0.9317625042666814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 254}], {
             RGBColor[
             0.9385319831809146, 0.9530255488228302, 0.9663183543185792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 333}], {
             RGBColor[
             0.9067263394968119, 0.6676656589480965, 0.5668812646681152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 112}], {
             RGBColor[
             0.9253884285854235, 0.7346994489819865, 0.5496131424352348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 141}], {
             RGBColor[
             0.856218474802171, 0.4223203418967938, 0.2010450816639502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 172}], {
             RGBColor[
             0.9291688335869352, 0.7343483278123673, 0.34780422987338444`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 208}], {
             RGBColor[
             0.891449206028312, 0.5961191298669215, 0.23093527901093866`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 240}], {
             RGBColor[
             0.9296180469900661, 0.7353091498592221, 0.3966983365804012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 242}], {
             RGBColor[
             0.8691351857600907, 0.49865526743801664`, 0.21251553001914078`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 243}], {
             RGBColor[
             0.9297964660396203, 0.7356907701652855, 0.41611814904963906`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 285}], {
             RGBColor[
             0.9115757969595293, 0.675348416558434, 0.25007702936369225`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 337}], {
             RGBColor[
             0.9252039234327514, 0.7346231513597905, 0.552670870299039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 357}], {
             RGBColor[
             0.9118416263094901, 0.6762451213755509, 0.251109726190629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 399}], {
             RGBColor[
             0.9235961011141675, 0.7335803822483924, 0.5623938146073737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 114}], {
             RGBColor[
             0.9837134337125177, 0.9865516521212468, 0.8756228163963463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 171}], {
             RGBColor[
             0.9862771603828983, 0.9867386153492623, 0.7696625445010156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 202}], {
             RGBColor[
             0.9860663075493301, 0.9862876224587516, 0.7467125147999664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 218}], {
             RGBColor[
             0.9688307662568596, 0.9289782492447551, 0.6091653311948191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 229}], {
             RGBColor[
             0.9866809624689715, 0.9876023071807195, 0.8136139095924775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 261}], {
             RGBColor[
             0.9699523075648876, 0.9771110606972496, 0.9357470849860523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 349}], {
             RGBColor[
             0.9824401944047869, 0.9860251349467425, 0.8967236867631486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 353}], {
             RGBColor[
             0.9762810404802034, 0.95410977360767, 0.638108239686277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.9543904730801566, 0.860343131894538, 0.5707892854450025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 150}], {
             RGBColor[
             0.9574938535445021, 0.861626459469785, 0.5193582398596046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 158}], {
             RGBColor[
             0.953997248477181, 0.8601805234157964, 0.5773060347489571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 241}], {
             RGBColor[
             0.9586570598256388, 0.8621074751600729, 0.50008090149981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 270}], {
             RGBColor[
             0.8674769305941534, 0.792667698048863, 0.6193840602649903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 292}], {
             RGBColor[
             0.9489818010466408, 0.8298073072924113, 0.3071266347206796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 310}], {
             RGBColor[
             0.951206560959646, 0.8373119448774464, 0.31576940687204774`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 320}], {
             RGBColor[
             0.9313016141844632, 0.8433935387320095, 0.6219656438216279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 347}], {
             RGBColor[
             0.9466810188036843, 0.8220462285375578, 0.29818853017306246`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 374}], {
             RGBColor[
             0.9347367434398253, 0.8459554525061505, 0.6161508660174986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 384}], {
             RGBColor[
             0.9207226126047936, 0.7233986071409626, 0.25506975710360963`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 389}], {
             RGBColor[
             0.958641119414696, 0.861269861474558, 0.43993855478606747`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 390}], {
             RGBColor[
             0.9563837155379267, 0.8611673888748206, 0.5377560995736255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 158}], {
             RGBColor[
             0.985424187456122, 0.9882405411788797, 0.8912224650531407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 190}], {
             RGBColor[
             0.9746479264579624, 0.9803430055819918, 0.9157056842085635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 212}], {
             RGBColor[
             0.9651153765979428, 0.9028638004803244, 0.5794187945612543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 241}], {
             RGBColor[
             0.9900839988045798, 0.9901674929231563, 0.8139973318039937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 268}], {
             RGBColor[
             0.9853682976648361, 0.9882174293138809, 0.8921487035328907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 270}], {
             RGBColor[
             0.8989038695730943, 0.9207277158119463, 0.933300490569174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 295}], {
             RGBColor[
             0.9830686859745428, 0.96683994732635, 0.6313764527479335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 310}], {
             RGBColor[
             0.9826334999385868, 0.9653719626405298, 0.6296858371762314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 324}], {
             RGBColor[
             0.9733009251318538, 0.9793384141984923, 0.9179858060994539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 346}], {
             RGBColor[
             0.9902540624467626, 0.9897277230993826, 0.7741003783890192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 351}], {
             RGBColor[
             0.924453484440511, 0.9410356752991271, 0.9357545811198231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 373}], {
             RGBColor[
             0.9899925041515776, 0.9891682763535821, 0.7456313721088204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 390}], {
             RGBColor[
             0.9878106545168676, 0.989227406637904, 0.8516725298778092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 152}], {
             RGBColor[
             0.991835441311373, 0.9896649230282708, 0.6957933430893373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 154}], {
             RGBColor[
             0.9914902607739344, 0.9889266167617956, 0.6582225717965069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 180}], {
             RGBColor[
             0.977480056355472, 0.9817917243746839, 0.8811996797074519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 198}], {
             RGBColor[
             0.9842944478914358, 0.9650648097277597, 0.5952891570028676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 205}], {
             RGBColor[
             0.9920142573752091, 0.9900473925077391, 0.7152563681130841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 236}], {
             RGBColor[
             0.9914755713461508, 0.9888951975610953, 0.6566237182348962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 262}], {
             RGBColor[
             0.9870385024679212, 0.9743211501488993, 0.605949290861288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 267}], {
             RGBColor[
             0.9887845886797955, 0.989630153443241, 0.8355319203372741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 284}], {
             RGBColor[
             0.9894639272432373, 0.9899110773974289, 0.824273522269199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 286}], {
             RGBColor[
             0.9900011213158311, 0.9901332209517044, 0.8153708262726236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 332}], {
             RGBColor[
             0.9376873406269473, 0.7816539271729666, 0.5223728015226984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 367}], {
             RGBColor[
             0.9856994407108284, 0.9879217277689022, 0.867286405952605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 398}], {
             RGBColor[
             0.9764200353092006, 0.9385025670878817, 0.5646985510789249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 157}], {
             RGBColor[
             0.991741665171531, 0.9832865224548937, 0.4664922432086904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 181}], {
             RGBColor[
             0.9517670417561828, 0.9596975636430487, 0.7540412006167745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 191}], {
             RGBColor[
             0.9783058978707678, 0.980147973636714, 0.7319232964618755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 305}], {
             RGBColor[
             0.9941589311905694, 0.9899148693763027, 0.6056138908707742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 334}], {
             RGBColor[
             0.9941149356712262, 0.9898207674090569, 0.6008252500991381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 340}], {
             RGBColor[
             0.993532957891647, 0.9885759757855161, 0.5374805603424583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 360}], {
             RGBColor[
             0.9839951709095929, 0.9571557783460277, 0.43639857580375424`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 365}], {
             RGBColor[
             0.9518734734738309, 0.9597824294056894, 0.7540513521690164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 370}], {
             RGBColor[
             0.9941014539814882, 0.9897919314379149, 0.5993578513704898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 227}], {
             RGBColor[
             0.9024616098552602, 0.8942346777312626, 0.6660347683857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 237}], {
             RGBColor[
             0.9790604771782171, 0.9538142702569057, 0.6192264108155823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 251}], {
             RGBColor[
             0.9753005808943324, 0.9512246197799603, 0.6351955190878995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 308}], {
             RGBColor[
             0.9828348331465258, 0.9534337286190446, 0.41556101652954597`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 375}], {
             RGBColor[
             0.9615182169819194, 0.880208519489361, 0.3135759266351844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 116}], {
             RGBColor[
             0.9319599409548854, 0.9461271115405855, 0.8976496211739062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 151}], {
             RGBColor[
             0.9336134228841588, 0.9455172908654234, 0.7762176855995628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 154}], {
             RGBColor[
             0.9333069247399293, 0.9448617223266325, 0.7428572540874743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 286}], {
             RGBColor[
             0.9318177852818259, 0.9460683265165413, 0.900005508563591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 291}], {
             RGBColor[
             0.9329245316194297, 0.943983180016857, 0.7063926884628423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 304}], {
             RGBColor[
             0.9341279991085156, 0.9470236593036647, 0.8617192868136085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 383}], {
             RGBColor[
             0.8705931506536246, 0.6971269261821761, 0.599572048861682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 141}], {
             RGBColor[
             0.9163321037899337, 0.6758936353882637, 0.5413638949206997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 172}], {
             RGBColor[
             0.9892824625746981, 0.9879216213038373, 0.688123043130134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 179}], {
             RGBColor[
             0.9091603224373119, 0.9289018470010156, 0.9369240650431834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 240}], {
             RGBColor[
             0.989731675977829, 0.9888824433506921, 0.7370171498371507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 279}], {
             RGBColor[
             0.9887300355956581, 0.9896075943409999, 0.8364360061202889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 285}], {
             RGBColor[
             0.9716894259472921, 0.9289217100499039, 0.5903958426204418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 337}], {
             RGBColor[
             0.9853175524205142, 0.9881964448512603, 0.8929896835557887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 399}], {
             RGBColor[
             0.9837097301019302, 0.9871536757398623, 0.9027126278641233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 124}], {
             RGBColor[
             0.9337468147389911, 0.9458026025549244, 0.7907365657989616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 149}], {
             RGBColor[
             0.9899042849253072, 0.9890297493996907, 0.7396757233769542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 210}], {
             RGBColor[
             0.9476861562333083, 0.8172465159857254, 0.4165279368289595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 249}], {
             RGBColor[
             0.9922070898812563, 0.9899820184283636, 0.7015122857886875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 266}], {
             RGBColor[
             0.9645619971687943, 0.8849900970764426, 0.4301499056088294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 293}], {
             RGBColor[
             0.9898000981935635, 0.9889866655086378, 0.7414023671485659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 315}], {
             RGBColor[
             0.9746107166062643, 0.9248299211087623, 0.4382353411419785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 316}], {
             RGBColor[
             0.9944524698634807, 0.9905427189163475, 0.6375637639064662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 387}], {
             RGBColor[
             0.9845246877905935, 0.9585059480154092, 0.47553122633605555`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 397}], {
             RGBColor[
             0.9592110104911594, 0.9661070610405232, 0.7931653635219593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 128}], {
             RGBColor[
             0.9686658851325401, 0.9110367118561657, 0.5533864934703573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 155}], {
             RGBColor[
             0.9147287329369135, 0.9326432873542758, 0.9071169978179301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 170}], {
             RGBColor[
             0.9908378744305257, 0.9904792398682047, 0.8015036617144871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 187}], {
             RGBColor[
             0.9905416870169013, 0.9903567587610018, 0.8064122536667004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 202}], {
             RGBColor[
             0.9914952294614242, 0.9895140696066185, 0.7006924945941139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 261}], {
             RGBColor[
             0.9753812294769817, 0.9803375078451164, 0.8897270647801998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 306}], {
             RGBColor[
             0.9005663413558516, 0.9214151906176924, 0.9057490307898278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 353}], {
             RGBColor[
             0.9817099623922976, 0.9573362207555367, 0.5920882194804244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 122}], {
             RGBColor[
             0.9833640447650396, 0.9542265268706441, 0.5019997632073024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 166}], {
             RGBColor[
             0.9833177225475536, 0.9541274483313361, 0.49695787570153765`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 169}], {
             RGBColor[
             0.9739256851893001, 0.9237073549825603, 0.3532066399919633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 197}], {
             RGBColor[
             0.9810832488325009, 0.9538375628127223, 0.5800832109459604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 221}], {
             RGBColor[
             0.9704885872387776, 0.9469139586855231, 0.6418085458431569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 239}], {
             RGBColor[
             0.9468836034445007, 0.8223496485262676, 0.3009542962544972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 300}], {
             RGBColor[
             0.9698313860527292, 0.9098963226077532, 0.33730106098990065`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 350}], {
             RGBColor[
             0.966830995014689, 0.8997752991111259, 0.32564510838341876`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 392}], {
             RGBColor[
             0.6012091525957872, 0.6384658590908785, 0.6412489286759326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 151}], {
             RGBColor[
             0.9921290419501831, 0.9897195928736109, 0.6860762135471168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 154}], {
             RGBColor[
             0.9918225438059536, 0.98906402433482, 0.6527157820350282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 265}], {
             RGBColor[
             0.9921370982682265, 0.989736824523287, 0.6869530940483106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 291}], {
             RGBColor[
             0.991440150685454, 0.9881854820250446, 0.6162512164103963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 304}], {
             RGBColor[
             0.9926436181745399, 0.9912259613118521, 0.7715778147611625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 383}], {
             RGBColor[
             0.929108769719649, 0.7413292281903636, 0.509430576809236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 289}], {
             RGBColor[
             0.9595167443041318, 0.8657686633515451, 0.3798564612776534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 303}], {
             RGBColor[
             0.9488670597485366, 0.8302708908344785, 0.3022507759312709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 376}], {
             RGBColor[
             0.9586071085091386, 0.8671942828895927, 0.5259016707967232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 158}], {
             RGBColor[
             0.9889100820847923, 0.9875315441883034, 0.6771332307107836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 164}], {
             RGBColor[
             0.9849254090736921, 0.9846991637919598, 0.690120062933953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 173}], {
             RGBColor[
             0.9752678053221917, 0.9774965387269655, 0.7064678669787773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 209}], {
             RGBColor[
             0.9816031770883478, 0.9494287036353013, 0.39805195074442046`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 241}], {
             RGBColor[
             0.99356989343325, 0.9894584959325798, 0.5999080974616365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 323}], {
             RGBColor[
             0.9927206535017707, 0.9868385388321428, 0.44906624046602617`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 346}], {
             RGBColor[
             0.9937399570754328, 0.9890187261088061, 0.5600111440466622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 354}], {
             RGBColor[
             0.993122139859744, 0.9876972775553501, 0.4927655528448205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 388}], {
             RGBColor[
             0.9507456812328907, 0.8313633391872832, 0.35096253338538347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 389}], {
             RGBColor[
             0.9935539530223072, 0.988620882247065, 0.5397657507478939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 126}], {
             RGBColor[
             0.9894679795002801, 0.9899127531098544, 0.8242063658830949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 127}], {
             RGBColor[
             0.9838606861746688, 0.9578588443565433, 0.55391015702533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 129}], {
             RGBColor[
             0.9440101063045092, 0.8023559581970819, 0.493873483343112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 196}], {
             RGBColor[
             0.9931014440702423, 0.9914152840853139, 0.7639904548539379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 231}], {
             RGBColor[
             0.9901437563153951, 0.9901922041895763, 0.8130069952023021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 235}], {
             RGBColor[
             0.9904606514319858, 0.9903232484641197, 0.8077552230221202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 317}], {
             RGBColor[
             0.9831967523211944, 0.9556192395696919, 0.5513308993779695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 326}], {
             RGBColor[
             0.9906067148494941, 0.990383649440918, 0.8053345741940012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 327}], {
             RGBColor[
             0.9938028390304454, 0.9905252102791654, 0.6665843575242207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 336}], {
             RGBColor[
             0.9484314813012947, 0.95864382996691, 0.8724179674950762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 396}], {
             RGBColor[
             0.9818213347550929, 0.9843847271252837, 0.8449793472341882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 132}], {
             RGBColor[
             0.9940925773915922, 0.9897729453096882, 0.5983916893402699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 160}], {
             RGBColor[
             0.9939050201195903, 0.9893717792698251, 0.5779772377521715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 187}], {
             RGBColor[
             0.9925427346677038, 0.9893402084617153, 0.6392078429426848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 202}], {
             RGBColor[
             0.9934962771122268, 0.988497519307332, 0.5334880838700982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 206}], {
             RGBColor[
             0.9773822771277842, 0.97932095754583, 0.7225226540561841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 217}], {
             RGBColor[
             0.9935745518696903, 0.9886649410987547, 0.5420078081642008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 220}], {
             RGBColor[
             0.969687021755393, 0.9061351408670519, 0.3853936233317853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 233}], {
             RGBColor[
             0.9934880498820949, 0.989731120596359, 0.6235415234428707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 244}], {
             RGBColor[
             0.928772988218661, 0.7324529102461768, 0.35187981130860957`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 307}], {
             RGBColor[
             0.9773822771277842, 0.97932095754583, 0.7225226540561841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 321}], {
             RGBColor[
             0.965169298895582, 0.8882238751698002, 0.3817585574741964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 341}], {
             RGBColor[
             0.9683351187630012, 0.9007752959971844, 0.38430585045086496`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 366}], {
             RGBColor[
             0.9939541448739853, 0.9894768521522017, 0.5833241641052346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 122}], {
             RGBColor[
             0.9916334199786575, 0.9902540147229806, 0.7480346565502343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 175}], {
             RGBColor[
             0.987845956364538, 0.9892420048591317, 0.8510874869036569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 178}], {
             RGBColor[
             0.9626705567566456, 0.888181828454865, 0.5530380093957411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.942653363160393, 0.8066462614960853, 0.5368192434508297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 274}], {
             RGBColor[
             0.9890022797682716, 0.9897201743027315, 0.8319242156347489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 296}], {
             RGBColor[
             0.9657792444363837, 0.9732619398922183, 0.9098130233954043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 319}], {
             RGBColor[
             0.9871204156054503, 0.9889419751097019, 0.8631115749210357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 373}], {
             RGBColor[
             0.9913974261028564, 0.989749247685283, 0.7223481795546678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 166}], {
             RGBColor[
             0.9945932617781738, 0.9908438585856297, 0.6528880949538225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 169}], {
             RGBColor[
             0.9852012244199204, 0.9604237652368539, 0.509136859244248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 175}], {
             RGBColor[
             0.9908521203815402, 0.9899309272610889, 0.76098281281301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 178}], {
             RGBColor[
             0.9656767207736479, 0.8888707508568221, 0.4629333353050941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 268}], {
             RGBColor[
             0.9897793836331172, 0.9894873230475391, 0.7787608368880912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 274}], {
             RGBColor[
             0.9920084437852739, 0.9904090967046887, 0.741819541544102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 319}], {
             RGBColor[
             0.9901265796224525, 0.9896308975116591, 0.7730069008303888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 351}], {
             RGBColor[
             0.9288645704087921, 0.9423055690327853, 0.8223667144750236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 131}], {
             RGBColor[
             0.8815322085751458, 0.7839905054303223, 0.616303604736085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 140}], {
             RGBColor[
             0.9316034487970304, 0.8234760304595663, 0.6058270455175723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 203}], {
             RGBColor[
             0.9450215336241234, 0.8127474093797243, 0.3110165415149687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 232}], {
             RGBColor[
             0.9502487077371341, 0.8364085367982056, 0.5306882025815225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 275}], {
             RGBColor[
             0.9308648867570287, 0.8229252120994175, 0.6070772384034646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 280}], {
             RGBColor[
             0.8472116651505095, 0.7569152819517665, 0.61295284594218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 297}], {
             RGBColor[
             0.9283133784650772, 0.7534934643042136, 0.26117746549296883`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 309}], {
             RGBColor[
             0.9119147650087811, 0.6884784264639934, 0.24798275618110296`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 322}], {
             RGBColor[
             0.9332783876815123, 0.7731350206935074, 0.26539663703495786`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 325}], {
             RGBColor[
             0.8716333907736484, 0.7760974568116596, 0.6153594466573993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 339}], {
             RGBColor[
             0.9478376756818319, 0.8222469178019746, 0.32195672162536193`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 149}], {
             RGBColor[
             0.9296017920751772, 0.9451519563771642, 0.9367302508043449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 185}], {
             RGBColor[
             0.8770559534516771, 0.7264730042621893, 0.6049647699341698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 210}], {
             RGBColor[
             0.8873836633831783, 0.7733687229631989, 0.6135824642563502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 219}], {
             RGBColor[
             0.9336776250253664, 0.9456546127536343, 0.7832056924603276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 249}], {
             RGBColor[
             0.9319045970311264, 0.9461042254058372, 0.8985668132160782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 266}], {
             RGBColor[
             0.9042595043186643, 0.8411123040539161, 0.6272044330362201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 293}], {
             RGBColor[
             0.9294976053434336, 0.9451088724861113, 0.9384568945759566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 315}], {
             RGBColor[
             0.9143082237561344, 0.8809521280862358, 0.6352898685693692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 316}], {
             RGBColor[
             0.9341499770133508, 0.946664925893821, 0.8346182913338569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 338}], {
             RGBColor[
             0.9283984118113775, 0.9445148565500441, 0.9504275724073277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 387}], {
             RGBColor[
             0.9242221949404634, 0.9146281549928827, 0.6725857537634463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 397}], {
             RGBColor[
             0.8989085176410294, 0.9222292680179968, 0.99021989094935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 148}], {
             RGBColor[
             0.9673866442517907, 0.9104864004445478, 0.5744825348306337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 162}], {
             RGBColor[
             0.9447540919477329, 0.8940064513022508, 0.6306782055318517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 211}], {
             RGBColor[
             0.9681455802368335, 0.9108002399781282, 0.5619050014951026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 214}], {
             RGBColor[
             0.898674661427701, 0.8574091921017406, 0.6313182508895672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 248}], {
             RGBColor[
             0.9683480136866223, 0.9108839514119181, 0.5585501553511303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 263}], {
             RGBColor[
             0.9714387234140428, 0.9121620393118235, 0.5073290966673941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 276}], {
             RGBColor[
             0.9538892745774716, 0.853817514286622, 0.2873595052718053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 288}], {
             RGBColor[
             0.9655969917581957, 0.9095510518537777, 0.595396612851637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 196}], {
             RGBColor[
             0.9888777879488825, 0.9896686937361203, 0.833987367256527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 289}], {
             RGBColor[
             0.9892188790201671, 0.9880079663438865, 0.6973644151558881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 317}], {
             RGBColor[
             0.9789730961998346, 0.9538726492204983, 0.6213278117805587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 326}], {
             RGBColor[
             0.9863830587281344, 0.9886370590917244, 0.8753314865965904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 327}], {
             RGBColor[
             0.9895791829090856, 0.988778619929972, 0.7365812699268098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 336}], {
             RGBColor[
             0.944207825179935, 0.9568972396177164, 0.9424148798976653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 376}], {
             RGBColor[
             0.9883092432251739, 0.989433585881934, 0.8434096246749578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 129}], {
             RGBColor[
             0.9341791568575382, 0.7685554590945775, 0.2935741868879362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 216}], {
             RGBColor[
             0.9841669555038995, 0.9571419374562604, 0.4875167827000039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 231}], {
             RGBColor[
             0.9803128068684241, 0.9563917050870718, 0.6127076987471263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 235}], {
             RGBColor[
             0.9806297019850149, 0.9565227493616152, 0.6074559265669444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 298}], {
             RGBColor[
             0.9845775430049284, 0.9580201426041968, 0.5322066983346507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 313}], {
             RGBColor[
             0.9836406574134159, 0.9560162390576152, 0.43023248348617815`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 317}], {
             RGBColor[
             0.9733658028742234, 0.9218187404671874, 0.35103160292279373`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 336}], {
             RGBColor[
             0.9386005318543238, 0.9248433308644055, 0.6721186710399003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 361}], {
             RGBColor[
             0.9678249200285247, 0.947477630837579, 0.65173109697003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 393}], {
             RGBColor[
             0.9702584873633258, 0.9492925813712727, 0.6476117022482254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 396}], {
             RGBColor[
             0.971990385308122, 0.9505842280227792, 0.6446800507790125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 133}], {
             RGBColor[
             0.9501577934589727, 0.8980558413153672, 0.6215461364885806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 155}], {
             RGBColor[
             0.8942522624448418, 0.8539018999413279, 0.6309006950977936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 170}], {
             RGBColor[
             0.970361403938454, 0.9117378524552568, 0.5252873589943504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 171}], {
             RGBColor[
             0.9712296118029207, 0.9112236750841813, 0.44742622157502654`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 199}], {
             RGBColor[
             0.9501556105601172, 0.8400906360686753, 0.27875223813972005`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 261}], {
             RGBColor[
             0.95490475898491, 0.9015961204321685, 0.6135107620600633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 299}], {
             RGBColor[
             0.9715770605476077, 0.91196683281661, 0.4852438732290987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 306}], {
             RGBColor[
             0.8800898708637799, 0.8426738032047445, 0.6295327280696912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 342}], {
             RGBColor[
             0.9441411077128989, 0.8935686069373641, 0.6317308160537178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 353}], {
             RGBColor[
             0.9612334919002259, 0.8785948333425888, 0.3158719167602879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 216}], {
             RGBColor[
             0.9443163756337398, 0.801639051296799, 0.4274801090177859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 231}], {
             RGBColor[
             0.9404622269982644, 0.8008888189276104, 0.5526710250649083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 235}], {
             RGBColor[
             0.9407791221148551, 0.8010198632021538, 0.5474192528847264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 298}], {
             RGBColor[
             0.9447269631347687, 0.8025172564447354, 0.47217002465243263`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 313}], {
             RGBColor[
             0.9437900775432562, 0.8005133528981538, 0.37019580980396016`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 317}], {
             RGBColor[
             0.9335152230040638, 0.766315854307726, 0.2909949292405757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 336}], {
             RGBColor[
             0.8987499519841641, 0.7693404447049441, 0.6120819973576823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 361}], {
             RGBColor[
             0.9279743401583651, 0.7919747446781176, 0.591694423287812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 393}], {
             RGBColor[
             0.930407907493166, 0.7937896952118113, 0.5875750285660074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 396}], {
             RGBColor[
             0.9321398054379623, 0.7950813418633178, 0.5846433770967945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 147}], {
             RGBColor[
             0.9089822796360534, 0.6082479415641527, 0.2873590759839607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 164}], {
             RGBColor[
             0.980909478706641, 0.9713291219621755, 0.6594992273054272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 287}], {
             RGBColor[
             0.9872155239216063, 0.9751214494213618, 0.6080412501455232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 371}], {
             RGBColor[
             0.9783709247880445, 0.9694358726061867, 0.663796336928711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 391}], {
             RGBColor[
             0.9853279245921509, 0.974340878589542, 0.6393236559850731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 140}], {
             RGBColor[
             0.9026874631263166, 0.9248025737951441, 0.9753279313332414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 186}], {
             RGBColor[
             0.9101902406683202, 0.8941202322624949, 0.6575375755401136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 188}], {
             RGBColor[
             0.9223081075212122, 0.9381384270856026, 0.8840244271946508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 203}], {
             RGBColor[
             0.9161055479534098, 0.9140739527153021, 0.6805174273306378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 228}], {
             RGBColor[
             0.9205402185773397, 0.9374073595746378, 0.9133229221445442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 238}], {
             RGBColor[
             0.5527545320093337, 0.6342269187410763, 0.9617588678902769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 273}], {
             RGBColor[
             0.9197914062987129, 0.9265072183947047, 0.6948362909861967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 280}], {
             RGBColor[
             0.8182956794797958, 0.8582418252873443, 0.982453731757849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 309}], {
             RGBColor[
             0.8829987793380675, 0.7898049697995712, 0.617483641996772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 322}], {
             RGBColor[
             0.9043624020107986, 0.8744615640290851, 0.6348975228506268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 325}], {
             RGBColor[
             0.8427174051029348, 0.8774240001472375, 0.9848603324730683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 330}], {
             RGBColor[
             0.8961279585860715, 0.9199105060492321, 0.9864314615270955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 339}], {
             RGBColor[
             0.9189216900111182, 0.9235734611375523, 0.691457607441031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 160}], {
             RGBColor[
             0.9948531465849655, 0.9913997259089725, 0.6811749523499788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 202}], {
             RGBColor[
             0.994444403577602, 0.9905254659464794, 0.6366857984679056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 220}], {
             RGBColor[
             0.9706351482207682, 0.9081630875061992, 0.4885913379295927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 244}], {
             RGBColor[
             0.9297211146840363, 0.734480856885324, 0.45507752590641704`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 260}], {
             RGBColor[
             0.9946951577008027, 0.9910618036608749, 0.6639788373032417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 307}], {
             RGBColor[
             0.9783304035931595, 0.9813489041849774, 0.8257203686539916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 321}], {
             RGBColor[
             0.9661174253609572, 0.8902518218089475, 0.48495627207200387`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 341}], {
             RGBColor[
             0.9692832452283764, 0.9028032426363317, 0.4875035650486724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 348}], {
             RGBColor[
             0.972607003340576, 0.9159808359744706, 0.49017793884437844`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 366}], {
             RGBColor[
             0.9949022713393605, 0.991504798791349, 0.686521878703042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 155}], {
             RGBColor[
             0.896220641263346, 0.9196624168134773, 0.9752766408361534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 199}], {
             RGBColor[
             0.9521239893786214, 0.9058511529408246, 0.6231281838780798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 216}], {
             RGBColor[
             0.973215173278789, 0.9770209439229992, 0.7936723935283969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 298}], {
             RGBColor[
             0.9736257607798179, 0.9778991490709356, 0.8383623091630437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 299}], {
             RGBColor[
             0.9735454393661119, 0.9777273496887592, 0.8296198189674584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 306}], {
             RGBColor[
             0.8820582496822841, 0.9084343200768938, 0.9739086738080511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 342}], {
             RGBColor[
             0.9461094865314033, 0.9593291238095134, 0.9761067617920777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 361}], {
             RGBColor[
             0.9568731378034143, 0.9673566373043179, 0.957886707798423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 393}], {
             RGBColor[
             0.9593067051382153, 0.9691715878380116, 0.9537673130766184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 135}], {
             RGBColor[
             0.968527442309512, 0.9760483985227932, 0.9381590101990265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 226}], {
             RGBColor[
             0.9038926593647697, 0.9256125878655352, 0.9702084272007891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 234}], {
             RGBColor[
             0.9721920183391317, 0.9785191656425307, 0.920210956168134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 239}], {
             RGBColor[
             0.9401460543615752, 0.8479218539663822, 0.6053899669567948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 246}], {
             RGBColor[
             0.9743694378231511, 0.979419584556301, 0.8841254803369415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 269}], {
             RGBColor[
             0.9630769033009433, 0.9354114068065871, 0.6416709475863306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 272}], {
             RGBColor[
             0.8933896352754511, 0.9172377615537066, 0.9692066393869897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 350}], {
             RGBColor[
             0.9600934459317635, 0.9253475045512405, 0.6300807790857164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 355}], {
             RGBColor[
             0.9613606408868896, 0.9707034097563618, 0.9502905356063509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 392}], {
             RGBColor[
             0.5944716035128617, 0.6640380645309931, 0.9456845993782301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 395}], {
             RGBColor[
             0.9574658517435359, 0.9677986823903805, 0.956883397702351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 156}], {
             RGBColor[
             0.9763327078617432, 0.9540778514453954, 0.6378712163586444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 165}], {
             RGBColor[
             0.9849382643196256, 0.987084228718102, 0.8564920145549854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 221}], {
             RGBColor[
             0.9736650730967958, 0.9798800351518512, 0.9294623413848682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 234}], {
             RGBColor[
             0.9821060532800756, 0.9859130366687443, 0.9034290810075476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 255}], {
             RGBColor[
             0.9867414880719516, 0.9876224310002414, 0.8115265368954897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 281}], {
             RGBColor[
             0.9828733858452707, 0.9862303484039999, 0.8907123946092415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 328}], {
             RGBColor[
             0.9815994089163957, 0.9718436707829534, 0.6583313554229301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 355}], {
             RGBColor[
             0.9712746758278334, 0.9780972807825754, 0.9335086604457645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 386}], {
             RGBColor[
             0.9296621209859303, 0.7677202746667877, 0.5718475664512058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 400}], {
             RGBColor[
             0.9850474509877387, 0.9871293802113361, 0.8546825088983117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 331}], {
             RGBColor[
             0.9846219363260756, 0.9861306565489611, 0.8221748667114908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 335}], {
             RGBColor[
             0.9942389423093618, 0.9900860050690343, 0.614322607379926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 394}], {
             RGBColor[
             0.9674044712033731, 0.9732898992514614, 0.8513195441301318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 169}], {
             RGBColor[
             0.9053862821220359, 0.900591339094249, 0.6722344503256353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 175}], {
             RGBColor[
             0.9110371780836557, 0.9300985011184839, 0.9240804038943973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 178}], {
             RGBColor[
             0.8858617784757633, 0.8290383247142172, 0.6260309263864814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 197}], {
             RGBColor[
             0.9125438457652366, 0.9307215469244109, 0.8991110212796325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 252}], {
             RGBColor[
             0.8490848665758257, 0.8825012410855835, 0.9854676666326525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 278}], {
             RGBColor[
             0.9122552839290482, 0.9306022191894461, 0.903893237679368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 282}], {
             RGBColor[
             0.9129715703068795, 0.9261782972520882, 0.7017018625622726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 300}], {
             RGBColor[
             0.9012919829854651, 0.886780306719442, 0.6563288713235726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 314}], {
             RGBColor[
             0.8987054227004493, 0.8780552315248478, 0.6462805730472106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 319}], {
             RGBColor[
             0.9103116373245681, 0.9297984713690541, 0.936104491911776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 352}], {
             RGBColor[
             0.9144258160207498, 0.9302574631866367, 0.777617859863521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 159}], {
             RGBColor[
             0.9910301668884058, 0.9905587577412289, 0.7983168780504853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 215}], {
             RGBColor[
             0.9226213417202866, 0.7178570658312436, 0.5320123462453394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 218}], {
             RGBColor[
             0.9733165479410051, 0.9318146836707669, 0.578775585334746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 229}], {
             RGBColor[
             0.991166744153117, 0.9904387416067313, 0.7832241637324044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 329}], {
             RGBColor[
             0.9902842224575771, 0.988551116936602, 0.6871671234654664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 349}], {
             RGBColor[
             0.9869259760889324, 0.9888615693727543, 0.8663339409030756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 193}], {
             RGBColor[
             0.5794635679029903, 0.6247959516307269, 0.6551528667870103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 204}], {
             RGBColor[
             0.5853137197274998, 0.6481149663363674, 0.8603548635061153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 224}], {
             RGBColor[
             0.5836821230128109, 0.6474402591647206, 0.887394643505455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 276}], {
             RGBColor[
             0.5692640688302562, 0.5903906463021267, 0.6155297389032208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 290}], {
             RGBColor[
             0.5218192406882596, 0.3919811295073129, 0.5711626413232858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 318}], {
             RGBColor[
             0.5845340119655349, 0.6477925371392195, 0.8732766389408766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 203}], {
             RGBColor[
             0.9661767881752945, 0.9535594777445461, 0.6700408681121252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 232}], {
             RGBColor[
             0.9714039622883051, 0.9772206051630273, 0.8897125291786789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 257}], {
             RGBColor[
             0.9707313115773403, 0.9689229546325965, 0.6877343314794979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 275}], {
             RGBColor[
             0.9520201413081997, 0.9637372804642392, 0.966101565000621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 280}], {
             RGBColor[
             0.8683669197016803, 0.8977273503165882, 0.9719771725393364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 288}], {
             RGBColor[
             0.9678876376850809, 0.9755712332814765, 0.9392420325404169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 297}], {
             RGBColor[
             0.9494686330162483, 0.8943055326690353, 0.6202017920901253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 309}], {
             RGBColor[
             0.9330700195599522, 0.8292904948288151, 0.6070070827782594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 322}], {
             RGBColor[
             0.9544336422326833, 0.9139470890583291, 0.6244209636321143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 325}], {
             RGBColor[
             0.8927886453248195, 0.9169095251764814, 0.9743837732545556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 339}], {
             RGBColor[
             0.9689929302330029, 0.9630589861667963, 0.6809810482225183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 172}], {
             RGBColor[
             0.9201125087914457, 0.6755425142186446, 0.3395549823588494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[
             0.9205617221945764, 0.6765033362654995, 0.38844908906586606`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 243}], {
             RGBColor[
             0.9207401412441307, 0.6768849565715629, 0.4078689015351039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 279}], {
             RGBColor[
             0.9195600818124056, 0.6772284872558072, 0.4878679453490043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 285}], {
             RGBColor[
             0.9025194721640397, 0.6165426029647112, 0.24182778184915713`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 337}], {
             RGBColor[
             0.9161475986372617, 0.6758173377660677, 0.544421622784504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 399}], {
             RGBColor[
             0.9145397763186778, 0.6747745686546698, 0.5541445670928387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 143}], {
             RGBColor[
             0.985676659746664, 0.9881330060265304, 0.8775472873972358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 258}], {
             RGBColor[
             0.9889229117967273, 0.989475414674104, 0.8237484898966816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 277}], {
             RGBColor[
             0.9735430943069636, 0.9387891643189316, 0.614554800027787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 302}], {
             RGBColor[
             0.9387207932218687, 0.8003626712869444, 0.5737520308515172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 377}], {
             RGBColor[
             0.9278701905345156, 0.7510926187063169, 0.5646980219965796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 378}], {
             RGBColor[
             0.9888639917331086, 0.9894510497136211, 0.8247249478310831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 379}], {
             RGBColor[
             0.9847560920735985, 0.9877523276362078, 0.8928034760926999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 258}], {
             RGBColor[
             0.9916832644053446, 0.9908288303483237, 0.7874933620326161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 277}], {
             RGBColor[
             0.9763034469155809, 0.9401425799931513, 0.5782996721637215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 302}], {
             RGBColor[
             0.9414811458304859, 0.8017160869611641, 0.5374969029874516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 377}], {
             RGBColor[
             0.9306305431431328, 0.7524460343805367, 0.528442894132514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 378}], {
             RGBColor[
             0.9916243443417257, 0.9908044653878407, 0.7884698199670175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 379}], {
             RGBColor[
             0.9875164446822158, 0.9891057433104276, 0.8565483482286342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 186}], {
             RGBColor[
             0.9808273690826048, 0.9461320473061299, 0.452832633466648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 188}], {
             RGBColor[
             0.9929452359354967, 0.9901502421292374, 0.6793194851211852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 200}], {
             RGBColor[
             0.744047265598055, 0.794798408663275, 0.7648596530732701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 228}], {
             RGBColor[
             0.9911773469916243, 0.9894191746182728, 0.7086179800710786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 333}], {
             RGBColor[
             0.9203416544714236, 0.6750082228371801, 0.3844183892710501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 368}], {
             RGBColor[
             0.9769759258711816, 0.9795375480040147, 0.7644422326586162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 200}], {
             RGBColor[
             0.734257943744618, 0.7626330354505426, 0.654015731408143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 207}], {
             RGBColor[
             0.9799313624120665, 0.956651433933765, 0.6219147295000649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 222}], {
             RGBColor[
             0.9761322255066704, 0.9540438046506123, 0.6384557072044893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 254}], {
             RGBColor[
             0.9423579763020892, 0.9282027394991814, 0.6730115572563871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 333}], {
             RGBColor[
             0.9105523326179865, 0.6428428496244478, 0.273574467605923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 227}], {
             RGBColor[
             0.9093477209216985, 0.928876974804383, 0.9293732896273711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 302}], {
             RGBColor[
             0.9404677519415696, 0.8012970225450622, 0.5542914623061113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 375}], {
             RGBColor[
             0.9684043280483577, 0.9148508165624815, 0.5769144478768411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 377}], {
             RGBColor[
             0.9296171492542165, 0.7520269699644349, 0.5452374534511737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 344}], {
             RGBColor[
             0.8443833685228422, 0.342155596148474, 0.19013486986230604`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 354}], {
             RGBColor[
             0.9133311485464106, 0.6223301052728183, 0.3542182173928352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 371}], {
             RGBColor[
             0.9025958638417624, 0.6174387421534393, 0.5558698371052517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 388}], {
             RGBColor[
             0.8709546899195575, 0.46599616690475154`, 0.2124151979333982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 391}], {
             RGBColor[
             0.9095528636458687, 0.6223437481367946, 0.5313971561616138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 179}], {
             RGBColor[
             0.9097072321552939, 0.9291280082243398, 0.9278603556592404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 232}], {
             RGBColor[
             0.9883225491187795, 0.9894390882108858, 0.8431891115833637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 257}], {
             RGBColor[
             0.9876498984078148, 0.9811414376804549, 0.6412109138841828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 275}], {
             RGBColor[
             0.9689387281386741, 0.9759557635120977, 0.919578147405306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 276}], {
             RGBColor[
             0.9730985073348313, 0.9320561787621793, 0.58468150736527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 279}], {
             RGBColor[
             0.9892769453136401, 0.9898337555643241, 0.8273722967363459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 288}], {
             RGBColor[
             0.9848062245155554, 0.987789716329335, 0.8927186149451019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 195}], {
             RGBColor[
             0.9903206798633419, 0.9902653666233802, 0.8100749141493586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 210}], {
             RGBColor[
             0.9435411335694944, 0.8165958698079652, 0.562521621834343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 247}], {
             RGBColor[
             0.9892722485082786, 0.9898318133146047, 0.8274501349561294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 249}], {
             RGBColor[
             0.9880620672174425, 0.9893313722506034, 0.8475059707940709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 253}], {
             RGBColor[
             0.9715094498301452, 0.9780119956458249, 0.9214509365905084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 266}], {
             RGBColor[
             0.9604169745049804, 0.8843394508986824, 0.5761435906142128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 315}], {
             RGBColor[
             0.9704656939424505, 0.924179274931002, 0.5842290261473619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 316}], {
             RGBColor[
             0.9903074471996669, 0.9898920727385873, 0.7835574489118495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 358}], {
             RGBColor[
             0.9896114232842832, 0.9884033479623942, 0.7077995410840292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 359}], {
             RGBColor[
             0.9038777163705913, 0.9246402766717611, 0.9342766654994881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 362}], {
             RGBColor[
             0.9747725744170227, 0.980445628619842, 0.915927317824121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 363}], {
             RGBColor[
             0.9830126361171247, 0.966736931239071, 0.6317535064440793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 369}], {
             RGBColor[
             0.9903372193459961, 0.9899557523491598, 0.7867979633074015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 397}], {
             RGBColor[
             0.9550659878273455, 0.965456414862763, 0.9391590485273427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 192}], {
             RGBColor[
             0.9900061523095744, 0.9901353013969079, 0.8152874496865025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 283}], {
             RGBColor[
             0.9834877655137875, 0.9859045745821753, 0.8545643105358088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 294}], {
             RGBColor[
             0.9934696747091437, 0.9912511031422522, 0.7348850714054278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 320}], {
             RGBColor[
             0.9658319336277497, 0.9727368840703396, 0.8844510285404136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 347}], {
             RGBColor[
             0.9812113382469707, 0.9513895738758881, 0.560673914891848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 380}], {
             RGBColor[
             0.9544883668674444, 0.9637934515031954, 0.8868922862336523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 381}], {
             RGBColor[
             0.9910515943691958, 0.9905676185551967, 0.7979617692412557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 384}], {
             RGBColor[
             0.95525293204808, 0.8527419524792929, 0.5175551418223953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 168}], {
             RGBColor[
             0.978711743935046, 0.9390621738052691, 0.4389483591072776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 265}], {
             RGBColor[
             0.9937905801974998, 0.9891270038481249, 0.5655211584739672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 291}], {
             RGBColor[
             0.9930936326147274, 0.9875756613498825, 0.49481928083605287`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 304}], {
             RGBColor[
             0.9942971001038133, 0.99061614063669, 0.6501458791868191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 378}], {
             RGBColor[
             0.9942971001038133, 0.99061614063669, 0.6501458791868191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 383}], {
             RGBColor[
             0.9307622516489223, 0.7407194075152015, 0.38799864123489264`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 154}], {
             RGBColor[
             0.993514708128436, 0.988536941387342, 0.5354941862414269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 180}], {
             RGBColor[
             0.9795045037099734, 0.9814020490002303, 0.7584712941523719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 198}], {
             RGBColor[
             0.9863188952459374, 0.9646751343533061, 0.4725607714477875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 236}], {
             RGBColor[
             0.9935000187006524, 0.9885055221866418, 0.5338953326798161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 267}], {
             RGBColor[
             0.990809036034297, 0.9892404780687873, 0.712803534782194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 284}], {
             RGBColor[
             0.9914883745977388, 0.9895214020229752, 0.701545136714119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 332}], {
             RGBColor[
             0.9397117879814488, 0.781264251798513, 0.39964441596761835`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 367}], {
             RGBColor[
             0.98772388806533, 0.9875320523944486, 0.7445580203975249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 383}], {
             RGBColor[
             0.9308009340421314, 0.7408021452428857, 0.39220898101563456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 398}], {
             RGBColor[
             0.9784444826637022, 0.938112891713428, 0.4419701655238448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 161}], {
             RGBColor[
             0.9870022826763754, 0.9661607852354515, 0.5449063776999385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 184}], {
             RGBColor[
             0.9644319405680104, 0.889933318522758, 0.32543617426660965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[
             0.9867430684281709, 0.965606352169123, 0.5166925064677972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 372}], {
             RGBColor[
             0.9680314137079906, 0.9539203741278128, 0.6647313632391023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 180}], {
             RGBColor[
             0.979159323172535, 0.9806637427337552, 0.7209005228595415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 236}], {
             RGBColor[
             0.9931548381632138, 0.9877672159201667, 0.49632456138698566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 267}], {
             RGBColor[
             0.9904638554968586, 0.9885021718023124, 0.6752327634893636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 286}], {
             RGBColor[
             0.9916803881328942, 0.9890052393107758, 0.6550716694247131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 291}], {
             RGBColor[
             0.9927871344704979, 0.9869200928110915, 0.4614588493239644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 332}], {
             RGBColor[
             0.9393666074440103, 0.7805259455320379, 0.3620736446747879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 383}], {
             RGBColor[
             0.9304557535046929, 0.7400638389764106, 0.35463820972280413`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 170}], {
             RGBColor[
             0.9164242517428274, 0.933344427953367, 0.8790178633419233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 171}], {
             RGBColor[
             0.917292459607294, 0.9328302505822914, 0.8011567259225993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 199}], {
             RGBColor[
             0.8962184583644905, 0.8616972115667855, 0.632482742487293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 261}], {
             RGBColor[
             0.9009676067892833, 0.9232026959302786, 0.9672412664076361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.9176399083519811, 0.93357340831472, 0.8389743775766716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 306}], {
             RGBColor[
             0.8261527186681532, 0.8642803787028547, 0.9832632324172641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 342}], {
             RGBColor[
             0.8902039555172723, 0.9151751824354742, 0.9854613204012908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 353}], {
             RGBColor[
             0.9072963397045992, 0.900201408840699, 0.6696024211078608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 361}], {
             RGBColor[
             0.9009676067892833, 0.9232026959302786, 0.9672412664076361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 165}], {
             RGBColor[
             0.982829494930913, 0.9577198106144904, 0.5729860958751898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 221}], {
             RGBColor[
             0.9715563037080832, 0.9505156170482396, 0.6459564227050725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 245}], {
             RGBColor[
             0.984209485690665, 0.9582904722577927, 0.5501160776844926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 255}], {
             RGBColor[
             0.984632718683239, 0.9582580128966298, 0.5280206182156941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 328}], {
             RGBColor[
             0.979490639527683, 0.942479252679342, 0.3748254367431345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 364}], {
             RGBColor[
             0.9846972868024346, 0.9583961175747513, 0.5350484595219054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 386}], {
             RGBColor[
             0.9275533515972176, 0.7383558565631763, 0.28834164777141025`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 400}], {
             RGBColor[
             0.9829386815990261, 0.9577649621077247, 0.571176590218516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 181}], {
             RGBColor[
             0.9501658765581034, 0.9548147738572214, 0.7037470909256376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 191}], {
             RGBColor[
             0.9767047326726883, 0.9752651838508866, 0.6816291867707386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 334}], {
             RGBColor[
             0.9925137704731468, 0.9849379776232294, 0.5505311404080012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 365}], {
             RGBColor[
             0.9502723082757514, 0.9548996396198619, 0.7037572424778795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 370}], {
             RGBColor[
             0.9925002887834087, 0.9849091416520875, 0.5490637416793529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 209}], {
             RGBColor[
             0.9777240578567021, 0.9499750921471359, 0.6186579343907321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 241}], {
             RGBColor[
             0.9896907742016042, 0.9900048844444145, 0.8205140811079483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 270}], {
             RGBColor[
             0.8985106449701188, 0.9205651073332046, 0.9398172398731286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 310}], {
             RGBColor[
             0.9822402753356114, 0.9652093541617881, 0.636202586480186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 323}], {
             RGBColor[
             0.988841534270125, 0.9873849273439774, 0.6696722241123378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 324}], {
             RGBColor[
             0.9729077005288784, 0.9791758057197506, 0.9245025554034085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 346}], {
             RGBColor[
             0.9898608378437871, 0.9895651146206408, 0.7806171276929739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 390}], {
             RGBColor[
             0.987417429913892, 0.9890647981591623, 0.8581892791817638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 215}], {
             RGBColor[
             0.9263954334399781, 0.7194177497470691, 0.4694658794137721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 218}], {
             RGBColor[
             0.9770906396606964, 0.9333753675865923, 0.5162291185031787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 329}], {
             RGBColor[
             0.9940583141772685, 0.9901118008524274, 0.624620656633899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 349}], {
             RGBColor[
             0.9907000678086237, 0.9904222532885797, 0.8037874740715082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 217}], {
             RGBColor[
             0.9943351210630637, 0.9902917216980389, 0.6247910711739098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 220}], {
             RGBColor[
             0.9704475909487664, 0.9077619214663362, 0.46817688634149424`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 233}], {
             RGBColor[
             0.9942486190754682, 0.9913579011956433, 0.7063247864525797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 244}], {
             RGBColor[
             0.9295335574120343, 0.734079690845461, 0.4346630743183186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 263}], {
             RGBColor[
             0.9946828123233091, 0.991537451261883, 0.6991290806797499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 264}], {
             RGBColor[
             0.9941028864446904, 0.9912976370076588, 0.7087399532885277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 307}], {
             RGBColor[
             0.9781428463211577, 0.9809477381451144, 0.805305917065893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 312}], {
             RGBColor[
             0.9576847107520003, 0.9653034100456148, 0.8265296241349587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 321}], {
             RGBColor[
             0.9659298680889552, 0.8898506557690844, 0.46454182048390535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 341}], {
             RGBColor[
             0.9690956879563744, 0.9024020765964686, 0.4670891134605739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 348}], {
             RGBColor[
             0.9724194460685741, 0.9155796699346075, 0.46976348725628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 366}], {
             RGBColor[
             0.9947147140673587, 0.9911036327514859, 0.6661074271149436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 176}], {
             RGBColor[
             0.9950610169061993, 0.9918443395071782, 0.7038003539893583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 184}], {
             RGBColor[
             0.9726175082088067, 0.9158881566357294, 0.4981351846152754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 195}], {
             RGBColor[
             0.995034973891181, 0.9921336266866263, 0.726042903982492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 250}], {
             RGBColor[
             0.9897269306480713, 0.9753516626217487, 0.5554911205633815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 344}], {
             RGBColor[
             0.9253736843365423, 0.7100880022669828, 0.4592212758063575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.9949286360689671, 0.9915611902820944, 0.689391516816463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 363}], {
             RGBColor[
             0.9877269301449638, 0.9686051913023173, 0.5477214962772127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 372}], {
             RGBColor[
             0.9762169813487868, 0.9798752122407841, 0.8374303735877682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 191}], {
             RGBColor[
             0.9522998688864801, 0.9639459008341089, 0.9656280591752291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 211}], {
             RGBColor[
             0.9647222606901356, 0.9725589553113884, 0.9154226742897853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 214}], {
             RGBColor[
             0.8952513418810031, 0.9191679074350008, 0.9848359236842501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 248}], {
             RGBColor[
             0.9649246941399242, 0.9726426667451783, 0.912067828145813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 263}], {
             RGBColor[
             0.9680154038673447, 0.9739207546450837, 0.8608467694620769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 312}], {
             RGBColor[
             0.9310173022960361, 0.9476867134288155, 0.9882473129172857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 340}], {
             RGBColor[
             0.9675269289073593, 0.9723739029829112, 0.7711853230558119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 348}], {
             RGBColor[
             0.9457520376126098, 0.8979629733178082, 0.631481176038607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 167}], {
             RGBColor[
             0.9877304110933518, 0.9717636702749834, 0.5748277041726356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 174}], {
             RGBColor[
             0.9889185553176175, 0.9896855520907659, 0.833311746454019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.992643565945739, 0.9912259397139007, 0.7715786803275595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 222}], {
             RGBColor[
             0.9855344838231901, 0.9872495630217434, 0.8429740161438439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 226}], {
             RGBColor[
             0.9211441320100687, 0.936996048702229, 0.8746096749976217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 395}], {
             RGBColor[
             0.974717324388835, 0.9791821432270742, 0.8612846454991834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 287}], {
             RGBColor[
             0.9833676620459118, 0.9862054993666372, 0.8722549016435303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 292}], {
             RGBColor[
             0.9760308424115061, 0.9548723361804092, 0.6405466465519871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 354}], {
             RGBColor[
             0.9852583476169983, 0.9854112856708411, 0.7263583687143016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 371}], {
             RGBColor[
             0.97452306291235, 0.980519922551462, 0.9280099884267181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 374}], {
             RGBColor[
             0.9617857848046906, 0.9710204813941485, 0.9495708778488063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 388}], {
             RGBColor[
             0.942881888990145, 0.8290773473027743, 0.5845553492548645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 389}], {
             RGBColor[
             0.9856901607795614, 0.9863348903625561, 0.773358566617375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 391}], {
             RGBColor[
             0.9814800627164563, 0.9854249285348173, 0.9035373074830801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 182}], {
             RGBColor[
             0.9712967995958111, 0.9173965679570957, 0.5355830595293487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 256}], {
             RGBColor[
             0.9933582874620999, 0.9915210843888023, 0.7597040169203346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 281}], {
             RGBColor[
             0.9893701729144405, 0.9898723075730951, 0.8258272741257866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 311}], {
             RGBColor[
             0.9927461494680299, 0.9902117831161314, 0.6930765739436087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 328}], {
             RGBColor[
             0.9880961959855656, 0.9754856299520487, 0.5934462349394753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 386}], {
             RGBColor[
             0.9361589080551, 0.7713622338358829, 0.5069624459677511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 400}], {
             RGBColor[
             0.9915442380569086, 0.9907713393804313, 0.7897973884148569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 169}], {
             RGBColor[
             0.9851549022024344, 0.9603246866975459, 0.5040949717384833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 178}], {
             RGBColor[
             0.9656303985561618, 0.8887716723175141, 0.45789144779932933`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 197}], {
             RGBColor[
             0.992312465845635, 0.9904548945277079, 0.7309715426924804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.9581128204576349, 0.8589669802412532, 0.4518426280010172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 300}], {
             RGBColor[
             0.9810606030658635, 0.9465136543227388, 0.48818939273642065`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 319}], {
             RGBColor[
             0.9900802574049665, 0.9895318189723511, 0.767965013324624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 174}], {
             RGBColor[
             0.983532613751803, 0.9700277731957823, 0.6443960696733768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 183}], {
             RGBColor[
             0.9814190105465319, 0.9685392972966115, 0.6519077679408587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 189}], {
             RGBColor[
             0.9872576243799245, 0.971568160818917, 0.5826630035469174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 222}], {
             RGBColor[
             0.9801485422573757, 0.9675917841267596, 0.6540583393632018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 238}], {
             RGBColor[
             0.6176186553208862, 0.667621340048126, 0.6618126363103966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 246}], {
             RGBColor[
             0.9862349689026357, 0.971145266498011, 0.5996110513531319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 269}], {
             RGBColor[
             0.9749424343804278, 0.9271370887482971, 0.35715651860252096`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 272}], {
             RGBColor[
             0.9052551663549357, 0.9089634434954166, 0.6846922104031801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 309}], {
             RGBColor[
             0.9478629026496201, 0.8231993911066209, 0.31753741041689176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 395}], {
             RGBColor[
             0.9693313828230204, 0.9595243643320905, 0.6723689687185412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 265}], {
             RGBColor[
             0.9787198002530895, 0.9390794054549454, 0.4398252396084714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 304}], {
             RGBColor[
             0.9792263201594029, 0.9405685422435105, 0.5244499603213233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 378}], {
             RGBColor[
             0.9792263201594029, 0.9405685422435105, 0.5244499603213233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 177}], {
             RGBColor[
             0.9615293629686528, 0.8793286378679193, 0.3183974763102697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 178}], {
             RGBColor[
             0.9562383611979084, 0.8583515789687384, 0.31414021208975496`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 197}], {
             RGBColor[
             0.9829204284873817, 0.9600348011789319, 0.5872203069829061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 239}], {
             RGBColor[
             0.9487207830993816, 0.8285468868924775, 0.30809139229144283`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 300}], {
             RGBColor[
             0.9716685657076101, 0.916093560973963, 0.34443815702684627`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 319}], {
             RGBColor[
             0.9806882200467131, 0.9591117256235753, 0.6242137776150496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 171}], {
             RGBColor[
             0.9934016011009064, 0.9906662030962203, 0.6955433898191563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 187}], {
             RGBColor[
             0.9922372058228153, 0.9910578993600929, 0.7783131191906937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 261}], {
             RGBColor[
             0.9770767482828957, 0.9810386484442075, 0.8616279303041929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 299}], {
             RGBColor[
             0.9937490498455933, 0.991409360828649, 0.7333610414732283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 306}], {
             RGBColor[
             0.9022618601617655, 0.9221163312167836, 0.8776498963138211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 353}], {
             RGBColor[
             0.9834054811982115, 0.9580373613546279, 0.5639890850044177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 361}], {
             RGBColor[
             0.9770767482828957, 0.9810386484442075, 0.8616279303041929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 299}], {
             RGBColor[
             0.9946172577100599, 0.9908951834575733, 0.6554999040539045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 306}], {
             RGBColor[
             0.9031300680262321, 0.921602153845708, 0.7997887588944971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 342}], {
             RGBColor[
             0.9671813048753513, 0.9724969575783275, 0.8019868468785236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 353}], {
             RGBColor[
             0.9842736890626781, 0.9575231839835523, 0.48612794758509376`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 208}], {
             RGBColor[
             0.9553432400175867, 0.8493413021887724, 0.36944517970583785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 225}], {
             RGBColor[
             0.9876657045460733, 0.9697101342511718, 0.4359655959865052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 240}], {
             RGBColor[
             0.9935120809793407, 0.988531322181073, 0.5352082372753004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 243}], {
             RGBColor[
             0.993690500028895, 0.9889129424871363, 0.5546280497445382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 285}], {
             RGBColor[
             0.975469830948804, 0.9285705888802848, 0.3885869300585914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 337}], {
             RGBColor[
             0.989097957422026, 0.9878453236816412, 0.6911807709939384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 357}], {
             RGBColor[
             0.9757356602987648, 0.9294672936974018, 0.3896196268855282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 399}], {
             RGBColor[
             0.9874901351034422, 0.9868025545702432, 0.700903715302273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 176}], {
             RGBColor[
             0.9763402964115863, 0.9797904887216979, 0.8232019034115975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 209}], {
             RGBColor[
             0.9640817810941016, 0.9399400866857981, 0.6479925706587258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 250}], {
             RGBColor[
             0.9710062101534582, 0.9632978118362683, 0.6748926699856207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 323}], {
             RGBColor[
             0.9751992575075246, 0.9773499218826396, 0.6990068603803316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 354}], {
             RGBColor[
             0.9756007438654978, 0.9782086606058469, 0.7427061727591259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 388}], {
             RGBColor[
             0.9332242852386445, 0.82187472223778, 0.6009031532996889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 183}], {
             RGBColor[
             0.9826071547707977, 0.9864611791123941, 0.910391810222242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 189}], {
             RGBColor[
             0.9884457686041903, 0.9894900426346995, 0.8411470458283008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 238}], {
             RGBColor[
             0.618806799545152, 0.6855432218639086, 0.9202966785917799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 246}], {
             RGBColor[
             0.9874231131269015, 0.9890671483137936, 0.8580950936345152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 269}], {
             RGBColor[
             0.9761305786046937, 0.9450589705640797, 0.6156405608839043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 272}], {
             RGBColor[
             0.9064433105792016, 0.9268853253111992, 0.9431762526845634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 309}], {
             RGBColor[
             0.9490510468738859, 0.8411212729224035, 0.5760214526982752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 325}], {
             RGBColor[
             0.9087696726387532, 0.9287403032700698, 0.9433981431745714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 395}], {
             RGBColor[
             0.9705195270472862, 0.977446246147873, 0.9308530109999247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 178}], {
             RGBColor[
             0.9618892571595283, 0.8878587409929732, 0.5659861656585168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 213}], {
             RGBColor[
             0.9418720635632758, 0.8063231740341936, 0.5497673997136054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 227}], {
             RGBColor[
             0.9096749370166846, 0.9290122870687298, 0.9239504721253426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 278}], {
             RGBColor[
             0.9882827626128132, 0.9894226354682021, 0.8438484769514034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 296}], {
             RGBColor[
             0.9649979448392665, 0.9729388524303266, 0.92276117965818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 314}], {
             RGBColor[
             0.9747329013842143, 0.9368756478036038, 0.5862358123192462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 319}], {
             RGBColor[
             0.986339116008333, 0.9886188876478103, 0.8760597311838114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 352}], {
             RGBColor[
             0.9904532947045148, 0.9890778794653927, 0.7175730991355566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 250}], {
             RGBColor[
             0.9896000972370991, 0.975080378780504, 0.5416860865041355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 344}], {
             RGBColor[
             0.9252468509255701, 0.7098167184257381, 0.44541624174711153`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 354}], {
             RGBColor[
             0.9941946309491385, 0.9899912275500825, 0.6094995892776407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 356}], {
             RGBColor[
             0.9948018026579948, 0.9912899064408498, 0.675586482757217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 372}], {
             RGBColor[
             0.9760901479378146, 0.9796039283995395, 0.8236253395285222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 388}], {
             RGBColor[
             0.9518181723222854, 0.8336572891820156, 0.4676965698182037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 197}], {
             RGBColor[
             0.9686869266118536, 0.9094588456980811, 0.5452740472642668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 225}], {
             RGBColor[
             0.9647822013045306, 0.890301225377597, 0.3310341389981786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 243}], {
             RGBColor[
             0.9708069967873524, 0.9095040336135615, 0.44969659275621165`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 252}], {
             RGBColor[
             0.9052279474224427, 0.8612385398592537, 0.6316306926172868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 300}], {
             RGBColor[
             0.957435063832082, 0.8655176054931122, 0.302491897308207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 337}], {
             RGBColor[
             0.9662144541804834, 0.9084364148080664, 0.5862493140056118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 367}], {
             RGBColor[
             0.9644418742789551, 0.9072707697610742, 0.5962511499262115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 398}], {
             RGBColor[
             0.9551624688773273, 0.8578516090800536, 0.29366329505253147`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 197}], {
             RGBColor[
             0.9633959248411091, 0.8884817867989002, 0.5410167830437521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 274}], {
             RGBColor[
             0.9630455805632618, 0.888336910436573, 0.5468228943896088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 278}], {
             RGBColor[
             0.9631073630049207, 0.8883624590639354, 0.5457989994434875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 300}], {
             RGBColor[
             0.9521440620613375, 0.8445405465939313, 0.2982346330876923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 319}], {
             RGBColor[
             0.9611637164004405, 0.8875587112435435, 0.5780102536758956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 352}], {
             RGBColor[
             0.9652778950966223, 0.888017703061126, 0.41952362162764073`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 232}], {
             RGBColor[
             0.9114339042649231, 0.9298420315151208, 0.8992449303185057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 257}], {
             RGBColor[
             0.9107612535539584, 0.9215443809846899, 0.6972667326193249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 275}], {
             RGBColor[
             0.8920500832848177, 0.9163587068163326, 0.975633966140448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 279}], {
             RGBColor[
             0.9123883004597837, 0.9302366988685591, 0.883428115471488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 285}], {
             RGBColor[
             0.8953476908114177, 0.8695508145774631, 0.6373879519716408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 288}], {
             RGBColor[
             0.9079175796616991, 0.9281926596335699, 0.948774433680244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 399}], {
             RGBColor[
             0.9073679949660559, 0.9277827802674216, 0.9497047372153224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 198}], {
             RGBColor[
             0.9719635102900364, 0.9568019356997193, 0.6579671080659022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 236}], {
             RGBColor[
             0.9791446337447514, 0.980632323533055, 0.7193016692979308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 262}], {
             RGBColor[
             0.9747075648665218, 0.9660582761208589, 0.6686272419243227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 267}], {
             RGBColor[
             0.976453651078396, 0.9813672794152006, 0.8982098714003087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 284}], {
             RGBColor[
             0.9771329896418377, 0.9816482033693885, 0.8869514733322337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 286}], {
             RGBColor[
             0.9776701837144316, 0.981870346923664, 0.8780487773356582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 332}], {
             RGBColor[
             0.9253564030255478, 0.7733910531449262, 0.585050752585733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 367}], {
             RGBColor[
             0.9733685031094289, 0.9796588537408617, 0.9299643570156396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 398}], {
             RGBColor[
             0.9640890977078012, 0.9302396930598413, 0.6273765021419595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 191}], {
             RGBColor[
             0.9367301092573403, 0.9516762250390417, 0.9691781441788225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 211}], {
             RGBColor[
             0.9491525010609958, 0.9602892795163211, 0.9189727592933788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 214}], {
             RGBColor[
             0.8796815822518633, 0.9068982316399337, 0.9883860086878435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 305}], {
             RGBColor[
             0.9525831425771419, 0.9614431207786304, 0.8428687385877214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 334}], {
             RGBColor[
             0.9525391470577987, 0.9613490188113846, 0.8380800978160852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 340}], {
             RGBColor[
             0.9519571692782194, 0.9601042271878439, 0.7747354080594053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 365}], {
             RGBColor[
             0.9102976848604034, 0.9313106808080172, 0.9913061998859636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 370}], {
             RGBColor[
             0.9525256653680607, 0.9613201828402427, 0.8366126990874369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 256}], {
             RGBColor[
             0.9732200356691153, 0.9181914644587008, 0.5036801823781527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 281}], {
             RGBColor[
             0.969231921121456, 0.9165426876429936, 0.5698034395836047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 311}], {
             RGBColor[
             0.9726078976750453, 0.91688216318603, 0.4370527394014267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 386}], {
             RGBColor[
             0.9160206562621156, 0.6980326139057813, 0.25093861142556917`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 238}], {
             RGBColor[
             0.616693196339881, 0.6840547459647378, 0.9278083768592618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 246}], {
             RGBColor[
             0.9853095099216304, 0.9875786724146228, 0.865606791901997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 269}], {
             RGBColor[
             0.9740169753994226, 0.9435704946649089, 0.6231522591513861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 272}], {
             RGBColor[
             0.9043297073739305, 0.9253968494120284, 0.9506879509520452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 280}], {
             RGBColor[
             0.882234343810343, 0.9080696525110059, 0.9485032407268339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 309}], {
             RGBColor[
             0.9469374436686148, 0.8396327970232327, 0.5835331509657569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 325}], {
             RGBColor[
             0.9066560694334821, 0.9272518273708991, 0.9509098414420531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 339}], {
             RGBColor[
             0.9828603543416655, 0.973401288361214, 0.6575071164100159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 395}], {
             RGBColor[
             0.9684059238420151, 0.9759577702487023, 0.9383647092674064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 343}], {
             RGBColor[
             0.9582420645245853, 0.8690534131762745, 0.3013896746979107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 356}], {
             RGBColor[
             0.9723582939606021, 0.915333723569401, 0.46992131338313414`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 369}], {
             RGBColor[
             0.9724811712654703, 0.9155965456997126, 0.4832957497072059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 372}], {
             RGBColor[
             0.9536466392404219, 0.9036477455280907, 0.6179601701544393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 198}], {
             RGBColor[
             0.9297227434202466, 0.7455481100223879, 0.2970975160016526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 205}], {
             RGBColor[
             0.93744255290402, 0.7705306928023672, 0.41706472711186915`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 208}], {
             RGBColor[
             0.8991455987367283, 0.6310666516176536, 0.2373573377426897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 210}], {
             RGBColor[
             0.8909952949459943, 0.5979169176929904, 0.23075614096416774`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 219}], {
             RGBColor[
             0.9372892565881824, 0.7702028074834256, 0.4003793691681451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 249}], {
             RGBColor[
             0.9355162285939422, 0.7706524201356284, 0.5157404899238958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 284}], {
             RGBColor[
             0.934892222772048, 0.770394377692057, 0.5260818812679842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 293}], {
             RGBColor[
             0.9331092369062495, 0.7696570672159027, 0.5556305712837741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 338}], {
             RGBColor[
             0.9320100433741934, 0.7690630512798355, 0.5676012491151452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 188}], {
             RGBColor[
             0.9798821252851003, 0.9469416105821974, 0.5557575121830104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 228}], {
             RGBColor[
             0.9781142363412278, 0.9462105430712326, 0.5850560071329038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 238}], {
             RGBColor[
             0.6103285497732218, 0.643030102237671, 0.6334919528786365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 273}], {
             RGBColor[
             0.9773654240626011, 0.9353104018912994, 0.36656937597455624`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 322}], {
             RGBColor[
             0.9619364197746868, 0.88326474752568, 0.3066306078389865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 330}], {
             RGBColor[
             0.9537019763499597, 0.928713689545827, 0.6581645465154551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 206}], {
             RGBColor[
             0.9767805608692712, 0.9809161673370046, 0.8665365222564064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 220}], {
             RGBColor[
             0.96908530549688, 0.9077303506582264, 0.5294074915320076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 261}], {
             RGBColor[
             0.9767805608692712, 0.9809161673370046, 0.8665365222564064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 321}], {
             RGBColor[
             0.9645675826370688, 0.8898190849609746, 0.5257724256744187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 228}], {
             RGBColor[
             0.9902321031941198, 0.9902287378943403, 0.8115428587874409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 238}], {
             RGBColor[
             0.6224464166261138, 0.6870482970607787, 0.8599788045331735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 273}], {
             RGBColor[
             0.989483290915493, 0.9793285967144072, 0.5930562276290934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 322}], {
             RGBColor[
             0.9740542866275788, 0.9272829423487876, 0.5331174594935237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 330}], {
             RGBColor[
             0.9658198432028515, 0.9727318843689345, 0.8846513981699923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 222}], {
             RGBColor[
             0.9850616971097629, 0.9870540535656769, 0.8508093155181256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 226}], {
             RGBColor[
             0.9206713452966415, 0.9368005392461625, 0.8824449743719034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 395}], {
             RGBColor[
             0.9742445376754076, 0.9789866337710078, 0.8691199448734652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 212}], {
             RGBColor[
             0.9539458909968077, 0.8948036564046948, 0.6104187630206317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 221}], {
             RGBColor[
             0.9661835548999816, 0.9743003311305289, 0.9421266001996185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 255}], {
             RGBColor[
             0.9792599698751374, 0.9820427269789191, 0.8241907957102401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 268}], {
             RGBColor[
             0.9741988120637011, 0.9801572852382513, 0.923148671992268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 270}], {
             RGBColor[
             0.8877343839719594, 0.9126675717363167, 0.9643004590285513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 274}], {
             RGBColor[
             0.9764278722158577, 0.9810790588954009, 0.8862073766482788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 295}], {
             RGBColor[
             0.9718992003734078, 0.9587798032507204, 0.6623764212073109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 324}], {
             RGBColor[
             0.9621314395307189, 0.9712782701228627, 0.9489857745588313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 351}], {
             RGBColor[
             0.9132839988393759, 0.9329755312234975, 0.9667545495792005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 211}], {
             RGBColor[
             0.9756913571755808, 0.9807396895099864, 0.8968548551384798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 214}], {
             RGBColor[
             0.9062204383664483, 0.9273486416335988, 0.9662681045329446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 312}], {
             RGBColor[
             0.9419863987814813, 0.9558674476274135, 0.9696794937659803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 334}], {
             RGBColor[
             0.9790780031723838, 0.9817994288050498, 0.8159621936611863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 340}], {
             RGBColor[
             0.9784960253928044, 0.9805546371815091, 0.7526175039045064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 365}], {
             RGBColor[
             0.9368365409749884, 0.9517610908016823, 0.9691882957310646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 370}], {
             RGBColor[
             0.9790645214826457, 0.9817705928339079, 0.8144947949325378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 292}], {
             RGBColor[
             0.9814940998117131, 0.958316149219534, 0.6030558445475775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 320}], {
             RGBColor[
             0.9638139129495356, 0.9719023806591323, 0.9178948536485259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 347}], {
             RGBColor[
             0.9791933175687566, 0.9505550704646807, 0.5941177399999604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 374}], {
             RGBColor[
             0.9672490422048976, 0.9744642944332733, 0.9120800758443965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 382}], {
             RGBColor[
             0.9731982923263399, 0.930332442623143, 0.5708281989986937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 384}], {
             RGBColor[
             0.9532349113698659, 0.8519074490680855, 0.5509989669305075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 248}], {
             RGBColor[
             0.984259375842397, 0.9668590350581499, 0.6083722557695561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 305}], {
             RGBColor[
             0.9874875839087545, 0.967929164886669, 0.5356230812078708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 334}], {
             RGBColor[
             0.9874435883894113, 0.9678350629194232, 0.5308344404362348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 360}], {
             RGBColor[
             0.9773238236277779, 0.9351700738563942, 0.3664077661408509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 201}], {
             RGBColor[
             0.9912693864487847, 0.9890560996463607, 0.6779343207234535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 208}], {
             RGBColor[
             0.9533684449219291, 0.8504390894565204, 0.5413304633590346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 223}], {
             RGBColor[
             0.9910208336765647, 0.9905548982182801, 0.7984715535242712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 230}], {
             RGBColor[
             0.9917746999107575, 0.9901369140464924, 0.7329345726259918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 242}], {
             RGBColor[
             0.9310544246537078, 0.7529752270276153, 0.5229107143672367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 357}], {
             RGBColor[
             0.9737608652031071, 0.9305650809651498, 0.5615049105387249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 364}], {
             RGBColor[
             0.9921419562583669, 0.9909224382387163, 0.7729081596198195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 385}], {
             RGBColor[
             0.9857052144182769, 0.9880419498624455, 0.8724675911056837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 387}], {
             RGBColor[
             0.9820566726884803, 0.9585487875615408, 0.5937325560876086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 247}], {
             RGBColor[
             0.993833666110127, 0.9917180767160544, 0.7518556407231504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 253}], {
             RGBColor[
             0.9760708674319938, 0.9798982590472746, 0.8458564423575294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 315}], {
             RGBColor[
             0.975027111544299, 0.9260655383324519, 0.5086345319143829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 316}], {
             RGBColor[
             0.9948688648015154, 0.991778336140037, 0.7079629546788706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 343}], {
             RGBColor[
             0.9806595302069596, 0.9452988832271714, 0.5292973940651273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 358}], {
             RGBColor[
             0.9941728408861317, 0.9902896113638439, 0.6322050468510503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 359}], {
             RGBColor[
             0.9084391339724399, 0.9265265400732108, 0.8586821712665091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 362}], {
             RGBColor[
             0.9793339920188713, 0.9823318920212917, 0.8403328235911419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 363}], {
             RGBColor[
             0.9875740537189732, 0.9686231946405208, 0.5561590122111004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 369}], {
             RGBColor[
             0.9948986369478446, 0.9918420157506096, 0.7112034690744224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 372}], {
             RGBColor[
             0.9760641049227963, 0.9798932155789877, 0.8458678895216558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 397}], {
             RGBColor[
             0.959627405429194, 0.9673426782642127, 0.8635645542943637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 289}], {
             RGBColor[
             0.9928523435901293, 0.989510497319346, 0.6371485041267311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 317}], {
             RGBColor[
             0.9826065607697968, 0.9553751801959578, 0.5611119007514016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 326}], {
             RGBColor[
             0.9900165232980965, 0.990139590067184, 0.8151155755674333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 327}], {
             RGBColor[
             0.9932126474790477, 0.9902811509054315, 0.6763653588976528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 336}], {
             RGBColor[
             0.9478412897498971, 0.9583997705931759, 0.8821989688685082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 376}], {
             RGBColor[
             0.9919427077951362, 0.9909361168573936, 0.7831937136458008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 252}], {
             RGBColor[
             0.9266190129411715, 0.9419447031702665, 0.9004535232899232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 300}], {
             RGBColor[
             0.9788261293508109, 0.9462237688041248, 0.5713147279808435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 205}], {
             RGBColor[
             0.9864977113097735, 0.9650576038327745, 0.4920237964715344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 219}], {
             RGBColor[
             0.986344414993936, 0.9647297185138328, 0.4753384385278103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 236}], {
             RGBColor[
             0.9859590252807152, 0.9639054088861307, 0.4333911465933464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 284}], {
             RGBColor[
             0.9839473811778017, 0.9649212887224643, 0.6010409506276493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 332}], {
             RGBColor[
             0.9321707945615116, 0.756664138498002, 0.29914022988114863`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 367}], {
             RGBColor[
             0.9801828946453928, 0.9629319390939375, 0.6440538343110552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 398}], {
             RGBColor[
             0.970903489243765, 0.9135127784129171, 0.3414659794373751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 216}], {
             RGBColor[
             0.9732129903799336, 0.9190557386763074, 0.4508784951795365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 298}], {
             RGBColor[
             0.9736235778809623, 0.9199339438242438, 0.49556841081418324`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 299}], {
             RGBColor[
             0.9735432564672564, 0.9197621444420674, 0.486825920618598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 306}], {
             RGBColor[
             0.8820560667834285, 0.850469114830202, 0.6311147754591906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 342}], {
             RGBColor[
             0.9461073036325477, 0.9013639185628216, 0.6333128634432172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 353}], {
             RGBColor[
             0.9631996878198745, 0.8863901449680464, 0.31745396414978727`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 361}], {
             RGBColor[
             0.9568709549045588, 0.909391432057626, 0.6150928094495625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 393}], {
             RGBColor[
             0.9593045222393597, 0.9112063825913197, 0.6109734147277579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 207}], {
             RGBColor[
             0.7398774701305575, 0.7942745369566024, 0.9212236978336392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 333}], {
             RGBColor[
             0.6704984403364774, 0.4804659526472852, 0.5728834359394974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 368}], {
             RGBColor[
             0.7271327117362356, 0.7849952778141198, 0.9529072793270634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 223}], {
             RGBColor[
             0.9931769427404544, 0.9898449231949267, 0.6463211763730476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 230}], {
             RGBColor[
             0.9939308089746473, 0.989426939023139, 0.5807841954747683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 245}], {
             RGBColor[
             0.993810264210487, 0.9901068178984045, 0.6358254006311832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 364}], {
             RGBColor[
             0.9942980653222566, 0.9902124632153629, 0.620757782468596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 385}], {
             RGBColor[
             0.9878613234821667, 0.9873319748390921, 0.7203172139544602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 218}], {
             RGBColor[
             0.9766125620057662, 0.9319406667301268, 0.4342350093925867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 229}], {
             RGBColor[
             0.994462758217878, 0.9905647246660911, 0.638683587790245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 260}], {
             RGBColor[
             0.9940988574214373, 0.9897863776585187, 0.59907523183307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 307}], {
             RGBColor[
             0.9777341033137941, 0.9800734781826212, 0.7608167631838199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 341}], {
             RGBColor[
             0.968686944949011, 0.9015278166339755, 0.4225999595785007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 349}], {
             RGBColor[
             0.9902219901536935, 0.9889875524321141, 0.7217933649609162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 366}], {
             RGBColor[
             0.9943059710599951, 0.9902293727889928, 0.6216182732328703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 232}], {
             RGBColor[
             0.9848220471153981, 0.9664919840831854, 0.5949020251760753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 257}], {
             RGBColor[
             0.9841493964044334, 0.9581943335527545, 0.3929238274768944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 275}], {
             RGBColor[
             0.9654382261352927, 0.9530086593843972, 0.6712910609980175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 280}], {
             RGBColor[
             0.8817850045287735, 0.8869987292367463, 0.6771666685367328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 297}], {
             RGBColor[
             0.9628867178433413, 0.8835769115891934, 0.3253912880875217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 309}], {
             RGBColor[
             0.9464881043870452, 0.8185618737489732, 0.3121965787756558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 322}], {
             RGBColor[
             0.9678517270597764, 0.9032184679784871, 0.3296104596295107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 325}], {
             RGBColor[
             0.9062067301519126, 0.9061809040966395, 0.679573269251952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 339}], {
             RGBColor[
             0.982411015060096, 0.9523303650869543, 0.38617054421991476`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 224}], {
             RGBColor[
             0.9900688427403106, 0.9901612255010879, 0.8142485070115704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 276}], {
             RGBColor[
             0.9756507885577559, 0.9331116126384942, 0.5423836024093361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 290}], {
             RGBColor[
             0.9282059604157593, 0.7347020958436803, 0.4980165048294011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 297}], {
             RGBColor[
             0.9689395010696473, 0.9075794495932087, 0.5313804695388762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 318}], {
             RGBColor[
             0.9909207316930347, 0.9905135034755868, 0.8001305024469919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 345}], {
             RGBColor[
             0.9740093677867516, 0.978889384978458, 0.8730173185286598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 219}], {
             RGBColor[
             0.9940642244777094, 0.9897123012938123, 0.5953056496380269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 284}], {
             RGBColor[
             0.9916671906615749, 0.9899038715024436, 0.7210081617378659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 293}], {
             RGBColor[
             0.9898842047957764, 0.9891665610262892, 0.750556851753656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 338}], {
             RGBColor[
             0.9887850112637203, 0.9885725450902221, 0.7625275295850271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 220}], {
             RGBColor[
             0.9539248479569604, 0.8977110997423411, 0.6127223026455069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 321}], {
             RGBColor[
             0.9494071250971493, 0.8797998340450892, 0.609087236787918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 328}], {
             RGBColor[
             0.9731887219558437, 0.9655709942190096, 0.6725684545886629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 386}], {
             RGBColor[
             0.9212514340253781, 0.7614475981028439, 0.5860846656169386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 254}], {
             RGBColor[
             0.9479775026880287, 0.9598442410052412, 0.9402195236818833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 333}], {
             RGBColor[
             0.9161718590039261, 0.6744843511305074, 0.5407824340314192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 230}], {
             RGBColor[
             0.9560298674477917, 0.8508099288332988, 0.44418033811034935`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 240}], {
             RGBColor[
             0.9557924534207175, 0.8503021242356272, 0.41833928641285456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 242}], {
             RGBColor[
             0.8953095921907421, 0.6136482418144217, 0.23415647985159416`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 357}], {
             RGBColor[
             0.9380160327401414, 0.791238095751956, 0.2727506760230824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 385}], {
             RGBColor[
             0.9499603819553111, 0.8487149646492518, 0.5837133565900412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 387}], {
             RGBColor[
             0.9463118402255146, 0.8192218023483471, 0.30497832157196614`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 241}], {
             RGBColor[
             0.9823838692051599, 0.9519020438914124, 0.5414328011415851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 270}], {
             RGBColor[
             0.8912037399736745, 0.8824622667802025, 0.6607359599067655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 310}], {
             RGBColor[
             0.9749333703391669, 0.9271065136087859, 0.3571213065138228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 323}], {
             RGBColor[
             0.9815346292736806, 0.9492820867909754, 0.39059094414597473`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 346}], {
             RGBColor[
             0.9825539328473427, 0.9514622740676387, 0.5015358477266108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 390}], {
             RGBColor[
             0.9801105249174478, 0.9509619576061601, 0.5791079992154006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 249}], {
             RGBColor[
             0.9458439385254436, 0.8175481388366381, 0.524358184246076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 266}], {
             RGBColor[
             0.9181988458129815, 0.7125562174847171, 0.252995804066218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 293}], {
             RGBColor[
             0.9434369468377508, 0.8165527859169124, 0.5642482656059545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 315}], {
             RGBColor[
             0.9282475652504516, 0.7523960415170369, 0.26108123959936713`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 316}], {
             RGBColor[
             0.948089318507668, 0.8181088393246221, 0.46040966236385483`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 387}], {
             RGBColor[
             0.9381615364347806, 0.7860720684236838, 0.2983771247934442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 397}], {
             RGBColor[
             0.9128478591353466, 0.7936731814487978, 0.616011261979348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 214}], {
             RGBColor[
             0.9186428301701037, 0.9359616961108783, 0.9160627196475009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 248}], {
             RGBColor[
             0.9883161824290249, 0.9894364554210557, 0.8432946241090639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 263}], {
             RGBColor[
             0.9914068921564454, 0.9907145433209612, 0.7920735654253277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 312}], {
             RGBColor[
             0.9544087905851367, 0.9644805021046929, 0.9194741088805365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 334}], {
             RGBColor[
             0.9915003949760393, 0.9904124832823292, 0.7657568087757425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 340}], {
             RGBColor[
             0.9909184171964599, 0.9891676916587886, 0.7024121190190626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 370}], {
             RGBColor[
             0.9914869132863011, 0.9903836473111873, 0.7642894100470942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 268}], {
             RGBColor[
             0.9646662622036815, 0.9026780801365839, 0.5868617823449589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 270}], {
             RGBColor[
             0.8782018341119396, 0.8351883666346493, 0.6280135693812421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 274}], {
             RGBColor[
             0.966895322355838, 0.9035998537937335, 0.5499204870009695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 295}], {
             RGBColor[
             0.9623666505133881, 0.8813005981490529, 0.32608953156000164`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 310}], {
             RGBColor[
             0.9619314644774322, 0.8798326134632328, 0.32439891598829956`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 324}], {
             RGBColor[
             0.9525988896706992, 0.8937990650211953, 0.612698884911522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 351}], {
             RGBColor[
             0.9037514489793563, 0.8554963261218301, 0.6304676599318912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 373}], {
             RGBColor[
             0.9692904686904229, 0.903628927176285, 0.4403444509208885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 390}], {
             RGBColor[
             0.9671086190557129, 0.903688057460607, 0.5463856086898773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 227}], {
             RGBColor[
             0.8644823438125397, 0.7464165437056834, 0.6096822286725153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 296}], {
             RGBColor[
             0.9198053516351217, 0.7903431090672801, 0.6084929362053527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 308}], {
             RGBColor[
             0.9448555671038052, 0.8056155945934653, 0.3592084768163469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 352}], {
             RGBColor[
             0.9452607015003699, 0.8064821361023462, 0.4033048556827292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 248}], {
             RGBColor[
             0.9188452636198924, 0.9360454075446683, 0.9127078735035286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 263}], {
             RGBColor[
             0.9219359733473129, 0.9373234954445736, 0.8614868148197925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 312}], {
             RGBColor[
             0.8849378717760042, 0.9110894542283055, 0.9888873582750012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 340}], {
             RGBColor[
             0.9214474983873274, 0.9357766437824011, 0.7718253684135274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 218}], {
             RGBColor[
             0.9086818144925772, 0.6606736756766071, 0.24992458669803286`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 229}], {
             RGBColor[
             0.9265320107046893, 0.7192977336125714, 0.45437316509569114`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 329}], {
             RGBColor[
             0.9256494890091493, 0.7174101089424422, 0.3583161248287532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 349}], {
             RGBColor[
             0.9222912426405045, 0.7177205613785944, 0.5374829422663624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 231}], {
             RGBColor[
             0.9904500256446258, 0.9894752972892935, 0.746613620876976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 235}], {
             RGBColor[
             0.9907669207612165, 0.9896063415638368, 0.7413618486967941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 298}], {
             RGBColor[
             0.99471476178113, 0.9911037348064183, 0.6661126204645004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 313}], {
             RGBColor[
             0.9937778761896175, 0.9890998312598369, 0.5641384056160279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 361}], {
             RGBColor[
             0.9779621388047264, 0.9805612230398006, 0.7856370190998796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 393}], {
             RGBColor[
             0.9803957061395274, 0.9823761735734944, 0.781517624378075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 396}], {
             RGBColor[
             0.9821276040843236, 0.9836678202250008, 0.7785859729088622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 220}], {
             RGBColor[
             0.9701171226988665, 0.9070550832952657, 0.43220745675352357`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 230}], {
             RGBColor[
             0.9942203876248918, 0.9900463184751196, 0.6123030444816229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 233}], {
             RGBColor[
             0.9939181508255683, 0.9906510630245727, 0.670355356864609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 242}], {
             RGBColor[
             0.9335001123678424, 0.7528846314562425, 0.4022791862228677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 244}], {
             RGBColor[
             0.9292030891621343, 0.7333728526743905, 0.3986936447303479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 264}], {
             RGBColor[
             0.9937724181947905, 0.9905907988365883, 0.672770523700557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 321}], {
             RGBColor[
             0.9655993998390553, 0.8891438175980139, 0.4285723908959347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 357}], {
             RGBColor[
             0.9762065529172417, 0.930474485393777, 0.4408733823943559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 364}], {
             RGBColor[
             0.9945876439725013, 0.9908318426673435, 0.6522766314754506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 366}], {
             RGBColor[
             0.9943842458174588, 0.9903967945804155, 0.630137997526973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 229}], {
             RGBColor[
             0.9772272169254076, 0.9332553514520947, 0.5011364041850978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 260}], {
             RGBColor[
             0.9768633161289668, 0.9324770044445223, 0.46152804822792276`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 329}], {
             RGBColor[
             0.9763446952298677, 0.9313677267819654, 0.40507936391815974`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 349}], {
             RGBColor[
             0.972986448861223, 0.9316781792181177, 0.5842461813557689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 284}], {
             RGBColor[
             0.9915138943457373, 0.9895759861835021, 0.7043228037941418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 293}], {
             RGBColor[
             0.9897309084799388, 0.9888386757073476, 0.733871493809932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 338}], {
             RGBColor[
             0.9886317149478827, 0.9882446597712804, 0.7458421716413031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 233}], {
             RGBColor[
             0.970030620711271, 0.9081212627928701, 0.5137411720321935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 244}], {
             RGBColor[
             0.9053155590478371, 0.6508430524426878, 0.2420794598979324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 321}], {
             RGBColor[
             0.9417118697247581, 0.8066140173663112, 0.27195820606351917`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 341}], {
             RGBColor[
             0.9448776895921772, 0.8191654381936955, 0.27450549904018773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 366}], {
             RGBColor[
             0.9704967157031614, 0.9078669943487128, 0.4735238126945574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 239}], {
             RGBColor[
             0.945283685148859, 0.8517534905954401, 0.5966932981426365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 255}], {
             RGBColor[
             0.9819650839182916, 0.9840601966030857, 0.8196117432419178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 268}], {
             RGBColor[
             0.9769039261068553, 0.982174754862418, 0.9185696195239457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 324}], {
             RGBColor[
             0.9648365535738731, 0.9732957397470294, 0.944406722090509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 351}], {
             RGBColor[
             0.9159891128825302, 0.9349930008476641, 0.9621754971108781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 400}], {
             RGBColor[
             0.9802710468340787, 0.9835671458141805, 0.8627677152447397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 333}], {
             RGBColor[
             0.91237272209853, 0.6718767218473549, 0.5573234117358437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 230}], {
             RGBColor[
             0.9936822562024272, 0.9909257375950585, 0.701321428275586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 242}], {
             RGBColor[
             0.9329619809453777, 0.7537640505761815, 0.49129757001683083`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 245}], {
             RGBColor[
             0.9935617114382671, 0.991605616470324, 0.7563626334320008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 328}], {
             RGBColor[
             0.9888428652752851, 0.9757943968918732, 0.5810719924906428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 364}], {
             RGBColor[
             0.9940495125500367, 0.9917112617872824, 0.7412950152694138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 385}], {
             RGBColor[
             0.9876127707099467, 0.9888307734110116, 0.8408544467552779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 290}], {
             RGBColor[
             0.9265743637010704, 0.7340273886720334, 0.5250562848287408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 318}], {
             RGBColor[
             0.9892891349783458, 0.9898387963039399, 0.8271702824463316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 345}], {
             RGBColor[
             0.9723777710720627, 0.9782146778068112, 0.9000570985279996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 240}], {
             RGBColor[
             0.9881149179492041, 0.9706709562980267, 0.48485970269352185`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 243}], {
             RGBColor[
             0.9882933369987583, 0.9710525766040901, 0.5042795151627597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 337}], {
             RGBColor[
             0.9837007943918894, 0.9699849577985951, 0.6408322364121599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 367}], {
             RGBColor[
             0.9819282144903609, 0.9688193127516028, 0.6508340723327597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 398}], {
             RGBColor[
             0.9726488090887332, 0.9194001520705823, 0.3482462174590796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 234}], {
             RGBColor[
             0.9174712703353333, 0.9354772260114863, 0.9354784980093104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 281}], {
             RGBColor[
             0.9182386029005284, 0.9357945377467418, 0.9227618116110041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 350}], {
             RGBColor[
             0.905372697927965, 0.8823055649201961, 0.6453483209268926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 355}], {
             RGBColor[
             0.9066398928830911, 0.9276614701253173, 0.9655580774475272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 392}], {
             RGBColor[
             0.5397508555090633, 0.6209961248999487, 0.9609521412194065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 395}], {
             RGBColor[
             0.9027451037397374, 0.924756742759336, 0.9721509395435273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 296}], {
             RGBColor[
             0.8876082250885304, 0.9130322221018164, 0.9826760086170899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 308}], {
             RGBColor[
             0.912658440557214, 0.9283047076280018, 0.733391549228084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 352}], {
             RGBColor[
             0.9130635749537787, 0.9291712491368826, 0.7774879280944664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 375}], {
             RGBColor[
             0.8913418243926077, 0.8550794984983181, 0.6314064593337225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 238}], {
             RGBColor[
             0.6206785276822413, 0.6863172295498139, 0.889277299483067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 273}], {
             RGBColor[
             0.9877154019716206, 0.9785975292034423, 0.6223547225789868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 330}], {
             RGBColor[
             0.9640519542589792, 0.9720008168579699, 0.9139498931198857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 368}], {
             RGBColor[
             0.9742627931298048, 0.9796160437691175, 0.896665606324872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 260}], {
             RGBColor[
             0.9947135123410789, 0.9911010623804867, 0.6659766266255811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[
             0.9941948914419796, 0.9899917847179298, 0.609527942315818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 349}], {
             RGBColor[
             0.9908366450733349, 0.9903022371540819, 0.7886947597534273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 233}], {
             RGBColor[
             0.9941338856372965, 0.9911124979727239, 0.6938367597602928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 242}], {
             RGBColor[
             0.9337158471795705, 0.7533460664043938, 0.42576058911855147`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 244}], {
             RGBColor[
             0.9294188239738626, 0.7338342876225418, 0.4221750476260317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 245}], {
             RGBColor[
             0.9943155776724598, 0.9911876322985363, 0.6908256525337215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 328}], {
             RGBColor[
             0.9895967315094778, 0.9753764127200855, 0.5155350115923634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 357}], {
             RGBColor[
             0.9764222877289698, 0.9309359203419282, 0.4643547852900397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 364}], {
             RGBColor[
             0.9948033787842294, 0.9912932776154948, 0.6757580343711344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 385}], {
             RGBColor[
             0.9883666369441395, 0.9884127892392239, 0.7753174658569986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 235}], {
             RGBColor[
             0.9869127721257411, 0.9888561091946482, 0.8665527647439165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 298}], {
             RGBColor[
             0.9908606131456545, 0.9903535024372299, 0.7913035365116228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 336}], {
             RGBColor[
             0.94488360199505, 0.9571766906974385, 0.9312155092168725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 393}], {
             RGBColor[
             0.9765415575040519, 0.9816259412043058, 0.9067085404251976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 396}], {
             RGBColor[
             0.9782734554488481, 0.9829175878558123, 0.9037768889559845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 257}], {
             RGBColor[
             0.989376570517444, 0.9818554609712358, 0.6125954885434481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 275}], {
             RGBColor[
             0.9706654002483034, 0.9766697868028784, 0.8909627220645713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 279}], {
             RGBColor[
             0.9910036174232693, 0.9905477788551049, 0.7987568713956112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 280}], {
             RGBColor[
             0.8870121786417842, 0.9106598566552275, 0.8968383296032865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 288}], {
             RGBColor[
             0.9865328966251847, 0.9885037396201157, 0.8641031896043672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 297}], {
             RGBColor[
             0.9681138919563519, 0.9072380390076746, 0.5450629491540755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 309}], {
             RGBColor[
             0.9517152785000558, 0.8422230011674544, 0.5318682398422095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 325}], {
             RGBColor[
             0.9114339042649231, 0.9298420315151208, 0.8992449303185057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 339}], {
             RGBColor[
             0.9876381891731065, 0.9759914925054356, 0.6058422052864685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 242}], {
             RGBColor[
             0.9334136103802468, 0.7539508109538469, 0.4838129015015376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 244}], {
             RGBColor[
             0.929116587174539, 0.7344390321719948, 0.48022736000901783`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 264}], {
             RGBColor[
             0.993685916207195, 0.9916569783341926, 0.7543042389792269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 307}], {
             RGBColor[
             0.9777258760836622, 0.9813070794716481, 0.8508702027565923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 348}], {
             RGBColor[
             0.9720024758310788, 0.9159390112611412, 0.5153277729469792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 357}], {
             RGBColor[
             0.9761200509296462, 0.9315406648913813, 0.5224070976730258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 366}], {
             RGBColor[
             0.9942977438298632, 0.9914629740780199, 0.7116717128056429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[
             0.9537246653321387, 0.8577864921123333, 0.5706600377653159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 246}], {
             RGBColor[
             0.9879480487937147, 0.989284222702252, 0.8493955511454627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 269}], {
             RGBColor[
             0.9766555142715069, 0.9452760449525381, 0.6069410183948518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 272}], {
             RGBColor[
             0.9069682462460147, 0.9271023996996577, 0.9344767101955109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 350}], {
             RGBColor[
             0.973672056902327, 0.9352121426971916, 0.5953508498942375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 355}], {
             RGBColor[
             0.9749392518574531, 0.9805680479023129, 0.915560606414872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 392}], {
             RGBColor[
             0.6080502144834252, 0.6739027026769442, 0.9109546701867514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 395}], {
             RGBColor[
             0.9710444627140995, 0.9776633205363315, 0.9221534685108721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 298}], {
             RGBColor[
             0.9911775082622454, 0.9904845467117731, 0.7860517643314409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 313}], {
             RGBColor[
             0.9902406226707329, 0.9884806431651916, 0.6840775494829683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 317}], {
             RGBColor[
             0.9799657681315403, 0.9542831445747637, 0.6048766689195839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 336}], {
             RGBColor[
             0.9452004971116408, 0.9573077349719818, 0.9259637370366905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 393}], {
             RGBColor[
             0.9768584526206427, 0.981756985478849, 0.9014567682450156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 396}], {
             RGBColor[
             0.978590350565439, 0.9830486321303555, 0.8985251167758026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 267}], {
             RGBColor[
             0.9904491660690748, 0.9884707526016121, 0.6736339099277528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 284}], {
             RGBColor[
             0.9911285046325167, 0.9887516765558, 0.6623755118596779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 286}], {
             RGBColor[
             0.9916656987051105, 0.9889738201100755, 0.6534728158631024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 332}], {
             RGBColor[
             0.9393519180162266, 0.7804945263313376, 0.3604747911131772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 367}], {
             RGBColor[
             0.9873640181001078, 0.9867623269272732, 0.7053883955430837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 383}], {
             RGBColor[
             0.9304410640769092, 0.7400324197757103, 0.3530393561611934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 398}], {
             RGBColor[
             0.97808461269848, 0.9373431662462528, 0.40280054066940374`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 251}], {
             RGBColor[
             0.9817230556279776, 0.9856751913145605, 0.9062176942163055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 296}], {
             RGBColor[
             0.9642070924114874, 0.9726118146274596, 0.9358676510469577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 308}], {
             RGBColor[
             0.989257307880171, 0.9878843001536448, 0.6865831916579519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 380}], {
             RGBColor[
             0.9512177563294812, 0.9624409699948908, 0.9410947669164513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 269}], {
             RGBColor[
             0.6102166201737769, 0.6426525374164235, 0.633057127520924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 272}], {
             RGBColor[
             0.5405293521482848, 0.6244788921635429, 0.9605928193215831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 280}], {
             RGBColor[
             0.5184339885846974, 0.6071516952625204, 0.9584081090963719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 309}], {
             RGBColor[
             0.583137088442969, 0.5387148397747472, 0.5934380193352948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 325}], {
             RGBColor[
             0.5428557142078363, 0.6263338701224136, 0.9608147098115911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 339}], {
             RGBColor[
             0.6190599991160197, 0.6724833311127285, 0.6674119847795538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 246}], {
             RGBColor[
             0.9559020848161581, 0.8586869110261035, 0.5345745619341234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 269}], {
             RGBColor[
             0.9446095502939502, 0.8146787332763896, 0.29212002918351254`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 272}], {
             RGBColor[
             0.8749222822684581, 0.7965050880235092, 0.6196557209841717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 350}], {
             RGBColor[
             0.9416260929247704, 0.804614831021043, 0.2805298606828983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 355}], {
             RGBColor[
             0.9428932878798966, 0.8499707362261644, 0.6007396172035329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 392}], {
             RGBColor[
             0.5760042505058687, 0.5433053910007957, 0.5961336809754121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 242}], {
             RGBColor[
             0.9334784331524962, 0.7528382618067222, 0.3999195374210567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 243}], {
             RGBColor[
             0.9941397134320258, 0.9898737645339912, 0.6035221564515549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 285}], {
             RGBColor[
             0.9759190443519348, 0.9295314109271395, 0.4374810367656081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 337}], {
             RGBColor[
             0.9895471708251569, 0.988806145728496, 0.740074877700955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 357}], {
             RGBColor[
             0.9761848737018956, 0.9304281157442567, 0.4385137335925449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 399}], {
             RGBColor[
             0.987939348506573, 0.987763376617098, 0.7497978220092897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 270}], {
             RGBColor[
             0.9031704563185765, 0.9224920590774812, 0.8625921066239814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 310}], {
             RGBColor[
             0.9869000866840691, 0.9671363059060647, 0.5589774532310389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 323}], {
             RGBColor[
             0.9935013456185827, 0.989311879088254, 0.5924470908631908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 346}], {
             RGBColor[
             0.9945206491922448, 0.9914920663649174, 0.7033919944438268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 389}], {
             RGBColor[
             0.9943346451391192, 0.9910942225031762, 0.6831466011450587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 390}], {
             RGBColor[
             0.9920772412623498, 0.9909917499034389, 0.7809641459326166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 244}], {
             RGBColor[
             0.868698548716813, 0.4966726006036647, 0.2121511893672765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 357}], {
             RGBColor[
             0.9157020124719202, 0.6937742333230511, 0.2543309270312845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 364}], {
             RGBColor[
             0.9340831035271799, 0.7541315905966177, 0.46573417611237916`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 385}], {
             RGBColor[
             0.9276463616870898, 0.7512511022203469, 0.5652936075982433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 337}], {
             RGBColor[
             0.989725589874711, 0.9891877660345595, 0.7594946901701929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 367}], {
             RGBColor[
             0.9879530099731828, 0.9880221209875673, 0.7694965260907927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 398}], {
             RGBColor[
             0.978673604571555, 0.9386029603065469, 0.46690867121711266`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 264}], {
             RGBColor[
             0.9289708545437612, 0.7343787679840104, 0.4826425268449658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 307}], {
             RGBColor[
             0.9130108144202284, 0.7240288691214659, 0.5792084906223312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 321}], {
             RGBColor[
             0.900797836188026, 0.6329317867454359, 0.2384443940403435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 341}], {
             RGBColor[
             0.9039636560554452, 0.6454832075728203, 0.24099168701701207`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 348}], {
             RGBColor[
             0.9072874141676448, 0.658660800910959, 0.24366606081271813`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 357}], {
             RGBColor[
             0.9114049892662123, 0.674262454541199, 0.25074538553876474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 366}], {
             RGBColor[
             0.9295826821664294, 0.7341847637278376, 0.44001000067138174`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 328}], {
             RGBColor[
             0.9894761867453177, 0.976056291595351, 0.5705762167487782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 364}], {
             RGBColor[
             0.9946828340200693, 0.9919731564907602, 0.7307992395275491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 400}], {
             RGBColor[
             0.9929242288166606, 0.9913420010237336, 0.7669273702241597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 269}], {
             RGBColor[
             0.9788329337555263, 0.9461764638663085, 0.5708555425636592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 272}], {
             RGBColor[
             0.9091456657300341, 0.9280028186134279, 0.8983912343643183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 350}], {
             RGBColor[
             0.9758494763863464, 0.9361125616109618, 0.559265374063045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 355}], {
             RGBColor[
             0.9771166713414725, 0.9814684668160831, 0.8794751305836795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 392}], {
             RGBColor[
             0.6102276339674446, 0.6748031215907144, 0.8748691943555589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 395}], {
             RGBColor[
             0.9732218821981189, 0.9785637394501019, 0.8860679926796796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 253}], {
             RGBColor[
             0.9750224360769304, 0.9794647057384991, 0.8632316631643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 266}], {
             RGBColor[
             0.9639299607517656, 0.8857921609913566, 0.5179243171880045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 301}], {
             RGBColor[
             0.9473399479073561, 0.9579474305652895, 0.8798677867521503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 315}], {
             RGBColor[
             0.9739786801892356, 0.9256319850236763, 0.5260097527211536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 316}], {
             RGBColor[
             0.993820433446452, 0.9913447828312615, 0.7253381754856413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 343}], {
             RGBColor[
             0.9796110988518962, 0.944865329918396, 0.546672614871898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 358}], {
             RGBColor[
             0.9931244095310684, 0.9898560580550684, 0.649580267657821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 359}], {
             RGBColor[
             0.9073907026173766, 0.9260929867644353, 0.8760573920732798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 362}], {
             RGBColor[
             0.9782855606638079, 0.9818983387125162, 0.8577080443979126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 363}], {
             RGBColor[
             0.98652562236391, 0.9681896413317452, 0.573534233017871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 369}], {
             RGBColor[
             0.9938502055927814, 0.991408462441834, 0.7285786898811932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 397}], {
             RGBColor[
             0.9585789740741307, 0.9669091249554372, 0.8809397751011344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 276}], {
             RGBColor[
             0.9740598767696629, 0.9324537297295497, 0.5687491278857666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 340}], {
             RGBColor[
             0.9911208506462486, 0.9892514030925785, 0.6990572728750903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 360}], {
             RGBColor[
             0.9815830636641945, 0.95783120565309, 0.5979752883363864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 266}], {
             RGBColor[
             0.9627197794609295, 0.8852917199273552, 0.537980153025946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 293}], {
             RGBColor[
             0.9879578804856988, 0.9892882883595504, 0.8492326145656826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 315}], {
             RGBColor[
             0.9727684988983996, 0.925131543959675, 0.546065588559095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 316}], {
             RGBColor[
             0.9926102521556159, 0.9908443417672601, 0.7453940113235829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 387}], {
             RGBColor[
             0.9826824700827287, 0.958807570866322, 0.5833614737531722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 397}], {
             RGBColor[
             0.9573687927832946, 0.9664086838914359, 0.900995610939076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 356}], {
             RGBColor[
             0.9894677163998669, 0.9747972295554201, 0.5272772493312402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 363}], {
             RGBColor[
             0.9822660104758636, 0.951841230575643, 0.3856072287919899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 372}], {
             RGBColor[
             0.9707560616796865, 0.9631112515141099, 0.6753161061025454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 283}], {
             RGBColor[
             0.9764572586919397, 0.9819624425969251, 0.9247358994909252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 308}], {
             RGBColor[
             0.9854974115962862, 0.9852946496766993, 0.7025522999302692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 380}], {
             RGBColor[
             0.9474578600455965, 0.9598513195179452, 0.9570638751887687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 381}], {
             RGBColor[
             0.9840210875473479, 0.9866254865699466, 0.868133358196372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 282}], {
             RGBColor[
             0.9270467374828144, 0.9374014534979438, 0.7030443645725634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 300}], {
             RGBColor[
             0.9153671501614, 0.8980034629652975, 0.6576713733338635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 367}], {
             RGBColor[
             0.922373960608273, 0.9397566272332596, 0.9514306259518679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 398}], {
             RGBColor[
             0.9130945552066453, 0.890337466552239, 0.6488427710781879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 266}], {
             RGBColor[
             0.9461671620736323, 0.8739723433225768, 0.6119251188223835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 301}], {
             RGBColor[
             0.9295771492292229, 0.9461276128965097, 0.9738685883865293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 315}], {
             RGBColor[
             0.9562158815111024, 0.9138121673548965, 0.6200105543555325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 316}], {
             RGBColor[
             0.9760576347683187, 0.9795249651624817, 0.8193389771200204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 343}], {
             RGBColor[
             0.9618483001737629, 0.9330455122496162, 0.640673416506277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 358}], {
             RGBColor[
             0.975361610852935, 0.9780362403862886, 0.7435810692922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 359}], {
             RGBColor[
             0.8896279039392432, 0.9142731690956555, 0.9700581937076589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 362}], {
             RGBColor[
             0.9605227619856745, 0.9700785210437364, 0.9517088460322916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 369}], {
             RGBColor[
             0.9760874069146479, 0.9795886447730542, 0.8225794915155722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 394}], {
             RGBColor[
             0.948449665833254, 0.9610744257011417, 0.9721454486505581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 397}], {
             RGBColor[
             0.9408161753959974, 0.9550893072866574, 0.9749405767355135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 303}], {
             RGBColor[
             0.9411490910641375, 0.9241248857318183, 0.6683152663857663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 268}], {
             RGBColor[
             0.9899803410820112, 0.9899171507108082, 0.8006338150345673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 324}], {
             RGBColor[
             0.9779129685490289, 0.9810381355954196, 0.8264709176011305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 328}], {
             RGBColor[
             0.9898994197378916, 0.9760238322341881, 0.5484807572799797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 351}], {
             RGBColor[
             0.929065527857686, 0.9427353966960543, 0.8442396926214997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 400}], {
             RGBColor[
             0.9933474618092346, 0.9913095416625707, 0.7448319107553613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 311}], {
             RGBColor[
             0.9946693855413341, 0.9910066796177366, 0.6611736967924127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 313}], {
             RGBColor[
             0.994266550817269, 0.9901450568757996, 0.6173276230856704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 386}], {
             RGBColor[
             0.9380821441284044, 0.772157130337488, 0.4750595688165551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 275}], {
             RGBColor[
             0.9699927495373386, 0.9683721362724476, 0.6889845243653903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 276}], {
             RGBColor[
             0.9741525287334958, 0.9244725515225292, 0.3540878843253545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 279}], {
             RGBColor[
             0.9903309667123046, 0.9822501283246741, 0.5967786736964305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 280}], {
             RGBColor[
             0.8863395279308193, 0.9023622061247967, 0.6948601319041057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 288}], {
             RGBColor[
             0.9858602459142198, 0.9802060890896849, 0.6621249919051863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 309}], {
             RGBColor[
             0.9510426277890911, 0.8339253506370236, 0.32989004214302864`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 325}], {
             RGBColor[
             0.9107612535539584, 0.9215443809846899, 0.6972667326193249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 339}], {
             RGBColor[
             0.9869655384621419, 0.9676938419750047, 0.4038640075872876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 277}], {
             RGBColor[
             0.9795496989656443, 0.9414849886407248, 0.5245008746631673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 302}], {
             RGBColor[
             0.9447273978805493, 0.8030584956087377, 0.4836981054868974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 377}], {
             RGBColor[
             0.9338767951931961, 0.7537884430281103, 0.4746440966319599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 378}], {
             RGBColor[
             0.9948705963917891, 0.9921468740354144, 0.7346710224664634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 379}], {
             RGBColor[
             0.9907626967322791, 0.9904481519580011, 0.8027495507280802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 262}], {
             RGBColor[
             0.9888580143015202, 0.9750735650514137, 0.5757952710328711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 331}], {
             RGBColor[
             0.9837623210685926, 0.9858724530676585, 0.8434913833263693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 335}], {
             RGBColor[
             0.9933793270518787, 0.9898278015877315, 0.6356391239948045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 307}], {
             RGBColor[
             0.9779848574369949, 0.9806098158970168, 0.7881098020191559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 329}], {
             RGBColor[
             0.9938309906455389, 0.9892134377103574, 0.569919586358643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 341}], {
             RGBColor[
             0.9689376990722116, 0.9020641543483712, 0.4498929984138368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 349}], {
             RGBColor[
             0.9904727442768941, 0.9895238901465097, 0.7490864037962522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 366}], {
             RGBColor[
             0.9945567251831959, 0.9907657105033885, 0.6489113120682064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 306}], {
             RGBColor[
             0.8868052152082214, 0.9119745991936952, 0.9658732993795338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 284}], {
             RGBColor[
             0.9866914357542871, 0.974177629143604, 0.6117010844860697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 286}], {
             RGBColor[
             0.9872286298268809, 0.9743997726978795, 0.6027983884894943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 331}], {
             RGBColor[
             0.9791703177460435, 0.9693865899113191, 0.6610729653716569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 332}], {
             RGBColor[
             0.934914849137997, 0.7659204789191416, 0.3098003637395691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 338}], {
             RGBColor[
             0.9838092563564325, 0.9728463027313823, 0.653220452333231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 264}], {
             RGBColor[
             0.9941201094550359, 0.9918365284004323, 0.7471085332063971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 312}], {
             RGBColor[
             0.957701933762346, 0.9658423014383883, 0.8648982040528281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 348}], {
             RGBColor[
             0.9724366690789197, 0.916118561327381, 0.5081320671741494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 307}], {
             RGBColor[
             0.9775801434528844, 0.9812468152836638, 0.8532853695925402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 312}], {
             RGBColor[
             0.9571220078837273, 0.9656024871841642, 0.8745090766616058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 348}], {
             RGBColor[
             0.9718567432003009, 0.9158787470731569, 0.5177429397829272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 357}], {
             RGBColor[
             0.9759743182988683, 0.9314804007033968, 0.5248222645089737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 366}], {
             RGBColor[
             0.9941520111990854, 0.9914027098900353, 0.7140868796415908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 291}], {
             RGBColor[
             0.9931016889327708, 0.9875928929995585, 0.4956961613372467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 304}], {
             RGBColor[
             0.9943051564218568, 0.9906333722863663, 0.6510227596880129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 378}], {
             RGBColor[
             0.9943051564218568, 0.9906333722863663, 0.6510227596880129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 383}], {
             RGBColor[
             0.9307703079669658, 0.7407366391648776, 0.38887552173608647`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 293}], {
             RGBColor[
             0.9603127877732367, 0.8842963670076294, 0.5778702343858244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 315}], {
             RGBColor[
             0.9451234061859375, 0.820139622607754, 0.274703208379237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 316}], {
             RGBColor[
             0.9649651594431539, 0.8858524204153391, 0.4740316311437247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 338}], {
             RGBColor[
             0.9592135942411806, 0.8837023510715623, 0.5898409122171955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 397}], {
             RGBColor[
             0.9297237000708326, 0.8614167625395148, 0.6296332307592178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 282}], {
             RGBColor[
             0.9893458123082939, 0.985142109074103, 0.6359103362661571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 332}], {
             RGBColor[
             0.9366609353498714, 0.7812294822134833, 0.5393829932155552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 367}], {
             RGBColor[
             0.9846730354337525, 0.9874972828094188, 0.8842965976454618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 383}], {
             RGBColor[
             0.9277500814105539, 0.7407673756578559, 0.5319475582635713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 398}], {
             RGBColor[
             0.9753936300321246, 0.9380781221283984, 0.5817087427717816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 270}], {
             RGBColor[
             0.898454755178833, 0.9205419954682058, 0.9407434783528785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 274}], {
             RGBColor[
             0.9871482434227313, 0.98895348262729, 0.862650395972606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 295}], {
             RGBColor[
             0.9826195715802815, 0.9666542269826095, 0.6388194405316381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 324}], {
             RGBColor[
             0.9728518107375925, 0.9791526938547518, 0.9254287938831585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 351}], {
             RGBColor[
             0.9240043700462497, 0.9408499549553866, 0.9431975689035277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 373}], {
             RGBColor[
             0.9895433897573163, 0.9889825560098415, 0.7530743598925249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 272}], {
             RGBColor[
             0.8978531312078264, 0.883994640863714, 0.6559367016137074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 350}], {
             RGBColor[
             0.9645569418641387, 0.8921043838612479, 0.3168108413124341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 355}], {
             RGBColor[
             0.9658241368192647, 0.9374602890663692, 0.6370205978330687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 392}], {
             RGBColor[
             0.5989350994452369, 0.6307949438410005, 0.632414661604948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 395}], {
             RGBColor[
             0.961929347675911, 0.934555561700388, 0.6436134599290688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 295}], {
             RGBColor[
             0.8961551434885398, 0.8991645134806749, 0.6799712275679213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 310}], {
             RGBColor[
             0.8957199574525837, 0.8976965287948547, 0.6782806119962193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 324}], {
             RGBColor[
             0.8863873826458508, 0.9116629803528172, 0.9665805809194418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 346}], {
             RGBColor[
             0.9033405199607594, 0.9220522892537075, 0.8226951532090072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 351}], {
             RGBColor[
             0.8375399419545078, 0.873360241453452, 0.9843493559398109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 373}], {
             RGBColor[
             0.9030789616655744, 0.921492842507907, 0.7942261469288081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 390}], {
             RGBColor[
             0.9008971120308644, 0.9215519727922289, 0.9002673046977969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 287}], {
             RGBColor[
             0.943749749096657, 0.8094652157451906, 0.5286262993648297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 292}], {
             RGBColor[
             0.9364129294622514, 0.7781320525589627, 0.29691804427328666`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 371}], {
             RGBColor[
             0.9349051499630953, 0.8037796389300156, 0.5843813861480176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 374}], {
             RGBColor[
             0.9221678718554358, 0.7942801977727019, 0.6059422755701058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 382}], {
             RGBColor[
             0.9281171219768782, 0.7501483459625715, 0.2646903987244029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 384}], {
             RGBColor[
             0.9081537410204042, 0.6717233524075141, 0.24486116665621674`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 389}], {
             RGBColor[
             0.9460722478303067, 0.8095946067411095, 0.42972996433867455`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 391}], {
             RGBColor[
             0.9418621497672015, 0.8086846449133707, 0.5599087052043796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 350}], {
             RGBColor[
             0.8948696738386466, 0.8739307386083675, 0.6443465331130932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 392}], {
             RGBColor[
             0.5292478314197447, 0.6126212985881201, 0.9599503534056071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 395}], {
             RGBColor[
             0.8922420796504189, 0.9163819164475074, 0.9711491517297278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 322}], {
             RGBColor[
             0.9715375854050795, 0.9156517336578898, 0.34392932328506953`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 330}], {
             RGBColor[
             0.9633031419803524, 0.9611006756780367, 0.6954632619615382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 295}], {
             RGBColor[
             0.9848486317324381, 0.9675760006397591, 0.6018781451876487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 296}], {
             RGBColor[
             0.9661542682430001, 0.9734170218739264, 0.903597908389272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 319}], {
             RGBColor[
             0.9874954394120665, 0.98909705709141, 0.8568964599149035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 324}], {
             RGBColor[
             0.9750808708897492, 0.9800744675119014, 0.8884874985391692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 351}], {
             RGBColor[
             0.9262334301984061, 0.9417717286125362, 0.9062562735595383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 373}], {
             RGBColor[
             0.9917724499094728, 0.9899043296669912, 0.7161330645485355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 276}], {
             RGBColor[
             0.9554413584643552, 0.9192868773541719, 0.6324551178464776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 280}], {
             RGBColor[
             0.8676283576616788, 0.8971765319564393, 0.9732273654252287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 288}], {
             RGBColor[
             0.9671490756450793, 0.9750204149213276, 0.9404922254263093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 290}], {
             RGBColor[
             0.9079965303223585, 0.720877360559358, 0.5880880202665425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 297}], {
             RGBColor[
             0.9487300709762465, 0.8937547143088864, 0.6214519849760176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 318}], {
             RGBColor[
             0.970711301599634, 0.9766887681912646, 0.8902020178841333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 325}], {
             RGBColor[
             0.8920500832848177, 0.9163587068163326, 0.975633966140448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 339}], {
             RGBColor[
             0.9682543681930011, 0.9625081678066474, 0.6822312411084106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 288}], {
             RGBColor[
             0.9713088548412365, 0.9311208301714092, 0.6055955853862736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 290}], {
             RGBColor[
             0.9121563095185157, 0.6769777758094396, 0.25319138022650667`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 297}], {
             RGBColor[
             0.9528898501724037, 0.849855129558968, 0.2865553449359818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 318}], {
             RGBColor[
             0.9748710807957912, 0.9327891834413462, 0.5553053778440975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 278}], {
             RGBColor[
             0.9768353749670431, 0.9403625459123583, 0.5694842477653235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 302}], {
             RGBColor[
             0.9293475803907856, 0.7523722452535653, 0.27450441561800276`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 314}], {
             RGBColor[
             0.9632855137384442, 0.88781555824776, 0.3118715831331661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 352}], {
             RGBColor[
             0.9790059070587447, 0.940017789909549, 0.44320886994947656`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 378}], {
             RGBColor[
             0.9794907789020254, 0.9414606236802419, 0.5254773325975688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 379}], {
             RGBColor[
             0.9753828792425154, 0.9397619016028287, 0.5935558608591855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 314}], {
             RGBColor[
             0.9759510072296067, 0.9373793658745659, 0.5660486461042169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 319}], {
             RGBColor[
             0.9875572218537254, 0.9891226057187723, 0.8558725649687822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 352}], {
             RGBColor[
             0.9916714005499072, 0.9895815975363549, 0.6973859329205273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 379}], {
             RGBColor[
             0.988048372733678, 0.9893257092296346, 0.8477329238302362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.9749174039697639, 0.9302565619174473, 0.5368998930487463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 288}], {
             RGBColor[
             0.9874872928200452, 0.988898406973554, 0.8482863747573495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 309}], {
             RGBColor[
             0.9526696746949164, 0.8426176685208927, 0.5160514249951917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 325}], {
             RGBColor[
             0.9123883004597837, 0.9302366988685591, 0.883428115471488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 399}], {
             RGBColor[
             0.9869377081244021, 0.9884885276074058, 0.849216678292428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 297}], {
             RGBColor[
             0.8650768493697273, 0.8277447841612355, 0.6273275925147329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 309}], {
             RGBColor[
             0.8486782359134312, 0.7627297463210153, 0.614132883202867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 322}], {
             RGBColor[
             0.8700418585861623, 0.8473863405505293, 0.6315467640567218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 325}], {
             RGBColor[
             0.8083968616782985, 0.8503487766686817, 0.9815095736791632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 339}], {
             RGBColor[
             0.8846011465864819, 0.8964982376589965, 0.688106848647126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 355}], {
             RGBColor[
             0.9757065844226482, 0.9808853596375684, 0.9028439200165659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 386}], {
             RGBColor[
             0.9340940295807452, 0.7705083535217808, 0.5411828260220072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 367}], {
             RGBColor[
             0.9862606643393268, 0.9834336833997643, 0.667664821881488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 383}], {
             RGBColor[
             0.9293377103161282, 0.7367037762482014, 0.3153157824995977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 398}], {
             RGBColor[
             0.9769812589376989, 0.9340145227187437, 0.36507696700780795`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 294}], {
             RGBColor[
             0.9849332672351427, 0.9861858729163122, 0.8076057573628463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 320}], {
             RGBColor[
             0.9572955261537487, 0.9676716538443997, 0.9571717144978322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 347}], {
             RGBColor[
             0.9726749307729696, 0.9463243436499481, 0.6333946008492668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 373}], {
             RGBColor[
             0.9845594771419222, 0.985386373702889, 0.766921012480841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 380}], {
             RGBColor[
             0.9459519593934433, 0.9587282212772554, 0.959612972191071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 381}], {
             RGBColor[
             0.9825151868951947, 0.9855023883292567, 0.8706824551986744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 332}], {
             RGBColor[
             0.9373402739133131, 0.7815104061676712, 0.5281245951474802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 338}], {
             RGBColor[
             0.9862346811317484, 0.9884362299799119, 0.871544683741142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 367}], {
             RGBColor[
             0.9853523739971942, 0.9877782067636067, 0.8730381995773868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 399}], {
             RGBColor[
             0.9698970984760362, 0.9278026433163098, 0.6031765147925807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 332}], {
             RGBColor[
             0.937877467985907, 0.7817325497219467, 0.5192218991509046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 292}], {
             RGBColor[
             0.9823368876264714, 0.9586646636395956, 0.5890886693920834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 371}], {
             RGBColor[
             0.9808291081273153, 0.9843122500106485, 0.8765520112668141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 374}], {
             RGBColor[
             0.9680918300196559, 0.9748128088533348, 0.8981129006889024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 382}], {
             RGBColor[
             0.9740410801410982, 0.9306809570432044, 0.5568610238431996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 384}], {
             RGBColor[
             0.9540776991846243, 0.852255963488147, 0.5370317917750134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 389}], {
             RGBColor[
             0.9919962059945266, 0.9901272178217424, 0.7219005894574713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 391}], {
             RGBColor[
             0.9877861079314216, 0.9892172559940036, 0.8520793303231763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 303}], {
             RGBColor[
             0.9825437501058187, 0.9523519974100454, 0.42291986667970954`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 376}], {
             RGBColor[
             0.9922837988664208, 0.9892753894651596, 0.6465707615451619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 297}], {
             RGBColor[
             0.9054450220304071, 0.6514456127641541, 0.24218824735604672`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 318}], {
             RGBColor[
             0.9274262526537944, 0.7343796666465323, 0.5109382802641624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 345}], {
             RGBColor[
             0.9105148887475113, 0.7227555481494035, 0.5838250963458304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 304}], {
             RGBColor[
             0.9936082088390843, 0.9890820297881238, 0.5803208820500986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 383}], {
             RGBColor[
             0.9300733603841933, 0.7391852966666352, 0.31817364409817217`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 371}], {
             RGBColor[
             0.9734922884929097, 0.9529790868244206, 0.6448437561752711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 374}], {
             RGBColor[
             0.9607550103852502, 0.9434796456671068, 0.6664046455973593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 382}], {
             RGBColor[
             0.9667042605066927, 0.8993477938569765, 0.3251527687516565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 384}], {
             RGBColor[
             0.9467408795502187, 0.8209228003019191, 0.30532353668347034`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 389}], {
             RGBColor[
             0.9846593863601212, 0.9587940546355145, 0.49019233436592813`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 316}], {
             RGBColor[
             0.9902032604679232, 0.9898489888475344, 0.7852840926834612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 387}], {
             RGBColor[
             0.9802754783950359, 0.9578122179465962, 0.6232515551130506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 320}], {
             RGBColor[
             0.9672774353491049, 0.9730181824044767, 0.8374924753674511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 347}], {
             RGBColor[
             0.9826568399683258, 0.9516708722100251, 0.5137153617188857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 380}], {
             RGBColor[
             0.9559338685887996, 0.9640747498373323, 0.83993373306069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 381}], {
             RGBColor[
             0.9924970960905508, 0.9908489168893337, 0.7510032160682933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 310}], {
             RGBColor[
             0.9798847738540322, 0.9438087603092584, 0.3763565741749787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 324}], {
             RGBColor[
             0.9705521990472993, 0.9577752118672209, 0.6646565430982012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 351}], {
             RGBColor[
             0.9217047583559563, 0.9194724729678556, 0.6824253181185704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 373}], {
             RGBColor[
             0.9872437780670229, 0.9676050740223106, 0.49230210910756766`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 390}], {
             RGBColor[
             0.985061928432313, 0.9676642043066326, 0.5983432668765565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 308}], {
             RGBColor[
             0.9679814483797959, 0.9722312729895983, 0.7322022567609214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 373}], {
             RGBColor[
             0.968549414577585, 0.9734460952564779, 0.794021872309191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 380}], {
             RGBColor[
             0.9299418968291063, 0.9467879428308443, 0.9867138320194209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 318}], {
             RGBColor[
             0.9681597933076825, 0.9072570203960608, 0.5443022449736376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 322}], {
             RGBColor[
             0.9511435719007302, 0.8439645229029764, 0.2797713836075108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 339}], {
             RGBColor[
             0.9657028599010498, 0.8930764200114436, 0.3363314681979149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 313}], {
             RGBColor[
             0.9941884636906464, 0.9899780364077733, 0.6088283212506747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 361}], {
             RGBColor[
             0.9783727263057552, 0.981439428187737, 0.8303269347345263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 393}], {
             RGBColor[
             0.9808062936405562, 0.9832543787214307, 0.8262075400127218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 396}], {
             RGBColor[
             0.9825381915853524, 0.9845460253729371, 0.823275888543509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 306}], {
             RGBColor[
             0.903477516770919, 0.9223453115781366, 0.8376064105485692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 342}], {
             RGBColor[
             0.9675287536200382, 0.9732401153107562, 0.8398044985325959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 353}], {
             RGBColor[
             0.984621137807365, 0.9582663417159809, 0.523945599239166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 319}], {
             RGBColor[
             0.9765939209101423, 0.9453006932487682, 0.608308198612987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 343}], {
             RGBColor[
             0.9341658120041887, 0.9115282370764065, 0.6573095400941272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 358}], {
             RGBColor[
             0.9476791226833607, 0.956518965213079, 0.7602171928800503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 359}], {
             RGBColor[
             0.861945415769669, 0.8927558939224458, 0.9866943172955092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 362}], {
             RGBColor[
             0.9328402738161004, 0.9485612458705268, 0.9683449696201418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 369}], {
             RGBColor[
             0.9484049187450737, 0.9580713695998446, 0.8392156151034225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 394}], {
             RGBColor[
             0.9207671776636797, 0.9395571505279321, 0.9887815722384083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 397}], {
             RGBColor[
             0.9131336872264231, 0.9335720321134477, 0.9915767003233638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 314}], {
             RGBColor[
             0.9284632126533492, 0.7493890652157729, 0.27106881395689625`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 352}], {
             RGBColor[
             0.9441836059736497, 0.8015912968775618, 0.4024061007732067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 377}], {
             RGBColor[
             0.8836746766183375, 0.5646756996409507, 0.22464763758679535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 379}], {
             RGBColor[
             0.9405605781574204, 0.8013354085708415, 0.5527530916829158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 376}], {
             RGBColor[
             0.9816341143108256, 0.9537776169480929, 0.5689650761987793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 383}], {
             RGBColor[
             0.9312768278732793, 0.7422257759534427, 0.47350024244893835`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 334}], {
             RGBColor[
             0.9949310364921854, 0.9915663245446384, 0.689652788070085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 340}], {
             RGBColor[
             0.994349058712606, 0.9903215329210978, 0.6263080983134052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 360}], {
             RGBColor[
             0.9848112717305519, 0.9589013354816094, 0.5252261137747012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 370}], {
             RGBColor[
             0.9949175548024474, 0.9915374885734966, 0.6881853893414367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 342}], {
             RGBColor[
             0.8760415639362104, 0.9039470856988908, 0.9840933533731884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 353}], {
             RGBColor[
             0.8931339481235372, 0.8889733121041156, 0.6682344540797585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 361}], {
             RGBColor[
             0.8868052152082214, 0.9119745991936952, 0.9658732993795338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 312}], {
             RGBColor[
             0.9411619677601945, 0.9552525883216196, 0.9710750404389712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 341}], {
             RGBColor[
             0.9525729449645685, 0.8923512548724736, 0.6116345297645865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 348}], {
             RGBColor[
             0.9558967030767682, 0.9055288482106123, 0.6143089035602927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 366}], {
             RGBColor[
             0.9781919710755527, 0.9810528110274909, 0.8106528434189562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 325}], {
             RGBColor[
             0.8730999615365702, 0.7819119211809085, 0.6165394839180862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 339}], {
             RGBColor[
             0.9493042464447536, 0.8280613821712234, 0.323136758886049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 323}], {
             RGBColor[
             0.9860508467525899, 0.9645163488056276, 0.4081355962354285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 324}], {
             RGBColor[
             0.9701170130113432, 0.9563072271814007, 0.6629659275264992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 346}], {
             RGBColor[
             0.987070150326252, 0.966696536082291, 0.5190804998160645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 389}], {
             RGBColor[
             0.9868841462731264, 0.9662986922205498, 0.49883510651729634`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 390}], {
             RGBColor[
             0.984626742396357, 0.9661962196208124, 0.5966526513048543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 313}], {
             RGBColor[
             0.993654412823199, 0.9888357556031288, 0.5507001801089444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 361}], {
             RGBColor[
             0.9778386754383079, 0.9802971473830925, 0.7721987935927961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 386}], {
             RGBColor[
             0.9374700061343344, 0.7708478290648172, 0.40843212583982913`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 348}], {
             RGBColor[
             0.9354385675076109, 0.8898845201111127, 0.6355326106293582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 366}], {
             RGBColor[
             0.9577338355063955, 0.9654084829279913, 0.8318765504880218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 361}], {
             RGBColor[
             0.9774358407142427, 0.9794355246411555, 0.7283527198860539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 393}], {
             RGBColor[
             0.9798694080490438, 0.9812504751748492, 0.7242333251642493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 396}], {
             RGBColor[
             0.98160130599384, 0.9825421218263557, 0.7213016736950364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 352}], {
             RGBColor[
             0.9781215393213083, 0.9370346098717566, 0.43977326828837005`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 379}], {
             RGBColor[
             0.974498511505079, 0.9367787215650363, 0.590120259198079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 316}], {
             RGBColor[
             0.975013878880624, 0.925692244447659, 0.4821170666768738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 358}], {
             RGBColor[
             0.9743178549652403, 0.9242035196714657, 0.4063591588490535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 359}], {
             RGBColor[
             0.8885841480515485, 0.8604404483808328, 0.6328362832645124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 362}], {
             RGBColor[
             0.9594790060979799, 0.9162458003289136, 0.6144869355891451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 363}], {
             RGBColor[
             0.9677190677980818, 0.9025371029481427, 0.3303131242091036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 369}], {
             RGBColor[
             0.9750436510269532, 0.9257559240582315, 0.4853575810724257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 397}], {
             RGBColor[
             0.9397724195083026, 0.9012565865718347, 0.637718666292367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 358}], {
             RGBColor[
             0.9941596082224566, 0.989916317479051, 0.6056875816135412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 359}], {
             RGBColor[
             0.9084259013087649, 0.9261532461884179, 0.8321647060290001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 362}], {
             RGBColor[
             0.9793207593551962, 0.9819585981364988, 0.8138153583536328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 363}], {
             RGBColor[
             0.9875608210552982, 0.9682499007557279, 0.5296415469735913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 369}], {
             RGBColor[
             0.9948854042841696, 0.9914687218658167, 0.6846860038369134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 397}], {
             RGBColor[
             0.959614172765519, 0.9669693843794198, 0.8370470890568547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 326}], {
             RGBColor[
             0.9801118315490487, 0.9543435455515619, 0.602456020091465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 327}], {
             RGBColor[0.98330795573, 0.9544851063898094, 0.4637058034216844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 336}], {
             RGBColor[
             0.9379365980008493, 0.9226037260775539, 0.6695394133925399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 396}], {
             RGBColor[
             0.9713264514546475, 0.9483446232359276, 0.642100793131652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 345}], {
             RGBColor[
             0.9732296600247867, 0.9785669557813101, 0.8859390939634212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 347}], {
             RGBColor[
             0.9550190988869318, 0.9331566531381126, 0.6632813188538715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 380}], {
             RGBColor[
             0.9282961275074055, 0.9455605307654198, 0.9894996901956757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 381}], {
             RGBColor[
             0.9648593550091569, 0.9723346978174212, 0.9005691732032791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 384}], {
             RGBColor[
             0.9290606926880411, 0.8345090317415174, 0.6201625457844187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 341}], {
             RGBColor[
             0.9403599667323661, 0.8012541724964437, 0.2708704331825989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 366}], {
             RGBColor[
             0.9659789928433503, 0.889955728651461, 0.4698887468369686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 330}], {
             RGBColor[
             0.947874137692438, 0.9090550213124171, 0.6355244938259683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 339}], {
             RGBColor[
             0.9706678691174848, 0.9127179764007374, 0.34055063973990385`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 346}], {
             RGBColor[
             0.9936714092607656, 0.9888721092644803, 0.5525501374482165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 346}], {
             RGBColor[
             0.977737575519519, 0.9806629876402535, 0.8073804687392871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 351}], {
             RGBColor[
             0.9119369975132674, 0.931970939839998, 0.9690346714700908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 390}], {
             RGBColor[
             0.9752941675896241, 0.9801626711787749, 0.8849526202280769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 339}], {
             RGBColor[
             0.909022872209621, 0.9156804125188898, 0.6905134493623453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 327}], {
             RGBColor[
             0.9907179182582997, 0.9892495162610355, 0.7177094782377161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 336}], {
             RGBColor[
             0.945346560529149, 0.95736813594878, 0.9235430882085716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 336}], {
             RGBColor[
             0.9485426847101002, 0.9575096967870276, 0.7847928715387911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 376}], {
             RGBColor[
             0.9926441027553392, 0.990046043051245, 0.6857876163160836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 364}], {
             RGBColor[
             0.9899639878570873, 0.9761619369123093, 0.5555085985861911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 386}], {
             RGBColor[
             0.9328200526518702, 0.7561216759007343, 0.30880178683569587`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 400}], {
             RGBColor[
             0.9882053826536787, 0.9755307814452827, 0.5916367292828016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 349}], {
             RGBColor[
             0.989954123377795, 0.9884146124839528, 0.6926377194864892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 335}], {
             RGBColor[
             0.9836916304964021, 0.984140826447637, 0.7209168183335903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 338}], {
             RGBColor[
             0.9787135631235049, 0.9836451907476271, 0.9209165646267291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 368}], {
             RGBColor[
             0.9034271006096042, 0.6652050919880248, 0.5724660155248436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 340}], {
             RGBColor[
             0.9943050631932628, 0.990227430953852, 0.6215194575417691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 360}], {
             RGBColor[
             0.9847672762112087, 0.9588072335143636, 0.520437473003065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 365}], {
             RGBColor[
             0.9526455787754469, 0.9614338845740251, 0.8380902493683272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 370}], {
             RGBColor[
             0.9948735592831042, 0.9914433866062508, 0.6833967485698005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 394}], {
             RGBColor[
             0.9664741653736995, 0.9713000691501371, 0.7500614957522312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 396}], {
             RGBColor[
             0.9365611804347478, 0.9513692136331457, 0.9631878612487585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 367}], {
             RGBColor[
             0.9833604673663138, 0.9869545021820723, 0.9060492473401929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 398}], {
             RGBColor[
             0.974081061964686, 0.9375353415010517, 0.6034613924665128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 399}], {
             RGBColor[
             0.9835252249492582, 0.9870773781176663, 0.9057703557279276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 360}], {
             RGBColor[
             0.9841852984316295, 0.9575624418908228, 0.4570927832463852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 370}], {
             RGBColor[
             0.9942915815035248, 0.9901985949827101, 0.6200520588131206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 348}], {
             RGBColor[
             0.9468495447119849, 0.8269831866619667, 0.2760920999549735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 366}], {
             RGBColor[
             0.9691448127107695, 0.9025071494788452, 0.47243603981363713`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 353}], {
             RGBColor[
             0.9571851849726564, 0.9398681158367351, 0.6704325420637851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 358}], {
             RGBColor[
             0.9799502736279009, 0.9434368645661855, 0.4270220209997979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 359}], {
             RGBColor[
             0.894216566714209, 0.8796737932755523, 0.6534991454152568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 362}], {
             RGBColor[
             0.9651114247606404, 0.9354791452236333, 0.6351497977398894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 369}], {
             RGBColor[
             0.9806760696896137, 0.9449892689529511, 0.5060204432231701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 354}], {
             RGBColor[
             0.9245072983794816, 0.7082348903098871, 0.3649205110946399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 356}], {
             RGBColor[
             0.925114470088338, 0.7095335692006544, 0.4310074045742162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 388}], {
             RGBColor[
             0.8821308397526284, 0.5519009519418202, 0.2231174916352029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 390}], {
             RGBColor[
             0.9922473049045326, 0.9905519800796652, 0.7410671925176423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 380}], {
             RGBColor[
             0.9436755321266266, 0.9242132205709682, 0.6657225765471102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 381}], {
             RGBColor[
             0.9802387596283778, 0.9509873876229695, 0.5767920595547136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 384}], {
             RGBColor[
             0.9444400973072622, 0.8131617215470657, 0.2963854321358532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 366}], {
             RGBColor[
             0.9724685708229692, 0.915684742816984, 0.47511041360934314`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 355}], {
             RGBColor[
             0.9628406794500849, 0.9273963868110227, 0.6254304293324544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 392}], {
             RGBColor[
             0.5959516420760571, 0.620731041585654, 0.6208244931043336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 395}], {
             RGBColor[
             0.9589458903067312, 0.9244916594450413, 0.6320232914284545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 379}], {
             RGBColor[
             0.9902189048253796, 0.9889809532268252, 0.7214575460143895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 371}], {
             RGBColor[
             0.9827197936984018, 0.9835180363148524, 0.7306554783375856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 388}], {
             RGBColor[
             0.9510786197761969, 0.8320754610661646, 0.38720083916573206`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 392}], {
             RGBColor[
             0.5972188370311831, 0.6660869467907753, 0.9410342496249682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 395}], {
             RGBColor[
             0.9602130852618573, 0.9698475646501625, 0.952233047949089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 363}], {
             RGBColor[
             0.9874677158967594, 0.9680507582359887, 0.5195076250450714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 372}], {
             RGBColor[
             0.9759577671005824, 0.9793207791744557, 0.8092165023556268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 364}], {
             RGBColor[
             0.9767895440765793, 0.9317214445341521, 0.5043283722838674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 385}], {
             RGBColor[
             0.9703528022364891, 0.9288409561578812, 0.6038878037697316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 359}], {
             RGBColor[
             0.9077298773933813, 0.9246645214122248, 0.7564067982011797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 362}], {
             RGBColor[
             0.9786247354398125, 0.9804698733603057, 0.7380574505258125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 363}], {
             RGBColor[
             0.9868647971399146, 0.9667611759795347, 0.45388363914577096`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 369}], {
             RGBColor[
             0.994189380368786, 0.9899799970896235, 0.608928096009093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 372}], {
             RGBColor[
             0.9753548483437375, 0.9780311969180017, 0.7435925164563264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 397}], {
             RGBColor[
             0.9589181488501354, 0.9654806596032267, 0.7612891812290343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 362}], {
             RGBColor[
             0.8928910285261207, 0.9167068020696726, 0.9645345749412714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 369}], {
             RGBColor[
             0.9084556734550941, 0.9262169257989905, 0.8354052204245519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 394}], {
             RGBColor[
             0.8808179323737002, 0.907702706727078, 0.9849711775595378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 397}], {
             RGBColor[
             0.8731844419364436, 0.9017175883125936, 0.9877663056444932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 370}], {
             RGBColor[
             0.9847537945214707, 0.9587783975432216, 0.5189700742744167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 393}], {
             RGBColor[
             0.9640536706641526, 0.9727118669548129, 0.9457319386481011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 396}], {
             RGBColor[
             0.9657855686089488, 0.9740035136063194, 0.9428002871788882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 363}], {
             RGBColor[
             0.9720259482726541, 0.9588034566369825, 0.6620114158858625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 369}], {
             RGBColor[
             0.9793505315015254, 0.9820222777470713, 0.8170558727491848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 397}], {
             RGBColor[
             0.9440792999828749, 0.9575229402606745, 0.969416957969126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 369}], {
             RGBColor[
             0.9875905932016276, 0.9683135803663004, 0.5328820613691432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 372}], {
             RGBColor[
             0.9687560611765791, 0.9563647801946786, 0.6675464818163765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 385}], {
             RGBColor[
             0.9887338932917489, 0.9891983134314478, 0.8152910528508263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 370}], {
             RGBColor[
             0.9526320970857087, 0.9614050486028833, 0.8366228506396789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 398}], {
             RGBColor[
             0.9723084820631576, 0.9363696964540595, 0.6134632283871125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 372}], {
             RGBColor[
             0.9760806444054504, 0.9795836013047674, 0.8225909386796987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 389}], {
             RGBColor[
             0.9831516068609649, 0.9844416410065673, 0.777655676240659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 391}], {
             RGBColor[
             0.9789415087978599, 0.9835316791788286, 0.9078344171063641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 380}], {
             RGBColor[
             0.955560078495579, 0.9632752506239091, 0.7992489881786845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 382}], {
             RGBColor[
             0.9524592028998771, 0.9154959390707158, 0.6341770000484757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 384}], {
             RGBColor[
             0.9324958219434032, 0.8370709455156583, 0.6143477679802894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 389}], {
             RGBColor[
             0.9704143287533056, 0.9749421998492538, 0.7992165656627472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 377}], {
             RGBColor[
             0.9116112527251257, 0.6782294936583699, 0.24727062315752513`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 379}], {
             RGBColor[
             0.9907037766686603, 0.9904237869975181, 0.8037260086624816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 381}], {
             RGBColor[
             0.9535157882488516, 0.9633912652502769, 0.9030104308965179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 384}], {
             RGBColor[
             0.9384450720648455, 0.792939093705528, 0.27309589113458654`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 389}], {
             RGBColor[
             0.976363578874748, 0.9308103480391234, 0.4579646888170444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 389}], {
             RGBColor[
             0.9564001979182739, 0.8523853544840658, 0.43813545674885823`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 387}], {
             RGBColor[
             0.9786486097218623, 0.9568246627542722, 0.6361154493186154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 400}], {
             RGBColor[
             0.9362680947232132, 0.771407385329117, 0.5051529403110775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 390}], {
             RGBColor[
             0.992061300851407, 0.9901541362179239, 0.7208217992188741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 395}], {
             RGBColor[
             0.5933240478878294, 0.6631822194247939, 0.9476271117209683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 396}], {
             RGBColor[
             0.9682191359437498, 0.9758184641400132, 0.9386808924570836]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.0002105009621202394], {
             RGBColor[
             0.9828879759502404, 0.9539392661651541, 0.38802344721161935`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.0002105009621202394], {
             RGBColor[
             0.9579404327247287, 0.9681526241090991, 0.9560800558917352]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.0002105009621202394], {
             RGBColor[
             0.7205676449525134, 0.7816321878446202, 0.9727831068275259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.0002105009621202394], {
             RGBColor[
             0.9484655253352116, 0.8333900113394398, 0.277392355896362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.0002105009621202394], {
             RGBColor[
             0.9852070014068534, 0.9881507291660803, 0.8948217999490007]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.0002105009621202394], {
             RGBColor[
             0.9950629069602337, 0.9918483821416441, 0.7040060747069435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.0002105009621202394], {
             RGBColor[
             0.9756719670207536, 0.9295979736465257, 0.3599906151495073]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.0002105009621202394], {
             RGBColor[
             0.9009781315626139, 0.923879521980895, 0.9904172925727569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.0002105009621202394], {
             RGBColor[
             0.8919494102834592, 0.9166802647110073, 0.9895561250771165]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.0002105009621202394], {
             RGBColor[
             0.9553303131372158, 0.9662060011944106, 0.9604983075251787]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.0002105009621202394], {
             RGBColor[
             0.9742775691599832, 0.9248943422419599, 0.3545736427703552]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.0002105009621202394], {
             RGBColor[
             0.939082188638584, 0.7961882081489056, 0.269842302935035]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.0002105009621202394], {
             RGBColor[
             0.9951407338489145, 0.992014845987027, 0.7124770512479781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.0002105009621202394], {
             RGBColor[
             0.9324715808643752, 0.769979351178622, 0.264523252748999]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.0002105009621202394], {
             RGBColor[
             0.9951023043005559, 0.9919326490689112, 0.7082942320688198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.0002105009621202394], {
             RGBColor[
             0.8573999889370166, 0.8891314939484133, 0.9862607704264603]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.0002105009621202394], {
             RGBColor[
             0.9897734772645105, 0.990039084286298, 0.8191434773269266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.0002105009621202394], {
             RGBColor[
             0.948895252039341, 0.8350937345233774, 0.2777381240894867]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.0002105009621202394], {
             RGBColor[
             0.9811831585657033, 0.9481885168169526, 0.38140055360044167`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.0002105009621202394], {
             RGBColor[
             0.24406890634008505`, 0.3738622737988424, 0.9372107351972535]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.0002105009621202394], {
             RGBColor[
             0.993395861717036, 0.9882827409305729, 0.5225584877955738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.0002105009621202394], {
             RGBColor[
             0.9942325610199864, 0.9900723561363075, 0.613628043412162]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.0002105009621202394], {
             RGBColor[
             0.9100405428804852, 0.6810477602728002, 0.24647471306302837`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.0002105009621202394], {
             RGBColor[
             0.9880591674148439, 0.9893301731077073, 0.8475540280275774]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.0002105009621202394], {
             RGBColor[
             0.9418502329460632, 0.9561525794594544, 0.9833165671208103]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.0002105009621202394], {
             RGBColor[
             0.9512518521540752, 0.9631642916710511, 0.9674020781366502]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.0002105009621202394], {
             RGBColor[
             0.9889310946938675, 0.9896907374450926, 0.8331039365386905]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.0002105009621202394], {
             RGBColor[
             0.897825790932437, 0.6289326046645577, 0.2364556742460331]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.0002105009621202394], {
             RGBColor[
             0.957826216273993, 0.8694000659961638, 0.2906632433855933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.0002105009621202394], {
             RGBColor[
             0.9865306128830749, 0.9886980765267612, 0.872886132391314]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.0002105009621202394], {
             RGBColor[
             0.9844603247770298, 0.9878419591909341, 0.9071961640423525]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.0002105009621202394], {
             RGBColor[
             0.9152453005909956, 0.9352557752921401, 0.9917781078911361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.0002105009621202394], {
             RGBColor[
             0.8925150036348286, 0.6048175599120048, 0.23202422314559976`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.0002105009621202394], {
             RGBColor[
             0.9891422275385692, 0.9897780463022433, 0.8296049189076977]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.0002105009621202394], {
             RGBColor[
             0.9683382840446508, 0.9048597389374815, 0.3315006416371711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.0002105009621202394], {
             RGBColor[
             0.9065960025807546, 0.9283590598377139, 0.9909531301255998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.0002105009621202394], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.0002105009621202394], {
             RGBColor[
             0.9895667687271889, 0.9899536049939485, 0.822569172734893]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.0002105009621202394], {
             RGBColor[
             0.8320815633109008, 0.24759853060407463`, 0.17835464729844908`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.0002105009621202394], {
             RGBColor[
             0.8884053622073753, 0.9138543369757604, 0.9892180906078105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.0002105009621202394], {
             RGBColor[
             0.9714413449397767, 0.9153270919700877, 0.3435554472508552]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.0002105009621202394], {
             RGBColor[
             0.9917388452287326, 0.983795326524442, 0.42240740301214574`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.0002105009621202394], {
             RGBColor[
             0.9205574605660656, 0.7227438343410605, 0.2549368718966325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.0002105009621202394], {
             RGBColor[
             0.9893110438227898, 0.9898478561741492, 0.8268071961956238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.0002105009621202394], {
             RGBColor[
             0.8819720949915795, 0.5569446741218838, 0.22322696174333378`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.0002105009621202394], {
             RGBColor[
             0.9793334471177425, 0.9419490057700797, 0.3742147739138114]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.0002105009621202394], {
             RGBColor[
             0.8340200559088429, 0.2624986341647308, 0.18021094999945272`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.0002105009621202394], {
             RGBColor[
             0.9935981248373978, 0.9916206743466462, 0.755759169173549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.0002105009621202394], {
             RGBColor[
             0.9856070517787426, 0.9631113474040576, 0.39858654335096605`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.0002105009621202394], {
             RGBColor[
             0.9901424702606844, 0.9784103789105484, 0.41620578771139594`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.0002105009621202394], {
             RGBColor[
             0.9947057185988575, 0.9920786928308711, 0.7374034741853904]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.0002105009621202394], {
             RGBColor[
             0.9469458791491044, 0.9599529040543278, 0.9746909672564412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.0002105009621202394], {
             RGBColor[
             0.9687284348161009, 0.9061758091013402, 0.33301630371046376`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.0002105009621202394], {
             RGBColor[
             0.9936283996253691, 0.9916331937494989, 0.7552574375882243]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.0002105009621202394], {
             RGBColor[
             0.9065200759494623, 0.928298518002895, 0.9909458881757267]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.0002105009621202394], {
             RGBColor[
             0.9891125414810424, 0.9897657703545591, 0.8300968937059698]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.0002105009621202394], {
             RGBColor[
             0.9905081623991598, 0.9903428954700223, 0.8069678433416062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.0002105009621202394], {
             RGBColor[
             0.8470764299196405, 0.36285564615129445`, 0.1927137484972579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.0002105009621202394], {
             RGBColor[
             0.9351745822349072, 0.9511468435090561, 0.9936789805654122]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.0002105009621202394], {
             RGBColor[
             0.9934849012828627, 0.9915738534971333, 0.7576355764853618]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.0002105009621202394], {
             RGBColor[
             0.977952614987214, 0.9830776768735195, 0.92220465133441]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.0002105009621202394], {
             RGBColor[
             0.9928868053020993, 0.991326525438722, 0.7675475747093934]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.0002105009621202394], {
             RGBColor[
             0.9677668596092648, 0.9754811571902887, 0.9394464783188067]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.0002105009621202394], {
             RGBColor[
             0.9924795345788142, 0.9911581085282635, 0.7742971045770716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.0002105009621202394], {
             RGBColor[
             0.9947383209771076, 0.9920921747521204, 0.7368631684055362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.0002105009621202394], {
             RGBColor[
             0.9932255051874108, 0.9879183655393918, 0.5040162308645052]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.0002105009621202394], {
             RGBColor[
             0.95454873505318, 0.857507910761715, 0.28228704922672376`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.0002105009621202394], {
             RGBColor[
             0.9895667687271889, 0.9899536049939485, 0.822569172734893]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.0002105009621202394], {
             RGBColor[
             0.9910522145862081, 0.9905678750308702, 0.7979514906402906]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.0002105009621202394], {
             RGBColor[
             0.9050188550438306, 0.6611384413787375, 0.24243414515549291`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.0002105009621202394], {
             RGBColor[
             0.9934044065597317, 0.988301017485083, 0.5234885411903494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.0002105009621202394], {
             RGBColor[
             0.9674096768035977, 0.9752147708386554, 0.9400510956406054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.0002105009621202394], {
             RGBColor[
             0.993026745162457, 0.9874932379437368, 0.4823824287529716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.0002105009621202394], {
             RGBColor[
             0.9867904160366081, 0.9671031129129786, 0.4031836900331841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.0002105009621202394], {
             RGBColor[
             0.9947124151158158, 0.9910987155265956, 0.6658572004269913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.0002105009621202394], {
             RGBColor[
             0.9935860860115531, 0.9916156959827758, 0.7559586836732777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.0002105009621202394], {
             RGBColor[
             0.962948206035669, 0.9718874132449221, 0.9476032019127724]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.0002105009621202394], {
             RGBColor[
             0.9355999193880387, 0.9514859958094936, 0.9937195496027807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.0002105009621202394], {
             RGBColor[
             0.9907576703959716, 0.990446073438767, 0.8028328501284367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.0002105009621202394], {
             RGBColor[
             0.9936358743966383, 0.9887961037832378, 0.5486823867837146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.0002105009621202394], {
             RGBColor[
             0.9945022138477219, 0.990649116268751, 0.6429780896068295]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.0002105009621202394], {
             RGBColor[
             0.99418975619694, 0.9899808009480432, 0.6089690025843287]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.0002105009621202394], {
             RGBColor[
             0.9232246095453774, 0.9416182596597925, 0.9925391815024183]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.0002105009621202394], {
             RGBColor[
             0.8262110762691934, 0.8642623015875723, 0.9832859440935323]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.0002105009621202394], {
             RGBColor[
             0.9933936108804234, 0.9882779266186532, 0.5223134981208528]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.0002105009621202394], {
             RGBColor[
             0.9837499409536165, 0.956846876520549, 0.39137201848130293`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.0002105009621202394], {
             RGBColor[
             0.9143544283916373, 0.6981508788073887, 0.24994576660520865`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.0002105009621202394], {
             RGBColor[
             0.9888447531595371, 0.9740328744099133, 0.4111644018267503]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.0002105009621202394], {
             RGBColor[
             0.9579404327247287, 0.9681526241090991, 0.9560800558917352]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.0002105009621202394], {
             RGBColor[
             0.9047061197036843, 0.9268521185310421, 0.9907728714096665]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.0002105009621202394], {
             RGBColor[
             0.8252129746580207, 0.8634664424555697, 0.9831907442708429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.0002105009621202394], {
             RGBColor[
             0.9855534588624701, 0.9882939982275283, 0.8890801033062757]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.0002105009621202394], {
             RGBColor[
             0.9869328401529732, 0.9888644078396335, 0.8662201855982905]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.0002105009621202394], {
             RGBColor[
             0.9948042586080973, 0.9921194416570545, 0.7357704112189187]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.0002105009621202394], {
             RGBColor[
             0.9396396942677109, 0.9545039633325642, 0.987058432502437]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.0002105009621202394], {
             RGBColor[
             0.8943285769873786, 0.6130525729351161, 0.23353751320571817`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.0002105009621202394], {
             RGBColor[
             0.9917576924778831, 0.9838589027213716, 0.4224806210160915]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.0002105009621202394], {
             RGBColor[
             0.9801761790278822, 0.9447917383858431, 0.37748862824813645`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.0002105009621202394], {
             RGBColor[
             0.9898165458615376, 0.9773109593815379, 0.4149396329663687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.0002105009621202394], {
             RGBColor[
             0.9884372460256217, 0.989486518329441, 0.8412882870109101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.0002105009621202394], {
             RGBColor[
             0.9867609265490414, 0.9887933171464296, 0.8690692389135868]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.0002105009621202394], {
             RGBColor[
             0.9897594900686549, 0.9900333002213573, 0.819375281359956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.0002105009621202394], {
             RGBColor[
             0.9666598497837777, 0.9746555510750027, 0.9413203571989528]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.0002105009621202394], {
             RGBColor[
             0.8652747995976606, 0.4811261554905165, 0.20929432917848528`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.0002105009621202394], {
             RGBColor[
             0.9782845118004235, 0.98332520497338, 0.9216428366021988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.0002105009621202394], {
             RGBColor[
             0.9229635341012157, 0.7322831141314547, 0.25687285514081887`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.0002105009621202394], {
             RGBColor[
             0.9858174120590975, 0.9884031496576214, 0.8847057157491861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.0002105009621202394], {
             RGBColor[
             0.9898109939568714, 0.9900545984027244, 0.8185217286444173]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.0002105009621202394], {
             RGBColor[
             0.9933428303696104, 0.988169312240721, 0.5167863528998273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.0002105009621202394], {
             RGBColor[
             0.9726380024445719, 0.9193636987223055, 0.3482042356871763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.0002105009621202394], {
             RGBColor[
             0.8734443218888611, 0.901924809532398, 0.9877910932263523]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.0002105009621202394], {
             RGBColor[
             0.9855020575731862, 0.9882727424734564, 0.8899319556919844]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.0002105009621202394], {
             RGBColor[
             0.9940493075891211, 0.9896803955774509, 0.5936820383715709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.0002105009621202394], {
             RGBColor[
             0.9891423556246118, 0.9897780992691136, 0.8296027961904938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.0002105009621202394], {
             RGBColor[
             0.9720885055344193, 0.9175101166163505, 0.34606954395501766`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.0002105009621202394], {
             RGBColor[
             0.9904755600209098, 0.990329413548773, 0.8075081491214602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.0002105009621202394], {
             RGBColor[
             0.9258400539468497, 0.7436875567759781, 0.25918737052921476`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.0002105009621202394], {
             RGBColor[
             0.9927892013164379, 0.9869851556764687, 0.4565272470644719]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.0002105009621202394], {
             RGBColor[
             0.9936916356216399, 0.9916593434590478, 0.7542094534805058]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.0002105009621202394], {
             RGBColor[
             0.993144450926217, 0.9877449986705409, 0.49519397474246246`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.0002105009621202394], {
             RGBColor[
             0.9886272559616552, 0.9895650923210235, 0.8381393306408812]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.0002105009621202394], {
             RGBColor[
             0.9946395839956598, 0.9909429371249378, 0.6579299824595872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.0002105009621202394], {
             RGBColor[
             0.9104481942458594, 0.6826639620947446, 0.2468027189204159]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.0002105009621202394], {
             RGBColor[
             0.8734443218888611, 0.901924809532398, 0.9877910932263523]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.0002105009621202394], {
             RGBColor[
             0.9481774114944309, 0.8322477359689906, 0.2771605327371689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.0002105009621202394], {
             RGBColor[
             0.9852443233789203, 0.9881661627606608, 0.8942032782856841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.0002105009621202394], {
             RGBColor[
             0.9740297367276979, 0.9240583452540388, 0.35361086057015423`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.0002105009621202394], {
             RGBColor[
             0.9481894146404685, 0.8322953244432179, 0.2771701907502207]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.0002105009621202394], {
             RGBColor[
             0.8943285769873786, 0.6130525729351161, 0.23353751320571817`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.0002105009621202394], {
             RGBColor[
             0.9847573405823357, 0.9602450720169001, 0.39528557580742013`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.0002105009621202394], {
             RGBColor[
             0.8526162229044321, 0.8853170487659001, 0.985804490551754]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.0002105009621202394], {
             RGBColor[
             0.9950407038569674, 0.9918008919488356, 0.7015894039380773]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.0002105009621202394], {
             RGBColor[
             0.952126172277477, 0.9638163581875164, 0.9659220822269403]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.0002105009621202394], {
             RGBColor[
             0.9586134073685681, 0.9686545274965797, 0.9549408853596129]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.0002105009621202394], {
             RGBColor[
             0.9784414772504558, 0.9834422695490068, 0.9213771350384401]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.0002105009621202394], {
             RGBColor[
             0.9951692481390354, 0.9920758351703585, 0.7155806557578265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.0002105009621202394], {
             RGBColor[
             0.8350096993998908, 0.8712780848397279, 0.9841251646223618]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.0002105009621202394], {
             RGBColor[
             0.9872560751687145, 0.9889980738254035, 0.8608633448820527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.0002105009621202394], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.0002105009621202394], {
             RGBColor[
             0.9527587033482013, 0.964288098824388, 0.9648513721147287]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.0002105009621202394], {
             RGBColor[
             0.8471621500066813, 0.3635145283030711, 0.1927958341494151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.0002105009621202394], {
             RGBColor[
             0.9829163071380468, 0.9867795903523107, 0.9138024152613013]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.0002105009621202394], {
             RGBColor[
             0.9884370123552813, 0.9894864217007502, 0.8412921595331702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.0002105009621202394], {
             RGBColor[
             0.9938904797330012, 0.9893406788531699, 0.5763946064048228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.0002105009621202394], {
             RGBColor[
             0.9743118360261269, 0.9250099324277052, 0.3547067630745686]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.0002105009621202394], {
             RGBColor[
             0.9864102245774485, 0.9886482928685464, 0.8748812781704897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.0002105009621202394], {
             RGBColor[
             0.8332072186897712, 0.2562508111114053, 0.17943257616050134`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.0002105009621202394], {
             RGBColor[
             0.9865958770091503, 0.9887250649201049, 0.8718045369240984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.0002105009621202394], {
             RGBColor[
             0.9857592622614934, 0.9883791032219305, 0.8856694083823377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.0002105009621202394], {
             RGBColor[
             0.9920241729877886, 0.9909698048081153, 0.7818436245783902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.0002105009621202394], {
             RGBColor[
             0.9937825238794564, 0.9891097721984488, 0.5646442779727734]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.0002105009621202394], {
             RGBColor[
             0.9938598886658745, 0.9892752476538171, 0.5730649575342572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.0002105009621202394], {
             RGBColor[
             0.9788167150355792, 0.9402059471224802, 0.37220736735127274`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.0002105009621202394], {
             RGBColor[
             0.9931695275909975, 0.987798635120867, 0.4979234149485964]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.0002105009621202394], {
             RGBColor[
             0.8403151102492151, 0.8755084754394381, 0.9846311994453665]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.0002105009621202394], {
             RGBColor[
             0.9742239384730305, 0.9247134333417838, 0.35436529767884883`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.0002105009621202394], {
             RGBColor[
             0.9901404999734514, 0.9784037326690662, 0.4161981335175535]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.0002105009621202394], {
             RGBColor[
             0.9850309628531465, 0.988077932700138, 0.8977392143570954]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.0002105009621202394], {
             RGBColor[
             0.9948042586080973, 0.9921194416570545, 0.735770411218918]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.0002105009621202394], {
             RGBColor[
             0.9946655893129636, 0.9909985598691095, 0.6607605007618804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.0002105009621202394], {
             RGBColor[
             0.9951878503171715, 0.9921156233484228, 0.7176053880486043]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.0002105009621202394], {
             RGBColor[
             0.9413307724010349, 0.9557651666355109, 0.9841958783265345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.0002105009621202394], {
             RGBColor[
             0.9931163526591662, 0.9914214491699672, 0.7637433809532778]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.0002105009621202394], {
             RGBColor[
             0.9770616168309464, 0.9824131719074508, 0.9237128788034341]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.0002105009621202394], {
             RGBColor[
             0.9914350513887955, 0.9907261878871971, 0.7916068940715306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.0002105009621202394], {
             RGBColor[
             0.9945469395606877, 0.9907447800463217, 0.6478462074480577]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.0002105009621202394], {
             RGBColor[
             0.9823444695275373, 0.9521058913799997, 0.3859120273919935]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.0002105009621202394], {
             RGBColor[
             0.9636409639906356, 0.8890145754120896, 0.3132524402417817]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.0002105009621202394], {
             RGBColor[
             0.975762864844181, 0.9299045933487701, 0.3603437360289089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.0002105009621202394], {
             RGBColor[
             0.9925333932364397, 0.991180380467296, 0.7734045272384802]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.0002105009621202394], {
             RGBColor[
             0.994269808965373, 0.9901520257251447, 0.6176822523998323]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.0002105009621202394], {
             RGBColor[
             0.99306286757621, 0.9875705001342181, 0.48631413056828365`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.0002105009621202394], {
             RGBColor[
             0.9577464093279455, 0.9680079217774623, 0.9564084868930827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.0002105009621202394], {
             RGBColor[
             0.9847207579760688, 0.9879496550115647, 0.9028801119547603]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.0002105009621202394], {
             RGBColor[
             0.9870646567674207, 0.98891891739724, 0.8640356431664327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.0002105009621202394], {
             RGBColor[
             0.994934183495227, 0.9915730556659336, 0.6899953199301123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.0002105009621202394], {
             RGBColor[
             0.9472958610931247, 0.8287526823870683, 0.27645121659163047`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.0002105009621202394], {
             RGBColor[
             0.9367138575516358, 0.7867985645887066, 0.267936688150601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.0002105009621202394], {
             RGBColor[
             0.8328185873014375, 0.8695309515285748, 0.9839161743943825]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.0002105009621202394], {
             RGBColor[
             0.9651491187540724, 0.9735288503466435, 0.9438776307704866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.0002105009621202394], {
             RGBColor[
             0.9101912531427553, 0.9312258150453765, 0.9912960483337215]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.0002105009621202394], {
             RGBColor[
             0.9511585478028265, 0.8440669480269941, 0.2795592249871668]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.0002105009621202394], {
             RGBColor[
             0.9804935515655266, 0.9849727032132233, 0.9179035084897238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.0002105009621202394], {
             RGBColor[
             0.9500471661004417, 0.839660689923036, 0.27866498118194655`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.0002105009621202394], {
             RGBColor[
             0.880667585014493, 0.5510211989919807, 0.22213844664198734`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.0002105009621202394], {
             RGBColor[
             0.9677642584322084, 0.9029234157590897, 0.3292706605284732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.0002105009621202394], {
             RGBColor[
             0.9919410184091907, 0.9909354182528899, 0.7832217111429072]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.0002105009621202394], {
             RGBColor[
             0.9919999921379923, 0.990959805405305, 0.7822443638375476]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.0002105009621202394], {
             RGBColor[
             0.9921707792323118, 0.9910304302578342, 0.7794139797018412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.0002105009621202394], {
             RGBColor[
             0.9634784408568274, 0.9722828615063622, 0.9467056526679408]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.0002105009621202394], {
             RGBColor[
             0.9632689653719253, 0.9721266350327069, 0.9470602400239236]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.0002105009621202394], {
             RGBColor[
             0.9879881316313603, 0.9893007979857005, 0.8487312747946147]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.0002105009621202394], {
             RGBColor[
             0.9800001358059803, 0.9441979032614539, 0.37680473357402067`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.0002105009621202394], {
             RGBColor[
             0.9891132773848949, 0.989766074669714, 0.830084697874677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.0002105009621202394], {
             RGBColor[
             0.9948820974651904, 0.9921516300248299, 0.7344804199163797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.0002105009621202394], {
             RGBColor[
             0.9925112525188446, 0.9911712247115799, 0.77377145622737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.0002105009621202394], {
             RGBColor[
             0.9900779921305825, 0.9901650090090939, 0.8140968779369032]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.0002105009621202394], {
             RGBColor[
             0.9787779018260002, 0.9400750210527951, 0.3720565853613178]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.0002105009621202394], {
             RGBColor[
             0.9521218064797659, 0.8478859476941328, 0.28033428552921935`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.0002105009621202394], {
             RGBColor[
             0.4942040514631089, 0.6002561384733801, 0.9533246997417173]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.0002105009621202394], {
             RGBColor[
             0.9934254955126745, 0.9883461246230072, 0.52578394357223]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.0002105009621202394], {
             RGBColor[
             0.9938481032982366, 0.9892500399441232, 0.5717821929977339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.0002105009621202394], {
             RGBColor[
             0.9795948730023876, 0.9428308566647041, 0.3752303641095216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.0002105009621202394], {
             RGBColor[
             0.9917004394549995, 0.9908359326727347, 0.7872087270122305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.0002105009621202394], {
             RGBColor[
             0.9942175207935469, 0.9900401866127538, 0.611991007581751]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.0002105009621202394], {
             RGBColor[
             0.9616201033293517, 0.9708969164211192, 0.9498513333699057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.0002105009621202394], {
             RGBColor[
             0.985550888798006, 0.9882929354398247, 0.889122695925561]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.0002105009621202394], {
             RGBColor[
             0.9176236124589634, 0.7111121042433266, 0.25257622884339204`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.0002105009621202394], {
             RGBColor[
             0.9704171528602578, 0.9118722515941338, 0.339576654424369]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.0002105009621202394], {
             RGBColor[
             0.9013230048774955, 0.644812636394, 0.23937383528634812`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.0002105009621202394], {
             RGBColor[
             0.9881137489792362, 0.9893527439872658, 0.8466494702530362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.0002105009621202394], {
             RGBColor[
             0.9444133411367881, 0.8173244513030274, 0.2741318733733225]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.0002105009621202394], {
             RGBColor[
             0.896679470359131, 0.6237274306711471, 0.23549915626077808`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.0002105009621202394], {
             RGBColor[
             0.8491719113609713, 0.8825706482344907, 0.9854759690419655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.0002105009621202394], {
             RGBColor[
             0.8579866082718589, 0.4467160578370838, 0.20316134760862628`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.0002105009621202394], {
             RGBColor[
             0.9943041742801012, 0.990225529658482, 0.6214227048298536]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.0002105009621202394], {
             RGBColor[
             0.9940046528131637, 0.9895848835269684, 0.5888216415859391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.0002105009621202394], {
             RGBColor[
             0.9593770207132957, 0.8746312935161303, 0.29668782578743946`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.0002105009621202394], {
             RGBColor[
             0.9939109281618718, 0.9893844159748706, 0.5786202916943028]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.0002105009621202394], {
             RGBColor[
             0.9462295925845692, 0.824525283063563, 0.27559327192110805`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.0002105009621202394], {
             RGBColor[
             0.9688886689431359, 0.9763178007546955, 0.9375475477312962]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.0002105009621202394], {
             RGBColor[
             0.977952614987214, 0.9830776768735195, 0.92220465133441]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.0002105009621202394], {
             RGBColor[
             0.9929283899682345, 0.9913437217668462, 0.7668584091738654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.0002105009621202394], {
             RGBColor[
             0.9884372460256217, 0.989486518329441, 0.8412882870109101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.0002105009621202394], {
             RGBColor[
             0.9822685415159366, 0.9518497683681256, 0.3856170614047267]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.0002105009621202394], {
             RGBColor[
             0.8491719113609713, 0.8825706482344907, 0.9854759690419655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.0002105009621202394], {
             RGBColor[
             0.8322852172659485, 0.8691056567402198, 0.9838653010842525]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.0002105009621202394], {
             RGBColor[
             0.9884642142502473, 0.9894976703833755, 0.8408413537373344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.0002105009621202394], {
             RGBColor[
             0.9950774131375195, 0.991879409388059, 0.705584982582756]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.0002105009621202394], {
             RGBColor[
             0.99443612243662, 0.9905077534232709, 0.6357844473773067]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.0002105009621202394], {
             RGBColor[
             0.9865958770091503, 0.9887250649201049, 0.8718045369240984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.0002105009621202394], {
             RGBColor[
             0.9900492212284088, 0.9901531115016666, 0.814573686242629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.0002105009621202394], {
             RGBColor[
             0.9938316488379729, 0.9917172425221771, 0.7518890721432789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.0002105009621202394], {
             RGBColor[
             0.9857706293096953, 0.9883838037884818, 0.8854810269766552]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.0002105009621202394], {
             RGBColor[
             0.9872296672423319, 0.9889871534691915, 0.8613009925637346]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.0002105009621202394], {
             RGBColor[
             0.9931401487354302, 0.9877357967194664, 0.49472570782537495`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.0002105009621202394], {
             RGBColor[
             0.9854829519118623, 0.988264841791506, 0.8902485859439881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.0002105009621202394], {
             RGBColor[
             0.2528928411142352, 0.38313678871625234`, 0.9377132452287996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.0002105009621202394], {
             RGBColor[
             0.9216787013545821, 0.7271891804361847, 0.25583904855397677`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.0002105009621202394], {
             RGBColor[
             0.9939612943824716, 0.9894921442279278, 0.5841023439823171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.0002105009621202394], {
             RGBColor[
             0.994350585550062, 0.9919318361886911, 0.7432889478588012]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.0002105009621202394], {
             RGBColor[
             0.8729955719225209, 0.5161843793855168, 0.21573673085979628`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.0002105009621202394], {
             RGBColor[
             0.9943181324815801, 0.9902553848400546, 0.6229419689207928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.0002105009621202394], {
             RGBColor[
             0.864401525511105, 0.4771608218218126, 0.2085656478747567]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.0002105009621202394], {
             RGBColor[
             0.9941950329082996, 0.9918675111738018, 0.7458668576901363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.0002105009621202394], {
             RGBColor[
             0.9901254682777341, 0.9901846416160224, 0.8133100753142701]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.0002105009621202394], {
             RGBColor[
             0.9927852347550638, 0.9912845234072789, 0.769230861529921]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.0002105009621202394], {
             RGBColor[
             0.9885186158788135, 0.9895201668548457, 0.8399397779650916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.0002105009621202394], {
             RGBColor[
             0.9903648721733915, 0.9902836412792763, 0.8093425332058041]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.0002105009621202394], {
             RGBColor[
             0.984266010978971, 0.9585877018950744, 0.39337685307815873`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.0002105009621202394], {
             RGBColor[
             0.9779631593440928, 0.983085540837615, 0.9221868024886228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.0002105009621202394], {
             RGBColor[
             0.8631600337517608, 0.893724397331439, 0.9868101686429432]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.0002105009621202394], {
             RGBColor[
             0.957259637398797, 0.9676448880697193, 0.9572324647986791]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.0002105009621202394], {
             RGBColor[
             0.9104041165780514, 0.9313955465706577, 0.9913163514382055]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.0002105009621202394], {
             RGBColor[
             0.9950414988934475, 0.991802592451476, 0.7016759387525393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.0002105009621202394], {
             RGBColor[
             0.9952815235354041, 0.9923159808904074, 0.7278011397691386]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.0002105009621202394], {
             RGBColor[
             0.9887039198064792, 0.9735578104408049, 0.41061729084426724`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.0002105009621202394], {
             RGBColor[
             0.994929516455408, 0.9921712389958973, 0.7336945645320619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.0002105009621202394], {
             RGBColor[
             0.9934500176240693, 0.9915594282077531, 0.7582136889875835]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.0002105009621202394], {
             RGBColor[
             0.9943496115446381, 0.9903227153729144, 0.6263682706684061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.0002105009621202394], {
             RGBColor[
             0.9616201033293517, 0.9708969164211192, 0.9498513333699057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.0002105009621202394], {
             RGBColor[
             0.984266010978971, 0.9585877018950744, 0.39337685307815873`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.0002105009621202394], {
             RGBColor[
             0.9947000353336547, 0.9920763426546565, 0.7374976605976193]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.0002105009621202394], {
             RGBColor[
             0.9935401835764172, 0.9915967141462082, 0.7567194058151748]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.0002105009621202394], {
             RGBColor[
             0.9937986365155432, 0.9891442354978011, 0.5663980389751611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.0002105009621202394], {
             RGBColor[
             0.9350746867484675, 0.7802997985754342, 0.26661777284608795`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.0002105009621202394], {
             RGBColor[
             0.9877581834027196, 0.9892057084837577, 0.8525421120301309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.0002105009621202394], {
             RGBColor[
             0.9849191832705748, 0.9880317089701404, 0.8995916913165952]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.0002105009621202394], {
             RGBColor[
             0.9675403992333185, 0.9021682861165946, 0.3284010098130484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.0002105009621202394], {
             RGBColor[
             0.8119903270870912, 0.8530522819662713, 0.9818952653891618]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.0002105009621202394], {
             RGBColor[
             0.897825790932437, 0.6289326046645577, 0.2364556742460331]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.0002105009621202394], {
             RGBColor[
             0.8281658631823342, 0.8658209956108336, 0.9834723934143665]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.0002105009621202394], {
             RGBColor[
             0.9869665896929938, 0.9676973880235092, 0.4038680914206393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.0002105009621202394], {
             RGBColor[
             0.9893773035748878, 0.9898752562844396, 0.8257091006286167]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.0002105009621202394], {
             RGBColor[
             0.951281579268198, 0.9631864621040903, 0.9673517578865134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.0002105009621202394], {
             RGBColor[
             0.9596011376605124, 0.8753872926042535, 0.29755847780644173`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.0002105009621202394], {
             RGBColor[
             0.9641698814758806, 0.8907987382855524, 0.31530718479427267`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.0002105009621202394], {
             RGBColor[
             0.9895008684582056, 0.9899263535391642, 0.8236613107363742]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.0002105009621202394], {
             RGBColor[
             0.9919580136181299, 0.9909424462085432, 0.7829400565485936]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.0002105009621202394], {
             RGBColor[
             0.7839751360551594, 0.8311666018087884, 0.979102972963944]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.0002105009621202394], {
             RGBColor[
             0.9873052944400855, 0.989018427258993, 0.8600476541800427]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.0002105009621202394], {
             RGBColor[
             0.9909334412138681, 0.9810785096644485, 0.41927856050218343`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.0002105009621202394], {
             RGBColor[
             0.9749513580397865, 0.9808393443562353, 0.9272849964932275]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.0002105009621202394], {
             RGBColor[
             0.989116860529603, 0.9897675563921334, 0.8300253158939809]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.0002105009621202394], {
             RGBColor[
             0.957876794321398, 0.8695706776263514, 0.29085972954889916`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.0002105009621202394], {
             RGBColor[
             0.9901912486747908, 0.9902118435006845, 0.8122199239008298]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.0002105009621202394], {
             RGBColor[
             0.989673707260877, 0.9899978268258235, 0.8207969244836264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.0002105009621202394], {
             RGBColor[
             0.9830165720219606, 0.9868543677385649, 0.9136326929661053]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.0002105009621202394], {
             RGBColor[
             0.993193434661414, 0.9878497699271122, 0.5005255520260921]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.0002105009621202394], {
             RGBColor[
             0.864711481376519, 0.47856825901462574`, 0.2088242826465716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.0002105009621202394], {
             RGBColor[
             0.9924047413499983, 0.9860415505013161, 0.4249942836993324]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.0002105009621202394], {
             RGBColor[
             0.9750000679920658, 0.9273315004533677, 0.35738041430054024`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.0002105009621202394], {
             RGBColor[
             0.985550888798006, 0.9882929354398247, 0.889122695925561]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.0002105009621202394], {
             RGBColor[
             0.9949151764304989, 0.9915324014763892, 0.6879265182324653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.0002105009621202394], {
             RGBColor[
             0.9803199598899882, 0.9452767449950785, 0.37804718974668083`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.0002105009621202394], {
             RGBColor[
             0.9429312329111124, 0.9569587874634131, 0.9814867161499273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.0002105009621202394], {
             RGBColor[
             0.9461785626842951, 0.8243229665136826, 0.27555221206552183`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.0002105009621202394], {
             RGBColor[
             0.9951253492821588, 0.9919819399543547, 0.7108025360991471]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.0002105009621202394], {
             RGBColor[
             0.9949647064547469, 0.9916383411900019, 0.6933175557079766]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.0002105009621202394], {
             RGBColor[
             0.9675742665710393, 0.9022825285991559, 0.32853257802478364`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.0002105009621202394], {
             RGBColor[
             0.9018946610596486, 0.9246103377233, 0.9905047119743796]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.0002105009621202394], {
             RGBColor[
             0.8945252793056907, 0.6139457522215781, 0.2337016464417329]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.0002105009621202394], {
             RGBColor[
             0.9718940655502235, 0.9168542248929787, 0.34531418133332703`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.0002105009621202394], {
             RGBColor[
             0.9948116763281702, 0.9921225090749314, 0.7356474804008648]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.0002105009621202394], {
             RGBColor[
             0.9949750320115286, 0.9916604265118842, 0.6944414288417211]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.0002105009621202394], {
             RGBColor[
             0.8119903270870912, 0.8530522819662713, 0.9818952653891618]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.0002105009621202394], {
             RGBColor[
             0.9616201033293517, 0.9708969164211192, 0.9498513333699057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.0002105009621202394], {
             RGBColor[
             0.9930316638484796, 0.9875037585157836, 0.48291779737191565`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.0002105009621202394], {
             RGBColor[
             0.9133813357717029, 0.6942928908332422, 0.24916279344179004`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.0002105009621202394], {
             RGBColor[
             0.9794495878180762, 0.9423407756234382, 0.3746659586032766]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.0002105009621202394], {
             RGBColor[
             0.9940572475472641, 0.9896973783450658, 0.5945462538156866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.0002105009621202394], {
             RGBColor[
             0.9207038321910372, 0.9396082602221201, 0.9922987475080368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.0002105009621202394], {
             RGBColor[
             0.9932515780991339, 0.9879741328611917, 0.5068541064022021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.0002105009621202394], {
             RGBColor[
             0.9624011460010078, 0.8848323782099676, 0.3084359814720596]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.0002105009621202394], {
             RGBColor[
             0.9551721256234076, 0.8599794466400738, 0.2827886439123861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.0002105009621202394], {
             RGBColor[
             0.9948556321378403, 0.9914050422552441, 0.6814454894413615]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.0002105009621202394], {
             RGBColor[
             0.972701869020749, 0.9195791356803358, 0.34845234527543323`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.0002105009621202394], {
             RGBColor[
             0.99014102393107, 0.9901910742784389, 0.8130522778817533]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.0002105009621202394], {
             RGBColor[
             0.9856135752492453, 0.9883188578983805, 0.8880838192011903]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.0002105009621202394], {
             RGBColor[
             0.9396396942677109, 0.9545039633325642, 0.987058432502437]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.0002105009621202394], {
             RGBColor[
             0.937194146864947, 0.7887027516690593, 0.26832314020593034`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.0002105009621202394], {
             RGBColor[
             0.9561085811171652, 0.8636060792922702, 0.2839905551494998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.0002105009621202394], {
             RGBColor[
             0.9926521056871035, 0.986691921987817, 0.4416052338675804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.0002105009621202394], {
             RGBColor[
             0.9607844382046103, 0.9702736787393632, 0.9512658964497217]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.0002105009621202394], {
             RGBColor[
             0.8328185873014375, 0.8695309515285748, 0.9839161743943825]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.0002105009621202394], {
             RGBColor[
             0.9875217940773484, 0.9891079554227881, 0.8564596949074967]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.0002105009621202394], {
             RGBColor[
             0.9939140424392509, 0.989391077099283, 0.5789592615679355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.0002105009621202394], {
             RGBColor[
             0.9847573405823357, 0.9602450720169001, 0.39528557580742013`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.0002105009621202394], {
             RGBColor[
             0.9933123697464397, 0.9881041600478006, 0.51347090204888]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.0002105009621202394], {
             RGBColor[
             0.9396396942677109, 0.9545039633325642, 0.987058432502437]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.0002105009621202394], {
             RGBColor[
             0.9740746245131159, 0.9801854779275638, 0.928769077665155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.0002105009621202394], {
             RGBColor[
             0.8855636872970232, 0.5732532559432089, 0.22622387440097944`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.0002105009621202394], {
             RGBColor[
             0.846792829209846, 0.3606757668211903, 0.19244217213727746`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.0002105009621202394], {
             RGBColor[
             0.9948870409728422, 0.9914722225773926, 0.6848641472984489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.0002105009621202394], {
             RGBColor[
             0.9933086364796881, 0.9880961749677101, 0.5130645590020255]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.0002105009621202394], {
             RGBColor[
             0.9031713269809496, 0.9256283164747721, 0.9906264815096465]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.0002105009621202394], {
             RGBColor[
             0.9851330472678421, 0.9881201472290644, 0.896047411419593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.0002105009621202394], {
             RGBColor[
             0.9833525017338938, 0.9871049035676903, 0.9130640515883032]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.0002105009621202394], {
             RGBColor[
             0.9852271571178044, 0.9618298735092046, 0.3971107243303079]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.0002105009621202394], {
             RGBColor[
             0.9937230854136836, 0.9889826393303114, 0.5581747677850892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.0002105009621202394], {
             RGBColor[
             0.9435257865997853, 0.813805593323828, 0.27341772615926746`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.0002105009621202394], {
             RGBColor[
             0.9400928007853295, 0.9548418894315104, 0.986291441357215]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.0002105009621202394], {
             RGBColor[
             0.9664369629487287, 0.898446136429513, 0.3241143682138749]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.0002105009621202394], {
             RGBColor[
             0.8555595183559133, 0.4280603811855427, 0.20083716356411074`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.0002105009621202394], {
             RGBColor[
             0.9563182961185036, 0.9669428372841813, 0.9588259100450891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.0002105009621202394], {
             RGBColor[
             0.9946907128344277, 0.9910522965411437, 0.6634950410288525]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.0002105009621202394], {
             RGBColor[
             0.9703985035061528, 0.9118093429436609, 0.339504205205306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.0002105009621202394], {
             RGBColor[
             0.9501733028241847, 0.8401607800001054, 0.27876647375067953`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.0002105009621202394], {
             RGBColor[
             0.9865958770091503, 0.9887250649201049, 0.8718045369240984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.0002105009621202394], {
             RGBColor[
             0.9615734844949588, 0.8820404816059013, 0.30522067281181986`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.0002105009621202394], {
             RGBColor[
             0.8630895568219245, 0.8936682009406328, 0.98680344649046]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.0002105009621202394], {
             RGBColor[
             0.9938419326416088, 0.9892368415335454, 0.5711105551046805]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.0002105009621202394], {
             RGBColor[
             0.9742775691599832, 0.9248943422419599, 0.3545736427703552]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.0002105009621202394], {
             RGBColor[
             0.99345507840305, 0.9884093994342315, 0.5290038586251691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.0002105009621202394], {
             RGBColor[
             0.964107874405211, 0.9727522920161439, 0.945640185853089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.0002105009621202394], {
             RGBColor[
             0.9946694218207627, 0.9910067572157659, 0.6611776455843217]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.0002105009621202394], {
             RGBColor[
             0.9584084530213195, 0.8713640872605855, 0.29292512320277275`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.0002105009621202394], {
             RGBColor[
             0.993463584307073, 0.9884275927028578, 0.5299296737857209]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.0002105009621202394], {
             RGBColor[
             0.8219961704796894, 0.8609014501215917, 0.9828839226166386]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.0002105009621202394], {
             RGBColor[
             0.9746475114495754, 0.9261422444513344, 0.35601079870768115`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.0002105009621202394], {
             RGBColor[
             0.9616201033293517, 0.9708969164211192, 0.9498513333699057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.0002105009621202394], {
             RGBColor[
             0.963785886572552, 0.9725121540177535, 0.9461852272659041]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.0002105009621202394], {
             RGBColor[
             0.9802660099727561, 0.9450947592562117, 0.37783760450582105`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.0002105009621202394], {
             RGBColor[
             0.9951706351318389, 0.9920788018077187, 0.715731621364962]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.0002105009621202394], {
             RGBColor[
             0.9104041165780514, 0.9313955465706577, 0.9913163514382055]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.0002105009621202394], {
             RGBColor[
             0.9947638388217537, 0.9912087056338625, 0.6714543534680067]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.0002105009621202394], {
             RGBColor[
             0.9815878874647854, 0.98578885713508, 0.9160510832607927]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.0002105009621202394], {
             RGBColor[
             0.9600613720093623, 0.9697344171548594, 0.9524898589124097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.0002105009621202394], {
             RGBColor[
             0.9949151764304989, 0.9915324014763892, 0.6879265182324653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.0002105009621202394], {
             RGBColor[
             0.994860077593366, 0.9914145506351089, 0.6819293498411522]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.0002105009621202394], {
             RGBColor[
             0.9719845089937535, 0.9786266731954734, 0.932307098050002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.0002105009621202394], {
             RGBColor[
             0.957246112380402, 0.9676348011331455, 0.957255359126932]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.0002105009621202394], {
             RGBColor[
             0.9941675962440577, 0.9899334030495426, 0.6065570284684545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.0002105009621202394], {
             RGBColor[
             0.9465099527784347, 0.9596277908808462, 0.9754288768941785]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.0002105009621202394], {
             RGBColor[
             0.950398431519267, 0.8410533402564165, 0.2789476175831925]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.0002105009621202394], {
             RGBColor[
             0.9913741630714276, 0.9907010090032071, 0.7926159710642317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.0002105009621202394], {
             RGBColor[
             0.8728240739309844, 0.5154056470603232, 0.2155936287318578]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.0002105009621202394], {
             RGBColor[
             0.9948116763281702, 0.9921225090749314, 0.7356474804008648]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.0002105009621202394], {
             RGBColor[
             0.9865958770091503, 0.9887250649201049, 0.8718045369240984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.0002105009621202394], {
             RGBColor[
             0.9169525607471003, 0.9366170981982755, 0.9919409478889145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.0002105009621202394], {
             RGBColor[
             0.9900790157506029, 0.9901654323022782, 0.8140799139041213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.0002105009621202394], {
             RGBColor[
             0.9584084530213195, 0.8713640872605855, 0.29292512320277275`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.0002105009621202394], {
             RGBColor[
             0.8677419794183883, 0.4923290428319542, 0.2113530044970119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.0002105009621202394], {
             RGBColor[
             0.9184816911083715, 0.7145141001504705, 0.2532666590664004]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.0002105009621202394], {
             RGBColor[
             0.9822971514516589, 0.986317825055177, 0.9148504843366905]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.0002105009621202394], {
             RGBColor[
             0.8808827647214047, 0.5519982797845686, 0.2223179978639716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.0002105009621202394], {
             RGBColor[
             0.9750000679920658, 0.9273315004533677, 0.35738041430054024`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.0002105009621202394], {
             RGBColor[
             0.9087021611493437, 0.6757415226980977, 0.24539781970629504`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.0002105009621202394], {
             RGBColor[
             0.9943187047281764, 0.9902566088176613, 0.623004254431316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.0002105009621202394], {
             RGBColor[
             0.9898038969746377, 0.9900516636181865, 0.8186393440064321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.0002105009621202394], {
             RGBColor[
             0.9858985086019662, 0.9884366851621837, 0.8833617361627262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.0002105009621202394], {
             RGBColor[
             0.23032979965715525`, 0.3594216015654066, 0.9364283133968475]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.0002105009621202394], {
             RGBColor[
             0.9664872379989535, 0.9745268174885067, 0.9416125439262966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.0002105009621202394], {
             RGBColor[
             0.9396396942677109, 0.9545039633325642, 0.987058432502437]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.0002105009621202394], {
             RGBColor[
             0.9563182961185036, 0.9669428372841813, 0.9588259100450891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.0002105009621202394], {
             RGBColor[
             0.969951033888546, 0.9771101107915195, 0.9357492409878707]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.0002105009621202394], {
             RGBColor[
             0.9243727133931977, 0.9425337265035956, 0.9926486886723478]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.0002105009621202394], {
             RGBColor[
             0.9630290766615298, 0.8869505357730391, 0.3108753735134325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.0002105009621202394], {
             RGBColor[
             0.9819174026306743, 0.9860346090062683, 0.9154933000362623]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.0002105009621202394], {
             RGBColor[
             0.9916534247250217, 0.9908164908736654, 0.7879878827581832]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN2wucznW+wPHf/+zadNlSKJUyheimsIbchiJLGlM0NrNmJtWMMW5DaZZc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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[337, 399] -> 
             RGBColor[
              0.9603114409091467, 0.8681403292906987, 0.42659540071605706`], 
             UndirectedEdge[15, 92] -> 
             RGBColor[
              0.3916080301069964, 0.5102971083648917, 0.9465821312407912], 
             UndirectedEdge[87, 313] -> 
             RGBColor[
              0.2082730893529932, 0.33623860055952687`, 0.9351722163750043], 
             UndirectedEdge[35, 214] -> 
             RGBColor[
              0.23799829524204824`, 0.3674816766358314, 0.9368650228758846], 
             UndirectedEdge[105, 218] -> 
             RGBColor[
              0.20016816814604027`, 0.3277198144893344, 0.9347106531024247], 
             UndirectedEdge[149, 316] -> 
             RGBColor[
              0.2254786330368893, 0.3543227178657783, 0.9361520466344813], 
             UndirectedEdge[160, 348] -> 
             RGBColor[
              0.39638156393997953`, 0.5175763121944144, 0.946525366087156], 
             UndirectedEdge[17, 287] -> 
             RGBColor[
              0.2108043778715786, 0.3388991452855218, 0.9353163695114319], 
             UndirectedEdge[268, 295] -> 
             RGBColor[
              0.5541988760682194, 0.6477364431214906, 0.9586174510059542], 
             UndirectedEdge[277, 379] -> 
             RGBColor[
              0.2074585735841274, 0.33538249284316635`, 0.9351258309069355], 
             UndirectedEdge[10, 37] -> 
             RGBColor[
              0.29314980125126083`, 0.4217462676405007, 0.9401414095988625], 
             UndirectedEdge[118, 389] -> 
             RGBColor[
              0.22076497088432706`, 0.3493683600799934, 0.9358836105481312], 
             UndirectedEdge[127, 313] -> 
             RGBColor[
              0.20658568658737522`, 0.3344650332653477, 0.935076121283791], 
             UndirectedEdge[92, 281] -> 
             RGBColor[
              0.46303919301965735`, 0.5742863383640635, 0.9510560694278913], 
             UndirectedEdge[2, 193] -> 
             RGBColor[
              0.18596534003799042`, 0.3127917416364609, 0.9339018230528726], 
             UndirectedEdge[265, 378] -> 
             RGBColor[
              0.19040066183963522`, 0.31745354606563403`, 0.9341544080680056],
              UndirectedEdge[108, 367] -> 
             RGBColor[
              0.31561783688898226`, 0.44293150514134, 0.9415099085808494], 
             UndirectedEdge[26, 342] -> 
             RGBColor[
              0.18535691671142462`, 0.3121522501439733, 0.9338671742445064], 
             UndirectedEdge[57, 144] -> 
             RGBColor[
              0.20411547873617336`, 0.33186868819351084`, 0.93493544660101], 
             UndirectedEdge[341, 348] -> 
             RGBColor[
              0.33468734849454873`, 0.4643110922158917, 0.9425469597870388], 
             UndirectedEdge[232, 309] -> 
             RGBColor[
              0.2963446868922668, 0.42880743363510754`, 0.9401877635646132], 
             UndirectedEdge[23, 202] -> 
             RGBColor[
              0.2682077809117381, 0.39923376146669465`, 0.9385854083938443], 
             UndirectedEdge[89, 170] -> 
             RGBColor[
              0.21045471282523004`, 0.33853162515176505`, 0.9352964566043255],
              UndirectedEdge[291, 383] -> 
             RGBColor[
              0.1977645203288262, 0.3251934282333686, 0.9345737689151127], 
             UndirectedEdge[45, 140] -> 
             RGBColor[
              0.25525427585226035`, 0.38561880634952683`, 0.9378477254437005],
              UndirectedEdge[213, 308] -> 
             RGBColor[
              0.2120594900785835, 0.3402183477937941, 0.9353878462948488], 
             UndirectedEdge[165, 386] -> 
             RGBColor[
              0.8287550787424094, 0.8667695006906301, 0.9834015662110343], 
             UndirectedEdge[347, 381] -> 
             RGBColor[
              0.1970073353004369, 0.3243975787602278, 0.9345306483479008], 
             UndirectedEdge[216, 396] -> 
             RGBColor[
              0.19963425463605258`, 0.3271586375382656, 0.9346802475178853], 
             UndirectedEdge[39, 150] -> 
             RGBColor[
              0.1883607596919023, 0.31530947957110045`, 0.9340382386584571], 
             UndirectedEdge[20, 378] -> 
             RGBColor[
              0.19055340614426983`, 0.31761409001435326`, 0.9341631066301896],
              UndirectedEdge[363, 372] -> 
             RGBColor[
              0.20698461099735616`, 0.3348843281135061, 0.9350988394387836], 
             UndirectedEdge[54, 318] -> 
             RGBColor[
              0.18950140793350456`, 0.31650837319430003`, 0.9341031968883784],
              UndirectedEdge[40, 246] -> 
             RGBColor[
              0.7206526383610699, 0.7806508133791874, 0.9738469548784772], 
             UndirectedEdge[59, 178] -> 
             RGBColor[
              0.3941011919373124, 0.5157723771794137, 0.9463327573536129], 
             UndirectedEdge[172, 357] -> 
             RGBColor[
              0.8404518577056951, 0.3119362812088553, 0.18637005066379952`], 
             UndirectedEdge[268, 274] -> 
             RGBColor[
              0.5862206904488971, 0.6743925388404906, 0.9609561467561663], 
             UndirectedEdge[122, 175] -> 
             RGBColor[
              0.4398070896700592, 0.5489279977942612, 0.9504219852000314], 
             UndirectedEdge[120, 341] -> 
             RGBColor[
              0.42726711236099996`, 0.542734639248357, 0.9489335670306169], 
             UndirectedEdge[220, 366] -> 
             RGBColor[
              0.5151109603637722, 0.615629530907049, 0.9554125916387102], 
             UndirectedEdge[202, 366] -> 
             RGBColor[
              0.31887937893336776`, 0.4445735814559359, 0.9417610431931018], 
             UndirectedEdge[17, 61] -> 
             RGBColor[
              0.22052046256389546`, 0.34911136633249684`, 0.9358696861610002],
              UndirectedEdge[112, 279] -> 
             RGBColor[
              0.8046710367643358, 0.7661172165820809, 0.618109700945247], 
             UndirectedEdge[129, 313] -> 
             RGBColor[
              0.203727765298821, 0.33146117678840176`, 0.9349133668943235], 
             UndirectedEdge[204, 318] -> 
             RGBColor[
              0.1940125074344074, 0.321249824789977, 0.9343600973313813], 
             UndirectedEdge[60, 335] -> 
             RGBColor[
              0.18275395419094043`, 0.3094163714975885, 0.9337189393797027], 
             UndirectedEdge[256, 386] -> 
             RGBColor[
              0.556034698630532, 0.6458694921919914, 0.9601976146247932], 
             UndirectedEdge[7, 65] -> 
             RGBColor[
              0.36829577629683624`, 0.4914979419428903, 0.9447588725119885], 
             UndirectedEdge[66, 280] -> 
             RGBColor[
              0.23290342941472336`, 0.362126649618162, 0.936574877804197], 
             UndirectedEdge[147, 344] -> 
             RGBColor[
              0.1873628349672718, 0.31426059741343176`, 0.9339814083216866], 
             UndirectedEdge[329, 349] -> 
             RGBColor[
              0.19621450085245074`, 0.32356425948678696`, 0.9344854975989814],
              UndirectedEdge[170, 306] -> 
             RGBColor[
              0.21718838977102684`, 0.3456091465615747, 0.9356799295448063], 
             UndirectedEdge[175, 178] -> 
             RGBColor[
              0.3616708025324146, 0.48517771913218966`, 0.9443580450417194], 
             UndirectedEdge[115, 166] -> 
             RGBColor[
              0.92715146758626, 0.7340525782000142, 0.5145919024804202], 
             UndirectedEdge[361, 396] -> 
             RGBColor[
              0.20859692759923504`, 0.3365789750888577, 0.935190658484052], 
             UndirectedEdge[80, 265] -> 
             RGBColor[
              0.18489536415726843`, 0.31166712914543293`, 0.933840889509353], 
             UndirectedEdge[18, 288] -> 
             RGBColor[
              0.45525573629442806`, 0.5643070139273578, 0.9513799079587884], 
             UndirectedEdge[225, 240] -> 
             RGBColor[
              0.8581995989845774, 0.5777442515282645, 0.5834221523927036], 
             UndirectedEdge[110, 251] -> 
             RGBColor[
              0.18685400772656674`, 0.3137257877219404, 0.9339524313630709], 
             UndirectedEdge[56, 169] -> 
             RGBColor[
              0.6387195548301612, 0.7123648726900207, 0.967730862260616], 
             UndirectedEdge[87, 231] -> 
             RGBColor[
              0.19018595982878306`, 0.3172278806393347, 0.9341421811061108], 
             UndirectedEdge[266, 315] -> 
             RGBColor[
              0.22579916171770553`, 0.3546596138320083, 0.9361703002686741], 
             UndirectedEdge[31, 292] -> 
             RGBColor[
              0.19543097961487327`, 0.32274072898797734`, 0.9344408772236172],
              UndirectedEdge[1, 87] -> 
             RGBColor[
              0.19586287681444192`, 0.32319468032858806`, 0.934465473130198], 
             UndirectedEdge[231, 336] -> 
             RGBColor[
              0.1812731232878139, 0.3078599243283004, 0.9336346082504626], 
             UndirectedEdge[13, 309] -> 
             RGBColor[
              0.25587961899129924`, 0.38627608163770166`, 0.9378833378103566],
              UndirectedEdge[237, 296] -> 
             RGBColor[
              0.2211466738327187, 0.34976955408011773`, 0.935905347966363], 
             UndirectedEdge[95, 312] -> 
             RGBColor[
              0.43115946169626646`, 0.5444500738116986, 0.9495097680739197], 
             UndirectedEdge[108, 236] -> 
             RGBColor[
              0.2534644343240474, 0.3837375694208677, 0.9377457966165021], 
             UndirectedEdge[48, 176] -> 
             RGBColor[
              0.2369284794639835, 0.36635723242284735`, 0.9368040984499744], 
             UndirectedEdge[49, 52] -> 
             RGBColor[
              0.1835216269875808, 0.31022324428012404`, 0.9337626572098012], 
             UndirectedEdge[310, 390] -> 
             RGBColor[
              0.27115500533733905`, 0.4023314812028227, 0.9387532484648545], 
             UndirectedEdge[343, 358] -> 
             RGBColor[
              0.18639835798283702`, 0.3132468709514181, 0.933926482784239], 
             UndirectedEdge[271, 374] -> 
             RGBColor[
              0.184659451088446, 0.3114191695523481, 0.9338274546090857], 
             UndirectedEdge[57, 167] -> 
             RGBColor[
              0.2639676028821611, 0.3946376054360735, 0.9383490428444853], 
             UndirectedEdge[34, 214] -> 
             RGBColor[
              0.25149658822823806`, 0.38166923840552336`, 0.9376337306925131],
              UndirectedEdge[83, 220] -> 
             RGBColor[
              0.790428504618827, 0.8368778917698232, 0.9711999364788909], 
             UndirectedEdge[9, 347] -> 
             RGBColor[
              0.19444294915612814`, 0.3217022463310869, 0.9343846103506517], 
             UndirectedEdge[188, 238] -> 
             RGBColor[
              0.2458833929201038, 0.375769414239536, 0.9373140675236933], 
             UndirectedEdge[79, 137] -> 
             RGBColor[
              0.2827537056275888, 0.4121446936308188, 0.939500838618308], 
             UndirectedEdge[115, 197] -> 
             RGBColor[
              0.914459777232721, 0.7255013666531043, 0.5770167261447392], 
             UndirectedEdge[67, 194] -> 
             RGBColor[
              0.709877099853931, 0.7667201163798876, 0.7972498678529694], 
             UndirectedEdge[75, 260] -> 
             RGBColor[
              0.22127423884363956`, 0.34990363299468435`, 0.9359126126050195],
              UndirectedEdge[32, 387] -> 
             RGBColor[
              0.7455791435710649, 0.7496942133696903, 0.622023162461701], 
             UndirectedEdge[76, 144] -> 
             RGBColor[
              0.19222334020881804`, 0.31936929659612845`, 0.9342582069047196],
              UndirectedEdge[50, 164] -> 
             RGBColor[
              0.18999442899880858`, 0.3170265695932755, 0.9341312737086882], 
             UndirectedEdge[279, 285] -> 
             RGBColor[
              0.8332166202434534, 0.8669371947579207, 0.788972494773293], 
             UndirectedEdge[137, 352] -> 
             RGBColor[
              0.28703295098175935`, 0.4166424518178782, 0.9397445353106518], 
             UndirectedEdge[4, 275] -> 
             RGBColor[
              0.235784586016354, 0.3651549278823552, 0.9367389554103707], 
             UndirectedEdge[8, 373] -> 
             RGBColor[
              0.2548317087924608, 0.38517466157737845`, 0.937823660874777], 
             UndirectedEdge[41, 135] -> 
             RGBColor[
              0.9333566323648748, 0.9460233638065111, 0.83381543555314], 
             UndirectedEdge[85, 211] -> 
             RGBColor[
              0.231317411938528, 0.36045964469136466`, 0.9364845564552302], 
             UndirectedEdge[63, 139] -> 
             RGBColor[
              0.18462055320460163`, 0.31137828541015944`, 0.9338252394321449],
              UndirectedEdge[55, 92] -> 
             RGBColor[
              0.7345108890138425, 0.7594054710903482, 0.6489345144638174], 
             UndirectedEdge[31, 371] -> 
             RGBColor[
              0.1915120199175549, 0.31862165386969954`, 0.9342176982664363], 
             UndirectedEdge[99, 169] -> 
             RGBColor[
              0.9307128082989145, 0.9468171296861931, 0.9664871194315787], 
             UndirectedEdge[71, 72] -> 
             RGBColor[
              0.18087056047954858`, 0.30743680529285733`, 0.9336116828940703],
              UndirectedEdge[104, 112] -> 
             RGBColor[
              0.8780584972468868, 0.4677393624570944, 0.21704509236247566`], 
             UndirectedEdge[389, 390] -> 
             RGBColor[
              0.23267978688900162`, 0.3618915871438733, 0.9365621416932066], 
             UndirectedEdge[260, 349] -> 
             RGBColor[
              0.21328372600725728`, 0.3415050973758713, 0.9354575647198919], 
             UndirectedEdge[70, 284] -> 
             RGBColor[
              0.24975725951810934`, 0.3798410936513683, 0.9375346784955776], 
             UndirectedEdge[24, 172] -> 
             RGBColor[
              0.8222950385758708, 0.17237501300815056`, 0.16898306015988562`],
              UndirectedEdge[343, 362] -> 
             RGBColor[
              0.18559297832352872`, 0.3124003658654654, 0.9338806176040938], 
             UndirectedEdge[233, 307] -> 
             RGBColor[
              0.6538804302709667, 0.7226974017073509, 0.9485082265240019], 
             UndirectedEdge[79, 278] -> 
             RGBColor[
              0.24460490622546205`, 0.37442564366272924`, 0.937241259597785], 
             UndirectedEdge[1, 216] -> 
             RGBColor[
              0.19662871859939152`, 0.3239996286017438, 0.9345090866868895], 
             UndirectedEdge[192, 374] -> 
             RGBColor[
              0.18592011737534742`, 0.3127442097507407, 0.933899247689136], 
             UndirectedEdge[152, 383] -> 
             RGBColor[
              0.2325615956471479, 0.3617673606549275, 0.9365554108768314], 
             UndirectedEdge[43, 121] -> 
             RGBColor[
              0.28563299292961386`, 0.4173490407437973, 0.9395850612911336], 
             UndirectedEdge[13, 280] -> 
             RGBColor[
              0.23284937828008462`, 0.36206983844861684`, 0.9365717996720409],
              UndirectedEdge[246, 272] -> 
             RGBColor[
              0.8305893181173114, 0.8683923303180165, 0.9835339903359117], 
             UndirectedEdge[385, 387] -> 
             RGBColor[
              0.7642756795140044, 0.8115756260652711, 0.7955379877927361], 
             UndirectedEdge[90, 268] -> 
             RGBColor[
              0.6438707815800897, 0.7211954799278018, 0.9654945731092558], 
             UndirectedEdge[195, 363] -> 
             RGBColor[
              0.21087458530257291`, 0.33897293774690507`, 0.9353203677207644],
              UndirectedEdge[88, 109] -> 
             RGBColor[
              0.18639597403767888`, 0.31324436527390603`, 0.9339263470220889],
              UndirectedEdge[63, 318] -> 
             RGBColor[
              0.18778593589765713`, 0.3147053033174152, 0.9340055032937504], 
             UndirectedEdge[257, 276] -> 
             RGBColor[
              0.27298076036949565`, 0.4029229337235066, 0.9389058299544288], 
             UndirectedEdge[16, 106] -> 
             RGBColor[
              0.2722971064429795, 0.4026970623499158, 0.9388488569979281], 
             UndirectedEdge[100, 227] -> 
             RGBColor[
              0.20880854883445307`, 0.33680140242463313`, 0.9352027100003322],
              UndirectedEdge[195, 359] -> 
             RGBColor[
              0.19452611281546262`, 0.321789656609928, 0.9343893463980213], 
             UndirectedEdge[216, 313] -> 
             RGBColor[
              0.2090389311379428, 0.3370435488326826, 0.9352158299316957], 
             UndirectedEdge[12, 47] -> 
             RGBColor[
              0.4262898849714413, 0.5411626092696967, 0.9490658048705467], 
             UndirectedEdge[386, 400] -> 
             RGBColor[
              0.8054695470793142, 0.5998653041518983, 0.5862367210785956], 
             UndirectedEdge[180, 262] -> 
             RGBColor[
              0.23634740435871976`, 0.36574648564492557`, 0.9367710070823533],
              UndirectedEdge[247, 359] -> 
             RGBColor[
              0.1924159607622266, 0.31957175301060936`, 0.9342691763602797], 
             UndirectedEdge[74, 141] -> 
             RGBColor[
              0.8643287930251963, 0.6881181472098445, 0.5981821297581387], 
             UndirectedEdge[170, 171] -> 
             RGBColor[
              0.21031358554217228`, 0.3383832914292848, 0.9352884196143345], 
             UndirectedEdge[207, 333] -> 
             RGBColor[
              0.18793493502051017`, 0.3148619108426237, 0.9340139885733725], 
             UndirectedEdge[311, 313] -> 
             RGBColor[
              0.2605556138292256, 0.39119084868755866`, 0.938149628798862], 
             UndirectedEdge[161, 195] -> 
             RGBColor[
              0.20065168741435874`, 0.3282280238972294, 0.9347381888094528], 
             UndirectedEdge[87, 129] -> 
             RGBColor[
              0.1936336407966272, 0.32085161193213774`, 0.9343385214368426], 
             UndirectedEdge[198, 367] -> 
             RGBColor[
              0.36419518981338295`, 0.4898693012590379, 0.9444271733431154], 
             UndirectedEdge[322, 330] -> 
             RGBColor[
              0.19291768102176954`, 0.3200990928142907, 0.934297748586832], 
             UndirectedEdge[79, 314] -> 
             RGBColor[
              0.23185910927542647`, 0.36102900293803986`, 0.9365154053171973],
              UndirectedEdge[56, 274] -> 
             RGBColor[
              0.43736444745775693`, 0.5521652442024196, 0.9493877477928349], 
             UndirectedEdge[249, 316] -> 
             RGBColor[
              0.271715102066897, 0.4028896300992718, 0.9387862636671344], 
             UndirectedEdge[69, 294] -> 
             RGBColor[
              0.2158880199071448, 0.3442423753864234, 0.935605875404783], 
             UndirectedEdge[6, 300] -> 
             RGBColor[
              0.6101439916355338, 0.6866719134983721, 0.9662201158700239], 
             UndirectedEdge[36, 265] -> 
             RGBColor[
              0.1914303121066489, 0.318535773779863, 0.934213045127481], 
             UndirectedEdge[167, 395] -> 
             RGBColor[
              0.389446651029121, 0.5113248488468087, 0.9461511158699245], 
             UndirectedEdge[261, 306] -> 
             RGBColor[
              0.2313412040252819, 0.36048465168304844`, 0.9364859113793738], 
             UndirectedEdge[35, 211] -> 
             RGBColor[
              0.22907054143597805`, 0.35809804133336665`, 0.9363566005040571],
              UndirectedEdge[54, 63] -> 
             RGBColor[
              0.18289690010848875`, 0.3095666167202264, 0.9337270799382376], 
             UndirectedEdge[302, 314] -> 
             RGBColor[
              0.21202470254257239`, 0.3401817838877893, 0.9353858651961364], 
             UndirectedEdge[54, 224] -> 
             RGBColor[
              0.18197335735342035`, 0.3085959147286568, 0.9336744855445955], 
             UndirectedEdge[164, 389] -> 
             RGBColor[
              0.20180063292388895`, 0.3294356384750984, 0.934803619556508], 
             UndirectedEdge[113, 210] -> 
             RGBColor[
              0.3065896783902691, 0.43957556926948627`, 0.9407712006743179], 
             UndirectedEdge[307, 348] -> 
             RGBColor[
              0.3407470767330234, 0.4695597242452613, 0.9429330803119872], 
             UndirectedEdge[18, 74] -> 
             RGBColor[
              0.7341001698400949, 0.7919819236306536, 0.974429319456183], 
             UndirectedEdge[41, 328] -> 
             RGBColor[
              0.8707008812978143, 0.7005608755905404, 0.6002433163697872], 
             UndirectedEdge[63, 290] -> 
             RGBColor[
              0.18969933550436535`, 0.3167164076206075, 0.9341144685707314], 
             UndirectedEdge[45, 288] -> 
             RGBColor[
              0.29509029119202934`, 0.4274889842208769, 0.9401163275851969], 
             UndirectedEdge[249, 315] -> 
             RGBColor[
              0.2639611950336743, 0.39473978218125394`, 0.9383446901324698], 
             UndirectedEdge[306, 342] -> 
             RGBColor[
              0.1932134040418383, 0.3204099164583054, 0.934314589575342], 
             UndirectedEdge[163, 395] -> 
             RGBColor[
              0.36771682090515007`, 0.4886248797144314, 0.9449085278741232], 
             UndirectedEdge[378, 379] -> 
             RGBColor[
              0.19896021464386793`, 0.3264501787698757, 0.934641861937483], 
             UndirectedEdge[216, 235] -> 
             RGBColor[
              0.1956123156574894, 0.32293132466613605`, 0.9344512040429815], 
             UndirectedEdge[220, 321] -> 
             RGBColor[
              0.5950920301278422, 0.6821615445050555, 0.961266970987048], 
             UndirectedEdge[133, 199] -> 
             RGBColor[
              0.18613849661309062`, 0.31297374017565216`, 0.9339116840636623],
              UndirectedEdge[317, 396] -> 
             RGBColor[
              0.19745595153076353`, 0.32486910286221293`, 0.9345561963785496],
              UndirectedEdge[177, 197] -> 
             RGBColor[
              0.9295820155952076, 0.9459496447868232, 0.9675642537426303], 
             UndirectedEdge[208, 242] -> 
             RGBColor[
              0.9226443508532682, 0.6970908441139261, 0.4815544446680411], 
             UndirectedEdge[51, 163] -> 
             RGBColor[
              0.3241863421441664, 0.4513369658591039, 0.9420198625128315], 
             UndirectedEdge[188, 228] -> 
             RGBColor[
              0.20268995802939208`, 0.3303703755474506, 0.9348542653056278], 
             UndirectedEdge[95, 125] -> 
             RGBColor[
              0.41046090544111513`, 0.5226945788232695, 0.9483310159159588], 
             UndirectedEdge[66, 203] -> 
             RGBColor[
              0.2200139191384291, 0.3485789570756236, 0.9358408392622837], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.2667189772067604, 0.39766893437715617`, 0.9385006232253336], 
             UndirectedEdge[151, 265] -> 
             RGBColor[
              0.1910010224377346, 0.31808456311929695`, 0.9341885977159134], 
             UndirectedEdge[76, 333] -> 
             RGBColor[
              0.19100459551754329`, 0.3180883186527222, 0.9341888011975227], 
             UndirectedEdge[119, 336] -> 
             RGBColor[
              0.18138462902211405`, 0.30797712392492177`, 0.9336409583370731],
              UndirectedEdge[183, 395] -> 
             RGBColor[
              0.40931291362813915`, 0.5285320070026871, 0.9474169765556877], 
             UndirectedEdge[42, 204] -> 
             RGBColor[
              0.20507426806755127`, 0.33287643657154375`, 0.9349900482350304],
              UndirectedEdge[12, 107] -> 
             RGBColor[
              0.3285473986430889, 0.45896802364421685`, 0.9421566412492507], 
             UndirectedEdge[234, 239] -> 
             RGBColor[
              0.8067428279900561, 0.5234676801505931, 0.5767481319037369], 
             UndirectedEdge[164, 287] -> 
             RGBColor[
              0.19544251078166353`, 0.3227528489753921, 0.9344415339065071], 
             UndirectedEdge[32, 194] -> 
             RGBColor[
              0.9757819569708761, 0.9287169668940988, 0.4668813870087187], 
             UndirectedEdge[6, 169] -> 
             RGBColor[
              0.6006886092479335, 0.6791324482420171, 0.965318253056975], 
             UndirectedEdge[24, 240] -> 
             RGBColor[
              0.8262378872131442, 0.20268147540152273`, 0.17275873646774914`],
              UndirectedEdge[9, 381] -> 
             RGBColor[
              0.19359903145009902`, 0.3208152353145773, 0.9343365504857577], 
             UndirectedEdge[43, 90] -> 
             RGBColor[
              0.434369237561579, 0.5419666394359329, 0.9502257108546233], 
             UndirectedEdge[88, 157] -> 
             RGBColor[
              0.189431793006949, 0.31643520349264886`, 0.9340992324212971], 
             UndirectedEdge[100, 314] -> 
             RGBColor[
              0.22141089937149833`, 0.35004727187424184`, 0.93592039521991], 
             UndirectedEdge[56, 296] -> 
             RGBColor[
              0.313305483869233, 0.43989379597440015`, 0.9414004589756761], 
             UndirectedEdge[49, 235] -> 
             RGBColor[
              0.18959591922153213`, 0.31660771055037873`, 0.9341085791664148],
              UndirectedEdge[359, 362] -> 
             RGBColor[
              0.18818450229900258`, 0.31512422187579864`, 0.9340282010606809],
              UndirectedEdge[104, 285] -> 
             RGBColor[
              0.9066040807260044, 0.5685593406329343, 0.38790788619052163`], 
             UndirectedEdge[80, 168] -> 
             RGBColor[
              0.18200651498987047`, 0.3086307655068815, 0.933676373822939], 
             UndirectedEdge[311, 386] -> 
             RGBColor[
              0.5317523136158948, 0.6242823861276408, 0.958670681032904], 
             UndirectedEdge[61, 173] -> 
             RGBColor[
              0.24592220228648118`, 0.3758102053442546, 0.937316277659695], 
             UndirectedEdge[118, 354] -> 
             RGBColor[
              0.22736699671866945`, 0.3563075078245018, 0.9362595861525749], 
             UndirectedEdge[154, 180] -> 
             RGBColor[
              0.2320279298273124, 0.36120644404191316`, 0.9365250193978796], 
             UndirectedEdge[17, 158] -> 
             RGBColor[
              0.2852162427380673, 0.4143360909345327, 0.9396556083799944], 
             UndirectedEdge[8, 237] -> 
             RGBColor[
              0.2175725261235523, 0.3460128982237305, 0.9357018055418038], 
             UndirectedEdge[55, 255] -> 
             RGBColor[
              0.9034963603733146, 0.5943883495886708, 0.2628944512543936], 
             UndirectedEdge[93, 214] -> 
             RGBColor[
              0.23703264551730702`, 0.36646671754939963`, 0.9368100305526114],
              UndirectedEdge[129, 235] -> 
             RGBColor[
              0.1903011498183676, 0.3173489526218552, 0.9341487410056093], 
             UndirectedEdge[47, 158] -> 
             RGBColor[
              0.44142989596913074`, 0.5543010784500094, 0.9500295993461311], 
             UndirectedEdge[106, 347] -> 
             RGBColor[
              0.21233497992474068`, 0.3405079050891704, 0.9354035350340366], 
             UndirectedEdge[169, 178] -> 
             RGBColor[
              0.668739474081812, 0.7383666179007873, 0.9696437049697588], 
             UndirectedEdge[230, 385] -> 
             RGBColor[
              0.9060818174117249, 0.56391734784212, 0.3996140043462989], 
             UndirectedEdge[304, 383] -> 
             RGBColor[
              0.1946222087294852, 0.32189065950839857`, 0.9343948189181637], 
             UndirectedEdge[100, 352] -> 
             RGBColor[
              0.2248749641652065, 0.3536882236068225, 0.936117668585287], 
             UndirectedEdge[87, 216] -> 
             RGBColor[
              0.198944806635749, 0.32643398397641854`, 0.9346409844742148], 
             UndirectedEdge[79, 277] -> 
             RGBColor[
              0.21942962029019444`, 0.3479648219394422, 0.9358075643072694], 
             UndirectedEdge[217, 220] -> 
             RGBColor[
              0.8144460532518553, 0.851406632354037, 0.7257595325601884], 
             UndirectedEdge[78, 104] -> 
             RGBColor[
              0.819473350823259, 0.1506862844701191, 0.16628100878134408`], 
             UndirectedEdge[170, 353] -> 
             RGBColor[
              0.2108426436010009, 0.33893936499333205`, 0.9353185486881135], 
             UndirectedEdge[78, 385] -> 
             RGBColor[
              0.9071814483660026, 0.5723695932180546, 0.4006670121899707], 
             UndirectedEdge[40, 102] -> 
             RGBColor[
              0.39926565859510593`, 0.5155146756656562, 0.9472759248895897], 
             UndirectedEdge[41, 256] -> 
             RGBColor[
              0.6115898950741928, 0.6896890172445088, 0.9656235459657501], 
             UndirectedEdge[120, 217] -> 
             RGBColor[
              0.7556843813439534, 0.80370125991605, 0.7211335984965017], 
             UndirectedEdge[210, 315] -> 
             RGBColor[
              0.26224986664151034`, 0.39297161581510254`, 0.9382461139900993],
              UndirectedEdge[83, 187] -> 
             RGBColor[
              0.6899774075909928, 0.7548276258988081, 0.9634300825559947], 
             UndirectedEdge[2, 305] -> 
             RGBColor[
              0.18360947068078184`, 0.31031557357129014`, 0.9337676597781759],
              UndirectedEdge[121, 175] -> 
             RGBColor[
              0.29627876905743955`, 0.4285384264353338, 0.9401913224925988], 
             UndirectedEdge[36, 151] -> 
             RGBColor[
              0.19244860485001886`, 0.3196060640166337, 0.9342710353927868], 
             UndirectedEdge[70, 332] -> 
             RGBColor[
              0.22563024765380635`, 0.35448207444108004`, 0.936160680862621], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.1986384662361157, 0.32611200079330077`, 0.9346235388416457], 
             UndirectedEdge[221, 400] -> 
             RGBColor[
              0.8762434284382803, 0.5179931725974458, 0.21794016454172604`], 
             UndirectedEdge[49, 216] -> 
             RGBColor[
              0.19369425198474133`, 0.320915318133817, 0.9343419731543394], 
             UndirectedEdge[75, 349] -> 
             RGBColor[
              0.2099761655665867, 0.3380286416412822, 0.935269204045893], 
             UndirectedEdge[62, 87] -> 
             RGBColor[
              0.1996423811721627, 0.3271671790429695, 0.9346807103120945], 
             UndirectedEdge[38, 189] -> 
             RGBColor[
              0.24478652953490182`, 0.3746165412765333, 0.9372516027765698], 
             UndirectedEdge[49, 361] -> 
             RGBColor[
              0.2026569249479238, 0.33033565568440915`, 0.9348523841205063], 
             UndirectedEdge[107, 270] -> 
             RGBColor[
              0.35385896317997434`, 0.4809165812630355, 0.943768558122001], 
             UndirectedEdge[5, 8] -> 
             RGBColor[
              0.2601258969540067, 0.39073918900607996`, 0.9381251570585274], 
             UndirectedEdge[162, 340] -> 
             RGBColor[
              0.23763180163327896`, 0.367096468615978, 0.9368441516070439], 
             UndirectedEdge[34, 85] -> 
             RGBColor[
              0.25199669770088307`, 0.3821948851700452, 0.9376622111871347], 
             UndirectedEdge[21, 172] -> 
             RGBColor[
              0.8935026650840421, 0.5357509007293852, 0.24098742713821833`], 
             UndirectedEdge[298, 393] -> 
             RGBColor[
              0.19018046268844432`, 0.31722210279629987`, 0.9341418680521008],
              UndirectedEdge[164, 371] -> 
             RGBColor[
              0.1937500929349124, 0.3209740105129675, 0.9343451532138425], 
             UndirectedEdge[11, 85] -> 
             RGBColor[
              0.2763549775912347, 0.40749939278433556`, 0.9390602753814483], 
             UndirectedEdge[202, 307] -> 
             RGBColor[
              0.295856931076972, 0.42463269426460054`, 0.9402940731736436], 
             UndirectedEdge[20, 265] -> 
             RGBColor[
              0.19013547399899927`, 0.31717481683124543`, 0.9341393060127917],
              UndirectedEdge[195, 247] -> 
             RGBColor[
              0.1997381438211963, 0.32726783165880646`, 0.9346861638532888], 
             UndirectedEdge[281, 355] -> 
             RGBColor[
              0.5971975343016019, 0.6813125874620714, 0.9629093916561169], 
             UndirectedEdge[298, 313] -> 
             RGBColor[
              0.20768244341745035`, 0.33561779423215604`, 0.9351385799627575],
              UndirectedEdge[67, 210] -> 
             RGBColor[
              0.365438140563206, 0.4906599829992886, 0.9445168412553058], 
             UndirectedEdge[11, 263] -> 
             RGBColor[
              0.35195866140263943`, 0.47927063537545245`, 0.9436474725731201],
              UndirectedEdge[88, 181] -> 
             RGBColor[
              0.19319654196954522`, 0.3203921933512083, 0.9343136293052701], 
             UndirectedEdge[212, 390] -> 
             RGBColor[
              0.3400236714682391, 0.46467688938800766`, 0.9430428280078589], 
             UndirectedEdge[13, 203] -> 
             RGBColor[
              0.21995986800379036`, 0.3485221459060784, 0.9358377611301275], 
             UndirectedEdge[75, 105] -> 
             RGBColor[
              0.21372122175088312`, 0.34196493314125437`, 0.9354824794552745],
              UndirectedEdge[12, 270] -> 
             RGBColor[
              0.3337876806083378, 0.46350689249828564`, 0.9424905473822769], 
             UndirectedEdge[127, 393] -> 
             RGBColor[
              0.1890837058583692, 0.31606934182949153`, 0.9340794093731344], 
             UndirectedEdge[185, 208] -> 
             RGBColor[
              0.6963078073762952, 0.755957556681333, 0.8560508247348155], 
             UndirectedEdge[246, 355] -> 
             RGBColor[
              0.8429762449225704, 0.8780690916824152, 0.9847686034374477], 
             UndirectedEdge[62, 336] -> 
             RGBColor[
              0.19072954463119351`, 0.31779922273193517`, 0.9341731374564464],
              UndirectedEdge[118, 209] -> 
             RGBColor[
              0.2868618960178613, 0.41642761918472027`, 0.9397360770801573], 
             UndirectedEdge[178, 352] -> 
             RGBColor[
              0.3406463330534576, 0.4630796686814488, 0.9431607326078082], 
             UndirectedEdge[17, 22] -> 
             RGBColor[
              0.2739758563683775, 0.40460023321935323`, 0.9389393809000012], 
             UndirectedEdge[12, 158] -> 
             RGBColor[
              0.32361612706914167`, 0.45469680405977975`, 0.941842424985111], 
             UndirectedEdge[200, 333] -> 
             RGBColor[
              0.18616349406283006`, 0.3130000140802582, 0.9339131076314446], 
             UndirectedEdge[69, 295] -> 
             RGBColor[
              0.3354255676488553, 0.4587623903805083, 0.9428205754850394], 
             UndirectedEdge[181, 340] -> 
             RGBColor[
              0.19892920598511726`, 0.3264175867034662, 0.9346400960402405], 
             UndirectedEdge[205, 284] -> 
             RGBColor[
              0.313308210862673, 0.4428213204414291, 0.9412935282095445], 
             UndirectedEdge[283, 373] -> 
             RGBColor[
              0.2404157449182508, 0.3700225695206825, 0.937002693058648], 
             UndirectedEdge[302, 379] -> 
             RGBColor[
              0.199238475276043, 0.32674264833703476`, 0.9346577084688357], 
             UndirectedEdge[254, 303] -> 
             RGBColor[
              0.20024144683233963`, 0.3277968350347721, 0.9347148262152034], 
             UndirectedEdge[38, 254] -> 
             RGBColor[
              0.20508861754811766`, 0.3328915187854286, 0.9349908654167205], 
             UndirectedEdge[158, 209] -> 
             RGBColor[
              0.336799320476102, 0.4661403761955148, 0.94268153277416], 
             UndirectedEdge[365, 370] -> 
             RGBColor[
              0.18400910577117147`, 0.3107356153896179, 0.9337904184053665], 
             UndirectedEdge[61, 164] -> 
             RGBColor[
              0.2051585954739804, 0.3329650700223671, 0.9349948505560753], 
             UndirectedEdge[163, 167] -> 
             RGBColor[
              0.2885245503262027, 0.4204485142001573, 0.9397475246726753], 
             UndirectedEdge[62, 119] -> 
             RGBColor[
              0.1917608818844465, 0.31888322357566273`, 0.9342318705872924], 
             UndirectedEdge[137, 197] -> 
             RGBColor[
              0.6493874970557305, 0.7185106775296126, 0.9439140882472267], 
             UndirectedEdge[265, 383] -> 
             RGBColor[
              0.1991683094404495, 0.3266688995950551, 0.9346537126282998], 
             UndirectedEdge[19, 338] -> 
             RGBColor[
              0.24730224830049347`, 0.3772607212049526, 0.937394869238598], 
             UndirectedEdge[69, 212] -> 
             RGBColor[
              0.32957634955032006`, 0.4536960916538069, 0.9424478684800611], 
             UndirectedEdge[45, 275] -> 
             RGBColor[
              0.261779864050582, 0.3924776132921515, 0.9382193480378523], 
             UndirectedEdge[248, 360] -> 
             RGBColor[
              0.20162405229043762`, 0.3292500410334822, 0.9347935635506606], 
             UndirectedEdge[188, 322] -> 
             RGBColor[
              0.20084485470176572`, 0.3284310549638075, 0.9347491894007052], 
             UndirectedEdge[167, 183] -> 
             RGBColor[
              0.33012064304919175`, 0.46035564148841296`, 0.9422559733542398],
              UndirectedEdge[141, 240] -> 
             RGBColor[
              0.8486432291011581, 0.36358607454286945`, 0.19377114111448232`],
              UndirectedEdge[23, 220] -> 
             RGBColor[
              0.46443936234214256`, 0.5702897109178078, 0.9522369568394528], 
             UndirectedEdge[123, 322] -> 
             RGBColor[
              0.20580146810397543`, 0.3336407699169709, 0.9350314612013086], 
             UndirectedEdge[177, 398] -> 
             RGBColor[
              0.6604733814795012, 0.7312391377896288, 0.9691021762679148], 
             UndirectedEdge[272, 395] -> 
             RGBColor[
              0.6047861017850406, 0.688521596311049, 0.9630625411341533], 
             UndirectedEdge[85, 312] -> 
             RGBColor[
              0.27182714160879756`, 0.40303793904002655`, 0.9387915256311776],
              UndirectedEdge[25, 328] -> 
             RGBColor[
              0.8434248781398908, 0.3172892303900453, 0.1885318018785458], 
             UndirectedEdge[8, 121] -> 
             RGBColor[
              0.2743592219367422, 0.4054995926319236, 0.9389430367111391], 
             UndirectedEdge[169, 319] -> 
             RGBColor[
              0.6745752376290368, 0.7434200744106859, 0.9700158830654886], 
             UndirectedEdge[84, 167] -> 
             RGBColor[
              0.32454610124482625`, 0.4555272535620894, 0.9419007684798394], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.2877186940288704, 0.4160544664052851, 0.9398315069221266], 
             UndirectedEdge[43, 213] -> 
             RGBColor[
              0.2414891450614786, 0.3711507811287148, 0.9370638216088516], 
             UndirectedEdge[170, 187] -> 
             RGBColor[
              0.33329236872326556`, 0.45597611149735384`, 0.9427190170162062],
              UndirectedEdge[89, 199] -> 
             RGBColor[
              0.18786740786844439`, 0.3147909355243339, 0.9340101430019597], 
             UndirectedEdge[16, 373] -> 
             RGBColor[
              0.29481332974402036`, 0.42636304065032193`, 0.9401311226051551],
              UndirectedEdge[22, 158] -> 
             RGBColor[
              0.3275157516971413, 0.458099415524913, 0.9420899919807021], 
             UndirectedEdge[233, 264] -> 
             RGBColor[
              0.8413490098710985, 0.8765030596973409, 0.9633266229040078], 
             UndirectedEdge[274, 296] -> 
             RGBColor[
              0.36901952314668135`, 0.4870709060931353, 0.9452488023460986], 
             UndirectedEdge[97, 211] -> 
             RGBColor[
              0.20738956458852648`, 0.33530996001336677`, 0.9351219009467256],
              UndirectedEdge[1, 129] -> 
             RGBColor[
              0.19131755276026974`, 0.31841725655746295`, 0.9342066236495172],
              UndirectedEdge[24, 141] -> 
             RGBColor[
              0.8431921928460754, 0.3216870212269862, 0.1885512226405503], 
             UndirectedEdge[347, 384] -> 
             RGBColor[
              0.19370455937175246`, 0.32092615185109175`, 0.9343425601447813],
              UndirectedEdge[36, 378] -> 
             RGBColor[
              0.1918482442519195, 0.31897504696297085`, 0.934236845744879], 
             UndirectedEdge[174, 395] -> 
             RGBColor[
              0.4063176896518592, 0.5259376945387678, 0.9472261235324917], 
             UndirectedEdge[104, 357] -> 
             RGBColor[
              0.8380548061555597, 0.2935114925998279, 0.18407463139230737`], 
             UndirectedEdge[47, 173] -> 
             RGBColor[
              0.41329174036295263`, 0.5275007351562074, 0.948325579764125], 
             UndirectedEdge[127, 231] -> 
             RGBColor[
              0.1884985570631651, 0.31545431334515556`, 0.9340460860148976], 
             UndirectedEdge[252, 367] -> 
             RGBColor[
              0.372324185998124, 0.4969102291790325, 0.9449451457918181], 
             UndirectedEdge[158, 310] -> 
             RGBColor[
              0.30917761379090525`, 0.4395210111497373, 0.9410201730137817], 
             UndirectedEdge[149, 397] -> 
             RGBColor[
              0.21476341163145843`, 0.34306034078439396`, 0.9355418306271915],
              UndirectedEdge[204, 345] -> 
             RGBColor[
              0.18631088399028722`, 0.3131549302390768, 0.9339215012697695], 
             UndirectedEdge[231, 396] -> 
             RGBColor[
              0.19087540782908663`, 0.31795253420118175`, 0.9341814441497811],
              UndirectedEdge[162, 263] -> 
             RGBColor[
              0.33214075614847005`, 0.45873834938016844`, 0.9425079759974546],
              UndirectedEdge[14, 196] -> 
             RGBColor[
              0.18714224683050756`, 0.3140287452955969, 0.9339688461536289], 
             UndirectedEdge[43, 175] -> 
             RGBColor[
              0.2710055822533935, 0.4021744280676252, 0.9387447390412754], 
             UndirectedEdge[113, 397] -> 
             RGBColor[
              0.2602244815922864, 0.3908428077115391, 0.9381307713078346], 
             UndirectedEdge[126, 336] -> 
             RGBColor[
              0.18346975723563688`, 0.31016872588209876`, 0.9337597033041625],
              UndirectedEdge[48, 173] -> 
             RGBColor[
              0.2613339339978391, 0.3920089125331203, 0.938193952981043], 
             UndirectedEdge[28, 168] -> 
             RGBColor[
              0.19559687276408316`, 0.32291509320603007`, 0.9344503245930478],
              UndirectedEdge[253, 359] -> 
             RGBColor[
              0.18914843365842357`, 0.3161373748513282, 0.9340830955255912], 
             UndirectedEdge[41, 187] -> 
             RGBColor[
              0.6533956652271913, 0.7258990741319324, 0.9682873726725081], 
             UndirectedEdge[198, 398] -> 
             RGBColor[
              0.38970123207440616`, 0.5119613530945772, 0.9460523958018803], 
             UndirectedEdge[260, 329] -> 
             RGBColor[
              0.20751257412950358`, 0.3354392508401891, 0.9351289061581081], 
             UndirectedEdge[60, 82] -> 
             RGBColor[
              0.18336573314646784`, 0.31005938996887394`, 0.9337537792861741],
              UndirectedEdge[12, 17] -> 
             RGBColor[0.2700762317403779, 0.40119762175422, 0.93869181390441],
              UndirectedEdge[268, 351] -> 
             RGBColor[
              0.7945761589543001, 0.8401740652758038, 0.979966961918109], 
             UndirectedEdge[122, 274] -> 
             RGBColor[
              0.5455206538470523, 0.6419172680752578, 0.9573645306602898], 
             UndirectedEdge[150, 384] -> 
             RGBColor[
              0.19155187583051508`, 0.31866354496123156`, 0.9342199680017178],
              UndirectedEdge[179, 232] -> 
             RGBColor[
              0.374520452238133, 0.49753308772821003`, 0.9451360369712756], 
             UndirectedEdge[4, 131] -> 
             RGBColor[
              0.22303764420255517`, 0.35175708383326204`, 0.9360130359314853],
              UndirectedEdge[128, 155] -> 
             RGBColor[
              0.2008465417565683, 0.32843282816537045`, 0.9347492854759805], 
             UndirectedEdge[316, 362] -> 
             RGBColor[
              0.2117594365618467, 0.339902972523212, 0.9353707586909601], 
             UndirectedEdge[283, 320] -> 
             RGBColor[
              0.20238649627655553`, 0.330051418004633, 0.9348369836077353], 
             UndirectedEdge[49, 396] -> 
             RGBColor[
              0.1936178582000953, 0.3208350234225083, 0.9343376226413184], 
             UndirectedEdge[371, 389] -> 
             RGBColor[
              0.194598112629328, 0.3218653329793524, 0.9343934466809067], 
             UndirectedEdge[53, 58] -> 
             RGBColor[
              0.20217788494718347`, 0.3298321542707407, 0.9348251035011402], 
             UndirectedEdge[18, 399] -> 
             RGBColor[
              0.7658581753592988, 0.7184623790314186, 0.610918793426945], 
             UndirectedEdge[241, 270] -> 
             RGBColor[
              0.31115624108701556`, 0.43971981464523346`, 0.9412017203817521],
              UndirectedEdge[137, 169] -> 
             RGBColor[
              0.6151260920101136, 0.6919294010372166, 0.9662275076726026], 
             UndirectedEdge[156, 386] -> 
             RGBColor[
              0.795873240259372, 0.5261038848053603, 0.5770472868303405], 
             UndirectedEdge[19, 262] -> 
             RGBColor[
              0.23727783738368446`, 0.36672442974702457`, 0.9368239938666727],
              UndirectedEdge[85, 181] -> 
             RGBColor[
              0.2178344766889036, 0.34628822487653976`, 0.9357167232389794], 
             UndirectedEdge[74, 240] -> 
             RGBColor[
              0.8473744873922651, 0.569112601384381, 0.5823896435853375], 
             UndirectedEdge[72, 88] -> 
             RGBColor[
              0.18714176336881175`, 0.31402823714670136`, 0.9339688186212005],
              UndirectedEdge[63, 98] -> 
             RGBColor[
              0.19109841618892076`, 0.3181869301269141, 0.9341941441459625], 
             UndirectedEdge[43, 56] -> 
             RGBColor[
              0.3210051071529382, 0.44798658822988663`, 0.9418389411311112], 
             UndirectedEdge[174, 272] -> 
             RGBColor[
              0.5424648698288314, 0.6349580764887339, 0.9589765455952728], 
             UndirectedEdge[180, 198] -> 
             RGBColor[
              0.30592577418738304`, 0.43475768207038135`, 0.9408842486890967],
              UndirectedEdge[126, 289] -> 
             RGBColor[
              0.1863769520635358, 0.31322437197301883`, 0.933925263748802], 
             UndirectedEdge[233, 244] -> 
             RGBColor[
              0.9570858882964418, 0.9675153062736708, 0.9575265767079428], 
             UndirectedEdge[51, 189] -> 
             RGBColor[
              0.324110599148695, 0.45125735516848015`, 0.9420155490612911], 
             UndirectedEdge[199, 306] -> 
             RGBColor[
              0.19460108481424115`, 0.32186845693414357`, 0.9343936159424405],
              UndirectedEdge[86, 214] -> 
             RGBColor[
              0.32538385594789154`, 0.4498732658782442, 0.9421877381945456], 
             UndirectedEdge[104, 172] -> 
             RGBColor[
              0.8214061746435448, 0.16554281532163417`, 0.16813188305446203`],
              UndirectedEdge[67, 293] -> 
             RGBColor[
              0.3870584168095417, 0.509672279343909, 0.9458839979501529], 
             UndirectedEdge[296, 380] -> 
             RGBColor[
              0.23254239925943204`, 0.3617471840343169, 0.9365543176709494], 
             UndirectedEdge[290, 297] -> 
             RGBColor[
              0.20256888353236238`, 0.33024311857450594`, 0.9348473702921356],
              UndirectedEdge[206, 328] -> 
             RGBColor[
              0.7999219852902167, 0.6448484807342735, 0.5933000289298582], 
             UndirectedEdge[5, 319] -> 
             RGBColor[
              0.3679006517731242, 0.4906453846924169, 0.9447526657346955], 
             UndirectedEdge[235, 393] -> 
             RGBColor[
              0.18743861764572758`, 0.31434024981338815`, 0.9339857240331143],
              UndirectedEdge[40, 189] -> 
             RGBColor[
              0.3938515783304093, 0.5098241340349448, 0.9469676010279292], 
             UndirectedEdge[15, 256] -> 
             RGBColor[
              0.31856719551894513`, 0.448229479012007, 0.9415973902435224], 
             UndirectedEdge[71, 365] -> 
             RGBColor[
              0.17992874679989868`, 0.30644689940110903`, 0.9335580479983027],
              UndirectedEdge[53, 64] -> 
             RGBColor[
              0.18652020523185484`, 0.31337494013569756`, 0.9339334218048136],
              UndirectedEdge[231, 298] -> 
             RGBColor[
              0.1895953138932402, 0.3166070743119639, 0.934108544693864], 
             UndirectedEdge[81, 382] -> 
             RGBColor[
              0.18072466475425025`, 0.3072834596352455, 0.9336033743483478], 
             UndirectedEdge[9, 294] -> 
             RGBColor[
              0.1904972038981096, 0.3175550178902107, 0.9341599059954147], 
             UndirectedEdge[175, 213] -> 
             RGBColor[
              0.25213492118930436`, 0.3823401668202513, 0.9376700828103168], 
             UndirectedEdge[174, 189] -> 
             RGBColor[
              0.3053198459534695, 0.4349817492014926, 0.9408182188837021], 
             UndirectedEdge[14, 127] -> 
             RGBColor[
              0.18967658911817914`, 0.3166924997265216, 0.9341131731976884], 
             UndirectedEdge[86, 95] -> 
             RGBColor[
              0.48521628550800544`, 0.5918110474144382, 0.9529344611319093], 
             UndirectedEdge[103, 200] -> 
             RGBColor[
              0.18928086975494526`, 0.31627657358570604`, 0.9340906375653665],
              UndirectedEdge[24, 112] -> 
             RGBColor[
              0.8789473611792127, 0.4745715601436108, 0.21789626946789925`], 
             UndirectedEdge[109, 360] -> 
             RGBColor[
              0.18328589355082267`, 0.3099754734917281, 0.9337492325393142], 
             UndirectedEdge[90, 121] -> 
             RGBColor[
              0.4596424243656251, 0.5683306378036415, 0.9516722943059467], 
             UndirectedEdge[75, 202] -> 
             RGBColor[
              0.23066301686818202`, 0.3597718339813871, 0.9364472896240648], 
             UndirectedEdge[27, 32] -> 
             RGBColor[
              0.8890352414528142, 0.5147182506008601, 0.2276791825593331], 
             UndirectedEdge[131, 273] -> 
             RGBColor[
              0.19754073794696791`, 0.32495821876141306`, 0.9345610248395222],
              UndirectedEdge[160, 220] -> 
             RGBColor[
              0.5477229997143326, 0.6437052316648666, 0.9575379073944208], 
             UndirectedEdge[50, 147] -> 
             RGBColor[
              0.18125622821196816`, 0.30784216653237684`, 0.9336336461008872],
              UndirectedEdge[13, 339] -> 
             RGBColor[
              0.2328552355524508, 0.3620759948132462, 0.936572133235037], 
             UndirectedEdge[17, 209] -> 
             RGBColor[
              0.2832594251473382, 0.412641193889955, 0.9395309216934591], 
             UndirectedEdge[174, 325] -> 
             RGBColor[
              0.31656779052141654`, 0.4468040521032807, 0.9414587726870038], 
             UndirectedEdge[21, 78] -> 
             RGBColor[
              0.8915698412637564, 0.5208943698778701, 0.23913655286510038`], 
             UndirectedEdge[274, 373] -> 
             RGBColor[
              0.38246482009015115`, 0.5012027656617852, 0.9460144921164949], 
             UndirectedEdge[97, 305] -> 
             RGBColor[
              0.18756138502713113`, 0.3144692861151448, 0.9339927154538672], 
             UndirectedEdge[11, 162] -> 
             RGBColor[
              0.29214677471105677`, 0.42409757281503596`, 0.9399595948655519],
              UndirectedEdge[103, 207] -> 
             RGBColor[
              0.19105231071262538`, 0.3181384703480716, 0.9341915185072943], 
             UndirectedEdge[210, 249] -> 
             RGBColor[
              0.3073650774594488, 0.4403600145758346, 0.9408164770263279], 
             UndirectedEdge[52, 299] -> 
             RGBColor[
              0.18351379325327066`, 0.3102150105286766, 0.9337622110902213], 
             UndirectedEdge[43, 373] -> 
             RGBColor[
              0.2661054797853324, 0.3970241096892522, 0.9384656854547713], 
             UndirectedEdge[1, 336] -> 
             RGBColor[
              0.18695004027347276`, 0.31382672401755374`, 0.9339579002745498],
              UndirectedEdge[30, 345] -> 
             RGBColor[
              0.1795989351746539, 0.30610024647171197`, 0.9335392657141575], 
             UndirectedEdge[247, 363] -> 
             RGBColor[
              0.20876443324933688`, 0.3367550341475864, 0.9352001976830229], 
             UndirectedEdge[14, 119] -> 
             RGBColor[
              0.18348249259608096`, 0.310182111553394, 0.9337604285640995], 
             UndirectedEdge[74, 104] -> 
             RGBColor[
              0.8410345872048564, 0.5203813503819814, 0.5763185480059819], 
             UndirectedEdge[258, 277] -> 
             RGBColor[
              0.19561158896014919`, 0.3229305608611562, 0.9344511626586431], 
             UndirectedEdge[152, 236] -> 
             RGBColor[
              0.2537723278978401, 0.38406118508850384`, 0.9377633307000419], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.26676233186552467`, 0.3975147794964234, 0.938510405060175], 
             UndirectedEdge[120, 132] -> 
             RGBColor[
              0.4382862950940797, 0.5522789014915227, 0.9496356996104882], 
             UndirectedEdge[212, 270] -> 
             RGBColor[
              0.38821783346100136`, 0.5106765077734281, 0.9459578749539519], 
             UndirectedEdge[69, 270] -> 
             RGBColor[
              0.300457761234542, 0.4284750339974831, 0.9405924577811364], 
             UndirectedEdge[16, 270] -> 
             RGBColor[
              0.3384373755940835, 0.46755917720766627`, 0.9427859081978025], 
             UndirectedEdge[24, 73] -> 
             RGBColor[
              0.8757010840349191, 0.46170115302421727`, 0.21528423867768243`],
              UndirectedEdge[56, 178] -> 
             RGBColor[
              0.4116703274319593, 0.5309898792944511, 0.9474522471315552], 
             UndirectedEdge[6, 319] -> 
             RGBColor[
              0.37947514539695637`, 0.5028109113563464, 0.945411816023644], 
             UndirectedEdge[231, 235] -> 
             RGBColor[
              0.18685346885052345`, 0.3137252213290522, 0.9339524006748775], 
             UndirectedEdge[18, 86] -> 
             RGBColor[
              0.5080814719938581, 0.6103740358685661, 0.9547344923700136], 
             UndirectedEdge[30, 63] -> 
             RGBColor[
              0.18069605079375822`, 0.30725338454853857`, 0.9336017448256284],
              UndirectedEdge[46, 358] -> 
             RGBColor[
              0.19603463800818394`, 0.3233752122334996, 0.9344752546760837], 
             UndirectedEdge[241, 389] -> 
             RGBColor[
              0.23293094482355622`, 0.362155570057423, 0.9365764447660246], 
             UndirectedEdge[286, 332] -> 
             RGBColor[
              0.2115950206250406, 0.3397301609490563, 0.9353613954465905], 
             UndirectedEdge[40, 174] -> 
             RGBColor[
              0.4325281900725898, 0.5472165595499049, 0.9492895101378381], 
             UndirectedEdge[157, 365] -> 
             RGBColor[
              0.18416233691758455`, 0.3108966710399138, 0.9337991446924696], 
             UndirectedEdge[235, 336] -> 
             RGBColor[
              0.18593363733157064`, 0.312758420081946, 0.9339000176306419], 
             UndirectedEdge[76, 222] -> 
             RGBColor[
              0.21314128516619657`, 0.3413553830206456, 0.9354494529247159], 
             UndirectedEdge[115, 392] -> 
             RGBColor[
              0.9278459781809479, 0.7343397761790258, 0.5030820645906373], 
             UndirectedEdge[76, 77] -> 
             RGBColor[
              0.1883529029244576, 0.3153012216103682, 0.9340377912271741], 
             UndirectedEdge[160, 366] -> 
             RGBColor[
              0.4270114418839008, 0.5441063729670104, 0.948477074824805], 
             UndirectedEdge[3, 348] -> 
             RGBColor[
              0.45750426505624076`, 0.5671984745069012, 0.9513371690188597], 
             UndirectedEdge[299, 306] -> 
             RGBColor[
              0.19518727715711093`, 0.32248458225324084`, 0.9344269987291731],
              UndirectedEdge[56, 121] -> 
             RGBColor[
              0.3462782939569843, 0.4743505865975952, 0.9432855245824346], 
             UndirectedEdge[280, 322] -> 
             RGBColor[
              0.22572058379982396`, 0.354577023458187, 0.9361658253724963], 
             UndirectedEdge[81, 271] -> 
             RGBColor[
              0.1793288256722832, 0.3058163442587888, 0.9335238833775887], 
             UndirectedEdge[2, 191] -> 
             RGBColor[
              0.19610476461646903`, 0.323448919745091, 0.9344792482826825], 
             UndirectedEdge[146, 377] -> 
             RGBColor[
              0.18543930213235216`, 0.3122388424449055, 0.9338718659723498], 
             UndirectedEdge[10, 396] -> 
             RGBColor[
              0.21852942039278686`, 0.3470186547712968, 0.9357562992548385], 
             UndirectedEdge[382, 384] -> 
             RGBColor[
              0.18572468011707222`, 0.3125387928008556, 0.9338881178264007], 
             UndirectedEdge[147, 391] -> 
             RGBColor[
              0.18230154859335337`, 0.30894086453035285`, 0.9336931755501943],
              UndirectedEdge[133, 216] -> 
             RGBColor[
              0.19274891912622777`, 0.3199217133619542, 0.9342881378465417], 
             UndirectedEdge[86, 264] -> 
             RGBColor[
              0.5671571608223211, 0.6570945561668415, 0.9602327949234224], 
             UndirectedEdge[6, 56] -> 
             RGBColor[
              0.34361946259808085`, 0.47175570963568103`, 0.9431267952187714],
              UndirectedEdge[43, 308] -> 
             RGBColor[
              0.23093015114267265`, 0.3600526090411681, 0.9364625025258073], 
             UndirectedEdge[201, 364] -> 
             RGBColor[
              0.8833604425346897, 0.5491985864535379, 0.5678503651913112], 
             UndirectedEdge[109, 365] -> 
             RGBColor[
              0.1811265179483144, 0.30770583282117103`, 0.9336262592932614], 
             UndirectedEdge[229, 349] -> 
             RGBColor[
              0.20443433824615148`, 0.33220382975535845`, 0.934953605178393], 
             UndirectedEdge[216, 231] -> 
             RGBColor[
              0.19095180161373265`, 0.3180328289124904, 0.9341857946628023], 
             UndirectedEdge[114, 353] -> 
             RGBColor[
              0.2156557406567855, 0.3439982351669406, 0.9355926474451014], 
             UndirectedEdge[70, 236] -> 
             RGBColor[
              0.23684558512377027`, 0.36627010521547854`, 0.9367993777399305],
              UndirectedEdge[64, 94] -> 
             RGBColor[
              0.1809149928406964, 0.30748350652159806`, 0.9336142132513059], 
             UndirectedEdge[240, 285] -> 
             RGBColor[
              0.912943980913413, 0.617290591635334, 0.3939789817698772], 
             UndirectedEdge[56, 90] -> 
             RGBColor[
              0.4950145385889495, 0.5989681852897308, 0.9539261741459244], 
             UndirectedEdge[90, 295] -> 
             RGBColor[
              0.5187067634857201, 0.6194891996894659, 0.9554358217661347], 
             UndirectedEdge[165, 281] -> 
             RGBColor[
              0.6627187385434833, 0.7331187175098175, 0.9692752800168635], 
             UndirectedEdge[54, 345] -> 
             RGBColor[
              0.1817997844893844, 0.30841347864339985`, 0.9336646008267666], 
             UndirectedEdge[101, 136] -> 
             RGBColor[
              0.18384486237801373`, 0.31056298516977654`, 0.9337810649871026],
              UndirectedEdge[6, 314] -> 
             RGBColor[
              0.26913140342587094`, 0.400204547290098, 0.9386380073296472], 
             UndirectedEdge[125, 276] -> 
             RGBColor[
              0.2421845103154749, 0.3718816540993685, 0.9371034216313661], 
             UndirectedEdge[244, 341] -> 
             RGBColor[
              0.6455002366075493, 0.7157181703634723, 0.9520500486891706], 
             UndirectedEdge[46, 153] -> 
             RGBColor[
              0.1918690303202028, 0.3189968944386494, 0.9342380294807175], 
             UndirectedEdge[14, 336] -> 
             RGBColor[
              0.18245115534282794`, 0.3090981107096664, 0.9337016954332534], 
             UndirectedEdge[109, 370] -> 
             RGBColor[
              0.1842051301196885, 0.31094164940857083`, 0.9338015817020224], 
             UndirectedEdge[51, 234] -> 
             RGBColor[
              0.5836503518814267, 0.668728614845342, 0.9624059730547245], 
             UndirectedEdge[144, 228] -> 
             RGBColor[
              0.19707272190642572`, 0.32446630422887235`, 0.934534372018381], 
             UndirectedEdge[320, 347] -> 
             RGBColor[
              0.1968219545840863, 0.324202731873527, 0.9345200911903508], 
             UndirectedEdge[31, 106] -> 
             RGBColor[
              0.21164758701888683`, 0.33978541156189057`, 0.935364389024955], 
             UndirectedEdge[77, 103] -> 
             RGBColor[
              0.18857832587467818`, 0.31553815542369057`, 0.9340506287307058],
              UndirectedEdge[266, 316] -> 
             RGBColor[
              0.23355306875092818`, 0.36280946175002615`, 0.9366118738033387],
              UndirectedEdge[109, 334] -> 
             RGBColor[
              0.18315174728548578`, 0.30983447726149455`, 0.9337415931079549],
              UndirectedEdge[45, 179] -> 
             RGBColor[
              0.3693787364367489, 0.49212881841734446`, 0.9448432238628737], 
             UndirectedEdge[181, 191] -> 
             RGBColor[
              0.2010737277844803, 0.3286716150851321, 0.9347622233841785], 
             UndirectedEdge[125, 148] -> 
             RGBColor[
              0.2977450564931756, 0.4279464199660071, 0.9403529311058223], 
             UndirectedEdge[18, 112] -> 
             RGBColor[
              0.7711240798821252, 0.7393399357057666, 0.6151558638126768], 
             UndirectedEdge[221, 239] -> 
             RGBColor[
              0.8650356462249088, 0.43184524722399015`, 0.20720757963682196`],
              UndirectedEdge[57, 76] -> 
             RGBColor[
              0.20578868678679324`, 0.33362733594223004`, 0.9350307333242034],
              UndirectedEdge[222, 333] -> 
             RGBColor[
              0.21024933242430197`, 0.33831575732852015`, 0.9352847604943257],
              UndirectedEdge[125, 214] -> 
             RGBColor[
              0.25062847588100123`, 0.38075679728707557`, 0.9375842929785951],
              UndirectedEdge[220, 244] -> 
             RGBColor[
              0.7952939705328516, 0.8405065482820335, 0.9629639718031929], 
             UndirectedEdge[143, 379] -> 
             RGBColor[
              0.19607245739300067`, 0.3234149628048294, 0.9344774084341002], 
             UndirectedEdge[31, 241] -> 
             RGBColor[
              0.22984485211178313`, 0.3589118909477702, 0.9364006963515542], 
             UndirectedEdge[81, 374] -> 
             RGBColor[
              0.1848884604275577, 0.3116598728877852, 0.9338404963521592], 
             UndirectedEdge[168, 304] -> 
             RGBColor[
              0.18254777981600245`, 0.3091996691573183, 0.9337071980540577], 
             UndirectedEdge[156, 328] -> 
             RGBColor[
              0.850258311685, 0.36981399504742796`, 0.1950755055586017], 
             UndirectedEdge[46, 363] -> 
             RGBColor[
              0.21059715829347625`, 0.33868134437045616`, 0.9353045686630128],
              UndirectedEdge[51, 269] -> 
             RGBColor[
              0.5625797337470475, 0.652268087816136, 0.9603058507552114], 
             UndirectedEdge[13, 325] -> 
             RGBColor[
              0.25165090865355244`, 0.3818314389570088, 0.9376425190124382], 
             UndirectedEdge[164, 374] -> 
             RGBColor[
              0.1955858495365969, 0.322903507095029, 0.9344496968365499], 
             UndirectedEdge[49, 199] -> 
             RGBColor[
              0.18708382947160418`, 0.313967344947515, 0.93396551937146], 
             UndirectedEdge[49, 313] -> 
             RGBColor[
              0.20302253470198556`, 0.3307199347169253, 0.9348732050551289], 
             UndirectedEdge[176, 388] -> 
             RGBColor[
              0.22659156217478169`, 0.35549247695348607`, 0.9362154263024531],
              UndirectedEdge[45, 232] -> 
             RGBColor[
              0.28995111396047296`, 0.4220873831078549, 0.9398236590445912], 
             UndirectedEdge[176, 250] -> 
             RGBColor[
              0.24600820440775967`, 0.3759005990265677, 0.9373211753532731], 
             UndirectedEdge[346, 390] -> 
             RGBColor[
              0.30688867117659013`, 0.43597701754892004`, 0.9409314950894052],
              UndirectedEdge[331, 335] -> 
             RGBColor[
              0.18932527309814626`, 0.31632324431474484`, 0.9340931662700729],
              UndirectedEdge[135, 355] -> 
             RGBColor[
              0.8802746969932166, 0.9041359691009224, 0.8286360157619015], 
             UndirectedEdge[326, 327] -> 
             RGBColor[
              0.19380937140054372`, 0.3210363159388178, 0.9343485290347655], 
             UndirectedEdge[80, 304] -> 
             RGBColor[
              0.18034926344630414`, 0.30688888905877654`, 0.9335819957992169],
              UndirectedEdge[65, 173] -> 
             RGBColor[
              0.2852130264023293, 0.4171073526721437, 0.9395538319675272], 
             UndirectedEdge[203, 257] -> 
             RGBColor[
              0.27443071882287484`, 0.40444693199068393`, 0.9389884029433275],
              UndirectedEdge[275, 325] -> 
             RGBColor[
              0.2639447266446291, 0.3947530211387112, 0.9383426337599561], 
             UndirectedEdge[240, 337] -> 
             RGBColor[
              0.9128678714659045, 0.6171278012229586, 0.3856949381016387], 
             UndirectedEdge[77, 254] -> 
             RGBColor[
              0.18502833391359902`, 0.3118068887901059, 0.9338484619402648], 
             UndirectedEdge[32, 364] -> 
             RGBColor[
              0.8873546832703587, 0.5018007439852152, 0.22606987814589463`], 
             UndirectedEdge[38, 53] -> 
             RGBColor[
              0.2076634431002256, 0.3355978236940631, 0.9351374979228], 
             UndirectedEdge[28, 291] -> 
             RGBColor[
              0.1970819328198578, 0.3244759854828951, 0.9345348965662746], 
             UndirectedEdge[174, 269] -> 
             RGBColor[
              0.543788980551822, 0.6359924818491485, 0.9591085205776222], 
             UndirectedEdge[216, 361] -> 
             RGBColor[
              0.20867332138388106`, 0.3366592698001664, 0.9351950089970731], 
             UndirectedEdge[356, 363] -> 
             RGBColor[
              0.2074463229173425, 0.3353696166156383, 0.9351251332495853], 
             UndirectedEdge[151, 383] -> 
             RGBColor[
              0.20018660218381945`, 0.3277391898318258, 0.9347117028936056], 
             UndirectedEdge[61, 130] -> 
             RGBColor[
              0.19568837198846437`, 0.3230112646922406, 0.9344555353385153], 
             UndirectedEdge[331, 338] -> 
             RGBColor[
              0.2166739251358942, 0.34506841161110846`, 0.9356506315449178], 
             UndirectedEdge[239, 246] -> 
             RGBColor[
              0.874004135287985, 0.576823099817974, 0.5832370617608514], 
             UndirectedEdge[190, 212] -> 
             RGBColor[
              0.6867778683351773, 0.7513832913392242, 0.9534033725466657], 
             UndirectedEdge[111, 286] -> 
             RGBColor[
              0.1920478961746871, 0.3191848937924626, 0.934248215626522], 
             UndirectedEdge[228, 273] -> 
             RGBColor[
              0.1927101706170558, 0.31988098622201705`, 0.9342859311762677], 
             UndirectedEdge[199, 299] -> 
             RGBColor[
              0.18707599573729403`, 0.31395911119606756`, 0.93396507325188], 
             UndirectedEdge[50, 391] -> 
             RGBColor[
              0.18008156514952903`, 0.3066075211758136, 0.9335667507772396], 
             UndirectedEdge[358, 362] -> 
             RGBColor[
              0.18997045450082056`, 0.31700137087581914`, 0.9341299083964949],
              UndirectedEdge[42, 98] -> 
             RGBColor[
              0.20876468464708048`, 0.33675529838255447`, 0.9352002119997525],
              UndirectedEdge[39, 251] -> 
             RGBColor[
              0.18672478342346222`, 0.3135899647860835, 0.9339450722301794], 
             UndirectedEdge[148, 179] -> 
             RGBColor[
              0.39396314610535543`, 0.515635700812435, 0.9463286881882242], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.19127206346984504`, 0.31836944442903903`, 0.934204033101723], 
             UndirectedEdge[77, 333] -> 
             RGBColor[
              0.18546095018256298`, 0.31226159591824276`, 0.9338730987967839],
              UndirectedEdge[173, 354] -> 
             RGBColor[
              0.24916626557073213`, 0.3792199215414943, 0.9375010222645717], 
             UndirectedEdge[160, 217] -> 
             RGBColor[
              0.7263465347719837, 0.7798834744139984, 0.7188240157462833], 
             UndirectedEdge[59, 90] -> 
             RGBColor[
              0.47744540309430256`, 0.5837506831746934, 0.9528066843679821], 
             UndirectedEdge[237, 380] -> 
             RGBColor[
              0.20872851353399335`, 0.33671728024931885`, 0.9351981521083725],
              UndirectedEdge[285, 399] -> 
             RGBColor[
              0.9603875503566552, 0.868303119703074, 0.4348794443842956], 
             UndirectedEdge[51, 392] -> 
             RGBColor[
              0.6863309387769014, 0.7477531849917098, 0.8714804732443268], 
             UndirectedEdge[264, 307] -> 
             RGBColor[
              0.5358230864206805, 0.6299545558165122, 0.958236215410184], 
             UndirectedEdge[78, 208] -> 
             RGBColor[
              0.9064764270189856, 0.5728170966942296, 0.4660720225452738], 
             UndirectedEdge[28, 383] -> 
             RGBColor[
              0.20767130167756592`, 0.3356060835571104, 0.9351379454571538], 
             UndirectedEdge[255, 268] -> 
             RGBColor[
              0.7573621449450872, 0.5111257415751345, 0.5750858104368912], 
             UndirectedEdge[46, 247] -> 
             RGBColor[
              0.1994607168120997, 0.32697623828235756`, 0.9346703647955372], 
             UndirectedEdge[272, 392] -> 
             RGBColor[
              0.8660085977148573, 0.8940614807970035, 0.8861195606683994], 
             UndirectedEdge[316, 359] -> 
             RGBColor[
              0.21077886401933704`, 0.3388723286091443, 0.9353149165352912], 
             UndirectedEdge[223, 242] -> 
             RGBColor[
              0.8910877878932282, 0.5812972246774919, 0.23007311301914762`], 
             UndirectedEdge[158, 390] -> 
             RGBColor[
              0.3007335296132649, 0.43064574329317795`, 0.9405392949117681], 
             UndirectedEdge[26, 128] -> 
             RGBColor[
              0.19080558249119994`, 0.3178791433438807, 0.9341774677000858], 
             UndirectedEdge[136, 335] -> 
             RGBColor[
              0.18204623503960604`, 0.3086725137975501, 0.9336786358210108], 
             UndirectedEdge[193, 248] -> 
             RGBColor[
              0.20247189401375032`, 0.330141176440954, 0.9348418468825339], 
             UndirectedEdge[281, 386] -> 
             RGBColor[
              0.5947242732295994, 0.6793804571151425, 0.9626628801063983], 
             UndirectedEdge[225, 337] -> 
             RGBColor[
              0.9393785469822551, 0.9502915240338172, 0.7911384355526612], 
             UndirectedEdge[30, 297] -> 
             RGBColor[
              0.19356559882175525`, 0.3207800955024369, 0.9343346465470327], 
             UndirectedEdge[32, 104] -> 
             RGBColor[
              0.8880206846932135, 0.5069199227649615, 0.22670764186056142`], 
             UndirectedEdge[264, 366] -> 
             RGBColor[
              0.5588455342770764, 0.6498954430078475, 0.9597031854296422], 
             UndirectedEdge[2, 97] -> 
             RGBColor[
              0.18893766617089083`, 0.31591584485850077`, 0.9340710926289788],
              UndirectedEdge[258, 377] -> 
             RGBColor[
              0.18407204095648846`, 0.3108017642597073, 0.933794002471066], 
             UndirectedEdge[134, 135] -> 
             RGBColor[
              0.9129052217970873, 0.9297159641585085, 0.8318647617559947], 
             UndirectedEdge[185, 338] -> 
             RGBColor[
              0.3169003211264983, 0.4420126040845884, 0.9416659454971446], 
             UndirectedEdge[40, 84] -> 
             RGBColor[
              0.42994887224450423`, 0.5449824840875006, 0.9491251582866337], 
             UndirectedEdge[217, 242] -> 
             RGBColor[
              0.9226715072655902, 0.6951934560850966, 0.34236801946865186`], 
             UndirectedEdge[124, 266] -> 
             RGBColor[
              0.27124098687969256`, 0.402330909521441, 0.9387614748820916], 
             UndirectedEdge[219, 293] -> 
             RGBColor[
              0.34300984476630975`, 0.47151962018566573`, 0.943077261890181], 
             UndirectedEdge[37, 170] -> 
             RGBColor[
              0.29023151793817503`, 0.41867896684859873`, 0.9399752176813956],
              UndirectedEdge[205, 293] -> 
             RGBColor[
              0.3494560104043527, 0.47710296486763304`, 0.9434880058645166], 
             UndirectedEdge[122, 268] -> 
             RGBColor[
              0.638662857560744, 0.7169674525945936, 0.9650845862531987], 
             UndirectedEdge[246, 392] -> 
             RGBColor[
              0.955664633870156, 0.964911832854005, 0.8948405878073766], 
             UndirectedEdge[282, 398] -> 
             RGBColor[
              0.3466184248527956, 0.47079867288483046`, 0.9434480372889362], 
             UndirectedEdge[34, 248] -> 
             RGBColor[
              0.24062348998029212`, 0.37024092275268566`, 0.9370145238326], 
             UndirectedEdge[263, 264] -> 
             RGBColor[
              0.5576221544304325, 0.6488358128735436, 0.9596252327476064], 
             UndirectedEdge[100, 377] -> 
             RGBColor[
              0.19744186238260558`, 0.3248542942741953, 0.9345553940224051], 
             UndirectedEdge[107, 241] -> 
             RGBColor[
              0.30591595912176667`, 0.43518094579116473`, 0.9408678142487259],
              UndirectedEdge[11, 95] -> 
             RGBColor[
              0.43568729767870357`, 0.5489115275560077, 0.9497785178241904], 
             UndirectedEdge[7, 96] -> 
             RGBColor[
              0.5984222253415448, 0.6831169372542267, 0.9626727079088397], 
             UndirectedEdge[111, 383] -> 
             RGBColor[
              0.1988021595169091, 0.3262840528101681, 0.9346328609318244], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.2782593236768137, 0.4070163756656283, 0.939259698655848], 
             UndirectedEdge[121, 122] -> 
             RGBColor[
              0.4544345003462795, 0.5641026104704333, 0.9512623074498896], 
             UndirectedEdge[156, 221] -> 
             RGBColor[
              0.866647121618338, 0.4442317532509077, 0.20875073029347097`], 
             UndirectedEdge[61, 176] -> 
             RGBColor[
              0.2215167477526256, 0.3501585252339816, 0.9359264231286265], 
             UndirectedEdge[128, 261] -> 
             RGBColor[
              0.22729090761283746`, 0.3562275333499445, 0.9362552529905616], 
             UndirectedEdge[69, 381] -> 
             RGBColor[
              0.21898984745913425`, 0.34750259281079, 0.9357825198951262], 
             UndirectedEdge[166, 178] -> 
             RGBColor[
              0.7156925694809679, 0.7734991059400932, 0.884905461880064], 
             UndirectedEdge[114, 202] -> 
             RGBColor[
              0.2423249813764799, 0.37202929809086444`, 0.937111421250482], 
             UndirectedEdge[40, 134] -> 
             RGBColor[
              0.6760140538149009, 0.745057217744171, 0.9695892868351288], 
             UndirectedEdge[84, 234] -> 
             RGBColor[
              0.5622802808581155, 0.6502189334159502, 0.961044291025931], 
             UndirectedEdge[236, 367] -> 
             RGBColor[
              0.3129287562528536, 0.440105110895209, 0.9413567694167602], 
             UndirectedEdge[307, 366] -> 
             RGBColor[
              0.37137695467694465`, 0.4960897850178574, 0.9448847890496364], 
             UndirectedEdge[129, 396] -> 
             RGBColor[
              0.19432308879693078`, 0.32157626549398477`, 0.934377784480513], 
             UndirectedEdge[67, 208] -> 
             RGBColor[
              0.7091189037719949, 0.7670538844748609, 0.8568671364687419], 
             UndirectedEdge[203, 309] -> 
             RGBColor[
              0.2616767930351678, 0.3923692791198713, 0.9382134782960043], 
             UndirectedEdge[142, 302] -> 
             RGBColor[
              0.18693197467623224`, 0.31380773592942895`, 0.9339568714655127],
              UndirectedEdge[93, 248] -> 
             RGBColor[
              0.22615954726936105`, 0.355038401896562, 0.9361908236926982], 
             UndirectedEdge[110, 227] -> 
             RGBColor[
              0.1954518354139104, 0.3227626497550994, 0.934442064930519], 
             UndirectedEdge[129, 361] -> 
             RGBColor[
              0.20336215554475928`, 0.33107689775588556`, 0.9348925459597008],
              UndirectedEdge[236, 332] -> 
             RGBColor[
              0.2395600162179548, 0.36912314440033817`, 0.9369539605751034], 
             UndirectedEdge[306, 353] -> 
             RGBColor[
              0.19636662006403216`, 0.3237241464230741, 0.9344941605630408], 
             UndirectedEdge[257, 280] -> 
             RGBColor[
              0.2873202290991691, 0.41799462453322234`, 0.9397224414852408], 
             UndirectedEdge[208, 385] -> 
             RGBColor[
              0.9937202968318795, 0.9909321476846529, 0.7000134809555262], 
             UndirectedEdge[79, 302] -> 
             RGBColor[
              0.21120952198211004`, 0.3393249774333106, 0.9353394418691697], 
             UndirectedEdge[21, 242] -> 
             RGBColor[
              0.907737765098039, 0.6451681172975665, 0.25461897498786773`], 
             UndirectedEdge[94, 103] -> 
             RGBColor[
              0.18776701535974932`, 0.31468541663244265`, 0.934004425797107], 
             UndirectedEdge[237, 308] -> 
             RGBColor[
              0.19941664213352878`, 0.3269299130006835, 0.9346678548077954], 
             UndirectedEdge[1, 235] -> 
             RGBColor[
              0.19253038583618232`, 0.3196920210183055, 0.9342756926989647], 
             UndirectedEdge[31, 374] -> 
             RGBColor[
              0.1933477765192394, 0.32055115045176114`, 0.9343222418891437], 
             UndirectedEdge[324, 351] -> 
             RGBColor[
              0.7714595274314936, 0.8219737948771062, 0.9777595758801894], 
             UndirectedEdge[62, 396] -> 
             RGBColor[
              0.20033182917246628`, 0.3278918326048165, 0.934719973355765], 
             UndirectedEdge[13, 123] -> 
             RGBColor[
              0.2129302625842361, 0.3411335849074007, 0.9354374355008532], 
             UndirectedEdge[112, 337] -> 
             RGBColor[
              0.9655773454319732, 0.8890178859650467, 0.43083247110178885`], 
             UndirectedEdge[262, 286] -> 
             RGBColor[
              0.20449842182687056`, 0.3322711856618279, 0.9349572546435119], 
             UndirectedEdge[56, 59] -> 
             RGBColor[
              0.3640812726856617, 0.4897706319686471, 0.9444199146444701], 
             UndirectedEdge[61, 118] -> 
             RGBColor[
              0.22412293343441853`, 0.3528977916272621, 0.9360748415476985], 
             UndirectedEdge[14, 235] -> 
             RGBColor[
              0.1880315009055375, 0.3149634077104182, 0.9340194878576683], 
             UndirectedEdge[154, 286] -> 
             RGBColor[
              0.2001789472954632, 0.3277311440588154, 0.9347112669590381], 
             UndirectedEdge[159, 215] -> 
             RGBColor[
              0.1817543271405076, 0.3083657000875679, 0.9336620120979963], 
             UndirectedEdge[25, 385] -> 
             RGBColor[
              0.9058721590894482, 0.562305822104239, 0.3994132353001115], 
             UndirectedEdge[165, 256] -> 
             RGBColor[
              0.624029163944416, 0.6996077525866663, 0.9668100145352584], 
             UndirectedEdge[292, 384] -> 
             RGBColor[
              0.19197167888601352`, 0.3191047845896115, 0.9342438751646855], 
             UndirectedEdge[1, 49] -> 
             RGBColor[
              0.19061232216343427`, 0.3176760144859865, 0.9341664618103227], 
             UndirectedEdge[93, 125] -> 
             RGBColor[
              0.24791606512635506`, 0.37790588160716765`, 0.9374298251987702],
              UndirectedEdge[15, 37] -> 
             RGBColor[
              0.31731211488685307`, 0.44714239125067556`, 0.9415174176154697],
              UndirectedEdge[141, 399] -> 
             RGBColor[
              0.8960867985444002, 0.6145986026106095, 0.23467160372890067`], 
             UndirectedEdge[42, 288] -> 
             RGBColor[
              0.26094257460696524`, 0.39159756899969334`, 0.938171665642697], 
             UndirectedEdge[26, 218] -> 
             RGBColor[
              0.188929981383257, 0.31590776765945394`, 0.9340706549916917], 
             UndirectedEdge[292, 389] -> 
             RGBColor[
              0.1985170723266464, 0.32598440809763013`, 0.9346166256380877], 
             UndirectedEdge[87, 361] -> 
             RGBColor[
              0.20790747959893147`, 0.33585432152701067`, 0.9351513954403816],
              UndirectedEdge[3, 11] -> 
             RGBColor[
              0.4469167817161049, 0.5580281285800609, 0.9506625439425702], 
             UndirectedEdge[217, 364] -> 
             RGBColor[
              0.9053733542786032, 0.5622322721281416, 0.3258032886328436], 
             UndirectedEdge[83, 120] -> 
             RGBColor[
              0.7316668327109251, 0.7891725193318362, 0.9665740024152043], 
             UndirectedEdge[251, 380] -> 
             RGBColor[
              0.20519908617390886`, 0.3330076283152506, 0.9349971564415356], 
             UndirectedEdge[209, 390] -> 
             RGBColor[
              0.2987767120225358, 0.42895084624860025`, 0.9404146082252327], 
             UndirectedEdge[149, 315] -> 
             RGBColor[
              0.21772472600366666`, 0.3461728699477604, 0.9357104730998167], 
             UndirectedEdge[34, 263] -> 
             RGBColor[
              0.3276003815122878, 0.45396612776116196`, 0.9422494083788064], 
             UndirectedEdge[327, 376] -> 
             RGBColor[
              0.2026044968471712, 0.33028055042638454`, 0.9348493984177288], 
             UndirectedEdge[113, 316] -> 
             RGBColor[
              0.2709397029977173, 0.40210518479292345`, 0.9387409873151243], 
             UndirectedEdge[85, 307] -> 
             RGBColor[
              0.294549891018896, 0.4232589122924366, 0.9402196391759287], 
             UndirectedEdge[140, 257] -> 
             RGBColor[
              0.2744017745717613, 0.404416509747592, 0.9389867546110457], 
             UndirectedEdge[228, 330] -> 
             RGBColor[
              0.1947627843493959, 0.3220384133979338, 0.9344028244917546], 
             UndirectedEdge[22, 96] -> 
             RGBColor[
              0.5322372446835262, 0.6257908335621027, 0.9584554594663912], 
             UndirectedEdge[22, 323] -> 
             RGBColor[
              0.35748321527472365`, 0.48405572626730053`, 0.943999492260678], 
             UndirectedEdge[167, 269] -> 
             RGBColor[
              0.5269179419290838, 0.6213796361571894, 0.958033512915055], 
             UndirectedEdge[85, 214] -> 
             RGBColor[
              0.2402451657445982, 0.3698432799938294, 0.9369929788270578], 
             UndirectedEdge[89, 155] -> 
             RGBColor[
              0.19816316122321598`, 0.3256124250886648, 0.9345964709243118], 
             UndirectedEdge[1, 396] -> 
             RGBColor[
              0.1965523248147455, 0.3239193338904351, 0.9345047361738683], 
             UndirectedEdge[172, 208] -> 
             RGBColor[
              0.9084092508392714, 0.5876736275457447, 0.4679228968183917], 
             UndirectedEdge[45, 339] -> 
             RGBColor[
              0.26817858765203434`, 0.39920307749978645`, 0.9385837458808918],
              UndirectedEdge[250, 363] -> 
             RGBColor[
              0.2391241828797345, 0.3686650559284389, 0.9369291405112493], 
             UndirectedEdge[167, 222] -> 
             RGBColor[
              0.2713202012615644, 0.4023656525144891, 0.9387677624449977], 
             UndirectedEdge[73, 208] -> 
             RGBColor[
              0.9618152962983195, 0.8769997675618114, 0.5142240753361885], 
             UndirectedEdge[14, 317] -> 
             RGBColor[
              0.18995153056345765`, 0.3169814806178038, 0.9341288307062575], 
             UndirectedEdge[157, 334] -> 
             RGBColor[
              0.1861875662547559, 0.3130253154802374, 0.9339144785071631], 
             UndirectedEdge[107, 190] -> 
             RGBColor[
              0.6524189980541504, 0.7216233648288316, 0.9512140557147148], 
             UndirectedEdge[12, 209] -> 
             RGBColor[
              0.3216593094784126, 0.45300190701520204`, 0.9417177382985756], 
             UndirectedEdge[185, 219] -> 
             RGBColor[
              0.36836286362019555`, 0.4934791308371227, 0.9446927338327562], 
             UndirectedEdge[318, 345] -> 
             RGBColor[
              0.18668882027855277`, 0.3135521652405886, 0.9339430241822795], 
             UndirectedEdge[36, 383] -> 
             RGBColor[
              0.20061589185273376`, 0.3281904004923918, 0.9347361503051731], 
             UndirectedEdge[24, 357] -> 
             RGBColor[
              0.8389436700878857, 0.3003436902863443, 0.184925808497731], 
             UndirectedEdge[344, 354] -> 
             RGBColor[
              0.2035510812828702, 0.3312754706852238, 0.9349033050009957], 
             UndirectedEdge[7, 194] -> 
             RGBColor[
              0.7215884971461117, 0.7768639400824314, 0.7979961077324451], 
             UndirectedEdge[97, 248] -> 
             RGBColor[
              0.2054442201466507, 0.3332652796629938, 0.9350111164586401], 
             UndirectedEdge[14, 129] -> 
             RGBColor[
              0.18681866782962492`, 0.3136886432495756, 0.9339504188082208], 
             UndirectedEdge[160, 307] -> 
             RGBColor[
              0.403988994027505, 0.524165485775675, 0.9470101048053469], 
             UndirectedEdge[165, 400] -> 
             RGBColor[
              0.873464012393198, 0.6536035645465732, 0.5928491209890607], 
             UndirectedEdge[310, 323] -> 
             RGBColor[
              0.33914507736848765`, 0.46547732189212476`, 0.9429296732937578],
              UndirectedEdge[309, 339] -> 
             RGBColor[
              0.27457216058382816`, 0.4059231280270391, 0.9389478504009139], 
             UndirectedEdge[355, 395] -> 
             RGBColor[
              0.6171730285902994, 0.6981983576754478, 0.9642971542356892], 
             UndirectedEdge[32, 240] -> 
             RGBColor[
              0.8943605848806221, 0.5556511737673611, 0.23277873743991706`], 
             UndirectedEdge[66, 322] -> 
             RGBColor[
              0.2070879506142999, 0.33499294460302415`, 0.9351047244770914], 
             UndirectedEdge[28, 267] -> 
             RGBColor[
              0.23148773999796957`, 0.36063867028126045`, 0.9364942563862377],
              UndirectedEdge[51, 102] -> 
             RGBColor[
              0.32952467941339164`, 0.45694789679919157`, 0.9423238729229517],
              UndirectedEdge[244, 321] -> 
             RGBColor[
              0.7545634824664897, 0.8074397031821838, 0.959757518581915], 
             UndirectedEdge[140, 309] -> 
             RGBColor[
              0.2616478487840542, 0.3923388568767794, 0.9382118299637227], 
             UndirectedEdge[12, 324] -> 
             RGBColor[
              0.4708028735942141, 0.577300258720949, 0.9525700303913813], 
             UndirectedEdge[130, 287] -> 
             RGBColor[
              0.1859722872961475, 0.31279904364526556`, 0.9339022186889471], 
             UndirectedEdge[267, 367] -> 
             RGBColor[
              0.315534462322565, 0.44284387318578267`, 0.9415051605226336], 
             UndirectedEdge[138, 229] -> 
             RGBColor[
              0.19456770903936127`, 0.32183337687859837`, 0.9343917152414362],
              UndirectedEdge[97, 193] -> 
             RGBColor[
              0.1899172543843397, 0.31694545418031556`, 0.9341268787285638], 
             UndirectedEdge[248, 340] -> 
             RGBColor[
              0.2104667967928659, 0.33854432616791813`, 0.9352971447684058], 
             UndirectedEdge[162, 248] -> 
             RGBColor[
              0.24516386461647438`, 0.3750131443716921, 0.9372730914512483], 
             UndirectedEdge[127, 317] -> 
             RGBColor[
              0.19507910076484197`, 0.32237088200618674`, 0.9344208382436661],
              UndirectedEdge[269, 355] -> 
             RGBColor[
              0.7546443194902623, 0.8082531449858283, 0.9761795512808198], 
             UndirectedEdge[161, 184] -> 
             RGBColor[
              0.19128276610466352`, 0.31838069357681953`, 0.9342046426009427],
              UndirectedEdge[340, 360] -> 
             RGBColor[
              0.1940919893072422, 0.3213333652777681, 0.9343646237064562], 
             UndirectedEdge[19, 185] -> 
             RGBColor[
              0.330002266441723, 0.4557835793222022, 0.9424120819002554], 
             UndirectedEdge[240, 357] -> 
             RGBColor[
              0.8443947063429684, 0.3422427436022275, 0.19014572697166301`], 
             UndirectedEdge[75, 132] -> 
             RGBColor[
              0.28812004710636396`, 0.4155836677571048, 0.9398870475355221], 
             UndirectedEdge[89, 353] -> 
             RGBColor[
              0.18963294311823536`, 0.31664662501326446`, 0.93411068762256], 
             UndirectedEdge[214, 312] -> 
             RGBColor[
              0.2713270321361526, 0.4025122922755047, 0.9387630451365561], 
             UndirectedEdge[119, 129] -> 
             RGBColor[
              0.18575214150891103`, 0.312567656464831, 0.9338896817120405], 
             UndirectedEdge[143, 377] -> 
             RGBColor[
              0.1848896476706373, 0.3116611207555374, 0.933840563963896], 
             UndirectedEdge[5, 122] -> 
             RGBColor[
              0.440201175363544, 0.5493422068445898, 0.9504444277972779], 
             UndirectedEdge[42, 318] -> 
             RGBColor[
              0.2054522043558168, 0.33327367157305554`, 0.9350115711475404], 
             UndirectedEdge[6, 137] -> 
             RGBColor[
              0.32002599977803325`, 0.451320237982877, 0.941623440630758], 
             UndirectedEdge[113, 149] -> 
             RGBColor[
              0.26206453775242544`, 0.39277682340214404`, 0.9382355597840353],
              UndirectedEdge[67, 124] -> 
             RGBColor[
              0.3674760832994186, 0.49271104629414053`, 0.9446362289748654], 
             UndirectedEdge[141, 337] -> 
             RGBColor[
              0.9298221770988357, 0.7361333470484221, 0.40148742427443984`], 
             UndirectedEdge[63, 224] -> 
             RGBColor[
              0.1802578853175729, 0.30679284485177194`, 0.9335767919499673], 
             UndirectedEdge[244, 357] -> 
             RGBColor[
              0.9059329560446046, 0.7028448327231054, 0.5818836591998524], 
             UndirectedEdge[9, 192] -> 
             RGBColor[
              0.1863278971063823, 0.3131728121027866, 0.9339224701415624], 
             UndirectedEdge[46, 369] -> 
             RGBColor[
              0.19594555683555187`, 0.3232815822729907, 0.934470181635086], 
             UndirectedEdge[350, 392] -> 
             RGBColor[
              0.9924671913475096, 0.9911530042849124, 0.7745016638630496], 
             UndirectedEdge[275, 339] -> 
             RGBColor[
              0.24514905354352745`, 0.3749975769949486, 0.9372722479825549], 
             UndirectedEdge[119, 127] -> 
             RGBColor[
              0.18861006279746526`, 0.31557151294177693`, 0.9340524361015079],
              UndirectedEdge[152, 398] -> 
             RGBColor[
              0.3414317727237982, 0.4653471726445155, 0.943152665123154], 
             UndirectedEdge[105, 229] -> 
             RGBColor[
              0.20817939443044792`, 0.33614012125533055`, 0.9351668805877746],
              UndirectedEdge[181, 365] -> 
             RGBColor[
              0.1879270858801807, 0.3148536608984732, 0.9340135415764423], 
             UndirectedEdge[24, 285] -> 
             RGBColor[
              0.9074929446583304, 0.5753915383194507, 0.38875906329594523`], 
             UndirectedEdge[167, 189] -> 
             RGBColor[
              0.2884488073307313, 0.4203689035095335, 0.9397432112211349], 
             UndirectedEdge[157, 191] -> 
             RGBColor[
              0.1973089788218841, 0.3247146252265727, 0.9345478265002056], 
             UndirectedEdge[78, 194] -> 
             RGBColor[
              0.9072346231009216, 0.5724833285992563, 0.40645475392950137`], 
             UndirectedEdge[107, 268] -> 
             RGBColor[
              0.5139907876886572, 0.6129102178843966, 0.9560554271690249], 
             UndirectedEdge[5, 274] -> 
             RGBColor[
              0.38775900825169696`, 0.5067672930904867, 0.9463159883002454], 
             UndirectedEdge[12, 118] -> 
             RGBColor[
              0.27367870261090094`, 0.4049840470489852, 0.9388969692911083], 
             UndirectedEdge[20, 291] -> 
             RGBColor[
              0.18873168488737596`, 0.31569934546955897`, 0.9340593622996046],
              UndirectedEdge[6, 379] -> 
             RGBColor[
              0.25634517615934155`, 0.38676541173934353`, 0.9379098506023464],
              UndirectedEdge[97, 181] -> 
             RGBColor[
              0.19390662933890207`, 0.32113854019854193`, 0.9343540677304747],
              UndirectedEdge[39, 320] -> 
             RGBColor[
              0.18948414481075992`, 0.3164902285577502, 0.9341022137790767], 
             UndirectedEdge[202, 218] -> 
             RGBColor[
              0.2171099632633392, 0.3455267153294672, 0.9356754632712151], 
             UndirectedEdge[61, 344] -> 
             RGBColor[
              0.20030701799861927`, 0.32786575448798405`, 0.9347185603961192],
              UndirectedEdge[181, 214] -> 
             RGBColor[
              0.21733436721625865`, 0.34576257811201794`, 0.9356882427443579],
              UndirectedEdge[274, 324] -> 
             RGBColor[
              0.5631040589260905, 0.6561922684417929, 0.9587487607182468], 
             UndirectedEdge[62, 231] -> 
             RGBColor[
              0.19164937615014635`, 0.31876602397904136`, 0.934225520500682], 
             UndirectedEdge[117, 289] -> 
             RGBColor[
              0.20615434433043495`, 0.33401166520462483`, 0.935051556980372], 
             UndirectedEdge[14, 396] -> 
             RGBColor[
              0.19205343988410067`, 0.31919072058254777`, 0.9342485313325719],
              UndirectedEdge[79, 175] -> 
             RGBColor[
              0.2563476435480917, 0.3867680051213614, 0.9379099911164857], 
             UndirectedEdge[246, 395] -> 
             RGBColor[
              0.6944421379403393, 0.7593719483680503, 0.9717835682731306], 
             UndirectedEdge[87, 396] -> 
             RGBColor[
              0.198868412851103, 0.3263536892651099, 0.9346366339611938], 
             UndirectedEdge[341, 366] -> 
             RGBColor[
              0.36531722643847, 0.49084115298848774`, 0.9444986685246879], 
             UndirectedEdge[40, 226] -> 
             RGBColor[
              0.48315013418370223`, 0.5910627432060597, 0.9525150956533707], 
             UndirectedEdge[67, 316] -> 
             RGBColor[
              0.32978816517065423`, 0.4531895985227258, 0.9424866278961124], 
             UndirectedEdge[303, 376] -> 
             RGBColor[
              0.21141869489039777`, 0.33954483142224945`, 0.9353513539568531],
              UndirectedEdge[208, 357] -> 
             RGBColor[
              0.9250578823512863, 0.7156423048239384, 0.4838656451562371], 
             UndirectedEdge[54, 66] -> 
             RGBColor[
              0.19944158418676777`, 0.3269561286800552, 0.9346692752208288], 
             UndirectedEdge[3, 160] -> 
             RGBColor[
              0.5207461823507223, 0.6218042360373149, 0.9554141935122193], 
             UndirectedEdge[230, 328] -> 
             RGBColor[
              0.8436345364621675, 0.31890075612792645`, 0.1887325709247331], 
             UndirectedEdge[282, 383] -> 
             RGBColor[
              0.23774824777614534`, 0.3672188608952424, 0.9368507830426136], 
             UndirectedEdge[106, 150] -> 
             RGBColor[
              0.2101822963835033, 0.33824529819931026`, 0.9352809428909732], 
             UndirectedEdge[1, 298] -> 
             RGBColor[
              0.19527223087889906`, 0.32257387400121723`, 0.9344318367179512],
              UndirectedEdge[66, 131] -> 
             RGBColor[
              0.2137636212718384, 0.34200949772606326`, 0.9354848940452685], 
             UndirectedEdge[53, 126] -> 
             RGBColor[
              0.1894916420221746, 0.31649810860229766`, 0.9341026407341755], 
             UndirectedEdge[182, 281] -> 
             RGBColor[
              0.38860982761707186`, 0.5110160334092172, 0.94598285247495], 
             UndirectedEdge[74, 263] -> 
             RGBColor[
              0.627506347078178, 0.7037780429959705, 0.9664982429670084], 
             UndirectedEdge[24, 243] -> 
             RGBColor[
              0.8951565236421906, 0.5687878448594291, 0.5520035990795774], 
             UndirectedEdge[177, 252] -> 
             RGBColor[
              0.6322093663988135, 0.7067582685174405, 0.9673012182198607], 
             UndirectedEdge[10, 216] -> 
             RGBColor[
              0.21860581417743288`, 0.3470989494826055, 0.9357606497678597], 
             UndirectedEdge[280, 339] -> 
             RGBColor[
              0.2515419198726136, 0.3817168848379542, 0.9376363122625981], 
             UndirectedEdge[152, 154] -> 
             RGBColor[
              0.23114091709829876`, 0.3602741374238645, 0.93647450533518], 
             UndirectedEdge[36, 304] -> 
             RGBColor[
              0.18688421139568462`, 0.3137575336932065, 0.933954151417345], 
             UndirectedEdge[128, 299] -> 
             RGBColor[
              0.19113698074466645`, 0.31822746392013684`, 0.934196340340361], 
             UndirectedEdge[95, 162] -> 
             RGBColor[
              0.41586939242453425`, 0.5283792415607237, 0.9486390212485251], 
             UndirectedEdge[215, 329] -> 
             RGBColor[
              0.1867198905000643, 0.313584822013363, 0.9339447935854304], 
             UndirectedEdge[208, 387] -> 
             RGBColor[
              0.7635706581669874, 0.8120231295414462, 0.8609429981480392], 
             UndirectedEdge[178, 197] -> 
             RGBColor[
              0.7030008791274289, 0.7649478943931832, 0.947330285544383], 
             UndirectedEdge[53, 303] -> 
             RGBColor[
              0.20281627238444755`, 0.3305031399434066, 0.9348614587212829], 
             UndirectedEdge[59, 121] -> 
             RGBColor[
              0.3287091584623374, 0.4591330844825578, 0.9421660348044922], 
             UndirectedEdge[134, 269] -> 
             RGBColor[
              0.7872748442941331, 0.8338331400434145, 0.9794082972749127], 
             UndirectedEdge[44, 362] -> 
             RGBColor[
              0.21291981933663207`, 0.3411226083920287, 0.9354368407733515], 
             UndirectedEdge[284, 338] -> 
             RGBColor[
              0.2553995027309328, 0.3857714490069275, 0.9378559958995971], 
             UndirectedEdge[12, 346] -> 
             RGBColor[
              0.329771268632467, 0.46002807831552184`, 0.9422346251627481], 
             UndirectedEdge[113, 387] -> 
             RGBColor[
              0.4208258242811829, 0.5366129491256768, 0.9486460027249637], 
             UndirectedEdge[55, 400] -> 
             RGBColor[
              0.9109049028745734, 0.6513336536973703, 0.2699888799203509], 
             UndirectedEdge[25, 201] -> 
             RGBColor[
              0.8831813824108397, 0.5478222518769809, 0.567678897014493], 
             UndirectedEdge[123, 309] -> 
             RGBColor[
              0.2546471876156135, 0.3849807181211936, 0.93781315266673], 
             UndirectedEdge[35, 162] -> 
             RGBColor[
              0.25429020183451534`, 0.3846055034310536, 0.9377928228546097], 
             UndirectedEdge[73, 172] -> 
             RGBColor[
              0.8772092716527284, 0.4732937439467283, 0.21672848084375096`], 
             UndirectedEdge[137, 282] -> 
             RGBColor[
              0.3008030444529849, 0.4311156931304887, 0.9405287217628104], 
             UndirectedEdge[37, 114] -> 
             RGBColor[
              0.2950446149939596, 0.4237378370222073, 0.9402493164383834], 
             UndirectedEdge[214, 248] -> 
             RGBColor[
              0.22887195802400728`, 0.3578893175764699, 0.9363452914725232], 
             UndirectedEdge[161, 363] -> 
             RGBColor[
              0.20967797684249928`, 0.3377152263860093, 0.9352522226391868], 
             UndirectedEdge[51, 84] -> 
             RGBColor[
              0.36020789306278994`, 0.48641570522103605`, 0.9441731063199956],
              UndirectedEdge[56, 278] -> 
             RGBColor[
              0.3199081459581343, 0.44683361246279085`, 0.9417764708138758], 
             UndirectedEdge[4, 140] -> 
             RGBColor[
              0.22925899781803233`, 0.3582961209397305, 0.9363673328162189], 
             UndirectedEdge[221, 351] -> 
             RGBColor[
              0.9060488999462345, 0.7900961921894157, 0.6157268873569864], 
             UndirectedEdge[54, 204] -> 
             RGBColor[
              0.18912347164523904`, 0.31611113819278824`, 0.9340816739758684],
              UndirectedEdge[10, 298] -> 
             RGBColor[
              0.21724932645694042`, 0.3456731948820789, 0.9356833997989213], 
             UndirectedEdge[134, 226] -> 
             RGBColor[
              0.6381042655490734, 0.7140610165668736, 0.9666654902064342], 
             UndirectedEdge[35, 98] -> 
             RGBColor[
              0.21863346925867172`, 0.3471280167264209, 0.9357622246838242], 
             UndirectedEdge[70, 180] -> 
             RGBColor[
              0.24072957206270523`, 0.3703524217472943, 0.9370205650502591], 
             UndirectedEdge[165, 328] -> 
             RGBColor[
              0.8831401501680374, 0.7104796109326978, 0.6014297849392954], 
             UndirectedEdge[162, 214] -> 
             RGBColor[
              0.25603696286442035`, 0.3864414600245297, 0.9378922983111614], 
             UndirectedEdge[211, 370] -> 
             RGBColor[
              0.20448863330117922`, 0.3322608973006979, 0.9349566972014545], 
             UndirectedEdge[55, 245] -> 
             RGBColor[
              0.8952306902685789, 0.5308547871239369, 0.2549792362273595], 
             UndirectedEdge[247, 315] -> 
             RGBColor[
              0.2082369879918481, 0.3362006557400048, 0.9351701604558942], 
             UndirectedEdge[16, 268] -> 
             RGBColor[
              0.49856920010276634`, 0.5995528138290274, 0.9550727772448264], 
             UndirectedEdge[154, 291] -> 
             RGBColor[
              0.1963438417799771, 0.3237002050023056, 0.9344928633734613], 
             UndirectedEdge[296, 373] -> 
             RGBColor[
              0.25840585650162723`, 0.38893131743376574`, 0.9380272032993362],
              UndirectedEdge[101, 394] -> 
             RGBColor[
              0.18176625720560394`, 0.308378239342394, 0.9336626914975545], 
             UndirectedEdge[173, 388] -> 
             RGBColor[
              0.2509970167086373, 0.38114415706375904`, 0.9376052808335218], 
             UndirectedEdge[84, 102] -> 
             RGBColor[
              0.3081546083900806, 0.43843821536979977`, 0.9409621908941581], 
             UndirectedEdge[216, 298] -> 
             RGBColor[
              0.19835416070020614`, 0.3258131776490477, 0.9346073480619681], 
             UndirectedEdge[209, 310] -> 
             RGBColor[
              0.30722079620017617`, 0.4378261141051596, 0.9408954863272463], 
             UndirectedEdge[34, 93] -> 
             RGBColor[
              0.24878417747359188`, 0.37881832272561544`, 0.9374792629126882],
              UndirectedEdge[112, 285] -> 
             RGBColor[
              0.9656534548794817, 0.8891806763774219, 0.4391165147700274], 
             UndirectedEdge[131, 309] -> 
             RGBColor[
              0.255426495168577, 0.38579981977031097`, 0.9378575330789891], 
             UndirectedEdge[116, 265] -> 
             RGBColor[
              0.18666044049465552`, 0.3135223362883303, 0.9339414079955707], 
             UndirectedEdge[49, 129] -> 
             RGBColor[
              0.18838308614561955`, 0.31533294608953616`, 0.9340395101169672],
              UndirectedEdge[238, 325] -> 
             RGBColor[
              0.28956065239162987`, 0.42167698324230746`, 0.9398014228358818],
              UndirectedEdge[112, 399] -> 
             RGBColor[
              0.9318419668775375, 0.7674831415272341, 0.2640166505562497], 
             UndirectedEdge[186, 322] -> 
             RGBColor[
              0.20337835674212623`, 0.3310939262415335, 0.9348934685939234], 
             UndirectedEdge[180, 332] -> 
             RGBColor[
              0.2434440031568898, 0.373205460932154, 0.937175147885432], 
             UndirectedEdge[60, 331] -> 
             RGBColor[
              0.19257622837931382`, 0.31974020443772183`, 0.9342783033639781],
              UndirectedEdge[14, 126] -> 
             RGBColor[
              0.18556762080960376`, 0.31237371351057097`, 0.9338791735311889],
              UndirectedEdge[275, 288] -> 
             RGBColor[
              0.2720607570835225, 0.40328348371603906`, 0.9388048296868601], 
             UndirectedEdge[276, 290] -> 
             RGBColor[
              0.21053718403849497`, 0.33861830762588346`, 0.9353011532179156],
              UndirectedEdge[18, 232] -> 
             RGBColor[
              0.4501165590628717, 0.5589054128143358, 0.9510872394181826], 
             UndirectedEdge[4, 325] -> 
             RGBColor[
              0.26097898271890796`, 0.39163583623375275`, 0.9381737390308114],
              UndirectedEdge[1, 62] -> 
             RGBColor[
              0.19732629313580521`, 0.3247328236682947, 0.9345488125247692], 
             UndirectedEdge[20, 304] -> 
             RGBColor[
              0.185589373288035, 0.312396576744589, 0.9338804123026556], 
             UndirectedEdge[255, 328] -> 
             RGBColor[
              0.8524460760036836, 0.3866301102852666, 0.1971705111408994], 
             UndirectedEdge[3, 74] -> 
             RGBColor[
              0.7224644673916434, 0.782535536200579, 0.9735133143364585], 
             UndirectedEdge[18, 279] -> 
             RGBColor[
              0.638687245246097, 0.7170964540862654, 0.9650118438159424], 
             UndirectedEdge[163, 226] -> 
             RGBColor[
              0.35601753306005335`, 0.4789075435482711, 0.944048117850775], 
             UndirectedEdge[145, 254] -> 
             RGBColor[
              0.19225246823374995`, 0.31939991199715534`, 0.9342598657026484],
              UndirectedEdge[23, 348] -> 
             RGBColor[
              0.3130979265677895, 0.44416079144735543`, 0.9412244155321879], 
             UndirectedEdge[119, 396] -> 
             RGBColor[
              0.19098691356338682`, 0.3180697337978031, 0.9341877942363916], 
             UndirectedEdge[73, 141] -> 
             RGBColor[
              0.898106425922933, 0.622605752165564, 0.23629664332441563`], 
             UndirectedEdge[29, 396] -> 
             RGBColor[
              0.19049809514878532`, 0.31755595465117936`, 0.9341599567508221],
              UndirectedEdge[160, 312] -> 
             RGBColor[
              0.38126624461740655`, 0.5039445125232649, 0.9455819912605958], 
             UndirectedEdge[210, 397] -> 
             RGBColor[
              0.25928855226930214`, 0.38985908665173613`, 0.938077471517474], 
             UndirectedEdge[11, 86] -> 
             RGBColor[
              0.361493667794528, 0.48752937866875046`, 0.9442550347489361], 
             UndirectedEdge[113, 315] -> 
             RGBColor[
              0.26318579596449465`, 0.3939553368749055, 0.9382994137804598], 
             UndirectedEdge[120, 160] -> 
             RGBColor[
              0.48896132780643076`, 0.5959998592268796, 0.9529119733307341], 
             UndirectedEdge[5, 308] -> 
             RGBColor[
              0.24197001296398313`, 0.37165620378303305`, 0.9370912063245189],
              UndirectedEdge[37, 261] -> 
             RGBColor[
              0.30438433219243016`, 0.43355447197007246`, 0.940781199515963], 
             UndirectedEdge[22, 241] -> 
             RGBColor[
              0.28974430117812966`, 0.42117386849154814`, 0.9398373705045929],
              UndirectedEdge[55, 165] -> 
             RGBColor[
              0.9341904345376686, 0.918237850236102, 0.6671537250527897], 
             UndirectedEdge[251, 283] -> 
             RGBColor[
              0.19962713488925782`, 0.32715115423296626`, 0.934679842058838], 
             UndirectedEdge[334, 365] -> 
             RGBColor[
              0.18295572293696874`, 0.30962844324254163`, 0.933730429811299], 
             UndirectedEdge[44, 358] -> 
             RGBColor[
              0.21372519899594036`, 0.3419691134779814, 0.9354827059534967], 
             UndirectedEdge[225, 367] -> 
             RGBColor[
              0.6298962166593582, 0.7051035104774022, 0.9669932656124167], 
             UndirectedEdge[23, 321] -> 
             RGBColor[
              0.42370887427578074`, 0.5372228658179581, 0.9490305036181749], 
             UndirectedEdge[234, 269] -> 
             RGBColor[
              0.7646521215423732, 0.8160713160110501, 0.9771770354611466], 
             UndirectedEdge[21, 208] -> 
             RGBColor[
              0.9781086897296334, 0.9394569243444684, 0.5384830216306559], 
             UndirectedEdge[208, 240] -> 
             RGBColor[
              0.9123520994765446, 0.6179800899391169, 0.47169857312625524`], 
             UndirectedEdge[15, 313] -> 
             RGBColor[
              0.25209641053026927`, 0.3822996896758886, 0.9376678896852563], 
             UndirectedEdge[63, 204] -> 
             RGBColor[
              0.18740799960939158`, 0.3143080683159034, 0.9339839803812403], 
             UndirectedEdge[241, 310] -> 
             RGBColor[
              0.2714061632718937, 0.40259546411637237`, 0.9387675515376726], 
             UndirectedEdge[182, 256] -> 
             RGBColor[
              0.34992025301800456`, 0.4775050684860661, 0.9435175869933449], 
             UndirectedEdge[373, 380] -> 
             RGBColor[
              0.24598769620290184`, 0.37587904360296687`, 0.9373200074413457],
              UndirectedEdge[185, 210] -> 
             RGBColor[
              0.35262704416750634`, 0.4795636552057607, 0.9437005295213796], 
             UndirectedEdge[96, 223] -> 
             RGBColor[
              0.8390506368021915, 0.7815052608012159, 0.618996491222558], 
             UndirectedEdge[103, 222] -> 
             RGBColor[
              0.21336670811641717`, 0.34159231683396796`, 0.9354622904282476],
              UndirectedEdge[146, 375] -> 
             RGBColor[
              0.18336952246536248`, 0.3100633727832889, 0.9337539950822794], 
             UndirectedEdge[42, 276] -> 
             RGBColor[
              0.2196855450649306, 0.3482338151042579, 0.9358221388445839], 
             UndirectedEdge[46, 372] -> 
             RGBColor[
              0.19768089456011895`, 0.32510553224827726`, 0.934569006551298], 
             UndirectedEdge[95, 285] -> 
             RGBColor[
              0.7768044768753901, 0.8215969254274786, 0.7842186264026185], 
             UndirectedEdge[14, 326] -> 
             RGBColor[
              0.18828033718868842`, 0.3152249504211414, 0.9340336587158735], 
             UndirectedEdge[22, 310] -> 
             RGBColor[
              0.2979372274212155, 0.4297851534345578, 0.9403039455337885], 
             UndirectedEdge[23, 229] -> 
             RGBColor[
              0.24996961512608984`, 0.38006429285947896`, 0.9375467718333002],
              UndirectedEdge[23, 160] -> 
             RGBColor[
              0.3763398438622711, 0.4987665529777692, 0.9453014400255476], 
             UndirectedEdge[165, 311] -> 
             RGBColor[
              0.5997467789297788, 0.6780206465223158, 0.965283080943369], 
             UndirectedEdge[179, 288] -> 
             RGBColor[
              0.3796596294696894, 0.502934688841232, 0.9454287055118813], 
             UndirectedEdge[51, 167] -> 
             RGBColor[
              0.3459161722681373, 0.47403693499148125`, 0.9432624505086329], 
             UndirectedEdge[310, 346] -> 
             RGBColor[
              0.31533275535423055`, 0.4448522854054794, 0.9414123731914188], 
             UndirectedEdge[79, 379] -> 
             RGBColor[
              0.21907288200889707`, 0.34758986738728526`, 0.9357872485898966],
              UndirectedEdge[78, 264] -> 
             RGBColor[
              0.7716146222869605, 0.4690073780170669, 0.569890082784954], 
             UndirectedEdge[309, 325] -> 
             RGBColor[
              0.2933678336849298, 0.42567857217080163`, 0.9400182361783151], 
             UndirectedEdge[149, 358] -> 
             RGBColor[
              0.20368965097586314`, 0.3314211162183854, 0.9349111963400162], 
             UndirectedEdge[6, 79] -> 
             RGBColor[
              0.26831622286540857`, 0.39934774083561936`, 0.9385915840026804],
              UndirectedEdge[134, 234] -> 
             RGBColor[
              0.8083454624285121, 0.8502936670726204, 0.9815084195744261], 
             UndirectedEdge[96, 209] -> 
             RGBColor[
              0.5415208134624869, 0.6338317942327045, 0.9590470002598491], 
             UndirectedEdge[216, 393] -> 
             RGBColor[
              0.19153695040893678`, 0.31864785739682644`, 0.9342191180210391],
              UndirectedEdge[164, 388] -> 
             RGBColor[
              0.21023340989613648`, 0.33829902174187165`, 0.935283853729902], 
             UndirectedEdge[155, 261] -> 
             RGBColor[
              0.23352567596023666`, 0.3627806701902061, 0.9366103138244327], 
             UndirectedEdge[125, 288] -> 
             RGBColor[
              0.28344153985750953`, 0.415245407994804, 0.9394529484294792], 
             UndirectedEdge[287, 384] -> 
             RGBColor[
              0.18974513703544627`, 0.3167645479337583, 0.9341170769001692], 
             UndirectedEdge[69, 320] -> 
             RGBColor[
              0.21880446674278364`, 0.34730774592408925`, 0.9357719627375762],
              UndirectedEdge[123, 339] -> 
             RGBColor[
              0.23162280417676506`, 0.3607806312967381, 0.9365019480914105], 
             UndirectedEdge[132, 202] -> 
             RGBColor[
              0.300816385571577, 0.4289283244783967, 0.9406100852285664], 
             UndirectedEdge[67, 249] -> 
             RGBColor[
              0.36714946895537004`, 0.49242814936543994`, 0.9446154173976764],
              UndirectedEdge[374, 384] -> 
             RGBColor[
              0.18988847579037965`, 0.3169152060533953, 0.934125239830212], 
             UndirectedEdge[99, 252] -> 
             RGBColor[
              0.6676015641481373, 0.7342070299092066, 0.9439106644834332], 
             UndirectedEdge[44, 65] -> 
             RGBColor[
              0.2623103948909678, 0.393035234842995, 0.9382495609843622], 
             UndirectedEdge[88, 370] -> 
             RGBColor[
              0.189278561860536, 0.3162741478423529, 0.9340905061341941], 
             UndirectedEdge[13, 275] -> 
             RGBColor[
              0.22645651195099847`, 0.3553505306056112, 0.9362077353919975], 
             UndirectedEdge[183, 269] -> 
             RGBColor[
              0.546784204528102, 0.6385867943130678, 0.9592993736008182], 
             UndirectedEdge[122, 178] -> 
             RGBColor[
              0.5198265338212547, 0.6207419031672892, 0.9554290299990101], 
             UndirectedEdge[199, 216] -> 
             RGBColor[
              0.19310022590756143`, 0.3202909590632723, 0.9343081442480269], 
             UndirectedEdge[107, 295] -> 
             RGBColor[
              0.38882676959428764`, 0.5112039376460608, 0.945996675825904], 
             UndirectedEdge[89, 171] -> 
             RGBColor[
              0.18910388505940673`, 0.3160905514492172, 0.934080558548781], 
             UndirectedEdge[18, 91] -> 
             RGBColor[
              0.5492190587011108, 0.6449197997470224, 0.9576556826381046], 
             UndirectedEdge[194, 357] -> 
             RGBColor[
              0.9258160784332223, 0.7153085367289651, 0.42424837654046466`], 
             UndirectedEdge[147, 388] -> 
             RGBColor[
              0.20149520910929605`, 0.3291146186809729, 0.9347862261221009], 
             UndirectedEdge[96, 323] -> 
             RGBColor[
              0.5734450946307983, 0.6614830020196698, 0.9610811872263605], 
             UndirectedEdge[168, 265] -> 
             RGBColor[
              0.18709388052696674`, 0.31397790924397473`, 0.9339660917641938],
              UndirectedEdge[44, 372] -> 
             RGBColor[
              0.21537145554787535`, 0.3436994334927591, 0.9355764578287111], 
             UndirectedEdge[180, 286] -> 
             RGBColor[
              0.22669434503393948`, 0.3556005082552706, 0.9362212796342286], 
             UndirectedEdge[18, 45] -> 
             RGBColor[
              0.4449748432614876, 0.5535011435034702, 0.9507944263097807], 
             UndirectedEdge[83, 217] -> 
             RGBColor[
              0.9690520396764782, 0.9730561345189551, 0.7324860448307533], 
             UndirectedEdge[137, 314] -> 
             RGBColor[
              0.28356888618805115`, 0.41300150008529746`, 0.9395472619452747],
              UndirectedEdge[205, 338] -> 
             RGBColor[
              0.292109011117009, 0.4205396174018403, 0.9400862651454345], 
             UndirectedEdge[210, 293] -> 
             RGBColor[
              0.3272740253136205, 0.45760414455430376`, 0.9420850575788042], 
             UndirectedEdge[295, 324] -> 
             RGBColor[
              0.5310822445454129, 0.6295361727227928, 0.9564100649680346], 
             UndirectedEdge[270, 346] -> 
             RGBColor[
              0.3550828331693524, 0.4819766359343405, 0.9438465420354984], 
             UndirectedEdge[26, 349] -> 
             RGBColor[
              0.19449252215171758`, 0.32175435069256086`, 0.9343874334594139],
              UndirectedEdge[27, 208] -> 
             RGBColor[
              0.9070267560487368, 0.5770471667726158, 0.46659901824567124`], 
             UndirectedEdge[139, 193] -> 
             RGBColor[
              0.18750230329400064`, 0.31440718746762647`, 0.933989350836569], 
             UndirectedEdge[5, 296] -> 
             RGBColor[
              0.26370004466317304`, 0.39449584486246725`, 0.9383286994830867],
              UndirectedEdge[42, 125] -> 
             RGBColor[
              0.23901293023950498`, 0.3685481223497329, 0.9369228048379719], 
             UndirectedEdge[12, 106] -> 
             RGBColor[
              0.2676474114572338, 0.3986447776405352, 0.9385534961824027], 
             UndirectedEdge[242, 357] -> 
             RGBColor[
              0.854686957719692, 0.4213534977770367, 0.2000015985134489], 
             UndirectedEdge[148, 279] -> 
             RGBColor[
              0.5031062098123048, 0.6037853067748751, 0.9552337277677017], 
             UndirectedEdge[292, 374] -> 
             RGBColor[
              0.19230228893935433`, 0.31945227671756077`, 0.9342627029181295],
              UndirectedEdge[195, 369] -> 
             RGBColor[
              0.19622298384464848`, 0.3235731756494396, 0.9344859806928376], 
             UndirectedEdge[50, 371] -> 
             RGBColor[
              0.1827919087042476, 0.30945626409752947`, 0.9337211008330868], 
             UndirectedEdge[29, 127] -> 
             RGBColor[
              0.18812124438286376`, 0.3150577337951532, 0.9340245986159385], 
             UndirectedEdge[87, 127] -> 
             RGBColor[
              0.19649156208518143`, 0.3238554684090837, 0.93450127582631], 
             UndirectedEdge[264, 357] -> 
             RGBColor[
              0.7901960776192611, 0.6118325861467757, 0.5876837053959174], 
             UndirectedEdge[171, 306] -> 
             RGBColor[
              0.19583756200520352`, 0.3231680728590269, 0.9344640314892618], 
             UndirectedEdge[114, 170] -> 
             RGBColor[
              0.23647751036378017`, 0.3658832353054412, 0.9367784164268669], 
             UndirectedEdge[57, 222] -> 
             RGBColor[
              0.22503342369355192`, 0.35385477461802795`, 0.9361266926210063],
              UndirectedEdge[38, 102] -> 
             RGBColor[
              0.25020060979959846`, 0.3803070829072448, 0.9375599266382304], 
             UndirectedEdge[82, 331] -> 
             RGBColor[
              0.18993705205367367`, 0.31696626278603024`, 0.9341280061765445],
              UndirectedEdge[90, 324] -> 
             RGBColor[
              0.6207541500572831, 0.7029952095291041, 0.9632871870713362], 
             UndirectedEdge[160, 341] -> 
             RGBColor[
              0.3979292657890303, 0.5189168537463054, 0.9466239842803985], 
             UndirectedEdge[15, 311] -> 
             RGBColor[
              0.2942848105043079, 0.4266423729476564, 0.940070456651633], 
             UndirectedEdge[271, 292] -> 
             RGBColor[
              0.18674265418407987`, 0.3136087480885643, 0.9339460899435592], 
             UndirectedEdge[41, 156] -> 
             RGBColor[
              0.8514284367030327, 0.5699234098578776, 0.5824732181712974], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.26166329356975937`, 0.3923550903258115, 0.9382127095214201], 
             UndirectedEdge[129, 317] -> 
             RGBColor[
              0.19222117947628775`, 0.3193670255292408, 0.9342580838541985], 
             UndirectedEdge[164, 354] -> 
             RGBColor[
              0.20840265875823133`, 0.3363747862196069, 0.9351795951609518], 
             UndirectedEdge[78, 230] -> 
             RGBColor[
              0.818837947598831, 0.14580229685169685`, 0.1656725459360465], 
             UndirectedEdge[315, 363] -> 
             RGBColor[
              0.2193734294732247, 0.3479057618281034, 0.9358043643233698], 
             UndirectedEdge[5, 121] -> 
             RGBColor[
              0.2966728547509243, 0.4289526354856623, 0.9402137650898452], 
             UndirectedEdge[43, 380] -> 
             RGBColor[
              0.2402420225431372, 0.36983997628980336`, 0.9369927998263845], 
             UndirectedEdge[135, 234] -> 
             RGBColor[
              0.8902824990453274, 0.9119541401261442, 0.8296334999422285], 
             UndirectedEdge[344, 356] -> 
             RGBColor[
              0.19312061469136133`, 0.3203123889677695, 0.9343093053591018], 
             UndirectedEdge[186, 228] -> 
             RGBColor[
              0.20522346006975262`, 0.3330332468251766, 0.934998544498846], 
             UndirectedEdge[298, 396] -> 
             RGBColor[
              0.19827776691556012`, 0.32573288293773905`, 0.9346029975489469],
              UndirectedEdge[86, 93] -> 
             RGBColor[
              0.32267144519324537`, 0.4470223501983363, 0.9420332704147207], 
             UndirectedEdge[249, 266] -> 
             RGBColor[
              0.270914372535644, 0.40204801259274037`, 0.9387406633049027], 
             UndirectedEdge[156, 364] -> 
             RGBColor[
              0.8243314936689592, 0.18802809923393973`, 0.1709331718568741], 
             UndirectedEdge[10, 311] -> 
             RGBColor[
              0.2701224968687157, 0.40124624933748154`, 0.9386944486350258], 
             UndirectedEdge[27, 73] -> 
             RGBColor[
              0.8758267768621938, 0.46266728317359945`, 0.2154046022710305], 
             UndirectedEdge[56, 213] -> 
             RGBColor[
              0.30213444608884904`, 0.4281523269825127, 0.9407642849001527], 
             UndirectedEdge[27, 243] -> 
             RGBColor[
              0.8952822164694654, 0.5697539750088114, 0.5521239626729255], 
             UndirectedEdge[109, 157] -> 
             RGBColor[
              0.18435836126610156`, 0.3111027050588667, 0.9338103079891256], 
             UndirectedEdge[12, 241] -> 
             RGBColor[
              0.28584467655013013`, 0.4177712570264148, 0.9395898035090018], 
             UndirectedEdge[192, 382] -> 
             RGBColor[
              0.18175632170203998`, 0.30836779649820095`, 0.9336621256853248],
              UndirectedEdge[140, 280] -> 
             RGBColor[
              0.2386176080728396, 0.36813261368769457`, 0.936900291825407], 
             UndirectedEdge[199, 361] -> 
             RGBColor[
              0.2020628988707439, 0.32971129661386445`, 0.9348185552141937], 
             UndirectedEdge[16, 351] -> 
             RGBColor[
              0.6137824648944775, 0.6902841557450048, 0.9663635368138602], 
             UndirectedEdge[140, 322] -> 
             RGBColor[
              0.21280212927241615`, 0.34099890867255667`, 0.9354301384983013],
              UndirectedEdge[57, 238] -> 
             RGBColor[
              0.2538315033751126, 0.3841233822670593, 0.9377667006559303], 
             UndirectedEdge[49, 127] -> 
             RGBColor[
              0.19124100743417377`, 0.3183368025664821, 0.9342022645064347], 
             UndirectedEdge[165, 182] -> 
             RGBColor[
              0.6226406331298818, 0.6984050769847048, 0.9667215385795859], 
             UndirectedEdge[253, 343] -> 
             RGBColor[
              0.18655690968294972`, 0.31341351884099494`, 0.9339355120690042],
              UndirectedEdge[104, 240] -> 
             RGBColor[
              0.825349023280818, 0.19584927771500635`, 0.17190755936232552`], 
             UndirectedEdge[312, 348] -> 
             RGBColor[
              0.31802432732292496`, 0.44933875099285125`, 0.9415049667672362],
              UndirectedEdge[242, 244] -> 
             RGBColor[
              0.9035194245465865, 0.684293372013093, 0.5795724587116564], 
             UndirectedEdge[41, 165] -> 
             RGBColor[
              0.8843102751860701, 0.9105890257431475, 0.9888274975519911], 
             UndirectedEdge[54, 297] -> 
             RGBColor[
              0.19576644813648575`, 0.3230933276741248, 0.9344599816596418], 
             UndirectedEdge[77, 145] -> 
             RGBColor[
              0.19003339190962826`, 0.3170675220829382, 0.934133492588819], 
             UndirectedEdge[69, 150] -> 
             RGBColor[
              0.217681081623926, 0.3461269969374395, 0.9357079876169566], 
             UndirectedEdge[106, 241] -> 
             RGBColor[
              0.24501597193591163`, 0.37485769978748307`, 0.9372646691818778],
              UndirectedEdge[139, 276] -> 
             RGBColor[
              0.20545840173873126`, 0.33328018541543536`, 0.9350119240793292],
              UndirectedEdge[313, 393] -> 
             RGBColor[
              0.200865233126181, 0.3284524739799347, 0.9347503499218286], 
             UndirectedEdge[209, 323] -> 
             RGBColor[
              0.36676678405368435`, 0.4920966869379023, 0.9445910330541359], 
             UndirectedEdge[8, 213] -> 
             RGBColor[
              0.230215374068607, 0.3593013330168411, 0.9364217970288573], 
             UndirectedEdge[160, 244] -> 
             RGBColor[
              0.7071944520529801, 0.7689833903419949, 0.9560284549892878], 
             UndirectedEdge[180, 284] -> 
             RGBColor[
              0.2675710150211928, 0.3985644801424423, 0.9385491455183885], 
             UndirectedEdge[24, 242] -> 
             RGBColor[
              0.8365301385898678, 0.28179222957633193`, 0.182614608009535], 
             UndirectedEdge[81, 192] -> 
             RGBColor[
              0.1805894919591846, 0.3071413844571813, 0.9335956764576392], 
             UndirectedEdge[124, 249] -> 
             RGBColor[
              0.30940302019566135`, 0.4424110778706867, 0.9409358647458874], 
             UndirectedEdge[195, 253] -> 
             RGBColor[
              0.1964706167173933, 0.3238334534995253, 0.9345000830186004], 
             UndirectedEdge[31, 81] -> 
             RGBColor[
              0.1880171511030766, 0.3149483251582018, 0.9340186706576468], 
             UndirectedEdge[172, 399] -> 
             RGBColor[
              0.8751896442741957, 0.46528659439177383`, 0.21510344124823602`],
              UndirectedEdge[124, 315] -> 
             RGBColor[
              0.2642878093777229, 0.3950226791099546, 0.9383655017096588], 
             UndirectedEdge[181, 370] -> 
             RGBColor[
              0.19100569805155482`, 0.318089477485873, 0.9341888639852036], 
             UndirectedEdge[244, 348] -> 
             RGBColor[
              0.6439525347584986, 0.7143776288115813, 0.9519514304959281], 
             UndirectedEdge[284, 367] -> 
             RGBColor[
              0.3258404306471927, 0.4536760993310988, 0.9420920701724073], 
             UndirectedEdge[148, 232] -> 
             RGBColor[
              0.3145355236290795, 0.4455942655029455, 0.9413091233699418], 
             UndirectedEdge[34, 211] -> 
             RGBColor[
              0.2425688344221679, 0.3722856031030586, 0.9371253083206856], 
             UndirectedEdge[355, 392] -> 
             RGBColor[
              0.8783955245201162, 0.9037382421614023, 0.8873541737699352], 
             UndirectedEdge[262, 338] -> 
             RGBColor[
              0.22417589206845978`, 0.35295345450941085`, 0.9360778574635618],
              UndirectedEdge[87, 119] -> 
             RGBColor[
              0.19029746556308325`, 0.3173450802359561, 0.9341485311927212], 
             UndirectedEdge[180, 367] -> 
             RGBColor[
              0.31681274319178854`, 0.44418742742702483`, 0.9415779567270888],
              UndirectedEdge[69, 380] -> 
             RGBColor[
              0.2309702581422837, 0.36009476404068996`, 0.9364647865601021], 
             UndirectedEdge[124, 338] -> 
             RGBColor[
              0.2719649687624893, 0.40309186038336303`, 0.9388027045792817], 
             UndirectedEdge[249, 293] -> 
             RGBColor[
              0.3289853537057845, 0.45937231092045516`, 0.9421836337211749], 
             UndirectedEdge[212, 373] -> 
             RGBColor[
              0.34459378761093823`, 0.4694803712160838, 0.9433030893613046], 
             UndirectedEdge[287, 292] -> 
             RGBColor[
              0.19215895018442095`, 0.31930161859792383`, 0.9342545399880867],
              UndirectedEdge[12, 323] -> 
             RGBColor[
              0.35358359064672407`, 0.4806531148021672, 0.943751925265087], 
             UndirectedEdge[120, 307] -> 
             RGBColor[
              0.43332684059947457`, 0.5479832712777266, 0.9493196875555654], 
             UndirectedEdge[99, 398] -> 
             RGBColor[
              0.695865579228825, 0.7586878991813948, 0.9457116225314874], 
             UndirectedEdge[134, 350] -> 
             RGBColor[
              0.9124093272037948, 0.929890258170909, 0.8676584254872136], 
             UndirectedEdge[45, 280] -> 
             RGBColor[
              0.26817273037966816`, 0.3991969211351571, 0.9385834123178955], 
             UndirectedEdge[188, 330] -> 
             RGBColor[
              0.19385743072413472`, 0.32108682933504906`, 0.9343512659421467],
              UndirectedEdge[236, 284] -> 
             RGBColor[
              0.26368702808225786`, 0.3944821636106265, 0.9383279582080599], 
             UndirectedEdge[374, 389] -> 
             RGBColor[
              0.19643386923101253`, 0.3237948295614139, 0.9344979903036141], 
             UndirectedEdge[278, 319] -> 
             RGBColor[
              0.35576382875700985`, 0.4778888141834562, 0.9440614916187484], 
             UndirectedEdge[78, 242] -> 
             RGBColor[
              0.8361055023873913, 0.2785282896473279, 0.1822079759024856], 
             UndirectedEdge[84, 189] -> 
             RGBColor[
              0.30274052812538393`, 0.4327476737390883, 0.9406538670324976], 
             UndirectedEdge[223, 385] -> 
             RGBColor[
              0.9621637338718393, 0.8751385282482187, 0.44853214930663265`], 
             UndirectedEdge[175, 278] -> 
             RGBColor[
              0.2699086210585896, 0.40102145230052944`, 0.93868226872404], 
             UndirectedEdge[151, 168] -> 
             RGBColor[
              0.18811217327033666`, 0.31504819948074547`, 0.9340240820294996],
              UndirectedEdge[322, 339] -> 
             RGBColor[
              0.22572644107219014`, 0.3545831798228164, 0.9361661589354925], 
             UndirectedEdge[177, 367] -> 
             RGBColor[
              0.6349673392184779, 0.7091470859540894, 0.9674769538091501], 
             UndirectedEdge[294, 320] -> 
             RGBColor[
              0.19287620932606772`, 0.32005550343265077`, 0.9342953868351136],
              UndirectedEdge[179, 279] -> 
             RGBColor[
              0.5630911384213583, 0.6557241290001397, 0.9590606413690353], 
             UndirectedEdge[18, 285] -> 
             RGBColor[
              0.7996696633612428, 0.8401599138816065, 0.7860186576407228], 
             UndirectedEdge[121, 296] -> 
             RGBColor[
              0.27793336964590865`, 0.4092562484883108, 0.9391465791356984], 
             UndirectedEdge[212, 351] -> 
             RGBColor[
              0.6635629227613954, 0.7334014863107667, 0.9695355035700097], 
             UndirectedEdge[29, 87] -> 
             RGBColor[
              0.18980864714848175`, 0.31683130108933233`, 0.9341206937071518],
              UndirectedEdge[99, 141] -> 
             RGBColor[
              0.9156172249259522, 0.7282421342221813, 0.5763077730258106], 
             UndirectedEdge[121, 274] -> 
             RGBColor[
              0.4019923332344326, 0.5215276967163304, 0.9471338679528571], 
             UndirectedEdge[138, 218] -> 
             RGBColor[
              0.18655648275495362`, 0.3134130701126022, 0.9339354877560864], 
             UndirectedEdge[61, 388] -> 
             RGBColor[
              0.2144393921406435, 0.3427197757555252, 0.9355233781965335], 
             UndirectedEdge[283, 347] -> 
             RGBColor[
              0.20341579469893528`, 0.33113327590784336`, 0.9348956006301792],
              UndirectedEdge[253, 315] -> 
             RGBColor[
              0.20496946088804507`, 0.3327662775807237, 0.9349840796212059], 
             UndirectedEdge[321, 366] -> 
             RGBColor[
              0.4743804722974104, 0.5825626858071993, 0.9522061384174323], 
             UndirectedEdge[164, 391] -> 
             RGBColor[
              0.1910397493801938, 0.3181252675912516, 0.9341908031579952], 
             UndirectedEdge[74, 91] -> 
             RGBColor[
              0.6781789401773193, 0.7465825501677249, 0.9700269954109155], 
             UndirectedEdge[91, 285] -> 
             RGBColor[
              0.7437484336984672, 0.7947605404186777, 0.7816163335954551], 
             UndirectedEdge[51, 183] -> 
             RGBColor[
              0.36578243486715545`, 0.4912440931473596, 0.9445283111943961], 
             UndirectedEdge[30, 54] -> 
             RGBColor[
              0.1824115228296057, 0.3090564544254234, 0.9336994384202565], 
             UndirectedEdge[68, 250] -> 
             RGBColor[
              0.2641868760172087, 0.3950075354824494, 0.9383564238084967], 
             UndirectedEdge[32, 230] -> 
             RGBColor[
              0.8873852814687854, 0.5020359351465393, 0.22609917901526383`], 
             UndirectedEdge[275, 318] -> 
             RGBColor[
              0.21657038683237403`, 0.3449595862894012, 0.9356447351917034], 
             UndirectedEdge[131, 186] -> 
             RGBColor[
              0.21005402739966472`, 0.3381104793645726, 0.9352736381621005], 
             UndirectedEdge[192, 292] -> 
             RGBColor[
              0.18800332047098128`, 0.31493378828695684`, 0.9340178830236096],
              UndirectedEdge[144, 200] -> 
             RGBColor[
              0.18738223875410484`, 0.31428099202366444`, 0.9339825133386415],
              UndirectedEdge[139, 318] -> 
             RGBColor[
              0.19122506102961745`, 0.318320041884233, 0.9342013563822857], 
             UndirectedEdge[93, 148] -> 
             RGBColor[
              0.2841492261294814, 0.41365634022833114`, 0.9395786686798384], 
             UndirectedEdge[92, 311] -> 
             RGBColor[
              0.40006723340595274`, 0.5191882673765618, 0.947063870354397], 
             UndirectedEdge[334, 370] -> 
             RGBColor[
              0.18603433510834283`, 0.3128642598299414, 0.93390575222006], 
             UndirectedEdge[62, 129] -> 
             RGBColor[
              0.19509705711799047`, 0.3223897552718444, 0.9344218608314138], 
             UndirectedEdge[97, 191] -> 
             RGBColor[
              0.2000566789628183, 0.32760263228894565`, 0.9347043039583738], 
             UndirectedEdge[120, 366] -> 
             RGBColor[
              0.4563492884558704, 0.567924158469062, 0.9507866575750236], 
             UndirectedEdge[91, 288] -> 
             RGBColor[
              0.3993345066316525, 0.518907640464429, 0.9469775839135208], 
             UndirectedEdge[21, 32] -> 
             RGBColor[
              0.9601171751337108, 0.8771280081727125, 0.29956318594431774`], 
             UndirectedEdge[121, 178] -> 
             RGBColor[
              0.376298213208635, 0.5003523318083618, 0.9451983672915776], 
             UndirectedEdge[294, 381] -> 
             RGBColor[
              0.19306159004241835`, 0.32025035031935156`, 0.9343059439926636],
              UndirectedEdge[46, 149] -> 
             RGBColor[
              0.20894845482391827`, 0.3369484524901131, 0.9352106774394597], 
             UndirectedEdge[66, 232] -> 
             RGBColor[
              0.25468181299552817`, 0.38501711159085983`, 0.9378151245308926],
              UndirectedEdge[114, 261] -> 
             RGBColor[
              0.25063032461803525`, 0.380758740426915, 0.9375843982614342], 
             UndirectedEdge[189, 395] -> 
             RGBColor[
              0.3676410779096787, 0.4885452690238077, 0.9449042144225828], 
             UndirectedEdge[54, 290] -> 
             RGBColor[
              0.19141480754021284`, 0.3185194774974923, 0.9342121621653594], 
             UndirectedEdge[4, 309] -> 
             RGBColor[
              0.2652076930566547, 0.39608047891444564`, 0.9384145578287296], 
             UndirectedEdge[195, 315] -> 
             RGBColor[
              0.21034714004508412`, 0.3384185593393235, 0.9352903304936357], 
             UndirectedEdge[181, 305] -> 
             RGBColor[
              0.18857843384879308`, 0.3155382689113313, 0.9340506348796719], 
             UndirectedEdge[153, 372] -> 
             RGBColor[
              0.18825648302408265`, 0.31519987818169937`, 0.9340323002564883],
              UndirectedEdge[175, 227] -> 
             RGBColor[
              0.24456047357150879`, 0.37437894212623135`, 0.9372387292238745],
              UndirectedEdge[271, 287] -> 
             RGBColor[
              0.18451611233351262`, 0.31126851143271117`, 0.9338192916790429],
              UndirectedEdge[232, 297] -> 
             RGBColor[
              0.25100667694524614`, 0.38115431058492943`, 0.9376058309697055],
              UndirectedEdge[21, 25] -> 
             RGBColor[
              0.890260551987202, 0.5108305987640545, 0.23788277597524127`], 
             UndirectedEdge[123, 297] -> 
             RGBColor[
              0.20930917766859286`, 0.3373275950710155, 0.9352312200718224], 
             UndirectedEdge[6, 178] -> 
             RGBColor[
              0.37363938184973156`, 0.4977574548464476, 0.9450396379279142], 
             UndirectedEdge[90, 319] -> 
             RGBColor[
              0.530870221387825, 0.6300233870103961, 0.956211194950797], 
             UndirectedEdge[258, 302] -> 
             RGBColor[
              0.18739149065206478`, 0.3142907163550246, 0.9339830402205433], 
             UndirectedEdge[253, 397] -> 
             RGBColor[
              0.20200814651583682`, 0.3296537484173573, 0.9348154371485806], 
             UndirectedEdge[169, 177] -> 
             RGBColor[
              0.8953206105495907, 0.9193683682944271, 0.9898776731680061], 
             UndirectedEdge[198, 332] -> 
             RGBColor[
              0.29082644977848415`, 0.41888733476416706`, 0.9400243645014585],
              UndirectedEdge[45, 123] -> 
             RGBColor[
              0.24825361468381962`, 0.37826066759394095`, 0.9374490481467079],
              UndirectedEdge[223, 245] -> 
             RGBColor[
              0.8743661025414482, 0.452767023574467, 0.2140604082418407], 
             UndirectedEdge[380, 381] -> 
             RGBColor[
              0.20814382827755723`, 0.3361027389736181, 0.9351648551479828], 
             UndirectedEdge[277, 378] -> 
             RGBColor[
              0.19931695292516527`, 0.3268251333220326, 0.934662177654856], 
             UndirectedEdge[119, 326] -> 
             RGBColor[
              0.18721381086797456`, 0.3141039636363968, 0.933972921619693], 
             UndirectedEdge[89, 133] -> 
             RGBColor[
              0.1875161010871107, 0.31442168982301577`, 0.9339901366004746], 
             UndirectedEdge[22, 346] -> 
             RGBColor[
              0.3336708932604665, 0.46343068978065516`, 0.9424821921583393], 
             UndirectedEdge[73, 243] -> 
             RGBColor[
              0.9500707567190481, 0.8697065757980069, 0.5997490197634427], 
             UndirectedEdge[26, 353] -> 
             RGBColor[
              0.1885101327336185, 0.315466480108742, 0.9340467452322052], 
             UndirectedEdge[21, 230] -> 
             RGBColor[
              0.8904702103094787, 0.5124421245019355, 0.2380835450214286], 
             UndirectedEdge[107, 390] -> 
             RGBColor[
              0.30566480118721207`, 0.43491696287761505`, 0.9408535111759078],
              UndirectedEdge[223, 364] -> 
             RGBColor[
              0.8737896349062411, 0.4483360407205369, 0.2135083821833393], 
             UndirectedEdge[2, 211] -> 
             RGBColor[
              0.2034376502421772, 0.3311562474695121, 0.9348968452710344], 
             UndirectedEdge[128, 353] -> 
             RGBColor[
              0.19231632365158768`, 0.3194670280899702, 0.9342635021742287], 
             UndirectedEdge[259, 331] -> 
             RGBColor[
              0.19269223822101744`, 0.31986213813680114`, 0.934284909952842], 
             UndirectedEdge[2, 334] -> 
             RGBColor[
              0.18498335204934083`, 0.3117596099987556, 0.93384590028964], 
             UndirectedEdge[72, 191] -> 
             RGBColor[
              0.19501894918374685`, 0.32230765888062524`, 0.934417412700109], 
             UndirectedEdge[247, 301] -> 
             RGBColor[
              0.1901623548072361, 0.317203070265044, 0.9341408368350541], 
             UndirectedEdge[247, 397] -> 
             RGBColor[
              0.20527567361963986`, 0.3330881265766384, 0.935001517983269], 
             UndirectedEdge[125, 263] -> 
             RGBColor[
              0.326732269165051, 0.4530536866427142, 0.9421999706648885], 
             UndirectedEdge[123, 325] -> 
             RGBColor[
              0.2504184772778667, 0.38053607544050067`, 0.9375723338688118], 
             UndirectedEdge[129, 393] -> 
             RGBColor[
              0.18622578456981498`, 0.3130654853525456, 0.9339166549836668], 
             UndirectedEdge[19, 205] -> 
             RGBColor[
              0.30521095643223367`, 0.4343105926394541, 0.9408324015485454], 
             UndirectedEdge[277, 352] -> 
             RGBColor[
              0.22370886564436498`, 0.3524625801265016, 0.9360512609996132], 
             UndirectedEdge[139, 224] -> 
             RGBColor[
              0.18369701044953324`, 0.3104075834185898, 0.9337726450385029], 
             UndirectedEdge[65, 250] -> 
             RGBColor[
              0.2731468584894696, 0.40442504515649597`, 0.9388666815551856], 
             UndirectedEdge[58, 117] -> 
             RGBColor[
              0.2190498578943207, 0.34756566758305235`, 0.9357859374006325], 
             UndirectedEdge[134, 272] -> 
             RGBColor[0.7859507335711424, 0.832798734683, 0.9792763222925633],
              UndirectedEdge[74, 95] -> 
             RGBColor[
              0.7112349833542422, 0.7734189351765257, 0.9726292882180788], 
             UndirectedEdge[156, 245] -> 
             RGBColor[
              0.8249079613041663, 0.19245908208786985`, 0.17148519791537548`],
              UndirectedEdge[221, 324] -> 
             RGBColor[
              0.7677190036317167, 0.6811645798747406, 0.602228741750033], 
             UndirectedEdge[227, 375] -> 
             RGBColor[
              0.1940331226429612, 0.32127149268124666`, 0.9343612713370109], 
             UndirectedEdge[132, 348] -> 
             RGBColor[
              0.34570653122762846`, 0.47385535445905747`, 0.94324909236691], 
             UndirectedEdge[137, 319] -> 
             RGBColor[
              0.3939126281591366, 0.5156078641515458, 0.9463210706392715], 
             UndirectedEdge[128, 170] -> 
             RGBColor[
              0.21313809335858236`, 0.34135202822847077`, 0.9354492711559941],
              UndirectedEdge[120, 220] -> 
             RGBColor[
              0.5770608462863022, 0.6675230171669182, 0.9598474901446392], 
             UndirectedEdge[292, 371] -> 
             RGBColor[
              0.1904665323376698, 0.31752278013549917`, 0.934158159295422], 
             UndirectedEdge[143, 378] -> 
             RGBColor[
              0.18793083673403851`, 0.31485760328369566`, 0.9340137551820207],
              UndirectedEdge[59, 373] -> 
             RGBColor[
              0.3091816453180559, 0.4388081534280127, 0.9410466589681301], 
             UndirectedEdge[2, 340] -> 
             RGBColor[
              0.19396024281710603`, 0.32119489136342505`, 0.9343571209387445],
              UndirectedEdge[131, 322] -> 
             RGBColor[
              0.206580775656939, 0.33445987156608825`, 0.9350758416135677], 
             UndirectedEdge[62, 317] -> 
             RGBColor[
              0.19822991985182326`, 0.32568259264007254`, 0.9346002727294505],
              UndirectedEdge[243, 337] -> 
             RGBColor[
              0.981786507894951, 0.983234170680865, 0.764939800713467], 
             UndirectedEdge[21, 217] -> 
             RGBColor[
              0.9781358461419554, 0.9375595363156388, 0.3992965964312667], 
             UndirectedEdge[24, 74] -> 
             RGBColor[
              0.8419234511371824, 0.5272135480684979, 0.5771697251114055], 
             UndirectedEdge[1, 127] -> 
             RGBColor[
              0.19417547404882396`, 0.3214211130344089, 0.9343693780389848], 
             UndirectedEdge[226, 355] -> 
             RGBColor[
              0.6054737407452027, 0.6884810215092875, 0.963436744212341], 
             UndirectedEdge[97, 370] -> 
             RGBColor[
              0.18998864922989284`, 0.31702049468968657`, 0.9341309445593988],
              UndirectedEdge[148, 257] -> 
             RGBColor[
              0.3285413065471964, 0.4589876995901452, 0.9421553394288851], 
             UndirectedEdge[48, 344] -> 
             RGBColor[
              0.21571874970997718`, 0.3440644616768498, 0.9355962357174672], 
             UndirectedEdge[74, 148] -> 
             RGBColor[
              0.5985191344063026, 0.6786707763192633, 0.9646512034079422], 
             UndirectedEdge[266, 293] -> 
             RGBColor[
              0.2908233203898157, 0.4192921425712095, 0.940009243857379], 
             UndirectedEdge[84, 226] -> 
             RGBColor[
              0.39203908397867687`, 0.5139862829102032, 0.9462013616579391], 
             UndirectedEdge[354, 371] -> 
             RGBColor[
              0.20120013846367035`, 0.3288044807238608, 0.9347694222853504], 
             UndirectedEdge[57, 188] -> 
             RGBColor[
              0.20973271485913975`, 0.33777275951208907`, 0.9352553398882568],
              UndirectedEdge[134, 355] -> 
             RGBColor[
              0.7983376603764013, 0.8424754960473988, 0.9805109353940992], 
             UndirectedEdge[151, 378] -> 
             RGBColor[
              0.19141895458300517`, 0.3185238363024048, 0.9342123983333115], 
             UndirectedEdge[167, 238] -> 
             RGBColor[
              0.3001182809431252, 0.43263426016352036`, 0.9404077704799216], 
             UndirectedEdge[41, 311] -> 
             RGBColor[
              0.5873075100595555, 0.6681019111801583, 0.9640966123738608], 
             UndirectedEdge[212, 295] -> 
             RGBColor[
              0.42318563987531466`, 0.5409638641564534, 0.9481859926578549], 
             UndirectedEdge[179, 285] -> 
             RGBColor[
              0.7240735565365042, 0.7787875887954807, 0.7800674551938157], 
             UndirectedEdge[85, 348] -> 
             RGBColor[
              0.28694246093137055`, 0.4166697387111759, 0.9397349004577378], 
             UndirectedEdge[108, 152] -> 
             RGBColor[
              0.2564614085339687, 0.38688757933463486`, 0.9379164698641311], 
             UndirectedEdge[86, 148] -> 
             RGBColor[
              0.37250043656006593`, 0.49706288855717573`, 0.9449563763217728],
              UndirectedEdge[113, 293] -> 
             RGBColor[
              0.32820995463660485`, 0.4585878656141067, 0.9421383573691648], 
             UndirectedEdge[229, 260] -> 
             RGBColor[
              0.21573241152320438`, 0.34407882110876054`, 0.9355970137375196],
              UndirectedEdge[6, 278] -> 
             RGBColor[
              0.28187720037590647`, 0.4136011880147874, 0.9393638616102349], 
             UndirectedEdge[142, 378] -> 
             RGBColor[
              0.18665371404405717`, 0.3135152663622699, 0.93394102493416], 
             UndirectedEdge[289, 303] -> 
             RGBColor[
              0.19970158242580874`, 0.32722940331412775`, 0.9346840817359092],
              UndirectedEdge[5, 213] -> 
             RGBColor[
              0.25252900688278906`, 0.3827543758705798, 0.9376925254075633], 
             UndirectedEdge[104, 243] -> 
             RGBColor[
              0.8942676597098645, 0.5619556471729128, 0.5511524219741538], 
             UndirectedEdge[121, 373] -> 
             RGBColor[
              0.2913786665893785, 0.4233881080569608, 0.9399122689060947], 
             UndirectedEdge[120, 202] -> 
             RGBColor[
              0.38082926485589774`, 0.49646706771580507`, 0.9461959416990309],
              UndirectedEdge[270, 351] -> 
             RGBColor[
              0.6344443344456173, 0.7081804286544429, 0.9676800928710849], 
             UndirectedEdge[91, 125] -> 
             RGBColor[
              0.37740486226419223`, 0.49585819381446866`, 0.9457287231087954],
              UndirectedEdge[280, 297] -> 
             RGBColor[
              0.22922829336444137`, 0.3582638486122316, 0.9363655842430101], 
             UndirectedEdge[33, 281] -> 
             RGBColor[
              0.3526148324525338, 0.4768614731328931, 0.9437983042422098], 
             UndirectedEdge[16, 241] -> 
             RGBColor[
              0.29049437153587576`, 0.42182354173579545`, 0.9398851643245274],
              UndirectedEdge[89, 342] -> 
             RGBColor[
              0.18647972709604152`, 0.31333239504849575`, 0.9339311166348612],
              UndirectedEdge[157, 370] -> 
             RGBColor[
              0.18724094908895864`, 0.3141324876273136, 0.9339744671012307], 
             UndirectedEdge[90, 122] -> 
             RGBColor[
              0.6031707449782447, 0.6887202091625689, 0.9619029570133792], 
             UndirectedEdge[135, 156] -> 
             RGBColor[
              0.9129140627520606, 0.6152764832633987, 0.4286476247419544], 
             UndirectedEdge[12, 22] -> 
             RGBColor[
              0.3123757406994519, 0.44496094634460026`, 0.9411261975051177], 
             UndirectedEdge[271, 384] -> 
             RGBColor[
              0.18432884103510522`, 0.31107167742439884`, 0.9338086268556416],
              UndirectedEdge[158, 324] -> 
             RGBColor[
              0.4859428845919035, 0.5904387279012617, 0.9535338248669657], 
             UndirectedEdge[301, 397] -> 
             RGBColor[
              0.19781003665891564`, 0.3252412687821946, 0.934576361002776], 
             UndirectedEdge[95, 233] -> 
             RGBColor[
              0.7594081345567827, 0.8112195509449376, 0.9560282891124947], 
             UndirectedEdge[123, 203] -> 
             RGBColor[
              0.21872743662810462`, 0.3472267823895703, 0.935767575986501], 
             UndirectedEdge[103, 145] -> 
             RGBColor[
              0.1958024601948291, 0.32313117863074003`, 0.9344620324930895], 
             UndirectedEdge[20, 80] -> 
             RGBColor[
              0.18504810846190303`, 0.31182767309415216`, 0.933849588071537], 
             UndirectedEdge[73, 337] -> 
             RGBColor[
              0.9623310682876794, 0.8761474788456531, 0.428220440311572], 
             UndirectedEdge[122, 166] -> 
             RGBColor[
              0.7938288566186125, 0.8372493846021647, 0.890969402038376], 
             UndirectedEdge[62, 216] -> 
             RGBColor[
              0.2004082229571123, 0.32797212731612524`, 0.934724323868786], 
             UndirectedEdge[128, 342] -> 
             RGBColor[
              0.18916310762939384`, 0.3161527981252015, 0.9340839311865298], 
             UndirectedEdge[280, 309] -> 
             RGBColor[
              0.27456630331146203`, 0.4059169716624097, 0.9389475168379178], 
             UndirectedEdge[104, 141] -> 
             RGBColor[
              0.8423033289137494, 0.3148548235404699, 0.18770004553512668`], 
             UndirectedEdge[148, 276] -> 
             RGBColor[
              0.27841767131860123`, 0.407632112720532, 0.9392522651124343], 
             UndirectedEdge[359, 394] -> 
             RGBColor[
              0.18381809529055626`, 0.3105348512637273, 0.9337795406410702], 
             UndirectedEdge[8, 43] -> 
             RGBColor[
              0.24908603513269617`, 0.379135594264215, 0.9374964532598158], 
             UndirectedEdge[56, 352] -> 
             RGBColor[
              0.31062641380180694`, 0.4370779234706822, 0.9412478898986653], 
             UndirectedEdge[70, 152] -> 
             RGBColor[
              0.2398425593336916, 0.3694201151292457, 0.9369700509875596], 
             UndirectedEdge[359, 397] -> 
             RGBColor[
              0.20006364261390616`, 0.32760995152775996`, 0.9347047005280014],
              UndirectedEdge[118, 241] -> 
             RGBColor[
              0.25104726308957875`, 0.38119696919593304`, 0.9376081422905835],
              UndirectedEdge[43, 227] -> 
             RGBColor[
              0.23391469744368304`, 0.36318955643469497`, 0.9366324680224093],
              UndirectedEdge[234, 246] -> 
             RGBColor[
              0.8529840469746812, 0.885887262707637, 0.9857660876177745], 
             UndirectedEdge[196, 317] -> 
             RGBColor[
              0.1925447584771704, 0.3197071275752621, 0.9342765111996065], 
             UndirectedEdge[46, 184] -> 
             RGBColor[
              0.19220194755564052`, 0.3193468115612663, 0.9342569886247687], 
             UndirectedEdge[136, 331] -> 
             RGBColor[
              0.19186850922797938`, 0.3189963467376835, 0.9342379998052863], 
             UndirectedEdge[106, 320] -> 
             RGBColor[
              0.21130568150236095`, 0.33942604718596003`, 0.9353449180115927],
              UndirectedEdge[68, 161] -> 
             RGBColor[
              0.23474066997997348`, 0.36405770594001974`, 0.9366795059364341],
              UndirectedEdge[45, 297] -> 
             RGBColor[
              0.2458649611438621, 0.37575004127406386`, 0.9373130178613036], 
             UndirectedEdge[140, 203] -> 
             RGBColor[
              0.22572809779654535`, 0.3545849211451561, 0.9361662532834936], 
             UndirectedEdge[225, 243] -> 
             RGBColor[
              0.9271182354136238, 0.9438506209861709, 0.9626670150045318], 
             UndirectedEdge[107, 373] -> 
             RGBColor[
              0.31023491732991126`, 0.43972044470569116`, 0.9411137725293536],
              UndirectedEdge[187, 321] -> 
             RGBColor[
              0.494640933100008, 0.6001112786340405, 0.9534971170641517], 
             UndirectedEdge[297, 322] -> 
             RGBColor[
              0.2034128145640179, 0.33113014359709375`, 0.9348954309159043], 
             UndirectedEdge[106, 374] -> 
             RGBColor[
              0.2085188963433679, 0.336496959291474, 0.9351862147194673], 
             UndirectedEdge[154, 383] -> 
             RGBColor[
              0.20693321063768522`, 0.33483030307652095`, 0.9350959122643404],
              UndirectedEdge[111, 151] -> 
             RGBColor[
              0.1906348725141942, 0.31769971633440997`, 0.9341677460194382], 
             UndirectedEdge[79, 227] -> 
             RGBColor[
              0.21925675873838124`, 0.34778313348843115`, 0.9357977200976195],
              UndirectedEdge[93, 290] -> 
             RGBColor[
              0.21626873884937514`, 0.3446425351336826, 0.9356275567853198], 
             UndirectedEdge[150, 283] -> 
             RGBColor[
              0.2012631111576979, 0.32887066901798323`, 0.9347730084871156], 
             UndirectedEdge[46, 195] -> 
             RGBColor[
              0.2015708688653357, 0.3291941418816762, 0.9347905348332788], 
             UndirectedEdge[73, 177] -> 
             RGBColor[
              0.912733918365472, 0.8408075046276462, 0.6264313427993702], 
             UndirectedEdge[102, 189] -> 
             RGBColor[
              0.27205731447598563`, 0.4032798653172439, 0.9388046336354536], 
             UndirectedEdge[3, 95] -> 
             RGBColor[
              0.5706393994295823, 0.6623097973257487, 0.9593419703255434], 
             UndirectedEdge[39, 294] -> 
             RGBColor[
              0.18656769797512113`, 0.31342485802008435`, 0.9339361264462835],
              UndirectedEdge[5, 227] -> 
             RGBColor[
              0.24495455926499354`, 0.3747931511765599, 0.937261171821121], 
             UndirectedEdge[166, 169] -> 
             RGBColor[
              0.9427417968791698, 0.9548740993356628, 0.9051840770091248], 
             UndirectedEdge[27, 337] -> 
             RGBColor[
              0.9075425280380967, 0.5761948780564576, 0.3805953832210548], 
             UndirectedEdge[84, 174] -> 
             RGBColor[
              0.3414171398675645, 0.4701400992540484, 0.9429757761424066], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.313125811057198, 0.4456106195888476, 0.9411739913250522], 
             UndirectedEdge[138, 349] -> 
             RGBColor[
              0.19211902352341417`, 0.31925965314570914`, 0.9342522662238085],
              UndirectedEdge[26, 159] -> 
             RGBColor[
              0.18375580691440718`, 0.3104693822310835, 0.9337759934101959], 
             UndirectedEdge[81, 287] -> 
             RGBColor[
              0.1847451216726243, 0.31150921476814825`, 0.9338323334221164], 
             UndirectedEdge[311, 361] -> 
             RGBColor[
              0.2601900040751639, 0.39080656965504246`, 0.9381288078642394], 
             UndirectedEdge[231, 393] -> 
             RGBColor[
              0.18277810360197083`, 0.30944175405974256`, 0.933720314652935], 
             UndirectedEdge[201, 223] -> 
             RGBColor[
              0.9394729571932308, 0.8606549580209606, 0.6167978110210142], 
             UndirectedEdge[180, 267] -> 
             RGBColor[
              0.25726504669656514`, 0.3877322539971262, 0.9379622358686148], 
             UndirectedEdge[217, 264] -> 
             RGBColor[
              0.8581806271651595, 0.8856725444548357, 0.7300501263511203], 
             UndirectedEdge[163, 174] -> 
             RGBColor[
              0.3053955889489409, 0.4350613598921163, 0.9408225323352425], 
             UndirectedEdge[203, 280] -> 
             RGBColor[
              0.23864655232395315`, 0.36816303593078636`, 0.9369019401576887],
              UndirectedEdge[40, 163] -> 
             RGBColor[
              0.3939273213258807, 0.5099037447255685, 0.9469719144794696], 
             UndirectedEdge[14, 62] -> 
             RGBColor[
              0.1928274082051604, 0.3200042103604074, 0.9342926076834728], 
             UndirectedEdge[49, 133] -> 
             RGBColor[
              0.18673252269027052`, 0.31359809924619686`, 0.933945512969975], 
             UndirectedEdge[276, 288] -> 
             RGBColor[
              0.2641141546829352, 0.39493110074932897`, 0.9383522824360913], 
             UndirectedEdge[312, 366] -> 
             RGBColor[
              0.3486542052668462, 0.4758688117654473, 0.9434566755048852], 
             UndirectedEdge[23, 120] -> 
             RGBColor[
              0.40567769043424073`, 0.5225843384798207, 0.9476110227757661], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.18052420551329257`, 0.307072764263149, 0.9335919584911282], 
             UndirectedEdge[73, 399] -> 
             RGBColor[
              0.9285956897332439, 0.7546127344078406, 0.2614046197660328], 
             UndirectedEdge[269, 272] -> 
             RGBColor[
              0.7422573926850033, 0.7985763836214297, 0.9749449381792838], 
             UndirectedEdge[20, 151] -> 
             RGBColor[
              0.19115376674236922`, 0.3182451070680162, 0.9341972962780976], 
             UndirectedEdge[239, 355] -> 
             RGBColor[
              0.7967350259379453, 0.5156495091253714, 0.57575064772341], 
             UndirectedEdge[274, 319] -> 
             RGBColor[
              0.47322013025663245`, 0.583220445923085, 0.9516727685977074], 
             UndirectedEdge[6, 352] -> 
             RGBColor[
              0.27259546821957914`, 0.40384549902267874`, 0.9388352806950242],
              UndirectedEdge[133, 342] -> 
             RGBColor[
              0.18475081584068775`, 0.311515199699814, 0.9338326576965637], 
             UndirectedEdge[290, 318] -> 
             RGBColor[
              0.1963038433293812, 0.3236581640946811, 0.9344905855208723], 
             UndirectedEdge[87, 298] -> 
             RGBColor[
              0.19758831891525655`, 0.325008229375892, 0.9345637345052766], 
             UndirectedEdge[86, 263] -> 
             RGBColor[
              0.4014876492319413, 0.5221701552338829, 0.9468034158808389], 
             UndirectedEdge[109, 191] -> 
             RGBColor[
              0.19427315985261398`, 0.3215237870078299, 0.9343749411009974], 
             UndirectedEdge[84, 238] -> 
             RGBColor[
              0.3144100017377778, 0.44501303039307516`, 0.9413184262912844], 
             UndirectedEdge[21, 244] -> 
             RGBColor[
              0.9589837634229517, 0.9266594522436353, 0.6365010356742713], 
             UndirectedEdge[137, 175] -> 
             RGBColor[
              0.3080574204607164, 0.43874050226861905`, 0.940941847744563], 
             UndirectedEdge[363, 369] -> 
             RGBColor[
              0.20524927327278905`, 0.33306037813821954`, 0.9350000145225716],
              UndirectedEdge[98, 290] -> 
             RGBColor[
              0.19961632362064485`, 0.32713979090418005`, 0.9346792263730843],
              UndirectedEdge[175, 352] -> 
             RGBColor[
              0.2606268889022622, 0.3912657633084208, 0.9381536878088295], 
             UndirectedEdge[121, 319] -> 
             RGBColor[
              0.3821339767558598, 0.5054057883182604, 0.9455705453873072], 
             UndirectedEdge[249, 387] -> 
             RGBColor[
              0.4216012233503626, 0.5373973944320252, 0.9486912790769737], 
             UndirectedEdge[310, 389] -> 
             RGBColor[
              0.24112387106664201`, 0.3707668550004327, 0.9370430197952202], 
             UndirectedEdge[228, 238] -> 
             RGBColor[
              0.24678874654536498`, 0.3767209983024208, 0.9373656260733012], 
             UndirectedEdge[268, 324] -> 
             RGBColor[
              0.6562462626397825, 0.7312424529611288, 0.9664688163111557], 
             UndirectedEdge[144, 368] -> 
             RGBColor[
              0.18786109875542928`, 0.31478430424653414`, 0.934009783707307], 
             UndirectedEdge[137, 278] -> 
             RGBColor[
              0.29631468313808673`, 0.42639814080998684`, 0.9402731162258624],
              UndirectedEdge[127, 298] -> 
             RGBColor[
              0.19590091614963856`, 0.32323466208171286`, 0.9344676394140633],
              UndirectedEdge[131, 228] -> 
             RGBColor[
              0.20842587898456535`, 0.33639919214973135`, 0.9351809175184903],
              UndirectedEdge[278, 314] -> 
             RGBColor[
              0.2454200867859244, 0.3752824501172079, 0.9372876829247517], 
             UndirectedEdge[182, 311] -> 
             RGBColor[
              0.32563786800336725`, 0.45591796242171545`, 0.9419906534014555],
              UndirectedEdge[77, 94] -> 
             RGBColor[
              0.18199794707454847`, 0.3086217600846408, 0.9336758858928365], 
             UndirectedEdge[144, 333] -> 
             RGBColor[
              0.1893313874669234, 0.316329670904003, 0.9340935144743294], 
             UndirectedEdge[166, 197] -> 
             RGBColor[
              0.9770032019247867, 0.9814553758280588, 0.8828706575837489], 
             UndirectedEdge[106, 384] -> 
             RGBColor[
              0.2081882862900271, 0.33614946716352473`, 0.9351673869660233], 
             UndirectedEdge[28, 265] -> 
             RGBColor[
              0.1984857219314811, 0.32595145684458154`, 0.9346148402794617], 
             UndirectedEdge[113, 266] -> 
             RGBColor[
              0.2701389734664643, 0.40126356728639195`, 0.9386953869528927], 
             UndirectedEdge[164, 292] -> 
             RGBColor[
              0.19766905263223078`, 0.3250930856312453, 0.9345683321710234], 
             UndirectedEdge[98, 248] -> 
             RGBColor[
              0.2095071320406308, 0.3375356576670594, 0.9352424932804627], 
             UndirectedEdge[91, 95] -> 
             RGBColor[
              0.5263538722152581, 0.6263568112928946, 0.9558556514000003], 
             UndirectedEdge[155, 342] -> 
             RGBColor[
              0.19539787597679303`, 0.32270593496546307`, 0.9344389920204009],
              UndirectedEdge[47, 209] -> 
             RGBColor[
              0.43947307837840166`, 0.5526061814054317, 0.9499049126595958], 
             UndirectedEdge[2, 360] -> 
             RGBColor[
              0.18511749831467772`, 0.3119006062289892, 0.9338535397209994], 
             UndirectedEdge[75, 341] -> 
             RGBColor[
              0.2771008643732843, 0.406039405513939, 0.9391849149556509], 
             UndirectedEdge[12, 390] -> 
             RGBColor[
              0.28559351861557547`, 0.41750727411286515`, 0.9395755004361839],
              UndirectedEdge[19, 198] -> 
             RGBColor[
              0.30685620721234774`, 0.43573562617248035`, 0.9409372354734161],
              UndirectedEdge[8, 56] -> 
             RGBColor[
              0.30973133616006665`, 0.43613714011801286`, 0.9411969165511169],
              UndirectedEdge[70, 154] -> 
             RGBColor[
              0.21421417432422896`, 0.3424830575508392, 0.9355105523750686], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.18749255911212426`, 0.3143969457146576, 0.9339887959198263], 
             UndirectedEdge[177, 243] -> 
             RGBColor[
              0.9321893579727436, 0.9478941964628581, 0.9631507032012652], 
             UndirectedEdge[109, 340] -> 
             RGBColor[
              0.19212863805325098`, 0.319269758626164, 0.9342528137570594], 
             UndirectedEdge[28, 36] -> 
             RGBColor[
              0.19993330434376533`, 0.3274729577419183, 0.9346972779563351], 
             UndirectedEdge[203, 339] -> 
             RGBColor[
              0.23865240959631934`, 0.3681691922954158, 0.9369022737206849], 
             UndirectedEdge[247, 369] -> 
             RGBColor[
              0.19411283179141248`, 0.32135527205012093`, 0.934365810655096], 
             UndirectedEdge[223, 230] -> 
             RGBColor[
              0.8738202331046678, 0.44857123188186093`, 0.21353768305270848`],
              UndirectedEdge[22, 173] -> 
             RGBColor[
              0.2993775960909632, 0.43129907223111097`, 0.940385972398696], 
             UndirectedEdge[69, 283] -> 
             RGBColor[
              0.22539830685763262`, 0.3542382899584056, 0.9361474721774046], 
             UndirectedEdge[59, 274] -> 
             RGBColor[
              0.41979531196311004`, 0.5369477420873823, 0.9482682580148925], 
             UndirectedEdge[31, 164] -> 
             RGBColor[
              0.19871454021211585`, 0.32619195936544565`, 0.9346278711420376],
              UndirectedEdge[116, 154] -> 
             RGBColor[
              0.19442534169189124`, 0.3216837397697962, 0.9343836076316113], 
             UndirectedEdge[10, 170] -> 
             RGBColor[
              0.2345826966210814, 0.3638916659237347, 0.936670509587346], 
             UndirectedEdge[301, 394] -> 
             RGBColor[
              0.18156448933556574`, 0.30816616851816203`, 0.9336512011158447],
              UndirectedEdge[90, 351] -> 
             RGBColor[
              0.7590840463718008, 0.8119268218437792, 0.9767853326782896], 
             UndirectedEdge[4, 203] -> 
             RGBColor[
              0.22928794206914588`, 0.35832654318282237`, 0.9363689811485005],
              UndirectedEdge[274, 351] -> 
             RGBColor[
              0.7014339552406084, 0.7651238807564681, 0.9722469063252], 
             UndirectedEdge[238, 269] -> 
             RGBColor[
              0.5167818424220354, 0.6108654129881752, 0.9574511707265], 
             UndirectedEdge[66, 325] -> 
             RGBColor[
              0.2517049597881912, 0.3818882501265539, 0.9376455971445944], 
             UndirectedEdge[128, 171] -> 
             RGBColor[
              0.19178726559275905`, 0.3189109545259229, 0.9342333731004496], 
             UndirectedEdge[198, 205] -> 
             RGBColor[
              0.35166297002886326`, 0.47901452236936815`, 0.9436286313802527],
              UndirectedEdge[202, 349] -> 
             RGBColor[
              0.22267250403179975`, 0.35137329836257414`, 0.9359922417389372],
              UndirectedEdge[295, 390] -> 
             RGBColor[
              0.34587288956677426`, 0.46974318811470905`, 0.943415535012837], 
             UndirectedEdge[250, 356] -> 
             RGBColor[
              0.22666963106636354`, 0.3555745323083922, 0.9362198722103361], 
             UndirectedEdge[133, 393] -> 
             RGBColor[
              0.18457522111446595`, 0.3113306385092063, 0.9338226578366745], 
             UndirectedEdge[124, 293] -> 
             RGBColor[
              0.3293119680498331, 0.45965520784915576`, 0.9422044452983639], 
             UndirectedEdge[45, 325] -> 
             RGBColor[
              0.2869742607531359, 0.4189585216435491, 0.9396541316582929], 
             UndirectedEdge[116, 304] -> 
             RGBColor[
              0.18211433978369124`, 0.30874409620167387`, 0.9336825142854346],
              UndirectedEdge[213, 296] -> 
             RGBColor[
              0.2337895217777734, 0.3630579888732283, 0.9366253394534165], 
             UndirectedEdge[248, 276] -> 
             RGBColor[
              0.22042799245848094`, 0.3490141743887628, 0.9358644201252941], 
             UndirectedEdge[209, 346] -> 
             RGBColor[
              0.34295446203942725`, 0.47147165045125694`, 0.9430737329517971],
              UndirectedEdge[31, 382] -> 
             RGBColor[
              0.18918398084593196`, 0.3161747371992214, 0.9340851198853325], 
             UndirectedEdge[69, 373] -> 
             RGBColor[
              0.25683371538447886`, 0.38727889744013877`, 0.937937672188489], 
             UndirectedEdge[166, 239] -> 
             RGBColor[
              0.9087289042908429, 0.6022050523179494, 0.4973324699831219], 
             UndirectedEdge[235, 317] -> 
             RGBColor[
              0.19343401255220036`, 0.32064178999008336`, 0.934327152903646], 
             UndirectedEdge[43, 59] -> 
             RGBColor[
              0.3034359716582913, 0.4327690861148492, 0.9407194513531689], 
             UndirectedEdge[94, 207] -> 
             RGBColor[
              0.18447193191249567`, 0.3112220750090219, 0.933816775669425], 
             UndirectedEdge[209, 270] -> 
             RGBColor[
              0.34697087401529814`, 0.4749504646340207, 0.9433296551713259], 
             UndirectedEdge[23, 341] -> 
             RGBColor[
              0.3146456284168403, 0.44550133299924655`, 0.9413230337254305], 
             UndirectedEdge[264, 312] -> 
             RGBColor[
              0.5131003370105822, 0.6097335825641022, 0.9568081018654329], 
             UndirectedEdge[48, 118] -> 
             RGBColor[
              0.23953466514577643`, 0.3690964988161278, 0.9369525168690463], 
             UndirectedEdge[106, 310] -> 
             RGBColor[
              0.2532088981789974, 0.38346898473049273`, 0.9377312442110733], 
             UndirectedEdge[267, 282] -> 
             RGBColor[
              0.2615646860965489, 0.39225144761939246`, 0.9382070939716974], 
             UndirectedEdge[43, 274] -> 
             RGBColor[
              0.3767191464303865, 0.4951636983486218, 0.9456872845015338], 
             UndirectedEdge[46, 362] -> 
             RGBColor[
              0.19522925834887567`, 0.3225287071475469, 0.9344293894959386], 
             UndirectedEdge[38, 117] -> 
             RGBColor[
              0.22453541604736282`, 0.35333133700637476`, 0.9360983318222922],
              UndirectedEdge[252, 300] -> 
             RGBColor[
              0.6421328397168371, 0.7146709767757251, 0.9682477279637229], 
             UndirectedEdge[7, 67] -> 
             RGBColor[
              0.43693392935130804`, 0.5528719414914377, 0.9490620215061302], 
             UndirectedEdge[150, 192] -> 
             RGBColor[
              0.1875835174154828, 0.3144925486585769, 0.9339939758606419], 
             UndirectedEdge[239, 272] -> 
             RGBColor[
              0.7843480991326863, 0.5059727477609727, 0.5745160346218742], 
             UndirectedEdge[22, 209] -> 
             RGBColor[
              0.32555893410641223`, 0.4564045184803353, 0.9419653052941668], 
             UndirectedEdge[167, 246] -> 
             RGBColor[
              0.6152498673613919, 0.6911955828537762, 0.9666225650716829], 
             UndirectedEdge[131, 140] -> 
             RGBColor[
              0.21947779992995464`, 0.3480154617955958, 0.9358103080664784], 
             UndirectedEdge[67, 385] -> 
             RGBColor[
              0.7098239251190117, 0.7666063809986858, 0.7914621261134387], 
             UndirectedEdge[60, 101] -> 
             RGBColor[
              0.18455258152934814`, 0.31130684286981486`, 0.9338213685457943],
              UndirectedEdge[113, 249] -> 
             RGBColor[
              0.3083010067824331, 0.4413437356356376, 0.9408697768166884], 
             UndirectedEdge[52, 393] -> 
             RGBColor[
              0.18136432541177624`, 0.30795578354313347`, 0.9336398020765009],
              UndirectedEdge[99, 367] -> 
             RGBColor[
              0.6703595369678017, 0.7365958473458555, 0.9440864000727226], 
             UndirectedEdge[5, 43] -> 
             RGBColor[
              0.2713996679468782, 0.4025886371179538, 0.9387671816385219], 
             UndirectedEdge[26, 105] -> 
             RGBColor[
              0.19823757833601402`, 0.32569064219253296`, 0.9346007088687955],
              UndirectedEdge[128, 306] -> 
             RGBColor[
              0.1986620698216136, 0.3261368096582128, 0.9346248830309214], 
             UndirectedEdge[226, 281] -> 
             RGBColor[
              0.43696413947427415`, 0.552898107981546, 0.9490639464684518], 
             UndirectedEdge[63, 345] -> 
             RGBColor[
              0.18008431245353695`, 0.306610408766515, 0.9335669072321386], 
             UndirectedEdge[4, 280] -> 
             RGBColor[
              0.24217745234544014`, 0.3718742357253608, 0.937103019690414], 
             UndirectedEdge[7, 223] -> 
             RGBColor[
              0.6892737381041355, 0.6614040887409706, 0.6061320446993241], 
             UndirectedEdge[155, 361] -> 
             RGBColor[
              0.21235865222551553`, 0.3405327861781953, 0.9354048831365458], 
             UndirectedEdge[252, 398] -> 
             RGBColor[
              0.39783022825914727`, 0.5190022810145718, 0.9465703682505828], 
             UndirectedEdge[6, 252] -> 
             RGBColor[
              0.3375773650971563, 0.4665223484650306, 0.9427417981088295], 
             UndirectedEdge[260, 307] -> 
             RGBColor[
              0.28646815305242945`, 0.41476449327789777`, 0.9397593961545982],
              UndirectedEdge[21, 357] -> 
             RGBColor[
              0.910151296596057, 0.6637195780075789, 0.25693017547606367`], 
             UndirectedEdge[233, 366] -> 
             RGBColor[
              0.6769028781273625, 0.7426382888986862, 0.9499751965434602], 
             UndirectedEdge[37, 41] -> 
             RGBColor[
              0.6103348144421008, 0.6886019294831773, 0.9655435733376975], 
             UndirectedEdge[173, 176] -> 
             RGBColor[
              0.25807437232061936`, 0.38858290654221544`, 0.9380083257656147],
              UndirectedEdge[60, 136] -> 
             RGBColor[
              0.18529719032077357`, 0.3120894739205271, 0.933863772914916], 
             UndirectedEdge[74, 285] -> 
             RGBColor[
              0.9286295448374513, 0.9418226643023089, 0.7983899704135337], 
             UndirectedEdge[234, 395] -> 
             RGBColor[
              0.6271808306424103, 0.7060165287006694, 0.9652946384160161], 
             UndirectedEdge[17, 164] -> 
             RGBColor[
              0.21631448031938844`, 0.34469061231884324`, 0.9356301616943686],
              UndirectedEdge[20, 383] -> 
             RGBColor[
              0.1993210537450841, 0.3268294435437743, 0.9346624111904838], 
             UndirectedEdge[19, 219] -> 
             RGBColor[
              0.2987647907941907, 0.4287272479574868, 0.9404216575742097], 
             UndirectedEdge[91, 279] -> 
             RGBColor[
              0.5827660155833214, 0.6716970806233367, 0.9606095197706748], 
             UndirectedEdge[76, 207] -> 
             RGBColor[
              0.1908268877624048, 0.3179015365347492, 0.9341786810037627], 
             UndirectedEdge[238, 339] -> 
             RGBColor[
              0.27076497929052823`, 0.4019215390985449, 0.9387310370584805], 
             UndirectedEdge[142, 379] -> 
             RGBColor[
              0.1947953347030193, 0.32207262588340363`, 0.9344046781862394], 
             UndirectedEdge[205, 219] -> 
             RGBColor[
              0.34357155361070624`, 0.4720061441543746, 0.9431130534810463], 
             UndirectedEdge[7, 68] -> 
             RGBColor[
              0.3593357938245753, 0.4820804322688437, 0.9442486147652995], 
             UndirectedEdge[188, 273] -> 
             RGBColor[
              0.19180481699179464`, 0.3189294021591323, 0.9342343726266598], 
             UndirectedEdge[16, 69] -> 
             RGBColor[
              0.2797958916834022, 0.41057876108804503`, 0.9392759017239116], 
             UndirectedEdge[118, 323] -> 
             RGBColor[
              0.3187861771861727, 0.44407882697168544`, 0.9417702640466686], 
             UndirectedEdge[211, 263] -> 
             RGBColor[
              0.30692109574993276`, 0.4322308872824815, 0.9410717536469021], 
             UndirectedEdge[191, 340] -> 
             RGBColor[
              0.2050792556090335, 0.33288167879387, 0.9349903322681394], 
             UndirectedEdge[33, 182] -> 
             RGBColor[
              0.3125367270389322, 0.44214783260778046`, 0.9412445628049322], 
             UndirectedEdge[99, 300] -> 
             RGBColor[
              0.9401681906865148, 0.9543565949425481, 0.9673889822446275], 
             UndirectedEdge[11, 91] -> 
             RGBColor[
              0.40263125450178067`, 0.5220751425472069, 0.9471762250170271], 
             UndirectedEdge[78, 233] -> 
             RGBColor[
              0.8896719661372465, 0.5617502239079055, 0.560162093898772], 
             UndirectedEdge[27, 172] -> 
             RGBColor[
              0.8224207314031455, 0.17334114315753277`, 0.1691034237532337], 
             UndirectedEdge[313, 396] -> 
             RGBColor[
              0.20896253735329678`, 0.3369632541213739, 0.9352114794186747], 
             UndirectedEdge[74, 172] -> 
             RGBColor[
              0.8434316387549917, 0.5388061389910088, 0.578613967277474], 
             UndirectedEdge[217, 366] -> 
             RGBColor[
              0.6937344954214235, 0.7518077736561808, 0.7166986999905727], 
             UndirectedEdge[277, 302] -> 
             RGBColor[
              0.19959521355734036`, 0.32711760288919167`, 0.9346780241862087],
              UndirectedEdge[203, 232] -> 
             RGBColor[
              0.26042493590475796`, 0.3910534979034842, 0.9381421868843842], 
             UndirectedEdge[27, 285] -> 
             RGBColor[
              0.9076186374856052, 0.576357668468833, 0.38887942688929333`], 
             UndirectedEdge[193, 334] -> 
             RGBColor[
              0.1859629402627897, 0.3127892193205704, 0.9339016863892251], 
             UndirectedEdge[39, 381] -> 
             RGBColor[
              0.18966952552711056`, 0.31668507544445096`, 0.9341127709366266],
              UndirectedEdge[270, 390] -> 
             RGBColor[
              0.310905083152461, 0.4394558317316838, 0.9411874173089341], 
             UndirectedEdge[35, 42] -> 
             RGBColor[
              0.22638274960055194`, 0.35527300169848874`, 0.9362035347352613],
              UndirectedEdge[41, 245] -> 
             RGBColor[
              0.8453505309169804, 0.5232059626309822, 0.576653008726561], 
             UndirectedEdge[45, 276] -> 
             RGBColor[
              0.2538332616499947, 0.38412523032544144`, 0.9377668007870836], 
             UndirectedEdge[17, 241] -> 
             RGBColor[
              0.2474447922190557, 0.37741054390116785`, 0.9374029869038852], 
             UndirectedEdge[69, 347] -> 
             RGBColor[
              0.21983376516516337`, 0.34838960382729967`, 0.9358305797600202],
              UndirectedEdge[16, 295] -> 
             RGBColor[
              0.3734051820083968, 0.4978465335906915, 0.9450140259017055], 
             UndirectedEdge[190, 351] -> 
             RGBColor[
              0.9330043693197932, 0.948887212220239, 0.9751255904637988], 
             UndirectedEdge[112, 141] -> 
             RGBColor[
              0.9013527030672266, 0.6354761592849575, 0.23890867411463246`], 
             UndirectedEdge[135, 400] -> 
             RGBColor[
              0.9225103695720027, 0.6890379026099368, 0.4378370589902095], 
             UndirectedEdge[295, 310] -> 
             RGBColor[
              0.3543169737444146, 0.4786184559712684, 0.9438964131148506], 
             UndirectedEdge[185, 249] -> 
             RGBColor[
              0.35433837255967027`, 0.48133182157191207`, 0.9437991056637501],
              UndirectedEdge[93, 98] -> 
             RGBColor[
              0.21766781953393055`, 0.3461130576399892, 0.9357072323605509], 
             UndirectedEdge[221, 268] -> 
             RGBColor[
              0.7908356351545234, 0.6993648502734382, 0.6044361277879526], 
             UndirectedEdge[265, 291] -> 
             RGBColor[
              0.18857894058274138`, 0.31553880152083974`, 0.9340506637374206],
              UndirectedEdge[128, 133] -> 
             RGBColor[
              0.19019948162046302`, 0.31724209289972144`, 0.9341429511521433],
              UndirectedEdge[57, 333] -> 
             RGBColor[
              0.2028967340448986, 0.3305877102501046, 0.9348660408938132], 
             UndirectedEdge[28, 378] -> 
             RGBColor[
              0.19890365407675165`, 0.32639073002768937`, 0.9346386408968597],
              UndirectedEdge[92, 386] -> 
             RGBColor[
              0.6290755332185833, 0.7079371215448762, 0.9651823556220622], 
             UndirectedEdge[35, 248] -> 
             RGBColor[
              0.22712519699410227`, 0.3560533609829937, 0.9362458160159715], 
             UndirectedEdge[56, 175] -> 
             RGBColor[
              0.331650883280764, 0.45917597392142306`, 0.9424452023325764], 
             UndirectedEdge[3, 21] -> 
             RGBColor[
              0.7725354937206939, 0.7794802979389553, 0.6358867741972027], 
             UndirectedEdge[98, 204] -> 
             RGBColor[
              0.19732498772567109`, 0.3247314515994759, 0.9345487381835933], 
             UndirectedEdge[243, 367] -> 
             RGBColor[
              0.6723041775720541, 0.7380461571244501, 0.9407946307732227], 
             UndirectedEdge[48, 209] -> 
             RGBColor[
              0.2875152720132881, 0.41711435878234465`, 0.9397732858765137], 
             UndirectedEdge[116, 291] -> 
             RGBColor[
              0.1852566513830322, 0.31204686492664385`, 0.9338614642823836], 
             UndirectedEdge[214, 340] -> 
             RGBColor[
              0.22133989504081186`, 0.3499726418207558, 0.9359163516283189], 
             UndirectedEdge[138, 159] -> 
             RGBColor[
              0.18138230828610377`, 0.30797468468423184`, 0.9336408261745905],
              UndirectedEdge[22, 48] -> 
             RGBColor[
              0.27823170323432733`, 0.40907339811174287`, 0.9391817450830557],
              UndirectedEdge[13, 297] -> 
             RGBColor[
              0.2105416090442786, 0.33862295858752356`, 0.9353014052154489], 
             UndirectedEdge[192, 347] -> 
             RGBColor[
              0.18973620095672017`, 0.3167551555484371, 0.9341165680037053], 
             UndirectedEdge[4, 322] -> 
             RGBColor[
              0.21636197354501668`, 0.3447405307102229, 0.9356328663633082], 
             UndirectedEdge[111, 304] -> 
             RGBColor[
              0.18507047905985996`, 0.31185118601098283`, 0.9338508620439963],
              UndirectedEdge[133, 361] -> 
             RGBColor[
              0.20171159208941025`, 0.3293420509125463, 0.9347985488127086], 
             UndirectedEdge[4, 186] -> 
             RGBColor[
              0.2198352252877424, 0.3483911385087073, 0.9358306629118409], 
             UndirectedEdge[73, 240] -> 
             RGBColor[
              0.8811521202900017, 0.5036002063401005, 0.22050415715161448`], 
             UndirectedEdge[82, 335] -> 
             RGBColor[
              0.18011477786530028`, 0.30664242984589696`, 0.933568642192269], 
             UndirectedEdge[184, 372] -> 
             RGBColor[
              0.18858940025952037`, 0.31554979530431626`, 0.9340512594005395],
              UndirectedEdge[85, 340] -> 
             RGBColor[
              0.22184000451345684`, 0.35049828858527765`, 0.9359448321229403],
              UndirectedEdge[344, 388] -> 
             RGBColor[
              0.20538183242077535`, 0.3331997062074885, 0.9350075635699459], 
             UndirectedEdge[57, 228] -> 
             RGBColor[
              0.21063806848440092`, 0.33872434357497383`, 0.9353068984378649],
              UndirectedEdge[36, 80] -> 
             RGBColor[
              0.1863429465695527, 0.31318863004276976`, 0.9339233271862263], 
             UndirectedEdge[88, 365] -> 
             RGBColor[
              0.18619994968916187`, 0.3130383312549531, 0.9339151837254329], 
             UndirectedEdge[209, 241] -> 
             RGBColor[
              0.2990278699570904, 0.4292148291621499, 0.9404289112980508], 
             UndirectedEdge[49, 62] -> 
             RGBColor[
              0.19439182652115503`, 0.3216485132003679, 0.9343816989922191], 
             UndirectedEdge[161, 250] -> 
             RGBColor[
              0.22890128499152032`, 0.3579201420787632, 0.9363469615999377], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.19292841019979173`, 0.32011036986066127`, 0.934298359597648], 
             UndirectedEdge[324, 346] -> 
             RGBColor[
              0.4920980261552287, 0.5957700021570038, 0.9539260250446029], 
             UndirectedEdge[142, 258] -> 
             RGBColor[
              0.18294835007904106`, 0.30962069390139346`, 0.9337300099379471],
              UndirectedEdge[44, 46] -> 
             RGBColor[
              0.2189840028439955, 0.34749644974970917`, 0.9357821870529404], 
             UndirectedEdge[85, 191] -> 
             RGBColor[
              0.22398452631281984`, 0.35275231696694354`, 0.9360669594668783],
              UndirectedEdge[112, 172] -> 
             RGBColor[
              0.880455548797022, 0.4861641510661218, 0.21934051163396778`], 
             UndirectedEdge[133, 298] -> 
             RGBColor[
              0.1913924314057353, 0.3184959587614276, 0.9342108878776034], 
             UndirectedEdge[26, 215] -> 
             RGBColor[
              0.18499791179933114`, 0.3117749132191369, 0.9338467294458628], 
             UndirectedEdge[127, 129] -> 
             RGBColor[
              0.19194623803100921`, 0.3190780446379586, 0.9342424263456293], 
             UndirectedEdge[172, 225] -> 
             RGBColor[
              0.8542567503473041, 0.5474377891348923, 0.5796464760848401], 
             UndirectedEdge[38, 376] -> 
             RGBColor[
              0.21626586560617583`, 0.3446395151729059, 0.9356273931583702], 
             UndirectedEdge[158, 346] -> 
             RGBColor[
              0.34491127963015633`, 0.47316654749583464`, 0.9431984196383325],
              UndirectedEdge[340, 370] -> 
             RGBColor[
              0.19501122587610803`, 0.3222995411946109, 0.9344169728691645], 
             UndirectedEdge[44, 266] -> 
             RGBColor[
              0.23471345152571355`, 0.36402909761884283`, 0.9366779558857301],
              UndirectedEdge[183, 238] -> 
             RGBColor[
              0.31998454354214334`, 0.4498414183193987, 0.9416736311656848], 
             UndirectedEdge[21, 264] -> 
             RGBColor[
              0.8432468849976082, 0.8356472056673055, 0.6423010818703361], 
             UndirectedEdge[13, 140] -> 
             RGBColor[
              0.2199309237526768, 0.34849172366298653`, 0.9358361127978458], 
             UndirectedEdge[210, 266] -> 
             RGBColor[
              0.26920304414348, 0.40027984622658896`, 0.9386420871625321], 
             UndirectedEdge[51, 395] -> 
             RGBColor[
              0.4251084428470847, 0.5422133005057554, 0.9484234537100807], 
             UndirectedEdge[358, 372] -> 
             RGBColor[
              0.19242209071206384`, 0.3195781959765495, 0.9342695254518545], 
             UndirectedEdge[174, 309] -> 
             RGBColor[
              0.32079650085916334`, 0.45124869478397367`, 0.9416995914849222],
              UndirectedEdge[65, 363] -> 
             RGBColor[
              0.25392355034044856`, 0.38422012946374207`, 0.9377719425944349],
              UndirectedEdge[236, 267] -> 
             RGBColor[
              0.25338105975763014`, 0.38364993746531034`, 0.9377410485582862],
              UndirectedEdge[227, 352] -> 
             RGBColor[
              0.22353600409255178`, 0.3522808916754905, 0.9360414167899633], 
             UndirectedEdge[2, 370] -> 
             RGBColor[
              0.18603673488354355`, 0.3128667821458319, 0.9339058888837076], 
             UndirectedEdge[17, 354] -> 
             RGBColor[
              0.2237645258481464, 0.35252108252973663`, 0.9360544307658767], 
             UndirectedEdge[133, 306] -> 
             RGBColor[
              0.1942497780329075, 0.32149921123282543`, 0.9343736095409554], 
             UndirectedEdge[105, 261] -> 
             RGBColor[
              0.23472290345765154`, 0.3640390321985968, 0.9366784941592712], 
             UndirectedEdge[120, 206] -> 
             RGBColor[
              0.624306194339526, 0.7045315727086937, 0.9644880050917888], 
             UndirectedEdge[361, 393] -> 
             RGBColor[
              0.20049962337211924`, 0.32806819494741857`, 0.934729528987206], 
             UndirectedEdge[270, 295] -> 
             RGBColor[
              0.3940670515595366, 0.5157428065001295, 0.9463305819589302], 
             UndirectedEdge[9, 283] -> 
             RGBColor[
              0.2000074908485974, 0.3275509324621929, 0.9347015027680361], 
             UndirectedEdge[43, 122] -> 
             RGBColor[
              0.42916131354223347`, 0.5377386121027248, 0.9498157239985662], 
             UndirectedEdge[127, 336] -> 
             RGBColor[
              0.18757872554421223`, 0.31448751209804937`, 0.933993702970662], 
             UndirectedEdge[4, 123] -> 
             RGBColor[
              0.2222583366495916, 0.3509379821841447, 0.9359686555192263], 
             UndirectedEdge[45, 279] -> 
             RGBColor[
              0.4785218001436983, 0.5802784243797845, 0.9537482634423509], 
             UndirectedEdge[135, 255] -> 
             RGBColor[
              0.9151018270707441, 0.6320925985012373, 0.4307426303242521], 
             UndirectedEdge[152, 180] -> 
             RGBColor[
              0.2576563148367751, 0.3881435016203197, 0.9379845180103705], 
             UndirectedEdge[48, 68] -> 
             RGBColor[
              0.2551071510734325, 0.38546416887872903`, 0.937839346905198], 
             UndirectedEdge[362, 363] -> 
             RGBColor[
              0.20453297478611288`, 0.3323075030127757, 0.9349592223834241], 
             UndirectedEdge[18, 257] -> 
             RGBColor[
              0.46412234198098856`, 0.5722988469015355, 0.9519334554771259], 
             UndirectedEdge[72, 109] -> 
             RGBColor[
              0.18206833162796426`, 0.3086957387129193, 0.933679894189029], 
             UndirectedEdge[181, 211] -> 
             RGBColor[
              0.20840661341018846`, 0.33637894280955327`, 0.9351798203725303],
              UndirectedEdge[82, 259] -> 
             RGBColor[
              0.1834817429881715, 0.31018132366795326`, 0.9337603858750381], 
             UndirectedEdge[282, 367] -> 
             RGBColor[
              0.3211123825917724, 0.44870662104929115`, 0.9418228148301714], 
             UndirectedEdge[44, 363] -> 
             RGBColor[
              0.22828771928123268`, 0.35727524561493795`, 0.9363120199404259],
              UndirectedEdge[139, 290] -> 
             RGBColor[
              0.19313846063632573`, 0.32033114618742536`, 0.9343103216592668],
              UndirectedEdge[255, 351] -> 
             RGBColor[
              0.8725754097367984, 0.601857083491112, 0.5863765700059249], 
             UndirectedEdge[290, 345] -> 
             RGBColor[
              0.18860221988526102`, 0.31556326954378094`, 0.9340519894592605],
              UndirectedEdge[145, 200] -> 
             RGBColor[
              0.19073593578989534`, 0.3178059402449537, 0.9341735014234795], 
             UndirectedEdge[44, 316] -> 
             RGBColor[
              0.23551418105696653`, 0.3648707151253743, 0.9367235562479619], 
             UndirectedEdge[172, 240] -> 
             RGBColor[
              0.8277460748309535, 0.21427406632403376`, 0.17420297863381767`],
              UndirectedEdge[89, 299] -> 
             RGBColor[
              0.18845360021131413`, 0.3154070608434312, 0.9340435257886923], 
             UndirectedEdge[119, 196] -> 
             RGBColor[
              0.18607572050979368`, 0.3129077585108523, 0.9339081090574485], 
             UndirectedEdge[149, 369] -> 
             RGBColor[
              0.20360056980323105`, 0.3313274862578765, 0.9349061232990186], 
             UndirectedEdge[32, 385] -> 
             RGBColor[
              0.9757287822359568, 0.928603231512897, 0.461093645269188], 
             UndirectedEdge[149, 253] -> 
             RGBColor[
              0.20384820267597584`, 0.3315877641079622, 0.9349202256247814], 
             UndirectedEdge[317, 336] -> 
             RGBColor[
              0.1878536669894908, 0.3147764929893316, 0.9340093604792311], 
             UndirectedEdge[138, 215] -> 
             RGBColor[
              0.18262441317102773`, 0.30928021567228525`, 0.9337115622102574],
              UndirectedEdge[157, 181] -> 
             RGBColor[
              0.19115892919796787`, 0.31825053313616897`, 0.9341975902723066],
              UndirectedEdge[299, 342] -> 
             RGBColor[
              0.18568831496489116`, 0.3125005707202294, 0.9338860468847814], 
             UndirectedEdge[108, 198] -> 
             RGBColor[
              0.3047308678845767, 0.4335017597846965, 0.9408162005428573], 
             UndirectedEdge[152, 367] -> 
             RGBColor[
              0.31592573046277495`, 0.4432551208089762, 0.9415274426643891], 
             UndirectedEdge[17, 118] -> 
             RGBColor[
              0.23527881827982655`, 0.36462333392373825`, 0.9367101526859918],
              UndirectedEdge[44, 68] -> 
             RGBColor[
              0.25335041241870687`, 0.38361772516894843`, 0.9377393032376733],
              UndirectedEdge[158, 323] -> 
             RGBColor[
              0.3687236016444134, 0.49379158398248, 0.9447157197406713], 
             UndirectedEdge[343, 359] -> 
             RGBColor[
              0.18461240578101906`, 0.3113697219513976, 0.933824775448425], 
             UndirectedEdge[354, 388] -> 
             RGBColor[
              0.21768345542489445`, 0.346129491952765, 0.93570812280141], 
             UndirectedEdge[382, 389] -> 
             RGBColor[
              0.1922700735577051, 0.31941841630887424`, 0.9342608682998029], 
             UndirectedEdge[178, 319] -> 
             RGBColor[
              0.4475260102308348, 0.5620450810151163, 0.9497372679364278], 
             UndirectedEdge[15, 386] -> 
             RGBColor[
              0.5232931103169385, 0.6153912271159707, 0.9581889419192983], 
             UndirectedEdge[27, 104] -> 
             RGBColor[
              0.8200236798530103, 0.15491635454850536`, 0.16680800448174155`],
              UndirectedEdge[236, 398] -> 
             RGBColor[
              0.3384347985138768, 0.4621971627307483, 0.9429819918755249], 
             UndirectedEdge[151, 304] -> 
             RGBColor[
              0.1864549217267703, 0.3133063230326405, 0.9339297040057775], 
             UndirectedEdge[21, 233] -> 
             RGBColor[
              0.9613042288478943, 0.9283900515581442, 0.6325730929841542], 
             UndirectedEdge[120, 321] -> 
             RGBColor[
              0.5363303582199404, 0.6344561720670685, 0.9566410369233613], 
             UndirectedEdge[170, 299] -> 
             RGBColor[
              0.20966330069407968`, 0.3376998008234987, 0.9352513868542458], 
             UndirectedEdge[97, 109] -> 
             RGBColor[
              0.18710606140703578`, 0.3139907121212397, 0.9339667854472937], 
             UndirectedEdge[251, 381] -> 
             RGBColor[
              0.19321867549075944`, 0.3204154570853507, 0.9343148897765596], 
             UndirectedEdge[134, 392] -> 
             RGBColor[
              0.9110260493239869, 0.9293182372189884, 0.8905829197640283], 
             UndirectedEdge[132, 220] -> 
             RGBColor[
              0.4970479670019815, 0.5999842739295098, 0.9542616336741748], 
             UndirectedEdge[102, 167] -> 
             RGBColor[
              0.29386288759542795`, 0.42605944514024496`, 0.9400515350827954],
              UndirectedEdge[270, 373] -> 
             RGBColor[
              0.31547519929516016`, 0.44425931355976, 0.9414476786623798], 
             UndirectedEdge[122, 351] -> 
             RGBColor[
              0.7538761223524553, 0.8076987945105711, 0.9763753458222324], 
             UndirectedEdge[96, 173] -> 
             RGBColor[
              0.515339475447038, 0.6087263479834802, 0.9574676673643785], 
             UndirectedEdge[253, 266] -> 
             RGBColor[
              0.21192263839001468`, 0.3400745079922101, 0.9353800527936387], 
             UndirectedEdge[217, 230] -> 
             RGBColor[
              0.9054039524770299, 0.5624674632894656, 0.3258325895022128], 
             UndirectedEdge[118, 158] -> 
             RGBColor[
              0.28881871360859035`, 0.41812251622929797`, 0.9398607637666927],
              UndirectedEdge[208, 230] -> 
             RGBColor[
              0.9053767960647079, 0.5643648513182951, 0.465019014701602], 
             UndirectedEdge[86, 179] -> 
             RGBColor[
              0.4324853651691194, 0.5490017107824403, 0.9487832899231066], 
             UndirectedEdge[185, 284] -> 
             RGBColor[
              0.33809952087216233`, 0.4642943071241772, 0.9428732085612545], 
             UndirectedEdge[279, 399] -> 
             RGBColor[
              0.7994051322415094, 0.7452396599077329, 0.6138726305595152], 
             UndirectedEdge[167, 309] -> 
             RGBColor[
              0.30392546223642514`, 0.4366358490920146, 0.940624583822355], 
             UndirectedEdge[174, 183] -> 
             RGBColor[
              0.34699168167192995`, 0.474968487180372, 0.943330981016807], 
             UndirectedEdge[149, 247] -> 
             RGBColor[
              0.20711572977977888`, 0.33502214226724336`, 0.9351063064594698],
              UndirectedEdge[297, 339] -> 
             RGBColor[
              0.22923415063680755`, 0.358270004976861, 0.9363659178060062], 
             UndirectedEdge[28, 282] -> 
             RGBColor[
              0.2370656602671769, 0.3665014181447689, 0.9368119106937756], 
             UndirectedEdge[35, 125] -> 
             RGBColor[
              0.24888171485109623`, 0.37892084069359944`, 0.9374848175220434],
              UndirectedEdge[119, 231] -> 
             RGBColor[
              0.18230446054106692`, 0.30894392517202796`, 0.9336933413813087],
              UndirectedEdge[257, 309] -> 
             RGBColor[
              0.31035046981038367`, 0.4422008677223072, 0.9410339796235565], 
             UndirectedEdge[153, 161] -> 
             RGBColor[
              0.1909498488692258, 0.3180307764542026, 0.9341856834568915], 
             UndirectedEdge[315, 369] -> 
             RGBColor[
              0.20472182801530026`, 0.332505999730638, 0.934969977295443], 
             UndirectedEdge[145, 207] -> 
             RGBColor[
              0.19250737674757545`, 0.31966783700731927`, 0.9342743823654074],
              UndirectedEdge[75, 215] -> 
             RGBColor[
              0.20048155521420025`, 0.3280492041678583, 0.9347285000323418], 
             UndirectedEdge[155, 199] -> 
             RGBColor[
              0.1967855567491959, 0.3241644754413012, 0.9345180183874995], 
             UndirectedEdge[28, 151] -> 
             RGBColor[
              0.19950401467485102`, 0.3270217470813523, 0.9346728305447676], 
             UndirectedEdge[141, 279] -> 
             RGBColor[
              0.7689158684311985, 0.6132326776654563, 0.588764654117898], 
             UndirectedEdge[347, 380] -> 
             RGBColor[
              0.20898774598358635`, 0.3369897499901277, 0.9352129150128767], 
             UndirectedEdge[107, 346] -> 
             RGBColor[
              0.3498425512041035, 0.47743776708027175`, 0.9435126359024721], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.684630729662244, 0.7517566465973935, 0.970608286963019], 
             UndirectedEdge[171, 299] -> 
             RGBColor[
              0.18831247292825637`, 0.31525872712095093`, 0.9340354887987012],
              UndirectedEdge[283, 294] -> 
             RGBColor[
              0.19947004944091673`, 0.32698604746696713`, 0.934670896274942], 
             UndirectedEdge[83, 244] -> 
             RGBColor[
              0.9498999569574745, 0.9621560504469515, 0.9696904840737579], 
             UndirectedEdge[112, 179] -> 
             RGBColor[
              0.6955279730573865, 0.6779676106196408, 0.6092046613657698], 
             UndirectedEdge[42, 93] -> 
             RGBColor[
              0.22541709987581074`, 0.35425804261205696`, 0.936148542411988], 
             UndirectedEdge[94, 254] -> 
             RGBColor[
              0.18421702339867016`, 0.31095414999885795`, 0.9338022590066659],
              UndirectedEdge[84, 222] -> 
             RGBColor[
              0.2856119220562171, 0.4147444227440439, 0.9396784182563604], 
             UndirectedEdge[132, 366] -> 
             RGBColor[
              0.3763364091715497, 0.5003854152316536, 0.9452008011045592], 
             UndirectedEdge[52, 133] -> 
             RGBColor[
              0.18257629412906723`, 0.3092296395082612, 0.9337088219020035], 
             UndirectedEdge[255, 400] -> 
             RGBColor[
              0.8427699382288443, 0.329754063899142, 0.18858984719066463`], 
             UndirectedEdge[276, 318] -> 
             RGBColor[
              0.20862378443178675`, 0.3366072033226911, 0.9351921879409346], 
             UndirectedEdge[235, 313] -> 
             RGBColor[
              0.2049405983747336, 0.3327359412492443, 0.9349824359437711], 
             UndirectedEdge[218, 229] -> 
             RGBColor[
              0.19887179747769093`, 0.3263572467222515, 0.9346368267106708], 
             UndirectedEdge[202, 260] -> 
             RGBColor[
              0.23397057730885262`, 0.3632482897159762, 0.9366356502980638], 
             UndirectedEdge[129, 216] -> 
             RGBColor[
              0.1943994825815768, 0.32165656020529343`, 0.9343821349935341], 
             UndirectedEdge[307, 312] -> 
             RGBColor[
              0.32563175741045036`, 0.45592792457411196`, 0.9419897054854269],
              UndirectedEdge[215, 349] -> 
             RGBColor[
              0.192491042377818, 0.3196506685490453, 0.9342734521472142], 
             UndirectedEdge[48, 61] -> 
             RGBColor[
              0.22477630942984533`, 0.3535845312248864, 0.9361120503440548], 
             UndirectedEdge[198, 284] -> 
             RGBColor[
              0.31495346164278715`, 0.44424635397445533`, 0.9413983621344152],
              UndirectedEdge[37, 256] -> 
             RGBColor[
              0.3500537032004466, 0.4776206563266962, 0.9435260903209648], 
             UndirectedEdge[260, 366] -> 
             RGBColor[
              0.3094906009088253, 0.4347053804692331, 0.9412263661740565], 
             UndirectedEdge[35, 263] -> 
             RGBColor[
              0.31410208852609794`, 0.43977856599147, 0.9414807005621779], 
             UndirectedEdge[124, 185] -> 
             RGBColor[
              0.35466498690371884`, 0.48161471850061266`, 0.9438199172409392],
              UndirectedEdge[17, 48] -> 
             RGBColor[
              0.23593219427525336`, 0.3653100735213626, 0.936747361482348], 
             UndirectedEdge[98, 139] -> 
             RGBColor[
              0.19453754132088114`, 0.32180166869373195`, 0.9343899972344978],
              UndirectedEdge[98, 125] -> 
             RGBColor[
              0.23126364989762477`, 0.3604031373776651, 0.9364814947865346], 
             UndirectedEdge[195, 397] -> 
             RGBColor[
              0.2073858256728759, 0.33530603017595706`, 0.9351216880210106], 
             UndirectedEdge[152, 198] -> 
             RGBColor[
              0.3050387614583694, 0.43382537545233274`, 0.9408337346263971], 
             UndirectedEdge[29, 129] -> 
             RGBColor[
              0.18526332309430954`, 0.3120538773182072, 0.933861844226471], 
             UndirectedEdge[83, 230] -> 
             RGBColor[
              0.8813864038440016, 0.5479387227052518, 0.5712729934209153], 
             UndirectedEdge[10, 155] -> 
             RGBColor[
              0.22229114501906733`, 0.3509724658606344, 0.9359705239073323], 
             UndirectedEdge[210, 316] -> 
             RGBColor[
              0.270003773674733, 0.40112146373312046`, 0.9386876875247638], 
             UndirectedEdge[6, 175] -> 
             RGBColor[
              0.2936199376985361, 0.4259435494734196, 0.9400325931289355], 
             UndirectedEdge[301, 343] -> 
             RGBColor[
              0.18235879982602854`, 0.30900103920583233`, 0.9336964359231994],
              UndirectedEdge[140, 297] -> 
             RGBColor[
              0.21630983883703356`, 0.3446857338266013, 0.935629897368815], 
             UndirectedEdge[274, 295] -> 
             RGBColor[
              0.4610566723545275, 0.5726862586021548, 0.9508973954130453], 
             UndirectedEdge[61, 371] -> 
             RGBColor[
              0.19795607517941943`, 0.3253947645266211, 0.934584677680474], 
             UndirectedEdge[266, 397] -> 
             RGBColor[
              0.22283784734549728`, 0.3515470846686418, 0.9360016577960488], 
             UndirectedEdge[71, 88] -> 
             RGBColor[
              0.1851982028892632, 0.3119854318538441, 0.9338581357271303], 
             UndirectedEdge[156, 255] -> 
             RGBColor[
              0.833173631408902, 0.25599264455260395`, 0.17940041294240955`], 
             UndirectedEdge[22, 388] -> 
             RGBColor[
              0.26789478594512556`, 0.39820864264238165`, 0.9385930729355345],
              UndirectedEdge[17, 346] -> 
             RGBColor[
              0.29137138430139253`, 0.41966736519027487`, 0.9400478085576316],
              UndirectedEdge[72, 365] -> 
             RGBColor[
              0.18187230727944725`, 0.30848970469396636`, 0.9336687308923729],
              UndirectedEdge[194, 230] -> 
             RGBColor[
              0.906134992146644, 0.5640310832233217, 0.4054017460858296], 
             UndirectedEdge[95, 264] -> 
             RGBColor[
              0.6413507907064967, 0.7184767050540989, 0.9657562779986768], 
             UndirectedEdge[131, 325] -> 
             RGBColor[
              0.2511977848308302, 0.381355177089618, 0.9376167142810707], 
             UndirectedEdge[369, 372] -> 
             RGBColor[
              0.19233300953943172`, 0.31948456601604064`, 0.9342644524108568],
              UndirectedEdge[11, 248] -> 
             RGBColor[
              0.2649817698706437, 0.3955454303669761, 0.9384125880269136], 
             UndirectedEdge[32, 223] -> 
             RGBColor[
              0.9434671979288998, 0.8132571155526379, 0.27501732397559764`], 
             UndirectedEdge[75, 229] -> 
             RGBColor[
              0.21242485108253378`, 0.34060236537417143`, 0.9354086530635206],
              UndirectedEdge[123, 131] -> 
             RGBColor[
              0.21247713876151392`, 0.34065732304000995`, 0.9354116307694857],
              UndirectedEdge[35, 340] -> 
             RGBColor[
              0.21959313401090685`, 0.34813668522727964`, 0.9358168761717671],
              UndirectedEdge[316, 369] -> 
             RGBColor[
              0.2124757350485229, 0.34065584764865586`, 0.9354115508301075], 
             UndirectedEdge[232, 280] -> 
             RGBColor[
              0.2733144461810522, 0.4046011904460226, 0.9388762254262976], 
             UndirectedEdge[30, 318] -> 
             RGBColor[
              0.18730055861877407`, 0.31419514102261215`, 0.9339778617757692],
              UndirectedEdge[219, 338] -> 
             RGBColor[
              0.28566284547896603`, 0.414956272719873, 0.9396755211710989], 
             UndirectedEdge[124, 397] -> 
             RGBColor[
              0.26132649500551464`, 0.3919101499465881, 0.9381968592370336], 
             UndirectedEdge[131, 280] -> 
             RGBColor[
              0.23239625445736245`, 0.36159357658122604`, 0.9365459949406734],
              UndirectedEdge[224, 345] -> 
             RGBColor[
              0.17916076969846856`, 0.3056397067749454, 0.9335143128384965], 
             UndirectedEdge[44, 195] -> 
             RGBColor[
              0.2192614298530921, 0.3477880431261581, 0.9357979861106919], 
             UndirectedEdge[57, 102] -> 
             RGBColor[
              0.24757611002741542`, 0.37754856724378383`, 0.937410465258804], 
             UndirectedEdge[102, 222] -> 
             RGBColor[
              0.2549287084068188, 0.3852766143221994, 0.9378291848593165], 
             UndirectedEdge[86, 285] -> 
             RGBColor[
              0.7026108469912147, 0.7602147765402214, 0.7786951433273641], 
             UndirectedEdge[97, 340] -> 
             RGBColor[
              0.1979121571634553, 0.3253486039072797, 0.9345821766144358], 
             UndirectedEdge[84, 183] -> 
             RGBColor[
              0.3444123638438444, 0.47273441171796776`, 0.9431666291656026], 
             UndirectedEdge[23, 132] -> 
             RGBColor[
              0.32566481114992, 0.45504559524241234`, 0.9420251663053016], 
             UndirectedEdge[124, 210] -> 
             RGBColor[
              0.30769169180349737`, 0.4406429115045353, 0.9408372886035168], 
             UndirectedEdge[257, 288] -> 
             RGBColor[
              0.3142377899115303, 0.4462866876189422, 0.9412553567525421], 
             UndirectedEdge[31, 287] -> 
             RGBColor[
              0.19320443776430601`, 0.3204004923321242, 0.9343140789591009], 
             UndirectedEdge[163, 222] -> 
             RGBColor[
              0.24959037113759353`, 0.3796656833821117, 0.9375251744491964], 
             UndirectedEdge[206, 386] -> 
             RGBColor[
              0.7455369138645886, 0.8011383704922057, 0.975271810201597], 
             UndirectedEdge[95, 263] -> 
             RGBColor[
              0.47568127911611685`, 0.5835523041211401, 0.9523268989560933], 
             UndirectedEdge[103, 333] -> 
             RGBColor[
              0.19123001846776383`, 0.3183252524660446, 0.9342016387010543], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.19722342502912832`, 0.3246247027659626, 0.9345429543382737], 
             UndirectedEdge[57, 174] -> 
             RGBColor[
              0.28083864150489934`, 0.40925045112803254`, 0.9394240505070525],
              UndirectedEdge[32, 208] -> 
             RGBColor[0.97502376088894, 0.929050734989072, 0.526498655624491],
              UndirectedEdge[11, 125] -> 
             RGBColor[
              0.2867382877276377, 0.41841291007758175`, 0.9396515895329856], 
             UndirectedEdge[82, 136] -> 
             RGBColor[
              0.18265801399513343`, 0.30931553226883557`, 0.9337134757274823],
              UndirectedEdge[129, 298] -> 
             RGBColor[
              0.19304299486108434`, 0.3202308056047669, 0.9343048850245959], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.24346570234943876`, 0.37322826815933124`, 0.9371763836223466],
              UndirectedEdge[155, 306] -> 
             RGBColor[
              0.20489683816901277`, 0.33268994649847444`, 0.9349799438647926],
              UndirectedEdge[247, 358] -> 
             RGBColor[
              0.19420191296404457`, 0.3214489020106298, 0.9343708836960937], 
             UndirectedEdge[5, 373] -> 
             RGBColor[
              0.27714534160664284`, 0.4086277044311172, 0.939094389253483], 
             UndirectedEdge[194, 201] -> 
             RGBColor[
              0.9717877162352071, 0.9761148093624215, 0.8086618740541351], 
             UndirectedEdge[7, 173] -> 
             RGBColor[
              0.36556257674898185`, 0.48862517592323496`, 0.9446032208411446],
              UndirectedEdge[25, 364] -> 
             RGBColor[
              0.81749806012385, 0.1355033345765571, 0.16438946817681815`], 
             UndirectedEdge[1, 313] -> 
             RGBColor[
              0.20595700131663575`, 0.3338042451848521, 0.935040318587679], 
             UndirectedEdge[189, 222] -> 
             RGBColor[
              0.24951462814212214`, 0.379586072691488, 0.937520860997656], 
             UndirectedEdge[232, 275] -> 
             RGBColor[
              0.2669215798519661, 0.39788188260301705`, 0.9385121611462544], 
             UndirectedEdge[289, 376] -> 
             RGBColor[
              0.19788479388924796`, 0.32531984337115605`, 0.93458061831645], 
             UndirectedEdge[194, 208] -> 
             RGBColor[
              0.9937734715667986, 0.9910458830658546, 0.7058012226950569], 
             UndirectedEdge[320, 384] -> 
             RGBColor[
              0.1926752609493727, 0.31984429394788133`, 0.9342839431223373], 
             UndirectedEdge[262, 332] -> 
             RGBColor[
              0.22124807994982085`, 0.34987613833871123`, 0.9359111228947152],
              UndirectedEdge[39, 237] -> 
             RGBColor[
              0.19025421078354665`, 0.3172996167201517, 0.9341460678970164], 
             UndirectedEdge[105, 353] -> 
             RGBColor[
              0.19974831949640176`, 0.32727852693862247`, 0.9346867433429382],
              UndirectedEdge[160, 321] -> 
             RGBColor[
              0.5069925116479708, 0.6106383865650169, 0.9543314541731429], 
             UndirectedEdge[22, 354] -> 
             RGBColor[
              0.2660640348072204, 0.3962844071201169, 0.9384888143665844], 
             UndirectedEdge[70, 286] -> 
             RGBColor[
              0.20888058953085603`, 0.33687712176419665`, 0.9352068126114177],
              UndirectedEdge[97, 334] -> 
             RGBColor[
              0.1889352663956901, 0.3159133225426103, 0.9340709559653313], 
             UndirectedEdge[301, 362] -> 
             RGBColor[
              0.18593089634401205`, 0.31275553913023335`, 0.9338998615354555],
              UndirectedEdge[166, 300] -> 
             RGBColor[
              0.9521971792667703, 0.9624135645920178, 0.9060859398221737], 
             UndirectedEdge[357, 364] -> 
             RGBColor[
              0.8373888047327049, 0.2883923138200816, 0.1834368676776406], 
             UndirectedEdge[13, 66] -> 
             RGBColor[
              0.21421674509456057`, 0.34248575959345395`, 0.9355106987766358],
              UndirectedEdge[102, 395] -> 
             RGBColor[
              0.3730551581743753, 0.49423581065451916`, 0.9452125382842432], 
             UndirectedEdge[129, 336] -> 
             RGBColor[
              0.184720804255658, 0.3114836556211034, 0.9338309485811944], 
             UndirectedEdge[257, 275] -> 
             RGBColor[
              0.2809273627700829, 0.4112753166902168, 0.9393583772051975], 
             UndirectedEdge[358, 369] -> 
             RGBColor[
              0.19068675298749674`, 0.31775424600126295`, 0.9341707005356424],
              UndirectedEdge[42, 139] -> 
             RGBColor[
              0.20228682166276132`, 0.3299466536657998, 0.934831307285935], 
             UndirectedEdge[37, 206] -> 
             RGBColor[
              0.5395559184345032, 0.6328895346269106, 0.9586002858977685], 
             UndirectedEdge[3, 162] -> 
             RGBColor[
              0.42709887646193556`, 0.5374958425847769, 0.9495230473669047], 
             UndirectedEdge[44, 161] -> 
             RGBColor[
              0.2180648213930185, 0.34653033176526227`, 0.9357298410291143], 
             UndirectedEdge[67, 266] -> 
             RGBColor[
              0.3289874356394012, 0.4523479810161943, 0.9424410275338806], 
             UndirectedEdge[305, 360] -> 
             RGBColor[
              0.18374121717091801`, 0.3104540474856332, 0.9337751625458877], 
             UndirectedEdge[51, 174] -> 
             RGBColor[
              0.3627872108908755, 0.4886497806834403, 0.9443374581712001], 
             UndirectedEdge[132, 321] -> 
             RGBColor[
              0.4563174789356197, 0.5669174288296601, 0.9510551804528969], 
             UndirectedEdge[198, 236] -> 
             RGBColor[
              0.3020417872484481, 0.43067536553856556`, 0.9406630613787681], 
             UndirectedEdge[153, 356] -> 
             RGBColor[
              0.18871819494406902`, 0.31568516668383156`, 0.9340585940672899],
              UndirectedEdge[78, 217] -> 
             RGBColor[
              0.9065035834313075, 0.5709197086654001, 0.3268855973458845], 
             UndirectedEdge[16, 324] -> 
             RGBColor[
              0.47545256857995977`, 0.5813525434303296, 0.9528653912069069], 
             UndirectedEdge[263, 312] -> 
             RGBColor[
              0.3474308254202023, 0.4748091816311434, 0.9433787228228494], 
             UndirectedEdge[49, 231] -> 
             RGBColor[
              0.1849354051777754, 0.31170921479673314`, 0.9338431697862355], 
             UndirectedEdge[58, 303] -> 
             RGBColor[
              0.21259709598969448`, 0.3407834056925553, 0.9354184621561699], 
             UndirectedEdge[287, 371] -> 
             RGBColor[
              0.18823999048710255`, 0.315182543479646, 0.9340313610309057], 
             UndirectedEdge[108, 332] -> 
             RGBColor[
              0.24224909685408347`, 0.3719495386464692, 0.9371070997391926], 
             UndirectedEdge[55, 135] -> 
             RGBColor[
              0.9832367917164733, 0.9536721882994657, 0.5121416630539384], 
             UndirectedEdge[38, 145] -> 
             RGBColor[
              0.21009367554414693`, 0.338152152078261, 0.9352758960652745], 
             UndirectedEdge[41, 400] -> 
             RGBColor[
              0.861024743522975, 0.6436848292044157, 0.5916626524195524], 
             UndirectedEdge[184, 369] -> 
             RGBColor[
              0.1868540625349533, 0.3137258453290297, 0.9339524344843275], 
             UndirectedEdge[68, 363] -> 
             RGBColor[
              0.24496356786818765`, 0.3748026197896954, 0.9372616848477457], 
             UndirectedEdge[239, 350] -> 
             RGBColor[
              0.9108066927653387, 0.6030642712488816, 0.46289813781652445`], 
             UndirectedEdge[197, 300] -> 
             RGBColor[
              0.9395054889132312, 0.9538623530451078, 0.9685107634864926], 
             UndirectedEdge[34, 340] -> 
             RGBColor[
              0.23309142699709673`, 0.3623242469969716, 0.9365855839883956], 
             UndirectedEdge[99, 225] -> 
             RGBColor[
              0.9251735948093716, 0.9424003112075763, 0.9659587843040318], 
             UndirectedEdge[75, 218] -> 
             RGBColor[
              0.20441362479812614`, 0.3321820586081753, 0.9349524255781707], 
             UndirectedEdge[33, 256] -> 
             RGBColor[
              0.3139252578534664, 0.443350508209742, 0.9413330387606047], 
             UndirectedEdge[68, 173] -> 
             RGBColor[
              0.2762530439300684, 0.40768984299809713`, 0.9390435742208383], 
             UndirectedEdge[76, 368] -> 
             RGBColor[
              0.18953430680604916`, 0.3165429519952533, 0.9341050704305003], 
             UndirectedEdge[343, 369] -> 
             RGBColor[
              0.18630927681020493`, 0.31315324099090924`, 0.9339214097432413],
              UndirectedEdge[172, 243] -> 
             RGBColor[
              0.8966647112599999, 0.5803804357819402, 0.5534478412456459], 
             UndirectedEdge[25, 83] -> 
             RGBColor[
              0.881176745521725, 0.5463271969673706, 0.5710722243747279], 
             UndirectedEdge[176, 372] -> 
             RGBColor[
              0.2138686325253813, 0.34211987121163484`, 0.9354908742808075], 
             UndirectedEdge[211, 214] -> 
             RGBColor[
              0.23081730246588306`, 0.35993399792684283`, 0.9364560759606089],
              UndirectedEdge[273, 330] -> 
             RGBColor[
              0.18387764331179846`, 0.31059744000961553`, 0.9337829318127865],
              UndirectedEdge[247, 266] -> 
             RGBColor[
              0.21519016549381775`, 0.3435088861514912, 0.9355661336283271], 
             UndirectedEdge[294, 347] -> 
             RGBColor[
              0.19390550774844745`, 0.3211373613358611, 0.9343540038575576], 
             UndirectedEdge[247, 343] -> 
             RGBColor[
              0.18982443678675276`, 0.31684789700027605`, 0.9341215929036926],
              UndirectedEdge[147, 354] -> 
             RGBColor[
              0.1996644579713909, 0.3271903831587082, 0.9346819675531508], 
             UndirectedEdge[83, 206] -> 
             RGBColor[
              0.8376738526720509, 0.8738864473115988, 0.9758404514260404], 
             UndirectedEdge[178, 300] -> 
             RGBColor[
              0.6781948564694122, 0.7459060831571422, 0.9705455677828076], 
             UndirectedEdge[31, 384] -> 
             RGBColor[
              0.19301716646589862`, 0.32020365832381187`, 0.9343034141356996],
              UndirectedEdge[325, 339] -> 
             RGBColor[
              0.2703434502460814, 0.40147848534634617`, 0.9387070316029955], 
             UndirectedEdge[43, 237] -> 
             RGBColor[
              0.22884629711642387`, 0.3578623463356042, 0.9363438301217982], 
             UndirectedEdge[114, 128] -> 
             RGBColor[
              0.21795119041436695`, 0.34641089840207934`, 0.9357233699129821],
              UndirectedEdge[131, 188] -> 
             RGBColor[
              0.20752052535930418`, 0.3354476080868466, 0.9351293589688823], 
             UndirectedEdge[8, 352] -> 
             RGBColor[
              0.23870734178156489`, 0.36822692950501057`, 0.9369054020273697],
              UndirectedEdge[56, 137] -> 
             RGBColor[
              0.35805694536026106`, 0.48455266243088047`, 0.9440360498343989],
              UndirectedEdge[11, 93] -> 
             RGBColor[
              0.2731424573639435, 0.4041228303399058, 0.9388773271070019], 
             UndirectedEdge[232, 325] -> 
             RGBColor[
              0.29211597655452004`, 0.4243627909544146, 0.9399469447666949], 
             UndirectedEdge[293, 387] -> 
             RGBColor[
              0.4415101712045343, 0.5546415244104943, 0.9499598596294503], 
             UndirectedEdge[100, 175] -> 
             RGBColor[
              0.2458994336441635, 0.3757862740575634, 0.9373149810191983], 
             UndirectedEdge[327, 336] -> 
             RGBColor[
              0.18798018955468324`, 0.3149094762273428, 0.9340165657521455], 
             UndirectedEdge[230, 357] -> 
             RGBColor[
              0.8374194029311317, 0.28862750498140566`, 0.18346616854700978`],
              UndirectedEdge[151, 291] -> 
             RGBColor[
              0.1895972333261113, 0.3166090917576105, 0.9341086540027264], 
             UndirectedEdge[10, 87] -> 
             RGBColor[
              0.2178399723924833, 0.34629400120944975`, 0.9357170362111682], 
             UndirectedEdge[44, 247] -> 
             RGBColor[
              0.2171512777998561, 0.34557013952683935`, 0.9356778160729503], 
             UndirectedEdge[191, 334] -> 
             RGBColor[
              0.1961023648412683, 0.3234463974292005, 0.934479111619035], 
             UndirectedEdge[31, 389] -> 
             RGBColor[
              0.19956255990653143`, 0.3270832818318305, 0.9346761646091019], 
             UndirectedEdge[323, 346] -> 
             RGBColor[
              0.37487874320773873`, 0.4991228582382221, 0.9451079199183084], 
             UndirectedEdge[91, 257] -> 
             RGBColor[
              0.408201112318213, 0.5268994734386068, 0.9475311314318583], 
             UndirectedEdge[25, 217] -> 
             RGBColor[
              0.9051942941547533, 0.5608559375515845, 0.32563182045602546`], 
             UndirectedEdge[4, 238] -> 
             RGBColor[
              0.26140051176335477`, 0.3920788899859515, 0.9381977444862962], 
             UndirectedEdge[49, 298] -> 
             RGBColor[
              0.19233776426424887`, 0.31948956353329044`, 0.9342647231854012],
              UndirectedEdge[96, 245] -> 
             RGBColor[
              0.7835145897788575, 0.47447987208772324`, 0.5706010714513564], 
             UndirectedEdge[198, 219] -> 
             RGBColor[
              0.34521680439082036`, 0.47343117768740084`, 0.9432178874059169],
              UndirectedEdge[69, 106] -> 
             RGBColor[
              0.23431749208343802`, 0.36361291913973265`, 0.936655406581262], 
             UndirectedEdge[246, 350] -> 
             RGBColor[
              0.9570479117499637, 0.9654838538059254, 0.8719160935305621], 
             UndirectedEdge[91, 263] -> 
             RGBColor[
              0.44262523593919395`, 0.5567159191123393, 0.94972460614893], 
             UndirectedEdge[193, 305] -> 
             RGBColor[
              0.18458905889423072`, 0.311345182893105, 0.933823445877761], 
             UndirectedEdge[217, 244] -> 
             RGBColor[
              0.9739175055905028, 0.9766847910311653, 0.7242500801550553], 
             UndirectedEdge[218, 260] -> 
             RGBColor[
              0.20772118523879674`, 0.3356585143427644, 0.9351407862521698], 
             UndirectedEdge[115, 169] -> 
             RGBColor[
              0.8801983721871041, 0.6989200901607082, 0.599330145570115], 
             UndirectedEdge[152, 332] -> 
             RGBColor[
              0.24255699042787615`, 0.37227315431410535`, 0.9371246338227324],
              UndirectedEdge[8, 227] -> 
             RGBColor[
              0.22264092645081146`, 0.35134010832282114`, 0.9359904434424149],
              UndirectedEdge[161, 344] -> 
             RGBColor[
              0.1953522686165181, 0.3226579987381405, 0.9344363947487033], 
             UndirectedEdge[255, 324] -> 
             RGBColor[
              0.7342455134222807, 0.4929254711764368, 0.5728784243989717], 
             UndirectedEdge[135, 221] -> 
             RGBColor[
              0.9485753172801801, 0.8203317071995411, 0.46009294767531356`], 
             UndirectedEdge[179, 257] -> 
             RGBColor[
              0.38852623515624984`, 0.5109265218154098, 0.9459822530302189], 
             UndirectedEdge[40, 350] -> 
             RGBColor[
              0.7574551958384235, 0.806891984810095, 0.8535080309341501], 
             UndirectedEdge[358, 397] -> 
             RGBColor[
              0.20184959481572412`, 0.3294871005277804, 0.9348064078638154], 
             UndirectedEdge[44, 149] -> 
             RGBColor[
              0.22663901581167467`, 0.355542353734595, 0.9362181287168728], 
             UndirectedEdge[215, 218] -> 
             RGBColor[
              0.18692850160935742`, 0.31380408551593836`, 0.9339566736794921],
              UndirectedEdge[211, 248] -> 
             RGBColor[
              0.2199442042179371, 0.34850568227400514`, 0.9358368691006957], 
             UndirectedEdge[38, 103] -> 
             RGBColor[
              0.20863860950919683`, 0.3366227854190133, 0.9351930322071614], 
             UndirectedEdge[79, 213] -> 
             RGBColor[
              0.22683120635617676`, 0.355744358182451, 0.9362290736840618], 
             UndirectedEdge[116, 383] -> 
             RGBColor[
              0.19584602024074033`, 0.3231769630008592, 0.9344645131732627], 
             UndirectedEdge[214, 263] -> 
             RGBColor[
              0.315848849556003, 0.4416145225849462, 0.9415801760187297], 
             UndirectedEdge[203, 275] -> 
             RGBColor[
              0.232253685994867, 0.3614437280877808, 0.9365378758776455], 
             UndirectedEdge[235, 396] -> 
             RGBColor[
              0.19553592187284338`, 0.32285102995482734`, 0.9344468535299604],
              UndirectedEdge[170, 361] -> 
             RGBColor[
              0.22465020382752957`, 0.3534519862412956, 0.9361048688165594], 
             UndirectedEdge[190, 255] -> 
             RGBColor[
              0.8957903553105804, 0.6198388885195696, 0.570244438982581], 
             UndirectedEdge[67, 113] -> 
             RGBColor[
              0.36637406988619037`, 0.4916437040590915, 0.9445701410456664], 
             UndirectedEdge[244, 307] -> 
             RGBColor[
              0.651559964846024, 0.7209668023928419, 0.952436169214119], 
             UndirectedEdge[106, 292] -> 
             RGBColor[
              0.21060209943900177`, 0.3386865378276902, 0.9353048500539408], 
             UndirectedEdge[119, 126] -> 
             RGBColor[
              0.1845010944888899, 0.3112527267258263, 0.9338184364350084], 
             UndirectedEdge[148, 288] -> 
             RGBColor[
              0.3196747008606359, 0.4509958666159675, 0.9416017919105475], 
             UndirectedEdge[143, 277] -> 
             RGBColor[
              0.196429195674298, 0.32378991735698637`, 0.9344977241514731], 
             UndirectedEdge[245, 364] -> 
             RGBColor[
              0.8182535878829069, 0.14131065200704435`, 0.16511296241213771`],
              UndirectedEdge[101, 335] -> 
             RGBColor[
              0.18130162624818058`, 0.3078898827468379, 0.9336362314518891], 
             UndirectedEdge[175, 296] -> 
             RGBColor[
              0.26330595896968834`, 0.39408163581213873`, 0.9383062568858402],
              UndirectedEdge[106, 158] -> 
             RGBColor[
              0.2827874224549232, 0.411783246820848, 0.939517290657987], 
             UndirectedEdge[59, 319] -> 
             RGBColor[
              0.3999369554845372, 0.5208258336893123, 0.9467049354493426], 
             UndirectedEdge[159, 218] -> 
             RGBColor[
              0.18568639672443343`, 0.31249855452788494`, 0.9338859376438252],
              UndirectedEdge[126, 326] -> 
             RGBColor[
              0.18929893908149736`, 0.31629556559357375`, 0.9340916665867824],
              UndirectedEdge[130, 371] -> 
             RGBColor[
              0.18427986944939637`, 0.311020205182841, 0.9338058379962824], 
             UndirectedEdge[108, 262] -> 
             RGBColor[
              0.23515249805591343`, 0.36449056335924074`, 0.936702958936114], 
             UndirectedEdge[34, 91] -> 
             RGBColor[
              0.37827297461142906`, 0.4967706349329164, 0.9457781608227135], 
             UndirectedEdge[173, 323] -> 
             RGBColor[
              0.3405854460382354, 0.4669912406886779, 0.9430117001586653], 
             UndirectedEdge[104, 208] -> 
             RGBColor[
              0.906012199289136, 0.5692488389367173, 0.4656274775468996], 
             UndirectedEdge[115, 122] -> 
             RGBColor[
              0.7312854319265467, 0.5812953754272103, 0.5851154705993664], 
             UndirectedEdge[275, 297] -> 
             RGBColor[
              0.22283542703535522`, 0.35154454076922603`, 0.9360015199629668],
              UndirectedEdge[185, 293] -> 
             RGBColor[
              0.374247320413842, 0.49857595155038115`, 0.9450676862162266], 
             UndirectedEdge[92, 256] -> 
             RGBColor[
              0.42434961842059, 0.5407753734409124, 0.9485908039462863], 
             UndirectedEdge[135, 165] -> 
             RGBColor[
              0.9457959012350979, 0.9559420991486686, 0.8350019041226482], 
             UndirectedEdge[158, 270] -> 
             RGBColor[
              0.3489276916060272, 0.4766453616785984, 0.9434543418578613], 
             UndirectedEdge[35, 86] -> 
             RGBColor[
              0.32363709491798653`, 0.44803730928476804`, 0.942088262737994], 
             UndirectedEdge[124, 387] -> 
             RGBColor[
              0.42192783769441117`, 0.5376802913607258, 0.9487120906541628], 
             UndirectedEdge[170, 261] -> 
             RGBColor[
              0.2458172275622507, 0.3756998702533064, 0.9373102995044464], 
             UndirectedEdge[78, 244] -> 
             RGBColor[
              0.8873515007123038, 0.5600196245933966, 0.5640900365888891], 
             UndirectedEdge[320, 381] -> 
             RGBColor[
              0.19597803687805715`, 0.32331572085701743`, 0.9344720313254569],
              UndirectedEdge[90, 166] -> 
             RGBColor[
              0.7990367806379581, 0.841477411935373, 0.8913793888944332], 
             UndirectedEdge[119, 317] -> 
             RGBColor[
              0.1888850042427438, 0.31586049383305914`, 0.9340680936100771], 
             UndirectedEdge[173, 250] -> 
             RGBColor[
              0.27041365894161523`, 0.40155227913684066`, 0.9387110298843417],
              UndirectedEdge[234, 355] -> 
             RGBColor[
              0.7757149376246414, 0.8247136720150343, 0.978279673580333], 
             UndirectedEdge[203, 297] -> 
             RGBColor[
              0.2163387830881471, 0.3447161560696932, 0.9356315457010966], 
             UndirectedEdge[48, 388] -> 
             RGBColor[
              0.2298511238520014, 0.358918482944391, 0.9364010535178815], 
             UndirectedEdge[34, 95] -> 
             RGBColor[
              0.41132901778835196`, 0.5236070199417173, 0.9483804536298768], 
             UndirectedEdge[133, 299] -> 
             RGBColor[
              0.18672468895596034`, 0.31358986549474943`, 0.9339450668503949],
              UndirectedEdge[58, 376] -> 
             RGBColor[
              0.2107803074531337, 0.33887384574958357`, 0.9353149987367104], 
             UndirectedEdge[239, 392] -> 
             RGBColor[
              0.9094234148855309, 0.6024922502969611, 0.4858226320933391], 
             UndirectedEdge[64, 77] -> 
             RGBColor[
              0.18172630335562523`, 0.308336245312846, 0.9336604161849047], 
             UndirectedEdge[73, 112] -> 
             RGBColor[
              0.9338615942560703, 0.7754902910821886, 0.2656416901517646], 
             UndirectedEdge[257, 339] -> 
             RGBColor[
              0.2873260863715352, 0.41800078089785175`, 0.939722775048237], 
             UndirectedEdge[35, 85] -> 
             RGBColor[
              0.2384984047146932, 0.36800732340035325`, 0.9368935033705061], 
             UndirectedEdge[37, 187] -> 
             RGBColor[
              0.39185947335344506`, 0.5138307132141199, 0.9461899170277228], 
             UndirectedEdge[9, 39] -> 
             RGBColor[
              0.1871051393828018, 0.3139897430153101, 0.9339667329393776], 
             UndirectedEdge[136, 394] -> 
             RGBColor[
              0.18251086599702937`, 0.30916087039310625`, 0.9337050958666762],
              UndirectedEdge[287, 389] -> 
             RGBColor[
              0.19629053047607914`, 0.32364417144177693`, 0.9344898273735713],
              UndirectedEdge[195, 372] -> 
             RGBColor[
              0.19795832156921558`, 0.32539712562472617`, 0.9345848056090496],
              UndirectedEdge[149, 362] -> 
             RGBColor[
              0.20288427131655484`, 0.3305746111324327, 0.934865331159871], 
             UndirectedEdge[83, 321] -> 
             RGBColor[
              0.7496980165524652, 0.8038110466699736, 0.967993483257613], 
             UndirectedEdge[227, 308] -> 
             RGBColor[
              0.20448504246078797`, 0.33225712309977423`, 0.9349564927084064],
              UndirectedEdge[100, 146] -> 
             RGBColor[
              0.1981449486568544, 0.3255932825266753, 0.9345954337456006], 
             UndirectedEdge[100, 278] -> 
             RGBColor[
              0.23415669632153385`, 0.3634439125989312, 0.9366462495004977], 
             UndirectedEdge[234, 350] -> 
             RGBColor[
              0.8897866044520348, 0.9121284341385445, 0.8654271636734474], 
             UndirectedEdge[278, 352] -> 
             RGBColor[
              0.24888415157963256`, 0.37892340184978857`, 0.9374849562901288],
              UndirectedEdge[342, 353] -> 
             RGBColor[
              0.1868676578718124, 0.31374013489006275`, 0.9339532087186491], 
             UndirectedEdge[109, 181] -> 
             RGBColor[
              0.18812311022869774`, 0.31505969491742614`, 0.9340247048730984],
              UndirectedEdge[59, 296] -> 
             RGBColor[
              0.2957363483745861, 0.42467629385936273`, 0.9402809691977339], 
             UndirectedEdge[168, 378] -> 
             RGBColor[
              0.18751181267223727`, 0.3144171824270826, 0.9339898923815917], 
             UndirectedEdge[191, 370] -> 
             RGBColor[
              0.19715574767547106`, 0.3245535695762768, 0.9345391002131025], 
             UndirectedEdge[153, 184] -> 
             RGBColor[
              0.18277753601960423`, 0.3094411574946885, 0.933720282329959], 
             UndirectedEdge[3, 91] -> 
             RGBColor[
              0.5375833562526594, 0.6354734123169479, 0.9567396775183801], 
             UndirectedEdge[149, 210] -> 
             RGBColor[
              0.26112860842944113`, 0.3917931023423411, 0.9381822599936748], 
             UndirectedEdge[3, 312] -> 
             RGBColor[
              0.44238894573366777`, 0.553566674835752, 0.9503937941922995], 
             UndirectedEdge[17, 388] -> 
             RGBColor[
              0.22559527698605156`, 0.35444531805200136`, 0.9361586893348268],
              UndirectedEdge[99, 243] -> 
             RGBColor[
              0.9675815557220673, 0.9753429578546242, 0.9397601494648378], 
             UndirectedEdge[108, 398] -> 
             RGBColor[
              0.34112387915000547`, 0.4650235569768793, 0.9431351310396142], 
             UndirectedEdge[57, 186] -> 
             RGBColor[
              0.21226621689950026`, 0.3404356307898151, 0.9353996190814751], 
             UndirectedEdge[180, 398] -> 
             RGBColor[
              0.3423187854528118, 0.46627947926256413`, 0.9432031791858535], 
             UndirectedEdge[66, 318] -> 
             RGBColor[
              0.20433061997593613`, 0.33209481527724394`, 0.9349476985763416],
              UndirectedEdge[374, 382] -> 
             RGBColor[
              0.18605529017041303`, 0.3128862849288049, 0.9339069455798448], 
             UndirectedEdge[190, 270] -> 
             RGBColor[
              0.6576592800193992, 0.7261622336829004, 0.951547961847741], 
             UndirectedEdge[47, 96] -> 
             RGBColor[
              0.6461513889555156, 0.7219924964871992, 0.9663950668318202], 
             UndirectedEdge[245, 328] -> 
             RGBColor[
              0.8441804058989478, 0.32309654782053254`, 0.18925529611386532`],
              UndirectedEdge[142, 143] -> 
             RGBColor[
              0.1837659567931899, 0.3104800503972236, 0.9337765714307771], 
             UndirectedEdge[268, 373] -> 
             RGBColor[
              0.475607023803843, 0.5762529501811211, 0.9537345477094038], 
             UndirectedEdge[69, 390] -> 
             RGBColor[
              0.2522635992417797, 0.3824754156120626, 0.9376774108350432], 
             UndirectedEdge[91, 112] -> 
             RGBColor[
              0.7152028502193496, 0.6939405622428378, 0.6107535397674092], 
             UndirectedEdge[16, 190] -> 
             RGBColor[
              0.6369974104682594, 0.7082659607734624, 0.9502314057905163], 
             UndirectedEdge[40, 395] -> 
             RGBColor[
              0.494849422028799, 0.60078007937222, 0.9533755056767188], 
             UndirectedEdge[84, 246] -> 
             RGBColor[
              0.6295415881560444, 0.703574353083331, 0.9675332208830456], 
             UndirectedEdge[196, 376] -> 
             RGBColor[
              0.19966869054902864`, 0.32719483186616644`, 0.9346822085921858],
              UndirectedEdge[37, 311] -> 
             RGBColor[
              0.3257713181858094, 0.4560335502623456, 0.9419991567290754], 
             UndirectedEdge[179, 275] -> 
             RGBColor[
              0.34634920232824207`, 0.46792331791250663`, 0.9435317259645368],
              UndirectedEdge[334, 340] -> 
             RGBColor[
              0.1939578430419053, 0.32119236904753456`, 0.934356984275097], 
             UndirectedEdge[23, 366] -> 
             RGBColor[
              0.34372780451171075`, 0.47069085221995155`, 0.9431761242698371],
              UndirectedEdge[295, 351] -> 
             RGBColor[
              0.6694121408599306, 0.7384677850374681, 0.9699082105749879], 
             UndirectedEdge[358, 363] -> 
             RGBColor[
              0.20533835444542115`, 0.3331540080987284, 0.9350050875635693], 
             UndirectedEdge[111, 116] -> 
             RGBColor[
              0.1862942905711151, 0.31313748950344333`, 0.9339205562990953], 
             UndirectedEdge[147, 371] -> 
             RGBColor[
              0.18501189214807195`, 0.3117896074520688, 0.9338475256060415], 
             UndirectedEdge[33, 311] -> 
             RGBColor[
              0.28964287283882917`, 0.4217634021453914, 0.9398061051687154], 
             UndirectedEdge[137, 178] -> 
             RGBColor[
              0.3880768646119117, 0.5105544076416471, 0.9459488925435418], 
             UndirectedEdge[328, 386] -> 
             RGBColor[
              0.8151456848541535, 0.6567413505380229, 0.5948173850288303], 
             UndirectedEdge[20, 36] -> 
             RGBColor[
              0.19158305641128354`, 0.3186963177285822, 0.934221743689665], 
             UndirectedEdge[107, 212] -> 
             RGBColor[
              0.3829775514957524, 0.5061376389193594, 0.9456239688209257], 
             UndirectedEdge[21, 27] -> 
             RGBColor[
              0.8921201702935075, 0.5251244399562564, 0.23966354856549787`], 
             UndirectedEdge[138, 329] -> 
             RGBColor[
              0.18634787164566047`, 0.31319380661002694`, 0.9339236076620245],
              UndirectedEdge[3, 263] -> 
             RGBColor[
              0.48691076315351817`, 0.5926689051451934, 0.9532109250744729], 
             UndirectedEdge[239, 269] -> 
             RGBColor[
              0.785672209855677, 0.5070071531213871, 0.5746480096042236], 
             UndirectedEdge[74, 86] -> 
             RGBColor[
              0.6370413534700665, 0.7120367862892685, 0.9671058051428245], 
             UndirectedEdge[91, 179] -> 
             RGBColor[
              0.47362295187637204`, 0.5835474746608966, 0.9517044801911976], 
             UndirectedEdge[316, 358] -> 
             RGBColor[
              0.212564816221155, 0.34074947760916474`, 0.9354166238711052], 
             UndirectedEdge[154, 267] -> 
             RGBColor[
              0.23074964895808886`, 0.359862889800671, 0.9364522231934242], 
             UndirectedEdge[25, 357] -> 
             RGBColor[
              0.837209744608855, 0.2870159792435245, 0.18326539950082243`], 
             UndirectedEdge[118, 388] -> 
             RGBColor[
              0.2291977478565746, 0.35823174334676655`, 0.936363844721525], 
             UndirectedEdge[305, 340] -> 
             RGBColor[
              0.19258396167334632`, 0.31974833262006913`, 0.9342787437636328],
              UndirectedEdge[100, 213] -> 
             RGBColor[
              0.21638299645224862`, 0.344762627118653, 0.9356340635867745], 
             UndirectedEdge[51, 238] -> 
             RGBColor[
              0.3357800727610889, 0.463522711822467, 0.942680108320078], 
             UndirectedEdge[104, 242] -> 
             RGBColor[
              0.8356412746575417, 0.27496003188981555`, 0.1817634309041114], 
             UndirectedEdge[99, 337] -> 
             RGBColor[
              0.9798418672906987, 0.9817838609022704, 0.7682315700129669], 
             UndirectedEdge[143, 302] -> 
             RGBColor[
              0.1882090973662136, 0.3151500728508547, 0.9340296017133733], 
             UndirectedEdge[14, 327] -> 
             RGBColor[
              0.19007805312865012`, 0.317114463855815, 0.9341360359791719], 
             UndirectedEdge[162, 348] -> 
             RGBColor[
              0.3027342580511927, 0.4332679187418763, 0.9406342199418414], 
             UndirectedEdge[130, 391] -> 
             RGBColor[
              0.18156952589467779`, 0.3081714622611251, 0.9336514879404352], 
             UndirectedEdge[182, 386] -> 
             RGBColor[
              0.5546461678159978, 0.6446668165900299, 0.9601091386691207], 
             UndirectedEdge[32, 217] -> 
             RGBColor[
              0.975050917301262, 0.9271533469602427, 0.3873122304251019], 
             UndirectedEdge[3, 285] -> 
             RGBColor[
              0.7880339609127915, 0.8307135264515318, 0.7851026525209982], 
             UndirectedEdge[212, 274] -> 
             RGBColor[
              0.45520745425599235`, 0.5676199598754534, 0.950524688408067], 
             UndirectedEdge[234, 272] -> 
             RGBColor[
              0.7633280108193825, 0.8150369106506357, 0.9770450604787972], 
             UndirectedEdge[24, 104] -> 
             RGBColor[
              0.8198979870257355, 0.15395022439912315`, 0.1666876408883935], 
             UndirectedEdge[317, 327] -> 
             RGBColor[
              0.19548056477531295`, 0.3227928461354802, 0.9344437010251496], 
             UndirectedEdge[85, 263] -> 
             RGBColor[
              0.31634895902864796`, 0.44214016934946804`, 0.941608656513351], 
             UndirectedEdge[169, 300] -> 
             RGBColor[
              0.9052440838676142, 0.9272810765527117, 0.9908241829118685], 
             UndirectedEdge[34, 162] -> 
             RGBColor[
              0.2677884948207052, 0.39879306520074553`, 0.9385615306712383], 
             UndirectedEdge[62, 313] -> 
             RGBColor[
              0.20973650567435648`, 0.3377767438992335, 0.9352555557695754], 
             UndirectedEdge[337, 367] -> 
             RGBColor[
              0.6845644891406854, 0.7444870601720963, 0.7692660513213518], 
             UndirectedEdge[21, 240] -> 
             RGBColor[
              0.8974455137213154, 0.5660573631227573, 0.24476310344608182`], 
             UndirectedEdge[258, 378] -> 
             RGBColor[
              0.18711323001988966`, 0.3139982467878655, 0.9339671936891907], 
             UndirectedEdge[240, 242] -> 
             RGBColor[
              0.8419811748449504, 0.32369128289221516`, 0.18783452648346705`],
              UndirectedEdge[16, 380] -> 
             RGBColor[
              0.26894987250182517`, 0.3991789072508731, 0.9386582369767682], 
             UndirectedEdge[38, 222] -> 
             RGBColor[
              0.22765792346573496`, 0.35661329028148886`, 0.9362761540004327],
              UndirectedEdge[61, 147] -> 
             RGBColor[
              0.19642039468713995`, 0.32378066696146846`, 0.9344972229482744],
              UndirectedEdge[279, 288] -> 
             RGBColor[
              0.4888026931766387, 0.5910842948036721, 0.9543337450913586], 
             UndirectedEdge[192, 384] -> 
             RGBColor[
              0.1855895073220066, 0.3123967176227914, 0.933880419935692], 
             UndirectedEdge[196, 289] -> 
             RGBColor[
              0.18795157808443957`, 0.3148794037580448, 0.934014936371242], 
             UndirectedEdge[9, 384] -> 
             RGBColor[
              0.19029625552141455`, 0.3173438084054412, 0.9341484622826384], 
             UndirectedEdge[114, 187] -> 
             RGBColor[
              0.33810546577905015`, 0.4610349816709624, 0.9429931157731941], 
             UndirectedEdge[90, 274] -> 
             RGBColor[
              0.5507285778663977, 0.6461452954084659, 0.9577745175163469], 
             UndirectedEdge[270, 324] -> 
             RGBColor[
              0.49611443813109957`, 0.5992488163397677, 0.9541819472641316], 
             UndirectedEdge[42, 45] -> 
             RGBColor[
              0.2506616815740248, 0.3807916985758058, 0.9375861839936894], 
             UndirectedEdge[316, 363] -> 
             RGBColor[
              0.2271273365064473, 0.3560556097461213, 0.9362459378580343], 
             UndirectedEdge[44, 250] -> 
             RGBColor[
              0.24751102743025372`, 0.3774801613076919, 0.9374067589011768], 
             UndirectedEdge[213, 352] -> 
             RGBColor[
              0.23111045171034733`, 0.3602421163695104, 0.9364727703764056], 
             UndirectedEdge[80, 378] -> 
             RGBColor[
              0.18531329630253898`, 0.3121064023285408, 0.9338646901267509], 
             UndirectedEdge[238, 272] -> 
             RGBColor[
              0.5154577316990447, 0.6098310076277607, 0.9573191957441505], 
             UndirectedEdge[126, 196] -> 
             RGBColor[
              0.1881608487233165, 0.3150993604680292, 0.9340268540245378], 
             UndirectedEdge[112, 240] -> 
             RGBColor[
              0.8843983974342954, 0.516470613459494, 0.2231161879418313], 
             UndirectedEdge[52, 89] -> 
             RGBColor[
              0.18430520538442102`, 0.31104683485694296`, 0.933807280840301], 
             UndirectedEdge[99, 177] -> 
             RGBColor[
              0.9302447173684912, 0.9464438866842635, 0.9664424725007652], 
             UndirectedEdge[41, 206] -> 
             RGBColor[
              0.8010921103082493, 0.8449578955447232, 0.9806977415425538], 
             UndirectedEdge[1, 119] -> 
             RGBColor[
              0.18798137752672578`, 0.3149107248612813, 0.9340166334053959], 
             UndirectedEdge[2, 109] -> 
             RGBColor[
              0.1831541470606865, 0.30983699957738503`, 0.9337417297716024], 
             UndirectedEdge[8, 100] -> 
             RGBColor[
              0.22397988652346618`, 0.35274744025415317`, 0.9360666952377386],
              UndirectedEdge[203, 322] -> 
             RGBColor[
              0.2128310735235297, 0.3410293309156486, 0.935431786830583], 
             UndirectedEdge[98, 193] -> 
             RGBColor[
              0.1939801662783198, 0.32121583218438116`, 0.9343582555503864], 
             UndirectedEdge[141, 285] -> 
             RGBColor[
              0.9298982865463443, 0.7362961374607975, 0.4097714679426784], 
             UndirectedEdge[29, 231] -> 
             RGBColor[
              0.1818156421264654, 0.3084301460254042, 0.9336655038957391], 
             UndirectedEdge[225, 398] -> 
             RGBColor[
              0.6554022589203814, 0.7271955623129416, 0.9686184880711814], 
             UndirectedEdge[149, 359] -> 
             RGBColor[
              0.20190369877404518`, 0.3295439672183649, 0.9348094890042022], 
             UndirectedEdge[87, 235] -> 
             RGBColor[
              0.1948464738725398, 0.3221263763929803, 0.9344075904862901], 
             UndirectedEdge[162, 312] -> 
             RGBColor[
              0.28761893872861966`, 0.41963611907072695`, 0.9396908451152812],
              UndirectedEdge[392, 395] -> 
             RGBColor[
              0.729861417537885, 0.7850410988470374, 0.8743691386056183], 
             UndirectedEdge[212, 268] -> 
             RGBColor[
              0.5483496579696843, 0.6426701443947892, 0.9582447440009759], 
             UndirectedEdge[50, 271] -> 
             RGBColor[
              0.17906803055065768`, 0.3055422320505946, 0.933509031481224], 
             UndirectedEdge[200, 207] -> 
             RGBColor[
              0.1859857863076916, 0.31281323196228517`, 0.9339029874376845], 
             UndirectedEdge[360, 370] -> 
             RGBColor[
              0.18616848137367975`, 0.313005256060175, 0.9339133916514194], 
             UndirectedEdge[134, 246] -> 
             RGBColor[
              0.8756067697264411, 0.9036490867400013, 0.9879973494315406], 
             UndirectedEdge[88, 191] -> 
             RGBColor[
              0.19934659159346146`, 0.326856285441612, 0.9346638655331689], 
             UndirectedEdge[277, 278] -> 
             RGBColor[
              0.23299059780069237`, 0.3622182691186103, 0.9365798419148239], 
             UndirectedEdge[233, 242] -> 
             RGBColor[
              0.9058398899715292, 0.686023971327602, 0.5756445160215393], 
             UndirectedEdge[66, 123] -> 
             RGBColor[
              0.21298431371887483`, 0.3411903960769459, 0.9354405136330093], 
             UndirectedEdge[315, 316] -> 
             RGBColor[
              0.22659989124895852`, 0.3555012313385397, 0.9362159006309058], 
             UndirectedEdge[127, 216] -> 
             RGBColor[
              0.19725740387013102`, 0.32466041668223944`, 0.9345448893830015],
              UndirectedEdge[29, 326] -> 
             RGBColor[
              0.18672499245337307`, 0.31359018448977305`, 0.9339450841341236],
              UndirectedEdge[76, 145] -> 
             RGBColor[
              0.19557703724460856`, 0.3228942448174177, 0.9344491949895577], 
             UndirectedEdge[21, 104] -> 
             RGBColor[
              0.8911056135339068, 0.5173261121203578, 0.23869200786672617`], 
             UndirectedEdge[27, 112] -> 
             RGBColor[
              0.8790730540064875, 0.47553769029299303`, 0.21801663306124733`],
              UndirectedEdge[190, 221] -> 
             RGBColor[
              0.9292638455200164, 0.8080779972178733, 0.5995947563336426], 
             UndirectedEdge[310, 324] -> 
             RGBColor[
              0.45636436031597766`, 0.5621244658109066, 0.9517477784200521], 
             UndirectedEdge[11, 312] -> 
             RGBColor[
              0.30743684398278903`, 0.44016840506601096`, 0.9408303416909466],
              UndirectedEdge[177, 225] -> 
             RGBColor[
              0.8897813970600477, 0.9149515498158103, 0.9893493380404593], 
             UndirectedEdge[253, 316] -> 
             RGBColor[
              0.2127233679212677, 0.3409161254987416, 0.9354256531558705], 
             UndirectedEdge[17, 323] -> 
             RGBColor[
              0.3151837063156497, 0.44029240167692024`, 0.9415651086599703], 
             UndirectedEdge[315, 397] -> 
             RGBColor[
              0.21588466984352767`, 0.3442388542571554, 0.935605684623616], 
             UndirectedEdge[43, 296] -> 
             RGBColor[
              0.2526601828418626, 0.38289225012060224`, 0.937699995684375], 
             UndirectedEdge[50, 287] -> 
             RGBColor[
              0.18448432655099875`, 0.31123510255995407`, 0.9338174815257515],
              UndirectedEdge[253, 369] -> 
             RGBColor[
              0.19084530468760944`, 0.3179208938908398, 0.9341797298204076], 
             UndirectedEdge[187, 220] -> 
             RGBColor[
              0.5353714211663698, 0.63317812373389, 0.9567035702854296], 
             UndirectedEdge[211, 340] -> 
             RGBColor[
              0.21241214123474167`, 0.34058900651829105`, 0.9354079292564914],
              UndirectedEdge[213, 227] -> 
             RGBColor[
              0.2150440363795939, 0.343355295187321, 0.9355578117914507], 
             UndirectedEdge[17, 389] -> 
             RGBColor[
              0.21716250001380405`, 0.34558193478522814`, 0.9356784551614329],
              UndirectedEdge[117, 376] -> 
             RGBColor[
              0.217871456795024, 0.34632709331274647`, 0.9357188292013159], 
             UndirectedEdge[186, 330] -> 
             RGBColor[
              0.19639093276449526`, 0.3237497006127751, 0.9344955451353647], 
             UndirectedEdge[24, 337] -> 
             RGBColor[
              0.9074168352108218, 0.5752287479070755, 0.3804750196277067], 
             UndirectedEdge[73, 99] -> 
             RGBColor[
              0.9481261161147958, 0.8682562660194123, 0.6030407890629428], 
             UndirectedEdge[114, 155] -> 
             RGBColor[
              0.2241859587617661, 0.352964035242341, 0.9360784307468533], 
             UndirectedEdge[123, 232] -> 
             RGBColor[
              0.2533953304852037, 0.3836649369048065, 0.9377418612551098], 
             UndirectedEdge[53, 289] -> 
             RGBColor[
              0.18928237138329773`, 0.3162781518923132, 0.9340907230808797], 
             UndirectedEdge[126, 376] -> 
             RGBColor[
              0.19809406452812484`, 0.3255398000811405, 0.9345925359697458], 
             UndirectedEdge[207, 254] -> 
             RGBColor[
              0.18750231875154622`, 0.3144072037144869, 0.9339893517168534], 
             UndirectedEdge[291, 304] -> 
             RGBColor[
              0.1840328398717771, 0.3107605614341833, 0.9337917700272845], 
             UndirectedEdge[333, 368] -> 
             RGBColor[
              0.18664235406415453`, 0.3135033263031278, 0.9339403780001101], 
             UndirectedEdge[26, 171] -> 
             RGBColor[
              0.18798107467478986`, 0.3149104065446947, 0.9340166161584262], 
             UndirectedEdge[81, 384] -> 
             RGBColor[
              0.18455785037421688`, 0.3113123807598359, 0.9338216685987151], 
             UndirectedEdge[120, 233] -> 
             RGBColor[
              0.7388527640498924, 0.7945317751585553, 0.9544100950493892], 
             UndirectedEdge[224, 290] -> 
             RGBColor[
              0.18877579274929696`, 0.3157457056290379, 0.9340618741770893], 
             UndirectedEdge[393, 396] -> 
             RGBColor[
              0.19146055662429076`, 0.3185675626855177, 0.9342147675080179], 
             UndirectedEdge[2, 365] -> 
             RGBColor[
              0.18295812271216946`, 0.3096309655584321, 0.9337305664749465], 
             UndirectedEdge[210, 387] -> 
             RGBColor[
              0.4198898949581986, 0.5356292280658739, 0.9485927029346032], 
             UndirectedEdge[23, 307] -> 
             RGBColor[
              0.32070535665531497`, 0.4507499650286162, 0.9417091542503788], 
             UndirectedEdge[120, 244] -> 
             RGBColor[
              0.7365322986249497, 0.7928011758440465, 0.9583380377395063], 
             UndirectedEdge[42, 248] -> 
             RGBColor[
              0.21725641238251098`, 0.34568064263912723`, 0.9356838033318999],
              UndirectedEdge[49, 393] -> 
             RGBColor[
              0.1855205539729795, 0.3123242432810691, 0.9338764931444723], 
             UndirectedEdge[375, 377] -> 
             RGBColor[
              0.18266643619111367`, 0.3093243845308089, 0.9337139553590839], 
             UndirectedEdge[269, 350] -> 
             RGBColor[
              0.8687159863176557, 0.8956679071093385, 0.8633270413739342], 
             UndirectedEdge[77, 207] -> 
             RGBColor[
              0.18528324242742453`, 0.31207481380026975`, 0.9338629786030239],
              UndirectedEdge[200, 368] -> 
             RGBColor[
              0.18469320535133593`, 0.3114546474227893, 0.9338293768644222], 
             UndirectedEdge[384, 389] -> 
             RGBColor[
              0.1961032591776717, 0.32344733743346465`, 0.93447916255017], 
             UndirectedEdge[1, 361] -> 
             RGBColor[
              0.205591391562574, 0.33341996615233593`, 0.9350194976530564], 
             UndirectedEdge[150, 380] -> 
             RGBColor[
              0.20683506244234898`, 0.3347271431002675, 0.9350903228698133], 
             UndirectedEdge[150, 381] -> 
             RGBColor[
              0.19485465175919953`, 0.32213497187036766`, 0.9344080562048372],
              UndirectedEdge[232, 279] -> 
             RGBColor[
              0.48366351594508233`, 0.5856826936906501, 0.9540410765507529], 
             UndirectedEdge[132, 341] -> 
             RGBColor[
              0.34725423307667924`, 0.4751958960109486, 0.9433477105601525], 
             UndirectedEdge[1, 14] -> 
             RGBColor[
              0.18904790384743964`, 0.31603171164602595`, 0.9340773705015762],
              UndirectedEdge[171, 342] -> 
             RGBColor[
              0.18633859981298379`, 0.3131840613260155, 0.9339230796448701], 
             UndirectedEdge[140, 325] -> 
             RGBColor[
              0.25741913844630737`, 0.3878942141960865, 0.9379710111658044], 
             UndirectedEdge[89, 306] -> 
             RGBColor[
              0.1959786892882613, 0.3233164065815071, 0.9344720684792528], 
             UndirectedEdge[130, 147] -> 
             RGBColor[
              0.18274418895711692`, 0.3094061076176884, 0.9337183832640827], 
             UndirectedEdge[4, 183] -> 
             RGBColor[
              0.2914028738694214, 0.4198002713108441, 0.9400459473606144], 
             UndirectedEdge[80, 151] -> 
             RGBColor[
              0.18591365690063838`, 0.3127374193822037, 0.9338988797746588], 
             UndirectedEdge[236, 286] -> 
             RGBColor[
              0.22281035809500455`, 0.3515181917234548, 0.9360000923239], 
             UndirectedEdge[108, 180] -> 
             RGBColor[
              0.25734842126298235`, 0.38781988595268346`, 0.9379669839268308],
              UndirectedEdge[9, 320] -> 
             RGBColor[
              0.1934136507337484, 0.32062038842787655`, 0.9343259933282078], 
             UndirectedEdge[35, 97] -> 
             RGBColor[
              0.21457055736469166`, 0.3428576387223553, 0.9355308478620015], 
             UndirectedEdge[154, 236] -> 
             RGBColor[
              0.22814394288837742`, 0.3571241275100973, 0.936303832087551], 
             UndirectedEdge[60, 259] -> 
             RGBColor[
              0.18612091931381164`, 0.3129552653196448, 0.9339106830624717], 
             UndirectedEdge[179, 399] -> 
             RGBColor[
              0.6902620685345601, 0.6570900539452929, 0.6049675909800379], 
             UndirectedEdge[314, 352] -> 
             RGBColor[
              0.23613835462959704`, 0.3655267611250992, 0.9367591020095412], 
             UndirectedEdge[85, 88] -> 
             RGBColor[
              0.21610734049788477`, 0.34447289523301966`, 0.9356183653879699],
              UndirectedEdge[70, 267] -> 
             RGBColor[
              0.23945129119348169`, 0.3690088675060522, 0.9369477688458039], 
             UndirectedEdge[31, 192] -> 
             RGBColor[
              0.18904880805086632`, 0.3160326620211572, 0.9340774219946237], 
             UndirectedEdge[221, 255] -> 
             RGBColor[
              0.8688348859370216, 0.46104786848874635`, 0.21084573587576866`],
              UndirectedEdge[11, 211] -> 
             RGBColor[
              0.2669271143125195, 0.39759011071734907`, 0.9385233725149993], 
             UndirectedEdge[211, 312] -> 
             RGBColor[
              0.26239927833008236`, 0.39312865697304, 0.9382546227647286], 
             UndirectedEdge[123, 280] -> 
             RGBColor[
              0.23161694690439888`, 0.3607744749321087, 0.9365016145284144], 
             UndirectedEdge[178, 278] -> 
             RGBColor[
              0.349928065209785, 0.47283535767355744`, 0.9436893135230188], 
             UndirectedEdge[83, 364] -> 
             RGBColor[
              0.8813558056455749, 0.5477035315439278, 0.5712436925515461], 
             UndirectedEdge[10, 313] -> 
             RGBColor[
              0.22793409689467709`, 0.35690356606571383`, 0.9362918816686491],
              UndirectedEdge[32, 242] -> 
             RGBColor[
              0.9046528362573457, 0.6347619279421703, 0.24263460898170292`], 
             UndirectedEdge[44, 369] -> 
             RGBColor[
              0.21363611782330827`, 0.34187548351747254`, 0.9354776329124991],
              UndirectedEdge[110, 375] -> 
             RGBColor[
              0.18201536929507323`, 0.30864007194304494`, 0.9336768780625215],
              UndirectedEdge[275, 290] -> 
             RGBColor[
              0.21848378643908228`, 0.34697069059259356`, 0.9357537004686844],
              UndirectedEdge[362, 369] -> 
             RGBColor[
              0.18988137332818844`, 0.31690774091531027`, 0.9341248353554973],
              UndirectedEdge[266, 338] -> 
             RGBColor[
              0.23347632110247196`, 0.3627287951054168, 0.936607503138297], 
             UndirectedEdge[350, 395] -> 
             RGBColor[
              0.7312446954176929, 0.785613119798958, 0.8514446443288036], 
             UndirectedEdge[141, 172] -> 
             RGBColor[
              0.8447003804638847, 0.3332796121494973, 0.18999546480661883`], 
             UndirectedEdge[123, 275] -> 
             RGBColor[
              0.22522408057531274`, 0.3540551670891031, 0.9361375502483711], 
             UndirectedEdge[46, 315] -> 
             RGBColor[
              0.21006971303598748`, 0.3381269659628746, 0.9352745314358842], 
             UndirectedEdge[185, 205] -> 
             RGBColor[
              0.3748090292582385, 0.49906247551909, 0.9451034778070919], 
             UndirectedEdge[3, 86] -> 
             RGBColor[
              0.49644576954540676`, 0.6009276484384913, 0.9538184872502891], 
             UndirectedEdge[316, 397] -> 
             RGBColor[
              0.2236385768767503, 0.3523887021751733, 0.9360472581582806], 
             UndirectedEdge[11, 214] -> 
             RGBColor[
              0.2758548681185897, 0.40697374601981373`, 0.9390317948868268], 
             UndirectedEdge[3, 34] -> 
             RGBColor[
              0.4225585018257533, 0.5327236209657705, 0.9492644797482566], 
             UndirectedEdge[5, 100] -> 
             RGBColor[
              0.24629351933764826`, 0.37620048310789195`, 0.9373374236164447],
              UndirectedEdge[25, 245] -> 
             RGBColor[
              0.8180745277590571, 0.13993431743048723`, 0.16494149423531956`],
              UndirectedEdge[183, 325] -> 
             RGBColor[
              0.3195630144976964, 0.44939836456720006`, 0.9416496257101998], 
             UndirectedEdge[149, 266] -> 
             RGBColor[
              0.22467790350563632`, 0.35348110035924685`, 0.9361064462722496],
              UndirectedEdge[73, 78] -> 
             RGBColor[
              0.8752764478324426, 0.45843721309521324`, 0.21487760657063304`],
              UndirectedEdge[40, 167] -> 
             RGBColor[
              0.4156571514498516, 0.5326037138579458, 0.948214502475271], 
             UndirectedEdge[5, 175] -> 
             RGBColor[
              0.282045444074704, 0.41377802280949016`, 0.9393734428399871], 
             UndirectedEdge[279, 309] -> 
             RGBColor[
              0.48491537307549215`, 0.5869984749070372, 0.9541123679623731], 
             UndirectedEdge[66, 257] -> 
             RGBColor[
              0.268687595913645, 0.3984105456780595, 0.9386613405898359], 
             UndirectedEdge[238, 309] -> 
             RGBColor[
              0.29378936272937667`, 0.4261216259230004, 0.9400422416338], 
             UndirectedEdge[40, 355] -> 
             RGBColor[
              0.6433835290110301, 0.7194772226865849, 0.9663605408410356], 
             UndirectedEdge[31, 271] -> 
             RGBColor[
              0.18778814176396494`, 0.3147076218227647, 0.9340056289145733], 
             UndirectedEdge[271, 391] -> 
             RGBColor[
              0.1801133509320429, 0.3066409300485706, 0.9335685609305309], 
             UndirectedEdge[264, 348] -> 
             RGBColor[
              0.5282156563331551, 0.6233653822352514, 0.957751476691993], 
             UndirectedEdge[146, 302] -> 
             RGBColor[
              0.18875875182792845`, 0.3157277945402228, 0.9340609037218272], 
             UndirectedEdge[86, 91] -> 
             RGBColor[
              0.45216024233108254`, 0.5649746624056373, 0.950332168324746], 
             UndirectedEdge[232, 257] -> 
             RGBColor[
              0.30909861267997385`, 0.4408850865059202, 0.9409626882119364], 
             UndirectedEdge[201, 385] -> 
             RGBColor[
              0.9717345415002878, 0.9760010739812197, 0.8028741323146045], 
             UndirectedEdge[204, 297] -> 
             RGBColor[
              0.2002775476373886, 0.32783477926980176`, 0.9347168821026446], 
             UndirectedEdge[241, 323] -> 
             RGBColor[
              0.3309521511254019, 0.4568660369491151, 0.9424630982645621], 
             UndirectedEdge[269, 395] -> 
             RGBColor[
              0.6061102125080312, 0.6895560016714635, 0.9631945161165028], 
             UndirectedEdge[52, 342] -> 
             RGBColor[
              0.18153992013799802`, 0.30814034473374124`, 0.9336498019363901],
              UndirectedEdge[201, 245] -> 
             RGBColor[
              0.8839369101698967, 0.553629569307468, 0.5684023912498125], 
             UndirectedEdge[131, 330] -> 
             RGBColor[
              0.199593351679308, 0.3271156459373298, 0.9346779181550091], 
             UndirectedEdge[159, 349] -> 
             RGBColor[
              0.191248937492894, 0.31834513756099186`, 0.9342027161115474], 
             UndirectedEdge[15, 33] -> 
             RGBColor[
              0.28118366953987284`, 0.41287224313372134`, 0.9393243660551096],
              UndirectedEdge[16, 212] -> 
             RGBColor[
              0.36755596390986156`, 0.4927802348639901, 0.9446413188967272], 
             UndirectedEdge[246, 269] -> 
             RGBColor[
              0.8319134288403021, 0.869426735678431, 0.9836659653182612], 
             UndirectedEdge[150, 294] -> 
             RGBColor[
              0.19175282420721007`, 0.318874754446001, 0.9342314117144941], 
             UndirectedEdge[77, 200] -> 
             RGBColor[
              0.1835118014697444, 0.3102129170379042, 0.9337620976610961], 
             UndirectedEdge[21, 285] -> 
             RGBColor[
              0.9787005711665018, 0.9387674260406853, 0.4607634302742779], 
             UndirectedEdge[275, 280] -> 
             RGBColor[
              0.24514319627116127`, 0.3749914206303192, 0.9372719144195587], 
             UndirectedEdge[171, 353] -> 
             RGBColor[
              0.1894918158351776, 0.3164982912907842, 0.9341026506325689], 
             UndirectedEdge[197, 252] -> 
             RGBColor[
              0.6669388623748537, 0.7337127880117662, 0.9450324457252983], 
             UndirectedEdge[15, 361] -> 
             RGBColor[
              0.2517308007762076, 0.3819154106433724, 0.9376470687506336], 
             UndirectedEdge[348, 366] -> 
             RGBColor[
              0.3637695245894192, 0.4895006114365967, 0.9444000503314454], 
             UndirectedEdge[235, 298] -> 
             RGBColor[
              0.19425582793699694`, 0.3215055700656095, 0.9343739540740432], 
             UndirectedEdge[62, 298] -> 
             RGBColor[
              0.19905173523661984`, 0.32654637271559867`, 0.9346470738998478],
              UndirectedEdge[110, 308] -> 
             RGBColor[
              0.1924672891129, 0.3196257023615725, 0.9342720994339171], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.2089266760744028, 0.33692556164351994`, 0.9352094371718936], 
             UndirectedEdge[204, 290] -> 
             RGBColor[
              0.19592590704111568`, 0.32326092909316934`, 0.9344690626083623],
              UndirectedEdge[35, 93] -> 
             RGBColor[
              0.235285884487402, 0.3646307609559235, 0.9367105550960597], 
             UndirectedEdge[162, 211] -> 
             RGBColor[
              0.24710920905835015`, 0.37705782472206506`, 0.9373838759393338],
              UndirectedEdge[66, 275] -> 
             RGBColor[
              0.22651056308563722`, 0.3554073417751564, 0.9362108135241538], 
             UndirectedEdge[36, 277] -> 
             RGBColor[
              0.20034660319217895`, 0.3279073610362615, 0.9347208147143313], 
             UndirectedEdge[174, 246] -> 
             RGBColor[
              0.6321209059841302, 0.7058084285457353, 0.96769757273425], 
             UndirectedEdge[218, 329] -> 
             RGBColor[
              0.19065196008399016`, 0.31771767645368004`, 0.9341687191312593],
              UndirectedEdge[186, 188] -> 
             RGBColor[
              0.20431810644449144`, 0.33208166276229184`, 0.934946985949238], 
             UndirectedEdge[230, 245] -> 
             RGBColor[
              0.8182841860813337, 0.14154584316836838`, 0.16514226328150688`],
              UndirectedEdge[57, 368] -> 
             RGBColor[
              0.20142644533340448`, 0.3290423435926357, 0.9347823101267909], 
             UndirectedEdge[293, 316] -> 
             RGBColor[
              0.2916240499210687, 0.42013376007774095`, 0.9400548442196108], 
             UndirectedEdge[8, 308] -> 
             RGBColor[
              0.21965638014980107`, 0.34820316092929426`, 0.9358204779458129],
              UndirectedEdge[37, 361] -> 
             RGBColor[
              0.28321730845770904`, 0.41130658795806163`, 0.939575768828076], 
             UndirectedEdge[19, 331] -> 
             RGBColor[
              0.22977587045111889`, 0.35883938684872224`, 0.9363967679480286],
              UndirectedEdge[98, 276] -> 
             RGBColor[
              0.21193626472305038`, 0.34008883013219005`, 0.9353808287931467],
              UndirectedEdge[326, 336] -> 
             RGBColor[
              0.18618247361472157`, 0.3130199627926692, 0.9339141884888471], 
             UndirectedEdge[4, 13] -> 
             RGBColor[
              0.22349076802527734`, 0.3522333457006528, 0.9360388406628528], 
             UndirectedEdge[137, 300] -> 
             RGBColor[
              0.624581474397714, 0.6994688662935715, 0.9671293704856514], 
             UndirectedEdge[57, 163] -> 
             RGBColor[
              0.24223777275819017`, 0.37193763630369614`, 0.9371064548486839],
              UndirectedEdge[28, 304] -> 
             RGBColor[
              0.1939396212205168, 0.3211732167579251, 0.9343559465693256], 
             UndirectedEdge[83, 328] -> 
             RGBColor[
              0.9072826236616158, 0.729489427357416, 0.5953860262532737], 
             UndirectedEdge[206, 321] -> 
             RGBColor[
              0.6423373781810662, 0.7191701000468311, 0.9659074859341975], 
             UndirectedEdge[295, 373] -> 
             RGBColor[
              0.3504430057094734, 0.4745466699427852, 0.9436757963662827], 
             UndirectedEdge[29, 235] -> 
             RGBColor[
              0.18647615617022215`, 0.31332864177904984`, 0.9339309132759184],
              UndirectedEdge[234, 392] -> 
             RGBColor[
              0.888403326572227, 0.9115564131866241, 0.8883516579502622], 
             UndirectedEdge[42, 275] -> 
             RGBColor[
              0.2276321474655179, 0.3565861980709679, 0.9362746860953526], 
             UndirectedEdge[107, 324] -> 
             RGBColor[
              0.4908741561658506, 0.5947099474856988, 0.9538480411311054], 
             UndirectedEdge[75, 329] -> 
             RGBColor[
              0.20420501368883298`, 0.3319627951056, 0.934940545484109], 
             UndirectedEdge[267, 383] -> 
             RGBColor[
              0.23217032750693795`, 0.361356113031734, 0.9365331287350758], 
             UndirectedEdge[253, 362] -> 
             RGBColor[
              0.19012900620093326`, 0.31716801876539596`, 0.9341389376812601],
              UndirectedEdge[137, 252] -> 
             RGBColor[
              0.35201484785933657`, 0.47931930126023004`, 0.943651052724457], 
             UndirectedEdge[131, 203] -> 
             RGBColor[
              0.2195067441810682, 0.34804588403868764`, 0.9358119563987601], 
             UndirectedEdge[52, 199] -> 
             RGBColor[
              0.1829276009104009, 0.30959888520957934`, 0.9337288283034887], 
             UndirectedEdge[41, 386] -> 
             RGBColor[
              0.8163158098721861, 0.8568507653484726, 0.982215097641526], 
             UndirectedEdge[59, 122] -> 
             RGBColor[
              0.472237479074957, 0.5795226558414852, 0.9523966975119249], 
             UndirectedEdge[32, 172] -> 
             RGBColor[
              0.8904177362433487, 0.5253447113739889, 0.22900306113205354`], 
             UndirectedEdge[55, 156] -> 
             RGBColor[
              0.9013085960546312, 0.5775722343508322, 0.2607994456720959], 
             UndirectedEdge[97, 214] -> 
             RGBColor[
              0.21631731839459667`, 0.3446935953158315, 0.9356303233185532], 
             UndirectedEdge[133, 155] -> 
             RGBColor[
              0.1964342499678622, 0.3237952297399831, 0.9344980119860145], 
             UndirectedEdge[186, 273] -> 
             RGBColor[
              0.19433831903215518`, 0.3215922734368583, 0.9343786518198778], 
             UndirectedEdge[74, 179] -> 
             RGBColor[
              0.6585040630153561, 0.7306095985445278, 0.968478117009276], 
             UndirectedEdge[10, 62] -> 
             RGBColor[
              0.21930338871384658`, 0.34783214454915645`, 0.9358003756057394],
              UndirectedEdge[273, 322] -> 
             RGBColor[
              0.19086506728942945`, 0.31794166563837395`, 0.9341808552713451],
              UndirectedEdge[18, 148] -> 
             RGBColor[
              0.46955925293009415`, 0.5770080258985608, 0.9522798906351313], 
             UndirectedEdge[78, 172] -> 
             RGBColor[
              0.8218704023733945, 0.1691110730791465, 0.16857642805283624`], 
             UndirectedEdge[84, 269] -> 
             RGBColor[
              0.5412096627237364, 0.6337584063867442, 0.9589441687264177], 
             UndirectedEdge[103, 254] -> 
             RGBColor[
              0.19079740219879987`, 0.3178705453379077, 0.9341770018445352], 
             UndirectedEdge[46, 343] -> 
             RGBColor[
              0.19165716183089215`, 0.31877420722314587`, 0.9342259638836825],
              UndirectedEdge[1, 317] -> 
             RGBColor[
              0.19445041549410247`, 0.3217100939256911, 0.9343850355475539], 
             UndirectedEdge[27, 399] -> 
             RGBColor[
              0.873807149483661, 0.45466013361864505`, 0.21377956267551557`], 
             UndirectedEdge[247, 253] -> 
             RGBColor[
              0.19436046466415727`, 0.3216155499002067, 0.9343799129808589], 
             UndirectedEdge[27, 357] -> 
             RGBColor[
              0.8390693629151604, 0.3013098204357265, 0.18504617209107904`], 
             UndirectedEdge[41, 55] -> 
             RGBColor[
              0.9217511656674453, 0.9083191148939446, 0.6659672564832814], 
             UndirectedEdge[183, 272] -> 
             RGBColor[
              0.5454600938051113, 0.6375523889526532, 0.9591673986184688], 
             UndirectedEdge[131, 238] -> 
             RGBColor[
              0.2516193138752771, 0.38179823084181674`, 0.9376407197365557], 
             UndirectedEdge[13, 131] -> 
             RGBColor[
              0.21370957013719966`, 0.34195268655651806`, 0.9354818159131122],
              UndirectedEdge[55, 328] -> 
             RGBColor[
              0.9205810406494127, 0.7082097000834948, 0.27856954387058575`], 
             UndirectedEdge[40, 392] -> 
             RGBColor[
              0.7560719179586157, 0.8063199638581745, 0.8764325252109648], 
             UndirectedEdge[39, 347] -> 
             RGBColor[
              0.19051344323313968`, 0.3175720864609606, 0.9341608308015206], 
             UndirectedEdge[195, 362] -> 
             RGBColor[
              0.1955066853579723, 0.3228203005239958, 0.9344451885536901], 
             UndirectedEdge[46, 250] -> 
             RGBColor[
              0.22982046644249732`, 0.3588862600632101, 0.9363993076237638], 
             UndirectedEdge[22, 47] -> 
             RGBColor[
              0.4301895095994409, 0.5445652207348299, 0.9493133718661378], 
             UndirectedEdge[79, 100] -> 
             RGBColor[
              0.22059571881103596`, 0.3491904654197632, 0.9358739718929432], 
             UndirectedEdge[45, 148] -> 
             RGBColor[
              0.30939380782769543`, 0.44018999619208, 0.9410163102615399], 
             UndirectedEdge[65, 68] -> 
             RGBColor[
              0.2789862434779228, 0.41056260901775243`, 0.9391992258916821], 
             UndirectedEdge[86, 162] -> 
             RGBColor[
              0.3416757625403587, 0.46699709267346645`, 0.9431155381732708], 
             UndirectedEdge[3, 264] -> 
             RGBColor[
              0.652580274743898, 0.7275933060781521, 0.9666403041170564], 
             UndirectedEdge[55, 386] -> 
             RGBColor[
              0.8661959692237846, 0.8644995898414272, 0.6605413251423246], 
             UndirectedEdge[315, 362] -> 
             RGBColor[
              0.20400552952862408`, 0.3317531246051941, 0.9349291851562955], 
             UndirectedEdge[92, 182] -> 
             RGBColor[
              0.4229610876060558, 0.5395726978389508, 0.9485023279906137], 
             UndirectedEdge[202, 341] -> 
             RGBColor[
              0.2897972028384973, 0.4193840622352309, 0.9399079526486953], 
             UndirectedEdge[86, 125] -> 
             RGBColor[
              0.3362672755569396, 0.46131242993601224`, 0.9428075328407044], 
             UndirectedEdge[155, 353] -> 
             RGBColor[
              0.19855109199898685`, 0.3260201649302318, 0.9346185630080999], 
             UndirectedEdge[119, 235] -> 
             RGBColor[
              0.18696497458482364`, 0.31384242092567355`, 0.9339587507614879],
              UndirectedEdge[139, 204] -> 
             RGBColor[
              0.19084712474135193`, 0.31792280688272123`, 0.9341798334697757],
              UndirectedEdge[167, 174] -> 
             RGBColor[
              0.3271254190729118, 0.4577613290244936, 0.9420651203310438], 
             UndirectedEdge[218, 349] -> 
             RGBColor[
              0.19642311196174383`, 0.3237835229893623, 0.9344973776930432], 
             UndirectedEdge[362, 397] -> 
             RGBColor[
              0.20104421515641585`, 0.32864059544182767`, 0.9347605426836703],
              UndirectedEdge[70, 108] -> 
             RGBColor[
              0.2395346657598989, 0.3690964994616095, 0.9369525169040198], 
             UndirectedEdge[71, 157] -> 
             RGBColor[
              0.18316059011768585`, 0.3098437716388048, 0.933742096694167], 
             UndirectedEdge[186, 238] -> 
             RGBColor[
              0.24841689496046435`, 0.37843228551726205`, 0.9374583467169113],
              UndirectedEdge[51, 246] -> 
             RGBColor[
              0.6509116591793556, 0.7220840345127228, 0.9688949029118392], 
             UndirectedEdge[109, 305] -> 
             RGBColor[
              0.1817778659169268, 0.3083904408340291, 0.9336633525964908], 
             UndirectedEdge[125, 248] -> 
             RGBColor[
              0.2397553776330553, 0.3693284816342379, 0.936965086118682], 
             UndirectedEdge[106, 390] -> 
             RGBColor[
              0.24476481400135702`, 0.3745937168739334, 0.9372503661090598], 
             UndirectedEdge[1, 231] -> 
             RGBColor[
              0.1878698717924256, 0.3147935252646599, 0.9340102833187854], 
             UndirectedEdge[104, 399] -> 
             RGBColor[
              0.8727925927240603, 0.4468618057827464, 0.21280802197674387`], 
             UndirectedEdge[244, 366] -> 
             RGBColor[
              0.6745824127024198, 0.7409076895841773, 0.9539031392335773], 
             UndirectedEdge[64, 289] -> 
             RGBColor[
              0.18340551527321602`, 0.3101012035064188, 0.9337560448194401], 
             UndirectedEdge[160, 233] -> 
             RGBColor[
              0.7095149174779228, 0.7707139896565038, 0.9521005122991707], 
             UndirectedEdge[100, 302] -> 
             RGBColor[
              0.20076131207818187`, 0.3283432463695126, 0.9347444317718824], 
             UndirectedEdge[177, 337] -> 
             RGBColor[
              0.9444496695413749, 0.9543350995105044, 0.7916221237493946], 
             UndirectedEdge[124, 219] -> 
             RGBColor[
              0.32342751125618663`, 0.45455838713589725`, 0.9418294929148936],
              UndirectedEdge[2, 181] -> 
             RGBColor[
              0.1899547149925528, 0.3169848276546873, 0.9341290120547836], 
             UndirectedEdge[185, 198] -> 
             RGBColor[
              0.3764542800383526, 0.5004875090521163, 0.9452083117319626], 
             UndirectedEdge[11, 35] -> 
             RGBColor[
              0.27410810708868466`, 0.4051377894263376, 0.9389323194302751], 
             UndirectedEdge[5, 56] -> 
             RGBColor[
              0.3320449689742487, 0.4595901829717516, 0.9424676449298229], 
             UndirectedEdge[69, 107] -> 
             RGBColor[
              0.2952174792692931, 0.42393616514341426`, 0.9402585516481101], 
             UndirectedEdge[51, 350] -> 
             RGBColor[
              0.6877142166567092, 0.7483252059436304, 0.8485559789675121], 
             UndirectedEdge[226, 392] -> 
             RGBColor[
              0.7181621296927883, 0.7753237626808771, 0.8735087285822702], 
             UndirectedEdge[81, 292] -> 
             RGBColor[
              0.18697166352319156`, 0.31384945142400145`, 0.9339591316866327],
              UndirectedEdge[51, 272] -> 
             RGBColor[
              0.5612556230240568, 0.6512336824557214, 0.9601738757728618], 
             UndirectedEdge[10, 261] -> 
             RGBColor[
              0.24873551087533646`, 0.3787671710452084, 0.9374764914219134], 
             UndirectedEdge[132, 244] -> 
             RGBColor[
              0.656519419340629, 0.7252624326066381, 0.9527521812690418], 
             UndirectedEdge[53, 376] -> 
             RGBColor[
              0.20099948384788677`, 0.3285935800004348, 0.9347579953018235], 
             UndirectedEdge[242, 364] -> 
             RGBColor[
              0.8349752732346869, 0.2698408531100693, 0.18112566718944462`], 
             UndirectedEdge[29, 327] -> 
             RGBColor[
              0.18852270839333474`, 0.31547969792444663`, 0.934047461397422], 
             UndirectedEdge[328, 364] -> 
             RGBColor[
              0.8436039382637408, 0.3186655649666024, 0.18870327005536394`], 
             UndirectedEdge[257, 279] -> 
             RGBColor[
              0.4976692988631992, 0.5990761277778498, 0.9548872926096961], 
             UndirectedEdge[13, 322] -> 
             RGBColor[
              0.20703389947966117`, 0.33493613343347894`, 0.9351016463449351],
              UndirectedEdge[21, 24] -> 
             RGBColor[
              0.8919944774662327, 0.5241583098068742, 0.2395431849721498], 
             UndirectedEdge[56, 122] -> 
             RGBColor[
              0.48980661456960395`, 0.5947401579565226, 0.9535161872898672], 
             UndirectedEdge[87, 393] -> 
             RGBColor[
              0.1907711086239872, 0.3178429091236707, 0.9341755044643476], 
             UndirectedEdge[27, 74] -> 
             RGBColor[
              0.8420491439644571, 0.52817967821788, 0.5772900887047536], 
             UndirectedEdge[93, 288] -> 
             RGBColor[
              0.2698457094938153, 0.4009553282571281, 0.9386786860034955], 
             UndirectedEdge[125, 211] -> 
             RGBColor[
              0.24170072207493107`, 0.37137316198461084`, 0.9370758706067677],
              UndirectedEdge[265, 304] -> 
             RGBColor[
              0.18543662898340038`, 0.31223603279586976`, 0.9338717137404716],
              UndirectedEdge[195, 343] -> 
             RGBColor[
              0.19193458883998876`, 0.3190658005995948, 0.9342417629414341], 
             UndirectedEdge[199, 393] -> 
             RGBColor[
              0.1849265278957996, 0.3116998842105244, 0.9338426642381596], 
             UndirectedEdge[24, 208] -> 
             RGBColor[
              0.906901063221462, 0.5760810366232336, 0.4664786546523232], 
             UndirectedEdge[135, 386] -> 
             RGBColor[
              0.8778014359212141, 0.9022038387539937, 0.8283895042121832], 
             UndirectedEdge[32, 357] -> 
             RGBColor[
              0.9070663677553636, 0.6533133886521827, 0.2449458094698989], 
             UndirectedEdge[230, 233] -> 
             RGBColor[
              0.8885723351829689, 0.5532979785319709, 0.5591090860551002], 
             UndirectedEdge[46, 161] -> 
             RGBColor[
              0.20037426040526207`, 0.3279364305207805, 0.9347223897517012], 
             UndirectedEdge[114, 306] -> 
             RGBColor[
              0.2220014868268114, 0.35066801673518333`, 0.9359540283017942], 
             UndirectedEdge[233, 357] -> 
             RGBColor[
              0.9082534214695472, 0.7045754320376143, 0.5779557165097353], 
             UndirectedEdge[134, 395] -> 
             RGBColor[
              0.6498035533941702, 0.7237783527330339, 0.9675259002297822], 
             UndirectedEdge[108, 267] -> 
             RGBColor[
              0.2560701403937588, 0.38647633171144136`, 0.9378941877223754], 
             UndirectedEdge[217, 233] -> 
             RGBColor[
              0.9762379710154455, 0.9784153903456743, 0.7203221374649382], 
             UndirectedEdge[245, 400] -> 
             RGBColor[
              0.8345042681241085, 0.26622050143440795`, 0.18067463216363056`],
              UndirectedEdge[269, 392] -> 
             RGBColor[
              0.8673327084378479, 0.8950958861574181, 0.8862515356507488], 
             UndirectedEdge[232, 288] -> 
             RGBColor[
              0.30023200699341346`, 0.43289325353174246`, 0.9404091406935988],
              UndirectedEdge[260, 341] -> 
             RGBColor[
              0.2804084248139549, 0.4095158612485281, 0.93937327562965], 
             UndirectedEdge[47, 323] -> 
             RGBColor[
              0.4713973595467131, 0.580257389192397, 0.951939099626107], 
             UndirectedEdge[142, 377] -> 
             RGBColor[
              0.18361252498065594`, 0.31031878383411166`, 0.9337678337160353],
              UndirectedEdge[53, 117] -> 
             RGBColor[
              0.20926903428907379`, 0.33728540183390365`, 0.9352289339657456],
              UndirectedEdge[251, 308] -> 
             RGBColor[
              0.1958872147734443, 0.3232202610666153, 0.9344668591409584], 
             UndirectedEdge[85, 162] -> 
             RGBColor[
              0.2565370723370653, 0.38696710678905155`, 0.9379207788057828], 
             UndirectedEdge[249, 397] -> 
             RGBColor[
              0.26099988066146607`, 0.3916272530178875, 0.9381760476598446], 
             UndirectedEdge[262, 284] -> 
             RGBColor[
              0.24537509181412387`, 0.37523515754899955`, 0.9372851205276718],
              UndirectedEdge[307, 341] -> 
             RGBColor[
              0.3422947785820742, 0.4709002657971524, 0.9430316985052297], 
             UndirectedEdge[7, 387] -> 
             RGBColor[
              0.4913856837463006, 0.597841186558023, 0.9531378831854276], 
             UndirectedEdge[228, 368] -> 
             RGBColor[
              0.19438368850365684`, 0.3216399596279972, 0.9343812355441619], 
             UndirectedEdge[240, 399] -> 
             RGBColor[
              0.879132492911469, 0.49559305678514604`, 0.2188791175560995], 
             UndirectedEdge[105, 114] -> 
             RGBColor[
              0.22538318625918102`, 0.3542223972507317, 0.9361466110816916], 
             UndirectedEdge[78, 357] -> 
             RGBColor[
              0.8385190338854094, 0.29707975035734024`, 0.18451917639068158`],
              UndirectedEdge[359, 369] -> 
             RGBColor[
              0.18890080078567878`, 0.31587709700124245`, 0.9340689931998285],
              UndirectedEdge[48, 354] -> 
             RGBColor[
              0.22802037271409625`, 0.35699424742212627`, 0.9362967949489314],
              UndirectedEdge[280, 325] -> 
             RGBColor[
              0.2703375929737152, 0.4014723289817168, 0.9387066980399994], 
             UndirectedEdge[259, 262] -> 
             RGBColor[
              0.20019420515358305`, 0.3277471810351035, 0.934712135871486], 
             UndirectedEdge[120, 187] -> 
             RGBColor[
              0.47660974925846794`, 0.585472751295903, 0.952077636221743], 
             UndirectedEdge[70, 198] -> 
             RGBColor[
              0.2881120186842996, 0.4160342955793074, 0.9398697816662858], 
             UndirectedEdge[62, 235] -> 
             RGBColor[
              0.1963098901939031, 0.32366451973268695`, 0.9344909298808612], 
             UndirectedEdge[65, 176] -> 
             RGBColor[
              0.26080757186847375`, 0.39145567256187075`, 0.9381639774364586],
              UndirectedEdge[199, 342] -> 
             RGBColor[
              0.18510212262202141`, 0.31188444540113214`, 0.9338526640980489],
              UndirectedEdge[324, 390] -> 
             RGBColor[
              0.4479202761383373, 0.5532491979543472, 0.9512669003180385], 
             UndirectedEdge[226, 234] -> 
             RGBColor[
              0.6154815427973135, 0.6962991925345092, 0.964434228392668], 
             UndirectedEdge[47, 201] -> 
             RGBColor[
              0.7465737093465549, 0.8011421937069441, 0.9641963866302764], 
             UndirectedEdge[160, 264] -> 
             RGBColor[
              0.5914575736276367, 0.6779711437656651, 0.9618285011853527], 
             UndirectedEdge[277, 314] -> 
             RGBColor[
              0.22024480085065679`, 0.34882162839392095`, 0.9358539876342362],
              UndirectedEdge[4, 66] -> 
             RGBColor[
              0.22354481915991609`, 0.35229015687019793`, 0.9360419187950089],
              UndirectedEdge[23, 75] -> 
             RGBColor[0.255511442446525, 0.3858891047454028, 0.9378623707008],
              UndirectedEdge[287, 391] -> 
             RGBColor[
              0.18552964693238397`, 0.31233380055793014`, 0.9338770109750585],
              UndirectedEdge[45, 91] -> 
             RGBColor[
              0.38905361359871204`, 0.5081017700405416, 0.9463921022645131], 
             UndirectedEdge[175, 314] -> 
             RGBColor[
              0.25716282410855407`, 0.38762481157584006`, 0.9379564144434523],
              UndirectedEdge[195, 358] -> 
             RGBColor[
              0.1963120650172806, 0.3236668056099485, 0.9344910537338352], 
             UndirectedEdge[321, 341] -> 
             RGBColor[
              0.44529829620254, 0.5573731665864943, 0.9503530478730258], 
             UndirectedEdge[91, 148] -> 
             RGBColor[
              0.4136380232673186, 0.5316086524356322, 0.9478775665898638], 
             UndirectedEdge[115, 350] -> 
             RGBColor[
              0.9292292560607558, 0.7349117971309463, 0.4801575703138227], 
             UndirectedEdge[142, 277] -> 
             RGBColor[
              0.19515207298431664`, 0.32244758043556054`, 0.9344249939036124],
              UndirectedEdge[45, 66] -> 
             RGBColor[
              0.2495400971941441, 0.37961284227999426`, 0.9375223114224907], 
             UndirectedEdge[259, 335] -> 
             RGBColor[
              0.18286996403264408`, 0.3095383051966678, 0.9337255459685665], 
             UndirectedEdge[118, 173] -> 
             RGBColor[
              0.26068055800241224`, 0.3913221729354959, 0.9381567441846866], 
             UndirectedEdge[52, 128] -> 
             RGBColor[
              0.18698858591777334`, 0.3138672379336487, 0.9339600953919696], 
             UndirectedEdge[27, 225] -> 
             RGBColor[
              0.8528742555567694, 0.5368113283617635, 0.5783225975121196], 
             UndirectedEdge[302, 352] -> 
             RGBColor[
              0.21548876733628058`, 0.34382273562037, 0.9355831385615135], 
             UndirectedEdge[25, 242] -> 
             RGBColor[
              0.8347962131108371, 0.26846451853351216`, 0.18095419901262647`],
              UndirectedEdge[30, 224] -> 
             RGBColor[
              0.17977250803868983`, 0.30628268255696894`, 0.9335491504319864],
              UndirectedEdge[313, 361] -> 
             RGBColor[
              0.2180016041011253, 0.34646388638327474`, 0.9357262408978626], 
             UndirectedEdge[270, 310] -> 
             RGBColor[
              0.3193491673301014, 0.4483310995882432, 0.9416682954109477], 
             UndirectedEdge[72, 370] -> 
             RGBColor[
              0.18495091945082137`, 0.31172552128136616`, 0.9338440533011341],
              UndirectedEdge[283, 380] -> 
             RGBColor[
              0.2145522876760556, 0.34283843612123366`, 0.9355298074302612], 
             UndirectedEdge[34, 35] -> 
             RGBColor[
              0.24974982719833305`, 0.3798332818120472, 0.9375342552359615], 
             UndirectedEdge[25, 230] -> 
             RGBColor[
              0.8175286583222767, 0.13573852573788114`, 0.16441876904618735`],
              UndirectedEdge[191, 211] -> 
             RGBColor[
              0.2145566630341047, 0.342843034899957, 0.9355300566004294], 
             UndirectedEdge[17, 173] -> 
             RGBColor[
              0.25707808713188923`, 0.38753574764073073`, 0.9379515887979883],
              UndirectedEdge[40, 51] -> 
             RGBColor[
              0.4513189432678153, 0.5634921655168925, 0.9504868403154272], 
             UndirectedEdge[105, 202] -> 
             RGBColor[
              0.2264175602160962, 0.35530958986254624`, 0.9362055171483188], 
             UndirectedEdge[183, 309] -> 
             RGBColor[
              0.3237917248354433, 0.45384300724789295`, 0.9418904445081182], 
             UndirectedEdge[187, 261] -> 
             RGBColor[
              0.3474451829775207, 0.4708516166188276, 0.9435249988507737], 
             UndirectedEdge[190, 274] -> 
             RGBColor[
              0.7246489008143902, 0.7831056857849257, 0.9561147753018562], 
             UndirectedEdge[176, 354] -> 
             RGBColor[
              0.22476081103687653`, 0.35356824143122134`, 0.936111167733503], 
             UndirectedEdge[42, 148] -> 
             RGBColor[
              0.27524609124263133`, 0.40429858097089644`, 0.9390716483190401],
              UndirectedEdge[320, 380] -> 
             RGBColor[
              0.20795844756120663`, 0.3359078920869173, 0.9351542979904328], 
             UndirectedEdge[51, 222] -> 
             RGBColor[
              0.3069819930795281, 0.4332541041734357, 0.9410401002851541], 
             UndirectedEdge[122, 319] -> 
             RGBColor[
              0.5256622973684795, 0.6257953596771879, 0.9558012080947398], 
             UndirectedEdge[27, 78] -> 
             RGBColor[
              0.8204879075828598, 0.15848461230601768`, 0.16725254948011575`],
              UndirectedEdge[5, 178] -> 
             RGBColor[
              0.36206488822589933`, 0.4855919281825182, 0.9443804876389659], 
             UndirectedEdge[196, 336] -> 
             RGBColor[
              0.18504438325654066`, 0.31182375766712467`, 0.9338493759266024],
              UndirectedEdge[297, 318] -> 
             RGBColor[
              0.20065548392565413`, 0.32823201427131354`, 0.9347384050151546],
              UndirectedEdge[127, 235] -> 
             RGBColor[
              0.19315907110692182`, 0.32035280909880115`, 0.9343114953950769],
              UndirectedEdge[45, 203] -> 
             RGBColor[
              0.2552832201033739, 0.38564922859261863`, 0.9378493737759823], 
             UndirectedEdge[305, 370] -> 
             RGBColor[
              0.18466045373978385`, 0.311420223402476, 0.9338275117085959], 
             UndirectedEdge[122, 169] -> 
             RGBColor[
              0.7468757612194565, 0.8021168965628588, 0.9757076451280708], 
             UndirectedEdge[51, 226] -> 
             RGBColor[
              0.41340915500198794`, 0.532495964339595, 0.9475630436867326], 
             UndirectedEdge[226, 395] -> 
             RGBColor[
              0.45693963376297164`, 0.5697838781949226, 0.9504517090480242], 
             UndirectedEdge[61, 354] -> 
             RGBColor[
              0.21260864100273835`, 0.3407955402332605, 0.9354191196275834], 
             UndirectedEdge[211, 334] -> 
             RGBColor[
              0.20343525046697647`, 0.3311537251536216, 0.9348967086073869], 
             UndirectedEdge[10, 361] -> 
             RGBColor[
              0.22756848714061534`, 0.35651928703319763`, 0.9362710607340264],
              UndirectedEdge[44, 249] -> 
             RGBColor[
              0.27287548484168234`, 0.4041092659680885, 0.9388523457495259], 
             UndirectedEdge[302, 377] -> 
             RGBColor[
              0.18805566555367964`, 0.3149888062877428, 0.9340208639986316], 
             UndirectedEdge[149, 363] -> 
             RGBColor[
              0.21825217126115545`, 0.34672724835534197`, 0.9357405103269454],
              UndirectedEdge[358, 359] -> 
             RGBColor[
              0.18898988195831087`, 0.3159707269617513, 0.934074066240826], 
             UndirectedEdge[126, 317] -> 
             RGBColor[
              0.1909701324562666, 0.31805209579023613`, 0.9341868385771666], 
             UndirectedEdge[194, 364] -> 
             RGBColor[
              0.9061043939482173, 0.5637958920619978, 0.4053724452164604], 
             UndirectedEdge[184, 343] -> 
             RGBColor[
              0.18256566753029357`, 0.30921847027918486`, 0.933708216732924], 
             UndirectedEdge[118, 346] -> 
             RGBColor[
              0.2949738551719156, 0.42345379048504006`, 0.9402529639443298], 
             UndirectedEdge[169, 239] -> 
             RGBColor[
              0.8617758088916869, 0.5670725642786435, 0.5820707130728167], 
             UndirectedEdge[72, 157] -> 
             RGBColor[
              0.1851041505972344, 0.3118865769316621, 0.9338527795882372], 
             UndirectedEdge[162, 191] -> 
             RGBColor[
              0.239776323432642, 0.3693504969976439, 0.936966278950982], 
             UndirectedEdge[84, 272] -> 
             RGBColor[
              0.5398855520007457, 0.6327240010263296, 0.9588121937440683], 
             UndirectedEdge[21, 160] -> 
             RGBColor[
              0.7114127926044326, 0.7298581356264684, 0.631074971265499], 
             UndirectedEdge[29, 336] -> 
             RGBColor[
              0.18089581060751259`, 0.30746334477829806`, 0.9336131208515035],
              UndirectedEdge[275, 276] -> 
             RGBColor[
              0.2308037275414878, 0.35991972982060355`, 0.9364553028887468], 
             UndirectedEdge[38, 303] -> 
             RGBColor[
              0.21808265414273661`, 0.3465490751158777, 0.9357308565778295], 
             UndirectedEdge[172, 285] -> 
             RGBColor[
              0.9090011322761398, 0.5869841292419617, 0.39020330546201376`], 
             UndirectedEdge[73, 285] -> 
             RGBColor[
              0.9624071777351879, 0.8763102692580285, 0.43650448397981056`], 
             UndirectedEdge[5, 59] -> 
             RGBColor[
              0.31447583347960173`, 0.4443726808567142, 0.9413481551518805], 
             UndirectedEdge[73, 225] -> 
             RGBColor[
              0.9076627958063523, 0.836763929150959, 0.6259476546026368], 
             UndirectedEdge[64, 254] -> 
             RGBColor[
              0.1839453796797469, 0.3106686352270631, 0.9337867892987342], 
             UndirectedEdge[241, 390] -> 
             RGBColor[
              0.2629620790942533, 0.393720196259813, 0.938286673435659], 
             UndirectedEdge[58, 289] -> 
             RGBColor[
              0.19906319498854463`, 0.3265584176414619, 0.9346477265157667], 
             UndirectedEdge[262, 331] -> 
             RGBColor[
              0.20664951421908523`, 0.3345321201531805, 0.9350797561729924], 
             UndirectedEdge[22, 118] -> 
             RGBColor[
              0.2775783272389005, 0.4083866585141185, 0.9391445362866995], 
             UndirectedEdge[97, 360] -> 
             RGBColor[
              0.189069412661027, 0.31605431877284385`, 0.9340785953966906], 
             UndirectedEdge[301, 358] -> 
             RGBColor[
              0.18673627600332035`, 0.31360204421618604`, 0.9339457267156006],
              UndirectedEdge[16, 274] -> 
             RGBColor[
              0.4054269963890745, 0.5245026293096915, 0.9473527216519175], 
             UndirectedEdge[166, 319] -> 
             RGBColor[
              0.7215283330281927, 0.7785525624499918, 0.8852776399757938], 
             UndirectedEdge[82, 101] -> 
             RGBColor[
              0.181913405203708, 0.30853290121812327`, 0.9336710713583607], 
             UndirectedEdge[24, 399] -> 
             RGBColor[
              0.8736814566563863, 0.4536940034692628, 0.2136591990821675], 
             UndirectedEdge[328, 400] -> 
             RGBColor[
              0.8598546185049423, 0.443575414393966, 0.20426493980685678`], 
             UndirectedEdge[17, 371] -> 
             RGBColor[
              0.20911196002482746`, 0.33712030682309724`, 0.9352199888187673],
              UndirectedEdge[107, 158] -> 
             RGBColor[
              0.34368740964077826`, 0.4721064928245296, 0.9431204357248351], 
             UndirectedEdge[60, 394] -> 
             RGBColor[
              0.18321858514836378`, 0.3099047280931446, 0.933745399425368], 
             UndirectedEdge[219, 284] -> 
             RGBColor[
              0.3068620452246301, 0.43723797575946177`, 0.9408827842352088], 
             UndirectedEdge[124, 149] -> 
             RGBColor[
              0.2631665511656537, 0.3938441656371931, 0.9383016477132344], 
             UndirectedEdge[227, 296] -> 
             RGBColor[
              0.22621507415997788`, 0.35509676417920844`, 0.9361939858669741],
              UndirectedEdge[202, 229] -> 
             RGBColor[
              0.22512118954774685`, 0.35394702209546336`, 0.9361316907565649],
              UndirectedEdge[315, 358] -> 
             RGBColor[
              0.20481090918793238`, 0.33259962969114687`, 0.9349750503364407],
              UndirectedEdge[145, 222] -> 
             RGBColor[
              0.21482177415136725`, 0.3431216834932156, 0.9355451542863606], 
             UndirectedEdge[155, 299] -> 
             RGBColor[
              0.19737174909206562`, 0.3247806007603985, 0.9345514011742322], 
             UndirectedEdge[14, 29] -> 
             RGBColor[
              0.18299367418147944`, 0.3096683324067703, 0.9337325910785299], 
             UndirectedEdge[116, 151] -> 
             RGBColor[
              0.18767873323802545`, 0.31459262652510106`, 0.9339993982608765],
              UndirectedEdge[45, 257] -> 
             RGBColor[
              0.30395689687858984`, 0.4354808171950546, 0.9406698751035344], 
             UndirectedEdge[27, 240] -> 
             RGBColor[
              0.8263635800404189, 0.20364760555090494`, 0.1728791000610972], 
             UndirectedEdge[144, 188] -> 
             RGBColor[
              0.19616736828116454`, 0.3235147201659876, 0.934482813468773], 
             UndirectedEdge[76, 200] -> 
             RGBColor[
              0.1890554468047247, 0.31603963977238364`, 0.9340778000618348], 
             UndirectedEdge[90, 221] -> 
             RGBColor[
              0.755343522572024, 0.6711176068414135, 0.6012544985481333], 
             UndirectedEdge[271, 382] -> 
             RGBColor[
              0.18049565541513857`, 0.3070427562998084, 0.9335903326052744], 
             UndirectedEdge[242, 385] -> 
             RGBColor[
              0.9233493722002852, 0.696643340637751, 0.416149434312738], 
             UndirectedEdge[74, 112] -> 
             RGBColor[
              0.9000839613583336, 0.841002686126469, 0.6275271765854877], 
             UndirectedEdge[237, 251] -> 
             RGBColor[
              0.19380336074719554`, 0.32102999836105145`, 0.9343481867369493],
              UndirectedEdge[25, 223] -> 
             RGBColor[
              0.8736105747823911, 0.4469597061439798, 0.21333691400652116`], 
             UndirectedEdge[284, 332] -> 
             RGBColor[
              0.2524716906122939, 0.382694132836228, 0.9376892613307504], 
             UndirectedEdge[145, 333] -> 
             RGBColor[
              0.19268508450271393`, 0.3198546191252922, 0.9342845025591675], 
             UndirectedEdge[146, 227] -> 
             RGBColor[
              0.19680598858419968`, 0.3241859505953433, 0.934519181950277], 
             UndirectedEdge[108, 286] -> 
             RGBColor[
              0.22549943873113315`, 0.3543445859695858, 0.9361532314879892], 
             UndirectedEdge[127, 361] -> 
             RGBColor[
              0.2062200768333135, 0.33408075423283157`, 0.9350553003491684], 
             UndirectedEdge[143, 258] -> 
             RGBColor[
              0.1842254727690224, 0.31096303082281923`, 0.9338027401858078], 
             UndirectedEdge[212, 310] -> 
             RGBColor[
              0.34846775564587945`, 0.473552157244567, 0.9435237061098725], 
             UndirectedEdge[107, 310] -> 
             RGBColor[
              0.3141088853648525, 0.4437922307341744, 0.9413343892779213], 
             UndirectedEdge[253, 394] -> 
             RGBColor[
              0.1857625991924869, 0.31257864815332465`, 0.9338902772616493], 
             UndirectedEdge[152, 284] -> 
             RGBColor[
              0.26668400229217915`, 0.3976321735243937, 0.9384986314556889], 
             UndirectedEdge[230, 364] -> 
             RGBColor[
              0.8177077184461266, 0.13711486031443826`, 0.16459023722300553`],
              UndirectedEdge[158, 241] -> 
             RGBColor[
              0.3009846875478195, 0.43090972620672763`, 0.9405535979845862], 
             UndirectedEdge[44, 315] -> 
             RGBColor[
              0.22776027402374388`, 0.3567208672073564, 0.9362819827132973], 
             UndirectedEdge[357, 385] -> 
             RGBColor[
              0.9257629036983032, 0.7151948013477634, 0.418460634800934], 
             UndirectedEdge[99, 197] -> 
             RGBColor[
              0.9649742133445314, 0.9733984061785892, 0.9441737000062027], 
             UndirectedEdge[152, 267] -> 
             RGBColor[
              0.25637803396755154`, 0.3867999473790775, 0.9379117218059152], 
             UndirectedEdge[169, 197] -> 
             RGBColor[
              0.9300501065256308, 0.9463228877887528, 0.9676089006734437], 
             UndirectedEdge[263, 348] -> 
             RGBColor[
              0.36254614474277536`, 0.48844098130229274`, 0.9443220976494096],
              UndirectedEdge[314, 379] -> 
             RGBColor[
              0.21988806256935944`, 0.348446673841764, 0.9358336719168633], 
             UndirectedEdge[300, 319] -> 
             RGBColor[
              0.6840306200166372, 0.7509595396670409, 0.9709177458785374], 
             UndirectedEdge[25, 78] -> 
             RGBColor[
              0.8186282892765544, 0.1441907711138157, 0.16547177688985915`], 
             UndirectedEdge[44, 113] -> 
             RGBColor[
              0.27210008577250266`, 0.4033248206617401, 0.9388070693975159], 
             UndirectedEdge[115, 221] -> 
             RGBColor[
              0.8834582095203258, 0.5636927731060549, 0.2244670121341203], 
             UndirectedEdge[175, 319] -> 
             RGBColor[
              0.3675065660796395, 0.49023117564208835`, 0.944730223137449], 
             UndirectedEdge[176, 356] -> 
             RGBColor[
              0.21433034444536764`, 0.34260515971376704`, 0.9355171680916091],
              UndirectedEdge[84, 395] -> 
             RGBColor[
              0.4037383718237736, 0.5237036190763635, 0.9470617716812872], 
             UndirectedEdge[301, 359] -> 
             RGBColor[
              0.1849503238015024, 0.31172489521616553`, 0.9338440193797866], 
             UndirectedEdge[238, 280] -> 
             RGBColor[
              0.2707591220181621, 0.40191538273391547`, 0.9387307034954844], 
             UndirectedEdge[36, 168] -> 
             RGBColor[
              0.18854146293925098`, 0.3154994101413115, 0.9340485294410671], 
             UndirectedEdge[4, 232] -> 
             RGBColor[
              0.26395583592624494`, 0.3947646976980586, 0.9383432664171094], 
             UndirectedEdge[140, 339] -> 
             RGBColor[
              0.2386234653452058, 0.3681387700523239, 0.9369006253884031], 
             UndirectedEdge[18, 141] -> 
             RGBColor[
              0.7353689115489879, 0.586455396789142, 0.5858108169853278], 
             UndirectedEdge[123, 140] -> 
             RGBColor[
              0.21869849237699107`, 0.3471963601464784, 0.9357659276542193], 
             UndirectedEdge[24, 78] -> 
             RGBColor[
              0.8203622147555851, 0.15751848215663547`, 0.1671321858867677], 
             UndirectedEdge[62, 127] -> 
             RGBColor[
              0.1979549784065447, 0.32539361174879033`, 0.9345846152208812], 
             UndirectedEdge[299, 353] -> 
             RGBColor[
              0.188841530987085, 0.3158148006849981, 0.9340656178724803], 
             UndirectedEdge[256, 311] -> 
             RGBColor[
              0.32702639881790146`, 0.45712063802367703`, 0.942079129357128], 
             UndirectedEdge[47, 346] -> 
             RGBColor[
              0.44758503753245593`, 0.5596323527057516, 0.9504217995237683], 
             UndirectedEdge[34, 125] -> 
             RGBColor[
              0.2623800078372861, 0.3931084024632914, 0.9382535253386719], 
             UndirectedEdge[194, 387] -> 
             RGBColor[
              0.7643288542489235, 0.8116893614464729, 0.8013257295322668], 
             UndirectedEdge[117, 303] -> 
             RGBColor[
              0.21968824533158482`, 0.34823665325571823`, 0.9358222926207751],
              UndirectedEdge[287, 382] -> 
             RGBColor[
              0.18591195141547964`, 0.3127356268091679, 0.933898782649802], 
             UndirectedEdge[20, 168] -> 
             RGBColor[
              0.18724662483160132`, 0.31413845319269396`, 0.9339747903263778],
              UndirectedEdge[51, 355] -> 
             RGBColor[
              0.5736425498293158, 0.6609104438201203, 0.9614084888743977], 
             UndirectedEdge[183, 339] -> 
             RGBColor[
              0.30076734139659483`, 0.42964292042343744`, 0.9405792399327987],
              UndirectedEdge[118, 164] -> 
             RGBColor[
              0.21991695118991147`, 0.3484770376136085, 0.9358353170810669], 
             UndirectedEdge[51, 134] -> 
             RGBColor[
              0.6062730746331866, 0.6864904388777064, 0.9646372348684907], 
             UndirectedEdge[46, 356] -> 
             RGBColor[
              0.1981426064801053, 0.32559082075040946`, 0.9345953003620997], 
             UndirectedEdge[204, 276] -> 
             RGBColor[
              0.2082458481435212, 0.33620996832117933`, 0.9351706650284246], 
             UndirectedEdge[108, 154] -> 
             RGBColor[
              0.23083302352450608`, 0.3599505217562283, 0.9364569712516402], 
             UndirectedEdge[29, 119] -> 
             RGBColor[
              0.18192714786076558`, 0.30854734562202557`, 0.9336718539823496],
              UndirectedEdge[244, 264] -> 
             RGBColor[
              0.8390285444461558, 0.8747724603828321, 0.9672545655941249], 
             UndirectedEdge[217, 321] -> 
             RGBColor[
              0.7737155651854934, 0.8183397872541874, 0.7225530793389106], 
             UndirectedEdge[241, 346] -> 
             RGBColor[
              0.30713982911114474`, 0.4362410004624697, 0.9409457981622233], 
             UndirectedEdge[108, 284] -> 
             RGBColor[
              0.26637610871838646`, 0.39730855785675745`, 0.9384810973721491],
              UndirectedEdge[181, 334] -> 
             RGBColor[
              0.18995231521735206`, 0.3169823053387968, 0.934128875391136], 
             UndirectedEdge[8, 59] -> 
             RGBColor[
              0.2921622006654197, 0.4209196380029755, 0.9400774267731745], 
             UndirectedEdge[236, 383] -> 
             RGBColor[
              0.22956462143722656`, 0.3586173507411603, 0.9363847376292023], 
             UndirectedEdge[42, 290] -> 
             RGBColor[
              0.20736560396252507`, 0.33528477587624783`, 0.9351205364245214],
              UndirectedEdge[173, 209] -> 
             RGBColor[
              0.3086611648699239, 0.43934003290171275`, 0.940977513192154], 
             UndirectedEdge[154, 332] -> 
             RGBColor[
              0.2169286054184135, 0.3453360967356988, 0.9356651352102414], 
             UndirectedEdge[5, 352] -> 
             RGBColor[
              0.26102097459574697`, 0.3916799723587493, 0.9381761304060758], 
             UndirectedEdge[189, 226] -> 
             RGBColor[
              0.35594179006458193`, 0.47882793285764735`, 0.9440438043992346],
              UndirectedEdge[16, 390] -> 
             RGBColor[
              0.2902432136013212, 0.4215595588222458, 0.9398708612517093], 
             UndirectedEdge[119, 327] -> 
             RGBColor[
              0.18901152680793626`, 0.3159934770710704, 0.9340752988829915], 
             UndirectedEdge[129, 231] -> 
             RGBColor[
              0.18564063577461087`, 0.3124504568682096, 0.93388333162543], 
             UndirectedEdge[79, 352] -> 
             RGBColor[
              0.23532317406913467`, 0.3646699546706205, 0.9367126786825744], 
             UndirectedEdge[62, 361] -> 
             RGBColor[
              0.20937089592029476`, 0.33739246486671737`, 0.9352347348349528],
              UndirectedEdge[150, 347] -> 
             RGBColor[
              0.19569856946522865`, 0.3230219828868772, 0.9344561160697312], 
             UndirectedEdge[5, 90] -> 
             RGBColor[
              0.44540909938288953`, 0.5535702341777979, 0.950854414653335], 
             UndirectedEdge[24, 27] -> 
             RGBColor[
              0.8209125437853362, 0.16174855223502174`, 0.16765918158716517`],
              UndirectedEdge[62, 393] -> 
             RGBColor[
              0.19223452494535048`, 0.31938105246337734`, 0.9342588438589188],
              UndirectedEdge[199, 353] -> 
             RGBColor[
              0.18825533864421526`, 0.31519867536590085`, 0.9340322350857477],
              UndirectedEdge[96, 201] -> 
             RGBColor[
              0.8486214444306401, 0.8823678065342169, 0.9733384742305298], 
             UndirectedEdge[155, 170] -> 
             RGBColor[
              0.21937286170598153`, 0.34790516506873237`, 0.9358043319898652],
              UndirectedEdge[335, 394] -> 
             RGBColor[
              0.17996762986719622`, 0.30648776797016763`, 0.9335602623314629],
              UndirectedEdge[16, 310] -> 
             RGBColor[
              0.2986872977789616, 0.43043482667880517`, 0.9403517393537228], 
             UndirectedEdge[6, 277] -> 
             RGBColor[
              0.2567019144406389, 0.38714036629150045`, 0.9379301663197194], 
             UndirectedEdge[140, 232] -> 
             RGBColor[
              0.2603959916536444, 0.39102307566039235`, 0.9381405385521024], 
             UndirectedEdge[177, 300] -> 
             RGBColor[
              0.904775992937191, 0.9269078335507821, 0.990779535981055], 
             UndirectedEdge[24, 32] -> 
             RGBColor[
              0.8889095486255394, 0.5137521204514779, 0.227558818965985], 
             UndirectedEdge[102, 226] -> 
             RGBColor[
              0.3613558703292786, 0.48451847448835883`, 0.9443521282608951], 
             UndirectedEdge[187, 206] -> 
             RGBColor[
              0.5826167692195937, 0.6701866792756657, 0.9613440852325792], 
             UndirectedEdge[336, 396] -> 
             RGBColor[
              0.18995557631013382`, 0.31698573295407556`, 0.9341290611055455],
              UndirectedEdge[267, 332] -> 
             RGBColor[
              0.24216572228766625`, 0.37186190669091185`, 0.9371023516809767],
              UndirectedEdge[115, 300] -> 
             RGBColor[
              0.8896537545747043, 0.7064595554170632, 0.6002320083831638], 
             UndirectedEdge[149, 195] -> 
             RGBColor[
              0.20922588183301488`, 0.33724004586656203`, 0.9352264764972114],
              UndirectedEdge[127, 396] -> 
             RGBColor[
              0.197181010085485, 0.3245801219709307, 0.9345405388699805], 
             UndirectedEdge[206, 220] -> 
             RGBColor[
              0.6830678662474279, 0.7522369451466808, 0.9691139391554754], 
             UndirectedEdge[298, 361] -> 
             RGBColor[
              0.2073168336633886, 0.33523351519963984`, 0.9351177590281349], 
             UndirectedEdge[27, 141] -> 
             RGBColor[
              0.8433178856733501, 0.32265315137636846`, 0.18867158623389835`],
              UndirectedEdge[55, 221] -> 
             RGBColor[
              0.9369698505827507, 0.7826274582869746, 0.292244768605455], 
             UndirectedEdge[40, 269] -> 
             RGBColor[
              0.6323207129287618, 0.7108348666826005, 0.9652579027218493], 
             UndirectedEdge[191, 312] -> 
             RGBColor[
              0.25506639270437426`, 0.3854213292486189, 0.9378370257763766], 
             UndirectedEdge[78, 240] -> 
             RGBColor[
              0.8258132510106677, 0.19941753547251867`, 0.17235210436069973`],
              UndirectedEdge[183, 246] -> 
             RGBColor[
              0.63511612996041, 0.7084027410096546, 0.967888425757446], 
             UndirectedEdge[130, 164] -> 
             RGBColor[
              0.19148238974395732`, 0.318590510678587, 0.9342160108718838], 
             UndirectedEdge[190, 295] -> 
             RGBColor[
              0.6926270864337125, 0.7564495900659256, 0.953776079551644], 
             UndirectedEdge[18, 179] -> 
             RGBColor[
              0.5295441815391476, 0.6289468481238254, 0.9561068042364651], 
             UndirectedEdge[128, 199] -> 
             RGBColor[
              0.1905507884017967, 0.3176113386010396, 0.9341629575536283], 
             UndirectedEdge[350, 355] -> 
             RGBColor[
              0.879778802399924, 0.9043102631133229, 0.8644296794931206], 
             UndirectedEdge[233, 348] -> 
             RGBColor[
              0.6462730001834412, 0.7161082281260901, 0.948023487805811], 
             UndirectedEdge[247, 316] -> 
             RGBColor[
              0.21599089502507074`, 0.3443505036580227, 0.9356117339905587], 
             UndirectedEdge[74, 399] -> 
             RGBColor[
              0.8948180568355072, 0.820125129452121, 0.6232901061997559], 
             UndirectedEdge[155, 171] -> 
             RGBColor[
              0.19802203394015824`, 0.32546409136618454`, 0.9345884339343208],
              UndirectedEdge[21, 95] -> 
             RGBColor[
              0.7613060096832925, 0.7703636969149021, 0.6350027480788232], 
             UndirectedEdge[257, 325] -> 
             RGBColor[
              0.30612175947263687`, 0.43775622504161427`, 0.9407931608256381],
              UndirectedEdge[250, 372] -> 
             RGBColor[
              0.22620791914637717`, 0.35508924380626006`, 0.9361935783995345],
              UndirectedEdge[156, 400] -> 
             RGBColor[
              0.8405821739101607, 0.3129379486613033, 0.18649484160836693`], 
             UndirectedEdge[193, 360] -> 
             RGBColor[
              0.18609708652812662`, 0.31293021555080397`, 0.9339093258205844],
              UndirectedEdge[92, 135] -> 
             RGBColor[
              0.746116355711272, 0.7971097200029147, 0.816782693533676], 
             UndirectedEdge[102, 174] -> 
             RGBColor[
              0.3107339262181662, 0.44067229083220405`, 0.9411265427453626], 
             UndirectedEdge[140, 275] -> 
             RGBColor[
              0.23222474174375346`, 0.36141330584468895`, 0.9365362275453637],
              UndirectedEdge[101, 301] -> 
             RGBColor[
              0.1828984857165501, 0.3095682832948322, 0.9337271702362709], 
             UndirectedEdge[337, 398] -> 
             RGBColor[
              0.7100705314017086, 0.7665791120076357, 0.7708912737801167], 
             UndirectedEdge[149, 249] -> 
             RGBColor[
              0.2628399368216051, 0.3935612687084925, 0.9382808361360453], 
             UndirectedEdge[92, 165] -> 
             RGBColor[
              0.6970699985324673, 0.761675381939551, 0.9717947555325273], 
             UndirectedEdge[150, 320] -> 
             RGBColor[
              0.19466927104284892`, 0.32194012498366686`, 0.9343974990472872],
              UndirectedEdge[59, 175] -> 
             RGBColor[
              0.314081747786117, 0.4439584718063857, 0.9413257125546342], 
             UndirectedEdge[278, 379] -> 
             RGBColor[
              0.232633859519395, 0.36184331456645336`, 0.936559526197451], 
             UndirectedEdge[87, 317] -> 
             RGBColor[
              0.19676650353045996`, 0.3241444493003659, 0.9345169333348793], 
             UndirectedEdge[212, 324] -> 
             RGBColor[
              0.5252330264468776, 0.6244698739960914, 0.9560373579630563], 
             UndirectedEdge[135, 328] -> 
             RGBColor[
              0.932186507346842, 0.7459139489960613, 0.44641772294044424`], 
             UndirectedEdge[176, 344] -> 
             RGBColor[
              0.21245918803275743`, 0.3406384556859449, 0.9354106085020388], 
             UndirectedEdge[59, 213] -> 
             RGBColor[
              0.2845653105942021, 0.4129348248674753, 0.9396447951222104], 
             UndirectedEdge[371, 391] -> 
             RGBColor[
              0.18383722908563283`, 0.3105549620955055, 0.9337806302823939], 
             UndirectedEdge[98, 318] -> 
             RGBColor[
              0.1977029240139366, 0.3251286866009877, 0.9345702610961033], 
             UndirectedEdge[25, 244] -> 
             RGBColor[
              0.8860422114357496, 0.549955853479581, 0.56283625969903], 
             UndirectedEdge[204, 224] -> 
             RGBColor[
              0.1864844568543232, 0.3133373663243338, 0.9339313859875982], 
             UndirectedEdge[180, 236] -> 
             RGBColor[
              0.2546593406268537, 0.3849934917065525, 0.9378138447627414], 
             UndirectedEdge[102, 163] -> 
             RGBColor[
              0.272133057471457, 0.4033594760078676, 0.938808947086994], 
             UndirectedEdge[16, 107] -> 
             RGBColor[
              0.33319709362883454`, 0.4630203083535974, 0.9424520020647762], 
             UndirectedEdge[194, 223] -> 
             RGBColor[
              0.9622169086067585, 0.8752522636294204, 0.4543198910461633], 
             UndirectedEdge[111, 291] -> 
             RGBColor[
              0.18821279065920096`, 0.31515395473595276`, 0.9340298120409453],
              UndirectedEdge[108, 205] -> 
             RGBColor[
              0.3030856171044626, 0.43207672625167026`, 0.9407113666179867], 
             UndirectedEdge[66, 297] -> 
             RGBColor[
              0.21059566017891732`, 0.33867976975706876`, 0.935304483347605], 
             UndirectedEdge[19, 284] -> 
             RGBColor[
              0.2685014480461575, 0.3995424242445413, 0.938602132302708], 
             UndirectedEdge[23, 260] -> 
             RGBColor[
              0.2588190028871956, 0.3893655604799919, 0.938050731374799], 
             UndirectedEdge[10, 256] -> 
             RGBColor[
              0.29440488188335295`, 0.4228333554018322, 0.9402213822269152], 
             UndirectedEdge[230, 242] -> 
             RGBColor[
              0.8350058714331137, 0.2700760442713933, 0.18115496805881381`], 
             UndirectedEdge[29, 317] -> 
             RGBColor[
              0.1883961858281423, 0.3153467146864354, 0.9340402561245076], 
             UndirectedEdge[124, 316] -> 
             RGBColor[
              0.27204171641094554`, 0.40317252702797246`, 0.9388070752443234],
              UndirectedEdge[306, 361] -> 
             RGBColor[
              0.21017418029056079`, 0.33823676767103766`, 0.9352804806914867],
              UndirectedEdge[1, 393] -> 
             RGBColor[
              0.1884550205876297, 0.3154085537489959, 0.9340436066770222], 
             UndirectedEdge[74, 279] -> 
             RGBColor[
              0.7676471267223055, 0.8187592045069678, 0.9773831565887533], 
             UndirectedEdge[40, 234] -> 
             RGBColor[
              0.653391331063141, 0.7272953937118065, 0.9673580250213626], 
             UndirectedEdge[195, 316] -> 
             RGBColor[
              0.21810104707830674`, 0.3465684072573414, 0.9357319040283003], 
             UndirectedEdge[279, 325] -> 
             RGBColor[
              0.4806866627377453, 0.5825538322263442, 0.9538715491644547], 
             UndirectedEdge[172, 337] -> 
             RGBColor[
              0.9089250228286312, 0.5868213388295864, 0.3819192617937752], 
             UndirectedEdge[148, 275] -> 
             RGBColor[
              0.28636427371918854`, 0.4159844956872421, 0.939704812363203], 
             UndirectedEdge[13, 188] -> 
             RGBColor[
              0.20797364918202638`, 0.3359238699542373, 0.9351551637002498], 
             UndirectedEdge[220, 233] -> 
             RGBColor[
              0.7976144359577942, 0.8422371475965424, 0.9590360291130758], 
             UndirectedEdge[230, 244] -> 
             RGBColor[
              0.8862518697580262, 0.551567379217462, 0.5630370287452173], 
             UndirectedEdge[253, 358] -> 
             RGBColor[
              0.19093438586024153`, 0.31801452385134865`, 0.9341848028614053],
              UndirectedEdge[66, 140] -> 
             RGBColor[
              0.21998497488731555`, 0.3485485348325317, 0.9358391909300019], 
             UndirectedEdge[89, 128] -> 
             RGBColor[
              0.1919283928758168, 0.31905928824840313`, 0.9342414100904406], 
             UndirectedEdge[199, 298] -> 
             RGBColor[
              0.19174373818706897`, 0.31886520446274574`, 0.9342308942790887],
              UndirectedEdge[367, 398] -> 
             RGBColor[
              0.40058820107881166`, 0.5213910984512207, 0.9467461038398723], 
             UndirectedEdge[72, 181] -> 
             RGBColor[
              0.1888688995598306, 0.3158435667902215, 0.9340671764722099], 
             UndirectedEdge[229, 329] -> 
             RGBColor[
              0.1986631863683978, 0.3261379832196762, 0.934624946616609], 
             UndirectedEdge[196, 326] -> 
             RGBColor[
              0.19087356510240117`, 0.3179505973785997, 0.9341813392092224], 
             UndirectedEdge[247, 362] -> 
             RGBColor[
              0.19339653330473627`, 0.32060239692467707`, 0.9343250185159485],
              UndirectedEdge[276, 297] -> 
             RGBColor[
              0.21488882463476794`, 0.3431921578025159, 0.9355489727121981], 
             UndirectedEdge[7, 201] -> 
             RGBColor[
              0.698844545732584, 0.7622666344739716, 0.960474027707296], 
             UndirectedEdge[191, 214] -> 
             RGBColor[
              0.2234844168401749, 0.3522266702024217, 0.9360384789722569], 
             UndirectedEdge[25, 32] -> 
             RGBColor[
              0.8871756231465087, 0.5004244094086581, 0.22589840996907645`], 
             UndirectedEdge[190, 324] -> 
             RGBColor[
              0.7946744730052755, 0.8399555999055638, 0.9616274448568455], 
             UndirectedEdge[8, 296] -> 
             RGBColor[
              0.241386411848991, 0.3710428020087285, 0.9370579711043807], 
             UndirectedEdge[292, 382] -> 
             RGBColor[
              0.1881384932660469, 0.31507586346502103`, 0.9340255809143183], 
             UndirectedEdge[223, 328] -> 
             RGBColor[
              0.8997164529222819, 0.6301219365340252, 0.23765071588506692`], 
             UndirectedEdge[70, 262] -> 
             RGBColor[
              0.2185336488556363, 0.3470230991538516, 0.9357565400595423], 
             UndirectedEdge[78, 285] -> 
             RGBColor[
              0.907068308455854, 0.5721275983904466, 0.38835243118889584`], 
             UndirectedEdge[167, 272] -> 
             RGBColor[
              0.5255938312060932, 0.6203452307967748, 0.9579015379327056], 
             UndirectedEdge[93, 276] -> 
             RGBColor[
              0.22858867995178067`, 0.3575915743616926, 0.9363291592053822], 
             UndirectedEdge[56, 319] -> 
             RGBColor[
              0.4175060909791842, 0.5360433358043497, 0.9478244252272849], 
             UndirectedEdge[93, 162] -> 
             RGBColor[
              0.2533245521097741, 0.3835905443446218, 0.9377378305313364], 
             UndirectedEdge[106, 389] -> 
             RGBColor[
              0.21473367973065993`, 0.34302909067154336`, 0.9355401374394254],
              UndirectedEdge[68, 176] -> 
             RGBColor[
              0.2518475893962128, 0.38203816288782416`, 0.9376537196897696], 
             UndirectedEdge[253, 301] -> 
             RGBColor[
              0.18689482770343305`, 0.31376869210576286`, 0.9339547560003658],
              UndirectedEdge[217, 357] -> 
             RGBColor[
              0.9250850387636083, 0.713744916795109, 0.34467921995684786`], 
             UndirectedEdge[364, 385] -> 
             RGBColor[
              0.9060512192132981, 0.563682156680796, 0.3995847034769297], 
             UndirectedEdge[161, 372] -> 
             RGBColor[
              0.19676171310914198`, 0.3241394142638304, 0.934516660527472], 
             UndirectedEdge[4, 339] -> 
             RGBColor[
              0.24218330961780632`, 0.3718803920899902, 0.9371033532534101], 
             UndirectedEdge[183, 280] -> 
             RGBColor[
              0.30076148412422865`, 0.4296367640588081, 0.9405789063698025], 
             UndirectedEdge[94, 145] -> 
             RGBColor[
              0.18922208139469943`, 0.31621478329169034`, 0.9340872896552201],
              UndirectedEdge[107, 351] -> 
             RGBColor[
              0.6292040524803684, 0.703641559800374, 0.9673461867380587], 
             UndirectedEdge[90, 178] -> 
             RGBColor[
              0.5250344578406001, 0.6249699305004974, 0.9558390168550672], 
             UndirectedEdge[113, 124] -> 
             RGBColor[
              0.3086276211264817, 0.4416266325643382, 0.9408905883938774], 
             UndirectedEdge[191, 365] -> 
             RGBColor[
              0.19407713550409694`, 0.321317752988877, 0.9343637778043414], 
             UndirectedEdge[184, 356] -> 
             RGBColor[
              0.18905111217950674`, 0.3160350838064485, 0.9340775532113412], 
             UndirectedEdge[196, 327] -> 
             RGBColor[
              0.19267128104236286`, 0.3198401108132733, 0.9342837164725208], 
             UndirectedEdge[140, 288] -> 
             RGBColor[
              0.2655351688852008, 0.39642467677341436`, 0.9384332070927082], 
             UndirectedEdge[13, 232] -> 
             RGBColor[
              0.2546277618608894, 0.3849603004213146, 0.9378120463987364], 
             UndirectedEdge[34, 86] -> 
             RGBColor[
              0.3371353879041764, 0.46222487105446, 0.9428569705546225], 
             UndirectedEdge[287, 374] -> 
             RGBColor[
              0.19007574708878708`, 0.31711204006170757`, 0.9341359046536132],
              UndirectedEdge[201, 230] -> 
             RGBColor[
              0.8833910407331164, 0.5494337776148619, 0.5678796660606804], 
             UndirectedEdge[71, 138] -> 
             RGBColor[
              0.18058969715831197`, 0.30714160013447456`, 0.9335956881434259],
              UndirectedEdge[334, 360] -> 
             RGBColor[
              0.185115098539477, 0.3118980839130987, 0.9338534030573518], 
             UndirectedEdge[38, 58] -> 
             RGBColor[
              0.2174442667054725, 0.3458780894432118, 0.935694501357687], 
             UndirectedEdge[115, 239] -> 
             RGBColor[
              0.8461854795987771, 0.346251043142995, 0.19147853854411218`], 
             UndirectedEdge[32, 78] -> 
             RGBColor[
              0.888484912423063, 0.5104881805224738, 0.22715218685893562`], 
             UndirectedEdge[41, 83] -> 
             RGBColor[
              0.9084527486796484, 0.9295988421678656, 0.9827837388659694], 
             UndirectedEdge[90, 212] -> 
             RGBColor[
              0.5128575453871849, 0.6144229009627645, 0.9550631147611566], 
             UndirectedEdge[160, 263] -> 
             RGBColor[
              0.42578806203725694`, 0.5430467428327064, 0.9483991221427692], 
             UndirectedEdge[226, 350] -> 
             RGBColor[
              0.7195454075725961, 0.7758957836327975, 0.8505842343054555], 
             UndirectedEdge[159, 329] -> 
             RGBColor[
              0.18547778561514033`, 0.3122792910253096, 0.9338740575497635], 
             UndirectedEdge[132, 260] -> 
             RGBColor[
              0.29142760754703456`, 0.4190601234916939, 0.9400754082095211], 
             UndirectedEdge[7, 250] -> 
             RGBColor[
              0.35349640883612216`, 0.4759428684075872, 0.943916070428803], 
             UndirectedEdge[135, 281] -> 
             RGBColor[
              0.711765095722288, 0.768553055573181, 0.8142632180180123], 
             UndirectedEdge[240, 243] -> 
             RGBColor[
              0.9006075598972731, 0.6106868981753124, 0.5572235175535094], 
             UndirectedEdge[105, 349] -> 
             RGBColor[
              0.20573070891450085`, 0.3335663975224413, 0.935027431570147], 
             UndirectedEdge[111, 154] -> 
             RGBColor[
              0.19738148096805996`, 0.3247908295791051, 0.934551955390173], 
             UndirectedEdge[3, 233] -> 
             RGBColor[
              0.7706376185941841, 0.8203361519689907, 0.9569123152308744], 
             UndirectedEdge[125, 162] -> 
             RGBColor[
              0.2669203824734684, 0.39788062408229774`, 0.9385120929573202], 
             UndirectedEdge[301, 369] -> 
             RGBColor[
              0.18664719483068826`, 0.31350841425567716`, 0.9339406536746029],
              UndirectedEdge[268, 270] -> 
             RGBColor[
              0.5192310696539062, 0.6174490867384653, 0.9563893333020512], 
             UndirectedEdge[4, 188] -> 
             RGBColor[
              0.2173017232473819, 0.34572826723098127`, 0.9356863837186229], 
             UndirectedEdge[161, 176] -> 
             RGBColor[
              0.21656199837052442`, 0.34495076948413805`, 0.9356442574812107],
              UndirectedEdge[106, 270] -> 
             RGBColor[
              0.2929589759941193, 0.42059333525935383`, 0.9401654130551529], 
             UndirectedEdge[190, 268] -> 
             RGBColor[
              0.8177911045280821, 0.8581558703042615, 0.9638348308947651], 
             UndirectedEdge[220, 341] -> 
             RGBColor[
              0.4860287842689018, 0.590440011686344, 0.9535595010943037], 
             UndirectedEdge[76, 103] -> 
             RGBColor[
              0.19412197120965846`, 0.32136487815817005`, 0.9343663311314445],
              UndirectedEdge[84, 163] -> 
             RGBColor[
              0.3028162711208553, 0.4328272844297121, 0.940658180484038], 
             UndirectedEdge[356, 372] -> 
             RGBColor[
              0.1945300591839852, 0.3217938044934594, 0.9343895711378705], 
             UndirectedEdge[243, 398] -> 
             RGBColor[
              0.6978102198330773, 0.7601382089599893, 0.9424198532319874], 
             UndirectedEdge[141, 243] -> 
             RGBColor[
              0.9175618655302045, 0.7296924440007758, 0.5730160037263106], 
             UndirectedEdge[192, 320] -> 
             RGBColor[
              0.18870690253434044`, 0.31567329764522667`, 0.9340579509812614],
              UndirectedEdge[83, 245] -> 
             RGBColor[
              0.8819322732807819, 0.5521345143978579, 0.5717957186100475], 
             UndirectedEdge[256, 313] -> 
             RGBColor[
              0.28483799884386285`, 0.41277795475190926`, 0.9396765623907513],
              UndirectedEdge[144, 186] -> 
             RGBColor[
              0.19870087032152506`, 0.3261775914437136, 0.9346270926619912], 
             UndirectedEdge[271, 371] -> 
             RGBColor[
              0.1828236944867615, 0.3094896729702865, 0.9337229109863782], 
             UndirectedEdge[317, 326] -> 
             RGBColor[
              0.19368284883535128`, 0.3209033327008066, 0.9343413237618512], 
             UndirectedEdge[194, 242] -> 
             RGBColor[
              0.9234025469352043, 0.6967570760189528, 0.42193717605226866`], 
             UndirectedEdge[305, 334] -> 
             RGBColor[
              0.18360707090558112`, 0.31031305125539965`, 0.9337675231145284],
              UndirectedEdge[252, 282] -> 
             RGBColor[
              0.31835440977210794`, 0.4463178036126423, 0.941647079240882], 
             UndirectedEdge[134, 239] -> 
             RGBColor[
              0.8293655507418161, 0.5412295041829576, 0.578979393717503], 
             UndirectedEdge[267, 398] -> 
             RGBColor[
              0.34104050458358826`, 0.46493592502132197`, 0.9431303829813984],
              UndirectedEdge[4, 297] -> 
             RGBColor[
              0.2198696831096341, 0.34842735586426754`, 0.9358326252338219], 
             UndirectedEdge[40, 272] -> 
             RGBColor[
              0.6309966022057711, 0.7098004613221861, 0.9651259277394999], 
             UndirectedEdge[203, 325] -> 
             RGBColor[
              0.2574480826974209, 0.38792463643917835`, 0.9379726594980861], 
             UndirectedEdge[315, 359] -> 
             RGBColor[
              0.2030249569861144, 0.33072248069112636`, 0.9348733430006266], 
             UndirectedEdge[132, 160] -> 
             RGBColor[
              0.40894844852211004`, 0.5284611159894712, 0.9473261168602697], 
             UndirectedEdge[283, 381] -> 
             RGBColor[
              0.20257187699290616`, 0.3302462648913338, 0.9348475407652852], 
             UndirectedEdge[40, 183] -> 
             RGBColor[
              0.43552341404886974`, 0.5498108720138242, 0.9494803631610341], 
             UndirectedEdge[131, 339] -> 
             RGBColor[
              0.23240211172972863`, 0.36159973294585546`, 0.9365463285036696],
              UndirectedEdge[156, 165] -> 
             RGBColor[
              0.8638677055732559, 0.5798421452000351, 0.5836596867408057], 
             UndirectedEdge[352, 379] -> 
             RGBColor[
              0.22335212736306764`, 0.3520876255743447, 0.9360309452822404], 
             UndirectedEdge[25, 194] -> 
             RGBColor[
              0.9059253338243674, 0.5624195574854407, 0.4052009770396422], 
             UndirectedEdge[174, 238] -> 
             RGBColor[
              0.3169893195658634, 0.44724710585547944`, 0.9414827781424888], 
             UndirectedEdge[66, 339] -> 
             RGBColor[
              0.23290928668708955`, 0.3621328059827914, 0.9365752113671932], 
             UndirectedEdge[67, 387] -> 
             RGBColor[
              0.4796742864541198, 0.5876973628554791, 0.9523916433059518], 
             UndirectedEdge[90, 190] -> 
             RGBColor[
              0.7822989919455827, 0.8299086268722369, 0.9606532016549456], 
             UndirectedEdge[271, 389] -> 
             RGBColor[
              0.19087423447573804`, 0.31795130093241747`, 0.9341813773290437],
              UndirectedEdge[19, 293] -> 
             RGBColor[
              0.3046492475878372, 0.4338240686707453, 0.9407966099576801], 
             UndirectedEdge[126, 327] -> 
             RGBColor[
              0.19109665502145906`, 0.31818507902824733`, 0.9341940438500809],
              UndirectedEdge[12, 310] -> 
             RGBColor[
              0.2940376027932159, 0.42638254196942454`, 0.9400563785381975], 
             UndirectedEdge[272, 350] -> 
             RGBColor[
              0.867391875594665, 0.894633501748924, 0.8631950663915847], 
             UndirectedEdge[215, 229] -> 
             RGBColor[
              0.19493972789376507`, 0.3222243922819345, 0.9344129011648419], 
             UndirectedEdge[57, 189] -> 
             RGBColor[
              0.24216202976271878`, 0.3718580256130724, 0.9371021413971435], 
             UndirectedEdge[104, 337] -> 
             RGBColor[
              0.9065279712784959, 0.568396550220559, 0.3796238425222831], 
             UndirectedEdge[194, 385] -> 
             RGBColor[
              0.9944784929138155, 0.9905983795896796, 0.6403962123397537], 
             UndirectedEdge[56, 166] -> 
             RGBColor[
              0.6856726502293173, 0.7474973607293266, 0.8829926191709212], 
             UndirectedEdge[258, 379] -> 
             RGBColor[
              0.19525485067885182`, 0.32255560630899927`, 0.9344308469412701],
              UndirectedEdge[9, 150] -> 
             RGBColor[
              0.19229026561489077`, 0.3194396394412268, 0.9342620182075883], 
             UndirectedEdge[294, 380] -> 
             RGBColor[
              0.20504200072556777`, 0.3328425215492514, 0.9349882106576397], 
             UndirectedEdge[296, 308] -> 
             RGBColor[
              0.22323052785896746`, 0.35195981678568156`, 0.9360240203703722],
              UndirectedEdge[33, 92] -> 
             RGBColor[
              0.3869660924415177, 0.5054181375626268, 0.9463177797578736], 
             UndirectedEdge[39, 283] -> 
             RGBColor[
              0.19607798492560893`, 0.3234207725920666, 0.934477723218905], 
             UndirectedEdge[11, 34] -> 
             RGBColor[
              0.28760640007487454`, 0.41932535119602954`, 0.9397010272469036],
              UndirectedEdge[105, 171] -> 
             RGBColor[
              0.19921926143757313`, 0.32672245337457523`, 0.9346566142691592],
              UndirectedEdge[110, 237] -> 
             RGBColor[
              0.19038343508665123`, 0.3174354396560086, 0.9341534270299079], 
             UndirectedEdge[8, 175] -> 
             RGBColor[
              0.2597318112605219, 0.39032497995575144`, 0.938102714461281], 
             UndirectedEdge[90, 373] -> 
             RGBColor[
              0.44011491122134366`, 0.5480057067490964, 0.9505529184695845], 
             UndirectedEdge[73, 104] -> 
             RGBColor[
              0.874812220102593, 0.4548689553377009, 0.21443306157225883`], 
             UndirectedEdge[232, 339] -> 
             RGBColor[
              0.2733203034534184, 0.404607346810652, 0.9388765589892938], 
             UndirectedEdge[178, 274] -> 
             RGBColor[
              0.46738436670940764`, 0.5781669894131862, 0.9513005905019778], 
             UndirectedEdge[224, 318] -> 
             RGBColor[
              0.18686239314258873`, 0.3137346013258456, 0.9339529089001083], 
             UndirectedEdge[132, 307] -> 
             RGBColor[
              0.3533139613151539, 0.48044452804031823`, 0.9437338310851009]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.1972575262297792, 0.3246605452899877, 0.9345448963512025], 
             316 -> RGBColor[
              0.23435379828218117`, 0.36365107925655765`, 0.9366574741655703],
              308 -> RGBColor[
              0.20150049615977755`, 0.32912017570624735`, 0.9347865272118044],
              160 -> RGBColor[
              0.4596234812344611, 0.572182073724828, 0.9506023905805157], 245 -> 
             RGBColor[
              0.818830055518114, 0.14574163486097447`, 0.1656649884706391], 
             155 -> RGBColor[
              0.2070813101039675, 0.3349859650056321, 0.9351043463098516], 
             213 -> RGBColor[
              0.22261848399738943`, 0.3513165198813409, 0.9359891653778931], 
             352 -> RGBColor[
              0.2396024194233052, 0.3691677128576799, 0.9369563753749182], 27 -> 
             RGBColor[
              0.821038236612611, 0.16271468238440395`, 0.16777954518051325`], 
             367 -> RGBColor[
              0.37508215881778845`, 0.49929904661568136`, 0.9451208813811075],
              19 -> RGBColor[
              0.26040419361571815`, 0.3910316964425663, 0.9381410056417089], 
             164 -> RGBColor[
              0.20095261322947336`, 0.32854431600871353`, 0.9347553260894438],
              190 -> RGBColor[
              0.9562193148935751, 0.9668690172486966, 0.9589934594404549], 
             103 -> RGBColor[
              0.19434739415987903`, 0.3216018119714924, 0.9343791686349763], 
             138 -> RGBColor[
              0.18225239431662393`, 0.3088892002689491, 0.9336903762868517], 
             291 -> RGBColor[
              0.18717515147111807`, 0.3140633301591533, 0.9339707200242335], 
             28 -> RGBColor[
              0.20698871416859752`, 0.3348886408066369, 0.9350990731083157], 
             337 -> RGBColor[
              0.9940468194635823, 0.9896750737285114, 0.5934112212615963], 
             195 -> RGBColor[
              0.20184829587443234`, 0.32948573525812513`, 0.9348063338910304],
              114 -> RGBColor[
              0.24129060741956473`, 0.3709421054790498, 0.9370525151838548], 
             93 -> RGBColor[
              0.2343202347626608, 0.3636158018694917, 0.9366555627727864], 34 -> 
             RGBColor[
              0.2632481201845229, 0.3940208435817391, 0.93830296305259], 161 -> 
             RGBColor[
              0.1994550789542851, 0.32697031253633363`, 0.9346700437278752], 
             22 -> RGBColor[
              0.3162753653274515, 0.4483635578097335, 0.9413737645007089], 
             124 -> RGBColor[
              0.3097296345397099, 0.44269397479938727`, 0.9409566763230764], 
             84 -> RGBColor[
              0.3388378220394789, 0.4679060237916442, 0.9428114242912021], 46 -> 
             RGBColor[
              0.20129344185623907`, 0.3289025485052273, 0.9347747357755273], 
             241 -> 
             RGBColor[
              0.2632132370288079, 0.3939841791733627, 0.938300976508477], 185 -> 
             RGBColor[
              0.3996003392677278, 0.5205354622018381, 0.9466831581588019], 
             390 -> RGBColor[
              0.2627109211596987, 0.39345621334626335`, 0.938272370362841], 
             121 -> RGBColor[
              0.3109061797336599, 0.4437130391115059, 0.9410316447424569], 
             322 -> RGBColor[
              0.1999051049994005, 0.32744331844304914`, 0.9346956720453906], 
             126 -> RGBColor[
              0.1865862227024127, 0.3134443286830033, 0.9339371814020978], 
             236 -> RGBColor[
              0.25077535368791876`, 0.38091117517473666`, 0.9375926574524128],
              78 -> RGBColor[
              0.8199375785531087, 0.1542545422276314, 0.1667255537797183], 
             376 -> RGBColor[
              0.209601906353837, 0.3376352714792777, 0.9352478905373938], 254 -> 
             RGBColor[
              0.18724741023772068`, 0.314139278704323, 0.9339748350540943], 
             290 -> RGBColor[
              0.19821724293608944`, 0.32566926839787347`, 0.9345995507978533],
              251 -> RGBColor[
              0.19027393338711107`, 0.3173203464269832, 0.9341471910701123], 
             165 -> RGBColor[
              0.8967495440562933, 0.920507761085305, 0.9900139661214994], 100 -> 
             RGBColor[
              0.2101475089071078, 0.33820873435596516`, 0.9352789617956558], 
             235 -> RGBColor[
              0.1915139828942802, 0.31862371708269777`, 0.9342178100550568], 
             70 -> RGBColor[
              0.22291581655962178`, 0.35162903525622036`, 0.9360060980274482],
              234 -> RGBColor[
              0.7857227396767522, 0.8325318430402561, 0.9792771577606599], 
             257 -> RGBColor[
              0.32310439559809073`, 0.45427852059311985`, 0.9418089042708796],
              135 -> RGBColor[
              0.9948422584139026, 0.9913764372120322, 0.679989842123797], 265 -> 
             RGBColor[
              0.18998272969436467`, 0.3170142728825262, 0.9341306074506077], 
             111 -> RGBColor[
              0.18925042984728385`, 0.3162445793127523, 0.934088904057657], 
             381 -> RGBColor[
              0.19616341759440778`, 0.32351056774371817`, 0.9344825884830068],
              182 -> RGBColor[
              0.34853172220347034`, 0.47630239288410453`, 0.9434291110376724],
              188 -> RGBColor[
              0.2017846044041309, 0.3294187914845658, 0.9348027067560198], 
             154 -> 
             RGBColor[
              0.2055125320888361, 0.33333707984545796`, 0.935015006722689], 
             336 -> RGBColor[
              0.18035329176886106`, 0.3068931230811942, 0.933582225206227], 
             315 -> RGBColor[
              0.2188459842157359, 0.34735138342052185`, 0.9357743270962412], 
             368 -> RGBColor[
              0.1851720653526604, 0.311957959645659, 0.9338566472330878], 269 -> 
             RGBColor[
              0.743581503407994, 0.7996107889818441, 0.9750769131616334], 208 -> 
             RGBColor[
              0.9930152754848626, 0.9913796511608278, 0.7654184913108293], 86 -> 
             RGBColor[
              0.4110226556238299, 0.5304288985271809, 0.947410978056655], 119 -> 
             RGBColor[
              0.18241596627536708`, 0.30906112476864933`, 0.9336996914679191],
              377 -> RGBColor[
              0.18473621585810335`, 0.3114998541924255, 0.9338318262491543], 
             140 -> RGBColor[
              0.2256991535454318, 0.35455449890206425`, 0.9361646049512119], 
             85 -> RGBColor[
              0.24074527521724318`, 0.3703689267583512, 0.9370214593216792], 
             351 -> RGBColor[
              0.9097894237460113, 0.9309054071917814, 0.9912577214871428], 
             242 -> RGBColor[
              0.852273426221674, 0.40280203706702433`, 0.19769039802525293`], 
             117 -> RGBColor[
              0.22614100723621103`, 0.3550189151462153, 0.9361897678652379], 
             47 -> RGBColor[
              0.5441036538714303, 0.6407668836599264, 0.9572529792315668], 81 -> 
             RGBColor[
              0.17955783501139488`, 0.30605704759422586`, 0.9335369251206622],
              275 -> RGBColor[
              0.23875032994207512`, 0.36827211278731364`, 0.9369078501395155],
              23 -> RGBColor[
              0.2930562064900811, 0.4253510322307103, 0.9400004894705796], 
             328 -> RGBColor[
              0.8695307562797816, 0.5004514607800906, 0.21284560375709155`], 
             110 -> RGBColor[
              0.18343408206602244`, 0.3101312290168976, 0.9337576716560296], 
             6 -> RGBColor[
              0.30558851701585305`, 0.4385232851876776, 0.9407141860151303], 
             218 -> RGBColor[
              0.19086057119328328`, 0.3179369399562554, 0.934180599225321], 
             108 -> RGBColor[
              0.256153514960176, 0.38656396366699863`, 0.9378989357805914], 
             297 -> RGBColor[
              0.20692052412863532`, 0.33481696875113837`, 0.935095189786418], 
             157 -> 
             RGBColor[
              0.1873941802353717, 0.31429354327760956`, 0.9339831933883338], 
             354 -> RGBColor[
              0.2158527042869893, 0.34420525643050026`, 0.9356038642324599], 
             385 -> RGBColor[
              0.9944253181788963, 0.9904846442084778, 0.6346084706002231], 
             270 -> RGBColor[
              0.3590992451452233, 0.4854554501171043, 0.9441024642550272], 
             392 -> RGBColor[
              0.9910839134677017, 0.9905809833329919, 0.7974261581398643], 33 -> 
             RGBColor[
              0.2765417318743941, 0.4079932723314563, 0.939060014572192], 252 -> 
             RGBColor[
              0.3695662131784596, 0.4945214117423836, 0.9447694102025287], 
             394 -> RGBColor[
              0.18043226082461958`, 0.30697612456572376`, 0.9335867223771283],
              260 -> RGBColor[
              0.22458179928431016`, 0.35338008872927346`, 0.9361009732790185],
              159 -> RGBColor[
              0.1805122222555836, 0.3070601690995145, 0.9335912760623294], 
             183 -> RGBColor[
              0.3499869056482099, 0.4775627996442913, 0.943521834040003], 99 -> 
             RGBColor[
              0.965636915117815, 0.9738926480760296, 0.9430519187643377], 329 -> 
             RGBColor[
              0.19044334897469703`, 0.3174984129511047, 0.9341568390371975], 
             309 -> RGBColor[
              0.2975965440226766, 0.4301232148514946, 0.9402590549762334], 17 -> 
             RGBColor[
              0.2316763474093035, 0.360836908628973, 0.9365049972992935], 349 -> 
             RGBColor[
              0.2019856527302044, 0.3296301060224692, 0.9348141561607654], 
             347 -> RGBColor[
              0.19785125300646603`, 0.3252845897767374, 0.9345787082127948], 
             340 -> RGBColor[
              0.2029347338096705, 0.33062765041220404`, 0.9348682049242014], 
             277 -> RGBColor[
              0.20781531186542476`, 0.3357574473953233, 0.9351461466243084], 
             104 -> RGBColor[
              0.8190091230934095, 0.14711802671260676`, 0.16583646378296987`],
              79 -> RGBColor[
              0.23104392871496413`, 0.36017219648356114`, 0.9364689819902305],
              327 -> RGBColor[
              0.19560708734050541`, 0.3229258293734914, 0.9344509062980639], 
             191 -> RGBColor[
              0.20722377740839654`, 0.33513570717553587`, 0.9351124596120775],
              50 -> RGBColor[
              0.1790362447681438, 0.3055088231778375, 0.9335072213279326], 
             225 -> 
             RGBColor[
              0.884710274500928, 0.9109079743391231, 0.9888656498437259], 61 -> 
             RGBColor[
              0.20936457771848743`, 0.3373858240360207, 0.9352343750227069], 
             196 -> RGBColor[
              0.18973547474422028`, 0.3167543922530552, 0.9341165266469779], 
             1 -> RGBColor[
              0.19354678877808446`, 0.32076032495391327`, 0.9343335753428726],
              263 -> RGBColor[
              0.3919526428400527, 0.5139114119405849, 0.9461958537050229], 
             201 -> RGBColor[
              0.9490437648216794, 0.9615175037539616, 0.971139794028986], 371 -> 
             RGBColor[
              0.18654757264035143`, 0.3134037050172214, 0.9339349803382411], 
             293 -> RGBColor[
              0.3488943015599562, 0.47661644089892424`, 0.9434522142736513], 
             362 -> RGBColor[
              0.18916507484151227`, 0.3161548657898664, 0.9340840432163497], 
             184 -> RGBColor[
              0.18311045325504194`, 0.3097910746173054, 0.9337392414740102], 
             106 -> RGBColor[
              0.22681870684301533`, 0.35573122040160343`, 0.9362283618552786],
              206 -> RGBColor[
              0.7303132143006519, 0.7892455006884563, 0.9737544541026248], 
             358 -> RGBColor[
              0.19077583416012883`, 0.31784787596177183`, 0.9341757735766401],
              247 -> RGBColor[
              0.1976279917679603, 0.3250499280594878, 0.9345659938155473], 
             220 -> RGBColor[
              0.635822518194204, 0.7152283896049052, 0.9644734242083259], 107 -> 
             RGBColor[
              0.34861868121472545`, 0.4763777124089667, 0.9434346519889747], 
             375 -> RGBColor[
              0.180596656524124, 0.30714891486919227`, 0.9335960844690134], 
             131 -> RGBColor[
              0.21325644631447746`, 0.3414764246891273, 0.9354560111817448], 
             127 -> RGBColor[
              0.19480415931956344`, 0.32208190111490453`, 0.9344051807350968],
              210 -> RGBColor[
              0.3056537490672848, 0.4385918482096833, 0.9407179008839572], 
             357 -> RGBColor[
              0.85710048921771, 0.439904958487049, 0.20231279900164487`], 181 -> 
             RGBColor[
              0.19492367816056405`, 0.3222075229947284, 0.9344119871562795], 
             194 -> RGBColor[
              0.9945316676487347, 0.9907121149708813, 0.6461839540792844], 
             118 -> RGBColor[
              0.2388812891503496, 0.36840975921850344`, 0.93691530807269], 
             348 -> 
             RGBColor[
              0.33313964664549794`, 0.4629705506640006, 0.9424483415937963], 
             276 -> RGBColor[
              0.22285712514090053`, 0.35156734685389346`, 0.9360027556379781],
              305 -> RGBColor[
              0.18223318953702214`, 0.3088690148279342, 0.9336892826030643], 
             343 -> RGBColor[
              0.1820208818055452, 0.30864586594106436`, 0.9336771919918379], 
             280 -> RGBColor[
              0.2515360626002474, 0.3817107284733248, 0.937635978699602], 189 -> 
             RGBColor[
              0.266643234211289, 0.39758932368653244`, 0.9384963097737932], 
             168 -> RGBColor[
              0.18420503135956878`, 0.31094154560542325`, 0.9338015760777798],
              363 -> RGBColor[
              0.21990087473071346`, 0.348460140235685, 0.9358344015504985], 
             41 -> RGBColor[
              0.8718710063158469, 0.90067029040099, 0.9876410289824828], 14 -> 
             RGBColor[
              0.18454901891679482`, 0.31130309833813863`, 0.9338211656602798],
              77 -> RGBColor[
              0.18280925758947733`, 0.30947449887588874`, 0.9337220888264354],
              51 -> RGBColor[
              0.381577964086101, 0.5049253866504279, 0.9455347883487892], 179 -> 
             RGBColor[
              0.45394807471440896`, 0.5675745230376996, 0.950155601789558], 
             223 -> RGBColor[
              0.9299021495647822, 0.7597924122879596, 0.2624558280130423], 
             323 -> RGBColor[
              0.3986910652219958, 0.5197478947248675, 0.9466252200206473], 
             292 -> RGBColor[
              0.1943854920349882, 0.321641855253777, 0.934381338252603], 396 -> 
             RGBColor[
              0.19955786085140656`, 0.3270783428269569, 0.9346758970048641], 
             321 -> RGBColor[
              0.5543615420614805, 0.6490946994052059, 0.9580605177657702], 
             143 -> RGBColor[
              0.18504307948317125`, 0.3118223873186494, 0.9338493016786379], 
             112 -> RGBColor[
              0.937107871400364, 0.788360698201582, 0.2682537209419814], 197 -> 
             RGBColor[
              0.9643115115712477, 0.9729041642811488, 0.9452954812480678], 54 -> 
             RGBColor[
              0.1846123721443362, 0.31136968659711123`, 0.9338247735328656], 
             71 -> RGBColor[0.178927, 0.305394, 0.933501], 177 -> 
             RGBColor[
              0.8948525196191675, 0.9189951252924975, 0.9898330262371927], 
             158 -> RGBColor[
              0.3387561380668311, 0.4678352732400925, 0.9428062194606953], 
             226 -> RGBColor[
              0.44524034591787487`, 0.5600665420287623, 0.9495912990246761], 
             350 -> RGBColor[
              0.9938504692273173, 0.9917250252368329, 0.751577169586235], 203 -> 
             RGBColor[
              0.2257570420476589, 0.35461534338824796`, 0.9361679016157753], 
             115 -> RGBColor[
              0.8646080428941941, 0.47809856902505976`, 0.2087379710414105], 
             173 -> RGBColor[
              0.2824798268544749, 0.4142345866524884, 0.9393981802966833], 
             212 -> RGBColor[
              0.41733642177677943`, 0.535897565429752, 0.9478132856528767], 
             129 -> RGBColor[
              0.189088316742455, 0.3160741881610126, 0.9340796719561618], 279 -> 
             RGBColor[
              0.6722342021283076, 0.7438737349625797, 0.9679656809485127], 26 -> 
             RGBColor[
              0.18699939157323073`, 0.3138785953626525, 0.9339607107580624], 
             40 -> RGBColor[
              0.5210599224495296, 0.6220589443833571, 0.9554388922820652], 
             146 -> RGBColor[
              0.18614238840660097`, 0.3129778306973855, 0.9339119056955454], 
             386 -> RGBColor[
              0.7607606134285254, 0.8130312402959552, 0.9767891663005692], 
             192 -> RGBColor[
              0.18162114890697434`, 0.30822572132013676`, 0.933654427794616], 
             300 -> RGBColor[
              0.9146994662552146, 0.9348205418090667, 0.9917260457249173], 
             221 -> RGBColor[
              0.9023083761464576, 0.6492869771870501, 0.2401960532268301], 62 -> 
             RGBColor[
              0.20110579749352597`, 0.32870532238267614`, 0.9347640497066657],
              286 -> RGBColor[
              0.1948453625020903, 0.32212520827217295`, 0.9344075271953871], 
             152 -> RGBColor[
              0.25676930210776144`, 0.3872111950022711, 0.9379340039476709], 
             64 -> RGBColor[
              0.18064334912177313`, 0.30719799174980317`, 0.933598743543374], 
             307 -> RGBColor[
              0.3483545068205488, 0.47614889782652203`, 0.9434178190301781], 
             37 -> RGBColor[
              0.34879862256835453`, 0.4765335685653648, 0.9434461176929121], 
             148 -> RGBColor[
              0.33397821749630197`, 0.46369687858717057`, 0.9425017745868906],
              261 -> RGBColor[
              0.2599700418165058, 0.39057537537478015`, 0.9381162813390138], 
             387 -> 
             RGBColor[
              0.5341260408491124, 0.6326666079220644, 0.9564675049852491], 15 -> 
             RGBColor[
              0.28582560720535155`, 0.41775121393598635`, 0.9395887175380273],
              136 -> RGBColor[
              0.18458947116943916`, 0.3113456162204888, 0.9338234693562242], 
             198 -> RGBColor[
              0.3533082208089774, 0.4804395559023944, 0.9437334653051234], 63 -> 
             RGBColor[
              0.1811814280726413, 0.30776354684334156`, 0.9336293863436095], 
             310 -> RGBColor[
              0.27959908951497947`, 0.4112067490593821, 0.9392341265668681], 
             171 -> RGBColor[
              0.188962757776349, 0.315942217726737, 0.93407252155879], 395 -> 
             RGBColor[
              0.46863892160806836`, 0.5795012143610829, 0.9513121190713723], 
             311 -> RGBColor[
              0.3027440138032642, 0.4355335319593264, 0.9405521957652387], 
             353 -> RGBColor[
              0.19002087389400624`, 0.31705436485483146`, 0.934132779706348], 
             59 -> RGBColor[
              0.3465121371910148, 0.4745531298536097, 0.9433004248665277], 
             397 -> RGBColor[
              0.2129233554713194, 0.341126325093789, 0.9354370421509908], 229 -> 
             RGBColor[
              0.20688302376209858`, 0.33477755348824767`, 0.9350930541960206],
              102 -> RGBColor[
              0.2774713947406823, 0.40897040694795533`, 0.9391129574971142], 
             299 -> RGBColor[
              0.18766218808016377`, 0.31457523651516484`, 0.9339984560386126],
              128 -> RGBColor[
              0.19461177340916913`, 0.32187969132510885`, 0.9343942246421093],
              12 -> RGBColor[
              0.3084761160714523, 0.441558334879467, 0.9408786305095267], 222 -> 
             RGBColor[
              0.23238602207295528`, 0.3615828216964435, 0.9365454122215189], 
             92 -> RGBColor[
              0.49739045300864126`, 0.6028430027937971, 0.9535755449435551], 
             271 -> RGBColor[
              0.17909981633317154`, 0.30557564092335165`, 0.9335108416345153],
              361 -> RGBColor[
              0.21763599434706354`, 0.34607960735075854`, 0.93570541996324], 
             344 -> RGBColor[
              0.1912494582787511, 0.31834568493994736`, 0.9342027457695316], 
             132 -> RGBColor[
              0.35827341580975897`, 0.4847401582541144, 0.9440498431400237], 
             80 -> RGBColor[
              0.1798079986201722, 0.3063199854083397, 0.9335511715680982], 
             324 -> 
             RGBColor[
              0.6331296311169758, 0.713042182562431, 0.9642614302732361], 244 -> 
             RGBColor[
              0.9547654228714991, 0.9657847069591619, 0.9614545193980599], 
             150 -> RGBColor[
              0.19354588592399127`, 0.3207593759970171, 0.9343335239266677], 
             125 -> RGBColor[
              0.2615118954900493, 0.3921959613448436, 0.9382040876247539], 
             258 -> RGBColor[
              0.18340786605487358`, 0.31010367432698904`, 0.9337561786929778],
              133 -> RGBColor[
              0.18578718983175693`, 0.312604494474334, 0.9338916776621772], 
             255 -> RGBColor[
              0.8353613957275855, 0.2728087597904426, 0.18149541852470724`], 
             326 -> RGBColor[
              0.19201165546058205`, 0.31914680250414423`, 0.9342461517714671],
              176 -> RGBColor[
              0.23366891778676377`, 0.3629312264319425, 0.9366184712345461], 
             230 -> RGBColor[
              0.8177383166445533, 0.1373500514757623, 0.1646195380923747], 
             274 -> RGBColor[
              0.49307848673520527`, 0.5993423543211548, 0.9532360911632574], 
             87 -> RGBColor[
              0.19817896485079942`, 0.32562903570326285`, 0.9345973709175234],
              130 -> RGBColor[
              0.1820121662584413, 0.30863670534846055`, 0.9336766956543238], 
             35 -> RGBColor[
              0.2362515342121432, 0.36564572004235524`, 0.9367655474193329], 
             379 -> RGBColor[
              0.20710183530283005`, 0.33500753829100943`, 0.9351055151895625],
              31 -> RGBColor[
              0.19647646719475834`, 0.3238396027221777, 0.9345004161946314], 
             18 -> RGBColor[
              0.6051402883638863, 0.6903191732099512, 0.9620580066833722], 24 -> 
             RGBColor[
              0.8207868509580615, 0.16078242208563953`, 0.1675388179938171], 
             151 -> RGBColor[
              0.19201931518110454`, 0.3191548533560677, 0.9342465879812193], 
             137 -> RGBColor[
              0.33446348254021346`, 0.46411719077807645`, 0.9425326952463855],
              330 -> RGBColor[
              0.18593025704413854`, 0.31275486718553225`, 0.9338998251282734],
              296 -> RGBColor[
              0.2449605595581574, 0.37479945786511576`, 0.9372615135289399], 
             266 -> RGBColor[
              0.23275233921967517`, 0.3619678442434947, 0.9365662734411069], 
             302 -> RGBColor[
              0.19137511524925596`, 0.3184777583830601, 0.9342099017481089], 
             283 -> 
             RGBColor[
              0.20898033639140454`, 0.33698196203894937`, 0.9352124930475636],
              388 -> RGBColor[
              0.2195142065627996, 0.3480537274750297, 0.9358123813703602], 
             284 -> RGBColor[
              0.2765987024765969, 0.40805315204651627`, 0.939063258963707], 
             318 -> RGBColor[
              0.19439044372267295`, 0.3216470597914888, 0.9343816202438913], 
             238 -> RGBColor[
              0.28998218143607674`, 0.4221200369945062, 0.9398254282913666], 
             72 -> RGBColor[
              0.18281412095909713`, 0.3094796105857146, 0.9337223657881405], 
             288 -> RGBColor[
              0.30537118422496984`, 0.4382948546447645, 0.9407018092342045], 
             382 -> RGBColor[
              0.1818914944971056, 0.30850987167626515`, 0.9336698235760336], 
             389 -> RGBColor[
              0.20264865261830456`, 0.3303269609414833, 0.9348519130235723], 
             172 -> RGBColor[
              0.8238032261936802, 0.18396760393066158`, 0.17042730232595416`],
              243 -> RGBColor[
              0.9695261963263196, 0.9767932676332187, 0.9364683801653377], 88 -> 
             RGBColor[
              0.19146940577852636`, 0.3185768637076881, 0.9342152714542605], 
             273 -> RGBColor[
              0.1818250295794584, 0.30844001283369876`, 0.9336660384972996], 
             202 -> RGBColor[
              0.2433593553333951, 0.37311649070267905`, 0.9371703273171091], 
             393 -> RGBColor[
              0.18336325239717496`, 0.31005678254407854`, 0.9337536380111718],
              98 -> RGBColor[
              0.20101540430520026`, 0.32861031341048663`, 0.9347589019483153],
              30 -> RGBColor[
              0.18021067351487519`, 0.3067432222537355, 0.9335741033076473], 
             116 -> RGBColor[
              0.18333815129494635`, 0.31003039969413443`, 0.9337522085405336],
              373 -> RGBColor[
              0.271851153445097, 0.4030631770024157, 0.9387928930697325], 240 -> 
             RGBColor[
              0.8316889234682268, 0.24458052871740593`, 0.17797865494168116`],
              317 -> RGBColor[
              0.1953540422101205, 0.32265986289746895`, 0.9344364957522352], 
             391 -> RGBColor[
              0.18112688553091424`, 0.3077062191737896, 0.9336262802265466], 
             73 -> RGBColor[
              0.9306153171117766, 0.762619883962795, 0.26302965936154776`], 
             303 -> RGBColor[
              0.21323548342695858`, 0.34145439136522115`, 0.9354548173763124],
              29 -> 
             RGBColor[
              0.1814383294461641, 0.30803356647540187`, 0.9336440164967801], 
             360 -> RGBColor[
              0.18524924480481392`, 0.31203908014333226`, 0.9338610424887112],
              320 -> RGBColor[
              0.19579265616170655`, 0.32312087397031664`, 0.9344614741679068],
              75 -> RGBColor[
              0.21796667840296896`, 0.34642717726009525`, 0.9357242519310205],
              200 -> RGBColor[
              0.1842143453500115, 0.31095133519991963`, 0.9338021064957567], 
             301 -> RGBColor[
              0.18269671784651187`, 0.30935621247060024`, 0.933715679854561], 
             156 -> RGBColor[
              0.8309858670902185, 0.23917652931476524`, 0.17730540736011186`],
              25 -> RGBColor[0.817319, 0.134127, 0.164218], 38 -> 
             RGBColor[
              0.22292982485851465`, 0.3516437588665342, 0.9360068957793466], 
             365 -> RGBColor[
              0.18093049359979738`, 0.3074997988022181, 0.9336150959966053], 
             380 -> RGBColor[
              0.22012423896070668`, 0.348694910203518, 0.9358471218129588], 
             370 -> RGBColor[
              0.18708771794254558`, 0.3139714319770177, 0.9339657408141276], 
             3 -> RGBColor[
              0.5818688834669836, 0.6714263983498019, 0.960225996443923], 57 -> 
             RGBColor[
              0.21768082531414856`, 0.3461267275396124, 0.9357079730204939], 
             227 -> RGBColor[
              0.20746958876179836`, 0.3353940704933011, 0.9351264582050084], 
             39 -> RGBColor[
              0.18317563345981333`, 0.30985958314518375`, 0.9337429533902465],
              109 -> RGBColor[
              0.18132254229683142`, 0.30791186684012395`, 0.9336374225899173],
              256 -> RGBColor[
              0.3513087838325387, 0.47870774408802763`, 0.9436060629490174], 
             339 -> RGBColor[
              0.2515477771449798, 0.3817230412025836, 0.9376366458255944], 
             287 -> RGBColor[
              0.1899324083338537, 0.31696138194207063`, 0.9341277417235704], 
             239 -> RGBColor[
              0.82776291630336, 0.2144035172609302, 0.17421910604681382`], 
             285 -> RGBColor[
              0.9941990383585994, 0.9900006545532618, 0.6099793085980734], 
             345 -> RGBColor[
              0.1789871968344326, 0.3054572706896884, 0.9335044281206677], 
             366 -> RGBColor[
              0.39439940253334044`, 0.5160306722091927, 0.9463517590690945], 
             216 -> 
             RGBColor[
              0.1997106484206986, 0.3272389322495743, 0.9346845980309063], 21 -> 
             RGBColor[
              0.9632021039744041, 0.8875341975281088, 0.3115475519504825], 
             355 -> RGBColor[
              0.7657071355725306, 0.8168955009898127, 0.9772821894000061], 
             175 -> RGBColor[
              0.28165135838121924`, 0.41336381375916165`, 0.9393510002427407],
              7 -> RGBColor[
              0.4486453266434888, 0.5630157651939816, 0.9498082613856059], 13 -> 
             RGBColor[
              0.21416269395992185`, 0.3424289484239088, 0.9355076206444797], 
             294 -> RGBColor[
              0.1899597624904289, 0.3169901328949849, 0.9341292995023205], 
             193 -> RGBColor[
              0.18694492825143932`, 0.3138213509582757, 0.9339576091524576], 
             60 -> RGBColor[
              0.186004909472108, 0.3128333316205655, 0.9339040764736078], 65 -> 
             RGBColor[
              0.2879462259501837, 0.4199801186917991, 0.9397094836383711], 69 -> 
             RGBColor[
              0.2418162773238607, 0.37149461787786187`, 0.9370824513072455], 
             217 -> RGBColor[
              0.9930695883095065, 0.987584875103169, 0.4870456409120508], 214 -> 
             RGBColor[
              0.23974505627195325`, 0.36931763322930755`, 0.9369644983324363],
              170 -> RGBColor[
              0.2316644133079956, 0.36082436513183264`, 0.936504317669879], 
             359 -> RGBColor[
              0.18720392975649292`, 0.3140935779617309, 0.9339723589050121], 
             74 -> RGBColor[
              0.8630600513163033, 0.8936446740513561, 0.986800632228994], 246 -> 
             RGBColor[
              0.9202453542726101, 0.9392426823750178, 0.9922550174748891], 
             264 -> RGBColor[
              0.7232916660208124, 0.7837602138065023, 0.9730546117901898], 
             278 -> RGBColor[
              0.25816588373595994`, 0.3886790908418973, 0.9380135372053394], 
             45 -> RGBColor[
              0.2848093981590889, 0.41668311379698936`, 0.9395308459361892], 
             306 -> RGBColor[
              0.20271236623405806`, 0.3303939279913168, 0.9348555414197336], 
             237 -> RGBColor[
              0.19733278810728, 0.3247396502951197, 0.9345491824037863], 228 -> 
             RGBColor[
              0.20359531165465325`, 0.33132195961033534`, 0.9349058238552358],
              180 -> RGBColor[
              0.2585433275657887, 0.3890758082383683, 0.93803503207307], 383 -> 
             RGBColor[
              0.20835388918653433`, 0.3363235263075839, 0.9351768178059918], 
             53 -> RGBColor[
              0.19239706134193654`, 0.319551888521592, 0.9342681000662533], 
             304 -> RGBColor[
              0.1808905282724361, 0.3074577927092133, 0.9336128200303355], 48 -> 
             RGBColor[
              0.24018804114120323`, 0.3697832384137522, 0.9369897256654027], 
             5 -> RGBColor[
              0.2824395297681887, 0.41419223185981874`, 0.9393958854372335], 
             101 -> RGBColor[
              0.1831002535865883, 0.30978035411906424`, 0.9337386606179808], 
             333 -> RGBColor[
              0.18811264277564865`, 0.31504869296059673`, 0.9340241087671325],
              267 -> RGBColor[
              0.2559867658273416, 0.386388699755884, 0.9378894396641596], 120 -> 
             RGBColor[
              0.5182991743784003, 0.6198176447289311, 0.9552215560809526], 
             147 -> RGBColor[
              0.1834762116557925, 0.31017550988691617`, 0.9337600708738418], 
             89 -> RGBColor[
              0.1892450123424645, 0.31623888517169746`, 0.934088595538772], 
             43 -> RGBColor[
              0.26035980612556775`, 0.3909850423760888, 0.9381384778398102], 
             199 -> RGBColor[
              0.18648980339442428`, 0.3133429858769703, 0.9339316904651475], 
             268 -> RGBColor[
              0.679362894162589, 0.7494427233598264, 0.9686762023490751], 169 -> 
             RGBColor[
              0.8957887014800139, 0.9197416112963568, 0.9899223200988196], 20 -> 
             RGBColor[
              0.19028821830363388`, 0.31733536077996466`, 0.9341480045749757],
              4 -> RGBColor[
              0.23281884209063286`, 0.36203774297739677`, 0.9365700606812258],
              167 -> RGBColor[
              0.3102543804501736, 0.4431484833325346, 0.9409901126684767], 
             142 -> RGBColor[
              0.18248883410320854`, 0.3091377134757978, 0.9337038411829164], 
             16 -> RGBColor[
              0.3177755060429437, 0.4496629042982282, 0.9414693521405777], 
             281 -> RGBColor[
              0.4286879330306734, 0.5457296739343299, 0.9485365939122276], 
             289 -> RGBColor[
              0.1861676814246589, 0.31300441526303435`, 0.9339133460955061], 
             398 -> RGBColor[
              0.4260942433398349, 0.54348315028676, 0.9483713262986371], 178 -> 
             RGBColor[
              0.44169024668361, 0.5569916245052177, 0.9493650898406981], 58 -> 
             RGBColor[
              0.21195870855243037`, 0.3401124200198894, 0.9353821069360272], 
             186 -> RGBColor[
              0.20685160848485196`, 0.33474453404001786`, 0.9350912651424561],
              122 -> RGBColor[
              0.5979628209588992, 0.6844921818293608, 0.9614929701573222], 
             249 -> RGBColor[
              0.3090764058516128, 0.442128180941986, 0.9409150531686984], 113 -> 
             RGBColor[
              0.30752560771325343`, 0.4405592903292892, 0.9408245004646784], 
             52 -> RGBColor[
              0.17936539842637753`, 0.30585478454218845`, 0.9335259661418299],
              187 -> RGBColor[
              0.43492032413853554`, 0.551127857862875, 0.9489337163625334], 
             259 -> RGBColor[
              0.18623692915551526`, 0.3130771990187241, 0.9339172896513356], 
             42 -> RGBColor[
              0.21651396498896067`, 0.34490028335462225`, 0.9356415220511897],
              134 -> RGBColor[
              0.830968185180272, 0.8680554911049849, 0.9837396813881922], 313 -> 
             RGBColor[
              0.218367213855187, 0.3468481654157909, 0.9357470618324852], 248 -> 
             RGBColor[
              0.21799885977606132`, 0.3464610019236322, 0.9357260846126101], 
             174 -> RGBColor[
              0.34399645769565007`, 0.4723741747164527, 0.943140127993611], 
             215 -> RGBColor[
              0.18299643202543156`, 0.30967123107562133`, 0.9337327481336631],
              399 -> RGBColor[
              0.9265760623547111, 0.7466055848528861, 0.2597795801705179], 83 -> 
             RGBColor[
              0.9450344910434499, 0.9585273939347413, 0.9779264487494559], 95 -> 
             RGBColor[
              0.559409915392181, 0.6531931963016955, 0.9584579442071637], 166 -> 
             RGBColor[
              0.9896948922783259, 0.9900065873749687, 0.82044583391943], 384 -> 
             RGBColor[
              0.18955786573703887`, 0.316567713925446, 0.9341064120767679], 
             233 -> RGBColor[
              0.9594063537213845, 0.9692459055881796, 0.9535986340178257], 
             295 -> RGBColor[
              0.4290348579738498, 0.5460301628831548, 0.9485586996628331], 
             141 -> RGBColor[
              0.8655975347340893, 0.482591620368333, 0.20956362728728348`], 
             319 -> RGBColor[
              0.4533617737780597, 0.567098537525015, 0.9501094460321575], 205 -> 
             RGBColor[
              0.3500177192487492, 0.4775894888363419, 0.943523797455382], 224 -> 
             RGBColor[
              0.1793343425625045, 0.3058221428602024, 0.9335241975563253], 
             231 -> RGBColor[
              0.18219295480676673`, 0.3088267255754066, 0.9336869912946982], 
             332 -> RGBColor[
              0.2283446787479909, 0.35733511362593967`, 0.9363152636977938], 
             68 -> RGBColor[
              0.27002626100566185`, 0.40114509934370585`, 0.9386889681449931],
              10 -> RGBColor[
              0.23750097993416716`, 0.3669589667156367, 0.9368367015048129], 
             250 -> RGBColor[
              0.25834749102875554`, 0.38886997162119286`, 0.9380238794720002],
              282 -> RGBColor[
              0.2671426063657563, 0.39811419548290095`, 0.9385247482792353], 
             374 -> RGBColor[
              0.19021908584372046`, 0.31726269818134456`, 0.934144067583656], 
             232 -> RGBColor[
              0.295092829761857, 0.42749165241872045`, 0.9401164721529931], 
             253 -> RGBColor[
              0.19109293756035423`, 0.31818117174092553`, 0.9341938321461705],
              55 -> RGBColor[
              0.9716313250190438, 0.9159679393868991, 0.3442934839840799], 
             325 -> RGBColor[
              0.289139123347183, 0.42123392949010874`, 0.9397774173803968], 
             91 -> RGBColor[
              0.4932978290383352, 0.5995204262840937, 0.953253358592837], 105 -> 
             RGBColor[
              0.20947576509879728`, 0.3375026890224135, 0.9352407069795285], 
             36 -> RGBColor[
              0.19287789451893317`, 0.32005727467719974`, 0.9342954828043544],
              123 -> RGBColor[
              0.21169783120855037`, 0.3398382213908926, 0.9353672503572267], 
             94 -> RGBColor[
              0.18118663655961964`, 0.30776902129339295`, 0.9336296829592377],
              312 -> RGBColor[
              0.3029090080003519, 0.4357069513217019, 0.9405615919406759], 96 -> 
             RGBColor[
              0.7481991240396009, 0.803218109314472, 0.9755371544320737], 2 -> 
             RGBColor[
              0.18498575182454155`, 0.3117621323146461, 0.9338460369532876], 
             262 -> RGBColor[
              0.2141514811516508, 0.34241716305148284`, 0.9355069820916365], 
             272 -> RGBColor[
              0.7409332819620127, 0.7975419782610151, 0.9748129631969344], 97 -> 
             RGBColor[
              0.19288958051724012`, 0.32006955740235543`, 0.93429614830467], 
             372 -> RGBColor[
              0.19406834726399882`, 0.3213085159913272, 0.9343632773270688], 
             356 -> 
             RGBColor[
              0.19499177110397153`, 0.3222790929955916, 0.9344158649486721], 
             346 -> RGBColor[
              0.3510664211934816, 0.47849782175157674`, 0.9435906198159696], 
             341 -> RGBColor[
              0.3362350503435996, 0.46565163376778274`, 0.9426455779802814], 
             209 -> RGBColor[
              0.33484250288537293`, 0.4644454791509371, 0.9425568460876246], 
             378 -> RGBColor[
              0.19081859398490578`, 0.3178928192487419, 0.9341782086854036], 
             66 -> RGBColor[
              0.2142707962291993, 0.34254257076299915`, 0.935513776908792], 
             139 -> RGBColor[
              0.18805967833656198`, 0.31499302397697726`, 0.9340210925206803],
              56 -> RGBColor[
              0.38165040818030865`, 0.5049881340836845, 0.9455394044224124], 
             335 -> RGBColor[
              0.1795029989097729, 0.3059994113746115, 0.9335338022857975], 
             314 -> RGBColor[
              0.23267428983588884`, 0.3618858093925185, 0.936561828644164], 
             144 -> RGBColor[
              0.1905501321581982, 0.3176106488474093, 0.9341629201815262], 
             298 -> RGBColor[
              0.19699767297971368`, 0.3243874230485212, 0.9345300980930298], 
             204 -> RGBColor[
              0.19363457114614188`, 0.3208525897884652, 0.9343385744188711], 
             207 -> RGBColor[
              0.18775722726537172`, 0.31467512872465075`, 0.9340038683796124],
              334 -> RGBColor[
              0.1849809522741401, 0.31175708768286514`, 0.9338457636259925], 
             149 -> RGBColor[
              0.21660346779159745`, 0.34499435647499893`, 0.9356466191033923],
              219 -> RGBColor[
              0.3371253879726633, 0.4664227994724073, 0.9427023095067106], 
             400 -> RGBColor[
              0.8501784807301029, 0.38669936800784144`, 0.19568427585662201`],
              9 -> RGBColor[
              0.19103464530579026`, 0.3181199028854364, 0.9341905124885087], 
             11 -> RGBColor[
              0.31196467996522614`, 0.44462985881031997`, 0.9410990914412173],
              44 -> RGBColor[
              0.2366745638317519, 0.36609035099419096`, 0.9367896383303533], 
             153 -> RGBColor[
              0.1824446187841665, 0.30909124037207153`, 0.9337013231859077], 
             32 -> RGBColor[
              0.9570322462930174, 0.8667218188173162, 0.28757881993815293`], 
             162 -> RGBColor[
              0.27232886945688745`, 0.40356528681975196`, 0.9388200982898864],
              90 -> 
             RGBColor[
              0.6083786689975903, 0.6929482364957771, 0.9623129438694364], 
             331 -> RGBColor[
              0.19914754728651962`, 0.3266470772548782, 0.9346525302543484], 
             8 -> RGBColor[
              0.2378122641398246, 0.36728614615234123`, 0.9368544286798214], 
             364 -> RGBColor[
              0.8176771202476999, 0.13687966915311423`, 0.16456093635363633`],
              342 -> RGBColor[
              0.18371444184961855`, 0.31042590492529404`, 0.9337736377309502],
              163 -> RGBColor[
              0.26679472020223177`, 0.3977485450677799, 0.938504936676874], 
             49 -> RGBColor[
              0.18767785554878408`, 0.3145917040180597, 0.9339993482777726], 
             338 -> RGBColor[
              0.23420030298526878`, 0.3634897459673388, 0.9366487328354871], 
             76 -> RGBColor[
              0.1938965482594379, 0.32112794434484765`, 0.9343534936279129], 
             369 -> RGBColor[
              0.19059767181486464`, 0.3176606160407541, 0.9341656274946448], 
             82 -> RGBColor[
              0.1807265568208277, 0.30728544831718235`, 0.9336034820987404], 
             67 -> RGBColor[
              0.42522253205912725`, 0.5427281177888938, 0.9483157816266544], 
             211 -> RGBColor[
              0.22188954865981286`, 0.3505503626243781, 
               0.9359476535887813]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9l2k4lWvYhs1zWMs8LNZoLbMSqfBetRslSppMScqwSaE2pQyZolBokCJT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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 14}], {
             RGBColor[
             0.18904790384743964`, 0.31603171164602595`, 0.9340773705015762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.18749255911212426`, 0.3143969457146576, 0.9339887959198263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 49}], {
             RGBColor[
             0.19061232216343427`, 0.3176760144859865, 0.9341664618103227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 62}], {
             RGBColor[
             0.19732629313580521`, 0.3247328236682947, 0.9345488125247692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 87}], {
             RGBColor[
             0.19586287681444192`, 0.32319468032858806`, 0.934465473130198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 119}], {
             RGBColor[
             0.18798137752672578`, 0.3149107248612813, 0.9340166334053959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 127}], {
             RGBColor[
             0.19417547404882396`, 0.3214211130344089, 0.9343693780389848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 129}], {
             RGBColor[
             0.19131755276026974`, 0.31841725655746295`, 0.9342066236495172]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 216}], {
             RGBColor[
             0.19662871859939152`, 0.3239996286017438, 0.9345090866868895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 231}], {
             RGBColor[
             0.1878698717924256, 0.3147935252646599, 0.9340102833187854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 235}], {
             RGBColor[
             0.19253038583618232`, 0.3196920210183055, 0.9342756926989647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 298}], {
             RGBColor[
             0.19527223087889906`, 0.32257387400121723`, 0.9344318367179512]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 313}], {
             RGBColor[
             0.20595700131663575`, 0.3338042451848521, 0.935040318587679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 317}], {
             RGBColor[
             0.19445041549410247`, 0.3217100939256911, 0.9343850355475539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 336}], {
             RGBColor[
             0.18695004027347276`, 0.31382672401755374`, 0.9339579002745498]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 361}], {
             RGBColor[
             0.205591391562574, 0.33341996615233593`, 0.9350194976530564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 393}], {
             RGBColor[
             0.1884550205876297, 0.3154085537489959, 0.9340436066770222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 396}], {
             RGBColor[
             0.1965523248147455, 0.3239193338904351, 0.9345047361738683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 97}], {
             RGBColor[
             0.18893766617089083`, 0.31591584485850077`, 0.9340710926289788]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 109}], {
             RGBColor[
             0.1831541470606865, 0.30983699957738503`, 0.9337417297716024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 181}], {
             RGBColor[
             0.1899547149925528, 0.3169848276546873, 0.9341290120547836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 191}], {
             RGBColor[
             0.19610476461646903`, 0.323448919745091, 0.9344792482826825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 193}], {
             RGBColor[
             0.18596534003799042`, 0.3127917416364609, 0.9339018230528726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 211}], {
             RGBColor[
             0.2034376502421772, 0.3311562474695121, 0.9348968452710344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 305}], {
             RGBColor[
             0.18360947068078184`, 0.31031557357129014`, 0.9337676597781759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 334}], {
             RGBColor[
             0.18498335204934083`, 0.3117596099987556, 0.93384590028964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 340}], {
             RGBColor[
             0.19396024281710603`, 0.32119489136342505`, 0.9343571209387445]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 360}], {
             RGBColor[
             0.18511749831467772`, 0.3119006062289892, 0.9338535397209994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 365}], {
             RGBColor[
             0.18295812271216946`, 0.3096309655584321, 0.9337305664749465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 370}], {
             RGBColor[
             0.18603673488354355`, 0.3128667821458319, 0.9339058888837076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 11}], {
             RGBColor[
             0.4469167817161049, 0.5580281285800609, 0.9506625439425702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 21}], {
             RGBColor[
             0.7725354937206939, 0.7794802979389553, 0.6358867741972027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 34}], {
             RGBColor[
             0.4225585018257533, 0.5327236209657705, 0.9492644797482566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 74}], {
             RGBColor[
             0.7224644673916434, 0.782535536200579, 0.9735133143364585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 86}], {
             RGBColor[
             0.49644576954540676`, 0.6009276484384913, 0.9538184872502891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 91}], {
             RGBColor[
             0.5375833562526594, 0.6354734123169479, 0.9567396775183801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 95}], {
             RGBColor[
             0.5706393994295823, 0.6623097973257487, 0.9593419703255434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 160}], {
             RGBColor[
             0.5207461823507223, 0.6218042360373149, 0.9554141935122193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[
             0.42709887646193556`, 0.5374958425847769, 0.9495230473669047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 233}], {
             RGBColor[
             0.7706376185941841, 0.8203361519689907, 0.9569123152308744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 263}], {
             RGBColor[
             0.48691076315351817`, 0.5926689051451934, 0.9532109250744729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 264}], {
             RGBColor[
             0.652580274743898, 0.7275933060781521, 0.9666403041170564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 285}], {
             RGBColor[
             0.7880339609127915, 0.8307135264515318, 0.7851026525209982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 312}], {
             RGBColor[
             0.44238894573366777`, 0.553566674835752, 0.9503937941922995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 348}], {
             RGBColor[
             0.45750426505624076`, 0.5671984745069012, 0.9513371690188597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 13}], {
             RGBColor[
             0.22349076802527734`, 0.3522333457006528, 0.9360388406628528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 66}], {
             RGBColor[
             0.22354481915991609`, 0.35229015687019793`, 0.9360419187950089]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 123}], {
             RGBColor[
             0.2222583366495916, 0.3509379821841447, 0.9359686555192263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 131}], {
             RGBColor[
             0.22303764420255517`, 0.35175708383326204`, 0.9360130359314853]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 140}], {
             RGBColor[
             0.22925899781803233`, 0.3582961209397305, 0.9363673328162189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 183}], {
             RGBColor[
             0.2914028738694214, 0.4198002713108441, 0.9400459473606144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 186}], {
             RGBColor[
             0.2198352252877424, 0.3483911385087073, 0.9358306629118409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 188}], {
             RGBColor[
             0.2173017232473819, 0.34572826723098127`, 0.9356863837186229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 203}], {
             RGBColor[
             0.22928794206914588`, 0.35832654318282237`, 0.9363689811485005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 232}], {
             RGBColor[
             0.26395583592624494`, 0.3947646976980586, 0.9383432664171094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 238}], {
             RGBColor[
             0.26140051176335477`, 0.3920788899859515, 0.9381977444862962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 275}], {
             RGBColor[
             0.235784586016354, 0.3651549278823552, 0.9367389554103707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 280}], {
             RGBColor[
             0.24217745234544014`, 0.3718742357253608, 0.937103019690414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 297}], {
             RGBColor[
             0.2198696831096341, 0.34842735586426754`, 0.9358326252338219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 309}], {
             RGBColor[
             0.2652076930566547, 0.39608047891444564`, 0.9384145578287296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 322}], {
             RGBColor[
             0.21636197354501668`, 0.3447405307102229, 0.9356328663633082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 325}], {
             RGBColor[
             0.26097898271890796`, 0.39163583623375275`, 0.9381737390308114]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 339}], {
             RGBColor[
             0.24218330961780632`, 0.3718803920899902, 0.9371033532534101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 8}], {
             RGBColor[
             0.2601258969540067, 0.39073918900607996`, 0.9381251570585274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 43}], {
             RGBColor[
             0.2713996679468782, 0.4025886371179538, 0.9387671816385219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 56}], {
             RGBColor[
             0.3320449689742487, 0.4595901829717516, 0.9424676449298229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.31447583347960173`, 0.4443726808567142, 0.9413481551518805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 90}], {
             RGBColor[
             0.44540909938288953`, 0.5535702341777979, 0.950854414653335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 100}], {
             RGBColor[
             0.24629351933764826`, 0.37620048310789195`, 0.9373374236164447]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 121}], {
             RGBColor[
             0.2966728547509243, 0.4289526354856623, 0.9402137650898452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 122}], {
             RGBColor[
             0.440201175363544, 0.5493422068445898, 0.9504444277972779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 175}], {
             RGBColor[
             0.282045444074704, 0.41377802280949016`, 0.9393734428399871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 178}], {
             RGBColor[
             0.36206488822589933`, 0.4855919281825182, 0.9443804876389659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 213}], {
             RGBColor[
             0.25252900688278906`, 0.3827543758705798, 0.9376925254075633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 227}], {
             RGBColor[
             0.24495455926499354`, 0.3747931511765599, 0.937261171821121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 274}], {
             RGBColor[
             0.38775900825169696`, 0.5067672930904867, 0.9463159883002454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 296}], {
             RGBColor[
             0.26370004466317304`, 0.39449584486246725`, 0.9383286994830867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 308}], {
             RGBColor[
             0.24197001296398313`, 0.37165620378303305`, 0.9370912063245189]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 319}], {
             RGBColor[
             0.3679006517731242, 0.4906453846924169, 0.9447526657346955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 352}], {
             RGBColor[
             0.26102097459574697`, 0.3916799723587493, 0.9381761304060758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 373}], {
             RGBColor[
             0.27714534160664284`, 0.4086277044311172, 0.939094389253483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 56}], {
             RGBColor[
             0.34361946259808085`, 0.47175570963568103`, 0.9431267952187714]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 79}], {
             RGBColor[
             0.26831622286540857`, 0.39934774083561936`, 0.9385915840026804]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 137}], {
             RGBColor[
             0.32002599977803325`, 0.451320237982877, 0.941623440630758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 169}], {
             RGBColor[
             0.6006886092479335, 0.6791324482420171, 0.965318253056975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 175}], {
             RGBColor[
             0.2936199376985361, 0.4259435494734196, 0.9400325931289355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 178}], {
             RGBColor[
             0.37363938184973156`, 0.4977574548464476, 0.9450396379279142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 252}], {
             RGBColor[
             0.3375773650971563, 0.4665223484650306, 0.9427417981088295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 277}], {
             RGBColor[
             0.2567019144406389, 0.38714036629150045`, 0.9379301663197194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 278}], {
             RGBColor[
             0.28187720037590647`, 0.4136011880147874, 0.9393638616102349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 300}], {
             RGBColor[
             0.6101439916355338, 0.6866719134983721, 0.9662201158700239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 314}], {
             RGBColor[
             0.26913140342587094`, 0.400204547290098, 0.9386380073296472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 319}], {
             RGBColor[
             0.37947514539695637`, 0.5028109113563464, 0.945411816023644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 352}], {
             RGBColor[
             0.27259546821957914`, 0.40384549902267874`, 0.9388352806950242]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 379}], {
             RGBColor[
             0.25634517615934155`, 0.38676541173934353`, 0.9379098506023464]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 65}], {
             RGBColor[
             0.36829577629683624`, 0.4914979419428903, 0.9447588725119885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 67}], {
             RGBColor[
             0.43693392935130804`, 0.5528719414914377, 0.9490620215061302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 68}], {
             RGBColor[
             0.3593357938245753, 0.4820804322688437, 0.9442486147652995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 96}], {
             RGBColor[
             0.5984222253415448, 0.6831169372542267, 0.9626727079088397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 173}], {
             RGBColor[
             0.36556257674898185`, 0.48862517592323496`, 0.9446032208411446]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[
             0.7215884971461117, 0.7768639400824314, 0.7979961077324451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 201}], {
             RGBColor[
             0.698844545732584, 0.7622666344739716, 0.960474027707296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 223}], {
             RGBColor[
             0.6892737381041355, 0.6614040887409706, 0.6061320446993241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 250}], {
             RGBColor[
             0.35349640883612216`, 0.4759428684075872, 0.943916070428803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 387}], {
             RGBColor[
             0.4913856837463006, 0.597841186558023, 0.9531378831854276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 43}], {
             RGBColor[
             0.24908603513269617`, 0.379135594264215, 0.9374964532598158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 56}], {
             RGBColor[
             0.30973133616006665`, 0.43613714011801286`, 0.9411969165511169]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 59}], {
             RGBColor[
             0.2921622006654197, 0.4209196380029755, 0.9400774267731745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 100}], {
             RGBColor[
             0.22397988652346618`, 0.35274744025415317`, 0.9360666952377386]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 121}], {
             RGBColor[
             0.2743592219367422, 0.4054995926319236, 0.9389430367111391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 175}], {
             RGBColor[
             0.2597318112605219, 0.39032497995575144`, 0.938102714461281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 213}], {
             RGBColor[
             0.230215374068607, 0.3593013330168411, 0.9364217970288573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 227}], {
             RGBColor[
             0.22264092645081146`, 0.35134010832282114`, 0.9359904434424149]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 237}], {
             RGBColor[
             0.2175725261235523, 0.3460128982237305, 0.9357018055418038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 296}], {
             RGBColor[
             0.241386411848991, 0.3710428020087285, 0.9370579711043807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 308}], {
             RGBColor[
             0.21965638014980107`, 0.34820316092929426`, 0.9358204779458129]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 352}], {
             RGBColor[
             0.23870734178156489`, 0.36822692950501057`, 0.9369054020273697]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 373}], {
             RGBColor[
             0.2548317087924608, 0.38517466157737845`, 0.937823660874777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 39}], {
             RGBColor[
             0.1871051393828018, 0.3139897430153101, 0.9339667329393776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.2089266760744028, 0.33692556164351994`, 0.9352094371718936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 150}], {
             RGBColor[
             0.19229026561489077`, 0.3194396394412268, 0.9342620182075883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 192}], {
             RGBColor[
             0.1863278971063823, 0.3131728121027866, 0.9339224701415624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 283}], {
             RGBColor[
             0.2000074908485974, 0.3275509324621929, 0.9347015027680361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 294}], {
             RGBColor[
             0.1904972038981096, 0.3175550178902107, 0.9341599059954147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 320}], {
             RGBColor[
             0.1934136507337484, 0.32062038842787655`, 0.9343259933282078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 347}], {
             RGBColor[
             0.19444294915612814`, 0.3217022463310869, 0.9343846103506517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 381}], {
             RGBColor[
             0.19359903145009902`, 0.3208152353145773, 0.9343365504857577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 384}], {
             RGBColor[
             0.19029625552141455`, 0.3173438084054412, 0.9341484622826384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.26166329356975937`, 0.3923550903258115, 0.9382127095214201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 37}], {
             RGBColor[
             0.29314980125126083`, 0.4217462676405007, 0.9401414095988625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 62}], {
             RGBColor[
             0.21930338871384658`, 0.34783214454915645`, 0.9358003756057394]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 87}], {
             RGBColor[
             0.2178399723924833, 0.34629400120944975`, 0.9357170362111682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 155}], {
             RGBColor[
             0.22229114501906733`, 0.3509724658606344, 0.9359705239073323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 170}], {
             RGBColor[
             0.2345826966210814, 0.3638916659237347, 0.936670509587346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 216}], {
             RGBColor[
             0.21860581417743288`, 0.3470989494826055, 0.9357606497678597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 256}], {
             RGBColor[
             0.29440488188335295`, 0.4228333554018322, 0.9402213822269152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 261}], {
             RGBColor[
             0.24873551087533646`, 0.3787671710452084, 0.9374764914219134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 298}], {
             RGBColor[
             0.21724932645694042`, 0.3456731948820789, 0.9356833997989213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 311}], {
             RGBColor[
             0.2701224968687157, 0.40124624933748154`, 0.9386944486350258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 313}], {
             RGBColor[
             0.22793409689467709`, 0.35690356606571383`, 0.9362918816686491]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 361}], {
             RGBColor[
             0.22756848714061534`, 0.35651928703319763`, 0.9362710607340264]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 396}], {
             RGBColor[
             0.21852942039278686`, 0.3470186547712968, 0.9357562992548385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 34}], {
             RGBColor[
             0.28760640007487454`, 0.41932535119602954`, 0.9397010272469036]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 35}], {
             RGBColor[
             0.27410810708868466`, 0.4051377894263376, 0.9389323194302751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 85}], {
             RGBColor[
             0.2763549775912347, 0.40749939278433556`, 0.9390602753814483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 86}], {
             RGBColor[
             0.361493667794528, 0.48752937866875046`, 0.9442550347489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 91}], {
             RGBColor[
             0.40263125450178067`, 0.5220751425472069, 0.9471762250170271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 93}], {
             RGBColor[
             0.2731424573639435, 0.4041228303399058, 0.9388773271070019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 95}], {
             RGBColor[
             0.43568729767870357`, 0.5489115275560077, 0.9497785178241904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 125}], {
             RGBColor[
             0.2867382877276377, 0.41841291007758175`, 0.9396515895329856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 162}], {
             RGBColor[
             0.29214677471105677`, 0.42409757281503596`, 0.9399595948655519]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 211}], {
             RGBColor[
             0.2669271143125195, 0.39759011071734907`, 0.9385233725149993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 214}], {
             RGBColor[
             0.2758548681185897, 0.40697374601981373`, 0.9390317948868268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 248}], {
             RGBColor[
             0.2649817698706437, 0.3955454303669761, 0.9384125880269136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 263}], {
             RGBColor[
             0.35195866140263943`, 0.47927063537545245`, 0.9436474725731201]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 312}], {
             RGBColor[
             0.30743684398278903`, 0.44016840506601096`, 0.9408303416909466]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.313125811057198, 0.4456106195888476, 0.9411739913250522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 17}], {
             RGBColor[
             0.2700762317403779, 0.40119762175422, 0.93869181390441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 22}], {
             RGBColor[
             0.3123757406994519, 0.44496094634460026`, 0.9411261975051177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 47}], {
             RGBColor[
             0.4262898849714413, 0.5411626092696967, 0.9490658048705467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 106}], {
             RGBColor[
             0.2676474114572338, 0.3986447776405352, 0.9385534961824027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 107}], {
             RGBColor[
             0.3285473986430889, 0.45896802364421685`, 0.9421566412492507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 118}], {
             RGBColor[
             0.27367870261090094`, 0.4049840470489852, 0.9388969692911083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 158}], {
             RGBColor[
             0.32361612706914167`, 0.45469680405977975`, 0.941842424985111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 209}], {
             RGBColor[
             0.3216593094784126, 0.45300190701520204`, 0.9417177382985756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 241}], {
             RGBColor[
             0.28584467655013013`, 0.4177712570264148, 0.9395898035090018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 270}], {
             RGBColor[
             0.3337876806083378, 0.46350689249828564`, 0.9424905473822769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 310}], {
             RGBColor[
             0.2940376027932159, 0.42638254196942454`, 0.9400563785381975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 323}], {
             RGBColor[
             0.35358359064672407`, 0.4806531148021672, 0.943751925265087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 324}], {
             RGBColor[
             0.4708028735942141, 0.577300258720949, 0.9525700303913813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 346}], {
             RGBColor[
             0.329771268632467, 0.46002807831552184`, 0.9422346251627481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 390}], {
             RGBColor[
             0.28559351861557547`, 0.41750727411286515`, 0.9395755004361839]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 66}], {
             RGBColor[
             0.21421674509456057`, 0.34248575959345395`, 0.9355106987766358]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 123}], {
             RGBColor[
             0.2129302625842361, 0.3411335849074007, 0.9354374355008532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 131}], {
             RGBColor[
             0.21370957013719966`, 0.34195268655651806`, 0.9354818159131122]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[
             0.2199309237526768, 0.34849172366298653`, 0.9358361127978458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 188}], {
             RGBColor[
             0.20797364918202638`, 0.3359238699542373, 0.9351551637002498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 203}], {
             RGBColor[
             0.21995986800379036`, 0.3485221459060784, 0.9358377611301275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 232}], {
             RGBColor[
             0.2546277618608894, 0.3849603004213146, 0.9378120463987364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 275}], {
             RGBColor[
             0.22645651195099847`, 0.3553505306056112, 0.9362077353919975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 280}], {
             RGBColor[
             0.23284937828008462`, 0.36206983844861684`, 0.9365717996720409]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 297}], {
             RGBColor[
             0.2105416090442786, 0.33862295858752356`, 0.9353014052154489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 309}], {
             RGBColor[
             0.25587961899129924`, 0.38627608163770166`, 0.9378833378103566]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 322}], {
             RGBColor[
             0.20703389947966117`, 0.33493613343347894`, 0.9351016463449351]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 325}], {
             RGBColor[
             0.25165090865355244`, 0.3818314389570088, 0.9376425190124382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 339}], {
             RGBColor[
             0.2328552355524508, 0.3620759948132462, 0.936572133235037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 29}], {
             RGBColor[
             0.18299367418147944`, 0.3096683324067703, 0.9337325910785299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 62}], {
             RGBColor[
             0.1928274082051604, 0.3200042103604074, 0.9342926076834728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 119}], {
             RGBColor[
             0.18348249259608096`, 0.310182111553394, 0.9337604285640995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 126}], {
             RGBColor[
             0.18556762080960376`, 0.31237371351057097`, 0.9338791735311889]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 127}], {
             RGBColor[
             0.18967658911817914`, 0.3166924997265216, 0.9341131731976884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 129}], {
             RGBColor[
             0.18681866782962492`, 0.3136886432495756, 0.9339504188082208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 196}], {
             RGBColor[
             0.18714224683050756`, 0.3140287452955969, 0.9339688461536289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 235}], {
             RGBColor[
             0.1880315009055375, 0.3149634077104182, 0.9340194878576683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 317}], {
             RGBColor[
             0.18995153056345765`, 0.3169814806178038, 0.9341288307062575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 326}], {
             RGBColor[
             0.18828033718868842`, 0.3152249504211414, 0.9340336587158735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 327}], {
             RGBColor[
             0.19007805312865012`, 0.317114463855815, 0.9341360359791719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 336}], {
             RGBColor[
             0.18245115534282794`, 0.3090981107096664, 0.9337016954332534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 396}], {
             RGBColor[
             0.19205343988410067`, 0.31919072058254777`, 0.9342485313325719]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 33}], {
             RGBColor[
             0.28118366953987284`, 0.41287224313372134`, 0.9393243660551096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 37}], {
             RGBColor[
             0.31731211488685307`, 0.44714239125067556`, 0.9415174176154697]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.24346570234943876`, 0.37322826815933124`, 0.9371763836223466]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 92}], {
             RGBColor[
             0.3916080301069964, 0.5102971083648917, 0.9465821312407912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 256}], {
             RGBColor[
             0.31856719551894513`, 0.448229479012007, 0.9415973902435224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 311}], {
             RGBColor[
             0.2942848105043079, 0.4266423729476564, 0.940070456651633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 313}], {
             RGBColor[
             0.25209641053026927`, 0.3822996896758886, 0.9376678896852563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 361}], {
             RGBColor[
             0.2517308007762076, 0.3819154106433724, 0.9376470687506336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 386}], {
             RGBColor[
             0.5232931103169385, 0.6153912271159707, 0.9581889419192983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 69}], {
             RGBColor[
             0.2797958916834022, 0.41057876108804503`, 0.9392759017239116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 106}], {
             RGBColor[
             0.2722971064429795, 0.4026970623499158, 0.9388488569979281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 107}], {
             RGBColor[
             0.33319709362883454`, 0.4630203083535974, 0.9424520020647762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 190}], {
             RGBColor[
             0.6369974104682594, 0.7082659607734624, 0.9502314057905163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 212}], {
             RGBColor[
             0.36755596390986156`, 0.4927802348639901, 0.9446413188967272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 241}], {
             RGBColor[
             0.29049437153587576`, 0.42182354173579545`, 0.9398851643245274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 268}], {
             RGBColor[
             0.49856920010276634`, 0.5995528138290274, 0.9550727772448264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 270}], {
             RGBColor[
             0.3384373755940835, 0.46755917720766627`, 0.9427859081978025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 274}], {
             RGBColor[
             0.4054269963890745, 0.5245026293096915, 0.9473527216519175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 295}], {
             RGBColor[
             0.3734051820083968, 0.4978465335906915, 0.9450140259017055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 310}], {
             RGBColor[
             0.2986872977789616, 0.43043482667880517`, 0.9403517393537228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 324}], {
             RGBColor[
             0.47545256857995977`, 0.5813525434303296, 0.9528653912069069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 351}], {
             RGBColor[
             0.6137824648944775, 0.6902841557450048, 0.9663635368138602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 373}], {
             RGBColor[
             0.29481332974402036`, 0.42636304065032193`, 0.9401311226051551]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 380}], {
             RGBColor[
             0.26894987250182517`, 0.3991789072508731, 0.9386582369767682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 390}], {
             RGBColor[
             0.2902432136013212, 0.4215595588222458, 0.9398708612517093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 22}], {
             RGBColor[
             0.2739758563683775, 0.40460023321935323`, 0.9389393809000012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 48}], {
             RGBColor[
             0.23593219427525336`, 0.3653100735213626, 0.936747361482348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 61}], {
             RGBColor[
             0.22052046256389546`, 0.34911136633249684`, 0.9358696861610002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 118}], {
             RGBColor[
             0.23527881827982655`, 0.36462333392373825`, 0.9367101526859918]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 158}], {
             RGBColor[
             0.2852162427380673, 0.4143360909345327, 0.9396556083799944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 164}], {
             RGBColor[
             0.21631448031938844`, 0.34469061231884324`, 0.9356301616943686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 173}], {
             RGBColor[
             0.25707808713188923`, 0.38753574764073073`, 0.9379515887979883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 209}], {
             RGBColor[
             0.2832594251473382, 0.412641193889955, 0.9395309216934591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 241}], {
             RGBColor[
             0.2474447922190557, 0.37741054390116785`, 0.9374029869038852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 287}], {
             RGBColor[
             0.2108043778715786, 0.3388991452855218, 0.9353163695114319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 323}], {
             RGBColor[
             0.3151837063156497, 0.44029240167692024`, 0.9415651086599703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 346}], {
             RGBColor[
             0.29137138430139253`, 0.41966736519027487`, 0.9400478085576316]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 354}], {
             RGBColor[
             0.2237645258481464, 0.35252108252973663`, 0.9360544307658767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 371}], {
             RGBColor[
             0.20911196002482746`, 0.33712030682309724`, 0.9352199888187673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 388}], {
             RGBColor[
             0.22559527698605156`, 0.35444531805200136`, 0.9361586893348268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 389}], {
             RGBColor[
             0.21716250001380405`, 0.34558193478522814`, 0.9356784551614329]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 45}], {
             RGBColor[
             0.4449748432614876, 0.5535011435034702, 0.9507944263097807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 74}], {
             RGBColor[
             0.7341001698400949, 0.7919819236306536, 0.974429319456183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 86}], {
             RGBColor[
             0.5080814719938581, 0.6103740358685661, 0.9547344923700136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 91}], {
             RGBColor[
             0.5492190587011108, 0.6449197997470224, 0.9576556826381046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 112}], {
             RGBColor[
             0.7711240798821252, 0.7393399357057666, 0.6151558638126768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 141}], {
             RGBColor[
             0.7353689115489879, 0.586455396789142, 0.5858108169853278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 148}], {
             RGBColor[
             0.46955925293009415`, 0.5770080258985608, 0.9522798906351313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 179}], {
             RGBColor[
             0.5295441815391476, 0.6289468481238254, 0.9561068042364651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 232}], {
             RGBColor[
             0.4501165590628717, 0.5589054128143358, 0.9510872394181826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 257}], {
             RGBColor[
             0.46412234198098856`, 0.5722988469015355, 0.9519334554771259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 279}], {
             RGBColor[
             0.638687245246097, 0.7170964540862654, 0.9650118438159424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 285}], {
             RGBColor[
             0.7996696633612428, 0.8401599138816065, 0.7860186576407228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 288}], {
             RGBColor[
             0.45525573629442806`, 0.5643070139273578, 0.9513799079587884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 399}], {
             RGBColor[
             0.7658581753592988, 0.7184623790314186, 0.610918793426945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 185}], {
             RGBColor[
             0.330002266441723, 0.4557835793222022, 0.9424120819002554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 198}], {
             RGBColor[
             0.30685620721234774`, 0.43573562617248035`, 0.9409372354734161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 205}], {
             RGBColor[
             0.30521095643223367`, 0.4343105926394541, 0.9408324015485454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 219}], {
             RGBColor[
             0.2987647907941907, 0.4287272479574868, 0.9404216575742097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 262}], {
             RGBColor[
             0.23727783738368446`, 0.36672442974702457`, 0.9368239938666727]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 284}], {
             RGBColor[
             0.2685014480461575, 0.3995424242445413, 0.938602132302708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 293}], {
             RGBColor[
             0.3046492475878372, 0.4338240686707453, 0.9407966099576801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 331}], {
             RGBColor[
             0.22977587045111889`, 0.35883938684872224`, 0.9363967679480286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 338}], {
             RGBColor[
             0.24730224830049347`, 0.3772607212049526, 0.937394869238598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.1986384662361157, 0.32611200079330077`, 0.9346235388416457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 36}], {
             RGBColor[
             0.19158305641128354`, 0.3186963177285822, 0.934221743689665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 80}], {
             RGBColor[
             0.18504810846190303`, 0.31182767309415216`, 0.933849588071537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 151}], {
             RGBColor[
             0.19115376674236922`, 0.3182451070680162, 0.9341972962780976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 168}], {
             RGBColor[
             0.18724662483160132`, 0.31413845319269396`, 0.9339747903263778]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 265}], {
             RGBColor[
             0.19013547399899927`, 0.31717481683124543`, 0.9341393060127917]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 291}], {
             RGBColor[
             0.18873168488737596`, 0.31569934546955897`, 0.9340593622996046]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 304}], {
             RGBColor[
             0.185589373288035, 0.312396576744589, 0.9338804123026556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 378}], {
             RGBColor[
             0.19055340614426983`, 0.31761409001435326`, 0.9341631066301896]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 383}], {
             RGBColor[
             0.1993210537450841, 0.3268294435437743, 0.9346624111904838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 24}], {
             RGBColor[
             0.8919944774662327, 0.5241583098068742, 0.2395431849721498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 25}], {
             RGBColor[
             0.890260551987202, 0.5108305987640545, 0.23788277597524127`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 27}], {
             RGBColor[
             0.8921201702935075, 0.5251244399562564, 0.23966354856549787`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 32}], {
             RGBColor[
             0.9601171751337108, 0.8771280081727125, 0.29956318594431774`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 78}], {
             RGBColor[
             0.8915698412637564, 0.5208943698778701, 0.23913655286510038`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 95}], {
             RGBColor[
             0.7613060096832925, 0.7703636969149021, 0.6350027480788232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 104}], {
             RGBColor[
             0.8911056135339068, 0.5173261121203578, 0.23869200786672617`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 160}], {
             RGBColor[
             0.7114127926044326, 0.7298581356264684, 0.631074971265499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 172}], {
             RGBColor[
             0.8935026650840421, 0.5357509007293852, 0.24098742713821833`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 208}], {
             RGBColor[
             0.9781086897296334, 0.9394569243444684, 0.5384830216306559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 217}], {
             RGBColor[
             0.9781358461419554, 0.9375595363156388, 0.3992965964312667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 230}], {
             RGBColor[
             0.8904702103094787, 0.5124421245019355, 0.2380835450214286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 233}], {
             RGBColor[
             0.9613042288478943, 0.9283900515581442, 0.6325730929841542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 240}], {
             RGBColor[
             0.8974455137213154, 0.5660573631227573, 0.24476310344608182`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 242}], {
             RGBColor[
             0.907737765098039, 0.6451681172975665, 0.25461897498786773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 244}], {
             RGBColor[
             0.9589837634229517, 0.9266594522436353, 0.6365010356742713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 264}], {
             RGBColor[
             0.8432468849976082, 0.8356472056673055, 0.6423010818703361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 285}], {
             RGBColor[
             0.9787005711665018, 0.9387674260406853, 0.4607634302742779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 357}], {
             RGBColor[
             0.910151296596057, 0.6637195780075789, 0.25693017547606367`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 47}], {
             RGBColor[
             0.4301895095994409, 0.5445652207348299, 0.9493133718661378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.27823170323432733`, 0.40907339811174287`, 0.9391817450830557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 96}], {
             RGBColor[
             0.5322372446835262, 0.6257908335621027, 0.9584554594663912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 118}], {
             RGBColor[
             0.2775783272389005, 0.4083866585141185, 0.9391445362866995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 158}], {
             RGBColor[
             0.3275157516971413, 0.458099415524913, 0.9420899919807021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 173}], {
             RGBColor[
             0.2993775960909632, 0.43129907223111097`, 0.940385972398696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 209}], {
             RGBColor[
             0.32555893410641223`, 0.4564045184803353, 0.9419653052941668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 241}], {
             RGBColor[
             0.28974430117812966`, 0.42117386849154814`, 0.9398373705045929]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 310}], {
             RGBColor[
             0.2979372274212155, 0.4297851534345578, 0.9403039455337885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 323}], {
             RGBColor[
             0.35748321527472365`, 0.48405572626730053`, 0.943999492260678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 346}], {
             RGBColor[
             0.3336708932604665, 0.46343068978065516`, 0.9424821921583393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 354}], {
             RGBColor[
             0.2660640348072204, 0.3962844071201169, 0.9384888143665844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 388}], {
             RGBColor[
             0.26789478594512556`, 0.39820864264238165`, 0.9385930729355345]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 75}], {
             RGBColor[
             0.255511442446525, 0.3858891047454028, 0.9378623707008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 120}], {
             RGBColor[
             0.40567769043424073`, 0.5225843384798207, 0.9476110227757661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 132}], {
             RGBColor[
             0.32566481114992, 0.45504559524241234`, 0.9420251663053016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 160}], {
             RGBColor[
             0.3763398438622711, 0.4987665529777692, 0.9453014400255476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 202}], {
             RGBColor[
             0.2682077809117381, 0.39923376146669465`, 0.9385854083938443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 220}], {
             RGBColor[
             0.46443936234214256`, 0.5702897109178078, 0.9522369568394528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 229}], {
             RGBColor[
             0.24996961512608984`, 0.38006429285947896`, 0.9375467718333002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 260}], {
             RGBColor[
             0.2588190028871956, 0.3893655604799919, 0.938050731374799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 307}], {
             RGBColor[
             0.32070535665531497`, 0.4507499650286162, 0.9417091542503788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 321}], {
             RGBColor[
             0.42370887427578074`, 0.5372228658179581, 0.9490305036181749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 341}], {
             RGBColor[
             0.3146456284168403, 0.44550133299924655`, 0.9413230337254305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 348}], {
             RGBColor[
             0.3130979265677895, 0.44416079144735543`, 0.9412244155321879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 366}], {
             RGBColor[
             0.34372780451171075`, 0.47069085221995155`, 0.9431761242698371]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.8209125437853362, 0.16174855223502174`, 0.16765918158716517`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 32}], {
             RGBColor[
             0.8889095486255394, 0.5137521204514779, 0.227558818965985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 73}], {
             RGBColor[
             0.8757010840349191, 0.46170115302421727`, 0.21528423867768243`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.8419234511371824, 0.5272135480684979, 0.5771697251114055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 78}], {
             RGBColor[
             0.8203622147555851, 0.15751848215663547`, 0.1671321858867677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 104}], {
             RGBColor[
             0.8198979870257355, 0.15395022439912315`, 0.1666876408883935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 112}], {
             RGBColor[
             0.8789473611792127, 0.4745715601436108, 0.21789626946789925`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 141}], {
             RGBColor[
             0.8431921928460754, 0.3216870212269862, 0.1885512226405503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 172}], {
             RGBColor[
             0.8222950385758708, 0.17237501300815056`, 0.16898306015988562`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 208}], {
             RGBColor[
             0.906901063221462, 0.5760810366232336, 0.4664786546523232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 240}], {
             RGBColor[
             0.8262378872131442, 0.20268147540152273`, 0.17275873646774914`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 242}], {
             RGBColor[
             0.8365301385898678, 0.28179222957633193`, 0.182614608009535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 243}], {
             RGBColor[
             0.8951565236421906, 0.5687878448594291, 0.5520035990795774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 285}], {
             RGBColor[
             0.9074929446583304, 0.5753915383194507, 0.38875906329594523`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 337}], {
             RGBColor[
             0.9074168352108218, 0.5752287479070755, 0.3804750196277067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 357}], {
             RGBColor[
             0.8389436700878857, 0.3003436902863443, 0.184925808497731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 399}], {
             RGBColor[
             0.8736814566563863, 0.4536940034692628, 0.2136591990821675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 32}], {
             RGBColor[
             0.8871756231465087, 0.5004244094086581, 0.22589840996907645`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 78}], {
             RGBColor[
             0.8186282892765544, 0.1441907711138157, 0.16547177688985915`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 83}], {
             RGBColor[
             0.881176745521725, 0.5463271969673706, 0.5710722243747279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 194}], {
             RGBColor[
             0.9059253338243674, 0.5624195574854407, 0.4052009770396422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 201}], {
             RGBColor[
             0.8831813824108397, 0.5478222518769809, 0.567678897014493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 217}], {
             RGBColor[
             0.9051942941547533, 0.5608559375515845, 0.32563182045602546`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 223}], {
             RGBColor[
             0.8736105747823911, 0.4469597061439798, 0.21333691400652116`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 230}], {
             RGBColor[
             0.8175286583222767, 0.13573852573788114`, 0.16441876904618735`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 242}], {
             RGBColor[
             0.8347962131108371, 0.26846451853351216`, 0.18095419901262647`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 244}], {
             RGBColor[
             0.8860422114357496, 0.549955853479581, 0.56283625969903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 245}], {
             RGBColor[
             0.8180745277590571, 0.13993431743048723`, 0.16494149423531956`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 328}], {
             RGBColor[
             0.8434248781398908, 0.3172892303900453, 0.1885318018785458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 357}], {
             RGBColor[
             0.837209744608855, 0.2870159792435245, 0.18326539950082243`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 364}], {
             RGBColor[
             0.81749806012385, 0.1355033345765571, 0.16438946817681815`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 385}], {
             RGBColor[
             0.9058721590894482, 0.562305822104239, 0.3994132353001115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 105}], {
             RGBColor[
             0.19823757833601402`, 0.32569064219253296`, 0.9346007088687955]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 128}], {
             RGBColor[
             0.19080558249119994`, 0.3178791433438807, 0.9341774677000858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 159}], {
             RGBColor[
             0.18375580691440718`, 0.3104693822310835, 0.9337759934101959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 171}], {
             RGBColor[
             0.18798107467478986`, 0.3149104065446947, 0.9340166161584262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 215}], {
             RGBColor[
             0.18499791179933114`, 0.3117749132191369, 0.9338467294458628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 218}], {
             RGBColor[
             0.188929981383257, 0.31590776765945394`, 0.9340706549916917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 342}], {
             RGBColor[
             0.18535691671142462`, 0.3121522501439733, 0.9338671742445064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 349}], {
             RGBColor[
             0.19449252215171758`, 0.32175435069256086`, 0.9343874334594139]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 353}], {
             RGBColor[
             0.1885101327336185, 0.315466480108742, 0.9340467452322052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 32}], {
             RGBColor[
             0.8890352414528142, 0.5147182506008601, 0.2276791825593331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 73}], {
             RGBColor[
             0.8758267768621938, 0.46266728317359945`, 0.2154046022710305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 74}], {
             RGBColor[
             0.8420491439644571, 0.52817967821788, 0.5772900887047536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 78}], {
             RGBColor[
             0.8204879075828598, 0.15848461230601768`, 0.16725254948011575`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 104}], {
             RGBColor[
             0.8200236798530103, 0.15491635454850536`, 0.16680800448174155`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 112}], {
             RGBColor[
             0.8790730540064875, 0.47553769029299303`, 0.21801663306124733`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 141}], {
             RGBColor[
             0.8433178856733501, 0.32265315137636846`, 0.18867158623389835`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 172}], {
             RGBColor[
             0.8224207314031455, 0.17334114315753277`, 0.1691034237532337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 208}], {
             RGBColor[
             0.9070267560487368, 0.5770471667726158, 0.46659901824567124`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 225}], {
             RGBColor[
             0.8528742555567694, 0.5368113283617635, 0.5783225975121196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 240}], {
             RGBColor[
             0.8263635800404189, 0.20364760555090494`, 0.1728791000610972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 243}], {
             RGBColor[
             0.8952822164694654, 0.5697539750088114, 0.5521239626729255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 285}], {
             RGBColor[
             0.9076186374856052, 0.576357668468833, 0.38887942688929333`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 337}], {
             RGBColor[
             0.9075425280380967, 0.5761948780564576, 0.3805953832210548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 357}], {
             RGBColor[
             0.8390693629151604, 0.3013098204357265, 0.18504617209107904`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 399}], {
             RGBColor[
             0.873807149483661, 0.45466013361864505`, 0.21377956267551557`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 36}], {
             RGBColor[
             0.19993330434376533`, 0.3274729577419183, 0.9346972779563351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 151}], {
             RGBColor[
             0.19950401467485102`, 0.3270217470813523, 0.9346728305447676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 168}], {
             RGBColor[
             0.19559687276408316`, 0.32291509320603007`, 0.9344503245930478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 265}], {
             RGBColor[
             0.1984857219314811, 0.32595145684458154`, 0.9346148402794617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 267}], {
             RGBColor[
             0.23148773999796957`, 0.36063867028126045`, 0.9364942563862377]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 282}], {
             RGBColor[
             0.2370656602671769, 0.3665014181447689, 0.9368119106937756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 291}], {
             RGBColor[
             0.1970819328198578, 0.3244759854828951, 0.9345348965662746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 304}], {
             RGBColor[
             0.1939396212205168, 0.3211732167579251, 0.9343559465693256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 378}], {
             RGBColor[
             0.19890365407675165`, 0.32639073002768937`, 0.9346386408968597]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 383}], {
             RGBColor[
             0.20767130167756592`, 0.3356060835571104, 0.9351379454571538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.19127206346984504`, 0.31836944442903903`, 0.934204033101723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 87}], {
             RGBColor[
             0.18980864714848175`, 0.31683130108933233`, 0.9341206937071518]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 119}], {
             RGBColor[
             0.18192714786076558`, 0.30854734562202557`, 0.9336718539823496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 127}], {
             RGBColor[
             0.18812124438286376`, 0.3150577337951532, 0.9340245986159385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 129}], {
             RGBColor[
             0.18526332309430954`, 0.3120538773182072, 0.933861844226471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 231}], {
             RGBColor[
             0.1818156421264654, 0.3084301460254042, 0.9336655038957391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 235}], {
             RGBColor[
             0.18647615617022215`, 0.31332864177904984`, 0.9339309132759184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 317}], {
             RGBColor[
             0.1883961858281423, 0.3153467146864354, 0.9340402561245076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 326}], {
             RGBColor[
             0.18672499245337307`, 0.31359018448977305`, 0.9339450841341236]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 327}], {
             RGBColor[
             0.18852270839333474`, 0.31547969792444663`, 0.934047461397422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 336}], {
             RGBColor[
             0.18089581060751259`, 0.30746334477829806`, 0.9336131208515035]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 396}], {
             RGBColor[
             0.19049809514878532`, 0.31755595465117936`, 0.9341599567508221]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 54}], {
             RGBColor[
             0.1824115228296057, 0.3090564544254234, 0.9336994384202565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 63}], {
             RGBColor[
             0.18069605079375822`, 0.30725338454853857`, 0.9336017448256284]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 224}], {
             RGBColor[
             0.17977250803868983`, 0.30628268255696894`, 0.9335491504319864]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 297}], {
             RGBColor[
             0.19356559882175525`, 0.3207800955024369, 0.9343346465470327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 318}], {
             RGBColor[
             0.18730055861877407`, 0.31419514102261215`, 0.9339778617757692]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 345}], {
             RGBColor[
             0.1795989351746539, 0.30610024647171197`, 0.9335392657141575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 81}], {
             RGBColor[
             0.1880171511030766, 0.3149483251582018, 0.9340186706576468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 106}], {
             RGBColor[
             0.21164758701888683`, 0.33978541156189057`, 0.935364389024955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 164}], {
             RGBColor[
             0.19871454021211585`, 0.32619195936544565`, 0.9346278711420376]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 192}], {
             RGBColor[
             0.18904880805086632`, 0.3160326620211572, 0.9340774219946237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 241}], {
             RGBColor[
             0.22984485211178313`, 0.3589118909477702, 0.9364006963515542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 271}], {
             RGBColor[
             0.18778814176396494`, 0.3147076218227647, 0.9340056289145733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 287}], {
             RGBColor[
             0.19320443776430601`, 0.3204004923321242, 0.9343140789591009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 292}], {
             RGBColor[
             0.19543097961487327`, 0.32274072898797734`, 0.9344408772236172]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 371}], {
             RGBColor[
             0.1915120199175549, 0.31862165386969954`, 0.9342176982664363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 374}], {
             RGBColor[
             0.1933477765192394, 0.32055115045176114`, 0.9343222418891437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 382}], {
             RGBColor[
             0.18918398084593196`, 0.3161747371992214, 0.9340851198853325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 384}], {
             RGBColor[
             0.19301716646589862`, 0.32020365832381187`, 0.9343034141356996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 389}], {
             RGBColor[
             0.19956255990653143`, 0.3270832818318305, 0.9346761646091019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 78}], {
             RGBColor[
             0.888484912423063, 0.5104881805224738, 0.22715218685893562`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 104}], {
             RGBColor[
             0.8880206846932135, 0.5069199227649615, 0.22670764186056142`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 172}], {
             RGBColor[
             0.8904177362433487, 0.5253447113739889, 0.22900306113205354`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 194}], {
             RGBColor[
             0.9757819569708761, 0.9287169668940988, 0.4668813870087187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 208}], {
             RGBColor[
             0.97502376088894, 0.929050734989072, 0.526498655624491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 217}], {
             RGBColor[
             0.975050917301262, 0.9271533469602427, 0.3873122304251019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 223}], {
             RGBColor[
             0.9434671979288998, 0.8132571155526379, 0.27501732397559764`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 230}], {
             RGBColor[
             0.8873852814687854, 0.5020359351465393, 0.22609917901526383`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 240}], {
             RGBColor[
             0.8943605848806221, 0.5556511737673611, 0.23277873743991706`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 242}], {
             RGBColor[
             0.9046528362573457, 0.6347619279421703, 0.24263460898170292`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 357}], {
             RGBColor[
             0.9070663677553636, 0.6533133886521827, 0.2449458094698989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 364}], {
             RGBColor[
             0.8873546832703587, 0.5018007439852152, 0.22606987814589463`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 385}], {
             RGBColor[
             0.9757287822359568, 0.928603231512897, 0.461093645269188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 387}], {
             RGBColor[
             0.7455791435710649, 0.7496942133696903, 0.622023162461701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 92}], {
             RGBColor[
             0.3869660924415177, 0.5054181375626268, 0.9463177797578736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 182}], {
             RGBColor[
             0.3125367270389322, 0.44214783260778046`, 0.9412445628049322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 256}], {
             RGBColor[
             0.3139252578534664, 0.443350508209742, 0.9413330387606047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 281}], {
             RGBColor[
             0.3526148324525338, 0.4768614731328931, 0.9437983042422098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 311}], {
             RGBColor[
             0.28964287283882917`, 0.4217634021453914, 0.9398061051687154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 35}], {
             RGBColor[
             0.24974982719833305`, 0.3798332818120472, 0.9375342552359615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 85}], {
             RGBColor[
             0.25199669770088307`, 0.3821948851700452, 0.9376622111871347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 86}], {
             RGBColor[
             0.3371353879041764, 0.46222487105446, 0.9428569705546225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 91}], {
             RGBColor[
             0.37827297461142906`, 0.4967706349329164, 0.9457781608227135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 93}], {
             RGBColor[
             0.24878417747359188`, 0.37881832272561544`, 0.9374792629126882]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 95}], {
             RGBColor[
             0.41132901778835196`, 0.5236070199417173, 0.9483804536298768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 125}], {
             RGBColor[
             0.2623800078372861, 0.3931084024632914, 0.9382535253386719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 162}], {
             RGBColor[
             0.2677884948207052, 0.39879306520074553`, 0.9385615306712383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 211}], {
             RGBColor[
             0.2425688344221679, 0.3722856031030586, 0.9371253083206856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 214}], {
             RGBColor[
             0.25149658822823806`, 0.38166923840552336`, 0.9376337306925131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 248}], {
             RGBColor[
             0.24062348998029212`, 0.37024092275268566`, 0.9370145238326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 263}], {
             RGBColor[
             0.3276003815122878, 0.45396612776116196`, 0.9422494083788064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 340}], {
             RGBColor[
             0.23309142699709673`, 0.3623242469969716, 0.9365855839883956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 42}], {
             RGBColor[
             0.22638274960055194`, 0.35527300169848874`, 0.9362035347352613]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 85}], {
             RGBColor[
             0.2384984047146932, 0.36800732340035325`, 0.9368935033705061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 86}], {
             RGBColor[
             0.32363709491798653`, 0.44803730928476804`, 0.942088262737994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 93}], {
             RGBColor[
             0.235285884487402, 0.3646307609559235, 0.9367105550960597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 97}], {
             RGBColor[
             0.21457055736469166`, 0.3428576387223553, 0.9355308478620015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 98}], {
             RGBColor[
             0.21863346925867172`, 0.3471280167264209, 0.9357622246838242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 125}], {
             RGBColor[
             0.24888171485109623`, 0.37892084069359944`, 0.9374848175220434]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 162}], {
             RGBColor[
             0.25429020183451534`, 0.3846055034310536, 0.9377928228546097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 211}], {
             RGBColor[
             0.22907054143597805`, 0.35809804133336665`, 0.9363566005040571]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 214}], {
             RGBColor[
             0.23799829524204824`, 0.3674816766358314, 0.9368650228758846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 248}], {
             RGBColor[
             0.22712519699410227`, 0.3560533609829937, 0.9362458160159715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 263}], {
             RGBColor[
             0.31410208852609794`, 0.43977856599147, 0.9414807005621779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 340}], {
             RGBColor[
             0.21959313401090685`, 0.34813668522727964`, 0.9358168761717671]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 80}], {
             RGBColor[
             0.1863429465695527, 0.31318863004276976`, 0.9339233271862263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 151}], {
             RGBColor[
             0.19244860485001886`, 0.3196060640166337, 0.9342710353927868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 168}], {
             RGBColor[
             0.18854146293925098`, 0.3154994101413115, 0.9340485294410671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 265}], {
             RGBColor[
             0.1914303121066489, 0.318535773779863, 0.934213045127481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 277}], {
             RGBColor[
             0.20034660319217895`, 0.3279073610362615, 0.9347208147143313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 304}], {
             RGBColor[
             0.18688421139568462`, 0.3137575336932065, 0.933954151417345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 378}], {
             RGBColor[
             0.1918482442519195, 0.31897504696297085`, 0.934236845744879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 383}], {
             RGBColor[
             0.20061589185273376`, 0.3281904004923918, 0.9347361503051731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 41}], {
             RGBColor[
             0.6103348144421008, 0.6886019294831773, 0.9655435733376975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 114}], {
             RGBColor[
             0.2950446149939596, 0.4237378370222073, 0.9402493164383834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 170}], {
             RGBColor[
             0.29023151793817503`, 0.41867896684859873`, 0.9399752176813956]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 187}], {
             RGBColor[
             0.39185947335344506`, 0.5138307132141199, 0.9461899170277228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 206}], {
             RGBColor[
             0.5395559184345032, 0.6328895346269106, 0.9586002858977685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 256}], {
             RGBColor[
             0.3500537032004466, 0.4776206563266962, 0.9435260903209648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 261}], {
             RGBColor[
             0.30438433219243016`, 0.43355447197007246`, 0.940781199515963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 311}], {
             RGBColor[
             0.3257713181858094, 0.4560335502623456, 0.9419991567290754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 361}], {
             RGBColor[
             0.28321730845770904`, 0.41130658795806163`, 0.939575768828076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 53}], {
             RGBColor[
             0.2076634431002256, 0.3355978236940631, 0.9351374979228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 58}], {
             RGBColor[
             0.2174442667054725, 0.3458780894432118, 0.935694501357687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 102}], {
             RGBColor[
             0.25020060979959846`, 0.3803070829072448, 0.9375599266382304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 103}], {
             RGBColor[
             0.20863860950919683`, 0.3366227854190133, 0.9351930322071614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 117}], {
             RGBColor[
             0.22453541604736282`, 0.35333133700637476`, 0.9360983318222922]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 145}], {
             RGBColor[
             0.21009367554414693`, 0.338152152078261, 0.9352758960652745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 189}], {
             RGBColor[
             0.24478652953490182`, 0.3746165412765333, 0.9372516027765698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 222}], {
             RGBColor[
             0.22765792346573496`, 0.35661329028148886`, 0.9362761540004327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 254}], {
             RGBColor[
             0.20508861754811766`, 0.3328915187854286, 0.9349908654167205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 303}], {
             RGBColor[
             0.21808265414273661`, 0.3465490751158777, 0.9357308565778295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 376}], {
             RGBColor[
             0.21626586560617583`, 0.3446395151729059, 0.9356273931583702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 150}], {
             RGBColor[
             0.1883607596919023, 0.31530947957110045`, 0.9340382386584571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 237}], {
             RGBColor[
             0.19025421078354665`, 0.3172996167201517, 0.9341460678970164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 251}], {
             RGBColor[
             0.18672478342346222`, 0.3135899647860835, 0.9339450722301794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 283}], {
             RGBColor[
             0.19607798492560893`, 0.3234207725920666, 0.934477723218905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 294}], {
             RGBColor[
             0.18656769797512113`, 0.31342485802008435`, 0.9339361264462835]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 320}], {
             RGBColor[
             0.18948414481075992`, 0.3164902285577502, 0.9341022137790767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 347}], {
             RGBColor[
             0.19051344323313968`, 0.3175720864609606, 0.9341608308015206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 381}], {
             RGBColor[
             0.18966952552711056`, 0.31668507544445096`, 0.9341127709366266]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 51}], {
             RGBColor[
             0.4513189432678153, 0.5634921655168925, 0.9504868403154272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 84}], {
             RGBColor[
             0.42994887224450423`, 0.5449824840875006, 0.9491251582866337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 102}], {
             RGBColor[
             0.39926565859510593`, 0.5155146756656562, 0.9472759248895897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 134}], {
             RGBColor[
             0.6760140538149009, 0.745057217744171, 0.9695892868351288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 163}], {
             RGBColor[
             0.3939273213258807, 0.5099037447255685, 0.9469719144794696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 167}], {
             RGBColor[
             0.4156571514498516, 0.5326037138579458, 0.948214502475271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 174}], {
             RGBColor[
             0.4325281900725898, 0.5472165595499049, 0.9492895101378381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 183}], {
             RGBColor[
             0.43552341404886974`, 0.5498108720138242, 0.9494803631610341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 189}], {
             RGBColor[
             0.3938515783304093, 0.5098241340349448, 0.9469676010279292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 226}], {
             RGBColor[
             0.48315013418370223`, 0.5910627432060597, 0.9525150956533707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 234}], {
             RGBColor[
             0.653391331063141, 0.7272953937118065, 0.9673580250213626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 246}], {
             RGBColor[
             0.7206526383610699, 0.7806508133791874, 0.9738469548784772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 269}], {
             RGBColor[
             0.6323207129287618, 0.7108348666826005, 0.9652579027218493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 272}], {
             RGBColor[
             0.6309966022057711, 0.7098004613221861, 0.9651259277394999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 350}], {
             RGBColor[
             0.7574551958384235, 0.806891984810095, 0.8535080309341501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 355}], {
             RGBColor[
             0.6433835290110301, 0.7194772226865849, 0.9663605408410356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 392}], {
             RGBColor[
             0.7560719179586157, 0.8063199638581745, 0.8764325252109648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 395}], {
             RGBColor[
             0.494849422028799, 0.60078007937222, 0.9533755056767188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 55}], {
             RGBColor[
             0.9217511656674453, 0.9083191148939446, 0.6659672564832814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 83}], {
             RGBColor[
             0.9084527486796484, 0.9295988421678656, 0.9827837388659694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.684630729662244, 0.7517566465973935, 0.970608286963019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 135}], {
             RGBColor[
             0.9333566323648748, 0.9460233638065111, 0.83381543555314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 156}], {
             RGBColor[
             0.8514284367030327, 0.5699234098578776, 0.5824732181712974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 165}], {
             RGBColor[
             0.8843102751860701, 0.9105890257431475, 0.9888274975519911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 187}], {
             RGBColor[
             0.6533956652271913, 0.7258990741319324, 0.9682873726725081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 206}], {
             RGBColor[
             0.8010921103082493, 0.8449578955447232, 0.9806977415425538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 245}], {
             RGBColor[
             0.8453505309169804, 0.5232059626309822, 0.576653008726561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 256}], {
             RGBColor[
             0.6115898950741928, 0.6896890172445088, 0.9656235459657501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 311}], {
             RGBColor[
             0.5873075100595555, 0.6681019111801583, 0.9640966123738608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 328}], {
             RGBColor[
             0.8707008812978143, 0.7005608755905404, 0.6002433163697872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 386}], {
             RGBColor[
             0.8163158098721861, 0.8568507653484726, 0.982215097641526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 400}], {
             RGBColor[
             0.861024743522975, 0.6436848292044157, 0.5916626524195524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 45}], {
             RGBColor[
             0.2506616815740248, 0.3807916985758058, 0.9375861839936894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 93}], {
             RGBColor[
             0.22541709987581074`, 0.35425804261205696`, 0.936148542411988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 98}], {
             RGBColor[
             0.20876468464708048`, 0.33675529838255447`, 0.9352002119997525]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 125}], {
             RGBColor[
             0.23901293023950498`, 0.3685481223497329, 0.9369228048379719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 139}], {
             RGBColor[
             0.20228682166276132`, 0.3299466536657998, 0.934831307285935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 148}], {
             RGBColor[
             0.27524609124263133`, 0.40429858097089644`, 0.9390716483190401]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 204}], {
             RGBColor[
             0.20507426806755127`, 0.33287643657154375`, 0.9349900482350304]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 248}], {
             RGBColor[
             0.21725641238251098`, 0.34568064263912723`, 0.9356838033318999]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 275}], {
             RGBColor[
             0.2276321474655179, 0.3565861980709679, 0.9362746860953526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 276}], {
             RGBColor[
             0.2196855450649306, 0.3482338151042579, 0.9358221388445839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 288}], {
             RGBColor[
             0.26094257460696524`, 0.39159756899969334`, 0.938171665642697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 290}], {
             RGBColor[
             0.20736560396252507`, 0.33528477587624783`, 0.9351205364245214]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 318}], {
             RGBColor[
             0.2054522043558168, 0.33327367157305554`, 0.9350115711475404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 56}], {
             RGBColor[
             0.3210051071529382, 0.44798658822988663`, 0.9418389411311112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 59}], {
             RGBColor[
             0.3034359716582913, 0.4327690861148492, 0.9407194513531689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[
             0.434369237561579, 0.5419666394359329, 0.9502257108546233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 121}], {
             RGBColor[
             0.28563299292961386`, 0.4173490407437973, 0.9395850612911336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 122}], {
             RGBColor[
             0.42916131354223347`, 0.5377386121027248, 0.9498157239985662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 175}], {
             RGBColor[
             0.2710055822533935, 0.4021744280676252, 0.9387447390412754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 213}], {
             RGBColor[
             0.2414891450614786, 0.3711507811287148, 0.9370638216088516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 227}], {
             RGBColor[
             0.23391469744368304`, 0.36318955643469497`, 0.9366324680224093]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 237}], {
             RGBColor[
             0.22884629711642387`, 0.3578623463356042, 0.9363438301217982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 274}], {
             RGBColor[
             0.3767191464303865, 0.4951636983486218, 0.9456872845015338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 296}], {
             RGBColor[
             0.2526601828418626, 0.38289225012060224`, 0.937699995684375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 308}], {
             RGBColor[
             0.23093015114267265`, 0.3600526090411681, 0.9364625025258073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 373}], {
             RGBColor[
             0.2661054797853324, 0.3970241096892522, 0.9384656854547713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 380}], {
             RGBColor[
             0.2402420225431372, 0.36983997628980336`, 0.9369927998263845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 46}], {
             RGBColor[
             0.2189840028439955, 0.34749644974970917`, 0.9357821870529404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 65}], {
             RGBColor[
             0.2623103948909678, 0.393035234842995, 0.9382495609843622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 68}], {
             RGBColor[
             0.25335041241870687`, 0.38361772516894843`, 0.9377393032376733]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 113}], {
             RGBColor[
             0.27210008577250266`, 0.4033248206617401, 0.9388070693975159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 149}], {
             RGBColor[
             0.22663901581167467`, 0.355542353734595, 0.9362181287168728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 161}], {
             RGBColor[
             0.2180648213930185, 0.34653033176526227`, 0.9357298410291143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 195}], {
             RGBColor[
             0.2192614298530921, 0.3477880431261581, 0.9357979861106919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 247}], {
             RGBColor[
             0.2171512777998561, 0.34557013952683935`, 0.9356778160729503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 249}], {
             RGBColor[
             0.27287548484168234`, 0.4041092659680885, 0.9388523457495259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 250}], {
             RGBColor[
             0.24751102743025372`, 0.3774801613076919, 0.9374067589011768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 266}], {
             RGBColor[
             0.23471345152571355`, 0.36402909761884283`, 0.9366779558857301]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 315}], {
             RGBColor[
             0.22776027402374388`, 0.3567208672073564, 0.9362819827132973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 316}], {
             RGBColor[
             0.23551418105696653`, 0.3648707151253743, 0.9367235562479619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 358}], {
             RGBColor[
             0.21372519899594036`, 0.3419691134779814, 0.9354827059534967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 362}], {
             RGBColor[
             0.21291981933663207`, 0.3411226083920287, 0.9354368407733515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 363}], {
             RGBColor[
             0.22828771928123268`, 0.35727524561493795`, 0.9363120199404259]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 369}], {
             RGBColor[
             0.21363611782330827`, 0.34187548351747254`, 0.9354776329124991]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 372}], {
             RGBColor[
             0.21537145554787535`, 0.3436994334927591, 0.9355764578287111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 66}], {
             RGBColor[
             0.2495400971941441, 0.37961284227999426`, 0.9375223114224907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 91}], {
             RGBColor[
             0.38905361359871204`, 0.5081017700405416, 0.9463921022645131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 123}], {
             RGBColor[
             0.24825361468381962`, 0.37826066759394095`, 0.9374490481467079]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 140}], {
             RGBColor[
             0.25525427585226035`, 0.38561880634952683`, 0.9378477254437005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 148}], {
             RGBColor[
             0.30939380782769543`, 0.44018999619208, 0.9410163102615399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 179}], {
             RGBColor[
             0.3693787364367489, 0.49212881841734446`, 0.9448432238628737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 203}], {
             RGBColor[
             0.2552832201033739, 0.38564922859261863`, 0.9378493737759823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 232}], {
             RGBColor[
             0.28995111396047296`, 0.4220873831078549, 0.9398236590445912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 257}], {
             RGBColor[
             0.30395689687858984`, 0.4354808171950546, 0.9406698751035344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 275}], {
             RGBColor[
             0.261779864050582, 0.3924776132921515, 0.9382193480378523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 276}], {
             RGBColor[
             0.2538332616499947, 0.38412523032544144`, 0.9377668007870836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 279}], {
             RGBColor[
             0.4785218001436983, 0.5802784243797845, 0.9537482634423509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 280}], {
             RGBColor[
             0.26817273037966816`, 0.3991969211351571, 0.9385834123178955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 288}], {
             RGBColor[
             0.29509029119202934`, 0.4274889842208769, 0.9401163275851969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 297}], {
             RGBColor[
             0.2458649611438621, 0.37575004127406386`, 0.9373130178613036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 325}], {
             RGBColor[
             0.2869742607531359, 0.4189585216435491, 0.9396541316582929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 339}], {
             RGBColor[
             0.26817858765203434`, 0.39920307749978645`, 0.9385837458808918]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 149}], {
             RGBColor[
             0.20894845482391827`, 0.3369484524901131, 0.9352106774394597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 153}], {
             RGBColor[
             0.1918690303202028, 0.3189968944386494, 0.9342380294807175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 161}], {
             RGBColor[
             0.20037426040526207`, 0.3279364305207805, 0.9347223897517012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 184}], {
             RGBColor[
             0.19220194755564052`, 0.3193468115612663, 0.9342569886247687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 195}], {
             RGBColor[
             0.2015708688653357, 0.3291941418816762, 0.9347905348332788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 247}], {
             RGBColor[
             0.1994607168120997, 0.32697623828235756`, 0.9346703647955372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 250}], {
             RGBColor[
             0.22982046644249732`, 0.3588862600632101, 0.9363993076237638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 315}], {
             RGBColor[
             0.21006971303598748`, 0.3381269659628746, 0.9352745314358842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 343}], {
             RGBColor[
             0.19165716183089215`, 0.31877420722314587`, 0.9342259638836825]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 356}], {
             RGBColor[
             0.1981426064801053, 0.32559082075040946`, 0.9345953003620997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 358}], {
             RGBColor[
             0.19603463800818394`, 0.3233752122334996, 0.9344752546760837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 362}], {
             RGBColor[
             0.19522925834887567`, 0.3225287071475469, 0.9344293894959386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 363}], {
             RGBColor[
             0.21059715829347625`, 0.33868134437045616`, 0.9353045686630128]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 369}], {
             RGBColor[
             0.19594555683555187`, 0.3232815822729907, 0.934470181635086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 372}], {
             RGBColor[
             0.19768089456011895`, 0.32510553224827726`, 0.934569006551298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.6461513889555156, 0.7219924964871992, 0.9663950668318202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.44142989596913074`, 0.5543010784500094, 0.9500295993461311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 173}], {
             RGBColor[
             0.41329174036295263`, 0.5275007351562074, 0.948325579764125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 201}], {
             RGBColor[
             0.7465737093465549, 0.8011421937069441, 0.9641963866302764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 209}], {
             RGBColor[
             0.43947307837840166`, 0.5526061814054317, 0.9499049126595958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 323}], {
             RGBColor[
             0.4713973595467131, 0.580257389192397, 0.951939099626107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 346}], {
             RGBColor[
             0.44758503753245593`, 0.5596323527057516, 0.9504217995237683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 61}], {
             RGBColor[
             0.22477630942984533`, 0.3535845312248864, 0.9361120503440548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 68}], {
             RGBColor[
             0.2551071510734325, 0.38546416887872903`, 0.937839346905198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 118}], {
             RGBColor[
             0.23953466514577643`, 0.3690964988161278, 0.9369525168690463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 173}], {
             RGBColor[
             0.2613339339978391, 0.3920089125331203, 0.938193952981043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 176}], {
             RGBColor[
             0.2369284794639835, 0.36635723242284735`, 0.9368040984499744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 209}], {
             RGBColor[
             0.2875152720132881, 0.41711435878234465`, 0.9397732858765137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 344}], {
             RGBColor[
             0.21571874970997718`, 0.3440644616768498, 0.9355962357174672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 354}], {
             RGBColor[
             0.22802037271409625`, 0.35699424742212627`, 0.9362967949489314]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 388}], {
             RGBColor[
             0.2298511238520014, 0.358918482944391, 0.9364010535178815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 52}], {
             RGBColor[
             0.1835216269875808, 0.31022324428012404`, 0.9337626572098012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 62}], {
             RGBColor[
             0.19439182652115503`, 0.3216485132003679, 0.9343816989922191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.19292841019979173`, 0.32011036986066127`, 0.934298359597648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 127}], {
             RGBColor[
             0.19124100743417377`, 0.3183368025664821, 0.9342022645064347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[
             0.18838308614561955`, 0.31533294608953616`, 0.9340395101169672]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 133}], {
             RGBColor[
             0.18673252269027052`, 0.31359809924619686`, 0.933945512969975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 199}], {
             RGBColor[
             0.18708382947160418`, 0.313967344947515, 0.93396551937146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 216}], {
             RGBColor[
             0.19369425198474133`, 0.320915318133817, 0.9343419731543394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 231}], {
             RGBColor[
             0.1849354051777754, 0.31170921479673314`, 0.9338431697862355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 235}], {
             RGBColor[
             0.18959591922153213`, 0.31660771055037873`, 0.9341085791664148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 298}], {
             RGBColor[
             0.19233776426424887`, 0.31948956353329044`, 0.9342647231854012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 313}], {
             RGBColor[
             0.20302253470198556`, 0.3307199347169253, 0.9348732050551289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 361}], {
             RGBColor[
             0.2026569249479238, 0.33033565568440915`, 0.9348523841205063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 393}], {
             RGBColor[
             0.1855205539729795, 0.3123242432810691, 0.9338764931444723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 396}], {
             RGBColor[
             0.1936178582000953, 0.3208350234225083, 0.9343376226413184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.18052420551329257`, 0.307072764263149, 0.9335919584911282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 147}], {
             RGBColor[
             0.18125622821196816`, 0.30784216653237684`, 0.9336336461008872]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 164}], {
             RGBColor[
             0.18999442899880858`, 0.3170265695932755, 0.9341312737086882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 271}], {
             RGBColor[
             0.17906803055065768`, 0.3055422320505946, 0.933509031481224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 287}], {
             RGBColor[
             0.18448432655099875`, 0.31123510255995407`, 0.9338174815257515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 371}], {
             RGBColor[
             0.1827919087042476, 0.30945626409752947`, 0.9337211008330868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 391}], {
             RGBColor[
             0.18008156514952903`, 0.3066075211758136, 0.9335667507772396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 84}], {
             RGBColor[
             0.36020789306278994`, 0.48641570522103605`, 0.9441731063199956]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 102}], {
             RGBColor[
             0.32952467941339164`, 0.45694789679919157`, 0.9423238729229517]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 134}], {
             RGBColor[
             0.6062730746331866, 0.6864904388777064, 0.9646372348684907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 163}], {
             RGBColor[
             0.3241863421441664, 0.4513369658591039, 0.9420198625128315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 167}], {
             RGBColor[
             0.3459161722681373, 0.47403693499148125`, 0.9432624505086329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 174}], {
             RGBColor[
             0.3627872108908755, 0.4886497806834403, 0.9443374581712001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 183}], {
             RGBColor[
             0.36578243486715545`, 0.4912440931473596, 0.9445283111943961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 189}], {
             RGBColor[
             0.324110599148695, 0.45125735516848015`, 0.9420155490612911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 222}], {
             RGBColor[
             0.3069819930795281, 0.4332541041734357, 0.9410401002851541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 226}], {
             RGBColor[
             0.41340915500198794`, 0.532495964339595, 0.9475630436867326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 234}], {
             RGBColor[
             0.5836503518814267, 0.668728614845342, 0.9624059730547245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 238}], {
             RGBColor[
             0.3357800727610889, 0.463522711822467, 0.942680108320078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 246}], {
             RGBColor[
             0.6509116591793556, 0.7220840345127228, 0.9688949029118392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 269}], {
             RGBColor[
             0.5625797337470475, 0.652268087816136, 0.9603058507552114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 272}], {
             RGBColor[
             0.5612556230240568, 0.6512336824557214, 0.9601738757728618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 350}], {
             RGBColor[
             0.6877142166567092, 0.7483252059436304, 0.8485559789675121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 355}], {
             RGBColor[
             0.5736425498293158, 0.6609104438201203, 0.9614084888743977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 392}], {
             RGBColor[
             0.6863309387769014, 0.7477531849917098, 0.8714804732443268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 395}], {
             RGBColor[
             0.4251084428470847, 0.5422133005057554, 0.9484234537100807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 89}], {
             RGBColor[
             0.18430520538442102`, 0.31104683485694296`, 0.933807280840301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 128}], {
             RGBColor[
             0.18698858591777334`, 0.3138672379336487, 0.9339600953919696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 133}], {
             RGBColor[
             0.18257629412906723`, 0.3092296395082612, 0.9337088219020035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 199}], {
             RGBColor[
             0.1829276009104009, 0.30959888520957934`, 0.9337288283034887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 299}], {
             RGBColor[
             0.18351379325327066`, 0.3102150105286766, 0.9337622110902213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 342}], {
             RGBColor[
             0.18153992013799802`, 0.30814034473374124`, 0.9336498019363901]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 393}], {
             RGBColor[
             0.18136432541177624`, 0.30795578354313347`, 0.9336398020765009]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 58}], {
             RGBColor[
             0.20217788494718347`, 0.3298321542707407, 0.9348251035011402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 64}], {
             RGBColor[
             0.18652020523185484`, 0.31337494013569756`, 0.9339334218048136]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 117}], {
             RGBColor[
             0.20926903428907379`, 0.33728540183390365`, 0.9352289339657456]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 126}], {
             RGBColor[
             0.1894916420221746, 0.31649810860229766`, 0.9341026407341755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 289}], {
             RGBColor[
             0.18928237138329773`, 0.3162781518923132, 0.9340907230808797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 303}], {
             RGBColor[
             0.20281627238444755`, 0.3305031399434066, 0.9348614587212829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 376}], {
             RGBColor[
             0.20099948384788677`, 0.3285935800004348, 0.9347579953018235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 63}], {
             RGBColor[
             0.18289690010848875`, 0.3095666167202264, 0.9337270799382376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 66}], {
             RGBColor[
             0.19944158418676777`, 0.3269561286800552, 0.9346692752208288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 204}], {
             RGBColor[
             0.18912347164523904`, 0.31611113819278824`, 0.9340816739758684]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 224}], {
             RGBColor[
             0.18197335735342035`, 0.3085959147286568, 0.9336744855445955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 290}], {
             RGBColor[
             0.19141480754021284`, 0.3185194774974923, 0.9342121621653594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 297}], {
             RGBColor[
             0.19576644813648575`, 0.3230933276741248, 0.9344599816596418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 318}], {
             RGBColor[
             0.18950140793350456`, 0.31650837319430003`, 0.9341031968883784]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 345}], {
             RGBColor[
             0.1817997844893844, 0.30841347864339985`, 0.9336646008267666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 92}], {
             RGBColor[
             0.7345108890138425, 0.7594054710903482, 0.6489345144638174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 135}], {
             RGBColor[
             0.9832367917164733, 0.9536721882994657, 0.5121416630539384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 156}], {
             RGBColor[
             0.9013085960546312, 0.5775722343508322, 0.2607994456720959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.9341904345376686, 0.918237850236102, 0.6671537250527897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 221}], {
             RGBColor[
             0.9369698505827507, 0.7826274582869746, 0.292244768605455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 245}], {
             RGBColor[
             0.8952306902685789, 0.5308547871239369, 0.2549792362273595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 255}], {
             RGBColor[
             0.9034963603733146, 0.5943883495886708, 0.2628944512543936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 328}], {
             RGBColor[
             0.9205810406494127, 0.7082097000834948, 0.27856954387058575`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 386}], {
             RGBColor[
             0.8661959692237846, 0.8644995898414272, 0.6605413251423246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 400}], {
             RGBColor[
             0.9109049028745734, 0.6513336536973703, 0.2699888799203509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 59}], {
             RGBColor[
             0.3640812726856617, 0.4897706319686471, 0.9444199146444701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 90}], {
             RGBColor[
             0.4950145385889495, 0.5989681852897308, 0.9539261741459244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 121}], {
             RGBColor[
             0.3462782939569843, 0.4743505865975952, 0.9432855245824346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 122}], {
             RGBColor[
             0.48980661456960395`, 0.5947401579565226, 0.9535161872898672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 137}], {
             RGBColor[
             0.35805694536026106`, 0.48455266243088047`, 0.9440360498343989]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 166}], {
             RGBColor[
             0.6856726502293173, 0.7474973607293266, 0.8829926191709212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 169}], {
             RGBColor[
             0.6387195548301612, 0.7123648726900207, 0.967730862260616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 175}], {
             RGBColor[
             0.331650883280764, 0.45917597392142306`, 0.9424452023325764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 178}], {
             RGBColor[
             0.4116703274319593, 0.5309898792944511, 0.9474522471315552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 213}], {
             RGBColor[
             0.30213444608884904`, 0.4281523269825127, 0.9407642849001527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 274}], {
             RGBColor[
             0.43736444745775693`, 0.5521652442024196, 0.9493877477928349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 278}], {
             RGBColor[
             0.3199081459581343, 0.44683361246279085`, 0.9417764708138758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 296}], {
             RGBColor[
             0.313305483869233, 0.43989379597440015`, 0.9414004589756761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 319}], {
             RGBColor[
             0.4175060909791842, 0.5360433358043497, 0.9478244252272849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 352}], {
             RGBColor[
             0.31062641380180694`, 0.4370779234706822, 0.9412478898986653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 76}], {
             RGBColor[
             0.20578868678679324`, 0.33362733594223004`, 0.9350307333242034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.2782593236768137, 0.4070163756656283, 0.939259698655848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 102}], {
             RGBColor[
             0.24757611002741542`, 0.37754856724378383`, 0.937410465258804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 144}], {
             RGBColor[
             0.20411547873617336`, 0.33186868819351084`, 0.93493544660101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 163}], {
             RGBColor[
             0.24223777275819017`, 0.37193763630369614`, 0.9371064548486839]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 167}], {
             RGBColor[
             0.2639676028821611, 0.3946376054360735, 0.9383490428444853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 174}], {
             RGBColor[
             0.28083864150489934`, 0.40925045112803254`, 0.9394240505070525]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 186}], {
             RGBColor[
             0.21226621689950026`, 0.3404356307898151, 0.9353996190814751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 188}], {
             RGBColor[
             0.20973271485913975`, 0.33777275951208907`, 0.9352553398882568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 189}], {
             RGBColor[
             0.24216202976271878`, 0.3718580256130724, 0.9371021413971435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 222}], {
             RGBColor[
             0.22503342369355192`, 0.35385477461802795`, 0.9361266926210063]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 228}], {
             RGBColor[
             0.21063806848440092`, 0.33872434357497383`, 0.9353068984378649]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 238}], {
             RGBColor[
             0.2538315033751126, 0.3841233822670593, 0.9377667006559303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 333}], {
             RGBColor[
             0.2028967340448986, 0.3305877102501046, 0.9348660408938132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 368}], {
             RGBColor[
             0.20142644533340448`, 0.3290423435926357, 0.9347823101267909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 117}], {
             RGBColor[
             0.2190498578943207, 0.34756566758305235`, 0.9357859374006325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 289}], {
             RGBColor[
             0.19906319498854463`, 0.3265584176414619, 0.9346477265157667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 303}], {
             RGBColor[
             0.21259709598969448`, 0.3407834056925553, 0.9354184621561699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 376}], {
             RGBColor[
             0.2107803074531337, 0.33887384574958357`, 0.9353149987367104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 90}], {
             RGBColor[
             0.47744540309430256`, 0.5837506831746934, 0.9528066843679821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 121}], {
             RGBColor[
             0.3287091584623374, 0.4591330844825578, 0.9421660348044922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 122}], {
             RGBColor[
             0.472237479074957, 0.5795226558414852, 0.9523966975119249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 175}], {
             RGBColor[
             0.314081747786117, 0.4439584718063857, 0.9413257125546342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 178}], {
             RGBColor[
             0.3941011919373124, 0.5157723771794137, 0.9463327573536129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 213}], {
             RGBColor[
             0.2845653105942021, 0.4129348248674753, 0.9396447951222104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 274}], {
             RGBColor[
             0.41979531196311004`, 0.5369477420873823, 0.9482682580148925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 296}], {
             RGBColor[
             0.2957363483745861, 0.42467629385936273`, 0.9402809691977339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 319}], {
             RGBColor[
             0.3999369554845372, 0.5208258336893123, 0.9467049354493426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 373}], {
             RGBColor[
             0.3091816453180559, 0.4388081534280127, 0.9410466589681301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.18336573314646784`, 0.31005938996887394`, 0.9337537792861741]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 101}], {
             RGBColor[
             0.18455258152934814`, 0.31130684286981486`, 0.9338213685457943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.18529719032077357`, 0.3120894739205271, 0.933863772914916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 259}], {
             RGBColor[
             0.18612091931381164`, 0.3129552653196448, 0.9339106830624717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 331}], {
             RGBColor[
             0.19257622837931382`, 0.31974020443772183`, 0.9342783033639781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 335}], {
             RGBColor[
             0.18275395419094043`, 0.3094163714975885, 0.9337189393797027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 394}], {
             RGBColor[
             0.18321858514836378`, 0.3099047280931446, 0.933745399425368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 118}], {
             RGBColor[
             0.22412293343441853`, 0.3528977916272621, 0.9360748415476985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 130}], {
             RGBColor[
             0.19568837198846437`, 0.3230112646922406, 0.9344555353385153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 147}], {
             RGBColor[
             0.19642039468713995`, 0.32378066696146846`, 0.9344972229482744]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 164}], {
             RGBColor[
             0.2051585954739804, 0.3329650700223671, 0.9349948505560753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 173}], {
             RGBColor[
             0.24592220228648118`, 0.3758102053442546, 0.937316277659695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 176}], {
             RGBColor[
             0.2215167477526256, 0.3501585252339816, 0.9359264231286265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 344}], {
             RGBColor[
             0.20030701799861927`, 0.32786575448798405`, 0.9347185603961192]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 354}], {
             RGBColor[
             0.21260864100273835`, 0.3407955402332605, 0.9354191196275834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 371}], {
             RGBColor[
             0.19795607517941943`, 0.3253947645266211, 0.934584677680474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 388}], {
             RGBColor[
             0.2144393921406435, 0.3427197757555252, 0.9355233781965335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 87}], {
             RGBColor[
             0.1996423811721627, 0.3271671790429695, 0.9346807103120945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 119}], {
             RGBColor[
             0.1917608818844465, 0.31888322357566273`, 0.9342318705872924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 127}], {
             RGBColor[
             0.1979549784065447, 0.32539361174879033`, 0.9345846152208812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 129}], {
             RGBColor[
             0.19509705711799047`, 0.3223897552718444, 0.9344218608314138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 216}], {
             RGBColor[
             0.2004082229571123, 0.32797212731612524`, 0.934724323868786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 231}], {
             RGBColor[
             0.19164937615014635`, 0.31876602397904136`, 0.934225520500682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 235}], {
             RGBColor[
             0.1963098901939031, 0.32366451973268695`, 0.9344909298808612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 298}], {
             RGBColor[
             0.19905173523661984`, 0.32654637271559867`, 0.9346470738998478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 313}], {
             RGBColor[
             0.20973650567435648`, 0.3377767438992335, 0.9352555557695754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 317}], {
             RGBColor[
             0.19822991985182326`, 0.32568259264007254`, 0.9346002727294505]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 336}], {
             RGBColor[
             0.19072954463119351`, 0.31779922273193517`, 0.9341731374564464]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 361}], {
             RGBColor[
             0.20937089592029476`, 0.33739246486671737`, 0.9352347348349528]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 393}], {
             RGBColor[
             0.19223452494535048`, 0.31938105246337734`, 0.9342588438589188]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 396}], {
             RGBColor[
             0.20033182917246628`, 0.3278918326048165, 0.934719973355765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 98}], {
             RGBColor[
             0.19109841618892076`, 0.3181869301269141, 0.9341941441459625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 139}], {
             RGBColor[
             0.18462055320460163`, 0.31137828541015944`, 0.9338252394321449]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 204}], {
             RGBColor[
             0.18740799960939158`, 0.3143080683159034, 0.9339839803812403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 224}], {
             RGBColor[
             0.1802578853175729, 0.30679284485177194`, 0.9335767919499673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 290}], {
             RGBColor[
             0.18969933550436535`, 0.3167164076206075, 0.9341144685707314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 318}], {
             RGBColor[
             0.18778593589765713`, 0.3147053033174152, 0.9340055032937504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 345}], {
             RGBColor[
             0.18008431245353695`, 0.306610408766515, 0.9335669072321386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 77}], {
             RGBColor[
             0.18172630335562523`, 0.308336245312846, 0.9336604161849047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 94}], {
             RGBColor[
             0.1809149928406964, 0.30748350652159806`, 0.9336142132513059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 254}], {
             RGBColor[
             0.1839453796797469, 0.3106686352270631, 0.9337867892987342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 289}], {
             RGBColor[
             0.18340551527321602`, 0.3101012035064188, 0.9337560448194401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 68}], {
             RGBColor[
             0.2789862434779228, 0.41056260901775243`, 0.9391992258916821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 173}], {
             RGBColor[
             0.2852130264023293, 0.4171073526721437, 0.9395538319675272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 176}], {
             RGBColor[
             0.26080757186847375`, 0.39145567256187075`, 0.9381639774364586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 250}], {
             RGBColor[
             0.2731468584894696, 0.40442504515649597`, 0.9388666815551856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 363}], {
             RGBColor[
             0.25392355034044856`, 0.38422012946374207`, 0.9377719425944349]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 123}], {
             RGBColor[
             0.21298431371887483`, 0.3411903960769459, 0.9354405136330093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 131}], {
             RGBColor[
             0.2137636212718384, 0.34200949772606326`, 0.9354848940452685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 140}], {
             RGBColor[
             0.21998497488731555`, 0.3485485348325317, 0.9358391909300019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 203}], {
             RGBColor[
             0.2200139191384291, 0.3485789570756236, 0.9358408392622837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 232}], {
             RGBColor[
             0.25468181299552817`, 0.38501711159085983`, 0.9378151245308926]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 257}], {
             RGBColor[
             0.268687595913645, 0.3984105456780595, 0.9386613405898359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 275}], {
             RGBColor[
             0.22651056308563722`, 0.3554073417751564, 0.9362108135241538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 280}], {
             RGBColor[
             0.23290342941472336`, 0.362126649618162, 0.936574877804197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 297}], {
             RGBColor[
             0.21059566017891732`, 0.33867976975706876`, 0.935304483347605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 318}], {
             RGBColor[
             0.20433061997593613`, 0.33209481527724394`, 0.9349476985763416]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 322}], {
             RGBColor[
             0.2070879506142999, 0.33499294460302415`, 0.9351047244770914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 325}], {
             RGBColor[
             0.2517049597881912, 0.3818882501265539, 0.9376455971445944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 339}], {
             RGBColor[
             0.23290928668708955`, 0.3621328059827914, 0.9365752113671932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 113}], {
             RGBColor[
             0.36637406988619037`, 0.4916437040590915, 0.9445701410456664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 124}], {
             RGBColor[
             0.3674760832994186, 0.49271104629414053`, 0.9446362289748654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 194}], {
             RGBColor[
             0.709877099853931, 0.7667201163798876, 0.7972498678529694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 208}], {
             RGBColor[
             0.7091189037719949, 0.7670538844748609, 0.8568671364687419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 210}], {
             RGBColor[
             0.365438140563206, 0.4906599829992886, 0.9445168412553058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 249}], {
             RGBColor[
             0.36714946895537004`, 0.49242814936543994`, 0.9446154173976764]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 266}], {
             RGBColor[
             0.3289874356394012, 0.4523479810161943, 0.9424410275338806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 293}], {
             RGBColor[
             0.3870584168095417, 0.509672279343909, 0.9458839979501529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 316}], {
             RGBColor[
             0.32978816517065423`, 0.4531895985227258, 0.9424866278961124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 385}], {
             RGBColor[
             0.7098239251190117, 0.7666063809986858, 0.7914621261134387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 387}], {
             RGBColor[
             0.4796742864541198, 0.5876973628554791, 0.9523916433059518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 161}], {
             RGBColor[
             0.23474066997997348`, 0.36405770594001974`, 0.9366795059364341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 173}], {
             RGBColor[
             0.2762530439300684, 0.40768984299809713`, 0.9390435742208383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 176}], {
             RGBColor[
             0.2518475893962128, 0.38203816288782416`, 0.9376537196897696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 250}], {
             RGBColor[
             0.2641868760172087, 0.3950075354824494, 0.9383564238084967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 363}], {
             RGBColor[
             0.24496356786818765`, 0.3748026197896954, 0.9372616848477457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 106}], {
             RGBColor[
             0.23431749208343802`, 0.36361291913973265`, 0.936655406581262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 107}], {
             RGBColor[
             0.2952174792692931, 0.42393616514341426`, 0.9402585516481101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 150}], {
             RGBColor[
             0.217681081623926, 0.3461269969374395, 0.9357079876169566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 212}], {
             RGBColor[
             0.32957634955032006`, 0.4536960916538069, 0.9424478684800611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 270}], {
             RGBColor[
             0.300457761234542, 0.4284750339974831, 0.9405924577811364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 283}], {
             RGBColor[
             0.22539830685763262`, 0.3542382899584056, 0.9361474721774046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 294}], {
             RGBColor[
             0.2158880199071448, 0.3442423753864234, 0.935605875404783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 295}], {
             RGBColor[
             0.3354255676488553, 0.4587623903805083, 0.9428205754850394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 320}], {
             RGBColor[
             0.21880446674278364`, 0.34730774592408925`, 0.9357719627375762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 347}], {
             RGBColor[
             0.21983376516516337`, 0.34838960382729967`, 0.9358305797600202]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 373}], {
             RGBColor[
             0.25683371538447886`, 0.38727889744013877`, 0.937937672188489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 380}], {
             RGBColor[
             0.2309702581422837, 0.36009476404068996`, 0.9364647865601021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 381}], {
             RGBColor[
             0.21898984745913425`, 0.34750259281079, 0.9357825198951262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 390}], {
             RGBColor[
             0.2522635992417797, 0.3824754156120626, 0.9376774108350432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 108}], {
             RGBColor[
             0.2395346657598989, 0.3690964994616095, 0.9369525169040198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 152}], {
             RGBColor[
             0.2398425593336916, 0.3694201151292457, 0.9369700509875596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 154}], {
             RGBColor[
             0.21421417432422896`, 0.3424830575508392, 0.9355105523750686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 180}], {
             RGBColor[
             0.24072957206270523`, 0.3703524217472943, 0.9370205650502591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 198}], {
             RGBColor[
             0.2881120186842996, 0.4160342955793074, 0.9398697816662858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 236}], {
             RGBColor[
             0.23684558512377027`, 0.36627010521547854`, 0.9367993777399305]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 262}], {
             RGBColor[
             0.2185336488556363, 0.3470230991538516, 0.9357565400595423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 267}], {
             RGBColor[
             0.23945129119348169`, 0.3690088675060522, 0.9369477688458039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 284}], {
             RGBColor[
             0.24975725951810934`, 0.3798410936513683, 0.9375346784955776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 286}], {
             RGBColor[
             0.20888058953085603`, 0.33687712176419665`, 0.9352068126114177]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 332}], {
             RGBColor[
             0.22563024765380635`, 0.35448207444108004`, 0.936160680862621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 72}], {
             RGBColor[
             0.18087056047954858`, 0.30743680529285733`, 0.9336116828940703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 88}], {
             RGBColor[
             0.1851982028892632, 0.3119854318538441, 0.9338581357271303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 138}], {
             RGBColor[
             0.18058969715831197`, 0.30714160013447456`, 0.9335956881434259]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 157}], {
             RGBColor[
             0.18316059011768585`, 0.3098437716388048, 0.933742096694167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 365}], {
             RGBColor[
             0.17992874679989868`, 0.30644689940110903`, 0.9335580479983027]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 88}], {
             RGBColor[
             0.18714176336881175`, 0.31402823714670136`, 0.9339688186212005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 109}], {
             RGBColor[
             0.18206833162796426`, 0.3086957387129193, 0.933679894189029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 157}], {
             RGBColor[
             0.1851041505972344, 0.3118865769316621, 0.9338527795882372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 181}], {
             RGBColor[
             0.1888688995598306, 0.3158435667902215, 0.9340671764722099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 191}], {
             RGBColor[
             0.19501894918374685`, 0.32230765888062524`, 0.934417412700109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 365}], {
             RGBColor[
             0.18187230727944725`, 0.30848970469396636`, 0.9336687308923729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 370}], {
             RGBColor[
             0.18495091945082137`, 0.31172552128136616`, 0.9338440533011341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 78}], {
             RGBColor[
             0.8752764478324426, 0.45843721309521324`, 0.21487760657063304`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 99}], {
             RGBColor[
             0.9481261161147958, 0.8682562660194123, 0.6030407890629428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 104}], {
             RGBColor[
             0.874812220102593, 0.4548689553377009, 0.21443306157225883`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 112}], {
             RGBColor[
             0.9338615942560703, 0.7754902910821886, 0.2656416901517646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 141}], {
             RGBColor[
             0.898106425922933, 0.622605752165564, 0.23629664332441563`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 172}], {
             RGBColor[
             0.8772092716527284, 0.4732937439467283, 0.21672848084375096`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 177}], {
             RGBColor[
             0.912733918365472, 0.8408075046276462, 0.6264313427993702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 208}], {
             RGBColor[
             0.9618152962983195, 0.8769997675618114, 0.5142240753361885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 225}], {
             RGBColor[
             0.9076627958063523, 0.836763929150959, 0.6259476546026368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 240}], {
             RGBColor[
             0.8811521202900017, 0.5036002063401005, 0.22050415715161448`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 243}], {
             RGBColor[
             0.9500707567190481, 0.8697065757980069, 0.5997490197634427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 285}], {
             RGBColor[
             0.9624071777351879, 0.8763102692580285, 0.43650448397981056`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 337}], {
             RGBColor[
             0.9623310682876794, 0.8761474788456531, 0.428220440311572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 399}], {
             RGBColor[
             0.9285956897332439, 0.7546127344078406, 0.2614046197660328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 86}], {
             RGBColor[
             0.6370413534700665, 0.7120367862892685, 0.9671058051428245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 91}], {
             RGBColor[
             0.6781789401773193, 0.7465825501677249, 0.9700269954109155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 95}], {
             RGBColor[
             0.7112349833542422, 0.7734189351765257, 0.9726292882180788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 104}], {
             RGBColor[
             0.8410345872048564, 0.5203813503819814, 0.5763185480059819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 112}], {
             RGBColor[
             0.9000839613583336, 0.841002686126469, 0.6275271765854877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 141}], {
             RGBColor[
             0.8643287930251963, 0.6881181472098445, 0.5981821297581387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 148}], {
             RGBColor[
             0.5985191344063026, 0.6786707763192633, 0.9646512034079422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 172}], {
             RGBColor[
             0.8434316387549917, 0.5388061389910088, 0.578613967277474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 179}], {
             RGBColor[
             0.6585040630153561, 0.7306095985445278, 0.968478117009276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 240}], {
             RGBColor[
             0.8473744873922651, 0.569112601384381, 0.5823896435853375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 263}], {
             RGBColor[
             0.627506347078178, 0.7037780429959705, 0.9664982429670084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 279}], {
             RGBColor[
             0.7676471267223055, 0.8187592045069678, 0.9773831565887533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 285}], {
             RGBColor[
             0.9286295448374513, 0.9418226643023089, 0.7983899704135337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 399}], {
             RGBColor[
             0.8948180568355072, 0.820125129452121, 0.6232901061997559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 105}], {
             RGBColor[
             0.21372122175088312`, 0.34196493314125437`, 0.9354824794552745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 132}], {
             RGBColor[
             0.28812004710636396`, 0.4155836677571048, 0.9398870475355221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 202}], {
             RGBColor[
             0.23066301686818202`, 0.3597718339813871, 0.9364472896240648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 215}], {
             RGBColor[
             0.20048155521420025`, 0.3280492041678583, 0.9347285000323418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 218}], {
             RGBColor[
             0.20441362479812614`, 0.3321820586081753, 0.9349524255781707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 229}], {
             RGBColor[
             0.21242485108253378`, 0.34060236537417143`, 0.9354086530635206]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 260}], {
             RGBColor[
             0.22127423884363956`, 0.34990363299468435`, 0.9359126126050195]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 329}], {
             RGBColor[
             0.20420501368883298`, 0.3319627951056, 0.934940545484109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 341}], {
             RGBColor[
             0.2771008643732843, 0.406039405513939, 0.9391849149556509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 349}], {
             RGBColor[
             0.2099761655665867, 0.3380286416412822, 0.935269204045893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 77}], {
             RGBColor[
             0.1883529029244576, 0.3153012216103682, 0.9340377912271741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 103}], {
             RGBColor[
             0.19412197120965846`, 0.32136487815817005`, 0.9343663311314445]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 144}], {
             RGBColor[
             0.19222334020881804`, 0.31936929659612845`, 0.9342582069047196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 145}], {
             RGBColor[
             0.19557703724460856`, 0.3228942448174177, 0.9344491949895577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 200}], {
             RGBColor[
             0.1890554468047247, 0.31603963977238364`, 0.9340778000618348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 207}], {
             RGBColor[
             0.1908268877624048, 0.3179015365347492, 0.9341786810037627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 222}], {
             RGBColor[
             0.21314128516619657`, 0.3413553830206456, 0.9354494529247159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 333}], {
             RGBColor[
             0.19100459551754329`, 0.3180883186527222, 0.9341888011975227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 368}], {
             RGBColor[
             0.18953430680604916`, 0.3165429519952533, 0.9341050704305003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 94}], {
             RGBColor[
             0.18199794707454847`, 0.3086217600846408, 0.9336758858928365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 103}], {
             RGBColor[
             0.18857832587467818`, 0.31553815542369057`, 0.9340506287307058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 145}], {
             RGBColor[
             0.19003339190962826`, 0.3170675220829382, 0.934133492588819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 200}], {
             RGBColor[
             0.1835118014697444, 0.3102129170379042, 0.9337620976610961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 207}], {
             RGBColor[
             0.18528324242742453`, 0.31207481380026975`, 0.9338629786030239]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 254}], {
             RGBColor[
             0.18502833391359902`, 0.3118068887901059, 0.9338484619402648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 333}], {
             RGBColor[
             0.18546095018256298`, 0.31226159591824276`, 0.9338730987967839]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 104}], {
             RGBColor[
             0.819473350823259, 0.1506862844701191, 0.16628100878134408`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 172}], {
             RGBColor[
             0.8218704023733945, 0.1691110730791465, 0.16857642805283624`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 194}], {
             RGBColor[
             0.9072346231009216, 0.5724833285992563, 0.40645475392950137`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 208}], {
             RGBColor[
             0.9064764270189856, 0.5728170966942296, 0.4660720225452738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 217}], {
             RGBColor[
             0.9065035834313075, 0.5709197086654001, 0.3268855973458845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 230}], {
             RGBColor[
             0.818837947598831, 0.14580229685169685`, 0.1656725459360465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 233}], {
             RGBColor[
             0.8896719661372465, 0.5617502239079055, 0.560162093898772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 240}], {
             RGBColor[
             0.8258132510106677, 0.19941753547251867`, 0.17235210436069973`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 242}], {
             RGBColor[
             0.8361055023873913, 0.2785282896473279, 0.1822079759024856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 244}], {
             RGBColor[
             0.8873515007123038, 0.5600196245933966, 0.5640900365888891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 264}], {
             RGBColor[
             0.7716146222869605, 0.4690073780170669, 0.569890082784954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 285}], {
             RGBColor[
             0.907068308455854, 0.5721275983904466, 0.38835243118889584`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 357}], {
             RGBColor[
             0.8385190338854094, 0.29707975035734024`, 0.18451917639068158`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 385}], {
             RGBColor[
             0.9071814483660026, 0.5723695932180546, 0.4006670121899707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 100}], {
             RGBColor[
             0.22059571881103596`, 0.3491904654197632, 0.9358739718929432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 137}], {
             RGBColor[
             0.2827537056275888, 0.4121446936308188, 0.939500838618308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 175}], {
             RGBColor[
             0.2563476435480917, 0.3867680051213614, 0.9379099911164857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 213}], {
             RGBColor[
             0.22683120635617676`, 0.355744358182451, 0.9362290736840618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 227}], {
             RGBColor[
             0.21925675873838124`, 0.34778313348843115`, 0.9357977200976195]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[
             0.21942962029019444`, 0.3479648219394422, 0.9358075643072694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 278}], {
             RGBColor[
             0.24460490622546205`, 0.37442564366272924`, 0.937241259597785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 302}], {
             RGBColor[
             0.21120952198211004`, 0.3393249774333106, 0.9353394418691697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 314}], {
             RGBColor[
             0.23185910927542647`, 0.36102900293803986`, 0.9365154053171973]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 352}], {
             RGBColor[
             0.23532317406913467`, 0.3646699546706205, 0.9367126786825744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 379}], {
             RGBColor[
             0.21907288200889707`, 0.34758986738728526`, 0.9357872485898966]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 151}], {
             RGBColor[
             0.18591365690063838`, 0.3127374193822037, 0.9338988797746588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 168}], {
             RGBColor[
             0.18200651498987047`, 0.3086307655068815, 0.933676373822939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 265}], {
             RGBColor[
             0.18489536415726843`, 0.31166712914543293`, 0.933840889509353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 304}], {
             RGBColor[
             0.18034926344630414`, 0.30688888905877654`, 0.9335819957992169]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 378}], {
             RGBColor[
             0.18531329630253898`, 0.3121064023285408, 0.9338646901267509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 192}], {
             RGBColor[
             0.1805894919591846, 0.3071413844571813, 0.9335956764576392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 271}], {
             RGBColor[
             0.1793288256722832, 0.3058163442587888, 0.9335238833775887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 287}], {
             RGBColor[
             0.1847451216726243, 0.31150921476814825`, 0.9338323334221164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 292}], {
             RGBColor[
             0.18697166352319156`, 0.31384945142400145`, 0.9339591316866327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 374}], {
             RGBColor[
             0.1848884604275577, 0.3116598728877852, 0.9338404963521592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 382}], {
             RGBColor[
             0.18072466475425025`, 0.3072834596352455, 0.9336033743483478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 384}], {
             RGBColor[
             0.18455785037421688`, 0.3113123807598359, 0.9338216685987151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 101}], {
             RGBColor[
             0.181913405203708, 0.30853290121812327`, 0.9336710713583607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 136}], {
             RGBColor[
             0.18265801399513343`, 0.30931553226883557`, 0.9337134757274823]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 259}], {
             RGBColor[
             0.1834817429881715, 0.31018132366795326`, 0.9337603858750381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 331}], {
             RGBColor[
             0.18993705205367367`, 0.31696626278603024`, 0.9341280061765445]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 335}], {
             RGBColor[
             0.18011477786530028`, 0.30664242984589696`, 0.933568642192269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 120}], {
             RGBColor[
             0.7316668327109251, 0.7891725193318362, 0.9665740024152043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 187}], {
             RGBColor[
             0.6899774075909928, 0.7548276258988081, 0.9634300825559947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 206}], {
             RGBColor[
             0.8376738526720509, 0.8738864473115988, 0.9758404514260404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 217}], {
             RGBColor[
             0.9690520396764782, 0.9730561345189551, 0.7324860448307533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 220}], {
             RGBColor[
             0.790428504618827, 0.8368778917698232, 0.9711999364788909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 230}], {
             RGBColor[
             0.8813864038440016, 0.5479387227052518, 0.5712729934209153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 244}], {
             RGBColor[
             0.9498999569574745, 0.9621560504469515, 0.9696904840737579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 245}], {
             RGBColor[
             0.8819322732807819, 0.5521345143978579, 0.5717957186100475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 321}], {
             RGBColor[
             0.7496980165524652, 0.8038110466699736, 0.967993483257613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 328}], {
             RGBColor[
             0.9072826236616158, 0.729489427357416, 0.5953860262532737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 364}], {
             RGBColor[
             0.8813558056455749, 0.5477035315439278, 0.5712436925515461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 102}], {
             RGBColor[
             0.3081546083900806, 0.43843821536979977`, 0.9409621908941581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 163}], {
             RGBColor[
             0.3028162711208553, 0.4328272844297121, 0.940658180484038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 167}], {
             RGBColor[
             0.32454610124482625`, 0.4555272535620894, 0.9419007684798394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 174}], {
             RGBColor[
             0.3414171398675645, 0.4701400992540484, 0.9429757761424066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 183}], {
             RGBColor[
             0.3444123638438444, 0.47273441171796776`, 0.9431666291656026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 189}], {
             RGBColor[
             0.30274052812538393`, 0.4327476737390883, 0.9406538670324976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 222}], {
             RGBColor[
             0.2856119220562171, 0.4147444227440439, 0.9396784182563604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 226}], {
             RGBColor[
             0.39203908397867687`, 0.5139862829102032, 0.9462013616579391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 234}], {
             RGBColor[
             0.5622802808581155, 0.6502189334159502, 0.961044291025931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 238}], {
             RGBColor[
             0.3144100017377778, 0.44501303039307516`, 0.9413184262912844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 246}], {
             RGBColor[
             0.6295415881560444, 0.703574353083331, 0.9675332208830456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 269}], {
             RGBColor[
             0.5412096627237364, 0.6337584063867442, 0.9589441687264177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 272}], {
             RGBColor[
             0.5398855520007457, 0.6327240010263296, 0.9588121937440683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 395}], {
             RGBColor[
             0.4037383718237736, 0.5237036190763635, 0.9470617716812872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 88}], {
             RGBColor[
             0.21610734049788477`, 0.34447289523301966`, 0.9356183653879699]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 162}], {
             RGBColor[
             0.2565370723370653, 0.38696710678905155`, 0.9379207788057828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 181}], {
             RGBColor[
             0.2178344766889036, 0.34628822487653976`, 0.9357167232389794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 191}], {
             RGBColor[
             0.22398452631281984`, 0.35275231696694354`, 0.9360669594668783]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 211}], {
             RGBColor[
             0.231317411938528, 0.36045964469136466`, 0.9364845564552302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 214}], {
             RGBColor[
             0.2402451657445982, 0.3698432799938294, 0.9369929788270578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 263}], {
             RGBColor[
             0.31634895902864796`, 0.44214016934946804`, 0.941608656513351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 307}], {
             RGBColor[
             0.294549891018896, 0.4232589122924366, 0.9402196391759287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 312}], {
             RGBColor[
             0.27182714160879756`, 0.40303793904002655`, 0.9387915256311776]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 340}], {
             RGBColor[
             0.22184000451345684`, 0.35049828858527765`, 0.9359448321229403]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 348}], {
             RGBColor[
             0.28694246093137055`, 0.4166697387111759, 0.9397349004577378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 91}], {
             RGBColor[
             0.45216024233108254`, 0.5649746624056373, 0.950332168324746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 93}], {
             RGBColor[
             0.32267144519324537`, 0.4470223501983363, 0.9420332704147207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 95}], {
             RGBColor[
             0.48521628550800544`, 0.5918110474144382, 0.9529344611319093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 125}], {
             RGBColor[
             0.3362672755569396, 0.46131242993601224`, 0.9428075328407044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 148}], {
             RGBColor[
             0.37250043656006593`, 0.49706288855717573`, 0.9449563763217728]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 162}], {
             RGBColor[
             0.3416757625403587, 0.46699709267346645`, 0.9431155381732708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 179}], {
             RGBColor[
             0.4324853651691194, 0.5490017107824403, 0.9487832899231066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 214}], {
             RGBColor[
             0.32538385594789154`, 0.4498732658782442, 0.9421877381945456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 263}], {
             RGBColor[
             0.4014876492319413, 0.5221701552338829, 0.9468034158808389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 264}], {
             RGBColor[
             0.5671571608223211, 0.6570945561668415, 0.9602327949234224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 285}], {
             RGBColor[
             0.7026108469912147, 0.7602147765402214, 0.7786951433273641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 119}], {
             RGBColor[
             0.19029746556308325`, 0.3173450802359561, 0.9341485311927212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 127}], {
             RGBColor[
             0.19649156208518143`, 0.3238554684090837, 0.93450127582631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 129}], {
             RGBColor[
             0.1936336407966272, 0.32085161193213774`, 0.9343385214368426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 216}], {
             RGBColor[
             0.198944806635749, 0.32643398397641854`, 0.9346409844742148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 231}], {
             RGBColor[
             0.19018595982878306`, 0.3172278806393347, 0.9341421811061108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 235}], {
             RGBColor[
             0.1948464738725398, 0.3221263763929803, 0.9344075904862901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 298}], {
             RGBColor[
             0.19758831891525655`, 0.325008229375892, 0.9345637345052766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 313}], {
             RGBColor[
             0.2082730893529932, 0.33623860055952687`, 0.9351722163750043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 317}], {
             RGBColor[
             0.19676650353045996`, 0.3241444493003659, 0.9345169333348793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 361}], {
             RGBColor[
             0.20790747959893147`, 0.33585432152701067`, 0.9351513954403816]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 393}], {
             RGBColor[
             0.1907711086239872, 0.3178429091236707, 0.9341755044643476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 396}], {
             RGBColor[
             0.198868412851103, 0.3263536892651099, 0.9346366339611938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 109}], {
             RGBColor[
             0.18639597403767888`, 0.31324436527390603`, 0.9339263470220889]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 157}], {
             RGBColor[
             0.189431793006949, 0.31643520349264886`, 0.9340992324212971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 181}], {
             RGBColor[
             0.19319654196954522`, 0.3203921933512083, 0.9343136293052701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 191}], {
             RGBColor[
             0.19934659159346146`, 0.326856285441612, 0.9346638655331689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 365}], {
             RGBColor[
             0.18619994968916187`, 0.3130383312549531, 0.9339151837254329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 370}], {
             RGBColor[
             0.189278561860536, 0.3162741478423529, 0.9340905061341941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 128}], {
             RGBColor[
             0.1919283928758168, 0.31905928824840313`, 0.9342414100904406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 133}], {
             RGBColor[
             0.1875161010871107, 0.31442168982301577`, 0.9339901366004746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 155}], {
             RGBColor[
             0.19816316122321598`, 0.3256124250886648, 0.9345964709243118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 170}], {
             RGBColor[
             0.21045471282523004`, 0.33853162515176505`, 0.9352964566043255]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 171}], {
             RGBColor[
             0.18910388505940673`, 0.3160905514492172, 0.934080558548781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 199}], {
             RGBColor[
             0.18786740786844439`, 0.3147909355243339, 0.9340101430019597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 299}], {
             RGBColor[
             0.18845360021131413`, 0.3154070608434312, 0.9340435257886923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 306}], {
             RGBColor[
             0.1959786892882613, 0.3233164065815071, 0.9344720684792528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 342}], {
             RGBColor[
             0.18647972709604152`, 0.31333239504849575`, 0.9339311166348612]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 353}], {
             RGBColor[
             0.18963294311823536`, 0.31664662501326446`, 0.93411068762256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 121}], {
             RGBColor[
             0.4596424243656251, 0.5683306378036415, 0.9516722943059467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 122}], {
             RGBColor[
             0.6031707449782447, 0.6887202091625689, 0.9619029570133792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.7990367806379581, 0.841477411935373, 0.8913793888944332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 178}], {
             RGBColor[
             0.5250344578406001, 0.6249699305004974, 0.9558390168550672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 190}], {
             RGBColor[
             0.7822989919455827, 0.8299086268722369, 0.9606532016549456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 212}], {
             RGBColor[
             0.5128575453871849, 0.6144229009627645, 0.9550631147611566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 221}], {
             RGBColor[
             0.755343522572024, 0.6711176068414135, 0.6012544985481333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 268}], {
             RGBColor[
             0.6438707815800897, 0.7211954799278018, 0.9654945731092558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 274}], {
             RGBColor[
             0.5507285778663977, 0.6461452954084659, 0.9577745175163469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 295}], {
             RGBColor[
             0.5187067634857201, 0.6194891996894659, 0.9554358217661347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 319}], {
             RGBColor[
             0.530870221387825, 0.6300233870103961, 0.956211194950797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 324}], {
             RGBColor[
             0.6207541500572831, 0.7029952095291041, 0.9632871870713362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 351}], {
             RGBColor[
             0.7590840463718008, 0.8119268218437792, 0.9767853326782896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 373}], {
             RGBColor[
             0.44011491122134366`, 0.5480057067490964, 0.9505529184695845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 95}], {
             RGBColor[
             0.5263538722152581, 0.6263568112928946, 0.9558556514000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 112}], {
             RGBColor[
             0.7152028502193496, 0.6939405622428378, 0.6107535397674092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 125}], {
             RGBColor[
             0.37740486226419223`, 0.49585819381446866`, 0.9457287231087954]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 148}], {
             RGBColor[
             0.4136380232673186, 0.5316086524356322, 0.9478775665898638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 179}], {
             RGBColor[
             0.47362295187637204`, 0.5835474746608966, 0.9517044801911976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 257}], {
             RGBColor[
             0.408201112318213, 0.5268994734386068, 0.9475311314318583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 263}], {
             RGBColor[
             0.44262523593919395`, 0.5567159191123393, 0.94972460614893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 279}], {
             RGBColor[
             0.5827660155833214, 0.6716970806233367, 0.9606095197706748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 285}], {
             RGBColor[
             0.7437484336984672, 0.7947605404186777, 0.7816163335954551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 288}], {
             RGBColor[
             0.3993345066316525, 0.518907640464429, 0.9469775839135208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 135}], {
             RGBColor[
             0.746116355711272, 0.7971097200029147, 0.816782693533676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 165}], {
             RGBColor[
             0.6970699985324673, 0.761675381939551, 0.9717947555325273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 182}], {
             RGBColor[
             0.4229610876060558, 0.5395726978389508, 0.9485023279906137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 256}], {
             RGBColor[
             0.42434961842059, 0.5407753734409124, 0.9485908039462863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 281}], {
             RGBColor[
             0.46303919301965735`, 0.5742863383640635, 0.9510560694278913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 311}], {
             RGBColor[
             0.40006723340595274`, 0.5191882673765618, 0.947063870354397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 386}], {
             RGBColor[
             0.6290755332185833, 0.7079371215448762, 0.9651823556220622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 98}], {
             RGBColor[
             0.21766781953393055`, 0.3461130576399892, 0.9357072323605509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 125}], {
             RGBColor[
             0.24791606512635506`, 0.37790588160716765`, 0.9374298251987702]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 148}], {
             RGBColor[
             0.2841492261294814, 0.41365634022833114`, 0.9395786686798384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 162}], {
             RGBColor[
             0.2533245521097741, 0.3835905443446218, 0.9377378305313364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 214}], {
             RGBColor[
             0.23703264551730702`, 0.36646671754939963`, 0.9368100305526114]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 248}], {
             RGBColor[
             0.22615954726936105`, 0.355038401896562, 0.9361908236926982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 276}], {
             RGBColor[
             0.22858867995178067`, 0.3575915743616926, 0.9363291592053822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 288}], {
             RGBColor[
             0.2698457094938153, 0.4009553282571281, 0.9386786860034955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 290}], {
             RGBColor[
             0.21626873884937514`, 0.3446425351336826, 0.9356275567853198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 103}], {
             RGBColor[
             0.18776701535974932`, 0.31468541663244265`, 0.934004425797107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 145}], {
             RGBColor[
             0.18922208139469943`, 0.31621478329169034`, 0.9340872896552201]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 207}], {
             RGBColor[
             0.18447193191249567`, 0.3112220750090219, 0.933816775669425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 254}], {
             RGBColor[
             0.18421702339867016`, 0.31095414999885795`, 0.9338022590066659]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 125}], {
             RGBColor[
             0.41046090544111513`, 0.5226945788232695, 0.9483310159159588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 162}], {
             RGBColor[
             0.41586939242453425`, 0.5283792415607237, 0.9486390212485251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 233}], {
             RGBColor[
             0.7594081345567827, 0.8112195509449376, 0.9560282891124947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 263}], {
             RGBColor[
             0.47568127911611685`, 0.5835523041211401, 0.9523268989560933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 264}], {
             RGBColor[
             0.6413507907064967, 0.7184767050540989, 0.9657562779986768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 285}], {
             RGBColor[
             0.7768044768753901, 0.8215969254274786, 0.7842186264026185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 312}], {
             RGBColor[
             0.43115946169626646`, 0.5444500738116986, 0.9495097680739197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 173}], {
             RGBColor[
             0.515339475447038, 0.6087263479834802, 0.9574676673643785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 201}], {
             RGBColor[
             0.8486214444306401, 0.8823678065342169, 0.9733384742305298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 209}], {
             RGBColor[
             0.5415208134624869, 0.6338317942327045, 0.9590470002598491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 223}], {
             RGBColor[
             0.8390506368021915, 0.7815052608012159, 0.618996491222558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 245}], {
             RGBColor[
             0.7835145897788575, 0.47447987208772324`, 0.5706010714513564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 323}], {
             RGBColor[
             0.5734450946307983, 0.6614830020196698, 0.9610811872263605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 109}], {
             RGBColor[
             0.18710606140703578`, 0.3139907121212397, 0.9339667854472937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 181}], {
             RGBColor[
             0.19390662933890207`, 0.32113854019854193`, 0.9343540677304747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 191}], {
             RGBColor[
             0.2000566789628183, 0.32760263228894565`, 0.9347043039583738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 193}], {
             RGBColor[
             0.1899172543843397, 0.31694545418031556`, 0.9341268787285638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 211}], {
             RGBColor[
             0.20738956458852648`, 0.33530996001336677`, 0.9351219009467256]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 214}], {
             RGBColor[
             0.21631731839459667`, 0.3446935953158315, 0.9356303233185532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 248}], {
             RGBColor[
             0.2054442201466507, 0.3332652796629938, 0.9350111164586401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 305}], {
             RGBColor[
             0.18756138502713113`, 0.3144692861151448, 0.9339927154538672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 334}], {
             RGBColor[
             0.1889352663956901, 0.3159133225426103, 0.9340709559653313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 340}], {
             RGBColor[
             0.1979121571634553, 0.3253486039072797, 0.9345821766144358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 360}], {
             RGBColor[
             0.189069412661027, 0.31605431877284385`, 0.9340785953966906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 370}], {
             RGBColor[
             0.18998864922989284`, 0.31702049468968657`, 0.9341309445593988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 125}], {
             RGBColor[
             0.23126364989762477`, 0.3604031373776651, 0.9364814947865346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 139}], {
             RGBColor[
             0.19453754132088114`, 0.32180166869373195`, 0.9343899972344978]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 193}], {
             RGBColor[
             0.1939801662783198, 0.32121583218438116`, 0.9343582555503864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 204}], {
             RGBColor[
             0.19732498772567109`, 0.3247314515994759, 0.9345487381835933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 248}], {
             RGBColor[
             0.2095071320406308, 0.3375356576670594, 0.9352424932804627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 276}], {
             RGBColor[
             0.21193626472305038`, 0.34008883013219005`, 0.9353808287931467]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 290}], {
             RGBColor[
             0.19961632362064485`, 0.32713979090418005`, 0.9346792263730843]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 318}], {
             RGBColor[
             0.1977029240139366, 0.3251286866009877, 0.9345702610961033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 141}], {
             RGBColor[
             0.9156172249259522, 0.7282421342221813, 0.5763077730258106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 169}], {
             RGBColor[
             0.9307128082989145, 0.9468171296861931, 0.9664871194315787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 177}], {
             RGBColor[
             0.9302447173684912, 0.9464438866842635, 0.9664424725007652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 197}], {
             RGBColor[
             0.9649742133445314, 0.9733984061785892, 0.9441737000062027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 225}], {
             RGBColor[
             0.9251735948093716, 0.9424003112075763, 0.9659587843040318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 243}], {
             RGBColor[
             0.9675815557220673, 0.9753429578546242, 0.9397601494648378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 252}], {
             RGBColor[
             0.6676015641481373, 0.7342070299092066, 0.9439106644834332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 300}], {
             RGBColor[
             0.9401681906865148, 0.9543565949425481, 0.9673889822446275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 337}], {
             RGBColor[
             0.9798418672906987, 0.9817838609022704, 0.7682315700129669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 367}], {
             RGBColor[
             0.6703595369678017, 0.7365958473458555, 0.9440864000727226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 398}], {
             RGBColor[
             0.695865579228825, 0.7586878991813948, 0.9457116225314874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 146}], {
             RGBColor[
             0.1981449486568544, 0.3255932825266753, 0.9345954337456006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 175}], {
             RGBColor[
             0.2458994336441635, 0.3757862740575634, 0.9373149810191983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 213}], {
             RGBColor[
             0.21638299645224862`, 0.344762627118653, 0.9356340635867745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 227}], {
             RGBColor[
             0.20880854883445307`, 0.33680140242463313`, 0.9352027100003322]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 278}], {
             RGBColor[
             0.23415669632153385`, 0.3634439125989312, 0.9366462495004977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 302}], {
             RGBColor[
             0.20076131207818187`, 0.3283432463695126, 0.9347444317718824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 314}], {
             RGBColor[
             0.22141089937149833`, 0.35004727187424184`, 0.93592039521991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 352}], {
             RGBColor[
             0.2248749641652065, 0.3536882236068225, 0.936117668585287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 377}], {
             RGBColor[
             0.19744186238260558`, 0.3248542942741953, 0.9345553940224051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 136}], {
             RGBColor[
             0.18384486237801373`, 0.31056298516977654`, 0.9337810649871026]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 301}], {
             RGBColor[
             0.1828984857165501, 0.3095682832948322, 0.9337271702362709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 335}], {
             RGBColor[
             0.18130162624818058`, 0.3078898827468379, 0.9336362314518891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 394}], {
             RGBColor[
             0.18176625720560394`, 0.308378239342394, 0.9336626914975545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 163}], {
             RGBColor[
             0.272133057471457, 0.4033594760078676, 0.938808947086994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 167}], {
             RGBColor[
             0.29386288759542795`, 0.42605944514024496`, 0.9400515350827954]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 174}], {
             RGBColor[
             0.3107339262181662, 0.44067229083220405`, 0.9411265427453626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 189}], {
             RGBColor[
             0.27205731447598563`, 0.4032798653172439, 0.9388046336354536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 222}], {
             RGBColor[
             0.2549287084068188, 0.3852766143221994, 0.9378291848593165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 226}], {
             RGBColor[
             0.3613558703292786, 0.48451847448835883`, 0.9443521282608951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 395}], {
             RGBColor[
             0.3730551581743753, 0.49423581065451916`, 0.9452125382842432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 145}], {
             RGBColor[
             0.1958024601948291, 0.32313117863074003`, 0.9344620324930895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 200}], {
             RGBColor[
             0.18928086975494526`, 0.31627657358570604`, 0.9340906375653665]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 207}], {
             RGBColor[
             0.19105231071262538`, 0.3181384703480716, 0.9341915185072943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 222}], {
             RGBColor[
             0.21336670811641717`, 0.34159231683396796`, 0.9354622904282476]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 254}], {
             RGBColor[
             0.19079740219879987`, 0.3178705453379077, 0.9341770018445352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 333}], {
             RGBColor[
             0.19123001846776383`, 0.3183252524660446, 0.9342016387010543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 112}], {
             RGBColor[
             0.8780584972468868, 0.4677393624570944, 0.21704509236247566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 141}], {
             RGBColor[
             0.8423033289137494, 0.3148548235404699, 0.18770004553512668`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 172}], {
             RGBColor[
             0.8214061746435448, 0.16554281532163417`, 0.16813188305446203`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 208}], {
             RGBColor[
             0.906012199289136, 0.5692488389367173, 0.4656274775468996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 240}], {
             RGBColor[
             0.825349023280818, 0.19584927771500635`, 0.17190755936232552`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 242}], {
             RGBColor[
             0.8356412746575417, 0.27496003188981555`, 0.1817634309041114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 243}], {
             RGBColor[
             0.8942676597098645, 0.5619556471729128, 0.5511524219741538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 285}], {
             RGBColor[
             0.9066040807260044, 0.5685593406329343, 0.38790788619052163`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 337}], {
             RGBColor[
             0.9065279712784959, 0.568396550220559, 0.3796238425222831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 357}], {
             RGBColor[
             0.8380548061555597, 0.2935114925998279, 0.18407463139230737`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 399}], {
             RGBColor[
             0.8727925927240603, 0.4468618057827464, 0.21280802197674387`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 114}], {
             RGBColor[
             0.22538318625918102`, 0.3542223972507317, 0.9361466110816916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 171}], {
             RGBColor[
             0.19921926143757313`, 0.32672245337457523`, 0.9346566142691592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 202}], {
             RGBColor[
             0.2264175602160962, 0.35530958986254624`, 0.9362055171483188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 218}], {
             RGBColor[
             0.20016816814604027`, 0.3277198144893344, 0.9347106531024247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 229}], {
             RGBColor[
             0.20817939443044792`, 0.33614012125533055`, 0.9351668805877746]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 261}], {
             RGBColor[
             0.23472290345765154`, 0.3640390321985968, 0.9366784941592712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 349}], {
             RGBColor[
             0.20573070891450085`, 0.3335663975224413, 0.935027431570147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 353}], {
             RGBColor[
             0.19974831949640176`, 0.32727852693862247`, 0.9346867433429382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.2877186940288704, 0.4160544664052851, 0.9398315069221266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 150}], {
             RGBColor[
             0.2101822963835033, 0.33824529819931026`, 0.9352809428909732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 158}], {
             RGBColor[
             0.2827874224549232, 0.411783246820848, 0.939517290657987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 241}], {
             RGBColor[
             0.24501597193591163`, 0.37485769978748307`, 0.9372646691818778]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 270}], {
             RGBColor[
             0.2929589759941193, 0.42059333525935383`, 0.9401654130551529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 292}], {
             RGBColor[
             0.21060209943900177`, 0.3386865378276902, 0.9353048500539408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 310}], {
             RGBColor[
             0.2532088981789974, 0.38346898473049273`, 0.9377312442110733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 320}], {
             RGBColor[
             0.21130568150236095`, 0.33942604718596003`, 0.9353449180115927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 347}], {
             RGBColor[
             0.21233497992474068`, 0.3405079050891704, 0.9354035350340366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 374}], {
             RGBColor[
             0.2085188963433679, 0.336496959291474, 0.9351862147194673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 384}], {
             RGBColor[
             0.2081882862900271, 0.33614946716352473`, 0.9351673869660233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 389}], {
             RGBColor[
             0.21473367973065993`, 0.34302909067154336`, 0.9355401374394254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 390}], {
             RGBColor[
             0.24476481400135702`, 0.3745937168739334, 0.9372503661090598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 158}], {
             RGBColor[
             0.34368740964077826`, 0.4721064928245296, 0.9431204357248351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 190}], {
             RGBColor[
             0.6524189980541504, 0.7216233648288316, 0.9512140557147148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 212}], {
             RGBColor[
             0.3829775514957524, 0.5061376389193594, 0.9456239688209257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 241}], {
             RGBColor[
             0.30591595912176667`, 0.43518094579116473`, 0.9408678142487259]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 268}], {
             RGBColor[
             0.5139907876886572, 0.6129102178843966, 0.9560554271690249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 270}], {
             RGBColor[
             0.35385896317997434`, 0.4809165812630355, 0.943768558122001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 295}], {
             RGBColor[
             0.38882676959428764`, 0.5112039376460608, 0.945996675825904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 310}], {
             RGBColor[
             0.3141088853648525, 0.4437922307341744, 0.9413343892779213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 324}], {
             RGBColor[
             0.4908741561658506, 0.5947099474856988, 0.9538480411311054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 346}], {
             RGBColor[
             0.3498425512041035, 0.47743776708027175`, 0.9435126359024721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 351}], {
             RGBColor[
             0.6292040524803684, 0.703641559800374, 0.9673461867380587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 373}], {
             RGBColor[
             0.31023491732991126`, 0.43972044470569116`, 0.9411137725293536]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 390}], {
             RGBColor[
             0.30566480118721207`, 0.43491696287761505`, 0.9408535111759078]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 152}], {
             RGBColor[
             0.2564614085339687, 0.38688757933463486`, 0.9379164698641311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 154}], {
             RGBColor[
             0.23083302352450608`, 0.3599505217562283, 0.9364569712516402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 180}], {
             RGBColor[
             0.25734842126298235`, 0.38781988595268346`, 0.9379669839268308]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 198}], {
             RGBColor[
             0.3047308678845767, 0.4335017597846965, 0.9408162005428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 205}], {
             RGBColor[
             0.3030856171044626, 0.43207672625167026`, 0.9407113666179867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 236}], {
             RGBColor[
             0.2534644343240474, 0.3837375694208677, 0.9377457966165021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 262}], {
             RGBColor[
             0.23515249805591343`, 0.36449056335924074`, 0.936702958936114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 267}], {
             RGBColor[
             0.2560701403937588, 0.38647633171144136`, 0.9378941877223754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 284}], {
             RGBColor[
             0.26637610871838646`, 0.39730855785675745`, 0.9384810973721491]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 286}], {
             RGBColor[
             0.22549943873113315`, 0.3543445859695858, 0.9361532314879892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 332}], {
             RGBColor[
             0.24224909685408347`, 0.3719495386464692, 0.9371070997391926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 367}], {
             RGBColor[
             0.31561783688898226`, 0.44293150514134, 0.9415099085808494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 398}], {
             RGBColor[
             0.34112387915000547`, 0.4650235569768793, 0.9431351310396142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 157}], {
             RGBColor[
             0.18435836126610156`, 0.3111027050588667, 0.9338103079891256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 181}], {
             RGBColor[
             0.18812311022869774`, 0.31505969491742614`, 0.9340247048730984]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 191}], {
             RGBColor[
             0.19427315985261398`, 0.3215237870078299, 0.9343749411009974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 305}], {
             RGBColor[
             0.1817778659169268, 0.3083904408340291, 0.9336633525964908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 334}], {
             RGBColor[
             0.18315174728548578`, 0.30983447726149455`, 0.9337415931079549]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 340}], {
             RGBColor[
             0.19212863805325098`, 0.319269758626164, 0.9342528137570594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 360}], {
             RGBColor[
             0.18328589355082267`, 0.3099754734917281, 0.9337492325393142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 365}], {
             RGBColor[
             0.1811265179483144, 0.30770583282117103`, 0.9336262592932614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 370}], {
             RGBColor[
             0.1842051301196885, 0.31094164940857083`, 0.9338015817020224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 227}], {
             RGBColor[
             0.1954518354139104, 0.3227626497550994, 0.934442064930519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 237}], {
             RGBColor[
             0.19038343508665123`, 0.3174354396560086, 0.9341534270299079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 251}], {
             RGBColor[
             0.18685400772656674`, 0.3137257877219404, 0.9339524313630709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 308}], {
             RGBColor[
             0.1924672891129, 0.3196257023615725, 0.9342720994339171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 375}], {
             RGBColor[
             0.18201536929507323`, 0.30864007194304494`, 0.9336768780625215]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 116}], {
             RGBColor[
             0.1862942905711151, 0.31313748950344333`, 0.9339205562990953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 151}], {
             RGBColor[
             0.1906348725141942, 0.31769971633440997`, 0.9341677460194382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 154}], {
             RGBColor[
             0.19738148096805996`, 0.3247908295791051, 0.934551955390173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 286}], {
             RGBColor[
             0.1920478961746871, 0.3191848937924626, 0.934248215626522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 291}], {
             RGBColor[
             0.18821279065920096`, 0.31515395473595276`, 0.9340298120409453]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 304}], {
             RGBColor[
             0.18507047905985996`, 0.31185118601098283`, 0.9338508620439963]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 383}], {
             RGBColor[
             0.1988021595169091, 0.3262840528101681, 0.9346328609318244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 141}], {
             RGBColor[
             0.9013527030672266, 0.6354761592849575, 0.23890867411463246`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 172}], {
             RGBColor[
             0.880455548797022, 0.4861641510661218, 0.21934051163396778`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 179}], {
             RGBColor[
             0.6955279730573865, 0.6779676106196408, 0.6092046613657698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 240}], {
             RGBColor[
             0.8843983974342954, 0.516470613459494, 0.2231161879418313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 279}], {
             RGBColor[
             0.8046710367643358, 0.7661172165820809, 0.618109700945247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 285}], {
             RGBColor[
             0.9656534548794817, 0.8891806763774219, 0.4391165147700274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 337}], {
             RGBColor[
             0.9655773454319732, 0.8890178859650467, 0.43083247110178885`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 399}], {
             RGBColor[
             0.9318419668775375, 0.7674831415272341, 0.2640166505562497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 124}], {
             RGBColor[
             0.3086276211264817, 0.4416266325643382, 0.9408905883938774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 149}], {
             RGBColor[
             0.26206453775242544`, 0.39277682340214404`, 0.9382355597840353]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 210}], {
             RGBColor[
             0.3065896783902691, 0.43957556926948627`, 0.9407712006743179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 249}], {
             RGBColor[
             0.3083010067824331, 0.4413437356356376, 0.9408697768166884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 266}], {
             RGBColor[
             0.2701389734664643, 0.40126356728639195`, 0.9386953869528927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 293}], {
             RGBColor[
             0.32820995463660485`, 0.4585878656141067, 0.9421383573691648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 315}], {
             RGBColor[
             0.26318579596449465`, 0.3939553368749055, 0.9382994137804598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 316}], {
             RGBColor[
             0.2709397029977173, 0.40210518479292345`, 0.9387409873151243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 387}], {
             RGBColor[
             0.4208258242811829, 0.5366129491256768, 0.9486460027249637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 397}], {
             RGBColor[
             0.2602244815922864, 0.3908428077115391, 0.9381307713078346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 128}], {
             RGBColor[
             0.21795119041436695`, 0.34641089840207934`, 0.9357233699129821]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 155}], {
             RGBColor[
             0.2241859587617661, 0.352964035242341, 0.9360784307468533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 170}], {
             RGBColor[
             0.23647751036378017`, 0.3658832353054412, 0.9367784164268669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 187}], {
             RGBColor[
             0.33810546577905015`, 0.4610349816709624, 0.9429931157731941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 202}], {
             RGBColor[
             0.2423249813764799, 0.37202929809086444`, 0.937111421250482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 261}], {
             RGBColor[
             0.25063032461803525`, 0.380758740426915, 0.9375843982614342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 306}], {
             RGBColor[
             0.2220014868268114, 0.35066801673518333`, 0.9359540283017942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 353}], {
             RGBColor[
             0.2156557406567855, 0.3439982351669406, 0.9355926474451014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 122}], {
             RGBColor[
             0.7312854319265467, 0.5812953754272103, 0.5851154705993664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 166}], {
             RGBColor[
             0.92715146758626, 0.7340525782000142, 0.5145919024804202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 169}], {
             RGBColor[
             0.8801983721871041, 0.6989200901607082, 0.599330145570115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 197}], {
             RGBColor[
             0.914459777232721, 0.7255013666531043, 0.5770167261447392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 221}], {
             RGBColor[
             0.8834582095203258, 0.5636927731060549, 0.2244670121341203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 239}], {
             RGBColor[
             0.8461854795987771, 0.346251043142995, 0.19147853854411218`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 300}], {
             RGBColor[
             0.8896537545747043, 0.7064595554170632, 0.6002320083831638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 350}], {
             RGBColor[
             0.9292292560607558, 0.7349117971309463, 0.4801575703138227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 392}], {
             RGBColor[
             0.9278459781809479, 0.7343397761790258, 0.5030820645906373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 151}], {
             RGBColor[
             0.18767873323802545`, 0.31459262652510106`, 0.9339993982608765]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 154}], {
             RGBColor[
             0.19442534169189124`, 0.3216837397697962, 0.9343836076316113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 265}], {
             RGBColor[
             0.18666044049465552`, 0.3135223362883303, 0.9339414079955707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 291}], {
             RGBColor[
             0.1852566513830322, 0.31204686492664385`, 0.9338614642823836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 304}], {
             RGBColor[
             0.18211433978369124`, 0.30874409620167387`, 0.9336825142854346]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 383}], {
             RGBColor[
             0.19584602024074033`, 0.3231769630008592, 0.9344645131732627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 289}], {
             RGBColor[
             0.20615434433043495`, 0.33401166520462483`, 0.935051556980372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 303}], {
             RGBColor[
             0.21968824533158482`, 0.34823665325571823`, 0.9358222926207751]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 376}], {
             RGBColor[
             0.217871456795024, 0.34632709331274647`, 0.9357188292013159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 158}], {
             RGBColor[
             0.28881871360859035`, 0.41812251622929797`, 0.9398607637666927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 164}], {
             RGBColor[
             0.21991695118991147`, 0.3484770376136085, 0.9358353170810669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 173}], {
             RGBColor[
             0.26068055800241224`, 0.3913221729354959, 0.9381567441846866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 209}], {
             RGBColor[
             0.2868618960178613, 0.41642761918472027`, 0.9397360770801573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 241}], {
             RGBColor[
             0.25104726308957875`, 0.38119696919593304`, 0.9376081422905835]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 323}], {
             RGBColor[
             0.3187861771861727, 0.44407882697168544`, 0.9417702640466686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 346}], {
             RGBColor[
             0.2949738551719156, 0.42345379048504006`, 0.9402529639443298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 354}], {
             RGBColor[
             0.22736699671866945`, 0.3563075078245018, 0.9362595861525749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 388}], {
             RGBColor[
             0.2291977478565746, 0.35823174334676655`, 0.936363844721525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 389}], {
             RGBColor[
             0.22076497088432706`, 0.3493683600799934, 0.9358836105481312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 126}], {
             RGBColor[
             0.1845010944888899, 0.3112527267258263, 0.9338184364350084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 127}], {
             RGBColor[
             0.18861006279746526`, 0.31557151294177693`, 0.9340524361015079]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 129}], {
             RGBColor[
             0.18575214150891103`, 0.312567656464831, 0.9338896817120405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 196}], {
             RGBColor[
             0.18607572050979368`, 0.3129077585108523, 0.9339081090574485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 231}], {
             RGBColor[
             0.18230446054106692`, 0.30894392517202796`, 0.9336933413813087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 235}], {
             RGBColor[
             0.18696497458482364`, 0.31384242092567355`, 0.9339587507614879]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 317}], {
             RGBColor[
             0.1888850042427438, 0.31586049383305914`, 0.9340680936100771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 326}], {
             RGBColor[
             0.18721381086797456`, 0.3141039636363968, 0.933972921619693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 327}], {
             RGBColor[
             0.18901152680793626`, 0.3159934770710704, 0.9340752988829915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 336}], {
             RGBColor[
             0.18138462902211405`, 0.30797712392492177`, 0.9336409583370731]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 396}], {
             RGBColor[
             0.19098691356338682`, 0.3180697337978031, 0.9341877942363916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 132}], {
             RGBColor[
             0.4382862950940797, 0.5522789014915227, 0.9496356996104882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 160}], {
             RGBColor[
             0.48896132780643076`, 0.5959998592268796, 0.9529119733307341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 187}], {
             RGBColor[
             0.47660974925846794`, 0.585472751295903, 0.952077636221743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 202}], {
             RGBColor[
             0.38082926485589774`, 0.49646706771580507`, 0.9461959416990309]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 206}], {
             RGBColor[
             0.624306194339526, 0.7045315727086937, 0.9644880050917888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 217}], {
             RGBColor[
             0.7556843813439534, 0.80370125991605, 0.7211335984965017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 220}], {
             RGBColor[
             0.5770608462863022, 0.6675230171669182, 0.9598474901446392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 233}], {
             RGBColor[
             0.7388527640498924, 0.7945317751585553, 0.9544100950493892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 244}], {
             RGBColor[
             0.7365322986249497, 0.7928011758440465, 0.9583380377395063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 307}], {
             RGBColor[
             0.43332684059947457`, 0.5479832712777266, 0.9493196875555654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 321}], {
             RGBColor[
             0.5363303582199404, 0.6344561720670685, 0.9566410369233613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 341}], {
             RGBColor[
             0.42726711236099996`, 0.542734639248357, 0.9489335670306169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 366}], {
             RGBColor[
             0.4563492884558704, 0.567924158469062, 0.9507866575750236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 122}], {
             RGBColor[
             0.4544345003462795, 0.5641026104704333, 0.9512623074498896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 175}], {
             RGBColor[
             0.29627876905743955`, 0.4285384264353338, 0.9401913224925988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 178}], {
             RGBColor[
             0.376298213208635, 0.5003523318083618, 0.9451983672915776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.26676233186552467`, 0.3975147794964234, 0.938510405060175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 274}], {
             RGBColor[
             0.4019923332344326, 0.5215276967163304, 0.9471338679528571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 296}], {
             RGBColor[
             0.27793336964590865`, 0.4092562484883108, 0.9391465791356984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 319}], {
             RGBColor[
             0.3821339767558598, 0.5054057883182604, 0.9455705453873072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 373}], {
             RGBColor[
             0.2913786665893785, 0.4233881080569608, 0.9399122689060947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 166}], {
             RGBColor[
             0.7938288566186125, 0.8372493846021647, 0.890969402038376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 169}], {
             RGBColor[
             0.7468757612194565, 0.8021168965628588, 0.9757076451280708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 175}], {
             RGBColor[
             0.4398070896700592, 0.5489279977942612, 0.9504219852000314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 178}], {
             RGBColor[
             0.5198265338212547, 0.6207419031672892, 0.9554290299990101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 268}], {
             RGBColor[
             0.638662857560744, 0.7169674525945936, 0.9650845862531987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 274}], {
             RGBColor[
             0.5455206538470523, 0.6419172680752578, 0.9573645306602898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 319}], {
             RGBColor[
             0.5256622973684795, 0.6257953596771879, 0.9558012080947398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 351}], {
             RGBColor[
             0.7538761223524553, 0.8076987945105711, 0.9763753458222324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 131}], {
             RGBColor[
             0.21247713876151392`, 0.34065732304000995`, 0.9354116307694857]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 140}], {
             RGBColor[
             0.21869849237699107`, 0.3471963601464784, 0.9357659276542193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 203}], {
             RGBColor[
             0.21872743662810462`, 0.3472267823895703, 0.935767575986501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 232}], {
             RGBColor[
             0.2533953304852037, 0.3836649369048065, 0.9377418612551098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 275}], {
             RGBColor[
             0.22522408057531274`, 0.3540551670891031, 0.9361375502483711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 280}], {
             RGBColor[
             0.23161694690439888`, 0.3607744749321087, 0.9365016145284144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 297}], {
             RGBColor[
             0.20930917766859286`, 0.3373275950710155, 0.9352312200718224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 309}], {
             RGBColor[
             0.2546471876156135, 0.3849807181211936, 0.93781315266673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 322}], {
             RGBColor[
             0.20580146810397543`, 0.3336407699169709, 0.9350314612013086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 325}], {
             RGBColor[
             0.2504184772778667, 0.38053607544050067`, 0.9375723338688118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 339}], {
             RGBColor[
             0.23162280417676506`, 0.3607806312967381, 0.9365019480914105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 149}], {
             RGBColor[
             0.2631665511656537, 0.3938441656371931, 0.9383016477132344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 185}], {
             RGBColor[
             0.35466498690371884`, 0.48161471850061266`, 0.9438199172409392]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 210}], {
             RGBColor[
             0.30769169180349737`, 0.4406429115045353, 0.9408372886035168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 219}], {
             RGBColor[
             0.32342751125618663`, 0.45455838713589725`, 0.9418294929148936]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 249}], {
             RGBColor[
             0.30940302019566135`, 0.4424110778706867, 0.9409358647458874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 266}], {
             RGBColor[
             0.27124098687969256`, 0.402330909521441, 0.9387614748820916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 293}], {
             RGBColor[
             0.3293119680498331, 0.45965520784915576`, 0.9422044452983639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 315}], {
             RGBColor[
             0.2642878093777229, 0.3950226791099546, 0.9383655017096588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 316}], {
             RGBColor[
             0.27204171641094554`, 0.40317252702797246`, 0.9388070752443234]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 338}], {
             RGBColor[
             0.2719649687624893, 0.40309186038336303`, 0.9388027045792817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 387}], {
             RGBColor[
             0.42192783769441117`, 0.5376802913607258, 0.9487120906541628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 397}], {
             RGBColor[
             0.26132649500551464`, 0.3919101499465881, 0.9381968592370336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 148}], {
             RGBColor[
             0.2977450564931756, 0.4279464199660071, 0.9403529311058223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 162}], {
             RGBColor[
             0.2669203824734684, 0.39788062408229774`, 0.9385120929573202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 211}], {
             RGBColor[
             0.24170072207493107`, 0.37137316198461084`, 0.9370758706067677]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 214}], {
             RGBColor[
             0.25062847588100123`, 0.38075679728707557`, 0.9375842929785951]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 248}], {
             RGBColor[
             0.2397553776330553, 0.3693284816342379, 0.936965086118682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 263}], {
             RGBColor[
             0.326732269165051, 0.4530536866427142, 0.9421999706648885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 276}], {
             RGBColor[
             0.2421845103154749, 0.3718816540993685, 0.9371034216313661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 288}], {
             RGBColor[
             0.28344153985750953`, 0.415245407994804, 0.9394529484294792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 196}], {
             RGBColor[
             0.1881608487233165, 0.3150993604680292, 0.9340268540245378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 289}], {
             RGBColor[
             0.1863769520635358, 0.31322437197301883`, 0.933925263748802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 317}], {
             RGBColor[
             0.1909701324562666, 0.31805209579023613`, 0.9341868385771666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 326}], {
             RGBColor[
             0.18929893908149736`, 0.31629556559357375`, 0.9340916665867824]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 327}], {
             RGBColor[
             0.19109665502145906`, 0.31818507902824733`, 0.9341940438500809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 336}], {
             RGBColor[
             0.18346975723563688`, 0.31016872588209876`, 0.9337597033041625]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 376}], {
             RGBColor[
             0.19809406452812484`, 0.3255398000811405, 0.9345925359697458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 129}], {
             RGBColor[
             0.19194623803100921`, 0.3190780446379586, 0.9342424263456293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 216}], {
             RGBColor[
             0.19725740387013102`, 0.32466041668223944`, 0.9345448893830015]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 231}], {
             RGBColor[
             0.1884985570631651, 0.31545431334515556`, 0.9340460860148976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 235}], {
             RGBColor[
             0.19315907110692182`, 0.32035280909880115`, 0.9343114953950769]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 298}], {
             RGBColor[
             0.19590091614963856`, 0.32323466208171286`, 0.9344676394140633]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 313}], {
             RGBColor[
             0.20658568658737522`, 0.3344650332653477, 0.935076121283791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 317}], {
             RGBColor[
             0.19507910076484197`, 0.32237088200618674`, 0.9344208382436661]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 336}], {
             RGBColor[
             0.18757872554421223`, 0.31448751209804937`, 0.933993702970662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 361}], {
             RGBColor[
             0.2062200768333135, 0.33408075423283157`, 0.9350553003491684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 393}], {
             RGBColor[
             0.1890837058583692, 0.31606934182949153`, 0.9340794093731344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 396}], {
             RGBColor[
             0.197181010085485, 0.3245801219709307, 0.9345405388699805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 133}], {
             RGBColor[
             0.19019948162046302`, 0.31724209289972144`, 0.9341429511521433]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 155}], {
             RGBColor[
             0.2008465417565683, 0.32843282816537045`, 0.9347492854759805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 170}], {
             RGBColor[
             0.21313809335858236`, 0.34135202822847077`, 0.9354492711559941]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 171}], {
             RGBColor[
             0.19178726559275905`, 0.3189109545259229, 0.9342333731004496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 199}], {
             RGBColor[
             0.1905507884017967, 0.3176113386010396, 0.9341629575536283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 261}], {
             RGBColor[
             0.22729090761283746`, 0.3562275333499445, 0.9362552529905616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 299}], {
             RGBColor[
             0.19113698074466645`, 0.31822746392013684`, 0.934196340340361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 306}], {
             RGBColor[
             0.1986620698216136, 0.3261368096582128, 0.9346248830309214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 342}], {
             RGBColor[
             0.18916310762939384`, 0.3161527981252015, 0.9340839311865298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 353}], {
             RGBColor[
             0.19231632365158768`, 0.3194670280899702, 0.9342635021742287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 216}], {
             RGBColor[
             0.1943994825815768, 0.32165656020529343`, 0.9343821349935341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 231}], {
             RGBColor[
             0.18564063577461087`, 0.3124504568682096, 0.93388333162543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 235}], {
             RGBColor[
             0.1903011498183676, 0.3173489526218552, 0.9341487410056093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 298}], {
             RGBColor[
             0.19304299486108434`, 0.3202308056047669, 0.9343048850245959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 313}], {
             RGBColor[
             0.203727765298821, 0.33146117678840176`, 0.9349133668943235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 317}], {
             RGBColor[
             0.19222117947628775`, 0.3193670255292408, 0.9342580838541985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 336}], {
             RGBColor[
             0.184720804255658, 0.3114836556211034, 0.9338309485811944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 361}], {
             RGBColor[
             0.20336215554475928`, 0.33107689775588556`, 0.9348925459597008]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 393}], {
             RGBColor[
             0.18622578456981498`, 0.3130654853525456, 0.9339166549836668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 396}], {
             RGBColor[
             0.19432308879693078`, 0.32157626549398477`, 0.934377784480513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 147}], {
             RGBColor[
             0.18274418895711692`, 0.3094061076176884, 0.9337183832640827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 164}], {
             RGBColor[
             0.19148238974395732`, 0.318590510678587, 0.9342160108718838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 287}], {
             RGBColor[
             0.1859722872961475, 0.31279904364526556`, 0.9339022186889471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 371}], {
             RGBColor[
             0.18427986944939637`, 0.311020205182841, 0.9338058379962824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 391}], {
             RGBColor[
             0.18156952589467779`, 0.3081714622611251, 0.9336514879404352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 140}], {
             RGBColor[
             0.21947779992995464`, 0.3480154617955958, 0.9358103080664784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 186}], {
             RGBColor[
             0.21005402739966472`, 0.3381104793645726, 0.9352736381621005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 188}], {
             RGBColor[
             0.20752052535930418`, 0.3354476080868466, 0.9351293589688823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 203}], {
             RGBColor[
             0.2195067441810682, 0.34804588403868764`, 0.9358119563987601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 228}], {
             RGBColor[
             0.20842587898456535`, 0.33639919214973135`, 0.9351809175184903]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 238}], {
             RGBColor[
             0.2516193138752771, 0.38179823084181674`, 0.9376407197365557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 273}], {
             RGBColor[
             0.19754073794696791`, 0.32495821876141306`, 0.9345610248395222]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 280}], {
             RGBColor[
             0.23239625445736245`, 0.36159357658122604`, 0.9365459949406734]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 309}], {
             RGBColor[
             0.255426495168577, 0.38579981977031097`, 0.9378575330789891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 322}], {
             RGBColor[
             0.206580775656939, 0.33445987156608825`, 0.9350758416135677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 325}], {
             RGBColor[
             0.2511977848308302, 0.381355177089618, 0.9376167142810707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 330}], {
             RGBColor[
             0.199593351679308, 0.3271156459373298, 0.9346779181550091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 339}], {
             RGBColor[
             0.23240211172972863`, 0.36159973294585546`, 0.9365463285036696]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 160}], {
             RGBColor[
             0.40894844852211004`, 0.5284611159894712, 0.9473261168602697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 202}], {
             RGBColor[
             0.300816385571577, 0.4289283244783967, 0.9406100852285664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 220}], {
             RGBColor[
             0.4970479670019815, 0.5999842739295098, 0.9542616336741748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 244}], {
             RGBColor[
             0.656519419340629, 0.7252624326066381, 0.9527521812690418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 260}], {
             RGBColor[
             0.29142760754703456`, 0.4190601234916939, 0.9400754082095211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 307}], {
             RGBColor[
             0.3533139613151539, 0.48044452804031823`, 0.9437338310851009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 321}], {
             RGBColor[
             0.4563174789356197, 0.5669174288296601, 0.9510551804528969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 341}], {
             RGBColor[
             0.34725423307667924`, 0.4751958960109486, 0.9433477105601525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 348}], {
             RGBColor[
             0.34570653122762846`, 0.47385535445905747`, 0.94324909236691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 366}], {
             RGBColor[
             0.3763364091715497, 0.5003854152316536, 0.9452008011045592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 155}], {
             RGBColor[
             0.1964342499678622, 0.3237952297399831, 0.9344980119860145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 199}], {
             RGBColor[
             0.18613849661309062`, 0.31297374017565216`, 0.9339116840636623]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 216}], {
             RGBColor[
             0.19274891912622777`, 0.3199217133619542, 0.9342881378465417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 298}], {
             RGBColor[
             0.1913924314057353, 0.3184959587614276, 0.9342108878776034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 299}], {
             RGBColor[
             0.18672468895596034`, 0.31358986549474943`, 0.9339450668503949]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 306}], {
             RGBColor[
             0.1942497780329075, 0.32149921123282543`, 0.9343736095409554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 342}], {
             RGBColor[
             0.18475081584068775`, 0.311515199699814, 0.9338326576965637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 361}], {
             RGBColor[
             0.20171159208941025`, 0.3293420509125463, 0.9347985488127086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 393}], {
             RGBColor[
             0.18457522111446595`, 0.3113306385092063, 0.9338226578366745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 135}], {
             RGBColor[
             0.9129052217970873, 0.9297159641585085, 0.8318647617559947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 226}], {
             RGBColor[
             0.6381042655490734, 0.7140610165668736, 0.9666654902064342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 234}], {
             RGBColor[
             0.8083454624285121, 0.8502936670726204, 0.9815084195744261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 239}], {
             RGBColor[
             0.8293655507418161, 0.5412295041829576, 0.578979393717503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 246}], {
             RGBColor[
             0.8756067697264411, 0.9036490867400013, 0.9879973494315406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 269}], {
             RGBColor[
             0.7872748442941331, 0.8338331400434145, 0.9794082972749127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 272}], {
             RGBColor[
             0.7859507335711424, 0.832798734683, 0.9792763222925633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 350}], {
             RGBColor[
             0.9124093272037948, 0.929890258170909, 0.8676584254872136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 355}], {
             RGBColor[
             0.7983376603764013, 0.8424754960473988, 0.9805109353940992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 392}], {
             RGBColor[
             0.9110260493239869, 0.9293182372189884, 0.8905829197640283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 395}], {
             RGBColor[
             0.6498035533941702, 0.7237783527330339, 0.9675259002297822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 156}], {
             RGBColor[
             0.9129140627520606, 0.6152764832633987, 0.4286476247419544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 165}], {
             RGBColor[
             0.9457959012350979, 0.9559420991486686, 0.8350019041226482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 221}], {
             RGBColor[
             0.9485753172801801, 0.8203317071995411, 0.46009294767531356`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 234}], {
             RGBColor[
             0.8902824990453274, 0.9119541401261442, 0.8296334999422285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 255}], {
             RGBColor[
             0.9151018270707441, 0.6320925985012373, 0.4307426303242521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 281}], {
             RGBColor[
             0.711765095722288, 0.768553055573181, 0.8142632180180123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 328}], {
             RGBColor[
             0.932186507346842, 0.7459139489960613, 0.44641772294044424`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 355}], {
             RGBColor[
             0.8802746969932166, 0.9041359691009224, 0.8286360157619015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 386}], {
             RGBColor[
             0.8778014359212141, 0.9022038387539937, 0.8283895042121832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 400}], {
             RGBColor[
             0.9225103695720027, 0.6890379026099368, 0.4378370589902095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 331}], {
             RGBColor[
             0.19186850922797938`, 0.3189963467376835, 0.9342379998052863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 335}], {
             RGBColor[
             0.18204623503960604`, 0.3086725137975501, 0.9336786358210108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 394}], {
             RGBColor[
             0.18251086599702937`, 0.30916087039310625`, 0.9337050958666762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 169}], {
             RGBColor[
             0.6151260920101136, 0.6919294010372166, 0.9662275076726026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 175}], {
             RGBColor[
             0.3080574204607164, 0.43874050226861905`, 0.940941847744563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 178}], {
             RGBColor[
             0.3880768646119117, 0.5105544076416471, 0.9459488925435418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 197}], {
             RGBColor[
             0.6493874970557305, 0.7185106775296126, 0.9439140882472267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 252}], {
             RGBColor[
             0.35201484785933657`, 0.47931930126023004`, 0.943651052724457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 278}], {
             RGBColor[
             0.29631468313808673`, 0.42639814080998684`, 0.9402731162258624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 282}], {
             RGBColor[
             0.3008030444529849, 0.4311156931304887, 0.9405287217628104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 300}], {
             RGBColor[
             0.624581474397714, 0.6994688662935715, 0.9671293704856514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 314}], {
             RGBColor[
             0.28356888618805115`, 0.41300150008529746`, 0.9395472619452747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 319}], {
             RGBColor[
             0.3939126281591366, 0.5156078641515458, 0.9463210706392715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 352}], {
             RGBColor[
             0.28703295098175935`, 0.4166424518178782, 0.9397445353106518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 159}], {
             RGBColor[
             0.18138230828610377`, 0.30797468468423184`, 0.9336408261745905]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 215}], {
             RGBColor[
             0.18262441317102773`, 0.30928021567228525`, 0.9337115622102574]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 218}], {
             RGBColor[
             0.18655648275495362`, 0.3134130701126022, 0.9339354877560864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 229}], {
             RGBColor[
             0.19456770903936127`, 0.32183337687859837`, 0.9343917152414362]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 329}], {
             RGBColor[
             0.18634787164566047`, 0.31319380661002694`, 0.9339236076620245]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 349}], {
             RGBColor[
             0.19211902352341417`, 0.31925965314570914`, 0.9342522662238085]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 193}], {
             RGBColor[
             0.18750230329400064`, 0.31440718746762647`, 0.933989350836569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 204}], {
             RGBColor[
             0.19084712474135193`, 0.31792280688272123`, 0.9341798334697757]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 224}], {
             RGBColor[
             0.18369701044953324`, 0.3104075834185898, 0.9337726450385029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 276}], {
             RGBColor[
             0.20545840173873126`, 0.33328018541543536`, 0.9350119240793292]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 290}], {
             RGBColor[
             0.19313846063632573`, 0.32033114618742536`, 0.9343103216592668]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 318}], {
             RGBColor[
             0.19122506102961745`, 0.318320041884233, 0.9342013563822857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 203}], {
             RGBColor[
             0.22572809779654535`, 0.3545849211451561, 0.9361662532834936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 232}], {
             RGBColor[
             0.2603959916536444, 0.39102307566039235`, 0.9381405385521024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 257}], {
             RGBColor[
             0.2744017745717613, 0.404416509747592, 0.9389867546110457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 275}], {
             RGBColor[
             0.23222474174375346`, 0.36141330584468895`, 0.9365362275453637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 280}], {
             RGBColor[
             0.2386176080728396, 0.36813261368769457`, 0.936900291825407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 288}], {
             RGBColor[
             0.2655351688852008, 0.39642467677341436`, 0.9384332070927082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 297}], {
             RGBColor[
             0.21630983883703356`, 0.3446857338266013, 0.935629897368815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 309}], {
             RGBColor[
             0.2616478487840542, 0.3923388568767794, 0.9382118299637227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 322}], {
             RGBColor[
             0.21280212927241615`, 0.34099890867255667`, 0.9354301384983013]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 325}], {
             RGBColor[
             0.25741913844630737`, 0.3878942141960865, 0.9379710111658044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 339}], {
             RGBColor[
             0.2386234653452058, 0.3681387700523239, 0.9369006253884031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 172}], {
             RGBColor[
             0.8447003804638847, 0.3332796121494973, 0.18999546480661883`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[
             0.8486432291011581, 0.36358607454286945`, 0.19377114111448232`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 243}], {
             RGBColor[
             0.9175618655302045, 0.7296924440007758, 0.5730160037263106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 279}], {
             RGBColor[
             0.7689158684311985, 0.6132326776654563, 0.588764654117898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 285}], {
             RGBColor[
             0.9298982865463443, 0.7362961374607975, 0.4097714679426784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 337}], {
             RGBColor[
             0.9298221770988357, 0.7361333470484221, 0.40148742427443984`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 399}], {
             RGBColor[
             0.8960867985444002, 0.6145986026106095, 0.23467160372890067`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 143}], {
             RGBColor[
             0.1837659567931899, 0.3104800503972236, 0.9337765714307771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 258}], {
             RGBColor[
             0.18294835007904106`, 0.30962069390139346`, 0.9337300099379471]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 277}], {
             RGBColor[
             0.19515207298431664`, 0.32244758043556054`, 0.9344249939036124]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 302}], {
             RGBColor[
             0.18693197467623224`, 0.31380773592942895`, 0.9339568714655127]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 377}], {
             RGBColor[
             0.18361252498065594`, 0.31031878383411166`, 0.9337678337160353]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 378}], {
             RGBColor[
             0.18665371404405717`, 0.3135152663622699, 0.93394102493416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 379}], {
             RGBColor[
             0.1947953347030193, 0.32207262588340363`, 0.9344046781862394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 258}], {
             RGBColor[
             0.1842254727690224, 0.31096303082281923`, 0.9338027401858078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 277}], {
             RGBColor[
             0.196429195674298, 0.32378991735698637`, 0.9344977241514731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 302}], {
             RGBColor[
             0.1882090973662136, 0.3151500728508547, 0.9340296017133733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 377}], {
             RGBColor[
             0.1848896476706373, 0.3116611207555374, 0.933840563963896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 378}], {
             RGBColor[
             0.18793083673403851`, 0.31485760328369566`, 0.9340137551820207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 379}], {
             RGBColor[
             0.19607245739300067`, 0.3234149628048294, 0.9344774084341002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 186}], {
             RGBColor[
             0.19870087032152506`, 0.3261775914437136, 0.9346270926619912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 188}], {
             RGBColor[
             0.19616736828116454`, 0.3235147201659876, 0.934482813468773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 200}], {
             RGBColor[
             0.18738223875410484`, 0.31428099202366444`, 0.9339825133386415]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 228}], {
             RGBColor[
             0.19707272190642572`, 0.32446630422887235`, 0.934534372018381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 333}], {
             RGBColor[
             0.1893313874669234, 0.316329670904003, 0.9340935144743294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 368}], {
             RGBColor[
             0.18786109875542928`, 0.31478430424653414`, 0.934009783707307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 200}], {
             RGBColor[
             0.19073593578989534`, 0.3178059402449537, 0.9341735014234795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 207}], {
             RGBColor[
             0.19250737674757545`, 0.31966783700731927`, 0.9342743823654074]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 222}], {
             RGBColor[
             0.21482177415136725`, 0.3431216834932156, 0.9355451542863606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 254}], {
             RGBColor[
             0.19225246823374995`, 0.31939991199715534`, 0.9342598657026484]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 333}], {
             RGBColor[
             0.19268508450271393`, 0.3198546191252922, 0.9342845025591675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 227}], {
             RGBColor[
             0.19680598858419968`, 0.3241859505953433, 0.934519181950277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 302}], {
             RGBColor[
             0.18875875182792845`, 0.3157277945402228, 0.9340609037218272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 375}], {
             RGBColor[
             0.18336952246536248`, 0.3100633727832889, 0.9337539950822794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 377}], {
             RGBColor[
             0.18543930213235216`, 0.3122388424449055, 0.9338718659723498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 344}], {
             RGBColor[
             0.1873628349672718, 0.31426059741343176`, 0.9339814083216866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 354}], {
             RGBColor[
             0.1996644579713909, 0.3271903831587082, 0.9346819675531508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 371}], {
             RGBColor[
             0.18501189214807195`, 0.3117896074520688, 0.9338475256060415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 388}], {
             RGBColor[
             0.20149520910929605`, 0.3291146186809729, 0.9347862261221009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 391}], {
             RGBColor[
             0.18230154859335337`, 0.30894086453035285`, 0.9336931755501943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 179}], {
             RGBColor[
             0.39396314610535543`, 0.515635700812435, 0.9463286881882242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 232}], {
             RGBColor[
             0.3145355236290795, 0.4455942655029455, 0.9413091233699418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 257}], {
             RGBColor[
             0.3285413065471964, 0.4589876995901452, 0.9421553394288851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 275}], {
             RGBColor[
             0.28636427371918854`, 0.4159844956872421, 0.939704812363203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 276}], {
             RGBColor[
             0.27841767131860123`, 0.407632112720532, 0.9392522651124343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 279}], {
             RGBColor[
             0.5031062098123048, 0.6037853067748751, 0.9552337277677017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 288}], {
             RGBColor[
             0.3196747008606359, 0.4509958666159675, 0.9416017919105475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 195}], {
             RGBColor[
             0.20922588183301488`, 0.33724004586656203`, 0.9352264764972114]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 210}], {
             RGBColor[
             0.26112860842944113`, 0.3917931023423411, 0.9381822599936748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 247}], {
             RGBColor[
             0.20711572977977888`, 0.33502214226724336`, 0.9351063064594698]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 249}], {
             RGBColor[
             0.2628399368216051, 0.3935612687084925, 0.9382808361360453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 253}], {
             RGBColor[
             0.20384820267597584`, 0.3315877641079622, 0.9349202256247814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 266}], {
             RGBColor[
             0.22467790350563632`, 0.35348110035924685`, 0.9361064462722496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 315}], {
             RGBColor[
             0.21772472600366666`, 0.3461728699477604, 0.9357104730998167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 316}], {
             RGBColor[
             0.2254786330368893, 0.3543227178657783, 0.9361520466344813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 358}], {
             RGBColor[
             0.20368965097586314`, 0.3314211162183854, 0.9349111963400162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 359}], {
             RGBColor[
             0.20190369877404518`, 0.3295439672183649, 0.9348094890042022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 362}], {
             RGBColor[
             0.20288427131655484`, 0.3305746111324327, 0.934865331159871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 363}], {
             RGBColor[
             0.21825217126115545`, 0.34672724835534197`, 0.9357405103269454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 369}], {
             RGBColor[
             0.20360056980323105`, 0.3313274862578765, 0.9349061232990186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 397}], {
             RGBColor[
             0.21476341163145843`, 0.34306034078439396`, 0.9355418306271915]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 192}], {
             RGBColor[
             0.1875835174154828, 0.3144925486585769, 0.9339939758606419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 283}], {
             RGBColor[
             0.2012631111576979, 0.32887066901798323`, 0.9347730084871156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 294}], {
             RGBColor[
             0.19175282420721007`, 0.318874754446001, 0.9342314117144941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 320}], {
             RGBColor[
             0.19466927104284892`, 0.32194012498366686`, 0.9343974990472872]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 347}], {
             RGBColor[
             0.19569856946522865`, 0.3230219828868772, 0.9344561160697312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 380}], {
             RGBColor[
             0.20683506244234898`, 0.3347271431002675, 0.9350903228698133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 381}], {
             RGBColor[
             0.19485465175919953`, 0.32213497187036766`, 0.9344080562048372]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 384}], {
             RGBColor[
             0.19155187583051508`, 0.31866354496123156`, 0.9342199680017178]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 168}], {
             RGBColor[
             0.18811217327033666`, 0.31504819948074547`, 0.9340240820294996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 265}], {
             RGBColor[
             0.1910010224377346, 0.31808456311929695`, 0.9341885977159134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 291}], {
             RGBColor[
             0.1895972333261113, 0.3166090917576105, 0.9341086540027264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 304}], {
             RGBColor[
             0.1864549217267703, 0.3133063230326405, 0.9339297040057775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 378}], {
             RGBColor[
             0.19141895458300517`, 0.3185238363024048, 0.9342123983333115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 383}], {
             RGBColor[
             0.20018660218381945`, 0.3277391898318258, 0.9347117028936056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 154}], {
             RGBColor[
             0.23114091709829876`, 0.3602741374238645, 0.93647450533518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 180}], {
             RGBColor[
             0.2576563148367751, 0.3881435016203197, 0.9379845180103705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 198}], {
             RGBColor[
             0.3050387614583694, 0.43382537545233274`, 0.9408337346263971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 236}], {
             RGBColor[
             0.2537723278978401, 0.38406118508850384`, 0.9377633307000419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 267}], {
             RGBColor[
             0.25637803396755154`, 0.3867999473790775, 0.9379117218059152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 284}], {
             RGBColor[
             0.26668400229217915`, 0.3976321735243937, 0.9384986314556889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 332}], {
             RGBColor[
             0.24255699042787615`, 0.37227315431410535`, 0.9371246338227324]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 367}], {
             RGBColor[
             0.31592573046277495`, 0.4432551208089762, 0.9415274426643891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 383}], {
             RGBColor[
             0.2325615956471479, 0.3617673606549275, 0.9365554108768314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 398}], {
             RGBColor[
             0.3414317727237982, 0.4653471726445155, 0.943152665123154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 161}], {
             RGBColor[
             0.1909498488692258, 0.3180307764542026, 0.9341856834568915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 184}], {
             RGBColor[
             0.18277753601960423`, 0.3094411574946885, 0.933720282329959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[
             0.18871819494406902`, 0.31568516668383156`, 0.9340585940672899]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 372}], {
             RGBColor[
             0.18825648302408265`, 0.31519987818169937`, 0.9340323002564883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 180}], {
             RGBColor[
             0.2320279298273124, 0.36120644404191316`, 0.9365250193978796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 236}], {
             RGBColor[
             0.22814394288837742`, 0.3571241275100973, 0.936303832087551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 267}], {
             RGBColor[
             0.23074964895808886`, 0.359862889800671, 0.9364522231934242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 286}], {
             RGBColor[
             0.2001789472954632, 0.3277311440588154, 0.9347112669590381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 291}], {
             RGBColor[
             0.1963438417799771, 0.3237002050023056, 0.9344928633734613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 332}], {
             RGBColor[
             0.2169286054184135, 0.3453360967356988, 0.9356651352102414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 383}], {
             RGBColor[
             0.20693321063768522`, 0.33483030307652095`, 0.9350959122643404]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 170}], {
             RGBColor[
             0.21937286170598153`, 0.34790516506873237`, 0.9358043319898652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 171}], {
             RGBColor[
             0.19802203394015824`, 0.32546409136618454`, 0.9345884339343208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 199}], {
             RGBColor[
             0.1967855567491959, 0.3241644754413012, 0.9345180183874995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 261}], {
             RGBColor[
             0.23352567596023666`, 0.3627806701902061, 0.9366103138244327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.19737174909206562`, 0.3247806007603985, 0.9345514011742322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 306}], {
             RGBColor[
             0.20489683816901277`, 0.33268994649847444`, 0.9349799438647926]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 342}], {
             RGBColor[
             0.19539787597679303`, 0.32270593496546307`, 0.9344389920204009]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 353}], {
             RGBColor[
             0.19855109199898685`, 0.3260201649302318, 0.9346185630080999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 361}], {
             RGBColor[
             0.21235865222551553`, 0.3405327861781953, 0.9354048831365458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 165}], {
             RGBColor[
             0.8638677055732559, 0.5798421452000351, 0.5836596867408057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 221}], {
             RGBColor[
             0.866647121618338, 0.4442317532509077, 0.20875073029347097`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 245}], {
             RGBColor[
             0.8249079613041663, 0.19245908208786985`, 0.17148519791537548`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 255}], {
             RGBColor[
             0.833173631408902, 0.25599264455260395`, 0.17940041294240955`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 328}], {
             RGBColor[
             0.850258311685, 0.36981399504742796`, 0.1950755055586017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 364}], {
             RGBColor[
             0.8243314936689592, 0.18802809923393973`, 0.1709331718568741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 386}], {
             RGBColor[
             0.795873240259372, 0.5261038848053603, 0.5770472868303405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 400}], {
             RGBColor[
             0.8405821739101607, 0.3129379486613033, 0.18649484160836693`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 181}], {
             RGBColor[
             0.19115892919796787`, 0.31825053313616897`, 0.9341975902723066]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 191}], {
             RGBColor[
             0.1973089788218841, 0.3247146252265727, 0.9345478265002056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 334}], {
             RGBColor[
             0.1861875662547559, 0.3130253154802374, 0.9339144785071631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 365}], {
             RGBColor[
             0.18416233691758455`, 0.3108966710399138, 0.9337991446924696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 370}], {
             RGBColor[
             0.18724094908895864`, 0.3141324876273136, 0.9339744671012307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 209}], {
             RGBColor[
             0.336799320476102, 0.4661403761955148, 0.94268153277416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 241}], {
             RGBColor[
             0.3009846875478195, 0.43090972620672763`, 0.9405535979845862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 270}], {
             RGBColor[
             0.3489276916060272, 0.4766453616785984, 0.9434543418578613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 310}], {
             RGBColor[
             0.30917761379090525`, 0.4395210111497373, 0.9410201730137817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 323}], {
             RGBColor[
             0.3687236016444134, 0.49379158398248, 0.9447157197406713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 324}], {
             RGBColor[
             0.4859428845919035, 0.5904387279012617, 0.9535338248669657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 346}], {
             RGBColor[
             0.34491127963015633`, 0.47316654749583464`, 0.9431984196383325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 390}], {
             RGBColor[
             0.3007335296132649, 0.43064574329317795`, 0.9405392949117681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 215}], {
             RGBColor[
             0.1817543271405076, 0.3083657000875679, 0.9336620120979963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 218}], {
             RGBColor[
             0.18568639672443343`, 0.31249855452788494`, 0.9338859376438252]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 329}], {
             RGBColor[
             0.18547778561514033`, 0.3122792910253096, 0.9338740575497635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 349}], {
             RGBColor[
             0.191248937492894, 0.31834513756099186`, 0.9342027161115474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 217}], {
             RGBColor[
             0.7263465347719837, 0.7798834744139984, 0.7188240157462833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 220}], {
             RGBColor[
             0.5477229997143326, 0.6437052316648666, 0.9575379073944208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 233}], {
             RGBColor[
             0.7095149174779228, 0.7707139896565038, 0.9521005122991707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 244}], {
             RGBColor[
             0.7071944520529801, 0.7689833903419949, 0.9560284549892878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 263}], {
             RGBColor[
             0.42578806203725694`, 0.5430467428327064, 0.9483991221427692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 264}], {
             RGBColor[
             0.5914575736276367, 0.6779711437656651, 0.9618285011853527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 307}], {
             RGBColor[
             0.403988994027505, 0.524165485775675, 0.9470101048053469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 312}], {
             RGBColor[
             0.38126624461740655`, 0.5039445125232649, 0.9455819912605958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 321}], {
             RGBColor[
             0.5069925116479708, 0.6106383865650169, 0.9543314541731429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 341}], {
             RGBColor[
             0.3979292657890303, 0.5189168537463054, 0.9466239842803985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 348}], {
             RGBColor[
             0.39638156393997953`, 0.5175763121944144, 0.946525366087156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 366}], {
             RGBColor[
             0.4270114418839008, 0.5441063729670104, 0.948477074824805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 176}], {
             RGBColor[
             0.21656199837052442`, 0.34495076948413805`, 0.9356442574812107]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 184}], {
             RGBColor[
             0.19128276610466352`, 0.31838069357681953`, 0.9342046426009427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 195}], {
             RGBColor[
             0.20065168741435874`, 0.3282280238972294, 0.9347381888094528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 250}], {
             RGBColor[
             0.22890128499152032`, 0.3579201420787632, 0.9363469615999377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 344}], {
             RGBColor[
             0.1953522686165181, 0.3226579987381405, 0.9344363947487033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.19722342502912832`, 0.3246247027659626, 0.9345429543382737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 363}], {
             RGBColor[
             0.20967797684249928`, 0.3377152263860093, 0.9352522226391868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 372}], {
             RGBColor[
             0.19676171310914198`, 0.3241394142638304, 0.934516660527472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 191}], {
             RGBColor[
             0.239776323432642, 0.3693504969976439, 0.936966278950982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 211}], {
             RGBColor[
             0.24710920905835015`, 0.37705782472206506`, 0.9373838759393338]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 214}], {
             RGBColor[
             0.25603696286442035`, 0.3864414600245297, 0.9378922983111614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 248}], {
             RGBColor[
             0.24516386461647438`, 0.3750131443716921, 0.9372730914512483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 263}], {
             RGBColor[
             0.33214075614847005`, 0.45873834938016844`, 0.9425079759974546]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 312}], {
             RGBColor[
             0.28761893872861966`, 0.41963611907072695`, 0.9396908451152812]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 340}], {
             RGBColor[
             0.23763180163327896`, 0.367096468615978, 0.9368441516070439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 348}], {
             RGBColor[
             0.3027342580511927, 0.4332679187418763, 0.9406342199418414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 167}], {
             RGBColor[
             0.2885245503262027, 0.4204485142001573, 0.9397475246726753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 174}], {
             RGBColor[
             0.3053955889489409, 0.4350613598921163, 0.9408225323352425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.2667189772067604, 0.39766893437715617`, 0.9385006232253336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 222}], {
             RGBColor[
             0.24959037113759353`, 0.3796656833821117, 0.9375251744491964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 226}], {
             RGBColor[
             0.35601753306005335`, 0.4789075435482711, 0.944048117850775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 395}], {
             RGBColor[
             0.36771682090515007`, 0.4886248797144314, 0.9449085278741232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 287}], {
             RGBColor[
             0.19544251078166353`, 0.3227528489753921, 0.9344415339065071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 292}], {
             RGBColor[
             0.19766905263223078`, 0.3250930856312453, 0.9345683321710234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 354}], {
             RGBColor[
             0.20840265875823133`, 0.3363747862196069, 0.9351795951609518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 371}], {
             RGBColor[
             0.1937500929349124, 0.3209740105129675, 0.9343451532138425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 374}], {
             RGBColor[
             0.1955858495365969, 0.322903507095029, 0.9344496968365499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 388}], {
             RGBColor[
             0.21023340989613648`, 0.33829902174187165`, 0.935283853729902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 389}], {
             RGBColor[
             0.20180063292388895`, 0.3294356384750984, 0.934803619556508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 391}], {
             RGBColor[
             0.1910397493801938, 0.3181252675912516, 0.9341908031579952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 182}], {
             RGBColor[
             0.6226406331298818, 0.6984050769847048, 0.9667215385795859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 256}], {
             RGBColor[
             0.624029163944416, 0.6996077525866663, 0.9668100145352584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 281}], {
             RGBColor[
             0.6627187385434833, 0.7331187175098175, 0.9692752800168635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 311}], {
             RGBColor[
             0.5997467789297788, 0.6780206465223158, 0.965283080943369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 328}], {
             RGBColor[
             0.8831401501680374, 0.7104796109326978, 0.6014297849392954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 386}], {
             RGBColor[
             0.8287550787424094, 0.8667695006906301, 0.9834015662110343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 400}], {
             RGBColor[
             0.873464012393198, 0.6536035645465732, 0.5928491209890607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 169}], {
             RGBColor[
             0.9427417968791698, 0.9548740993356628, 0.9051840770091248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 178}], {
             RGBColor[
             0.7156925694809679, 0.7734991059400932, 0.884905461880064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 197}], {
             RGBColor[
             0.9770032019247867, 0.9814553758280588, 0.8828706575837489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.9087289042908429, 0.6022050523179494, 0.4973324699831219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 300}], {
             RGBColor[
             0.9521971792667703, 0.9624135645920178, 0.9060859398221737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 319}], {
             RGBColor[
             0.7215283330281927, 0.7785525624499918, 0.8852776399757938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 174}], {
             RGBColor[
             0.3271254190729118, 0.4577613290244936, 0.9420651203310438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 183}], {
             RGBColor[
             0.33012064304919175`, 0.46035564148841296`, 0.9422559733542398]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 189}], {
             RGBColor[
             0.2884488073307313, 0.4203689035095335, 0.9397432112211349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 222}], {
             RGBColor[
             0.2713202012615644, 0.4023656525144891, 0.9387677624449977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 238}], {
             RGBColor[
             0.3001182809431252, 0.43263426016352036`, 0.9404077704799216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 246}], {
             RGBColor[
             0.6152498673613919, 0.6911955828537762, 0.9666225650716829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 269}], {
             RGBColor[
             0.5269179419290838, 0.6213796361571894, 0.958033512915055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 272}], {
             RGBColor[
             0.5255938312060932, 0.6203452307967748, 0.9579015379327056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 309}], {
             RGBColor[
             0.30392546223642514`, 0.4366358490920146, 0.940624583822355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 395}], {
             RGBColor[
             0.389446651029121, 0.5113248488468087, 0.9461511158699245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 265}], {
             RGBColor[
             0.18709388052696674`, 0.31397790924397473`, 0.9339660917641938]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 304}], {
             RGBColor[
             0.18254777981600245`, 0.3091996691573183, 0.9337071980540577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 378}], {
             RGBColor[
             0.18751181267223727`, 0.3144171824270826, 0.9339898923815917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 177}], {
             RGBColor[
             0.8953206105495907, 0.9193683682944271, 0.9898776731680061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 178}], {
             RGBColor[
             0.668739474081812, 0.7383666179007873, 0.9696437049697588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 197}], {
             RGBColor[
             0.9300501065256308, 0.9463228877887528, 0.9676089006734437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 239}], {
             RGBColor[
             0.8617758088916869, 0.5670725642786435, 0.5820707130728167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 300}], {
             RGBColor[
             0.9052440838676142, 0.9272810765527117, 0.9908241829118685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 319}], {
             RGBColor[
             0.6745752376290368, 0.7434200744106859, 0.9700158830654886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 171}], {
             RGBColor[
             0.21031358554217228`, 0.3383832914292848, 0.9352884196143345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 187}], {
             RGBColor[
             0.33329236872326556`, 0.45597611149735384`, 0.9427190170162062]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 261}], {
             RGBColor[
             0.2458172275622507, 0.3756998702533064, 0.9373102995044464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 299}], {
             RGBColor[
             0.20966330069407968`, 0.3376998008234987, 0.9352513868542458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 306}], {
             RGBColor[
             0.21718838977102684`, 0.3456091465615747, 0.9356799295448063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 353}], {
             RGBColor[
             0.2108426436010009, 0.33893936499333205`, 0.9353185486881135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 361}], {
             RGBColor[
             0.22465020382752957`, 0.3534519862412956, 0.9361048688165594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 299}], {
             RGBColor[
             0.18831247292825637`, 0.31525872712095093`, 0.9340354887987012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 306}], {
             RGBColor[
             0.19583756200520352`, 0.3231680728590269, 0.9344640314892618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 342}], {
             RGBColor[
             0.18633859981298379`, 0.3131840613260155, 0.9339230796448701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 353}], {
             RGBColor[
             0.1894918158351776, 0.3164982912907842, 0.9341026506325689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 208}], {
             RGBColor[
             0.9084092508392714, 0.5876736275457447, 0.4679228968183917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 225}], {
             RGBColor[
             0.8542567503473041, 0.5474377891348923, 0.5796464760848401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 240}], {
             RGBColor[
             0.8277460748309535, 0.21427406632403376`, 0.17420297863381767`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 243}], {
             RGBColor[
             0.8966647112599999, 0.5803804357819402, 0.5534478412456459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 285}], {
             RGBColor[
             0.9090011322761398, 0.5869841292419617, 0.39020330546201376`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 337}], {
             RGBColor[
             0.9089250228286312, 0.5868213388295864, 0.3819192617937752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 357}], {
             RGBColor[
             0.8404518577056951, 0.3119362812088553, 0.18637005066379952`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 399}], {
             RGBColor[
             0.8751896442741957, 0.46528659439177383`, 0.21510344124823602`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 176}], {
             RGBColor[
             0.25807437232061936`, 0.38858290654221544`, 0.9380083257656147]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 209}], {
             RGBColor[
             0.3086611648699239, 0.43934003290171275`, 0.940977513192154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 250}], {
             RGBColor[
             0.27041365894161523`, 0.40155227913684066`, 0.9387110298843417]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 323}], {
             RGBColor[
             0.3405854460382354, 0.4669912406886779, 0.9430117001586653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 354}], {
             RGBColor[
             0.24916626557073213`, 0.3792199215414943, 0.9375010222645717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 388}], {
             RGBColor[
             0.2509970167086373, 0.38114415706375904`, 0.9376052808335218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 183}], {
             RGBColor[
             0.34699168167192995`, 0.474968487180372, 0.943330981016807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 189}], {
             RGBColor[
             0.3053198459534695, 0.4349817492014926, 0.9408182188837021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 238}], {
             RGBColor[
             0.3169893195658634, 0.44724710585547944`, 0.9414827781424888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 246}], {
             RGBColor[
             0.6321209059841302, 0.7058084285457353, 0.96769757273425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 269}], {
             RGBColor[
             0.543788980551822, 0.6359924818491485, 0.9591085205776222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 272}], {
             RGBColor[
             0.5424648698288314, 0.6349580764887339, 0.9589765455952728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 309}], {
             RGBColor[
             0.32079650085916334`, 0.45124869478397367`, 0.9416995914849222]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 325}], {
             RGBColor[
             0.31656779052141654`, 0.4468040521032807, 0.9414587726870038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 395}], {
             RGBColor[
             0.4063176896518592, 0.5259376945387678, 0.9472261235324917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 178}], {
             RGBColor[
             0.3616708025324146, 0.48517771913218966`, 0.9443580450417194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 213}], {
             RGBColor[
             0.25213492118930436`, 0.3823401668202513, 0.9376700828103168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 227}], {
             RGBColor[
             0.24456047357150879`, 0.37437894212623135`, 0.9372387292238745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 278}], {
             RGBColor[
             0.2699086210585896, 0.40102145230052944`, 0.93868226872404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 296}], {
             RGBColor[
             0.26330595896968834`, 0.39408163581213873`, 0.9383062568858402]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 314}], {
             RGBColor[
             0.25716282410855407`, 0.38762481157584006`, 0.9379564144434523]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 319}], {
             RGBColor[
             0.3675065660796395, 0.49023117564208835`, 0.944730223137449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 352}], {
             RGBColor[
             0.2606268889022622, 0.3912657633084208, 0.9381536878088295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 250}], {
             RGBColor[
             0.24600820440775967`, 0.3759005990265677, 0.9373211753532731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 344}], {
             RGBColor[
             0.21245918803275743`, 0.3406384556859449, 0.9354106085020388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 354}], {
             RGBColor[
             0.22476081103687653`, 0.35356824143122134`, 0.936111167733503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 356}], {
             RGBColor[
             0.21433034444536764`, 0.34260515971376704`, 0.9355171680916091]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 372}], {
             RGBColor[
             0.2138686325253813, 0.34211987121163484`, 0.9354908742808075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 388}], {
             RGBColor[
             0.22659156217478169`, 0.35549247695348607`, 0.9362154263024531]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 197}], {
             RGBColor[
             0.9295820155952076, 0.9459496447868232, 0.9675642537426303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 225}], {
             RGBColor[
             0.8897813970600477, 0.9149515498158103, 0.9893493380404593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 243}], {
             RGBColor[
             0.9321893579727436, 0.9478941964628581, 0.9631507032012652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 252}], {
             RGBColor[
             0.6322093663988135, 0.7067582685174405, 0.9673012182198607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 300}], {
             RGBColor[
             0.904775992937191, 0.9269078335507821, 0.990779535981055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 337}], {
             RGBColor[
             0.9444496695413749, 0.9543350995105044, 0.7916221237493946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 367}], {
             RGBColor[
             0.6349673392184779, 0.7091470859540894, 0.9674769538091501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 398}], {
             RGBColor[
             0.6604733814795012, 0.7312391377896288, 0.9691021762679148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 197}], {
             RGBColor[
             0.7030008791274289, 0.7649478943931832, 0.947330285544383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 274}], {
             RGBColor[
             0.46738436670940764`, 0.5781669894131862, 0.9513005905019778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 278}], {
             RGBColor[
             0.349928065209785, 0.47283535767355744`, 0.9436893135230188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 300}], {
             RGBColor[
             0.6781948564694122, 0.7459060831571422, 0.9705455677828076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 319}], {
             RGBColor[
             0.4475260102308348, 0.5620450810151163, 0.9497372679364278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 352}], {
             RGBColor[
             0.3406463330534576, 0.4630796686814488, 0.9431607326078082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 232}], {
             RGBColor[
             0.374520452238133, 0.49753308772821003`, 0.9451360369712756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 257}], {
             RGBColor[
             0.38852623515624984`, 0.5109265218154098, 0.9459822530302189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 275}], {
             RGBColor[
             0.34634920232824207`, 0.46792331791250663`, 0.9435317259645368]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 279}], {
             RGBColor[
             0.5630911384213583, 0.6557241290001397, 0.9590606413690353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 285}], {
             RGBColor[
             0.7240735565365042, 0.7787875887954807, 0.7800674551938157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 288}], {
             RGBColor[
             0.3796596294696894, 0.502934688841232, 0.9454287055118813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 399}], {
             RGBColor[
             0.6902620685345601, 0.6570900539452929, 0.6049675909800379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 198}], {
             RGBColor[
             0.30592577418738304`, 0.43475768207038135`, 0.9408842486890967]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 236}], {
             RGBColor[
             0.2546593406268537, 0.3849934917065525, 0.9378138447627414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 262}], {
             RGBColor[
             0.23634740435871976`, 0.36574648564492557`, 0.9367710070823533]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 267}], {
             RGBColor[
             0.25726504669656514`, 0.3877322539971262, 0.9379622358686148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 284}], {
             RGBColor[
             0.2675710150211928, 0.3985644801424423, 0.9385491455183885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 286}], {
             RGBColor[
             0.22669434503393948`, 0.3556005082552706, 0.9362212796342286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 332}], {
             RGBColor[
             0.2434440031568898, 0.373205460932154, 0.937175147885432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 367}], {
             RGBColor[
             0.31681274319178854`, 0.44418742742702483`, 0.9415779567270888]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 398}], {
             RGBColor[
             0.3423187854528118, 0.46627947926256413`, 0.9432031791858535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 191}], {
             RGBColor[
             0.2010737277844803, 0.3286716150851321, 0.9347622233841785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 211}], {
             RGBColor[
             0.20840661341018846`, 0.33637894280955327`, 0.9351798203725303]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 214}], {
             RGBColor[
             0.21733436721625865`, 0.34576257811201794`, 0.9356882427443579]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 305}], {
             RGBColor[
             0.18857843384879308`, 0.3155382689113313, 0.9340506348796719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 334}], {
             RGBColor[
             0.18995231521735206`, 0.3169823053387968, 0.934128875391136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 340}], {
             RGBColor[
             0.19892920598511726`, 0.3264175867034662, 0.9346400960402405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 365}], {
             RGBColor[
             0.1879270858801807, 0.3148536608984732, 0.9340135415764423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 370}], {
             RGBColor[
             0.19100569805155482`, 0.318089477485873, 0.9341888639852036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 256}], {
             RGBColor[
             0.34992025301800456`, 0.4775050684860661, 0.9435175869933449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 281}], {
             RGBColor[
             0.38860982761707186`, 0.5110160334092172, 0.94598285247495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 311}], {
             RGBColor[
             0.32563786800336725`, 0.45591796242171545`, 0.9419906534014555]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 386}], {
             RGBColor[
             0.5546461678159978, 0.6446668165900299, 0.9601091386691207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 238}], {
             RGBColor[
             0.31998454354214334`, 0.4498414183193987, 0.9416736311656848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 246}], {
             RGBColor[
             0.63511612996041, 0.7084027410096546, 0.967888425757446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 269}], {
             RGBColor[
             0.546784204528102, 0.6385867943130678, 0.9592993736008182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 272}], {
             RGBColor[
             0.5454600938051113, 0.6375523889526532, 0.9591673986184688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 280}], {
             RGBColor[
             0.30076148412422865`, 0.4296367640588081, 0.9405789063698025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 309}], {
             RGBColor[
             0.3237917248354433, 0.45384300724789295`, 0.9418904445081182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 325}], {
             RGBColor[
             0.3195630144976964, 0.44939836456720006`, 0.9416496257101998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 339}], {
             RGBColor[
             0.30076734139659483`, 0.42964292042343744`, 0.9405792399327987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 395}], {
             RGBColor[
             0.40931291362813915`, 0.5285320070026871, 0.9474169765556877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 343}], {
             RGBColor[
             0.18256566753029357`, 0.30921847027918486`, 0.933708216732924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 356}], {
             RGBColor[
             0.18905111217950674`, 0.3160350838064485, 0.9340775532113412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 369}], {
             RGBColor[
             0.1868540625349533, 0.3137258453290297, 0.9339524344843275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 372}], {
             RGBColor[
             0.18858940025952037`, 0.31554979530431626`, 0.9340512594005395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 198}], {
             RGBColor[
             0.3764542800383526, 0.5004875090521163, 0.9452083117319626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 205}], {
             RGBColor[
             0.3748090292582385, 0.49906247551909, 0.9451034778070919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 208}], {
             RGBColor[
             0.6963078073762952, 0.755957556681333, 0.8560508247348155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 210}], {
             RGBColor[
             0.35262704416750634`, 0.4795636552057607, 0.9437005295213796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 219}], {
             RGBColor[
             0.36836286362019555`, 0.4934791308371227, 0.9446927338327562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 249}], {
             RGBColor[
             0.35433837255967027`, 0.48133182157191207`, 0.9437991056637501]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 284}], {
             RGBColor[
             0.33809952087216233`, 0.4642943071241772, 0.9428732085612545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 293}], {
             RGBColor[
             0.374247320413842, 0.49857595155038115`, 0.9450676862162266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 338}], {
             RGBColor[
             0.3169003211264983, 0.4420126040845884, 0.9416659454971446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 188}], {
             RGBColor[
             0.20431810644449144`, 0.33208166276229184`, 0.934946985949238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 228}], {
             RGBColor[
             0.20522346006975262`, 0.3330332468251766, 0.934998544498846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 238}], {
             RGBColor[
             0.24841689496046435`, 0.37843228551726205`, 0.9374583467169113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 273}], {
             RGBColor[
             0.19433831903215518`, 0.3215922734368583, 0.9343786518198778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 322}], {
             RGBColor[
             0.20337835674212623`, 0.3310939262415335, 0.9348934685939234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 330}], {
             RGBColor[
             0.19639093276449526`, 0.3237497006127751, 0.9344955451353647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 206}], {
             RGBColor[
             0.5826167692195937, 0.6701866792756657, 0.9613440852325792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 220}], {
             RGBColor[
             0.5353714211663698, 0.63317812373389, 0.9567035702854296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 261}], {
             RGBColor[
             0.3474451829775207, 0.4708516166188276, 0.9435249988507737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 321}], {
             RGBColor[
             0.494640933100008, 0.6001112786340405, 0.9534971170641517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 228}], {
             RGBColor[
             0.20268995802939208`, 0.3303703755474506, 0.9348542653056278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 238}], {
             RGBColor[
             0.2458833929201038, 0.375769414239536, 0.9373140675236933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 273}], {
             RGBColor[
             0.19180481699179464`, 0.3189294021591323, 0.9342343726266598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 322}], {
             RGBColor[
             0.20084485470176572`, 0.3284310549638075, 0.9347491894007052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 330}], {
             RGBColor[
             0.19385743072413472`, 0.32108682933504906`, 0.9343512659421467]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 222}], {
             RGBColor[
             0.24951462814212214`, 0.379586072691488, 0.937520860997656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 226}], {
             RGBColor[
             0.35594179006458193`, 0.47882793285764735`, 0.9440438043992346]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 395}], {
             RGBColor[
             0.3676410779096787, 0.4885452690238077, 0.9449042144225828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 212}], {
             RGBColor[
             0.6867778683351773, 0.7513832913392242, 0.9534033725466657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 221}], {
             RGBColor[
             0.9292638455200164, 0.8080779972178733, 0.5995947563336426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 255}], {
             RGBColor[
             0.8957903553105804, 0.6198388885195696, 0.570244438982581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 268}], {
             RGBColor[
             0.8177911045280821, 0.8581558703042615, 0.9638348308947651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 270}], {
             RGBColor[
             0.6576592800193992, 0.7261622336829004, 0.951547961847741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 274}], {
             RGBColor[
             0.7246489008143902, 0.7831056857849257, 0.9561147753018562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 295}], {
             RGBColor[
             0.6926270864337125, 0.7564495900659256, 0.953776079551644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 324}], {
             RGBColor[
             0.7946744730052755, 0.8399555999055638, 0.9616274448568455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 351}], {
             RGBColor[
             0.9330043693197932, 0.948887212220239, 0.9751255904637988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 211}], {
             RGBColor[
             0.2145566630341047, 0.342843034899957, 0.9355300566004294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 214}], {
             RGBColor[
             0.2234844168401749, 0.3522266702024217, 0.9360384789722569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 312}], {
             RGBColor[
             0.25506639270437426`, 0.3854213292486189, 0.9378370257763766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 334}], {
             RGBColor[
             0.1961023648412683, 0.3234463974292005, 0.934479111619035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 340}], {
             RGBColor[
             0.2050792556090335, 0.33288167879387, 0.9349903322681394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 365}], {
             RGBColor[
             0.19407713550409694`, 0.321317752988877, 0.9343637778043414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 370}], {
             RGBColor[
             0.19715574767547106`, 0.3245535695762768, 0.9345391002131025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 292}], {
             RGBColor[
             0.18800332047098128`, 0.31493378828695684`, 0.9340178830236096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 320}], {
             RGBColor[
             0.18870690253434044`, 0.31567329764522667`, 0.9340579509812614]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 347}], {
             RGBColor[
             0.18973620095672017`, 0.3167551555484371, 0.9341165680037053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 374}], {
             RGBColor[
             0.18592011737534742`, 0.3127442097507407, 0.933899247689136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 382}], {
             RGBColor[
             0.18175632170203998`, 0.30836779649820095`, 0.9336621256853248]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 384}], {
             RGBColor[
             0.1855895073220066, 0.3123967176227914, 0.933880419935692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 248}], {
             RGBColor[
             0.20247189401375032`, 0.330141176440954, 0.9348418468825339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 305}], {
             RGBColor[
             0.18458905889423072`, 0.311345182893105, 0.933823445877761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 334}], {
             RGBColor[
             0.1859629402627897, 0.3127892193205704, 0.9339016863892251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 360}], {
             RGBColor[
             0.18609708652812662`, 0.31293021555080397`, 0.9339093258205844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 201}], {
             RGBColor[
             0.9717877162352071, 0.9761148093624215, 0.8086618740541351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 208}], {
             RGBColor[
             0.9937734715667986, 0.9910458830658546, 0.7058012226950569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 223}], {
             RGBColor[
             0.9622169086067585, 0.8752522636294204, 0.4543198910461633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 230}], {
             RGBColor[
             0.906134992146644, 0.5640310832233217, 0.4054017460858296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 242}], {
             RGBColor[
             0.9234025469352043, 0.6967570760189528, 0.42193717605226866`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 357}], {
             RGBColor[
             0.9258160784332223, 0.7153085367289651, 0.42424837654046466`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 364}], {
             RGBColor[
             0.9061043939482173, 0.5637958920619978, 0.4053724452164604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 385}], {
             RGBColor[
             0.9944784929138155, 0.9905983795896796, 0.6403962123397537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 387}], {
             RGBColor[
             0.7643288542489235, 0.8116893614464729, 0.8013257295322668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 247}], {
             RGBColor[
             0.1997381438211963, 0.32726783165880646`, 0.9346861638532888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 253}], {
             RGBColor[
             0.1964706167173933, 0.3238334534995253, 0.9345000830186004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 315}], {
             RGBColor[
             0.21034714004508412`, 0.3384185593393235, 0.9352903304936357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 316}], {
             RGBColor[
             0.21810104707830674`, 0.3465684072573414, 0.9357319040283003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 343}], {
             RGBColor[
             0.19193458883998876`, 0.3190658005995948, 0.9342417629414341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 358}], {
             RGBColor[
             0.1963120650172806, 0.3236668056099485, 0.9344910537338352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 359}], {
             RGBColor[
             0.19452611281546262`, 0.321789656609928, 0.9343893463980213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 362}], {
             RGBColor[
             0.1955066853579723, 0.3228203005239958, 0.9344451885536901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 363}], {
             RGBColor[
             0.21087458530257291`, 0.33897293774690507`, 0.9353203677207644]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 369}], {
             RGBColor[
             0.19622298384464848`, 0.3235731756494396, 0.9344859806928376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 372}], {
             RGBColor[
             0.19795832156921558`, 0.32539712562472617`, 0.9345848056090496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 397}], {
             RGBColor[
             0.2073858256728759, 0.33530603017595706`, 0.9351216880210106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 289}], {
             RGBColor[
             0.18795157808443957`, 0.3148794037580448, 0.934014936371242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 317}], {
             RGBColor[
             0.1925447584771704, 0.3197071275752621, 0.9342765111996065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 326}], {
             RGBColor[
             0.19087356510240117`, 0.3179505973785997, 0.9341813392092224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 327}], {
             RGBColor[
             0.19267128104236286`, 0.3198401108132733, 0.9342837164725208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 336}], {
             RGBColor[
             0.18504438325654066`, 0.31182375766712467`, 0.9338493759266024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 376}], {
             RGBColor[
             0.19966869054902864`, 0.32719483186616644`, 0.9346822085921858]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 252}], {
             RGBColor[
             0.6669388623748537, 0.7337127880117662, 0.9450324457252983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 300}], {
             RGBColor[
             0.9395054889132312, 0.9538623530451078, 0.9685107634864926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 205}], {
             RGBColor[
             0.35166297002886326`, 0.47901452236936815`, 0.9436286313802527]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 219}], {
             RGBColor[
             0.34521680439082036`, 0.47343117768740084`, 0.9432178874059169]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 236}], {
             RGBColor[
             0.3020417872484481, 0.43067536553856556`, 0.9406630613787681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 284}], {
             RGBColor[
             0.31495346164278715`, 0.44424635397445533`, 0.9413983621344152]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 332}], {
             RGBColor[
             0.29082644977848415`, 0.41888733476416706`, 0.9400243645014585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 367}], {
             RGBColor[
             0.36419518981338295`, 0.4898693012590379, 0.9444271733431154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 398}], {
             RGBColor[
             0.38970123207440616`, 0.5119613530945772, 0.9460523958018803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 216}], {
             RGBColor[
             0.19310022590756143`, 0.3202909590632723, 0.9343081442480269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 298}], {
             RGBColor[
             0.19174373818706897`, 0.31886520446274574`, 0.9342308942790887]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 299}], {
             RGBColor[
             0.18707599573729403`, 0.31395911119606756`, 0.93396507325188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 306}], {
             RGBColor[
             0.19460108481424115`, 0.32186845693414357`, 0.9343936159424405]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 342}], {
             RGBColor[
             0.18510212262202141`, 0.31188444540113214`, 0.9338526640980489]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 353}], {
             RGBColor[
             0.18825533864421526`, 0.31519867536590085`, 0.9340322350857477]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 361}], {
             RGBColor[
             0.2020628988707439, 0.32971129661386445`, 0.9348185552141937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 393}], {
             RGBColor[
             0.1849265278957996, 0.3116998842105244, 0.9338426642381596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 207}], {
             RGBColor[
             0.1859857863076916, 0.31281323196228517`, 0.9339029874376845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 333}], {
             RGBColor[
             0.18616349406283006`, 0.3130000140802582, 0.9339131076314446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 368}], {
             RGBColor[
             0.18469320535133593`, 0.3114546474227893, 0.9338293768644222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 223}], {
             RGBColor[
             0.9394729571932308, 0.8606549580209606, 0.6167978110210142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 230}], {
             RGBColor[
             0.8833910407331164, 0.5494337776148619, 0.5678796660606804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 245}], {
             RGBColor[
             0.8839369101698967, 0.553629569307468, 0.5684023912498125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 364}], {
             RGBColor[
             0.8833604425346897, 0.5491985864535379, 0.5678503651913112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 385}], {
             RGBColor[
             0.9717345415002878, 0.9760010739812197, 0.8028741323146045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 218}], {
             RGBColor[
             0.2171099632633392, 0.3455267153294672, 0.9356754632712151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 229}], {
             RGBColor[
             0.22512118954774685`, 0.35394702209546336`, 0.9361316907565649]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 260}], {
             RGBColor[
             0.23397057730885262`, 0.3632482897159762, 0.9366356502980638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 307}], {
             RGBColor[
             0.295856931076972, 0.42463269426460054`, 0.9402940731736436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 341}], {
             RGBColor[
             0.2897972028384973, 0.4193840622352309, 0.9399079526486953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 349}], {
             RGBColor[
             0.22267250403179975`, 0.35137329836257414`, 0.9359922417389372]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 366}], {
             RGBColor[
             0.31887937893336776`, 0.4445735814559359, 0.9417610431931018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 232}], {
             RGBColor[
             0.26042493590475796`, 0.3910534979034842, 0.9381421868843842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 257}], {
             RGBColor[
             0.27443071882287484`, 0.40444693199068393`, 0.9389884029433275]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 275}], {
             RGBColor[
             0.232253685994867, 0.3614437280877808, 0.9365378758776455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 280}], {
             RGBColor[
             0.23864655232395315`, 0.36816303593078636`, 0.9369019401576887]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 297}], {
             RGBColor[
             0.2163387830881471, 0.3447161560696932, 0.9356315457010966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 309}], {
             RGBColor[
             0.2616767930351678, 0.3923692791198713, 0.9382134782960043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 322}], {
             RGBColor[
             0.2128310735235297, 0.3410293309156486, 0.935431786830583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 325}], {
             RGBColor[
             0.2574480826974209, 0.38792463643917835`, 0.9379726594980861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 339}], {
             RGBColor[
             0.23865240959631934`, 0.3681691922954158, 0.9369022737206849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 224}], {
             RGBColor[
             0.1864844568543232, 0.3133373663243338, 0.9339313859875982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 276}], {
             RGBColor[
             0.2082458481435212, 0.33620996832117933`, 0.9351706650284246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 290}], {
             RGBColor[
             0.19592590704111568`, 0.32326092909316934`, 0.9344690626083623]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 297}], {
             RGBColor[
             0.2002775476373886, 0.32783477926980176`, 0.9347168821026446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 318}], {
             RGBColor[
             0.1940125074344074, 0.321249824789977, 0.9343600973313813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 345}], {
             RGBColor[
             0.18631088399028722`, 0.3131549302390768, 0.9339215012697695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 219}], {
             RGBColor[
             0.34357155361070624`, 0.4720061441543746, 0.9431130534810463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 284}], {
             RGBColor[
             0.313308210862673, 0.4428213204414291, 0.9412935282095445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 293}], {
             RGBColor[
             0.3494560104043527, 0.47710296486763304`, 0.9434880058645166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 338}], {
             RGBColor[
             0.292109011117009, 0.4205396174018403, 0.9400862651454345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 220}], {
             RGBColor[
             0.6830678662474279, 0.7522369451466808, 0.9691139391554754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 321}], {
             RGBColor[
             0.6423373781810662, 0.7191701000468311, 0.9659074859341975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 328}], {
             RGBColor[
             0.7999219852902167, 0.6448484807342735, 0.5933000289298582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 386}], {
             RGBColor[
             0.7455369138645886, 0.8011383704922057, 0.975271810201597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 254}], {
             RGBColor[
             0.18750231875154622`, 0.3144072037144869, 0.9339893517168534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 333}], {
             RGBColor[
             0.18793493502051017`, 0.3148619108426237, 0.9340139885733725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 230}], {
             RGBColor[
             0.9053767960647079, 0.5643648513182951, 0.465019014701602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 240}], {
             RGBColor[
             0.9123520994765446, 0.6179800899391169, 0.47169857312625524`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 242}], {
             RGBColor[
             0.9226443508532682, 0.6970908441139261, 0.4815544446680411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 357}], {
             RGBColor[
             0.9250578823512863, 0.7156423048239384, 0.4838656451562371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 385}], {
             RGBColor[
             0.9937202968318795, 0.9909321476846529, 0.7000134809555262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 387}], {
             RGBColor[
             0.7635706581669874, 0.8120231295414462, 0.8609429981480392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 241}], {
             RGBColor[
             0.2990278699570904, 0.4292148291621499, 0.9404289112980508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 270}], {
             RGBColor[
             0.34697087401529814`, 0.4749504646340207, 0.9433296551713259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 310}], {
             RGBColor[
             0.30722079620017617`, 0.4378261141051596, 0.9408954863272463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 323}], {
             RGBColor[
             0.36676678405368435`, 0.4920966869379023, 0.9445910330541359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 346}], {
             RGBColor[
             0.34295446203942725`, 0.47147165045125694`, 0.9430737329517971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 390}], {
             RGBColor[
             0.2987767120225358, 0.42895084624860025`, 0.9404146082252327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 249}], {
             RGBColor[
             0.3073650774594488, 0.4403600145758346, 0.9408164770263279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 266}], {
             RGBColor[
             0.26920304414348, 0.40027984622658896`, 0.9386420871625321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 293}], {
             RGBColor[
             0.3272740253136205, 0.45760414455430376`, 0.9420850575788042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 315}], {
             RGBColor[
             0.26224986664151034`, 0.39297161581510254`, 0.9382461139900993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 316}], {
             RGBColor[
             0.270003773674733, 0.40112146373312046`, 0.9386876875247638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 387}], {
             RGBColor[
             0.4198898949581986, 0.5356292280658739, 0.9485927029346032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 397}], {
             RGBColor[
             0.25928855226930214`, 0.38985908665173613`, 0.938077471517474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 214}], {
             RGBColor[
             0.23081730246588306`, 0.35993399792684283`, 0.9364560759606089]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 248}], {
             RGBColor[
             0.2199442042179371, 0.34850568227400514`, 0.9358368691006957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 263}], {
             RGBColor[
             0.30692109574993276`, 0.4322308872824815, 0.9410717536469021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 312}], {
             RGBColor[
             0.26239927833008236`, 0.39312865697304, 0.9382546227647286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 334}], {
             RGBColor[
             0.20343525046697647`, 0.3311537251536216, 0.9348967086073869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 340}], {
             RGBColor[
             0.21241214123474167`, 0.34058900651829105`, 0.9354079292564914]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 370}], {
             RGBColor[
             0.20448863330117922`, 0.3322608973006979, 0.9349566972014545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 268}], {
             RGBColor[
             0.5483496579696843, 0.6426701443947892, 0.9582447440009759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 270}], {
             RGBColor[
             0.38821783346100136`, 0.5106765077734281, 0.9459578749539519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 274}], {
             RGBColor[
             0.45520745425599235`, 0.5676199598754534, 0.950524688408067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 295}], {
             RGBColor[
             0.42318563987531466`, 0.5409638641564534, 0.9481859926578549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 310}], {
             RGBColor[
             0.34846775564587945`, 0.473552157244567, 0.9435237061098725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 324}], {
             RGBColor[
             0.5252330264468776, 0.6244698739960914, 0.9560373579630563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 351}], {
             RGBColor[
             0.6635629227613954, 0.7334014863107667, 0.9695355035700097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 373}], {
             RGBColor[
             0.34459378761093823`, 0.4694803712160838, 0.9433030893613046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 390}], {
             RGBColor[
             0.3400236714682391, 0.46467688938800766`, 0.9430428280078589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 227}], {
             RGBColor[
             0.2150440363795939, 0.343355295187321, 0.9355578117914507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 296}], {
             RGBColor[
             0.2337895217777734, 0.3630579888732283, 0.9366253394534165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 308}], {
             RGBColor[
             0.2120594900785835, 0.3402183477937941, 0.9353878462948488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 352}], {
             RGBColor[
             0.23111045171034733`, 0.3602421163695104, 0.9364727703764056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 248}], {
             RGBColor[
             0.22887195802400728`, 0.3578893175764699, 0.9363452914725232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 263}], {
             RGBColor[
             0.315848849556003, 0.4416145225849462, 0.9415801760187297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 312}], {
             RGBColor[
             0.2713270321361526, 0.4025122922755047, 0.9387630451365561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 340}], {
             RGBColor[
             0.22133989504081186`, 0.3499726418207558, 0.9359163516283189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 218}], {
             RGBColor[
             0.18692850160935742`, 0.31380408551593836`, 0.9339566736794921]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 229}], {
             RGBColor[
             0.19493972789376507`, 0.3222243922819345, 0.9344129011648419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 329}], {
             RGBColor[
             0.1867198905000643, 0.313584822013363, 0.9339447935854304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 349}], {
             RGBColor[
             0.192491042377818, 0.3196506685490453, 0.9342734521472142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 231}], {
             RGBColor[
             0.19095180161373265`, 0.3180328289124904, 0.9341857946628023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 235}], {
             RGBColor[
             0.1956123156574894, 0.32293132466613605`, 0.9344512040429815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 298}], {
             RGBColor[
             0.19835416070020614`, 0.3258131776490477, 0.9346073480619681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 313}], {
             RGBColor[
             0.2090389311379428, 0.3370435488326826, 0.9352158299316957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 361}], {
             RGBColor[
             0.20867332138388106`, 0.3366592698001664, 0.9351950089970731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 393}], {
             RGBColor[
             0.19153695040893678`, 0.31864785739682644`, 0.9342191180210391]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 396}], {
             RGBColor[
             0.19963425463605258`, 0.3271586375382656, 0.9346802475178853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 220}], {
             RGBColor[
             0.8144460532518553, 0.851406632354037, 0.7257595325601884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 230}], {
             RGBColor[
             0.9054039524770299, 0.5624674632894656, 0.3258325895022128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 233}], {
             RGBColor[
             0.9762379710154455, 0.9784153903456743, 0.7203221374649382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 242}], {
             RGBColor[
             0.9226715072655902, 0.6951934560850966, 0.34236801946865186`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 244}], {
             RGBColor[
             0.9739175055905028, 0.9766847910311653, 0.7242500801550553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 264}], {
             RGBColor[
             0.8581806271651595, 0.8856725444548357, 0.7300501263511203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 321}], {
             RGBColor[
             0.7737155651854934, 0.8183397872541874, 0.7225530793389106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 357}], {
             RGBColor[
             0.9250850387636083, 0.713744916795109, 0.34467921995684786`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 364}], {
             RGBColor[
             0.9053733542786032, 0.5622322721281416, 0.3258032886328436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 366}], {
             RGBColor[
             0.6937344954214235, 0.7518077736561808, 0.7166986999905727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 229}], {
             RGBColor[
             0.19887179747769093`, 0.3263572467222515, 0.9346368267106708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 260}], {
             RGBColor[
             0.20772118523879674`, 0.3356585143427644, 0.9351407862521698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 329}], {
             RGBColor[
             0.19065196008399016`, 0.31771767645368004`, 0.9341687191312593]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 349}], {
             RGBColor[
             0.19642311196174383`, 0.3237835229893623, 0.9344973776930432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 284}], {
             RGBColor[
             0.3068620452246301, 0.43723797575946177`, 0.9408827842352088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 293}], {
             RGBColor[
             0.34300984476630975`, 0.47151962018566573`, 0.943077261890181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 338}], {
             RGBColor[
             0.28566284547896603`, 0.414956272719873, 0.9396755211710989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 233}], {
             RGBColor[
             0.7976144359577942, 0.8422371475965424, 0.9590360291130758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 244}], {
             RGBColor[
             0.7952939705328516, 0.8405065482820335, 0.9629639718031929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 321}], {
             RGBColor[
             0.5950920301278422, 0.6821615445050555, 0.961266970987048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 341}], {
             RGBColor[
             0.4860287842689018, 0.590440011686344, 0.9535595010943037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 366}], {
             RGBColor[
             0.5151109603637722, 0.615629530907049, 0.9554125916387102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 239}], {
             RGBColor[
             0.8650356462249088, 0.43184524722399015`, 0.20720757963682196`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 255}], {
             RGBColor[
             0.8688348859370216, 0.46104786848874635`, 0.21084573587576866`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 268}], {
             RGBColor[
             0.7908356351545234, 0.6993648502734382, 0.6044361277879526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 324}], {
             RGBColor[
             0.7677190036317167, 0.6811645798747406, 0.602228741750033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 351}], {
             RGBColor[
             0.9060488999462345, 0.7900961921894157, 0.6157268873569864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 400}], {
             RGBColor[
             0.8762434284382803, 0.5179931725974458, 0.21794016454172604`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 333}], {
             RGBColor[
             0.21024933242430197`, 0.33831575732852015`, 0.9352847604943257]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 230}], {
             RGBColor[
             0.8738202331046678, 0.44857123188186093`, 0.21353768305270848`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 242}], {
             RGBColor[
             0.8910877878932282, 0.5812972246774919, 0.23007311301914762`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 245}], {
             RGBColor[
             0.8743661025414482, 0.452767023574467, 0.2140604082418407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 328}], {
             RGBColor[
             0.8997164529222819, 0.6301219365340252, 0.23765071588506692`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 364}], {
             RGBColor[
             0.8737896349062411, 0.4483360407205369, 0.2135083821833393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 385}], {
             RGBColor[
             0.9621637338718393, 0.8751385282482187, 0.44853214930663265`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 290}], {
             RGBColor[
             0.18877579274929696`, 0.3157457056290379, 0.9340618741770893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 318}], {
             RGBColor[
             0.18686239314258873`, 0.3137346013258456, 0.9339529089001083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 345}], {
             RGBColor[
             0.17916076969846856`, 0.3056397067749454, 0.9335143128384965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 240}], {
             RGBColor[
             0.8581995989845774, 0.5777442515282645, 0.5834221523927036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 243}], {
             RGBColor[
             0.9271182354136238, 0.9438506209861709, 0.9626670150045318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 337}], {
             RGBColor[
             0.9393785469822551, 0.9502915240338172, 0.7911384355526612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 367}], {
             RGBColor[
             0.6298962166593582, 0.7051035104774022, 0.9669932656124167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 398}], {
             RGBColor[
             0.6554022589203814, 0.7271955623129416, 0.9686184880711814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 234}], {
             RGBColor[
             0.6154815427973135, 0.6962991925345092, 0.964434228392668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 281}], {
             RGBColor[
             0.43696413947427415`, 0.552898107981546, 0.9490639464684518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 350}], {
             RGBColor[
             0.7195454075725961, 0.7758957836327975, 0.8505842343054555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 355}], {
             RGBColor[
             0.6054737407452027, 0.6884810215092875, 0.963436744212341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 392}], {
             RGBColor[
             0.7181621296927883, 0.7753237626808771, 0.8735087285822702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 395}], {
             RGBColor[
             0.45693963376297164`, 0.5697838781949226, 0.9504517090480242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 296}], {
             RGBColor[
             0.22621507415997788`, 0.35509676417920844`, 0.9361939858669741]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 308}], {
             RGBColor[
             0.20448504246078797`, 0.33225712309977423`, 0.9349564927084064]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 352}], {
             RGBColor[
             0.22353600409255178`, 0.3522808916754905, 0.9360414167899633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 375}], {
             RGBColor[
             0.1940331226429612, 0.32127149268124666`, 0.9343612713370109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 238}], {
             RGBColor[
             0.24678874654536498`, 0.3767209983024208, 0.9373656260733012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 273}], {
             RGBColor[
             0.1927101706170558, 0.31988098622201705`, 0.9342859311762677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 330}], {
             RGBColor[
             0.1947627843493959, 0.3220384133979338, 0.9344028244917546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 368}], {
             RGBColor[
             0.19438368850365684`, 0.3216399596279972, 0.9343812355441619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 260}], {
             RGBColor[
             0.21573241152320438`, 0.34407882110876054`, 0.9355970137375196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[
             0.1986631863683978, 0.3261379832196762, 0.934624946616609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 349}], {
             RGBColor[
             0.20443433824615148`, 0.33220382975535845`, 0.934953605178393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 233}], {
             RGBColor[
             0.8885723351829689, 0.5532979785319709, 0.5591090860551002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 242}], {
             RGBColor[
             0.8350058714331137, 0.2700760442713933, 0.18115496805881381`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 244}], {
             RGBColor[
             0.8862518697580262, 0.551567379217462, 0.5630370287452173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 245}], {
             RGBColor[
             0.8182841860813337, 0.14154584316836838`, 0.16514226328150688`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 328}], {
             RGBColor[
             0.8436345364621675, 0.31890075612792645`, 0.1887325709247331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 357}], {
             RGBColor[
             0.8374194029311317, 0.28862750498140566`, 0.18346616854700978`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 364}], {
             RGBColor[
             0.8177077184461266, 0.13711486031443826`, 0.16459023722300553`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 385}], {
             RGBColor[
             0.9060818174117249, 0.56391734784212, 0.3996140043462989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 235}], {
             RGBColor[
             0.18685346885052345`, 0.3137252213290522, 0.9339524006748775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 298}], {
             RGBColor[
             0.1895953138932402, 0.3166070743119639, 0.934108544693864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 336}], {
             RGBColor[
             0.1812731232878139, 0.3078599243283004, 0.9336346082504626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 393}], {
             RGBColor[
             0.18277810360197083`, 0.30944175405974256`, 0.933720314652935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 396}], {
             RGBColor[
             0.19087540782908663`, 0.31795253420118175`, 0.9341814441497811]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 257}], {
             RGBColor[
             0.30909861267997385`, 0.4408850865059202, 0.9409626882119364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 275}], {
             RGBColor[
             0.2669215798519661, 0.39788188260301705`, 0.9385121611462544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 279}], {
             RGBColor[
             0.48366351594508233`, 0.5856826936906501, 0.9540410765507529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 280}], {
             RGBColor[
             0.2733144461810522, 0.4046011904460226, 0.9388762254262976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 288}], {
             RGBColor[
             0.30023200699341346`, 0.43289325353174246`, 0.9404091406935988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 297}], {
             RGBColor[
             0.25100667694524614`, 0.38115431058492943`, 0.9376058309697055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 309}], {
             RGBColor[
             0.2963446868922668, 0.42880743363510754`, 0.9401877635646132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 325}], {
             RGBColor[
             0.29211597655452004`, 0.4243627909544146, 0.9399469447666949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 339}], {
             RGBColor[
             0.2733203034534184, 0.404607346810652, 0.9388765589892938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 242}], {
             RGBColor[
             0.9058398899715292, 0.686023971327602, 0.5756445160215393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 244}], {
             RGBColor[
             0.9570858882964418, 0.9675153062736708, 0.9575265767079428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 264}], {
             RGBColor[
             0.8413490098710985, 0.8765030596973409, 0.9633266229040078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 307}], {
             RGBColor[
             0.6538804302709667, 0.7226974017073509, 0.9485082265240019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 348}], {
             RGBColor[
             0.6462730001834412, 0.7161082281260901, 0.948023487805811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 357}], {
             RGBColor[
             0.9082534214695472, 0.7045754320376143, 0.5779557165097353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 366}], {
             RGBColor[
             0.6769028781273625, 0.7426382888986862, 0.9499751965434602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[
             0.8067428279900561, 0.5234676801505931, 0.5767481319037369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 246}], {
             RGBColor[
             0.8529840469746812, 0.885887262707637, 0.9857660876177745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 269}], {
             RGBColor[
             0.7646521215423732, 0.8160713160110501, 0.9771770354611466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 272}], {
             RGBColor[
             0.7633280108193825, 0.8150369106506357, 0.9770450604787972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 350}], {
             RGBColor[
             0.8897866044520348, 0.9121284341385445, 0.8654271636734474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 355}], {
             RGBColor[
             0.7757149376246414, 0.8247136720150343, 0.978279673580333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 392}], {
             RGBColor[
             0.888403326572227, 0.9115564131866241, 0.8883516579502622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 395}], {
             RGBColor[
             0.6271808306424103, 0.7060165287006694, 0.9652946384160161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 298}], {
             RGBColor[
             0.19425582793699694`, 0.3215055700656095, 0.9343739540740432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 313}], {
             RGBColor[
             0.2049405983747336, 0.3327359412492443, 0.9349824359437711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 317}], {
             RGBColor[
             0.19343401255220036`, 0.32064178999008336`, 0.934327152903646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 336}], {
             RGBColor[
             0.18593363733157064`, 0.312758420081946, 0.9339000176306419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 393}], {
             RGBColor[
             0.18743861764572758`, 0.31434024981338815`, 0.9339857240331143]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 396}], {
             RGBColor[
             0.19553592187284338`, 0.32285102995482734`, 0.9344468535299604]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 267}], {
             RGBColor[
             0.25338105975763014`, 0.38364993746531034`, 0.9377410485582862]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 284}], {
             RGBColor[
             0.26368702808225786`, 0.3944821636106265, 0.9383279582080599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 286}], {
             RGBColor[
             0.22281035809500455`, 0.3515181917234548, 0.9360000923239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 332}], {
             RGBColor[
             0.2395600162179548, 0.36912314440033817`, 0.9369539605751034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 367}], {
             RGBColor[
             0.3129287562528536, 0.440105110895209, 0.9413567694167602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 383}], {
             RGBColor[
             0.22956462143722656`, 0.3586173507411603, 0.9363847376292023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 398}], {
             RGBColor[
             0.3384347985138768, 0.4621971627307483, 0.9429819918755249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 251}], {
             RGBColor[
             0.19380336074719554`, 0.32102999836105145`, 0.9343481867369493]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 296}], {
             RGBColor[
             0.2211466738327187, 0.34976955408011773`, 0.935905347966363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 308}], {
             RGBColor[
             0.19941664213352878`, 0.3269299130006835, 0.9346678548077954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 380}], {
             RGBColor[
             0.20872851353399335`, 0.33671728024931885`, 0.9351981521083725]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 269}], {
             RGBColor[
             0.5167818424220354, 0.6108654129881752, 0.9574511707265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 272}], {
             RGBColor[
             0.5154577316990447, 0.6098310076277607, 0.9573191957441505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 280}], {
             RGBColor[
             0.2707591220181621, 0.40191538273391547`, 0.9387307034954844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 309}], {
             RGBColor[
             0.29378936272937667`, 0.4261216259230004, 0.9400422416338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 325}], {
             RGBColor[
             0.28956065239162987`, 0.42167698324230746`, 0.9398014228358818]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 339}], {
             RGBColor[
             0.27076497929052823`, 0.4019215390985449, 0.9387310370584805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 246}], {
             RGBColor[
             0.874004135287985, 0.576823099817974, 0.5832370617608514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 269}], {
             RGBColor[
             0.785672209855677, 0.5070071531213871, 0.5746480096042236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 272}], {
             RGBColor[
             0.7843480991326863, 0.5059727477609727, 0.5745160346218742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 350}], {
             RGBColor[
             0.9108066927653387, 0.6030642712488816, 0.46289813781652445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 355}], {
             RGBColor[
             0.7967350259379453, 0.5156495091253714, 0.57575064772341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 392}], {
             RGBColor[
             0.9094234148855309, 0.6024922502969611, 0.4858226320933391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 242}], {
             RGBColor[
             0.8419811748449504, 0.32369128289221516`, 0.18783452648346705`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 243}], {
             RGBColor[
             0.9006075598972731, 0.6106868981753124, 0.5572235175535094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 285}], {
             RGBColor[
             0.912943980913413, 0.617290591635334, 0.3939789817698772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 337}], {
             RGBColor[
             0.9128678714659045, 0.6171278012229586, 0.3856949381016387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 357}], {
             RGBColor[
             0.8443947063429684, 0.3422427436022275, 0.19014572697166301`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 399}], {
             RGBColor[
             0.879132492911469, 0.49559305678514604`, 0.2188791175560995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 270}], {
             RGBColor[
             0.31115624108701556`, 0.43971981464523346`, 0.9412017203817521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 310}], {
             RGBColor[
             0.2714061632718937, 0.40259546411637237`, 0.9387675515376726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 323}], {
             RGBColor[
             0.3309521511254019, 0.4568660369491151, 0.9424630982645621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 346}], {
             RGBColor[
             0.30713982911114474`, 0.4362410004624697, 0.9409457981622233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 389}], {
             RGBColor[
             0.23293094482355622`, 0.362155570057423, 0.9365764447660246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 390}], {
             RGBColor[
             0.2629620790942533, 0.393720196259813, 0.938286673435659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 244}], {
             RGBColor[
             0.9035194245465865, 0.684293372013093, 0.5795724587116564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 357}], {
             RGBColor[
             0.854686957719692, 0.4213534977770367, 0.2000015985134489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 364}], {
             RGBColor[
             0.8349752732346869, 0.2698408531100693, 0.18112566718944462`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 385}], {
             RGBColor[
             0.9233493722002852, 0.696643340637751, 0.416149434312738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 337}], {
             RGBColor[
             0.981786507894951, 0.983234170680865, 0.764939800713467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 367}], {
             RGBColor[
             0.6723041775720541, 0.7380461571244501, 0.9407946307732227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 398}], {
             RGBColor[
             0.6978102198330773, 0.7601382089599893, 0.9424198532319874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 264}], {
             RGBColor[
             0.8390285444461558, 0.8747724603828321, 0.9672545655941249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 307}], {
             RGBColor[
             0.651559964846024, 0.7209668023928419, 0.952436169214119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 321}], {
             RGBColor[
             0.7545634824664897, 0.8074397031821838, 0.959757518581915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 341}], {
             RGBColor[
             0.6455002366075493, 0.7157181703634723, 0.9520500486891706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 348}], {
             RGBColor[
             0.6439525347584986, 0.7143776288115813, 0.9519514304959281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 357}], {
             RGBColor[
             0.9059329560446046, 0.7028448327231054, 0.5818836591998524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 366}], {
             RGBColor[
             0.6745824127024198, 0.7409076895841773, 0.9539031392335773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 328}], {
             RGBColor[
             0.8441804058989478, 0.32309654782053254`, 0.18925529611386532`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 364}], {
             RGBColor[
             0.8182535878829069, 0.14131065200704435`, 0.16511296241213771`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 400}], {
             RGBColor[
             0.8345042681241085, 0.26622050143440795`, 0.18067463216363056`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 269}], {
             RGBColor[
             0.8319134288403021, 0.869426735678431, 0.9836659653182612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 272}], {
             RGBColor[
             0.8305893181173114, 0.8683923303180165, 0.9835339903359117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 350}], {
             RGBColor[
             0.9570479117499637, 0.9654838538059254, 0.8719160935305621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 355}], {
             RGBColor[
             0.8429762449225704, 0.8780690916824152, 0.9847686034374477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 392}], {
             RGBColor[
             0.955664633870156, 0.964911832854005, 0.8948405878073766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 395}], {
             RGBColor[
             0.6944421379403393, 0.7593719483680503, 0.9717835682731306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 253}], {
             RGBColor[
             0.19436046466415727`, 0.3216155499002067, 0.9343799129808589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 266}], {
             RGBColor[
             0.21519016549381775`, 0.3435088861514912, 0.9355661336283271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 301}], {
             RGBColor[
             0.1901623548072361, 0.317203070265044, 0.9341408368350541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 315}], {
             RGBColor[
             0.2082369879918481, 0.3362006557400048, 0.9351701604558942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 316}], {
             RGBColor[
             0.21599089502507074`, 0.3443505036580227, 0.9356117339905587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 343}], {
             RGBColor[
             0.18982443678675276`, 0.31684789700027605`, 0.9341215929036926]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 358}], {
             RGBColor[
             0.19420191296404457`, 0.3214489020106298, 0.9343708836960937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 359}], {
             RGBColor[
             0.1924159607622266, 0.31957175301060936`, 0.9342691763602797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 362}], {
             RGBColor[
             0.19339653330473627`, 0.32060239692467707`, 0.9343250185159485]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 363}], {
             RGBColor[
             0.20876443324933688`, 0.3367550341475864, 0.9352001976830229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 369}], {
             RGBColor[
             0.19411283179141248`, 0.32135527205012093`, 0.934365810655096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 397}], {
             RGBColor[
             0.20527567361963986`, 0.3330881265766384, 0.935001517983269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 276}], {
             RGBColor[
             0.22042799245848094`, 0.3490141743887628, 0.9358644201252941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 340}], {
             RGBColor[
             0.2104667967928659, 0.33854432616791813`, 0.9352971447684058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 360}], {
             RGBColor[
             0.20162405229043762`, 0.3292500410334822, 0.9347935635506606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 266}], {
             RGBColor[
             0.270914372535644, 0.40204801259274037`, 0.9387406633049027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 293}], {
             RGBColor[
             0.3289853537057845, 0.45937231092045516`, 0.9421836337211749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 315}], {
             RGBColor[
             0.2639611950336743, 0.39473978218125394`, 0.9383446901324698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 316}], {
             RGBColor[
             0.271715102066897, 0.4028896300992718, 0.9387862636671344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 387}], {
             RGBColor[
             0.4216012233503626, 0.5373973944320252, 0.9486912790769737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 397}], {
             RGBColor[
             0.26099988066146607`, 0.3916272530178875, 0.9381760476598446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 356}], {
             RGBColor[
             0.22666963106636354`, 0.3555745323083922, 0.9362198722103361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 363}], {
             RGBColor[
             0.2391241828797345, 0.3686650559284389, 0.9369291405112493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 372}], {
             RGBColor[
             0.22620791914637717`, 0.35508924380626006`, 0.9361935783995345]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 283}], {
             RGBColor[
             0.19962713488925782`, 0.32715115423296626`, 0.934679842058838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 308}], {
             RGBColor[
             0.1958872147734443, 0.3232202610666153, 0.9344668591409584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 380}], {
             RGBColor[
             0.20519908617390886`, 0.3330076283152506, 0.9349971564415356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 381}], {
             RGBColor[
             0.19321867549075944`, 0.3204154570853507, 0.9343148897765596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 282}], {
             RGBColor[
             0.31835440977210794`, 0.4463178036126423, 0.941647079240882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 300}], {
             RGBColor[
             0.6421328397168371, 0.7146709767757251, 0.9682477279637229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 367}], {
             RGBColor[
             0.372324185998124, 0.4969102291790325, 0.9449451457918181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 398}], {
             RGBColor[
             0.39783022825914727`, 0.5190022810145718, 0.9465703682505828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 266}], {
             RGBColor[
             0.21192263839001468`, 0.3400745079922101, 0.9353800527936387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 301}], {
             RGBColor[
             0.18689482770343305`, 0.31376869210576286`, 0.9339547560003658]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 315}], {
             RGBColor[
             0.20496946088804507`, 0.3327662775807237, 0.9349840796212059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 316}], {
             RGBColor[
             0.2127233679212677, 0.3409161254987416, 0.9354256531558705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 343}], {
             RGBColor[
             0.18655690968294972`, 0.31341351884099494`, 0.9339355120690042]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 358}], {
             RGBColor[
             0.19093438586024153`, 0.31801452385134865`, 0.9341848028614053]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 359}], {
             RGBColor[
             0.18914843365842357`, 0.3161373748513282, 0.9340830955255912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 362}], {
             RGBColor[
             0.19012900620093326`, 0.31716801876539596`, 0.9341389376812601]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 369}], {
             RGBColor[
             0.19084530468760944`, 0.3179208938908398, 0.9341797298204076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 394}], {
             RGBColor[
             0.1857625991924869, 0.31257864815332465`, 0.9338902772616493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 397}], {
             RGBColor[
             0.20200814651583682`, 0.3296537484173573, 0.9348154371485806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 303}], {
             RGBColor[
             0.20024144683233963`, 0.3277968350347721, 0.9347148262152034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 268}], {
             RGBColor[
             0.7573621449450872, 0.5111257415751345, 0.5750858104368912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 324}], {
             RGBColor[
             0.7342455134222807, 0.4929254711764368, 0.5728784243989717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 328}], {
             RGBColor[
             0.8524460760036836, 0.3866301102852666, 0.1971705111408994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 351}], {
             RGBColor[
             0.8725754097367984, 0.601857083491112, 0.5863765700059249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 400}], {
             RGBColor[
             0.8427699382288443, 0.329754063899142, 0.18858984719066463`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 311}], {
             RGBColor[
             0.32702639881790146`, 0.45712063802367703`, 0.942079129357128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 313}], {
             RGBColor[
             0.28483799884386285`, 0.41277795475190926`, 0.9396765623907513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 386}], {
             RGBColor[
             0.556034698630532, 0.6458694921919914, 0.9601976146247932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 275}], {
             RGBColor[
             0.2809273627700829, 0.4112753166902168, 0.9393583772051975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 276}], {
             RGBColor[
             0.27298076036949565`, 0.4029229337235066, 0.9389058299544288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 279}], {
             RGBColor[
             0.4976692988631992, 0.5990761277778498, 0.9548872926096961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 280}], {
             RGBColor[
             0.2873202290991691, 0.41799462453322234`, 0.9397224414852408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 288}], {
             RGBColor[
             0.3142377899115303, 0.4462866876189422, 0.9412553567525421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 309}], {
             RGBColor[
             0.31035046981038367`, 0.4422008677223072, 0.9410339796235565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 325}], {
             RGBColor[
             0.30612175947263687`, 0.43775622504161427`, 0.9407931608256381]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 339}], {
             RGBColor[
             0.2873260863715352, 0.41800078089785175`, 0.939722775048237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 277}], {
             RGBColor[
             0.19561158896014919`, 0.3229305608611562, 0.9344511626586431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 302}], {
             RGBColor[
             0.18739149065206478`, 0.3142907163550246, 0.9339830402205433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 377}], {
             RGBColor[
             0.18407204095648846`, 0.3108017642597073, 0.933794002471066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 378}], {
             RGBColor[
             0.18711323001988966`, 0.3139982467878655, 0.9339671936891907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 379}], {
             RGBColor[
             0.19525485067885182`, 0.32255560630899927`, 0.9344308469412701]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 262}], {
             RGBColor[
             0.20019420515358305`, 0.3277471810351035, 0.934712135871486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 331}], {
             RGBColor[
             0.19269223822101744`, 0.31986213813680114`, 0.934284909952842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 335}], {
             RGBColor[
             0.18286996403264408`, 0.3095383051966678, 0.9337255459685665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 307}], {
             RGBColor[
             0.28646815305242945`, 0.41476449327789777`, 0.9397593961545982]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 329}], {
             RGBColor[
             0.20751257412950358`, 0.3354392508401891, 0.9351289061581081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 341}], {
             RGBColor[
             0.2804084248139549, 0.4095158612485281, 0.93937327562965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 349}], {
             RGBColor[
             0.21328372600725728`, 0.3415050973758713, 0.9354575647198919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 366}], {
             RGBColor[
             0.3094906009088253, 0.4347053804692331, 0.9412263661740565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 306}], {
             RGBColor[
             0.2313412040252819, 0.36048465168304844`, 0.9364859113793738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 284}], {
             RGBColor[
             0.24537509181412387`, 0.37523515754899955`, 0.9372851205276718]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 286}], {
             RGBColor[
             0.20449842182687056`, 0.3322711856618279, 0.9349572546435119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 331}], {
             RGBColor[
             0.20664951421908523`, 0.3345321201531805, 0.9350797561729924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 332}], {
             RGBColor[
             0.22124807994982085`, 0.34987613833871123`, 0.9359111228947152]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 338}], {
             RGBColor[
             0.22417589206845978`, 0.35295345450941085`, 0.9360778574635618]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 264}], {
             RGBColor[
             0.5576221544304325, 0.6488358128735436, 0.9596252327476064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 312}], {
             RGBColor[
             0.3474308254202023, 0.4748091816311434, 0.9433787228228494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 348}], {
             RGBColor[
             0.36254614474277536`, 0.48844098130229274`, 0.9443220976494096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 307}], {
             RGBColor[
             0.5358230864206805, 0.6299545558165122, 0.958236215410184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 312}], {
             RGBColor[
             0.5131003370105822, 0.6097335825641022, 0.9568081018654329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 348}], {
             RGBColor[
             0.5282156563331551, 0.6233653822352514, 0.957751476691993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 357}], {
             RGBColor[
             0.7901960776192611, 0.6118325861467757, 0.5876837053959174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 366}], {
             RGBColor[
             0.5588455342770764, 0.6498954430078475, 0.9597031854296422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 291}], {
             RGBColor[
             0.18857894058274138`, 0.31553880152083974`, 0.9340506637374206]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 304}], {
             RGBColor[
             0.18543662898340038`, 0.31223603279586976`, 0.9338717137404716]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 378}], {
             RGBColor[
             0.19040066183963522`, 0.31745354606563403`, 0.9341544080680056]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 383}], {
             RGBColor[
             0.1991683094404495, 0.3266688995950551, 0.9346537126282998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 293}], {
             RGBColor[
             0.2908233203898157, 0.4192921425712095, 0.940009243857379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 315}], {
             RGBColor[
             0.22579916171770553`, 0.3546596138320083, 0.9361703002686741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 316}], {
             RGBColor[
             0.23355306875092818`, 0.36280946175002615`, 0.9366118738033387]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 338}], {
             RGBColor[
             0.23347632110247196`, 0.3627287951054168, 0.936607503138297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 397}], {
             RGBColor[
             0.22283784734549728`, 0.3515470846686418, 0.9360016577960488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 282}], {
             RGBColor[
             0.2615646860965489, 0.39225144761939246`, 0.9382070939716974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 332}], {
             RGBColor[
             0.24216572228766625`, 0.37186190669091185`, 0.9371023516809767]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 367}], {
             RGBColor[
             0.315534462322565, 0.44284387318578267`, 0.9415051605226336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 383}], {
             RGBColor[
             0.23217032750693795`, 0.361356113031734, 0.9365331287350758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 398}], {
             RGBColor[
             0.34104050458358826`, 0.46493592502132197`, 0.9431303829813984]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 270}], {
             RGBColor[
             0.5192310696539062, 0.6174490867384653, 0.9563893333020512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 274}], {
             RGBColor[
             0.5862206904488971, 0.6743925388404906, 0.9609561467561663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 295}], {
             RGBColor[
             0.5541988760682194, 0.6477364431214906, 0.9586174510059542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 324}], {
             RGBColor[
             0.6562462626397825, 0.7312424529611288, 0.9664688163111557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 351}], {
             RGBColor[
             0.7945761589543001, 0.8401740652758038, 0.979966961918109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 373}], {
             RGBColor[
             0.475607023803843, 0.5762529501811211, 0.9537345477094038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 272}], {
             RGBColor[
             0.7422573926850033, 0.7985763836214297, 0.9749449381792838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 350}], {
             RGBColor[
             0.8687159863176557, 0.8956679071093385, 0.8633270413739342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 355}], {
             RGBColor[
             0.7546443194902623, 0.8082531449858283, 0.9761795512808198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 392}], {
             RGBColor[
             0.8673327084378479, 0.8950958861574181, 0.8862515356507488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 395}], {
             RGBColor[
             0.6061102125080312, 0.6895560016714635, 0.9631945161165028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 295}], {
             RGBColor[
             0.3940670515595366, 0.5157428065001295, 0.9463305819589302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 310}], {
             RGBColor[
             0.3193491673301014, 0.4483310995882432, 0.9416682954109477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 324}], {
             RGBColor[
             0.49611443813109957`, 0.5992488163397677, 0.9541819472641316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 346}], {
             RGBColor[
             0.3550828331693524, 0.4819766359343405, 0.9438465420354984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 351}], {
             RGBColor[
             0.6344443344456173, 0.7081804286544429, 0.9676800928710849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 373}], {
             RGBColor[
             0.31547519929516016`, 0.44425931355976, 0.9414476786623798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 390}], {
             RGBColor[
             0.310905083152461, 0.4394558317316838, 0.9411874173089341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 287}], {
             RGBColor[
             0.18451611233351262`, 0.31126851143271117`, 0.9338192916790429]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 292}], {
             RGBColor[
             0.18674265418407987`, 0.3136087480885643, 0.9339460899435592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 371}], {
             RGBColor[
             0.1828236944867615, 0.3094896729702865, 0.9337229109863782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 374}], {
             RGBColor[
             0.184659451088446, 0.3114191695523481, 0.9338274546090857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 382}], {
             RGBColor[
             0.18049565541513857`, 0.3070427562998084, 0.9335903326052744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 384}], {
             RGBColor[
             0.18432884103510522`, 0.31107167742439884`, 0.9338086268556416]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 389}], {
             RGBColor[
             0.19087423447573804`, 0.31795130093241747`, 0.9341813773290437]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 391}], {
             RGBColor[
             0.1801133509320429, 0.3066409300485706, 0.9335685609305309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 350}], {
             RGBColor[
             0.867391875594665, 0.894633501748924, 0.8631950663915847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 392}], {
             RGBColor[
             0.8660085977148573, 0.8940614807970035, 0.8861195606683994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 395}], {
             RGBColor[
             0.6047861017850406, 0.688521596311049, 0.9630625411341533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 322}], {
             RGBColor[
             0.19086506728942945`, 0.31794166563837395`, 0.9341808552713451]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 330}], {
             RGBColor[
             0.18387764331179846`, 0.31059744000961553`, 0.9337829318127865]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 295}], {
             RGBColor[
             0.4610566723545275, 0.5726862586021548, 0.9508973954130453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 296}], {
             RGBColor[
             0.36901952314668135`, 0.4870709060931353, 0.9452488023460986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 319}], {
             RGBColor[
             0.47322013025663245`, 0.583220445923085, 0.9516727685977074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 324}], {
             RGBColor[
             0.5631040589260905, 0.6561922684417929, 0.9587487607182468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 351}], {
             RGBColor[
             0.7014339552406084, 0.7651238807564681, 0.9722469063252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 373}], {
             RGBColor[
             0.38246482009015115`, 0.5012027656617852, 0.9460144921164949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 276}], {
             RGBColor[
             0.2308037275414878, 0.35991972982060355`, 0.9364553028887468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 280}], {
             RGBColor[
             0.24514319627116127`, 0.3749914206303192, 0.9372719144195587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 288}], {
             RGBColor[
             0.2720607570835225, 0.40328348371603906`, 0.9388048296868601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 290}], {
             RGBColor[
             0.21848378643908228`, 0.34697069059259356`, 0.9357537004686844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 297}], {
             RGBColor[
             0.22283542703535522`, 0.35154454076922603`, 0.9360015199629668]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 318}], {
             RGBColor[
             0.21657038683237403`, 0.3449595862894012, 0.9356447351917034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 325}], {
             RGBColor[
             0.2639447266446291, 0.3947530211387112, 0.9383426337599561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 339}], {
             RGBColor[
             0.24514905354352745`, 0.3749975769949486, 0.9372722479825549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 288}], {
             RGBColor[
             0.2641141546829352, 0.39493110074932897`, 0.9383522824360913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 290}], {
             RGBColor[
             0.21053718403849497`, 0.33861830762588346`, 0.9353011532179156]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 297}], {
             RGBColor[
             0.21488882463476794`, 0.3431921578025159, 0.9355489727121981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 318}], {
             RGBColor[
             0.20862378443178675`, 0.3366072033226911, 0.9351921879409346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 278}], {
             RGBColor[
             0.23299059780069237`, 0.3622182691186103, 0.9365798419148239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 302}], {
             RGBColor[
             0.19959521355734036`, 0.32711760288919167`, 0.9346780241862087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 314}], {
             RGBColor[
             0.22024480085065679`, 0.34882162839392095`, 0.9358539876342362]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 352}], {
             RGBColor[
             0.22370886564436498`, 0.3524625801265016, 0.9360512609996132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 378}], {
             RGBColor[
             0.19931695292516527`, 0.3268251333220326, 0.934662177654856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 379}], {
             RGBColor[
             0.2074585735841274, 0.33538249284316635`, 0.9351258309069355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 314}], {
             RGBColor[
             0.2454200867859244, 0.3752824501172079, 0.9372876829247517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 319}], {
             RGBColor[
             0.35576382875700985`, 0.4778888141834562, 0.9440614916187484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 352}], {
             RGBColor[
             0.24888415157963256`, 0.37892340184978857`, 0.9374849562901288]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 379}], {
             RGBColor[
             0.232633859519395, 0.36184331456645336`, 0.936559526197451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.8332166202434534, 0.8669371947579207, 0.788972494773293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 288}], {
             RGBColor[
             0.4888026931766387, 0.5910842948036721, 0.9543337450913586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 309}], {
             RGBColor[
             0.48491537307549215`, 0.5869984749070372, 0.9541123679623731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 325}], {
             RGBColor[
             0.4806866627377453, 0.5825538322263442, 0.9538715491644547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 399}], {
             RGBColor[
             0.7994051322415094, 0.7452396599077329, 0.6138726305595152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 297}], {
             RGBColor[
             0.22922829336444137`, 0.3582638486122316, 0.9363655842430101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 309}], {
             RGBColor[
             0.27456630331146203`, 0.4059169716624097, 0.9389475168379178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 322}], {
             RGBColor[
             0.22572058379982396`, 0.354577023458187, 0.9361658253724963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 325}], {
             RGBColor[
             0.2703375929737152, 0.4014723289817168, 0.9387066980399994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 339}], {
             RGBColor[
             0.2515419198726136, 0.3817168848379542, 0.9376363122625981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 355}], {
             RGBColor[
             0.5971975343016019, 0.6813125874620714, 0.9629093916561169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 386}], {
             RGBColor[
             0.5947242732295994, 0.6793804571151425, 0.9626628801063983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 367}], {
             RGBColor[
             0.3211123825917724, 0.44870662104929115`, 0.9418228148301714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 383}], {
             RGBColor[
             0.23774824777614534`, 0.3672188608952424, 0.9368507830426136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 398}], {
             RGBColor[
             0.3466184248527956, 0.47079867288483046`, 0.9434480372889362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 294}], {
             RGBColor[
             0.19947004944091673`, 0.32698604746696713`, 0.934670896274942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 320}], {
             RGBColor[
             0.20238649627655553`, 0.330051418004633, 0.9348369836077353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 347}], {
             RGBColor[
             0.20341579469893528`, 0.33113327590784336`, 0.9348956006301792]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 373}], {
             RGBColor[
             0.2404157449182508, 0.3700225695206825, 0.937002693058648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 380}], {
             RGBColor[
             0.2145522876760556, 0.34283843612123366`, 0.9355298074302612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 381}], {
             RGBColor[
             0.20257187699290616`, 0.3302462648913338, 0.9348475407652852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 332}], {
             RGBColor[
             0.2524716906122939, 0.382694132836228, 0.9376892613307504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 338}], {
             RGBColor[
             0.2553995027309328, 0.3857714490069275, 0.9378559958995971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 367}], {
             RGBColor[
             0.3258404306471927, 0.4536760993310988, 0.9420920701724073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 399}], {
             RGBColor[
             0.9603875503566552, 0.868303119703074, 0.4348794443842956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 332}], {
             RGBColor[
             0.2115950206250406, 0.3397301609490563, 0.9353613954465905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 292}], {
             RGBColor[
             0.19215895018442095`, 0.31930161859792383`, 0.9342545399880867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 371}], {
             RGBColor[
             0.18823999048710255`, 0.315182543479646, 0.9340313610309057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 374}], {
             RGBColor[
             0.19007574708878708`, 0.31711204006170757`, 0.9341359046536132]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 382}], {
             RGBColor[
             0.18591195141547964`, 0.3127356268091679, 0.933898782649802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 384}], {
             RGBColor[
             0.18974513703544627`, 0.3167645479337583, 0.9341170769001692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 389}], {
             RGBColor[
             0.19629053047607914`, 0.32364417144177693`, 0.9344898273735713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 391}], {
             RGBColor[
             0.18552964693238397`, 0.31233380055793014`, 0.9338770109750585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 303}], {
             RGBColor[
             0.19970158242580874`, 0.32722940331412775`, 0.9346840817359092]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 376}], {
             RGBColor[
             0.19788479388924796`, 0.32531984337115605`, 0.93458061831645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 297}], {
             RGBColor[
             0.20256888353236238`, 0.33024311857450594`, 0.9348473702921356]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 318}], {
             RGBColor[
             0.1963038433293812, 0.3236581640946811, 0.9344905855208723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 345}], {
             RGBColor[
             0.18860221988526102`, 0.31556326954378094`, 0.9340519894592605]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 304}], {
             RGBColor[
             0.1840328398717771, 0.3107605614341833, 0.9337917700272845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 383}], {
             RGBColor[
             0.1977645203288262, 0.3251934282333686, 0.9345737689151127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 371}], {
             RGBColor[
             0.1904665323376698, 0.31752278013549917`, 0.934158159295422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 374}], {
             RGBColor[
             0.19230228893935433`, 0.31945227671756077`, 0.9342627029181295]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 382}], {
             RGBColor[
             0.1881384932660469, 0.31507586346502103`, 0.9340255809143183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 384}], {
             RGBColor[
             0.19197167888601352`, 0.3191047845896115, 0.9342438751646855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 389}], {
             RGBColor[
             0.1985170723266464, 0.32598440809763013`, 0.9346166256380877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 316}], {
             RGBColor[
             0.2916240499210687, 0.42013376007774095`, 0.9400548442196108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 387}], {
             RGBColor[
             0.4415101712045343, 0.5546415244104943, 0.9499598596294503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 320}], {
             RGBColor[
             0.19287620932606772`, 0.32005550343265077`, 0.9342953868351136]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 347}], {
             RGBColor[
             0.19390550774844745`, 0.3211373613358611, 0.9343540038575576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 380}], {
             RGBColor[
             0.20504200072556777`, 0.3328425215492514, 0.9349882106576397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 381}], {
             RGBColor[
             0.19306159004241835`, 0.32025035031935156`, 0.9343059439926636]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 310}], {
             RGBColor[
             0.3543169737444146, 0.4786184559712684, 0.9438964131148506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 324}], {
             RGBColor[
             0.5310822445454129, 0.6295361727227928, 0.9564100649680346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 351}], {
             RGBColor[
             0.6694121408599306, 0.7384677850374681, 0.9699082105749879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 373}], {
             RGBColor[
             0.3504430057094734, 0.4745466699427852, 0.9436757963662827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 390}], {
             RGBColor[
             0.34587288956677426`, 0.46974318811470905`, 0.943415535012837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 308}], {
             RGBColor[
             0.22323052785896746`, 0.35195981678568156`, 0.9360240203703722]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 373}], {
             RGBColor[
             0.25840585650162723`, 0.38893131743376574`, 0.9380272032993362]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 380}], {
             RGBColor[
             0.23254239925943204`, 0.3617471840343169, 0.9365543176709494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 318}], {
             RGBColor[
             0.20065548392565413`, 0.32823201427131354`, 0.9347384050151546]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 322}], {
             RGBColor[
             0.2034128145640179, 0.33113014359709375`, 0.9348954309159043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 339}], {
             RGBColor[
             0.22923415063680755`, 0.358270004976861, 0.9363659178060062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 313}], {
             RGBColor[
             0.20768244341745035`, 0.33561779423215604`, 0.9351385799627575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 361}], {
             RGBColor[
             0.2073168336633886, 0.33523351519963984`, 0.9351177590281349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 393}], {
             RGBColor[
             0.19018046268844432`, 0.31722210279629987`, 0.9341418680521008]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 396}], {
             RGBColor[
             0.19827776691556012`, 0.32573288293773905`, 0.9346029975489469]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 306}], {
             RGBColor[
             0.19518727715711093`, 0.32248458225324084`, 0.9344269987291731]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 342}], {
             RGBColor[
             0.18568831496489116`, 0.3125005707202294, 0.9338860468847814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 353}], {
             RGBColor[
             0.188841530987085, 0.3158148006849981, 0.9340656178724803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 319}], {
             RGBColor[
             0.6840306200166372, 0.7509595396670409, 0.9709177458785374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 343}], {
             RGBColor[
             0.18235879982602854`, 0.30900103920583233`, 0.9336964359231994]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 358}], {
             RGBColor[
             0.18673627600332035`, 0.31360204421618604`, 0.9339457267156006]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 359}], {
             RGBColor[
             0.1849503238015024, 0.31172489521616553`, 0.9338440193797866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 362}], {
             RGBColor[
             0.18593089634401205`, 0.31275553913023335`, 0.9338998615354555]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 369}], {
             RGBColor[
             0.18664719483068826`, 0.31350841425567716`, 0.9339406536746029]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 394}], {
             RGBColor[
             0.18156448933556574`, 0.30816616851816203`, 0.9336512011158447]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 397}], {
             RGBColor[
             0.19781003665891564`, 0.3252412687821946, 0.934576361002776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 314}], {
             RGBColor[
             0.21202470254257239`, 0.3401817838877893, 0.9353858651961364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 352}], {
             RGBColor[
             0.21548876733628058`, 0.34382273562037, 0.9355831385615135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 377}], {
             RGBColor[
             0.18805566555367964`, 0.3149888062877428, 0.9340208639986316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 379}], {
             RGBColor[
             0.199238475276043, 0.32674264833703476`, 0.9346577084688357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 376}], {
             RGBColor[
             0.21141869489039777`, 0.33954483142224945`, 0.9353513539568531]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 383}], {
             RGBColor[
             0.1946222087294852, 0.32189065950839857`, 0.9343948189181637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 334}], {
             RGBColor[
             0.18360707090558112`, 0.31031305125539965`, 0.9337675231145284]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 340}], {
             RGBColor[
             0.19258396167334632`, 0.31974833262006913`, 0.9342787437636328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 360}], {
             RGBColor[
             0.18374121717091801`, 0.3104540474856332, 0.9337751625458877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 370}], {
             RGBColor[
             0.18466045373978385`, 0.311420223402476, 0.9338275117085959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 342}], {
             RGBColor[
             0.1932134040418383, 0.3204099164583054, 0.934314589575342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 353}], {
             RGBColor[
             0.19636662006403216`, 0.3237241464230741, 0.9344941605630408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 361}], {
             RGBColor[
             0.21017418029056079`, 0.33823676767103766`, 0.9352804806914867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 312}], {
             RGBColor[
             0.32563175741045036`, 0.45592792457411196`, 0.9419897054854269]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 341}], {
             RGBColor[
             0.3422947785820742, 0.4709002657971524, 0.9430316985052297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 348}], {
             RGBColor[
             0.3407470767330234, 0.4695597242452613, 0.9429330803119872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 366}], {
             RGBColor[
             0.37137695467694465`, 0.4960897850178574, 0.9448847890496364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 325}], {
             RGBColor[
             0.2933678336849298, 0.42567857217080163`, 0.9400182361783151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 339}], {
             RGBColor[
             0.27457216058382816`, 0.4059231280270391, 0.9389478504009139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 323}], {
             RGBColor[
             0.33914507736848765`, 0.46547732189212476`, 0.9429296732937578]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 324}], {
             RGBColor[
             0.45636436031597766`, 0.5621244658109066, 0.9517477784200521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 346}], {
             RGBColor[
             0.31533275535423055`, 0.4448522854054794, 0.9414123731914188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 389}], {
             RGBColor[
             0.24112387106664201`, 0.3707668550004327, 0.9370430197952202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 390}], {
             RGBColor[
             0.27115500533733905`, 0.4023314812028227, 0.9387532484648545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 313}], {
             RGBColor[
             0.2605556138292256, 0.39119084868755866`, 0.938149628798862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 361}], {
             RGBColor[
             0.2601900040751639, 0.39080656965504246`, 0.9381288078642394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 386}], {
             RGBColor[
             0.5317523136158948, 0.6242823861276408, 0.958670681032904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 348}], {
             RGBColor[
             0.31802432732292496`, 0.44933875099285125`, 0.9415049667672362]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 366}], {
             RGBColor[
             0.3486542052668462, 0.4758688117654473, 0.9434566755048852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 361}], {
             RGBColor[
             0.2180016041011253, 0.34646388638327474`, 0.9357262408978626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 393}], {
             RGBColor[
             0.200865233126181, 0.3284524739799347, 0.9347503499218286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 396}], {
             RGBColor[
             0.20896253735329678`, 0.3369632541213739, 0.9352114794186747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 352}], {
             RGBColor[
             0.23613835462959704`, 0.3655267611250992, 0.9367591020095412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 379}], {
             RGBColor[
             0.21988806256935944`, 0.348446673841764, 0.9358336719168633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 316}], {
             RGBColor[
             0.22659989124895852`, 0.3555012313385397, 0.9362159006309058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 358}], {
             RGBColor[
             0.20481090918793238`, 0.33259962969114687`, 0.9349750503364407]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 359}], {
             RGBColor[
             0.2030249569861144, 0.33072248069112636`, 0.9348733430006266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 362}], {
             RGBColor[
             0.20400552952862408`, 0.3317531246051941, 0.9349291851562955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 363}], {
             RGBColor[
             0.2193734294732247, 0.3479057618281034, 0.9358043643233698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 369}], {
             RGBColor[
             0.20472182801530026`, 0.332505999730638, 0.934969977295443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 397}], {
             RGBColor[
             0.21588466984352767`, 0.3442388542571554, 0.935605684623616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 358}], {
             RGBColor[
             0.212564816221155, 0.34074947760916474`, 0.9354166238711052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 359}], {
             RGBColor[
             0.21077886401933704`, 0.3388723286091443, 0.9353149165352912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 362}], {
             RGBColor[
             0.2117594365618467, 0.339902972523212, 0.9353707586909601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 363}], {
             RGBColor[
             0.2271273365064473, 0.3560556097461213, 0.9362459378580343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 369}], {
             RGBColor[
             0.2124757350485229, 0.34065584764865586`, 0.9354115508301075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 397}], {
             RGBColor[
             0.2236385768767503, 0.3523887021751733, 0.9360472581582806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 326}], {
             RGBColor[
             0.19368284883535128`, 0.3209033327008066, 0.9343413237618512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 327}], {
             RGBColor[
             0.19548056477531295`, 0.3227928461354802, 0.9344437010251496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 336}], {
             RGBColor[
             0.1878536669894908, 0.3147764929893316, 0.9340093604792311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 396}], {
             RGBColor[
             0.19745595153076353`, 0.32486910286221293`, 0.9345561963785496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 345}], {
             RGBColor[
             0.18668882027855277`, 0.3135521652405886, 0.9339430241822795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 347}], {
             RGBColor[
             0.1968219545840863, 0.324202731873527, 0.9345200911903508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 380}], {
             RGBColor[
             0.20795844756120663`, 0.3359078920869173, 0.9351542979904328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 381}], {
             RGBColor[
             0.19597803687805715`, 0.32331572085701743`, 0.9344720313254569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 384}], {
             RGBColor[
             0.1926752609493727, 0.31984429394788133`, 0.9342839431223373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 341}], {
             RGBColor[
             0.44529829620254, 0.5573731665864943, 0.9503530478730258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 366}], {
             RGBColor[
             0.4743804722974104, 0.5825626858071993, 0.9522061384174323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 330}], {
             RGBColor[
             0.19291768102176954`, 0.3200990928142907, 0.934297748586832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 339}], {
             RGBColor[
             0.22572644107219014`, 0.3545831798228164, 0.9361661589354925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 346}], {
             RGBColor[
             0.37487874320773873`, 0.4991228582382221, 0.9451079199183084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 346}], {
             RGBColor[
             0.4920980261552287, 0.5957700021570038, 0.9539260250446029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 351}], {
             RGBColor[
             0.7714595274314936, 0.8219737948771062, 0.9777595758801894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 390}], {
             RGBColor[
             0.4479202761383373, 0.5532491979543472, 0.9512669003180385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 339}], {
             RGBColor[
             0.2703434502460814, 0.40147848534634617`, 0.9387070316029955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 327}], {
             RGBColor[
             0.19380937140054372`, 0.3210363159388178, 0.9343485290347655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 336}], {
             RGBColor[
             0.18618247361472157`, 0.3130199627926692, 0.9339141884888471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 336}], {
             RGBColor[
             0.18798018955468324`, 0.3149094762273428, 0.9340165657521455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 376}], {
             RGBColor[
             0.2026044968471712, 0.33028055042638454`, 0.9348493984177288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 364}], {
             RGBColor[
             0.8436039382637408, 0.3186655649666024, 0.18870327005536394`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 386}], {
             RGBColor[
             0.8151456848541535, 0.6567413505380229, 0.5948173850288303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 400}], {
             RGBColor[
             0.8598546185049423, 0.443575414393966, 0.20426493980685678`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 349}], {
             RGBColor[
             0.19621450085245074`, 0.32356425948678696`, 0.9344854975989814]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 335}], {
             RGBColor[
             0.18932527309814626`, 0.31632324431474484`, 0.9340931662700729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 338}], {
             RGBColor[
             0.2166739251358942, 0.34506841161110846`, 0.9356506315449178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 368}], {
             RGBColor[
             0.18664235406415453`, 0.3135033263031278, 0.9339403780001101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 340}], {
             RGBColor[
             0.1939578430419053, 0.32119236904753456`, 0.934356984275097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 360}], {
             RGBColor[
             0.185115098539477, 0.3118980839130987, 0.9338534030573518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 365}], {
             RGBColor[
             0.18295572293696874`, 0.30962844324254163`, 0.933730429811299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 370}], {
             RGBColor[
             0.18603433510834283`, 0.3128642598299414, 0.93390575222006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 394}], {
             RGBColor[
             0.17996762986719622`, 0.30648776797016763`, 0.9335602623314629]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 396}], {
             RGBColor[
             0.18995557631013382`, 0.31698573295407556`, 0.9341290611055455]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 367}], {
             RGBColor[
             0.6845644891406854, 0.7444870601720963, 0.7692660513213518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 398}], {
             RGBColor[
             0.7100705314017086, 0.7665791120076357, 0.7708912737801167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 399}], {
             RGBColor[
             0.9603114409091467, 0.8681403292906987, 0.42659540071605706`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 360}], {
             RGBColor[
             0.1940919893072422, 0.3213333652777681, 0.9343646237064562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 370}], {
             RGBColor[
             0.19501122587610803`, 0.3222995411946109, 0.9344169728691645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 348}], {
             RGBColor[
             0.33468734849454873`, 0.4643110922158917, 0.9425469597870388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 366}], {
             RGBColor[
             0.36531722643847, 0.49084115298848774`, 0.9444986685246879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 353}], {
             RGBColor[
             0.1868676578718124, 0.31374013489006275`, 0.9339532087186491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 358}], {
             RGBColor[
             0.18639835798283702`, 0.3132468709514181, 0.933926482784239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 359}], {
             RGBColor[
             0.18461240578101906`, 0.3113697219513976, 0.933824775448425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 362}], {
             RGBColor[
             0.18559297832352872`, 0.3124003658654654, 0.9338806176040938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 369}], {
             RGBColor[
             0.18630927681020493`, 0.31315324099090924`, 0.9339214097432413]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 354}], {
             RGBColor[
             0.2035510812828702, 0.3312754706852238, 0.9349033050009957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 356}], {
             RGBColor[
             0.19312061469136133`, 0.3203123889677695, 0.9343093053591018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 388}], {
             RGBColor[
             0.20538183242077535`, 0.3331997062074885, 0.9350075635699459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 390}], {
             RGBColor[
             0.30688867117659013`, 0.43597701754892004`, 0.9409314950894052]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 380}], {
             RGBColor[
             0.20898774598358635`, 0.3369897499901277, 0.9352129150128767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 381}], {
             RGBColor[
             0.1970073353004369, 0.3243975787602278, 0.9345306483479008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 384}], {
             RGBColor[
             0.19370455937175246`, 0.32092615185109175`, 0.9343425601447813]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 366}], {
             RGBColor[
             0.3637695245894192, 0.4895006114365967, 0.9444000503314454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 355}], {
             RGBColor[
             0.879778802399924, 0.9043102631133229, 0.8644296794931206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 392}], {
             RGBColor[
             0.9924671913475096, 0.9911530042849124, 0.7745016638630496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 395}], {
             RGBColor[
             0.7312446954176929, 0.785613119798958, 0.8514446443288036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 379}], {
             RGBColor[
             0.22335212736306764`, 0.3520876255743447, 0.9360309452822404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 371}], {
             RGBColor[
             0.20120013846367035`, 0.3288044807238608, 0.9347694222853504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 388}], {
             RGBColor[
             0.21768345542489445`, 0.346129491952765, 0.93570812280141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 392}], {
             RGBColor[
             0.8783955245201162, 0.9037382421614023, 0.8873541737699352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 395}], {
             RGBColor[
             0.6171730285902994, 0.6981983576754478, 0.9642971542356892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 363}], {
             RGBColor[
             0.2074463229173425, 0.3353696166156383, 0.9351251332495853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 372}], {
             RGBColor[
             0.1945300591839852, 0.3217938044934594, 0.9343895711378705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 364}], {
             RGBColor[
             0.8373888047327049, 0.2883923138200816, 0.1834368676776406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 385}], {
             RGBColor[
             0.9257629036983032, 0.7151948013477634, 0.418460634800934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 359}], {
             RGBColor[
             0.18898988195831087`, 0.3159707269617513, 0.934074066240826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 362}], {
             RGBColor[
             0.18997045450082056`, 0.31700137087581914`, 0.9341299083964949]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 363}], {
             RGBColor[
             0.20533835444542115`, 0.3331540080987284, 0.9350050875635693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 369}], {
             RGBColor[
             0.19068675298749674`, 0.31775424600126295`, 0.9341707005356424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 372}], {
             RGBColor[
             0.19242209071206384`, 0.3195781959765495, 0.9342695254518545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 397}], {
             RGBColor[
             0.20184959481572412`, 0.3294871005277804, 0.9348064078638154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 362}], {
             RGBColor[
             0.18818450229900258`, 0.31512422187579864`, 0.9340282010606809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 369}], {
             RGBColor[
             0.18890080078567878`, 0.31587709700124245`, 0.9340689931998285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 394}], {
             RGBColor[
             0.18381809529055626`, 0.3105348512637273, 0.9337795406410702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 397}], {
             RGBColor[
             0.20006364261390616`, 0.32760995152775996`, 0.9347047005280014]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 370}], {
             RGBColor[
             0.18616848137367975`, 0.313005256060175, 0.9339133916514194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 393}], {
             RGBColor[
             0.20049962337211924`, 0.32806819494741857`, 0.934729528987206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 396}], {
             RGBColor[
             0.20859692759923504`, 0.3365789750888577, 0.935190658484052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 363}], {
             RGBColor[
             0.20453297478611288`, 0.3323075030127757, 0.9349592223834241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 369}], {
             RGBColor[
             0.18988137332818844`, 0.31690774091531027`, 0.9341248353554973]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 397}], {
             RGBColor[
             0.20104421515641585`, 0.32864059544182767`, 0.9347605426836703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 369}], {
             RGBColor[
             0.20524927327278905`, 0.33306037813821954`, 0.9350000145225716]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 372}], {
             RGBColor[
             0.20698461099735616`, 0.3348843281135061, 0.9350988394387836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 385}], {
             RGBColor[
             0.9060512192132981, 0.563682156680796, 0.3995847034769297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 370}], {
             RGBColor[
             0.18400910577117147`, 0.3107356153896179, 0.9337904184053665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 398}], {
             RGBColor[
             0.40058820107881166`, 0.5213910984512207, 0.9467461038398723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 372}], {
             RGBColor[
             0.19233300953943172`, 0.31948456601604064`, 0.9342644524108568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 389}], {
             RGBColor[
             0.194598112629328, 0.3218653329793524, 0.9343934466809067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 391}], {
             RGBColor[
             0.18383722908563283`, 0.3105549620955055, 0.9337806302823939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 380}], {
             RGBColor[
             0.24598769620290184`, 0.37587904360296687`, 0.9373200074413457]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 382}], {
             RGBColor[
             0.18605529017041303`, 0.3128862849288049, 0.9339069455798448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 384}], {
             RGBColor[
             0.18988847579037965`, 0.3169152060533953, 0.934125239830212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 389}], {
             RGBColor[
             0.19643386923101253`, 0.3237948295614139, 0.9344979903036141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 377}], {
             RGBColor[
             0.18266643619111367`, 0.3093243845308089, 0.9337139553590839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 379}], {
             RGBColor[
             0.19896021464386793`, 0.3264501787698757, 0.934641861937483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 381}], {
             RGBColor[
             0.20814382827755723`, 0.3361027389736181, 0.9351648551479828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 384}], {
             RGBColor[
             0.18572468011707222`, 0.3125387928008556, 0.9338881178264007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 389}], {
             RGBColor[
             0.1922700735577051, 0.31941841630887424`, 0.9342608682998029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 389}], {
             RGBColor[
             0.1961032591776717, 0.32344733743346465`, 0.93447916255017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 387}], {
             RGBColor[
             0.7642756795140044, 0.8115756260652711, 0.7955379877927361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 400}], {
             RGBColor[
             0.8054695470793142, 0.5998653041518983, 0.5862367210785956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 390}], {
             RGBColor[
             0.23267978688900162`, 0.3618915871438733, 0.9365621416932066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 395}], {
             RGBColor[
             0.729861417537885, 0.7850410988470374, 0.8743691386056183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 396}], {
             RGBColor[
             0.19146055662429076`, 0.3185675626855177, 0.9342147675080179]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.0002105009621202394], {
             RGBColor[
             0.19354678877808446`, 0.32076032495391327`, 0.9343335753428726]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.0002105009621202394], {
             RGBColor[
             0.18498575182454155`, 0.3117621323146461, 0.9338460369532876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.0002105009621202394], {
             RGBColor[
             0.5818688834669836, 0.6714263983498019, 0.960225996443923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.0002105009621202394], {
             RGBColor[
             0.23281884209063286`, 0.36203774297739677`, 0.9365700606812258]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.0002105009621202394], {
             RGBColor[
             0.2824395297681887, 0.41419223185981874`, 0.9393958854372335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.0002105009621202394], {
             RGBColor[
             0.30558851701585305`, 0.4385232851876776, 0.9407141860151303]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.0002105009621202394], {
             RGBColor[
             0.4486453266434888, 0.5630157651939816, 0.9498082613856059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.0002105009621202394], {
             RGBColor[
             0.2378122641398246, 0.36728614615234123`, 0.9368544286798214]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.0002105009621202394], {
             RGBColor[
             0.19103464530579026`, 0.3181199028854364, 0.9341905124885087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.0002105009621202394], {
             RGBColor[
             0.23750097993416716`, 0.3669589667156367, 0.9368367015048129]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.0002105009621202394], {
             RGBColor[
             0.31196467996522614`, 0.44462985881031997`, 0.9410990914412173]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.0002105009621202394], {
             RGBColor[
             0.3084761160714523, 0.441558334879467, 0.9408786305095267]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.0002105009621202394], {
             RGBColor[
             0.21416269395992185`, 0.3424289484239088, 0.9355076206444797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.0002105009621202394], {
             RGBColor[
             0.18454901891679482`, 0.31130309833813863`, 0.9338211656602798]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.0002105009621202394], {
             RGBColor[
             0.28582560720535155`, 0.41775121393598635`, 0.9395887175380273]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.0002105009621202394], {
             RGBColor[
             0.3177755060429437, 0.4496629042982282, 0.9414693521405777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.0002105009621202394], {
             RGBColor[
             0.2316763474093035, 0.360836908628973, 0.9365049972992935]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.0002105009621202394], {
             RGBColor[
             0.6051402883638863, 0.6903191732099512, 0.9620580066833722]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.0002105009621202394], {
             RGBColor[
             0.26040419361571815`, 0.3910316964425663, 0.9381410056417089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.0002105009621202394], {
             RGBColor[
             0.19028821830363388`, 0.31733536077996466`, 0.9341480045749757]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.0002105009621202394], {
             RGBColor[
             0.9632021039744041, 0.8875341975281088, 0.3115475519504825]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.0002105009621202394], {
             RGBColor[
             0.3162753653274515, 0.4483635578097335, 0.9413737645007089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.0002105009621202394], {
             RGBColor[
             0.2930562064900811, 0.4253510322307103, 0.9400004894705796]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.0002105009621202394], {
             RGBColor[
             0.8207868509580615, 0.16078242208563953`, 0.1675388179938171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.0002105009621202394], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.0002105009621202394], {
             RGBColor[
             0.18699939157323073`, 0.3138785953626525, 0.9339607107580624]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.0002105009621202394], {
             RGBColor[
             0.821038236612611, 0.16271468238440395`, 0.16777954518051325`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.0002105009621202394], {
             RGBColor[
             0.20698871416859752`, 0.3348886408066369, 0.9350990731083157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.0002105009621202394], {
             RGBColor[
             0.1814383294461641, 0.30803356647540187`, 0.9336440164967801]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.0002105009621202394], {
             RGBColor[
             0.18021067351487519`, 0.3067432222537355, 0.9335741033076473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.0002105009621202394], {
             RGBColor[
             0.19647646719475834`, 0.3238396027221777, 0.9345004161946314]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.0002105009621202394], {
             RGBColor[
             0.9570322462930174, 0.8667218188173162, 0.28757881993815293`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.0002105009621202394], {
             RGBColor[
             0.2765417318743941, 0.4079932723314563, 0.939060014572192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.0002105009621202394], {
             RGBColor[
             0.2632481201845229, 0.3940208435817391, 0.93830296305259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.0002105009621202394], {
             RGBColor[
             0.2362515342121432, 0.36564572004235524`, 0.9367655474193329]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.0002105009621202394], {
             RGBColor[
             0.19287789451893317`, 0.32005727467719974`, 0.9342954828043544]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.0002105009621202394], {
             RGBColor[
             0.34879862256835453`, 0.4765335685653648, 0.9434461176929121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.0002105009621202394], {
             RGBColor[
             0.22292982485851465`, 0.3516437588665342, 0.9360068957793466]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.0002105009621202394], {
             RGBColor[
             0.18317563345981333`, 0.30985958314518375`, 0.9337429533902465]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.0002105009621202394], {
             RGBColor[
             0.5210599224495296, 0.6220589443833571, 0.9554388922820652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.0002105009621202394], {
             RGBColor[
             0.8718710063158469, 0.90067029040099, 0.9876410289824828]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.0002105009621202394], {
             RGBColor[
             0.21651396498896067`, 0.34490028335462225`, 0.9356415220511897]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.0002105009621202394], {
             RGBColor[
             0.26035980612556775`, 0.3909850423760888, 0.9381384778398102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.0002105009621202394], {
             RGBColor[
             0.2366745638317519, 0.36609035099419096`, 0.9367896383303533]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.0002105009621202394], {
             RGBColor[
             0.2848093981590889, 0.41668311379698936`, 0.9395308459361892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.0002105009621202394], {
             RGBColor[
             0.20129344185623907`, 0.3289025485052273, 0.9347747357755273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.0002105009621202394], {
             RGBColor[
             0.5441036538714303, 0.6407668836599264, 0.9572529792315668]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.0002105009621202394], {
             RGBColor[
             0.24018804114120323`, 0.3697832384137522, 0.9369897256654027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.0002105009621202394], {
             RGBColor[
             0.18767785554878408`, 0.3145917040180597, 0.9339993482777726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.0002105009621202394], {
             RGBColor[
             0.1790362447681438, 0.3055088231778375, 0.9335072213279326]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.0002105009621202394], {
             RGBColor[
             0.381577964086101, 0.5049253866504279, 0.9455347883487892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.0002105009621202394], {
             RGBColor[
             0.17936539842637753`, 0.30585478454218845`, 0.9335259661418299]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.0002105009621202394], {
             RGBColor[
             0.19239706134193654`, 0.319551888521592, 0.9342681000662533]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.0002105009621202394], {
             RGBColor[
             0.1846123721443362, 0.31136968659711123`, 0.9338247735328656]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.0002105009621202394], {
             RGBColor[
             0.9716313250190438, 0.9159679393868991, 0.3442934839840799]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.0002105009621202394], {
             RGBColor[
             0.38165040818030865`, 0.5049881340836845, 0.9455394044224124]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.0002105009621202394], {
             RGBColor[
             0.21768082531414856`, 0.3461267275396124, 0.9357079730204939]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.0002105009621202394], {
             RGBColor[
             0.21195870855243037`, 0.3401124200198894, 0.9353821069360272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.0002105009621202394], {
             RGBColor[
             0.3465121371910148, 0.4745531298536097, 0.9433004248665277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.0002105009621202394], {
             RGBColor[
             0.186004909472108, 0.3128333316205655, 0.9339040764736078]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.0002105009621202394], {
             RGBColor[
             0.20936457771848743`, 0.3373858240360207, 0.9352343750227069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.0002105009621202394], {
             RGBColor[
             0.20110579749352597`, 0.32870532238267614`, 0.9347640497066657]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.0002105009621202394], {
             RGBColor[
             0.1811814280726413, 0.30776354684334156`, 0.9336293863436095]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.0002105009621202394], {
             RGBColor[
             0.18064334912177313`, 0.30719799174980317`, 0.933598743543374]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.0002105009621202394], {
             RGBColor[
             0.2879462259501837, 0.4199801186917991, 0.9397094836383711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.0002105009621202394], {
             RGBColor[
             0.2142707962291993, 0.34254257076299915`, 0.935513776908792]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.0002105009621202394], {
             RGBColor[
             0.42522253205912725`, 0.5427281177888938, 0.9483157816266544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.0002105009621202394], {
             RGBColor[
             0.27002626100566185`, 0.40114509934370585`, 0.9386889681449931]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.0002105009621202394], {
             RGBColor[
             0.2418162773238607, 0.37149461787786187`, 0.9370824513072455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.0002105009621202394], {
             RGBColor[
             0.22291581655962178`, 0.35162903525622036`, 0.9360060980274482]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.0002105009621202394], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.0002105009621202394], {
             RGBColor[
             0.18281412095909713`, 0.3094796105857146, 0.9337223657881405]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.0002105009621202394], {
             RGBColor[
             0.9306153171117766, 0.762619883962795, 0.26302965936154776`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.0002105009621202394], {
             RGBColor[
             0.8630600513163033, 0.8936446740513561, 0.986800632228994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.0002105009621202394], {
             RGBColor[
             0.21796667840296896`, 0.34642717726009525`, 0.9357242519310205]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.0002105009621202394], {
             RGBColor[
             0.1938965482594379, 0.32112794434484765`, 0.9343534936279129]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.0002105009621202394], {
             RGBColor[
             0.18280925758947733`, 0.30947449887588874`, 0.9337220888264354]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.0002105009621202394], {
             RGBColor[
             0.8199375785531087, 0.1542545422276314, 0.1667255537797183]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.0002105009621202394], {
             RGBColor[
             0.23104392871496413`, 0.36017219648356114`, 0.9364689819902305]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.0002105009621202394], {
             RGBColor[
             0.1798079986201722, 0.3063199854083397, 0.9335511715680982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.0002105009621202394], {
             RGBColor[
             0.17955783501139488`, 0.30605704759422586`, 0.9335369251206622]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.0002105009621202394], {
             RGBColor[
             0.1807265568208277, 0.30728544831718235`, 0.9336034820987404]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.0002105009621202394], {
             RGBColor[
             0.9450344910434499, 0.9585273939347413, 0.9779264487494559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.0002105009621202394], {
             RGBColor[
             0.3388378220394789, 0.4679060237916442, 0.9428114242912021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.0002105009621202394], {
             RGBColor[
             0.24074527521724318`, 0.3703689267583512, 0.9370214593216792]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.0002105009621202394], {
             RGBColor[
             0.4110226556238299, 0.5304288985271809, 0.947410978056655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.0002105009621202394], {
             RGBColor[
             0.19817896485079942`, 0.32562903570326285`, 0.9345973709175234]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.0002105009621202394], {
             RGBColor[
             0.19146940577852636`, 0.3185768637076881, 0.9342152714542605]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.0002105009621202394], {
             RGBColor[
             0.1892450123424645, 0.31623888517169746`, 0.934088595538772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.0002105009621202394], {
             RGBColor[
             0.6083786689975903, 0.6929482364957771, 0.9623129438694364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.0002105009621202394], {
             RGBColor[
             0.4932978290383352, 0.5995204262840937, 0.953253358592837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.0002105009621202394], {
             RGBColor[
             0.49739045300864126`, 0.6028430027937971, 0.9535755449435551]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.0002105009621202394], {
             RGBColor[
             0.2343202347626608, 0.3636158018694917, 0.9366555627727864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.0002105009621202394], {
             RGBColor[
             0.18118663655961964`, 0.30776902129339295`, 0.9336296829592377]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.0002105009621202394], {
             RGBColor[
             0.559409915392181, 0.6531931963016955, 0.9584579442071637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.0002105009621202394], {
             RGBColor[
             0.7481991240396009, 0.803218109314472, 0.9755371544320737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.0002105009621202394], {
             RGBColor[
             0.19288958051724012`, 0.32006955740235543`, 0.93429614830467]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.0002105009621202394], {
             RGBColor[
             0.20101540430520026`, 0.32861031341048663`, 0.9347589019483153]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.0002105009621202394], {
             RGBColor[
             0.965636915117815, 0.9738926480760296, 0.9430519187643377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.0002105009621202394], {
             RGBColor[
             0.2101475089071078, 0.33820873435596516`, 0.9352789617956558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.0002105009621202394], {
             RGBColor[
             0.1831002535865883, 0.30978035411906424`, 0.9337386606179808]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.0002105009621202394], {
             RGBColor[
             0.2774713947406823, 0.40897040694795533`, 0.9391129574971142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.0002105009621202394], {
             RGBColor[
             0.19434739415987903`, 0.3216018119714924, 0.9343791686349763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.0002105009621202394], {
             RGBColor[
             0.8190091230934095, 0.14711802671260676`, 0.16583646378296987`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.0002105009621202394], {
             RGBColor[
             0.20947576509879728`, 0.3375026890224135, 0.9352407069795285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.0002105009621202394], {
             RGBColor[
             0.22681870684301533`, 0.35573122040160343`, 0.9362283618552786]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.0002105009621202394], {
             RGBColor[
             0.34861868121472545`, 0.4763777124089667, 0.9434346519889747]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.0002105009621202394], {
             RGBColor[
             0.256153514960176, 0.38656396366699863`, 0.9378989357805914]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.0002105009621202394], {
             RGBColor[
             0.18132254229683142`, 0.30791186684012395`, 0.9336374225899173]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.0002105009621202394], {
             RGBColor[
             0.18343408206602244`, 0.3101312290168976, 0.9337576716560296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.0002105009621202394], {
             RGBColor[
             0.18925042984728385`, 0.3162445793127523, 0.934088904057657]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.0002105009621202394], {
             RGBColor[
             0.937107871400364, 0.788360698201582, 0.2682537209419814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.0002105009621202394], {
             RGBColor[
             0.30752560771325343`, 0.4405592903292892, 0.9408245004646784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.0002105009621202394], {
             RGBColor[
             0.24129060741956473`, 0.3709421054790498, 0.9370525151838548]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.0002105009621202394], {
             RGBColor[
             0.8646080428941941, 0.47809856902505976`, 0.2087379710414105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.0002105009621202394], {
             RGBColor[
             0.18333815129494635`, 0.31003039969413443`, 0.9337522085405336]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.0002105009621202394], {
             RGBColor[
             0.22614100723621103`, 0.3550189151462153, 0.9361897678652379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.0002105009621202394], {
             RGBColor[
             0.2388812891503496, 0.36840975921850344`, 0.93691530807269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.0002105009621202394], {
             RGBColor[
             0.18241596627536708`, 0.30906112476864933`, 0.9336996914679191]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.0002105009621202394], {
             RGBColor[
             0.5182991743784003, 0.6198176447289311, 0.9552215560809526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.0002105009621202394], {
             RGBColor[
             0.3109061797336599, 0.4437130391115059, 0.9410316447424569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.0002105009621202394], {
             RGBColor[
             0.5979628209588992, 0.6844921818293608, 0.9614929701573222]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.0002105009621202394], {
             RGBColor[
             0.21169783120855037`, 0.3398382213908926, 0.9353672503572267]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.0002105009621202394], {
             RGBColor[
             0.3097296345397099, 0.44269397479938727`, 0.9409566763230764]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.0002105009621202394], {
             RGBColor[
             0.2615118954900493, 0.3921959613448436, 0.9382040876247539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.0002105009621202394], {
             RGBColor[
             0.1865862227024127, 0.3134443286830033, 0.9339371814020978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.0002105009621202394], {
             RGBColor[
             0.19480415931956344`, 0.32208190111490453`, 0.9344051807350968]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.0002105009621202394], {
             RGBColor[
             0.19461177340916913`, 0.32187969132510885`, 0.9343942246421093]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.0002105009621202394], {
             RGBColor[
             0.189088316742455, 0.3160741881610126, 0.9340796719561618]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.0002105009621202394], {
             RGBColor[
             0.1820121662584413, 0.30863670534846055`, 0.9336766956543238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.0002105009621202394], {
             RGBColor[
             0.21325644631447746`, 0.3414764246891273, 0.9354560111817448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.0002105009621202394], {
             RGBColor[
             0.35827341580975897`, 0.4847401582541144, 0.9440498431400237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.0002105009621202394], {
             RGBColor[
             0.18578718983175693`, 0.312604494474334, 0.9338916776621772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.0002105009621202394], {
             RGBColor[
             0.830968185180272, 0.8680554911049849, 0.9837396813881922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.0002105009621202394], {
             RGBColor[
             0.9948422584139026, 0.9913764372120322, 0.679989842123797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.0002105009621202394], {
             RGBColor[
             0.18458947116943916`, 0.3113456162204888, 0.9338234693562242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.0002105009621202394], {
             RGBColor[
             0.33446348254021346`, 0.46411719077807645`, 0.9425326952463855]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.0002105009621202394], {
             RGBColor[
             0.18225239431662393`, 0.3088892002689491, 0.9336903762868517]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.0002105009621202394], {
             RGBColor[
             0.18805967833656198`, 0.31499302397697726`, 0.9340210925206803]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.0002105009621202394], {
             RGBColor[
             0.2256991535454318, 0.35455449890206425`, 0.9361646049512119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.0002105009621202394], {
             RGBColor[
             0.8655975347340893, 0.482591620368333, 0.20956362728728348`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.0002105009621202394], {
             RGBColor[
             0.18248883410320854`, 0.3091377134757978, 0.9337038411829164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.0002105009621202394], {
             RGBColor[
             0.18504307948317125`, 0.3118223873186494, 0.9338493016786379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.0002105009621202394], {
             RGBColor[
             0.1905501321581982, 0.3176106488474093, 0.9341629201815262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.0002105009621202394], {
             RGBColor[
             0.1972575262297792, 0.3246605452899877, 0.9345448963512025]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.0002105009621202394], {
             RGBColor[
             0.18614238840660097`, 0.3129778306973855, 0.9339119056955454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.0002105009621202394], {
             RGBColor[
             0.1834762116557925, 0.31017550988691617`, 0.9337600708738418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.0002105009621202394], {
             RGBColor[
             0.33397821749630197`, 0.46369687858717057`, 0.9425017745868906]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.0002105009621202394], {
             RGBColor[
             0.21660346779159745`, 0.34499435647499893`, 0.9356466191033923]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.0002105009621202394], {
             RGBColor[
             0.19354588592399127`, 0.3207593759970171, 0.9343335239266677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.0002105009621202394], {
             RGBColor[
             0.19201931518110454`, 0.3191548533560677, 0.9342465879812193]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.0002105009621202394], {
             RGBColor[
             0.25676930210776144`, 0.3872111950022711, 0.9379340039476709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.0002105009621202394], {
             RGBColor[
             0.1824446187841665, 0.30909124037207153`, 0.9337013231859077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.0002105009621202394], {
             RGBColor[
             0.2055125320888361, 0.33333707984545796`, 0.935015006722689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.0002105009621202394], {
             RGBColor[
             0.2070813101039675, 0.3349859650056321, 0.9351043463098516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.0002105009621202394], {
             RGBColor[
             0.8309858670902185, 0.23917652931476524`, 0.17730540736011186`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.0002105009621202394], {
             RGBColor[
             0.1873941802353717, 0.31429354327760956`, 0.9339831933883338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.0002105009621202394], {
             RGBColor[
             0.3387561380668311, 0.4678352732400925, 0.9428062194606953]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.0002105009621202394], {
             RGBColor[
             0.1805122222555836, 0.3070601690995145, 0.9335912760623294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.0002105009621202394], {
             RGBColor[
             0.4596234812344611, 0.572182073724828, 0.9506023905805157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.0002105009621202394], {
             RGBColor[
             0.1994550789542851, 0.32697031253633363`, 0.9346700437278752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.0002105009621202394], {
             RGBColor[
             0.27232886945688745`, 0.40356528681975196`, 0.9388200982898864]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.0002105009621202394], {
             RGBColor[
             0.26679472020223177`, 0.3977485450677799, 0.938504936676874]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.0002105009621202394], {
             RGBColor[
             0.20095261322947336`, 0.32854431600871353`, 0.9347553260894438]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.0002105009621202394], {
             RGBColor[
             0.8967495440562933, 0.920507761085305, 0.9900139661214994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.0002105009621202394], {
             RGBColor[
             0.9896948922783259, 0.9900065873749687, 0.82044583391943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.0002105009621202394], {
             RGBColor[
             0.3102543804501736, 0.4431484833325346, 0.9409901126684767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.0002105009621202394], {
             RGBColor[
             0.18420503135956878`, 0.31094154560542325`, 0.9338015760777798]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.0002105009621202394], {
             RGBColor[
             0.8957887014800139, 0.9197416112963568, 0.9899223200988196]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.0002105009621202394], {
             RGBColor[
             0.2316644133079956, 0.36082436513183264`, 0.936504317669879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.0002105009621202394], {
             RGBColor[
             0.188962757776349, 0.315942217726737, 0.93407252155879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.0002105009621202394], {
             RGBColor[
             0.8238032261936802, 0.18396760393066158`, 0.17042730232595416`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.0002105009621202394], {
             RGBColor[
             0.2824798268544749, 0.4142345866524884, 0.9393981802966833]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.0002105009621202394], {
             RGBColor[
             0.34399645769565007`, 0.4723741747164527, 0.943140127993611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.0002105009621202394], {
             RGBColor[
             0.28165135838121924`, 0.41336381375916165`, 0.9393510002427407]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.0002105009621202394], {
             RGBColor[
             0.23366891778676377`, 0.3629312264319425, 0.9366184712345461]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.0002105009621202394], {
             RGBColor[
             0.8948525196191675, 0.9189951252924975, 0.9898330262371927]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.0002105009621202394], {
             RGBColor[
             0.44169024668361, 0.5569916245052177, 0.9493650898406981]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.0002105009621202394], {
             RGBColor[
             0.45394807471440896`, 0.5675745230376996, 0.950155601789558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.0002105009621202394], {
             RGBColor[
             0.2585433275657887, 0.3890758082383683, 0.93803503207307]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.0002105009621202394], {
             RGBColor[
             0.19492367816056405`, 0.3222075229947284, 0.9344119871562795]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.0002105009621202394], {
             RGBColor[
             0.34853172220347034`, 0.47630239288410453`, 0.9434291110376724]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.0002105009621202394], {
             RGBColor[
             0.3499869056482099, 0.4775627996442913, 0.943521834040003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.0002105009621202394], {
             RGBColor[
             0.18311045325504194`, 0.3097910746173054, 0.9337392414740102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.0002105009621202394], {
             RGBColor[
             0.3996003392677278, 0.5205354622018381, 0.9466831581588019]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.0002105009621202394], {
             RGBColor[
             0.20685160848485196`, 0.33474453404001786`, 0.9350912651424561]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.0002105009621202394], {
             RGBColor[
             0.43492032413853554`, 0.551127857862875, 0.9489337163625334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.0002105009621202394], {
             RGBColor[
             0.2017846044041309, 0.3294187914845658, 0.9348027067560198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.0002105009621202394], {
             RGBColor[
             0.266643234211289, 0.39758932368653244`, 0.9384963097737932]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.0002105009621202394], {
             RGBColor[
             0.9562193148935751, 0.9668690172486966, 0.9589934594404549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.0002105009621202394], {
             RGBColor[
             0.20722377740839654`, 0.33513570717553587`, 0.9351124596120775]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.0002105009621202394], {
             RGBColor[
             0.18162114890697434`, 0.30822572132013676`, 0.933654427794616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.0002105009621202394], {
             RGBColor[
             0.18694492825143932`, 0.3138213509582757, 0.9339576091524576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.0002105009621202394], {
             RGBColor[
             0.9945316676487347, 0.9907121149708813, 0.6461839540792844]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.0002105009621202394], {
             RGBColor[
             0.20184829587443234`, 0.32948573525812513`, 0.9348063338910304]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.0002105009621202394], {
             RGBColor[
             0.18973547474422028`, 0.3167543922530552, 0.9341165266469779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.0002105009621202394], {
             RGBColor[
             0.9643115115712477, 0.9729041642811488, 0.9452954812480678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.0002105009621202394], {
             RGBColor[
             0.3533082208089774, 0.4804395559023944, 0.9437334653051234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.0002105009621202394], {
             RGBColor[
             0.18648980339442428`, 0.3133429858769703, 0.9339316904651475]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.0002105009621202394], {
             RGBColor[
             0.1842143453500115, 0.31095133519991963`, 0.9338021064957567]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.0002105009621202394], {
             RGBColor[
             0.9490437648216794, 0.9615175037539616, 0.971139794028986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.0002105009621202394], {
             RGBColor[
             0.2433593553333951, 0.37311649070267905`, 0.9371703273171091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.0002105009621202394], {
             RGBColor[
             0.2257570420476589, 0.35461534338824796`, 0.9361679016157753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.0002105009621202394], {
             RGBColor[
             0.19363457114614188`, 0.3208525897884652, 0.9343385744188711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.0002105009621202394], {
             RGBColor[
             0.3500177192487492, 0.4775894888363419, 0.943523797455382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.0002105009621202394], {
             RGBColor[
             0.7303132143006519, 0.7892455006884563, 0.9737544541026248]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.0002105009621202394], {
             RGBColor[
             0.18775722726537172`, 0.31467512872465075`, 0.9340038683796124]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.0002105009621202394], {
             RGBColor[
             0.9930152754848626, 0.9913796511608278, 0.7654184913108293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.0002105009621202394], {
             RGBColor[
             0.33484250288537293`, 0.4644454791509371, 0.9425568460876246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.0002105009621202394], {
             RGBColor[
             0.3056537490672848, 0.4385918482096833, 0.9407179008839572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.0002105009621202394], {
             RGBColor[
             0.22188954865981286`, 0.3505503626243781, 0.9359476535887813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.0002105009621202394], {
             RGBColor[
             0.41733642177677943`, 0.535897565429752, 0.9478132856528767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.0002105009621202394], {
             RGBColor[
             0.22261848399738943`, 0.3513165198813409, 0.9359891653778931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.0002105009621202394], {
             RGBColor[
             0.23974505627195325`, 0.36931763322930755`, 0.9369644983324363]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.0002105009621202394], {
             RGBColor[
             0.18299643202543156`, 0.30967123107562133`, 0.9337327481336631]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.0002105009621202394], {
             RGBColor[
             0.1997106484206986, 0.3272389322495743, 0.9346845980309063]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.0002105009621202394], {
             RGBColor[
             0.9930695883095065, 0.987584875103169, 0.4870456409120508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.0002105009621202394], {
             RGBColor[
             0.19086057119328328`, 0.3179369399562554, 0.934180599225321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.0002105009621202394], {
             RGBColor[
             0.3371253879726633, 0.4664227994724073, 0.9427023095067106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.0002105009621202394], {
             RGBColor[
             0.635822518194204, 0.7152283896049052, 0.9644734242083259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.0002105009621202394], {
             RGBColor[
             0.9023083761464576, 0.6492869771870501, 0.2401960532268301]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.0002105009621202394], {
             RGBColor[
             0.23238602207295528`, 0.3615828216964435, 0.9365454122215189]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.0002105009621202394], {
             RGBColor[
             0.9299021495647822, 0.7597924122879596, 0.2624558280130423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.0002105009621202394], {
             RGBColor[
             0.1793343425625045, 0.3058221428602024, 0.9335241975563253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.0002105009621202394], {
             RGBColor[
             0.884710274500928, 0.9109079743391231, 0.9888656498437259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.0002105009621202394], {
             RGBColor[
             0.44524034591787487`, 0.5600665420287623, 0.9495912990246761]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.0002105009621202394], {
             RGBColor[
             0.20746958876179836`, 0.3353940704933011, 0.9351264582050084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.0002105009621202394], {
             RGBColor[
             0.20359531165465325`, 0.33132195961033534`, 0.9349058238552358]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.0002105009621202394], {
             RGBColor[
             0.20688302376209858`, 0.33477755348824767`, 0.9350930541960206]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.0002105009621202394], {
             RGBColor[
             0.8177383166445533, 0.1373500514757623, 0.1646195380923747]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.0002105009621202394], {
             RGBColor[
             0.18219295480676673`, 0.3088267255754066, 0.9336869912946982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.0002105009621202394], {
             RGBColor[
             0.295092829761857, 0.42749165241872045`, 0.9401164721529931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.0002105009621202394], {
             RGBColor[
             0.9594063537213845, 0.9692459055881796, 0.9535986340178257]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.0002105009621202394], {
             RGBColor[
             0.7857227396767522, 0.8325318430402561, 0.9792771577606599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.0002105009621202394], {
             RGBColor[
             0.1915139828942802, 0.31862371708269777`, 0.9342178100550568]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.0002105009621202394], {
             RGBColor[
             0.25077535368791876`, 0.38091117517473666`, 0.9375926574524128]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.0002105009621202394], {
             RGBColor[
             0.19733278810728, 0.3247396502951197, 0.9345491824037863]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.0002105009621202394], {
             RGBColor[
             0.28998218143607674`, 0.4221200369945062, 0.9398254282913666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.0002105009621202394], {
             RGBColor[
             0.82776291630336, 0.2144035172609302, 0.17421910604681382`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.0002105009621202394], {
             RGBColor[
             0.8316889234682268, 0.24458052871740593`, 0.17797865494168116`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.0002105009621202394], {
             RGBColor[
             0.2632132370288079, 0.3939841791733627, 0.938300976508477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.0002105009621202394], {
             RGBColor[
             0.852273426221674, 0.40280203706702433`, 0.19769039802525293`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.0002105009621202394], {
             RGBColor[
             0.9695261963263196, 0.9767932676332187, 0.9364683801653377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.0002105009621202394], {
             RGBColor[
             0.9547654228714991, 0.9657847069591619, 0.9614545193980599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.0002105009621202394], {
             RGBColor[
             0.818830055518114, 0.14574163486097447`, 0.1656649884706391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.0002105009621202394], {
             RGBColor[
             0.9202453542726101, 0.9392426823750178, 0.9922550174748891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.0002105009621202394], {
             RGBColor[
             0.1976279917679603, 0.3250499280594878, 0.9345659938155473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.0002105009621202394], {
             RGBColor[
             0.21799885977606132`, 0.3464610019236322, 0.9357260846126101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.0002105009621202394], {
             RGBColor[
             0.3090764058516128, 0.442128180941986, 0.9409150531686984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.0002105009621202394], {
             RGBColor[
             0.25834749102875554`, 0.38886997162119286`, 0.9380238794720002]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.0002105009621202394], {
             RGBColor[
             0.19027393338711107`, 0.3173203464269832, 0.9341471910701123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.0002105009621202394], {
             RGBColor[
             0.3695662131784596, 0.4945214117423836, 0.9447694102025287]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.0002105009621202394], {
             RGBColor[
             0.19109293756035423`, 0.31818117174092553`, 0.9341938321461705]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.0002105009621202394], {
             RGBColor[
             0.18724741023772068`, 0.314139278704323, 0.9339748350540943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.0002105009621202394], {
             RGBColor[
             0.8353613957275855, 0.2728087597904426, 0.18149541852470724`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.0002105009621202394], {
             RGBColor[
             0.3513087838325387, 0.47870774408802763`, 0.9436060629490174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.0002105009621202394], {
             RGBColor[
             0.32310439559809073`, 0.45427852059311985`, 0.9418089042708796]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.0002105009621202394], {
             RGBColor[
             0.18340786605487358`, 0.31010367432698904`, 0.9337561786929778]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.0002105009621202394], {
             RGBColor[
             0.18623692915551526`, 0.3130771990187241, 0.9339172896513356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.0002105009621202394], {
             RGBColor[
             0.22458179928431016`, 0.35338008872927346`, 0.9361009732790185]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.0002105009621202394], {
             RGBColor[
             0.2599700418165058, 0.39057537537478015`, 0.9381162813390138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.0002105009621202394], {
             RGBColor[
             0.2141514811516508, 0.34241716305148284`, 0.9355069820916365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.0002105009621202394], {
             RGBColor[
             0.3919526428400527, 0.5139114119405849, 0.9461958537050229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.0002105009621202394], {
             RGBColor[
             0.7232916660208124, 0.7837602138065023, 0.9730546117901898]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.0002105009621202394], {
             RGBColor[
             0.18998272969436467`, 0.3170142728825262, 0.9341306074506077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.0002105009621202394], {
             RGBColor[
             0.23275233921967517`, 0.3619678442434947, 0.9365662734411069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.0002105009621202394], {
             RGBColor[
             0.2559867658273416, 0.386388699755884, 0.9378894396641596]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.0002105009621202394], {
             RGBColor[
             0.679362894162589, 0.7494427233598264, 0.9686762023490751]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.0002105009621202394], {
             RGBColor[
             0.743581503407994, 0.7996107889818441, 0.9750769131616334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.0002105009621202394], {
             RGBColor[
             0.3590992451452233, 0.4854554501171043, 0.9441024642550272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.0002105009621202394], {
             RGBColor[
             0.17909981633317154`, 0.30557564092335165`, 0.9335108416345153]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.0002105009621202394], {
             RGBColor[
             0.7409332819620127, 0.7975419782610151, 0.9748129631969344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.0002105009621202394], {
             RGBColor[
             0.1818250295794584, 0.30844001283369876`, 0.9336660384972996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.0002105009621202394], {
             RGBColor[
             0.49307848673520527`, 0.5993423543211548, 0.9532360911632574]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.0002105009621202394], {
             RGBColor[
             0.23875032994207512`, 0.36827211278731364`, 0.9369078501395155]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.0002105009621202394], {
             RGBColor[
             0.22285712514090053`, 0.35156734685389346`, 0.9360027556379781]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.0002105009621202394], {
             RGBColor[
             0.20781531186542476`, 0.3357574473953233, 0.9351461466243084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.0002105009621202394], {
             RGBColor[
             0.25816588373595994`, 0.3886790908418973, 0.9380135372053394]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.0002105009621202394], {
             RGBColor[
             0.6722342021283076, 0.7438737349625797, 0.9679656809485127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.0002105009621202394], {
             RGBColor[
             0.2515360626002474, 0.3817107284733248, 0.937635978699602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.0002105009621202394], {
             RGBColor[
             0.4286879330306734, 0.5457296739343299, 0.9485365939122276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.0002105009621202394], {
             RGBColor[
             0.2671426063657563, 0.39811419548290095`, 0.9385247482792353]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.0002105009621202394], {
             RGBColor[
             0.20898033639140454`, 0.33698196203894937`, 0.9352124930475636]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.0002105009621202394], {
             RGBColor[
             0.2765987024765969, 0.40805315204651627`, 0.939063258963707]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.0002105009621202394], {
             RGBColor[
             0.9941990383585994, 0.9900006545532618, 0.6099793085980734]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.0002105009621202394], {
             RGBColor[
             0.1948453625020903, 0.32212520827217295`, 0.9344075271953871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.0002105009621202394], {
             RGBColor[
             0.1899324083338537, 0.31696138194207063`, 0.9341277417235704]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.0002105009621202394], {
             RGBColor[
             0.30537118422496984`, 0.4382948546447645, 0.9407018092342045]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.0002105009621202394], {
             RGBColor[
             0.1861676814246589, 0.31300441526303435`, 0.9339133460955061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.0002105009621202394], {
             RGBColor[
             0.19821724293608944`, 0.32566926839787347`, 0.9345995507978533]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.0002105009621202394], {
             RGBColor[
             0.18717515147111807`, 0.3140633301591533, 0.9339707200242335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.0002105009621202394], {
             RGBColor[
             0.1943854920349882, 0.321641855253777, 0.934381338252603]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.0002105009621202394], {
             RGBColor[
             0.3488943015599562, 0.47661644089892424`, 0.9434522142736513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.0002105009621202394], {
             RGBColor[
             0.1899597624904289, 0.3169901328949849, 0.9341292995023205]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.0002105009621202394], {
             RGBColor[
             0.4290348579738498, 0.5460301628831548, 0.9485586996628331]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.0002105009621202394], {
             RGBColor[
             0.2449605595581574, 0.37479945786511576`, 0.9372615135289399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.0002105009621202394], {
             RGBColor[
             0.20692052412863532`, 0.33481696875113837`, 0.935095189786418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.0002105009621202394], {
             RGBColor[
             0.19699767297971368`, 0.3243874230485212, 0.9345300980930298]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.0002105009621202394], {
             RGBColor[
             0.18766218808016377`, 0.31457523651516484`, 0.9339984560386126]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.0002105009621202394], {
             RGBColor[
             0.9146994662552146, 0.9348205418090667, 0.9917260457249173]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.0002105009621202394], {
             RGBColor[
             0.18269671784651187`, 0.30935621247060024`, 0.933715679854561]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.0002105009621202394], {
             RGBColor[
             0.19137511524925596`, 0.3184777583830601, 0.9342099017481089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.0002105009621202394], {
             RGBColor[
             0.21323548342695858`, 0.34145439136522115`, 0.9354548173763124]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.0002105009621202394], {
             RGBColor[
             0.1808905282724361, 0.3074577927092133, 0.9336128200303355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.0002105009621202394], {
             RGBColor[
             0.18223318953702214`, 0.3088690148279342, 0.9336892826030643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.0002105009621202394], {
             RGBColor[
             0.20271236623405806`, 0.3303939279913168, 0.9348555414197336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.0002105009621202394], {
             RGBColor[
             0.3483545068205488, 0.47614889782652203`, 0.9434178190301781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.0002105009621202394], {
             RGBColor[
             0.20150049615977755`, 0.32912017570624735`, 0.9347865272118044]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.0002105009621202394], {
             RGBColor[
             0.2975965440226766, 0.4301232148514946, 0.9402590549762334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.0002105009621202394], {
             RGBColor[
             0.27959908951497947`, 0.4112067490593821, 0.9392341265668681]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.0002105009621202394], {
             RGBColor[
             0.3027440138032642, 0.4355335319593264, 0.9405521957652387]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.0002105009621202394], {
             RGBColor[
             0.3029090080003519, 0.4357069513217019, 0.9405615919406759]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.0002105009621202394], {
             RGBColor[
             0.218367213855187, 0.3468481654157909, 0.9357470618324852]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.0002105009621202394], {
             RGBColor[
             0.23267428983588884`, 0.3618858093925185, 0.936561828644164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.0002105009621202394], {
             RGBColor[
             0.2188459842157359, 0.34735138342052185`, 0.9357743270962412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.0002105009621202394], {
             RGBColor[
             0.23435379828218117`, 0.36365107925655765`, 0.9366574741655703]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.0002105009621202394], {
             RGBColor[
             0.1953540422101205, 0.32265986289746895`, 0.9344364957522352]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.0002105009621202394], {
             RGBColor[
             0.19439044372267295`, 0.3216470597914888, 0.9343816202438913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.0002105009621202394], {
             RGBColor[
             0.4533617737780597, 0.567098537525015, 0.9501094460321575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.0002105009621202394], {
             RGBColor[
             0.19579265616170655`, 0.32312087397031664`, 0.9344614741679068]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.0002105009621202394], {
             RGBColor[
             0.5543615420614805, 0.6490946994052059, 0.9580605177657702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.0002105009621202394], {
             RGBColor[
             0.1999051049994005, 0.32744331844304914`, 0.9346956720453906]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.0002105009621202394], {
             RGBColor[
             0.3986910652219958, 0.5197478947248675, 0.9466252200206473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.0002105009621202394], {
             RGBColor[
             0.6331296311169758, 0.713042182562431, 0.9642614302732361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.0002105009621202394], {
             RGBColor[
             0.289139123347183, 0.42123392949010874`, 0.9397774173803968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.0002105009621202394], {
             RGBColor[
             0.19201165546058205`, 0.31914680250414423`, 0.9342461517714671]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.0002105009621202394], {
             RGBColor[
             0.19560708734050541`, 0.3229258293734914, 0.9344509062980639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.0002105009621202394], {
             RGBColor[
             0.8695307562797816, 0.5004514607800906, 0.21284560375709155`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.0002105009621202394], {
             RGBColor[
             0.19044334897469703`, 0.3174984129511047, 0.9341568390371975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.0002105009621202394], {
             RGBColor[
             0.18593025704413854`, 0.31275486718553225`, 0.9338998251282734]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.0002105009621202394], {
             RGBColor[
             0.19914754728651962`, 0.3266470772548782, 0.9346525302543484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.0002105009621202394], {
             RGBColor[
             0.2283446787479909, 0.35733511362593967`, 0.9363152636977938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.0002105009621202394], {
             RGBColor[
             0.18811264277564865`, 0.31504869296059673`, 0.9340241087671325]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.0002105009621202394], {
             RGBColor[
             0.1849809522741401, 0.31175708768286514`, 0.9338457636259925]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.0002105009621202394], {
             RGBColor[
             0.1795029989097729, 0.3059994113746115, 0.9335338022857975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.0002105009621202394], {
             RGBColor[
             0.18035329176886106`, 0.3068931230811942, 0.933582225206227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.0002105009621202394], {
             RGBColor[
             0.9940468194635823, 0.9896750737285114, 0.5934112212615963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.0002105009621202394], {
             RGBColor[
             0.23420030298526878`, 0.3634897459673388, 0.9366487328354871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.0002105009621202394], {
             RGBColor[
             0.2515477771449798, 0.3817230412025836, 0.9376366458255944]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.0002105009621202394], {
             RGBColor[
             0.2029347338096705, 0.33062765041220404`, 0.9348682049242014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.0002105009621202394], {
             RGBColor[
             0.3362350503435996, 0.46565163376778274`, 0.9426455779802814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.0002105009621202394], {
             RGBColor[
             0.18371444184961855`, 0.31042590492529404`, 0.9337736377309502]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.0002105009621202394], {
             RGBColor[
             0.1820208818055452, 0.30864586594106436`, 0.9336771919918379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.0002105009621202394], {
             RGBColor[
             0.1912494582787511, 0.31834568493994736`, 0.9342027457695316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.0002105009621202394], {
             RGBColor[
             0.1789871968344326, 0.3054572706896884, 0.9335044281206677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.0002105009621202394], {
             RGBColor[
             0.3510664211934816, 0.47849782175157674`, 0.9435906198159696]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.0002105009621202394], {
             RGBColor[
             0.19785125300646603`, 0.3252845897767374, 0.9345787082127948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.0002105009621202394], {
             RGBColor[
             0.33313964664549794`, 0.4629705506640006, 0.9424483415937963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.0002105009621202394], {
             RGBColor[
             0.2019856527302044, 0.3296301060224692, 0.9348141561607654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.0002105009621202394], {
             RGBColor[
             0.9938504692273173, 0.9917250252368329, 0.751577169586235]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.0002105009621202394], {
             RGBColor[
             0.9097894237460113, 0.9309054071917814, 0.9912577214871428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.0002105009621202394], {
             RGBColor[
             0.2396024194233052, 0.3691677128576799, 0.9369563753749182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.0002105009621202394], {
             RGBColor[
             0.19002087389400624`, 0.31705436485483146`, 0.934132779706348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.0002105009621202394], {
             RGBColor[
             0.2158527042869893, 0.34420525643050026`, 0.9356038642324599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.0002105009621202394], {
             RGBColor[
             0.7657071355725306, 0.8168955009898127, 0.9772821894000061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.0002105009621202394], {
             RGBColor[
             0.19499177110397153`, 0.3222790929955916, 0.9344158649486721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.0002105009621202394], {
             RGBColor[
             0.85710048921771, 0.439904958487049, 0.20231279900164487`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.0002105009621202394], {
             RGBColor[
             0.19077583416012883`, 0.31784787596177183`, 0.9341757735766401]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.0002105009621202394], {
             RGBColor[
             0.18720392975649292`, 0.3140935779617309, 0.9339723589050121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.0002105009621202394], {
             RGBColor[
             0.18524924480481392`, 0.31203908014333226`, 0.9338610424887112]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.0002105009621202394], {
             RGBColor[
             0.21763599434706354`, 0.34607960735075854`, 0.93570541996324]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.0002105009621202394], {
             RGBColor[
             0.18916507484151227`, 0.3161548657898664, 0.9340840432163497]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.0002105009621202394], {
             RGBColor[
             0.21990087473071346`, 0.348460140235685, 0.9358344015504985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.0002105009621202394], {
             RGBColor[
             0.8176771202476999, 0.13687966915311423`, 0.16456093635363633`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.0002105009621202394], {
             RGBColor[
             0.18093049359979738`, 0.3074997988022181, 0.9336150959966053]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.0002105009621202394], {
             RGBColor[
             0.39439940253334044`, 0.5160306722091927, 0.9463517590690945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.0002105009621202394], {
             RGBColor[
             0.37508215881778845`, 0.49929904661568136`, 0.9451208813811075]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.0002105009621202394], {
             RGBColor[
             0.1851720653526604, 0.311957959645659, 0.9338566472330878]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.0002105009621202394], {
             RGBColor[
             0.19059767181486464`, 0.3176606160407541, 0.9341656274946448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.0002105009621202394], {
             RGBColor[
             0.18708771794254558`, 0.3139714319770177, 0.9339657408141276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.0002105009621202394], {
             RGBColor[
             0.18654757264035143`, 0.3134037050172214, 0.9339349803382411]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.0002105009621202394], {
             RGBColor[
             0.19406834726399882`, 0.3213085159913272, 0.9343632773270688]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.0002105009621202394], {
             RGBColor[
             0.271851153445097, 0.4030631770024157, 0.9387928930697325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.0002105009621202394], {
             RGBColor[
             0.19021908584372046`, 0.31726269818134456`, 0.934144067583656]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.0002105009621202394], {
             RGBColor[
             0.180596656524124, 0.30714891486919227`, 0.9335960844690134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.0002105009621202394], {
             RGBColor[
             0.209601906353837, 0.3376352714792777, 0.9352478905373938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.0002105009621202394], {
             RGBColor[
             0.18473621585810335`, 0.3114998541924255, 0.9338318262491543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.0002105009621202394], {
             RGBColor[
             0.19081859398490578`, 0.3178928192487419, 0.9341782086854036]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.0002105009621202394], {
             RGBColor[
             0.20710183530283005`, 0.33500753829100943`, 0.9351055151895625]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.0002105009621202394], {
             RGBColor[
             0.22012423896070668`, 0.348694910203518, 0.9358471218129588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.0002105009621202394], {
             RGBColor[
             0.19616341759440778`, 0.32351056774371817`, 0.9344825884830068]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.0002105009621202394], {
             RGBColor[
             0.1818914944971056, 0.30850987167626515`, 0.9336698235760336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.0002105009621202394], {
             RGBColor[
             0.20835388918653433`, 0.3363235263075839, 0.9351768178059918]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.0002105009621202394], {
             RGBColor[
             0.18955786573703887`, 0.316567713925446, 0.9341064120767679]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.0002105009621202394], {
             RGBColor[
             0.9944253181788963, 0.9904846442084778, 0.6346084706002231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.0002105009621202394], {
             RGBColor[
             0.7607606134285254, 0.8130312402959552, 0.9767891663005692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.0002105009621202394], {
             RGBColor[
             0.5341260408491124, 0.6326666079220644, 0.9564675049852491]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.0002105009621202394], {
             RGBColor[
             0.2195142065627996, 0.3480537274750297, 0.9358123813703602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.0002105009621202394], {
             RGBColor[
             0.20264865261830456`, 0.3303269609414833, 0.9348519130235723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.0002105009621202394], {
             RGBColor[
             0.2627109211596987, 0.39345621334626335`, 0.938272370362841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.0002105009621202394], {
             RGBColor[
             0.18112688553091424`, 0.3077062191737896, 0.9336262802265466]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.0002105009621202394], {
             RGBColor[
             0.9910839134677017, 0.9905809833329919, 0.7974261581398643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.0002105009621202394], {
             RGBColor[
             0.18336325239717496`, 0.31005678254407854`, 0.9337536380111718]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.0002105009621202394], {
             RGBColor[
             0.18043226082461958`, 0.30697612456572376`, 0.9335867223771283]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.0002105009621202394], {
             RGBColor[
             0.46863892160806836`, 0.5795012143610829, 0.9513121190713723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.0002105009621202394], {
             RGBColor[
             0.19955786085140656`, 0.3270783428269569, 0.9346758970048641]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.0002105009621202394], {
             RGBColor[
             0.2129233554713194, 0.341126325093789, 0.9354370421509908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.0002105009621202394], {
             RGBColor[
             0.4260942433398349, 0.54348315028676, 0.9483713262986371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.0002105009621202394], {
             RGBColor[
             0.9265760623547111, 0.7466055848528861, 0.2597795801705179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.0002105009621202394], {
             RGBColor[
             0.8501784807301029, 0.38669936800784144`, 0.19568427585662201`]},
             StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{3.8349502435193233`*^9, 3.834957407142641*^9, 
  3.8349598090610213`*^9, 3.835023938778575*^9},
 CellLabel->
  "Out[205]=",ExpressionUUID->"793a2a47-f363-415a-8c99-30ef773192ea"]
}, Open  ]],

Cell["Estimated with absolute Mean Deviation v Calculated: (r=6)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 
  3.8349503922098827`*^9}},ExpressionUUID->"b01746e6-1c24-40da-9dac-\
ae73b328198a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphin4b", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsi4b", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}],
      "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"AMDi6400b", ",", "kri4b"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502409842243`*^9}, {3.8349504019691753`*^9, 3.834950402221115*^9}, {
   3.8349577477528667`*^9, 3.8349577551942053`*^9}, {3.8349598169833813`*^9, 
   3.8349598253674707`*^9}},
 CellLabel->
  "In[206]:=",ExpressionUUID->"ea0ccbf8-9ec6-41c3-a660-ceb2fa1b7cc2"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN2wucznW+wPHf/+zadNlSKJUyheimsIbchiJLGlM0NrNmJtWMMW5DaZZc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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[337, 399] -> 
             RGBColor[
              0.9920247910550795, 0.9900095624703071, 0.7120153220230777], 
             UndirectedEdge[15, 92] -> 
             RGBColor[
              0.9777291094385683, 0.9369716986650458, 0.5286808066584634], 
             UndirectedEdge[87, 313] -> 
             RGBColor[
              0.9931705213060869, 0.9870776760000367, 0.5595174677730553], 
             UndirectedEdge[35, 214] -> 
             RGBColor[
              0.9494585993065829, 0.9529052025993756, 0.7017000652239718], 
             UndirectedEdge[105, 218] -> 
             RGBColor[
              0.9844541264065585, 0.986190976564977, 0.8334792966190898], 
             UndirectedEdge[149, 316] -> 
             RGBColor[
              0.9652232343959615, 0.8946005489269867, 0.5369775263568979], 
             UndirectedEdge[160, 348] -> 
             RGBColor[
              0.9615398577692174, 0.9705803216940694, 0.9384894807176856], 
             UndirectedEdge[17, 287] -> 
             RGBColor[
              0.9886827055461808, 0.9724567245842287, 0.4980782670570499], 
             UndirectedEdge[268, 295] -> 
             RGBColor[
              0.9268557878309867, 0.9417627132432057, 0.8843752207704405], 
             UndirectedEdge[277, 379] -> 
             RGBColor[
              0.9787217348506241, 0.9390427925286449, 0.4435009654566403], 
             UndirectedEdge[10, 37] -> 
             RGBColor[
              0.9773940988663481, 0.9699195523682438, 0.6680231088500093], 
             UndirectedEdge[118, 389] -> 
             RGBColor[
              0.9905768307446454, 0.9838293137552973, 0.6029165944236043], 
             UndirectedEdge[127, 313] -> 
             RGBColor[
              0.9921946001163285, 0.9849902792559119, 0.45329446895531555`], 
             UndirectedEdge[92, 281] -> 
             RGBColor[
              0.9755494461290541, 0.9360703518717697, 0.5648034684849381], 
             UndirectedEdge[2, 193] -> 
             RGBColor[
              0.9709065433330959, 0.9349296439542705, 0.614998919717755], 
             UndirectedEdge[265, 378] -> 
             RGBColor[
              0.9631945000141574, 0.9251770670683014, 0.6195601428664193], 
             UndirectedEdge[108, 367] -> 
             RGBColor[
              0.9740134374969356, 0.9610957940899868, 0.6603667429896145], 
             UndirectedEdge[26, 342] -> 
             RGBColor[
              0.97227931488156, 0.9757911732335793, 0.7530597858655176], 
             UndirectedEdge[57, 144] -> 
             RGBColor[
              0.9424135886934057, 0.8606454780024364, 0.6101112006874331], 
             UndirectedEdge[341, 348] -> 
             RGBColor[
              0.9545200586334317, 0.8609989557278015, 0.5715887131842876], 
             UndirectedEdge[232, 309] -> 
             RGBColor[
              0.9903312851663982, 0.9776101256786878, 0.5391458818242217], 
             UndirectedEdge[23, 202] -> 
             RGBColor[
              0.9837776777090815, 0.9858359573998582, 0.8413181511414486], 
             UndirectedEdge[89, 170] -> 
             RGBColor[
              0.9866926107190892, 0.9870701329334177, 0.7706791460197004], 
             UndirectedEdge[291, 383] -> 
             RGBColor[
              0.9332012376117995, 0.7728721970384621, 0.26511035169522174`], 
             UndirectedEdge[45, 140] -> 
             RGBColor[
              0.9708774121816628, 0.9202589321802012, 0.5573887867137362], 
             UndirectedEdge[213, 308] -> 
             RGBColor[
              0.9293326022296471, 0.7418986961951546, 0.30167825612212895`], 
             UndirectedEdge[165, 386] -> 
             RGBColor[
              0.9892834719629269, 0.98113245757171, 0.6094071011685092], 
             UndirectedEdge[347, 381] -> 
             RGBColor[
              0.9945827303672009, 0.991287520121694, 0.685628701017124], 
             UndirectedEdge[216, 396] -> 
             RGBColor[
              0.993162603310225, 0.9877838247844468, 0.49716974971821926`], 
             UndirectedEdge[39, 150] -> 
             RGBColor[
              0.9856902081112485, 0.9616951894645742, 0.5431816306121151], 
             UndirectedEdge[20, 378] -> 
             RGBColor[
              0.7428335458883891, 0.75086037639464, 0.6268520485399902], 
             UndirectedEdge[363, 372] -> 
             RGBColor[
              0.9929702779836942, 0.9871753696073305, 0.4929954996267124], 
             UndirectedEdge[54, 318] -> 
             RGBColor[
              0.9890557880309855, 0.9874542232597161, 0.6647183226656943], 
             UndirectedEdge[40, 246] -> 
             RGBColor[
              0.9783688776130631, 0.9833881248583104, 0.921500027287528], 
             UndirectedEdge[59, 178] -> 
             RGBColor[
              0.9936391093761218, 0.9888030230772464, 0.5490344943365179], 
             UndirectedEdge[172, 357] -> 
             RGBColor[
              0.9934533452931028, 0.9909188770411007, 0.711497206839451], 
             UndirectedEdge[268, 274] -> 
             RGBColor[
              0.9927700839519419, 0.9897670213482382, 0.6596309866980661], 
             UndirectedEdge[122, 175] -> 
             RGBColor[
              0.9932406003383885, 0.9895077540664616, 0.6188440881951849], 
             UndirectedEdge[120, 341] -> 
             RGBColor[
              0.9546525270758686, 0.8610537348330327, 0.5693933682757681], 
             UndirectedEdge[220, 366] -> 
             RGBColor[
              0.9938052226270642, 0.9891583225243862, 0.5671148965694386], 
             UndirectedEdge[202, 366] -> 
             RGBColor[
              0.9943517973704254, 0.9916588371942747, 0.7233882938378788], 
             UndirectedEdge[17, 61] -> 
             RGBColor[
              0.961767577545643, 0.8780754949592158, 0.33003420587329907`], 
             UndirectedEdge[112, 279] -> 
             RGBColor[
              0.9842354540136973, 0.9569510742631412, 0.5236603217632598], 
             UndirectedEdge[129, 313] -> 
             RGBColor[
              0.9928596467736628, 0.9864127468094183, 0.5256806934139225], 
             UndirectedEdge[204, 318] -> 
             RGBColor[
              0.9764602746967264, 0.9817504015741938, 0.9151344343012433], 
             UndirectedEdge[60, 335] -> 
             RGBColor[
              0.9304758020299917, 0.7387255457356581, 0.41893032455741674`], 
             UndirectedEdge[256, 386] -> 
             RGBColor[
              0.9918559539531716, 0.9892648772363658, 0.6657577010225054], 
             UndirectedEdge[7, 65] -> 
             RGBColor[
              0.9378450463408037, 0.7794355437939149, 0.3116974510664284], 
             UndirectedEdge[66, 280] -> 
             RGBColor[
              0.9817789495008209, 0.9833046804216592, 0.770994516304759], 
             UndirectedEdge[147, 344] -> 
             RGBColor[
              0.8902698415916347, 0.5946228034447788, 0.2301508049028011], 
             UndirectedEdge[329, 349] -> 
             RGBColor[
              0.9650016270195668, 0.9719649404382062, 0.8790181990250207], 
             UndirectedEdge[170, 306] -> 
             RGBColor[
              0.9845286384863194, 0.9854562459853973, 0.7743421865554303], 
             UndirectedEdge[175, 178] -> 
             RGBColor[
              0.9930567691774437, 0.9891145578013825, 0.5988352008007788], 
             UndirectedEdge[115, 166] -> 
             RGBColor[
              0.9631940185799455, 0.8923494079013927, 0.5636973403196543], 
             UndirectedEdge[361, 396] -> 
             RGBColor[
              0.9934730607507238, 0.9884478618576116, 0.530961126195286], 
             UndirectedEdge[80, 265] -> 
             RGBColor[
              0.9804255596363569, 0.9822878421723196, 0.7726917634740694], 
             UndirectedEdge[18, 288] -> 
             RGBColor[
              0.9777661156097885, 0.9571840823122453, 0.6397694161331529], 
             UndirectedEdge[225, 240] -> 
             RGBColor[
              0.9457414033384735, 0.8072320072179966, 0.4681412041652081], 
             UndirectedEdge[110, 251] -> 
             RGBColor[
              0.8934493603134446, 0.9132981578689564, 0.7394452334466335], 
             UndirectedEdge[56, 169] -> 
             RGBColor[
              0.9868650291385044, 0.9664146910136404, 0.483413666367122], 
             UndirectedEdge[87, 231] -> 
             RGBColor[
              0.9660348010888795, 0.9721572402046625, 0.8448178632368313], 
             UndirectedEdge[266, 315] -> 
             RGBColor[
              0.9441548347327264, 0.8162995595530758, 0.2739238730526894], 
             UndirectedEdge[31, 292] -> 
             RGBColor[
              0.9859691535400709, 0.988465898659582, 0.8821909667150922], 
             UndirectedEdge[1, 87] -> 
             RGBColor[
              0.9831301455185285, 0.9532091308762585, 0.5205125038042628], 
             UndirectedEdge[231, 336] -> 
             RGBColor[
              0.9481157973828385, 0.9608254271574812, 0.9727106008502737], 
             UndirectedEdge[13, 309] -> 
             RGBColor[
              0.9901355765993882, 0.9779177031747484, 0.5706297108665758], 
             UndirectedEdge[237, 296] -> 
             RGBColor[
              0.9867238711235232, 0.9880141049807143, 0.8354748422551902], 
             UndirectedEdge[95, 312] -> 
             RGBColor[
              0.9933522839989224, 0.9877559733570995, 0.554682070440768], 
             UndirectedEdge[108, 236] -> 
             RGBColor[
              0.9721092276108825, 0.959675637474826, 0.6635900736292233], 
             UndirectedEdge[48, 176] -> 
             RGBColor[
              0.9761500306947214, 0.9796861848114327, 0.8265070514564374], 
             UndirectedEdge[49, 52] -> 
             RGBColor[
              0.973245972080542, 0.9392495210250668, 0.6165054011918987], 
             UndirectedEdge[310, 390] -> 
             RGBColor[
              0.9827354265176975, 0.9518821427499001, 0.5185971492055212], 
             UndirectedEdge[343, 358] -> 
             RGBColor[
              0.9050878493572301, 0.5606282628929022, 0.3140459611467675], 
             UndirectedEdge[271, 374] -> 
             RGBColor[
              0.9754687930783343, 0.9289126202312354, 0.3592013227493882], 
             UndirectedEdge[57, 167] -> 
             RGBColor[
              0.9754114068355861, 0.9788156549799449, 0.8023932694006202], 
             UndirectedEdge[34, 214] -> 
             RGBColor[
              0.9486027698374206, 0.9599909835364515, 0.9250015531154289], 
             UndirectedEdge[83, 220] -> 
             RGBColor[
              0.9840729430977735, 0.9578485055871766, 0.40010400928246226`], 
             UndirectedEdge[9, 347] -> 
             RGBColor[
              0.9171091586927157, 0.9334667452898293, 0.8606799458381074], 
             UndirectedEdge[188, 238] -> 
             RGBColor[
              0.8215635744367447, 0.859872969289208, 0.9058254620484087], 
             UndirectedEdge[79, 137] -> 
             RGBColor[
              0.9491226198441998, 0.889107809297212, 0.6169550557594734], 
             UndirectedEdge[115, 197] -> 
             RGBColor[
              0.9628600561222531, 0.8922113058426933, 0.5692319625107534], 
             UndirectedEdge[67, 194] -> 
             RGBColor[
              0.9782394095467696, 0.9489551450217433, 0.6015943702297679], 
             UndirectedEdge[75, 260] -> 
             RGBColor[
              0.8526357992393719, 0.8848360634688806, 0.9401753380144158], 
             UndirectedEdge[32, 387] -> 
             RGBColor[
              0.9846308842914946, 0.9879124899333448, 0.9043695514937979], 
             UndirectedEdge[76, 144] -> 
             RGBColor[
              0.9511250657747565, 0.8386841985604598, 0.30687439661903737`], 
             UndirectedEdge[50, 164] -> 
             RGBColor[
              0.9649807564628414, 0.8874109572249995, 0.38547746832518665`], 
             UndirectedEdge[279, 285] -> 
             RGBColor[
              0.9189805140052199, 0.6998610869467218, 0.2800583205183801], 
             UndirectedEdge[137, 352] -> 
             RGBColor[
              0.9597956140933492, 0.9289113494879548, 0.6386218230496783], 
             UndirectedEdge[4, 275] -> 
             RGBColor[
              0.9510849891245148, 0.9605169221227149, 0.8621303242533005], 
             UndirectedEdge[8, 373] -> 
             RGBColor[
              0.9901947306406158, 0.9897496626780167, 0.7784618876901608], 
             UndirectedEdge[41, 135] -> 
             RGBColor[
              0.9898899091202207, 0.9889094986978371, 0.7316051327248937], 
             UndirectedEdge[85, 211] -> 
             RGBColor[
              0.9913870270028501, 0.988999902410314, 0.6683636146117473], 
             UndirectedEdge[63, 139] -> 
             RGBColor[
              0.8909438238301377, 0.9133979455458447, 0.882115047999223], 
             UndirectedEdge[55, 92] -> 
             RGBColor[
              0.9763682367376081, 0.9319466548933795, 0.36269549151998337`], 
             UndirectedEdge[31, 371] -> 
             RGBColor[
              0.9909159260896987, 0.9898089022732984, 0.7491375258771963], 
             UndirectedEdge[99, 169] -> 
             RGBColor[
              0.9753454635984442, 0.9284966009364268, 0.35872221100883295`], 
             UndirectedEdge[71, 72] -> 
             RGBColor[
              0.9660954707344187, 0.9740487833501258, 0.9339527481104528], 
             UndirectedEdge[104, 112] -> 
             RGBColor[
              0.9938105391170942, 0.991454728687098, 0.7337914663808771], 
             UndirectedEdge[389, 390] -> 
             RGBColor[
              0.9932268524213561, 0.9912259207665453, 0.7443777559558111], 
             UndirectedEdge[260, 349] -> 
             RGBColor[
              0.8289460182361599, 0.8672093830601559, 0.9821173720715861], 
             UndirectedEdge[70, 284] -> 
             RGBColor[
              0.9817574303289419, 0.9500839527264486, 0.38717885397032803`], 
             UndirectedEdge[24, 172] -> 
             RGBColor[
              0.9946440000022947, 0.9909523825166031, 0.6584106375293626], 
             UndirectedEdge[343, 362] -> 
             RGBColor[
              0.9049903752928123, 0.5604197757252523, 0.3034365107750914], 
             UndirectedEdge[233, 307] -> 
             RGBColor[
              0.9928917095454683, 0.9900504179790004, 0.6745593412379431], 
             UndirectedEdge[79, 278] -> 
             RGBColor[
              0.9414254489737628, 0.8833672718650007, 0.6299843582994418], 
             UndirectedEdge[1, 216] -> 
             RGBColor[
              0.9822150703428698, 0.9512518776038168, 0.420912218123183], 
             UndirectedEdge[192, 374] -> 
             RGBColor[
              0.9777205116870717, 0.9755159617474775, 0.678833921934265], 
             UndirectedEdge[152, 383] -> 
             RGBColor[
              0.9363933787978567, 0.7855279731231859, 0.2676788234227071], 
             UndirectedEdge[43, 121] -> 
             RGBColor[
              0.9596985781926477, 0.8794486672976345, 0.5655703500350114], 
             UndirectedEdge[13, 280] -> 
             RGBColor[
              0.9819209979452285, 0.9843346860126698, 0.8392411116452629], 
             UndirectedEdge[246, 272] -> 
             RGBColor[
              0.9827896990857659, 0.9866851662742213, 0.9140167296691444], 
             UndirectedEdge[385, 387] -> 
             RGBColor[
              0.9594716427075187, 0.9691968430577325, 0.9494571692307233], 
             UndirectedEdge[90, 268] -> 
             RGBColor[
              0.9293147962872859, 0.9437234598382523, 0.884609763192185], 
             UndirectedEdge[195, 363] -> 
             RGBColor[
              0.9887255789057541, 0.9867357581992289, 0.6589772493643742], 
             UndirectedEdge[88, 109] -> 
             RGBColor[
              0.992958781731407, 0.9890305233723623, 0.5972960905135105], 
             UndirectedEdge[63, 318] -> 
             RGBColor[
              0.988672138724151, 0.9895836524967501, 0.8373955071134591], 
             UndirectedEdge[257, 276] -> 
             RGBColor[
              0.9946827684344328, 0.9910353042728566, 0.6626303421165594], 
             UndirectedEdge[16, 106] -> 
             RGBColor[
              0.9217590264105647, 0.9368098618655136, 0.8354746562693207], 
             UndirectedEdge[100, 227] -> 
             RGBColor[
              0.8874562607955654, 0.9090482247714575, 0.7734426335979978], 
             UndirectedEdge[195, 359] -> 
             RGBColor[
              0.9753073790365945, 0.9809261838048466, 0.9186806711849241], 
             UndirectedEdge[216, 313] -> 
             RGBColor[
              0.992255446130428, 0.985120422727595, 0.4599171820919756], 
             UndirectedEdge[12, 47] -> 
             RGBColor[
              0.9760441623400042, 0.9305508816671251, 0.3871669491529826], 
             UndirectedEdge[386, 400] -> 
             RGBColor[
              0.9783820068595466, 0.9443592559922781, 0.5670569678108208], 
             UndirectedEdge[180, 262] -> 
             RGBColor[
              0.953437536417751, 0.8747905815281833, 0.5960462567782383], 
             UndirectedEdge[247, 359] -> 
             RGBColor[
              0.9764300888090589, 0.9813904531480857, 0.9000744647754355], 
             UndirectedEdge[74, 141] -> 
             RGBColor[
              0.9894914232624015, 0.9882673420203578, 0.7035091307687985], 
             UndirectedEdge[170, 171] -> 
             RGBColor[
              0.986448498593722, 0.9648401220333951, 0.4962097407893097], 
             UndirectedEdge[207, 333] -> 
             RGBColor[
              0.9495815134747629, 0.8262638371266813, 0.3786642742952961], 
             UndirectedEdge[311, 313] -> 
             RGBColor[
              0.9698349456540161, 0.9717061924643291, 0.6965790488229069], 
             UndirectedEdge[161, 195] -> 
             RGBColor[
              0.9896590839642838, 0.9889295218783247, 0.7438243392528682], 
             UndirectedEdge[87, 129] -> 
             RGBColor[
              0.9946987852405234, 0.9910695626015368, 0.6643736726152487], 
             UndirectedEdge[198, 367] -> 
             RGBColor[
              0.9794266884467032, 0.9829281689320057, 0.8637825010393236], 
             UndirectedEdge[322, 330] -> 
             RGBColor[
              0.989272849934757, 0.9863950611582225, 0.6459884161982552], 
             UndirectedEdge[79, 314] -> 
             RGBColor[
              0.9679434723395108, 0.9017179940125325, 0.5212202185975361], 
             UndirectedEdge[56, 274] -> 
             RGBColor[
              0.9937782419118115, 0.9891006135026298, 0.5641782122198751], 
             UndirectedEdge[249, 316] -> 
             RGBColor[
              0.9668908740390161, 0.8942250739706952, 0.43191985465712557`], 
             UndirectedEdge[69, 294] -> 
             RGBColor[
              0.9299810503643144, 0.9469891379592922, 0.9926107120969914], 
             UndirectedEdge[6, 300] -> 
             RGBColor[
              0.9916955461392558, 0.9904931531274328, 0.7625204554864795], 
             UndirectedEdge[36, 265] -> 
             RGBColor[
              0.9801949628084885, 0.9817946188744247, 0.7475927218392504], 
             UndirectedEdge[167, 395] -> 
             RGBColor[
              0.9643876426433443, 0.9705566822128828, 0.8197546055900882], 
             UndirectedEdge[261, 306] -> 
             RGBColor[
              0.9842783870453765, 0.9849209834575224, 0.7471038615816739], 
             UndirectedEdge[35, 211] -> 
             RGBColor[
              0.9892829043980638, 0.9823965313824861, 0.6181553605140615], 
             UndirectedEdge[54, 63] -> 
             RGBColor[
              0.9922460803278208, 0.9887734911112298, 0.611846923095329], 
             UndirectedEdge[302, 314] -> 
             RGBColor[
              0.9833238619043252, 0.9574006839519948, 0.5611743277720851], 
             UndirectedEdge[54, 224] -> 
             RGBColor[
              0.9932218590645243, 0.987910566851217, 0.5036193728895642], 
             UndirectedEdge[164, 389] -> 
             RGBColor[
              0.9640983664975886, 0.8888282879426048, 0.5296496530775736], 
             UndirectedEdge[113, 210] -> 
             RGBColor[
              0.9510199992267698, 0.8447988275429914, 0.557402342062336], 
             UndirectedEdge[307, 348] -> 
             RGBColor[
              0.9897689140544379, 0.9887590617912758, 0.7263121440599881], 
             UndirectedEdge[18, 74] -> 
             RGBColor[
              0.9845690508649605, 0.9590788832152655, 0.43971020103488967`], 
             UndirectedEdge[41, 328] -> 
             RGBColor[
              0.9940943460374905, 0.9897767282644272, 0.598584195531483], 
             UndirectedEdge[63, 290] -> 
             RGBColor[
              0.929628412983143, 0.7408268316341693, 0.49779353951784266`], 
             UndirectedEdge[45, 288] -> 
             RGBColor[
              0.9663129424256496, 0.9176346885994116, 0.6000421242224894], 
             UndirectedEdge[249, 315] -> 
             RGBColor[
              0.9632815364805163, 0.8799152532916854, 0.4290156969355152], 
             UndirectedEdge[306, 342] -> 
             RGBColor[
              0.9841485171271547, 0.9846432048343088, 0.7329683224474597], 
             UndirectedEdge[163, 395] -> 
             RGBColor[
              0.9526540751467398, 0.9641725998008055, 0.9637294592385752], 
             UndirectedEdge[378, 379] -> 
             RGBColor[
              0.9767759063033763, 0.9324790559365081, 0.43594178898947056`], 
             UndirectedEdge[216, 235] -> 
             RGBColor[
              0.9940905464610106, 0.9897686013545329, 0.5981706350799219], 
             UndirectedEdge[220, 321] -> 
             RGBColor[
              0.9440319931696229, 0.8023397210418333, 0.3376654282269924], 
             UndirectedEdge[133, 199] -> 
             RGBColor[
              0.9328828164559254, 0.7696683930800238, 0.5598256078323178], 
             UndirectedEdge[317, 396] -> 
             RGBColor[
              0.9809542728466347, 0.9470197794203733, 0.41423980908829283`], 
             UndirectedEdge[177, 197] -> 
             RGBColor[
              0.972328213649408, 0.9291838570747615, 0.5797955973125346], 
             UndirectedEdge[208, 242] -> 
             RGBColor[
              0.909444144094198, 0.6770706705474087, 0.24591142016598438`], 
             UndirectedEdge[51, 163] -> 
             RGBColor[
              0.9829179832083763, 0.9850228073114646, 0.8350712661997661], 
             UndirectedEdge[188, 228] -> 
             RGBColor[
              0.9914662674934838, 0.9902749211349321, 0.7573489099357887], 
             UndirectedEdge[95, 125] -> 
             RGBColor[
              0.9889797966520831, 0.9862738760947111, 0.6508450674897446], 
             UndirectedEdge[66, 203] -> 
             RGBColor[
              0.9730713567665783, 0.9186293473284136, 0.44276774406048863`], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.9822015075310206, 0.9830519812670175, 0.7252233826628796], 
             UndirectedEdge[151, 265] -> 
             RGBColor[
              0.9807627017116862, 0.9830089549811565, 0.8093875977739619], 
             UndirectedEdge[76, 333] -> 
             RGBColor[
              0.9397801063040482, 0.7937052147427347, 0.2977459759284805], 
             UndirectedEdge[119, 336] -> 
             RGBColor[
              0.9723568834469178, 0.9786800863767684, 0.9216320152027679], 
             UndirectedEdge[183, 395] -> 
             RGBColor[
              0.9639828645023505, 0.9710386993404179, 0.8736675907362683], 
             UndirectedEdge[42, 204] -> 
             RGBColor[
              0.9465892805820957, 0.9594301345819912, 0.9663905250414808], 
             UndirectedEdge[12, 107] -> 
             RGBColor[
              0.9649415992302872, 0.8874591099570537, 0.3734099461787711], 
             UndirectedEdge[234, 239] -> 
             RGBColor[
              0.9094502589837179, 0.8334722982598751, 0.6250619020016945], 
             UndirectedEdge[164, 287] -> 
             RGBColor[
              0.9654582770767548, 0.8884323255334199, 0.43745264023402075`], 
             UndirectedEdge[32, 194] -> 
             RGBColor[
              0.9857913289902847, 0.9883923636383629, 0.8851379797002322], 
             UndirectedEdge[6, 169] -> 
             RGBColor[
              0.9872954004014711, 0.967335211627917, 0.5302569223975016], 
             UndirectedEdge[24, 240] -> 
             RGBColor[
              0.994892588206137, 0.9914840875484989, 0.6854679294090322], 
             UndirectedEdge[9, 381] -> 
             RGBColor[
              0.9169502790035184, 0.9326607305405907, 0.8094999870054052], 
             UndirectedEdge[43, 90] -> 
             RGBColor[
              0.8995535793551228, 0.833262758475618, 0.6258381110620894], 
             UndirectedEdge[88, 157] -> 
             RGBColor[
              0.980969507759176, 0.9474165711505961, 0.3849286035829999], 
             UndirectedEdge[100, 314] -> 
             RGBColor[
              0.9932957827148239, 0.9902292142651145, 0.6687133892767639], 
             UndirectedEdge[56, 296] -> 
             RGBColor[
              0.9939399846219414, 0.9906787350824584, 0.6713486797849137], 
             UndirectedEdge[49, 235] -> 
             RGBColor[
              0.9798452820488847, 0.9421334994872137, 0.5073275907026341], 
             UndirectedEdge[359, 362] -> 
             RGBColor[
              0.9790045019129976, 0.980194585086307, 0.6930986311585584], 
             UndirectedEdge[104, 285] -> 
             RGBColor[
              0.9285555991086167, 0.7343647413706786, 0.49018946513599737`], 
             UndirectedEdge[80, 168] -> 
             RGBColor[
              0.9827437455725694, 0.9840167414478658, 0.7687676793637866], 
             UndirectedEdge[311, 386] -> 
             RGBColor[
              0.969332040628401, 0.9756294573471035, 0.8911637173997213], 
             UndirectedEdge[61, 173] -> 
             RGBColor[
              0.9668250065052799, 0.8946378759894456, 0.39198639506533367`], 
             UndirectedEdge[118, 354] -> 
             RGBColor[
              0.9726646299995665, 0.9193541359582733, 0.348825271018705], 
             UndirectedEdge[154, 180] -> 
             RGBColor[
              0.9821685831722756, 0.9853108223643036, 0.8742664505085989], 
             UndirectedEdge[17, 158] -> 
             RGBColor[
              0.9838090074467067, 0.9713996455535461, 0.6485078325027096], 
             UndirectedEdge[8, 237] -> 
             RGBColor[
              0.9826194563701266, 0.986316824001537, 0.9034956166038612], 
             UndirectedEdge[55, 255] -> 
             RGBColor[
              0.9427521354009989, 0.7975138373251768, 0.32677484386149963`], 
             UndirectedEdge[93, 214] -> 
             RGBColor[
              0.95138296232551, 0.9591240860495325, 0.7323425977484455], 
             UndirectedEdge[129, 235] -> 
             RGBColor[
              0.9946947471042453, 0.9910609254363562, 0.6639341464018688], 
             UndirectedEdge[47, 158] -> 
             RGBColor[
              0.9717593889997348, 0.9307534531469539, 0.6016973402157331], 
             UndirectedEdge[106, 347] -> 
             RGBColor[
              0.9948173636622437, 0.9917893770147252, 0.7111670871936768], 
             UndirectedEdge[169, 178] -> 
             RGBColor[
              0.9861701388926508, 0.9649283910419406, 0.40777915147146154`], 
             UndirectedEdge[230, 385] -> 
             RGBColor[
              0.9623846326765296, 0.970401439270346, 0.9011813868678265], 
             UndirectedEdge[304, 383] -> 
             RGBColor[
              0.9518836954504917, 0.8400188234770212, 0.3161982835491062], 
             UndirectedEdge[100, 352] -> 
             RGBColor[
              0.9791346723682299, 0.940469391766399, 0.4422426037425413], 
             UndirectedEdge[87, 216] -> 
             RGBColor[
              0.9940945845972887, 0.9897772385197136, 0.5986101612933017], 
             UndirectedEdge[79, 277] -> 
             RGBColor[
              0.9533421514876239, 0.850473238113122, 0.29303929837702897`], 
             UndirectedEdge[217, 220] -> 
             RGBColor[
              0.9693593732221341, 0.9052916277608583, 0.35817568383370946`], 
             UndirectedEdge[78, 104] -> 
             RGBColor[
              0.9754465330982183, 0.979806245562737, 0.8636444775519435], 
             UndirectedEdge[170, 353] -> 
             RGBColor[
              0.9942206367025832, 0.9900468512271157, 0.6123301550511855], 
             UndirectedEdge[78, 385] -> 
             RGBColor[
              0.9463145439978343, 0.9594477654941357, 0.9745708027767527], 
             UndirectedEdge[40, 102] -> 
             RGBColor[
              0.9715806509847216, 0.9783254765535943, 0.9329907243162545], 
             UndirectedEdge[41, 256] -> 
             RGBColor[
              0.993651571374913, 0.9888296780325594, 0.5503909059983934], 
             UndirectedEdge[120, 217] -> 
             RGBColor[
              0.9660378044437063, 0.9061925656777328, 0.578554229692738], 
             UndirectedEdge[210, 315] -> 
             RGBColor[
              0.923754828545509, 0.7354203329198357, 0.2575095492247651], 
             UndirectedEdge[83, 187] -> 
             RGBColor[
              0.9838520081771561, 0.9571911732320719, 0.3917685303709766], 
             UndirectedEdge[2, 305] -> 
             RGBColor[
              0.9757942905747656, 0.9814680020606474, 0.925858131583523], 
             UndirectedEdge[121, 175] -> 
             RGBColor[
              0.9901933490402178, 0.9902127120557654, 0.8121851154101315], 
             UndirectedEdge[36, 151] -> 
             RGBColor[
              0.9942519426288448, 0.9901138114378746, 0.6157376119269835], 
             UndirectedEdge[70, 332] -> 
             RGBColor[
              0.9647824840739967, 0.8872141469763706, 0.3504478590207425], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.7435833331416353, 0.7533895848582584, 0.6297648304334098], 
             UndirectedEdge[221, 400] -> 
             RGBColor[
              0.9800403957757615, 0.9436305388910807, 0.4367536968363166], 
             UndirectedEdge[49, 216] -> 
             RGBColor[
              0.978934245009504, 0.9401848833799527, 0.40816683123493425`], 
             UndirectedEdge[75, 349] -> 
             RGBColor[
              0.9607497234080236, 0.9702066690258946, 0.9494832454421107], 
             UndirectedEdge[62, 87] -> 
             RGBColor[
              0.9949761399460422, 0.9916627962717794, 0.6945620206761459], 
             UndirectedEdge[38, 189] -> 
             RGBColor[
              0.9912142819336496, 0.9889603491047025, 0.6735438755860479], 
             UndirectedEdge[49, 361] -> 
             RGBColor[
              0.9792447024500028, 0.9408489204531174, 0.4419582077120011], 
             UndirectedEdge[107, 270] -> 
             RGBColor[0.9558231267699624, 0.88409521831494, 0.59784671682629],
              UndirectedEdge[5, 8] -> 
             RGBColor[
              0.981495492974215, 0.9854785739411873, 0.9053981934565369], 
             UndirectedEdge[162, 340] -> 
             RGBColor[
              0.9824347571313514, 0.9602662532807227, 0.5982571084473112], 
             UndirectedEdge[34, 85] -> 
             RGBColor[
              0.9903440107416279, 0.9885685883820032, 0.6856490932997572], 
             UndirectedEdge[21, 172] -> 
             RGBColor[
              0.9939188502311687, 0.9894013604800527, 0.5794825600479261], 
             UndirectedEdge[298, 393] -> 
             RGBColor[
              0.9740213493666725, 0.9794877555263422, 0.8993931272235629], 
             UndirectedEdge[164, 371] -> 
             RGBColor[
              0.9656064806202502, 0.8887493179272801, 0.45358368133725463`], 
             UndirectedEdge[11, 85] -> 
             RGBColor[
              0.9937221545181147, 0.9889806482388176, 0.5580734455472441], 
             UndirectedEdge[202, 307] -> 
             RGBColor[
              0.9937695260186639, 0.9904134176495211, 0.6600116505608804], 
             UndirectedEdge[20, 265] -> 
             RGBColor[
              0.7463447677655617, 0.8003730717440452, 0.9485346133597996], 
             UndirectedEdge[195, 247] -> 
             RGBColor[
              0.9863902146052828, 0.988640018230823, 0.8752128951934257], 
             UndirectedEdge[281, 355] -> 
             RGBColor[
              0.9915518991444447, 0.9893525472500543, 0.6863089297514087], 
             UndirectedEdge[298, 313] -> 
             RGBColor[
              0.9897419623111894, 0.9858948230082665, 0.6334155308356548], 
             UndirectedEdge[67, 210] -> 
             RGBColor[
              0.9422889457275101, 0.8048740066919582, 0.2934000353966787], 
             UndirectedEdge[11, 263] -> 
             RGBColor[
              0.9675633536701924, 0.8968063677568368, 0.4374827381992709], 
             UndirectedEdge[88, 181] -> 
             RGBColor[
              0.9904379669548644, 0.9879881016802772, 0.6390725150203422], 
             UndirectedEdge[212, 390] -> 
             RGBColor[
              0.9928103646598048, 0.9910536923738966, 0.7512800360004923], 
             UndirectedEdge[13, 203] -> 
             RGBColor[
              0.973213405210986, 0.9196593529194242, 0.5110143394009925], 
             UndirectedEdge[75, 105] -> 
             RGBColor[
              0.9895389230192384, 0.9899420900781088, 0.8230306481780129], 
             UndirectedEdge[12, 270] -> 
             RGBColor[
              0.9838748222484501, 0.984057799163557, 0.7031783239494731], 
             UndirectedEdge[127, 393] -> 
             RGBColor[
              0.9764739871718116, 0.9785832117739874, 0.7192720653432236], 
             UndirectedEdge[185, 208] -> 
             RGBColor[
              0.8861171187753519, 0.5757662590290942, 0.2266856711923439], 
             UndirectedEdge[246, 355] -> 
             RGBColor[
              0.98863878483498, 0.9880568340776628, 0.7305086717375693], 
             UndirectedEdge[62, 336] -> 
             RGBColor[
              0.9770571362400011, 0.9803309832245981, 0.8224547582895884], 
             UndirectedEdge[118, 209] -> 
             RGBColor[
              0.9916106249353449, 0.9827358213666064, 0.47522382525249734`], 
             UndirectedEdge[178, 352] -> 
             RGBColor[
              0.9785459196090596, 0.9392101091465688, 0.37816049926771067`], 
             UndirectedEdge[17, 22] -> 
             RGBColor[
              0.9884484397585654, 0.971955653752424, 0.47257988179598015`], 
             UndirectedEdge[12, 158] -> 
             RGBColor[
              0.9887085213685055, 0.9876242622854995, 0.6932719443647045], 
             UndirectedEdge[200, 333] -> 
             RGBColor[
              0.9329477100701457, 0.8170679096040258, 0.5978019862649221], 
             UndirectedEdge[69, 295] -> 
             RGBColor[
              0.8990207090785423, 0.9223022022140938, 0.9896576871065315], 
             UndirectedEdge[181, 340] -> 
             RGBColor[
              0.9821724361664549, 0.9601577768203967, 0.6026044457005413], 
             UndirectedEdge[205, 284] -> 
             RGBColor[
              0.9596821478616882, 0.873429982353771, 0.3094900684087917], 
             UndirectedEdge[283, 373] -> 
             RGBColor[
              0.9947430349523174, 0.991164208260732, 0.6691899806664618], 
             UndirectedEdge[302, 379] -> 
             RGBColor[
              0.9838693406715819, 0.9564068756780595, 0.4634984420272689], 
             UndirectedEdge[254, 303] -> 
             RGBColor[
              0.9832111066758938, 0.9869994513649472, 0.9133033965397599], 
             UndirectedEdge[38, 254] -> 
             RGBColor[
              0.9856974192620115, 0.9880403946659784, 0.8726714869444233], 
             UndirectedEdge[158, 209] -> 
             RGBColor[
              0.9889713297392433, 0.9881863828165052, 0.7218770136542411], 
             UndirectedEdge[365, 370] -> 
             RGBColor[
              0.9791150733155438, 0.9583849619450641, 0.637899568088249], 
             UndirectedEdge[61, 164] -> 
             RGBColor[
              0.938543149076217, 0.794051095908407, 0.26940857905026994`], 
             UndirectedEdge[163, 167] -> 
             RGBColor[
              0.9827956640048978, 0.9843228218862063, 0.7898936481356927], 
             UndirectedEdge[62, 119] -> 
             RGBColor[
              0.9902423673260538, 0.9899402039035738, 0.7900908512910899], 
             UndirectedEdge[137, 197] -> 
             RGBColor[
              0.9709584309419116, 0.977431300572606, 0.9147820911811282], 
             UndirectedEdge[265, 383] -> 
             RGBColor[
              0.9455494100723406, 0.8563203110191824, 0.5996329118500197], 
             UndirectedEdge[19, 338] -> 
             RGBColor[
              0.9481567003916243, 0.9606519481884455, 0.9655690967038058], 
             UndirectedEdge[69, 212] -> 
             RGBColor[
              0.9634790687944403, 0.9712156800123681, 0.8988930499571957], 
             UndirectedEdge[45, 275] -> 
             RGBColor[
              0.9300409282005804, 0.8898485185353535, 0.6359734835619606], 
             UndirectedEdge[248, 360] -> 
             RGBColor[
              0.9605607042543215, 0.9278491317564446, 0.6338605556041572], 
             UndirectedEdge[188, 322] -> 
             RGBColor[
              0.9874668954075557, 0.9890852534119974, 0.8573695079391647], 
             UndirectedEdge[167, 183] -> 
             RGBColor[
              0.9941244533605086, 0.9911889214258187, 0.6998317796333859], 
             UndirectedEdge[141, 240] -> 
             RGBColor[
              0.990327234249532, 0.9900550572083764, 0.7944819986904521], 
             UndirectedEdge[23, 220] -> 
             RGBColor[
              0.9832311029657201, 0.9833354427299696, 0.6850447538730084], 
             UndirectedEdge[123, 322] -> 
             RGBColor[
              0.9499417827845069, 0.8410582082171941, 0.5591486000016428], 
             UndirectedEdge[177, 398] -> 
             RGBColor[
              0.9549452419801352, 0.916649790557674, 0.6284823235101245], 
             UndirectedEdge[272, 395] -> 
             RGBColor[
              0.9580907946927617, 0.9682272963364174, 0.9545265111707146], 
             UndirectedEdge[85, 312] -> 
             RGBColor[
              0.994104014391239, 0.9897974078954748, 0.5996365361708488], 
             UndirectedEdge[25, 328] -> 
             RGBColor[
              0.9940886972689134, 0.9897646461196188, 0.5979693619320228], 
             UndirectedEdge[8, 121] -> 
             RGBColor[
              0.9862772594854654, 0.9885933083859644, 0.877084853847277], 
             UndirectedEdge[169, 319] -> 
             RGBColor[
              0.9852438058194092, 0.966827580578148, 0.5890265204099694], 
             UndirectedEdge[84, 167] -> 
             RGBColor[
              0.9899187424130917, 0.9894497518672206, 0.7695312940631194], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.9658915105099443, 0.8894908741334773, 0.47680192679655775`], 
             UndirectedEdge[43, 213] -> 
             RGBColor[
              0.9045789945210447, 0.6514568885451212, 0.24166961651811514`], 
             UndirectedEdge[170, 187] -> 
             RGBColor[
              0.993252267795628, 0.9877908331524026, 0.522641099354711], 
             UndirectedEdge[89, 199] -> 
             RGBColor[
              0.9299013698295896, 0.7675869127831725, 0.5712349496622451], 
             UndirectedEdge[16, 373] -> 
             RGBColor[
              0.9216847602824711, 0.9366510141269788, 0.827391246543745], 
             UndirectedEdge[22, 158] -> 
             RGBColor[
              0.9890631803400947, 0.9883828419642062, 0.7318743847207255], 
             UndirectedEdge[233, 264] -> 
             RGBColor[
              0.9887533057961997, 0.9896172171669406, 0.836050358675966], 
             UndirectedEdge[274, 296] -> 
             RGBColor[
              0.9936919630659933, 0.990148242053111, 0.6443530640315649], 
             UndirectedEdge[97, 211] -> 
             RGBColor[
              0.9902887041541895, 0.9902521438459074, 0.8106048344004966], 
             UndirectedEdge[1, 129] -> 
             RGBColor[0.9828192709861044, 0.95254420168564, 0.48667572944513],
              UndirectedEdge[24, 141] -> 
             RGBColor[
              0.9901847485397224, 0.989750294682609, 0.7789733084975577], 
             UndirectedEdge[347, 384] -> 
             RGBColor[
              0.9937709386247044, 0.9895511796692293, 0.5972701796442836], 
             UndirectedEdge[36, 378] -> 
             RGBColor[
              0.9766837409313159, 0.9322819235250195, 0.42591015701944096`], 
             UndirectedEdge[174, 395] -> 
             RGBColor[
              0.9601487873817993, 0.9694532099197823, 0.9372081708973221], 
             UndirectedEdge[104, 357] -> 
             RGBColor[
              0.9925010252394149, 0.9911669954687066, 0.7739409487148738], 
             UndirectedEdge[47, 173] -> 
             RGBColor[
              0.9762020773778424, 0.9308886459654016, 0.40435502648302224`], 
             UndirectedEdge[127, 231] -> 
             RGBColor[
              0.9650588798991212, 0.9700698434605377, 0.7385948644190916], 
             UndirectedEdge[252, 367] -> 
             RGBColor[
              0.9763922156359873, 0.9816733364423805, 0.9140715684767873], 
             UndirectedEdge[158, 310] -> 
             RGBColor[
              0.9774461096448852, 0.9499360971885508, 0.6237891760750582], 
             UndirectedEdge[149, 397] -> 
             RGBColor[
              0.9644909713284909, 0.9719547788193375, 0.8964826178331616], 
             UndirectedEdge[204, 345] -> 
             RGBColor[
              0.9508423783756615, 0.9628214393153165, 0.9667961893058163], 
             UndirectedEdge[231, 396] -> 
             RGBColor[
              0.9651028198018158, 0.9701638264693957, 0.7433774516617488], 
             UndirectedEdge[162, 263] -> 
             RGBColor[
              0.9649004471018253, 0.8966900768663377, 0.5532050544386804], 
             UndirectedEdge[14, 196] -> 
             RGBColor[
              0.9610636083474007, 0.8708843329159524, 0.4412894862381884], 
             UndirectedEdge[43, 175] -> 
             RGBColor[
              0.9629822845312646, 0.8808065642560563, 0.5111508380445346], 
             UndirectedEdge[113, 397] -> 
             RGBColor[
              0.9626579342893277, 0.9711967708967402, 0.9268607853198898], 
             UndirectedEdge[126, 336] -> 
             RGBColor[
              0.9699635970517588, 0.9771194803780734, 0.935727974829549], 
             UndirectedEdge[48, 173] -> 
             RGBColor[
              0.9753105140909251, 0.977890543684061, 0.7351308500291178], 
             UndirectedEdge[28, 168] -> 
             RGBColor[
              0.966262473203616, 0.9294351748074661, 0.6185488406495561], 
             UndirectedEdge[253, 359] -> 
             RGBColor[
              0.9742955831963742, 0.964408272324051, 0.6664742183978781], 
             UndirectedEdge[41, 187] -> 
             RGBColor[
              0.9930602080191107, 0.987380036710654, 0.5017365779363439], 
             UndirectedEdge[198, 398] -> 
             RGBColor[
              0.9718620916389276, 0.977286505018657, 0.8765873902720599], 
             UndirectedEdge[260, 329] -> 
             RGBColor[
              0.8568877028509152, 0.8865943348811923, 0.8697102915973257], 
             UndirectedEdge[60, 82] -> 
             RGBColor[
              0.9304606760729726, 0.7386931928430628, 0.4172839574824631], 
             UndirectedEdge[12, 17] -> 
             RGBColor[
              0.9880937807869763, 0.9711970740737172, 0.43397744143995914`], 
             UndirectedEdge[268, 351] -> 
             RGBColor[
              0.988504188116855, 0.9895142006044993, 0.8401788833185949], 
             UndirectedEdge[122, 274] -> 
             RGBColor[
              0.9932671828269027, 0.9880075097960093, 0.5085525847186207], 
             UndirectedEdge[150, 384] -> 
             RGBColor[
              0.9940261895325311, 0.9896309483919987, 0.5911657805798423], 
             UndirectedEdge[179, 232] -> 
             RGBColor[
              0.9923729255816831, 0.9907255149502235, 0.7478234599453135], 
             UndirectedEdge[4, 131] -> 
             RGBColor[
              0.9949378821230392, 0.9921746984144506, 0.7335559237697586], 
             UndirectedEdge[128, 155] -> 
             RGBColor[
              0.9755927846798436, 0.9776607762249419, 0.6997183554120812], 
             UndirectedEdge[316, 362] -> 
             RGBColor[
              0.9661980574098308, 0.8927432092553741, 0.3565110401389241], 
             UndirectedEdge[283, 320] -> 
             RGBColor[
              0.993270993461838, 0.9875821011180101, 0.5458340971461861], 
             UndirectedEdge[49, 396] -> 
             RGBColor[
              0.9789173388980991, 0.9401487229171275, 0.4063267053409315], 
             UndirectedEdge[371, 389] -> 
             RGBColor[
              0.9929594371915134, 0.9906539466297386, 0.7152712584829224], 
             UndirectedEdge[53, 58] -> 
             RGBColor[
              0.9797069203146553, 0.9809669111092645, 0.7116241383372022], 
             UndirectedEdge[18, 399] -> 
             RGBColor[
              0.9828278059061859, 0.9600139393644688, 0.5888758475047203], 
             UndirectedEdge[241, 270] -> 
             RGBColor[
              0.9835783724455032, 0.9859096449213083, 0.8516118725483379], 
             UndirectedEdge[137, 169] -> 
             RGBColor[
              0.9674198333769405, 0.9546296313833267, 0.6682404752534291], 
             UndirectedEdge[156, 386] -> 
             RGBColor[
              0.9922276913796821, 0.9900599860032528, 0.7062190258007173], 
             UndirectedEdge[19, 262] -> 
             RGBColor[
              0.9503693694742126, 0.8725023476453547, 0.6012398631075495], 
             UndirectedEdge[85, 181] -> 
             RGBColor[
              0.9907969269848511, 0.9887558808879926, 0.6781430990398838], 
             UndirectedEdge[74, 240] -> 
             RGBColor[
              0.994199262928816, 0.9900011348862476, 0.610003751680273], 
             UndirectedEdge[72, 88] -> 
             RGBColor[
              0.9697331480126705, 0.9732272902191365, 0.7046083731095706], 
             UndirectedEdge[63, 98] -> 
             RGBColor[
              0.9935347186478014, 0.9915297581763487, 0.7521072516713663], 
             UndirectedEdge[43, 56] -> 
             RGBColor[
              0.9632568885757271, 0.8798368130149512, 0.42785495032131926`], 
             UndirectedEdge[174, 272] -> 
             RGBColor[
              0.9839935282893749, 0.9872740461287179, 0.8981442653750662], 
             UndirectedEdge[180, 198] -> 
             RGBColor[
              0.9831850761678804, 0.9857311683406647, 0.8574205309718799], 
             UndirectedEdge[126, 289] -> 
             RGBColor[
              0.9666060148046283, 0.9746154010356998, 0.9414114857762415], 
             UndirectedEdge[233, 244] -> 
             RGBColor[
              0.9824796729047504, 0.9557289022418334, 0.5660223549625538], 
             UndirectedEdge[51, 189] -> 
             RGBColor[
              0.9940573942311037, 0.9901360491043532, 0.626426147078466], 
             UndirectedEdge[199, 306] -> 
             RGBColor[
              0.9277373975968197, 0.765973025835152, 0.5748979901979747], 
             UndirectedEdge[86, 214] -> 
             RGBColor[
              0.9476696742153559, 0.9468707382070805, 0.6947504290547113], 
             UndirectedEdge[104, 172] -> 
             RGBColor[
              0.9935855774545739, 0.9909735584380805, 0.7093057777180103], 
             UndirectedEdge[67, 293] -> 
             RGBColor[
              0.9814516370774204, 0.9485903323960079, 0.42528522426957327`], 
             UndirectedEdge[296, 380] -> 
             RGBColor[
              0.994480064979129, 0.9919853792600799, 0.741143138637141], 
             UndirectedEdge[290, 297] -> 
             RGBColor[
              0.9205387605094495, 0.7068199445248939, 0.2816636575617515], 
             UndirectedEdge[206, 328] -> 
             RGBColor[
              0.9940361543730649, 0.9896522621783008, 0.5922503919760936], 
             UndirectedEdge[5, 319] -> 
             RGBColor[
              0.9840649632543348, 0.986541115934391, 0.8628154213390234], 
             UndirectedEdge[235, 393] -> 
             RGBColor[
              0.9774458702252917, 0.9806619713529316, 0.8250555379475835], 
             UndirectedEdge[40, 189] -> 
             RGBColor[
              0.9832174056043399, 0.9838096363867186, 0.7235037322134026], 
             UndirectedEdge[15, 256] -> 
             RGBColor[
              0.9936078764637496, 0.9899893422168446, 0.6367238111921061], 
             UndirectedEdge[71, 365] -> 
             RGBColor[
              0.9838089407047856, 0.9872594602508804, 0.9039684638634988], 
             UndirectedEdge[53, 64] -> 
             RGBColor[
              0.9692107387915666, 0.9458789493887563, 0.6437975564131029], 
             UndirectedEdge[231, 298] -> 
             RGBColor[
              0.962606242093982, 0.9709743872128924, 0.9187159262994309], 
             UndirectedEdge[81, 382] -> 
             RGBColor[
              0.9924720336535076, 0.9888199506698323, 0.6046874908229418], 
             UndirectedEdge[9, 294] -> 
             RGBColor[
              0.8815495090072653, 0.9083876657311701, 0.9885641732092917], 
             UndirectedEdge[175, 213] -> 
             RGBColor[
              0.9350737653686148, 0.7622209333032521, 0.4882843818932352], 
             UndirectedEdge[174, 189] -> 
             RGBColor[
              0.9896962197660804, 0.9883325913859944, 0.6987020943216264], 
             UndirectedEdge[14, 127] -> 
             RGBColor[
              0.9604387021143779, 0.8695477216712286, 0.37327229924789646`], 
             UndirectedEdge[86, 95] -> 
             RGBColor[
              0.9886591847272466, 0.9734069085142569, 0.41044350350895903`], 
             UndirectedEdge[103, 200] -> 
             RGBColor[
              0.9650259705772553, 0.9734370066380099, 0.9440860885116495], 
             UndirectedEdge[24, 112] -> 
             RGBColor[
              0.9948689616648149, 0.9914335527656206, 0.6828963261922294], 
             UndirectedEdge[109, 360] -> 
             RGBColor[
              0.978271988345268, 0.9395397719861834, 0.535882628555223], 
             UndirectedEdge[90, 121] -> 
             RGBColor[
              0.9267646438640762, 0.9426689062753272, 0.9268723884276863], 
             UndirectedEdge[75, 202] -> 
             RGBColor[
              0.9890890660729679, 0.9897560626700299, 0.8304859419701727], 
             UndirectedEdge[27, 32] -> 
             RGBColor[
              0.9892346492144803, 0.9885218349170646, 0.7339818472936052], 
             UndirectedEdge[131, 273] -> 
             RGBColor[
              0.969786202014179, 0.905220953541809, 0.504093996264013], 
             UndirectedEdge[160, 220] -> 
             RGBColor[
              0.964993894990082, 0.9697341628824261, 0.7159155899501377], 
             UndirectedEdge[50, 147] -> 
             RGBColor[
              0.9423953277859266, 0.7942227232478654, 0.36711617422254583`], 
             UndirectedEdge[13, 339] -> 
             RGBColor[
              0.9661894527545787, 0.8918117220231737, 0.505362702381213], 
             UndirectedEdge[17, 209] -> 
             RGBColor[
              0.988356589157714, 0.9717591946047228, 0.4625825107294957], 
             UndirectedEdge[174, 325] -> 
             RGBColor[
              0.9879828593964217, 0.9892986177810631, 0.8488186493716557], 
             UndirectedEdge[21, 78] -> 
             RGBColor[
              0.9757798058748128, 0.9782340476047091, 0.7338212598818593], 
             UndirectedEdge[274, 373] -> 
             RGBColor[
              0.9941374026838826, 0.9898688220773653, 0.6032706457764512], 
             UndirectedEdge[97, 305] -> 
             RGBColor[
              0.9818058020070608, 0.9848024920238765, 0.864232774362499], 
             UndirectedEdge[11, 162] -> 
             RGBColor[
              0.9914774396522859, 0.9897588271143809, 0.7193133478279119], 
             UndirectedEdge[103, 207] -> 
             RGBColor[
              0.9816597739818724, 0.9826329341606654, 0.7249483765420235], 
             UndirectedEdge[210, 249] -> 
             RGBColor[
              0.9545206759089878, 0.845181360509297, 0.42196650287583554`], 
             UndirectedEdge[52, 299] -> 
             RGBColor[
              0.9879694947772946, 0.9879075690038723, 0.7594039083827884], 
             UndirectedEdge[43, 373] -> 
             RGBColor[
              0.9636160493477981, 0.8806050215896868, 0.46694738387789525`], 
             UndirectedEdge[1, 336] -> 
             RGBColor[
              0.9652111418124875, 0.9418773178290771, 0.6484052414177053], 
             UndirectedEdge[30, 345] -> 
             RGBColor[
              0.9637569806665837, 0.9709452905693785, 0.8774110704635527], 
             UndirectedEdge[247, 363] -> 
             RGBColor[
              0.9898482886782184, 0.987200027542468, 0.6403710429548856], 
             UndirectedEdge[14, 119] -> 
             RGBColor[
              0.9566808506841478, 0.8699125260471479, 0.5750241286805802], 
             UndirectedEdge[74, 104] -> 
             RGBColor[
              0.9929983546712857, 0.9897175482819578, 0.6453902016760262], 
             UndirectedEdge[258, 277] -> 
             RGBColor[
              0.9616812414091112, 0.8824039709798637, 0.30563928807511587`], 
             UndirectedEdge[152, 236] -> 
             RGBColor[
              0.9558647398932264, 0.9026407910308881, 0.6121408013284733], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.9317900590299979, 0.7608630363448303, 0.542703893883712], 
             UndirectedEdge[120, 132] -> 
             RGBColor[
              0.9897240120728736, 0.9884344634944692, 0.7048111231023072], 
             UndirectedEdge[212, 270] -> 
             RGBColor[
              0.9826873486669372, 0.9855411836906047, 0.8663784424547978], 
             UndirectedEdge[69, 270] -> 
             RGBColor[
              0.9555480699156285, 0.9663684038432068, 0.9601297020993899], 
             UndirectedEdge[16, 270] -> 
             RGBColor[
              0.9116906426705829, 0.9314142060469763, 0.9565194462990529], 
             UndirectedEdge[24, 73] -> 
             RGBColor[
              0.9944744132433334, 0.9905896535870364, 0.6399521653845872], 
             UndirectedEdge[56, 178] -> 
             RGBColor[
              0.9933313732219062, 0.9881448065602775, 0.5155393130775634], 
             UndirectedEdge[6, 319] -> 
             RGBColor[
              0.9928354114116316, 0.9909645167107615, 0.7436299380464508], 
             UndirectedEdge[231, 235] -> 
             RGBColor[
              0.9660307629526014, 0.9721486030394819, 0.8443783370234513], 
             UndirectedEdge[18, 86] -> 
             RGBColor[
              0.9806462586058926, 0.9463774271824055, 0.37931479864162676`], 
             UndirectedEdge[30, 63] -> 
             RGBColor[
              0.9925651692844837, 0.9911935206797694, 0.7728779158886143], 
             UndirectedEdge[46, 358] -> 
             RGBColor[
              0.972821295663737, 0.9757189511596858, 0.7143396350375162], 
             UndirectedEdge[241, 389] -> 
             RGBColor[
              0.9919258590858664, 0.9909291494831184, 0.7834729403614626], 
             UndirectedEdge[286, 332] -> 
             RGBColor[
              0.9401453282901941, 0.8004032025972527, 0.2706977300538156], 
             UndirectedEdge[40, 174] -> 
             RGBColor[
              0.9795727068166722, 0.9839770047128071, 0.9056275629934497], 
             UndirectedEdge[157, 365] -> 
             RGBColor[
              0.9758300829866104, 0.9473039182131628, 0.6251380009787135], 
             UndirectedEdge[235, 336] -> 
             RGBColor[
              0.9770866179306283, 0.9803940415797933, 0.825663658374444], 
             UndirectedEdge[76, 222] -> 
             RGBColor[
              0.95702871227924, 0.8620901896771604, 0.31162460917293866`], 
             UndirectedEdge[115, 392] -> 
             RGBColor[
              0.5589330611526576, 0.5505074989057622, 0.6016140942025443], 
             UndirectedEdge[76, 77] -> 
             RGBColor[
              0.9805618255965312, 0.956031189698616, 0.6053771812425286], 
             UndirectedEdge[160, 366] -> 
             RGBColor[
              0.9661536393691686, 0.9722147388411488, 0.8421466085010516], 
             UndirectedEdge[3, 348] -> 
             RGBColor[
              0.9817875019694509, 0.9856809815861289, 0.9042155005180614], 
             UndirectedEdge[299, 306] -> 
             RGBColor[
              0.9844461878895043, 0.9852798924958439, 0.765367947918209], 
             UndirectedEdge[56, 121] -> 
             RGBColor[
              0.9904679530846804, 0.9892429608146605, 0.7288892276869161], 
             UndirectedEdge[280, 322] -> 
             RGBColor[
              0.9780734787570561, 0.9827436379516277, 0.9030044616537574], 
             UndirectedEdge[81, 271] -> 
             RGBColor[
              0.9768790634362743, 0.9336251879570356, 0.3684728728215091], 
             UndirectedEdge[2, 191] -> 
             RGBColor[
              0.9858556482518339, 0.9852799548458446, 0.679580946592578], 
             UndirectedEdge[146, 377] -> 
             RGBColor[0.994816250546754, 0.991320809014, 0.6771590462866165], 
             UndirectedEdge[10, 396] -> 
             RGBColor[
              0.981126916849115, 0.9821145718102207, 0.7162528351145233], 
             UndirectedEdge[382, 384] -> 
             RGBColor[
              0.9925845301354772, 0.9890605692696264, 0.6169320386375277], 
             UndirectedEdge[147, 391] -> 
             RGBColor[
              0.9407356508732896, 0.789064347636633, 0.32324534770855434`], 
             UndirectedEdge[133, 216] -> 
             RGBColor[
              0.9891133484639834, 0.9879523136292293, 0.69824010273895], 
             UndirectedEdge[86, 264] -> 
             RGBColor[
              0.98552074211382, 0.9755460827009957, 0.6439073712072474], 
             UndirectedEdge[6, 56] -> 
             RGBColor[
              0.9944566347307267, 0.9905516271462538, 0.6380170840036035], 
             UndirectedEdge[43, 308] -> 
             RGBColor[
              0.9572411213922969, 0.8604843271479587, 0.3245447122734284], 
             UndirectedEdge[201, 364] -> 
             RGBColor[
              0.9571346147063775, 0.8564642598375471, 0.3696584538864374], 
             UndirectedEdge[109, 365] -> 
             RGBColor[
              0.9878193569588414, 0.9889178704349291, 0.8375054879092243], 
             UndirectedEdge[229, 349] -> 
             RGBColor[
              0.9596534006964768, 0.9521783083638724, 0.6884790541889637], 
             UndirectedEdge[216, 231] -> 
             RGBColor[
              0.9651197259132207, 0.9701999869322209, 0.7452175775557515], 
             UndirectedEdge[114, 353] -> 
             RGBColor[
              0.9746622300054221, 0.9249510468657156, 0.4431946607306405], 
             UndirectedEdge[70, 236] -> 
             RGBColor[
              0.9779532078231916, 0.9793470373694213, 0.6898401962228098], 
             UndirectedEdge[64, 94] -> 
             RGBColor[
              0.9822744234266505, 0.9518574182079732, 0.38667656538869594`], 
             UndirectedEdge[240, 285] -> 
             RGBColor[
              0.929756507366147, 0.7346483279749686, 0.4548030151402441], 
             UndirectedEdge[56, 90] -> 
             RGBColor[
              0.9303229542471556, 0.9430570519926439, 0.7891569887139941], 
             UndirectedEdge[90, 295] -> 
             RGBColor[
              0.8641606365702521, 0.894522250858264, 0.9869056070330197], 
             UndirectedEdge[165, 281] -> 
             RGBColor[
              0.9888557311639907, 0.9809555757589128, 0.6164958731645844], 
             UndirectedEdge[54, 345] -> 
             RGBColor[
              0.9634378917099207, 0.9685252610008388, 0.7163800776702673], 
             UndirectedEdge[101, 136] -> 
             RGBColor[
              0.9840783168532444, 0.9850392406345956, 0.768665065141001], 
             UndirectedEdge[6, 314] -> 
             RGBColor[
              0.9938322914644739, 0.9913767522312606, 0.7271090557279732], 
             UndirectedEdge[125, 276] -> 
             RGBColor[
              0.9907007946671432, 0.9903884760701456, 0.8012983323290686], 
             UndirectedEdge[244, 341] -> 
             RGBColor[
              0.9481395322409035, 0.8270664375929604, 0.3033322114152658], 
             UndirectedEdge[46, 153] -> 
             RGBColor[
              0.9609871822982217, 0.9360179995110851, 0.6498044045081516], 
             UndirectedEdge[14, 336] -> 
             RGBColor[
              0.9434956195980951, 0.8603033053681721, 0.6073880356790786], 
             UndirectedEdge[109, 370] -> 
             RGBColor[
              0.9846272370639134, 0.9609775181975353, 0.560571569739143], 
             UndirectedEdge[51, 234] -> 
             RGBColor[
              0.9430187895016167, 0.9541201901724066, 0.8628823764504798], 
             UndirectedEdge[144, 228] -> 
             RGBColor[
              0.9616387686137842, 0.8727663493547881, 0.4653216827023828], 
             UndirectedEdge[320, 347] -> 
             RGBColor[
              0.9932710560436707, 0.9880484221334686, 0.5797277939478254], 
             UndirectedEdge[31, 106] -> 
             RGBColor[
              0.9911287090666558, 0.9902640235453506, 0.7722976397746584], 
             UndirectedEdge[77, 103] -> 
             RGBColor[
              0.9787036560753173, 0.9831036546976816, 0.8970131232404932], 
             UndirectedEdge[266, 316] -> 
             RGBColor[
              0.9477641722912262, 0.8306093802320855, 0.2768280307742997], 
             UndirectedEdge[109, 334] -> 
             RGBColor[
              0.9654847939497277, 0.9722607899122226, 0.875312077296684], 
             UndirectedEdge[45, 179] -> 
             RGBColor[
              0.9713912506171942, 0.9204714175783388, 0.5488731540657354], 
             UndirectedEdge[181, 191] -> 
             RGBColor[
              0.9904584467020643, 0.9880319057887177, 0.6413016091167025], 
             UndirectedEdge[125, 148] -> 
             RGBColor[
              0.9616095168390173, 0.9705622157052938, 0.9352342432164729], 
             UndirectedEdge[18, 112] -> 
             RGBColor[
              0.9853812353107688, 0.9608160636204057, 0.5281114657397405], 
             UndirectedEdge[221, 239] -> 
             RGBColor[
              0.9606395797465437, 0.869810523547405, 0.4050101827470658], 
             UndirectedEdge[57, 76] -> 
             RGBColor[
              0.9650050592510206, 0.9449631262196299, 0.6556309402456391], 
             UndirectedEdge[222, 333] -> 
             RGBColor[
              0.9230922822509167, 0.7327935576422419, 0.2569764489241758], 
             UndirectedEdge[125, 214] -> 
             RGBColor[
              0.9479902861401925, 0.9597377057875347, 0.9351519930354969], 
             UndirectedEdge[220, 244] -> 
             RGBColor[
              0.9828109146345846, 0.9535913872424655, 0.39520126701705083`], 
             UndirectedEdge[143, 379] -> 
             RGBColor[
              0.990657989374433, 0.9891854750123146, 0.7158489317039731], 
             UndirectedEdge[31, 241] -> 
             RGBColor[
              0.9898823479840517, 0.9900841051266782, 0.8173392077557367], 
             UndirectedEdge[81, 374] -> 
             RGBColor[
              0.9911650038711315, 0.9818150195421378, 0.4239710537374483], 
             UndirectedEdge[168, 304] -> 
             RGBColor[
              0.9753581932056936, 0.9601171741510914, 0.6538839952750324], 
             UndirectedEdge[156, 328] -> 
             RGBColor[
              0.9942008472074353, 0.9900045234980194, 0.610176190630954], 
             UndirectedEdge[46, 363] -> 
             RGBColor[
              0.9724847727958518, 0.9748020720222205, 0.6944703724536656], 
             UndirectedEdge[51, 269] -> 
             RGBColor[
              0.9902841391961696, 0.9902502561184521, 0.8106804875686184], 
             UndirectedEdge[13, 325] -> 
             RGBColor[
              0.9921772170146731, 0.9910330924462841, 0.7793072889876675], 
             UndirectedEdge[164, 374] -> 
             RGBColor[
              0.9632500717197586, 0.8820130555282419, 0.34133078979861664`], 
             UndirectedEdge[49, 199] -> 
             RGBColor[
              0.9227037130014462, 0.7219009628307471, 0.26975233632830203`], 
             UndirectedEdge[49, 313] -> 
             RGBColor[
              0.9780101817183021, 0.9374853208602758, 0.3690741377146879], 
             UndirectedEdge[176, 388] -> 
             RGBColor[
              0.9937815455017107, 0.9891076795473798, 0.5645377875929973], 
             UndirectedEdge[45, 232] -> 
             RGBColor[
              0.9738499783844465, 0.9210996566785192, 0.47988524036941105`], 
             UndirectedEdge[176, 250] -> 
             RGBColor[
              0.9940357478171116, 0.9915481491344812, 0.730080318020776], 
             UndirectedEdge[346, 390] -> 
             RGBColor[
              0.9841753112386646, 0.9856813334798501, 0.8137084688360148], 
             UndirectedEdge[331, 335] -> 
             RGBColor[
              0.9898335385650443, 0.9892682729919728, 0.7603128823394644], 
             UndirectedEdge[135, 355] -> 
             RGBColor[
              0.9897483588538643, 0.988606736991028, 0.7161982597789808], 
             UndirectedEdge[326, 327] -> 
             RGBColor[
              0.9903932374442285, 0.9902953710477216, 0.8088724472610682], 
             UndirectedEdge[80, 304] -> 
             RGBColor[
              0.9867598450145081, 0.9659863546301584, 0.489257135173156], 
             UndirectedEdge[65, 173] -> 
             RGBColor[
              0.9886079378521144, 0.9727365263796821, 0.45254945177539707`], 
             UndirectedEdge[203, 257] -> 
             RGBColor[
              0.9730548065074293, 0.9185939479975815, 0.4409663504884672], 
             UndirectedEdge[275, 325] -> 
             RGBColor[
              0.948563875397817, 0.9594743768070579, 0.9039117031378632], 
             UndirectedEdge[240, 337] -> 
             RGBColor[
              0.9946018470009843, 0.9908622215091224, 0.6538225434749007], 
             UndirectedEdge[77, 254] -> 
             RGBColor[
              0.9848571540355813, 0.9876929234010182, 0.886596856283072], 
             UndirectedEdge[32, 364] -> 
             RGBColor[
              0.9888639477287378, 0.9877289419227306, 0.6936332782749077], 
             UndirectedEdge[38, 53] -> 
             RGBColor[
              0.9777415147706912, 0.9821068941229497, 0.8861387580160115], 
             UndirectedEdge[28, 291] -> 
             RGBColor[
              0.9515961148068626, 0.8442581615511995, 0.287950364605041], 
             UndirectedEdge[174, 269] -> 
             RGBColor[
              0.9859229647311463, 0.9884467984000935, 0.882956434811779], 
             UndirectedEdge[216, 361] -> 
             RGBColor[
              0.9934899668621289, 0.9884840223204368, 0.5328012520892889], 
             UndirectedEdge[356, 363] -> 
             RGBColor[
              0.9910765460232087, 0.9877079435193955, 0.6200156401202807], 
             UndirectedEdge[151, 383] -> 
             RGBColor[
              0.959606389892697, 0.8646395035826324, 0.4677778019377528], 
             UndirectedEdge[61, 130] -> 
             RGBColor[
              0.9673063863348054, 0.8956674987698339, 0.4443816187772328], 
             UndirectedEdge[331, 338] -> 
             RGBColor[
              0.9565480436319103, 0.9667248950473619, 0.9430664859604119], 
             UndirectedEdge[239, 246] -> 
             RGBColor[
              0.9556403357219281, 0.8690666456634135, 0.5866019677038059], 
             UndirectedEdge[190, 212] -> 
             RGBColor[
              0.9927371227562845, 0.9908970353481589, 0.7433081067989344], 
             UndirectedEdge[111, 286] -> 
             RGBColor[
              0.9541383171154337, 0.893149336937682, 0.608698186963218], 
             UndirectedEdge[228, 273] -> 
             RGBColor[
              0.9696985035302663, 0.9047205125511919, 0.4718067346024778], 
             UndirectedEdge[199, 299] -> 
             RGBColor[
              0.9374272356981986, 0.7705590108095527, 0.4126508435191918], 
             UndirectedEdge[50, 391] -> 
             RGBColor[
              0.9915564260867203, 0.9827398795986204, 0.45912203420447584`], 
             UndirectedEdge[358, 362] -> 
             RGBColor[
              0.9927592246500423, 0.9869210386181546, 0.4532644719218589], 
             UndirectedEdge[42, 98] -> 
             RGBColor[
              0.9604734322363355, 0.9678902233326324, 0.8562347419819692], 
             UndirectedEdge[39, 251] -> 
             RGBColor[
              0.8849246478487939, 0.884958722323403, 0.6709188741212699], 
             UndirectedEdge[148, 179] -> 
             RGBColor[
              0.9634870701096212, 0.9713386322336066, 0.9041183265704595], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.9948988245979477, 0.9918657686509955, 0.712921303770677], 
             UndirectedEdge[77, 333] -> 
             RGBColor[
              0.9466253955682078, 0.8267345576636974, 0.5507290209937657], 
             UndirectedEdge[173, 354] -> 
             RGBColor[
              0.9744680231815726, 0.9249398902266195, 0.3981361456877379], 
             UndirectedEdge[160, 217] -> 
             RGBColor[
              0.9417077899642385, 0.8883480440776209, 0.6332073957653224], 
             UndirectedEdge[59, 90] -> 
             RGBColor[
              0.930630690401371, 0.9437152685096128, 0.8226521699729485], 
             UndirectedEdge[237, 380] -> 
             RGBColor[
              0.9873502303265291, 0.9882731206078545, 0.8250944492957277], 
             UndirectedEdge[285, 399] -> 
             RGBColor[
              0.927179451420242, 0.7337956689361533, 0.5129957936884211], 
             UndirectedEdge[51, 392] -> 
             RGBColor[
              0.5868504349542296, 0.6487504375744001, 0.8348875153076762], 
             UndirectedEdge[264, 307] -> 
             RGBColor[
              0.989662020553359, 0.988714858581542, 0.7280836460043785], 
             UndirectedEdge[78, 208] -> 
             RGBColor[
              0.9284442928068801, 0.8004847951447607, 0.5963325704312805], 
             UndirectedEdge[28, 383] -> 
             RGBColor[
              0.9427879754484142, 0.8093368241333958, 0.28086312892362975`], 
             UndirectedEdge[255, 268] -> 
             RGBColor[
              0.9432032729713935, 0.8021626822412277, 0.5078368244325029], 
             UndirectedEdge[46, 247] -> 
             RGBColor[
              0.9701494084953804, 0.9767063320538145, 0.9107060182827171], 
             UndirectedEdge[272, 392] -> 
             RGBColor[
              0.5804312678001686, 0.6457210662726764, 0.9244818028242294], 
             UndirectedEdge[316, 359] -> 
             RGBColor[
              0.9525408087372038, 0.8862252428911764, 0.6069546497472997], 
             UndirectedEdge[223, 242] -> 
             RGBColor[
              0.9570822584270106, 0.8554671565152538, 0.4163363898601825], 
             UndirectedEdge[158, 390] -> 
             RGBColor[
              0.9897130649010484, 0.9897728793266777, 0.8026103085579179], 
             UndirectedEdge[26, 128] -> 
             RGBColor[
              0.9718474886425651, 0.974867540572699, 0.7060581646735424], 
             UndirectedEdge[136, 335] -> 
             RGBColor[
              0.9841659635206876, 0.9852267079938193, 0.7782048639996697], 
             UndirectedEdge[193, 248] -> 
             RGBColor[
              0.9603188724689223, 0.9270333763594898, 0.6329210847839821], 
             UndirectedEdge[281, 386] -> 
             RGBColor[
              0.9898978319890598, 0.9900905081606699, 0.8170825977214335], 
             UndirectedEdge[225, 337] -> 
             RGBColor[
              0.9453081764235113, 0.8063053786528527, 0.42098712803818217`], 
             UndirectedEdge[30, 297] -> 
             RGBColor[
              0.9834755168107903, 0.957186633570494, 0.5567480339325231], 
             UndirectedEdge[32, 104] -> 
             RGBColor[
              0.9886605098844778, 0.9895788436726976, 0.8375882270813171], 
             UndirectedEdge[264, 366] -> 
             RGBColor[
              0.9902442919051205, 0.9899602781262957, 0.7914602892813769], 
             UndirectedEdge[2, 97] -> 
             RGBColor[
              0.9850958056859602, 0.9872561713807131, 0.8586636563045085], 
             UndirectedEdge[258, 377] -> 
             RGBColor[
              0.977217536031863, 0.9334880090340711, 0.4785384500090286], 
             UndirectedEdge[134, 135] -> 
             RGBColor[
              0.9905267070074628, 0.9902715449885053, 0.8009166528901748], 
             UndirectedEdge[185, 338] -> 
             RGBColor[
              0.9006970898721338, 0.7321056493436502, 0.6046100736851663], 
             UndirectedEdge[40, 84] -> 
             RGBColor[
              0.9792010729898064, 0.9838233245748444, 0.9117864972621295], 
             UndirectedEdge[217, 242] -> 
             RGBColor[
              0.9331663897832385, 0.7727340370105684, 0.2650823123143779], 
             UndirectedEdge[124, 266] -> 
             RGBColor[
              0.9603871654722977, 0.9179239383673736, 0.6137261570304736], 
             UndirectedEdge[219, 293] -> 
             RGBColor[
              0.9933055141126014, 0.9880894965402311, 0.5127247086136432], 
             UndirectedEdge[37, 170] -> 
             RGBColor[
              0.9899904942088997, 0.9767881049435094, 0.5099697249045285], 
             UndirectedEdge[205, 293] -> 
             RGBColor[
              0.9708696904707929, 0.9106643650514854, 0.3957932412040392], 
             UndirectedEdge[122, 268] -> 
             RGBColor[
              0.9925070464229813, 0.9892044106709651, 0.6310009749501605], 
             UndirectedEdge[246, 392] -> 
             RGBColor[
              0.5812854312855972, 0.6463581000015448, 0.9230359268449151], 
             UndirectedEdge[282, 398] -> 
             RGBColor[
              0.9291825727582745, 0.8150749302802353, 0.6048077421174352], 
             UndirectedEdge[34, 248] -> 
             RGBColor[
              0.9726465055964986, 0.9785900722595869, 0.9074378353757576], 
             UndirectedEdge[263, 264] -> 
             RGBColor[
              0.9632549889619111, 0.8960096376391379, 0.5804745541262204], 
             UndirectedEdge[100, 377] -> 
             RGBColor[
              0.9942307564856888, 0.9900684964199116, 0.6134316309901695], 
             UndirectedEdge[107, 241] -> 
             RGBColor[
              0.9646451494273403, 0.8893109557148049, 0.521843494777636], 
             UndirectedEdge[11, 95] -> 
             RGBColor[
              0.9929704241257982, 0.9869392137004422, 0.5131189798171634], 
             UndirectedEdge[7, 96] -> 
             RGBColor[
              0.9430856262349645, 0.7959499438208038, 0.43097530240010595`], 
             UndirectedEdge[111, 383] -> 
             RGBColor[
              0.9446867244247656, 0.8556769214757391, 0.6010932136269119], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.9708009177471754, 0.977558502548882, 0.9260057689765339], 
             UndirectedEdge[121, 122] -> 
             RGBColor[
              0.9899568939997716, 0.9881498571080399, 0.6732636001856618], 
             UndirectedEdge[156, 221] -> 
             RGBColor[
              0.9938860802958971, 0.9893312689020555, 0.5759157548262129], 
             UndirectedEdge[61, 176] -> 
             RGBColor[
              0.9676645231090764, 0.8964335171168172, 0.4833625964926534], 
             UndirectedEdge[128, 261] -> 
             RGBColor[
              0.9932387281454108, 0.9879466481095077, 0.5054554682401663], 
             UndirectedEdge[69, 381] -> 
             RGBColor[
              0.9653818203605676, 0.9712622027687128, 0.8135465258931047], 
             UndirectedEdge[166, 178] -> 
             RGBColor[
              0.9900426989153144, 0.9878681622899195, 0.6487861452080615], 
             UndirectedEdge[114, 202] -> 
             RGBColor[
              0.9744613707624457, 0.9258528758159958, 0.5181144812140919], 
             UndirectedEdge[40, 134] -> 
             RGBColor[
              0.9841421480304473, 0.9857875669303608, 0.8241562384464611], 
             UndirectedEdge[84, 234] -> 
             RGBColor[
              0.9382859812097275, 0.9521630523160851, 0.94131725796232], 
             UndirectedEdge[236, 367] -> 
             RGBColor[
              0.9652400303301438, 0.9735966520512236, 0.9437237411857341], 
             UndirectedEdge[307, 366] -> 
             RGBColor[
              0.9943826956543892, 0.9903934789383553, 0.629969271843354], 
             UndirectedEdge[129, 396] -> 
             RGBColor[
              0.9937668039534597, 0.98907614886627, 0.5629332610401663], 
             UndirectedEdge[67, 208] -> 
             RGBColor[
              0.9341063501496247, 0.7708201746381015, 0.2867327104901896], 
             UndirectedEdge[203, 309] -> 
             RGBColor[
              0.9689087455954588, 0.9056081470516477, 0.33984084593387115`], 
             UndirectedEdge[142, 302] -> 
             RGBColor[
              0.9367192597877048, 0.7801826363459458, 0.2954503056556811], 
             UndirectedEdge[93, 248] -> 
             RGBColor[
              0.9754266980845879, 0.977723174772668, 0.7147788800087742], 
             UndirectedEdge[110, 227] -> 
             RGBColor[
              0.8871381311882421, 0.9083677777092305, 0.7388161891092228], 
             UndirectedEdge[129, 361] -> 
             RGBColor[
              0.9940941675053634, 0.98977634640226, 0.5985647634112358], 
             UndirectedEdge[236, 332] -> 
             RGBColor[
              0.9501650966948959, 0.880043605043012, 0.6075547346232757], 
             UndirectedEdge[306, 353] -> 
             RGBColor[
              0.9844483480043892, 0.9852845127631615, 0.7656030630927472], 
             UndirectedEdge[257, 280] -> 
             RGBColor[
              0.9817623992416717, 0.9832692810908272, 0.7691931227327375], 
             UndirectedEdge[208, 385] -> 
             RGBColor[
              0.9164990280091639, 0.7915417463791088, 0.6153639376975794], 
             UndirectedEdge[79, 302] -> 
             RGBColor[
              0.9584897573085817, 0.8678373212625365, 0.3130367749476576], 
             UndirectedEdge[21, 242] -> 
             RGBColor[
              0.9567796571621309, 0.8548199230073572, 0.38340010961656323`], 
             UndirectedEdge[94, 103] -> 
             RGBColor[
              0.9812614753939712, 0.9817810137553094, 0.6815960332629326], 
             UndirectedEdge[237, 308] -> 
             RGBColor[
              0.9807943827859114, 0.9676139905632406, 0.6519897523956095], 
             UndirectedEdge[1, 235] -> 
             RGBColor[
              0.9831261073822504, 0.9532004937110778, 0.5200729775908828], 
             UndirectedEdge[31, 374] -> 
             RGBColor[
              0.9885595171892071, 0.9830726398742604, 0.6368846343385584], 
             UndirectedEdge[324, 351] -> 
             RGBColor[
              0.9634796072492994, 0.9721497542961696, 0.9407039098308148], 
             UndirectedEdge[62, 396] -> 
             RGBColor[
              0.9940441586589785, 0.9896693825365126, 0.5931216091010634], 
             UndirectedEdge[13, 123] -> 
             RGBColor[
              0.9537893019726793, 0.8426492562782364, 0.49538524999314837`], 
             UndirectedEdge[112, 337] -> 
             RGBColor[
              0.9945782204596623, 0.9908116867262441, 0.6512509402580979], 
             UndirectedEdge[262, 286] -> 
             RGBColor[
              0.9377551704058189, 0.7909270230586043, 0.26877455291583097`], 
             UndirectedEdge[56, 59] -> 
             RGBColor[
              0.9943339996219753, 0.9902893230489461, 0.6246690092321784], 
             UndirectedEdge[61, 118] -> 
             RGBColor[
              0.9650216133232739, 0.8890521217210994, 0.3426755203963007], 
             UndirectedEdge[14, 235] -> 
             RGBColor[
              0.961410585167858, 0.8716264812501728, 0.47905577185225623`], 
             UndirectedEdge[154, 286] -> 
             RGBColor[
              0.9664862171603437, 0.9014472638947245, 0.5469947466461915], 
             UndirectedEdge[159, 215] -> 
             RGBColor[
              0.9829412446857245, 0.9863620019250223, 0.8942268659858728], 
             UndirectedEdge[25, 385] -> 
             RGBColor[
              0.9641373946472213, 0.9699387720023607, 0.7858163692606327], 
             UndirectedEdge[165, 256] -> 
             RGBColor[
              0.9908138531281026, 0.9801299448346088, 0.4651709764656563], 
             UndirectedEdge[292, 384] -> 
             RGBColor[
              0.9886871367039649, 0.9874488969272536, 0.6815219339285681], 
             UndirectedEdge[1, 49] -> 
             RGBColor[
              0.9679698059307438, 0.9036167757364976, 0.3300691737458953], 
             UndirectedEdge[93, 125] -> 
             RGBColor[
              0.9895517674585405, 0.9879308230554155, 0.6762338116466132], 
             UndirectedEdge[15, 37] -> 
             RGBColor[
              0.989754739521219, 0.9775369726860462, 0.5753981086798741], 
             UndirectedEdge[141, 399] -> 
             RGBColor[
              0.9877501783036269, 0.9892023981695612, 0.8526747772386292], 
             UndirectedEdge[42, 288] -> 
             RGBColor[
              0.952748719814698, 0.96402383427651, 0.9559642010597227], 
             UndirectedEdge[26, 218] -> 
             RGBColor[
              0.9626439282414059, 0.9716604833641699, 0.948118264850101], 
             UndirectedEdge[292, 389] -> 
             RGBColor[
              0.9880126646418854, 0.9893109430160223, 0.8483246993208182], 
             UndirectedEdge[87, 361] -> 
             RGBColor[
              0.9944050420377875, 0.9904412755928784, 0.6324015377703686], 
             UndirectedEdge[3, 11] -> 
             RGBColor[
              0.9859889731766533, 0.986433508494094, 0.7629951865355024], 
             UndirectedEdge[217, 364] -> 
             RGBColor[
              0.9695567006428482, 0.905713691160903, 0.37965355581475435`], 
             UndirectedEdge[83, 120] -> 
             RGBColor[
              0.9807513743193457, 0.9587494435040512, 0.6204825551414908], 
             UndirectedEdge[251, 380] -> 
             RGBColor[
              0.8944137077646385, 0.9155122664606744, 0.8554185472084657], 
             UndirectedEdge[209, 390] -> 
             RGBColor[
              0.9942606466120555, 0.9901324283778545, 0.6166849867847041], 
             UndirectedEdge[149, 315] -> 
             RGBColor[
              0.9616138968374617, 0.8802907282479769, 0.5340733686352876], 
             UndirectedEdge[34, 263] -> 
             RGBColor[
              0.9641852098937056, 0.8963943079000224, 0.565058385951784], 
             UndirectedEdge[327, 376] -> 
             RGBColor[
              0.9944755700904836, 0.9908677052694415, 0.6601096418675468], 
             UndirectedEdge[113, 316] -> 
             RGBColor[
              0.9633901973567982, 0.8938425410043895, 0.567355693843626], 
             UndirectedEdge[85, 307] -> 
             RGBColor[
              0.9935521935591021, 0.9886171189331785, 0.5395742440361708], 
             UndirectedEdge[140, 257] -> 
             RGBColor[
              0.9915047798755849, 0.9897552021263036, 0.7177749327231429], 
             UndirectedEdge[228, 330] -> 
             RGBColor[
              0.9932722220206849, 0.9875847288811572, 0.5459678181948793], 
             UndirectedEdge[22, 96] -> 
             RGBColor[
              0.9940452616800264, 0.9896717417870012, 0.593241666135056], 
             UndirectedEdge[22, 323] -> 
             RGBColor[
              0.9873359578237548, 0.9682029909631276, 0.46825809955382625`], 
             UndirectedEdge[167, 269] -> 
             RGBColor[
              0.9901618199926912, 0.9895502706931938, 0.765502869504545], 
             UndirectedEdge[85, 214] -> 
             RGBColor[
              0.9515627219113694, 0.9595085736272035, 0.7519083193216576], 
             UndirectedEdge[89, 155] -> 
             RGBColor[
              0.968796415812579, 0.976248998520977, 0.937703708217859], 
             UndirectedEdge[1, 396] -> 
             RGBColor[
              0.9821981642314648, 0.9512157171409917, 0.4190720922291803], 
             UndirectedEdge[172, 208] -> 
             RGBColor[
              0.9465833371632358, 0.8116521080201042, 0.44199387059734724`], 
             UndirectedEdge[45, 339] -> 
             RGBColor[
              0.9454034863570999, 0.8212500471552284, 0.27492856745928085`], 
             UndirectedEdge[250, 363] -> 
             RGBColor[
              0.9926334953104343, 0.9883517820614349, 0.5942129611753567], 
             UndirectedEdge[167, 222] -> 
             RGBColor[
              0.9674350598638055, 0.8959427184374756, 0.4583869383279198], 
             UndirectedEdge[73, 208] -> 
             RGBColor[
              0.9464137504042746, 0.8112893790905376, 0.4235353984525718], 
             UndirectedEdge[14, 317] -> 
             RGBColor[
              0.9482912176648871, 0.8289138197788384, 0.29696507175463], 
             UndirectedEdge[157, 334] -> 
             RGBColor[
              0.9534955199774969, 0.9306468376904564, 0.6629445903661735], 
             UndirectedEdge[107, 190] -> 
             RGBColor[
              0.9658729008593097, 0.8894510699724941, 0.47477638117042664`], 
             UndirectedEdge[12, 209] -> 
             RGBColor[
              0.9932561030795126, 0.9879838113366763, 0.5073466225914907], 
             UndirectedEdge[185, 219] -> 
             RGBColor[
              0.9334485691419478, 0.7535068217816854, 0.36373216067449626`], 
             UndirectedEdge[318, 345] -> 
             RGBColor[
              0.959863950106251, 0.9693354223863591, 0.9419286616883975], 
             UndirectedEdge[36, 383] -> 
             RGBColor[
              0.9590386509894991, 0.8634251674759006, 0.4059829260030413], 
             UndirectedEdge[24, 357] -> 
             RGBColor[
              0.9935594477871356, 0.9911458195472291, 0.7230458085262261], 
             UndirectedEdge[344, 354] -> 
             RGBColor[
              0.9222960260947337, 0.7252404883273477, 0.2561083527462102], 
             UndirectedEdge[7, 194] -> 
             RGBColor[
              0.9393391186871647, 0.7951719855138533, 0.5491313656876797], 
             UndirectedEdge[97, 248] -> 
             RGBColor[
              0.9745081348217867, 0.9793599037859324, 0.8765858213707355], 
             UndirectedEdge[14, 129] -> 
             RGBColor[
              0.9611037487717121, 0.870970189224735, 0.4456585237065034], 
             UndirectedEdge[160, 307] -> 
             RGBColor[
              0.9655713680174071, 0.9709693192963952, 0.7787699652240532], 
             UndirectedEdge[165, 400] -> 
             RGBColor[
              0.9773399060344776, 0.9352243235905211, 0.3664702432539717], 
             UndirectedEdge[310, 323] -> 
             RGBColor[
              0.9757188871285454, 0.9297562461874722, 0.36017289090815896`], 
             UndirectedEdge[309, 339] -> 
             RGBColor[
              0.9618847931390515, 0.8777605161553972, 0.33418920891409154`], 
             UndirectedEdge[355, 395] -> 
             RGBColor[
              0.963939880441976, 0.9695989641398589, 0.7710184532391395], 
             UndirectedEdge[32, 240] -> 
             RGBColor[
              0.9898614181420082, 0.9898624302769874, 0.8022017770855637], 
             UndirectedEdge[66, 322] -> 
             RGBColor[
              0.9904506685823354, 0.9893478553904721, 0.7373199590016877], 
             UndirectedEdge[28, 267] -> 
             RGBColor[
              0.9780270303422622, 0.9360805730916858, 0.4934219861077803], 
             UndirectedEdge[51, 102] -> 
             RGBColor[
              0.9824206396114854, 0.9846518892712288, 0.8359131391813179], 
             UndirectedEdge[244, 321] -> 
             RGBColor[
              0.9341974295562301, 0.7692533617186355, 0.29198281722551844`], 
             UndirectedEdge[140, 309] -> 
             RGBColor[
              0.9873587189636144, 0.9767694011803698, 0.6166494281685468], 
             UndirectedEdge[12, 324] -> 
             RGBColor[
              0.9674770402608421, 0.9718283602061026, 0.7309354916279998], 
             UndirectedEdge[130, 287] -> 
             RGBColor[
              0.9942215143353431, 0.9900487283948469, 0.6124256799609836], 
             UndirectedEdge[267, 367] -> 
             RGBColor[
              0.9810077241286221, 0.9832275831018114, 0.8118206204641185], 
             UndirectedEdge[138, 229] -> 
             RGBColor[
              0.9886859556786023, 0.9718789664989196, 0.5481515239098038], 
             UndirectedEdge[97, 193] -> 
             RGBColor[
              0.9769180547653911, 0.9382641339174995, 0.553373562496731], 
             UndirectedEdge[248, 340] -> 
             RGBColor[
              0.966981966852051, 0.9495095582827431, 0.6588059482426438], 
             UndirectedEdge[162, 248] -> 
             RGBColor[
              0.9733617428046183, 0.9788858412259023, 0.895584503862654], 
             UndirectedEdge[127, 317] -> 
             RGBColor[
              0.9809103329439401, 0.9469257964115152, 0.40945722184563554`], 
             UndirectedEdge[269, 355] -> 
             RGBColor[
              0.9897140577913228, 0.98859255262017, 0.7167667171535964], 
             UndirectedEdge[161, 184] -> 
             RGBColor[
              0.9620560691540736, 0.8750536901288484, 0.42820680103589476`], 
             UndirectedEdge[340, 360] -> 
             RGBColor[
              0.9696337185810546, 0.909229543811265, 0.3365331601888143], 
             UndirectedEdge[19, 185] -> 
             RGBColor[
              0.9210650712519844, 0.74750004087325, 0.5772046600512203], 
             UndirectedEdge[240, 357] -> 
             RGBColor[
              0.993701933496945, 0.9914505820729965, 0.7385544987191205], 
             UndirectedEdge[75, 132] -> 
             RGBColor[
              0.9889425939329304, 0.9881113270120725, 0.7177612439264864], 
             UndirectedEdge[89, 353] -> 
             RGBColor[
              0.9866123202371591, 0.986898399711182, 0.7619400225570174], 
             UndirectedEdge[214, 312] -> 
             RGBColor[
              0.9523627734870317, 0.961219803049923, 0.8389889959865204], 
             UndirectedEdge[119, 129] -> 
             RGBColor[
              0.9899650126205348, 0.9893469702333313, 0.7599025032301927], 
             UndirectedEdge[143, 377] -> 
             RGBColor[
              0.9910474843780411, 0.9900185654410469, 0.7582430591621949], 
             UndirectedEdge[5, 122] -> 
             RGBColor[
              0.9851751274885211, 0.9850351226632628, 0.7015769397949216], 
             UndirectedEdge[42, 318] -> 
             RGBColor[
              0.9556108523126852, 0.9659441176530338, 0.941522997424062], 
             UndirectedEdge[6, 137] -> 
             RGBColor[
              0.9750114389691629, 0.9787665675159402, 0.8228438928899104], 
             UndirectedEdge[113, 149] -> 
             RGBColor[
              0.9888790675187225, 0.9896692228711327, 0.8339661614728586], 
             UndirectedEdge[67, 124] -> 
             RGBColor[
              0.9672821370386099, 0.9412322782886446, 0.6402515134341427], 
             UndirectedEdge[141, 337] -> 
             RGBColor[
              0.9898940073345698, 0.9891284286432325, 0.7473279225634262], 
             UndirectedEdge[63, 224] -> 
             RGBColor[
              0.9928382097576899, 0.9900399960882509, 0.676296557337329], 
             UndirectedEdge[244, 357] -> 
             RGBColor[
              0.9826725720495677, 0.9558086709954973, 0.5628255169259456], 
             UndirectedEdge[9, 192] -> 
             RGBColor[
              0.9025814985949926, 0.9243847136936717, 0.9637597860147955], 
             UndirectedEdge[46, 369] -> 
             RGBColor[
              0.9382041016492555, 0.9531218761435906, 0.9786912311868461], 
             UndirectedEdge[350, 392] -> 
             RGBColor[
              0.5763308702866579, 0.6426629965208849, 0.9314227062596541], 
             UndirectedEdge[275, 339] -> 
             RGBColor[
              0.9225761111377226, 0.8602530063839475, 0.6299671165314085], 
             UndirectedEdge[119, 127] -> 
             RGBColor[
              0.9892999659632007, 0.9879245026798249, 0.6875162787715857], 
             UndirectedEdge[152, 398] -> 
             RGBColor[
              0.9502043529715037, 0.8984192837327003, 0.6217223599216006], 
             UndirectedEdge[105, 229] -> 
             RGBColor[
              0.9884426003076916, 0.9719137294160867, 0.5620264569248659], 
             UndirectedEdge[181, 365] -> 
             RGBColor[
              0.9852985421822987, 0.9878754487428438, 0.879281912416056], 
             UndirectedEdge[24, 285] -> 
             RGBColor[
              0.9296140216563376, 0.7343435654492012, 0.43929432494734966`], 
             UndirectedEdge[167, 189] -> 
             RGBColor[
              0.9939350750276252, 0.9894360636790949, 0.5812485290143925], 
             UndirectedEdge[157, 191] -> 
             RGBColor[
              0.9809899875063759, 0.9474603752590366, 0.38715769767936015`], 
             UndirectedEdge[78, 194] -> 
             RGBColor[
              0.972577352204025, 0.9786197655284025, 0.9111942301708587], 
             UndirectedEdge[107, 268] -> 
             RGBColor[
              0.96444992564991, 0.8892302256658153, 0.5250788579925969], 
             UndirectedEdge[5, 274] -> 
             RGBColor[
              0.9854381650174817, 0.9855977333405359, 0.7302069515428273], 
             UndirectedEdge[12, 118] -> 
             RGBColor[
              0.9913478165646071, 0.9821737008356008, 0.4466187559629608], 
             UndirectedEdge[20, 291] -> 
             RGBColor[
              0.7339965953050207, 0.7169249577633248, 0.6140120532050017], 
             UndirectedEdge[6, 379] -> 
             RGBColor[
              0.9943777702317307, 0.9903829439573253, 0.629433169983157], 
             UndirectedEdge[97, 181] -> 
             RGBColor[
              0.9896986041361906, 0.9900081223235861, 0.820384318828633], 
             UndirectedEdge[39, 320] -> 
             RGBColor[
              0.9839644031906944, 0.957570308004341, 0.3922051637745557], 
             UndirectedEdge[202, 218] -> 
             RGBColor[
              0.984004269460288, 0.9860049491568981, 0.8409345904112497], 
             UndirectedEdge[61, 344] -> 
             RGBColor[
              0.9146530094184411, 0.6949384740901736, 0.24995860212380594`], 
             UndirectedEdge[181, 214] -> 
             RGBColor[
              0.9490556860806438, 0.9601782760424409, 0.9174955588555553], 
             UndirectedEdge[274, 324] -> 
             RGBColor[
              0.9677455030843862, 0.9724025750399085, 0.7601560132102858], 
             UndirectedEdge[62, 231] -> 
             RGBColor[
              0.9660012812619743, 0.9720855446842867, 0.8411694369385957], 
             UndirectedEdge[117, 289] -> 
             RGBColor[
              0.9725199128640056, 0.9753037707875956, 0.699741612260492], 
             UndirectedEdge[14, 396] -> 
             RGBColor[
              0.9604826420170725, 0.8696417046800866, 0.37805488649055374`], 
             UndirectedEdge[79, 175] -> 
             RGBColor[
              0.968293211561301, 0.9018626201686307, 0.5154241345963817], 
             UndirectedEdge[246, 395] -> 
             RGBColor[
              0.9589449581781904, 0.9688643300652857, 0.9530806351914003], 
             UndirectedEdge[87, 396] -> 
             RGBColor[
              0.9940776784858838, 0.9897410780568885, 0.5967700353992991], 
             UndirectedEdge[341, 366] -> 
             RGBColor[
              0.9591338402333831, 0.862633372874881, 0.47524584096765354`], 
             UndirectedEdge[40, 226] -> 
             RGBColor[
              0.9414576868310469, 0.9551925092475915, 0.9608449900112774], 
             UndirectedEdge[67, 316] -> 
             RGBColor[
              0.9546591438575385, 0.8539177201533564, 0.3033533871779688], 
             UndirectedEdge[303, 376] -> 
             RGBColor[
              0.9890518005657566, 0.9886120480350951, 0.7494228148305133], 
             UndirectedEdge[208, 357] -> 
             RGBColor[
              0.9454987849480767, 0.8118455450507303, 0.5066290415942107], 
             UndirectedEdge[54, 66] -> 
             RGBColor[
              0.9933929344803777, 0.9882764798673498, 0.5222398761501267], 
             UndirectedEdge[3, 160] -> 
             RGBColor[
              0.9575899559324201, 0.9678912390912484, 0.9566733216821265], 
             UndirectedEdge[230, 328] -> 
             RGBColor[
              0.9923359352982217, 0.9902273133876041, 0.7133343795392165], 
             UndirectedEdge[282, 383] -> 
             RGBColor[
              0.9153715985846274, 0.7021836196707208, 0.25076420561854157`], 
             UndirectedEdge[106, 150] -> 
             RGBColor[
              0.9950726145700703, 0.9918691457374946, 0.7050626881292354], 
             UndirectedEdge[1, 298] -> 
             RGBColor[
              0.9797015865236312, 0.9520262778844883, 0.5944105668668623], 
             UndirectedEdge[66, 131] -> 
             RGBColor[
              0.9945377391521761, 0.9910379641040239, 0.6695866226598469], 
             UndirectedEdge[53, 126] -> 
             RGBColor[
              0.9735754629852418, 0.9798132040773773, 0.9296140279296691], 
             UndirectedEdge[182, 281] -> 
             RGBColor[
              0.9205912739641667, 0.6942019030732983, 0.510662291365936], 
             UndirectedEdge[74, 263] -> 
             RGBColor[
              0.9671749065307087, 0.8959755186035112, 0.3952026642843294], 
             UndirectedEdge[24, 243] -> 
             RGBColor[
              0.9945489439917359, 0.9915550016567238, 0.7066472956819071], 
             UndirectedEdge[177, 252] -> 
             RGBColor[
              0.9717578142077012, 0.9289479822470188, 0.5892485922080503], 
             UndirectedEdge[10, 216] -> 
             RGBColor[
              0.98114382296052, 0.9821507322730458, 0.718092961008526], 
             UndirectedEdge[280, 339] -> 
             RGBColor[
              0.9536702144848919, 0.8841774989933187, 0.6028006096927787], 
             UndirectedEdge[152, 154] -> 
             RGBColor[
              0.9690349050141809, 0.9115519619353092, 0.5490454807187819], 
             UndirectedEdge[36, 304] -> 
             RGBColor[
              0.9865292481866397, 0.9654931313322634, 0.4641580935383369], 
             UndirectedEdge[128, 299] -> 
             RGBColor[
              0.9934065289895386, 0.9883055571478292, 0.5237195545767015], 
             UndirectedEdge[95, 162] -> 
             RGBColor[
              0.990307517557431, 0.9868229228099432, 0.6288412960565729], 
             UndirectedEdge[215, 329] -> 
             RGBColor[
              0.9860041629321898, 0.9876285973333443, 0.8434663840636123], 
             UndirectedEdge[208, 387] -> 
             RGBColor[
              0.9416013915165644, 0.8102338727083573, 0.5712189368852512], 
             UndirectedEdge[178, 197] -> 
             RGBColor[
              0.9897087364576219, 0.98773006023122, 0.6543207673991606], 
             UndirectedEdge[53, 303] -> 
             RGBColor[
              0.9752552021845735, 0.9810659508219184, 0.9267706676113481], 
             UndirectedEdge[59, 121] -> 
             RGBColor[
              0.9907756892388959, 0.9899011773316294, 0.7623844089458706], 
             UndirectedEdge[134, 269] -> 
             RGBColor[
              0.9904924059449214, 0.9902573606176472, 0.8014851102647904], 
             UndirectedEdge[44, 362] -> 
             RGBColor[
              0.9799089336528015, 0.9808691087969816, 0.6915676641366473], 
             UndirectedEdge[284, 338] -> 
             RGBColor[
              0.9493664922336826, 0.9294539414044816, 0.6672994488290656], 
             UndirectedEdge[12, 346] -> 
             RGBColor[
              0.9831707677061218, 0.9835327164386719, 0.7043701046428014], 
             UndirectedEdge[113, 387] -> 
             RGBColor[
              0.9858100183472391, 0.9884000921677583, 0.8848282486889909], 
             UndirectedEdge[55, 400] -> 
             RGBColor[
              0.9787730566691644, 0.9400586772010907, 0.37203776284194146`], 
             UndirectedEdge[25, 201] -> 
             RGBColor[
              0.9575673032088368, 0.8573897367927896, 0.4167539271352371], 
             UndirectedEdge[123, 309] -> 
             RGBColor[
              0.9494846423571521, 0.8285980504104598, 0.32421175652602696`], 
             UndirectedEdge[35, 162] -> 
             RGBColor[
              0.9889551253449612, 0.9822609863204907, 0.6235875076889678], 
             UndirectedEdge[73, 172] -> 
             RGBColor[
              0.9943683107493007, 0.990362711080908, 0.628403563697812], 
             UndirectedEdge[137, 282] -> 
             RGBColor[
              0.9307429854302678, 0.8162386834960667, 0.6021663704845553], 
             UndirectedEdge[37, 114] -> 
             RGBColor[
              0.9704320875117387, 0.9116923005821094, 0.3408342305839836], 
             UndirectedEdge[214, 248] -> 
             RGBColor[
              0.93386521676624, 0.9495300575047871, 0.9736970613976579], 
             UndirectedEdge[161, 363] -> 
             RGBColor[
              0.9931171580372196, 0.9874895311899698, 0.508982487014328], 
             UndirectedEdge[51, 84] -> 
             RGBColor[
              0.9900410616165701, 0.9901497372924789, 0.8147089121271927], 
             UndirectedEdge[56, 278] -> 
             RGBColor[
              0.9668838968357589, 0.9721055094694522, 0.7890299393994995], 
             UndirectedEdge[4, 140] -> 
             RGBColor[
              0.9919214731055972, 0.9909273357675625, 0.7835456274050759], 
             UndirectedEdge[221, 351] -> 
             RGBColor[
              0.9893203896530576, 0.9884372173784385, 0.7238328367419669], 
             UndirectedEdge[54, 204] -> 
             RGBColor[
              0.980034216300396, 0.9809402401886735, 0.689585850283113], 
             UndirectedEdge[10, 298] -> 
             RGBColor[
              0.9786303391412814, 0.9829251325537174, 0.8915913097522054], 
             UndirectedEdge[134, 226] -> 
             RGBColor[
              0.9525059422065625, 0.9615260264644212, 0.8545720275725128], 
             UndirectedEdge[35, 98] -> 
             RGBColor[
              0.9921513619403102, 0.9835180162107666, 0.5659148735551266], 
             UndirectedEdge[70, 180] -> 
             RGBColor[
              0.9836158054304218, 0.983570193393241, 0.680254895515757], 
             UndirectedEdge[165, 328] -> 
             RGBColor[
              0.99125662779068, 0.9810769950664766, 0.5133642659987459], 
             UndirectedEdge[162, 214] -> 
             RGBColor[
              0.9493180070455404, 0.9602867525027668, 0.9131482216023252], 
             UndirectedEdge[211, 370] -> 
             RGBColor[
              0.9826965223053699, 0.9601791180277714, 0.5925685098178383], 
             UndirectedEdge[55, 245] -> 
             RGBColor[
              0.9550464621165153, 0.9599520716397965, 0.7060451217831025], 
             UndirectedEdge[247, 315] -> 
             RGBColor[
              0.9600143067473923, 0.8796292566381431, 0.560582716034191], 
             UndirectedEdge[16, 268] -> 
             RGBColor[
              0.9203174415505304, 0.9365492133978517, 0.8837515874653599], 
             UndirectedEdge[154, 291] -> 
             RGBColor[
              0.9658427638281238, 0.8988961858505854, 0.5464770089912966], 
             UndirectedEdge[296, 373] -> 
             RGBColor[
              0.9942991453940124, 0.991446943657194, 0.7104411133414897], 
             UndirectedEdge[101, 394] -> 
             RGBColor[
              0.9929924587870491, 0.9869863436128122, 0.515517316712172], 
             UndirectedEdge[173, 388] -> 
             RGBColor[
              0.9929420288979143, 0.9873120384200081, 0.4731615861656776], 
             UndirectedEdge[84, 102] -> 
             RGBColor[
              0.9776878313195962, 0.9826947514149074, 0.9143480206931581], 
             UndirectedEdge[216, 298] -> 
             RGBColor[
              0.9906660256023914, 0.9885943855279433, 0.6725082243559013], 
             UndirectedEdge[209, 310] -> 
             RGBColor[
              0.9819936913558924, 0.9502956462397276, 0.4378638543018444], 
             UndirectedEdge[34, 93] -> 
             RGBColor[
              0.9901642511557686, 0.9881841008043324, 0.6660833717265452], 
             UndirectedEdge[112, 285] -> 
             RGBColor[
              0.9297328808248249, 0.7345977931920903, 0.4522314119234413], 
             UndirectedEdge[131, 309] -> 
             RGBColor[
              0.9903751279810564, 0.9780167638272579, 0.5666597245332294], 
             UndirectedEdge[116, 265] -> 
             RGBColor[
              0.9731850925638534, 0.9795220664562787, 0.9302748232281675], 
             UndirectedEdge[49, 129] -> 
             RGBColor[
              0.9795384456527387, 0.9414772074617759, 0.47393034255688127`], 
             UndirectedEdge[238, 325] -> 
             RGBColor[
              0.8224263768556896, 0.8602297602624526, 0.891526593105406], 
             UndirectedEdge[112, 399] -> 
             RGBColor[
              0.9924343914287195, 0.9908856562525727, 0.7565977949333009], 
             UndirectedEdge[186, 322] -> 
             RGBColor[
              0.9849121643106354, 0.9716854446103853, 0.6290479759949255], 
             UndirectedEdge[180, 332] -> 
             RGBColor[
              0.9558276943021262, 0.8842667610668318, 0.597969433916223], 
             UndirectedEdge[60, 331] -> 
             RGBColor[
              0.9259496317169944, 0.7376495061795634, 0.5517759038010243], 
             UndirectedEdge[14, 126] -> 
             RGBColor[
              0.9542875642889888, 0.868351920048453, 0.5891200883073613], 
             UndirectedEdge[275, 288] -> 
             RGBColor[
              0.9434855672062723, 0.9566376478281307, 0.9550806732946171], 
             UndirectedEdge[276, 290] -> 
             RGBColor[
              0.9313184465031816, 0.7414916261334742, 0.467308214608532], 
             UndirectedEdge[18, 232] -> 
             RGBColor[
              0.9853031515685854, 0.9606490503913527, 0.5196125322800745], 
             UndirectedEdge[4, 325] -> 
             RGBColor[
              0.9924353115411286, 0.9911398211657003, 0.7750299947570753], 
             UndirectedEdge[1, 62] -> 
             RGBColor[
              0.9830966256916234, 0.9531374353558827, 0.5168640775060271], 
             UndirectedEdge[20, 304] -> 
             RGBColor[
              0.7526790531437129, 0.7840715842018838, 0.6650999850588861], 
             UndirectedEdge[255, 328] -> 
             RGBColor[
              0.9443342414191344, 0.8017589536111307, 0.42575121366061575`], 
             UndirectedEdge[3, 74] -> 
             RGBColor[
              0.9856005260371696, 0.9856026593407685, 0.7207151126205609], 
             UndirectedEdge[18, 279] -> 
             RGBColor[
              0.9746288684911637, 0.9260793573750372, 0.35593837433467934`], 
             UndirectedEdge[163, 226] -> 
             RGBColor[
              0.9404417887577277, 0.9544348541278904, 0.9625646404607544], 
             UndirectedEdge[145, 254] -> 
             RGBColor[
              0.9602706825796156, 0.8895757093705094, 0.5919967275296112], 
             UndirectedEdge[23, 348] -> 
             RGBColor[
              0.9797770657448555, 0.9841816015416129, 0.9076186446405563], 
             UndirectedEdge[119, 396] -> 
             RGBColor[
              0.9893439058658953, 0.9880184856886829, 0.6922988660142431], 
             UndirectedEdge[73, 141] -> 
             RGBColor[
              0.9899090592867283, 0.9891606232469139, 0.7489662346660071], 
             UndirectedEdge[29, 396] -> 
             RGBColor[
              0.9940003631377892, 0.9899440504361046, 0.61512931849383], 
             UndirectedEdge[160, 312] -> 
             RGBColor[
              0.966123188849544, 0.9721496082586916, 0.8388322573587311], 
             UndirectedEdge[210, 397] -> 
             RGBColor[
              0.9266319030365383, 0.8270843834911961, 0.6199187984226391], 
             UndirectedEdge[11, 86] -> 
             RGBColor[
              0.9898291068221013, 0.9763428128186946, 0.500915555280298], 
             UndirectedEdge[113, 315] -> 
             RGBColor[
              0.9597808597982984, 0.8795327203253798, 0.5644515361220157], 
             UndirectedEdge[120, 160] -> 
             RGBColor[
              0.9616723262116542, 0.9706351007993006, 0.9362941358091661], 
             UndirectedEdge[5, 308] -> 
             RGBColor[
              0.9796704193899997, 0.9667757405028907, 0.6538923292482852], 
             UndirectedEdge[37, 261] -> 
             RGBColor[
              0.9897402427679569, 0.9762528424156347, 0.4827313999307721], 
             UndirectedEdge[22, 241] -> 
             RGBColor[
              0.9930515038774173, 0.9900321162421287, 0.66577754225684], 
             UndirectedEdge[55, 165] -> 
             RGBColor[
              0.9896745217725446, 0.9768318787805226, 0.4143878961996297], 
             UndirectedEdge[251, 283] -> 
             RGBColor[
              0.8942312381199375, 0.9149705154370723, 0.8245478074929004], 
             UndirectedEdge[334, 365] -> 
             RGBColor[
              0.9599726302013583, 0.9696682336597514, 0.9526400756457901], 
             UndirectedEdge[44, 358] -> 
             RGBColor[
              0.9800064077172193, 0.9810775959646316, 0.7021771145083233], 
             UndirectedEdge[225, 367] -> 
             RGBColor[
              0.9317959864885986, 0.7988459865140557, 0.5879030996373075], 
             UndirectedEdge[23, 321] -> 
             RGBColor[
              0.9346176178873656, 0.7989974172061396, 0.581826304081476], 
             UndirectedEdge[234, 269] -> 
             RGBColor[
              0.938529058789327, 0.9522635711420584, 0.9372888334037457], 
             UndirectedEdge[21, 208] -> 
             RGBColor[
              0.9459642898861425, 0.8103280284896821, 0.37461439480268593`], 
             UndirectedEdge[208, 240] -> 
             RGBColor[
              0.946831925367078, 0.812183813052, 0.46905116247701684`], 
             UndirectedEdge[15, 313] -> 
             RGBColor[
              0.992580400324189, 0.9870685900711715, 0.5863752673181444], 
             UndirectedEdge[63, 204] -> 
             RGBColor[
              0.9796505669935616, 0.9830696694257075, 0.862263034730878], 
             UndirectedEdge[241, 310] -> 
             RGBColor[
              0.9814344331822077, 0.9515853714664733, 0.5576923336111728], 
             UndirectedEdge[182, 256] -> 
             RGBColor[
              0.9225493959282786, 0.6933762721489942, 0.3593373946670079], 
             UndirectedEdge[373, 380] -> 
             RGBColor[
              0.9949255045970183, 0.9917059592843341, 0.7000607203820273], 
             UndirectedEdge[185, 210] -> 
             RGBColor[
              0.8942997143532373, 0.609820091082951, 0.23335299609883303`], 
             UndirectedEdge[96, 223] -> 
             RGBColor[
              0.9941464580959669, 0.9898881906881711, 0.6042562714983096], 
             UndirectedEdge[103, 222] -> 
             RGBColor[
              0.9551705427580262, 0.889162654676226, 0.6032605511709033], 
             UndirectedEdge[146, 375] -> 
             RGBColor[
              0.9777405340875523, 0.935043939632011, 0.4982795212135168], 
             UndirectedEdge[42, 276] -> 
             RGBColor[
              0.9604911781295589, 0.9679281800038524, 0.858166272944386], 
             UndirectedEdge[46, 372] -> 
             RGBColor[
              0.9732713978008563, 0.976681674118677, 0.763330474954544], 
             UndirectedEdge[95, 285] -> 
             RGBColor[
              0.9281392214236455, 0.7307555576358378, 0.315638169362193], 
             UndirectedEdge[14, 326] -> 
             RGBColor[
              0.956821751266506, 0.8699707920589328, 0.5726890413918855], 
             UndirectedEdge[22, 310] -> 
             RGBColor[
              0.9820855419567438, 0.9504921053874287, 0.44786122536832884`], 
             UndirectedEdge[23, 229] -> 
             RGBColor[
              0.9780317933358025, 0.9658848835024254, 0.6573692293030692], 
             UndirectedEdge[23, 160] -> 
             RGBColor[
              0.9555795197078247, 0.9663918590467323, 0.9600764658046212], 
             UndirectedEdge[165, 311] -> 
             RGBColor[
              0.968289939803332, 0.9664945249453465, 0.6905769928428722], 
             UndirectedEdge[179, 288] -> 
             RGBColor[
              0.9848358896228862, 0.987260546871116, 0.867980343798392], 
             UndirectedEdge[51, 167] -> 
             RGBColor[
              0.9946515507049809, 0.991406889723542, 0.6910964125512791], 
             UndirectedEdge[310, 346] -> 
             RGBColor[
              0.9719083559825015, 0.9458445513417232, 0.6348873363531551], 
             UndirectedEdge[79, 379] -> 
             RGBColor[
              0.9684889511067676, 0.9007241857385972, 0.4235443328527199], 
             UndirectedEdge[78, 264] -> 
             RGBColor[
              0.9718917127998203, 0.9783362360146349, 0.9225570494764275], 
             UndirectedEdge[309, 325] -> 
             RGBColor[
              0.9878725573991459, 0.9769818865785076, 0.6081337955205461], 
             UndirectedEdge[149, 358] -> 
             RGBColor[
              0.9917844016361729, 0.9887783782897672, 0.6337309581398327], 
             UndirectedEdge[6, 79] -> 
             RGBColor[
              0.9689981868687304, 0.9018133895418023, 0.47897150290354573`], 
             UndirectedEdge[134, 234] -> 
             RGBColor[
              0.9432270562503684, 0.9541272946716017, 0.8536869991466518], 
             UndirectedEdge[96, 209] -> 
             RGBColor[
              0.9939534110791748, 0.9894752826393001, 0.5832442950685716], 
             UndirectedEdge[216, 393] -> 
             RGBColor[
              0.9765348331859112, 0.9787133552456706, 0.7258947784798837], 
             UndirectedEdge[164, 388] -> 
             RGBColor[
              0.9646601714688514, 0.8867252583389695, 0.3505837701506138], 
             UndirectedEdge[155, 261] -> 
             RGBColor[
              0.9761544808370604, 0.9788621875090358, 0.7608555157382706], 
             UndirectedEdge[125, 288] -> 
             RGBColor[
              0.9829583363522822, 0.9864841303428031, 0.8990962604444053], 
             UndirectedEdge[287, 384] -> 
             RGBColor[
              0.9934857057100973, 0.9884749081471098, 0.5323374519874383], 
             UndirectedEdge[69, 320] -> 
             RGBColor[
              0.9640701460370374, 0.9680231047804874, 0.707645618823806], 
             UndirectedEdge[123, 339] -> 
             RGBColor[
              0.9255385185123427, 0.7424920692588851, 0.25894474804066414`], 
             UndirectedEdge[132, 202] -> 
             RGBColor[
              0.9935921555946627, 0.9900340402474832, 0.640705974511719], 
             UndirectedEdge[67, 249] -> 
             RGBColor[
              0.9818156536625174, 0.9493689270638082, 0.4649061831074289], 
             UndirectedEdge[374, 384] -> 
             RGBColor[
              0.9912775003531011, 0.9820556381419319, 0.4362156015520342], 
             UndirectedEdge[99, 252] -> 
             RGBColor[
              0.9783136617217087, 0.9510623952979634, 0.6147168218320476], 
             UndirectedEdge[44, 65] -> 
             RGBColor[
              0.975531433819878, 0.9662007497502997, 0.6662307511559362], 
             UndirectedEdge[88, 370] -> 
             RGBColor[
              0.9842544980881095, 0.9584976148824973, 0.3976901706925353], 
             UndirectedEdge[13, 275] -> 
             RGBColor[
              0.9508268945980592, 0.9604101934032987, 0.8664076184838927], 
             UndirectedEdge[183, 269] -> 
             RGBColor[
              0.9897570418516973, 0.9900322878207289, 0.8194158546507253], 
             UndirectedEdge[122, 178] -> 
             RGBColor[
              0.9928203141369975, 0.987051702853657, 0.4599136855763091], 
             UndirectedEdge[199, 216] -> 
             RGBColor[
              0.9369489774135721, 0.7695360646980663, 0.3605953807055897], 
             UndirectedEdge[107, 295] -> 
             RGBColor[
              0.8992957659328761, 0.840029016685827, 0.6273747018334315], 
             UndirectedEdge[89, 171] -> 
             RGBColor[
              0.9788401821282978, 0.9616916705174614, 0.6458196082951417], 
             UndirectedEdge[18, 91] -> 
             RGBColor[
              0.9804251256063656, 0.9590203693144258, 0.6286944780100394], 
             UndirectedEdge[194, 357] -> 
             RGBColor[
              0.9896318443452216, 0.989980515434372, 0.821490701333789], 
             UndirectedEdge[147, 388] -> 
             RGBColor[
              0.9420747427919365, 0.7935370243618354, 0.33222247604797306`], 
             UndirectedEdge[96, 323] -> 
             RGBColor[
              0.9876786068518277, 0.9689358825870447, 0.5055533316748861], 
             UndirectedEdge[168, 265] -> 
             RGBColor[
              0.9690239078275424, 0.9764186616932528, 0.9373186235759459], 
             UndirectedEdge[44, 372] -> 
             RGBColor[
              0.9804565098543385, 0.9820403189236229, 0.7511679544253511], 
             UndirectedEdge[180, 286] -> 
             RGBColor[
              0.9589786496466195, 0.8967592490141232, 0.6005047665488301], 
             UndirectedEdge[18, 45] -> 
             RGBColor[
              0.9643214766040965, 0.8903949530194681, 0.32066222640049646`], 
             UndirectedEdge[83, 217] -> 
             RGBColor[
              0.9607868380719301, 0.8764623867823715, 0.3173958150976469], 
             UndirectedEdge[137, 314] -> 
             RGBColor[
              0.9739567244399433, 0.9786711719866703, 0.8650926085839008], 
             UndirectedEdge[205, 338] -> 
             RGBColor[
              0.9381043746397791, 0.8892335976081351, 0.6351651299174779], 
             UndirectedEdge[210, 293] -> 
             RGBColor[
              0.9541566593238908, 0.8444027658414968, 0.38234554403797993`], 
             UndirectedEdge[295, 324] -> 
             RGBColor[
              0.901831206963431, 0.9243982669348759, 0.9849002472826602], 
             UndirectedEdge[270, 346] -> 
             RGBColor[
              0.9740522952457971, 0.9801688247965582, 0.9288068752903202], 
             UndirectedEdge[26, 349] -> 
             RGBColor[
              0.9440389438508738, 0.957784916468577, 0.9796116504661945], 
             UndirectedEdge[27, 208] -> 
             RGBColor[
              0.9462051564395502, 0.8108432176920771, 0.40083123268505827`], 
             UndirectedEdge[139, 193] -> 
             RGBColor[
              0.8763770045259078, 0.8609152886172413, 0.644707407182665], 
             UndirectedEdge[5, 296] -> 
             RGBColor[
              0.9855999077276116, 0.9871758549203646, 0.8373774191078659], 
             UndirectedEdge[42, 125] -> 
             RGBColor[
              0.9559494747356387, 0.9660841467271244, 0.9359111475489821], 
             UndirectedEdge[12, 106] -> 
             RGBColor[
              0.9939432059884321, 0.9894534549820944, 0.5821335339197408], 
             UndirectedEdge[242, 357] -> 
             RGBColor[
              0.956314152224065, 0.8563374395684051, 0.515414756408088], 
             UndirectedEdge[148, 279] -> 
             RGBColor[
              0.9552715147994518, 0.9373971783174713, 0.6714562549287398], 
             UndirectedEdge[292, 374] -> 
             RGBColor[
              0.9871643698640554, 0.9824957106016593, 0.6600058360418612], 
             UndirectedEdge[195, 369] -> 
             RGBColor[
              0.9544449077591578, 0.965055562320599, 0.9431981080975547], 
             UndirectedEdge[50, 371] -> 
             RGBColor[
              0.9938418271567662, 0.9892366159121332, 0.5710990737305354], 
             UndirectedEdge[29, 127] -> 
             RGBColor[
              0.9939564232350946, 0.9898500674272465, 0.6103467312511728], 
             UndirectedEdge[87, 127] -> 
             RGBColor[
              0.9940337385831892, 0.9896470950480304, 0.5919874481566417], 
             UndirectedEdge[264, 357] -> 
             RGBColor[
              0.9889462049410169, 0.9896969859206045, 0.8328535206393578], 
             UndirectedEdge[171, 306] -> 
             RGBColor[
              0.976676209895528, 0.9600777835694411, 0.6494826488308714], 
             UndirectedEdge[114, 170] -> 
             RGBColor[
              0.9747425204873523, 0.9251227800879512, 0.4519337841933236], 
             UndirectedEdge[57, 222] -> 
             RGBColor[
              0.9483172351978891, 0.884051469119137, 0.6148614132413344], 
             UndirectedEdge[38, 102] -> 
             RGBColor[
              0.9795775273140312, 0.9834761892715782, 0.8830308676888998], 
             UndirectedEdge[82, 331] -> 
             RGBColor[
              0.9898184126080252, 0.9892359200993776, 0.7586665152645107], 
             UndirectedEdge[90, 324] -> 
             RGBColor[
              0.9042902154197303, 0.9263590135299226, 0.9851347897044048], 
             UndirectedEdge[160, 341] -> 
             RGBColor[
              0.930322512596401, 0.8432092132329209, 0.6240465343483526], 
             UndirectedEdge[15, 311] -> 
             RGBColor[
              0.9710839631389789, 0.9763539223275823, 0.8621298275693221], 
             UndirectedEdge[271, 292] -> 
             RGBColor[
              0.9728784294291981, 0.934305879016557, 0.6045076551259221], 
             UndirectedEdge[41, 156] -> 
             RGBColor[
              0.9940233088014235, 0.9896247867994464, 0.5908522307766052], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.9814687771542809, 0.9840988996166222, 0.8445510462346948], 
             UndirectedEdge[129, 317] -> 
             RGBColor[
              0.9815753796012743, 0.9483482639650216, 0.4818434463042425], 
             UndirectedEdge[164, 354] -> 
             RGBColor[
              0.9461861657525097, 0.824353110145581, 0.27555832967267424`], 
             UndirectedEdge[78, 230] -> 
             RGBColor[
              0.9743298974742458, 0.9793444880359978, 0.8821500196015276], 
             UndirectedEdge[315, 363] -> 
             RGBColor[
              0.9623496710478636, 0.877724996606549, 0.34434707020513944`], 
             UndirectedEdge[5, 121] -> 
             RGBColor[
              0.9821278761903505, 0.9857400806525667, 0.8949179670098683], 
             UndirectedEdge[43, 380] -> 
             RGBColor[
              0.9637969689329147, 0.8811434571925727, 0.49764940917354655`], 
             UndirectedEdge[135, 234] -> 
             RGBColor[
              0.9385633598518685, 0.9522777555129164, 0.93672037602913], 
             UndirectedEdge[344, 356] -> 
             RGBColor[
              0.9394672848392507, 0.7894092675657983, 0.5224790025968525], 
             UndirectedEdge[186, 228] -> 
             RGBColor[
              0.9889115363965635, 0.9728751123333201, 0.5290273779915495], 
             UndirectedEdge[298, 396] -> 
             RGBColor[
              0.9906491194909863, 0.9885582250651183, 0.6706680984618986], 
             UndirectedEdge[86, 93] -> 
             RGBColor[
              0.9892311555337039, 0.9750638554749613, 0.4358322476658276], 
             UndirectedEdge[249, 266] -> 
             RGBColor[
              0.9749206820962053, 0.9260605871425371, 0.43838082670375983`], 
             UndirectedEdge[156, 364] -> 
             RGBColor[
              0.993584971530387, 0.9886872276993957, 0.5431419239283453], 
             UndirectedEdge[10, 311] -> 
             RGBColor[
              0.9587233224841081, 0.9687365020097798, 0.9547548277394573], 
             UndirectedEdge[27, 73] -> 
             RGBColor[
              0.9939901300256151, 0.9895538207528809, 0.587240925785523], 
             UndirectedEdge[56, 213] -> 
             RGBColor[
              0.9353483694130773, 0.761251182062147, 0.4049884941700198], 
             UndirectedEdge[27, 243] -> 
             RGBColor[
              0.9940646607740176, 0.9905191688225685, 0.6539360560828429], 
             UndirectedEdge[109, 157] -> 
             RGBColor[
              0.9813422467349799, 0.9498964744656341, 0.5478100026296076], 
             UndirectedEdge[12, 241] -> 
             RGBColor[
              0.992696844905828, 0.989273536563422, 0.627175101900819], 
             UndirectedEdge[192, 382] -> 
             RGBColor[
              0.9790275414694478, 0.9825208928751721, 0.8595503590197584], 
             UndirectedEdge[140, 280] -> 
             RGBColor[
              0.9791441403094547, 0.9831863840182913, 0.8852608289472339], 
             UndirectedEdge[199, 361] -> 
             RGBColor[
              0.9372594348540708, 0.7702001017712312, 0.3943867571826566], 
             UndirectedEdge[16, 351] -> 
             RGBColor[
              0.9168116821193649, 0.935099491779157, 0.941851093854349], 
             UndirectedEdge[140, 322] -> 
             RGBColor[
              0.9878158593909692, 0.9892295589871041, 0.8515862716441627], 
             UndirectedEdge[57, 238] -> 
             RGBColor[
              0.8056160690333091, 0.8486433251682342, 0.9625547784416044], 
             UndirectedEdge[49, 127] -> 
             RGBColor[
              0.9788733989954045, 0.9400547399082695, 0.4015441180982743], 
             UndirectedEdge[165, 182] -> 
             RGBColor[
              0.9199769139380338, 0.6852438524843385, 0.3029867948130116], 
             UndirectedEdge[253, 343] -> 
             RGBColor[
              0.9002814565761889, 0.5446334629629963, 0.27681209801441115`], 
             UndirectedEdge[104, 240] -> 
             RGBColor[
              0.9938341656584162, 0.9915052634699764, 0.7363630695976799], 
             UndirectedEdge[312, 348] -> 
             RGBColor[
              0.9903207348865748, 0.9899393507535721, 0.7863744361946661], 
             UndirectedEdge[242, 244] -> 
             RGBColor[
              0.946617931195689, 0.8210337964921757, 0.30210789549771927`], 
             UndirectedEdge[41, 165] -> 
             RGBColor[
              0.9910790893846682, 0.9806972583679037, 0.4940403061443971], 
             UndirectedEdge[54, 297] -> 
             RGBColor[
              0.9831564278541273, 0.9547666040019545, 0.3957170411392377], 
             UndirectedEdge[77, 145] -> 
             RGBColor[
              0.9628206434047251, 0.8909433185890698, 0.563760097554353], 
             UndirectedEdge[69, 150] -> 
             RGBColor[
              0.9657959509575915, 0.9721479862407207, 0.8586220856613656], 
             UndirectedEdge[106, 241] -> 
             RGBColor[
              0.9936467561854851, 0.9913053007398457, 0.7305670825186057], 
             UndirectedEdge[139, 276] -> 
             RGBColor[
              0.8926338573501762, 0.9140627400451498, 0.8516297230899124], 
             UndirectedEdge[313, 393] -> 
             RGBColor[
              0.9756107698947092, 0.9760137927259938, 0.6868020849596372], 
             UndirectedEdge[209, 323] -> 
             RGBColor[
              0.9872441072229033, 0.9680065318154265, 0.4582607284873418], 
             UndirectedEdge[8, 213] -> 
             RGBColor[
              0.9311576758138624, 0.760601529633451, 0.5531841203303807], 
             UndirectedEdge[160, 244] -> 
             RGBColor[
              0.9551593313766891, 0.9366478035592283, 0.6702329789486637], 
             UndirectedEdge[180, 284] -> 
             RGBColor[
              0.9728026405570716, 0.9471365668169098, 0.6347004288658085], 
             UndirectedEdge[24, 242] -> 
             RGBColor[
              0.957504806933257, 0.8563709450439075, 0.4623281870979997], 
             UndirectedEdge[81, 192] -> 
             RGBColor[
              0.9791307820450117, 0.9802285294732777, 0.6881054720063857], 
             UndirectedEdge[124, 249] -> 
             RGBColor[
              0.9795138672200876, 0.9815396321059834, 0.7688179809132996], 
             UndirectedEdge[195, 253] -> 
             RGBColor[
              0.9842557089925981, 0.9716578374067883, 0.6416126488158683], 
             UndirectedEdge[31, 81] -> 
             RGBColor[
              0.9899697875471469, 0.9877852076000606, 0.6461561844106792], 
             UndirectedEdge[172, 399] -> 
             RGBColor[
              0.9922094297661992, 0.9904044860035552, 0.7321121062704341], 
             UndirectedEdge[124, 315] -> 
             RGBColor[
              0.9487480198566087, 0.8717786045165219, 0.6043610272622291], 
             UndirectedEdge[181, 370] -> 
             RGBColor[
              0.9821064222873708, 0.9599350965054502, 0.6023479942459747], 
             UndirectedEdge[244, 348] -> 
             RGBColor[
              0.9793568774137199, 0.9544375460541088, 0.6177751577845987], 
             UndirectedEdge[284, 367] -> 
             RGBColor[
              0.9690442528358942, 0.9443335674082509, 0.6410623989332525], 
             UndirectedEdge[148, 232] -> 
             RGBColor[
              0.9659457978768735, 0.9719668713337868, 0.835130412874135], 
             UndirectedEdge[34, 211] -> 
             RGBColor[
              0.9884270749289015, 0.989482312319562, 0.8414568484055187], 
             UndirectedEdge[355, 392] -> 
             RGBColor[
              0.5862803535493829, 0.647092734076118, 0.7409737448926542], 
             UndirectedEdge[262, 338] -> 
             RGBColor[
              0.9300013880943621, 0.8571079561157551, 0.6286452767414954], 
             UndirectedEdge[87, 119] -> 
             RGBColor[
              0.9902758871529589, 0.9900118994239497, 0.7937392775893255], 
             UndirectedEdge[180, 367] -> 
             RGBColor[
              0.9709026279373743, 0.9778198080750433, 0.9341384404786814], 
             UndirectedEdge[69, 380] -> 
             RGBColor[
              0.9657231071126332, 0.9721436475260952, 0.8617035276397331], 
             UndirectedEdge[124, 338] -> 
             RGBColor[
              0.9463845348039768, 0.9593302699948327, 0.9685689107888825], 
             UndirectedEdge[249, 293] -> 
             RGBColor[
              0.993683367258898, 0.9888976862133467, 0.5538516917487302], 
             UndirectedEdge[212, 373] -> 
             RGBColor[
              0.9926814662788255, 0.9907779917706072, 0.7372502426994898], 
             UndirectedEdge[287, 292] -> 
             RGBColor[
              0.9893725752210516, 0.9889149806068374, 0.7561276864772654], 
             UndirectedEdge[12, 323] -> 
             RGBColor[
              0.9869812988521656, 0.9674444112844209, 0.42965565919780524`], 
             UndirectedEdge[120, 307] -> 
             RGBColor[
              0.9899013824968748, 0.988813840896507, 0.7241167991514686], 
             UndirectedEdge[99, 398] -> 
             RGBColor[
              0.9615010894941426, 0.9387642036086187, 0.6539505531341216], 
             UndirectedEdge[134, 350] -> 
             RGBColor[
              0.9844625719896392, 0.9860265385944802, 0.8236138442635023], 
             UndirectedEdge[45, 280] -> 
             RGBColor[
              0.9611350315477496, 0.9137730111447246, 0.6088069767233308], 
             UndirectedEdge[188, 330] -> 
             RGBColor[
              0.989994547503742, 0.9866935016497793, 0.6340280197867338], 
             UndirectedEdge[236, 284] -> 
             RGBColor[
              0.9671400429498411, 0.9429134107930901, 0.6442857295728611], 
             UndirectedEdge[374, 389] -> 
             RGBColor[
              0.9906030282910216, 0.9839176842307005, 0.6030183669442843], 
             UndirectedEdge[278, 319] -> 
             RGBColor[
              0.9652626735166638, 0.9725183990339599, 0.8946427934423469], 
             UndirectedEdge[78, 242] -> 
             RGBColor[
              0.9392596600828684, 0.8449766896624356, 0.6051182852451578], 
             UndirectedEdge[84, 189] -> 
             RGBColor[
              0.9893245859392146, 0.9881789112480317, 0.7048610285903062], 
             UndirectedEdge[223, 385] -> 
             RGBColor[
              0.9641371423419764, 0.9699382323469539, 0.7857889073917774], 
             UndirectedEdge[175, 278] -> 
             RGBColor[
              0.9666092927912964, 0.9730752607105572, 0.8723258271227148], 
             UndirectedEdge[151, 168] -> 
             RGBColor[
              0.9830808876478988, 0.9847378542567027, 0.8054635136636791], 
             UndirectedEdge[322, 339] -> 
             RGBColor[
              0.9623419335664063, 0.8902206739621314, 0.5691260523897074], 
             UndirectedEdge[177, 367] -> 
             RGBColor[
              0.962509838787911, 0.9222914544710226, 0.6156774342773883], 
             UndirectedEdge[294, 320] -> 
             RGBColor[
              0.9577114063582203, 0.9629693425748094, 0.7076120213190097], 
             UndirectedEdge[179, 279] -> 
             RGBColor[
              0.9816986425042615, 0.9561558219339079, 0.5841493019999182], 
             UndirectedEdge[18, 285] -> 
             RGBColor[
              0.9201262953022915, 0.7037260763039863, 0.2845094644948608], 
             UndirectedEdge[121, 296] -> 
             RGBColor[
              0.990381674238862, 0.9902905893651417, 0.8090640794986059], 
             UndirectedEdge[212, 351] -> 
             RGBColor[
              0.9878083881157194, 0.9892264694227854, 0.8517100900100938], 
             UndirectedEdge[29, 87] -> 
             RGBColor[
              0.9949323444248528, 0.9919374641713713, 0.7165697300689124], 
             UndirectedEdge[99, 141] -> 
             RGBColor[
              0.9783032634853785, 0.9510580953600184, 0.6148891475178118], 
             UndirectedEdge[121, 274] -> 
             RGBColor[
              0.9902199315287321, 0.9887124677853131, 0.7018936119335673], 
             UndirectedEdge[138, 218] -> 
             RGBColor[
              0.9846974817774692, 0.9861562136478099, 0.8196043636040278], 
             UndirectedEdge[61, 388] -> 
             RGBColor[
              0.9664579106187429, 0.8938526950072303, 0.35203027326897784`], 
             UndirectedEdge[283, 347] -> 
             RGBColor[
              0.9947415474745656, 0.9916272138554743, 0.702914963048187], 
             UndirectedEdge[253, 315] -> 
             RGBColor[
              0.9578798011347076, 0.8626470758141084, 0.3269824696566336], 
             UndirectedEdge[321, 366] -> 
             RGBColor[
              0.9451917375487096, 0.8048202970005561, 0.4638964467779062], 
             UndirectedEdge[164, 391] -> 
             RGBColor[
              0.9633210795502045, 0.8822525816137672, 0.34160664181119516`], 
             UndirectedEdge[74, 91] -> 
             RGBColor[
              0.9892195266830907, 0.9881549057973895, 0.7080151607337691], 
             UndirectedEdge[91, 285] -> 
             RGBColor[
              0.9247767711204217, 0.7328020988861104, 0.5528144241937403], 
             UndirectedEdge[51, 183] -> 
             RGBColor[
              0.994246772563987, 0.991888906851077, 0.7450093976974592], 
             UndirectedEdge[30, 54] -> 
             RGBColor[
              0.9929488185913181, 0.9890640914427355, 0.6002007314408495], 
             UndirectedEdge[68, 250] -> 
             RGBColor[
              0.9910854914778651, 0.9905816358807474, 0.7974000064276978], 
             UndirectedEdge[32, 230] -> 
             RGBColor[
              0.9875438742605055, 0.9891170861459584, 0.8560937691309012], 
             UndirectedEdge[275, 318] -> 
             RGBColor[
              0.9463476997042595, 0.9585579312046544, 0.9406394696589564], 
             UndirectedEdge[131, 186] -> 
             RGBColor[
              0.9889992348804761, 0.9733755533239372, 0.5613146396530847], 
             UndirectedEdge[192, 292] -> 
             RGBColor[
              0.9751301480379355, 0.9809092205327992, 0.9241402543107988], 
             UndirectedEdge[144, 200] -> 
             RGBColor[
              0.944292669540854, 0.8620468934217509, 0.606930406955479], 
             UndirectedEdge[139, 318] -> 
             RGBColor[
              0.8877535315333025, 0.912078677694331, 0.9349864475695884], 
             UndirectedEdge[93, 148] -> 
             RGBColor[
              0.9650021930243347, 0.9699485959672915, 0.7324248479294213], 
             UndirectedEdge[92, 311] -> 
             RGBColor[
              0.9549836547683954, 0.9216093010582034, 0.6388845881632259], 
             UndirectedEdge[334, 370] -> 
             RGBColor[
              0.9567805103064304, 0.9417278814223577, 0.6757061574757088], 
             UndirectedEdge[62, 129] -> 
             RGBColor[
              0.9946652654136181, 0.990997867081161, 0.6607252463170131], 
             UndirectedEdge[97, 191] -> 
             RGBColor[
              0.9918671596841291, 0.9886144448090738, 0.6179555893715539], 
             UndirectedEdge[120, 366] -> 
             RGBColor[
              0.9904836538486363, 0.9900592604412608, 0.7874934424284671], 
             UndirectedEdge[91, 288] -> 
             RGBColor[
              0.9824165914279187, 0.9862601048943693, 0.9080743758320324], 
             UndirectedEdge[21, 32] -> 
             RGBColor[
              0.9889937826610726, 0.9880066457146697, 0.7077650094112329], 
             UndirectedEdge[121, 178] -> 
             RGBColor[
              0.9897730628388268, 0.9877566608429608, 0.6532547127912556], 
             UndirectedEdge[294, 381] -> 
             RGBColor[
              0.9590230806817505, 0.9662084405630349, 0.8135129283883084], 
             UndirectedEdge[46, 149] -> 
             RGBColor[
              0.9717489985854497, 0.9773678036636484, 0.8841966708838138], 
             UndirectedEdge[66, 232] -> 
             RGBColor[
              0.9944938963375178, 0.9906313259554538, 0.6420727799508392], 
             UndirectedEdge[114, 261] -> 
             RGBColor[
              0.9744922690464094, 0.9245875175600764, 0.42469545921956714`], 
             UndirectedEdge[189, 395] -> 
             RGBColor[
              0.9637934861694671, 0.9692858415936939, 0.7550843401172751], 
             UndirectedEdge[54, 290] -> 
             RGBColor[
              0.9300120622899775, 0.7386974023971353, 0.32511635507007786`], 
             UndirectedEdge[4, 309] -> 
             RGBColor[
              0.9903936711258438, 0.9780244318941645, 0.5663524166359835], 
             UndirectedEdge[195, 315] -> 
             RGBColor[
              0.9588915969749279, 0.8791649872949039, 0.5791889224436796], 
             UndirectedEdge[181, 305] -> 
             RGBColor[
              0.980397089024996, 0.9842199530035204, 0.8875787941076476], 
             UndirectedEdge[153, 372] -> 
             RGBColor[
              0.9814726874860641, 0.9483912970961952, 0.4483295316811984], 
             UndirectedEdge[175, 227] -> 
             RGBColor[
              0.887287794237786, 0.910244993364432, 0.8682909317420431], 
             UndirectedEdge[271, 287] -> 
             RGBColor[
              0.9776769984353306, 0.9353318902364134, 0.4553231731847923], 
             UndirectedEdge[232, 297] -> 
             RGBColor[
              0.9842573897112674, 0.9571214500900584, 0.5155499449399503], 
             UndirectedEdge[21, 25] -> 
             RGBColor[
              0.9936026565241998, 0.9887250541129341, 0.5450668263657393], 
             UndirectedEdge[123, 297] -> 
             RGBColor[
              0.9434107469020214, 0.8081093748218304, 0.30061581964175554`], 
             UndirectedEdge[6, 178] -> 
             RGBColor[
              0.9937617444848732, 0.9890653271745542, 0.5623825691079429], 
             UndirectedEdge[90, 319] -> 
             RGBColor[
              0.9287017309280604, 0.9434699415571515, 0.8947698427568415], 
             UndirectedEdge[258, 302] -> 
             RGBColor[
              0.9668288472300689, 0.8997680541292783, 0.3256367646457444], 
             UndirectedEdge[253, 397] -> 
             RGBColor[
              0.960756875625737, 0.9543111263854689, 0.6893917188545076], 
             UndirectedEdge[169, 177] -> 
             RGBColor[
              0.9687896160844369, 0.9063821878854822, 0.33325398138483564`], 
             UndirectedEdge[198, 332] -> 
             RGBColor[
              0.9643517548114553, 0.8893751219237942, 0.5276134944768652], 
             UndirectedEdge[45, 123] -> 
             RGBColor[
              0.9330033355752005, 0.7720875814102912, 0.26495111507121627`], 
             UndirectedEdge[223, 245] -> 
             RGBColor[
              0.956445128654817, 0.9638048294269623, 0.7850552362595544], 
             UndirectedEdge[380, 381] -> 
             RGBColor[
              0.9947651374300692, 0.9913629501298378, 0.6826057439310502], 
             UndirectedEdge[277, 378] -> 
             RGBColor[
              0.9616291066842326, 0.882228108311033, 0.3054367545137796], 
             UndirectedEdge[119, 326] -> 
             RGBColor[
              0.9856830151153287, 0.9883475730675291, 0.8869330209155748], 
             UndirectedEdge[89, 133] -> 
             RGBColor[
              0.9820657408800009, 0.9860031617143354, 0.9088796716956054], 
             UndirectedEdge[22, 346] -> 
             RGBColor[
              0.9835254266777109, 0.9842912961173786, 0.7429725449988224], 
             UndirectedEdge[73, 243] -> 
             RGBColor[
              0.9942732547387418, 0.9909653302210288, 0.6766402218503564], 
             UndirectedEdge[26, 353] -> 
             RGBColor[
              0.9725791457587946, 0.9764324811624321, 0.7856945265108051], 
             UndirectedEdge[21, 230] -> 
             RGBColor[
              0.9918498945535081, 0.9891877213809194, 0.6604318439729331], 
             UndirectedEdge[107, 390] -> 
             RGBColor[
              0.96594614276283, 0.8896077269982319, 0.4827483103719845], 
             UndirectedEdge[223, 364] -> 
             RGBColor[
              0.9934725692866202, 0.9884468106655884, 0.5309076333605589], 
             UndirectedEdge[2, 211] -> 
             RGBColor[
              0.9842771927218943, 0.9869176538826783, 0.8722301916215207], 
             UndirectedEdge[128, 353] -> 
             RGBColor[
              0.9934086891044235, 0.9883101774151468, 0.5239546697512396], 
             UndirectedEdge[259, 331] -> 
             RGBColor[
              0.9886903331518313, 0.9895911763601712, 0.8370939783611296], 
             UndirectedEdge[2, 334] -> 
             RGBColor[
              0.9583611807229548, 0.9684664172772646, 0.9553678392793912], 
             UndirectedEdge[72, 191] -> 
             RGBColor[
              0.9697536277598704, 0.973271094327577, 0.7068374672059309], 
             UndirectedEdge[247, 301] -> 
             RGBColor[
              0.9872798005240777, 0.98900788486956, 0.8604701543444329], 
             UndirectedEdge[247, 397] -> 
             RGBColor[
              0.9628913812384217, 0.9712933072095036, 0.922991965232065], 
             UndirectedEdge[125, 263] -> 
             RGBColor[
              0.9635727261964775, 0.8961410301511055, 0.5752088258718521], 
             UndirectedEdge[123, 325] -> 
             RGBColor[
              0.9515262827724371, 0.8417134396819955, 0.5328893346471189], 
             UndirectedEdge[129, 393] -> 
             RGBColor[
              0.9771390338291457, 0.9800056793274938, 0.7916582898018306], 
             UndirectedEdge[19, 205] -> 
             RGBColor[
              0.9584723560196298, 0.9046279891377348, 0.6077597162835319], 
             UndirectedEdge[277, 352] -> 
             RGBColor[
              0.9640151457367734, 0.8902767783038648, 0.31470606566723386`], 
             UndirectedEdge[139, 224] -> 
             RGBColor[
              0.8919196025668412, 0.9125350212858321, 0.7738874977934583], 
             UndirectedEdge[65, 250] -> 
             RGBColor[
              0.9884950442809782, 0.9743918149845683, 0.5781358604068201], 
             UndirectedEdge[58, 117] -> 
             RGBColor[
              0.9928008971314434, 0.9870101718421371, 0.4578002643496151], 
             UndirectedEdge[134, 272] -> 
             RGBColor[
              0.98856296950315, 0.9890846083462718, 0.8166729408280776], 
             UndirectedEdge[74, 95] -> 
             RGBColor[
              0.9925819769863145, 0.9861083645471168, 0.4708389059022219], 
             UndirectedEdge[156, 245] -> 
             RGBColor[
              0.956557530898584, 0.9640452464607696, 0.7972895268273409], 
             UndirectedEdge[221, 324] -> 
             RGBColor[
              0.9678015682166674, 0.9725224926888034, 0.7662583568651975], 
             UndirectedEdge[227, 375] -> 
             RGBColor[
              0.8707973123276591, 0.8536627799811419, 0.6399257323835035], 
             UndirectedEdge[132, 348] -> 
             RGBColor[
              0.9895915436304367, 0.9883796843892378, 0.7070064680108267], 
             UndirectedEdge[137, 319] -> 
             RGBColor[
              0.9729598443871008, 0.9782589364661711, 0.8816134909023784], 
             UndirectedEdge[128, 170] -> 
             RGBColor[
              0.9934889795863537, 0.9884819106373826, 0.5326937932139227], 
             UndirectedEdge[120, 220] -> 
             RGBColor[
              0.9893239094695496, 0.9875786844825379, 0.6612624238775533], 
             UndirectedEdge[292, 371] -> 
             RGBColor[
              0.989520778764547, 0.9892319730006973, 0.7722587275804993], 
             UndirectedEdge[143, 378] -> 
             RGBColor[
              0.9735653612080415, 0.9323707907947025, 0.5777847207611124], 
             UndirectedEdge[59, 373] -> 
             RGBColor[
              0.9946931603940463, 0.9910575316236816, 0.6637614427887544], 
             UndirectedEdge[2, 340] -> 
             RGBColor[
              0.9775696377162246, 0.9574058258775238, 0.6408837831764167], 
             UndirectedEdge[131, 322] -> 
             RGBColor[
              0.9908322684084112, 0.9904769216339923, 0.8015965680088453], 
             UndirectedEdge[62, 317] -> 
             RGBColor[
              0.9818527343067931, 0.9489414976352643, 0.5120317943651397], 
             UndirectedEdge[243, 337] -> 
             RGBColor[
              0.9942582027865834, 0.9909331356173474, 0.6750019097477755], 
             UndirectedEdge[21, 217] -> 
             RGBColor[
              0.9696865355751829, 0.9059913949528419, 0.3937852869510795], 
             UndirectedEdge[24, 74] -> 
             RGBColor[
              0.9940567772190065, 0.9896963723604802, 0.5944950614873785], 
             UndirectedEdge[1, 127] -> 
             RGBColor[
              0.9821542243287702, 0.9511217341321336, 0.41428950498652306`], 
             UndirectedEdge[226, 355] -> 
             RGBColor[
              0.9517275940529639, 0.9598612184669438, 0.7698536344613187], 
             UndirectedEdge[97, 370] -> 
             RGBColor[
              0.9835151352694357, 0.9605176355258063, 0.579001974500826], 
             UndirectedEdge[148, 257] -> 
             RGBColor[
              0.9655914906063068, 0.9712090439080048, 0.7965662530039638], 
             UndirectedEdge[48, 344] -> 
             RGBColor[
              0.9231385170040861, 0.7781911417847891, 0.59310305708759], 
             UndirectedEdge[74, 148] -> 
             RGBColor[
              0.9652116971732485, 0.9703967041576995, 0.7552280816289502], 
             UndirectedEdge[266, 293] -> 
             RGBColor[
              0.9745566655111082, 0.925281992474737, 0.3987598678659042], 
             UndirectedEdge[84, 226] -> 
             RGBColor[
              0.9475648671659216, 0.9595617841089046, 0.942202286388181], 
             UndirectedEdge[354, 371] -> 
             RGBColor[
              0.9750472364464344, 0.9261787688327148, 0.4611799350780229], 
             UndirectedEdge[57, 188] -> 
             RGBColor[
              0.9722410875731053, 0.9781540497825802, 0.9021384279208391], 
             UndirectedEdge[134, 355] -> 
             RGBColor[
              0.9944120552523643, 0.9904562761497133, 0.6331648828965024], 
             UndirectedEdge[151, 378] -> 
             RGBColor[
              0.9772514798345138, 0.9334962596317513, 0.48770503295415246`], 
             UndirectedEdge[167, 238] -> 
             RGBColor[
              0.8247338936992255, 0.8605345744865728, 0.8060803035281899], 
             UndirectedEdge[41, 311] -> 
             RGBColor[
              0.9711276580501423, 0.9751942581432971, 0.7757969223756094], 
             UndirectedEdge[212, 295] -> 
             RGBColor[
              0.926159987829851, 0.9414749820614917, 0.8959064274619394], 
             UndirectedEdge[179, 285] -> 
             RGBColor[
              0.9271960693153891, 0.733802540862857, 0.5127203921600998], 
             UndirectedEdge[85, 348] -> 
             RGBColor[
              0.9895206833109123, 0.9882281213308526, 0.6992937595298032], 
             UndirectedEdge[108, 152] -> 
             RGBColor[
              0.964638147060018, 0.8901399330696513, 0.32878380313235367`], 
             UndirectedEdge[86, 148] -> 
             RGBColor[
              0.9612889049141806, 0.9576952481248395, 0.6948326792356874], 
             UndirectedEdge[113, 293] -> 
             RGBColor[
              0.9901826905766802, 0.988515153247041, 0.6892875309352307], 
             UndirectedEdge[229, 260] -> 
             RGBColor[
              0.8515394765278251, 0.8668077028068584, 0.6791711467612688], 
             UndirectedEdge[6, 278] -> 
             RGBColor[
              0.9673142680987259, 0.9730260300837288, 0.8358731954298789], 
             UndirectedEdge[142, 378] -> 
             RGBColor[
              0.9296258254194992, 0.7562548166043944, 0.2678936526178827], 
             UndirectedEdge[289, 303] -> 
             RGBColor[
              0.96828575400396, 0.9758681477802409, 0.9385681254579203], 
             UndirectedEdge[5, 213] -> 
             RGBColor[
              0.9270082925187475, 0.7577483019000533, 0.571017233492972], 
             UndirectedEdge[104, 243] -> 
             RGBColor[
              0.9934905214440152, 0.9915761775782015, 0.7575424358705548], 
             UndirectedEdge[121, 373] -> 
             RGBColor[
              0.9908271138567515, 0.990011169389396, 0.7679816612434921], 
             UndirectedEdge[120, 202] -> 
             RGBColor[
              0.9898704842129111, 0.9900791991524265, 0.8175358211459934], 
             UndirectedEdge[270, 351] -> 
             RGBColor[
              0.9798773892369075, 0.9843791932536239, 0.912946742152288], 
             UndirectedEdge[91, 125] -> 
             RGBColor[
              0.9856173463488593, 0.9883204173449838, 0.8880213223212918], 
             UndirectedEdge[280, 297] -> 
             RGBColor[
              0.9715424428745705, 0.9497948045562639, 0.64447168129387], 
             UndirectedEdge[33, 281] -> 
             RGBColor[
              0.9906176042144936, 0.9868987872657242, 0.6233404172639806], 
             UndirectedEdge[16, 241] -> 
             RGBColor[
              0.9205126653279607, 0.9366299434468413, 0.880516224250399], 
             UndirectedEdge[89, 342] -> 
             RGBColor[
              0.9863124893599245, 0.9862570917823292, 0.7293052819117299], 
             UndirectedEdge[157, 370] -> 
             RGBColor[
              0.9726379630916826, 0.9193635659757691, 0.34820408280863235`], 
             UndirectedEdge[90, 122] -> 
             RGBColor[
              0.9298118951622467, 0.9419639482860234, 0.7335313612127397], 
             UndirectedEdge[135, 156] -> 
             RGBColor[
              0.9899964102901656, 0.9891372939314294, 0.7431971278243646], 
             UndirectedEdge[12, 22] -> 
             RGBColor[
              0.9933479536803642, 0.9881802704843774, 0.5173439936579751], 
             UndirectedEdge[271, 384] -> 
             RGBColor[
              0.9769915599182439, 0.9338658065568297, 0.38071742063609504`], 
             UndirectedEdge[158, 324] -> 
             RGBColor[
              0.9631922669205726, 0.9720309316859315, 0.9454658826907502], 
             UndirectedEdge[301, 397] -> 
             RGBColor[
              0.9626582573847522, 0.9711969045050015, 0.9268554307925607], 
             UndirectedEdge[95, 233] -> 
             RGBColor[
              0.9918917484096261, 0.9874780429802018, 0.6025864909776776], 
             UndirectedEdge[123, 203] -> 
             RGBColor[
              0.9325624709687499, 0.7703397001551356, 0.2645963850604438], 
             UndirectedEdge[103, 145] -> 
             RGBColor[
              0.9541171846193517, 0.8849864406671728, 0.6024129944870322], 
             UndirectedEdge[20, 80] -> 
             RGBColor[
              0.7600646055105886, 0.8079711514986581, 0.7799836691476404], 
             UndirectedEdge[73, 337] -> 
             RGBColor[
              0.9941836720381808, 0.9899677875476599, 0.6083067794504556], 
             UndirectedEdge[122, 166] -> 
             RGBColor[
              0.9902265300762589, 0.9882613585549986, 0.6687950326024676], 
             UndirectedEdge[62, 216] -> 
             RGBColor[
              0.9940610647703836, 0.9897055429993378, 0.5949617349950662], 
             UndirectedEdge[128, 342] -> 
             RGBColor[
              0.993108858227189, 0.9876688694862941, 0.4913199291059522], 
             UndirectedEdge[280, 309] -> 
             RGBColor[
              0.9776163383297013, 0.9702834801448933, 0.6680676181781415], 
             UndirectedEdge[104, 141] -> 
             RGBColor[
              0.9891263259920016, 0.9897714706040865, 0.8298684486862055], 
             UndirectedEdge[148, 276] -> 
             RGBColor[
              0.9661512202329374, 0.9724062489820218, 0.8574893686118767], 
             UndirectedEdge[359, 394] -> 
             RGBColor[
              0.978573877635657, 0.9788399640590569, 0.6830945844063792], 
             UndirectedEdge[8, 43] -> 
             RGBColor[
              0.9590661949765121, 0.8791871605862551, 0.5760505764816801], 
             UndirectedEdge[56, 352] -> 
             RGBColor[
              0.979240809854913, 0.9406964091182685, 0.45379501416337115`], 
             UndirectedEdge[70, 152] -> 
             RGBColor[
              0.9704821272723272, 0.9098113329642467, 0.35503392572594006`], 
             UndirectedEdge[359, 397] -> 
             RGBColor[
              0.9518085456697334, 0.9635794727835272, 0.9664597412235634], 
             UndirectedEdge[118, 241] -> 
             RGBColor[
              0.9910513667616602, 0.9840255465933522, 0.5950523045618257], 
             UndirectedEdge[43, 227] -> 
             RGBColor[
              0.8567930233902159, 0.799480948606301, 0.621676166366923], 
             UndirectedEdge[234, 246] -> 
             RGBColor[
              0.9374537858329843, 0.9517278525995512, 0.9510307879877186], 
             UndirectedEdge[196, 317] -> 
             RGBColor[
              0.9815352391769628, 0.9482624076562389, 0.4774744088359275], 
             UndirectedEdge[46, 184] -> 
             RGBColor[
              0.9414236839127059, 0.862366230961099, 0.6136946864752324], 
             UndirectedEdge[136, 331] -> 
             RGBColor[
              0.9796397932076903, 0.9841506684377247, 0.9110504432432772], 
             UndirectedEdge[106, 320] -> 
             RGBColor[
              0.9933468096495162, 0.9877442642772614, 0.554086221291676], 
             UndirectedEdge[68, 161] -> 
             RGBColor[
              0.9915691542046503, 0.9897193850092825, 0.7121695322666692], 
             UndirectedEdge[45, 297] -> 
             RGBColor[
              0.9632757147467785, 0.8868673527181737, 0.3165996390603722], 
             UndirectedEdge[140, 203] -> 
             RGBColor[
              0.9704365475752121, 0.9185110509250456, 0.5570340567029636], 
             UndirectedEdge[225, 243] -> 
             RGBColor[
              0.9453977591240723, 0.8073029213262217, 0.48932057043808297`], 
             UndirectedEdge[107, 373] -> 
             RGBColor[
              0.9658172443818507, 0.8893320263949425, 0.468718517070982], 
             UndirectedEdge[187, 321] -> 
             RGBColor[
              0.9438110582490056, 0.8016823886867286, 0.32932994931550674`], 
             UndirectedEdge[297, 322] -> 
             RGBColor[
              0.980214161956085, 0.9558379795250767, 0.6107971239907988], 
             UndirectedEdge[106, 374] -> 
             RGBColor[
              0.9923239253906404, 0.9842938354874278, 0.5501125091014274], 
             UndirectedEdge[154, 383] -> 
             RGBColor[
              0.9570346244696755, 0.8639748484327816, 0.5393897733098854], 
             UndirectedEdge[111, 151] -> 
             RGBColor[
              0.9799000160641114, 0.9823655654377131, 0.8108478995508541], 
             UndirectedEdge[79, 227] -> 
             RGBColor[
              0.8621039504202523, 0.8205370045188756, 0.6259494629187701], 
             UndirectedEdge[93, 290] -> 
             RGBColor[
              0.9301694192945789, 0.7390339731187441, 0.3422436939260767], 
             UndirectedEdge[150, 283] -> 
             RGBColor[
              0.9949967983823922, 0.9917069825782436, 0.6968105639837456], 
             UndirectedEdge[46, 195] -> 
             RGBColor[
              0.9690266987229161, 0.9762420627105755, 0.9293122246922058], 
             UndirectedEdge[73, 177] -> 
             RGBColor[
              0.9760370806749821, 0.9297830412135011, 0.45039977478084386`], 
             UndirectedEdge[102, 189] -> 
             RGBColor[
              0.9817041639341297, 0.9826810632267816, 0.7260652556444314], 
             UndirectedEdge[3, 95] -> 
             RGBColor[
              0.9848190510817985, 0.9834976041896563, 0.6725231347641634], 
             UndirectedEdge[39, 294] -> 
             RGBColor[
              0.9498753075179714, 0.9365363411831458, 0.6771702570477409], 
             UndirectedEdge[5, 227] -> 
             RGBColor[
              0.8792223213879187, 0.9057723619612332, 0.9510237833417798], 
             UndirectedEdge[166, 169] -> 
             RGBColor[
              0.9835763548319123, 0.9661380467432823, 0.6166604984976202], 
             UndirectedEdge[27, 337] -> 
             RGBColor[
              0.9939750780734564, 0.9895216261491995, 0.5856026136829421], 
             UndirectedEdge[84, 174] -> 
             RGBColor[
              0.9856798871515468, 0.9883462795741202, 0.8869848593703533], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.9208091151309077, 0.93477809768909, 0.7320826756515341], 
             UndirectedEdge[138, 349] -> 
             RGBColor[
              0.966092497386937, 0.9722806467522171, 0.8510977492201212], 
             UndirectedEdge[26, 159] -> 
             RGBColor[
              0.9689177102191637, 0.9759032728812915, 0.9179650519141944], 
             UndirectedEdge[81, 287] -> 
             RGBColor[
              0.9933732092281277, 0.9882342895473157, 0.5200929041728524], 
             UndirectedEdge[311, 361] -> 
             RGBColor[
              0.9710694663857169, 0.9750697920571707, 0.7694631188202201], 
             UndirectedEdge[231, 393] -> 
             RGBColor[
              0.9484750496775018, 0.9610933569306196, 0.9721024804234132], 
             UndirectedEdge[201, 223] -> 
             RGBColor[
              0.957567050903592, 0.8573891971373828, 0.41672646526638185`], 
             UndirectedEdge[180, 267] -> 
             RGBColor[
              0.9847661118497995, 0.9860305825104703, 0.8054586503966745], 
             UndirectedEdge[217, 264] -> 
             RGBColor[
              0.9657984425001904, 0.9060935833627677, 0.5825210765456477], 
             UndirectedEdge[163, 174] -> 
             RGBColor[
              0.9785568087433529, 0.983219349593106, 0.9073472134429267], 
             UndirectedEdge[203, 280] -> 
             RGBColor[
              0.9606941669412989, 0.9120251298895692, 0.6084522467125584], 
             UndirectedEdge[40, 163] -> 
             RGBColor[
              0.9720779945816126, 0.9786963945938301, 0.9321488513347028], 
             UndirectedEdge[14, 62] -> 
             RGBColor[
              0.961381103477231, 0.8715634228949776, 0.4758468717674006], 
             UndirectedEdge[49, 133] -> 
             RGBColor[
              0.9748680840518573, 0.9403172117619101, 0.6073970583616624], 
             UndirectedEdge[276, 288] -> 
             RGBColor[
              0.9875000397462026, 0.9883281636195311, 0.8213513858398092], 
             UndirectedEdge[312, 366] -> 
             RGBColor[
              0.9949345164865261, 0.9915737679006518, 0.6900315639780321], 
             UndirectedEdge[23, 120] -> 
             RGBColor[
              0.9799095341872923, 0.9842363806468442, 0.9054232997320368], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.9937439937214299, 0.9890273600864263, 0.5604505080521496], 
             UndirectedEdge[73, 399] -> 
             RGBColor[
              0.9920398430072379, 0.9900417570739886, 0.7136536341256586], 
             UndirectedEdge[269, 272] -> 
             RGBColor[
              0.9838649720421087, 0.9872208848167285, 0.9002747750851716], 
             UndirectedEdge[20, 151] -> 
             RGBColor[
              0.7604017475859179, 0.808692264307495, 0.8166795034475328], 
             UndirectedEdge[239, 355] -> 
             RGBColor[
              0.9606352579857138, 0.8698012797379867, 0.40453978575154514`], 
             UndirectedEdge[274, 319] -> 
             RGBColor[
              0.9921570185927164, 0.9895135030671374, 0.6697910662627224], 
             UndirectedEdge[6, 352] -> 
             RGBColor[
              0.97967118111788, 0.9416169297325452, 0.5006382701937506], 
             UndirectedEdge[133, 342] -> 
             RGBColor[
              0.9892939359862604, 0.9883385720791806, 0.7178959400818028], 
             UndirectedEdge[290, 318] -> 
             RGBColor[
              0.9264381206863077, 0.7395075637826556, 0.5506649390882081], 
             UndirectedEdge[87, 298] -> 
             RGBColor[
              0.9915811007780501, 0.990551638800385, 0.7721085100369811], 
             UndirectedEdge[86, 263] -> 
             RGBColor[
              0.9632521142716408, 0.8832740625706513, 0.3348072618910665], 
             UndirectedEdge[109, 191] -> 
             RGBColor[
              0.9929792614786068, 0.9890743274808028, 0.5995251846098708], 
             UndirectedEdge[84, 238] -> 
             RGBColor[
              0.8201234046108147, 0.8592774220555097, 0.9296928031041036], 
             UndirectedEdge[21, 244] -> 
             RGBColor[
              0.9831380769876334, 0.9542911544344492, 0.4308108701344209], 
             UndirectedEdge[137, 175] -> 
             RGBColor[
              0.9743064636617333, 0.9788157981427685, 0.8592965245827464], 
             UndirectedEdge[363, 369] -> 
             RGBColor[
              0.9579029818320934, 0.9636155716322441, 0.7083562558590144], 
             UndirectedEdge[98, 290] -> 
             RGBColor[
              0.9313007006099581, 0.7414536694622542, 0.4653766836461153], 
             UndirectedEdge[175, 352] -> 
             RGBColor[
              0.9789662058104505, 0.9416661603593734, 0.5370909018865866], 
             UndirectedEdge[121, 319] -> 
             RGBColor[
              0.9888467297655852, 0.9896558503791681, 0.8345020817297635], 
             UndirectedEdge[249, 387] -> 
             RGBColor[
              0.9893106950294572, 0.9887826251340639, 0.7493924095024904], 
             UndirectedEdge[310, 389] -> 
             RGBColor[
              0.9809598971651929, 0.9513891386284183, 0.5655566234729514], 
             UndirectedEdge[228, 238] -> 
             RGBColor[
              0.8248412489536875, 0.8607641965205859, 0.8177652604565542], 
             UndirectedEdge[268, 324] -> 
             RGBColor[
              0.9669853666804649, 0.9735994759148643, 0.8826044034418257], 
             UndirectedEdge[144, 368] -> 
             RGBColor[
              0.9444772909091057, 0.8621845837359032, 0.6066178911359935], 
             UndirectedEdge[137, 278] -> 
             RGBColor[
              0.9474387010741951, 0.9603204498391384, 0.9738567482858065], 
             UndirectedEdge[127, 298] -> 
             RGBColor[
              0.9906051795882918, 0.9884642420562602, 0.6658855112192413], 
             UndirectedEdge[131, 228] -> 
             RGBColor[
              0.9948316404943393, 0.991666589356927, 0.7015759700054693], 
             UndirectedEdge[278, 314] -> 
             RGBColor[
              0.9662595535695063, 0.9729306345544589, 0.8781219111238693], 
             UndirectedEdge[182, 311] -> 
             RGBColor[
              0.9000254826035079, 0.6797408522597319, 0.5847434110442239], 
             UndirectedEdge[77, 94] -> 
             RGBColor[
              0.9899649341793446, 0.9877378916772064, 0.6429431363302534], 
             UndirectedEdge[144, 333] -> 
             RGBColor[
              0.9171886357464332, 0.7093875665255412, 0.2522262363702745], 
             UndirectedEdge[166, 197] -> 
             RGBColor[
              0.9871149523968834, 0.9889397159325616, 0.8632021144253191], 
             UndirectedEdge[106, 384] -> 
             RGBColor[
              0.9938466922305499, 0.989247021813022, 0.5716286069881342], 
             UndirectedEdge[28, 265] -> 
             RGBColor[
              0.9639442872674036, 0.9277062755319199, 0.6224729247598388], 
             UndirectedEdge[113, 266] -> 
             RGBColor[
              0.9714200054139873, 0.9256780541762315, 0.5738166658902604], 
             UndirectedEdge[164, 292] -> 
             RGBColor[
              0.9606597080706224, 0.8874063143135636, 0.5866371221751505], 
             UndirectedEdge[98, 248] -> 
             RGBColor[
              0.9765579793999672, 0.9801428711161781, 0.8379118697288128], 
             UndirectedEdge[91, 95] -> 
             RGBColor[
              0.9884380517277196, 0.9860498506462771, 0.6598231828773717], 
             UndirectedEdge[155, 342] -> 
             RGBColor[
              0.9760246109188385, 0.9785844088858222, 0.7467199766040564], 
             UndirectedEdge[47, 209] -> 
             RGBColor[
              0.9763069707107419, 0.9311130021981308, 0.41577201844251915`], 
             UndirectedEdge[2, 360] -> 
             RGBColor[
              0.971148375118495, 0.9357453993512252, 0.6159383905379301], 
             UndirectedEdge[75, 341] -> 
             RGBColor[
              0.9538711089359255, 0.8607305983506361, 0.5823434890999475], 
             UndirectedEdge[12, 390] -> 
             RGBColor[
              0.9939978382413177, 0.9895703078468489, 0.5880799174951675], 
             UndirectedEdge[19, 198] -> 
             RGBColor[
              0.9801169092243421, 0.983442934457836, 0.862614137301191], 
             UndirectedEdge[8, 56] -> 
             RGBColor[
              0.9898355698685448, 0.9889814541032811, 0.7393694541335848], 
             UndirectedEdge[70, 154] -> 
             RGBColor[
              0.991123372944146, 0.9882582082738424, 0.6267448756131184], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.983052830170434, 0.9534121032554745, 0.5388717868987938], 
             UndirectedEdge[177, 243] -> 
             RGBColor[
              0.9761116114233847, 0.9307483892831886, 0.5170949050781638], 
             UndirectedEdge[109, 340] -> 
             RGBColor[
              0.9846932509429975, 0.9612001985124818, 0.5608280211937096], 
             UndirectedEdge[28, 36] -> 
             RGBColor[
              0.9774335281845621, 0.934811131988638, 0.4288229389128605], 
             UndirectedEdge[203, 339] -> 
             RGBColor[
              0.9449626217506493, 0.819502165900073, 0.27457383744850833`], 
             UndirectedEdge[247, 369] -> 
             RGBColor[
              0.9555676175316221, 0.9655198316638381, 0.9245919016880659], 
             UndirectedEdge[223, 230] -> 
             RGBColor[
              0.9921524958183878, 0.9898349548888161, 0.6933681242165524], 
             UndirectedEdge[22, 173] -> 
             RGBColor[
              0.9935058687182023, 0.9885180347826538, 0.5345320709880148], 
             UndirectedEdge[69, 283] -> 
             RGBColor[
              0.9655406374679323, 0.9716018965024931, 0.8308327879241677], 
             UndirectedEdge[59, 274] -> 
             RGBColor[
              0.994085978066027, 0.9897588300195987, 0.5976733934788296], 
             UndirectedEdge[31, 164] -> 
             RGBColor[
              0.9620548553957741, 0.8879832435861648, 0.5635159204718476], 
             UndirectedEdge[116, 154] -> 
             RGBColor[
              0.9846703069611884, 0.9871766038698779, 0.8700316846880333], 
             UndirectedEdge[10, 170] -> 
             RGBColor[
              0.9817045318419617, 0.9833500318740855, 0.7791226624593492], 
             UndirectedEdge[301, 394] -> 
             RGBColor[
              0.9894235893506758, 0.9864573957805313, 0.6434902739753765], 
             UndirectedEdge[90, 351] -> 
             RGBColor[
              0.9258090368561205, 0.9422737382195576, 0.9427092695811741], 
             UndirectedEdge[4, 203] -> 
             RGBColor[
              0.9734714997374414, 0.9197660816388404, 0.5067370451704003], 
             UndirectedEdge[274, 351] -> 
             RGBColor[
              0.9892643245207764, 0.9883172997295435, 0.7177304930870552], 
             UndirectedEdge[238, 269] -> 
             RGBColor[
              0.8203664821904142, 0.859377940881483, 0.9256643785455293], 
             UndirectedEdge[66, 325] -> 
             RGBColor[
              0.9920351685702655, 0.9900030868552735, 0.7110606936471636], 
             UndirectedEdge[128, 171] -> 
             RGBColor[
              0.9856365509955622, 0.9631034482214264, 0.4078342554893639], 
             UndirectedEdge[198, 205] -> 
             RGBColor[
              0.970064583472497, 0.9120245838775257, 0.532210170514863], 
             UndirectedEdge[202, 349] -> 
             RGBColor[
              0.9653992850697559, 0.9721293822613052, 0.8724279760273431], 
             UndirectedEdge[295, 390] -> 
             RGBColor[
              0.9283520049439067, 0.9421402145756221, 0.842044673149828], 
             UndirectedEdge[250, 356] -> 
             RGBColor[
              0.9915263883549534, 0.9907639580699563, 0.7900932041698032], 
             UndirectedEdge[133, 393] -> 
             RGBColor[
              0.9724686722282645, 0.978845683627628, 0.9251250056066117], 
             UndirectedEdge[124, 293] -> 
             RGBColor[
              0.9791498506349905, 0.9807610374381832, 0.7291970220754439], 
             UndirectedEdge[45, 325] -> 
             RGBColor[
              0.9713912506171942, 0.9204714175783388, 0.5488731540657354], 
             UndirectedEdge[116, 304] -> 
             RGBColor[
              0.9795193779420046, 0.9632205789141175, 0.646840194927254], 
             UndirectedEdge[213, 296] -> 
             RGBColor[
              0.9352620905672591, 0.7622988106126283, 0.4851633459817096], 
             UndirectedEdge[248, 276] -> 
             RGBColor[
              0.9765757252931907, 0.980180827787398, 0.8398434006912294], 
             UndirectedEdge[209, 346] -> 
             RGBColor[
              0.9834335760768596, 0.9840948369696776, 0.7329751739323379], 
             UndirectedEdge[31, 382] -> 
             RGBColor[
              0.989866546971583, 0.9900775710019549, 0.8176010714240518], 
             UndirectedEdge[69, 373] -> 
             RGBColor[
              0.9655421875275167, 0.9716052119232093, 0.8310015023440818], 
             UndirectedEdge[166, 239] -> 
             RGBColor[
              0.9575428618636188, 0.8699444546574993, 0.559150286976001], 
             UndirectedEdge[235, 317] -> 
             RGBColor[
              0.9818822159974203, 0.9490045559904594, 0.5152406944499953], 
             UndirectedEdge[43, 59] -> 
             RGBColor[
              0.9635646247299425, 0.8804950295319203, 0.4613501315802737], 
             UndirectedEdge[94, 207] -> 
             RGBColor[
              0.9929210520858999, 0.9872671711401904, 0.47087838963178363`], 
             UndirectedEdge[209, 270] -> 
             RGBColor[
              0.9841376306191879, 0.9846199196945626, 0.7317833932390096], 
             UndirectedEdge[23, 341] -> 
             RGBColor[
              0.9485597205720391, 0.8568104930804644, 0.5931756982712233], 
             UndirectedEdge[264, 312] -> 
             RGBColor[
              0.9902138413854958, 0.9898951475438383, 0.7881459381390564], 
             UndirectedEdge[48, 118] -> 
             RGBColor[
              0.973507120908919, 0.9723047894157149, 0.6858199753600849], 
             UndirectedEdge[106, 310] -> 
             RGBColor[
              0.9826807942648117, 0.9517652898851456, 0.5126507656300945], 
             UndirectedEdge[267, 282] -> 
             RGBColor[
              0.9506106534784754, 0.8289273686290108, 0.4633230628026921], 
             UndirectedEdge[43, 274] -> 
             RGBColor[
              0.963008867019779, 0.8793063199856039, 0.40085933456797046`], 
             UndirectedEdge[46, 362] -> 
             RGBColor[
              0.9727238215993192, 0.9755104639920358, 0.70373018466584], 
             UndirectedEdge[38, 117] -> 
             RGBColor[
              0.9908354915874791, 0.9881501548558225, 0.6323148840284245], 
             UndirectedEdge[252, 300] -> 
             RGBColor[
              0.987072138670298, 0.9889220113563559, 0.8639116486732127], 
             UndirectedEdge[7, 67] -> 
             RGBColor[
              0.9306836326214347, 0.7552784137385793, 0.283876711086184], 
             UndirectedEdge[150, 192] -> 
             RGBColor[
              0.9804692008665017, 0.9830912719975443, 0.8337841009620729], 
             UndirectedEdge[239, 272] -> 
             RGBColor[
              0.9547861722364995, 0.8684296119345452, 0.5880478436831202], 
             UndirectedEdge[22, 209] -> 
             RGBColor[
              0.9936107620511019, 0.988742391015383, 0.5459490629475117], 
             UndirectedEdge[167, 246] -> 
             RGBColor[
              0.9890865470363484, 0.9890145521506866, 0.7792448240885179], 
             UndirectedEdge[131, 140] -> 
             RGBColor[
              0.9919029299608099, 0.990919667700656, 0.7838529353023218], 
             UndirectedEdge[67, 385] -> 
             RGBColor[
              0.9519766013405789, 0.9297831449874765, 0.6649709428356618], 
             UndirectedEdge[60, 101] -> 
             RGBColor[
              0.9303881553625484, 0.7385380783764343, 0.40939052569874806`], 
             UndirectedEdge[113, 249] -> 
             RGBColor[
              0.9905467071617772, 0.9892937479148411, 0.7289084897730862], 
             UndirectedEdge[52, 393] -> 
             RGBColor[
              0.9708465602569492, 0.9777779928907848, 0.9342333484368479], 
             UndirectedEdge[99, 367] -> 
             RGBColor[
              0.9690656863019182, 0.9444058675219673, 0.6411456639013855], 
             UndirectedEdge[5, 43] -> 
             RGBColor[
              0.9549168116813973, 0.8763339328528574, 0.5938836896442714], 
             UndirectedEdge[26, 105] -> 
             RGBColor[
              0.9728281434620887, 0.9775203375207915, 0.8531590532020966], 
             UndirectedEdge[128, 306] -> 
             RGBColor[
              0.9837166908881597, 0.9837195721734285, 0.6859667012554844], 
             UndirectedEdge[226, 281] -> 
             RGBColor[
              0.9496457860986429, 0.9604222975647622, 0.907716074427419], 
             UndirectedEdge[63, 345] -> 
             RGBColor[
              0.9630542424030863, 0.9706546902378728, 0.8890572621180322], 
             UndirectedEdge[4, 280] -> 
             RGBColor[
              0.982179092471684, 0.984441414732086, 0.8349638174146707], 
             UndirectedEdge[7, 223] -> 
             RGBColor[
              0.9428441736228322, 0.7954335010980567, 0.40469467564229966`], 
             UndirectedEdge[155, 361] -> 
             RGBColor[
              0.9761544808370604, 0.9788621875090358, 0.7608555157382706], 
             UndirectedEdge[252, 398] -> 
             RGBColor[
              0.9688276188282117, 0.9760316725290319, 0.9268764577095235], 
             UndirectedEdge[6, 252] -> 
             RGBColor[
              0.9902635985247357, 0.9899010059894535, 0.7862515332207161], 
             UndirectedEdge[260, 307] -> 
             RGBColor[
              0.8573162591850679, 0.8854934184483718, 0.7697010466051234], 
             UndirectedEdge[21, 357] -> 
             RGBColor[
              0.9928342980160094, 0.9895947975106787, 0.6441177310447896], 
             UndirectedEdge[233, 366] -> 
             RGBColor[
              0.9934739808972299, 0.991295837523754, 0.7379359845149416], 
             UndirectedEdge[37, 41] -> 
             RGBColor[
              0.9897984344323824, 0.976377308501761, 0.4890652034861614], 
             UndirectedEdge[173, 176] -> 
             RGBColor[
              0.9941486413882477, 0.989892860529595, 0.6044939093893531], 
             UndirectedEdge[60, 136] -> 
             RGBColor[
              0.9202820566726377, 0.7336079411814099, 0.5696678854612296], 
             UndirectedEdge[74, 285] -> 
             RGBColor[
              0.9289206963790165, 0.7328606127869499, 0.3638301472185904], 
             UndirectedEdge[234, 395] -> 
             RGBColor[
              0.9127548814399802, 0.9332699826617473, 0.9915405694892889], 
             UndirectedEdge[17, 164] -> 
             RGBColor[
              0.9599698383957516, 0.870948058290955, 0.32858770275493504`], 
             UndirectedEdge[20, 383] -> 
             RGBColor[
              0.7251884559465723, 0.682003620345521, 0.6069248175235906], 
             UndirectedEdge[19, 219] -> 
             RGBColor[
              0.9809081796614383, 0.9820531206264805, 0.7246911836931358], 
             UndirectedEdge[91, 279] -> 
             RGBColor[
              0.979279344309294, 0.9551553799571613, 0.6242433340335588], 
             UndirectedEdge[76, 207] -> 
             RGBColor[
              0.9835179435030863, 0.9555604691615999, 0.43331243454405893`], 
             UndirectedEdge[238, 339] -> 
             RGBColor[
              0.7964386125955952, 0.7610083898393422, 0.6175820064989515], 
             UndirectedEdge[142, 379] -> 
             RGBColor[
              0.9467184535858907, 0.8130695008220064, 0.4059578635607435], 
             UndirectedEdge[205, 219] -> 
             RGBColor[
              0.9708558539095932, 0.9106347700461702, 0.39428721690680785`], 
             UndirectedEdge[7, 68] -> 
             RGBColor[
              0.9404354935376905, 0.7956253646900942, 0.5309615970873062], 
             UndirectedEdge[188, 273] -> 
             RGBColor[
              0.9664208290133234, 0.903829285319814, 0.5598669361943324], 
             UndirectedEdge[16, 69] -> 
             RGBColor[
              0.892482362798086, 0.9170887023687397, 0.9890340538014508], 
             UndirectedEdge[118, 323] -> 
             RGBColor[
              0.9853358207079979, 0.962196421314351, 0.3975328618588119], 
             UndirectedEdge[211, 263] -> 
             RGBColor[
              0.9652282261549279, 0.896825621928333, 0.5477729072637741], 
             UndirectedEdge[191, 340] -> 
             RGBColor[
              0.9843409917143935, 0.9587640993058844, 0.4001757162434622], 
             UndirectedEdge[33, 182] -> 
             RGBColor[
              0.9217387869885367, 0.6911870639911499, 0.3098313389124079], 
             UndirectedEdge[99, 300] -> 
             RGBColor[
              0.9797456093362289, 0.9516545424359426, 0.5909857440978108], 
             UndirectedEdge[11, 91] -> 
             RGBColor[
              0.9896079738225744, 0.9889857549507148, 0.7502952346487106], 
             UndirectedEdge[78, 233] -> 
             RGBColor[
              0.9751214017919297, 0.9796717954120933, 0.8690327447099923], 
             UndirectedEdge[27, 172] -> 
             RGBColor[
              0.9941597167845764, 0.9899165496824476, 0.6056993979302985], 
             UndirectedEdge[313, 396] -> 
             RGBColor[
              0.9922385400190231, 0.98508426226477, 0.45807705619797284`], 
             UndirectedEdge[74, 172] -> 
             RGBColor[
              0.9939506747249738, 0.9894694298543518, 0.5829464598006033], 
             UndirectedEdge[217, 366] -> 
             RGBColor[
              0.9705191176012207, 0.907772203719581, 0.48440670238462336`], 
             UndirectedEdge[277, 302] -> 
             RGBColor[
              0.9687225410524383, 0.9061559280525844, 0.33299340755157797`], 
             UndirectedEdge[203, 232] -> 
             RGBColor[
              0.9734091137779959, 0.9193517754233637, 0.47953051035863853`], 
             UndirectedEdge[27, 285] -> 
             RGBColor[
              0.9291297384386191, 0.7333077326150457, 0.38658308534828556`], 
             UndirectedEdge[193, 334] -> 
             RGBColor[
              0.9501834298023857, 0.919474379814051, 0.6500777454716138], 
             UndirectedEdge[39, 381] -> 
             RGBColor[
              0.9852760775142246, 0.9608094059925664, 0.4981060708438544], 
             UndirectedEdge[270, 390] -> 
             RGBColor[
              0.984879365780993, 0.9862064162047351, 0.8125166881426864], 
             UndirectedEdge[35, 42] -> 
             RGBColor[
              0.9574177879020291, 0.9592516435389654, 0.7024592197374568], 
             UndirectedEdge[41, 245] -> 
             RGBColor[
              0.956451029728639, 0.9638174512271775, 0.7856975317278699], 
             UndirectedEdge[45, 276] -> 
             RGBColor[
              0.9740554007405106, 0.921539034326754, 0.5022441961071527], 
             UndirectedEdge[17, 241] -> 
             RGBColor[
              0.9877973309840293, 0.9730489198314686, 0.5824109900388241], 
             UndirectedEdge[69, 347] -> 
             RGBColor[
              0.9655407000497649, 0.9720682175179514, 0.8647264847258069], 
             UndirectedEdge[16, 295] -> 
             RGBColor[
              0.8551632818334965, 0.8873480044178633, 0.9860474313061945], 
             UndirectedEdge[190, 351] -> 
             RGBColor[
              0.9899271633262547, 0.9897350449111781, 0.7898764064964247], 
             UndirectedEdge[112, 141] -> 
             RGBColor[
              0.9903036077082098, 0.9900045224254981, 0.7919103954736494], 
             UndirectedEdge[135, 400] -> 
             RGBColor[
              0.97615072577003, 0.9434365639204545, 0.6040350698344683], 
             UndirectedEdge[295, 310] -> 
             RGBColor[
              0.9160850496877435, 0.9023034324374952, 0.6632235406669683], 
             UndirectedEdge[185, 249] -> 
             RGBColor[
              0.9338264222882446, 0.7543150114548008, 0.4048591438095832], 
             UndirectedEdge[93, 98] -> 
             RGBColor[
              0.9940757249592372, 0.9897368996609235, 0.5965574060796003], 
             UndirectedEdge[221, 268] -> 
             RGBColor[
              0.992826149084223, 0.9898869389971332, 0.6657333303529778], 
             UndirectedEdge[265, 291] -> 
             RGBColor[
              0.954357549430789, 0.8912416484369863, 0.6067201475314308], 
             UndirectedEdge[128, 133] -> 
             RGBColor[
              0.9888621097472654, 0.9874149394183003, 0.6708943188898275], 
             UndirectedEdge[57, 333] -> 
             RGBColor[
              0.9310686292226973, 0.8156664941847112, 0.6009827799968762], 
             UndirectedEdge[28, 378] -> 
             RGBColor[
              0.960433065390231, 0.8781935801825147, 0.30079035994002945`], 
             UndirectedEdge[92, 386] -> 
             RGBColor[
              0.9759771869279903, 0.9362472336845669, 0.5577146964888628], 
             UndirectedEdge[35, 248] -> 
             RGBColor[
              0.9735023350656609, 0.9715042913225111, 0.6841363474843005], 
             UndirectedEdge[56, 175] -> 
             RGBColor[
              0.9937516594232972, 0.9906008577730822, 0.6744697156964393], 
             UndirectedEdge[3, 21] -> 
             RGBColor[
              0.9855687015433645, 0.9855345899664694, 0.7172512128678836], 
             UndirectedEdge[98, 204] -> 
             RGBColor[
              0.9813228546203767, 0.9836965072537924, 0.8298461788591505], 
             UndirectedEdge[243, 367] -> 
             RGBColor[
              0.9807460128516707, 0.9834737434785503, 0.8419178813469008], 
             UndirectedEdge[48, 209] -> 
             RGBColor[
              0.9754154074238246, 0.9781148999167902, 0.7465478419886147], 
             UndirectedEdge[116, 291] -> 
             RGBColor[
              0.9608369201033125, 0.8960739524755584, 0.5957522630733696], 
             UndirectedEdge[214, 340] -> 
             RGBColor[
              0.942938231092973, 0.9309104695596075, 0.6763696659823151], 
             UndirectedEdge[138, 159] -> 
             RGBColor[
              0.990971263755227, 0.9903990031649317, 0.7894511506681212], 
             UndirectedEdge[22, 48] -> 
             RGBColor[
              0.975507258024676, 0.9783113590644914, 0.7565452130550991], 
             UndirectedEdge[13, 297] -> 
             RGBColor[
              0.9840616811442574, 0.957429027586119, 0.5470337739823043], 
             UndirectedEdge[192, 347] -> 
             RGBColor[
              0.9802139499586751, 0.9830115032747749, 0.8398885000265144], 
             UndirectedEdge[4, 322] -> 
             RGBColor[
              0.9908508115531985, 0.9904845897008989, 0.8012892601115993], 
             UndirectedEdge[111, 304] -> 
             RGBColor[
              0.9721773216219061, 0.957744885332102, 0.6592683811622075], 
             UndirectedEdge[133, 361] -> 
             RGBColor[
              0.9894238059044822, 0.9886163507023942, 0.7320314792160169], 
             UndirectedEdge[4, 186] -> 
             RGBColor[
              0.9890177780252634, 0.9733832213908438, 0.5610073317558387], 
             UndirectedEdge[73, 240] -> 
             RGBColor[
              0.994616898953143, 0.9908944161128038, 0.6554608555774816], 
             UndirectedEdge[82, 335] -> 
             RGBColor[
              0.9943445829210225, 0.9903119596554721, 0.6258209360209033], 
             UndirectedEdge[184, 372] -> 
             RGBColor[
              0.9619091891005482, 0.8747395285462091, 0.4122198136482791], 
             UndirectedEdge[85, 340] -> 
             RGBColor[
              0.9846794719971803, 0.9594880744051594, 0.4370172061666434], 
             UndirectedEdge[344, 388] -> 
             RGBColor[
              0.9407700318110754, 0.7876126365207363, 0.3311337932241498], 
             UndirectedEdge[57, 228] -> 
             RGBColor[
              0.9755187620900482, 0.9790452770139582, 0.8140782263289845], 
             UndirectedEdge[36, 80] -> 
             RGBColor[
              0.9939148005535154, 0.9893926986290377, 0.5790417776270911], 
             UndirectedEdge[88, 365] -> 
             RGBColor[
              0.9874466179830375, 0.9864379671198911, 0.6746240888626166], 
             UndirectedEdge[209, 241] -> 
             RGBColor[
              0.9929596532765657, 0.9898356570944276, 0.6557801711903556], 
             UndirectedEdge[49, 62] -> 
             RGBColor[
              0.9798158003582575, 0.9420704411320184, 0.5041186906177785], 
             UndirectedEdge[161, 250] -> 
             RGBColor[
              0.9935670003689642, 0.9905455457405308, 0.6790600510638507], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.9798493201851628, 0.9421421366523943, 0.5077671169160141], 
             UndirectedEdge[324, 346] -> 
             RGBColor[
              0.9576545132581888, 0.9679393858391039, 0.956564042968847], 
             UndirectedEdge[142, 258] -> 
             RGBColor[
              0.9296779601443776, 0.7564306792732252, 0.268096186179219], 
             UndirectedEdge[44, 46] -> 
             RGBColor[
              0.9599710046664961, 0.9696670213385128, 0.9526428272523044], 
             UndirectedEdge[85, 191] -> 
             RGBColor[
              0.9929654825327896, 0.9873622033734804, 0.47571436958280466`], 
             UndirectedEdge[112, 172] -> 
             RGBColor[
              0.9947628591707821, 0.9912066102594922, 0.6713477245054542], 
             UndirectedEdge[133, 298] -> 
             RGBColor[
              0.9865998646447447, 0.9887267139099007, 0.8717384514826294], 
             UndirectedEdge[26, 215] -> 
             RGBColor[
              0.965041479763497, 0.973448573363715, 0.944059835504786], 
             UndirectedEdge[127, 129] -> 
             RGBColor[
              0.9937228640507652, 0.9889821658574119, 0.5581506737975089], 
             UndirectedEdge[172, 225] -> 
             RGBColor[
              0.9454928151346311, 0.8067003021861008, 0.44108391228553845`], 
             UndirectedEdge[38, 376] -> 
             RGBColor[
              0.9915381131518742, 0.9896529913361265, 0.7087909052351768], 
             UndirectedEdge[158, 346] -> 
             RGBColor[
              0.9788859943658523, 0.9837352879185007, 0.9189004957055518], 
             UndirectedEdge[340, 370] -> 
             RGBColor[
              0.9759889672997, 0.9306672900226169, 0.36122210137273436`], 
             UndirectedEdge[44, 266] -> 
             RGBColor[
              0.961475048534197, 0.9187352797736931, 0.6118846547720228], 
             UndirectedEdge[183, 238] -> 
             RGBColor[
              0.8243291155582315, 0.8610165916141079, 0.8599932886743702], 
             UndirectedEdge[21, 264] -> 
             RGBColor[
              0.9894117098790828, 0.9881794693595565, 0.700838873847833], 
             UndirectedEdge[13, 140] -> 
             RGBColor[
              0.9916633785791416, 0.9908206070481465, 0.7878229216356682], 
             UndirectedEdge[210, 266] -> 
             RGBColor[
              0.935393974161198, 0.7815656667706874, 0.26687467899300965`], 
             UndirectedEdge[51, 395] -> 
             RGBColor[
              0.9645099618468227, 0.9712566676381411, 0.8649322236541616], 
             UndirectedEdge[358, 372] -> 
             RGBColor[
              0.9933068008515793, 0.9880922487447958, 0.5128647622105629], 
             UndirectedEdge[174, 309] -> 
             RGBColor[
              0.9859412189811367, 0.9761832285095273, 0.640141071250564], 
             UndirectedEdge[65, 363] -> 
             RGBColor[
              0.9880452019492336, 0.9713358004340074, 0.40805829635729746`], 
             UndirectedEdge[236, 267] -> 
             RGBColor[
              0.979103514242569, 0.9818074264866505, 0.8150439511037273], 
             UndirectedEdge[227, 352] -> 
             RGBColor[
              0.8727769446694018, 0.8603405447096183, 0.647616230208975], 
             UndirectedEdge[2, 370] -> 
             RGBColor[
              0.9775036238371405, 0.9571831455625772, 0.6406273317218502], 
             UndirectedEdge[17, 354] -> 
             RGBColor[
              0.9694105942219357, 0.9083775091963897, 0.3361839564957033], 
             UndirectedEdge[133, 306] -> 
             RGBColor[
              0.9799017686472311, 0.984389274766315, 0.912542712231335], 
             UndirectedEdge[105, 261] -> 
             RGBColor[
              0.9942193829649344, 0.9905994450576001, 0.6525563567687205], 
             UndirectedEdge[120, 206] -> 
             RGBColor[
              0.9899013824968748, 0.988813840896507, 0.7241167991514686], 
             UndirectedEdge[361, 393] -> 
             RGBColor[
              0.9768452906264099, 0.9793773923188355, 0.7596861549569505], 
             UndirectedEdge[270, 295] -> 
             RGBColor[
              0.9182289889510391, 0.9366277058923302, 0.9571430796041336], 
             UndirectedEdge[9, 283] -> 
             RGBColor[
              0.917109096110883, 0.933000424274371, 0.8267862490364681], 
             UndirectedEdge[43, 122] -> 
             RGBColor[
              0.9627458294908182, 0.8787437093083308, 0.3722293228200649], 
             UndirectedEdge[127, 336] -> 
             RGBColor[
              0.9761147348771482, 0.978315282000849, 0.7198801857700842], 
             UndirectedEdge[4, 123] -> 
             RGBColor[
              0.954047396499135, 0.8427559849976525, 0.49110795576255617`], 
             UndirectedEdge[45, 279] -> 
             RGBColor[
              0.963175695307025, 0.8865299636622036, 0.3162110824240158], 
             UndirectedEdge[135, 255] -> 
             RGBColor[
              0.9401298045018647, 0.8008917240445406, 0.5587721508540265], 
             UndirectedEdge[152, 180] -> 
             RGBColor[
              0.9615273375004567, 0.9068639470547079, 0.6025555006214205], 
             UndirectedEdge[48, 68] -> 
             RGBColor[
              0.973199774355475, 0.9787196715576989, 0.8938267398633593], 
             UndirectedEdge[362, 363] -> 
             RGBColor[
              0.9924227017821572, 0.9860041594806893, 0.43339520933800846`], 
             UndirectedEdge[18, 257] -> 
             RGBColor[
              0.9849488442980188, 0.9598912229655707, 0.4810483724099033], 
             UndirectedEdge[72, 109] -> 
             RGBColor[
              0.9701058869884744, 0.9757071935341745, 0.8674897721561783], 
             UndirectedEdge[181, 211] -> 
             RGBColor[
              0.9888799911721247, 0.9896696048255513, 0.8339508541456453], 
             UndirectedEdge[82, 259] -> 
             RGBColor[
              0.9932013775078093, 0.9906348630236705, 0.7026020320425685], 
             UndirectedEdge[282, 367] -> 
             RGBColor[
              0.9367471695660502, 0.8207165941935839, 0.592002852884699], 
             UndirectedEdge[44, 363] -> 
             RGBColor[
              0.979669884849334, 0.9801607168271663, 0.6823078519244729], 
             UndirectedEdge[139, 290] -> 
             RGBColor[
              0.8287098057922944, 0.6633218568317504, 0.595384479973972], 
             UndirectedEdge[255, 351] -> 
             RGBColor[
              0.939697513540228, 0.8007129606225329, 0.565936330821492], 
             UndirectedEdge[290, 345] -> 
             RGBColor[
              0.900820224365243, 0.7205786015237784, 0.6023266940927812], 
             UndirectedEdge[145, 200] -> 
             RGBColor[
              0.9491429579066629, 0.8812766705293982, 0.6108330628255093], 
             UndirectedEdge[44, 316] -> 
             RGBColor[
              0.9534452404770077, 0.8868997666018511, 0.6054236827253885], 
             UndirectedEdge[172, 240] -> 
             RGBColor[
              0.9947864857121043, 0.9912571450423705, 0.673919327722257], 
             UndirectedEdge[89, 299] -> 
             RGBColor[
              0.9866101601222741, 0.9868937794438644, 0.7617049073824793], 
             UndirectedEdge[119, 196] -> 
             RGBColor[
              0.9899248721962235, 0.9892611139245486, 0.7555334657618777], 
             UndirectedEdge[149, 369] -> 
             RGBColor[
              0.9571672076216915, 0.966181303273672, 0.8980825542891626], 
             UndirectedEdge[32, 385] -> 
             RGBColor[
              0.959528520784094, 0.9692203636040961, 0.9485145523061262], 
             UndirectedEdge[149, 253] -> 
             RGBColor[
              0.9869780088551316, 0.9727835783598613, 0.5964970950074764], 
             UndirectedEdge[317, 336] -> 
             RGBColor[
              0.9639672504276573, 0.9376813801084587, 0.6435729582768177], 
             UndirectedEdge[138, 215] -> 
             RGBColor[
              0.98709503329956, 0.9879443036473551, 0.8155459342587128], 
             UndirectedEdge[157, 181] -> 
             RGBColor[
              0.9788214319584374, 0.948854052773549, 0.5895864271364393], 
             UndirectedEdge[299, 342] -> 
             RGBColor[
              0.9938383552285336, 0.9892291898087096, 0.5707211757686768], 
             UndirectedEdge[108, 198] -> 
             RGBColor[
              0.9862958857274418, 0.969007154355608, 0.5836488334828129], 
             UndirectedEdge[152, 367] -> 
             RGBColor[
              0.9577689497792794, 0.9040609476460489, 0.6089174706888645], 
             UndirectedEdge[17, 118] -> 
             RGBColor[
              0.9864483026428084, 0.9659490841036474, 0.40185464410096583`], 
             UndirectedEdge[44, 68] -> 
             RGBColor[
              0.9781218810167648, 0.9823905706464788, 0.885494897176814], 
             UndirectedEdge[158, 323] -> 
             RGBColor[
              0.9826965255118962, 0.9676469827642498, 0.6441860502605556], 
             UndirectedEdge[343, 359] -> 
             RGBColor[
              0.8913331266201854, 0.5539018093610546, 0.553880120383467], 
             UndirectedEdge[354, 388] -> 
             RGBColor[
              0.9741009272950355, 0.9241547092444042, 0.35818002389138215`], 
             UndirectedEdge[382, 389] -> 
             RGBColor[
              0.9919100580733977, 0.9909226153583951, 0.7837348040297778], 
             UndirectedEdge[178, 319] -> 
             RGBColor[
              0.9917101499028111, 0.9885576961247851, 0.6211521671204108], 
             UndirectedEdge[15, 386] -> 
             RGBColor[
              0.9920774952985739, 0.9909918549539459, 0.7809599358949589], 
             UndirectedEdge[27, 104] -> 
             RGBColor[
              0.9932073967308883, 0.9901646681100535, 0.6681431398057214], 
             UndirectedEdge[236, 398] -> 
             RGBColor[
              0.9576754335223682, 0.967954988137875, 0.9565286304184704], 
             UndirectedEdge[151, 304] -> 
             RGBColor[
              0.9870969870898374, 0.9667074674389953, 0.5259529694730485], 
             UndirectedEdge[21, 233] -> 
             RGBColor[
              0.9926413988711922, 0.9895150287570149, 0.6473145690813977], 
             UndirectedEdge[120, 321] -> 
             RGBColor[
              0.9407104243911952, 0.8032406589587079, 0.5580439740860208], 
             UndirectedEdge[170, 299] -> 
             RGBColor[
              0.9942184765876982, 0.9900422309597979, 0.6120950398766473], 
             UndirectedEdge[97, 109] -> 
             RGBColor[
              0.9922194189127331, 0.9910505440156713, 0.7786078943218013], 
             UndirectedEdge[251, 381] -> 
             RGBColor[
              0.8940724210125729, 0.9146308217032921, 0.8072615454618374], 
             UndirectedEdge[134, 392] -> 
             RGBColor[
              0.5870587017029814, 0.6487575420735953, 0.8256921380038482], 
             UndirectedEdge[132, 220] -> 
             RGBColor[
              0.9930455808513013, 0.9875335255775946, 0.48443257724327876`], 
             UndirectedEdge[102, 167] -> 
             RGBColor[
              0.9822983204080069, 0.9839519038459705, 0.7907355211172444], 
             UndirectedEdge[270, 373] -> 
             RGBColor[
              0.9847504674000136, 0.9859307156014457, 0.7984868948416839], 
             UndirectedEdge[122, 351] -> 
             RGBColor[
              0.9890012869918159, 0.9877546890522704, 0.6891004813391496], 
             UndirectedEdge[96, 173] -> 
             RGBColor[
              0.9938485177462753, 0.9892509264065709, 0.5718273031090746], 
             UndirectedEdge[253, 266] -> 
             RGBColor[
              0.9695189467503966, 0.9087924096649601, 0.33634759942487813`], 
             UndirectedEdge[217, 230] -> 
             RGBColor[
              0.9682366271746159, 0.9071018353841306, 0.5421140466707477], 
             UndirectedEdge[118, 158] -> 
             RGBColor[
              0.9870630432243377, 0.9823762723154297, 0.6611491470257111], 
             UndirectedEdge[208, 230] -> 
             RGBColor[
              0.9445143814855754, 0.8114384689209708, 0.5229431545223543], 
             UndirectedEdge[86, 179] -> 
             RGBColor[
              0.9877160326189902, 0.9764538917412762, 0.6075257263068657], 
             UndirectedEdge[185, 284] -> 
             RGBColor[
              0.9222748630940428, 0.7163020340892862, 0.2789350121764801], 
             UndirectedEdge[279, 399] -> 
             RGBColor[
              0.9816820246091144, 0.9561489500072042, 0.5844247035282397], 
             UndirectedEdge[167, 309] -> 
             RGBColor[
              0.9901800742426817, 0.9772867008026278, 0.52268750594333], 
             UndirectedEdge[174, 183] -> 
             RGBColor[
              0.9898855980989636, 0.9900854491327185, 0.8172853449406199], 
             UndirectedEdge[149, 247] -> 
             RGBColor[
              0.9891125144678163, 0.989765759183896, 0.8300973413850338], 
             UndirectedEdge[297, 339] -> 
             RGBColor[
              0.9558108976839208, 0.8572718405667676, 0.31059327202982007`], 
             UndirectedEdge[28, 282] -> 
             RGBColor[
              0.9337664757796903, 0.7735695841834582, 0.2736042185283608], 
             UndirectedEdge[35, 125] -> 
             RGBColor[
              0.9876274044396134, 0.9817119396052586, 0.6455912791221394], 
             UndirectedEdge[119, 231] -> 
             RGBColor[
              0.961301028468891, 0.9704346478364569, 0.9403466938517753], 
             UndirectedEdge[257, 309] -> 
             RGBColor[
              0.9899769778958316, 0.9768522982529058, 0.5005817219540505], 
             UndirectedEdge[153, 161] -> 
             RGBColor[
              0.9816195675395895, 0.9487054586788345, 0.464316519068814], 
             UndirectedEdge[315, 369] -> 
             RGBColor[
              0.9280689999012675, 0.8560448007279191, 0.6285679289383199], 
             UndirectedEdge[145, 207] -> 
             RGBColor[
              0.9657767613112802, 0.8904725980520538, 0.3916953508558833], 
             UndirectedEdge[75, 215] -> 
             RGBColor[
              0.9817522593206467, 0.9858703259210324, 0.9139314304807022], 
             UndirectedEdge[155, 199] -> 
             RGBColor[
              0.9196134913885036, 0.7599142298866653, 0.5886496443545715], 
             UndirectedEdge[28, 151] -> 
             RGBColor[
              0.9780012670877598, 0.9360254680953698, 0.49061781484757205`], 
             UndirectedEdge[141, 279] -> 
             RGBColor[
              0.9795512408886047, 0.9552678161801296, 0.6197373040685882], 
             UndirectedEdge[347, 380] -> 
             RGBColor[
              0.9949240171192665, 0.9921689648790764, 0.7337857027637524], 
             UndirectedEdge[107, 346] -> 
             RGBColor[
              0.9551190722276339, 0.8835701355900549, 0.5990384975196184], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.9777728043497317, 0.9358120344807606, 0.4423479014647508], 
             UndirectedEdge[171, 299] -> 
             RGBColor[
              0.9863660479969069, 0.9646637685438417, 0.48723550215208844`], 
             UndirectedEdge[283, 294] -> 
             RGBColor[
              0.9591818977891151, 0.966548134296815, 0.8307991904193713], 
             UndirectedEdge[83, 244] -> 
             RGBColor[
              0.9742383794843806, 0.9247621462639788, 0.3544213982809883], 
             UndirectedEdge[112, 179] -> 
             RGBColor[
              0.9924510093238665, 0.9908925281792764, 0.7563223934049794], 
             UndirectedEdge[42, 93] -> 
             RGBColor[
              0.9593421509209561, 0.9654705269891223, 0.7331017522619306], 
             UndirectedEdge[94, 254] -> 
             RGBColor[
              0.9874149733542352, 0.986370282458646, 0.6711797663055115], 
             UndirectedEdge[84, 222] -> 
             RGBColor[
              0.9628245707753947, 0.8946855660064126, 0.5819994379038335], 
             UndirectedEdge[132, 366] -> 
             RGBColor[
              0.994205325230388, 0.9900141015363174, 0.6106635957941926], 
             UndirectedEdge[52, 133] -> 
             RGBColor[
              0.9834250755350213, 0.9870169512743434, 0.9065786726959144], 
             UndirectedEdge[255, 400] -> 
             RGBColor[
              0.9304175196629318, 0.7559062821351752, 0.2788571909158417], 
             UndirectedEdge[276, 318] -> 
             RGBColor[
              0.9903621722441897, 0.990248446996055, 0.8069101822041485], 
             UndirectedEdge[235, 313] -> 
             RGBColor[
              0.9931664831698087, 0.9870690388348561, 0.5590779415596754], 
             UndirectedEdge[218, 229] -> 
             RGBColor[
              0.9782583850870088, 0.9660538752594652, 0.6569856685728703], 
             UndirectedEdge[202, 260] -> 
             RGBColor[
              0.8572853609011042, 0.8867587767042913, 0.8631200685996482], 
             UndirectedEdge[129, 216] -> 
             RGBColor[
              0.9937837100648647, 0.9891123093290951, 0.5647733869341689], 
             UndirectedEdge[307, 312] -> 
             RGBColor[
              0.9943522451347645, 0.990328348355898, 0.6266549207010337], 
             UndirectedEdge[215, 349] -> 
             RGBColor[
              0.9580624783174345, 0.9682436455123078, 0.9558734645378727], 
             UndirectedEdge[48, 61] -> 
             RGBColor[
              0.9488263958117535, 0.8844312002712831, 0.6139995371324181], 
             UndirectedEdge[198, 284] -> 
             RGBColor[
              0.9813267010664005, 0.9522449276738723, 0.5643444894264508], 
             UndirectedEdge[37, 256] -> 
             RGBColor[
              0.9895331981758166, 0.9758099949684661, 0.46019587380742055`], 
             UndirectedEdge[260, 366] -> 
             RGBColor[
              0.8578985305368295, 0.8867388379931255, 0.8330776898821218], 
             UndirectedEdge[35, 263] -> 
             RGBColor[
              0.9650410393628679, 0.8893085269629466, 0.34175689806032683`], 
             UndirectedEdge[124, 185] -> 
             RGBColor[
              0.9192929056643371, 0.7461783626796373, 0.580204474136297], 
             UndirectedEdge[17, 48] -> 
             RGBColor[
              0.970253085131288, 0.9613281626538313, 0.6731786608370831], 
             UndirectedEdge[98, 139] -> 
             RGBColor[
              0.8926161114569529, 0.9140247833739297, 0.8496981921274956], 
             UndirectedEdge[98, 125] -> 
             RGBColor[
              0.9906830487739198, 0.9903505193989256, 0.7993668013666517], 
             UndirectedEdge[195, 397] -> 
             RGBColor[
              0.9617686714659572, 0.9708290378662644, 0.9415981716415536], 
             UndirectedEdge[152, 198] -> 
             RGBColor[
              0.9700513980097858, 0.9119723079116702, 0.5321995611820629], 
             UndirectedEdge[29, 129] -> 
             RGBColor[
              0.9946214698924287, 0.9912725349807529, 0.6827329557097797], 
             UndirectedEdge[83, 230] -> 
             RGBColor[
              0.9829501970502553, 0.959658713210449, 0.5840423721195005], 
             UndirectedEdge[10, 155] -> 
             RGBColor[
              0.9638083369354515, 0.9725288974616448, 0.9461472246575078], 
             UndirectedEdge[210, 316] -> 
             RGBColor[
              0.9273641661040088, 0.7497301535988454, 0.2604137069463754], 
             UndirectedEdge[6, 175] -> 
             RGBColor[
              0.9941820306862641, 0.9915213783873589, 0.7213129717268187], 
             UndirectedEdge[301, 343] -> 
             RGBColor[
              0.9021828383352042, 0.5615192410825289, 0.5142758099524642], 
             UndirectedEdge[140, 297] -> 
             RGBColor[
              0.9812848235084837, 0.9562807255917404, 0.5930534912842753], 
             UndirectedEdge[274, 295] -> 
             RGBColor[
              0.927615924234908, 0.9405658123682499, 0.7619268305389006], 
             UndirectedEdge[61, 371] -> 
             RGBColor[
              0.9674042197701418, 0.8958767545955406, 0.45503018445561866`], 
             UndirectedEdge[266, 397] -> 
             RGBColor[
              0.9470319092237558, 0.9079636101244362, 0.6363331222505634], 
             UndirectedEdge[71, 88] -> 
             RGBColor[
              0.9889483654773512, 0.9873721131883136, 0.6637590664677853], 
             UndirectedEdge[156, 255] -> 
             RGBColor[
              0.9442632041830674, 0.8016070121461499, 0.41801924890573805`], 
             UndirectedEdge[22, 388] -> 
             RGBColor[
              0.9931387728316653, 0.9877328538004385, 0.4945759491916589], 
             UndirectedEdge[17, 346] -> 
             RGBColor[
              0.978271253784323, 0.9673080997067185, 0.6596059927808064], 
             UndirectedEdge[72, 365] -> 
             RGBColor[
              0.9645937232401048, 0.9731146372817032, 0.9448177705052843], 
             UndirectedEdge[194, 230] -> 
             RGBColor[
              0.9886474408827203, 0.9895734393046127, 0.8378048142619325], 
             UndirectedEdge[95, 264] -> 
             RGBColor[
              0.9886620594175168, 0.9861424835827435, 0.6561107957441128], 
             UndirectedEdge[131, 325] -> 
             RGBColor[
              0.9924167683963414, 0.9911321530987937, 0.7753373026543212], 
             UndirectedEdge[369, 372] -> 
             RGBColor[
              0.9586896068370979, 0.9654951737287006, 0.7772163583598928], 
             UndirectedEdge[11, 248] -> 
             RGBColor[
              0.9760246493729854, 0.9790021321164013, 0.7798621876232446], 
             UndirectedEdge[32, 223] -> 
             RGBColor[
              0.9892963839259523, 0.9886538792225663, 0.7407012896548522], 
             UndirectedEdge[75, 229] -> 
             RGBColor[
              0.9833431816996888, 0.969804988772597, 0.6465370201317933], 
             UndirectedEdge[123, 131] -> 
             RGBColor[
              0.9540288533543476, 0.8427483169307459, 0.49141526365980204`], 
             UndirectedEdge[35, 340] -> 
             RGBColor[
              0.9825753493923939, 0.9528847033773316, 0.3868089520689576], 
             UndirectedEdge[316, 369] -> 
             RGBColor[
              0.9316783374597672, 0.8703546214069289, 0.6314720866599302], 
             UndirectedEdge[232, 280] -> 
             RGBColor[
              0.9821167065122385, 0.9840271085166092, 0.8077572826029089], 
             UndirectedEdge[30, 318] -> 
             RGBColor[
              0.9893748769876485, 0.9898742528282558, 0.8257493154589797], 
             UndirectedEdge[219, 338] -> 
             RGBColor[
              0.9605401982815877, 0.9666587290968809, 0.7520965973270818], 
             UndirectedEdge[124, 397] -> 
             RGBColor[
              0.9516250943476381, 0.9634426550878824, 0.966770276460103], 
             UndirectedEdge[131, 280] -> 
             RGBColor[
              0.9821605493268968, 0.9844337466651794, 0.8352711253119166], 
             UndirectedEdge[224, 345] -> 
             RGBColor[
              0.9640300211397899, 0.9697917659778601, 0.7808297119122675], 
             UndirectedEdge[44, 195] -> 
             RGBColor[
              0.9762118107763984, 0.9816007075155213, 0.917149704163013], 
             UndirectedEdge[57, 102] -> 
             RGBColor[
              0.9631804957420906, 0.9720606545276318, 0.947209996030659], 
             UndirectedEdge[102, 222] -> 
             RGBColor[
              0.95520414877031, 0.8891877179851624, 0.6032036649579586], 
             UndirectedEdge[86, 285] -> 
             RGBColor[
              0.9249979041199486, 0.72015915675409, 0.3034347448253276], 
             UndirectedEdge[97, 340] -> 
             RGBColor[
              0.9835811491485198, 0.9607403158407528, 0.5792584259553927], 
             UndirectedEdge[84, 183] -> 
             RGBColor[
              0.9895139642720978, 0.9899317689947558, 0.8234442792092995], 
             UndirectedEdge[23, 132] -> 
             RGBColor[
              0.983631205569044, 0.9841912217419009, 0.7285934530977624], 
             UndirectedEdge[124, 210] -> 
             RGBColor[
              0.9399871592850803, 0.8370447117341335, 0.5973118332025493], 
             UndirectedEdge[257, 288] -> 
             RGBColor[
              0.9869403101195718, 0.9871309585455141, 0.7604282702318962], 
             UndirectedEdge[31, 287] -> 
             RGBColor[
              0.9907677225462033, 0.9894919098794384, 0.7330064847739624], 
             UndirectedEdge[163, 222] -> 
             RGBColor[
              0.9557014923672009, 0.8895586360253983, 0.6023617919764068], 
             UndirectedEdge[206, 386] -> 
             RGBColor[
              0.9920629985453118, 0.9897077246835344, 0.688293227145857], 
             UndirectedEdge[95, 263] -> 
             RGBColor[
              0.9663934315753376, 0.8938704634523991, 0.347010686427932], 
             UndirectedEdge[103, 333] -> 
             RGBColor[
              0.9379219367828344, 0.8207776797418003, 0.589381917926445], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.9920100510817385, 0.9899017071984914, 0.7048627300087746], 
             UndirectedEdge[57, 174] -> 
             RGBColor[
              0.9711725515740411, 0.9777121826868447, 0.9198468347078541], 
             UndirectedEdge[32, 208] -> 
             RGBColor[
              0.9416582695931398, 0.8102573932547211, 0.570276319960654], 
             UndirectedEdge[11, 125] -> 
             RGBColor[
              0.9901497187469379, 0.9892097803991488, 0.7413171192610835], 
             UndirectedEdge[82, 136] -> 
             RGBColor[
              0.9841508375636685, 0.9851943551012241, 0.7765584969247161], 
             UndirectedEdge[129, 298] -> 
             RGBColor[
              0.991270226245626, 0.9898867096097665, 0.7382717356778483], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.9943860189641445, 0.9916537103429142, 0.721419820221235], 
             UndirectedEdge[155, 306] -> 
             RGBColor[
              0.9666324435798093, 0.9746351115729566, 0.9413667487535887], 
             UndirectedEdge[247, 358] -> 
             RGBColor[
              0.9901848115461036, 0.9881169066799333, 0.660240305538736], 
             UndirectedEdge[5, 373] -> 
             RGBColor[
              0.986045347345501, 0.9868964349446189, 0.7962950008527521], 
             UndirectedEdge[194, 201] -> 
             RGBColor[
              0.9540619959679244, 0.8571276815531794, 0.561163155311762], 
             UndirectedEdge[7, 173] -> 
             RGBColor[
              0.9425462332731406, 0.7947962368164563, 0.3722657072530646], 
             UndirectedEdge[25, 364] -> 
             RGBColor[
              0.993472821591865, 0.9884473503209952, 0.5309350952294142], 
             UndirectedEdge[1, 313] -> 
             RGBColor[
              0.9812910070516678, 0.94855231508414, 0.3818195246029366], 
             UndirectedEdge[189, 222] -> 
             RGBColor[
              0.9668409033899283, 0.8946718778182867, 0.3937166728551067], 
             UndirectedEdge[232, 275] -> 
             RGBColor[
              0.9510226031650693, 0.9601026159072381, 0.8349237894415387], 
             UndirectedEdge[289, 376] -> 
             RGBColor[
              0.9732225344284007, 0.9768066072678996, 0.7762176334672444], 
             UndirectedEdge[194, 208] -> 
             RGBColor[
              0.9427618362153546, 0.8107137464133756, 0.5519873650916853], 
             UndirectedEdge[320, 384] -> 
             RGBColor[
              0.9923003846119769, 0.9855060669317653, 0.44018931374228276`], 
             UndirectedEdge[262, 332] -> 
             RGBColor[
              0.9346042150613256, 0.7784345351113129, 0.2662392202832238], 
             UndirectedEdge[39, 237] -> 
             RGBColor[
              0.9778611704106845, 0.9577195764705831, 0.6405947762085319], 
             UndirectedEdge[105, 353] -> 
             RGBColor[
              0.9943893439239471, 0.9909629743632393, 0.6710555582797939], 
             UndirectedEdge[160, 321] -> 
             RGBColor[
              0.9163804099117274, 0.785396137358596, 0.6126971401586053], 
             UndirectedEdge[22, 354] -> 
             RGBColor[
              0.9746647671153236, 0.9253607056070499, 0.41955050871371935`], 
             UndirectedEdge[70, 286] -> 
             RGBColor[
              0.9679334394184899, 0.899706634923662, 0.3529831916533497], 
             UndirectedEdge[97, 334] -> 
             RGBColor[
              0.96437269215525, 0.9718009072404936, 0.8937424820583671], 
             UndirectedEdge[301, 362] -> 
             RGBColor[
              0.9898542136280164, 0.9878120168077813, 0.6534943207275558], 
             UndirectedEdge[166, 300] -> 
             RGBColor[
              0.987976500569697, 0.9892959882427981, 0.848924031586598], 
             UndirectedEdge[357, 364] -> 
             RGBColor[
              0.9927044630836747, 0.9893170937187397, 0.6299859999084645], 
             UndirectedEdge[13, 66] -> 
             RGBColor[
              0.9942981877705078, 0.9909389034515144, 0.6735566089931933], 
             UndirectedEdge[102, 395] -> 
             RGBColor[
              0.9521567315498488, 0.9638016817605696, 0.964571332220127], 
             UndirectedEdge[129, 336] -> 
             RGBColor[
              0.9767797815344823, 0.9797377495543554, 0.7922664102286912], 
             UndirectedEdge[257, 275] -> 
             RGBColor[
              0.9506682958945025, 0.9593447884814561, 0.7963596295713674], 
             UndirectedEdge[358, 369] -> 
             RGBColor[
              0.9582395046999787, 0.9645324507697093, 0.728225518442865], 
             UndirectedEdge[42, 139] -> 
             RGBColor[
              0.8578825374186717, 0.8897584107021286, 0.986242538309826], 
             UndirectedEdge[37, 206] -> 
             RGBColor[
              0.9897402427679569, 0.9762528424156347, 0.4827313999307721], 
             UndirectedEdge[3, 162] -> 
             RGBColor[
              0.9833260666082861, 0.986317217603595, 0.8787175027749119], 
             UndirectedEdge[44, 161] -> 
             RGBColor[
              0.9806033899078639, 0.9823544805062622, 0.7671549418129668], 
             UndirectedEdge[67, 266] -> 
             RGBColor[
              0.9626889519147276, 0.8857532333251984, 0.309814359224603], 
             UndirectedEdge[305, 360] -> 
             RGBColor[
              0.9678583714395956, 0.9332917199943886, 0.6215075085959207], 
             UndirectedEdge[51, 174] -> 
             RGBColor[
              0.9904126954434359, 0.9903034174304416, 0.808549977858513], 
             UndirectedEdge[132, 321] -> 
             RGBColor[
              0.9444320957729468, 0.8031955000537645, 0.3812141274517464], 
             UndirectedEdge[198, 236] -> 
             RGBColor[
              0.9775224785606502, 0.9815080123168449, 0.8670058316789324], 
             UndirectedEdge[153, 356] -> 
             RGBColor[
              0.9795789555255787, 0.9489238710082601, 0.5753496721747666], 
             UndirectedEdge[78, 217] -> 
             RGBColor[
              0.9521665384959206, 0.8961481616079203, 0.615503462579674], 
             UndirectedEdge[16, 324] -> 
             RGBColor[
              0.8952928606829748, 0.9191847670895219, 0.9842766139775797], 
             UndirectedEdge[263, 312] -> 
             RGBColor[
              0.9679452135433166, 0.8976231274134939, 0.47904582882287555`], 
             UndirectedEdge[49, 231] -> 
             RGBColor[
              0.9508744615010948, 0.9225648850649015, 0.6543745331784638], 
             UndirectedEdge[58, 303] -> 
             RGBColor[
              0.9885667382713978, 0.9875745488347826, 0.6966267775470435], 
             UndirectedEdge[287, 371] -> 
             RGBColor[
              0.9943193477706795, 0.9902579842205537, 0.6230742456393694], 
             UndirectedEdge[108, 332] -> 
             RGBColor[
              0.9589385038616876, 0.8675427470817753, 0.3241977364271561], 
             UndirectedEdge[55, 135] -> 
             RGBColor[
              0.988485341508097, 0.9850441191104562, 0.6519527227801263], 
             UndirectedEdge[38, 145] -> 
             RGBColor[
              0.9636609086311553, 0.8912907898540301, 0.5498347282157042], 
             UndirectedEdge[41, 400] -> 
             RGBColor[
              0.980177624281288, 0.9439240567884717, 0.45169017278670887`], 
             UndirectedEdge[184, 369] -> 
             RGBColor[
              0.9268418929489476, 0.8511797305711226, 0.6275805698805812], 
             UndirectedEdge[68, 363] -> 
             RGBColor[
              0.9906356491461205, 0.9875256213301866, 0.6273224423781752], 
             UndirectedEdge[239, 350] -> 
             RGBColor[
              0.9506857747229887, 0.8653715421827536, 0.5949887471185449], 
             UndirectedEdge[197, 300] -> 
             RGBColor[
              0.9876425381120046, 0.9891578861840986, 0.854458653777697], 
             UndirectedEdge[34, 340] -> 
             RGBColor[
              0.9817195199232316, 0.9599704843144075, 0.6101104399604148], 
             UndirectedEdge[99, 225] -> 
             RGBColor[
              0.93371743257432, 0.7682350453696386, 0.2885483529925676], 
             UndirectedEdge[75, 218] -> 
             RGBColor[
              0.9793547077985556, 0.9840822359214874, 0.9179898598260172], 
             UndirectedEdge[33, 256] -> 
             RGBColor[
              0.9925757261786055, 0.9860731563414201, 0.47201552056505247`], 
             UndirectedEdge[68, 173] -> 
             RGBColor[
              0.9911983850490013, 0.9889263472758613, 0.6718135977962749], 
             UndirectedEdge[76, 368] -> 
             RGBColor[
              0.9670687614667207, 0.9465022319530967, 0.6521376306941995], 
             UndirectedEdge[343, 369] -> 
             RGBColor[
              0.8704706553427486, 0.5380311878768071, 0.5783975572960974], 
             UndirectedEdge[172, 243] -> 
             RGBColor[
              0.9944428414977031, 0.9913280591505955, 0.6950986939951319], 
             UndirectedEdge[25, 83] -> 
             RGBColor[
              0.984702959020947, 0.9591960459424638, 0.4686773545123068], 
             UndirectedEdge[176, 372] -> 
             RGBColor[
              0.9943725304903713, 0.9903717366803768, 0.6288628564721317], 
             UndirectedEdge[211, 214] -> 
             RGBColor[
              0.9496457860986429, 0.9604222975647622, 0.907716074427419], 
             UndirectedEdge[273, 330] -> 
             RGBColor[
              0.9682267835405246, 0.9011390930660392, 0.348485844453423], 
             UndirectedEdge[247, 266] -> 
             RGBColor[
              0.9716534523630813, 0.9257745904889948, 0.5699478458024355], 
             UndirectedEdge[294, 347] -> 
             RGBColor[
              0.9591819603709477, 0.9670144553122734, 0.8646928872210106], 
             UndirectedEdge[247, 343] -> 
             RGBColor[
              0.9024159621888735, 0.561615643787031, 0.5104123443919686], 
             UndirectedEdge[147, 354] -> 
             RGBColor[
              0.9236007370755948, 0.7311648761684468, 0.2571970355700334], 
             UndirectedEdge[83, 206] -> 
             RGBColor[
              0.9846504161250986, 0.9590836620011458, 0.46295838455637767`], 
             UndirectedEdge[178, 300] -> 
             RGBColor[
              0.9905702846304355, 0.9880863325414564, 0.6400426845604394], 
             UndirectedEdge[31, 384] -> 
             RGBColor[
              0.9900822840291166, 0.9880258261998547, 0.6584007322252652], 
             UndirectedEdge[325, 339] -> 
             RGBColor[
              0.9639264335543365, 0.8908759054269328, 0.5428667870351833], 
             UndirectedEdge[43, 237] -> 
             RGBColor[
              0.9560407750773089, 0.8771721829132072, 0.5919811127915957], 
             UndirectedEdge[114, 128] -> 
             RGBColor[
              0.9739305728891926, 0.9233861062759825, 0.3635582988933778], 
             UndirectedEdge[131, 188] -> 
             RGBColor[
              0.9915539659773964, 0.9907753621255491, 0.7896361715973239], 
             UndirectedEdge[8, 352] -> 
             RGBColor[
              0.9750501162556982, 0.9400467566895724, 0.6019906403237321], 
             UndirectedEdge[56, 137] -> 
             RGBColor[
              0.9745810677061959, 0.9778460469016634, 0.776000636859531], 
             UndirectedEdge[11, 93] -> 
             RGBColor[
              0.9935423949322555, 0.9885961606611466, 0.538507723974032], 
             UndirectedEdge[232, 325] -> 
             RGBColor[
              0.9923729255816831, 0.9907255149502235, 0.7478234599453135], 
             UndirectedEdge[293, 387] -> 
             RGBColor[
              0.9889466784443601, 0.9880040304662637, 0.7097714506646349], 
             UndirectedEdge[100, 175] -> 
             RGBColor[
              0.993645521936614, 0.9903738404212127, 0.6629173052756094], 
             UndirectedEdge[327, 336] -> 
             RGBColor[
              0.9770671057758176, 0.9806278843569608, 0.8435714415482614], 
             UndirectedEdge[230, 357] -> 
             RGBColor[
              0.9913843896154424, 0.9907052379419674, 0.792446490764458], 
             UndirectedEdge[151, 291] -> 
             RGBColor[
              0.9684145292511452, 0.8995608410004361, 0.474865037619164], 
             UndirectedEdge[10, 87] -> 
             RGBColor[
              0.9820588981361787, 0.9841079855454875, 0.8176932466896059], 
             UndirectedEdge[44, 247] -> 
             RGBColor[
              0.9773345205488627, 0.9820649768587604, 0.8985434977535244], 
             UndirectedEdge[191, 334] -> 
             RGBColor[
              0.9651325347211237, 0.9698246907056252, 0.7146597723464367], 
             UndirectedEdge[31, 389] -> 
             RGBColor[
              0.9894078119670371, 0.9898878722886233, 0.8252034976175153], 
             UndirectedEdge[323, 346] -> 
             RGBColor[
              0.9771587718495125, 0.9635554369174222, 0.6552842105386525], 
             UndirectedEdge[91, 257] -> 
             RGBColor[
              0.9895993201161489, 0.9889672455476948, 0.7493533321087827], 
             UndirectedEdge[25, 217] -> 
             RGBColor[
              0.9699893891453075, 0.9066391681161453, 0.42674902906355405`], 
             UndirectedEdge[4, 238] -> 
             RGBColor[
              0.8249474905823875, 0.8612723055781095, 0.8497452142208435], 
             UndirectedEdge[49, 298] -> 
             RGBColor[
              0.9764207611902653, 0.9409592836606241, 0.5816651799786137], 
             UndirectedEdge[96, 245] -> 
             RGBColor[
              0.9566865812669494, 0.9643212721497095, 0.8113358630173608], 
             UndirectedEdge[198, 219] -> 
             RGBColor[
              0.9925004071143055, 0.9894497153662715, 0.649141637924467], 
             UndirectedEdge[69, 106] -> 
             RGBColor[
              0.9656164536556104, 0.9717640596617441, 0.8390849120696575], 
             UndirectedEdge[246, 350] -> 
             RGBColor[
              0.9786893015722551, 0.9836270965224296, 0.920957633104569], 
             UndirectedEdge[91, 263] -> 
             RGBColor[
              0.9630309812721138, 0.8959170047026717, 0.5841869412594792], 
             UndirectedEdge[193, 305] -> 
             RGBColor[
              0.9676165396541965, 0.9324759645974339, 0.6205680377757457], 
             UndirectedEdge[217, 244] -> 
             RGBColor[
              0.9595248096087412, 0.8722052684376604, 0.31249307283223554`], 
             UndirectedEdge[218, 260] -> 
             RGBColor[
              0.8475510026266919, 0.8810849499557487, 0.9506239864554927], 
             UndirectedEdge[115, 169] -> 
             RGBColor[
              0.959321458557282, 0.8694096366534141, 0.32269034658305434`], 
             UndirectedEdge[152, 332] -> 
             RGBColor[
              0.9426940161440315, 0.8105079006378374, 0.272748464126406], 
             UndirectedEdge[8, 227] -> 
             RGBColor[
              0.8833717046830336, 0.9086255896946309, 0.9331906701791886], 
             UndirectedEdge[161, 344] -> 
             RGBColor[
              0.9415078968532614, 0.7891908552363727, 0.41144584949089996`], 
             UndirectedEdge[255, 324] -> 
             RGBColor[
              0.9181786921038378, 0.7847982359328979, 0.6083618509447226], 
             UndirectedEdge[135, 221] -> 
             RGBColor[
              0.9897526806146941, 0.9886159808004462, 0.7166686567745014], 
             UndirectedEdge[179, 257] -> 
             RGBColor[
              0.9920186183111164, 0.9899676875244414, 0.7092593000751422], 
             UndirectedEdge[40, 350] -> 
             RGBColor[
              0.9734143166141238, 0.9796930213776505, 0.929886806702267], 
             UndirectedEdge[358, 397] -> 
             RGBColor[
              0.9655632684067781, 0.9703059263153747, 0.7266255819868639], 
             UndirectedEdge[44, 149] -> 
             RGBColor[
              0.978934110638932, 0.9827264484685942, 0.8720341503546211], 
             UndirectedEdge[215, 218] -> 
             RGBColor[
              0.9766674627079667, 0.9821192124079006, 0.9243800789217793], 
             UndirectedEdge[211, 248] -> 
             RGBColor[
              0.9736895218577208, 0.9790213862878976, 0.8901523566877477], 
             UndirectedEdge[38, 103] -> 
             RGBColor[
              0.9795439213017476, 0.9834511259626417, 0.8830877539018445], 
             UndirectedEdge[79, 213] -> 
             RGBColor[
              0.9098899215510812, 0.6725129444576956, 0.24594291306996213`], 
             UndirectedEdge[116, 383] -> 
             RGBColor[
              0.9520287807448641, 0.8611526150577546, 0.5886650273919585], 
             UndirectedEdge[214, 263] -> 
             RGBColor[
              0.925403921063447, 0.8673342931452226, 0.6313176119736843], 
             UndirectedEdge[203, 275] -> 
             RGBColor[
              0.9296000635941297, 0.8881006372801981, 0.6356187535511881], 
             UndirectedEdge[235, 396] -> 
             RGBColor[
              0.9940736403496057, 0.9897324408917079, 0.596330509185919], 
             UndirectedEdge[170, 361] -> 
             RGBColor[
              0.9940506757435705, 0.9896833219214765, 0.5938309535401121], 
             UndirectedEdge[190, 255] -> 
             RGBColor[
              0.9446262481807932, 0.8023835265479065, 0.4575343476103326], 
             UndirectedEdge[67, 113] -> 
             RGBColor[
              0.9783149769802995, 0.9489863940975024, 0.6003420222939293], 
             UndirectedEdge[244, 307] -> 
             RGBColor[
              0.9833883876619096, 0.9548265436564347, 0.4580556422909663], 
             UndirectedEdge[106, 292] -> 
             RGBColor[
              0.9897335617415042, 0.9896870942727496, 0.7954188414779613], 
             UndirectedEdge[119, 126] -> 
             RGBColor[
              0.9831488281378115, 0.9867287010570491, 0.9033640678310505], 
             UndirectedEdge[148, 288] -> 
             RGBColor[
              0.9584087619180766, 0.9685019032546793, 0.9552872967272135], 
             UndirectedEdge[143, 277] -> 
             RGBColor[
              0.9755111897552893, 0.9389345273868394, 0.5853438972282821], 
             UndirectedEdge[245, 364] -> 
             RGBColor[
              0.9560126924576026, 0.9628798921271267, 0.73798722487961], 
             UndirectedEdge[101, 335] -> 
             RGBColor[
              0.9942720622105983, 0.9901568451888436, 0.6179275042371881], 
             UndirectedEdge[175, 296] -> 
             RGBColor[
              0.9936653805774789, 0.9916484863235634, 0.7546445675081291], 
             UndirectedEdge[106, 158] -> 
             RGBColor[
              0.9896584326481626, 0.9896560264619232, 0.7966639249824912], 
             UndirectedEdge[59, 319] -> 
             RGBColor[
              0.9927127763028801, 0.9907022126134537, 0.7302818632750258], 
             UndirectedEdge[159, 218] -> 
             RGBColor[
              0.9805436931636335, 0.9845739119254772, 0.8982852953311877], 
             UndirectedEdge[126, 326] -> 
             RGBColor[
              0.9832897287201697, 0.9867869670688341, 0.9010289805423559], 
             UndirectedEdge[130, 371] -> 
             RGBColor[
              0.9943697178788387, 0.9903657207887069, 0.6285567210642176], 
             UndirectedEdge[108, 262] -> 
             RGBColor[
              0.9565483459773123, 0.8580665675431267, 0.3222745592891714], 
             UndirectedEdge[34, 91] -> 
             RGBColor[
              0.9862298300460874, 0.9885736950939006, 0.8778708824012238], 
             UndirectedEdge[173, 323] -> 
             RGBColor[
              0.9871392138900038, 0.9677821755826972, 0.44684373652784487`], 
             UndirectedEdge[104, 208] -> 
             RGBColor[
              0.9456310171095479, 0.8119002264477101, 0.5044376124727701], 
             UndirectedEdge[115, 122] -> 
             RGBColor[
              0.9659716338016286, 0.8915329484651303, 0.3748248806879019], 
             UndirectedEdge[275, 297] -> 
             RGBColor[
              0.9404483395274013, 0.9258703119468927, 0.6716381881324999], 
             UndirectedEdge[185, 293] -> 
             RGBColor[
              0.9334624057031475, 0.7535364167870007, 0.3652381849717276], 
             UndirectedEdge[92, 256] -> 
             RGBColor[
              0.977507568093166, 0.9352447209474657, 0.41347857178600994`], 
             UndirectedEdge[135, 165] -> 
             RGBColor[
              0.9870521908734102, 0.9802097654998865, 0.6463852031921565], 
             UndirectedEdge[158, 270] -> 
             RGBColor[
              0.9795900489081808, 0.9842603706433858, 0.9177087150122234], 
             UndirectedEdge[35, 86] -> 
             RGBColor[
              0.9873067925147767, 0.9688449720248045, 0.40518971514135393`], 
             UndirectedEdge[124, 387] -> 
             RGBColor[
              0.9747771784055497, 0.9806459763589004, 0.9247377398292043], 
             UndirectedEdge[170, 261] -> 
             RGBColor[
              0.9940506757435705, 0.9896833219214765, 0.5938309535401121], 
             UndirectedEdge[78, 244] -> 
             RGBColor[
              0.9656180799083711, 0.9444479210895277, 0.6525290457630154], 
             UndirectedEdge[320, 381] -> 
             RGBColor[
              0.9931121763544735, 0.9872424073842301, 0.5285478351151232], 
             UndirectedEdge[90, 166] -> 
             RGBColor[
              0.9270342799405635, 0.9427804077222859, 0.9224038208444922], 
             UndirectedEdge[119, 317] -> 
             RGBColor[
              0.9771524815137098, 0.9472906007874345, 0.6112090512783193], 
             UndirectedEdge[173, 250] -> 
             RGBColor[
              0.9931962312133151, 0.9897525080071096, 0.6387041165934564], 
             UndirectedEdge[234, 355] -> 
             RGBColor[
              0.94244870809677, 0.9524624866741244, 0.7689686060354577], 
             UndirectedEdge[203, 297] -> 
             RGBColor[
              0.9628348501403279, 0.8851194714630182, 0.3162449090495997], 
             UndirectedEdge[48, 388] -> 
             RGBColor[
              0.9749434182043879, 0.9771053627018458, 0.6951747282327619], 
             UndirectedEdge[34, 95] -> 
             RGBColor[
              0.9895922803493112, 0.986527153843628, 0.6406946275696765], 
             UndirectedEdge[133, 299] -> 
             RGBColor[
              0.9895916067486099, 0.9889752597407157, 0.7502955655525521], 
             UndirectedEdge[58, 376] -> 
             RGBColor[
              0.9935035186958385, 0.9885130083224412, 0.5342762855563674], 
             UndirectedEdge[239, 392] -> 
             RGBColor[
              0.5532819044363309, 0.5281025456618688, 0.597067040858891], 
             UndirectedEdge[64, 77] -> 
             RGBColor[
              0.9797166041079964, 0.9531800591503454, 0.6020936553662565], 
             UndirectedEdge[73, 112] -> 
             RGBColor[
              0.9945932724118208, 0.9908438813299255, 0.6528892523606789], 
             UndirectedEdge[257, 339] -> 
             RGBColor[
              0.9660308540510221, 0.890746317101331, 0.4353147134686876], 
             UndirectedEdge[35, 85] -> 
             RGBColor[
              0.9911998402107902, 0.9814828074449274, 0.4623476054083001], 
             UndirectedEdge[37, 187] -> 
             RGBColor[
              0.9889418348200144, 0.9743603536465608, 0.411541545745371], 
             UndirectedEdge[9, 39] -> 
             RGBColor[
              0.9078025058397394, 0.9029886311607016, 0.6731573156648377], 
             UndirectedEdge[136, 394] -> 
             RGBColor[
              0.9828863600971385, 0.9820562064177879, 0.6757946764746535], 
             UndirectedEdge[287, 389] -> 
             RGBColor[
              0.9928112336480178, 0.9903369542358785, 0.6991402173796885], 
             UndirectedEdge[195, 372] -> 
             RGBColor[
              0.9895122039107584, 0.9886153602956855, 0.7278373518652526], 
             UndirectedEdge[149, 362] -> 
             RGBColor[
              0.9916869275717551, 0.9885698911221172, 0.6231215077681567], 
             UndirectedEdge[83, 321] -> 
             RGBColor[
              0.935459458019419, 0.7735104800633466, 0.2968855594909299], 
             UndirectedEdge[227, 308] -> 
             RGBColor[
              0.8815466310988183, 0.8899227562563344, 0.6816848059709368], 
             UndirectedEdge[100, 146] -> 
             RGBColor[
              0.9943994825554586, 0.9904293844223266, 0.6317964224280113], 
             UndirectedEdge[100, 278] -> 
             RGBColor[
              0.9667777593490758, 0.9718784921175827, 0.7774775289786696], 
             UndirectedEdge[234, 350] -> 
             RGBColor[
              0.9324992248340449, 0.9480327491188912, 0.9594175674024575], 
             UndirectedEdge[278, 352] -> 
             RGBColor[
              0.9520984432229123, 0.9231708120557435, 0.6516511255896467], 
             UndirectedEdge[342, 353] -> 
             RGBColor[
              0.9938405153434184, 0.9892338100760272, 0.5709562909432149], 
             UndirectedEdge[109, 181] -> 
             RGBColor[
              0.9908107059306683, 0.9904680049953152, 0.8019539140669499], 
             UndirectedEdge[59, 296] -> 
             RGBColor[
              0.9942477207761569, 0.9913369515994274, 0.7048438610438682], 
             UndirectedEdge[168, 378] -> 
             RGBColor[
              0.96551268595037, 0.9269059663438476, 0.6156360587561365], 
             UndirectedEdge[191, 370] -> 
             RGBColor[
              0.9842749778353094, 0.9585414189909378, 0.3999192647888956], 
             UndirectedEdge[153, 184] -> 
             RGBColor[
              0.9496249735979138, 0.8340758539386172, 0.2986937432018868], 
             UndirectedEdge[3, 91] -> 
             RGBColor[
              0.9814566007785748, 0.985544145439929, 0.9096993895957106], 
             UndirectedEdge[149, 210] -> 
             RGBColor[
              0.9528530362659331, 0.8455568354655885, 0.5270241745756079], 
             UndirectedEdge[3, 312] -> 
             RGBColor[
              0.9863708330497776, 0.9872502681507511, 0.804558277159107], 
             UndirectedEdge[17, 388] -> 
             RGBColor[
              0.9878845999382774, 0.9707496573897784, 0.411209396973643], 
             UndirectedEdge[99, 243] -> 
             RGBColor[
              0.982667458937392, 0.9528628023341332, 0.5425631347021611], 
             UndirectedEdge[108, 398] -> 
             RGBColor[
              0.9664488406891598, 0.9554541301766382, 0.6731716322223507], 
             UndirectedEdge[57, 186] -> 
             RGBColor[
              0.9696863564761851, 0.9607542409809683, 0.6738168959765998], 
             UndirectedEdge[180, 398] -> 
             RGBColor[
              0.9633380311295985, 0.9721781441616947, 0.9469433297114176], 
             UndirectedEdge[66, 318] -> 
             RGBColor[0.989818992876708, 0.98908664125287, 0.747788460168257],
              UndirectedEdge[374, 382] -> 
             RGBColor[
              0.9910617632955676, 0.9841073829440321, 0.5954159407508209], 
             UndirectedEdge[190, 270] -> 
             RGBColor[
              0.9848061238774726, 0.9860497591789974, 0.8045447589411286], 
             UndirectedEdge[47, 96] -> 
             RGBColor[
              0.9767414703396664, 0.932042352969749, 0.4630646216300635], 
             UndirectedEdge[245, 328] -> 
             RGBColor[
              0.9566285681346509, 0.9641971879257505, 0.8050214915822187], 
             UndirectedEdge[142, 143] -> 
             RGBColor[
              0.9435079084905558, 0.8129612356802007, 0.5478007953323852], 
             UndirectedEdge[268, 373] -> 
             RGBColor[
              0.9933772662799611, 0.9910657229523212, 0.7257190360079908], 
             UndirectedEdge[69, 390] -> 
             RGBColor[
              0.965671085908496, 0.9718809125264987, 0.8450312956450843], 
             UndirectedEdge[91, 112] -> 
             RGBColor[
              0.990031711128899, 0.9898920862025298, 0.79641642543862], 
             UndirectedEdge[16, 190] -> 
             RGBColor[
              0.9217404167599301, 0.9367700577045305, 0.8334491106431896], 
             UndirectedEdge[40, 395] -> 
             RGBColor[
              0.9536699732200591, 0.9649302549205065, 0.9620098087890983], 
             UndirectedEdge[84, 246] -> 
             RGBColor[
              0.9844760579479377, 0.9877573997196236, 0.9028573236644315], 
             UndirectedEdge[196, 376] -> 
             RGBColor[
              0.9941481054248369, 0.9898917141580534, 0.6044355730796616], 
             UndirectedEdge[37, 311] -> 
             RGBColor[
              0.9670092848510461, 0.9621745750792038, 0.6856018901846366], 
             UndirectedEdge[179, 275] -> 
             RGBColor[
              0.948563875397817, 0.9594743768070579, 0.9039117031378632], 
             UndirectedEdge[334, 340] -> 
             RGBColor[
              0.9568465241855144, 0.9419505617373043, 0.6759626089302755], 
             UndirectedEdge[23, 366] -> 
             RGBColor[
              0.9843908473448069, 0.9858160186886924, 0.8112757724239222], 
             UndirectedEdge[295, 351] -> 
             RGBColor[
              0.9233500283998212, 0.940312991624511, 0.9424747271594296], 
             UndirectedEdge[358, 363] -> 
             RGBColor[
              0.9925201758465749, 0.9862126466483392, 0.4440046597096846], 
             UndirectedEdge[111, 116] -> 
             RGBColor[
              0.9723224069162785, 0.9788786769128355, 0.9317351250050598], 
             UndirectedEdge[147, 371] -> 
             RGBColor[
              0.9430210519433354, 0.7955610839501459, 0.4352223872346138], 
             UndirectedEdge[33, 311] -> 
             RGBColor[
              0.9700518128538349, 0.9724377364521578, 0.6974215369422685], 
             UndirectedEdge[137, 178] -> 
             RGBColor[
              0.9738861774603425, 0.9763597469299639, 0.7003661219638705], 
             UndirectedEdge[328, 386] -> 
             RGBColor[
              0.9922987286157491, 0.9902119274682336, 0.713950990555595], 
             UndirectedEdge[20, 36] -> 
             RGBColor[
              0.7598340086827202, 0.8074779282007631, 0.7548846275128214], 
             UndirectedEdge[107, 212] -> 
             RGBColor[
              0.9637541256487743, 0.8889424944841013, 0.5366100646840959], 
             UndirectedEdge[21, 27] -> 
             RGBColor[
              0.993540669507483, 0.9885924701520257, 0.5383199221356372], 
             UndirectedEdge[138, 329] -> 
             RGBColor[
              0.9940341820016924, 0.9916655985732536, 0.7386906687458608], 
             UndirectedEdge[3, 263] -> 
             RGBColor[
              0.9594119806261928, 0.8933647582460507, 0.596886893146271], 
             UndirectedEdge[239, 269] -> 
             RGBColor[
              0.9567156086782709, 0.8696023642059207, 0.5728600131198331], 
             UndirectedEdge[74, 86] -> 
             RGBColor[
              0.9894406596826176, 0.9755119636653691, 0.4586354813653564], 
             UndirectedEdge[91, 179] -> 
             RGBColor[
              0.9874948996194632, 0.9890968338732966, 0.8569054056752785], 
             UndirectedEdge[316, 358] -> 
             RGBColor[
              0.9662955314742485, 0.892951696423024, 0.36712049051060025`], 
             UndirectedEdge[154, 267] -> 
             RGBColor[
              0.9922736793635236, 0.9907185973910717, 0.7519486304940359], 
             UndirectedEdge[25, 357] -> 
             RGBColor[
              0.993137151586134, 0.9902425706739821, 0.6770814731572641], 
             UndirectedEdge[118, 388] -> 
             RGBColor[
              0.9911386357159082, 0.981726284151662, 0.42385071149664466`], 
             UndirectedEdge[305, 340] -> 
             RGBColor[
              0.9742796340373252, 0.9549521465206872, 0.6464529012344074], 
             UndirectedEdge[100, 213] -> 
             RGBColor[
              0.9352422319263942, 0.7610241647102776, 0.39343608374919], 
             UndirectedEdge[51, 238] -> 
             RGBColor[
              0.8248562129027038, 0.8612345599118311, 0.8512579215922633], 
             UndirectedEdge[104, 242] -> 
             RGBColor[
              0.9564463843855362, 0.8563921209653851, 0.5132233272866474], 
             UndirectedEdge[99, 337] -> 
             RGBColor[
              0.9825778762368309, 0.9518652596607644, 0.4742296923022602], 
             UndirectedEdge[143, 302] -> 
             RGBColor[
              0.980658795576247, 0.9562986105362539, 0.6053413737989107], 
             UndirectedEdge[14, 327] -> 
             RGBColor[
              0.9613910730130475, 0.8718603240273404, 0.4969635550260736], 
             UndirectedEdge[162, 348] -> 
             RGBColor[
              0.9872759684450834, 0.989006300206416, 0.860533661810471], 
             UndirectedEdge[130, 391] -> 
             RGBColor[
              0.9920843168087927, 0.9838689844751941, 0.516579681538158], 
             UndirectedEdge[182, 386] -> 
             RGBColor[
              0.9210190147631029, 0.6943787848860956, 0.5035735193698607], 
             UndirectedEdge[32, 217] -> 
             RGBColor[
              0.9653805152821803, 0.9059207597178809, 0.5894472121090475], 
             UndirectedEdge[3, 285] -> 
             RGBColor[
              0.9211577704745006, 0.7302498524294894, 0.565514376080532], 
             UndirectedEdge[212, 274] -> 
             RGBColor[
              0.9920742839508062, 0.9894792901665243, 0.6711621933895651], 
             UndirectedEdge[234, 272] -> 
             RGBColor[
              0.9365996223475557, 0.9510908188706828, 0.9524766639670329], 
             UndirectedEdge[24, 104] -> 
             RGBColor[
              0.9936916799486066, 0.991200500944209, 0.7208543794047855], 
             UndirectedEdge[317, 327] -> 
             RGBColor[
              0.9818627038426095, 0.949238398767627, 0.5331484776238127], 
             UndirectedEdge[85, 263] -> 
             RGBColor[
              0.9671451619676543, 0.8959118979907743, 0.3919651521580127], 
             UndirectedEdge[169, 300] -> 
             RGBColor[
              0.9841039405470335, 0.9663562169948193, 0.6079170378499981], 
             UndirectedEdge[34, 162] -> 
             RGBColor[
              0.9880992958757989, 0.9893467672575667, 0.846888995580425], 
             UndirectedEdge[62, 313] -> 
             RGBColor[
              0.9931370014791816, 0.9870059804796609, 0.5558690414748197], 
             UndirectedEdge[337, 367] -> 
             RGBColor[0.9806564301511096, 0.9824762008051815, 0.773584438947],
              UndirectedEdge[21, 240] -> 
             RGBColor[
              0.9941674384350109, 0.9899330655119485, 0.6065398519275957], 
             UndirectedEdge[258, 378] -> 
             RGBColor[
              0.9597354128618634, 0.875840234387727, 0.2980801116079461], 
             UndirectedEdge[240, 242] -> 
             RGBColor[
              0.9576472926430665, 0.8566757075696749, 0.4778368772908941], 
             UndirectedEdge[16, 380] -> 
             RGBColor[
              0.9218656798675875, 0.9371894497298647, 0.8580932718393963], 
             UndirectedEdge[38, 222] -> 
             RGBColor[
              0.9647142667698299, 0.8954670038630834, 0.5506822848995752], 
             UndirectedEdge[61, 147] -> 
             RGBColor[
              0.9159577203993021, 0.7008628619312728, 0.2510472849476292], 
             UndirectedEdge[279, 288] -> 
             RGBColor[
              0.9766203343127169, 0.9533190929549806, 0.6353182721566722], 
             UndirectedEdge[192, 384] -> 
             RGBColor[
              0.9792432785269813, 0.9804691480730717, 0.7003500198209718], 
             UndirectedEdge[196, 289] -> 
             RGBColor[
              0.9733820588630403, 0.9771478139031992, 0.7935808837070686], 
             UndirectedEdge[9, 384] -> 
             RGBColor[
              0.9161384872610219, 0.9309243900881261, 0.7211414656325648], 
             UndirectedEdge[114, 187] -> 
             RGBColor[
              0.9736938610984669, 0.9226950287910025, 0.35350560503416606`], 
             UndirectedEdge[90, 274] -> 
             RGBColor[
              0.9300749326912073, 0.9425265589632965, 0.7621613729606453], 
             UndirectedEdge[270, 324] -> 
             RGBColor[
              0.9583585678005173, 0.9684644685639889, 0.9553722622755187], 
             UndirectedEdge[42, 45] -> 
             RGBColor[
              0.9393040808090061, 0.8972347049837328, 0.6368570113270663], 
             UndirectedEdge[316, 363] -> 
             RGBColor[
              0.9659590086063634, 0.8920348172855588, 0.3472512279267498], 
             UndirectedEdge[44, 250] -> 
             RGBColor[
              0.9801197271810786, 0.9832167313777271, 0.8523854159739954], 
             UndirectedEdge[213, 352] -> 
             RGBColor[
              0.9205629158002306, 0.7123164846484384, 0.267609680360167], 
             UndirectedEdge[80, 378] -> 
             RGBColor[
              0.9769143377591843, 0.9327751468229144, 0.45100919865426004`], 
             UndirectedEdge[238, 272] -> 
             RGBColor[
              0.8184370457486428, 0.8582051886101074, 0.9408522091088165], 
             UndirectedEdge[126, 196] -> 
             RGBColor[
              0.9875315858010645, 0.9877005079258536, 0.7696294253886586], 
             UndirectedEdge[112, 240] -> 
             RGBColor[
              0.9950114473746243, 0.991738315291388, 0.6984050163851239], 
             UndirectedEdge[52, 89] -> 
             RGBColor[
              0.9804436289086855, 0.9849354709774921, 0.9179880145258416], 
             UndirectedEdge[99, 177] -> 
             RGBColor[
              0.9644312848736323, 0.8916805133266055, 0.3163226876326484], 
             UndirectedEdge[41, 206] -> 
             RGBColor[
              0.993858615967053, 0.9892725254797279, 0.5729264321217449], 
             UndirectedEdge[1, 119] -> 
             RGBColor[
              0.9783963728985401, 0.951486538508053, 0.6160413344192068], 
             UndirectedEdge[2, 109] -> 
             RGBColor[
              0.986207907480438, 0.9877160540524421, 0.8402332515428254], 
             UndirectedEdge[8, 100] -> 
             RGBColor[
              0.9897294323818616, 0.9887544367514116, 0.7278170437127549], 
             UndirectedEdge[203, 322] -> 
             RGBColor[
              0.9693658860228136, 0.918068304858382, 0.5747776894094869], 
             UndirectedEdge[98, 193] -> 
             RGBColor[
              0.9789678993435716, 0.9390471012477453, 0.5146996108548082], 
             UndirectedEdge[141, 285] -> 
             RGBColor[
              0.9250486676997325, 0.7329145351090787, 0.5483083942287696], 
             UndirectedEdge[29, 231] -> 
             RGBColor[
              0.9659574857407849, 0.9723602125838786, 0.8631771463313622], 
             UndirectedEdge[225, 398] -> 
             RGBColor[
              0.924231389680823, 0.7932043226007071, 0.6007079888700436], 
             UndirectedEdge[149, 359] -> 
             RGBColor[
              0.9780296788991282, 0.9820519247579196, 0.8735651173765322], 
             UndirectedEdge[87, 235] -> 
             RGBColor[
              0.9950056216366694, 0.9917258546269746, 0.6977709207610016], 
             UndirectedEdge[162, 312] -> 
             RGBColor[
              0.9918592995254101, 0.9905755867710382, 0.7608764384515165], 
             UndirectedEdge[392, 395] -> 
             RGBColor[
              0.5565865268925931, 0.6279002300637408, 0.9635457083464853], 
             UndirectedEdge[212, 268] -> 
             RGBColor[
              0.9913141475468847, 0.9906761910414801, 0.7936105836211047], 
             UndirectedEdge[50, 271] -> 
             RGBColor[
              0.9771994778214173, 0.9343105219279929, 0.40334800127595816`], 
             UndirectedEdge[200, 207] -> 
             RGBColor[
              0.9766855472691838, 0.9789231640228909, 0.7333684448805005], 
             UndirectedEdge[360, 370] -> 
             RGBColor[
              0.9695677047019705, 0.9090068634963184, 0.33627670873424775`], 
             UndirectedEdge[134, 246] -> 
             RGBColor[
              0.9894171329885786, 0.98972164207514, 0.8152270648487633], 
             UndirectedEdge[88, 191] -> 
             RGBColor[
              0.9926065225028029, 0.9865944241657648, 0.4366437855632632], 
             UndirectedEdge[277, 278] -> 
             RGBColor[
              0.9516582327176193, 0.9216858786550485, 0.6499409909033622], 
             UndirectedEdge[233, 242] -> 
             RGBColor[
              0.9561212530792478, 0.8562576708147414, 0.5186115944446962], 
             UndirectedEdge[66, 123] -> 
             RGBColor[
              0.9536472535282718, 0.8416192506872258, 0.42713865465264444`], 
             UndirectedEdge[315, 316] -> 
             RGBColor[
              0.9361250266755373, 0.7844640463812338, 0.2674629010060551], 
             UndirectedEdge[127, 216] -> 
             RGBColor[
              0.9931186634075304, 0.9876898417755887, 0.492387162475562], 
             UndirectedEdge[29, 326] -> 
             RGBColor[
              0.9903394723872226, 0.9902731378149507, 0.8097634733951619], 
             UndirectedEdge[76, 145] -> 
             RGBColor[
              0.9559753541405654, 0.8579139756681071, 0.31077705248906773`], 
             UndirectedEdge[21, 104] -> 
             RGBColor[
              0.9929665301774806, 0.9896494789076586, 0.641926301923349], 
             UndirectedEdge[27, 112] -> 
             RGBColor[
              0.9943846784470964, 0.9903977199314651, 0.6301850865931653], 
             UndirectedEdge[190, 221] -> 
             RGBColor[
              0.9942491242936227, 0.990107783303812, 0.6154308535308075], 
             UndirectedEdge[310, 324] -> 
             RGBColor[
              0.9562146285372217, 0.9341401951091539, 0.6614527233383535], 
             UndirectedEdge[11, 312] -> 
             RGBColor[
              0.9945222060937772, 0.9906918776615372, 0.645154122212107], 
             UndirectedEdge[177, 225] -> 
             RGBColor[
              0.9271615850603125, 0.746120632318694, 0.26308012336857034`], 
             UndirectedEdge[253, 316] -> 
             RGBColor[
              0.9614891386932074, 0.8769568964931181, 0.32988662737824387`], 
             UndirectedEdge[17, 323] -> 
             RGBColor[
              0.9820817849303669, 0.9512197945524674, 0.38489154733581027`], 
             UndirectedEdge[315, 397] -> 
             RGBColor[
              0.9353927636080668, 0.8618182762735844, 0.6269679924823188], 
             UndirectedEdge[43, 296] -> 
             RGBColor[
              0.9631706097299088, 0.8808844415654324, 0.5080298021330091], 
             UndirectedEdge[50, 287] -> 
             RGBColor[
              0.9936936236132707, 0.9889196235182731, 0.5549680326273014], 
             UndirectedEdge[253, 369] -> 
             RGBColor[
              0.9534331119189374, 0.9485376508398035, 0.6909916553105087], 
             UndirectedEdge[187, 220] -> 
             RGBColor[
              0.9924245433273601, 0.9860204142105586, 0.4325483991070391], 
             UndirectedEdge[211, 340] -> 
             RGBColor[
              0.9827625361844539, 0.960401798342718, 0.5928249612724049], 
             UndirectedEdge[213, 227] -> 
             RGBColor[
              0.8288845042275661, 0.6808953176534969, 0.5988097102156236], 
             UndirectedEdge[17, 389] -> 
             RGBColor[
              0.9873227949670146, 0.9728526869934137, 0.5902752799006028], 
             UndirectedEdge[117, 376] -> 
             RGBColor[
              0.9932859594258021, 0.9880476710424497, 0.510596301633085], 
             UndirectedEdge[186, 330] -> 
             RGBColor[
              0.9874398164068218, 0.9692936928481675, 0.40570648784249463`], 
             UndirectedEdge[24, 337] -> 
             RGBColor[
              0.9944593612911748, 0.990557458983355, 0.6383138532820063], 
             UndirectedEdge[73, 99] -> 
             RGBColor[
              0.9825929281889896, 0.9518974542644458, 0.4758680044048411], 
             UndirectedEdge[114, 155] -> 
             RGBColor[
              0.9568463255808421, 0.9143016456755105, 0.6189583463914821], 
             UndirectedEdge[123, 232] -> 
             RGBColor[
              0.9539850105396894, 0.8423416787821758, 0.46390142095079434`], 
             UndirectedEdge[53, 289] -> 
             RGBColor[
              0.9594259360472176, 0.9692605100547228, 0.9535654862480789], 
             UndirectedEdge[126, 376] -> 
             RGBColor[
              0.9873720613664249, 0.9873593012905539, 0.7522661751488344], 
             UndirectedEdge[207, 254] -> 
             RGBColor[
              0.9878132719421364, 0.9872222028640021, 0.7145321095846024], 
             UndirectedEdge[291, 304] -> 
             RGBColor[
              0.96069183480894, 0.874940160894825, 0.32328551923051735`], 
             UndirectedEdge[333, 368] -> 
             RGBColor[
              0.9331323314383974, 0.8172055999181781, 0.5974894704454367], 
             UndirectedEdge[26, 171] -> 
             RGBColor[
              0.9648070076499333, 0.9512257519687115, 0.6695741122489294], 
             UndirectedEdge[81, 384] -> 
             RGBColor[
              0.992687770711041, 0.9867682058677321, 0.4454871516241551], 
             UndirectedEdge[120, 233] -> 
             RGBColor[
              0.9889926677397154, 0.9897161994819058, 0.8320835118230562], 
             UndirectedEdge[224, 290] -> 
             RGBColor[
              0.9306041917198465, 0.7399639073741565, 0.389565989312078], 
             UndirectedEdge[393, 396] -> 
             RGBColor[
              0.9765179270745061, 0.9786771947828454, 0.7240546525858809], 
             UndirectedEdge[2, 365] -> 
             RGBColor[
              0.9806957437320685, 0.9851234977999709, 0.9175612498919314], 
             UndirectedEdge[210, 387] -> 
             RGBColor[
              0.9497839870944498, 0.8442877047622142, 0.5778862617917402], 
             UndirectedEdge[23, 307] -> 
             RGBColor[
              0.9838085759930453, 0.9845705991439387, 0.7478991291469238], 
             UndirectedEdge[120, 244] -> 
             RGBColor[
              0.9794893458561569, 0.9544923251593402, 0.6155798128760793], 
             UndirectedEdge[42, 248] -> 
             RGBColor[
              0.9418244053616862, 0.9558764984443768, 0.9744562159111432], 
             UndirectedEdge[49, 393] -> 
             RGBColor[
              0.9622895687737851, 0.9310782533783513, 0.6350517341025959], 
             UndirectedEdge[375, 377] -> 
             RGBColor[
              0.9775718080177825, 0.9346830516295959, 0.4799147297756752], 
             UndirectedEdge[269, 350] -> 
             RGBColor[
              0.9797645745285978, 0.9841628150649369, 0.9072156785205963], 
             UndirectedEdge[77, 207] -> 
             RGBColor[
              0.9903632327672458, 0.9885898120825626, 0.6862954796093441], 
             UndirectedEdge[200, 368] -> 
             RGBColor[
              0.9602363652328182, 0.9698649268143877, 0.9521936410306411], 
             UndirectedEdge[384, 389] -> 
             RGBColor[
              0.9921257951309311, 0.9888708705562947, 0.6245344648309912], 
             UndirectedEdge[1, 361] -> 
             RGBColor[
              0.9825255277833687, 0.9519159146769818, 0.45470359460024984`], 
             UndirectedEdge[150, 380] -> 
             RGBColor[
              0.9951792680270931, 0.9922487336018457, 0.7276813036993109], 
             UndirectedEdge[150, 381] -> 
             RGBColor[
              0.9948379812750275, 0.9913672888444633, 0.6795243019526827], 
             UndirectedEdge[232, 279] -> 
             RGBColor[
              0.9841573702715138, 0.9567840610340883, 0.5151613883035939], 
             UndirectedEdge[132, 341] -> 
             RGBColor[
              0.9583741984576203, 0.8610085759280894, 0.39256352164149366`], 
             UndirectedEdge[1, 14] -> 
             RGBColor[
              0.9495351090497173, 0.8331097574994568, 0.3017973548955175], 
             UndirectedEdge[171, 342] -> 
             RGBColor[
              0.9860683772345573, 0.9640270808823066, 0.4548358766813392], 
             UndirectedEdge[140, 325] -> 
             RGBColor[
              0.9894003593788994, 0.9898847904519055, 0.8253270062896385], 
             UndirectedEdge[89, 306] -> 
             RGBColor[
              0.9769203220208953, 0.9823077944694636, 0.9239520540612622], 
             UndirectedEdge[130, 147] -> 
             RGBColor[
              0.942923218507999, 0.795351828124439, 0.424573821556228], 
             UndirectedEdge[4, 183] -> 
             RGBColor[
              0.9943380502436706, 0.9919266525173556, 0.7434966903260394], 
             UndirectedEdge[80, 151] -> 
             RGBColor[
              0.9944825394567132, 0.9906070347357695, 0.6408366535618026], 
             UndirectedEdge[236, 286] -> 
             RGBColor[
              0.9533160520393891, 0.8925360929903035, 0.6100900672558828], 
             UndirectedEdge[108, 180] -> 
             RGBColor[
              0.9777718252181128, 0.9638987934986457, 0.6540047729221706], 
             UndirectedEdge[9, 320] -> 
             RGBColor[
              0.9156386046799883, 0.9294216325523653, 0.7035990799361065], 
             UndirectedEdge[35, 97] -> 
             RGBColor[
              0.9901015173621296, 0.9827350488805209, 0.6045888251970493], 
             UndirectedEdge[154, 236] -> 
             RGBColor[
              0.9765059855650453, 0.9810876663404838, 0.8838517512156516], 
             UndirectedEdge[60, 259] -> 
             RGBColor[
              0.9293325966167787, 0.7390484491038565, 0.495711420579082], 
             UndirectedEdge[179, 399] -> 
             RGBColor[
              0.9898975799192837, 0.9900904039233396, 0.8170867751699593], 
             UndirectedEdge[314, 352] -> 
             RGBColor[
              0.9786164665886604, 0.9415215342032752, 0.542886985887741], 
             UndirectedEdge[85, 88] -> 
             RGBColor[
              0.9929450027855897, 0.9873183992650398, 0.4734852754864444], 
             UndirectedEdge[70, 267] -> 
             RGBColor[
              0.9937209016216698, 0.9889779684200091, 0.5579370755011941], 
             UndirectedEdge[31, 192] -> 
             RGBColor[
              0.9765252953630872, 0.9814861498054002, 0.9010190526074958], 
             UndirectedEdge[221, 255] -> 
             RGBColor[
              0.944019474507596, 0.8010856990151668, 0.3914907778558748], 
             UndirectedEdge[11, 211] -> 
             RGBColor[
              0.9918052187053883, 0.9898943721763762, 0.7138812006530055], 
             UndirectedEdge[211, 312] -> 
             RGBColor[
              0.9921870785785125, 0.9907111318330335, 0.7554442912766102], 
             UndirectedEdge[123, 280] -> 
             RGBColor[
              0.9412700637029925, 0.8350150332483812, 0.5928231573047142], 
             UndirectedEdge[178, 278] -> 
             RGBColor[
              0.9661890065899055, 0.9706192094977525, 0.713395424503839], 
             UndirectedEdge[83, 364] -> 
             RGBColor[
              0.9842702705184876, 0.9582705689872213, 0.4215818812635071], 
             UndirectedEdge[10, 313] -> 
             RGBColor[
              0.9802197596693181, 0.979451169753369, 0.6790002674882796], 
             UndirectedEdge[32, 242] -> 
             RGBColor[
              0.9524736368691282, 0.8547492877723961, 0.5790620347745312], 
             UndirectedEdge[44, 369] -> 
             RGBColor[
              0.9453892137027378, 0.9584805209485364, 0.9665287106576532], 
             UndirectedEdge[110, 375] -> 
             RGBColor[
              0.9768369104191639, 0.9331111799756955, 0.3999256614282948], 
             UndirectedEdge[275, 290] -> 
             RGBColor[
              0.8873039739632513, 0.7098011103420737, 0.60103750206334], 
             UndirectedEdge[362, 369] -> 
             RGBColor[
              0.9581420306355609, 0.9643239636020594, 0.7176160680711889], 
             UndirectedEdge[266, 338] -> 
             RGBColor[
              0.9417913496800945, 0.9038512250313866, 0.6381317565793428], 
             UndirectedEdge[350, 395] -> 
             RGBColor[
              0.9539903971792509, 0.9651692265846258, 0.9614674146061393], 
             UndirectedEdge[141, 172] -> 
             RGBColor[
              0.9900786460456896, 0.9895233521764806, 0.7674247068107826], 
             UndirectedEdge[123, 275] -> 
             RGBColor[
              0.9101759603558233, 0.8110905406390101, 0.619989664143344], 
             UndirectedEdge[46, 315] -> 
             RGBColor[
              0.9426507908650257, 0.8672313011178955, 0.614682045532971], 
             UndirectedEdge[185, 205] -> 
             RGBColor[
              0.9110127455001393, 0.6760816902929396, 0.2468006932648923], 
             UndirectedEdge[3, 86] -> 
             RGBColor[
              0.9816777337781017, 0.9729012033079085, 0.660319710227298], 
             UndirectedEdge[316, 397] -> 
             RGBColor[
              0.9390021011665666, 0.8761280969525942, 0.6298721502039291], 
             UndirectedEdge[11, 214] -> 
             RGBColor[
              0.9519809136139075, 0.9604030433932658, 0.7974259053629158], 
             UndirectedEdge[3, 34] -> 
             RGBColor[
              0.9826108294001664, 0.9860214486372796, 0.8905708342880154], 
             UndirectedEdge[5, 100] -> 
             RGBColor[
              0.9855800490867468, 0.9859012090180139, 0.7456501568753462], 
             UndirectedEdge[25, 245] -> 
             RGBColor[
              0.9564453809600619, 0.9638053690823691, 0.7850826981284098], 
             UndirectedEdge[183, 325] -> 
             RGBColor[
              0.9918169365169728, 0.9908841072016985, 0.7852780692106021], 
             UndirectedEdge[149, 266] -> 
             RGBColor[
              0.9732530424531506, 0.9264360620988287, 0.5434384984035322], 
             UndirectedEdge[73, 78] -> 
             RGBColor[
              0.9762292663929449, 0.9791953982055644, 0.7827422635317451], 
             UndirectedEdge[40, 167] -> 
             RGBColor[
              0.9838115620782171, 0.9850804770059074, 0.7881739976862158], 
             UndirectedEdge[5, 175] -> 
             RGBColor[
              0.9854115825289673, 0.9870979776109883, 0.8404984550193915], 
             UndirectedEdge[279, 309] -> 
             RGBColor[
              0.9796570020889765, 0.9430404326623723, 0.3754717238788265], 
             UndirectedEdge[66, 257] -> 
             RGBColor[
              0.9941395890669511, 0.9898734985296717, 0.6035086200806679], 
             UndirectedEdge[238, 309] -> 
             RGBColor[
              0.8203847364404047, 0.8471143709909168, 0.6828490149843143], 
             UndirectedEdge[40, 355] -> 
             RGBColor[
              0.9833637998768487, 0.9841227589328836, 0.7394378453352671], 
             UndirectedEdge[31, 271] -> 
             RGBColor[
              0.9742735767543498, 0.9348828082891582, 0.5813864534226191], 
             UndirectedEdge[271, 391] -> 
             RGBColor[
              0.9755398009087802, 0.9291521463167607, 0.35947717476196667`], 
             UndirectedEdge[264, 348] -> 
             RGBColor[
              0.9856305103051692, 0.988325860979216, 0.8878031614980109], 
             UndirectedEdge[146, 302] -> 
             RGBColor[
              0.9844275617449599, 0.9576008541092069, 0.5242573609233323], 
             UndirectedEdge[86, 91] -> 
             RGBColor[
              0.9852967344240228, 0.9754534497645295, 0.6476197583405063], 
             UndirectedEdge[232, 257] -> 
             RGBColor[
              0.9944773460783687, 0.9905959266246217, 0.6402713863788179], 
             UndirectedEdge[201, 385] -> 
             RGBColor[
              0.9277991877617338, 0.8379556815189126, 0.6245397279176559], 
             UndirectedEdge[204, 297] -> 
             RGBColor[
              0.9705609145198681, 0.9490627823164322, 0.6461331527747867], 
             UndirectedEdge[241, 323] -> 
             RGBColor[
              0.9866848490492186, 0.9692962570421721, 0.5780892077966702], 
             UndirectedEdge[269, 395] -> 
             RGBColor[
              0.960020231134533, 0.9694000486077929, 0.9393386806074275], 
             UndirectedEdge[52, 342] -> 
             RGBColor[
              0.987671824014945, 0.9872708813423373, 0.727004282912039], 
             UndirectedEdge[201, 245] -> 
             RGBColor[
              0.9201071740745743, 0.8318222785989211, 0.623806056785433], 
             UndirectedEdge[131, 330] -> 
             RGBColor[
              0.9933599205045975, 0.9880851698717743, 0.5782550798564146], 
             UndirectedEdge[159, 349] -> 
             RGBColor[
              0.9619387087731015, 0.9706983450298843, 0.929778680947281], 
             UndirectedEdge[15, 33] -> 
             RGBColor[
              0.9927972675240078, 0.9878001340590002, 0.587217755437506], 
             UndirectedEdge[16, 212] -> 
             RGBColor[
              0.9196216415493947, 0.9362614822161377, 0.8952827941568589], 
             UndirectedEdge[246, 269] -> 
             RGBColor[
              0.9847191355275371, 0.9878579185455968, 0.8988288991058573], 
             UndirectedEdge[150, 294] -> 
             RGBColor[
              0.9594372112787743, 0.9670942240350427, 0.8585884881565691], 
             UndirectedEdge[77, 200] -> 
             RGBColor[
              0.9737294293626286, 0.9793938845599071, 0.9054331915789702], 
             UndirectedEdge[21, 285] -> 
             RGBColor[
              0.9288888718852114, 0.7327925434126508, 0.36036624746591317`], 
             UndirectedEdge[275, 280] -> 
             RGBColor[
              0.9383076563283723, 0.9527759703734436, 0.9638455257954586], 
             UndirectedEdge[171, 353] -> 
             RGBColor[
              0.9863682081117917, 0.9646683888111593, 0.48747061732662667`], 
             UndirectedEdge[197, 252] -> 
             RGBColor[
              0.9862105904974844, 0.9885657390461193, 0.8781897315119338], 
             UndirectedEdge[15, 361] -> 
             RGBColor[
              0.9938149210558898, 0.9904321896640131, 0.6592593373154576], 
             UndirectedEdge[348, 366] -> 
             RGBColor[
              0.9903511854061995, 0.9900044813360295, 0.7896887873369866], 
             UndirectedEdge[235, 298] -> 
             RGBColor[
              0.9915770626417719, 0.9905430016352044, 0.771668983823601], 
             UndirectedEdge[62, 298] -> 
             RGBColor[
              0.9915475809511449, 0.9904799432800092, 0.7684600837387454], 
             UndirectedEdge[110, 308] -> 
             RGBColor[
              0.987586229190323, 0.969371156250888, 0.44168473501572814`], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.9171849122985611, 0.933162587433622, 0.835038373181958], 
             UndirectedEdge[204, 290] -> 
             RGBColor[
              0.9174165489557182, 0.732993580711613, 0.5755324667056269], 
             UndirectedEdge[35, 93] -> 
             RGBColor[
              0.9910200806249309, 0.9810983198672565, 0.442781883835088], 
             UndirectedEdge[162, 211] -> 
             RGBColor[
              0.9891423121370211, 0.9897780812858773, 0.8296035168924151], 
             UndirectedEdge[66, 275] -> 
             RGBColor[
              0.9506848461536517, 0.9593801878122881, 0.7981610231433889], 
             UndirectedEdge[36, 277] -> 
             RGBColor[
              0.9786295694785638, 0.9388456601171562, 0.4334693334866107], 
             UndirectedEdge[174, 246] -> 
             RGBColor[
              0.9848476917748035, 0.9879110798575863, 0.8966983893957519], 
             UndirectedEdge[218, 329] -> 
             RGBColor[
              0.983606611410099, 0.9858405073337991, 0.8475248134089273], 
             UndirectedEdge[186, 188] -> 
             RGBColor[
              0.9856338618796205, 0.9719838851019422, 0.6170875795834041], 
             UndirectedEdge[230, 245] -> 
             RGBColor[
              0.9546926189893703, 0.9642680363503544, 0.9004477157356034], 
             UndirectedEdge[57, 368] -> 
             RGBColor[
              0.9583572843853698, 0.9684635113950733, 0.9553744347625952], 
             UndirectedEdge[293, 316] -> 
             RGBColor[
              0.9665268574539191, 0.893446479302895, 0.39229889581926997`], 
             UndirectedEdge[8, 308] -> 
             RGBColor[
              0.9838198026851146, 0.9696289682362885, 0.6360592160856939], 
             UndirectedEdge[37, 361] -> 
             RGBColor[
              0.9897402427679569, 0.9762528424156347, 0.4827313999307721], 
             UndirectedEdge[19, 331] -> 
             RGBColor[
              0.9769160250117609, 0.9821192865769617, 0.9156610723264659], 
             UndirectedEdge[98, 276] -> 
             RGBColor[
              0.99522475216784, 0.9921945526756536, 0.7216219267620556], 
             UndirectedEdge[326, 336] -> 
             RGBColor[
              0.9724977840292761, 0.9787383523885533, 0.9192969279140732], 
             UndirectedEdge[4, 13] -> 
             RGBColor[
              0.9946983307413709, 0.9920756377619411, 0.7375259101031049], 
             UndirectedEdge[137, 300] -> 
             RGBColor[
              0.9718199791147252, 0.9777875728828425, 0.9005040083424071], 
             UndirectedEdge[57, 163] -> 
             RGBColor[
              0.9636778393389815, 0.9724315725678676, 0.9463681230491072], 
             UndirectedEdge[28, 304] -> 
             RGBColor[
              0.9702785726455547, 0.9114047879897587, 0.33903829645892536`], 
             UndirectedEdge[83, 328] -> 
             RGBColor[
              0.9848861461955358, 0.959587864785845, 0.4886161479661157], 
             UndirectedEdge[206, 321] -> 
             RGBColor[
              0.944609466196948, 0.8035748774558025, 0.4005198035009078], 
             UndirectedEdge[295, 373] -> 
             RGBColor[
              0.9282231065629274, 0.9418645139723327, 0.8280148798488255], 
             UndirectedEdge[29, 235] -> 
             RGBColor[
              0.9949283062885748, 0.9919288270061907, 0.7161302038555326], 
             UndirectedEdge[234, 392] -> 
             RGBColor[
              0.5350953545473871, 0.6107637525980064, 0.9614958611428035], 
             UndirectedEdge[42, 275] -> 
             RGBColor[
              0.9164767055896288, 0.9362376642124519, 0.9918955603991939], 
             UndirectedEdge[107, 324] -> 
             RGBColor[
              0.9394253447823543, 0.8718657793574855, 0.6256038845048166], 
             UndirectedEdge[75, 329] -> 
             RGBColor[
              0.9886914080227789, 0.989591620846931, 0.8370761649678502], 
             UndirectedEdge[267, 383] -> 
             RGBColor[
              0.9596321531471993, 0.8646946085789484, 0.4705819731979611], 
             UndirectedEdge[253, 362] -> 
             RGBColor[
              0.9879528318690012, 0.9709262386882487, 0.4160306087895026], 
             UndirectedEdge[137, 252] -> 
             RGBColor[
              0.9703880315002049, 0.9771954257448632, 0.9242350860766437], 
             UndirectedEdge[131, 203] -> 
             RGBColor[
              0.9734529565926542, 0.9197584135719338, 0.5070443530676463], 
             UndirectedEdge[52, 199] -> 
             RGBColor[
              0.9312607044846101, 0.7686007023431805, 0.5689339506625541], 
             UndirectedEdge[41, 386] -> 
             RGBColor[
              0.9921211902097373, 0.9898321907696607, 0.6946270307012463], 
             UndirectedEdge[59, 122] -> 
             RGBColor[
              0.9938229405370664, 0.9891962193423256, 0.569043381730924], 
             UndirectedEdge[32, 172] -> 
             RGBColor[
              0.9896128299381659, 0.9893307252450916, 0.7751444852058942], 
             UndirectedEdge[55, 156] -> 
             RGBColor[
              0.9926187411892999, 0.9857594072120655, 0.5111998208318378], 
             UndirectedEdge[97, 214] -> 
             RGBColor[
              0.9504643990627087, 0.960760815062797, 0.8941495391104067], 
             UndirectedEdge[133, 155] -> 
             RGBColor[
              0.9717778624389148, 0.9783304788178283, 0.9262943663879317], 
             UndirectedEdge[186, 273] -> 
             RGBColor[
              0.9638660979164031, 0.8864294765182021, 0.33154540425009316`], 
             UndirectedEdge[74, 179] -> 
             RGBColor[
              0.9916388248780581, 0.9891553477741362, 0.6679211287001285], 
             UndirectedEdge[10, 62] -> 
             RGBColor[
              0.9820253783092736, 0.9840362900251116, 0.8140448203913702], 
             UndirectedEdge[273, 322] -> 
             RGBColor[
              0.9656991314443383, 0.9035308448282572, 0.5718273326058538], 
             UndirectedEdge[18, 148] -> 
             RGBColor[
              0.9564172960965234, 0.9412621676747358, 0.6759073989052204], 
             UndirectedEdge[78, 172] -> 
             RGBColor[
              0.9763988531519062, 0.9795581271351311, 0.8012007356765206], 
             UndirectedEdge[84, 269] -> 
             RGBColor[
              0.9855513309042805, 0.9882931182621308, 0.8891153690804587], 
             UndirectedEdge[103, 254] -> 
             RGBColor[
              0.9761536952502079, 0.9817360454791211, 0.9252497532157513], 
             UndirectedEdge[46, 343] -> 
             RGBColor[
              0.8850524463065069, 0.5492176882667834, 0.5645116738907485], 
             UndirectedEdge[1, 317] -> 
             RGBColor[
              0.9700067398792794, 0.9104878322397434, 0.3379822774932566], 
             UndirectedEdge[27, 399] -> 
             RGBColor[
              0.9918312490425136, 0.9895955956755282, 0.6909494683581451], 
             UndirectedEdge[247, 253] -> 
             RGBColor[
              0.9853784187650624, 0.9721221067500274, 0.6230064424063797], 
             UndirectedEdge[27, 357] -> 
             RGBColor[
              0.9930751645694171, 0.9901099867130736, 0.6703345689271619], 
             UndirectedEdge[41, 55] -> 
             RGBColor[
              0.9925122400193549, 0.9855316119784733, 0.49960782573236684`], 
             UndirectedEdge[183, 272] -> 
             RGBColor[
              0.987827605409926, 0.9888595355493535, 0.8346036852140124], 
             UndirectedEdge[131, 238] -> 
             RGBColor[
              0.8249289474376001, 0.861264637511203, 0.8500525221180893], 
             UndirectedEdge[13, 131] -> 
             RGBColor[
              0.9946797875965836, 0.9920679696950345, 0.7378332180003508], 
             UndirectedEdge[55, 328] -> 
             RGBColor[
              0.9926897784253668, 0.9859113486770462, 0.5189317855867155], 
             UndirectedEdge[40, 392] -> 
             RGBColor[
              0.5760104463274659, 0.6424240248567656, 0.9319651004426129], 
             UndirectedEdge[39, 347] -> 
             RGBColor[
              0.9854349572034219, 0.9616154207418048, 0.5492860296765566], 
             UndirectedEdge[195, 362] -> 
             RGBColor[
              0.9889646277092214, 0.9874441501690443, 0.6682370615765486], 
             UndirectedEdge[46, 250] -> 
             RGBColor[
              0.9729346151275964, 0.9778580865727813, 0.8645479365031883], 
             UndirectedEdge[22, 47] -> 
             RGBColor[
              0.9763988213115935, 0.9313094613458319, 0.4257693895090036], 
             UndirectedEdge[79, 100] -> 
             RGBColor[
              0.9684616781190803, 0.9006658515756563, 0.4205758364523364], 
             UndirectedEdge[45, 148] -> 
             RGBColor[
              0.9449641229123846, 0.9017127739619022, 0.636180106994557], 
             UndirectedEdge[65, 68] -> 
             RGBColor[
              0.9864971981166644, 0.97356565425332, 0.6112453416096386], 
             UndirectedEdge[86, 162] -> 
             RGBColor[
              0.9871662002537342, 0.9762265219281956, 0.6166378715197074], 
             UndirectedEdge[3, 264] -> 
             RGBColor[
              0.981680608468372, 0.9856367783763951, 0.9059870024624518], 
             UndirectedEdge[55, 386] -> 
             RGBColor[
              0.9907166225976136, 0.9859668111822797, 0.6149746207564788], 
             UndirectedEdge[315, 362] -> 
             RGBColor[
              0.962588719851331, 0.8784333885763643, 0.3536068824173138], 
             UndirectedEdge[92, 182] -> 
             RGBColor[
              0.9066706289030972, 0.6403586285971954, 0.2512943901333653], 
             UndirectedEdge[202, 341] -> 
             RGBColor[
              0.9585206705976578, 0.8626533115860467, 0.5052882196851799], 
             UndirectedEdge[86, 125] -> 
             RGBColor[
              0.9858384793483863, 0.9756774752129633, 0.6386416429528792], 
             UndirectedEdge[155, 353] -> 
             RGBColor[
              0.976324441796073, 0.979225716814675, 0.7793547172493439], 
             UndirectedEdge[119, 235] -> 
             RGBColor[
              0.9902718490166809, 0.9900032622587691, 0.7932997513759455], 
             UndirectedEdge[139, 204] -> 
             RGBColor[
              0.878731959802713, 0.9055646946232885, 0.9598539751870072], 
             UndirectedEdge[167, 174] -> 
             RGBColor[
              0.9902903762399575, 0.9896034320051833, 0.7633723597944396], 
             UndirectedEdge[218, 349] -> 
             RGBColor[
              0.9556649267953436, 0.9664555555127627, 0.9599318938831877], 
             UndirectedEdge[362, 397] -> 
             RGBColor[
              0.9654657943423604, 0.9700974391477248, 0.7160161316151878], 
             UndirectedEdge[70, 108] -> 
             RGBColor[
              0.9867266149899832, 0.9668461794081845, 0.40648319802669014`], 
             UndirectedEdge[71, 157] -> 
             RGBColor[
              0.9773318304809242, 0.9482380642815854, 0.6142729785838822], 
             UndirectedEdge[186, 238] -> 
             RGBColor[
              0.8190088433398244, 0.8424731604875961, 0.6775039301041694], 
             UndirectedEdge[51, 246] -> 
             RGBColor[
              0.9892088662398268, 0.9897145375759449, 0.8244224421525912], 
             UndirectedEdge[109, 305] -> 
             RGBColor[
              0.9829179038015385, 0.9852623746956055, 0.8458023696008159], 
             UndirectedEdge[125, 248] -> 
             RGBColor[
              0.9720340218992705, 0.97833679451067, 0.9175882752958257], 
             UndirectedEdge[106, 390] -> 
             RGBColor[
              0.9949477495209749, 0.9916020720232726, 0.6914718981129542], 
             UndirectedEdge[1, 231] -> 
             RGBColor[
              0.9541552868344605, 0.9336318792887659, 0.6671199200667126], 
             UndirectedEdge[104, 399] -> 
             RGBColor[
              0.9912571097125112, 0.9906526044311612, 0.794555848145857], 
             UndirectedEdge[244, 366] -> 
             RGBColor[
              0.9839706590136712, 0.9560719632011885, 0.5214322855679647], 
             UndirectedEdge[64, 289] -> 
             RGBColor[
              0.9622412906109532, 0.9406811463470788, 0.6555950142596751], 
             UndirectedEdge[160, 233] -> 
             RGBColor[
              0.9646626532602478, 0.971871677881794, 0.8867366778956407], 
             UndirectedEdge[100, 302] -> 
             RGBColor[
              0.9838420676838947, 0.9563485415151185, 0.46052994562688543`], 
             UndirectedEdge[177, 337] -> 
             RGBColor[
              0.9760220287228236, 0.9297508466098197, 0.44876146267826295`], 
             UndirectedEdge[124, 219] -> 
             RGBColor[
              0.9791360140737908, 0.9807314424328679, 0.7276909977782126], 
             UndirectedEdge[2, 181] -> 
             RGBColor[
              0.9836870927038954, 0.986673632360357, 0.8820096760496571], 
             UndirectedEdge[185, 198] -> 
             RGBColor[
              0.9326572987048518, 0.7548966356130409, 0.5016551142825514], 
             UndirectedEdge[11, 35] -> 
             RGBColor[
              0.9916180319133283, 0.9823772772109898, 0.5078651914495583], 
             UndirectedEdge[5, 56] -> 
             RGBColor[
              0.9856861865734299, 0.9861282263698834, 0.7572025672961761], 
             UndirectedEdge[69, 107] -> 
             RGBColor[
              0.9366148468974655, 0.8697697146367034, 0.6303613243286879], 
             UndirectedEdge[51, 350] -> 
             RGBColor[
              0.9842543052408874, 0.986019434095285, 0.8328092215673302], 
             UndirectedEdge[226, 392] -> 
             RGBColor[
              0.5443742405035811, 0.6181624843908259, 0.9623808895686645], 
             UndirectedEdge[81, 292] -> 
             RGBColor[
              0.9885746402219953, 0.9872082783274595, 0.6692773861139821], 
             UndirectedEdge[51, 272] -> 
             RGBColor[
              0.9883547027543983, 0.9890775038470766, 0.8258683181319055], 
             UndirectedEdge[10, 261] -> 
             RGBColor[
              0.9814542804010189, 0.9828147693462107, 0.7518843374855928], 
             UndirectedEdge[132, 244] -> 
             RGBColor[
              0.9832110172379085, 0.9544471662543967, 0.43874996624180485`], 
             UndirectedEdge[53, 376] -> 
             RGBColor[
              0.9801919826090142, 0.9820044103095771, 0.764420175620672], 
             UndirectedEdge[242, 364] -> 
             RGBColor[
              0.9566498222297961, 0.8545422192154182, 0.3692683784802381], 
             UndirectedEdge[29, 327] -> 
             RGBColor[
              0.9949087941337641, 0.9921626697833582, 0.7340379870293499], 
             UndirectedEdge[328, 364] -> 
             RGBColor[
              0.9936560087664539, 0.9888391691643764, 0.5508738886832231], 
             UndirectedEdge[257, 279] -> 
             RGBColor[
              0.9838030630009471, 0.9560262336083061, 0.47659722843342256`], 
             UndirectedEdge[13, 322] -> 
             RGBColor[
              0.990592717026743, 0.9903778609814827, 0.8055665543421916], 
             UndirectedEdge[21, 24] -> 
             RGBColor[
              0.9940249527252014, 0.989628302986181, 0.5910311617347013], 
             UndirectedEdge[56, 122] -> 
             RGBColor[
              0.993515204382851, 0.9885380028253566, 0.5355482004719696], 
             UndirectedEdge[87, 393] -> 
             RGBColor[
              0.9774499083615698, 0.9806706085181123, 0.8254950641609634], 
             UndirectedEdge[27, 74] -> 
             RGBColor[
              0.9935724940012881, 0.9886605395263248, 0.5417838218883144], 
             UndirectedEdge[93, 288] -> 
             RGBColor[
              0.9863510125375998, 0.985870510604801, 0.6962868651573538], 
             UndirectedEdge[125, 211] -> 
             RGBColor[
              0.9878145912316734, 0.9892290345706451, 0.8516072883255867], 
             UndirectedEdge[265, 304] -> 
             RGBColor[
              0.9730400072694811, 0.9583882748755452, 0.6578080793853152], 
             UndirectedEdge[195, 343] -> 
             RGBColor[
              0.9012932524164092, 0.5611513744437919, 0.5290185508014571], 
             UndirectedEdge[199, 393] -> 
             RGBColor[
              0.9203043011778531, 0.7604294346964651, 0.5874802835732514], 
             UndirectedEdge[24, 208] -> 
             RGBColor[
              0.9466894396572686, 0.8118790505262325, 0.4535424722841224], 
             UndirectedEdge[135, 386] -> 
             RGBColor[
              0.9880942916984794, 0.9893446979016436, 0.8469719277490058], 
             UndirectedEdge[32, 357] -> 
             RGBColor[
              0.9885282777230068, 0.9895241622757176, 0.8397796562027576], 
             UndirectedEdge[230, 233] -> 
             RGBColor[
              0.991191490470625, 0.9906254691883036, 0.795643328801066], 
             UndirectedEdge[46, 161] -> 
             RGBColor[
              0.9734182778543816, 0.9769958357013163, 0.7793174623421596], 
             UndirectedEdge[114, 306] -> 
             RGBColor[
              0.9649702317891583, 0.9203604416239972, 0.6052066922348853], 
             UndirectedEdge[233, 357] -> 
             RGBColor[
              0.9921758939331263, 0.9910325453180628, 0.7793292158729226], 
             UndirectedEdge[134, 395] -> 
             RGBColor[
              0.9647182285955744, 0.9712637721373363, 0.8557368463503336], 
             UndirectedEdge[108, 267] -> 
             RGBColor[
              0.9878769214093608, 0.9693065685254139, 0.5316869529076076], 
             UndirectedEdge[217, 233] -> 
             RGBColor[
              0.9690281314922998, 0.9074291427602261, 0.5289967717792123], 
             UndirectedEdge[245, 400] -> 
             RGBColor[
              0.9427118463784484, 0.918344516449795, 0.6581274688374446], 
             UndirectedEdge[269, 392] -> 
             RGBColor[
              0.58236070424194, 0.646893818544052, 0.9092939722609422], 
             UndirectedEdge[232, 288] -> 
             RGBColor[
              0.9872946173901385, 0.9878887859712963, 0.7989924301020674], 
             UndirectedEdge[260, 341] -> 
             RGBColor[
              0.8220674037640618, 0.7577333123848975, 0.6149776157294229], 
             UndirectedEdge[47, 323] -> 
             RGBColor[
              0.9700321664833949, 0.9105736021458753, 0.33808105504883373`], 
             UndirectedEdge[142, 377] -> 
             RGBColor[
              0.9471079485894989, 0.8139025912507387, 0.4483519910189653], 
             UndirectedEdge[53, 117] -> 
             RGBColor[
              0.9794893610446189, 0.980501573829273, 0.6879441544139197], 
             UndirectedEdge[251, 308] -> 
             RGBColor[
              0.8878578602240207, 0.8948531364160603, 0.6823138503083476], 
             UndirectedEdge[85, 162] -> 
             RGBColor[
              0.9910592479497475, 0.9888643573483187, 0.6737957617866537], 
             UndirectedEdge[249, 397] -> 
             RGBColor[
              0.9661586109715457, 0.9715793038630459, 0.7914249461333893], 
             UndirectedEdge[262, 284] -> 
             RGBColor[
              0.951579161316271, 0.8413043408613909, 0.3029702152328093], 
             UndirectedEdge[307, 341] -> 
             RGBColor[
              0.9585515688816215, 0.8613879533301273, 0.4118691976906551], 
             UndirectedEdge[7, 387] -> 
             RGBColor[
              0.9381786739883745, 0.794692111808835, 0.5683629374812456], 
             UndirectedEdge[228, 368] -> 
             RGBColor[
              0.9775824643057482, 0.980584382747425, 0.810584916777545], 
             UndirectedEdge[240, 399] -> 
             RGBColor[
              0.9924580179700415, 0.990936191035451, 0.7591693981501036], 
             UndirectedEdge[105, 114] -> 
             RGBColor[
              0.9749112277087162, 0.9260389032240749, 0.5106591874219321], 
             UndirectedEdge[78, 357] -> 
             RGBColor[
              0.9753143009367471, 0.9797515641657571, 0.8658359066733841], 
             UndirectedEdge[359, 369] -> 
             RGBColor[
              0.944484781962934, 0.9578059972378618, 0.9680596776795645], 
             UndirectedEdge[48, 354] -> 
             RGBColor[
              0.9564694124880462, 0.9147332145084571, 0.6201492877548224], 
             UndirectedEdge[280, 325] -> 
             RGBColor[
              0.9796579787449862, 0.9833988694164291, 0.8767451962992333], 
             UndirectedEdge[259, 262] -> 
             RGBColor[
              0.9621436776142829, 0.8799742374285643, 0.5226727691422133], 
             UndirectedEdge[120, 187] -> 
             RGBColor[
              0.9891029745489324, 0.9869213521274331, 0.6529269449660675], 
             UndirectedEdge[70, 198] -> 
             RGBColor[
              0.9921398659397509, 0.9886785542502035, 0.6098989560763993], 
             UndirectedEdge[62, 235] -> 
             RGBColor[
              0.9949721018097641, 0.9916541591065988, 0.694122494462766], 
             UndirectedEdge[65, 176] -> 
             RGBColor[
              0.9894474544559108, 0.9745321675070537, 0.5439256532027168], 
             UndirectedEdge[199, 342] -> 
             RGBColor[
              0.9371295649358491, 0.7699223231480177, 0.3802512180484424], 
             UndirectedEdge[324, 390] -> 
             RGBColor[
              0.9684815837933849, 0.9739769772472808, 0.8402738558212132], 
             UndirectedEdge[226, 234] -> 
             RGBColor[
              0.9005425950509681, 0.9235322369888322, 0.9903757507114681], 
             UndirectedEdge[47, 201] -> 
             RGBColor[
              0.9401620631472913, 0.7995433594189606, 0.27553481539813574`], 
             UndirectedEdge[160, 264] -> 
             RGBColor[
              0.9614329642681384, 0.9705361184843355, 0.9402609826620759], 
             UndirectedEdge[277, 314] -> 
             RGBColor[
              0.9781762560833676, 0.9400366008025802, 0.5411768512014565], 
             UndirectedEdge[4, 66] -> 
             RGBColor[
              0.9945562822969634, 0.9910456321709304, 0.669279314762601], 
             UndirectedEdge[23, 75] -> 
             RGBColor[
              0.9791281160473493, 0.9839132441644476, 0.9183734205562162], 
             UndirectedEdge[287, 391] -> 
             RGBColor[
              0.9920339467006336, 0.9837612479070408, 0.51109720611331], 
             UndirectedEdge[45, 91] -> 
             RGBColor[
              0.9689719524222267, 0.9194709756015922, 0.5889671860993759], 
             UndirectedEdge[175, 314] -> 
             RGBColor[
              0.9931273161570446, 0.9914259828580889, 0.7635616874208091], 
             UndirectedEdge[195, 358] -> 
             RGBColor[
              0.9890621017736392, 0.9876526373366942, 0.6788465119482248], 
             UndirectedEdge[321, 341] -> 
             RGBColor[
              0.9093606107759419, 0.6758147713923282, 0.24579637262520732`], 
             UndirectedEdge[91, 148] -> 
             RGBColor[
              0.9610677719146536, 0.9703381902568599, 0.9442123586041], 
             UndirectedEdge[115, 350] -> 
             RGBColor[
              0.9563369314393154, 0.8877764954266472, 0.5995358004621982], 
             UndirectedEdge[142, 277] -> 
             RGBColor[
              0.9315716539667471, 0.7628185531965312, 0.2754528290850525], 
             UndirectedEdge[45, 66] -> 
             RGBColor[
              0.973512221373029, 0.9203772285835692, 0.44312247407126115`], 
             UndirectedEdge[259, 335] -> 
             RGBColor[
              0.9932165034648286, 0.9906672159162658, 0.7042483991175221], 
             UndirectedEdge[118, 173] -> 
             RGBColor[
              0.9915057316024454, 0.9825114651338772, 0.46380683329300043`], 
             UndirectedEdge[52, 128] -> 
             RGBColor[
              0.9872399977759501, 0.9863472486814571, 0.6800026617200639], 
             UndirectedEdge[27, 225] -> 
             RGBColor[
              0.9451146344109456, 0.8058914118580738, 0.3999212743732495], 
             UndirectedEdge[302, 352] -> 
             RGBColor[
              0.9691627515577312, 0.9076408614532794, 0.3347035422378625], 
             UndirectedEdge[25, 242] -> 
             RGBColor[
              0.9570825107322554, 0.8554676961706607, 0.4163638517290378], 
             UndirectedEdge[30, 224] -> 
             RGBColor[
              0.9935409480211872, 0.9903305964197566, 0.6646503656828495], 
             UndirectedEdge[313, 361] -> 
             RGBColor[
              0.9925659035709269, 0.9857844598007599, 0.4937085585690424], 
             UndirectedEdge[270, 310] -> 
             RGBColor[
              0.9726124105248299, 0.9463696340666082, 0.6336955556598267], 
             UndirectedEdge[72, 370] -> 
             RGBColor[
              0.9614016033451769, 0.9451742850443094, 0.667883852335203], 
             UndirectedEdge[283, 380] -> 
             RGBColor[
              0.9949239545374338, 0.991702643863618, 0.6998920059621132], 
             UndirectedEdge[34, 35] -> 
             RGBColor[
              0.9882398881368415, 0.9819652173541755, 0.6354408392020714], 
             UndirectedEdge[25, 230] -> 
             RGBColor[
              0.9921527481236327, 0.9898354945442228, 0.6933955860854076], 
             UndirectedEdge[191, 211] -> 
             RGBColor[
              0.9910485467200632, 0.988275927311039, 0.6315221246885662], 
             UndirectedEdge[17, 173] -> 
             RGBColor[
              0.9882516958248144, 0.9715348383719936, 0.4511655187699988], 
             UndirectedEdge[40, 51] -> 
             RGBColor[
              0.9839338812816956, 0.9857804624311657, 0.8333516157502892], 
             UndirectedEdge[105, 202] -> 
             RGBColor[
              0.9941884846809708, 0.9918648033135196, 0.7459753787632453], 
             UndirectedEdge[183, 309] -> 
             RGBColor[
              0.9897752961016879, 0.9777687179301628, 0.5766004910895102], 
             UndirectedEdge[187, 261] -> 
             RGBColor[
              0.9930020163546851, 0.9872555706245277, 0.49540277438095454`], 
             UndirectedEdge[190, 274] -> 
             RGBColor[
              0.9941930591613416, 0.989987865654917, 0.6093285098758958], 
             UndirectedEdge[176, 354] -> 
             RGBColor[
              0.975307539785369, 0.9267355313539911, 0.48951234711505764`], 
             UndirectedEdge[42, 148] -> 
             RGBColor[
              0.9313999003014329, 0.9481019196390006, 0.9921021838317903], 
             UndirectedEdge[320, 380] -> 
             RGBColor[
              0.993453463106539, 0.9881238521416122, 0.5767048368617516], 
             UndirectedEdge[51, 222] -> 
             RGBColor[
              0.9675573790672839, 0.8966427038627339, 0.5035645563919933], 
             UndirectedEdge[122, 319] -> 
             RGBColor[
              0.9918939810637558, 0.9889508923898642, 0.641161054514817], 
             UndirectedEdge[27, 78] -> 
             RGBColor[
              0.9760206724282205, 0.978749236807104, 0.7600380977642316], 
             UndirectedEdge[5, 178] -> 
             RGBColor[
              0.9849912963275764, 0.9846419263981836, 0.6815680524005155], 
             UndirectedEdge[196, 336] -> 
             RGBColor[
              0.9767396411101709, 0.9796518932455728, 0.7878973727603762], 
             UndirectedEdge[297, 318] -> 
             RGBColor[
              0.9795824862504576, 0.9555767653874747, 0.6212656251573679], 
             UndirectedEdge[127, 235] -> 
             RGBColor[
              0.9940297004469111, 0.9896384578828498, 0.5915479219432618], 
             UndirectedEdge[45, 203] -> 
             RGBColor[
              0.952427438813507, 0.849097678051479, 0.28058020447906046`], 
             UndirectedEdge[305, 370] -> 
             RGBColor[
              0.9742136201582411, 0.9547294662057406, 0.6461964497798407], 
             UndirectedEdge[122, 169] -> 
             RGBColor[
              0.9863539700535955, 0.9653215873070198, 0.4277880388658677], 
             UndirectedEdge[51, 226] -> 
             RGBColor[
              0.9522976754578107, 0.961518921965226, 0.8637674048763408], 
             UndirectedEdge[226, 395] -> 
             RGBColor[
              0.9220337673961742, 0.9406687144545668, 0.99242559791515], 
             UndirectedEdge[61, 354] -> 
             RGBColor[
              0.9479839049024011, 0.8314805468138416, 0.27700483279103827`], 
             UndirectedEdge[211, 334] -> 
             RGBColor[
              0.9635540791911842, 0.9714623897424588, 0.9073090173753794], 
             UndirectedEdge[10, 361] -> 
             RGBColor[
              0.9814542804010189, 0.9828147693462107, 0.7518843374855928], 
             UndirectedEdge[44, 249] -> 
             RGBColor[
              0.9806017502819868, 0.9823509735123028, 0.7669764786548487], 
             UndirectedEdge[302, 377] -> 
             RGBColor[
              0.9842588356751901, 0.9572399661067919, 0.5058925694854908], 
             UndirectedEdge[149, 363] -> 
             RGBColor[
              0.9914478787682877, 0.9878614991523019, 0.6138616955559822], 
             UndirectedEdge[358, 359] -> 
             RGBColor[
              0.9791019759774153, 0.980403072253957, 0.7037080815302346], 
             UndirectedEdge[126, 317] -> 
             RGBColor[
              0.9747591951185508, 0.9457299947887396, 0.6253050109051003], 
             UndirectedEdge[194, 364] -> 
             RGBColor[
              0.9899675143509525, 0.988185295081385, 0.6753443234059391], 
             UndirectedEdge[184, 343] -> 
             RGBColor[
              0.873690237606199, 0.4472755426943155, 0.21340101258448374`], 
             UndirectedEdge[118, 346] -> 
             RGBColor[
              0.981525289561954, 0.9782847264686021, 0.672247307303808], 
             UndirectedEdge[169, 239] -> 
             RGBColor[
              0.9536703018409554, 0.8470046834095205, 0.31814329323940105`], 
             UndirectedEdge[72, 157] -> 
             RGBColor[
              0.9581166130162435, 0.9340932413124082, 0.6551222852256675], 
             UndirectedEdge[162, 191] -> 
             RGBColor[
              0.9907207676669607, 0.9881403822490437, 0.6369542718634724], 
             UndirectedEdge[84, 272] -> 
             RGBColor[
              0.9836218944625091, 0.9871203659907553, 0.9043031996437458], 
             UndirectedEdge[21, 160] -> 
             RGBColor[
              0.9653210573431309, 0.9704339300744097, 0.7515251930675078], 
             UndirectedEdge[29, 336] -> 
             RGBColor[
              0.9770133407188117, 0.98060565112419, 0.8444624676823549], 
             UndirectedEdge[275, 276] -> 
             RGBColor[
              0.9512280255211333, 0.9605419935554731, 0.8572827451792804], 
             UndirectedEdge[38, 303] -> 
             RGBColor[
              0.9866013327274336, 0.9887145318484678, 0.8711413972258528], 
             UndirectedEdge[172, 285] -> 
             RGBColor[
              0.9295079191623048, 0.7341166229430728, 0.4277457232605745], 
             UndirectedEdge[73, 285] -> 
             RGBColor[
              0.9293383324033435, 0.7337538940135061, 0.4092872511157991], 
             UndirectedEdge[5, 59] -> 
             RGBColor[
              0.9859939227276454, 0.9867864428868522, 0.7906977485551305], 
             UndirectedEdge[73, 225] -> 
             RGBColor[
              0.9453232283756698, 0.8063375732565341, 0.42262544014076303`], 
             UndirectedEdge[64, 254] -> 
             RGBColor[
              0.9771666432828869, 0.951812449931785, 0.6303302853415147], 
             UndirectedEdge[241, 390] -> 
             RGBColor[
              0.9937013884383707, 0.9914221536046002, 0.7365134660940325], 
             UndirectedEdge[58, 289] -> 
             RGBColor[
              0.972737472134042, 0.975769108067587, 0.7234215961837744], 
             UndirectedEdge[262, 331] -> 
             RGBColor[
              0.9587607127144987, 0.8785752945042713, 0.5787372523641555], 
             UndirectedEdge[22, 118] -> 
             RGBColor[
              0.9917024755361963, 0.9829322805143076, 0.4852211963189818], 
             UndirectedEdge[97, 360] -> 
             RGBColor[
              0.9771598865507902, 0.9390798893144544, 0.554313033316906], 
             UndirectedEdge[301, 358] -> 
             RGBColor[
              0.9899516876924341, 0.9880205039754313, 0.6641037710992319], 
             UndirectedEdge[16, 274] -> 
             RGBColor[
              0.9210775779544518, 0.9353523125228959, 0.7613031972338202], 
             UndirectedEdge[166, 319] -> 
             RGBColor[
              0.9891163658420727, 0.9897673518261267, 0.8300335141465693], 
             UndirectedEdge[82, 101] -> 
             RGBColor[
              0.9942569362535791, 0.9901244922962484, 0.6162811371622345], 
             UndirectedEdge[24, 399] -> 
             RGBColor[
              0.992315532260232, 0.9906314285096836, 0.7436607079572093], 
             UndirectedEdge[328, 400] -> 
             RGBColor[
              0.9803551626872997, 0.9443037934870446, 0.47101413264105757`], 
             UndirectedEdge[17, 371] -> 
             RGBColor[
              0.9888309090896763, 0.9727737169780888, 0.5142093081602838], 
             UndirectedEdge[107, 158] -> 
             RGBColor[
              0.9606568258900177, 0.8876616814368825, 0.5879403372415215], 
             UndirectedEdge[60, 394] -> 
             RGBColor[
              0.9291961986064425, 0.7355550441596266, 0.31652013703240056`], 
             UndirectedEdge[219, 284] -> 
             RGBColor[
              0.9821179715034967, 0.9508551138425168, 0.4264215358183956], 
             UndirectedEdge[124, 149] -> 
             RGBColor[
              0.9778462275770329, 0.9819151070622749, 0.8738756526130719], 
             UndirectedEdge[227, 296] -> 
             RGBColor[
              0.8874761194364302, 0.9103228706738082, 0.8651698958305175], 
             UndirectedEdge[202, 229] -> 
             RGBColor[
              0.9879927433614211, 0.9717277020080077, 0.5694817507170258], 
             UndirectedEdge[315, 358] -> 
             RGBColor[
              0.9626861939157487, 0.8786418757440142, 0.3642163327889899], 
             UndirectedEdge[145, 222] -> 
             RGBColor[
              0.9392875300874339, 0.7970023185676143, 0.27000752548476303`], 
             UndirectedEdge[155, 299] -> 
             RGBColor[
              0.9763222816811881, 0.9792210965473572, 0.7791196020748057], 
             UndirectedEdge[14, 29] -> 
             RGBColor[
              0.9613373079560417, 0.8718380907945695, 0.49785458116016723`], 
             UndirectedEdge[116, 151] -> 
             RGBColor[
              0.9872420723842097, 0.9878412590197287, 0.7984197133159007], 
             UndirectedEdge[45, 257] -> 
             RGBColor[
              0.9734956711138798, 0.920341829252737, 0.44132108049923974`], 
             UndirectedEdge[27, 240] -> 
             RGBColor[
              0.9944083049884186, 0.9904482547143434, 0.632756689809968], 
             UndirectedEdge[144, 188] -> 
             RGBColor[
              0.9583610940968412, 0.8718751221234102, 0.5533818842942373], 
             UndirectedEdge[76, 200] -> 
             RGBColor[
              0.966884140098469, 0.9463645416389443, 0.6524501465136849], 
             UndirectedEdge[90, 221] -> 
             RGBColor[
              0.9301309978234884, 0.9426464766121915, 0.768263716615557], 
             UndirectedEdge[271, 382] -> 
             RGBColor[
              0.9767758228607104, 0.93591755135893, 0.5399177598348817], 
             UndirectedEdge[242, 385] -> 
             RGBColor[
              0.9273143952851524, 0.8360336408967837, 0.6241496525114565], 
             UndirectedEdge[74, 112] -> 
             RGBColor[
              0.9941756363874938, 0.9899506001033693, 0.6074321484634702], 
             UndirectedEdge[237, 251] -> 
             RGBColor[
              0.8866575139090327, 0.9115409921813089, 0.9497502508265149], 
             UndirectedEdge[25, 223] -> 
             RGBColor[
              0.9939052577890795, 0.9893722876208308, 0.5780031066093586], 
             UndirectedEdge[284, 332] -> 
             RGBColor[
              0.9539693192006462, 0.8507805204000394, 0.30489339237079394`], 
             UndirectedEdge[145, 333] -> 
             RGBColor[
              0.9220389241122421, 0.7286173436331886, 0.2561288922403049], 
             UndirectedEdge[146, 227] -> 
             RGBColor[
              0.8880417548566306, 0.910300537365546, 0.8371700488944448], 
             UndirectedEdge[108, 286] -> 
             RGBColor[
              0.9620894592061808, 0.8800352350290667, 0.3267330690597632], 
             UndirectedEdge[127, 361] -> 
             RGBColor[
              0.9934291208480293, 0.9883538788487536, 0.5261785389526288], 
             UndirectedEdge[143, 258] -> 
             RGBColor[
              0.9736174959329199, 0.9325466534635333, 0.5779872543224486], 
             UndirectedEdge[212, 310] -> 
             RGBColor[
              0.9805434094036417, 0.9512169102357697, 0.5724589035176326], 
             UndirectedEdge[107, 310] -> 
             RGBColor[
              0.9536791875066668, 0.849770944860105, 0.3039271778891248], 
             UndirectedEdge[253, 394] -> 
             RGBColor[
              0.9875222075916605, 0.9695716176609986, 0.4060265620373234], 
             UndirectedEdge[152, 284] -> 
             RGBColor[
              0.9596689623989767, 0.8733777063879156, 0.3094794590759915], 
             UndirectedEdge[230, 364] -> 
             RGBColor[
              0.9917200596211734, 0.9889100175889805, 0.6463001128366079], 
             UndirectedEdge[158, 241] -> 
             RGBColor[
              0.9884120715655585, 0.9894761080432508, 0.8417054929635694], 
             UndirectedEdge[44, 315] -> 
             RGBColor[
              0.949835902918508, 0.8725899459228413, 0.6025195250037783], 
             UndirectedEdge[357, 385] -> 
             RGBColor[
              0.9633690361390309, 0.9708085154001053, 0.884867273939683], 
             UndirectedEdge[99, 197] -> 
             RGBColor[
              0.9788840611634153, 0.9512982701257062, 0.6052638269365319], 
             UndirectedEdge[152, 267] -> 
             RGBColor[
              0.9716324336917046, 0.912271722081476, 0.48023768060685756`], 
             UndirectedEdge[169, 197] -> 
             RGBColor[
              0.98324239237422, 0.9659999446845828, 0.6221951206887192], 
             UndirectedEdge[263, 348] -> 
             RGBColor[0.96336188246299, 0.8960538408488716, 0.57870305218183],
              UndirectedEdge[314, 379] -> 
             RGBColor[
              0.9933230557025111, 0.9902875484280553, 0.6716818856771474], 
             UndirectedEdge[300, 319] -> 
             RGBColor[
              0.9896439515571939, 0.9899855220776638, 0.8212900534989473], 
             UndirectedEdge[25, 78] -> 
             RGBColor[
              0.9760826594449374, 0.9788818207680126, 0.7667850019943339], 
             UndirectedEdge[44, 113] -> 
             RGBColor[
              0.9771010735997687, 0.9819684405459971, 0.9024123178413492], 
             UndirectedEdge[115, 221] -> 
             RGBColor[
              0.9662907364628703, 0.8922154767912984, 0.40955723609071915`], 
             UndirectedEdge[175, 319] -> 
             RGBColor[
              0.992130436104202, 0.9910137473375897, 0.7800825697392867], 
             UndirectedEdge[176, 356] -> 
             RGBColor[0.992478798529886, 0.9909043105924418, 0.7558829969657],
              UndirectedEdge[84, 395] -> 
             RGBColor[
              0.9597771535549335, 0.9692995297818197, 0.9433671051660018], 
             UndirectedEdge[301, 359] -> 
             RGBColor[
              0.9761969649553894, 0.9812940504435836, 0.9039379303359313], 
             UndirectedEdge[238, 280] -> 
             RGBColor[
              0.812170157786245, 0.8535313538288383, 0.9514604157630014], 
             UndirectedEdge[36, 168] -> 
             RGBColor[
              0.982513148744701, 0.9835235181499709, 0.7436686377289676], 
             UndirectedEdge[4, 232] -> 
             RGBColor[
              0.9948940393083809, 0.9917680602658805, 0.7060420810607508], 
             UndirectedEdge[140, 339] -> 
             RGBColor[
              0.963412595118805, 0.8906634200287951, 0.551382419683184], 
             UndirectedEdge[18, 141] -> 
             RGBColor[
              0.9806970221856763, 0.9591328055373942, 0.6241884480450688], 
             UndirectedEdge[123, 140] -> 
             RGBColor[
              0.9510124443369056, 0.8415009542838578, 0.5414049672951193], 
             UndirectedEdge[24, 78] -> 
             RGBColor[
              0.976504955645939, 0.9797850696412596, 0.8127493373632958], 
             UndirectedEdge[62, 127] -> 
             RGBColor[
              0.994000218756284, 0.9895753995276546, 0.5883390218584061], 
             UndirectedEdge[299, 353] -> 
             RGBColor[
              0.9941381861057681, 0.9898704977375623, 0.6033559164139641], 
             UndirectedEdge[256, 311] -> 
             RGBColor[
              0.9708624217935766, 0.9746269446100022, 0.7469275926968686], 
             UndirectedEdge[47, 346] -> 
             RGBColor[
              0.9662216353373511, 0.9266619073001263, 0.6127955004938299], 
             UndirectedEdge[34, 125] -> 
             RGBColor[
              0.9867715749704511, 0.9887977205423344, 0.8688927670135966], 
             UndirectedEdge[194, 387] -> 
             RGBColor[
              0.9857344509137094, 0.9883688430919992, 0.8860805966248293], 
             UndirectedEdge[117, 303] -> 
             RGBColor[
              0.9883491790013614, 0.987109211554791, 0.672946793623761], 
             UndirectedEdge[287, 382] -> 
             RGBColor[
              0.9932699686525639, 0.9905266529492102, 0.691537791186225], 
             UndirectedEdge[20, 168] -> 
             RGBColor[
              0.7486629537017742, 0.8021019710195914, 0.9446105292495168], 
             UndirectedEdge[51, 355] -> 
             RGBColor[
              0.9942037885036126, 0.9904491716505182, 0.6423602602003304], 
             UndirectedEdge[183, 339] -> 
             RGBColor[
              0.9658291722568784, 0.8916627367785881, 0.5113334826041473], 
             UndirectedEdge[118, 164] -> 
             RGBColor[
              0.9632238741733825, 0.8819246850528386, 0.3412290172779367], 
             UndirectedEdge[51, 134] -> 
             RGBColor[
              0.994982136657211, 0.9921139796479954, 0.7270786533115245], 
             UndirectedEdge[46, 356] -> 
             RGBColor[
              0.9713776658403708, 0.977214248030742, 0.8903506154481122], 
             UndirectedEdge[204, 276] -> 
             RGBColor[
              0.9813406005136002, 0.9837344639250124, 0.8317777098215672], 
             UndirectedEdge[108, 154] -> 
             RGBColor[
              0.985279392731837, 0.968586808379247, 0.6004947530195319], 
             UndirectedEdge[29, 119] -> 
             RGBColor[
              0.9901985718048644, 0.9902148718031658, 0.8120985606838564], 
             UndirectedEdge[244, 264] -> 
             RGBColor[
              0.979249983912641, 0.954393342844375, 0.6195466597289891], 
             UndirectedEdge[217, 321] -> 
             RGBColor[
              0.9207458881437796, 0.7209536022370282, 0.25495723404217707`], 
             UndirectedEdge[241, 346] -> 
             RGBColor[
              0.9828743179031748, 0.9853845621964232, 0.8528036532416663], 
             UndirectedEdge[108, 284] -> 
             RGBColor[
              0.9759134501166329, 0.9304125528318534, 0.36092873137674153`], 
             UndirectedEdge[181, 334] -> 
             RGBColor[
              0.9629639791731852, 0.9712183682201375, 0.9170885018035158], 
             UndirectedEdge[8, 59] -> 
             RGBColor[
              0.9901433060227602, 0.98963967062025, 0.7728646353925392], 
             UndirectedEdge[236, 383] -> 
             RGBColor[
              0.9438644593487211, 0.8550636775283605, 0.6024850939195767], 
             UndirectedEdge[42, 290] -> 
             RGBColor[
              0.896567126571677, 0.717187296790453, 0.6019210298284456], 
             UndirectedEdge[173, 209] -> 
             RGBColor[
              0.9934140181173509, 0.9883215756349526, 0.5245346999215303], 
             UndirectedEdge[154, 332] -> 
             RGBColor[
              0.9633352618158504, 0.8889547759474331, 0.5444594140135843], 
             UndirectedEdge[5, 352] -> 
             RGBColor[
              0.9709007329605832, 0.9371935289561746, 0.6198237534863233], 
             UndirectedEdge[189, 226] -> 
             RGBColor[
              0.9515811997804551, 0.9595480959207788, 0.7539195213394543], 
             UndirectedEdge[16, 390] -> 
             RGBColor[
              0.9218136586634504, 0.9369267147302682, 0.8414210398447475], 
             UndirectedEdge[119, 327] -> 
             RGBColor[
              0.9902523368618702, 0.9902371050359366, 0.8112075345497629], 
             UndirectedEdge[129, 231] -> 
             RGBColor[
              0.9657239265564554, 0.9714923110140441, 0.8109810888776985], 
             UndirectedEdge[79, 352] -> 
             RGBColor[
              0.9537823619929169, 0.851958171513817, 0.29474943306331347`], 
             UndirectedEdge[62, 361] -> 
             RGBColor[
              0.9943715222108823, 0.9903695800725025, 0.628753111472133], 
             UndirectedEdge[150, 347] -> 
             RGBColor[
              0.9949968609642248, 0.9921733035937019, 0.7307042607853849], 
             UndirectedEdge[5, 90] -> 
             RGBColor[
              0.9219828773528257, 0.93955417183055, 0.9551857280369462], 
             UndirectedEdge[24, 27] -> 
             RGBColor[
              0.9942658192786091, 0.990143492188576, 0.6172479996170737], 
             UndirectedEdge[62, 393] -> 
             RGBColor[
              0.9774163885346646, 0.9805989129977364, 0.8218466378627278], 
             UndirectedEdge[199, 353] -> 
             RGBColor[
              0.9374293958130835, 0.7705636310768704, 0.4128859586937299], 
             UndirectedEdge[96, 201] -> 
             RGBColor[
              0.9578085035157242, 0.8579056398601299, 0.44300709202418814`], 
             UndirectedEdge[155, 170] -> 
             RGBColor[
              0.9764047322780032, 0.9793974500369106, 0.788093840712027], 
             UndirectedEdge[335, 394] -> 
             RGBColor[
              0.9930801054544924, 0.987173810972036, 0.5250571155708407], 
             UndirectedEdge[16, 310] -> 
             RGBColor[
              0.9095467034072873, 0.8970899325921413, 0.6625999073618878], 
             UndirectedEdge[6, 277] -> 
             RGBColor[
              0.979230970612587, 0.9401319963318502, 0.4989281355074661], 
             UndirectedEdge[140, 232] -> 
             RGBColor[
              0.9918590871461517, 0.9905130295520859, 0.7563390925933142], 
             UndirectedEdge[177, 300] -> 
             RGBColor[
              0.9731897618222216, 0.929540129384998, 0.5655175144738136], 
             UndirectedEdge[24, 32] -> 
             RGBColor[
              0.9897189324321987, 0.98955766775122, 0.7866930868926694], 
             UndirectedEdge[102, 226] -> 
             RGBColor[
              0.9399444451608368, 0.9540639360876545, 0.9634065134423062], 
             UndirectedEdge[187, 206] -> 
             RGBColor[
              0.9930020163546851, 0.9872555706245277, 0.49540277438095454`], 
             UndirectedEdge[336, 396] -> 
             RGBColor[
              0.9761586747798427, 0.9784092650097072, 0.7246627730127415], 
             UndirectedEdge[267, 332] -> 
             RGBColor[
              0.9659327904933741, 0.8896745360935998, 0.47565161390166], 
             UndirectedEdge[115, 300] -> 
             RGBColor[
              0.9637216042950667, 0.8925675781529299, 0.5549538796720324], 
             UndirectedEdge[149, 195] -> 
             RGBColor[
              0.987989804695352, 0.9893014898406569, 0.8487035477945224], 
             UndirectedEdge[127, 396] -> 
             RGBColor[
              0.9931017572961255, 0.9876536813127637, 0.4905470365815593], 
             UndirectedEdge[206, 220] -> 
             RGBColor[
              0.9932229512753026, 0.9879129029796325, 0.5037382532924402], 
             UndirectedEdge[298, 361] -> 
             RGBColor[
              0.9909764830428902, 0.9892584226011083, 0.706299600832968], 
             UndirectedEdge[27, 141] -> 
             RGBColor[
              0.9897004653220041, 0.9887144618484536, 0.7262620688984935], 
             UndirectedEdge[55, 221] -> 
             RGBColor[
              0.9923750115138285, 0.9852380940810823, 0.48467134978197457`], 
             UndirectedEdge[40, 269] -> 
             RGBColor[
              0.9794441505694058, 0.9839238434008176, 0.9077580727035551], 
             UndirectedEdge[191, 312] -> 
             RGBColor[
              0.9937655341084521, 0.9890734327961999, 0.5627950462476675], 
             UndirectedEdge[78, 240] -> 
             RGBColor[
              0.9766474413557484, 0.9800898321670269, 0.8282580275561902], 
             UndirectedEdge[183, 246] -> 
             RGBColor[
              0.9886817688953546, 0.9894965692782217, 0.8331578092346981], 
             UndirectedEdge[130, 164] -> 
             RGBColor[
              0.9655086471849139, 0.8885400621015732, 0.4429351156588688], 
             UndirectedEdge[190, 295] -> 
             RGBColor[
              0.9282787630403864, 0.9419835575498845, 0.8340727439482702], 
             UndirectedEdge[18, 179] -> 
             RGBColor[
              0.9828444238013331, 0.9600208112911726, 0.5886004459763989], 
             UndirectedEdge[128, 199] -> 
             RGBColor[
              0.936697738696854, 0.7689986904871373, 0.33324959685646727`], 
             UndirectedEdge[350, 355] -> 
             RGBColor[
              0.9836842238360407, 0.9843617305970028, 0.7388954511523083], 
             UndirectedEdge[233, 348] -> 
             RGBColor[
              0.9888601992972785, 0.9896614203766745, 0.8342788567315756], 
             UndirectedEdge[247, 316] -> 
             RGBColor[
              0.9636236443058921, 0.8939390773171528, 0.5634868737558012], 
             UndirectedEdge[74, 399] -> 
             RGBColor[
              0.991622206982911, 0.9891484758474325, 0.66819653022845], 
             UndirectedEdge[155, 171] -> 
             RGBColor[
              0.9685523036872118, 0.9540189876209544, 0.6632343029874682], 
             UndirectedEdge[21, 95] -> 
             RGBColor[
              0.9925501524925093, 0.9860402951728175, 0.46737500614954464`], 
             UndirectedEdge[257, 325] -> 
             RGBColor[
              0.9920186183111164, 0.9899676875244414, 0.7092593000751422], 
             UndirectedEdge[250, 372] -> 
             RGBColor[
              0.9934201203154388, 0.9902313841578914, 0.663073063676235], 
             UndirectedEdge[156, 400] -> 
             RGBColor[
              0.9802841254512329, 0.9441518520220639, 0.4632821678861798], 
             UndirectedEdge[193, 360] -> 
             RGBColor[
              0.9629706241979259, 0.8867533618880117, 0.3106482967301526], 
             UndirectedEdge[92, 135] -> 
             RGBColor[
              0.9737459058384738, 0.9353245416127434, 0.5946927985125102], 
             UndirectedEdge[102, 174] -> 
             RGBColor[
              0.978059465146462, 0.98284843155287, 0.9081890864244784], 
             UndirectedEdge[140, 275] -> 
             RGBColor[
              0.9480500369622855, 0.9592618914089202, 0.9124273357858638], 
             UndirectedEdge[101, 301] -> 
             RGBColor[
              0.9906155461067816, 0.9894404299973389, 0.7363606626417241], 
             UndirectedEdge[337, 398] -> 
             RGBColor[
              0.9730918333433338, 0.9768345368918327, 0.7863893281797363], 
             UndirectedEdge[149, 249] -> 
             RGBColor[
              0.9923797442009404, 0.9900517558374384, 0.6985303222863581], 
             UndirectedEdge[92, 165] -> 
             RGBColor[
              0.9749350861029213, 0.9271123012828099, 0.3571279719320136], 
             UndirectedEdge[150, 320] -> 
             RGBColor[
              0.9935263069514974, 0.9881281908562379, 0.573623394883384], 
             UndirectedEdge[59, 175] -> 
             RGBColor[
              0.9940593955775128, 0.9912590742900511, 0.7079648969553938], 
             UndirectedEdge[278, 379] -> 
             RGBColor[
              0.966805032336763, 0.9719368262805237, 0.780446025379053], 
             UndirectedEdge[87, 317] -> 
             RGBColor[
              0.9818862541336983, 0.94901319315564, 0.5156802206633753], 
             UndirectedEdge[212, 324] -> 
             RGBColor[
              0.9662895666793292, 0.9733117447331503, 0.8941356101333245], 
             UndirectedEdge[135, 328] -> 
             RGBColor[
              0.9900674475262325, 0.98928923539641, 0.7509290925792425], 
             UndirectedEdge[176, 344] -> 
             RGBColor[
              0.9419766443014088, 0.7901934586303232, 0.46246611644782537`], 
             UndirectedEdge[59, 213] -> 
             RGBColor[
              0.9356561055672928, 0.7619093985791161, 0.43848367542897426`], 
             UndirectedEdge[371, 391] -> 
             RGBColor[
              0.9921821502441291, 0.984078240300901, 0.5272282472165438], 
             UndirectedEdge[98, 318] -> 
             RGBColor[
              0.9903444263509662, 0.990210490324835, 0.8049786512417316], 
             UndirectedEdge[25, 244] -> 
             RGBColor[
              0.983440930557758, 0.9549389275977527, 0.4637746122468954], 
             UndirectedEdge[204, 224] -> 
             RGBColor[
              0.9806263457302651, 0.9822067451656947, 0.7540354845251132], 
             UndirectedEdge[180, 236] -> 
             RGBColor[
              0.9689984180513211, 0.9763996514598825, 0.9373617711182902], 
             UndirectedEdge[102, 163] -> 
             RGBColor[
              0.9705647529114023, 0.9775678214338932, 0.9347103747657315], 
             UndirectedEdge[16, 107] -> 
             RGBColor[
              0.8927574196524198, 0.834815516840473, 0.626751068528351], 
             UndirectedEdge[194, 223] -> 
             RGBColor[
              0.9903999505481671, 0.9891102323812206, 0.7224123347858835], 
             UndirectedEdge[111, 291] -> 
             RGBColor[
              0.9534948637832139, 0.8905982588935428, 0.6081804493083232], 
             UndirectedEdge[108, 205] -> 
             RGBColor[
              0.9646513325227294, 0.8901922090355068, 0.3287944124651538], 
             UndirectedEdge[66, 297] -> 
             RGBColor[
              0.9839196326998498, 0.9563990219951084, 0.47878717864180037`], 
             UndirectedEdge[19, 284] -> 
             RGBColor[
              0.9697344736135332, 0.9448483329340813, 0.6398940351951197], 
             UndirectedEdge[23, 260] -> 
             RGBColor[
              0.8473244108754856, 0.8809159581987089, 0.9510075471856916], 
             UndirectedEdge[10, 256] -> 
             RGBColor[
              0.9812472358088786, 0.9823719218990421, 0.7293488113622413], 
             UndirectedEdge[230, 242] -> 
             RGBColor[
              0.9553297487615637, 0.8559303634386459, 0.5317288693362315], 
             UndirectedEdge[29, 317] -> 
             RGBColor[
              0.9818089387856037, 0.9492161655348561, 0.5340395037579063], 
             UndirectedEdge[124, 316] -> 
             RGBColor[
              0.9523573574151085, 0.8860884251955317, 0.6072651849838393], 
             UndirectedEdge[306, 361] -> 
             RGBColor[
              0.9842783870453765, 0.9849209834575224, 0.7471038615816739], 
             UndirectedEdge[1, 393] -> 
             RGBColor[
              0.965570394107151, 0.9421452476022156, 0.6477971209908446], 
             UndirectedEdge[74, 279] -> 
             RGBColor[
              0.9834232695678888, 0.9552138938580008, 0.43525905705840895`], 
             UndirectedEdge[40, 234] -> 
             RGBColor[
              0.932178800874853, 0.947793777454772, 0.9599599615854164], 
             UndirectedEdge[195, 316] -> 
             RGBColor[
              0.9625009345334277, 0.8934748079739137, 0.5820930801652899], 
             UndirectedEdge[279, 325] -> 
             RGBColor[
              0.9816986425042615, 0.9561558219339079, 0.5841493019999182], 
             UndirectedEdge[172, 337] -> 
             RGBColor[
              0.9943532587971421, 0.9903305164772266, 0.6267652515952311], 
             UndirectedEdge[148, 275] -> 
             RGBColor[
              0.9221367476930074, 0.9407157331906212, 0.9912186560666847], 
             UndirectedEdge[13, 188] -> 
             RGBColor[
              0.9913144145957281, 0.9906763014730395, 0.7936061579306702], 
             UndirectedEdge[220, 233] -> 
             RGBColor[
              0.9923142365181432, 0.9888152615650312, 0.6117049659640277], 
             UndirectedEdge[230, 244] -> 
             RGBColor[
              0.9816881685870664, 0.955401594865738, 0.5791396298540892], 
             UndirectedEdge[253, 358] -> 
             RGBColor[
              0.9880503059334189, 0.9711347258558987, 0.4266400591611787], 
             UndirectedEdge[66, 140] -> 
             RGBColor[
              0.9915213301347341, 0.9897906014571358, 0.7195763262951642], 
             UndirectedEdge[89, 128] -> 
             RGBColor[
              0.9858806631209296, 0.9853334591214489, 0.6823036607197548], 
             UndirectedEdge[199, 298] -> 
             RGBColor[
              0.9344354935943334, 0.7703104649787378, 0.534093729449269], 
             UndirectedEdge[367, 398] -> 
             RGBColor[
              0.9595796434084212, 0.9693751447530358, 0.9533052997788616], 
             UndirectedEdge[72, 181] -> 
             RGBColor[
              0.9675850722119318, 0.9746647718420893, 0.90926619666301], 
             UndirectedEdge[229, 329] -> 
             RGBColor[
              0.9875950853112321, 0.9715632601849088, 0.5760719737147033], 
             UndirectedEdge[196, 326] -> 
             RGBColor[
              0.9900657727785818, 0.9893193799363336, 0.753198378473183], 
             UndirectedEdge[247, 362] -> 
             RGBColor[
              0.9900873374816859, 0.9879084195122834, 0.64963085516706], 
             UndirectedEdge[276, 297] -> 
             RGBColor[
              0.9844628120673314, 0.9575608277382932, 0.5379089006776918], 
             UndirectedEdge[7, 201] -> 
             RGBColor[
              0.9065062190425895, 0.6634509502700154, 0.24344549616817812`], 
             UndirectedEdge[191, 214] -> 
             RGBColor[
              0.9512242416285824, 0.9587845985279285, 0.7150668293984763], 
             UndirectedEdge[25, 32] -> 
             RGBColor[
              0.9892966362311971, 0.9886544188779731, 0.7407287515237073], 
             UndirectedEdge[190, 324] -> 
             RGBColor[
              0.9684083418898646, 0.9738203202215431, 0.8323019266196554], 
             UndirectedEdge[8, 296] -> 
             RGBColor[
              0.9897492910227265, 0.9900290826537623, 0.8195443059452746], 
             UndirectedEdge[292, 382] -> 
             RGBColor[
              0.9884713996464314, 0.9895006417293539, 0.8407222731273547], 
             UndirectedEdge[223, 328] -> 
             RGBColor[
              0.9940884449636684, 0.9897641064642121, 0.5979419000631675], 
             UndirectedEdge[70, 262] -> 
             RGBColor[
              0.9623923261896213, 0.8777379674377221, 0.34852468188275787`], 
             UndirectedEdge[78, 285] -> 
             RGBColor[
              0.911368874805949, 0.7229493100677292, 0.5820844230945077], 
             UndirectedEdge[167, 272] -> 
             RGBColor[
              0.9882323835509199, 0.9883775184218183, 0.7806907000678323], 
             UndirectedEdge[93, 276] -> 
             RGBColor[
              0.9940934708524607, 0.9897748563321435, 0.598488937042017], 
             UndirectedEdge[56, 319] -> 
             RGBColor[
              0.9924050401486646, 0.9900439960964849, 0.6967866820160713], 
             UndirectedEdge[93, 162] -> 
             RGBColor[
              0.9908794883638883, 0.9884798697706476, 0.6542300402134416], 
             UndirectedEdge[106, 389] -> 
             RGBColor[
              0.9931722201684704, 0.9911090679017908, 0.7384313723803844], 
             UndirectedEdge[68, 176] -> 
             RGBColor[
              0.9920379016527976, 0.9907219884032329, 0.7631897992235945], 
             UndirectedEdge[253, 301] -> 
             RGBColor[
              0.985145294911393, 0.9720257040455254, 0.6268699079668755], 
             UndirectedEdge[217, 357] -> 
             RGBColor[
              0.9692210306371172, 0.9075089115138899, 0.5257999337426043], 
             UndirectedEdge[364, 385] -> 
             RGBColor[
              0.9637047061447619, 0.9690132950471182, 0.738720896011833], 
             UndirectedEdge[161, 372] -> 
             RGBColor[
              0.9939037830422239, 0.9893691332864264, 0.5778425895152064], 
             UndirectedEdge[4, 339] -> 
             RGBColor[
              0.9664475472810343, 0.8919184507425899, 0.5010854081506206], 
             UndirectedEdge[183, 280] -> 
             RGBColor[
              0.9815607174475282, 0.9841857007680843, 0.8452118918681975], 
             UndirectedEdge[94, 145] -> 
             RGBColor[
              0.965378462723379, 0.8896206776466976, 0.34834300757679243`], 
             UndirectedEdge[107, 351] -> 
             RGBColor[
              0.9609441662187445, 0.8877805040471206, 0.583178364381586], 
             UndirectedEdge[90, 178] -> 
             RGBColor[
              0.929628064001302, 0.9415707520209442, 0.7135224738183336], 
             UndirectedEdge[113, 124] -> 
             RGBColor[
              0.9760131905378696, 0.9811570991396776, 0.9042538200998], 
             UndirectedEdge[191, 365] -> 
             RGBColor[
              0.9874670977302373, 0.9864817712283316, 0.6768531829589769], 
             UndirectedEdge[184, 356] -> 
             RGBColor[
              0.9600154571400628, 0.875272102458274, 0.5392399541418473], 
             UndirectedEdge[196, 327] -> 
             RGBColor[
              0.9946350945251232, 0.991208911904741, 0.6774728921073712], 
             UndirectedEdge[140, 288] -> 
             RGBColor[
              0.9843220511873547, 0.9870480614729782, 0.8764959764463925], 
             UndirectedEdge[13, 232] -> 
             RGBColor[
              0.9946359447819254, 0.9916613315464644, 0.7103193752913431], 
             UndirectedEdge[34, 86] -> 
             RGBColor[
              0.9864509630456144, 0.9759307529618803, 0.6284912030328111], 
             UndirectedEdge[287, 374] -> 
             RGBColor[
              0.9919629388701878, 0.9835217218215155, 0.5108213541007315], 
             UndirectedEdge[201, 230] -> 
             RGBColor[
              0.9558145412381451, 0.8578524040607749, 0.5321189447424308], 
             UndirectedEdge[71, 138] -> 
             RGBColor[
              0.9902178702840809, 0.9900874556032837, 0.8019368302048144], 
             UndirectedEdge[334, 360] -> 
             RGBColor[
              0.9504252615877848, 0.9202901352110058, 0.6510172162917889], 
             UndirectedEdge[38, 58] -> 
             RGBColor[
              0.9910530508575155, 0.9886154921358139, 0.6559948679517069], 
             UndirectedEdge[115, 239] -> 
             RGBColor[
              0.9332879655889885, 0.773216044567631, 0.26518013506143523`], 
             UndirectedEdge[32, 78] -> 
             RGBColor[
              0.9714737855818102, 0.978163412369748, 0.9294831850398273], 
             UndirectedEdge[41, 83] -> 
             RGBColor[
              0.9847086077895241, 0.9592081280872721, 0.469292188111767], 
             UndirectedEdge[90, 212] -> 
             RGBColor[
              0.9286189962861502, 0.9434357286565384, 0.896140969883684], 
             UndirectedEdge[160, 263] -> 
             RGBColor[
              0.9391643364259592, 0.8782640983539911, 0.6311608733458951], 
             UndirectedEdge[226, 350] -> 
             RGBColor[
              0.9417781107902389, 0.9554314809117107, 0.9603025958283186], 
             UndirectedEdge[159, 329] -> 
             RGBColor[
              0.9898803933878568, 0.9900832968509208, 0.8173716004730207], 
             UndirectedEdge[132, 260] -> 
             RGBColor[
              0.8571388887610667, 0.8851140410463338, 0.750395370555962], 
             UndirectedEdge[7, 250] -> 
             RGBColor[
              0.9424333397020044, 0.7964515254213425, 0.49785211588448763`], 
             UndirectedEdge[135, 281] -> 
             RGBColor[
              0.9876665508995432, 0.9891678160888463, 0.854060699745081], 
             UndirectedEdge[240, 243] -> 
             RGBColor[
              0.9946914297015454, 0.9918597641824913, 0.7221559858748015], 
             UndirectedEdge[105, 349] -> 
             RGBColor[
              0.9658491420160263, 0.9723154096693842, 0.8649726822351833], 
             UndirectedEdge[111, 154] -> 
             RGBColor[
              0.9773282506410899, 0.9817009102878624, 0.8824598709229867], 
             UndirectedEdge[3, 233] -> 
             RGBColor[
              0.9849102974604813, 0.9869723377738535, 0.8524626976960166], 
             UndirectedEdge[125, 162] -> 
             RGBColor[
              0.9874868121785708, 0.9890934895086498, 0.857039435500493], 
             UndirectedEdge[301, 369] -> 
             RGBColor[
              0.9553344936779528, 0.9654234289593361, 0.9284553672485618], 
             UndirectedEdge[268, 270] -> 
             RGBColor[
              0.9833831486680729, 0.9858289148723187, 0.8548472357632989], 
             UndirectedEdge[4, 188] -> 
             RGBColor[
              0.9915725091221836, 0.9907830301924557, 0.7893288637000779], 
             UndirectedEdge[161, 176] -> 
             RGBColor[
              0.9945194105438967, 0.9906858982630162, 0.6448498438597474], 
             UndirectedEdge[106, 270] -> 
             RGBColor[
              0.9848247335281073, 0.9860895633399807, 0.8065703045672596], 
             UndirectedEdge[190, 268] -> 
             RGBColor[
              0.9934329227574201, 0.9911847665298729, 0.7317769001074356], 
             UndirectedEdge[220, 341] -> 
             RGBColor[
              0.9579740958542964, 0.8601527969161582, 0.3490148224167397], 
             UndirectedEdge[76, 103] -> 
             RGBColor[
              0.9718583668111578, 0.9500743117767189, 0.644030078175208], 
             UndirectedEdge[84, 163] -> 
             RGBColor[
              0.9781851749164872, 0.9830656694551433, 0.9135061477116064], 
             UndirectedEdge[356, 372] -> 
             RGBColor[
              0.9918631710282131, 0.989587545615852, 0.6888757426211589], 
             UndirectedEdge[243, 398] -> 
             RGBColor[
              0.973181416043895, 0.9778320795652018, 0.8547227705796371], 
             UndirectedEdge[141, 243] -> 
             RGBColor[
              0.9899835900351308, 0.9901259713166015, 0.8156613649633271], 
             UndirectedEdge[192, 320] -> 
             RGBColor[
              0.9787433959459476, 0.9789663905373109, 0.6828076341245135], 
             UndirectedEdge[83, 245] -> 
             RGBColor[
              0.9472428298866845, 0.9336285877485953, 0.6757294841625027], 
             UndirectedEdge[256, 313] -> 
             RGBColor[
              0.9923588589787867, 0.9853416123535914, 0.47117303244569086`], 
             UndirectedEdge[144, 186] -> 
             RGBColor[
              0.9558063629999209, 0.8544753133217984, 0.3250603523499981], 
             UndirectedEdge[271, 371] -> 
             RGBColor[
              0.977825201978826, 0.9356488826302735, 0.47145421428802614`], 
             UndirectedEdge[317, 326] -> 
             RGBColor[
              0.9772933820960681, 0.9473488667992195, 0.6088739639896246], 
             UndirectedEdge[194, 242] -> 
             RGBColor[
              0.953577203491343, 0.8552056409310504, 0.5607730799055626], 
             UndirectedEdge[305, 334] -> 
             RGBColor[
              0.9550711770440554, 0.966012737920428, 0.9609369573373818], 
             UndirectedEdge[252, 282] -> 
             RGBColor[
              0.9459951449858406, 0.82737312196958, 0.565574010815361], 
             UndirectedEdge[134, 239] -> 
             RGBColor[
              0.9614136061393123, 0.8714660877354641, 0.4892581788627392], 
             UndirectedEdge[267, 398] -> 
             RGBColor[
              0.9734431273208464, 0.9775859191884628, 0.8246255096968547], 
             UndirectedEdge[4, 297] -> 
             RGBColor[
              0.9843197756707129, 0.9575357563055351, 0.542756479751712], 
             UndirectedEdge[40, 272] -> 
             RGBColor[
              0.9775147141276346, 0.9827510911294421, 0.9229459032668423], 
             UndirectedEdge[203, 325] -> 
             RGBColor[
              0.9709503860107436, 0.9187235363231834, 0.548518424054963], 
             UndirectedEdge[315, 359] -> 
             RGBColor[
              0.948931471178704, 0.8719154222121667, 0.6040504920256893], 
             UndirectedEdge[132, 160] -> 
             RGBColor[
              0.9653939975934058, 0.9705899418943573, 0.7594642891748917], 
             UndirectedEdge[283, 381] -> 
             RGBColor[
              0.9945826677853682, 0.9908211991062357, 0.6517350042154848], 
             UndirectedEdge[40, 183] -> 
             RGBColor[
              0.9834067839372234, 0.9855624941334425, 0.842086982832396], 
             UndirectedEdge[131, 339] -> 
             RGBColor[
              0.966429004136247, 0.8919107826756832, 0.5013927160478666], 
             UndirectedEdge[156, 165] -> 
             RGBColor[
              0.9911855905546132, 0.9809250536014957, 0.505632301243868], 
             UndirectedEdge[352, 379] -> 
             RGBColor[
              0.979161945355917, 0.9405277259293399, 0.4452111001429248], 
             UndirectedEdge[25, 194] -> 
             RGBColor[
              0.9904002028534119, 0.9891107720366275, 0.7224397966547387], 
             UndirectedEdge[174, 238] -> 
             RGBColor[
              0.8204950384376805, 0.8594311021934724, 0.9235338688354239], 
             UndirectedEdge[66, 339] -> 
             RGBColor[
              0.9660474043101712, 0.8907817164321631, 0.437116107040709], 
             UndirectedEdge[67, 387] -> 
             RGBColor[
              0.9770789648479794, 0.9484752713167252, 0.6208259420233335], 
             UndirectedEdge[90, 190] -> 
             RGBColor[
              0.9307377714966856, 0.9439443041449311, 0.8343072863700147], 
             UndirectedEdge[271, 389] -> 
             RGBColor[
              0.9763170878561644, 0.9357278526455983, 0.5475201860283452], 
             UndirectedEdge[19, 293] -> 
             RGBColor[
              0.980922016222638, 0.9820827156317957, 0.7261972079903671], 
             UndirectedEdge[126, 327] -> 
             RGBColor[
              0.9878590504667112, 0.9886764990372416, 0.8253034941765439], 
             UndirectedEdge[12, 310] -> 
             RGBColor[
              0.9817308829851547, 0.9497335257087219, 0.40925878501230784`], 
             UndirectedEdge[272, 350] -> 
             RGBColor[
              0.9778351380868264, 0.9829900627935613, 0.9224035090838834], 
             UndirectedEdge[215, 229] -> 
             RGBColor[
              0.9806559366090999, 0.9678419652590102, 0.6529272392275554], 
             UndirectedEdge[57, 189] -> 
             RGBColor[
              0.974817250361709, 0.9775448143607561, 0.7377230039278071], 
             UndirectedEdge[104, 337] -> 
             RGBColor[
              0.9934009387434541, 0.9905786349048324, 0.689208993470654], 
             UndirectedEdge[194, 385] -> 
             RGBColor[
              0.9606320874063088, 0.9696767167627506, 0.9302255974371576], 
             UndirectedEdge[56, 166] -> 
             RGBColor[
              0.9907375891611678, 0.989354462261619, 0.724420660103722], 
             UndirectedEdge[258, 379] -> 
             RGBColor[
              0.9768280410282548, 0.9326549186053388, 0.4361443225508068], 
             UndirectedEdge[9, 150] -> 
             RGBColor[
              0.9173644096005423, 0.9335465140125987, 0.854575546773666], 
             UndirectedEdge[294, 380] -> 
             RGBColor[
              0.959364367433816, 0.9670898853204171, 0.8616699301349366], 
             UndirectedEdge[296, 308] -> 
             RGBColor[
              0.9879242174385112, 0.9713262492154658, 0.5680384417370229], 
             UndirectedEdge[33, 92] -> 
             RGBColor[
              0.9766969591534242, 0.9330555127896212, 0.3639725160314099], 
             UndirectedEdge[39, 283] -> 
             RGBColor[
              0.9854348946215892, 0.9611490997263465, 0.5153923328749174], 
             UndirectedEdge[11, 34] -> 
             RGBColor[
              0.990762202444166, 0.9894630581480657, 0.7311666793410154], 
             UndirectedEdge[105, 171] -> 
             RGBColor[
              0.9866172058150859, 0.9657562451695187, 0.5549351440179182], 
             UndirectedEdge[110, 237] -> 
             RGBColor[
              0.9863858828753351, 0.9860590120161365, 0.7091211355338954], 
             UndirectedEdge[8, 175] -> 
             RGBColor[
              0.9895609658240823, 0.9899512053443861, 0.8226653418568002], 
             UndirectedEdge[90, 373] -> 
             RGBColor[
              0.9306821150192266, 0.9438252605673794, 0.8282494222705701], 
             UndirectedEdge[73, 104] -> 
             RGBColor[
              0.9934159906956126, 0.9906108295085139, 0.6908473055732349], 
             UndirectedEdge[232, 339] -> 
             RGBColor[
              0.9663851613215888, 0.8915041445271131, 0.4738788733388589], 
             UndirectedEdge[178, 274] -> 
             RGBColor[
              0.9930833516659581, 0.9876143135309301, 0.48854369732421465`], 
             UndirectedEdge[224, 318] -> 
             RGBColor[
              0.9896479174608546, 0.9887207282367373, 0.7291679569076943], 
             UndirectedEdge[132, 307] -> 
             RGBColor[
              0.9936230538786264, 0.9887686819915638, 0.5472869525171942]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.9382341719487594, 0.7928261045585611, 0.2691599688008921], 
             316 -> RGBColor[
              0.9397343642340371, 0.7987738670602436, 0.2703670587276654], 
             308 -> RGBColor[
              0.9819947291008992, 0.950926134797992, 0.38455335187744216`], 
             160 -> RGBColor[
              0.9373423117321865, 0.9527905791991887, 0.9909473018817506], 
             245 -> RGBColor[
              0.9189852518257995, 0.9382379108885007, 0.9921348277786056], 
             155 -> RGBColor[
              0.958508537371493, 0.9685763156244699, 0.9551184029101855], 213 -> 
             RGBColor[
              0.8766704753583949, 0.532871257592317, 0.21880316036681569`], 
             352 -> RGBColor[
              0.9644553562420664, 0.8917617117045598, 0.31641620035351836`], 
             27 -> RGBColor[
              0.9937815360608907, 0.9891076593544206, 0.5645367600180095], 
             367 -> RGBColor[
              0.9671442402161969, 0.9750168086663844, 0.9405004105461253], 19 -> 
             RGBColor[
              0.9685246817714748, 0.9760463397180451, 0.9381636830698599], 
             164 -> RGBColor[
              0.9367454099263256, 0.7869236592401463, 0.2679620759319059], 
             190 -> RGBColor[
              0.9948558979668198, 0.9914056108365517, 0.6814744232852653], 
             103 -> RGBColor[
              0.9700001972899439, 0.9771467767757844, 0.9356660201731725], 
             138 -> RGBColor[
              0.9951250523690626, 0.9919813048872644, 0.7107702189409613], 
             291 -> RGBColor[
              0.9420093769702479, 0.8077935344562659, 0.2721975873766329], 28 -> 
             RGBColor[
              0.9611828526434771, 0.8807227886461332, 0.303703141833449], 337 -> 
             RGBColor[
              0.9941686200860222, 0.9899355929439785, 0.6066684673478747], 
             195 -> RGBColor[
              0.9852675048328183, 0.9881757488875839, 0.8938191016029143], 
             114 -> RGBColor[
              0.9551841137901912, 0.8600269757265512, 0.28279828987277866`], 
             93 -> RGBColor[
              0.9929444436438579, 0.9873172033174133, 0.47342441635956173`], 
             34 -> RGBColor[
              0.9873840586676792, 0.9890509982912513, 0.8587423270935286], 
             161 -> RGBColor[
              0.9940506630957493, 0.9896832948690657, 0.593829576902822], 22 -> 
             RGBColor[
              0.9937026126519534, 0.9889388501630841, 0.5559464340139961], 
             124 -> RGBColor[
              0.96498035059618, 0.9734029833308199, 0.9441633112400133], 84 -> 
             RGBColor[
              0.985308253324681, 0.9881925994361576, 0.893143793639033], 46 -> 
             RGBColor[
              0.9527858926130138, 0.9643083765335669, 0.9648053477814972], 
             241 -> RGBColor[
              0.992400395102881, 0.9911253823211733, 0.775608650499684], 185 -> 
             RGBColor[
              0.8736054607324941, 0.5189537420284548, 0.2162456370325807], 
             390 -> RGBColor[
              0.9950023817738606, 0.991718924888027, 0.6974182816883809], 121 -> 
             RGBColor[
              0.986909642701601, 0.9888548150973437, 0.8666046274006083], 322 -> 
             RGBColor[
              0.9867451978385706, 0.9887868129204405, 0.869329904350686], 126 -> 
             RGBColor[
              0.9807555417426524, 0.9851680950583542, 0.9174600274578315], 
             236 -> RGBColor[
              0.9633358204440908, 0.9721764954360628, 0.9469470718253429], 78 -> 
             RGBColor[
              0.9582598087955505, 0.9683908142597876, 0.9555394355104538], 
             376 -> RGBColor[
              0.9939885809901973, 0.9895505075227538, 0.5870723228398373], 
             254 -> RGBColor[
              0.9823071932104718, 0.9863253141824577, 0.9148334862583303], 
             290 -> RGBColor[
              0.8673943949452997, 0.49075074292007487`, 0.21106297149259162`],
              251 -> RGBColor[
              0.7937209913471421, 0.8387801380341288, 0.9800743487392529], 
             165 -> RGBColor[
              0.9882413711378578, 0.971997525169953, 0.40882037661166], 100 -> 
             RGBColor[
              0.9938139884943934, 0.9891770718282382, 0.5680690071315643], 
             235 -> RGBColor[
              0.9950015835003913, 0.991717217461794, 0.6973313945476216], 70 -> 
             RGBColor[
              0.9925705952022923, 0.9865175793027798, 0.4327333206202766], 
             234 -> RGBColor[
              0.8912637090947741, 0.9161335051960128, 0.9894907222856071], 
             257 -> RGBColor[
              0.9941230388078021, 0.9898380991988396, 0.6017072265086465], 
             135 -> RGBColor[
              0.9858630106089628, 0.98842200582982, 0.8839500297726531], 265 -> 
             RGBColor[
              0.96670572189133, 0.9746897624177066, 0.9412427076862286], 111 -> 
             RGBColor[
              0.96498035059618, 0.9734029833308199, 0.9441633112400133], 381 -> 
             RGBColor[
              0.9944238506780037, 0.9904815053724555, 0.6344487421844218], 
             182 -> RGBColor[
              0.8517124567382098, 0.39849017979872403`, 0.19715321301436328`],
              188 -> RGBColor[
              0.9881885929765408, 0.9893836939035542, 0.8454091115276433], 
             154 -> RGBColor[
              0.9896761506859998, 0.9899988372449049, 0.8207564306059603], 
             336 -> RGBColor[
              0.9591716523608653, 0.9690708656977925, 0.9539959222012664], 
             315 -> RGBColor[
              0.9325156891170375, 0.770154225702224, 0.2645587432844448], 368 -> 
             RGBColor[
              0.9604209866010699, 0.9700026171285401, 0.9518811252111556], 
             269 -> RGBColor[
              0.9857944084838799, 0.988393637088104, 0.8850869445218844], 208 -> 
             RGBColor[
              0.8986287768182097, 0.6325787760297337, 0.2371257053521071], 86 -> 
             RGBColor[
              0.9855178674235497, 0.9628105076325092, 0.39824007897209357`], 
             119 -> RGBColor[
              0.9855421145329705, 0.9882893070557441, 0.8892681082042695], 
             377 -> RGBColor[
              0.9946475244769842, 0.9909599210115848, 0.6587942548487749], 
             140 -> RGBColor[
              0.9888865209433678, 0.9896723050537678, 0.8338426389376392], 85 -> 
             RGBColor[
              0.9933039628155765, 0.9880861784727553, 0.5125558595059859], 
             351 -> RGBColor[
              0.9849984286856895, 0.9880644789858046, 0.898278389707584], 242 -> 
             RGBColor[
              0.9202595113701865, 0.7215625650650836, 0.25469713497986163`], 
             117 -> RGBColor[
              0.992583337861407, 0.9865448345621457, 0.43412028042633266`], 
             47 -> RGBColor[
              0.9590950299712335, 0.8736800725285796, 0.2955923450040111], 81 -> 
             RGBColor[
              0.9925752742290713, 0.986527587267938, 0.4332426038095692], 275 -> 
             RGBColor[
              0.9072135529812031, 0.9288514777640725, 0.9910120326340883], 23 -> 
             RGBColor[
              0.9738167276834628, 0.9799931388942759, 0.929205629727492], 328 -> 
             RGBColor[
              0.9942718844435022, 0.9901564649630001, 0.6179081553858317], 
             110 -> RGBColor[
              0.9931777292797469, 0.987816177703784, 0.49881611815401405`], 6 -> 
             RGBColor[
              0.9948870059936935, 0.9914721477605305, 0.6848603400339829], 
             218 -> RGBColor[
              0.9742699111858757, 0.9803311224083555, 0.9284385082670943], 
             108 -> RGBColor[
              0.9808826347776741, 0.9471747795135892, 0.3802330754331037], 
             297 -> RGBColor[
              0.9736831260735994, 0.922889146129713, 0.3522643436309114], 157 -> 
             RGBColor[
              0.9693529727627491, 0.9082825222438679, 0.3354425156990969], 
             354 -> RGBColor[
              0.9556269215786938, 0.8617825610510157, 0.2831545834134425], 
             385 -> RGBColor[
              0.9343692792001181, 0.9505047167284838, 0.9936021700430515], 
             270 -> RGBColor[
              0.9747563497881254, 0.9806939075214433, 0.927615094596992], 392 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 33 -> 
             RGBColor[
              0.9917651172388636, 0.9838839481835757, 0.42250946481045243`], 
             252 -> RGBColor[
              0.9856401910557777, 0.9883298642183767, 0.8876427264074493], 
             394 -> RGBColor[
              0.9918005020309433, 0.9840033093960046, 0.4226469280458245], 
             260 -> RGBColor[
              0.7208320940675083, 0.7818387775031419, 0.9728094646438912], 
             159 -> RGBColor[
              0.9868174751413914, 0.9888167014425988, 0.8681320823952811], 
             183 -> RGBColor[
              0.9937196752195148, 0.9916709385533539, 0.7537447647795661], 99 -> 
             RGBColor[
              0.9709871323876397, 0.9137949263775502, 0.3417909172566457], 
             329 -> RGBColor[
              0.9929433116343221, 0.9913498922592427, 0.7666111185507603], 
             309 -> RGBColor[
              0.985830916983861, 0.9638664973069718, 0.39945621739945436`], 
             17 -> RGBColor[
              0.9831942668651775, 0.9549724573417638, 0.3892133295779642], 
             349 -> RGBColor[
              0.9370599424048115, 0.9525799886171699, 0.991425279499281], 347 -> 
             RGBColor[
              0.9947416100563982, 0.9920935348709325, 0.7368086598498262], 
             340 -> RGBColor[
              0.9760549811787841, 0.9308899703375635, 0.36147855282730096`], 
             277 -> RGBColor[
              0.9635749352314805, 0.8887918449031698, 0.31299593098094936`], 
             104 -> RGBColor[
              0.9926332574008859, 0.9912216768656865, 0.7717495195934332], 79 -> 
             RGBColor[
              0.9431093677437673, 0.8121546313230743, 0.2730826657731086], 
             327 -> RGBColor[
              0.9949625591907699, 0.992184903016129, 0.7331469608952563], 191 -> 
             RGBColor[
              0.9926270022500028, 0.9866382282742053, 0.43887287965962346`], 
             50 -> RGBColor[
              0.9932161029993574, 0.9878982552098526, 0.5029928607184674], 
             225 -> RGBColor[
              0.8964477327610003, 0.622675164361727, 0.23530578872848953`], 
             61 -> RGBColor[
              0.9403408882261085, 0.8011785325766676, 0.27085508216863396`], 
             196 -> RGBColor[
              0.9943076298594764, 0.990232920793353, 0.6217988233194859], 1 -> 
             RGBColor[
              0.9712506312641096, 0.9146837699603618, 0.34281456063414406`], 
             263 -> RGBColor[
              0.940986361119732, 0.8037376175087935, 0.2713744448100395], 201 -> 
             RGBColor[
              0.9212290963233493, 0.7254066463093416, 0.25547728579226037`], 
             371 -> RGBColor[
              0.994467551314175, 0.9905749766144137, 0.6392052867426034], 293 -> 
             RGBColor[
              0.9933193506738011, 0.9881190915455464, 0.5142307329108745], 
             362 -> RGBColor[
              0.9926617505856246, 0.9867125514505046, 0.4426550215501828], 
             184 -> RGBColor[
              0.9300614752123979, 0.760424085388631, 0.2625840251689675], 106 -> 
             RGBColor[
              0.9948931172680892, 0.9914852191585181, 0.6855255145375274], 
             206 -> RGBColor[
              0.9938004243026276, 0.9891480593936016, 0.5665926285663556], 
             358 -> RGBColor[
              0.99285669871446, 0.9871295257858045, 0.4638739222935351], 247 -> 
             RGBColor[
              0.9875129243777471, 0.9891042875740621, 0.8566066887839371], 
             220 -> RGBColor[
              0.9926454782479774, 0.9866777465656633, 0.4408838780185248], 
             107 -> RGBColor[
              0.9368899037517994, 0.7874965291084366, 0.26807833905558803`], 
             375 -> RGBColor[
              0.9604960915585808, 0.878406182247607, 0.30103520470257555`], 
             131 -> RGBColor[
              0.9949193389782519, 0.992167030347544, 0.7338632316670045], 127 -> 
             RGBColor[
              0.9930578173934309, 0.9875596983039056, 0.485764449338902], 210 -> 
             RGBColor[
              0.9149939679739805, 0.7006864401374472, 0.25046035516508536`], 
             357 -> RGBColor[
              0.9923687930779437, 0.9911123140717267, 0.7761323778363144], 
             181 -> RGBColor[
              0.9882898911541257, 0.9894255833032299, 0.8437303385737817], 
             194 -> RGBColor[
              0.9868948956124994, 0.9888487167970174, 0.8668490248312636], 
             118 -> RGBColor[
              0.9897023384204393, 0.976925710865531, 0.4144959586239675], 348 -> 
             RGBColor[
              0.9857374038062481, 0.9883700641889499, 0.8860316595536206], 
             276 -> RGBColor[
              0.9952424980610635, 0.9922325093468736, 0.7235534577244723], 
             305 -> RGBColor[
              0.9725042868958662, 0.9790143227038108, 0.9314272496415137], 
             343 -> RGBColor[0.817319, 0.134127, 0.164218], 280 -> 
             RGBColor[
              0.9694017596755415, 0.9767004629828148, 0.9366790189568287], 
             189 -> RGBColor[
              0.9933409185537481, 0.988165223059906, 0.5165782635415794], 168 -> 
             RGBColor[
              0.971342093763755, 0.978147560968799, 0.9333945394656631], 363 -> 
             RGBColor[
              0.9921836529786897, 0.985295767510874, 0.4241353971258341], 41 -> 
             RGBColor[
              0.9939168076314786, 0.9893969915658543, 0.5792602356771342], 14 -> 
             RGBColor[
              0.927819586835325, 0.7515357450385517, 0.2607801491568909], 77 -> 
             RGBColor[
              0.9874071148606907, 0.9890605326195787, 0.8583602263078138], 51 -> 
             RGBColor[
              0.9947738699084593, 0.9921068751488002, 0.7362740306153525], 
             179 -> RGBColor[
              0.9899141978144308, 0.9900972758500433, 0.8168113736416379], 
             223 -> RGBColor[
              0.9939050054838346, 0.989371747965424, 0.5779756447405033], 323 -> 
             RGBColor[
              0.9809693029955563, 0.9474671317631711, 0.38056976509365636`], 
             292 -> RGBColor[
              0.9845740062149192, 0.987888969386981, 0.9053121684183951], 396 -> 
             RGBColor[
              0.9931456971988201, 0.9877476643216216, 0.4953296238242165], 
             321 -> RGBColor[
              0.8954185080912684, 0.6180016955180032, 0.23444697843546], 143 -> 
             RGBColor[
              0.987447444279098, 0.989077209870509, 0.8576918634756149], 112 -> 
             RGBColor[
              0.9949878208333023, 0.9916877805085097, 0.695833413168321], 197 -> 
             RGBColor[
              0.9867809899391911, 0.9888016138738621, 0.8687367366164181], 54 -> 
             RGBColor[
              0.9926297296346551, 0.9866440618741958, 0.43916973864756403`], 
             71 -> RGBColor[
              0.9853106881990994, 0.988193606319303, 0.8931034414686675], 177 -> 
             RGBColor[
              0.9578754373596249, 0.8695661002756608, 0.2908544580086512], 
             158 -> RGBColor[
              0.9844237480282361, 0.9878268337653283, 0.9078023354274549], 
             226 -> RGBColor[
              0.9098214810071621, 0.9309309687816517, 0.9912607791373291], 
             350 -> RGBColor[
              0.9737347405733157, 0.9799319930417697, 0.929344412519308], 203 -> 
             RGBColor[
              0.9519865742070565, 0.8473497967963235, 0.28022547446828794`], 
             115 -> RGBColor[
              0.9389391223053152, 0.7956209978115245, 0.2697271884050885], 
             173 -> RGBColor[
              0.9933091247844513, 0.9880972194022234, 0.5131177079620334], 
             212 -> RGBColor[
              0.9906183475457491, 0.9903884598597661, 0.8051417903126037], 
             129 -> RGBColor[
              0.9943879107080993, 0.9904046334109183, 0.6305368982561159], 
             279 -> RGBColor[
              0.9734830871940922, 0.9222143680177727, 0.3514872303581986], 26 -> 
             RGBColor[
              0.9510179452969362, 0.9629898443199842, 0.9677980214331078], 40 -> 
             RGBColor[
              0.9730938926549318, 0.9794540497135312, 0.9304292008852258], 
             146 -> RGBColor[
              0.9949849766165239, 0.9916816970164151, 0.6955238377244581], 
             386 -> RGBColor[
              0.9903255727879959, 0.9902673899734671, 0.8099938257253583], 
             192 -> RGBColor[
              0.965686289860952, 0.9739294716786173, 0.9429683402032024], 300 -> 
             RGBColor[
              0.9885040862848182, 0.9895141584943351, 0.840180570938976], 221 -> 
             RGBColor[
              0.9936423506204256, 0.9888099557710723, 0.5493872837763497], 62 -> 
             RGBColor[
              0.994942620119137, 0.9915911007514036, 0.6909135943779103], 286 -> 
             RGBColor[
              0.9432962836346874, 0.8128956905445441, 0.2732330626864227], 
             152 -> RGBColor[
              0.948393659342362, 0.8331050866257135, 0.2773345308316036], 64 -> 
             RGBColor[
              0.9720260933553022, 0.9172995856811123, 0.3458270844246991], 
             307 -> RGBColor[
              0.9938004243026276, 0.9891480593936016, 0.5665926285663556], 37 -> 
             RGBColor[
              0.9856800612332861, 0.9633576254376677, 0.39887017129518854`], 
             148 -> RGBColor[
              0.9370599424048115, 0.9525799886171699, 0.991425279499281], 261 -> 
             RGBColor[
              0.9938004243026276, 0.9891480593936016, 0.5665926285663556], 
             387 -> RGBColor[
              0.9845740062149192, 0.987888969386981, 0.9053121684183951], 15 -> 
             RGBColor[
              0.9938294178091519, 0.9917163199344248, 0.7519260460645596], 
             136 -> RGBColor[
              0.9739722181633338, 0.9801091034395712, 0.9289424249034826], 
             198 -> RGBColor[
              0.9917091366772095, 0.990839529197627, 0.7870645915325221], 63 -> 
             RGBColor[
              0.9918624310209864, 0.9909029203482637, 0.7845241075430938], 
             310 -> RGBColor[
              0.9704684712615343, 0.9120453606117732, 0.33977601672266156`], 
             171 -> RGBColor[
              0.9785960700029306, 0.9394616596174389, 0.3713502030647509], 
             395 -> RGBColor[
              0.9342460537851862, 0.9504064601274819, 0.9935904166929707], 
             311 -> RGBColor[
              0.9483385084688061, 0.9609915247207399, 0.9723336090740845], 
             353 -> RGBColor[
              0.994140346220653, 0.9898751180048799, 0.6035910315885024], 59 -> 
             RGBColor[
              0.9946417357761907, 0.9909475395659151, 0.6581641904911328], 
             397 -> RGBColor[
              0.9382698380990961, 0.9534823268449449, 0.9893772416801928], 
             229 -> RGBColor[
              0.982246858988142, 0.9517766281105748, 0.38553282887864637`], 
             102 -> RGBColor[
              0.9700674093145114, 0.9771969033936573, 0.9355522477472833], 
             299 -> RGBColor[
              0.9941360259908831, 0.9898658774702446, 0.603120801239426], 128 -> 
             RGBColor[
              0.992677031988194, 0.9867452368254138, 0.444318307913977], 12 -> 
             RGBColor[
              0.992993294708775, 0.9874216908056707, 0.4787415533019541], 222 -> 
             RGBColor[
              0.9403408882261085, 0.8011785325766676, 0.27085508216863396`], 
             92 -> RGBColor[
              0.9616288010679848, 0.8822270773956667, 0.3054355672523673], 
             271 -> RGBColor[
              0.9611828526434771, 0.8807227886461332, 0.303703141833449], 361 -> 
             RGBColor[
              0.9938004243026276, 0.9891480593936016, 0.5665926285663556], 
             344 -> RGBColor[
              0.8889651306107735, 0.5886984156036796, 0.2290621220789779], 
             132 -> RGBColor[
              0.9934456834546253, 0.9883893045895258, 0.5279812764680327], 80 -> 
             RGBColor[
              0.9941453973813839, 0.9898859219269326, 0.6041408192619102], 
             324 -> 
             RGBColor[
              0.9419607858129092, 0.9562350296065345, 0.9831294299540454], 
             244 -> RGBColor[
              0.9729763510211917, 0.9205050279192678, 0.3495186560155769], 
             150 -> RGBColor[
              0.9952521118720514, 0.9922530723164713, 0.7245998617209434], 
             125 -> RGBColor[
              0.986159091273223, 0.9885444427934176, 0.8790432069336647], 258 -> 
             RGBColor[
              0.9597875475867418, 0.8760160970565576, 0.2982826451692823], 
             133 -> RGBColor[
              0.9850471875063367, 0.9880846420111867, 0.8974703298656781], 
             255 -> RGBColor[
              0.8943965983947665, 0.6133614422592613, 0.23359427193539992`], 
             326 -> RGBColor[
              0.985823915697687, 0.988405839079314, 0.8845979336268802], 176 -> 
             RGBColor[
              0.9949881579920441, 0.9916885016569666, 0.6958701108166728], 
             230 -> RGBColor[
              0.9903999861529411, 0.9902981618122081, 0.8087606036926014], 
             274 -> RGBColor[
              0.9935302203558634, 0.9885701204732824, 0.5371825964665263], 87 -> 
             RGBColor[
              0.9950096597729474, 0.9917344917921552, 0.6982104469743815], 
             130 -> RGBColor[
              0.9942718844435022, 0.9901564649630001, 0.6179081553858317], 35 -> 
             RGBColor[
              0.9890957176060038, 0.9748794364170996, 0.41213935131061424`], 
             379 -> RGBColor[
              0.9938685344697678, 0.9892937401541201, 0.5740059999323313], 31 -> 
             RGBColor[
              0.9873643008652225, 0.9890428279321831, 0.8590697650117892], 18 -> 
             RGBColor[
              0.9757746497882354, 0.9299443467323018, 0.36038951831116], 24 -> 
             RGBColor[
              0.9947501024963274, 0.9911793250227314, 0.6699592392161378], 
             151 -> RGBColor[
              0.9948196815320426, 0.9913281475446064, 0.6775324878616951], 
             137 -> RGBColor[
              0.9551358719446321, 0.9660609872713498, 0.9608274457458381], 
             330 -> RGBColor[
              0.9918005020309433, 0.9840033093960046, 0.4226469280458245], 
             296 -> RGBColor[
              0.9938537057761231, 0.9917263636329396, 0.7515235315966036], 
             266 -> RGBColor[
              0.9557939803484155, 0.8624448934039275, 0.28328900282093394`], 
             302 -> RGBColor[
              0.973870146873396, 0.9235200112019989, 0.3529908841222066], 283 -> 
             RGBColor[
              0.9947414848927328, 0.9911608928400159, 0.6690212662465478], 
             388 -> RGBColor[
              0.9925749330113772, 0.9865268574377929, 0.4332054643693218], 
             284 -> RGBColor[
              0.9709442654555915, 0.9136503261501175, 0.3416243873203794], 
             318 -> RGBColor[
              0.9854818464273158, 0.9882643846452364, 0.8902669066838245], 
             238 -> RGBColor[
              0.6549385558969484, 0.7303622446748619, 0.9662418125691742], 72 -> 
             RGBColor[
              0.9468802532697379, 0.9599039603809486, 0.9748020547522382], 
             288 -> RGBColor[
              0.9797575814313416, 0.9844238178921887, 0.9191493139551459], 
             382 -> RGBColor[
              0.9923687930779437, 0.9911123140717267, 0.7761323778363144], 
             389 -> RGBColor[
              0.9914513230688516, 0.9907329166450635, 0.7913372302232413], 
             172 -> RGBColor[
              0.9945378975082619, 0.9907254400104747, 0.6468620358425874], 
             243 -> RGBColor[
              0.9943477854871444, 0.9919306782907163, 0.7433353521476764], 88 -> 
             RGBColor[
              0.992586042755603, 0.9865506200573243, 0.4344146914669029], 273 -> 
             RGBColor[
              0.9446530650501059, 0.8182748767360739, 0.2743247608610215], 
             202 -> RGBColor[
              0.9937386277347002, 0.9916787759054405, 0.7534306725554052], 
             393 -> RGBColor[
              0.9598901569501922, 0.9696067252440693, 0.9527796813475453], 98 -> 
             RGBColor[
              0.9952070062746166, 0.9921565960044336, 0.7196903957996389], 30 -> 
             RGBColor[
              0.9932679075479811, 0.9914841210112751, 0.7612317242341349], 
             116 -> RGBColor[
              0.9796644632363769, 0.984354370494851, 0.9193069387701063], 373 -> 
             RGBColor[
              0.9947445850119019, 0.9911675236814482, 0.6693586950863759], 
             240 -> RGBColor[
              0.9950350739159465, 0.9917888500742663, 0.7009766196019266], 
             317 -> RGBColor[
              0.9687628484944493, 0.906291894519125, 0.3331499943523691], 391 -> 
             RGBColor[
              0.9898967491740833, 0.9775815039873881, 0.41525120769048435`], 
             73 -> RGBColor[
              0.9941987239903394, 0.9899999821513413, 0.6099450915530366], 
             303 -> RGBColor[
              0.9841150201413159, 0.9876735885474365, 0.9117733068211894], 29 -> 
             RGBColor[
              0.9948550290767583, 0.9921404365505874, 0.7349290131634435], 
             360 -> RGBColor[
              0.963212455983325, 0.8875691172849666, 0.3115877675503277], 320 -> 
             RGBColor[
              0.9918005020309433, 0.9840033093960046, 0.4226469280458245], 75 -> 
             RGBColor[
              0.9844395044112356, 0.9878333494346192, 0.9075412113849403], 
             200 -> RGBColor[
              0.9600517438645665, 0.9697272365002354, 0.9525061568501265], 
             301 -> RGBColor[
              0.9870466766704082, 0.988911482165058, 0.8643336199049286], 156 -> 
             RGBColor[
              0.9941298099713685, 0.9898525820330386, 0.6024442258760762], 25 -> 
             RGBColor[
              0.9939055100943244, 0.9893728272762375, 0.5780305684782139], 38 -> 
             RGBColor[
              0.9890876453135512, 0.9897554751494991, 0.8305094876305164], 
             365 -> RGBColor[
              0.9823071932104718, 0.9863253141824577, 0.9148334862583303], 
             380 -> RGBColor[
              0.9951064241821348, 0.99224439488722, 0.7307627456776785], 370 -> 
             RGBColor[
              0.975922953420616, 0.9304446097076704, 0.36096564991816776`], 3 -> 
             RGBColor[
              0.9778376001326536, 0.982991898983308, 0.9223993414825024], 57 -> 
             RGBColor[
              0.9562935821696698, 0.9669244056616063, 0.9588677443140348], 
             227 -> RGBColor[
              0.7810985330967374, 0.8289193777146768, 0.9788162600644315], 39 -> 
             RGBColor[
              0.9761283043504456, 0.9311373066126772, 0.36176339950328695`], 
             109 -> RGBColor[
              0.9933315207072109, 0.9915104266874003, 0.7601774895601182], 
             256 -> RGBColor[
              0.9933863351183473, 0.9882623644992645, 0.5215215763196526], 
             339 -> RGBColor[
              0.9379386692942421, 0.7916545350038224, 0.2689222004287287], 
             287 -> RGBColor[
              0.994171144227184, 0.9899409918266936, 0.6069432045361356], 239 -> 
             RGBColor[
              0.9276368088726618, 0.7508110913237375, 0.2606330817177819], 
             285 -> RGBColor[
              0.8644779408163475, 0.4775078058756709, 0.2086294106785616], 
             345 -> RGBColor[
              0.9342460537851862, 0.9504064601274819, 0.9935904166929707], 
             366 -> RGBColor[
              0.9949649670061508, 0.991638898483109, 0.6933459151203525], 216 -> 
             RGBColor[
              0.99317950942163, 0.9878199852472719, 0.499009875612222], 21 -> 
             RGBColor[
              0.9932998029540753, 0.9880772809496307, 0.5121030842532648], 
             355 -> RGBColor[
              0.9936337070987658, 0.988791468152236, 0.5484464897853084], 175 -> 
             RGBColor[
              0.9934770553788347, 0.9915706090141871, 0.7577656034196547], 7 -> 
             RGBColor[
              0.8917833417618298, 0.6014952542306892, 0.2314137065440959], 13 -> 
             RGBColor[
              0.9944402362149154, 0.991968909042525, 0.7418032043336972], 294 -> 
             RGBColor[
              0.9236223106854973, 0.9419353757536142, 0.9925771145921949], 
             193 -> RGBColor[
              0.9627287924125267, 0.8859376064910569, 0.30970882590997756`], 
             60 -> RGBColor[
              0.8665918951819418, 0.4871067789232486, 0.21039334601897663`], 
             65 -> RGBColor[
              0.9839067509197774, 0.9573758333571407, 0.3919811955887608], 69 -> 
             RGBColor[
              0.9363397900431316, 0.9520429001649702, 0.9926443096017877], 
             217 -> RGBColor[
              0.9460732681962907, 0.8239055089560531, 0.27546748964889417`], 
             214 -> RGBColor[
              0.9098214810071621, 0.9309309687816517, 0.9912607791373291], 
             170 -> RGBColor[
              0.9943009271845134, 0.9902185844493513, 0.6210692785138685], 
             359 -> RGBColor[
              0.9653472532403706, 0.9736766187221093, 0.9435422407669339], 74 -> 
             RGBColor[
              0.9933634519416855, 0.9882134196982291, 0.5190308837586193], 
             246 -> RGBColor[
              0.9836438625711944, 0.9873222000030896, 0.91257085368983], 264 -> 
             RGBColor[
              0.9855236168040903, 0.9882816577694823, 0.8895746634424012], 
             278 -> RGBColor[
              0.9397415302037582, 0.9545799124069272, 0.986886050825775], 45 -> 
             RGBColor[
              0.9528683034199577, 0.8508455593066345, 0.280934934489833], 306 -> 
             RGBColor[
              0.9747563497881254, 0.9806939075214433, 0.927615094596992], 237 -> 
             RGBColor[
              0.9795940364709234, 0.984301846328489, 0.9194261529137768], 228 -> 
             RGBColor[
              0.9947439420104266, 0.99116614836631, 0.6692887083439342], 180 -> 
             RGBColor[
              0.9746610156585515, 0.9806228074837022, 0.9277764704112376], 
             383 -> RGBColor[
              0.9243930982533513, 0.7379508596206583, 0.25802311601381056`], 
             53 -> RGBColor[
              0.966395384227831, 0.9744583130964003, 0.9417680284015066], 304 -> R\
GBColor[0.9793742926476322, 0.942086787333384, 0.3743734510844018], 48 -> 
             RGBColor[
              0.9573119033973987, 0.9676838679658986, 0.9571439920962022], 5 -> 
             RGBColor[
              0.9773461096791001, 0.9826253462077895, 0.9232313066191282], 
             101 -> RGBColor[
              0.9941844155431551, 0.9899693778296199, 0.6083877053785195], 
             333 -> RGBColor[
              0.9058436762757248, 0.6644085827078161, 0.24309781567971767`], 
             267 -> RGBColor[
              0.9948712080410473, 0.9914383575372384, 0.6831408303821116], 
             120 -> RGBColor[
              0.9860023406911219, 0.9884796223994126, 0.8816409697365817], 
             147 -> RGBColor[
              0.8915745525724958, 0.600547191285878, 0.23123948772662434`], 
             89 -> RGBColor[
              0.979084294253665, 0.983921681417484, 0.9202890135255325], 43 -> 
             RGBColor[
              0.9324875136836944, 0.7700425194979253, 0.2645360726694146], 
             199 -> RGBColor[
              0.8807184454055141, 0.5512521441488608, 0.22218088579895753`], 
             268 -> RGBColor[
              0.9920099475480204, 0.9909639222231941, 0.7820793769296058], 
             169 -> RGBColor[
              0.9797037948092489, 0.9431982754953036, 0.37565350476102016`], 
             20 -> RGBColor[
              0.5259838136397934, 0.6260563810703836, 0.9558265190333706], 4 -> 
             RGBColor[
              0.9949564252678265, 0.9921823664813573, 0.7332486158725127], 
             167 -> RGBColor[
              0.9945292315015024, 0.9907069042982837, 0.6459187944872057], 
             142 -> RGBColor[
              0.8995683727020136, 0.6368452614898926, 0.23790972718915562`], 
             16 -> RGBColor[
              0.8486249355530403, 0.8821345045725093, 0.985423798001114], 281 -> 
             RGBColor[
              0.9894700911901236, 0.9899136263478726, 0.8241713697175088], 
             289 -> RGBColor[
              0.9524564878666042, 0.9640627070130453, 0.9653629440946513], 
             398 -> RGBColor[
              0.9520150466006455, 0.9637334808396871, 0.9661101890115977], 
             178 -> RGBColor[
              0.9926364829760528, 0.9866585065885778, 0.4399047981819029], 58 -> 
             RGBColor[
              0.9930184564014798, 0.9874755091221287, 0.4814802482728976], 
             186 -> RGBColor[
              0.9830791307827003, 0.9545840763003303, 0.38876604763916484`], 
             122 -> RGBColor[
              0.9930041452979421, 0.9874448991187361, 0.47992257297071517`], 
             249 -> 
             RGBColor[
              0.9940473838439952, 0.9896762808811469, 0.5934726505865857], 
             113 -> RGBColor[
              0.9870460304795592, 0.9889112149485355, 0.8643443289595867], 52 -> 
             RGBColor[
              0.981802963563706, 0.9859492605375002, 0.9156870155261506], 187 -> 
             RGBColor[
              0.9922036084067427, 0.9853630818554538, 0.42421292019555346`], 
             259 -> RGBColor[
              0.9920732980516155, 0.9909901192844642, 0.7810294951391874], 42 -> 
             RGBColor[
              0.9257398581980544, 0.9436238506608312, 0.9927790881642996], 
             134 -> RGBColor[
              0.9951904034059628, 0.9921210841471906, 0.7178832760076965], 
             313 -> RGBColor[
              0.9913313828392262, 0.9824208602079182, 0.42082448857172916`], 
             248 -> RGBColor[
              0.9579089525253179, 0.9681291462279226, 0.9561333436579866], 
             174 -> RGBColor[
              0.9860515209784125, 0.9884999597120829, 0.8808259251016736], 
             215 -> RGBColor[
              0.9790650142300577, 0.9839073024074457, 0.9203216495764643], 
             399 -> RGBColor[
              0.9898809620241366, 0.9900835319966358, 0.8173621766982807], 83 -> 
             RGBColor[
              0.9755004079475695, 0.9290192646086899, 0.3593241405463997], 95 -> 
             RGBColor[
              0.9918005020309433, 0.9840033093960046, 0.4226469280458245], 
             166 -> RGBColor[
              0.9874489148545759, 0.989077817991261, 0.8576674922342201], 384 -> 
             RGBColor[
              0.9928002671930106, 0.9870088244675261, 0.45773169943874104`], 
             233 -> RGBColor[
              0.991982994788309, 0.9909527765643991, 0.7825260539095307], 295 -> 
             RGBColor[
              0.8617016281139528, 0.8925615042632173, 0.9866710646112751], 
             141 -> RGBColor[
              0.9856193945831173, 0.9883212643424866, 0.8879873777789777], 
             319 -> RGBColor[
              0.9907838168295695, 0.9904568856609924, 0.8023995360589187], 
             205 -> RGBColor[
              0.9484200302677847, 0.8332096385574245, 0.2773557494972039], 
             224 -> RGBColor[
              0.9938139884943934, 0.9891770718282382, 0.5680690071315643], 
             231 -> RGBColor[
              0.9370599424048115, 0.9525799886171699, 0.991425279499281], 332 -> 
             RGBColor[
              0.936994372945701, 0.7879107146499613, 0.26816239742120845`], 
             68 -> RGBColor[
              0.9890876453135512, 0.9897554751494991, 0.8305094876305164], 10 -> 
             RGBColor[
              0.9691081364994101, 0.9764814792988198, 0.9371760464048301], 
             250 -> RGBColor[
              0.993083337642179, 0.9914077966119957, 0.7642905252248793], 282 -> 
             RGBColor[
              0.9063500989159035, 0.6664163797207834, 0.24350529522327258`], 
             374 -> RGBColor[
              0.9897547335131917, 0.9771024518163376, 0.41469950366532743`], 
             232 -> RGBColor[
              0.9948316533489354, 0.9913537540504038, 0.6788355462489891], 
             253 -> RGBColor[
              0.9832439131523777, 0.9551399259259927, 0.3894061960288223], 55 -> 
             RGBColor[
              0.9911076724072313, 0.9816662323910923, 0.4199554157875994], 
             325 -> RGBColor[
              0.9899141978144308, 0.9900972758500433, 0.8168113736416379], 91 -> 
             RGBColor[
              0.9850756014244958, 0.9880963918965499, 0.896999437708919], 105 -> 
             RGBColor[
              0.9946383416272412, 0.9920508307215986, 0.7385200849710855], 36 -> 
             RGBColor[
              0.993684203725647, 0.9888994753311428, 0.5539427359922721], 123 -> 
             RGBColor[
              0.9131383677304433, 0.6933296035139478, 0.24896729565259962`], 
             94 -> RGBColor[
              0.9925227534979987, 0.9864152507348342, 0.42752604635269276`], 
             312 -> RGBColor[
              0.9949040659669014, 0.9915086373181944, 0.6867172128357116], 96 -> 
             RGBColor[
              0.9943879107080993, 0.9904046334109183, 0.6305368982561159], 2 -> 
             RGBColor[
              0.979084294253665, 0.983921681417484, 0.9202890135255325], 262 -> 
             RGBColor[
              0.9322140571769504, 0.7689583555726643, 0.26431604314523915`], 
             272 -> RGBColor[
              0.9819355356003373, 0.986048132545353, 0.9154626056484587], 97 -> 
             RGBColor[
              0.9911073171182554, 0.9905906613439422, 0.7970382990834843], 
             372 -> RGBColor[
              0.9937569029886986, 0.9890549717037871, 0.5618556021275907], 
             356 -> RGBColor[
              0.9899694390677277, 0.990120119527917, 0.8158958831147273], 346 -> 
             RGBColor[
              0.9733482407034686, 0.9796437420716732, 0.9299986559836486], 
             341 -> RGBColor[
              0.9233027134606153, 0.733627847266653, 0.2571457668149546], 209 -> 
             RGBColor[
              0.9935189114502504, 0.9885459318676819, 0.5359516918810272], 
             378 -> 
             RGBColor[
              0.9596832781369848, 0.8756643717188962, 0.29787757804660986`], 
             66 -> RGBColor[
              0.9941561393261003, 0.9899088978605037, 0.6053100136526893], 
             139 -> RGBColor[
              0.790025216639289, 0.8358929707434258, 0.9797059884553524], 56 -> 
             RGBColor[
              0.9940262634677598, 0.9896311065319772, 0.5911738279732239], 
             335 -> RGBColor[
              0.9943597088780416, 0.9903443125480674, 0.6274673030958569], 
             314 -> RGBColor[
              0.9927775769352545, 0.9912813567019907, 0.7693577714219636], 
             144 -> RGBColor[
              0.9285335952171416, 0.7543665503432664, 0.2613546570608314], 
             298 -> RGBColor[
              0.9881525417831527, 0.9893687858086149, 0.8460065730995806], 
             204 -> RGBColor[
              0.9674387029661369, 0.9752364185031512, 0.940001961918662], 207 -> 
             RGBColor[
              0.9933193506738011, 0.9881190915455464, 0.5142307329108745], 
             334 -> RGBColor[
              0.9376380671922447, 0.9530111531370451, 0.99044666503325], 149 -> 
             RGBColor[
              0.9907121045578857, 0.9904272307937299, 0.8035879939861305], 
             219 -> RGBColor[
              0.9932916775514017, 0.988059901534916, 0.5112186843164118], 400 -> 
             RGBColor[
              0.9664384409310973, 0.8984511220110891, 0.3241201098962835], 9 -> 
             RGBColor[
              0.8394767073290332, 0.8748399557087261, 0.9845512318263885], 11 -> 
             RGBColor[
              0.994140346220653, 0.9898751180048799, 0.6035910315885024], 44 -> 
             RGBColor[
              0.9671561167199784, 0.9750256661434586, 0.9404803067231117], 
             153 -> RGBColor[
              0.9691884719834296, 0.9077276224886033, 0.33480346123480603`], 
             32 -> RGBColor[
              0.9846877623680699, 0.9879360104797086, 0.9034269345692009], 
             162 -> RGBColor[
              0.9888145330839186, 0.989642536223882, 0.8350356640673213], 90 -> 
             RGBColor[
              0.8666196450265513, 0.8964829974533106, 0.9871401494547642], 
             331 -> RGBColor[
              0.985307368252047, 0.9881922334358781, 0.8931584615830719], 8 -> 
             RGBColor[
              0.9856448762693298, 0.988331801674585, 0.8875650802939457], 364 -> 
             RGBColor[
              0.9930401330894056, 0.9875218733657527, 0.4838396219806145], 
             342 -> RGBColor[
              0.993540684466184, 0.9885925021471744, 0.5383215502979274], 163 -> 
             RGBColor[
              0.9710620965082933, 0.977938739474129, 0.9338685017841798], 49 -> 
             RGBColor[
              0.9646889805973781, 0.8925497815126333, 0.31732378685764656`], 
             338 -> RGBColor[
              0.9277887190117736, 0.9452575566588457, 0.9929745103377517], 76 -> 
             RGBColor[
              0.9737165363323715, 0.9230018467776533, 0.35239413617724336`], 
             369 -> RGBColor[
              0.9236223106854973, 0.9419353757536142, 0.9925771145921949], 82 -> 
             RGBColor[
              0.9943294569640032, 0.990279606762877, 0.6241745689459496], 67 -> 
             RGBColor[
              0.9695839234810397, 0.9090615732464693, 0.3363397156282721], 
             211 -> RGBColor[
              0.9894700911901236, 0.9899136263478726, 
               0.8241713697175088]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9l2k4lWvYhs1zWMs8LNZoLbMSqfBetRslSppMScqwSaE2pQyZolBokCJT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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 14}], {
             RGBColor[
             0.9495351090497173, 0.8331097574994568, 0.3017973548955175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.983052830170434, 0.9534121032554745, 0.5388717868987938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 49}], {
             RGBColor[
             0.9679698059307438, 0.9036167757364976, 0.3300691737458953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 62}], {
             RGBColor[
             0.9830966256916234, 0.9531374353558827, 0.5168640775060271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 87}], {
             RGBColor[
             0.9831301455185285, 0.9532091308762585, 0.5205125038042628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 119}], {
             RGBColor[
             0.9783963728985401, 0.951486538508053, 0.6160413344192068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 127}], {
             RGBColor[
             0.9821542243287702, 0.9511217341321336, 0.41428950498652306`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 129}], {
             RGBColor[
             0.9828192709861044, 0.95254420168564, 0.48667572944513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 216}], {
             RGBColor[
             0.9822150703428698, 0.9512518776038168, 0.420912218123183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 231}], {
             RGBColor[
             0.9541552868344605, 0.9336318792887659, 0.6671199200667126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 235}], {
             RGBColor[
             0.9831261073822504, 0.9532004937110778, 0.5200729775908828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 298}], {
             RGBColor[
             0.9797015865236312, 0.9520262778844883, 0.5944105668668623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 313}], {
             RGBColor[
             0.9812910070516678, 0.94855231508414, 0.3818195246029366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 317}], {
             RGBColor[
             0.9700067398792794, 0.9104878322397434, 0.3379822774932566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 336}], {
             RGBColor[
             0.9652111418124875, 0.9418773178290771, 0.6484052414177053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 361}], {
             RGBColor[
             0.9825255277833687, 0.9519159146769818, 0.45470359460024984`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 393}], {
             RGBColor[
             0.965570394107151, 0.9421452476022156, 0.6477971209908446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 396}], {
             RGBColor[
             0.9821981642314648, 0.9512157171409917, 0.4190720922291803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 97}], {
             RGBColor[
             0.9850958056859602, 0.9872561713807131, 0.8586636563045085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 109}], {
             RGBColor[
             0.986207907480438, 0.9877160540524421, 0.8402332515428254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 181}], {
             RGBColor[
             0.9836870927038954, 0.986673632360357, 0.8820096760496571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 191}], {
             RGBColor[
             0.9858556482518339, 0.9852799548458446, 0.679580946592578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 193}], {
             RGBColor[
             0.9709065433330959, 0.9349296439542705, 0.614998919717755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 211}], {
             RGBColor[
             0.9842771927218943, 0.9869176538826783, 0.8722301916215207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 305}], {
             RGBColor[
             0.9757942905747656, 0.9814680020606474, 0.925858131583523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 334}], {
             RGBColor[
             0.9583611807229548, 0.9684664172772646, 0.9553678392793912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 340}], {
             RGBColor[
             0.9775696377162246, 0.9574058258775238, 0.6408837831764167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 360}], {
             RGBColor[
             0.971148375118495, 0.9357453993512252, 0.6159383905379301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 365}], {
             RGBColor[
             0.9806957437320685, 0.9851234977999709, 0.9175612498919314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 370}], {
             RGBColor[
             0.9775036238371405, 0.9571831455625772, 0.6406273317218502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 11}], {
             RGBColor[
             0.9859889731766533, 0.986433508494094, 0.7629951865355024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 21}], {
             RGBColor[
             0.9855687015433645, 0.9855345899664694, 0.7172512128678836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 34}], {
             RGBColor[
             0.9826108294001664, 0.9860214486372796, 0.8905708342880154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 74}], {
             RGBColor[
             0.9856005260371696, 0.9856026593407685, 0.7207151126205609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 86}], {
             RGBColor[
             0.9816777337781017, 0.9729012033079085, 0.660319710227298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 91}], {
             RGBColor[
             0.9814566007785748, 0.985544145439929, 0.9096993895957106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 95}], {
             RGBColor[
             0.9848190510817985, 0.9834976041896563, 0.6725231347641634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 160}], {
             RGBColor[
             0.9575899559324201, 0.9678912390912484, 0.9566733216821265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[
             0.9833260666082861, 0.986317217603595, 0.8787175027749119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 233}], {
             RGBColor[
             0.9849102974604813, 0.9869723377738535, 0.8524626976960166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 263}], {
             RGBColor[
             0.9594119806261928, 0.8933647582460507, 0.596886893146271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 264}], {
             RGBColor[
             0.981680608468372, 0.9856367783763951, 0.9059870024624518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 285}], {
             RGBColor[
             0.9211577704745006, 0.7302498524294894, 0.565514376080532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 312}], {
             RGBColor[
             0.9863708330497776, 0.9872502681507511, 0.804558277159107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 348}], {
             RGBColor[
             0.9817875019694509, 0.9856809815861289, 0.9042155005180614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 13}], {
             RGBColor[
             0.9946983307413709, 0.9920756377619411, 0.7375259101031049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 66}], {
             RGBColor[
             0.9945562822969634, 0.9910456321709304, 0.669279314762601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 123}], {
             RGBColor[
             0.954047396499135, 0.8427559849976525, 0.49110795576255617`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 131}], {
             RGBColor[
             0.9949378821230392, 0.9921746984144506, 0.7335559237697586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 140}], {
             RGBColor[
             0.9919214731055972, 0.9909273357675625, 0.7835456274050759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 183}], {
             RGBColor[
             0.9943380502436706, 0.9919266525173556, 0.7434966903260394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 186}], {
             RGBColor[
             0.9890177780252634, 0.9733832213908438, 0.5610073317558387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 188}], {
             RGBColor[
             0.9915725091221836, 0.9907830301924557, 0.7893288637000779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 203}], {
             RGBColor[
             0.9734714997374414, 0.9197660816388404, 0.5067370451704003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 232}], {
             RGBColor[
             0.9948940393083809, 0.9917680602658805, 0.7060420810607508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 238}], {
             RGBColor[
             0.8249474905823875, 0.8612723055781095, 0.8497452142208435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 275}], {
             RGBColor[
             0.9510849891245148, 0.9605169221227149, 0.8621303242533005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 280}], {
             RGBColor[
             0.982179092471684, 0.984441414732086, 0.8349638174146707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 297}], {
             RGBColor[
             0.9843197756707129, 0.9575357563055351, 0.542756479751712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 309}], {
             RGBColor[
             0.9903936711258438, 0.9780244318941645, 0.5663524166359835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 322}], {
             RGBColor[
             0.9908508115531985, 0.9904845897008989, 0.8012892601115993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 325}], {
             RGBColor[
             0.9924353115411286, 0.9911398211657003, 0.7750299947570753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 339}], {
             RGBColor[
             0.9664475472810343, 0.8919184507425899, 0.5010854081506206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 8}], {
             RGBColor[
             0.981495492974215, 0.9854785739411873, 0.9053981934565369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 43}], {
             RGBColor[
             0.9549168116813973, 0.8763339328528574, 0.5938836896442714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 56}], {
             RGBColor[
             0.9856861865734299, 0.9861282263698834, 0.7572025672961761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.9859939227276454, 0.9867864428868522, 0.7906977485551305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 90}], {
             RGBColor[
             0.9219828773528257, 0.93955417183055, 0.9551857280369462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 100}], {
             RGBColor[
             0.9855800490867468, 0.9859012090180139, 0.7456501568753462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 121}], {
             RGBColor[
             0.9821278761903505, 0.9857400806525667, 0.8949179670098683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 122}], {
             RGBColor[
             0.9851751274885211, 0.9850351226632628, 0.7015769397949216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 175}], {
             RGBColor[
             0.9854115825289673, 0.9870979776109883, 0.8404984550193915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 178}], {
             RGBColor[
             0.9849912963275764, 0.9846419263981836, 0.6815680524005155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 213}], {
             RGBColor[
             0.9270082925187475, 0.7577483019000533, 0.571017233492972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 227}], {
             RGBColor[
             0.8792223213879187, 0.9057723619612332, 0.9510237833417798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 274}], {
             RGBColor[
             0.9854381650174817, 0.9855977333405359, 0.7302069515428273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 296}], {
             RGBColor[
             0.9855999077276116, 0.9871758549203646, 0.8373774191078659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 308}], {
             RGBColor[
             0.9796704193899997, 0.9667757405028907, 0.6538923292482852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 319}], {
             RGBColor[
             0.9840649632543348, 0.986541115934391, 0.8628154213390234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 352}], {
             RGBColor[
             0.9709007329605832, 0.9371935289561746, 0.6198237534863233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 373}], {
             RGBColor[
             0.986045347345501, 0.9868964349446189, 0.7962950008527521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 56}], {
             RGBColor[
             0.9944566347307267, 0.9905516271462538, 0.6380170840036035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 79}], {
             RGBColor[
             0.9689981868687304, 0.9018133895418023, 0.47897150290354573`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 137}], {
             RGBColor[
             0.9750114389691629, 0.9787665675159402, 0.8228438928899104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 169}], {
             RGBColor[
             0.9872954004014711, 0.967335211627917, 0.5302569223975016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 175}], {
             RGBColor[
             0.9941820306862641, 0.9915213783873589, 0.7213129717268187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 178}], {
             RGBColor[
             0.9937617444848732, 0.9890653271745542, 0.5623825691079429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 252}], {
             RGBColor[
             0.9902635985247357, 0.9899010059894535, 0.7862515332207161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 277}], {
             RGBColor[
             0.979230970612587, 0.9401319963318502, 0.4989281355074661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 278}], {
             RGBColor[
             0.9673142680987259, 0.9730260300837288, 0.8358731954298789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 300}], {
             RGBColor[
             0.9916955461392558, 0.9904931531274328, 0.7625204554864795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 314}], {
             RGBColor[
             0.9938322914644739, 0.9913767522312606, 0.7271090557279732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 319}], {
             RGBColor[
             0.9928354114116316, 0.9909645167107615, 0.7436299380464508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 352}], {
             RGBColor[
             0.97967118111788, 0.9416169297325452, 0.5006382701937506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 379}], {
             RGBColor[
             0.9943777702317307, 0.9903829439573253, 0.629433169983157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 65}], {
             RGBColor[
             0.9378450463408037, 0.7794355437939149, 0.3116974510664284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 67}], {
             RGBColor[
             0.9306836326214347, 0.7552784137385793, 0.283876711086184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 68}], {
             RGBColor[
             0.9404354935376905, 0.7956253646900942, 0.5309615970873062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 96}], {
             RGBColor[
             0.9430856262349645, 0.7959499438208038, 0.43097530240010595`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 173}], {
             RGBColor[
             0.9425462332731406, 0.7947962368164563, 0.3722657072530646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[
             0.9393391186871647, 0.7951719855138533, 0.5491313656876797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 201}], {
             RGBColor[
             0.9065062190425895, 0.6634509502700154, 0.24344549616817812`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 223}], {
             RGBColor[
             0.9428441736228322, 0.7954335010980567, 0.40469467564229966`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 250}], {
             RGBColor[
             0.9424333397020044, 0.7964515254213425, 0.49785211588448763`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 387}], {
             RGBColor[
             0.9381786739883745, 0.794692111808835, 0.5683629374812456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 43}], {
             RGBColor[
             0.9590661949765121, 0.8791871605862551, 0.5760505764816801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 56}], {
             RGBColor[
             0.9898355698685448, 0.9889814541032811, 0.7393694541335848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 59}], {
             RGBColor[
             0.9901433060227602, 0.98963967062025, 0.7728646353925392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 100}], {
             RGBColor[
             0.9897294323818616, 0.9887544367514116, 0.7278170437127549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 121}], {
             RGBColor[
             0.9862772594854654, 0.9885933083859644, 0.877084853847277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 175}], {
             RGBColor[
             0.9895609658240823, 0.9899512053443861, 0.8226653418568002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 213}], {
             RGBColor[
             0.9311576758138624, 0.760601529633451, 0.5531841203303807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 227}], {
             RGBColor[
             0.8833717046830336, 0.9086255896946309, 0.9331906701791886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 237}], {
             RGBColor[
             0.9826194563701266, 0.986316824001537, 0.9034956166038612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 296}], {
             RGBColor[
             0.9897492910227265, 0.9900290826537623, 0.8195443059452746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 308}], {
             RGBColor[
             0.9838198026851146, 0.9696289682362885, 0.6360592160856939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 352}], {
             RGBColor[
             0.9750501162556982, 0.9400467566895724, 0.6019906403237321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 373}], {
             RGBColor[
             0.9901947306406158, 0.9897496626780167, 0.7784618876901608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 39}], {
             RGBColor[
             0.9078025058397394, 0.9029886311607016, 0.6731573156648377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.9171849122985611, 0.933162587433622, 0.835038373181958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 150}], {
             RGBColor[
             0.9173644096005423, 0.9335465140125987, 0.854575546773666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 192}], {
             RGBColor[
             0.9025814985949926, 0.9243847136936717, 0.9637597860147955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 283}], {
             RGBColor[
             0.917109096110883, 0.933000424274371, 0.8267862490364681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 294}], {
             RGBColor[
             0.8815495090072653, 0.9083876657311701, 0.9885641732092917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 320}], {
             RGBColor[
             0.9156386046799883, 0.9294216325523653, 0.7035990799361065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 347}], {
             RGBColor[
             0.9171091586927157, 0.9334667452898293, 0.8606799458381074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 381}], {
             RGBColor[
             0.9169502790035184, 0.9326607305405907, 0.8094999870054052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 384}], {
             RGBColor[
             0.9161384872610219, 0.9309243900881261, 0.7211414656325648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.9814687771542809, 0.9840988996166222, 0.8445510462346948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 37}], {
             RGBColor[
             0.9773940988663481, 0.9699195523682438, 0.6680231088500093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 62}], {
             RGBColor[
             0.9820253783092736, 0.9840362900251116, 0.8140448203913702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 87}], {
             RGBColor[
             0.9820588981361787, 0.9841079855454875, 0.8176932466896059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 155}], {
             RGBColor[
             0.9638083369354515, 0.9725288974616448, 0.9461472246575078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 170}], {
             RGBColor[
             0.9817045318419617, 0.9833500318740855, 0.7791226624593492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 216}], {
             RGBColor[
             0.98114382296052, 0.9821507322730458, 0.718092961008526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 256}], {
             RGBColor[
             0.9812472358088786, 0.9823719218990421, 0.7293488113622413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 261}], {
             RGBColor[
             0.9814542804010189, 0.9828147693462107, 0.7518843374855928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 298}], {
             RGBColor[
             0.9786303391412814, 0.9829251325537174, 0.8915913097522054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 311}], {
             RGBColor[
             0.9587233224841081, 0.9687365020097798, 0.9547548277394573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 313}], {
             RGBColor[
             0.9802197596693181, 0.979451169753369, 0.6790002674882796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 361}], {
             RGBColor[
             0.9814542804010189, 0.9828147693462107, 0.7518843374855928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 396}], {
             RGBColor[
             0.981126916849115, 0.9821145718102207, 0.7162528351145233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 34}], {
             RGBColor[
             0.990762202444166, 0.9894630581480657, 0.7311666793410154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 35}], {
             RGBColor[
             0.9916180319133283, 0.9823772772109898, 0.5078651914495583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 85}], {
             RGBColor[
             0.9937221545181147, 0.9889806482388176, 0.5580734455472441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 86}], {
             RGBColor[
             0.9898291068221013, 0.9763428128186946, 0.500915555280298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 91}], {
             RGBColor[
             0.9896079738225744, 0.9889857549507148, 0.7502952346487106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 93}], {
             RGBColor[
             0.9935423949322555, 0.9885961606611466, 0.538507723974032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 95}], {
             RGBColor[
             0.9929704241257982, 0.9869392137004422, 0.5131189798171634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 125}], {
             RGBColor[
             0.9901497187469379, 0.9892097803991488, 0.7413171192610835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 162}], {
             RGBColor[
             0.9914774396522859, 0.9897588271143809, 0.7193133478279119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 211}], {
             RGBColor[
             0.9918052187053883, 0.9898943721763762, 0.7138812006530055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 214}], {
             RGBColor[
             0.9519809136139075, 0.9604030433932658, 0.7974259053629158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 248}], {
             RGBColor[
             0.9760246493729854, 0.9790021321164013, 0.7798621876232446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 263}], {
             RGBColor[
             0.9675633536701924, 0.8968063677568368, 0.4374827381992709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 312}], {
             RGBColor[
             0.9945222060937772, 0.9906918776615372, 0.645154122212107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.9208091151309077, 0.93477809768909, 0.7320826756515341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 17}], {
             RGBColor[
             0.9880937807869763, 0.9711970740737172, 0.43397744143995914`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 22}], {
             RGBColor[
             0.9933479536803642, 0.9881802704843774, 0.5173439936579751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 47}], {
             RGBColor[
             0.9760441623400042, 0.9305508816671251, 0.3871669491529826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 106}], {
             RGBColor[
             0.9939432059884321, 0.9894534549820944, 0.5821335339197408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 107}], {
             RGBColor[
             0.9649415992302872, 0.8874591099570537, 0.3734099461787711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 118}], {
             RGBColor[
             0.9913478165646071, 0.9821737008356008, 0.4466187559629608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 158}], {
             RGBColor[
             0.9887085213685055, 0.9876242622854995, 0.6932719443647045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 209}], {
             RGBColor[
             0.9932561030795126, 0.9879838113366763, 0.5073466225914907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 241}], {
             RGBColor[
             0.992696844905828, 0.989273536563422, 0.627175101900819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 270}], {
             RGBColor[
             0.9838748222484501, 0.984057799163557, 0.7031783239494731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 310}], {
             RGBColor[
             0.9817308829851547, 0.9497335257087219, 0.40925878501230784`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 323}], {
             RGBColor[
             0.9869812988521656, 0.9674444112844209, 0.42965565919780524`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 324}], {
             RGBColor[
             0.9674770402608421, 0.9718283602061026, 0.7309354916279998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 346}], {
             RGBColor[
             0.9831707677061218, 0.9835327164386719, 0.7043701046428014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 390}], {
             RGBColor[
             0.9939978382413177, 0.9895703078468489, 0.5880799174951675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 66}], {
             RGBColor[
             0.9942981877705078, 0.9909389034515144, 0.6735566089931933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 123}], {
             RGBColor[
             0.9537893019726793, 0.8426492562782364, 0.49538524999314837`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 131}], {
             RGBColor[
             0.9946797875965836, 0.9920679696950345, 0.7378332180003508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[
             0.9916633785791416, 0.9908206070481465, 0.7878229216356682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 188}], {
             RGBColor[
             0.9913144145957281, 0.9906763014730395, 0.7936061579306702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 203}], {
             RGBColor[
             0.973213405210986, 0.9196593529194242, 0.5110143394009925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 232}], {
             RGBColor[
             0.9946359447819254, 0.9916613315464644, 0.7103193752913431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 275}], {
             RGBColor[
             0.9508268945980592, 0.9604101934032987, 0.8664076184838927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 280}], {
             RGBColor[
             0.9819209979452285, 0.9843346860126698, 0.8392411116452629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 297}], {
             RGBColor[
             0.9840616811442574, 0.957429027586119, 0.5470337739823043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 309}], {
             RGBColor[
             0.9901355765993882, 0.9779177031747484, 0.5706297108665758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 322}], {
             RGBColor[
             0.990592717026743, 0.9903778609814827, 0.8055665543421916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 325}], {
             RGBColor[
             0.9921772170146731, 0.9910330924462841, 0.7793072889876675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 339}], {
             RGBColor[
             0.9661894527545787, 0.8918117220231737, 0.505362702381213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 29}], {
             RGBColor[
             0.9613373079560417, 0.8718380907945695, 0.49785458116016723`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 62}], {
             RGBColor[
             0.961381103477231, 0.8715634228949776, 0.4758468717674006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 119}], {
             RGBColor[
             0.9566808506841478, 0.8699125260471479, 0.5750241286805802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 126}], {
             RGBColor[
             0.9542875642889888, 0.868351920048453, 0.5891200883073613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 127}], {
             RGBColor[
             0.9604387021143779, 0.8695477216712286, 0.37327229924789646`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 129}], {
             RGBColor[
             0.9611037487717121, 0.870970189224735, 0.4456585237065034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 196}], {
             RGBColor[
             0.9610636083474007, 0.8708843329159524, 0.4412894862381884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 235}], {
             RGBColor[
             0.961410585167858, 0.8716264812501728, 0.47905577185225623`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 317}], {
             RGBColor[
             0.9482912176648871, 0.8289138197788384, 0.29696507175463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 326}], {
             RGBColor[
             0.956821751266506, 0.8699707920589328, 0.5726890413918855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 327}], {
             RGBColor[
             0.9613910730130475, 0.8718603240273404, 0.4969635550260736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 336}], {
             RGBColor[
             0.9434956195980951, 0.8603033053681721, 0.6073880356790786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 396}], {
             RGBColor[
             0.9604826420170725, 0.8696417046800866, 0.37805488649055374`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 33}], {
             RGBColor[
             0.9927972675240078, 0.9878001340590002, 0.587217755437506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 37}], {
             RGBColor[
             0.989754739521219, 0.9775369726860462, 0.5753981086798741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.9943860189641445, 0.9916537103429142, 0.721419820221235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 92}], {
             RGBColor[
             0.9777291094385683, 0.9369716986650458, 0.5286808066584634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 256}], {
             RGBColor[
             0.9936078764637496, 0.9899893422168446, 0.6367238111921061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 311}], {
             RGBColor[
             0.9710839631389789, 0.9763539223275823, 0.8621298275693221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 313}], {
             RGBColor[
             0.992580400324189, 0.9870685900711715, 0.5863752673181444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 361}], {
             RGBColor[
             0.9938149210558898, 0.9904321896640131, 0.6592593373154576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 386}], {
             RGBColor[
             0.9920774952985739, 0.9909918549539459, 0.7809599358949589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 69}], {
             RGBColor[
             0.892482362798086, 0.9170887023687397, 0.9890340538014508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 106}], {
             RGBColor[
             0.9217590264105647, 0.9368098618655136, 0.8354746562693207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 107}], {
             RGBColor[
             0.8927574196524198, 0.834815516840473, 0.626751068528351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 190}], {
             RGBColor[
             0.9217404167599301, 0.9367700577045305, 0.8334491106431896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 212}], {
             RGBColor[
             0.9196216415493947, 0.9362614822161377, 0.8952827941568589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 241}], {
             RGBColor[
             0.9205126653279607, 0.9366299434468413, 0.880516224250399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 268}], {
             RGBColor[
             0.9203174415505304, 0.9365492133978517, 0.8837515874653599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 270}], {
             RGBColor[
             0.9116906426705829, 0.9314142060469763, 0.9565194462990529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 274}], {
             RGBColor[
             0.9210775779544518, 0.9353523125228959, 0.7613031972338202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 295}], {
             RGBColor[
             0.8551632818334965, 0.8873480044178633, 0.9860474313061945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 310}], {
             RGBColor[
             0.9095467034072873, 0.8970899325921413, 0.6625999073618878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 324}], {
             RGBColor[
             0.8952928606829748, 0.9191847670895219, 0.9842766139775797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 351}], {
             RGBColor[
             0.9168116821193649, 0.935099491779157, 0.941851093854349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 373}], {
             RGBColor[
             0.9216847602824711, 0.9366510141269788, 0.827391246543745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 380}], {
             RGBColor[
             0.9218656798675875, 0.9371894497298647, 0.8580932718393963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 390}], {
             RGBColor[
             0.9218136586634504, 0.9369267147302682, 0.8414210398447475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 22}], {
             RGBColor[
             0.9884484397585654, 0.971955653752424, 0.47257988179598015`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 48}], {
             RGBColor[
             0.970253085131288, 0.9613281626538313, 0.6731786608370831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 61}], {
             RGBColor[
             0.961767577545643, 0.8780754949592158, 0.33003420587329907`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 118}], {
             RGBColor[
             0.9864483026428084, 0.9659490841036474, 0.40185464410096583`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 158}], {
             RGBColor[
             0.9838090074467067, 0.9713996455535461, 0.6485078325027096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 164}], {
             RGBColor[
             0.9599698383957516, 0.870948058290955, 0.32858770275493504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 173}], {
             RGBColor[
             0.9882516958248144, 0.9715348383719936, 0.4511655187699988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 209}], {
             RGBColor[
             0.988356589157714, 0.9717591946047228, 0.4625825107294957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 241}], {
             RGBColor[
             0.9877973309840293, 0.9730489198314686, 0.5824109900388241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 287}], {
             RGBColor[
             0.9886827055461808, 0.9724567245842287, 0.4980782670570499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 323}], {
             RGBColor[
             0.9820817849303669, 0.9512197945524674, 0.38489154733581027`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 346}], {
             RGBColor[
             0.978271253784323, 0.9673080997067185, 0.6596059927808064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 354}], {
             RGBColor[
             0.9694105942219357, 0.9083775091963897, 0.3361839564957033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 371}], {
             RGBColor[
             0.9888309090896763, 0.9727737169780888, 0.5142093081602838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 388}], {
             RGBColor[
             0.9878845999382774, 0.9707496573897784, 0.411209396973643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 389}], {
             RGBColor[
             0.9873227949670146, 0.9728526869934137, 0.5902752799006028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 45}], {
             RGBColor[
             0.9643214766040965, 0.8903949530194681, 0.32066222640049646`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 74}], {
             RGBColor[
             0.9845690508649605, 0.9590788832152655, 0.43971020103488967`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 86}], {
             RGBColor[
             0.9806462586058926, 0.9463774271824055, 0.37931479864162676`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 91}], {
             RGBColor[
             0.9804251256063656, 0.9590203693144258, 0.6286944780100394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 112}], {
             RGBColor[
             0.9853812353107688, 0.9608160636204057, 0.5281114657397405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 141}], {
             RGBColor[
             0.9806970221856763, 0.9591328055373942, 0.6241884480450688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 148}], {
             RGBColor[
             0.9564172960965234, 0.9412621676747358, 0.6759073989052204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 179}], {
             RGBColor[
             0.9828444238013331, 0.9600208112911726, 0.5886004459763989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 232}], {
             RGBColor[
             0.9853031515685854, 0.9606490503913527, 0.5196125322800745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 257}], {
             RGBColor[
             0.9849488442980188, 0.9598912229655707, 0.4810483724099033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 279}], {
             RGBColor[
             0.9746288684911637, 0.9260793573750372, 0.35593837433467934`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 285}], {
             RGBColor[
             0.9201262953022915, 0.7037260763039863, 0.2845094644948608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 288}], {
             RGBColor[
             0.9777661156097885, 0.9571840823122453, 0.6397694161331529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 399}], {
             RGBColor[
             0.9828278059061859, 0.9600139393644688, 0.5888758475047203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 185}], {
             RGBColor[
             0.9210650712519844, 0.74750004087325, 0.5772046600512203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 198}], {
             RGBColor[
             0.9801169092243421, 0.983442934457836, 0.862614137301191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 205}], {
             RGBColor[
             0.9584723560196298, 0.9046279891377348, 0.6077597162835319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 219}], {
             RGBColor[
             0.9809081796614383, 0.9820531206264805, 0.7246911836931358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 262}], {
             RGBColor[
             0.9503693694742126, 0.8725023476453547, 0.6012398631075495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 284}], {
             RGBColor[
             0.9697344736135332, 0.9448483329340813, 0.6398940351951197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 293}], {
             RGBColor[
             0.980922016222638, 0.9820827156317957, 0.7261972079903671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 331}], {
             RGBColor[
             0.9769160250117609, 0.9821192865769617, 0.9156610723264659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 338}], {
             RGBColor[
             0.9481567003916243, 0.9606519481884455, 0.9655690967038058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.7435833331416353, 0.7533895848582584, 0.6297648304334098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 36}], {
             RGBColor[
             0.7598340086827202, 0.8074779282007631, 0.7548846275128214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 80}], {
             RGBColor[
             0.7600646055105886, 0.8079711514986581, 0.7799836691476404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 151}], {
             RGBColor[
             0.7604017475859179, 0.808692264307495, 0.8166795034475328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 168}], {
             RGBColor[
             0.7486629537017742, 0.8021019710195914, 0.9446105292495168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 265}], {
             RGBColor[
             0.7463447677655617, 0.8003730717440452, 0.9485346133597996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 291}], {
             RGBColor[
             0.7339965953050207, 0.7169249577633248, 0.6140120532050017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 304}], {
             RGBColor[
             0.7526790531437129, 0.7840715842018838, 0.6650999850588861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 378}], {
             RGBColor[
             0.7428335458883891, 0.75086037639464, 0.6268520485399902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 383}], {
             RGBColor[
             0.7251884559465723, 0.682003620345521, 0.6069248175235906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 24}], {
             RGBColor[
             0.9940249527252014, 0.989628302986181, 0.5910311617347013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 25}], {
             RGBColor[
             0.9936026565241998, 0.9887250541129341, 0.5450668263657393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 27}], {
             RGBColor[
             0.993540669507483, 0.9885924701520257, 0.5383199221356372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 32}], {
             RGBColor[
             0.9889937826610726, 0.9880066457146697, 0.7077650094112329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 78}], {
             RGBColor[
             0.9757798058748128, 0.9782340476047091, 0.7338212598818593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 95}], {
             RGBColor[
             0.9925501524925093, 0.9860402951728175, 0.46737500614954464`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 104}], {
             RGBColor[
             0.9929665301774806, 0.9896494789076586, 0.641926301923349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 160}], {
             RGBColor[
             0.9653210573431309, 0.9704339300744097, 0.7515251930675078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 172}], {
             RGBColor[
             0.9939188502311687, 0.9894013604800527, 0.5794825600479261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 208}], {
             RGBColor[
             0.9459642898861425, 0.8103280284896821, 0.37461439480268593`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 217}], {
             RGBColor[
             0.9696865355751829, 0.9059913949528419, 0.3937852869510795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 230}], {
             RGBColor[
             0.9918498945535081, 0.9891877213809194, 0.6604318439729331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 233}], {
             RGBColor[
             0.9926413988711922, 0.9895150287570149, 0.6473145690813977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 240}], {
             RGBColor[
             0.9941674384350109, 0.9899330655119485, 0.6065398519275957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 242}], {
             RGBColor[
             0.9567796571621309, 0.8548199230073572, 0.38340010961656323`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 244}], {
             RGBColor[
             0.9831380769876334, 0.9542911544344492, 0.4308108701344209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 264}], {
             RGBColor[
             0.9894117098790828, 0.9881794693595565, 0.700838873847833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 285}], {
             RGBColor[
             0.9288888718852114, 0.7327925434126508, 0.36036624746591317`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 357}], {
             RGBColor[
             0.9928342980160094, 0.9895947975106787, 0.6441177310447896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 47}], {
             RGBColor[
             0.9763988213115935, 0.9313094613458319, 0.4257693895090036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.975507258024676, 0.9783113590644914, 0.7565452130550991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 96}], {
             RGBColor[
             0.9940452616800264, 0.9896717417870012, 0.593241666135056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 118}], {
             RGBColor[
             0.9917024755361963, 0.9829322805143076, 0.4852211963189818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 158}], {
             RGBColor[
             0.9890631803400947, 0.9883828419642062, 0.7318743847207255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 173}], {
             RGBColor[
             0.9935058687182023, 0.9885180347826538, 0.5345320709880148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 209}], {
             RGBColor[
             0.9936107620511019, 0.988742391015383, 0.5459490629475117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 241}], {
             RGBColor[
             0.9930515038774173, 0.9900321162421287, 0.66577754225684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 310}], {
             RGBColor[
             0.9820855419567438, 0.9504921053874287, 0.44786122536832884`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 323}], {
             RGBColor[
             0.9873359578237548, 0.9682029909631276, 0.46825809955382625`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 346}], {
             RGBColor[
             0.9835254266777109, 0.9842912961173786, 0.7429725449988224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 354}], {
             RGBColor[
             0.9746647671153236, 0.9253607056070499, 0.41955050871371935`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 388}], {
             RGBColor[
             0.9931387728316653, 0.9877328538004385, 0.4945759491916589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 75}], {
             RGBColor[
             0.9791281160473493, 0.9839132441644476, 0.9183734205562162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 120}], {
             RGBColor[
             0.9799095341872923, 0.9842363806468442, 0.9054232997320368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 132}], {
             RGBColor[
             0.983631205569044, 0.9841912217419009, 0.7285934530977624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 160}], {
             RGBColor[
             0.9555795197078247, 0.9663918590467323, 0.9600764658046212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 202}], {
             RGBColor[
             0.9837776777090815, 0.9858359573998582, 0.8413181511414486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 220}], {
             RGBColor[
             0.9832311029657201, 0.9833354427299696, 0.6850447538730084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 229}], {
             RGBColor[
             0.9780317933358025, 0.9658848835024254, 0.6573692293030692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 260}], {
             RGBColor[
             0.8473244108754856, 0.8809159581987089, 0.9510075471856916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 307}], {
             RGBColor[
             0.9838085759930453, 0.9845705991439387, 0.7478991291469238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 321}], {
             RGBColor[
             0.9346176178873656, 0.7989974172061396, 0.581826304081476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 341}], {
             RGBColor[
             0.9485597205720391, 0.8568104930804644, 0.5931756982712233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 348}], {
             RGBColor[
             0.9797770657448555, 0.9841816015416129, 0.9076186446405563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 366}], {
             RGBColor[
             0.9843908473448069, 0.9858160186886924, 0.8112757724239222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.9942658192786091, 0.990143492188576, 0.6172479996170737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 32}], {
             RGBColor[
             0.9897189324321987, 0.98955766775122, 0.7866930868926694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 73}], {
             RGBColor[
             0.9944744132433334, 0.9905896535870364, 0.6399521653845872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.9940567772190065, 0.9896963723604802, 0.5944950614873785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 78}], {
             RGBColor[
             0.976504955645939, 0.9797850696412596, 0.8127493373632958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 104}], {
             RGBColor[
             0.9936916799486066, 0.991200500944209, 0.7208543794047855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 112}], {
             RGBColor[
             0.9948689616648149, 0.9914335527656206, 0.6828963261922294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 141}], {
             RGBColor[
             0.9901847485397224, 0.989750294682609, 0.7789733084975577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 172}], {
             RGBColor[
             0.9946440000022947, 0.9909523825166031, 0.6584106375293626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 208}], {
             RGBColor[
             0.9466894396572686, 0.8118790505262325, 0.4535424722841224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 240}], {
             RGBColor[
             0.994892588206137, 0.9914840875484989, 0.6854679294090322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 242}], {
             RGBColor[
             0.957504806933257, 0.8563709450439075, 0.4623281870979997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 243}], {
             RGBColor[
             0.9945489439917359, 0.9915550016567238, 0.7066472956819071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 285}], {
             RGBColor[
             0.9296140216563376, 0.7343435654492012, 0.43929432494734966`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 337}], {
             RGBColor[
             0.9944593612911748, 0.990557458983355, 0.6383138532820063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 357}], {
             RGBColor[
             0.9935594477871356, 0.9911458195472291, 0.7230458085262261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 399}], {
             RGBColor[
             0.992315532260232, 0.9906314285096836, 0.7436607079572093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 32}], {
             RGBColor[
             0.9892966362311971, 0.9886544188779731, 0.7407287515237073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 78}], {
             RGBColor[
             0.9760826594449374, 0.9788818207680126, 0.7667850019943339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 83}], {
             RGBColor[
             0.984702959020947, 0.9591960459424638, 0.4686773545123068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 194}], {
             RGBColor[
             0.9904002028534119, 0.9891107720366275, 0.7224397966547387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 201}], {
             RGBColor[
             0.9575673032088368, 0.8573897367927896, 0.4167539271352371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 217}], {
             RGBColor[
             0.9699893891453075, 0.9066391681161453, 0.42674902906355405`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 223}], {
             RGBColor[
             0.9939052577890795, 0.9893722876208308, 0.5780031066093586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 230}], {
             RGBColor[
             0.9921527481236327, 0.9898354945442228, 0.6933955860854076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 242}], {
             RGBColor[
             0.9570825107322554, 0.8554676961706607, 0.4163638517290378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 244}], {
             RGBColor[
             0.983440930557758, 0.9549389275977527, 0.4637746122468954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 245}], {
             RGBColor[
             0.9564453809600619, 0.9638053690823691, 0.7850826981284098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 328}], {
             RGBColor[
             0.9940886972689134, 0.9897646461196188, 0.5979693619320228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 357}], {
             RGBColor[
             0.993137151586134, 0.9902425706739821, 0.6770814731572641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 364}], {
             RGBColor[
             0.993472821591865, 0.9884473503209952, 0.5309350952294142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 385}], {
             RGBColor[
             0.9641373946472213, 0.9699387720023607, 0.7858163692606327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 105}], {
             RGBColor[
             0.9728281434620887, 0.9775203375207915, 0.8531590532020966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 128}], {
             RGBColor[
             0.9718474886425651, 0.974867540572699, 0.7060581646735424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 159}], {
             RGBColor[
             0.9689177102191637, 0.9759032728812915, 0.9179650519141944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 171}], {
             RGBColor[
             0.9648070076499333, 0.9512257519687115, 0.6695741122489294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 215}], {
             RGBColor[
             0.965041479763497, 0.973448573363715, 0.944059835504786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 218}], {
             RGBColor[
             0.9626439282414059, 0.9716604833641699, 0.948118264850101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 342}], {
             RGBColor[
             0.97227931488156, 0.9757911732335793, 0.7530597858655176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 349}], {
             RGBColor[
             0.9440389438508738, 0.957784916468577, 0.9796116504661945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 353}], {
             RGBColor[
             0.9725791457587946, 0.9764324811624321, 0.7856945265108051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 32}], {
             RGBColor[
             0.9892346492144803, 0.9885218349170646, 0.7339818472936052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 73}], {
             RGBColor[
             0.9939901300256151, 0.9895538207528809, 0.587240925785523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 74}], {
             RGBColor[
             0.9935724940012881, 0.9886605395263248, 0.5417838218883144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 78}], {
             RGBColor[
             0.9760206724282205, 0.978749236807104, 0.7600380977642316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 104}], {
             RGBColor[
             0.9932073967308883, 0.9901646681100535, 0.6681431398057214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 112}], {
             RGBColor[
             0.9943846784470964, 0.9903977199314651, 0.6301850865931653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 141}], {
             RGBColor[
             0.9897004653220041, 0.9887144618484536, 0.7262620688984935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 172}], {
             RGBColor[
             0.9941597167845764, 0.9899165496824476, 0.6056993979302985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 208}], {
             RGBColor[
             0.9462051564395502, 0.8108432176920771, 0.40083123268505827`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 225}], {
             RGBColor[
             0.9451146344109456, 0.8058914118580738, 0.3999212743732495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 240}], {
             RGBColor[
             0.9944083049884186, 0.9904482547143434, 0.632756689809968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 243}], {
             RGBColor[
             0.9940646607740176, 0.9905191688225685, 0.6539360560828429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 285}], {
             RGBColor[
             0.9291297384386191, 0.7333077326150457, 0.38658308534828556`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 337}], {
             RGBColor[
             0.9939750780734564, 0.9895216261491995, 0.5856026136829421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 357}], {
             RGBColor[
             0.9930751645694171, 0.9901099867130736, 0.6703345689271619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 399}], {
             RGBColor[
             0.9918312490425136, 0.9895955956755282, 0.6909494683581451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 36}], {
             RGBColor[
             0.9774335281845621, 0.934811131988638, 0.4288229389128605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 151}], {
             RGBColor[
             0.9780012670877598, 0.9360254680953698, 0.49061781484757205`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 168}], {
             RGBColor[
             0.966262473203616, 0.9294351748074661, 0.6185488406495561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 265}], {
             RGBColor[
             0.9639442872674036, 0.9277062755319199, 0.6224729247598388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 267}], {
             RGBColor[
             0.9780270303422622, 0.9360805730916858, 0.4934219861077803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 282}], {
             RGBColor[
             0.9337664757796903, 0.7735695841834582, 0.2736042185283608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 291}], {
             RGBColor[
             0.9515961148068626, 0.8442581615511995, 0.287950364605041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 304}], {
             RGBColor[
             0.9702785726455547, 0.9114047879897587, 0.33903829645892536`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 378}], {
             RGBColor[
             0.960433065390231, 0.8781935801825147, 0.30079035994002945`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 383}], {
             RGBColor[
             0.9427879754484142, 0.8093368241333958, 0.28086312892362975`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.9948988245979477, 0.9918657686509955, 0.712921303770677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 87}], {
             RGBColor[
             0.9949323444248528, 0.9919374641713713, 0.7165697300689124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 119}], {
             RGBColor[
             0.9901985718048644, 0.9902148718031658, 0.8120985606838564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 127}], {
             RGBColor[
             0.9939564232350946, 0.9898500674272465, 0.6103467312511728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 129}], {
             RGBColor[
             0.9946214698924287, 0.9912725349807529, 0.6827329557097797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 231}], {
             RGBColor[
             0.9659574857407849, 0.9723602125838786, 0.8631771463313622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 235}], {
             RGBColor[
             0.9949283062885748, 0.9919288270061907, 0.7161302038555326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 317}], {
             RGBColor[
             0.9818089387856037, 0.9492161655348561, 0.5340395037579063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 326}], {
             RGBColor[
             0.9903394723872226, 0.9902731378149507, 0.8097634733951619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 327}], {
             RGBColor[
             0.9949087941337641, 0.9921626697833582, 0.7340379870293499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 336}], {
             RGBColor[
             0.9770133407188117, 0.98060565112419, 0.8444624676823549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 396}], {
             RGBColor[
             0.9940003631377892, 0.9899440504361046, 0.61512931849383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 54}], {
             RGBColor[
             0.9929488185913181, 0.9890640914427355, 0.6002007314408495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 63}], {
             RGBColor[
             0.9925651692844837, 0.9911935206797694, 0.7728779158886143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 224}], {
             RGBColor[
             0.9935409480211872, 0.9903305964197566, 0.6646503656828495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 297}], {
             RGBColor[
             0.9834755168107903, 0.957186633570494, 0.5567480339325231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 318}], {
             RGBColor[
             0.9893748769876485, 0.9898742528282558, 0.8257493154589797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 345}], {
             RGBColor[
             0.9637569806665837, 0.9709452905693785, 0.8774110704635527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 81}], {
             RGBColor[
             0.9899697875471469, 0.9877852076000606, 0.6461561844106792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 106}], {
             RGBColor[
             0.9911287090666558, 0.9902640235453506, 0.7722976397746584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 164}], {
             RGBColor[
             0.9620548553957741, 0.8879832435861648, 0.5635159204718476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 192}], {
             RGBColor[
             0.9765252953630872, 0.9814861498054002, 0.9010190526074958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 241}], {
             RGBColor[
             0.9898823479840517, 0.9900841051266782, 0.8173392077557367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 271}], {
             RGBColor[
             0.9742735767543498, 0.9348828082891582, 0.5813864534226191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 287}], {
             RGBColor[
             0.9907677225462033, 0.9894919098794384, 0.7330064847739624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 292}], {
             RGBColor[
             0.9859691535400709, 0.988465898659582, 0.8821909667150922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 371}], {
             RGBColor[
             0.9909159260896987, 0.9898089022732984, 0.7491375258771963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 374}], {
             RGBColor[
             0.9885595171892071, 0.9830726398742604, 0.6368846343385584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 382}], {
             RGBColor[
             0.989866546971583, 0.9900775710019549, 0.8176010714240518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 384}], {
             RGBColor[
             0.9900822840291166, 0.9880258261998547, 0.6584007322252652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 389}], {
             RGBColor[
             0.9894078119670371, 0.9898878722886233, 0.8252034976175153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 78}], {
             RGBColor[
             0.9714737855818102, 0.978163412369748, 0.9294831850398273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 104}], {
             RGBColor[
             0.9886605098844778, 0.9895788436726976, 0.8375882270813171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 172}], {
             RGBColor[
             0.9896128299381659, 0.9893307252450916, 0.7751444852058942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 194}], {
             RGBColor[
             0.9857913289902847, 0.9883923636383629, 0.8851379797002322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 208}], {
             RGBColor[
             0.9416582695931398, 0.8102573932547211, 0.570276319960654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 217}], {
             RGBColor[
             0.9653805152821803, 0.9059207597178809, 0.5894472121090475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 223}], {
             RGBColor[
             0.9892963839259523, 0.9886538792225663, 0.7407012896548522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 230}], {
             RGBColor[
             0.9875438742605055, 0.9891170861459584, 0.8560937691309012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 240}], {
             RGBColor[
             0.9898614181420082, 0.9898624302769874, 0.8022017770855637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 242}], {
             RGBColor[
             0.9524736368691282, 0.8547492877723961, 0.5790620347745312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 357}], {
             RGBColor[
             0.9885282777230068, 0.9895241622757176, 0.8397796562027576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 364}], {
             RGBColor[
             0.9888639477287378, 0.9877289419227306, 0.6936332782749077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 385}], {
             RGBColor[
             0.959528520784094, 0.9692203636040961, 0.9485145523061262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 387}], {
             RGBColor[
             0.9846308842914946, 0.9879124899333448, 0.9043695514937979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 92}], {
             RGBColor[
             0.9766969591534242, 0.9330555127896212, 0.3639725160314099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 182}], {
             RGBColor[
             0.9217387869885367, 0.6911870639911499, 0.3098313389124079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 256}], {
             RGBColor[
             0.9925757261786055, 0.9860731563414201, 0.47201552056505247`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 281}], {
             RGBColor[
             0.9906176042144936, 0.9868987872657242, 0.6233404172639806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 311}], {
             RGBColor[
             0.9700518128538349, 0.9724377364521578, 0.6974215369422685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 35}], {
             RGBColor[
             0.9882398881368415, 0.9819652173541755, 0.6354408392020714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 85}], {
             RGBColor[
             0.9903440107416279, 0.9885685883820032, 0.6856490932997572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 86}], {
             RGBColor[
             0.9864509630456144, 0.9759307529618803, 0.6284912030328111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 91}], {
             RGBColor[
             0.9862298300460874, 0.9885736950939006, 0.8778708824012238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 93}], {
             RGBColor[
             0.9901642511557686, 0.9881841008043324, 0.6660833717265452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 95}], {
             RGBColor[
             0.9895922803493112, 0.986527153843628, 0.6406946275696765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 125}], {
             RGBColor[
             0.9867715749704511, 0.9887977205423344, 0.8688927670135966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 162}], {
             RGBColor[
             0.9880992958757989, 0.9893467672575667, 0.846888995580425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 211}], {
             RGBColor[
             0.9884270749289015, 0.989482312319562, 0.8414568484055187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 214}], {
             RGBColor[
             0.9486027698374206, 0.9599909835364515, 0.9250015531154289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 248}], {
             RGBColor[
             0.9726465055964986, 0.9785900722595869, 0.9074378353757576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 263}], {
             RGBColor[
             0.9641852098937056, 0.8963943079000224, 0.565058385951784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 340}], {
             RGBColor[
             0.9817195199232316, 0.9599704843144075, 0.6101104399604148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 42}], {
             RGBColor[
             0.9574177879020291, 0.9592516435389654, 0.7024592197374568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 85}], {
             RGBColor[
             0.9911998402107902, 0.9814828074449274, 0.4623476054083001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 86}], {
             RGBColor[
             0.9873067925147767, 0.9688449720248045, 0.40518971514135393`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 93}], {
             RGBColor[
             0.9910200806249309, 0.9810983198672565, 0.442781883835088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 97}], {
             RGBColor[
             0.9901015173621296, 0.9827350488805209, 0.6045888251970493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 98}], {
             RGBColor[
             0.9921513619403102, 0.9835180162107666, 0.5659148735551266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 125}], {
             RGBColor[
             0.9876274044396134, 0.9817119396052586, 0.6455912791221394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 162}], {
             RGBColor[
             0.9889551253449612, 0.9822609863204907, 0.6235875076889678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 211}], {
             RGBColor[
             0.9892829043980638, 0.9823965313824861, 0.6181553605140615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 214}], {
             RGBColor[
             0.9494585993065829, 0.9529052025993756, 0.7017000652239718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 248}], {
             RGBColor[
             0.9735023350656609, 0.9715042913225111, 0.6841363474843005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 263}], {
             RGBColor[
             0.9650410393628679, 0.8893085269629466, 0.34175689806032683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 340}], {
             RGBColor[
             0.9825753493923939, 0.9528847033773316, 0.3868089520689576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 80}], {
             RGBColor[
             0.9939148005535154, 0.9893926986290377, 0.5790417776270911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 151}], {
             RGBColor[
             0.9942519426288448, 0.9901138114378746, 0.6157376119269835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 168}], {
             RGBColor[
             0.982513148744701, 0.9835235181499709, 0.7436686377289676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 265}], {
             RGBColor[
             0.9801949628084885, 0.9817946188744247, 0.7475927218392504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 277}], {
             RGBColor[
             0.9786295694785638, 0.9388456601171562, 0.4334693334866107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 304}], {
             RGBColor[
             0.9865292481866397, 0.9654931313322634, 0.4641580935383369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 378}], {
             RGBColor[
             0.9766837409313159, 0.9322819235250195, 0.42591015701944096`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 383}], {
             RGBColor[
             0.9590386509894991, 0.8634251674759006, 0.4059829260030413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 41}], {
             RGBColor[
             0.9897984344323824, 0.976377308501761, 0.4890652034861614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 114}], {
             RGBColor[
             0.9704320875117387, 0.9116923005821094, 0.3408342305839836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 170}], {
             RGBColor[
             0.9899904942088997, 0.9767881049435094, 0.5099697249045285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 187}], {
             RGBColor[
             0.9889418348200144, 0.9743603536465608, 0.411541545745371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 206}], {
             RGBColor[
             0.9897402427679569, 0.9762528424156347, 0.4827313999307721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 256}], {
             RGBColor[
             0.9895331981758166, 0.9758099949684661, 0.46019587380742055`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 261}], {
             RGBColor[
             0.9897402427679569, 0.9762528424156347, 0.4827313999307721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 311}], {
             RGBColor[
             0.9670092848510461, 0.9621745750792038, 0.6856018901846366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 361}], {
             RGBColor[
             0.9897402427679569, 0.9762528424156347, 0.4827313999307721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 53}], {
             RGBColor[
             0.9777415147706912, 0.9821068941229497, 0.8861387580160115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 58}], {
             RGBColor[
             0.9910530508575155, 0.9886154921358139, 0.6559948679517069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 102}], {
             RGBColor[
             0.9795775273140312, 0.9834761892715782, 0.8830308676888998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 103}], {
             RGBColor[
             0.9795439213017476, 0.9834511259626417, 0.8830877539018445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 117}], {
             RGBColor[
             0.9908354915874791, 0.9881501548558225, 0.6323148840284245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 145}], {
             RGBColor[
             0.9636609086311553, 0.8912907898540301, 0.5498347282157042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 189}], {
             RGBColor[
             0.9912142819336496, 0.9889603491047025, 0.6735438755860479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 222}], {
             RGBColor[
             0.9647142667698299, 0.8954670038630834, 0.5506822848995752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 254}], {
             RGBColor[
             0.9856974192620115, 0.9880403946659784, 0.8726714869444233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 303}], {
             RGBColor[
             0.9866013327274336, 0.9887145318484678, 0.8711413972258528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 376}], {
             RGBColor[
             0.9915381131518742, 0.9896529913361265, 0.7087909052351768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 150}], {
             RGBColor[
             0.9856902081112485, 0.9616951894645742, 0.5431816306121151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 237}], {
             RGBColor[
             0.9778611704106845, 0.9577195764705831, 0.6405947762085319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 251}], {
             RGBColor[
             0.8849246478487939, 0.884958722323403, 0.6709188741212699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 283}], {
             RGBColor[
             0.9854348946215892, 0.9611490997263465, 0.5153923328749174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 294}], {
             RGBColor[
             0.9498753075179714, 0.9365363411831458, 0.6771702570477409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 320}], {
             RGBColor[
             0.9839644031906944, 0.957570308004341, 0.3922051637745557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 347}], {
             RGBColor[
             0.9854349572034219, 0.9616154207418048, 0.5492860296765566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 381}], {
             RGBColor[
             0.9852760775142246, 0.9608094059925664, 0.4981060708438544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 51}], {
             RGBColor[
             0.9839338812816956, 0.9857804624311657, 0.8333516157502892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 84}], {
             RGBColor[
             0.9792010729898064, 0.9838233245748444, 0.9117864972621295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 102}], {
             RGBColor[
             0.9715806509847216, 0.9783254765535943, 0.9329907243162545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 134}], {
             RGBColor[
             0.9841421480304473, 0.9857875669303608, 0.8241562384464611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 163}], {
             RGBColor[
             0.9720779945816126, 0.9786963945938301, 0.9321488513347028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 167}], {
             RGBColor[
             0.9838115620782171, 0.9850804770059074, 0.7881739976862158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 174}], {
             RGBColor[
             0.9795727068166722, 0.9839770047128071, 0.9056275629934497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 183}], {
             RGBColor[
             0.9834067839372234, 0.9855624941334425, 0.842086982832396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 189}], {
             RGBColor[
             0.9832174056043399, 0.9838096363867186, 0.7235037322134026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 226}], {
             RGBColor[
             0.9414576868310469, 0.9551925092475915, 0.9608449900112774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 234}], {
             RGBColor[
             0.932178800874853, 0.947793777454772, 0.9599599615854164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 246}], {
             RGBColor[
             0.9783688776130631, 0.9833881248583104, 0.921500027287528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 269}], {
             RGBColor[
             0.9794441505694058, 0.9839238434008176, 0.9077580727035551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 272}], {
             RGBColor[
             0.9775147141276346, 0.9827510911294421, 0.9229459032668423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 350}], {
             RGBColor[
             0.9734143166141238, 0.9796930213776505, 0.929886806702267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 355}], {
             RGBColor[
             0.9833637998768487, 0.9841227589328836, 0.7394378453352671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 392}], {
             RGBColor[
             0.5760104463274659, 0.6424240248567656, 0.9319651004426129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 395}], {
             RGBColor[
             0.9536699732200591, 0.9649302549205065, 0.9620098087890983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 55}], {
             RGBColor[
             0.9925122400193549, 0.9855316119784733, 0.49960782573236684`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 83}], {
             RGBColor[
             0.9847086077895241, 0.9592081280872721, 0.469292188111767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.9777728043497317, 0.9358120344807606, 0.4423479014647508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 135}], {
             RGBColor[
             0.9898899091202207, 0.9889094986978371, 0.7316051327248937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 156}], {
             RGBColor[
             0.9940233088014235, 0.9896247867994464, 0.5908522307766052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 165}], {
             RGBColor[
             0.9910790893846682, 0.9806972583679037, 0.4940403061443971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 187}], {
             RGBColor[
             0.9930602080191107, 0.987380036710654, 0.5017365779363439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 206}], {
             RGBColor[
             0.993858615967053, 0.9892725254797279, 0.5729264321217449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 245}], {
             RGBColor[
             0.956451029728639, 0.9638174512271775, 0.7856975317278699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 256}], {
             RGBColor[
             0.993651571374913, 0.9888296780325594, 0.5503909059983934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 311}], {
             RGBColor[
             0.9711276580501423, 0.9751942581432971, 0.7757969223756094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 328}], {
             RGBColor[
             0.9940943460374905, 0.9897767282644272, 0.598584195531483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 386}], {
             RGBColor[
             0.9921211902097373, 0.9898321907696607, 0.6946270307012463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 400}], {
             RGBColor[
             0.980177624281288, 0.9439240567884717, 0.45169017278670887`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 45}], {
             RGBColor[
             0.9393040808090061, 0.8972347049837328, 0.6368570113270663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 93}], {
             RGBColor[
             0.9593421509209561, 0.9654705269891223, 0.7331017522619306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 98}], {
             RGBColor[
             0.9604734322363355, 0.9678902233326324, 0.8562347419819692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 125}], {
             RGBColor[
             0.9559494747356387, 0.9660841467271244, 0.9359111475489821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 139}], {
             RGBColor[
             0.8578825374186717, 0.8897584107021286, 0.986242538309826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 148}], {
             RGBColor[
             0.9313999003014329, 0.9481019196390006, 0.9921021838317903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 204}], {
             RGBColor[
             0.9465892805820957, 0.9594301345819912, 0.9663905250414808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 248}], {
             RGBColor[
             0.9418244053616862, 0.9558764984443768, 0.9744562159111432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 275}], {
             RGBColor[
             0.9164767055896288, 0.9362376642124519, 0.9918955603991939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 276}], {
             RGBColor[
             0.9604911781295589, 0.9679281800038524, 0.858166272944386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 288}], {
             RGBColor[
             0.952748719814698, 0.96402383427651, 0.9559642010597227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 290}], {
             RGBColor[
             0.896567126571677, 0.717187296790453, 0.6019210298284456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 318}], {
             RGBColor[
             0.9556108523126852, 0.9659441176530338, 0.941522997424062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 56}], {
             RGBColor[
             0.9632568885757271, 0.8798368130149512, 0.42785495032131926`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 59}], {
             RGBColor[
             0.9635646247299425, 0.8804950295319203, 0.4613501315802737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[
             0.8995535793551228, 0.833262758475618, 0.6258381110620894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 121}], {
             RGBColor[
             0.9596985781926477, 0.8794486672976345, 0.5655703500350114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 122}], {
             RGBColor[
             0.9627458294908182, 0.8787437093083308, 0.3722293228200649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 175}], {
             RGBColor[
             0.9629822845312646, 0.8808065642560563, 0.5111508380445346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 213}], {
             RGBColor[
             0.9045789945210447, 0.6514568885451212, 0.24166961651811514`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 227}], {
             RGBColor[
             0.8567930233902159, 0.799480948606301, 0.621676166366923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 237}], {
             RGBColor[
             0.9560407750773089, 0.8771721829132072, 0.5919811127915957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 274}], {
             RGBColor[
             0.963008867019779, 0.8793063199856039, 0.40085933456797046`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 296}], {
             RGBColor[
             0.9631706097299088, 0.8808844415654324, 0.5080298021330091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 308}], {
             RGBColor[
             0.9572411213922969, 0.8604843271479587, 0.3245447122734284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 373}], {
             RGBColor[
             0.9636160493477981, 0.8806050215896868, 0.46694738387789525`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 380}], {
             RGBColor[
             0.9637969689329147, 0.8811434571925727, 0.49764940917354655`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 46}], {
             RGBColor[
             0.9599710046664961, 0.9696670213385128, 0.9526428272523044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 65}], {
             RGBColor[
             0.975531433819878, 0.9662007497502997, 0.6662307511559362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 68}], {
             RGBColor[
             0.9781218810167648, 0.9823905706464788, 0.885494897176814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 113}], {
             RGBColor[
             0.9771010735997687, 0.9819684405459971, 0.9024123178413492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 149}], {
             RGBColor[
             0.978934110638932, 0.9827264484685942, 0.8720341503546211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 161}], {
             RGBColor[
             0.9806033899078639, 0.9823544805062622, 0.7671549418129668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 195}], {
             RGBColor[
             0.9762118107763984, 0.9816007075155213, 0.917149704163013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 247}], {
             RGBColor[
             0.9773345205488627, 0.9820649768587604, 0.8985434977535244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 249}], {
             RGBColor[
             0.9806017502819868, 0.9823509735123028, 0.7669764786548487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 250}], {
             RGBColor[
             0.9801197271810786, 0.9832167313777271, 0.8523854159739954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 266}], {
             RGBColor[
             0.961475048534197, 0.9187352797736931, 0.6118846547720228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 315}], {
             RGBColor[
             0.949835902918508, 0.8725899459228413, 0.6025195250037783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 316}], {
             RGBColor[
             0.9534452404770077, 0.8868997666018511, 0.6054236827253885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 358}], {
             RGBColor[
             0.9800064077172193, 0.9810775959646316, 0.7021771145083233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 362}], {
             RGBColor[
             0.9799089336528015, 0.9808691087969816, 0.6915676641366473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 363}], {
             RGBColor[
             0.979669884849334, 0.9801607168271663, 0.6823078519244729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 369}], {
             RGBColor[
             0.9453892137027378, 0.9584805209485364, 0.9665287106576532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 372}], {
             RGBColor[
             0.9804565098543385, 0.9820403189236229, 0.7511679544253511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 66}], {
             RGBColor[
             0.973512221373029, 0.9203772285835692, 0.44312247407126115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 91}], {
             RGBColor[
             0.9689719524222267, 0.9194709756015922, 0.5889671860993759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 123}], {
             RGBColor[
             0.9330033355752005, 0.7720875814102912, 0.26495111507121627`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 140}], {
             RGBColor[
             0.9708774121816628, 0.9202589321802012, 0.5573887867137362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 148}], {
             RGBColor[
             0.9449641229123846, 0.9017127739619022, 0.636180106994557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 179}], {
             RGBColor[
             0.9713912506171942, 0.9204714175783388, 0.5488731540657354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 203}], {
             RGBColor[
             0.952427438813507, 0.849097678051479, 0.28058020447906046`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 232}], {
             RGBColor[
             0.9738499783844465, 0.9210996566785192, 0.47988524036941105`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 257}], {
             RGBColor[
             0.9734956711138798, 0.920341829252737, 0.44132108049923974`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 275}], {
             RGBColor[
             0.9300409282005804, 0.8898485185353535, 0.6359734835619606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 276}], {
             RGBColor[
             0.9740554007405106, 0.921539034326754, 0.5022441961071527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 279}], {
             RGBColor[
             0.963175695307025, 0.8865299636622036, 0.3162110824240158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 280}], {
             RGBColor[
             0.9611350315477496, 0.9137730111447246, 0.6088069767233308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 288}], {
             RGBColor[
             0.9663129424256496, 0.9176346885994116, 0.6000421242224894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 297}], {
             RGBColor[
             0.9632757147467785, 0.8868673527181737, 0.3165996390603722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 325}], {
             RGBColor[
             0.9713912506171942, 0.9204714175783388, 0.5488731540657354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 339}], {
             RGBColor[
             0.9454034863570999, 0.8212500471552284, 0.27492856745928085`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 149}], {
             RGBColor[
             0.9717489985854497, 0.9773678036636484, 0.8841966708838138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 153}], {
             RGBColor[
             0.9609871822982217, 0.9360179995110851, 0.6498044045081516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 161}], {
             RGBColor[
             0.9734182778543816, 0.9769958357013163, 0.7793174623421596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 184}], {
             RGBColor[
             0.9414236839127059, 0.862366230961099, 0.6136946864752324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 195}], {
             RGBColor[
             0.9690266987229161, 0.9762420627105755, 0.9293122246922058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 247}], {
             RGBColor[
             0.9701494084953804, 0.9767063320538145, 0.9107060182827171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 250}], {
             RGBColor[
             0.9729346151275964, 0.9778580865727813, 0.8645479365031883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 315}], {
             RGBColor[
             0.9426507908650257, 0.8672313011178955, 0.614682045532971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 343}], {
             RGBColor[
             0.8850524463065069, 0.5492176882667834, 0.5645116738907485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 356}], {
             RGBColor[
             0.9713776658403708, 0.977214248030742, 0.8903506154481122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 358}], {
             RGBColor[
             0.972821295663737, 0.9757189511596858, 0.7143396350375162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 362}], {
             RGBColor[
             0.9727238215993192, 0.9755104639920358, 0.70373018466584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 363}], {
             RGBColor[
             0.9724847727958518, 0.9748020720222205, 0.6944703724536656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 369}], {
             RGBColor[
             0.9382041016492555, 0.9531218761435906, 0.9786912311868461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 372}], {
             RGBColor[
             0.9732713978008563, 0.976681674118677, 0.763330474954544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.9767414703396664, 0.932042352969749, 0.4630646216300635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.9717593889997348, 0.9307534531469539, 0.6016973402157331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 173}], {
             RGBColor[
             0.9762020773778424, 0.9308886459654016, 0.40435502648302224`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 201}], {
             RGBColor[
             0.9401620631472913, 0.7995433594189606, 0.27553481539813574`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 209}], {
             RGBColor[
             0.9763069707107419, 0.9311130021981308, 0.41577201844251915`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 323}], {
             RGBColor[
             0.9700321664833949, 0.9105736021458753, 0.33808105504883373`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 346}], {
             RGBColor[
             0.9662216353373511, 0.9266619073001263, 0.6127955004938299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 61}], {
             RGBColor[
             0.9488263958117535, 0.8844312002712831, 0.6139995371324181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 68}], {
             RGBColor[
             0.973199774355475, 0.9787196715576989, 0.8938267398633593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 118}], {
             RGBColor[
             0.973507120908919, 0.9723047894157149, 0.6858199753600849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 173}], {
             RGBColor[
             0.9753105140909251, 0.977890543684061, 0.7351308500291178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 176}], {
             RGBColor[
             0.9761500306947214, 0.9796861848114327, 0.8265070514564374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 209}], {
             RGBColor[
             0.9754154074238246, 0.9781148999167902, 0.7465478419886147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 344}], {
             RGBColor[
             0.9231385170040861, 0.7781911417847891, 0.59310305708759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 354}], {
             RGBColor[
             0.9564694124880462, 0.9147332145084571, 0.6201492877548224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 388}], {
             RGBColor[
             0.9749434182043879, 0.9771053627018458, 0.6951747282327619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 52}], {
             RGBColor[
             0.973245972080542, 0.9392495210250668, 0.6165054011918987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 62}], {
             RGBColor[
             0.9798158003582575, 0.9420704411320184, 0.5041186906177785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.9798493201851628, 0.9421421366523943, 0.5077671169160141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 127}], {
             RGBColor[
             0.9788733989954045, 0.9400547399082695, 0.4015441180982743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[
             0.9795384456527387, 0.9414772074617759, 0.47393034255688127`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 133}], {
             RGBColor[
             0.9748680840518573, 0.9403172117619101, 0.6073970583616624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 199}], {
             RGBColor[
             0.9227037130014462, 0.7219009628307471, 0.26975233632830203`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 216}], {
             RGBColor[
             0.978934245009504, 0.9401848833799527, 0.40816683123493425`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 231}], {
             RGBColor[
             0.9508744615010948, 0.9225648850649015, 0.6543745331784638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 235}], {
             RGBColor[
             0.9798452820488847, 0.9421334994872137, 0.5073275907026341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 298}], {
             RGBColor[
             0.9764207611902653, 0.9409592836606241, 0.5816651799786137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 313}], {
             RGBColor[
             0.9780101817183021, 0.9374853208602758, 0.3690741377146879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 361}], {
             RGBColor[
             0.9792447024500028, 0.9408489204531174, 0.4419582077120011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 393}], {
             RGBColor[
             0.9622895687737851, 0.9310782533783513, 0.6350517341025959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 396}], {
             RGBColor[
             0.9789173388980991, 0.9401487229171275, 0.4063267053409315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.9937439937214299, 0.9890273600864263, 0.5604505080521496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 147}], {
             RGBColor[
             0.9423953277859266, 0.7942227232478654, 0.36711617422254583`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 164}], {
             RGBColor[
             0.9649807564628414, 0.8874109572249995, 0.38547746832518665`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 271}], {
             RGBColor[
             0.9771994778214173, 0.9343105219279929, 0.40334800127595816`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 287}], {
             RGBColor[
             0.9936936236132707, 0.9889196235182731, 0.5549680326273014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 371}], {
             RGBColor[
             0.9938418271567662, 0.9892366159121332, 0.5710990737305354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 391}], {
             RGBColor[
             0.9915564260867203, 0.9827398795986204, 0.45912203420447584`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 84}], {
             RGBColor[
             0.9900410616165701, 0.9901497372924789, 0.8147089121271927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 102}], {
             RGBColor[
             0.9824206396114854, 0.9846518892712288, 0.8359131391813179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 134}], {
             RGBColor[
             0.994982136657211, 0.9921139796479954, 0.7270786533115245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 163}], {
             RGBColor[
             0.9829179832083763, 0.9850228073114646, 0.8350712661997661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 167}], {
             RGBColor[
             0.9946515507049809, 0.991406889723542, 0.6910964125512791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 174}], {
             RGBColor[
             0.9904126954434359, 0.9903034174304416, 0.808549977858513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 183}], {
             RGBColor[
             0.994246772563987, 0.991888906851077, 0.7450093976974592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 189}], {
             RGBColor[
             0.9940573942311037, 0.9901360491043532, 0.626426147078466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 222}], {
             RGBColor[
             0.9675573790672839, 0.8966427038627339, 0.5035645563919933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 226}], {
             RGBColor[
             0.9522976754578107, 0.961518921965226, 0.8637674048763408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 234}], {
             RGBColor[
             0.9430187895016167, 0.9541201901724066, 0.8628823764504798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 238}], {
             RGBColor[
             0.8248562129027038, 0.8612345599118311, 0.8512579215922633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 246}], {
             RGBColor[
             0.9892088662398268, 0.9897145375759449, 0.8244224421525912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 269}], {
             RGBColor[
             0.9902841391961696, 0.9902502561184521, 0.8106804875686184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 272}], {
             RGBColor[
             0.9883547027543983, 0.9890775038470766, 0.8258683181319055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 350}], {
             RGBColor[
             0.9842543052408874, 0.986019434095285, 0.8328092215673302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 355}], {
             RGBColor[
             0.9942037885036126, 0.9904491716505182, 0.6423602602003304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 392}], {
             RGBColor[
             0.5868504349542296, 0.6487504375744001, 0.8348875153076762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 395}], {
             RGBColor[
             0.9645099618468227, 0.9712566676381411, 0.8649322236541616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 89}], {
             RGBColor[
             0.9804436289086855, 0.9849354709774921, 0.9179880145258416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 128}], {
             RGBColor[
             0.9872399977759501, 0.9863472486814571, 0.6800026617200639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 133}], {
             RGBColor[
             0.9834250755350213, 0.9870169512743434, 0.9065786726959144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 199}], {
             RGBColor[
             0.9312607044846101, 0.7686007023431805, 0.5689339506625541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 299}], {
             RGBColor[
             0.9879694947772946, 0.9879075690038723, 0.7594039083827884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 342}], {
             RGBColor[
             0.987671824014945, 0.9872708813423373, 0.727004282912039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 393}], {
             RGBColor[
             0.9708465602569492, 0.9777779928907848, 0.9342333484368479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 58}], {
             RGBColor[
             0.9797069203146553, 0.9809669111092645, 0.7116241383372022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 64}], {
             RGBColor[
             0.9692107387915666, 0.9458789493887563, 0.6437975564131029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 117}], {
             RGBColor[
             0.9794893610446189, 0.980501573829273, 0.6879441544139197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 126}], {
             RGBColor[
             0.9735754629852418, 0.9798132040773773, 0.9296140279296691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 289}], {
             RGBColor[
             0.9594259360472176, 0.9692605100547228, 0.9535654862480789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 303}], {
             RGBColor[
             0.9752552021845735, 0.9810659508219184, 0.9267706676113481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 376}], {
             RGBColor[
             0.9801919826090142, 0.9820044103095771, 0.764420175620672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 63}], {
             RGBColor[
             0.9922460803278208, 0.9887734911112298, 0.611846923095329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 66}], {
             RGBColor[
             0.9933929344803777, 0.9882764798673498, 0.5222398761501267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 204}], {
             RGBColor[
             0.980034216300396, 0.9809402401886735, 0.689585850283113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 224}], {
             RGBColor[
             0.9932218590645243, 0.987910566851217, 0.5036193728895642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 290}], {
             RGBColor[
             0.9300120622899775, 0.7386974023971353, 0.32511635507007786`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 297}], {
             RGBColor[
             0.9831564278541273, 0.9547666040019545, 0.3957170411392377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 318}], {
             RGBColor[
             0.9890557880309855, 0.9874542232597161, 0.6647183226656943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 345}], {
             RGBColor[
             0.9634378917099207, 0.9685252610008388, 0.7163800776702673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 92}], {
             RGBColor[
             0.9763682367376081, 0.9319466548933795, 0.36269549151998337`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 135}], {
             RGBColor[
             0.988485341508097, 0.9850441191104562, 0.6519527227801263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 156}], {
             RGBColor[
             0.9926187411892999, 0.9857594072120655, 0.5111998208318378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.9896745217725446, 0.9768318787805226, 0.4143878961996297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 221}], {
             RGBColor[
             0.9923750115138285, 0.9852380940810823, 0.48467134978197457`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 245}], {
             RGBColor[
             0.9550464621165153, 0.9599520716397965, 0.7060451217831025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 255}], {
             RGBColor[
             0.9427521354009989, 0.7975138373251768, 0.32677484386149963`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 328}], {
             RGBColor[
             0.9926897784253668, 0.9859113486770462, 0.5189317855867155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 386}], {
             RGBColor[
             0.9907166225976136, 0.9859668111822797, 0.6149746207564788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 400}], {
             RGBColor[
             0.9787730566691644, 0.9400586772010907, 0.37203776284194146`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 59}], {
             RGBColor[
             0.9943339996219753, 0.9902893230489461, 0.6246690092321784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 90}], {
             RGBColor[
             0.9303229542471556, 0.9430570519926439, 0.7891569887139941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 121}], {
             RGBColor[
             0.9904679530846804, 0.9892429608146605, 0.7288892276869161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 122}], {
             RGBColor[
             0.993515204382851, 0.9885380028253566, 0.5355482004719696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 137}], {
             RGBColor[
             0.9745810677061959, 0.9778460469016634, 0.776000636859531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 166}], {
             RGBColor[
             0.9907375891611678, 0.989354462261619, 0.724420660103722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 169}], {
             RGBColor[
             0.9868650291385044, 0.9664146910136404, 0.483413666367122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 175}], {
             RGBColor[
             0.9937516594232972, 0.9906008577730822, 0.6744697156964393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 178}], {
             RGBColor[
             0.9933313732219062, 0.9881448065602775, 0.5155393130775634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 213}], {
             RGBColor[
             0.9353483694130773, 0.761251182062147, 0.4049884941700198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 274}], {
             RGBColor[
             0.9937782419118115, 0.9891006135026298, 0.5641782122198751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 278}], {
             RGBColor[
             0.9668838968357589, 0.9721055094694522, 0.7890299393994995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 296}], {
             RGBColor[
             0.9939399846219414, 0.9906787350824584, 0.6713486797849137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 319}], {
             RGBColor[
             0.9924050401486646, 0.9900439960964849, 0.6967866820160713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 352}], {
             RGBColor[
             0.979240809854913, 0.9406964091182685, 0.45379501416337115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 76}], {
             RGBColor[
             0.9650050592510206, 0.9449631262196299, 0.6556309402456391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.9708009177471754, 0.977558502548882, 0.9260057689765339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 102}], {
             RGBColor[
             0.9631804957420906, 0.9720606545276318, 0.947209996030659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 144}], {
             RGBColor[
             0.9424135886934057, 0.8606454780024364, 0.6101112006874331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 163}], {
             RGBColor[
             0.9636778393389815, 0.9724315725678676, 0.9463681230491072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 167}], {
             RGBColor[
             0.9754114068355861, 0.9788156549799449, 0.8023932694006202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 174}], {
             RGBColor[
             0.9711725515740411, 0.9777121826868447, 0.9198468347078541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 186}], {
             RGBColor[
             0.9696863564761851, 0.9607542409809683, 0.6738168959765998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 188}], {
             RGBColor[
             0.9722410875731053, 0.9781540497825802, 0.9021384279208391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 189}], {
             RGBColor[
             0.974817250361709, 0.9775448143607561, 0.7377230039278071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 222}], {
             RGBColor[
             0.9483172351978891, 0.884051469119137, 0.6148614132413344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 228}], {
             RGBColor[
             0.9755187620900482, 0.9790452770139582, 0.8140782263289845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 238}], {
             RGBColor[
             0.8056160690333091, 0.8486433251682342, 0.9625547784416044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 333}], {
             RGBColor[
             0.9310686292226973, 0.8156664941847112, 0.6009827799968762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 368}], {
             RGBColor[
             0.9583572843853698, 0.9684635113950733, 0.9553744347625952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 117}], {
             RGBColor[
             0.9928008971314434, 0.9870101718421371, 0.4578002643496151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 289}], {
             RGBColor[
             0.972737472134042, 0.975769108067587, 0.7234215961837744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 303}], {
             RGBColor[
             0.9885667382713978, 0.9875745488347826, 0.6966267775470435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 376}], {
             RGBColor[
             0.9935035186958385, 0.9885130083224412, 0.5342762855563674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 90}], {
             RGBColor[
             0.930630690401371, 0.9437152685096128, 0.8226521699729485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 121}], {
             RGBColor[
             0.9907756892388959, 0.9899011773316294, 0.7623844089458706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 122}], {
             RGBColor[
             0.9938229405370664, 0.9891962193423256, 0.569043381730924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 175}], {
             RGBColor[
             0.9940593955775128, 0.9912590742900511, 0.7079648969553938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 178}], {
             RGBColor[
             0.9936391093761218, 0.9888030230772464, 0.5490344943365179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 213}], {
             RGBColor[
             0.9356561055672928, 0.7619093985791161, 0.43848367542897426`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 274}], {
             RGBColor[
             0.994085978066027, 0.9897588300195987, 0.5976733934788296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 296}], {
             RGBColor[
             0.9942477207761569, 0.9913369515994274, 0.7048438610438682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 319}], {
             RGBColor[
             0.9927127763028801, 0.9907022126134537, 0.7302818632750258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 373}], {
             RGBColor[
             0.9946931603940463, 0.9910575316236816, 0.6637614427887544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.9304606760729726, 0.7386931928430628, 0.4172839574824631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 101}], {
             RGBColor[
             0.9303881553625484, 0.7385380783764343, 0.40939052569874806`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.9202820566726377, 0.7336079411814099, 0.5696678854612296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 259}], {
             RGBColor[
             0.9293325966167787, 0.7390484491038565, 0.495711420579082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 331}], {
             RGBColor[
             0.9259496317169944, 0.7376495061795634, 0.5517759038010243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 335}], {
             RGBColor[
             0.9304758020299917, 0.7387255457356581, 0.41893032455741674`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 394}], {
             RGBColor[
             0.9291961986064425, 0.7355550441596266, 0.31652013703240056`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 118}], {
             RGBColor[
             0.9650216133232739, 0.8890521217210994, 0.3426755203963007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 130}], {
             RGBColor[
             0.9673063863348054, 0.8956674987698339, 0.4443816187772328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 147}], {
             RGBColor[
             0.9159577203993021, 0.7008628619312728, 0.2510472849476292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 164}], {
             RGBColor[
             0.938543149076217, 0.794051095908407, 0.26940857905026994`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 173}], {
             RGBColor[
             0.9668250065052799, 0.8946378759894456, 0.39198639506533367`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 176}], {
             RGBColor[
             0.9676645231090764, 0.8964335171168172, 0.4833625964926534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 344}], {
             RGBColor[
             0.9146530094184411, 0.6949384740901736, 0.24995860212380594`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 354}], {
             RGBColor[
             0.9479839049024011, 0.8314805468138416, 0.27700483279103827`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 371}], {
             RGBColor[
             0.9674042197701418, 0.8958767545955406, 0.45503018445561866`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 388}], {
             RGBColor[
             0.9664579106187429, 0.8938526950072303, 0.35203027326897784`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 87}], {
             RGBColor[
             0.9949761399460422, 0.9916627962717794, 0.6945620206761459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 119}], {
             RGBColor[
             0.9902423673260538, 0.9899402039035738, 0.7900908512910899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 127}], {
             RGBColor[
             0.994000218756284, 0.9895753995276546, 0.5883390218584061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 129}], {
             RGBColor[
             0.9946652654136181, 0.990997867081161, 0.6607252463170131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 216}], {
             RGBColor[
             0.9940610647703836, 0.9897055429993378, 0.5949617349950662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 231}], {
             RGBColor[
             0.9660012812619743, 0.9720855446842867, 0.8411694369385957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 235}], {
             RGBColor[
             0.9949721018097641, 0.9916541591065988, 0.694122494462766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 298}], {
             RGBColor[
             0.9915475809511449, 0.9904799432800092, 0.7684600837387454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 313}], {
             RGBColor[
             0.9931370014791816, 0.9870059804796609, 0.5558690414748197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 317}], {
             RGBColor[
             0.9818527343067931, 0.9489414976352643, 0.5120317943651397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 336}], {
             RGBColor[
             0.9770571362400011, 0.9803309832245981, 0.8224547582895884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 361}], {
             RGBColor[
             0.9943715222108823, 0.9903695800725025, 0.628753111472133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 393}], {
             RGBColor[
             0.9774163885346646, 0.9805989129977364, 0.8218466378627278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 396}], {
             RGBColor[
             0.9940441586589785, 0.9896693825365126, 0.5931216091010634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 98}], {
             RGBColor[
             0.9935347186478014, 0.9915297581763487, 0.7521072516713663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 139}], {
             RGBColor[
             0.8909438238301377, 0.9133979455458447, 0.882115047999223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 204}], {
             RGBColor[
             0.9796505669935616, 0.9830696694257075, 0.862263034730878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 224}], {
             RGBColor[
             0.9928382097576899, 0.9900399960882509, 0.676296557337329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 290}], {
             RGBColor[
             0.929628412983143, 0.7408268316341693, 0.49779353951784266`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 318}], {
             RGBColor[
             0.988672138724151, 0.9895836524967501, 0.8373955071134591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 345}], {
             RGBColor[
             0.9630542424030863, 0.9706546902378728, 0.8890572621180322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 77}], {
             RGBColor[
             0.9797166041079964, 0.9531800591503454, 0.6020936553662565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 94}], {
             RGBColor[
             0.9822744234266505, 0.9518574182079732, 0.38667656538869594`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 254}], {
             RGBColor[
             0.9771666432828869, 0.951812449931785, 0.6303302853415147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 289}], {
             RGBColor[
             0.9622412906109532, 0.9406811463470788, 0.6555950142596751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 68}], {
             RGBColor[
             0.9864971981166644, 0.97356565425332, 0.6112453416096386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 173}], {
             RGBColor[
             0.9886079378521144, 0.9727365263796821, 0.45254945177539707`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 176}], {
             RGBColor[
             0.9894474544559108, 0.9745321675070537, 0.5439256532027168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 250}], {
             RGBColor[
             0.9884950442809782, 0.9743918149845683, 0.5781358604068201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 363}], {
             RGBColor[
             0.9880452019492336, 0.9713358004340074, 0.40805829635729746`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 123}], {
             RGBColor[
             0.9536472535282718, 0.8416192506872258, 0.42713865465264444`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 131}], {
             RGBColor[
             0.9945377391521761, 0.9910379641040239, 0.6695866226598469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 140}], {
             RGBColor[
             0.9915213301347341, 0.9897906014571358, 0.7195763262951642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 203}], {
             RGBColor[
             0.9730713567665783, 0.9186293473284136, 0.44276774406048863`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 232}], {
             RGBColor[
             0.9944938963375178, 0.9906313259554538, 0.6420727799508392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 257}], {
             RGBColor[
             0.9941395890669511, 0.9898734985296717, 0.6035086200806679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 275}], {
             RGBColor[
             0.9506848461536517, 0.9593801878122881, 0.7981610231433889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 280}], {
             RGBColor[
             0.9817789495008209, 0.9833046804216592, 0.770994516304759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 297}], {
             RGBColor[
             0.9839196326998498, 0.9563990219951084, 0.47878717864180037`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 318}], {
             RGBColor[
             0.989818992876708, 0.98908664125287, 0.747788460168257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 322}], {
             RGBColor[
             0.9904506685823354, 0.9893478553904721, 0.7373199590016877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 325}], {
             RGBColor[
             0.9920351685702655, 0.9900030868552735, 0.7110606936471636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 339}], {
             RGBColor[
             0.9660474043101712, 0.8907817164321631, 0.437116107040709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 113}], {
             RGBColor[
             0.9783149769802995, 0.9489863940975024, 0.6003420222939293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 124}], {
             RGBColor[
             0.9672821370386099, 0.9412322782886446, 0.6402515134341427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 194}], {
             RGBColor[
             0.9782394095467696, 0.9489551450217433, 0.6015943702297679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 208}], {
             RGBColor[
             0.9341063501496247, 0.7708201746381015, 0.2867327104901896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 210}], {
             RGBColor[
             0.9422889457275101, 0.8048740066919582, 0.2934000353966787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 249}], {
             RGBColor[
             0.9818156536625174, 0.9493689270638082, 0.4649061831074289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 266}], {
             RGBColor[
             0.9626889519147276, 0.8857532333251984, 0.309814359224603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 293}], {
             RGBColor[
             0.9814516370774204, 0.9485903323960079, 0.42528522426957327`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 316}], {
             RGBColor[
             0.9546591438575385, 0.8539177201533564, 0.3033533871779688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 385}], {
             RGBColor[
             0.9519766013405789, 0.9297831449874765, 0.6649709428356618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 387}], {
             RGBColor[
             0.9770789648479794, 0.9484752713167252, 0.6208259420233335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 161}], {
             RGBColor[
             0.9915691542046503, 0.9897193850092825, 0.7121695322666692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 173}], {
             RGBColor[
             0.9911983850490013, 0.9889263472758613, 0.6718135977962749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 176}], {
             RGBColor[
             0.9920379016527976, 0.9907219884032329, 0.7631897992235945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 250}], {
             RGBColor[
             0.9910854914778651, 0.9905816358807474, 0.7974000064276978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 363}], {
             RGBColor[
             0.9906356491461205, 0.9875256213301866, 0.6273224423781752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 106}], {
             RGBColor[
             0.9656164536556104, 0.9717640596617441, 0.8390849120696575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 107}], {
             RGBColor[
             0.9366148468974655, 0.8697697146367034, 0.6303613243286879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 150}], {
             RGBColor[
             0.9657959509575915, 0.9721479862407207, 0.8586220856613656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 212}], {
             RGBColor[
             0.9634790687944403, 0.9712156800123681, 0.8988930499571957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 270}], {
             RGBColor[
             0.9555480699156285, 0.9663684038432068, 0.9601297020993899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 283}], {
             RGBColor[
             0.9655406374679323, 0.9716018965024931, 0.8308327879241677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 294}], {
             RGBColor[
             0.9299810503643144, 0.9469891379592922, 0.9926107120969914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 295}], {
             RGBColor[
             0.8990207090785423, 0.9223022022140938, 0.9896576871065315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 320}], {
             RGBColor[
             0.9640701460370374, 0.9680231047804874, 0.707645618823806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 347}], {
             RGBColor[
             0.9655407000497649, 0.9720682175179514, 0.8647264847258069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 373}], {
             RGBColor[
             0.9655421875275167, 0.9716052119232093, 0.8310015023440818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 380}], {
             RGBColor[
             0.9657231071126332, 0.9721436475260952, 0.8617035276397331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 381}], {
             RGBColor[
             0.9653818203605676, 0.9712622027687128, 0.8135465258931047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 390}], {
             RGBColor[
             0.965671085908496, 0.9718809125264987, 0.8450312956450843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 108}], {
             RGBColor[
             0.9867266149899832, 0.9668461794081845, 0.40648319802669014`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 152}], {
             RGBColor[
             0.9704821272723272, 0.9098113329642467, 0.35503392572594006`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 154}], {
             RGBColor[
             0.991123372944146, 0.9882582082738424, 0.6267448756131184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 180}], {
             RGBColor[
             0.9836158054304218, 0.983570193393241, 0.680254895515757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 198}], {
             RGBColor[
             0.9921398659397509, 0.9886785542502035, 0.6098989560763993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 236}], {
             RGBColor[
             0.9779532078231916, 0.9793470373694213, 0.6898401962228098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 262}], {
             RGBColor[
             0.9623923261896213, 0.8777379674377221, 0.34852468188275787`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 267}], {
             RGBColor[
             0.9937209016216698, 0.9889779684200091, 0.5579370755011941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 284}], {
             RGBColor[
             0.9817574303289419, 0.9500839527264486, 0.38717885397032803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 286}], {
             RGBColor[
             0.9679334394184899, 0.899706634923662, 0.3529831916533497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 332}], {
             RGBColor[
             0.9647824840739967, 0.8872141469763706, 0.3504478590207425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 72}], {
             RGBColor[
             0.9660954707344187, 0.9740487833501258, 0.9339527481104528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 88}], {
             RGBColor[
             0.9889483654773512, 0.9873721131883136, 0.6637590664677853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 138}], {
             RGBColor[
             0.9902178702840809, 0.9900874556032837, 0.8019368302048144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 157}], {
             RGBColor[
             0.9773318304809242, 0.9482380642815854, 0.6142729785838822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 365}], {
             RGBColor[
             0.9838089407047856, 0.9872594602508804, 0.9039684638634988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 88}], {
             RGBColor[
             0.9697331480126705, 0.9732272902191365, 0.7046083731095706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 109}], {
             RGBColor[
             0.9701058869884744, 0.9757071935341745, 0.8674897721561783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 157}], {
             RGBColor[
             0.9581166130162435, 0.9340932413124082, 0.6551222852256675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 181}], {
             RGBColor[
             0.9675850722119318, 0.9746647718420893, 0.90926619666301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 191}], {
             RGBColor[
             0.9697536277598704, 0.973271094327577, 0.7068374672059309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 365}], {
             RGBColor[
             0.9645937232401048, 0.9731146372817032, 0.9448177705052843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 370}], {
             RGBColor[
             0.9614016033451769, 0.9451742850443094, 0.667883852335203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 78}], {
             RGBColor[
             0.9762292663929449, 0.9791953982055644, 0.7827422635317451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 99}], {
             RGBColor[
             0.9825929281889896, 0.9518974542644458, 0.4758680044048411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 104}], {
             RGBColor[
             0.9934159906956126, 0.9906108295085139, 0.6908473055732349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 112}], {
             RGBColor[
             0.9945932724118208, 0.9908438813299255, 0.6528892523606789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 141}], {
             RGBColor[
             0.9899090592867283, 0.9891606232469139, 0.7489662346660071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 172}], {
             RGBColor[
             0.9943683107493007, 0.990362711080908, 0.628403563697812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 177}], {
             RGBColor[
             0.9760370806749821, 0.9297830412135011, 0.45039977478084386`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 208}], {
             RGBColor[
             0.9464137504042746, 0.8112893790905376, 0.4235353984525718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 225}], {
             RGBColor[
             0.9453232283756698, 0.8063375732565341, 0.42262544014076303`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 240}], {
             RGBColor[
             0.994616898953143, 0.9908944161128038, 0.6554608555774816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 243}], {
             RGBColor[
             0.9942732547387418, 0.9909653302210288, 0.6766402218503564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 285}], {
             RGBColor[
             0.9293383324033435, 0.7337538940135061, 0.4092872511157991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 337}], {
             RGBColor[
             0.9941836720381808, 0.9899677875476599, 0.6083067794504556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 399}], {
             RGBColor[
             0.9920398430072379, 0.9900417570739886, 0.7136536341256586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 86}], {
             RGBColor[
             0.9894406596826176, 0.9755119636653691, 0.4586354813653564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 91}], {
             RGBColor[
             0.9892195266830907, 0.9881549057973895, 0.7080151607337691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 95}], {
             RGBColor[
             0.9925819769863145, 0.9861083645471168, 0.4708389059022219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 104}], {
             RGBColor[
             0.9929983546712857, 0.9897175482819578, 0.6453902016760262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 112}], {
             RGBColor[
             0.9941756363874938, 0.9899506001033693, 0.6074321484634702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 141}], {
             RGBColor[
             0.9894914232624015, 0.9882673420203578, 0.7035091307687985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 148}], {
             RGBColor[
             0.9652116971732485, 0.9703967041576995, 0.7552280816289502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 172}], {
             RGBColor[
             0.9939506747249738, 0.9894694298543518, 0.5829464598006033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 179}], {
             RGBColor[
             0.9916388248780581, 0.9891553477741362, 0.6679211287001285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 240}], {
             RGBColor[
             0.994199262928816, 0.9900011348862476, 0.610003751680273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 263}], {
             RGBColor[
             0.9671749065307087, 0.8959755186035112, 0.3952026642843294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 279}], {
             RGBColor[
             0.9834232695678888, 0.9552138938580008, 0.43525905705840895`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 285}], {
             RGBColor[
             0.9289206963790165, 0.7328606127869499, 0.3638301472185904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 399}], {
             RGBColor[
             0.991622206982911, 0.9891484758474325, 0.66819653022845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 105}], {
             RGBColor[
             0.9895389230192384, 0.9899420900781088, 0.8230306481780129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 132}], {
             RGBColor[
             0.9889425939329304, 0.9881113270120725, 0.7177612439264864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 202}], {
             RGBColor[
             0.9890890660729679, 0.9897560626700299, 0.8304859419701727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 215}], {
             RGBColor[
             0.9817522593206467, 0.9858703259210324, 0.9139314304807022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 218}], {
             RGBColor[
             0.9793547077985556, 0.9840822359214874, 0.9179898598260172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 229}], {
             RGBColor[
             0.9833431816996888, 0.969804988772597, 0.6465370201317933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 260}], {
             RGBColor[
             0.8526357992393719, 0.8848360634688806, 0.9401753380144158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 329}], {
             RGBColor[
             0.9886914080227789, 0.989591620846931, 0.8370761649678502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 341}], {
             RGBColor[
             0.9538711089359255, 0.8607305983506361, 0.5823434890999475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 349}], {
             RGBColor[
             0.9607497234080236, 0.9702066690258946, 0.9494832454421107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 77}], {
             RGBColor[
             0.9805618255965312, 0.956031189698616, 0.6053771812425286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 103}], {
             RGBColor[
             0.9718583668111578, 0.9500743117767189, 0.644030078175208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 144}], {
             RGBColor[
             0.9511250657747565, 0.8386841985604598, 0.30687439661903737`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 145}], {
             RGBColor[
             0.9559753541405654, 0.8579139756681071, 0.31077705248906773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 200}], {
             RGBColor[
             0.966884140098469, 0.9463645416389443, 0.6524501465136849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 207}], {
             RGBColor[
             0.9835179435030863, 0.9555604691615999, 0.43331243454405893`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 222}], {
             RGBColor[
             0.95702871227924, 0.8620901896771604, 0.31162460917293866`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 333}], {
             RGBColor[
             0.9397801063040482, 0.7937052147427347, 0.2977459759284805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 368}], {
             RGBColor[
             0.9670687614667207, 0.9465022319530967, 0.6521376306941995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 94}], {
             RGBColor[
             0.9899649341793446, 0.9877378916772064, 0.6429431363302534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 103}], {
             RGBColor[
             0.9787036560753173, 0.9831036546976816, 0.8970131232404932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 145}], {
             RGBColor[
             0.9628206434047251, 0.8909433185890698, 0.563760097554353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 200}], {
             RGBColor[
             0.9737294293626286, 0.9793938845599071, 0.9054331915789702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 207}], {
             RGBColor[
             0.9903632327672458, 0.9885898120825626, 0.6862954796093441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 254}], {
             RGBColor[
             0.9848571540355813, 0.9876929234010182, 0.886596856283072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 333}], {
             RGBColor[
             0.9466253955682078, 0.8267345576636974, 0.5507290209937657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 104}], {
             RGBColor[
             0.9754465330982183, 0.979806245562737, 0.8636444775519435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 172}], {
             RGBColor[
             0.9763988531519062, 0.9795581271351311, 0.8012007356765206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 194}], {
             RGBColor[
             0.972577352204025, 0.9786197655284025, 0.9111942301708587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 208}], {
             RGBColor[
             0.9284442928068801, 0.8004847951447607, 0.5963325704312805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 217}], {
             RGBColor[
             0.9521665384959206, 0.8961481616079203, 0.615503462579674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 230}], {
             RGBColor[
             0.9743298974742458, 0.9793444880359978, 0.8821500196015276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 233}], {
             RGBColor[
             0.9751214017919297, 0.9796717954120933, 0.8690327447099923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 240}], {
             RGBColor[
             0.9766474413557484, 0.9800898321670269, 0.8282580275561902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 242}], {
             RGBColor[
             0.9392596600828684, 0.8449766896624356, 0.6051182852451578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 244}], {
             RGBColor[
             0.9656180799083711, 0.9444479210895277, 0.6525290457630154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 264}], {
             RGBColor[
             0.9718917127998203, 0.9783362360146349, 0.9225570494764275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 285}], {
             RGBColor[
             0.911368874805949, 0.7229493100677292, 0.5820844230945077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 357}], {
             RGBColor[
             0.9753143009367471, 0.9797515641657571, 0.8658359066733841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 385}], {
             RGBColor[
             0.9463145439978343, 0.9594477654941357, 0.9745708027767527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 100}], {
             RGBColor[
             0.9684616781190803, 0.9006658515756563, 0.4205758364523364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 137}], {
             RGBColor[
             0.9491226198441998, 0.889107809297212, 0.6169550557594734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 175}], {
             RGBColor[
             0.968293211561301, 0.9018626201686307, 0.5154241345963817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 213}], {
             RGBColor[
             0.9098899215510812, 0.6725129444576956, 0.24594291306996213`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 227}], {
             RGBColor[
             0.8621039504202523, 0.8205370045188756, 0.6259494629187701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[
             0.9533421514876239, 0.850473238113122, 0.29303929837702897`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 278}], {
             RGBColor[
             0.9414254489737628, 0.8833672718650007, 0.6299843582994418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 302}], {
             RGBColor[
             0.9584897573085817, 0.8678373212625365, 0.3130367749476576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 314}], {
             RGBColor[
             0.9679434723395108, 0.9017179940125325, 0.5212202185975361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 352}], {
             RGBColor[
             0.9537823619929169, 0.851958171513817, 0.29474943306331347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 379}], {
             RGBColor[
             0.9684889511067676, 0.9007241857385972, 0.4235443328527199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 151}], {
             RGBColor[
             0.9944825394567132, 0.9906070347357695, 0.6408366535618026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 168}], {
             RGBColor[
             0.9827437455725694, 0.9840167414478658, 0.7687676793637866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 265}], {
             RGBColor[
             0.9804255596363569, 0.9822878421723196, 0.7726917634740694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 304}], {
             RGBColor[
             0.9867598450145081, 0.9659863546301584, 0.489257135173156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 378}], {
             RGBColor[
             0.9769143377591843, 0.9327751468229144, 0.45100919865426004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 192}], {
             RGBColor[
             0.9791307820450117, 0.9802285294732777, 0.6881054720063857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 271}], {
             RGBColor[
             0.9768790634362743, 0.9336251879570356, 0.3684728728215091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 287}], {
             RGBColor[
             0.9933732092281277, 0.9882342895473157, 0.5200929041728524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 292}], {
             RGBColor[
             0.9885746402219953, 0.9872082783274595, 0.6692773861139821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 374}], {
             RGBColor[
             0.9911650038711315, 0.9818150195421378, 0.4239710537374483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 382}], {
             RGBColor[
             0.9924720336535076, 0.9888199506698323, 0.6046874908229418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 384}], {
             RGBColor[
             0.992687770711041, 0.9867682058677321, 0.4454871516241551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 101}], {
             RGBColor[
             0.9942569362535791, 0.9901244922962484, 0.6162811371622345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 136}], {
             RGBColor[
             0.9841508375636685, 0.9851943551012241, 0.7765584969247161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 259}], {
             RGBColor[
             0.9932013775078093, 0.9906348630236705, 0.7026020320425685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 331}], {
             RGBColor[
             0.9898184126080252, 0.9892359200993776, 0.7586665152645107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 335}], {
             RGBColor[
             0.9943445829210225, 0.9903119596554721, 0.6258209360209033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 120}], {
             RGBColor[
             0.9807513743193457, 0.9587494435040512, 0.6204825551414908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 187}], {
             RGBColor[
             0.9838520081771561, 0.9571911732320719, 0.3917685303709766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 206}], {
             RGBColor[
             0.9846504161250986, 0.9590836620011458, 0.46295838455637767`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 217}], {
             RGBColor[
             0.9607868380719301, 0.8764623867823715, 0.3173958150976469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 220}], {
             RGBColor[
             0.9840729430977735, 0.9578485055871766, 0.40010400928246226`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 230}], {
             RGBColor[
             0.9829501970502553, 0.959658713210449, 0.5840423721195005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 244}], {
             RGBColor[
             0.9742383794843806, 0.9247621462639788, 0.3544213982809883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 245}], {
             RGBColor[
             0.9472428298866845, 0.9336285877485953, 0.6757294841625027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 321}], {
             RGBColor[
             0.935459458019419, 0.7735104800633466, 0.2968855594909299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 328}], {
             RGBColor[
             0.9848861461955358, 0.959587864785845, 0.4886161479661157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 364}], {
             RGBColor[
             0.9842702705184876, 0.9582705689872213, 0.4215818812635071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 102}], {
             RGBColor[
             0.9776878313195962, 0.9826947514149074, 0.9143480206931581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 163}], {
             RGBColor[
             0.9781851749164872, 0.9830656694551433, 0.9135061477116064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 167}], {
             RGBColor[
             0.9899187424130917, 0.9894497518672206, 0.7695312940631194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 174}], {
             RGBColor[
             0.9856798871515468, 0.9883462795741202, 0.8869848593703533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 183}], {
             RGBColor[
             0.9895139642720978, 0.9899317689947558, 0.8234442792092995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 189}], {
             RGBColor[
             0.9893245859392146, 0.9881789112480317, 0.7048610285903062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 222}], {
             RGBColor[
             0.9628245707753947, 0.8946855660064126, 0.5819994379038335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 226}], {
             RGBColor[
             0.9475648671659216, 0.9595617841089046, 0.942202286388181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 234}], {
             RGBColor[
             0.9382859812097275, 0.9521630523160851, 0.94131725796232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 238}], {
             RGBColor[
             0.8201234046108147, 0.8592774220555097, 0.9296928031041036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 246}], {
             RGBColor[
             0.9844760579479377, 0.9877573997196236, 0.9028573236644315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 269}], {
             RGBColor[
             0.9855513309042805, 0.9882931182621308, 0.8891153690804587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 272}], {
             RGBColor[
             0.9836218944625091, 0.9871203659907553, 0.9043031996437458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 395}], {
             RGBColor[
             0.9597771535549335, 0.9692995297818197, 0.9433671051660018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 88}], {
             RGBColor[
             0.9929450027855897, 0.9873183992650398, 0.4734852754864444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 162}], {
             RGBColor[
             0.9910592479497475, 0.9888643573483187, 0.6737957617866537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 181}], {
             RGBColor[
             0.9907969269848511, 0.9887558808879926, 0.6781430990398838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 191}], {
             RGBColor[
             0.9929654825327896, 0.9873622033734804, 0.47571436958280466`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 211}], {
             RGBColor[
             0.9913870270028501, 0.988999902410314, 0.6683636146117473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 214}], {
             RGBColor[
             0.9515627219113694, 0.9595085736272035, 0.7519083193216576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 263}], {
             RGBColor[
             0.9671451619676543, 0.8959118979907743, 0.3919651521580127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 307}], {
             RGBColor[
             0.9935521935591021, 0.9886171189331785, 0.5395742440361708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 312}], {
             RGBColor[
             0.994104014391239, 0.9897974078954748, 0.5996365361708488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 340}], {
             RGBColor[
             0.9846794719971803, 0.9594880744051594, 0.4370172061666434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 348}], {
             RGBColor[
             0.9895206833109123, 0.9882281213308526, 0.6992937595298032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 91}], {
             RGBColor[
             0.9852967344240228, 0.9754534497645295, 0.6476197583405063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 93}], {
             RGBColor[
             0.9892311555337039, 0.9750638554749613, 0.4358322476658276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 95}], {
             RGBColor[
             0.9886591847272466, 0.9734069085142569, 0.41044350350895903`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 125}], {
             RGBColor[
             0.9858384793483863, 0.9756774752129633, 0.6386416429528792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 148}], {
             RGBColor[
             0.9612889049141806, 0.9576952481248395, 0.6948326792356874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 162}], {
             RGBColor[
             0.9871662002537342, 0.9762265219281956, 0.6166378715197074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 179}], {
             RGBColor[
             0.9877160326189902, 0.9764538917412762, 0.6075257263068657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 214}], {
             RGBColor[
             0.9476696742153559, 0.9468707382070805, 0.6947504290547113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 263}], {
             RGBColor[
             0.9632521142716408, 0.8832740625706513, 0.3348072618910665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 264}], {
             RGBColor[
             0.98552074211382, 0.9755460827009957, 0.6439073712072474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 285}], {
             RGBColor[
             0.9249979041199486, 0.72015915675409, 0.3034347448253276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 119}], {
             RGBColor[
             0.9902758871529589, 0.9900118994239497, 0.7937392775893255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 127}], {
             RGBColor[
             0.9940337385831892, 0.9896470950480304, 0.5919874481566417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 129}], {
             RGBColor[
             0.9946987852405234, 0.9910695626015368, 0.6643736726152487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 216}], {
             RGBColor[
             0.9940945845972887, 0.9897772385197136, 0.5986101612933017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 231}], {
             RGBColor[
             0.9660348010888795, 0.9721572402046625, 0.8448178632368313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 235}], {
             RGBColor[
             0.9950056216366694, 0.9917258546269746, 0.6977709207610016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 298}], {
             RGBColor[
             0.9915811007780501, 0.990551638800385, 0.7721085100369811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 313}], {
             RGBColor[
             0.9931705213060869, 0.9870776760000367, 0.5595174677730553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 317}], {
             RGBColor[
             0.9818862541336983, 0.94901319315564, 0.5156802206633753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 361}], {
             RGBColor[
             0.9944050420377875, 0.9904412755928784, 0.6324015377703686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 393}], {
             RGBColor[
             0.9774499083615698, 0.9806706085181123, 0.8254950641609634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 396}], {
             RGBColor[
             0.9940776784858838, 0.9897410780568885, 0.5967700353992991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 109}], {
             RGBColor[
             0.992958781731407, 0.9890305233723623, 0.5972960905135105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 157}], {
             RGBColor[
             0.980969507759176, 0.9474165711505961, 0.3849286035829999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 181}], {
             RGBColor[
             0.9904379669548644, 0.9879881016802772, 0.6390725150203422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 191}], {
             RGBColor[
             0.9926065225028029, 0.9865944241657648, 0.4366437855632632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 365}], {
             RGBColor[
             0.9874466179830375, 0.9864379671198911, 0.6746240888626166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 370}], {
             RGBColor[
             0.9842544980881095, 0.9584976148824973, 0.3976901706925353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 128}], {
             RGBColor[
             0.9858806631209296, 0.9853334591214489, 0.6823036607197548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 133}], {
             RGBColor[
             0.9820657408800009, 0.9860031617143354, 0.9088796716956054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 155}], {
             RGBColor[
             0.968796415812579, 0.976248998520977, 0.937703708217859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 170}], {
             RGBColor[
             0.9866926107190892, 0.9870701329334177, 0.7706791460197004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 171}], {
             RGBColor[
             0.9788401821282978, 0.9616916705174614, 0.6458196082951417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 199}], {
             RGBColor[
             0.9299013698295896, 0.7675869127831725, 0.5712349496622451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 299}], {
             RGBColor[
             0.9866101601222741, 0.9868937794438644, 0.7617049073824793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 306}], {
             RGBColor[
             0.9769203220208953, 0.9823077944694636, 0.9239520540612622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 342}], {
             RGBColor[
             0.9863124893599245, 0.9862570917823292, 0.7293052819117299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 353}], {
             RGBColor[
             0.9866123202371591, 0.986898399711182, 0.7619400225570174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 121}], {
             RGBColor[
             0.9267646438640762, 0.9426689062753272, 0.9268723884276863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 122}], {
             RGBColor[
             0.9298118951622467, 0.9419639482860234, 0.7335313612127397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.9270342799405635, 0.9427804077222859, 0.9224038208444922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 178}], {
             RGBColor[
             0.929628064001302, 0.9415707520209442, 0.7135224738183336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 190}], {
             RGBColor[
             0.9307377714966856, 0.9439443041449311, 0.8343072863700147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 212}], {
             RGBColor[
             0.9286189962861502, 0.9434357286565384, 0.896140969883684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 221}], {
             RGBColor[
             0.9301309978234884, 0.9426464766121915, 0.768263716615557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 268}], {
             RGBColor[
             0.9293147962872859, 0.9437234598382523, 0.884609763192185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 274}], {
             RGBColor[
             0.9300749326912073, 0.9425265589632965, 0.7621613729606453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 295}], {
             RGBColor[
             0.8641606365702521, 0.894522250858264, 0.9869056070330197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 319}], {
             RGBColor[
             0.9287017309280604, 0.9434699415571515, 0.8947698427568415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 324}], {
             RGBColor[
             0.9042902154197303, 0.9263590135299226, 0.9851347897044048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 351}], {
             RGBColor[
             0.9258090368561205, 0.9422737382195576, 0.9427092695811741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 373}], {
             RGBColor[
             0.9306821150192266, 0.9438252605673794, 0.8282494222705701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 95}], {
             RGBColor[
             0.9884380517277196, 0.9860498506462771, 0.6598231828773717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 112}], {
             RGBColor[
             0.990031711128899, 0.9898920862025298, 0.79641642543862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 125}], {
             RGBColor[
             0.9856173463488593, 0.9883204173449838, 0.8880213223212918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 148}], {
             RGBColor[
             0.9610677719146536, 0.9703381902568599, 0.9442123586041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 179}], {
             RGBColor[
             0.9874948996194632, 0.9890968338732966, 0.8569054056752785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 257}], {
             RGBColor[
             0.9895993201161489, 0.9889672455476948, 0.7493533321087827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 263}], {
             RGBColor[
             0.9630309812721138, 0.8959170047026717, 0.5841869412594792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 279}], {
             RGBColor[
             0.979279344309294, 0.9551553799571613, 0.6242433340335588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 285}], {
             RGBColor[
             0.9247767711204217, 0.7328020988861104, 0.5528144241937403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 288}], {
             RGBColor[
             0.9824165914279187, 0.9862601048943693, 0.9080743758320324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 135}], {
             RGBColor[
             0.9737459058384738, 0.9353245416127434, 0.5946927985125102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 165}], {
             RGBColor[
             0.9749350861029213, 0.9271123012828099, 0.3571279719320136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 182}], {
             RGBColor[
             0.9066706289030972, 0.6403586285971954, 0.2512943901333653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 256}], {
             RGBColor[
             0.977507568093166, 0.9352447209474657, 0.41347857178600994`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 281}], {
             RGBColor[
             0.9755494461290541, 0.9360703518717697, 0.5648034684849381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 311}], {
             RGBColor[
             0.9549836547683954, 0.9216093010582034, 0.6388845881632259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 386}], {
             RGBColor[
             0.9759771869279903, 0.9362472336845669, 0.5577146964888628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 98}], {
             RGBColor[
             0.9940757249592372, 0.9897368996609235, 0.5965574060796003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 125}], {
             RGBColor[
             0.9895517674585405, 0.9879308230554155, 0.6762338116466132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 148}], {
             RGBColor[
             0.9650021930243347, 0.9699485959672915, 0.7324248479294213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 162}], {
             RGBColor[
             0.9908794883638883, 0.9884798697706476, 0.6542300402134416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 214}], {
             RGBColor[
             0.95138296232551, 0.9591240860495325, 0.7323425977484455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 248}], {
             RGBColor[
             0.9754266980845879, 0.977723174772668, 0.7147788800087742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 276}], {
             RGBColor[
             0.9940934708524607, 0.9897748563321435, 0.598488937042017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 288}], {
             RGBColor[
             0.9863510125375998, 0.985870510604801, 0.6962868651573538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 290}], {
             RGBColor[
             0.9301694192945789, 0.7390339731187441, 0.3422436939260767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 103}], {
             RGBColor[
             0.9812614753939712, 0.9817810137553094, 0.6815960332629326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 145}], {
             RGBColor[
             0.965378462723379, 0.8896206776466976, 0.34834300757679243`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 207}], {
             RGBColor[
             0.9929210520858999, 0.9872671711401904, 0.47087838963178363`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 254}], {
             RGBColor[
             0.9874149733542352, 0.986370282458646, 0.6711797663055115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 125}], {
             RGBColor[
             0.9889797966520831, 0.9862738760947111, 0.6508450674897446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 162}], {
             RGBColor[
             0.990307517557431, 0.9868229228099432, 0.6288412960565729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 233}], {
             RGBColor[
             0.9918917484096261, 0.9874780429802018, 0.6025864909776776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 263}], {
             RGBColor[
             0.9663934315753376, 0.8938704634523991, 0.347010686427932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 264}], {
             RGBColor[
             0.9886620594175168, 0.9861424835827435, 0.6561107957441128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 285}], {
             RGBColor[
             0.9281392214236455, 0.7307555576358378, 0.315638169362193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 312}], {
             RGBColor[
             0.9933522839989224, 0.9877559733570995, 0.554682070440768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 173}], {
             RGBColor[
             0.9938485177462753, 0.9892509264065709, 0.5718273031090746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 201}], {
             RGBColor[
             0.9578085035157242, 0.8579056398601299, 0.44300709202418814`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 209}], {
             RGBColor[
             0.9939534110791748, 0.9894752826393001, 0.5832442950685716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 223}], {
             RGBColor[
             0.9941464580959669, 0.9898881906881711, 0.6042562714983096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 245}], {
             RGBColor[
             0.9566865812669494, 0.9643212721497095, 0.8113358630173608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 323}], {
             RGBColor[
             0.9876786068518277, 0.9689358825870447, 0.5055533316748861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 109}], {
             RGBColor[
             0.9922194189127331, 0.9910505440156713, 0.7786078943218013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 181}], {
             RGBColor[
             0.9896986041361906, 0.9900081223235861, 0.820384318828633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 191}], {
             RGBColor[
             0.9918671596841291, 0.9886144448090738, 0.6179555893715539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 193}], {
             RGBColor[
             0.9769180547653911, 0.9382641339174995, 0.553373562496731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 211}], {
             RGBColor[
             0.9902887041541895, 0.9902521438459074, 0.8106048344004966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 214}], {
             RGBColor[
             0.9504643990627087, 0.960760815062797, 0.8941495391104067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 248}], {
             RGBColor[
             0.9745081348217867, 0.9793599037859324, 0.8765858213707355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 305}], {
             RGBColor[
             0.9818058020070608, 0.9848024920238765, 0.864232774362499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 334}], {
             RGBColor[
             0.96437269215525, 0.9718009072404936, 0.8937424820583671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 340}], {
             RGBColor[
             0.9835811491485198, 0.9607403158407528, 0.5792584259553927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 360}], {
             RGBColor[
             0.9771598865507902, 0.9390798893144544, 0.554313033316906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 370}], {
             RGBColor[
             0.9835151352694357, 0.9605176355258063, 0.579001974500826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 125}], {
             RGBColor[
             0.9906830487739198, 0.9903505193989256, 0.7993668013666517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 139}], {
             RGBColor[
             0.8926161114569529, 0.9140247833739297, 0.8496981921274956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 193}], {
             RGBColor[
             0.9789678993435716, 0.9390471012477453, 0.5146996108548082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 204}], {
             RGBColor[
             0.9813228546203767, 0.9836965072537924, 0.8298461788591505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 248}], {
             RGBColor[
             0.9765579793999672, 0.9801428711161781, 0.8379118697288128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 276}], {
             RGBColor[
             0.99522475216784, 0.9921945526756536, 0.7216219267620556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 290}], {
             RGBColor[
             0.9313007006099581, 0.7414536694622542, 0.4653766836461153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 318}], {
             RGBColor[
             0.9903444263509662, 0.990210490324835, 0.8049786512417316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 141}], {
             RGBColor[
             0.9783032634853785, 0.9510580953600184, 0.6148891475178118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 169}], {
             RGBColor[
             0.9753454635984442, 0.9284966009364268, 0.35872221100883295`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 177}], {
             RGBColor[
             0.9644312848736323, 0.8916805133266055, 0.3163226876326484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 197}], {
             RGBColor[
             0.9788840611634153, 0.9512982701257062, 0.6052638269365319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 225}], {
             RGBColor[
             0.93371743257432, 0.7682350453696386, 0.2885483529925676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 243}], {
             RGBColor[
             0.982667458937392, 0.9528628023341332, 0.5425631347021611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 252}], {
             RGBColor[
             0.9783136617217087, 0.9510623952979634, 0.6147168218320476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 300}], {
             RGBColor[
             0.9797456093362289, 0.9516545424359426, 0.5909857440978108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 337}], {
             RGBColor[
             0.9825778762368309, 0.9518652596607644, 0.4742296923022602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 367}], {
             RGBColor[
             0.9690656863019182, 0.9444058675219673, 0.6411456639013855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 398}], {
             RGBColor[
             0.9615010894941426, 0.9387642036086187, 0.6539505531341216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 146}], {
             RGBColor[
             0.9943994825554586, 0.9904293844223266, 0.6317964224280113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 175}], {
             RGBColor[
             0.993645521936614, 0.9903738404212127, 0.6629173052756094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 213}], {
             RGBColor[
             0.9352422319263942, 0.7610241647102776, 0.39343608374919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 227}], {
             RGBColor[
             0.8874562607955654, 0.9090482247714575, 0.7734426335979978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 278}], {
             RGBColor[
             0.9667777593490758, 0.9718784921175827, 0.7774775289786696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 302}], {
             RGBColor[
             0.9838420676838947, 0.9563485415151185, 0.46052994562688543`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 314}], {
             RGBColor[
             0.9932957827148239, 0.9902292142651145, 0.6687133892767639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 352}], {
             RGBColor[
             0.9791346723682299, 0.940469391766399, 0.4422426037425413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 377}], {
             RGBColor[
             0.9942307564856888, 0.9900684964199116, 0.6134316309901695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 136}], {
             RGBColor[
             0.9840783168532444, 0.9850392406345956, 0.768665065141001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 301}], {
             RGBColor[
             0.9906155461067816, 0.9894404299973389, 0.7363606626417241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 335}], {
             RGBColor[
             0.9942720622105983, 0.9901568451888436, 0.6179275042371881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 394}], {
             RGBColor[
             0.9929924587870491, 0.9869863436128122, 0.515517316712172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 163}], {
             RGBColor[
             0.9705647529114023, 0.9775678214338932, 0.9347103747657315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 167}], {
             RGBColor[
             0.9822983204080069, 0.9839519038459705, 0.7907355211172444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 174}], {
             RGBColor[
             0.978059465146462, 0.98284843155287, 0.9081890864244784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 189}], {
             RGBColor[
             0.9817041639341297, 0.9826810632267816, 0.7260652556444314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 222}], {
             RGBColor[
             0.95520414877031, 0.8891877179851624, 0.6032036649579586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 226}], {
             RGBColor[
             0.9399444451608368, 0.9540639360876545, 0.9634065134423062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 395}], {
             RGBColor[
             0.9521567315498488, 0.9638016817605696, 0.964571332220127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 145}], {
             RGBColor[
             0.9541171846193517, 0.8849864406671728, 0.6024129944870322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 200}], {
             RGBColor[
             0.9650259705772553, 0.9734370066380099, 0.9440860885116495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 207}], {
             RGBColor[
             0.9816597739818724, 0.9826329341606654, 0.7249483765420235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 222}], {
             RGBColor[
             0.9551705427580262, 0.889162654676226, 0.6032605511709033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 254}], {
             RGBColor[
             0.9761536952502079, 0.9817360454791211, 0.9252497532157513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 333}], {
             RGBColor[
             0.9379219367828344, 0.8207776797418003, 0.589381917926445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 112}], {
             RGBColor[
             0.9938105391170942, 0.991454728687098, 0.7337914663808771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 141}], {
             RGBColor[
             0.9891263259920016, 0.9897714706040865, 0.8298684486862055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 172}], {
             RGBColor[
             0.9935855774545739, 0.9909735584380805, 0.7093057777180103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 208}], {
             RGBColor[
             0.9456310171095479, 0.8119002264477101, 0.5044376124727701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 240}], {
             RGBColor[
             0.9938341656584162, 0.9915052634699764, 0.7363630695976799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 242}], {
             RGBColor[
             0.9564463843855362, 0.8563921209653851, 0.5132233272866474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 243}], {
             RGBColor[
             0.9934905214440152, 0.9915761775782015, 0.7575424358705548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 285}], {
             RGBColor[
             0.9285555991086167, 0.7343647413706786, 0.49018946513599737`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 337}], {
             RGBColor[
             0.9934009387434541, 0.9905786349048324, 0.689208993470654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 357}], {
             RGBColor[
             0.9925010252394149, 0.9911669954687066, 0.7739409487148738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 399}], {
             RGBColor[
             0.9912571097125112, 0.9906526044311612, 0.794555848145857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 114}], {
             RGBColor[
             0.9749112277087162, 0.9260389032240749, 0.5106591874219321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 171}], {
             RGBColor[
             0.9866172058150859, 0.9657562451695187, 0.5549351440179182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 202}], {
             RGBColor[
             0.9941884846809708, 0.9918648033135196, 0.7459753787632453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 218}], {
             RGBColor[
             0.9844541264065585, 0.986190976564977, 0.8334792966190898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 229}], {
             RGBColor[
             0.9884426003076916, 0.9719137294160867, 0.5620264569248659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 261}], {
             RGBColor[
             0.9942193829649344, 0.9905994450576001, 0.6525563567687205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 349}], {
             RGBColor[
             0.9658491420160263, 0.9723154096693842, 0.8649726822351833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 353}], {
             RGBColor[
             0.9943893439239471, 0.9909629743632393, 0.6710555582797939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.9658915105099443, 0.8894908741334773, 0.47680192679655775`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 150}], {
             RGBColor[
             0.9950726145700703, 0.9918691457374946, 0.7050626881292354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 158}], {
             RGBColor[
             0.9896584326481626, 0.9896560264619232, 0.7966639249824912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 241}], {
             RGBColor[
             0.9936467561854851, 0.9913053007398457, 0.7305670825186057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 270}], {
             RGBColor[
             0.9848247335281073, 0.9860895633399807, 0.8065703045672596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 292}], {
             RGBColor[
             0.9897335617415042, 0.9896870942727496, 0.7954188414779613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 310}], {
             RGBColor[
             0.9826807942648117, 0.9517652898851456, 0.5126507656300945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 320}], {
             RGBColor[
             0.9933468096495162, 0.9877442642772614, 0.554086221291676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 347}], {
             RGBColor[
             0.9948173636622437, 0.9917893770147252, 0.7111670871936768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 374}], {
             RGBColor[
             0.9923239253906404, 0.9842938354874278, 0.5501125091014274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 384}], {
             RGBColor[
             0.9938466922305499, 0.989247021813022, 0.5716286069881342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 389}], {
             RGBColor[
             0.9931722201684704, 0.9911090679017908, 0.7384313723803844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 390}], {
             RGBColor[
             0.9949477495209749, 0.9916020720232726, 0.6914718981129542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 158}], {
             RGBColor[
             0.9606568258900177, 0.8876616814368825, 0.5879403372415215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 190}], {
             RGBColor[
             0.9658729008593097, 0.8894510699724941, 0.47477638117042664`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 212}], {
             RGBColor[
             0.9637541256487743, 0.8889424944841013, 0.5366100646840959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 241}], {
             RGBColor[
             0.9646451494273403, 0.8893109557148049, 0.521843494777636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 268}], {
             RGBColor[
             0.96444992564991, 0.8892302256658153, 0.5250788579925969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 270}], {
             RGBColor[
             0.9558231267699624, 0.88409521831494, 0.59784671682629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 295}], {
             RGBColor[
             0.8992957659328761, 0.840029016685827, 0.6273747018334315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 310}], {
             RGBColor[
             0.9536791875066668, 0.849770944860105, 0.3039271778891248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 324}], {
             RGBColor[
             0.9394253447823543, 0.8718657793574855, 0.6256038845048166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 346}], {
             RGBColor[
             0.9551190722276339, 0.8835701355900549, 0.5990384975196184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 351}], {
             RGBColor[
             0.9609441662187445, 0.8877805040471206, 0.583178364381586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 373}], {
             RGBColor[
             0.9658172443818507, 0.8893320263949425, 0.468718517070982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 390}], {
             RGBColor[
             0.96594614276283, 0.8896077269982319, 0.4827483103719845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 152}], {
             RGBColor[
             0.964638147060018, 0.8901399330696513, 0.32878380313235367`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 154}], {
             RGBColor[
             0.985279392731837, 0.968586808379247, 0.6004947530195319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 180}], {
             RGBColor[
             0.9777718252181128, 0.9638987934986457, 0.6540047729221706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 198}], {
             RGBColor[
             0.9862958857274418, 0.969007154355608, 0.5836488334828129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 205}], {
             RGBColor[
             0.9646513325227294, 0.8901922090355068, 0.3287944124651538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 236}], {
             RGBColor[
             0.9721092276108825, 0.959675637474826, 0.6635900736292233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 262}], {
             RGBColor[
             0.9565483459773123, 0.8580665675431267, 0.3222745592891714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 267}], {
             RGBColor[
             0.9878769214093608, 0.9693065685254139, 0.5316869529076076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 284}], {
             RGBColor[
             0.9759134501166329, 0.9304125528318534, 0.36092873137674153`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 286}], {
             RGBColor[
             0.9620894592061808, 0.8800352350290667, 0.3267330690597632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 332}], {
             RGBColor[
             0.9589385038616876, 0.8675427470817753, 0.3241977364271561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 367}], {
             RGBColor[
             0.9740134374969356, 0.9610957940899868, 0.6603667429896145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 398}], {
             RGBColor[
             0.9664488406891598, 0.9554541301766382, 0.6731716322223507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 157}], {
             RGBColor[
             0.9813422467349799, 0.9498964744656341, 0.5478100026296076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 181}], {
             RGBColor[
             0.9908107059306683, 0.9904680049953152, 0.8019539140669499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 191}], {
             RGBColor[
             0.9929792614786068, 0.9890743274808028, 0.5995251846098708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 305}], {
             RGBColor[
             0.9829179038015385, 0.9852623746956055, 0.8458023696008159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 334}], {
             RGBColor[
             0.9654847939497277, 0.9722607899122226, 0.875312077296684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 340}], {
             RGBColor[
             0.9846932509429975, 0.9612001985124818, 0.5608280211937096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 360}], {
             RGBColor[
             0.978271988345268, 0.9395397719861834, 0.535882628555223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 365}], {
             RGBColor[
             0.9878193569588414, 0.9889178704349291, 0.8375054879092243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 370}], {
             RGBColor[
             0.9846272370639134, 0.9609775181975353, 0.560571569739143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 227}], {
             RGBColor[
             0.8871381311882421, 0.9083677777092305, 0.7388161891092228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 237}], {
             RGBColor[
             0.9863858828753351, 0.9860590120161365, 0.7091211355338954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 251}], {
             RGBColor[
             0.8934493603134446, 0.9132981578689564, 0.7394452334466335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 308}], {
             RGBColor[
             0.987586229190323, 0.969371156250888, 0.44168473501572814`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 375}], {
             RGBColor[
             0.9768369104191639, 0.9331111799756955, 0.3999256614282948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 116}], {
             RGBColor[
             0.9723224069162785, 0.9788786769128355, 0.9317351250050598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 151}], {
             RGBColor[
             0.9799000160641114, 0.9823655654377131, 0.8108478995508541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 154}], {
             RGBColor[
             0.9773282506410899, 0.9817009102878624, 0.8824598709229867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 286}], {
             RGBColor[
             0.9541383171154337, 0.893149336937682, 0.608698186963218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 291}], {
             RGBColor[
             0.9534948637832139, 0.8905982588935428, 0.6081804493083232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 304}], {
             RGBColor[
             0.9721773216219061, 0.957744885332102, 0.6592683811622075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 383}], {
             RGBColor[
             0.9446867244247656, 0.8556769214757391, 0.6010932136269119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 141}], {
             RGBColor[
             0.9903036077082098, 0.9900045224254981, 0.7919103954736494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 172}], {
             RGBColor[
             0.9947628591707821, 0.9912066102594922, 0.6713477245054542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 179}], {
             RGBColor[
             0.9924510093238665, 0.9908925281792764, 0.7563223934049794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 240}], {
             RGBColor[
             0.9950114473746243, 0.991738315291388, 0.6984050163851239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 279}], {
             RGBColor[
             0.9842354540136973, 0.9569510742631412, 0.5236603217632598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 285}], {
             RGBColor[
             0.9297328808248249, 0.7345977931920903, 0.4522314119234413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 337}], {
             RGBColor[
             0.9945782204596623, 0.9908116867262441, 0.6512509402580979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 399}], {
             RGBColor[
             0.9924343914287195, 0.9908856562525727, 0.7565977949333009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 124}], {
             RGBColor[
             0.9760131905378696, 0.9811570991396776, 0.9042538200998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 149}], {
             RGBColor[
             0.9888790675187225, 0.9896692228711327, 0.8339661614728586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 210}], {
             RGBColor[
             0.9510199992267698, 0.8447988275429914, 0.557402342062336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 249}], {
             RGBColor[
             0.9905467071617772, 0.9892937479148411, 0.7289084897730862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 266}], {
             RGBColor[
             0.9714200054139873, 0.9256780541762315, 0.5738166658902604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 293}], {
             RGBColor[
             0.9901826905766802, 0.988515153247041, 0.6892875309352307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 315}], {
             RGBColor[
             0.9597808597982984, 0.8795327203253798, 0.5644515361220157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 316}], {
             RGBColor[
             0.9633901973567982, 0.8938425410043895, 0.567355693843626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 387}], {
             RGBColor[
             0.9858100183472391, 0.9884000921677583, 0.8848282486889909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 397}], {
             RGBColor[
             0.9626579342893277, 0.9711967708967402, 0.9268607853198898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 128}], {
             RGBColor[
             0.9739305728891926, 0.9233861062759825, 0.3635582988933778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 155}], {
             RGBColor[
             0.9568463255808421, 0.9143016456755105, 0.6189583463914821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 170}], {
             RGBColor[
             0.9747425204873523, 0.9251227800879512, 0.4519337841933236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 187}], {
             RGBColor[
             0.9736938610984669, 0.9226950287910025, 0.35350560503416606`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 202}], {
             RGBColor[
             0.9744613707624457, 0.9258528758159958, 0.5181144812140919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 261}], {
             RGBColor[
             0.9744922690464094, 0.9245875175600764, 0.42469545921956714`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 306}], {
             RGBColor[
             0.9649702317891583, 0.9203604416239972, 0.6052066922348853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 353}], {
             RGBColor[
             0.9746622300054221, 0.9249510468657156, 0.4431946607306405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 122}], {
             RGBColor[
             0.9659716338016286, 0.8915329484651303, 0.3748248806879019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 166}], {
             RGBColor[
             0.9631940185799455, 0.8923494079013927, 0.5636973403196543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 169}], {
             RGBColor[
             0.959321458557282, 0.8694096366534141, 0.32269034658305434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 197}], {
             RGBColor[
             0.9628600561222531, 0.8922113058426933, 0.5692319625107534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 221}], {
             RGBColor[
             0.9662907364628703, 0.8922154767912984, 0.40955723609071915`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 239}], {
             RGBColor[
             0.9332879655889885, 0.773216044567631, 0.26518013506143523`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 300}], {
             RGBColor[
             0.9637216042950667, 0.8925675781529299, 0.5549538796720324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 350}], {
             RGBColor[
             0.9563369314393154, 0.8877764954266472, 0.5995358004621982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 392}], {
             RGBColor[
             0.5589330611526576, 0.5505074989057622, 0.6016140942025443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 151}], {
             RGBColor[
             0.9872420723842097, 0.9878412590197287, 0.7984197133159007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 154}], {
             RGBColor[
             0.9846703069611884, 0.9871766038698779, 0.8700316846880333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 265}], {
             RGBColor[
             0.9731850925638534, 0.9795220664562787, 0.9302748232281675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 291}], {
             RGBColor[
             0.9608369201033125, 0.8960739524755584, 0.5957522630733696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 304}], {
             RGBColor[
             0.9795193779420046, 0.9632205789141175, 0.646840194927254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 383}], {
             RGBColor[
             0.9520287807448641, 0.8611526150577546, 0.5886650273919585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 289}], {
             RGBColor[
             0.9725199128640056, 0.9753037707875956, 0.699741612260492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 303}], {
             RGBColor[
             0.9883491790013614, 0.987109211554791, 0.672946793623761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 376}], {
             RGBColor[
             0.9932859594258021, 0.9880476710424497, 0.510596301633085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 158}], {
             RGBColor[
             0.9870630432243377, 0.9823762723154297, 0.6611491470257111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 164}], {
             RGBColor[
             0.9632238741733825, 0.8819246850528386, 0.3412290172779367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 173}], {
             RGBColor[
             0.9915057316024454, 0.9825114651338772, 0.46380683329300043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 209}], {
             RGBColor[
             0.9916106249353449, 0.9827358213666064, 0.47522382525249734`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 241}], {
             RGBColor[
             0.9910513667616602, 0.9840255465933522, 0.5950523045618257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 323}], {
             RGBColor[
             0.9853358207079979, 0.962196421314351, 0.3975328618588119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 346}], {
             RGBColor[
             0.981525289561954, 0.9782847264686021, 0.672247307303808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 354}], {
             RGBColor[
             0.9726646299995665, 0.9193541359582733, 0.348825271018705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 388}], {
             RGBColor[
             0.9911386357159082, 0.981726284151662, 0.42385071149664466`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 389}], {
             RGBColor[
             0.9905768307446454, 0.9838293137552973, 0.6029165944236043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 126}], {
             RGBColor[
             0.9831488281378115, 0.9867287010570491, 0.9033640678310505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 127}], {
             RGBColor[
             0.9892999659632007, 0.9879245026798249, 0.6875162787715857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 129}], {
             RGBColor[
             0.9899650126205348, 0.9893469702333313, 0.7599025032301927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 196}], {
             RGBColor[
             0.9899248721962235, 0.9892611139245486, 0.7555334657618777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 231}], {
             RGBColor[
             0.961301028468891, 0.9704346478364569, 0.9403466938517753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 235}], {
             RGBColor[
             0.9902718490166809, 0.9900032622587691, 0.7932997513759455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 317}], {
             RGBColor[
             0.9771524815137098, 0.9472906007874345, 0.6112090512783193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 326}], {
             RGBColor[
             0.9856830151153287, 0.9883475730675291, 0.8869330209155748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 327}], {
             RGBColor[
             0.9902523368618702, 0.9902371050359366, 0.8112075345497629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 336}], {
             RGBColor[
             0.9723568834469178, 0.9786800863767684, 0.9216320152027679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 396}], {
             RGBColor[
             0.9893439058658953, 0.9880184856886829, 0.6922988660142431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 132}], {
             RGBColor[
             0.9897240120728736, 0.9884344634944692, 0.7048111231023072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 160}], {
             RGBColor[
             0.9616723262116542, 0.9706351007993006, 0.9362941358091661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 187}], {
             RGBColor[
             0.9891029745489324, 0.9869213521274331, 0.6529269449660675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 202}], {
             RGBColor[
             0.9898704842129111, 0.9900791991524265, 0.8175358211459934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 206}], {
             RGBColor[
             0.9899013824968748, 0.988813840896507, 0.7241167991514686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 217}], {
             RGBColor[
             0.9660378044437063, 0.9061925656777328, 0.578554229692738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 220}], {
             RGBColor[
             0.9893239094695496, 0.9875786844825379, 0.6612624238775533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 233}], {
             RGBColor[
             0.9889926677397154, 0.9897161994819058, 0.8320835118230562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 244}], {
             RGBColor[
             0.9794893458561569, 0.9544923251593402, 0.6155798128760793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 307}], {
             RGBColor[
             0.9899013824968748, 0.988813840896507, 0.7241167991514686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 321}], {
             RGBColor[
             0.9407104243911952, 0.8032406589587079, 0.5580439740860208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 341}], {
             RGBColor[
             0.9546525270758686, 0.8610537348330327, 0.5693933682757681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 366}], {
             RGBColor[
             0.9904836538486363, 0.9900592604412608, 0.7874934424284671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 122}], {
             RGBColor[
             0.9899568939997716, 0.9881498571080399, 0.6732636001856618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 175}], {
             RGBColor[
             0.9901933490402178, 0.9902127120557654, 0.8121851154101315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 178}], {
             RGBColor[
             0.9897730628388268, 0.9877566608429608, 0.6532547127912556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.9317900590299979, 0.7608630363448303, 0.542703893883712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 274}], {
             RGBColor[
             0.9902199315287321, 0.9887124677853131, 0.7018936119335673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 296}], {
             RGBColor[
             0.990381674238862, 0.9902905893651417, 0.8090640794986059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 319}], {
             RGBColor[
             0.9888467297655852, 0.9896558503791681, 0.8345020817297635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 373}], {
             RGBColor[
             0.9908271138567515, 0.990011169389396, 0.7679816612434921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 166}], {
             RGBColor[
             0.9902265300762589, 0.9882613585549986, 0.6687950326024676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 169}], {
             RGBColor[
             0.9863539700535955, 0.9653215873070198, 0.4277880388658677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 175}], {
             RGBColor[
             0.9932406003383885, 0.9895077540664616, 0.6188440881951849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 178}], {
             RGBColor[
             0.9928203141369975, 0.987051702853657, 0.4599136855763091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 268}], {
             RGBColor[
             0.9925070464229813, 0.9892044106709651, 0.6310009749501605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 274}], {
             RGBColor[
             0.9932671828269027, 0.9880075097960093, 0.5085525847186207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 319}], {
             RGBColor[
             0.9918939810637558, 0.9889508923898642, 0.641161054514817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 351}], {
             RGBColor[
             0.9890012869918159, 0.9877546890522704, 0.6891004813391496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 131}], {
             RGBColor[
             0.9540288533543476, 0.8427483169307459, 0.49141526365980204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 140}], {
             RGBColor[
             0.9510124443369056, 0.8415009542838578, 0.5414049672951193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 203}], {
             RGBColor[
             0.9325624709687499, 0.7703397001551356, 0.2645963850604438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 232}], {
             RGBColor[
             0.9539850105396894, 0.8423416787821758, 0.46390142095079434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 275}], {
             RGBColor[
             0.9101759603558233, 0.8110905406390101, 0.619989664143344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 280}], {
             RGBColor[
             0.9412700637029925, 0.8350150332483812, 0.5928231573047142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 297}], {
             RGBColor[
             0.9434107469020214, 0.8081093748218304, 0.30061581964175554`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 309}], {
             RGBColor[
             0.9494846423571521, 0.8285980504104598, 0.32421175652602696`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 322}], {
             RGBColor[
             0.9499417827845069, 0.8410582082171941, 0.5591486000016428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 325}], {
             RGBColor[
             0.9515262827724371, 0.8417134396819955, 0.5328893346471189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 339}], {
             RGBColor[
             0.9255385185123427, 0.7424920692588851, 0.25894474804066414`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 149}], {
             RGBColor[
             0.9778462275770329, 0.9819151070622749, 0.8738756526130719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 185}], {
             RGBColor[
             0.9192929056643371, 0.7461783626796373, 0.580204474136297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 210}], {
             RGBColor[
             0.9399871592850803, 0.8370447117341335, 0.5973118332025493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 219}], {
             RGBColor[
             0.9791360140737908, 0.9807314424328679, 0.7276909977782126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 249}], {
             RGBColor[
             0.9795138672200876, 0.9815396321059834, 0.7688179809132996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 266}], {
             RGBColor[
             0.9603871654722977, 0.9179239383673736, 0.6137261570304736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 293}], {
             RGBColor[
             0.9791498506349905, 0.9807610374381832, 0.7291970220754439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 315}], {
             RGBColor[
             0.9487480198566087, 0.8717786045165219, 0.6043610272622291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 316}], {
             RGBColor[
             0.9523573574151085, 0.8860884251955317, 0.6072651849838393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 338}], {
             RGBColor[
             0.9463845348039768, 0.9593302699948327, 0.9685689107888825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 387}], {
             RGBColor[
             0.9747771784055497, 0.9806459763589004, 0.9247377398292043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 397}], {
             RGBColor[
             0.9516250943476381, 0.9634426550878824, 0.966770276460103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 148}], {
             RGBColor[
             0.9616095168390173, 0.9705622157052938, 0.9352342432164729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 162}], {
             RGBColor[
             0.9874868121785708, 0.9890934895086498, 0.857039435500493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 211}], {
             RGBColor[
             0.9878145912316734, 0.9892290345706451, 0.8516072883255867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 214}], {
             RGBColor[
             0.9479902861401925, 0.9597377057875347, 0.9351519930354969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 248}], {
             RGBColor[
             0.9720340218992705, 0.97833679451067, 0.9175882752958257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 263}], {
             RGBColor[
             0.9635727261964775, 0.8961410301511055, 0.5752088258718521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 276}], {
             RGBColor[
             0.9907007946671432, 0.9903884760701456, 0.8012983323290686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 288}], {
             RGBColor[
             0.9829583363522822, 0.9864841303428031, 0.8990962604444053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 196}], {
             RGBColor[
             0.9875315858010645, 0.9877005079258536, 0.7696294253886586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 289}], {
             RGBColor[
             0.9666060148046283, 0.9746154010356998, 0.9414114857762415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 317}], {
             RGBColor[
             0.9747591951185508, 0.9457299947887396, 0.6253050109051003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 326}], {
             RGBColor[
             0.9832897287201697, 0.9867869670688341, 0.9010289805423559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 327}], {
             RGBColor[
             0.9878590504667112, 0.9886764990372416, 0.8253034941765439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 336}], {
             RGBColor[
             0.9699635970517588, 0.9771194803780734, 0.935727974829549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 376}], {
             RGBColor[
             0.9873720613664249, 0.9873593012905539, 0.7522661751488344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 129}], {
             RGBColor[
             0.9937228640507652, 0.9889821658574119, 0.5581506737975089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 216}], {
             RGBColor[
             0.9931186634075304, 0.9876898417755887, 0.492387162475562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 231}], {
             RGBColor[
             0.9650588798991212, 0.9700698434605377, 0.7385948644190916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 235}], {
             RGBColor[
             0.9940297004469111, 0.9896384578828498, 0.5915479219432618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 298}], {
             RGBColor[
             0.9906051795882918, 0.9884642420562602, 0.6658855112192413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 313}], {
             RGBColor[
             0.9921946001163285, 0.9849902792559119, 0.45329446895531555`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 317}], {
             RGBColor[
             0.9809103329439401, 0.9469257964115152, 0.40945722184563554`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 336}], {
             RGBColor[
             0.9761147348771482, 0.978315282000849, 0.7198801857700842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 361}], {
             RGBColor[
             0.9934291208480293, 0.9883538788487536, 0.5261785389526288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 393}], {
             RGBColor[
             0.9764739871718116, 0.9785832117739874, 0.7192720653432236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 396}], {
             RGBColor[
             0.9931017572961255, 0.9876536813127637, 0.4905470365815593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 133}], {
             RGBColor[
             0.9888621097472654, 0.9874149394183003, 0.6708943188898275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 155}], {
             RGBColor[
             0.9755927846798436, 0.9776607762249419, 0.6997183554120812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 170}], {
             RGBColor[
             0.9934889795863537, 0.9884819106373826, 0.5326937932139227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 171}], {
             RGBColor[
             0.9856365509955622, 0.9631034482214264, 0.4078342554893639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 199}], {
             RGBColor[
             0.936697738696854, 0.7689986904871373, 0.33324959685646727`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 261}], {
             RGBColor[
             0.9932387281454108, 0.9879466481095077, 0.5054554682401663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 299}], {
             RGBColor[
             0.9934065289895386, 0.9883055571478292, 0.5237195545767015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 306}], {
             RGBColor[
             0.9837166908881597, 0.9837195721734285, 0.6859667012554844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 342}], {
             RGBColor[
             0.993108858227189, 0.9876688694862941, 0.4913199291059522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 353}], {
             RGBColor[
             0.9934086891044235, 0.9883101774151468, 0.5239546697512396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 216}], {
             RGBColor[
             0.9937837100648647, 0.9891123093290951, 0.5647733869341689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 231}], {
             RGBColor[
             0.9657239265564554, 0.9714923110140441, 0.8109810888776985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 235}], {
             RGBColor[
             0.9946947471042453, 0.9910609254363562, 0.6639341464018688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 298}], {
             RGBColor[
             0.991270226245626, 0.9898867096097665, 0.7382717356778483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 313}], {
             RGBColor[
             0.9928596467736628, 0.9864127468094183, 0.5256806934139225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 317}], {
             RGBColor[
             0.9815753796012743, 0.9483482639650216, 0.4818434463042425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 336}], {
             RGBColor[
             0.9767797815344823, 0.9797377495543554, 0.7922664102286912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 361}], {
             RGBColor[
             0.9940941675053634, 0.98977634640226, 0.5985647634112358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 393}], {
             RGBColor[
             0.9771390338291457, 0.9800056793274938, 0.7916582898018306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 396}], {
             RGBColor[
             0.9937668039534597, 0.98907614886627, 0.5629332610401663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 147}], {
             RGBColor[
             0.942923218507999, 0.795351828124439, 0.424573821556228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 164}], {
             RGBColor[
             0.9655086471849139, 0.8885400621015732, 0.4429351156588688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 287}], {
             RGBColor[
             0.9942215143353431, 0.9900487283948469, 0.6124256799609836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 371}], {
             RGBColor[
             0.9943697178788387, 0.9903657207887069, 0.6285567210642176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 391}], {
             RGBColor[
             0.9920843168087927, 0.9838689844751941, 0.516579681538158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 140}], {
             RGBColor[
             0.9919029299608099, 0.990919667700656, 0.7838529353023218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 186}], {
             RGBColor[
             0.9889992348804761, 0.9733755533239372, 0.5613146396530847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 188}], {
             RGBColor[
             0.9915539659773964, 0.9907753621255491, 0.7896361715973239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 203}], {
             RGBColor[
             0.9734529565926542, 0.9197584135719338, 0.5070443530676463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 228}], {
             RGBColor[
             0.9948316404943393, 0.991666589356927, 0.7015759700054693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 238}], {
             RGBColor[
             0.8249289474376001, 0.861264637511203, 0.8500525221180893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 273}], {
             RGBColor[
             0.969786202014179, 0.905220953541809, 0.504093996264013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 280}], {
             RGBColor[
             0.9821605493268968, 0.9844337466651794, 0.8352711253119166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 309}], {
             RGBColor[
             0.9903751279810564, 0.9780167638272579, 0.5666597245332294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 322}], {
             RGBColor[
             0.9908322684084112, 0.9904769216339923, 0.8015965680088453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 325}], {
             RGBColor[
             0.9924167683963414, 0.9911321530987937, 0.7753373026543212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 330}], {
             RGBColor[
             0.9933599205045975, 0.9880851698717743, 0.5782550798564146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 339}], {
             RGBColor[
             0.966429004136247, 0.8919107826756832, 0.5013927160478666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 160}], {
             RGBColor[
             0.9653939975934058, 0.9705899418943573, 0.7594642891748917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 202}], {
             RGBColor[
             0.9935921555946627, 0.9900340402474832, 0.640705974511719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 220}], {
             RGBColor[
             0.9930455808513013, 0.9875335255775946, 0.48443257724327876`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 244}], {
             RGBColor[
             0.9832110172379085, 0.9544471662543967, 0.43874996624180485`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 260}], {
             RGBColor[
             0.8571388887610667, 0.8851140410463338, 0.750395370555962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 307}], {
             RGBColor[
             0.9936230538786264, 0.9887686819915638, 0.5472869525171942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 321}], {
             RGBColor[
             0.9444320957729468, 0.8031955000537645, 0.3812141274517464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 341}], {
             RGBColor[
             0.9583741984576203, 0.8610085759280894, 0.39256352164149366`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 348}], {
             RGBColor[
             0.9895915436304367, 0.9883796843892378, 0.7070064680108267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 366}], {
             RGBColor[
             0.994205325230388, 0.9900141015363174, 0.6106635957941926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 155}], {
             RGBColor[
             0.9717778624389148, 0.9783304788178283, 0.9262943663879317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 199}], {
             RGBColor[
             0.9328828164559254, 0.7696683930800238, 0.5598256078323178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 216}], {
             RGBColor[
             0.9891133484639834, 0.9879523136292293, 0.69824010273895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 298}], {
             RGBColor[
             0.9865998646447447, 0.9887267139099007, 0.8717384514826294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 299}], {
             RGBColor[
             0.9895916067486099, 0.9889752597407157, 0.7502955655525521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 306}], {
             RGBColor[
             0.9799017686472311, 0.984389274766315, 0.912542712231335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 342}], {
             RGBColor[
             0.9892939359862604, 0.9883385720791806, 0.7178959400818028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 361}], {
             RGBColor[
             0.9894238059044822, 0.9886163507023942, 0.7320314792160169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 393}], {
             RGBColor[
             0.9724686722282645, 0.978845683627628, 0.9251250056066117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 135}], {
             RGBColor[
             0.9905267070074628, 0.9902715449885053, 0.8009166528901748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 226}], {
             RGBColor[
             0.9525059422065625, 0.9615260264644212, 0.8545720275725128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 234}], {
             RGBColor[
             0.9432270562503684, 0.9541272946716017, 0.8536869991466518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 239}], {
             RGBColor[
             0.9614136061393123, 0.8714660877354641, 0.4892581788627392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 246}], {
             RGBColor[
             0.9894171329885786, 0.98972164207514, 0.8152270648487633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 269}], {
             RGBColor[
             0.9904924059449214, 0.9902573606176472, 0.8014851102647904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 272}], {
             RGBColor[
             0.98856296950315, 0.9890846083462718, 0.8166729408280776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 350}], {
             RGBColor[
             0.9844625719896392, 0.9860265385944802, 0.8236138442635023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 355}], {
             RGBColor[
             0.9944120552523643, 0.9904562761497133, 0.6331648828965024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 392}], {
             RGBColor[
             0.5870587017029814, 0.6487575420735953, 0.8256921380038482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 395}], {
             RGBColor[
             0.9647182285955744, 0.9712637721373363, 0.8557368463503336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 156}], {
             RGBColor[
             0.9899964102901656, 0.9891372939314294, 0.7431971278243646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 165}], {
             RGBColor[
             0.9870521908734102, 0.9802097654998865, 0.6463852031921565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 221}], {
             RGBColor[
             0.9897526806146941, 0.9886159808004462, 0.7166686567745014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 234}], {
             RGBColor[
             0.9385633598518685, 0.9522777555129164, 0.93672037602913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 255}], {
             RGBColor[
             0.9401298045018647, 0.8008917240445406, 0.5587721508540265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 281}], {
             RGBColor[
             0.9876665508995432, 0.9891678160888463, 0.854060699745081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 328}], {
             RGBColor[
             0.9900674475262325, 0.98928923539641, 0.7509290925792425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 355}], {
             RGBColor[
             0.9897483588538643, 0.988606736991028, 0.7161982597789808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 386}], {
             RGBColor[
             0.9880942916984794, 0.9893446979016436, 0.8469719277490058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 400}], {
             RGBColor[
             0.97615072577003, 0.9434365639204545, 0.6040350698344683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 331}], {
             RGBColor[
             0.9796397932076903, 0.9841506684377247, 0.9110504432432772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 335}], {
             RGBColor[
             0.9841659635206876, 0.9852267079938193, 0.7782048639996697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 394}], {
             RGBColor[
             0.9828863600971385, 0.9820562064177879, 0.6757946764746535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 169}], {
             RGBColor[
             0.9674198333769405, 0.9546296313833267, 0.6682404752534291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 175}], {
             RGBColor[
             0.9743064636617333, 0.9788157981427685, 0.8592965245827464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 178}], {
             RGBColor[
             0.9738861774603425, 0.9763597469299639, 0.7003661219638705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 197}], {
             RGBColor[
             0.9709584309419116, 0.977431300572606, 0.9147820911811282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 252}], {
             RGBColor[
             0.9703880315002049, 0.9771954257448632, 0.9242350860766437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 278}], {
             RGBColor[
             0.9474387010741951, 0.9603204498391384, 0.9738567482858065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 282}], {
             RGBColor[
             0.9307429854302678, 0.8162386834960667, 0.6021663704845553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 300}], {
             RGBColor[
             0.9718199791147252, 0.9777875728828425, 0.9005040083424071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 314}], {
             RGBColor[
             0.9739567244399433, 0.9786711719866703, 0.8650926085839008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 319}], {
             RGBColor[
             0.9729598443871008, 0.9782589364661711, 0.8816134909023784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 352}], {
             RGBColor[
             0.9597956140933492, 0.9289113494879548, 0.6386218230496783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 159}], {
             RGBColor[
             0.990971263755227, 0.9903990031649317, 0.7894511506681212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 215}], {
             RGBColor[
             0.98709503329956, 0.9879443036473551, 0.8155459342587128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 218}], {
             RGBColor[
             0.9846974817774692, 0.9861562136478099, 0.8196043636040278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 229}], {
             RGBColor[
             0.9886859556786023, 0.9718789664989196, 0.5481515239098038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 329}], {
             RGBColor[
             0.9940341820016924, 0.9916655985732536, 0.7386906687458608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 349}], {
             RGBColor[
             0.966092497386937, 0.9722806467522171, 0.8510977492201212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 193}], {
             RGBColor[
             0.8763770045259078, 0.8609152886172413, 0.644707407182665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 204}], {
             RGBColor[
             0.878731959802713, 0.9055646946232885, 0.9598539751870072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 224}], {
             RGBColor[
             0.8919196025668412, 0.9125350212858321, 0.7738874977934583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 276}], {
             RGBColor[
             0.8926338573501762, 0.9140627400451498, 0.8516297230899124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 290}], {
             RGBColor[
             0.8287098057922944, 0.6633218568317504, 0.595384479973972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 318}], {
             RGBColor[
             0.8877535315333025, 0.912078677694331, 0.9349864475695884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 203}], {
             RGBColor[
             0.9704365475752121, 0.9185110509250456, 0.5570340567029636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 232}], {
             RGBColor[
             0.9918590871461517, 0.9905130295520859, 0.7563390925933142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 257}], {
             RGBColor[
             0.9915047798755849, 0.9897552021263036, 0.7177749327231429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 275}], {
             RGBColor[
             0.9480500369622855, 0.9592618914089202, 0.9124273357858638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 280}], {
             RGBColor[
             0.9791441403094547, 0.9831863840182913, 0.8852608289472339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 288}], {
             RGBColor[
             0.9843220511873547, 0.9870480614729782, 0.8764959764463925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 297}], {
             RGBColor[
             0.9812848235084837, 0.9562807255917404, 0.5930534912842753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 309}], {
             RGBColor[
             0.9873587189636144, 0.9767694011803698, 0.6166494281685468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 322}], {
             RGBColor[
             0.9878158593909692, 0.9892295589871041, 0.8515862716441627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 325}], {
             RGBColor[
             0.9894003593788994, 0.9898847904519055, 0.8253270062896385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 339}], {
             RGBColor[
             0.963412595118805, 0.8906634200287951, 0.551382419683184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 172}], {
             RGBColor[
             0.9900786460456896, 0.9895233521764806, 0.7674247068107826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[
             0.990327234249532, 0.9900550572083764, 0.7944819986904521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 243}], {
             RGBColor[
             0.9899835900351308, 0.9901259713166015, 0.8156613649633271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 279}], {
             RGBColor[
             0.9795512408886047, 0.9552678161801296, 0.6197373040685882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 285}], {
             RGBColor[
             0.9250486676997325, 0.7329145351090787, 0.5483083942287696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 337}], {
             RGBColor[
             0.9898940073345698, 0.9891284286432325, 0.7473279225634262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 399}], {
             RGBColor[
             0.9877501783036269, 0.9892023981695612, 0.8526747772386292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 143}], {
             RGBColor[
             0.9435079084905558, 0.8129612356802007, 0.5478007953323852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 258}], {
             RGBColor[
             0.9296779601443776, 0.7564306792732252, 0.268096186179219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 277}], {
             RGBColor[
             0.9315716539667471, 0.7628185531965312, 0.2754528290850525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 302}], {
             RGBColor[
             0.9367192597877048, 0.7801826363459458, 0.2954503056556811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 377}], {
             RGBColor[
             0.9471079485894989, 0.8139025912507387, 0.4483519910189653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 378}], {
             RGBColor[
             0.9296258254194992, 0.7562548166043944, 0.2678936526178827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 379}], {
             RGBColor[
             0.9467184535858907, 0.8130695008220064, 0.4059578635607435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 258}], {
             RGBColor[
             0.9736174959329199, 0.9325466534635333, 0.5779872543224486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 277}], {
             RGBColor[
             0.9755111897552893, 0.9389345273868394, 0.5853438972282821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 302}], {
             RGBColor[
             0.980658795576247, 0.9562986105362539, 0.6053413737989107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 377}], {
             RGBColor[
             0.9910474843780411, 0.9900185654410469, 0.7582430591621949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 378}], {
             RGBColor[
             0.9735653612080415, 0.9323707907947025, 0.5777847207611124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 379}], {
             RGBColor[
             0.990657989374433, 0.9891854750123146, 0.7158489317039731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 186}], {
             RGBColor[
             0.9558063629999209, 0.8544753133217984, 0.3250603523499981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 188}], {
             RGBColor[
             0.9583610940968412, 0.8718751221234102, 0.5533818842942373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 200}], {
             RGBColor[
             0.944292669540854, 0.8620468934217509, 0.606930406955479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 228}], {
             RGBColor[
             0.9616387686137842, 0.8727663493547881, 0.4653216827023828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 333}], {
             RGBColor[
             0.9171886357464332, 0.7093875665255412, 0.2522262363702745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 368}], {
             RGBColor[
             0.9444772909091057, 0.8621845837359032, 0.6066178911359935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 200}], {
             RGBColor[
             0.9491429579066629, 0.8812766705293982, 0.6108330628255093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 207}], {
             RGBColor[
             0.9657767613112802, 0.8904725980520538, 0.3916953508558833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 222}], {
             RGBColor[
             0.9392875300874339, 0.7970023185676143, 0.27000752548476303`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 254}], {
             RGBColor[
             0.9602706825796156, 0.8895757093705094, 0.5919967275296112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 333}], {
             RGBColor[
             0.9220389241122421, 0.7286173436331886, 0.2561288922403049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 227}], {
             RGBColor[
             0.8880417548566306, 0.910300537365546, 0.8371700488944448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 302}], {
             RGBColor[
             0.9844275617449599, 0.9576008541092069, 0.5242573609233323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 375}], {
             RGBColor[
             0.9777405340875523, 0.935043939632011, 0.4982795212135168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 377}], {
             RGBColor[0.994816250546754, 0.991320809014, 0.6771590462866165]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 344}], {
             RGBColor[
             0.8902698415916347, 0.5946228034447788, 0.2301508049028011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 354}], {
             RGBColor[
             0.9236007370755948, 0.7311648761684468, 0.2571970355700334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 371}], {
             RGBColor[
             0.9430210519433354, 0.7955610839501459, 0.4352223872346138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 388}], {
             RGBColor[
             0.9420747427919365, 0.7935370243618354, 0.33222247604797306`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 391}], {
             RGBColor[
             0.9407356508732896, 0.789064347636633, 0.32324534770855434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 179}], {
             RGBColor[
             0.9634870701096212, 0.9713386322336066, 0.9041183265704595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 232}], {
             RGBColor[
             0.9659457978768735, 0.9719668713337868, 0.835130412874135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 257}], {
             RGBColor[
             0.9655914906063068, 0.9712090439080048, 0.7965662530039638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 275}], {
             RGBColor[
             0.9221367476930074, 0.9407157331906212, 0.9912186560666847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 276}], {
             RGBColor[
             0.9661512202329374, 0.9724062489820218, 0.8574893686118767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 279}], {
             RGBColor[
             0.9552715147994518, 0.9373971783174713, 0.6714562549287398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 288}], {
             RGBColor[
             0.9584087619180766, 0.9685019032546793, 0.9552872967272135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 195}], {
             RGBColor[
             0.987989804695352, 0.9893014898406569, 0.8487035477945224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 210}], {
             RGBColor[
             0.9528530362659331, 0.8455568354655885, 0.5270241745756079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 247}], {
             RGBColor[
             0.9891125144678163, 0.989765759183896, 0.8300973413850338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 249}], {
             RGBColor[
             0.9923797442009404, 0.9900517558374384, 0.6985303222863581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 253}], {
             RGBColor[
             0.9869780088551316, 0.9727835783598613, 0.5964970950074764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 266}], {
             RGBColor[
             0.9732530424531506, 0.9264360620988287, 0.5434384984035322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 315}], {
             RGBColor[
             0.9616138968374617, 0.8802907282479769, 0.5340733686352876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 316}], {
             RGBColor[
             0.9652232343959615, 0.8946005489269867, 0.5369775263568979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 358}], {
             RGBColor[
             0.9917844016361729, 0.9887783782897672, 0.6337309581398327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 359}], {
             RGBColor[
             0.9780296788991282, 0.9820519247579196, 0.8735651173765322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 362}], {
             RGBColor[
             0.9916869275717551, 0.9885698911221172, 0.6231215077681567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 363}], {
             RGBColor[
             0.9914478787682877, 0.9878614991523019, 0.6138616955559822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 369}], {
             RGBColor[
             0.9571672076216915, 0.966181303273672, 0.8980825542891626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 397}], {
             RGBColor[
             0.9644909713284909, 0.9719547788193375, 0.8964826178331616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 192}], {
             RGBColor[
             0.9804692008665017, 0.9830912719975443, 0.8337841009620729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 283}], {
             RGBColor[
             0.9949967983823922, 0.9917069825782436, 0.6968105639837456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 294}], {
             RGBColor[
             0.9594372112787743, 0.9670942240350427, 0.8585884881565691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 320}], {
             RGBColor[
             0.9935263069514974, 0.9881281908562379, 0.573623394883384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 347}], {
             RGBColor[
             0.9949968609642248, 0.9921733035937019, 0.7307042607853849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 380}], {
             RGBColor[
             0.9951792680270931, 0.9922487336018457, 0.7276813036993109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 381}], {
             RGBColor[
             0.9948379812750275, 0.9913672888444633, 0.6795243019526827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 384}], {
             RGBColor[
             0.9940261895325311, 0.9896309483919987, 0.5911657805798423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 168}], {
             RGBColor[
             0.9830808876478988, 0.9847378542567027, 0.8054635136636791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 265}], {
             RGBColor[
             0.9807627017116862, 0.9830089549811565, 0.8093875977739619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 291}], {
             RGBColor[
             0.9684145292511452, 0.8995608410004361, 0.474865037619164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 304}], {
             RGBColor[
             0.9870969870898374, 0.9667074674389953, 0.5259529694730485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 378}], {
             RGBColor[
             0.9772514798345138, 0.9334962596317513, 0.48770503295415246`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 383}], {
             RGBColor[
             0.959606389892697, 0.8646395035826324, 0.4677778019377528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 154}], {
             RGBColor[
             0.9690349050141809, 0.9115519619353092, 0.5490454807187819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 180}], {
             RGBColor[
             0.9615273375004567, 0.9068639470547079, 0.6025555006214205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 198}], {
             RGBColor[
             0.9700513980097858, 0.9119723079116702, 0.5321995611820629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 236}], {
             RGBColor[
             0.9558647398932264, 0.9026407910308881, 0.6121408013284733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 267}], {
             RGBColor[
             0.9716324336917046, 0.912271722081476, 0.48023768060685756`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 284}], {
             RGBColor[
             0.9596689623989767, 0.8733777063879156, 0.3094794590759915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 332}], {
             RGBColor[
             0.9426940161440315, 0.8105079006378374, 0.272748464126406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 367}], {
             RGBColor[
             0.9577689497792794, 0.9040609476460489, 0.6089174706888645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 383}], {
             RGBColor[
             0.9363933787978567, 0.7855279731231859, 0.2676788234227071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 398}], {
             RGBColor[
             0.9502043529715037, 0.8984192837327003, 0.6217223599216006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 161}], {
             RGBColor[
             0.9816195675395895, 0.9487054586788345, 0.464316519068814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 184}], {
             RGBColor[
             0.9496249735979138, 0.8340758539386172, 0.2986937432018868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[
             0.9795789555255787, 0.9489238710082601, 0.5753496721747666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 372}], {
             RGBColor[
             0.9814726874860641, 0.9483912970961952, 0.4483295316811984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 180}], {
             RGBColor[
             0.9821685831722756, 0.9853108223643036, 0.8742664505085989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 236}], {
             RGBColor[
             0.9765059855650453, 0.9810876663404838, 0.8838517512156516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 267}], {
             RGBColor[
             0.9922736793635236, 0.9907185973910717, 0.7519486304940359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 286}], {
             RGBColor[
             0.9664862171603437, 0.9014472638947245, 0.5469947466461915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 291}], {
             RGBColor[
             0.9658427638281238, 0.8988961858505854, 0.5464770089912966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 332}], {
             RGBColor[
             0.9633352618158504, 0.8889547759474331, 0.5444594140135843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 383}], {
             RGBColor[
             0.9570346244696755, 0.8639748484327816, 0.5393897733098854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 170}], {
             RGBColor[
             0.9764047322780032, 0.9793974500369106, 0.788093840712027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 171}], {
             RGBColor[
             0.9685523036872118, 0.9540189876209544, 0.6632343029874682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 199}], {
             RGBColor[
             0.9196134913885036, 0.7599142298866653, 0.5886496443545715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 261}], {
             RGBColor[
             0.9761544808370604, 0.9788621875090358, 0.7608555157382706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.9763222816811881, 0.9792210965473572, 0.7791196020748057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 306}], {
             RGBColor[
             0.9666324435798093, 0.9746351115729566, 0.9413667487535887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 342}], {
             RGBColor[
             0.9760246109188385, 0.9785844088858222, 0.7467199766040564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 353}], {
             RGBColor[
             0.976324441796073, 0.979225716814675, 0.7793547172493439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 361}], {
             RGBColor[
             0.9761544808370604, 0.9788621875090358, 0.7608555157382706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 165}], {
             RGBColor[
             0.9911855905546132, 0.9809250536014957, 0.505632301243868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 221}], {
             RGBColor[
             0.9938860802958971, 0.9893312689020555, 0.5759157548262129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 245}], {
             RGBColor[
             0.956557530898584, 0.9640452464607696, 0.7972895268273409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 255}], {
             RGBColor[
             0.9442632041830674, 0.8016070121461499, 0.41801924890573805`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 328}], {
             RGBColor[
             0.9942008472074353, 0.9900045234980194, 0.610176190630954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 364}], {
             RGBColor[
             0.993584971530387, 0.9886872276993957, 0.5431419239283453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 386}], {
             RGBColor[
             0.9922276913796821, 0.9900599860032528, 0.7062190258007173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 400}], {
             RGBColor[
             0.9802841254512329, 0.9441518520220639, 0.4632821678861798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 181}], {
             RGBColor[
             0.9788214319584374, 0.948854052773549, 0.5895864271364393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 191}], {
             RGBColor[
             0.9809899875063759, 0.9474603752590366, 0.38715769767936015`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 334}], {
             RGBColor[
             0.9534955199774969, 0.9306468376904564, 0.6629445903661735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 365}], {
             RGBColor[
             0.9758300829866104, 0.9473039182131628, 0.6251380009787135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 370}], {
             RGBColor[
             0.9726379630916826, 0.9193635659757691, 0.34820408280863235`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 209}], {
             RGBColor[
             0.9889713297392433, 0.9881863828165052, 0.7218770136542411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 241}], {
             RGBColor[
             0.9884120715655585, 0.9894761080432508, 0.8417054929635694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 270}], {
             RGBColor[
             0.9795900489081808, 0.9842603706433858, 0.9177087150122234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 310}], {
             RGBColor[
             0.9774461096448852, 0.9499360971885508, 0.6237891760750582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 323}], {
             RGBColor[
             0.9826965255118962, 0.9676469827642498, 0.6441860502605556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 324}], {
             RGBColor[
             0.9631922669205726, 0.9720309316859315, 0.9454658826907502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 346}], {
             RGBColor[
             0.9788859943658523, 0.9837352879185007, 0.9189004957055518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 390}], {
             RGBColor[
             0.9897130649010484, 0.9897728793266777, 0.8026103085579179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 215}], {
             RGBColor[
             0.9829412446857245, 0.9863620019250223, 0.8942268659858728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 218}], {
             RGBColor[
             0.9805436931636335, 0.9845739119254772, 0.8982852953311877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 329}], {
             RGBColor[
             0.9898803933878568, 0.9900832968509208, 0.8173716004730207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 349}], {
             RGBColor[
             0.9619387087731015, 0.9706983450298843, 0.929778680947281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 217}], {
             RGBColor[
             0.9417077899642385, 0.8883480440776209, 0.6332073957653224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 220}], {
             RGBColor[
             0.964993894990082, 0.9697341628824261, 0.7159155899501377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 233}], {
             RGBColor[
             0.9646626532602478, 0.971871677881794, 0.8867366778956407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 244}], {
             RGBColor[
             0.9551593313766891, 0.9366478035592283, 0.6702329789486637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 263}], {
             RGBColor[
             0.9391643364259592, 0.8782640983539911, 0.6311608733458951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 264}], {
             RGBColor[
             0.9614329642681384, 0.9705361184843355, 0.9402609826620759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 307}], {
             RGBColor[
             0.9655713680174071, 0.9709693192963952, 0.7787699652240532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 312}], {
             RGBColor[
             0.966123188849544, 0.9721496082586916, 0.8388322573587311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 321}], {
             RGBColor[
             0.9163804099117274, 0.785396137358596, 0.6126971401586053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 341}], {
             RGBColor[
             0.930322512596401, 0.8432092132329209, 0.6240465343483526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 348}], {
             RGBColor[
             0.9615398577692174, 0.9705803216940694, 0.9384894807176856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 366}], {
             RGBColor[
             0.9661536393691686, 0.9722147388411488, 0.8421466085010516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 176}], {
             RGBColor[
             0.9945194105438967, 0.9906858982630162, 0.6448498438597474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 184}], {
             RGBColor[
             0.9620560691540736, 0.8750536901288484, 0.42820680103589476`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 195}], {
             RGBColor[
             0.9896590839642838, 0.9889295218783247, 0.7438243392528682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 250}], {
             RGBColor[
             0.9935670003689642, 0.9905455457405308, 0.6790600510638507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 344}], {
             RGBColor[
             0.9415078968532614, 0.7891908552363727, 0.41144584949089996`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.9920100510817385, 0.9899017071984914, 0.7048627300087746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 363}], {
             RGBColor[
             0.9931171580372196, 0.9874895311899698, 0.508982487014328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 372}], {
             RGBColor[
             0.9939037830422239, 0.9893691332864264, 0.5778425895152064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 191}], {
             RGBColor[
             0.9907207676669607, 0.9881403822490437, 0.6369542718634724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 211}], {
             RGBColor[
             0.9891423121370211, 0.9897780812858773, 0.8296035168924151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 214}], {
             RGBColor[
             0.9493180070455404, 0.9602867525027668, 0.9131482216023252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 248}], {
             RGBColor[
             0.9733617428046183, 0.9788858412259023, 0.895584503862654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 263}], {
             RGBColor[
             0.9649004471018253, 0.8966900768663377, 0.5532050544386804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 312}], {
             RGBColor[
             0.9918592995254101, 0.9905755867710382, 0.7608764384515165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 340}], {
             RGBColor[
             0.9824347571313514, 0.9602662532807227, 0.5982571084473112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 348}], {
             RGBColor[
             0.9872759684450834, 0.989006300206416, 0.860533661810471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 167}], {
             RGBColor[
             0.9827956640048978, 0.9843228218862063, 0.7898936481356927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 174}], {
             RGBColor[
             0.9785568087433529, 0.983219349593106, 0.9073472134429267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.9822015075310206, 0.9830519812670175, 0.7252233826628796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 222}], {
             RGBColor[
             0.9557014923672009, 0.8895586360253983, 0.6023617919764068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 226}], {
             RGBColor[
             0.9404417887577277, 0.9544348541278904, 0.9625646404607544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 395}], {
             RGBColor[
             0.9526540751467398, 0.9641725998008055, 0.9637294592385752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 287}], {
             RGBColor[
             0.9654582770767548, 0.8884323255334199, 0.43745264023402075`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 292}], {
             RGBColor[
             0.9606597080706224, 0.8874063143135636, 0.5866371221751505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 354}], {
             RGBColor[
             0.9461861657525097, 0.824353110145581, 0.27555832967267424`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 371}], {
             RGBColor[
             0.9656064806202502, 0.8887493179272801, 0.45358368133725463`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 374}], {
             RGBColor[
             0.9632500717197586, 0.8820130555282419, 0.34133078979861664`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 388}], {
             RGBColor[
             0.9646601714688514, 0.8867252583389695, 0.3505837701506138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 389}], {
             RGBColor[
             0.9640983664975886, 0.8888282879426048, 0.5296496530775736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 391}], {
             RGBColor[
             0.9633210795502045, 0.8822525816137672, 0.34160664181119516`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 182}], {
             RGBColor[
             0.9199769139380338, 0.6852438524843385, 0.3029867948130116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 256}], {
             RGBColor[
             0.9908138531281026, 0.9801299448346088, 0.4651709764656563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 281}], {
             RGBColor[
             0.9888557311639907, 0.9809555757589128, 0.6164958731645844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 311}], {
             RGBColor[
             0.968289939803332, 0.9664945249453465, 0.6905769928428722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 328}], {
             RGBColor[
             0.99125662779068, 0.9810769950664766, 0.5133642659987459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 386}], {
             RGBColor[
             0.9892834719629269, 0.98113245757171, 0.6094071011685092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 400}], {
             RGBColor[
             0.9773399060344776, 0.9352243235905211, 0.3664702432539717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 169}], {
             RGBColor[
             0.9835763548319123, 0.9661380467432823, 0.6166604984976202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 178}], {
             RGBColor[
             0.9900426989153144, 0.9878681622899195, 0.6487861452080615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 197}], {
             RGBColor[
             0.9871149523968834, 0.9889397159325616, 0.8632021144253191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.9575428618636188, 0.8699444546574993, 0.559150286976001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 300}], {
             RGBColor[
             0.987976500569697, 0.9892959882427981, 0.848924031586598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 319}], {
             RGBColor[
             0.9891163658420727, 0.9897673518261267, 0.8300335141465693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 174}], {
             RGBColor[
             0.9902903762399575, 0.9896034320051833, 0.7633723597944396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 183}], {
             RGBColor[
             0.9941244533605086, 0.9911889214258187, 0.6998317796333859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 189}], {
             RGBColor[
             0.9939350750276252, 0.9894360636790949, 0.5812485290143925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 222}], {
             RGBColor[
             0.9674350598638055, 0.8959427184374756, 0.4583869383279198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 238}], {
             RGBColor[
             0.8247338936992255, 0.8605345744865728, 0.8060803035281899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 246}], {
             RGBColor[
             0.9890865470363484, 0.9890145521506866, 0.7792448240885179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 269}], {
             RGBColor[
             0.9901618199926912, 0.9895502706931938, 0.765502869504545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 272}], {
             RGBColor[
             0.9882323835509199, 0.9883775184218183, 0.7806907000678323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 309}], {
             RGBColor[
             0.9901800742426817, 0.9772867008026278, 0.52268750594333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 395}], {
             RGBColor[
             0.9643876426433443, 0.9705566822128828, 0.8197546055900882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 265}], {
             RGBColor[
             0.9690239078275424, 0.9764186616932528, 0.9373186235759459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 304}], {
             RGBColor[
             0.9753581932056936, 0.9601171741510914, 0.6538839952750324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 378}], {
             RGBColor[
             0.96551268595037, 0.9269059663438476, 0.6156360587561365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 177}], {
             RGBColor[
             0.9687896160844369, 0.9063821878854822, 0.33325398138483564`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 178}], {
             RGBColor[
             0.9861701388926508, 0.9649283910419406, 0.40777915147146154`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 197}], {
             RGBColor[
             0.98324239237422, 0.9659999446845828, 0.6221951206887192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 239}], {
             RGBColor[
             0.9536703018409554, 0.8470046834095205, 0.31814329323940105`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 300}], {
             RGBColor[
             0.9841039405470335, 0.9663562169948193, 0.6079170378499981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 319}], {
             RGBColor[
             0.9852438058194092, 0.966827580578148, 0.5890265204099694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 171}], {
             RGBColor[
             0.986448498593722, 0.9648401220333951, 0.4962097407893097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 187}], {
             RGBColor[
             0.993252267795628, 0.9877908331524026, 0.522641099354711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 261}], {
             RGBColor[
             0.9940506757435705, 0.9896833219214765, 0.5938309535401121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 299}], {
             RGBColor[
             0.9942184765876982, 0.9900422309597979, 0.6120950398766473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 306}], {
             RGBColor[
             0.9845286384863194, 0.9854562459853973, 0.7743421865554303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 353}], {
             RGBColor[
             0.9942206367025832, 0.9900468512271157, 0.6123301550511855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 361}], {
             RGBColor[
             0.9940506757435705, 0.9896833219214765, 0.5938309535401121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 299}], {
             RGBColor[
             0.9863660479969069, 0.9646637685438417, 0.48723550215208844`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 306}], {
             RGBColor[
             0.976676209895528, 0.9600777835694411, 0.6494826488308714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 342}], {
             RGBColor[
             0.9860683772345573, 0.9640270808823066, 0.4548358766813392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 353}], {
             RGBColor[
             0.9863682081117917, 0.9646683888111593, 0.48747061732662667`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 208}], {
             RGBColor[
             0.9465833371632358, 0.8116521080201042, 0.44199387059734724`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 225}], {
             RGBColor[
             0.9454928151346311, 0.8067003021861008, 0.44108391228553845`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 240}], {
             RGBColor[
             0.9947864857121043, 0.9912571450423705, 0.673919327722257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 243}], {
             RGBColor[
             0.9944428414977031, 0.9913280591505955, 0.6950986939951319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 285}], {
             RGBColor[
             0.9295079191623048, 0.7341166229430728, 0.4277457232605745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 337}], {
             RGBColor[
             0.9943532587971421, 0.9903305164772266, 0.6267652515952311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 357}], {
             RGBColor[
             0.9934533452931028, 0.9909188770411007, 0.711497206839451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 399}], {
             RGBColor[
             0.9922094297661992, 0.9904044860035552, 0.7321121062704341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 176}], {
             RGBColor[
             0.9941486413882477, 0.989892860529595, 0.6044939093893531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 209}], {
             RGBColor[
             0.9934140181173509, 0.9883215756349526, 0.5245346999215303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 250}], {
             RGBColor[
             0.9931962312133151, 0.9897525080071096, 0.6387041165934564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 323}], {
             RGBColor[
             0.9871392138900038, 0.9677821755826972, 0.44684373652784487`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 354}], {
             RGBColor[
             0.9744680231815726, 0.9249398902266195, 0.3981361456877379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 388}], {
             RGBColor[
             0.9929420288979143, 0.9873120384200081, 0.4731615861656776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 183}], {
             RGBColor[
             0.9898855980989636, 0.9900854491327185, 0.8172853449406199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 189}], {
             RGBColor[
             0.9896962197660804, 0.9883325913859944, 0.6987020943216264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 238}], {
             RGBColor[
             0.8204950384376805, 0.8594311021934724, 0.9235338688354239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 246}], {
             RGBColor[
             0.9848476917748035, 0.9879110798575863, 0.8966983893957519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 269}], {
             RGBColor[
             0.9859229647311463, 0.9884467984000935, 0.882956434811779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 272}], {
             RGBColor[
             0.9839935282893749, 0.9872740461287179, 0.8981442653750662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 309}], {
             RGBColor[
             0.9859412189811367, 0.9761832285095273, 0.640141071250564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 325}], {
             RGBColor[
             0.9879828593964217, 0.9892986177810631, 0.8488186493716557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 395}], {
             RGBColor[
             0.9601487873817993, 0.9694532099197823, 0.9372081708973221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 178}], {
             RGBColor[
             0.9930567691774437, 0.9891145578013825, 0.5988352008007788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 213}], {
             RGBColor[
             0.9350737653686148, 0.7622209333032521, 0.4882843818932352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 227}], {
             RGBColor[
             0.887287794237786, 0.910244993364432, 0.8682909317420431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 278}], {
             RGBColor[
             0.9666092927912964, 0.9730752607105572, 0.8723258271227148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 296}], {
             RGBColor[
             0.9936653805774789, 0.9916484863235634, 0.7546445675081291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 314}], {
             RGBColor[
             0.9931273161570446, 0.9914259828580889, 0.7635616874208091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 319}], {
             RGBColor[
             0.992130436104202, 0.9910137473375897, 0.7800825697392867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 352}], {
             RGBColor[
             0.9789662058104505, 0.9416661603593734, 0.5370909018865866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 250}], {
             RGBColor[
             0.9940357478171116, 0.9915481491344812, 0.730080318020776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 344}], {
             RGBColor[
             0.9419766443014088, 0.7901934586303232, 0.46246611644782537`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 354}], {
             RGBColor[
             0.975307539785369, 0.9267355313539911, 0.48951234711505764`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 356}], {
             RGBColor[
             0.992478798529886, 0.9909043105924418, 0.7558829969657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 372}], {
             RGBColor[
             0.9943725304903713, 0.9903717366803768, 0.6288628564721317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 388}], {
             RGBColor[
             0.9937815455017107, 0.9891076795473798, 0.5645377875929973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 197}], {
             RGBColor[
             0.972328213649408, 0.9291838570747615, 0.5797955973125346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 225}], {
             RGBColor[
             0.9271615850603125, 0.746120632318694, 0.26308012336857034`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 243}], {
             RGBColor[
             0.9761116114233847, 0.9307483892831886, 0.5170949050781638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 252}], {
             RGBColor[
             0.9717578142077012, 0.9289479822470188, 0.5892485922080503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 300}], {
             RGBColor[
             0.9731897618222216, 0.929540129384998, 0.5655175144738136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 337}], {
             RGBColor[
             0.9760220287228236, 0.9297508466098197, 0.44876146267826295`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 367}], {
             RGBColor[
             0.962509838787911, 0.9222914544710226, 0.6156774342773883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 398}], {
             RGBColor[
             0.9549452419801352, 0.916649790557674, 0.6284823235101245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 197}], {
             RGBColor[
             0.9897087364576219, 0.98773006023122, 0.6543207673991606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 274}], {
             RGBColor[
             0.9930833516659581, 0.9876143135309301, 0.48854369732421465`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 278}], {
             RGBColor[
             0.9661890065899055, 0.9706192094977525, 0.713395424503839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 300}], {
             RGBColor[
             0.9905702846304355, 0.9880863325414564, 0.6400426845604394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 319}], {
             RGBColor[
             0.9917101499028111, 0.9885576961247851, 0.6211521671204108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 352}], {
             RGBColor[
             0.9785459196090596, 0.9392101091465688, 0.37816049926771067`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 232}], {
             RGBColor[
             0.9923729255816831, 0.9907255149502235, 0.7478234599453135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 257}], {
             RGBColor[
             0.9920186183111164, 0.9899676875244414, 0.7092593000751422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 275}], {
             RGBColor[
             0.948563875397817, 0.9594743768070579, 0.9039117031378632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 279}], {
             RGBColor[
             0.9816986425042615, 0.9561558219339079, 0.5841493019999182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 285}], {
             RGBColor[
             0.9271960693153891, 0.733802540862857, 0.5127203921600998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 288}], {
             RGBColor[
             0.9848358896228862, 0.987260546871116, 0.867980343798392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 399}], {
             RGBColor[
             0.9898975799192837, 0.9900904039233396, 0.8170867751699593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 198}], {
             RGBColor[
             0.9831850761678804, 0.9857311683406647, 0.8574205309718799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 236}], {
             RGBColor[
             0.9689984180513211, 0.9763996514598825, 0.9373617711182902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 262}], {
             RGBColor[
             0.953437536417751, 0.8747905815281833, 0.5960462567782383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 267}], {
             RGBColor[
             0.9847661118497995, 0.9860305825104703, 0.8054586503966745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 284}], {
             RGBColor[
             0.9728026405570716, 0.9471365668169098, 0.6347004288658085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 286}], {
             RGBColor[
             0.9589786496466195, 0.8967592490141232, 0.6005047665488301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 332}], {
             RGBColor[
             0.9558276943021262, 0.8842667610668318, 0.597969433916223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 367}], {
             RGBColor[
             0.9709026279373743, 0.9778198080750433, 0.9341384404786814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 398}], {
             RGBColor[
             0.9633380311295985, 0.9721781441616947, 0.9469433297114176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 191}], {
             RGBColor[
             0.9904584467020643, 0.9880319057887177, 0.6413016091167025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 211}], {
             RGBColor[
             0.9888799911721247, 0.9896696048255513, 0.8339508541456453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 214}], {
             RGBColor[
             0.9490556860806438, 0.9601782760424409, 0.9174955588555553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 305}], {
             RGBColor[
             0.980397089024996, 0.9842199530035204, 0.8875787941076476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 334}], {
             RGBColor[
             0.9629639791731852, 0.9712183682201375, 0.9170885018035158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 340}], {
             RGBColor[
             0.9821724361664549, 0.9601577768203967, 0.6026044457005413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 365}], {
             RGBColor[
             0.9852985421822987, 0.9878754487428438, 0.879281912416056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 370}], {
             RGBColor[
             0.9821064222873708, 0.9599350965054502, 0.6023479942459747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 256}], {
             RGBColor[
             0.9225493959282786, 0.6933762721489942, 0.3593373946670079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 281}], {
             RGBColor[
             0.9205912739641667, 0.6942019030732983, 0.510662291365936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 311}], {
             RGBColor[
             0.9000254826035079, 0.6797408522597319, 0.5847434110442239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 386}], {
             RGBColor[
             0.9210190147631029, 0.6943787848860956, 0.5035735193698607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 238}], {
             RGBColor[
             0.8243291155582315, 0.8610165916141079, 0.8599932886743702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 246}], {
             RGBColor[
             0.9886817688953546, 0.9894965692782217, 0.8331578092346981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 269}], {
             RGBColor[
             0.9897570418516973, 0.9900322878207289, 0.8194158546507253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 272}], {
             RGBColor[
             0.987827605409926, 0.9888595355493535, 0.8346036852140124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 280}], {
             RGBColor[
             0.9815607174475282, 0.9841857007680843, 0.8452118918681975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 309}], {
             RGBColor[
             0.9897752961016879, 0.9777687179301628, 0.5766004910895102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 325}], {
             RGBColor[
             0.9918169365169728, 0.9908841072016985, 0.7852780692106021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 339}], {
             RGBColor[
             0.9658291722568784, 0.8916627367785881, 0.5113334826041473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 395}], {
             RGBColor[
             0.9639828645023505, 0.9710386993404179, 0.8736675907362683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 343}], {
             RGBColor[
             0.873690237606199, 0.4472755426943155, 0.21340101258448374`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 356}], {
             RGBColor[
             0.9600154571400628, 0.875272102458274, 0.5392399541418473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 369}], {
             RGBColor[
             0.9268418929489476, 0.8511797305711226, 0.6275805698805812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 372}], {
             RGBColor[
             0.9619091891005482, 0.8747395285462091, 0.4122198136482791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 198}], {
             RGBColor[
             0.9326572987048518, 0.7548966356130409, 0.5016551142825514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 205}], {
             RGBColor[
             0.9110127455001393, 0.6760816902929396, 0.2468006932648923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 208}], {
             RGBColor[
             0.8861171187753519, 0.5757662590290942, 0.2266856711923439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 210}], {
             RGBColor[
             0.8942997143532373, 0.609820091082951, 0.23335299609883303`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 219}], {
             RGBColor[
             0.9334485691419478, 0.7535068217816854, 0.36373216067449626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 249}], {
             RGBColor[
             0.9338264222882446, 0.7543150114548008, 0.4048591438095832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 284}], {
             RGBColor[
             0.9222748630940428, 0.7163020340892862, 0.2789350121764801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 293}], {
             RGBColor[
             0.9334624057031475, 0.7535364167870007, 0.3652381849717276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 338}], {
             RGBColor[
             0.9006970898721338, 0.7321056493436502, 0.6046100736851663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 188}], {
             RGBColor[
             0.9856338618796205, 0.9719838851019422, 0.6170875795834041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 228}], {
             RGBColor[
             0.9889115363965635, 0.9728751123333201, 0.5290273779915495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 238}], {
             RGBColor[
             0.8190088433398244, 0.8424731604875961, 0.6775039301041694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 273}], {
             RGBColor[
             0.9638660979164031, 0.8864294765182021, 0.33154540425009316`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 322}], {
             RGBColor[
             0.9849121643106354, 0.9716854446103853, 0.6290479759949255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 330}], {
             RGBColor[
             0.9874398164068218, 0.9692936928481675, 0.40570648784249463`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 206}], {
             RGBColor[
             0.9930020163546851, 0.9872555706245277, 0.49540277438095454`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 220}], {
             RGBColor[
             0.9924245433273601, 0.9860204142105586, 0.4325483991070391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 261}], {
             RGBColor[
             0.9930020163546851, 0.9872555706245277, 0.49540277438095454`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 321}], {
             RGBColor[
             0.9438110582490056, 0.8016823886867286, 0.32932994931550674`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 228}], {
             RGBColor[
             0.9914662674934838, 0.9902749211349321, 0.7573489099357887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 238}], {
             RGBColor[
             0.8215635744367447, 0.859872969289208, 0.9058254620484087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 273}], {
             RGBColor[
             0.9664208290133234, 0.903829285319814, 0.5598669361943324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 322}], {
             RGBColor[
             0.9874668954075557, 0.9890852534119974, 0.8573695079391647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 330}], {
             RGBColor[
             0.989994547503742, 0.9866935016497793, 0.6340280197867338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 222}], {
             RGBColor[
             0.9668409033899283, 0.8946718778182867, 0.3937166728551067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 226}], {
             RGBColor[
             0.9515811997804551, 0.9595480959207788, 0.7539195213394543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 395}], {
             RGBColor[
             0.9637934861694671, 0.9692858415936939, 0.7550843401172751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 212}], {
             RGBColor[
             0.9927371227562845, 0.9908970353481589, 0.7433081067989344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 221}], {
             RGBColor[
             0.9942491242936227, 0.990107783303812, 0.6154308535308075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 255}], {
             RGBColor[
             0.9446262481807932, 0.8023835265479065, 0.4575343476103326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 268}], {
             RGBColor[
             0.9934329227574201, 0.9911847665298729, 0.7317769001074356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 270}], {
             RGBColor[
             0.9848061238774726, 0.9860497591789974, 0.8045447589411286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 274}], {
             RGBColor[
             0.9941930591613416, 0.989987865654917, 0.6093285098758958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 295}], {
             RGBColor[
             0.9282787630403864, 0.9419835575498845, 0.8340727439482702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 324}], {
             RGBColor[
             0.9684083418898646, 0.9738203202215431, 0.8323019266196554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 351}], {
             RGBColor[
             0.9899271633262547, 0.9897350449111781, 0.7898764064964247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 211}], {
             RGBColor[
             0.9910485467200632, 0.988275927311039, 0.6315221246885662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 214}], {
             RGBColor[
             0.9512242416285824, 0.9587845985279285, 0.7150668293984763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 312}], {
             RGBColor[
             0.9937655341084521, 0.9890734327961999, 0.5627950462476675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 334}], {
             RGBColor[
             0.9651325347211237, 0.9698246907056252, 0.7146597723464367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 340}], {
             RGBColor[
             0.9843409917143935, 0.9587640993058844, 0.4001757162434622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 365}], {
             RGBColor[
             0.9874670977302373, 0.9864817712283316, 0.6768531829589769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 370}], {
             RGBColor[
             0.9842749778353094, 0.9585414189909378, 0.3999192647888956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 292}], {
             RGBColor[
             0.9751301480379355, 0.9809092205327992, 0.9241402543107988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 320}], {
             RGBColor[
             0.9787433959459476, 0.9789663905373109, 0.6828076341245135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 347}], {
             RGBColor[
             0.9802139499586751, 0.9830115032747749, 0.8398885000265144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 374}], {
             RGBColor[
             0.9777205116870717, 0.9755159617474775, 0.678833921934265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 382}], {
             RGBColor[
             0.9790275414694478, 0.9825208928751721, 0.8595503590197584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 384}], {
             RGBColor[
             0.9792432785269813, 0.9804691480730717, 0.7003500198209718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 248}], {
             RGBColor[
             0.9603188724689223, 0.9270333763594898, 0.6329210847839821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 305}], {
             RGBColor[
             0.9676165396541965, 0.9324759645974339, 0.6205680377757457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 334}], {
             RGBColor[
             0.9501834298023857, 0.919474379814051, 0.6500777454716138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 360}], {
             RGBColor[
             0.9629706241979259, 0.8867533618880117, 0.3106482967301526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 201}], {
             RGBColor[
             0.9540619959679244, 0.8571276815531794, 0.561163155311762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 208}], {
             RGBColor[
             0.9427618362153546, 0.8107137464133756, 0.5519873650916853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 223}], {
             RGBColor[
             0.9903999505481671, 0.9891102323812206, 0.7224123347858835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 230}], {
             RGBColor[
             0.9886474408827203, 0.9895734393046127, 0.8378048142619325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 242}], {
             RGBColor[
             0.953577203491343, 0.8552056409310504, 0.5607730799055626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 357}], {
             RGBColor[
             0.9896318443452216, 0.989980515434372, 0.821490701333789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 364}], {
             RGBColor[
             0.9899675143509525, 0.988185295081385, 0.6753443234059391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 385}], {
             RGBColor[
             0.9606320874063088, 0.9696767167627506, 0.9302255974371576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 387}], {
             RGBColor[
             0.9857344509137094, 0.9883688430919992, 0.8860805966248293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 247}], {
             RGBColor[
             0.9863902146052828, 0.988640018230823, 0.8752128951934257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 253}], {
             RGBColor[
             0.9842557089925981, 0.9716578374067883, 0.6416126488158683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 315}], {
             RGBColor[
             0.9588915969749279, 0.8791649872949039, 0.5791889224436796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 316}], {
             RGBColor[
             0.9625009345334277, 0.8934748079739137, 0.5820930801652899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 343}], {
             RGBColor[
             0.9012932524164092, 0.5611513744437919, 0.5290185508014571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 358}], {
             RGBColor[
             0.9890621017736392, 0.9876526373366942, 0.6788465119482248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 359}], {
             RGBColor[
             0.9753073790365945, 0.9809261838048466, 0.9186806711849241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 362}], {
             RGBColor[
             0.9889646277092214, 0.9874441501690443, 0.6682370615765486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 363}], {
             RGBColor[
             0.9887255789057541, 0.9867357581992289, 0.6589772493643742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 369}], {
             RGBColor[
             0.9544449077591578, 0.965055562320599, 0.9431981080975547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 372}], {
             RGBColor[
             0.9895122039107584, 0.9886153602956855, 0.7278373518652526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 397}], {
             RGBColor[
             0.9617686714659572, 0.9708290378662644, 0.9415981716415536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 289}], {
             RGBColor[
             0.9733820588630403, 0.9771478139031992, 0.7935808837070686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 317}], {
             RGBColor[
             0.9815352391769628, 0.9482624076562389, 0.4774744088359275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 326}], {
             RGBColor[
             0.9900657727785818, 0.9893193799363336, 0.753198378473183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 327}], {
             RGBColor[
             0.9946350945251232, 0.991208911904741, 0.6774728921073712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 336}], {
             RGBColor[
             0.9767396411101709, 0.9796518932455728, 0.7878973727603762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 376}], {
             RGBColor[
             0.9941481054248369, 0.9898917141580534, 0.6044355730796616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 252}], {
             RGBColor[
             0.9862105904974844, 0.9885657390461193, 0.8781897315119338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 300}], {
             RGBColor[
             0.9876425381120046, 0.9891578861840986, 0.854458653777697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 205}], {
             RGBColor[
             0.970064583472497, 0.9120245838775257, 0.532210170514863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 219}], {
             RGBColor[
             0.9925004071143055, 0.9894497153662715, 0.649141637924467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 236}], {
             RGBColor[
             0.9775224785606502, 0.9815080123168449, 0.8670058316789324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 284}], {
             RGBColor[
             0.9813267010664005, 0.9522449276738723, 0.5643444894264508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 332}], {
             RGBColor[
             0.9643517548114553, 0.8893751219237942, 0.5276134944768652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 367}], {
             RGBColor[
             0.9794266884467032, 0.9829281689320057, 0.8637825010393236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 398}], {
             RGBColor[
             0.9718620916389276, 0.977286505018657, 0.8765873902720599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 216}], {
             RGBColor[
             0.9369489774135721, 0.7695360646980663, 0.3605953807055897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 298}], {
             RGBColor[
             0.9344354935943334, 0.7703104649787378, 0.534093729449269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 299}], {
             RGBColor[
             0.9374272356981986, 0.7705590108095527, 0.4126508435191918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 306}], {
             RGBColor[
             0.9277373975968197, 0.765973025835152, 0.5748979901979747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 342}], {
             RGBColor[
             0.9371295649358491, 0.7699223231480177, 0.3802512180484424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 353}], {
             RGBColor[
             0.9374293958130835, 0.7705636310768704, 0.4128859586937299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 361}], {
             RGBColor[
             0.9372594348540708, 0.7702001017712312, 0.3943867571826566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 393}], {
             RGBColor[
             0.9203043011778531, 0.7604294346964651, 0.5874802835732514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 207}], {
             RGBColor[
             0.9766855472691838, 0.9789231640228909, 0.7333684448805005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 333}], {
             RGBColor[
             0.9329477100701457, 0.8170679096040258, 0.5978019862649221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 368}], {
             RGBColor[
             0.9602363652328182, 0.9698649268143877, 0.9521936410306411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 223}], {
             RGBColor[
             0.957567050903592, 0.8573891971373828, 0.41672646526638185`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 230}], {
             RGBColor[
             0.9558145412381451, 0.8578524040607749, 0.5321189447424308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 245}], {
             RGBColor[
             0.9201071740745743, 0.8318222785989211, 0.623806056785433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 364}], {
             RGBColor[
             0.9571346147063775, 0.8564642598375471, 0.3696584538864374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 385}], {
             RGBColor[
             0.9277991877617338, 0.8379556815189126, 0.6245397279176559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 218}], {
             RGBColor[
             0.984004269460288, 0.9860049491568981, 0.8409345904112497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 229}], {
             RGBColor[
             0.9879927433614211, 0.9717277020080077, 0.5694817507170258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 260}], {
             RGBColor[
             0.8572853609011042, 0.8867587767042913, 0.8631200685996482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 307}], {
             RGBColor[
             0.9937695260186639, 0.9904134176495211, 0.6600116505608804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 341}], {
             RGBColor[
             0.9585206705976578, 0.8626533115860467, 0.5052882196851799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 349}], {
             RGBColor[
             0.9653992850697559, 0.9721293822613052, 0.8724279760273431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 366}], {
             RGBColor[
             0.9943517973704254, 0.9916588371942747, 0.7233882938378788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 232}], {
             RGBColor[
             0.9734091137779959, 0.9193517754233637, 0.47953051035863853`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 257}], {
             RGBColor[
             0.9730548065074293, 0.9185939479975815, 0.4409663504884672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 275}], {
             RGBColor[
             0.9296000635941297, 0.8881006372801981, 0.6356187535511881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 280}], {
             RGBColor[
             0.9606941669412989, 0.9120251298895692, 0.6084522467125584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 297}], {
             RGBColor[
             0.9628348501403279, 0.8851194714630182, 0.3162449090495997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 309}], {
             RGBColor[
             0.9689087455954588, 0.9056081470516477, 0.33984084593387115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 322}], {
             RGBColor[
             0.9693658860228136, 0.918068304858382, 0.5747776894094869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 325}], {
             RGBColor[
             0.9709503860107436, 0.9187235363231834, 0.548518424054963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 339}], {
             RGBColor[
             0.9449626217506493, 0.819502165900073, 0.27457383744850833`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 224}], {
             RGBColor[
             0.9806263457302651, 0.9822067451656947, 0.7540354845251132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 276}], {
             RGBColor[
             0.9813406005136002, 0.9837344639250124, 0.8317777098215672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 290}], {
             RGBColor[
             0.9174165489557182, 0.732993580711613, 0.5755324667056269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 297}], {
             RGBColor[
             0.9705609145198681, 0.9490627823164322, 0.6461331527747867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 318}], {
             RGBColor[
             0.9764602746967264, 0.9817504015741938, 0.9151344343012433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 345}], {
             RGBColor[
             0.9508423783756615, 0.9628214393153165, 0.9667961893058163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 219}], {
             RGBColor[
             0.9708558539095932, 0.9106347700461702, 0.39428721690680785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 284}], {
             RGBColor[
             0.9596821478616882, 0.873429982353771, 0.3094900684087917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 293}], {
             RGBColor[
             0.9708696904707929, 0.9106643650514854, 0.3957932412040392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 338}], {
             RGBColor[
             0.9381043746397791, 0.8892335976081351, 0.6351651299174779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 220}], {
             RGBColor[
             0.9932229512753026, 0.9879129029796325, 0.5037382532924402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 321}], {
             RGBColor[
             0.944609466196948, 0.8035748774558025, 0.4005198035009078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 328}], {
             RGBColor[
             0.9940361543730649, 0.9896522621783008, 0.5922503919760936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 386}], {
             RGBColor[
             0.9920629985453118, 0.9897077246835344, 0.688293227145857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 254}], {
             RGBColor[
             0.9878132719421364, 0.9872222028640021, 0.7145321095846024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 333}], {
             RGBColor[
             0.9495815134747629, 0.8262638371266813, 0.3786642742952961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 230}], {
             RGBColor[
             0.9445143814855754, 0.8114384689209708, 0.5229431545223543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 240}], {
             RGBColor[
             0.946831925367078, 0.812183813052, 0.46905116247701684`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 242}], {
             RGBColor[
             0.909444144094198, 0.6770706705474087, 0.24591142016598438`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 357}], {
             RGBColor[
             0.9454987849480767, 0.8118455450507303, 0.5066290415942107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 385}], {
             RGBColor[
             0.9164990280091639, 0.7915417463791088, 0.6153639376975794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 387}], {
             RGBColor[
             0.9416013915165644, 0.8102338727083573, 0.5712189368852512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 241}], {
             RGBColor[
             0.9929596532765657, 0.9898356570944276, 0.6557801711903556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 270}], {
             RGBColor[
             0.9841376306191879, 0.9846199196945626, 0.7317833932390096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 310}], {
             RGBColor[
             0.9819936913558924, 0.9502956462397276, 0.4378638543018444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 323}], {
             RGBColor[
             0.9872441072229033, 0.9680065318154265, 0.4582607284873418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 346}], {
             RGBColor[
             0.9834335760768596, 0.9840948369696776, 0.7329751739323379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 390}], {
             RGBColor[
             0.9942606466120555, 0.9901324283778545, 0.6166849867847041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 249}], {
             RGBColor[
             0.9545206759089878, 0.845181360509297, 0.42196650287583554`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 266}], {
             RGBColor[
             0.935393974161198, 0.7815656667706874, 0.26687467899300965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 293}], {
             RGBColor[
             0.9541566593238908, 0.8444027658414968, 0.38234554403797993`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 315}], {
             RGBColor[
             0.923754828545509, 0.7354203329198357, 0.2575095492247651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 316}], {
             RGBColor[
             0.9273641661040088, 0.7497301535988454, 0.2604137069463754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 387}], {
             RGBColor[
             0.9497839870944498, 0.8442877047622142, 0.5778862617917402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 397}], {
             RGBColor[
             0.9266319030365383, 0.8270843834911961, 0.6199187984226391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 214}], {
             RGBColor[
             0.9496457860986429, 0.9604222975647622, 0.907716074427419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 248}], {
             RGBColor[
             0.9736895218577208, 0.9790213862878976, 0.8901523566877477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 263}], {
             RGBColor[
             0.9652282261549279, 0.896825621928333, 0.5477729072637741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 312}], {
             RGBColor[
             0.9921870785785125, 0.9907111318330335, 0.7554442912766102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 334}], {
             RGBColor[
             0.9635540791911842, 0.9714623897424588, 0.9073090173753794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 340}], {
             RGBColor[
             0.9827625361844539, 0.960401798342718, 0.5928249612724049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 370}], {
             RGBColor[
             0.9826965223053699, 0.9601791180277714, 0.5925685098178383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 268}], {
             RGBColor[
             0.9913141475468847, 0.9906761910414801, 0.7936105836211047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 270}], {
             RGBColor[
             0.9826873486669372, 0.9855411836906047, 0.8663784424547978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 274}], {
             RGBColor[
             0.9920742839508062, 0.9894792901665243, 0.6711621933895651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 295}], {
             RGBColor[
             0.926159987829851, 0.9414749820614917, 0.8959064274619394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 310}], {
             RGBColor[
             0.9805434094036417, 0.9512169102357697, 0.5724589035176326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 324}], {
             RGBColor[
             0.9662895666793292, 0.9733117447331503, 0.8941356101333245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 351}], {
             RGBColor[
             0.9878083881157194, 0.9892264694227854, 0.8517100900100938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 373}], {
             RGBColor[
             0.9926814662788255, 0.9907779917706072, 0.7372502426994898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 390}], {
             RGBColor[
             0.9928103646598048, 0.9910536923738966, 0.7512800360004923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 227}], {
             RGBColor[
             0.8288845042275661, 0.6808953176534969, 0.5988097102156236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 296}], {
             RGBColor[
             0.9352620905672591, 0.7622988106126283, 0.4851633459817096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 308}], {
             RGBColor[
             0.9293326022296471, 0.7418986961951546, 0.30167825612212895`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 352}], {
             RGBColor[
             0.9205629158002306, 0.7123164846484384, 0.267609680360167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 248}], {
             RGBColor[
             0.93386521676624, 0.9495300575047871, 0.9736970613976579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 263}], {
             RGBColor[
             0.925403921063447, 0.8673342931452226, 0.6313176119736843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 312}], {
             RGBColor[
             0.9523627734870317, 0.961219803049923, 0.8389889959865204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 340}], {
             RGBColor[
             0.942938231092973, 0.9309104695596075, 0.6763696659823151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 218}], {
             RGBColor[
             0.9766674627079667, 0.9821192124079006, 0.9243800789217793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 229}], {
             RGBColor[
             0.9806559366090999, 0.9678419652590102, 0.6529272392275554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 329}], {
             RGBColor[
             0.9860041629321898, 0.9876285973333443, 0.8434663840636123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 349}], {
             RGBColor[
             0.9580624783174345, 0.9682436455123078, 0.9558734645378727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 231}], {
             RGBColor[
             0.9651197259132207, 0.9701999869322209, 0.7452175775557515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 235}], {
             RGBColor[
             0.9940905464610106, 0.9897686013545329, 0.5981706350799219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 298}], {
             RGBColor[
             0.9906660256023914, 0.9885943855279433, 0.6725082243559013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 313}], {
             RGBColor[
             0.992255446130428, 0.985120422727595, 0.4599171820919756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 361}], {
             RGBColor[
             0.9934899668621289, 0.9884840223204368, 0.5328012520892889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 393}], {
             RGBColor[
             0.9765348331859112, 0.9787133552456706, 0.7258947784798837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 396}], {
             RGBColor[
             0.993162603310225, 0.9877838247844468, 0.49716974971821926`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 220}], {
             RGBColor[
             0.9693593732221341, 0.9052916277608583, 0.35817568383370946`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 230}], {
             RGBColor[
             0.9682366271746159, 0.9071018353841306, 0.5421140466707477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 233}], {
             RGBColor[
             0.9690281314922998, 0.9074291427602261, 0.5289967717792123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 242}], {
             RGBColor[
             0.9331663897832385, 0.7727340370105684, 0.2650823123143779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 244}], {
             RGBColor[
             0.9595248096087412, 0.8722052684376604, 0.31249307283223554`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 264}], {
             RGBColor[
             0.9657984425001904, 0.9060935833627677, 0.5825210765456477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 321}], {
             RGBColor[
             0.9207458881437796, 0.7209536022370282, 0.25495723404217707`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 357}], {
             RGBColor[
             0.9692210306371172, 0.9075089115138899, 0.5257999337426043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 364}], {
             RGBColor[
             0.9695567006428482, 0.905713691160903, 0.37965355581475435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 366}], {
             RGBColor[
             0.9705191176012207, 0.907772203719581, 0.48440670238462336`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 229}], {
             RGBColor[
             0.9782583850870088, 0.9660538752594652, 0.6569856685728703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 260}], {
             RGBColor[
             0.8475510026266919, 0.8810849499557487, 0.9506239864554927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 329}], {
             RGBColor[
             0.983606611410099, 0.9858405073337991, 0.8475248134089273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 349}], {
             RGBColor[
             0.9556649267953436, 0.9664555555127627, 0.9599318938831877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 284}], {
             RGBColor[
             0.9821179715034967, 0.9508551138425168, 0.4264215358183956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 293}], {
             RGBColor[
             0.9933055141126014, 0.9880894965402311, 0.5127247086136432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 338}], {
             RGBColor[
             0.9605401982815877, 0.9666587290968809, 0.7520965973270818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 233}], {
             RGBColor[
             0.9923142365181432, 0.9888152615650312, 0.6117049659640277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 244}], {
             RGBColor[
             0.9828109146345846, 0.9535913872424655, 0.39520126701705083`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 321}], {
             RGBColor[
             0.9440319931696229, 0.8023397210418333, 0.3376654282269924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 341}], {
             RGBColor[
             0.9579740958542964, 0.8601527969161582, 0.3490148224167397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 366}], {
             RGBColor[
             0.9938052226270642, 0.9891583225243862, 0.5671148965694386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 239}], {
             RGBColor[
             0.9606395797465437, 0.869810523547405, 0.4050101827470658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 255}], {
             RGBColor[
             0.944019474507596, 0.8010856990151668, 0.3914907778558748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 268}], {
             RGBColor[
             0.992826149084223, 0.9898869389971332, 0.6657333303529778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 324}], {
             RGBColor[
             0.9678015682166674, 0.9725224926888034, 0.7662583568651975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 351}], {
             RGBColor[
             0.9893203896530576, 0.9884372173784385, 0.7238328367419669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 400}], {
             RGBColor[
             0.9800403957757615, 0.9436305388910807, 0.4367536968363166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 333}], {
             RGBColor[
             0.9230922822509167, 0.7327935576422419, 0.2569764489241758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 230}], {
             RGBColor[
             0.9921524958183878, 0.9898349548888161, 0.6933681242165524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 242}], {
             RGBColor[
             0.9570822584270106, 0.8554671565152538, 0.4163363898601825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 245}], {
             RGBColor[
             0.956445128654817, 0.9638048294269623, 0.7850552362595544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 328}], {
             RGBColor[
             0.9940884449636684, 0.9897641064642121, 0.5979419000631675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 364}], {
             RGBColor[
             0.9934725692866202, 0.9884468106655884, 0.5309076333605589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 385}], {
             RGBColor[
             0.9641371423419764, 0.9699382323469539, 0.7857889073917774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 290}], {
             RGBColor[
             0.9306041917198465, 0.7399639073741565, 0.389565989312078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 318}], {
             RGBColor[
             0.9896479174608546, 0.9887207282367373, 0.7291679569076943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 345}], {
             RGBColor[
             0.9640300211397899, 0.9697917659778601, 0.7808297119122675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 240}], {
             RGBColor[
             0.9457414033384735, 0.8072320072179966, 0.4681412041652081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 243}], {
             RGBColor[
             0.9453977591240723, 0.8073029213262217, 0.48932057043808297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 337}], {
             RGBColor[
             0.9453081764235113, 0.8063053786528527, 0.42098712803818217`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 367}], {
             RGBColor[
             0.9317959864885986, 0.7988459865140557, 0.5879030996373075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 398}], {
             RGBColor[
             0.924231389680823, 0.7932043226007071, 0.6007079888700436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 234}], {
             RGBColor[
             0.9005425950509681, 0.9235322369888322, 0.9903757507114681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 281}], {
             RGBColor[
             0.9496457860986429, 0.9604222975647622, 0.907716074427419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 350}], {
             RGBColor[
             0.9417781107902389, 0.9554314809117107, 0.9603025958283186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 355}], {
             RGBColor[
             0.9517275940529639, 0.9598612184669438, 0.7698536344613187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 392}], {
             RGBColor[
             0.5443742405035811, 0.6181624843908259, 0.9623808895686645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 395}], {
             RGBColor[
             0.9220337673961742, 0.9406687144545668, 0.99242559791515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 296}], {
             RGBColor[
             0.8874761194364302, 0.9103228706738082, 0.8651698958305175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 308}], {
             RGBColor[
             0.8815466310988183, 0.8899227562563344, 0.6816848059709368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 352}], {
             RGBColor[
             0.8727769446694018, 0.8603405447096183, 0.647616230208975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 375}], {
             RGBColor[
             0.8707973123276591, 0.8536627799811419, 0.6399257323835035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 238}], {
             RGBColor[
             0.8248412489536875, 0.8607641965205859, 0.8177652604565542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 273}], {
             RGBColor[
             0.9696985035302663, 0.9047205125511919, 0.4718067346024778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 330}], {
             RGBColor[
             0.9932722220206849, 0.9875847288811572, 0.5459678181948793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 368}], {
             RGBColor[
             0.9775824643057482, 0.980584382747425, 0.810584916777545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 260}], {
             RGBColor[
             0.8515394765278251, 0.8668077028068584, 0.6791711467612688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[
             0.9875950853112321, 0.9715632601849088, 0.5760719737147033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 349}], {
             RGBColor[
             0.9596534006964768, 0.9521783083638724, 0.6884790541889637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 233}], {
             RGBColor[
             0.991191490470625, 0.9906254691883036, 0.795643328801066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 242}], {
             RGBColor[
             0.9553297487615637, 0.8559303634386459, 0.5317288693362315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 244}], {
             RGBColor[
             0.9816881685870664, 0.955401594865738, 0.5791396298540892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 245}], {
             RGBColor[
             0.9546926189893703, 0.9642680363503544, 0.9004477157356034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 328}], {
             RGBColor[
             0.9923359352982217, 0.9902273133876041, 0.7133343795392165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 357}], {
             RGBColor[
             0.9913843896154424, 0.9907052379419674, 0.792446490764458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 364}], {
             RGBColor[
             0.9917200596211734, 0.9889100175889805, 0.6463001128366079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 385}], {
             RGBColor[
             0.9623846326765296, 0.970401439270346, 0.9011813868678265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 235}], {
             RGBColor[
             0.9660307629526014, 0.9721486030394819, 0.8443783370234513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 298}], {
             RGBColor[
             0.962606242093982, 0.9709743872128924, 0.9187159262994309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 336}], {
             RGBColor[
             0.9481157973828385, 0.9608254271574812, 0.9727106008502737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 393}], {
             RGBColor[
             0.9484750496775018, 0.9610933569306196, 0.9721024804234132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 396}], {
             RGBColor[
             0.9651028198018158, 0.9701638264693957, 0.7433774516617488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 257}], {
             RGBColor[
             0.9944773460783687, 0.9905959266246217, 0.6402713863788179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 275}], {
             RGBColor[
             0.9510226031650693, 0.9601026159072381, 0.8349237894415387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 279}], {
             RGBColor[
             0.9841573702715138, 0.9567840610340883, 0.5151613883035939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 280}], {
             RGBColor[
             0.9821167065122385, 0.9840271085166092, 0.8077572826029089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 288}], {
             RGBColor[
             0.9872946173901385, 0.9878887859712963, 0.7989924301020674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 297}], {
             RGBColor[
             0.9842573897112674, 0.9571214500900584, 0.5155499449399503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 309}], {
             RGBColor[
             0.9903312851663982, 0.9776101256786878, 0.5391458818242217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 325}], {
             RGBColor[
             0.9923729255816831, 0.9907255149502235, 0.7478234599453135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 339}], {
             RGBColor[
             0.9663851613215888, 0.8915041445271131, 0.4738788733388589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 242}], {
             RGBColor[
             0.9561212530792478, 0.8562576708147414, 0.5186115944446962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 244}], {
             RGBColor[
             0.9824796729047504, 0.9557289022418334, 0.5660223549625538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 264}], {
             RGBColor[
             0.9887533057961997, 0.9896172171669406, 0.836050358675966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 307}], {
             RGBColor[
             0.9928917095454683, 0.9900504179790004, 0.6745593412379431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 348}], {
             RGBColor[
             0.9888601992972785, 0.9896614203766745, 0.8342788567315756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 357}], {
             RGBColor[
             0.9921758939331263, 0.9910325453180628, 0.7793292158729226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 366}], {
             RGBColor[
             0.9934739808972299, 0.991295837523754, 0.7379359845149416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[
             0.9094502589837179, 0.8334722982598751, 0.6250619020016945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 246}], {
             RGBColor[
             0.9374537858329843, 0.9517278525995512, 0.9510307879877186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 269}], {
             RGBColor[
             0.938529058789327, 0.9522635711420584, 0.9372888334037457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 272}], {
             RGBColor[
             0.9365996223475557, 0.9510908188706828, 0.9524766639670329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 350}], {
             RGBColor[
             0.9324992248340449, 0.9480327491188912, 0.9594175674024575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 355}], {
             RGBColor[
             0.94244870809677, 0.9524624866741244, 0.7689686060354577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 392}], {
             RGBColor[
             0.5350953545473871, 0.6107637525980064, 0.9614958611428035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 395}], {
             RGBColor[
             0.9127548814399802, 0.9332699826617473, 0.9915405694892889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 298}], {
             RGBColor[
             0.9915770626417719, 0.9905430016352044, 0.771668983823601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 313}], {
             RGBColor[
             0.9931664831698087, 0.9870690388348561, 0.5590779415596754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 317}], {
             RGBColor[
             0.9818822159974203, 0.9490045559904594, 0.5152406944499953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 336}], {
             RGBColor[
             0.9770866179306283, 0.9803940415797933, 0.825663658374444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 393}], {
             RGBColor[
             0.9774458702252917, 0.9806619713529316, 0.8250555379475835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 396}], {
             RGBColor[
             0.9940736403496057, 0.9897324408917079, 0.596330509185919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 267}], {
             RGBColor[
             0.979103514242569, 0.9818074264866505, 0.8150439511037273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 284}], {
             RGBColor[
             0.9671400429498411, 0.9429134107930901, 0.6442857295728611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 286}], {
             RGBColor[
             0.9533160520393891, 0.8925360929903035, 0.6100900672558828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 332}], {
             RGBColor[
             0.9501650966948959, 0.880043605043012, 0.6075547346232757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 367}], {
             RGBColor[
             0.9652400303301438, 0.9735966520512236, 0.9437237411857341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 383}], {
             RGBColor[
             0.9438644593487211, 0.8550636775283605, 0.6024850939195767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 398}], {
             RGBColor[
             0.9576754335223682, 0.967954988137875, 0.9565286304184704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 251}], {
             RGBColor[
             0.8866575139090327, 0.9115409921813089, 0.9497502508265149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 296}], {
             RGBColor[
             0.9867238711235232, 0.9880141049807143, 0.8354748422551902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 308}], {
             RGBColor[
             0.9807943827859114, 0.9676139905632406, 0.6519897523956095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 380}], {
             RGBColor[
             0.9873502303265291, 0.9882731206078545, 0.8250944492957277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 269}], {
             RGBColor[
             0.8203664821904142, 0.859377940881483, 0.9256643785455293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 272}], {
             RGBColor[
             0.8184370457486428, 0.8582051886101074, 0.9408522091088165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 280}], {
             RGBColor[
             0.812170157786245, 0.8535313538288383, 0.9514604157630014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 309}], {
             RGBColor[
             0.8203847364404047, 0.8471143709909168, 0.6828490149843143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 325}], {
             RGBColor[
             0.8224263768556896, 0.8602297602624526, 0.891526593105406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 339}], {
             RGBColor[
             0.7964386125955952, 0.7610083898393422, 0.6175820064989515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 246}], {
             RGBColor[
             0.9556403357219281, 0.8690666456634135, 0.5866019677038059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 269}], {
             RGBColor[
             0.9567156086782709, 0.8696023642059207, 0.5728600131198331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 272}], {
             RGBColor[
             0.9547861722364995, 0.8684296119345452, 0.5880478436831202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 350}], {
             RGBColor[
             0.9506857747229887, 0.8653715421827536, 0.5949887471185449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 355}], {
             RGBColor[
             0.9606352579857138, 0.8698012797379867, 0.40453978575154514`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 392}], {
             RGBColor[
             0.5532819044363309, 0.5281025456618688, 0.597067040858891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 242}], {
             RGBColor[
             0.9576472926430665, 0.8566757075696749, 0.4778368772908941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 243}], {
             RGBColor[
             0.9946914297015454, 0.9918597641824913, 0.7221559858748015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 285}], {
             RGBColor[
             0.929756507366147, 0.7346483279749686, 0.4548030151402441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 337}], {
             RGBColor[
             0.9946018470009843, 0.9908622215091224, 0.6538225434749007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 357}], {
             RGBColor[
             0.993701933496945, 0.9914505820729965, 0.7385544987191205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 399}], {
             RGBColor[
             0.9924580179700415, 0.990936191035451, 0.7591693981501036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 270}], {
             RGBColor[
             0.9835783724455032, 0.9859096449213083, 0.8516118725483379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 310}], {
             RGBColor[
             0.9814344331822077, 0.9515853714664733, 0.5576923336111728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 323}], {
             RGBColor[
             0.9866848490492186, 0.9692962570421721, 0.5780892077966702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 346}], {
             RGBColor[
             0.9828743179031748, 0.9853845621964232, 0.8528036532416663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 389}], {
             RGBColor[
             0.9919258590858664, 0.9909291494831184, 0.7834729403614626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 390}], {
             RGBColor[
             0.9937013884383707, 0.9914221536046002, 0.7365134660940325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 244}], {
             RGBColor[
             0.946617931195689, 0.8210337964921757, 0.30210789549771927`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 357}], {
             RGBColor[
             0.956314152224065, 0.8563374395684051, 0.515414756408088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 364}], {
             RGBColor[
             0.9566498222297961, 0.8545422192154182, 0.3692683784802381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 385}], {
             RGBColor[
             0.9273143952851524, 0.8360336408967837, 0.6241496525114565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 337}], {
             RGBColor[
             0.9942582027865834, 0.9909331356173474, 0.6750019097477755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 367}], {
             RGBColor[
             0.9807460128516707, 0.9834737434785503, 0.8419178813469008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 398}], {
             RGBColor[
             0.973181416043895, 0.9778320795652018, 0.8547227705796371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 264}], {
             RGBColor[
             0.979249983912641, 0.954393342844375, 0.6195466597289891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 307}], {
             RGBColor[
             0.9833883876619096, 0.9548265436564347, 0.4580556422909663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 321}], {
             RGBColor[
             0.9341974295562301, 0.7692533617186355, 0.29198281722551844`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 341}], {
             RGBColor[
             0.9481395322409035, 0.8270664375929604, 0.3033322114152658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 348}], {
             RGBColor[
             0.9793568774137199, 0.9544375460541088, 0.6177751577845987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 357}], {
             RGBColor[
             0.9826725720495677, 0.9558086709954973, 0.5628255169259456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 366}], {
             RGBColor[
             0.9839706590136712, 0.9560719632011885, 0.5214322855679647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 328}], {
             RGBColor[
             0.9566285681346509, 0.9641971879257505, 0.8050214915822187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 364}], {
             RGBColor[
             0.9560126924576026, 0.9628798921271267, 0.73798722487961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 400}], {
             RGBColor[
             0.9427118463784484, 0.918344516449795, 0.6581274688374446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 269}], {
             RGBColor[
             0.9847191355275371, 0.9878579185455968, 0.8988288991058573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 272}], {
             RGBColor[
             0.9827896990857659, 0.9866851662742213, 0.9140167296691444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 350}], {
             RGBColor[
             0.9786893015722551, 0.9836270965224296, 0.920957633104569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 355}], {
             RGBColor[
             0.98863878483498, 0.9880568340776628, 0.7305086717375693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 392}], {
             RGBColor[
             0.5812854312855972, 0.6463581000015448, 0.9230359268449151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 395}], {
             RGBColor[
             0.9589449581781904, 0.9688643300652857, 0.9530806351914003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 253}], {
             RGBColor[
             0.9853784187650624, 0.9721221067500274, 0.6230064424063797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 266}], {
             RGBColor[
             0.9716534523630813, 0.9257745904889948, 0.5699478458024355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 301}], {
             RGBColor[
             0.9872798005240777, 0.98900788486956, 0.8604701543444329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 315}], {
             RGBColor[
             0.9600143067473923, 0.8796292566381431, 0.560582716034191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 316}], {
             RGBColor[
             0.9636236443058921, 0.8939390773171528, 0.5634868737558012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 343}], {
             RGBColor[
             0.9024159621888735, 0.561615643787031, 0.5104123443919686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 358}], {
             RGBColor[
             0.9901848115461036, 0.9881169066799333, 0.660240305538736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 359}], {
             RGBColor[
             0.9764300888090589, 0.9813904531480857, 0.9000744647754355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 362}], {
             RGBColor[
             0.9900873374816859, 0.9879084195122834, 0.64963085516706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 363}], {
             RGBColor[
             0.9898482886782184, 0.987200027542468, 0.6403710429548856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 369}], {
             RGBColor[
             0.9555676175316221, 0.9655198316638381, 0.9245919016880659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 397}], {
             RGBColor[
             0.9628913812384217, 0.9712933072095036, 0.922991965232065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 276}], {
             RGBColor[
             0.9765757252931907, 0.980180827787398, 0.8398434006912294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 340}], {
             RGBColor[
             0.966981966852051, 0.9495095582827431, 0.6588059482426438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 360}], {
             RGBColor[
             0.9605607042543215, 0.9278491317564446, 0.6338605556041572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 266}], {
             RGBColor[
             0.9749206820962053, 0.9260605871425371, 0.43838082670375983`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 293}], {
             RGBColor[
             0.993683367258898, 0.9888976862133467, 0.5538516917487302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 315}], {
             RGBColor[
             0.9632815364805163, 0.8799152532916854, 0.4290156969355152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 316}], {
             RGBColor[
             0.9668908740390161, 0.8942250739706952, 0.43191985465712557`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 387}], {
             RGBColor[
             0.9893106950294572, 0.9887826251340639, 0.7493924095024904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 397}], {
             RGBColor[
             0.9661586109715457, 0.9715793038630459, 0.7914249461333893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 356}], {
             RGBColor[
             0.9915263883549534, 0.9907639580699563, 0.7900932041698032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 363}], {
             RGBColor[
             0.9926334953104343, 0.9883517820614349, 0.5942129611753567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 372}], {
             RGBColor[
             0.9934201203154388, 0.9902313841578914, 0.663073063676235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 283}], {
             RGBColor[
             0.8942312381199375, 0.9149705154370723, 0.8245478074929004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 308}], {
             RGBColor[
             0.8878578602240207, 0.8948531364160603, 0.6823138503083476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 380}], {
             RGBColor[
             0.8944137077646385, 0.9155122664606744, 0.8554185472084657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 381}], {
             RGBColor[
             0.8940724210125729, 0.9146308217032921, 0.8072615454618374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 282}], {
             RGBColor[
             0.9459951449858406, 0.82737312196958, 0.565574010815361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 300}], {
             RGBColor[
             0.987072138670298, 0.9889220113563559, 0.8639116486732127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 367}], {
             RGBColor[
             0.9763922156359873, 0.9816733364423805, 0.9140715684767873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 398}], {
             RGBColor[
             0.9688276188282117, 0.9760316725290319, 0.9268764577095235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 266}], {
             RGBColor[
             0.9695189467503966, 0.9087924096649601, 0.33634759942487813`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 301}], {
             RGBColor[
             0.985145294911393, 0.9720257040455254, 0.6268699079668755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 315}], {
             RGBColor[
             0.9578798011347076, 0.8626470758141084, 0.3269824696566336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 316}], {
             RGBColor[
             0.9614891386932074, 0.8769568964931181, 0.32988662737824387`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 343}], {
             RGBColor[
             0.9002814565761889, 0.5446334629629963, 0.27681209801441115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 358}], {
             RGBColor[
             0.9880503059334189, 0.9711347258558987, 0.4266400591611787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 359}], {
             RGBColor[
             0.9742955831963742, 0.964408272324051, 0.6664742183978781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 362}], {
             RGBColor[
             0.9879528318690012, 0.9709262386882487, 0.4160306087895026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 369}], {
             RGBColor[
             0.9534331119189374, 0.9485376508398035, 0.6909916553105087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 394}], {
             RGBColor[
             0.9875222075916605, 0.9695716176609986, 0.4060265620373234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 397}], {
             RGBColor[
             0.960756875625737, 0.9543111263854689, 0.6893917188545076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 303}], {
             RGBColor[
             0.9832111066758938, 0.9869994513649472, 0.9133033965397599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 268}], {
             RGBColor[
             0.9432032729713935, 0.8021626822412277, 0.5078368244325029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 324}], {
             RGBColor[
             0.9181786921038378, 0.7847982359328979, 0.6083618509447226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 328}], {
             RGBColor[
             0.9443342414191344, 0.8017589536111307, 0.42575121366061575`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 351}], {
             RGBColor[
             0.939697513540228, 0.8007129606225329, 0.565936330821492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 400}], {
             RGBColor[
             0.9304175196629318, 0.7559062821351752, 0.2788571909158417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 311}], {
             RGBColor[
             0.9708624217935766, 0.9746269446100022, 0.7469275926968686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 313}], {
             RGBColor[
             0.9923588589787867, 0.9853416123535914, 0.47117303244569086`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 386}], {
             RGBColor[
             0.9918559539531716, 0.9892648772363658, 0.6657577010225054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 275}], {
             RGBColor[
             0.9506682958945025, 0.9593447884814561, 0.7963596295713674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 276}], {
             RGBColor[
             0.9946827684344328, 0.9910353042728566, 0.6626303421165594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 279}], {
             RGBColor[
             0.9838030630009471, 0.9560262336083061, 0.47659722843342256`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 280}], {
             RGBColor[
             0.9817623992416717, 0.9832692810908272, 0.7691931227327375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 288}], {
             RGBColor[
             0.9869403101195718, 0.9871309585455141, 0.7604282702318962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 309}], {
             RGBColor[
             0.9899769778958316, 0.9768522982529058, 0.5005817219540505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 325}], {
             RGBColor[
             0.9920186183111164, 0.9899676875244414, 0.7092593000751422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 339}], {
             RGBColor[
             0.9660308540510221, 0.890746317101331, 0.4353147134686876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 277}], {
             RGBColor[
             0.9616812414091112, 0.8824039709798637, 0.30563928807511587`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 302}], {
             RGBColor[
             0.9668288472300689, 0.8997680541292783, 0.3256367646457444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 377}], {
             RGBColor[
             0.977217536031863, 0.9334880090340711, 0.4785384500090286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 378}], {
             RGBColor[
             0.9597354128618634, 0.875840234387727, 0.2980801116079461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 379}], {
             RGBColor[
             0.9768280410282548, 0.9326549186053388, 0.4361443225508068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 262}], {
             RGBColor[
             0.9621436776142829, 0.8799742374285643, 0.5226727691422133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 331}], {
             RGBColor[
             0.9886903331518313, 0.9895911763601712, 0.8370939783611296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 335}], {
             RGBColor[
             0.9932165034648286, 0.9906672159162658, 0.7042483991175221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 307}], {
             RGBColor[
             0.8573162591850679, 0.8854934184483718, 0.7697010466051234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 329}], {
             RGBColor[
             0.8568877028509152, 0.8865943348811923, 0.8697102915973257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 341}], {
             RGBColor[
             0.8220674037640618, 0.7577333123848975, 0.6149776157294229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 349}], {
             RGBColor[
             0.8289460182361599, 0.8672093830601559, 0.9821173720715861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 366}], {
             RGBColor[
             0.8578985305368295, 0.8867388379931255, 0.8330776898821218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 306}], {
             RGBColor[
             0.9842783870453765, 0.9849209834575224, 0.7471038615816739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 284}], {
             RGBColor[
             0.951579161316271, 0.8413043408613909, 0.3029702152328093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 286}], {
             RGBColor[
             0.9377551704058189, 0.7909270230586043, 0.26877455291583097`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 331}], {
             RGBColor[
             0.9587607127144987, 0.8785752945042713, 0.5787372523641555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 332}], {
             RGBColor[
             0.9346042150613256, 0.7784345351113129, 0.2662392202832238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 338}], {
             RGBColor[
             0.9300013880943621, 0.8571079561157551, 0.6286452767414954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 264}], {
             RGBColor[
             0.9632549889619111, 0.8960096376391379, 0.5804745541262204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 312}], {
             RGBColor[
             0.9679452135433166, 0.8976231274134939, 0.47904582882287555`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 348}], {
             RGBColor[
             0.96336188246299, 0.8960538408488716, 0.57870305218183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 307}], {
             RGBColor[
             0.989662020553359, 0.988714858581542, 0.7280836460043785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 312}], {
             RGBColor[
             0.9902138413854958, 0.9898951475438383, 0.7881459381390564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 348}], {
             RGBColor[
             0.9856305103051692, 0.988325860979216, 0.8878031614980109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 357}], {
             RGBColor[
             0.9889462049410169, 0.9896969859206045, 0.8328535206393578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 366}], {
             RGBColor[
             0.9902442919051205, 0.9899602781262957, 0.7914602892813769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 291}], {
             RGBColor[
             0.954357549430789, 0.8912416484369863, 0.6067201475314308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 304}], {
             RGBColor[
             0.9730400072694811, 0.9583882748755452, 0.6578080793853152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 378}], {
             RGBColor[
             0.9631945000141574, 0.9251770670683014, 0.6195601428664193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 383}], {
             RGBColor[
             0.9455494100723406, 0.8563203110191824, 0.5996329118500197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 293}], {
             RGBColor[
             0.9745566655111082, 0.925281992474737, 0.3987598678659042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 315}], {
             RGBColor[
             0.9441548347327264, 0.8162995595530758, 0.2739238730526894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 316}], {
             RGBColor[
             0.9477641722912262, 0.8306093802320855, 0.2768280307742997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 338}], {
             RGBColor[
             0.9417913496800945, 0.9038512250313866, 0.6381317565793428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 397}], {
             RGBColor[
             0.9470319092237558, 0.9079636101244362, 0.6363331222505634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 282}], {
             RGBColor[
             0.9506106534784754, 0.8289273686290108, 0.4633230628026921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 332}], {
             RGBColor[
             0.9659327904933741, 0.8896745360935998, 0.47565161390166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 367}], {
             RGBColor[
             0.9810077241286221, 0.9832275831018114, 0.8118206204641185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 383}], {
             RGBColor[
             0.9596321531471993, 0.8646946085789484, 0.4705819731979611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 398}], {
             RGBColor[
             0.9734431273208464, 0.9775859191884628, 0.8246255096968547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 270}], {
             RGBColor[
             0.9833831486680729, 0.9858289148723187, 0.8548472357632989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 274}], {
             RGBColor[
             0.9927700839519419, 0.9897670213482382, 0.6596309866980661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 295}], {
             RGBColor[
             0.9268557878309867, 0.9417627132432057, 0.8843752207704405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 324}], {
             RGBColor[
             0.9669853666804649, 0.9735994759148643, 0.8826044034418257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 351}], {
             RGBColor[
             0.988504188116855, 0.9895142006044993, 0.8401788833185949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 373}], {
             RGBColor[
             0.9933772662799611, 0.9910657229523212, 0.7257190360079908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 272}], {
             RGBColor[
             0.9838649720421087, 0.9872208848167285, 0.9002747750851716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 350}], {
             RGBColor[
             0.9797645745285978, 0.9841628150649369, 0.9072156785205963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 355}], {
             RGBColor[
             0.9897140577913228, 0.98859255262017, 0.7167667171535964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 392}], {
             RGBColor[
             0.58236070424194, 0.646893818544052, 0.9092939722609422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 395}], {
             RGBColor[
             0.960020231134533, 0.9694000486077929, 0.9393386806074275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 295}], {
             RGBColor[
             0.9182289889510391, 0.9366277058923302, 0.9571430796041336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 310}], {
             RGBColor[
             0.9726124105248299, 0.9463696340666082, 0.6336955556598267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 324}], {
             RGBColor[
             0.9583585678005173, 0.9684644685639889, 0.9553722622755187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 346}], {
             RGBColor[
             0.9740522952457971, 0.9801688247965582, 0.9288068752903202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 351}], {
             RGBColor[
             0.9798773892369075, 0.9843791932536239, 0.912946742152288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 373}], {
             RGBColor[
             0.9847504674000136, 0.9859307156014457, 0.7984868948416839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 390}], {
             RGBColor[
             0.984879365780993, 0.9862064162047351, 0.8125166881426864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 287}], {
             RGBColor[
             0.9776769984353306, 0.9353318902364134, 0.4553231731847923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 292}], {
             RGBColor[
             0.9728784294291981, 0.934305879016557, 0.6045076551259221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 371}], {
             RGBColor[
             0.977825201978826, 0.9356488826302735, 0.47145421428802614`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 374}], {
             RGBColor[
             0.9754687930783343, 0.9289126202312354, 0.3592013227493882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 382}], {
             RGBColor[
             0.9767758228607104, 0.93591755135893, 0.5399177598348817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 384}], {
             RGBColor[
             0.9769915599182439, 0.9338658065568297, 0.38071742063609504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 389}], {
             RGBColor[
             0.9763170878561644, 0.9357278526455983, 0.5475201860283452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 391}], {
             RGBColor[
             0.9755398009087802, 0.9291521463167607, 0.35947717476196667`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 350}], {
             RGBColor[
             0.9778351380868264, 0.9829900627935613, 0.9224035090838834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 392}], {
             RGBColor[
             0.5804312678001686, 0.6457210662726764, 0.9244818028242294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 395}], {
             RGBColor[
             0.9580907946927617, 0.9682272963364174, 0.9545265111707146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 322}], {
             RGBColor[
             0.9656991314443383, 0.9035308448282572, 0.5718273326058538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 330}], {
             RGBColor[
             0.9682267835405246, 0.9011390930660392, 0.348485844453423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 295}], {
             RGBColor[
             0.927615924234908, 0.9405658123682499, 0.7619268305389006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 296}], {
             RGBColor[
             0.9936919630659933, 0.990148242053111, 0.6443530640315649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 319}], {
             RGBColor[
             0.9921570185927164, 0.9895135030671374, 0.6697910662627224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 324}], {
             RGBColor[
             0.9677455030843862, 0.9724025750399085, 0.7601560132102858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 351}], {
             RGBColor[
             0.9892643245207764, 0.9883172997295435, 0.7177304930870552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 373}], {
             RGBColor[
             0.9941374026838826, 0.9898688220773653, 0.6032706457764512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 276}], {
             RGBColor[
             0.9512280255211333, 0.9605419935554731, 0.8572827451792804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 280}], {
             RGBColor[
             0.9383076563283723, 0.9527759703734436, 0.9638455257954586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 288}], {
             RGBColor[
             0.9434855672062723, 0.9566376478281307, 0.9550806732946171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 290}], {
             RGBColor[
             0.8873039739632513, 0.7098011103420737, 0.60103750206334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 297}], {
             RGBColor[
             0.9404483395274013, 0.9258703119468927, 0.6716381881324999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 318}], {
             RGBColor[
             0.9463476997042595, 0.9585579312046544, 0.9406394696589564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 325}], {
             RGBColor[
             0.948563875397817, 0.9594743768070579, 0.9039117031378632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 339}], {
             RGBColor[
             0.9225761111377226, 0.8602530063839475, 0.6299671165314085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 288}], {
             RGBColor[
             0.9875000397462026, 0.9883281636195311, 0.8213513858398092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 290}], {
             RGBColor[
             0.9313184465031816, 0.7414916261334742, 0.467308214608532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 297}], {
             RGBColor[
             0.9844628120673314, 0.9575608277382932, 0.5379089006776918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 318}], {
             RGBColor[
             0.9903621722441897, 0.990248446996055, 0.8069101822041485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 278}], {
             RGBColor[
             0.9516582327176193, 0.9216858786550485, 0.6499409909033622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 302}], {
             RGBColor[
             0.9687225410524383, 0.9061559280525844, 0.33299340755157797`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 314}], {
             RGBColor[
             0.9781762560833676, 0.9400366008025802, 0.5411768512014565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 352}], {
             RGBColor[
             0.9640151457367734, 0.8902767783038648, 0.31470606566723386`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 378}], {
             RGBColor[
             0.9616291066842326, 0.882228108311033, 0.3054367545137796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 379}], {
             RGBColor[
             0.9787217348506241, 0.9390427925286449, 0.4435009654566403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 314}], {
             RGBColor[
             0.9662595535695063, 0.9729306345544589, 0.8781219111238693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 319}], {
             RGBColor[
             0.9652626735166638, 0.9725183990339599, 0.8946427934423469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 352}], {
             RGBColor[
             0.9520984432229123, 0.9231708120557435, 0.6516511255896467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 379}], {
             RGBColor[
             0.966805032336763, 0.9719368262805237, 0.780446025379053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.9189805140052199, 0.6998610869467218, 0.2800583205183801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 288}], {
             RGBColor[
             0.9766203343127169, 0.9533190929549806, 0.6353182721566722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 309}], {
             RGBColor[
             0.9796570020889765, 0.9430404326623723, 0.3754717238788265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 325}], {
             RGBColor[
             0.9816986425042615, 0.9561558219339079, 0.5841493019999182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 399}], {
             RGBColor[
             0.9816820246091144, 0.9561489500072042, 0.5844247035282397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 297}], {
             RGBColor[
             0.9715424428745705, 0.9497948045562639, 0.64447168129387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 309}], {
             RGBColor[
             0.9776163383297013, 0.9702834801448933, 0.6680676181781415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 322}], {
             RGBColor[
             0.9780734787570561, 0.9827436379516277, 0.9030044616537574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 325}], {
             RGBColor[
             0.9796579787449862, 0.9833988694164291, 0.8767451962992333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 339}], {
             RGBColor[
             0.9536702144848919, 0.8841774989933187, 0.6028006096927787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 355}], {
             RGBColor[
             0.9915518991444447, 0.9893525472500543, 0.6863089297514087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 386}], {
             RGBColor[
             0.9898978319890598, 0.9900905081606699, 0.8170825977214335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 367}], {
             RGBColor[
             0.9367471695660502, 0.8207165941935839, 0.592002852884699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 383}], {
             RGBColor[
             0.9153715985846274, 0.7021836196707208, 0.25076420561854157`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 398}], {
             RGBColor[
             0.9291825727582745, 0.8150749302802353, 0.6048077421174352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 294}], {
             RGBColor[
             0.9591818977891151, 0.966548134296815, 0.8307991904193713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 320}], {
             RGBColor[
             0.993270993461838, 0.9875821011180101, 0.5458340971461861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 347}], {
             RGBColor[
             0.9947415474745656, 0.9916272138554743, 0.702914963048187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 373}], {
             RGBColor[
             0.9947430349523174, 0.991164208260732, 0.6691899806664618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 380}], {
             RGBColor[
             0.9949239545374338, 0.991702643863618, 0.6998920059621132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 381}], {
             RGBColor[
             0.9945826677853682, 0.9908211991062357, 0.6517350042154848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 332}], {
             RGBColor[
             0.9539693192006462, 0.8507805204000394, 0.30489339237079394`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 338}], {
             RGBColor[
             0.9493664922336826, 0.9294539414044816, 0.6672994488290656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 367}], {
             RGBColor[
             0.9690442528358942, 0.9443335674082509, 0.6410623989332525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 399}], {
             RGBColor[
             0.927179451420242, 0.7337956689361533, 0.5129957936884211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 332}], {
             RGBColor[
             0.9401453282901941, 0.8004032025972527, 0.2706977300538156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 292}], {
             RGBColor[
             0.9893725752210516, 0.9889149806068374, 0.7561276864772654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 371}], {
             RGBColor[
             0.9943193477706795, 0.9902579842205537, 0.6230742456393694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 374}], {
             RGBColor[
             0.9919629388701878, 0.9835217218215155, 0.5108213541007315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 382}], {
             RGBColor[
             0.9932699686525639, 0.9905266529492102, 0.691537791186225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 384}], {
             RGBColor[
             0.9934857057100973, 0.9884749081471098, 0.5323374519874383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 389}], {
             RGBColor[
             0.9928112336480178, 0.9903369542358785, 0.6991402173796885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 391}], {
             RGBColor[
             0.9920339467006336, 0.9837612479070408, 0.51109720611331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 303}], {
             RGBColor[
             0.96828575400396, 0.9758681477802409, 0.9385681254579203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 376}], {
             RGBColor[
             0.9732225344284007, 0.9768066072678996, 0.7762176334672444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 297}], {
             RGBColor[
             0.9205387605094495, 0.7068199445248939, 0.2816636575617515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 318}], {
             RGBColor[
             0.9264381206863077, 0.7395075637826556, 0.5506649390882081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 345}], {
             RGBColor[
             0.900820224365243, 0.7205786015237784, 0.6023266940927812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 304}], {
             RGBColor[
             0.96069183480894, 0.874940160894825, 0.32328551923051735`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 383}], {
             RGBColor[
             0.9332012376117995, 0.7728721970384621, 0.26511035169522174`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 371}], {
             RGBColor[
             0.989520778764547, 0.9892319730006973, 0.7722587275804993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 374}], {
             RGBColor[
             0.9871643698640554, 0.9824957106016593, 0.6600058360418612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 382}], {
             RGBColor[
             0.9884713996464314, 0.9895006417293539, 0.8407222731273547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 384}], {
             RGBColor[
             0.9886871367039649, 0.9874488969272536, 0.6815219339285681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 389}], {
             RGBColor[
             0.9880126646418854, 0.9893109430160223, 0.8483246993208182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 316}], {
             RGBColor[
             0.9665268574539191, 0.893446479302895, 0.39229889581926997`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 387}], {
             RGBColor[
             0.9889466784443601, 0.9880040304662637, 0.7097714506646349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 320}], {
             RGBColor[
             0.9577114063582203, 0.9629693425748094, 0.7076120213190097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 347}], {
             RGBColor[
             0.9591819603709477, 0.9670144553122734, 0.8646928872210106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 380}], {
             RGBColor[
             0.959364367433816, 0.9670898853204171, 0.8616699301349366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 381}], {
             RGBColor[
             0.9590230806817505, 0.9662084405630349, 0.8135129283883084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 310}], {
             RGBColor[
             0.9160850496877435, 0.9023034324374952, 0.6632235406669683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 324}], {
             RGBColor[
             0.901831206963431, 0.9243982669348759, 0.9849002472826602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 351}], {
             RGBColor[
             0.9233500283998212, 0.940312991624511, 0.9424747271594296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 373}], {
             RGBColor[
             0.9282231065629274, 0.9418645139723327, 0.8280148798488255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 390}], {
             RGBColor[
             0.9283520049439067, 0.9421402145756221, 0.842044673149828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 308}], {
             RGBColor[
             0.9879242174385112, 0.9713262492154658, 0.5680384417370229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 373}], {
             RGBColor[
             0.9942991453940124, 0.991446943657194, 0.7104411133414897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 380}], {
             RGBColor[
             0.994480064979129, 0.9919853792600799, 0.741143138637141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 318}], {
             RGBColor[
             0.9795824862504576, 0.9555767653874747, 0.6212656251573679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 322}], {
             RGBColor[
             0.980214161956085, 0.9558379795250767, 0.6107971239907988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 339}], {
             RGBColor[
             0.9558108976839208, 0.8572718405667676, 0.31059327202982007`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 313}], {
             RGBColor[
             0.9897419623111894, 0.9858948230082665, 0.6334155308356548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 361}], {
             RGBColor[
             0.9909764830428902, 0.9892584226011083, 0.706299600832968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 393}], {
             RGBColor[
             0.9740213493666725, 0.9794877555263422, 0.8993931272235629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 396}], {
             RGBColor[
             0.9906491194909863, 0.9885582250651183, 0.6706680984618986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 306}], {
             RGBColor[
             0.9844461878895043, 0.9852798924958439, 0.765367947918209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 342}], {
             RGBColor[
             0.9938383552285336, 0.9892291898087096, 0.5707211757686768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 353}], {
             RGBColor[
             0.9941381861057681, 0.9898704977375623, 0.6033559164139641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 319}], {
             RGBColor[
             0.9896439515571939, 0.9899855220776638, 0.8212900534989473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 343}], {
             RGBColor[
             0.9021828383352042, 0.5615192410825289, 0.5142758099524642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 358}], {
             RGBColor[
             0.9899516876924341, 0.9880205039754313, 0.6641037710992319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 359}], {
             RGBColor[
             0.9761969649553894, 0.9812940504435836, 0.9039379303359313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 362}], {
             RGBColor[
             0.9898542136280164, 0.9878120168077813, 0.6534943207275558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 369}], {
             RGBColor[
             0.9553344936779528, 0.9654234289593361, 0.9284553672485618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 394}], {
             RGBColor[
             0.9894235893506758, 0.9864573957805313, 0.6434902739753765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 397}], {
             RGBColor[
             0.9626582573847522, 0.9711969045050015, 0.9268554307925607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 314}], {
             RGBColor[
             0.9833238619043252, 0.9574006839519948, 0.5611743277720851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 352}], {
             RGBColor[
             0.9691627515577312, 0.9076408614532794, 0.3347035422378625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 377}], {
             RGBColor[
             0.9842588356751901, 0.9572399661067919, 0.5058925694854908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 379}], {
             RGBColor[
             0.9838693406715819, 0.9564068756780595, 0.4634984420272689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 376}], {
             RGBColor[
             0.9890518005657566, 0.9886120480350951, 0.7494228148305133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 383}], {
             RGBColor[
             0.9518836954504917, 0.8400188234770212, 0.3161982835491062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 334}], {
             RGBColor[
             0.9550711770440554, 0.966012737920428, 0.9609369573373818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 340}], {
             RGBColor[
             0.9742796340373252, 0.9549521465206872, 0.6464529012344074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 360}], {
             RGBColor[
             0.9678583714395956, 0.9332917199943886, 0.6215075085959207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 370}], {
             RGBColor[
             0.9742136201582411, 0.9547294662057406, 0.6461964497798407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 342}], {
             RGBColor[
             0.9841485171271547, 0.9846432048343088, 0.7329683224474597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 353}], {
             RGBColor[
             0.9844483480043892, 0.9852845127631615, 0.7656030630927472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 361}], {
             RGBColor[
             0.9842783870453765, 0.9849209834575224, 0.7471038615816739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 312}], {
             RGBColor[
             0.9943522451347645, 0.990328348355898, 0.6266549207010337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 341}], {
             RGBColor[
             0.9585515688816215, 0.8613879533301273, 0.4118691976906551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 348}], {
             RGBColor[
             0.9897689140544379, 0.9887590617912758, 0.7263121440599881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 366}], {
             RGBColor[
             0.9943826956543892, 0.9903934789383553, 0.629969271843354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 325}], {
             RGBColor[
             0.9878725573991459, 0.9769818865785076, 0.6081337955205461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 339}], {
             RGBColor[
             0.9618847931390515, 0.8777605161553972, 0.33418920891409154`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 323}], {
             RGBColor[
             0.9757188871285454, 0.9297562461874722, 0.36017289090815896`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 324}], {
             RGBColor[
             0.9562146285372217, 0.9341401951091539, 0.6614527233383535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 346}], {
             RGBColor[
             0.9719083559825015, 0.9458445513417232, 0.6348873363531551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 389}], {
             RGBColor[
             0.9809598971651929, 0.9513891386284183, 0.5655566234729514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 390}], {
             RGBColor[
             0.9827354265176975, 0.9518821427499001, 0.5185971492055212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 313}], {
             RGBColor[
             0.9698349456540161, 0.9717061924643291, 0.6965790488229069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 361}], {
             RGBColor[
             0.9710694663857169, 0.9750697920571707, 0.7694631188202201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 386}], {
             RGBColor[
             0.969332040628401, 0.9756294573471035, 0.8911637173997213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 348}], {
             RGBColor[
             0.9903207348865748, 0.9899393507535721, 0.7863744361946661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 366}], {
             RGBColor[
             0.9949345164865261, 0.9915737679006518, 0.6900315639780321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 361}], {
             RGBColor[
             0.9925659035709269, 0.9857844598007599, 0.4937085585690424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 393}], {
             RGBColor[
             0.9756107698947092, 0.9760137927259938, 0.6868020849596372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 396}], {
             RGBColor[
             0.9922385400190231, 0.98508426226477, 0.45807705619797284`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 352}], {
             RGBColor[
             0.9786164665886604, 0.9415215342032752, 0.542886985887741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 379}], {
             RGBColor[
             0.9933230557025111, 0.9902875484280553, 0.6716818856771474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 316}], {
             RGBColor[
             0.9361250266755373, 0.7844640463812338, 0.2674629010060551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 358}], {
             RGBColor[
             0.9626861939157487, 0.8786418757440142, 0.3642163327889899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 359}], {
             RGBColor[
             0.948931471178704, 0.8719154222121667, 0.6040504920256893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 362}], {
             RGBColor[
             0.962588719851331, 0.8784333885763643, 0.3536068824173138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 363}], {
             RGBColor[
             0.9623496710478636, 0.877724996606549, 0.34434707020513944`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 369}], {
             RGBColor[
             0.9280689999012675, 0.8560448007279191, 0.6285679289383199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 397}], {
             RGBColor[
             0.9353927636080668, 0.8618182762735844, 0.6269679924823188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 358}], {
             RGBColor[
             0.9662955314742485, 0.892951696423024, 0.36712049051060025`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 359}], {
             RGBColor[
             0.9525408087372038, 0.8862252428911764, 0.6069546497472997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 362}], {
             RGBColor[
             0.9661980574098308, 0.8927432092553741, 0.3565110401389241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 363}], {
             RGBColor[
             0.9659590086063634, 0.8920348172855588, 0.3472512279267498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 369}], {
             RGBColor[
             0.9316783374597672, 0.8703546214069289, 0.6314720866599302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 397}], {
             RGBColor[
             0.9390021011665666, 0.8761280969525942, 0.6298721502039291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 326}], {
             RGBColor[
             0.9772933820960681, 0.9473488667992195, 0.6088739639896246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 327}], {
             RGBColor[
             0.9818627038426095, 0.949238398767627, 0.5331484776238127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 336}], {
             RGBColor[
             0.9639672504276573, 0.9376813801084587, 0.6435729582768177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 396}], {
             RGBColor[
             0.9809542728466347, 0.9470197794203733, 0.41423980908829283`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 345}], {
             RGBColor[
             0.959863950106251, 0.9693354223863591, 0.9419286616883975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 347}], {
             RGBColor[
             0.9932710560436707, 0.9880484221334686, 0.5797277939478254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 380}], {
             RGBColor[
             0.993453463106539, 0.9881238521416122, 0.5767048368617516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 381}], {
             RGBColor[
             0.9931121763544735, 0.9872424073842301, 0.5285478351151232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 384}], {
             RGBColor[
             0.9923003846119769, 0.9855060669317653, 0.44018931374228276`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 341}], {
             RGBColor[
             0.9093606107759419, 0.6758147713923282, 0.24579637262520732`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 366}], {
             RGBColor[
             0.9451917375487096, 0.8048202970005561, 0.4638964467779062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 330}], {
             RGBColor[
             0.989272849934757, 0.9863950611582225, 0.6459884161982552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 339}], {
             RGBColor[
             0.9623419335664063, 0.8902206739621314, 0.5691260523897074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 346}], {
             RGBColor[
             0.9771587718495125, 0.9635554369174222, 0.6552842105386525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 346}], {
             RGBColor[
             0.9576545132581888, 0.9679393858391039, 0.956564042968847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 351}], {
             RGBColor[
             0.9634796072492994, 0.9721497542961696, 0.9407039098308148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 390}], {
             RGBColor[
             0.9684815837933849, 0.9739769772472808, 0.8402738558212132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 339}], {
             RGBColor[
             0.9639264335543365, 0.8908759054269328, 0.5428667870351833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 327}], {
             RGBColor[
             0.9903932374442285, 0.9902953710477216, 0.8088724472610682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 336}], {
             RGBColor[
             0.9724977840292761, 0.9787383523885533, 0.9192969279140732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 336}], {
             RGBColor[
             0.9770671057758176, 0.9806278843569608, 0.8435714415482614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 376}], {
             RGBColor[
             0.9944755700904836, 0.9908677052694415, 0.6601096418675468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 364}], {
             RGBColor[
             0.9936560087664539, 0.9888391691643764, 0.5508738886832231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 386}], {
             RGBColor[
             0.9922987286157491, 0.9902119274682336, 0.713950990555595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 400}], {
             RGBColor[
             0.9803551626872997, 0.9443037934870446, 0.47101413264105757`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 349}], {
             RGBColor[
             0.9650016270195668, 0.9719649404382062, 0.8790181990250207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 335}], {
             RGBColor[
             0.9898335385650443, 0.9892682729919728, 0.7603128823394644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 338}], {
             RGBColor[
             0.9565480436319103, 0.9667248950473619, 0.9430664859604119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 368}], {
             RGBColor[
             0.9331323314383974, 0.8172055999181781, 0.5974894704454367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 340}], {
             RGBColor[
             0.9568465241855144, 0.9419505617373043, 0.6759626089302755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 360}], {
             RGBColor[
             0.9504252615877848, 0.9202901352110058, 0.6510172162917889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 365}], {
             RGBColor[
             0.9599726302013583, 0.9696682336597514, 0.9526400756457901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 370}], {
             RGBColor[
             0.9567805103064304, 0.9417278814223577, 0.6757061574757088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 394}], {
             RGBColor[
             0.9930801054544924, 0.987173810972036, 0.5250571155708407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 396}], {
             RGBColor[
             0.9761586747798427, 0.9784092650097072, 0.7246627730127415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 367}], {
             RGBColor[
             0.9806564301511096, 0.9824762008051815, 0.773584438947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 398}], {
             RGBColor[
             0.9730918333433338, 0.9768345368918327, 0.7863893281797363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 399}], {
             RGBColor[
             0.9920247910550795, 0.9900095624703071, 0.7120153220230777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 360}], {
             RGBColor[
             0.9696337185810546, 0.909229543811265, 0.3365331601888143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 370}], {
             RGBColor[
             0.9759889672997, 0.9306672900226169, 0.36122210137273436`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 348}], {
             RGBColor[
             0.9545200586334317, 0.8609989557278015, 0.5715887131842876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 366}], {
             RGBColor[
             0.9591338402333831, 0.862633372874881, 0.47524584096765354`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 353}], {
             RGBColor[
             0.9938405153434184, 0.9892338100760272, 0.5709562909432149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 358}], {
             RGBColor[
             0.9050878493572301, 0.5606282628929022, 0.3140459611467675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 359}], {
             RGBColor[
             0.8913331266201854, 0.5539018093610546, 0.553880120383467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 362}], {
             RGBColor[
             0.9049903752928123, 0.5604197757252523, 0.3034365107750914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 369}], {
             RGBColor[
             0.8704706553427486, 0.5380311878768071, 0.5783975572960974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 354}], {
             RGBColor[
             0.9222960260947337, 0.7252404883273477, 0.2561083527462102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 356}], {
             RGBColor[
             0.9394672848392507, 0.7894092675657983, 0.5224790025968525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 388}], {
             RGBColor[
             0.9407700318110754, 0.7876126365207363, 0.3311337932241498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 390}], {
             RGBColor[
             0.9841753112386646, 0.9856813334798501, 0.8137084688360148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 380}], {
             RGBColor[
             0.9949240171192665, 0.9921689648790764, 0.7337857027637524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 381}], {
             RGBColor[
             0.9945827303672009, 0.991287520121694, 0.685628701017124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 384}], {
             RGBColor[
             0.9937709386247044, 0.9895511796692293, 0.5972701796442836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 366}], {
             RGBColor[
             0.9903511854061995, 0.9900044813360295, 0.7896887873369866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 355}], {
             RGBColor[
             0.9836842238360407, 0.9843617305970028, 0.7388954511523083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 392}], {
             RGBColor[
             0.5763308702866579, 0.6426629965208849, 0.9314227062596541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 395}], {
             RGBColor[
             0.9539903971792509, 0.9651692265846258, 0.9614674146061393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 379}], {
             RGBColor[
             0.979161945355917, 0.9405277259293399, 0.4452111001429248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 371}], {
             RGBColor[
             0.9750472364464344, 0.9261787688327148, 0.4611799350780229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 388}], {
             RGBColor[
             0.9741009272950355, 0.9241547092444042, 0.35818002389138215`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 392}], {
             RGBColor[
             0.5862803535493829, 0.647092734076118, 0.7409737448926542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 395}], {
             RGBColor[
             0.963939880441976, 0.9695989641398589, 0.7710184532391395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 363}], {
             RGBColor[
             0.9910765460232087, 0.9877079435193955, 0.6200156401202807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 372}], {
             RGBColor[
             0.9918631710282131, 0.989587545615852, 0.6888757426211589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 364}], {
             RGBColor[
             0.9927044630836747, 0.9893170937187397, 0.6299859999084645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 385}], {
             RGBColor[
             0.9633690361390309, 0.9708085154001053, 0.884867273939683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 359}], {
             RGBColor[
             0.9791019759774153, 0.980403072253957, 0.7037080815302346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 362}], {
             RGBColor[
             0.9927592246500423, 0.9869210386181546, 0.4532644719218589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 363}], {
             RGBColor[
             0.9925201758465749, 0.9862126466483392, 0.4440046597096846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 369}], {
             RGBColor[
             0.9582395046999787, 0.9645324507697093, 0.728225518442865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 372}], {
             RGBColor[
             0.9933068008515793, 0.9880922487447958, 0.5128647622105629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 397}], {
             RGBColor[
             0.9655632684067781, 0.9703059263153747, 0.7266255819868639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 362}], {
             RGBColor[
             0.9790045019129976, 0.980194585086307, 0.6930986311585584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 369}], {
             RGBColor[
             0.944484781962934, 0.9578059972378618, 0.9680596776795645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 394}], {
             RGBColor[
             0.978573877635657, 0.9788399640590569, 0.6830945844063792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 397}], {
             RGBColor[
             0.9518085456697334, 0.9635794727835272, 0.9664597412235634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 370}], {
             RGBColor[
             0.9695677047019705, 0.9090068634963184, 0.33627670873424775`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 393}], {
             RGBColor[
             0.9768452906264099, 0.9793773923188355, 0.7596861549569505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 396}], {
             RGBColor[
             0.9934730607507238, 0.9884478618576116, 0.530961126195286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 363}], {
             RGBColor[
             0.9924227017821572, 0.9860041594806893, 0.43339520933800846`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 369}], {
             RGBColor[
             0.9581420306355609, 0.9643239636020594, 0.7176160680711889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 397}], {
             RGBColor[
             0.9654657943423604, 0.9700974391477248, 0.7160161316151878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 369}], {
             RGBColor[
             0.9579029818320934, 0.9636155716322441, 0.7083562558590144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 372}], {
             RGBColor[
             0.9929702779836942, 0.9871753696073305, 0.4929954996267124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 385}], {
             RGBColor[
             0.9637047061447619, 0.9690132950471182, 0.738720896011833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 370}], {
             RGBColor[
             0.9791150733155438, 0.9583849619450641, 0.637899568088249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 398}], {
             RGBColor[
             0.9595796434084212, 0.9693751447530358, 0.9533052997788616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 372}], {
             RGBColor[
             0.9586896068370979, 0.9654951737287006, 0.7772163583598928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 389}], {
             RGBColor[
             0.9929594371915134, 0.9906539466297386, 0.7152712584829224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 391}], {
             RGBColor[
             0.9921821502441291, 0.984078240300901, 0.5272282472165438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 380}], {
             RGBColor[
             0.9949255045970183, 0.9917059592843341, 0.7000607203820273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 382}], {
             RGBColor[
             0.9910617632955676, 0.9841073829440321, 0.5954159407508209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 384}], {
             RGBColor[
             0.9912775003531011, 0.9820556381419319, 0.4362156015520342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 389}], {
             RGBColor[
             0.9906030282910216, 0.9839176842307005, 0.6030183669442843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 377}], {
             RGBColor[
             0.9775718080177825, 0.9346830516295959, 0.4799147297756752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 379}], {
             RGBColor[
             0.9767759063033763, 0.9324790559365081, 0.43594178898947056`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 381}], {
             RGBColor[
             0.9947651374300692, 0.9913629501298378, 0.6826057439310502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 384}], {
             RGBColor[
             0.9925845301354772, 0.9890605692696264, 0.6169320386375277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 389}], {
             RGBColor[
             0.9919100580733977, 0.9909226153583951, 0.7837348040297778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 389}], {
             RGBColor[
             0.9921257951309311, 0.9888708705562947, 0.6245344648309912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 387}], {
             RGBColor[
             0.9594716427075187, 0.9691968430577325, 0.9494571692307233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 400}], {
             RGBColor[
             0.9783820068595466, 0.9443592559922781, 0.5670569678108208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 390}], {
             RGBColor[
             0.9932268524213561, 0.9912259207665453, 0.7443777559558111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 395}], {
             RGBColor[
             0.5565865268925931, 0.6279002300637408, 0.9635457083464853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 396}], {
             RGBColor[
             0.9765179270745061, 0.9786771947828454, 0.7240546525858809]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.0002105009621202394], {
             RGBColor[
             0.9712506312641096, 0.9146837699603618, 0.34281456063414406`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.0002105009621202394], {
             RGBColor[
             0.979084294253665, 0.983921681417484, 0.9202890135255325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.0002105009621202394], {
             RGBColor[
             0.9778376001326536, 0.982991898983308, 0.9223993414825024]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.0002105009621202394], {
             RGBColor[
             0.9949564252678265, 0.9921823664813573, 0.7332486158725127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.0002105009621202394], {
             RGBColor[
             0.9773461096791001, 0.9826253462077895, 0.9232313066191282]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.0002105009621202394], {
             RGBColor[
             0.9948870059936935, 0.9914721477605305, 0.6848603400339829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.0002105009621202394], {
             RGBColor[
             0.8917833417618298, 0.6014952542306892, 0.2314137065440959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.0002105009621202394], {
             RGBColor[
             0.9856448762693298, 0.988331801674585, 0.8875650802939457]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.0002105009621202394], {
             RGBColor[
             0.8394767073290332, 0.8748399557087261, 0.9845512318263885]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.0002105009621202394], {
             RGBColor[
             0.9691081364994101, 0.9764814792988198, 0.9371760464048301]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.0002105009621202394], {
             RGBColor[
             0.994140346220653, 0.9898751180048799, 0.6035910315885024]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.0002105009621202394], {
             RGBColor[
             0.992993294708775, 0.9874216908056707, 0.4787415533019541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.0002105009621202394], {
             RGBColor[
             0.9944402362149154, 0.991968909042525, 0.7418032043336972]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.0002105009621202394], {
             RGBColor[
             0.927819586835325, 0.7515357450385517, 0.2607801491568909]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.0002105009621202394], {
             RGBColor[
             0.9938294178091519, 0.9917163199344248, 0.7519260460645596]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.0002105009621202394], {
             RGBColor[
             0.8486249355530403, 0.8821345045725093, 0.985423798001114]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.0002105009621202394], {
             RGBColor[
             0.9831942668651775, 0.9549724573417638, 0.3892133295779642]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.0002105009621202394], {
             RGBColor[
             0.9757746497882354, 0.9299443467323018, 0.36038951831116]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.0002105009621202394], {
             RGBColor[
             0.9685246817714748, 0.9760463397180451, 0.9381636830698599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.0002105009621202394], {
             RGBColor[
             0.5259838136397934, 0.6260563810703836, 0.9558265190333706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.0002105009621202394], {
             RGBColor[
             0.9932998029540753, 0.9880772809496307, 0.5121030842532648]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.0002105009621202394], {
             RGBColor[
             0.9937026126519534, 0.9889388501630841, 0.5559464340139961]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.0002105009621202394], {
             RGBColor[
             0.9738167276834628, 0.9799931388942759, 0.929205629727492]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.0002105009621202394], {
             RGBColor[
             0.9947501024963274, 0.9911793250227314, 0.6699592392161378]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.0002105009621202394], {
             RGBColor[
             0.9939055100943244, 0.9893728272762375, 0.5780305684782139]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.0002105009621202394], {
             RGBColor[
             0.9510179452969362, 0.9629898443199842, 0.9677980214331078]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.0002105009621202394], {
             RGBColor[
             0.9937815360608907, 0.9891076593544206, 0.5645367600180095]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.0002105009621202394], {
             RGBColor[
             0.9611828526434771, 0.8807227886461332, 0.303703141833449]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.0002105009621202394], {
             RGBColor[
             0.9948550290767583, 0.9921404365505874, 0.7349290131634435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.0002105009621202394], {
             RGBColor[
             0.9932679075479811, 0.9914841210112751, 0.7612317242341349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.0002105009621202394], {
             RGBColor[
             0.9873643008652225, 0.9890428279321831, 0.8590697650117892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.0002105009621202394], {
             RGBColor[
             0.9846877623680699, 0.9879360104797086, 0.9034269345692009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.0002105009621202394], {
             RGBColor[
             0.9917651172388636, 0.9838839481835757, 0.42250946481045243`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.0002105009621202394], {
             RGBColor[
             0.9873840586676792, 0.9890509982912513, 0.8587423270935286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.0002105009621202394], {
             RGBColor[
             0.9890957176060038, 0.9748794364170996, 0.41213935131061424`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.0002105009621202394], {
             RGBColor[
             0.993684203725647, 0.9888994753311428, 0.5539427359922721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.0002105009621202394], {
             RGBColor[
             0.9856800612332861, 0.9633576254376677, 0.39887017129518854`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.0002105009621202394], {
             RGBColor[
             0.9890876453135512, 0.9897554751494991, 0.8305094876305164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.0002105009621202394], {
             RGBColor[
             0.9761283043504456, 0.9311373066126772, 0.36176339950328695`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.0002105009621202394], {
             RGBColor[
             0.9730938926549318, 0.9794540497135312, 0.9304292008852258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.0002105009621202394], {
             RGBColor[
             0.9939168076314786, 0.9893969915658543, 0.5792602356771342]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.0002105009621202394], {
             RGBColor[
             0.9257398581980544, 0.9436238506608312, 0.9927790881642996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.0002105009621202394], {
             RGBColor[
             0.9324875136836944, 0.7700425194979253, 0.2645360726694146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.0002105009621202394], {
             RGBColor[
             0.9671561167199784, 0.9750256661434586, 0.9404803067231117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.0002105009621202394], {
             RGBColor[
             0.9528683034199577, 0.8508455593066345, 0.280934934489833]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.0002105009621202394], {
             RGBColor[
             0.9527858926130138, 0.9643083765335669, 0.9648053477814972]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.0002105009621202394], {
             RGBColor[
             0.9590950299712335, 0.8736800725285796, 0.2955923450040111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.0002105009621202394], {
             RGBColor[
             0.9573119033973987, 0.9676838679658986, 0.9571439920962022]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.0002105009621202394], {
             RGBColor[
             0.9646889805973781, 0.8925497815126333, 0.31732378685764656`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.0002105009621202394], {
             RGBColor[
             0.9932161029993574, 0.9878982552098526, 0.5029928607184674]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.0002105009621202394], {
             RGBColor[
             0.9947738699084593, 0.9921068751488002, 0.7362740306153525]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.0002105009621202394], {
             RGBColor[
             0.981802963563706, 0.9859492605375002, 0.9156870155261506]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.0002105009621202394], {
             RGBColor[
             0.966395384227831, 0.9744583130964003, 0.9417680284015066]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.0002105009621202394], {
             RGBColor[
             0.9926297296346551, 0.9866440618741958, 0.43916973864756403`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.0002105009621202394], {
             RGBColor[
             0.9911076724072313, 0.9816662323910923, 0.4199554157875994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.0002105009621202394], {
             RGBColor[
             0.9940262634677598, 0.9896311065319772, 0.5911738279732239]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.0002105009621202394], {
             RGBColor[
             0.9562935821696698, 0.9669244056616063, 0.9588677443140348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.0002105009621202394], {
             RGBColor[
             0.9930184564014798, 0.9874755091221287, 0.4814802482728976]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.0002105009621202394], {
             RGBColor[
             0.9946417357761907, 0.9909475395659151, 0.6581641904911328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.0002105009621202394], {
             RGBColor[
             0.8665918951819418, 0.4871067789232486, 0.21039334601897663`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.0002105009621202394], {
             RGBColor[
             0.9403408882261085, 0.8011785325766676, 0.27085508216863396`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.0002105009621202394], {
             RGBColor[
             0.994942620119137, 0.9915911007514036, 0.6909135943779103]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.0002105009621202394], {
             RGBColor[
             0.9918624310209864, 0.9909029203482637, 0.7845241075430938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.0002105009621202394], {
             RGBColor[
             0.9720260933553022, 0.9172995856811123, 0.3458270844246991]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.0002105009621202394], {
             RGBColor[
             0.9839067509197774, 0.9573758333571407, 0.3919811955887608]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.0002105009621202394], {
             RGBColor[
             0.9941561393261003, 0.9899088978605037, 0.6053100136526893]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.0002105009621202394], {
             RGBColor[
             0.9695839234810397, 0.9090615732464693, 0.3363397156282721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.0002105009621202394], {
             RGBColor[
             0.9890876453135512, 0.9897554751494991, 0.8305094876305164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.0002105009621202394], {
             RGBColor[
             0.9363397900431316, 0.9520429001649702, 0.9926443096017877]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.0002105009621202394], {
             RGBColor[
             0.9925705952022923, 0.9865175793027798, 0.4327333206202766]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.0002105009621202394], {
             RGBColor[
             0.9853106881990994, 0.988193606319303, 0.8931034414686675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.0002105009621202394], {
             RGBColor[
             0.9468802532697379, 0.9599039603809486, 0.9748020547522382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.0002105009621202394], {
             RGBColor[
             0.9941987239903394, 0.9899999821513413, 0.6099450915530366]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.0002105009621202394], {
             RGBColor[
             0.9933634519416855, 0.9882134196982291, 0.5190308837586193]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.0002105009621202394], {
             RGBColor[
             0.9844395044112356, 0.9878333494346192, 0.9075412113849403]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.0002105009621202394], {
             RGBColor[
             0.9737165363323715, 0.9230018467776533, 0.35239413617724336`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.0002105009621202394], {
             RGBColor[
             0.9874071148606907, 0.9890605326195787, 0.8583602263078138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.0002105009621202394], {
             RGBColor[
             0.9582598087955505, 0.9683908142597876, 0.9555394355104538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.0002105009621202394], {
             RGBColor[
             0.9431093677437673, 0.8121546313230743, 0.2730826657731086]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.0002105009621202394], {
             RGBColor[
             0.9941453973813839, 0.9898859219269326, 0.6041408192619102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.0002105009621202394], {
             RGBColor[
             0.9925752742290713, 0.986527587267938, 0.4332426038095692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.0002105009621202394], {
             RGBColor[
             0.9943294569640032, 0.990279606762877, 0.6241745689459496]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.0002105009621202394], {
             RGBColor[
             0.9755004079475695, 0.9290192646086899, 0.3593241405463997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.0002105009621202394], {
             RGBColor[
             0.985308253324681, 0.9881925994361576, 0.893143793639033]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.0002105009621202394], {
             RGBColor[
             0.9933039628155765, 0.9880861784727553, 0.5125558595059859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.0002105009621202394], {
             RGBColor[
             0.9855178674235497, 0.9628105076325092, 0.39824007897209357`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.0002105009621202394], {
             RGBColor[
             0.9950096597729474, 0.9917344917921552, 0.6982104469743815]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.0002105009621202394], {
             RGBColor[
             0.992586042755603, 0.9865506200573243, 0.4344146914669029]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.0002105009621202394], {
             RGBColor[
             0.979084294253665, 0.983921681417484, 0.9202890135255325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.0002105009621202394], {
             RGBColor[
             0.8666196450265513, 0.8964829974533106, 0.9871401494547642]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.0002105009621202394], {
             RGBColor[
             0.9850756014244958, 0.9880963918965499, 0.896999437708919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.0002105009621202394], {
             RGBColor[
             0.9616288010679848, 0.8822270773956667, 0.3054355672523673]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.0002105009621202394], {
             RGBColor[
             0.9929444436438579, 0.9873172033174133, 0.47342441635956173`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.0002105009621202394], {
             RGBColor[
             0.9925227534979987, 0.9864152507348342, 0.42752604635269276`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.0002105009621202394], {
             RGBColor[
             0.9918005020309433, 0.9840033093960046, 0.4226469280458245]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.0002105009621202394], {
             RGBColor[
             0.9943879107080993, 0.9904046334109183, 0.6305368982561159]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.0002105009621202394], {
             RGBColor[
             0.9911073171182554, 0.9905906613439422, 0.7970382990834843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.0002105009621202394], {
             RGBColor[
             0.9952070062746166, 0.9921565960044336, 0.7196903957996389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.0002105009621202394], {
             RGBColor[
             0.9709871323876397, 0.9137949263775502, 0.3417909172566457]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.0002105009621202394], {
             RGBColor[
             0.9938139884943934, 0.9891770718282382, 0.5680690071315643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.0002105009621202394], {
             RGBColor[
             0.9941844155431551, 0.9899693778296199, 0.6083877053785195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.0002105009621202394], {
             RGBColor[
             0.9700674093145114, 0.9771969033936573, 0.9355522477472833]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.0002105009621202394], {
             RGBColor[
             0.9700001972899439, 0.9771467767757844, 0.9356660201731725]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.0002105009621202394], {
             RGBColor[
             0.9926332574008859, 0.9912216768656865, 0.7717495195934332]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.0002105009621202394], {
             RGBColor[
             0.9946383416272412, 0.9920508307215986, 0.7385200849710855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.0002105009621202394], {
             RGBColor[
             0.9948931172680892, 0.9914852191585181, 0.6855255145375274]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.0002105009621202394], {
             RGBColor[
             0.9368899037517994, 0.7874965291084366, 0.26807833905558803`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.0002105009621202394], {
             RGBColor[
             0.9808826347776741, 0.9471747795135892, 0.3802330754331037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.0002105009621202394], {
             RGBColor[
             0.9933315207072109, 0.9915104266874003, 0.7601774895601182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.0002105009621202394], {
             RGBColor[
             0.9931777292797469, 0.987816177703784, 0.49881611815401405`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.0002105009621202394], {
             RGBColor[
             0.96498035059618, 0.9734029833308199, 0.9441633112400133]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.0002105009621202394], {
             RGBColor[
             0.9949878208333023, 0.9916877805085097, 0.695833413168321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.0002105009621202394], {
             RGBColor[
             0.9870460304795592, 0.9889112149485355, 0.8643443289595867]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.0002105009621202394], {
             RGBColor[
             0.9551841137901912, 0.8600269757265512, 0.28279828987277866`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.0002105009621202394], {
             RGBColor[
             0.9389391223053152, 0.7956209978115245, 0.2697271884050885]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.0002105009621202394], {
             RGBColor[
             0.9796644632363769, 0.984354370494851, 0.9193069387701063]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.0002105009621202394], {
             RGBColor[
             0.992583337861407, 0.9865448345621457, 0.43412028042633266`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.0002105009621202394], {
             RGBColor[
             0.9897023384204393, 0.976925710865531, 0.4144959586239675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.0002105009621202394], {
             RGBColor[
             0.9855421145329705, 0.9882893070557441, 0.8892681082042695]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.0002105009621202394], {
             RGBColor[
             0.9860023406911219, 0.9884796223994126, 0.8816409697365817]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.0002105009621202394], {
             RGBColor[
             0.986909642701601, 0.9888548150973437, 0.8666046274006083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.0002105009621202394], {
             RGBColor[
             0.9930041452979421, 0.9874448991187361, 0.47992257297071517`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.0002105009621202394], {
             RGBColor[
             0.9131383677304433, 0.6933296035139478, 0.24896729565259962`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.0002105009621202394], {
             RGBColor[
             0.96498035059618, 0.9734029833308199, 0.9441633112400133]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.0002105009621202394], {
             RGBColor[
             0.986159091273223, 0.9885444427934176, 0.8790432069336647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.0002105009621202394], {
             RGBColor[
             0.9807555417426524, 0.9851680950583542, 0.9174600274578315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.0002105009621202394], {
             RGBColor[
             0.9930578173934309, 0.9875596983039056, 0.485764449338902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.0002105009621202394], {
             RGBColor[
             0.992677031988194, 0.9867452368254138, 0.444318307913977]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.0002105009621202394], {
             RGBColor[
             0.9943879107080993, 0.9904046334109183, 0.6305368982561159]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.0002105009621202394], {
             RGBColor[
             0.9942718844435022, 0.9901564649630001, 0.6179081553858317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.0002105009621202394], {
             RGBColor[
             0.9949193389782519, 0.992167030347544, 0.7338632316670045]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.0002105009621202394], {
             RGBColor[
             0.9934456834546253, 0.9883893045895258, 0.5279812764680327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.0002105009621202394], {
             RGBColor[
             0.9850471875063367, 0.9880846420111867, 0.8974703298656781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.0002105009621202394], {
             RGBColor[
             0.9951904034059628, 0.9921210841471906, 0.7178832760076965]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.0002105009621202394], {
             RGBColor[
             0.9858630106089628, 0.98842200582982, 0.8839500297726531]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.0002105009621202394], {
             RGBColor[
             0.9739722181633338, 0.9801091034395712, 0.9289424249034826]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.0002105009621202394], {
             RGBColor[
             0.9551358719446321, 0.9660609872713498, 0.9608274457458381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.0002105009621202394], {
             RGBColor[
             0.9951250523690626, 0.9919813048872644, 0.7107702189409613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.0002105009621202394], {
             RGBColor[
             0.790025216639289, 0.8358929707434258, 0.9797059884553524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.0002105009621202394], {
             RGBColor[
             0.9888865209433678, 0.9896723050537678, 0.8338426389376392]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.0002105009621202394], {
             RGBColor[
             0.9856193945831173, 0.9883212643424866, 0.8879873777789777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.0002105009621202394], {
             RGBColor[
             0.8995683727020136, 0.6368452614898926, 0.23790972718915562`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.0002105009621202394], {
             RGBColor[
             0.987447444279098, 0.989077209870509, 0.8576918634756149]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.0002105009621202394], {
             RGBColor[
             0.9285335952171416, 0.7543665503432664, 0.2613546570608314]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.0002105009621202394], {
             RGBColor[
             0.9382341719487594, 0.7928261045585611, 0.2691599688008921]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.0002105009621202394], {
             RGBColor[
             0.9949849766165239, 0.9916816970164151, 0.6955238377244581]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.0002105009621202394], {
             RGBColor[
             0.8915745525724958, 0.600547191285878, 0.23123948772662434`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.0002105009621202394], {
             RGBColor[
             0.9370599424048115, 0.9525799886171699, 0.991425279499281]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.0002105009621202394], {
             RGBColor[
             0.9907121045578857, 0.9904272307937299, 0.8035879939861305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.0002105009621202394], {
             RGBColor[
             0.9952521118720514, 0.9922530723164713, 0.7245998617209434]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.0002105009621202394], {
             RGBColor[
             0.9948196815320426, 0.9913281475446064, 0.6775324878616951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.0002105009621202394], {
             RGBColor[
             0.948393659342362, 0.8331050866257135, 0.2773345308316036]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.0002105009621202394], {
             RGBColor[
             0.9691884719834296, 0.9077276224886033, 0.33480346123480603`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.0002105009621202394], {
             RGBColor[
             0.9896761506859998, 0.9899988372449049, 0.8207564306059603]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.0002105009621202394], {
             RGBColor[
             0.958508537371493, 0.9685763156244699, 0.9551184029101855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.0002105009621202394], {
             RGBColor[
             0.9941298099713685, 0.9898525820330386, 0.6024442258760762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.0002105009621202394], {
             RGBColor[
             0.9693529727627491, 0.9082825222438679, 0.3354425156990969]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.0002105009621202394], {
             RGBColor[
             0.9844237480282361, 0.9878268337653283, 0.9078023354274549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.0002105009621202394], {
             RGBColor[
             0.9868174751413914, 0.9888167014425988, 0.8681320823952811]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.0002105009621202394], {
             RGBColor[
             0.9373423117321865, 0.9527905791991887, 0.9909473018817506]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.0002105009621202394], {
             RGBColor[
             0.9940506630957493, 0.9896832948690657, 0.593829576902822]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.0002105009621202394], {
             RGBColor[
             0.9888145330839186, 0.989642536223882, 0.8350356640673213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.0002105009621202394], {
             RGBColor[
             0.9710620965082933, 0.977938739474129, 0.9338685017841798]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.0002105009621202394], {
             RGBColor[
             0.9367454099263256, 0.7869236592401463, 0.2679620759319059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.0002105009621202394], {
             RGBColor[
             0.9882413711378578, 0.971997525169953, 0.40882037661166]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.0002105009621202394], {
             RGBColor[
             0.9874489148545759, 0.989077817991261, 0.8576674922342201]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.0002105009621202394], {
             RGBColor[
             0.9945292315015024, 0.9907069042982837, 0.6459187944872057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.0002105009621202394], {
             RGBColor[
             0.971342093763755, 0.978147560968799, 0.9333945394656631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.0002105009621202394], {
             RGBColor[
             0.9797037948092489, 0.9431982754953036, 0.37565350476102016`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.0002105009621202394], {
             RGBColor[
             0.9943009271845134, 0.9902185844493513, 0.6210692785138685]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.0002105009621202394], {
             RGBColor[
             0.9785960700029306, 0.9394616596174389, 0.3713502030647509]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.0002105009621202394], {
             RGBColor[
             0.9945378975082619, 0.9907254400104747, 0.6468620358425874]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.0002105009621202394], {
             RGBColor[
             0.9933091247844513, 0.9880972194022234, 0.5131177079620334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.0002105009621202394], {
             RGBColor[
             0.9860515209784125, 0.9884999597120829, 0.8808259251016736]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.0002105009621202394], {
             RGBColor[
             0.9934770553788347, 0.9915706090141871, 0.7577656034196547]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.0002105009621202394], {
             RGBColor[
             0.9949881579920441, 0.9916885016569666, 0.6958701108166728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.0002105009621202394], {
             RGBColor[
             0.9578754373596249, 0.8695661002756608, 0.2908544580086512]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.0002105009621202394], {
             RGBColor[
             0.9926364829760528, 0.9866585065885778, 0.4399047981819029]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.0002105009621202394], {
             RGBColor[
             0.9899141978144308, 0.9900972758500433, 0.8168113736416379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.0002105009621202394], {
             RGBColor[
             0.9746610156585515, 0.9806228074837022, 0.9277764704112376]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.0002105009621202394], {
             RGBColor[
             0.9882898911541257, 0.9894255833032299, 0.8437303385737817]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.0002105009621202394], {
             RGBColor[
             0.8517124567382098, 0.39849017979872403`, 0.19715321301436328`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.0002105009621202394], {
             RGBColor[
             0.9937196752195148, 0.9916709385533539, 0.7537447647795661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.0002105009621202394], {
             RGBColor[
             0.9300614752123979, 0.760424085388631, 0.2625840251689675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.0002105009621202394], {
             RGBColor[
             0.8736054607324941, 0.5189537420284548, 0.2162456370325807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.0002105009621202394], {
             RGBColor[
             0.9830791307827003, 0.9545840763003303, 0.38876604763916484`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.0002105009621202394], {
             RGBColor[
             0.9922036084067427, 0.9853630818554538, 0.42421292019555346`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.0002105009621202394], {
             RGBColor[
             0.9881885929765408, 0.9893836939035542, 0.8454091115276433]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.0002105009621202394], {
             RGBColor[
             0.9933409185537481, 0.988165223059906, 0.5165782635415794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.0002105009621202394], {
             RGBColor[
             0.9948558979668198, 0.9914056108365517, 0.6814744232852653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.0002105009621202394], {
             RGBColor[
             0.9926270022500028, 0.9866382282742053, 0.43887287965962346`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.0002105009621202394], {
             RGBColor[
             0.965686289860952, 0.9739294716786173, 0.9429683402032024]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.0002105009621202394], {
             RGBColor[
             0.9627287924125267, 0.8859376064910569, 0.30970882590997756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.0002105009621202394], {
             RGBColor[
             0.9868948956124994, 0.9888487167970174, 0.8668490248312636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.0002105009621202394], {
             RGBColor[
             0.9852675048328183, 0.9881757488875839, 0.8938191016029143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.0002105009621202394], {
             RGBColor[
             0.9943076298594764, 0.990232920793353, 0.6217988233194859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.0002105009621202394], {
             RGBColor[
             0.9867809899391911, 0.9888016138738621, 0.8687367366164181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.0002105009621202394], {
             RGBColor[
             0.9917091366772095, 0.990839529197627, 0.7870645915325221]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.0002105009621202394], {
             RGBColor[
             0.8807184454055141, 0.5512521441488608, 0.22218088579895753`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.0002105009621202394], {
             RGBColor[
             0.9600517438645665, 0.9697272365002354, 0.9525061568501265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.0002105009621202394], {
             RGBColor[
             0.9212290963233493, 0.7254066463093416, 0.25547728579226037`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.0002105009621202394], {
             RGBColor[
             0.9937386277347002, 0.9916787759054405, 0.7534306725554052]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.0002105009621202394], {
             RGBColor[
             0.9519865742070565, 0.8473497967963235, 0.28022547446828794`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.0002105009621202394], {
             RGBColor[
             0.9674387029661369, 0.9752364185031512, 0.940001961918662]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.0002105009621202394], {
             RGBColor[
             0.9484200302677847, 0.8332096385574245, 0.2773557494972039]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.0002105009621202394], {
             RGBColor[
             0.9938004243026276, 0.9891480593936016, 0.5665926285663556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.0002105009621202394], {
             RGBColor[
             0.9933193506738011, 0.9881190915455464, 0.5142307329108745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.0002105009621202394], {
             RGBColor[
             0.8986287768182097, 0.6325787760297337, 0.2371257053521071]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.0002105009621202394], {
             RGBColor[
             0.9935189114502504, 0.9885459318676819, 0.5359516918810272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.0002105009621202394], {
             RGBColor[
             0.9149939679739805, 0.7006864401374472, 0.25046035516508536`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.0002105009621202394], {
             RGBColor[
             0.9894700911901236, 0.9899136263478726, 0.8241713697175088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.0002105009621202394], {
             RGBColor[
             0.9906183475457491, 0.9903884598597661, 0.8051417903126037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.0002105009621202394], {
             RGBColor[
             0.8766704753583949, 0.532871257592317, 0.21880316036681569`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.0002105009621202394], {
             RGBColor[
             0.9098214810071621, 0.9309309687816517, 0.9912607791373291]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.0002105009621202394], {
             RGBColor[
             0.9790650142300577, 0.9839073024074457, 0.9203216495764643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.0002105009621202394], {
             RGBColor[
             0.99317950942163, 0.9878199852472719, 0.499009875612222]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.0002105009621202394], {
             RGBColor[
             0.9460732681962907, 0.8239055089560531, 0.27546748964889417`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.0002105009621202394], {
             RGBColor[
             0.9742699111858757, 0.9803311224083555, 0.9284385082670943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.0002105009621202394], {
             RGBColor[
             0.9932916775514017, 0.988059901534916, 0.5112186843164118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.0002105009621202394], {
             RGBColor[
             0.9926454782479774, 0.9866777465656633, 0.4408838780185248]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.0002105009621202394], {
             RGBColor[
             0.9936423506204256, 0.9888099557710723, 0.5493872837763497]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.0002105009621202394], {
             RGBColor[
             0.9403408882261085, 0.8011785325766676, 0.27085508216863396`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.0002105009621202394], {
             RGBColor[
             0.9939050054838346, 0.989371747965424, 0.5779756447405033]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.0002105009621202394], {
             RGBColor[
             0.9938139884943934, 0.9891770718282382, 0.5680690071315643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.0002105009621202394], {
             RGBColor[
             0.8964477327610003, 0.622675164361727, 0.23530578872848953`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.0002105009621202394], {
             RGBColor[
             0.9098214810071621, 0.9309309687816517, 0.9912607791373291]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.0002105009621202394], {
             RGBColor[
             0.7810985330967374, 0.8289193777146768, 0.9788162600644315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.0002105009621202394], {
             RGBColor[
             0.9947439420104266, 0.99116614836631, 0.6692887083439342]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.0002105009621202394], {
             RGBColor[
             0.982246858988142, 0.9517766281105748, 0.38553282887864637`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.0002105009621202394], {
             RGBColor[
             0.9903999861529411, 0.9902981618122081, 0.8087606036926014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.0002105009621202394], {
             RGBColor[
             0.9370599424048115, 0.9525799886171699, 0.991425279499281]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.0002105009621202394], {
             RGBColor[
             0.9948316533489354, 0.9913537540504038, 0.6788355462489891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.0002105009621202394], {
             RGBColor[
             0.991982994788309, 0.9909527765643991, 0.7825260539095307]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.0002105009621202394], {
             RGBColor[
             0.8912637090947741, 0.9161335051960128, 0.9894907222856071]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.0002105009621202394], {
             RGBColor[
             0.9950015835003913, 0.991717217461794, 0.6973313945476216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.0002105009621202394], {
             RGBColor[
             0.9633358204440908, 0.9721764954360628, 0.9469470718253429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.0002105009621202394], {
             RGBColor[
             0.9795940364709234, 0.984301846328489, 0.9194261529137768]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.0002105009621202394], {
             RGBColor[
             0.6549385558969484, 0.7303622446748619, 0.9662418125691742]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.0002105009621202394], {
             RGBColor[
             0.9276368088726618, 0.7508110913237375, 0.2606330817177819]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.0002105009621202394], {
             RGBColor[
             0.9950350739159465, 0.9917888500742663, 0.7009766196019266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.0002105009621202394], {
             RGBColor[
             0.992400395102881, 0.9911253823211733, 0.775608650499684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.0002105009621202394], {
             RGBColor[
             0.9202595113701865, 0.7215625650650836, 0.25469713497986163`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.0002105009621202394], {
             RGBColor[
             0.9943477854871444, 0.9919306782907163, 0.7433353521476764]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.0002105009621202394], {
             RGBColor[
             0.9729763510211917, 0.9205050279192678, 0.3495186560155769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.0002105009621202394], {
             RGBColor[
             0.9189852518257995, 0.9382379108885007, 0.9921348277786056]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.0002105009621202394], {
             RGBColor[
             0.9836438625711944, 0.9873222000030896, 0.91257085368983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.0002105009621202394], {
             RGBColor[
             0.9875129243777471, 0.9891042875740621, 0.8566066887839371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.0002105009621202394], {
             RGBColor[
             0.9579089525253179, 0.9681291462279226, 0.9561333436579866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.0002105009621202394], {
             RGBColor[
             0.9940473838439952, 0.9896762808811469, 0.5934726505865857]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.0002105009621202394], {
             RGBColor[
             0.993083337642179, 0.9914077966119957, 0.7642905252248793]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.0002105009621202394], {
             RGBColor[
             0.7937209913471421, 0.8387801380341288, 0.9800743487392529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.0002105009621202394], {
             RGBColor[
             0.9856401910557777, 0.9883298642183767, 0.8876427264074493]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.0002105009621202394], {
             RGBColor[
             0.9832439131523777, 0.9551399259259927, 0.3894061960288223]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.0002105009621202394], {
             RGBColor[
             0.9823071932104718, 0.9863253141824577, 0.9148334862583303]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.0002105009621202394], {
             RGBColor[
             0.8943965983947665, 0.6133614422592613, 0.23359427193539992`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.0002105009621202394], {
             RGBColor[
             0.9933863351183473, 0.9882623644992645, 0.5215215763196526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.0002105009621202394], {
             RGBColor[
             0.9941230388078021, 0.9898380991988396, 0.6017072265086465]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.0002105009621202394], {
             RGBColor[
             0.9597875475867418, 0.8760160970565576, 0.2982826451692823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.0002105009621202394], {
             RGBColor[
             0.9920732980516155, 0.9909901192844642, 0.7810294951391874]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.0002105009621202394], {
             RGBColor[
             0.7208320940675083, 0.7818387775031419, 0.9728094646438912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.0002105009621202394], {
             RGBColor[
             0.9938004243026276, 0.9891480593936016, 0.5665926285663556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.0002105009621202394], {
             RGBColor[
             0.9322140571769504, 0.7689583555726643, 0.26431604314523915`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.0002105009621202394], {
             RGBColor[
             0.940986361119732, 0.8037376175087935, 0.2713744448100395]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.0002105009621202394], {
             RGBColor[
             0.9855236168040903, 0.9882816577694823, 0.8895746634424012]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.0002105009621202394], {
             RGBColor[
             0.96670572189133, 0.9746897624177066, 0.9412427076862286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.0002105009621202394], {
             RGBColor[
             0.9557939803484155, 0.8624448934039275, 0.28328900282093394`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.0002105009621202394], {
             RGBColor[
             0.9948712080410473, 0.9914383575372384, 0.6831408303821116]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.0002105009621202394], {
             RGBColor[
             0.9920099475480204, 0.9909639222231941, 0.7820793769296058]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.0002105009621202394], {
             RGBColor[
             0.9857944084838799, 0.988393637088104, 0.8850869445218844]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.0002105009621202394], {
             RGBColor[
             0.9747563497881254, 0.9806939075214433, 0.927615094596992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.0002105009621202394], {
             RGBColor[
             0.9611828526434771, 0.8807227886461332, 0.303703141833449]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.0002105009621202394], {
             RGBColor[
             0.9819355356003373, 0.986048132545353, 0.9154626056484587]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.0002105009621202394], {
             RGBColor[
             0.9446530650501059, 0.8182748767360739, 0.2743247608610215]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.0002105009621202394], {
             RGBColor[
             0.9935302203558634, 0.9885701204732824, 0.5371825964665263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.0002105009621202394], {
             RGBColor[
             0.9072135529812031, 0.9288514777640725, 0.9910120326340883]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.0002105009621202394], {
             RGBColor[
             0.9952424980610635, 0.9922325093468736, 0.7235534577244723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.0002105009621202394], {
             RGBColor[
             0.9635749352314805, 0.8887918449031698, 0.31299593098094936`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.0002105009621202394], {
             RGBColor[
             0.9397415302037582, 0.9545799124069272, 0.986886050825775]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.0002105009621202394], {
             RGBColor[
             0.9734830871940922, 0.9222143680177727, 0.3514872303581986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.0002105009621202394], {
             RGBColor[
             0.9694017596755415, 0.9767004629828148, 0.9366790189568287]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.0002105009621202394], {
             RGBColor[
             0.9894700911901236, 0.9899136263478726, 0.8241713697175088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.0002105009621202394], {
             RGBColor[
             0.9063500989159035, 0.6664163797207834, 0.24350529522327258`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.0002105009621202394], {
             RGBColor[
             0.9947414848927328, 0.9911608928400159, 0.6690212662465478]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.0002105009621202394], {
             RGBColor[
             0.9709442654555915, 0.9136503261501175, 0.3416243873203794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.0002105009621202394], {
             RGBColor[
             0.8644779408163475, 0.4775078058756709, 0.2086294106785616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.0002105009621202394], {
             RGBColor[
             0.9432962836346874, 0.8128956905445441, 0.2732330626864227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.0002105009621202394], {
             RGBColor[
             0.994171144227184, 0.9899409918266936, 0.6069432045361356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.0002105009621202394], {
             RGBColor[
             0.9797575814313416, 0.9844238178921887, 0.9191493139551459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.0002105009621202394], {
             RGBColor[
             0.9524564878666042, 0.9640627070130453, 0.9653629440946513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.0002105009621202394], {
             RGBColor[
             0.8673943949452997, 0.49075074292007487`, 0.21106297149259162`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.0002105009621202394], {
             RGBColor[
             0.9420093769702479, 0.8077935344562659, 0.2721975873766329]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.0002105009621202394], {
             RGBColor[
             0.9845740062149192, 0.987888969386981, 0.9053121684183951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.0002105009621202394], {
             RGBColor[
             0.9933193506738011, 0.9881190915455464, 0.5142307329108745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.0002105009621202394], {
             RGBColor[
             0.9236223106854973, 0.9419353757536142, 0.9925771145921949]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.0002105009621202394], {
             RGBColor[
             0.8617016281139528, 0.8925615042632173, 0.9866710646112751]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.0002105009621202394], {
             RGBColor[
             0.9938537057761231, 0.9917263636329396, 0.7515235315966036]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.0002105009621202394], {
             RGBColor[
             0.9736831260735994, 0.922889146129713, 0.3522643436309114]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.0002105009621202394], {
             RGBColor[
             0.9881525417831527, 0.9893687858086149, 0.8460065730995806]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.0002105009621202394], {
             RGBColor[
             0.9941360259908831, 0.9898658774702446, 0.603120801239426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.0002105009621202394], {
             RGBColor[
             0.9885040862848182, 0.9895141584943351, 0.840180570938976]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.0002105009621202394], {
             RGBColor[
             0.9870466766704082, 0.988911482165058, 0.8643336199049286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.0002105009621202394], {
             RGBColor[
             0.973870146873396, 0.9235200112019989, 0.3529908841222066]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.0002105009621202394], {
             RGBColor[
             0.9841150201413159, 0.9876735885474365, 0.9117733068211894]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.0002105009621202394], {
             RGBColor[
             0.9793742926476322, 0.942086787333384, 0.3743734510844018]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.0002105009621202394], {
             RGBColor[
             0.9725042868958662, 0.9790143227038108, 0.9314272496415137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.0002105009621202394], {
             RGBColor[
             0.9747563497881254, 0.9806939075214433, 0.927615094596992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.0002105009621202394], {
             RGBColor[
             0.9938004243026276, 0.9891480593936016, 0.5665926285663556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.0002105009621202394], {
             RGBColor[
             0.9819947291008992, 0.950926134797992, 0.38455335187744216`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.0002105009621202394], {
             RGBColor[
             0.985830916983861, 0.9638664973069718, 0.39945621739945436`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.0002105009621202394], {
             RGBColor[
             0.9704684712615343, 0.9120453606117732, 0.33977601672266156`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.0002105009621202394], {
             RGBColor[
             0.9483385084688061, 0.9609915247207399, 0.9723336090740845]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.0002105009621202394], {
             RGBColor[
             0.9949040659669014, 0.9915086373181944, 0.6867172128357116]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.0002105009621202394], {
             RGBColor[
             0.9913313828392262, 0.9824208602079182, 0.42082448857172916`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.0002105009621202394], {
             RGBColor[
             0.9927775769352545, 0.9912813567019907, 0.7693577714219636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.0002105009621202394], {
             RGBColor[
             0.9325156891170375, 0.770154225702224, 0.2645587432844448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.0002105009621202394], {
             RGBColor[
             0.9397343642340371, 0.7987738670602436, 0.2703670587276654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.0002105009621202394], {
             RGBColor[
             0.9687628484944493, 0.906291894519125, 0.3331499943523691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.0002105009621202394], {
             RGBColor[
             0.9854818464273158, 0.9882643846452364, 0.8902669066838245]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.0002105009621202394], {
             RGBColor[
             0.9907838168295695, 0.9904568856609924, 0.8023995360589187]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.0002105009621202394], {
             RGBColor[
             0.9918005020309433, 0.9840033093960046, 0.4226469280458245]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.0002105009621202394], {
             RGBColor[
             0.8954185080912684, 0.6180016955180032, 0.23444697843546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.0002105009621202394], {
             RGBColor[
             0.9867451978385706, 0.9887868129204405, 0.869329904350686]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.0002105009621202394], {
             RGBColor[
             0.9809693029955563, 0.9474671317631711, 0.38056976509365636`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.0002105009621202394], {
             RGBColor[
             0.9419607858129092, 0.9562350296065345, 0.9831294299540454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.0002105009621202394], {
             RGBColor[
             0.9899141978144308, 0.9900972758500433, 0.8168113736416379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.0002105009621202394], {
             RGBColor[
             0.985823915697687, 0.988405839079314, 0.8845979336268802]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.0002105009621202394], {
             RGBColor[
             0.9949625591907699, 0.992184903016129, 0.7331469608952563]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.0002105009621202394], {
             RGBColor[
             0.9942718844435022, 0.9901564649630001, 0.6179081553858317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.0002105009621202394], {
             RGBColor[
             0.9929433116343221, 0.9913498922592427, 0.7666111185507603]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.0002105009621202394], {
             RGBColor[
             0.9918005020309433, 0.9840033093960046, 0.4226469280458245]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.0002105009621202394], {
             RGBColor[
             0.985307368252047, 0.9881922334358781, 0.8931584615830719]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.0002105009621202394], {
             RGBColor[
             0.936994372945701, 0.7879107146499613, 0.26816239742120845`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.0002105009621202394], {
             RGBColor[
             0.9058436762757248, 0.6644085827078161, 0.24309781567971767`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.0002105009621202394], {
             RGBColor[
             0.9376380671922447, 0.9530111531370451, 0.99044666503325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.0002105009621202394], {
             RGBColor[
             0.9943597088780416, 0.9903443125480674, 0.6274673030958569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.0002105009621202394], {
             RGBColor[
             0.9591716523608653, 0.9690708656977925, 0.9539959222012664]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.0002105009621202394], {
             RGBColor[
             0.9941686200860222, 0.9899355929439785, 0.6066684673478747]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.0002105009621202394], {
             RGBColor[
             0.9277887190117736, 0.9452575566588457, 0.9929745103377517]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.0002105009621202394], {
             RGBColor[
             0.9379386692942421, 0.7916545350038224, 0.2689222004287287]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.0002105009621202394], {
             RGBColor[
             0.9760549811787841, 0.9308899703375635, 0.36147855282730096`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.0002105009621202394], {
             RGBColor[
             0.9233027134606153, 0.733627847266653, 0.2571457668149546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.0002105009621202394], {
             RGBColor[
             0.993540684466184, 0.9885925021471744, 0.5383215502979274]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.0002105009621202394], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.0002105009621202394], {
             RGBColor[
             0.8889651306107735, 0.5886984156036796, 0.2290621220789779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.0002105009621202394], {
             RGBColor[
             0.9342460537851862, 0.9504064601274819, 0.9935904166929707]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.0002105009621202394], {
             RGBColor[
             0.9733482407034686, 0.9796437420716732, 0.9299986559836486]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.0002105009621202394], {
             RGBColor[
             0.9947416100563982, 0.9920935348709325, 0.7368086598498262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.0002105009621202394], {
             RGBColor[
             0.9857374038062481, 0.9883700641889499, 0.8860316595536206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.0002105009621202394], {
             RGBColor[
             0.9370599424048115, 0.9525799886171699, 0.991425279499281]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.0002105009621202394], {
             RGBColor[
             0.9737347405733157, 0.9799319930417697, 0.929344412519308]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.0002105009621202394], {
             RGBColor[
             0.9849984286856895, 0.9880644789858046, 0.898278389707584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.0002105009621202394], {
             RGBColor[
             0.9644553562420664, 0.8917617117045598, 0.31641620035351836`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.0002105009621202394], {
             RGBColor[
             0.994140346220653, 0.9898751180048799, 0.6035910315885024]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.0002105009621202394], {
             RGBColor[
             0.9556269215786938, 0.8617825610510157, 0.2831545834134425]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.0002105009621202394], {
             RGBColor[
             0.9936337070987658, 0.988791468152236, 0.5484464897853084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.0002105009621202394], {
             RGBColor[
             0.9899694390677277, 0.990120119527917, 0.8158958831147273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.0002105009621202394], {
             RGBColor[
             0.9923687930779437, 0.9911123140717267, 0.7761323778363144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.0002105009621202394], {
             RGBColor[
             0.99285669871446, 0.9871295257858045, 0.4638739222935351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.0002105009621202394], {
             RGBColor[
             0.9653472532403706, 0.9736766187221093, 0.9435422407669339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.0002105009621202394], {
             RGBColor[
             0.963212455983325, 0.8875691172849666, 0.3115877675503277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.0002105009621202394], {
             RGBColor[
             0.9938004243026276, 0.9891480593936016, 0.5665926285663556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.0002105009621202394], {
             RGBColor[
             0.9926617505856246, 0.9867125514505046, 0.4426550215501828]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.0002105009621202394], {
             RGBColor[
             0.9921836529786897, 0.985295767510874, 0.4241353971258341]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.0002105009621202394], {
             RGBColor[
             0.9930401330894056, 0.9875218733657527, 0.4838396219806145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.0002105009621202394], {
             RGBColor[
             0.9823071932104718, 0.9863253141824577, 0.9148334862583303]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.0002105009621202394], {
             RGBColor[
             0.9949649670061508, 0.991638898483109, 0.6933459151203525]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.0002105009621202394], {
             RGBColor[
             0.9671442402161969, 0.9750168086663844, 0.9405004105461253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.0002105009621202394], {
             RGBColor[
             0.9604209866010699, 0.9700026171285401, 0.9518811252111556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.0002105009621202394], {
             RGBColor[
             0.9236223106854973, 0.9419353757536142, 0.9925771145921949]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.0002105009621202394], {
             RGBColor[
             0.975922953420616, 0.9304446097076704, 0.36096564991816776`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.0002105009621202394], {
             RGBColor[
             0.994467551314175, 0.9905749766144137, 0.6392052867426034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.0002105009621202394], {
             RGBColor[
             0.9937569029886986, 0.9890549717037871, 0.5618556021275907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.0002105009621202394], {
             RGBColor[
             0.9947445850119019, 0.9911675236814482, 0.6693586950863759]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.0002105009621202394], {
             RGBColor[
             0.9897547335131917, 0.9771024518163376, 0.41469950366532743`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.0002105009621202394], {
             RGBColor[
             0.9604960915585808, 0.878406182247607, 0.30103520470257555`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.0002105009621202394], {
             RGBColor[
             0.9939885809901973, 0.9895505075227538, 0.5870723228398373]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.0002105009621202394], {
             RGBColor[
             0.9946475244769842, 0.9909599210115848, 0.6587942548487749]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.0002105009621202394], {
             RGBColor[
             0.9596832781369848, 0.8756643717188962, 0.29787757804660986`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.0002105009621202394], {
             RGBColor[
             0.9938685344697678, 0.9892937401541201, 0.5740059999323313]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.0002105009621202394], {
             RGBColor[
             0.9951064241821348, 0.99224439488722, 0.7307627456776785]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.0002105009621202394], {
             RGBColor[
             0.9944238506780037, 0.9904815053724555, 0.6344487421844218]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.0002105009621202394], {
             RGBColor[
             0.9923687930779437, 0.9911123140717267, 0.7761323778363144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.0002105009621202394], {
             RGBColor[
             0.9243930982533513, 0.7379508596206583, 0.25802311601381056`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.0002105009621202394], {
             RGBColor[
             0.9928002671930106, 0.9870088244675261, 0.45773169943874104`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.0002105009621202394], {
             RGBColor[
             0.9343692792001181, 0.9505047167284838, 0.9936021700430515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.0002105009621202394], {
             RGBColor[
             0.9903255727879959, 0.9902673899734671, 0.8099938257253583]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.0002105009621202394], {
             RGBColor[
             0.9845740062149192, 0.987888969386981, 0.9053121684183951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.0002105009621202394], {
             RGBColor[
             0.9925749330113772, 0.9865268574377929, 0.4332054643693218]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.0002105009621202394], {
             RGBColor[
             0.9914513230688516, 0.9907329166450635, 0.7913372302232413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.0002105009621202394], {
             RGBColor[
             0.9950023817738606, 0.991718924888027, 0.6974182816883809]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.0002105009621202394], {
             RGBColor[
             0.9898967491740833, 0.9775815039873881, 0.41525120769048435`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.0002105009621202394], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.0002105009621202394], {
             RGBColor[
             0.9598901569501922, 0.9696067252440693, 0.9527796813475453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.0002105009621202394], {
             RGBColor[
             0.9918005020309433, 0.9840033093960046, 0.4226469280458245]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.0002105009621202394], {
             RGBColor[
             0.9342460537851862, 0.9504064601274819, 0.9935904166929707]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.0002105009621202394], {
             RGBColor[
             0.9931456971988201, 0.9877476643216216, 0.4953296238242165]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.0002105009621202394], {
             RGBColor[
             0.9382698380990961, 0.9534823268449449, 0.9893772416801928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.0002105009621202394], {
             RGBColor[
             0.9520150466006455, 0.9637334808396871, 0.9661101890115977]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.0002105009621202394], {
             RGBColor[
             0.9898809620241366, 0.9900835319966358, 0.8173621766982807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.0002105009621202394], {
             RGBColor[
             0.9664384409310973, 0.8984511220110891, 0.3241201098962835]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN2wucznW+wPHf/+zadNlSKJUyheimsIbchiJLGlM0NrNmJtWMMW5DaZZc
xiXEpDYnbVorhVi3nLW60EUbOdQepCtJuQyjGrY9Lm05z6ffZ157Xi/ffefx
PP/nd/n+bv//s1cMGHbn0P8IIXx2ZgiYkYqtqeiWikdTke5r6b5eKxVHU/Fw
KhonIWxIuScVO1LRJ/X3fSmHJ/Hzv07Fz1P/PTQVnbV+6rVL/NwxP4uZIb6W
6d8nhXgt7J16/40pl6didCoWpeLJVExNvX6OZTrHcnH9OakYkYq5vn5uEt+D
R/XNlDk6zutPTuJ1cblelXJ9Kloq5Vln7PP1aV6/SRKv3cTrDfB6A7weEly3
id9PnTcbtAWvf287VBnH9A7L82Aq+qciLfX3B6zv/BDbGId63cFJvC7u0WOa
+hOyUv9zm330s1T08vMtk/haS4PrXZJ6/aMQ3/+RuYHdkngd6v+6QRu8bnvU
Nk+uSBnsr20hts82+3SbcVT5fIMk9gtO9frnJLH/z/H6eI5tfo7tTrucMB9P
GORl65SnLd9pg890t62728bdbWfa+IqU2bY15oXY/m2NB5X31fU6dX1fXfuk
rtetaz9SjzzrkWc98LRSpjzrlGed8hw3jYw55nWx1ys2XtejyrWKbc9i+6PY
75kYYm5iA/9OO5PPh41p5sd++3u/fb7f+Ll5VJTEsYYFfIf5fsooNq92GeTp
LvOUfL8qiZHj99dK4vcjQTnahdhmuDPE+WeSeY7kGPL6SYPXTvrv9P/EJOYg
5pt7uFm3KWPlDP/7DN+HG3SzVr/vlFZ/z1TjsJ5Wvrd9iGMNezmef0xFrpaa
N6W2FTIGS223UtuNeahVEqO317khifl4g/mLPyo5eoPl2215dpszu43TSt7s
Nk9ut2y3Wz7m9CEG4+qxlP9heV411uk+3zcwieMQ+cxA54FRIc4Do4zluk2P
KnMmTnacpRmZukH3aJUeU+a7NPuHdiq1nUptp1Lbp9Q2wm7K/FU/5REdGWIe
4iLdreQp6+QXIa6ZuFVph+ZJjD460Pb7XRLbEHuFmN+p5finsYFvKmMEq8dJ
ruXJdbzkOl5yDcqTJHGdSMyVxHzB2kaa9ra+7xnUFxv7+m3mLZLDtxm97M/z
jRt1lC7XbXpUmXfOt3/Pt3/JrxFJbC/cobTXCNtuhG2Hl4fY5pfb5pfb3rRT
J+cXfFNpw05GjvNKRhL7FBcp/dDM/mlm/zQz6KdfhpjzvzTfsbavt1Lak/Wk
3KhS1hemog5JjG6aZX4+EeJ4w1wlGH/0+2JjvdLni/1e5qIHkjgPY7FSjllJ
/H6sUsoyy/rmJzH38q0nso+qkcT5HVkHz0jiGofzdYfSjyOTuJ7gk0pf4wAl
pvq9bf2+tgbfSw6tMndWGaeUa6yynqvMmzohrpHYSFknmS/qGWnaXTO1XKv0
mNI29WwnrlMziZ+paTvUtB1q2g5IG9Q0WirzNetDF8dGF2O5rtJTWmy7vxbi
fP+asUvpB+xs/ja135r6uaUh9tdS4zXlc1jkeJ0XYn9hsY5SYpse1XPNqxLz
qsSgH9gndE/iPgE/0v3KXqG75WthPrWwPEjZWhiUr02IdcPRukh3alPfl6H5
jqsygzGFWcp1zzMXzzMHcZxONY+yzKEsgzziupVet9Lg+pVen3nx0STOhY86
jlsZbfVBZa3BG5R15nrb9nrb9Hqvw5mMuRB3aHNf76MDlfmQeXqj8Z4eUeZz
1v/Hk7j+4249rexR8KEkznPk+dgQ98CYp2MtD55Qch/TbMfxSRyT2Egf0Dl6
RDkTjne8DQ9xjA43yrVKGZc4y+95McTvedF+e9F+e9G+w4tCzFEs1fm6S/cr
uYottbMONW83GeTqpvDv8dQliftxLNZ5+rru1tPKXgvP1SZKsP9iHZkZ4loz
02Dtxtqapq2Udee8EM9cGPx7kdLHrCMzkrhu4Ho9rKwpmKvTlHqmW89065lu
PXGbHlXqlW690o0u1qteEutVz3IjdcPaSrTS6vV0r1GldzheCh1DhUaJPmq5
b0nifIf5Okrn6XLdpkeVcmOzEOdpLPDvxVqizIeclyeEON9NMObqUt2kzH0T
zCfGV5sk5ibuUMYW1tSWSgx1HJzpeDvT8YZZ+oDO0Rf1TMcd7XODka/zdLlu
1m1KezDv9gtxru5njNZF+rruVnIem2iGdtHqc8ffQ9z/4BNKsA9qGmIO42Jd
r4eVHMZcnaYz7KdB5s0g82aQ+TLIKFb69ZoQ50Acq1v1hNb2fWle/2WDz79s
XvD9ay37Wsu+1qC8ax0H2Ep7K+X+WYh7EczWPJ2vZ/i+mtrGvJ9ivk8xr5F1
Dxtouo7Uccp6VmC7Flj+AmOxrlfKyb55lsHeGZvp78zHZ4wjSh6m/oSDIa6z
B41KzbIeL4RYD5yoBHXAATpSJ+sUner3zEzi9+BBrVTWdszSIqVf/2C8rPQr
89kYY5LOVPJijP06xn4dY7+S57cn7vmTmN9IcB+VebarUazMqXiVNtFOyrnm
ipQXJ3GdR2Ki5dxiubZY1i2WdYvBHLzFcm+x3Fss9xbLzX2W8iTeXyl3HJU7
jsodR+WOH/xFiHMF9tK2vp6h+bbHuyG2x7vG35U2weGOszpJHJM4VrfqCaUu
WFsJxif7tWkGZ1jspawXg81J3Kjv6RFlP8W8e2MS511spFn6gM7RF5V590Zj
vOOrMMT6Y64W2haFtkGh7YE/Vn/G7z/bcuMzekSJS3S87+vp+3CjHlHeh/WV
OedAiGcozNQNuln3KHFMB5vHH5i/2E+L9XUlWB8+MM8/ML8xXbto9f6ownyu
MI8rzOMKgxyoMJ8rzGdM01ba2/lhVBLvFyDzIzZQYpwynzB+zk/i/S5cp/uU
+XdBiHM19tc8HavEDj2hzOPYRvs4Ti5M4ljCXkq01QxlPHHu7Gx00eW6Sk9p
seXNsbw5Rp4O17FKu+ZYzhzbk/tR34a49uNuPawE6xzm6jTrNcb64GM6S1lD
xlgvbKZtNV+ZF2Zb/tmWc7btPtuyzzYqlHrMNj+wjlav432TONcj81xfo0AL
dZCW2I49QjzP9DCyNUfzdLiW62ytUtoXOe/UDLHvsZ3u1Kb+e77zUkPnhYbO
Qw2dhxo67hs6DzU0btTqdbhjiOeFjkaZHtRKZa3ELC1S1kvOpWtCvK+HQ3SN
+Y6cZ9eY3zjCfFhtXVdbV+yno3WRrnYcYIbmO299EuK8hZlaqvOV2KUH9Jiy
j8LOOljZd7MfeiTE/dAjxlQ9rN8qeY+5Ok3ZL3Euf9bPPmvs1tPK9+JEfdz8
PG6Qm8fNUyzQQh2kxVqirM+cV7KTeA7BubpJOZtkO76uN3J0jM7U2bpFK5Rx
hrW1jtbTNO1t/y+x/3GkjtZFusS+X2I7L7H/ybvMJOZbpnmFO5ScyzT66EAl
/2qEOJZqWIYa5mANc7CGZanh9+NObernM5Q8JP/Kkph/uEE36x49oMeUPi8z
eH4xNMTnw/iQ4/Rco6OWaaUyPrGbZinjk/sadyXx3giW6nzdpdwTwZbaWQnG
AfvB7cZJ5bkBTlLyjPvyT4V4Xx67KvGmsq/FTprjOPsyxHGGBfqIrlfisLLn
xVydpjOcFy420jRTN+hm/UT36AE9pvTRxfYX/b0yxPxdaQ6tNIdWmkPYS0fr
SvNopXmEzGcrzSdsqxma7/h/2ziujH8s0EIdpMVaog9oue28wnZeYTvjYiXW
6nplXsNWOsPxNySJvwPBX+sQXaM/jVGDccc4fyfE8Y1LdLWS75eFmL+XGR21
TA9qpZL/2E2zdKZ5MDDEdXqguYDdtYdmKjFcy7VKjyn3o5D1+uch7lFxjE7S
mbpWX9V1ukUrtLbXq6ettPp+X+sknvuQhmptFOlEx2l7+7u947K96wCeVMZu
e6NAC3WQFmuJkj+3hni2wGd0ox7Rs31ffe3pvPN+iM8q3jd2KXMNUn72VWcb
2Zqj/TVPx+oC3aEnlH0Vsr+mT3oksQ9wne5T9vI9HB/3JnF84CM6Vb/Uw/qt
MhdhrhLTlPHCc6HfJPF5Ga5SYoBOdt6+1fxFcvtWo5uS3w2C90RCnFfxqJ7n
vzfQkTpKx+kUx/Fbxgll7cRMZd1k/3BPEu934gSdq0t1k7KfwGxlX3FlEp/l
Yob21636hTIWsI5eEOLeAXtotubocC3X2VqhiddJ01l6URKvjT00R4druc7W
CuWaFxlp2kpnWe8BIdZ3gDk8wBirb+lWPaHUfYDtwf3bR5J4zsauWqzzdJt+
oEeVszY20XTtolOU5+t3209320932z932z932yfIOjg9xPUPeymxRFfqan1H
Wf/wEm2rGZrv/PF0iHPO08YzulGPKPMO1teeynmHfcmgENsRa2kD7apEsT6l
8/So0paYrp00R0fpFKVdr0j5V4O5Gy/W1sr8x3rfLonzOL6t2/W4nlSivRZo
oQ7SYi1R5nHOIwtDnNfwWV1oGRdazoWWc6HlXGg58XHz8sIQ79teaNygN2q+
jtJ5uly36VGlXfEWHaDMjzz/fCXE9nnF2Kjv6XY9qeQDsuaxf7svxH3bfebr
fcZK3ankJzbTtpqvP/2uJ+UbIe5/cIgu0DVK7FDWI8zUPjpE2SexP7nXKNcl
+o7uVfYj7HPuT+I+By/WNM3UgbpBP9EDWqXHlLPx/cZgZR9Mf3ewjzsYo3Si
Pqkv6HJdpax5HexfHKnVvwNbFmJ9ME27aw/N1IE6XMt1me2EVUp7LbN+yDzN
PNDI8Yov6JvKmooNlBipo3ScMu5ZLz8N8dyFj+pHSuxXzl7Y3c8V+bkiY4R+
qvuV54p4j/Pb2CSeu7CrPqXfK2cv7KQ5yj7z5iTuZXGMTtKZ+qqu0y3K/gnr
KdFD2b+WhDhmcbue1Mb+ezttr5OU+Yp90d8Mfl+BHfRW7aZZWv37vs/8bnxF
N+p7SjBPfGZ5aI+utgder2N0ks7UFbpWt2iFsk/A2nqR1tNW2tX2ui7EtQA7
axct0bf1uJ7UU9rO67TXAh2kxVqinBM5ZzQ2RuhSfU3fV9aHxuYhtlbOI6k/
YXoSz25Yppv0oFYqn5luzLTffpHE9R8HK79L/IVRX2/TntbjOdvuOdsM/6DE
Kn1Z39ZTyrz0nO3znO3CfPRdiPMqZmqpztdPdJce0GNKMKdiS+2sd+n9Wv27
/P5JnA/6O97xUf1IP9X9ypyC3ZU6/mCu/GBwP/EH8+QH8wT7aoEW6iAt0UeV
8cm57VCI7XTI9sE8LdX5+onu0gN6yLY6ZFsdsr0O2V6HbJ9Dtg/zwrgQf2c1
zvibMk9gB71Vu2mWllr+K0M8L15pZGuO9tc8HasLdIeeUM6f2MdxcbXRWqfq
s7pQX9P3lcH00+d0orL/4v7e5BDzY7LtPNmYr7v0OyU3Jtuek82/yebf5P+X
d38OMd9wgs7VpUpw1sNsZT3qGeKzTizUJ/Rd/bve7vt57stzjdFJfK6BjTRL
H9NZOkdfVJ4j4ZlK8NyI/f7DSVwX8Sn9XlkXsal20hwlWCfZP17g9bCNttN+
OlpX6+v6gfIM9AKjiTbVDO2iPAdl3ultPvQ2SvU1fV8/0V16QL9T+hvZz3E+
nRHiOQ8HKPGWbtUvlHMpXul8+58hzrdYog8r8bZu1+N6Un9Q5iFsrwVaqIO0
WEuU+Sf1JzwU4nyAl2lHJcZpmf5ND2qlMl/grdpNs5T1if3/7w3OB/iQci5g
Hf1tiOe+39pv2FqJqbpQ/6pUBi/W1jrR/Ls2xPPLtUYbbaf9dLSu1J1KTmFT
JbeHhfgMEefoM9rQf79ROU9z7r8uiecPHKnTdZEu0dX6jl6X/Pv5yVfW5yvL
h730Ph2qv9eVulO/sj6Yrw85bv5p+//T9sfemq/P6mbdoweUYLwg8y77kzuT
mOf4ir6nnyn7Eqyvtyn1/TrE/frX1vtr6/m18b1Sr6/tJ9anhiGuKw2NazRb
++sAHasLdIeeUNYpZJ3idzP3G9OUfQL20urfP38e4n1S7KkFWqhP6GJdrwTz
Ps8P/hji+RmHKLFG31DOyz+9R0c47q9J4jjHMt2kB7VSiSKdroxn1v/Lkng/
EOtqPe2uPTRTszVH83SgDtdyXaZVyjngMmOW8+lZSZxHzzK/znKew+16XE/q
D0o01nbaXu/Ucut3aYj1u9RI0+7aQzN1oA7Xcl2me7VKqRPeofcr9ZyQcoox
VzcpfYItNFuLdLr98VKI8w8uUeId3avMNS+Ff///cvqGuD5gRyUe0jI9qJVK
ubCDFul0nen1x4e4Do33e8b7PeO9zni/a7xRpge1Uvm+8X4fZmmRTtfq/P1t
EveDOFnn6wI9pN8pYx9raktto3cpMdT5+kHnL6yl12o77ar9tFg/UPY/eK5e
oE20qRLMe5zHr07ieRwv1+s1XcfoTN2iW7VCOYdjHa2nVypxs3IeZ3573HhV
1+m7uk+Z15D9LPdH+yXxfhleqDdosY7SebpNjyrthOl6i3ZRgvvMPL/6ZRLn
ZXxEF+sKXauH9Vslammu3qvTdIb98U2I34OTdLGu0LX6qq7TffqN34u1tJ62
0q5KP7Ce/zqJ6zm21t46VZ/Vhfq+7tED+k89rcRgnais93eHOGfhFJ2rS/XP
uklb+Llsvcf+6WO79TEKdLGu0LW6Xj/XL/WwfqO0Yx/bEeknfh94i1GiD+sG
3a4nlTUCG2t7LVPuy7EPuSvEfQg2VGKBrtE3dIcy52BLbaN9lLmG83wn43bN
1R+V8z3n1D+FeD/kT8ZH+qlyDwS5D8K+tW4Sz5XYSx/TWco5sq5xoTbTtpqv
o3WM4+Lm4H3UEOcnTFdijE7SmbpFK5R7hlhb6+nVerN2VcYH6+GwJN4vw6f1
Jd2oe/WI8uwML9H6eodyH+5yr4vD9Bk9oux3Lzd6mu/Pm+/Pm6fPm/PPG4t1
ha7Xz/VLnWHefWjefWjefWheYbb217G6QNfoG7pDiRNKfn5oXn5oXt4U4hpw
k3W4yTrg4/q8LtYV+qqu0/X6ue7Tb/R2v4/1I+G1JJ4nsaP21fFappXKB/Ea
ba1EkU7XmY6Lf4WYPzhdX9J3lCBH8DodZjk/DrF82FfHa5lO0U1KHNRKpcwf
Ww8s0ulKec8KsU2wsXbUvjpXl+rHGvx8Db1GW+tNWqR8H+eC/wpxPGMPzdYc
Ha6zlahQxjPW1ov0Mk1T9sc8V7wnxPy+xxiia/QNfUt36Id6Qvk9B2ZqHx2o
nKN4fnRpEs+j2FWf0u+VuEo7aY4+qA8r98t4rnaH8abyLA0baCMdpTxH+1WI
ayZO0Cm6SbN9H3nBfrBjEs/CmK4ZerMO0Bm6Vb9Q+gbr6JV6tRL87oFz8p3G
/TpNeUaBt2kvx0dz41faUfvqeC3TKbpJP9aDWqnkb3Pztrl529x2aW7+Mn//
JcT5G5/WZ5TYqEeUuRzP1vp6ufZUxj/ngt+FeC7Aa7WNttN+SozWlbpadypn
AmyqGUqetQjxOTM+qS/oef57Ax2p/P/CmN8eS2I74NP6kv5FN+pePaL/UtoE
L9E7dJhyDvvvEO/LY5GO0FKdrMSnul+5T48t9S7tr9W/T//fENdX7KOP6GJd
oWv1sH6rBPtHrKW5eq9O0xmOu2uTOEZxgk7RubpU/6yblGih2cr+mPtBvwnx
fhDepcQQ/aOu0Teq/z2JMp9xf+N/Qry/gZdqmt6i3TVTB+oyfUU3KHFAq/SY
cn8Dy3SS4+JXSRwXeK0O1Z36lX6t3yu5j9TjH9bjH5Yb79WBWq7L9CXdq1VK
kLM4TMlb7uPfl8TnpficrtKX9ZTyrPQ+o1h5Xsp6MsH5f4LzOg7Sp/RNZcz+
9H5tpJ00R0fpOCX4vcX/Ab8fSPc=
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[337, 399] -> 
             RGBColor[
              0.9603114409091467, 0.8681403292906987, 0.42659540071605706`], 
             UndirectedEdge[15, 92] -> 
             RGBColor[
              0.3916080301069964, 0.5102971083648917, 0.9465821312407912], 
             UndirectedEdge[87, 313] -> 
             RGBColor[
              0.2082730893529932, 0.33623860055952687`, 0.9351722163750043], 
             UndirectedEdge[35, 214] -> 
             RGBColor[
              0.23799829524204824`, 0.3674816766358314, 0.9368650228758846], 
             UndirectedEdge[105, 218] -> 
             RGBColor[
              0.20016816814604027`, 0.3277198144893344, 0.9347106531024247], 
             UndirectedEdge[149, 316] -> 
             RGBColor[
              0.2254786330368893, 0.3543227178657783, 0.9361520466344813], 
             UndirectedEdge[160, 348] -> 
             RGBColor[
              0.39638156393997953`, 0.5175763121944144, 0.946525366087156], 
             UndirectedEdge[17, 287] -> 
             RGBColor[
              0.2108043778715786, 0.3388991452855218, 0.9353163695114319], 
             UndirectedEdge[268, 295] -> 
             RGBColor[
              0.5541988760682194, 0.6477364431214906, 0.9586174510059542], 
             UndirectedEdge[277, 379] -> 
             RGBColor[
              0.2074585735841274, 0.33538249284316635`, 0.9351258309069355], 
             UndirectedEdge[10, 37] -> 
             RGBColor[
              0.29314980125126083`, 0.4217462676405007, 0.9401414095988625], 
             UndirectedEdge[118, 389] -> 
             RGBColor[
              0.22076497088432706`, 0.3493683600799934, 0.9358836105481312], 
             UndirectedEdge[127, 313] -> 
             RGBColor[
              0.20658568658737522`, 0.3344650332653477, 0.935076121283791], 
             UndirectedEdge[92, 281] -> 
             RGBColor[
              0.46303919301965735`, 0.5742863383640635, 0.9510560694278913], 
             UndirectedEdge[2, 193] -> 
             RGBColor[
              0.18596534003799042`, 0.3127917416364609, 0.9339018230528726], 
             UndirectedEdge[265, 378] -> 
             RGBColor[
              0.19040066183963522`, 0.31745354606563403`, 0.9341544080680056],
              UndirectedEdge[108, 367] -> 
             RGBColor[
              0.31561783688898226`, 0.44293150514134, 0.9415099085808494], 
             UndirectedEdge[26, 342] -> 
             RGBColor[
              0.18535691671142462`, 0.3121522501439733, 0.9338671742445064], 
             UndirectedEdge[57, 144] -> 
             RGBColor[
              0.20411547873617336`, 0.33186868819351084`, 0.93493544660101], 
             UndirectedEdge[341, 348] -> 
             RGBColor[
              0.33468734849454873`, 0.4643110922158917, 0.9425469597870388], 
             UndirectedEdge[232, 309] -> 
             RGBColor[
              0.2963446868922668, 0.42880743363510754`, 0.9401877635646132], 
             UndirectedEdge[23, 202] -> 
             RGBColor[
              0.2682077809117381, 0.39923376146669465`, 0.9385854083938443], 
             UndirectedEdge[89, 170] -> 
             RGBColor[
              0.21045471282523004`, 0.33853162515176505`, 0.9352964566043255],
              UndirectedEdge[291, 383] -> 
             RGBColor[
              0.1977645203288262, 0.3251934282333686, 0.9345737689151127], 
             UndirectedEdge[45, 140] -> 
             RGBColor[
              0.25525427585226035`, 0.38561880634952683`, 0.9378477254437005],
              UndirectedEdge[213, 308] -> 
             RGBColor[
              0.2120594900785835, 0.3402183477937941, 0.9353878462948488], 
             UndirectedEdge[165, 386] -> 
             RGBColor[
              0.8287550787424094, 0.8667695006906301, 0.9834015662110343], 
             UndirectedEdge[347, 381] -> 
             RGBColor[
              0.1970073353004369, 0.3243975787602278, 0.9345306483479008], 
             UndirectedEdge[216, 396] -> 
             RGBColor[
              0.19963425463605258`, 0.3271586375382656, 0.9346802475178853], 
             UndirectedEdge[39, 150] -> 
             RGBColor[
              0.1883607596919023, 0.31530947957110045`, 0.9340382386584571], 
             UndirectedEdge[20, 378] -> 
             RGBColor[
              0.19055340614426983`, 0.31761409001435326`, 0.9341631066301896],
              UndirectedEdge[363, 372] -> 
             RGBColor[
              0.20698461099735616`, 0.3348843281135061, 0.9350988394387836], 
             UndirectedEdge[54, 318] -> 
             RGBColor[
              0.18950140793350456`, 0.31650837319430003`, 0.9341031968883784],
              UndirectedEdge[40, 246] -> 
             RGBColor[
              0.7206526383610699, 0.7806508133791874, 0.9738469548784772], 
             UndirectedEdge[59, 178] -> 
             RGBColor[
              0.3941011919373124, 0.5157723771794137, 0.9463327573536129], 
             UndirectedEdge[172, 357] -> 
             RGBColor[
              0.8404518577056951, 0.3119362812088553, 0.18637005066379952`], 
             UndirectedEdge[268, 274] -> 
             RGBColor[
              0.5862206904488971, 0.6743925388404906, 0.9609561467561663], 
             UndirectedEdge[122, 175] -> 
             RGBColor[
              0.4398070896700592, 0.5489279977942612, 0.9504219852000314], 
             UndirectedEdge[120, 341] -> 
             RGBColor[
              0.42726711236099996`, 0.542734639248357, 0.9489335670306169], 
             UndirectedEdge[220, 366] -> 
             RGBColor[
              0.5151109603637722, 0.615629530907049, 0.9554125916387102], 
             UndirectedEdge[202, 366] -> 
             RGBColor[
              0.31887937893336776`, 0.4445735814559359, 0.9417610431931018], 
             UndirectedEdge[17, 61] -> 
             RGBColor[
              0.22052046256389546`, 0.34911136633249684`, 0.9358696861610002],
              UndirectedEdge[112, 279] -> 
             RGBColor[
              0.8046710367643358, 0.7661172165820809, 0.618109700945247], 
             UndirectedEdge[129, 313] -> 
             RGBColor[
              0.203727765298821, 0.33146117678840176`, 0.9349133668943235], 
             UndirectedEdge[204, 318] -> 
             RGBColor[
              0.1940125074344074, 0.321249824789977, 0.9343600973313813], 
             UndirectedEdge[60, 335] -> 
             RGBColor[
              0.18275395419094043`, 0.3094163714975885, 0.9337189393797027], 
             UndirectedEdge[256, 386] -> 
             RGBColor[
              0.556034698630532, 0.6458694921919914, 0.9601976146247932], 
             UndirectedEdge[7, 65] -> 
             RGBColor[
              0.36829577629683624`, 0.4914979419428903, 0.9447588725119885], 
             UndirectedEdge[66, 280] -> 
             RGBColor[
              0.23290342941472336`, 0.362126649618162, 0.936574877804197], 
             UndirectedEdge[147, 344] -> 
             RGBColor[
              0.1873628349672718, 0.31426059741343176`, 0.9339814083216866], 
             UndirectedEdge[329, 349] -> 
             RGBColor[
              0.19621450085245074`, 0.32356425948678696`, 0.9344854975989814],
              UndirectedEdge[170, 306] -> 
             RGBColor[
              0.21718838977102684`, 0.3456091465615747, 0.9356799295448063], 
             UndirectedEdge[175, 178] -> 
             RGBColor[
              0.3616708025324146, 0.48517771913218966`, 0.9443580450417194], 
             UndirectedEdge[115, 166] -> 
             RGBColor[
              0.92715146758626, 0.7340525782000142, 0.5145919024804202], 
             UndirectedEdge[361, 396] -> 
             RGBColor[
              0.20859692759923504`, 0.3365789750888577, 0.935190658484052], 
             UndirectedEdge[80, 265] -> 
             RGBColor[
              0.18489536415726843`, 0.31166712914543293`, 0.933840889509353], 
             UndirectedEdge[18, 288] -> 
             RGBColor[
              0.45525573629442806`, 0.5643070139273578, 0.9513799079587884], 
             UndirectedEdge[225, 240] -> 
             RGBColor[
              0.8581995989845774, 0.5777442515282645, 0.5834221523927036], 
             UndirectedEdge[110, 251] -> 
             RGBColor[
              0.18685400772656674`, 0.3137257877219404, 0.9339524313630709], 
             UndirectedEdge[56, 169] -> 
             RGBColor[
              0.6387195548301612, 0.7123648726900207, 0.967730862260616], 
             UndirectedEdge[87, 231] -> 
             RGBColor[
              0.19018595982878306`, 0.3172278806393347, 0.9341421811061108], 
             UndirectedEdge[266, 315] -> 
             RGBColor[
              0.22579916171770553`, 0.3546596138320083, 0.9361703002686741], 
             UndirectedEdge[31, 292] -> 
             RGBColor[
              0.19543097961487327`, 0.32274072898797734`, 0.9344408772236172],
              UndirectedEdge[1, 87] -> 
             RGBColor[
              0.19586287681444192`, 0.32319468032858806`, 0.934465473130198], 
             UndirectedEdge[231, 336] -> 
             RGBColor[
              0.1812731232878139, 0.3078599243283004, 0.9336346082504626], 
             UndirectedEdge[13, 309] -> 
             RGBColor[
              0.25587961899129924`, 0.38627608163770166`, 0.9378833378103566],
              UndirectedEdge[237, 296] -> 
             RGBColor[
              0.2211466738327187, 0.34976955408011773`, 0.935905347966363], 
             UndirectedEdge[95, 312] -> 
             RGBColor[
              0.43115946169626646`, 0.5444500738116986, 0.9495097680739197], 
             UndirectedEdge[108, 236] -> 
             RGBColor[
              0.2534644343240474, 0.3837375694208677, 0.9377457966165021], 
             UndirectedEdge[48, 176] -> 
             RGBColor[
              0.2369284794639835, 0.36635723242284735`, 0.9368040984499744], 
             UndirectedEdge[49, 52] -> 
             RGBColor[
              0.1835216269875808, 0.31022324428012404`, 0.9337626572098012], 
             UndirectedEdge[310, 390] -> 
             RGBColor[
              0.27115500533733905`, 0.4023314812028227, 0.9387532484648545], 
             UndirectedEdge[343, 358] -> 
             RGBColor[
              0.18639835798283702`, 0.3132468709514181, 0.933926482784239], 
             UndirectedEdge[271, 374] -> 
             RGBColor[
              0.184659451088446, 0.3114191695523481, 0.9338274546090857], 
             UndirectedEdge[57, 167] -> 
             RGBColor[
              0.2639676028821611, 0.3946376054360735, 0.9383490428444853], 
             UndirectedEdge[34, 214] -> 
             RGBColor[
              0.25149658822823806`, 0.38166923840552336`, 0.9376337306925131],
              UndirectedEdge[83, 220] -> 
             RGBColor[
              0.790428504618827, 0.8368778917698232, 0.9711999364788909], 
             UndirectedEdge[9, 347] -> 
             RGBColor[
              0.19444294915612814`, 0.3217022463310869, 0.9343846103506517], 
             UndirectedEdge[188, 238] -> 
             RGBColor[
              0.2458833929201038, 0.375769414239536, 0.9373140675236933], 
             UndirectedEdge[79, 137] -> 
             RGBColor[
              0.2827537056275888, 0.4121446936308188, 0.939500838618308], 
             UndirectedEdge[115, 197] -> 
             RGBColor[
              0.914459777232721, 0.7255013666531043, 0.5770167261447392], 
             UndirectedEdge[67, 194] -> 
             RGBColor[
              0.709877099853931, 0.7667201163798876, 0.7972498678529694], 
             UndirectedEdge[75, 260] -> 
             RGBColor[
              0.22127423884363956`, 0.34990363299468435`, 0.9359126126050195],
              UndirectedEdge[32, 387] -> 
             RGBColor[
              0.7455791435710649, 0.7496942133696903, 0.622023162461701], 
             UndirectedEdge[76, 144] -> 
             RGBColor[
              0.19222334020881804`, 0.31936929659612845`, 0.9342582069047196],
              UndirectedEdge[50, 164] -> 
             RGBColor[
              0.18999442899880858`, 0.3170265695932755, 0.9341312737086882], 
             UndirectedEdge[279, 285] -> 
             RGBColor[
              0.8332166202434534, 0.8669371947579207, 0.788972494773293], 
             UndirectedEdge[137, 352] -> 
             RGBColor[
              0.28703295098175935`, 0.4166424518178782, 0.9397445353106518], 
             UndirectedEdge[4, 275] -> 
             RGBColor[
              0.235784586016354, 0.3651549278823552, 0.9367389554103707], 
             UndirectedEdge[8, 373] -> 
             RGBColor[
              0.2548317087924608, 0.38517466157737845`, 0.937823660874777], 
             UndirectedEdge[41, 135] -> 
             RGBColor[
              0.9333566323648748, 0.9460233638065111, 0.83381543555314], 
             UndirectedEdge[85, 211] -> 
             RGBColor[
              0.231317411938528, 0.36045964469136466`, 0.9364845564552302], 
             UndirectedEdge[63, 139] -> 
             RGBColor[
              0.18462055320460163`, 0.31137828541015944`, 0.9338252394321449],
              UndirectedEdge[55, 92] -> 
             RGBColor[
              0.7345108890138425, 0.7594054710903482, 0.6489345144638174], 
             UndirectedEdge[31, 371] -> 
             RGBColor[
              0.1915120199175549, 0.31862165386969954`, 0.9342176982664363], 
             UndirectedEdge[99, 169] -> 
             RGBColor[
              0.9307128082989145, 0.9468171296861931, 0.9664871194315787], 
             UndirectedEdge[71, 72] -> 
             RGBColor[
              0.18087056047954858`, 0.30743680529285733`, 0.9336116828940703],
              UndirectedEdge[104, 112] -> 
             RGBColor[
              0.8780584972468868, 0.4677393624570944, 0.21704509236247566`], 
             UndirectedEdge[389, 390] -> 
             RGBColor[
              0.23267978688900162`, 0.3618915871438733, 0.9365621416932066], 
             UndirectedEdge[260, 349] -> 
             RGBColor[
              0.21328372600725728`, 0.3415050973758713, 0.9354575647198919], 
             UndirectedEdge[70, 284] -> 
             RGBColor[
              0.24975725951810934`, 0.3798410936513683, 0.9375346784955776], 
             UndirectedEdge[24, 172] -> 
             RGBColor[
              0.8222950385758708, 0.17237501300815056`, 0.16898306015988562`],
              UndirectedEdge[343, 362] -> 
             RGBColor[
              0.18559297832352872`, 0.3124003658654654, 0.9338806176040938], 
             UndirectedEdge[233, 307] -> 
             RGBColor[
              0.6538804302709667, 0.7226974017073509, 0.9485082265240019], 
             UndirectedEdge[79, 278] -> 
             RGBColor[
              0.24460490622546205`, 0.37442564366272924`, 0.937241259597785], 
             UndirectedEdge[1, 216] -> 
             RGBColor[
              0.19662871859939152`, 0.3239996286017438, 0.9345090866868895], 
             UndirectedEdge[192, 374] -> 
             RGBColor[
              0.18592011737534742`, 0.3127442097507407, 0.933899247689136], 
             UndirectedEdge[152, 383] -> 
             RGBColor[
              0.2325615956471479, 0.3617673606549275, 0.9365554108768314], 
             UndirectedEdge[43, 121] -> 
             RGBColor[
              0.28563299292961386`, 0.4173490407437973, 0.9395850612911336], 
             UndirectedEdge[13, 280] -> 
             RGBColor[
              0.23284937828008462`, 0.36206983844861684`, 0.9365717996720409],
              UndirectedEdge[246, 272] -> 
             RGBColor[
              0.8305893181173114, 0.8683923303180165, 0.9835339903359117], 
             UndirectedEdge[385, 387] -> 
             RGBColor[
              0.7642756795140044, 0.8115756260652711, 0.7955379877927361], 
             UndirectedEdge[90, 268] -> 
             RGBColor[
              0.6438707815800897, 0.7211954799278018, 0.9654945731092558], 
             UndirectedEdge[195, 363] -> 
             RGBColor[
              0.21087458530257291`, 0.33897293774690507`, 0.9353203677207644],
              UndirectedEdge[88, 109] -> 
             RGBColor[
              0.18639597403767888`, 0.31324436527390603`, 0.9339263470220889],
              UndirectedEdge[63, 318] -> 
             RGBColor[
              0.18778593589765713`, 0.3147053033174152, 0.9340055032937504], 
             UndirectedEdge[257, 276] -> 
             RGBColor[
              0.27298076036949565`, 0.4029229337235066, 0.9389058299544288], 
             UndirectedEdge[16, 106] -> 
             RGBColor[
              0.2722971064429795, 0.4026970623499158, 0.9388488569979281], 
             UndirectedEdge[100, 227] -> 
             RGBColor[
              0.20880854883445307`, 0.33680140242463313`, 0.9352027100003322],
              UndirectedEdge[195, 359] -> 
             RGBColor[
              0.19452611281546262`, 0.321789656609928, 0.9343893463980213], 
             UndirectedEdge[216, 313] -> 
             RGBColor[
              0.2090389311379428, 0.3370435488326826, 0.9352158299316957], 
             UndirectedEdge[12, 47] -> 
             RGBColor[
              0.4262898849714413, 0.5411626092696967, 0.9490658048705467], 
             UndirectedEdge[386, 400] -> 
             RGBColor[
              0.8054695470793142, 0.5998653041518983, 0.5862367210785956], 
             UndirectedEdge[180, 262] -> 
             RGBColor[
              0.23634740435871976`, 0.36574648564492557`, 0.9367710070823533],
              UndirectedEdge[247, 359] -> 
             RGBColor[
              0.1924159607622266, 0.31957175301060936`, 0.9342691763602797], 
             UndirectedEdge[74, 141] -> 
             RGBColor[
              0.8643287930251963, 0.6881181472098445, 0.5981821297581387], 
             UndirectedEdge[170, 171] -> 
             RGBColor[
              0.21031358554217228`, 0.3383832914292848, 0.9352884196143345], 
             UndirectedEdge[207, 333] -> 
             RGBColor[
              0.18793493502051017`, 0.3148619108426237, 0.9340139885733725], 
             UndirectedEdge[311, 313] -> 
             RGBColor[
              0.2605556138292256, 0.39119084868755866`, 0.938149628798862], 
             UndirectedEdge[161, 195] -> 
             RGBColor[
              0.20065168741435874`, 0.3282280238972294, 0.9347381888094528], 
             UndirectedEdge[87, 129] -> 
             RGBColor[
              0.1936336407966272, 0.32085161193213774`, 0.9343385214368426], 
             UndirectedEdge[198, 367] -> 
             RGBColor[
              0.36419518981338295`, 0.4898693012590379, 0.9444271733431154], 
             UndirectedEdge[322, 330] -> 
             RGBColor[
              0.19291768102176954`, 0.3200990928142907, 0.934297748586832], 
             UndirectedEdge[79, 314] -> 
             RGBColor[
              0.23185910927542647`, 0.36102900293803986`, 0.9365154053171973],
              UndirectedEdge[56, 274] -> 
             RGBColor[
              0.43736444745775693`, 0.5521652442024196, 0.9493877477928349], 
             UndirectedEdge[249, 316] -> 
             RGBColor[
              0.271715102066897, 0.4028896300992718, 0.9387862636671344], 
             UndirectedEdge[69, 294] -> 
             RGBColor[
              0.2158880199071448, 0.3442423753864234, 0.935605875404783], 
             UndirectedEdge[6, 300] -> 
             RGBColor[
              0.6101439916355338, 0.6866719134983721, 0.9662201158700239], 
             UndirectedEdge[36, 265] -> 
             RGBColor[
              0.1914303121066489, 0.318535773779863, 0.934213045127481], 
             UndirectedEdge[167, 395] -> 
             RGBColor[
              0.389446651029121, 0.5113248488468087, 0.9461511158699245], 
             UndirectedEdge[261, 306] -> 
             RGBColor[
              0.2313412040252819, 0.36048465168304844`, 0.9364859113793738], 
             UndirectedEdge[35, 211] -> 
             RGBColor[
              0.22907054143597805`, 0.35809804133336665`, 0.9363566005040571],
              UndirectedEdge[54, 63] -> 
             RGBColor[
              0.18289690010848875`, 0.3095666167202264, 0.9337270799382376], 
             UndirectedEdge[302, 314] -> 
             RGBColor[
              0.21202470254257239`, 0.3401817838877893, 0.9353858651961364], 
             UndirectedEdge[54, 224] -> 
             RGBColor[
              0.18197335735342035`, 0.3085959147286568, 0.9336744855445955], 
             UndirectedEdge[164, 389] -> 
             RGBColor[
              0.20180063292388895`, 0.3294356384750984, 0.934803619556508], 
             UndirectedEdge[113, 210] -> 
             RGBColor[
              0.3065896783902691, 0.43957556926948627`, 0.9407712006743179], 
             UndirectedEdge[307, 348] -> 
             RGBColor[
              0.3407470767330234, 0.4695597242452613, 0.9429330803119872], 
             UndirectedEdge[18, 74] -> 
             RGBColor[
              0.7341001698400949, 0.7919819236306536, 0.974429319456183], 
             UndirectedEdge[41, 328] -> 
             RGBColor[
              0.8707008812978143, 0.7005608755905404, 0.6002433163697872], 
             UndirectedEdge[63, 290] -> 
             RGBColor[
              0.18969933550436535`, 0.3167164076206075, 0.9341144685707314], 
             UndirectedEdge[45, 288] -> 
             RGBColor[
              0.29509029119202934`, 0.4274889842208769, 0.9401163275851969], 
             UndirectedEdge[249, 315] -> 
             RGBColor[
              0.2639611950336743, 0.39473978218125394`, 0.9383446901324698], 
             UndirectedEdge[306, 342] -> 
             RGBColor[
              0.1932134040418383, 0.3204099164583054, 0.934314589575342], 
             UndirectedEdge[163, 395] -> 
             RGBColor[
              0.36771682090515007`, 0.4886248797144314, 0.9449085278741232], 
             UndirectedEdge[378, 379] -> 
             RGBColor[
              0.19896021464386793`, 0.3264501787698757, 0.934641861937483], 
             UndirectedEdge[216, 235] -> 
             RGBColor[
              0.1956123156574894, 0.32293132466613605`, 0.9344512040429815], 
             UndirectedEdge[220, 321] -> 
             RGBColor[
              0.5950920301278422, 0.6821615445050555, 0.961266970987048], 
             UndirectedEdge[133, 199] -> 
             RGBColor[
              0.18613849661309062`, 0.31297374017565216`, 0.9339116840636623],
              UndirectedEdge[317, 396] -> 
             RGBColor[
              0.19745595153076353`, 0.32486910286221293`, 0.9345561963785496],
              UndirectedEdge[177, 197] -> 
             RGBColor[
              0.9295820155952076, 0.9459496447868232, 0.9675642537426303], 
             UndirectedEdge[208, 242] -> 
             RGBColor[
              0.9226443508532682, 0.6970908441139261, 0.4815544446680411], 
             UndirectedEdge[51, 163] -> 
             RGBColor[
              0.3241863421441664, 0.4513369658591039, 0.9420198625128315], 
             UndirectedEdge[188, 228] -> 
             RGBColor[
              0.20268995802939208`, 0.3303703755474506, 0.9348542653056278], 
             UndirectedEdge[95, 125] -> 
             RGBColor[
              0.41046090544111513`, 0.5226945788232695, 0.9483310159159588], 
             UndirectedEdge[66, 203] -> 
             RGBColor[
              0.2200139191384291, 0.3485789570756236, 0.9358408392622837], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.2667189772067604, 0.39766893437715617`, 0.9385006232253336], 
             UndirectedEdge[151, 265] -> 
             RGBColor[
              0.1910010224377346, 0.31808456311929695`, 0.9341885977159134], 
             UndirectedEdge[76, 333] -> 
             RGBColor[
              0.19100459551754329`, 0.3180883186527222, 0.9341888011975227], 
             UndirectedEdge[119, 336] -> 
             RGBColor[
              0.18138462902211405`, 0.30797712392492177`, 0.9336409583370731],
              UndirectedEdge[183, 395] -> 
             RGBColor[
              0.40931291362813915`, 0.5285320070026871, 0.9474169765556877], 
             UndirectedEdge[42, 204] -> 
             RGBColor[
              0.20507426806755127`, 0.33287643657154375`, 0.9349900482350304],
              UndirectedEdge[12, 107] -> 
             RGBColor[
              0.3285473986430889, 0.45896802364421685`, 0.9421566412492507], 
             UndirectedEdge[234, 239] -> 
             RGBColor[
              0.8067428279900561, 0.5234676801505931, 0.5767481319037369], 
             UndirectedEdge[164, 287] -> 
             RGBColor[
              0.19544251078166353`, 0.3227528489753921, 0.9344415339065071], 
             UndirectedEdge[32, 194] -> 
             RGBColor[
              0.9757819569708761, 0.9287169668940988, 0.4668813870087187], 
             UndirectedEdge[6, 169] -> 
             RGBColor[
              0.6006886092479335, 0.6791324482420171, 0.965318253056975], 
             UndirectedEdge[24, 240] -> 
             RGBColor[
              0.8262378872131442, 0.20268147540152273`, 0.17275873646774914`],
              UndirectedEdge[9, 381] -> 
             RGBColor[
              0.19359903145009902`, 0.3208152353145773, 0.9343365504857577], 
             UndirectedEdge[43, 90] -> 
             RGBColor[
              0.434369237561579, 0.5419666394359329, 0.9502257108546233], 
             UndirectedEdge[88, 157] -> 
             RGBColor[
              0.189431793006949, 0.31643520349264886`, 0.9340992324212971], 
             UndirectedEdge[100, 314] -> 
             RGBColor[
              0.22141089937149833`, 0.35004727187424184`, 0.93592039521991], 
             UndirectedEdge[56, 296] -> 
             RGBColor[
              0.313305483869233, 0.43989379597440015`, 0.9414004589756761], 
             UndirectedEdge[49, 235] -> 
             RGBColor[
              0.18959591922153213`, 0.31660771055037873`, 0.9341085791664148],
              UndirectedEdge[359, 362] -> 
             RGBColor[
              0.18818450229900258`, 0.31512422187579864`, 0.9340282010606809],
              UndirectedEdge[104, 285] -> 
             RGBColor[
              0.9066040807260044, 0.5685593406329343, 0.38790788619052163`], 
             UndirectedEdge[80, 168] -> 
             RGBColor[
              0.18200651498987047`, 0.3086307655068815, 0.933676373822939], 
             UndirectedEdge[311, 386] -> 
             RGBColor[
              0.5317523136158948, 0.6242823861276408, 0.958670681032904], 
             UndirectedEdge[61, 173] -> 
             RGBColor[
              0.24592220228648118`, 0.3758102053442546, 0.937316277659695], 
             UndirectedEdge[118, 354] -> 
             RGBColor[
              0.22736699671866945`, 0.3563075078245018, 0.9362595861525749], 
             UndirectedEdge[154, 180] -> 
             RGBColor[
              0.2320279298273124, 0.36120644404191316`, 0.9365250193978796], 
             UndirectedEdge[17, 158] -> 
             RGBColor[
              0.2852162427380673, 0.4143360909345327, 0.9396556083799944], 
             UndirectedEdge[8, 237] -> 
             RGBColor[
              0.2175725261235523, 0.3460128982237305, 0.9357018055418038], 
             UndirectedEdge[55, 255] -> 
             RGBColor[
              0.9034963603733146, 0.5943883495886708, 0.2628944512543936], 
             UndirectedEdge[93, 214] -> 
             RGBColor[
              0.23703264551730702`, 0.36646671754939963`, 0.9368100305526114],
              UndirectedEdge[129, 235] -> 
             RGBColor[
              0.1903011498183676, 0.3173489526218552, 0.9341487410056093], 
             UndirectedEdge[47, 158] -> 
             RGBColor[
              0.44142989596913074`, 0.5543010784500094, 0.9500295993461311], 
             UndirectedEdge[106, 347] -> 
             RGBColor[
              0.21233497992474068`, 0.3405079050891704, 0.9354035350340366], 
             UndirectedEdge[169, 178] -> 
             RGBColor[
              0.668739474081812, 0.7383666179007873, 0.9696437049697588], 
             UndirectedEdge[230, 385] -> 
             RGBColor[
              0.9060818174117249, 0.56391734784212, 0.3996140043462989], 
             UndirectedEdge[304, 383] -> 
             RGBColor[
              0.1946222087294852, 0.32189065950839857`, 0.9343948189181637], 
             UndirectedEdge[100, 352] -> 
             RGBColor[
              0.2248749641652065, 0.3536882236068225, 0.936117668585287], 
             UndirectedEdge[87, 216] -> 
             RGBColor[
              0.198944806635749, 0.32643398397641854`, 0.9346409844742148], 
             UndirectedEdge[79, 277] -> 
             RGBColor[
              0.21942962029019444`, 0.3479648219394422, 0.9358075643072694], 
             UndirectedEdge[217, 220] -> 
             RGBColor[
              0.8144460532518553, 0.851406632354037, 0.7257595325601884], 
             UndirectedEdge[78, 104] -> 
             RGBColor[
              0.819473350823259, 0.1506862844701191, 0.16628100878134408`], 
             UndirectedEdge[170, 353] -> 
             RGBColor[
              0.2108426436010009, 0.33893936499333205`, 0.9353185486881135], 
             UndirectedEdge[78, 385] -> 
             RGBColor[
              0.9071814483660026, 0.5723695932180546, 0.4006670121899707], 
             UndirectedEdge[40, 102] -> 
             RGBColor[
              0.39926565859510593`, 0.5155146756656562, 0.9472759248895897], 
             UndirectedEdge[41, 256] -> 
             RGBColor[
              0.6115898950741928, 0.6896890172445088, 0.9656235459657501], 
             UndirectedEdge[120, 217] -> 
             RGBColor[
              0.7556843813439534, 0.80370125991605, 0.7211335984965017], 
             UndirectedEdge[210, 315] -> 
             RGBColor[
              0.26224986664151034`, 0.39297161581510254`, 0.9382461139900993],
              UndirectedEdge[83, 187] -> 
             RGBColor[
              0.6899774075909928, 0.7548276258988081, 0.9634300825559947], 
             UndirectedEdge[2, 305] -> 
             RGBColor[
              0.18360947068078184`, 0.31031557357129014`, 0.9337676597781759],
              UndirectedEdge[121, 175] -> 
             RGBColor[
              0.29627876905743955`, 0.4285384264353338, 0.9401913224925988], 
             UndirectedEdge[36, 151] -> 
             RGBColor[
              0.19244860485001886`, 0.3196060640166337, 0.9342710353927868], 
             UndirectedEdge[70, 332] -> 
             RGBColor[
              0.22563024765380635`, 0.35448207444108004`, 0.936160680862621], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.1986384662361157, 0.32611200079330077`, 0.9346235388416457], 
             UndirectedEdge[221, 400] -> 
             RGBColor[
              0.8762434284382803, 0.5179931725974458, 0.21794016454172604`], 
             UndirectedEdge[49, 216] -> 
             RGBColor[
              0.19369425198474133`, 0.320915318133817, 0.9343419731543394], 
             UndirectedEdge[75, 349] -> 
             RGBColor[
              0.2099761655665867, 0.3380286416412822, 0.935269204045893], 
             UndirectedEdge[62, 87] -> 
             RGBColor[
              0.1996423811721627, 0.3271671790429695, 0.9346807103120945], 
             UndirectedEdge[38, 189] -> 
             RGBColor[
              0.24478652953490182`, 0.3746165412765333, 0.9372516027765698], 
             UndirectedEdge[49, 361] -> 
             RGBColor[
              0.2026569249479238, 0.33033565568440915`, 0.9348523841205063], 
             UndirectedEdge[107, 270] -> 
             RGBColor[
              0.35385896317997434`, 0.4809165812630355, 0.943768558122001], 
             UndirectedEdge[5, 8] -> 
             RGBColor[
              0.2601258969540067, 0.39073918900607996`, 0.9381251570585274], 
             UndirectedEdge[162, 340] -> 
             RGBColor[
              0.23763180163327896`, 0.367096468615978, 0.9368441516070439], 
             UndirectedEdge[34, 85] -> 
             RGBColor[
              0.25199669770088307`, 0.3821948851700452, 0.9376622111871347], 
             UndirectedEdge[21, 172] -> 
             RGBColor[
              0.8935026650840421, 0.5357509007293852, 0.24098742713821833`], 
             UndirectedEdge[298, 393] -> 
             RGBColor[
              0.19018046268844432`, 0.31722210279629987`, 0.9341418680521008],
              UndirectedEdge[164, 371] -> 
             RGBColor[
              0.1937500929349124, 0.3209740105129675, 0.9343451532138425], 
             UndirectedEdge[11, 85] -> 
             RGBColor[
              0.2763549775912347, 0.40749939278433556`, 0.9390602753814483], 
             UndirectedEdge[202, 307] -> 
             RGBColor[
              0.295856931076972, 0.42463269426460054`, 0.9402940731736436], 
             UndirectedEdge[20, 265] -> 
             RGBColor[
              0.19013547399899927`, 0.31717481683124543`, 0.9341393060127917],
              UndirectedEdge[195, 247] -> 
             RGBColor[
              0.1997381438211963, 0.32726783165880646`, 0.9346861638532888], 
             UndirectedEdge[281, 355] -> 
             RGBColor[
              0.5971975343016019, 0.6813125874620714, 0.9629093916561169], 
             UndirectedEdge[298, 313] -> 
             RGBColor[
              0.20768244341745035`, 0.33561779423215604`, 0.9351385799627575],
              UndirectedEdge[67, 210] -> 
             RGBColor[
              0.365438140563206, 0.4906599829992886, 0.9445168412553058], 
             UndirectedEdge[11, 263] -> 
             RGBColor[
              0.35195866140263943`, 0.47927063537545245`, 0.9436474725731201],
              UndirectedEdge[88, 181] -> 
             RGBColor[
              0.19319654196954522`, 0.3203921933512083, 0.9343136293052701], 
             UndirectedEdge[212, 390] -> 
             RGBColor[
              0.3400236714682391, 0.46467688938800766`, 0.9430428280078589], 
             UndirectedEdge[13, 203] -> 
             RGBColor[
              0.21995986800379036`, 0.3485221459060784, 0.9358377611301275], 
             UndirectedEdge[75, 105] -> 
             RGBColor[
              0.21372122175088312`, 0.34196493314125437`, 0.9354824794552745],
              UndirectedEdge[12, 270] -> 
             RGBColor[
              0.3337876806083378, 0.46350689249828564`, 0.9424905473822769], 
             UndirectedEdge[127, 393] -> 
             RGBColor[
              0.1890837058583692, 0.31606934182949153`, 0.9340794093731344], 
             UndirectedEdge[185, 208] -> 
             RGBColor[
              0.6963078073762952, 0.755957556681333, 0.8560508247348155], 
             UndirectedEdge[246, 355] -> 
             RGBColor[
              0.8429762449225704, 0.8780690916824152, 0.9847686034374477], 
             UndirectedEdge[62, 336] -> 
             RGBColor[
              0.19072954463119351`, 0.31779922273193517`, 0.9341731374564464],
              UndirectedEdge[118, 209] -> 
             RGBColor[
              0.2868618960178613, 0.41642761918472027`, 0.9397360770801573], 
             UndirectedEdge[178, 352] -> 
             RGBColor[
              0.3406463330534576, 0.4630796686814488, 0.9431607326078082], 
             UndirectedEdge[17, 22] -> 
             RGBColor[
              0.2739758563683775, 0.40460023321935323`, 0.9389393809000012], 
             UndirectedEdge[12, 158] -> 
             RGBColor[
              0.32361612706914167`, 0.45469680405977975`, 0.941842424985111], 
             UndirectedEdge[200, 333] -> 
             RGBColor[
              0.18616349406283006`, 0.3130000140802582, 0.9339131076314446], 
             UndirectedEdge[69, 295] -> 
             RGBColor[
              0.3354255676488553, 0.4587623903805083, 0.9428205754850394], 
             UndirectedEdge[181, 340] -> 
             RGBColor[
              0.19892920598511726`, 0.3264175867034662, 0.9346400960402405], 
             UndirectedEdge[205, 284] -> 
             RGBColor[
              0.313308210862673, 0.4428213204414291, 0.9412935282095445], 
             UndirectedEdge[283, 373] -> 
             RGBColor[
              0.2404157449182508, 0.3700225695206825, 0.937002693058648], 
             UndirectedEdge[302, 379] -> 
             RGBColor[
              0.199238475276043, 0.32674264833703476`, 0.9346577084688357], 
             UndirectedEdge[254, 303] -> 
             RGBColor[
              0.20024144683233963`, 0.3277968350347721, 0.9347148262152034], 
             UndirectedEdge[38, 254] -> 
             RGBColor[
              0.20508861754811766`, 0.3328915187854286, 0.9349908654167205], 
             UndirectedEdge[158, 209] -> 
             RGBColor[
              0.336799320476102, 0.4661403761955148, 0.94268153277416], 
             UndirectedEdge[365, 370] -> 
             RGBColor[
              0.18400910577117147`, 0.3107356153896179, 0.9337904184053665], 
             UndirectedEdge[61, 164] -> 
             RGBColor[
              0.2051585954739804, 0.3329650700223671, 0.9349948505560753], 
             UndirectedEdge[163, 167] -> 
             RGBColor[
              0.2885245503262027, 0.4204485142001573, 0.9397475246726753], 
             UndirectedEdge[62, 119] -> 
             RGBColor[
              0.1917608818844465, 0.31888322357566273`, 0.9342318705872924], 
             UndirectedEdge[137, 197] -> 
             RGBColor[
              0.6493874970557305, 0.7185106775296126, 0.9439140882472267], 
             UndirectedEdge[265, 383] -> 
             RGBColor[
              0.1991683094404495, 0.3266688995950551, 0.9346537126282998], 
             UndirectedEdge[19, 338] -> 
             RGBColor[
              0.24730224830049347`, 0.3772607212049526, 0.937394869238598], 
             UndirectedEdge[69, 212] -> 
             RGBColor[
              0.32957634955032006`, 0.4536960916538069, 0.9424478684800611], 
             UndirectedEdge[45, 275] -> 
             RGBColor[
              0.261779864050582, 0.3924776132921515, 0.9382193480378523], 
             UndirectedEdge[248, 360] -> 
             RGBColor[
              0.20162405229043762`, 0.3292500410334822, 0.9347935635506606], 
             UndirectedEdge[188, 322] -> 
             RGBColor[
              0.20084485470176572`, 0.3284310549638075, 0.9347491894007052], 
             UndirectedEdge[167, 183] -> 
             RGBColor[
              0.33012064304919175`, 0.46035564148841296`, 0.9422559733542398],
              UndirectedEdge[141, 240] -> 
             RGBColor[
              0.8486432291011581, 0.36358607454286945`, 0.19377114111448232`],
              UndirectedEdge[23, 220] -> 
             RGBColor[
              0.46443936234214256`, 0.5702897109178078, 0.9522369568394528], 
             UndirectedEdge[123, 322] -> 
             RGBColor[
              0.20580146810397543`, 0.3336407699169709, 0.9350314612013086], 
             UndirectedEdge[177, 398] -> 
             RGBColor[
              0.6604733814795012, 0.7312391377896288, 0.9691021762679148], 
             UndirectedEdge[272, 395] -> 
             RGBColor[
              0.6047861017850406, 0.688521596311049, 0.9630625411341533], 
             UndirectedEdge[85, 312] -> 
             RGBColor[
              0.27182714160879756`, 0.40303793904002655`, 0.9387915256311776],
              UndirectedEdge[25, 328] -> 
             RGBColor[
              0.8434248781398908, 0.3172892303900453, 0.1885318018785458], 
             UndirectedEdge[8, 121] -> 
             RGBColor[
              0.2743592219367422, 0.4054995926319236, 0.9389430367111391], 
             UndirectedEdge[169, 319] -> 
             RGBColor[
              0.6745752376290368, 0.7434200744106859, 0.9700158830654886], 
             UndirectedEdge[84, 167] -> 
             RGBColor[
              0.32454610124482625`, 0.4555272535620894, 0.9419007684798394], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.2877186940288704, 0.4160544664052851, 0.9398315069221266], 
             UndirectedEdge[43, 213] -> 
             RGBColor[
              0.2414891450614786, 0.3711507811287148, 0.9370638216088516], 
             UndirectedEdge[170, 187] -> 
             RGBColor[
              0.33329236872326556`, 0.45597611149735384`, 0.9427190170162062],
              UndirectedEdge[89, 199] -> 
             RGBColor[
              0.18786740786844439`, 0.3147909355243339, 0.9340101430019597], 
             UndirectedEdge[16, 373] -> 
             RGBColor[
              0.29481332974402036`, 0.42636304065032193`, 0.9401311226051551],
              UndirectedEdge[22, 158] -> 
             RGBColor[
              0.3275157516971413, 0.458099415524913, 0.9420899919807021], 
             UndirectedEdge[233, 264] -> 
             RGBColor[
              0.8413490098710985, 0.8765030596973409, 0.9633266229040078], 
             UndirectedEdge[274, 296] -> 
             RGBColor[
              0.36901952314668135`, 0.4870709060931353, 0.9452488023460986], 
             UndirectedEdge[97, 211] -> 
             RGBColor[
              0.20738956458852648`, 0.33530996001336677`, 0.9351219009467256],
              UndirectedEdge[1, 129] -> 
             RGBColor[
              0.19131755276026974`, 0.31841725655746295`, 0.9342066236495172],
              UndirectedEdge[24, 141] -> 
             RGBColor[
              0.8431921928460754, 0.3216870212269862, 0.1885512226405503], 
             UndirectedEdge[347, 384] -> 
             RGBColor[
              0.19370455937175246`, 0.32092615185109175`, 0.9343425601447813],
              UndirectedEdge[36, 378] -> 
             RGBColor[
              0.1918482442519195, 0.31897504696297085`, 0.934236845744879], 
             UndirectedEdge[174, 395] -> 
             RGBColor[
              0.4063176896518592, 0.5259376945387678, 0.9472261235324917], 
             UndirectedEdge[104, 357] -> 
             RGBColor[
              0.8380548061555597, 0.2935114925998279, 0.18407463139230737`], 
             UndirectedEdge[47, 173] -> 
             RGBColor[
              0.41329174036295263`, 0.5275007351562074, 0.948325579764125], 
             UndirectedEdge[127, 231] -> 
             RGBColor[
              0.1884985570631651, 0.31545431334515556`, 0.9340460860148976], 
             UndirectedEdge[252, 367] -> 
             RGBColor[
              0.372324185998124, 0.4969102291790325, 0.9449451457918181], 
             UndirectedEdge[158, 310] -> 
             RGBColor[
              0.30917761379090525`, 0.4395210111497373, 0.9410201730137817], 
             UndirectedEdge[149, 397] -> 
             RGBColor[
              0.21476341163145843`, 0.34306034078439396`, 0.9355418306271915],
              UndirectedEdge[204, 345] -> 
             RGBColor[
              0.18631088399028722`, 0.3131549302390768, 0.9339215012697695], 
             UndirectedEdge[231, 396] -> 
             RGBColor[
              0.19087540782908663`, 0.31795253420118175`, 0.9341814441497811],
              UndirectedEdge[162, 263] -> 
             RGBColor[
              0.33214075614847005`, 0.45873834938016844`, 0.9425079759974546],
              UndirectedEdge[14, 196] -> 
             RGBColor[
              0.18714224683050756`, 0.3140287452955969, 0.9339688461536289], 
             UndirectedEdge[43, 175] -> 
             RGBColor[
              0.2710055822533935, 0.4021744280676252, 0.9387447390412754], 
             UndirectedEdge[113, 397] -> 
             RGBColor[
              0.2602244815922864, 0.3908428077115391, 0.9381307713078346], 
             UndirectedEdge[126, 336] -> 
             RGBColor[
              0.18346975723563688`, 0.31016872588209876`, 0.9337597033041625],
              UndirectedEdge[48, 173] -> 
             RGBColor[
              0.2613339339978391, 0.3920089125331203, 0.938193952981043], 
             UndirectedEdge[28, 168] -> 
             RGBColor[
              0.19559687276408316`, 0.32291509320603007`, 0.9344503245930478],
              UndirectedEdge[253, 359] -> 
             RGBColor[
              0.18914843365842357`, 0.3161373748513282, 0.9340830955255912], 
             UndirectedEdge[41, 187] -> 
             RGBColor[
              0.6533956652271913, 0.7258990741319324, 0.9682873726725081], 
             UndirectedEdge[198, 398] -> 
             RGBColor[
              0.38970123207440616`, 0.5119613530945772, 0.9460523958018803], 
             UndirectedEdge[260, 329] -> 
             RGBColor[
              0.20751257412950358`, 0.3354392508401891, 0.9351289061581081], 
             UndirectedEdge[60, 82] -> 
             RGBColor[
              0.18336573314646784`, 0.31005938996887394`, 0.9337537792861741],
              UndirectedEdge[12, 17] -> 
             RGBColor[0.2700762317403779, 0.40119762175422, 0.93869181390441],
              UndirectedEdge[268, 351] -> 
             RGBColor[
              0.7945761589543001, 0.8401740652758038, 0.979966961918109], 
             UndirectedEdge[122, 274] -> 
             RGBColor[
              0.5455206538470523, 0.6419172680752578, 0.9573645306602898], 
             UndirectedEdge[150, 384] -> 
             RGBColor[
              0.19155187583051508`, 0.31866354496123156`, 0.9342199680017178],
              UndirectedEdge[179, 232] -> 
             RGBColor[
              0.374520452238133, 0.49753308772821003`, 0.9451360369712756], 
             UndirectedEdge[4, 131] -> 
             RGBColor[
              0.22303764420255517`, 0.35175708383326204`, 0.9360130359314853],
              UndirectedEdge[128, 155] -> 
             RGBColor[
              0.2008465417565683, 0.32843282816537045`, 0.9347492854759805], 
             UndirectedEdge[316, 362] -> 
             RGBColor[
              0.2117594365618467, 0.339902972523212, 0.9353707586909601], 
             UndirectedEdge[283, 320] -> 
             RGBColor[
              0.20238649627655553`, 0.330051418004633, 0.9348369836077353], 
             UndirectedEdge[49, 396] -> 
             RGBColor[
              0.1936178582000953, 0.3208350234225083, 0.9343376226413184], 
             UndirectedEdge[371, 389] -> 
             RGBColor[
              0.194598112629328, 0.3218653329793524, 0.9343934466809067], 
             UndirectedEdge[53, 58] -> 
             RGBColor[
              0.20217788494718347`, 0.3298321542707407, 0.9348251035011402], 
             UndirectedEdge[18, 399] -> 
             RGBColor[
              0.7658581753592988, 0.7184623790314186, 0.610918793426945], 
             UndirectedEdge[241, 270] -> 
             RGBColor[
              0.31115624108701556`, 0.43971981464523346`, 0.9412017203817521],
              UndirectedEdge[137, 169] -> 
             RGBColor[
              0.6151260920101136, 0.6919294010372166, 0.9662275076726026], 
             UndirectedEdge[156, 386] -> 
             RGBColor[
              0.795873240259372, 0.5261038848053603, 0.5770472868303405], 
             UndirectedEdge[19, 262] -> 
             RGBColor[
              0.23727783738368446`, 0.36672442974702457`, 0.9368239938666727],
              UndirectedEdge[85, 181] -> 
             RGBColor[
              0.2178344766889036, 0.34628822487653976`, 0.9357167232389794], 
             UndirectedEdge[74, 240] -> 
             RGBColor[
              0.8473744873922651, 0.569112601384381, 0.5823896435853375], 
             UndirectedEdge[72, 88] -> 
             RGBColor[
              0.18714176336881175`, 0.31402823714670136`, 0.9339688186212005],
              UndirectedEdge[63, 98] -> 
             RGBColor[
              0.19109841618892076`, 0.3181869301269141, 0.9341941441459625], 
             UndirectedEdge[43, 56] -> 
             RGBColor[
              0.3210051071529382, 0.44798658822988663`, 0.9418389411311112], 
             UndirectedEdge[174, 272] -> 
             RGBColor[
              0.5424648698288314, 0.6349580764887339, 0.9589765455952728], 
             UndirectedEdge[180, 198] -> 
             RGBColor[
              0.30592577418738304`, 0.43475768207038135`, 0.9408842486890967],
              UndirectedEdge[126, 289] -> 
             RGBColor[
              0.1863769520635358, 0.31322437197301883`, 0.933925263748802], 
             UndirectedEdge[233, 244] -> 
             RGBColor[
              0.9570858882964418, 0.9675153062736708, 0.9575265767079428], 
             UndirectedEdge[51, 189] -> 
             RGBColor[
              0.324110599148695, 0.45125735516848015`, 0.9420155490612911], 
             UndirectedEdge[199, 306] -> 
             RGBColor[
              0.19460108481424115`, 0.32186845693414357`, 0.9343936159424405],
              UndirectedEdge[86, 214] -> 
             RGBColor[
              0.32538385594789154`, 0.4498732658782442, 0.9421877381945456], 
             UndirectedEdge[104, 172] -> 
             RGBColor[
              0.8214061746435448, 0.16554281532163417`, 0.16813188305446203`],
              UndirectedEdge[67, 293] -> 
             RGBColor[
              0.3870584168095417, 0.509672279343909, 0.9458839979501529], 
             UndirectedEdge[296, 380] -> 
             RGBColor[
              0.23254239925943204`, 0.3617471840343169, 0.9365543176709494], 
             UndirectedEdge[290, 297] -> 
             RGBColor[
              0.20256888353236238`, 0.33024311857450594`, 0.9348473702921356],
              UndirectedEdge[206, 328] -> 
             RGBColor[
              0.7999219852902167, 0.6448484807342735, 0.5933000289298582], 
             UndirectedEdge[5, 319] -> 
             RGBColor[
              0.3679006517731242, 0.4906453846924169, 0.9447526657346955], 
             UndirectedEdge[235, 393] -> 
             RGBColor[
              0.18743861764572758`, 0.31434024981338815`, 0.9339857240331143],
              UndirectedEdge[40, 189] -> 
             RGBColor[
              0.3938515783304093, 0.5098241340349448, 0.9469676010279292], 
             UndirectedEdge[15, 256] -> 
             RGBColor[
              0.31856719551894513`, 0.448229479012007, 0.9415973902435224], 
             UndirectedEdge[71, 365] -> 
             RGBColor[
              0.17992874679989868`, 0.30644689940110903`, 0.9335580479983027],
              UndirectedEdge[53, 64] -> 
             RGBColor[
              0.18652020523185484`, 0.31337494013569756`, 0.9339334218048136],
              UndirectedEdge[231, 298] -> 
             RGBColor[
              0.1895953138932402, 0.3166070743119639, 0.934108544693864], 
             UndirectedEdge[81, 382] -> 
             RGBColor[
              0.18072466475425025`, 0.3072834596352455, 0.9336033743483478], 
             UndirectedEdge[9, 294] -> 
             RGBColor[
              0.1904972038981096, 0.3175550178902107, 0.9341599059954147], 
             UndirectedEdge[175, 213] -> 
             RGBColor[
              0.25213492118930436`, 0.3823401668202513, 0.9376700828103168], 
             UndirectedEdge[174, 189] -> 
             RGBColor[
              0.3053198459534695, 0.4349817492014926, 0.9408182188837021], 
             UndirectedEdge[14, 127] -> 
             RGBColor[
              0.18967658911817914`, 0.3166924997265216, 0.9341131731976884], 
             UndirectedEdge[86, 95] -> 
             RGBColor[
              0.48521628550800544`, 0.5918110474144382, 0.9529344611319093], 
             UndirectedEdge[103, 200] -> 
             RGBColor[
              0.18928086975494526`, 0.31627657358570604`, 0.9340906375653665],
              UndirectedEdge[24, 112] -> 
             RGBColor[
              0.8789473611792127, 0.4745715601436108, 0.21789626946789925`], 
             UndirectedEdge[109, 360] -> 
             RGBColor[
              0.18328589355082267`, 0.3099754734917281, 0.9337492325393142], 
             UndirectedEdge[90, 121] -> 
             RGBColor[
              0.4596424243656251, 0.5683306378036415, 0.9516722943059467], 
             UndirectedEdge[75, 202] -> 
             RGBColor[
              0.23066301686818202`, 0.3597718339813871, 0.9364472896240648], 
             UndirectedEdge[27, 32] -> 
             RGBColor[
              0.8890352414528142, 0.5147182506008601, 0.2276791825593331], 
             UndirectedEdge[131, 273] -> 
             RGBColor[
              0.19754073794696791`, 0.32495821876141306`, 0.9345610248395222],
              UndirectedEdge[160, 220] -> 
             RGBColor[
              0.5477229997143326, 0.6437052316648666, 0.9575379073944208], 
             UndirectedEdge[50, 147] -> 
             RGBColor[
              0.18125622821196816`, 0.30784216653237684`, 0.9336336461008872],
              UndirectedEdge[13, 339] -> 
             RGBColor[
              0.2328552355524508, 0.3620759948132462, 0.936572133235037], 
             UndirectedEdge[17, 209] -> 
             RGBColor[
              0.2832594251473382, 0.412641193889955, 0.9395309216934591], 
             UndirectedEdge[174, 325] -> 
             RGBColor[
              0.31656779052141654`, 0.4468040521032807, 0.9414587726870038], 
             UndirectedEdge[21, 78] -> 
             RGBColor[
              0.8915698412637564, 0.5208943698778701, 0.23913655286510038`], 
             UndirectedEdge[274, 373] -> 
             RGBColor[
              0.38246482009015115`, 0.5012027656617852, 0.9460144921164949], 
             UndirectedEdge[97, 305] -> 
             RGBColor[
              0.18756138502713113`, 0.3144692861151448, 0.9339927154538672], 
             UndirectedEdge[11, 162] -> 
             RGBColor[
              0.29214677471105677`, 0.42409757281503596`, 0.9399595948655519],
              UndirectedEdge[103, 207] -> 
             RGBColor[
              0.19105231071262538`, 0.3181384703480716, 0.9341915185072943], 
             UndirectedEdge[210, 249] -> 
             RGBColor[
              0.3073650774594488, 0.4403600145758346, 0.9408164770263279], 
             UndirectedEdge[52, 299] -> 
             RGBColor[
              0.18351379325327066`, 0.3102150105286766, 0.9337622110902213], 
             UndirectedEdge[43, 373] -> 
             RGBColor[
              0.2661054797853324, 0.3970241096892522, 0.9384656854547713], 
             UndirectedEdge[1, 336] -> 
             RGBColor[
              0.18695004027347276`, 0.31382672401755374`, 0.9339579002745498],
              UndirectedEdge[30, 345] -> 
             RGBColor[
              0.1795989351746539, 0.30610024647171197`, 0.9335392657141575], 
             UndirectedEdge[247, 363] -> 
             RGBColor[
              0.20876443324933688`, 0.3367550341475864, 0.9352001976830229], 
             UndirectedEdge[14, 119] -> 
             RGBColor[
              0.18348249259608096`, 0.310182111553394, 0.9337604285640995], 
             UndirectedEdge[74, 104] -> 
             RGBColor[
              0.8410345872048564, 0.5203813503819814, 0.5763185480059819], 
             UndirectedEdge[258, 277] -> 
             RGBColor[
              0.19561158896014919`, 0.3229305608611562, 0.9344511626586431], 
             UndirectedEdge[152, 236] -> 
             RGBColor[
              0.2537723278978401, 0.38406118508850384`, 0.9377633307000419], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.26676233186552467`, 0.3975147794964234, 0.938510405060175], 
             UndirectedEdge[120, 132] -> 
             RGBColor[
              0.4382862950940797, 0.5522789014915227, 0.9496356996104882], 
             UndirectedEdge[212, 270] -> 
             RGBColor[
              0.38821783346100136`, 0.5106765077734281, 0.9459578749539519], 
             UndirectedEdge[69, 270] -> 
             RGBColor[
              0.300457761234542, 0.4284750339974831, 0.9405924577811364], 
             UndirectedEdge[16, 270] -> 
             RGBColor[
              0.3384373755940835, 0.46755917720766627`, 0.9427859081978025], 
             UndirectedEdge[24, 73] -> 
             RGBColor[
              0.8757010840349191, 0.46170115302421727`, 0.21528423867768243`],
              UndirectedEdge[56, 178] -> 
             RGBColor[
              0.4116703274319593, 0.5309898792944511, 0.9474522471315552], 
             UndirectedEdge[6, 319] -> 
             RGBColor[
              0.37947514539695637`, 0.5028109113563464, 0.945411816023644], 
             UndirectedEdge[231, 235] -> 
             RGBColor[
              0.18685346885052345`, 0.3137252213290522, 0.9339524006748775], 
             UndirectedEdge[18, 86] -> 
             RGBColor[
              0.5080814719938581, 0.6103740358685661, 0.9547344923700136], 
             UndirectedEdge[30, 63] -> 
             RGBColor[
              0.18069605079375822`, 0.30725338454853857`, 0.9336017448256284],
              UndirectedEdge[46, 358] -> 
             RGBColor[
              0.19603463800818394`, 0.3233752122334996, 0.9344752546760837], 
             UndirectedEdge[241, 389] -> 
             RGBColor[
              0.23293094482355622`, 0.362155570057423, 0.9365764447660246], 
             UndirectedEdge[286, 332] -> 
             RGBColor[
              0.2115950206250406, 0.3397301609490563, 0.9353613954465905], 
             UndirectedEdge[40, 174] -> 
             RGBColor[
              0.4325281900725898, 0.5472165595499049, 0.9492895101378381], 
             UndirectedEdge[157, 365] -> 
             RGBColor[
              0.18416233691758455`, 0.3108966710399138, 0.9337991446924696], 
             UndirectedEdge[235, 336] -> 
             RGBColor[
              0.18593363733157064`, 0.312758420081946, 0.9339000176306419], 
             UndirectedEdge[76, 222] -> 
             RGBColor[
              0.21314128516619657`, 0.3413553830206456, 0.9354494529247159], 
             UndirectedEdge[115, 392] -> 
             RGBColor[
              0.9278459781809479, 0.7343397761790258, 0.5030820645906373], 
             UndirectedEdge[76, 77] -> 
             RGBColor[
              0.1883529029244576, 0.3153012216103682, 0.9340377912271741], 
             UndirectedEdge[160, 366] -> 
             RGBColor[
              0.4270114418839008, 0.5441063729670104, 0.948477074824805], 
             UndirectedEdge[3, 348] -> 
             RGBColor[
              0.45750426505624076`, 0.5671984745069012, 0.9513371690188597], 
             UndirectedEdge[299, 306] -> 
             RGBColor[
              0.19518727715711093`, 0.32248458225324084`, 0.9344269987291731],
              UndirectedEdge[56, 121] -> 
             RGBColor[
              0.3462782939569843, 0.4743505865975952, 0.9432855245824346], 
             UndirectedEdge[280, 322] -> 
             RGBColor[
              0.22572058379982396`, 0.354577023458187, 0.9361658253724963], 
             UndirectedEdge[81, 271] -> 
             RGBColor[
              0.1793288256722832, 0.3058163442587888, 0.9335238833775887], 
             UndirectedEdge[2, 191] -> 
             RGBColor[
              0.19610476461646903`, 0.323448919745091, 0.9344792482826825], 
             UndirectedEdge[146, 377] -> 
             RGBColor[
              0.18543930213235216`, 0.3122388424449055, 0.9338718659723498], 
             UndirectedEdge[10, 396] -> 
             RGBColor[
              0.21852942039278686`, 0.3470186547712968, 0.9357562992548385], 
             UndirectedEdge[382, 384] -> 
             RGBColor[
              0.18572468011707222`, 0.3125387928008556, 0.9338881178264007], 
             UndirectedEdge[147, 391] -> 
             RGBColor[
              0.18230154859335337`, 0.30894086453035285`, 0.9336931755501943],
              UndirectedEdge[133, 216] -> 
             RGBColor[
              0.19274891912622777`, 0.3199217133619542, 0.9342881378465417], 
             UndirectedEdge[86, 264] -> 
             RGBColor[
              0.5671571608223211, 0.6570945561668415, 0.9602327949234224], 
             UndirectedEdge[6, 56] -> 
             RGBColor[
              0.34361946259808085`, 0.47175570963568103`, 0.9431267952187714],
              UndirectedEdge[43, 308] -> 
             RGBColor[
              0.23093015114267265`, 0.3600526090411681, 0.9364625025258073], 
             UndirectedEdge[201, 364] -> 
             RGBColor[
              0.8833604425346897, 0.5491985864535379, 0.5678503651913112], 
             UndirectedEdge[109, 365] -> 
             RGBColor[
              0.1811265179483144, 0.30770583282117103`, 0.9336262592932614], 
             UndirectedEdge[229, 349] -> 
             RGBColor[
              0.20443433824615148`, 0.33220382975535845`, 0.934953605178393], 
             UndirectedEdge[216, 231] -> 
             RGBColor[
              0.19095180161373265`, 0.3180328289124904, 0.9341857946628023], 
             UndirectedEdge[114, 353] -> 
             RGBColor[
              0.2156557406567855, 0.3439982351669406, 0.9355926474451014], 
             UndirectedEdge[70, 236] -> 
             RGBColor[
              0.23684558512377027`, 0.36627010521547854`, 0.9367993777399305],
              UndirectedEdge[64, 94] -> 
             RGBColor[
              0.1809149928406964, 0.30748350652159806`, 0.9336142132513059], 
             UndirectedEdge[240, 285] -> 
             RGBColor[
              0.912943980913413, 0.617290591635334, 0.3939789817698772], 
             UndirectedEdge[56, 90] -> 
             RGBColor[
              0.4950145385889495, 0.5989681852897308, 0.9539261741459244], 
             UndirectedEdge[90, 295] -> 
             RGBColor[
              0.5187067634857201, 0.6194891996894659, 0.9554358217661347], 
             UndirectedEdge[165, 281] -> 
             RGBColor[
              0.6627187385434833, 0.7331187175098175, 0.9692752800168635], 
             UndirectedEdge[54, 345] -> 
             RGBColor[
              0.1817997844893844, 0.30841347864339985`, 0.9336646008267666], 
             UndirectedEdge[101, 136] -> 
             RGBColor[
              0.18384486237801373`, 0.31056298516977654`, 0.9337810649871026],
              UndirectedEdge[6, 314] -> 
             RGBColor[
              0.26913140342587094`, 0.400204547290098, 0.9386380073296472], 
             UndirectedEdge[125, 276] -> 
             RGBColor[
              0.2421845103154749, 0.3718816540993685, 0.9371034216313661], 
             UndirectedEdge[244, 341] -> 
             RGBColor[
              0.6455002366075493, 0.7157181703634723, 0.9520500486891706], 
             UndirectedEdge[46, 153] -> 
             RGBColor[
              0.1918690303202028, 0.3189968944386494, 0.9342380294807175], 
             UndirectedEdge[14, 336] -> 
             RGBColor[
              0.18245115534282794`, 0.3090981107096664, 0.9337016954332534], 
             UndirectedEdge[109, 370] -> 
             RGBColor[
              0.1842051301196885, 0.31094164940857083`, 0.9338015817020224], 
             UndirectedEdge[51, 234] -> 
             RGBColor[
              0.5836503518814267, 0.668728614845342, 0.9624059730547245], 
             UndirectedEdge[144, 228] -> 
             RGBColor[
              0.19707272190642572`, 0.32446630422887235`, 0.934534372018381], 
             UndirectedEdge[320, 347] -> 
             RGBColor[
              0.1968219545840863, 0.324202731873527, 0.9345200911903508], 
             UndirectedEdge[31, 106] -> 
             RGBColor[
              0.21164758701888683`, 0.33978541156189057`, 0.935364389024955], 
             UndirectedEdge[77, 103] -> 
             RGBColor[
              0.18857832587467818`, 0.31553815542369057`, 0.9340506287307058],
              UndirectedEdge[266, 316] -> 
             RGBColor[
              0.23355306875092818`, 0.36280946175002615`, 0.9366118738033387],
              UndirectedEdge[109, 334] -> 
             RGBColor[
              0.18315174728548578`, 0.30983447726149455`, 0.9337415931079549],
              UndirectedEdge[45, 179] -> 
             RGBColor[
              0.3693787364367489, 0.49212881841734446`, 0.9448432238628737], 
             UndirectedEdge[181, 191] -> 
             RGBColor[
              0.2010737277844803, 0.3286716150851321, 0.9347622233841785], 
             UndirectedEdge[125, 148] -> 
             RGBColor[
              0.2977450564931756, 0.4279464199660071, 0.9403529311058223], 
             UndirectedEdge[18, 112] -> 
             RGBColor[
              0.7711240798821252, 0.7393399357057666, 0.6151558638126768], 
             UndirectedEdge[221, 239] -> 
             RGBColor[
              0.8650356462249088, 0.43184524722399015`, 0.20720757963682196`],
              UndirectedEdge[57, 76] -> 
             RGBColor[
              0.20578868678679324`, 0.33362733594223004`, 0.9350307333242034],
              UndirectedEdge[222, 333] -> 
             RGBColor[
              0.21024933242430197`, 0.33831575732852015`, 0.9352847604943257],
              UndirectedEdge[125, 214] -> 
             RGBColor[
              0.25062847588100123`, 0.38075679728707557`, 0.9375842929785951],
              UndirectedEdge[220, 244] -> 
             RGBColor[
              0.7952939705328516, 0.8405065482820335, 0.9629639718031929], 
             UndirectedEdge[143, 379] -> 
             RGBColor[
              0.19607245739300067`, 0.3234149628048294, 0.9344774084341002], 
             UndirectedEdge[31, 241] -> 
             RGBColor[
              0.22984485211178313`, 0.3589118909477702, 0.9364006963515542], 
             UndirectedEdge[81, 374] -> 
             RGBColor[
              0.1848884604275577, 0.3116598728877852, 0.9338404963521592], 
             UndirectedEdge[168, 304] -> 
             RGBColor[
              0.18254777981600245`, 0.3091996691573183, 0.9337071980540577], 
             UndirectedEdge[156, 328] -> 
             RGBColor[
              0.850258311685, 0.36981399504742796`, 0.1950755055586017], 
             UndirectedEdge[46, 363] -> 
             RGBColor[
              0.21059715829347625`, 0.33868134437045616`, 0.9353045686630128],
              UndirectedEdge[51, 269] -> 
             RGBColor[
              0.5625797337470475, 0.652268087816136, 0.9603058507552114], 
             UndirectedEdge[13, 325] -> 
             RGBColor[
              0.25165090865355244`, 0.3818314389570088, 0.9376425190124382], 
             UndirectedEdge[164, 374] -> 
             RGBColor[
              0.1955858495365969, 0.322903507095029, 0.9344496968365499], 
             UndirectedEdge[49, 199] -> 
             RGBColor[
              0.18708382947160418`, 0.313967344947515, 0.93396551937146], 
             UndirectedEdge[49, 313] -> 
             RGBColor[
              0.20302253470198556`, 0.3307199347169253, 0.9348732050551289], 
             UndirectedEdge[176, 388] -> 
             RGBColor[
              0.22659156217478169`, 0.35549247695348607`, 0.9362154263024531],
              UndirectedEdge[45, 232] -> 
             RGBColor[
              0.28995111396047296`, 0.4220873831078549, 0.9398236590445912], 
             UndirectedEdge[176, 250] -> 
             RGBColor[
              0.24600820440775967`, 0.3759005990265677, 0.9373211753532731], 
             UndirectedEdge[346, 390] -> 
             RGBColor[
              0.30688867117659013`, 0.43597701754892004`, 0.9409314950894052],
              UndirectedEdge[331, 335] -> 
             RGBColor[
              0.18932527309814626`, 0.31632324431474484`, 0.9340931662700729],
              UndirectedEdge[135, 355] -> 
             RGBColor[
              0.8802746969932166, 0.9041359691009224, 0.8286360157619015], 
             UndirectedEdge[326, 327] -> 
             RGBColor[
              0.19380937140054372`, 0.3210363159388178, 0.9343485290347655], 
             UndirectedEdge[80, 304] -> 
             RGBColor[
              0.18034926344630414`, 0.30688888905877654`, 0.9335819957992169],
              UndirectedEdge[65, 173] -> 
             RGBColor[
              0.2852130264023293, 0.4171073526721437, 0.9395538319675272], 
             UndirectedEdge[203, 257] -> 
             RGBColor[
              0.27443071882287484`, 0.40444693199068393`, 0.9389884029433275],
              UndirectedEdge[275, 325] -> 
             RGBColor[
              0.2639447266446291, 0.3947530211387112, 0.9383426337599561], 
             UndirectedEdge[240, 337] -> 
             RGBColor[
              0.9128678714659045, 0.6171278012229586, 0.3856949381016387], 
             UndirectedEdge[77, 254] -> 
             RGBColor[
              0.18502833391359902`, 0.3118068887901059, 0.9338484619402648], 
             UndirectedEdge[32, 364] -> 
             RGBColor[
              0.8873546832703587, 0.5018007439852152, 0.22606987814589463`], 
             UndirectedEdge[38, 53] -> 
             RGBColor[
              0.2076634431002256, 0.3355978236940631, 0.9351374979228], 
             UndirectedEdge[28, 291] -> 
             RGBColor[
              0.1970819328198578, 0.3244759854828951, 0.9345348965662746], 
             UndirectedEdge[174, 269] -> 
             RGBColor[
              0.543788980551822, 0.6359924818491485, 0.9591085205776222], 
             UndirectedEdge[216, 361] -> 
             RGBColor[
              0.20867332138388106`, 0.3366592698001664, 0.9351950089970731], 
             UndirectedEdge[356, 363] -> 
             RGBColor[
              0.2074463229173425, 0.3353696166156383, 0.9351251332495853], 
             UndirectedEdge[151, 383] -> 
             RGBColor[
              0.20018660218381945`, 0.3277391898318258, 0.9347117028936056], 
             UndirectedEdge[61, 130] -> 
             RGBColor[
              0.19568837198846437`, 0.3230112646922406, 0.9344555353385153], 
             UndirectedEdge[331, 338] -> 
             RGBColor[
              0.2166739251358942, 0.34506841161110846`, 0.9356506315449178], 
             UndirectedEdge[239, 246] -> 
             RGBColor[
              0.874004135287985, 0.576823099817974, 0.5832370617608514], 
             UndirectedEdge[190, 212] -> 
             RGBColor[
              0.6867778683351773, 0.7513832913392242, 0.9534033725466657], 
             UndirectedEdge[111, 286] -> 
             RGBColor[
              0.1920478961746871, 0.3191848937924626, 0.934248215626522], 
             UndirectedEdge[228, 273] -> 
             RGBColor[
              0.1927101706170558, 0.31988098622201705`, 0.9342859311762677], 
             UndirectedEdge[199, 299] -> 
             RGBColor[
              0.18707599573729403`, 0.31395911119606756`, 0.93396507325188], 
             UndirectedEdge[50, 391] -> 
             RGBColor[
              0.18008156514952903`, 0.3066075211758136, 0.9335667507772396], 
             UndirectedEdge[358, 362] -> 
             RGBColor[
              0.18997045450082056`, 0.31700137087581914`, 0.9341299083964949],
              UndirectedEdge[42, 98] -> 
             RGBColor[
              0.20876468464708048`, 0.33675529838255447`, 0.9352002119997525],
              UndirectedEdge[39, 251] -> 
             RGBColor[
              0.18672478342346222`, 0.3135899647860835, 0.9339450722301794], 
             UndirectedEdge[148, 179] -> 
             RGBColor[
              0.39396314610535543`, 0.515635700812435, 0.9463286881882242], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.19127206346984504`, 0.31836944442903903`, 0.934204033101723], 
             UndirectedEdge[77, 333] -> 
             RGBColor[
              0.18546095018256298`, 0.31226159591824276`, 0.9338730987967839],
              UndirectedEdge[173, 354] -> 
             RGBColor[
              0.24916626557073213`, 0.3792199215414943, 0.9375010222645717], 
             UndirectedEdge[160, 217] -> 
             RGBColor[
              0.7263465347719837, 0.7798834744139984, 0.7188240157462833], 
             UndirectedEdge[59, 90] -> 
             RGBColor[
              0.47744540309430256`, 0.5837506831746934, 0.9528066843679821], 
             UndirectedEdge[237, 380] -> 
             RGBColor[
              0.20872851353399335`, 0.33671728024931885`, 0.9351981521083725],
              UndirectedEdge[285, 399] -> 
             RGBColor[
              0.9603875503566552, 0.868303119703074, 0.4348794443842956], 
             UndirectedEdge[51, 392] -> 
             RGBColor[
              0.6863309387769014, 0.7477531849917098, 0.8714804732443268], 
             UndirectedEdge[264, 307] -> 
             RGBColor[
              0.5358230864206805, 0.6299545558165122, 0.958236215410184], 
             UndirectedEdge[78, 208] -> 
             RGBColor[
              0.9064764270189856, 0.5728170966942296, 0.4660720225452738], 
             UndirectedEdge[28, 383] -> 
             RGBColor[
              0.20767130167756592`, 0.3356060835571104, 0.9351379454571538], 
             UndirectedEdge[255, 268] -> 
             RGBColor[
              0.7573621449450872, 0.5111257415751345, 0.5750858104368912], 
             UndirectedEdge[46, 247] -> 
             RGBColor[
              0.1994607168120997, 0.32697623828235756`, 0.9346703647955372], 
             UndirectedEdge[272, 392] -> 
             RGBColor[
              0.8660085977148573, 0.8940614807970035, 0.8861195606683994], 
             UndirectedEdge[316, 359] -> 
             RGBColor[
              0.21077886401933704`, 0.3388723286091443, 0.9353149165352912], 
             UndirectedEdge[223, 242] -> 
             RGBColor[
              0.8910877878932282, 0.5812972246774919, 0.23007311301914762`], 
             UndirectedEdge[158, 390] -> 
             RGBColor[
              0.3007335296132649, 0.43064574329317795`, 0.9405392949117681], 
             UndirectedEdge[26, 128] -> 
             RGBColor[
              0.19080558249119994`, 0.3178791433438807, 0.9341774677000858], 
             UndirectedEdge[136, 335] -> 
             RGBColor[
              0.18204623503960604`, 0.3086725137975501, 0.9336786358210108], 
             UndirectedEdge[193, 248] -> 
             RGBColor[
              0.20247189401375032`, 0.330141176440954, 0.9348418468825339], 
             UndirectedEdge[281, 386] -> 
             RGBColor[
              0.5947242732295994, 0.6793804571151425, 0.9626628801063983], 
             UndirectedEdge[225, 337] -> 
             RGBColor[
              0.9393785469822551, 0.9502915240338172, 0.7911384355526612], 
             UndirectedEdge[30, 297] -> 
             RGBColor[
              0.19356559882175525`, 0.3207800955024369, 0.9343346465470327], 
             UndirectedEdge[32, 104] -> 
             RGBColor[
              0.8880206846932135, 0.5069199227649615, 0.22670764186056142`], 
             UndirectedEdge[264, 366] -> 
             RGBColor[
              0.5588455342770764, 0.6498954430078475, 0.9597031854296422], 
             UndirectedEdge[2, 97] -> 
             RGBColor[
              0.18893766617089083`, 0.31591584485850077`, 0.9340710926289788],
              UndirectedEdge[258, 377] -> 
             RGBColor[
              0.18407204095648846`, 0.3108017642597073, 0.933794002471066], 
             UndirectedEdge[134, 135] -> 
             RGBColor[
              0.9129052217970873, 0.9297159641585085, 0.8318647617559947], 
             UndirectedEdge[185, 338] -> 
             RGBColor[
              0.3169003211264983, 0.4420126040845884, 0.9416659454971446], 
             UndirectedEdge[40, 84] -> 
             RGBColor[
              0.42994887224450423`, 0.5449824840875006, 0.9491251582866337], 
             UndirectedEdge[217, 242] -> 
             RGBColor[
              0.9226715072655902, 0.6951934560850966, 0.34236801946865186`], 
             UndirectedEdge[124, 266] -> 
             RGBColor[
              0.27124098687969256`, 0.402330909521441, 0.9387614748820916], 
             UndirectedEdge[219, 293] -> 
             RGBColor[
              0.34300984476630975`, 0.47151962018566573`, 0.943077261890181], 
             UndirectedEdge[37, 170] -> 
             RGBColor[
              0.29023151793817503`, 0.41867896684859873`, 0.9399752176813956],
              UndirectedEdge[205, 293] -> 
             RGBColor[
              0.3494560104043527, 0.47710296486763304`, 0.9434880058645166], 
             UndirectedEdge[122, 268] -> 
             RGBColor[
              0.638662857560744, 0.7169674525945936, 0.9650845862531987], 
             UndirectedEdge[246, 392] -> 
             RGBColor[
              0.955664633870156, 0.964911832854005, 0.8948405878073766], 
             UndirectedEdge[282, 398] -> 
             RGBColor[
              0.3466184248527956, 0.47079867288483046`, 0.9434480372889362], 
             UndirectedEdge[34, 248] -> 
             RGBColor[
              0.24062348998029212`, 0.37024092275268566`, 0.9370145238326], 
             UndirectedEdge[263, 264] -> 
             RGBColor[
              0.5576221544304325, 0.6488358128735436, 0.9596252327476064], 
             UndirectedEdge[100, 377] -> 
             RGBColor[
              0.19744186238260558`, 0.3248542942741953, 0.9345553940224051], 
             UndirectedEdge[107, 241] -> 
             RGBColor[
              0.30591595912176667`, 0.43518094579116473`, 0.9408678142487259],
              UndirectedEdge[11, 95] -> 
             RGBColor[
              0.43568729767870357`, 0.5489115275560077, 0.9497785178241904], 
             UndirectedEdge[7, 96] -> 
             RGBColor[
              0.5984222253415448, 0.6831169372542267, 0.9626727079088397], 
             UndirectedEdge[111, 383] -> 
             RGBColor[
              0.1988021595169091, 0.3262840528101681, 0.9346328609318244], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.2782593236768137, 0.4070163756656283, 0.939259698655848], 
             UndirectedEdge[121, 122] -> 
             RGBColor[
              0.4544345003462795, 0.5641026104704333, 0.9512623074498896], 
             UndirectedEdge[156, 221] -> 
             RGBColor[
              0.866647121618338, 0.4442317532509077, 0.20875073029347097`], 
             UndirectedEdge[61, 176] -> 
             RGBColor[
              0.2215167477526256, 0.3501585252339816, 0.9359264231286265], 
             UndirectedEdge[128, 261] -> 
             RGBColor[
              0.22729090761283746`, 0.3562275333499445, 0.9362552529905616], 
             UndirectedEdge[69, 381] -> 
             RGBColor[
              0.21898984745913425`, 0.34750259281079, 0.9357825198951262], 
             UndirectedEdge[166, 178] -> 
             RGBColor[
              0.7156925694809679, 0.7734991059400932, 0.884905461880064], 
             UndirectedEdge[114, 202] -> 
             RGBColor[
              0.2423249813764799, 0.37202929809086444`, 0.937111421250482], 
             UndirectedEdge[40, 134] -> 
             RGBColor[
              0.6760140538149009, 0.745057217744171, 0.9695892868351288], 
             UndirectedEdge[84, 234] -> 
             RGBColor[
              0.5622802808581155, 0.6502189334159502, 0.961044291025931], 
             UndirectedEdge[236, 367] -> 
             RGBColor[
              0.3129287562528536, 0.440105110895209, 0.9413567694167602], 
             UndirectedEdge[307, 366] -> 
             RGBColor[
              0.37137695467694465`, 0.4960897850178574, 0.9448847890496364], 
             UndirectedEdge[129, 396] -> 
             RGBColor[
              0.19432308879693078`, 0.32157626549398477`, 0.934377784480513], 
             UndirectedEdge[67, 208] -> 
             RGBColor[
              0.7091189037719949, 0.7670538844748609, 0.8568671364687419], 
             UndirectedEdge[203, 309] -> 
             RGBColor[
              0.2616767930351678, 0.3923692791198713, 0.9382134782960043], 
             UndirectedEdge[142, 302] -> 
             RGBColor[
              0.18693197467623224`, 0.31380773592942895`, 0.9339568714655127],
              UndirectedEdge[93, 248] -> 
             RGBColor[
              0.22615954726936105`, 0.355038401896562, 0.9361908236926982], 
             UndirectedEdge[110, 227] -> 
             RGBColor[
              0.1954518354139104, 0.3227626497550994, 0.934442064930519], 
             UndirectedEdge[129, 361] -> 
             RGBColor[
              0.20336215554475928`, 0.33107689775588556`, 0.9348925459597008],
              UndirectedEdge[236, 332] -> 
             RGBColor[
              0.2395600162179548, 0.36912314440033817`, 0.9369539605751034], 
             UndirectedEdge[306, 353] -> 
             RGBColor[
              0.19636662006403216`, 0.3237241464230741, 0.9344941605630408], 
             UndirectedEdge[257, 280] -> 
             RGBColor[
              0.2873202290991691, 0.41799462453322234`, 0.9397224414852408], 
             UndirectedEdge[208, 385] -> 
             RGBColor[
              0.9937202968318795, 0.9909321476846529, 0.7000134809555262], 
             UndirectedEdge[79, 302] -> 
             RGBColor[
              0.21120952198211004`, 0.3393249774333106, 0.9353394418691697], 
             UndirectedEdge[21, 242] -> 
             RGBColor[
              0.907737765098039, 0.6451681172975665, 0.25461897498786773`], 
             UndirectedEdge[94, 103] -> 
             RGBColor[
              0.18776701535974932`, 0.31468541663244265`, 0.934004425797107], 
             UndirectedEdge[237, 308] -> 
             RGBColor[
              0.19941664213352878`, 0.3269299130006835, 0.9346678548077954], 
             UndirectedEdge[1, 235] -> 
             RGBColor[
              0.19253038583618232`, 0.3196920210183055, 0.9342756926989647], 
             UndirectedEdge[31, 374] -> 
             RGBColor[
              0.1933477765192394, 0.32055115045176114`, 0.9343222418891437], 
             UndirectedEdge[324, 351] -> 
             RGBColor[
              0.7714595274314936, 0.8219737948771062, 0.9777595758801894], 
             UndirectedEdge[62, 396] -> 
             RGBColor[
              0.20033182917246628`, 0.3278918326048165, 0.934719973355765], 
             UndirectedEdge[13, 123] -> 
             RGBColor[
              0.2129302625842361, 0.3411335849074007, 0.9354374355008532], 
             UndirectedEdge[112, 337] -> 
             RGBColor[
              0.9655773454319732, 0.8890178859650467, 0.43083247110178885`], 
             UndirectedEdge[262, 286] -> 
             RGBColor[
              0.20449842182687056`, 0.3322711856618279, 0.9349572546435119], 
             UndirectedEdge[56, 59] -> 
             RGBColor[
              0.3640812726856617, 0.4897706319686471, 0.9444199146444701], 
             UndirectedEdge[61, 118] -> 
             RGBColor[
              0.22412293343441853`, 0.3528977916272621, 0.9360748415476985], 
             UndirectedEdge[14, 235] -> 
             RGBColor[
              0.1880315009055375, 0.3149634077104182, 0.9340194878576683], 
             UndirectedEdge[154, 286] -> 
             RGBColor[
              0.2001789472954632, 0.3277311440588154, 0.9347112669590381], 
             UndirectedEdge[159, 215] -> 
             RGBColor[
              0.1817543271405076, 0.3083657000875679, 0.9336620120979963], 
             UndirectedEdge[25, 385] -> 
             RGBColor[
              0.9058721590894482, 0.562305822104239, 0.3994132353001115], 
             UndirectedEdge[165, 256] -> 
             RGBColor[
              0.624029163944416, 0.6996077525866663, 0.9668100145352584], 
             UndirectedEdge[292, 384] -> 
             RGBColor[
              0.19197167888601352`, 0.3191047845896115, 0.9342438751646855], 
             UndirectedEdge[1, 49] -> 
             RGBColor[
              0.19061232216343427`, 0.3176760144859865, 0.9341664618103227], 
             UndirectedEdge[93, 125] -> 
             RGBColor[
              0.24791606512635506`, 0.37790588160716765`, 0.9374298251987702],
              UndirectedEdge[15, 37] -> 
             RGBColor[
              0.31731211488685307`, 0.44714239125067556`, 0.9415174176154697],
              UndirectedEdge[141, 399] -> 
             RGBColor[
              0.8960867985444002, 0.6145986026106095, 0.23467160372890067`], 
             UndirectedEdge[42, 288] -> 
             RGBColor[
              0.26094257460696524`, 0.39159756899969334`, 0.938171665642697], 
             UndirectedEdge[26, 218] -> 
             RGBColor[
              0.188929981383257, 0.31590776765945394`, 0.9340706549916917], 
             UndirectedEdge[292, 389] -> 
             RGBColor[
              0.1985170723266464, 0.32598440809763013`, 0.9346166256380877], 
             UndirectedEdge[87, 361] -> 
             RGBColor[
              0.20790747959893147`, 0.33585432152701067`, 0.9351513954403816],
              UndirectedEdge[3, 11] -> 
             RGBColor[
              0.4469167817161049, 0.5580281285800609, 0.9506625439425702], 
             UndirectedEdge[217, 364] -> 
             RGBColor[
              0.9053733542786032, 0.5622322721281416, 0.3258032886328436], 
             UndirectedEdge[83, 120] -> 
             RGBColor[
              0.7316668327109251, 0.7891725193318362, 0.9665740024152043], 
             UndirectedEdge[251, 380] -> 
             RGBColor[
              0.20519908617390886`, 0.3330076283152506, 0.9349971564415356], 
             UndirectedEdge[209, 390] -> 
             RGBColor[
              0.2987767120225358, 0.42895084624860025`, 0.9404146082252327], 
             UndirectedEdge[149, 315] -> 
             RGBColor[
              0.21772472600366666`, 0.3461728699477604, 0.9357104730998167], 
             UndirectedEdge[34, 263] -> 
             RGBColor[
              0.3276003815122878, 0.45396612776116196`, 0.9422494083788064], 
             UndirectedEdge[327, 376] -> 
             RGBColor[
              0.2026044968471712, 0.33028055042638454`, 0.9348493984177288], 
             UndirectedEdge[113, 316] -> 
             RGBColor[
              0.2709397029977173, 0.40210518479292345`, 0.9387409873151243], 
             UndirectedEdge[85, 307] -> 
             RGBColor[
              0.294549891018896, 0.4232589122924366, 0.9402196391759287], 
             UndirectedEdge[140, 257] -> 
             RGBColor[
              0.2744017745717613, 0.404416509747592, 0.9389867546110457], 
             UndirectedEdge[228, 330] -> 
             RGBColor[
              0.1947627843493959, 0.3220384133979338, 0.9344028244917546], 
             UndirectedEdge[22, 96] -> 
             RGBColor[
              0.5322372446835262, 0.6257908335621027, 0.9584554594663912], 
             UndirectedEdge[22, 323] -> 
             RGBColor[
              0.35748321527472365`, 0.48405572626730053`, 0.943999492260678], 
             UndirectedEdge[167, 269] -> 
             RGBColor[
              0.5269179419290838, 0.6213796361571894, 0.958033512915055], 
             UndirectedEdge[85, 214] -> 
             RGBColor[
              0.2402451657445982, 0.3698432799938294, 0.9369929788270578], 
             UndirectedEdge[89, 155] -> 
             RGBColor[
              0.19816316122321598`, 0.3256124250886648, 0.9345964709243118], 
             UndirectedEdge[1, 396] -> 
             RGBColor[
              0.1965523248147455, 0.3239193338904351, 0.9345047361738683], 
             UndirectedEdge[172, 208] -> 
             RGBColor[
              0.9084092508392714, 0.5876736275457447, 0.4679228968183917], 
             UndirectedEdge[45, 339] -> 
             RGBColor[
              0.26817858765203434`, 0.39920307749978645`, 0.9385837458808918],
              UndirectedEdge[250, 363] -> 
             RGBColor[
              0.2391241828797345, 0.3686650559284389, 0.9369291405112493], 
             UndirectedEdge[167, 222] -> 
             RGBColor[
              0.2713202012615644, 0.4023656525144891, 0.9387677624449977], 
             UndirectedEdge[73, 208] -> 
             RGBColor[
              0.9618152962983195, 0.8769997675618114, 0.5142240753361885], 
             UndirectedEdge[14, 317] -> 
             RGBColor[
              0.18995153056345765`, 0.3169814806178038, 0.9341288307062575], 
             UndirectedEdge[157, 334] -> 
             RGBColor[
              0.1861875662547559, 0.3130253154802374, 0.9339144785071631], 
             UndirectedEdge[107, 190] -> 
             RGBColor[
              0.6524189980541504, 0.7216233648288316, 0.9512140557147148], 
             UndirectedEdge[12, 209] -> 
             RGBColor[
              0.3216593094784126, 0.45300190701520204`, 0.9417177382985756], 
             UndirectedEdge[185, 219] -> 
             RGBColor[
              0.36836286362019555`, 0.4934791308371227, 0.9446927338327562], 
             UndirectedEdge[318, 345] -> 
             RGBColor[
              0.18668882027855277`, 0.3135521652405886, 0.9339430241822795], 
             UndirectedEdge[36, 383] -> 
             RGBColor[
              0.20061589185273376`, 0.3281904004923918, 0.9347361503051731], 
             UndirectedEdge[24, 357] -> 
             RGBColor[
              0.8389436700878857, 0.3003436902863443, 0.184925808497731], 
             UndirectedEdge[344, 354] -> 
             RGBColor[
              0.2035510812828702, 0.3312754706852238, 0.9349033050009957], 
             UndirectedEdge[7, 194] -> 
             RGBColor[
              0.7215884971461117, 0.7768639400824314, 0.7979961077324451], 
             UndirectedEdge[97, 248] -> 
             RGBColor[
              0.2054442201466507, 0.3332652796629938, 0.9350111164586401], 
             UndirectedEdge[14, 129] -> 
             RGBColor[
              0.18681866782962492`, 0.3136886432495756, 0.9339504188082208], 
             UndirectedEdge[160, 307] -> 
             RGBColor[
              0.403988994027505, 0.524165485775675, 0.9470101048053469], 
             UndirectedEdge[165, 400] -> 
             RGBColor[
              0.873464012393198, 0.6536035645465732, 0.5928491209890607], 
             UndirectedEdge[310, 323] -> 
             RGBColor[
              0.33914507736848765`, 0.46547732189212476`, 0.9429296732937578],
              UndirectedEdge[309, 339] -> 
             RGBColor[
              0.27457216058382816`, 0.4059231280270391, 0.9389478504009139], 
             UndirectedEdge[355, 395] -> 
             RGBColor[
              0.6171730285902994, 0.6981983576754478, 0.9642971542356892], 
             UndirectedEdge[32, 240] -> 
             RGBColor[
              0.8943605848806221, 0.5556511737673611, 0.23277873743991706`], 
             UndirectedEdge[66, 322] -> 
             RGBColor[
              0.2070879506142999, 0.33499294460302415`, 0.9351047244770914], 
             UndirectedEdge[28, 267] -> 
             RGBColor[
              0.23148773999796957`, 0.36063867028126045`, 0.9364942563862377],
              UndirectedEdge[51, 102] -> 
             RGBColor[
              0.32952467941339164`, 0.45694789679919157`, 0.9423238729229517],
              UndirectedEdge[244, 321] -> 
             RGBColor[
              0.7545634824664897, 0.8074397031821838, 0.959757518581915], 
             UndirectedEdge[140, 309] -> 
             RGBColor[
              0.2616478487840542, 0.3923388568767794, 0.9382118299637227], 
             UndirectedEdge[12, 324] -> 
             RGBColor[
              0.4708028735942141, 0.577300258720949, 0.9525700303913813], 
             UndirectedEdge[130, 287] -> 
             RGBColor[
              0.1859722872961475, 0.31279904364526556`, 0.9339022186889471], 
             UndirectedEdge[267, 367] -> 
             RGBColor[
              0.315534462322565, 0.44284387318578267`, 0.9415051605226336], 
             UndirectedEdge[138, 229] -> 
             RGBColor[
              0.19456770903936127`, 0.32183337687859837`, 0.9343917152414362],
              UndirectedEdge[97, 193] -> 
             RGBColor[
              0.1899172543843397, 0.31694545418031556`, 0.9341268787285638], 
             UndirectedEdge[248, 340] -> 
             RGBColor[
              0.2104667967928659, 0.33854432616791813`, 0.9352971447684058], 
             UndirectedEdge[162, 248] -> 
             RGBColor[
              0.24516386461647438`, 0.3750131443716921, 0.9372730914512483], 
             UndirectedEdge[127, 317] -> 
             RGBColor[
              0.19507910076484197`, 0.32237088200618674`, 0.9344208382436661],
              UndirectedEdge[269, 355] -> 
             RGBColor[
              0.7546443194902623, 0.8082531449858283, 0.9761795512808198], 
             UndirectedEdge[161, 184] -> 
             RGBColor[
              0.19128276610466352`, 0.31838069357681953`, 0.9342046426009427],
              UndirectedEdge[340, 360] -> 
             RGBColor[
              0.1940919893072422, 0.3213333652777681, 0.9343646237064562], 
             UndirectedEdge[19, 185] -> 
             RGBColor[
              0.330002266441723, 0.4557835793222022, 0.9424120819002554], 
             UndirectedEdge[240, 357] -> 
             RGBColor[
              0.8443947063429684, 0.3422427436022275, 0.19014572697166301`], 
             UndirectedEdge[75, 132] -> 
             RGBColor[
              0.28812004710636396`, 0.4155836677571048, 0.9398870475355221], 
             UndirectedEdge[89, 353] -> 
             RGBColor[
              0.18963294311823536`, 0.31664662501326446`, 0.93411068762256], 
             UndirectedEdge[214, 312] -> 
             RGBColor[
              0.2713270321361526, 0.4025122922755047, 0.9387630451365561], 
             UndirectedEdge[119, 129] -> 
             RGBColor[
              0.18575214150891103`, 0.312567656464831, 0.9338896817120405], 
             UndirectedEdge[143, 377] -> 
             RGBColor[
              0.1848896476706373, 0.3116611207555374, 0.933840563963896], 
             UndirectedEdge[5, 122] -> 
             RGBColor[
              0.440201175363544, 0.5493422068445898, 0.9504444277972779], 
             UndirectedEdge[42, 318] -> 
             RGBColor[
              0.2054522043558168, 0.33327367157305554`, 0.9350115711475404], 
             UndirectedEdge[6, 137] -> 
             RGBColor[
              0.32002599977803325`, 0.451320237982877, 0.941623440630758], 
             UndirectedEdge[113, 149] -> 
             RGBColor[
              0.26206453775242544`, 0.39277682340214404`, 0.9382355597840353],
              UndirectedEdge[67, 124] -> 
             RGBColor[
              0.3674760832994186, 0.49271104629414053`, 0.9446362289748654], 
             UndirectedEdge[141, 337] -> 
             RGBColor[
              0.9298221770988357, 0.7361333470484221, 0.40148742427443984`], 
             UndirectedEdge[63, 224] -> 
             RGBColor[
              0.1802578853175729, 0.30679284485177194`, 0.9335767919499673], 
             UndirectedEdge[244, 357] -> 
             RGBColor[
              0.9059329560446046, 0.7028448327231054, 0.5818836591998524], 
             UndirectedEdge[9, 192] -> 
             RGBColor[
              0.1863278971063823, 0.3131728121027866, 0.9339224701415624], 
             UndirectedEdge[46, 369] -> 
             RGBColor[
              0.19594555683555187`, 0.3232815822729907, 0.934470181635086], 
             UndirectedEdge[350, 392] -> 
             RGBColor[
              0.9924671913475096, 0.9911530042849124, 0.7745016638630496], 
             UndirectedEdge[275, 339] -> 
             RGBColor[
              0.24514905354352745`, 0.3749975769949486, 0.9372722479825549], 
             UndirectedEdge[119, 127] -> 
             RGBColor[
              0.18861006279746526`, 0.31557151294177693`, 0.9340524361015079],
              UndirectedEdge[152, 398] -> 
             RGBColor[
              0.3414317727237982, 0.4653471726445155, 0.943152665123154], 
             UndirectedEdge[105, 229] -> 
             RGBColor[
              0.20817939443044792`, 0.33614012125533055`, 0.9351668805877746],
              UndirectedEdge[181, 365] -> 
             RGBColor[
              0.1879270858801807, 0.3148536608984732, 0.9340135415764423], 
             UndirectedEdge[24, 285] -> 
             RGBColor[
              0.9074929446583304, 0.5753915383194507, 0.38875906329594523`], 
             UndirectedEdge[167, 189] -> 
             RGBColor[
              0.2884488073307313, 0.4203689035095335, 0.9397432112211349], 
             UndirectedEdge[157, 191] -> 
             RGBColor[
              0.1973089788218841, 0.3247146252265727, 0.9345478265002056], 
             UndirectedEdge[78, 194] -> 
             RGBColor[
              0.9072346231009216, 0.5724833285992563, 0.40645475392950137`], 
             UndirectedEdge[107, 268] -> 
             RGBColor[
              0.5139907876886572, 0.6129102178843966, 0.9560554271690249], 
             UndirectedEdge[5, 274] -> 
             RGBColor[
              0.38775900825169696`, 0.5067672930904867, 0.9463159883002454], 
             UndirectedEdge[12, 118] -> 
             RGBColor[
              0.27367870261090094`, 0.4049840470489852, 0.9388969692911083], 
             UndirectedEdge[20, 291] -> 
             RGBColor[
              0.18873168488737596`, 0.31569934546955897`, 0.9340593622996046],
              UndirectedEdge[6, 379] -> 
             RGBColor[
              0.25634517615934155`, 0.38676541173934353`, 0.9379098506023464],
              UndirectedEdge[97, 181] -> 
             RGBColor[
              0.19390662933890207`, 0.32113854019854193`, 0.9343540677304747],
              UndirectedEdge[39, 320] -> 
             RGBColor[
              0.18948414481075992`, 0.3164902285577502, 0.9341022137790767], 
             UndirectedEdge[202, 218] -> 
             RGBColor[
              0.2171099632633392, 0.3455267153294672, 0.9356754632712151], 
             UndirectedEdge[61, 344] -> 
             RGBColor[
              0.20030701799861927`, 0.32786575448798405`, 0.9347185603961192],
              UndirectedEdge[181, 214] -> 
             RGBColor[
              0.21733436721625865`, 0.34576257811201794`, 0.9356882427443579],
              UndirectedEdge[274, 324] -> 
             RGBColor[
              0.5631040589260905, 0.6561922684417929, 0.9587487607182468], 
             UndirectedEdge[62, 231] -> 
             RGBColor[
              0.19164937615014635`, 0.31876602397904136`, 0.934225520500682], 
             UndirectedEdge[117, 289] -> 
             RGBColor[
              0.20615434433043495`, 0.33401166520462483`, 0.935051556980372], 
             UndirectedEdge[14, 396] -> 
             RGBColor[
              0.19205343988410067`, 0.31919072058254777`, 0.9342485313325719],
              UndirectedEdge[79, 175] -> 
             RGBColor[
              0.2563476435480917, 0.3867680051213614, 0.9379099911164857], 
             UndirectedEdge[246, 395] -> 
             RGBColor[
              0.6944421379403393, 0.7593719483680503, 0.9717835682731306], 
             UndirectedEdge[87, 396] -> 
             RGBColor[
              0.198868412851103, 0.3263536892651099, 0.9346366339611938], 
             UndirectedEdge[341, 366] -> 
             RGBColor[
              0.36531722643847, 0.49084115298848774`, 0.9444986685246879], 
             UndirectedEdge[40, 226] -> 
             RGBColor[
              0.48315013418370223`, 0.5910627432060597, 0.9525150956533707], 
             UndirectedEdge[67, 316] -> 
             RGBColor[
              0.32978816517065423`, 0.4531895985227258, 0.9424866278961124], 
             UndirectedEdge[303, 376] -> 
             RGBColor[
              0.21141869489039777`, 0.33954483142224945`, 0.9353513539568531],
              UndirectedEdge[208, 357] -> 
             RGBColor[
              0.9250578823512863, 0.7156423048239384, 0.4838656451562371], 
             UndirectedEdge[54, 66] -> 
             RGBColor[
              0.19944158418676777`, 0.3269561286800552, 0.9346692752208288], 
             UndirectedEdge[3, 160] -> 
             RGBColor[
              0.5207461823507223, 0.6218042360373149, 0.9554141935122193], 
             UndirectedEdge[230, 328] -> 
             RGBColor[
              0.8436345364621675, 0.31890075612792645`, 0.1887325709247331], 
             UndirectedEdge[282, 383] -> 
             RGBColor[
              0.23774824777614534`, 0.3672188608952424, 0.9368507830426136], 
             UndirectedEdge[106, 150] -> 
             RGBColor[
              0.2101822963835033, 0.33824529819931026`, 0.9352809428909732], 
             UndirectedEdge[1, 298] -> 
             RGBColor[
              0.19527223087889906`, 0.32257387400121723`, 0.9344318367179512],
              UndirectedEdge[66, 131] -> 
             RGBColor[
              0.2137636212718384, 0.34200949772606326`, 0.9354848940452685], 
             UndirectedEdge[53, 126] -> 
             RGBColor[
              0.1894916420221746, 0.31649810860229766`, 0.9341026407341755], 
             UndirectedEdge[182, 281] -> 
             RGBColor[
              0.38860982761707186`, 0.5110160334092172, 0.94598285247495], 
             UndirectedEdge[74, 263] -> 
             RGBColor[
              0.627506347078178, 0.7037780429959705, 0.9664982429670084], 
             UndirectedEdge[24, 243] -> 
             RGBColor[
              0.8951565236421906, 0.5687878448594291, 0.5520035990795774], 
             UndirectedEdge[177, 252] -> 
             RGBColor[
              0.6322093663988135, 0.7067582685174405, 0.9673012182198607], 
             UndirectedEdge[10, 216] -> 
             RGBColor[
              0.21860581417743288`, 0.3470989494826055, 0.9357606497678597], 
             UndirectedEdge[280, 339] -> 
             RGBColor[
              0.2515419198726136, 0.3817168848379542, 0.9376363122625981], 
             UndirectedEdge[152, 154] -> 
             RGBColor[
              0.23114091709829876`, 0.3602741374238645, 0.93647450533518], 
             UndirectedEdge[36, 304] -> 
             RGBColor[
              0.18688421139568462`, 0.3137575336932065, 0.933954151417345], 
             UndirectedEdge[128, 299] -> 
             RGBColor[
              0.19113698074466645`, 0.31822746392013684`, 0.934196340340361], 
             UndirectedEdge[95, 162] -> 
             RGBColor[
              0.41586939242453425`, 0.5283792415607237, 0.9486390212485251], 
             UndirectedEdge[215, 329] -> 
             RGBColor[
              0.1867198905000643, 0.313584822013363, 0.9339447935854304], 
             UndirectedEdge[208, 387] -> 
             RGBColor[
              0.7635706581669874, 0.8120231295414462, 0.8609429981480392], 
             UndirectedEdge[178, 197] -> 
             RGBColor[
              0.7030008791274289, 0.7649478943931832, 0.947330285544383], 
             UndirectedEdge[53, 303] -> 
             RGBColor[
              0.20281627238444755`, 0.3305031399434066, 0.9348614587212829], 
             UndirectedEdge[59, 121] -> 
             RGBColor[
              0.3287091584623374, 0.4591330844825578, 0.9421660348044922], 
             UndirectedEdge[134, 269] -> 
             RGBColor[
              0.7872748442941331, 0.8338331400434145, 0.9794082972749127], 
             UndirectedEdge[44, 362] -> 
             RGBColor[
              0.21291981933663207`, 0.3411226083920287, 0.9354368407733515], 
             UndirectedEdge[284, 338] -> 
             RGBColor[
              0.2553995027309328, 0.3857714490069275, 0.9378559958995971], 
             UndirectedEdge[12, 346] -> 
             RGBColor[
              0.329771268632467, 0.46002807831552184`, 0.9422346251627481], 
             UndirectedEdge[113, 387] -> 
             RGBColor[
              0.4208258242811829, 0.5366129491256768, 0.9486460027249637], 
             UndirectedEdge[55, 400] -> 
             RGBColor[
              0.9109049028745734, 0.6513336536973703, 0.2699888799203509], 
             UndirectedEdge[25, 201] -> 
             RGBColor[
              0.8831813824108397, 0.5478222518769809, 0.567678897014493], 
             UndirectedEdge[123, 309] -> 
             RGBColor[
              0.2546471876156135, 0.3849807181211936, 0.93781315266673], 
             UndirectedEdge[35, 162] -> 
             RGBColor[
              0.25429020183451534`, 0.3846055034310536, 0.9377928228546097], 
             UndirectedEdge[73, 172] -> 
             RGBColor[
              0.8772092716527284, 0.4732937439467283, 0.21672848084375096`], 
             UndirectedEdge[137, 282] -> 
             RGBColor[
              0.3008030444529849, 0.4311156931304887, 0.9405287217628104], 
             UndirectedEdge[37, 114] -> 
             RGBColor[
              0.2950446149939596, 0.4237378370222073, 0.9402493164383834], 
             UndirectedEdge[214, 248] -> 
             RGBColor[
              0.22887195802400728`, 0.3578893175764699, 0.9363452914725232], 
             UndirectedEdge[161, 363] -> 
             RGBColor[
              0.20967797684249928`, 0.3377152263860093, 0.9352522226391868], 
             UndirectedEdge[51, 84] -> 
             RGBColor[
              0.36020789306278994`, 0.48641570522103605`, 0.9441731063199956],
              UndirectedEdge[56, 278] -> 
             RGBColor[
              0.3199081459581343, 0.44683361246279085`, 0.9417764708138758], 
             UndirectedEdge[4, 140] -> 
             RGBColor[
              0.22925899781803233`, 0.3582961209397305, 0.9363673328162189], 
             UndirectedEdge[221, 351] -> 
             RGBColor[
              0.9060488999462345, 0.7900961921894157, 0.6157268873569864], 
             UndirectedEdge[54, 204] -> 
             RGBColor[
              0.18912347164523904`, 0.31611113819278824`, 0.9340816739758684],
              UndirectedEdge[10, 298] -> 
             RGBColor[
              0.21724932645694042`, 0.3456731948820789, 0.9356833997989213], 
             UndirectedEdge[134, 226] -> 
             RGBColor[
              0.6381042655490734, 0.7140610165668736, 0.9666654902064342], 
             UndirectedEdge[35, 98] -> 
             RGBColor[
              0.21863346925867172`, 0.3471280167264209, 0.9357622246838242], 
             UndirectedEdge[70, 180] -> 
             RGBColor[
              0.24072957206270523`, 0.3703524217472943, 0.9370205650502591], 
             UndirectedEdge[165, 328] -> 
             RGBColor[
              0.8831401501680374, 0.7104796109326978, 0.6014297849392954], 
             UndirectedEdge[162, 214] -> 
             RGBColor[
              0.25603696286442035`, 0.3864414600245297, 0.9378922983111614], 
             UndirectedEdge[211, 370] -> 
             RGBColor[
              0.20448863330117922`, 0.3322608973006979, 0.9349566972014545], 
             UndirectedEdge[55, 245] -> 
             RGBColor[
              0.8952306902685789, 0.5308547871239369, 0.2549792362273595], 
             UndirectedEdge[247, 315] -> 
             RGBColor[
              0.2082369879918481, 0.3362006557400048, 0.9351701604558942], 
             UndirectedEdge[16, 268] -> 
             RGBColor[
              0.49856920010276634`, 0.5995528138290274, 0.9550727772448264], 
             UndirectedEdge[154, 291] -> 
             RGBColor[
              0.1963438417799771, 0.3237002050023056, 0.9344928633734613], 
             UndirectedEdge[296, 373] -> 
             RGBColor[
              0.25840585650162723`, 0.38893131743376574`, 0.9380272032993362],
              UndirectedEdge[101, 394] -> 
             RGBColor[
              0.18176625720560394`, 0.308378239342394, 0.9336626914975545], 
             UndirectedEdge[173, 388] -> 
             RGBColor[
              0.2509970167086373, 0.38114415706375904`, 0.9376052808335218], 
             UndirectedEdge[84, 102] -> 
             RGBColor[
              0.3081546083900806, 0.43843821536979977`, 0.9409621908941581], 
             UndirectedEdge[216, 298] -> 
             RGBColor[
              0.19835416070020614`, 0.3258131776490477, 0.9346073480619681], 
             UndirectedEdge[209, 310] -> 
             RGBColor[
              0.30722079620017617`, 0.4378261141051596, 0.9408954863272463], 
             UndirectedEdge[34, 93] -> 
             RGBColor[
              0.24878417747359188`, 0.37881832272561544`, 0.9374792629126882],
              UndirectedEdge[112, 285] -> 
             RGBColor[
              0.9656534548794817, 0.8891806763774219, 0.4391165147700274], 
             UndirectedEdge[131, 309] -> 
             RGBColor[
              0.255426495168577, 0.38579981977031097`, 0.9378575330789891], 
             UndirectedEdge[116, 265] -> 
             RGBColor[
              0.18666044049465552`, 0.3135223362883303, 0.9339414079955707], 
             UndirectedEdge[49, 129] -> 
             RGBColor[
              0.18838308614561955`, 0.31533294608953616`, 0.9340395101169672],
              UndirectedEdge[238, 325] -> 
             RGBColor[
              0.28956065239162987`, 0.42167698324230746`, 0.9398014228358818],
              UndirectedEdge[112, 399] -> 
             RGBColor[
              0.9318419668775375, 0.7674831415272341, 0.2640166505562497], 
             UndirectedEdge[186, 322] -> 
             RGBColor[
              0.20337835674212623`, 0.3310939262415335, 0.9348934685939234], 
             UndirectedEdge[180, 332] -> 
             RGBColor[
              0.2434440031568898, 0.373205460932154, 0.937175147885432], 
             UndirectedEdge[60, 331] -> 
             RGBColor[
              0.19257622837931382`, 0.31974020443772183`, 0.9342783033639781],
              UndirectedEdge[14, 126] -> 
             RGBColor[
              0.18556762080960376`, 0.31237371351057097`, 0.9338791735311889],
              UndirectedEdge[275, 288] -> 
             RGBColor[
              0.2720607570835225, 0.40328348371603906`, 0.9388048296868601], 
             UndirectedEdge[276, 290] -> 
             RGBColor[
              0.21053718403849497`, 0.33861830762588346`, 0.9353011532179156],
              UndirectedEdge[18, 232] -> 
             RGBColor[
              0.4501165590628717, 0.5589054128143358, 0.9510872394181826], 
             UndirectedEdge[4, 325] -> 
             RGBColor[
              0.26097898271890796`, 0.39163583623375275`, 0.9381737390308114],
              UndirectedEdge[1, 62] -> 
             RGBColor[
              0.19732629313580521`, 0.3247328236682947, 0.9345488125247692], 
             UndirectedEdge[20, 304] -> 
             RGBColor[
              0.185589373288035, 0.312396576744589, 0.9338804123026556], 
             UndirectedEdge[255, 328] -> 
             RGBColor[
              0.8524460760036836, 0.3866301102852666, 0.1971705111408994], 
             UndirectedEdge[3, 74] -> 
             RGBColor[
              0.7224644673916434, 0.782535536200579, 0.9735133143364585], 
             UndirectedEdge[18, 279] -> 
             RGBColor[
              0.638687245246097, 0.7170964540862654, 0.9650118438159424], 
             UndirectedEdge[163, 226] -> 
             RGBColor[
              0.35601753306005335`, 0.4789075435482711, 0.944048117850775], 
             UndirectedEdge[145, 254] -> 
             RGBColor[
              0.19225246823374995`, 0.31939991199715534`, 0.9342598657026484],
              UndirectedEdge[23, 348] -> 
             RGBColor[
              0.3130979265677895, 0.44416079144735543`, 0.9412244155321879], 
             UndirectedEdge[119, 396] -> 
             RGBColor[
              0.19098691356338682`, 0.3180697337978031, 0.9341877942363916], 
             UndirectedEdge[73, 141] -> 
             RGBColor[
              0.898106425922933, 0.622605752165564, 0.23629664332441563`], 
             UndirectedEdge[29, 396] -> 
             RGBColor[
              0.19049809514878532`, 0.31755595465117936`, 0.9341599567508221],
              UndirectedEdge[160, 312] -> 
             RGBColor[
              0.38126624461740655`, 0.5039445125232649, 0.9455819912605958], 
             UndirectedEdge[210, 397] -> 
             RGBColor[
              0.25928855226930214`, 0.38985908665173613`, 0.938077471517474], 
             UndirectedEdge[11, 86] -> 
             RGBColor[
              0.361493667794528, 0.48752937866875046`, 0.9442550347489361], 
             UndirectedEdge[113, 315] -> 
             RGBColor[
              0.26318579596449465`, 0.3939553368749055, 0.9382994137804598], 
             UndirectedEdge[120, 160] -> 
             RGBColor[
              0.48896132780643076`, 0.5959998592268796, 0.9529119733307341], 
             UndirectedEdge[5, 308] -> 
             RGBColor[
              0.24197001296398313`, 0.37165620378303305`, 0.9370912063245189],
              UndirectedEdge[37, 261] -> 
             RGBColor[
              0.30438433219243016`, 0.43355447197007246`, 0.940781199515963], 
             UndirectedEdge[22, 241] -> 
             RGBColor[
              0.28974430117812966`, 0.42117386849154814`, 0.9398373705045929],
              UndirectedEdge[55, 165] -> 
             RGBColor[
              0.9341904345376686, 0.918237850236102, 0.6671537250527897], 
             UndirectedEdge[251, 283] -> 
             RGBColor[
              0.19962713488925782`, 0.32715115423296626`, 0.934679842058838], 
             UndirectedEdge[334, 365] -> 
             RGBColor[
              0.18295572293696874`, 0.30962844324254163`, 0.933730429811299], 
             UndirectedEdge[44, 358] -> 
             RGBColor[
              0.21372519899594036`, 0.3419691134779814, 0.9354827059534967], 
             UndirectedEdge[225, 367] -> 
             RGBColor[
              0.6298962166593582, 0.7051035104774022, 0.9669932656124167], 
             UndirectedEdge[23, 321] -> 
             RGBColor[
              0.42370887427578074`, 0.5372228658179581, 0.9490305036181749], 
             UndirectedEdge[234, 269] -> 
             RGBColor[
              0.7646521215423732, 0.8160713160110501, 0.9771770354611466], 
             UndirectedEdge[21, 208] -> 
             RGBColor[
              0.9781086897296334, 0.9394569243444684, 0.5384830216306559], 
             UndirectedEdge[208, 240] -> 
             RGBColor[
              0.9123520994765446, 0.6179800899391169, 0.47169857312625524`], 
             UndirectedEdge[15, 313] -> 
             RGBColor[
              0.25209641053026927`, 0.3822996896758886, 0.9376678896852563], 
             UndirectedEdge[63, 204] -> 
             RGBColor[
              0.18740799960939158`, 0.3143080683159034, 0.9339839803812403], 
             UndirectedEdge[241, 310] -> 
             RGBColor[
              0.2714061632718937, 0.40259546411637237`, 0.9387675515376726], 
             UndirectedEdge[182, 256] -> 
             RGBColor[
              0.34992025301800456`, 0.4775050684860661, 0.9435175869933449], 
             UndirectedEdge[373, 380] -> 
             RGBColor[
              0.24598769620290184`, 0.37587904360296687`, 0.9373200074413457],
              UndirectedEdge[185, 210] -> 
             RGBColor[
              0.35262704416750634`, 0.4795636552057607, 0.9437005295213796], 
             UndirectedEdge[96, 223] -> 
             RGBColor[
              0.8390506368021915, 0.7815052608012159, 0.618996491222558], 
             UndirectedEdge[103, 222] -> 
             RGBColor[
              0.21336670811641717`, 0.34159231683396796`, 0.9354622904282476],
              UndirectedEdge[146, 375] -> 
             RGBColor[
              0.18336952246536248`, 0.3100633727832889, 0.9337539950822794], 
             UndirectedEdge[42, 276] -> 
             RGBColor[
              0.2196855450649306, 0.3482338151042579, 0.9358221388445839], 
             UndirectedEdge[46, 372] -> 
             RGBColor[
              0.19768089456011895`, 0.32510553224827726`, 0.934569006551298], 
             UndirectedEdge[95, 285] -> 
             RGBColor[
              0.7768044768753901, 0.8215969254274786, 0.7842186264026185], 
             UndirectedEdge[14, 326] -> 
             RGBColor[
              0.18828033718868842`, 0.3152249504211414, 0.9340336587158735], 
             UndirectedEdge[22, 310] -> 
             RGBColor[
              0.2979372274212155, 0.4297851534345578, 0.9403039455337885], 
             UndirectedEdge[23, 229] -> 
             RGBColor[
              0.24996961512608984`, 0.38006429285947896`, 0.9375467718333002],
              UndirectedEdge[23, 160] -> 
             RGBColor[
              0.3763398438622711, 0.4987665529777692, 0.9453014400255476], 
             UndirectedEdge[165, 311] -> 
             RGBColor[
              0.5997467789297788, 0.6780206465223158, 0.965283080943369], 
             UndirectedEdge[179, 288] -> 
             RGBColor[
              0.3796596294696894, 0.502934688841232, 0.9454287055118813], 
             UndirectedEdge[51, 167] -> 
             RGBColor[
              0.3459161722681373, 0.47403693499148125`, 0.9432624505086329], 
             UndirectedEdge[310, 346] -> 
             RGBColor[
              0.31533275535423055`, 0.4448522854054794, 0.9414123731914188], 
             UndirectedEdge[79, 379] -> 
             RGBColor[
              0.21907288200889707`, 0.34758986738728526`, 0.9357872485898966],
              UndirectedEdge[78, 264] -> 
             RGBColor[
              0.7716146222869605, 0.4690073780170669, 0.569890082784954], 
             UndirectedEdge[309, 325] -> 
             RGBColor[
              0.2933678336849298, 0.42567857217080163`, 0.9400182361783151], 
             UndirectedEdge[149, 358] -> 
             RGBColor[
              0.20368965097586314`, 0.3314211162183854, 0.9349111963400162], 
             UndirectedEdge[6, 79] -> 
             RGBColor[
              0.26831622286540857`, 0.39934774083561936`, 0.9385915840026804],
              UndirectedEdge[134, 234] -> 
             RGBColor[
              0.8083454624285121, 0.8502936670726204, 0.9815084195744261], 
             UndirectedEdge[96, 209] -> 
             RGBColor[
              0.5415208134624869, 0.6338317942327045, 0.9590470002598491], 
             UndirectedEdge[216, 393] -> 
             RGBColor[
              0.19153695040893678`, 0.31864785739682644`, 0.9342191180210391],
              UndirectedEdge[164, 388] -> 
             RGBColor[
              0.21023340989613648`, 0.33829902174187165`, 0.935283853729902], 
             UndirectedEdge[155, 261] -> 
             RGBColor[
              0.23352567596023666`, 0.3627806701902061, 0.9366103138244327], 
             UndirectedEdge[125, 288] -> 
             RGBColor[
              0.28344153985750953`, 0.415245407994804, 0.9394529484294792], 
             UndirectedEdge[287, 384] -> 
             RGBColor[
              0.18974513703544627`, 0.3167645479337583, 0.9341170769001692], 
             UndirectedEdge[69, 320] -> 
             RGBColor[
              0.21880446674278364`, 0.34730774592408925`, 0.9357719627375762],
              UndirectedEdge[123, 339] -> 
             RGBColor[
              0.23162280417676506`, 0.3607806312967381, 0.9365019480914105], 
             UndirectedEdge[132, 202] -> 
             RGBColor[
              0.300816385571577, 0.4289283244783967, 0.9406100852285664], 
             UndirectedEdge[67, 249] -> 
             RGBColor[
              0.36714946895537004`, 0.49242814936543994`, 0.9446154173976764],
              UndirectedEdge[374, 384] -> 
             RGBColor[
              0.18988847579037965`, 0.3169152060533953, 0.934125239830212], 
             UndirectedEdge[99, 252] -> 
             RGBColor[
              0.6676015641481373, 0.7342070299092066, 0.9439106644834332], 
             UndirectedEdge[44, 65] -> 
             RGBColor[
              0.2623103948909678, 0.393035234842995, 0.9382495609843622], 
             UndirectedEdge[88, 370] -> 
             RGBColor[
              0.189278561860536, 0.3162741478423529, 0.9340905061341941], 
             UndirectedEdge[13, 275] -> 
             RGBColor[
              0.22645651195099847`, 0.3553505306056112, 0.9362077353919975], 
             UndirectedEdge[183, 269] -> 
             RGBColor[
              0.546784204528102, 0.6385867943130678, 0.9592993736008182], 
             UndirectedEdge[122, 178] -> 
             RGBColor[
              0.5198265338212547, 0.6207419031672892, 0.9554290299990101], 
             UndirectedEdge[199, 216] -> 
             RGBColor[
              0.19310022590756143`, 0.3202909590632723, 0.9343081442480269], 
             UndirectedEdge[107, 295] -> 
             RGBColor[
              0.38882676959428764`, 0.5112039376460608, 0.945996675825904], 
             UndirectedEdge[89, 171] -> 
             RGBColor[
              0.18910388505940673`, 0.3160905514492172, 0.934080558548781], 
             UndirectedEdge[18, 91] -> 
             RGBColor[
              0.5492190587011108, 0.6449197997470224, 0.9576556826381046], 
             UndirectedEdge[194, 357] -> 
             RGBColor[
              0.9258160784332223, 0.7153085367289651, 0.42424837654046466`], 
             UndirectedEdge[147, 388] -> 
             RGBColor[
              0.20149520910929605`, 0.3291146186809729, 0.9347862261221009], 
             UndirectedEdge[96, 323] -> 
             RGBColor[
              0.5734450946307983, 0.6614830020196698, 0.9610811872263605], 
             UndirectedEdge[168, 265] -> 
             RGBColor[
              0.18709388052696674`, 0.31397790924397473`, 0.9339660917641938],
              UndirectedEdge[44, 372] -> 
             RGBColor[
              0.21537145554787535`, 0.3436994334927591, 0.9355764578287111], 
             UndirectedEdge[180, 286] -> 
             RGBColor[
              0.22669434503393948`, 0.3556005082552706, 0.9362212796342286], 
             UndirectedEdge[18, 45] -> 
             RGBColor[
              0.4449748432614876, 0.5535011435034702, 0.9507944263097807], 
             UndirectedEdge[83, 217] -> 
             RGBColor[
              0.9690520396764782, 0.9730561345189551, 0.7324860448307533], 
             UndirectedEdge[137, 314] -> 
             RGBColor[
              0.28356888618805115`, 0.41300150008529746`, 0.9395472619452747],
              UndirectedEdge[205, 338] -> 
             RGBColor[
              0.292109011117009, 0.4205396174018403, 0.9400862651454345], 
             UndirectedEdge[210, 293] -> 
             RGBColor[
              0.3272740253136205, 0.45760414455430376`, 0.9420850575788042], 
             UndirectedEdge[295, 324] -> 
             RGBColor[
              0.5310822445454129, 0.6295361727227928, 0.9564100649680346], 
             UndirectedEdge[270, 346] -> 
             RGBColor[
              0.3550828331693524, 0.4819766359343405, 0.9438465420354984], 
             UndirectedEdge[26, 349] -> 
             RGBColor[
              0.19449252215171758`, 0.32175435069256086`, 0.9343874334594139],
              UndirectedEdge[27, 208] -> 
             RGBColor[
              0.9070267560487368, 0.5770471667726158, 0.46659901824567124`], 
             UndirectedEdge[139, 193] -> 
             RGBColor[
              0.18750230329400064`, 0.31440718746762647`, 0.933989350836569], 
             UndirectedEdge[5, 296] -> 
             RGBColor[
              0.26370004466317304`, 0.39449584486246725`, 0.9383286994830867],
              UndirectedEdge[42, 125] -> 
             RGBColor[
              0.23901293023950498`, 0.3685481223497329, 0.9369228048379719], 
             UndirectedEdge[12, 106] -> 
             RGBColor[
              0.2676474114572338, 0.3986447776405352, 0.9385534961824027], 
             UndirectedEdge[242, 357] -> 
             RGBColor[
              0.854686957719692, 0.4213534977770367, 0.2000015985134489], 
             UndirectedEdge[148, 279] -> 
             RGBColor[
              0.5031062098123048, 0.6037853067748751, 0.9552337277677017], 
             UndirectedEdge[292, 374] -> 
             RGBColor[
              0.19230228893935433`, 0.31945227671756077`, 0.9342627029181295],
              UndirectedEdge[195, 369] -> 
             RGBColor[
              0.19622298384464848`, 0.3235731756494396, 0.9344859806928376], 
             UndirectedEdge[50, 371] -> 
             RGBColor[
              0.1827919087042476, 0.30945626409752947`, 0.9337211008330868], 
             UndirectedEdge[29, 127] -> 
             RGBColor[
              0.18812124438286376`, 0.3150577337951532, 0.9340245986159385], 
             UndirectedEdge[87, 127] -> 
             RGBColor[
              0.19649156208518143`, 0.3238554684090837, 0.93450127582631], 
             UndirectedEdge[264, 357] -> 
             RGBColor[
              0.7901960776192611, 0.6118325861467757, 0.5876837053959174], 
             UndirectedEdge[171, 306] -> 
             RGBColor[
              0.19583756200520352`, 0.3231680728590269, 0.9344640314892618], 
             UndirectedEdge[114, 170] -> 
             RGBColor[
              0.23647751036378017`, 0.3658832353054412, 0.9367784164268669], 
             UndirectedEdge[57, 222] -> 
             RGBColor[
              0.22503342369355192`, 0.35385477461802795`, 0.9361266926210063],
              UndirectedEdge[38, 102] -> 
             RGBColor[
              0.25020060979959846`, 0.3803070829072448, 0.9375599266382304], 
             UndirectedEdge[82, 331] -> 
             RGBColor[
              0.18993705205367367`, 0.31696626278603024`, 0.9341280061765445],
              UndirectedEdge[90, 324] -> 
             RGBColor[
              0.6207541500572831, 0.7029952095291041, 0.9632871870713362], 
             UndirectedEdge[160, 341] -> 
             RGBColor[
              0.3979292657890303, 0.5189168537463054, 0.9466239842803985], 
             UndirectedEdge[15, 311] -> 
             RGBColor[
              0.2942848105043079, 0.4266423729476564, 0.940070456651633], 
             UndirectedEdge[271, 292] -> 
             RGBColor[
              0.18674265418407987`, 0.3136087480885643, 0.9339460899435592], 
             UndirectedEdge[41, 156] -> 
             RGBColor[
              0.8514284367030327, 0.5699234098578776, 0.5824732181712974], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.26166329356975937`, 0.3923550903258115, 0.9382127095214201], 
             UndirectedEdge[129, 317] -> 
             RGBColor[
              0.19222117947628775`, 0.3193670255292408, 0.9342580838541985], 
             UndirectedEdge[164, 354] -> 
             RGBColor[
              0.20840265875823133`, 0.3363747862196069, 0.9351795951609518], 
             UndirectedEdge[78, 230] -> 
             RGBColor[
              0.818837947598831, 0.14580229685169685`, 0.1656725459360465], 
             UndirectedEdge[315, 363] -> 
             RGBColor[
              0.2193734294732247, 0.3479057618281034, 0.9358043643233698], 
             UndirectedEdge[5, 121] -> 
             RGBColor[
              0.2966728547509243, 0.4289526354856623, 0.9402137650898452], 
             UndirectedEdge[43, 380] -> 
             RGBColor[
              0.2402420225431372, 0.36983997628980336`, 0.9369927998263845], 
             UndirectedEdge[135, 234] -> 
             RGBColor[
              0.8902824990453274, 0.9119541401261442, 0.8296334999422285], 
             UndirectedEdge[344, 356] -> 
             RGBColor[
              0.19312061469136133`, 0.3203123889677695, 0.9343093053591018], 
             UndirectedEdge[186, 228] -> 
             RGBColor[
              0.20522346006975262`, 0.3330332468251766, 0.934998544498846], 
             UndirectedEdge[298, 396] -> 
             RGBColor[
              0.19827776691556012`, 0.32573288293773905`, 0.9346029975489469],
              UndirectedEdge[86, 93] -> 
             RGBColor[
              0.32267144519324537`, 0.4470223501983363, 0.9420332704147207], 
             UndirectedEdge[249, 266] -> 
             RGBColor[
              0.270914372535644, 0.40204801259274037`, 0.9387406633049027], 
             UndirectedEdge[156, 364] -> 
             RGBColor[
              0.8243314936689592, 0.18802809923393973`, 0.1709331718568741], 
             UndirectedEdge[10, 311] -> 
             RGBColor[
              0.2701224968687157, 0.40124624933748154`, 0.9386944486350258], 
             UndirectedEdge[27, 73] -> 
             RGBColor[
              0.8758267768621938, 0.46266728317359945`, 0.2154046022710305], 
             UndirectedEdge[56, 213] -> 
             RGBColor[
              0.30213444608884904`, 0.4281523269825127, 0.9407642849001527], 
             UndirectedEdge[27, 243] -> 
             RGBColor[
              0.8952822164694654, 0.5697539750088114, 0.5521239626729255], 
             UndirectedEdge[109, 157] -> 
             RGBColor[
              0.18435836126610156`, 0.3111027050588667, 0.9338103079891256], 
             UndirectedEdge[12, 241] -> 
             RGBColor[
              0.28584467655013013`, 0.4177712570264148, 0.9395898035090018], 
             UndirectedEdge[192, 382] -> 
             RGBColor[
              0.18175632170203998`, 0.30836779649820095`, 0.9336621256853248],
              UndirectedEdge[140, 280] -> 
             RGBColor[
              0.2386176080728396, 0.36813261368769457`, 0.936900291825407], 
             UndirectedEdge[199, 361] -> 
             RGBColor[
              0.2020628988707439, 0.32971129661386445`, 0.9348185552141937], 
             UndirectedEdge[16, 351] -> 
             RGBColor[
              0.6137824648944775, 0.6902841557450048, 0.9663635368138602], 
             UndirectedEdge[140, 322] -> 
             RGBColor[
              0.21280212927241615`, 0.34099890867255667`, 0.9354301384983013],
              UndirectedEdge[57, 238] -> 
             RGBColor[
              0.2538315033751126, 0.3841233822670593, 0.9377667006559303], 
             UndirectedEdge[49, 127] -> 
             RGBColor[
              0.19124100743417377`, 0.3183368025664821, 0.9342022645064347], 
             UndirectedEdge[165, 182] -> 
             RGBColor[
              0.6226406331298818, 0.6984050769847048, 0.9667215385795859], 
             UndirectedEdge[253, 343] -> 
             RGBColor[
              0.18655690968294972`, 0.31341351884099494`, 0.9339355120690042],
              UndirectedEdge[104, 240] -> 
             RGBColor[
              0.825349023280818, 0.19584927771500635`, 0.17190755936232552`], 
             UndirectedEdge[312, 348] -> 
             RGBColor[
              0.31802432732292496`, 0.44933875099285125`, 0.9415049667672362],
              UndirectedEdge[242, 244] -> 
             RGBColor[
              0.9035194245465865, 0.684293372013093, 0.5795724587116564], 
             UndirectedEdge[41, 165] -> 
             RGBColor[
              0.8843102751860701, 0.9105890257431475, 0.9888274975519911], 
             UndirectedEdge[54, 297] -> 
             RGBColor[
              0.19576644813648575`, 0.3230933276741248, 0.9344599816596418], 
             UndirectedEdge[77, 145] -> 
             RGBColor[
              0.19003339190962826`, 0.3170675220829382, 0.934133492588819], 
             UndirectedEdge[69, 150] -> 
             RGBColor[
              0.217681081623926, 0.3461269969374395, 0.9357079876169566], 
             UndirectedEdge[106, 241] -> 
             RGBColor[
              0.24501597193591163`, 0.37485769978748307`, 0.9372646691818778],
              UndirectedEdge[139, 276] -> 
             RGBColor[
              0.20545840173873126`, 0.33328018541543536`, 0.9350119240793292],
              UndirectedEdge[313, 393] -> 
             RGBColor[
              0.200865233126181, 0.3284524739799347, 0.9347503499218286], 
             UndirectedEdge[209, 323] -> 
             RGBColor[
              0.36676678405368435`, 0.4920966869379023, 0.9445910330541359], 
             UndirectedEdge[8, 213] -> 
             RGBColor[
              0.230215374068607, 0.3593013330168411, 0.9364217970288573], 
             UndirectedEdge[160, 244] -> 
             RGBColor[
              0.7071944520529801, 0.7689833903419949, 0.9560284549892878], 
             UndirectedEdge[180, 284] -> 
             RGBColor[
              0.2675710150211928, 0.3985644801424423, 0.9385491455183885], 
             UndirectedEdge[24, 242] -> 
             RGBColor[
              0.8365301385898678, 0.28179222957633193`, 0.182614608009535], 
             UndirectedEdge[81, 192] -> 
             RGBColor[
              0.1805894919591846, 0.3071413844571813, 0.9335956764576392], 
             UndirectedEdge[124, 249] -> 
             RGBColor[
              0.30940302019566135`, 0.4424110778706867, 0.9409358647458874], 
             UndirectedEdge[195, 253] -> 
             RGBColor[
              0.1964706167173933, 0.3238334534995253, 0.9345000830186004], 
             UndirectedEdge[31, 81] -> 
             RGBColor[
              0.1880171511030766, 0.3149483251582018, 0.9340186706576468], 
             UndirectedEdge[172, 399] -> 
             RGBColor[
              0.8751896442741957, 0.46528659439177383`, 0.21510344124823602`],
              UndirectedEdge[124, 315] -> 
             RGBColor[
              0.2642878093777229, 0.3950226791099546, 0.9383655017096588], 
             UndirectedEdge[181, 370] -> 
             RGBColor[
              0.19100569805155482`, 0.318089477485873, 0.9341888639852036], 
             UndirectedEdge[244, 348] -> 
             RGBColor[
              0.6439525347584986, 0.7143776288115813, 0.9519514304959281], 
             UndirectedEdge[284, 367] -> 
             RGBColor[
              0.3258404306471927, 0.4536760993310988, 0.9420920701724073], 
             UndirectedEdge[148, 232] -> 
             RGBColor[
              0.3145355236290795, 0.4455942655029455, 0.9413091233699418], 
             UndirectedEdge[34, 211] -> 
             RGBColor[
              0.2425688344221679, 0.3722856031030586, 0.9371253083206856], 
             UndirectedEdge[355, 392] -> 
             RGBColor[
              0.8783955245201162, 0.9037382421614023, 0.8873541737699352], 
             UndirectedEdge[262, 338] -> 
             RGBColor[
              0.22417589206845978`, 0.35295345450941085`, 0.9360778574635618],
              UndirectedEdge[87, 119] -> 
             RGBColor[
              0.19029746556308325`, 0.3173450802359561, 0.9341485311927212], 
             UndirectedEdge[180, 367] -> 
             RGBColor[
              0.31681274319178854`, 0.44418742742702483`, 0.9415779567270888],
              UndirectedEdge[69, 380] -> 
             RGBColor[
              0.2309702581422837, 0.36009476404068996`, 0.9364647865601021], 
             UndirectedEdge[124, 338] -> 
             RGBColor[
              0.2719649687624893, 0.40309186038336303`, 0.9388027045792817], 
             UndirectedEdge[249, 293] -> 
             RGBColor[
              0.3289853537057845, 0.45937231092045516`, 0.9421836337211749], 
             UndirectedEdge[212, 373] -> 
             RGBColor[
              0.34459378761093823`, 0.4694803712160838, 0.9433030893613046], 
             UndirectedEdge[287, 292] -> 
             RGBColor[
              0.19215895018442095`, 0.31930161859792383`, 0.9342545399880867],
              UndirectedEdge[12, 323] -> 
             RGBColor[
              0.35358359064672407`, 0.4806531148021672, 0.943751925265087], 
             UndirectedEdge[120, 307] -> 
             RGBColor[
              0.43332684059947457`, 0.5479832712777266, 0.9493196875555654], 
             UndirectedEdge[99, 398] -> 
             RGBColor[
              0.695865579228825, 0.7586878991813948, 0.9457116225314874], 
             UndirectedEdge[134, 350] -> 
             RGBColor[
              0.9124093272037948, 0.929890258170909, 0.8676584254872136], 
             UndirectedEdge[45, 280] -> 
             RGBColor[
              0.26817273037966816`, 0.3991969211351571, 0.9385834123178955], 
             UndirectedEdge[188, 330] -> 
             RGBColor[
              0.19385743072413472`, 0.32108682933504906`, 0.9343512659421467],
              UndirectedEdge[236, 284] -> 
             RGBColor[
              0.26368702808225786`, 0.3944821636106265, 0.9383279582080599], 
             UndirectedEdge[374, 389] -> 
             RGBColor[
              0.19643386923101253`, 0.3237948295614139, 0.9344979903036141], 
             UndirectedEdge[278, 319] -> 
             RGBColor[
              0.35576382875700985`, 0.4778888141834562, 0.9440614916187484], 
             UndirectedEdge[78, 242] -> 
             RGBColor[
              0.8361055023873913, 0.2785282896473279, 0.1822079759024856], 
             UndirectedEdge[84, 189] -> 
             RGBColor[
              0.30274052812538393`, 0.4327476737390883, 0.9406538670324976], 
             UndirectedEdge[223, 385] -> 
             RGBColor[
              0.9621637338718393, 0.8751385282482187, 0.44853214930663265`], 
             UndirectedEdge[175, 278] -> 
             RGBColor[
              0.2699086210585896, 0.40102145230052944`, 0.93868226872404], 
             UndirectedEdge[151, 168] -> 
             RGBColor[
              0.18811217327033666`, 0.31504819948074547`, 0.9340240820294996],
              UndirectedEdge[322, 339] -> 
             RGBColor[
              0.22572644107219014`, 0.3545831798228164, 0.9361661589354925], 
             UndirectedEdge[177, 367] -> 
             RGBColor[
              0.6349673392184779, 0.7091470859540894, 0.9674769538091501], 
             UndirectedEdge[294, 320] -> 
             RGBColor[
              0.19287620932606772`, 0.32005550343265077`, 0.9342953868351136],
              UndirectedEdge[179, 279] -> 
             RGBColor[
              0.5630911384213583, 0.6557241290001397, 0.9590606413690353], 
             UndirectedEdge[18, 285] -> 
             RGBColor[
              0.7996696633612428, 0.8401599138816065, 0.7860186576407228], 
             UndirectedEdge[121, 296] -> 
             RGBColor[
              0.27793336964590865`, 0.4092562484883108, 0.9391465791356984], 
             UndirectedEdge[212, 351] -> 
             RGBColor[
              0.6635629227613954, 0.7334014863107667, 0.9695355035700097], 
             UndirectedEdge[29, 87] -> 
             RGBColor[
              0.18980864714848175`, 0.31683130108933233`, 0.9341206937071518],
              UndirectedEdge[99, 141] -> 
             RGBColor[
              0.9156172249259522, 0.7282421342221813, 0.5763077730258106], 
             UndirectedEdge[121, 274] -> 
             RGBColor[
              0.4019923332344326, 0.5215276967163304, 0.9471338679528571], 
             UndirectedEdge[138, 218] -> 
             RGBColor[
              0.18655648275495362`, 0.3134130701126022, 0.9339354877560864], 
             UndirectedEdge[61, 388] -> 
             RGBColor[
              0.2144393921406435, 0.3427197757555252, 0.9355233781965335], 
             UndirectedEdge[283, 347] -> 
             RGBColor[
              0.20341579469893528`, 0.33113327590784336`, 0.9348956006301792],
              UndirectedEdge[253, 315] -> 
             RGBColor[
              0.20496946088804507`, 0.3327662775807237, 0.9349840796212059], 
             UndirectedEdge[321, 366] -> 
             RGBColor[
              0.4743804722974104, 0.5825626858071993, 0.9522061384174323], 
             UndirectedEdge[164, 391] -> 
             RGBColor[
              0.1910397493801938, 0.3181252675912516, 0.9341908031579952], 
             UndirectedEdge[74, 91] -> 
             RGBColor[
              0.6781789401773193, 0.7465825501677249, 0.9700269954109155], 
             UndirectedEdge[91, 285] -> 
             RGBColor[
              0.7437484336984672, 0.7947605404186777, 0.7816163335954551], 
             UndirectedEdge[51, 183] -> 
             RGBColor[
              0.36578243486715545`, 0.4912440931473596, 0.9445283111943961], 
             UndirectedEdge[30, 54] -> 
             RGBColor[
              0.1824115228296057, 0.3090564544254234, 0.9336994384202565], 
             UndirectedEdge[68, 250] -> 
             RGBColor[
              0.2641868760172087, 0.3950075354824494, 0.9383564238084967], 
             UndirectedEdge[32, 230] -> 
             RGBColor[
              0.8873852814687854, 0.5020359351465393, 0.22609917901526383`], 
             UndirectedEdge[275, 318] -> 
             RGBColor[
              0.21657038683237403`, 0.3449595862894012, 0.9356447351917034], 
             UndirectedEdge[131, 186] -> 
             RGBColor[
              0.21005402739966472`, 0.3381104793645726, 0.9352736381621005], 
             UndirectedEdge[192, 292] -> 
             RGBColor[
              0.18800332047098128`, 0.31493378828695684`, 0.9340178830236096],
              UndirectedEdge[144, 200] -> 
             RGBColor[
              0.18738223875410484`, 0.31428099202366444`, 0.9339825133386415],
              UndirectedEdge[139, 318] -> 
             RGBColor[
              0.19122506102961745`, 0.318320041884233, 0.9342013563822857], 
             UndirectedEdge[93, 148] -> 
             RGBColor[
              0.2841492261294814, 0.41365634022833114`, 0.9395786686798384], 
             UndirectedEdge[92, 311] -> 
             RGBColor[
              0.40006723340595274`, 0.5191882673765618, 0.947063870354397], 
             UndirectedEdge[334, 370] -> 
             RGBColor[
              0.18603433510834283`, 0.3128642598299414, 0.93390575222006], 
             UndirectedEdge[62, 129] -> 
             RGBColor[
              0.19509705711799047`, 0.3223897552718444, 0.9344218608314138], 
             UndirectedEdge[97, 191] -> 
             RGBColor[
              0.2000566789628183, 0.32760263228894565`, 0.9347043039583738], 
             UndirectedEdge[120, 366] -> 
             RGBColor[
              0.4563492884558704, 0.567924158469062, 0.9507866575750236], 
             UndirectedEdge[91, 288] -> 
             RGBColor[
              0.3993345066316525, 0.518907640464429, 0.9469775839135208], 
             UndirectedEdge[21, 32] -> 
             RGBColor[
              0.9601171751337108, 0.8771280081727125, 0.29956318594431774`], 
             UndirectedEdge[121, 178] -> 
             RGBColor[
              0.376298213208635, 0.5003523318083618, 0.9451983672915776], 
             UndirectedEdge[294, 381] -> 
             RGBColor[
              0.19306159004241835`, 0.32025035031935156`, 0.9343059439926636],
              UndirectedEdge[46, 149] -> 
             RGBColor[
              0.20894845482391827`, 0.3369484524901131, 0.9352106774394597], 
             UndirectedEdge[66, 232] -> 
             RGBColor[
              0.25468181299552817`, 0.38501711159085983`, 0.9378151245308926],
              UndirectedEdge[114, 261] -> 
             RGBColor[
              0.25063032461803525`, 0.380758740426915, 0.9375843982614342], 
             UndirectedEdge[189, 395] -> 
             RGBColor[
              0.3676410779096787, 0.4885452690238077, 0.9449042144225828], 
             UndirectedEdge[54, 290] -> 
             RGBColor[
              0.19141480754021284`, 0.3185194774974923, 0.9342121621653594], 
             UndirectedEdge[4, 309] -> 
             RGBColor[
              0.2652076930566547, 0.39608047891444564`, 0.9384145578287296], 
             UndirectedEdge[195, 315] -> 
             RGBColor[
              0.21034714004508412`, 0.3384185593393235, 0.9352903304936357], 
             UndirectedEdge[181, 305] -> 
             RGBColor[
              0.18857843384879308`, 0.3155382689113313, 0.9340506348796719], 
             UndirectedEdge[153, 372] -> 
             RGBColor[
              0.18825648302408265`, 0.31519987818169937`, 0.9340323002564883],
              UndirectedEdge[175, 227] -> 
             RGBColor[
              0.24456047357150879`, 0.37437894212623135`, 0.9372387292238745],
              UndirectedEdge[271, 287] -> 
             RGBColor[
              0.18451611233351262`, 0.31126851143271117`, 0.9338192916790429],
              UndirectedEdge[232, 297] -> 
             RGBColor[
              0.25100667694524614`, 0.38115431058492943`, 0.9376058309697055],
              UndirectedEdge[21, 25] -> 
             RGBColor[
              0.890260551987202, 0.5108305987640545, 0.23788277597524127`], 
             UndirectedEdge[123, 297] -> 
             RGBColor[
              0.20930917766859286`, 0.3373275950710155, 0.9352312200718224], 
             UndirectedEdge[6, 178] -> 
             RGBColor[
              0.37363938184973156`, 0.4977574548464476, 0.9450396379279142], 
             UndirectedEdge[90, 319] -> 
             RGBColor[
              0.530870221387825, 0.6300233870103961, 0.956211194950797], 
             UndirectedEdge[258, 302] -> 
             RGBColor[
              0.18739149065206478`, 0.3142907163550246, 0.9339830402205433], 
             UndirectedEdge[253, 397] -> 
             RGBColor[
              0.20200814651583682`, 0.3296537484173573, 0.9348154371485806], 
             UndirectedEdge[169, 177] -> 
             RGBColor[
              0.8953206105495907, 0.9193683682944271, 0.9898776731680061], 
             UndirectedEdge[198, 332] -> 
             RGBColor[
              0.29082644977848415`, 0.41888733476416706`, 0.9400243645014585],
              UndirectedEdge[45, 123] -> 
             RGBColor[
              0.24825361468381962`, 0.37826066759394095`, 0.9374490481467079],
              UndirectedEdge[223, 245] -> 
             RGBColor[
              0.8743661025414482, 0.452767023574467, 0.2140604082418407], 
             UndirectedEdge[380, 381] -> 
             RGBColor[
              0.20814382827755723`, 0.3361027389736181, 0.9351648551479828], 
             UndirectedEdge[277, 378] -> 
             RGBColor[
              0.19931695292516527`, 0.3268251333220326, 0.934662177654856], 
             UndirectedEdge[119, 326] -> 
             RGBColor[
              0.18721381086797456`, 0.3141039636363968, 0.933972921619693], 
             UndirectedEdge[89, 133] -> 
             RGBColor[
              0.1875161010871107, 0.31442168982301577`, 0.9339901366004746], 
             UndirectedEdge[22, 346] -> 
             RGBColor[
              0.3336708932604665, 0.46343068978065516`, 0.9424821921583393], 
             UndirectedEdge[73, 243] -> 
             RGBColor[
              0.9500707567190481, 0.8697065757980069, 0.5997490197634427], 
             UndirectedEdge[26, 353] -> 
             RGBColor[
              0.1885101327336185, 0.315466480108742, 0.9340467452322052], 
             UndirectedEdge[21, 230] -> 
             RGBColor[
              0.8904702103094787, 0.5124421245019355, 0.2380835450214286], 
             UndirectedEdge[107, 390] -> 
             RGBColor[
              0.30566480118721207`, 0.43491696287761505`, 0.9408535111759078],
              UndirectedEdge[223, 364] -> 
             RGBColor[
              0.8737896349062411, 0.4483360407205369, 0.2135083821833393], 
             UndirectedEdge[2, 211] -> 
             RGBColor[
              0.2034376502421772, 0.3311562474695121, 0.9348968452710344], 
             UndirectedEdge[128, 353] -> 
             RGBColor[
              0.19231632365158768`, 0.3194670280899702, 0.9342635021742287], 
             UndirectedEdge[259, 331] -> 
             RGBColor[
              0.19269223822101744`, 0.31986213813680114`, 0.934284909952842], 
             UndirectedEdge[2, 334] -> 
             RGBColor[
              0.18498335204934083`, 0.3117596099987556, 0.93384590028964], 
             UndirectedEdge[72, 191] -> 
             RGBColor[
              0.19501894918374685`, 0.32230765888062524`, 0.934417412700109], 
             UndirectedEdge[247, 301] -> 
             RGBColor[
              0.1901623548072361, 0.317203070265044, 0.9341408368350541], 
             UndirectedEdge[247, 397] -> 
             RGBColor[
              0.20527567361963986`, 0.3330881265766384, 0.935001517983269], 
             UndirectedEdge[125, 263] -> 
             RGBColor[
              0.326732269165051, 0.4530536866427142, 0.9421999706648885], 
             UndirectedEdge[123, 325] -> 
             RGBColor[
              0.2504184772778667, 0.38053607544050067`, 0.9375723338688118], 
             UndirectedEdge[129, 393] -> 
             RGBColor[
              0.18622578456981498`, 0.3130654853525456, 0.9339166549836668], 
             UndirectedEdge[19, 205] -> 
             RGBColor[
              0.30521095643223367`, 0.4343105926394541, 0.9408324015485454], 
             UndirectedEdge[277, 352] -> 
             RGBColor[
              0.22370886564436498`, 0.3524625801265016, 0.9360512609996132], 
             UndirectedEdge[139, 224] -> 
             RGBColor[
              0.18369701044953324`, 0.3104075834185898, 0.9337726450385029], 
             UndirectedEdge[65, 250] -> 
             RGBColor[
              0.2731468584894696, 0.40442504515649597`, 0.9388666815551856], 
             UndirectedEdge[58, 117] -> 
             RGBColor[
              0.2190498578943207, 0.34756566758305235`, 0.9357859374006325], 
             UndirectedEdge[134, 272] -> 
             RGBColor[0.7859507335711424, 0.832798734683, 0.9792763222925633],
              UndirectedEdge[74, 95] -> 
             RGBColor[
              0.7112349833542422, 0.7734189351765257, 0.9726292882180788], 
             UndirectedEdge[156, 245] -> 
             RGBColor[
              0.8249079613041663, 0.19245908208786985`, 0.17148519791537548`],
              UndirectedEdge[221, 324] -> 
             RGBColor[
              0.7677190036317167, 0.6811645798747406, 0.602228741750033], 
             UndirectedEdge[227, 375] -> 
             RGBColor[
              0.1940331226429612, 0.32127149268124666`, 0.9343612713370109], 
             UndirectedEdge[132, 348] -> 
             RGBColor[
              0.34570653122762846`, 0.47385535445905747`, 0.94324909236691], 
             UndirectedEdge[137, 319] -> 
             RGBColor[
              0.3939126281591366, 0.5156078641515458, 0.9463210706392715], 
             UndirectedEdge[128, 170] -> 
             RGBColor[
              0.21313809335858236`, 0.34135202822847077`, 0.9354492711559941],
              UndirectedEdge[120, 220] -> 
             RGBColor[
              0.5770608462863022, 0.6675230171669182, 0.9598474901446392], 
             UndirectedEdge[292, 371] -> 
             RGBColor[
              0.1904665323376698, 0.31752278013549917`, 0.934158159295422], 
             UndirectedEdge[143, 378] -> 
             RGBColor[
              0.18793083673403851`, 0.31485760328369566`, 0.9340137551820207],
              UndirectedEdge[59, 373] -> 
             RGBColor[
              0.3091816453180559, 0.4388081534280127, 0.9410466589681301], 
             UndirectedEdge[2, 340] -> 
             RGBColor[
              0.19396024281710603`, 0.32119489136342505`, 0.9343571209387445],
              UndirectedEdge[131, 322] -> 
             RGBColor[
              0.206580775656939, 0.33445987156608825`, 0.9350758416135677], 
             UndirectedEdge[62, 317] -> 
             RGBColor[
              0.19822991985182326`, 0.32568259264007254`, 0.9346002727294505],
              UndirectedEdge[243, 337] -> 
             RGBColor[
              0.981786507894951, 0.983234170680865, 0.764939800713467], 
             UndirectedEdge[21, 217] -> 
             RGBColor[
              0.9781358461419554, 0.9375595363156388, 0.3992965964312667], 
             UndirectedEdge[24, 74] -> 
             RGBColor[
              0.8419234511371824, 0.5272135480684979, 0.5771697251114055], 
             UndirectedEdge[1, 127] -> 
             RGBColor[
              0.19417547404882396`, 0.3214211130344089, 0.9343693780389848], 
             UndirectedEdge[226, 355] -> 
             RGBColor[
              0.6054737407452027, 0.6884810215092875, 0.963436744212341], 
             UndirectedEdge[97, 370] -> 
             RGBColor[
              0.18998864922989284`, 0.31702049468968657`, 0.9341309445593988],
              UndirectedEdge[148, 257] -> 
             RGBColor[
              0.3285413065471964, 0.4589876995901452, 0.9421553394288851], 
             UndirectedEdge[48, 344] -> 
             RGBColor[
              0.21571874970997718`, 0.3440644616768498, 0.9355962357174672], 
             UndirectedEdge[74, 148] -> 
             RGBColor[
              0.5985191344063026, 0.6786707763192633, 0.9646512034079422], 
             UndirectedEdge[266, 293] -> 
             RGBColor[
              0.2908233203898157, 0.4192921425712095, 0.940009243857379], 
             UndirectedEdge[84, 226] -> 
             RGBColor[
              0.39203908397867687`, 0.5139862829102032, 0.9462013616579391], 
             UndirectedEdge[354, 371] -> 
             RGBColor[
              0.20120013846367035`, 0.3288044807238608, 0.9347694222853504], 
             UndirectedEdge[57, 188] -> 
             RGBColor[
              0.20973271485913975`, 0.33777275951208907`, 0.9352553398882568],
              UndirectedEdge[134, 355] -> 
             RGBColor[
              0.7983376603764013, 0.8424754960473988, 0.9805109353940992], 
             UndirectedEdge[151, 378] -> 
             RGBColor[
              0.19141895458300517`, 0.3185238363024048, 0.9342123983333115], 
             UndirectedEdge[167, 238] -> 
             RGBColor[
              0.3001182809431252, 0.43263426016352036`, 0.9404077704799216], 
             UndirectedEdge[41, 311] -> 
             RGBColor[
              0.5873075100595555, 0.6681019111801583, 0.9640966123738608], 
             UndirectedEdge[212, 295] -> 
             RGBColor[
              0.42318563987531466`, 0.5409638641564534, 0.9481859926578549], 
             UndirectedEdge[179, 285] -> 
             RGBColor[
              0.7240735565365042, 0.7787875887954807, 0.7800674551938157], 
             UndirectedEdge[85, 348] -> 
             RGBColor[
              0.28694246093137055`, 0.4166697387111759, 0.9397349004577378], 
             UndirectedEdge[108, 152] -> 
             RGBColor[
              0.2564614085339687, 0.38688757933463486`, 0.9379164698641311], 
             UndirectedEdge[86, 148] -> 
             RGBColor[
              0.37250043656006593`, 0.49706288855717573`, 0.9449563763217728],
              UndirectedEdge[113, 293] -> 
             RGBColor[
              0.32820995463660485`, 0.4585878656141067, 0.9421383573691648], 
             UndirectedEdge[229, 260] -> 
             RGBColor[
              0.21573241152320438`, 0.34407882110876054`, 0.9355970137375196],
              UndirectedEdge[6, 278] -> 
             RGBColor[
              0.28187720037590647`, 0.4136011880147874, 0.9393638616102349], 
             UndirectedEdge[142, 378] -> 
             RGBColor[
              0.18665371404405717`, 0.3135152663622699, 0.93394102493416], 
             UndirectedEdge[289, 303] -> 
             RGBColor[
              0.19970158242580874`, 0.32722940331412775`, 0.9346840817359092],
              UndirectedEdge[5, 213] -> 
             RGBColor[
              0.25252900688278906`, 0.3827543758705798, 0.9376925254075633], 
             UndirectedEdge[104, 243] -> 
             RGBColor[
              0.8942676597098645, 0.5619556471729128, 0.5511524219741538], 
             UndirectedEdge[121, 373] -> 
             RGBColor[
              0.2913786665893785, 0.4233881080569608, 0.9399122689060947], 
             UndirectedEdge[120, 202] -> 
             RGBColor[
              0.38082926485589774`, 0.49646706771580507`, 0.9461959416990309],
              UndirectedEdge[270, 351] -> 
             RGBColor[
              0.6344443344456173, 0.7081804286544429, 0.9676800928710849], 
             UndirectedEdge[91, 125] -> 
             RGBColor[
              0.37740486226419223`, 0.49585819381446866`, 0.9457287231087954],
              UndirectedEdge[280, 297] -> 
             RGBColor[
              0.22922829336444137`, 0.3582638486122316, 0.9363655842430101], 
             UndirectedEdge[33, 281] -> 
             RGBColor[
              0.3526148324525338, 0.4768614731328931, 0.9437983042422098], 
             UndirectedEdge[16, 241] -> 
             RGBColor[
              0.29049437153587576`, 0.42182354173579545`, 0.9398851643245274],
              UndirectedEdge[89, 342] -> 
             RGBColor[
              0.18647972709604152`, 0.31333239504849575`, 0.9339311166348612],
              UndirectedEdge[157, 370] -> 
             RGBColor[
              0.18724094908895864`, 0.3141324876273136, 0.9339744671012307], 
             UndirectedEdge[90, 122] -> 
             RGBColor[
              0.6031707449782447, 0.6887202091625689, 0.9619029570133792], 
             UndirectedEdge[135, 156] -> 
             RGBColor[
              0.9129140627520606, 0.6152764832633987, 0.4286476247419544], 
             UndirectedEdge[12, 22] -> 
             RGBColor[
              0.3123757406994519, 0.44496094634460026`, 0.9411261975051177], 
             UndirectedEdge[271, 384] -> 
             RGBColor[
              0.18432884103510522`, 0.31107167742439884`, 0.9338086268556416],
              UndirectedEdge[158, 324] -> 
             RGBColor[
              0.4859428845919035, 0.5904387279012617, 0.9535338248669657], 
             UndirectedEdge[301, 397] -> 
             RGBColor[
              0.19781003665891564`, 0.3252412687821946, 0.934576361002776], 
             UndirectedEdge[95, 233] -> 
             RGBColor[
              0.7594081345567827, 0.8112195509449376, 0.9560282891124947], 
             UndirectedEdge[123, 203] -> 
             RGBColor[
              0.21872743662810462`, 0.3472267823895703, 0.935767575986501], 
             UndirectedEdge[103, 145] -> 
             RGBColor[
              0.1958024601948291, 0.32313117863074003`, 0.9344620324930895], 
             UndirectedEdge[20, 80] -> 
             RGBColor[
              0.18504810846190303`, 0.31182767309415216`, 0.933849588071537], 
             UndirectedEdge[73, 337] -> 
             RGBColor[
              0.9623310682876794, 0.8761474788456531, 0.428220440311572], 
             UndirectedEdge[122, 166] -> 
             RGBColor[
              0.7938288566186125, 0.8372493846021647, 0.890969402038376], 
             UndirectedEdge[62, 216] -> 
             RGBColor[
              0.2004082229571123, 0.32797212731612524`, 0.934724323868786], 
             UndirectedEdge[128, 342] -> 
             RGBColor[
              0.18916310762939384`, 0.3161527981252015, 0.9340839311865298], 
             UndirectedEdge[280, 309] -> 
             RGBColor[
              0.27456630331146203`, 0.4059169716624097, 0.9389475168379178], 
             UndirectedEdge[104, 141] -> 
             RGBColor[
              0.8423033289137494, 0.3148548235404699, 0.18770004553512668`], 
             UndirectedEdge[148, 276] -> 
             RGBColor[
              0.27841767131860123`, 0.407632112720532, 0.9392522651124343], 
             UndirectedEdge[359, 394] -> 
             RGBColor[
              0.18381809529055626`, 0.3105348512637273, 0.9337795406410702], 
             UndirectedEdge[8, 43] -> 
             RGBColor[
              0.24908603513269617`, 0.379135594264215, 0.9374964532598158], 
             UndirectedEdge[56, 352] -> 
             RGBColor[
              0.31062641380180694`, 0.4370779234706822, 0.9412478898986653], 
             UndirectedEdge[70, 152] -> 
             RGBColor[
              0.2398425593336916, 0.3694201151292457, 0.9369700509875596], 
             UndirectedEdge[359, 397] -> 
             RGBColor[
              0.20006364261390616`, 0.32760995152775996`, 0.9347047005280014],
              UndirectedEdge[118, 241] -> 
             RGBColor[
              0.25104726308957875`, 0.38119696919593304`, 0.9376081422905835],
              UndirectedEdge[43, 227] -> 
             RGBColor[
              0.23391469744368304`, 0.36318955643469497`, 0.9366324680224093],
              UndirectedEdge[234, 246] -> 
             RGBColor[
              0.8529840469746812, 0.885887262707637, 0.9857660876177745], 
             UndirectedEdge[196, 317] -> 
             RGBColor[
              0.1925447584771704, 0.3197071275752621, 0.9342765111996065], 
             UndirectedEdge[46, 184] -> 
             RGBColor[
              0.19220194755564052`, 0.3193468115612663, 0.9342569886247687], 
             UndirectedEdge[136, 331] -> 
             RGBColor[
              0.19186850922797938`, 0.3189963467376835, 0.9342379998052863], 
             UndirectedEdge[106, 320] -> 
             RGBColor[
              0.21130568150236095`, 0.33942604718596003`, 0.9353449180115927],
              UndirectedEdge[68, 161] -> 
             RGBColor[
              0.23474066997997348`, 0.36405770594001974`, 0.9366795059364341],
              UndirectedEdge[45, 297] -> 
             RGBColor[
              0.2458649611438621, 0.37575004127406386`, 0.9373130178613036], 
             UndirectedEdge[140, 203] -> 
             RGBColor[
              0.22572809779654535`, 0.3545849211451561, 0.9361662532834936], 
             UndirectedEdge[225, 243] -> 
             RGBColor[
              0.9271182354136238, 0.9438506209861709, 0.9626670150045318], 
             UndirectedEdge[107, 373] -> 
             RGBColor[
              0.31023491732991126`, 0.43972044470569116`, 0.9411137725293536],
              UndirectedEdge[187, 321] -> 
             RGBColor[
              0.494640933100008, 0.6001112786340405, 0.9534971170641517], 
             UndirectedEdge[297, 322] -> 
             RGBColor[
              0.2034128145640179, 0.33113014359709375`, 0.9348954309159043], 
             UndirectedEdge[106, 374] -> 
             RGBColor[
              0.2085188963433679, 0.336496959291474, 0.9351862147194673], 
             UndirectedEdge[154, 383] -> 
             RGBColor[
              0.20693321063768522`, 0.33483030307652095`, 0.9350959122643404],
              UndirectedEdge[111, 151] -> 
             RGBColor[
              0.1906348725141942, 0.31769971633440997`, 0.9341677460194382], 
             UndirectedEdge[79, 227] -> 
             RGBColor[
              0.21925675873838124`, 0.34778313348843115`, 0.9357977200976195],
              UndirectedEdge[93, 290] -> 
             RGBColor[
              0.21626873884937514`, 0.3446425351336826, 0.9356275567853198], 
             UndirectedEdge[150, 283] -> 
             RGBColor[
              0.2012631111576979, 0.32887066901798323`, 0.9347730084871156], 
             UndirectedEdge[46, 195] -> 
             RGBColor[
              0.2015708688653357, 0.3291941418816762, 0.9347905348332788], 
             UndirectedEdge[73, 177] -> 
             RGBColor[
              0.912733918365472, 0.8408075046276462, 0.6264313427993702], 
             UndirectedEdge[102, 189] -> 
             RGBColor[
              0.27205731447598563`, 0.4032798653172439, 0.9388046336354536], 
             UndirectedEdge[3, 95] -> 
             RGBColor[
              0.5706393994295823, 0.6623097973257487, 0.9593419703255434], 
             UndirectedEdge[39, 294] -> 
             RGBColor[
              0.18656769797512113`, 0.31342485802008435`, 0.9339361264462835],
              UndirectedEdge[5, 227] -> 
             RGBColor[
              0.24495455926499354`, 0.3747931511765599, 0.937261171821121], 
             UndirectedEdge[166, 169] -> 
             RGBColor[
              0.9427417968791698, 0.9548740993356628, 0.9051840770091248], 
             UndirectedEdge[27, 337] -> 
             RGBColor[
              0.9075425280380967, 0.5761948780564576, 0.3805953832210548], 
             UndirectedEdge[84, 174] -> 
             RGBColor[
              0.3414171398675645, 0.4701400992540484, 0.9429757761424066], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.313125811057198, 0.4456106195888476, 0.9411739913250522], 
             UndirectedEdge[138, 349] -> 
             RGBColor[
              0.19211902352341417`, 0.31925965314570914`, 0.9342522662238085],
              UndirectedEdge[26, 159] -> 
             RGBColor[
              0.18375580691440718`, 0.3104693822310835, 0.9337759934101959], 
             UndirectedEdge[81, 287] -> 
             RGBColor[
              0.1847451216726243, 0.31150921476814825`, 0.9338323334221164], 
             UndirectedEdge[311, 361] -> 
             RGBColor[
              0.2601900040751639, 0.39080656965504246`, 0.9381288078642394], 
             UndirectedEdge[231, 393] -> 
             RGBColor[
              0.18277810360197083`, 0.30944175405974256`, 0.933720314652935], 
             UndirectedEdge[201, 223] -> 
             RGBColor[
              0.9394729571932308, 0.8606549580209606, 0.6167978110210142], 
             UndirectedEdge[180, 267] -> 
             RGBColor[
              0.25726504669656514`, 0.3877322539971262, 0.9379622358686148], 
             UndirectedEdge[217, 264] -> 
             RGBColor[
              0.8581806271651595, 0.8856725444548357, 0.7300501263511203], 
             UndirectedEdge[163, 174] -> 
             RGBColor[
              0.3053955889489409, 0.4350613598921163, 0.9408225323352425], 
             UndirectedEdge[203, 280] -> 
             RGBColor[
              0.23864655232395315`, 0.36816303593078636`, 0.9369019401576887],
              UndirectedEdge[40, 163] -> 
             RGBColor[
              0.3939273213258807, 0.5099037447255685, 0.9469719144794696], 
             UndirectedEdge[14, 62] -> 
             RGBColor[
              0.1928274082051604, 0.3200042103604074, 0.9342926076834728], 
             UndirectedEdge[49, 133] -> 
             RGBColor[
              0.18673252269027052`, 0.31359809924619686`, 0.933945512969975], 
             UndirectedEdge[276, 288] -> 
             RGBColor[
              0.2641141546829352, 0.39493110074932897`, 0.9383522824360913], 
             UndirectedEdge[312, 366] -> 
             RGBColor[
              0.3486542052668462, 0.4758688117654473, 0.9434566755048852], 
             UndirectedEdge[23, 120] -> 
             RGBColor[
              0.40567769043424073`, 0.5225843384798207, 0.9476110227757661], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.18052420551329257`, 0.307072764263149, 0.9335919584911282], 
             UndirectedEdge[73, 399] -> 
             RGBColor[
              0.9285956897332439, 0.7546127344078406, 0.2614046197660328], 
             UndirectedEdge[269, 272] -> 
             RGBColor[
              0.7422573926850033, 0.7985763836214297, 0.9749449381792838], 
             UndirectedEdge[20, 151] -> 
             RGBColor[
              0.19115376674236922`, 0.3182451070680162, 0.9341972962780976], 
             UndirectedEdge[239, 355] -> 
             RGBColor[
              0.7967350259379453, 0.5156495091253714, 0.57575064772341], 
             UndirectedEdge[274, 319] -> 
             RGBColor[
              0.47322013025663245`, 0.583220445923085, 0.9516727685977074], 
             UndirectedEdge[6, 352] -> 
             RGBColor[
              0.27259546821957914`, 0.40384549902267874`, 0.9388352806950242],
              UndirectedEdge[133, 342] -> 
             RGBColor[
              0.18475081584068775`, 0.311515199699814, 0.9338326576965637], 
             UndirectedEdge[290, 318] -> 
             RGBColor[
              0.1963038433293812, 0.3236581640946811, 0.9344905855208723], 
             UndirectedEdge[87, 298] -> 
             RGBColor[
              0.19758831891525655`, 0.325008229375892, 0.9345637345052766], 
             UndirectedEdge[86, 263] -> 
             RGBColor[
              0.4014876492319413, 0.5221701552338829, 0.9468034158808389], 
             UndirectedEdge[109, 191] -> 
             RGBColor[
              0.19427315985261398`, 0.3215237870078299, 0.9343749411009974], 
             UndirectedEdge[84, 238] -> 
             RGBColor[
              0.3144100017377778, 0.44501303039307516`, 0.9413184262912844], 
             UndirectedEdge[21, 244] -> 
             RGBColor[
              0.9589837634229517, 0.9266594522436353, 0.6365010356742713], 
             UndirectedEdge[137, 175] -> 
             RGBColor[
              0.3080574204607164, 0.43874050226861905`, 0.940941847744563], 
             UndirectedEdge[363, 369] -> 
             RGBColor[
              0.20524927327278905`, 0.33306037813821954`, 0.9350000145225716],
              UndirectedEdge[98, 290] -> 
             RGBColor[
              0.19961632362064485`, 0.32713979090418005`, 0.9346792263730843],
              UndirectedEdge[175, 352] -> 
             RGBColor[
              0.2606268889022622, 0.3912657633084208, 0.9381536878088295], 
             UndirectedEdge[121, 319] -> 
             RGBColor[
              0.3821339767558598, 0.5054057883182604, 0.9455705453873072], 
             UndirectedEdge[249, 387] -> 
             RGBColor[
              0.4216012233503626, 0.5373973944320252, 0.9486912790769737], 
             UndirectedEdge[310, 389] -> 
             RGBColor[
              0.24112387106664201`, 0.3707668550004327, 0.9370430197952202], 
             UndirectedEdge[228, 238] -> 
             RGBColor[
              0.24678874654536498`, 0.3767209983024208, 0.9373656260733012], 
             UndirectedEdge[268, 324] -> 
             RGBColor[
              0.6562462626397825, 0.7312424529611288, 0.9664688163111557], 
             UndirectedEdge[144, 368] -> 
             RGBColor[
              0.18786109875542928`, 0.31478430424653414`, 0.934009783707307], 
             UndirectedEdge[137, 278] -> 
             RGBColor[
              0.29631468313808673`, 0.42639814080998684`, 0.9402731162258624],
              UndirectedEdge[127, 298] -> 
             RGBColor[
              0.19590091614963856`, 0.32323466208171286`, 0.9344676394140633],
              UndirectedEdge[131, 228] -> 
             RGBColor[
              0.20842587898456535`, 0.33639919214973135`, 0.9351809175184903],
              UndirectedEdge[278, 314] -> 
             RGBColor[
              0.2454200867859244, 0.3752824501172079, 0.9372876829247517], 
             UndirectedEdge[182, 311] -> 
             RGBColor[
              0.32563786800336725`, 0.45591796242171545`, 0.9419906534014555],
              UndirectedEdge[77, 94] -> 
             RGBColor[
              0.18199794707454847`, 0.3086217600846408, 0.9336758858928365], 
             UndirectedEdge[144, 333] -> 
             RGBColor[
              0.1893313874669234, 0.316329670904003, 0.9340935144743294], 
             UndirectedEdge[166, 197] -> 
             RGBColor[
              0.9770032019247867, 0.9814553758280588, 0.8828706575837489], 
             UndirectedEdge[106, 384] -> 
             RGBColor[
              0.2081882862900271, 0.33614946716352473`, 0.9351673869660233], 
             UndirectedEdge[28, 265] -> 
             RGBColor[
              0.1984857219314811, 0.32595145684458154`, 0.9346148402794617], 
             UndirectedEdge[113, 266] -> 
             RGBColor[
              0.2701389734664643, 0.40126356728639195`, 0.9386953869528927], 
             UndirectedEdge[164, 292] -> 
             RGBColor[
              0.19766905263223078`, 0.3250930856312453, 0.9345683321710234], 
             UndirectedEdge[98, 248] -> 
             RGBColor[
              0.2095071320406308, 0.3375356576670594, 0.9352424932804627], 
             UndirectedEdge[91, 95] -> 
             RGBColor[
              0.5263538722152581, 0.6263568112928946, 0.9558556514000003], 
             UndirectedEdge[155, 342] -> 
             RGBColor[
              0.19539787597679303`, 0.32270593496546307`, 0.9344389920204009],
              UndirectedEdge[47, 209] -> 
             RGBColor[
              0.43947307837840166`, 0.5526061814054317, 0.9499049126595958], 
             UndirectedEdge[2, 360] -> 
             RGBColor[
              0.18511749831467772`, 0.3119006062289892, 0.9338535397209994], 
             UndirectedEdge[75, 341] -> 
             RGBColor[
              0.2771008643732843, 0.406039405513939, 0.9391849149556509], 
             UndirectedEdge[12, 390] -> 
             RGBColor[
              0.28559351861557547`, 0.41750727411286515`, 0.9395755004361839],
              UndirectedEdge[19, 198] -> 
             RGBColor[
              0.30685620721234774`, 0.43573562617248035`, 0.9409372354734161],
              UndirectedEdge[8, 56] -> 
             RGBColor[
              0.30973133616006665`, 0.43613714011801286`, 0.9411969165511169],
              UndirectedEdge[70, 154] -> 
             RGBColor[
              0.21421417432422896`, 0.3424830575508392, 0.9355105523750686], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.18749255911212426`, 0.3143969457146576, 0.9339887959198263], 
             UndirectedEdge[177, 243] -> 
             RGBColor[
              0.9321893579727436, 0.9478941964628581, 0.9631507032012652], 
             UndirectedEdge[109, 340] -> 
             RGBColor[
              0.19212863805325098`, 0.319269758626164, 0.9342528137570594], 
             UndirectedEdge[28, 36] -> 
             RGBColor[
              0.19993330434376533`, 0.3274729577419183, 0.9346972779563351], 
             UndirectedEdge[203, 339] -> 
             RGBColor[
              0.23865240959631934`, 0.3681691922954158, 0.9369022737206849], 
             UndirectedEdge[247, 369] -> 
             RGBColor[
              0.19411283179141248`, 0.32135527205012093`, 0.934365810655096], 
             UndirectedEdge[223, 230] -> 
             RGBColor[
              0.8738202331046678, 0.44857123188186093`, 0.21353768305270848`],
              UndirectedEdge[22, 173] -> 
             RGBColor[
              0.2993775960909632, 0.43129907223111097`, 0.940385972398696], 
             UndirectedEdge[69, 283] -> 
             RGBColor[
              0.22539830685763262`, 0.3542382899584056, 0.9361474721774046], 
             UndirectedEdge[59, 274] -> 
             RGBColor[
              0.41979531196311004`, 0.5369477420873823, 0.9482682580148925], 
             UndirectedEdge[31, 164] -> 
             RGBColor[
              0.19871454021211585`, 0.32619195936544565`, 0.9346278711420376],
              UndirectedEdge[116, 154] -> 
             RGBColor[
              0.19442534169189124`, 0.3216837397697962, 0.9343836076316113], 
             UndirectedEdge[10, 170] -> 
             RGBColor[
              0.2345826966210814, 0.3638916659237347, 0.936670509587346], 
             UndirectedEdge[301, 394] -> 
             RGBColor[
              0.18156448933556574`, 0.30816616851816203`, 0.9336512011158447],
              UndirectedEdge[90, 351] -> 
             RGBColor[
              0.7590840463718008, 0.8119268218437792, 0.9767853326782896], 
             UndirectedEdge[4, 203] -> 
             RGBColor[
              0.22928794206914588`, 0.35832654318282237`, 0.9363689811485005],
              UndirectedEdge[274, 351] -> 
             RGBColor[
              0.7014339552406084, 0.7651238807564681, 0.9722469063252], 
             UndirectedEdge[238, 269] -> 
             RGBColor[
              0.5167818424220354, 0.6108654129881752, 0.9574511707265], 
             UndirectedEdge[66, 325] -> 
             RGBColor[
              0.2517049597881912, 0.3818882501265539, 0.9376455971445944], 
             UndirectedEdge[128, 171] -> 
             RGBColor[
              0.19178726559275905`, 0.3189109545259229, 0.9342333731004496], 
             UndirectedEdge[198, 205] -> 
             RGBColor[
              0.35166297002886326`, 0.47901452236936815`, 0.9436286313802527],
              UndirectedEdge[202, 349] -> 
             RGBColor[
              0.22267250403179975`, 0.35137329836257414`, 0.9359922417389372],
              UndirectedEdge[295, 390] -> 
             RGBColor[
              0.34587288956677426`, 0.46974318811470905`, 0.943415535012837], 
             UndirectedEdge[250, 356] -> 
             RGBColor[
              0.22666963106636354`, 0.3555745323083922, 0.9362198722103361], 
             UndirectedEdge[133, 393] -> 
             RGBColor[
              0.18457522111446595`, 0.3113306385092063, 0.9338226578366745], 
             UndirectedEdge[124, 293] -> 
             RGBColor[
              0.3293119680498331, 0.45965520784915576`, 0.9422044452983639], 
             UndirectedEdge[45, 325] -> 
             RGBColor[
              0.2869742607531359, 0.4189585216435491, 0.9396541316582929], 
             UndirectedEdge[116, 304] -> 
             RGBColor[
              0.18211433978369124`, 0.30874409620167387`, 0.9336825142854346],
              UndirectedEdge[213, 296] -> 
             RGBColor[
              0.2337895217777734, 0.3630579888732283, 0.9366253394534165], 
             UndirectedEdge[248, 276] -> 
             RGBColor[
              0.22042799245848094`, 0.3490141743887628, 0.9358644201252941], 
             UndirectedEdge[209, 346] -> 
             RGBColor[
              0.34295446203942725`, 0.47147165045125694`, 0.9430737329517971],
              UndirectedEdge[31, 382] -> 
             RGBColor[
              0.18918398084593196`, 0.3161747371992214, 0.9340851198853325], 
             UndirectedEdge[69, 373] -> 
             RGBColor[
              0.25683371538447886`, 0.38727889744013877`, 0.937937672188489], 
             UndirectedEdge[166, 239] -> 
             RGBColor[
              0.9087289042908429, 0.6022050523179494, 0.4973324699831219], 
             UndirectedEdge[235, 317] -> 
             RGBColor[
              0.19343401255220036`, 0.32064178999008336`, 0.934327152903646], 
             UndirectedEdge[43, 59] -> 
             RGBColor[
              0.3034359716582913, 0.4327690861148492, 0.9407194513531689], 
             UndirectedEdge[94, 207] -> 
             RGBColor[
              0.18447193191249567`, 0.3112220750090219, 0.933816775669425], 
             UndirectedEdge[209, 270] -> 
             RGBColor[
              0.34697087401529814`, 0.4749504646340207, 0.9433296551713259], 
             UndirectedEdge[23, 341] -> 
             RGBColor[
              0.3146456284168403, 0.44550133299924655`, 0.9413230337254305], 
             UndirectedEdge[264, 312] -> 
             RGBColor[
              0.5131003370105822, 0.6097335825641022, 0.9568081018654329], 
             UndirectedEdge[48, 118] -> 
             RGBColor[
              0.23953466514577643`, 0.3690964988161278, 0.9369525168690463], 
             UndirectedEdge[106, 310] -> 
             RGBColor[
              0.2532088981789974, 0.38346898473049273`, 0.9377312442110733], 
             UndirectedEdge[267, 282] -> 
             RGBColor[
              0.2615646860965489, 0.39225144761939246`, 0.9382070939716974], 
             UndirectedEdge[43, 274] -> 
             RGBColor[
              0.3767191464303865, 0.4951636983486218, 0.9456872845015338], 
             UndirectedEdge[46, 362] -> 
             RGBColor[
              0.19522925834887567`, 0.3225287071475469, 0.9344293894959386], 
             UndirectedEdge[38, 117] -> 
             RGBColor[
              0.22453541604736282`, 0.35333133700637476`, 0.9360983318222922],
              UndirectedEdge[252, 300] -> 
             RGBColor[
              0.6421328397168371, 0.7146709767757251, 0.9682477279637229], 
             UndirectedEdge[7, 67] -> 
             RGBColor[
              0.43693392935130804`, 0.5528719414914377, 0.9490620215061302], 
             UndirectedEdge[150, 192] -> 
             RGBColor[
              0.1875835174154828, 0.3144925486585769, 0.9339939758606419], 
             UndirectedEdge[239, 272] -> 
             RGBColor[
              0.7843480991326863, 0.5059727477609727, 0.5745160346218742], 
             UndirectedEdge[22, 209] -> 
             RGBColor[
              0.32555893410641223`, 0.4564045184803353, 0.9419653052941668], 
             UndirectedEdge[167, 246] -> 
             RGBColor[
              0.6152498673613919, 0.6911955828537762, 0.9666225650716829], 
             UndirectedEdge[131, 140] -> 
             RGBColor[
              0.21947779992995464`, 0.3480154617955958, 0.9358103080664784], 
             UndirectedEdge[67, 385] -> 
             RGBColor[
              0.7098239251190117, 0.7666063809986858, 0.7914621261134387], 
             UndirectedEdge[60, 101] -> 
             RGBColor[
              0.18455258152934814`, 0.31130684286981486`, 0.9338213685457943],
              UndirectedEdge[113, 249] -> 
             RGBColor[
              0.3083010067824331, 0.4413437356356376, 0.9408697768166884], 
             UndirectedEdge[52, 393] -> 
             RGBColor[
              0.18136432541177624`, 0.30795578354313347`, 0.9336398020765009],
              UndirectedEdge[99, 367] -> 
             RGBColor[
              0.6703595369678017, 0.7365958473458555, 0.9440864000727226], 
             UndirectedEdge[5, 43] -> 
             RGBColor[
              0.2713996679468782, 0.4025886371179538, 0.9387671816385219], 
             UndirectedEdge[26, 105] -> 
             RGBColor[
              0.19823757833601402`, 0.32569064219253296`, 0.9346007088687955],
              UndirectedEdge[128, 306] -> 
             RGBColor[
              0.1986620698216136, 0.3261368096582128, 0.9346248830309214], 
             UndirectedEdge[226, 281] -> 
             RGBColor[
              0.43696413947427415`, 0.552898107981546, 0.9490639464684518], 
             UndirectedEdge[63, 345] -> 
             RGBColor[
              0.18008431245353695`, 0.306610408766515, 0.9335669072321386], 
             UndirectedEdge[4, 280] -> 
             RGBColor[
              0.24217745234544014`, 0.3718742357253608, 0.937103019690414], 
             UndirectedEdge[7, 223] -> 
             RGBColor[
              0.6892737381041355, 0.6614040887409706, 0.6061320446993241], 
             UndirectedEdge[155, 361] -> 
             RGBColor[
              0.21235865222551553`, 0.3405327861781953, 0.9354048831365458], 
             UndirectedEdge[252, 398] -> 
             RGBColor[
              0.39783022825914727`, 0.5190022810145718, 0.9465703682505828], 
             UndirectedEdge[6, 252] -> 
             RGBColor[
              0.3375773650971563, 0.4665223484650306, 0.9427417981088295], 
             UndirectedEdge[260, 307] -> 
             RGBColor[
              0.28646815305242945`, 0.41476449327789777`, 0.9397593961545982],
              UndirectedEdge[21, 357] -> 
             RGBColor[
              0.910151296596057, 0.6637195780075789, 0.25693017547606367`], 
             UndirectedEdge[233, 366] -> 
             RGBColor[
              0.6769028781273625, 0.7426382888986862, 0.9499751965434602], 
             UndirectedEdge[37, 41] -> 
             RGBColor[
              0.6103348144421008, 0.6886019294831773, 0.9655435733376975], 
             UndirectedEdge[173, 176] -> 
             RGBColor[
              0.25807437232061936`, 0.38858290654221544`, 0.9380083257656147],
              UndirectedEdge[60, 136] -> 
             RGBColor[
              0.18529719032077357`, 0.3120894739205271, 0.933863772914916], 
             UndirectedEdge[74, 285] -> 
             RGBColor[
              0.9286295448374513, 0.9418226643023089, 0.7983899704135337], 
             UndirectedEdge[234, 395] -> 
             RGBColor[
              0.6271808306424103, 0.7060165287006694, 0.9652946384160161], 
             UndirectedEdge[17, 164] -> 
             RGBColor[
              0.21631448031938844`, 0.34469061231884324`, 0.9356301616943686],
              UndirectedEdge[20, 383] -> 
             RGBColor[
              0.1993210537450841, 0.3268294435437743, 0.9346624111904838], 
             UndirectedEdge[19, 219] -> 
             RGBColor[
              0.2987647907941907, 0.4287272479574868, 0.9404216575742097], 
             UndirectedEdge[91, 279] -> 
             RGBColor[
              0.5827660155833214, 0.6716970806233367, 0.9606095197706748], 
             UndirectedEdge[76, 207] -> 
             RGBColor[
              0.1908268877624048, 0.3179015365347492, 0.9341786810037627], 
             UndirectedEdge[238, 339] -> 
             RGBColor[
              0.27076497929052823`, 0.4019215390985449, 0.9387310370584805], 
             UndirectedEdge[142, 379] -> 
             RGBColor[
              0.1947953347030193, 0.32207262588340363`, 0.9344046781862394], 
             UndirectedEdge[205, 219] -> 
             RGBColor[
              0.34357155361070624`, 0.4720061441543746, 0.9431130534810463], 
             UndirectedEdge[7, 68] -> 
             RGBColor[
              0.3593357938245753, 0.4820804322688437, 0.9442486147652995], 
             UndirectedEdge[188, 273] -> 
             RGBColor[
              0.19180481699179464`, 0.3189294021591323, 0.9342343726266598], 
             UndirectedEdge[16, 69] -> 
             RGBColor[
              0.2797958916834022, 0.41057876108804503`, 0.9392759017239116], 
             UndirectedEdge[118, 323] -> 
             RGBColor[
              0.3187861771861727, 0.44407882697168544`, 0.9417702640466686], 
             UndirectedEdge[211, 263] -> 
             RGBColor[
              0.30692109574993276`, 0.4322308872824815, 0.9410717536469021], 
             UndirectedEdge[191, 340] -> 
             RGBColor[
              0.2050792556090335, 0.33288167879387, 0.9349903322681394], 
             UndirectedEdge[33, 182] -> 
             RGBColor[
              0.3125367270389322, 0.44214783260778046`, 0.9412445628049322], 
             UndirectedEdge[99, 300] -> 
             RGBColor[
              0.9401681906865148, 0.9543565949425481, 0.9673889822446275], 
             UndirectedEdge[11, 91] -> 
             RGBColor[
              0.40263125450178067`, 0.5220751425472069, 0.9471762250170271], 
             UndirectedEdge[78, 233] -> 
             RGBColor[
              0.8896719661372465, 0.5617502239079055, 0.560162093898772], 
             UndirectedEdge[27, 172] -> 
             RGBColor[
              0.8224207314031455, 0.17334114315753277`, 0.1691034237532337], 
             UndirectedEdge[313, 396] -> 
             RGBColor[
              0.20896253735329678`, 0.3369632541213739, 0.9352114794186747], 
             UndirectedEdge[74, 172] -> 
             RGBColor[
              0.8434316387549917, 0.5388061389910088, 0.578613967277474], 
             UndirectedEdge[217, 366] -> 
             RGBColor[
              0.6937344954214235, 0.7518077736561808, 0.7166986999905727], 
             UndirectedEdge[277, 302] -> 
             RGBColor[
              0.19959521355734036`, 0.32711760288919167`, 0.9346780241862087],
              UndirectedEdge[203, 232] -> 
             RGBColor[
              0.26042493590475796`, 0.3910534979034842, 0.9381421868843842], 
             UndirectedEdge[27, 285] -> 
             RGBColor[
              0.9076186374856052, 0.576357668468833, 0.38887942688929333`], 
             UndirectedEdge[193, 334] -> 
             RGBColor[
              0.1859629402627897, 0.3127892193205704, 0.9339016863892251], 
             UndirectedEdge[39, 381] -> 
             RGBColor[
              0.18966952552711056`, 0.31668507544445096`, 0.9341127709366266],
              UndirectedEdge[270, 390] -> 
             RGBColor[
              0.310905083152461, 0.4394558317316838, 0.9411874173089341], 
             UndirectedEdge[35, 42] -> 
             RGBColor[
              0.22638274960055194`, 0.35527300169848874`, 0.9362035347352613],
              UndirectedEdge[41, 245] -> 
             RGBColor[
              0.8453505309169804, 0.5232059626309822, 0.576653008726561], 
             UndirectedEdge[45, 276] -> 
             RGBColor[
              0.2538332616499947, 0.38412523032544144`, 0.9377668007870836], 
             UndirectedEdge[17, 241] -> 
             RGBColor[
              0.2474447922190557, 0.37741054390116785`, 0.9374029869038852], 
             UndirectedEdge[69, 347] -> 
             RGBColor[
              0.21983376516516337`, 0.34838960382729967`, 0.9358305797600202],
              UndirectedEdge[16, 295] -> 
             RGBColor[
              0.3734051820083968, 0.4978465335906915, 0.9450140259017055], 
             UndirectedEdge[190, 351] -> 
             RGBColor[
              0.9330043693197932, 0.948887212220239, 0.9751255904637988], 
             UndirectedEdge[112, 141] -> 
             RGBColor[
              0.9013527030672266, 0.6354761592849575, 0.23890867411463246`], 
             UndirectedEdge[135, 400] -> 
             RGBColor[
              0.9225103695720027, 0.6890379026099368, 0.4378370589902095], 
             UndirectedEdge[295, 310] -> 
             RGBColor[
              0.3543169737444146, 0.4786184559712684, 0.9438964131148506], 
             UndirectedEdge[185, 249] -> 
             RGBColor[
              0.35433837255967027`, 0.48133182157191207`, 0.9437991056637501],
              UndirectedEdge[93, 98] -> 
             RGBColor[
              0.21766781953393055`, 0.3461130576399892, 0.9357072323605509], 
             UndirectedEdge[221, 268] -> 
             RGBColor[
              0.7908356351545234, 0.6993648502734382, 0.6044361277879526], 
             UndirectedEdge[265, 291] -> 
             RGBColor[
              0.18857894058274138`, 0.31553880152083974`, 0.9340506637374206],
              UndirectedEdge[128, 133] -> 
             RGBColor[
              0.19019948162046302`, 0.31724209289972144`, 0.9341429511521433],
              UndirectedEdge[57, 333] -> 
             RGBColor[
              0.2028967340448986, 0.3305877102501046, 0.9348660408938132], 
             UndirectedEdge[28, 378] -> 
             RGBColor[
              0.19890365407675165`, 0.32639073002768937`, 0.9346386408968597],
              UndirectedEdge[92, 386] -> 
             RGBColor[
              0.6290755332185833, 0.7079371215448762, 0.9651823556220622], 
             UndirectedEdge[35, 248] -> 
             RGBColor[
              0.22712519699410227`, 0.3560533609829937, 0.9362458160159715], 
             UndirectedEdge[56, 175] -> 
             RGBColor[
              0.331650883280764, 0.45917597392142306`, 0.9424452023325764], 
             UndirectedEdge[3, 21] -> 
             RGBColor[
              0.7725354937206939, 0.7794802979389553, 0.6358867741972027], 
             UndirectedEdge[98, 204] -> 
             RGBColor[
              0.19732498772567109`, 0.3247314515994759, 0.9345487381835933], 
             UndirectedEdge[243, 367] -> 
             RGBColor[
              0.6723041775720541, 0.7380461571244501, 0.9407946307732227], 
             UndirectedEdge[48, 209] -> 
             RGBColor[
              0.2875152720132881, 0.41711435878234465`, 0.9397732858765137], 
             UndirectedEdge[116, 291] -> 
             RGBColor[
              0.1852566513830322, 0.31204686492664385`, 0.9338614642823836], 
             UndirectedEdge[214, 340] -> 
             RGBColor[
              0.22133989504081186`, 0.3499726418207558, 0.9359163516283189], 
             UndirectedEdge[138, 159] -> 
             RGBColor[
              0.18138230828610377`, 0.30797468468423184`, 0.9336408261745905],
              UndirectedEdge[22, 48] -> 
             RGBColor[
              0.27823170323432733`, 0.40907339811174287`, 0.9391817450830557],
              UndirectedEdge[13, 297] -> 
             RGBColor[
              0.2105416090442786, 0.33862295858752356`, 0.9353014052154489], 
             UndirectedEdge[192, 347] -> 
             RGBColor[
              0.18973620095672017`, 0.3167551555484371, 0.9341165680037053], 
             UndirectedEdge[4, 322] -> 
             RGBColor[
              0.21636197354501668`, 0.3447405307102229, 0.9356328663633082], 
             UndirectedEdge[111, 304] -> 
             RGBColor[
              0.18507047905985996`, 0.31185118601098283`, 0.9338508620439963],
              UndirectedEdge[133, 361] -> 
             RGBColor[
              0.20171159208941025`, 0.3293420509125463, 0.9347985488127086], 
             UndirectedEdge[4, 186] -> 
             RGBColor[
              0.2198352252877424, 0.3483911385087073, 0.9358306629118409], 
             UndirectedEdge[73, 240] -> 
             RGBColor[
              0.8811521202900017, 0.5036002063401005, 0.22050415715161448`], 
             UndirectedEdge[82, 335] -> 
             RGBColor[
              0.18011477786530028`, 0.30664242984589696`, 0.933568642192269], 
             UndirectedEdge[184, 372] -> 
             RGBColor[
              0.18858940025952037`, 0.31554979530431626`, 0.9340512594005395],
              UndirectedEdge[85, 340] -> 
             RGBColor[
              0.22184000451345684`, 0.35049828858527765`, 0.9359448321229403],
              UndirectedEdge[344, 388] -> 
             RGBColor[
              0.20538183242077535`, 0.3331997062074885, 0.9350075635699459], 
             UndirectedEdge[57, 228] -> 
             RGBColor[
              0.21063806848440092`, 0.33872434357497383`, 0.9353068984378649],
              UndirectedEdge[36, 80] -> 
             RGBColor[
              0.1863429465695527, 0.31318863004276976`, 0.9339233271862263], 
             UndirectedEdge[88, 365] -> 
             RGBColor[
              0.18619994968916187`, 0.3130383312549531, 0.9339151837254329], 
             UndirectedEdge[209, 241] -> 
             RGBColor[
              0.2990278699570904, 0.4292148291621499, 0.9404289112980508], 
             UndirectedEdge[49, 62] -> 
             RGBColor[
              0.19439182652115503`, 0.3216485132003679, 0.9343816989922191], 
             UndirectedEdge[161, 250] -> 
             RGBColor[
              0.22890128499152032`, 0.3579201420787632, 0.9363469615999377], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.19292841019979173`, 0.32011036986066127`, 0.934298359597648], 
             UndirectedEdge[324, 346] -> 
             RGBColor[
              0.4920980261552287, 0.5957700021570038, 0.9539260250446029], 
             UndirectedEdge[142, 258] -> 
             RGBColor[
              0.18294835007904106`, 0.30962069390139346`, 0.9337300099379471],
              UndirectedEdge[44, 46] -> 
             RGBColor[
              0.2189840028439955, 0.34749644974970917`, 0.9357821870529404], 
             UndirectedEdge[85, 191] -> 
             RGBColor[
              0.22398452631281984`, 0.35275231696694354`, 0.9360669594668783],
              UndirectedEdge[112, 172] -> 
             RGBColor[
              0.880455548797022, 0.4861641510661218, 0.21934051163396778`], 
             UndirectedEdge[133, 298] -> 
             RGBColor[
              0.1913924314057353, 0.3184959587614276, 0.9342108878776034], 
             UndirectedEdge[26, 215] -> 
             RGBColor[
              0.18499791179933114`, 0.3117749132191369, 0.9338467294458628], 
             UndirectedEdge[127, 129] -> 
             RGBColor[
              0.19194623803100921`, 0.3190780446379586, 0.9342424263456293], 
             UndirectedEdge[172, 225] -> 
             RGBColor[
              0.8542567503473041, 0.5474377891348923, 0.5796464760848401], 
             UndirectedEdge[38, 376] -> 
             RGBColor[
              0.21626586560617583`, 0.3446395151729059, 0.9356273931583702], 
             UndirectedEdge[158, 346] -> 
             RGBColor[
              0.34491127963015633`, 0.47316654749583464`, 0.9431984196383325],
              UndirectedEdge[340, 370] -> 
             RGBColor[
              0.19501122587610803`, 0.3222995411946109, 0.9344169728691645], 
             UndirectedEdge[44, 266] -> 
             RGBColor[
              0.23471345152571355`, 0.36402909761884283`, 0.9366779558857301],
              UndirectedEdge[183, 238] -> 
             RGBColor[
              0.31998454354214334`, 0.4498414183193987, 0.9416736311656848], 
             UndirectedEdge[21, 264] -> 
             RGBColor[
              0.8432468849976082, 0.8356472056673055, 0.6423010818703361], 
             UndirectedEdge[13, 140] -> 
             RGBColor[
              0.2199309237526768, 0.34849172366298653`, 0.9358361127978458], 
             UndirectedEdge[210, 266] -> 
             RGBColor[
              0.26920304414348, 0.40027984622658896`, 0.9386420871625321], 
             UndirectedEdge[51, 395] -> 
             RGBColor[
              0.4251084428470847, 0.5422133005057554, 0.9484234537100807], 
             UndirectedEdge[358, 372] -> 
             RGBColor[
              0.19242209071206384`, 0.3195781959765495, 0.9342695254518545], 
             UndirectedEdge[174, 309] -> 
             RGBColor[
              0.32079650085916334`, 0.45124869478397367`, 0.9416995914849222],
              UndirectedEdge[65, 363] -> 
             RGBColor[
              0.25392355034044856`, 0.38422012946374207`, 0.9377719425944349],
              UndirectedEdge[236, 267] -> 
             RGBColor[
              0.25338105975763014`, 0.38364993746531034`, 0.9377410485582862],
              UndirectedEdge[227, 352] -> 
             RGBColor[
              0.22353600409255178`, 0.3522808916754905, 0.9360414167899633], 
             UndirectedEdge[2, 370] -> 
             RGBColor[
              0.18603673488354355`, 0.3128667821458319, 0.9339058888837076], 
             UndirectedEdge[17, 354] -> 
             RGBColor[
              0.2237645258481464, 0.35252108252973663`, 0.9360544307658767], 
             UndirectedEdge[133, 306] -> 
             RGBColor[
              0.1942497780329075, 0.32149921123282543`, 0.9343736095409554], 
             UndirectedEdge[105, 261] -> 
             RGBColor[
              0.23472290345765154`, 0.3640390321985968, 0.9366784941592712], 
             UndirectedEdge[120, 206] -> 
             RGBColor[
              0.624306194339526, 0.7045315727086937, 0.9644880050917888], 
             UndirectedEdge[361, 393] -> 
             RGBColor[
              0.20049962337211924`, 0.32806819494741857`, 0.934729528987206], 
             UndirectedEdge[270, 295] -> 
             RGBColor[
              0.3940670515595366, 0.5157428065001295, 0.9463305819589302], 
             UndirectedEdge[9, 283] -> 
             RGBColor[
              0.2000074908485974, 0.3275509324621929, 0.9347015027680361], 
             UndirectedEdge[43, 122] -> 
             RGBColor[
              0.42916131354223347`, 0.5377386121027248, 0.9498157239985662], 
             UndirectedEdge[127, 336] -> 
             RGBColor[
              0.18757872554421223`, 0.31448751209804937`, 0.933993702970662], 
             UndirectedEdge[4, 123] -> 
             RGBColor[
              0.2222583366495916, 0.3509379821841447, 0.9359686555192263], 
             UndirectedEdge[45, 279] -> 
             RGBColor[
              0.4785218001436983, 0.5802784243797845, 0.9537482634423509], 
             UndirectedEdge[135, 255] -> 
             RGBColor[
              0.9151018270707441, 0.6320925985012373, 0.4307426303242521], 
             UndirectedEdge[152, 180] -> 
             RGBColor[
              0.2576563148367751, 0.3881435016203197, 0.9379845180103705], 
             UndirectedEdge[48, 68] -> 
             RGBColor[
              0.2551071510734325, 0.38546416887872903`, 0.937839346905198], 
             UndirectedEdge[362, 363] -> 
             RGBColor[
              0.20453297478611288`, 0.3323075030127757, 0.9349592223834241], 
             UndirectedEdge[18, 257] -> 
             RGBColor[
              0.46412234198098856`, 0.5722988469015355, 0.9519334554771259], 
             UndirectedEdge[72, 109] -> 
             RGBColor[
              0.18206833162796426`, 0.3086957387129193, 0.933679894189029], 
             UndirectedEdge[181, 211] -> 
             RGBColor[
              0.20840661341018846`, 0.33637894280955327`, 0.9351798203725303],
              UndirectedEdge[82, 259] -> 
             RGBColor[
              0.1834817429881715, 0.31018132366795326`, 0.9337603858750381], 
             UndirectedEdge[282, 367] -> 
             RGBColor[
              0.3211123825917724, 0.44870662104929115`, 0.9418228148301714], 
             UndirectedEdge[44, 363] -> 
             RGBColor[
              0.22828771928123268`, 0.35727524561493795`, 0.9363120199404259],
              UndirectedEdge[139, 290] -> 
             RGBColor[
              0.19313846063632573`, 0.32033114618742536`, 0.9343103216592668],
              UndirectedEdge[255, 351] -> 
             RGBColor[
              0.8725754097367984, 0.601857083491112, 0.5863765700059249], 
             UndirectedEdge[290, 345] -> 
             RGBColor[
              0.18860221988526102`, 0.31556326954378094`, 0.9340519894592605],
              UndirectedEdge[145, 200] -> 
             RGBColor[
              0.19073593578989534`, 0.3178059402449537, 0.9341735014234795], 
             UndirectedEdge[44, 316] -> 
             RGBColor[
              0.23551418105696653`, 0.3648707151253743, 0.9367235562479619], 
             UndirectedEdge[172, 240] -> 
             RGBColor[
              0.8277460748309535, 0.21427406632403376`, 0.17420297863381767`],
              UndirectedEdge[89, 299] -> 
             RGBColor[
              0.18845360021131413`, 0.3154070608434312, 0.9340435257886923], 
             UndirectedEdge[119, 196] -> 
             RGBColor[
              0.18607572050979368`, 0.3129077585108523, 0.9339081090574485], 
             UndirectedEdge[149, 369] -> 
             RGBColor[
              0.20360056980323105`, 0.3313274862578765, 0.9349061232990186], 
             UndirectedEdge[32, 385] -> 
             RGBColor[
              0.9757287822359568, 0.928603231512897, 0.461093645269188], 
             UndirectedEdge[149, 253] -> 
             RGBColor[
              0.20384820267597584`, 0.3315877641079622, 0.9349202256247814], 
             UndirectedEdge[317, 336] -> 
             RGBColor[
              0.1878536669894908, 0.3147764929893316, 0.9340093604792311], 
             UndirectedEdge[138, 215] -> 
             RGBColor[
              0.18262441317102773`, 0.30928021567228525`, 0.9337115622102574],
              UndirectedEdge[157, 181] -> 
             RGBColor[
              0.19115892919796787`, 0.31825053313616897`, 0.9341975902723066],
              UndirectedEdge[299, 342] -> 
             RGBColor[
              0.18568831496489116`, 0.3125005707202294, 0.9338860468847814], 
             UndirectedEdge[108, 198] -> 
             RGBColor[
              0.3047308678845767, 0.4335017597846965, 0.9408162005428573], 
             UndirectedEdge[152, 367] -> 
             RGBColor[
              0.31592573046277495`, 0.4432551208089762, 0.9415274426643891], 
             UndirectedEdge[17, 118] -> 
             RGBColor[
              0.23527881827982655`, 0.36462333392373825`, 0.9367101526859918],
              UndirectedEdge[44, 68] -> 
             RGBColor[
              0.25335041241870687`, 0.38361772516894843`, 0.9377393032376733],
              UndirectedEdge[158, 323] -> 
             RGBColor[
              0.3687236016444134, 0.49379158398248, 0.9447157197406713], 
             UndirectedEdge[343, 359] -> 
             RGBColor[
              0.18461240578101906`, 0.3113697219513976, 0.933824775448425], 
             UndirectedEdge[354, 388] -> 
             RGBColor[
              0.21768345542489445`, 0.346129491952765, 0.93570812280141], 
             UndirectedEdge[382, 389] -> 
             RGBColor[
              0.1922700735577051, 0.31941841630887424`, 0.9342608682998029], 
             UndirectedEdge[178, 319] -> 
             RGBColor[
              0.4475260102308348, 0.5620450810151163, 0.9497372679364278], 
             UndirectedEdge[15, 386] -> 
             RGBColor[
              0.5232931103169385, 0.6153912271159707, 0.9581889419192983], 
             UndirectedEdge[27, 104] -> 
             RGBColor[
              0.8200236798530103, 0.15491635454850536`, 0.16680800448174155`],
              UndirectedEdge[236, 398] -> 
             RGBColor[
              0.3384347985138768, 0.4621971627307483, 0.9429819918755249], 
             UndirectedEdge[151, 304] -> 
             RGBColor[
              0.1864549217267703, 0.3133063230326405, 0.9339297040057775], 
             UndirectedEdge[21, 233] -> 
             RGBColor[
              0.9613042288478943, 0.9283900515581442, 0.6325730929841542], 
             UndirectedEdge[120, 321] -> 
             RGBColor[
              0.5363303582199404, 0.6344561720670685, 0.9566410369233613], 
             UndirectedEdge[170, 299] -> 
             RGBColor[
              0.20966330069407968`, 0.3376998008234987, 0.9352513868542458], 
             UndirectedEdge[97, 109] -> 
             RGBColor[
              0.18710606140703578`, 0.3139907121212397, 0.9339667854472937], 
             UndirectedEdge[251, 381] -> 
             RGBColor[
              0.19321867549075944`, 0.3204154570853507, 0.9343148897765596], 
             UndirectedEdge[134, 392] -> 
             RGBColor[
              0.9110260493239869, 0.9293182372189884, 0.8905829197640283], 
             UndirectedEdge[132, 220] -> 
             RGBColor[
              0.4970479670019815, 0.5999842739295098, 0.9542616336741748], 
             UndirectedEdge[102, 167] -> 
             RGBColor[
              0.29386288759542795`, 0.42605944514024496`, 0.9400515350827954],
              UndirectedEdge[270, 373] -> 
             RGBColor[
              0.31547519929516016`, 0.44425931355976, 0.9414476786623798], 
             UndirectedEdge[122, 351] -> 
             RGBColor[
              0.7538761223524553, 0.8076987945105711, 0.9763753458222324], 
             UndirectedEdge[96, 173] -> 
             RGBColor[
              0.515339475447038, 0.6087263479834802, 0.9574676673643785], 
             UndirectedEdge[253, 266] -> 
             RGBColor[
              0.21192263839001468`, 0.3400745079922101, 0.9353800527936387], 
             UndirectedEdge[217, 230] -> 
             RGBColor[
              0.9054039524770299, 0.5624674632894656, 0.3258325895022128], 
             UndirectedEdge[118, 158] -> 
             RGBColor[
              0.28881871360859035`, 0.41812251622929797`, 0.9398607637666927],
              UndirectedEdge[208, 230] -> 
             RGBColor[
              0.9053767960647079, 0.5643648513182951, 0.465019014701602], 
             UndirectedEdge[86, 179] -> 
             RGBColor[
              0.4324853651691194, 0.5490017107824403, 0.9487832899231066], 
             UndirectedEdge[185, 284] -> 
             RGBColor[
              0.33809952087216233`, 0.4642943071241772, 0.9428732085612545], 
             UndirectedEdge[279, 399] -> 
             RGBColor[
              0.7994051322415094, 0.7452396599077329, 0.6138726305595152], 
             UndirectedEdge[167, 309] -> 
             RGBColor[
              0.30392546223642514`, 0.4366358490920146, 0.940624583822355], 
             UndirectedEdge[174, 183] -> 
             RGBColor[
              0.34699168167192995`, 0.474968487180372, 0.943330981016807], 
             UndirectedEdge[149, 247] -> 
             RGBColor[
              0.20711572977977888`, 0.33502214226724336`, 0.9351063064594698],
              UndirectedEdge[297, 339] -> 
             RGBColor[
              0.22923415063680755`, 0.358270004976861, 0.9363659178060062], 
             UndirectedEdge[28, 282] -> 
             RGBColor[
              0.2370656602671769, 0.3665014181447689, 0.9368119106937756], 
             UndirectedEdge[35, 125] -> 
             RGBColor[
              0.24888171485109623`, 0.37892084069359944`, 0.9374848175220434],
              UndirectedEdge[119, 231] -> 
             RGBColor[
              0.18230446054106692`, 0.30894392517202796`, 0.9336933413813087],
              UndirectedEdge[257, 309] -> 
             RGBColor[
              0.31035046981038367`, 0.4422008677223072, 0.9410339796235565], 
             UndirectedEdge[153, 161] -> 
             RGBColor[
              0.1909498488692258, 0.3180307764542026, 0.9341856834568915], 
             UndirectedEdge[315, 369] -> 
             RGBColor[
              0.20472182801530026`, 0.332505999730638, 0.934969977295443], 
             UndirectedEdge[145, 207] -> 
             RGBColor[
              0.19250737674757545`, 0.31966783700731927`, 0.9342743823654074],
              UndirectedEdge[75, 215] -> 
             RGBColor[
              0.20048155521420025`, 0.3280492041678583, 0.9347285000323418], 
             UndirectedEdge[155, 199] -> 
             RGBColor[
              0.1967855567491959, 0.3241644754413012, 0.9345180183874995], 
             UndirectedEdge[28, 151] -> 
             RGBColor[
              0.19950401467485102`, 0.3270217470813523, 0.9346728305447676], 
             UndirectedEdge[141, 279] -> 
             RGBColor[
              0.7689158684311985, 0.6132326776654563, 0.588764654117898], 
             UndirectedEdge[347, 380] -> 
             RGBColor[
              0.20898774598358635`, 0.3369897499901277, 0.9352129150128767], 
             UndirectedEdge[107, 346] -> 
             RGBColor[
              0.3498425512041035, 0.47743776708027175`, 0.9435126359024721], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.684630729662244, 0.7517566465973935, 0.970608286963019], 
             UndirectedEdge[171, 299] -> 
             RGBColor[
              0.18831247292825637`, 0.31525872712095093`, 0.9340354887987012],
              UndirectedEdge[283, 294] -> 
             RGBColor[
              0.19947004944091673`, 0.32698604746696713`, 0.934670896274942], 
             UndirectedEdge[83, 244] -> 
             RGBColor[
              0.9498999569574745, 0.9621560504469515, 0.9696904840737579], 
             UndirectedEdge[112, 179] -> 
             RGBColor[
              0.6955279730573865, 0.6779676106196408, 0.6092046613657698], 
             UndirectedEdge[42, 93] -> 
             RGBColor[
              0.22541709987581074`, 0.35425804261205696`, 0.936148542411988], 
             UndirectedEdge[94, 254] -> 
             RGBColor[
              0.18421702339867016`, 0.31095414999885795`, 0.9338022590066659],
              UndirectedEdge[84, 222] -> 
             RGBColor[
              0.2856119220562171, 0.4147444227440439, 0.9396784182563604], 
             UndirectedEdge[132, 366] -> 
             RGBColor[
              0.3763364091715497, 0.5003854152316536, 0.9452008011045592], 
             UndirectedEdge[52, 133] -> 
             RGBColor[
              0.18257629412906723`, 0.3092296395082612, 0.9337088219020035], 
             UndirectedEdge[255, 400] -> 
             RGBColor[
              0.8427699382288443, 0.329754063899142, 0.18858984719066463`], 
             UndirectedEdge[276, 318] -> 
             RGBColor[
              0.20862378443178675`, 0.3366072033226911, 0.9351921879409346], 
             UndirectedEdge[235, 313] -> 
             RGBColor[
              0.2049405983747336, 0.3327359412492443, 0.9349824359437711], 
             UndirectedEdge[218, 229] -> 
             RGBColor[
              0.19887179747769093`, 0.3263572467222515, 0.9346368267106708], 
             UndirectedEdge[202, 260] -> 
             RGBColor[
              0.23397057730885262`, 0.3632482897159762, 0.9366356502980638], 
             UndirectedEdge[129, 216] -> 
             RGBColor[
              0.1943994825815768, 0.32165656020529343`, 0.9343821349935341], 
             UndirectedEdge[307, 312] -> 
             RGBColor[
              0.32563175741045036`, 0.45592792457411196`, 0.9419897054854269],
              UndirectedEdge[215, 349] -> 
             RGBColor[
              0.192491042377818, 0.3196506685490453, 0.9342734521472142], 
             UndirectedEdge[48, 61] -> 
             RGBColor[
              0.22477630942984533`, 0.3535845312248864, 0.9361120503440548], 
             UndirectedEdge[198, 284] -> 
             RGBColor[
              0.31495346164278715`, 0.44424635397445533`, 0.9413983621344152],
              UndirectedEdge[37, 256] -> 
             RGBColor[
              0.3500537032004466, 0.4776206563266962, 0.9435260903209648], 
             UndirectedEdge[260, 366] -> 
             RGBColor[
              0.3094906009088253, 0.4347053804692331, 0.9412263661740565], 
             UndirectedEdge[35, 263] -> 
             RGBColor[
              0.31410208852609794`, 0.43977856599147, 0.9414807005621779], 
             UndirectedEdge[124, 185] -> 
             RGBColor[
              0.35466498690371884`, 0.48161471850061266`, 0.9438199172409392],
              UndirectedEdge[17, 48] -> 
             RGBColor[
              0.23593219427525336`, 0.3653100735213626, 0.936747361482348], 
             UndirectedEdge[98, 139] -> 
             RGBColor[
              0.19453754132088114`, 0.32180166869373195`, 0.9343899972344978],
              UndirectedEdge[98, 125] -> 
             RGBColor[
              0.23126364989762477`, 0.3604031373776651, 0.9364814947865346], 
             UndirectedEdge[195, 397] -> 
             RGBColor[
              0.2073858256728759, 0.33530603017595706`, 0.9351216880210106], 
             UndirectedEdge[152, 198] -> 
             RGBColor[
              0.3050387614583694, 0.43382537545233274`, 0.9408337346263971], 
             UndirectedEdge[29, 129] -> 
             RGBColor[
              0.18526332309430954`, 0.3120538773182072, 0.933861844226471], 
             UndirectedEdge[83, 230] -> 
             RGBColor[
              0.8813864038440016, 0.5479387227052518, 0.5712729934209153], 
             UndirectedEdge[10, 155] -> 
             RGBColor[
              0.22229114501906733`, 0.3509724658606344, 0.9359705239073323], 
             UndirectedEdge[210, 316] -> 
             RGBColor[
              0.270003773674733, 0.40112146373312046`, 0.9386876875247638], 
             UndirectedEdge[6, 175] -> 
             RGBColor[
              0.2936199376985361, 0.4259435494734196, 0.9400325931289355], 
             UndirectedEdge[301, 343] -> 
             RGBColor[
              0.18235879982602854`, 0.30900103920583233`, 0.9336964359231994],
              UndirectedEdge[140, 297] -> 
             RGBColor[
              0.21630983883703356`, 0.3446857338266013, 0.935629897368815], 
             UndirectedEdge[274, 295] -> 
             RGBColor[
              0.4610566723545275, 0.5726862586021548, 0.9508973954130453], 
             UndirectedEdge[61, 371] -> 
             RGBColor[
              0.19795607517941943`, 0.3253947645266211, 0.934584677680474], 
             UndirectedEdge[266, 397] -> 
             RGBColor[
              0.22283784734549728`, 0.3515470846686418, 0.9360016577960488], 
             UndirectedEdge[71, 88] -> 
             RGBColor[
              0.1851982028892632, 0.3119854318538441, 0.9338581357271303], 
             UndirectedEdge[156, 255] -> 
             RGBColor[
              0.833173631408902, 0.25599264455260395`, 0.17940041294240955`], 
             UndirectedEdge[22, 388] -> 
             RGBColor[
              0.26789478594512556`, 0.39820864264238165`, 0.9385930729355345],
              UndirectedEdge[17, 346] -> 
             RGBColor[
              0.29137138430139253`, 0.41966736519027487`, 0.9400478085576316],
              UndirectedEdge[72, 365] -> 
             RGBColor[
              0.18187230727944725`, 0.30848970469396636`, 0.9336687308923729],
              UndirectedEdge[194, 230] -> 
             RGBColor[
              0.906134992146644, 0.5640310832233217, 0.4054017460858296], 
             UndirectedEdge[95, 264] -> 
             RGBColor[
              0.6413507907064967, 0.7184767050540989, 0.9657562779986768], 
             UndirectedEdge[131, 325] -> 
             RGBColor[
              0.2511977848308302, 0.381355177089618, 0.9376167142810707], 
             UndirectedEdge[369, 372] -> 
             RGBColor[
              0.19233300953943172`, 0.31948456601604064`, 0.9342644524108568],
              UndirectedEdge[11, 248] -> 
             RGBColor[
              0.2649817698706437, 0.3955454303669761, 0.9384125880269136], 
             UndirectedEdge[32, 223] -> 
             RGBColor[
              0.9434671979288998, 0.8132571155526379, 0.27501732397559764`], 
             UndirectedEdge[75, 229] -> 
             RGBColor[
              0.21242485108253378`, 0.34060236537417143`, 0.9354086530635206],
              UndirectedEdge[123, 131] -> 
             RGBColor[
              0.21247713876151392`, 0.34065732304000995`, 0.9354116307694857],
              UndirectedEdge[35, 340] -> 
             RGBColor[
              0.21959313401090685`, 0.34813668522727964`, 0.9358168761717671],
              UndirectedEdge[316, 369] -> 
             RGBColor[
              0.2124757350485229, 0.34065584764865586`, 0.9354115508301075], 
             UndirectedEdge[232, 280] -> 
             RGBColor[
              0.2733144461810522, 0.4046011904460226, 0.9388762254262976], 
             UndirectedEdge[30, 318] -> 
             RGBColor[
              0.18730055861877407`, 0.31419514102261215`, 0.9339778617757692],
              UndirectedEdge[219, 338] -> 
             RGBColor[
              0.28566284547896603`, 0.414956272719873, 0.9396755211710989], 
             UndirectedEdge[124, 397] -> 
             RGBColor[
              0.26132649500551464`, 0.3919101499465881, 0.9381968592370336], 
             UndirectedEdge[131, 280] -> 
             RGBColor[
              0.23239625445736245`, 0.36159357658122604`, 0.9365459949406734],
              UndirectedEdge[224, 345] -> 
             RGBColor[
              0.17916076969846856`, 0.3056397067749454, 0.9335143128384965], 
             UndirectedEdge[44, 195] -> 
             RGBColor[
              0.2192614298530921, 0.3477880431261581, 0.9357979861106919], 
             UndirectedEdge[57, 102] -> 
             RGBColor[
              0.24757611002741542`, 0.37754856724378383`, 0.937410465258804], 
             UndirectedEdge[102, 222] -> 
             RGBColor[
              0.2549287084068188, 0.3852766143221994, 0.9378291848593165], 
             UndirectedEdge[86, 285] -> 
             RGBColor[
              0.7026108469912147, 0.7602147765402214, 0.7786951433273641], 
             UndirectedEdge[97, 340] -> 
             RGBColor[
              0.1979121571634553, 0.3253486039072797, 0.9345821766144358], 
             UndirectedEdge[84, 183] -> 
             RGBColor[
              0.3444123638438444, 0.47273441171796776`, 0.9431666291656026], 
             UndirectedEdge[23, 132] -> 
             RGBColor[
              0.32566481114992, 0.45504559524241234`, 0.9420251663053016], 
             UndirectedEdge[124, 210] -> 
             RGBColor[
              0.30769169180349737`, 0.4406429115045353, 0.9408372886035168], 
             UndirectedEdge[257, 288] -> 
             RGBColor[
              0.3142377899115303, 0.4462866876189422, 0.9412553567525421], 
             UndirectedEdge[31, 287] -> 
             RGBColor[
              0.19320443776430601`, 0.3204004923321242, 0.9343140789591009], 
             UndirectedEdge[163, 222] -> 
             RGBColor[
              0.24959037113759353`, 0.3796656833821117, 0.9375251744491964], 
             UndirectedEdge[206, 386] -> 
             RGBColor[
              0.7455369138645886, 0.8011383704922057, 0.975271810201597], 
             UndirectedEdge[95, 263] -> 
             RGBColor[
              0.47568127911611685`, 0.5835523041211401, 0.9523268989560933], 
             UndirectedEdge[103, 333] -> 
             RGBColor[
              0.19123001846776383`, 0.3183252524660446, 0.9342016387010543], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.19722342502912832`, 0.3246247027659626, 0.9345429543382737], 
             UndirectedEdge[57, 174] -> 
             RGBColor[
              0.28083864150489934`, 0.40925045112803254`, 0.9394240505070525],
              UndirectedEdge[32, 208] -> 
             RGBColor[0.97502376088894, 0.929050734989072, 0.526498655624491],
              UndirectedEdge[11, 125] -> 
             RGBColor[
              0.2867382877276377, 0.41841291007758175`, 0.9396515895329856], 
             UndirectedEdge[82, 136] -> 
             RGBColor[
              0.18265801399513343`, 0.30931553226883557`, 0.9337134757274823],
              UndirectedEdge[129, 298] -> 
             RGBColor[
              0.19304299486108434`, 0.3202308056047669, 0.9343048850245959], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.24346570234943876`, 0.37322826815933124`, 0.9371763836223466],
              UndirectedEdge[155, 306] -> 
             RGBColor[
              0.20489683816901277`, 0.33268994649847444`, 0.9349799438647926],
              UndirectedEdge[247, 358] -> 
             RGBColor[
              0.19420191296404457`, 0.3214489020106298, 0.9343708836960937], 
             UndirectedEdge[5, 373] -> 
             RGBColor[
              0.27714534160664284`, 0.4086277044311172, 0.939094389253483], 
             UndirectedEdge[194, 201] -> 
             RGBColor[
              0.9717877162352071, 0.9761148093624215, 0.8086618740541351], 
             UndirectedEdge[7, 173] -> 
             RGBColor[
              0.36556257674898185`, 0.48862517592323496`, 0.9446032208411446],
              UndirectedEdge[25, 364] -> 
             RGBColor[
              0.81749806012385, 0.1355033345765571, 0.16438946817681815`], 
             UndirectedEdge[1, 313] -> 
             RGBColor[
              0.20595700131663575`, 0.3338042451848521, 0.935040318587679], 
             UndirectedEdge[189, 222] -> 
             RGBColor[
              0.24951462814212214`, 0.379586072691488, 0.937520860997656], 
             UndirectedEdge[232, 275] -> 
             RGBColor[
              0.2669215798519661, 0.39788188260301705`, 0.9385121611462544], 
             UndirectedEdge[289, 376] -> 
             RGBColor[
              0.19788479388924796`, 0.32531984337115605`, 0.93458061831645], 
             UndirectedEdge[194, 208] -> 
             RGBColor[
              0.9937734715667986, 0.9910458830658546, 0.7058012226950569], 
             UndirectedEdge[320, 384] -> 
             RGBColor[
              0.1926752609493727, 0.31984429394788133`, 0.9342839431223373], 
             UndirectedEdge[262, 332] -> 
             RGBColor[
              0.22124807994982085`, 0.34987613833871123`, 0.9359111228947152],
              UndirectedEdge[39, 237] -> 
             RGBColor[
              0.19025421078354665`, 0.3172996167201517, 0.9341460678970164], 
             UndirectedEdge[105, 353] -> 
             RGBColor[
              0.19974831949640176`, 0.32727852693862247`, 0.9346867433429382],
              UndirectedEdge[160, 321] -> 
             RGBColor[
              0.5069925116479708, 0.6106383865650169, 0.9543314541731429], 
             UndirectedEdge[22, 354] -> 
             RGBColor[
              0.2660640348072204, 0.3962844071201169, 0.9384888143665844], 
             UndirectedEdge[70, 286] -> 
             RGBColor[
              0.20888058953085603`, 0.33687712176419665`, 0.9352068126114177],
              UndirectedEdge[97, 334] -> 
             RGBColor[
              0.1889352663956901, 0.3159133225426103, 0.9340709559653313], 
             UndirectedEdge[301, 362] -> 
             RGBColor[
              0.18593089634401205`, 0.31275553913023335`, 0.9338998615354555],
              UndirectedEdge[166, 300] -> 
             RGBColor[
              0.9521971792667703, 0.9624135645920178, 0.9060859398221737], 
             UndirectedEdge[357, 364] -> 
             RGBColor[
              0.8373888047327049, 0.2883923138200816, 0.1834368676776406], 
             UndirectedEdge[13, 66] -> 
             RGBColor[
              0.21421674509456057`, 0.34248575959345395`, 0.9355106987766358],
              UndirectedEdge[102, 395] -> 
             RGBColor[
              0.3730551581743753, 0.49423581065451916`, 0.9452125382842432], 
             UndirectedEdge[129, 336] -> 
             RGBColor[
              0.184720804255658, 0.3114836556211034, 0.9338309485811944], 
             UndirectedEdge[257, 275] -> 
             RGBColor[
              0.2809273627700829, 0.4112753166902168, 0.9393583772051975], 
             UndirectedEdge[358, 369] -> 
             RGBColor[
              0.19068675298749674`, 0.31775424600126295`, 0.9341707005356424],
              UndirectedEdge[42, 139] -> 
             RGBColor[
              0.20228682166276132`, 0.3299466536657998, 0.934831307285935], 
             UndirectedEdge[37, 206] -> 
             RGBColor[
              0.5395559184345032, 0.6328895346269106, 0.9586002858977685], 
             UndirectedEdge[3, 162] -> 
             RGBColor[
              0.42709887646193556`, 0.5374958425847769, 0.9495230473669047], 
             UndirectedEdge[44, 161] -> 
             RGBColor[
              0.2180648213930185, 0.34653033176526227`, 0.9357298410291143], 
             UndirectedEdge[67, 266] -> 
             RGBColor[
              0.3289874356394012, 0.4523479810161943, 0.9424410275338806], 
             UndirectedEdge[305, 360] -> 
             RGBColor[
              0.18374121717091801`, 0.3104540474856332, 0.9337751625458877], 
             UndirectedEdge[51, 174] -> 
             RGBColor[
              0.3627872108908755, 0.4886497806834403, 0.9443374581712001], 
             UndirectedEdge[132, 321] -> 
             RGBColor[
              0.4563174789356197, 0.5669174288296601, 0.9510551804528969], 
             UndirectedEdge[198, 236] -> 
             RGBColor[
              0.3020417872484481, 0.43067536553856556`, 0.9406630613787681], 
             UndirectedEdge[153, 356] -> 
             RGBColor[
              0.18871819494406902`, 0.31568516668383156`, 0.9340585940672899],
              UndirectedEdge[78, 217] -> 
             RGBColor[
              0.9065035834313075, 0.5709197086654001, 0.3268855973458845], 
             UndirectedEdge[16, 324] -> 
             RGBColor[
              0.47545256857995977`, 0.5813525434303296, 0.9528653912069069], 
             UndirectedEdge[263, 312] -> 
             RGBColor[
              0.3474308254202023, 0.4748091816311434, 0.9433787228228494], 
             UndirectedEdge[49, 231] -> 
             RGBColor[
              0.1849354051777754, 0.31170921479673314`, 0.9338431697862355], 
             UndirectedEdge[58, 303] -> 
             RGBColor[
              0.21259709598969448`, 0.3407834056925553, 0.9354184621561699], 
             UndirectedEdge[287, 371] -> 
             RGBColor[
              0.18823999048710255`, 0.315182543479646, 0.9340313610309057], 
             UndirectedEdge[108, 332] -> 
             RGBColor[
              0.24224909685408347`, 0.3719495386464692, 0.9371070997391926], 
             UndirectedEdge[55, 135] -> 
             RGBColor[
              0.9832367917164733, 0.9536721882994657, 0.5121416630539384], 
             UndirectedEdge[38, 145] -> 
             RGBColor[
              0.21009367554414693`, 0.338152152078261, 0.9352758960652745], 
             UndirectedEdge[41, 400] -> 
             RGBColor[
              0.861024743522975, 0.6436848292044157, 0.5916626524195524], 
             UndirectedEdge[184, 369] -> 
             RGBColor[
              0.1868540625349533, 0.3137258453290297, 0.9339524344843275], 
             UndirectedEdge[68, 363] -> 
             RGBColor[
              0.24496356786818765`, 0.3748026197896954, 0.9372616848477457], 
             UndirectedEdge[239, 350] -> 
             RGBColor[
              0.9108066927653387, 0.6030642712488816, 0.46289813781652445`], 
             UndirectedEdge[197, 300] -> 
             RGBColor[
              0.9395054889132312, 0.9538623530451078, 0.9685107634864926], 
             UndirectedEdge[34, 340] -> 
             RGBColor[
              0.23309142699709673`, 0.3623242469969716, 0.9365855839883956], 
             UndirectedEdge[99, 225] -> 
             RGBColor[
              0.9251735948093716, 0.9424003112075763, 0.9659587843040318], 
             UndirectedEdge[75, 218] -> 
             RGBColor[
              0.20441362479812614`, 0.3321820586081753, 0.9349524255781707], 
             UndirectedEdge[33, 256] -> 
             RGBColor[
              0.3139252578534664, 0.443350508209742, 0.9413330387606047], 
             UndirectedEdge[68, 173] -> 
             RGBColor[
              0.2762530439300684, 0.40768984299809713`, 0.9390435742208383], 
             UndirectedEdge[76, 368] -> 
             RGBColor[
              0.18953430680604916`, 0.3165429519952533, 0.9341050704305003], 
             UndirectedEdge[343, 369] -> 
             RGBColor[
              0.18630927681020493`, 0.31315324099090924`, 0.9339214097432413],
              UndirectedEdge[172, 243] -> 
             RGBColor[
              0.8966647112599999, 0.5803804357819402, 0.5534478412456459], 
             UndirectedEdge[25, 83] -> 
             RGBColor[
              0.881176745521725, 0.5463271969673706, 0.5710722243747279], 
             UndirectedEdge[176, 372] -> 
             RGBColor[
              0.2138686325253813, 0.34211987121163484`, 0.9354908742808075], 
             UndirectedEdge[211, 214] -> 
             RGBColor[
              0.23081730246588306`, 0.35993399792684283`, 0.9364560759606089],
              UndirectedEdge[273, 330] -> 
             RGBColor[
              0.18387764331179846`, 0.31059744000961553`, 0.9337829318127865],
              UndirectedEdge[247, 266] -> 
             RGBColor[
              0.21519016549381775`, 0.3435088861514912, 0.9355661336283271], 
             UndirectedEdge[294, 347] -> 
             RGBColor[
              0.19390550774844745`, 0.3211373613358611, 0.9343540038575576], 
             UndirectedEdge[247, 343] -> 
             RGBColor[
              0.18982443678675276`, 0.31684789700027605`, 0.9341215929036926],
              UndirectedEdge[147, 354] -> 
             RGBColor[
              0.1996644579713909, 0.3271903831587082, 0.9346819675531508], 
             UndirectedEdge[83, 206] -> 
             RGBColor[
              0.8376738526720509, 0.8738864473115988, 0.9758404514260404], 
             UndirectedEdge[178, 300] -> 
             RGBColor[
              0.6781948564694122, 0.7459060831571422, 0.9705455677828076], 
             UndirectedEdge[31, 384] -> 
             RGBColor[
              0.19301716646589862`, 0.32020365832381187`, 0.9343034141356996],
              UndirectedEdge[325, 339] -> 
             RGBColor[
              0.2703434502460814, 0.40147848534634617`, 0.9387070316029955], 
             UndirectedEdge[43, 237] -> 
             RGBColor[
              0.22884629711642387`, 0.3578623463356042, 0.9363438301217982], 
             UndirectedEdge[114, 128] -> 
             RGBColor[
              0.21795119041436695`, 0.34641089840207934`, 0.9357233699129821],
              UndirectedEdge[131, 188] -> 
             RGBColor[
              0.20752052535930418`, 0.3354476080868466, 0.9351293589688823], 
             UndirectedEdge[8, 352] -> 
             RGBColor[
              0.23870734178156489`, 0.36822692950501057`, 0.9369054020273697],
              UndirectedEdge[56, 137] -> 
             RGBColor[
              0.35805694536026106`, 0.48455266243088047`, 0.9440360498343989],
              UndirectedEdge[11, 93] -> 
             RGBColor[
              0.2731424573639435, 0.4041228303399058, 0.9388773271070019], 
             UndirectedEdge[232, 325] -> 
             RGBColor[
              0.29211597655452004`, 0.4243627909544146, 0.9399469447666949], 
             UndirectedEdge[293, 387] -> 
             RGBColor[
              0.4415101712045343, 0.5546415244104943, 0.9499598596294503], 
             UndirectedEdge[100, 175] -> 
             RGBColor[
              0.2458994336441635, 0.3757862740575634, 0.9373149810191983], 
             UndirectedEdge[327, 336] -> 
             RGBColor[
              0.18798018955468324`, 0.3149094762273428, 0.9340165657521455], 
             UndirectedEdge[230, 357] -> 
             RGBColor[
              0.8374194029311317, 0.28862750498140566`, 0.18346616854700978`],
              UndirectedEdge[151, 291] -> 
             RGBColor[
              0.1895972333261113, 0.3166090917576105, 0.9341086540027264], 
             UndirectedEdge[10, 87] -> 
             RGBColor[
              0.2178399723924833, 0.34629400120944975`, 0.9357170362111682], 
             UndirectedEdge[44, 247] -> 
             RGBColor[
              0.2171512777998561, 0.34557013952683935`, 0.9356778160729503], 
             UndirectedEdge[191, 334] -> 
             RGBColor[
              0.1961023648412683, 0.3234463974292005, 0.934479111619035], 
             UndirectedEdge[31, 389] -> 
             RGBColor[
              0.19956255990653143`, 0.3270832818318305, 0.9346761646091019], 
             UndirectedEdge[323, 346] -> 
             RGBColor[
              0.37487874320773873`, 0.4991228582382221, 0.9451079199183084], 
             UndirectedEdge[91, 257] -> 
             RGBColor[
              0.408201112318213, 0.5268994734386068, 0.9475311314318583], 
             UndirectedEdge[25, 217] -> 
             RGBColor[
              0.9051942941547533, 0.5608559375515845, 0.32563182045602546`], 
             UndirectedEdge[4, 238] -> 
             RGBColor[
              0.26140051176335477`, 0.3920788899859515, 0.9381977444862962], 
             UndirectedEdge[49, 298] -> 
             RGBColor[
              0.19233776426424887`, 0.31948956353329044`, 0.9342647231854012],
              UndirectedEdge[96, 245] -> 
             RGBColor[
              0.7835145897788575, 0.47447987208772324`, 0.5706010714513564], 
             UndirectedEdge[198, 219] -> 
             RGBColor[
              0.34521680439082036`, 0.47343117768740084`, 0.9432178874059169],
              UndirectedEdge[69, 106] -> 
             RGBColor[
              0.23431749208343802`, 0.36361291913973265`, 0.936655406581262], 
             UndirectedEdge[246, 350] -> 
             RGBColor[
              0.9570479117499637, 0.9654838538059254, 0.8719160935305621], 
             UndirectedEdge[91, 263] -> 
             RGBColor[
              0.44262523593919395`, 0.5567159191123393, 0.94972460614893], 
             UndirectedEdge[193, 305] -> 
             RGBColor[
              0.18458905889423072`, 0.311345182893105, 0.933823445877761], 
             UndirectedEdge[217, 244] -> 
             RGBColor[
              0.9739175055905028, 0.9766847910311653, 0.7242500801550553], 
             UndirectedEdge[218, 260] -> 
             RGBColor[
              0.20772118523879674`, 0.3356585143427644, 0.9351407862521698], 
             UndirectedEdge[115, 169] -> 
             RGBColor[
              0.8801983721871041, 0.6989200901607082, 0.599330145570115], 
             UndirectedEdge[152, 332] -> 
             RGBColor[
              0.24255699042787615`, 0.37227315431410535`, 0.9371246338227324],
              UndirectedEdge[8, 227] -> 
             RGBColor[
              0.22264092645081146`, 0.35134010832282114`, 0.9359904434424149],
              UndirectedEdge[161, 344] -> 
             RGBColor[
              0.1953522686165181, 0.3226579987381405, 0.9344363947487033], 
             UndirectedEdge[255, 324] -> 
             RGBColor[
              0.7342455134222807, 0.4929254711764368, 0.5728784243989717], 
             UndirectedEdge[135, 221] -> 
             RGBColor[
              0.9485753172801801, 0.8203317071995411, 0.46009294767531356`], 
             UndirectedEdge[179, 257] -> 
             RGBColor[
              0.38852623515624984`, 0.5109265218154098, 0.9459822530302189], 
             UndirectedEdge[40, 350] -> 
             RGBColor[
              0.7574551958384235, 0.806891984810095, 0.8535080309341501], 
             UndirectedEdge[358, 397] -> 
             RGBColor[
              0.20184959481572412`, 0.3294871005277804, 0.9348064078638154], 
             UndirectedEdge[44, 149] -> 
             RGBColor[
              0.22663901581167467`, 0.355542353734595, 0.9362181287168728], 
             UndirectedEdge[215, 218] -> 
             RGBColor[
              0.18692850160935742`, 0.31380408551593836`, 0.9339566736794921],
              UndirectedEdge[211, 248] -> 
             RGBColor[
              0.2199442042179371, 0.34850568227400514`, 0.9358368691006957], 
             UndirectedEdge[38, 103] -> 
             RGBColor[
              0.20863860950919683`, 0.3366227854190133, 0.9351930322071614], 
             UndirectedEdge[79, 213] -> 
             RGBColor[
              0.22683120635617676`, 0.355744358182451, 0.9362290736840618], 
             UndirectedEdge[116, 383] -> 
             RGBColor[
              0.19584602024074033`, 0.3231769630008592, 0.9344645131732627], 
             UndirectedEdge[214, 263] -> 
             RGBColor[
              0.315848849556003, 0.4416145225849462, 0.9415801760187297], 
             UndirectedEdge[203, 275] -> 
             RGBColor[
              0.232253685994867, 0.3614437280877808, 0.9365378758776455], 
             UndirectedEdge[235, 396] -> 
             RGBColor[
              0.19553592187284338`, 0.32285102995482734`, 0.9344468535299604],
              UndirectedEdge[170, 361] -> 
             RGBColor[
              0.22465020382752957`, 0.3534519862412956, 0.9361048688165594], 
             UndirectedEdge[190, 255] -> 
             RGBColor[
              0.8957903553105804, 0.6198388885195696, 0.570244438982581], 
             UndirectedEdge[67, 113] -> 
             RGBColor[
              0.36637406988619037`, 0.4916437040590915, 0.9445701410456664], 
             UndirectedEdge[244, 307] -> 
             RGBColor[
              0.651559964846024, 0.7209668023928419, 0.952436169214119], 
             UndirectedEdge[106, 292] -> 
             RGBColor[
              0.21060209943900177`, 0.3386865378276902, 0.9353048500539408], 
             UndirectedEdge[119, 126] -> 
             RGBColor[
              0.1845010944888899, 0.3112527267258263, 0.9338184364350084], 
             UndirectedEdge[148, 288] -> 
             RGBColor[
              0.3196747008606359, 0.4509958666159675, 0.9416017919105475], 
             UndirectedEdge[143, 277] -> 
             RGBColor[
              0.196429195674298, 0.32378991735698637`, 0.9344977241514731], 
             UndirectedEdge[245, 364] -> 
             RGBColor[
              0.8182535878829069, 0.14131065200704435`, 0.16511296241213771`],
              UndirectedEdge[101, 335] -> 
             RGBColor[
              0.18130162624818058`, 0.3078898827468379, 0.9336362314518891], 
             UndirectedEdge[175, 296] -> 
             RGBColor[
              0.26330595896968834`, 0.39408163581213873`, 0.9383062568858402],
              UndirectedEdge[106, 158] -> 
             RGBColor[
              0.2827874224549232, 0.411783246820848, 0.939517290657987], 
             UndirectedEdge[59, 319] -> 
             RGBColor[
              0.3999369554845372, 0.5208258336893123, 0.9467049354493426], 
             UndirectedEdge[159, 218] -> 
             RGBColor[
              0.18568639672443343`, 0.31249855452788494`, 0.9338859376438252],
              UndirectedEdge[126, 326] -> 
             RGBColor[
              0.18929893908149736`, 0.31629556559357375`, 0.9340916665867824],
              UndirectedEdge[130, 371] -> 
             RGBColor[
              0.18427986944939637`, 0.311020205182841, 0.9338058379962824], 
             UndirectedEdge[108, 262] -> 
             RGBColor[
              0.23515249805591343`, 0.36449056335924074`, 0.936702958936114], 
             UndirectedEdge[34, 91] -> 
             RGBColor[
              0.37827297461142906`, 0.4967706349329164, 0.9457781608227135], 
             UndirectedEdge[173, 323] -> 
             RGBColor[
              0.3405854460382354, 0.4669912406886779, 0.9430117001586653], 
             UndirectedEdge[104, 208] -> 
             RGBColor[
              0.906012199289136, 0.5692488389367173, 0.4656274775468996], 
             UndirectedEdge[115, 122] -> 
             RGBColor[
              0.7312854319265467, 0.5812953754272103, 0.5851154705993664], 
             UndirectedEdge[275, 297] -> 
             RGBColor[
              0.22283542703535522`, 0.35154454076922603`, 0.9360015199629668],
              UndirectedEdge[185, 293] -> 
             RGBColor[
              0.374247320413842, 0.49857595155038115`, 0.9450676862162266], 
             UndirectedEdge[92, 256] -> 
             RGBColor[
              0.42434961842059, 0.5407753734409124, 0.9485908039462863], 
             UndirectedEdge[135, 165] -> 
             RGBColor[
              0.9457959012350979, 0.9559420991486686, 0.8350019041226482], 
             UndirectedEdge[158, 270] -> 
             RGBColor[
              0.3489276916060272, 0.4766453616785984, 0.9434543418578613], 
             UndirectedEdge[35, 86] -> 
             RGBColor[
              0.32363709491798653`, 0.44803730928476804`, 0.942088262737994], 
             UndirectedEdge[124, 387] -> 
             RGBColor[
              0.42192783769441117`, 0.5376802913607258, 0.9487120906541628], 
             UndirectedEdge[170, 261] -> 
             RGBColor[
              0.2458172275622507, 0.3756998702533064, 0.9373102995044464], 
             UndirectedEdge[78, 244] -> 
             RGBColor[
              0.8873515007123038, 0.5600196245933966, 0.5640900365888891], 
             UndirectedEdge[320, 381] -> 
             RGBColor[
              0.19597803687805715`, 0.32331572085701743`, 0.9344720313254569],
              UndirectedEdge[90, 166] -> 
             RGBColor[
              0.7990367806379581, 0.841477411935373, 0.8913793888944332], 
             UndirectedEdge[119, 317] -> 
             RGBColor[
              0.1888850042427438, 0.31586049383305914`, 0.9340680936100771], 
             UndirectedEdge[173, 250] -> 
             RGBColor[
              0.27041365894161523`, 0.40155227913684066`, 0.9387110298843417],
              UndirectedEdge[234, 355] -> 
             RGBColor[
              0.7757149376246414, 0.8247136720150343, 0.978279673580333], 
             UndirectedEdge[203, 297] -> 
             RGBColor[
              0.2163387830881471, 0.3447161560696932, 0.9356315457010966], 
             UndirectedEdge[48, 388] -> 
             RGBColor[
              0.2298511238520014, 0.358918482944391, 0.9364010535178815], 
             UndirectedEdge[34, 95] -> 
             RGBColor[
              0.41132901778835196`, 0.5236070199417173, 0.9483804536298768], 
             UndirectedEdge[133, 299] -> 
             RGBColor[
              0.18672468895596034`, 0.31358986549474943`, 0.9339450668503949],
              UndirectedEdge[58, 376] -> 
             RGBColor[
              0.2107803074531337, 0.33887384574958357`, 0.9353149987367104], 
             UndirectedEdge[239, 392] -> 
             RGBColor[
              0.9094234148855309, 0.6024922502969611, 0.4858226320933391], 
             UndirectedEdge[64, 77] -> 
             RGBColor[
              0.18172630335562523`, 0.308336245312846, 0.9336604161849047], 
             UndirectedEdge[73, 112] -> 
             RGBColor[
              0.9338615942560703, 0.7754902910821886, 0.2656416901517646], 
             UndirectedEdge[257, 339] -> 
             RGBColor[
              0.2873260863715352, 0.41800078089785175`, 0.939722775048237], 
             UndirectedEdge[35, 85] -> 
             RGBColor[
              0.2384984047146932, 0.36800732340035325`, 0.9368935033705061], 
             UndirectedEdge[37, 187] -> 
             RGBColor[
              0.39185947335344506`, 0.5138307132141199, 0.9461899170277228], 
             UndirectedEdge[9, 39] -> 
             RGBColor[
              0.1871051393828018, 0.3139897430153101, 0.9339667329393776], 
             UndirectedEdge[136, 394] -> 
             RGBColor[
              0.18251086599702937`, 0.30916087039310625`, 0.9337050958666762],
              UndirectedEdge[287, 389] -> 
             RGBColor[
              0.19629053047607914`, 0.32364417144177693`, 0.9344898273735713],
              UndirectedEdge[195, 372] -> 
             RGBColor[
              0.19795832156921558`, 0.32539712562472617`, 0.9345848056090496],
              UndirectedEdge[149, 362] -> 
             RGBColor[
              0.20288427131655484`, 0.3305746111324327, 0.934865331159871], 
             UndirectedEdge[83, 321] -> 
             RGBColor[
              0.7496980165524652, 0.8038110466699736, 0.967993483257613], 
             UndirectedEdge[227, 308] -> 
             RGBColor[
              0.20448504246078797`, 0.33225712309977423`, 0.9349564927084064],
              UndirectedEdge[100, 146] -> 
             RGBColor[
              0.1981449486568544, 0.3255932825266753, 0.9345954337456006], 
             UndirectedEdge[100, 278] -> 
             RGBColor[
              0.23415669632153385`, 0.3634439125989312, 0.9366462495004977], 
             UndirectedEdge[234, 350] -> 
             RGBColor[
              0.8897866044520348, 0.9121284341385445, 0.8654271636734474], 
             UndirectedEdge[278, 352] -> 
             RGBColor[
              0.24888415157963256`, 0.37892340184978857`, 0.9374849562901288],
              UndirectedEdge[342, 353] -> 
             RGBColor[
              0.1868676578718124, 0.31374013489006275`, 0.9339532087186491], 
             UndirectedEdge[109, 181] -> 
             RGBColor[
              0.18812311022869774`, 0.31505969491742614`, 0.9340247048730984],
              UndirectedEdge[59, 296] -> 
             RGBColor[
              0.2957363483745861, 0.42467629385936273`, 0.9402809691977339], 
             UndirectedEdge[168, 378] -> 
             RGBColor[
              0.18751181267223727`, 0.3144171824270826, 0.9339898923815917], 
             UndirectedEdge[191, 370] -> 
             RGBColor[
              0.19715574767547106`, 0.3245535695762768, 0.9345391002131025], 
             UndirectedEdge[153, 184] -> 
             RGBColor[
              0.18277753601960423`, 0.3094411574946885, 0.933720282329959], 
             UndirectedEdge[3, 91] -> 
             RGBColor[
              0.5375833562526594, 0.6354734123169479, 0.9567396775183801], 
             UndirectedEdge[149, 210] -> 
             RGBColor[
              0.26112860842944113`, 0.3917931023423411, 0.9381822599936748], 
             UndirectedEdge[3, 312] -> 
             RGBColor[
              0.44238894573366777`, 0.553566674835752, 0.9503937941922995], 
             UndirectedEdge[17, 388] -> 
             RGBColor[
              0.22559527698605156`, 0.35444531805200136`, 0.9361586893348268],
              UndirectedEdge[99, 243] -> 
             RGBColor[
              0.9675815557220673, 0.9753429578546242, 0.9397601494648378], 
             UndirectedEdge[108, 398] -> 
             RGBColor[
              0.34112387915000547`, 0.4650235569768793, 0.9431351310396142], 
             UndirectedEdge[57, 186] -> 
             RGBColor[
              0.21226621689950026`, 0.3404356307898151, 0.9353996190814751], 
             UndirectedEdge[180, 398] -> 
             RGBColor[
              0.3423187854528118, 0.46627947926256413`, 0.9432031791858535], 
             UndirectedEdge[66, 318] -> 
             RGBColor[
              0.20433061997593613`, 0.33209481527724394`, 0.9349476985763416],
              UndirectedEdge[374, 382] -> 
             RGBColor[
              0.18605529017041303`, 0.3128862849288049, 0.9339069455798448], 
             UndirectedEdge[190, 270] -> 
             RGBColor[
              0.6576592800193992, 0.7261622336829004, 0.951547961847741], 
             UndirectedEdge[47, 96] -> 
             RGBColor[
              0.6461513889555156, 0.7219924964871992, 0.9663950668318202], 
             UndirectedEdge[245, 328] -> 
             RGBColor[
              0.8441804058989478, 0.32309654782053254`, 0.18925529611386532`],
              UndirectedEdge[142, 143] -> 
             RGBColor[
              0.1837659567931899, 0.3104800503972236, 0.9337765714307771], 
             UndirectedEdge[268, 373] -> 
             RGBColor[
              0.475607023803843, 0.5762529501811211, 0.9537345477094038], 
             UndirectedEdge[69, 390] -> 
             RGBColor[
              0.2522635992417797, 0.3824754156120626, 0.9376774108350432], 
             UndirectedEdge[91, 112] -> 
             RGBColor[
              0.7152028502193496, 0.6939405622428378, 0.6107535397674092], 
             UndirectedEdge[16, 190] -> 
             RGBColor[
              0.6369974104682594, 0.7082659607734624, 0.9502314057905163], 
             UndirectedEdge[40, 395] -> 
             RGBColor[
              0.494849422028799, 0.60078007937222, 0.9533755056767188], 
             UndirectedEdge[84, 246] -> 
             RGBColor[
              0.6295415881560444, 0.703574353083331, 0.9675332208830456], 
             UndirectedEdge[196, 376] -> 
             RGBColor[
              0.19966869054902864`, 0.32719483186616644`, 0.9346822085921858],
              UndirectedEdge[37, 311] -> 
             RGBColor[
              0.3257713181858094, 0.4560335502623456, 0.9419991567290754], 
             UndirectedEdge[179, 275] -> 
             RGBColor[
              0.34634920232824207`, 0.46792331791250663`, 0.9435317259645368],
              UndirectedEdge[334, 340] -> 
             RGBColor[
              0.1939578430419053, 0.32119236904753456`, 0.934356984275097], 
             UndirectedEdge[23, 366] -> 
             RGBColor[
              0.34372780451171075`, 0.47069085221995155`, 0.9431761242698371],
              UndirectedEdge[295, 351] -> 
             RGBColor[
              0.6694121408599306, 0.7384677850374681, 0.9699082105749879], 
             UndirectedEdge[358, 363] -> 
             RGBColor[
              0.20533835444542115`, 0.3331540080987284, 0.9350050875635693], 
             UndirectedEdge[111, 116] -> 
             RGBColor[
              0.1862942905711151, 0.31313748950344333`, 0.9339205562990953], 
             UndirectedEdge[147, 371] -> 
             RGBColor[
              0.18501189214807195`, 0.3117896074520688, 0.9338475256060415], 
             UndirectedEdge[33, 311] -> 
             RGBColor[
              0.28964287283882917`, 0.4217634021453914, 0.9398061051687154], 
             UndirectedEdge[137, 178] -> 
             RGBColor[
              0.3880768646119117, 0.5105544076416471, 0.9459488925435418], 
             UndirectedEdge[328, 386] -> 
             RGBColor[
              0.8151456848541535, 0.6567413505380229, 0.5948173850288303], 
             UndirectedEdge[20, 36] -> 
             RGBColor[
              0.19158305641128354`, 0.3186963177285822, 0.934221743689665], 
             UndirectedEdge[107, 212] -> 
             RGBColor[
              0.3829775514957524, 0.5061376389193594, 0.9456239688209257], 
             UndirectedEdge[21, 27] -> 
             RGBColor[
              0.8921201702935075, 0.5251244399562564, 0.23966354856549787`], 
             UndirectedEdge[138, 329] -> 
             RGBColor[
              0.18634787164566047`, 0.31319380661002694`, 0.9339236076620245],
              UndirectedEdge[3, 263] -> 
             RGBColor[
              0.48691076315351817`, 0.5926689051451934, 0.9532109250744729], 
             UndirectedEdge[239, 269] -> 
             RGBColor[
              0.785672209855677, 0.5070071531213871, 0.5746480096042236], 
             UndirectedEdge[74, 86] -> 
             RGBColor[
              0.6370413534700665, 0.7120367862892685, 0.9671058051428245], 
             UndirectedEdge[91, 179] -> 
             RGBColor[
              0.47362295187637204`, 0.5835474746608966, 0.9517044801911976], 
             UndirectedEdge[316, 358] -> 
             RGBColor[
              0.212564816221155, 0.34074947760916474`, 0.9354166238711052], 
             UndirectedEdge[154, 267] -> 
             RGBColor[
              0.23074964895808886`, 0.359862889800671, 0.9364522231934242], 
             UndirectedEdge[25, 357] -> 
             RGBColor[
              0.837209744608855, 0.2870159792435245, 0.18326539950082243`], 
             UndirectedEdge[118, 388] -> 
             RGBColor[
              0.2291977478565746, 0.35823174334676655`, 0.936363844721525], 
             UndirectedEdge[305, 340] -> 
             RGBColor[
              0.19258396167334632`, 0.31974833262006913`, 0.9342787437636328],
              UndirectedEdge[100, 213] -> 
             RGBColor[
              0.21638299645224862`, 0.344762627118653, 0.9356340635867745], 
             UndirectedEdge[51, 238] -> 
             RGBColor[
              0.3357800727610889, 0.463522711822467, 0.942680108320078], 
             UndirectedEdge[104, 242] -> 
             RGBColor[
              0.8356412746575417, 0.27496003188981555`, 0.1817634309041114], 
             UndirectedEdge[99, 337] -> 
             RGBColor[
              0.9798418672906987, 0.9817838609022704, 0.7682315700129669], 
             UndirectedEdge[143, 302] -> 
             RGBColor[
              0.1882090973662136, 0.3151500728508547, 0.9340296017133733], 
             UndirectedEdge[14, 327] -> 
             RGBColor[
              0.19007805312865012`, 0.317114463855815, 0.9341360359791719], 
             UndirectedEdge[162, 348] -> 
             RGBColor[
              0.3027342580511927, 0.4332679187418763, 0.9406342199418414], 
             UndirectedEdge[130, 391] -> 
             RGBColor[
              0.18156952589467779`, 0.3081714622611251, 0.9336514879404352], 
             UndirectedEdge[182, 386] -> 
             RGBColor[
              0.5546461678159978, 0.6446668165900299, 0.9601091386691207], 
             UndirectedEdge[32, 217] -> 
             RGBColor[
              0.975050917301262, 0.9271533469602427, 0.3873122304251019], 
             UndirectedEdge[3, 285] -> 
             RGBColor[
              0.7880339609127915, 0.8307135264515318, 0.7851026525209982], 
             UndirectedEdge[212, 274] -> 
             RGBColor[
              0.45520745425599235`, 0.5676199598754534, 0.950524688408067], 
             UndirectedEdge[234, 272] -> 
             RGBColor[
              0.7633280108193825, 0.8150369106506357, 0.9770450604787972], 
             UndirectedEdge[24, 104] -> 
             RGBColor[
              0.8198979870257355, 0.15395022439912315`, 0.1666876408883935], 
             UndirectedEdge[317, 327] -> 
             RGBColor[
              0.19548056477531295`, 0.3227928461354802, 0.9344437010251496], 
             UndirectedEdge[85, 263] -> 
             RGBColor[
              0.31634895902864796`, 0.44214016934946804`, 0.941608656513351], 
             UndirectedEdge[169, 300] -> 
             RGBColor[
              0.9052440838676142, 0.9272810765527117, 0.9908241829118685], 
             UndirectedEdge[34, 162] -> 
             RGBColor[
              0.2677884948207052, 0.39879306520074553`, 0.9385615306712383], 
             UndirectedEdge[62, 313] -> 
             RGBColor[
              0.20973650567435648`, 0.3377767438992335, 0.9352555557695754], 
             UndirectedEdge[337, 367] -> 
             RGBColor[
              0.6845644891406854, 0.7444870601720963, 0.7692660513213518], 
             UndirectedEdge[21, 240] -> 
             RGBColor[
              0.8974455137213154, 0.5660573631227573, 0.24476310344608182`], 
             UndirectedEdge[258, 378] -> 
             RGBColor[
              0.18711323001988966`, 0.3139982467878655, 0.9339671936891907], 
             UndirectedEdge[240, 242] -> 
             RGBColor[
              0.8419811748449504, 0.32369128289221516`, 0.18783452648346705`],
              UndirectedEdge[16, 380] -> 
             RGBColor[
              0.26894987250182517`, 0.3991789072508731, 0.9386582369767682], 
             UndirectedEdge[38, 222] -> 
             RGBColor[
              0.22765792346573496`, 0.35661329028148886`, 0.9362761540004327],
              UndirectedEdge[61, 147] -> 
             RGBColor[
              0.19642039468713995`, 0.32378066696146846`, 0.9344972229482744],
              UndirectedEdge[279, 288] -> 
             RGBColor[
              0.4888026931766387, 0.5910842948036721, 0.9543337450913586], 
             UndirectedEdge[192, 384] -> 
             RGBColor[
              0.1855895073220066, 0.3123967176227914, 0.933880419935692], 
             UndirectedEdge[196, 289] -> 
             RGBColor[
              0.18795157808443957`, 0.3148794037580448, 0.934014936371242], 
             UndirectedEdge[9, 384] -> 
             RGBColor[
              0.19029625552141455`, 0.3173438084054412, 0.9341484622826384], 
             UndirectedEdge[114, 187] -> 
             RGBColor[
              0.33810546577905015`, 0.4610349816709624, 0.9429931157731941], 
             UndirectedEdge[90, 274] -> 
             RGBColor[
              0.5507285778663977, 0.6461452954084659, 0.9577745175163469], 
             UndirectedEdge[270, 324] -> 
             RGBColor[
              0.49611443813109957`, 0.5992488163397677, 0.9541819472641316], 
             UndirectedEdge[42, 45] -> 
             RGBColor[
              0.2506616815740248, 0.3807916985758058, 0.9375861839936894], 
             UndirectedEdge[316, 363] -> 
             RGBColor[
              0.2271273365064473, 0.3560556097461213, 0.9362459378580343], 
             UndirectedEdge[44, 250] -> 
             RGBColor[
              0.24751102743025372`, 0.3774801613076919, 0.9374067589011768], 
             UndirectedEdge[213, 352] -> 
             RGBColor[
              0.23111045171034733`, 0.3602421163695104, 0.9364727703764056], 
             UndirectedEdge[80, 378] -> 
             RGBColor[
              0.18531329630253898`, 0.3121064023285408, 0.9338646901267509], 
             UndirectedEdge[238, 272] -> 
             RGBColor[
              0.5154577316990447, 0.6098310076277607, 0.9573191957441505], 
             UndirectedEdge[126, 196] -> 
             RGBColor[
              0.1881608487233165, 0.3150993604680292, 0.9340268540245378], 
             UndirectedEdge[112, 240] -> 
             RGBColor[
              0.8843983974342954, 0.516470613459494, 0.2231161879418313], 
             UndirectedEdge[52, 89] -> 
             RGBColor[
              0.18430520538442102`, 0.31104683485694296`, 0.933807280840301], 
             UndirectedEdge[99, 177] -> 
             RGBColor[
              0.9302447173684912, 0.9464438866842635, 0.9664424725007652], 
             UndirectedEdge[41, 206] -> 
             RGBColor[
              0.8010921103082493, 0.8449578955447232, 0.9806977415425538], 
             UndirectedEdge[1, 119] -> 
             RGBColor[
              0.18798137752672578`, 0.3149107248612813, 0.9340166334053959], 
             UndirectedEdge[2, 109] -> 
             RGBColor[
              0.1831541470606865, 0.30983699957738503`, 0.9337417297716024], 
             UndirectedEdge[8, 100] -> 
             RGBColor[
              0.22397988652346618`, 0.35274744025415317`, 0.9360666952377386],
              UndirectedEdge[203, 322] -> 
             RGBColor[
              0.2128310735235297, 0.3410293309156486, 0.935431786830583], 
             UndirectedEdge[98, 193] -> 
             RGBColor[
              0.1939801662783198, 0.32121583218438116`, 0.9343582555503864], 
             UndirectedEdge[141, 285] -> 
             RGBColor[
              0.9298982865463443, 0.7362961374607975, 0.4097714679426784], 
             UndirectedEdge[29, 231] -> 
             RGBColor[
              0.1818156421264654, 0.3084301460254042, 0.9336655038957391], 
             UndirectedEdge[225, 398] -> 
             RGBColor[
              0.6554022589203814, 0.7271955623129416, 0.9686184880711814], 
             UndirectedEdge[149, 359] -> 
             RGBColor[
              0.20190369877404518`, 0.3295439672183649, 0.9348094890042022], 
             UndirectedEdge[87, 235] -> 
             RGBColor[
              0.1948464738725398, 0.3221263763929803, 0.9344075904862901], 
             UndirectedEdge[162, 312] -> 
             RGBColor[
              0.28761893872861966`, 0.41963611907072695`, 0.9396908451152812],
              UndirectedEdge[392, 395] -> 
             RGBColor[
              0.729861417537885, 0.7850410988470374, 0.8743691386056183], 
             UndirectedEdge[212, 268] -> 
             RGBColor[
              0.5483496579696843, 0.6426701443947892, 0.9582447440009759], 
             UndirectedEdge[50, 271] -> 
             RGBColor[
              0.17906803055065768`, 0.3055422320505946, 0.933509031481224], 
             UndirectedEdge[200, 207] -> 
             RGBColor[
              0.1859857863076916, 0.31281323196228517`, 0.9339029874376845], 
             UndirectedEdge[360, 370] -> 
             RGBColor[
              0.18616848137367975`, 0.313005256060175, 0.9339133916514194], 
             UndirectedEdge[134, 246] -> 
             RGBColor[
              0.8756067697264411, 0.9036490867400013, 0.9879973494315406], 
             UndirectedEdge[88, 191] -> 
             RGBColor[
              0.19934659159346146`, 0.326856285441612, 0.9346638655331689], 
             UndirectedEdge[277, 278] -> 
             RGBColor[
              0.23299059780069237`, 0.3622182691186103, 0.9365798419148239], 
             UndirectedEdge[233, 242] -> 
             RGBColor[
              0.9058398899715292, 0.686023971327602, 0.5756445160215393], 
             UndirectedEdge[66, 123] -> 
             RGBColor[
              0.21298431371887483`, 0.3411903960769459, 0.9354405136330093], 
             UndirectedEdge[315, 316] -> 
             RGBColor[
              0.22659989124895852`, 0.3555012313385397, 0.9362159006309058], 
             UndirectedEdge[127, 216] -> 
             RGBColor[
              0.19725740387013102`, 0.32466041668223944`, 0.9345448893830015],
              UndirectedEdge[29, 326] -> 
             RGBColor[
              0.18672499245337307`, 0.31359018448977305`, 0.9339450841341236],
              UndirectedEdge[76, 145] -> 
             RGBColor[
              0.19557703724460856`, 0.3228942448174177, 0.9344491949895577], 
             UndirectedEdge[21, 104] -> 
             RGBColor[
              0.8911056135339068, 0.5173261121203578, 0.23869200786672617`], 
             UndirectedEdge[27, 112] -> 
             RGBColor[
              0.8790730540064875, 0.47553769029299303`, 0.21801663306124733`],
              UndirectedEdge[190, 221] -> 
             RGBColor[
              0.9292638455200164, 0.8080779972178733, 0.5995947563336426], 
             UndirectedEdge[310, 324] -> 
             RGBColor[
              0.45636436031597766`, 0.5621244658109066, 0.9517477784200521], 
             UndirectedEdge[11, 312] -> 
             RGBColor[
              0.30743684398278903`, 0.44016840506601096`, 0.9408303416909466],
              UndirectedEdge[177, 225] -> 
             RGBColor[
              0.8897813970600477, 0.9149515498158103, 0.9893493380404593], 
             UndirectedEdge[253, 316] -> 
             RGBColor[
              0.2127233679212677, 0.3409161254987416, 0.9354256531558705], 
             UndirectedEdge[17, 323] -> 
             RGBColor[
              0.3151837063156497, 0.44029240167692024`, 0.9415651086599703], 
             UndirectedEdge[315, 397] -> 
             RGBColor[
              0.21588466984352767`, 0.3442388542571554, 0.935605684623616], 
             UndirectedEdge[43, 296] -> 
             RGBColor[
              0.2526601828418626, 0.38289225012060224`, 0.937699995684375], 
             UndirectedEdge[50, 287] -> 
             RGBColor[
              0.18448432655099875`, 0.31123510255995407`, 0.9338174815257515],
              UndirectedEdge[253, 369] -> 
             RGBColor[
              0.19084530468760944`, 0.3179208938908398, 0.9341797298204076], 
             UndirectedEdge[187, 220] -> 
             RGBColor[
              0.5353714211663698, 0.63317812373389, 0.9567035702854296], 
             UndirectedEdge[211, 340] -> 
             RGBColor[
              0.21241214123474167`, 0.34058900651829105`, 0.9354079292564914],
              UndirectedEdge[213, 227] -> 
             RGBColor[
              0.2150440363795939, 0.343355295187321, 0.9355578117914507], 
             UndirectedEdge[17, 389] -> 
             RGBColor[
              0.21716250001380405`, 0.34558193478522814`, 0.9356784551614329],
              UndirectedEdge[117, 376] -> 
             RGBColor[
              0.217871456795024, 0.34632709331274647`, 0.9357188292013159], 
             UndirectedEdge[186, 330] -> 
             RGBColor[
              0.19639093276449526`, 0.3237497006127751, 0.9344955451353647], 
             UndirectedEdge[24, 337] -> 
             RGBColor[
              0.9074168352108218, 0.5752287479070755, 0.3804750196277067], 
             UndirectedEdge[73, 99] -> 
             RGBColor[
              0.9481261161147958, 0.8682562660194123, 0.6030407890629428], 
             UndirectedEdge[114, 155] -> 
             RGBColor[
              0.2241859587617661, 0.352964035242341, 0.9360784307468533], 
             UndirectedEdge[123, 232] -> 
             RGBColor[
              0.2533953304852037, 0.3836649369048065, 0.9377418612551098], 
             UndirectedEdge[53, 289] -> 
             RGBColor[
              0.18928237138329773`, 0.3162781518923132, 0.9340907230808797], 
             UndirectedEdge[126, 376] -> 
             RGBColor[
              0.19809406452812484`, 0.3255398000811405, 0.9345925359697458], 
             UndirectedEdge[207, 254] -> 
             RGBColor[
              0.18750231875154622`, 0.3144072037144869, 0.9339893517168534], 
             UndirectedEdge[291, 304] -> 
             RGBColor[
              0.1840328398717771, 0.3107605614341833, 0.9337917700272845], 
             UndirectedEdge[333, 368] -> 
             RGBColor[
              0.18664235406415453`, 0.3135033263031278, 0.9339403780001101], 
             UndirectedEdge[26, 171] -> 
             RGBColor[
              0.18798107467478986`, 0.3149104065446947, 0.9340166161584262], 
             UndirectedEdge[81, 384] -> 
             RGBColor[
              0.18455785037421688`, 0.3113123807598359, 0.9338216685987151], 
             UndirectedEdge[120, 233] -> 
             RGBColor[
              0.7388527640498924, 0.7945317751585553, 0.9544100950493892], 
             UndirectedEdge[224, 290] -> 
             RGBColor[
              0.18877579274929696`, 0.3157457056290379, 0.9340618741770893], 
             UndirectedEdge[393, 396] -> 
             RGBColor[
              0.19146055662429076`, 0.3185675626855177, 0.9342147675080179], 
             UndirectedEdge[2, 365] -> 
             RGBColor[
              0.18295812271216946`, 0.3096309655584321, 0.9337305664749465], 
             UndirectedEdge[210, 387] -> 
             RGBColor[
              0.4198898949581986, 0.5356292280658739, 0.9485927029346032], 
             UndirectedEdge[23, 307] -> 
             RGBColor[
              0.32070535665531497`, 0.4507499650286162, 0.9417091542503788], 
             UndirectedEdge[120, 244] -> 
             RGBColor[
              0.7365322986249497, 0.7928011758440465, 0.9583380377395063], 
             UndirectedEdge[42, 248] -> 
             RGBColor[
              0.21725641238251098`, 0.34568064263912723`, 0.9356838033318999],
              UndirectedEdge[49, 393] -> 
             RGBColor[
              0.1855205539729795, 0.3123242432810691, 0.9338764931444723], 
             UndirectedEdge[375, 377] -> 
             RGBColor[
              0.18266643619111367`, 0.3093243845308089, 0.9337139553590839], 
             UndirectedEdge[269, 350] -> 
             RGBColor[
              0.8687159863176557, 0.8956679071093385, 0.8633270413739342], 
             UndirectedEdge[77, 207] -> 
             RGBColor[
              0.18528324242742453`, 0.31207481380026975`, 0.9338629786030239],
              UndirectedEdge[200, 368] -> 
             RGBColor[
              0.18469320535133593`, 0.3114546474227893, 0.9338293768644222], 
             UndirectedEdge[384, 389] -> 
             RGBColor[
              0.1961032591776717, 0.32344733743346465`, 0.93447916255017], 
             UndirectedEdge[1, 361] -> 
             RGBColor[
              0.205591391562574, 0.33341996615233593`, 0.9350194976530564], 
             UndirectedEdge[150, 380] -> 
             RGBColor[
              0.20683506244234898`, 0.3347271431002675, 0.9350903228698133], 
             UndirectedEdge[150, 381] -> 
             RGBColor[
              0.19485465175919953`, 0.32213497187036766`, 0.9344080562048372],
              UndirectedEdge[232, 279] -> 
             RGBColor[
              0.48366351594508233`, 0.5856826936906501, 0.9540410765507529], 
             UndirectedEdge[132, 341] -> 
             RGBColor[
              0.34725423307667924`, 0.4751958960109486, 0.9433477105601525], 
             UndirectedEdge[1, 14] -> 
             RGBColor[
              0.18904790384743964`, 0.31603171164602595`, 0.9340773705015762],
              UndirectedEdge[171, 342] -> 
             RGBColor[
              0.18633859981298379`, 0.3131840613260155, 0.9339230796448701], 
             UndirectedEdge[140, 325] -> 
             RGBColor[
              0.25741913844630737`, 0.3878942141960865, 0.9379710111658044], 
             UndirectedEdge[89, 306] -> 
             RGBColor[
              0.1959786892882613, 0.3233164065815071, 0.9344720684792528], 
             UndirectedEdge[130, 147] -> 
             RGBColor[
              0.18274418895711692`, 0.3094061076176884, 0.9337183832640827], 
             UndirectedEdge[4, 183] -> 
             RGBColor[
              0.2914028738694214, 0.4198002713108441, 0.9400459473606144], 
             UndirectedEdge[80, 151] -> 
             RGBColor[
              0.18591365690063838`, 0.3127374193822037, 0.9338988797746588], 
             UndirectedEdge[236, 286] -> 
             RGBColor[
              0.22281035809500455`, 0.3515181917234548, 0.9360000923239], 
             UndirectedEdge[108, 180] -> 
             RGBColor[
              0.25734842126298235`, 0.38781988595268346`, 0.9379669839268308],
              UndirectedEdge[9, 320] -> 
             RGBColor[
              0.1934136507337484, 0.32062038842787655`, 0.9343259933282078], 
             UndirectedEdge[35, 97] -> 
             RGBColor[
              0.21457055736469166`, 0.3428576387223553, 0.9355308478620015], 
             UndirectedEdge[154, 236] -> 
             RGBColor[
              0.22814394288837742`, 0.3571241275100973, 0.936303832087551], 
             UndirectedEdge[60, 259] -> 
             RGBColor[
              0.18612091931381164`, 0.3129552653196448, 0.9339106830624717], 
             UndirectedEdge[179, 399] -> 
             RGBColor[
              0.6902620685345601, 0.6570900539452929, 0.6049675909800379], 
             UndirectedEdge[314, 352] -> 
             RGBColor[
              0.23613835462959704`, 0.3655267611250992, 0.9367591020095412], 
             UndirectedEdge[85, 88] -> 
             RGBColor[
              0.21610734049788477`, 0.34447289523301966`, 0.9356183653879699],
              UndirectedEdge[70, 267] -> 
             RGBColor[
              0.23945129119348169`, 0.3690088675060522, 0.9369477688458039], 
             UndirectedEdge[31, 192] -> 
             RGBColor[
              0.18904880805086632`, 0.3160326620211572, 0.9340774219946237], 
             UndirectedEdge[221, 255] -> 
             RGBColor[
              0.8688348859370216, 0.46104786848874635`, 0.21084573587576866`],
              UndirectedEdge[11, 211] -> 
             RGBColor[
              0.2669271143125195, 0.39759011071734907`, 0.9385233725149993], 
             UndirectedEdge[211, 312] -> 
             RGBColor[
              0.26239927833008236`, 0.39312865697304, 0.9382546227647286], 
             UndirectedEdge[123, 280] -> 
             RGBColor[
              0.23161694690439888`, 0.3607744749321087, 0.9365016145284144], 
             UndirectedEdge[178, 278] -> 
             RGBColor[
              0.349928065209785, 0.47283535767355744`, 0.9436893135230188], 
             UndirectedEdge[83, 364] -> 
             RGBColor[
              0.8813558056455749, 0.5477035315439278, 0.5712436925515461], 
             UndirectedEdge[10, 313] -> 
             RGBColor[
              0.22793409689467709`, 0.35690356606571383`, 0.9362918816686491],
              UndirectedEdge[32, 242] -> 
             RGBColor[
              0.9046528362573457, 0.6347619279421703, 0.24263460898170292`], 
             UndirectedEdge[44, 369] -> 
             RGBColor[
              0.21363611782330827`, 0.34187548351747254`, 0.9354776329124991],
              UndirectedEdge[110, 375] -> 
             RGBColor[
              0.18201536929507323`, 0.30864007194304494`, 0.9336768780625215],
              UndirectedEdge[275, 290] -> 
             RGBColor[
              0.21848378643908228`, 0.34697069059259356`, 0.9357537004686844],
              UndirectedEdge[362, 369] -> 
             RGBColor[
              0.18988137332818844`, 0.31690774091531027`, 0.9341248353554973],
              UndirectedEdge[266, 338] -> 
             RGBColor[
              0.23347632110247196`, 0.3627287951054168, 0.936607503138297], 
             UndirectedEdge[350, 395] -> 
             RGBColor[
              0.7312446954176929, 0.785613119798958, 0.8514446443288036], 
             UndirectedEdge[141, 172] -> 
             RGBColor[
              0.8447003804638847, 0.3332796121494973, 0.18999546480661883`], 
             UndirectedEdge[123, 275] -> 
             RGBColor[
              0.22522408057531274`, 0.3540551670891031, 0.9361375502483711], 
             UndirectedEdge[46, 315] -> 
             RGBColor[
              0.21006971303598748`, 0.3381269659628746, 0.9352745314358842], 
             UndirectedEdge[185, 205] -> 
             RGBColor[
              0.3748090292582385, 0.49906247551909, 0.9451034778070919], 
             UndirectedEdge[3, 86] -> 
             RGBColor[
              0.49644576954540676`, 0.6009276484384913, 0.9538184872502891], 
             UndirectedEdge[316, 397] -> 
             RGBColor[
              0.2236385768767503, 0.3523887021751733, 0.9360472581582806], 
             UndirectedEdge[11, 214] -> 
             RGBColor[
              0.2758548681185897, 0.40697374601981373`, 0.9390317948868268], 
             UndirectedEdge[3, 34] -> 
             RGBColor[
              0.4225585018257533, 0.5327236209657705, 0.9492644797482566], 
             UndirectedEdge[5, 100] -> 
             RGBColor[
              0.24629351933764826`, 0.37620048310789195`, 0.9373374236164447],
              UndirectedEdge[25, 245] -> 
             RGBColor[
              0.8180745277590571, 0.13993431743048723`, 0.16494149423531956`],
              UndirectedEdge[183, 325] -> 
             RGBColor[
              0.3195630144976964, 0.44939836456720006`, 0.9416496257101998], 
             UndirectedEdge[149, 266] -> 
             RGBColor[
              0.22467790350563632`, 0.35348110035924685`, 0.9361064462722496],
              UndirectedEdge[73, 78] -> 
             RGBColor[
              0.8752764478324426, 0.45843721309521324`, 0.21487760657063304`],
              UndirectedEdge[40, 167] -> 
             RGBColor[
              0.4156571514498516, 0.5326037138579458, 0.948214502475271], 
             UndirectedEdge[5, 175] -> 
             RGBColor[
              0.282045444074704, 0.41377802280949016`, 0.9393734428399871], 
             UndirectedEdge[279, 309] -> 
             RGBColor[
              0.48491537307549215`, 0.5869984749070372, 0.9541123679623731], 
             UndirectedEdge[66, 257] -> 
             RGBColor[
              0.268687595913645, 0.3984105456780595, 0.9386613405898359], 
             UndirectedEdge[238, 309] -> 
             RGBColor[
              0.29378936272937667`, 0.4261216259230004, 0.9400422416338], 
             UndirectedEdge[40, 355] -> 
             RGBColor[
              0.6433835290110301, 0.7194772226865849, 0.9663605408410356], 
             UndirectedEdge[31, 271] -> 
             RGBColor[
              0.18778814176396494`, 0.3147076218227647, 0.9340056289145733], 
             UndirectedEdge[271, 391] -> 
             RGBColor[
              0.1801133509320429, 0.3066409300485706, 0.9335685609305309], 
             UndirectedEdge[264, 348] -> 
             RGBColor[
              0.5282156563331551, 0.6233653822352514, 0.957751476691993], 
             UndirectedEdge[146, 302] -> 
             RGBColor[
              0.18875875182792845`, 0.3157277945402228, 0.9340609037218272], 
             UndirectedEdge[86, 91] -> 
             RGBColor[
              0.45216024233108254`, 0.5649746624056373, 0.950332168324746], 
             UndirectedEdge[232, 257] -> 
             RGBColor[
              0.30909861267997385`, 0.4408850865059202, 0.9409626882119364], 
             UndirectedEdge[201, 385] -> 
             RGBColor[
              0.9717345415002878, 0.9760010739812197, 0.8028741323146045], 
             UndirectedEdge[204, 297] -> 
             RGBColor[
              0.2002775476373886, 0.32783477926980176`, 0.9347168821026446], 
             UndirectedEdge[241, 323] -> 
             RGBColor[
              0.3309521511254019, 0.4568660369491151, 0.9424630982645621], 
             UndirectedEdge[269, 395] -> 
             RGBColor[
              0.6061102125080312, 0.6895560016714635, 0.9631945161165028], 
             UndirectedEdge[52, 342] -> 
             RGBColor[
              0.18153992013799802`, 0.30814034473374124`, 0.9336498019363901],
              UndirectedEdge[201, 245] -> 
             RGBColor[
              0.8839369101698967, 0.553629569307468, 0.5684023912498125], 
             UndirectedEdge[131, 330] -> 
             RGBColor[
              0.199593351679308, 0.3271156459373298, 0.9346779181550091], 
             UndirectedEdge[159, 349] -> 
             RGBColor[
              0.191248937492894, 0.31834513756099186`, 0.9342027161115474], 
             UndirectedEdge[15, 33] -> 
             RGBColor[
              0.28118366953987284`, 0.41287224313372134`, 0.9393243660551096],
              UndirectedEdge[16, 212] -> 
             RGBColor[
              0.36755596390986156`, 0.4927802348639901, 0.9446413188967272], 
             UndirectedEdge[246, 269] -> 
             RGBColor[
              0.8319134288403021, 0.869426735678431, 0.9836659653182612], 
             UndirectedEdge[150, 294] -> 
             RGBColor[
              0.19175282420721007`, 0.318874754446001, 0.9342314117144941], 
             UndirectedEdge[77, 200] -> 
             RGBColor[
              0.1835118014697444, 0.3102129170379042, 0.9337620976610961], 
             UndirectedEdge[21, 285] -> 
             RGBColor[
              0.9787005711665018, 0.9387674260406853, 0.4607634302742779], 
             UndirectedEdge[275, 280] -> 
             RGBColor[
              0.24514319627116127`, 0.3749914206303192, 0.9372719144195587], 
             UndirectedEdge[171, 353] -> 
             RGBColor[
              0.1894918158351776, 0.3164982912907842, 0.9341026506325689], 
             UndirectedEdge[197, 252] -> 
             RGBColor[
              0.6669388623748537, 0.7337127880117662, 0.9450324457252983], 
             UndirectedEdge[15, 361] -> 
             RGBColor[
              0.2517308007762076, 0.3819154106433724, 0.9376470687506336], 
             UndirectedEdge[348, 366] -> 
             RGBColor[
              0.3637695245894192, 0.4895006114365967, 0.9444000503314454], 
             UndirectedEdge[235, 298] -> 
             RGBColor[
              0.19425582793699694`, 0.3215055700656095, 0.9343739540740432], 
             UndirectedEdge[62, 298] -> 
             RGBColor[
              0.19905173523661984`, 0.32654637271559867`, 0.9346470738998478],
              UndirectedEdge[110, 308] -> 
             RGBColor[
              0.1924672891129, 0.3196257023615725, 0.9342720994339171], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.2089266760744028, 0.33692556164351994`, 0.9352094371718936], 
             UndirectedEdge[204, 290] -> 
             RGBColor[
              0.19592590704111568`, 0.32326092909316934`, 0.9344690626083623],
              UndirectedEdge[35, 93] -> 
             RGBColor[
              0.235285884487402, 0.3646307609559235, 0.9367105550960597], 
             UndirectedEdge[162, 211] -> 
             RGBColor[
              0.24710920905835015`, 0.37705782472206506`, 0.9373838759393338],
              UndirectedEdge[66, 275] -> 
             RGBColor[
              0.22651056308563722`, 0.3554073417751564, 0.9362108135241538], 
             UndirectedEdge[36, 277] -> 
             RGBColor[
              0.20034660319217895`, 0.3279073610362615, 0.9347208147143313], 
             UndirectedEdge[174, 246] -> 
             RGBColor[
              0.6321209059841302, 0.7058084285457353, 0.96769757273425], 
             UndirectedEdge[218, 329] -> 
             RGBColor[
              0.19065196008399016`, 0.31771767645368004`, 0.9341687191312593],
              UndirectedEdge[186, 188] -> 
             RGBColor[
              0.20431810644449144`, 0.33208166276229184`, 0.934946985949238], 
             UndirectedEdge[230, 245] -> 
             RGBColor[
              0.8182841860813337, 0.14154584316836838`, 0.16514226328150688`],
              UndirectedEdge[57, 368] -> 
             RGBColor[
              0.20142644533340448`, 0.3290423435926357, 0.9347823101267909], 
             UndirectedEdge[293, 316] -> 
             RGBColor[
              0.2916240499210687, 0.42013376007774095`, 0.9400548442196108], 
             UndirectedEdge[8, 308] -> 
             RGBColor[
              0.21965638014980107`, 0.34820316092929426`, 0.9358204779458129],
              UndirectedEdge[37, 361] -> 
             RGBColor[
              0.28321730845770904`, 0.41130658795806163`, 0.939575768828076], 
             UndirectedEdge[19, 331] -> 
             RGBColor[
              0.22977587045111889`, 0.35883938684872224`, 0.9363967679480286],
              UndirectedEdge[98, 276] -> 
             RGBColor[
              0.21193626472305038`, 0.34008883013219005`, 0.9353808287931467],
              UndirectedEdge[326, 336] -> 
             RGBColor[
              0.18618247361472157`, 0.3130199627926692, 0.9339141884888471], 
             UndirectedEdge[4, 13] -> 
             RGBColor[
              0.22349076802527734`, 0.3522333457006528, 0.9360388406628528], 
             UndirectedEdge[137, 300] -> 
             RGBColor[
              0.624581474397714, 0.6994688662935715, 0.9671293704856514], 
             UndirectedEdge[57, 163] -> 
             RGBColor[
              0.24223777275819017`, 0.37193763630369614`, 0.9371064548486839],
              UndirectedEdge[28, 304] -> 
             RGBColor[
              0.1939396212205168, 0.3211732167579251, 0.9343559465693256], 
             UndirectedEdge[83, 328] -> 
             RGBColor[
              0.9072826236616158, 0.729489427357416, 0.5953860262532737], 
             UndirectedEdge[206, 321] -> 
             RGBColor[
              0.6423373781810662, 0.7191701000468311, 0.9659074859341975], 
             UndirectedEdge[295, 373] -> 
             RGBColor[
              0.3504430057094734, 0.4745466699427852, 0.9436757963662827], 
             UndirectedEdge[29, 235] -> 
             RGBColor[
              0.18647615617022215`, 0.31332864177904984`, 0.9339309132759184],
              UndirectedEdge[234, 392] -> 
             RGBColor[
              0.888403326572227, 0.9115564131866241, 0.8883516579502622], 
             UndirectedEdge[42, 275] -> 
             RGBColor[
              0.2276321474655179, 0.3565861980709679, 0.9362746860953526], 
             UndirectedEdge[107, 324] -> 
             RGBColor[
              0.4908741561658506, 0.5947099474856988, 0.9538480411311054], 
             UndirectedEdge[75, 329] -> 
             RGBColor[
              0.20420501368883298`, 0.3319627951056, 0.934940545484109], 
             UndirectedEdge[267, 383] -> 
             RGBColor[
              0.23217032750693795`, 0.361356113031734, 0.9365331287350758], 
             UndirectedEdge[253, 362] -> 
             RGBColor[
              0.19012900620093326`, 0.31716801876539596`, 0.9341389376812601],
              UndirectedEdge[137, 252] -> 
             RGBColor[
              0.35201484785933657`, 0.47931930126023004`, 0.943651052724457], 
             UndirectedEdge[131, 203] -> 
             RGBColor[
              0.2195067441810682, 0.34804588403868764`, 0.9358119563987601], 
             UndirectedEdge[52, 199] -> 
             RGBColor[
              0.1829276009104009, 0.30959888520957934`, 0.9337288283034887], 
             UndirectedEdge[41, 386] -> 
             RGBColor[
              0.8163158098721861, 0.8568507653484726, 0.982215097641526], 
             UndirectedEdge[59, 122] -> 
             RGBColor[
              0.472237479074957, 0.5795226558414852, 0.9523966975119249], 
             UndirectedEdge[32, 172] -> 
             RGBColor[
              0.8904177362433487, 0.5253447113739889, 0.22900306113205354`], 
             UndirectedEdge[55, 156] -> 
             RGBColor[
              0.9013085960546312, 0.5775722343508322, 0.2607994456720959], 
             UndirectedEdge[97, 214] -> 
             RGBColor[
              0.21631731839459667`, 0.3446935953158315, 0.9356303233185532], 
             UndirectedEdge[133, 155] -> 
             RGBColor[
              0.1964342499678622, 0.3237952297399831, 0.9344980119860145], 
             UndirectedEdge[186, 273] -> 
             RGBColor[
              0.19433831903215518`, 0.3215922734368583, 0.9343786518198778], 
             UndirectedEdge[74, 179] -> 
             RGBColor[
              0.6585040630153561, 0.7306095985445278, 0.968478117009276], 
             UndirectedEdge[10, 62] -> 
             RGBColor[
              0.21930338871384658`, 0.34783214454915645`, 0.9358003756057394],
              UndirectedEdge[273, 322] -> 
             RGBColor[
              0.19086506728942945`, 0.31794166563837395`, 0.9341808552713451],
              UndirectedEdge[18, 148] -> 
             RGBColor[
              0.46955925293009415`, 0.5770080258985608, 0.9522798906351313], 
             UndirectedEdge[78, 172] -> 
             RGBColor[
              0.8218704023733945, 0.1691110730791465, 0.16857642805283624`], 
             UndirectedEdge[84, 269] -> 
             RGBColor[
              0.5412096627237364, 0.6337584063867442, 0.9589441687264177], 
             UndirectedEdge[103, 254] -> 
             RGBColor[
              0.19079740219879987`, 0.3178705453379077, 0.9341770018445352], 
             UndirectedEdge[46, 343] -> 
             RGBColor[
              0.19165716183089215`, 0.31877420722314587`, 0.9342259638836825],
              UndirectedEdge[1, 317] -> 
             RGBColor[
              0.19445041549410247`, 0.3217100939256911, 0.9343850355475539], 
             UndirectedEdge[27, 399] -> 
             RGBColor[
              0.873807149483661, 0.45466013361864505`, 0.21377956267551557`], 
             UndirectedEdge[247, 253] -> 
             RGBColor[
              0.19436046466415727`, 0.3216155499002067, 0.9343799129808589], 
             UndirectedEdge[27, 357] -> 
             RGBColor[
              0.8390693629151604, 0.3013098204357265, 0.18504617209107904`], 
             UndirectedEdge[41, 55] -> 
             RGBColor[
              0.9217511656674453, 0.9083191148939446, 0.6659672564832814], 
             UndirectedEdge[183, 272] -> 
             RGBColor[
              0.5454600938051113, 0.6375523889526532, 0.9591673986184688], 
             UndirectedEdge[131, 238] -> 
             RGBColor[
              0.2516193138752771, 0.38179823084181674`, 0.9376407197365557], 
             UndirectedEdge[13, 131] -> 
             RGBColor[
              0.21370957013719966`, 0.34195268655651806`, 0.9354818159131122],
              UndirectedEdge[55, 328] -> 
             RGBColor[
              0.9205810406494127, 0.7082097000834948, 0.27856954387058575`], 
             UndirectedEdge[40, 392] -> 
             RGBColor[
              0.7560719179586157, 0.8063199638581745, 0.8764325252109648], 
             UndirectedEdge[39, 347] -> 
             RGBColor[
              0.19051344323313968`, 0.3175720864609606, 0.9341608308015206], 
             UndirectedEdge[195, 362] -> 
             RGBColor[
              0.1955066853579723, 0.3228203005239958, 0.9344451885536901], 
             UndirectedEdge[46, 250] -> 
             RGBColor[
              0.22982046644249732`, 0.3588862600632101, 0.9363993076237638], 
             UndirectedEdge[22, 47] -> 
             RGBColor[
              0.4301895095994409, 0.5445652207348299, 0.9493133718661378], 
             UndirectedEdge[79, 100] -> 
             RGBColor[
              0.22059571881103596`, 0.3491904654197632, 0.9358739718929432], 
             UndirectedEdge[45, 148] -> 
             RGBColor[
              0.30939380782769543`, 0.44018999619208, 0.9410163102615399], 
             UndirectedEdge[65, 68] -> 
             RGBColor[
              0.2789862434779228, 0.41056260901775243`, 0.9391992258916821], 
             UndirectedEdge[86, 162] -> 
             RGBColor[
              0.3416757625403587, 0.46699709267346645`, 0.9431155381732708], 
             UndirectedEdge[3, 264] -> 
             RGBColor[
              0.652580274743898, 0.7275933060781521, 0.9666403041170564], 
             UndirectedEdge[55, 386] -> 
             RGBColor[
              0.8661959692237846, 0.8644995898414272, 0.6605413251423246], 
             UndirectedEdge[315, 362] -> 
             RGBColor[
              0.20400552952862408`, 0.3317531246051941, 0.9349291851562955], 
             UndirectedEdge[92, 182] -> 
             RGBColor[
              0.4229610876060558, 0.5395726978389508, 0.9485023279906137], 
             UndirectedEdge[202, 341] -> 
             RGBColor[
              0.2897972028384973, 0.4193840622352309, 0.9399079526486953], 
             UndirectedEdge[86, 125] -> 
             RGBColor[
              0.3362672755569396, 0.46131242993601224`, 0.9428075328407044], 
             UndirectedEdge[155, 353] -> 
             RGBColor[
              0.19855109199898685`, 0.3260201649302318, 0.9346185630080999], 
             UndirectedEdge[119, 235] -> 
             RGBColor[
              0.18696497458482364`, 0.31384242092567355`, 0.9339587507614879],
              UndirectedEdge[139, 204] -> 
             RGBColor[
              0.19084712474135193`, 0.31792280688272123`, 0.9341798334697757],
              UndirectedEdge[167, 174] -> 
             RGBColor[
              0.3271254190729118, 0.4577613290244936, 0.9420651203310438], 
             UndirectedEdge[218, 349] -> 
             RGBColor[
              0.19642311196174383`, 0.3237835229893623, 0.9344973776930432], 
             UndirectedEdge[362, 397] -> 
             RGBColor[
              0.20104421515641585`, 0.32864059544182767`, 0.9347605426836703],
              UndirectedEdge[70, 108] -> 
             RGBColor[
              0.2395346657598989, 0.3690964994616095, 0.9369525169040198], 
             UndirectedEdge[71, 157] -> 
             RGBColor[
              0.18316059011768585`, 0.3098437716388048, 0.933742096694167], 
             UndirectedEdge[186, 238] -> 
             RGBColor[
              0.24841689496046435`, 0.37843228551726205`, 0.9374583467169113],
              UndirectedEdge[51, 246] -> 
             RGBColor[
              0.6509116591793556, 0.7220840345127228, 0.9688949029118392], 
             UndirectedEdge[109, 305] -> 
             RGBColor[
              0.1817778659169268, 0.3083904408340291, 0.9336633525964908], 
             UndirectedEdge[125, 248] -> 
             RGBColor[
              0.2397553776330553, 0.3693284816342379, 0.936965086118682], 
             UndirectedEdge[106, 390] -> 
             RGBColor[
              0.24476481400135702`, 0.3745937168739334, 0.9372503661090598], 
             UndirectedEdge[1, 231] -> 
             RGBColor[
              0.1878698717924256, 0.3147935252646599, 0.9340102833187854], 
             UndirectedEdge[104, 399] -> 
             RGBColor[
              0.8727925927240603, 0.4468618057827464, 0.21280802197674387`], 
             UndirectedEdge[244, 366] -> 
             RGBColor[
              0.6745824127024198, 0.7409076895841773, 0.9539031392335773], 
             UndirectedEdge[64, 289] -> 
             RGBColor[
              0.18340551527321602`, 0.3101012035064188, 0.9337560448194401], 
             UndirectedEdge[160, 233] -> 
             RGBColor[
              0.7095149174779228, 0.7707139896565038, 0.9521005122991707], 
             UndirectedEdge[100, 302] -> 
             RGBColor[
              0.20076131207818187`, 0.3283432463695126, 0.9347444317718824], 
             UndirectedEdge[177, 337] -> 
             RGBColor[
              0.9444496695413749, 0.9543350995105044, 0.7916221237493946], 
             UndirectedEdge[124, 219] -> 
             RGBColor[
              0.32342751125618663`, 0.45455838713589725`, 0.9418294929148936],
              UndirectedEdge[2, 181] -> 
             RGBColor[
              0.1899547149925528, 0.3169848276546873, 0.9341290120547836], 
             UndirectedEdge[185, 198] -> 
             RGBColor[
              0.3764542800383526, 0.5004875090521163, 0.9452083117319626], 
             UndirectedEdge[11, 35] -> 
             RGBColor[
              0.27410810708868466`, 0.4051377894263376, 0.9389323194302751], 
             UndirectedEdge[5, 56] -> 
             RGBColor[
              0.3320449689742487, 0.4595901829717516, 0.9424676449298229], 
             UndirectedEdge[69, 107] -> 
             RGBColor[
              0.2952174792692931, 0.42393616514341426`, 0.9402585516481101], 
             UndirectedEdge[51, 350] -> 
             RGBColor[
              0.6877142166567092, 0.7483252059436304, 0.8485559789675121], 
             UndirectedEdge[226, 392] -> 
             RGBColor[
              0.7181621296927883, 0.7753237626808771, 0.8735087285822702], 
             UndirectedEdge[81, 292] -> 
             RGBColor[
              0.18697166352319156`, 0.31384945142400145`, 0.9339591316866327],
              UndirectedEdge[51, 272] -> 
             RGBColor[
              0.5612556230240568, 0.6512336824557214, 0.9601738757728618], 
             UndirectedEdge[10, 261] -> 
             RGBColor[
              0.24873551087533646`, 0.3787671710452084, 0.9374764914219134], 
             UndirectedEdge[132, 244] -> 
             RGBColor[
              0.656519419340629, 0.7252624326066381, 0.9527521812690418], 
             UndirectedEdge[53, 376] -> 
             RGBColor[
              0.20099948384788677`, 0.3285935800004348, 0.9347579953018235], 
             UndirectedEdge[242, 364] -> 
             RGBColor[
              0.8349752732346869, 0.2698408531100693, 0.18112566718944462`], 
             UndirectedEdge[29, 327] -> 
             RGBColor[
              0.18852270839333474`, 0.31547969792444663`, 0.934047461397422], 
             UndirectedEdge[328, 364] -> 
             RGBColor[
              0.8436039382637408, 0.3186655649666024, 0.18870327005536394`], 
             UndirectedEdge[257, 279] -> 
             RGBColor[
              0.4976692988631992, 0.5990761277778498, 0.9548872926096961], 
             UndirectedEdge[13, 322] -> 
             RGBColor[
              0.20703389947966117`, 0.33493613343347894`, 0.9351016463449351],
              UndirectedEdge[21, 24] -> 
             RGBColor[
              0.8919944774662327, 0.5241583098068742, 0.2395431849721498], 
             UndirectedEdge[56, 122] -> 
             RGBColor[
              0.48980661456960395`, 0.5947401579565226, 0.9535161872898672], 
             UndirectedEdge[87, 393] -> 
             RGBColor[
              0.1907711086239872, 0.3178429091236707, 0.9341755044643476], 
             UndirectedEdge[27, 74] -> 
             RGBColor[
              0.8420491439644571, 0.52817967821788, 0.5772900887047536], 
             UndirectedEdge[93, 288] -> 
             RGBColor[
              0.2698457094938153, 0.4009553282571281, 0.9386786860034955], 
             UndirectedEdge[125, 211] -> 
             RGBColor[
              0.24170072207493107`, 0.37137316198461084`, 0.9370758706067677],
              UndirectedEdge[265, 304] -> 
             RGBColor[
              0.18543662898340038`, 0.31223603279586976`, 0.9338717137404716],
              UndirectedEdge[195, 343] -> 
             RGBColor[
              0.19193458883998876`, 0.3190658005995948, 0.9342417629414341], 
             UndirectedEdge[199, 393] -> 
             RGBColor[
              0.1849265278957996, 0.3116998842105244, 0.9338426642381596], 
             UndirectedEdge[24, 208] -> 
             RGBColor[
              0.906901063221462, 0.5760810366232336, 0.4664786546523232], 
             UndirectedEdge[135, 386] -> 
             RGBColor[
              0.8778014359212141, 0.9022038387539937, 0.8283895042121832], 
             UndirectedEdge[32, 357] -> 
             RGBColor[
              0.9070663677553636, 0.6533133886521827, 0.2449458094698989], 
             UndirectedEdge[230, 233] -> 
             RGBColor[
              0.8885723351829689, 0.5532979785319709, 0.5591090860551002], 
             UndirectedEdge[46, 161] -> 
             RGBColor[
              0.20037426040526207`, 0.3279364305207805, 0.9347223897517012], 
             UndirectedEdge[114, 306] -> 
             RGBColor[
              0.2220014868268114, 0.35066801673518333`, 0.9359540283017942], 
             UndirectedEdge[233, 357] -> 
             RGBColor[
              0.9082534214695472, 0.7045754320376143, 0.5779557165097353], 
             UndirectedEdge[134, 395] -> 
             RGBColor[
              0.6498035533941702, 0.7237783527330339, 0.9675259002297822], 
             UndirectedEdge[108, 267] -> 
             RGBColor[
              0.2560701403937588, 0.38647633171144136`, 0.9378941877223754], 
             UndirectedEdge[217, 233] -> 
             RGBColor[
              0.9762379710154455, 0.9784153903456743, 0.7203221374649382], 
             UndirectedEdge[245, 400] -> 
             RGBColor[
              0.8345042681241085, 0.26622050143440795`, 0.18067463216363056`],
              UndirectedEdge[269, 392] -> 
             RGBColor[
              0.8673327084378479, 0.8950958861574181, 0.8862515356507488], 
             UndirectedEdge[232, 288] -> 
             RGBColor[
              0.30023200699341346`, 0.43289325353174246`, 0.9404091406935988],
              UndirectedEdge[260, 341] -> 
             RGBColor[
              0.2804084248139549, 0.4095158612485281, 0.93937327562965], 
             UndirectedEdge[47, 323] -> 
             RGBColor[
              0.4713973595467131, 0.580257389192397, 0.951939099626107], 
             UndirectedEdge[142, 377] -> 
             RGBColor[
              0.18361252498065594`, 0.31031878383411166`, 0.9337678337160353],
              UndirectedEdge[53, 117] -> 
             RGBColor[
              0.20926903428907379`, 0.33728540183390365`, 0.9352289339657456],
              UndirectedEdge[251, 308] -> 
             RGBColor[
              0.1958872147734443, 0.3232202610666153, 0.9344668591409584], 
             UndirectedEdge[85, 162] -> 
             RGBColor[
              0.2565370723370653, 0.38696710678905155`, 0.9379207788057828], 
             UndirectedEdge[249, 397] -> 
             RGBColor[
              0.26099988066146607`, 0.3916272530178875, 0.9381760476598446], 
             UndirectedEdge[262, 284] -> 
             RGBColor[
              0.24537509181412387`, 0.37523515754899955`, 0.9372851205276718],
              UndirectedEdge[307, 341] -> 
             RGBColor[
              0.3422947785820742, 0.4709002657971524, 0.9430316985052297], 
             UndirectedEdge[7, 387] -> 
             RGBColor[
              0.4913856837463006, 0.597841186558023, 0.9531378831854276], 
             UndirectedEdge[228, 368] -> 
             RGBColor[
              0.19438368850365684`, 0.3216399596279972, 0.9343812355441619], 
             UndirectedEdge[240, 399] -> 
             RGBColor[
              0.879132492911469, 0.49559305678514604`, 0.2188791175560995], 
             UndirectedEdge[105, 114] -> 
             RGBColor[
              0.22538318625918102`, 0.3542223972507317, 0.9361466110816916], 
             UndirectedEdge[78, 357] -> 
             RGBColor[
              0.8385190338854094, 0.29707975035734024`, 0.18451917639068158`],
              UndirectedEdge[359, 369] -> 
             RGBColor[
              0.18890080078567878`, 0.31587709700124245`, 0.9340689931998285],
              UndirectedEdge[48, 354] -> 
             RGBColor[
              0.22802037271409625`, 0.35699424742212627`, 0.9362967949489314],
              UndirectedEdge[280, 325] -> 
             RGBColor[
              0.2703375929737152, 0.4014723289817168, 0.9387066980399994], 
             UndirectedEdge[259, 262] -> 
             RGBColor[
              0.20019420515358305`, 0.3277471810351035, 0.934712135871486], 
             UndirectedEdge[120, 187] -> 
             RGBColor[
              0.47660974925846794`, 0.585472751295903, 0.952077636221743], 
             UndirectedEdge[70, 198] -> 
             RGBColor[
              0.2881120186842996, 0.4160342955793074, 0.9398697816662858], 
             UndirectedEdge[62, 235] -> 
             RGBColor[
              0.1963098901939031, 0.32366451973268695`, 0.9344909298808612], 
             UndirectedEdge[65, 176] -> 
             RGBColor[
              0.26080757186847375`, 0.39145567256187075`, 0.9381639774364586],
              UndirectedEdge[199, 342] -> 
             RGBColor[
              0.18510212262202141`, 0.31188444540113214`, 0.9338526640980489],
              UndirectedEdge[324, 390] -> 
             RGBColor[
              0.4479202761383373, 0.5532491979543472, 0.9512669003180385], 
             UndirectedEdge[226, 234] -> 
             RGBColor[
              0.6154815427973135, 0.6962991925345092, 0.964434228392668], 
             UndirectedEdge[47, 201] -> 
             RGBColor[
              0.7465737093465549, 0.8011421937069441, 0.9641963866302764], 
             UndirectedEdge[160, 264] -> 
             RGBColor[
              0.5914575736276367, 0.6779711437656651, 0.9618285011853527], 
             UndirectedEdge[277, 314] -> 
             RGBColor[
              0.22024480085065679`, 0.34882162839392095`, 0.9358539876342362],
              UndirectedEdge[4, 66] -> 
             RGBColor[
              0.22354481915991609`, 0.35229015687019793`, 0.9360419187950089],
              UndirectedEdge[23, 75] -> 
             RGBColor[0.255511442446525, 0.3858891047454028, 0.9378623707008],
              UndirectedEdge[287, 391] -> 
             RGBColor[
              0.18552964693238397`, 0.31233380055793014`, 0.9338770109750585],
              UndirectedEdge[45, 91] -> 
             RGBColor[
              0.38905361359871204`, 0.5081017700405416, 0.9463921022645131], 
             UndirectedEdge[175, 314] -> 
             RGBColor[
              0.25716282410855407`, 0.38762481157584006`, 0.9379564144434523],
              UndirectedEdge[195, 358] -> 
             RGBColor[
              0.1963120650172806, 0.3236668056099485, 0.9344910537338352], 
             UndirectedEdge[321, 341] -> 
             RGBColor[
              0.44529829620254, 0.5573731665864943, 0.9503530478730258], 
             UndirectedEdge[91, 148] -> 
             RGBColor[
              0.4136380232673186, 0.5316086524356322, 0.9478775665898638], 
             UndirectedEdge[115, 350] -> 
             RGBColor[
              0.9292292560607558, 0.7349117971309463, 0.4801575703138227], 
             UndirectedEdge[142, 277] -> 
             RGBColor[
              0.19515207298431664`, 0.32244758043556054`, 0.9344249939036124],
              UndirectedEdge[45, 66] -> 
             RGBColor[
              0.2495400971941441, 0.37961284227999426`, 0.9375223114224907], 
             UndirectedEdge[259, 335] -> 
             RGBColor[
              0.18286996403264408`, 0.3095383051966678, 0.9337255459685665], 
             UndirectedEdge[118, 173] -> 
             RGBColor[
              0.26068055800241224`, 0.3913221729354959, 0.9381567441846866], 
             UndirectedEdge[52, 128] -> 
             RGBColor[
              0.18698858591777334`, 0.3138672379336487, 0.9339600953919696], 
             UndirectedEdge[27, 225] -> 
             RGBColor[
              0.8528742555567694, 0.5368113283617635, 0.5783225975121196], 
             UndirectedEdge[302, 352] -> 
             RGBColor[
              0.21548876733628058`, 0.34382273562037, 0.9355831385615135], 
             UndirectedEdge[25, 242] -> 
             RGBColor[
              0.8347962131108371, 0.26846451853351216`, 0.18095419901262647`],
              UndirectedEdge[30, 224] -> 
             RGBColor[
              0.17977250803868983`, 0.30628268255696894`, 0.9335491504319864],
              UndirectedEdge[313, 361] -> 
             RGBColor[
              0.2180016041011253, 0.34646388638327474`, 0.9357262408978626], 
             UndirectedEdge[270, 310] -> 
             RGBColor[
              0.3193491673301014, 0.4483310995882432, 0.9416682954109477], 
             UndirectedEdge[72, 370] -> 
             RGBColor[
              0.18495091945082137`, 0.31172552128136616`, 0.9338440533011341],
              UndirectedEdge[283, 380] -> 
             RGBColor[
              0.2145522876760556, 0.34283843612123366`, 0.9355298074302612], 
             UndirectedEdge[34, 35] -> 
             RGBColor[
              0.24974982719833305`, 0.3798332818120472, 0.9375342552359615], 
             UndirectedEdge[25, 230] -> 
             RGBColor[
              0.8175286583222767, 0.13573852573788114`, 0.16441876904618735`],
              UndirectedEdge[191, 211] -> 
             RGBColor[
              0.2145566630341047, 0.342843034899957, 0.9355300566004294], 
             UndirectedEdge[17, 173] -> 
             RGBColor[
              0.25707808713188923`, 0.38753574764073073`, 0.9379515887979883],
              UndirectedEdge[40, 51] -> 
             RGBColor[
              0.4513189432678153, 0.5634921655168925, 0.9504868403154272], 
             UndirectedEdge[105, 202] -> 
             RGBColor[
              0.2264175602160962, 0.35530958986254624`, 0.9362055171483188], 
             UndirectedEdge[183, 309] -> 
             RGBColor[
              0.3237917248354433, 0.45384300724789295`, 0.9418904445081182], 
             UndirectedEdge[187, 261] -> 
             RGBColor[
              0.3474451829775207, 0.4708516166188276, 0.9435249988507737], 
             UndirectedEdge[190, 274] -> 
             RGBColor[
              0.7246489008143902, 0.7831056857849257, 0.9561147753018562], 
             UndirectedEdge[176, 354] -> 
             RGBColor[
              0.22476081103687653`, 0.35356824143122134`, 0.936111167733503], 
             UndirectedEdge[42, 148] -> 
             RGBColor[
              0.27524609124263133`, 0.40429858097089644`, 0.9390716483190401],
              UndirectedEdge[320, 380] -> 
             RGBColor[
              0.20795844756120663`, 0.3359078920869173, 0.9351542979904328], 
             UndirectedEdge[51, 222] -> 
             RGBColor[
              0.3069819930795281, 0.4332541041734357, 0.9410401002851541], 
             UndirectedEdge[122, 319] -> 
             RGBColor[
              0.5256622973684795, 0.6257953596771879, 0.9558012080947398], 
             UndirectedEdge[27, 78] -> 
             RGBColor[
              0.8204879075828598, 0.15848461230601768`, 0.16725254948011575`],
              UndirectedEdge[5, 178] -> 
             RGBColor[
              0.36206488822589933`, 0.4855919281825182, 0.9443804876389659], 
             UndirectedEdge[196, 336] -> 
             RGBColor[
              0.18504438325654066`, 0.31182375766712467`, 0.9338493759266024],
              UndirectedEdge[297, 318] -> 
             RGBColor[
              0.20065548392565413`, 0.32823201427131354`, 0.9347384050151546],
              UndirectedEdge[127, 235] -> 
             RGBColor[
              0.19315907110692182`, 0.32035280909880115`, 0.9343114953950769],
              UndirectedEdge[45, 203] -> 
             RGBColor[
              0.2552832201033739, 0.38564922859261863`, 0.9378493737759823], 
             UndirectedEdge[305, 370] -> 
             RGBColor[
              0.18466045373978385`, 0.311420223402476, 0.9338275117085959], 
             UndirectedEdge[122, 169] -> 
             RGBColor[
              0.7468757612194565, 0.8021168965628588, 0.9757076451280708], 
             UndirectedEdge[51, 226] -> 
             RGBColor[
              0.41340915500198794`, 0.532495964339595, 0.9475630436867326], 
             UndirectedEdge[226, 395] -> 
             RGBColor[
              0.45693963376297164`, 0.5697838781949226, 0.9504517090480242], 
             UndirectedEdge[61, 354] -> 
             RGBColor[
              0.21260864100273835`, 0.3407955402332605, 0.9354191196275834], 
             UndirectedEdge[211, 334] -> 
             RGBColor[
              0.20343525046697647`, 0.3311537251536216, 0.9348967086073869], 
             UndirectedEdge[10, 361] -> 
             RGBColor[
              0.22756848714061534`, 0.35651928703319763`, 0.9362710607340264],
              UndirectedEdge[44, 249] -> 
             RGBColor[
              0.27287548484168234`, 0.4041092659680885, 0.9388523457495259], 
             UndirectedEdge[302, 377] -> 
             RGBColor[
              0.18805566555367964`, 0.3149888062877428, 0.9340208639986316], 
             UndirectedEdge[149, 363] -> 
             RGBColor[
              0.21825217126115545`, 0.34672724835534197`, 0.9357405103269454],
              UndirectedEdge[358, 359] -> 
             RGBColor[
              0.18898988195831087`, 0.3159707269617513, 0.934074066240826], 
             UndirectedEdge[126, 317] -> 
             RGBColor[
              0.1909701324562666, 0.31805209579023613`, 0.9341868385771666], 
             UndirectedEdge[194, 364] -> 
             RGBColor[
              0.9061043939482173, 0.5637958920619978, 0.4053724452164604], 
             UndirectedEdge[184, 343] -> 
             RGBColor[
              0.18256566753029357`, 0.30921847027918486`, 0.933708216732924], 
             UndirectedEdge[118, 346] -> 
             RGBColor[
              0.2949738551719156, 0.42345379048504006`, 0.9402529639443298], 
             UndirectedEdge[169, 239] -> 
             RGBColor[
              0.8617758088916869, 0.5670725642786435, 0.5820707130728167], 
             UndirectedEdge[72, 157] -> 
             RGBColor[
              0.1851041505972344, 0.3118865769316621, 0.9338527795882372], 
             UndirectedEdge[162, 191] -> 
             RGBColor[
              0.239776323432642, 0.3693504969976439, 0.936966278950982], 
             UndirectedEdge[84, 272] -> 
             RGBColor[
              0.5398855520007457, 0.6327240010263296, 0.9588121937440683], 
             UndirectedEdge[21, 160] -> 
             RGBColor[
              0.7114127926044326, 0.7298581356264684, 0.631074971265499], 
             UndirectedEdge[29, 336] -> 
             RGBColor[
              0.18089581060751259`, 0.30746334477829806`, 0.9336131208515035],
              UndirectedEdge[275, 276] -> 
             RGBColor[
              0.2308037275414878, 0.35991972982060355`, 0.9364553028887468], 
             UndirectedEdge[38, 303] -> 
             RGBColor[
              0.21808265414273661`, 0.3465490751158777, 0.9357308565778295], 
             UndirectedEdge[172, 285] -> 
             RGBColor[
              0.9090011322761398, 0.5869841292419617, 0.39020330546201376`], 
             UndirectedEdge[73, 285] -> 
             RGBColor[
              0.9624071777351879, 0.8763102692580285, 0.43650448397981056`], 
             UndirectedEdge[5, 59] -> 
             RGBColor[
              0.31447583347960173`, 0.4443726808567142, 0.9413481551518805], 
             UndirectedEdge[73, 225] -> 
             RGBColor[
              0.9076627958063523, 0.836763929150959, 0.6259476546026368], 
             UndirectedEdge[64, 254] -> 
             RGBColor[
              0.1839453796797469, 0.3106686352270631, 0.9337867892987342], 
             UndirectedEdge[241, 390] -> 
             RGBColor[
              0.2629620790942533, 0.393720196259813, 0.938286673435659], 
             UndirectedEdge[58, 289] -> 
             RGBColor[
              0.19906319498854463`, 0.3265584176414619, 0.9346477265157667], 
             UndirectedEdge[262, 331] -> 
             RGBColor[
              0.20664951421908523`, 0.3345321201531805, 0.9350797561729924], 
             UndirectedEdge[22, 118] -> 
             RGBColor[
              0.2775783272389005, 0.4083866585141185, 0.9391445362866995], 
             UndirectedEdge[97, 360] -> 
             RGBColor[
              0.189069412661027, 0.31605431877284385`, 0.9340785953966906], 
             UndirectedEdge[301, 358] -> 
             RGBColor[
              0.18673627600332035`, 0.31360204421618604`, 0.9339457267156006],
              UndirectedEdge[16, 274] -> 
             RGBColor[
              0.4054269963890745, 0.5245026293096915, 0.9473527216519175], 
             UndirectedEdge[166, 319] -> 
             RGBColor[
              0.7215283330281927, 0.7785525624499918, 0.8852776399757938], 
             UndirectedEdge[82, 101] -> 
             RGBColor[
              0.181913405203708, 0.30853290121812327`, 0.9336710713583607], 
             UndirectedEdge[24, 399] -> 
             RGBColor[
              0.8736814566563863, 0.4536940034692628, 0.2136591990821675], 
             UndirectedEdge[328, 400] -> 
             RGBColor[
              0.8598546185049423, 0.443575414393966, 0.20426493980685678`], 
             UndirectedEdge[17, 371] -> 
             RGBColor[
              0.20911196002482746`, 0.33712030682309724`, 0.9352199888187673],
              UndirectedEdge[107, 158] -> 
             RGBColor[
              0.34368740964077826`, 0.4721064928245296, 0.9431204357248351], 
             UndirectedEdge[60, 394] -> 
             RGBColor[
              0.18321858514836378`, 0.3099047280931446, 0.933745399425368], 
             UndirectedEdge[219, 284] -> 
             RGBColor[
              0.3068620452246301, 0.43723797575946177`, 0.9408827842352088], 
             UndirectedEdge[124, 149] -> 
             RGBColor[
              0.2631665511656537, 0.3938441656371931, 0.9383016477132344], 
             UndirectedEdge[227, 296] -> 
             RGBColor[
              0.22621507415997788`, 0.35509676417920844`, 0.9361939858669741],
              UndirectedEdge[202, 229] -> 
             RGBColor[
              0.22512118954774685`, 0.35394702209546336`, 0.9361316907565649],
              UndirectedEdge[315, 358] -> 
             RGBColor[
              0.20481090918793238`, 0.33259962969114687`, 0.9349750503364407],
              UndirectedEdge[145, 222] -> 
             RGBColor[
              0.21482177415136725`, 0.3431216834932156, 0.9355451542863606], 
             UndirectedEdge[155, 299] -> 
             RGBColor[
              0.19737174909206562`, 0.3247806007603985, 0.9345514011742322], 
             UndirectedEdge[14, 29] -> 
             RGBColor[
              0.18299367418147944`, 0.3096683324067703, 0.9337325910785299], 
             UndirectedEdge[116, 151] -> 
             RGBColor[
              0.18767873323802545`, 0.31459262652510106`, 0.9339993982608765],
              UndirectedEdge[45, 257] -> 
             RGBColor[
              0.30395689687858984`, 0.4354808171950546, 0.9406698751035344], 
             UndirectedEdge[27, 240] -> 
             RGBColor[
              0.8263635800404189, 0.20364760555090494`, 0.1728791000610972], 
             UndirectedEdge[144, 188] -> 
             RGBColor[
              0.19616736828116454`, 0.3235147201659876, 0.934482813468773], 
             UndirectedEdge[76, 200] -> 
             RGBColor[
              0.1890554468047247, 0.31603963977238364`, 0.9340778000618348], 
             UndirectedEdge[90, 221] -> 
             RGBColor[
              0.755343522572024, 0.6711176068414135, 0.6012544985481333], 
             UndirectedEdge[271, 382] -> 
             RGBColor[
              0.18049565541513857`, 0.3070427562998084, 0.9335903326052744], 
             UndirectedEdge[242, 385] -> 
             RGBColor[
              0.9233493722002852, 0.696643340637751, 0.416149434312738], 
             UndirectedEdge[74, 112] -> 
             RGBColor[
              0.9000839613583336, 0.841002686126469, 0.6275271765854877], 
             UndirectedEdge[237, 251] -> 
             RGBColor[
              0.19380336074719554`, 0.32102999836105145`, 0.9343481867369493],
              UndirectedEdge[25, 223] -> 
             RGBColor[
              0.8736105747823911, 0.4469597061439798, 0.21333691400652116`], 
             UndirectedEdge[284, 332] -> 
             RGBColor[
              0.2524716906122939, 0.382694132836228, 0.9376892613307504], 
             UndirectedEdge[145, 333] -> 
             RGBColor[
              0.19268508450271393`, 0.3198546191252922, 0.9342845025591675], 
             UndirectedEdge[146, 227] -> 
             RGBColor[
              0.19680598858419968`, 0.3241859505953433, 0.934519181950277], 
             UndirectedEdge[108, 286] -> 
             RGBColor[
              0.22549943873113315`, 0.3543445859695858, 0.9361532314879892], 
             UndirectedEdge[127, 361] -> 
             RGBColor[
              0.2062200768333135, 0.33408075423283157`, 0.9350553003491684], 
             UndirectedEdge[143, 258] -> 
             RGBColor[
              0.1842254727690224, 0.31096303082281923`, 0.9338027401858078], 
             UndirectedEdge[212, 310] -> 
             RGBColor[
              0.34846775564587945`, 0.473552157244567, 0.9435237061098725], 
             UndirectedEdge[107, 310] -> 
             RGBColor[
              0.3141088853648525, 0.4437922307341744, 0.9413343892779213], 
             UndirectedEdge[253, 394] -> 
             RGBColor[
              0.1857625991924869, 0.31257864815332465`, 0.9338902772616493], 
             UndirectedEdge[152, 284] -> 
             RGBColor[
              0.26668400229217915`, 0.3976321735243937, 0.9384986314556889], 
             UndirectedEdge[230, 364] -> 
             RGBColor[
              0.8177077184461266, 0.13711486031443826`, 0.16459023722300553`],
              UndirectedEdge[158, 241] -> 
             RGBColor[
              0.3009846875478195, 0.43090972620672763`, 0.9405535979845862], 
             UndirectedEdge[44, 315] -> 
             RGBColor[
              0.22776027402374388`, 0.3567208672073564, 0.9362819827132973], 
             UndirectedEdge[357, 385] -> 
             RGBColor[
              0.9257629036983032, 0.7151948013477634, 0.418460634800934], 
             UndirectedEdge[99, 197] -> 
             RGBColor[
              0.9649742133445314, 0.9733984061785892, 0.9441737000062027], 
             UndirectedEdge[152, 267] -> 
             RGBColor[
              0.25637803396755154`, 0.3867999473790775, 0.9379117218059152], 
             UndirectedEdge[169, 197] -> 
             RGBColor[
              0.9300501065256308, 0.9463228877887528, 0.9676089006734437], 
             UndirectedEdge[263, 348] -> 
             RGBColor[
              0.36254614474277536`, 0.48844098130229274`, 0.9443220976494096],
              UndirectedEdge[314, 379] -> 
             RGBColor[
              0.21988806256935944`, 0.348446673841764, 0.9358336719168633], 
             UndirectedEdge[300, 319] -> 
             RGBColor[
              0.6840306200166372, 0.7509595396670409, 0.9709177458785374], 
             UndirectedEdge[25, 78] -> 
             RGBColor[
              0.8186282892765544, 0.1441907711138157, 0.16547177688985915`], 
             UndirectedEdge[44, 113] -> 
             RGBColor[
              0.27210008577250266`, 0.4033248206617401, 0.9388070693975159], 
             UndirectedEdge[115, 221] -> 
             RGBColor[
              0.8834582095203258, 0.5636927731060549, 0.2244670121341203], 
             UndirectedEdge[175, 319] -> 
             RGBColor[
              0.3675065660796395, 0.49023117564208835`, 0.944730223137449], 
             UndirectedEdge[176, 356] -> 
             RGBColor[
              0.21433034444536764`, 0.34260515971376704`, 0.9355171680916091],
              UndirectedEdge[84, 395] -> 
             RGBColor[
              0.4037383718237736, 0.5237036190763635, 0.9470617716812872], 
             UndirectedEdge[301, 359] -> 
             RGBColor[
              0.1849503238015024, 0.31172489521616553`, 0.9338440193797866], 
             UndirectedEdge[238, 280] -> 
             RGBColor[
              0.2707591220181621, 0.40191538273391547`, 0.9387307034954844], 
             UndirectedEdge[36, 168] -> 
             RGBColor[
              0.18854146293925098`, 0.3154994101413115, 0.9340485294410671], 
             UndirectedEdge[4, 232] -> 
             RGBColor[
              0.26395583592624494`, 0.3947646976980586, 0.9383432664171094], 
             UndirectedEdge[140, 339] -> 
             RGBColor[
              0.2386234653452058, 0.3681387700523239, 0.9369006253884031], 
             UndirectedEdge[18, 141] -> 
             RGBColor[
              0.7353689115489879, 0.586455396789142, 0.5858108169853278], 
             UndirectedEdge[123, 140] -> 
             RGBColor[
              0.21869849237699107`, 0.3471963601464784, 0.9357659276542193], 
             UndirectedEdge[24, 78] -> 
             RGBColor[
              0.8203622147555851, 0.15751848215663547`, 0.1671321858867677], 
             UndirectedEdge[62, 127] -> 
             RGBColor[
              0.1979549784065447, 0.32539361174879033`, 0.9345846152208812], 
             UndirectedEdge[299, 353] -> 
             RGBColor[
              0.188841530987085, 0.3158148006849981, 0.9340656178724803], 
             UndirectedEdge[256, 311] -> 
             RGBColor[
              0.32702639881790146`, 0.45712063802367703`, 0.942079129357128], 
             UndirectedEdge[47, 346] -> 
             RGBColor[
              0.44758503753245593`, 0.5596323527057516, 0.9504217995237683], 
             UndirectedEdge[34, 125] -> 
             RGBColor[
              0.2623800078372861, 0.3931084024632914, 0.9382535253386719], 
             UndirectedEdge[194, 387] -> 
             RGBColor[
              0.7643288542489235, 0.8116893614464729, 0.8013257295322668], 
             UndirectedEdge[117, 303] -> 
             RGBColor[
              0.21968824533158482`, 0.34823665325571823`, 0.9358222926207751],
              UndirectedEdge[287, 382] -> 
             RGBColor[
              0.18591195141547964`, 0.3127356268091679, 0.933898782649802], 
             UndirectedEdge[20, 168] -> 
             RGBColor[
              0.18724662483160132`, 0.31413845319269396`, 0.9339747903263778],
              UndirectedEdge[51, 355] -> 
             RGBColor[
              0.5736425498293158, 0.6609104438201203, 0.9614084888743977], 
             UndirectedEdge[183, 339] -> 
             RGBColor[
              0.30076734139659483`, 0.42964292042343744`, 0.9405792399327987],
              UndirectedEdge[118, 164] -> 
             RGBColor[
              0.21991695118991147`, 0.3484770376136085, 0.9358353170810669], 
             UndirectedEdge[51, 134] -> 
             RGBColor[
              0.6062730746331866, 0.6864904388777064, 0.9646372348684907], 
             UndirectedEdge[46, 356] -> 
             RGBColor[
              0.1981426064801053, 0.32559082075040946`, 0.9345953003620997], 
             UndirectedEdge[204, 276] -> 
             RGBColor[
              0.2082458481435212, 0.33620996832117933`, 0.9351706650284246], 
             UndirectedEdge[108, 154] -> 
             RGBColor[
              0.23083302352450608`, 0.3599505217562283, 0.9364569712516402], 
             UndirectedEdge[29, 119] -> 
             RGBColor[
              0.18192714786076558`, 0.30854734562202557`, 0.9336718539823496],
              UndirectedEdge[244, 264] -> 
             RGBColor[
              0.8390285444461558, 0.8747724603828321, 0.9672545655941249], 
             UndirectedEdge[217, 321] -> 
             RGBColor[
              0.7737155651854934, 0.8183397872541874, 0.7225530793389106], 
             UndirectedEdge[241, 346] -> 
             RGBColor[
              0.30713982911114474`, 0.4362410004624697, 0.9409457981622233], 
             UndirectedEdge[108, 284] -> 
             RGBColor[
              0.26637610871838646`, 0.39730855785675745`, 0.9384810973721491],
              UndirectedEdge[181, 334] -> 
             RGBColor[
              0.18995231521735206`, 0.3169823053387968, 0.934128875391136], 
             UndirectedEdge[8, 59] -> 
             RGBColor[
              0.2921622006654197, 0.4209196380029755, 0.9400774267731745], 
             UndirectedEdge[236, 383] -> 
             RGBColor[
              0.22956462143722656`, 0.3586173507411603, 0.9363847376292023], 
             UndirectedEdge[42, 290] -> 
             RGBColor[
              0.20736560396252507`, 0.33528477587624783`, 0.9351205364245214],
              UndirectedEdge[173, 209] -> 
             RGBColor[
              0.3086611648699239, 0.43934003290171275`, 0.940977513192154], 
             UndirectedEdge[154, 332] -> 
             RGBColor[
              0.2169286054184135, 0.3453360967356988, 0.9356651352102414], 
             UndirectedEdge[5, 352] -> 
             RGBColor[
              0.26102097459574697`, 0.3916799723587493, 0.9381761304060758], 
             UndirectedEdge[189, 226] -> 
             RGBColor[
              0.35594179006458193`, 0.47882793285764735`, 0.9440438043992346],
              UndirectedEdge[16, 390] -> 
             RGBColor[
              0.2902432136013212, 0.4215595588222458, 0.9398708612517093], 
             UndirectedEdge[119, 327] -> 
             RGBColor[
              0.18901152680793626`, 0.3159934770710704, 0.9340752988829915], 
             UndirectedEdge[129, 231] -> 
             RGBColor[
              0.18564063577461087`, 0.3124504568682096, 0.93388333162543], 
             UndirectedEdge[79, 352] -> 
             RGBColor[
              0.23532317406913467`, 0.3646699546706205, 0.9367126786825744], 
             UndirectedEdge[62, 361] -> 
             RGBColor[
              0.20937089592029476`, 0.33739246486671737`, 0.9352347348349528],
              UndirectedEdge[150, 347] -> 
             RGBColor[
              0.19569856946522865`, 0.3230219828868772, 0.9344561160697312], 
             UndirectedEdge[5, 90] -> 
             RGBColor[
              0.44540909938288953`, 0.5535702341777979, 0.950854414653335], 
             UndirectedEdge[24, 27] -> 
             RGBColor[
              0.8209125437853362, 0.16174855223502174`, 0.16765918158716517`],
              UndirectedEdge[62, 393] -> 
             RGBColor[
              0.19223452494535048`, 0.31938105246337734`, 0.9342588438589188],
              UndirectedEdge[199, 353] -> 
             RGBColor[
              0.18825533864421526`, 0.31519867536590085`, 0.9340322350857477],
              UndirectedEdge[96, 201] -> 
             RGBColor[
              0.8486214444306401, 0.8823678065342169, 0.9733384742305298], 
             UndirectedEdge[155, 170] -> 
             RGBColor[
              0.21937286170598153`, 0.34790516506873237`, 0.9358043319898652],
              UndirectedEdge[335, 394] -> 
             RGBColor[
              0.17996762986719622`, 0.30648776797016763`, 0.9335602623314629],
              UndirectedEdge[16, 310] -> 
             RGBColor[
              0.2986872977789616, 0.43043482667880517`, 0.9403517393537228], 
             UndirectedEdge[6, 277] -> 
             RGBColor[
              0.2567019144406389, 0.38714036629150045`, 0.9379301663197194], 
             UndirectedEdge[140, 232] -> 
             RGBColor[
              0.2603959916536444, 0.39102307566039235`, 0.9381405385521024], 
             UndirectedEdge[177, 300] -> 
             RGBColor[
              0.904775992937191, 0.9269078335507821, 0.990779535981055], 
             UndirectedEdge[24, 32] -> 
             RGBColor[
              0.8889095486255394, 0.5137521204514779, 0.227558818965985], 
             UndirectedEdge[102, 226] -> 
             RGBColor[
              0.3613558703292786, 0.48451847448835883`, 0.9443521282608951], 
             UndirectedEdge[187, 206] -> 
             RGBColor[
              0.5826167692195937, 0.6701866792756657, 0.9613440852325792], 
             UndirectedEdge[336, 396] -> 
             RGBColor[
              0.18995557631013382`, 0.31698573295407556`, 0.9341290611055455],
              UndirectedEdge[267, 332] -> 
             RGBColor[
              0.24216572228766625`, 0.37186190669091185`, 0.9371023516809767],
              UndirectedEdge[115, 300] -> 
             RGBColor[
              0.8896537545747043, 0.7064595554170632, 0.6002320083831638], 
             UndirectedEdge[149, 195] -> 
             RGBColor[
              0.20922588183301488`, 0.33724004586656203`, 0.9352264764972114],
              UndirectedEdge[127, 396] -> 
             RGBColor[
              0.197181010085485, 0.3245801219709307, 0.9345405388699805], 
             UndirectedEdge[206, 220] -> 
             RGBColor[
              0.6830678662474279, 0.7522369451466808, 0.9691139391554754], 
             UndirectedEdge[298, 361] -> 
             RGBColor[
              0.2073168336633886, 0.33523351519963984`, 0.9351177590281349], 
             UndirectedEdge[27, 141] -> 
             RGBColor[
              0.8433178856733501, 0.32265315137636846`, 0.18867158623389835`],
              UndirectedEdge[55, 221] -> 
             RGBColor[
              0.9369698505827507, 0.7826274582869746, 0.292244768605455], 
             UndirectedEdge[40, 269] -> 
             RGBColor[
              0.6323207129287618, 0.7108348666826005, 0.9652579027218493], 
             UndirectedEdge[191, 312] -> 
             RGBColor[
              0.25506639270437426`, 0.3854213292486189, 0.9378370257763766], 
             UndirectedEdge[78, 240] -> 
             RGBColor[
              0.8258132510106677, 0.19941753547251867`, 0.17235210436069973`],
              UndirectedEdge[183, 246] -> 
             RGBColor[
              0.63511612996041, 0.7084027410096546, 0.967888425757446], 
             UndirectedEdge[130, 164] -> 
             RGBColor[
              0.19148238974395732`, 0.318590510678587, 0.9342160108718838], 
             UndirectedEdge[190, 295] -> 
             RGBColor[
              0.6926270864337125, 0.7564495900659256, 0.953776079551644], 
             UndirectedEdge[18, 179] -> 
             RGBColor[
              0.5295441815391476, 0.6289468481238254, 0.9561068042364651], 
             UndirectedEdge[128, 199] -> 
             RGBColor[
              0.1905507884017967, 0.3176113386010396, 0.9341629575536283], 
             UndirectedEdge[350, 355] -> 
             RGBColor[
              0.879778802399924, 0.9043102631133229, 0.8644296794931206], 
             UndirectedEdge[233, 348] -> 
             RGBColor[
              0.6462730001834412, 0.7161082281260901, 0.948023487805811], 
             UndirectedEdge[247, 316] -> 
             RGBColor[
              0.21599089502507074`, 0.3443505036580227, 0.9356117339905587], 
             UndirectedEdge[74, 399] -> 
             RGBColor[
              0.8948180568355072, 0.820125129452121, 0.6232901061997559], 
             UndirectedEdge[155, 171] -> 
             RGBColor[
              0.19802203394015824`, 0.32546409136618454`, 0.9345884339343208],
              UndirectedEdge[21, 95] -> 
             RGBColor[
              0.7613060096832925, 0.7703636969149021, 0.6350027480788232], 
             UndirectedEdge[257, 325] -> 
             RGBColor[
              0.30612175947263687`, 0.43775622504161427`, 0.9407931608256381],
              UndirectedEdge[250, 372] -> 
             RGBColor[
              0.22620791914637717`, 0.35508924380626006`, 0.9361935783995345],
              UndirectedEdge[156, 400] -> 
             RGBColor[
              0.8405821739101607, 0.3129379486613033, 0.18649484160836693`], 
             UndirectedEdge[193, 360] -> 
             RGBColor[
              0.18609708652812662`, 0.31293021555080397`, 0.9339093258205844],
              UndirectedEdge[92, 135] -> 
             RGBColor[
              0.746116355711272, 0.7971097200029147, 0.816782693533676], 
             UndirectedEdge[102, 174] -> 
             RGBColor[
              0.3107339262181662, 0.44067229083220405`, 0.9411265427453626], 
             UndirectedEdge[140, 275] -> 
             RGBColor[
              0.23222474174375346`, 0.36141330584468895`, 0.9365362275453637],
              UndirectedEdge[101, 301] -> 
             RGBColor[
              0.1828984857165501, 0.3095682832948322, 0.9337271702362709], 
             UndirectedEdge[337, 398] -> 
             RGBColor[
              0.7100705314017086, 0.7665791120076357, 0.7708912737801167], 
             UndirectedEdge[149, 249] -> 
             RGBColor[
              0.2628399368216051, 0.3935612687084925, 0.9382808361360453], 
             UndirectedEdge[92, 165] -> 
             RGBColor[
              0.6970699985324673, 0.761675381939551, 0.9717947555325273], 
             UndirectedEdge[150, 320] -> 
             RGBColor[
              0.19466927104284892`, 0.32194012498366686`, 0.9343974990472872],
              UndirectedEdge[59, 175] -> 
             RGBColor[
              0.314081747786117, 0.4439584718063857, 0.9413257125546342], 
             UndirectedEdge[278, 379] -> 
             RGBColor[
              0.232633859519395, 0.36184331456645336`, 0.936559526197451], 
             UndirectedEdge[87, 317] -> 
             RGBColor[
              0.19676650353045996`, 0.3241444493003659, 0.9345169333348793], 
             UndirectedEdge[212, 324] -> 
             RGBColor[
              0.5252330264468776, 0.6244698739960914, 0.9560373579630563], 
             UndirectedEdge[135, 328] -> 
             RGBColor[
              0.932186507346842, 0.7459139489960613, 0.44641772294044424`], 
             UndirectedEdge[176, 344] -> 
             RGBColor[
              0.21245918803275743`, 0.3406384556859449, 0.9354106085020388], 
             UndirectedEdge[59, 213] -> 
             RGBColor[
              0.2845653105942021, 0.4129348248674753, 0.9396447951222104], 
             UndirectedEdge[371, 391] -> 
             RGBColor[
              0.18383722908563283`, 0.3105549620955055, 0.9337806302823939], 
             UndirectedEdge[98, 318] -> 
             RGBColor[
              0.1977029240139366, 0.3251286866009877, 0.9345702610961033], 
             UndirectedEdge[25, 244] -> 
             RGBColor[
              0.8860422114357496, 0.549955853479581, 0.56283625969903], 
             UndirectedEdge[204, 224] -> 
             RGBColor[
              0.1864844568543232, 0.3133373663243338, 0.9339313859875982], 
             UndirectedEdge[180, 236] -> 
             RGBColor[
              0.2546593406268537, 0.3849934917065525, 0.9378138447627414], 
             UndirectedEdge[102, 163] -> 
             RGBColor[
              0.272133057471457, 0.4033594760078676, 0.938808947086994], 
             UndirectedEdge[16, 107] -> 
             RGBColor[
              0.33319709362883454`, 0.4630203083535974, 0.9424520020647762], 
             UndirectedEdge[194, 223] -> 
             RGBColor[
              0.9622169086067585, 0.8752522636294204, 0.4543198910461633], 
             UndirectedEdge[111, 291] -> 
             RGBColor[
              0.18821279065920096`, 0.31515395473595276`, 0.9340298120409453],
              UndirectedEdge[108, 205] -> 
             RGBColor[
              0.3030856171044626, 0.43207672625167026`, 0.9407113666179867], 
             UndirectedEdge[66, 297] -> 
             RGBColor[
              0.21059566017891732`, 0.33867976975706876`, 0.935304483347605], 
             UndirectedEdge[19, 284] -> 
             RGBColor[
              0.2685014480461575, 0.3995424242445413, 0.938602132302708], 
             UndirectedEdge[23, 260] -> 
             RGBColor[
              0.2588190028871956, 0.3893655604799919, 0.938050731374799], 
             UndirectedEdge[10, 256] -> 
             RGBColor[
              0.29440488188335295`, 0.4228333554018322, 0.9402213822269152], 
             UndirectedEdge[230, 242] -> 
             RGBColor[
              0.8350058714331137, 0.2700760442713933, 0.18115496805881381`], 
             UndirectedEdge[29, 317] -> 
             RGBColor[
              0.1883961858281423, 0.3153467146864354, 0.9340402561245076], 
             UndirectedEdge[124, 316] -> 
             RGBColor[
              0.27204171641094554`, 0.40317252702797246`, 0.9388070752443234],
              UndirectedEdge[306, 361] -> 
             RGBColor[
              0.21017418029056079`, 0.33823676767103766`, 0.9352804806914867],
              UndirectedEdge[1, 393] -> 
             RGBColor[
              0.1884550205876297, 0.3154085537489959, 0.9340436066770222], 
             UndirectedEdge[74, 279] -> 
             RGBColor[
              0.7676471267223055, 0.8187592045069678, 0.9773831565887533], 
             UndirectedEdge[40, 234] -> 
             RGBColor[
              0.653391331063141, 0.7272953937118065, 0.9673580250213626], 
             UndirectedEdge[195, 316] -> 
             RGBColor[
              0.21810104707830674`, 0.3465684072573414, 0.9357319040283003], 
             UndirectedEdge[279, 325] -> 
             RGBColor[
              0.4806866627377453, 0.5825538322263442, 0.9538715491644547], 
             UndirectedEdge[172, 337] -> 
             RGBColor[
              0.9089250228286312, 0.5868213388295864, 0.3819192617937752], 
             UndirectedEdge[148, 275] -> 
             RGBColor[
              0.28636427371918854`, 0.4159844956872421, 0.939704812363203], 
             UndirectedEdge[13, 188] -> 
             RGBColor[
              0.20797364918202638`, 0.3359238699542373, 0.9351551637002498], 
             UndirectedEdge[220, 233] -> 
             RGBColor[
              0.7976144359577942, 0.8422371475965424, 0.9590360291130758], 
             UndirectedEdge[230, 244] -> 
             RGBColor[
              0.8862518697580262, 0.551567379217462, 0.5630370287452173], 
             UndirectedEdge[253, 358] -> 
             RGBColor[
              0.19093438586024153`, 0.31801452385134865`, 0.9341848028614053],
              UndirectedEdge[66, 140] -> 
             RGBColor[
              0.21998497488731555`, 0.3485485348325317, 0.9358391909300019], 
             UndirectedEdge[89, 128] -> 
             RGBColor[
              0.1919283928758168, 0.31905928824840313`, 0.9342414100904406], 
             UndirectedEdge[199, 298] -> 
             RGBColor[
              0.19174373818706897`, 0.31886520446274574`, 0.9342308942790887],
              UndirectedEdge[367, 398] -> 
             RGBColor[
              0.40058820107881166`, 0.5213910984512207, 0.9467461038398723], 
             UndirectedEdge[72, 181] -> 
             RGBColor[
              0.1888688995598306, 0.3158435667902215, 0.9340671764722099], 
             UndirectedEdge[229, 329] -> 
             RGBColor[
              0.1986631863683978, 0.3261379832196762, 0.934624946616609], 
             UndirectedEdge[196, 326] -> 
             RGBColor[
              0.19087356510240117`, 0.3179505973785997, 0.9341813392092224], 
             UndirectedEdge[247, 362] -> 
             RGBColor[
              0.19339653330473627`, 0.32060239692467707`, 0.9343250185159485],
              UndirectedEdge[276, 297] -> 
             RGBColor[
              0.21488882463476794`, 0.3431921578025159, 0.9355489727121981], 
             UndirectedEdge[7, 201] -> 
             RGBColor[
              0.698844545732584, 0.7622666344739716, 0.960474027707296], 
             UndirectedEdge[191, 214] -> 
             RGBColor[
              0.2234844168401749, 0.3522266702024217, 0.9360384789722569], 
             UndirectedEdge[25, 32] -> 
             RGBColor[
              0.8871756231465087, 0.5004244094086581, 0.22589840996907645`], 
             UndirectedEdge[190, 324] -> 
             RGBColor[
              0.7946744730052755, 0.8399555999055638, 0.9616274448568455], 
             UndirectedEdge[8, 296] -> 
             RGBColor[
              0.241386411848991, 0.3710428020087285, 0.9370579711043807], 
             UndirectedEdge[292, 382] -> 
             RGBColor[
              0.1881384932660469, 0.31507586346502103`, 0.9340255809143183], 
             UndirectedEdge[223, 328] -> 
             RGBColor[
              0.8997164529222819, 0.6301219365340252, 0.23765071588506692`], 
             UndirectedEdge[70, 262] -> 
             RGBColor[
              0.2185336488556363, 0.3470230991538516, 0.9357565400595423], 
             UndirectedEdge[78, 285] -> 
             RGBColor[
              0.907068308455854, 0.5721275983904466, 0.38835243118889584`], 
             UndirectedEdge[167, 272] -> 
             RGBColor[
              0.5255938312060932, 0.6203452307967748, 0.9579015379327056], 
             UndirectedEdge[93, 276] -> 
             RGBColor[
              0.22858867995178067`, 0.3575915743616926, 0.9363291592053822], 
             UndirectedEdge[56, 319] -> 
             RGBColor[
              0.4175060909791842, 0.5360433358043497, 0.9478244252272849], 
             UndirectedEdge[93, 162] -> 
             RGBColor[
              0.2533245521097741, 0.3835905443446218, 0.9377378305313364], 
             UndirectedEdge[106, 389] -> 
             RGBColor[
              0.21473367973065993`, 0.34302909067154336`, 0.9355401374394254],
              UndirectedEdge[68, 176] -> 
             RGBColor[
              0.2518475893962128, 0.38203816288782416`, 0.9376537196897696], 
             UndirectedEdge[253, 301] -> 
             RGBColor[
              0.18689482770343305`, 0.31376869210576286`, 0.9339547560003658],
              UndirectedEdge[217, 357] -> 
             RGBColor[
              0.9250850387636083, 0.713744916795109, 0.34467921995684786`], 
             UndirectedEdge[364, 385] -> 
             RGBColor[
              0.9060512192132981, 0.563682156680796, 0.3995847034769297], 
             UndirectedEdge[161, 372] -> 
             RGBColor[
              0.19676171310914198`, 0.3241394142638304, 0.934516660527472], 
             UndirectedEdge[4, 339] -> 
             RGBColor[
              0.24218330961780632`, 0.3718803920899902, 0.9371033532534101], 
             UndirectedEdge[183, 280] -> 
             RGBColor[
              0.30076148412422865`, 0.4296367640588081, 0.9405789063698025], 
             UndirectedEdge[94, 145] -> 
             RGBColor[
              0.18922208139469943`, 0.31621478329169034`, 0.9340872896552201],
              UndirectedEdge[107, 351] -> 
             RGBColor[
              0.6292040524803684, 0.703641559800374, 0.9673461867380587], 
             UndirectedEdge[90, 178] -> 
             RGBColor[
              0.5250344578406001, 0.6249699305004974, 0.9558390168550672], 
             UndirectedEdge[113, 124] -> 
             RGBColor[
              0.3086276211264817, 0.4416266325643382, 0.9408905883938774], 
             UndirectedEdge[191, 365] -> 
             RGBColor[
              0.19407713550409694`, 0.321317752988877, 0.9343637778043414], 
             UndirectedEdge[184, 356] -> 
             RGBColor[
              0.18905111217950674`, 0.3160350838064485, 0.9340775532113412], 
             UndirectedEdge[196, 327] -> 
             RGBColor[
              0.19267128104236286`, 0.3198401108132733, 0.9342837164725208], 
             UndirectedEdge[140, 288] -> 
             RGBColor[
              0.2655351688852008, 0.39642467677341436`, 0.9384332070927082], 
             UndirectedEdge[13, 232] -> 
             RGBColor[
              0.2546277618608894, 0.3849603004213146, 0.9378120463987364], 
             UndirectedEdge[34, 86] -> 
             RGBColor[
              0.3371353879041764, 0.46222487105446, 0.9428569705546225], 
             UndirectedEdge[287, 374] -> 
             RGBColor[
              0.19007574708878708`, 0.31711204006170757`, 0.9341359046536132],
              UndirectedEdge[201, 230] -> 
             RGBColor[
              0.8833910407331164, 0.5494337776148619, 0.5678796660606804], 
             UndirectedEdge[71, 138] -> 
             RGBColor[
              0.18058969715831197`, 0.30714160013447456`, 0.9335956881434259],
              UndirectedEdge[334, 360] -> 
             RGBColor[
              0.185115098539477, 0.3118980839130987, 0.9338534030573518], 
             UndirectedEdge[38, 58] -> 
             RGBColor[
              0.2174442667054725, 0.3458780894432118, 0.935694501357687], 
             UndirectedEdge[115, 239] -> 
             RGBColor[
              0.8461854795987771, 0.346251043142995, 0.19147853854411218`], 
             UndirectedEdge[32, 78] -> 
             RGBColor[
              0.888484912423063, 0.5104881805224738, 0.22715218685893562`], 
             UndirectedEdge[41, 83] -> 
             RGBColor[
              0.9084527486796484, 0.9295988421678656, 0.9827837388659694], 
             UndirectedEdge[90, 212] -> 
             RGBColor[
              0.5128575453871849, 0.6144229009627645, 0.9550631147611566], 
             UndirectedEdge[160, 263] -> 
             RGBColor[
              0.42578806203725694`, 0.5430467428327064, 0.9483991221427692], 
             UndirectedEdge[226, 350] -> 
             RGBColor[
              0.7195454075725961, 0.7758957836327975, 0.8505842343054555], 
             UndirectedEdge[159, 329] -> 
             RGBColor[
              0.18547778561514033`, 0.3122792910253096, 0.9338740575497635], 
             UndirectedEdge[132, 260] -> 
             RGBColor[
              0.29142760754703456`, 0.4190601234916939, 0.9400754082095211], 
             UndirectedEdge[7, 250] -> 
             RGBColor[
              0.35349640883612216`, 0.4759428684075872, 0.943916070428803], 
             UndirectedEdge[135, 281] -> 
             RGBColor[
              0.711765095722288, 0.768553055573181, 0.8142632180180123], 
             UndirectedEdge[240, 243] -> 
             RGBColor[
              0.9006075598972731, 0.6106868981753124, 0.5572235175535094], 
             UndirectedEdge[105, 349] -> 
             RGBColor[
              0.20573070891450085`, 0.3335663975224413, 0.935027431570147], 
             UndirectedEdge[111, 154] -> 
             RGBColor[
              0.19738148096805996`, 0.3247908295791051, 0.934551955390173], 
             UndirectedEdge[3, 233] -> 
             RGBColor[
              0.7706376185941841, 0.8203361519689907, 0.9569123152308744], 
             UndirectedEdge[125, 162] -> 
             RGBColor[
              0.2669203824734684, 0.39788062408229774`, 0.9385120929573202], 
             UndirectedEdge[301, 369] -> 
             RGBColor[
              0.18664719483068826`, 0.31350841425567716`, 0.9339406536746029],
              UndirectedEdge[268, 270] -> 
             RGBColor[
              0.5192310696539062, 0.6174490867384653, 0.9563893333020512], 
             UndirectedEdge[4, 188] -> 
             RGBColor[
              0.2173017232473819, 0.34572826723098127`, 0.9356863837186229], 
             UndirectedEdge[161, 176] -> 
             RGBColor[
              0.21656199837052442`, 0.34495076948413805`, 0.9356442574812107],
              UndirectedEdge[106, 270] -> 
             RGBColor[
              0.2929589759941193, 0.42059333525935383`, 0.9401654130551529], 
             UndirectedEdge[190, 268] -> 
             RGBColor[
              0.8177911045280821, 0.8581558703042615, 0.9638348308947651], 
             UndirectedEdge[220, 341] -> 
             RGBColor[
              0.4860287842689018, 0.590440011686344, 0.9535595010943037], 
             UndirectedEdge[76, 103] -> 
             RGBColor[
              0.19412197120965846`, 0.32136487815817005`, 0.9343663311314445],
              UndirectedEdge[84, 163] -> 
             RGBColor[
              0.3028162711208553, 0.4328272844297121, 0.940658180484038], 
             UndirectedEdge[356, 372] -> 
             RGBColor[
              0.1945300591839852, 0.3217938044934594, 0.9343895711378705], 
             UndirectedEdge[243, 398] -> 
             RGBColor[
              0.6978102198330773, 0.7601382089599893, 0.9424198532319874], 
             UndirectedEdge[141, 243] -> 
             RGBColor[
              0.9175618655302045, 0.7296924440007758, 0.5730160037263106], 
             UndirectedEdge[192, 320] -> 
             RGBColor[
              0.18870690253434044`, 0.31567329764522667`, 0.9340579509812614],
              UndirectedEdge[83, 245] -> 
             RGBColor[
              0.8819322732807819, 0.5521345143978579, 0.5717957186100475], 
             UndirectedEdge[256, 313] -> 
             RGBColor[
              0.28483799884386285`, 0.41277795475190926`, 0.9396765623907513],
              UndirectedEdge[144, 186] -> 
             RGBColor[
              0.19870087032152506`, 0.3261775914437136, 0.9346270926619912], 
             UndirectedEdge[271, 371] -> 
             RGBColor[
              0.1828236944867615, 0.3094896729702865, 0.9337229109863782], 
             UndirectedEdge[317, 326] -> 
             RGBColor[
              0.19368284883535128`, 0.3209033327008066, 0.9343413237618512], 
             UndirectedEdge[194, 242] -> 
             RGBColor[
              0.9234025469352043, 0.6967570760189528, 0.42193717605226866`], 
             UndirectedEdge[305, 334] -> 
             RGBColor[
              0.18360707090558112`, 0.31031305125539965`, 0.9337675231145284],
              UndirectedEdge[252, 282] -> 
             RGBColor[
              0.31835440977210794`, 0.4463178036126423, 0.941647079240882], 
             UndirectedEdge[134, 239] -> 
             RGBColor[
              0.8293655507418161, 0.5412295041829576, 0.578979393717503], 
             UndirectedEdge[267, 398] -> 
             RGBColor[
              0.34104050458358826`, 0.46493592502132197`, 0.9431303829813984],
              UndirectedEdge[4, 297] -> 
             RGBColor[
              0.2198696831096341, 0.34842735586426754`, 0.9358326252338219], 
             UndirectedEdge[40, 272] -> 
             RGBColor[
              0.6309966022057711, 0.7098004613221861, 0.9651259277394999], 
             UndirectedEdge[203, 325] -> 
             RGBColor[
              0.2574480826974209, 0.38792463643917835`, 0.9379726594980861], 
             UndirectedEdge[315, 359] -> 
             RGBColor[
              0.2030249569861144, 0.33072248069112636`, 0.9348733430006266], 
             UndirectedEdge[132, 160] -> 
             RGBColor[
              0.40894844852211004`, 0.5284611159894712, 0.9473261168602697], 
             UndirectedEdge[283, 381] -> 
             RGBColor[
              0.20257187699290616`, 0.3302462648913338, 0.9348475407652852], 
             UndirectedEdge[40, 183] -> 
             RGBColor[
              0.43552341404886974`, 0.5498108720138242, 0.9494803631610341], 
             UndirectedEdge[131, 339] -> 
             RGBColor[
              0.23240211172972863`, 0.36159973294585546`, 0.9365463285036696],
              UndirectedEdge[156, 165] -> 
             RGBColor[
              0.8638677055732559, 0.5798421452000351, 0.5836596867408057], 
             UndirectedEdge[352, 379] -> 
             RGBColor[
              0.22335212736306764`, 0.3520876255743447, 0.9360309452822404], 
             UndirectedEdge[25, 194] -> 
             RGBColor[
              0.9059253338243674, 0.5624195574854407, 0.4052009770396422], 
             UndirectedEdge[174, 238] -> 
             RGBColor[
              0.3169893195658634, 0.44724710585547944`, 0.9414827781424888], 
             UndirectedEdge[66, 339] -> 
             RGBColor[
              0.23290928668708955`, 0.3621328059827914, 0.9365752113671932], 
             UndirectedEdge[67, 387] -> 
             RGBColor[
              0.4796742864541198, 0.5876973628554791, 0.9523916433059518], 
             UndirectedEdge[90, 190] -> 
             RGBColor[
              0.7822989919455827, 0.8299086268722369, 0.9606532016549456], 
             UndirectedEdge[271, 389] -> 
             RGBColor[
              0.19087423447573804`, 0.31795130093241747`, 0.9341813773290437],
              UndirectedEdge[19, 293] -> 
             RGBColor[
              0.3046492475878372, 0.4338240686707453, 0.9407966099576801], 
             UndirectedEdge[126, 327] -> 
             RGBColor[
              0.19109665502145906`, 0.31818507902824733`, 0.9341940438500809],
              UndirectedEdge[12, 310] -> 
             RGBColor[
              0.2940376027932159, 0.42638254196942454`, 0.9400563785381975], 
             UndirectedEdge[272, 350] -> 
             RGBColor[
              0.867391875594665, 0.894633501748924, 0.8631950663915847], 
             UndirectedEdge[215, 229] -> 
             RGBColor[
              0.19493972789376507`, 0.3222243922819345, 0.9344129011648419], 
             UndirectedEdge[57, 189] -> 
             RGBColor[
              0.24216202976271878`, 0.3718580256130724, 0.9371021413971435], 
             UndirectedEdge[104, 337] -> 
             RGBColor[
              0.9065279712784959, 0.568396550220559, 0.3796238425222831], 
             UndirectedEdge[194, 385] -> 
             RGBColor[
              0.9944784929138155, 0.9905983795896796, 0.6403962123397537], 
             UndirectedEdge[56, 166] -> 
             RGBColor[
              0.6856726502293173, 0.7474973607293266, 0.8829926191709212], 
             UndirectedEdge[258, 379] -> 
             RGBColor[
              0.19525485067885182`, 0.32255560630899927`, 0.9344308469412701],
              UndirectedEdge[9, 150] -> 
             RGBColor[
              0.19229026561489077`, 0.3194396394412268, 0.9342620182075883], 
             UndirectedEdge[294, 380] -> 
             RGBColor[
              0.20504200072556777`, 0.3328425215492514, 0.9349882106576397], 
             UndirectedEdge[296, 308] -> 
             RGBColor[
              0.22323052785896746`, 0.35195981678568156`, 0.9360240203703722],
              UndirectedEdge[33, 92] -> 
             RGBColor[
              0.3869660924415177, 0.5054181375626268, 0.9463177797578736], 
             UndirectedEdge[39, 283] -> 
             RGBColor[
              0.19607798492560893`, 0.3234207725920666, 0.934477723218905], 
             UndirectedEdge[11, 34] -> 
             RGBColor[
              0.28760640007487454`, 0.41932535119602954`, 0.9397010272469036],
              UndirectedEdge[105, 171] -> 
             RGBColor[
              0.19921926143757313`, 0.32672245337457523`, 0.9346566142691592],
              UndirectedEdge[110, 237] -> 
             RGBColor[
              0.19038343508665123`, 0.3174354396560086, 0.9341534270299079], 
             UndirectedEdge[8, 175] -> 
             RGBColor[
              0.2597318112605219, 0.39032497995575144`, 0.938102714461281], 
             UndirectedEdge[90, 373] -> 
             RGBColor[
              0.44011491122134366`, 0.5480057067490964, 0.9505529184695845], 
             UndirectedEdge[73, 104] -> 
             RGBColor[
              0.874812220102593, 0.4548689553377009, 0.21443306157225883`], 
             UndirectedEdge[232, 339] -> 
             RGBColor[
              0.2733203034534184, 0.404607346810652, 0.9388765589892938], 
             UndirectedEdge[178, 274] -> 
             RGBColor[
              0.46738436670940764`, 0.5781669894131862, 0.9513005905019778], 
             UndirectedEdge[224, 318] -> 
             RGBColor[
              0.18686239314258873`, 0.3137346013258456, 0.9339529089001083], 
             UndirectedEdge[132, 307] -> 
             RGBColor[
              0.3533139613151539, 0.48044452804031823`, 0.9437338310851009]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.1972575262297792, 0.3246605452899877, 0.9345448963512025], 
             316 -> RGBColor[
              0.23435379828218117`, 0.36365107925655765`, 0.9366574741655703],
              308 -> RGBColor[
              0.20150049615977755`, 0.32912017570624735`, 0.9347865272118044],
              160 -> RGBColor[
              0.4596234812344611, 0.572182073724828, 0.9506023905805157], 245 -> 
             RGBColor[
              0.818830055518114, 0.14574163486097447`, 0.1656649884706391], 
             155 -> RGBColor[
              0.2070813101039675, 0.3349859650056321, 0.9351043463098516], 
             213 -> RGBColor[
              0.22261848399738943`, 0.3513165198813409, 0.9359891653778931], 
             352 -> RGBColor[
              0.2396024194233052, 0.3691677128576799, 0.9369563753749182], 27 -> 
             RGBColor[
              0.821038236612611, 0.16271468238440395`, 0.16777954518051325`], 
             367 -> RGBColor[
              0.37508215881778845`, 0.49929904661568136`, 0.9451208813811075],
              19 -> RGBColor[
              0.26040419361571815`, 0.3910316964425663, 0.9381410056417089], 
             164 -> RGBColor[
              0.20095261322947336`, 0.32854431600871353`, 0.9347553260894438],
              190 -> RGBColor[
              0.9562193148935751, 0.9668690172486966, 0.9589934594404549], 
             103 -> RGBColor[
              0.19434739415987903`, 0.3216018119714924, 0.9343791686349763], 
             138 -> RGBColor[
              0.18225239431662393`, 0.3088892002689491, 0.9336903762868517], 
             291 -> RGBColor[
              0.18717515147111807`, 0.3140633301591533, 0.9339707200242335], 
             28 -> RGBColor[
              0.20698871416859752`, 0.3348886408066369, 0.9350990731083157], 
             337 -> RGBColor[
              0.9940468194635823, 0.9896750737285114, 0.5934112212615963], 
             195 -> RGBColor[
              0.20184829587443234`, 0.32948573525812513`, 0.9348063338910304],
              114 -> RGBColor[
              0.24129060741956473`, 0.3709421054790498, 0.9370525151838548], 
             93 -> RGBColor[
              0.2343202347626608, 0.3636158018694917, 0.9366555627727864], 34 -> 
             RGBColor[
              0.2632481201845229, 0.3940208435817391, 0.93830296305259], 161 -> 
             RGBColor[
              0.1994550789542851, 0.32697031253633363`, 0.9346700437278752], 
             22 -> RGBColor[
              0.3162753653274515, 0.4483635578097335, 0.9413737645007089], 
             124 -> RGBColor[
              0.3097296345397099, 0.44269397479938727`, 0.9409566763230764], 
             84 -> RGBColor[
              0.3388378220394789, 0.4679060237916442, 0.9428114242912021], 46 -> 
             RGBColor[
              0.20129344185623907`, 0.3289025485052273, 0.9347747357755273], 
             241 -> RGBColor[
              0.2632132370288079, 0.3939841791733627, 0.938300976508477], 185 -> 
             RGBColor[
              0.3996003392677278, 0.5205354622018381, 0.9466831581588019], 
             390 -> RGBColor[
              0.2627109211596987, 0.39345621334626335`, 0.938272370362841], 
             121 -> RGBColor[
              0.3109061797336599, 0.4437130391115059, 0.9410316447424569], 
             322 -> RGBColor[
              0.1999051049994005, 0.32744331844304914`, 0.9346956720453906], 
             126 -> RGBColor[
              0.1865862227024127, 0.3134443286830033, 0.9339371814020978], 
             236 -> RGBColor[
              0.25077535368791876`, 0.38091117517473666`, 0.9375926574524128],
              78 -> RGBColor[
              0.8199375785531087, 0.1542545422276314, 0.1667255537797183], 
             376 -> RGBColor[
              0.209601906353837, 0.3376352714792777, 0.9352478905373938], 254 -> 
             RGBColor[
              0.18724741023772068`, 0.314139278704323, 0.9339748350540943], 
             290 -> RGBColor[
              0.19821724293608944`, 0.32566926839787347`, 0.9345995507978533],
              251 -> RGBColor[
              0.19027393338711107`, 0.3173203464269832, 0.9341471910701123], 
             165 -> RGBColor[
              0.8967495440562933, 0.920507761085305, 0.9900139661214994], 100 -> 
             RGBColor[
              0.2101475089071078, 0.33820873435596516`, 0.9352789617956558], 
             235 -> RGBColor[
              0.1915139828942802, 0.31862371708269777`, 0.9342178100550568], 
             70 -> 
             RGBColor[
              0.22291581655962178`, 0.35162903525622036`, 0.9360060980274482],
              234 -> RGBColor[
              0.7857227396767522, 0.8325318430402561, 0.9792771577606599], 
             257 -> RGBColor[
              0.32310439559809073`, 0.45427852059311985`, 0.9418089042708796],
              135 -> RGBColor[
              0.9948422584139026, 0.9913764372120322, 0.679989842123797], 265 -> 
             RGBColor[
              0.18998272969436467`, 0.3170142728825262, 0.9341306074506077], 
             111 -> RGBColor[
              0.18925042984728385`, 0.3162445793127523, 0.934088904057657], 
             381 -> RGBColor[
              0.19616341759440778`, 0.32351056774371817`, 0.9344825884830068],
              182 -> RGBColor[
              0.34853172220347034`, 0.47630239288410453`, 0.9434291110376724],
              188 -> RGBColor[
              0.2017846044041309, 0.3294187914845658, 0.9348027067560198], 
             154 -> RGBColor[
              0.2055125320888361, 0.33333707984545796`, 0.935015006722689], 
             336 -> RGBColor[
              0.18035329176886106`, 0.3068931230811942, 0.933582225206227], 
             315 -> RGBColor[
              0.2188459842157359, 0.34735138342052185`, 0.9357743270962412], 
             368 -> RGBColor[
              0.1851720653526604, 0.311957959645659, 0.9338566472330878], 269 -> 
             RGBColor[
              0.743581503407994, 0.7996107889818441, 0.9750769131616334], 208 -> 
             RGBColor[
              0.9930152754848626, 0.9913796511608278, 0.7654184913108293], 86 -> 
             RGBColor[
              0.4110226556238299, 0.5304288985271809, 0.947410978056655], 119 -> 
             RGBColor[
              0.18241596627536708`, 0.30906112476864933`, 0.9336996914679191],
              377 -> RGBColor[
              0.18473621585810335`, 0.3114998541924255, 0.9338318262491543], 
             140 -> RGBColor[
              0.2256991535454318, 0.35455449890206425`, 0.9361646049512119], 
             85 -> RGBColor[
              0.24074527521724318`, 0.3703689267583512, 0.9370214593216792], 
             351 -> RGBColor[
              0.9097894237460113, 0.9309054071917814, 0.9912577214871428], 
             242 -> RGBColor[
              0.852273426221674, 0.40280203706702433`, 0.19769039802525293`], 
             117 -> RGBColor[
              0.22614100723621103`, 0.3550189151462153, 0.9361897678652379], 
             47 -> RGBColor[
              0.5441036538714303, 0.6407668836599264, 0.9572529792315668], 81 -> 
             RGBColor[
              0.17955783501139488`, 0.30605704759422586`, 0.9335369251206622],
              275 -> RGBColor[
              0.23875032994207512`, 0.36827211278731364`, 0.9369078501395155],
              23 -> RGBColor[
              0.2930562064900811, 0.4253510322307103, 0.9400004894705796], 
             328 -> RGBColor[
              0.8695307562797816, 0.5004514607800906, 0.21284560375709155`], 
             110 -> RGBColor[
              0.18343408206602244`, 0.3101312290168976, 0.9337576716560296], 
             6 -> RGBColor[
              0.30558851701585305`, 0.4385232851876776, 0.9407141860151303], 
             218 -> RGBColor[
              0.19086057119328328`, 0.3179369399562554, 0.934180599225321], 
             108 -> RGBColor[
              0.256153514960176, 0.38656396366699863`, 0.9378989357805914], 
             297 -> RGBColor[
              0.20692052412863532`, 0.33481696875113837`, 0.935095189786418], 
             157 -> RGBColor[
              0.1873941802353717, 0.31429354327760956`, 0.9339831933883338], 
             354 -> RGBColor[
              0.2158527042869893, 0.34420525643050026`, 0.9356038642324599], 
             385 -> RGBColor[
              0.9944253181788963, 0.9904846442084778, 0.6346084706002231], 
             270 -> RGBColor[
              0.3590992451452233, 0.4854554501171043, 0.9441024642550272], 
             392 -> RGBColor[
              0.9910839134677017, 0.9905809833329919, 0.7974261581398643], 33 -> 
             RGBColor[
              0.2765417318743941, 0.4079932723314563, 0.939060014572192], 252 -> 
             RGBColor[
              0.3695662131784596, 0.4945214117423836, 0.9447694102025287], 
             394 -> RGBColor[
              0.18043226082461958`, 0.30697612456572376`, 0.9335867223771283],
              260 -> RGBColor[
              0.22458179928431016`, 0.35338008872927346`, 0.9361009732790185],
              159 -> RGBColor[
              0.1805122222555836, 0.3070601690995145, 0.9335912760623294], 
             183 -> RGBColor[
              0.3499869056482099, 0.4775627996442913, 0.943521834040003], 99 -> 
             RGBColor[
              0.965636915117815, 0.9738926480760296, 0.9430519187643377], 329 -> 
             RGBColor[
              0.19044334897469703`, 0.3174984129511047, 0.9341568390371975], 
             309 -> RGBColor[
              0.2975965440226766, 0.4301232148514946, 0.9402590549762334], 17 -> 
             RGBColor[
              0.2316763474093035, 0.360836908628973, 0.9365049972992935], 349 -> 
             RGBColor[
              0.2019856527302044, 0.3296301060224692, 0.9348141561607654], 
             347 -> RGBColor[
              0.19785125300646603`, 0.3252845897767374, 0.9345787082127948], 
             340 -> RGBColor[
              0.2029347338096705, 0.33062765041220404`, 0.9348682049242014], 
             277 -> RGBColor[
              0.20781531186542476`, 0.3357574473953233, 0.9351461466243084], 
             104 -> RGBColor[
              0.8190091230934095, 0.14711802671260676`, 0.16583646378296987`],
              79 -> RGBColor[
              0.23104392871496413`, 0.36017219648356114`, 0.9364689819902305],
              327 -> RGBColor[
              0.19560708734050541`, 0.3229258293734914, 0.9344509062980639], 
             191 -> RGBColor[
              0.20722377740839654`, 0.33513570717553587`, 0.9351124596120775],
              50 -> RGBColor[
              0.1790362447681438, 0.3055088231778375, 0.9335072213279326], 
             225 -> RGBColor[
              0.884710274500928, 0.9109079743391231, 0.9888656498437259], 61 -> 
             RGBColor[
              0.20936457771848743`, 0.3373858240360207, 0.9352343750227069], 
             196 -> RGBColor[
              0.18973547474422028`, 0.3167543922530552, 0.9341165266469779], 
             1 -> RGBColor[
              0.19354678877808446`, 0.32076032495391327`, 0.9343335753428726],
              263 -> RGBColor[
              0.3919526428400527, 0.5139114119405849, 0.9461958537050229], 
             201 -> RGBColor[
              0.9490437648216794, 0.9615175037539616, 0.971139794028986], 371 -> 
             RGBColor[
              0.18654757264035143`, 0.3134037050172214, 0.9339349803382411], 
             293 -> RGBColor[
              0.3488943015599562, 0.47661644089892424`, 0.9434522142736513], 
             362 -> RGBColor[
              0.18916507484151227`, 0.3161548657898664, 0.9340840432163497], 
             184 -> RGBColor[
              0.18311045325504194`, 0.3097910746173054, 0.9337392414740102], 
             106 -> RGBColor[
              0.22681870684301533`, 0.35573122040160343`, 0.9362283618552786],
              206 -> RGBColor[
              0.7303132143006519, 0.7892455006884563, 0.9737544541026248], 
             358 -> RGBColor[
              0.19077583416012883`, 0.31784787596177183`, 0.9341757735766401],
              247 -> RGBColor[
              0.1976279917679603, 0.3250499280594878, 0.9345659938155473], 
             220 -> RGBColor[
              0.635822518194204, 0.7152283896049052, 0.9644734242083259], 107 -> 
             RGBColor[
              0.34861868121472545`, 0.4763777124089667, 0.9434346519889747], 
             375 -> RGBColor[
              0.180596656524124, 0.30714891486919227`, 0.9335960844690134], 
             131 -> RGBColor[
              0.21325644631447746`, 0.3414764246891273, 0.9354560111817448], 
             127 -> RGBColor[
              0.19480415931956344`, 0.32208190111490453`, 0.9344051807350968],
              210 -> RGBColor[
              0.3056537490672848, 0.4385918482096833, 0.9407179008839572], 
             357 -> RGBColor[
              0.85710048921771, 0.439904958487049, 0.20231279900164487`], 181 -> 
             RGBColor[
              0.19492367816056405`, 0.3222075229947284, 0.9344119871562795], 
             194 -> RGBColor[
              0.9945316676487347, 0.9907121149708813, 0.6461839540792844], 
             118 -> RGBColor[
              0.2388812891503496, 0.36840975921850344`, 0.93691530807269], 
             348 -> RGBColor[
              0.33313964664549794`, 0.4629705506640006, 0.9424483415937963], 
             276 -> RGBColor[
              0.22285712514090053`, 0.35156734685389346`, 0.9360027556379781],
              305 -> RGBColor[
              0.18223318953702214`, 0.3088690148279342, 0.9336892826030643], 
             343 -> RGBColor[
              0.1820208818055452, 0.30864586594106436`, 0.9336771919918379], 
             280 -> RGBColor[
              0.2515360626002474, 0.3817107284733248, 0.937635978699602], 189 -> 
             RGBColor[
              0.266643234211289, 0.39758932368653244`, 0.9384963097737932], 
             168 -> RGBColor[
              0.18420503135956878`, 0.31094154560542325`, 0.9338015760777798],
              363 -> RGBColor[
              0.21990087473071346`, 0.348460140235685, 0.9358344015504985], 
             41 -> RGBColor[
              0.8718710063158469, 0.90067029040099, 0.9876410289824828], 14 -> 
             RGBColor[
              0.18454901891679482`, 0.31130309833813863`, 0.9338211656602798],
              77 -> RGBColor[
              0.18280925758947733`, 0.30947449887588874`, 0.9337220888264354],
              51 -> RGBColor[
              0.381577964086101, 0.5049253866504279, 0.9455347883487892], 179 -> 
             RGBColor[
              0.45394807471440896`, 0.5675745230376996, 0.950155601789558], 
             223 -> RGBColor[
              0.9299021495647822, 0.7597924122879596, 0.2624558280130423], 
             323 -> RGBColor[
              0.3986910652219958, 0.5197478947248675, 0.9466252200206473], 
             292 -> 
             RGBColor[
              0.1943854920349882, 0.321641855253777, 0.934381338252603], 396 -> 
             RGBColor[
              0.19955786085140656`, 0.3270783428269569, 0.9346758970048641], 
             321 -> RGBColor[
              0.5543615420614805, 0.6490946994052059, 0.9580605177657702], 
             143 -> RGBColor[
              0.18504307948317125`, 0.3118223873186494, 0.9338493016786379], 
             112 -> RGBColor[
              0.937107871400364, 0.788360698201582, 0.2682537209419814], 197 -> 
             RGBColor[
              0.9643115115712477, 0.9729041642811488, 0.9452954812480678], 54 -> 
             RGBColor[
              0.1846123721443362, 0.31136968659711123`, 0.9338247735328656], 
             71 -> RGBColor[0.178927, 0.305394, 0.933501], 177 -> 
             RGBColor[
              0.8948525196191675, 0.9189951252924975, 0.9898330262371927], 
             158 -> RGBColor[
              0.3387561380668311, 0.4678352732400925, 0.9428062194606953], 
             226 -> RGBColor[
              0.44524034591787487`, 0.5600665420287623, 0.9495912990246761], 
             350 -> RGBColor[
              0.9938504692273173, 0.9917250252368329, 0.751577169586235], 203 -> 
             RGBColor[
              0.2257570420476589, 0.35461534338824796`, 0.9361679016157753], 
             115 -> RGBColor[
              0.8646080428941941, 0.47809856902505976`, 0.2087379710414105], 
             173 -> RGBColor[
              0.2824798268544749, 0.4142345866524884, 0.9393981802966833], 
             212 -> RGBColor[
              0.41733642177677943`, 0.535897565429752, 0.9478132856528767], 
             129 -> RGBColor[
              0.189088316742455, 0.3160741881610126, 0.9340796719561618], 279 -> 
             RGBColor[
              0.6722342021283076, 0.7438737349625797, 0.9679656809485127], 26 -> 
             RGBColor[
              0.18699939157323073`, 0.3138785953626525, 0.9339607107580624], 
             40 -> RGBColor[
              0.5210599224495296, 0.6220589443833571, 0.9554388922820652], 
             146 -> RGBColor[
              0.18614238840660097`, 0.3129778306973855, 0.9339119056955454], 
             386 -> RGBColor[
              0.7607606134285254, 0.8130312402959552, 0.9767891663005692], 
             192 -> RGBColor[
              0.18162114890697434`, 0.30822572132013676`, 0.933654427794616], 
             300 -> RGBColor[
              0.9146994662552146, 0.9348205418090667, 0.9917260457249173], 
             221 -> RGBColor[
              0.9023083761464576, 0.6492869771870501, 0.2401960532268301], 62 -> 
             RGBColor[
              0.20110579749352597`, 0.32870532238267614`, 0.9347640497066657],
              286 -> RGBColor[
              0.1948453625020903, 0.32212520827217295`, 0.9344075271953871], 
             152 -> RGBColor[
              0.25676930210776144`, 0.3872111950022711, 0.9379340039476709], 
             64 -> RGBColor[
              0.18064334912177313`, 0.30719799174980317`, 0.933598743543374], 
             307 -> RGBColor[
              0.3483545068205488, 0.47614889782652203`, 0.9434178190301781], 
             37 -> RGBColor[
              0.34879862256835453`, 0.4765335685653648, 0.9434461176929121], 
             148 -> RGBColor[
              0.33397821749630197`, 0.46369687858717057`, 0.9425017745868906],
              261 -> RGBColor[
              0.2599700418165058, 0.39057537537478015`, 0.9381162813390138], 
             387 -> RGBColor[
              0.5341260408491124, 0.6326666079220644, 0.9564675049852491], 15 -> 
             RGBColor[
              0.28582560720535155`, 0.41775121393598635`, 0.9395887175380273],
              136 -> RGBColor[
              0.18458947116943916`, 0.3113456162204888, 0.9338234693562242], 
             198 -> RGBColor[
              0.3533082208089774, 0.4804395559023944, 0.9437334653051234], 63 -> 
             RGBColor[
              0.1811814280726413, 0.30776354684334156`, 0.9336293863436095], 
             310 -> RGBColor[
              0.27959908951497947`, 0.4112067490593821, 0.9392341265668681], 
             171 -> RGBColor[
              0.188962757776349, 0.315942217726737, 0.93407252155879], 395 -> 
             RGBColor[
              0.46863892160806836`, 0.5795012143610829, 0.9513121190713723], 
             311 -> RGBColor[
              0.3027440138032642, 0.4355335319593264, 0.9405521957652387], 
             353 -> RGBColor[
              0.19002087389400624`, 0.31705436485483146`, 0.934132779706348], 
             59 -> RGBColor[
              0.3465121371910148, 0.4745531298536097, 0.9433004248665277], 
             397 -> RGBColor[
              0.2129233554713194, 0.341126325093789, 0.9354370421509908], 229 -> 
             RGBColor[
              0.20688302376209858`, 0.33477755348824767`, 0.9350930541960206],
              102 -> RGBColor[
              0.2774713947406823, 0.40897040694795533`, 0.9391129574971142], 
             299 -> RGBColor[
              0.18766218808016377`, 0.31457523651516484`, 0.9339984560386126],
              128 -> RGBColor[
              0.19461177340916913`, 0.32187969132510885`, 0.9343942246421093],
              12 -> 
             RGBColor[
              0.3084761160714523, 0.441558334879467, 0.9408786305095267], 222 -> 
             RGBColor[
              0.23238602207295528`, 0.3615828216964435, 0.9365454122215189], 
             92 -> RGBColor[
              0.49739045300864126`, 0.6028430027937971, 0.9535755449435551], 
             271 -> RGBColor[
              0.17909981633317154`, 0.30557564092335165`, 0.9335108416345153],
              361 -> RGBColor[
              0.21763599434706354`, 0.34607960735075854`, 0.93570541996324], 
             344 -> RGBColor[
              0.1912494582787511, 0.31834568493994736`, 0.9342027457695316], 
             132 -> RGBColor[
              0.35827341580975897`, 0.4847401582541144, 0.9440498431400237], 
             80 -> RGBColor[
              0.1798079986201722, 0.3063199854083397, 0.9335511715680982], 
             324 -> RGBColor[
              0.6331296311169758, 0.713042182562431, 0.9642614302732361], 244 -> 
             RGBColor[
              0.9547654228714991, 0.9657847069591619, 0.9614545193980599], 
             150 -> RGBColor[
              0.19354588592399127`, 0.3207593759970171, 0.9343335239266677], 
             125 -> RGBColor[
              0.2615118954900493, 0.3921959613448436, 0.9382040876247539], 
             258 -> RGBColor[
              0.18340786605487358`, 0.31010367432698904`, 0.9337561786929778],
              133 -> RGBColor[
              0.18578718983175693`, 0.312604494474334, 0.9338916776621772], 
             255 -> RGBColor[
              0.8353613957275855, 0.2728087597904426, 0.18149541852470724`], 
             326 -> RGBColor[
              0.19201165546058205`, 0.31914680250414423`, 0.9342461517714671],
              176 -> RGBColor[
              0.23366891778676377`, 0.3629312264319425, 0.9366184712345461], 
             230 -> RGBColor[
              0.8177383166445533, 0.1373500514757623, 0.1646195380923747], 
             274 -> RGBColor[
              0.49307848673520527`, 0.5993423543211548, 0.9532360911632574], 
             87 -> RGBColor[
              0.19817896485079942`, 0.32562903570326285`, 0.9345973709175234],
              130 -> RGBColor[
              0.1820121662584413, 0.30863670534846055`, 0.9336766956543238], 
             35 -> RGBColor[
              0.2362515342121432, 0.36564572004235524`, 0.9367655474193329], 
             379 -> RGBColor[
              0.20710183530283005`, 0.33500753829100943`, 0.9351055151895625],
              31 -> RGBColor[
              0.19647646719475834`, 0.3238396027221777, 0.9345004161946314], 
             18 -> 
             RGBColor[
              0.6051402883638863, 0.6903191732099512, 0.9620580066833722], 24 -> 
             RGBColor[
              0.8207868509580615, 0.16078242208563953`, 0.1675388179938171], 
             151 -> RGBColor[
              0.19201931518110454`, 0.3191548533560677, 0.9342465879812193], 
             137 -> RGBColor[
              0.33446348254021346`, 0.46411719077807645`, 0.9425326952463855],
              330 -> RGBColor[
              0.18593025704413854`, 0.31275486718553225`, 0.9338998251282734],
              296 -> RGBColor[
              0.2449605595581574, 0.37479945786511576`, 0.9372615135289399], 
             266 -> RGBColor[
              0.23275233921967517`, 0.3619678442434947, 0.9365662734411069], 
             302 -> RGBColor[
              0.19137511524925596`, 0.3184777583830601, 0.9342099017481089], 
             283 -> RGBColor[
              0.20898033639140454`, 0.33698196203894937`, 0.9352124930475636],
              388 -> RGBColor[
              0.2195142065627996, 0.3480537274750297, 0.9358123813703602], 
             284 -> RGBColor[
              0.2765987024765969, 0.40805315204651627`, 0.939063258963707], 
             318 -> RGBColor[
              0.19439044372267295`, 0.3216470597914888, 0.9343816202438913], 
             238 -> RGBColor[
              0.28998218143607674`, 0.4221200369945062, 0.9398254282913666], 
             72 -> RGBColor[
              0.18281412095909713`, 0.3094796105857146, 0.9337223657881405], 
             288 -> RGBColor[
              0.30537118422496984`, 0.4382948546447645, 0.9407018092342045], 
             382 -> RGBColor[
              0.1818914944971056, 0.30850987167626515`, 0.9336698235760336], 
             389 -> RGBColor[
              0.20264865261830456`, 0.3303269609414833, 0.9348519130235723], 
             172 -> RGBColor[
              0.8238032261936802, 0.18396760393066158`, 0.17042730232595416`],
              243 -> RGBColor[
              0.9695261963263196, 0.9767932676332187, 0.9364683801653377], 88 -> 
             RGBColor[
              0.19146940577852636`, 0.3185768637076881, 0.9342152714542605], 
             273 -> RGBColor[
              0.1818250295794584, 0.30844001283369876`, 0.9336660384972996], 
             202 -> RGBColor[
              0.2433593553333951, 0.37311649070267905`, 0.9371703273171091], 
             393 -> RGBColor[
              0.18336325239717496`, 0.31005678254407854`, 0.9337536380111718],
              98 -> RGBColor[
              0.20101540430520026`, 0.32861031341048663`, 0.9347589019483153],
              30 -> 
             RGBColor[
              0.18021067351487519`, 0.3067432222537355, 0.9335741033076473], 
             116 -> RGBColor[
              0.18333815129494635`, 0.31003039969413443`, 0.9337522085405336],
              373 -> RGBColor[
              0.271851153445097, 0.4030631770024157, 0.9387928930697325], 240 -> 
             RGBColor[
              0.8316889234682268, 0.24458052871740593`, 0.17797865494168116`],
              317 -> RGBColor[
              0.1953540422101205, 0.32265986289746895`, 0.9344364957522352], 
             391 -> RGBColor[
              0.18112688553091424`, 0.3077062191737896, 0.9336262802265466], 
             73 -> RGBColor[
              0.9306153171117766, 0.762619883962795, 0.26302965936154776`], 
             303 -> RGBColor[
              0.21323548342695858`, 0.34145439136522115`, 0.9354548173763124],
              29 -> RGBColor[
              0.1814383294461641, 0.30803356647540187`, 0.9336440164967801], 
             360 -> RGBColor[
              0.18524924480481392`, 0.31203908014333226`, 0.9338610424887112],
              320 -> RGBColor[
              0.19579265616170655`, 0.32312087397031664`, 0.9344614741679068],
              75 -> RGBColor[
              0.21796667840296896`, 0.34642717726009525`, 0.9357242519310205],
              200 -> RGBColor[
              0.1842143453500115, 0.31095133519991963`, 0.9338021064957567], 
             301 -> RGBColor[
              0.18269671784651187`, 0.30935621247060024`, 0.933715679854561], 
             156 -> RGBColor[
              0.8309858670902185, 0.23917652931476524`, 0.17730540736011186`],
              25 -> RGBColor[0.817319, 0.134127, 0.164218], 38 -> 
             RGBColor[
              0.22292982485851465`, 0.3516437588665342, 0.9360068957793466], 
             365 -> RGBColor[
              0.18093049359979738`, 0.3074997988022181, 0.9336150959966053], 
             380 -> RGBColor[
              0.22012423896070668`, 0.348694910203518, 0.9358471218129588], 
             370 -> RGBColor[
              0.18708771794254558`, 0.3139714319770177, 0.9339657408141276], 
             3 -> RGBColor[
              0.5818688834669836, 0.6714263983498019, 0.960225996443923], 57 -> 
             RGBColor[
              0.21768082531414856`, 0.3461267275396124, 0.9357079730204939], 
             227 -> RGBColor[
              0.20746958876179836`, 0.3353940704933011, 0.9351264582050084], 
             39 -> RGBColor[
              0.18317563345981333`, 0.30985958314518375`, 0.9337429533902465],
              109 -> 
             RGBColor[
              0.18132254229683142`, 0.30791186684012395`, 0.9336374225899173],
              256 -> RGBColor[
              0.3513087838325387, 0.47870774408802763`, 0.9436060629490174], 
             339 -> RGBColor[
              0.2515477771449798, 0.3817230412025836, 0.9376366458255944], 
             287 -> RGBColor[
              0.1899324083338537, 0.31696138194207063`, 0.9341277417235704], 
             239 -> RGBColor[
              0.82776291630336, 0.2144035172609302, 0.17421910604681382`], 
             285 -> RGBColor[
              0.9941990383585994, 0.9900006545532618, 0.6099793085980734], 
             345 -> RGBColor[
              0.1789871968344326, 0.3054572706896884, 0.9335044281206677], 
             366 -> RGBColor[
              0.39439940253334044`, 0.5160306722091927, 0.9463517590690945], 
             216 -> RGBColor[
              0.1997106484206986, 0.3272389322495743, 0.9346845980309063], 21 -> 
             RGBColor[
              0.9632021039744041, 0.8875341975281088, 0.3115475519504825], 
             355 -> RGBColor[
              0.7657071355725306, 0.8168955009898127, 0.9772821894000061], 
             175 -> RGBColor[
              0.28165135838121924`, 0.41336381375916165`, 0.9393510002427407],
              7 -> RGBColor[
              0.4486453266434888, 0.5630157651939816, 0.9498082613856059], 13 -> 
             RGBColor[
              0.21416269395992185`, 0.3424289484239088, 0.9355076206444797], 
             294 -> RGBColor[
              0.1899597624904289, 0.3169901328949849, 0.9341292995023205], 
             193 -> RGBColor[
              0.18694492825143932`, 0.3138213509582757, 0.9339576091524576], 
             60 -> RGBColor[
              0.186004909472108, 0.3128333316205655, 0.9339040764736078], 65 -> 
             RGBColor[
              0.2879462259501837, 0.4199801186917991, 0.9397094836383711], 69 -> 
             RGBColor[
              0.2418162773238607, 0.37149461787786187`, 0.9370824513072455], 
             217 -> RGBColor[
              0.9930695883095065, 0.987584875103169, 0.4870456409120508], 214 -> 
             RGBColor[
              0.23974505627195325`, 0.36931763322930755`, 0.9369644983324363],
              170 -> RGBColor[
              0.2316644133079956, 0.36082436513183264`, 0.936504317669879], 
             359 -> RGBColor[
              0.18720392975649292`, 0.3140935779617309, 0.9339723589050121], 
             74 -> RGBColor[
              0.8630600513163033, 0.8936446740513561, 0.986800632228994], 246 -> 
             RGBColor[
              0.9202453542726101, 0.9392426823750178, 0.9922550174748891], 
             264 -> RGBColor[
              0.7232916660208124, 0.7837602138065023, 0.9730546117901898], 
             278 -> RGBColor[
              0.25816588373595994`, 0.3886790908418973, 0.9380135372053394], 
             45 -> RGBColor[
              0.2848093981590889, 0.41668311379698936`, 0.9395308459361892], 
             306 -> RGBColor[
              0.20271236623405806`, 0.3303939279913168, 0.9348555414197336], 
             237 -> RGBColor[
              0.19733278810728, 0.3247396502951197, 0.9345491824037863], 228 -> 
             RGBColor[
              0.20359531165465325`, 0.33132195961033534`, 0.9349058238552358],
              180 -> RGBColor[
              0.2585433275657887, 0.3890758082383683, 0.93803503207307], 383 -> 
             RGBColor[
              0.20835388918653433`, 0.3363235263075839, 0.9351768178059918], 
             53 -> RGBColor[
              0.19239706134193654`, 0.319551888521592, 0.9342681000662533], 
             304 -> RGBColor[
              0.1808905282724361, 0.3074577927092133, 0.9336128200303355], 48 -> 
             RGBColor[
              0.24018804114120323`, 0.3697832384137522, 0.9369897256654027], 
             5 -> RGBColor[
              0.2824395297681887, 0.41419223185981874`, 0.9393958854372335], 
             101 -> RGBColor[
              0.1831002535865883, 0.30978035411906424`, 0.9337386606179808], 
             333 -> RGBColor[
              0.18811264277564865`, 0.31504869296059673`, 0.9340241087671325],
              267 -> RGBColor[
              0.2559867658273416, 0.386388699755884, 0.9378894396641596], 120 -> 
             RGBColor[
              0.5182991743784003, 0.6198176447289311, 0.9552215560809526], 
             147 -> RGBColor[
              0.1834762116557925, 0.31017550988691617`, 0.9337600708738418], 
             89 -> RGBColor[
              0.1892450123424645, 0.31623888517169746`, 0.934088595538772], 
             43 -> RGBColor[
              0.26035980612556775`, 0.3909850423760888, 0.9381384778398102], 
             199 -> RGBColor[
              0.18648980339442428`, 0.3133429858769703, 0.9339316904651475], 
             268 -> RGBColor[
              0.679362894162589, 0.7494427233598264, 0.9686762023490751], 169 -> 
             RGBColor[
              0.8957887014800139, 0.9197416112963568, 0.9899223200988196], 20 -> 
             RGBColor[
              0.19028821830363388`, 0.31733536077996466`, 0.9341480045749757],
              4 -> 
             RGBColor[
              0.23281884209063286`, 0.36203774297739677`, 0.9365700606812258],
              167 -> RGBColor[
              0.3102543804501736, 0.4431484833325346, 0.9409901126684767], 
             142 -> RGBColor[
              0.18248883410320854`, 0.3091377134757978, 0.9337038411829164], 
             16 -> RGBColor[
              0.3177755060429437, 0.4496629042982282, 0.9414693521405777], 
             281 -> RGBColor[
              0.4286879330306734, 0.5457296739343299, 0.9485365939122276], 
             289 -> RGBColor[
              0.1861676814246589, 0.31300441526303435`, 0.9339133460955061], 
             398 -> RGBColor[
              0.4260942433398349, 0.54348315028676, 0.9483713262986371], 178 -> 
             RGBColor[
              0.44169024668361, 0.5569916245052177, 0.9493650898406981], 58 -> 
             RGBColor[
              0.21195870855243037`, 0.3401124200198894, 0.9353821069360272], 
             186 -> RGBColor[
              0.20685160848485196`, 0.33474453404001786`, 0.9350912651424561],
              122 -> RGBColor[
              0.5979628209588992, 0.6844921818293608, 0.9614929701573222], 
             249 -> RGBColor[
              0.3090764058516128, 0.442128180941986, 0.9409150531686984], 113 -> 
             RGBColor[
              0.30752560771325343`, 0.4405592903292892, 0.9408245004646784], 
             52 -> RGBColor[
              0.17936539842637753`, 0.30585478454218845`, 0.9335259661418299],
              187 -> RGBColor[
              0.43492032413853554`, 0.551127857862875, 0.9489337163625334], 
             259 -> RGBColor[
              0.18623692915551526`, 0.3130771990187241, 0.9339172896513356], 
             42 -> RGBColor[
              0.21651396498896067`, 0.34490028335462225`, 0.9356415220511897],
              134 -> RGBColor[
              0.830968185180272, 0.8680554911049849, 0.9837396813881922], 313 -> 
             RGBColor[
              0.218367213855187, 0.3468481654157909, 0.9357470618324852], 248 -> 
             RGBColor[
              0.21799885977606132`, 0.3464610019236322, 0.9357260846126101], 
             174 -> RGBColor[
              0.34399645769565007`, 0.4723741747164527, 0.943140127993611], 
             215 -> RGBColor[
              0.18299643202543156`, 0.30967123107562133`, 0.9337327481336631],
              399 -> RGBColor[
              0.9265760623547111, 0.7466055848528861, 0.2597795801705179], 83 -> 
             RGBColor[
              0.9450344910434499, 0.9585273939347413, 0.9779264487494559], 95 -> 
             RGBColor[
              0.559409915392181, 0.6531931963016955, 0.9584579442071637], 166 -> 
             RGBColor[
              0.9896948922783259, 0.9900065873749687, 0.82044583391943], 384 -> 
             RGBColor[
              0.18955786573703887`, 0.316567713925446, 0.9341064120767679], 
             233 -> RGBColor[
              0.9594063537213845, 0.9692459055881796, 0.9535986340178257], 
             295 -> RGBColor[
              0.4290348579738498, 0.5460301628831548, 0.9485586996628331], 
             141 -> RGBColor[
              0.8655975347340893, 0.482591620368333, 0.20956362728728348`], 
             319 -> RGBColor[
              0.4533617737780597, 0.567098537525015, 0.9501094460321575], 205 -> 
             RGBColor[
              0.3500177192487492, 0.4775894888363419, 0.943523797455382], 224 -> 
             RGBColor[
              0.1793343425625045, 0.3058221428602024, 0.9335241975563253], 
             231 -> RGBColor[
              0.18219295480676673`, 0.3088267255754066, 0.9336869912946982], 
             332 -> RGBColor[
              0.2283446787479909, 0.35733511362593967`, 0.9363152636977938], 
             68 -> RGBColor[
              0.27002626100566185`, 0.40114509934370585`, 0.9386889681449931],
              10 -> RGBColor[
              0.23750097993416716`, 0.3669589667156367, 0.9368367015048129], 
             250 -> RGBColor[
              0.25834749102875554`, 0.38886997162119286`, 0.9380238794720002],
              282 -> RGBColor[
              0.2671426063657563, 0.39811419548290095`, 0.9385247482792353], 
             374 -> RGBColor[
              0.19021908584372046`, 0.31726269818134456`, 0.934144067583656], 
             232 -> RGBColor[
              0.295092829761857, 0.42749165241872045`, 0.9401164721529931], 
             253 -> RGBColor[
              0.19109293756035423`, 0.31818117174092553`, 0.9341938321461705],
              55 -> RGBColor[
              0.9716313250190438, 0.9159679393868991, 0.3442934839840799], 
             325 -> RGBColor[
              0.289139123347183, 0.42123392949010874`, 0.9397774173803968], 
             91 -> RGBColor[
              0.4932978290383352, 0.5995204262840937, 0.953253358592837], 105 -> 
             RGBColor[
              0.20947576509879728`, 0.3375026890224135, 0.9352407069795285], 
             36 -> RGBColor[
              0.19287789451893317`, 0.32005727467719974`, 0.9342954828043544],
              123 -> RGBColor[
              0.21169783120855037`, 0.3398382213908926, 0.9353672503572267], 
             94 -> 
             RGBColor[
              0.18118663655961964`, 0.30776902129339295`, 0.9336296829592377],
              312 -> RGBColor[
              0.3029090080003519, 0.4357069513217019, 0.9405615919406759], 96 -> 
             RGBColor[
              0.7481991240396009, 0.803218109314472, 0.9755371544320737], 2 -> 
             RGBColor[
              0.18498575182454155`, 0.3117621323146461, 0.9338460369532876], 
             262 -> RGBColor[
              0.2141514811516508, 0.34241716305148284`, 0.9355069820916365], 
             272 -> RGBColor[
              0.7409332819620127, 0.7975419782610151, 0.9748129631969344], 97 -> 
             RGBColor[
              0.19288958051724012`, 0.32006955740235543`, 0.93429614830467], 
             372 -> RGBColor[
              0.19406834726399882`, 0.3213085159913272, 0.9343632773270688], 
             356 -> RGBColor[
              0.19499177110397153`, 0.3222790929955916, 0.9344158649486721], 
             346 -> RGBColor[
              0.3510664211934816, 0.47849782175157674`, 0.9435906198159696], 
             341 -> RGBColor[
              0.3362350503435996, 0.46565163376778274`, 0.9426455779802814], 
             209 -> RGBColor[
              0.33484250288537293`, 0.4644454791509371, 0.9425568460876246], 
             378 -> RGBColor[
              0.19081859398490578`, 0.3178928192487419, 0.9341782086854036], 
             66 -> RGBColor[
              0.2142707962291993, 0.34254257076299915`, 0.935513776908792], 
             139 -> RGBColor[
              0.18805967833656198`, 0.31499302397697726`, 0.9340210925206803],
              56 -> RGBColor[
              0.38165040818030865`, 0.5049881340836845, 0.9455394044224124], 
             335 -> RGBColor[
              0.1795029989097729, 0.3059994113746115, 0.9335338022857975], 
             314 -> RGBColor[
              0.23267428983588884`, 0.3618858093925185, 0.936561828644164], 
             144 -> RGBColor[
              0.1905501321581982, 0.3176106488474093, 0.9341629201815262], 
             298 -> RGBColor[
              0.19699767297971368`, 0.3243874230485212, 0.9345300980930298], 
             204 -> RGBColor[
              0.19363457114614188`, 0.3208525897884652, 0.9343385744188711], 
             207 -> RGBColor[
              0.18775722726537172`, 0.31467512872465075`, 0.9340038683796124],
              334 -> RGBColor[
              0.1849809522741401, 0.31175708768286514`, 0.9338457636259925], 
             149 -> RGBColor[
              0.21660346779159745`, 0.34499435647499893`, 0.9356466191033923],
              219 -> 
             RGBColor[
              0.3371253879726633, 0.4664227994724073, 0.9427023095067106], 
             400 -> RGBColor[
              0.8501784807301029, 0.38669936800784144`, 0.19568427585662201`],
              9 -> RGBColor[
              0.19103464530579026`, 0.3181199028854364, 0.9341905124885087], 
             11 -> RGBColor[
              0.31196467996522614`, 0.44462985881031997`, 0.9410990914412173],
              44 -> RGBColor[
              0.2366745638317519, 0.36609035099419096`, 0.9367896383303533], 
             153 -> RGBColor[
              0.1824446187841665, 0.30909124037207153`, 0.9337013231859077], 
             32 -> RGBColor[
              0.9570322462930174, 0.8667218188173162, 0.28757881993815293`], 
             162 -> RGBColor[
              0.27232886945688745`, 0.40356528681975196`, 0.9388200982898864],
              90 -> RGBColor[
              0.6083786689975903, 0.6929482364957771, 0.9623129438694364], 
             331 -> RGBColor[
              0.19914754728651962`, 0.3266470772548782, 0.9346525302543484], 
             8 -> RGBColor[
              0.2378122641398246, 0.36728614615234123`, 0.9368544286798214], 
             364 -> RGBColor[
              0.8176771202476999, 0.13687966915311423`, 0.16456093635363633`],
              342 -> RGBColor[
              0.18371444184961855`, 0.31042590492529404`, 0.9337736377309502],
              163 -> RGBColor[
              0.26679472020223177`, 0.3977485450677799, 0.938504936676874], 
             49 -> RGBColor[
              0.18767785554878408`, 0.3145917040180597, 0.9339993482777726], 
             338 -> RGBColor[
              0.23420030298526878`, 0.3634897459673388, 0.9366487328354871], 
             76 -> RGBColor[
              0.1938965482594379, 0.32112794434484765`, 0.9343534936279129], 
             369 -> RGBColor[
              0.19059767181486464`, 0.3176606160407541, 0.9341656274946448], 
             82 -> RGBColor[
              0.1807265568208277, 0.30728544831718235`, 0.9336034820987404], 
             67 -> RGBColor[
              0.42522253205912725`, 0.5427281177888938, 0.9483157816266544], 
             211 -> RGBColor[
              0.22188954865981286`, 0.3505503626243781, 
               0.9359476535887813]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9l2k4lWvYhs1zWMs8LNZoLbMSqfBetRslSppMScqwSaE2pQyZolBokCJT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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 14}], {
             RGBColor[
             0.18904790384743964`, 0.31603171164602595`, 0.9340773705015762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.18749255911212426`, 0.3143969457146576, 0.9339887959198263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 49}], {
             RGBColor[
             0.19061232216343427`, 0.3176760144859865, 0.9341664618103227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 62}], {
             RGBColor[
             0.19732629313580521`, 0.3247328236682947, 0.9345488125247692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 87}], {
             RGBColor[
             0.19586287681444192`, 0.32319468032858806`, 0.934465473130198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 119}], {
             RGBColor[
             0.18798137752672578`, 0.3149107248612813, 0.9340166334053959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 127}], {
             RGBColor[
             0.19417547404882396`, 0.3214211130344089, 0.9343693780389848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 129}], {
             RGBColor[
             0.19131755276026974`, 0.31841725655746295`, 0.9342066236495172]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 216}], {
             RGBColor[
             0.19662871859939152`, 0.3239996286017438, 0.9345090866868895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 231}], {
             RGBColor[
             0.1878698717924256, 0.3147935252646599, 0.9340102833187854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 235}], {
             RGBColor[
             0.19253038583618232`, 0.3196920210183055, 0.9342756926989647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 298}], {
             RGBColor[
             0.19527223087889906`, 0.32257387400121723`, 0.9344318367179512]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 313}], {
             RGBColor[
             0.20595700131663575`, 0.3338042451848521, 0.935040318587679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 317}], {
             RGBColor[
             0.19445041549410247`, 0.3217100939256911, 0.9343850355475539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 336}], {
             RGBColor[
             0.18695004027347276`, 0.31382672401755374`, 0.9339579002745498]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 361}], {
             RGBColor[
             0.205591391562574, 0.33341996615233593`, 0.9350194976530564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 393}], {
             RGBColor[
             0.1884550205876297, 0.3154085537489959, 0.9340436066770222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 396}], {
             RGBColor[
             0.1965523248147455, 0.3239193338904351, 0.9345047361738683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 97}], {
             RGBColor[
             0.18893766617089083`, 0.31591584485850077`, 0.9340710926289788]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 109}], {
             RGBColor[
             0.1831541470606865, 0.30983699957738503`, 0.9337417297716024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 181}], {
             RGBColor[
             0.1899547149925528, 0.3169848276546873, 0.9341290120547836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 191}], {
             RGBColor[
             0.19610476461646903`, 0.323448919745091, 0.9344792482826825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 193}], {
             RGBColor[
             0.18596534003799042`, 0.3127917416364609, 0.9339018230528726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 211}], {
             RGBColor[
             0.2034376502421772, 0.3311562474695121, 0.9348968452710344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 305}], {
             RGBColor[
             0.18360947068078184`, 0.31031557357129014`, 0.9337676597781759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 334}], {
             RGBColor[
             0.18498335204934083`, 0.3117596099987556, 0.93384590028964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 340}], {
             RGBColor[
             0.19396024281710603`, 0.32119489136342505`, 0.9343571209387445]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 360}], {
             RGBColor[
             0.18511749831467772`, 0.3119006062289892, 0.9338535397209994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 365}], {
             RGBColor[
             0.18295812271216946`, 0.3096309655584321, 0.9337305664749465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 370}], {
             RGBColor[
             0.18603673488354355`, 0.3128667821458319, 0.9339058888837076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 11}], {
             RGBColor[
             0.4469167817161049, 0.5580281285800609, 0.9506625439425702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 21}], {
             RGBColor[
             0.7725354937206939, 0.7794802979389553, 0.6358867741972027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 34}], {
             RGBColor[
             0.4225585018257533, 0.5327236209657705, 0.9492644797482566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 74}], {
             RGBColor[
             0.7224644673916434, 0.782535536200579, 0.9735133143364585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 86}], {
             RGBColor[
             0.49644576954540676`, 0.6009276484384913, 0.9538184872502891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 91}], {
             RGBColor[
             0.5375833562526594, 0.6354734123169479, 0.9567396775183801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 95}], {
             RGBColor[
             0.5706393994295823, 0.6623097973257487, 0.9593419703255434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 160}], {
             RGBColor[
             0.5207461823507223, 0.6218042360373149, 0.9554141935122193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[
             0.42709887646193556`, 0.5374958425847769, 0.9495230473669047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 233}], {
             RGBColor[
             0.7706376185941841, 0.8203361519689907, 0.9569123152308744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 263}], {
             RGBColor[
             0.48691076315351817`, 0.5926689051451934, 0.9532109250744729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 264}], {
             RGBColor[
             0.652580274743898, 0.7275933060781521, 0.9666403041170564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 285}], {
             RGBColor[
             0.7880339609127915, 0.8307135264515318, 0.7851026525209982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 312}], {
             RGBColor[
             0.44238894573366777`, 0.553566674835752, 0.9503937941922995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 348}], {
             RGBColor[
             0.45750426505624076`, 0.5671984745069012, 0.9513371690188597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 13}], {
             RGBColor[
             0.22349076802527734`, 0.3522333457006528, 0.9360388406628528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 66}], {
             RGBColor[
             0.22354481915991609`, 0.35229015687019793`, 0.9360419187950089]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 123}], {
             RGBColor[
             0.2222583366495916, 0.3509379821841447, 0.9359686555192263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 131}], {
             RGBColor[
             0.22303764420255517`, 0.35175708383326204`, 0.9360130359314853]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 140}], {
             RGBColor[
             0.22925899781803233`, 0.3582961209397305, 0.9363673328162189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 183}], {
             RGBColor[
             0.2914028738694214, 0.4198002713108441, 0.9400459473606144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 186}], {
             RGBColor[
             0.2198352252877424, 0.3483911385087073, 0.9358306629118409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 188}], {
             RGBColor[
             0.2173017232473819, 0.34572826723098127`, 0.9356863837186229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 203}], {
             RGBColor[
             0.22928794206914588`, 0.35832654318282237`, 0.9363689811485005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 232}], {
             RGBColor[
             0.26395583592624494`, 0.3947646976980586, 0.9383432664171094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 238}], {
             RGBColor[
             0.26140051176335477`, 0.3920788899859515, 0.9381977444862962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 275}], {
             RGBColor[
             0.235784586016354, 0.3651549278823552, 0.9367389554103707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 280}], {
             RGBColor[
             0.24217745234544014`, 0.3718742357253608, 0.937103019690414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 297}], {
             RGBColor[
             0.2198696831096341, 0.34842735586426754`, 0.9358326252338219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 309}], {
             RGBColor[
             0.2652076930566547, 0.39608047891444564`, 0.9384145578287296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 322}], {
             RGBColor[
             0.21636197354501668`, 0.3447405307102229, 0.9356328663633082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 325}], {
             RGBColor[
             0.26097898271890796`, 0.39163583623375275`, 0.9381737390308114]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 339}], {
             RGBColor[
             0.24218330961780632`, 0.3718803920899902, 0.9371033532534101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 8}], {
             RGBColor[
             0.2601258969540067, 0.39073918900607996`, 0.9381251570585274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 43}], {
             RGBColor[
             0.2713996679468782, 0.4025886371179538, 0.9387671816385219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 56}], {
             RGBColor[
             0.3320449689742487, 0.4595901829717516, 0.9424676449298229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.31447583347960173`, 0.4443726808567142, 0.9413481551518805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 90}], {
             RGBColor[
             0.44540909938288953`, 0.5535702341777979, 0.950854414653335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 100}], {
             RGBColor[
             0.24629351933764826`, 0.37620048310789195`, 0.9373374236164447]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 121}], {
             RGBColor[
             0.2966728547509243, 0.4289526354856623, 0.9402137650898452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 122}], {
             RGBColor[
             0.440201175363544, 0.5493422068445898, 0.9504444277972779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 175}], {
             RGBColor[
             0.282045444074704, 0.41377802280949016`, 0.9393734428399871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 178}], {
             RGBColor[
             0.36206488822589933`, 0.4855919281825182, 0.9443804876389659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 213}], {
             RGBColor[
             0.25252900688278906`, 0.3827543758705798, 0.9376925254075633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 227}], {
             RGBColor[
             0.24495455926499354`, 0.3747931511765599, 0.937261171821121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 274}], {
             RGBColor[
             0.38775900825169696`, 0.5067672930904867, 0.9463159883002454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 296}], {
             RGBColor[
             0.26370004466317304`, 0.39449584486246725`, 0.9383286994830867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 308}], {
             RGBColor[
             0.24197001296398313`, 0.37165620378303305`, 0.9370912063245189]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 319}], {
             RGBColor[
             0.3679006517731242, 0.4906453846924169, 0.9447526657346955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 352}], {
             RGBColor[
             0.26102097459574697`, 0.3916799723587493, 0.9381761304060758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 373}], {
             RGBColor[
             0.27714534160664284`, 0.4086277044311172, 0.939094389253483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 56}], {
             RGBColor[
             0.34361946259808085`, 0.47175570963568103`, 0.9431267952187714]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 79}], {
             RGBColor[
             0.26831622286540857`, 0.39934774083561936`, 0.9385915840026804]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 137}], {
             RGBColor[
             0.32002599977803325`, 0.451320237982877, 0.941623440630758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 169}], {
             RGBColor[
             0.6006886092479335, 0.6791324482420171, 0.965318253056975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 175}], {
             RGBColor[
             0.2936199376985361, 0.4259435494734196, 0.9400325931289355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 178}], {
             RGBColor[
             0.37363938184973156`, 0.4977574548464476, 0.9450396379279142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 252}], {
             RGBColor[
             0.3375773650971563, 0.4665223484650306, 0.9427417981088295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 277}], {
             RGBColor[
             0.2567019144406389, 0.38714036629150045`, 0.9379301663197194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 278}], {
             RGBColor[
             0.28187720037590647`, 0.4136011880147874, 0.9393638616102349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 300}], {
             RGBColor[
             0.6101439916355338, 0.6866719134983721, 0.9662201158700239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 314}], {
             RGBColor[
             0.26913140342587094`, 0.400204547290098, 0.9386380073296472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 319}], {
             RGBColor[
             0.37947514539695637`, 0.5028109113563464, 0.945411816023644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 352}], {
             RGBColor[
             0.27259546821957914`, 0.40384549902267874`, 0.9388352806950242]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 379}], {
             RGBColor[
             0.25634517615934155`, 0.38676541173934353`, 0.9379098506023464]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 65}], {
             RGBColor[
             0.36829577629683624`, 0.4914979419428903, 0.9447588725119885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 67}], {
             RGBColor[
             0.43693392935130804`, 0.5528719414914377, 0.9490620215061302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 68}], {
             RGBColor[
             0.3593357938245753, 0.4820804322688437, 0.9442486147652995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 96}], {
             RGBColor[
             0.5984222253415448, 0.6831169372542267, 0.9626727079088397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 173}], {
             RGBColor[
             0.36556257674898185`, 0.48862517592323496`, 0.9446032208411446]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[
             0.7215884971461117, 0.7768639400824314, 0.7979961077324451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 201}], {
             RGBColor[
             0.698844545732584, 0.7622666344739716, 0.960474027707296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 223}], {
             RGBColor[
             0.6892737381041355, 0.6614040887409706, 0.6061320446993241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 250}], {
             RGBColor[
             0.35349640883612216`, 0.4759428684075872, 0.943916070428803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 387}], {
             RGBColor[
             0.4913856837463006, 0.597841186558023, 0.9531378831854276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 43}], {
             RGBColor[
             0.24908603513269617`, 0.379135594264215, 0.9374964532598158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 56}], {
             RGBColor[
             0.30973133616006665`, 0.43613714011801286`, 0.9411969165511169]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 59}], {
             RGBColor[
             0.2921622006654197, 0.4209196380029755, 0.9400774267731745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 100}], {
             RGBColor[
             0.22397988652346618`, 0.35274744025415317`, 0.9360666952377386]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 121}], {
             RGBColor[
             0.2743592219367422, 0.4054995926319236, 0.9389430367111391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 175}], {
             RGBColor[
             0.2597318112605219, 0.39032497995575144`, 0.938102714461281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 213}], {
             RGBColor[
             0.230215374068607, 0.3593013330168411, 0.9364217970288573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 227}], {
             RGBColor[
             0.22264092645081146`, 0.35134010832282114`, 0.9359904434424149]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 237}], {
             RGBColor[
             0.2175725261235523, 0.3460128982237305, 0.9357018055418038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 296}], {
             RGBColor[
             0.241386411848991, 0.3710428020087285, 0.9370579711043807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 308}], {
             RGBColor[
             0.21965638014980107`, 0.34820316092929426`, 0.9358204779458129]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 352}], {
             RGBColor[
             0.23870734178156489`, 0.36822692950501057`, 0.9369054020273697]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 373}], {
             RGBColor[
             0.2548317087924608, 0.38517466157737845`, 0.937823660874777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 39}], {
             RGBColor[
             0.1871051393828018, 0.3139897430153101, 0.9339667329393776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.2089266760744028, 0.33692556164351994`, 0.9352094371718936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 150}], {
             RGBColor[
             0.19229026561489077`, 0.3194396394412268, 0.9342620182075883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 192}], {
             RGBColor[
             0.1863278971063823, 0.3131728121027866, 0.9339224701415624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 283}], {
             RGBColor[
             0.2000074908485974, 0.3275509324621929, 0.9347015027680361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 294}], {
             RGBColor[
             0.1904972038981096, 0.3175550178902107, 0.9341599059954147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 320}], {
             RGBColor[
             0.1934136507337484, 0.32062038842787655`, 0.9343259933282078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 347}], {
             RGBColor[
             0.19444294915612814`, 0.3217022463310869, 0.9343846103506517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 381}], {
             RGBColor[
             0.19359903145009902`, 0.3208152353145773, 0.9343365504857577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 384}], {
             RGBColor[
             0.19029625552141455`, 0.3173438084054412, 0.9341484622826384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.26166329356975937`, 0.3923550903258115, 0.9382127095214201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 37}], {
             RGBColor[
             0.29314980125126083`, 0.4217462676405007, 0.9401414095988625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 62}], {
             RGBColor[
             0.21930338871384658`, 0.34783214454915645`, 0.9358003756057394]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 87}], {
             RGBColor[
             0.2178399723924833, 0.34629400120944975`, 0.9357170362111682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 155}], {
             RGBColor[
             0.22229114501906733`, 0.3509724658606344, 0.9359705239073323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 170}], {
             RGBColor[
             0.2345826966210814, 0.3638916659237347, 0.936670509587346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 216}], {
             RGBColor[
             0.21860581417743288`, 0.3470989494826055, 0.9357606497678597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 256}], {
             RGBColor[
             0.29440488188335295`, 0.4228333554018322, 0.9402213822269152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 261}], {
             RGBColor[
             0.24873551087533646`, 0.3787671710452084, 0.9374764914219134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 298}], {
             RGBColor[
             0.21724932645694042`, 0.3456731948820789, 0.9356833997989213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 311}], {
             RGBColor[
             0.2701224968687157, 0.40124624933748154`, 0.9386944486350258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 313}], {
             RGBColor[
             0.22793409689467709`, 0.35690356606571383`, 0.9362918816686491]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 361}], {
             RGBColor[
             0.22756848714061534`, 0.35651928703319763`, 0.9362710607340264]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 396}], {
             RGBColor[
             0.21852942039278686`, 0.3470186547712968, 0.9357562992548385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 34}], {
             RGBColor[
             0.28760640007487454`, 0.41932535119602954`, 0.9397010272469036]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 35}], {
             RGBColor[
             0.27410810708868466`, 0.4051377894263376, 0.9389323194302751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 85}], {
             RGBColor[
             0.2763549775912347, 0.40749939278433556`, 0.9390602753814483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 86}], {
             RGBColor[
             0.361493667794528, 0.48752937866875046`, 0.9442550347489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 91}], {
             RGBColor[
             0.40263125450178067`, 0.5220751425472069, 0.9471762250170271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 93}], {
             RGBColor[
             0.2731424573639435, 0.4041228303399058, 0.9388773271070019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 95}], {
             RGBColor[
             0.43568729767870357`, 0.5489115275560077, 0.9497785178241904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 125}], {
             RGBColor[
             0.2867382877276377, 0.41841291007758175`, 0.9396515895329856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 162}], {
             RGBColor[
             0.29214677471105677`, 0.42409757281503596`, 0.9399595948655519]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 211}], {
             RGBColor[
             0.2669271143125195, 0.39759011071734907`, 0.9385233725149993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 214}], {
             RGBColor[
             0.2758548681185897, 0.40697374601981373`, 0.9390317948868268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 248}], {
             RGBColor[
             0.2649817698706437, 0.3955454303669761, 0.9384125880269136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 263}], {
             RGBColor[
             0.35195866140263943`, 0.47927063537545245`, 0.9436474725731201]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 312}], {
             RGBColor[
             0.30743684398278903`, 0.44016840506601096`, 0.9408303416909466]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.313125811057198, 0.4456106195888476, 0.9411739913250522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 17}], {
             RGBColor[
             0.2700762317403779, 0.40119762175422, 0.93869181390441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 22}], {
             RGBColor[
             0.3123757406994519, 0.44496094634460026`, 0.9411261975051177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 47}], {
             RGBColor[
             0.4262898849714413, 0.5411626092696967, 0.9490658048705467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 106}], {
             RGBColor[
             0.2676474114572338, 0.3986447776405352, 0.9385534961824027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 107}], {
             RGBColor[
             0.3285473986430889, 0.45896802364421685`, 0.9421566412492507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 118}], {
             RGBColor[
             0.27367870261090094`, 0.4049840470489852, 0.9388969692911083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 158}], {
             RGBColor[
             0.32361612706914167`, 0.45469680405977975`, 0.941842424985111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 209}], {
             RGBColor[
             0.3216593094784126, 0.45300190701520204`, 0.9417177382985756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 241}], {
             RGBColor[
             0.28584467655013013`, 0.4177712570264148, 0.9395898035090018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 270}], {
             RGBColor[
             0.3337876806083378, 0.46350689249828564`, 0.9424905473822769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 310}], {
             RGBColor[
             0.2940376027932159, 0.42638254196942454`, 0.9400563785381975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 323}], {
             RGBColor[
             0.35358359064672407`, 0.4806531148021672, 0.943751925265087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 324}], {
             RGBColor[
             0.4708028735942141, 0.577300258720949, 0.9525700303913813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 346}], {
             RGBColor[
             0.329771268632467, 0.46002807831552184`, 0.9422346251627481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 390}], {
             RGBColor[
             0.28559351861557547`, 0.41750727411286515`, 0.9395755004361839]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 66}], {
             RGBColor[
             0.21421674509456057`, 0.34248575959345395`, 0.9355106987766358]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 123}], {
             RGBColor[
             0.2129302625842361, 0.3411335849074007, 0.9354374355008532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 131}], {
             RGBColor[
             0.21370957013719966`, 0.34195268655651806`, 0.9354818159131122]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[
             0.2199309237526768, 0.34849172366298653`, 0.9358361127978458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 188}], {
             RGBColor[
             0.20797364918202638`, 0.3359238699542373, 0.9351551637002498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 203}], {
             RGBColor[
             0.21995986800379036`, 0.3485221459060784, 0.9358377611301275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 232}], {
             RGBColor[
             0.2546277618608894, 0.3849603004213146, 0.9378120463987364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 275}], {
             RGBColor[
             0.22645651195099847`, 0.3553505306056112, 0.9362077353919975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 280}], {
             RGBColor[
             0.23284937828008462`, 0.36206983844861684`, 0.9365717996720409]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 297}], {
             RGBColor[
             0.2105416090442786, 0.33862295858752356`, 0.9353014052154489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 309}], {
             RGBColor[
             0.25587961899129924`, 0.38627608163770166`, 0.9378833378103566]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 322}], {
             RGBColor[
             0.20703389947966117`, 0.33493613343347894`, 0.9351016463449351]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 325}], {
             RGBColor[
             0.25165090865355244`, 0.3818314389570088, 0.9376425190124382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 339}], {
             RGBColor[
             0.2328552355524508, 0.3620759948132462, 0.936572133235037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 29}], {
             RGBColor[
             0.18299367418147944`, 0.3096683324067703, 0.9337325910785299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 62}], {
             RGBColor[
             0.1928274082051604, 0.3200042103604074, 0.9342926076834728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 119}], {
             RGBColor[
             0.18348249259608096`, 0.310182111553394, 0.9337604285640995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 126}], {
             RGBColor[
             0.18556762080960376`, 0.31237371351057097`, 0.9338791735311889]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 127}], {
             RGBColor[
             0.18967658911817914`, 0.3166924997265216, 0.9341131731976884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 129}], {
             RGBColor[
             0.18681866782962492`, 0.3136886432495756, 0.9339504188082208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 196}], {
             RGBColor[
             0.18714224683050756`, 0.3140287452955969, 0.9339688461536289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 235}], {
             RGBColor[
             0.1880315009055375, 0.3149634077104182, 0.9340194878576683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 317}], {
             RGBColor[
             0.18995153056345765`, 0.3169814806178038, 0.9341288307062575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 326}], {
             RGBColor[
             0.18828033718868842`, 0.3152249504211414, 0.9340336587158735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 327}], {
             RGBColor[
             0.19007805312865012`, 0.317114463855815, 0.9341360359791719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 336}], {
             RGBColor[
             0.18245115534282794`, 0.3090981107096664, 0.9337016954332534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 396}], {
             RGBColor[
             0.19205343988410067`, 0.31919072058254777`, 0.9342485313325719]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 33}], {
             RGBColor[
             0.28118366953987284`, 0.41287224313372134`, 0.9393243660551096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 37}], {
             RGBColor[
             0.31731211488685307`, 0.44714239125067556`, 0.9415174176154697]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.24346570234943876`, 0.37322826815933124`, 0.9371763836223466]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 92}], {
             RGBColor[
             0.3916080301069964, 0.5102971083648917, 0.9465821312407912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 256}], {
             RGBColor[
             0.31856719551894513`, 0.448229479012007, 0.9415973902435224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 311}], {
             RGBColor[
             0.2942848105043079, 0.4266423729476564, 0.940070456651633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 313}], {
             RGBColor[
             0.25209641053026927`, 0.3822996896758886, 0.9376678896852563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 361}], {
             RGBColor[
             0.2517308007762076, 0.3819154106433724, 0.9376470687506336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 386}], {
             RGBColor[
             0.5232931103169385, 0.6153912271159707, 0.9581889419192983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 69}], {
             RGBColor[
             0.2797958916834022, 0.41057876108804503`, 0.9392759017239116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 106}], {
             RGBColor[
             0.2722971064429795, 0.4026970623499158, 0.9388488569979281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 107}], {
             RGBColor[
             0.33319709362883454`, 0.4630203083535974, 0.9424520020647762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 190}], {
             RGBColor[
             0.6369974104682594, 0.7082659607734624, 0.9502314057905163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 212}], {
             RGBColor[
             0.36755596390986156`, 0.4927802348639901, 0.9446413188967272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 241}], {
             RGBColor[
             0.29049437153587576`, 0.42182354173579545`, 0.9398851643245274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 268}], {
             RGBColor[
             0.49856920010276634`, 0.5995528138290274, 0.9550727772448264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 270}], {
             RGBColor[
             0.3384373755940835, 0.46755917720766627`, 0.9427859081978025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 274}], {
             RGBColor[
             0.4054269963890745, 0.5245026293096915, 0.9473527216519175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 295}], {
             RGBColor[
             0.3734051820083968, 0.4978465335906915, 0.9450140259017055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 310}], {
             RGBColor[
             0.2986872977789616, 0.43043482667880517`, 0.9403517393537228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 324}], {
             RGBColor[
             0.47545256857995977`, 0.5813525434303296, 0.9528653912069069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 351}], {
             RGBColor[
             0.6137824648944775, 0.6902841557450048, 0.9663635368138602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 373}], {
             RGBColor[
             0.29481332974402036`, 0.42636304065032193`, 0.9401311226051551]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 380}], {
             RGBColor[
             0.26894987250182517`, 0.3991789072508731, 0.9386582369767682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 390}], {
             RGBColor[
             0.2902432136013212, 0.4215595588222458, 0.9398708612517093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 22}], {
             RGBColor[
             0.2739758563683775, 0.40460023321935323`, 0.9389393809000012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 48}], {
             RGBColor[
             0.23593219427525336`, 0.3653100735213626, 0.936747361482348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 61}], {
             RGBColor[
             0.22052046256389546`, 0.34911136633249684`, 0.9358696861610002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 118}], {
             RGBColor[
             0.23527881827982655`, 0.36462333392373825`, 0.9367101526859918]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 158}], {
             RGBColor[
             0.2852162427380673, 0.4143360909345327, 0.9396556083799944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 164}], {
             RGBColor[
             0.21631448031938844`, 0.34469061231884324`, 0.9356301616943686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 173}], {
             RGBColor[
             0.25707808713188923`, 0.38753574764073073`, 0.9379515887979883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 209}], {
             RGBColor[
             0.2832594251473382, 0.412641193889955, 0.9395309216934591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 241}], {
             RGBColor[
             0.2474447922190557, 0.37741054390116785`, 0.9374029869038852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 287}], {
             RGBColor[
             0.2108043778715786, 0.3388991452855218, 0.9353163695114319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 323}], {
             RGBColor[
             0.3151837063156497, 0.44029240167692024`, 0.9415651086599703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 346}], {
             RGBColor[
             0.29137138430139253`, 0.41966736519027487`, 0.9400478085576316]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 354}], {
             RGBColor[
             0.2237645258481464, 0.35252108252973663`, 0.9360544307658767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 371}], {
             RGBColor[
             0.20911196002482746`, 0.33712030682309724`, 0.9352199888187673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 388}], {
             RGBColor[
             0.22559527698605156`, 0.35444531805200136`, 0.9361586893348268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 389}], {
             RGBColor[
             0.21716250001380405`, 0.34558193478522814`, 0.9356784551614329]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 45}], {
             RGBColor[
             0.4449748432614876, 0.5535011435034702, 0.9507944263097807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 74}], {
             RGBColor[
             0.7341001698400949, 0.7919819236306536, 0.974429319456183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 86}], {
             RGBColor[
             0.5080814719938581, 0.6103740358685661, 0.9547344923700136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 91}], {
             RGBColor[
             0.5492190587011108, 0.6449197997470224, 0.9576556826381046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 112}], {
             RGBColor[
             0.7711240798821252, 0.7393399357057666, 0.6151558638126768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 141}], {
             RGBColor[
             0.7353689115489879, 0.586455396789142, 0.5858108169853278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 148}], {
             RGBColor[
             0.46955925293009415`, 0.5770080258985608, 0.9522798906351313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 179}], {
             RGBColor[
             0.5295441815391476, 0.6289468481238254, 0.9561068042364651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 232}], {
             RGBColor[
             0.4501165590628717, 0.5589054128143358, 0.9510872394181826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 257}], {
             RGBColor[
             0.46412234198098856`, 0.5722988469015355, 0.9519334554771259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 279}], {
             RGBColor[
             0.638687245246097, 0.7170964540862654, 0.9650118438159424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 285}], {
             RGBColor[
             0.7996696633612428, 0.8401599138816065, 0.7860186576407228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 288}], {
             RGBColor[
             0.45525573629442806`, 0.5643070139273578, 0.9513799079587884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 399}], {
             RGBColor[
             0.7658581753592988, 0.7184623790314186, 0.610918793426945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 185}], {
             RGBColor[
             0.330002266441723, 0.4557835793222022, 0.9424120819002554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 198}], {
             RGBColor[
             0.30685620721234774`, 0.43573562617248035`, 0.9409372354734161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 205}], {
             RGBColor[
             0.30521095643223367`, 0.4343105926394541, 0.9408324015485454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 219}], {
             RGBColor[
             0.2987647907941907, 0.4287272479574868, 0.9404216575742097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 262}], {
             RGBColor[
             0.23727783738368446`, 0.36672442974702457`, 0.9368239938666727]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 284}], {
             RGBColor[
             0.2685014480461575, 0.3995424242445413, 0.938602132302708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 293}], {
             RGBColor[
             0.3046492475878372, 0.4338240686707453, 0.9407966099576801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 331}], {
             RGBColor[
             0.22977587045111889`, 0.35883938684872224`, 0.9363967679480286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 338}], {
             RGBColor[
             0.24730224830049347`, 0.3772607212049526, 0.937394869238598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.1986384662361157, 0.32611200079330077`, 0.9346235388416457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 36}], {
             RGBColor[
             0.19158305641128354`, 0.3186963177285822, 0.934221743689665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 80}], {
             RGBColor[
             0.18504810846190303`, 0.31182767309415216`, 0.933849588071537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 151}], {
             RGBColor[
             0.19115376674236922`, 0.3182451070680162, 0.9341972962780976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 168}], {
             RGBColor[
             0.18724662483160132`, 0.31413845319269396`, 0.9339747903263778]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 265}], {
             RGBColor[
             0.19013547399899927`, 0.31717481683124543`, 0.9341393060127917]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 291}], {
             RGBColor[
             0.18873168488737596`, 0.31569934546955897`, 0.9340593622996046]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 304}], {
             RGBColor[
             0.185589373288035, 0.312396576744589, 0.9338804123026556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 378}], {
             RGBColor[
             0.19055340614426983`, 0.31761409001435326`, 0.9341631066301896]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 383}], {
             RGBColor[
             0.1993210537450841, 0.3268294435437743, 0.9346624111904838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 24}], {
             RGBColor[
             0.8919944774662327, 0.5241583098068742, 0.2395431849721498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 25}], {
             RGBColor[
             0.890260551987202, 0.5108305987640545, 0.23788277597524127`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 27}], {
             RGBColor[
             0.8921201702935075, 0.5251244399562564, 0.23966354856549787`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 32}], {
             RGBColor[
             0.9601171751337108, 0.8771280081727125, 0.29956318594431774`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 78}], {
             RGBColor[
             0.8915698412637564, 0.5208943698778701, 0.23913655286510038`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 95}], {
             RGBColor[
             0.7613060096832925, 0.7703636969149021, 0.6350027480788232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 104}], {
             RGBColor[
             0.8911056135339068, 0.5173261121203578, 0.23869200786672617`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 160}], {
             RGBColor[
             0.7114127926044326, 0.7298581356264684, 0.631074971265499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 172}], {
             RGBColor[
             0.8935026650840421, 0.5357509007293852, 0.24098742713821833`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 208}], {
             RGBColor[
             0.9781086897296334, 0.9394569243444684, 0.5384830216306559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 217}], {
             RGBColor[
             0.9781358461419554, 0.9375595363156388, 0.3992965964312667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 230}], {
             RGBColor[
             0.8904702103094787, 0.5124421245019355, 0.2380835450214286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 233}], {
             RGBColor[
             0.9613042288478943, 0.9283900515581442, 0.6325730929841542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 240}], {
             RGBColor[
             0.8974455137213154, 0.5660573631227573, 0.24476310344608182`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 242}], {
             RGBColor[
             0.907737765098039, 0.6451681172975665, 0.25461897498786773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 244}], {
             RGBColor[
             0.9589837634229517, 0.9266594522436353, 0.6365010356742713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 264}], {
             RGBColor[
             0.8432468849976082, 0.8356472056673055, 0.6423010818703361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 285}], {
             RGBColor[
             0.9787005711665018, 0.9387674260406853, 0.4607634302742779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 357}], {
             RGBColor[
             0.910151296596057, 0.6637195780075789, 0.25693017547606367`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 47}], {
             RGBColor[
             0.4301895095994409, 0.5445652207348299, 0.9493133718661378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.27823170323432733`, 0.40907339811174287`, 0.9391817450830557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 96}], {
             RGBColor[
             0.5322372446835262, 0.6257908335621027, 0.9584554594663912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 118}], {
             RGBColor[
             0.2775783272389005, 0.4083866585141185, 0.9391445362866995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 158}], {
             RGBColor[
             0.3275157516971413, 0.458099415524913, 0.9420899919807021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 173}], {
             RGBColor[
             0.2993775960909632, 0.43129907223111097`, 0.940385972398696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 209}], {
             RGBColor[
             0.32555893410641223`, 0.4564045184803353, 0.9419653052941668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 241}], {
             RGBColor[
             0.28974430117812966`, 0.42117386849154814`, 0.9398373705045929]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 310}], {
             RGBColor[
             0.2979372274212155, 0.4297851534345578, 0.9403039455337885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 323}], {
             RGBColor[
             0.35748321527472365`, 0.48405572626730053`, 0.943999492260678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 346}], {
             RGBColor[
             0.3336708932604665, 0.46343068978065516`, 0.9424821921583393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 354}], {
             RGBColor[
             0.2660640348072204, 0.3962844071201169, 0.9384888143665844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 388}], {
             RGBColor[
             0.26789478594512556`, 0.39820864264238165`, 0.9385930729355345]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 75}], {
             RGBColor[
             0.255511442446525, 0.3858891047454028, 0.9378623707008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 120}], {
             RGBColor[
             0.40567769043424073`, 0.5225843384798207, 0.9476110227757661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 132}], {
             RGBColor[
             0.32566481114992, 0.45504559524241234`, 0.9420251663053016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 160}], {
             RGBColor[
             0.3763398438622711, 0.4987665529777692, 0.9453014400255476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 202}], {
             RGBColor[
             0.2682077809117381, 0.39923376146669465`, 0.9385854083938443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 220}], {
             RGBColor[
             0.46443936234214256`, 0.5702897109178078, 0.9522369568394528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 229}], {
             RGBColor[
             0.24996961512608984`, 0.38006429285947896`, 0.9375467718333002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 260}], {
             RGBColor[
             0.2588190028871956, 0.3893655604799919, 0.938050731374799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 307}], {
             RGBColor[
             0.32070535665531497`, 0.4507499650286162, 0.9417091542503788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 321}], {
             RGBColor[
             0.42370887427578074`, 0.5372228658179581, 0.9490305036181749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 341}], {
             RGBColor[
             0.3146456284168403, 0.44550133299924655`, 0.9413230337254305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 348}], {
             RGBColor[
             0.3130979265677895, 0.44416079144735543`, 0.9412244155321879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 366}], {
             RGBColor[
             0.34372780451171075`, 0.47069085221995155`, 0.9431761242698371]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.8209125437853362, 0.16174855223502174`, 0.16765918158716517`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 32}], {
             RGBColor[
             0.8889095486255394, 0.5137521204514779, 0.227558818965985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 73}], {
             RGBColor[
             0.8757010840349191, 0.46170115302421727`, 0.21528423867768243`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.8419234511371824, 0.5272135480684979, 0.5771697251114055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 78}], {
             RGBColor[
             0.8203622147555851, 0.15751848215663547`, 0.1671321858867677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 104}], {
             RGBColor[
             0.8198979870257355, 0.15395022439912315`, 0.1666876408883935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 112}], {
             RGBColor[
             0.8789473611792127, 0.4745715601436108, 0.21789626946789925`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 141}], {
             RGBColor[
             0.8431921928460754, 0.3216870212269862, 0.1885512226405503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 172}], {
             RGBColor[
             0.8222950385758708, 0.17237501300815056`, 0.16898306015988562`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 208}], {
             RGBColor[
             0.906901063221462, 0.5760810366232336, 0.4664786546523232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 240}], {
             RGBColor[
             0.8262378872131442, 0.20268147540152273`, 0.17275873646774914`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 242}], {
             RGBColor[
             0.8365301385898678, 0.28179222957633193`, 0.182614608009535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 243}], {
             RGBColor[
             0.8951565236421906, 0.5687878448594291, 0.5520035990795774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 285}], {
             RGBColor[
             0.9074929446583304, 0.5753915383194507, 0.38875906329594523`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 337}], {
             RGBColor[
             0.9074168352108218, 0.5752287479070755, 0.3804750196277067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 357}], {
             RGBColor[
             0.8389436700878857, 0.3003436902863443, 0.184925808497731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 399}], {
             RGBColor[
             0.8736814566563863, 0.4536940034692628, 0.2136591990821675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 32}], {
             RGBColor[
             0.8871756231465087, 0.5004244094086581, 0.22589840996907645`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 78}], {
             RGBColor[
             0.8186282892765544, 0.1441907711138157, 0.16547177688985915`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 83}], {
             RGBColor[
             0.881176745521725, 0.5463271969673706, 0.5710722243747279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 194}], {
             RGBColor[
             0.9059253338243674, 0.5624195574854407, 0.4052009770396422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 201}], {
             RGBColor[
             0.8831813824108397, 0.5478222518769809, 0.567678897014493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 217}], {
             RGBColor[
             0.9051942941547533, 0.5608559375515845, 0.32563182045602546`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 223}], {
             RGBColor[
             0.8736105747823911, 0.4469597061439798, 0.21333691400652116`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 230}], {
             RGBColor[
             0.8175286583222767, 0.13573852573788114`, 0.16441876904618735`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 242}], {
             RGBColor[
             0.8347962131108371, 0.26846451853351216`, 0.18095419901262647`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 244}], {
             RGBColor[
             0.8860422114357496, 0.549955853479581, 0.56283625969903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 245}], {
             RGBColor[
             0.8180745277590571, 0.13993431743048723`, 0.16494149423531956`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 328}], {
             RGBColor[
             0.8434248781398908, 0.3172892303900453, 0.1885318018785458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 357}], {
             RGBColor[
             0.837209744608855, 0.2870159792435245, 0.18326539950082243`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 364}], {
             RGBColor[
             0.81749806012385, 0.1355033345765571, 0.16438946817681815`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 385}], {
             RGBColor[
             0.9058721590894482, 0.562305822104239, 0.3994132353001115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 105}], {
             RGBColor[
             0.19823757833601402`, 0.32569064219253296`, 0.9346007088687955]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 128}], {
             RGBColor[
             0.19080558249119994`, 0.3178791433438807, 0.9341774677000858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 159}], {
             RGBColor[
             0.18375580691440718`, 0.3104693822310835, 0.9337759934101959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 171}], {
             RGBColor[
             0.18798107467478986`, 0.3149104065446947, 0.9340166161584262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 215}], {
             RGBColor[
             0.18499791179933114`, 0.3117749132191369, 0.9338467294458628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 218}], {
             RGBColor[
             0.188929981383257, 0.31590776765945394`, 0.9340706549916917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 342}], {
             RGBColor[
             0.18535691671142462`, 0.3121522501439733, 0.9338671742445064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 349}], {
             RGBColor[
             0.19449252215171758`, 0.32175435069256086`, 0.9343874334594139]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 353}], {
             RGBColor[
             0.1885101327336185, 0.315466480108742, 0.9340467452322052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 32}], {
             RGBColor[
             0.8890352414528142, 0.5147182506008601, 0.2276791825593331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 73}], {
             RGBColor[
             0.8758267768621938, 0.46266728317359945`, 0.2154046022710305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 74}], {
             RGBColor[
             0.8420491439644571, 0.52817967821788, 0.5772900887047536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 78}], {
             RGBColor[
             0.8204879075828598, 0.15848461230601768`, 0.16725254948011575`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 104}], {
             RGBColor[
             0.8200236798530103, 0.15491635454850536`, 0.16680800448174155`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 112}], {
             RGBColor[
             0.8790730540064875, 0.47553769029299303`, 0.21801663306124733`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 141}], {
             RGBColor[
             0.8433178856733501, 0.32265315137636846`, 0.18867158623389835`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 172}], {
             RGBColor[
             0.8224207314031455, 0.17334114315753277`, 0.1691034237532337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 208}], {
             RGBColor[
             0.9070267560487368, 0.5770471667726158, 0.46659901824567124`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 225}], {
             RGBColor[
             0.8528742555567694, 0.5368113283617635, 0.5783225975121196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 240}], {
             RGBColor[
             0.8263635800404189, 0.20364760555090494`, 0.1728791000610972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 243}], {
             RGBColor[
             0.8952822164694654, 0.5697539750088114, 0.5521239626729255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 285}], {
             RGBColor[
             0.9076186374856052, 0.576357668468833, 0.38887942688929333`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 337}], {
             RGBColor[
             0.9075425280380967, 0.5761948780564576, 0.3805953832210548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 357}], {
             RGBColor[
             0.8390693629151604, 0.3013098204357265, 0.18504617209107904`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 399}], {
             RGBColor[
             0.873807149483661, 0.45466013361864505`, 0.21377956267551557`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 36}], {
             RGBColor[
             0.19993330434376533`, 0.3274729577419183, 0.9346972779563351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 151}], {
             RGBColor[
             0.19950401467485102`, 0.3270217470813523, 0.9346728305447676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 168}], {
             RGBColor[
             0.19559687276408316`, 0.32291509320603007`, 0.9344503245930478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 265}], {
             RGBColor[
             0.1984857219314811, 0.32595145684458154`, 0.9346148402794617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 267}], {
             RGBColor[
             0.23148773999796957`, 0.36063867028126045`, 0.9364942563862377]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 282}], {
             RGBColor[
             0.2370656602671769, 0.3665014181447689, 0.9368119106937756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 291}], {
             RGBColor[
             0.1970819328198578, 0.3244759854828951, 0.9345348965662746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 304}], {
             RGBColor[
             0.1939396212205168, 0.3211732167579251, 0.9343559465693256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 378}], {
             RGBColor[
             0.19890365407675165`, 0.32639073002768937`, 0.9346386408968597]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 383}], {
             RGBColor[
             0.20767130167756592`, 0.3356060835571104, 0.9351379454571538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.19127206346984504`, 0.31836944442903903`, 0.934204033101723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 87}], {
             RGBColor[
             0.18980864714848175`, 0.31683130108933233`, 0.9341206937071518]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 119}], {
             RGBColor[
             0.18192714786076558`, 0.30854734562202557`, 0.9336718539823496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 127}], {
             RGBColor[
             0.18812124438286376`, 0.3150577337951532, 0.9340245986159385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 129}], {
             RGBColor[
             0.18526332309430954`, 0.3120538773182072, 0.933861844226471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 231}], {
             RGBColor[
             0.1818156421264654, 0.3084301460254042, 0.9336655038957391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 235}], {
             RGBColor[
             0.18647615617022215`, 0.31332864177904984`, 0.9339309132759184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 317}], {
             RGBColor[
             0.1883961858281423, 0.3153467146864354, 0.9340402561245076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 326}], {
             RGBColor[
             0.18672499245337307`, 0.31359018448977305`, 0.9339450841341236]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 327}], {
             RGBColor[
             0.18852270839333474`, 0.31547969792444663`, 0.934047461397422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 336}], {
             RGBColor[
             0.18089581060751259`, 0.30746334477829806`, 0.9336131208515035]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 396}], {
             RGBColor[
             0.19049809514878532`, 0.31755595465117936`, 0.9341599567508221]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 54}], {
             RGBColor[
             0.1824115228296057, 0.3090564544254234, 0.9336994384202565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 63}], {
             RGBColor[
             0.18069605079375822`, 0.30725338454853857`, 0.9336017448256284]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 224}], {
             RGBColor[
             0.17977250803868983`, 0.30628268255696894`, 0.9335491504319864]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 297}], {
             RGBColor[
             0.19356559882175525`, 0.3207800955024369, 0.9343346465470327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 318}], {
             RGBColor[
             0.18730055861877407`, 0.31419514102261215`, 0.9339778617757692]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 345}], {
             RGBColor[
             0.1795989351746539, 0.30610024647171197`, 0.9335392657141575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 81}], {
             RGBColor[
             0.1880171511030766, 0.3149483251582018, 0.9340186706576468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 106}], {
             RGBColor[
             0.21164758701888683`, 0.33978541156189057`, 0.935364389024955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 164}], {
             RGBColor[
             0.19871454021211585`, 0.32619195936544565`, 0.9346278711420376]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 192}], {
             RGBColor[
             0.18904880805086632`, 0.3160326620211572, 0.9340774219946237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 241}], {
             RGBColor[
             0.22984485211178313`, 0.3589118909477702, 0.9364006963515542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 271}], {
             RGBColor[
             0.18778814176396494`, 0.3147076218227647, 0.9340056289145733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 287}], {
             RGBColor[
             0.19320443776430601`, 0.3204004923321242, 0.9343140789591009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 292}], {
             RGBColor[
             0.19543097961487327`, 0.32274072898797734`, 0.9344408772236172]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 371}], {
             RGBColor[
             0.1915120199175549, 0.31862165386969954`, 0.9342176982664363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 374}], {
             RGBColor[
             0.1933477765192394, 0.32055115045176114`, 0.9343222418891437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 382}], {
             RGBColor[
             0.18918398084593196`, 0.3161747371992214, 0.9340851198853325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 384}], {
             RGBColor[
             0.19301716646589862`, 0.32020365832381187`, 0.9343034141356996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 389}], {
             RGBColor[
             0.19956255990653143`, 0.3270832818318305, 0.9346761646091019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 78}], {
             RGBColor[
             0.888484912423063, 0.5104881805224738, 0.22715218685893562`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 104}], {
             RGBColor[
             0.8880206846932135, 0.5069199227649615, 0.22670764186056142`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 172}], {
             RGBColor[
             0.8904177362433487, 0.5253447113739889, 0.22900306113205354`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 194}], {
             RGBColor[
             0.9757819569708761, 0.9287169668940988, 0.4668813870087187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 208}], {
             RGBColor[
             0.97502376088894, 0.929050734989072, 0.526498655624491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 217}], {
             RGBColor[
             0.975050917301262, 0.9271533469602427, 0.3873122304251019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 223}], {
             RGBColor[
             0.9434671979288998, 0.8132571155526379, 0.27501732397559764`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 230}], {
             RGBColor[
             0.8873852814687854, 0.5020359351465393, 0.22609917901526383`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 240}], {
             RGBColor[
             0.8943605848806221, 0.5556511737673611, 0.23277873743991706`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 242}], {
             RGBColor[
             0.9046528362573457, 0.6347619279421703, 0.24263460898170292`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 357}], {
             RGBColor[
             0.9070663677553636, 0.6533133886521827, 0.2449458094698989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 364}], {
             RGBColor[
             0.8873546832703587, 0.5018007439852152, 0.22606987814589463`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 385}], {
             RGBColor[
             0.9757287822359568, 0.928603231512897, 0.461093645269188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 387}], {
             RGBColor[
             0.7455791435710649, 0.7496942133696903, 0.622023162461701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 92}], {
             RGBColor[
             0.3869660924415177, 0.5054181375626268, 0.9463177797578736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 182}], {
             RGBColor[
             0.3125367270389322, 0.44214783260778046`, 0.9412445628049322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 256}], {
             RGBColor[
             0.3139252578534664, 0.443350508209742, 0.9413330387606047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 281}], {
             RGBColor[
             0.3526148324525338, 0.4768614731328931, 0.9437983042422098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 311}], {
             RGBColor[
             0.28964287283882917`, 0.4217634021453914, 0.9398061051687154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 35}], {
             RGBColor[
             0.24974982719833305`, 0.3798332818120472, 0.9375342552359615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 85}], {
             RGBColor[
             0.25199669770088307`, 0.3821948851700452, 0.9376622111871347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 86}], {
             RGBColor[
             0.3371353879041764, 0.46222487105446, 0.9428569705546225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 91}], {
             RGBColor[
             0.37827297461142906`, 0.4967706349329164, 0.9457781608227135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 93}], {
             RGBColor[
             0.24878417747359188`, 0.37881832272561544`, 0.9374792629126882]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 95}], {
             RGBColor[
             0.41132901778835196`, 0.5236070199417173, 0.9483804536298768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 125}], {
             RGBColor[
             0.2623800078372861, 0.3931084024632914, 0.9382535253386719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 162}], {
             RGBColor[
             0.2677884948207052, 0.39879306520074553`, 0.9385615306712383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 211}], {
             RGBColor[
             0.2425688344221679, 0.3722856031030586, 0.9371253083206856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 214}], {
             RGBColor[
             0.25149658822823806`, 0.38166923840552336`, 0.9376337306925131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 248}], {
             RGBColor[
             0.24062348998029212`, 0.37024092275268566`, 0.9370145238326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 263}], {
             RGBColor[
             0.3276003815122878, 0.45396612776116196`, 0.9422494083788064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 340}], {
             RGBColor[
             0.23309142699709673`, 0.3623242469969716, 0.9365855839883956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 42}], {
             RGBColor[
             0.22638274960055194`, 0.35527300169848874`, 0.9362035347352613]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 85}], {
             RGBColor[
             0.2384984047146932, 0.36800732340035325`, 0.9368935033705061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 86}], {
             RGBColor[
             0.32363709491798653`, 0.44803730928476804`, 0.942088262737994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 93}], {
             RGBColor[
             0.235285884487402, 0.3646307609559235, 0.9367105550960597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 97}], {
             RGBColor[
             0.21457055736469166`, 0.3428576387223553, 0.9355308478620015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 98}], {
             RGBColor[
             0.21863346925867172`, 0.3471280167264209, 0.9357622246838242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 125}], {
             RGBColor[
             0.24888171485109623`, 0.37892084069359944`, 0.9374848175220434]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 162}], {
             RGBColor[
             0.25429020183451534`, 0.3846055034310536, 0.9377928228546097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 211}], {
             RGBColor[
             0.22907054143597805`, 0.35809804133336665`, 0.9363566005040571]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 214}], {
             RGBColor[
             0.23799829524204824`, 0.3674816766358314, 0.9368650228758846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 248}], {
             RGBColor[
             0.22712519699410227`, 0.3560533609829937, 0.9362458160159715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 263}], {
             RGBColor[
             0.31410208852609794`, 0.43977856599147, 0.9414807005621779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 340}], {
             RGBColor[
             0.21959313401090685`, 0.34813668522727964`, 0.9358168761717671]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 80}], {
             RGBColor[
             0.1863429465695527, 0.31318863004276976`, 0.9339233271862263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 151}], {
             RGBColor[
             0.19244860485001886`, 0.3196060640166337, 0.9342710353927868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 168}], {
             RGBColor[
             0.18854146293925098`, 0.3154994101413115, 0.9340485294410671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 265}], {
             RGBColor[
             0.1914303121066489, 0.318535773779863, 0.934213045127481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 277}], {
             RGBColor[
             0.20034660319217895`, 0.3279073610362615, 0.9347208147143313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 304}], {
             RGBColor[
             0.18688421139568462`, 0.3137575336932065, 0.933954151417345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 378}], {
             RGBColor[
             0.1918482442519195, 0.31897504696297085`, 0.934236845744879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 383}], {
             RGBColor[
             0.20061589185273376`, 0.3281904004923918, 0.9347361503051731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 41}], {
             RGBColor[
             0.6103348144421008, 0.6886019294831773, 0.9655435733376975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 114}], {
             RGBColor[
             0.2950446149939596, 0.4237378370222073, 0.9402493164383834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 170}], {
             RGBColor[
             0.29023151793817503`, 0.41867896684859873`, 0.9399752176813956]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 187}], {
             RGBColor[
             0.39185947335344506`, 0.5138307132141199, 0.9461899170277228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 206}], {
             RGBColor[
             0.5395559184345032, 0.6328895346269106, 0.9586002858977685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 256}], {
             RGBColor[
             0.3500537032004466, 0.4776206563266962, 0.9435260903209648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 261}], {
             RGBColor[
             0.30438433219243016`, 0.43355447197007246`, 0.940781199515963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 311}], {
             RGBColor[
             0.3257713181858094, 0.4560335502623456, 0.9419991567290754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 361}], {
             RGBColor[
             0.28321730845770904`, 0.41130658795806163`, 0.939575768828076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 53}], {
             RGBColor[
             0.2076634431002256, 0.3355978236940631, 0.9351374979228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 58}], {
             RGBColor[
             0.2174442667054725, 0.3458780894432118, 0.935694501357687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 102}], {
             RGBColor[
             0.25020060979959846`, 0.3803070829072448, 0.9375599266382304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 103}], {
             RGBColor[
             0.20863860950919683`, 0.3366227854190133, 0.9351930322071614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 117}], {
             RGBColor[
             0.22453541604736282`, 0.35333133700637476`, 0.9360983318222922]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 145}], {
             RGBColor[
             0.21009367554414693`, 0.338152152078261, 0.9352758960652745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 189}], {
             RGBColor[
             0.24478652953490182`, 0.3746165412765333, 0.9372516027765698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 222}], {
             RGBColor[
             0.22765792346573496`, 0.35661329028148886`, 0.9362761540004327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 254}], {
             RGBColor[
             0.20508861754811766`, 0.3328915187854286, 0.9349908654167205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 303}], {
             RGBColor[
             0.21808265414273661`, 0.3465490751158777, 0.9357308565778295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 376}], {
             RGBColor[
             0.21626586560617583`, 0.3446395151729059, 0.9356273931583702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 150}], {
             RGBColor[
             0.1883607596919023, 0.31530947957110045`, 0.9340382386584571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 237}], {
             RGBColor[
             0.19025421078354665`, 0.3172996167201517, 0.9341460678970164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 251}], {
             RGBColor[
             0.18672478342346222`, 0.3135899647860835, 0.9339450722301794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 283}], {
             RGBColor[
             0.19607798492560893`, 0.3234207725920666, 0.934477723218905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 294}], {
             RGBColor[
             0.18656769797512113`, 0.31342485802008435`, 0.9339361264462835]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 320}], {
             RGBColor[
             0.18948414481075992`, 0.3164902285577502, 0.9341022137790767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 347}], {
             RGBColor[
             0.19051344323313968`, 0.3175720864609606, 0.9341608308015206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 381}], {
             RGBColor[
             0.18966952552711056`, 0.31668507544445096`, 0.9341127709366266]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 51}], {
             RGBColor[
             0.4513189432678153, 0.5634921655168925, 0.9504868403154272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 84}], {
             RGBColor[
             0.42994887224450423`, 0.5449824840875006, 0.9491251582866337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 102}], {
             RGBColor[
             0.39926565859510593`, 0.5155146756656562, 0.9472759248895897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 134}], {
             RGBColor[
             0.6760140538149009, 0.745057217744171, 0.9695892868351288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 163}], {
             RGBColor[
             0.3939273213258807, 0.5099037447255685, 0.9469719144794696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 167}], {
             RGBColor[
             0.4156571514498516, 0.5326037138579458, 0.948214502475271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 174}], {
             RGBColor[
             0.4325281900725898, 0.5472165595499049, 0.9492895101378381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 183}], {
             RGBColor[
             0.43552341404886974`, 0.5498108720138242, 0.9494803631610341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 189}], {
             RGBColor[
             0.3938515783304093, 0.5098241340349448, 0.9469676010279292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 226}], {
             RGBColor[
             0.48315013418370223`, 0.5910627432060597, 0.9525150956533707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 234}], {
             RGBColor[
             0.653391331063141, 0.7272953937118065, 0.9673580250213626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 246}], {
             RGBColor[
             0.7206526383610699, 0.7806508133791874, 0.9738469548784772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 269}], {
             RGBColor[
             0.6323207129287618, 0.7108348666826005, 0.9652579027218493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 272}], {
             RGBColor[
             0.6309966022057711, 0.7098004613221861, 0.9651259277394999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 350}], {
             RGBColor[
             0.7574551958384235, 0.806891984810095, 0.8535080309341501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 355}], {
             RGBColor[
             0.6433835290110301, 0.7194772226865849, 0.9663605408410356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 392}], {
             RGBColor[
             0.7560719179586157, 0.8063199638581745, 0.8764325252109648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 395}], {
             RGBColor[
             0.494849422028799, 0.60078007937222, 0.9533755056767188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 55}], {
             RGBColor[
             0.9217511656674453, 0.9083191148939446, 0.6659672564832814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 83}], {
             RGBColor[
             0.9084527486796484, 0.9295988421678656, 0.9827837388659694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.684630729662244, 0.7517566465973935, 0.970608286963019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 135}], {
             RGBColor[
             0.9333566323648748, 0.9460233638065111, 0.83381543555314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 156}], {
             RGBColor[
             0.8514284367030327, 0.5699234098578776, 0.5824732181712974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 165}], {
             RGBColor[
             0.8843102751860701, 0.9105890257431475, 0.9888274975519911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 187}], {
             RGBColor[
             0.6533956652271913, 0.7258990741319324, 0.9682873726725081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 206}], {
             RGBColor[
             0.8010921103082493, 0.8449578955447232, 0.9806977415425538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 245}], {
             RGBColor[
             0.8453505309169804, 0.5232059626309822, 0.576653008726561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 256}], {
             RGBColor[
             0.6115898950741928, 0.6896890172445088, 0.9656235459657501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 311}], {
             RGBColor[
             0.5873075100595555, 0.6681019111801583, 0.9640966123738608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 328}], {
             RGBColor[
             0.8707008812978143, 0.7005608755905404, 0.6002433163697872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 386}], {
             RGBColor[
             0.8163158098721861, 0.8568507653484726, 0.982215097641526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 400}], {
             RGBColor[
             0.861024743522975, 0.6436848292044157, 0.5916626524195524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 45}], {
             RGBColor[
             0.2506616815740248, 0.3807916985758058, 0.9375861839936894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 93}], {
             RGBColor[
             0.22541709987581074`, 0.35425804261205696`, 0.936148542411988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 98}], {
             RGBColor[
             0.20876468464708048`, 0.33675529838255447`, 0.9352002119997525]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 125}], {
             RGBColor[
             0.23901293023950498`, 0.3685481223497329, 0.9369228048379719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 139}], {
             RGBColor[
             0.20228682166276132`, 0.3299466536657998, 0.934831307285935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 148}], {
             RGBColor[
             0.27524609124263133`, 0.40429858097089644`, 0.9390716483190401]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 204}], {
             RGBColor[
             0.20507426806755127`, 0.33287643657154375`, 0.9349900482350304]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 248}], {
             RGBColor[
             0.21725641238251098`, 0.34568064263912723`, 0.9356838033318999]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 275}], {
             RGBColor[
             0.2276321474655179, 0.3565861980709679, 0.9362746860953526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 276}], {
             RGBColor[
             0.2196855450649306, 0.3482338151042579, 0.9358221388445839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 288}], {
             RGBColor[
             0.26094257460696524`, 0.39159756899969334`, 0.938171665642697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 290}], {
             RGBColor[
             0.20736560396252507`, 0.33528477587624783`, 0.9351205364245214]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 318}], {
             RGBColor[
             0.2054522043558168, 0.33327367157305554`, 0.9350115711475404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 56}], {
             RGBColor[
             0.3210051071529382, 0.44798658822988663`, 0.9418389411311112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 59}], {
             RGBColor[
             0.3034359716582913, 0.4327690861148492, 0.9407194513531689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[
             0.434369237561579, 0.5419666394359329, 0.9502257108546233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 121}], {
             RGBColor[
             0.28563299292961386`, 0.4173490407437973, 0.9395850612911336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 122}], {
             RGBColor[
             0.42916131354223347`, 0.5377386121027248, 0.9498157239985662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 175}], {
             RGBColor[
             0.2710055822533935, 0.4021744280676252, 0.9387447390412754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 213}], {
             RGBColor[
             0.2414891450614786, 0.3711507811287148, 0.9370638216088516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 227}], {
             RGBColor[
             0.23391469744368304`, 0.36318955643469497`, 0.9366324680224093]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 237}], {
             RGBColor[
             0.22884629711642387`, 0.3578623463356042, 0.9363438301217982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 274}], {
             RGBColor[
             0.3767191464303865, 0.4951636983486218, 0.9456872845015338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 296}], {
             RGBColor[
             0.2526601828418626, 0.38289225012060224`, 0.937699995684375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 308}], {
             RGBColor[
             0.23093015114267265`, 0.3600526090411681, 0.9364625025258073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 373}], {
             RGBColor[
             0.2661054797853324, 0.3970241096892522, 0.9384656854547713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 380}], {
             RGBColor[
             0.2402420225431372, 0.36983997628980336`, 0.9369927998263845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 46}], {
             RGBColor[
             0.2189840028439955, 0.34749644974970917`, 0.9357821870529404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 65}], {
             RGBColor[
             0.2623103948909678, 0.393035234842995, 0.9382495609843622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 68}], {
             RGBColor[
             0.25335041241870687`, 0.38361772516894843`, 0.9377393032376733]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 113}], {
             RGBColor[
             0.27210008577250266`, 0.4033248206617401, 0.9388070693975159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 149}], {
             RGBColor[
             0.22663901581167467`, 0.355542353734595, 0.9362181287168728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 161}], {
             RGBColor[
             0.2180648213930185, 0.34653033176526227`, 0.9357298410291143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 195}], {
             RGBColor[
             0.2192614298530921, 0.3477880431261581, 0.9357979861106919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 247}], {
             RGBColor[
             0.2171512777998561, 0.34557013952683935`, 0.9356778160729503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 249}], {
             RGBColor[
             0.27287548484168234`, 0.4041092659680885, 0.9388523457495259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 250}], {
             RGBColor[
             0.24751102743025372`, 0.3774801613076919, 0.9374067589011768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 266}], {
             RGBColor[
             0.23471345152571355`, 0.36402909761884283`, 0.9366779558857301]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 315}], {
             RGBColor[
             0.22776027402374388`, 0.3567208672073564, 0.9362819827132973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 316}], {
             RGBColor[
             0.23551418105696653`, 0.3648707151253743, 0.9367235562479619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 358}], {
             RGBColor[
             0.21372519899594036`, 0.3419691134779814, 0.9354827059534967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 362}], {
             RGBColor[
             0.21291981933663207`, 0.3411226083920287, 0.9354368407733515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 363}], {
             RGBColor[
             0.22828771928123268`, 0.35727524561493795`, 0.9363120199404259]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 369}], {
             RGBColor[
             0.21363611782330827`, 0.34187548351747254`, 0.9354776329124991]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 372}], {
             RGBColor[
             0.21537145554787535`, 0.3436994334927591, 0.9355764578287111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 66}], {
             RGBColor[
             0.2495400971941441, 0.37961284227999426`, 0.9375223114224907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 91}], {
             RGBColor[
             0.38905361359871204`, 0.5081017700405416, 0.9463921022645131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 123}], {
             RGBColor[
             0.24825361468381962`, 0.37826066759394095`, 0.9374490481467079]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 140}], {
             RGBColor[
             0.25525427585226035`, 0.38561880634952683`, 0.9378477254437005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 148}], {
             RGBColor[
             0.30939380782769543`, 0.44018999619208, 0.9410163102615399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 179}], {
             RGBColor[
             0.3693787364367489, 0.49212881841734446`, 0.9448432238628737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 203}], {
             RGBColor[
             0.2552832201033739, 0.38564922859261863`, 0.9378493737759823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 232}], {
             RGBColor[
             0.28995111396047296`, 0.4220873831078549, 0.9398236590445912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 257}], {
             RGBColor[
             0.30395689687858984`, 0.4354808171950546, 0.9406698751035344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 275}], {
             RGBColor[
             0.261779864050582, 0.3924776132921515, 0.9382193480378523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 276}], {
             RGBColor[
             0.2538332616499947, 0.38412523032544144`, 0.9377668007870836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 279}], {
             RGBColor[
             0.4785218001436983, 0.5802784243797845, 0.9537482634423509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 280}], {
             RGBColor[
             0.26817273037966816`, 0.3991969211351571, 0.9385834123178955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 288}], {
             RGBColor[
             0.29509029119202934`, 0.4274889842208769, 0.9401163275851969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 297}], {
             RGBColor[
             0.2458649611438621, 0.37575004127406386`, 0.9373130178613036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 325}], {
             RGBColor[
             0.2869742607531359, 0.4189585216435491, 0.9396541316582929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 339}], {
             RGBColor[
             0.26817858765203434`, 0.39920307749978645`, 0.9385837458808918]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 149}], {
             RGBColor[
             0.20894845482391827`, 0.3369484524901131, 0.9352106774394597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 153}], {
             RGBColor[
             0.1918690303202028, 0.3189968944386494, 0.9342380294807175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 161}], {
             RGBColor[
             0.20037426040526207`, 0.3279364305207805, 0.9347223897517012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 184}], {
             RGBColor[
             0.19220194755564052`, 0.3193468115612663, 0.9342569886247687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 195}], {
             RGBColor[
             0.2015708688653357, 0.3291941418816762, 0.9347905348332788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 247}], {
             RGBColor[
             0.1994607168120997, 0.32697623828235756`, 0.9346703647955372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 250}], {
             RGBColor[
             0.22982046644249732`, 0.3588862600632101, 0.9363993076237638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 315}], {
             RGBColor[
             0.21006971303598748`, 0.3381269659628746, 0.9352745314358842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 343}], {
             RGBColor[
             0.19165716183089215`, 0.31877420722314587`, 0.9342259638836825]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 356}], {
             RGBColor[
             0.1981426064801053, 0.32559082075040946`, 0.9345953003620997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 358}], {
             RGBColor[
             0.19603463800818394`, 0.3233752122334996, 0.9344752546760837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 362}], {
             RGBColor[
             0.19522925834887567`, 0.3225287071475469, 0.9344293894959386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 363}], {
             RGBColor[
             0.21059715829347625`, 0.33868134437045616`, 0.9353045686630128]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 369}], {
             RGBColor[
             0.19594555683555187`, 0.3232815822729907, 0.934470181635086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 372}], {
             RGBColor[
             0.19768089456011895`, 0.32510553224827726`, 0.934569006551298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.6461513889555156, 0.7219924964871992, 0.9663950668318202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.44142989596913074`, 0.5543010784500094, 0.9500295993461311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 173}], {
             RGBColor[
             0.41329174036295263`, 0.5275007351562074, 0.948325579764125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 201}], {
             RGBColor[
             0.7465737093465549, 0.8011421937069441, 0.9641963866302764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 209}], {
             RGBColor[
             0.43947307837840166`, 0.5526061814054317, 0.9499049126595958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 323}], {
             RGBColor[
             0.4713973595467131, 0.580257389192397, 0.951939099626107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 346}], {
             RGBColor[
             0.44758503753245593`, 0.5596323527057516, 0.9504217995237683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 61}], {
             RGBColor[
             0.22477630942984533`, 0.3535845312248864, 0.9361120503440548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 68}], {
             RGBColor[
             0.2551071510734325, 0.38546416887872903`, 0.937839346905198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 118}], {
             RGBColor[
             0.23953466514577643`, 0.3690964988161278, 0.9369525168690463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 173}], {
             RGBColor[
             0.2613339339978391, 0.3920089125331203, 0.938193952981043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 176}], {
             RGBColor[
             0.2369284794639835, 0.36635723242284735`, 0.9368040984499744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 209}], {
             RGBColor[
             0.2875152720132881, 0.41711435878234465`, 0.9397732858765137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 344}], {
             RGBColor[
             0.21571874970997718`, 0.3440644616768498, 0.9355962357174672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 354}], {
             RGBColor[
             0.22802037271409625`, 0.35699424742212627`, 0.9362967949489314]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 388}], {
             RGBColor[
             0.2298511238520014, 0.358918482944391, 0.9364010535178815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 52}], {
             RGBColor[
             0.1835216269875808, 0.31022324428012404`, 0.9337626572098012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 62}], {
             RGBColor[
             0.19439182652115503`, 0.3216485132003679, 0.9343816989922191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.19292841019979173`, 0.32011036986066127`, 0.934298359597648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 127}], {
             RGBColor[
             0.19124100743417377`, 0.3183368025664821, 0.9342022645064347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[
             0.18838308614561955`, 0.31533294608953616`, 0.9340395101169672]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 133}], {
             RGBColor[
             0.18673252269027052`, 0.31359809924619686`, 0.933945512969975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 199}], {
             RGBColor[
             0.18708382947160418`, 0.313967344947515, 0.93396551937146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 216}], {
             RGBColor[
             0.19369425198474133`, 0.320915318133817, 0.9343419731543394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 231}], {
             RGBColor[
             0.1849354051777754, 0.31170921479673314`, 0.9338431697862355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 235}], {
             RGBColor[
             0.18959591922153213`, 0.31660771055037873`, 0.9341085791664148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 298}], {
             RGBColor[
             0.19233776426424887`, 0.31948956353329044`, 0.9342647231854012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 313}], {
             RGBColor[
             0.20302253470198556`, 0.3307199347169253, 0.9348732050551289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 361}], {
             RGBColor[
             0.2026569249479238, 0.33033565568440915`, 0.9348523841205063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 393}], {
             RGBColor[
             0.1855205539729795, 0.3123242432810691, 0.9338764931444723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 396}], {
             RGBColor[
             0.1936178582000953, 0.3208350234225083, 0.9343376226413184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.18052420551329257`, 0.307072764263149, 0.9335919584911282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 147}], {
             RGBColor[
             0.18125622821196816`, 0.30784216653237684`, 0.9336336461008872]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 164}], {
             RGBColor[
             0.18999442899880858`, 0.3170265695932755, 0.9341312737086882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 271}], {
             RGBColor[
             0.17906803055065768`, 0.3055422320505946, 0.933509031481224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 287}], {
             RGBColor[
             0.18448432655099875`, 0.31123510255995407`, 0.9338174815257515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 371}], {
             RGBColor[
             0.1827919087042476, 0.30945626409752947`, 0.9337211008330868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 391}], {
             RGBColor[
             0.18008156514952903`, 0.3066075211758136, 0.9335667507772396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 84}], {
             RGBColor[
             0.36020789306278994`, 0.48641570522103605`, 0.9441731063199956]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 102}], {
             RGBColor[
             0.32952467941339164`, 0.45694789679919157`, 0.9423238729229517]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 134}], {
             RGBColor[
             0.6062730746331866, 0.6864904388777064, 0.9646372348684907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 163}], {
             RGBColor[
             0.3241863421441664, 0.4513369658591039, 0.9420198625128315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 167}], {
             RGBColor[
             0.3459161722681373, 0.47403693499148125`, 0.9432624505086329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 174}], {
             RGBColor[
             0.3627872108908755, 0.4886497806834403, 0.9443374581712001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 183}], {
             RGBColor[
             0.36578243486715545`, 0.4912440931473596, 0.9445283111943961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 189}], {
             RGBColor[
             0.324110599148695, 0.45125735516848015`, 0.9420155490612911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 222}], {
             RGBColor[
             0.3069819930795281, 0.4332541041734357, 0.9410401002851541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 226}], {
             RGBColor[
             0.41340915500198794`, 0.532495964339595, 0.9475630436867326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 234}], {
             RGBColor[
             0.5836503518814267, 0.668728614845342, 0.9624059730547245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 238}], {
             RGBColor[
             0.3357800727610889, 0.463522711822467, 0.942680108320078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 246}], {
             RGBColor[
             0.6509116591793556, 0.7220840345127228, 0.9688949029118392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 269}], {
             RGBColor[
             0.5625797337470475, 0.652268087816136, 0.9603058507552114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 272}], {
             RGBColor[
             0.5612556230240568, 0.6512336824557214, 0.9601738757728618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 350}], {
             RGBColor[
             0.6877142166567092, 0.7483252059436304, 0.8485559789675121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 355}], {
             RGBColor[
             0.5736425498293158, 0.6609104438201203, 0.9614084888743977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 392}], {
             RGBColor[
             0.6863309387769014, 0.7477531849917098, 0.8714804732443268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 395}], {
             RGBColor[
             0.4251084428470847, 0.5422133005057554, 0.9484234537100807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 89}], {
             RGBColor[
             0.18430520538442102`, 0.31104683485694296`, 0.933807280840301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 128}], {
             RGBColor[
             0.18698858591777334`, 0.3138672379336487, 0.9339600953919696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 133}], {
             RGBColor[
             0.18257629412906723`, 0.3092296395082612, 0.9337088219020035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 199}], {
             RGBColor[
             0.1829276009104009, 0.30959888520957934`, 0.9337288283034887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 299}], {
             RGBColor[
             0.18351379325327066`, 0.3102150105286766, 0.9337622110902213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 342}], {
             RGBColor[
             0.18153992013799802`, 0.30814034473374124`, 0.9336498019363901]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 393}], {
             RGBColor[
             0.18136432541177624`, 0.30795578354313347`, 0.9336398020765009]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 58}], {
             RGBColor[
             0.20217788494718347`, 0.3298321542707407, 0.9348251035011402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 64}], {
             RGBColor[
             0.18652020523185484`, 0.31337494013569756`, 0.9339334218048136]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 117}], {
             RGBColor[
             0.20926903428907379`, 0.33728540183390365`, 0.9352289339657456]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 126}], {
             RGBColor[
             0.1894916420221746, 0.31649810860229766`, 0.9341026407341755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 289}], {
             RGBColor[
             0.18928237138329773`, 0.3162781518923132, 0.9340907230808797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 303}], {
             RGBColor[
             0.20281627238444755`, 0.3305031399434066, 0.9348614587212829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 376}], {
             RGBColor[
             0.20099948384788677`, 0.3285935800004348, 0.9347579953018235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 63}], {
             RGBColor[
             0.18289690010848875`, 0.3095666167202264, 0.9337270799382376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 66}], {
             RGBColor[
             0.19944158418676777`, 0.3269561286800552, 0.9346692752208288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 204}], {
             RGBColor[
             0.18912347164523904`, 0.31611113819278824`, 0.9340816739758684]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 224}], {
             RGBColor[
             0.18197335735342035`, 0.3085959147286568, 0.9336744855445955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 290}], {
             RGBColor[
             0.19141480754021284`, 0.3185194774974923, 0.9342121621653594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 297}], {
             RGBColor[
             0.19576644813648575`, 0.3230933276741248, 0.9344599816596418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 318}], {
             RGBColor[
             0.18950140793350456`, 0.31650837319430003`, 0.9341031968883784]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 345}], {
             RGBColor[
             0.1817997844893844, 0.30841347864339985`, 0.9336646008267666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 92}], {
             RGBColor[
             0.7345108890138425, 0.7594054710903482, 0.6489345144638174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 135}], {
             RGBColor[
             0.9832367917164733, 0.9536721882994657, 0.5121416630539384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 156}], {
             RGBColor[
             0.9013085960546312, 0.5775722343508322, 0.2607994456720959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.9341904345376686, 0.918237850236102, 0.6671537250527897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 221}], {
             RGBColor[
             0.9369698505827507, 0.7826274582869746, 0.292244768605455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 245}], {
             RGBColor[
             0.8952306902685789, 0.5308547871239369, 0.2549792362273595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 255}], {
             RGBColor[
             0.9034963603733146, 0.5943883495886708, 0.2628944512543936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 328}], {
             RGBColor[
             0.9205810406494127, 0.7082097000834948, 0.27856954387058575`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 386}], {
             RGBColor[
             0.8661959692237846, 0.8644995898414272, 0.6605413251423246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 400}], {
             RGBColor[
             0.9109049028745734, 0.6513336536973703, 0.2699888799203509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 59}], {
             RGBColor[
             0.3640812726856617, 0.4897706319686471, 0.9444199146444701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 90}], {
             RGBColor[
             0.4950145385889495, 0.5989681852897308, 0.9539261741459244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 121}], {
             RGBColor[
             0.3462782939569843, 0.4743505865975952, 0.9432855245824346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 122}], {
             RGBColor[
             0.48980661456960395`, 0.5947401579565226, 0.9535161872898672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 137}], {
             RGBColor[
             0.35805694536026106`, 0.48455266243088047`, 0.9440360498343989]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 166}], {
             RGBColor[
             0.6856726502293173, 0.7474973607293266, 0.8829926191709212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 169}], {
             RGBColor[
             0.6387195548301612, 0.7123648726900207, 0.967730862260616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 175}], {
             RGBColor[
             0.331650883280764, 0.45917597392142306`, 0.9424452023325764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 178}], {
             RGBColor[
             0.4116703274319593, 0.5309898792944511, 0.9474522471315552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 213}], {
             RGBColor[
             0.30213444608884904`, 0.4281523269825127, 0.9407642849001527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 274}], {
             RGBColor[
             0.43736444745775693`, 0.5521652442024196, 0.9493877477928349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 278}], {
             RGBColor[
             0.3199081459581343, 0.44683361246279085`, 0.9417764708138758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 296}], {
             RGBColor[
             0.313305483869233, 0.43989379597440015`, 0.9414004589756761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 319}], {
             RGBColor[
             0.4175060909791842, 0.5360433358043497, 0.9478244252272849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 352}], {
             RGBColor[
             0.31062641380180694`, 0.4370779234706822, 0.9412478898986653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 76}], {
             RGBColor[
             0.20578868678679324`, 0.33362733594223004`, 0.9350307333242034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.2782593236768137, 0.4070163756656283, 0.939259698655848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 102}], {
             RGBColor[
             0.24757611002741542`, 0.37754856724378383`, 0.937410465258804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 144}], {
             RGBColor[
             0.20411547873617336`, 0.33186868819351084`, 0.93493544660101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 163}], {
             RGBColor[
             0.24223777275819017`, 0.37193763630369614`, 0.9371064548486839]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 167}], {
             RGBColor[
             0.2639676028821611, 0.3946376054360735, 0.9383490428444853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 174}], {
             RGBColor[
             0.28083864150489934`, 0.40925045112803254`, 0.9394240505070525]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 186}], {
             RGBColor[
             0.21226621689950026`, 0.3404356307898151, 0.9353996190814751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 188}], {
             RGBColor[
             0.20973271485913975`, 0.33777275951208907`, 0.9352553398882568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 189}], {
             RGBColor[
             0.24216202976271878`, 0.3718580256130724, 0.9371021413971435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 222}], {
             RGBColor[
             0.22503342369355192`, 0.35385477461802795`, 0.9361266926210063]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 228}], {
             RGBColor[
             0.21063806848440092`, 0.33872434357497383`, 0.9353068984378649]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 238}], {
             RGBColor[
             0.2538315033751126, 0.3841233822670593, 0.9377667006559303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 333}], {
             RGBColor[
             0.2028967340448986, 0.3305877102501046, 0.9348660408938132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 368}], {
             RGBColor[
             0.20142644533340448`, 0.3290423435926357, 0.9347823101267909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 117}], {
             RGBColor[
             0.2190498578943207, 0.34756566758305235`, 0.9357859374006325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 289}], {
             RGBColor[
             0.19906319498854463`, 0.3265584176414619, 0.9346477265157667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 303}], {
             RGBColor[
             0.21259709598969448`, 0.3407834056925553, 0.9354184621561699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 376}], {
             RGBColor[
             0.2107803074531337, 0.33887384574958357`, 0.9353149987367104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 90}], {
             RGBColor[
             0.47744540309430256`, 0.5837506831746934, 0.9528066843679821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 121}], {
             RGBColor[
             0.3287091584623374, 0.4591330844825578, 0.9421660348044922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 122}], {
             RGBColor[
             0.472237479074957, 0.5795226558414852, 0.9523966975119249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 175}], {
             RGBColor[
             0.314081747786117, 0.4439584718063857, 0.9413257125546342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 178}], {
             RGBColor[
             0.3941011919373124, 0.5157723771794137, 0.9463327573536129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 213}], {
             RGBColor[
             0.2845653105942021, 0.4129348248674753, 0.9396447951222104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 274}], {
             RGBColor[
             0.41979531196311004`, 0.5369477420873823, 0.9482682580148925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 296}], {
             RGBColor[
             0.2957363483745861, 0.42467629385936273`, 0.9402809691977339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 319}], {
             RGBColor[
             0.3999369554845372, 0.5208258336893123, 0.9467049354493426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 373}], {
             RGBColor[
             0.3091816453180559, 0.4388081534280127, 0.9410466589681301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.18336573314646784`, 0.31005938996887394`, 0.9337537792861741]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 101}], {
             RGBColor[
             0.18455258152934814`, 0.31130684286981486`, 0.9338213685457943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.18529719032077357`, 0.3120894739205271, 0.933863772914916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 259}], {
             RGBColor[
             0.18612091931381164`, 0.3129552653196448, 0.9339106830624717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 331}], {
             RGBColor[
             0.19257622837931382`, 0.31974020443772183`, 0.9342783033639781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 335}], {
             RGBColor[
             0.18275395419094043`, 0.3094163714975885, 0.9337189393797027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 394}], {
             RGBColor[
             0.18321858514836378`, 0.3099047280931446, 0.933745399425368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 118}], {
             RGBColor[
             0.22412293343441853`, 0.3528977916272621, 0.9360748415476985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 130}], {
             RGBColor[
             0.19568837198846437`, 0.3230112646922406, 0.9344555353385153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 147}], {
             RGBColor[
             0.19642039468713995`, 0.32378066696146846`, 0.9344972229482744]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 164}], {
             RGBColor[
             0.2051585954739804, 0.3329650700223671, 0.9349948505560753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 173}], {
             RGBColor[
             0.24592220228648118`, 0.3758102053442546, 0.937316277659695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 176}], {
             RGBColor[
             0.2215167477526256, 0.3501585252339816, 0.9359264231286265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 344}], {
             RGBColor[
             0.20030701799861927`, 0.32786575448798405`, 0.9347185603961192]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 354}], {
             RGBColor[
             0.21260864100273835`, 0.3407955402332605, 0.9354191196275834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 371}], {
             RGBColor[
             0.19795607517941943`, 0.3253947645266211, 0.934584677680474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 388}], {
             RGBColor[
             0.2144393921406435, 0.3427197757555252, 0.9355233781965335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 87}], {
             RGBColor[
             0.1996423811721627, 0.3271671790429695, 0.9346807103120945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 119}], {
             RGBColor[
             0.1917608818844465, 0.31888322357566273`, 0.9342318705872924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 127}], {
             RGBColor[
             0.1979549784065447, 0.32539361174879033`, 0.9345846152208812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 129}], {
             RGBColor[
             0.19509705711799047`, 0.3223897552718444, 0.9344218608314138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 216}], {
             RGBColor[
             0.2004082229571123, 0.32797212731612524`, 0.934724323868786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 231}], {
             RGBColor[
             0.19164937615014635`, 0.31876602397904136`, 0.934225520500682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 235}], {
             RGBColor[
             0.1963098901939031, 0.32366451973268695`, 0.9344909298808612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 298}], {
             RGBColor[
             0.19905173523661984`, 0.32654637271559867`, 0.9346470738998478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 313}], {
             RGBColor[
             0.20973650567435648`, 0.3377767438992335, 0.9352555557695754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 317}], {
             RGBColor[
             0.19822991985182326`, 0.32568259264007254`, 0.9346002727294505]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 336}], {
             RGBColor[
             0.19072954463119351`, 0.31779922273193517`, 0.9341731374564464]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 361}], {
             RGBColor[
             0.20937089592029476`, 0.33739246486671737`, 0.9352347348349528]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 393}], {
             RGBColor[
             0.19223452494535048`, 0.31938105246337734`, 0.9342588438589188]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 396}], {
             RGBColor[
             0.20033182917246628`, 0.3278918326048165, 0.934719973355765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 98}], {
             RGBColor[
             0.19109841618892076`, 0.3181869301269141, 0.9341941441459625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 139}], {
             RGBColor[
             0.18462055320460163`, 0.31137828541015944`, 0.9338252394321449]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 204}], {
             RGBColor[
             0.18740799960939158`, 0.3143080683159034, 0.9339839803812403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 224}], {
             RGBColor[
             0.1802578853175729, 0.30679284485177194`, 0.9335767919499673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 290}], {
             RGBColor[
             0.18969933550436535`, 0.3167164076206075, 0.9341144685707314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 318}], {
             RGBColor[
             0.18778593589765713`, 0.3147053033174152, 0.9340055032937504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 345}], {
             RGBColor[
             0.18008431245353695`, 0.306610408766515, 0.9335669072321386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 77}], {
             RGBColor[
             0.18172630335562523`, 0.308336245312846, 0.9336604161849047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 94}], {
             RGBColor[
             0.1809149928406964, 0.30748350652159806`, 0.9336142132513059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 254}], {
             RGBColor[
             0.1839453796797469, 0.3106686352270631, 0.9337867892987342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 289}], {
             RGBColor[
             0.18340551527321602`, 0.3101012035064188, 0.9337560448194401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 68}], {
             RGBColor[
             0.2789862434779228, 0.41056260901775243`, 0.9391992258916821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 173}], {
             RGBColor[
             0.2852130264023293, 0.4171073526721437, 0.9395538319675272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 176}], {
             RGBColor[
             0.26080757186847375`, 0.39145567256187075`, 0.9381639774364586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 250}], {
             RGBColor[
             0.2731468584894696, 0.40442504515649597`, 0.9388666815551856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 363}], {
             RGBColor[
             0.25392355034044856`, 0.38422012946374207`, 0.9377719425944349]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 123}], {
             RGBColor[
             0.21298431371887483`, 0.3411903960769459, 0.9354405136330093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 131}], {
             RGBColor[
             0.2137636212718384, 0.34200949772606326`, 0.9354848940452685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 140}], {
             RGBColor[
             0.21998497488731555`, 0.3485485348325317, 0.9358391909300019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 203}], {
             RGBColor[
             0.2200139191384291, 0.3485789570756236, 0.9358408392622837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 232}], {
             RGBColor[
             0.25468181299552817`, 0.38501711159085983`, 0.9378151245308926]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 257}], {
             RGBColor[
             0.268687595913645, 0.3984105456780595, 0.9386613405898359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 275}], {
             RGBColor[
             0.22651056308563722`, 0.3554073417751564, 0.9362108135241538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 280}], {
             RGBColor[
             0.23290342941472336`, 0.362126649618162, 0.936574877804197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 297}], {
             RGBColor[
             0.21059566017891732`, 0.33867976975706876`, 0.935304483347605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 318}], {
             RGBColor[
             0.20433061997593613`, 0.33209481527724394`, 0.9349476985763416]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 322}], {
             RGBColor[
             0.2070879506142999, 0.33499294460302415`, 0.9351047244770914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 325}], {
             RGBColor[
             0.2517049597881912, 0.3818882501265539, 0.9376455971445944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 339}], {
             RGBColor[
             0.23290928668708955`, 0.3621328059827914, 0.9365752113671932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 113}], {
             RGBColor[
             0.36637406988619037`, 0.4916437040590915, 0.9445701410456664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 124}], {
             RGBColor[
             0.3674760832994186, 0.49271104629414053`, 0.9446362289748654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 194}], {
             RGBColor[
             0.709877099853931, 0.7667201163798876, 0.7972498678529694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 208}], {
             RGBColor[
             0.7091189037719949, 0.7670538844748609, 0.8568671364687419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 210}], {
             RGBColor[
             0.365438140563206, 0.4906599829992886, 0.9445168412553058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 249}], {
             RGBColor[
             0.36714946895537004`, 0.49242814936543994`, 0.9446154173976764]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 266}], {
             RGBColor[
             0.3289874356394012, 0.4523479810161943, 0.9424410275338806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 293}], {
             RGBColor[
             0.3870584168095417, 0.509672279343909, 0.9458839979501529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 316}], {
             RGBColor[
             0.32978816517065423`, 0.4531895985227258, 0.9424866278961124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 385}], {
             RGBColor[
             0.7098239251190117, 0.7666063809986858, 0.7914621261134387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 387}], {
             RGBColor[
             0.4796742864541198, 0.5876973628554791, 0.9523916433059518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 161}], {
             RGBColor[
             0.23474066997997348`, 0.36405770594001974`, 0.9366795059364341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 173}], {
             RGBColor[
             0.2762530439300684, 0.40768984299809713`, 0.9390435742208383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 176}], {
             RGBColor[
             0.2518475893962128, 0.38203816288782416`, 0.9376537196897696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 250}], {
             RGBColor[
             0.2641868760172087, 0.3950075354824494, 0.9383564238084967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 363}], {
             RGBColor[
             0.24496356786818765`, 0.3748026197896954, 0.9372616848477457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 106}], {
             RGBColor[
             0.23431749208343802`, 0.36361291913973265`, 0.936655406581262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 107}], {
             RGBColor[
             0.2952174792692931, 0.42393616514341426`, 0.9402585516481101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 150}], {
             RGBColor[
             0.217681081623926, 0.3461269969374395, 0.9357079876169566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 212}], {
             RGBColor[
             0.32957634955032006`, 0.4536960916538069, 0.9424478684800611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 270}], {
             RGBColor[
             0.300457761234542, 0.4284750339974831, 0.9405924577811364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 283}], {
             RGBColor[
             0.22539830685763262`, 0.3542382899584056, 0.9361474721774046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 294}], {
             RGBColor[
             0.2158880199071448, 0.3442423753864234, 0.935605875404783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 295}], {
             RGBColor[
             0.3354255676488553, 0.4587623903805083, 0.9428205754850394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 320}], {
             RGBColor[
             0.21880446674278364`, 0.34730774592408925`, 0.9357719627375762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 347}], {
             RGBColor[
             0.21983376516516337`, 0.34838960382729967`, 0.9358305797600202]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 373}], {
             RGBColor[
             0.25683371538447886`, 0.38727889744013877`, 0.937937672188489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 380}], {
             RGBColor[
             0.2309702581422837, 0.36009476404068996`, 0.9364647865601021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 381}], {
             RGBColor[
             0.21898984745913425`, 0.34750259281079, 0.9357825198951262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 390}], {
             RGBColor[
             0.2522635992417797, 0.3824754156120626, 0.9376774108350432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 108}], {
             RGBColor[
             0.2395346657598989, 0.3690964994616095, 0.9369525169040198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 152}], {
             RGBColor[
             0.2398425593336916, 0.3694201151292457, 0.9369700509875596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 154}], {
             RGBColor[
             0.21421417432422896`, 0.3424830575508392, 0.9355105523750686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 180}], {
             RGBColor[
             0.24072957206270523`, 0.3703524217472943, 0.9370205650502591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 198}], {
             RGBColor[
             0.2881120186842996, 0.4160342955793074, 0.9398697816662858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 236}], {
             RGBColor[
             0.23684558512377027`, 0.36627010521547854`, 0.9367993777399305]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 262}], {
             RGBColor[
             0.2185336488556363, 0.3470230991538516, 0.9357565400595423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 267}], {
             RGBColor[
             0.23945129119348169`, 0.3690088675060522, 0.9369477688458039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 284}], {
             RGBColor[
             0.24975725951810934`, 0.3798410936513683, 0.9375346784955776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 286}], {
             RGBColor[
             0.20888058953085603`, 0.33687712176419665`, 0.9352068126114177]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 332}], {
             RGBColor[
             0.22563024765380635`, 0.35448207444108004`, 0.936160680862621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 72}], {
             RGBColor[
             0.18087056047954858`, 0.30743680529285733`, 0.9336116828940703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 88}], {
             RGBColor[
             0.1851982028892632, 0.3119854318538441, 0.9338581357271303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 138}], {
             RGBColor[
             0.18058969715831197`, 0.30714160013447456`, 0.9335956881434259]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 157}], {
             RGBColor[
             0.18316059011768585`, 0.3098437716388048, 0.933742096694167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 365}], {
             RGBColor[
             0.17992874679989868`, 0.30644689940110903`, 0.9335580479983027]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 88}], {
             RGBColor[
             0.18714176336881175`, 0.31402823714670136`, 0.9339688186212005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 109}], {
             RGBColor[
             0.18206833162796426`, 0.3086957387129193, 0.933679894189029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 157}], {
             RGBColor[
             0.1851041505972344, 0.3118865769316621, 0.9338527795882372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 181}], {
             RGBColor[
             0.1888688995598306, 0.3158435667902215, 0.9340671764722099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 191}], {
             RGBColor[
             0.19501894918374685`, 0.32230765888062524`, 0.934417412700109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 365}], {
             RGBColor[
             0.18187230727944725`, 0.30848970469396636`, 0.9336687308923729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 370}], {
             RGBColor[
             0.18495091945082137`, 0.31172552128136616`, 0.9338440533011341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 78}], {
             RGBColor[
             0.8752764478324426, 0.45843721309521324`, 0.21487760657063304`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 99}], {
             RGBColor[
             0.9481261161147958, 0.8682562660194123, 0.6030407890629428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 104}], {
             RGBColor[
             0.874812220102593, 0.4548689553377009, 0.21443306157225883`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 112}], {
             RGBColor[
             0.9338615942560703, 0.7754902910821886, 0.2656416901517646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 141}], {
             RGBColor[
             0.898106425922933, 0.622605752165564, 0.23629664332441563`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 172}], {
             RGBColor[
             0.8772092716527284, 0.4732937439467283, 0.21672848084375096`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 177}], {
             RGBColor[
             0.912733918365472, 0.8408075046276462, 0.6264313427993702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 208}], {
             RGBColor[
             0.9618152962983195, 0.8769997675618114, 0.5142240753361885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 225}], {
             RGBColor[
             0.9076627958063523, 0.836763929150959, 0.6259476546026368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 240}], {
             RGBColor[
             0.8811521202900017, 0.5036002063401005, 0.22050415715161448`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 243}], {
             RGBColor[
             0.9500707567190481, 0.8697065757980069, 0.5997490197634427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 285}], {
             RGBColor[
             0.9624071777351879, 0.8763102692580285, 0.43650448397981056`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 337}], {
             RGBColor[
             0.9623310682876794, 0.8761474788456531, 0.428220440311572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 399}], {
             RGBColor[
             0.9285956897332439, 0.7546127344078406, 0.2614046197660328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 86}], {
             RGBColor[
             0.6370413534700665, 0.7120367862892685, 0.9671058051428245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 91}], {
             RGBColor[
             0.6781789401773193, 0.7465825501677249, 0.9700269954109155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 95}], {
             RGBColor[
             0.7112349833542422, 0.7734189351765257, 0.9726292882180788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 104}], {
             RGBColor[
             0.8410345872048564, 0.5203813503819814, 0.5763185480059819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 112}], {
             RGBColor[
             0.9000839613583336, 0.841002686126469, 0.6275271765854877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 141}], {
             RGBColor[
             0.8643287930251963, 0.6881181472098445, 0.5981821297581387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 148}], {
             RGBColor[
             0.5985191344063026, 0.6786707763192633, 0.9646512034079422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 172}], {
             RGBColor[
             0.8434316387549917, 0.5388061389910088, 0.578613967277474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 179}], {
             RGBColor[
             0.6585040630153561, 0.7306095985445278, 0.968478117009276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 240}], {
             RGBColor[
             0.8473744873922651, 0.569112601384381, 0.5823896435853375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 263}], {
             RGBColor[
             0.627506347078178, 0.7037780429959705, 0.9664982429670084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 279}], {
             RGBColor[
             0.7676471267223055, 0.8187592045069678, 0.9773831565887533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 285}], {
             RGBColor[
             0.9286295448374513, 0.9418226643023089, 0.7983899704135337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 399}], {
             RGBColor[
             0.8948180568355072, 0.820125129452121, 0.6232901061997559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 105}], {
             RGBColor[
             0.21372122175088312`, 0.34196493314125437`, 0.9354824794552745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 132}], {
             RGBColor[
             0.28812004710636396`, 0.4155836677571048, 0.9398870475355221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 202}], {
             RGBColor[
             0.23066301686818202`, 0.3597718339813871, 0.9364472896240648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 215}], {
             RGBColor[
             0.20048155521420025`, 0.3280492041678583, 0.9347285000323418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 218}], {
             RGBColor[
             0.20441362479812614`, 0.3321820586081753, 0.9349524255781707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 229}], {
             RGBColor[
             0.21242485108253378`, 0.34060236537417143`, 0.9354086530635206]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 260}], {
             RGBColor[
             0.22127423884363956`, 0.34990363299468435`, 0.9359126126050195]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 329}], {
             RGBColor[
             0.20420501368883298`, 0.3319627951056, 0.934940545484109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 341}], {
             RGBColor[
             0.2771008643732843, 0.406039405513939, 0.9391849149556509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 349}], {
             RGBColor[
             0.2099761655665867, 0.3380286416412822, 0.935269204045893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 77}], {
             RGBColor[
             0.1883529029244576, 0.3153012216103682, 0.9340377912271741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 103}], {
             RGBColor[
             0.19412197120965846`, 0.32136487815817005`, 0.9343663311314445]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 144}], {
             RGBColor[
             0.19222334020881804`, 0.31936929659612845`, 0.9342582069047196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 145}], {
             RGBColor[
             0.19557703724460856`, 0.3228942448174177, 0.9344491949895577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 200}], {
             RGBColor[
             0.1890554468047247, 0.31603963977238364`, 0.9340778000618348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 207}], {
             RGBColor[
             0.1908268877624048, 0.3179015365347492, 0.9341786810037627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 222}], {
             RGBColor[
             0.21314128516619657`, 0.3413553830206456, 0.9354494529247159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 333}], {
             RGBColor[
             0.19100459551754329`, 0.3180883186527222, 0.9341888011975227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 368}], {
             RGBColor[
             0.18953430680604916`, 0.3165429519952533, 0.9341050704305003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 94}], {
             RGBColor[
             0.18199794707454847`, 0.3086217600846408, 0.9336758858928365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 103}], {
             RGBColor[
             0.18857832587467818`, 0.31553815542369057`, 0.9340506287307058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 145}], {
             RGBColor[
             0.19003339190962826`, 0.3170675220829382, 0.934133492588819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 200}], {
             RGBColor[
             0.1835118014697444, 0.3102129170379042, 0.9337620976610961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 207}], {
             RGBColor[
             0.18528324242742453`, 0.31207481380026975`, 0.9338629786030239]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 254}], {
             RGBColor[
             0.18502833391359902`, 0.3118068887901059, 0.9338484619402648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 333}], {
             RGBColor[
             0.18546095018256298`, 0.31226159591824276`, 0.9338730987967839]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 104}], {
             RGBColor[
             0.819473350823259, 0.1506862844701191, 0.16628100878134408`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 172}], {
             RGBColor[
             0.8218704023733945, 0.1691110730791465, 0.16857642805283624`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 194}], {
             RGBColor[
             0.9072346231009216, 0.5724833285992563, 0.40645475392950137`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 208}], {
             RGBColor[
             0.9064764270189856, 0.5728170966942296, 0.4660720225452738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 217}], {
             RGBColor[
             0.9065035834313075, 0.5709197086654001, 0.3268855973458845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 230}], {
             RGBColor[
             0.818837947598831, 0.14580229685169685`, 0.1656725459360465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 233}], {
             RGBColor[
             0.8896719661372465, 0.5617502239079055, 0.560162093898772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 240}], {
             RGBColor[
             0.8258132510106677, 0.19941753547251867`, 0.17235210436069973`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 242}], {
             RGBColor[
             0.8361055023873913, 0.2785282896473279, 0.1822079759024856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 244}], {
             RGBColor[
             0.8873515007123038, 0.5600196245933966, 0.5640900365888891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 264}], {
             RGBColor[
             0.7716146222869605, 0.4690073780170669, 0.569890082784954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 285}], {
             RGBColor[
             0.907068308455854, 0.5721275983904466, 0.38835243118889584`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 357}], {
             RGBColor[
             0.8385190338854094, 0.29707975035734024`, 0.18451917639068158`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 385}], {
             RGBColor[
             0.9071814483660026, 0.5723695932180546, 0.4006670121899707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 100}], {
             RGBColor[
             0.22059571881103596`, 0.3491904654197632, 0.9358739718929432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 137}], {
             RGBColor[
             0.2827537056275888, 0.4121446936308188, 0.939500838618308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 175}], {
             RGBColor[
             0.2563476435480917, 0.3867680051213614, 0.9379099911164857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 213}], {
             RGBColor[
             0.22683120635617676`, 0.355744358182451, 0.9362290736840618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 227}], {
             RGBColor[
             0.21925675873838124`, 0.34778313348843115`, 0.9357977200976195]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[
             0.21942962029019444`, 0.3479648219394422, 0.9358075643072694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 278}], {
             RGBColor[
             0.24460490622546205`, 0.37442564366272924`, 0.937241259597785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 302}], {
             RGBColor[
             0.21120952198211004`, 0.3393249774333106, 0.9353394418691697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 314}], {
             RGBColor[
             0.23185910927542647`, 0.36102900293803986`, 0.9365154053171973]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 352}], {
             RGBColor[
             0.23532317406913467`, 0.3646699546706205, 0.9367126786825744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 379}], {
             RGBColor[
             0.21907288200889707`, 0.34758986738728526`, 0.9357872485898966]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 151}], {
             RGBColor[
             0.18591365690063838`, 0.3127374193822037, 0.9338988797746588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 168}], {
             RGBColor[
             0.18200651498987047`, 0.3086307655068815, 0.933676373822939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 265}], {
             RGBColor[
             0.18489536415726843`, 0.31166712914543293`, 0.933840889509353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 304}], {
             RGBColor[
             0.18034926344630414`, 0.30688888905877654`, 0.9335819957992169]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 378}], {
             RGBColor[
             0.18531329630253898`, 0.3121064023285408, 0.9338646901267509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 192}], {
             RGBColor[
             0.1805894919591846, 0.3071413844571813, 0.9335956764576392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 271}], {
             RGBColor[
             0.1793288256722832, 0.3058163442587888, 0.9335238833775887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 287}], {
             RGBColor[
             0.1847451216726243, 0.31150921476814825`, 0.9338323334221164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 292}], {
             RGBColor[
             0.18697166352319156`, 0.31384945142400145`, 0.9339591316866327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 374}], {
             RGBColor[
             0.1848884604275577, 0.3116598728877852, 0.9338404963521592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 382}], {
             RGBColor[
             0.18072466475425025`, 0.3072834596352455, 0.9336033743483478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 384}], {
             RGBColor[
             0.18455785037421688`, 0.3113123807598359, 0.9338216685987151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 101}], {
             RGBColor[
             0.181913405203708, 0.30853290121812327`, 0.9336710713583607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 136}], {
             RGBColor[
             0.18265801399513343`, 0.30931553226883557`, 0.9337134757274823]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 259}], {
             RGBColor[
             0.1834817429881715, 0.31018132366795326`, 0.9337603858750381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 331}], {
             RGBColor[
             0.18993705205367367`, 0.31696626278603024`, 0.9341280061765445]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 335}], {
             RGBColor[
             0.18011477786530028`, 0.30664242984589696`, 0.933568642192269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 120}], {
             RGBColor[
             0.7316668327109251, 0.7891725193318362, 0.9665740024152043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 187}], {
             RGBColor[
             0.6899774075909928, 0.7548276258988081, 0.9634300825559947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 206}], {
             RGBColor[
             0.8376738526720509, 0.8738864473115988, 0.9758404514260404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 217}], {
             RGBColor[
             0.9690520396764782, 0.9730561345189551, 0.7324860448307533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 220}], {
             RGBColor[
             0.790428504618827, 0.8368778917698232, 0.9711999364788909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 230}], {
             RGBColor[
             0.8813864038440016, 0.5479387227052518, 0.5712729934209153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 244}], {
             RGBColor[
             0.9498999569574745, 0.9621560504469515, 0.9696904840737579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 245}], {
             RGBColor[
             0.8819322732807819, 0.5521345143978579, 0.5717957186100475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 321}], {
             RGBColor[
             0.7496980165524652, 0.8038110466699736, 0.967993483257613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 328}], {
             RGBColor[
             0.9072826236616158, 0.729489427357416, 0.5953860262532737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 364}], {
             RGBColor[
             0.8813558056455749, 0.5477035315439278, 0.5712436925515461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 102}], {
             RGBColor[
             0.3081546083900806, 0.43843821536979977`, 0.9409621908941581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 163}], {
             RGBColor[
             0.3028162711208553, 0.4328272844297121, 0.940658180484038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 167}], {
             RGBColor[
             0.32454610124482625`, 0.4555272535620894, 0.9419007684798394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 174}], {
             RGBColor[
             0.3414171398675645, 0.4701400992540484, 0.9429757761424066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 183}], {
             RGBColor[
             0.3444123638438444, 0.47273441171796776`, 0.9431666291656026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 189}], {
             RGBColor[
             0.30274052812538393`, 0.4327476737390883, 0.9406538670324976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 222}], {
             RGBColor[
             0.2856119220562171, 0.4147444227440439, 0.9396784182563604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 226}], {
             RGBColor[
             0.39203908397867687`, 0.5139862829102032, 0.9462013616579391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 234}], {
             RGBColor[
             0.5622802808581155, 0.6502189334159502, 0.961044291025931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 238}], {
             RGBColor[
             0.3144100017377778, 0.44501303039307516`, 0.9413184262912844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 246}], {
             RGBColor[
             0.6295415881560444, 0.703574353083331, 0.9675332208830456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 269}], {
             RGBColor[
             0.5412096627237364, 0.6337584063867442, 0.9589441687264177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 272}], {
             RGBColor[
             0.5398855520007457, 0.6327240010263296, 0.9588121937440683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 395}], {
             RGBColor[
             0.4037383718237736, 0.5237036190763635, 0.9470617716812872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 88}], {
             RGBColor[
             0.21610734049788477`, 0.34447289523301966`, 0.9356183653879699]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 162}], {
             RGBColor[
             0.2565370723370653, 0.38696710678905155`, 0.9379207788057828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 181}], {
             RGBColor[
             0.2178344766889036, 0.34628822487653976`, 0.9357167232389794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 191}], {
             RGBColor[
             0.22398452631281984`, 0.35275231696694354`, 0.9360669594668783]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 211}], {
             RGBColor[
             0.231317411938528, 0.36045964469136466`, 0.9364845564552302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 214}], {
             RGBColor[
             0.2402451657445982, 0.3698432799938294, 0.9369929788270578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 263}], {
             RGBColor[
             0.31634895902864796`, 0.44214016934946804`, 0.941608656513351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 307}], {
             RGBColor[
             0.294549891018896, 0.4232589122924366, 0.9402196391759287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 312}], {
             RGBColor[
             0.27182714160879756`, 0.40303793904002655`, 0.9387915256311776]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 340}], {
             RGBColor[
             0.22184000451345684`, 0.35049828858527765`, 0.9359448321229403]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 348}], {
             RGBColor[
             0.28694246093137055`, 0.4166697387111759, 0.9397349004577378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 91}], {
             RGBColor[
             0.45216024233108254`, 0.5649746624056373, 0.950332168324746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 93}], {
             RGBColor[
             0.32267144519324537`, 0.4470223501983363, 0.9420332704147207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 95}], {
             RGBColor[
             0.48521628550800544`, 0.5918110474144382, 0.9529344611319093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 125}], {
             RGBColor[
             0.3362672755569396, 0.46131242993601224`, 0.9428075328407044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 148}], {
             RGBColor[
             0.37250043656006593`, 0.49706288855717573`, 0.9449563763217728]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 162}], {
             RGBColor[
             0.3416757625403587, 0.46699709267346645`, 0.9431155381732708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 179}], {
             RGBColor[
             0.4324853651691194, 0.5490017107824403, 0.9487832899231066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 214}], {
             RGBColor[
             0.32538385594789154`, 0.4498732658782442, 0.9421877381945456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 263}], {
             RGBColor[
             0.4014876492319413, 0.5221701552338829, 0.9468034158808389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 264}], {
             RGBColor[
             0.5671571608223211, 0.6570945561668415, 0.9602327949234224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 285}], {
             RGBColor[
             0.7026108469912147, 0.7602147765402214, 0.7786951433273641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 119}], {
             RGBColor[
             0.19029746556308325`, 0.3173450802359561, 0.9341485311927212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 127}], {
             RGBColor[
             0.19649156208518143`, 0.3238554684090837, 0.93450127582631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 129}], {
             RGBColor[
             0.1936336407966272, 0.32085161193213774`, 0.9343385214368426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 216}], {
             RGBColor[
             0.198944806635749, 0.32643398397641854`, 0.9346409844742148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 231}], {
             RGBColor[
             0.19018595982878306`, 0.3172278806393347, 0.9341421811061108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 235}], {
             RGBColor[
             0.1948464738725398, 0.3221263763929803, 0.9344075904862901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 298}], {
             RGBColor[
             0.19758831891525655`, 0.325008229375892, 0.9345637345052766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 313}], {
             RGBColor[
             0.2082730893529932, 0.33623860055952687`, 0.9351722163750043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 317}], {
             RGBColor[
             0.19676650353045996`, 0.3241444493003659, 0.9345169333348793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 361}], {
             RGBColor[
             0.20790747959893147`, 0.33585432152701067`, 0.9351513954403816]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 393}], {
             RGBColor[
             0.1907711086239872, 0.3178429091236707, 0.9341755044643476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 396}], {
             RGBColor[
             0.198868412851103, 0.3263536892651099, 0.9346366339611938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 109}], {
             RGBColor[
             0.18639597403767888`, 0.31324436527390603`, 0.9339263470220889]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 157}], {
             RGBColor[
             0.189431793006949, 0.31643520349264886`, 0.9340992324212971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 181}], {
             RGBColor[
             0.19319654196954522`, 0.3203921933512083, 0.9343136293052701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 191}], {
             RGBColor[
             0.19934659159346146`, 0.326856285441612, 0.9346638655331689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 365}], {
             RGBColor[
             0.18619994968916187`, 0.3130383312549531, 0.9339151837254329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 370}], {
             RGBColor[
             0.189278561860536, 0.3162741478423529, 0.9340905061341941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 128}], {
             RGBColor[
             0.1919283928758168, 0.31905928824840313`, 0.9342414100904406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 133}], {
             RGBColor[
             0.1875161010871107, 0.31442168982301577`, 0.9339901366004746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 155}], {
             RGBColor[
             0.19816316122321598`, 0.3256124250886648, 0.9345964709243118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 170}], {
             RGBColor[
             0.21045471282523004`, 0.33853162515176505`, 0.9352964566043255]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 171}], {
             RGBColor[
             0.18910388505940673`, 0.3160905514492172, 0.934080558548781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 199}], {
             RGBColor[
             0.18786740786844439`, 0.3147909355243339, 0.9340101430019597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 299}], {
             RGBColor[
             0.18845360021131413`, 0.3154070608434312, 0.9340435257886923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 306}], {
             RGBColor[
             0.1959786892882613, 0.3233164065815071, 0.9344720684792528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 342}], {
             RGBColor[
             0.18647972709604152`, 0.31333239504849575`, 0.9339311166348612]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 353}], {
             RGBColor[
             0.18963294311823536`, 0.31664662501326446`, 0.93411068762256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 121}], {
             RGBColor[
             0.4596424243656251, 0.5683306378036415, 0.9516722943059467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 122}], {
             RGBColor[
             0.6031707449782447, 0.6887202091625689, 0.9619029570133792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.7990367806379581, 0.841477411935373, 0.8913793888944332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 178}], {
             RGBColor[
             0.5250344578406001, 0.6249699305004974, 0.9558390168550672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 190}], {
             RGBColor[
             0.7822989919455827, 0.8299086268722369, 0.9606532016549456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 212}], {
             RGBColor[
             0.5128575453871849, 0.6144229009627645, 0.9550631147611566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 221}], {
             RGBColor[
             0.755343522572024, 0.6711176068414135, 0.6012544985481333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 268}], {
             RGBColor[
             0.6438707815800897, 0.7211954799278018, 0.9654945731092558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 274}], {
             RGBColor[
             0.5507285778663977, 0.6461452954084659, 0.9577745175163469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 295}], {
             RGBColor[
             0.5187067634857201, 0.6194891996894659, 0.9554358217661347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 319}], {
             RGBColor[
             0.530870221387825, 0.6300233870103961, 0.956211194950797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 324}], {
             RGBColor[
             0.6207541500572831, 0.7029952095291041, 0.9632871870713362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 351}], {
             RGBColor[
             0.7590840463718008, 0.8119268218437792, 0.9767853326782896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 373}], {
             RGBColor[
             0.44011491122134366`, 0.5480057067490964, 0.9505529184695845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 95}], {
             RGBColor[
             0.5263538722152581, 0.6263568112928946, 0.9558556514000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 112}], {
             RGBColor[
             0.7152028502193496, 0.6939405622428378, 0.6107535397674092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 125}], {
             RGBColor[
             0.37740486226419223`, 0.49585819381446866`, 0.9457287231087954]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 148}], {
             RGBColor[
             0.4136380232673186, 0.5316086524356322, 0.9478775665898638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 179}], {
             RGBColor[
             0.47362295187637204`, 0.5835474746608966, 0.9517044801911976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 257}], {
             RGBColor[
             0.408201112318213, 0.5268994734386068, 0.9475311314318583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 263}], {
             RGBColor[
             0.44262523593919395`, 0.5567159191123393, 0.94972460614893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 279}], {
             RGBColor[
             0.5827660155833214, 0.6716970806233367, 0.9606095197706748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 285}], {
             RGBColor[
             0.7437484336984672, 0.7947605404186777, 0.7816163335954551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 288}], {
             RGBColor[
             0.3993345066316525, 0.518907640464429, 0.9469775839135208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 135}], {
             RGBColor[
             0.746116355711272, 0.7971097200029147, 0.816782693533676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 165}], {
             RGBColor[
             0.6970699985324673, 0.761675381939551, 0.9717947555325273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 182}], {
             RGBColor[
             0.4229610876060558, 0.5395726978389508, 0.9485023279906137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 256}], {
             RGBColor[
             0.42434961842059, 0.5407753734409124, 0.9485908039462863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 281}], {
             RGBColor[
             0.46303919301965735`, 0.5742863383640635, 0.9510560694278913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 311}], {
             RGBColor[
             0.40006723340595274`, 0.5191882673765618, 0.947063870354397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 386}], {
             RGBColor[
             0.6290755332185833, 0.7079371215448762, 0.9651823556220622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 98}], {
             RGBColor[
             0.21766781953393055`, 0.3461130576399892, 0.9357072323605509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 125}], {
             RGBColor[
             0.24791606512635506`, 0.37790588160716765`, 0.9374298251987702]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 148}], {
             RGBColor[
             0.2841492261294814, 0.41365634022833114`, 0.9395786686798384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 162}], {
             RGBColor[
             0.2533245521097741, 0.3835905443446218, 0.9377378305313364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 214}], {
             RGBColor[
             0.23703264551730702`, 0.36646671754939963`, 0.9368100305526114]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 248}], {
             RGBColor[
             0.22615954726936105`, 0.355038401896562, 0.9361908236926982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 276}], {
             RGBColor[
             0.22858867995178067`, 0.3575915743616926, 0.9363291592053822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 288}], {
             RGBColor[
             0.2698457094938153, 0.4009553282571281, 0.9386786860034955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 290}], {
             RGBColor[
             0.21626873884937514`, 0.3446425351336826, 0.9356275567853198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 103}], {
             RGBColor[
             0.18776701535974932`, 0.31468541663244265`, 0.934004425797107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 145}], {
             RGBColor[
             0.18922208139469943`, 0.31621478329169034`, 0.9340872896552201]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 207}], {
             RGBColor[
             0.18447193191249567`, 0.3112220750090219, 0.933816775669425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 254}], {
             RGBColor[
             0.18421702339867016`, 0.31095414999885795`, 0.9338022590066659]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 125}], {
             RGBColor[
             0.41046090544111513`, 0.5226945788232695, 0.9483310159159588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 162}], {
             RGBColor[
             0.41586939242453425`, 0.5283792415607237, 0.9486390212485251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 233}], {
             RGBColor[
             0.7594081345567827, 0.8112195509449376, 0.9560282891124947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 263}], {
             RGBColor[
             0.47568127911611685`, 0.5835523041211401, 0.9523268989560933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 264}], {
             RGBColor[
             0.6413507907064967, 0.7184767050540989, 0.9657562779986768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 285}], {
             RGBColor[
             0.7768044768753901, 0.8215969254274786, 0.7842186264026185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 312}], {
             RGBColor[
             0.43115946169626646`, 0.5444500738116986, 0.9495097680739197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 173}], {
             RGBColor[
             0.515339475447038, 0.6087263479834802, 0.9574676673643785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 201}], {
             RGBColor[
             0.8486214444306401, 0.8823678065342169, 0.9733384742305298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 209}], {
             RGBColor[
             0.5415208134624869, 0.6338317942327045, 0.9590470002598491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 223}], {
             RGBColor[
             0.8390506368021915, 0.7815052608012159, 0.618996491222558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 245}], {
             RGBColor[
             0.7835145897788575, 0.47447987208772324`, 0.5706010714513564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 323}], {
             RGBColor[
             0.5734450946307983, 0.6614830020196698, 0.9610811872263605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 109}], {
             RGBColor[
             0.18710606140703578`, 0.3139907121212397, 0.9339667854472937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 181}], {
             RGBColor[
             0.19390662933890207`, 0.32113854019854193`, 0.9343540677304747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 191}], {
             RGBColor[
             0.2000566789628183, 0.32760263228894565`, 0.9347043039583738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 193}], {
             RGBColor[
             0.1899172543843397, 0.31694545418031556`, 0.9341268787285638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 211}], {
             RGBColor[
             0.20738956458852648`, 0.33530996001336677`, 0.9351219009467256]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 214}], {
             RGBColor[
             0.21631731839459667`, 0.3446935953158315, 0.9356303233185532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 248}], {
             RGBColor[
             0.2054442201466507, 0.3332652796629938, 0.9350111164586401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 305}], {
             RGBColor[
             0.18756138502713113`, 0.3144692861151448, 0.9339927154538672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 334}], {
             RGBColor[
             0.1889352663956901, 0.3159133225426103, 0.9340709559653313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 340}], {
             RGBColor[
             0.1979121571634553, 0.3253486039072797, 0.9345821766144358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 360}], {
             RGBColor[
             0.189069412661027, 0.31605431877284385`, 0.9340785953966906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 370}], {
             RGBColor[
             0.18998864922989284`, 0.31702049468968657`, 0.9341309445593988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 125}], {
             RGBColor[
             0.23126364989762477`, 0.3604031373776651, 0.9364814947865346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 139}], {
             RGBColor[
             0.19453754132088114`, 0.32180166869373195`, 0.9343899972344978]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 193}], {
             RGBColor[
             0.1939801662783198, 0.32121583218438116`, 0.9343582555503864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 204}], {
             RGBColor[
             0.19732498772567109`, 0.3247314515994759, 0.9345487381835933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 248}], {
             RGBColor[
             0.2095071320406308, 0.3375356576670594, 0.9352424932804627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 276}], {
             RGBColor[
             0.21193626472305038`, 0.34008883013219005`, 0.9353808287931467]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 290}], {
             RGBColor[
             0.19961632362064485`, 0.32713979090418005`, 0.9346792263730843]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 318}], {
             RGBColor[
             0.1977029240139366, 0.3251286866009877, 0.9345702610961033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 141}], {
             RGBColor[
             0.9156172249259522, 0.7282421342221813, 0.5763077730258106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 169}], {
             RGBColor[
             0.9307128082989145, 0.9468171296861931, 0.9664871194315787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 177}], {
             RGBColor[
             0.9302447173684912, 0.9464438866842635, 0.9664424725007652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 197}], {
             RGBColor[
             0.9649742133445314, 0.9733984061785892, 0.9441737000062027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 225}], {
             RGBColor[
             0.9251735948093716, 0.9424003112075763, 0.9659587843040318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 243}], {
             RGBColor[
             0.9675815557220673, 0.9753429578546242, 0.9397601494648378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 252}], {
             RGBColor[
             0.6676015641481373, 0.7342070299092066, 0.9439106644834332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 300}], {
             RGBColor[
             0.9401681906865148, 0.9543565949425481, 0.9673889822446275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 337}], {
             RGBColor[
             0.9798418672906987, 0.9817838609022704, 0.7682315700129669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 367}], {
             RGBColor[
             0.6703595369678017, 0.7365958473458555, 0.9440864000727226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 398}], {
             RGBColor[
             0.695865579228825, 0.7586878991813948, 0.9457116225314874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 146}], {
             RGBColor[
             0.1981449486568544, 0.3255932825266753, 0.9345954337456006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 175}], {
             RGBColor[
             0.2458994336441635, 0.3757862740575634, 0.9373149810191983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 213}], {
             RGBColor[
             0.21638299645224862`, 0.344762627118653, 0.9356340635867745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 227}], {
             RGBColor[
             0.20880854883445307`, 0.33680140242463313`, 0.9352027100003322]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 278}], {
             RGBColor[
             0.23415669632153385`, 0.3634439125989312, 0.9366462495004977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 302}], {
             RGBColor[
             0.20076131207818187`, 0.3283432463695126, 0.9347444317718824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 314}], {
             RGBColor[
             0.22141089937149833`, 0.35004727187424184`, 0.93592039521991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 352}], {
             RGBColor[
             0.2248749641652065, 0.3536882236068225, 0.936117668585287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 377}], {
             RGBColor[
             0.19744186238260558`, 0.3248542942741953, 0.9345553940224051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 136}], {
             RGBColor[
             0.18384486237801373`, 0.31056298516977654`, 0.9337810649871026]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 301}], {
             RGBColor[
             0.1828984857165501, 0.3095682832948322, 0.9337271702362709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 335}], {
             RGBColor[
             0.18130162624818058`, 0.3078898827468379, 0.9336362314518891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 394}], {
             RGBColor[
             0.18176625720560394`, 0.308378239342394, 0.9336626914975545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 163}], {
             RGBColor[
             0.272133057471457, 0.4033594760078676, 0.938808947086994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 167}], {
             RGBColor[
             0.29386288759542795`, 0.42605944514024496`, 0.9400515350827954]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 174}], {
             RGBColor[
             0.3107339262181662, 0.44067229083220405`, 0.9411265427453626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 189}], {
             RGBColor[
             0.27205731447598563`, 0.4032798653172439, 0.9388046336354536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 222}], {
             RGBColor[
             0.2549287084068188, 0.3852766143221994, 0.9378291848593165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 226}], {
             RGBColor[
             0.3613558703292786, 0.48451847448835883`, 0.9443521282608951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 395}], {
             RGBColor[
             0.3730551581743753, 0.49423581065451916`, 0.9452125382842432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 145}], {
             RGBColor[
             0.1958024601948291, 0.32313117863074003`, 0.9344620324930895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 200}], {
             RGBColor[
             0.18928086975494526`, 0.31627657358570604`, 0.9340906375653665]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 207}], {
             RGBColor[
             0.19105231071262538`, 0.3181384703480716, 0.9341915185072943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 222}], {
             RGBColor[
             0.21336670811641717`, 0.34159231683396796`, 0.9354622904282476]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 254}], {
             RGBColor[
             0.19079740219879987`, 0.3178705453379077, 0.9341770018445352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 333}], {
             RGBColor[
             0.19123001846776383`, 0.3183252524660446, 0.9342016387010543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 112}], {
             RGBColor[
             0.8780584972468868, 0.4677393624570944, 0.21704509236247566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 141}], {
             RGBColor[
             0.8423033289137494, 0.3148548235404699, 0.18770004553512668`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 172}], {
             RGBColor[
             0.8214061746435448, 0.16554281532163417`, 0.16813188305446203`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 208}], {
             RGBColor[
             0.906012199289136, 0.5692488389367173, 0.4656274775468996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 240}], {
             RGBColor[
             0.825349023280818, 0.19584927771500635`, 0.17190755936232552`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 242}], {
             RGBColor[
             0.8356412746575417, 0.27496003188981555`, 0.1817634309041114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 243}], {
             RGBColor[
             0.8942676597098645, 0.5619556471729128, 0.5511524219741538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 285}], {
             RGBColor[
             0.9066040807260044, 0.5685593406329343, 0.38790788619052163`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 337}], {
             RGBColor[
             0.9065279712784959, 0.568396550220559, 0.3796238425222831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 357}], {
             RGBColor[
             0.8380548061555597, 0.2935114925998279, 0.18407463139230737`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 399}], {
             RGBColor[
             0.8727925927240603, 0.4468618057827464, 0.21280802197674387`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 114}], {
             RGBColor[
             0.22538318625918102`, 0.3542223972507317, 0.9361466110816916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 171}], {
             RGBColor[
             0.19921926143757313`, 0.32672245337457523`, 0.9346566142691592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 202}], {
             RGBColor[
             0.2264175602160962, 0.35530958986254624`, 0.9362055171483188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 218}], {
             RGBColor[
             0.20016816814604027`, 0.3277198144893344, 0.9347106531024247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 229}], {
             RGBColor[
             0.20817939443044792`, 0.33614012125533055`, 0.9351668805877746]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 261}], {
             RGBColor[
             0.23472290345765154`, 0.3640390321985968, 0.9366784941592712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 349}], {
             RGBColor[
             0.20573070891450085`, 0.3335663975224413, 0.935027431570147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 353}], {
             RGBColor[
             0.19974831949640176`, 0.32727852693862247`, 0.9346867433429382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.2877186940288704, 0.4160544664052851, 0.9398315069221266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 150}], {
             RGBColor[
             0.2101822963835033, 0.33824529819931026`, 0.9352809428909732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 158}], {
             RGBColor[
             0.2827874224549232, 0.411783246820848, 0.939517290657987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 241}], {
             RGBColor[
             0.24501597193591163`, 0.37485769978748307`, 0.9372646691818778]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 270}], {
             RGBColor[
             0.2929589759941193, 0.42059333525935383`, 0.9401654130551529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 292}], {
             RGBColor[
             0.21060209943900177`, 0.3386865378276902, 0.9353048500539408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 310}], {
             RGBColor[
             0.2532088981789974, 0.38346898473049273`, 0.9377312442110733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 320}], {
             RGBColor[
             0.21130568150236095`, 0.33942604718596003`, 0.9353449180115927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 347}], {
             RGBColor[
             0.21233497992474068`, 0.3405079050891704, 0.9354035350340366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 374}], {
             RGBColor[
             0.2085188963433679, 0.336496959291474, 0.9351862147194673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 384}], {
             RGBColor[
             0.2081882862900271, 0.33614946716352473`, 0.9351673869660233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 389}], {
             RGBColor[
             0.21473367973065993`, 0.34302909067154336`, 0.9355401374394254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 390}], {
             RGBColor[
             0.24476481400135702`, 0.3745937168739334, 0.9372503661090598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 158}], {
             RGBColor[
             0.34368740964077826`, 0.4721064928245296, 0.9431204357248351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 190}], {
             RGBColor[
             0.6524189980541504, 0.7216233648288316, 0.9512140557147148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 212}], {
             RGBColor[
             0.3829775514957524, 0.5061376389193594, 0.9456239688209257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 241}], {
             RGBColor[
             0.30591595912176667`, 0.43518094579116473`, 0.9408678142487259]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 268}], {
             RGBColor[
             0.5139907876886572, 0.6129102178843966, 0.9560554271690249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 270}], {
             RGBColor[
             0.35385896317997434`, 0.4809165812630355, 0.943768558122001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 295}], {
             RGBColor[
             0.38882676959428764`, 0.5112039376460608, 0.945996675825904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 310}], {
             RGBColor[
             0.3141088853648525, 0.4437922307341744, 0.9413343892779213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 324}], {
             RGBColor[
             0.4908741561658506, 0.5947099474856988, 0.9538480411311054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 346}], {
             RGBColor[
             0.3498425512041035, 0.47743776708027175`, 0.9435126359024721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 351}], {
             RGBColor[
             0.6292040524803684, 0.703641559800374, 0.9673461867380587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 373}], {
             RGBColor[
             0.31023491732991126`, 0.43972044470569116`, 0.9411137725293536]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 390}], {
             RGBColor[
             0.30566480118721207`, 0.43491696287761505`, 0.9408535111759078]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 152}], {
             RGBColor[
             0.2564614085339687, 0.38688757933463486`, 0.9379164698641311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 154}], {
             RGBColor[
             0.23083302352450608`, 0.3599505217562283, 0.9364569712516402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 180}], {
             RGBColor[
             0.25734842126298235`, 0.38781988595268346`, 0.9379669839268308]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 198}], {
             RGBColor[
             0.3047308678845767, 0.4335017597846965, 0.9408162005428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 205}], {
             RGBColor[
             0.3030856171044626, 0.43207672625167026`, 0.9407113666179867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 236}], {
             RGBColor[
             0.2534644343240474, 0.3837375694208677, 0.9377457966165021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 262}], {
             RGBColor[
             0.23515249805591343`, 0.36449056335924074`, 0.936702958936114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 267}], {
             RGBColor[
             0.2560701403937588, 0.38647633171144136`, 0.9378941877223754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 284}], {
             RGBColor[
             0.26637610871838646`, 0.39730855785675745`, 0.9384810973721491]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 286}], {
             RGBColor[
             0.22549943873113315`, 0.3543445859695858, 0.9361532314879892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 332}], {
             RGBColor[
             0.24224909685408347`, 0.3719495386464692, 0.9371070997391926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 367}], {
             RGBColor[
             0.31561783688898226`, 0.44293150514134, 0.9415099085808494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 398}], {
             RGBColor[
             0.34112387915000547`, 0.4650235569768793, 0.9431351310396142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 157}], {
             RGBColor[
             0.18435836126610156`, 0.3111027050588667, 0.9338103079891256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 181}], {
             RGBColor[
             0.18812311022869774`, 0.31505969491742614`, 0.9340247048730984]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 191}], {
             RGBColor[
             0.19427315985261398`, 0.3215237870078299, 0.9343749411009974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 305}], {
             RGBColor[
             0.1817778659169268, 0.3083904408340291, 0.9336633525964908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 334}], {
             RGBColor[
             0.18315174728548578`, 0.30983447726149455`, 0.9337415931079549]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 340}], {
             RGBColor[
             0.19212863805325098`, 0.319269758626164, 0.9342528137570594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 360}], {
             RGBColor[
             0.18328589355082267`, 0.3099754734917281, 0.9337492325393142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 365}], {
             RGBColor[
             0.1811265179483144, 0.30770583282117103`, 0.9336262592932614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 370}], {
             RGBColor[
             0.1842051301196885, 0.31094164940857083`, 0.9338015817020224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 227}], {
             RGBColor[
             0.1954518354139104, 0.3227626497550994, 0.934442064930519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 237}], {
             RGBColor[
             0.19038343508665123`, 0.3174354396560086, 0.9341534270299079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 251}], {
             RGBColor[
             0.18685400772656674`, 0.3137257877219404, 0.9339524313630709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 308}], {
             RGBColor[
             0.1924672891129, 0.3196257023615725, 0.9342720994339171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 375}], {
             RGBColor[
             0.18201536929507323`, 0.30864007194304494`, 0.9336768780625215]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 116}], {
             RGBColor[
             0.1862942905711151, 0.31313748950344333`, 0.9339205562990953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 151}], {
             RGBColor[
             0.1906348725141942, 0.31769971633440997`, 0.9341677460194382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 154}], {
             RGBColor[
             0.19738148096805996`, 0.3247908295791051, 0.934551955390173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 286}], {
             RGBColor[
             0.1920478961746871, 0.3191848937924626, 0.934248215626522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 291}], {
             RGBColor[
             0.18821279065920096`, 0.31515395473595276`, 0.9340298120409453]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 304}], {
             RGBColor[
             0.18507047905985996`, 0.31185118601098283`, 0.9338508620439963]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 383}], {
             RGBColor[
             0.1988021595169091, 0.3262840528101681, 0.9346328609318244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 141}], {
             RGBColor[
             0.9013527030672266, 0.6354761592849575, 0.23890867411463246`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 172}], {
             RGBColor[
             0.880455548797022, 0.4861641510661218, 0.21934051163396778`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 179}], {
             RGBColor[
             0.6955279730573865, 0.6779676106196408, 0.6092046613657698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 240}], {
             RGBColor[
             0.8843983974342954, 0.516470613459494, 0.2231161879418313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 279}], {
             RGBColor[
             0.8046710367643358, 0.7661172165820809, 0.618109700945247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 285}], {
             RGBColor[
             0.9656534548794817, 0.8891806763774219, 0.4391165147700274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 337}], {
             RGBColor[
             0.9655773454319732, 0.8890178859650467, 0.43083247110178885`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 399}], {
             RGBColor[
             0.9318419668775375, 0.7674831415272341, 0.2640166505562497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 124}], {
             RGBColor[
             0.3086276211264817, 0.4416266325643382, 0.9408905883938774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 149}], {
             RGBColor[
             0.26206453775242544`, 0.39277682340214404`, 0.9382355597840353]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 210}], {
             RGBColor[
             0.3065896783902691, 0.43957556926948627`, 0.9407712006743179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 249}], {
             RGBColor[
             0.3083010067824331, 0.4413437356356376, 0.9408697768166884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 266}], {
             RGBColor[
             0.2701389734664643, 0.40126356728639195`, 0.9386953869528927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 293}], {
             RGBColor[
             0.32820995463660485`, 0.4585878656141067, 0.9421383573691648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 315}], {
             RGBColor[
             0.26318579596449465`, 0.3939553368749055, 0.9382994137804598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 316}], {
             RGBColor[
             0.2709397029977173, 0.40210518479292345`, 0.9387409873151243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 387}], {
             RGBColor[
             0.4208258242811829, 0.5366129491256768, 0.9486460027249637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 397}], {
             RGBColor[
             0.2602244815922864, 0.3908428077115391, 0.9381307713078346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 128}], {
             RGBColor[
             0.21795119041436695`, 0.34641089840207934`, 0.9357233699129821]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 155}], {
             RGBColor[
             0.2241859587617661, 0.352964035242341, 0.9360784307468533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 170}], {
             RGBColor[
             0.23647751036378017`, 0.3658832353054412, 0.9367784164268669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 187}], {
             RGBColor[
             0.33810546577905015`, 0.4610349816709624, 0.9429931157731941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 202}], {
             RGBColor[
             0.2423249813764799, 0.37202929809086444`, 0.937111421250482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 261}], {
             RGBColor[
             0.25063032461803525`, 0.380758740426915, 0.9375843982614342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 306}], {
             RGBColor[
             0.2220014868268114, 0.35066801673518333`, 0.9359540283017942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 353}], {
             RGBColor[
             0.2156557406567855, 0.3439982351669406, 0.9355926474451014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 122}], {
             RGBColor[
             0.7312854319265467, 0.5812953754272103, 0.5851154705993664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 166}], {
             RGBColor[
             0.92715146758626, 0.7340525782000142, 0.5145919024804202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 169}], {
             RGBColor[
             0.8801983721871041, 0.6989200901607082, 0.599330145570115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 197}], {
             RGBColor[
             0.914459777232721, 0.7255013666531043, 0.5770167261447392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 221}], {
             RGBColor[
             0.8834582095203258, 0.5636927731060549, 0.2244670121341203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 239}], {
             RGBColor[
             0.8461854795987771, 0.346251043142995, 0.19147853854411218`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 300}], {
             RGBColor[
             0.8896537545747043, 0.7064595554170632, 0.6002320083831638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 350}], {
             RGBColor[
             0.9292292560607558, 0.7349117971309463, 0.4801575703138227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 392}], {
             RGBColor[
             0.9278459781809479, 0.7343397761790258, 0.5030820645906373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 151}], {
             RGBColor[
             0.18767873323802545`, 0.31459262652510106`, 0.9339993982608765]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 154}], {
             RGBColor[
             0.19442534169189124`, 0.3216837397697962, 0.9343836076316113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 265}], {
             RGBColor[
             0.18666044049465552`, 0.3135223362883303, 0.9339414079955707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 291}], {
             RGBColor[
             0.1852566513830322, 0.31204686492664385`, 0.9338614642823836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 304}], {
             RGBColor[
             0.18211433978369124`, 0.30874409620167387`, 0.9336825142854346]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 383}], {
             RGBColor[
             0.19584602024074033`, 0.3231769630008592, 0.9344645131732627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 289}], {
             RGBColor[
             0.20615434433043495`, 0.33401166520462483`, 0.935051556980372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 303}], {
             RGBColor[
             0.21968824533158482`, 0.34823665325571823`, 0.9358222926207751]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 376}], {
             RGBColor[
             0.217871456795024, 0.34632709331274647`, 0.9357188292013159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 158}], {
             RGBColor[
             0.28881871360859035`, 0.41812251622929797`, 0.9398607637666927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 164}], {
             RGBColor[
             0.21991695118991147`, 0.3484770376136085, 0.9358353170810669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 173}], {
             RGBColor[
             0.26068055800241224`, 0.3913221729354959, 0.9381567441846866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 209}], {
             RGBColor[
             0.2868618960178613, 0.41642761918472027`, 0.9397360770801573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 241}], {
             RGBColor[
             0.25104726308957875`, 0.38119696919593304`, 0.9376081422905835]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 323}], {
             RGBColor[
             0.3187861771861727, 0.44407882697168544`, 0.9417702640466686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 346}], {
             RGBColor[
             0.2949738551719156, 0.42345379048504006`, 0.9402529639443298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 354}], {
             RGBColor[
             0.22736699671866945`, 0.3563075078245018, 0.9362595861525749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 388}], {
             RGBColor[
             0.2291977478565746, 0.35823174334676655`, 0.936363844721525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 389}], {
             RGBColor[
             0.22076497088432706`, 0.3493683600799934, 0.9358836105481312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 126}], {
             RGBColor[
             0.1845010944888899, 0.3112527267258263, 0.9338184364350084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 127}], {
             RGBColor[
             0.18861006279746526`, 0.31557151294177693`, 0.9340524361015079]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 129}], {
             RGBColor[
             0.18575214150891103`, 0.312567656464831, 0.9338896817120405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 196}], {
             RGBColor[
             0.18607572050979368`, 0.3129077585108523, 0.9339081090574485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 231}], {
             RGBColor[
             0.18230446054106692`, 0.30894392517202796`, 0.9336933413813087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 235}], {
             RGBColor[
             0.18696497458482364`, 0.31384242092567355`, 0.9339587507614879]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 317}], {
             RGBColor[
             0.1888850042427438, 0.31586049383305914`, 0.9340680936100771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 326}], {
             RGBColor[
             0.18721381086797456`, 0.3141039636363968, 0.933972921619693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 327}], {
             RGBColor[
             0.18901152680793626`, 0.3159934770710704, 0.9340752988829915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 336}], {
             RGBColor[
             0.18138462902211405`, 0.30797712392492177`, 0.9336409583370731]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 396}], {
             RGBColor[
             0.19098691356338682`, 0.3180697337978031, 0.9341877942363916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 132}], {
             RGBColor[
             0.4382862950940797, 0.5522789014915227, 0.9496356996104882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 160}], {
             RGBColor[
             0.48896132780643076`, 0.5959998592268796, 0.9529119733307341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 187}], {
             RGBColor[
             0.47660974925846794`, 0.585472751295903, 0.952077636221743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 202}], {
             RGBColor[
             0.38082926485589774`, 0.49646706771580507`, 0.9461959416990309]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 206}], {
             RGBColor[
             0.624306194339526, 0.7045315727086937, 0.9644880050917888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 217}], {
             RGBColor[
             0.7556843813439534, 0.80370125991605, 0.7211335984965017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 220}], {
             RGBColor[
             0.5770608462863022, 0.6675230171669182, 0.9598474901446392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 233}], {
             RGBColor[
             0.7388527640498924, 0.7945317751585553, 0.9544100950493892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 244}], {
             RGBColor[
             0.7365322986249497, 0.7928011758440465, 0.9583380377395063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 307}], {
             RGBColor[
             0.43332684059947457`, 0.5479832712777266, 0.9493196875555654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 321}], {
             RGBColor[
             0.5363303582199404, 0.6344561720670685, 0.9566410369233613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 341}], {
             RGBColor[
             0.42726711236099996`, 0.542734639248357, 0.9489335670306169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 366}], {
             RGBColor[
             0.4563492884558704, 0.567924158469062, 0.9507866575750236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 122}], {
             RGBColor[
             0.4544345003462795, 0.5641026104704333, 0.9512623074498896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 175}], {
             RGBColor[
             0.29627876905743955`, 0.4285384264353338, 0.9401913224925988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 178}], {
             RGBColor[
             0.376298213208635, 0.5003523318083618, 0.9451983672915776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.26676233186552467`, 0.3975147794964234, 0.938510405060175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 274}], {
             RGBColor[
             0.4019923332344326, 0.5215276967163304, 0.9471338679528571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 296}], {
             RGBColor[
             0.27793336964590865`, 0.4092562484883108, 0.9391465791356984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 319}], {
             RGBColor[
             0.3821339767558598, 0.5054057883182604, 0.9455705453873072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 373}], {
             RGBColor[
             0.2913786665893785, 0.4233881080569608, 0.9399122689060947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 166}], {
             RGBColor[
             0.7938288566186125, 0.8372493846021647, 0.890969402038376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 169}], {
             RGBColor[
             0.7468757612194565, 0.8021168965628588, 0.9757076451280708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 175}], {
             RGBColor[
             0.4398070896700592, 0.5489279977942612, 0.9504219852000314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 178}], {
             RGBColor[
             0.5198265338212547, 0.6207419031672892, 0.9554290299990101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 268}], {
             RGBColor[
             0.638662857560744, 0.7169674525945936, 0.9650845862531987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 274}], {
             RGBColor[
             0.5455206538470523, 0.6419172680752578, 0.9573645306602898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 319}], {
             RGBColor[
             0.5256622973684795, 0.6257953596771879, 0.9558012080947398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 351}], {
             RGBColor[
             0.7538761223524553, 0.8076987945105711, 0.9763753458222324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 131}], {
             RGBColor[
             0.21247713876151392`, 0.34065732304000995`, 0.9354116307694857]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 140}], {
             RGBColor[
             0.21869849237699107`, 0.3471963601464784, 0.9357659276542193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 203}], {
             RGBColor[
             0.21872743662810462`, 0.3472267823895703, 0.935767575986501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 232}], {
             RGBColor[
             0.2533953304852037, 0.3836649369048065, 0.9377418612551098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 275}], {
             RGBColor[
             0.22522408057531274`, 0.3540551670891031, 0.9361375502483711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 280}], {
             RGBColor[
             0.23161694690439888`, 0.3607744749321087, 0.9365016145284144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 297}], {
             RGBColor[
             0.20930917766859286`, 0.3373275950710155, 0.9352312200718224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 309}], {
             RGBColor[
             0.2546471876156135, 0.3849807181211936, 0.93781315266673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 322}], {
             RGBColor[
             0.20580146810397543`, 0.3336407699169709, 0.9350314612013086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 325}], {
             RGBColor[
             0.2504184772778667, 0.38053607544050067`, 0.9375723338688118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 339}], {
             RGBColor[
             0.23162280417676506`, 0.3607806312967381, 0.9365019480914105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 149}], {
             RGBColor[
             0.2631665511656537, 0.3938441656371931, 0.9383016477132344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 185}], {
             RGBColor[
             0.35466498690371884`, 0.48161471850061266`, 0.9438199172409392]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 210}], {
             RGBColor[
             0.30769169180349737`, 0.4406429115045353, 0.9408372886035168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 219}], {
             RGBColor[
             0.32342751125618663`, 0.45455838713589725`, 0.9418294929148936]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 249}], {
             RGBColor[
             0.30940302019566135`, 0.4424110778706867, 0.9409358647458874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 266}], {
             RGBColor[
             0.27124098687969256`, 0.402330909521441, 0.9387614748820916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 293}], {
             RGBColor[
             0.3293119680498331, 0.45965520784915576`, 0.9422044452983639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 315}], {
             RGBColor[
             0.2642878093777229, 0.3950226791099546, 0.9383655017096588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 316}], {
             RGBColor[
             0.27204171641094554`, 0.40317252702797246`, 0.9388070752443234]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 338}], {
             RGBColor[
             0.2719649687624893, 0.40309186038336303`, 0.9388027045792817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 387}], {
             RGBColor[
             0.42192783769441117`, 0.5376802913607258, 0.9487120906541628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 397}], {
             RGBColor[
             0.26132649500551464`, 0.3919101499465881, 0.9381968592370336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 148}], {
             RGBColor[
             0.2977450564931756, 0.4279464199660071, 0.9403529311058223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 162}], {
             RGBColor[
             0.2669203824734684, 0.39788062408229774`, 0.9385120929573202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 211}], {
             RGBColor[
             0.24170072207493107`, 0.37137316198461084`, 0.9370758706067677]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 214}], {
             RGBColor[
             0.25062847588100123`, 0.38075679728707557`, 0.9375842929785951]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 248}], {
             RGBColor[
             0.2397553776330553, 0.3693284816342379, 0.936965086118682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 263}], {
             RGBColor[
             0.326732269165051, 0.4530536866427142, 0.9421999706648885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 276}], {
             RGBColor[
             0.2421845103154749, 0.3718816540993685, 0.9371034216313661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 288}], {
             RGBColor[
             0.28344153985750953`, 0.415245407994804, 0.9394529484294792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 196}], {
             RGBColor[
             0.1881608487233165, 0.3150993604680292, 0.9340268540245378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 289}], {
             RGBColor[
             0.1863769520635358, 0.31322437197301883`, 0.933925263748802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 317}], {
             RGBColor[
             0.1909701324562666, 0.31805209579023613`, 0.9341868385771666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 326}], {
             RGBColor[
             0.18929893908149736`, 0.31629556559357375`, 0.9340916665867824]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 327}], {
             RGBColor[
             0.19109665502145906`, 0.31818507902824733`, 0.9341940438500809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 336}], {
             RGBColor[
             0.18346975723563688`, 0.31016872588209876`, 0.9337597033041625]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 376}], {
             RGBColor[
             0.19809406452812484`, 0.3255398000811405, 0.9345925359697458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 129}], {
             RGBColor[
             0.19194623803100921`, 0.3190780446379586, 0.9342424263456293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 216}], {
             RGBColor[
             0.19725740387013102`, 0.32466041668223944`, 0.9345448893830015]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 231}], {
             RGBColor[
             0.1884985570631651, 0.31545431334515556`, 0.9340460860148976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 235}], {
             RGBColor[
             0.19315907110692182`, 0.32035280909880115`, 0.9343114953950769]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 298}], {
             RGBColor[
             0.19590091614963856`, 0.32323466208171286`, 0.9344676394140633]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 313}], {
             RGBColor[
             0.20658568658737522`, 0.3344650332653477, 0.935076121283791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 317}], {
             RGBColor[
             0.19507910076484197`, 0.32237088200618674`, 0.9344208382436661]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 336}], {
             RGBColor[
             0.18757872554421223`, 0.31448751209804937`, 0.933993702970662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 361}], {
             RGBColor[
             0.2062200768333135, 0.33408075423283157`, 0.9350553003491684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 393}], {
             RGBColor[
             0.1890837058583692, 0.31606934182949153`, 0.9340794093731344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 396}], {
             RGBColor[
             0.197181010085485, 0.3245801219709307, 0.9345405388699805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 133}], {
             RGBColor[
             0.19019948162046302`, 0.31724209289972144`, 0.9341429511521433]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 155}], {
             RGBColor[
             0.2008465417565683, 0.32843282816537045`, 0.9347492854759805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 170}], {
             RGBColor[
             0.21313809335858236`, 0.34135202822847077`, 0.9354492711559941]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 171}], {
             RGBColor[
             0.19178726559275905`, 0.3189109545259229, 0.9342333731004496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 199}], {
             RGBColor[
             0.1905507884017967, 0.3176113386010396, 0.9341629575536283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 261}], {
             RGBColor[
             0.22729090761283746`, 0.3562275333499445, 0.9362552529905616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 299}], {
             RGBColor[
             0.19113698074466645`, 0.31822746392013684`, 0.934196340340361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 306}], {
             RGBColor[
             0.1986620698216136, 0.3261368096582128, 0.9346248830309214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 342}], {
             RGBColor[
             0.18916310762939384`, 0.3161527981252015, 0.9340839311865298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 353}], {
             RGBColor[
             0.19231632365158768`, 0.3194670280899702, 0.9342635021742287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 216}], {
             RGBColor[
             0.1943994825815768, 0.32165656020529343`, 0.9343821349935341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 231}], {
             RGBColor[
             0.18564063577461087`, 0.3124504568682096, 0.93388333162543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 235}], {
             RGBColor[
             0.1903011498183676, 0.3173489526218552, 0.9341487410056093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 298}], {
             RGBColor[
             0.19304299486108434`, 0.3202308056047669, 0.9343048850245959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 313}], {
             RGBColor[
             0.203727765298821, 0.33146117678840176`, 0.9349133668943235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 317}], {
             RGBColor[
             0.19222117947628775`, 0.3193670255292408, 0.9342580838541985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 336}], {
             RGBColor[
             0.184720804255658, 0.3114836556211034, 0.9338309485811944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 361}], {
             RGBColor[
             0.20336215554475928`, 0.33107689775588556`, 0.9348925459597008]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 393}], {
             RGBColor[
             0.18622578456981498`, 0.3130654853525456, 0.9339166549836668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 396}], {
             RGBColor[
             0.19432308879693078`, 0.32157626549398477`, 0.934377784480513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 147}], {
             RGBColor[
             0.18274418895711692`, 0.3094061076176884, 0.9337183832640827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 164}], {
             RGBColor[
             0.19148238974395732`, 0.318590510678587, 0.9342160108718838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 287}], {
             RGBColor[
             0.1859722872961475, 0.31279904364526556`, 0.9339022186889471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 371}], {
             RGBColor[
             0.18427986944939637`, 0.311020205182841, 0.9338058379962824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 391}], {
             RGBColor[
             0.18156952589467779`, 0.3081714622611251, 0.9336514879404352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 140}], {
             RGBColor[
             0.21947779992995464`, 0.3480154617955958, 0.9358103080664784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 186}], {
             RGBColor[
             0.21005402739966472`, 0.3381104793645726, 0.9352736381621005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 188}], {
             RGBColor[
             0.20752052535930418`, 0.3354476080868466, 0.9351293589688823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 203}], {
             RGBColor[
             0.2195067441810682, 0.34804588403868764`, 0.9358119563987601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 228}], {
             RGBColor[
             0.20842587898456535`, 0.33639919214973135`, 0.9351809175184903]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 238}], {
             RGBColor[
             0.2516193138752771, 0.38179823084181674`, 0.9376407197365557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 273}], {
             RGBColor[
             0.19754073794696791`, 0.32495821876141306`, 0.9345610248395222]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 280}], {
             RGBColor[
             0.23239625445736245`, 0.36159357658122604`, 0.9365459949406734]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 309}], {
             RGBColor[
             0.255426495168577, 0.38579981977031097`, 0.9378575330789891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 322}], {
             RGBColor[
             0.206580775656939, 0.33445987156608825`, 0.9350758416135677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 325}], {
             RGBColor[
             0.2511977848308302, 0.381355177089618, 0.9376167142810707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 330}], {
             RGBColor[
             0.199593351679308, 0.3271156459373298, 0.9346779181550091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 339}], {
             RGBColor[
             0.23240211172972863`, 0.36159973294585546`, 0.9365463285036696]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 160}], {
             RGBColor[
             0.40894844852211004`, 0.5284611159894712, 0.9473261168602697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 202}], {
             RGBColor[
             0.300816385571577, 0.4289283244783967, 0.9406100852285664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 220}], {
             RGBColor[
             0.4970479670019815, 0.5999842739295098, 0.9542616336741748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 244}], {
             RGBColor[
             0.656519419340629, 0.7252624326066381, 0.9527521812690418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 260}], {
             RGBColor[
             0.29142760754703456`, 0.4190601234916939, 0.9400754082095211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 307}], {
             RGBColor[
             0.3533139613151539, 0.48044452804031823`, 0.9437338310851009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 321}], {
             RGBColor[
             0.4563174789356197, 0.5669174288296601, 0.9510551804528969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 341}], {
             RGBColor[
             0.34725423307667924`, 0.4751958960109486, 0.9433477105601525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 348}], {
             RGBColor[
             0.34570653122762846`, 0.47385535445905747`, 0.94324909236691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 366}], {
             RGBColor[
             0.3763364091715497, 0.5003854152316536, 0.9452008011045592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 155}], {
             RGBColor[
             0.1964342499678622, 0.3237952297399831, 0.9344980119860145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 199}], {
             RGBColor[
             0.18613849661309062`, 0.31297374017565216`, 0.9339116840636623]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 216}], {
             RGBColor[
             0.19274891912622777`, 0.3199217133619542, 0.9342881378465417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 298}], {
             RGBColor[
             0.1913924314057353, 0.3184959587614276, 0.9342108878776034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 299}], {
             RGBColor[
             0.18672468895596034`, 0.31358986549474943`, 0.9339450668503949]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 306}], {
             RGBColor[
             0.1942497780329075, 0.32149921123282543`, 0.9343736095409554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 342}], {
             RGBColor[
             0.18475081584068775`, 0.311515199699814, 0.9338326576965637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 361}], {
             RGBColor[
             0.20171159208941025`, 0.3293420509125463, 0.9347985488127086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 393}], {
             RGBColor[
             0.18457522111446595`, 0.3113306385092063, 0.9338226578366745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 135}], {
             RGBColor[
             0.9129052217970873, 0.9297159641585085, 0.8318647617559947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 226}], {
             RGBColor[
             0.6381042655490734, 0.7140610165668736, 0.9666654902064342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 234}], {
             RGBColor[
             0.8083454624285121, 0.8502936670726204, 0.9815084195744261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 239}], {
             RGBColor[
             0.8293655507418161, 0.5412295041829576, 0.578979393717503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 246}], {
             RGBColor[
             0.8756067697264411, 0.9036490867400013, 0.9879973494315406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 269}], {
             RGBColor[
             0.7872748442941331, 0.8338331400434145, 0.9794082972749127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 272}], {
             RGBColor[
             0.7859507335711424, 0.832798734683, 0.9792763222925633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 350}], {
             RGBColor[
             0.9124093272037948, 0.929890258170909, 0.8676584254872136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 355}], {
             RGBColor[
             0.7983376603764013, 0.8424754960473988, 0.9805109353940992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 392}], {
             RGBColor[
             0.9110260493239869, 0.9293182372189884, 0.8905829197640283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 395}], {
             RGBColor[
             0.6498035533941702, 0.7237783527330339, 0.9675259002297822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 156}], {
             RGBColor[
             0.9129140627520606, 0.6152764832633987, 0.4286476247419544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 165}], {
             RGBColor[
             0.9457959012350979, 0.9559420991486686, 0.8350019041226482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 221}], {
             RGBColor[
             0.9485753172801801, 0.8203317071995411, 0.46009294767531356`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 234}], {
             RGBColor[
             0.8902824990453274, 0.9119541401261442, 0.8296334999422285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 255}], {
             RGBColor[
             0.9151018270707441, 0.6320925985012373, 0.4307426303242521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 281}], {
             RGBColor[
             0.711765095722288, 0.768553055573181, 0.8142632180180123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 328}], {
             RGBColor[
             0.932186507346842, 0.7459139489960613, 0.44641772294044424`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 355}], {
             RGBColor[
             0.8802746969932166, 0.9041359691009224, 0.8286360157619015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 386}], {
             RGBColor[
             0.8778014359212141, 0.9022038387539937, 0.8283895042121832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 400}], {
             RGBColor[
             0.9225103695720027, 0.6890379026099368, 0.4378370589902095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 331}], {
             RGBColor[
             0.19186850922797938`, 0.3189963467376835, 0.9342379998052863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 335}], {
             RGBColor[
             0.18204623503960604`, 0.3086725137975501, 0.9336786358210108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 394}], {
             RGBColor[
             0.18251086599702937`, 0.30916087039310625`, 0.9337050958666762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 169}], {
             RGBColor[
             0.6151260920101136, 0.6919294010372166, 0.9662275076726026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 175}], {
             RGBColor[
             0.3080574204607164, 0.43874050226861905`, 0.940941847744563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 178}], {
             RGBColor[
             0.3880768646119117, 0.5105544076416471, 0.9459488925435418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 197}], {
             RGBColor[
             0.6493874970557305, 0.7185106775296126, 0.9439140882472267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 252}], {
             RGBColor[
             0.35201484785933657`, 0.47931930126023004`, 0.943651052724457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 278}], {
             RGBColor[
             0.29631468313808673`, 0.42639814080998684`, 0.9402731162258624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 282}], {
             RGBColor[
             0.3008030444529849, 0.4311156931304887, 0.9405287217628104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 300}], {
             RGBColor[
             0.624581474397714, 0.6994688662935715, 0.9671293704856514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 314}], {
             RGBColor[
             0.28356888618805115`, 0.41300150008529746`, 0.9395472619452747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 319}], {
             RGBColor[
             0.3939126281591366, 0.5156078641515458, 0.9463210706392715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 352}], {
             RGBColor[
             0.28703295098175935`, 0.4166424518178782, 0.9397445353106518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 159}], {
             RGBColor[
             0.18138230828610377`, 0.30797468468423184`, 0.9336408261745905]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 215}], {
             RGBColor[
             0.18262441317102773`, 0.30928021567228525`, 0.9337115622102574]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 218}], {
             RGBColor[
             0.18655648275495362`, 0.3134130701126022, 0.9339354877560864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 229}], {
             RGBColor[
             0.19456770903936127`, 0.32183337687859837`, 0.9343917152414362]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 329}], {
             RGBColor[
             0.18634787164566047`, 0.31319380661002694`, 0.9339236076620245]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 349}], {
             RGBColor[
             0.19211902352341417`, 0.31925965314570914`, 0.9342522662238085]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 193}], {
             RGBColor[
             0.18750230329400064`, 0.31440718746762647`, 0.933989350836569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 204}], {
             RGBColor[
             0.19084712474135193`, 0.31792280688272123`, 0.9341798334697757]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 224}], {
             RGBColor[
             0.18369701044953324`, 0.3104075834185898, 0.9337726450385029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 276}], {
             RGBColor[
             0.20545840173873126`, 0.33328018541543536`, 0.9350119240793292]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 290}], {
             RGBColor[
             0.19313846063632573`, 0.32033114618742536`, 0.9343103216592668]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 318}], {
             RGBColor[
             0.19122506102961745`, 0.318320041884233, 0.9342013563822857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 203}], {
             RGBColor[
             0.22572809779654535`, 0.3545849211451561, 0.9361662532834936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 232}], {
             RGBColor[
             0.2603959916536444, 0.39102307566039235`, 0.9381405385521024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 257}], {
             RGBColor[
             0.2744017745717613, 0.404416509747592, 0.9389867546110457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 275}], {
             RGBColor[
             0.23222474174375346`, 0.36141330584468895`, 0.9365362275453637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 280}], {
             RGBColor[
             0.2386176080728396, 0.36813261368769457`, 0.936900291825407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 288}], {
             RGBColor[
             0.2655351688852008, 0.39642467677341436`, 0.9384332070927082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 297}], {
             RGBColor[
             0.21630983883703356`, 0.3446857338266013, 0.935629897368815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 309}], {
             RGBColor[
             0.2616478487840542, 0.3923388568767794, 0.9382118299637227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 322}], {
             RGBColor[
             0.21280212927241615`, 0.34099890867255667`, 0.9354301384983013]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 325}], {
             RGBColor[
             0.25741913844630737`, 0.3878942141960865, 0.9379710111658044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 339}], {
             RGBColor[
             0.2386234653452058, 0.3681387700523239, 0.9369006253884031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 172}], {
             RGBColor[
             0.8447003804638847, 0.3332796121494973, 0.18999546480661883`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[
             0.8486432291011581, 0.36358607454286945`, 0.19377114111448232`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 243}], {
             RGBColor[
             0.9175618655302045, 0.7296924440007758, 0.5730160037263106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 279}], {
             RGBColor[
             0.7689158684311985, 0.6132326776654563, 0.588764654117898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 285}], {
             RGBColor[
             0.9298982865463443, 0.7362961374607975, 0.4097714679426784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 337}], {
             RGBColor[
             0.9298221770988357, 0.7361333470484221, 0.40148742427443984`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 399}], {
             RGBColor[
             0.8960867985444002, 0.6145986026106095, 0.23467160372890067`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 143}], {
             RGBColor[
             0.1837659567931899, 0.3104800503972236, 0.9337765714307771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 258}], {
             RGBColor[
             0.18294835007904106`, 0.30962069390139346`, 0.9337300099379471]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 277}], {
             RGBColor[
             0.19515207298431664`, 0.32244758043556054`, 0.9344249939036124]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 302}], {
             RGBColor[
             0.18693197467623224`, 0.31380773592942895`, 0.9339568714655127]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 377}], {
             RGBColor[
             0.18361252498065594`, 0.31031878383411166`, 0.9337678337160353]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 378}], {
             RGBColor[
             0.18665371404405717`, 0.3135152663622699, 0.93394102493416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 379}], {
             RGBColor[
             0.1947953347030193, 0.32207262588340363`, 0.9344046781862394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 258}], {
             RGBColor[
             0.1842254727690224, 0.31096303082281923`, 0.9338027401858078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 277}], {
             RGBColor[
             0.196429195674298, 0.32378991735698637`, 0.9344977241514731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 302}], {
             RGBColor[
             0.1882090973662136, 0.3151500728508547, 0.9340296017133733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 377}], {
             RGBColor[
             0.1848896476706373, 0.3116611207555374, 0.933840563963896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 378}], {
             RGBColor[
             0.18793083673403851`, 0.31485760328369566`, 0.9340137551820207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 379}], {
             RGBColor[
             0.19607245739300067`, 0.3234149628048294, 0.9344774084341002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 186}], {
             RGBColor[
             0.19870087032152506`, 0.3261775914437136, 0.9346270926619912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 188}], {
             RGBColor[
             0.19616736828116454`, 0.3235147201659876, 0.934482813468773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 200}], {
             RGBColor[
             0.18738223875410484`, 0.31428099202366444`, 0.9339825133386415]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 228}], {
             RGBColor[
             0.19707272190642572`, 0.32446630422887235`, 0.934534372018381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 333}], {
             RGBColor[
             0.1893313874669234, 0.316329670904003, 0.9340935144743294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 368}], {
             RGBColor[
             0.18786109875542928`, 0.31478430424653414`, 0.934009783707307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 200}], {
             RGBColor[
             0.19073593578989534`, 0.3178059402449537, 0.9341735014234795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 207}], {
             RGBColor[
             0.19250737674757545`, 0.31966783700731927`, 0.9342743823654074]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 222}], {
             RGBColor[
             0.21482177415136725`, 0.3431216834932156, 0.9355451542863606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 254}], {
             RGBColor[
             0.19225246823374995`, 0.31939991199715534`, 0.9342598657026484]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 333}], {
             RGBColor[
             0.19268508450271393`, 0.3198546191252922, 0.9342845025591675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 227}], {
             RGBColor[
             0.19680598858419968`, 0.3241859505953433, 0.934519181950277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 302}], {
             RGBColor[
             0.18875875182792845`, 0.3157277945402228, 0.9340609037218272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 375}], {
             RGBColor[
             0.18336952246536248`, 0.3100633727832889, 0.9337539950822794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 377}], {
             RGBColor[
             0.18543930213235216`, 0.3122388424449055, 0.9338718659723498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 344}], {
             RGBColor[
             0.1873628349672718, 0.31426059741343176`, 0.9339814083216866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 354}], {
             RGBColor[
             0.1996644579713909, 0.3271903831587082, 0.9346819675531508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 371}], {
             RGBColor[
             0.18501189214807195`, 0.3117896074520688, 0.9338475256060415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 388}], {
             RGBColor[
             0.20149520910929605`, 0.3291146186809729, 0.9347862261221009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 391}], {
             RGBColor[
             0.18230154859335337`, 0.30894086453035285`, 0.9336931755501943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 179}], {
             RGBColor[
             0.39396314610535543`, 0.515635700812435, 0.9463286881882242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 232}], {
             RGBColor[
             0.3145355236290795, 0.4455942655029455, 0.9413091233699418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 257}], {
             RGBColor[
             0.3285413065471964, 0.4589876995901452, 0.9421553394288851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 275}], {
             RGBColor[
             0.28636427371918854`, 0.4159844956872421, 0.939704812363203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 276}], {
             RGBColor[
             0.27841767131860123`, 0.407632112720532, 0.9392522651124343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 279}], {
             RGBColor[
             0.5031062098123048, 0.6037853067748751, 0.9552337277677017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 288}], {
             RGBColor[
             0.3196747008606359, 0.4509958666159675, 0.9416017919105475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 195}], {
             RGBColor[
             0.20922588183301488`, 0.33724004586656203`, 0.9352264764972114]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 210}], {
             RGBColor[
             0.26112860842944113`, 0.3917931023423411, 0.9381822599936748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 247}], {
             RGBColor[
             0.20711572977977888`, 0.33502214226724336`, 0.9351063064594698]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 249}], {
             RGBColor[
             0.2628399368216051, 0.3935612687084925, 0.9382808361360453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 253}], {
             RGBColor[
             0.20384820267597584`, 0.3315877641079622, 0.9349202256247814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 266}], {
             RGBColor[
             0.22467790350563632`, 0.35348110035924685`, 0.9361064462722496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 315}], {
             RGBColor[
             0.21772472600366666`, 0.3461728699477604, 0.9357104730998167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 316}], {
             RGBColor[
             0.2254786330368893, 0.3543227178657783, 0.9361520466344813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 358}], {
             RGBColor[
             0.20368965097586314`, 0.3314211162183854, 0.9349111963400162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 359}], {
             RGBColor[
             0.20190369877404518`, 0.3295439672183649, 0.9348094890042022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 362}], {
             RGBColor[
             0.20288427131655484`, 0.3305746111324327, 0.934865331159871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 363}], {
             RGBColor[
             0.21825217126115545`, 0.34672724835534197`, 0.9357405103269454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 369}], {
             RGBColor[
             0.20360056980323105`, 0.3313274862578765, 0.9349061232990186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 397}], {
             RGBColor[
             0.21476341163145843`, 0.34306034078439396`, 0.9355418306271915]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 192}], {
             RGBColor[
             0.1875835174154828, 0.3144925486585769, 0.9339939758606419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 283}], {
             RGBColor[
             0.2012631111576979, 0.32887066901798323`, 0.9347730084871156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 294}], {
             RGBColor[
             0.19175282420721007`, 0.318874754446001, 0.9342314117144941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 320}], {
             RGBColor[
             0.19466927104284892`, 0.32194012498366686`, 0.9343974990472872]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 347}], {
             RGBColor[
             0.19569856946522865`, 0.3230219828868772, 0.9344561160697312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 380}], {
             RGBColor[
             0.20683506244234898`, 0.3347271431002675, 0.9350903228698133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 381}], {
             RGBColor[
             0.19485465175919953`, 0.32213497187036766`, 0.9344080562048372]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 384}], {
             RGBColor[
             0.19155187583051508`, 0.31866354496123156`, 0.9342199680017178]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 168}], {
             RGBColor[
             0.18811217327033666`, 0.31504819948074547`, 0.9340240820294996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 265}], {
             RGBColor[
             0.1910010224377346, 0.31808456311929695`, 0.9341885977159134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 291}], {
             RGBColor[
             0.1895972333261113, 0.3166090917576105, 0.9341086540027264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 304}], {
             RGBColor[
             0.1864549217267703, 0.3133063230326405, 0.9339297040057775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 378}], {
             RGBColor[
             0.19141895458300517`, 0.3185238363024048, 0.9342123983333115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 383}], {
             RGBColor[
             0.20018660218381945`, 0.3277391898318258, 0.9347117028936056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 154}], {
             RGBColor[
             0.23114091709829876`, 0.3602741374238645, 0.93647450533518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 180}], {
             RGBColor[
             0.2576563148367751, 0.3881435016203197, 0.9379845180103705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 198}], {
             RGBColor[
             0.3050387614583694, 0.43382537545233274`, 0.9408337346263971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 236}], {
             RGBColor[
             0.2537723278978401, 0.38406118508850384`, 0.9377633307000419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 267}], {
             RGBColor[
             0.25637803396755154`, 0.3867999473790775, 0.9379117218059152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 284}], {
             RGBColor[
             0.26668400229217915`, 0.3976321735243937, 0.9384986314556889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 332}], {
             RGBColor[
             0.24255699042787615`, 0.37227315431410535`, 0.9371246338227324]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 367}], {
             RGBColor[
             0.31592573046277495`, 0.4432551208089762, 0.9415274426643891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 383}], {
             RGBColor[
             0.2325615956471479, 0.3617673606549275, 0.9365554108768314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 398}], {
             RGBColor[
             0.3414317727237982, 0.4653471726445155, 0.943152665123154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 161}], {
             RGBColor[
             0.1909498488692258, 0.3180307764542026, 0.9341856834568915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 184}], {
             RGBColor[
             0.18277753601960423`, 0.3094411574946885, 0.933720282329959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[
             0.18871819494406902`, 0.31568516668383156`, 0.9340585940672899]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 372}], {
             RGBColor[
             0.18825648302408265`, 0.31519987818169937`, 0.9340323002564883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 180}], {
             RGBColor[
             0.2320279298273124, 0.36120644404191316`, 0.9365250193978796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 236}], {
             RGBColor[
             0.22814394288837742`, 0.3571241275100973, 0.936303832087551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 267}], {
             RGBColor[
             0.23074964895808886`, 0.359862889800671, 0.9364522231934242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 286}], {
             RGBColor[
             0.2001789472954632, 0.3277311440588154, 0.9347112669590381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 291}], {
             RGBColor[
             0.1963438417799771, 0.3237002050023056, 0.9344928633734613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 332}], {
             RGBColor[
             0.2169286054184135, 0.3453360967356988, 0.9356651352102414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 383}], {
             RGBColor[
             0.20693321063768522`, 0.33483030307652095`, 0.9350959122643404]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 170}], {
             RGBColor[
             0.21937286170598153`, 0.34790516506873237`, 0.9358043319898652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 171}], {
             RGBColor[
             0.19802203394015824`, 0.32546409136618454`, 0.9345884339343208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 199}], {
             RGBColor[
             0.1967855567491959, 0.3241644754413012, 0.9345180183874995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 261}], {
             RGBColor[
             0.23352567596023666`, 0.3627806701902061, 0.9366103138244327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.19737174909206562`, 0.3247806007603985, 0.9345514011742322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 306}], {
             RGBColor[
             0.20489683816901277`, 0.33268994649847444`, 0.9349799438647926]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 342}], {
             RGBColor[
             0.19539787597679303`, 0.32270593496546307`, 0.9344389920204009]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 353}], {
             RGBColor[
             0.19855109199898685`, 0.3260201649302318, 0.9346185630080999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 361}], {
             RGBColor[
             0.21235865222551553`, 0.3405327861781953, 0.9354048831365458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 165}], {
             RGBColor[
             0.8638677055732559, 0.5798421452000351, 0.5836596867408057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 221}], {
             RGBColor[
             0.866647121618338, 0.4442317532509077, 0.20875073029347097`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 245}], {
             RGBColor[
             0.8249079613041663, 0.19245908208786985`, 0.17148519791537548`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 255}], {
             RGBColor[
             0.833173631408902, 0.25599264455260395`, 0.17940041294240955`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 328}], {
             RGBColor[
             0.850258311685, 0.36981399504742796`, 0.1950755055586017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 364}], {
             RGBColor[
             0.8243314936689592, 0.18802809923393973`, 0.1709331718568741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 386}], {
             RGBColor[
             0.795873240259372, 0.5261038848053603, 0.5770472868303405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 400}], {
             RGBColor[
             0.8405821739101607, 0.3129379486613033, 0.18649484160836693`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 181}], {
             RGBColor[
             0.19115892919796787`, 0.31825053313616897`, 0.9341975902723066]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 191}], {
             RGBColor[
             0.1973089788218841, 0.3247146252265727, 0.9345478265002056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 334}], {
             RGBColor[
             0.1861875662547559, 0.3130253154802374, 0.9339144785071631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 365}], {
             RGBColor[
             0.18416233691758455`, 0.3108966710399138, 0.9337991446924696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 370}], {
             RGBColor[
             0.18724094908895864`, 0.3141324876273136, 0.9339744671012307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 209}], {
             RGBColor[
             0.336799320476102, 0.4661403761955148, 0.94268153277416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 241}], {
             RGBColor[
             0.3009846875478195, 0.43090972620672763`, 0.9405535979845862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 270}], {
             RGBColor[
             0.3489276916060272, 0.4766453616785984, 0.9434543418578613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 310}], {
             RGBColor[
             0.30917761379090525`, 0.4395210111497373, 0.9410201730137817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 323}], {
             RGBColor[
             0.3687236016444134, 0.49379158398248, 0.9447157197406713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 324}], {
             RGBColor[
             0.4859428845919035, 0.5904387279012617, 0.9535338248669657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 346}], {
             RGBColor[
             0.34491127963015633`, 0.47316654749583464`, 0.9431984196383325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 390}], {
             RGBColor[
             0.3007335296132649, 0.43064574329317795`, 0.9405392949117681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 215}], {
             RGBColor[
             0.1817543271405076, 0.3083657000875679, 0.9336620120979963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 218}], {
             RGBColor[
             0.18568639672443343`, 0.31249855452788494`, 0.9338859376438252]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 329}], {
             RGBColor[
             0.18547778561514033`, 0.3122792910253096, 0.9338740575497635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 349}], {
             RGBColor[
             0.191248937492894, 0.31834513756099186`, 0.9342027161115474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 217}], {
             RGBColor[
             0.7263465347719837, 0.7798834744139984, 0.7188240157462833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 220}], {
             RGBColor[
             0.5477229997143326, 0.6437052316648666, 0.9575379073944208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 233}], {
             RGBColor[
             0.7095149174779228, 0.7707139896565038, 0.9521005122991707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 244}], {
             RGBColor[
             0.7071944520529801, 0.7689833903419949, 0.9560284549892878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 263}], {
             RGBColor[
             0.42578806203725694`, 0.5430467428327064, 0.9483991221427692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 264}], {
             RGBColor[
             0.5914575736276367, 0.6779711437656651, 0.9618285011853527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 307}], {
             RGBColor[
             0.403988994027505, 0.524165485775675, 0.9470101048053469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 312}], {
             RGBColor[
             0.38126624461740655`, 0.5039445125232649, 0.9455819912605958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 321}], {
             RGBColor[
             0.5069925116479708, 0.6106383865650169, 0.9543314541731429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 341}], {
             RGBColor[
             0.3979292657890303, 0.5189168537463054, 0.9466239842803985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 348}], {
             RGBColor[
             0.39638156393997953`, 0.5175763121944144, 0.946525366087156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 366}], {
             RGBColor[
             0.4270114418839008, 0.5441063729670104, 0.948477074824805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 176}], {
             RGBColor[
             0.21656199837052442`, 0.34495076948413805`, 0.9356442574812107]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 184}], {
             RGBColor[
             0.19128276610466352`, 0.31838069357681953`, 0.9342046426009427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 195}], {
             RGBColor[
             0.20065168741435874`, 0.3282280238972294, 0.9347381888094528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 250}], {
             RGBColor[
             0.22890128499152032`, 0.3579201420787632, 0.9363469615999377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 344}], {
             RGBColor[
             0.1953522686165181, 0.3226579987381405, 0.9344363947487033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.19722342502912832`, 0.3246247027659626, 0.9345429543382737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 363}], {
             RGBColor[
             0.20967797684249928`, 0.3377152263860093, 0.9352522226391868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 372}], {
             RGBColor[
             0.19676171310914198`, 0.3241394142638304, 0.934516660527472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 191}], {
             RGBColor[
             0.239776323432642, 0.3693504969976439, 0.936966278950982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 211}], {
             RGBColor[
             0.24710920905835015`, 0.37705782472206506`, 0.9373838759393338]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 214}], {
             RGBColor[
             0.25603696286442035`, 0.3864414600245297, 0.9378922983111614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 248}], {
             RGBColor[
             0.24516386461647438`, 0.3750131443716921, 0.9372730914512483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 263}], {
             RGBColor[
             0.33214075614847005`, 0.45873834938016844`, 0.9425079759974546]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 312}], {
             RGBColor[
             0.28761893872861966`, 0.41963611907072695`, 0.9396908451152812]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 340}], {
             RGBColor[
             0.23763180163327896`, 0.367096468615978, 0.9368441516070439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 348}], {
             RGBColor[
             0.3027342580511927, 0.4332679187418763, 0.9406342199418414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 167}], {
             RGBColor[
             0.2885245503262027, 0.4204485142001573, 0.9397475246726753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 174}], {
             RGBColor[
             0.3053955889489409, 0.4350613598921163, 0.9408225323352425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.2667189772067604, 0.39766893437715617`, 0.9385006232253336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 222}], {
             RGBColor[
             0.24959037113759353`, 0.3796656833821117, 0.9375251744491964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 226}], {
             RGBColor[
             0.35601753306005335`, 0.4789075435482711, 0.944048117850775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 395}], {
             RGBColor[
             0.36771682090515007`, 0.4886248797144314, 0.9449085278741232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 287}], {
             RGBColor[
             0.19544251078166353`, 0.3227528489753921, 0.9344415339065071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 292}], {
             RGBColor[
             0.19766905263223078`, 0.3250930856312453, 0.9345683321710234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 354}], {
             RGBColor[
             0.20840265875823133`, 0.3363747862196069, 0.9351795951609518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 371}], {
             RGBColor[
             0.1937500929349124, 0.3209740105129675, 0.9343451532138425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 374}], {
             RGBColor[
             0.1955858495365969, 0.322903507095029, 0.9344496968365499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 388}], {
             RGBColor[
             0.21023340989613648`, 0.33829902174187165`, 0.935283853729902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 389}], {
             RGBColor[
             0.20180063292388895`, 0.3294356384750984, 0.934803619556508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 391}], {
             RGBColor[
             0.1910397493801938, 0.3181252675912516, 0.9341908031579952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 182}], {
             RGBColor[
             0.6226406331298818, 0.6984050769847048, 0.9667215385795859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 256}], {
             RGBColor[
             0.624029163944416, 0.6996077525866663, 0.9668100145352584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 281}], {
             RGBColor[
             0.6627187385434833, 0.7331187175098175, 0.9692752800168635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 311}], {
             RGBColor[
             0.5997467789297788, 0.6780206465223158, 0.965283080943369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 328}], {
             RGBColor[
             0.8831401501680374, 0.7104796109326978, 0.6014297849392954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 386}], {
             RGBColor[
             0.8287550787424094, 0.8667695006906301, 0.9834015662110343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 400}], {
             RGBColor[
             0.873464012393198, 0.6536035645465732, 0.5928491209890607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 169}], {
             RGBColor[
             0.9427417968791698, 0.9548740993356628, 0.9051840770091248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 178}], {
             RGBColor[
             0.7156925694809679, 0.7734991059400932, 0.884905461880064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 197}], {
             RGBColor[
             0.9770032019247867, 0.9814553758280588, 0.8828706575837489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.9087289042908429, 0.6022050523179494, 0.4973324699831219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 300}], {
             RGBColor[
             0.9521971792667703, 0.9624135645920178, 0.9060859398221737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 319}], {
             RGBColor[
             0.7215283330281927, 0.7785525624499918, 0.8852776399757938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 174}], {
             RGBColor[
             0.3271254190729118, 0.4577613290244936, 0.9420651203310438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 183}], {
             RGBColor[
             0.33012064304919175`, 0.46035564148841296`, 0.9422559733542398]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 189}], {
             RGBColor[
             0.2884488073307313, 0.4203689035095335, 0.9397432112211349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 222}], {
             RGBColor[
             0.2713202012615644, 0.4023656525144891, 0.9387677624449977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 238}], {
             RGBColor[
             0.3001182809431252, 0.43263426016352036`, 0.9404077704799216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 246}], {
             RGBColor[
             0.6152498673613919, 0.6911955828537762, 0.9666225650716829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 269}], {
             RGBColor[
             0.5269179419290838, 0.6213796361571894, 0.958033512915055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 272}], {
             RGBColor[
             0.5255938312060932, 0.6203452307967748, 0.9579015379327056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 309}], {
             RGBColor[
             0.30392546223642514`, 0.4366358490920146, 0.940624583822355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 395}], {
             RGBColor[
             0.389446651029121, 0.5113248488468087, 0.9461511158699245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 265}], {
             RGBColor[
             0.18709388052696674`, 0.31397790924397473`, 0.9339660917641938]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 304}], {
             RGBColor[
             0.18254777981600245`, 0.3091996691573183, 0.9337071980540577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 378}], {
             RGBColor[
             0.18751181267223727`, 0.3144171824270826, 0.9339898923815917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 177}], {
             RGBColor[
             0.8953206105495907, 0.9193683682944271, 0.9898776731680061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 178}], {
             RGBColor[
             0.668739474081812, 0.7383666179007873, 0.9696437049697588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 197}], {
             RGBColor[
             0.9300501065256308, 0.9463228877887528, 0.9676089006734437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 239}], {
             RGBColor[
             0.8617758088916869, 0.5670725642786435, 0.5820707130728167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 300}], {
             RGBColor[
             0.9052440838676142, 0.9272810765527117, 0.9908241829118685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 319}], {
             RGBColor[
             0.6745752376290368, 0.7434200744106859, 0.9700158830654886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 171}], {
             RGBColor[
             0.21031358554217228`, 0.3383832914292848, 0.9352884196143345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 187}], {
             RGBColor[
             0.33329236872326556`, 0.45597611149735384`, 0.9427190170162062]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 261}], {
             RGBColor[
             0.2458172275622507, 0.3756998702533064, 0.9373102995044464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 299}], {
             RGBColor[
             0.20966330069407968`, 0.3376998008234987, 0.9352513868542458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 306}], {
             RGBColor[
             0.21718838977102684`, 0.3456091465615747, 0.9356799295448063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 353}], {
             RGBColor[
             0.2108426436010009, 0.33893936499333205`, 0.9353185486881135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 361}], {
             RGBColor[
             0.22465020382752957`, 0.3534519862412956, 0.9361048688165594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 299}], {
             RGBColor[
             0.18831247292825637`, 0.31525872712095093`, 0.9340354887987012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 306}], {
             RGBColor[
             0.19583756200520352`, 0.3231680728590269, 0.9344640314892618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 342}], {
             RGBColor[
             0.18633859981298379`, 0.3131840613260155, 0.9339230796448701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 353}], {
             RGBColor[
             0.1894918158351776, 0.3164982912907842, 0.9341026506325689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 208}], {
             RGBColor[
             0.9084092508392714, 0.5876736275457447, 0.4679228968183917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 225}], {
             RGBColor[
             0.8542567503473041, 0.5474377891348923, 0.5796464760848401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 240}], {
             RGBColor[
             0.8277460748309535, 0.21427406632403376`, 0.17420297863381767`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 243}], {
             RGBColor[
             0.8966647112599999, 0.5803804357819402, 0.5534478412456459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 285}], {
             RGBColor[
             0.9090011322761398, 0.5869841292419617, 0.39020330546201376`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 337}], {
             RGBColor[
             0.9089250228286312, 0.5868213388295864, 0.3819192617937752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 357}], {
             RGBColor[
             0.8404518577056951, 0.3119362812088553, 0.18637005066379952`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 399}], {
             RGBColor[
             0.8751896442741957, 0.46528659439177383`, 0.21510344124823602`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 176}], {
             RGBColor[
             0.25807437232061936`, 0.38858290654221544`, 0.9380083257656147]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 209}], {
             RGBColor[
             0.3086611648699239, 0.43934003290171275`, 0.940977513192154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 250}], {
             RGBColor[
             0.27041365894161523`, 0.40155227913684066`, 0.9387110298843417]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 323}], {
             RGBColor[
             0.3405854460382354, 0.4669912406886779, 0.9430117001586653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 354}], {
             RGBColor[
             0.24916626557073213`, 0.3792199215414943, 0.9375010222645717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 388}], {
             RGBColor[
             0.2509970167086373, 0.38114415706375904`, 0.9376052808335218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 183}], {
             RGBColor[
             0.34699168167192995`, 0.474968487180372, 0.943330981016807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 189}], {
             RGBColor[
             0.3053198459534695, 0.4349817492014926, 0.9408182188837021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 238}], {
             RGBColor[
             0.3169893195658634, 0.44724710585547944`, 0.9414827781424888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 246}], {
             RGBColor[
             0.6321209059841302, 0.7058084285457353, 0.96769757273425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 269}], {
             RGBColor[
             0.543788980551822, 0.6359924818491485, 0.9591085205776222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 272}], {
             RGBColor[
             0.5424648698288314, 0.6349580764887339, 0.9589765455952728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 309}], {
             RGBColor[
             0.32079650085916334`, 0.45124869478397367`, 0.9416995914849222]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 325}], {
             RGBColor[
             0.31656779052141654`, 0.4468040521032807, 0.9414587726870038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 395}], {
             RGBColor[
             0.4063176896518592, 0.5259376945387678, 0.9472261235324917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 178}], {
             RGBColor[
             0.3616708025324146, 0.48517771913218966`, 0.9443580450417194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 213}], {
             RGBColor[
             0.25213492118930436`, 0.3823401668202513, 0.9376700828103168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 227}], {
             RGBColor[
             0.24456047357150879`, 0.37437894212623135`, 0.9372387292238745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 278}], {
             RGBColor[
             0.2699086210585896, 0.40102145230052944`, 0.93868226872404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 296}], {
             RGBColor[
             0.26330595896968834`, 0.39408163581213873`, 0.9383062568858402]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 314}], {
             RGBColor[
             0.25716282410855407`, 0.38762481157584006`, 0.9379564144434523]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 319}], {
             RGBColor[
             0.3675065660796395, 0.49023117564208835`, 0.944730223137449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 352}], {
             RGBColor[
             0.2606268889022622, 0.3912657633084208, 0.9381536878088295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 250}], {
             RGBColor[
             0.24600820440775967`, 0.3759005990265677, 0.9373211753532731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 344}], {
             RGBColor[
             0.21245918803275743`, 0.3406384556859449, 0.9354106085020388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 354}], {
             RGBColor[
             0.22476081103687653`, 0.35356824143122134`, 0.936111167733503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 356}], {
             RGBColor[
             0.21433034444536764`, 0.34260515971376704`, 0.9355171680916091]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 372}], {
             RGBColor[
             0.2138686325253813, 0.34211987121163484`, 0.9354908742808075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 388}], {
             RGBColor[
             0.22659156217478169`, 0.35549247695348607`, 0.9362154263024531]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 197}], {
             RGBColor[
             0.9295820155952076, 0.9459496447868232, 0.9675642537426303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 225}], {
             RGBColor[
             0.8897813970600477, 0.9149515498158103, 0.9893493380404593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 243}], {
             RGBColor[
             0.9321893579727436, 0.9478941964628581, 0.9631507032012652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 252}], {
             RGBColor[
             0.6322093663988135, 0.7067582685174405, 0.9673012182198607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 300}], {
             RGBColor[
             0.904775992937191, 0.9269078335507821, 0.990779535981055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 337}], {
             RGBColor[
             0.9444496695413749, 0.9543350995105044, 0.7916221237493946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 367}], {
             RGBColor[
             0.6349673392184779, 0.7091470859540894, 0.9674769538091501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 398}], {
             RGBColor[
             0.6604733814795012, 0.7312391377896288, 0.9691021762679148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 197}], {
             RGBColor[
             0.7030008791274289, 0.7649478943931832, 0.947330285544383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 274}], {
             RGBColor[
             0.46738436670940764`, 0.5781669894131862, 0.9513005905019778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 278}], {
             RGBColor[
             0.349928065209785, 0.47283535767355744`, 0.9436893135230188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 300}], {
             RGBColor[
             0.6781948564694122, 0.7459060831571422, 0.9705455677828076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 319}], {
             RGBColor[
             0.4475260102308348, 0.5620450810151163, 0.9497372679364278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 352}], {
             RGBColor[
             0.3406463330534576, 0.4630796686814488, 0.9431607326078082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 232}], {
             RGBColor[
             0.374520452238133, 0.49753308772821003`, 0.9451360369712756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 257}], {
             RGBColor[
             0.38852623515624984`, 0.5109265218154098, 0.9459822530302189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 275}], {
             RGBColor[
             0.34634920232824207`, 0.46792331791250663`, 0.9435317259645368]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 279}], {
             RGBColor[
             0.5630911384213583, 0.6557241290001397, 0.9590606413690353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 285}], {
             RGBColor[
             0.7240735565365042, 0.7787875887954807, 0.7800674551938157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 288}], {
             RGBColor[
             0.3796596294696894, 0.502934688841232, 0.9454287055118813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 399}], {
             RGBColor[
             0.6902620685345601, 0.6570900539452929, 0.6049675909800379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 198}], {
             RGBColor[
             0.30592577418738304`, 0.43475768207038135`, 0.9408842486890967]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 236}], {
             RGBColor[
             0.2546593406268537, 0.3849934917065525, 0.9378138447627414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 262}], {
             RGBColor[
             0.23634740435871976`, 0.36574648564492557`, 0.9367710070823533]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 267}], {
             RGBColor[
             0.25726504669656514`, 0.3877322539971262, 0.9379622358686148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 284}], {
             RGBColor[
             0.2675710150211928, 0.3985644801424423, 0.9385491455183885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 286}], {
             RGBColor[
             0.22669434503393948`, 0.3556005082552706, 0.9362212796342286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 332}], {
             RGBColor[
             0.2434440031568898, 0.373205460932154, 0.937175147885432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 367}], {
             RGBColor[
             0.31681274319178854`, 0.44418742742702483`, 0.9415779567270888]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 398}], {
             RGBColor[
             0.3423187854528118, 0.46627947926256413`, 0.9432031791858535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 191}], {
             RGBColor[
             0.2010737277844803, 0.3286716150851321, 0.9347622233841785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 211}], {
             RGBColor[
             0.20840661341018846`, 0.33637894280955327`, 0.9351798203725303]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 214}], {
             RGBColor[
             0.21733436721625865`, 0.34576257811201794`, 0.9356882427443579]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 305}], {
             RGBColor[
             0.18857843384879308`, 0.3155382689113313, 0.9340506348796719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 334}], {
             RGBColor[
             0.18995231521735206`, 0.3169823053387968, 0.934128875391136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 340}], {
             RGBColor[
             0.19892920598511726`, 0.3264175867034662, 0.9346400960402405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 365}], {
             RGBColor[
             0.1879270858801807, 0.3148536608984732, 0.9340135415764423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 370}], {
             RGBColor[
             0.19100569805155482`, 0.318089477485873, 0.9341888639852036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 256}], {
             RGBColor[
             0.34992025301800456`, 0.4775050684860661, 0.9435175869933449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 281}], {
             RGBColor[
             0.38860982761707186`, 0.5110160334092172, 0.94598285247495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 311}], {
             RGBColor[
             0.32563786800336725`, 0.45591796242171545`, 0.9419906534014555]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 386}], {
             RGBColor[
             0.5546461678159978, 0.6446668165900299, 0.9601091386691207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 238}], {
             RGBColor[
             0.31998454354214334`, 0.4498414183193987, 0.9416736311656848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 246}], {
             RGBColor[
             0.63511612996041, 0.7084027410096546, 0.967888425757446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 269}], {
             RGBColor[
             0.546784204528102, 0.6385867943130678, 0.9592993736008182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 272}], {
             RGBColor[
             0.5454600938051113, 0.6375523889526532, 0.9591673986184688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 280}], {
             RGBColor[
             0.30076148412422865`, 0.4296367640588081, 0.9405789063698025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 309}], {
             RGBColor[
             0.3237917248354433, 0.45384300724789295`, 0.9418904445081182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 325}], {
             RGBColor[
             0.3195630144976964, 0.44939836456720006`, 0.9416496257101998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 339}], {
             RGBColor[
             0.30076734139659483`, 0.42964292042343744`, 0.9405792399327987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 395}], {
             RGBColor[
             0.40931291362813915`, 0.5285320070026871, 0.9474169765556877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 343}], {
             RGBColor[
             0.18256566753029357`, 0.30921847027918486`, 0.933708216732924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 356}], {
             RGBColor[
             0.18905111217950674`, 0.3160350838064485, 0.9340775532113412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 369}], {
             RGBColor[
             0.1868540625349533, 0.3137258453290297, 0.9339524344843275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 372}], {
             RGBColor[
             0.18858940025952037`, 0.31554979530431626`, 0.9340512594005395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 198}], {
             RGBColor[
             0.3764542800383526, 0.5004875090521163, 0.9452083117319626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 205}], {
             RGBColor[
             0.3748090292582385, 0.49906247551909, 0.9451034778070919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 208}], {
             RGBColor[
             0.6963078073762952, 0.755957556681333, 0.8560508247348155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 210}], {
             RGBColor[
             0.35262704416750634`, 0.4795636552057607, 0.9437005295213796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 219}], {
             RGBColor[
             0.36836286362019555`, 0.4934791308371227, 0.9446927338327562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 249}], {
             RGBColor[
             0.35433837255967027`, 0.48133182157191207`, 0.9437991056637501]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 284}], {
             RGBColor[
             0.33809952087216233`, 0.4642943071241772, 0.9428732085612545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 293}], {
             RGBColor[
             0.374247320413842, 0.49857595155038115`, 0.9450676862162266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 338}], {
             RGBColor[
             0.3169003211264983, 0.4420126040845884, 0.9416659454971446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 188}], {
             RGBColor[
             0.20431810644449144`, 0.33208166276229184`, 0.934946985949238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 228}], {
             RGBColor[
             0.20522346006975262`, 0.3330332468251766, 0.934998544498846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 238}], {
             RGBColor[
             0.24841689496046435`, 0.37843228551726205`, 0.9374583467169113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 273}], {
             RGBColor[
             0.19433831903215518`, 0.3215922734368583, 0.9343786518198778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 322}], {
             RGBColor[
             0.20337835674212623`, 0.3310939262415335, 0.9348934685939234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 330}], {
             RGBColor[
             0.19639093276449526`, 0.3237497006127751, 0.9344955451353647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 206}], {
             RGBColor[
             0.5826167692195937, 0.6701866792756657, 0.9613440852325792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 220}], {
             RGBColor[
             0.5353714211663698, 0.63317812373389, 0.9567035702854296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 261}], {
             RGBColor[
             0.3474451829775207, 0.4708516166188276, 0.9435249988507737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 321}], {
             RGBColor[
             0.494640933100008, 0.6001112786340405, 0.9534971170641517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 228}], {
             RGBColor[
             0.20268995802939208`, 0.3303703755474506, 0.9348542653056278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 238}], {
             RGBColor[
             0.2458833929201038, 0.375769414239536, 0.9373140675236933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 273}], {
             RGBColor[
             0.19180481699179464`, 0.3189294021591323, 0.9342343726266598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 322}], {
             RGBColor[
             0.20084485470176572`, 0.3284310549638075, 0.9347491894007052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 330}], {
             RGBColor[
             0.19385743072413472`, 0.32108682933504906`, 0.9343512659421467]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 222}], {
             RGBColor[
             0.24951462814212214`, 0.379586072691488, 0.937520860997656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 226}], {
             RGBColor[
             0.35594179006458193`, 0.47882793285764735`, 0.9440438043992346]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 395}], {
             RGBColor[
             0.3676410779096787, 0.4885452690238077, 0.9449042144225828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 212}], {
             RGBColor[
             0.6867778683351773, 0.7513832913392242, 0.9534033725466657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 221}], {
             RGBColor[
             0.9292638455200164, 0.8080779972178733, 0.5995947563336426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 255}], {
             RGBColor[
             0.8957903553105804, 0.6198388885195696, 0.570244438982581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 268}], {
             RGBColor[
             0.8177911045280821, 0.8581558703042615, 0.9638348308947651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 270}], {
             RGBColor[
             0.6576592800193992, 0.7261622336829004, 0.951547961847741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 274}], {
             RGBColor[
             0.7246489008143902, 0.7831056857849257, 0.9561147753018562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 295}], {
             RGBColor[
             0.6926270864337125, 0.7564495900659256, 0.953776079551644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 324}], {
             RGBColor[
             0.7946744730052755, 0.8399555999055638, 0.9616274448568455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 351}], {
             RGBColor[
             0.9330043693197932, 0.948887212220239, 0.9751255904637988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 211}], {
             RGBColor[
             0.2145566630341047, 0.342843034899957, 0.9355300566004294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 214}], {
             RGBColor[
             0.2234844168401749, 0.3522266702024217, 0.9360384789722569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 312}], {
             RGBColor[
             0.25506639270437426`, 0.3854213292486189, 0.9378370257763766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 334}], {
             RGBColor[
             0.1961023648412683, 0.3234463974292005, 0.934479111619035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 340}], {
             RGBColor[
             0.2050792556090335, 0.33288167879387, 0.9349903322681394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 365}], {
             RGBColor[
             0.19407713550409694`, 0.321317752988877, 0.9343637778043414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 370}], {
             RGBColor[
             0.19715574767547106`, 0.3245535695762768, 0.9345391002131025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 292}], {
             RGBColor[
             0.18800332047098128`, 0.31493378828695684`, 0.9340178830236096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 320}], {
             RGBColor[
             0.18870690253434044`, 0.31567329764522667`, 0.9340579509812614]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 347}], {
             RGBColor[
             0.18973620095672017`, 0.3167551555484371, 0.9341165680037053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 374}], {
             RGBColor[
             0.18592011737534742`, 0.3127442097507407, 0.933899247689136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 382}], {
             RGBColor[
             0.18175632170203998`, 0.30836779649820095`, 0.9336621256853248]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 384}], {
             RGBColor[
             0.1855895073220066, 0.3123967176227914, 0.933880419935692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 248}], {
             RGBColor[
             0.20247189401375032`, 0.330141176440954, 0.9348418468825339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 305}], {
             RGBColor[
             0.18458905889423072`, 0.311345182893105, 0.933823445877761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 334}], {
             RGBColor[
             0.1859629402627897, 0.3127892193205704, 0.9339016863892251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 360}], {
             RGBColor[
             0.18609708652812662`, 0.31293021555080397`, 0.9339093258205844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 201}], {
             RGBColor[
             0.9717877162352071, 0.9761148093624215, 0.8086618740541351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 208}], {
             RGBColor[
             0.9937734715667986, 0.9910458830658546, 0.7058012226950569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 223}], {
             RGBColor[
             0.9622169086067585, 0.8752522636294204, 0.4543198910461633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 230}], {
             RGBColor[
             0.906134992146644, 0.5640310832233217, 0.4054017460858296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 242}], {
             RGBColor[
             0.9234025469352043, 0.6967570760189528, 0.42193717605226866`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 357}], {
             RGBColor[
             0.9258160784332223, 0.7153085367289651, 0.42424837654046466`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 364}], {
             RGBColor[
             0.9061043939482173, 0.5637958920619978, 0.4053724452164604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 385}], {
             RGBColor[
             0.9944784929138155, 0.9905983795896796, 0.6403962123397537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 387}], {
             RGBColor[
             0.7643288542489235, 0.8116893614464729, 0.8013257295322668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 247}], {
             RGBColor[
             0.1997381438211963, 0.32726783165880646`, 0.9346861638532888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 253}], {
             RGBColor[
             0.1964706167173933, 0.3238334534995253, 0.9345000830186004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 315}], {
             RGBColor[
             0.21034714004508412`, 0.3384185593393235, 0.9352903304936357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 316}], {
             RGBColor[
             0.21810104707830674`, 0.3465684072573414, 0.9357319040283003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 343}], {
             RGBColor[
             0.19193458883998876`, 0.3190658005995948, 0.9342417629414341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 358}], {
             RGBColor[
             0.1963120650172806, 0.3236668056099485, 0.9344910537338352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 359}], {
             RGBColor[
             0.19452611281546262`, 0.321789656609928, 0.9343893463980213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 362}], {
             RGBColor[
             0.1955066853579723, 0.3228203005239958, 0.9344451885536901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 363}], {
             RGBColor[
             0.21087458530257291`, 0.33897293774690507`, 0.9353203677207644]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 369}], {
             RGBColor[
             0.19622298384464848`, 0.3235731756494396, 0.9344859806928376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 372}], {
             RGBColor[
             0.19795832156921558`, 0.32539712562472617`, 0.9345848056090496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 397}], {
             RGBColor[
             0.2073858256728759, 0.33530603017595706`, 0.9351216880210106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 289}], {
             RGBColor[
             0.18795157808443957`, 0.3148794037580448, 0.934014936371242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 317}], {
             RGBColor[
             0.1925447584771704, 0.3197071275752621, 0.9342765111996065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 326}], {
             RGBColor[
             0.19087356510240117`, 0.3179505973785997, 0.9341813392092224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 327}], {
             RGBColor[
             0.19267128104236286`, 0.3198401108132733, 0.9342837164725208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 336}], {
             RGBColor[
             0.18504438325654066`, 0.31182375766712467`, 0.9338493759266024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 376}], {
             RGBColor[
             0.19966869054902864`, 0.32719483186616644`, 0.9346822085921858]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 252}], {
             RGBColor[
             0.6669388623748537, 0.7337127880117662, 0.9450324457252983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 300}], {
             RGBColor[
             0.9395054889132312, 0.9538623530451078, 0.9685107634864926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 205}], {
             RGBColor[
             0.35166297002886326`, 0.47901452236936815`, 0.9436286313802527]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 219}], {
             RGBColor[
             0.34521680439082036`, 0.47343117768740084`, 0.9432178874059169]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 236}], {
             RGBColor[
             0.3020417872484481, 0.43067536553856556`, 0.9406630613787681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 284}], {
             RGBColor[
             0.31495346164278715`, 0.44424635397445533`, 0.9413983621344152]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 332}], {
             RGBColor[
             0.29082644977848415`, 0.41888733476416706`, 0.9400243645014585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 367}], {
             RGBColor[
             0.36419518981338295`, 0.4898693012590379, 0.9444271733431154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 398}], {
             RGBColor[
             0.38970123207440616`, 0.5119613530945772, 0.9460523958018803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 216}], {
             RGBColor[
             0.19310022590756143`, 0.3202909590632723, 0.9343081442480269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 298}], {
             RGBColor[
             0.19174373818706897`, 0.31886520446274574`, 0.9342308942790887]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 299}], {
             RGBColor[
             0.18707599573729403`, 0.31395911119606756`, 0.93396507325188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 306}], {
             RGBColor[
             0.19460108481424115`, 0.32186845693414357`, 0.9343936159424405]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 342}], {
             RGBColor[
             0.18510212262202141`, 0.31188444540113214`, 0.9338526640980489]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 353}], {
             RGBColor[
             0.18825533864421526`, 0.31519867536590085`, 0.9340322350857477]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 361}], {
             RGBColor[
             0.2020628988707439, 0.32971129661386445`, 0.9348185552141937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 393}], {
             RGBColor[
             0.1849265278957996, 0.3116998842105244, 0.9338426642381596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 207}], {
             RGBColor[
             0.1859857863076916, 0.31281323196228517`, 0.9339029874376845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 333}], {
             RGBColor[
             0.18616349406283006`, 0.3130000140802582, 0.9339131076314446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 368}], {
             RGBColor[
             0.18469320535133593`, 0.3114546474227893, 0.9338293768644222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 223}], {
             RGBColor[
             0.9394729571932308, 0.8606549580209606, 0.6167978110210142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 230}], {
             RGBColor[
             0.8833910407331164, 0.5494337776148619, 0.5678796660606804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 245}], {
             RGBColor[
             0.8839369101698967, 0.553629569307468, 0.5684023912498125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 364}], {
             RGBColor[
             0.8833604425346897, 0.5491985864535379, 0.5678503651913112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 385}], {
             RGBColor[
             0.9717345415002878, 0.9760010739812197, 0.8028741323146045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 218}], {
             RGBColor[
             0.2171099632633392, 0.3455267153294672, 0.9356754632712151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 229}], {
             RGBColor[
             0.22512118954774685`, 0.35394702209546336`, 0.9361316907565649]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 260}], {
             RGBColor[
             0.23397057730885262`, 0.3632482897159762, 0.9366356502980638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 307}], {
             RGBColor[
             0.295856931076972, 0.42463269426460054`, 0.9402940731736436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 341}], {
             RGBColor[
             0.2897972028384973, 0.4193840622352309, 0.9399079526486953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 349}], {
             RGBColor[
             0.22267250403179975`, 0.35137329836257414`, 0.9359922417389372]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 366}], {
             RGBColor[
             0.31887937893336776`, 0.4445735814559359, 0.9417610431931018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 232}], {
             RGBColor[
             0.26042493590475796`, 0.3910534979034842, 0.9381421868843842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 257}], {
             RGBColor[
             0.27443071882287484`, 0.40444693199068393`, 0.9389884029433275]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 275}], {
             RGBColor[
             0.232253685994867, 0.3614437280877808, 0.9365378758776455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 280}], {
             RGBColor[
             0.23864655232395315`, 0.36816303593078636`, 0.9369019401576887]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 297}], {
             RGBColor[
             0.2163387830881471, 0.3447161560696932, 0.9356315457010966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 309}], {
             RGBColor[
             0.2616767930351678, 0.3923692791198713, 0.9382134782960043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 322}], {
             RGBColor[
             0.2128310735235297, 0.3410293309156486, 0.935431786830583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 325}], {
             RGBColor[
             0.2574480826974209, 0.38792463643917835`, 0.9379726594980861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 339}], {
             RGBColor[
             0.23865240959631934`, 0.3681691922954158, 0.9369022737206849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 224}], {
             RGBColor[
             0.1864844568543232, 0.3133373663243338, 0.9339313859875982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 276}], {
             RGBColor[
             0.2082458481435212, 0.33620996832117933`, 0.9351706650284246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 290}], {
             RGBColor[
             0.19592590704111568`, 0.32326092909316934`, 0.9344690626083623]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 297}], {
             RGBColor[
             0.2002775476373886, 0.32783477926980176`, 0.9347168821026446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 318}], {
             RGBColor[
             0.1940125074344074, 0.321249824789977, 0.9343600973313813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 345}], {
             RGBColor[
             0.18631088399028722`, 0.3131549302390768, 0.9339215012697695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 219}], {
             RGBColor[
             0.34357155361070624`, 0.4720061441543746, 0.9431130534810463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 284}], {
             RGBColor[
             0.313308210862673, 0.4428213204414291, 0.9412935282095445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 293}], {
             RGBColor[
             0.3494560104043527, 0.47710296486763304`, 0.9434880058645166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 338}], {
             RGBColor[
             0.292109011117009, 0.4205396174018403, 0.9400862651454345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 220}], {
             RGBColor[
             0.6830678662474279, 0.7522369451466808, 0.9691139391554754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 321}], {
             RGBColor[
             0.6423373781810662, 0.7191701000468311, 0.9659074859341975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 328}], {
             RGBColor[
             0.7999219852902167, 0.6448484807342735, 0.5933000289298582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 386}], {
             RGBColor[
             0.7455369138645886, 0.8011383704922057, 0.975271810201597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 254}], {
             RGBColor[
             0.18750231875154622`, 0.3144072037144869, 0.9339893517168534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 333}], {
             RGBColor[
             0.18793493502051017`, 0.3148619108426237, 0.9340139885733725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 230}], {
             RGBColor[
             0.9053767960647079, 0.5643648513182951, 0.465019014701602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 240}], {
             RGBColor[
             0.9123520994765446, 0.6179800899391169, 0.47169857312625524`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 242}], {
             RGBColor[
             0.9226443508532682, 0.6970908441139261, 0.4815544446680411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 357}], {
             RGBColor[
             0.9250578823512863, 0.7156423048239384, 0.4838656451562371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 385}], {
             RGBColor[
             0.9937202968318795, 0.9909321476846529, 0.7000134809555262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 387}], {
             RGBColor[
             0.7635706581669874, 0.8120231295414462, 0.8609429981480392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 241}], {
             RGBColor[
             0.2990278699570904, 0.4292148291621499, 0.9404289112980508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 270}], {
             RGBColor[
             0.34697087401529814`, 0.4749504646340207, 0.9433296551713259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 310}], {
             RGBColor[
             0.30722079620017617`, 0.4378261141051596, 0.9408954863272463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 323}], {
             RGBColor[
             0.36676678405368435`, 0.4920966869379023, 0.9445910330541359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 346}], {
             RGBColor[
             0.34295446203942725`, 0.47147165045125694`, 0.9430737329517971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 390}], {
             RGBColor[
             0.2987767120225358, 0.42895084624860025`, 0.9404146082252327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 249}], {
             RGBColor[
             0.3073650774594488, 0.4403600145758346, 0.9408164770263279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 266}], {
             RGBColor[
             0.26920304414348, 0.40027984622658896`, 0.9386420871625321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 293}], {
             RGBColor[
             0.3272740253136205, 0.45760414455430376`, 0.9420850575788042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 315}], {
             RGBColor[
             0.26224986664151034`, 0.39297161581510254`, 0.9382461139900993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 316}], {
             RGBColor[
             0.270003773674733, 0.40112146373312046`, 0.9386876875247638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 387}], {
             RGBColor[
             0.4198898949581986, 0.5356292280658739, 0.9485927029346032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 397}], {
             RGBColor[
             0.25928855226930214`, 0.38985908665173613`, 0.938077471517474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 214}], {
             RGBColor[
             0.23081730246588306`, 0.35993399792684283`, 0.9364560759606089]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 248}], {
             RGBColor[
             0.2199442042179371, 0.34850568227400514`, 0.9358368691006957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 263}], {
             RGBColor[
             0.30692109574993276`, 0.4322308872824815, 0.9410717536469021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 312}], {
             RGBColor[
             0.26239927833008236`, 0.39312865697304, 0.9382546227647286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 334}], {
             RGBColor[
             0.20343525046697647`, 0.3311537251536216, 0.9348967086073869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 340}], {
             RGBColor[
             0.21241214123474167`, 0.34058900651829105`, 0.9354079292564914]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 370}], {
             RGBColor[
             0.20448863330117922`, 0.3322608973006979, 0.9349566972014545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 268}], {
             RGBColor[
             0.5483496579696843, 0.6426701443947892, 0.9582447440009759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 270}], {
             RGBColor[
             0.38821783346100136`, 0.5106765077734281, 0.9459578749539519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 274}], {
             RGBColor[
             0.45520745425599235`, 0.5676199598754534, 0.950524688408067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 295}], {
             RGBColor[
             0.42318563987531466`, 0.5409638641564534, 0.9481859926578549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 310}], {
             RGBColor[
             0.34846775564587945`, 0.473552157244567, 0.9435237061098725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 324}], {
             RGBColor[
             0.5252330264468776, 0.6244698739960914, 0.9560373579630563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 351}], {
             RGBColor[
             0.6635629227613954, 0.7334014863107667, 0.9695355035700097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 373}], {
             RGBColor[
             0.34459378761093823`, 0.4694803712160838, 0.9433030893613046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 390}], {
             RGBColor[
             0.3400236714682391, 0.46467688938800766`, 0.9430428280078589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 227}], {
             RGBColor[
             0.2150440363795939, 0.343355295187321, 0.9355578117914507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 296}], {
             RGBColor[
             0.2337895217777734, 0.3630579888732283, 0.9366253394534165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 308}], {
             RGBColor[
             0.2120594900785835, 0.3402183477937941, 0.9353878462948488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 352}], {
             RGBColor[
             0.23111045171034733`, 0.3602421163695104, 0.9364727703764056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 248}], {
             RGBColor[
             0.22887195802400728`, 0.3578893175764699, 0.9363452914725232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 263}], {
             RGBColor[
             0.315848849556003, 0.4416145225849462, 0.9415801760187297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 312}], {
             RGBColor[
             0.2713270321361526, 0.4025122922755047, 0.9387630451365561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 340}], {
             RGBColor[
             0.22133989504081186`, 0.3499726418207558, 0.9359163516283189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 218}], {
             RGBColor[
             0.18692850160935742`, 0.31380408551593836`, 0.9339566736794921]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 229}], {
             RGBColor[
             0.19493972789376507`, 0.3222243922819345, 0.9344129011648419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 329}], {
             RGBColor[
             0.1867198905000643, 0.313584822013363, 0.9339447935854304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 349}], {
             RGBColor[
             0.192491042377818, 0.3196506685490453, 0.9342734521472142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 231}], {
             RGBColor[
             0.19095180161373265`, 0.3180328289124904, 0.9341857946628023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 235}], {
             RGBColor[
             0.1956123156574894, 0.32293132466613605`, 0.9344512040429815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 298}], {
             RGBColor[
             0.19835416070020614`, 0.3258131776490477, 0.9346073480619681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 313}], {
             RGBColor[
             0.2090389311379428, 0.3370435488326826, 0.9352158299316957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 361}], {
             RGBColor[
             0.20867332138388106`, 0.3366592698001664, 0.9351950089970731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 393}], {
             RGBColor[
             0.19153695040893678`, 0.31864785739682644`, 0.9342191180210391]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 396}], {
             RGBColor[
             0.19963425463605258`, 0.3271586375382656, 0.9346802475178853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 220}], {
             RGBColor[
             0.8144460532518553, 0.851406632354037, 0.7257595325601884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 230}], {
             RGBColor[
             0.9054039524770299, 0.5624674632894656, 0.3258325895022128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 233}], {
             RGBColor[
             0.9762379710154455, 0.9784153903456743, 0.7203221374649382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 242}], {
             RGBColor[
             0.9226715072655902, 0.6951934560850966, 0.34236801946865186`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 244}], {
             RGBColor[
             0.9739175055905028, 0.9766847910311653, 0.7242500801550553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 264}], {
             RGBColor[
             0.8581806271651595, 0.8856725444548357, 0.7300501263511203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 321}], {
             RGBColor[
             0.7737155651854934, 0.8183397872541874, 0.7225530793389106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 357}], {
             RGBColor[
             0.9250850387636083, 0.713744916795109, 0.34467921995684786`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 364}], {
             RGBColor[
             0.9053733542786032, 0.5622322721281416, 0.3258032886328436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 366}], {
             RGBColor[
             0.6937344954214235, 0.7518077736561808, 0.7166986999905727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 229}], {
             RGBColor[
             0.19887179747769093`, 0.3263572467222515, 0.9346368267106708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 260}], {
             RGBColor[
             0.20772118523879674`, 0.3356585143427644, 0.9351407862521698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 329}], {
             RGBColor[
             0.19065196008399016`, 0.31771767645368004`, 0.9341687191312593]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 349}], {
             RGBColor[
             0.19642311196174383`, 0.3237835229893623, 0.9344973776930432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 284}], {
             RGBColor[
             0.3068620452246301, 0.43723797575946177`, 0.9408827842352088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 293}], {
             RGBColor[
             0.34300984476630975`, 0.47151962018566573`, 0.943077261890181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 338}], {
             RGBColor[
             0.28566284547896603`, 0.414956272719873, 0.9396755211710989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 233}], {
             RGBColor[
             0.7976144359577942, 0.8422371475965424, 0.9590360291130758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 244}], {
             RGBColor[
             0.7952939705328516, 0.8405065482820335, 0.9629639718031929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 321}], {
             RGBColor[
             0.5950920301278422, 0.6821615445050555, 0.961266970987048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 341}], {
             RGBColor[
             0.4860287842689018, 0.590440011686344, 0.9535595010943037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 366}], {
             RGBColor[
             0.5151109603637722, 0.615629530907049, 0.9554125916387102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 239}], {
             RGBColor[
             0.8650356462249088, 0.43184524722399015`, 0.20720757963682196`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 255}], {
             RGBColor[
             0.8688348859370216, 0.46104786848874635`, 0.21084573587576866`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 268}], {
             RGBColor[
             0.7908356351545234, 0.6993648502734382, 0.6044361277879526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 324}], {
             RGBColor[
             0.7677190036317167, 0.6811645798747406, 0.602228741750033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 351}], {
             RGBColor[
             0.9060488999462345, 0.7900961921894157, 0.6157268873569864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 400}], {
             RGBColor[
             0.8762434284382803, 0.5179931725974458, 0.21794016454172604`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 333}], {
             RGBColor[
             0.21024933242430197`, 0.33831575732852015`, 0.9352847604943257]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 230}], {
             RGBColor[
             0.8738202331046678, 0.44857123188186093`, 0.21353768305270848`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 242}], {
             RGBColor[
             0.8910877878932282, 0.5812972246774919, 0.23007311301914762`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 245}], {
             RGBColor[
             0.8743661025414482, 0.452767023574467, 0.2140604082418407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 328}], {
             RGBColor[
             0.8997164529222819, 0.6301219365340252, 0.23765071588506692`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 364}], {
             RGBColor[
             0.8737896349062411, 0.4483360407205369, 0.2135083821833393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 385}], {
             RGBColor[
             0.9621637338718393, 0.8751385282482187, 0.44853214930663265`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 290}], {
             RGBColor[
             0.18877579274929696`, 0.3157457056290379, 0.9340618741770893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 318}], {
             RGBColor[
             0.18686239314258873`, 0.3137346013258456, 0.9339529089001083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 345}], {
             RGBColor[
             0.17916076969846856`, 0.3056397067749454, 0.9335143128384965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 240}], {
             RGBColor[
             0.8581995989845774, 0.5777442515282645, 0.5834221523927036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 243}], {
             RGBColor[
             0.9271182354136238, 0.9438506209861709, 0.9626670150045318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 337}], {
             RGBColor[
             0.9393785469822551, 0.9502915240338172, 0.7911384355526612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 367}], {
             RGBColor[
             0.6298962166593582, 0.7051035104774022, 0.9669932656124167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 398}], {
             RGBColor[
             0.6554022589203814, 0.7271955623129416, 0.9686184880711814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 234}], {
             RGBColor[
             0.6154815427973135, 0.6962991925345092, 0.964434228392668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 281}], {
             RGBColor[
             0.43696413947427415`, 0.552898107981546, 0.9490639464684518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 350}], {
             RGBColor[
             0.7195454075725961, 0.7758957836327975, 0.8505842343054555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 355}], {
             RGBColor[
             0.6054737407452027, 0.6884810215092875, 0.963436744212341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 392}], {
             RGBColor[
             0.7181621296927883, 0.7753237626808771, 0.8735087285822702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 395}], {
             RGBColor[
             0.45693963376297164`, 0.5697838781949226, 0.9504517090480242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 296}], {
             RGBColor[
             0.22621507415997788`, 0.35509676417920844`, 0.9361939858669741]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 308}], {
             RGBColor[
             0.20448504246078797`, 0.33225712309977423`, 0.9349564927084064]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 352}], {
             RGBColor[
             0.22353600409255178`, 0.3522808916754905, 0.9360414167899633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 375}], {
             RGBColor[
             0.1940331226429612, 0.32127149268124666`, 0.9343612713370109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 238}], {
             RGBColor[
             0.24678874654536498`, 0.3767209983024208, 0.9373656260733012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 273}], {
             RGBColor[
             0.1927101706170558, 0.31988098622201705`, 0.9342859311762677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 330}], {
             RGBColor[
             0.1947627843493959, 0.3220384133979338, 0.9344028244917546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 368}], {
             RGBColor[
             0.19438368850365684`, 0.3216399596279972, 0.9343812355441619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 260}], {
             RGBColor[
             0.21573241152320438`, 0.34407882110876054`, 0.9355970137375196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[
             0.1986631863683978, 0.3261379832196762, 0.934624946616609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 349}], {
             RGBColor[
             0.20443433824615148`, 0.33220382975535845`, 0.934953605178393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 233}], {
             RGBColor[
             0.8885723351829689, 0.5532979785319709, 0.5591090860551002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 242}], {
             RGBColor[
             0.8350058714331137, 0.2700760442713933, 0.18115496805881381`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 244}], {
             RGBColor[
             0.8862518697580262, 0.551567379217462, 0.5630370287452173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 245}], {
             RGBColor[
             0.8182841860813337, 0.14154584316836838`, 0.16514226328150688`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 328}], {
             RGBColor[
             0.8436345364621675, 0.31890075612792645`, 0.1887325709247331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 357}], {
             RGBColor[
             0.8374194029311317, 0.28862750498140566`, 0.18346616854700978`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 364}], {
             RGBColor[
             0.8177077184461266, 0.13711486031443826`, 0.16459023722300553`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 385}], {
             RGBColor[
             0.9060818174117249, 0.56391734784212, 0.3996140043462989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 235}], {
             RGBColor[
             0.18685346885052345`, 0.3137252213290522, 0.9339524006748775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 298}], {
             RGBColor[
             0.1895953138932402, 0.3166070743119639, 0.934108544693864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 336}], {
             RGBColor[
             0.1812731232878139, 0.3078599243283004, 0.9336346082504626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 393}], {
             RGBColor[
             0.18277810360197083`, 0.30944175405974256`, 0.933720314652935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 396}], {
             RGBColor[
             0.19087540782908663`, 0.31795253420118175`, 0.9341814441497811]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 257}], {
             RGBColor[
             0.30909861267997385`, 0.4408850865059202, 0.9409626882119364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 275}], {
             RGBColor[
             0.2669215798519661, 0.39788188260301705`, 0.9385121611462544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 279}], {
             RGBColor[
             0.48366351594508233`, 0.5856826936906501, 0.9540410765507529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 280}], {
             RGBColor[
             0.2733144461810522, 0.4046011904460226, 0.9388762254262976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 288}], {
             RGBColor[
             0.30023200699341346`, 0.43289325353174246`, 0.9404091406935988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 297}], {
             RGBColor[
             0.25100667694524614`, 0.38115431058492943`, 0.9376058309697055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 309}], {
             RGBColor[
             0.2963446868922668, 0.42880743363510754`, 0.9401877635646132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 325}], {
             RGBColor[
             0.29211597655452004`, 0.4243627909544146, 0.9399469447666949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 339}], {
             RGBColor[
             0.2733203034534184, 0.404607346810652, 0.9388765589892938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 242}], {
             RGBColor[
             0.9058398899715292, 0.686023971327602, 0.5756445160215393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 244}], {
             RGBColor[
             0.9570858882964418, 0.9675153062736708, 0.9575265767079428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 264}], {
             RGBColor[
             0.8413490098710985, 0.8765030596973409, 0.9633266229040078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 307}], {
             RGBColor[
             0.6538804302709667, 0.7226974017073509, 0.9485082265240019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 348}], {
             RGBColor[
             0.6462730001834412, 0.7161082281260901, 0.948023487805811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 357}], {
             RGBColor[
             0.9082534214695472, 0.7045754320376143, 0.5779557165097353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 366}], {
             RGBColor[
             0.6769028781273625, 0.7426382888986862, 0.9499751965434602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[
             0.8067428279900561, 0.5234676801505931, 0.5767481319037369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 246}], {
             RGBColor[
             0.8529840469746812, 0.885887262707637, 0.9857660876177745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 269}], {
             RGBColor[
             0.7646521215423732, 0.8160713160110501, 0.9771770354611466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 272}], {
             RGBColor[
             0.7633280108193825, 0.8150369106506357, 0.9770450604787972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 350}], {
             RGBColor[
             0.8897866044520348, 0.9121284341385445, 0.8654271636734474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 355}], {
             RGBColor[
             0.7757149376246414, 0.8247136720150343, 0.978279673580333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 392}], {
             RGBColor[
             0.888403326572227, 0.9115564131866241, 0.8883516579502622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 395}], {
             RGBColor[
             0.6271808306424103, 0.7060165287006694, 0.9652946384160161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 298}], {
             RGBColor[
             0.19425582793699694`, 0.3215055700656095, 0.9343739540740432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 313}], {
             RGBColor[
             0.2049405983747336, 0.3327359412492443, 0.9349824359437711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 317}], {
             RGBColor[
             0.19343401255220036`, 0.32064178999008336`, 0.934327152903646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 336}], {
             RGBColor[
             0.18593363733157064`, 0.312758420081946, 0.9339000176306419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 393}], {
             RGBColor[
             0.18743861764572758`, 0.31434024981338815`, 0.9339857240331143]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 396}], {
             RGBColor[
             0.19553592187284338`, 0.32285102995482734`, 0.9344468535299604]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 267}], {
             RGBColor[
             0.25338105975763014`, 0.38364993746531034`, 0.9377410485582862]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 284}], {
             RGBColor[
             0.26368702808225786`, 0.3944821636106265, 0.9383279582080599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 286}], {
             RGBColor[
             0.22281035809500455`, 0.3515181917234548, 0.9360000923239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 332}], {
             RGBColor[
             0.2395600162179548, 0.36912314440033817`, 0.9369539605751034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 367}], {
             RGBColor[
             0.3129287562528536, 0.440105110895209, 0.9413567694167602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 383}], {
             RGBColor[
             0.22956462143722656`, 0.3586173507411603, 0.9363847376292023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 398}], {
             RGBColor[
             0.3384347985138768, 0.4621971627307483, 0.9429819918755249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 251}], {
             RGBColor[
             0.19380336074719554`, 0.32102999836105145`, 0.9343481867369493]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 296}], {
             RGBColor[
             0.2211466738327187, 0.34976955408011773`, 0.935905347966363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 308}], {
             RGBColor[
             0.19941664213352878`, 0.3269299130006835, 0.9346678548077954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 380}], {
             RGBColor[
             0.20872851353399335`, 0.33671728024931885`, 0.9351981521083725]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 269}], {
             RGBColor[
             0.5167818424220354, 0.6108654129881752, 0.9574511707265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 272}], {
             RGBColor[
             0.5154577316990447, 0.6098310076277607, 0.9573191957441505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 280}], {
             RGBColor[
             0.2707591220181621, 0.40191538273391547`, 0.9387307034954844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 309}], {
             RGBColor[
             0.29378936272937667`, 0.4261216259230004, 0.9400422416338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 325}], {
             RGBColor[
             0.28956065239162987`, 0.42167698324230746`, 0.9398014228358818]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 339}], {
             RGBColor[
             0.27076497929052823`, 0.4019215390985449, 0.9387310370584805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 246}], {
             RGBColor[
             0.874004135287985, 0.576823099817974, 0.5832370617608514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 269}], {
             RGBColor[
             0.785672209855677, 0.5070071531213871, 0.5746480096042236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 272}], {
             RGBColor[
             0.7843480991326863, 0.5059727477609727, 0.5745160346218742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 350}], {
             RGBColor[
             0.9108066927653387, 0.6030642712488816, 0.46289813781652445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 355}], {
             RGBColor[
             0.7967350259379453, 0.5156495091253714, 0.57575064772341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 392}], {
             RGBColor[
             0.9094234148855309, 0.6024922502969611, 0.4858226320933391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 242}], {
             RGBColor[
             0.8419811748449504, 0.32369128289221516`, 0.18783452648346705`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 243}], {
             RGBColor[
             0.9006075598972731, 0.6106868981753124, 0.5572235175535094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 285}], {
             RGBColor[
             0.912943980913413, 0.617290591635334, 0.3939789817698772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 337}], {
             RGBColor[
             0.9128678714659045, 0.6171278012229586, 0.3856949381016387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 357}], {
             RGBColor[
             0.8443947063429684, 0.3422427436022275, 0.19014572697166301`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 399}], {
             RGBColor[
             0.879132492911469, 0.49559305678514604`, 0.2188791175560995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 270}], {
             RGBColor[
             0.31115624108701556`, 0.43971981464523346`, 0.9412017203817521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 310}], {
             RGBColor[
             0.2714061632718937, 0.40259546411637237`, 0.9387675515376726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 323}], {
             RGBColor[
             0.3309521511254019, 0.4568660369491151, 0.9424630982645621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 346}], {
             RGBColor[
             0.30713982911114474`, 0.4362410004624697, 0.9409457981622233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 389}], {
             RGBColor[
             0.23293094482355622`, 0.362155570057423, 0.9365764447660246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 390}], {
             RGBColor[
             0.2629620790942533, 0.393720196259813, 0.938286673435659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 244}], {
             RGBColor[
             0.9035194245465865, 0.684293372013093, 0.5795724587116564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 357}], {
             RGBColor[
             0.854686957719692, 0.4213534977770367, 0.2000015985134489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 364}], {
             RGBColor[
             0.8349752732346869, 0.2698408531100693, 0.18112566718944462`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 385}], {
             RGBColor[
             0.9233493722002852, 0.696643340637751, 0.416149434312738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 337}], {
             RGBColor[
             0.981786507894951, 0.983234170680865, 0.764939800713467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 367}], {
             RGBColor[
             0.6723041775720541, 0.7380461571244501, 0.9407946307732227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 398}], {
             RGBColor[
             0.6978102198330773, 0.7601382089599893, 0.9424198532319874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 264}], {
             RGBColor[
             0.8390285444461558, 0.8747724603828321, 0.9672545655941249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 307}], {
             RGBColor[
             0.651559964846024, 0.7209668023928419, 0.952436169214119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 321}], {
             RGBColor[
             0.7545634824664897, 0.8074397031821838, 0.959757518581915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 341}], {
             RGBColor[
             0.6455002366075493, 0.7157181703634723, 0.9520500486891706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 348}], {
             RGBColor[
             0.6439525347584986, 0.7143776288115813, 0.9519514304959281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 357}], {
             RGBColor[
             0.9059329560446046, 0.7028448327231054, 0.5818836591998524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 366}], {
             RGBColor[
             0.6745824127024198, 0.7409076895841773, 0.9539031392335773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 328}], {
             RGBColor[
             0.8441804058989478, 0.32309654782053254`, 0.18925529611386532`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 364}], {
             RGBColor[
             0.8182535878829069, 0.14131065200704435`, 0.16511296241213771`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 400}], {
             RGBColor[
             0.8345042681241085, 0.26622050143440795`, 0.18067463216363056`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 269}], {
             RGBColor[
             0.8319134288403021, 0.869426735678431, 0.9836659653182612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 272}], {
             RGBColor[
             0.8305893181173114, 0.8683923303180165, 0.9835339903359117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 350}], {
             RGBColor[
             0.9570479117499637, 0.9654838538059254, 0.8719160935305621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 355}], {
             RGBColor[
             0.8429762449225704, 0.8780690916824152, 0.9847686034374477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 392}], {
             RGBColor[
             0.955664633870156, 0.964911832854005, 0.8948405878073766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 395}], {
             RGBColor[
             0.6944421379403393, 0.7593719483680503, 0.9717835682731306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 253}], {
             RGBColor[
             0.19436046466415727`, 0.3216155499002067, 0.9343799129808589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 266}], {
             RGBColor[
             0.21519016549381775`, 0.3435088861514912, 0.9355661336283271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 301}], {
             RGBColor[
             0.1901623548072361, 0.317203070265044, 0.9341408368350541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 315}], {
             RGBColor[
             0.2082369879918481, 0.3362006557400048, 0.9351701604558942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 316}], {
             RGBColor[
             0.21599089502507074`, 0.3443505036580227, 0.9356117339905587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 343}], {
             RGBColor[
             0.18982443678675276`, 0.31684789700027605`, 0.9341215929036926]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 358}], {
             RGBColor[
             0.19420191296404457`, 0.3214489020106298, 0.9343708836960937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 359}], {
             RGBColor[
             0.1924159607622266, 0.31957175301060936`, 0.9342691763602797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 362}], {
             RGBColor[
             0.19339653330473627`, 0.32060239692467707`, 0.9343250185159485]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 363}], {
             RGBColor[
             0.20876443324933688`, 0.3367550341475864, 0.9352001976830229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 369}], {
             RGBColor[
             0.19411283179141248`, 0.32135527205012093`, 0.934365810655096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 397}], {
             RGBColor[
             0.20527567361963986`, 0.3330881265766384, 0.935001517983269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 276}], {
             RGBColor[
             0.22042799245848094`, 0.3490141743887628, 0.9358644201252941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 340}], {
             RGBColor[
             0.2104667967928659, 0.33854432616791813`, 0.9352971447684058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 360}], {
             RGBColor[
             0.20162405229043762`, 0.3292500410334822, 0.9347935635506606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 266}], {
             RGBColor[
             0.270914372535644, 0.40204801259274037`, 0.9387406633049027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 293}], {
             RGBColor[
             0.3289853537057845, 0.45937231092045516`, 0.9421836337211749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 315}], {
             RGBColor[
             0.2639611950336743, 0.39473978218125394`, 0.9383446901324698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 316}], {
             RGBColor[
             0.271715102066897, 0.4028896300992718, 0.9387862636671344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 387}], {
             RGBColor[
             0.4216012233503626, 0.5373973944320252, 0.9486912790769737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 397}], {
             RGBColor[
             0.26099988066146607`, 0.3916272530178875, 0.9381760476598446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 356}], {
             RGBColor[
             0.22666963106636354`, 0.3555745323083922, 0.9362198722103361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 363}], {
             RGBColor[
             0.2391241828797345, 0.3686650559284389, 0.9369291405112493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 372}], {
             RGBColor[
             0.22620791914637717`, 0.35508924380626006`, 0.9361935783995345]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 283}], {
             RGBColor[
             0.19962713488925782`, 0.32715115423296626`, 0.934679842058838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 308}], {
             RGBColor[
             0.1958872147734443, 0.3232202610666153, 0.9344668591409584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 380}], {
             RGBColor[
             0.20519908617390886`, 0.3330076283152506, 0.9349971564415356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 381}], {
             RGBColor[
             0.19321867549075944`, 0.3204154570853507, 0.9343148897765596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 282}], {
             RGBColor[
             0.31835440977210794`, 0.4463178036126423, 0.941647079240882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 300}], {
             RGBColor[
             0.6421328397168371, 0.7146709767757251, 0.9682477279637229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 367}], {
             RGBColor[
             0.372324185998124, 0.4969102291790325, 0.9449451457918181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 398}], {
             RGBColor[
             0.39783022825914727`, 0.5190022810145718, 0.9465703682505828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 266}], {
             RGBColor[
             0.21192263839001468`, 0.3400745079922101, 0.9353800527936387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 301}], {
             RGBColor[
             0.18689482770343305`, 0.31376869210576286`, 0.9339547560003658]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 315}], {
             RGBColor[
             0.20496946088804507`, 0.3327662775807237, 0.9349840796212059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 316}], {
             RGBColor[
             0.2127233679212677, 0.3409161254987416, 0.9354256531558705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 343}], {
             RGBColor[
             0.18655690968294972`, 0.31341351884099494`, 0.9339355120690042]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 358}], {
             RGBColor[
             0.19093438586024153`, 0.31801452385134865`, 0.9341848028614053]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 359}], {
             RGBColor[
             0.18914843365842357`, 0.3161373748513282, 0.9340830955255912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 362}], {
             RGBColor[
             0.19012900620093326`, 0.31716801876539596`, 0.9341389376812601]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 369}], {
             RGBColor[
             0.19084530468760944`, 0.3179208938908398, 0.9341797298204076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 394}], {
             RGBColor[
             0.1857625991924869, 0.31257864815332465`, 0.9338902772616493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 397}], {
             RGBColor[
             0.20200814651583682`, 0.3296537484173573, 0.9348154371485806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 303}], {
             RGBColor[
             0.20024144683233963`, 0.3277968350347721, 0.9347148262152034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 268}], {
             RGBColor[
             0.7573621449450872, 0.5111257415751345, 0.5750858104368912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 324}], {
             RGBColor[
             0.7342455134222807, 0.4929254711764368, 0.5728784243989717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 328}], {
             RGBColor[
             0.8524460760036836, 0.3866301102852666, 0.1971705111408994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 351}], {
             RGBColor[
             0.8725754097367984, 0.601857083491112, 0.5863765700059249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 400}], {
             RGBColor[
             0.8427699382288443, 0.329754063899142, 0.18858984719066463`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 311}], {
             RGBColor[
             0.32702639881790146`, 0.45712063802367703`, 0.942079129357128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 313}], {
             RGBColor[
             0.28483799884386285`, 0.41277795475190926`, 0.9396765623907513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 386}], {
             RGBColor[
             0.556034698630532, 0.6458694921919914, 0.9601976146247932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 275}], {
             RGBColor[
             0.2809273627700829, 0.4112753166902168, 0.9393583772051975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 276}], {
             RGBColor[
             0.27298076036949565`, 0.4029229337235066, 0.9389058299544288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 279}], {
             RGBColor[
             0.4976692988631992, 0.5990761277778498, 0.9548872926096961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 280}], {
             RGBColor[
             0.2873202290991691, 0.41799462453322234`, 0.9397224414852408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 288}], {
             RGBColor[
             0.3142377899115303, 0.4462866876189422, 0.9412553567525421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 309}], {
             RGBColor[
             0.31035046981038367`, 0.4422008677223072, 0.9410339796235565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 325}], {
             RGBColor[
             0.30612175947263687`, 0.43775622504161427`, 0.9407931608256381]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 339}], {
             RGBColor[
             0.2873260863715352, 0.41800078089785175`, 0.939722775048237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 277}], {
             RGBColor[
             0.19561158896014919`, 0.3229305608611562, 0.9344511626586431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 302}], {
             RGBColor[
             0.18739149065206478`, 0.3142907163550246, 0.9339830402205433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 377}], {
             RGBColor[
             0.18407204095648846`, 0.3108017642597073, 0.933794002471066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 378}], {
             RGBColor[
             0.18711323001988966`, 0.3139982467878655, 0.9339671936891907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 379}], {
             RGBColor[
             0.19525485067885182`, 0.32255560630899927`, 0.9344308469412701]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 262}], {
             RGBColor[
             0.20019420515358305`, 0.3277471810351035, 0.934712135871486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 331}], {
             RGBColor[
             0.19269223822101744`, 0.31986213813680114`, 0.934284909952842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 335}], {
             RGBColor[
             0.18286996403264408`, 0.3095383051966678, 0.9337255459685665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 307}], {
             RGBColor[
             0.28646815305242945`, 0.41476449327789777`, 0.9397593961545982]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 329}], {
             RGBColor[
             0.20751257412950358`, 0.3354392508401891, 0.9351289061581081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 341}], {
             RGBColor[
             0.2804084248139549, 0.4095158612485281, 0.93937327562965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 349}], {
             RGBColor[
             0.21328372600725728`, 0.3415050973758713, 0.9354575647198919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 366}], {
             RGBColor[
             0.3094906009088253, 0.4347053804692331, 0.9412263661740565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 306}], {
             RGBColor[
             0.2313412040252819, 0.36048465168304844`, 0.9364859113793738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 284}], {
             RGBColor[
             0.24537509181412387`, 0.37523515754899955`, 0.9372851205276718]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 286}], {
             RGBColor[
             0.20449842182687056`, 0.3322711856618279, 0.9349572546435119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 331}], {
             RGBColor[
             0.20664951421908523`, 0.3345321201531805, 0.9350797561729924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 332}], {
             RGBColor[
             0.22124807994982085`, 0.34987613833871123`, 0.9359111228947152]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 338}], {
             RGBColor[
             0.22417589206845978`, 0.35295345450941085`, 0.9360778574635618]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 264}], {
             RGBColor[
             0.5576221544304325, 0.6488358128735436, 0.9596252327476064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 312}], {
             RGBColor[
             0.3474308254202023, 0.4748091816311434, 0.9433787228228494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 348}], {
             RGBColor[
             0.36254614474277536`, 0.48844098130229274`, 0.9443220976494096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 307}], {
             RGBColor[
             0.5358230864206805, 0.6299545558165122, 0.958236215410184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 312}], {
             RGBColor[
             0.5131003370105822, 0.6097335825641022, 0.9568081018654329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 348}], {
             RGBColor[
             0.5282156563331551, 0.6233653822352514, 0.957751476691993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 357}], {
             RGBColor[
             0.7901960776192611, 0.6118325861467757, 0.5876837053959174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 366}], {
             RGBColor[
             0.5588455342770764, 0.6498954430078475, 0.9597031854296422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 291}], {
             RGBColor[
             0.18857894058274138`, 0.31553880152083974`, 0.9340506637374206]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 304}], {
             RGBColor[
             0.18543662898340038`, 0.31223603279586976`, 0.9338717137404716]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 378}], {
             RGBColor[
             0.19040066183963522`, 0.31745354606563403`, 0.9341544080680056]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 383}], {
             RGBColor[
             0.1991683094404495, 0.3266688995950551, 0.9346537126282998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 293}], {
             RGBColor[
             0.2908233203898157, 0.4192921425712095, 0.940009243857379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 315}], {
             RGBColor[
             0.22579916171770553`, 0.3546596138320083, 0.9361703002686741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 316}], {
             RGBColor[
             0.23355306875092818`, 0.36280946175002615`, 0.9366118738033387]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 338}], {
             RGBColor[
             0.23347632110247196`, 0.3627287951054168, 0.936607503138297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 397}], {
             RGBColor[
             0.22283784734549728`, 0.3515470846686418, 0.9360016577960488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 282}], {
             RGBColor[
             0.2615646860965489, 0.39225144761939246`, 0.9382070939716974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 332}], {
             RGBColor[
             0.24216572228766625`, 0.37186190669091185`, 0.9371023516809767]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 367}], {
             RGBColor[
             0.315534462322565, 0.44284387318578267`, 0.9415051605226336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 383}], {
             RGBColor[
             0.23217032750693795`, 0.361356113031734, 0.9365331287350758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 398}], {
             RGBColor[
             0.34104050458358826`, 0.46493592502132197`, 0.9431303829813984]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 270}], {
             RGBColor[
             0.5192310696539062, 0.6174490867384653, 0.9563893333020512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 274}], {
             RGBColor[
             0.5862206904488971, 0.6743925388404906, 0.9609561467561663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 295}], {
             RGBColor[
             0.5541988760682194, 0.6477364431214906, 0.9586174510059542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 324}], {
             RGBColor[
             0.6562462626397825, 0.7312424529611288, 0.9664688163111557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 351}], {
             RGBColor[
             0.7945761589543001, 0.8401740652758038, 0.979966961918109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 373}], {
             RGBColor[
             0.475607023803843, 0.5762529501811211, 0.9537345477094038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 272}], {
             RGBColor[
             0.7422573926850033, 0.7985763836214297, 0.9749449381792838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 350}], {
             RGBColor[
             0.8687159863176557, 0.8956679071093385, 0.8633270413739342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 355}], {
             RGBColor[
             0.7546443194902623, 0.8082531449858283, 0.9761795512808198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 392}], {
             RGBColor[
             0.8673327084378479, 0.8950958861574181, 0.8862515356507488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 395}], {
             RGBColor[
             0.6061102125080312, 0.6895560016714635, 0.9631945161165028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 295}], {
             RGBColor[
             0.3940670515595366, 0.5157428065001295, 0.9463305819589302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 310}], {
             RGBColor[
             0.3193491673301014, 0.4483310995882432, 0.9416682954109477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 324}], {
             RGBColor[
             0.49611443813109957`, 0.5992488163397677, 0.9541819472641316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 346}], {
             RGBColor[
             0.3550828331693524, 0.4819766359343405, 0.9438465420354984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 351}], {
             RGBColor[
             0.6344443344456173, 0.7081804286544429, 0.9676800928710849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 373}], {
             RGBColor[
             0.31547519929516016`, 0.44425931355976, 0.9414476786623798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 390}], {
             RGBColor[
             0.310905083152461, 0.4394558317316838, 0.9411874173089341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 287}], {
             RGBColor[
             0.18451611233351262`, 0.31126851143271117`, 0.9338192916790429]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 292}], {
             RGBColor[
             0.18674265418407987`, 0.3136087480885643, 0.9339460899435592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 371}], {
             RGBColor[
             0.1828236944867615, 0.3094896729702865, 0.9337229109863782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 374}], {
             RGBColor[
             0.184659451088446, 0.3114191695523481, 0.9338274546090857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 382}], {
             RGBColor[
             0.18049565541513857`, 0.3070427562998084, 0.9335903326052744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 384}], {
             RGBColor[
             0.18432884103510522`, 0.31107167742439884`, 0.9338086268556416]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 389}], {
             RGBColor[
             0.19087423447573804`, 0.31795130093241747`, 0.9341813773290437]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 391}], {
             RGBColor[
             0.1801133509320429, 0.3066409300485706, 0.9335685609305309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 350}], {
             RGBColor[
             0.867391875594665, 0.894633501748924, 0.8631950663915847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 392}], {
             RGBColor[
             0.8660085977148573, 0.8940614807970035, 0.8861195606683994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 395}], {
             RGBColor[
             0.6047861017850406, 0.688521596311049, 0.9630625411341533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 322}], {
             RGBColor[
             0.19086506728942945`, 0.31794166563837395`, 0.9341808552713451]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 330}], {
             RGBColor[
             0.18387764331179846`, 0.31059744000961553`, 0.9337829318127865]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 295}], {
             RGBColor[
             0.4610566723545275, 0.5726862586021548, 0.9508973954130453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 296}], {
             RGBColor[
             0.36901952314668135`, 0.4870709060931353, 0.9452488023460986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 319}], {
             RGBColor[
             0.47322013025663245`, 0.583220445923085, 0.9516727685977074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 324}], {
             RGBColor[
             0.5631040589260905, 0.6561922684417929, 0.9587487607182468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 351}], {
             RGBColor[
             0.7014339552406084, 0.7651238807564681, 0.9722469063252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 373}], {
             RGBColor[
             0.38246482009015115`, 0.5012027656617852, 0.9460144921164949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 276}], {
             RGBColor[
             0.2308037275414878, 0.35991972982060355`, 0.9364553028887468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 280}], {
             RGBColor[
             0.24514319627116127`, 0.3749914206303192, 0.9372719144195587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 288}], {
             RGBColor[
             0.2720607570835225, 0.40328348371603906`, 0.9388048296868601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 290}], {
             RGBColor[
             0.21848378643908228`, 0.34697069059259356`, 0.9357537004686844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 297}], {
             RGBColor[
             0.22283542703535522`, 0.35154454076922603`, 0.9360015199629668]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 318}], {
             RGBColor[
             0.21657038683237403`, 0.3449595862894012, 0.9356447351917034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 325}], {
             RGBColor[
             0.2639447266446291, 0.3947530211387112, 0.9383426337599561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 339}], {
             RGBColor[
             0.24514905354352745`, 0.3749975769949486, 0.9372722479825549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 288}], {
             RGBColor[
             0.2641141546829352, 0.39493110074932897`, 0.9383522824360913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 290}], {
             RGBColor[
             0.21053718403849497`, 0.33861830762588346`, 0.9353011532179156]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 297}], {
             RGBColor[
             0.21488882463476794`, 0.3431921578025159, 0.9355489727121981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 318}], {
             RGBColor[
             0.20862378443178675`, 0.3366072033226911, 0.9351921879409346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 278}], {
             RGBColor[
             0.23299059780069237`, 0.3622182691186103, 0.9365798419148239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 302}], {
             RGBColor[
             0.19959521355734036`, 0.32711760288919167`, 0.9346780241862087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 314}], {
             RGBColor[
             0.22024480085065679`, 0.34882162839392095`, 0.9358539876342362]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 352}], {
             RGBColor[
             0.22370886564436498`, 0.3524625801265016, 0.9360512609996132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 378}], {
             RGBColor[
             0.19931695292516527`, 0.3268251333220326, 0.934662177654856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 379}], {
             RGBColor[
             0.2074585735841274, 0.33538249284316635`, 0.9351258309069355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 314}], {
             RGBColor[
             0.2454200867859244, 0.3752824501172079, 0.9372876829247517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 319}], {
             RGBColor[
             0.35576382875700985`, 0.4778888141834562, 0.9440614916187484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 352}], {
             RGBColor[
             0.24888415157963256`, 0.37892340184978857`, 0.9374849562901288]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 379}], {
             RGBColor[
             0.232633859519395, 0.36184331456645336`, 0.936559526197451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.8332166202434534, 0.8669371947579207, 0.788972494773293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 288}], {
             RGBColor[
             0.4888026931766387, 0.5910842948036721, 0.9543337450913586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 309}], {
             RGBColor[
             0.48491537307549215`, 0.5869984749070372, 0.9541123679623731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 325}], {
             RGBColor[
             0.4806866627377453, 0.5825538322263442, 0.9538715491644547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 399}], {
             RGBColor[
             0.7994051322415094, 0.7452396599077329, 0.6138726305595152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 297}], {
             RGBColor[
             0.22922829336444137`, 0.3582638486122316, 0.9363655842430101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 309}], {
             RGBColor[
             0.27456630331146203`, 0.4059169716624097, 0.9389475168379178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 322}], {
             RGBColor[
             0.22572058379982396`, 0.354577023458187, 0.9361658253724963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 325}], {
             RGBColor[
             0.2703375929737152, 0.4014723289817168, 0.9387066980399994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 339}], {
             RGBColor[
             0.2515419198726136, 0.3817168848379542, 0.9376363122625981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 355}], {
             RGBColor[
             0.5971975343016019, 0.6813125874620714, 0.9629093916561169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 386}], {
             RGBColor[
             0.5947242732295994, 0.6793804571151425, 0.9626628801063983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 367}], {
             RGBColor[
             0.3211123825917724, 0.44870662104929115`, 0.9418228148301714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 383}], {
             RGBColor[
             0.23774824777614534`, 0.3672188608952424, 0.9368507830426136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 398}], {
             RGBColor[
             0.3466184248527956, 0.47079867288483046`, 0.9434480372889362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 294}], {
             RGBColor[
             0.19947004944091673`, 0.32698604746696713`, 0.934670896274942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 320}], {
             RGBColor[
             0.20238649627655553`, 0.330051418004633, 0.9348369836077353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 347}], {
             RGBColor[
             0.20341579469893528`, 0.33113327590784336`, 0.9348956006301792]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 373}], {
             RGBColor[
             0.2404157449182508, 0.3700225695206825, 0.937002693058648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 380}], {
             RGBColor[
             0.2145522876760556, 0.34283843612123366`, 0.9355298074302612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 381}], {
             RGBColor[
             0.20257187699290616`, 0.3302462648913338, 0.9348475407652852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 332}], {
             RGBColor[
             0.2524716906122939, 0.382694132836228, 0.9376892613307504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 338}], {
             RGBColor[
             0.2553995027309328, 0.3857714490069275, 0.9378559958995971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 367}], {
             RGBColor[
             0.3258404306471927, 0.4536760993310988, 0.9420920701724073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 399}], {
             RGBColor[
             0.9603875503566552, 0.868303119703074, 0.4348794443842956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 332}], {
             RGBColor[
             0.2115950206250406, 0.3397301609490563, 0.9353613954465905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 292}], {
             RGBColor[
             0.19215895018442095`, 0.31930161859792383`, 0.9342545399880867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 371}], {
             RGBColor[
             0.18823999048710255`, 0.315182543479646, 0.9340313610309057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 374}], {
             RGBColor[
             0.19007574708878708`, 0.31711204006170757`, 0.9341359046536132]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 382}], {
             RGBColor[
             0.18591195141547964`, 0.3127356268091679, 0.933898782649802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 384}], {
             RGBColor[
             0.18974513703544627`, 0.3167645479337583, 0.9341170769001692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 389}], {
             RGBColor[
             0.19629053047607914`, 0.32364417144177693`, 0.9344898273735713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 391}], {
             RGBColor[
             0.18552964693238397`, 0.31233380055793014`, 0.9338770109750585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 303}], {
             RGBColor[
             0.19970158242580874`, 0.32722940331412775`, 0.9346840817359092]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 376}], {
             RGBColor[
             0.19788479388924796`, 0.32531984337115605`, 0.93458061831645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 297}], {
             RGBColor[
             0.20256888353236238`, 0.33024311857450594`, 0.9348473702921356]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 318}], {
             RGBColor[
             0.1963038433293812, 0.3236581640946811, 0.9344905855208723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 345}], {
             RGBColor[
             0.18860221988526102`, 0.31556326954378094`, 0.9340519894592605]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 304}], {
             RGBColor[
             0.1840328398717771, 0.3107605614341833, 0.9337917700272845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 383}], {
             RGBColor[
             0.1977645203288262, 0.3251934282333686, 0.9345737689151127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 371}], {
             RGBColor[
             0.1904665323376698, 0.31752278013549917`, 0.934158159295422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 374}], {
             RGBColor[
             0.19230228893935433`, 0.31945227671756077`, 0.9342627029181295]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 382}], {
             RGBColor[
             0.1881384932660469, 0.31507586346502103`, 0.9340255809143183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 384}], {
             RGBColor[
             0.19197167888601352`, 0.3191047845896115, 0.9342438751646855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 389}], {
             RGBColor[
             0.1985170723266464, 0.32598440809763013`, 0.9346166256380877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 316}], {
             RGBColor[
             0.2916240499210687, 0.42013376007774095`, 0.9400548442196108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 387}], {
             RGBColor[
             0.4415101712045343, 0.5546415244104943, 0.9499598596294503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 320}], {
             RGBColor[
             0.19287620932606772`, 0.32005550343265077`, 0.9342953868351136]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 347}], {
             RGBColor[
             0.19390550774844745`, 0.3211373613358611, 0.9343540038575576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 380}], {
             RGBColor[
             0.20504200072556777`, 0.3328425215492514, 0.9349882106576397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 381}], {
             RGBColor[
             0.19306159004241835`, 0.32025035031935156`, 0.9343059439926636]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 310}], {
             RGBColor[
             0.3543169737444146, 0.4786184559712684, 0.9438964131148506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 324}], {
             RGBColor[
             0.5310822445454129, 0.6295361727227928, 0.9564100649680346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 351}], {
             RGBColor[
             0.6694121408599306, 0.7384677850374681, 0.9699082105749879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 373}], {
             RGBColor[
             0.3504430057094734, 0.4745466699427852, 0.9436757963662827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 390}], {
             RGBColor[
             0.34587288956677426`, 0.46974318811470905`, 0.943415535012837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 308}], {
             RGBColor[
             0.22323052785896746`, 0.35195981678568156`, 0.9360240203703722]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 373}], {
             RGBColor[
             0.25840585650162723`, 0.38893131743376574`, 0.9380272032993362]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 380}], {
             RGBColor[
             0.23254239925943204`, 0.3617471840343169, 0.9365543176709494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 318}], {
             RGBColor[
             0.20065548392565413`, 0.32823201427131354`, 0.9347384050151546]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 322}], {
             RGBColor[
             0.2034128145640179, 0.33113014359709375`, 0.9348954309159043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 339}], {
             RGBColor[
             0.22923415063680755`, 0.358270004976861, 0.9363659178060062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 313}], {
             RGBColor[
             0.20768244341745035`, 0.33561779423215604`, 0.9351385799627575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 361}], {
             RGBColor[
             0.2073168336633886, 0.33523351519963984`, 0.9351177590281349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 393}], {
             RGBColor[
             0.19018046268844432`, 0.31722210279629987`, 0.9341418680521008]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 396}], {
             RGBColor[
             0.19827776691556012`, 0.32573288293773905`, 0.9346029975489469]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 306}], {
             RGBColor[
             0.19518727715711093`, 0.32248458225324084`, 0.9344269987291731]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 342}], {
             RGBColor[
             0.18568831496489116`, 0.3125005707202294, 0.9338860468847814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 353}], {
             RGBColor[
             0.188841530987085, 0.3158148006849981, 0.9340656178724803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 319}], {
             RGBColor[
             0.6840306200166372, 0.7509595396670409, 0.9709177458785374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 343}], {
             RGBColor[
             0.18235879982602854`, 0.30900103920583233`, 0.9336964359231994]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 358}], {
             RGBColor[
             0.18673627600332035`, 0.31360204421618604`, 0.9339457267156006]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 359}], {
             RGBColor[
             0.1849503238015024, 0.31172489521616553`, 0.9338440193797866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 362}], {
             RGBColor[
             0.18593089634401205`, 0.31275553913023335`, 0.9338998615354555]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 369}], {
             RGBColor[
             0.18664719483068826`, 0.31350841425567716`, 0.9339406536746029]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 394}], {
             RGBColor[
             0.18156448933556574`, 0.30816616851816203`, 0.9336512011158447]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 397}], {
             RGBColor[
             0.19781003665891564`, 0.3252412687821946, 0.934576361002776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 314}], {
             RGBColor[
             0.21202470254257239`, 0.3401817838877893, 0.9353858651961364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 352}], {
             RGBColor[
             0.21548876733628058`, 0.34382273562037, 0.9355831385615135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 377}], {
             RGBColor[
             0.18805566555367964`, 0.3149888062877428, 0.9340208639986316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 379}], {
             RGBColor[
             0.199238475276043, 0.32674264833703476`, 0.9346577084688357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 376}], {
             RGBColor[
             0.21141869489039777`, 0.33954483142224945`, 0.9353513539568531]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 383}], {
             RGBColor[
             0.1946222087294852, 0.32189065950839857`, 0.9343948189181637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 334}], {
             RGBColor[
             0.18360707090558112`, 0.31031305125539965`, 0.9337675231145284]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 340}], {
             RGBColor[
             0.19258396167334632`, 0.31974833262006913`, 0.9342787437636328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 360}], {
             RGBColor[
             0.18374121717091801`, 0.3104540474856332, 0.9337751625458877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 370}], {
             RGBColor[
             0.18466045373978385`, 0.311420223402476, 0.9338275117085959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 342}], {
             RGBColor[
             0.1932134040418383, 0.3204099164583054, 0.934314589575342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 353}], {
             RGBColor[
             0.19636662006403216`, 0.3237241464230741, 0.9344941605630408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 361}], {
             RGBColor[
             0.21017418029056079`, 0.33823676767103766`, 0.9352804806914867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 312}], {
             RGBColor[
             0.32563175741045036`, 0.45592792457411196`, 0.9419897054854269]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 341}], {
             RGBColor[
             0.3422947785820742, 0.4709002657971524, 0.9430316985052297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 348}], {
             RGBColor[
             0.3407470767330234, 0.4695597242452613, 0.9429330803119872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 366}], {
             RGBColor[
             0.37137695467694465`, 0.4960897850178574, 0.9448847890496364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 325}], {
             RGBColor[
             0.2933678336849298, 0.42567857217080163`, 0.9400182361783151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 339}], {
             RGBColor[
             0.27457216058382816`, 0.4059231280270391, 0.9389478504009139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 323}], {
             RGBColor[
             0.33914507736848765`, 0.46547732189212476`, 0.9429296732937578]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 324}], {
             RGBColor[
             0.45636436031597766`, 0.5621244658109066, 0.9517477784200521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 346}], {
             RGBColor[
             0.31533275535423055`, 0.4448522854054794, 0.9414123731914188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 389}], {
             RGBColor[
             0.24112387106664201`, 0.3707668550004327, 0.9370430197952202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 390}], {
             RGBColor[
             0.27115500533733905`, 0.4023314812028227, 0.9387532484648545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 313}], {
             RGBColor[
             0.2605556138292256, 0.39119084868755866`, 0.938149628798862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 361}], {
             RGBColor[
             0.2601900040751639, 0.39080656965504246`, 0.9381288078642394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 386}], {
             RGBColor[
             0.5317523136158948, 0.6242823861276408, 0.958670681032904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 348}], {
             RGBColor[
             0.31802432732292496`, 0.44933875099285125`, 0.9415049667672362]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 366}], {
             RGBColor[
             0.3486542052668462, 0.4758688117654473, 0.9434566755048852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 361}], {
             RGBColor[
             0.2180016041011253, 0.34646388638327474`, 0.9357262408978626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 393}], {
             RGBColor[
             0.200865233126181, 0.3284524739799347, 0.9347503499218286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 396}], {
             RGBColor[
             0.20896253735329678`, 0.3369632541213739, 0.9352114794186747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 352}], {
             RGBColor[
             0.23613835462959704`, 0.3655267611250992, 0.9367591020095412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 379}], {
             RGBColor[
             0.21988806256935944`, 0.348446673841764, 0.9358336719168633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 316}], {
             RGBColor[
             0.22659989124895852`, 0.3555012313385397, 0.9362159006309058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 358}], {
             RGBColor[
             0.20481090918793238`, 0.33259962969114687`, 0.9349750503364407]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 359}], {
             RGBColor[
             0.2030249569861144, 0.33072248069112636`, 0.9348733430006266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 362}], {
             RGBColor[
             0.20400552952862408`, 0.3317531246051941, 0.9349291851562955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 363}], {
             RGBColor[
             0.2193734294732247, 0.3479057618281034, 0.9358043643233698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 369}], {
             RGBColor[
             0.20472182801530026`, 0.332505999730638, 0.934969977295443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 397}], {
             RGBColor[
             0.21588466984352767`, 0.3442388542571554, 0.935605684623616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 358}], {
             RGBColor[
             0.212564816221155, 0.34074947760916474`, 0.9354166238711052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 359}], {
             RGBColor[
             0.21077886401933704`, 0.3388723286091443, 0.9353149165352912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 362}], {
             RGBColor[
             0.2117594365618467, 0.339902972523212, 0.9353707586909601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 363}], {
             RGBColor[
             0.2271273365064473, 0.3560556097461213, 0.9362459378580343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 369}], {
             RGBColor[
             0.2124757350485229, 0.34065584764865586`, 0.9354115508301075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 397}], {
             RGBColor[
             0.2236385768767503, 0.3523887021751733, 0.9360472581582806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 326}], {
             RGBColor[
             0.19368284883535128`, 0.3209033327008066, 0.9343413237618512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 327}], {
             RGBColor[
             0.19548056477531295`, 0.3227928461354802, 0.9344437010251496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 336}], {
             RGBColor[
             0.1878536669894908, 0.3147764929893316, 0.9340093604792311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 396}], {
             RGBColor[
             0.19745595153076353`, 0.32486910286221293`, 0.9345561963785496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 345}], {
             RGBColor[
             0.18668882027855277`, 0.3135521652405886, 0.9339430241822795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 347}], {
             RGBColor[
             0.1968219545840863, 0.324202731873527, 0.9345200911903508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 380}], {
             RGBColor[
             0.20795844756120663`, 0.3359078920869173, 0.9351542979904328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 381}], {
             RGBColor[
             0.19597803687805715`, 0.32331572085701743`, 0.9344720313254569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 384}], {
             RGBColor[
             0.1926752609493727, 0.31984429394788133`, 0.9342839431223373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 341}], {
             RGBColor[
             0.44529829620254, 0.5573731665864943, 0.9503530478730258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 366}], {
             RGBColor[
             0.4743804722974104, 0.5825626858071993, 0.9522061384174323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 330}], {
             RGBColor[
             0.19291768102176954`, 0.3200990928142907, 0.934297748586832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 339}], {
             RGBColor[
             0.22572644107219014`, 0.3545831798228164, 0.9361661589354925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 346}], {
             RGBColor[
             0.37487874320773873`, 0.4991228582382221, 0.9451079199183084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 346}], {
             RGBColor[
             0.4920980261552287, 0.5957700021570038, 0.9539260250446029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 351}], {
             RGBColor[
             0.7714595274314936, 0.8219737948771062, 0.9777595758801894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 390}], {
             RGBColor[
             0.4479202761383373, 0.5532491979543472, 0.9512669003180385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 339}], {
             RGBColor[
             0.2703434502460814, 0.40147848534634617`, 0.9387070316029955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 327}], {
             RGBColor[
             0.19380937140054372`, 0.3210363159388178, 0.9343485290347655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 336}], {
             RGBColor[
             0.18618247361472157`, 0.3130199627926692, 0.9339141884888471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 336}], {
             RGBColor[
             0.18798018955468324`, 0.3149094762273428, 0.9340165657521455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 376}], {
             RGBColor[
             0.2026044968471712, 0.33028055042638454`, 0.9348493984177288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 364}], {
             RGBColor[
             0.8436039382637408, 0.3186655649666024, 0.18870327005536394`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 386}], {
             RGBColor[
             0.8151456848541535, 0.6567413505380229, 0.5948173850288303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 400}], {
             RGBColor[
             0.8598546185049423, 0.443575414393966, 0.20426493980685678`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 349}], {
             RGBColor[
             0.19621450085245074`, 0.32356425948678696`, 0.9344854975989814]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 335}], {
             RGBColor[
             0.18932527309814626`, 0.31632324431474484`, 0.9340931662700729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 338}], {
             RGBColor[
             0.2166739251358942, 0.34506841161110846`, 0.9356506315449178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 368}], {
             RGBColor[
             0.18664235406415453`, 0.3135033263031278, 0.9339403780001101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 340}], {
             RGBColor[
             0.1939578430419053, 0.32119236904753456`, 0.934356984275097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 360}], {
             RGBColor[
             0.185115098539477, 0.3118980839130987, 0.9338534030573518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 365}], {
             RGBColor[
             0.18295572293696874`, 0.30962844324254163`, 0.933730429811299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 370}], {
             RGBColor[
             0.18603433510834283`, 0.3128642598299414, 0.93390575222006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 394}], {
             RGBColor[
             0.17996762986719622`, 0.30648776797016763`, 0.9335602623314629]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 396}], {
             RGBColor[
             0.18995557631013382`, 0.31698573295407556`, 0.9341290611055455]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 367}], {
             RGBColor[
             0.6845644891406854, 0.7444870601720963, 0.7692660513213518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 398}], {
             RGBColor[
             0.7100705314017086, 0.7665791120076357, 0.7708912737801167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 399}], {
             RGBColor[
             0.9603114409091467, 0.8681403292906987, 0.42659540071605706`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 360}], {
             RGBColor[
             0.1940919893072422, 0.3213333652777681, 0.9343646237064562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 370}], {
             RGBColor[
             0.19501122587610803`, 0.3222995411946109, 0.9344169728691645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 348}], {
             RGBColor[
             0.33468734849454873`, 0.4643110922158917, 0.9425469597870388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 366}], {
             RGBColor[
             0.36531722643847, 0.49084115298848774`, 0.9444986685246879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 353}], {
             RGBColor[
             0.1868676578718124, 0.31374013489006275`, 0.9339532087186491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 358}], {
             RGBColor[
             0.18639835798283702`, 0.3132468709514181, 0.933926482784239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 359}], {
             RGBColor[
             0.18461240578101906`, 0.3113697219513976, 0.933824775448425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 362}], {
             RGBColor[
             0.18559297832352872`, 0.3124003658654654, 0.9338806176040938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 369}], {
             RGBColor[
             0.18630927681020493`, 0.31315324099090924`, 0.9339214097432413]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 354}], {
             RGBColor[
             0.2035510812828702, 0.3312754706852238, 0.9349033050009957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 356}], {
             RGBColor[
             0.19312061469136133`, 0.3203123889677695, 0.9343093053591018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 388}], {
             RGBColor[
             0.20538183242077535`, 0.3331997062074885, 0.9350075635699459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 390}], {
             RGBColor[
             0.30688867117659013`, 0.43597701754892004`, 0.9409314950894052]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 380}], {
             RGBColor[
             0.20898774598358635`, 0.3369897499901277, 0.9352129150128767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 381}], {
             RGBColor[
             0.1970073353004369, 0.3243975787602278, 0.9345306483479008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 384}], {
             RGBColor[
             0.19370455937175246`, 0.32092615185109175`, 0.9343425601447813]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 366}], {
             RGBColor[
             0.3637695245894192, 0.4895006114365967, 0.9444000503314454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 355}], {
             RGBColor[
             0.879778802399924, 0.9043102631133229, 0.8644296794931206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 392}], {
             RGBColor[
             0.9924671913475096, 0.9911530042849124, 0.7745016638630496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 395}], {
             RGBColor[
             0.7312446954176929, 0.785613119798958, 0.8514446443288036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 379}], {
             RGBColor[
             0.22335212736306764`, 0.3520876255743447, 0.9360309452822404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 371}], {
             RGBColor[
             0.20120013846367035`, 0.3288044807238608, 0.9347694222853504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 388}], {
             RGBColor[
             0.21768345542489445`, 0.346129491952765, 0.93570812280141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 392}], {
             RGBColor[
             0.8783955245201162, 0.9037382421614023, 0.8873541737699352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 395}], {
             RGBColor[
             0.6171730285902994, 0.6981983576754478, 0.9642971542356892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 363}], {
             RGBColor[
             0.2074463229173425, 0.3353696166156383, 0.9351251332495853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 372}], {
             RGBColor[
             0.1945300591839852, 0.3217938044934594, 0.9343895711378705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 364}], {
             RGBColor[
             0.8373888047327049, 0.2883923138200816, 0.1834368676776406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 385}], {
             RGBColor[
             0.9257629036983032, 0.7151948013477634, 0.418460634800934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 359}], {
             RGBColor[
             0.18898988195831087`, 0.3159707269617513, 0.934074066240826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 362}], {
             RGBColor[
             0.18997045450082056`, 0.31700137087581914`, 0.9341299083964949]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 363}], {
             RGBColor[
             0.20533835444542115`, 0.3331540080987284, 0.9350050875635693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 369}], {
             RGBColor[
             0.19068675298749674`, 0.31775424600126295`, 0.9341707005356424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 372}], {
             RGBColor[
             0.19242209071206384`, 0.3195781959765495, 0.9342695254518545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 397}], {
             RGBColor[
             0.20184959481572412`, 0.3294871005277804, 0.9348064078638154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 362}], {
             RGBColor[
             0.18818450229900258`, 0.31512422187579864`, 0.9340282010606809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 369}], {
             RGBColor[
             0.18890080078567878`, 0.31587709700124245`, 0.9340689931998285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 394}], {
             RGBColor[
             0.18381809529055626`, 0.3105348512637273, 0.9337795406410702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 397}], {
             RGBColor[
             0.20006364261390616`, 0.32760995152775996`, 0.9347047005280014]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 370}], {
             RGBColor[
             0.18616848137367975`, 0.313005256060175, 0.9339133916514194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 393}], {
             RGBColor[
             0.20049962337211924`, 0.32806819494741857`, 0.934729528987206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 396}], {
             RGBColor[
             0.20859692759923504`, 0.3365789750888577, 0.935190658484052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 363}], {
             RGBColor[
             0.20453297478611288`, 0.3323075030127757, 0.9349592223834241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 369}], {
             RGBColor[
             0.18988137332818844`, 0.31690774091531027`, 0.9341248353554973]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 397}], {
             RGBColor[
             0.20104421515641585`, 0.32864059544182767`, 0.9347605426836703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 369}], {
             RGBColor[
             0.20524927327278905`, 0.33306037813821954`, 0.9350000145225716]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 372}], {
             RGBColor[
             0.20698461099735616`, 0.3348843281135061, 0.9350988394387836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 385}], {
             RGBColor[
             0.9060512192132981, 0.563682156680796, 0.3995847034769297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 370}], {
             RGBColor[
             0.18400910577117147`, 0.3107356153896179, 0.9337904184053665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 398}], {
             RGBColor[
             0.40058820107881166`, 0.5213910984512207, 0.9467461038398723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 372}], {
             RGBColor[
             0.19233300953943172`, 0.31948456601604064`, 0.9342644524108568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 389}], {
             RGBColor[
             0.194598112629328, 0.3218653329793524, 0.9343934466809067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 391}], {
             RGBColor[
             0.18383722908563283`, 0.3105549620955055, 0.9337806302823939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 380}], {
             RGBColor[
             0.24598769620290184`, 0.37587904360296687`, 0.9373200074413457]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 382}], {
             RGBColor[
             0.18605529017041303`, 0.3128862849288049, 0.9339069455798448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 384}], {
             RGBColor[
             0.18988847579037965`, 0.3169152060533953, 0.934125239830212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 389}], {
             RGBColor[
             0.19643386923101253`, 0.3237948295614139, 0.9344979903036141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 377}], {
             RGBColor[
             0.18266643619111367`, 0.3093243845308089, 0.9337139553590839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 379}], {
             RGBColor[
             0.19896021464386793`, 0.3264501787698757, 0.934641861937483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 381}], {
             RGBColor[
             0.20814382827755723`, 0.3361027389736181, 0.9351648551479828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 384}], {
             RGBColor[
             0.18572468011707222`, 0.3125387928008556, 0.9338881178264007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 389}], {
             RGBColor[
             0.1922700735577051, 0.31941841630887424`, 0.9342608682998029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 389}], {
             RGBColor[
             0.1961032591776717, 0.32344733743346465`, 0.93447916255017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 387}], {
             RGBColor[
             0.7642756795140044, 0.8115756260652711, 0.7955379877927361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 400}], {
             RGBColor[
             0.8054695470793142, 0.5998653041518983, 0.5862367210785956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 390}], {
             RGBColor[
             0.23267978688900162`, 0.3618915871438733, 0.9365621416932066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 395}], {
             RGBColor[
             0.729861417537885, 0.7850410988470374, 0.8743691386056183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 396}], {
             RGBColor[
             0.19146055662429076`, 0.3185675626855177, 0.9342147675080179]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.0002105009621202394], {
             RGBColor[
             0.19354678877808446`, 0.32076032495391327`, 0.9343335753428726]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.0002105009621202394], {
             RGBColor[
             0.18498575182454155`, 0.3117621323146461, 0.9338460369532876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.0002105009621202394], {
             RGBColor[
             0.5818688834669836, 0.6714263983498019, 0.960225996443923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.0002105009621202394], {
             RGBColor[
             0.23281884209063286`, 0.36203774297739677`, 0.9365700606812258]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.0002105009621202394], {
             RGBColor[
             0.2824395297681887, 0.41419223185981874`, 0.9393958854372335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.0002105009621202394], {
             RGBColor[
             0.30558851701585305`, 0.4385232851876776, 0.9407141860151303]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.0002105009621202394], {
             RGBColor[
             0.4486453266434888, 0.5630157651939816, 0.9498082613856059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.0002105009621202394], {
             RGBColor[
             0.2378122641398246, 0.36728614615234123`, 0.9368544286798214]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.0002105009621202394], {
             RGBColor[
             0.19103464530579026`, 0.3181199028854364, 0.9341905124885087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.0002105009621202394], {
             RGBColor[
             0.23750097993416716`, 0.3669589667156367, 0.9368367015048129]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.0002105009621202394], {
             RGBColor[
             0.31196467996522614`, 0.44462985881031997`, 0.9410990914412173]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.0002105009621202394], {
             RGBColor[
             0.3084761160714523, 0.441558334879467, 0.9408786305095267]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.0002105009621202394], {
             RGBColor[
             0.21416269395992185`, 0.3424289484239088, 0.9355076206444797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.0002105009621202394], {
             RGBColor[
             0.18454901891679482`, 0.31130309833813863`, 0.9338211656602798]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.0002105009621202394], {
             RGBColor[
             0.28582560720535155`, 0.41775121393598635`, 0.9395887175380273]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.0002105009621202394], {
             RGBColor[
             0.3177755060429437, 0.4496629042982282, 0.9414693521405777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.0002105009621202394], {
             RGBColor[
             0.2316763474093035, 0.360836908628973, 0.9365049972992935]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.0002105009621202394], {
             RGBColor[
             0.6051402883638863, 0.6903191732099512, 0.9620580066833722]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.0002105009621202394], {
             RGBColor[
             0.26040419361571815`, 0.3910316964425663, 0.9381410056417089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.0002105009621202394], {
             RGBColor[
             0.19028821830363388`, 0.31733536077996466`, 0.9341480045749757]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.0002105009621202394], {
             RGBColor[
             0.9632021039744041, 0.8875341975281088, 0.3115475519504825]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.0002105009621202394], {
             RGBColor[
             0.3162753653274515, 0.4483635578097335, 0.9413737645007089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.0002105009621202394], {
             RGBColor[
             0.2930562064900811, 0.4253510322307103, 0.9400004894705796]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.0002105009621202394], {
             RGBColor[
             0.8207868509580615, 0.16078242208563953`, 0.1675388179938171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.0002105009621202394], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.0002105009621202394], {
             RGBColor[
             0.18699939157323073`, 0.3138785953626525, 0.9339607107580624]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.0002105009621202394], {
             RGBColor[
             0.821038236612611, 0.16271468238440395`, 0.16777954518051325`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.0002105009621202394], {
             RGBColor[
             0.20698871416859752`, 0.3348886408066369, 0.9350990731083157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.0002105009621202394], {
             RGBColor[
             0.1814383294461641, 0.30803356647540187`, 0.9336440164967801]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.0002105009621202394], {
             RGBColor[
             0.18021067351487519`, 0.3067432222537355, 0.9335741033076473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.0002105009621202394], {
             RGBColor[
             0.19647646719475834`, 0.3238396027221777, 0.9345004161946314]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.0002105009621202394], {
             RGBColor[
             0.9570322462930174, 0.8667218188173162, 0.28757881993815293`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.0002105009621202394], {
             RGBColor[
             0.2765417318743941, 0.4079932723314563, 0.939060014572192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.0002105009621202394], {
             RGBColor[
             0.2632481201845229, 0.3940208435817391, 0.93830296305259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.0002105009621202394], {
             RGBColor[
             0.2362515342121432, 0.36564572004235524`, 0.9367655474193329]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.0002105009621202394], {
             RGBColor[
             0.19287789451893317`, 0.32005727467719974`, 0.9342954828043544]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.0002105009621202394], {
             RGBColor[
             0.34879862256835453`, 0.4765335685653648, 0.9434461176929121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.0002105009621202394], {
             RGBColor[
             0.22292982485851465`, 0.3516437588665342, 0.9360068957793466]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.0002105009621202394], {
             RGBColor[
             0.18317563345981333`, 0.30985958314518375`, 0.9337429533902465]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.0002105009621202394], {
             RGBColor[
             0.5210599224495296, 0.6220589443833571, 0.9554388922820652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.0002105009621202394], {
             RGBColor[
             0.8718710063158469, 0.90067029040099, 0.9876410289824828]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.0002105009621202394], {
             RGBColor[
             0.21651396498896067`, 0.34490028335462225`, 0.9356415220511897]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.0002105009621202394], {
             RGBColor[
             0.26035980612556775`, 0.3909850423760888, 0.9381384778398102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.0002105009621202394], {
             RGBColor[
             0.2366745638317519, 0.36609035099419096`, 0.9367896383303533]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.0002105009621202394], {
             RGBColor[
             0.2848093981590889, 0.41668311379698936`, 0.9395308459361892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.0002105009621202394], {
             RGBColor[
             0.20129344185623907`, 0.3289025485052273, 0.9347747357755273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.0002105009621202394], {
             RGBColor[
             0.5441036538714303, 0.6407668836599264, 0.9572529792315668]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.0002105009621202394], {
             RGBColor[
             0.24018804114120323`, 0.3697832384137522, 0.9369897256654027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.0002105009621202394], {
             RGBColor[
             0.18767785554878408`, 0.3145917040180597, 0.9339993482777726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.0002105009621202394], {
             RGBColor[
             0.1790362447681438, 0.3055088231778375, 0.9335072213279326]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.0002105009621202394], {
             RGBColor[
             0.381577964086101, 0.5049253866504279, 0.9455347883487892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.0002105009621202394], {
             RGBColor[
             0.17936539842637753`, 0.30585478454218845`, 0.9335259661418299]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.0002105009621202394], {
             RGBColor[
             0.19239706134193654`, 0.319551888521592, 0.9342681000662533]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.0002105009621202394], {
             RGBColor[
             0.1846123721443362, 0.31136968659711123`, 0.9338247735328656]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.0002105009621202394], {
             RGBColor[
             0.9716313250190438, 0.9159679393868991, 0.3442934839840799]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.0002105009621202394], {
             RGBColor[
             0.38165040818030865`, 0.5049881340836845, 0.9455394044224124]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.0002105009621202394], {
             RGBColor[
             0.21768082531414856`, 0.3461267275396124, 0.9357079730204939]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.0002105009621202394], {
             RGBColor[
             0.21195870855243037`, 0.3401124200198894, 0.9353821069360272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.0002105009621202394], {
             RGBColor[
             0.3465121371910148, 0.4745531298536097, 0.9433004248665277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.0002105009621202394], {
             RGBColor[
             0.186004909472108, 0.3128333316205655, 0.9339040764736078]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.0002105009621202394], {
             RGBColor[
             0.20936457771848743`, 0.3373858240360207, 0.9352343750227069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.0002105009621202394], {
             RGBColor[
             0.20110579749352597`, 0.32870532238267614`, 0.9347640497066657]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.0002105009621202394], {
             RGBColor[
             0.1811814280726413, 0.30776354684334156`, 0.9336293863436095]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.0002105009621202394], {
             RGBColor[
             0.18064334912177313`, 0.30719799174980317`, 0.933598743543374]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.0002105009621202394], {
             RGBColor[
             0.2879462259501837, 0.4199801186917991, 0.9397094836383711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.0002105009621202394], {
             RGBColor[
             0.2142707962291993, 0.34254257076299915`, 0.935513776908792]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.0002105009621202394], {
             RGBColor[
             0.42522253205912725`, 0.5427281177888938, 0.9483157816266544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.0002105009621202394], {
             RGBColor[
             0.27002626100566185`, 0.40114509934370585`, 0.9386889681449931]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.0002105009621202394], {
             RGBColor[
             0.2418162773238607, 0.37149461787786187`, 0.9370824513072455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.0002105009621202394], {
             RGBColor[
             0.22291581655962178`, 0.35162903525622036`, 0.9360060980274482]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.0002105009621202394], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.0002105009621202394], {
             RGBColor[
             0.18281412095909713`, 0.3094796105857146, 0.9337223657881405]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.0002105009621202394], {
             RGBColor[
             0.9306153171117766, 0.762619883962795, 0.26302965936154776`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.0002105009621202394], {
             RGBColor[
             0.8630600513163033, 0.8936446740513561, 0.986800632228994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.0002105009621202394], {
             RGBColor[
             0.21796667840296896`, 0.34642717726009525`, 0.9357242519310205]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.0002105009621202394], {
             RGBColor[
             0.1938965482594379, 0.32112794434484765`, 0.9343534936279129]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.0002105009621202394], {
             RGBColor[
             0.18280925758947733`, 0.30947449887588874`, 0.9337220888264354]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.0002105009621202394], {
             RGBColor[
             0.8199375785531087, 0.1542545422276314, 0.1667255537797183]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.0002105009621202394], {
             RGBColor[
             0.23104392871496413`, 0.36017219648356114`, 0.9364689819902305]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.0002105009621202394], {
             RGBColor[
             0.1798079986201722, 0.3063199854083397, 0.9335511715680982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.0002105009621202394], {
             RGBColor[
             0.17955783501139488`, 0.30605704759422586`, 0.9335369251206622]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.0002105009621202394], {
             RGBColor[
             0.1807265568208277, 0.30728544831718235`, 0.9336034820987404]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.0002105009621202394], {
             RGBColor[
             0.9450344910434499, 0.9585273939347413, 0.9779264487494559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.0002105009621202394], {
             RGBColor[
             0.3388378220394789, 0.4679060237916442, 0.9428114242912021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.0002105009621202394], {
             RGBColor[
             0.24074527521724318`, 0.3703689267583512, 0.9370214593216792]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.0002105009621202394], {
             RGBColor[
             0.4110226556238299, 0.5304288985271809, 0.947410978056655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.0002105009621202394], {
             RGBColor[
             0.19817896485079942`, 0.32562903570326285`, 0.9345973709175234]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.0002105009621202394], {
             RGBColor[
             0.19146940577852636`, 0.3185768637076881, 0.9342152714542605]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.0002105009621202394], {
             RGBColor[
             0.1892450123424645, 0.31623888517169746`, 0.934088595538772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.0002105009621202394], {
             RGBColor[
             0.6083786689975903, 0.6929482364957771, 0.9623129438694364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.0002105009621202394], {
             RGBColor[
             0.4932978290383352, 0.5995204262840937, 0.953253358592837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.0002105009621202394], {
             RGBColor[
             0.49739045300864126`, 0.6028430027937971, 0.9535755449435551]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.0002105009621202394], {
             RGBColor[
             0.2343202347626608, 0.3636158018694917, 0.9366555627727864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.0002105009621202394], {
             RGBColor[
             0.18118663655961964`, 0.30776902129339295`, 0.9336296829592377]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.0002105009621202394], {
             RGBColor[
             0.559409915392181, 0.6531931963016955, 0.9584579442071637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.0002105009621202394], {
             RGBColor[
             0.7481991240396009, 0.803218109314472, 0.9755371544320737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.0002105009621202394], {
             RGBColor[
             0.19288958051724012`, 0.32006955740235543`, 0.93429614830467]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.0002105009621202394], {
             RGBColor[
             0.20101540430520026`, 0.32861031341048663`, 0.9347589019483153]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.0002105009621202394], {
             RGBColor[
             0.965636915117815, 0.9738926480760296, 0.9430519187643377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.0002105009621202394], {
             RGBColor[
             0.2101475089071078, 0.33820873435596516`, 0.9352789617956558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.0002105009621202394], {
             RGBColor[
             0.1831002535865883, 0.30978035411906424`, 0.9337386606179808]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.0002105009621202394], {
             RGBColor[
             0.2774713947406823, 0.40897040694795533`, 0.9391129574971142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.0002105009621202394], {
             RGBColor[
             0.19434739415987903`, 0.3216018119714924, 0.9343791686349763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.0002105009621202394], {
             RGBColor[
             0.8190091230934095, 0.14711802671260676`, 0.16583646378296987`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.0002105009621202394], {
             RGBColor[
             0.20947576509879728`, 0.3375026890224135, 0.9352407069795285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.0002105009621202394], {
             RGBColor[
             0.22681870684301533`, 0.35573122040160343`, 0.9362283618552786]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.0002105009621202394], {
             RGBColor[
             0.34861868121472545`, 0.4763777124089667, 0.9434346519889747]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.0002105009621202394], {
             RGBColor[
             0.256153514960176, 0.38656396366699863`, 0.9378989357805914]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.0002105009621202394], {
             RGBColor[
             0.18132254229683142`, 0.30791186684012395`, 0.9336374225899173]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.0002105009621202394], {
             RGBColor[
             0.18343408206602244`, 0.3101312290168976, 0.9337576716560296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.0002105009621202394], {
             RGBColor[
             0.18925042984728385`, 0.3162445793127523, 0.934088904057657]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.0002105009621202394], {
             RGBColor[
             0.937107871400364, 0.788360698201582, 0.2682537209419814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.0002105009621202394], {
             RGBColor[
             0.30752560771325343`, 0.4405592903292892, 0.9408245004646784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.0002105009621202394], {
             RGBColor[
             0.24129060741956473`, 0.3709421054790498, 0.9370525151838548]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.0002105009621202394], {
             RGBColor[
             0.8646080428941941, 0.47809856902505976`, 0.2087379710414105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.0002105009621202394], {
             RGBColor[
             0.18333815129494635`, 0.31003039969413443`, 0.9337522085405336]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.0002105009621202394], {
             RGBColor[
             0.22614100723621103`, 0.3550189151462153, 0.9361897678652379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.0002105009621202394], {
             RGBColor[
             0.2388812891503496, 0.36840975921850344`, 0.93691530807269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.0002105009621202394], {
             RGBColor[
             0.18241596627536708`, 0.30906112476864933`, 0.9336996914679191]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.0002105009621202394], {
             RGBColor[
             0.5182991743784003, 0.6198176447289311, 0.9552215560809526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.0002105009621202394], {
             RGBColor[
             0.3109061797336599, 0.4437130391115059, 0.9410316447424569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.0002105009621202394], {
             RGBColor[
             0.5979628209588992, 0.6844921818293608, 0.9614929701573222]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.0002105009621202394], {
             RGBColor[
             0.21169783120855037`, 0.3398382213908926, 0.9353672503572267]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.0002105009621202394], {
             RGBColor[
             0.3097296345397099, 0.44269397479938727`, 0.9409566763230764]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.0002105009621202394], {
             RGBColor[
             0.2615118954900493, 0.3921959613448436, 0.9382040876247539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.0002105009621202394], {
             RGBColor[
             0.1865862227024127, 0.3134443286830033, 0.9339371814020978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.0002105009621202394], {
             RGBColor[
             0.19480415931956344`, 0.32208190111490453`, 0.9344051807350968]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.0002105009621202394], {
             RGBColor[
             0.19461177340916913`, 0.32187969132510885`, 0.9343942246421093]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.0002105009621202394], {
             RGBColor[
             0.189088316742455, 0.3160741881610126, 0.9340796719561618]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.0002105009621202394], {
             RGBColor[
             0.1820121662584413, 0.30863670534846055`, 0.9336766956543238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.0002105009621202394], {
             RGBColor[
             0.21325644631447746`, 0.3414764246891273, 0.9354560111817448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.0002105009621202394], {
             RGBColor[
             0.35827341580975897`, 0.4847401582541144, 0.9440498431400237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.0002105009621202394], {
             RGBColor[
             0.18578718983175693`, 0.312604494474334, 0.9338916776621772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.0002105009621202394], {
             RGBColor[
             0.830968185180272, 0.8680554911049849, 0.9837396813881922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.0002105009621202394], {
             RGBColor[
             0.9948422584139026, 0.9913764372120322, 0.679989842123797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.0002105009621202394], {
             RGBColor[
             0.18458947116943916`, 0.3113456162204888, 0.9338234693562242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.0002105009621202394], {
             RGBColor[
             0.33446348254021346`, 0.46411719077807645`, 0.9425326952463855]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.0002105009621202394], {
             RGBColor[
             0.18225239431662393`, 0.3088892002689491, 0.9336903762868517]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.0002105009621202394], {
             RGBColor[
             0.18805967833656198`, 0.31499302397697726`, 0.9340210925206803]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.0002105009621202394], {
             RGBColor[
             0.2256991535454318, 0.35455449890206425`, 0.9361646049512119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.0002105009621202394], {
             RGBColor[
             0.8655975347340893, 0.482591620368333, 0.20956362728728348`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.0002105009621202394], {
             RGBColor[
             0.18248883410320854`, 0.3091377134757978, 0.9337038411829164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.0002105009621202394], {
             RGBColor[
             0.18504307948317125`, 0.3118223873186494, 0.9338493016786379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.0002105009621202394], {
             RGBColor[
             0.1905501321581982, 0.3176106488474093, 0.9341629201815262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.0002105009621202394], {
             RGBColor[
             0.1972575262297792, 0.3246605452899877, 0.9345448963512025]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.0002105009621202394], {
             RGBColor[
             0.18614238840660097`, 0.3129778306973855, 0.9339119056955454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.0002105009621202394], {
             RGBColor[
             0.1834762116557925, 0.31017550988691617`, 0.9337600708738418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.0002105009621202394], {
             RGBColor[
             0.33397821749630197`, 0.46369687858717057`, 0.9425017745868906]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.0002105009621202394], {
             RGBColor[
             0.21660346779159745`, 0.34499435647499893`, 0.9356466191033923]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.0002105009621202394], {
             RGBColor[
             0.19354588592399127`, 0.3207593759970171, 0.9343335239266677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.0002105009621202394], {
             RGBColor[
             0.19201931518110454`, 0.3191548533560677, 0.9342465879812193]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.0002105009621202394], {
             RGBColor[
             0.25676930210776144`, 0.3872111950022711, 0.9379340039476709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.0002105009621202394], {
             RGBColor[
             0.1824446187841665, 0.30909124037207153`, 0.9337013231859077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.0002105009621202394], {
             RGBColor[
             0.2055125320888361, 0.33333707984545796`, 0.935015006722689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.0002105009621202394], {
             RGBColor[
             0.2070813101039675, 0.3349859650056321, 0.9351043463098516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.0002105009621202394], {
             RGBColor[
             0.8309858670902185, 0.23917652931476524`, 0.17730540736011186`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.0002105009621202394], {
             RGBColor[
             0.1873941802353717, 0.31429354327760956`, 0.9339831933883338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.0002105009621202394], {
             RGBColor[
             0.3387561380668311, 0.4678352732400925, 0.9428062194606953]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.0002105009621202394], {
             RGBColor[
             0.1805122222555836, 0.3070601690995145, 0.9335912760623294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.0002105009621202394], {
             RGBColor[
             0.4596234812344611, 0.572182073724828, 0.9506023905805157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.0002105009621202394], {
             RGBColor[
             0.1994550789542851, 0.32697031253633363`, 0.9346700437278752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.0002105009621202394], {
             RGBColor[
             0.27232886945688745`, 0.40356528681975196`, 0.9388200982898864]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.0002105009621202394], {
             RGBColor[
             0.26679472020223177`, 0.3977485450677799, 0.938504936676874]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.0002105009621202394], {
             RGBColor[
             0.20095261322947336`, 0.32854431600871353`, 0.9347553260894438]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.0002105009621202394], {
             RGBColor[
             0.8967495440562933, 0.920507761085305, 0.9900139661214994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.0002105009621202394], {
             RGBColor[
             0.9896948922783259, 0.9900065873749687, 0.82044583391943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.0002105009621202394], {
             RGBColor[
             0.3102543804501736, 0.4431484833325346, 0.9409901126684767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.0002105009621202394], {
             RGBColor[
             0.18420503135956878`, 0.31094154560542325`, 0.9338015760777798]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.0002105009621202394], {
             RGBColor[
             0.8957887014800139, 0.9197416112963568, 0.9899223200988196]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.0002105009621202394], {
             RGBColor[
             0.2316644133079956, 0.36082436513183264`, 0.936504317669879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.0002105009621202394], {
             RGBColor[
             0.188962757776349, 0.315942217726737, 0.93407252155879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.0002105009621202394], {
             RGBColor[
             0.8238032261936802, 0.18396760393066158`, 0.17042730232595416`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.0002105009621202394], {
             RGBColor[
             0.2824798268544749, 0.4142345866524884, 0.9393981802966833]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.0002105009621202394], {
             RGBColor[
             0.34399645769565007`, 0.4723741747164527, 0.943140127993611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.0002105009621202394], {
             RGBColor[
             0.28165135838121924`, 0.41336381375916165`, 0.9393510002427407]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.0002105009621202394], {
             RGBColor[
             0.23366891778676377`, 0.3629312264319425, 0.9366184712345461]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.0002105009621202394], {
             RGBColor[
             0.8948525196191675, 0.9189951252924975, 0.9898330262371927]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.0002105009621202394], {
             RGBColor[
             0.44169024668361, 0.5569916245052177, 0.9493650898406981]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.0002105009621202394], {
             RGBColor[
             0.45394807471440896`, 0.5675745230376996, 0.950155601789558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.0002105009621202394], {
             RGBColor[
             0.2585433275657887, 0.3890758082383683, 0.93803503207307]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.0002105009621202394], {
             RGBColor[
             0.19492367816056405`, 0.3222075229947284, 0.9344119871562795]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.0002105009621202394], {
             RGBColor[
             0.34853172220347034`, 0.47630239288410453`, 0.9434291110376724]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.0002105009621202394], {
             RGBColor[
             0.3499869056482099, 0.4775627996442913, 0.943521834040003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.0002105009621202394], {
             RGBColor[
             0.18311045325504194`, 0.3097910746173054, 0.9337392414740102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.0002105009621202394], {
             RGBColor[
             0.3996003392677278, 0.5205354622018381, 0.9466831581588019]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.0002105009621202394], {
             RGBColor[
             0.20685160848485196`, 0.33474453404001786`, 0.9350912651424561]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.0002105009621202394], {
             RGBColor[
             0.43492032413853554`, 0.551127857862875, 0.9489337163625334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.0002105009621202394], {
             RGBColor[
             0.2017846044041309, 0.3294187914845658, 0.9348027067560198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.0002105009621202394], {
             RGBColor[
             0.266643234211289, 0.39758932368653244`, 0.9384963097737932]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.0002105009621202394], {
             RGBColor[
             0.9562193148935751, 0.9668690172486966, 0.9589934594404549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.0002105009621202394], {
             RGBColor[
             0.20722377740839654`, 0.33513570717553587`, 0.9351124596120775]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.0002105009621202394], {
             RGBColor[
             0.18162114890697434`, 0.30822572132013676`, 0.933654427794616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.0002105009621202394], {
             RGBColor[
             0.18694492825143932`, 0.3138213509582757, 0.9339576091524576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.0002105009621202394], {
             RGBColor[
             0.9945316676487347, 0.9907121149708813, 0.6461839540792844]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.0002105009621202394], {
             RGBColor[
             0.20184829587443234`, 0.32948573525812513`, 0.9348063338910304]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.0002105009621202394], {
             RGBColor[
             0.18973547474422028`, 0.3167543922530552, 0.9341165266469779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.0002105009621202394], {
             RGBColor[
             0.9643115115712477, 0.9729041642811488, 0.9452954812480678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.0002105009621202394], {
             RGBColor[
             0.3533082208089774, 0.4804395559023944, 0.9437334653051234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.0002105009621202394], {
             RGBColor[
             0.18648980339442428`, 0.3133429858769703, 0.9339316904651475]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.0002105009621202394], {
             RGBColor[
             0.1842143453500115, 0.31095133519991963`, 0.9338021064957567]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.0002105009621202394], {
             RGBColor[
             0.9490437648216794, 0.9615175037539616, 0.971139794028986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.0002105009621202394], {
             RGBColor[
             0.2433593553333951, 0.37311649070267905`, 0.9371703273171091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.0002105009621202394], {
             RGBColor[
             0.2257570420476589, 0.35461534338824796`, 0.9361679016157753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.0002105009621202394], {
             RGBColor[
             0.19363457114614188`, 0.3208525897884652, 0.9343385744188711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.0002105009621202394], {
             RGBColor[
             0.3500177192487492, 0.4775894888363419, 0.943523797455382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.0002105009621202394], {
             RGBColor[
             0.7303132143006519, 0.7892455006884563, 0.9737544541026248]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.0002105009621202394], {
             RGBColor[
             0.18775722726537172`, 0.31467512872465075`, 0.9340038683796124]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.0002105009621202394], {
             RGBColor[
             0.9930152754848626, 0.9913796511608278, 0.7654184913108293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.0002105009621202394], {
             RGBColor[
             0.33484250288537293`, 0.4644454791509371, 0.9425568460876246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.0002105009621202394], {
             RGBColor[
             0.3056537490672848, 0.4385918482096833, 0.9407179008839572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.0002105009621202394], {
             RGBColor[
             0.22188954865981286`, 0.3505503626243781, 0.9359476535887813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.0002105009621202394], {
             RGBColor[
             0.41733642177677943`, 0.535897565429752, 0.9478132856528767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.0002105009621202394], {
             RGBColor[
             0.22261848399738943`, 0.3513165198813409, 0.9359891653778931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.0002105009621202394], {
             RGBColor[
             0.23974505627195325`, 0.36931763322930755`, 0.9369644983324363]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.0002105009621202394], {
             RGBColor[
             0.18299643202543156`, 0.30967123107562133`, 0.9337327481336631]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.0002105009621202394], {
             RGBColor[
             0.1997106484206986, 0.3272389322495743, 0.9346845980309063]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.0002105009621202394], {
             RGBColor[
             0.9930695883095065, 0.987584875103169, 0.4870456409120508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.0002105009621202394], {
             RGBColor[
             0.19086057119328328`, 0.3179369399562554, 0.934180599225321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.0002105009621202394], {
             RGBColor[
             0.3371253879726633, 0.4664227994724073, 0.9427023095067106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.0002105009621202394], {
             RGBColor[
             0.635822518194204, 0.7152283896049052, 0.9644734242083259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.0002105009621202394], {
             RGBColor[
             0.9023083761464576, 0.6492869771870501, 0.2401960532268301]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.0002105009621202394], {
             RGBColor[
             0.23238602207295528`, 0.3615828216964435, 0.9365454122215189]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.0002105009621202394], {
             RGBColor[
             0.9299021495647822, 0.7597924122879596, 0.2624558280130423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.0002105009621202394], {
             RGBColor[
             0.1793343425625045, 0.3058221428602024, 0.9335241975563253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.0002105009621202394], {
             RGBColor[
             0.884710274500928, 0.9109079743391231, 0.9888656498437259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.0002105009621202394], {
             RGBColor[
             0.44524034591787487`, 0.5600665420287623, 0.9495912990246761]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.0002105009621202394], {
             RGBColor[
             0.20746958876179836`, 0.3353940704933011, 0.9351264582050084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.0002105009621202394], {
             RGBColor[
             0.20359531165465325`, 0.33132195961033534`, 0.9349058238552358]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.0002105009621202394], {
             RGBColor[
             0.20688302376209858`, 0.33477755348824767`, 0.9350930541960206]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.0002105009621202394], {
             RGBColor[
             0.8177383166445533, 0.1373500514757623, 0.1646195380923747]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.0002105009621202394], {
             RGBColor[
             0.18219295480676673`, 0.3088267255754066, 0.9336869912946982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.0002105009621202394], {
             RGBColor[
             0.295092829761857, 0.42749165241872045`, 0.9401164721529931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.0002105009621202394], {
             RGBColor[
             0.9594063537213845, 0.9692459055881796, 0.9535986340178257]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.0002105009621202394], {
             RGBColor[
             0.7857227396767522, 0.8325318430402561, 0.9792771577606599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.0002105009621202394], {
             RGBColor[
             0.1915139828942802, 0.31862371708269777`, 0.9342178100550568]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.0002105009621202394], {
             RGBColor[
             0.25077535368791876`, 0.38091117517473666`, 0.9375926574524128]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.0002105009621202394], {
             RGBColor[
             0.19733278810728, 0.3247396502951197, 0.9345491824037863]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.0002105009621202394], {
             RGBColor[
             0.28998218143607674`, 0.4221200369945062, 0.9398254282913666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.0002105009621202394], {
             RGBColor[
             0.82776291630336, 0.2144035172609302, 0.17421910604681382`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.0002105009621202394], {
             RGBColor[
             0.8316889234682268, 0.24458052871740593`, 0.17797865494168116`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.0002105009621202394], {
             RGBColor[
             0.2632132370288079, 0.3939841791733627, 0.938300976508477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.0002105009621202394], {
             RGBColor[
             0.852273426221674, 0.40280203706702433`, 0.19769039802525293`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.0002105009621202394], {
             RGBColor[
             0.9695261963263196, 0.9767932676332187, 0.9364683801653377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.0002105009621202394], {
             RGBColor[
             0.9547654228714991, 0.9657847069591619, 0.9614545193980599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.0002105009621202394], {
             RGBColor[
             0.818830055518114, 0.14574163486097447`, 0.1656649884706391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.0002105009621202394], {
             RGBColor[
             0.9202453542726101, 0.9392426823750178, 0.9922550174748891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.0002105009621202394], {
             RGBColor[
             0.1976279917679603, 0.3250499280594878, 0.9345659938155473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.0002105009621202394], {
             RGBColor[
             0.21799885977606132`, 0.3464610019236322, 0.9357260846126101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.0002105009621202394], {
             RGBColor[
             0.3090764058516128, 0.442128180941986, 0.9409150531686984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.0002105009621202394], {
             RGBColor[
             0.25834749102875554`, 0.38886997162119286`, 0.9380238794720002]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.0002105009621202394], {
             RGBColor[
             0.19027393338711107`, 0.3173203464269832, 0.9341471910701123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.0002105009621202394], {
             RGBColor[
             0.3695662131784596, 0.4945214117423836, 0.9447694102025287]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.0002105009621202394], {
             RGBColor[
             0.19109293756035423`, 0.31818117174092553`, 0.9341938321461705]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.0002105009621202394], {
             RGBColor[
             0.18724741023772068`, 0.314139278704323, 0.9339748350540943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.0002105009621202394], {
             RGBColor[
             0.8353613957275855, 0.2728087597904426, 0.18149541852470724`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.0002105009621202394], {
             RGBColor[
             0.3513087838325387, 0.47870774408802763`, 0.9436060629490174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.0002105009621202394], {
             RGBColor[
             0.32310439559809073`, 0.45427852059311985`, 0.9418089042708796]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.0002105009621202394], {
             RGBColor[
             0.18340786605487358`, 0.31010367432698904`, 0.9337561786929778]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.0002105009621202394], {
             RGBColor[
             0.18623692915551526`, 0.3130771990187241, 0.9339172896513356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.0002105009621202394], {
             RGBColor[
             0.22458179928431016`, 0.35338008872927346`, 0.9361009732790185]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.0002105009621202394], {
             RGBColor[
             0.2599700418165058, 0.39057537537478015`, 0.9381162813390138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.0002105009621202394], {
             RGBColor[
             0.2141514811516508, 0.34241716305148284`, 0.9355069820916365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.0002105009621202394], {
             RGBColor[
             0.3919526428400527, 0.5139114119405849, 0.9461958537050229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.0002105009621202394], {
             RGBColor[
             0.7232916660208124, 0.7837602138065023, 0.9730546117901898]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.0002105009621202394], {
             RGBColor[
             0.18998272969436467`, 0.3170142728825262, 0.9341306074506077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.0002105009621202394], {
             RGBColor[
             0.23275233921967517`, 0.3619678442434947, 0.9365662734411069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.0002105009621202394], {
             RGBColor[
             0.2559867658273416, 0.386388699755884, 0.9378894396641596]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.0002105009621202394], {
             RGBColor[
             0.679362894162589, 0.7494427233598264, 0.9686762023490751]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.0002105009621202394], {
             RGBColor[
             0.743581503407994, 0.7996107889818441, 0.9750769131616334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.0002105009621202394], {
             RGBColor[
             0.3590992451452233, 0.4854554501171043, 0.9441024642550272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.0002105009621202394], {
             RGBColor[
             0.17909981633317154`, 0.30557564092335165`, 0.9335108416345153]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.0002105009621202394], {
             RGBColor[
             0.7409332819620127, 0.7975419782610151, 0.9748129631969344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.0002105009621202394], {
             RGBColor[
             0.1818250295794584, 0.30844001283369876`, 0.9336660384972996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.0002105009621202394], {
             RGBColor[
             0.49307848673520527`, 0.5993423543211548, 0.9532360911632574]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.0002105009621202394], {
             RGBColor[
             0.23875032994207512`, 0.36827211278731364`, 0.9369078501395155]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.0002105009621202394], {
             RGBColor[
             0.22285712514090053`, 0.35156734685389346`, 0.9360027556379781]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.0002105009621202394], {
             RGBColor[
             0.20781531186542476`, 0.3357574473953233, 0.9351461466243084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.0002105009621202394], {
             RGBColor[
             0.25816588373595994`, 0.3886790908418973, 0.9380135372053394]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.0002105009621202394], {
             RGBColor[
             0.6722342021283076, 0.7438737349625797, 0.9679656809485127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.0002105009621202394], {
             RGBColor[
             0.2515360626002474, 0.3817107284733248, 0.937635978699602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.0002105009621202394], {
             RGBColor[
             0.4286879330306734, 0.5457296739343299, 0.9485365939122276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.0002105009621202394], {
             RGBColor[
             0.2671426063657563, 0.39811419548290095`, 0.9385247482792353]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.0002105009621202394], {
             RGBColor[
             0.20898033639140454`, 0.33698196203894937`, 0.9352124930475636]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.0002105009621202394], {
             RGBColor[
             0.2765987024765969, 0.40805315204651627`, 0.939063258963707]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.0002105009621202394], {
             RGBColor[
             0.9941990383585994, 0.9900006545532618, 0.6099793085980734]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.0002105009621202394], {
             RGBColor[
             0.1948453625020903, 0.32212520827217295`, 0.9344075271953871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.0002105009621202394], {
             RGBColor[
             0.1899324083338537, 0.31696138194207063`, 0.9341277417235704]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.0002105009621202394], {
             RGBColor[
             0.30537118422496984`, 0.4382948546447645, 0.9407018092342045]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.0002105009621202394], {
             RGBColor[
             0.1861676814246589, 0.31300441526303435`, 0.9339133460955061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.0002105009621202394], {
             RGBColor[
             0.19821724293608944`, 0.32566926839787347`, 0.9345995507978533]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.0002105009621202394], {
             RGBColor[
             0.18717515147111807`, 0.3140633301591533, 0.9339707200242335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.0002105009621202394], {
             RGBColor[
             0.1943854920349882, 0.321641855253777, 0.934381338252603]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.0002105009621202394], {
             RGBColor[
             0.3488943015599562, 0.47661644089892424`, 0.9434522142736513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.0002105009621202394], {
             RGBColor[
             0.1899597624904289, 0.3169901328949849, 0.9341292995023205]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.0002105009621202394], {
             RGBColor[
             0.4290348579738498, 0.5460301628831548, 0.9485586996628331]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.0002105009621202394], {
             RGBColor[
             0.2449605595581574, 0.37479945786511576`, 0.9372615135289399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.0002105009621202394], {
             RGBColor[
             0.20692052412863532`, 0.33481696875113837`, 0.935095189786418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.0002105009621202394], {
             RGBColor[
             0.19699767297971368`, 0.3243874230485212, 0.9345300980930298]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.0002105009621202394], {
             RGBColor[
             0.18766218808016377`, 0.31457523651516484`, 0.9339984560386126]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.0002105009621202394], {
             RGBColor[
             0.9146994662552146, 0.9348205418090667, 0.9917260457249173]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.0002105009621202394], {
             RGBColor[
             0.18269671784651187`, 0.30935621247060024`, 0.933715679854561]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.0002105009621202394], {
             RGBColor[
             0.19137511524925596`, 0.3184777583830601, 0.9342099017481089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.0002105009621202394], {
             RGBColor[
             0.21323548342695858`, 0.34145439136522115`, 0.9354548173763124]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.0002105009621202394], {
             RGBColor[
             0.1808905282724361, 0.3074577927092133, 0.9336128200303355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.0002105009621202394], {
             RGBColor[
             0.18223318953702214`, 0.3088690148279342, 0.9336892826030643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.0002105009621202394], {
             RGBColor[
             0.20271236623405806`, 0.3303939279913168, 0.9348555414197336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.0002105009621202394], {
             RGBColor[
             0.3483545068205488, 0.47614889782652203`, 0.9434178190301781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.0002105009621202394], {
             RGBColor[
             0.20150049615977755`, 0.32912017570624735`, 0.9347865272118044]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.0002105009621202394], {
             RGBColor[
             0.2975965440226766, 0.4301232148514946, 0.9402590549762334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.0002105009621202394], {
             RGBColor[
             0.27959908951497947`, 0.4112067490593821, 0.9392341265668681]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.0002105009621202394], {
             RGBColor[
             0.3027440138032642, 0.4355335319593264, 0.9405521957652387]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.0002105009621202394], {
             RGBColor[
             0.3029090080003519, 0.4357069513217019, 0.9405615919406759]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.0002105009621202394], {
             RGBColor[
             0.218367213855187, 0.3468481654157909, 0.9357470618324852]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.0002105009621202394], {
             RGBColor[
             0.23267428983588884`, 0.3618858093925185, 0.936561828644164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.0002105009621202394], {
             RGBColor[
             0.2188459842157359, 0.34735138342052185`, 0.9357743270962412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.0002105009621202394], {
             RGBColor[
             0.23435379828218117`, 0.36365107925655765`, 0.9366574741655703]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.0002105009621202394], {
             RGBColor[
             0.1953540422101205, 0.32265986289746895`, 0.9344364957522352]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.0002105009621202394], {
             RGBColor[
             0.19439044372267295`, 0.3216470597914888, 0.9343816202438913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.0002105009621202394], {
             RGBColor[
             0.4533617737780597, 0.567098537525015, 0.9501094460321575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.0002105009621202394], {
             RGBColor[
             0.19579265616170655`, 0.32312087397031664`, 0.9344614741679068]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.0002105009621202394], {
             RGBColor[
             0.5543615420614805, 0.6490946994052059, 0.9580605177657702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.0002105009621202394], {
             RGBColor[
             0.1999051049994005, 0.32744331844304914`, 0.9346956720453906]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.0002105009621202394], {
             RGBColor[
             0.3986910652219958, 0.5197478947248675, 0.9466252200206473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.0002105009621202394], {
             RGBColor[
             0.6331296311169758, 0.713042182562431, 0.9642614302732361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.0002105009621202394], {
             RGBColor[
             0.289139123347183, 0.42123392949010874`, 0.9397774173803968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.0002105009621202394], {
             RGBColor[
             0.19201165546058205`, 0.31914680250414423`, 0.9342461517714671]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.0002105009621202394], {
             RGBColor[
             0.19560708734050541`, 0.3229258293734914, 0.9344509062980639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.0002105009621202394], {
             RGBColor[
             0.8695307562797816, 0.5004514607800906, 0.21284560375709155`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.0002105009621202394], {
             RGBColor[
             0.19044334897469703`, 0.3174984129511047, 0.9341568390371975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.0002105009621202394], {
             RGBColor[
             0.18593025704413854`, 0.31275486718553225`, 0.9338998251282734]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.0002105009621202394], {
             RGBColor[
             0.19914754728651962`, 0.3266470772548782, 0.9346525302543484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.0002105009621202394], {
             RGBColor[
             0.2283446787479909, 0.35733511362593967`, 0.9363152636977938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.0002105009621202394], {
             RGBColor[
             0.18811264277564865`, 0.31504869296059673`, 0.9340241087671325]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.0002105009621202394], {
             RGBColor[
             0.1849809522741401, 0.31175708768286514`, 0.9338457636259925]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.0002105009621202394], {
             RGBColor[
             0.1795029989097729, 0.3059994113746115, 0.9335338022857975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.0002105009621202394], {
             RGBColor[
             0.18035329176886106`, 0.3068931230811942, 0.933582225206227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.0002105009621202394], {
             RGBColor[
             0.9940468194635823, 0.9896750737285114, 0.5934112212615963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.0002105009621202394], {
             RGBColor[
             0.23420030298526878`, 0.3634897459673388, 0.9366487328354871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.0002105009621202394], {
             RGBColor[
             0.2515477771449798, 0.3817230412025836, 0.9376366458255944]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.0002105009621202394], {
             RGBColor[
             0.2029347338096705, 0.33062765041220404`, 0.9348682049242014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.0002105009621202394], {
             RGBColor[
             0.3362350503435996, 0.46565163376778274`, 0.9426455779802814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.0002105009621202394], {
             RGBColor[
             0.18371444184961855`, 0.31042590492529404`, 0.9337736377309502]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.0002105009621202394], {
             RGBColor[
             0.1820208818055452, 0.30864586594106436`, 0.9336771919918379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.0002105009621202394], {
             RGBColor[
             0.1912494582787511, 0.31834568493994736`, 0.9342027457695316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.0002105009621202394], {
             RGBColor[
             0.1789871968344326, 0.3054572706896884, 0.9335044281206677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.0002105009621202394], {
             RGBColor[
             0.3510664211934816, 0.47849782175157674`, 0.9435906198159696]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.0002105009621202394], {
             RGBColor[
             0.19785125300646603`, 0.3252845897767374, 0.9345787082127948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.0002105009621202394], {
             RGBColor[
             0.33313964664549794`, 0.4629705506640006, 0.9424483415937963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.0002105009621202394], {
             RGBColor[
             0.2019856527302044, 0.3296301060224692, 0.9348141561607654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.0002105009621202394], {
             RGBColor[
             0.9938504692273173, 0.9917250252368329, 0.751577169586235]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.0002105009621202394], {
             RGBColor[
             0.9097894237460113, 0.9309054071917814, 0.9912577214871428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.0002105009621202394], {
             RGBColor[
             0.2396024194233052, 0.3691677128576799, 0.9369563753749182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.0002105009621202394], {
             RGBColor[
             0.19002087389400624`, 0.31705436485483146`, 0.934132779706348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.0002105009621202394], {
             RGBColor[
             0.2158527042869893, 0.34420525643050026`, 0.9356038642324599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.0002105009621202394], {
             RGBColor[
             0.7657071355725306, 0.8168955009898127, 0.9772821894000061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.0002105009621202394], {
             RGBColor[
             0.19499177110397153`, 0.3222790929955916, 0.9344158649486721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.0002105009621202394], {
             RGBColor[
             0.85710048921771, 0.439904958487049, 0.20231279900164487`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.0002105009621202394], {
             RGBColor[
             0.19077583416012883`, 0.31784787596177183`, 0.9341757735766401]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.0002105009621202394], {
             RGBColor[
             0.18720392975649292`, 0.3140935779617309, 0.9339723589050121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.0002105009621202394], {
             RGBColor[
             0.18524924480481392`, 0.31203908014333226`, 0.9338610424887112]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.0002105009621202394], {
             RGBColor[
             0.21763599434706354`, 0.34607960735075854`, 0.93570541996324]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.0002105009621202394], {
             RGBColor[
             0.18916507484151227`, 0.3161548657898664, 0.9340840432163497]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.0002105009621202394], {
             RGBColor[
             0.21990087473071346`, 0.348460140235685, 0.9358344015504985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.0002105009621202394], {
             RGBColor[
             0.8176771202476999, 0.13687966915311423`, 0.16456093635363633`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.0002105009621202394], {
             RGBColor[
             0.18093049359979738`, 0.3074997988022181, 0.9336150959966053]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.0002105009621202394], {
             RGBColor[
             0.39439940253334044`, 0.5160306722091927, 0.9463517590690945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.0002105009621202394], {
             RGBColor[
             0.37508215881778845`, 0.49929904661568136`, 0.9451208813811075]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.0002105009621202394], {
             RGBColor[
             0.1851720653526604, 0.311957959645659, 0.9338566472330878]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.0002105009621202394], {
             RGBColor[
             0.19059767181486464`, 0.3176606160407541, 0.9341656274946448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.0002105009621202394], {
             RGBColor[
             0.18708771794254558`, 0.3139714319770177, 0.9339657408141276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.0002105009621202394], {
             RGBColor[
             0.18654757264035143`, 0.3134037050172214, 0.9339349803382411]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.0002105009621202394], {
             RGBColor[
             0.19406834726399882`, 0.3213085159913272, 0.9343632773270688]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.0002105009621202394], {
             RGBColor[
             0.271851153445097, 0.4030631770024157, 0.9387928930697325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.0002105009621202394], {
             RGBColor[
             0.19021908584372046`, 0.31726269818134456`, 0.934144067583656]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.0002105009621202394], {
             RGBColor[
             0.180596656524124, 0.30714891486919227`, 0.9335960844690134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.0002105009621202394], {
             RGBColor[
             0.209601906353837, 0.3376352714792777, 0.9352478905373938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.0002105009621202394], {
             RGBColor[
             0.18473621585810335`, 0.3114998541924255, 0.9338318262491543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.0002105009621202394], {
             RGBColor[
             0.19081859398490578`, 0.3178928192487419, 0.9341782086854036]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.0002105009621202394], {
             RGBColor[
             0.20710183530283005`, 0.33500753829100943`, 0.9351055151895625]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.0002105009621202394], {
             RGBColor[
             0.22012423896070668`, 0.348694910203518, 0.9358471218129588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.0002105009621202394], {
             RGBColor[
             0.19616341759440778`, 0.32351056774371817`, 0.9344825884830068]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.0002105009621202394], {
             RGBColor[
             0.1818914944971056, 0.30850987167626515`, 0.9336698235760336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.0002105009621202394], {
             RGBColor[
             0.20835388918653433`, 0.3363235263075839, 0.9351768178059918]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.0002105009621202394], {
             RGBColor[
             0.18955786573703887`, 0.316567713925446, 0.9341064120767679]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.0002105009621202394], {
             RGBColor[
             0.9944253181788963, 0.9904846442084778, 0.6346084706002231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.0002105009621202394], {
             RGBColor[
             0.7607606134285254, 0.8130312402959552, 0.9767891663005692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.0002105009621202394], {
             RGBColor[
             0.5341260408491124, 0.6326666079220644, 0.9564675049852491]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.0002105009621202394], {
             RGBColor[
             0.2195142065627996, 0.3480537274750297, 0.9358123813703602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.0002105009621202394], {
             RGBColor[
             0.20264865261830456`, 0.3303269609414833, 0.9348519130235723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.0002105009621202394], {
             RGBColor[
             0.2627109211596987, 0.39345621334626335`, 0.938272370362841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.0002105009621202394], {
             RGBColor[
             0.18112688553091424`, 0.3077062191737896, 0.9336262802265466]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.0002105009621202394], {
             RGBColor[
             0.9910839134677017, 0.9905809833329919, 0.7974261581398643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.0002105009621202394], {
             RGBColor[
             0.18336325239717496`, 0.31005678254407854`, 0.9337536380111718]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.0002105009621202394], {
             RGBColor[
             0.18043226082461958`, 0.30697612456572376`, 0.9335867223771283]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.0002105009621202394], {
             RGBColor[
             0.46863892160806836`, 0.5795012143610829, 0.9513121190713723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.0002105009621202394], {
             RGBColor[
             0.19955786085140656`, 0.3270783428269569, 0.9346758970048641]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.0002105009621202394], {
             RGBColor[
             0.2129233554713194, 0.341126325093789, 0.9354370421509908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.0002105009621202394], {
             RGBColor[
             0.4260942433398349, 0.54348315028676, 0.9483713262986371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.0002105009621202394], {
             RGBColor[
             0.9265760623547111, 0.7466055848528861, 0.2597795801705179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.0002105009621202394], {
             RGBColor[
             0.8501784807301029, 0.38669936800784144`, 0.19568427585662201`]},
             StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{3.8349504055390835`*^9, 3.834957759852075*^9, 
  3.834959830181028*^9, 3.8350239427848983`*^9},
 CellLabel->
  "Out[206]=",ExpressionUUID->"7f6f25a3-0deb-46e5-b1ec-db73dae2d329"]
}, Open  ]],

Cell["Estimated with Max-Min Deviation v Calculated: (r = 3)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 3.8349503922098827`*^9}, {3.8349504781120467`*^9, 
  3.8349504928656063`*^9}},ExpressionUUID->"4965bb42-a47b-4db4-9d7e-\
5412487bc278"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphin4b", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsi4b", ",", "#"}], "}"}], "]"}], ",", "500", ",", 
      "400"}], "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"mMDi3400b", ",", "kri4b"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502554527807`*^9}, {3.8349577716948586`*^9, 
   3.8349577796673746`*^9}, {3.8349598925438137`*^9, 
   3.8349598998017874`*^9}, {3.8349611605957685`*^9, 3.834961161612335*^9}},
 CellLabel->
  "In[207]:=",ExpressionUUID->"79d24648-1bfd-4e3c-a374-af19e8e8942f"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN2wucznW+wPHf/+zadNlSKJUyheimsIbchiJLGlM0NrNmJtWMMW5DaZZc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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[337, 399] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[15, 92] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[87, 313] -> 
             RGBColor[
              0.9313790000000001, 0.7572455714285717, 0.2875669285714287], 
             UndirectedEdge[35, 214] -> 
             RGBColor[
              0.8886209285714286, 0.7552864285714288, 0.6099357857142857], 
             UndirectedEdge[105, 218] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285717], 
             UndirectedEdge[149, 316] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[160, 348] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[17, 287] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[268, 295] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[277, 379] -> 
             RGBColor[
              0.9709799285714285, 0.9466688571428572, 0.639678642857143], 
             UndirectedEdge[10, 37] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[118, 389] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[127, 313] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[92, 281] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[2, 193] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[265, 378] -> 
             RGBColor[
              0.9531846428571429, 0.8528224285714285, 0.556411142857143], 
             UndirectedEdge[108, 367] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[26, 342] -> 
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475], 
             UndirectedEdge[57, 144] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[341, 348] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[232, 309] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[23, 202] -> 
             RGBColor[
              0.9705375714285714, 0.9100928571428573, 0.35142707142857166`], 
             UndirectedEdge[89, 170] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[291, 383] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[45, 140] -> 
             RGBColor[0.8555595, 0.7289241428571431, 0.6067823571428572], 
             UndirectedEdge[213, 308] -> 
             RGBColor[
              0.9418190000000001, 0.7924621428571431, 0.32812435714285737`], 
             UndirectedEdge[165, 386] -> 
             RGBColor[
              0.9055667857142857, 0.6459924285714286, 0.5608982142857144], 
             UndirectedEdge[347, 381] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[216, 396] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[39, 150] -> 
             RGBColor[
              0.8829455714285714, 0.4839698571428572, 0.22084807142857144`], 
             UndirectedEdge[20, 378] -> 
             RGBColor[
              0.5831437857142856, 0.6472176428571428, 0.8963162857142859], 
             UndirectedEdge[363, 372] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[54, 318] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[40, 246] -> 
             RGBColor[
              0.8813052857142857, 0.9080142857142857, 0.9823472142857144], 
             UndirectedEdge[59, 178] -> 
             RGBColor[
              0.9455993571428571, 0.8952721428571428, 0.6297402857142858], 
             UndirectedEdge[172, 357] -> 
             RGBColor[
              0.9563532142857143, 0.8541327142857142, 0.5038997142857143], 
             UndirectedEdge[268, 274] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[122, 175] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[120, 341] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[220, 366] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[202, 366] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285716], 
             UndirectedEdge[17, 61] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[112, 279] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[129, 313] -> 
             RGBColor[
              0.9600975714285714, 0.8748762857142858, 0.3108696428571429], 
             UndirectedEdge[204, 318] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[60, 335] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[256, 386] -> 
             RGBColor[
              0.9172472142857143, 0.6531244285714286, 0.47040450000000006`], 
             UndirectedEdge[7, 65] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[66, 280] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[147, 344] -> 
             RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 
             UndirectedEdge[329, 349] -> 
             RGBColor[
              0.9367337142857142, 0.9505314285714286, 0.9240652142857144], 
             UndirectedEdge[170, 306] -> 
             RGBColor[
              0.9036722857142857, 0.9241691428571428, 0.9209117857142859], 
             UndirectedEdge[175, 178] -> 
             RGBColor[
              0.9600975714285714, 0.8748762857142858, 0.3108696428571429], 
             UndirectedEdge[115, 166] -> 
             RGBColor[
              0.9426130000000001, 0.7941604285714288, 0.4145463571428576], 
             UndirectedEdge[361, 396] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[80, 265] -> 
             RGBColor[
              0.9446727857142856, 0.8470007142857143, 0.5943934285714286], 
             UndirectedEdge[18, 288] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[225, 240] -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 
             UndirectedEdge[110, 251] -> 
             RGBColor[
              0.9392477857142858, 0.793796285714286, 0.545002142857143], 
             UndirectedEdge[56, 169] -> 
             RGBColor[
              0.9261557857142857, 0.7343485714285716, 0.5340778571428573], 
             UndirectedEdge[87, 231] -> 
             RGBColor[
              0.8886209285714286, 0.7552864285714288, 0.6099357857142857], 
             UndirectedEdge[266, 315] -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 
             UndirectedEdge[31, 292] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[1, 87] -> 
             RGBColor[
              0.9313790000000001, 0.7572455714285717, 0.2875669285714287], 
             UndirectedEdge[231, 336] -> 
             RGBColor[
              0.9143667142857141, 0.9343765714285714, 0.9855006428571429], 
             UndirectedEdge[13, 309] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[237, 296] -> 
             RGBColor[
              0.9367337142857142, 0.9505314285714286, 0.9240652142857144], 
             UndirectedEdge[95, 312] -> 
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475], 
             UndirectedEdge[108, 236] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[48, 176] -> 
             RGBColor[
              0.9709799285714285, 0.9466688571428572, 0.6396786428571429], 
             UndirectedEdge[49, 52] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[310, 390] -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 
             UndirectedEdge[343, 358] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[271, 374] -> 
             RGBColor[
              0.9446727857142856, 0.8470007142857143, 0.5943934285714286], 
             UndirectedEdge[57, 167] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[34, 214] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[83, 220] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[9, 347] -> 
             RGBColor[0.8958035, 0.8876184285714286, 0.6634765714285715], 
             UndirectedEdge[188, 238] -> 
             RGBColor[
              0.6498679999999999, 0.7185642857142857, 0.9386530714285715], 
             UndirectedEdge[79, 137] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[115, 197] -> 
             RGBColor[
              0.9392477857142858, 0.793796285714286, 0.545002142857143], 
             UndirectedEdge[67, 194] -> 
             RGBColor[0.9172472142857143, 0.6531244285714286, 0.4704045], 
             UndirectedEdge[75, 260] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[32, 387] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[76, 144] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[50, 164] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[279, 285] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[137, 352] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[4, 275] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[8, 373] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[41, 135] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[85, 211] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[63, 139] -> 
             RGBColor[
              0.6117230714285713, 0.6803810714285714, 0.9364108571428572], 
             UndirectedEdge[55, 92] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[31, 371] -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 
             UndirectedEdge[99, 169] -> 
             RGBColor[
              0.9287270000000001, 0.7330144285714286, 0.31720007142857165`], 
             UndirectedEdge[71, 72] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[104, 112] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[389, 390] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[260, 349] -> 
             RGBColor[
              0.9367337142857142, 0.9505314285714286, 0.9240652142857144], 
             UndirectedEdge[70, 284] -> 
             RGBColor[
              0.9565498571428572, 0.8531865714285715, 0.42595535714285754`], 
             UndirectedEdge[24, 172] -> 
             RGBColor[
              0.9446727857142856, 0.8470007142857143, 0.5943934285714286], 
             UndirectedEdge[343, 362] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[233, 307] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[79, 278] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[1, 216] -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 
             UndirectedEdge[192, 374] -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 
             UndirectedEdge[152, 383] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[43, 121] -> 
             RGBColor[0.992503, 0.986373, 0.42537600000000036`], 
             UndirectedEdge[13, 280] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[246, 272] -> 
             RGBColor[
              0.8813052857142857, 0.9080142857142857, 0.9823472142857144], 
             UndirectedEdge[385, 387] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[90, 268] -> 
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475], 
             UndirectedEdge[195, 363] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[88, 109] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[63, 318] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[257, 276] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[16, 106] -> 
             RGBColor[
              0.7819626428571429, 0.7662115714285714, 0.6201700714285714], 
             UndirectedEdge[100, 227] -> 
             RGBColor[
              0.8529222857142856, 0.8845228571428572, 0.9158535000000001], 
             UndirectedEdge[195, 359] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[216, 313] -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 
             UndirectedEdge[12, 47] -> 
             RGBColor[
              0.9050718571428572, 0.6575774285714289, 0.24228171428571435`], 
             UndirectedEdge[386, 400] -> 
             RGBColor[
              0.9174438571428571, 0.6521782857142857, 0.39246014285714326`], 
             UndirectedEdge[180, 262] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             UndirectedEdge[247, 359] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[74, 141] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[170, 171] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[207, 333] -> 
             RGBColor[
              0.9531846428571429, 0.8528224285714285, 0.556411142857143], 
             UndirectedEdge[311, 313] -> 
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717], 
             UndirectedEdge[161, 195] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[87, 129] -> 
             RGBColor[
              0.9198535714285715, 0.7161820000000003, 0.2541754285714286], 
             UndirectedEdge[198, 367] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[322, 330] -> 
             RGBColor[0.9173395, 0.872917142857143, 0.6332385], 
             UndirectedEdge[79, 314] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[56, 274] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[249, 316] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[69, 294] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[6, 300] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[36, 265] -> 
             RGBColor[
              0.8694963571428571, 0.7879502857142857, 0.6181913571428572], 
             UndirectedEdge[167, 395] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[261, 306] -> 
             RGBColor[
              0.8813052857142857, 0.9080142857142857, 0.9823472142857144], 
             UndirectedEdge[35, 211] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.4924907142857144], 
             UndirectedEdge[54, 63] -> 
             RGBColor[
              0.9709799285714285, 0.9466688571428572, 0.639678642857143], 
             UndirectedEdge[302, 314] -> 
             RGBColor[
              0.9600975714285714, 0.8748762857142858, 0.3108696428571429], 
             UndirectedEdge[54, 224] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[164, 389] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[113, 210] -> 
             RGBColor[0.905705, 0.5619482857142857, 0.38121900000000036`], 
             UndirectedEdge[307, 348] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[18, 74] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[41, 328] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[63, 290] -> 
             RGBColor[
              0.9709799285714285, 0.9466688571428572, 0.6396786428571429], 
             UndirectedEdge[45, 288] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.4924907142857144], 
             UndirectedEdge[249, 315] -> 
             RGBColor[
              0.9446727857142856, 0.8470007142857143, 0.5943934285714286], 
             UndirectedEdge[306, 342] -> 
             RGBColor[
              0.8951604285714285, 0.9183474285714286, 0.9588940714285714], 
             UndirectedEdge[163, 395] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[378, 379] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[216, 235] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[220, 321] -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 
             UndirectedEdge[133, 199] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[317, 396] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[177, 197] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[208, 242] -> 
             RGBColor[
              0.9453158571428572, 0.8162717142857143, 0.29897592857142863`], 
             UndirectedEdge[51, 163] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[188, 228] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[95, 125] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[66, 203] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[151, 265] -> 
             RGBColor[
              0.9557558571428572, 0.8514882857142858, 0.3395333571428574], 
             UndirectedEdge[76, 333] -> 
             RGBColor[
              0.9531846428571429, 0.8528224285714285, 0.556411142857143], 
             UndirectedEdge[119, 336] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             UndirectedEdge[183, 395] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[42, 204] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[12, 107] -> 
             RGBColor[
              0.9565498571428572, 0.8531865714285715, 0.42595535714285754`], 
             UndirectedEdge[234, 239] -> 
             RGBColor[
              0.9308176428571429, 0.8366675714285714, 0.6178465714285715], 
             UndirectedEdge[164, 287] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[32, 194] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[6, 169] -> 
             RGBColor[
              0.9261557857142857, 0.7343485714285716, 0.5340778571428573], 
             UndirectedEdge[24, 240] -> 
             RGBColor[
              0.9446727857142856, 0.8470007142857143, 0.5943934285714286], 
             UndirectedEdge[9, 381] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[43, 90] -> 
             RGBColor[
              0.9393049285714286, 0.9491972857142857, 0.7071874285714288], 
             UndirectedEdge[88, 157] -> 
             RGBColor[
              0.9563532142857143, 0.8541327142857142, 0.5038997142857143], 
             UndirectedEdge[100, 314] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[56, 296] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[49, 235] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[359, 362] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[104, 285] -> 
             RGBColor[
              0.9705375714285714, 0.9100928571428573, 0.35142707142857166`], 
             UndirectedEdge[80, 168] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[311, 386] -> 
             RGBColor[
              0.9166498571428572, 0.6504800000000001, 0.30603814285714304`], 
             UndirectedEdge[61, 173] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[118, 354] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[154, 180] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[17, 158] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[8, 237] -> 
             RGBColor[
              0.9143667142857141, 0.9343765714285714, 0.9855006428571429], 
             UndirectedEdge[55, 255] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[93, 214] -> 
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475], 
             UndirectedEdge[129, 235] -> 
             RGBColor[
              0.9455993571428571, 0.8952721428571428, 0.6297402857142858], 
             UndirectedEdge[47, 158] -> 
             RGBColor[
              0.9392477857142858, 0.793796285714286, 0.545002142857143], 
             UndirectedEdge[106, 347] -> 
             RGBColor[
              0.9600975714285714, 0.8748762857142858, 0.3108696428571429], 
             UndirectedEdge[169, 178] -> 
             RGBColor[
              0.9067615714285715, 0.6567342857142858, 0.2432511428571429], 
             UndirectedEdge[230, 385] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[304, 383] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[100, 352] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[87, 216] -> 
             RGBColor[
              0.9313790000000001, 0.7572455714285717, 0.2875669285714287], 
             UndirectedEdge[79, 277] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[217, 220] -> 
             RGBColor[
              0.9600975714285714, 0.8748762857142858, 0.3108696428571429], 
             UndirectedEdge[78, 104] -> 
             RGBColor[
              0.9393049285714286, 0.9491972857142857, 0.7071874285714288], 
             UndirectedEdge[170, 353] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[78, 385] -> 
             RGBColor[
              0.9399022857142857, 0.9518417142857143, 0.8715537857142858], 
             UndirectedEdge[40, 102] -> 
             RGBColor[
              0.8842780714285714, 0.8465548571428572, 0.6300850714285715], 
             UndirectedEdge[41, 256] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[120, 217] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[210, 315] -> 
             RGBColor[
              0.8681638571428572, 0.4253652857142857, 0.20895435714285715`], 
             UndirectedEdge[83, 187] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[2, 305] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[121, 175] -> 
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717], 
             UndirectedEdge[36, 151] -> 
             RGBColor[0.9062435, 0.9228350000000001, 0.7040340000000002], 
             UndirectedEdge[70, 332] -> 
             RGBColor[
              0.9557558571428572, 0.8514882857142858, 0.3395333571428574], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.5489678571428571, 0.5109987857142857, 0.5935958571428572], 
             UndirectedEdge[221, 400] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[49, 216] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[75, 349] -> 
             RGBColor[
              0.9367337142857142, 0.9505314285714286, 0.9240652142857144], 
             UndirectedEdge[62, 87] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[38, 189] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[49, 361] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[107, 270] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[5, 8] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[162, 340] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[34, 85] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[21, 172] -> 
             RGBColor[
              0.9565498571428572, 0.8531865714285715, 0.42595535714285754`], 
             UndirectedEdge[298, 393] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[164, 371] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[11, 85] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[202, 307] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[20, 265] -> 
             RGBColor[
              0.5489678571428571, 0.5109987857142857, 0.5935958571428572], 
             UndirectedEdge[195, 247] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[281, 355] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[298, 313] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[67, 210] -> 
             RGBColor[
              0.8290578571428572, 0.22435700000000006`, 0.17545914285714287`],
              UndirectedEdge[11, 263] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[88, 181] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[212, 390] -> 
             RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 
             UndirectedEdge[13, 203] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[75, 105] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[12, 270] -> 
             RGBColor[
              0.8694963571428571, 0.7879502857142857, 0.6181913571428572], 
             UndirectedEdge[127, 393] -> 
             RGBColor[
              0.9399022857142857, 0.9518417142857143, 0.8715537857142858], 
             UndirectedEdge[185, 208] -> 
             RGBColor[
              0.8799027142857143, 0.5155952857142858, 0.22019550000000004`], 
             UndirectedEdge[246, 355] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[62, 336] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[118, 209] -> 
             RGBColor[0.992503, 0.986373, 0.42537600000000036`], 
             UndirectedEdge[178, 352] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[17, 22] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[12, 158] -> 
             RGBColor[
              0.9531846428571429, 0.8528224285714285, 0.556411142857143], 
             UndirectedEdge[200, 333] -> 
             RGBColor[0.7671809285714286, 0.707607, 0.6082763571428571], 
             UndirectedEdge[69, 295] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[181, 340] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[205, 284] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[283, 373] -> 
             RGBColor[0.9062435, 0.9228350000000001, 0.7040340000000002], 
             UndirectedEdge[302, 379] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[254, 303] -> 
             RGBColor[
              0.8045254285714285, 0.8451361428571429, 0.8584853571428572], 
             UndirectedEdge[38, 254] -> 
             RGBColor[
              0.8013568571428571, 0.8438258571428572, 0.9109967857142858], 
             UndirectedEdge[158, 209] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[365, 370] -> 
             RGBColor[
              0.7934880714285715, 0.807275142857143, 0.6535615714285715], 
             UndirectedEdge[61, 164] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[163, 167] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[62, 119] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[137, 197] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[265, 383] -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 
             UndirectedEdge[19, 338] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[69, 212] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[45, 275] -> 
             RGBColor[0.8555595, 0.7289241428571431, 0.6067823571428572], 
             UndirectedEdge[248, 360] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[188, 322] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[167, 183] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285716], 
             UndirectedEdge[141, 240] -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 
             UndirectedEdge[23, 220] -> 
             RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 
             UndirectedEdge[123, 322] -> 
             RGBColor[
              0.9198535714285715, 0.7161820000000003, 0.2541754285714286], 
             UndirectedEdge[177, 398] -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 
             UndirectedEdge[272, 395] -> 
             RGBColor[
              0.8813052857142857, 0.9080142857142857, 0.9823472142857144], 
             UndirectedEdge[85, 312] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285716], 
             UndirectedEdge[25, 328] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[8, 121] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[169, 319] -> 
             RGBColor[
              0.9037887857142857, 0.7181937142857143, 0.5955132857142857], 
             UndirectedEdge[84, 167] -> 
             RGBColor[0.9062435, 0.9228350000000001, 0.7040340000000002], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[43, 213] -> 
             RGBColor[
              0.9418190000000001, 0.7924621428571431, 0.32812435714285737`], 
             UndirectedEdge[170, 187] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[89, 199] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[16, 373] -> 
             RGBColor[
              0.8039280714285715, 0.8424917142857142, 0.6941190000000002], 
             UndirectedEdge[22, 158] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[233, 264] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[274, 296] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[97, 211] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[1, 129] -> 
             RGBColor[
              0.9600975714285714, 0.8748762857142858, 0.3108696428571429], 
             UndirectedEdge[24, 141] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[347, 384] -> 
             RGBColor[
              0.9313790000000001, 0.7572455714285717, 0.2875669285714287], 
             UndirectedEdge[36, 378] -> 
             RGBColor[
              0.9036722857142857, 0.9241691428571428, 0.9209117857142859], 
             UndirectedEdge[174, 395] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[104, 357] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[47, 173] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.4924907142857144], 
             UndirectedEdge[127, 231] -> 
             RGBColor[
              0.9399022857142857, 0.9518417142857143, 0.8715537857142858], 
             UndirectedEdge[252, 367] -> 
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475], 
             UndirectedEdge[158, 310] -> 
             RGBColor[
              0.9531846428571429, 0.8528224285714285, 0.556411142857143], 
             UndirectedEdge[149, 397] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[204, 345] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             UndirectedEdge[231, 396] -> 
             RGBColor[
              0.9367337142857142, 0.9505314285714286, 0.9240652142857144], 
             UndirectedEdge[162, 263] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[14, 196] -> 
             RGBColor[
              0.9455993571428571, 0.8952721428571428, 0.6297402857142858], 
             UndirectedEdge[43, 175] -> 
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717], 
             UndirectedEdge[113, 397] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[126, 336] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[48, 173] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[28, 168] -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 
             UndirectedEdge[253, 359] -> 
             RGBColor[
              0.9143667142857141, 0.9343765714285714, 0.9855006428571429], 
             UndirectedEdge[41, 187] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[198, 398] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[260, 329] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[60, 82] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[12, 17] -> 
             RGBColor[
              0.9565498571428572, 0.8531865714285715, 0.42595535714285754`], 
             UndirectedEdge[268, 351] -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 
             UndirectedEdge[122, 274] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[150, 384] -> 
             RGBColor[
              0.9198535714285715, 0.7161820000000003, 0.2541754285714286], 
             UndirectedEdge[179, 232] -> 
             RGBColor[
              0.8951604285714285, 0.9183474285714286, 0.9588940714285714], 
             UndirectedEdge[4, 131] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[128, 155] -> 
             RGBColor[0.9173395, 0.872917142857143, 0.6332385], 
             UndirectedEdge[316, 362] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[283, 320] -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714287], 
             UndirectedEdge[49, 396] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[371, 389] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[53, 58] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[18, 399] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[241, 270] -> 
             RGBColor[
              0.8951604285714285, 0.9183474285714286, 0.9588940714285714], 
             UndirectedEdge[137, 169] -> 
             RGBColor[
              0.9037887857142857, 0.7181937142857143, 0.5955132857142857], 
             UndirectedEdge[156, 386] -> 
             RGBColor[
              0.8946844285714286, 0.5741998571428573, 0.23208921428571433`], 
             UndirectedEdge[19, 262] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[85, 181] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[74, 240] -> 
             RGBColor[
              0.9565498571428572, 0.8531865714285715, 0.42595535714285754`], 
             UndirectedEdge[72, 88] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[63, 98] -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 
             UndirectedEdge[43, 56] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[174, 272] -> 
             RGBColor[
              0.8951604285714285, 0.9183474285714286, 0.9588940714285714], 
             UndirectedEdge[180, 198] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[126, 289] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[233, 244] -> 
             RGBColor[
              0.9174438571428571, 0.6521782857142858, 0.39246014285714326`], 
             UndirectedEdge[51, 189] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[199, 306] -> 
             RGBColor[0.8958035, 0.8876184285714286, 0.6634765714285715], 
             UndirectedEdge[86, 214] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[104, 172] -> 
             RGBColor[
              0.9557558571428572, 0.8514882857142858, 0.3395333571428574], 
             UndirectedEdge[67, 293] -> 
             RGBColor[
              0.9140786428571428, 0.6518141428571429, 0.5229159285714287], 
             UndirectedEdge[296, 380] -> 
             RGBColor[
              0.9367337142857142, 0.9505314285714286, 0.9240652142857144], 
             UndirectedEdge[290, 297] -> 
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717], 
             UndirectedEdge[206, 328] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[5, 319] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[235, 393] -> 
             RGBColor[
              0.9143667142857141, 0.9343765714285714, 0.9855006428571429], 
             UndirectedEdge[40, 189] -> 
             RGBColor[
              0.8951604285714285, 0.9183474285714286, 0.9588940714285714], 
             UndirectedEdge[15, 256] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[71, 365] -> 
             RGBColor[0.8047220714285714, 0.84419, 0.7805410000000004], 
             UndirectedEdge[53, 64] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[231, 298] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[81, 382] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[9, 294] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[175, 213] -> 
             RGBColor[
              0.9313790000000001, 0.7572455714285717, 0.2875669285714287], 
             UndirectedEdge[174, 189] -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 
             UndirectedEdge[14, 127] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[86, 95] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[103, 200] -> 
             RGBColor[
              0.7928449999999999, 0.8380041428571428, 0.9489790714285715], 
             UndirectedEdge[24, 112] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[109, 360] -> 
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717], 
             UndirectedEdge[90, 121] -> 
             RGBColor[
              0.9393049285714286, 0.9491972857142857, 0.7071874285714288], 
             UndirectedEdge[75, 202] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[27, 32] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[131, 273] -> 
             RGBColor[0.9173395, 0.872917142857143, 0.6332385], 
             UndirectedEdge[160, 220] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[50, 147] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[13, 339] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[17, 209] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[174, 325] -> 
             RGBColor[
              0.8951604285714285, 0.9183474285714286, 0.9588940714285714], 
             UndirectedEdge[21, 78] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[274, 373] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[97, 305] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[11, 162] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[103, 207] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[210, 249] -> 
             RGBColor[
              0.8938279285714286, 0.5557624285714285, 0.5496570714285715], 
             UndirectedEdge[52, 299] -> 
             RGBColor[0.8958035, 0.8876184285714286, 0.6634765714285715], 
             UndirectedEdge[43, 373] -> 
             RGBColor[0.992503, 0.986373, 0.42537600000000036`], 
             UndirectedEdge[1, 336] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[30, 345] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[247, 363] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[14, 119] -> 
             RGBColor[
              0.9455993571428571, 0.8952721428571428, 0.6297402857142858], 
             UndirectedEdge[74, 104] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[258, 277] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[152, 236] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.9418190000000001, 0.7924621428571431, 0.32812435714285737`], 
             UndirectedEdge[120, 132] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[212, 270] -> 
             RGBColor[
              0.8842780714285714, 0.8465548571428572, 0.6300850714285715], 
             UndirectedEdge[69, 270] -> 
             RGBColor[
              0.8951604285714285, 0.9183474285714286, 0.9588940714285714], 
             UndirectedEdge[16, 270] -> 
             RGBColor[0.7176685714285714, 0.7789537142857142, 0.972777], 
             UndirectedEdge[24, 73] -> 
             RGBColor[
              0.9709799285714285, 0.9466688571428572, 0.6396786428571429], 
             UndirectedEdge[56, 178] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[6, 319] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[231, 235] -> 
             RGBColor[
              0.9143667142857141, 0.9343765714285714, 0.9855006428571429], 
             UndirectedEdge[18, 86] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[30, 63] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[46, 358] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[241, 389] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[286, 332] -> 
             RGBColor[0.992503, 0.986373, 0.42537600000000036`], 
             UndirectedEdge[40, 174] -> 
             RGBColor[
              0.8951604285714285, 0.9183474285714286, 0.9588940714285714], 
             UndirectedEdge[157, 365] -> 
             RGBColor[0.7671809285714286, 0.707607, 0.6082763571428571], 
             UndirectedEdge[235, 336] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             UndirectedEdge[76, 222] -> 
             RGBColor[
              0.9036722857142857, 0.9241691428571428, 0.9209117857142859], 
             UndirectedEdge[115, 392] -> 
             RGBColor[0.535031, 0.4519726428571431, 0.5821868571428572], 
             UndirectedEdge[76, 77] -> 
             RGBColor[
              0.9367337142857142, 0.9505314285714286, 0.9240652142857144], 
             UndirectedEdge[160, 366] -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 
             UndirectedEdge[3, 348] -> 
             RGBColor[
              0.750710357142857, 0.8003408571428572, 0.7762890000000005], 
             UndirectedEdge[299, 306] -> 
             RGBColor[0.8958035, 0.8876184285714286, 0.6634765714285715], 
             UndirectedEdge[56, 121] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[280, 322] -> 
             RGBColor[0.9173395, 0.872917142857143, 0.6332385], 
             UndirectedEdge[81, 271] -> 
             RGBColor[
              0.9563532142857143, 0.8541327142857142, 0.5038997142857143], 
             UndirectedEdge[2, 191] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[146, 377] -> 
             RGBColor[
              0.9531846428571429, 0.8528224285714285, 0.556411142857143], 
             UndirectedEdge[10, 396] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[382, 384] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[147, 391] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[133, 216] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[86, 264] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[6, 56] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[43, 308] -> 
             RGBColor[0.992503, 0.986373, 0.42537600000000036`], 
             UndirectedEdge[201, 364] -> 
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717], 
             UndirectedEdge[109, 365] -> 
             RGBColor[
              0.7934880714285715, 0.807275142857143, 0.6535615714285714], 
             UndirectedEdge[229, 349] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[216, 231] -> 
             RGBColor[
              0.9288649285714285, 0.9139807142857144, 0.6666300000000001], 
             UndirectedEdge[114, 353] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[70, 236] -> 
             RGBColor[
              0.9557558571428572, 0.8514882857142858, 0.3395333571428574], 
             UndirectedEdge[64, 94] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[240, 285] -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 
             UndirectedEdge[56, 90] -> 
             RGBColor[
              0.9367337142857142, 0.9505314285714286, 0.9240652142857144], 
             UndirectedEdge[90, 295] -> 
             RGBColor[
              0.9399022857142857, 0.9518417142857143, 0.8715537857142858], 
             UndirectedEdge[165, 281] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285717], 
             UndirectedEdge[54, 345] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[101, 136] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[6, 314] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[125, 276] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[244, 341] -> 
             RGBColor[
              0.9140786428571428, 0.6518141428571429, 0.5229159285714287], 
             UndirectedEdge[46, 153] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[14, 336] -> 
             RGBColor[
              0.9455993571428571, 0.8952721428571428, 0.6297402857142858], 
             UndirectedEdge[109, 370] -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 
             UndirectedEdge[51, 234] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[144, 228] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[320, 347] -> 
             RGBColor[
              0.9288649285714285, 0.9139807142857144, 0.6666300000000001], 
             UndirectedEdge[31, 106] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[77, 103] -> 
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475], 
             UndirectedEdge[266, 316] -> 
             RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 
             UndirectedEdge[109, 334] -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 
             UndirectedEdge[45, 179] -> 
             RGBColor[0.8555595, 0.7289241428571431, 0.6067823571428572], 
             UndirectedEdge[181, 191] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[125, 148] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[18, 112] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[221, 239] -> 
             RGBColor[
              0.9531846428571429, 0.8528224285714285, 0.556411142857143], 
             UndirectedEdge[57, 76] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[222, 333] -> 
             RGBColor[
              0.8694963571428571, 0.7879502857142857, 0.6181913571428572], 
             UndirectedEdge[125, 214] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[220, 244] -> 
             RGBColor[
              0.8946844285714286, 0.5741998571428573, 0.23208921428571433`], 
             UndirectedEdge[143, 379] -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 
             UndirectedEdge[31, 241] -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 
             UndirectedEdge[81, 374] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[168, 304] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[156, 328] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[46, 363] -> 
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717], 
             UndirectedEdge[51, 269] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[13, 325] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[164, 374] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[49, 199] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[49, 313] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[176, 388] -> 
             RGBColor[
              0.9600975714285714, 0.8748762857142858, 0.3108696428571429], 
             UndirectedEdge[45, 232] -> 
             RGBColor[
              0.9307359285714285, 0.7879745714285716, 0.5829844285714287], 
             UndirectedEdge[176, 250] -> 
             RGBColor[
              0.9600975714285714, 0.8748762857142858, 0.3108696428571429], 
             UndirectedEdge[346, 390] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[331, 335] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[135, 355] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[326, 327] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             UndirectedEdge[80, 304] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[65, 173] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[203, 257] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[275, 325] -> 
             RGBColor[0.819984, 0.859297, 0.982692], UndirectedEdge[240, 337] -> 
             RGBColor[
              0.9446727857142856, 0.8470007142857143, 0.5943934285714286], 
             UndirectedEdge[77, 254] -> 
             RGBColor[
              0.7507299999999999, 0.8053159999999999, 0.9759304285714285], 
             UndirectedEdge[32, 364] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285717], 
             UndirectedEdge[38, 53] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[28, 291] -> 
             RGBColor[
              0.9531846428571429, 0.8528224285714285, 0.556411142857143], 
             UndirectedEdge[174, 269] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[216, 361] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[356, 363] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[151, 383] -> 
             RGBColor[
              0.9705375714285714, 0.9100928571428573, 0.35142707142857166`], 
             UndirectedEdge[61, 130] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[331, 338] -> 
             RGBColor[
              0.9036722857142857, 0.9241691428571428, 0.9209117857142859], 
             UndirectedEdge[239, 246] -> 
             RGBColor[
              0.9308176428571429, 0.8366675714285714, 0.6178465714285715], 
             UndirectedEdge[190, 212] -> 
             RGBColor[
              0.9455993571428571, 0.8952721428571428, 0.6297402857142858], 
             UndirectedEdge[111, 286] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285717], 
             UndirectedEdge[228, 273] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[199, 299] -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 
             UndirectedEdge[50, 391] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[358, 362] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[42, 98] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[39, 251] -> 
             RGBColor[
              0.9023397857142856, 0.5615841428571429, 0.5116747857142858], 
             UndirectedEdge[148, 179] -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714287], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.9293243571428571, 0.7356588571428573, 0.4815664285714286], 
             UndirectedEdge[77, 333] -> 
             RGBColor[
              0.9025577857142857, 0.8143125714285715, 0.6213447857142858], 
             UndirectedEdge[173, 354] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[160, 217] -> 
             RGBColor[
              0.9709799285714285, 0.9466688571428572, 0.6396786428571429], 
             UndirectedEdge[59, 90] -> 
             RGBColor[
              0.9143667142857141, 0.9343765714285714, 0.9855006428571429], 
             UndirectedEdge[237, 380] -> 
             RGBColor[
              0.8861068571428571, 0.9120215714285714, 0.9889988571428572], 
             UndirectedEdge[285, 399] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[51, 392] -> 
             RGBColor[
              0.5865090000000001, 0.6475817857142857, 0.7658605000000004], 
             UndirectedEdge[264, 307] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[78, 208] -> 
             RGBColor[
              0.9025577857142857, 0.8143125714285715, 0.6213447857142858], 
             UndirectedEdge[28, 383] -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 
             UndirectedEdge[255, 268] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[46, 247] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[272, 392] -> 
             RGBColor[0.49945550000000005`, 0.5823455, 0.9580965], 
             UndirectedEdge[316, 359] -> 
             RGBColor[
              0.9455993571428571, 0.8952721428571428, 0.6297402857142858], 
             UndirectedEdge[223, 242] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[158, 390] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[26, 128] -> 
             RGBColor[0.9173395, 0.872917142857143, 0.6332385], 
             UndirectedEdge[136, 335] -> 
             RGBColor[0.992503, 0.986373, 0.42537600000000036`], 
             UndirectedEdge[193, 248] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[281, 386] -> 
             RGBColor[
              0.9166498571428572, 0.6504800000000001, 0.30603814285714304`], 
             UndirectedEdge[225, 337] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[30, 297] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[32, 104] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285717], 
             UndirectedEdge[264, 366] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285716], 
             UndirectedEdge[2, 97] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[258, 377] -> 
             RGBColor[
              0.9531846428571429, 0.8528224285714285, 0.556411142857143], 
             UndirectedEdge[134, 135] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[185, 338] -> 
             RGBColor[
              0.8303903571428572, 0.5869420000000001, 0.5846961428571429], 
             UndirectedEdge[40, 84] -> RGBColor[0.819984, 0.859297, 0.982692],
              UndirectedEdge[217, 242] -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 
             UndirectedEdge[124, 266] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[219, 293] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[37, 170] -> 
             RGBColor[
              0.9392477857142858, 0.793796285714286, 0.545002142857143], 
             UndirectedEdge[205, 293] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[122, 268] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[246, 392] -> 
             RGBColor[
              0.5607767857142857, 0.6310627857142856, 0.9577517142857144], 
             UndirectedEdge[282, 398] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[34, 248] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[263, 264] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[100, 377] -> 
             RGBColor[
              0.9531846428571429, 0.8528224285714285, 0.556411142857143], 
             UndirectedEdge[107, 241] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[11, 95] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[7, 96] -> 
             RGBColor[
              0.9705375714285714, 0.9100928571428573, 0.35142707142857166`], 
             UndirectedEdge[111, 383] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.8813052857142857, 0.9080142857142857, 0.9823472142857144], 
             UndirectedEdge[121, 122] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[156, 221] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[61, 176] -> 
             RGBColor[0.8958035, 0.8876184285714286, 0.6634765714285715], 
             UndirectedEdge[128, 261] -> 
             RGBColor[
              0.9455993571428571, 0.8952721428571428, 0.6297402857142858], 
             UndirectedEdge[69, 381] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[166, 178] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[114, 202] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[40, 134] -> 
             RGBColor[
              0.8951604285714285, 0.9183474285714286, 0.9588940714285714], 
             UndirectedEdge[84, 234] -> 
             RGBColor[
              0.8813052857142857, 0.9080142857142857, 0.9823472142857144], 
             UndirectedEdge[236, 367] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285716], 
             UndirectedEdge[307, 366] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[129, 396] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[67, 208] -> 
             RGBColor[
              0.8799027142857143, 0.5155952857142858, 0.22019550000000004`], 
             UndirectedEdge[203, 309] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[142, 302] -> 
             RGBColor[
              0.9455993571428571, 0.8952721428571428, 0.6297402857142858], 
             UndirectedEdge[93, 248] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[110, 227] -> 
             RGBColor[0.8048095, 0.6892778571428573, 0.6017240714285714], 
             UndirectedEdge[129, 361] -> 
             RGBColor[
              0.9455993571428571, 0.8952721428571428, 0.6297402857142858], 
             UndirectedEdge[236, 332] -> 
             RGBColor[0.992503, 0.986373, 0.42537600000000036`], 
             UndirectedEdge[306, 353] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[257, 280] -> 
             RGBColor[
              0.9367337142857142, 0.9505314285714286, 0.9240652142857144], 
             UndirectedEdge[208, 385] -> 
             RGBColor[
              0.9563532142857143, 0.8541327142857142, 0.5038997142857143], 
             UndirectedEdge[79, 302] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[21, 242] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[94, 103] -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 
             UndirectedEdge[237, 308] -> 
             RGBColor[
              0.9393049285714286, 0.9491972857142857, 0.7071874285714288], 
             UndirectedEdge[1, 235] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[31, 374] -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 
             UndirectedEdge[324, 351] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[62, 396] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[13, 123] -> 
             RGBColor[
              0.9426130000000001, 0.7941604285714288, 0.4145463571428576], 
             UndirectedEdge[112, 337] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[262, 286] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[56, 59] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[61, 118] -> 
             RGBColor[0.9062435, 0.9228350000000001, 0.7040340000000002], 
             UndirectedEdge[14, 235] -> 
             RGBColor[
              0.9455993571428571, 0.8952721428571428, 0.6297402857142858], 
             UndirectedEdge[154, 286] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[159, 215] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[25, 385] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[165, 256] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[292, 384] -> 
             RGBColor[
              0.9198535714285715, 0.7161820000000003, 0.2541754285714286], 
             UndirectedEdge[1, 49] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[93, 125] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[15, 37] -> 
             RGBColor[
              0.9392477857142858, 0.793796285714286, 0.545002142857143], 
             UndirectedEdge[141, 399] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[42, 288] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[26, 218] -> 
             RGBColor[
              0.9393049285714286, 0.9491972857142857, 0.7071874285714288], 
             UndirectedEdge[292, 389] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[87, 361] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[3, 11] -> 
             RGBColor[
              0.750710357142857, 0.8003408571428572, 0.7762890000000005], 
             UndirectedEdge[217, 364] -> 
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717], 
             UndirectedEdge[83, 120] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[251, 380] -> 
             RGBColor[
              0.9367337142857142, 0.9505314285714286, 0.9240652142857144], 
             UndirectedEdge[209, 390] -> 
             RGBColor[
              0.9705375714285714, 0.9100928571428573, 0.35142707142857166`], 
             UndirectedEdge[149, 315] -> 
             RGBColor[
              0.9563532142857143, 0.8541327142857142, 0.5038997142857143], 
             UndirectedEdge[34, 263] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[327, 376] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[113, 316] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[85, 307] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[140, 257] -> 
             RGBColor[
              0.9036722857142857, 0.9241691428571428, 0.9209117857142859], 
             UndirectedEdge[228, 330] -> 
             RGBColor[
              0.9399022857142857, 0.9518417142857143, 0.8715537857142858], 
             UndirectedEdge[22, 96] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[22, 323] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[167, 269] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[85, 214] -> 
             RGBColor[
              0.9393049285714286, 0.9491972857142857, 0.7071874285714288], 
             UndirectedEdge[89, 155] -> 
             RGBColor[
              0.9143667142857141, 0.9343765714285714, 0.9855006428571429], 
             UndirectedEdge[1, 396] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[172, 208] -> 
             RGBColor[
              0.9190087142857143, 0.7166035714285715, 0.2536907142857143], 
             UndirectedEdge[45, 339] -> 
             RGBColor[
              0.9198535714285715, 0.7161820000000003, 0.2541754285714286], 
             UndirectedEdge[250, 363] -> 
             RGBColor[
              0.9600975714285714, 0.8748762857142858, 0.3108696428571429], 
             UndirectedEdge[167, 222] -> 
             RGBColor[0.9062435, 0.9228350000000001, 0.7040340000000003], 
             UndirectedEdge[73, 208] -> 
             RGBColor[
              0.9453158571428572, 0.8162717142857143, 0.29897592857142863`], 
             UndirectedEdge[14, 317] -> 
             RGBColor[
              0.9705375714285714, 0.9100928571428573, 0.35142707142857166`], 
             UndirectedEdge[157, 334] -> 
             RGBColor[
              0.9453158571428572, 0.8162717142857143, 0.29897592857142863`], 
             UndirectedEdge[107, 190] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[12, 209] -> 
             RGBColor[
              0.9557558571428572, 0.8514882857142858, 0.3395333571428574], 
             UndirectedEdge[185, 219] -> 
             RGBColor[
              0.9174438571428571, 0.6521782857142857, 0.39246014285714326`], 
             UndirectedEdge[318, 345] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[36, 383] -> 
             RGBColor[
              0.8842780714285714, 0.8465548571428572, 0.6300850714285715], 
             UndirectedEdge[24, 357] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[344, 354] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[7, 194] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[97, 248] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[14, 129] -> 
             RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 
             UndirectedEdge[160, 307] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[165, 400] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[310, 323] -> 
             RGBColor[
              0.9563532142857143, 0.8541327142857142, 0.5038997142857143], 
             UndirectedEdge[309, 339] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[355, 395] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[32, 240] -> 
             RGBColor[
              0.9446727857142856, 0.8470007142857143, 0.5943934285714286], 
             UndirectedEdge[66, 322] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[28, 267] -> 
             RGBColor[
              0.9308176428571429, 0.8366675714285714, 0.6178465714285715], 
             UndirectedEdge[51, 102] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[244, 321] -> 
             RGBColor[
              0.8799027142857143, 0.5155952857142858, 0.22019550000000004`], 
             UndirectedEdge[140, 309] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[12, 324] -> 
             RGBColor[
              0.9308176428571429, 0.8366675714285714, 0.6178465714285715], 
             UndirectedEdge[130, 287] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[267, 367] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[138, 229] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[97, 193] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[248, 340] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[162, 248] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[127, 317] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[269, 355] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[161, 184] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[340, 360] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[19, 185] -> 
             RGBColor[
              0.9172472142857143, 0.6531244285714286, 0.47040450000000006`], 
             UndirectedEdge[240, 357] -> 
             RGBColor[
              0.9563532142857143, 0.8541327142857142, 0.5038997142857143], 
             UndirectedEdge[75, 132] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[89, 353] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[214, 312] -> 
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475], 
             UndirectedEdge[119, 129] -> 
             RGBColor[
              0.9455993571428571, 0.8952721428571428, 0.6297402857142858], 
             UndirectedEdge[143, 377] -> 
             RGBColor[
              0.9446727857142856, 0.8470007142857143, 0.5943934285714286], 
             UndirectedEdge[5, 122] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[42, 318] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[6, 137] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[113, 149] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[67, 124] -> 
             RGBColor[
              0.9055667857142857, 0.6459924285714287, 0.5608982142857143], 
             UndirectedEdge[141, 337] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[63, 224] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[244, 357] -> 
             RGBColor[0.9172472142857143, 0.6531244285714286, 0.4704045], 
             UndirectedEdge[9, 192] -> 
             RGBColor[
              0.8951604285714285, 0.9183474285714286, 0.9588940714285714], 
             UndirectedEdge[46, 369] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[350, 392] -> 
             RGBColor[0.585715, 0.6458835, 0.6794385000000003], 
             UndirectedEdge[275, 339] -> 
             RGBColor[
              0.8842780714285714, 0.8465548571428572, 0.6300850714285715], 
             UndirectedEdge[119, 127] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[152, 398] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[105, 229] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[181, 365] -> 
             RGBColor[
              0.8013568571428571, 0.8438258571428572, 0.9109967857142858], 
             UndirectedEdge[24, 285] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[167, 189] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285716], 
             UndirectedEdge[157, 191] -> 
             RGBColor[
              0.9563532142857143, 0.8541327142857142, 0.5038997142857143], 
             UndirectedEdge[78, 194] -> 
             RGBColor[
              0.9399022857142857, 0.9518417142857143, 0.8715537857142858], 
             UndirectedEdge[107, 268] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[5, 274] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[12, 118] -> 
             RGBColor[
              0.9557558571428572, 0.8514882857142858, 0.3395333571428574], 
             UndirectedEdge[20, 291] -> 
             RGBColor[
              0.5831437857142856, 0.6472176428571428, 0.8963162857142859], 
             UndirectedEdge[6, 379] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[97, 181] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[39, 320] -> 
             RGBColor[
              0.8517129285714286, 0.5230742857142857, 0.5766084285714286], 
             UndirectedEdge[202, 218] -> 
             RGBColor[0.992503, 0.986373, 0.42537600000000036`], 
             UndirectedEdge[61, 344] -> 
             RGBColor[
              0.8842780714285714, 0.8465548571428572, 0.6300850714285715], 
             UndirectedEdge[181, 214] -> 
             RGBColor[
              0.9367337142857142, 0.9505314285714286, 0.9240652142857144], 
             UndirectedEdge[274, 324] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[62, 231] -> 
             RGBColor[
              0.9399022857142857, 0.9518417142857143, 0.8715537857142858], 
             UndirectedEdge[117, 289] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[14, 396] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[79, 175] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[246, 395] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             UndirectedEdge[87, 396] -> 
             RGBColor[
              0.9392477857142858, 0.793796285714286, 0.545002142857143], 
             UndirectedEdge[341, 366] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[40, 226] -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714287], 
             UndirectedEdge[67, 316] -> 
             RGBColor[
              0.8946844285714286, 0.5741998571428573, 0.23208921428571433`], 
             UndirectedEdge[303, 376] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[208, 357] -> 
             RGBColor[
              0.9563532142857143, 0.8541327142857142, 0.5038997142857143], 
             UndirectedEdge[54, 66] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[3, 160] -> 
             RGBColor[
              0.7388332857142856, 0.7941549999999999, 0.9447270714285715], 
             UndirectedEdge[230, 328] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[282, 383] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[106, 150] -> 
             RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 
             UndirectedEdge[1, 298] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[66, 131] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[53, 126] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[182, 281] -> 
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717], 
             UndirectedEdge[74, 263] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[24, 243] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[177, 252] -> 
             RGBColor[
              0.9288649285714285, 0.9139807142857144, 0.6666300000000001], 
             UndirectedEdge[10, 216] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[280, 339] -> 
             RGBColor[0.9173395, 0.872917142857143, 0.6332385], 
             UndirectedEdge[152, 154] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[36, 304] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[128, 299] -> 
             RGBColor[
              0.9600975714285714, 0.8748762857142858, 0.3108696428571429], 
             UndirectedEdge[95, 162] -> 
             RGBColor[
              0.9367337142857142, 0.9505314285714286, 0.9240652142857144], 
             UndirectedEdge[215, 329] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[208, 387] -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 
             UndirectedEdge[178, 197] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[53, 303] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[59, 121] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[134, 269] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[44, 362] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[284, 338] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[12, 346] -> 
             RGBColor[
              0.9565498571428572, 0.8531865714285715, 0.42595535714285754`], 
             UndirectedEdge[113, 387] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[55, 400] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[25, 201] -> 
             RGBColor[
              0.9709799285714285, 0.9466688571428572, 0.6396786428571429], 
             UndirectedEdge[123, 309] -> 
             RGBColor[
              0.9426130000000001, 0.7941604285714288, 0.4145463571428576], 
             UndirectedEdge[35, 162] -> 
             RGBColor[
              0.9392477857142858, 0.793796285714286, 0.545002142857143], 
             UndirectedEdge[73, 172] -> 
             RGBColor[
              0.9453158571428572, 0.8162717142857143, 0.29897592857142863`], 
             UndirectedEdge[137, 282] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[37, 114] -> 
             RGBColor[
              0.9426130000000001, 0.7941604285714288, 0.4145463571428576], 
             UndirectedEdge[214, 248] -> 
             RGBColor[
              0.9143667142857141, 0.9343765714285714, 0.9855006428571429], 
             UndirectedEdge[161, 363] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[51, 84] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[56, 278] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[4, 140] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[221, 351] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[54, 204] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[10, 298] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[134, 226] -> 
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475], 
             UndirectedEdge[35, 98] -> 
             RGBColor[
              0.9307359285714285, 0.7879745714285716, 0.5829844285714287], 
             UndirectedEdge[70, 180] -> 
             RGBColor[
              0.9308176428571429, 0.8366675714285714, 0.6178465714285715], 
             UndirectedEdge[165, 328] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[162, 214] -> 
             RGBColor[
              0.9367337142857142, 0.9505314285714286, 0.9240652142857144], 
             UndirectedEdge[211, 370] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[55, 245] -> 
             RGBColor[
              0.8951604285714285, 0.9183474285714286, 0.9588940714285714], 
             UndirectedEdge[247, 315] -> 
             RGBColor[
              0.9563532142857143, 0.8541327142857142, 0.5038997142857143], 
             UndirectedEdge[16, 268] -> 
             RGBColor[
              0.7928449999999999, 0.8380041428571428, 0.9489790714285715], 
             UndirectedEdge[154, 291] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[296, 373] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[101, 394] -> 
             RGBColor[
              0.9367337142857142, 0.9505314285714286, 0.9240652142857144], 
             UndirectedEdge[173, 388] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[84, 102] -> 
             RGBColor[
              0.8842780714285714, 0.8465548571428572, 0.6300850714285715], 
             UndirectedEdge[216, 298] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[209, 310] -> 
             RGBColor[
              0.9557558571428572, 0.8514882857142858, 0.3395333571428574], 
             UndirectedEdge[34, 93] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[112, 285] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[131, 309] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[116, 265] -> 
             RGBColor[
              0.9531846428571429, 0.8528224285714285, 0.556411142857143], 
             UndirectedEdge[49, 129] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[238, 325] -> 
             RGBColor[0.5746915714285714, 0.6595138571428572, 0.962451], 
             UndirectedEdge[112, 399] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[186, 322] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[180, 332] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[60, 331] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[14, 126] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[275, 288] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[276, 290] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[18, 232] -> 
             RGBColor[
              0.9709799285714285, 0.9466688571428572, 0.639678642857143], 
             UndirectedEdge[4, 325] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[1, 62] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[20, 304] -> 
             RGBColor[
              0.5863123571428572, 0.6485279285714285, 0.8438048571428571], 
             UndirectedEdge[255, 328] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[3, 74] -> 
             RGBColor[
              0.750710357142857, 0.8003408571428572, 0.7762890000000005], 
             UndirectedEdge[18, 279] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[163, 226] -> 
             RGBColor[
              0.9367337142857142, 0.9505314285714286, 0.9240652142857144], 
             UndirectedEdge[145, 254] -> 
             RGBColor[0.7671809285714286, 0.707607, 0.6082763571428571], 
             UndirectedEdge[23, 348] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[119, 396] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[73, 141] -> 
             RGBColor[
              0.9600975714285714, 0.8748762857142858, 0.3108696428571429], 
             UndirectedEdge[29, 396] -> 
             RGBColor[
              0.9261557857142857, 0.7343485714285716, 0.5340778571428573], 
             UndirectedEdge[160, 312] -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 
             UndirectedEdge[210, 397] -> 
             RGBColor[0.8186515000000001, 0.496712, 0.573455], 
             UndirectedEdge[11, 86] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[113, 315] -> 
             RGBColor[
              0.9565498571428572, 0.8531865714285715, 0.42595535714285754`], 
             UndirectedEdge[120, 160] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[5, 308] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[37, 261] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[22, 241] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[55, 165] -> 
             RGBColor[
              0.8951604285714285, 0.9183474285714286, 0.9588940714285714], 
             UndirectedEdge[251, 283] -> 
             RGBColor[
              0.9036722857142857, 0.9241691428571428, 0.9209117857142859], 
             UndirectedEdge[334, 365] -> 
             RGBColor[
              0.7934880714285715, 0.807275142857143, 0.6535615714285714], 
             UndirectedEdge[44, 358] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[225, 367] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[23, 321] -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 
             UndirectedEdge[234, 269] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[21, 208] -> 
             RGBColor[
              0.9565498571428572, 0.8531865714285715, 0.42595535714285754`], 
             UndirectedEdge[208, 240] -> 
             RGBColor[
              0.9190087142857143, 0.7166035714285715, 0.2536907142857143], 
             UndirectedEdge[15, 313] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[63, 204] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[241, 310] -> 
             RGBColor[
              0.9446727857142856, 0.8470007142857143, 0.5943934285714286], 
             UndirectedEdge[182, 256] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[373, 380] -> 
             RGBColor[
              0.9393049285714286, 0.9491972857142857, 0.7071874285714288], 
             UndirectedEdge[185, 210] -> 
             RGBColor[
              0.8290578571428572, 0.22435700000000006`, 0.17545914285714287`],
              UndirectedEdge[96, 223] -> 
             RGBColor[
              0.9455993571428571, 0.8952721428571428, 0.6297402857142858], 
             UndirectedEdge[103, 222] -> 
             RGBColor[
              0.8951604285714285, 0.9183474285714286, 0.9588940714285714], 
             UndirectedEdge[146, 375] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[42, 276] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[46, 372] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[95, 285] -> 
             RGBColor[0.9173395, 0.872917142857143, 0.6332385], 
             UndirectedEdge[14, 326] -> 
             RGBColor[
              0.9455993571428571, 0.8952721428571428, 0.6297402857142858], 
             UndirectedEdge[22, 310] -> 
             RGBColor[
              0.9563532142857143, 0.8541327142857142, 0.5038997142857143], 
             UndirectedEdge[23, 229] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[23, 160] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[165, 311] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285717], 
             UndirectedEdge[179, 288] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[51, 167] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[310, 346] -> 
             RGBColor[
              0.9565498571428572, 0.8531865714285715, 0.42595535714285754`], 
             UndirectedEdge[79, 379] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[78, 264] -> 
             RGBColor[
              0.9393049285714286, 0.9491972857142857, 0.7071874285714288], 
             UndirectedEdge[309, 325] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[149, 358] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[6, 79] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[134, 234] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[96, 209] -> 
             RGBColor[
              0.9705375714285714, 0.9100928571428573, 0.35142707142857166`], 
             UndirectedEdge[216, 393] -> 
             RGBColor[
              0.9288649285714285, 0.9139807142857144, 0.6666300000000001], 
             UndirectedEdge[164, 388] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[155, 261] -> 
             RGBColor[
              0.9143667142857141, 0.9343765714285714, 0.9855006428571429], 
             UndirectedEdge[125, 288] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[287, 384] -> 
             RGBColor[
              0.9392477857142858, 0.793796285714286, 0.545002142857143], 
             UndirectedEdge[69, 320] -> 
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475], 
             UndirectedEdge[123, 339] -> 
             RGBColor[
              0.9198535714285715, 0.7161820000000003, 0.2541754285714286], 
             UndirectedEdge[132, 202] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[67, 249] -> 
             RGBColor[
              0.9055667857142857, 0.6459924285714287, 0.5608982142857143], 
             UndirectedEdge[374, 384] -> 
             RGBColor[
              0.9307359285714285, 0.7879745714285716, 0.5829844285714286], 
             UndirectedEdge[99, 252] -> 
             RGBColor[
              0.9393049285714286, 0.9491972857142857, 0.7071874285714288], 
             UndirectedEdge[44, 65] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[88, 370] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[13, 275] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[183, 269] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[122, 178] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[199, 216] -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 
             UndirectedEdge[107, 295] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[89, 171] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[18, 91] -> 
             RGBColor[0.8958035, 0.8876184285714286, 0.6634765714285715], 
             UndirectedEdge[194, 357] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[147, 388] -> 
             RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 
             UndirectedEdge[96, 323] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[168, 265] -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 
             UndirectedEdge[44, 372] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[180, 286] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[18, 45] -> 
             RGBColor[
              0.9313790000000001, 0.7572455714285717, 0.2875669285714287], 
             UndirectedEdge[83, 217] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[137, 314] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[205, 338] -> 
             RGBColor[0.8958035, 0.8876184285714286, 0.6634765714285715], 
             UndirectedEdge[210, 293] -> 
             RGBColor[
              0.9023397857142856, 0.5615841428571429, 0.5116747857142858], 
             UndirectedEdge[295, 324] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[270, 346] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[26, 349] -> 
             RGBColor[
              0.8861068571428571, 0.9120215714285714, 0.9889988571428572], 
             UndirectedEdge[27, 208] -> 
             RGBColor[
              0.9531846428571429, 0.8528224285714285, 0.556411142857143], 
             UndirectedEdge[139, 193] -> 
             RGBColor[
              0.6202349285714286, 0.6862027857142857, 0.8984285714285716], 
             UndirectedEdge[5, 296] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[42, 125] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[12, 106] -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 
             UndirectedEdge[242, 357] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[148, 279] -> 
             RGBColor[
              0.9399022857142857, 0.9518417142857143, 0.8715537857142858], 
             UndirectedEdge[292, 374] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[195, 369] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[50, 371] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[29, 127] -> 
             RGBColor[
              0.9293243571428571, 0.7356588571428573, 0.4815664285714286], 
             UndirectedEdge[87, 127] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.4924907142857144], 
             UndirectedEdge[264, 357] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[171, 306] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[114, 170] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[57, 222] -> 
             RGBColor[
              0.8813052857142857, 0.9080142857142857, 0.9823472142857144], 
             UndirectedEdge[38, 102] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[82, 331] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[90, 324] -> 
             RGBColor[
              0.9143667142857141, 0.9343765714285714, 0.9855006428571429], 
             UndirectedEdge[160, 341] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[15, 311] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[271, 292] -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 
             UndirectedEdge[41, 156] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[129, 317] -> 
             RGBColor[
              0.9705375714285714, 0.9100928571428573, 0.35142707142857166`], 
             UndirectedEdge[164, 354] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[78, 230] -> 
             RGBColor[
              0.9288649285714285, 0.9139807142857144, 0.6666300000000001], 
             UndirectedEdge[315, 363] -> 
             RGBColor[
              0.9453158571428572, 0.8162717142857143, 0.29897592857142863`], 
             UndirectedEdge[5, 121] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[43, 380] -> 
             RGBColor[
              0.9393049285714286, 0.9491972857142857, 0.7071874285714288], 
             UndirectedEdge[135, 234] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             UndirectedEdge[344, 356] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[186, 228] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[298, 396] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[86, 93] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[249, 266] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[156, 364] -> 
             RGBColor[
              0.9705375714285714, 0.9100928571428573, 0.35142707142857166`], 
             UndirectedEdge[10, 311] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[27, 73] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[56, 213] -> 
             RGBColor[
              0.9392477857142858, 0.793796285714286, 0.545002142857143], 
             UndirectedEdge[27, 243] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[109, 157] -> 
             RGBColor[
              0.9453158571428572, 0.8162717142857143, 0.29897592857142863`], 
             UndirectedEdge[12, 241] -> 
             RGBColor[
              0.9446727857142856, 0.8470007142857143, 0.5943934285714286], 
             UndirectedEdge[192, 382] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[140, 280] -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714287], 
             UndirectedEdge[199, 361] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[16, 351] -> 
             RGBColor[
              0.7928449999999999, 0.8380041428571428, 0.9489790714285715], 
             UndirectedEdge[140, 322] -> 
             RGBColor[
              0.8842780714285714, 0.8465548571428572, 0.6300850714285715], 
             UndirectedEdge[57, 238] -> 
             RGBColor[
              0.6360128571428572, 0.7082311428571428, 0.9621062142857143], 
             UndirectedEdge[49, 127] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[165, 182] -> 
             RGBColor[
              0.9709799285714285, 0.9466688571428572, 0.6396786428571429], 
             UndirectedEdge[253, 343] -> 
             RGBColor[
              0.9288649285714285, 0.9139807142857144, 0.6666300000000001], 
             UndirectedEdge[104, 240] -> 
             RGBColor[
              0.9557558571428572, 0.8514882857142858, 0.3395333571428574], 
             UndirectedEdge[312, 348] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[242, 244] -> 
             RGBColor[
              0.9062098571428572, 0.6152634285714287, 0.26548071428571435`], 
             UndirectedEdge[41, 165] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[54, 297] -> 
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717], 
             UndirectedEdge[77, 145] -> 
             RGBColor[
              0.9025577857142857, 0.8143125714285715, 0.6213447857142858], 
             UndirectedEdge[69, 150] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[106, 241] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[139, 276] -> 
             RGBColor[0.6234035, 0.6875130714285714, 0.8459171428571429], 
             UndirectedEdge[313, 393] -> 
             RGBColor[
              0.9288649285714285, 0.9139807142857144, 0.6666300000000001], 
             UndirectedEdge[209, 323] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[8, 213] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[160, 244] -> 
             RGBColor[
              0.9055667857142857, 0.6459924285714286, 0.5608982142857144], 
             UndirectedEdge[180, 284] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[24, 242] -> 
             RGBColor[
              0.9709799285714285, 0.9466688571428572, 0.6396786428571429], 
             UndirectedEdge[81, 192] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[124, 249] -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 
             UndirectedEdge[195, 253] -> 
             RGBColor[
              0.9367337142857142, 0.9505314285714286, 0.9240652142857144], 
             UndirectedEdge[31, 81] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[172, 399] -> 
             RGBColor[
              0.9563532142857143, 0.8541327142857142, 0.5038997142857143], 
             UndirectedEdge[124, 315] -> 
             RGBColor[
              0.9446727857142856, 0.8470007142857143, 0.5943934285714286], 
             UndirectedEdge[181, 370] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[244, 348] -> 
             RGBColor[
              0.9174438571428571, 0.6521782857142857, 0.39246014285714326`], 
             UndirectedEdge[284, 367] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[148, 232] -> 
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475], 
             UndirectedEdge[34, 211] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[355, 392] -> 
             RGBColor[
              0.5863123571428571, 0.6485279285714286, 0.8438048571428571], 
             UndirectedEdge[262, 338] -> 
             RGBColor[
              0.8813052857142857, 0.9080142857142857, 0.9823472142857144], 
             UndirectedEdge[87, 119] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[180, 367] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[69, 380] -> 
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475], 
             UndirectedEdge[124, 338] -> 
             RGBColor[
              0.8951604285714285, 0.9183474285714286, 0.9588940714285714], 
             UndirectedEdge[249, 293] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[212, 373] -> 
             RGBColor[
              0.9705375714285714, 0.9100928571428573, 0.35142707142857166`], 
             UndirectedEdge[287, 292] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[12, 323] -> 
             RGBColor[
              0.9563532142857143, 0.8541327142857142, 0.5038997142857143], 
             UndirectedEdge[120, 307] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[99, 398] -> 
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717], 
             UndirectedEdge[134, 350] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285717], 
             UndirectedEdge[45, 280] -> 
             RGBColor[
              0.8886209285714286, 0.7552864285714288, 0.6099357857142857], 
             UndirectedEdge[188, 330] -> 
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475], 
             UndirectedEdge[236, 284] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[374, 389] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[278, 319] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[78, 242] -> 
             RGBColor[
              0.9288649285714285, 0.9139807142857144, 0.6666300000000001], 
             UndirectedEdge[84, 189] -> 
             RGBColor[
              0.8951604285714285, 0.9183474285714286, 0.9588940714285714], 
             UndirectedEdge[223, 385] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[175, 278] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[151, 168] -> 
             RGBColor[
              0.9705375714285714, 0.9100928571428573, 0.35142707142857166`], 
             UndirectedEdge[322, 339] -> 
             RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 
             UndirectedEdge[177, 367] -> 
             RGBColor[
              0.9709799285714285, 0.9466688571428572, 0.639678642857143], 
             UndirectedEdge[294, 320] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[179, 279] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[18, 285] -> 
             RGBColor[
              0.9600975714285714, 0.8748762857142858, 0.3108696428571429], 
             UndirectedEdge[121, 296] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[212, 351] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[29, 87] -> 
             RGBColor[
              0.8780430000000001, 0.5391035714285717, 0.21994842857142863`], 
             UndirectedEdge[99, 141] -> 
             RGBColor[
              0.9705375714285714, 0.9100928571428573, 0.35142707142857166`], 
             UndirectedEdge[121, 274] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[138, 218] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285717], 
             UndirectedEdge[61, 388] -> 
             RGBColor[
              0.8842780714285714, 0.8465548571428572, 0.6300850714285715], 
             UndirectedEdge[283, 347] -> 
             RGBColor[0.8958035, 0.8876184285714286, 0.6634765714285715], 
             UndirectedEdge[253, 315] -> 
             RGBColor[
              0.9025577857142857, 0.8143125714285715, 0.6213447857142858], 
             UndirectedEdge[321, 366] -> 
             RGBColor[
              0.9446727857142856, 0.8470007142857143, 0.5943934285714286], 
             UndirectedEdge[164, 391] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[74, 91] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[91, 285] -> 
             RGBColor[
              0.8842780714285714, 0.8465548571428572, 0.6300850714285715], 
             UndirectedEdge[51, 183] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[30, 54] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[68, 250] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[32, 230] -> 
             RGBColor[
              0.9709799285714285, 0.9466688571428572, 0.6396786428571429], 
             UndirectedEdge[275, 318] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[131, 186] -> 
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475], 
             UndirectedEdge[192, 292] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[144, 200] -> 
             RGBColor[
              0.8039280714285715, 0.8424917142857142, 0.6941190000000002], 
             UndirectedEdge[139, 318] -> 
             RGBColor[0.6234035, 0.6875130714285714, 0.8459171428571429], 
             UndirectedEdge[93, 148] -> 
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475], 
             UndirectedEdge[92, 311] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[334, 370] -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 
             UndirectedEdge[62, 129] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[97, 191] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[120, 366] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[91, 288] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[21, 32] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[121, 178] -> 
             RGBColor[
              0.9705375714285714, 0.9100928571428573, 0.35142707142857166`], 
             UndirectedEdge[294, 381] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[46, 149] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[66, 232] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[114, 261] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[189, 395] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[54, 290] -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 
             UndirectedEdge[4, 309] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[195, 315] -> 
             RGBColor[
              0.9531846428571429, 0.8528224285714285, 0.556411142857143], 
             UndirectedEdge[181, 305] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[153, 372] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[175, 227] -> 
             RGBColor[
              0.8450534999999999, 0.847972142857143, 0.6584182857142857], 
             UndirectedEdge[271, 287] -> 
             RGBColor[
              0.9531846428571429, 0.8528224285714285, 0.556411142857143], 
             UndirectedEdge[232, 297] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285717], 
             UndirectedEdge[21, 25] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[123, 297] -> 
             RGBColor[
              0.9418190000000001, 0.7924621428571431, 0.32812435714285737`], 
             UndirectedEdge[6, 178] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[90, 319] -> 
             RGBColor[
              0.9143667142857141, 0.9343765714285714, 0.9855006428571429], 
             UndirectedEdge[258, 302] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[253, 397] -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714287], 
             UndirectedEdge[169, 177] -> 
             RGBColor[
              0.9182870000000001, 0.6977978571428574, 0.2766426428571429], 
             UndirectedEdge[198, 332] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[45, 123] -> 
             RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             UndirectedEdge[223, 245] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[380, 381] -> 
             RGBColor[
              0.9399022857142857, 0.9518417142857143, 0.8715537857142858], 
             UndirectedEdge[277, 378] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[119, 326] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             UndirectedEdge[89, 133] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[22, 346] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[73, 243] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[26, 353] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[21, 230] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[107, 390] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[223, 364] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[2, 211] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[128, 353] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[259, 331] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[2, 334] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[72, 191] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[247, 301] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[247, 397] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[125, 263] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[123, 325] -> 
             RGBColor[0.8555595, 0.7289241428571431, 0.6067823571428572], 
             UndirectedEdge[129, 393] -> 
             RGBColor[0.9173395, 0.872917142857143, 0.6332385], 
             UndirectedEdge[19, 205] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[277, 352] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[139, 224] -> 
             RGBColor[
              0.6202349285714286, 0.6862027857142857, 0.8984285714285716], 
             UndirectedEdge[65, 250] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[58, 117] -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 
             UndirectedEdge[134, 272] -> 
             RGBColor[
              0.8951604285714285, 0.9183474285714286, 0.9588940714285714], 
             UndirectedEdge[74, 95] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[156, 245] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[221, 324] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[227, 375] -> 
             RGBColor[0.8562875, 0.884887, 0.7853977142857147], 
             UndirectedEdge[132, 348] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[137, 319] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             UndirectedEdge[128, 170] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[120, 220] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[292, 371] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[143, 378] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[59, 373] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[2, 340] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[131, 322] -> 
             RGBColor[0.9173395, 0.872917142857143, 0.6332385], 
             UndirectedEdge[62, 317] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[243, 337] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[21, 217] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[24, 74] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[1, 127] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[226, 355] -> 
             RGBColor[
              0.9399022857142857, 0.9518417142857143, 0.8715537857142858], 
             UndirectedEdge[97, 370] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[148, 257] -> 
             RGBColor[
              0.9367337142857142, 0.9505314285714286, 0.9240652142857144], 
             UndirectedEdge[48, 344] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[74, 148] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[266, 293] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[84, 226] -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714287], 
             UndirectedEdge[354, 371] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[57, 188] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[134, 355] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[151, 378] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[167, 238] -> 
             RGBColor[
              0.6609510714285715, 0.7230518571428571, 0.6837930000000001], 
             UndirectedEdge[41, 311] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[212, 295] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[179, 285] -> 
             RGBColor[
              0.8842780714285714, 0.8465548571428572, 0.6300850714285715], 
             UndirectedEdge[85, 348] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[108, 152] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[86, 148] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[113, 293] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[229, 260] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[6, 278] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[142, 378] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[289, 303] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[5, 213] -> 
             RGBColor[
              0.9392477857142858, 0.793796285714286, 0.545002142857143], 
             UndirectedEdge[104, 243] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[121, 373] -> 
             RGBColor[0.992503, 0.986373, 0.42537600000000036`], 
             UndirectedEdge[120, 202] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[270, 351] -> 
             RGBColor[
              0.8951604285714285, 0.9183474285714286, 0.9588940714285714], 
             UndirectedEdge[91, 125] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[280, 297] -> 
             RGBColor[
              0.9393049285714286, 0.9491972857142857, 0.7071874285714288], 
             UndirectedEdge[33, 281] -> 
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717], 
             UndirectedEdge[16, 241] -> 
             RGBColor[
              0.7928449999999999, 0.8380041428571428, 0.9489790714285715], 
             UndirectedEdge[89, 342] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[157, 370] -> 
             RGBColor[
              0.9453158571428572, 0.8162717142857143, 0.29897592857142863`], 
             UndirectedEdge[90, 122] -> 
             RGBColor[
              0.9367337142857142, 0.9505314285714286, 0.9240652142857144], 
             UndirectedEdge[135, 156] -> 
             RGBColor[
              0.9455993571428571, 0.8952721428571428, 0.6297402857142858], 
             UndirectedEdge[12, 22] -> 
             RGBColor[
              0.9563532142857143, 0.8541327142857142, 0.5038997142857143], 
             UndirectedEdge[271, 384] -> 
             RGBColor[
              0.9050718571428572, 0.6575774285714289, 0.24228171428571435`], 
             UndirectedEdge[158, 324] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[301, 397] -> 
             RGBColor[0.819984, 0.859297, 0.982692], UndirectedEdge[95, 233] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[123, 203] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.4924907142857144], 
             UndirectedEdge[103, 145] -> 
             RGBColor[
              0.9446727857142856, 0.8470007142857143, 0.5943934285714286], 
             UndirectedEdge[20, 80] -> 
             RGBColor[
              0.5746319285714285, 0.6413959285714286, 0.9342985714285714], 
             UndirectedEdge[73, 337] -> 
             RGBColor[
              0.9709799285714285, 0.9466688571428572, 0.639678642857143], 
             UndirectedEdge[122, 166] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[62, 216] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[128, 342] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[280, 309] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[104, 141] -> 
             RGBColor[
              0.9705375714285714, 0.9100928571428573, 0.35142707142857166`], 
             UndirectedEdge[148, 276] -> 
             RGBColor[
              0.9399022857142857, 0.9518417142857143, 0.8715537857142858], 
             UndirectedEdge[359, 394] -> 
             RGBColor[
              0.9143667142857141, 0.9343765714285714, 0.9855006428571429], 
             UndirectedEdge[8, 43] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[56, 352] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[70, 152] -> 
             RGBColor[
              0.9565498571428572, 0.8531865714285715, 0.42595535714285754`], 
             UndirectedEdge[359, 397] -> 
             RGBColor[
              0.8813052857142857, 0.9080142857142857, 0.9823472142857144], 
             UndirectedEdge[118, 241] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285716], 
             UndirectedEdge[43, 227] -> 
             RGBColor[
              0.8554934999999999, 0.8831887142857142, 0.6989757142857145], 
             UndirectedEdge[234, 246] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             UndirectedEdge[196, 317] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[46, 184] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[136, 331] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[106, 320] -> 
             RGBColor[0.9173395, 0.872917142857143, 0.6332385], 
             UndirectedEdge[68, 161] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[45, 297] -> 
             RGBColor[
              0.9418190000000001, 0.7924621428571431, 0.32812435714285737`], 
             UndirectedEdge[140, 203] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[225, 243] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[107, 373] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[187, 321] -> 
             RGBColor[
              0.9565498571428572, 0.8531865714285715, 0.42595535714285754`], 
             UndirectedEdge[297, 322] -> 
             RGBColor[
              0.9705375714285714, 0.9100928571428573, 0.35142707142857166`], 
             UndirectedEdge[106, 374] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[154, 383] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[111, 151] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285717], 
             UndirectedEdge[79, 227] -> 
             RGBColor[
              0.8529222857142856, 0.8845228571428572, 0.9158535000000001], 
             UndirectedEdge[93, 290] -> 
             RGBColor[
              0.9709799285714285, 0.9466688571428572, 0.6396786428571429], 
             UndirectedEdge[150, 283] -> 
             RGBColor[
              0.8842780714285714, 0.8465548571428572, 0.6300850714285715], 
             UndirectedEdge[46, 195] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[73, 177] -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 
             UndirectedEdge[102, 189] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[3, 95] -> 
             RGBColor[
              0.6967182857142856, 0.7614668571428571, 0.9716784285714286], 
             UndirectedEdge[39, 294] -> 
             RGBColor[0.905705, 0.5619482857142857, 0.3812190000000004], 
             UndirectedEdge[5, 227] -> 
             RGBColor[
              0.8529222857142856, 0.8845228571428572, 0.9158535000000001], 
             UndirectedEdge[166, 169] -> 
             RGBColor[0.929521, 0.7347127142857144, 0.4036220714285718], 
             UndirectedEdge[27, 337] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[84, 174] -> 
             RGBColor[
              0.8951604285714285, 0.9183474285714286, 0.9588940714285714], 
             UndirectedEdge[12, 16] -> 
             RGBColor[0.7671809285714286, 0.707607, 0.6082763571428571], 
             UndirectedEdge[138, 349] -> 
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475], 
             UndirectedEdge[26, 159] -> 
             RGBColor[
              0.9393049285714286, 0.9491972857142857, 0.7071874285714288], 
             UndirectedEdge[81, 287] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[311, 361] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[231, 393] -> 
             RGBColor[
              0.8861068571428571, 0.9120215714285714, 0.9889988571428572], 
             UndirectedEdge[201, 223] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[180, 267] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             UndirectedEdge[217, 264] -> 
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717], 
             UndirectedEdge[163, 174] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[203, 280] -> 
             RGBColor[
              0.9399022857142857, 0.9518417142857143, 0.8715537857142858], 
             UndirectedEdge[40, 163] -> 
             RGBColor[
              0.9036722857142857, 0.9241691428571428, 0.9209117857142859], 
             UndirectedEdge[14, 62] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[49, 133] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[276, 288] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[312, 366] -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 
             UndirectedEdge[23, 120] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[73, 399] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[269, 272] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[20, 151] -> 
             RGBColor[0.585715, 0.6458835, 0.6794385000000002], 
             UndirectedEdge[239, 355] -> 
             RGBColor[
              0.9563532142857143, 0.8541327142857142, 0.5038997142857143], 
             UndirectedEdge[274, 319] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[6, 352] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[133, 342] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[290, 318] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[87, 298] -> 
             RGBColor[
              0.9426130000000001, 0.7941604285714288, 0.4145463571428576], 
             UndirectedEdge[86, 263] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[109, 191] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[84, 238] -> 
             RGBColor[0.5746915714285714, 0.6595138571428572, 0.962451], 
             UndirectedEdge[21, 244] -> 
             RGBColor[
              0.9174438571428571, 0.6521782857142858, 0.39246014285714326`], 
             UndirectedEdge[137, 175] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[363, 369] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[98, 290] -> 
             RGBColor[
              0.9709799285714285, 0.9466688571428572, 0.6396786428571429], 
             UndirectedEdge[175, 352] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[121, 319] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[249, 387] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[310, 389] -> 
             RGBColor[
              0.9565498571428572, 0.8531865714285715, 0.42595535714285754`], 
             UndirectedEdge[228, 238] -> 
             RGBColor[
              0.6615484285714286, 0.7256962857142857, 0.8481593571428572], 
             UndirectedEdge[268, 324] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[144, 368] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[137, 278] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[127, 298] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[131, 228] -> 
             RGBColor[
              0.9399022857142857, 0.9518417142857143, 0.8715537857142858], 
             UndirectedEdge[278, 314] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[182, 311] -> 
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717], 
             UndirectedEdge[77, 94] -> 
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475], 
             UndirectedEdge[144, 333] -> 
             RGBColor[
              0.9557558571428572, 0.8514882857142858, 0.3395333571428574], 
             UndirectedEdge[166, 197] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[106, 384] -> 
             RGBColor[
              0.9198535714285715, 0.7161820000000003, 0.2541754285714286], 
             UndirectedEdge[28, 265] -> 
             RGBColor[
              0.9190087142857143, 0.7166035714285715, 0.2536907142857143], 
             UndirectedEdge[113, 266] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[164, 292] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[98, 248] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[91, 95] -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714287], 
             UndirectedEdge[155, 342] -> 
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475], 
             UndirectedEdge[47, 209] -> 
             RGBColor[
              0.9418190000000001, 0.7924621428571431, 0.32812435714285737`], 
             UndirectedEdge[2, 360] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[75, 341] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[12, 390] -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 
             UndirectedEdge[19, 198] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[8, 56] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[70, 154] -> 
             RGBColor[
              0.9531846428571429, 0.8528224285714285, 0.556411142857143], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.9182870000000001, 0.6977978571428574, 0.2766426428571429], 
             UndirectedEdge[177, 243] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[109, 340] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[28, 36] -> 
             RGBColor[
              0.8694963571428571, 0.7879502857142857, 0.6181913571428572], 
             UndirectedEdge[203, 339] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[247, 369] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[223, 230] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[22, 173] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[69, 283] -> 
             RGBColor[
              0.8951604285714285, 0.9183474285714286, 0.9588940714285714], 
             UndirectedEdge[59, 274] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[31, 164] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[116, 154] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[10, 170] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[301, 394] -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714287], 
             UndirectedEdge[90, 351] -> 
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475], 
             UndirectedEdge[4, 203] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[274, 351] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[238, 269] -> 
             RGBColor[
              0.6615484285714286, 0.7256962857142857, 0.8481593571428572], 
             UndirectedEdge[66, 325] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[128, 171] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[198, 205] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[202, 349] -> 
             RGBColor[
              0.9393049285714286, 0.9491972857142857, 0.7071874285714288], 
             UndirectedEdge[295, 390] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[250, 356] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[133, 393] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[124, 293] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[45, 325] -> 
             RGBColor[0.8555595, 0.7289241428571431, 0.6067823571428572], 
             UndirectedEdge[116, 304] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[213, 296] -> 
             RGBColor[
              0.9392477857142858, 0.793796285714286, 0.545002142857143], 
             UndirectedEdge[248, 276] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[209, 346] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[31, 382] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[69, 373] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285717], 
             UndirectedEdge[166, 239] -> 
             RGBColor[
              0.9565498571428572, 0.8531865714285715, 0.42595535714285754`], 
             UndirectedEdge[235, 317] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[43, 59] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[94, 207] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[209, 270] -> 
             RGBColor[0.9062435, 0.9228350000000001, 0.7040340000000003], 
             UndirectedEdge[23, 341] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[264, 312] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285716], 
             UndirectedEdge[48, 118] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285717], 
             UndirectedEdge[106, 310] -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 
             UndirectedEdge[267, 282] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[43, 274] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[46, 362] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[38, 117] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[252, 300] -> 
             RGBColor[
              0.9288649285714285, 0.9139807142857144, 0.6666300000000001], 
             UndirectedEdge[7, 67] -> 
             RGBColor[
              0.9166498571428572, 0.6504800000000001, 0.30603814285714304`], 
             UndirectedEdge[150, 192] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[239, 272] -> 
             RGBColor[
              0.8694963571428571, 0.7879502857142857, 0.6181913571428572], 
             UndirectedEdge[22, 209] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[167, 246] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[131, 140] -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714287], 
             UndirectedEdge[67, 385] -> 
             RGBColor[0.9172472142857143, 0.6531244285714286, 0.4704045], 
             UndirectedEdge[60, 101] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[113, 249] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[52, 393] -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714287], 
             UndirectedEdge[99, 367] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285716], 
             UndirectedEdge[5, 43] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[26, 105] -> 
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475], 
             UndirectedEdge[128, 306] -> 
             RGBColor[
              0.8842780714285714, 0.8465548571428572, 0.6300850714285715], 
             UndirectedEdge[226, 281] -> 
             RGBColor[
              0.9393049285714286, 0.9491972857142857, 0.7071874285714288], 
             UndirectedEdge[63, 345] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[4, 280] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[7, 223] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[155, 361] -> 
             RGBColor[
              0.9143667142857141, 0.9343765714285714, 0.9855006428571429], 
             UndirectedEdge[252, 398] -> 
             RGBColor[
              0.9288649285714285, 0.9139807142857144, 0.6666300000000001], 
             UndirectedEdge[6, 252] -> 
             RGBColor[
              0.9367337142857142, 0.9505314285714286, 0.9240652142857144], 
             UndirectedEdge[260, 307] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[21, 357] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[233, 366] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[37, 41] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.4924907142857144], 
             UndirectedEdge[173, 176] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[60, 136] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[74, 285] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[234, 395] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             UndirectedEdge[17, 164] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[20, 383] -> 
             RGBColor[
              0.5637495714285714, 0.5696033571428571, 0.6054895714285715], 
             UndirectedEdge[19, 219] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[91, 279] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[76, 207] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[238, 339] -> 
             RGBColor[
              0.6389856428571429, 0.6467717142857143, 0.6098440714285714], 
             UndirectedEdge[142, 379] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[205, 219] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[7, 68] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[188, 273] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[16, 69] -> 
             RGBColor[
              0.7928449999999999, 0.8380041428571428, 0.9489790714285715], 
             UndirectedEdge[118, 323] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[211, 263] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[191, 340] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[33, 182] -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 
             UndirectedEdge[99, 300] -> 
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717], 
             UndirectedEdge[11, 91] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[78, 233] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[27, 172] -> 
             RGBColor[
              0.9531846428571429, 0.8528224285714285, 0.556411142857143], 
             UndirectedEdge[313, 396] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[74, 172] -> 
             RGBColor[
              0.9565498571428572, 0.8531865714285715, 0.42595535714285754`], 
             UndirectedEdge[217, 366] -> 
             RGBColor[
              0.9709799285714285, 0.9466688571428572, 0.639678642857143], 
             UndirectedEdge[277, 302] -> 
             RGBColor[
              0.9600975714285714, 0.8748762857142858, 0.3108696428571429], 
             UndirectedEdge[203, 232] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[27, 285] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[193, 334] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[39, 381] -> 
             RGBColor[
              0.9055083571428572, 0.5628944285714286, 0.45916335714285716`], 
             UndirectedEdge[270, 390] -> 
             RGBColor[
              0.8842780714285714, 0.8465548571428572, 0.6300850714285715], 
             UndirectedEdge[35, 42] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.4924907142857144], 
             UndirectedEdge[41, 245] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[45, 276] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.4924907142857144], 
             UndirectedEdge[17, 241] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[69, 347] -> 
             RGBColor[
              0.9709799285714285, 0.9466688571428572, 0.6396786428571429], 
             UndirectedEdge[16, 295] -> 
             RGBColor[
              0.8045254285714285, 0.8451361428571429, 0.8584853571428572], 
             UndirectedEdge[190, 351] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[112, 141] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[135, 400] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[295, 310] -> 
             RGBColor[
              0.9563532142857143, 0.8541327142857142, 0.5038997142857143], 
             UndirectedEdge[185, 249] -> 
             RGBColor[
              0.9055667857142857, 0.6459924285714287, 0.5608982142857143], 
             UndirectedEdge[93, 98] -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 
             UndirectedEdge[221, 268] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[265, 291] -> 
             RGBColor[
              0.9531846428571429, 0.8528224285714285, 0.556411142857143], 
             UndirectedEdge[128, 133] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[57, 333] -> 
             RGBColor[
              0.9308176428571429, 0.8366675714285714, 0.6178465714285715], 
             UndirectedEdge[28, 378] -> 
             RGBColor[
              0.9531846428571429, 0.8528224285714285, 0.556411142857143], 
             UndirectedEdge[92, 386] -> 
             RGBColor[
              0.9172472142857143, 0.6531244285714286, 0.47040450000000006`], 
             UndirectedEdge[35, 248] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[56, 175] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[3, 21] -> 
             RGBColor[
              0.750710357142857, 0.8003408571428572, 0.7762890000000005], 
             UndirectedEdge[98, 204] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[243, 367] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[48, 209] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285717], 
             UndirectedEdge[116, 291] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[214, 340] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[138, 159] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285717], 
             UndirectedEdge[22, 48] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[13, 297] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[192, 347] -> 
             RGBColor[
              0.9709799285714285, 0.9466688571428572, 0.6396786428571429], 
             UndirectedEdge[4, 322] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[111, 304] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[133, 361] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[4, 186] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[73, 240] -> 
             RGBColor[
              0.9453158571428572, 0.8162717142857143, 0.29897592857142863`], 
             UndirectedEdge[82, 335] -> 
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717], 
             UndirectedEdge[184, 372] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[85, 340] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[344, 388] -> 
             RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 
             UndirectedEdge[57, 228] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[36, 80] -> 
             RGBColor[
              0.8951604285714285, 0.9183474285714286, 0.9588940714285714], 
             UndirectedEdge[88, 365] -> 
             RGBColor[
              0.8045254285714285, 0.8451361428571429, 0.8584853571428572], 
             UndirectedEdge[209, 241] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285716], 
             UndirectedEdge[49, 62] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[161, 250] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.9426130000000001, 0.7941604285714288, 0.4145463571428576], 
             UndirectedEdge[324, 346] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[142, 258] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[44, 46] -> 
             RGBColor[0.992503, 0.986373, 0.42537600000000036`], 
             UndirectedEdge[85, 191] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[112, 172] -> 
             RGBColor[
              0.9563532142857143, 0.8541327142857142, 0.5038997142857143], 
             UndirectedEdge[133, 298] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[26, 215] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[127, 129] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[172, 225] -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 
             UndirectedEdge[38, 376] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[158, 346] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[340, 370] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[44, 266] -> 
             RGBColor[
              0.9705375714285714, 0.9100928571428573, 0.35142707142857166`], 
             UndirectedEdge[183, 238] -> 
             RGBColor[
              0.6498679999999999, 0.7185642857142857, 0.9386530714285715], 
             UndirectedEdge[21, 264] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[13, 140] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[210, 266] -> 
             RGBColor[
              0.8829455714285714, 0.4839698571428572, 0.22084807142857144`], 
             UndirectedEdge[51, 395] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[358, 372] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[174, 309] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[65, 363] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[236, 267] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[227, 352] -> 
             RGBColor[0.8562875, 0.884887, 0.7853977142857147], 
             UndirectedEdge[2, 370] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[17, 354] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[133, 306] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[105, 261] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[120, 206] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[361, 393] -> 
             RGBColor[
              0.9143667142857141, 0.9343765714285714, 0.9855006428571429], 
             UndirectedEdge[270, 295] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[9, 283] -> RGBColor[0.819984, 0.859297, 0.982692],
              UndirectedEdge[43, 122] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[127, 336] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[4, 123] -> 
             RGBColor[
              0.9426130000000001, 0.7941604285714288, 0.4145463571428576], 
             UndirectedEdge[45, 279] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.4924907142857144], 
             UndirectedEdge[135, 255] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[152, 180] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[48, 68] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[362, 363] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[18, 257] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[72, 109] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[181, 211] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[82, 259] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[282, 367] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[44, 363] -> 
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717], 
             UndirectedEdge[139, 290] -> 
             RGBColor[
              0.6123661428571429, 0.6496520714285715, 0.6409933571428572], 
             UndirectedEdge[255, 351] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[290, 345] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[145, 200] -> 
             RGBColor[0.7671809285714286, 0.707607, 0.6082763571428571], 
             UndirectedEdge[44, 316] -> 
             RGBColor[
              0.9705375714285714, 0.9100928571428573, 0.35142707142857166`], 
             UndirectedEdge[172, 240] -> 
             RGBColor[
              0.9190087142857143, 0.7166035714285715, 0.2536907142857143], 
             UndirectedEdge[89, 299] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[119, 196] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             UndirectedEdge[149, 369] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[32, 385] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[149, 253] -> 
             RGBColor[
              0.9399022857142857, 0.9518417142857143, 0.8715537857142858], 
             UndirectedEdge[317, 336] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[138, 215] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[157, 181] -> 
             RGBColor[
              0.9531846428571429, 0.8528224285714285, 0.556411142857143], 
             UndirectedEdge[299, 342] -> 
             RGBColor[
              0.9709799285714285, 0.9466688571428572, 0.639678642857143], 
             UndirectedEdge[108, 198] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[152, 367] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[17, 118] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[44, 68] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[158, 323] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[343, 359] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[354, 388] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[382, 389] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[178, 319] -> 
             RGBColor[
              0.9455993571428571, 0.8952721428571428, 0.6297402857142858], 
             UndirectedEdge[15, 386] -> 
             RGBColor[
              0.9140786428571428, 0.6518141428571429, 0.5229159285714287], 
             UndirectedEdge[27, 104] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[236, 398] -> 
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717], 
             UndirectedEdge[151, 304] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[21, 233] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[120, 321] -> 
             RGBColor[
              0.9531846428571429, 0.8528224285714285, 0.556411142857143], 
             UndirectedEdge[170, 299] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[97, 109] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[251, 381] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[134, 392] -> 
             RGBColor[
              0.5746319285714285, 0.6413959285714286, 0.9342985714285714], 
             UndirectedEdge[132, 220] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[102, 167] -> 
             RGBColor[
              0.9705375714285714, 0.9100928571428573, 0.35142707142857166`], 
             UndirectedEdge[270, 373] -> 
             RGBColor[0.9062435, 0.9228350000000001, 0.7040340000000002], 
             UndirectedEdge[122, 351] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[96, 173] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[253, 266] -> 
             RGBColor[0.9173395, 0.872917142857143, 0.6332385], 
             UndirectedEdge[217, 230] -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 
             UndirectedEdge[118, 158] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[208, 230] -> 
             RGBColor[
              0.9453158571428572, 0.8162717142857143, 0.29897592857142863`], 
             UndirectedEdge[86, 179] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[185, 284] -> 
             RGBColor[
              0.9174438571428571, 0.6521782857142857, 0.39246014285714326`], 
             UndirectedEdge[279, 399] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[167, 309] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[174, 183] -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 
             UndirectedEdge[149, 247] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[297, 339] -> 
             RGBColor[
              0.9705375714285714, 0.9100928571428573, 0.35142707142857166`], 
             UndirectedEdge[28, 282] -> 
             RGBColor[
              0.9563532142857143, 0.8541327142857142, 0.5038997142857143], 
             UndirectedEdge[35, 125] -> 
             RGBColor[
              0.9426130000000001, 0.7941604285714288, 0.4145463571428576], 
             UndirectedEdge[119, 231] -> 
             RGBColor[
              0.9143667142857141, 0.9343765714285714, 0.9855006428571429], 
             UndirectedEdge[257, 309] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[153, 161] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[315, 369] -> 
             RGBColor[
              0.9565498571428572, 0.8531865714285715, 0.42595535714285754`], 
             UndirectedEdge[145, 207] -> 
             RGBColor[
              0.9531846428571429, 0.8528224285714285, 0.556411142857143], 
             UndirectedEdge[75, 215] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[155, 199] -> 
             RGBColor[
              0.9288649285714285, 0.9139807142857144, 0.6666300000000001], 
             UndirectedEdge[28, 151] -> 
             RGBColor[
              0.9557558571428572, 0.8514882857142858, 0.3395333571428574], 
             UndirectedEdge[141, 279] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[347, 380] -> 
             RGBColor[
              0.9288649285714285, 0.9139807142857144, 0.6666300000000001], 
             UndirectedEdge[107, 346] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[171, 299] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[283, 294] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[83, 244] -> 
             RGBColor[
              0.9174438571428571, 0.6521782857142858, 0.39246014285714326`], 
             UndirectedEdge[112, 179] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[42, 93] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[94, 254] -> 
             RGBColor[
              0.7928449999999999, 0.8380041428571428, 0.9489790714285715], 
             UndirectedEdge[84, 222] -> 
             RGBColor[0.819984, 0.859297, 0.982692], UndirectedEdge[132, 366] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[52, 133] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[255, 400] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[276, 318] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[235, 313] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[218, 229] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[202, 260] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[129, 216] -> 
             RGBColor[
              0.9600975714285714, 0.8748762857142858, 0.3108696428571429], 
             UndirectedEdge[307, 312] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[215, 349] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[48, 61] -> 
             RGBColor[
              0.8951604285714285, 0.9183474285714286, 0.9588940714285714], 
             UndirectedEdge[198, 284] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[37, 256] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.4924907142857144], 
             UndirectedEdge[260, 366] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[35, 263] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.4924907142857144], 
             UndirectedEdge[124, 185] -> 
             RGBColor[
              0.9055667857142857, 0.6459924285714286, 0.5608982142857144], 
             UndirectedEdge[17, 48] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[98, 139] -> 
             RGBColor[
              0.6117230714285713, 0.6803810714285714, 0.9364108571428572], 
             UndirectedEdge[98, 125] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[195, 397] -> 
             RGBColor[
              0.9036722857142857, 0.9241691428571428, 0.9209117857142859], 
             UndirectedEdge[152, 198] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[29, 129] -> 
             RGBColor[
              0.9067615714285715, 0.6567342857142858, 0.2432511428571429], 
             UndirectedEdge[83, 230] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[10, 155] -> 
             RGBColor[
              0.9143667142857141, 0.9343765714285714, 0.9855006428571429], 
             UndirectedEdge[210, 316] -> 
             RGBColor[
              0.8829455714285714, 0.4839698571428572, 0.22084807142857144`], 
             UndirectedEdge[6, 175] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[301, 343] -> 
             RGBColor[0.8958035, 0.8876184285714286, 0.6634765714285715], 
             UndirectedEdge[140, 297] -> 
             RGBColor[0.9062435, 0.9228350000000001, 0.7040340000000002], 
             UndirectedEdge[274, 295] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[61, 371] -> 
             RGBColor[
              0.8951604285714285, 0.9183474285714286, 0.9588940714285714], 
             UndirectedEdge[266, 397] -> 
             RGBColor[
              0.8842780714285714, 0.8465548571428572, 0.6300850714285715], 
             UndirectedEdge[71, 88] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[156, 255] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[22, 388] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[17, 346] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[72, 365] -> 
             RGBColor[
              0.7789898571428571, 0.8276709999999999, 0.9724322142857142], 
             UndirectedEdge[194, 230] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[95, 264] -> 
             RGBColor[
              0.9393049285714286, 0.9491972857142857, 0.7071874285714288], 
             UndirectedEdge[131, 325] -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714287], 
             UndirectedEdge[369, 372] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[11, 248] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[32, 223] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[75, 229] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[123, 131] -> 
             RGBColor[
              0.8886209285714286, 0.7552864285714288, 0.6099357857142857], 
             UndirectedEdge[35, 340] -> 
             RGBColor[
              0.9426130000000001, 0.7941604285714288, 0.4145463571428576], 
             UndirectedEdge[316, 369] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[232, 280] -> 
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475], 
             UndirectedEdge[30, 318] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[219, 338] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[124, 397] -> 
             RGBColor[
              0.8951604285714285, 0.9183474285714286, 0.9588940714285714], 
             UndirectedEdge[131, 280] -> 
             RGBColor[
              0.8861068571428571, 0.9120215714285714, 0.9889988571428572], 
             UndirectedEdge[224, 345] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[44, 195] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[57, 102] -> 
             RGBColor[
              0.9455993571428571, 0.8952721428571428, 0.6297402857142858], 
             UndirectedEdge[102, 222] -> 
             RGBColor[
              0.8842780714285714, 0.8465548571428572, 0.6300850714285715], 
             UndirectedEdge[86, 285] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[97, 340] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[84, 183] -> 
             RGBColor[
              0.8951604285714285, 0.9183474285714286, 0.9588940714285714], 
             UndirectedEdge[23, 132] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[124, 210] -> 
             RGBColor[
              0.8938279285714286, 0.5557624285714285, 0.5496570714285715], 
             UndirectedEdge[257, 288] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[31, 287] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[163, 222] -> 
             RGBColor[
              0.9036722857142857, 0.9241691428571428, 0.9209117857142859], 
             UndirectedEdge[206, 386] -> 
             RGBColor[
              0.8917116428571428, 0.6356592857142858, 0.5843513571428571], 
             UndirectedEdge[95, 263] -> 
             RGBColor[
              0.9399022857142857, 0.9518417142857143, 0.8715537857142858], 
             UndirectedEdge[103, 333] -> 
             RGBColor[
              0.9446727857142856, 0.8470007142857143, 0.5943934285714286], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[57, 174] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[32, 208] -> 
             RGBColor[
              0.9446727857142856, 0.8470007142857143, 0.5943934285714286], 
             UndirectedEdge[11, 125] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[82, 136] -> 
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717], 
             UndirectedEdge[129, 298] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[155, 306] -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714287], 
             UndirectedEdge[247, 358] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[5, 373] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[194, 201] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[7, 173] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[25, 364] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285717], 
             UndirectedEdge[1, 313] -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 
             UndirectedEdge[189, 222] -> 
             RGBColor[
              0.8951604285714285, 0.9183474285714286, 0.9588940714285714], 
             UndirectedEdge[232, 275] -> 
             RGBColor[
              0.8951604285714285, 0.9183474285714286, 0.9588940714285714], 
             UndirectedEdge[289, 376] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[194, 208] -> 
             RGBColor[
              0.9563532142857143, 0.8541327142857142, 0.5038997142857143], 
             UndirectedEdge[320, 384] -> 
             RGBColor[
              0.8886209285714286, 0.7552864285714288, 0.6099357857142857], 
             UndirectedEdge[262, 332] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[39, 237] -> 
             RGBColor[
              0.8517129285714286, 0.5230742857142857, 0.5766084285714286], 
             UndirectedEdge[105, 353] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[160, 321] -> 
             RGBColor[
              0.9446727857142856, 0.8470007142857143, 0.5943934285714286], 
             UndirectedEdge[22, 354] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[70, 286] -> 
             RGBColor[
              0.9557558571428572, 0.8514882857142858, 0.3395333571428574], 
             UndirectedEdge[97, 334] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[301, 362] -> 
             RGBColor[
              0.9036722857142857, 0.9241691428571428, 0.9209117857142859], 
             UndirectedEdge[166, 300] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[357, 364] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[13, 66] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[102, 395] -> 
             RGBColor[
              0.9455993571428571, 0.8952721428571428, 0.6297402857142858], 
             UndirectedEdge[129, 336] -> 
             RGBColor[
              0.9455993571428571, 0.8952721428571428, 0.6297402857142858], 
             UndirectedEdge[257, 275] -> 
             RGBColor[
              0.9036722857142857, 0.9241691428571428, 0.9209117857142859], 
             UndirectedEdge[358, 369] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[42, 139] -> 
             RGBColor[0.6234035, 0.6875130714285714, 0.8459171428571429], 
             UndirectedEdge[37, 206] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[3, 162] -> 
             RGBColor[
              0.7473451428571427, 0.7999767142857143, 0.9067447857142859], 
             UndirectedEdge[44, 161] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[67, 266] -> 
             RGBColor[
              0.8946844285714286, 0.5741998571428573, 0.23208921428571433`], 
             UndirectedEdge[305, 360] -> 
             RGBColor[0.992503, 0.986373, 0.42537600000000036`], 
             UndirectedEdge[51, 174] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[132, 321] -> 
             RGBColor[
              0.9563532142857143, 0.8541327142857142, 0.5038997142857143], 
             UndirectedEdge[198, 236] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[153, 356] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[78, 217] -> 
             RGBColor[
              0.9288649285714285, 0.9139807142857144, 0.6666300000000001], 
             UndirectedEdge[16, 324] -> 
             RGBColor[
              0.7789898571428571, 0.8276709999999999, 0.9724322142857142], 
             UndirectedEdge[263, 312] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[49, 231] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[58, 303] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[287, 371] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[108, 332] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[55, 135] -> 
             RGBColor[
              0.8813052857142857, 0.9080142857142857, 0.9823472142857144], 
             UndirectedEdge[38, 145] -> 
             RGBColor[
              0.9531846428571429, 0.8528224285714285, 0.556411142857143], 
             UndirectedEdge[41, 400] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[184, 369] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[68, 363] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[239, 350] -> 
             RGBColor[
              0.9557558571428572, 0.8514882857142858, 0.3395333571428574], 
             UndirectedEdge[197, 300] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[34, 340] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[99, 225] -> 
             RGBColor[
              0.9705375714285714, 0.9100928571428573, 0.35142707142857166`], 
             UndirectedEdge[75, 218] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[33, 256] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[68, 173] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[76, 368] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[343, 369] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[172, 243] -> 
             RGBColor[
              0.9531846428571429, 0.8528224285714285, 0.556411142857143], 
             UndirectedEdge[25, 83] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[176, 372] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[211, 214] -> 
             RGBColor[
              0.9399022857142857, 0.9518417142857143, 0.8715537857142858], 
             UndirectedEdge[273, 330] -> 
             RGBColor[0.9173395, 0.872917142857143, 0.6332385], 
             UndirectedEdge[247, 266] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[294, 347] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[247, 343] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[147, 354] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[83, 206] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[178, 300] -> 
             RGBColor[
              0.9600975714285714, 0.8748762857142858, 0.3108696428571429], 
             UndirectedEdge[31, 384] -> 
             RGBColor[
              0.9307359285714285, 0.7879745714285716, 0.5829844285714286], 
             UndirectedEdge[325, 339] -> 
             RGBColor[
              0.8842780714285714, 0.8465548571428572, 0.6300850714285715], 
             UndirectedEdge[43, 237] -> 
             RGBColor[
              0.9393049285714286, 0.9491972857142857, 0.7071874285714288], 
             UndirectedEdge[114, 128] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[131, 188] -> 
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475], 
             UndirectedEdge[8, 352] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[56, 137] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[11, 93] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[232, 325] -> 
             RGBColor[
              0.8951604285714285, 0.9183474285714286, 0.9588940714285714], 
             UndirectedEdge[293, 387] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[100, 175] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[327, 336] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             UndirectedEdge[230, 357] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[151, 291] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[10, 87] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[44, 247] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[191, 334] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[31, 389] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[323, 346] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[91, 257] -> 
             RGBColor[
              0.9036722857142857, 0.9241691428571428, 0.9209117857142859], 
             UndirectedEdge[25, 217] -> 
             RGBColor[
              0.9709799285714285, 0.9466688571428572, 0.6396786428571429], 
             UndirectedEdge[4, 238] -> 
             RGBColor[
              0.6617450714285715, 0.7247501428571429, 0.7702150000000003], 
             UndirectedEdge[49, 298] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[96, 245] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[198, 219] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[69, 106] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[246, 350] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[91, 263] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[193, 305] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[217, 244] -> 
             RGBColor[
              0.9062098571428572, 0.6152634285714287, 0.26548071428571435`], 
             UndirectedEdge[218, 260] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[115, 169] -> 
             RGBColor[
              0.8780430000000001, 0.5391035714285717, 0.21994842857142863`], 
             UndirectedEdge[152, 332] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[8, 227] -> 
             RGBColor[
              0.8305552857142856, 0.8683679999999999, 0.9772889285714286], 
             UndirectedEdge[161, 344] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[255, 324] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[135, 221] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[179, 257] -> 
             RGBColor[
              0.9036722857142857, 0.9241691428571428, 0.9209117857142859], 
             UndirectedEdge[40, 350] -> 
             RGBColor[0.9062435, 0.9228350000000001, 0.7040340000000002], 
             UndirectedEdge[358, 397] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[44, 149] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[215, 218] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[211, 248] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[38, 103] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[79, 213] -> 
             RGBColor[
              0.9392477857142858, 0.793796285714286, 0.545002142857143], 
             UndirectedEdge[116, 383] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[214, 263] -> 
             RGBColor[
              0.9399022857142857, 0.9518417142857143, 0.8715537857142858], 
             UndirectedEdge[203, 275] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[235, 396] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[170, 361] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[190, 255] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[67, 113] -> 
             RGBColor[
              0.9174438571428571, 0.6521782857142857, 0.39246014285714326`], 
             UndirectedEdge[244, 307] -> 
             RGBColor[
              0.8917116428571428, 0.6356592857142858, 0.5843513571428571], 
             UndirectedEdge[106, 292] -> 
             RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 
             UndirectedEdge[119, 126] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[148, 288] -> 
             RGBColor[
              0.9399022857142857, 0.9518417142857143, 0.8715537857142858], 
             UndirectedEdge[143, 277] -> 
             RGBColor[
              0.9709799285714285, 0.9466688571428572, 0.6396786428571429], 
             UndirectedEdge[245, 364] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285717], 
             UndirectedEdge[101, 335] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[175, 296] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[106, 158] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[59, 319] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             UndirectedEdge[159, 218] -> 
             RGBColor[0.992503, 0.986373, 0.42537600000000036`], 
             UndirectedEdge[126, 326] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[130, 371] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[108, 262] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[34, 91] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[173, 323] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[104, 208] -> 
             RGBColor[
              0.9557558571428572, 0.8514882857142858, 0.3395333571428574], 
             UndirectedEdge[115, 122] -> 
             RGBColor[
              0.9392477857142858, 0.793796285714286, 0.545002142857143], 
             UndirectedEdge[275, 297] -> 
             RGBColor[0.9062435, 0.9228350000000001, 0.7040340000000002], 
             UndirectedEdge[185, 293] -> 
             RGBColor[
              0.9140786428571428, 0.6518141428571429, 0.5229159285714287], 
             UndirectedEdge[92, 256] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[135, 165] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[158, 270] -> 
             RGBColor[
              0.9036722857142857, 0.9241691428571428, 0.9209117857142859], 
             UndirectedEdge[35, 86] -> 
             RGBColor[
              0.9426130000000001, 0.7941604285714288, 0.4145463571428576], 
             UndirectedEdge[124, 387] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[170, 261] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[78, 244] -> 
             RGBColor[
              0.8634517857142857, 0.6133042857142857, 0.5878495714285714], 
             UndirectedEdge[320, 381] -> 
             RGBColor[
              0.9399022857142857, 0.9518417142857143, 0.8715537857142858], 
             UndirectedEdge[90, 166] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[119, 317] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[173, 250] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[234, 355] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[203, 297] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[48, 388] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[34, 95] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[133, 299] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[58, 376] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[239, 392] -> 
             RGBColor[
              0.5489678571428571, 0.5109987857142857, 0.5935958571428572], 
             UndirectedEdge[64, 77] -> 
             RGBColor[
              0.9399022857142857, 0.9518417142857143, 0.8715537857142858], 
             UndirectedEdge[73, 112] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[257, 339] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[35, 85] -> 
             RGBColor[
              0.9418190000000001, 0.7924621428571431, 0.32812435714285737`], 
             UndirectedEdge[37, 187] -> 
             RGBColor[
              0.9426130000000001, 0.7941604285714288, 0.4145463571428576], 
             UndirectedEdge[9, 39] -> 
             RGBColor[0.8186515000000001, 0.496712, 0.573455], 
             UndirectedEdge[136, 394] -> 
             RGBColor[
              0.9393049285714286, 0.9491972857142857, 0.7071874285714288], 
             UndirectedEdge[287, 389] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[195, 372] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[149, 362] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[83, 321] -> 
             RGBColor[
              0.9565498571428572, 0.8531865714285715, 0.42595535714285754`], 
             UndirectedEdge[227, 308] -> 
             RGBColor[
              0.8554934999999999, 0.8831887142857142, 0.6989757142857145], 
             UndirectedEdge[100, 146] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[100, 278] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[234, 350] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[278, 352] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[342, 353] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[109, 181] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[59, 296] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[168, 378] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[191, 370] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[153, 184] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[3, 91] -> 
             RGBColor[
              0.6636568571428572, 0.7351045714285713, 0.9685250000000001], 
             UndirectedEdge[149, 210] -> 
             RGBColor[
              0.9055083571428572, 0.5628944285714286, 0.45916335714285716`], 
             UndirectedEdge[3, 312] -> 
             RGBColor[
              0.7388332857142856, 0.7941549999999999, 0.9447270714285715], 
             UndirectedEdge[17, 388] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[99, 243] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[108, 398] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[57, 186] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[180, 398] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[66, 318] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[374, 382] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[190, 270] -> 
             RGBColor[
              0.8813052857142857, 0.9080142857142857, 0.9823472142857144], 
             UndirectedEdge[47, 96] -> 
             RGBColor[
              0.9198535714285715, 0.7161820000000003, 0.2541754285714286], 
             UndirectedEdge[245, 328] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[142, 143] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[268, 373] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285717], 
             UndirectedEdge[69, 390] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[91, 112] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[16, 190] -> 
             RGBColor[
              0.7789898571428571, 0.8276709999999999, 0.9724322142857142], 
             UndirectedEdge[40, 395] -> 
             RGBColor[
              0.8813052857142857, 0.9080142857142857, 0.9823472142857144], 
             UndirectedEdge[84, 246] -> 
             RGBColor[
              0.8813052857142857, 0.9080142857142857, 0.9823472142857144], 
             UndirectedEdge[196, 376] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[37, 311] -> 
             RGBColor[
              0.9418190000000001, 0.7924621428571431, 0.32812435714285737`], 
             UndirectedEdge[179, 275] -> 
             RGBColor[0.819984, 0.859297, 0.982692], UndirectedEdge[334, 340] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[23, 366] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[295, 351] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[358, 363] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[111, 116] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[147, 371] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[33, 311] -> 
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717], 
             UndirectedEdge[137, 178] -> 
             RGBColor[
              0.9455993571428571, 0.8952721428571428, 0.6297402857142858], 
             UndirectedEdge[328, 386] -> 
             RGBColor[
              0.9174438571428571, 0.6521782857142858, 0.39246014285714326`], 
             UndirectedEdge[20, 36] -> 
             RGBColor[0.4994555, 0.5823455, 0.9580965], 
             UndirectedEdge[107, 212] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[21, 27] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[138, 329] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[3, 263] -> 
             RGBColor[0.7505137142857142, 0.801287, 0.8542333571428572], 
             UndirectedEdge[239, 269] -> 
             RGBColor[
              0.9563532142857143, 0.8541327142857142, 0.5038997142857143], 
             UndirectedEdge[74, 86] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[91, 179] -> 
             RGBColor[0.819984, 0.859297, 0.982692], UndirectedEdge[316, 358] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[154, 267] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[25, 357] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[118, 388] -> 
             RGBColor[
              0.9705375714285714, 0.9100928571428573, 0.35142707142857166`], 
             UndirectedEdge[305, 340] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[100, 213] -> 
             RGBColor[
              0.9392477857142858, 0.793796285714286, 0.545002142857143], 
             UndirectedEdge[51, 238] -> 
             RGBColor[
              0.6617450714285715, 0.7247501428571429, 0.7702150000000003], 
             UndirectedEdge[104, 242] -> 
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717], 
             UndirectedEdge[99, 337] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285716], 
             UndirectedEdge[143, 302] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[14, 327] -> 
             RGBColor[
              0.9455993571428571, 0.8952721428571428, 0.6297402857142858], 
             UndirectedEdge[162, 348] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[130, 391] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[182, 386] -> 
             RGBColor[
              0.9062098571428572, 0.6152634285714287, 0.26548071428571435`], 
             UndirectedEdge[32, 217] -> 
             RGBColor[
              0.9709799285714285, 0.9466688571428572, 0.6396786428571429], 
             UndirectedEdge[3, 285] -> 
             RGBColor[
              0.7279509285714285, 0.7223624285714285, 0.6159180714285715], 
             UndirectedEdge[212, 274] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[234, 272] -> 
             RGBColor[
              0.8813052857142857, 0.9080142857142857, 0.9823472142857144], 
             UndirectedEdge[24, 104] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285717], 
             UndirectedEdge[317, 327] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[85, 263] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[169, 300] -> 
             RGBColor[
              0.9182870000000001, 0.6977978571428574, 0.2766426428571429], 
             UndirectedEdge[34, 162] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[62, 313] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[337, 367] -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 
             UndirectedEdge[21, 240] -> 
             RGBColor[
              0.9565498571428572, 0.8531865714285715, 0.42595535714285754`], 
             UndirectedEdge[258, 378] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[240, 242] -> 
             RGBColor[
              0.9453158571428572, 0.8162717142857143, 0.29897592857142863`], 
             UndirectedEdge[16, 380] -> 
             RGBColor[
              0.7507299999999999, 0.8053159999999999, 0.9759304285714285], 
             UndirectedEdge[38, 222] -> 
             RGBColor[
              0.9036722857142857, 0.9241691428571428, 0.9209117857142859], 
             UndirectedEdge[61, 147] -> 
             RGBColor[
              0.8842780714285714, 0.8465548571428572, 0.6300850714285715], 
             UndirectedEdge[279, 288] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[192, 384] -> 
             RGBColor[
              0.9307359285714285, 0.7879745714285716, 0.5829844285714286], 
             UndirectedEdge[196, 289] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[9, 384] -> 
             RGBColor[0.8555595, 0.7289241428571431, 0.6067823571428572], 
             UndirectedEdge[114, 187] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[90, 274] -> 
             RGBColor[
              0.9399022857142857, 0.9518417142857143, 0.8715537857142858], 
             UndirectedEdge[270, 324] -> 
             RGBColor[
              0.8813052857142857, 0.9080142857142857, 0.9823472142857144], 
             UndirectedEdge[42, 45] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[316, 363] -> 
             RGBColor[
              0.9600975714285714, 0.8748762857142858, 0.3108696428571429], 
             UndirectedEdge[44, 250] -> 
             RGBColor[
              0.9705375714285714, 0.9100928571428573, 0.35142707142857166`], 
             UndirectedEdge[213, 352] -> 
             RGBColor[
              0.9426130000000001, 0.7941604285714288, 0.4145463571428576], 
             UndirectedEdge[80, 378] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[238, 272] -> 
             RGBColor[0.5746915714285714, 0.6595138571428572, 0.962451], 
             UndirectedEdge[126, 196] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[112, 240] -> 
             RGBColor[
              0.9563532142857143, 0.8541327142857142, 0.5038997142857143], 
             UndirectedEdge[52, 89] -> 
             RGBColor[
              0.8813052857142857, 0.9080142857142857, 0.9823472142857144], 
             UndirectedEdge[99, 177] -> 
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717], 
             UndirectedEdge[41, 206] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[1, 119] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[2, 109] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[8, 100] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[203, 322] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[98, 193] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[141, 285] -> 
             RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 
             UndirectedEdge[29, 231] -> 
             RGBColor[0.8755289285714285, 0.6958387142857143, 0.5990115], 
             UndirectedEdge[225, 398] -> 
             RGBColor[
              0.9600975714285714, 0.8748762857142858, 0.3108696428571429], 
             UndirectedEdge[149, 359] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[87, 235] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[162, 312] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[392, 395] -> 
             RGBColor[
              0.5607767857142856, 0.6310627857142856, 0.9577517142857144], 
             UndirectedEdge[212, 268] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[50, 271] -> 
             RGBColor[
              0.9565498571428572, 0.8531865714285715, 0.42595535714285754`], 
             UndirectedEdge[200, 207] -> 
             RGBColor[
              0.8013568571428571, 0.8438258571428572, 0.9109967857142858], 
             UndirectedEdge[360, 370] -> 
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717], 
             UndirectedEdge[134, 246] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[88, 191] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[277, 278] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[233, 242] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[66, 123] -> 
             RGBColor[
              0.9426130000000001, 0.7941604285714288, 0.4145463571428576], 
             UndirectedEdge[315, 316] -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 
             UndirectedEdge[127, 216] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[29, 326] -> 
             RGBColor[
              0.9037887857142857, 0.7181937142857143, 0.5955132857142857], 
             UndirectedEdge[76, 145] -> 
             RGBColor[
              0.9531846428571429, 0.8528224285714285, 0.556411142857143], 
             UndirectedEdge[21, 104] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[27, 112] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[190, 221] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[310, 324] -> 
             RGBColor[
              0.9308176428571429, 0.8366675714285714, 0.6178465714285715], 
             UndirectedEdge[11, 312] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[177, 225] -> 
             RGBColor[
              0.9600975714285714, 0.8748762857142858, 0.3108696428571429], 
             UndirectedEdge[253, 316] -> 
             RGBColor[0.9173395, 0.872917142857143, 0.6332385], 
             UndirectedEdge[17, 323] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[315, 397] -> 
             RGBColor[
              0.8694963571428571, 0.7879502857142857, 0.6181913571428572], 
             UndirectedEdge[43, 296] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[50, 287] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[253, 369] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[187, 220] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[211, 340] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[213, 227] -> 
             RGBColor[0.8048095, 0.6892778571428573, 0.6017240714285714], 
             UndirectedEdge[17, 389] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[117, 376] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[186, 330] -> 
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475], 
             UndirectedEdge[24, 337] -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 
             UndirectedEdge[73, 99] -> 
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717], 
             UndirectedEdge[114, 155] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[123, 232] -> 
             RGBColor[
              0.9307359285714285, 0.7879745714285716, 0.5829844285714287], 
             UndirectedEdge[53, 289] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[126, 376] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[207, 254] -> 
             RGBColor[
              0.8013568571428571, 0.8438258571428572, 0.9109967857142858], 
             UndirectedEdge[291, 304] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[333, 368] -> 
             RGBColor[
              0.9565498571428572, 0.8531865714285715, 0.42595535714285754`], 
             UndirectedEdge[26, 171] -> 
             RGBColor[
              0.9399022857142857, 0.9518417142857143, 0.8715537857142858], 
             UndirectedEdge[81, 384] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[120, 233] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[224, 290] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[393, 396] -> 
             RGBColor[
              0.9367337142857142, 0.9505314285714286, 0.9240652142857144], 
             UndirectedEdge[2, 365] -> 
             RGBColor[
              0.7789898571428571, 0.8276709999999999, 0.9724322142857142], 
             UndirectedEdge[210, 387] -> 
             RGBColor[
              0.8829455714285714, 0.4839698571428572, 0.22084807142857144`], 
             UndirectedEdge[23, 307] -> 
             RGBColor[
              0.9455993571428571, 0.8952721428571428, 0.6297402857142858], 
             UndirectedEdge[120, 244] -> 
             RGBColor[
              0.9140786428571428, 0.6518141428571429, 0.5229159285714287], 
             UndirectedEdge[42, 248] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[49, 393] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[375, 377] -> 
             RGBColor[
              0.9565498571428572, 0.8531865714285715, 0.42595535714285754`], 
             UndirectedEdge[269, 350] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[77, 207] -> 
             RGBColor[
              0.9367337142857142, 0.9505314285714286, 0.9240652142857144], 
             UndirectedEdge[200, 368] -> 
             RGBColor[0.8047220714285714, 0.84419, 0.7805410000000004], 
             UndirectedEdge[384, 389] -> 
             RGBColor[
              0.9426130000000001, 0.7941604285714288, 0.4145463571428576], 
             UndirectedEdge[1, 361] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[150, 380] -> 
             RGBColor[0.9173395, 0.872917142857143, 0.6332385], 
             UndirectedEdge[150, 381] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[232, 279] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[132, 341] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[1, 14] -> 
             RGBColor[
              0.9600975714285714, 0.8748762857142858, 0.3108696428571429], 
             UndirectedEdge[171, 342] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[140, 325] -> 
             RGBColor[0.819984, 0.859297, 0.982692], UndirectedEdge[89, 306] -> 
             RGBColor[
              0.8813052857142857, 0.9080142857142857, 0.9823472142857144], 
             UndirectedEdge[130, 147] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[4, 183] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[80, 151] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285717], 
             UndirectedEdge[236, 286] -> 
             RGBColor[0.992503, 0.986373, 0.42537600000000036`], 
             UndirectedEdge[108, 180] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[9, 320] -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714287], 
             UndirectedEdge[35, 97] -> 
             RGBColor[
              0.9392477857142858, 0.793796285714286, 0.545002142857143], 
             UndirectedEdge[154, 236] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[60, 259] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[179, 399] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[314, 352] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[85, 88] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[70, 267] -> 
             RGBColor[
              0.9308176428571429, 0.8366675714285714, 0.6178465714285715], 
             UndirectedEdge[31, 192] -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 
             UndirectedEdge[221, 255] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[11, 211] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[211, 312] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[123, 280] -> 
             RGBColor[
              0.8886209285714286, 0.7552864285714288, 0.6099357857142857], 
             UndirectedEdge[178, 278] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[83, 364] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[10, 313] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[32, 242] -> 
             RGBColor[
              0.9709799285714285, 0.9466688571428572, 0.6396786428571429], 
             UndirectedEdge[44, 369] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[110, 375] -> 
             RGBColor[
              0.9426130000000001, 0.7941604285714288, 0.4145463571428576], 
             UndirectedEdge[275, 290] -> 
             RGBColor[0.8958035, 0.8876184285714286, 0.6634765714285715], 
             UndirectedEdge[362, 369] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[266, 338] -> 
             RGBColor[
              0.8842780714285714, 0.8465548571428572, 0.6300850714285715], 
             UndirectedEdge[350, 395] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[141, 172] -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 
             UndirectedEdge[123, 275] -> 
             RGBColor[0.8555595, 0.7289241428571431, 0.6067823571428572], 
             UndirectedEdge[46, 315] -> 
             RGBColor[
              0.9557558571428572, 0.8514882857142858, 0.3395333571428574], 
             UndirectedEdge[185, 205] -> 
             RGBColor[
              0.9062098571428572, 0.6152634285714287, 0.26548071428571435`], 
             UndirectedEdge[3, 86] -> 
             RGBColor[
              0.750710357142857, 0.8003408571428572, 0.7762890000000005], 
             UndirectedEdge[316, 397] -> 
             RGBColor[
              0.8842780714285714, 0.8465548571428572, 0.6300850714285715], 
             UndirectedEdge[11, 214] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[3, 34] -> 
             RGBColor[
              0.750710357142857, 0.8003408571428572, 0.7762890000000005], 
             UndirectedEdge[5, 100] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[25, 245] -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 
             UndirectedEdge[183, 325] -> 
             RGBColor[
              0.8951604285714285, 0.9183474285714286, 0.9588940714285714], 
             UndirectedEdge[149, 266] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[73, 78] -> 
             RGBColor[
              0.9288649285714285, 0.9139807142857144, 0.6666300000000001], 
             UndirectedEdge[40, 167] -> 
             RGBColor[0.9062435, 0.9228350000000001, 0.7040340000000002], 
             UndirectedEdge[5, 175] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[279, 309] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[66, 257] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[238, 309] -> 
             RGBColor[
              0.6617450714285715, 0.7247501428571428, 0.7702150000000003], 
             UndirectedEdge[40, 355] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[31, 271] -> 
             RGBColor[
              0.9446727857142856, 0.8470007142857143, 0.5943934285714286], 
             UndirectedEdge[271, 391] -> 
             RGBColor[
              0.9563532142857143, 0.8541327142857142, 0.5038997142857143], 
             UndirectedEdge[264, 348] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[146, 302] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[86, 91] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[232, 257] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[201, 385] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[204, 297] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[241, 323] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[269, 395] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[52, 342] -> 
             RGBColor[
              0.8951604285714285, 0.9183474285714286, 0.9588940714285714], 
             UndirectedEdge[201, 245] -> 
             RGBColor[
              0.9709799285714285, 0.9466688571428572, 0.639678642857143], 
             UndirectedEdge[131, 330] -> 
             RGBColor[
              0.8861068571428571, 0.9120215714285714, 0.9889988571428572], 
             UndirectedEdge[159, 349] -> 
             RGBColor[
              0.9393049285714286, 0.9491972857142857, 0.7071874285714288], 
             UndirectedEdge[15, 33] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[16, 212] -> 
             RGBColor[
              0.7819626428571429, 0.7662115714285714, 0.6201700714285714], 
             UndirectedEdge[246, 269] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[150, 294] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[77, 200] -> 
             RGBColor[
              0.7507299999999999, 0.8053159999999999, 0.9759304285714285], 
             UndirectedEdge[21, 285] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[275, 280] -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714287], 
             UndirectedEdge[171, 353] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[197, 252] -> 
             RGBColor[
              0.9367337142857142, 0.9505314285714286, 0.9240652142857144], 
             UndirectedEdge[15, 361] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[348, 366] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[235, 298] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[62, 298] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[110, 308] -> 
             RGBColor[
              0.9418190000000001, 0.7924621428571431, 0.32812435714285737`], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.8842780714285714, 0.8465548571428572, 0.6300850714285715], 
             UndirectedEdge[204, 290] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[35, 93] -> 
             RGBColor[
              0.9307359285714285, 0.7879745714285716, 0.5829844285714287], 
             UndirectedEdge[162, 211] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[66, 275] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[36, 277] -> 
             RGBColor[0.8958035, 0.8876184285714286, 0.6634765714285715], 
             UndirectedEdge[174, 246] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[218, 329] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[186, 188] -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 
             UndirectedEdge[230, 245] -> 
             RGBColor[
              0.9709799285714285, 0.9466688571428572, 0.639678642857143], 
             UndirectedEdge[57, 368] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[293, 316] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[8, 308] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[37, 361] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[19, 331] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[98, 276] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[326, 336] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             UndirectedEdge[4, 13] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[137, 300] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[57, 163] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[28, 304] -> 
             RGBColor[
              0.9563532142857143, 0.8541327142857142, 0.5038997142857143], 
             UndirectedEdge[83, 328] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[206, 321] -> 
             RGBColor[
              0.9308176428571429, 0.8366675714285714, 0.6178465714285715], 
             UndirectedEdge[295, 373] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[29, 235] -> 
             RGBColor[
              0.9037887857142857, 0.7181937142857143, 0.5955132857142857], 
             UndirectedEdge[234, 392] -> 
             RGBColor[
              0.5607767857142857, 0.6310627857142856, 0.9577517142857144], 
             UndirectedEdge[42, 275] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[107, 324] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[75, 329] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[267, 383] -> 
             RGBColor[
              0.9455993571428571, 0.8952721428571428, 0.6297402857142858], 
             UndirectedEdge[253, 362] -> 
             RGBColor[
              0.9367337142857142, 0.9505314285714286, 0.9240652142857144], 
             UndirectedEdge[137, 252] -> 
             RGBColor[
              0.9143667142857141, 0.9343765714285714, 0.9855006428571429], 
             UndirectedEdge[131, 203] -> 
             RGBColor[
              0.9399022857142857, 0.9518417142857143, 0.8715537857142858], 
             UndirectedEdge[52, 199] -> 
             RGBColor[0.8958035, 0.8876184285714286, 0.6634765714285715], 
             UndirectedEdge[41, 386] -> 
             RGBColor[
              0.9172472142857143, 0.6531244285714286, 0.47040450000000006`], 
             UndirectedEdge[59, 122] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[32, 172] -> 
             RGBColor[
              0.9446727857142856, 0.8470007142857143, 0.5943934285714286], 
             UndirectedEdge[55, 156] -> 
             RGBColor[
              0.8842780714285714, 0.8465548571428572, 0.6300850714285715], 
             UndirectedEdge[97, 214] -> 
             RGBColor[
              0.9367337142857142, 0.9505314285714286, 0.9240652142857144], 
             UndirectedEdge[133, 155] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[186, 273] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[74, 179] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[10, 62] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[273, 322] -> 
             RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 
             UndirectedEdge[18, 148] -> 
             RGBColor[
              0.9288649285714285, 0.9139807142857144, 0.6666300000000001], 
             UndirectedEdge[78, 172] -> 
             RGBColor[
              0.9025577857142857, 0.8143125714285715, 0.6213447857142858], 
             UndirectedEdge[84, 269] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[103, 254] -> 
             RGBColor[
              0.7928449999999999, 0.8380041428571428, 0.9489790714285715], 
             UndirectedEdge[46, 343] -> 
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717], 
             UndirectedEdge[1, 317] -> 
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717], 
             UndirectedEdge[27, 399] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[247, 253] -> 
             RGBColor[
              0.9399022857142857, 0.9518417142857143, 0.8715537857142858], 
             UndirectedEdge[27, 357] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[41, 55] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[183, 272] -> 
             RGBColor[
              0.8951604285714285, 0.9183474285714286, 0.9588940714285714], 
             UndirectedEdge[131, 238] -> 
             RGBColor[0.607753, 0.6858761428571428, 0.9656044285714286], 
             UndirectedEdge[13, 131] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[55, 328] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[40, 392] -> 
             RGBColor[0.49945550000000005`, 0.5823455, 0.9580965], 
             UndirectedEdge[39, 347] -> 
             RGBColor[0.894471, 0.5250334285714287, 0.2542395714285715], 
             UndirectedEdge[195, 362] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[46, 250] -> 
             RGBColor[
              0.9705375714285714, 0.9100928571428573, 0.35142707142857166`], 
             UndirectedEdge[22, 47] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.49249071428571434`], 
             UndirectedEdge[79, 100] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[45, 148] -> 
             RGBColor[
              0.8886209285714286, 0.7552864285714288, 0.6099357857142857], 
             UndirectedEdge[65, 68] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[86, 162] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[3, 264] -> 
             RGBColor[
              0.7499163571428571, 0.7986425714285714, 0.6898670000000002], 
             UndirectedEdge[55, 386] -> 
             RGBColor[
              0.8303903571428572, 0.5869420000000001, 0.5846961428571429], 
             UndirectedEdge[315, 362] -> 
             RGBColor[
              0.9531846428571429, 0.8528224285714285, 0.556411142857143], 
             UndirectedEdge[92, 182] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[202, 341] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[86, 125] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[155, 353] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[119, 235] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             UndirectedEdge[139, 204] -> 
             RGBColor[0.5978679285714286, 0.6700479285714285, 0.959864], 
             UndirectedEdge[167, 174] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285716], 
             UndirectedEdge[218, 349] -> 
             RGBColor[
              0.9393049285714286, 0.9491972857142857, 0.7071874285714288], 
             UndirectedEdge[362, 397] -> 
             RGBColor[
              0.9036722857142857, 0.9241691428571428, 0.9209117857142859], 
             UndirectedEdge[70, 108] -> 
             RGBColor[
              0.9531846428571429, 0.8528224285714285, 0.556411142857143], 
             UndirectedEdge[71, 157] -> 
             RGBColor[
              0.9565498571428572, 0.8531865714285715, 0.42595535714285754`], 
             UndirectedEdge[186, 238] -> 
             RGBColor[
              0.6498679999999999, 0.7185642857142857, 0.9386530714285715], 
             UndirectedEdge[51, 246] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[109, 305] -> 
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717], 
             UndirectedEdge[125, 248] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[106, 390] -> 
             RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 
             UndirectedEdge[1, 231] -> 
             RGBColor[
              0.9288649285714285, 0.9139807142857144, 0.6666300000000001], 
             UndirectedEdge[104, 399] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[244, 366] -> 
             RGBColor[
              0.9055667857142857, 0.6459924285714287, 0.5608982142857143], 
             UndirectedEdge[64, 289] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[160, 233] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[100, 302] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[177, 337] -> 
             RGBColor[
              0.9709799285714285, 0.9466688571428572, 0.639678642857143], 
             UndirectedEdge[124, 219] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[2, 181] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[185, 198] -> 
             RGBColor[
              0.9174438571428571, 0.6521782857142857, 0.39246014285714326`], 
             UndirectedEdge[11, 35] -> 
             RGBColor[
              0.9426130000000001, 0.7941604285714288, 0.4145463571428576], 
             UndirectedEdge[5, 56] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[69, 107] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[51, 350] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[226, 392] -> 
             RGBColor[
              0.5325169285714285, 0.6087077857142857, 0.9612499285714287], 
             UndirectedEdge[81, 292] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[51, 272] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[10, 261] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             UndirectedEdge[132, 244] -> 
             RGBColor[
              0.9172472142857143, 0.6531244285714286, 0.47040450000000006`], 
             UndirectedEdge[53, 376] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[242, 364] -> 
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717], 
             UndirectedEdge[29, 327] -> 
             RGBColor[
              0.9037887857142857, 0.7181937142857143, 0.5955132857142857], 
             UndirectedEdge[328, 364] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[257, 279] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[13, 322] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[21, 24] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[56, 122] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[87, 393] -> 
             RGBColor[
              0.8886209285714286, 0.7552864285714288, 0.6099357857142857], 
             UndirectedEdge[27, 74] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[93, 288] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[125, 211] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[265, 304] -> 
             RGBColor[
              0.9563532142857143, 0.8541327142857142, 0.5038997142857143], 
             UndirectedEdge[195, 343] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[199, 393] -> 
             RGBColor[
              0.9288649285714285, 0.9139807142857144, 0.6666300000000001], 
             UndirectedEdge[24, 208] -> 
             RGBColor[
              0.9446727857142856, 0.8470007142857143, 0.5943934285714286], 
             UndirectedEdge[135, 386] -> 
             RGBColor[
              0.8917116428571428, 0.6356592857142858, 0.5843513571428571], 
             UndirectedEdge[32, 357] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[230, 233] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[46, 161] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[114, 306] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[233, 357] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[134, 395] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[108, 267] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[217, 233] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[245, 400] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[269, 392] -> 
             RGBColor[
              0.5863123571428571, 0.6485279285714286, 0.8438048571428571], 
             UndirectedEdge[232, 288] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[260, 341] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[47, 323] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.4924907142857144], 
             UndirectedEdge[142, 377] -> 
             RGBColor[
              0.9308176428571429, 0.8366675714285714, 0.6178465714285715], 
             UndirectedEdge[53, 117] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[251, 308] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[85, 162] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[249, 397] -> 
             RGBColor[
              0.8951604285714285, 0.9183474285714286, 0.9588940714285714], 
             UndirectedEdge[262, 284] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[307, 341] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[7, 387] -> 
             RGBColor[
              0.9705375714285714, 0.9100928571428573, 0.35142707142857166`], 
             UndirectedEdge[228, 368] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[240, 399] -> 
             RGBColor[
              0.9563532142857143, 0.8541327142857142, 0.5038997142857143], 
             UndirectedEdge[105, 114] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[78, 357] -> 
             RGBColor[
              0.9399022857142857, 0.9518417142857143, 0.8715537857142858], 
             UndirectedEdge[359, 369] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[48, 354] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[280, 325] -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714287], 
             UndirectedEdge[259, 262] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[120, 187] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[70, 198] -> 
             RGBColor[
              0.9565498571428572, 0.8531865714285715, 0.42595535714285754`], 
             UndirectedEdge[62, 235] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[65, 176] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[199, 342] -> 
             RGBColor[
              0.9709799285714285, 0.9466688571428572, 0.639678642857143], 
             UndirectedEdge[324, 390] -> 
             RGBColor[
              0.9455993571428571, 0.8952721428571428, 0.6297402857142858], 
             UndirectedEdge[226, 234] -> 
             RGBColor[
              0.9143667142857141, 0.9343765714285714, 0.9855006428571429], 
             UndirectedEdge[47, 201] -> 
             RGBColor[
              0.9313790000000001, 0.7572455714285717, 0.2875669285714287], 
             UndirectedEdge[160, 264] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285717], 
             UndirectedEdge[277, 314] -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 
             UndirectedEdge[4, 66] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[23, 75] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[287, 391] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[45, 91] -> 
             RGBColor[0.8555595, 0.7289241428571431, 0.6067823571428572], 
             UndirectedEdge[175, 314] -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 
             UndirectedEdge[195, 358] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[321, 341] -> 
             RGBColor[
              0.9531846428571429, 0.8528224285714285, 0.556411142857143], 
             UndirectedEdge[91, 148] -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714287], 
             UndirectedEdge[115, 350] -> 
             RGBColor[
              0.9418190000000001, 0.7924621428571431, 0.32812435714285737`], 
             UndirectedEdge[142, 277] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[45, 66] -> 
             RGBColor[
              0.9426130000000001, 0.7941604285714288, 0.4145463571428576], 
             UndirectedEdge[259, 335] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[118, 173] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[52, 128] -> 
             RGBColor[
              0.8842780714285714, 0.8465548571428572, 0.6300850714285715], 
             UndirectedEdge[27, 225] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[302, 352] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[25, 242] -> 
             RGBColor[
              0.9709799285714285, 0.9466688571428572, 0.6396786428571429], 
             UndirectedEdge[30, 224] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[313, 361] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[270, 310] -> 
             RGBColor[
              0.8694963571428571, 0.7879502857142857, 0.6181913571428572], 
             UndirectedEdge[72, 370] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[283, 380] -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714287], 
             UndirectedEdge[34, 35] -> 
             RGBColor[
              0.9426130000000001, 0.7941604285714288, 0.4145463571428576], 
             UndirectedEdge[25, 230] -> 
             RGBColor[
              0.9709799285714285, 0.9466688571428572, 0.6396786428571429], 
             UndirectedEdge[191, 211] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[17, 173] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[40, 51] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[105, 202] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285717], 
             UndirectedEdge[183, 309] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[187, 261] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[190, 274] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[176, 354] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[42, 148] -> 
             RGBColor[
              0.9399022857142857, 0.9518417142857143, 0.8715537857142858], 
             UndirectedEdge[320, 380] -> 
             RGBColor[
              0.8861068571428571, 0.9120215714285714, 0.9889988571428572], 
             UndirectedEdge[51, 222] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[122, 319] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[27, 78] -> 
             RGBColor[
              0.9367337142857142, 0.9505314285714286, 0.9240652142857144], 
             UndirectedEdge[5, 178] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[196, 336] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             UndirectedEdge[297, 318] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[127, 235] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[45, 203] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285717, 0.4924907142857144], 
             UndirectedEdge[305, 370] -> 
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717], 
             UndirectedEdge[122, 169] -> 
             RGBColor[
              0.9261557857142857, 0.7343485714285716, 0.5340778571428573], 
             UndirectedEdge[51, 226] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[226, 395] -> 
             RGBColor[
              0.9143667142857141, 0.9343765714285714, 0.9855006428571429], 
             UndirectedEdge[61, 354] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[211, 334] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[10, 361] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             UndirectedEdge[44, 249] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285716], 
             UndirectedEdge[302, 377] -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 
             UndirectedEdge[149, 363] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[358, 359] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[126, 317] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285717], 
             UndirectedEdge[194, 364] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[184, 343] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[118, 346] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[169, 239] -> 
             RGBColor[
              0.8919798571428572, 0.5981297142857144, 0.2313574285714286], 
             UndirectedEdge[72, 157] -> 
             RGBColor[
              0.9308176428571429, 0.8366675714285714, 0.6178465714285715], 
             UndirectedEdge[162, 191] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[84, 272] -> 
             RGBColor[0.819984, 0.859297, 0.982692], UndirectedEdge[21, 160] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[29, 336] -> 
             RGBColor[
              0.9037887857142857, 0.7181937142857143, 0.5955132857142857], 
             UndirectedEdge[275, 276] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[38, 303] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[172, 285] -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 
             UndirectedEdge[73, 285] -> 
             RGBColor[
              0.9600975714285714, 0.8748762857142858, 0.3108696428571429], 
             UndirectedEdge[5, 59] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[73, 225] -> 
             RGBColor[
              0.9600975714285714, 0.8748762857142858, 0.3108696428571429], 
             UndirectedEdge[64, 254] -> 
             RGBColor[
              0.8045254285714285, 0.8451361428571429, 0.8584853571428572], 
             UndirectedEdge[241, 390] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[58, 289] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[262, 331] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[22, 118] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[97, 360] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[301, 358] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[16, 274] -> 
             RGBColor[
              0.8045254285714285, 0.8451361428571429, 0.8584853571428572], 
             UndirectedEdge[166, 319] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[82, 101] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[24, 399] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[328, 400] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[17, 371] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[107, 158] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[60, 394] -> 
             RGBColor[
              0.9367337142857142, 0.9505314285714286, 0.9240652142857144], 
             UndirectedEdge[219, 284] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[124, 149] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[227, 296] -> 
             RGBColor[
              0.8529222857142856, 0.8845228571428572, 0.9158535000000001], 
             UndirectedEdge[202, 229] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[315, 358] -> 
             RGBColor[
              0.9563532142857143, 0.8541327142857142, 0.5038997142857143], 
             UndirectedEdge[145, 222] -> 
             RGBColor[
              0.8694963571428571, 0.7879502857142857, 0.6181913571428572], 
             UndirectedEdge[155, 299] -> 
             RGBColor[
              0.9288649285714285, 0.9139807142857144, 0.6666300000000001], 
             UndirectedEdge[14, 29] -> 
             RGBColor[
              0.9067615714285715, 0.6567342857142858, 0.2432511428571429], 
             UndirectedEdge[116, 151] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[45, 257] -> 
             RGBColor[
              0.9392477857142858, 0.793796285714286, 0.545002142857143], 
             UndirectedEdge[27, 240] -> 
             RGBColor[
              0.9531846428571429, 0.8528224285714285, 0.556411142857143], 
             UndirectedEdge[144, 188] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285716], 
             UndirectedEdge[76, 200] -> 
             RGBColor[
              0.8013568571428571, 0.8438258571428572, 0.9109967857142858], 
             UndirectedEdge[90, 221] -> 
             RGBColor[
              0.9367337142857142, 0.9505314285714286, 0.9240652142857144], 
             UndirectedEdge[271, 382] -> 
             RGBColor[
              0.9563532142857143, 0.8541327142857142, 0.5038997142857143], 
             UndirectedEdge[242, 385] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[74, 112] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[237, 251] -> 
             RGBColor[
              0.9367337142857142, 0.9505314285714286, 0.9240652142857144], 
             UndirectedEdge[25, 223] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[284, 332] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[145, 333] -> 
             RGBColor[
              0.9190087142857143, 0.7166035714285715, 0.2536907142857143], 
             UndirectedEdge[146, 227] -> 
             RGBColor[
              0.8529222857142856, 0.8845228571428572, 0.9158535000000001], 
             UndirectedEdge[108, 286] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[127, 361] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[143, 258] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[212, 310] -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 
             UndirectedEdge[107, 310] -> 
             RGBColor[
              0.9565498571428572, 0.8531865714285715, 0.42595535714285754`], 
             UndirectedEdge[253, 394] -> 
             RGBColor[
              0.8861068571428571, 0.9120215714285714, 0.9889988571428572], 
             UndirectedEdge[152, 284] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[230, 364] -> 
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717], 
             UndirectedEdge[158, 241] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[44, 315] -> 
             RGBColor[
              0.9557558571428572, 0.8514882857142858, 0.3395333571428574], 
             UndirectedEdge[357, 385] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[99, 197] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[152, 267] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[169, 197] -> 
             RGBColor[
              0.9261557857142857, 0.7343485714285716, 0.5340778571428573], 
             UndirectedEdge[263, 348] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[314, 379] -> 
             RGBColor[
              0.9709799285714285, 0.9466688571428572, 0.639678642857143], 
             UndirectedEdge[300, 319] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[25, 78] -> 
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475], 
             UndirectedEdge[44, 113] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[115, 221] -> 
             RGBColor[
              0.9392477857142858, 0.793796285714286, 0.545002142857143], 
             UndirectedEdge[175, 319] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[176, 356] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[84, 395] -> 
             RGBColor[
              0.8813052857142857, 0.9080142857142857, 0.9823472142857144], 
             UndirectedEdge[301, 359] -> 
             RGBColor[
              0.8813052857142857, 0.9080142857142857, 0.9823472142857144], 
             UndirectedEdge[238, 280] -> 
             RGBColor[0.607753, 0.6858761428571428, 0.9656044285714286], 
             UndirectedEdge[36, 168] -> 
             RGBColor[
              0.8842780714285714, 0.8465548571428572, 0.6300850714285715], 
             UndirectedEdge[4, 232] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[140, 339] -> 
             RGBColor[
              0.8842780714285714, 0.8465548571428572, 0.6300850714285715], 
             UndirectedEdge[18, 141] -> 
             RGBColor[
              0.9600975714285714, 0.8748762857142858, 0.3108696428571429], 
             UndirectedEdge[123, 140] -> 
             RGBColor[0.8555595, 0.7289241428571431, 0.6067823571428572], 
             UndirectedEdge[24, 78] -> 
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475], 
             UndirectedEdge[62, 127] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[299, 353] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[256, 311] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[47, 346] -> 
             RGBColor[
              0.9426130000000001, 0.7941604285714288, 0.4145463571428576], 
             UndirectedEdge[34, 125] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[194, 387] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[117, 303] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[287, 382] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[20, 168] -> 
             RGBColor[
              0.5637495714285714, 0.5696033571428571, 0.6054895714285715], 
             UndirectedEdge[51, 355] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[183, 339] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[118, 164] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[51, 134] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[46, 356] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[204, 276] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[108, 154] -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             UndirectedEdge[29, 119] -> 
             RGBColor[
              0.9037887857142857, 0.7181937142857143, 0.5955132857142857], 
             UndirectedEdge[244, 264] -> 
             RGBColor[
              0.9166498571428572, 0.6504800000000002, 0.30603814285714304`], 
             UndirectedEdge[217, 321] -> 
             RGBColor[
              0.9453158571428572, 0.8162717142857143, 0.29897592857142863`], 
             UndirectedEdge[241, 346] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[108, 284] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[181, 334] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[8, 59] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             UndirectedEdge[236, 383] -> 
             RGBColor[
              0.9705375714285714, 0.9100928571428573, 0.35142707142857166`], 
             UndirectedEdge[42, 290] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[173, 209] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[154, 332] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[5, 352] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[189, 226] -> 
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475], 
             UndirectedEdge[16, 390] -> 
             RGBColor[
              0.7819626428571429, 0.7662115714285714, 0.6201700714285714], 
             UndirectedEdge[119, 327] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             UndirectedEdge[129, 231] -> 
             RGBColor[0.9173395, 0.872917142857143, 0.6332385], 
             UndirectedEdge[79, 352] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[62, 361] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[150, 347] -> 
             RGBColor[
              0.9600975714285714, 0.8748762857142858, 0.3108696428571429], 
             UndirectedEdge[5, 90] -> 
             RGBColor[
              0.9367337142857142, 0.9505314285714286, 0.9240652142857144], 
             UndirectedEdge[24, 27] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[62, 393] -> 
             RGBColor[
              0.9399022857142857, 0.9518417142857143, 0.8715537857142858], 
             UndirectedEdge[199, 353] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[96, 201] -> 
             RGBColor[
              0.9600975714285714, 0.8748762857142858, 0.3108696428571429], 
             UndirectedEdge[155, 170] -> 
             RGBColor[
              0.9367337142857142, 0.9505314285714286, 0.9240652142857144], 
             UndirectedEdge[335, 394] -> 
             RGBColor[
              0.9393049285714286, 0.9491972857142857, 0.7071874285714288], 
             UndirectedEdge[16, 310] -> 
             RGBColor[0.7671809285714286, 0.707607, 0.6082763571428571], 
             UndirectedEdge[6, 277] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[140, 232] -> 
             RGBColor[
              0.8951604285714285, 0.9183474285714286, 0.9588940714285714], 
             UndirectedEdge[177, 300] -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 
             UndirectedEdge[24, 32] -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 
             UndirectedEdge[102, 226] -> 
             RGBColor[0.9173395, 0.872917142857143, 0.6332385], 
             UndirectedEdge[187, 206] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[336, 396] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[267, 332] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[115, 300] -> 
             RGBColor[
              0.9313790000000001, 0.7572455714285717, 0.2875669285714287], 
             UndirectedEdge[149, 195] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[127, 396] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[206, 220] -> 
             RGBColor[
              0.9455993571428571, 0.8952721428571428, 0.6297402857142858], 
             UndirectedEdge[298, 361] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[27, 141] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[55, 221] -> 
             RGBColor[
              0.9036722857142857, 0.9241691428571428, 0.9209117857142859], 
             UndirectedEdge[40, 269] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[191, 312] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[78, 240] -> 
             RGBColor[
              0.9025577857142857, 0.8143125714285715, 0.6213447857142858], 
             UndirectedEdge[183, 246] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[130, 164] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[190, 295] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[18, 179] -> 
             RGBColor[0.8958035, 0.8876184285714286, 0.6634765714285715], 
             UndirectedEdge[128, 199] -> 
             RGBColor[
              0.9600975714285714, 0.8748762857142858, 0.3108696428571429], 
             UndirectedEdge[350, 355] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[233, 348] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[247, 316] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[74, 399] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[155, 171] -> 
             RGBColor[
              0.9399022857142857, 0.9518417142857143, 0.8715537857142858], 
             UndirectedEdge[21, 95] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[257, 325] -> 
             RGBColor[
              0.9036722857142857, 0.9241691428571428, 0.9209117857142859], 
             UndirectedEdge[250, 372] -> 
             RGBColor[
              0.9455993571428571, 0.8952721428571428, 0.6297402857142858], 
             UndirectedEdge[156, 400] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[193, 360] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[92, 135] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[102, 174] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[140, 275] -> 
             RGBColor[0.819984, 0.859297, 0.982692], UndirectedEdge[101, 301] -> 
             RGBColor[
              0.9036722857142857, 0.9241691428571428, 0.9209117857142859], 
             UndirectedEdge[337, 398] -> 
             RGBColor[
              0.9709799285714285, 0.9466688571428572, 0.6396786428571429], 
             UndirectedEdge[149, 249] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[92, 165] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[150, 320] -> 
             RGBColor[0.9173395, 0.872917142857143, 0.6332385], 
             UndirectedEdge[59, 175] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[278, 379] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[87, 317] -> 
             RGBColor[
              0.9418190000000001, 0.7924621428571431, 0.32812435714285737`], 
             UndirectedEdge[212, 324] -> 
             RGBColor[
              0.9455993571428571, 0.8952721428571428, 0.6297402857142858], 
             UndirectedEdge[135, 328] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[176, 344] -> 
             RGBColor[
              0.9600975714285714, 0.8748762857142858, 0.3108696428571429], 
             UndirectedEdge[59, 213] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714288, 0.6064375714285715], 
             UndirectedEdge[371, 391] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[98, 318] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[25, 244] -> 
             RGBColor[
              0.9055667857142857, 0.6459924285714286, 0.5608982142857144], 
             UndirectedEdge[204, 224] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[180, 236] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[102, 163] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[16, 107] -> 
             RGBColor[0.8047220714285714, 0.84419, 0.7805410000000004], 
             UndirectedEdge[194, 223] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[111, 291] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[108, 205] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[66, 297] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[19, 284] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[23, 260] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[10, 256] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[230, 242] -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 
             UndirectedEdge[29, 317] -> 
             RGBColor[
              0.9287270000000001, 0.7330144285714286, 0.31720007142857165`], 
             UndirectedEdge[124, 316] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[306, 361] -> 
             RGBColor[
              0.8813052857142857, 0.9080142857142857, 0.9823472142857144], 
             UndirectedEdge[1, 393] -> 
             RGBColor[
              0.9288649285714285, 0.9139807142857144, 0.6666300000000001], 
             UndirectedEdge[74, 279] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[40, 234] -> 
             RGBColor[
              0.8813052857142857, 0.9080142857142857, 0.9823472142857144], 
             UndirectedEdge[195, 316] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[279, 325] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[172, 337] -> 
             RGBColor[
              0.9446727857142856, 0.8470007142857143, 0.5943934285714286], 
             UndirectedEdge[148, 275] -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714287], 
             UndirectedEdge[13, 188] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[220, 233] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[230, 244] -> 
             RGBColor[
              0.9062098571428572, 0.6152634285714287, 0.26548071428571435`], 
             UndirectedEdge[253, 358] -> 
             RGBColor[
              0.9399022857142857, 0.9518417142857143, 0.8715537857142858], 
             UndirectedEdge[66, 140] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[89, 128] -> 
             RGBColor[
              0.9455993571428571, 0.8952721428571428, 0.6297402857142858], 
             UndirectedEdge[199, 298] -> 
             RGBColor[
              0.9828570000000001, 0.9528547142857144, 0.4712405714285719], 
             UndirectedEdge[367, 398] -> 
             RGBColor[
              0.9709799285714285, 0.9466688571428572, 0.6396786428571429], 
             UndirectedEdge[72, 181] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[229, 329] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[196, 326] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             UndirectedEdge[247, 362] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[276, 297] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[7, 201] -> 
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717], 
             UndirectedEdge[191, 214] -> 
             RGBColor[
              0.9399022857142857, 0.9518417142857143, 0.8715537857142858], 
             UndirectedEdge[25, 32] -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 
             UndirectedEdge[190, 324] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             UndirectedEdge[8, 296] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[292, 382] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[223, 328] -> 
             RGBColor[
              0.9683587857142857, 0.9732505714285714, 0.7901112142857147], 
             UndirectedEdge[70, 262] -> 
             RGBColor[
              0.9308176428571429, 0.8366675714285714, 0.6178465714285715], 
             UndirectedEdge[78, 285] -> 
             RGBColor[0.9173395, 0.872917142857143, 0.6332385], 
             UndirectedEdge[167, 272] -> 
             RGBColor[0.9062435, 0.9228350000000001, 0.7040340000000003], 
             UndirectedEdge[93, 276] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[56, 319] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[93, 162] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[106, 389] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[68, 176] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[253, 301] -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714287], 
             UndirectedEdge[217, 357] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[364, 385] -> 
             RGBColor[
              0.9931003571428572, 0.9890174285714286, 0.5897423571428574], 
             UndirectedEdge[161, 372] -> 
             RGBColor[
              0.9649935714285713, 0.9728864285714285, 0.9205670000000001], 
             UndirectedEdge[4, 339] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[183, 280] -> 
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475], 
             UndirectedEdge[94, 145] -> 
             RGBColor[
              0.9446727857142856, 0.8470007142857143, 0.5943934285714286], 
             UndirectedEdge[107, 351] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[90, 178] -> 
             RGBColor[0.9173395, 0.872917142857143, 0.6332385], 
             UndirectedEdge[113, 124] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[191, 365] -> 
             RGBColor[
              0.8045254285714285, 0.8451361428571429, 0.8584853571428572], 
             UndirectedEdge[184, 356] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[196, 327] -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             UndirectedEdge[140, 288] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[13, 232] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[34, 86] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[287, 374] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[201, 230] -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 
             UndirectedEdge[71, 138] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[334, 360] -> 
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717], 
             UndirectedEdge[38, 58] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[115, 239] -> 
             RGBColor[
              0.9050718571428572, 0.6575774285714289, 0.24228171428571435`], 
             UndirectedEdge[32, 78] -> 
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475], 
             UndirectedEdge[41, 83] -> 
             RGBColor[
              0.9938943571428571, 0.9907157142857144, 0.6761643571428575], 
             UndirectedEdge[90, 212] -> 
             RGBColor[0.9173395, 0.872917142857143, 0.6332385], 
             UndirectedEdge[160, 263] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[226, 350] -> 
             RGBColor[
              0.9393049285714286, 0.9491972857142857, 0.7071874285714288], 
             UndirectedEdge[159, 329] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[132, 260] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[7, 250] -> 
             RGBColor[
              0.9705375714285714, 0.9100928571428573, 0.35142707142857166`], 
             UndirectedEdge[135, 281] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[240, 243] -> 
             RGBColor[
              0.9531846428571429, 0.8528224285714285, 0.556411142857143], 
             UndirectedEdge[105, 349] -> 
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475], 
             UndirectedEdge[111, 154] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[3, 233] -> 
             RGBColor[
              0.750710357142857, 0.8003408571428572, 0.7762890000000005], 
             UndirectedEdge[125, 162] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[301, 369] -> 
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004], 
             UndirectedEdge[268, 270] -> 
             RGBColor[
              0.8951604285714285, 0.9183474285714286, 0.9588940714285714], 
             UndirectedEdge[4, 188] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[161, 176] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[106, 270] -> 
             RGBColor[
              0.8842780714285714, 0.8465548571428572, 0.6300850714285715], 
             UndirectedEdge[190, 268] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[220, 341] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[76, 103] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[84, 163] -> 
             RGBColor[
              0.9036722857142857, 0.9241691428571428, 0.9209117857142859], 
             UndirectedEdge[356, 372] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715], 
             UndirectedEdge[243, 398] -> 
             RGBColor[
              0.9794917857142857, 0.9524905714285715, 0.6016963571428573], 
             UndirectedEdge[141, 243] -> 
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573], 
             UndirectedEdge[192, 320] -> 
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475], 
             UndirectedEdge[83, 245] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[256, 313] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[144, 186] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285716], 
             UndirectedEdge[271, 371] -> 
             RGBColor[
              0.9446727857142856, 0.8470007142857143, 0.5943934285714286], 
             UndirectedEdge[317, 326] -> 
             RGBColor[
              0.9675647857142857, 0.9715522857142858, 0.7036892142857145], 
             UndirectedEdge[194, 242] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[305, 334] -> 
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717], 
             UndirectedEdge[252, 282] -> 
             RGBColor[
              0.9399022857142857, 0.9518417142857143, 0.8715537857142858], 
             UndirectedEdge[134, 239] -> 
             RGBColor[
              0.9446727857142856, 0.8470007142857143, 0.5943934285714286], 
             UndirectedEdge[267, 398] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[4, 297] -> 
             RGBColor[
              0.9932970000000001, 0.9880712857142857, 0.5117980000000005], 
             UndirectedEdge[40, 272] -> 
             RGBColor[0.819984, 0.859297, 0.982692], UndirectedEdge[203, 325] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[315, 359] -> 
             RGBColor[
              0.9308176428571429, 0.8366675714285714, 0.6178465714285715], 
             UndirectedEdge[132, 160] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[283, 381] -> 
             RGBColor[
              0.9068408571428572, 0.9254794285714285, 0.8684003571428571], 
             UndirectedEdge[40, 183] -> 
             RGBColor[
              0.8951604285714285, 0.9183474285714286, 0.9588940714285714], 
             UndirectedEdge[131, 339] -> 
             RGBColor[0.9173395, 0.872917142857143, 0.6332385], 
             UndirectedEdge[156, 165] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[352, 379] -> 
             RGBColor[
              0.9822139285714285, 0.9835837142857142, 0.7666580714285718], 
             UndirectedEdge[25, 194] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[174, 238] -> 
             RGBColor[
              0.6498679999999999, 0.7185642857142857, 0.9386530714285715], 
             UndirectedEdge[66, 339] -> 
             RGBColor[
              0.9713315714285715, 0.9117911428571429, 0.4378490714285718], 
             UndirectedEdge[67, 387] -> 
             RGBColor[
              0.8946844285714286, 0.5741998571428573, 0.23208921428571433`], 
             UndirectedEdge[90, 190] -> 
             RGBColor[
              0.9143667142857141, 0.9343765714285714, 0.9855006428571429], 
             UndirectedEdge[271, 389] -> 
             RGBColor[
              0.9565498571428572, 0.8531865714285715, 0.42595535714285754`], 
             UndirectedEdge[19, 293] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[126, 327] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[12, 310] -> 
             RGBColor[
              0.9190087142857143, 0.7166035714285715, 0.2536907142857143], 
             UndirectedEdge[272, 350] -> 
             RGBColor[0.9062435, 0.9228350000000001, 0.7040340000000002], 
             UndirectedEdge[215, 229] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[57, 189] -> 
             RGBColor[
              0.9564817142857142, 0.9670647142857143, 0.9585492857142858], 
             UndirectedEdge[104, 337] -> 
             RGBColor[
              0.9814199285714285, 0.9818854285714286, 0.6802360714285716], 
             UndirectedEdge[194, 385] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[56, 166] -> 
             RGBColor[
              0.9907257857142857, 0.9894054285714287, 0.7286757857142863], 
             UndirectedEdge[258, 379] -> 
             RGBColor[
              0.9788487142857142, 0.9832195714285714, 0.8971138571428573], 
             UndirectedEdge[9, 150] -> 
             RGBColor[
              0.8842780714285714, 0.8465548571428572, 0.6300850714285715], 
             UndirectedEdge[294, 380] -> 
             RGBColor[
              0.9400989285714285, 0.9508955714285714, 0.793609428571429], 
             UndirectedEdge[296, 308] -> 
             RGBColor[
              0.9899317857142858, 0.9877071428571429, 0.642253785714286], 
             UndirectedEdge[33, 92] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[39, 283] -> 
             RGBColor[0.8186515000000001, 0.496712, 0.573455], 
             UndirectedEdge[11, 34] -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             UndirectedEdge[105, 171] -> 
             RGBColor[
              0.9820172857142857, 0.9845298571428571, 0.8446024285714286], 
             UndirectedEdge[110, 237] -> 
             RGBColor[
              0.8886209285714286, 0.7552864285714288, 0.6099357857142857], 
             UndirectedEdge[8, 175] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142858], 
             UndirectedEdge[90, 373] -> 
             RGBColor[
              0.9393049285714286, 0.9491972857142857, 0.7071874285714288], 
             UndirectedEdge[73, 104] -> 
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717], 
             UndirectedEdge[232, 339] -> 
             RGBColor[
              0.9594544999999999, 0.9056052857142858, 0.6062871428571429], 
             UndirectedEdge[178, 274] -> 
             RGBColor[
              0.9711349285714286, 0.9127372857142857, 0.5157934285714286], 
             UndirectedEdge[224, 318] -> 
             RGBColor[
              0.9905291428571428, 0.9903515714285714, 0.806620142857143], 
             UndirectedEdge[132, 307] -> 
             RGBColor[
              0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {400}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.9190087142857143, 0.7166035714285715, 0.2536907142857143], 
             316 -> RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 
             308 -> RGBColor[0.992503, 0.986373, 0.42537600000000036`], 160 -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 245 -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 155 -> 
             RGBColor[
              0.8861068571428571, 0.9120215714285714, 0.9889988571428572], 
             213 -> RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             352 -> RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 27 -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             367 -> RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 19 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             164 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             190 -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             103 -> RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 138 -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 291 -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 28 -> 
             RGBColor[
              0.9190087142857143, 0.7166035714285715, 0.2536907142857143], 
             337 -> RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 195 -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             114 -> RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 93 -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 34 -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             161 -> RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 22 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             124 -> RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 84 -> 
             RGBColor[0.819984, 0.859297, 0.982692], 46 -> 
             RGBColor[0.992503, 0.986373, 0.42537600000000036`], 241 -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 185 -> 
             RGBColor[
              0.8407967142857143, 0.3145870000000001, 0.18670028571428574`], 
             390 -> RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 
             121 -> RGBColor[0.992503, 0.986373, 0.42537600000000036`], 322 -> 
             RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 
             126 -> RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 236 -> 
             RGBColor[0.992503, 0.986373, 0.42537600000000036`], 78 -> 
             RGBColor[
              0.8861068571428571, 0.9120215714285714, 0.9889988571428572], 
             376 -> RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             254 -> RGBColor[
              0.6153531428571428, 0.6986104285714285, 0.962862], 290 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 251 -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             165 -> RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 100 -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             235 -> RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 70 -> 
             RGBColor[
              0.9190087142857143, 0.7166035714285715, 0.2536907142857143], 
             234 -> RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             257 -> RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             135 -> RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             265 -> RGBColor[
              0.9190087142857143, 0.7166035714285715, 0.2536907142857143], 
             111 -> RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 381 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             182 -> RGBColor[0.971623, 0.9159398571428573, 0.344261142857143],
              188 -> RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 154 -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             336 -> RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             315 -> RGBColor[
              0.9190087142857143, 0.7166035714285715, 0.2536907142857143], 
             368 -> RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             269 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             208 -> RGBColor[
              0.9190087142857143, 0.7166035714285715, 0.2536907142857143], 86 -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             119 -> RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             377 -> RGBColor[
              0.9190087142857143, 0.7166035714285715, 0.2536907142857143], 
             140 -> RGBColor[0.819984, 0.859297, 0.982692], 85 -> 
             RGBColor[0.992503, 0.986373, 0.42537600000000036`], 351 -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 242 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 117 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 47 -> 
             RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             81 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             275 -> RGBColor[0.819984, 0.859297, 0.982692], 23 -> 
             RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 
             328 -> RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             110 -> RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             6 -> RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             218 -> RGBColor[0.992503, 0.986373, 0.42537600000000036`], 108 -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             297 -> RGBColor[0.992503, 0.986373, 0.42537600000000036`], 157 -> 
             RGBColor[
              0.9190087142857143, 0.7166035714285715, 0.2536907142857143], 
             354 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             385 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             270 -> RGBColor[0.819984, 0.859297, 0.982692], 392 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 33 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 252 -> 
             RGBColor[
              0.8861068571428571, 0.9120215714285714, 0.9889988571428572], 
             394 -> RGBColor[
              0.8861068571428571, 0.9120215714285714, 0.9889988571428572], 
             260 -> RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             159 -> RGBColor[0.992503, 0.986373, 0.42537600000000036`], 183 -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 99 -> 
             RGBColor[0.992503, 0.986373, 0.42537600000000036`], 329 -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             309 -> RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 17 -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             349 -> 
             RGBColor[
              0.8861068571428571, 0.9120215714285714, 0.9889988571428572], 
             347 -> RGBColor[0.971623, 0.9159398571428573, 0.344261142857143],
              340 -> RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             277 -> RGBColor[0.971623, 0.9159398571428573, 0.344261142857143],
              104 -> RGBColor[0.992503, 0.986373, 0.42537600000000036`], 79 -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             327 -> RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             191 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 50 -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             225 -> RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 61 -> 
             RGBColor[0.819984, 0.859297, 0.982692], 196 -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 1 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 263 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             201 -> RGBColor[0.971623, 0.9159398571428573, 0.344261142857143],
              371 -> RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 293 -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             362 -> RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             184 -> RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             106 -> RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 
             206 -> RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             358 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             247 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             220 -> RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 
             107 -> RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             375 -> RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             131 -> 
             RGBColor[
              0.8861068571428571, 0.9120215714285714, 0.9889988571428572], 
             127 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             210 -> RGBColor[0.817319, 0.134127, 0.164218], 357 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             181 -> RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             194 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             118 -> RGBColor[0.992503, 0.986373, 0.42537600000000036`], 348 -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             276 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             305 -> RGBColor[0.992503, 0.986373, 0.42537600000000036`], 343 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 280 -> 
             RGBColor[
              0.8861068571428571, 0.9120215714285714, 0.9889988571428572], 
             189 -> RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 168 -> 
             RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 
             363 -> RGBColor[0.971623, 0.9159398571428573, 0.344261142857143],
              41 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 14 -> 
             RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 77 -> 
             RGBColor[
              0.8861068571428571, 0.9120215714285714, 0.9889988571428572], 51 -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             179 -> RGBColor[0.819984, 0.859297, 0.982692], 223 -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             323 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             292 -> RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 
             396 -> RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             321 -> RGBColor[
              0.9190087142857143, 0.7166035714285715, 0.2536907142857143], 
             143 -> RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 112 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             197 -> RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 54 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 71 -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             177 -> RGBColor[0.971623, 0.9159398571428573, 0.344261142857143],
              158 -> RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             226 -> RGBColor[
              0.8861068571428571, 0.9120215714285714, 0.9889988571428572], 
             350 -> RGBColor[0.992503, 0.986373, 0.42537600000000036`], 203 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             115 -> RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             173 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             212 -> RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 
             129 -> RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 
             279 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 26 -> 
             RGBColor[
              0.8861068571428571, 0.9120215714285714, 0.9889988571428572], 40 -> 
             RGBColor[0.819984, 0.859297, 0.982692], 146 -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             386 -> RGBColor[
              0.8407967142857143, 0.3145870000000001, 0.18670028571428574`], 
             192 -> RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 300 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 221 -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 62 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             286 -> RGBColor[0.992503, 0.986373, 0.42537600000000036`], 152 -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 64 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             307 -> RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 37 -> 
             RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             148 -> RGBColor[
              0.8861068571428571, 0.9120215714285714, 0.9889988571428572], 
             261 -> RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             387 -> RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 15 -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             136 -> RGBColor[0.992503, 0.986373, 0.42537600000000036`], 198 -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 63 -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 310 -> 
             RGBColor[
              0.9190087142857143, 0.7166035714285715, 0.2536907142857143], 
             171 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             395 -> RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             311 -> RGBColor[0.992503, 0.986373, 0.42537600000000036`], 353 -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 59 -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             397 -> RGBColor[0.819984, 0.859297, 0.982692], 229 -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             102 -> RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 
             299 -> RGBColor[0.971623, 0.9159398571428573, 0.344261142857143],
              128 -> RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 12 -> 
             RGBColor[
              0.9190087142857143, 0.7166035714285715, 0.2536907142857143], 
             222 -> RGBColor[0.819984, 0.859297, 0.982692], 92 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             271 -> RGBColor[
              0.9190087142857143, 0.7166035714285715, 0.2536907142857143], 
             361 -> RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             344 -> RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 
             132 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 80 -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 324 -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             244 -> RGBColor[
              0.8407967142857143, 0.3145870000000001, 0.18670028571428574`], 
             150 -> RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 
             125 -> RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             258 -> RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             133 -> RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             255 -> RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             326 -> RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             176 -> RGBColor[0.971623, 0.9159398571428573, 0.344261142857143],
              230 -> RGBColor[
              0.971623, 0.9159398571428573, 0.344261142857143], 274 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 87 -> 
             RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             130 -> RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 35 -> 
             RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             379 -> RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 31 -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 18 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 24 -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 151 -> 
             RGBColor[0.992503, 0.986373, 0.42537600000000036`], 137 -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             330 -> RGBColor[
              0.8861068571428571, 0.9120215714285714, 0.9889988571428572], 
             296 -> RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             266 -> RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 
             302 -> RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 
             283 -> RGBColor[0.819984, 0.859297, 0.982692], 388 -> 
             RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 
             284 -> RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             318 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             238 -> RGBColor[
              0.3293991428571429, 0.45973071428571427`, 0.94221], 72 -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             288 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             382 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             389 -> RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             172 -> RGBColor[
              0.9190087142857143, 0.7166035714285715, 0.2536907142857143], 
             243 -> RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 88 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             273 -> RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 
             202 -> RGBColor[0.992503, 0.986373, 0.42537600000000036`], 393 -> 
             RGBColor[
              0.8861068571428571, 0.9120215714285714, 0.9889988571428572], 98 -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 30 -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             116 -> RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             373 -> RGBColor[0.992503, 0.986373, 0.42537600000000036`], 240 -> 
             RGBColor[
              0.9190087142857143, 0.7166035714285715, 0.2536907142857143], 
             317 -> RGBColor[0.992503, 0.986373, 0.42537600000000036`], 391 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 73 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 303 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 29 -> 
             RGBColor[0.864951, 0.4796558571428573, 0.20902414285714288`], 
             360 -> RGBColor[0.992503, 0.986373, 0.42537600000000036`], 320 -> 
             RGBColor[
              0.8861068571428571, 0.9120215714285714, 0.9889988571428572], 75 -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             200 -> RGBColor[
              0.6153531428571428, 0.6986104285714285, 0.962862], 301 -> 
             RGBColor[0.819984, 0.859297, 0.982692], 156 -> 
             RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 25 -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 38 -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             365 -> RGBColor[
              0.6153531428571428, 0.6986104285714285, 0.962862], 380 -> 
             RGBColor[
              0.8861068571428571, 0.9120215714285714, 0.9889988571428572], 
             370 -> RGBColor[0.971623, 0.9159398571428573, 0.344261142857143],
              3 -> RGBColor[0.5073297142857142, 0.6109121428571428, 0.954358],
              57 -> RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             227 -> RGBColor[
              0.7184839999999999, 0.7800044285714285, 0.9725754285714285], 39 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 109 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 256 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             339 -> RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 
             287 -> RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             239 -> RGBColor[
              0.9190087142857143, 0.7166035714285715, 0.2536907142857143], 
             285 -> RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 
             345 -> RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             366 -> RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 216 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 21 -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             355 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             175 -> RGBColor[0.971623, 0.9159398571428573, 0.344261142857143],
              7 -> RGBColor[0.992503, 0.986373, 0.42537600000000036`], 13 -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             294 -> RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             193 -> RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 60 -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 65 -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 69 -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 217 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 214 -> 
             RGBColor[
              0.8861068571428571, 0.9120215714285714, 0.9889988571428572], 
             170 -> RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             359 -> RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 74 -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             246 -> RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             264 -> RGBColor[0.992503, 0.986373, 0.42537600000000036`], 278 -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 45 -> 
             RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             306 -> RGBColor[0.819984, 0.859297, 0.982692], 237 -> 
             RGBColor[
              0.8861068571428571, 0.9120215714285714, 0.9889988571428572], 
             228 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             180 -> RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             383 -> RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 53 -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             304 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 48 -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 5 -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             101 -> RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             333 -> RGBColor[
              0.9190087142857143, 0.7166035714285715, 0.2536907142857143], 
             267 -> RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             120 -> RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             147 -> RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 89 -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 43 -> 
             RGBColor[0.992503, 0.986373, 0.42537600000000036`], 199 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 268 -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 169 -> 
             RGBColor[0.864951, 0.4796558571428573, 0.20902414285714288`], 20 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 4 -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             167 -> RGBColor[0.992503, 0.986373, 0.42537600000000036`], 142 -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 16 -> 
             RGBColor[0.6153531428571428, 0.6986104285714285, 0.962862], 281 -> 
             RGBColor[0.992503, 0.986373, 0.42537600000000036`], 289 -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             398 -> RGBColor[0.971623, 0.9159398571428573, 0.344261142857143],
              178 -> RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 58 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 186 -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 122 -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             249 -> RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 113 -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 52 -> 
             RGBColor[0.819984, 0.859297, 0.982692], 187 -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             259 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 42 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             134 -> RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 313 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 248 -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             174 -> RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 215 -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             399 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 83 -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 95 -> 
             RGBColor[
              0.8861068571428571, 0.9120215714285714, 0.9889988571428572], 
             166 -> RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             384 -> RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             233 -> RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             295 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             141 -> RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 
             319 -> RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             205 -> RGBColor[0.971623, 0.9159398571428573, 0.344261142857143],
              224 -> RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             231 -> RGBColor[
              0.8861068571428571, 0.9120215714285714, 0.9889988571428572], 
             332 -> RGBColor[0.992503, 0.986373, 0.42537600000000036`], 68 -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 10 -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             250 -> RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 
             282 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             374 -> RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 232 -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 253 -> 
             RGBColor[
              0.8861068571428571, 0.9120215714285714, 0.9889988571428572], 55 -> 
             RGBColor[0.819984, 0.859297, 0.982692], 325 -> 
             RGBColor[0.819984, 0.859297, 0.982692], 91 -> 
             RGBColor[0.819984, 0.859297, 0.982692], 105 -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 36 -> 
             RGBColor[0.819984, 0.859297, 0.982692], 123 -> 
             RGBColor[
              0.8911350000000001, 0.5985512857142862, 0.23087271428571438`], 
             94 -> RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 312 -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 96 -> 
             RGBColor[
              0.9485721428571429, 0.8338127142857144, 0.2774781428571429], 2 -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             262 -> RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             272 -> RGBColor[0.819984, 0.859297, 0.982692], 97 -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             372 -> RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             356 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             346 -> RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             341 -> RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             209 -> RGBColor[0.992503, 0.986373, 0.42537600000000036`], 378 -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 66 -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             139 -> RGBColor[
              0.2531092857142857, 0.3833642857142857, 0.9377255714285715], 56 -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             335 -> RGBColor[0.992503, 0.986373, 0.42537600000000036`], 314 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 144 -> 
             RGBColor[0.992503, 0.986373, 0.42537600000000036`], 298 -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             204 -> RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             207 -> RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             334 -> RGBColor[0.971623, 0.9159398571428573, 0.344261142857143],
              149 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             219 -> RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             400 -> RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 9 -> 
             RGBColor[0.819984, 0.859297, 0.982692], 11 -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 44 -> 
             RGBColor[0.992503, 0.986373, 0.42537600000000036`], 153 -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 32 -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 162 -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 90 -> 
             RGBColor[
              0.8861068571428571, 0.9120215714285714, 0.9889988571428572], 
             331 -> RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 8 -> 
             RGBColor[
              0.9426265714285713, 0.9567315714285713, 0.9820024285714286], 
             364 -> RGBColor[0.992503, 0.986373, 0.42537600000000036`], 342 -> 
             RGBColor[
              0.970336857142857, 0.9773978571428571, 0.9350961428571429], 163 -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 49 -> 
             RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 
             338 -> RGBColor[0.819984, 0.859297, 0.982692], 76 -> 
             RGBColor[
              0.9873605714285714, 0.9890412857142857, 0.8591315714285717], 
             369 -> RGBColor[
              0.9940910000000001, 0.9897695714285715, 0.5982200000000008], 82 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 67 -> 
             RGBColor[
              0.8407967142857143, 0.3145870000000001, 0.18670028571428574`], 
             211 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 
               0.7541087142857144]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9l2k4lWvYhs1zWMs8LNZoLbMSqfBetRslSppMScqwSaE2pQyZolBokCJT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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 14}], {
             RGBColor[
             0.9600975714285714, 0.8748762857142858, 0.3108696428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.9182870000000001, 0.6977978571428574, 0.2766426428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 49}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 62}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 87}], {
             RGBColor[
             0.9313790000000001, 0.7572455714285717, 0.2875669285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 119}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 127}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 129}], {
             RGBColor[
             0.9600975714285714, 0.8748762857142858, 0.3108696428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 216}], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 231}], {
             RGBColor[
             0.9288649285714285, 0.9139807142857144, 0.6666300000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 235}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 298}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 313}], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 317}], {
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 336}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 361}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 393}], {
             RGBColor[
             0.9288649285714285, 0.9139807142857144, 0.6666300000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 396}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 97}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 109}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 181}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 191}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 193}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 211}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 305}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 334}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 340}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 360}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 365}], {
             RGBColor[
             0.7789898571428571, 0.8276709999999999, 0.9724322142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 370}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 11}], {
             RGBColor[
             0.750710357142857, 0.8003408571428572, 0.7762890000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 21}], {
             RGBColor[
             0.750710357142857, 0.8003408571428572, 0.7762890000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 34}], {
             RGBColor[
             0.750710357142857, 0.8003408571428572, 0.7762890000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 74}], {
             RGBColor[
             0.750710357142857, 0.8003408571428572, 0.7762890000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 86}], {
             RGBColor[
             0.750710357142857, 0.8003408571428572, 0.7762890000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 91}], {
             RGBColor[
             0.6636568571428572, 0.7351045714285713, 0.9685250000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 95}], {
             RGBColor[
             0.6967182857142856, 0.7614668571428571, 0.9716784285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 160}], {
             RGBColor[
             0.7388332857142856, 0.7941549999999999, 0.9447270714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[
             0.7473451428571427, 0.7999767142857143, 0.9067447857142859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 233}], {
             RGBColor[
             0.750710357142857, 0.8003408571428572, 0.7762890000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 263}], {
             RGBColor[0.7505137142857142, 0.801287, 0.8542333571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 264}], {
             RGBColor[
             0.7499163571428571, 0.7986425714285714, 0.6898670000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 285}], {
             RGBColor[
             0.7279509285714285, 0.7223624285714285, 0.6159180714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 312}], {
             RGBColor[
             0.7388332857142856, 0.7941549999999999, 0.9447270714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 348}], {
             RGBColor[
             0.750710357142857, 0.8003408571428572, 0.7762890000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 13}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 66}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 123}], {
             RGBColor[
             0.9426130000000001, 0.7941604285714288, 0.4145463571428576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 131}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 140}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 183}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 186}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 188}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 203}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 232}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 238}], {
             RGBColor[
             0.6617450714285715, 0.7247501428571429, 0.7702150000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 275}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 280}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 297}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 309}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 322}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 325}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 339}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 8}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 43}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 56}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 90}], {
             RGBColor[
             0.9367337142857142, 0.9505314285714286, 0.9240652142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 100}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 121}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 122}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 175}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 178}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 213}], {
             RGBColor[
             0.9392477857142858, 0.793796285714286, 0.545002142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 227}], {
             RGBColor[
             0.8529222857142856, 0.8845228571428572, 0.9158535000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 274}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 296}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 308}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 319}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 352}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 373}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 56}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 79}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 137}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 169}], {
             RGBColor[
             0.9261557857142857, 0.7343485714285716, 0.5340778571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 175}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 178}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 252}], {
             RGBColor[
             0.9367337142857142, 0.9505314285714286, 0.9240652142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 277}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 278}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 300}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 314}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 319}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 352}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 379}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 65}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 67}], {
             RGBColor[
             0.9166498571428572, 0.6504800000000001, 0.30603814285714304`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 68}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 96}], {
             RGBColor[
             0.9705375714285714, 0.9100928571428573, 0.35142707142857166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 173}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 201}], {
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 223}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 250}], {
             RGBColor[
             0.9705375714285714, 0.9100928571428573, 0.35142707142857166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 387}], {
             RGBColor[
             0.9705375714285714, 0.9100928571428573, 0.35142707142857166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 43}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 56}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 59}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 100}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 121}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 175}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 213}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 227}], {
             RGBColor[
             0.8305552857142856, 0.8683679999999999, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 237}], {
             RGBColor[
             0.9143667142857141, 0.9343765714285714, 0.9855006428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 296}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 308}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 352}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 373}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 39}], {
             RGBColor[0.8186515000000001, 0.496712, 0.573455]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.8842780714285714, 0.8465548571428572, 0.6300850714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 150}], {
             RGBColor[
             0.8842780714285714, 0.8465548571428572, 0.6300850714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 192}], {
             RGBColor[
             0.8951604285714285, 0.9183474285714286, 0.9588940714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 283}], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 294}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 320}], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 347}], {
             RGBColor[0.8958035, 0.8876184285714286, 0.6634765714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 381}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 384}], {
             RGBColor[0.8555595, 0.7289241428571431, 0.6067823571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 37}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 62}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 87}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 155}], {
             RGBColor[
             0.9143667142857141, 0.9343765714285714, 0.9855006428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 170}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 216}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 256}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 261}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 298}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 311}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 313}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 361}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 396}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 34}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 35}], {
             RGBColor[
             0.9426130000000001, 0.7941604285714288, 0.4145463571428576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 85}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 86}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 91}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 93}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 95}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 125}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 162}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 211}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 214}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 248}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 263}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 312}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[0.7671809285714286, 0.707607, 0.6082763571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 17}], {
             RGBColor[
             0.9565498571428572, 0.8531865714285715, 0.42595535714285754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 22}], {
             RGBColor[
             0.9563532142857143, 0.8541327142857142, 0.5038997142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 47}], {
             RGBColor[
             0.9050718571428572, 0.6575774285714289, 0.24228171428571435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 106}], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 107}], {
             RGBColor[
             0.9565498571428572, 0.8531865714285715, 0.42595535714285754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 118}], {
             RGBColor[
             0.9557558571428572, 0.8514882857142858, 0.3395333571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 158}], {
             RGBColor[
             0.9531846428571429, 0.8528224285714285, 0.556411142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 209}], {
             RGBColor[
             0.9557558571428572, 0.8514882857142858, 0.3395333571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 241}], {
             RGBColor[
             0.9446727857142856, 0.8470007142857143, 0.5943934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 270}], {
             RGBColor[
             0.8694963571428571, 0.7879502857142857, 0.6181913571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 310}], {
             RGBColor[
             0.9190087142857143, 0.7166035714285715, 0.2536907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 323}], {
             RGBColor[
             0.9563532142857143, 0.8541327142857142, 0.5038997142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 324}], {
             RGBColor[
             0.9308176428571429, 0.8366675714285714, 0.6178465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 346}], {
             RGBColor[
             0.9565498571428572, 0.8531865714285715, 0.42595535714285754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 390}], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 66}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 123}], {
             RGBColor[
             0.9426130000000001, 0.7941604285714288, 0.4145463571428576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 131}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 188}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 203}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 232}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 275}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 280}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 297}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 309}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 322}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 325}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 339}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 29}], {
             RGBColor[
             0.9067615714285715, 0.6567342857142858, 0.2432511428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 62}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 119}], {
             RGBColor[
             0.9455993571428571, 0.8952721428571428, 0.6297402857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 126}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 127}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 129}], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 196}], {
             RGBColor[
             0.9455993571428571, 0.8952721428571428, 0.6297402857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 235}], {
             RGBColor[
             0.9455993571428571, 0.8952721428571428, 0.6297402857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 317}], {
             RGBColor[
             0.9705375714285714, 0.9100928571428573, 0.35142707142857166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 326}], {
             RGBColor[
             0.9455993571428571, 0.8952721428571428, 0.6297402857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 327}], {
             RGBColor[
             0.9455993571428571, 0.8952721428571428, 0.6297402857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 336}], {
             RGBColor[
             0.9455993571428571, 0.8952721428571428, 0.6297402857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 396}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 33}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 37}], {
             RGBColor[
             0.9392477857142858, 0.793796285714286, 0.545002142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 92}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 256}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 311}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 313}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 361}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 386}], {
             RGBColor[
             0.9140786428571428, 0.6518141428571429, 0.5229159285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 69}], {
             RGBColor[
             0.7928449999999999, 0.8380041428571428, 0.9489790714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 106}], {
             RGBColor[
             0.7819626428571429, 0.7662115714285714, 0.6201700714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 107}], {
             RGBColor[0.8047220714285714, 0.84419, 0.7805410000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 190}], {
             RGBColor[
             0.7789898571428571, 0.8276709999999999, 0.9724322142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 212}], {
             RGBColor[
             0.7819626428571429, 0.7662115714285714, 0.6201700714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 241}], {
             RGBColor[
             0.7928449999999999, 0.8380041428571428, 0.9489790714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 268}], {
             RGBColor[
             0.7928449999999999, 0.8380041428571428, 0.9489790714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 270}], {
             RGBColor[0.7176685714285714, 0.7789537142857142, 0.972777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 274}], {
             RGBColor[
             0.8045254285714285, 0.8451361428571429, 0.8584853571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 295}], {
             RGBColor[
             0.8045254285714285, 0.8451361428571429, 0.8584853571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 310}], {
             RGBColor[0.7671809285714286, 0.707607, 0.6082763571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 324}], {
             RGBColor[
             0.7789898571428571, 0.8276709999999999, 0.9724322142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 351}], {
             RGBColor[
             0.7928449999999999, 0.8380041428571428, 0.9489790714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 373}], {
             RGBColor[
             0.8039280714285715, 0.8424917142857142, 0.6941190000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 380}], {
             RGBColor[
             0.7507299999999999, 0.8053159999999999, 0.9759304285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 390}], {
             RGBColor[
             0.7819626428571429, 0.7662115714285714, 0.6201700714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 22}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 48}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 61}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 118}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 158}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 164}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 173}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 209}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 241}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 287}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 323}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 346}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 354}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 371}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 388}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 389}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 45}], {
             RGBColor[
             0.9313790000000001, 0.7572455714285717, 0.2875669285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 74}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 86}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 91}], {
             RGBColor[0.8958035, 0.8876184285714286, 0.6634765714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 112}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 141}], {
             RGBColor[
             0.9600975714285714, 0.8748762857142858, 0.3108696428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 148}], {
             RGBColor[
             0.9288649285714285, 0.9139807142857144, 0.6666300000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 179}], {
             RGBColor[0.8958035, 0.8876184285714286, 0.6634765714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 232}], {
             RGBColor[
             0.9709799285714285, 0.9466688571428572, 0.639678642857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 257}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 279}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 285}], {
             RGBColor[
             0.9600975714285714, 0.8748762857142858, 0.3108696428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 288}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 399}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 185}], {
             RGBColor[
             0.9172472142857143, 0.6531244285714286, 0.47040450000000006`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 198}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 205}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 219}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 262}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 284}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 293}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 331}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 338}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.5489678571428571, 0.5109987857142857, 0.5935958571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 36}], {
             RGBColor[0.4994555, 0.5823455, 0.9580965]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{20, 80}], {
             RGBColor[
             0.5746319285714285, 0.6413959285714286, 0.9342985714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 151}], {
             RGBColor[0.585715, 0.6458835, 0.6794385000000002]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{20, 168}], {
             RGBColor[
             0.5637495714285714, 0.5696033571428571, 0.6054895714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 265}], {
             RGBColor[
             0.5489678571428571, 0.5109987857142857, 0.5935958571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 291}], {
             RGBColor[
             0.5831437857142856, 0.6472176428571428, 0.8963162857142859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 304}], {
             RGBColor[
             0.5863123571428572, 0.6485279285714285, 0.8438048571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 378}], {
             RGBColor[
             0.5831437857142856, 0.6472176428571428, 0.8963162857142859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 383}], {
             RGBColor[
             0.5637495714285714, 0.5696033571428571, 0.6054895714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 24}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 25}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 27}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 32}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 78}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 95}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 104}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 160}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 172}], {
             RGBColor[
             0.9565498571428572, 0.8531865714285715, 0.42595535714285754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 208}], {
             RGBColor[
             0.9565498571428572, 0.8531865714285715, 0.42595535714285754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 217}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 230}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 233}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 240}], {
             RGBColor[
             0.9565498571428572, 0.8531865714285715, 0.42595535714285754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 242}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 244}], {
             RGBColor[
             0.9174438571428571, 0.6521782857142858, 0.39246014285714326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 264}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 285}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 357}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 47}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 96}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 118}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 158}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 173}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 209}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 241}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 310}], {
             RGBColor[
             0.9563532142857143, 0.8541327142857142, 0.5038997142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 323}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 346}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 354}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 388}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 75}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 120}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 132}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 160}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 202}], {
             RGBColor[
             0.9705375714285714, 0.9100928571428573, 0.35142707142857166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 220}], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 229}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 260}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 307}], {
             RGBColor[
             0.9455993571428571, 0.8952721428571428, 0.6297402857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 321}], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 341}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 348}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 366}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 32}], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 73}], {
             RGBColor[
             0.9709799285714285, 0.9466688571428572, 0.6396786428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 78}], {
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 104}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 112}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 141}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 172}], {
             RGBColor[
             0.9446727857142856, 0.8470007142857143, 0.5943934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 208}], {
             RGBColor[
             0.9446727857142856, 0.8470007142857143, 0.5943934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 240}], {
             RGBColor[
             0.9446727857142856, 0.8470007142857143, 0.5943934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 242}], {
             RGBColor[
             0.9709799285714285, 0.9466688571428572, 0.6396786428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 243}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 285}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 337}], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 357}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 399}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 32}], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 78}], {
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 83}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 194}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 201}], {
             RGBColor[
             0.9709799285714285, 0.9466688571428572, 0.6396786428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 217}], {
             RGBColor[
             0.9709799285714285, 0.9466688571428572, 0.6396786428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 223}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 230}], {
             RGBColor[
             0.9709799285714285, 0.9466688571428572, 0.6396786428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 242}], {
             RGBColor[
             0.9709799285714285, 0.9466688571428572, 0.6396786428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 244}], {
             RGBColor[
             0.9055667857142857, 0.6459924285714286, 0.5608982142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 245}], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 328}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 357}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 364}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 385}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 105}], {
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 128}], {
             RGBColor[0.9173395, 0.872917142857143, 0.6332385]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{26, 159}], {
             RGBColor[
             0.9393049285714286, 0.9491972857142857, 0.7071874285714288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 171}], {
             RGBColor[
             0.9399022857142857, 0.9518417142857143, 0.8715537857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 215}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 218}], {
             RGBColor[
             0.9393049285714286, 0.9491972857142857, 0.7071874285714288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 342}], {
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 349}], {
             RGBColor[
             0.8861068571428571, 0.9120215714285714, 0.9889988571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 353}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 32}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 73}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 74}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 78}], {
             RGBColor[
             0.9367337142857142, 0.9505314285714286, 0.9240652142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 104}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 112}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 141}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 172}], {
             RGBColor[
             0.9531846428571429, 0.8528224285714285, 0.556411142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 208}], {
             RGBColor[
             0.9531846428571429, 0.8528224285714285, 0.556411142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 225}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 240}], {
             RGBColor[
             0.9531846428571429, 0.8528224285714285, 0.556411142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 243}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 285}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 337}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 357}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 399}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 36}], {
             RGBColor[
             0.8694963571428571, 0.7879502857142857, 0.6181913571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 151}], {
             RGBColor[
             0.9557558571428572, 0.8514882857142858, 0.3395333571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 168}], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 265}], {
             RGBColor[
             0.9190087142857143, 0.7166035714285715, 0.2536907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 267}], {
             RGBColor[
             0.9308176428571429, 0.8366675714285714, 0.6178465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 282}], {
             RGBColor[
             0.9563532142857143, 0.8541327142857142, 0.5038997142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 291}], {
             RGBColor[
             0.9531846428571429, 0.8528224285714285, 0.556411142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 304}], {
             RGBColor[
             0.9563532142857143, 0.8541327142857142, 0.5038997142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 378}], {
             RGBColor[
             0.9531846428571429, 0.8528224285714285, 0.556411142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 383}], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.9293243571428571, 0.7356588571428573, 0.4815664285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 87}], {
             RGBColor[
             0.8780430000000001, 0.5391035714285717, 0.21994842857142863`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 119}], {
             RGBColor[
             0.9037887857142857, 0.7181937142857143, 0.5955132857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 127}], {
             RGBColor[
             0.9293243571428571, 0.7356588571428573, 0.4815664285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 129}], {
             RGBColor[
             0.9067615714285715, 0.6567342857142858, 0.2432511428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 231}], {
             RGBColor[0.8755289285714285, 0.6958387142857143, 0.5990115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 235}], {
             RGBColor[
             0.9037887857142857, 0.7181937142857143, 0.5955132857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 317}], {
             RGBColor[
             0.9287270000000001, 0.7330144285714286, 0.31720007142857165`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 326}], {
             RGBColor[
             0.9037887857142857, 0.7181937142857143, 0.5955132857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 327}], {
             RGBColor[
             0.9037887857142857, 0.7181937142857143, 0.5955132857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 336}], {
             RGBColor[
             0.9037887857142857, 0.7181937142857143, 0.5955132857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 396}], {
             RGBColor[
             0.9261557857142857, 0.7343485714285716, 0.5340778571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 54}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 63}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 224}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 297}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 318}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 345}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 81}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 106}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 164}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 192}], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 241}], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 271}], {
             RGBColor[
             0.9446727857142856, 0.8470007142857143, 0.5943934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 287}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 292}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 371}], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 374}], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 382}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 384}], {
             RGBColor[
             0.9307359285714285, 0.7879745714285716, 0.5829844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 389}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 78}], {
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 104}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 172}], {
             RGBColor[
             0.9446727857142856, 0.8470007142857143, 0.5943934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 194}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 208}], {
             RGBColor[
             0.9446727857142856, 0.8470007142857143, 0.5943934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 217}], {
             RGBColor[
             0.9709799285714285, 0.9466688571428572, 0.6396786428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 223}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 230}], {
             RGBColor[
             0.9709799285714285, 0.9466688571428572, 0.6396786428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 240}], {
             RGBColor[
             0.9446727857142856, 0.8470007142857143, 0.5943934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 242}], {
             RGBColor[
             0.9709799285714285, 0.9466688571428572, 0.6396786428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 357}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 364}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 385}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 387}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 92}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 182}], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 256}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 281}], {
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 311}], {
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 35}], {
             RGBColor[
             0.9426130000000001, 0.7941604285714288, 0.4145463571428576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 85}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 86}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 91}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 93}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 95}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 125}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 162}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 211}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 214}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 248}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 263}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 340}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 42}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.4924907142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 85}], {
             RGBColor[
             0.9418190000000001, 0.7924621428571431, 0.32812435714285737`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 86}], {
             RGBColor[
             0.9426130000000001, 0.7941604285714288, 0.4145463571428576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 93}], {
             RGBColor[
             0.9307359285714285, 0.7879745714285716, 0.5829844285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 97}], {
             RGBColor[
             0.9392477857142858, 0.793796285714286, 0.545002142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 98}], {
             RGBColor[
             0.9307359285714285, 0.7879745714285716, 0.5829844285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 125}], {
             RGBColor[
             0.9426130000000001, 0.7941604285714288, 0.4145463571428576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 162}], {
             RGBColor[
             0.9392477857142858, 0.793796285714286, 0.545002142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 211}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.4924907142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 214}], {
             RGBColor[
             0.8886209285714286, 0.7552864285714288, 0.6099357857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 248}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 263}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.4924907142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 340}], {
             RGBColor[
             0.9426130000000001, 0.7941604285714288, 0.4145463571428576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 80}], {
             RGBColor[
             0.8951604285714285, 0.9183474285714286, 0.9588940714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 151}], {
             RGBColor[0.9062435, 0.9228350000000001, 0.7040340000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 168}], {
             RGBColor[
             0.8842780714285714, 0.8465548571428572, 0.6300850714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 265}], {
             RGBColor[
             0.8694963571428571, 0.7879502857142857, 0.6181913571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 277}], {
             RGBColor[0.8958035, 0.8876184285714286, 0.6634765714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 304}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 378}], {
             RGBColor[
             0.9036722857142857, 0.9241691428571428, 0.9209117857142859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 383}], {
             RGBColor[
             0.8842780714285714, 0.8465548571428572, 0.6300850714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 41}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.4924907142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 114}], {
             RGBColor[
             0.9426130000000001, 0.7941604285714288, 0.4145463571428576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 170}], {
             RGBColor[
             0.9392477857142858, 0.793796285714286, 0.545002142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 187}], {
             RGBColor[
             0.9426130000000001, 0.7941604285714288, 0.4145463571428576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 206}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 256}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.4924907142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 261}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 311}], {
             RGBColor[
             0.9418190000000001, 0.7924621428571431, 0.32812435714285737`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 361}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 53}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 58}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 102}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 103}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 117}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 145}], {
             RGBColor[
             0.9531846428571429, 0.8528224285714285, 0.556411142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 189}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 222}], {
             RGBColor[
             0.9036722857142857, 0.9241691428571428, 0.9209117857142859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 254}], {
             RGBColor[
             0.8013568571428571, 0.8438258571428572, 0.9109967857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 303}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 376}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 150}], {
             RGBColor[
             0.8829455714285714, 0.4839698571428572, 0.22084807142857144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 237}], {
             RGBColor[
             0.8517129285714286, 0.5230742857142857, 0.5766084285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 251}], {
             RGBColor[
             0.9023397857142856, 0.5615841428571429, 0.5116747857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 283}], {
             RGBColor[0.8186515000000001, 0.496712, 0.573455]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{39, 294}], {
             RGBColor[0.905705, 0.5619482857142857, 0.3812190000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 320}], {
             RGBColor[
             0.8517129285714286, 0.5230742857142857, 0.5766084285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 347}], {
             RGBColor[0.894471, 0.5250334285714287, 0.2542395714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 381}], {
             RGBColor[
             0.9055083571428572, 0.5628944285714286, 0.45916335714285716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 51}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 84}], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 102}], {
             RGBColor[
             0.8842780714285714, 0.8465548571428572, 0.6300850714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 134}], {
             RGBColor[
             0.8951604285714285, 0.9183474285714286, 0.9588940714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 163}], {
             RGBColor[
             0.9036722857142857, 0.9241691428571428, 0.9209117857142859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 167}], {
             RGBColor[0.9062435, 0.9228350000000001, 0.7040340000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 174}], {
             RGBColor[
             0.8951604285714285, 0.9183474285714286, 0.9588940714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 183}], {
             RGBColor[
             0.8951604285714285, 0.9183474285714286, 0.9588940714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 189}], {
             RGBColor[
             0.8951604285714285, 0.9183474285714286, 0.9588940714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 226}], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 234}], {
             RGBColor[
             0.8813052857142857, 0.9080142857142857, 0.9823472142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 246}], {
             RGBColor[
             0.8813052857142857, 0.9080142857142857, 0.9823472142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 269}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 272}], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 350}], {
             RGBColor[0.9062435, 0.9228350000000001, 0.7040340000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 355}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 392}], {
             RGBColor[0.49945550000000005`, 0.5823455, 0.9580965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 395}], {
             RGBColor[
             0.8813052857142857, 0.9080142857142857, 0.9823472142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 55}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 83}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 135}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 156}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 165}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 187}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 206}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 245}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 256}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 311}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 328}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 386}], {
             RGBColor[
             0.9172472142857143, 0.6531244285714286, 0.47040450000000006`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 400}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 45}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 93}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 98}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 125}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 139}], {
             RGBColor[0.6234035, 0.6875130714285714, 0.8459171428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 148}], {
             RGBColor[
             0.9399022857142857, 0.9518417142857143, 0.8715537857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 204}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 248}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 275}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 276}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 288}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 290}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 318}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 56}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 59}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[
             0.9393049285714286, 0.9491972857142857, 0.7071874285714288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 121}], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 122}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 175}], {
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 213}], {
             RGBColor[
             0.9418190000000001, 0.7924621428571431, 0.32812435714285737`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 227}], {
             RGBColor[
             0.8554934999999999, 0.8831887142857142, 0.6989757142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 237}], {
             RGBColor[
             0.9393049285714286, 0.9491972857142857, 0.7071874285714288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 274}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 296}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 308}], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 373}], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 380}], {
             RGBColor[
             0.9393049285714286, 0.9491972857142857, 0.7071874285714288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 46}], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 65}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 68}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 113}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 149}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 161}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 195}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 247}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 249}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 250}], {
             RGBColor[
             0.9705375714285714, 0.9100928571428573, 0.35142707142857166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 266}], {
             RGBColor[
             0.9705375714285714, 0.9100928571428573, 0.35142707142857166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 315}], {
             RGBColor[
             0.9557558571428572, 0.8514882857142858, 0.3395333571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 316}], {
             RGBColor[
             0.9705375714285714, 0.9100928571428573, 0.35142707142857166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 358}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 362}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 363}], {
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 369}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 372}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 66}], {
             RGBColor[
             0.9426130000000001, 0.7941604285714288, 0.4145463571428576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 91}], {
             RGBColor[0.8555595, 0.7289241428571431, 0.6067823571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 123}], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 140}], {
             RGBColor[0.8555595, 0.7289241428571431, 0.6067823571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 148}], {
             RGBColor[
             0.8886209285714286, 0.7552864285714288, 0.6099357857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 179}], {
             RGBColor[0.8555595, 0.7289241428571431, 0.6067823571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 203}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.4924907142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 232}], {
             RGBColor[
             0.9307359285714285, 0.7879745714285716, 0.5829844285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 257}], {
             RGBColor[
             0.9392477857142858, 0.793796285714286, 0.545002142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 275}], {
             RGBColor[0.8555595, 0.7289241428571431, 0.6067823571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 276}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.4924907142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 279}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.4924907142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 280}], {
             RGBColor[
             0.8886209285714286, 0.7552864285714288, 0.6099357857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 288}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.4924907142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 297}], {
             RGBColor[
             0.9418190000000001, 0.7924621428571431, 0.32812435714285737`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 325}], {
             RGBColor[0.8555595, 0.7289241428571431, 0.6067823571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 339}], {
             RGBColor[
             0.9198535714285715, 0.7161820000000003, 0.2541754285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 149}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 153}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 161}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 184}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 195}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 247}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 250}], {
             RGBColor[
             0.9705375714285714, 0.9100928571428573, 0.35142707142857166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 315}], {
             RGBColor[
             0.9557558571428572, 0.8514882857142858, 0.3395333571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 343}], {
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 356}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 358}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 362}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 363}], {
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 369}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 372}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.9198535714285715, 0.7161820000000003, 0.2541754285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.9392477857142858, 0.793796285714286, 0.545002142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 173}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.4924907142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 201}], {
             RGBColor[
             0.9313790000000001, 0.7572455714285717, 0.2875669285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 209}], {
             RGBColor[
             0.9418190000000001, 0.7924621428571431, 0.32812435714285737`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 323}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.4924907142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 346}], {
             RGBColor[
             0.9426130000000001, 0.7941604285714288, 0.4145463571428576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 61}], {
             RGBColor[
             0.8951604285714285, 0.9183474285714286, 0.9588940714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 68}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 118}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 173}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 176}], {
             RGBColor[
             0.9709799285714285, 0.9466688571428572, 0.6396786428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 209}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 344}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 354}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 388}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 52}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 62}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.9426130000000001, 0.7941604285714288, 0.4145463571428576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 127}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 133}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 199}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 216}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 231}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 235}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 298}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 313}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 361}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 393}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 396}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 147}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 164}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 271}], {
             RGBColor[
             0.9565498571428572, 0.8531865714285715, 0.42595535714285754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 287}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 371}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 391}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 84}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 102}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 134}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 163}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 167}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 174}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 183}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 189}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 222}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 226}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 234}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 238}], {
             RGBColor[
             0.6617450714285715, 0.7247501428571429, 0.7702150000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 246}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 269}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 272}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 350}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 355}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 392}], {
             RGBColor[
             0.5865090000000001, 0.6475817857142857, 0.7658605000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 395}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 89}], {
             RGBColor[
             0.8813052857142857, 0.9080142857142857, 0.9823472142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 128}], {
             RGBColor[
             0.8842780714285714, 0.8465548571428572, 0.6300850714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 133}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 199}], {
             RGBColor[0.8958035, 0.8876184285714286, 0.6634765714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 299}], {
             RGBColor[0.8958035, 0.8876184285714286, 0.6634765714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 342}], {
             RGBColor[
             0.8951604285714285, 0.9183474285714286, 0.9588940714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 393}], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 58}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 64}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 117}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 126}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 289}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 303}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 376}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 63}], {
             RGBColor[
             0.9709799285714285, 0.9466688571428572, 0.639678642857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 66}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 204}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 224}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 290}], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 297}], {
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 318}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 345}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 92}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 135}], {
             RGBColor[
             0.8813052857142857, 0.9080142857142857, 0.9823472142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 156}], {
             RGBColor[
             0.8842780714285714, 0.8465548571428572, 0.6300850714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.8951604285714285, 0.9183474285714286, 0.9588940714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 221}], {
             RGBColor[
             0.9036722857142857, 0.9241691428571428, 0.9209117857142859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 245}], {
             RGBColor[
             0.8951604285714285, 0.9183474285714286, 0.9588940714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 255}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 328}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 386}], {
             RGBColor[
             0.8303903571428572, 0.5869420000000001, 0.5846961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 400}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 59}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 90}], {
             RGBColor[
             0.9367337142857142, 0.9505314285714286, 0.9240652142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 121}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 122}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 137}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 166}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 169}], {
             RGBColor[
             0.9261557857142857, 0.7343485714285716, 0.5340778571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 175}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 178}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 213}], {
             RGBColor[
             0.9392477857142858, 0.793796285714286, 0.545002142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 274}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 278}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 296}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 319}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 352}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 76}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.8813052857142857, 0.9080142857142857, 0.9823472142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 102}], {
             RGBColor[
             0.9455993571428571, 0.8952721428571428, 0.6297402857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 144}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 163}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 167}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 174}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 186}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 188}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 189}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 222}], {
             RGBColor[
             0.8813052857142857, 0.9080142857142857, 0.9823472142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 228}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 238}], {
             RGBColor[
             0.6360128571428572, 0.7082311428571428, 0.9621062142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 333}], {
             RGBColor[
             0.9308176428571429, 0.8366675714285714, 0.6178465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 368}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 117}], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 289}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 303}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 376}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 90}], {
             RGBColor[
             0.9143667142857141, 0.9343765714285714, 0.9855006428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 121}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 122}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 175}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 178}], {
             RGBColor[
             0.9455993571428571, 0.8952721428571428, 0.6297402857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 213}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 274}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 296}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 319}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 373}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 101}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 259}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 331}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 335}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 394}], {
             RGBColor[
             0.9367337142857142, 0.9505314285714286, 0.9240652142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 118}], {
             RGBColor[0.9062435, 0.9228350000000001, 0.7040340000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 130}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 147}], {
             RGBColor[
             0.8842780714285714, 0.8465548571428572, 0.6300850714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 164}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 173}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 176}], {
             RGBColor[0.8958035, 0.8876184285714286, 0.6634765714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 344}], {
             RGBColor[
             0.8842780714285714, 0.8465548571428572, 0.6300850714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 354}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 371}], {
             RGBColor[
             0.8951604285714285, 0.9183474285714286, 0.9588940714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 388}], {
             RGBColor[
             0.8842780714285714, 0.8465548571428572, 0.6300850714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 87}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 119}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 127}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 129}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 216}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 231}], {
             RGBColor[
             0.9399022857142857, 0.9518417142857143, 0.8715537857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 235}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 298}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 313}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 317}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 336}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 361}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 393}], {
             RGBColor[
             0.9399022857142857, 0.9518417142857143, 0.8715537857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 396}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 98}], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 139}], {
             RGBColor[
             0.6117230714285713, 0.6803810714285714, 0.9364108571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 204}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 224}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 290}], {
             RGBColor[
             0.9709799285714285, 0.9466688571428572, 0.6396786428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 318}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 345}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 77}], {
             RGBColor[
             0.9399022857142857, 0.9518417142857143, 0.8715537857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 94}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 254}], {
             RGBColor[
             0.8045254285714285, 0.8451361428571429, 0.8584853571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 289}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 68}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 173}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 176}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 250}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 363}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 123}], {
             RGBColor[
             0.9426130000000001, 0.7941604285714288, 0.4145463571428576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 131}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 140}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 203}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 232}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 257}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 275}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 280}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 297}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 318}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 322}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 325}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 339}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 113}], {
             RGBColor[
             0.9174438571428571, 0.6521782857142857, 0.39246014285714326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 124}], {
             RGBColor[
             0.9055667857142857, 0.6459924285714287, 0.5608982142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 194}], {
             RGBColor[0.9172472142857143, 0.6531244285714286, 0.4704045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 208}], {
             RGBColor[
             0.8799027142857143, 0.5155952857142858, 0.22019550000000004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 210}], {
             RGBColor[
             0.8290578571428572, 0.22435700000000006`, 0.17545914285714287`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 249}], {
             RGBColor[
             0.9055667857142857, 0.6459924285714287, 0.5608982142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 266}], {
             RGBColor[
             0.8946844285714286, 0.5741998571428573, 0.23208921428571433`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 293}], {
             RGBColor[
             0.9140786428571428, 0.6518141428571429, 0.5229159285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 316}], {
             RGBColor[
             0.8946844285714286, 0.5741998571428573, 0.23208921428571433`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 385}], {
             RGBColor[0.9172472142857143, 0.6531244285714286, 0.4704045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 387}], {
             RGBColor[
             0.8946844285714286, 0.5741998571428573, 0.23208921428571433`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 161}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 173}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 176}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 250}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 363}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 106}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 107}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 150}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 212}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 270}], {
             RGBColor[
             0.8951604285714285, 0.9183474285714286, 0.9588940714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 283}], {
             RGBColor[
             0.8951604285714285, 0.9183474285714286, 0.9588940714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 294}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 295}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 320}], {
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 347}], {
             RGBColor[
             0.9709799285714285, 0.9466688571428572, 0.6396786428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 373}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 380}], {
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 381}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 390}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 108}], {
             RGBColor[
             0.9531846428571429, 0.8528224285714285, 0.556411142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 152}], {
             RGBColor[
             0.9565498571428572, 0.8531865714285715, 0.42595535714285754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 154}], {
             RGBColor[
             0.9531846428571429, 0.8528224285714285, 0.556411142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 180}], {
             RGBColor[
             0.9308176428571429, 0.8366675714285714, 0.6178465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 198}], {
             RGBColor[
             0.9565498571428572, 0.8531865714285715, 0.42595535714285754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 236}], {
             RGBColor[
             0.9557558571428572, 0.8514882857142858, 0.3395333571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 262}], {
             RGBColor[
             0.9308176428571429, 0.8366675714285714, 0.6178465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 267}], {
             RGBColor[
             0.9308176428571429, 0.8366675714285714, 0.6178465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 284}], {
             RGBColor[
             0.9565498571428572, 0.8531865714285715, 0.42595535714285754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 286}], {
             RGBColor[
             0.9557558571428572, 0.8514882857142858, 0.3395333571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 332}], {
             RGBColor[
             0.9557558571428572, 0.8514882857142858, 0.3395333571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 72}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 88}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 138}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 157}], {
             RGBColor[
             0.9565498571428572, 0.8531865714285715, 0.42595535714285754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 365}], {
             RGBColor[0.8047220714285714, 0.84419, 0.7805410000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 88}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 109}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 157}], {
             RGBColor[
             0.9308176428571429, 0.8366675714285714, 0.6178465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 181}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 191}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 365}], {
             RGBColor[
             0.7789898571428571, 0.8276709999999999, 0.9724322142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 370}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 78}], {
             RGBColor[
             0.9288649285714285, 0.9139807142857144, 0.6666300000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 99}], {
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 104}], {
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 112}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 141}], {
             RGBColor[
             0.9600975714285714, 0.8748762857142858, 0.3108696428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 172}], {
             RGBColor[
             0.9453158571428572, 0.8162717142857143, 0.29897592857142863`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 177}], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 208}], {
             RGBColor[
             0.9453158571428572, 0.8162717142857143, 0.29897592857142863`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 225}], {
             RGBColor[
             0.9600975714285714, 0.8748762857142858, 0.3108696428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 240}], {
             RGBColor[
             0.9453158571428572, 0.8162717142857143, 0.29897592857142863`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 243}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 285}], {
             RGBColor[
             0.9600975714285714, 0.8748762857142858, 0.3108696428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 337}], {
             RGBColor[
             0.9709799285714285, 0.9466688571428572, 0.639678642857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 399}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 86}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 91}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 95}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 104}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 112}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 141}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 148}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 172}], {
             RGBColor[
             0.9565498571428572, 0.8531865714285715, 0.42595535714285754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 179}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 240}], {
             RGBColor[
             0.9565498571428572, 0.8531865714285715, 0.42595535714285754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 263}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 279}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 285}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 399}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 105}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 132}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 202}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 215}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 218}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 229}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 260}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 329}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 341}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 349}], {
             RGBColor[
             0.9367337142857142, 0.9505314285714286, 0.9240652142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 77}], {
             RGBColor[
             0.9367337142857142, 0.9505314285714286, 0.9240652142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 103}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 144}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 145}], {
             RGBColor[
             0.9531846428571429, 0.8528224285714285, 0.556411142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 200}], {
             RGBColor[
             0.8013568571428571, 0.8438258571428572, 0.9109967857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 207}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 222}], {
             RGBColor[
             0.9036722857142857, 0.9241691428571428, 0.9209117857142859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 333}], {
             RGBColor[
             0.9531846428571429, 0.8528224285714285, 0.556411142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 368}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 94}], {
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 103}], {
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 145}], {
             RGBColor[
             0.9025577857142857, 0.8143125714285715, 0.6213447857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 200}], {
             RGBColor[
             0.7507299999999999, 0.8053159999999999, 0.9759304285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 207}], {
             RGBColor[
             0.9367337142857142, 0.9505314285714286, 0.9240652142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 254}], {
             RGBColor[
             0.7507299999999999, 0.8053159999999999, 0.9759304285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 333}], {
             RGBColor[
             0.9025577857142857, 0.8143125714285715, 0.6213447857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 104}], {
             RGBColor[
             0.9393049285714286, 0.9491972857142857, 0.7071874285714288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 172}], {
             RGBColor[
             0.9025577857142857, 0.8143125714285715, 0.6213447857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 194}], {
             RGBColor[
             0.9399022857142857, 0.9518417142857143, 0.8715537857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 208}], {
             RGBColor[
             0.9025577857142857, 0.8143125714285715, 0.6213447857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 217}], {
             RGBColor[
             0.9288649285714285, 0.9139807142857144, 0.6666300000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 230}], {
             RGBColor[
             0.9288649285714285, 0.9139807142857144, 0.6666300000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 233}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 240}], {
             RGBColor[
             0.9025577857142857, 0.8143125714285715, 0.6213447857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 242}], {
             RGBColor[
             0.9288649285714285, 0.9139807142857144, 0.6666300000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 244}], {
             RGBColor[
             0.8634517857142857, 0.6133042857142857, 0.5878495714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 264}], {
             RGBColor[
             0.9393049285714286, 0.9491972857142857, 0.7071874285714288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 285}], {
             RGBColor[0.9173395, 0.872917142857143, 0.6332385]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{78, 357}], {
             RGBColor[
             0.9399022857142857, 0.9518417142857143, 0.8715537857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 385}], {
             RGBColor[
             0.9399022857142857, 0.9518417142857143, 0.8715537857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 100}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 137}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 175}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 213}], {
             RGBColor[
             0.9392477857142858, 0.793796285714286, 0.545002142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 227}], {
             RGBColor[
             0.8529222857142856, 0.8845228571428572, 0.9158535000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 278}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 302}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 314}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 352}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 379}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 151}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 168}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 265}], {
             RGBColor[
             0.9446727857142856, 0.8470007142857143, 0.5943934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 304}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 378}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 192}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 271}], {
             RGBColor[
             0.9563532142857143, 0.8541327142857142, 0.5038997142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 287}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 292}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 374}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 382}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 384}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 101}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 136}], {
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 259}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 331}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 335}], {
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 120}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 187}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 206}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 217}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 220}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 230}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 244}], {
             RGBColor[
             0.9174438571428571, 0.6521782857142858, 0.39246014285714326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 245}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 321}], {
             RGBColor[
             0.9565498571428572, 0.8531865714285715, 0.42595535714285754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 328}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 364}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 102}], {
             RGBColor[
             0.8842780714285714, 0.8465548571428572, 0.6300850714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 163}], {
             RGBColor[
             0.9036722857142857, 0.9241691428571428, 0.9209117857142859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 167}], {
             RGBColor[0.9062435, 0.9228350000000001, 0.7040340000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 174}], {
             RGBColor[
             0.8951604285714285, 0.9183474285714286, 0.9588940714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 183}], {
             RGBColor[
             0.8951604285714285, 0.9183474285714286, 0.9588940714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 189}], {
             RGBColor[
             0.8951604285714285, 0.9183474285714286, 0.9588940714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 222}], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 226}], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 234}], {
             RGBColor[
             0.8813052857142857, 0.9080142857142857, 0.9823472142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 238}], {
             RGBColor[0.5746915714285714, 0.6595138571428572, 0.962451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 246}], {
             RGBColor[
             0.8813052857142857, 0.9080142857142857, 0.9823472142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 269}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 272}], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 395}], {
             RGBColor[
             0.8813052857142857, 0.9080142857142857, 0.9823472142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 88}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 162}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 181}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 191}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 211}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 214}], {
             RGBColor[
             0.9393049285714286, 0.9491972857142857, 0.7071874285714288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 263}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 307}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 312}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 340}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 348}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 91}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 93}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 95}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 125}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 148}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 162}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 179}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 214}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 263}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 264}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 285}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 119}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 127}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.4924907142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 129}], {
             RGBColor[
             0.9198535714285715, 0.7161820000000003, 0.2541754285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 216}], {
             RGBColor[
             0.9313790000000001, 0.7572455714285717, 0.2875669285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 231}], {
             RGBColor[
             0.8886209285714286, 0.7552864285714288, 0.6099357857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 235}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 298}], {
             RGBColor[
             0.9426130000000001, 0.7941604285714288, 0.4145463571428576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 313}], {
             RGBColor[
             0.9313790000000001, 0.7572455714285717, 0.2875669285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 317}], {
             RGBColor[
             0.9418190000000001, 0.7924621428571431, 0.32812435714285737`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 361}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714288, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 393}], {
             RGBColor[
             0.8886209285714286, 0.7552864285714288, 0.6099357857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 396}], {
             RGBColor[
             0.9392477857142858, 0.793796285714286, 0.545002142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 109}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 157}], {
             RGBColor[
             0.9563532142857143, 0.8541327142857142, 0.5038997142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 181}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 191}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 365}], {
             RGBColor[
             0.8045254285714285, 0.8451361428571429, 0.8584853571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 370}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 128}], {
             RGBColor[
             0.9455993571428571, 0.8952721428571428, 0.6297402857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 133}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 155}], {
             RGBColor[
             0.9143667142857141, 0.9343765714285714, 0.9855006428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 170}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 171}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 199}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 299}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 306}], {
             RGBColor[
             0.8813052857142857, 0.9080142857142857, 0.9823472142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 342}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 353}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 121}], {
             RGBColor[
             0.9393049285714286, 0.9491972857142857, 0.7071874285714288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 122}], {
             RGBColor[
             0.9367337142857142, 0.9505314285714286, 0.9240652142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 178}], {
             RGBColor[0.9173395, 0.872917142857143, 0.6332385]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{90, 190}], {
             RGBColor[
             0.9143667142857141, 0.9343765714285714, 0.9855006428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 212}], {
             RGBColor[0.9173395, 0.872917142857143, 0.6332385]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{90, 221}], {
             RGBColor[
             0.9367337142857142, 0.9505314285714286, 0.9240652142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 268}], {
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 274}], {
             RGBColor[
             0.9399022857142857, 0.9518417142857143, 0.8715537857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 295}], {
             RGBColor[
             0.9399022857142857, 0.9518417142857143, 0.8715537857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 319}], {
             RGBColor[
             0.9143667142857141, 0.9343765714285714, 0.9855006428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 324}], {
             RGBColor[
             0.9143667142857141, 0.9343765714285714, 0.9855006428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 351}], {
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 373}], {
             RGBColor[
             0.9393049285714286, 0.9491972857142857, 0.7071874285714288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 95}], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 112}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 125}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 148}], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 179}], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 257}], {
             RGBColor[
             0.9036722857142857, 0.9241691428571428, 0.9209117857142859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 263}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 279}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 285}], {
             RGBColor[
             0.8842780714285714, 0.8465548571428572, 0.6300850714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 288}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 135}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 165}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 182}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 256}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 281}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 311}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 386}], {
             RGBColor[
             0.9172472142857143, 0.6531244285714286, 0.47040450000000006`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 98}], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 125}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 148}], {
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 162}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 214}], {
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 248}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 276}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 288}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 290}], {
             RGBColor[
             0.9709799285714285, 0.9466688571428572, 0.6396786428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 103}], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 145}], {
             RGBColor[
             0.9446727857142856, 0.8470007142857143, 0.5943934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 207}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 254}], {
             RGBColor[
             0.7928449999999999, 0.8380041428571428, 0.9489790714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 125}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 162}], {
             RGBColor[
             0.9367337142857142, 0.9505314285714286, 0.9240652142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 233}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 263}], {
             RGBColor[
             0.9399022857142857, 0.9518417142857143, 0.8715537857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 264}], {
             RGBColor[
             0.9393049285714286, 0.9491972857142857, 0.7071874285714288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 285}], {
             RGBColor[0.9173395, 0.872917142857143, 0.6332385]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{95, 312}], {
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 173}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 201}], {
             RGBColor[
             0.9600975714285714, 0.8748762857142858, 0.3108696428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 209}], {
             RGBColor[
             0.9705375714285714, 0.9100928571428573, 0.35142707142857166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 223}], {
             RGBColor[
             0.9455993571428571, 0.8952721428571428, 0.6297402857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 245}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 323}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 109}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 181}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 191}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 193}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 211}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 214}], {
             RGBColor[
             0.9367337142857142, 0.9505314285714286, 0.9240652142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 248}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 305}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 334}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 340}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 360}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 370}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 125}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 139}], {
             RGBColor[
             0.6117230714285713, 0.6803810714285714, 0.9364108571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 193}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 204}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 248}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 276}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 290}], {
             RGBColor[
             0.9709799285714285, 0.9466688571428572, 0.6396786428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 318}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 141}], {
             RGBColor[
             0.9705375714285714, 0.9100928571428573, 0.35142707142857166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 169}], {
             RGBColor[
             0.9287270000000001, 0.7330144285714286, 0.31720007142857165`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 177}], {
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 197}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 225}], {
             RGBColor[
             0.9705375714285714, 0.9100928571428573, 0.35142707142857166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 243}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 252}], {
             RGBColor[
             0.9393049285714286, 0.9491972857142857, 0.7071874285714288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 300}], {
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 337}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 367}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 398}], {
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 146}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 175}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 213}], {
             RGBColor[
             0.9392477857142858, 0.793796285714286, 0.545002142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 227}], {
             RGBColor[
             0.8529222857142856, 0.8845228571428572, 0.9158535000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 278}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 302}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 314}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 352}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 377}], {
             RGBColor[
             0.9531846428571429, 0.8528224285714285, 0.556411142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 136}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 301}], {
             RGBColor[
             0.9036722857142857, 0.9241691428571428, 0.9209117857142859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 335}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 394}], {
             RGBColor[
             0.9367337142857142, 0.9505314285714286, 0.9240652142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 163}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 167}], {
             RGBColor[
             0.9705375714285714, 0.9100928571428573, 0.35142707142857166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 174}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 189}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 222}], {
             RGBColor[
             0.8842780714285714, 0.8465548571428572, 0.6300850714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 226}], {
             RGBColor[0.9173395, 0.872917142857143, 0.6332385]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{102, 395}], {
             RGBColor[
             0.9455993571428571, 0.8952721428571428, 0.6297402857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 145}], {
             RGBColor[
             0.9446727857142856, 0.8470007142857143, 0.5943934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 200}], {
             RGBColor[
             0.7928449999999999, 0.8380041428571428, 0.9489790714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 207}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 222}], {
             RGBColor[
             0.8951604285714285, 0.9183474285714286, 0.9588940714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 254}], {
             RGBColor[
             0.7928449999999999, 0.8380041428571428, 0.9489790714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 333}], {
             RGBColor[
             0.9446727857142856, 0.8470007142857143, 0.5943934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 112}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 141}], {
             RGBColor[
             0.9705375714285714, 0.9100928571428573, 0.35142707142857166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 172}], {
             RGBColor[
             0.9557558571428572, 0.8514882857142858, 0.3395333571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 208}], {
             RGBColor[
             0.9557558571428572, 0.8514882857142858, 0.3395333571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 240}], {
             RGBColor[
             0.9557558571428572, 0.8514882857142858, 0.3395333571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 242}], {
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 243}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 285}], {
             RGBColor[
             0.9705375714285714, 0.9100928571428573, 0.35142707142857166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 337}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 357}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 399}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 114}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 171}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 202}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 218}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 229}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 261}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 349}], {
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 353}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 150}], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 158}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 241}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 270}], {
             RGBColor[
             0.8842780714285714, 0.8465548571428572, 0.6300850714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 292}], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 310}], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 320}], {
             RGBColor[0.9173395, 0.872917142857143, 0.6332385]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{106, 347}], {
             RGBColor[
             0.9600975714285714, 0.8748762857142858, 0.3108696428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 374}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 384}], {
             RGBColor[
             0.9198535714285715, 0.7161820000000003, 0.2541754285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 389}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 390}], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 158}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 190}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 212}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 241}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 268}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 270}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 295}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 310}], {
             RGBColor[
             0.9565498571428572, 0.8531865714285715, 0.42595535714285754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 324}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 346}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 351}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 373}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 390}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 152}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 154}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 180}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 198}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 205}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 236}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 262}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 267}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 284}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 286}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 332}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 367}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 398}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 157}], {
             RGBColor[
             0.9453158571428572, 0.8162717142857143, 0.29897592857142863`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 181}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 191}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 305}], {
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 334}], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 340}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 360}], {
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 365}], {
             RGBColor[
             0.7934880714285715, 0.807275142857143, 0.6535615714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 370}], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 227}], {
             RGBColor[0.8048095, 0.6892778571428573, 0.6017240714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 237}], {
             RGBColor[
             0.8886209285714286, 0.7552864285714288, 0.6099357857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 251}], {
             RGBColor[
             0.9392477857142858, 0.793796285714286, 0.545002142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 308}], {
             RGBColor[
             0.9418190000000001, 0.7924621428571431, 0.32812435714285737`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 375}], {
             RGBColor[
             0.9426130000000001, 0.7941604285714288, 0.4145463571428576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 116}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 151}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 154}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 286}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 291}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 304}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 383}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 141}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 172}], {
             RGBColor[
             0.9563532142857143, 0.8541327142857142, 0.5038997142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 179}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 240}], {
             RGBColor[
             0.9563532142857143, 0.8541327142857142, 0.5038997142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 279}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 285}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 337}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 399}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 124}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 149}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 210}], {
             RGBColor[0.905705, 0.5619482857142857, 0.38121900000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 249}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 266}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 293}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 315}], {
             RGBColor[
             0.9565498571428572, 0.8531865714285715, 0.42595535714285754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 316}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 387}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 397}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 128}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 155}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 170}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 187}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 202}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 261}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 306}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 353}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 122}], {
             RGBColor[
             0.9392477857142858, 0.793796285714286, 0.545002142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 166}], {
             RGBColor[
             0.9426130000000001, 0.7941604285714288, 0.4145463571428576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 169}], {
             RGBColor[
             0.8780430000000001, 0.5391035714285717, 0.21994842857142863`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 197}], {
             RGBColor[
             0.9392477857142858, 0.793796285714286, 0.545002142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 221}], {
             RGBColor[
             0.9392477857142858, 0.793796285714286, 0.545002142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 239}], {
             RGBColor[
             0.9050718571428572, 0.6575774285714289, 0.24228171428571435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 300}], {
             RGBColor[
             0.9313790000000001, 0.7572455714285717, 0.2875669285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 350}], {
             RGBColor[
             0.9418190000000001, 0.7924621428571431, 0.32812435714285737`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 392}], {
             RGBColor[0.535031, 0.4519726428571431, 0.5821868571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 151}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 154}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 265}], {
             RGBColor[
             0.9531846428571429, 0.8528224285714285, 0.556411142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 291}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 304}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 383}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 289}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 303}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 376}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 158}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 164}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 173}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 209}], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 241}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 323}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 346}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 354}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 388}], {
             RGBColor[
             0.9705375714285714, 0.9100928571428573, 0.35142707142857166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 389}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 126}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 127}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 129}], {
             RGBColor[
             0.9455993571428571, 0.8952721428571428, 0.6297402857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 196}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 231}], {
             RGBColor[
             0.9143667142857141, 0.9343765714285714, 0.9855006428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 235}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 317}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 326}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 327}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 336}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 396}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 132}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 160}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 187}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 202}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 206}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 217}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 220}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 233}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 244}], {
             RGBColor[
             0.9140786428571428, 0.6518141428571429, 0.5229159285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 307}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 321}], {
             RGBColor[
             0.9531846428571429, 0.8528224285714285, 0.556411142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 341}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 366}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 122}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 175}], {
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 178}], {
             RGBColor[
             0.9705375714285714, 0.9100928571428573, 0.35142707142857166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.9418190000000001, 0.7924621428571431, 0.32812435714285737`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 274}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 296}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 319}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 373}], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 166}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 169}], {
             RGBColor[
             0.9261557857142857, 0.7343485714285716, 0.5340778571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 175}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 178}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 268}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 274}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 319}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 351}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 131}], {
             RGBColor[
             0.8886209285714286, 0.7552864285714288, 0.6099357857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 140}], {
             RGBColor[0.8555595, 0.7289241428571431, 0.6067823571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 203}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.4924907142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 232}], {
             RGBColor[
             0.9307359285714285, 0.7879745714285716, 0.5829844285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 275}], {
             RGBColor[0.8555595, 0.7289241428571431, 0.6067823571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 280}], {
             RGBColor[
             0.8886209285714286, 0.7552864285714288, 0.6099357857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 297}], {
             RGBColor[
             0.9418190000000001, 0.7924621428571431, 0.32812435714285737`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 309}], {
             RGBColor[
             0.9426130000000001, 0.7941604285714288, 0.4145463571428576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 322}], {
             RGBColor[
             0.9198535714285715, 0.7161820000000003, 0.2541754285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 325}], {
             RGBColor[0.8555595, 0.7289241428571431, 0.6067823571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 339}], {
             RGBColor[
             0.9198535714285715, 0.7161820000000003, 0.2541754285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 149}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 185}], {
             RGBColor[
             0.9055667857142857, 0.6459924285714286, 0.5608982142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 210}], {
             RGBColor[
             0.8938279285714286, 0.5557624285714285, 0.5496570714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 219}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 249}], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 266}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 293}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 315}], {
             RGBColor[
             0.9446727857142856, 0.8470007142857143, 0.5943934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 316}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 338}], {
             RGBColor[
             0.8951604285714285, 0.9183474285714286, 0.9588940714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 387}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 397}], {
             RGBColor[
             0.8951604285714285, 0.9183474285714286, 0.9588940714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 148}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 162}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 211}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 214}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 248}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 263}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 276}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 288}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 196}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 289}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 317}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 326}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 327}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 336}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 376}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 129}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 216}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 231}], {
             RGBColor[
             0.9399022857142857, 0.9518417142857143, 0.8715537857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 235}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 298}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 313}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 317}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 336}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 361}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 393}], {
             RGBColor[
             0.9399022857142857, 0.9518417142857143, 0.8715537857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 396}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 133}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 155}], {
             RGBColor[0.9173395, 0.872917142857143, 0.6332385]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{128, 170}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 171}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 199}], {
             RGBColor[
             0.9600975714285714, 0.8748762857142858, 0.3108696428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 261}], {
             RGBColor[
             0.9455993571428571, 0.8952721428571428, 0.6297402857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 299}], {
             RGBColor[
             0.9600975714285714, 0.8748762857142858, 0.3108696428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 306}], {
             RGBColor[
             0.8842780714285714, 0.8465548571428572, 0.6300850714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 342}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 353}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 216}], {
             RGBColor[
             0.9600975714285714, 0.8748762857142858, 0.3108696428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 231}], {
             RGBColor[0.9173395, 0.872917142857143, 0.6332385]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{129, 235}], {
             RGBColor[
             0.9455993571428571, 0.8952721428571428, 0.6297402857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 298}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 313}], {
             RGBColor[
             0.9600975714285714, 0.8748762857142858, 0.3108696428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 317}], {
             RGBColor[
             0.9705375714285714, 0.9100928571428573, 0.35142707142857166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 336}], {
             RGBColor[
             0.9455993571428571, 0.8952721428571428, 0.6297402857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 361}], {
             RGBColor[
             0.9455993571428571, 0.8952721428571428, 0.6297402857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 393}], {
             RGBColor[0.9173395, 0.872917142857143, 0.6332385]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{129, 396}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 147}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 164}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 287}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 371}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 391}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 140}], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 186}], {
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 188}], {
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 203}], {
             RGBColor[
             0.9399022857142857, 0.9518417142857143, 0.8715537857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 228}], {
             RGBColor[
             0.9399022857142857, 0.9518417142857143, 0.8715537857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 238}], {
             RGBColor[0.607753, 0.6858761428571428, 0.9656044285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 273}], {
             RGBColor[0.9173395, 0.872917142857143, 0.6332385]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{131, 280}], {
             RGBColor[
             0.8861068571428571, 0.9120215714285714, 0.9889988571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 309}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 322}], {
             RGBColor[0.9173395, 0.872917142857143, 0.6332385]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{131, 325}], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 330}], {
             RGBColor[
             0.8861068571428571, 0.9120215714285714, 0.9889988571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 339}], {
             RGBColor[0.9173395, 0.872917142857143, 0.6332385]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{132, 160}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 202}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 220}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 244}], {
             RGBColor[
             0.9172472142857143, 0.6531244285714286, 0.47040450000000006`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 260}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 307}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 321}], {
             RGBColor[
             0.9563532142857143, 0.8541327142857142, 0.5038997142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 341}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 348}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 366}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 155}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 199}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 216}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 298}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 299}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 306}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 342}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 361}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 393}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 135}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 226}], {
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 234}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 239}], {
             RGBColor[
             0.9446727857142856, 0.8470007142857143, 0.5943934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 246}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 269}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 272}], {
             RGBColor[
             0.8951604285714285, 0.9183474285714286, 0.9588940714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 350}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 355}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 392}], {
             RGBColor[
             0.5746319285714285, 0.6413959285714286, 0.9342985714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 395}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 156}], {
             RGBColor[
             0.9455993571428571, 0.8952721428571428, 0.6297402857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 165}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 221}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 234}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 255}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 281}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 328}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 355}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 386}], {
             RGBColor[
             0.8917116428571428, 0.6356592857142858, 0.5843513571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 400}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 331}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 335}], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 394}], {
             RGBColor[
             0.9393049285714286, 0.9491972857142857, 0.7071874285714288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 169}], {
             RGBColor[
             0.9037887857142857, 0.7181937142857143, 0.5955132857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 175}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 178}], {
             RGBColor[
             0.9455993571428571, 0.8952721428571428, 0.6297402857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 197}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 252}], {
             RGBColor[
             0.9143667142857141, 0.9343765714285714, 0.9855006428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 278}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 282}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 300}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 314}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 319}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 352}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 159}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 215}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 218}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 229}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 329}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 349}], {
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 193}], {
             RGBColor[
             0.6202349285714286, 0.6862027857142857, 0.8984285714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 204}], {
             RGBColor[0.5978679285714286, 0.6700479285714285, 0.959864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 224}], {
             RGBColor[
             0.6202349285714286, 0.6862027857142857, 0.8984285714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 276}], {
             RGBColor[0.6234035, 0.6875130714285714, 0.8459171428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 290}], {
             RGBColor[
             0.6123661428571429, 0.6496520714285715, 0.6409933571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 318}], {
             RGBColor[0.6234035, 0.6875130714285714, 0.8459171428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 203}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 232}], {
             RGBColor[
             0.8951604285714285, 0.9183474285714286, 0.9588940714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 257}], {
             RGBColor[
             0.9036722857142857, 0.9241691428571428, 0.9209117857142859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 275}], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 280}], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 288}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 297}], {
             RGBColor[0.9062435, 0.9228350000000001, 0.7040340000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 309}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 322}], {
             RGBColor[
             0.8842780714285714, 0.8465548571428572, 0.6300850714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 325}], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 339}], {
             RGBColor[
             0.8842780714285714, 0.8465548571428572, 0.6300850714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 172}], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 243}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 279}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 285}], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 337}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 399}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 143}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 258}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 277}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 302}], {
             RGBColor[
             0.9455993571428571, 0.8952721428571428, 0.6297402857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 377}], {
             RGBColor[
             0.9308176428571429, 0.8366675714285714, 0.6178465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 378}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 379}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 258}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 277}], {
             RGBColor[
             0.9709799285714285, 0.9466688571428572, 0.6396786428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 302}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 377}], {
             RGBColor[
             0.9446727857142856, 0.8470007142857143, 0.5943934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 378}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 379}], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 186}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 188}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 200}], {
             RGBColor[
             0.8039280714285715, 0.8424917142857142, 0.6941190000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 228}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 333}], {
             RGBColor[
             0.9557558571428572, 0.8514882857142858, 0.3395333571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 368}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 200}], {
             RGBColor[0.7671809285714286, 0.707607, 0.6082763571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 207}], {
             RGBColor[
             0.9531846428571429, 0.8528224285714285, 0.556411142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 222}], {
             RGBColor[
             0.8694963571428571, 0.7879502857142857, 0.6181913571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 254}], {
             RGBColor[0.7671809285714286, 0.707607, 0.6082763571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 333}], {
             RGBColor[
             0.9190087142857143, 0.7166035714285715, 0.2536907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 227}], {
             RGBColor[
             0.8529222857142856, 0.8845228571428572, 0.9158535000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 302}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 375}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 377}], {
             RGBColor[
             0.9531846428571429, 0.8528224285714285, 0.556411142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 344}], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 354}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 371}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 388}], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 391}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 179}], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 232}], {
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 257}], {
             RGBColor[
             0.9367337142857142, 0.9505314285714286, 0.9240652142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 275}], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 276}], {
             RGBColor[
             0.9399022857142857, 0.9518417142857143, 0.8715537857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 279}], {
             RGBColor[
             0.9399022857142857, 0.9518417142857143, 0.8715537857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 288}], {
             RGBColor[
             0.9399022857142857, 0.9518417142857143, 0.8715537857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 195}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 210}], {
             RGBColor[
             0.9055083571428572, 0.5628944285714286, 0.45916335714285716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 247}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 249}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 253}], {
             RGBColor[
             0.9399022857142857, 0.9518417142857143, 0.8715537857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 266}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 315}], {
             RGBColor[
             0.9563532142857143, 0.8541327142857142, 0.5038997142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 316}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 358}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 359}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 362}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 363}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 369}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 397}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 192}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 283}], {
             RGBColor[
             0.8842780714285714, 0.8465548571428572, 0.6300850714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 294}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 320}], {
             RGBColor[0.9173395, 0.872917142857143, 0.6332385]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{150, 347}], {
             RGBColor[
             0.9600975714285714, 0.8748762857142858, 0.3108696428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 380}], {
             RGBColor[0.9173395, 0.872917142857143, 0.6332385]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{150, 381}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 384}], {
             RGBColor[
             0.9198535714285715, 0.7161820000000003, 0.2541754285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 168}], {
             RGBColor[
             0.9705375714285714, 0.9100928571428573, 0.35142707142857166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 265}], {
             RGBColor[
             0.9557558571428572, 0.8514882857142858, 0.3395333571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 291}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 304}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 378}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 383}], {
             RGBColor[
             0.9705375714285714, 0.9100928571428573, 0.35142707142857166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 154}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 180}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 198}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 236}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 267}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 284}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 332}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 367}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 383}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 398}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 161}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 184}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 372}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 180}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 236}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 267}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 286}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 291}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 332}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 383}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 170}], {
             RGBColor[
             0.9367337142857142, 0.9505314285714286, 0.9240652142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 171}], {
             RGBColor[
             0.9399022857142857, 0.9518417142857143, 0.8715537857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 199}], {
             RGBColor[
             0.9288649285714285, 0.9139807142857144, 0.6666300000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 261}], {
             RGBColor[
             0.9143667142857141, 0.9343765714285714, 0.9855006428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.9288649285714285, 0.9139807142857144, 0.6666300000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 306}], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 342}], {
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 353}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 361}], {
             RGBColor[
             0.9143667142857141, 0.9343765714285714, 0.9855006428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 165}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 221}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 245}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 255}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 328}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 364}], {
             RGBColor[
             0.9705375714285714, 0.9100928571428573, 0.35142707142857166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 386}], {
             RGBColor[
             0.8946844285714286, 0.5741998571428573, 0.23208921428571433`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 400}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 181}], {
             RGBColor[
             0.9531846428571429, 0.8528224285714285, 0.556411142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 191}], {
             RGBColor[
             0.9563532142857143, 0.8541327142857142, 0.5038997142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 334}], {
             RGBColor[
             0.9453158571428572, 0.8162717142857143, 0.29897592857142863`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 365}], {
             RGBColor[0.7671809285714286, 0.707607, 0.6082763571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 370}], {
             RGBColor[
             0.9453158571428572, 0.8162717142857143, 0.29897592857142863`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 209}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 241}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 270}], {
             RGBColor[
             0.9036722857142857, 0.9241691428571428, 0.9209117857142859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 310}], {
             RGBColor[
             0.9531846428571429, 0.8528224285714285, 0.556411142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 323}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 324}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 346}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 390}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 215}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 218}], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 329}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 349}], {
             RGBColor[
             0.9393049285714286, 0.9491972857142857, 0.7071874285714288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 217}], {
             RGBColor[
             0.9709799285714285, 0.9466688571428572, 0.6396786428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 220}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 233}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 244}], {
             RGBColor[
             0.9055667857142857, 0.6459924285714286, 0.5608982142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 263}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 264}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 307}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 312}], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 321}], {
             RGBColor[
             0.9446727857142856, 0.8470007142857143, 0.5943934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 341}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 348}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 366}], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 176}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 184}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 195}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 250}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 344}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 363}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 372}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 191}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 211}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 214}], {
             RGBColor[
             0.9367337142857142, 0.9505314285714286, 0.9240652142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 248}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 263}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 312}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 340}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 348}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 167}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 174}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 222}], {
             RGBColor[
             0.9036722857142857, 0.9241691428571428, 0.9209117857142859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 226}], {
             RGBColor[
             0.9367337142857142, 0.9505314285714286, 0.9240652142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 395}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 287}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 292}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 354}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 371}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 374}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 388}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 389}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 391}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 182}], {
             RGBColor[
             0.9709799285714285, 0.9466688571428572, 0.6396786428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 256}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 281}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 311}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 328}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 386}], {
             RGBColor[
             0.9055667857142857, 0.6459924285714286, 0.5608982142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 400}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 169}], {
             RGBColor[0.929521, 0.7347127142857144, 0.4036220714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 178}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 197}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.9565498571428572, 0.8531865714285715, 0.42595535714285754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 300}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 319}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 174}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 183}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 189}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 222}], {
             RGBColor[0.9062435, 0.9228350000000001, 0.7040340000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 238}], {
             RGBColor[
             0.6609510714285715, 0.7230518571428571, 0.6837930000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 246}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 269}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 272}], {
             RGBColor[0.9062435, 0.9228350000000001, 0.7040340000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 309}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 395}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 265}], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 304}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 378}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 177}], {
             RGBColor[
             0.9182870000000001, 0.6977978571428574, 0.2766426428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 178}], {
             RGBColor[
             0.9067615714285715, 0.6567342857142858, 0.2432511428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 197}], {
             RGBColor[
             0.9261557857142857, 0.7343485714285716, 0.5340778571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 239}], {
             RGBColor[
             0.8919798571428572, 0.5981297142857144, 0.2313574285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 300}], {
             RGBColor[
             0.9182870000000001, 0.6977978571428574, 0.2766426428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 319}], {
             RGBColor[
             0.9037887857142857, 0.7181937142857143, 0.5955132857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 171}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 187}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 261}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 299}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 306}], {
             RGBColor[
             0.9036722857142857, 0.9241691428571428, 0.9209117857142859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 353}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 361}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 299}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 306}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 342}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 353}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 208}], {
             RGBColor[
             0.9190087142857143, 0.7166035714285715, 0.2536907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 225}], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 240}], {
             RGBColor[
             0.9190087142857143, 0.7166035714285715, 0.2536907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 243}], {
             RGBColor[
             0.9531846428571429, 0.8528224285714285, 0.556411142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 285}], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 337}], {
             RGBColor[
             0.9446727857142856, 0.8470007142857143, 0.5943934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 357}], {
             RGBColor[
             0.9563532142857143, 0.8541327142857142, 0.5038997142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 399}], {
             RGBColor[
             0.9563532142857143, 0.8541327142857142, 0.5038997142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 176}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 209}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 250}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 323}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 354}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 388}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 183}], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 189}], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 238}], {
             RGBColor[
             0.6498679999999999, 0.7185642857142857, 0.9386530714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 246}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 269}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 272}], {
             RGBColor[
             0.8951604285714285, 0.9183474285714286, 0.9588940714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 309}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 325}], {
             RGBColor[
             0.8951604285714285, 0.9183474285714286, 0.9588940714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 395}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 178}], {
             RGBColor[
             0.9600975714285714, 0.8748762857142858, 0.3108696428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 213}], {
             RGBColor[
             0.9313790000000001, 0.7572455714285717, 0.2875669285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 227}], {
             RGBColor[
             0.8450534999999999, 0.847972142857143, 0.6584182857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 278}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 296}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 314}], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 319}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 352}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 250}], {
             RGBColor[
             0.9600975714285714, 0.8748762857142858, 0.3108696428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 344}], {
             RGBColor[
             0.9600975714285714, 0.8748762857142858, 0.3108696428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 354}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 356}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 372}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 388}], {
             RGBColor[
             0.9600975714285714, 0.8748762857142858, 0.3108696428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 197}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 225}], {
             RGBColor[
             0.9600975714285714, 0.8748762857142858, 0.3108696428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 243}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 252}], {
             RGBColor[
             0.9288649285714285, 0.9139807142857144, 0.6666300000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 300}], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 337}], {
             RGBColor[
             0.9709799285714285, 0.9466688571428572, 0.639678642857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 367}], {
             RGBColor[
             0.9709799285714285, 0.9466688571428572, 0.639678642857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 398}], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 197}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 274}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 278}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 300}], {
             RGBColor[
             0.9600975714285714, 0.8748762857142858, 0.3108696428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 319}], {
             RGBColor[
             0.9455993571428571, 0.8952721428571428, 0.6297402857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 352}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 232}], {
             RGBColor[
             0.8951604285714285, 0.9183474285714286, 0.9588940714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 257}], {
             RGBColor[
             0.9036722857142857, 0.9241691428571428, 0.9209117857142859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 275}], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 279}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 285}], {
             RGBColor[
             0.8842780714285714, 0.8465548571428572, 0.6300850714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 288}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 399}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 198}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 236}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 262}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 267}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 284}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 286}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 332}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 367}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 398}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 191}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 211}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 214}], {
             RGBColor[
             0.9367337142857142, 0.9505314285714286, 0.9240652142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 305}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 334}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 340}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 365}], {
             RGBColor[
             0.8013568571428571, 0.8438258571428572, 0.9109967857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 370}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 256}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 281}], {
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 311}], {
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 386}], {
             RGBColor[
             0.9062098571428572, 0.6152634285714287, 0.26548071428571435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 238}], {
             RGBColor[
             0.6498679999999999, 0.7185642857142857, 0.9386530714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 246}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 269}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 272}], {
             RGBColor[
             0.8951604285714285, 0.9183474285714286, 0.9588940714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 280}], {
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 309}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 325}], {
             RGBColor[
             0.8951604285714285, 0.9183474285714286, 0.9588940714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 339}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 395}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 343}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 356}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 369}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 372}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 198}], {
             RGBColor[
             0.9174438571428571, 0.6521782857142857, 0.39246014285714326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 205}], {
             RGBColor[
             0.9062098571428572, 0.6152634285714287, 0.26548071428571435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 208}], {
             RGBColor[
             0.8799027142857143, 0.5155952857142858, 0.22019550000000004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 210}], {
             RGBColor[
             0.8290578571428572, 0.22435700000000006`, 0.17545914285714287`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 219}], {
             RGBColor[
             0.9174438571428571, 0.6521782857142857, 0.39246014285714326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 249}], {
             RGBColor[
             0.9055667857142857, 0.6459924285714287, 0.5608982142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 284}], {
             RGBColor[
             0.9174438571428571, 0.6521782857142857, 0.39246014285714326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 293}], {
             RGBColor[
             0.9140786428571428, 0.6518141428571429, 0.5229159285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 338}], {
             RGBColor[
             0.8303903571428572, 0.5869420000000001, 0.5846961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 188}], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 228}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 238}], {
             RGBColor[
             0.6498679999999999, 0.7185642857142857, 0.9386530714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 273}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 322}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 330}], {
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 206}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 220}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 261}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 321}], {
             RGBColor[
             0.9565498571428572, 0.8531865714285715, 0.42595535714285754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 228}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 238}], {
             RGBColor[
             0.6498679999999999, 0.7185642857142857, 0.9386530714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 273}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 322}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 330}], {
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 222}], {
             RGBColor[
             0.8951604285714285, 0.9183474285714286, 0.9588940714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 226}], {
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 395}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 212}], {
             RGBColor[
             0.9455993571428571, 0.8952721428571428, 0.6297402857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 221}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 255}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 268}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 270}], {
             RGBColor[
             0.8813052857142857, 0.9080142857142857, 0.9823472142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 274}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 295}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 324}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 351}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 211}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 214}], {
             RGBColor[
             0.9399022857142857, 0.9518417142857143, 0.8715537857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 312}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 334}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 340}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 365}], {
             RGBColor[
             0.8045254285714285, 0.8451361428571429, 0.8584853571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 370}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 292}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 320}], {
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 347}], {
             RGBColor[
             0.9709799285714285, 0.9466688571428572, 0.6396786428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 374}], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 382}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 384}], {
             RGBColor[
             0.9307359285714285, 0.7879745714285716, 0.5829844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 248}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 305}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 334}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 360}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 201}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 208}], {
             RGBColor[
             0.9563532142857143, 0.8541327142857142, 0.5038997142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 223}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 230}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 242}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 357}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 364}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 385}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 387}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 247}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 253}], {
             RGBColor[
             0.9367337142857142, 0.9505314285714286, 0.9240652142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 315}], {
             RGBColor[
             0.9531846428571429, 0.8528224285714285, 0.556411142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 316}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 343}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 358}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 359}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 362}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 363}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 369}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 372}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 397}], {
             RGBColor[
             0.9036722857142857, 0.9241691428571428, 0.9209117857142859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 289}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 317}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 326}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 327}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 336}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 376}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 252}], {
             RGBColor[
             0.9367337142857142, 0.9505314285714286, 0.9240652142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 300}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 205}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 219}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 236}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 284}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 332}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 367}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 398}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 216}], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 298}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 299}], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 306}], {
             RGBColor[0.8958035, 0.8876184285714286, 0.6634765714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 342}], {
             RGBColor[
             0.9709799285714285, 0.9466688571428572, 0.639678642857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 353}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 361}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 393}], {
             RGBColor[
             0.9288649285714285, 0.9139807142857144, 0.6666300000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 207}], {
             RGBColor[
             0.8013568571428571, 0.8438258571428572, 0.9109967857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 333}], {
             RGBColor[0.7671809285714286, 0.707607, 0.6082763571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 368}], {
             RGBColor[0.8047220714285714, 0.84419, 0.7805410000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 223}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 230}], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 245}], {
             RGBColor[
             0.9709799285714285, 0.9466688571428572, 0.639678642857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 364}], {
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 385}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 218}], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 229}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 260}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 307}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 341}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 349}], {
             RGBColor[
             0.9393049285714286, 0.9491972857142857, 0.7071874285714288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 366}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 232}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 257}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 275}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 280}], {
             RGBColor[
             0.9399022857142857, 0.9518417142857143, 0.8715537857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 297}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 309}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 322}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 325}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 339}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 224}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 276}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 290}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 297}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 318}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 345}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 219}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 284}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 293}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 338}], {
             RGBColor[0.8958035, 0.8876184285714286, 0.6634765714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 220}], {
             RGBColor[
             0.9455993571428571, 0.8952721428571428, 0.6297402857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 321}], {
             RGBColor[
             0.9308176428571429, 0.8366675714285714, 0.6178465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 328}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 386}], {
             RGBColor[
             0.8917116428571428, 0.6356592857142858, 0.5843513571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 254}], {
             RGBColor[
             0.8013568571428571, 0.8438258571428572, 0.9109967857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 333}], {
             RGBColor[
             0.9531846428571429, 0.8528224285714285, 0.556411142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 230}], {
             RGBColor[
             0.9453158571428572, 0.8162717142857143, 0.29897592857142863`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 240}], {
             RGBColor[
             0.9190087142857143, 0.7166035714285715, 0.2536907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 242}], {
             RGBColor[
             0.9453158571428572, 0.8162717142857143, 0.29897592857142863`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 357}], {
             RGBColor[
             0.9563532142857143, 0.8541327142857142, 0.5038997142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 385}], {
             RGBColor[
             0.9563532142857143, 0.8541327142857142, 0.5038997142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 387}], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 241}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 270}], {
             RGBColor[0.9062435, 0.9228350000000001, 0.7040340000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 310}], {
             RGBColor[
             0.9557558571428572, 0.8514882857142858, 0.3395333571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 323}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 346}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 390}], {
             RGBColor[
             0.9705375714285714, 0.9100928571428573, 0.35142707142857166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 249}], {
             RGBColor[
             0.8938279285714286, 0.5557624285714285, 0.5496570714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 266}], {
             RGBColor[
             0.8829455714285714, 0.4839698571428572, 0.22084807142857144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 293}], {
             RGBColor[
             0.9023397857142856, 0.5615841428571429, 0.5116747857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 315}], {
             RGBColor[
             0.8681638571428572, 0.4253652857142857, 0.20895435714285715`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 316}], {
             RGBColor[
             0.8829455714285714, 0.4839698571428572, 0.22084807142857144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 387}], {
             RGBColor[
             0.8829455714285714, 0.4839698571428572, 0.22084807142857144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 397}], {
             RGBColor[0.8186515000000001, 0.496712, 0.573455]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{211, 214}], {
             RGBColor[
             0.9399022857142857, 0.9518417142857143, 0.8715537857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 248}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 263}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 312}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 334}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 340}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 370}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 268}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 270}], {
             RGBColor[
             0.8842780714285714, 0.8465548571428572, 0.6300850714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 274}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 295}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 310}], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 324}], {
             RGBColor[
             0.9455993571428571, 0.8952721428571428, 0.6297402857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 351}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 373}], {
             RGBColor[
             0.9705375714285714, 0.9100928571428573, 0.35142707142857166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 390}], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 227}], {
             RGBColor[0.8048095, 0.6892778571428573, 0.6017240714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 296}], {
             RGBColor[
             0.9392477857142858, 0.793796285714286, 0.545002142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 308}], {
             RGBColor[
             0.9418190000000001, 0.7924621428571431, 0.32812435714285737`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 352}], {
             RGBColor[
             0.9426130000000001, 0.7941604285714288, 0.4145463571428576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 248}], {
             RGBColor[
             0.9143667142857141, 0.9343765714285714, 0.9855006428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 263}], {
             RGBColor[
             0.9399022857142857, 0.9518417142857143, 0.8715537857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 312}], {
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 340}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 218}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 229}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 329}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 349}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 231}], {
             RGBColor[
             0.9288649285714285, 0.9139807142857144, 0.6666300000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 235}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 298}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 313}], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 361}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 393}], {
             RGBColor[
             0.9288649285714285, 0.9139807142857144, 0.6666300000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 396}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 220}], {
             RGBColor[
             0.9600975714285714, 0.8748762857142858, 0.3108696428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 230}], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 233}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 242}], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 244}], {
             RGBColor[
             0.9062098571428572, 0.6152634285714287, 0.26548071428571435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 264}], {
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 321}], {
             RGBColor[
             0.9453158571428572, 0.8162717142857143, 0.29897592857142863`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 357}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 364}], {
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 366}], {
             RGBColor[
             0.9709799285714285, 0.9466688571428572, 0.639678642857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 229}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 260}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 329}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 349}], {
             RGBColor[
             0.9393049285714286, 0.9491972857142857, 0.7071874285714288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 284}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 293}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 338}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 233}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 244}], {
             RGBColor[
             0.8946844285714286, 0.5741998571428573, 0.23208921428571433`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 321}], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 341}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 366}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 239}], {
             RGBColor[
             0.9531846428571429, 0.8528224285714285, 0.556411142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 255}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 268}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 324}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 351}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 400}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 333}], {
             RGBColor[
             0.8694963571428571, 0.7879502857142857, 0.6181913571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 230}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 242}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 245}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 328}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 364}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 385}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 290}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 318}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 345}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 240}], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 243}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 337}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 367}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 398}], {
             RGBColor[
             0.9600975714285714, 0.8748762857142858, 0.3108696428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 234}], {
             RGBColor[
             0.9143667142857141, 0.9343765714285714, 0.9855006428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 281}], {
             RGBColor[
             0.9393049285714286, 0.9491972857142857, 0.7071874285714288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 350}], {
             RGBColor[
             0.9393049285714286, 0.9491972857142857, 0.7071874285714288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 355}], {
             RGBColor[
             0.9399022857142857, 0.9518417142857143, 0.8715537857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 392}], {
             RGBColor[
             0.5325169285714285, 0.6087077857142857, 0.9612499285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 395}], {
             RGBColor[
             0.9143667142857141, 0.9343765714285714, 0.9855006428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 296}], {
             RGBColor[
             0.8529222857142856, 0.8845228571428572, 0.9158535000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 308}], {
             RGBColor[
             0.8554934999999999, 0.8831887142857142, 0.6989757142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 352}], {
             RGBColor[0.8562875, 0.884887, 0.7853977142857147]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{227, 375}], {
             RGBColor[0.8562875, 0.884887, 0.7853977142857147]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{228, 238}], {
             RGBColor[
             0.6615484285714286, 0.7256962857142857, 0.8481593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 273}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 330}], {
             RGBColor[
             0.9399022857142857, 0.9518417142857143, 0.8715537857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 368}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 260}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 349}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 233}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 242}], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 244}], {
             RGBColor[
             0.9062098571428572, 0.6152634285714287, 0.26548071428571435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 245}], {
             RGBColor[
             0.9709799285714285, 0.9466688571428572, 0.639678642857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 328}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 357}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 364}], {
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 385}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 235}], {
             RGBColor[
             0.9143667142857141, 0.9343765714285714, 0.9855006428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 298}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 336}], {
             RGBColor[
             0.9143667142857141, 0.9343765714285714, 0.9855006428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 393}], {
             RGBColor[
             0.8861068571428571, 0.9120215714285714, 0.9889988571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 396}], {
             RGBColor[
             0.9367337142857142, 0.9505314285714286, 0.9240652142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 257}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 275}], {
             RGBColor[
             0.8951604285714285, 0.9183474285714286, 0.9588940714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 279}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 280}], {
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 288}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 297}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 309}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 325}], {
             RGBColor[
             0.8951604285714285, 0.9183474285714286, 0.9588940714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 339}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 242}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 244}], {
             RGBColor[
             0.9174438571428571, 0.6521782857142858, 0.39246014285714326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 264}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 307}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 348}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 357}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 366}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[
             0.9308176428571429, 0.8366675714285714, 0.6178465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 246}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 269}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 272}], {
             RGBColor[
             0.8813052857142857, 0.9080142857142857, 0.9823472142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 350}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 355}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 392}], {
             RGBColor[
             0.5607767857142857, 0.6310627857142856, 0.9577517142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 395}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 298}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 313}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 317}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 336}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 393}], {
             RGBColor[
             0.9143667142857141, 0.9343765714285714, 0.9855006428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 396}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 267}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 284}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 286}], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 332}], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 367}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 383}], {
             RGBColor[
             0.9705375714285714, 0.9100928571428573, 0.35142707142857166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 398}], {
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 251}], {
             RGBColor[
             0.9367337142857142, 0.9505314285714286, 0.9240652142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 296}], {
             RGBColor[
             0.9367337142857142, 0.9505314285714286, 0.9240652142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 308}], {
             RGBColor[
             0.9393049285714286, 0.9491972857142857, 0.7071874285714288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 380}], {
             RGBColor[
             0.8861068571428571, 0.9120215714285714, 0.9889988571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 269}], {
             RGBColor[
             0.6615484285714286, 0.7256962857142857, 0.8481593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 272}], {
             RGBColor[0.5746915714285714, 0.6595138571428572, 0.962451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 280}], {
             RGBColor[0.607753, 0.6858761428571428, 0.9656044285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 309}], {
             RGBColor[
             0.6617450714285715, 0.7247501428571428, 0.7702150000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 325}], {
             RGBColor[0.5746915714285714, 0.6595138571428572, 0.962451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 339}], {
             RGBColor[
             0.6389856428571429, 0.6467717142857143, 0.6098440714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 246}], {
             RGBColor[
             0.9308176428571429, 0.8366675714285714, 0.6178465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 269}], {
             RGBColor[
             0.9563532142857143, 0.8541327142857142, 0.5038997142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 272}], {
             RGBColor[
             0.8694963571428571, 0.7879502857142857, 0.6181913571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 350}], {
             RGBColor[
             0.9557558571428572, 0.8514882857142858, 0.3395333571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 355}], {
             RGBColor[
             0.9563532142857143, 0.8541327142857142, 0.5038997142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 392}], {
             RGBColor[
             0.5489678571428571, 0.5109987857142857, 0.5935958571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 242}], {
             RGBColor[
             0.9453158571428572, 0.8162717142857143, 0.29897592857142863`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 243}], {
             RGBColor[
             0.9531846428571429, 0.8528224285714285, 0.556411142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 285}], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 337}], {
             RGBColor[
             0.9446727857142856, 0.8470007142857143, 0.5943934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 357}], {
             RGBColor[
             0.9563532142857143, 0.8541327142857142, 0.5038997142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 399}], {
             RGBColor[
             0.9563532142857143, 0.8541327142857142, 0.5038997142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 270}], {
             RGBColor[
             0.8951604285714285, 0.9183474285714286, 0.9588940714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 310}], {
             RGBColor[
             0.9446727857142856, 0.8470007142857143, 0.5943934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 323}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 346}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 389}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 390}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 244}], {
             RGBColor[
             0.9062098571428572, 0.6152634285714287, 0.26548071428571435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 357}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 364}], {
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 385}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 337}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 367}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 398}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 264}], {
             RGBColor[
             0.9166498571428572, 0.6504800000000002, 0.30603814285714304`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 307}], {
             RGBColor[
             0.8917116428571428, 0.6356592857142858, 0.5843513571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 321}], {
             RGBColor[
             0.8799027142857143, 0.5155952857142858, 0.22019550000000004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 341}], {
             RGBColor[
             0.9140786428571428, 0.6518141428571429, 0.5229159285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 348}], {
             RGBColor[
             0.9174438571428571, 0.6521782857142857, 0.39246014285714326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 357}], {
             RGBColor[0.9172472142857143, 0.6531244285714286, 0.4704045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 366}], {
             RGBColor[
             0.9055667857142857, 0.6459924285714287, 0.5608982142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 328}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 364}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 400}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 269}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 272}], {
             RGBColor[
             0.8813052857142857, 0.9080142857142857, 0.9823472142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 350}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 355}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 392}], {
             RGBColor[
             0.5607767857142857, 0.6310627857142856, 0.9577517142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 395}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 253}], {
             RGBColor[
             0.9399022857142857, 0.9518417142857143, 0.8715537857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 266}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 301}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 315}], {
             RGBColor[
             0.9563532142857143, 0.8541327142857142, 0.5038997142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 316}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 343}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 358}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 359}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 362}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 363}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 369}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 397}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 276}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 340}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 360}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 266}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 293}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 315}], {
             RGBColor[
             0.9446727857142856, 0.8470007142857143, 0.5943934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 316}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 387}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 397}], {
             RGBColor[
             0.8951604285714285, 0.9183474285714286, 0.9588940714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 356}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 363}], {
             RGBColor[
             0.9600975714285714, 0.8748762857142858, 0.3108696428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 372}], {
             RGBColor[
             0.9455993571428571, 0.8952721428571428, 0.6297402857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 283}], {
             RGBColor[
             0.9036722857142857, 0.9241691428571428, 0.9209117857142859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 308}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 380}], {
             RGBColor[
             0.9367337142857142, 0.9505314285714286, 0.9240652142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 381}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 282}], {
             RGBColor[
             0.9399022857142857, 0.9518417142857143, 0.8715537857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 300}], {
             RGBColor[
             0.9288649285714285, 0.9139807142857144, 0.6666300000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 367}], {
             RGBColor[0.9282218571428571, 0.9447097142857143, 0.9620475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 398}], {
             RGBColor[
             0.9288649285714285, 0.9139807142857144, 0.6666300000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 266}], {
             RGBColor[0.9173395, 0.872917142857143, 0.6332385]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{253, 301}], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 315}], {
             RGBColor[
             0.9025577857142857, 0.8143125714285715, 0.6213447857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 316}], {
             RGBColor[0.9173395, 0.872917142857143, 0.6332385]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{253, 343}], {
             RGBColor[
             0.9288649285714285, 0.9139807142857144, 0.6666300000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 358}], {
             RGBColor[
             0.9399022857142857, 0.9518417142857143, 0.8715537857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 359}], {
             RGBColor[
             0.9143667142857141, 0.9343765714285714, 0.9855006428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 362}], {
             RGBColor[
             0.9367337142857142, 0.9505314285714286, 0.9240652142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 369}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 394}], {
             RGBColor[
             0.8861068571428571, 0.9120215714285714, 0.9889988571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 397}], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 303}], {
             RGBColor[
             0.8045254285714285, 0.8451361428571429, 0.8584853571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 268}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 324}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 328}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 351}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 400}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 311}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 313}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 386}], {
             RGBColor[
             0.9172472142857143, 0.6531244285714286, 0.47040450000000006`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 275}], {
             RGBColor[
             0.9036722857142857, 0.9241691428571428, 0.9209117857142859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 276}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 279}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 280}], {
             RGBColor[
             0.9367337142857142, 0.9505314285714286, 0.9240652142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 288}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 309}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 325}], {
             RGBColor[
             0.9036722857142857, 0.9241691428571428, 0.9209117857142859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 339}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 277}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 302}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 377}], {
             RGBColor[
             0.9531846428571429, 0.8528224285714285, 0.556411142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 378}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 379}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 262}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 331}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 335}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 307}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 329}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 341}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 349}], {
             RGBColor[
             0.9367337142857142, 0.9505314285714286, 0.9240652142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 366}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 306}], {
             RGBColor[
             0.8813052857142857, 0.9080142857142857, 0.9823472142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 284}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 286}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 331}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 332}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 338}], {
             RGBColor[
             0.8813052857142857, 0.9080142857142857, 0.9823472142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 264}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 312}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 348}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 307}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 312}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 348}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 357}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 366}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 291}], {
             RGBColor[
             0.9531846428571429, 0.8528224285714285, 0.556411142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 304}], {
             RGBColor[
             0.9563532142857143, 0.8541327142857142, 0.5038997142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 378}], {
             RGBColor[
             0.9531846428571429, 0.8528224285714285, 0.556411142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 383}], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 293}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 315}], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 316}], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 338}], {
             RGBColor[
             0.8842780714285714, 0.8465548571428572, 0.6300850714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 397}], {
             RGBColor[
             0.8842780714285714, 0.8465548571428572, 0.6300850714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 282}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 332}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 367}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 383}], {
             RGBColor[
             0.9455993571428571, 0.8952721428571428, 0.6297402857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 398}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 270}], {
             RGBColor[
             0.8951604285714285, 0.9183474285714286, 0.9588940714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 274}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 295}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 324}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 351}], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 373}], {
             RGBColor[
             0.9814199285714285, 0.9818854285714286, 0.6802360714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 272}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 350}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 355}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 392}], {
             RGBColor[
             0.5863123571428571, 0.6485279285714286, 0.8438048571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 395}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 295}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 310}], {
             RGBColor[
             0.8694963571428571, 0.7879502857142857, 0.6181913571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 324}], {
             RGBColor[
             0.8813052857142857, 0.9080142857142857, 0.9823472142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 346}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 351}], {
             RGBColor[
             0.8951604285714285, 0.9183474285714286, 0.9588940714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 373}], {
             RGBColor[0.9062435, 0.9228350000000001, 0.7040340000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 390}], {
             RGBColor[
             0.8842780714285714, 0.8465548571428572, 0.6300850714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 287}], {
             RGBColor[
             0.9531846428571429, 0.8528224285714285, 0.556411142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 292}], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 371}], {
             RGBColor[
             0.9446727857142856, 0.8470007142857143, 0.5943934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 374}], {
             RGBColor[
             0.9446727857142856, 0.8470007142857143, 0.5943934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 382}], {
             RGBColor[
             0.9563532142857143, 0.8541327142857142, 0.5038997142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 384}], {
             RGBColor[
             0.9050718571428572, 0.6575774285714289, 0.24228171428571435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 389}], {
             RGBColor[
             0.9565498571428572, 0.8531865714285715, 0.42595535714285754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 391}], {
             RGBColor[
             0.9563532142857143, 0.8541327142857142, 0.5038997142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 350}], {
             RGBColor[0.9062435, 0.9228350000000001, 0.7040340000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 392}], {
             RGBColor[0.49945550000000005`, 0.5823455, 0.9580965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 395}], {
             RGBColor[
             0.8813052857142857, 0.9080142857142857, 0.9823472142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 322}], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 330}], {
             RGBColor[0.9173395, 0.872917142857143, 0.6332385]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{274, 295}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 296}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 319}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 324}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 351}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 373}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 276}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 280}], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 288}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 290}], {
             RGBColor[0.8958035, 0.8876184285714286, 0.6634765714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 297}], {
             RGBColor[0.9062435, 0.9228350000000001, 0.7040340000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 318}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 325}], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 339}], {
             RGBColor[
             0.8842780714285714, 0.8465548571428572, 0.6300850714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 288}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 290}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 297}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 318}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 278}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 302}], {
             RGBColor[
             0.9600975714285714, 0.8748762857142858, 0.3108696428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 314}], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 352}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 378}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 379}], {
             RGBColor[
             0.9709799285714285, 0.9466688571428572, 0.639678642857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 314}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 319}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 352}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 379}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 288}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 309}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 325}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 399}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 297}], {
             RGBColor[
             0.9393049285714286, 0.9491972857142857, 0.7071874285714288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 309}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 322}], {
             RGBColor[0.9173395, 0.872917142857143, 0.6332385]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{280, 325}], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 339}], {
             RGBColor[0.9173395, 0.872917142857143, 0.6332385]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{281, 355}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 386}], {
             RGBColor[
             0.9166498571428572, 0.6504800000000001, 0.30603814285714304`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 367}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 383}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 398}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 294}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 320}], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 347}], {
             RGBColor[0.8958035, 0.8876184285714286, 0.6634765714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 373}], {
             RGBColor[0.9062435, 0.9228350000000001, 0.7040340000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 380}], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 381}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 332}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 338}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 367}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 399}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 332}], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 292}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 371}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 374}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 382}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 384}], {
             RGBColor[
             0.9392477857142858, 0.793796285714286, 0.545002142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 389}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 391}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 303}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 376}], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 297}], {
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 318}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 345}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 304}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 383}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 371}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 374}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 382}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 384}], {
             RGBColor[
             0.9198535714285715, 0.7161820000000003, 0.2541754285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 389}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 316}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 387}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 320}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 347}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 380}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 381}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 310}], {
             RGBColor[
             0.9563532142857143, 0.8541327142857142, 0.5038997142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 324}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 351}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 373}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 390}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 308}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 373}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 380}], {
             RGBColor[
             0.9367337142857142, 0.9505314285714286, 0.9240652142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 318}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 322}], {
             RGBColor[
             0.9705375714285714, 0.9100928571428573, 0.35142707142857166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 339}], {
             RGBColor[
             0.9705375714285714, 0.9100928571428573, 0.35142707142857166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 313}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 361}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 393}], {
             RGBColor[
             0.9400989285714285, 0.9508955714285714, 0.793609428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 396}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 306}], {
             RGBColor[0.8958035, 0.8876184285714286, 0.6634765714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 342}], {
             RGBColor[
             0.9709799285714285, 0.9466688571428572, 0.639678642857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 353}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 319}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 343}], {
             RGBColor[0.8958035, 0.8876184285714286, 0.6634765714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 358}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 359}], {
             RGBColor[
             0.8813052857142857, 0.9080142857142857, 0.9823472142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 362}], {
             RGBColor[
             0.9036722857142857, 0.9241691428571428, 0.9209117857142859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 369}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 394}], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 397}], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 314}], {
             RGBColor[
             0.9600975714285714, 0.8748762857142858, 0.3108696428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 352}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 377}], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 379}], {
             RGBColor[
             0.9594544999999999, 0.9056052857142858, 0.6062871428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 376}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 383}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 334}], {
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 340}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 360}], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 370}], {
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 342}], {
             RGBColor[
             0.8951604285714285, 0.9183474285714286, 0.9588940714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 353}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 361}], {
             RGBColor[
             0.8813052857142857, 0.9080142857142857, 0.9823472142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 312}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 341}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 348}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 366}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 325}], {
             RGBColor[0.9070375, 0.9245332857142857, 0.7904560000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 339}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 323}], {
             RGBColor[
             0.9563532142857143, 0.8541327142857142, 0.5038997142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 324}], {
             RGBColor[
             0.9308176428571429, 0.8366675714285714, 0.6178465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 346}], {
             RGBColor[
             0.9565498571428572, 0.8531865714285715, 0.42595535714285754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 389}], {
             RGBColor[
             0.9565498571428572, 0.8531865714285715, 0.42595535714285754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 390}], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 313}], {
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 361}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 386}], {
             RGBColor[
             0.9166498571428572, 0.6504800000000001, 0.30603814285714304`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 348}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 366}], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 361}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 393}], {
             RGBColor[
             0.9288649285714285, 0.9139807142857144, 0.6666300000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 396}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 352}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 379}], {
             RGBColor[
             0.9709799285714285, 0.9466688571428572, 0.639678642857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 316}], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 358}], {
             RGBColor[
             0.9563532142857143, 0.8541327142857142, 0.5038997142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 359}], {
             RGBColor[
             0.9308176428571429, 0.8366675714285714, 0.6178465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 362}], {
             RGBColor[
             0.9531846428571429, 0.8528224285714285, 0.556411142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 363}], {
             RGBColor[
             0.9453158571428572, 0.8162717142857143, 0.29897592857142863`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 369}], {
             RGBColor[
             0.9565498571428572, 0.8531865714285715, 0.42595535714285754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 397}], {
             RGBColor[
             0.8694963571428571, 0.7879502857142857, 0.6181913571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 358}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 359}], {
             RGBColor[
             0.9455993571428571, 0.8952721428571428, 0.6297402857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 362}], {
             RGBColor[0.9679663571428572, 0.911427, 0.5683048571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 363}], {
             RGBColor[
             0.9600975714285714, 0.8748762857142858, 0.3108696428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 369}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 397}], {
             RGBColor[
             0.8842780714285714, 0.8465548571428572, 0.6300850714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 326}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 327}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 336}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 396}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 345}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 347}], {
             RGBColor[
             0.9288649285714285, 0.9139807142857144, 0.6666300000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 380}], {
             RGBColor[
             0.8861068571428571, 0.9120215714285714, 0.9889988571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 381}], {
             RGBColor[
             0.9399022857142857, 0.9518417142857143, 0.8715537857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 384}], {
             RGBColor[
             0.8886209285714286, 0.7552864285714288, 0.6099357857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 341}], {
             RGBColor[
             0.9531846428571429, 0.8528224285714285, 0.556411142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 366}], {
             RGBColor[
             0.9446727857142856, 0.8470007142857143, 0.5943934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 330}], {
             RGBColor[0.9173395, 0.872917142857143, 0.6332385]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{322, 339}], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 346}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 346}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 351}], {
             RGBColor[
             0.9564817142857142, 0.9670647142857143, 0.9585492857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 390}], {
             RGBColor[
             0.9455993571428571, 0.8952721428571428, 0.6297402857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 339}], {
             RGBColor[
             0.8842780714285714, 0.8465548571428572, 0.6300850714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 327}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 336}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 336}], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 376}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 364}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 386}], {
             RGBColor[
             0.9174438571428571, 0.6521782857142858, 0.39246014285714326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 400}], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 349}], {
             RGBColor[
             0.9367337142857142, 0.9505314285714286, 0.9240652142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 335}], {
             RGBColor[
             0.9899317857142858, 0.9877071428571429, 0.642253785714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 338}], {
             RGBColor[
             0.9036722857142857, 0.9241691428571428, 0.9209117857142859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 368}], {
             RGBColor[
             0.9565498571428572, 0.8531865714285715, 0.42595535714285754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 340}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 360}], {
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 365}], {
             RGBColor[
             0.7934880714285715, 0.807275142857143, 0.6535615714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 370}], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 394}], {
             RGBColor[
             0.9393049285714286, 0.9491972857142857, 0.7071874285714288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 396}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 367}], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 398}], {
             RGBColor[
             0.9709799285714285, 0.9466688571428572, 0.6396786428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 399}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 360}], {
             RGBColor[
             0.9932970000000001, 0.9880712857142857, 0.5117980000000005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 370}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 348}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 366}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 353}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 358}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 359}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 362}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 369}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 354}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 356}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 388}], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 390}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 380}], {
             RGBColor[
             0.9288649285714285, 0.9139807142857144, 0.6666300000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 381}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 384}], {
             RGBColor[
             0.9313790000000001, 0.7572455714285717, 0.2875669285714287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 366}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 355}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 392}], {
             RGBColor[0.585715, 0.6458835, 0.6794385000000003]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{350, 395}], {
             RGBColor[
             0.9675647857142857, 0.9715522857142858, 0.7036892142857145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 379}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 371}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 388}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 392}], {
             RGBColor[
             0.5863123571428571, 0.6485279285714286, 0.8438048571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 395}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 363}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 372}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 364}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 385}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 359}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 362}], {
             RGBColor[
             0.9905291428571428, 0.9903515714285714, 0.806620142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 363}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 369}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 372}], {
             RGBColor[
             0.9681621428571427, 0.9741967142857142, 0.8680555714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 397}], {
             RGBColor[
             0.9068408571428572, 0.9254794285714285, 0.8684003571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 362}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 369}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 394}], {
             RGBColor[
             0.9143667142857141, 0.9343765714285714, 0.9855006428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 397}], {
             RGBColor[
             0.8813052857142857, 0.9080142857142857, 0.9823472142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 370}], {
             RGBColor[0.982063, 0.9511564285714287, 0.3848185714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 393}], {
             RGBColor[
             0.9143667142857141, 0.9343765714285714, 0.9855006428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 396}], {
             RGBColor[
             0.9649935714285713, 0.9728864285714285, 0.9205670000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 363}], {
             RGBColor[
             0.9794917857142857, 0.9524905714285715, 0.6016963571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 369}], {
             RGBColor[
             0.9907257857142857, 0.9894054285714287, 0.7286757857142863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 397}], {
             RGBColor[
             0.9036722857142857, 0.9241691428571428, 0.9209117857142859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 369}], {
             RGBColor[
             0.9828570000000001, 0.9528547142857144, 0.4712405714285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 372}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 385}], {
             RGBColor[
             0.9931003571428572, 0.9890174285714286, 0.5897423571428574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 370}], {
             RGBColor[
             0.7934880714285715, 0.807275142857143, 0.6535615714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 398}], {
             RGBColor[
             0.9709799285714285, 0.9466688571428572, 0.6396786428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 372}], {
             RGBColor[
             0.9683587857142857, 0.9732505714285714, 0.7901112142857147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 389}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 391}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 380}], {
             RGBColor[
             0.9393049285714286, 0.9491972857142857, 0.7071874285714288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 382}], {
             RGBColor[
             0.9820172857142857, 0.9845298571428571, 0.8446024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 384}], {
             RGBColor[
             0.9307359285714285, 0.7879745714285716, 0.5829844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 389}], {
             RGBColor[
             0.9822139285714285, 0.9835837142857142, 0.7666580714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 377}], {
             RGBColor[
             0.9565498571428572, 0.8531865714285715, 0.42595535714285754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 379}], {
             RGBColor[
             0.9788487142857142, 0.9832195714285714, 0.8971138571428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 381}], {
             RGBColor[
             0.9399022857142857, 0.9518417142857143, 0.8715537857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 384}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285717, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 389}], {
             RGBColor[
             0.9938943571428571, 0.9907157142857144, 0.6761643571428575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 389}], {
             RGBColor[
             0.9426130000000001, 0.7941604285714288, 0.4145463571428576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 387}], {
             RGBColor[
             0.9711349285714286, 0.9127372857142857, 0.5157934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 400}], {
             RGBColor[
             0.9174438571428571, 0.6521782857142857, 0.39246014285714326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 390}], {
             RGBColor[
             0.9713315714285715, 0.9117911428571429, 0.4378490714285718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 395}], {
             RGBColor[
             0.5607767857142856, 0.6310627857142856, 0.9577517142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 396}], {
             RGBColor[
             0.9367337142857142, 0.9505314285714286, 0.9240652142857144]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.08420038484809576], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.08420038484809576], {
             RGBColor[0.5073297142857142, 0.6109121428571428, 0.954358]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.08420038484809576], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.08420038484809576], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.08420038484809576], {
             RGBColor[
             0.9190087142857143, 0.7166035714285715, 0.2536907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.08420038484809576], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.08420038484809576], {
             RGBColor[0.6153531428571428, 0.6986104285714285, 0.962862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.08420038484809576], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.08420038484809576], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.08420038484809576], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.08420038484809576], {
             RGBColor[
             0.8861068571428571, 0.9120215714285714, 0.9889988571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.08420038484809576], {
             RGBColor[
             0.9190087142857143, 0.7166035714285715, 0.2536907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.08420038484809576], {
             RGBColor[0.864951, 0.4796558571428573, 0.20902414285714288`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.08420038484809576], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.08420038484809576], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.08420038484809576], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.08420038484809576], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.08420038484809576], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.08420038484809576], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.08420038484809576], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.08420038484809576], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.08420038484809576], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.08420038484809576], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.08420038484809576], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.08420038484809576], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.08420038484809576], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.08420038484809576], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.08420038484809576], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.08420038484809576], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.08420038484809576], {
             RGBColor[
             0.8407967142857143, 0.3145870000000001, 0.18670028571428574`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.08420038484809576], {
             RGBColor[
             0.9190087142857143, 0.7166035714285715, 0.2536907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.08420038484809576], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.08420038484809576], {
             RGBColor[
             0.8861068571428571, 0.9120215714285714, 0.9889988571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.08420038484809576], {
             RGBColor[
             0.8861068571428571, 0.9120215714285714, 0.9889988571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.08420038484809576], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.08420038484809576], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.08420038484809576], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.08420038484809576], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.08420038484809576], {
             RGBColor[
             0.8861068571428571, 0.9120215714285714, 0.9889988571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.08420038484809576], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.08420038484809576], {
             RGBColor[
             0.8861068571428571, 0.9120215714285714, 0.9889988571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.08420038484809576], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.08420038484809576], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.08420038484809576], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.08420038484809576], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.08420038484809576], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.08420038484809576], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.08420038484809576], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.08420038484809576], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.08420038484809576], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.08420038484809576], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.08420038484809576], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.08420038484809576], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.08420038484809576], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.08420038484809576], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.08420038484809576], {
             RGBColor[
             0.8861068571428571, 0.9120215714285714, 0.9889988571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.08420038484809576], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.08420038484809576], {
             RGBColor[
             0.2531092857142857, 0.3833642857142857, 0.9377255714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.08420038484809576], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.08420038484809576], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.08420038484809576], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.08420038484809576], {
             RGBColor[
             0.9190087142857143, 0.7166035714285715, 0.2536907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.08420038484809576], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.08420038484809576], {
             RGBColor[
             0.8861068571428571, 0.9120215714285714, 0.9889988571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.08420038484809576], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.08420038484809576], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.08420038484809576], {
             RGBColor[
             0.8861068571428571, 0.9120215714285714, 0.9889988571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.08420038484809576], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.08420038484809576], {
             RGBColor[
             0.9190087142857143, 0.7166035714285715, 0.2536907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.08420038484809576], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.08420038484809576], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.08420038484809576], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.08420038484809576], {
             RGBColor[0.864951, 0.4796558571428573, 0.20902414285714288`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.08420038484809576], {
             RGBColor[
             0.9190087142857143, 0.7166035714285715, 0.2536907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.08420038484809576], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.08420038484809576], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.08420038484809576], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.08420038484809576], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.08420038484809576], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.08420038484809576], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.08420038484809576], {
             RGBColor[
             0.8407967142857143, 0.3145870000000001, 0.18670028571428574`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.08420038484809576], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.08420038484809576], {
             RGBColor[0.6153531428571428, 0.6986104285714285, 0.962862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.08420038484809576], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.08420038484809576], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.08420038484809576], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.08420038484809576], {
             RGBColor[
             0.9190087142857143, 0.7166035714285715, 0.2536907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.08420038484809576], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.08420038484809576], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.08420038484809576], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.08420038484809576], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.08420038484809576], {
             RGBColor[
             0.8861068571428571, 0.9120215714285714, 0.9889988571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.08420038484809576], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.08420038484809576], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.08420038484809576], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.08420038484809576], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.08420038484809576], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.08420038484809576], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.08420038484809576], {
             RGBColor[
             0.8861068571428571, 0.9120215714285714, 0.9889988571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.08420038484809576], {
             RGBColor[
             0.7184839999999999, 0.7800044285714285, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.08420038484809576], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.08420038484809576], {
             RGBColor[
             0.8861068571428571, 0.9120215714285714, 0.9889988571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.08420038484809576], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.08420038484809576], {
             RGBColor[
             0.8861068571428571, 0.9120215714285714, 0.9889988571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.08420038484809576], {
             RGBColor[0.3293991428571429, 0.45973071428571427`, 0.94221]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.08420038484809576], {
             RGBColor[
             0.9190087142857143, 0.7166035714285715, 0.2536907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.08420038484809576], {
             RGBColor[
             0.9190087142857143, 0.7166035714285715, 0.2536907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.08420038484809576], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.08420038484809576], {
             RGBColor[
             0.8407967142857143, 0.3145870000000001, 0.18670028571428574`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.08420038484809576], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.08420038484809576], {
             RGBColor[
             0.8861068571428571, 0.9120215714285714, 0.9889988571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.08420038484809576], {
             RGBColor[
             0.8861068571428571, 0.9120215714285714, 0.9889988571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.08420038484809576], {
             RGBColor[0.6153531428571428, 0.6986104285714285, 0.962862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.08420038484809576], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.08420038484809576], {
             RGBColor[
             0.9190087142857143, 0.7166035714285715, 0.2536907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.08420038484809576], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.08420038484809576], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.08420038484809576], {
             RGBColor[
             0.9190087142857143, 0.7166035714285715, 0.2536907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.08420038484809576], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.08420038484809576], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.08420038484809576], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.08420038484809576], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.08420038484809576], {
             RGBColor[
             0.8861068571428571, 0.9120215714285714, 0.9889988571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.08420038484809576], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.08420038484809576], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.08420038484809576], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.08420038484809576], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.08420038484809576], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.08420038484809576], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.08420038484809576], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.08420038484809576], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.08420038484809576], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.08420038484809576], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.08420038484809576], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.08420038484809576], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.08420038484809576], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.08420038484809576], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.08420038484809576], {
             RGBColor[
             0.9190087142857143, 0.7166035714285715, 0.2536907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.08420038484809576], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.08420038484809576], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.08420038484809576], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.08420038484809576], {
             RGBColor[
             0.9190087142857143, 0.7166035714285715, 0.2536907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.08420038484809576], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.08420038484809576], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.08420038484809576], {
             RGBColor[
             0.8861068571428571, 0.9120215714285714, 0.9889988571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.08420038484809576], {
             RGBColor[
             0.9190087142857143, 0.7166035714285715, 0.2536907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.08420038484809576], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.08420038484809576], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.08420038484809576], {
             RGBColor[
             0.8861068571428571, 0.9120215714285714, 0.9889988571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.08420038484809576], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.08420038484809576], {
             RGBColor[
             0.9190087142857143, 0.7166035714285715, 0.2536907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.08420038484809576], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.08420038484809576], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.08420038484809576], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.08420038484809576], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.08420038484809576], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.08420038484809576], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.08420038484809576], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.08420038484809576], {
             RGBColor[
             0.8861068571428571, 0.9120215714285714, 0.9889988571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.08420038484809576], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.08420038484809576], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.08420038484809576], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.08420038484809576], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.08420038484809576], {
             RGBColor[0.6153531428571428, 0.6986104285714285, 0.962862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.08420038484809576], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.08420038484809576], {
             RGBColor[0.992503, 0.986373, 0.42537600000000036`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.08420038484809576], {
             RGBColor[
             0.9190087142857143, 0.7166035714285715, 0.2536907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.08420038484809576], {
             RGBColor[
             0.970336857142857, 0.9773978571428571, 0.9350961428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.08420038484809576], {
             RGBColor[
             0.8861068571428571, 0.9120215714285714, 0.9889988571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.08420038484809576], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.08420038484809576], {
             RGBColor[
             0.8911350000000001, 0.5985512857142862, 0.23087271428571438`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.08420038484809576], {
             RGBColor[
             0.8407967142857143, 0.3145870000000001, 0.18670028571428574`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.08420038484809576], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.08420038484809576], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.08420038484809576], {
             RGBColor[
             0.9485721428571429, 0.8338127142857144, 0.2774781428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.08420038484809576], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.08420038484809576], {
             RGBColor[
             0.8861068571428571, 0.9120215714285714, 0.9889988571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.08420038484809576], {
             RGBColor[
             0.8861068571428571, 0.9120215714285714, 0.9889988571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.08420038484809576], {
             RGBColor[
             0.9426265714285713, 0.9567315714285713, 0.9820024285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.08420038484809576], {
             RGBColor[
             0.9873605714285714, 0.9890412857142857, 0.8591315714285717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.08420038484809576], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.08420038484809576], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.08420038484809576], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.08420038484809576], {
             RGBColor[
             0.9940910000000001, 0.9897695714285715, 0.5982200000000008]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN2wucznW+wPHf/+zadNlSKJUyheimsIbchiJLGlM0NrNmJtWMMW5DaZZc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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[337, 399] -> 
             RGBColor[
              0.9603114409091467, 0.8681403292906987, 0.42659540071605706`], 
             UndirectedEdge[15, 92] -> 
             RGBColor[
              0.3916080301069964, 0.5102971083648917, 0.9465821312407912], 
             UndirectedEdge[87, 313] -> 
             RGBColor[
              0.2082730893529932, 0.33623860055952687`, 0.9351722163750043], 
             UndirectedEdge[35, 214] -> 
             RGBColor[
              0.23799829524204824`, 0.3674816766358314, 0.9368650228758846], 
             UndirectedEdge[105, 218] -> 
             RGBColor[
              0.20016816814604027`, 0.3277198144893344, 0.9347106531024247], 
             UndirectedEdge[149, 316] -> 
             RGBColor[
              0.2254786330368893, 0.3543227178657783, 0.9361520466344813], 
             UndirectedEdge[160, 348] -> 
             RGBColor[
              0.39638156393997953`, 0.5175763121944144, 0.946525366087156], 
             UndirectedEdge[17, 287] -> 
             RGBColor[
              0.2108043778715786, 0.3388991452855218, 0.9353163695114319], 
             UndirectedEdge[268, 295] -> 
             RGBColor[
              0.5541988760682194, 0.6477364431214906, 0.9586174510059542], 
             UndirectedEdge[277, 379] -> 
             RGBColor[
              0.2074585735841274, 0.33538249284316635`, 0.9351258309069355], 
             UndirectedEdge[10, 37] -> 
             RGBColor[
              0.29314980125126083`, 0.4217462676405007, 0.9401414095988625], 
             UndirectedEdge[118, 389] -> 
             RGBColor[
              0.22076497088432706`, 0.3493683600799934, 0.9358836105481312], 
             UndirectedEdge[127, 313] -> 
             RGBColor[
              0.20658568658737522`, 0.3344650332653477, 0.935076121283791], 
             UndirectedEdge[92, 281] -> 
             RGBColor[
              0.46303919301965735`, 0.5742863383640635, 0.9510560694278913], 
             UndirectedEdge[2, 193] -> 
             RGBColor[
              0.18596534003799042`, 0.3127917416364609, 0.9339018230528726], 
             UndirectedEdge[265, 378] -> 
             RGBColor[
              0.19040066183963522`, 0.31745354606563403`, 0.9341544080680056],
              UndirectedEdge[108, 367] -> 
             RGBColor[
              0.31561783688898226`, 0.44293150514134, 0.9415099085808494], 
             UndirectedEdge[26, 342] -> 
             RGBColor[
              0.18535691671142462`, 0.3121522501439733, 0.9338671742445064], 
             UndirectedEdge[57, 144] -> 
             RGBColor[
              0.20411547873617336`, 0.33186868819351084`, 0.93493544660101], 
             UndirectedEdge[341, 348] -> 
             RGBColor[
              0.33468734849454873`, 0.4643110922158917, 0.9425469597870388], 
             UndirectedEdge[232, 309] -> 
             RGBColor[
              0.2963446868922668, 0.42880743363510754`, 0.9401877635646132], 
             UndirectedEdge[23, 202] -> 
             RGBColor[
              0.2682077809117381, 0.39923376146669465`, 0.9385854083938443], 
             UndirectedEdge[89, 170] -> 
             RGBColor[
              0.21045471282523004`, 0.33853162515176505`, 0.9352964566043255],
              UndirectedEdge[291, 383] -> 
             RGBColor[
              0.1977645203288262, 0.3251934282333686, 0.9345737689151127], 
             UndirectedEdge[45, 140] -> 
             RGBColor[
              0.25525427585226035`, 0.38561880634952683`, 0.9378477254437005],
              UndirectedEdge[213, 308] -> 
             RGBColor[
              0.2120594900785835, 0.3402183477937941, 0.9353878462948488], 
             UndirectedEdge[165, 386] -> 
             RGBColor[
              0.8287550787424094, 0.8667695006906301, 0.9834015662110343], 
             UndirectedEdge[347, 381] -> 
             RGBColor[
              0.1970073353004369, 0.3243975787602278, 0.9345306483479008], 
             UndirectedEdge[216, 396] -> 
             RGBColor[
              0.19963425463605258`, 0.3271586375382656, 0.9346802475178853], 
             UndirectedEdge[39, 150] -> 
             RGBColor[
              0.1883607596919023, 0.31530947957110045`, 0.9340382386584571], 
             UndirectedEdge[20, 378] -> 
             RGBColor[
              0.19055340614426983`, 0.31761409001435326`, 0.9341631066301896],
              UndirectedEdge[363, 372] -> 
             RGBColor[
              0.20698461099735616`, 0.3348843281135061, 0.9350988394387836], 
             UndirectedEdge[54, 318] -> 
             RGBColor[
              0.18950140793350456`, 0.31650837319430003`, 0.9341031968883784],
              UndirectedEdge[40, 246] -> 
             RGBColor[
              0.7206526383610699, 0.7806508133791874, 0.9738469548784772], 
             UndirectedEdge[59, 178] -> 
             RGBColor[
              0.3941011919373124, 0.5157723771794137, 0.9463327573536129], 
             UndirectedEdge[172, 357] -> 
             RGBColor[
              0.8404518577056951, 0.3119362812088553, 0.18637005066379952`], 
             UndirectedEdge[268, 274] -> 
             RGBColor[
              0.5862206904488971, 0.6743925388404906, 0.9609561467561663], 
             UndirectedEdge[122, 175] -> 
             RGBColor[
              0.4398070896700592, 0.5489279977942612, 0.9504219852000314], 
             UndirectedEdge[120, 341] -> 
             RGBColor[
              0.42726711236099996`, 0.542734639248357, 0.9489335670306169], 
             UndirectedEdge[220, 366] -> 
             RGBColor[
              0.5151109603637722, 0.615629530907049, 0.9554125916387102], 
             UndirectedEdge[202, 366] -> 
             RGBColor[
              0.31887937893336776`, 0.4445735814559359, 0.9417610431931018], 
             UndirectedEdge[17, 61] -> 
             RGBColor[
              0.22052046256389546`, 0.34911136633249684`, 0.9358696861610002],
              UndirectedEdge[112, 279] -> 
             RGBColor[
              0.8046710367643358, 0.7661172165820809, 0.618109700945247], 
             UndirectedEdge[129, 313] -> 
             RGBColor[
              0.203727765298821, 0.33146117678840176`, 0.9349133668943235], 
             UndirectedEdge[204, 318] -> 
             RGBColor[
              0.1940125074344074, 0.321249824789977, 0.9343600973313813], 
             UndirectedEdge[60, 335] -> 
             RGBColor[
              0.18275395419094043`, 0.3094163714975885, 0.9337189393797027], 
             UndirectedEdge[256, 386] -> 
             RGBColor[
              0.556034698630532, 0.6458694921919914, 0.9601976146247932], 
             UndirectedEdge[7, 65] -> 
             RGBColor[
              0.36829577629683624`, 0.4914979419428903, 0.9447588725119885], 
             UndirectedEdge[66, 280] -> 
             RGBColor[
              0.23290342941472336`, 0.362126649618162, 0.936574877804197], 
             UndirectedEdge[147, 344] -> 
             RGBColor[
              0.1873628349672718, 0.31426059741343176`, 0.9339814083216866], 
             UndirectedEdge[329, 349] -> 
             RGBColor[
              0.19621450085245074`, 0.32356425948678696`, 0.9344854975989814],
              UndirectedEdge[170, 306] -> 
             RGBColor[
              0.21718838977102684`, 0.3456091465615747, 0.9356799295448063], 
             UndirectedEdge[175, 178] -> 
             RGBColor[
              0.3616708025324146, 0.48517771913218966`, 0.9443580450417194], 
             UndirectedEdge[115, 166] -> 
             RGBColor[
              0.92715146758626, 0.7340525782000142, 0.5145919024804202], 
             UndirectedEdge[361, 396] -> 
             RGBColor[
              0.20859692759923504`, 0.3365789750888577, 0.935190658484052], 
             UndirectedEdge[80, 265] -> 
             RGBColor[
              0.18489536415726843`, 0.31166712914543293`, 0.933840889509353], 
             UndirectedEdge[18, 288] -> 
             RGBColor[
              0.45525573629442806`, 0.5643070139273578, 0.9513799079587884], 
             UndirectedEdge[225, 240] -> 
             RGBColor[
              0.8581995989845774, 0.5777442515282645, 0.5834221523927036], 
             UndirectedEdge[110, 251] -> 
             RGBColor[
              0.18685400772656674`, 0.3137257877219404, 0.9339524313630709], 
             UndirectedEdge[56, 169] -> 
             RGBColor[
              0.6387195548301612, 0.7123648726900207, 0.967730862260616], 
             UndirectedEdge[87, 231] -> 
             RGBColor[
              0.19018595982878306`, 0.3172278806393347, 0.9341421811061108], 
             UndirectedEdge[266, 315] -> 
             RGBColor[
              0.22579916171770553`, 0.3546596138320083, 0.9361703002686741], 
             UndirectedEdge[31, 292] -> 
             RGBColor[
              0.19543097961487327`, 0.32274072898797734`, 0.9344408772236172],
              UndirectedEdge[1, 87] -> 
             RGBColor[
              0.19586287681444192`, 0.32319468032858806`, 0.934465473130198], 
             UndirectedEdge[231, 336] -> 
             RGBColor[
              0.1812731232878139, 0.3078599243283004, 0.9336346082504626], 
             UndirectedEdge[13, 309] -> 
             RGBColor[
              0.25587961899129924`, 0.38627608163770166`, 0.9378833378103566],
              UndirectedEdge[237, 296] -> 
             RGBColor[
              0.2211466738327187, 0.34976955408011773`, 0.935905347966363], 
             UndirectedEdge[95, 312] -> 
             RGBColor[
              0.43115946169626646`, 0.5444500738116986, 0.9495097680739197], 
             UndirectedEdge[108, 236] -> 
             RGBColor[
              0.2534644343240474, 0.3837375694208677, 0.9377457966165021], 
             UndirectedEdge[48, 176] -> 
             RGBColor[
              0.2369284794639835, 0.36635723242284735`, 0.9368040984499744], 
             UndirectedEdge[49, 52] -> 
             RGBColor[
              0.1835216269875808, 0.31022324428012404`, 0.9337626572098012], 
             UndirectedEdge[310, 390] -> 
             RGBColor[
              0.27115500533733905`, 0.4023314812028227, 0.9387532484648545], 
             UndirectedEdge[343, 358] -> 
             RGBColor[
              0.18639835798283702`, 0.3132468709514181, 0.933926482784239], 
             UndirectedEdge[271, 374] -> 
             RGBColor[
              0.184659451088446, 0.3114191695523481, 0.9338274546090857], 
             UndirectedEdge[57, 167] -> 
             RGBColor[
              0.2639676028821611, 0.3946376054360735, 0.9383490428444853], 
             UndirectedEdge[34, 214] -> 
             RGBColor[
              0.25149658822823806`, 0.38166923840552336`, 0.9376337306925131],
              UndirectedEdge[83, 220] -> 
             RGBColor[
              0.790428504618827, 0.8368778917698232, 0.9711999364788909], 
             UndirectedEdge[9, 347] -> 
             RGBColor[
              0.19444294915612814`, 0.3217022463310869, 0.9343846103506517], 
             UndirectedEdge[188, 238] -> 
             RGBColor[
              0.2458833929201038, 0.375769414239536, 0.9373140675236933], 
             UndirectedEdge[79, 137] -> 
             RGBColor[
              0.2827537056275888, 0.4121446936308188, 0.939500838618308], 
             UndirectedEdge[115, 197] -> 
             RGBColor[
              0.914459777232721, 0.7255013666531043, 0.5770167261447392], 
             UndirectedEdge[67, 194] -> 
             RGBColor[
              0.709877099853931, 0.7667201163798876, 0.7972498678529694], 
             UndirectedEdge[75, 260] -> 
             RGBColor[
              0.22127423884363956`, 0.34990363299468435`, 0.9359126126050195],
              UndirectedEdge[32, 387] -> 
             RGBColor[
              0.7455791435710649, 0.7496942133696903, 0.622023162461701], 
             UndirectedEdge[76, 144] -> 
             RGBColor[
              0.19222334020881804`, 0.31936929659612845`, 0.9342582069047196],
              UndirectedEdge[50, 164] -> 
             RGBColor[
              0.18999442899880858`, 0.3170265695932755, 0.9341312737086882], 
             UndirectedEdge[279, 285] -> 
             RGBColor[
              0.8332166202434534, 0.8669371947579207, 0.788972494773293], 
             UndirectedEdge[137, 352] -> 
             RGBColor[
              0.28703295098175935`, 0.4166424518178782, 0.9397445353106518], 
             UndirectedEdge[4, 275] -> 
             RGBColor[
              0.235784586016354, 0.3651549278823552, 0.9367389554103707], 
             UndirectedEdge[8, 373] -> 
             RGBColor[
              0.2548317087924608, 0.38517466157737845`, 0.937823660874777], 
             UndirectedEdge[41, 135] -> 
             RGBColor[
              0.9333566323648748, 0.9460233638065111, 0.83381543555314], 
             UndirectedEdge[85, 211] -> 
             RGBColor[
              0.231317411938528, 0.36045964469136466`, 0.9364845564552302], 
             UndirectedEdge[63, 139] -> 
             RGBColor[
              0.18462055320460163`, 0.31137828541015944`, 0.9338252394321449],
              UndirectedEdge[55, 92] -> 
             RGBColor[
              0.7345108890138425, 0.7594054710903482, 0.6489345144638174], 
             UndirectedEdge[31, 371] -> 
             RGBColor[
              0.1915120199175549, 0.31862165386969954`, 0.9342176982664363], 
             UndirectedEdge[99, 169] -> 
             RGBColor[
              0.9307128082989145, 0.9468171296861931, 0.9664871194315787], 
             UndirectedEdge[71, 72] -> 
             RGBColor[
              0.18087056047954858`, 0.30743680529285733`, 0.9336116828940703],
              UndirectedEdge[104, 112] -> 
             RGBColor[
              0.8780584972468868, 0.4677393624570944, 0.21704509236247566`], 
             UndirectedEdge[389, 390] -> 
             RGBColor[
              0.23267978688900162`, 0.3618915871438733, 0.9365621416932066], 
             UndirectedEdge[260, 349] -> 
             RGBColor[
              0.21328372600725728`, 0.3415050973758713, 0.9354575647198919], 
             UndirectedEdge[70, 284] -> 
             RGBColor[
              0.24975725951810934`, 0.3798410936513683, 0.9375346784955776], 
             UndirectedEdge[24, 172] -> 
             RGBColor[
              0.8222950385758708, 0.17237501300815056`, 0.16898306015988562`],
              UndirectedEdge[343, 362] -> 
             RGBColor[
              0.18559297832352872`, 0.3124003658654654, 0.9338806176040938], 
             UndirectedEdge[233, 307] -> 
             RGBColor[
              0.6538804302709667, 0.7226974017073509, 0.9485082265240019], 
             UndirectedEdge[79, 278] -> 
             RGBColor[
              0.24460490622546205`, 0.37442564366272924`, 0.937241259597785], 
             UndirectedEdge[1, 216] -> 
             RGBColor[
              0.19662871859939152`, 0.3239996286017438, 0.9345090866868895], 
             UndirectedEdge[192, 374] -> 
             RGBColor[
              0.18592011737534742`, 0.3127442097507407, 0.933899247689136], 
             UndirectedEdge[152, 383] -> 
             RGBColor[
              0.2325615956471479, 0.3617673606549275, 0.9365554108768314], 
             UndirectedEdge[43, 121] -> 
             RGBColor[
              0.28563299292961386`, 0.4173490407437973, 0.9395850612911336], 
             UndirectedEdge[13, 280] -> 
             RGBColor[
              0.23284937828008462`, 0.36206983844861684`, 0.9365717996720409],
              UndirectedEdge[246, 272] -> 
             RGBColor[
              0.8305893181173114, 0.8683923303180165, 0.9835339903359117], 
             UndirectedEdge[385, 387] -> 
             RGBColor[
              0.7642756795140044, 0.8115756260652711, 0.7955379877927361], 
             UndirectedEdge[90, 268] -> 
             RGBColor[
              0.6438707815800897, 0.7211954799278018, 0.9654945731092558], 
             UndirectedEdge[195, 363] -> 
             RGBColor[
              0.21087458530257291`, 0.33897293774690507`, 0.9353203677207644],
              UndirectedEdge[88, 109] -> 
             RGBColor[
              0.18639597403767888`, 0.31324436527390603`, 0.9339263470220889],
              UndirectedEdge[63, 318] -> 
             RGBColor[
              0.18778593589765713`, 0.3147053033174152, 0.9340055032937504], 
             UndirectedEdge[257, 276] -> 
             RGBColor[
              0.27298076036949565`, 0.4029229337235066, 0.9389058299544288], 
             UndirectedEdge[16, 106] -> 
             RGBColor[
              0.2722971064429795, 0.4026970623499158, 0.9388488569979281], 
             UndirectedEdge[100, 227] -> 
             RGBColor[
              0.20880854883445307`, 0.33680140242463313`, 0.9352027100003322],
              UndirectedEdge[195, 359] -> 
             RGBColor[
              0.19452611281546262`, 0.321789656609928, 0.9343893463980213], 
             UndirectedEdge[216, 313] -> 
             RGBColor[
              0.2090389311379428, 0.3370435488326826, 0.9352158299316957], 
             UndirectedEdge[12, 47] -> 
             RGBColor[
              0.4262898849714413, 0.5411626092696967, 0.9490658048705467], 
             UndirectedEdge[386, 400] -> 
             RGBColor[
              0.8054695470793142, 0.5998653041518983, 0.5862367210785956], 
             UndirectedEdge[180, 262] -> 
             RGBColor[
              0.23634740435871976`, 0.36574648564492557`, 0.9367710070823533],
              UndirectedEdge[247, 359] -> 
             RGBColor[
              0.1924159607622266, 0.31957175301060936`, 0.9342691763602797], 
             UndirectedEdge[74, 141] -> 
             RGBColor[
              0.8643287930251963, 0.6881181472098445, 0.5981821297581387], 
             UndirectedEdge[170, 171] -> 
             RGBColor[
              0.21031358554217228`, 0.3383832914292848, 0.9352884196143345], 
             UndirectedEdge[207, 333] -> 
             RGBColor[
              0.18793493502051017`, 0.3148619108426237, 0.9340139885733725], 
             UndirectedEdge[311, 313] -> 
             RGBColor[
              0.2605556138292256, 0.39119084868755866`, 0.938149628798862], 
             UndirectedEdge[161, 195] -> 
             RGBColor[
              0.20065168741435874`, 0.3282280238972294, 0.9347381888094528], 
             UndirectedEdge[87, 129] -> 
             RGBColor[
              0.1936336407966272, 0.32085161193213774`, 0.9343385214368426], 
             UndirectedEdge[198, 367] -> 
             RGBColor[
              0.36419518981338295`, 0.4898693012590379, 0.9444271733431154], 
             UndirectedEdge[322, 330] -> 
             RGBColor[
              0.19291768102176954`, 0.3200990928142907, 0.934297748586832], 
             UndirectedEdge[79, 314] -> 
             RGBColor[
              0.23185910927542647`, 0.36102900293803986`, 0.9365154053171973],
              UndirectedEdge[56, 274] -> 
             RGBColor[
              0.43736444745775693`, 0.5521652442024196, 0.9493877477928349], 
             UndirectedEdge[249, 316] -> 
             RGBColor[
              0.271715102066897, 0.4028896300992718, 0.9387862636671344], 
             UndirectedEdge[69, 294] -> 
             RGBColor[
              0.2158880199071448, 0.3442423753864234, 0.935605875404783], 
             UndirectedEdge[6, 300] -> 
             RGBColor[
              0.6101439916355338, 0.6866719134983721, 0.9662201158700239], 
             UndirectedEdge[36, 265] -> 
             RGBColor[
              0.1914303121066489, 0.318535773779863, 0.934213045127481], 
             UndirectedEdge[167, 395] -> 
             RGBColor[
              0.389446651029121, 0.5113248488468087, 0.9461511158699245], 
             UndirectedEdge[261, 306] -> 
             RGBColor[
              0.2313412040252819, 0.36048465168304844`, 0.9364859113793738], 
             UndirectedEdge[35, 211] -> 
             RGBColor[
              0.22907054143597805`, 0.35809804133336665`, 0.9363566005040571],
              UndirectedEdge[54, 63] -> 
             RGBColor[
              0.18289690010848875`, 0.3095666167202264, 0.9337270799382376], 
             UndirectedEdge[302, 314] -> 
             RGBColor[
              0.21202470254257239`, 0.3401817838877893, 0.9353858651961364], 
             UndirectedEdge[54, 224] -> 
             RGBColor[
              0.18197335735342035`, 0.3085959147286568, 0.9336744855445955], 
             UndirectedEdge[164, 389] -> 
             RGBColor[
              0.20180063292388895`, 0.3294356384750984, 0.934803619556508], 
             UndirectedEdge[113, 210] -> 
             RGBColor[
              0.3065896783902691, 0.43957556926948627`, 0.9407712006743179], 
             UndirectedEdge[307, 348] -> 
             RGBColor[
              0.3407470767330234, 0.4695597242452613, 0.9429330803119872], 
             UndirectedEdge[18, 74] -> 
             RGBColor[
              0.7341001698400949, 0.7919819236306536, 0.974429319456183], 
             UndirectedEdge[41, 328] -> 
             RGBColor[
              0.8707008812978143, 0.7005608755905404, 0.6002433163697872], 
             UndirectedEdge[63, 290] -> 
             RGBColor[
              0.18969933550436535`, 0.3167164076206075, 0.9341144685707314], 
             UndirectedEdge[45, 288] -> 
             RGBColor[
              0.29509029119202934`, 0.4274889842208769, 0.9401163275851969], 
             UndirectedEdge[249, 315] -> 
             RGBColor[
              0.2639611950336743, 0.39473978218125394`, 0.9383446901324698], 
             UndirectedEdge[306, 342] -> 
             RGBColor[
              0.1932134040418383, 0.3204099164583054, 0.934314589575342], 
             UndirectedEdge[163, 395] -> 
             RGBColor[
              0.36771682090515007`, 0.4886248797144314, 0.9449085278741232], 
             UndirectedEdge[378, 379] -> 
             RGBColor[
              0.19896021464386793`, 0.3264501787698757, 0.934641861937483], 
             UndirectedEdge[216, 235] -> 
             RGBColor[
              0.1956123156574894, 0.32293132466613605`, 0.9344512040429815], 
             UndirectedEdge[220, 321] -> 
             RGBColor[
              0.5950920301278422, 0.6821615445050555, 0.961266970987048], 
             UndirectedEdge[133, 199] -> 
             RGBColor[
              0.18613849661309062`, 0.31297374017565216`, 0.9339116840636623],
              UndirectedEdge[317, 396] -> 
             RGBColor[
              0.19745595153076353`, 0.32486910286221293`, 0.9345561963785496],
              UndirectedEdge[177, 197] -> 
             RGBColor[
              0.9295820155952076, 0.9459496447868232, 0.9675642537426303], 
             UndirectedEdge[208, 242] -> 
             RGBColor[
              0.9226443508532682, 0.6970908441139261, 0.4815544446680411], 
             UndirectedEdge[51, 163] -> 
             RGBColor[
              0.3241863421441664, 0.4513369658591039, 0.9420198625128315], 
             UndirectedEdge[188, 228] -> 
             RGBColor[
              0.20268995802939208`, 0.3303703755474506, 0.9348542653056278], 
             UndirectedEdge[95, 125] -> 
             RGBColor[
              0.41046090544111513`, 0.5226945788232695, 0.9483310159159588], 
             UndirectedEdge[66, 203] -> 
             RGBColor[
              0.2200139191384291, 0.3485789570756236, 0.9358408392622837], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.2667189772067604, 0.39766893437715617`, 0.9385006232253336], 
             UndirectedEdge[151, 265] -> 
             RGBColor[
              0.1910010224377346, 0.31808456311929695`, 0.9341885977159134], 
             UndirectedEdge[76, 333] -> 
             RGBColor[
              0.19100459551754329`, 0.3180883186527222, 0.9341888011975227], 
             UndirectedEdge[119, 336] -> 
             RGBColor[
              0.18138462902211405`, 0.30797712392492177`, 0.9336409583370731],
              UndirectedEdge[183, 395] -> 
             RGBColor[
              0.40931291362813915`, 0.5285320070026871, 0.9474169765556877], 
             UndirectedEdge[42, 204] -> 
             RGBColor[
              0.20507426806755127`, 0.33287643657154375`, 0.9349900482350304],
              UndirectedEdge[12, 107] -> 
             RGBColor[
              0.3285473986430889, 0.45896802364421685`, 0.9421566412492507], 
             UndirectedEdge[234, 239] -> 
             RGBColor[
              0.8067428279900561, 0.5234676801505931, 0.5767481319037369], 
             UndirectedEdge[164, 287] -> 
             RGBColor[
              0.19544251078166353`, 0.3227528489753921, 0.9344415339065071], 
             UndirectedEdge[32, 194] -> 
             RGBColor[
              0.9757819569708761, 0.9287169668940988, 0.4668813870087187], 
             UndirectedEdge[6, 169] -> 
             RGBColor[
              0.6006886092479335, 0.6791324482420171, 0.965318253056975], 
             UndirectedEdge[24, 240] -> 
             RGBColor[
              0.8262378872131442, 0.20268147540152273`, 0.17275873646774914`],
              UndirectedEdge[9, 381] -> 
             RGBColor[
              0.19359903145009902`, 0.3208152353145773, 0.9343365504857577], 
             UndirectedEdge[43, 90] -> 
             RGBColor[
              0.434369237561579, 0.5419666394359329, 0.9502257108546233], 
             UndirectedEdge[88, 157] -> 
             RGBColor[
              0.189431793006949, 0.31643520349264886`, 0.9340992324212971], 
             UndirectedEdge[100, 314] -> 
             RGBColor[
              0.22141089937149833`, 0.35004727187424184`, 0.93592039521991], 
             UndirectedEdge[56, 296] -> 
             RGBColor[
              0.313305483869233, 0.43989379597440015`, 0.9414004589756761], 
             UndirectedEdge[49, 235] -> 
             RGBColor[
              0.18959591922153213`, 0.31660771055037873`, 0.9341085791664148],
              UndirectedEdge[359, 362] -> 
             RGBColor[
              0.18818450229900258`, 0.31512422187579864`, 0.9340282010606809],
              UndirectedEdge[104, 285] -> 
             RGBColor[
              0.9066040807260044, 0.5685593406329343, 0.38790788619052163`], 
             UndirectedEdge[80, 168] -> 
             RGBColor[
              0.18200651498987047`, 0.3086307655068815, 0.933676373822939], 
             UndirectedEdge[311, 386] -> 
             RGBColor[
              0.5317523136158948, 0.6242823861276408, 0.958670681032904], 
             UndirectedEdge[61, 173] -> 
             RGBColor[
              0.24592220228648118`, 0.3758102053442546, 0.937316277659695], 
             UndirectedEdge[118, 354] -> 
             RGBColor[
              0.22736699671866945`, 0.3563075078245018, 0.9362595861525749], 
             UndirectedEdge[154, 180] -> 
             RGBColor[
              0.2320279298273124, 0.36120644404191316`, 0.9365250193978796], 
             UndirectedEdge[17, 158] -> 
             RGBColor[
              0.2852162427380673, 0.4143360909345327, 0.9396556083799944], 
             UndirectedEdge[8, 237] -> 
             RGBColor[
              0.2175725261235523, 0.3460128982237305, 0.9357018055418038], 
             UndirectedEdge[55, 255] -> 
             RGBColor[
              0.9034963603733146, 0.5943883495886708, 0.2628944512543936], 
             UndirectedEdge[93, 214] -> 
             RGBColor[
              0.23703264551730702`, 0.36646671754939963`, 0.9368100305526114],
              UndirectedEdge[129, 235] -> 
             RGBColor[
              0.1903011498183676, 0.3173489526218552, 0.9341487410056093], 
             UndirectedEdge[47, 158] -> 
             RGBColor[
              0.44142989596913074`, 0.5543010784500094, 0.9500295993461311], 
             UndirectedEdge[106, 347] -> 
             RGBColor[
              0.21233497992474068`, 0.3405079050891704, 0.9354035350340366], 
             UndirectedEdge[169, 178] -> 
             RGBColor[
              0.668739474081812, 0.7383666179007873, 0.9696437049697588], 
             UndirectedEdge[230, 385] -> 
             RGBColor[
              0.9060818174117249, 0.56391734784212, 0.3996140043462989], 
             UndirectedEdge[304, 383] -> 
             RGBColor[
              0.1946222087294852, 0.32189065950839857`, 0.9343948189181637], 
             UndirectedEdge[100, 352] -> 
             RGBColor[
              0.2248749641652065, 0.3536882236068225, 0.936117668585287], 
             UndirectedEdge[87, 216] -> 
             RGBColor[
              0.198944806635749, 0.32643398397641854`, 0.9346409844742148], 
             UndirectedEdge[79, 277] -> 
             RGBColor[
              0.21942962029019444`, 0.3479648219394422, 0.9358075643072694], 
             UndirectedEdge[217, 220] -> 
             RGBColor[
              0.8144460532518553, 0.851406632354037, 0.7257595325601884], 
             UndirectedEdge[78, 104] -> 
             RGBColor[
              0.819473350823259, 0.1506862844701191, 0.16628100878134408`], 
             UndirectedEdge[170, 353] -> 
             RGBColor[
              0.2108426436010009, 0.33893936499333205`, 0.9353185486881135], 
             UndirectedEdge[78, 385] -> 
             RGBColor[
              0.9071814483660026, 0.5723695932180546, 0.4006670121899707], 
             UndirectedEdge[40, 102] -> 
             RGBColor[
              0.39926565859510593`, 0.5155146756656562, 0.9472759248895897], 
             UndirectedEdge[41, 256] -> 
             RGBColor[
              0.6115898950741928, 0.6896890172445088, 0.9656235459657501], 
             UndirectedEdge[120, 217] -> 
             RGBColor[
              0.7556843813439534, 0.80370125991605, 0.7211335984965017], 
             UndirectedEdge[210, 315] -> 
             RGBColor[
              0.26224986664151034`, 0.39297161581510254`, 0.9382461139900993],
              UndirectedEdge[83, 187] -> 
             RGBColor[
              0.6899774075909928, 0.7548276258988081, 0.9634300825559947], 
             UndirectedEdge[2, 305] -> 
             RGBColor[
              0.18360947068078184`, 0.31031557357129014`, 0.9337676597781759],
              UndirectedEdge[121, 175] -> 
             RGBColor[
              0.29627876905743955`, 0.4285384264353338, 0.9401913224925988], 
             UndirectedEdge[36, 151] -> 
             RGBColor[
              0.19244860485001886`, 0.3196060640166337, 0.9342710353927868], 
             UndirectedEdge[70, 332] -> 
             RGBColor[
              0.22563024765380635`, 0.35448207444108004`, 0.936160680862621], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.1986384662361157, 0.32611200079330077`, 0.9346235388416457], 
             UndirectedEdge[221, 400] -> 
             RGBColor[
              0.8762434284382803, 0.5179931725974458, 0.21794016454172604`], 
             UndirectedEdge[49, 216] -> 
             RGBColor[
              0.19369425198474133`, 0.320915318133817, 0.9343419731543394], 
             UndirectedEdge[75, 349] -> 
             RGBColor[
              0.2099761655665867, 0.3380286416412822, 0.935269204045893], 
             UndirectedEdge[62, 87] -> 
             RGBColor[
              0.1996423811721627, 0.3271671790429695, 0.9346807103120945], 
             UndirectedEdge[38, 189] -> 
             RGBColor[
              0.24478652953490182`, 0.3746165412765333, 0.9372516027765698], 
             UndirectedEdge[49, 361] -> 
             RGBColor[
              0.2026569249479238, 0.33033565568440915`, 0.9348523841205063], 
             UndirectedEdge[107, 270] -> 
             RGBColor[
              0.35385896317997434`, 0.4809165812630355, 0.943768558122001], 
             UndirectedEdge[5, 8] -> 
             RGBColor[
              0.2601258969540067, 0.39073918900607996`, 0.9381251570585274], 
             UndirectedEdge[162, 340] -> 
             RGBColor[
              0.23763180163327896`, 0.367096468615978, 0.9368441516070439], 
             UndirectedEdge[34, 85] -> 
             RGBColor[
              0.25199669770088307`, 0.3821948851700452, 0.9376622111871347], 
             UndirectedEdge[21, 172] -> 
             RGBColor[
              0.8935026650840421, 0.5357509007293852, 0.24098742713821833`], 
             UndirectedEdge[298, 393] -> 
             RGBColor[
              0.19018046268844432`, 0.31722210279629987`, 0.9341418680521008],
              UndirectedEdge[164, 371] -> 
             RGBColor[
              0.1937500929349124, 0.3209740105129675, 0.9343451532138425], 
             UndirectedEdge[11, 85] -> 
             RGBColor[
              0.2763549775912347, 0.40749939278433556`, 0.9390602753814483], 
             UndirectedEdge[202, 307] -> 
             RGBColor[
              0.295856931076972, 0.42463269426460054`, 0.9402940731736436], 
             UndirectedEdge[20, 265] -> 
             RGBColor[
              0.19013547399899927`, 0.31717481683124543`, 0.9341393060127917],
              UndirectedEdge[195, 247] -> 
             RGBColor[
              0.1997381438211963, 0.32726783165880646`, 0.9346861638532888], 
             UndirectedEdge[281, 355] -> 
             RGBColor[
              0.5971975343016019, 0.6813125874620714, 0.9629093916561169], 
             UndirectedEdge[298, 313] -> 
             RGBColor[
              0.20768244341745035`, 0.33561779423215604`, 0.9351385799627575],
              UndirectedEdge[67, 210] -> 
             RGBColor[
              0.365438140563206, 0.4906599829992886, 0.9445168412553058], 
             UndirectedEdge[11, 263] -> 
             RGBColor[
              0.35195866140263943`, 0.47927063537545245`, 0.9436474725731201],
              UndirectedEdge[88, 181] -> 
             RGBColor[
              0.19319654196954522`, 0.3203921933512083, 0.9343136293052701], 
             UndirectedEdge[212, 390] -> 
             RGBColor[
              0.3400236714682391, 0.46467688938800766`, 0.9430428280078589], 
             UndirectedEdge[13, 203] -> 
             RGBColor[
              0.21995986800379036`, 0.3485221459060784, 0.9358377611301275], 
             UndirectedEdge[75, 105] -> 
             RGBColor[
              0.21372122175088312`, 0.34196493314125437`, 0.9354824794552745],
              UndirectedEdge[12, 270] -> 
             RGBColor[
              0.3337876806083378, 0.46350689249828564`, 0.9424905473822769], 
             UndirectedEdge[127, 393] -> 
             RGBColor[
              0.1890837058583692, 0.31606934182949153`, 0.9340794093731344], 
             UndirectedEdge[185, 208] -> 
             RGBColor[
              0.6963078073762952, 0.755957556681333, 0.8560508247348155], 
             UndirectedEdge[246, 355] -> 
             RGBColor[
              0.8429762449225704, 0.8780690916824152, 0.9847686034374477], 
             UndirectedEdge[62, 336] -> 
             RGBColor[
              0.19072954463119351`, 0.31779922273193517`, 0.9341731374564464],
              UndirectedEdge[118, 209] -> 
             RGBColor[
              0.2868618960178613, 0.41642761918472027`, 0.9397360770801573], 
             UndirectedEdge[178, 352] -> 
             RGBColor[
              0.3406463330534576, 0.4630796686814488, 0.9431607326078082], 
             UndirectedEdge[17, 22] -> 
             RGBColor[
              0.2739758563683775, 0.40460023321935323`, 0.9389393809000012], 
             UndirectedEdge[12, 158] -> 
             RGBColor[
              0.32361612706914167`, 0.45469680405977975`, 0.941842424985111], 
             UndirectedEdge[200, 333] -> 
             RGBColor[
              0.18616349406283006`, 0.3130000140802582, 0.9339131076314446], 
             UndirectedEdge[69, 295] -> 
             RGBColor[
              0.3354255676488553, 0.4587623903805083, 0.9428205754850394], 
             UndirectedEdge[181, 340] -> 
             RGBColor[
              0.19892920598511726`, 0.3264175867034662, 0.9346400960402405], 
             UndirectedEdge[205, 284] -> 
             RGBColor[
              0.313308210862673, 0.4428213204414291, 0.9412935282095445], 
             UndirectedEdge[283, 373] -> 
             RGBColor[
              0.2404157449182508, 0.3700225695206825, 0.937002693058648], 
             UndirectedEdge[302, 379] -> 
             RGBColor[
              0.199238475276043, 0.32674264833703476`, 0.9346577084688357], 
             UndirectedEdge[254, 303] -> 
             RGBColor[
              0.20024144683233963`, 0.3277968350347721, 0.9347148262152034], 
             UndirectedEdge[38, 254] -> 
             RGBColor[
              0.20508861754811766`, 0.3328915187854286, 0.9349908654167205], 
             UndirectedEdge[158, 209] -> 
             RGBColor[
              0.336799320476102, 0.4661403761955148, 0.94268153277416], 
             UndirectedEdge[365, 370] -> 
             RGBColor[
              0.18400910577117147`, 0.3107356153896179, 0.9337904184053665], 
             UndirectedEdge[61, 164] -> 
             RGBColor[
              0.2051585954739804, 0.3329650700223671, 0.9349948505560753], 
             UndirectedEdge[163, 167] -> 
             RGBColor[
              0.2885245503262027, 0.4204485142001573, 0.9397475246726753], 
             UndirectedEdge[62, 119] -> 
             RGBColor[
              0.1917608818844465, 0.31888322357566273`, 0.9342318705872924], 
             UndirectedEdge[137, 197] -> 
             RGBColor[
              0.6493874970557305, 0.7185106775296126, 0.9439140882472267], 
             UndirectedEdge[265, 383] -> 
             RGBColor[
              0.1991683094404495, 0.3266688995950551, 0.9346537126282998], 
             UndirectedEdge[19, 338] -> 
             RGBColor[
              0.24730224830049347`, 0.3772607212049526, 0.937394869238598], 
             UndirectedEdge[69, 212] -> 
             RGBColor[
              0.32957634955032006`, 0.4536960916538069, 0.9424478684800611], 
             UndirectedEdge[45, 275] -> 
             RGBColor[
              0.261779864050582, 0.3924776132921515, 0.9382193480378523], 
             UndirectedEdge[248, 360] -> 
             RGBColor[
              0.20162405229043762`, 0.3292500410334822, 0.9347935635506606], 
             UndirectedEdge[188, 322] -> 
             RGBColor[
              0.20084485470176572`, 0.3284310549638075, 0.9347491894007052], 
             UndirectedEdge[167, 183] -> 
             RGBColor[
              0.33012064304919175`, 0.46035564148841296`, 0.9422559733542398],
              UndirectedEdge[141, 240] -> 
             RGBColor[
              0.8486432291011581, 0.36358607454286945`, 0.19377114111448232`],
              UndirectedEdge[23, 220] -> 
             RGBColor[
              0.46443936234214256`, 0.5702897109178078, 0.9522369568394528], 
             UndirectedEdge[123, 322] -> 
             RGBColor[
              0.20580146810397543`, 0.3336407699169709, 0.9350314612013086], 
             UndirectedEdge[177, 398] -> 
             RGBColor[
              0.6604733814795012, 0.7312391377896288, 0.9691021762679148], 
             UndirectedEdge[272, 395] -> 
             RGBColor[
              0.6047861017850406, 0.688521596311049, 0.9630625411341533], 
             UndirectedEdge[85, 312] -> 
             RGBColor[
              0.27182714160879756`, 0.40303793904002655`, 0.9387915256311776],
              UndirectedEdge[25, 328] -> 
             RGBColor[
              0.8434248781398908, 0.3172892303900453, 0.1885318018785458], 
             UndirectedEdge[8, 121] -> 
             RGBColor[
              0.2743592219367422, 0.4054995926319236, 0.9389430367111391], 
             UndirectedEdge[169, 319] -> 
             RGBColor[
              0.6745752376290368, 0.7434200744106859, 0.9700158830654886], 
             UndirectedEdge[84, 167] -> 
             RGBColor[
              0.32454610124482625`, 0.4555272535620894, 0.9419007684798394], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.2877186940288704, 0.4160544664052851, 0.9398315069221266], 
             UndirectedEdge[43, 213] -> 
             RGBColor[
              0.2414891450614786, 0.3711507811287148, 0.9370638216088516], 
             UndirectedEdge[170, 187] -> 
             RGBColor[
              0.33329236872326556`, 0.45597611149735384`, 0.9427190170162062],
              UndirectedEdge[89, 199] -> 
             RGBColor[
              0.18786740786844439`, 0.3147909355243339, 0.9340101430019597], 
             UndirectedEdge[16, 373] -> 
             RGBColor[
              0.29481332974402036`, 0.42636304065032193`, 0.9401311226051551],
              UndirectedEdge[22, 158] -> 
             RGBColor[
              0.3275157516971413, 0.458099415524913, 0.9420899919807021], 
             UndirectedEdge[233, 264] -> 
             RGBColor[
              0.8413490098710985, 0.8765030596973409, 0.9633266229040078], 
             UndirectedEdge[274, 296] -> 
             RGBColor[
              0.36901952314668135`, 0.4870709060931353, 0.9452488023460986], 
             UndirectedEdge[97, 211] -> 
             RGBColor[
              0.20738956458852648`, 0.33530996001336677`, 0.9351219009467256],
              UndirectedEdge[1, 129] -> 
             RGBColor[
              0.19131755276026974`, 0.31841725655746295`, 0.9342066236495172],
              UndirectedEdge[24, 141] -> 
             RGBColor[
              0.8431921928460754, 0.3216870212269862, 0.1885512226405503], 
             UndirectedEdge[347, 384] -> 
             RGBColor[
              0.19370455937175246`, 0.32092615185109175`, 0.9343425601447813],
              UndirectedEdge[36, 378] -> 
             RGBColor[
              0.1918482442519195, 0.31897504696297085`, 0.934236845744879], 
             UndirectedEdge[174, 395] -> 
             RGBColor[
              0.4063176896518592, 0.5259376945387678, 0.9472261235324917], 
             UndirectedEdge[104, 357] -> 
             RGBColor[
              0.8380548061555597, 0.2935114925998279, 0.18407463139230737`], 
             UndirectedEdge[47, 173] -> 
             RGBColor[
              0.41329174036295263`, 0.5275007351562074, 0.948325579764125], 
             UndirectedEdge[127, 231] -> 
             RGBColor[
              0.1884985570631651, 0.31545431334515556`, 0.9340460860148976], 
             UndirectedEdge[252, 367] -> 
             RGBColor[
              0.372324185998124, 0.4969102291790325, 0.9449451457918181], 
             UndirectedEdge[158, 310] -> 
             RGBColor[
              0.30917761379090525`, 0.4395210111497373, 0.9410201730137817], 
             UndirectedEdge[149, 397] -> 
             RGBColor[
              0.21476341163145843`, 0.34306034078439396`, 0.9355418306271915],
              UndirectedEdge[204, 345] -> 
             RGBColor[
              0.18631088399028722`, 0.3131549302390768, 0.9339215012697695], 
             UndirectedEdge[231, 396] -> 
             RGBColor[
              0.19087540782908663`, 0.31795253420118175`, 0.9341814441497811],
              UndirectedEdge[162, 263] -> 
             RGBColor[
              0.33214075614847005`, 0.45873834938016844`, 0.9425079759974546],
              UndirectedEdge[14, 196] -> 
             RGBColor[
              0.18714224683050756`, 0.3140287452955969, 0.9339688461536289], 
             UndirectedEdge[43, 175] -> 
             RGBColor[
              0.2710055822533935, 0.4021744280676252, 0.9387447390412754], 
             UndirectedEdge[113, 397] -> 
             RGBColor[
              0.2602244815922864, 0.3908428077115391, 0.9381307713078346], 
             UndirectedEdge[126, 336] -> 
             RGBColor[
              0.18346975723563688`, 0.31016872588209876`, 0.9337597033041625],
              UndirectedEdge[48, 173] -> 
             RGBColor[
              0.2613339339978391, 0.3920089125331203, 0.938193952981043], 
             UndirectedEdge[28, 168] -> 
             RGBColor[
              0.19559687276408316`, 0.32291509320603007`, 0.9344503245930478],
              UndirectedEdge[253, 359] -> 
             RGBColor[
              0.18914843365842357`, 0.3161373748513282, 0.9340830955255912], 
             UndirectedEdge[41, 187] -> 
             RGBColor[
              0.6533956652271913, 0.7258990741319324, 0.9682873726725081], 
             UndirectedEdge[198, 398] -> 
             RGBColor[
              0.38970123207440616`, 0.5119613530945772, 0.9460523958018803], 
             UndirectedEdge[260, 329] -> 
             RGBColor[
              0.20751257412950358`, 0.3354392508401891, 0.9351289061581081], 
             UndirectedEdge[60, 82] -> 
             RGBColor[
              0.18336573314646784`, 0.31005938996887394`, 0.9337537792861741],
              UndirectedEdge[12, 17] -> 
             RGBColor[0.2700762317403779, 0.40119762175422, 0.93869181390441],
              UndirectedEdge[268, 351] -> 
             RGBColor[
              0.7945761589543001, 0.8401740652758038, 0.979966961918109], 
             UndirectedEdge[122, 274] -> 
             RGBColor[
              0.5455206538470523, 0.6419172680752578, 0.9573645306602898], 
             UndirectedEdge[150, 384] -> 
             RGBColor[
              0.19155187583051508`, 0.31866354496123156`, 0.9342199680017178],
              UndirectedEdge[179, 232] -> 
             RGBColor[
              0.374520452238133, 0.49753308772821003`, 0.9451360369712756], 
             UndirectedEdge[4, 131] -> 
             RGBColor[
              0.22303764420255517`, 0.35175708383326204`, 0.9360130359314853],
              UndirectedEdge[128, 155] -> 
             RGBColor[
              0.2008465417565683, 0.32843282816537045`, 0.9347492854759805], 
             UndirectedEdge[316, 362] -> 
             RGBColor[
              0.2117594365618467, 0.339902972523212, 0.9353707586909601], 
             UndirectedEdge[283, 320] -> 
             RGBColor[
              0.20238649627655553`, 0.330051418004633, 0.9348369836077353], 
             UndirectedEdge[49, 396] -> 
             RGBColor[
              0.1936178582000953, 0.3208350234225083, 0.9343376226413184], 
             UndirectedEdge[371, 389] -> 
             RGBColor[
              0.194598112629328, 0.3218653329793524, 0.9343934466809067], 
             UndirectedEdge[53, 58] -> 
             RGBColor[
              0.20217788494718347`, 0.3298321542707407, 0.9348251035011402], 
             UndirectedEdge[18, 399] -> 
             RGBColor[
              0.7658581753592988, 0.7184623790314186, 0.610918793426945], 
             UndirectedEdge[241, 270] -> 
             RGBColor[
              0.31115624108701556`, 0.43971981464523346`, 0.9412017203817521],
              UndirectedEdge[137, 169] -> 
             RGBColor[
              0.6151260920101136, 0.6919294010372166, 0.9662275076726026], 
             UndirectedEdge[156, 386] -> 
             RGBColor[
              0.795873240259372, 0.5261038848053603, 0.5770472868303405], 
             UndirectedEdge[19, 262] -> 
             RGBColor[
              0.23727783738368446`, 0.36672442974702457`, 0.9368239938666727],
              UndirectedEdge[85, 181] -> 
             RGBColor[
              0.2178344766889036, 0.34628822487653976`, 0.9357167232389794], 
             UndirectedEdge[74, 240] -> 
             RGBColor[
              0.8473744873922651, 0.569112601384381, 0.5823896435853375], 
             UndirectedEdge[72, 88] -> 
             RGBColor[
              0.18714176336881175`, 0.31402823714670136`, 0.9339688186212005],
              UndirectedEdge[63, 98] -> 
             RGBColor[
              0.19109841618892076`, 0.3181869301269141, 0.9341941441459625], 
             UndirectedEdge[43, 56] -> 
             RGBColor[
              0.3210051071529382, 0.44798658822988663`, 0.9418389411311112], 
             UndirectedEdge[174, 272] -> 
             RGBColor[
              0.5424648698288314, 0.6349580764887339, 0.9589765455952728], 
             UndirectedEdge[180, 198] -> 
             RGBColor[
              0.30592577418738304`, 0.43475768207038135`, 0.9408842486890967],
              UndirectedEdge[126, 289] -> 
             RGBColor[
              0.1863769520635358, 0.31322437197301883`, 0.933925263748802], 
             UndirectedEdge[233, 244] -> 
             RGBColor[
              0.9570858882964418, 0.9675153062736708, 0.9575265767079428], 
             UndirectedEdge[51, 189] -> 
             RGBColor[
              0.324110599148695, 0.45125735516848015`, 0.9420155490612911], 
             UndirectedEdge[199, 306] -> 
             RGBColor[
              0.19460108481424115`, 0.32186845693414357`, 0.9343936159424405],
              UndirectedEdge[86, 214] -> 
             RGBColor[
              0.32538385594789154`, 0.4498732658782442, 0.9421877381945456], 
             UndirectedEdge[104, 172] -> 
             RGBColor[
              0.8214061746435448, 0.16554281532163417`, 0.16813188305446203`],
              UndirectedEdge[67, 293] -> 
             RGBColor[
              0.3870584168095417, 0.509672279343909, 0.9458839979501529], 
             UndirectedEdge[296, 380] -> 
             RGBColor[
              0.23254239925943204`, 0.3617471840343169, 0.9365543176709494], 
             UndirectedEdge[290, 297] -> 
             RGBColor[
              0.20256888353236238`, 0.33024311857450594`, 0.9348473702921356],
              UndirectedEdge[206, 328] -> 
             RGBColor[
              0.7999219852902167, 0.6448484807342735, 0.5933000289298582], 
             UndirectedEdge[5, 319] -> 
             RGBColor[
              0.3679006517731242, 0.4906453846924169, 0.9447526657346955], 
             UndirectedEdge[235, 393] -> 
             RGBColor[
              0.18743861764572758`, 0.31434024981338815`, 0.9339857240331143],
              UndirectedEdge[40, 189] -> 
             RGBColor[
              0.3938515783304093, 0.5098241340349448, 0.9469676010279292], 
             UndirectedEdge[15, 256] -> 
             RGBColor[
              0.31856719551894513`, 0.448229479012007, 0.9415973902435224], 
             UndirectedEdge[71, 365] -> 
             RGBColor[
              0.17992874679989868`, 0.30644689940110903`, 0.9335580479983027],
              UndirectedEdge[53, 64] -> 
             RGBColor[
              0.18652020523185484`, 0.31337494013569756`, 0.9339334218048136],
              UndirectedEdge[231, 298] -> 
             RGBColor[
              0.1895953138932402, 0.3166070743119639, 0.934108544693864], 
             UndirectedEdge[81, 382] -> 
             RGBColor[
              0.18072466475425025`, 0.3072834596352455, 0.9336033743483478], 
             UndirectedEdge[9, 294] -> 
             RGBColor[
              0.1904972038981096, 0.3175550178902107, 0.9341599059954147], 
             UndirectedEdge[175, 213] -> 
             RGBColor[
              0.25213492118930436`, 0.3823401668202513, 0.9376700828103168], 
             UndirectedEdge[174, 189] -> 
             RGBColor[
              0.3053198459534695, 0.4349817492014926, 0.9408182188837021], 
             UndirectedEdge[14, 127] -> 
             RGBColor[
              0.18967658911817914`, 0.3166924997265216, 0.9341131731976884], 
             UndirectedEdge[86, 95] -> 
             RGBColor[
              0.48521628550800544`, 0.5918110474144382, 0.9529344611319093], 
             UndirectedEdge[103, 200] -> 
             RGBColor[
              0.18928086975494526`, 0.31627657358570604`, 0.9340906375653665],
              UndirectedEdge[24, 112] -> 
             RGBColor[
              0.8789473611792127, 0.4745715601436108, 0.21789626946789925`], 
             UndirectedEdge[109, 360] -> 
             RGBColor[
              0.18328589355082267`, 0.3099754734917281, 0.9337492325393142], 
             UndirectedEdge[90, 121] -> 
             RGBColor[
              0.4596424243656251, 0.5683306378036415, 0.9516722943059467], 
             UndirectedEdge[75, 202] -> 
             RGBColor[
              0.23066301686818202`, 0.3597718339813871, 0.9364472896240648], 
             UndirectedEdge[27, 32] -> 
             RGBColor[
              0.8890352414528142, 0.5147182506008601, 0.2276791825593331], 
             UndirectedEdge[131, 273] -> 
             RGBColor[
              0.19754073794696791`, 0.32495821876141306`, 0.9345610248395222],
              UndirectedEdge[160, 220] -> 
             RGBColor[
              0.5477229997143326, 0.6437052316648666, 0.9575379073944208], 
             UndirectedEdge[50, 147] -> 
             RGBColor[
              0.18125622821196816`, 0.30784216653237684`, 0.9336336461008872],
              UndirectedEdge[13, 339] -> 
             RGBColor[
              0.2328552355524508, 0.3620759948132462, 0.936572133235037], 
             UndirectedEdge[17, 209] -> 
             RGBColor[
              0.2832594251473382, 0.412641193889955, 0.9395309216934591], 
             UndirectedEdge[174, 325] -> 
             RGBColor[
              0.31656779052141654`, 0.4468040521032807, 0.9414587726870038], 
             UndirectedEdge[21, 78] -> 
             RGBColor[
              0.8915698412637564, 0.5208943698778701, 0.23913655286510038`], 
             UndirectedEdge[274, 373] -> 
             RGBColor[
              0.38246482009015115`, 0.5012027656617852, 0.9460144921164949], 
             UndirectedEdge[97, 305] -> 
             RGBColor[
              0.18756138502713113`, 0.3144692861151448, 0.9339927154538672], 
             UndirectedEdge[11, 162] -> 
             RGBColor[
              0.29214677471105677`, 0.42409757281503596`, 0.9399595948655519],
              UndirectedEdge[103, 207] -> 
             RGBColor[
              0.19105231071262538`, 0.3181384703480716, 0.9341915185072943], 
             UndirectedEdge[210, 249] -> 
             RGBColor[
              0.3073650774594488, 0.4403600145758346, 0.9408164770263279], 
             UndirectedEdge[52, 299] -> 
             RGBColor[
              0.18351379325327066`, 0.3102150105286766, 0.9337622110902213], 
             UndirectedEdge[43, 373] -> 
             RGBColor[
              0.2661054797853324, 0.3970241096892522, 0.9384656854547713], 
             UndirectedEdge[1, 336] -> 
             RGBColor[
              0.18695004027347276`, 0.31382672401755374`, 0.9339579002745498],
              UndirectedEdge[30, 345] -> 
             RGBColor[
              0.1795989351746539, 0.30610024647171197`, 0.9335392657141575], 
             UndirectedEdge[247, 363] -> 
             RGBColor[
              0.20876443324933688`, 0.3367550341475864, 0.9352001976830229], 
             UndirectedEdge[14, 119] -> 
             RGBColor[
              0.18348249259608096`, 0.310182111553394, 0.9337604285640995], 
             UndirectedEdge[74, 104] -> 
             RGBColor[
              0.8410345872048564, 0.5203813503819814, 0.5763185480059819], 
             UndirectedEdge[258, 277] -> 
             RGBColor[
              0.19561158896014919`, 0.3229305608611562, 0.9344511626586431], 
             UndirectedEdge[152, 236] -> 
             RGBColor[
              0.2537723278978401, 0.38406118508850384`, 0.9377633307000419], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.26676233186552467`, 0.3975147794964234, 0.938510405060175], 
             UndirectedEdge[120, 132] -> 
             RGBColor[
              0.4382862950940797, 0.5522789014915227, 0.9496356996104882], 
             UndirectedEdge[212, 270] -> 
             RGBColor[
              0.38821783346100136`, 0.5106765077734281, 0.9459578749539519], 
             UndirectedEdge[69, 270] -> 
             RGBColor[
              0.300457761234542, 0.4284750339974831, 0.9405924577811364], 
             UndirectedEdge[16, 270] -> 
             RGBColor[
              0.3384373755940835, 0.46755917720766627`, 0.9427859081978025], 
             UndirectedEdge[24, 73] -> 
             RGBColor[
              0.8757010840349191, 0.46170115302421727`, 0.21528423867768243`],
              UndirectedEdge[56, 178] -> 
             RGBColor[
              0.4116703274319593, 0.5309898792944511, 0.9474522471315552], 
             UndirectedEdge[6, 319] -> 
             RGBColor[
              0.37947514539695637`, 0.5028109113563464, 0.945411816023644], 
             UndirectedEdge[231, 235] -> 
             RGBColor[
              0.18685346885052345`, 0.3137252213290522, 0.9339524006748775], 
             UndirectedEdge[18, 86] -> 
             RGBColor[
              0.5080814719938581, 0.6103740358685661, 0.9547344923700136], 
             UndirectedEdge[30, 63] -> 
             RGBColor[
              0.18069605079375822`, 0.30725338454853857`, 0.9336017448256284],
              UndirectedEdge[46, 358] -> 
             RGBColor[
              0.19603463800818394`, 0.3233752122334996, 0.9344752546760837], 
             UndirectedEdge[241, 389] -> 
             RGBColor[
              0.23293094482355622`, 0.362155570057423, 0.9365764447660246], 
             UndirectedEdge[286, 332] -> 
             RGBColor[
              0.2115950206250406, 0.3397301609490563, 0.9353613954465905], 
             UndirectedEdge[40, 174] -> 
             RGBColor[
              0.4325281900725898, 0.5472165595499049, 0.9492895101378381], 
             UndirectedEdge[157, 365] -> 
             RGBColor[
              0.18416233691758455`, 0.3108966710399138, 0.9337991446924696], 
             UndirectedEdge[235, 336] -> 
             RGBColor[
              0.18593363733157064`, 0.312758420081946, 0.9339000176306419], 
             UndirectedEdge[76, 222] -> 
             RGBColor[
              0.21314128516619657`, 0.3413553830206456, 0.9354494529247159], 
             UndirectedEdge[115, 392] -> 
             RGBColor[
              0.9278459781809479, 0.7343397761790258, 0.5030820645906373], 
             UndirectedEdge[76, 77] -> 
             RGBColor[
              0.1883529029244576, 0.3153012216103682, 0.9340377912271741], 
             UndirectedEdge[160, 366] -> 
             RGBColor[
              0.4270114418839008, 0.5441063729670104, 0.948477074824805], 
             UndirectedEdge[3, 348] -> 
             RGBColor[
              0.45750426505624076`, 0.5671984745069012, 0.9513371690188597], 
             UndirectedEdge[299, 306] -> 
             RGBColor[
              0.19518727715711093`, 0.32248458225324084`, 0.9344269987291731],
              UndirectedEdge[56, 121] -> 
             RGBColor[
              0.3462782939569843, 0.4743505865975952, 0.9432855245824346], 
             UndirectedEdge[280, 322] -> 
             RGBColor[
              0.22572058379982396`, 0.354577023458187, 0.9361658253724963], 
             UndirectedEdge[81, 271] -> 
             RGBColor[
              0.1793288256722832, 0.3058163442587888, 0.9335238833775887], 
             UndirectedEdge[2, 191] -> 
             RGBColor[
              0.19610476461646903`, 0.323448919745091, 0.9344792482826825], 
             UndirectedEdge[146, 377] -> 
             RGBColor[
              0.18543930213235216`, 0.3122388424449055, 0.9338718659723498], 
             UndirectedEdge[10, 396] -> 
             RGBColor[
              0.21852942039278686`, 0.3470186547712968, 0.9357562992548385], 
             UndirectedEdge[382, 384] -> 
             RGBColor[
              0.18572468011707222`, 0.3125387928008556, 0.9338881178264007], 
             UndirectedEdge[147, 391] -> 
             RGBColor[
              0.18230154859335337`, 0.30894086453035285`, 0.9336931755501943],
              UndirectedEdge[133, 216] -> 
             RGBColor[
              0.19274891912622777`, 0.3199217133619542, 0.9342881378465417], 
             UndirectedEdge[86, 264] -> 
             RGBColor[
              0.5671571608223211, 0.6570945561668415, 0.9602327949234224], 
             UndirectedEdge[6, 56] -> 
             RGBColor[
              0.34361946259808085`, 0.47175570963568103`, 0.9431267952187714],
              UndirectedEdge[43, 308] -> 
             RGBColor[
              0.23093015114267265`, 0.3600526090411681, 0.9364625025258073], 
             UndirectedEdge[201, 364] -> 
             RGBColor[
              0.8833604425346897, 0.5491985864535379, 0.5678503651913112], 
             UndirectedEdge[109, 365] -> 
             RGBColor[
              0.1811265179483144, 0.30770583282117103`, 0.9336262592932614], 
             UndirectedEdge[229, 349] -> 
             RGBColor[
              0.20443433824615148`, 0.33220382975535845`, 0.934953605178393], 
             UndirectedEdge[216, 231] -> 
             RGBColor[
              0.19095180161373265`, 0.3180328289124904, 0.9341857946628023], 
             UndirectedEdge[114, 353] -> 
             RGBColor[
              0.2156557406567855, 0.3439982351669406, 0.9355926474451014], 
             UndirectedEdge[70, 236] -> 
             RGBColor[
              0.23684558512377027`, 0.36627010521547854`, 0.9367993777399305],
              UndirectedEdge[64, 94] -> 
             RGBColor[
              0.1809149928406964, 0.30748350652159806`, 0.9336142132513059], 
             UndirectedEdge[240, 285] -> 
             RGBColor[
              0.912943980913413, 0.617290591635334, 0.3939789817698772], 
             UndirectedEdge[56, 90] -> 
             RGBColor[
              0.4950145385889495, 0.5989681852897308, 0.9539261741459244], 
             UndirectedEdge[90, 295] -> 
             RGBColor[
              0.5187067634857201, 0.6194891996894659, 0.9554358217661347], 
             UndirectedEdge[165, 281] -> 
             RGBColor[
              0.6627187385434833, 0.7331187175098175, 0.9692752800168635], 
             UndirectedEdge[54, 345] -> 
             RGBColor[
              0.1817997844893844, 0.30841347864339985`, 0.9336646008267666], 
             UndirectedEdge[101, 136] -> 
             RGBColor[
              0.18384486237801373`, 0.31056298516977654`, 0.9337810649871026],
              UndirectedEdge[6, 314] -> 
             RGBColor[
              0.26913140342587094`, 0.400204547290098, 0.9386380073296472], 
             UndirectedEdge[125, 276] -> 
             RGBColor[
              0.2421845103154749, 0.3718816540993685, 0.9371034216313661], 
             UndirectedEdge[244, 341] -> 
             RGBColor[
              0.6455002366075493, 0.7157181703634723, 0.9520500486891706], 
             UndirectedEdge[46, 153] -> 
             RGBColor[
              0.1918690303202028, 0.3189968944386494, 0.9342380294807175], 
             UndirectedEdge[14, 336] -> 
             RGBColor[
              0.18245115534282794`, 0.3090981107096664, 0.9337016954332534], 
             UndirectedEdge[109, 370] -> 
             RGBColor[
              0.1842051301196885, 0.31094164940857083`, 0.9338015817020224], 
             UndirectedEdge[51, 234] -> 
             RGBColor[
              0.5836503518814267, 0.668728614845342, 0.9624059730547245], 
             UndirectedEdge[144, 228] -> 
             RGBColor[
              0.19707272190642572`, 0.32446630422887235`, 0.934534372018381], 
             UndirectedEdge[320, 347] -> 
             RGBColor[
              0.1968219545840863, 0.324202731873527, 0.9345200911903508], 
             UndirectedEdge[31, 106] -> 
             RGBColor[
              0.21164758701888683`, 0.33978541156189057`, 0.935364389024955], 
             UndirectedEdge[77, 103] -> 
             RGBColor[
              0.18857832587467818`, 0.31553815542369057`, 0.9340506287307058],
              UndirectedEdge[266, 316] -> 
             RGBColor[
              0.23355306875092818`, 0.36280946175002615`, 0.9366118738033387],
              UndirectedEdge[109, 334] -> 
             RGBColor[
              0.18315174728548578`, 0.30983447726149455`, 0.9337415931079549],
              UndirectedEdge[45, 179] -> 
             RGBColor[
              0.3693787364367489, 0.49212881841734446`, 0.9448432238628737], 
             UndirectedEdge[181, 191] -> 
             RGBColor[
              0.2010737277844803, 0.3286716150851321, 0.9347622233841785], 
             UndirectedEdge[125, 148] -> 
             RGBColor[
              0.2977450564931756, 0.4279464199660071, 0.9403529311058223], 
             UndirectedEdge[18, 112] -> 
             RGBColor[
              0.7711240798821252, 0.7393399357057666, 0.6151558638126768], 
             UndirectedEdge[221, 239] -> 
             RGBColor[
              0.8650356462249088, 0.43184524722399015`, 0.20720757963682196`],
              UndirectedEdge[57, 76] -> 
             RGBColor[
              0.20578868678679324`, 0.33362733594223004`, 0.9350307333242034],
              UndirectedEdge[222, 333] -> 
             RGBColor[
              0.21024933242430197`, 0.33831575732852015`, 0.9352847604943257],
              UndirectedEdge[125, 214] -> 
             RGBColor[
              0.25062847588100123`, 0.38075679728707557`, 0.9375842929785951],
              UndirectedEdge[220, 244] -> 
             RGBColor[
              0.7952939705328516, 0.8405065482820335, 0.9629639718031929], 
             UndirectedEdge[143, 379] -> 
             RGBColor[
              0.19607245739300067`, 0.3234149628048294, 0.9344774084341002], 
             UndirectedEdge[31, 241] -> 
             RGBColor[
              0.22984485211178313`, 0.3589118909477702, 0.9364006963515542], 
             UndirectedEdge[81, 374] -> 
             RGBColor[
              0.1848884604275577, 0.3116598728877852, 0.9338404963521592], 
             UndirectedEdge[168, 304] -> 
             RGBColor[
              0.18254777981600245`, 0.3091996691573183, 0.9337071980540577], 
             UndirectedEdge[156, 328] -> 
             RGBColor[
              0.850258311685, 0.36981399504742796`, 0.1950755055586017], 
             UndirectedEdge[46, 363] -> 
             RGBColor[
              0.21059715829347625`, 0.33868134437045616`, 0.9353045686630128],
              UndirectedEdge[51, 269] -> 
             RGBColor[
              0.5625797337470475, 0.652268087816136, 0.9603058507552114], 
             UndirectedEdge[13, 325] -> 
             RGBColor[
              0.25165090865355244`, 0.3818314389570088, 0.9376425190124382], 
             UndirectedEdge[164, 374] -> 
             RGBColor[
              0.1955858495365969, 0.322903507095029, 0.9344496968365499], 
             UndirectedEdge[49, 199] -> 
             RGBColor[
              0.18708382947160418`, 0.313967344947515, 0.93396551937146], 
             UndirectedEdge[49, 313] -> 
             RGBColor[
              0.20302253470198556`, 0.3307199347169253, 0.9348732050551289], 
             UndirectedEdge[176, 388] -> 
             RGBColor[
              0.22659156217478169`, 0.35549247695348607`, 0.9362154263024531],
              UndirectedEdge[45, 232] -> 
             RGBColor[
              0.28995111396047296`, 0.4220873831078549, 0.9398236590445912], 
             UndirectedEdge[176, 250] -> 
             RGBColor[
              0.24600820440775967`, 0.3759005990265677, 0.9373211753532731], 
             UndirectedEdge[346, 390] -> 
             RGBColor[
              0.30688867117659013`, 0.43597701754892004`, 0.9409314950894052],
              UndirectedEdge[331, 335] -> 
             RGBColor[
              0.18932527309814626`, 0.31632324431474484`, 0.9340931662700729],
              UndirectedEdge[135, 355] -> 
             RGBColor[
              0.8802746969932166, 0.9041359691009224, 0.8286360157619015], 
             UndirectedEdge[326, 327] -> 
             RGBColor[
              0.19380937140054372`, 0.3210363159388178, 0.9343485290347655], 
             UndirectedEdge[80, 304] -> 
             RGBColor[
              0.18034926344630414`, 0.30688888905877654`, 0.9335819957992169],
              UndirectedEdge[65, 173] -> 
             RGBColor[
              0.2852130264023293, 0.4171073526721437, 0.9395538319675272], 
             UndirectedEdge[203, 257] -> 
             RGBColor[
              0.27443071882287484`, 0.40444693199068393`, 0.9389884029433275],
              UndirectedEdge[275, 325] -> 
             RGBColor[
              0.2639447266446291, 0.3947530211387112, 0.9383426337599561], 
             UndirectedEdge[240, 337] -> 
             RGBColor[
              0.9128678714659045, 0.6171278012229586, 0.3856949381016387], 
             UndirectedEdge[77, 254] -> 
             RGBColor[
              0.18502833391359902`, 0.3118068887901059, 0.9338484619402648], 
             UndirectedEdge[32, 364] -> 
             RGBColor[
              0.8873546832703587, 0.5018007439852152, 0.22606987814589463`], 
             UndirectedEdge[38, 53] -> 
             RGBColor[
              0.2076634431002256, 0.3355978236940631, 0.9351374979228], 
             UndirectedEdge[28, 291] -> 
             RGBColor[
              0.1970819328198578, 0.3244759854828951, 0.9345348965662746], 
             UndirectedEdge[174, 269] -> 
             RGBColor[
              0.543788980551822, 0.6359924818491485, 0.9591085205776222], 
             UndirectedEdge[216, 361] -> 
             RGBColor[
              0.20867332138388106`, 0.3366592698001664, 0.9351950089970731], 
             UndirectedEdge[356, 363] -> 
             RGBColor[
              0.2074463229173425, 0.3353696166156383, 0.9351251332495853], 
             UndirectedEdge[151, 383] -> 
             RGBColor[
              0.20018660218381945`, 0.3277391898318258, 0.9347117028936056], 
             UndirectedEdge[61, 130] -> 
             RGBColor[
              0.19568837198846437`, 0.3230112646922406, 0.9344555353385153], 
             UndirectedEdge[331, 338] -> 
             RGBColor[
              0.2166739251358942, 0.34506841161110846`, 0.9356506315449178], 
             UndirectedEdge[239, 246] -> 
             RGBColor[
              0.874004135287985, 0.576823099817974, 0.5832370617608514], 
             UndirectedEdge[190, 212] -> 
             RGBColor[
              0.6867778683351773, 0.7513832913392242, 0.9534033725466657], 
             UndirectedEdge[111, 286] -> 
             RGBColor[
              0.1920478961746871, 0.3191848937924626, 0.934248215626522], 
             UndirectedEdge[228, 273] -> 
             RGBColor[
              0.1927101706170558, 0.31988098622201705`, 0.9342859311762677], 
             UndirectedEdge[199, 299] -> 
             RGBColor[
              0.18707599573729403`, 0.31395911119606756`, 0.93396507325188], 
             UndirectedEdge[50, 391] -> 
             RGBColor[
              0.18008156514952903`, 0.3066075211758136, 0.9335667507772396], 
             UndirectedEdge[358, 362] -> 
             RGBColor[
              0.18997045450082056`, 0.31700137087581914`, 0.9341299083964949],
              UndirectedEdge[42, 98] -> 
             RGBColor[
              0.20876468464708048`, 0.33675529838255447`, 0.9352002119997525],
              UndirectedEdge[39, 251] -> 
             RGBColor[
              0.18672478342346222`, 0.3135899647860835, 0.9339450722301794], 
             UndirectedEdge[148, 179] -> 
             RGBColor[
              0.39396314610535543`, 0.515635700812435, 0.9463286881882242], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.19127206346984504`, 0.31836944442903903`, 0.934204033101723], 
             UndirectedEdge[77, 333] -> 
             RGBColor[
              0.18546095018256298`, 0.31226159591824276`, 0.9338730987967839],
              UndirectedEdge[173, 354] -> 
             RGBColor[
              0.24916626557073213`, 0.3792199215414943, 0.9375010222645717], 
             UndirectedEdge[160, 217] -> 
             RGBColor[
              0.7263465347719837, 0.7798834744139984, 0.7188240157462833], 
             UndirectedEdge[59, 90] -> 
             RGBColor[
              0.47744540309430256`, 0.5837506831746934, 0.9528066843679821], 
             UndirectedEdge[237, 380] -> 
             RGBColor[
              0.20872851353399335`, 0.33671728024931885`, 0.9351981521083725],
              UndirectedEdge[285, 399] -> 
             RGBColor[
              0.9603875503566552, 0.868303119703074, 0.4348794443842956], 
             UndirectedEdge[51, 392] -> 
             RGBColor[
              0.6863309387769014, 0.7477531849917098, 0.8714804732443268], 
             UndirectedEdge[264, 307] -> 
             RGBColor[
              0.5358230864206805, 0.6299545558165122, 0.958236215410184], 
             UndirectedEdge[78, 208] -> 
             RGBColor[
              0.9064764270189856, 0.5728170966942296, 0.4660720225452738], 
             UndirectedEdge[28, 383] -> 
             RGBColor[
              0.20767130167756592`, 0.3356060835571104, 0.9351379454571538], 
             UndirectedEdge[255, 268] -> 
             RGBColor[
              0.7573621449450872, 0.5111257415751345, 0.5750858104368912], 
             UndirectedEdge[46, 247] -> 
             RGBColor[
              0.1994607168120997, 0.32697623828235756`, 0.9346703647955372], 
             UndirectedEdge[272, 392] -> 
             RGBColor[
              0.8660085977148573, 0.8940614807970035, 0.8861195606683994], 
             UndirectedEdge[316, 359] -> 
             RGBColor[
              0.21077886401933704`, 0.3388723286091443, 0.9353149165352912], 
             UndirectedEdge[223, 242] -> 
             RGBColor[
              0.8910877878932282, 0.5812972246774919, 0.23007311301914762`], 
             UndirectedEdge[158, 390] -> 
             RGBColor[
              0.3007335296132649, 0.43064574329317795`, 0.9405392949117681], 
             UndirectedEdge[26, 128] -> 
             RGBColor[
              0.19080558249119994`, 0.3178791433438807, 0.9341774677000858], 
             UndirectedEdge[136, 335] -> 
             RGBColor[
              0.18204623503960604`, 0.3086725137975501, 0.9336786358210108], 
             UndirectedEdge[193, 248] -> 
             RGBColor[
              0.20247189401375032`, 0.330141176440954, 0.9348418468825339], 
             UndirectedEdge[281, 386] -> 
             RGBColor[
              0.5947242732295994, 0.6793804571151425, 0.9626628801063983], 
             UndirectedEdge[225, 337] -> 
             RGBColor[
              0.9393785469822551, 0.9502915240338172, 0.7911384355526612], 
             UndirectedEdge[30, 297] -> 
             RGBColor[
              0.19356559882175525`, 0.3207800955024369, 0.9343346465470327], 
             UndirectedEdge[32, 104] -> 
             RGBColor[
              0.8880206846932135, 0.5069199227649615, 0.22670764186056142`], 
             UndirectedEdge[264, 366] -> 
             RGBColor[
              0.5588455342770764, 0.6498954430078475, 0.9597031854296422], 
             UndirectedEdge[2, 97] -> 
             RGBColor[
              0.18893766617089083`, 0.31591584485850077`, 0.9340710926289788],
              UndirectedEdge[258, 377] -> 
             RGBColor[
              0.18407204095648846`, 0.3108017642597073, 0.933794002471066], 
             UndirectedEdge[134, 135] -> 
             RGBColor[
              0.9129052217970873, 0.9297159641585085, 0.8318647617559947], 
             UndirectedEdge[185, 338] -> 
             RGBColor[
              0.3169003211264983, 0.4420126040845884, 0.9416659454971446], 
             UndirectedEdge[40, 84] -> 
             RGBColor[
              0.42994887224450423`, 0.5449824840875006, 0.9491251582866337], 
             UndirectedEdge[217, 242] -> 
             RGBColor[
              0.9226715072655902, 0.6951934560850966, 0.34236801946865186`], 
             UndirectedEdge[124, 266] -> 
             RGBColor[
              0.27124098687969256`, 0.402330909521441, 0.9387614748820916], 
             UndirectedEdge[219, 293] -> 
             RGBColor[
              0.34300984476630975`, 0.47151962018566573`, 0.943077261890181], 
             UndirectedEdge[37, 170] -> 
             RGBColor[
              0.29023151793817503`, 0.41867896684859873`, 0.9399752176813956],
              UndirectedEdge[205, 293] -> 
             RGBColor[
              0.3494560104043527, 0.47710296486763304`, 0.9434880058645166], 
             UndirectedEdge[122, 268] -> 
             RGBColor[
              0.638662857560744, 0.7169674525945936, 0.9650845862531987], 
             UndirectedEdge[246, 392] -> 
             RGBColor[
              0.955664633870156, 0.964911832854005, 0.8948405878073766], 
             UndirectedEdge[282, 398] -> 
             RGBColor[
              0.3466184248527956, 0.47079867288483046`, 0.9434480372889362], 
             UndirectedEdge[34, 248] -> 
             RGBColor[
              0.24062348998029212`, 0.37024092275268566`, 0.9370145238326], 
             UndirectedEdge[263, 264] -> 
             RGBColor[
              0.5576221544304325, 0.6488358128735436, 0.9596252327476064], 
             UndirectedEdge[100, 377] -> 
             RGBColor[
              0.19744186238260558`, 0.3248542942741953, 0.9345553940224051], 
             UndirectedEdge[107, 241] -> 
             RGBColor[
              0.30591595912176667`, 0.43518094579116473`, 0.9408678142487259],
              UndirectedEdge[11, 95] -> 
             RGBColor[
              0.43568729767870357`, 0.5489115275560077, 0.9497785178241904], 
             UndirectedEdge[7, 96] -> 
             RGBColor[
              0.5984222253415448, 0.6831169372542267, 0.9626727079088397], 
             UndirectedEdge[111, 383] -> 
             RGBColor[
              0.1988021595169091, 0.3262840528101681, 0.9346328609318244], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.2782593236768137, 0.4070163756656283, 0.939259698655848], 
             UndirectedEdge[121, 122] -> 
             RGBColor[
              0.4544345003462795, 0.5641026104704333, 0.9512623074498896], 
             UndirectedEdge[156, 221] -> 
             RGBColor[
              0.866647121618338, 0.4442317532509077, 0.20875073029347097`], 
             UndirectedEdge[61, 176] -> 
             RGBColor[
              0.2215167477526256, 0.3501585252339816, 0.9359264231286265], 
             UndirectedEdge[128, 261] -> 
             RGBColor[
              0.22729090761283746`, 0.3562275333499445, 0.9362552529905616], 
             UndirectedEdge[69, 381] -> 
             RGBColor[
              0.21898984745913425`, 0.34750259281079, 0.9357825198951262], 
             UndirectedEdge[166, 178] -> 
             RGBColor[
              0.7156925694809679, 0.7734991059400932, 0.884905461880064], 
             UndirectedEdge[114, 202] -> 
             RGBColor[
              0.2423249813764799, 0.37202929809086444`, 0.937111421250482], 
             UndirectedEdge[40, 134] -> 
             RGBColor[
              0.6760140538149009, 0.745057217744171, 0.9695892868351288], 
             UndirectedEdge[84, 234] -> 
             RGBColor[
              0.5622802808581155, 0.6502189334159502, 0.961044291025931], 
             UndirectedEdge[236, 367] -> 
             RGBColor[
              0.3129287562528536, 0.440105110895209, 0.9413567694167602], 
             UndirectedEdge[307, 366] -> 
             RGBColor[
              0.37137695467694465`, 0.4960897850178574, 0.9448847890496364], 
             UndirectedEdge[129, 396] -> 
             RGBColor[
              0.19432308879693078`, 0.32157626549398477`, 0.934377784480513], 
             UndirectedEdge[67, 208] -> 
             RGBColor[
              0.7091189037719949, 0.7670538844748609, 0.8568671364687419], 
             UndirectedEdge[203, 309] -> 
             RGBColor[
              0.2616767930351678, 0.3923692791198713, 0.9382134782960043], 
             UndirectedEdge[142, 302] -> 
             RGBColor[
              0.18693197467623224`, 0.31380773592942895`, 0.9339568714655127],
              UndirectedEdge[93, 248] -> 
             RGBColor[
              0.22615954726936105`, 0.355038401896562, 0.9361908236926982], 
             UndirectedEdge[110, 227] -> 
             RGBColor[
              0.1954518354139104, 0.3227626497550994, 0.934442064930519], 
             UndirectedEdge[129, 361] -> 
             RGBColor[
              0.20336215554475928`, 0.33107689775588556`, 0.9348925459597008],
              UndirectedEdge[236, 332] -> 
             RGBColor[
              0.2395600162179548, 0.36912314440033817`, 0.9369539605751034], 
             UndirectedEdge[306, 353] -> 
             RGBColor[
              0.19636662006403216`, 0.3237241464230741, 0.9344941605630408], 
             UndirectedEdge[257, 280] -> 
             RGBColor[
              0.2873202290991691, 0.41799462453322234`, 0.9397224414852408], 
             UndirectedEdge[208, 385] -> 
             RGBColor[
              0.9937202968318795, 0.9909321476846529, 0.7000134809555262], 
             UndirectedEdge[79, 302] -> 
             RGBColor[
              0.21120952198211004`, 0.3393249774333106, 0.9353394418691697], 
             UndirectedEdge[21, 242] -> 
             RGBColor[
              0.907737765098039, 0.6451681172975665, 0.25461897498786773`], 
             UndirectedEdge[94, 103] -> 
             RGBColor[
              0.18776701535974932`, 0.31468541663244265`, 0.934004425797107], 
             UndirectedEdge[237, 308] -> 
             RGBColor[
              0.19941664213352878`, 0.3269299130006835, 0.9346678548077954], 
             UndirectedEdge[1, 235] -> 
             RGBColor[
              0.19253038583618232`, 0.3196920210183055, 0.9342756926989647], 
             UndirectedEdge[31, 374] -> 
             RGBColor[
              0.1933477765192394, 0.32055115045176114`, 0.9343222418891437], 
             UndirectedEdge[324, 351] -> 
             RGBColor[
              0.7714595274314936, 0.8219737948771062, 0.9777595758801894], 
             UndirectedEdge[62, 396] -> 
             RGBColor[
              0.20033182917246628`, 0.3278918326048165, 0.934719973355765], 
             UndirectedEdge[13, 123] -> 
             RGBColor[
              0.2129302625842361, 0.3411335849074007, 0.9354374355008532], 
             UndirectedEdge[112, 337] -> 
             RGBColor[
              0.9655773454319732, 0.8890178859650467, 0.43083247110178885`], 
             UndirectedEdge[262, 286] -> 
             RGBColor[
              0.20449842182687056`, 0.3322711856618279, 0.9349572546435119], 
             UndirectedEdge[56, 59] -> 
             RGBColor[
              0.3640812726856617, 0.4897706319686471, 0.9444199146444701], 
             UndirectedEdge[61, 118] -> 
             RGBColor[
              0.22412293343441853`, 0.3528977916272621, 0.9360748415476985], 
             UndirectedEdge[14, 235] -> 
             RGBColor[
              0.1880315009055375, 0.3149634077104182, 0.9340194878576683], 
             UndirectedEdge[154, 286] -> 
             RGBColor[
              0.2001789472954632, 0.3277311440588154, 0.9347112669590381], 
             UndirectedEdge[159, 215] -> 
             RGBColor[
              0.1817543271405076, 0.3083657000875679, 0.9336620120979963], 
             UndirectedEdge[25, 385] -> 
             RGBColor[
              0.9058721590894482, 0.562305822104239, 0.3994132353001115], 
             UndirectedEdge[165, 256] -> 
             RGBColor[
              0.624029163944416, 0.6996077525866663, 0.9668100145352584], 
             UndirectedEdge[292, 384] -> 
             RGBColor[
              0.19197167888601352`, 0.3191047845896115, 0.9342438751646855], 
             UndirectedEdge[1, 49] -> 
             RGBColor[
              0.19061232216343427`, 0.3176760144859865, 0.9341664618103227], 
             UndirectedEdge[93, 125] -> 
             RGBColor[
              0.24791606512635506`, 0.37790588160716765`, 0.9374298251987702],
              UndirectedEdge[15, 37] -> 
             RGBColor[
              0.31731211488685307`, 0.44714239125067556`, 0.9415174176154697],
              UndirectedEdge[141, 399] -> 
             RGBColor[
              0.8960867985444002, 0.6145986026106095, 0.23467160372890067`], 
             UndirectedEdge[42, 288] -> 
             RGBColor[
              0.26094257460696524`, 0.39159756899969334`, 0.938171665642697], 
             UndirectedEdge[26, 218] -> 
             RGBColor[
              0.188929981383257, 0.31590776765945394`, 0.9340706549916917], 
             UndirectedEdge[292, 389] -> 
             RGBColor[
              0.1985170723266464, 0.32598440809763013`, 0.9346166256380877], 
             UndirectedEdge[87, 361] -> 
             RGBColor[
              0.20790747959893147`, 0.33585432152701067`, 0.9351513954403816],
              UndirectedEdge[3, 11] -> 
             RGBColor[
              0.4469167817161049, 0.5580281285800609, 0.9506625439425702], 
             UndirectedEdge[217, 364] -> 
             RGBColor[
              0.9053733542786032, 0.5622322721281416, 0.3258032886328436], 
             UndirectedEdge[83, 120] -> 
             RGBColor[
              0.7316668327109251, 0.7891725193318362, 0.9665740024152043], 
             UndirectedEdge[251, 380] -> 
             RGBColor[
              0.20519908617390886`, 0.3330076283152506, 0.9349971564415356], 
             UndirectedEdge[209, 390] -> 
             RGBColor[
              0.2987767120225358, 0.42895084624860025`, 0.9404146082252327], 
             UndirectedEdge[149, 315] -> 
             RGBColor[
              0.21772472600366666`, 0.3461728699477604, 0.9357104730998167], 
             UndirectedEdge[34, 263] -> 
             RGBColor[
              0.3276003815122878, 0.45396612776116196`, 0.9422494083788064], 
             UndirectedEdge[327, 376] -> 
             RGBColor[
              0.2026044968471712, 0.33028055042638454`, 0.9348493984177288], 
             UndirectedEdge[113, 316] -> 
             RGBColor[
              0.2709397029977173, 0.40210518479292345`, 0.9387409873151243], 
             UndirectedEdge[85, 307] -> 
             RGBColor[
              0.294549891018896, 0.4232589122924366, 0.9402196391759287], 
             UndirectedEdge[140, 257] -> 
             RGBColor[
              0.2744017745717613, 0.404416509747592, 0.9389867546110457], 
             UndirectedEdge[228, 330] -> 
             RGBColor[
              0.1947627843493959, 0.3220384133979338, 0.9344028244917546], 
             UndirectedEdge[22, 96] -> 
             RGBColor[
              0.5322372446835262, 0.6257908335621027, 0.9584554594663912], 
             UndirectedEdge[22, 323] -> 
             RGBColor[
              0.35748321527472365`, 0.48405572626730053`, 0.943999492260678], 
             UndirectedEdge[167, 269] -> 
             RGBColor[
              0.5269179419290838, 0.6213796361571894, 0.958033512915055], 
             UndirectedEdge[85, 214] -> 
             RGBColor[
              0.2402451657445982, 0.3698432799938294, 0.9369929788270578], 
             UndirectedEdge[89, 155] -> 
             RGBColor[
              0.19816316122321598`, 0.3256124250886648, 0.9345964709243118], 
             UndirectedEdge[1, 396] -> 
             RGBColor[
              0.1965523248147455, 0.3239193338904351, 0.9345047361738683], 
             UndirectedEdge[172, 208] -> 
             RGBColor[
              0.9084092508392714, 0.5876736275457447, 0.4679228968183917], 
             UndirectedEdge[45, 339] -> 
             RGBColor[
              0.26817858765203434`, 0.39920307749978645`, 0.9385837458808918],
              UndirectedEdge[250, 363] -> 
             RGBColor[
              0.2391241828797345, 0.3686650559284389, 0.9369291405112493], 
             UndirectedEdge[167, 222] -> 
             RGBColor[
              0.2713202012615644, 0.4023656525144891, 0.9387677624449977], 
             UndirectedEdge[73, 208] -> 
             RGBColor[
              0.9618152962983195, 0.8769997675618114, 0.5142240753361885], 
             UndirectedEdge[14, 317] -> 
             RGBColor[
              0.18995153056345765`, 0.3169814806178038, 0.9341288307062575], 
             UndirectedEdge[157, 334] -> 
             RGBColor[
              0.1861875662547559, 0.3130253154802374, 0.9339144785071631], 
             UndirectedEdge[107, 190] -> 
             RGBColor[
              0.6524189980541504, 0.7216233648288316, 0.9512140557147148], 
             UndirectedEdge[12, 209] -> 
             RGBColor[
              0.3216593094784126, 0.45300190701520204`, 0.9417177382985756], 
             UndirectedEdge[185, 219] -> 
             RGBColor[
              0.36836286362019555`, 0.4934791308371227, 0.9446927338327562], 
             UndirectedEdge[318, 345] -> 
             RGBColor[
              0.18668882027855277`, 0.3135521652405886, 0.9339430241822795], 
             UndirectedEdge[36, 383] -> 
             RGBColor[
              0.20061589185273376`, 0.3281904004923918, 0.9347361503051731], 
             UndirectedEdge[24, 357] -> 
             RGBColor[
              0.8389436700878857, 0.3003436902863443, 0.184925808497731], 
             UndirectedEdge[344, 354] -> 
             RGBColor[
              0.2035510812828702, 0.3312754706852238, 0.9349033050009957], 
             UndirectedEdge[7, 194] -> 
             RGBColor[
              0.7215884971461117, 0.7768639400824314, 0.7979961077324451], 
             UndirectedEdge[97, 248] -> 
             RGBColor[
              0.2054442201466507, 0.3332652796629938, 0.9350111164586401], 
             UndirectedEdge[14, 129] -> 
             RGBColor[
              0.18681866782962492`, 0.3136886432495756, 0.9339504188082208], 
             UndirectedEdge[160, 307] -> 
             RGBColor[
              0.403988994027505, 0.524165485775675, 0.9470101048053469], 
             UndirectedEdge[165, 400] -> 
             RGBColor[
              0.873464012393198, 0.6536035645465732, 0.5928491209890607], 
             UndirectedEdge[310, 323] -> 
             RGBColor[
              0.33914507736848765`, 0.46547732189212476`, 0.9429296732937578],
              UndirectedEdge[309, 339] -> 
             RGBColor[
              0.27457216058382816`, 0.4059231280270391, 0.9389478504009139], 
             UndirectedEdge[355, 395] -> 
             RGBColor[
              0.6171730285902994, 0.6981983576754478, 0.9642971542356892], 
             UndirectedEdge[32, 240] -> 
             RGBColor[
              0.8943605848806221, 0.5556511737673611, 0.23277873743991706`], 
             UndirectedEdge[66, 322] -> 
             RGBColor[
              0.2070879506142999, 0.33499294460302415`, 0.9351047244770914], 
             UndirectedEdge[28, 267] -> 
             RGBColor[
              0.23148773999796957`, 0.36063867028126045`, 0.9364942563862377],
              UndirectedEdge[51, 102] -> 
             RGBColor[
              0.32952467941339164`, 0.45694789679919157`, 0.9423238729229517],
              UndirectedEdge[244, 321] -> 
             RGBColor[
              0.7545634824664897, 0.8074397031821838, 0.959757518581915], 
             UndirectedEdge[140, 309] -> 
             RGBColor[
              0.2616478487840542, 0.3923388568767794, 0.9382118299637227], 
             UndirectedEdge[12, 324] -> 
             RGBColor[
              0.4708028735942141, 0.577300258720949, 0.9525700303913813], 
             UndirectedEdge[130, 287] -> 
             RGBColor[
              0.1859722872961475, 0.31279904364526556`, 0.9339022186889471], 
             UndirectedEdge[267, 367] -> 
             RGBColor[
              0.315534462322565, 0.44284387318578267`, 0.9415051605226336], 
             UndirectedEdge[138, 229] -> 
             RGBColor[
              0.19456770903936127`, 0.32183337687859837`, 0.9343917152414362],
              UndirectedEdge[97, 193] -> 
             RGBColor[
              0.1899172543843397, 0.31694545418031556`, 0.9341268787285638], 
             UndirectedEdge[248, 340] -> 
             RGBColor[
              0.2104667967928659, 0.33854432616791813`, 0.9352971447684058], 
             UndirectedEdge[162, 248] -> 
             RGBColor[
              0.24516386461647438`, 0.3750131443716921, 0.9372730914512483], 
             UndirectedEdge[127, 317] -> 
             RGBColor[
              0.19507910076484197`, 0.32237088200618674`, 0.9344208382436661],
              UndirectedEdge[269, 355] -> 
             RGBColor[
              0.7546443194902623, 0.8082531449858283, 0.9761795512808198], 
             UndirectedEdge[161, 184] -> 
             RGBColor[
              0.19128276610466352`, 0.31838069357681953`, 0.9342046426009427],
              UndirectedEdge[340, 360] -> 
             RGBColor[
              0.1940919893072422, 0.3213333652777681, 0.9343646237064562], 
             UndirectedEdge[19, 185] -> 
             RGBColor[
              0.330002266441723, 0.4557835793222022, 0.9424120819002554], 
             UndirectedEdge[240, 357] -> 
             RGBColor[
              0.8443947063429684, 0.3422427436022275, 0.19014572697166301`], 
             UndirectedEdge[75, 132] -> 
             RGBColor[
              0.28812004710636396`, 0.4155836677571048, 0.9398870475355221], 
             UndirectedEdge[89, 353] -> 
             RGBColor[
              0.18963294311823536`, 0.31664662501326446`, 0.93411068762256], 
             UndirectedEdge[214, 312] -> 
             RGBColor[
              0.2713270321361526, 0.4025122922755047, 0.9387630451365561], 
             UndirectedEdge[119, 129] -> 
             RGBColor[
              0.18575214150891103`, 0.312567656464831, 0.9338896817120405], 
             UndirectedEdge[143, 377] -> 
             RGBColor[
              0.1848896476706373, 0.3116611207555374, 0.933840563963896], 
             UndirectedEdge[5, 122] -> 
             RGBColor[
              0.440201175363544, 0.5493422068445898, 0.9504444277972779], 
             UndirectedEdge[42, 318] -> 
             RGBColor[
              0.2054522043558168, 0.33327367157305554`, 0.9350115711475404], 
             UndirectedEdge[6, 137] -> 
             RGBColor[
              0.32002599977803325`, 0.451320237982877, 0.941623440630758], 
             UndirectedEdge[113, 149] -> 
             RGBColor[
              0.26206453775242544`, 0.39277682340214404`, 0.9382355597840353],
              UndirectedEdge[67, 124] -> 
             RGBColor[
              0.3674760832994186, 0.49271104629414053`, 0.9446362289748654], 
             UndirectedEdge[141, 337] -> 
             RGBColor[
              0.9298221770988357, 0.7361333470484221, 0.40148742427443984`], 
             UndirectedEdge[63, 224] -> 
             RGBColor[
              0.1802578853175729, 0.30679284485177194`, 0.9335767919499673], 
             UndirectedEdge[244, 357] -> 
             RGBColor[
              0.9059329560446046, 0.7028448327231054, 0.5818836591998524], 
             UndirectedEdge[9, 192] -> 
             RGBColor[
              0.1863278971063823, 0.3131728121027866, 0.9339224701415624], 
             UndirectedEdge[46, 369] -> 
             RGBColor[
              0.19594555683555187`, 0.3232815822729907, 0.934470181635086], 
             UndirectedEdge[350, 392] -> 
             RGBColor[
              0.9924671913475096, 0.9911530042849124, 0.7745016638630496], 
             UndirectedEdge[275, 339] -> 
             RGBColor[
              0.24514905354352745`, 0.3749975769949486, 0.9372722479825549], 
             UndirectedEdge[119, 127] -> 
             RGBColor[
              0.18861006279746526`, 0.31557151294177693`, 0.9340524361015079],
              UndirectedEdge[152, 398] -> 
             RGBColor[
              0.3414317727237982, 0.4653471726445155, 0.943152665123154], 
             UndirectedEdge[105, 229] -> 
             RGBColor[
              0.20817939443044792`, 0.33614012125533055`, 0.9351668805877746],
              UndirectedEdge[181, 365] -> 
             RGBColor[
              0.1879270858801807, 0.3148536608984732, 0.9340135415764423], 
             UndirectedEdge[24, 285] -> 
             RGBColor[
              0.9074929446583304, 0.5753915383194507, 0.38875906329594523`], 
             UndirectedEdge[167, 189] -> 
             RGBColor[
              0.2884488073307313, 0.4203689035095335, 0.9397432112211349], 
             UndirectedEdge[157, 191] -> 
             RGBColor[
              0.1973089788218841, 0.3247146252265727, 0.9345478265002056], 
             UndirectedEdge[78, 194] -> 
             RGBColor[
              0.9072346231009216, 0.5724833285992563, 0.40645475392950137`], 
             UndirectedEdge[107, 268] -> 
             RGBColor[
              0.5139907876886572, 0.6129102178843966, 0.9560554271690249], 
             UndirectedEdge[5, 274] -> 
             RGBColor[
              0.38775900825169696`, 0.5067672930904867, 0.9463159883002454], 
             UndirectedEdge[12, 118] -> 
             RGBColor[
              0.27367870261090094`, 0.4049840470489852, 0.9388969692911083], 
             UndirectedEdge[20, 291] -> 
             RGBColor[
              0.18873168488737596`, 0.31569934546955897`, 0.9340593622996046],
              UndirectedEdge[6, 379] -> 
             RGBColor[
              0.25634517615934155`, 0.38676541173934353`, 0.9379098506023464],
              UndirectedEdge[97, 181] -> 
             RGBColor[
              0.19390662933890207`, 0.32113854019854193`, 0.9343540677304747],
              UndirectedEdge[39, 320] -> 
             RGBColor[
              0.18948414481075992`, 0.3164902285577502, 0.9341022137790767], 
             UndirectedEdge[202, 218] -> 
             RGBColor[
              0.2171099632633392, 0.3455267153294672, 0.9356754632712151], 
             UndirectedEdge[61, 344] -> 
             RGBColor[
              0.20030701799861927`, 0.32786575448798405`, 0.9347185603961192],
              UndirectedEdge[181, 214] -> 
             RGBColor[
              0.21733436721625865`, 0.34576257811201794`, 0.9356882427443579],
              UndirectedEdge[274, 324] -> 
             RGBColor[
              0.5631040589260905, 0.6561922684417929, 0.9587487607182468], 
             UndirectedEdge[62, 231] -> 
             RGBColor[
              0.19164937615014635`, 0.31876602397904136`, 0.934225520500682], 
             UndirectedEdge[117, 289] -> 
             RGBColor[
              0.20615434433043495`, 0.33401166520462483`, 0.935051556980372], 
             UndirectedEdge[14, 396] -> 
             RGBColor[
              0.19205343988410067`, 0.31919072058254777`, 0.9342485313325719],
              UndirectedEdge[79, 175] -> 
             RGBColor[
              0.2563476435480917, 0.3867680051213614, 0.9379099911164857], 
             UndirectedEdge[246, 395] -> 
             RGBColor[
              0.6944421379403393, 0.7593719483680503, 0.9717835682731306], 
             UndirectedEdge[87, 396] -> 
             RGBColor[
              0.198868412851103, 0.3263536892651099, 0.9346366339611938], 
             UndirectedEdge[341, 366] -> 
             RGBColor[
              0.36531722643847, 0.49084115298848774`, 0.9444986685246879], 
             UndirectedEdge[40, 226] -> 
             RGBColor[
              0.48315013418370223`, 0.5910627432060597, 0.9525150956533707], 
             UndirectedEdge[67, 316] -> 
             RGBColor[
              0.32978816517065423`, 0.4531895985227258, 0.9424866278961124], 
             UndirectedEdge[303, 376] -> 
             RGBColor[
              0.21141869489039777`, 0.33954483142224945`, 0.9353513539568531],
              UndirectedEdge[208, 357] -> 
             RGBColor[
              0.9250578823512863, 0.7156423048239384, 0.4838656451562371], 
             UndirectedEdge[54, 66] -> 
             RGBColor[
              0.19944158418676777`, 0.3269561286800552, 0.9346692752208288], 
             UndirectedEdge[3, 160] -> 
             RGBColor[
              0.5207461823507223, 0.6218042360373149, 0.9554141935122193], 
             UndirectedEdge[230, 328] -> 
             RGBColor[
              0.8436345364621675, 0.31890075612792645`, 0.1887325709247331], 
             UndirectedEdge[282, 383] -> 
             RGBColor[
              0.23774824777614534`, 0.3672188608952424, 0.9368507830426136], 
             UndirectedEdge[106, 150] -> 
             RGBColor[
              0.2101822963835033, 0.33824529819931026`, 0.9352809428909732], 
             UndirectedEdge[1, 298] -> 
             RGBColor[
              0.19527223087889906`, 0.32257387400121723`, 0.9344318367179512],
              UndirectedEdge[66, 131] -> 
             RGBColor[
              0.2137636212718384, 0.34200949772606326`, 0.9354848940452685], 
             UndirectedEdge[53, 126] -> 
             RGBColor[
              0.1894916420221746, 0.31649810860229766`, 0.9341026407341755], 
             UndirectedEdge[182, 281] -> 
             RGBColor[
              0.38860982761707186`, 0.5110160334092172, 0.94598285247495], 
             UndirectedEdge[74, 263] -> 
             RGBColor[
              0.627506347078178, 0.7037780429959705, 0.9664982429670084], 
             UndirectedEdge[24, 243] -> 
             RGBColor[
              0.8951565236421906, 0.5687878448594291, 0.5520035990795774], 
             UndirectedEdge[177, 252] -> 
             RGBColor[
              0.6322093663988135, 0.7067582685174405, 0.9673012182198607], 
             UndirectedEdge[10, 216] -> 
             RGBColor[
              0.21860581417743288`, 0.3470989494826055, 0.9357606497678597], 
             UndirectedEdge[280, 339] -> 
             RGBColor[
              0.2515419198726136, 0.3817168848379542, 0.9376363122625981], 
             UndirectedEdge[152, 154] -> 
             RGBColor[
              0.23114091709829876`, 0.3602741374238645, 0.93647450533518], 
             UndirectedEdge[36, 304] -> 
             RGBColor[
              0.18688421139568462`, 0.3137575336932065, 0.933954151417345], 
             UndirectedEdge[128, 299] -> 
             RGBColor[
              0.19113698074466645`, 0.31822746392013684`, 0.934196340340361], 
             UndirectedEdge[95, 162] -> 
             RGBColor[
              0.41586939242453425`, 0.5283792415607237, 0.9486390212485251], 
             UndirectedEdge[215, 329] -> 
             RGBColor[
              0.1867198905000643, 0.313584822013363, 0.9339447935854304], 
             UndirectedEdge[208, 387] -> 
             RGBColor[
              0.7635706581669874, 0.8120231295414462, 0.8609429981480392], 
             UndirectedEdge[178, 197] -> 
             RGBColor[
              0.7030008791274289, 0.7649478943931832, 0.947330285544383], 
             UndirectedEdge[53, 303] -> 
             RGBColor[
              0.20281627238444755`, 0.3305031399434066, 0.9348614587212829], 
             UndirectedEdge[59, 121] -> 
             RGBColor[
              0.3287091584623374, 0.4591330844825578, 0.9421660348044922], 
             UndirectedEdge[134, 269] -> 
             RGBColor[
              0.7872748442941331, 0.8338331400434145, 0.9794082972749127], 
             UndirectedEdge[44, 362] -> 
             RGBColor[
              0.21291981933663207`, 0.3411226083920287, 0.9354368407733515], 
             UndirectedEdge[284, 338] -> 
             RGBColor[
              0.2553995027309328, 0.3857714490069275, 0.9378559958995971], 
             UndirectedEdge[12, 346] -> 
             RGBColor[
              0.329771268632467, 0.46002807831552184`, 0.9422346251627481], 
             UndirectedEdge[113, 387] -> 
             RGBColor[
              0.4208258242811829, 0.5366129491256768, 0.9486460027249637], 
             UndirectedEdge[55, 400] -> 
             RGBColor[
              0.9109049028745734, 0.6513336536973703, 0.2699888799203509], 
             UndirectedEdge[25, 201] -> 
             RGBColor[
              0.8831813824108397, 0.5478222518769809, 0.567678897014493], 
             UndirectedEdge[123, 309] -> 
             RGBColor[
              0.2546471876156135, 0.3849807181211936, 0.93781315266673], 
             UndirectedEdge[35, 162] -> 
             RGBColor[
              0.25429020183451534`, 0.3846055034310536, 0.9377928228546097], 
             UndirectedEdge[73, 172] -> 
             RGBColor[
              0.8772092716527284, 0.4732937439467283, 0.21672848084375096`], 
             UndirectedEdge[137, 282] -> 
             RGBColor[
              0.3008030444529849, 0.4311156931304887, 0.9405287217628104], 
             UndirectedEdge[37, 114] -> 
             RGBColor[
              0.2950446149939596, 0.4237378370222073, 0.9402493164383834], 
             UndirectedEdge[214, 248] -> 
             RGBColor[
              0.22887195802400728`, 0.3578893175764699, 0.9363452914725232], 
             UndirectedEdge[161, 363] -> 
             RGBColor[
              0.20967797684249928`, 0.3377152263860093, 0.9352522226391868], 
             UndirectedEdge[51, 84] -> 
             RGBColor[
              0.36020789306278994`, 0.48641570522103605`, 0.9441731063199956],
              UndirectedEdge[56, 278] -> 
             RGBColor[
              0.3199081459581343, 0.44683361246279085`, 0.9417764708138758], 
             UndirectedEdge[4, 140] -> 
             RGBColor[
              0.22925899781803233`, 0.3582961209397305, 0.9363673328162189], 
             UndirectedEdge[221, 351] -> 
             RGBColor[
              0.9060488999462345, 0.7900961921894157, 0.6157268873569864], 
             UndirectedEdge[54, 204] -> 
             RGBColor[
              0.18912347164523904`, 0.31611113819278824`, 0.9340816739758684],
              UndirectedEdge[10, 298] -> 
             RGBColor[
              0.21724932645694042`, 0.3456731948820789, 0.9356833997989213], 
             UndirectedEdge[134, 226] -> 
             RGBColor[
              0.6381042655490734, 0.7140610165668736, 0.9666654902064342], 
             UndirectedEdge[35, 98] -> 
             RGBColor[
              0.21863346925867172`, 0.3471280167264209, 0.9357622246838242], 
             UndirectedEdge[70, 180] -> 
             RGBColor[
              0.24072957206270523`, 0.3703524217472943, 0.9370205650502591], 
             UndirectedEdge[165, 328] -> 
             RGBColor[
              0.8831401501680374, 0.7104796109326978, 0.6014297849392954], 
             UndirectedEdge[162, 214] -> 
             RGBColor[
              0.25603696286442035`, 0.3864414600245297, 0.9378922983111614], 
             UndirectedEdge[211, 370] -> 
             RGBColor[
              0.20448863330117922`, 0.3322608973006979, 0.9349566972014545], 
             UndirectedEdge[55, 245] -> 
             RGBColor[
              0.8952306902685789, 0.5308547871239369, 0.2549792362273595], 
             UndirectedEdge[247, 315] -> 
             RGBColor[
              0.2082369879918481, 0.3362006557400048, 0.9351701604558942], 
             UndirectedEdge[16, 268] -> 
             RGBColor[
              0.49856920010276634`, 0.5995528138290274, 0.9550727772448264], 
             UndirectedEdge[154, 291] -> 
             RGBColor[
              0.1963438417799771, 0.3237002050023056, 0.9344928633734613], 
             UndirectedEdge[296, 373] -> 
             RGBColor[
              0.25840585650162723`, 0.38893131743376574`, 0.9380272032993362],
              UndirectedEdge[101, 394] -> 
             RGBColor[
              0.18176625720560394`, 0.308378239342394, 0.9336626914975545], 
             UndirectedEdge[173, 388] -> 
             RGBColor[
              0.2509970167086373, 0.38114415706375904`, 0.9376052808335218], 
             UndirectedEdge[84, 102] -> 
             RGBColor[
              0.3081546083900806, 0.43843821536979977`, 0.9409621908941581], 
             UndirectedEdge[216, 298] -> 
             RGBColor[
              0.19835416070020614`, 0.3258131776490477, 0.9346073480619681], 
             UndirectedEdge[209, 310] -> 
             RGBColor[
              0.30722079620017617`, 0.4378261141051596, 0.9408954863272463], 
             UndirectedEdge[34, 93] -> 
             RGBColor[
              0.24878417747359188`, 0.37881832272561544`, 0.9374792629126882],
              UndirectedEdge[112, 285] -> 
             RGBColor[
              0.9656534548794817, 0.8891806763774219, 0.4391165147700274], 
             UndirectedEdge[131, 309] -> 
             RGBColor[
              0.255426495168577, 0.38579981977031097`, 0.9378575330789891], 
             UndirectedEdge[116, 265] -> 
             RGBColor[
              0.18666044049465552`, 0.3135223362883303, 0.9339414079955707], 
             UndirectedEdge[49, 129] -> 
             RGBColor[
              0.18838308614561955`, 0.31533294608953616`, 0.9340395101169672],
              UndirectedEdge[238, 325] -> 
             RGBColor[
              0.28956065239162987`, 0.42167698324230746`, 0.9398014228358818],
              UndirectedEdge[112, 399] -> 
             RGBColor[
              0.9318419668775375, 0.7674831415272341, 0.2640166505562497], 
             UndirectedEdge[186, 322] -> 
             RGBColor[
              0.20337835674212623`, 0.3310939262415335, 0.9348934685939234], 
             UndirectedEdge[180, 332] -> 
             RGBColor[
              0.2434440031568898, 0.373205460932154, 0.937175147885432], 
             UndirectedEdge[60, 331] -> 
             RGBColor[
              0.19257622837931382`, 0.31974020443772183`, 0.9342783033639781],
              UndirectedEdge[14, 126] -> 
             RGBColor[
              0.18556762080960376`, 0.31237371351057097`, 0.9338791735311889],
              UndirectedEdge[275, 288] -> 
             RGBColor[
              0.2720607570835225, 0.40328348371603906`, 0.9388048296868601], 
             UndirectedEdge[276, 290] -> 
             RGBColor[
              0.21053718403849497`, 0.33861830762588346`, 0.9353011532179156],
              UndirectedEdge[18, 232] -> 
             RGBColor[
              0.4501165590628717, 0.5589054128143358, 0.9510872394181826], 
             UndirectedEdge[4, 325] -> 
             RGBColor[
              0.26097898271890796`, 0.39163583623375275`, 0.9381737390308114],
              UndirectedEdge[1, 62] -> 
             RGBColor[
              0.19732629313580521`, 0.3247328236682947, 0.9345488125247692], 
             UndirectedEdge[20, 304] -> 
             RGBColor[
              0.185589373288035, 0.312396576744589, 0.9338804123026556], 
             UndirectedEdge[255, 328] -> 
             RGBColor[
              0.8524460760036836, 0.3866301102852666, 0.1971705111408994], 
             UndirectedEdge[3, 74] -> 
             RGBColor[
              0.7224644673916434, 0.782535536200579, 0.9735133143364585], 
             UndirectedEdge[18, 279] -> 
             RGBColor[
              0.638687245246097, 0.7170964540862654, 0.9650118438159424], 
             UndirectedEdge[163, 226] -> 
             RGBColor[
              0.35601753306005335`, 0.4789075435482711, 0.944048117850775], 
             UndirectedEdge[145, 254] -> 
             RGBColor[
              0.19225246823374995`, 0.31939991199715534`, 0.9342598657026484],
              UndirectedEdge[23, 348] -> 
             RGBColor[
              0.3130979265677895, 0.44416079144735543`, 0.9412244155321879], 
             UndirectedEdge[119, 396] -> 
             RGBColor[
              0.19098691356338682`, 0.3180697337978031, 0.9341877942363916], 
             UndirectedEdge[73, 141] -> 
             RGBColor[
              0.898106425922933, 0.622605752165564, 0.23629664332441563`], 
             UndirectedEdge[29, 396] -> 
             RGBColor[
              0.19049809514878532`, 0.31755595465117936`, 0.9341599567508221],
              UndirectedEdge[160, 312] -> 
             RGBColor[
              0.38126624461740655`, 0.5039445125232649, 0.9455819912605958], 
             UndirectedEdge[210, 397] -> 
             RGBColor[
              0.25928855226930214`, 0.38985908665173613`, 0.938077471517474], 
             UndirectedEdge[11, 86] -> 
             RGBColor[
              0.361493667794528, 0.48752937866875046`, 0.9442550347489361], 
             UndirectedEdge[113, 315] -> 
             RGBColor[
              0.26318579596449465`, 0.3939553368749055, 0.9382994137804598], 
             UndirectedEdge[120, 160] -> 
             RGBColor[
              0.48896132780643076`, 0.5959998592268796, 0.9529119733307341], 
             UndirectedEdge[5, 308] -> 
             RGBColor[
              0.24197001296398313`, 0.37165620378303305`, 0.9370912063245189],
              UndirectedEdge[37, 261] -> 
             RGBColor[
              0.30438433219243016`, 0.43355447197007246`, 0.940781199515963], 
             UndirectedEdge[22, 241] -> 
             RGBColor[
              0.28974430117812966`, 0.42117386849154814`, 0.9398373705045929],
              UndirectedEdge[55, 165] -> 
             RGBColor[
              0.9341904345376686, 0.918237850236102, 0.6671537250527897], 
             UndirectedEdge[251, 283] -> 
             RGBColor[
              0.19962713488925782`, 0.32715115423296626`, 0.934679842058838], 
             UndirectedEdge[334, 365] -> 
             RGBColor[
              0.18295572293696874`, 0.30962844324254163`, 0.933730429811299], 
             UndirectedEdge[44, 358] -> 
             RGBColor[
              0.21372519899594036`, 0.3419691134779814, 0.9354827059534967], 
             UndirectedEdge[225, 367] -> 
             RGBColor[
              0.6298962166593582, 0.7051035104774022, 0.9669932656124167], 
             UndirectedEdge[23, 321] -> 
             RGBColor[
              0.42370887427578074`, 0.5372228658179581, 0.9490305036181749], 
             UndirectedEdge[234, 269] -> 
             RGBColor[
              0.7646521215423732, 0.8160713160110501, 0.9771770354611466], 
             UndirectedEdge[21, 208] -> 
             RGBColor[
              0.9781086897296334, 0.9394569243444684, 0.5384830216306559], 
             UndirectedEdge[208, 240] -> 
             RGBColor[
              0.9123520994765446, 0.6179800899391169, 0.47169857312625524`], 
             UndirectedEdge[15, 313] -> 
             RGBColor[
              0.25209641053026927`, 0.3822996896758886, 0.9376678896852563], 
             UndirectedEdge[63, 204] -> 
             RGBColor[
              0.18740799960939158`, 0.3143080683159034, 0.9339839803812403], 
             UndirectedEdge[241, 310] -> 
             RGBColor[
              0.2714061632718937, 0.40259546411637237`, 0.9387675515376726], 
             UndirectedEdge[182, 256] -> 
             RGBColor[
              0.34992025301800456`, 0.4775050684860661, 0.9435175869933449], 
             UndirectedEdge[373, 380] -> 
             RGBColor[
              0.24598769620290184`, 0.37587904360296687`, 0.9373200074413457],
              UndirectedEdge[185, 210] -> 
             RGBColor[
              0.35262704416750634`, 0.4795636552057607, 0.9437005295213796], 
             UndirectedEdge[96, 223] -> 
             RGBColor[
              0.8390506368021915, 0.7815052608012159, 0.618996491222558], 
             UndirectedEdge[103, 222] -> 
             RGBColor[
              0.21336670811641717`, 0.34159231683396796`, 0.9354622904282476],
              UndirectedEdge[146, 375] -> 
             RGBColor[
              0.18336952246536248`, 0.3100633727832889, 0.9337539950822794], 
             UndirectedEdge[42, 276] -> 
             RGBColor[
              0.2196855450649306, 0.3482338151042579, 0.9358221388445839], 
             UndirectedEdge[46, 372] -> 
             RGBColor[
              0.19768089456011895`, 0.32510553224827726`, 0.934569006551298], 
             UndirectedEdge[95, 285] -> 
             RGBColor[
              0.7768044768753901, 0.8215969254274786, 0.7842186264026185], 
             UndirectedEdge[14, 326] -> 
             RGBColor[
              0.18828033718868842`, 0.3152249504211414, 0.9340336587158735], 
             UndirectedEdge[22, 310] -> 
             RGBColor[
              0.2979372274212155, 0.4297851534345578, 0.9403039455337885], 
             UndirectedEdge[23, 229] -> 
             RGBColor[
              0.24996961512608984`, 0.38006429285947896`, 0.9375467718333002],
              UndirectedEdge[23, 160] -> 
             RGBColor[
              0.3763398438622711, 0.4987665529777692, 0.9453014400255476], 
             UndirectedEdge[165, 311] -> 
             RGBColor[
              0.5997467789297788, 0.6780206465223158, 0.965283080943369], 
             UndirectedEdge[179, 288] -> 
             RGBColor[
              0.3796596294696894, 0.502934688841232, 0.9454287055118813], 
             UndirectedEdge[51, 167] -> 
             RGBColor[
              0.3459161722681373, 0.47403693499148125`, 0.9432624505086329], 
             UndirectedEdge[310, 346] -> 
             RGBColor[
              0.31533275535423055`, 0.4448522854054794, 0.9414123731914188], 
             UndirectedEdge[79, 379] -> 
             RGBColor[
              0.21907288200889707`, 0.34758986738728526`, 0.9357872485898966],
              UndirectedEdge[78, 264] -> 
             RGBColor[
              0.7716146222869605, 0.4690073780170669, 0.569890082784954], 
             UndirectedEdge[309, 325] -> 
             RGBColor[
              0.2933678336849298, 0.42567857217080163`, 0.9400182361783151], 
             UndirectedEdge[149, 358] -> 
             RGBColor[
              0.20368965097586314`, 0.3314211162183854, 0.9349111963400162], 
             UndirectedEdge[6, 79] -> 
             RGBColor[
              0.26831622286540857`, 0.39934774083561936`, 0.9385915840026804],
              UndirectedEdge[134, 234] -> 
             RGBColor[
              0.8083454624285121, 0.8502936670726204, 0.9815084195744261], 
             UndirectedEdge[96, 209] -> 
             RGBColor[
              0.5415208134624869, 0.6338317942327045, 0.9590470002598491], 
             UndirectedEdge[216, 393] -> 
             RGBColor[
              0.19153695040893678`, 0.31864785739682644`, 0.9342191180210391],
              UndirectedEdge[164, 388] -> 
             RGBColor[
              0.21023340989613648`, 0.33829902174187165`, 0.935283853729902], 
             UndirectedEdge[155, 261] -> 
             RGBColor[
              0.23352567596023666`, 0.3627806701902061, 0.9366103138244327], 
             UndirectedEdge[125, 288] -> 
             RGBColor[
              0.28344153985750953`, 0.415245407994804, 0.9394529484294792], 
             UndirectedEdge[287, 384] -> 
             RGBColor[
              0.18974513703544627`, 0.3167645479337583, 0.9341170769001692], 
             UndirectedEdge[69, 320] -> 
             RGBColor[
              0.21880446674278364`, 0.34730774592408925`, 0.9357719627375762],
              UndirectedEdge[123, 339] -> 
             RGBColor[
              0.23162280417676506`, 0.3607806312967381, 0.9365019480914105], 
             UndirectedEdge[132, 202] -> 
             RGBColor[
              0.300816385571577, 0.4289283244783967, 0.9406100852285664], 
             UndirectedEdge[67, 249] -> 
             RGBColor[
              0.36714946895537004`, 0.49242814936543994`, 0.9446154173976764],
              UndirectedEdge[374, 384] -> 
             RGBColor[
              0.18988847579037965`, 0.3169152060533953, 0.934125239830212], 
             UndirectedEdge[99, 252] -> 
             RGBColor[
              0.6676015641481373, 0.7342070299092066, 0.9439106644834332], 
             UndirectedEdge[44, 65] -> 
             RGBColor[
              0.2623103948909678, 0.393035234842995, 0.9382495609843622], 
             UndirectedEdge[88, 370] -> 
             RGBColor[
              0.189278561860536, 0.3162741478423529, 0.9340905061341941], 
             UndirectedEdge[13, 275] -> 
             RGBColor[
              0.22645651195099847`, 0.3553505306056112, 0.9362077353919975], 
             UndirectedEdge[183, 269] -> 
             RGBColor[
              0.546784204528102, 0.6385867943130678, 0.9592993736008182], 
             UndirectedEdge[122, 178] -> 
             RGBColor[
              0.5198265338212547, 0.6207419031672892, 0.9554290299990101], 
             UndirectedEdge[199, 216] -> 
             RGBColor[
              0.19310022590756143`, 0.3202909590632723, 0.9343081442480269], 
             UndirectedEdge[107, 295] -> 
             RGBColor[
              0.38882676959428764`, 0.5112039376460608, 0.945996675825904], 
             UndirectedEdge[89, 171] -> 
             RGBColor[
              0.18910388505940673`, 0.3160905514492172, 0.934080558548781], 
             UndirectedEdge[18, 91] -> 
             RGBColor[
              0.5492190587011108, 0.6449197997470224, 0.9576556826381046], 
             UndirectedEdge[194, 357] -> 
             RGBColor[
              0.9258160784332223, 0.7153085367289651, 0.42424837654046466`], 
             UndirectedEdge[147, 388] -> 
             RGBColor[
              0.20149520910929605`, 0.3291146186809729, 0.9347862261221009], 
             UndirectedEdge[96, 323] -> 
             RGBColor[
              0.5734450946307983, 0.6614830020196698, 0.9610811872263605], 
             UndirectedEdge[168, 265] -> 
             RGBColor[
              0.18709388052696674`, 0.31397790924397473`, 0.9339660917641938],
              UndirectedEdge[44, 372] -> 
             RGBColor[
              0.21537145554787535`, 0.3436994334927591, 0.9355764578287111], 
             UndirectedEdge[180, 286] -> 
             RGBColor[
              0.22669434503393948`, 0.3556005082552706, 0.9362212796342286], 
             UndirectedEdge[18, 45] -> 
             RGBColor[
              0.4449748432614876, 0.5535011435034702, 0.9507944263097807], 
             UndirectedEdge[83, 217] -> 
             RGBColor[
              0.9690520396764782, 0.9730561345189551, 0.7324860448307533], 
             UndirectedEdge[137, 314] -> 
             RGBColor[
              0.28356888618805115`, 0.41300150008529746`, 0.9395472619452747],
              UndirectedEdge[205, 338] -> 
             RGBColor[
              0.292109011117009, 0.4205396174018403, 0.9400862651454345], 
             UndirectedEdge[210, 293] -> 
             RGBColor[
              0.3272740253136205, 0.45760414455430376`, 0.9420850575788042], 
             UndirectedEdge[295, 324] -> 
             RGBColor[
              0.5310822445454129, 0.6295361727227928, 0.9564100649680346], 
             UndirectedEdge[270, 346] -> 
             RGBColor[
              0.3550828331693524, 0.4819766359343405, 0.9438465420354984], 
             UndirectedEdge[26, 349] -> 
             RGBColor[
              0.19449252215171758`, 0.32175435069256086`, 0.9343874334594139],
              UndirectedEdge[27, 208] -> 
             RGBColor[
              0.9070267560487368, 0.5770471667726158, 0.46659901824567124`], 
             UndirectedEdge[139, 193] -> 
             RGBColor[
              0.18750230329400064`, 0.31440718746762647`, 0.933989350836569], 
             UndirectedEdge[5, 296] -> 
             RGBColor[
              0.26370004466317304`, 0.39449584486246725`, 0.9383286994830867],
              UndirectedEdge[42, 125] -> 
             RGBColor[
              0.23901293023950498`, 0.3685481223497329, 0.9369228048379719], 
             UndirectedEdge[12, 106] -> 
             RGBColor[
              0.2676474114572338, 0.3986447776405352, 0.9385534961824027], 
             UndirectedEdge[242, 357] -> 
             RGBColor[
              0.854686957719692, 0.4213534977770367, 0.2000015985134489], 
             UndirectedEdge[148, 279] -> 
             RGBColor[
              0.5031062098123048, 0.6037853067748751, 0.9552337277677017], 
             UndirectedEdge[292, 374] -> 
             RGBColor[
              0.19230228893935433`, 0.31945227671756077`, 0.9342627029181295],
              UndirectedEdge[195, 369] -> 
             RGBColor[
              0.19622298384464848`, 0.3235731756494396, 0.9344859806928376], 
             UndirectedEdge[50, 371] -> 
             RGBColor[
              0.1827919087042476, 0.30945626409752947`, 0.9337211008330868], 
             UndirectedEdge[29, 127] -> 
             RGBColor[
              0.18812124438286376`, 0.3150577337951532, 0.9340245986159385], 
             UndirectedEdge[87, 127] -> 
             RGBColor[
              0.19649156208518143`, 0.3238554684090837, 0.93450127582631], 
             UndirectedEdge[264, 357] -> 
             RGBColor[
              0.7901960776192611, 0.6118325861467757, 0.5876837053959174], 
             UndirectedEdge[171, 306] -> 
             RGBColor[
              0.19583756200520352`, 0.3231680728590269, 0.9344640314892618], 
             UndirectedEdge[114, 170] -> 
             RGBColor[
              0.23647751036378017`, 0.3658832353054412, 0.9367784164268669], 
             UndirectedEdge[57, 222] -> 
             RGBColor[
              0.22503342369355192`, 0.35385477461802795`, 0.9361266926210063],
              UndirectedEdge[38, 102] -> 
             RGBColor[
              0.25020060979959846`, 0.3803070829072448, 0.9375599266382304], 
             UndirectedEdge[82, 331] -> 
             RGBColor[
              0.18993705205367367`, 0.31696626278603024`, 0.9341280061765445],
              UndirectedEdge[90, 324] -> 
             RGBColor[
              0.6207541500572831, 0.7029952095291041, 0.9632871870713362], 
             UndirectedEdge[160, 341] -> 
             RGBColor[
              0.3979292657890303, 0.5189168537463054, 0.9466239842803985], 
             UndirectedEdge[15, 311] -> 
             RGBColor[
              0.2942848105043079, 0.4266423729476564, 0.940070456651633], 
             UndirectedEdge[271, 292] -> 
             RGBColor[
              0.18674265418407987`, 0.3136087480885643, 0.9339460899435592], 
             UndirectedEdge[41, 156] -> 
             RGBColor[
              0.8514284367030327, 0.5699234098578776, 0.5824732181712974], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.26166329356975937`, 0.3923550903258115, 0.9382127095214201], 
             UndirectedEdge[129, 317] -> 
             RGBColor[
              0.19222117947628775`, 0.3193670255292408, 0.9342580838541985], 
             UndirectedEdge[164, 354] -> 
             RGBColor[
              0.20840265875823133`, 0.3363747862196069, 0.9351795951609518], 
             UndirectedEdge[78, 230] -> 
             RGBColor[
              0.818837947598831, 0.14580229685169685`, 0.1656725459360465], 
             UndirectedEdge[315, 363] -> 
             RGBColor[
              0.2193734294732247, 0.3479057618281034, 0.9358043643233698], 
             UndirectedEdge[5, 121] -> 
             RGBColor[
              0.2966728547509243, 0.4289526354856623, 0.9402137650898452], 
             UndirectedEdge[43, 380] -> 
             RGBColor[
              0.2402420225431372, 0.36983997628980336`, 0.9369927998263845], 
             UndirectedEdge[135, 234] -> 
             RGBColor[
              0.8902824990453274, 0.9119541401261442, 0.8296334999422285], 
             UndirectedEdge[344, 356] -> 
             RGBColor[
              0.19312061469136133`, 0.3203123889677695, 0.9343093053591018], 
             UndirectedEdge[186, 228] -> 
             RGBColor[
              0.20522346006975262`, 0.3330332468251766, 0.934998544498846], 
             UndirectedEdge[298, 396] -> 
             RGBColor[
              0.19827776691556012`, 0.32573288293773905`, 0.9346029975489469],
              UndirectedEdge[86, 93] -> 
             RGBColor[
              0.32267144519324537`, 0.4470223501983363, 0.9420332704147207], 
             UndirectedEdge[249, 266] -> 
             RGBColor[
              0.270914372535644, 0.40204801259274037`, 0.9387406633049027], 
             UndirectedEdge[156, 364] -> 
             RGBColor[
              0.8243314936689592, 0.18802809923393973`, 0.1709331718568741], 
             UndirectedEdge[10, 311] -> 
             RGBColor[
              0.2701224968687157, 0.40124624933748154`, 0.9386944486350258], 
             UndirectedEdge[27, 73] -> 
             RGBColor[
              0.8758267768621938, 0.46266728317359945`, 0.2154046022710305], 
             UndirectedEdge[56, 213] -> 
             RGBColor[
              0.30213444608884904`, 0.4281523269825127, 0.9407642849001527], 
             UndirectedEdge[27, 243] -> 
             RGBColor[
              0.8952822164694654, 0.5697539750088114, 0.5521239626729255], 
             UndirectedEdge[109, 157] -> 
             RGBColor[
              0.18435836126610156`, 0.3111027050588667, 0.9338103079891256], 
             UndirectedEdge[12, 241] -> 
             RGBColor[
              0.28584467655013013`, 0.4177712570264148, 0.9395898035090018], 
             UndirectedEdge[192, 382] -> 
             RGBColor[
              0.18175632170203998`, 0.30836779649820095`, 0.9336621256853248],
              UndirectedEdge[140, 280] -> 
             RGBColor[
              0.2386176080728396, 0.36813261368769457`, 0.936900291825407], 
             UndirectedEdge[199, 361] -> 
             RGBColor[
              0.2020628988707439, 0.32971129661386445`, 0.9348185552141937], 
             UndirectedEdge[16, 351] -> 
             RGBColor[
              0.6137824648944775, 0.6902841557450048, 0.9663635368138602], 
             UndirectedEdge[140, 322] -> 
             RGBColor[
              0.21280212927241615`, 0.34099890867255667`, 0.9354301384983013],
              UndirectedEdge[57, 238] -> 
             RGBColor[
              0.2538315033751126, 0.3841233822670593, 0.9377667006559303], 
             UndirectedEdge[49, 127] -> 
             RGBColor[
              0.19124100743417377`, 0.3183368025664821, 0.9342022645064347], 
             UndirectedEdge[165, 182] -> 
             RGBColor[
              0.6226406331298818, 0.6984050769847048, 0.9667215385795859], 
             UndirectedEdge[253, 343] -> 
             RGBColor[
              0.18655690968294972`, 0.31341351884099494`, 0.9339355120690042],
              UndirectedEdge[104, 240] -> 
             RGBColor[
              0.825349023280818, 0.19584927771500635`, 0.17190755936232552`], 
             UndirectedEdge[312, 348] -> 
             RGBColor[
              0.31802432732292496`, 0.44933875099285125`, 0.9415049667672362],
              UndirectedEdge[242, 244] -> 
             RGBColor[
              0.9035194245465865, 0.684293372013093, 0.5795724587116564], 
             UndirectedEdge[41, 165] -> 
             RGBColor[
              0.8843102751860701, 0.9105890257431475, 0.9888274975519911], 
             UndirectedEdge[54, 297] -> 
             RGBColor[
              0.19576644813648575`, 0.3230933276741248, 0.9344599816596418], 
             UndirectedEdge[77, 145] -> 
             RGBColor[
              0.19003339190962826`, 0.3170675220829382, 0.934133492588819], 
             UndirectedEdge[69, 150] -> 
             RGBColor[
              0.217681081623926, 0.3461269969374395, 0.9357079876169566], 
             UndirectedEdge[106, 241] -> 
             RGBColor[
              0.24501597193591163`, 0.37485769978748307`, 0.9372646691818778],
              UndirectedEdge[139, 276] -> 
             RGBColor[
              0.20545840173873126`, 0.33328018541543536`, 0.9350119240793292],
              UndirectedEdge[313, 393] -> 
             RGBColor[
              0.200865233126181, 0.3284524739799347, 0.9347503499218286], 
             UndirectedEdge[209, 323] -> 
             RGBColor[
              0.36676678405368435`, 0.4920966869379023, 0.9445910330541359], 
             UndirectedEdge[8, 213] -> 
             RGBColor[
              0.230215374068607, 0.3593013330168411, 0.9364217970288573], 
             UndirectedEdge[160, 244] -> 
             RGBColor[
              0.7071944520529801, 0.7689833903419949, 0.9560284549892878], 
             UndirectedEdge[180, 284] -> 
             RGBColor[
              0.2675710150211928, 0.3985644801424423, 0.9385491455183885], 
             UndirectedEdge[24, 242] -> 
             RGBColor[
              0.8365301385898678, 0.28179222957633193`, 0.182614608009535], 
             UndirectedEdge[81, 192] -> 
             RGBColor[
              0.1805894919591846, 0.3071413844571813, 0.9335956764576392], 
             UndirectedEdge[124, 249] -> 
             RGBColor[
              0.30940302019566135`, 0.4424110778706867, 0.9409358647458874], 
             UndirectedEdge[195, 253] -> 
             RGBColor[
              0.1964706167173933, 0.3238334534995253, 0.9345000830186004], 
             UndirectedEdge[31, 81] -> 
             RGBColor[
              0.1880171511030766, 0.3149483251582018, 0.9340186706576468], 
             UndirectedEdge[172, 399] -> 
             RGBColor[
              0.8751896442741957, 0.46528659439177383`, 0.21510344124823602`],
              UndirectedEdge[124, 315] -> 
             RGBColor[
              0.2642878093777229, 0.3950226791099546, 0.9383655017096588], 
             UndirectedEdge[181, 370] -> 
             RGBColor[
              0.19100569805155482`, 0.318089477485873, 0.9341888639852036], 
             UndirectedEdge[244, 348] -> 
             RGBColor[
              0.6439525347584986, 0.7143776288115813, 0.9519514304959281], 
             UndirectedEdge[284, 367] -> 
             RGBColor[
              0.3258404306471927, 0.4536760993310988, 0.9420920701724073], 
             UndirectedEdge[148, 232] -> 
             RGBColor[
              0.3145355236290795, 0.4455942655029455, 0.9413091233699418], 
             UndirectedEdge[34, 211] -> 
             RGBColor[
              0.2425688344221679, 0.3722856031030586, 0.9371253083206856], 
             UndirectedEdge[355, 392] -> 
             RGBColor[
              0.8783955245201162, 0.9037382421614023, 0.8873541737699352], 
             UndirectedEdge[262, 338] -> 
             RGBColor[
              0.22417589206845978`, 0.35295345450941085`, 0.9360778574635618],
              UndirectedEdge[87, 119] -> 
             RGBColor[
              0.19029746556308325`, 0.3173450802359561, 0.9341485311927212], 
             UndirectedEdge[180, 367] -> 
             RGBColor[
              0.31681274319178854`, 0.44418742742702483`, 0.9415779567270888],
              UndirectedEdge[69, 380] -> 
             RGBColor[
              0.2309702581422837, 0.36009476404068996`, 0.9364647865601021], 
             UndirectedEdge[124, 338] -> 
             RGBColor[
              0.2719649687624893, 0.40309186038336303`, 0.9388027045792817], 
             UndirectedEdge[249, 293] -> 
             RGBColor[
              0.3289853537057845, 0.45937231092045516`, 0.9421836337211749], 
             UndirectedEdge[212, 373] -> 
             RGBColor[
              0.34459378761093823`, 0.4694803712160838, 0.9433030893613046], 
             UndirectedEdge[287, 292] -> 
             RGBColor[
              0.19215895018442095`, 0.31930161859792383`, 0.9342545399880867],
              UndirectedEdge[12, 323] -> 
             RGBColor[
              0.35358359064672407`, 0.4806531148021672, 0.943751925265087], 
             UndirectedEdge[120, 307] -> 
             RGBColor[
              0.43332684059947457`, 0.5479832712777266, 0.9493196875555654], 
             UndirectedEdge[99, 398] -> 
             RGBColor[
              0.695865579228825, 0.7586878991813948, 0.9457116225314874], 
             UndirectedEdge[134, 350] -> 
             RGBColor[
              0.9124093272037948, 0.929890258170909, 0.8676584254872136], 
             UndirectedEdge[45, 280] -> 
             RGBColor[
              0.26817273037966816`, 0.3991969211351571, 0.9385834123178955], 
             UndirectedEdge[188, 330] -> 
             RGBColor[
              0.19385743072413472`, 0.32108682933504906`, 0.9343512659421467],
              UndirectedEdge[236, 284] -> 
             RGBColor[
              0.26368702808225786`, 0.3944821636106265, 0.9383279582080599], 
             UndirectedEdge[374, 389] -> 
             RGBColor[
              0.19643386923101253`, 0.3237948295614139, 0.9344979903036141], 
             UndirectedEdge[278, 319] -> 
             RGBColor[
              0.35576382875700985`, 0.4778888141834562, 0.9440614916187484], 
             UndirectedEdge[78, 242] -> 
             RGBColor[
              0.8361055023873913, 0.2785282896473279, 0.1822079759024856], 
             UndirectedEdge[84, 189] -> 
             RGBColor[
              0.30274052812538393`, 0.4327476737390883, 0.9406538670324976], 
             UndirectedEdge[223, 385] -> 
             RGBColor[
              0.9621637338718393, 0.8751385282482187, 0.44853214930663265`], 
             UndirectedEdge[175, 278] -> 
             RGBColor[
              0.2699086210585896, 0.40102145230052944`, 0.93868226872404], 
             UndirectedEdge[151, 168] -> 
             RGBColor[
              0.18811217327033666`, 0.31504819948074547`, 0.9340240820294996],
              UndirectedEdge[322, 339] -> 
             RGBColor[
              0.22572644107219014`, 0.3545831798228164, 0.9361661589354925], 
             UndirectedEdge[177, 367] -> 
             RGBColor[
              0.6349673392184779, 0.7091470859540894, 0.9674769538091501], 
             UndirectedEdge[294, 320] -> 
             RGBColor[
              0.19287620932606772`, 0.32005550343265077`, 0.9342953868351136],
              UndirectedEdge[179, 279] -> 
             RGBColor[
              0.5630911384213583, 0.6557241290001397, 0.9590606413690353], 
             UndirectedEdge[18, 285] -> 
             RGBColor[
              0.7996696633612428, 0.8401599138816065, 0.7860186576407228], 
             UndirectedEdge[121, 296] -> 
             RGBColor[
              0.27793336964590865`, 0.4092562484883108, 0.9391465791356984], 
             UndirectedEdge[212, 351] -> 
             RGBColor[
              0.6635629227613954, 0.7334014863107667, 0.9695355035700097], 
             UndirectedEdge[29, 87] -> 
             RGBColor[
              0.18980864714848175`, 0.31683130108933233`, 0.9341206937071518],
              UndirectedEdge[99, 141] -> 
             RGBColor[
              0.9156172249259522, 0.7282421342221813, 0.5763077730258106], 
             UndirectedEdge[121, 274] -> 
             RGBColor[
              0.4019923332344326, 0.5215276967163304, 0.9471338679528571], 
             UndirectedEdge[138, 218] -> 
             RGBColor[
              0.18655648275495362`, 0.3134130701126022, 0.9339354877560864], 
             UndirectedEdge[61, 388] -> 
             RGBColor[
              0.2144393921406435, 0.3427197757555252, 0.9355233781965335], 
             UndirectedEdge[283, 347] -> 
             RGBColor[
              0.20341579469893528`, 0.33113327590784336`, 0.9348956006301792],
              UndirectedEdge[253, 315] -> 
             RGBColor[
              0.20496946088804507`, 0.3327662775807237, 0.9349840796212059], 
             UndirectedEdge[321, 366] -> 
             RGBColor[
              0.4743804722974104, 0.5825626858071993, 0.9522061384174323], 
             UndirectedEdge[164, 391] -> 
             RGBColor[
              0.1910397493801938, 0.3181252675912516, 0.9341908031579952], 
             UndirectedEdge[74, 91] -> 
             RGBColor[
              0.6781789401773193, 0.7465825501677249, 0.9700269954109155], 
             UndirectedEdge[91, 285] -> 
             RGBColor[
              0.7437484336984672, 0.7947605404186777, 0.7816163335954551], 
             UndirectedEdge[51, 183] -> 
             RGBColor[
              0.36578243486715545`, 0.4912440931473596, 0.9445283111943961], 
             UndirectedEdge[30, 54] -> 
             RGBColor[
              0.1824115228296057, 0.3090564544254234, 0.9336994384202565], 
             UndirectedEdge[68, 250] -> 
             RGBColor[
              0.2641868760172087, 0.3950075354824494, 0.9383564238084967], 
             UndirectedEdge[32, 230] -> 
             RGBColor[
              0.8873852814687854, 0.5020359351465393, 0.22609917901526383`], 
             UndirectedEdge[275, 318] -> 
             RGBColor[
              0.21657038683237403`, 0.3449595862894012, 0.9356447351917034], 
             UndirectedEdge[131, 186] -> 
             RGBColor[
              0.21005402739966472`, 0.3381104793645726, 0.9352736381621005], 
             UndirectedEdge[192, 292] -> 
             RGBColor[
              0.18800332047098128`, 0.31493378828695684`, 0.9340178830236096],
              UndirectedEdge[144, 200] -> 
             RGBColor[
              0.18738223875410484`, 0.31428099202366444`, 0.9339825133386415],
              UndirectedEdge[139, 318] -> 
             RGBColor[
              0.19122506102961745`, 0.318320041884233, 0.9342013563822857], 
             UndirectedEdge[93, 148] -> 
             RGBColor[
              0.2841492261294814, 0.41365634022833114`, 0.9395786686798384], 
             UndirectedEdge[92, 311] -> 
             RGBColor[
              0.40006723340595274`, 0.5191882673765618, 0.947063870354397], 
             UndirectedEdge[334, 370] -> 
             RGBColor[
              0.18603433510834283`, 0.3128642598299414, 0.93390575222006], 
             UndirectedEdge[62, 129] -> 
             RGBColor[
              0.19509705711799047`, 0.3223897552718444, 0.9344218608314138], 
             UndirectedEdge[97, 191] -> 
             RGBColor[
              0.2000566789628183, 0.32760263228894565`, 0.9347043039583738], 
             UndirectedEdge[120, 366] -> 
             RGBColor[
              0.4563492884558704, 0.567924158469062, 0.9507866575750236], 
             UndirectedEdge[91, 288] -> 
             RGBColor[
              0.3993345066316525, 0.518907640464429, 0.9469775839135208], 
             UndirectedEdge[21, 32] -> 
             RGBColor[
              0.9601171751337108, 0.8771280081727125, 0.29956318594431774`], 
             UndirectedEdge[121, 178] -> 
             RGBColor[
              0.376298213208635, 0.5003523318083618, 0.9451983672915776], 
             UndirectedEdge[294, 381] -> 
             RGBColor[
              0.19306159004241835`, 0.32025035031935156`, 0.9343059439926636],
              UndirectedEdge[46, 149] -> 
             RGBColor[
              0.20894845482391827`, 0.3369484524901131, 0.9352106774394597], 
             UndirectedEdge[66, 232] -> 
             RGBColor[
              0.25468181299552817`, 0.38501711159085983`, 0.9378151245308926],
              UndirectedEdge[114, 261] -> 
             RGBColor[
              0.25063032461803525`, 0.380758740426915, 0.9375843982614342], 
             UndirectedEdge[189, 395] -> 
             RGBColor[
              0.3676410779096787, 0.4885452690238077, 0.9449042144225828], 
             UndirectedEdge[54, 290] -> 
             RGBColor[
              0.19141480754021284`, 0.3185194774974923, 0.9342121621653594], 
             UndirectedEdge[4, 309] -> 
             RGBColor[
              0.2652076930566547, 0.39608047891444564`, 0.9384145578287296], 
             UndirectedEdge[195, 315] -> 
             RGBColor[
              0.21034714004508412`, 0.3384185593393235, 0.9352903304936357], 
             UndirectedEdge[181, 305] -> 
             RGBColor[
              0.18857843384879308`, 0.3155382689113313, 0.9340506348796719], 
             UndirectedEdge[153, 372] -> 
             RGBColor[
              0.18825648302408265`, 0.31519987818169937`, 0.9340323002564883],
              UndirectedEdge[175, 227] -> 
             RGBColor[
              0.24456047357150879`, 0.37437894212623135`, 0.9372387292238745],
              UndirectedEdge[271, 287] -> 
             RGBColor[
              0.18451611233351262`, 0.31126851143271117`, 0.9338192916790429],
              UndirectedEdge[232, 297] -> 
             RGBColor[
              0.25100667694524614`, 0.38115431058492943`, 0.9376058309697055],
              UndirectedEdge[21, 25] -> 
             RGBColor[
              0.890260551987202, 0.5108305987640545, 0.23788277597524127`], 
             UndirectedEdge[123, 297] -> 
             RGBColor[
              0.20930917766859286`, 0.3373275950710155, 0.9352312200718224], 
             UndirectedEdge[6, 178] -> 
             RGBColor[
              0.37363938184973156`, 0.4977574548464476, 0.9450396379279142], 
             UndirectedEdge[90, 319] -> 
             RGBColor[
              0.530870221387825, 0.6300233870103961, 0.956211194950797], 
             UndirectedEdge[258, 302] -> 
             RGBColor[
              0.18739149065206478`, 0.3142907163550246, 0.9339830402205433], 
             UndirectedEdge[253, 397] -> 
             RGBColor[
              0.20200814651583682`, 0.3296537484173573, 0.9348154371485806], 
             UndirectedEdge[169, 177] -> 
             RGBColor[
              0.8953206105495907, 0.9193683682944271, 0.9898776731680061], 
             UndirectedEdge[198, 332] -> 
             RGBColor[
              0.29082644977848415`, 0.41888733476416706`, 0.9400243645014585],
              UndirectedEdge[45, 123] -> 
             RGBColor[
              0.24825361468381962`, 0.37826066759394095`, 0.9374490481467079],
              UndirectedEdge[223, 245] -> 
             RGBColor[
              0.8743661025414482, 0.452767023574467, 0.2140604082418407], 
             UndirectedEdge[380, 381] -> 
             RGBColor[
              0.20814382827755723`, 0.3361027389736181, 0.9351648551479828], 
             UndirectedEdge[277, 378] -> 
             RGBColor[
              0.19931695292516527`, 0.3268251333220326, 0.934662177654856], 
             UndirectedEdge[119, 326] -> 
             RGBColor[
              0.18721381086797456`, 0.3141039636363968, 0.933972921619693], 
             UndirectedEdge[89, 133] -> 
             RGBColor[
              0.1875161010871107, 0.31442168982301577`, 0.9339901366004746], 
             UndirectedEdge[22, 346] -> 
             RGBColor[
              0.3336708932604665, 0.46343068978065516`, 0.9424821921583393], 
             UndirectedEdge[73, 243] -> 
             RGBColor[
              0.9500707567190481, 0.8697065757980069, 0.5997490197634427], 
             UndirectedEdge[26, 353] -> 
             RGBColor[
              0.1885101327336185, 0.315466480108742, 0.9340467452322052], 
             UndirectedEdge[21, 230] -> 
             RGBColor[
              0.8904702103094787, 0.5124421245019355, 0.2380835450214286], 
             UndirectedEdge[107, 390] -> 
             RGBColor[
              0.30566480118721207`, 0.43491696287761505`, 0.9408535111759078],
              UndirectedEdge[223, 364] -> 
             RGBColor[
              0.8737896349062411, 0.4483360407205369, 0.2135083821833393], 
             UndirectedEdge[2, 211] -> 
             RGBColor[
              0.2034376502421772, 0.3311562474695121, 0.9348968452710344], 
             UndirectedEdge[128, 353] -> 
             RGBColor[
              0.19231632365158768`, 0.3194670280899702, 0.9342635021742287], 
             UndirectedEdge[259, 331] -> 
             RGBColor[
              0.19269223822101744`, 0.31986213813680114`, 0.934284909952842], 
             UndirectedEdge[2, 334] -> 
             RGBColor[
              0.18498335204934083`, 0.3117596099987556, 0.93384590028964], 
             UndirectedEdge[72, 191] -> 
             RGBColor[
              0.19501894918374685`, 0.32230765888062524`, 0.934417412700109], 
             UndirectedEdge[247, 301] -> 
             RGBColor[
              0.1901623548072361, 0.317203070265044, 0.9341408368350541], 
             UndirectedEdge[247, 397] -> 
             RGBColor[
              0.20527567361963986`, 0.3330881265766384, 0.935001517983269], 
             UndirectedEdge[125, 263] -> 
             RGBColor[
              0.326732269165051, 0.4530536866427142, 0.9421999706648885], 
             UndirectedEdge[123, 325] -> 
             RGBColor[
              0.2504184772778667, 0.38053607544050067`, 0.9375723338688118], 
             UndirectedEdge[129, 393] -> 
             RGBColor[
              0.18622578456981498`, 0.3130654853525456, 0.9339166549836668], 
             UndirectedEdge[19, 205] -> 
             RGBColor[
              0.30521095643223367`, 0.4343105926394541, 0.9408324015485454], 
             UndirectedEdge[277, 352] -> 
             RGBColor[
              0.22370886564436498`, 0.3524625801265016, 0.9360512609996132], 
             UndirectedEdge[139, 224] -> 
             RGBColor[
              0.18369701044953324`, 0.3104075834185898, 0.9337726450385029], 
             UndirectedEdge[65, 250] -> 
             RGBColor[
              0.2731468584894696, 0.40442504515649597`, 0.9388666815551856], 
             UndirectedEdge[58, 117] -> 
             RGBColor[
              0.2190498578943207, 0.34756566758305235`, 0.9357859374006325], 
             UndirectedEdge[134, 272] -> 
             RGBColor[0.7859507335711424, 0.832798734683, 0.9792763222925633],
              UndirectedEdge[74, 95] -> 
             RGBColor[
              0.7112349833542422, 0.7734189351765257, 0.9726292882180788], 
             UndirectedEdge[156, 245] -> 
             RGBColor[
              0.8249079613041663, 0.19245908208786985`, 0.17148519791537548`],
              UndirectedEdge[221, 324] -> 
             RGBColor[
              0.7677190036317167, 0.6811645798747406, 0.602228741750033], 
             UndirectedEdge[227, 375] -> 
             RGBColor[
              0.1940331226429612, 0.32127149268124666`, 0.9343612713370109], 
             UndirectedEdge[132, 348] -> 
             RGBColor[
              0.34570653122762846`, 0.47385535445905747`, 0.94324909236691], 
             UndirectedEdge[137, 319] -> 
             RGBColor[
              0.3939126281591366, 0.5156078641515458, 0.9463210706392715], 
             UndirectedEdge[128, 170] -> 
             RGBColor[
              0.21313809335858236`, 0.34135202822847077`, 0.9354492711559941],
              UndirectedEdge[120, 220] -> 
             RGBColor[
              0.5770608462863022, 0.6675230171669182, 0.9598474901446392], 
             UndirectedEdge[292, 371] -> 
             RGBColor[
              0.1904665323376698, 0.31752278013549917`, 0.934158159295422], 
             UndirectedEdge[143, 378] -> 
             RGBColor[
              0.18793083673403851`, 0.31485760328369566`, 0.9340137551820207],
              UndirectedEdge[59, 373] -> 
             RGBColor[
              0.3091816453180559, 0.4388081534280127, 0.9410466589681301], 
             UndirectedEdge[2, 340] -> 
             RGBColor[
              0.19396024281710603`, 0.32119489136342505`, 0.9343571209387445],
              UndirectedEdge[131, 322] -> 
             RGBColor[
              0.206580775656939, 0.33445987156608825`, 0.9350758416135677], 
             UndirectedEdge[62, 317] -> 
             RGBColor[
              0.19822991985182326`, 0.32568259264007254`, 0.9346002727294505],
              UndirectedEdge[243, 337] -> 
             RGBColor[
              0.981786507894951, 0.983234170680865, 0.764939800713467], 
             UndirectedEdge[21, 217] -> 
             RGBColor[
              0.9781358461419554, 0.9375595363156388, 0.3992965964312667], 
             UndirectedEdge[24, 74] -> 
             RGBColor[
              0.8419234511371824, 0.5272135480684979, 0.5771697251114055], 
             UndirectedEdge[1, 127] -> 
             RGBColor[
              0.19417547404882396`, 0.3214211130344089, 0.9343693780389848], 
             UndirectedEdge[226, 355] -> 
             RGBColor[
              0.6054737407452027, 0.6884810215092875, 0.963436744212341], 
             UndirectedEdge[97, 370] -> 
             RGBColor[
              0.18998864922989284`, 0.31702049468968657`, 0.9341309445593988],
              UndirectedEdge[148, 257] -> 
             RGBColor[
              0.3285413065471964, 0.4589876995901452, 0.9421553394288851], 
             UndirectedEdge[48, 344] -> 
             RGBColor[
              0.21571874970997718`, 0.3440644616768498, 0.9355962357174672], 
             UndirectedEdge[74, 148] -> 
             RGBColor[
              0.5985191344063026, 0.6786707763192633, 0.9646512034079422], 
             UndirectedEdge[266, 293] -> 
             RGBColor[
              0.2908233203898157, 0.4192921425712095, 0.940009243857379], 
             UndirectedEdge[84, 226] -> 
             RGBColor[
              0.39203908397867687`, 0.5139862829102032, 0.9462013616579391], 
             UndirectedEdge[354, 371] -> 
             RGBColor[
              0.20120013846367035`, 0.3288044807238608, 0.9347694222853504], 
             UndirectedEdge[57, 188] -> 
             RGBColor[
              0.20973271485913975`, 0.33777275951208907`, 0.9352553398882568],
              UndirectedEdge[134, 355] -> 
             RGBColor[
              0.7983376603764013, 0.8424754960473988, 0.9805109353940992], 
             UndirectedEdge[151, 378] -> 
             RGBColor[
              0.19141895458300517`, 0.3185238363024048, 0.9342123983333115], 
             UndirectedEdge[167, 238] -> 
             RGBColor[
              0.3001182809431252, 0.43263426016352036`, 0.9404077704799216], 
             UndirectedEdge[41, 311] -> 
             RGBColor[
              0.5873075100595555, 0.6681019111801583, 0.9640966123738608], 
             UndirectedEdge[212, 295] -> 
             RGBColor[
              0.42318563987531466`, 0.5409638641564534, 0.9481859926578549], 
             UndirectedEdge[179, 285] -> 
             RGBColor[
              0.7240735565365042, 0.7787875887954807, 0.7800674551938157], 
             UndirectedEdge[85, 348] -> 
             RGBColor[
              0.28694246093137055`, 0.4166697387111759, 0.9397349004577378], 
             UndirectedEdge[108, 152] -> 
             RGBColor[
              0.2564614085339687, 0.38688757933463486`, 0.9379164698641311], 
             UndirectedEdge[86, 148] -> 
             RGBColor[
              0.37250043656006593`, 0.49706288855717573`, 0.9449563763217728],
              UndirectedEdge[113, 293] -> 
             RGBColor[
              0.32820995463660485`, 0.4585878656141067, 0.9421383573691648], 
             UndirectedEdge[229, 260] -> 
             RGBColor[
              0.21573241152320438`, 0.34407882110876054`, 0.9355970137375196],
              UndirectedEdge[6, 278] -> 
             RGBColor[
              0.28187720037590647`, 0.4136011880147874, 0.9393638616102349], 
             UndirectedEdge[142, 378] -> 
             RGBColor[
              0.18665371404405717`, 0.3135152663622699, 0.93394102493416], 
             UndirectedEdge[289, 303] -> 
             RGBColor[
              0.19970158242580874`, 0.32722940331412775`, 0.9346840817359092],
              UndirectedEdge[5, 213] -> 
             RGBColor[
              0.25252900688278906`, 0.3827543758705798, 0.9376925254075633], 
             UndirectedEdge[104, 243] -> 
             RGBColor[
              0.8942676597098645, 0.5619556471729128, 0.5511524219741538], 
             UndirectedEdge[121, 373] -> 
             RGBColor[
              0.2913786665893785, 0.4233881080569608, 0.9399122689060947], 
             UndirectedEdge[120, 202] -> 
             RGBColor[
              0.38082926485589774`, 0.49646706771580507`, 0.9461959416990309],
              UndirectedEdge[270, 351] -> 
             RGBColor[
              0.6344443344456173, 0.7081804286544429, 0.9676800928710849], 
             UndirectedEdge[91, 125] -> 
             RGBColor[
              0.37740486226419223`, 0.49585819381446866`, 0.9457287231087954],
              UndirectedEdge[280, 297] -> 
             RGBColor[
              0.22922829336444137`, 0.3582638486122316, 0.9363655842430101], 
             UndirectedEdge[33, 281] -> 
             RGBColor[
              0.3526148324525338, 0.4768614731328931, 0.9437983042422098], 
             UndirectedEdge[16, 241] -> 
             RGBColor[
              0.29049437153587576`, 0.42182354173579545`, 0.9398851643245274],
              UndirectedEdge[89, 342] -> 
             RGBColor[
              0.18647972709604152`, 0.31333239504849575`, 0.9339311166348612],
              UndirectedEdge[157, 370] -> 
             RGBColor[
              0.18724094908895864`, 0.3141324876273136, 0.9339744671012307], 
             UndirectedEdge[90, 122] -> 
             RGBColor[
              0.6031707449782447, 0.6887202091625689, 0.9619029570133792], 
             UndirectedEdge[135, 156] -> 
             RGBColor[
              0.9129140627520606, 0.6152764832633987, 0.4286476247419544], 
             UndirectedEdge[12, 22] -> 
             RGBColor[
              0.3123757406994519, 0.44496094634460026`, 0.9411261975051177], 
             UndirectedEdge[271, 384] -> 
             RGBColor[
              0.18432884103510522`, 0.31107167742439884`, 0.9338086268556416],
              UndirectedEdge[158, 324] -> 
             RGBColor[
              0.4859428845919035, 0.5904387279012617, 0.9535338248669657], 
             UndirectedEdge[301, 397] -> 
             RGBColor[
              0.19781003665891564`, 0.3252412687821946, 0.934576361002776], 
             UndirectedEdge[95, 233] -> 
             RGBColor[
              0.7594081345567827, 0.8112195509449376, 0.9560282891124947], 
             UndirectedEdge[123, 203] -> 
             RGBColor[
              0.21872743662810462`, 0.3472267823895703, 0.935767575986501], 
             UndirectedEdge[103, 145] -> 
             RGBColor[
              0.1958024601948291, 0.32313117863074003`, 0.9344620324930895], 
             UndirectedEdge[20, 80] -> 
             RGBColor[
              0.18504810846190303`, 0.31182767309415216`, 0.933849588071537], 
             UndirectedEdge[73, 337] -> 
             RGBColor[
              0.9623310682876794, 0.8761474788456531, 0.428220440311572], 
             UndirectedEdge[122, 166] -> 
             RGBColor[
              0.7938288566186125, 0.8372493846021647, 0.890969402038376], 
             UndirectedEdge[62, 216] -> 
             RGBColor[
              0.2004082229571123, 0.32797212731612524`, 0.934724323868786], 
             UndirectedEdge[128, 342] -> 
             RGBColor[
              0.18916310762939384`, 0.3161527981252015, 0.9340839311865298], 
             UndirectedEdge[280, 309] -> 
             RGBColor[
              0.27456630331146203`, 0.4059169716624097, 0.9389475168379178], 
             UndirectedEdge[104, 141] -> 
             RGBColor[
              0.8423033289137494, 0.3148548235404699, 0.18770004553512668`], 
             UndirectedEdge[148, 276] -> 
             RGBColor[
              0.27841767131860123`, 0.407632112720532, 0.9392522651124343], 
             UndirectedEdge[359, 394] -> 
             RGBColor[
              0.18381809529055626`, 0.3105348512637273, 0.9337795406410702], 
             UndirectedEdge[8, 43] -> 
             RGBColor[
              0.24908603513269617`, 0.379135594264215, 0.9374964532598158], 
             UndirectedEdge[56, 352] -> 
             RGBColor[
              0.31062641380180694`, 0.4370779234706822, 0.9412478898986653], 
             UndirectedEdge[70, 152] -> 
             RGBColor[
              0.2398425593336916, 0.3694201151292457, 0.9369700509875596], 
             UndirectedEdge[359, 397] -> 
             RGBColor[
              0.20006364261390616`, 0.32760995152775996`, 0.9347047005280014],
              UndirectedEdge[118, 241] -> 
             RGBColor[
              0.25104726308957875`, 0.38119696919593304`, 0.9376081422905835],
              UndirectedEdge[43, 227] -> 
             RGBColor[
              0.23391469744368304`, 0.36318955643469497`, 0.9366324680224093],
              UndirectedEdge[234, 246] -> 
             RGBColor[
              0.8529840469746812, 0.885887262707637, 0.9857660876177745], 
             UndirectedEdge[196, 317] -> 
             RGBColor[
              0.1925447584771704, 0.3197071275752621, 0.9342765111996065], 
             UndirectedEdge[46, 184] -> 
             RGBColor[
              0.19220194755564052`, 0.3193468115612663, 0.9342569886247687], 
             UndirectedEdge[136, 331] -> 
             RGBColor[
              0.19186850922797938`, 0.3189963467376835, 0.9342379998052863], 
             UndirectedEdge[106, 320] -> 
             RGBColor[
              0.21130568150236095`, 0.33942604718596003`, 0.9353449180115927],
              UndirectedEdge[68, 161] -> 
             RGBColor[
              0.23474066997997348`, 0.36405770594001974`, 0.9366795059364341],
              UndirectedEdge[45, 297] -> 
             RGBColor[
              0.2458649611438621, 0.37575004127406386`, 0.9373130178613036], 
             UndirectedEdge[140, 203] -> 
             RGBColor[
              0.22572809779654535`, 0.3545849211451561, 0.9361662532834936], 
             UndirectedEdge[225, 243] -> 
             RGBColor[
              0.9271182354136238, 0.9438506209861709, 0.9626670150045318], 
             UndirectedEdge[107, 373] -> 
             RGBColor[
              0.31023491732991126`, 0.43972044470569116`, 0.9411137725293536],
              UndirectedEdge[187, 321] -> 
             RGBColor[
              0.494640933100008, 0.6001112786340405, 0.9534971170641517], 
             UndirectedEdge[297, 322] -> 
             RGBColor[
              0.2034128145640179, 0.33113014359709375`, 0.9348954309159043], 
             UndirectedEdge[106, 374] -> 
             RGBColor[
              0.2085188963433679, 0.336496959291474, 0.9351862147194673], 
             UndirectedEdge[154, 383] -> 
             RGBColor[
              0.20693321063768522`, 0.33483030307652095`, 0.9350959122643404],
              UndirectedEdge[111, 151] -> 
             RGBColor[
              0.1906348725141942, 0.31769971633440997`, 0.9341677460194382], 
             UndirectedEdge[79, 227] -> 
             RGBColor[
              0.21925675873838124`, 0.34778313348843115`, 0.9357977200976195],
              UndirectedEdge[93, 290] -> 
             RGBColor[
              0.21626873884937514`, 0.3446425351336826, 0.9356275567853198], 
             UndirectedEdge[150, 283] -> 
             RGBColor[
              0.2012631111576979, 0.32887066901798323`, 0.9347730084871156], 
             UndirectedEdge[46, 195] -> 
             RGBColor[
              0.2015708688653357, 0.3291941418816762, 0.9347905348332788], 
             UndirectedEdge[73, 177] -> 
             RGBColor[
              0.912733918365472, 0.8408075046276462, 0.6264313427993702], 
             UndirectedEdge[102, 189] -> 
             RGBColor[
              0.27205731447598563`, 0.4032798653172439, 0.9388046336354536], 
             UndirectedEdge[3, 95] -> 
             RGBColor[
              0.5706393994295823, 0.6623097973257487, 0.9593419703255434], 
             UndirectedEdge[39, 294] -> 
             RGBColor[
              0.18656769797512113`, 0.31342485802008435`, 0.9339361264462835],
              UndirectedEdge[5, 227] -> 
             RGBColor[
              0.24495455926499354`, 0.3747931511765599, 0.937261171821121], 
             UndirectedEdge[166, 169] -> 
             RGBColor[
              0.9427417968791698, 0.9548740993356628, 0.9051840770091248], 
             UndirectedEdge[27, 337] -> 
             RGBColor[
              0.9075425280380967, 0.5761948780564576, 0.3805953832210548], 
             UndirectedEdge[84, 174] -> 
             RGBColor[
              0.3414171398675645, 0.4701400992540484, 0.9429757761424066], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.313125811057198, 0.4456106195888476, 0.9411739913250522], 
             UndirectedEdge[138, 349] -> 
             RGBColor[
              0.19211902352341417`, 0.31925965314570914`, 0.9342522662238085],
              UndirectedEdge[26, 159] -> 
             RGBColor[
              0.18375580691440718`, 0.3104693822310835, 0.9337759934101959], 
             UndirectedEdge[81, 287] -> 
             RGBColor[
              0.1847451216726243, 0.31150921476814825`, 0.9338323334221164], 
             UndirectedEdge[311, 361] -> 
             RGBColor[
              0.2601900040751639, 0.39080656965504246`, 0.9381288078642394], 
             UndirectedEdge[231, 393] -> 
             RGBColor[
              0.18277810360197083`, 0.30944175405974256`, 0.933720314652935], 
             UndirectedEdge[201, 223] -> 
             RGBColor[
              0.9394729571932308, 0.8606549580209606, 0.6167978110210142], 
             UndirectedEdge[180, 267] -> 
             RGBColor[
              0.25726504669656514`, 0.3877322539971262, 0.9379622358686148], 
             UndirectedEdge[217, 264] -> 
             RGBColor[
              0.8581806271651595, 0.8856725444548357, 0.7300501263511203], 
             UndirectedEdge[163, 174] -> 
             RGBColor[
              0.3053955889489409, 0.4350613598921163, 0.9408225323352425], 
             UndirectedEdge[203, 280] -> 
             RGBColor[
              0.23864655232395315`, 0.36816303593078636`, 0.9369019401576887],
              UndirectedEdge[40, 163] -> 
             RGBColor[
              0.3939273213258807, 0.5099037447255685, 0.9469719144794696], 
             UndirectedEdge[14, 62] -> 
             RGBColor[
              0.1928274082051604, 0.3200042103604074, 0.9342926076834728], 
             UndirectedEdge[49, 133] -> 
             RGBColor[
              0.18673252269027052`, 0.31359809924619686`, 0.933945512969975], 
             UndirectedEdge[276, 288] -> 
             RGBColor[
              0.2641141546829352, 0.39493110074932897`, 0.9383522824360913], 
             UndirectedEdge[312, 366] -> 
             RGBColor[
              0.3486542052668462, 0.4758688117654473, 0.9434566755048852], 
             UndirectedEdge[23, 120] -> 
             RGBColor[
              0.40567769043424073`, 0.5225843384798207, 0.9476110227757661], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.18052420551329257`, 0.307072764263149, 0.9335919584911282], 
             UndirectedEdge[73, 399] -> 
             RGBColor[
              0.9285956897332439, 0.7546127344078406, 0.2614046197660328], 
             UndirectedEdge[269, 272] -> 
             RGBColor[
              0.7422573926850033, 0.7985763836214297, 0.9749449381792838], 
             UndirectedEdge[20, 151] -> 
             RGBColor[
              0.19115376674236922`, 0.3182451070680162, 0.9341972962780976], 
             UndirectedEdge[239, 355] -> 
             RGBColor[
              0.7967350259379453, 0.5156495091253714, 0.57575064772341], 
             UndirectedEdge[274, 319] -> 
             RGBColor[
              0.47322013025663245`, 0.583220445923085, 0.9516727685977074], 
             UndirectedEdge[6, 352] -> 
             RGBColor[
              0.27259546821957914`, 0.40384549902267874`, 0.9388352806950242],
              UndirectedEdge[133, 342] -> 
             RGBColor[
              0.18475081584068775`, 0.311515199699814, 0.9338326576965637], 
             UndirectedEdge[290, 318] -> 
             RGBColor[
              0.1963038433293812, 0.3236581640946811, 0.9344905855208723], 
             UndirectedEdge[87, 298] -> 
             RGBColor[
              0.19758831891525655`, 0.325008229375892, 0.9345637345052766], 
             UndirectedEdge[86, 263] -> 
             RGBColor[
              0.4014876492319413, 0.5221701552338829, 0.9468034158808389], 
             UndirectedEdge[109, 191] -> 
             RGBColor[
              0.19427315985261398`, 0.3215237870078299, 0.9343749411009974], 
             UndirectedEdge[84, 238] -> 
             RGBColor[
              0.3144100017377778, 0.44501303039307516`, 0.9413184262912844], 
             UndirectedEdge[21, 244] -> 
             RGBColor[
              0.9589837634229517, 0.9266594522436353, 0.6365010356742713], 
             UndirectedEdge[137, 175] -> 
             RGBColor[
              0.3080574204607164, 0.43874050226861905`, 0.940941847744563], 
             UndirectedEdge[363, 369] -> 
             RGBColor[
              0.20524927327278905`, 0.33306037813821954`, 0.9350000145225716],
              UndirectedEdge[98, 290] -> 
             RGBColor[
              0.19961632362064485`, 0.32713979090418005`, 0.9346792263730843],
              UndirectedEdge[175, 352] -> 
             RGBColor[
              0.2606268889022622, 0.3912657633084208, 0.9381536878088295], 
             UndirectedEdge[121, 319] -> 
             RGBColor[
              0.3821339767558598, 0.5054057883182604, 0.9455705453873072], 
             UndirectedEdge[249, 387] -> 
             RGBColor[
              0.4216012233503626, 0.5373973944320252, 0.9486912790769737], 
             UndirectedEdge[310, 389] -> 
             RGBColor[
              0.24112387106664201`, 0.3707668550004327, 0.9370430197952202], 
             UndirectedEdge[228, 238] -> 
             RGBColor[
              0.24678874654536498`, 0.3767209983024208, 0.9373656260733012], 
             UndirectedEdge[268, 324] -> 
             RGBColor[
              0.6562462626397825, 0.7312424529611288, 0.9664688163111557], 
             UndirectedEdge[144, 368] -> 
             RGBColor[
              0.18786109875542928`, 0.31478430424653414`, 0.934009783707307], 
             UndirectedEdge[137, 278] -> 
             RGBColor[
              0.29631468313808673`, 0.42639814080998684`, 0.9402731162258624],
              UndirectedEdge[127, 298] -> 
             RGBColor[
              0.19590091614963856`, 0.32323466208171286`, 0.9344676394140633],
              UndirectedEdge[131, 228] -> 
             RGBColor[
              0.20842587898456535`, 0.33639919214973135`, 0.9351809175184903],
              UndirectedEdge[278, 314] -> 
             RGBColor[
              0.2454200867859244, 0.3752824501172079, 0.9372876829247517], 
             UndirectedEdge[182, 311] -> 
             RGBColor[
              0.32563786800336725`, 0.45591796242171545`, 0.9419906534014555],
              UndirectedEdge[77, 94] -> 
             RGBColor[
              0.18199794707454847`, 0.3086217600846408, 0.9336758858928365], 
             UndirectedEdge[144, 333] -> 
             RGBColor[
              0.1893313874669234, 0.316329670904003, 0.9340935144743294], 
             UndirectedEdge[166, 197] -> 
             RGBColor[
              0.9770032019247867, 0.9814553758280588, 0.8828706575837489], 
             UndirectedEdge[106, 384] -> 
             RGBColor[
              0.2081882862900271, 0.33614946716352473`, 0.9351673869660233], 
             UndirectedEdge[28, 265] -> 
             RGBColor[
              0.1984857219314811, 0.32595145684458154`, 0.9346148402794617], 
             UndirectedEdge[113, 266] -> 
             RGBColor[
              0.2701389734664643, 0.40126356728639195`, 0.9386953869528927], 
             UndirectedEdge[164, 292] -> 
             RGBColor[
              0.19766905263223078`, 0.3250930856312453, 0.9345683321710234], 
             UndirectedEdge[98, 248] -> 
             RGBColor[
              0.2095071320406308, 0.3375356576670594, 0.9352424932804627], 
             UndirectedEdge[91, 95] -> 
             RGBColor[
              0.5263538722152581, 0.6263568112928946, 0.9558556514000003], 
             UndirectedEdge[155, 342] -> 
             RGBColor[
              0.19539787597679303`, 0.32270593496546307`, 0.9344389920204009],
              UndirectedEdge[47, 209] -> 
             RGBColor[
              0.43947307837840166`, 0.5526061814054317, 0.9499049126595958], 
             UndirectedEdge[2, 360] -> 
             RGBColor[
              0.18511749831467772`, 0.3119006062289892, 0.9338535397209994], 
             UndirectedEdge[75, 341] -> 
             RGBColor[
              0.2771008643732843, 0.406039405513939, 0.9391849149556509], 
             UndirectedEdge[12, 390] -> 
             RGBColor[
              0.28559351861557547`, 0.41750727411286515`, 0.9395755004361839],
              UndirectedEdge[19, 198] -> 
             RGBColor[
              0.30685620721234774`, 0.43573562617248035`, 0.9409372354734161],
              UndirectedEdge[8, 56] -> 
             RGBColor[
              0.30973133616006665`, 0.43613714011801286`, 0.9411969165511169],
              UndirectedEdge[70, 154] -> 
             RGBColor[
              0.21421417432422896`, 0.3424830575508392, 0.9355105523750686], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.18749255911212426`, 0.3143969457146576, 0.9339887959198263], 
             UndirectedEdge[177, 243] -> 
             RGBColor[
              0.9321893579727436, 0.9478941964628581, 0.9631507032012652], 
             UndirectedEdge[109, 340] -> 
             RGBColor[
              0.19212863805325098`, 0.319269758626164, 0.9342528137570594], 
             UndirectedEdge[28, 36] -> 
             RGBColor[
              0.19993330434376533`, 0.3274729577419183, 0.9346972779563351], 
             UndirectedEdge[203, 339] -> 
             RGBColor[
              0.23865240959631934`, 0.3681691922954158, 0.9369022737206849], 
             UndirectedEdge[247, 369] -> 
             RGBColor[
              0.19411283179141248`, 0.32135527205012093`, 0.934365810655096], 
             UndirectedEdge[223, 230] -> 
             RGBColor[
              0.8738202331046678, 0.44857123188186093`, 0.21353768305270848`],
              UndirectedEdge[22, 173] -> 
             RGBColor[
              0.2993775960909632, 0.43129907223111097`, 0.940385972398696], 
             UndirectedEdge[69, 283] -> 
             RGBColor[
              0.22539830685763262`, 0.3542382899584056, 0.9361474721774046], 
             UndirectedEdge[59, 274] -> 
             RGBColor[
              0.41979531196311004`, 0.5369477420873823, 0.9482682580148925], 
             UndirectedEdge[31, 164] -> 
             RGBColor[
              0.19871454021211585`, 0.32619195936544565`, 0.9346278711420376],
              UndirectedEdge[116, 154] -> 
             RGBColor[
              0.19442534169189124`, 0.3216837397697962, 0.9343836076316113], 
             UndirectedEdge[10, 170] -> 
             RGBColor[
              0.2345826966210814, 0.3638916659237347, 0.936670509587346], 
             UndirectedEdge[301, 394] -> 
             RGBColor[
              0.18156448933556574`, 0.30816616851816203`, 0.9336512011158447],
              UndirectedEdge[90, 351] -> 
             RGBColor[
              0.7590840463718008, 0.8119268218437792, 0.9767853326782896], 
             UndirectedEdge[4, 203] -> 
             RGBColor[
              0.22928794206914588`, 0.35832654318282237`, 0.9363689811485005],
              UndirectedEdge[274, 351] -> 
             RGBColor[
              0.7014339552406084, 0.7651238807564681, 0.9722469063252], 
             UndirectedEdge[238, 269] -> 
             RGBColor[
              0.5167818424220354, 0.6108654129881752, 0.9574511707265], 
             UndirectedEdge[66, 325] -> 
             RGBColor[
              0.2517049597881912, 0.3818882501265539, 0.9376455971445944], 
             UndirectedEdge[128, 171] -> 
             RGBColor[
              0.19178726559275905`, 0.3189109545259229, 0.9342333731004496], 
             UndirectedEdge[198, 205] -> 
             RGBColor[
              0.35166297002886326`, 0.47901452236936815`, 0.9436286313802527],
              UndirectedEdge[202, 349] -> 
             RGBColor[
              0.22267250403179975`, 0.35137329836257414`, 0.9359922417389372],
              UndirectedEdge[295, 390] -> 
             RGBColor[
              0.34587288956677426`, 0.46974318811470905`, 0.943415535012837], 
             UndirectedEdge[250, 356] -> 
             RGBColor[
              0.22666963106636354`, 0.3555745323083922, 0.9362198722103361], 
             UndirectedEdge[133, 393] -> 
             RGBColor[
              0.18457522111446595`, 0.3113306385092063, 0.9338226578366745], 
             UndirectedEdge[124, 293] -> 
             RGBColor[
              0.3293119680498331, 0.45965520784915576`, 0.9422044452983639], 
             UndirectedEdge[45, 325] -> 
             RGBColor[
              0.2869742607531359, 0.4189585216435491, 0.9396541316582929], 
             UndirectedEdge[116, 304] -> 
             RGBColor[
              0.18211433978369124`, 0.30874409620167387`, 0.9336825142854346],
              UndirectedEdge[213, 296] -> 
             RGBColor[
              0.2337895217777734, 0.3630579888732283, 0.9366253394534165], 
             UndirectedEdge[248, 276] -> 
             RGBColor[
              0.22042799245848094`, 0.3490141743887628, 0.9358644201252941], 
             UndirectedEdge[209, 346] -> 
             RGBColor[
              0.34295446203942725`, 0.47147165045125694`, 0.9430737329517971],
              UndirectedEdge[31, 382] -> 
             RGBColor[
              0.18918398084593196`, 0.3161747371992214, 0.9340851198853325], 
             UndirectedEdge[69, 373] -> 
             RGBColor[
              0.25683371538447886`, 0.38727889744013877`, 0.937937672188489], 
             UndirectedEdge[166, 239] -> 
             RGBColor[
              0.9087289042908429, 0.6022050523179494, 0.4973324699831219], 
             UndirectedEdge[235, 317] -> 
             RGBColor[
              0.19343401255220036`, 0.32064178999008336`, 0.934327152903646], 
             UndirectedEdge[43, 59] -> 
             RGBColor[
              0.3034359716582913, 0.4327690861148492, 0.9407194513531689], 
             UndirectedEdge[94, 207] -> 
             RGBColor[
              0.18447193191249567`, 0.3112220750090219, 0.933816775669425], 
             UndirectedEdge[209, 270] -> 
             RGBColor[
              0.34697087401529814`, 0.4749504646340207, 0.9433296551713259], 
             UndirectedEdge[23, 341] -> 
             RGBColor[
              0.3146456284168403, 0.44550133299924655`, 0.9413230337254305], 
             UndirectedEdge[264, 312] -> 
             RGBColor[
              0.5131003370105822, 0.6097335825641022, 0.9568081018654329], 
             UndirectedEdge[48, 118] -> 
             RGBColor[
              0.23953466514577643`, 0.3690964988161278, 0.9369525168690463], 
             UndirectedEdge[106, 310] -> 
             RGBColor[
              0.2532088981789974, 0.38346898473049273`, 0.9377312442110733], 
             UndirectedEdge[267, 282] -> 
             RGBColor[
              0.2615646860965489, 0.39225144761939246`, 0.9382070939716974], 
             UndirectedEdge[43, 274] -> 
             RGBColor[
              0.3767191464303865, 0.4951636983486218, 0.9456872845015338], 
             UndirectedEdge[46, 362] -> 
             RGBColor[
              0.19522925834887567`, 0.3225287071475469, 0.9344293894959386], 
             UndirectedEdge[38, 117] -> 
             RGBColor[
              0.22453541604736282`, 0.35333133700637476`, 0.9360983318222922],
              UndirectedEdge[252, 300] -> 
             RGBColor[
              0.6421328397168371, 0.7146709767757251, 0.9682477279637229], 
             UndirectedEdge[7, 67] -> 
             RGBColor[
              0.43693392935130804`, 0.5528719414914377, 0.9490620215061302], 
             UndirectedEdge[150, 192] -> 
             RGBColor[
              0.1875835174154828, 0.3144925486585769, 0.9339939758606419], 
             UndirectedEdge[239, 272] -> 
             RGBColor[
              0.7843480991326863, 0.5059727477609727, 0.5745160346218742], 
             UndirectedEdge[22, 209] -> 
             RGBColor[
              0.32555893410641223`, 0.4564045184803353, 0.9419653052941668], 
             UndirectedEdge[167, 246] -> 
             RGBColor[
              0.6152498673613919, 0.6911955828537762, 0.9666225650716829], 
             UndirectedEdge[131, 140] -> 
             RGBColor[
              0.21947779992995464`, 0.3480154617955958, 0.9358103080664784], 
             UndirectedEdge[67, 385] -> 
             RGBColor[
              0.7098239251190117, 0.7666063809986858, 0.7914621261134387], 
             UndirectedEdge[60, 101] -> 
             RGBColor[
              0.18455258152934814`, 0.31130684286981486`, 0.9338213685457943],
              UndirectedEdge[113, 249] -> 
             RGBColor[
              0.3083010067824331, 0.4413437356356376, 0.9408697768166884], 
             UndirectedEdge[52, 393] -> 
             RGBColor[
              0.18136432541177624`, 0.30795578354313347`, 0.9336398020765009],
              UndirectedEdge[99, 367] -> 
             RGBColor[
              0.6703595369678017, 0.7365958473458555, 0.9440864000727226], 
             UndirectedEdge[5, 43] -> 
             RGBColor[
              0.2713996679468782, 0.4025886371179538, 0.9387671816385219], 
             UndirectedEdge[26, 105] -> 
             RGBColor[
              0.19823757833601402`, 0.32569064219253296`, 0.9346007088687955],
              UndirectedEdge[128, 306] -> 
             RGBColor[
              0.1986620698216136, 0.3261368096582128, 0.9346248830309214], 
             UndirectedEdge[226, 281] -> 
             RGBColor[
              0.43696413947427415`, 0.552898107981546, 0.9490639464684518], 
             UndirectedEdge[63, 345] -> 
             RGBColor[
              0.18008431245353695`, 0.306610408766515, 0.9335669072321386], 
             UndirectedEdge[4, 280] -> 
             RGBColor[
              0.24217745234544014`, 0.3718742357253608, 0.937103019690414], 
             UndirectedEdge[7, 223] -> 
             RGBColor[
              0.6892737381041355, 0.6614040887409706, 0.6061320446993241], 
             UndirectedEdge[155, 361] -> 
             RGBColor[
              0.21235865222551553`, 0.3405327861781953, 0.9354048831365458], 
             UndirectedEdge[252, 398] -> 
             RGBColor[
              0.39783022825914727`, 0.5190022810145718, 0.9465703682505828], 
             UndirectedEdge[6, 252] -> 
             RGBColor[
              0.3375773650971563, 0.4665223484650306, 0.9427417981088295], 
             UndirectedEdge[260, 307] -> 
             RGBColor[
              0.28646815305242945`, 0.41476449327789777`, 0.9397593961545982],
              UndirectedEdge[21, 357] -> 
             RGBColor[
              0.910151296596057, 0.6637195780075789, 0.25693017547606367`], 
             UndirectedEdge[233, 366] -> 
             RGBColor[
              0.6769028781273625, 0.7426382888986862, 0.9499751965434602], 
             UndirectedEdge[37, 41] -> 
             RGBColor[
              0.6103348144421008, 0.6886019294831773, 0.9655435733376975], 
             UndirectedEdge[173, 176] -> 
             RGBColor[
              0.25807437232061936`, 0.38858290654221544`, 0.9380083257656147],
              UndirectedEdge[60, 136] -> 
             RGBColor[
              0.18529719032077357`, 0.3120894739205271, 0.933863772914916], 
             UndirectedEdge[74, 285] -> 
             RGBColor[
              0.9286295448374513, 0.9418226643023089, 0.7983899704135337], 
             UndirectedEdge[234, 395] -> 
             RGBColor[
              0.6271808306424103, 0.7060165287006694, 0.9652946384160161], 
             UndirectedEdge[17, 164] -> 
             RGBColor[
              0.21631448031938844`, 0.34469061231884324`, 0.9356301616943686],
              UndirectedEdge[20, 383] -> 
             RGBColor[
              0.1993210537450841, 0.3268294435437743, 0.9346624111904838], 
             UndirectedEdge[19, 219] -> 
             RGBColor[
              0.2987647907941907, 0.4287272479574868, 0.9404216575742097], 
             UndirectedEdge[91, 279] -> 
             RGBColor[
              0.5827660155833214, 0.6716970806233367, 0.9606095197706748], 
             UndirectedEdge[76, 207] -> 
             RGBColor[
              0.1908268877624048, 0.3179015365347492, 0.9341786810037627], 
             UndirectedEdge[238, 339] -> 
             RGBColor[
              0.27076497929052823`, 0.4019215390985449, 0.9387310370584805], 
             UndirectedEdge[142, 379] -> 
             RGBColor[
              0.1947953347030193, 0.32207262588340363`, 0.9344046781862394], 
             UndirectedEdge[205, 219] -> 
             RGBColor[
              0.34357155361070624`, 0.4720061441543746, 0.9431130534810463], 
             UndirectedEdge[7, 68] -> 
             RGBColor[
              0.3593357938245753, 0.4820804322688437, 0.9442486147652995], 
             UndirectedEdge[188, 273] -> 
             RGBColor[
              0.19180481699179464`, 0.3189294021591323, 0.9342343726266598], 
             UndirectedEdge[16, 69] -> 
             RGBColor[
              0.2797958916834022, 0.41057876108804503`, 0.9392759017239116], 
             UndirectedEdge[118, 323] -> 
             RGBColor[
              0.3187861771861727, 0.44407882697168544`, 0.9417702640466686], 
             UndirectedEdge[211, 263] -> 
             RGBColor[
              0.30692109574993276`, 0.4322308872824815, 0.9410717536469021], 
             UndirectedEdge[191, 340] -> 
             RGBColor[
              0.2050792556090335, 0.33288167879387, 0.9349903322681394], 
             UndirectedEdge[33, 182] -> 
             RGBColor[
              0.3125367270389322, 0.44214783260778046`, 0.9412445628049322], 
             UndirectedEdge[99, 300] -> 
             RGBColor[
              0.9401681906865148, 0.9543565949425481, 0.9673889822446275], 
             UndirectedEdge[11, 91] -> 
             RGBColor[
              0.40263125450178067`, 0.5220751425472069, 0.9471762250170271], 
             UndirectedEdge[78, 233] -> 
             RGBColor[
              0.8896719661372465, 0.5617502239079055, 0.560162093898772], 
             UndirectedEdge[27, 172] -> 
             RGBColor[
              0.8224207314031455, 0.17334114315753277`, 0.1691034237532337], 
             UndirectedEdge[313, 396] -> 
             RGBColor[
              0.20896253735329678`, 0.3369632541213739, 0.9352114794186747], 
             UndirectedEdge[74, 172] -> 
             RGBColor[
              0.8434316387549917, 0.5388061389910088, 0.578613967277474], 
             UndirectedEdge[217, 366] -> 
             RGBColor[
              0.6937344954214235, 0.7518077736561808, 0.7166986999905727], 
             UndirectedEdge[277, 302] -> 
             RGBColor[
              0.19959521355734036`, 0.32711760288919167`, 0.9346780241862087],
              UndirectedEdge[203, 232] -> 
             RGBColor[
              0.26042493590475796`, 0.3910534979034842, 0.9381421868843842], 
             UndirectedEdge[27, 285] -> 
             RGBColor[
              0.9076186374856052, 0.576357668468833, 0.38887942688929333`], 
             UndirectedEdge[193, 334] -> 
             RGBColor[
              0.1859629402627897, 0.3127892193205704, 0.9339016863892251], 
             UndirectedEdge[39, 381] -> 
             RGBColor[
              0.18966952552711056`, 0.31668507544445096`, 0.9341127709366266],
              UndirectedEdge[270, 390] -> 
             RGBColor[
              0.310905083152461, 0.4394558317316838, 0.9411874173089341], 
             UndirectedEdge[35, 42] -> 
             RGBColor[
              0.22638274960055194`, 0.35527300169848874`, 0.9362035347352613],
              UndirectedEdge[41, 245] -> 
             RGBColor[
              0.8453505309169804, 0.5232059626309822, 0.576653008726561], 
             UndirectedEdge[45, 276] -> 
             RGBColor[
              0.2538332616499947, 0.38412523032544144`, 0.9377668007870836], 
             UndirectedEdge[17, 241] -> 
             RGBColor[
              0.2474447922190557, 0.37741054390116785`, 0.9374029869038852], 
             UndirectedEdge[69, 347] -> 
             RGBColor[
              0.21983376516516337`, 0.34838960382729967`, 0.9358305797600202],
              UndirectedEdge[16, 295] -> 
             RGBColor[
              0.3734051820083968, 0.4978465335906915, 0.9450140259017055], 
             UndirectedEdge[190, 351] -> 
             RGBColor[
              0.9330043693197932, 0.948887212220239, 0.9751255904637988], 
             UndirectedEdge[112, 141] -> 
             RGBColor[
              0.9013527030672266, 0.6354761592849575, 0.23890867411463246`], 
             UndirectedEdge[135, 400] -> 
             RGBColor[
              0.9225103695720027, 0.6890379026099368, 0.4378370589902095], 
             UndirectedEdge[295, 310] -> 
             RGBColor[
              0.3543169737444146, 0.4786184559712684, 0.9438964131148506], 
             UndirectedEdge[185, 249] -> 
             RGBColor[
              0.35433837255967027`, 0.48133182157191207`, 0.9437991056637501],
              UndirectedEdge[93, 98] -> 
             RGBColor[
              0.21766781953393055`, 0.3461130576399892, 0.9357072323605509], 
             UndirectedEdge[221, 268] -> 
             RGBColor[
              0.7908356351545234, 0.6993648502734382, 0.6044361277879526], 
             UndirectedEdge[265, 291] -> 
             RGBColor[
              0.18857894058274138`, 0.31553880152083974`, 0.9340506637374206],
              UndirectedEdge[128, 133] -> 
             RGBColor[
              0.19019948162046302`, 0.31724209289972144`, 0.9341429511521433],
              UndirectedEdge[57, 333] -> 
             RGBColor[
              0.2028967340448986, 0.3305877102501046, 0.9348660408938132], 
             UndirectedEdge[28, 378] -> 
             RGBColor[
              0.19890365407675165`, 0.32639073002768937`, 0.9346386408968597],
              UndirectedEdge[92, 386] -> 
             RGBColor[
              0.6290755332185833, 0.7079371215448762, 0.9651823556220622], 
             UndirectedEdge[35, 248] -> 
             RGBColor[
              0.22712519699410227`, 0.3560533609829937, 0.9362458160159715], 
             UndirectedEdge[56, 175] -> 
             RGBColor[
              0.331650883280764, 0.45917597392142306`, 0.9424452023325764], 
             UndirectedEdge[3, 21] -> 
             RGBColor[
              0.7725354937206939, 0.7794802979389553, 0.6358867741972027], 
             UndirectedEdge[98, 204] -> 
             RGBColor[
              0.19732498772567109`, 0.3247314515994759, 0.9345487381835933], 
             UndirectedEdge[243, 367] -> 
             RGBColor[
              0.6723041775720541, 0.7380461571244501, 0.9407946307732227], 
             UndirectedEdge[48, 209] -> 
             RGBColor[
              0.2875152720132881, 0.41711435878234465`, 0.9397732858765137], 
             UndirectedEdge[116, 291] -> 
             RGBColor[
              0.1852566513830322, 0.31204686492664385`, 0.9338614642823836], 
             UndirectedEdge[214, 340] -> 
             RGBColor[
              0.22133989504081186`, 0.3499726418207558, 0.9359163516283189], 
             UndirectedEdge[138, 159] -> 
             RGBColor[
              0.18138230828610377`, 0.30797468468423184`, 0.9336408261745905],
              UndirectedEdge[22, 48] -> 
             RGBColor[
              0.27823170323432733`, 0.40907339811174287`, 0.9391817450830557],
              UndirectedEdge[13, 297] -> 
             RGBColor[
              0.2105416090442786, 0.33862295858752356`, 0.9353014052154489], 
             UndirectedEdge[192, 347] -> 
             RGBColor[
              0.18973620095672017`, 0.3167551555484371, 0.9341165680037053], 
             UndirectedEdge[4, 322] -> 
             RGBColor[
              0.21636197354501668`, 0.3447405307102229, 0.9356328663633082], 
             UndirectedEdge[111, 304] -> 
             RGBColor[
              0.18507047905985996`, 0.31185118601098283`, 0.9338508620439963],
              UndirectedEdge[133, 361] -> 
             RGBColor[
              0.20171159208941025`, 0.3293420509125463, 0.9347985488127086], 
             UndirectedEdge[4, 186] -> 
             RGBColor[
              0.2198352252877424, 0.3483911385087073, 0.9358306629118409], 
             UndirectedEdge[73, 240] -> 
             RGBColor[
              0.8811521202900017, 0.5036002063401005, 0.22050415715161448`], 
             UndirectedEdge[82, 335] -> 
             RGBColor[
              0.18011477786530028`, 0.30664242984589696`, 0.933568642192269], 
             UndirectedEdge[184, 372] -> 
             RGBColor[
              0.18858940025952037`, 0.31554979530431626`, 0.9340512594005395],
              UndirectedEdge[85, 340] -> 
             RGBColor[
              0.22184000451345684`, 0.35049828858527765`, 0.9359448321229403],
              UndirectedEdge[344, 388] -> 
             RGBColor[
              0.20538183242077535`, 0.3331997062074885, 0.9350075635699459], 
             UndirectedEdge[57, 228] -> 
             RGBColor[
              0.21063806848440092`, 0.33872434357497383`, 0.9353068984378649],
              UndirectedEdge[36, 80] -> 
             RGBColor[
              0.1863429465695527, 0.31318863004276976`, 0.9339233271862263], 
             UndirectedEdge[88, 365] -> 
             RGBColor[
              0.18619994968916187`, 0.3130383312549531, 0.9339151837254329], 
             UndirectedEdge[209, 241] -> 
             RGBColor[
              0.2990278699570904, 0.4292148291621499, 0.9404289112980508], 
             UndirectedEdge[49, 62] -> 
             RGBColor[
              0.19439182652115503`, 0.3216485132003679, 0.9343816989922191], 
             UndirectedEdge[161, 250] -> 
             RGBColor[
              0.22890128499152032`, 0.3579201420787632, 0.9363469615999377], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.19292841019979173`, 0.32011036986066127`, 0.934298359597648], 
             UndirectedEdge[324, 346] -> 
             RGBColor[
              0.4920980261552287, 0.5957700021570038, 0.9539260250446029], 
             UndirectedEdge[142, 258] -> 
             RGBColor[
              0.18294835007904106`, 0.30962069390139346`, 0.9337300099379471],
              UndirectedEdge[44, 46] -> 
             RGBColor[
              0.2189840028439955, 0.34749644974970917`, 0.9357821870529404], 
             UndirectedEdge[85, 191] -> 
             RGBColor[
              0.22398452631281984`, 0.35275231696694354`, 0.9360669594668783],
              UndirectedEdge[112, 172] -> 
             RGBColor[
              0.880455548797022, 0.4861641510661218, 0.21934051163396778`], 
             UndirectedEdge[133, 298] -> 
             RGBColor[
              0.1913924314057353, 0.3184959587614276, 0.9342108878776034], 
             UndirectedEdge[26, 215] -> 
             RGBColor[
              0.18499791179933114`, 0.3117749132191369, 0.9338467294458628], 
             UndirectedEdge[127, 129] -> 
             RGBColor[
              0.19194623803100921`, 0.3190780446379586, 0.9342424263456293], 
             UndirectedEdge[172, 225] -> 
             RGBColor[
              0.8542567503473041, 0.5474377891348923, 0.5796464760848401], 
             UndirectedEdge[38, 376] -> 
             RGBColor[
              0.21626586560617583`, 0.3446395151729059, 0.9356273931583702], 
             UndirectedEdge[158, 346] -> 
             RGBColor[
              0.34491127963015633`, 0.47316654749583464`, 0.9431984196383325],
              UndirectedEdge[340, 370] -> 
             RGBColor[
              0.19501122587610803`, 0.3222995411946109, 0.9344169728691645], 
             UndirectedEdge[44, 266] -> 
             RGBColor[
              0.23471345152571355`, 0.36402909761884283`, 0.9366779558857301],
              UndirectedEdge[183, 238] -> 
             RGBColor[
              0.31998454354214334`, 0.4498414183193987, 0.9416736311656848], 
             UndirectedEdge[21, 264] -> 
             RGBColor[
              0.8432468849976082, 0.8356472056673055, 0.6423010818703361], 
             UndirectedEdge[13, 140] -> 
             RGBColor[
              0.2199309237526768, 0.34849172366298653`, 0.9358361127978458], 
             UndirectedEdge[210, 266] -> 
             RGBColor[
              0.26920304414348, 0.40027984622658896`, 0.9386420871625321], 
             UndirectedEdge[51, 395] -> 
             RGBColor[
              0.4251084428470847, 0.5422133005057554, 0.9484234537100807], 
             UndirectedEdge[358, 372] -> 
             RGBColor[
              0.19242209071206384`, 0.3195781959765495, 0.9342695254518545], 
             UndirectedEdge[174, 309] -> 
             RGBColor[
              0.32079650085916334`, 0.45124869478397367`, 0.9416995914849222],
              UndirectedEdge[65, 363] -> 
             RGBColor[
              0.25392355034044856`, 0.38422012946374207`, 0.9377719425944349],
              UndirectedEdge[236, 267] -> 
             RGBColor[
              0.25338105975763014`, 0.38364993746531034`, 0.9377410485582862],
              UndirectedEdge[227, 352] -> 
             RGBColor[
              0.22353600409255178`, 0.3522808916754905, 0.9360414167899633], 
             UndirectedEdge[2, 370] -> 
             RGBColor[
              0.18603673488354355`, 0.3128667821458319, 0.9339058888837076], 
             UndirectedEdge[17, 354] -> 
             RGBColor[
              0.2237645258481464, 0.35252108252973663`, 0.9360544307658767], 
             UndirectedEdge[133, 306] -> 
             RGBColor[
              0.1942497780329075, 0.32149921123282543`, 0.9343736095409554], 
             UndirectedEdge[105, 261] -> 
             RGBColor[
              0.23472290345765154`, 0.3640390321985968, 0.9366784941592712], 
             UndirectedEdge[120, 206] -> 
             RGBColor[
              0.624306194339526, 0.7045315727086937, 0.9644880050917888], 
             UndirectedEdge[361, 393] -> 
             RGBColor[
              0.20049962337211924`, 0.32806819494741857`, 0.934729528987206], 
             UndirectedEdge[270, 295] -> 
             RGBColor[
              0.3940670515595366, 0.5157428065001295, 0.9463305819589302], 
             UndirectedEdge[9, 283] -> 
             RGBColor[
              0.2000074908485974, 0.3275509324621929, 0.9347015027680361], 
             UndirectedEdge[43, 122] -> 
             RGBColor[
              0.42916131354223347`, 0.5377386121027248, 0.9498157239985662], 
             UndirectedEdge[127, 336] -> 
             RGBColor[
              0.18757872554421223`, 0.31448751209804937`, 0.933993702970662], 
             UndirectedEdge[4, 123] -> 
             RGBColor[
              0.2222583366495916, 0.3509379821841447, 0.9359686555192263], 
             UndirectedEdge[45, 279] -> 
             RGBColor[
              0.4785218001436983, 0.5802784243797845, 0.9537482634423509], 
             UndirectedEdge[135, 255] -> 
             RGBColor[
              0.9151018270707441, 0.6320925985012373, 0.4307426303242521], 
             UndirectedEdge[152, 180] -> 
             RGBColor[
              0.2576563148367751, 0.3881435016203197, 0.9379845180103705], 
             UndirectedEdge[48, 68] -> 
             RGBColor[
              0.2551071510734325, 0.38546416887872903`, 0.937839346905198], 
             UndirectedEdge[362, 363] -> 
             RGBColor[
              0.20453297478611288`, 0.3323075030127757, 0.9349592223834241], 
             UndirectedEdge[18, 257] -> 
             RGBColor[
              0.46412234198098856`, 0.5722988469015355, 0.9519334554771259], 
             UndirectedEdge[72, 109] -> 
             RGBColor[
              0.18206833162796426`, 0.3086957387129193, 0.933679894189029], 
             UndirectedEdge[181, 211] -> 
             RGBColor[
              0.20840661341018846`, 0.33637894280955327`, 0.9351798203725303],
              UndirectedEdge[82, 259] -> 
             RGBColor[
              0.1834817429881715, 0.31018132366795326`, 0.9337603858750381], 
             UndirectedEdge[282, 367] -> 
             RGBColor[
              0.3211123825917724, 0.44870662104929115`, 0.9418228148301714], 
             UndirectedEdge[44, 363] -> 
             RGBColor[
              0.22828771928123268`, 0.35727524561493795`, 0.9363120199404259],
              UndirectedEdge[139, 290] -> 
             RGBColor[
              0.19313846063632573`, 0.32033114618742536`, 0.9343103216592668],
              UndirectedEdge[255, 351] -> 
             RGBColor[
              0.8725754097367984, 0.601857083491112, 0.5863765700059249], 
             UndirectedEdge[290, 345] -> 
             RGBColor[
              0.18860221988526102`, 0.31556326954378094`, 0.9340519894592605],
              UndirectedEdge[145, 200] -> 
             RGBColor[
              0.19073593578989534`, 0.3178059402449537, 0.9341735014234795], 
             UndirectedEdge[44, 316] -> 
             RGBColor[
              0.23551418105696653`, 0.3648707151253743, 0.9367235562479619], 
             UndirectedEdge[172, 240] -> 
             RGBColor[
              0.8277460748309535, 0.21427406632403376`, 0.17420297863381767`],
              UndirectedEdge[89, 299] -> 
             RGBColor[
              0.18845360021131413`, 0.3154070608434312, 0.9340435257886923], 
             UndirectedEdge[119, 196] -> 
             RGBColor[
              0.18607572050979368`, 0.3129077585108523, 0.9339081090574485], 
             UndirectedEdge[149, 369] -> 
             RGBColor[
              0.20360056980323105`, 0.3313274862578765, 0.9349061232990186], 
             UndirectedEdge[32, 385] -> 
             RGBColor[
              0.9757287822359568, 0.928603231512897, 0.461093645269188], 
             UndirectedEdge[149, 253] -> 
             RGBColor[
              0.20384820267597584`, 0.3315877641079622, 0.9349202256247814], 
             UndirectedEdge[317, 336] -> 
             RGBColor[
              0.1878536669894908, 0.3147764929893316, 0.9340093604792311], 
             UndirectedEdge[138, 215] -> 
             RGBColor[
              0.18262441317102773`, 0.30928021567228525`, 0.9337115622102574],
              UndirectedEdge[157, 181] -> 
             RGBColor[
              0.19115892919796787`, 0.31825053313616897`, 0.9341975902723066],
              UndirectedEdge[299, 342] -> 
             RGBColor[
              0.18568831496489116`, 0.3125005707202294, 0.9338860468847814], 
             UndirectedEdge[108, 198] -> 
             RGBColor[
              0.3047308678845767, 0.4335017597846965, 0.9408162005428573], 
             UndirectedEdge[152, 367] -> 
             RGBColor[
              0.31592573046277495`, 0.4432551208089762, 0.9415274426643891], 
             UndirectedEdge[17, 118] -> 
             RGBColor[
              0.23527881827982655`, 0.36462333392373825`, 0.9367101526859918],
              UndirectedEdge[44, 68] -> 
             RGBColor[
              0.25335041241870687`, 0.38361772516894843`, 0.9377393032376733],
              UndirectedEdge[158, 323] -> 
             RGBColor[
              0.3687236016444134, 0.49379158398248, 0.9447157197406713], 
             UndirectedEdge[343, 359] -> 
             RGBColor[
              0.18461240578101906`, 0.3113697219513976, 0.933824775448425], 
             UndirectedEdge[354, 388] -> 
             RGBColor[
              0.21768345542489445`, 0.346129491952765, 0.93570812280141], 
             UndirectedEdge[382, 389] -> 
             RGBColor[
              0.1922700735577051, 0.31941841630887424`, 0.9342608682998029], 
             UndirectedEdge[178, 319] -> 
             RGBColor[
              0.4475260102308348, 0.5620450810151163, 0.9497372679364278], 
             UndirectedEdge[15, 386] -> 
             RGBColor[
              0.5232931103169385, 0.6153912271159707, 0.9581889419192983], 
             UndirectedEdge[27, 104] -> 
             RGBColor[
              0.8200236798530103, 0.15491635454850536`, 0.16680800448174155`],
              UndirectedEdge[236, 398] -> 
             RGBColor[
              0.3384347985138768, 0.4621971627307483, 0.9429819918755249], 
             UndirectedEdge[151, 304] -> 
             RGBColor[
              0.1864549217267703, 0.3133063230326405, 0.9339297040057775], 
             UndirectedEdge[21, 233] -> 
             RGBColor[
              0.9613042288478943, 0.9283900515581442, 0.6325730929841542], 
             UndirectedEdge[120, 321] -> 
             RGBColor[
              0.5363303582199404, 0.6344561720670685, 0.9566410369233613], 
             UndirectedEdge[170, 299] -> 
             RGBColor[
              0.20966330069407968`, 0.3376998008234987, 0.9352513868542458], 
             UndirectedEdge[97, 109] -> 
             RGBColor[
              0.18710606140703578`, 0.3139907121212397, 0.9339667854472937], 
             UndirectedEdge[251, 381] -> 
             RGBColor[
              0.19321867549075944`, 0.3204154570853507, 0.9343148897765596], 
             UndirectedEdge[134, 392] -> 
             RGBColor[
              0.9110260493239869, 0.9293182372189884, 0.8905829197640283], 
             UndirectedEdge[132, 220] -> 
             RGBColor[
              0.4970479670019815, 0.5999842739295098, 0.9542616336741748], 
             UndirectedEdge[102, 167] -> 
             RGBColor[
              0.29386288759542795`, 0.42605944514024496`, 0.9400515350827954],
              UndirectedEdge[270, 373] -> 
             RGBColor[
              0.31547519929516016`, 0.44425931355976, 0.9414476786623798], 
             UndirectedEdge[122, 351] -> 
             RGBColor[
              0.7538761223524553, 0.8076987945105711, 0.9763753458222324], 
             UndirectedEdge[96, 173] -> 
             RGBColor[
              0.515339475447038, 0.6087263479834802, 0.9574676673643785], 
             UndirectedEdge[253, 266] -> 
             RGBColor[
              0.21192263839001468`, 0.3400745079922101, 0.9353800527936387], 
             UndirectedEdge[217, 230] -> 
             RGBColor[
              0.9054039524770299, 0.5624674632894656, 0.3258325895022128], 
             UndirectedEdge[118, 158] -> 
             RGBColor[
              0.28881871360859035`, 0.41812251622929797`, 0.9398607637666927],
              UndirectedEdge[208, 230] -> 
             RGBColor[
              0.9053767960647079, 0.5643648513182951, 0.465019014701602], 
             UndirectedEdge[86, 179] -> 
             RGBColor[
              0.4324853651691194, 0.5490017107824403, 0.9487832899231066], 
             UndirectedEdge[185, 284] -> 
             RGBColor[
              0.33809952087216233`, 0.4642943071241772, 0.9428732085612545], 
             UndirectedEdge[279, 399] -> 
             RGBColor[
              0.7994051322415094, 0.7452396599077329, 0.6138726305595152], 
             UndirectedEdge[167, 309] -> 
             RGBColor[
              0.30392546223642514`, 0.4366358490920146, 0.940624583822355], 
             UndirectedEdge[174, 183] -> 
             RGBColor[
              0.34699168167192995`, 0.474968487180372, 0.943330981016807], 
             UndirectedEdge[149, 247] -> 
             RGBColor[
              0.20711572977977888`, 0.33502214226724336`, 0.9351063064594698],
              UndirectedEdge[297, 339] -> 
             RGBColor[
              0.22923415063680755`, 0.358270004976861, 0.9363659178060062], 
             UndirectedEdge[28, 282] -> 
             RGBColor[
              0.2370656602671769, 0.3665014181447689, 0.9368119106937756], 
             UndirectedEdge[35, 125] -> 
             RGBColor[
              0.24888171485109623`, 0.37892084069359944`, 0.9374848175220434],
              UndirectedEdge[119, 231] -> 
             RGBColor[
              0.18230446054106692`, 0.30894392517202796`, 0.9336933413813087],
              UndirectedEdge[257, 309] -> 
             RGBColor[
              0.31035046981038367`, 0.4422008677223072, 0.9410339796235565], 
             UndirectedEdge[153, 161] -> 
             RGBColor[
              0.1909498488692258, 0.3180307764542026, 0.9341856834568915], 
             UndirectedEdge[315, 369] -> 
             RGBColor[
              0.20472182801530026`, 0.332505999730638, 0.934969977295443], 
             UndirectedEdge[145, 207] -> 
             RGBColor[
              0.19250737674757545`, 0.31966783700731927`, 0.9342743823654074],
              UndirectedEdge[75, 215] -> 
             RGBColor[
              0.20048155521420025`, 0.3280492041678583, 0.9347285000323418], 
             UndirectedEdge[155, 199] -> 
             RGBColor[
              0.1967855567491959, 0.3241644754413012, 0.9345180183874995], 
             UndirectedEdge[28, 151] -> 
             RGBColor[
              0.19950401467485102`, 0.3270217470813523, 0.9346728305447676], 
             UndirectedEdge[141, 279] -> 
             RGBColor[
              0.7689158684311985, 0.6132326776654563, 0.588764654117898], 
             UndirectedEdge[347, 380] -> 
             RGBColor[
              0.20898774598358635`, 0.3369897499901277, 0.9352129150128767], 
             UndirectedEdge[107, 346] -> 
             RGBColor[
              0.3498425512041035, 0.47743776708027175`, 0.9435126359024721], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.684630729662244, 0.7517566465973935, 0.970608286963019], 
             UndirectedEdge[171, 299] -> 
             RGBColor[
              0.18831247292825637`, 0.31525872712095093`, 0.9340354887987012],
              UndirectedEdge[283, 294] -> 
             RGBColor[
              0.19947004944091673`, 0.32698604746696713`, 0.934670896274942], 
             UndirectedEdge[83, 244] -> 
             RGBColor[
              0.9498999569574745, 0.9621560504469515, 0.9696904840737579], 
             UndirectedEdge[112, 179] -> 
             RGBColor[
              0.6955279730573865, 0.6779676106196408, 0.6092046613657698], 
             UndirectedEdge[42, 93] -> 
             RGBColor[
              0.22541709987581074`, 0.35425804261205696`, 0.936148542411988], 
             UndirectedEdge[94, 254] -> 
             RGBColor[
              0.18421702339867016`, 0.31095414999885795`, 0.9338022590066659],
              UndirectedEdge[84, 222] -> 
             RGBColor[
              0.2856119220562171, 0.4147444227440439, 0.9396784182563604], 
             UndirectedEdge[132, 366] -> 
             RGBColor[
              0.3763364091715497, 0.5003854152316536, 0.9452008011045592], 
             UndirectedEdge[52, 133] -> 
             RGBColor[
              0.18257629412906723`, 0.3092296395082612, 0.9337088219020035], 
             UndirectedEdge[255, 400] -> 
             RGBColor[
              0.8427699382288443, 0.329754063899142, 0.18858984719066463`], 
             UndirectedEdge[276, 318] -> 
             RGBColor[
              0.20862378443178675`, 0.3366072033226911, 0.9351921879409346], 
             UndirectedEdge[235, 313] -> 
             RGBColor[
              0.2049405983747336, 0.3327359412492443, 0.9349824359437711], 
             UndirectedEdge[218, 229] -> 
             RGBColor[
              0.19887179747769093`, 0.3263572467222515, 0.9346368267106708], 
             UndirectedEdge[202, 260] -> 
             RGBColor[
              0.23397057730885262`, 0.3632482897159762, 0.9366356502980638], 
             UndirectedEdge[129, 216] -> 
             RGBColor[
              0.1943994825815768, 0.32165656020529343`, 0.9343821349935341], 
             UndirectedEdge[307, 312] -> 
             RGBColor[
              0.32563175741045036`, 0.45592792457411196`, 0.9419897054854269],
              UndirectedEdge[215, 349] -> 
             RGBColor[
              0.192491042377818, 0.3196506685490453, 0.9342734521472142], 
             UndirectedEdge[48, 61] -> 
             RGBColor[
              0.22477630942984533`, 0.3535845312248864, 0.9361120503440548], 
             UndirectedEdge[198, 284] -> 
             RGBColor[
              0.31495346164278715`, 0.44424635397445533`, 0.9413983621344152],
              UndirectedEdge[37, 256] -> 
             RGBColor[
              0.3500537032004466, 0.4776206563266962, 0.9435260903209648], 
             UndirectedEdge[260, 366] -> 
             RGBColor[
              0.3094906009088253, 0.4347053804692331, 0.9412263661740565], 
             UndirectedEdge[35, 263] -> 
             RGBColor[
              0.31410208852609794`, 0.43977856599147, 0.9414807005621779], 
             UndirectedEdge[124, 185] -> 
             RGBColor[
              0.35466498690371884`, 0.48161471850061266`, 0.9438199172409392],
              UndirectedEdge[17, 48] -> 
             RGBColor[
              0.23593219427525336`, 0.3653100735213626, 0.936747361482348], 
             UndirectedEdge[98, 139] -> 
             RGBColor[
              0.19453754132088114`, 0.32180166869373195`, 0.9343899972344978],
              UndirectedEdge[98, 125] -> 
             RGBColor[
              0.23126364989762477`, 0.3604031373776651, 0.9364814947865346], 
             UndirectedEdge[195, 397] -> 
             RGBColor[
              0.2073858256728759, 0.33530603017595706`, 0.9351216880210106], 
             UndirectedEdge[152, 198] -> 
             RGBColor[
              0.3050387614583694, 0.43382537545233274`, 0.9408337346263971], 
             UndirectedEdge[29, 129] -> 
             RGBColor[
              0.18526332309430954`, 0.3120538773182072, 0.933861844226471], 
             UndirectedEdge[83, 230] -> 
             RGBColor[
              0.8813864038440016, 0.5479387227052518, 0.5712729934209153], 
             UndirectedEdge[10, 155] -> 
             RGBColor[
              0.22229114501906733`, 0.3509724658606344, 0.9359705239073323], 
             UndirectedEdge[210, 316] -> 
             RGBColor[
              0.270003773674733, 0.40112146373312046`, 0.9386876875247638], 
             UndirectedEdge[6, 175] -> 
             RGBColor[
              0.2936199376985361, 0.4259435494734196, 0.9400325931289355], 
             UndirectedEdge[301, 343] -> 
             RGBColor[
              0.18235879982602854`, 0.30900103920583233`, 0.9336964359231994],
              UndirectedEdge[140, 297] -> 
             RGBColor[
              0.21630983883703356`, 0.3446857338266013, 0.935629897368815], 
             UndirectedEdge[274, 295] -> 
             RGBColor[
              0.4610566723545275, 0.5726862586021548, 0.9508973954130453], 
             UndirectedEdge[61, 371] -> 
             RGBColor[
              0.19795607517941943`, 0.3253947645266211, 0.934584677680474], 
             UndirectedEdge[266, 397] -> 
             RGBColor[
              0.22283784734549728`, 0.3515470846686418, 0.9360016577960488], 
             UndirectedEdge[71, 88] -> 
             RGBColor[
              0.1851982028892632, 0.3119854318538441, 0.9338581357271303], 
             UndirectedEdge[156, 255] -> 
             RGBColor[
              0.833173631408902, 0.25599264455260395`, 0.17940041294240955`], 
             UndirectedEdge[22, 388] -> 
             RGBColor[
              0.26789478594512556`, 0.39820864264238165`, 0.9385930729355345],
              UndirectedEdge[17, 346] -> 
             RGBColor[
              0.29137138430139253`, 0.41966736519027487`, 0.9400478085576316],
              UndirectedEdge[72, 365] -> 
             RGBColor[
              0.18187230727944725`, 0.30848970469396636`, 0.9336687308923729],
              UndirectedEdge[194, 230] -> 
             RGBColor[
              0.906134992146644, 0.5640310832233217, 0.4054017460858296], 
             UndirectedEdge[95, 264] -> 
             RGBColor[
              0.6413507907064967, 0.7184767050540989, 0.9657562779986768], 
             UndirectedEdge[131, 325] -> 
             RGBColor[
              0.2511977848308302, 0.381355177089618, 0.9376167142810707], 
             UndirectedEdge[369, 372] -> 
             RGBColor[
              0.19233300953943172`, 0.31948456601604064`, 0.9342644524108568],
              UndirectedEdge[11, 248] -> 
             RGBColor[
              0.2649817698706437, 0.3955454303669761, 0.9384125880269136], 
             UndirectedEdge[32, 223] -> 
             RGBColor[
              0.9434671979288998, 0.8132571155526379, 0.27501732397559764`], 
             UndirectedEdge[75, 229] -> 
             RGBColor[
              0.21242485108253378`, 0.34060236537417143`, 0.9354086530635206],
              UndirectedEdge[123, 131] -> 
             RGBColor[
              0.21247713876151392`, 0.34065732304000995`, 0.9354116307694857],
              UndirectedEdge[35, 340] -> 
             RGBColor[
              0.21959313401090685`, 0.34813668522727964`, 0.9358168761717671],
              UndirectedEdge[316, 369] -> 
             RGBColor[
              0.2124757350485229, 0.34065584764865586`, 0.9354115508301075], 
             UndirectedEdge[232, 280] -> 
             RGBColor[
              0.2733144461810522, 0.4046011904460226, 0.9388762254262976], 
             UndirectedEdge[30, 318] -> 
             RGBColor[
              0.18730055861877407`, 0.31419514102261215`, 0.9339778617757692],
              UndirectedEdge[219, 338] -> 
             RGBColor[
              0.28566284547896603`, 0.414956272719873, 0.9396755211710989], 
             UndirectedEdge[124, 397] -> 
             RGBColor[
              0.26132649500551464`, 0.3919101499465881, 0.9381968592370336], 
             UndirectedEdge[131, 280] -> 
             RGBColor[
              0.23239625445736245`, 0.36159357658122604`, 0.9365459949406734],
              UndirectedEdge[224, 345] -> 
             RGBColor[
              0.17916076969846856`, 0.3056397067749454, 0.9335143128384965], 
             UndirectedEdge[44, 195] -> 
             RGBColor[
              0.2192614298530921, 0.3477880431261581, 0.9357979861106919], 
             UndirectedEdge[57, 102] -> 
             RGBColor[
              0.24757611002741542`, 0.37754856724378383`, 0.937410465258804], 
             UndirectedEdge[102, 222] -> 
             RGBColor[
              0.2549287084068188, 0.3852766143221994, 0.9378291848593165], 
             UndirectedEdge[86, 285] -> 
             RGBColor[
              0.7026108469912147, 0.7602147765402214, 0.7786951433273641], 
             UndirectedEdge[97, 340] -> 
             RGBColor[
              0.1979121571634553, 0.3253486039072797, 0.9345821766144358], 
             UndirectedEdge[84, 183] -> 
             RGBColor[
              0.3444123638438444, 0.47273441171796776`, 0.9431666291656026], 
             UndirectedEdge[23, 132] -> 
             RGBColor[
              0.32566481114992, 0.45504559524241234`, 0.9420251663053016], 
             UndirectedEdge[124, 210] -> 
             RGBColor[
              0.30769169180349737`, 0.4406429115045353, 0.9408372886035168], 
             UndirectedEdge[257, 288] -> 
             RGBColor[
              0.3142377899115303, 0.4462866876189422, 0.9412553567525421], 
             UndirectedEdge[31, 287] -> 
             RGBColor[
              0.19320443776430601`, 0.3204004923321242, 0.9343140789591009], 
             UndirectedEdge[163, 222] -> 
             RGBColor[
              0.24959037113759353`, 0.3796656833821117, 0.9375251744491964], 
             UndirectedEdge[206, 386] -> 
             RGBColor[
              0.7455369138645886, 0.8011383704922057, 0.975271810201597], 
             UndirectedEdge[95, 263] -> 
             RGBColor[
              0.47568127911611685`, 0.5835523041211401, 0.9523268989560933], 
             UndirectedEdge[103, 333] -> 
             RGBColor[
              0.19123001846776383`, 0.3183252524660446, 0.9342016387010543], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.19722342502912832`, 0.3246247027659626, 0.9345429543382737], 
             UndirectedEdge[57, 174] -> 
             RGBColor[
              0.28083864150489934`, 0.40925045112803254`, 0.9394240505070525],
              UndirectedEdge[32, 208] -> 
             RGBColor[0.97502376088894, 0.929050734989072, 0.526498655624491],
              UndirectedEdge[11, 125] -> 
             RGBColor[
              0.2867382877276377, 0.41841291007758175`, 0.9396515895329856], 
             UndirectedEdge[82, 136] -> 
             RGBColor[
              0.18265801399513343`, 0.30931553226883557`, 0.9337134757274823],
              UndirectedEdge[129, 298] -> 
             RGBColor[
              0.19304299486108434`, 0.3202308056047669, 0.9343048850245959], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.24346570234943876`, 0.37322826815933124`, 0.9371763836223466],
              UndirectedEdge[155, 306] -> 
             RGBColor[
              0.20489683816901277`, 0.33268994649847444`, 0.9349799438647926],
              UndirectedEdge[247, 358] -> 
             RGBColor[
              0.19420191296404457`, 0.3214489020106298, 0.9343708836960937], 
             UndirectedEdge[5, 373] -> 
             RGBColor[
              0.27714534160664284`, 0.4086277044311172, 0.939094389253483], 
             UndirectedEdge[194, 201] -> 
             RGBColor[
              0.9717877162352071, 0.9761148093624215, 0.8086618740541351], 
             UndirectedEdge[7, 173] -> 
             RGBColor[
              0.36556257674898185`, 0.48862517592323496`, 0.9446032208411446],
              UndirectedEdge[25, 364] -> 
             RGBColor[
              0.81749806012385, 0.1355033345765571, 0.16438946817681815`], 
             UndirectedEdge[1, 313] -> 
             RGBColor[
              0.20595700131663575`, 0.3338042451848521, 0.935040318587679], 
             UndirectedEdge[189, 222] -> 
             RGBColor[
              0.24951462814212214`, 0.379586072691488, 0.937520860997656], 
             UndirectedEdge[232, 275] -> 
             RGBColor[
              0.2669215798519661, 0.39788188260301705`, 0.9385121611462544], 
             UndirectedEdge[289, 376] -> 
             RGBColor[
              0.19788479388924796`, 0.32531984337115605`, 0.93458061831645], 
             UndirectedEdge[194, 208] -> 
             RGBColor[
              0.9937734715667986, 0.9910458830658546, 0.7058012226950569], 
             UndirectedEdge[320, 384] -> 
             RGBColor[
              0.1926752609493727, 0.31984429394788133`, 0.9342839431223373], 
             UndirectedEdge[262, 332] -> 
             RGBColor[
              0.22124807994982085`, 0.34987613833871123`, 0.9359111228947152],
              UndirectedEdge[39, 237] -> 
             RGBColor[
              0.19025421078354665`, 0.3172996167201517, 0.9341460678970164], 
             UndirectedEdge[105, 353] -> 
             RGBColor[
              0.19974831949640176`, 0.32727852693862247`, 0.9346867433429382],
              UndirectedEdge[160, 321] -> 
             RGBColor[
              0.5069925116479708, 0.6106383865650169, 0.9543314541731429], 
             UndirectedEdge[22, 354] -> 
             RGBColor[
              0.2660640348072204, 0.3962844071201169, 0.9384888143665844], 
             UndirectedEdge[70, 286] -> 
             RGBColor[
              0.20888058953085603`, 0.33687712176419665`, 0.9352068126114177],
              UndirectedEdge[97, 334] -> 
             RGBColor[
              0.1889352663956901, 0.3159133225426103, 0.9340709559653313], 
             UndirectedEdge[301, 362] -> 
             RGBColor[
              0.18593089634401205`, 0.31275553913023335`, 0.9338998615354555],
              UndirectedEdge[166, 300] -> 
             RGBColor[
              0.9521971792667703, 0.9624135645920178, 0.9060859398221737], 
             UndirectedEdge[357, 364] -> 
             RGBColor[
              0.8373888047327049, 0.2883923138200816, 0.1834368676776406], 
             UndirectedEdge[13, 66] -> 
             RGBColor[
              0.21421674509456057`, 0.34248575959345395`, 0.9355106987766358],
              UndirectedEdge[102, 395] -> 
             RGBColor[
              0.3730551581743753, 0.49423581065451916`, 0.9452125382842432], 
             UndirectedEdge[129, 336] -> 
             RGBColor[
              0.184720804255658, 0.3114836556211034, 0.9338309485811944], 
             UndirectedEdge[257, 275] -> 
             RGBColor[
              0.2809273627700829, 0.4112753166902168, 0.9393583772051975], 
             UndirectedEdge[358, 369] -> 
             RGBColor[
              0.19068675298749674`, 0.31775424600126295`, 0.9341707005356424],
              UndirectedEdge[42, 139] -> 
             RGBColor[
              0.20228682166276132`, 0.3299466536657998, 0.934831307285935], 
             UndirectedEdge[37, 206] -> 
             RGBColor[
              0.5395559184345032, 0.6328895346269106, 0.9586002858977685], 
             UndirectedEdge[3, 162] -> 
             RGBColor[
              0.42709887646193556`, 0.5374958425847769, 0.9495230473669047], 
             UndirectedEdge[44, 161] -> 
             RGBColor[
              0.2180648213930185, 0.34653033176526227`, 0.9357298410291143], 
             UndirectedEdge[67, 266] -> 
             RGBColor[
              0.3289874356394012, 0.4523479810161943, 0.9424410275338806], 
             UndirectedEdge[305, 360] -> 
             RGBColor[
              0.18374121717091801`, 0.3104540474856332, 0.9337751625458877], 
             UndirectedEdge[51, 174] -> 
             RGBColor[
              0.3627872108908755, 0.4886497806834403, 0.9443374581712001], 
             UndirectedEdge[132, 321] -> 
             RGBColor[
              0.4563174789356197, 0.5669174288296601, 0.9510551804528969], 
             UndirectedEdge[198, 236] -> 
             RGBColor[
              0.3020417872484481, 0.43067536553856556`, 0.9406630613787681], 
             UndirectedEdge[153, 356] -> 
             RGBColor[
              0.18871819494406902`, 0.31568516668383156`, 0.9340585940672899],
              UndirectedEdge[78, 217] -> 
             RGBColor[
              0.9065035834313075, 0.5709197086654001, 0.3268855973458845], 
             UndirectedEdge[16, 324] -> 
             RGBColor[
              0.47545256857995977`, 0.5813525434303296, 0.9528653912069069], 
             UndirectedEdge[263, 312] -> 
             RGBColor[
              0.3474308254202023, 0.4748091816311434, 0.9433787228228494], 
             UndirectedEdge[49, 231] -> 
             RGBColor[
              0.1849354051777754, 0.31170921479673314`, 0.9338431697862355], 
             UndirectedEdge[58, 303] -> 
             RGBColor[
              0.21259709598969448`, 0.3407834056925553, 0.9354184621561699], 
             UndirectedEdge[287, 371] -> 
             RGBColor[
              0.18823999048710255`, 0.315182543479646, 0.9340313610309057], 
             UndirectedEdge[108, 332] -> 
             RGBColor[
              0.24224909685408347`, 0.3719495386464692, 0.9371070997391926], 
             UndirectedEdge[55, 135] -> 
             RGBColor[
              0.9832367917164733, 0.9536721882994657, 0.5121416630539384], 
             UndirectedEdge[38, 145] -> 
             RGBColor[
              0.21009367554414693`, 0.338152152078261, 0.9352758960652745], 
             UndirectedEdge[41, 400] -> 
             RGBColor[
              0.861024743522975, 0.6436848292044157, 0.5916626524195524], 
             UndirectedEdge[184, 369] -> 
             RGBColor[
              0.1868540625349533, 0.3137258453290297, 0.9339524344843275], 
             UndirectedEdge[68, 363] -> 
             RGBColor[
              0.24496356786818765`, 0.3748026197896954, 0.9372616848477457], 
             UndirectedEdge[239, 350] -> 
             RGBColor[
              0.9108066927653387, 0.6030642712488816, 0.46289813781652445`], 
             UndirectedEdge[197, 300] -> 
             RGBColor[
              0.9395054889132312, 0.9538623530451078, 0.9685107634864926], 
             UndirectedEdge[34, 340] -> 
             RGBColor[
              0.23309142699709673`, 0.3623242469969716, 0.9365855839883956], 
             UndirectedEdge[99, 225] -> 
             RGBColor[
              0.9251735948093716, 0.9424003112075763, 0.9659587843040318], 
             UndirectedEdge[75, 218] -> 
             RGBColor[
              0.20441362479812614`, 0.3321820586081753, 0.9349524255781707], 
             UndirectedEdge[33, 256] -> 
             RGBColor[
              0.3139252578534664, 0.443350508209742, 0.9413330387606047], 
             UndirectedEdge[68, 173] -> 
             RGBColor[
              0.2762530439300684, 0.40768984299809713`, 0.9390435742208383], 
             UndirectedEdge[76, 368] -> 
             RGBColor[
              0.18953430680604916`, 0.3165429519952533, 0.9341050704305003], 
             UndirectedEdge[343, 369] -> 
             RGBColor[
              0.18630927681020493`, 0.31315324099090924`, 0.9339214097432413],
              UndirectedEdge[172, 243] -> 
             RGBColor[
              0.8966647112599999, 0.5803804357819402, 0.5534478412456459], 
             UndirectedEdge[25, 83] -> 
             RGBColor[
              0.881176745521725, 0.5463271969673706, 0.5710722243747279], 
             UndirectedEdge[176, 372] -> 
             RGBColor[
              0.2138686325253813, 0.34211987121163484`, 0.9354908742808075], 
             UndirectedEdge[211, 214] -> 
             RGBColor[
              0.23081730246588306`, 0.35993399792684283`, 0.9364560759606089],
              UndirectedEdge[273, 330] -> 
             RGBColor[
              0.18387764331179846`, 0.31059744000961553`, 0.9337829318127865],
              UndirectedEdge[247, 266] -> 
             RGBColor[
              0.21519016549381775`, 0.3435088861514912, 0.9355661336283271], 
             UndirectedEdge[294, 347] -> 
             RGBColor[
              0.19390550774844745`, 0.3211373613358611, 0.9343540038575576], 
             UndirectedEdge[247, 343] -> 
             RGBColor[
              0.18982443678675276`, 0.31684789700027605`, 0.9341215929036926],
              UndirectedEdge[147, 354] -> 
             RGBColor[
              0.1996644579713909, 0.3271903831587082, 0.9346819675531508], 
             UndirectedEdge[83, 206] -> 
             RGBColor[
              0.8376738526720509, 0.8738864473115988, 0.9758404514260404], 
             UndirectedEdge[178, 300] -> 
             RGBColor[
              0.6781948564694122, 0.7459060831571422, 0.9705455677828076], 
             UndirectedEdge[31, 384] -> 
             RGBColor[
              0.19301716646589862`, 0.32020365832381187`, 0.9343034141356996],
              UndirectedEdge[325, 339] -> 
             RGBColor[
              0.2703434502460814, 0.40147848534634617`, 0.9387070316029955], 
             UndirectedEdge[43, 237] -> 
             RGBColor[
              0.22884629711642387`, 0.3578623463356042, 0.9363438301217982], 
             UndirectedEdge[114, 128] -> 
             RGBColor[
              0.21795119041436695`, 0.34641089840207934`, 0.9357233699129821],
              UndirectedEdge[131, 188] -> 
             RGBColor[
              0.20752052535930418`, 0.3354476080868466, 0.9351293589688823], 
             UndirectedEdge[8, 352] -> 
             RGBColor[
              0.23870734178156489`, 0.36822692950501057`, 0.9369054020273697],
              UndirectedEdge[56, 137] -> 
             RGBColor[
              0.35805694536026106`, 0.48455266243088047`, 0.9440360498343989],
              UndirectedEdge[11, 93] -> 
             RGBColor[
              0.2731424573639435, 0.4041228303399058, 0.9388773271070019], 
             UndirectedEdge[232, 325] -> 
             RGBColor[
              0.29211597655452004`, 0.4243627909544146, 0.9399469447666949], 
             UndirectedEdge[293, 387] -> 
             RGBColor[
              0.4415101712045343, 0.5546415244104943, 0.9499598596294503], 
             UndirectedEdge[100, 175] -> 
             RGBColor[
              0.2458994336441635, 0.3757862740575634, 0.9373149810191983], 
             UndirectedEdge[327, 336] -> 
             RGBColor[
              0.18798018955468324`, 0.3149094762273428, 0.9340165657521455], 
             UndirectedEdge[230, 357] -> 
             RGBColor[
              0.8374194029311317, 0.28862750498140566`, 0.18346616854700978`],
              UndirectedEdge[151, 291] -> 
             RGBColor[
              0.1895972333261113, 0.3166090917576105, 0.9341086540027264], 
             UndirectedEdge[10, 87] -> 
             RGBColor[
              0.2178399723924833, 0.34629400120944975`, 0.9357170362111682], 
             UndirectedEdge[44, 247] -> 
             RGBColor[
              0.2171512777998561, 0.34557013952683935`, 0.9356778160729503], 
             UndirectedEdge[191, 334] -> 
             RGBColor[
              0.1961023648412683, 0.3234463974292005, 0.934479111619035], 
             UndirectedEdge[31, 389] -> 
             RGBColor[
              0.19956255990653143`, 0.3270832818318305, 0.9346761646091019], 
             UndirectedEdge[323, 346] -> 
             RGBColor[
              0.37487874320773873`, 0.4991228582382221, 0.9451079199183084], 
             UndirectedEdge[91, 257] -> 
             RGBColor[
              0.408201112318213, 0.5268994734386068, 0.9475311314318583], 
             UndirectedEdge[25, 217] -> 
             RGBColor[
              0.9051942941547533, 0.5608559375515845, 0.32563182045602546`], 
             UndirectedEdge[4, 238] -> 
             RGBColor[
              0.26140051176335477`, 0.3920788899859515, 0.9381977444862962], 
             UndirectedEdge[49, 298] -> 
             RGBColor[
              0.19233776426424887`, 0.31948956353329044`, 0.9342647231854012],
              UndirectedEdge[96, 245] -> 
             RGBColor[
              0.7835145897788575, 0.47447987208772324`, 0.5706010714513564], 
             UndirectedEdge[198, 219] -> 
             RGBColor[
              0.34521680439082036`, 0.47343117768740084`, 0.9432178874059169],
              UndirectedEdge[69, 106] -> 
             RGBColor[
              0.23431749208343802`, 0.36361291913973265`, 0.936655406581262], 
             UndirectedEdge[246, 350] -> 
             RGBColor[
              0.9570479117499637, 0.9654838538059254, 0.8719160935305621], 
             UndirectedEdge[91, 263] -> 
             RGBColor[
              0.44262523593919395`, 0.5567159191123393, 0.94972460614893], 
             UndirectedEdge[193, 305] -> 
             RGBColor[
              0.18458905889423072`, 0.311345182893105, 0.933823445877761], 
             UndirectedEdge[217, 244] -> 
             RGBColor[
              0.9739175055905028, 0.9766847910311653, 0.7242500801550553], 
             UndirectedEdge[218, 260] -> 
             RGBColor[
              0.20772118523879674`, 0.3356585143427644, 0.9351407862521698], 
             UndirectedEdge[115, 169] -> 
             RGBColor[
              0.8801983721871041, 0.6989200901607082, 0.599330145570115], 
             UndirectedEdge[152, 332] -> 
             RGBColor[
              0.24255699042787615`, 0.37227315431410535`, 0.9371246338227324],
              UndirectedEdge[8, 227] -> 
             RGBColor[
              0.22264092645081146`, 0.35134010832282114`, 0.9359904434424149],
              UndirectedEdge[161, 344] -> 
             RGBColor[
              0.1953522686165181, 0.3226579987381405, 0.9344363947487033], 
             UndirectedEdge[255, 324] -> 
             RGBColor[
              0.7342455134222807, 0.4929254711764368, 0.5728784243989717], 
             UndirectedEdge[135, 221] -> 
             RGBColor[
              0.9485753172801801, 0.8203317071995411, 0.46009294767531356`], 
             UndirectedEdge[179, 257] -> 
             RGBColor[
              0.38852623515624984`, 0.5109265218154098, 0.9459822530302189], 
             UndirectedEdge[40, 350] -> 
             RGBColor[
              0.7574551958384235, 0.806891984810095, 0.8535080309341501], 
             UndirectedEdge[358, 397] -> 
             RGBColor[
              0.20184959481572412`, 0.3294871005277804, 0.9348064078638154], 
             UndirectedEdge[44, 149] -> 
             RGBColor[
              0.22663901581167467`, 0.355542353734595, 0.9362181287168728], 
             UndirectedEdge[215, 218] -> 
             RGBColor[
              0.18692850160935742`, 0.31380408551593836`, 0.9339566736794921],
              UndirectedEdge[211, 248] -> 
             RGBColor[
              0.2199442042179371, 0.34850568227400514`, 0.9358368691006957], 
             UndirectedEdge[38, 103] -> 
             RGBColor[
              0.20863860950919683`, 0.3366227854190133, 0.9351930322071614], 
             UndirectedEdge[79, 213] -> 
             RGBColor[
              0.22683120635617676`, 0.355744358182451, 0.9362290736840618], 
             UndirectedEdge[116, 383] -> 
             RGBColor[
              0.19584602024074033`, 0.3231769630008592, 0.9344645131732627], 
             UndirectedEdge[214, 263] -> 
             RGBColor[
              0.315848849556003, 0.4416145225849462, 0.9415801760187297], 
             UndirectedEdge[203, 275] -> 
             RGBColor[
              0.232253685994867, 0.3614437280877808, 0.9365378758776455], 
             UndirectedEdge[235, 396] -> 
             RGBColor[
              0.19553592187284338`, 0.32285102995482734`, 0.9344468535299604],
              UndirectedEdge[170, 361] -> 
             RGBColor[
              0.22465020382752957`, 0.3534519862412956, 0.9361048688165594], 
             UndirectedEdge[190, 255] -> 
             RGBColor[
              0.8957903553105804, 0.6198388885195696, 0.570244438982581], 
             UndirectedEdge[67, 113] -> 
             RGBColor[
              0.36637406988619037`, 0.4916437040590915, 0.9445701410456664], 
             UndirectedEdge[244, 307] -> 
             RGBColor[
              0.651559964846024, 0.7209668023928419, 0.952436169214119], 
             UndirectedEdge[106, 292] -> 
             RGBColor[
              0.21060209943900177`, 0.3386865378276902, 0.9353048500539408], 
             UndirectedEdge[119, 126] -> 
             RGBColor[
              0.1845010944888899, 0.3112527267258263, 0.9338184364350084], 
             UndirectedEdge[148, 288] -> 
             RGBColor[
              0.3196747008606359, 0.4509958666159675, 0.9416017919105475], 
             UndirectedEdge[143, 277] -> 
             RGBColor[
              0.196429195674298, 0.32378991735698637`, 0.9344977241514731], 
             UndirectedEdge[245, 364] -> 
             RGBColor[
              0.8182535878829069, 0.14131065200704435`, 0.16511296241213771`],
              UndirectedEdge[101, 335] -> 
             RGBColor[
              0.18130162624818058`, 0.3078898827468379, 0.9336362314518891], 
             UndirectedEdge[175, 296] -> 
             RGBColor[
              0.26330595896968834`, 0.39408163581213873`, 0.9383062568858402],
              UndirectedEdge[106, 158] -> 
             RGBColor[
              0.2827874224549232, 0.411783246820848, 0.939517290657987], 
             UndirectedEdge[59, 319] -> 
             RGBColor[
              0.3999369554845372, 0.5208258336893123, 0.9467049354493426], 
             UndirectedEdge[159, 218] -> 
             RGBColor[
              0.18568639672443343`, 0.31249855452788494`, 0.9338859376438252],
              UndirectedEdge[126, 326] -> 
             RGBColor[
              0.18929893908149736`, 0.31629556559357375`, 0.9340916665867824],
              UndirectedEdge[130, 371] -> 
             RGBColor[
              0.18427986944939637`, 0.311020205182841, 0.9338058379962824], 
             UndirectedEdge[108, 262] -> 
             RGBColor[
              0.23515249805591343`, 0.36449056335924074`, 0.936702958936114], 
             UndirectedEdge[34, 91] -> 
             RGBColor[
              0.37827297461142906`, 0.4967706349329164, 0.9457781608227135], 
             UndirectedEdge[173, 323] -> 
             RGBColor[
              0.3405854460382354, 0.4669912406886779, 0.9430117001586653], 
             UndirectedEdge[104, 208] -> 
             RGBColor[
              0.906012199289136, 0.5692488389367173, 0.4656274775468996], 
             UndirectedEdge[115, 122] -> 
             RGBColor[
              0.7312854319265467, 0.5812953754272103, 0.5851154705993664], 
             UndirectedEdge[275, 297] -> 
             RGBColor[
              0.22283542703535522`, 0.35154454076922603`, 0.9360015199629668],
              UndirectedEdge[185, 293] -> 
             RGBColor[
              0.374247320413842, 0.49857595155038115`, 0.9450676862162266], 
             UndirectedEdge[92, 256] -> 
             RGBColor[
              0.42434961842059, 0.5407753734409124, 0.9485908039462863], 
             UndirectedEdge[135, 165] -> 
             RGBColor[
              0.9457959012350979, 0.9559420991486686, 0.8350019041226482], 
             UndirectedEdge[158, 270] -> 
             RGBColor[
              0.3489276916060272, 0.4766453616785984, 0.9434543418578613], 
             UndirectedEdge[35, 86] -> 
             RGBColor[
              0.32363709491798653`, 0.44803730928476804`, 0.942088262737994], 
             UndirectedEdge[124, 387] -> 
             RGBColor[
              0.42192783769441117`, 0.5376802913607258, 0.9487120906541628], 
             UndirectedEdge[170, 261] -> 
             RGBColor[
              0.2458172275622507, 0.3756998702533064, 0.9373102995044464], 
             UndirectedEdge[78, 244] -> 
             RGBColor[
              0.8873515007123038, 0.5600196245933966, 0.5640900365888891], 
             UndirectedEdge[320, 381] -> 
             RGBColor[
              0.19597803687805715`, 0.32331572085701743`, 0.9344720313254569],
              UndirectedEdge[90, 166] -> 
             RGBColor[
              0.7990367806379581, 0.841477411935373, 0.8913793888944332], 
             UndirectedEdge[119, 317] -> 
             RGBColor[
              0.1888850042427438, 0.31586049383305914`, 0.9340680936100771], 
             UndirectedEdge[173, 250] -> 
             RGBColor[
              0.27041365894161523`, 0.40155227913684066`, 0.9387110298843417],
              UndirectedEdge[234, 355] -> 
             RGBColor[
              0.7757149376246414, 0.8247136720150343, 0.978279673580333], 
             UndirectedEdge[203, 297] -> 
             RGBColor[
              0.2163387830881471, 0.3447161560696932, 0.9356315457010966], 
             UndirectedEdge[48, 388] -> 
             RGBColor[
              0.2298511238520014, 0.358918482944391, 0.9364010535178815], 
             UndirectedEdge[34, 95] -> 
             RGBColor[
              0.41132901778835196`, 0.5236070199417173, 0.9483804536298768], 
             UndirectedEdge[133, 299] -> 
             RGBColor[
              0.18672468895596034`, 0.31358986549474943`, 0.9339450668503949],
              UndirectedEdge[58, 376] -> 
             RGBColor[
              0.2107803074531337, 0.33887384574958357`, 0.9353149987367104], 
             UndirectedEdge[239, 392] -> 
             RGBColor[
              0.9094234148855309, 0.6024922502969611, 0.4858226320933391], 
             UndirectedEdge[64, 77] -> 
             RGBColor[
              0.18172630335562523`, 0.308336245312846, 0.9336604161849047], 
             UndirectedEdge[73, 112] -> 
             RGBColor[
              0.9338615942560703, 0.7754902910821886, 0.2656416901517646], 
             UndirectedEdge[257, 339] -> 
             RGBColor[
              0.2873260863715352, 0.41800078089785175`, 0.939722775048237], 
             UndirectedEdge[35, 85] -> 
             RGBColor[
              0.2384984047146932, 0.36800732340035325`, 0.9368935033705061], 
             UndirectedEdge[37, 187] -> 
             RGBColor[
              0.39185947335344506`, 0.5138307132141199, 0.9461899170277228], 
             UndirectedEdge[9, 39] -> 
             RGBColor[
              0.1871051393828018, 0.3139897430153101, 0.9339667329393776], 
             UndirectedEdge[136, 394] -> 
             RGBColor[
              0.18251086599702937`, 0.30916087039310625`, 0.9337050958666762],
              UndirectedEdge[287, 389] -> 
             RGBColor[
              0.19629053047607914`, 0.32364417144177693`, 0.9344898273735713],
              UndirectedEdge[195, 372] -> 
             RGBColor[
              0.19795832156921558`, 0.32539712562472617`, 0.9345848056090496],
              UndirectedEdge[149, 362] -> 
             RGBColor[
              0.20288427131655484`, 0.3305746111324327, 0.934865331159871], 
             UndirectedEdge[83, 321] -> 
             RGBColor[
              0.7496980165524652, 0.8038110466699736, 0.967993483257613], 
             UndirectedEdge[227, 308] -> 
             RGBColor[
              0.20448504246078797`, 0.33225712309977423`, 0.9349564927084064],
              UndirectedEdge[100, 146] -> 
             RGBColor[
              0.1981449486568544, 0.3255932825266753, 0.9345954337456006], 
             UndirectedEdge[100, 278] -> 
             RGBColor[
              0.23415669632153385`, 0.3634439125989312, 0.9366462495004977], 
             UndirectedEdge[234, 350] -> 
             RGBColor[
              0.8897866044520348, 0.9121284341385445, 0.8654271636734474], 
             UndirectedEdge[278, 352] -> 
             RGBColor[
              0.24888415157963256`, 0.37892340184978857`, 0.9374849562901288],
              UndirectedEdge[342, 353] -> 
             RGBColor[
              0.1868676578718124, 0.31374013489006275`, 0.9339532087186491], 
             UndirectedEdge[109, 181] -> 
             RGBColor[
              0.18812311022869774`, 0.31505969491742614`, 0.9340247048730984],
              UndirectedEdge[59, 296] -> 
             RGBColor[
              0.2957363483745861, 0.42467629385936273`, 0.9402809691977339], 
             UndirectedEdge[168, 378] -> 
             RGBColor[
              0.18751181267223727`, 0.3144171824270826, 0.9339898923815917], 
             UndirectedEdge[191, 370] -> 
             RGBColor[
              0.19715574767547106`, 0.3245535695762768, 0.9345391002131025], 
             UndirectedEdge[153, 184] -> 
             RGBColor[
              0.18277753601960423`, 0.3094411574946885, 0.933720282329959], 
             UndirectedEdge[3, 91] -> 
             RGBColor[
              0.5375833562526594, 0.6354734123169479, 0.9567396775183801], 
             UndirectedEdge[149, 210] -> 
             RGBColor[
              0.26112860842944113`, 0.3917931023423411, 0.9381822599936748], 
             UndirectedEdge[3, 312] -> 
             RGBColor[
              0.44238894573366777`, 0.553566674835752, 0.9503937941922995], 
             UndirectedEdge[17, 388] -> 
             RGBColor[
              0.22559527698605156`, 0.35444531805200136`, 0.9361586893348268],
              UndirectedEdge[99, 243] -> 
             RGBColor[
              0.9675815557220673, 0.9753429578546242, 0.9397601494648378], 
             UndirectedEdge[108, 398] -> 
             RGBColor[
              0.34112387915000547`, 0.4650235569768793, 0.9431351310396142], 
             UndirectedEdge[57, 186] -> 
             RGBColor[
              0.21226621689950026`, 0.3404356307898151, 0.9353996190814751], 
             UndirectedEdge[180, 398] -> 
             RGBColor[
              0.3423187854528118, 0.46627947926256413`, 0.9432031791858535], 
             UndirectedEdge[66, 318] -> 
             RGBColor[
              0.20433061997593613`, 0.33209481527724394`, 0.9349476985763416],
              UndirectedEdge[374, 382] -> 
             RGBColor[
              0.18605529017041303`, 0.3128862849288049, 0.9339069455798448], 
             UndirectedEdge[190, 270] -> 
             RGBColor[
              0.6576592800193992, 0.7261622336829004, 0.951547961847741], 
             UndirectedEdge[47, 96] -> 
             RGBColor[
              0.6461513889555156, 0.7219924964871992, 0.9663950668318202], 
             UndirectedEdge[245, 328] -> 
             RGBColor[
              0.8441804058989478, 0.32309654782053254`, 0.18925529611386532`],
              UndirectedEdge[142, 143] -> 
             RGBColor[
              0.1837659567931899, 0.3104800503972236, 0.9337765714307771], 
             UndirectedEdge[268, 373] -> 
             RGBColor[
              0.475607023803843, 0.5762529501811211, 0.9537345477094038], 
             UndirectedEdge[69, 390] -> 
             RGBColor[
              0.2522635992417797, 0.3824754156120626, 0.9376774108350432], 
             UndirectedEdge[91, 112] -> 
             RGBColor[
              0.7152028502193496, 0.6939405622428378, 0.6107535397674092], 
             UndirectedEdge[16, 190] -> 
             RGBColor[
              0.6369974104682594, 0.7082659607734624, 0.9502314057905163], 
             UndirectedEdge[40, 395] -> 
             RGBColor[
              0.494849422028799, 0.60078007937222, 0.9533755056767188], 
             UndirectedEdge[84, 246] -> 
             RGBColor[
              0.6295415881560444, 0.703574353083331, 0.9675332208830456], 
             UndirectedEdge[196, 376] -> 
             RGBColor[
              0.19966869054902864`, 0.32719483186616644`, 0.9346822085921858],
              UndirectedEdge[37, 311] -> 
             RGBColor[
              0.3257713181858094, 0.4560335502623456, 0.9419991567290754], 
             UndirectedEdge[179, 275] -> 
             RGBColor[
              0.34634920232824207`, 0.46792331791250663`, 0.9435317259645368],
              UndirectedEdge[334, 340] -> 
             RGBColor[
              0.1939578430419053, 0.32119236904753456`, 0.934356984275097], 
             UndirectedEdge[23, 366] -> 
             RGBColor[
              0.34372780451171075`, 0.47069085221995155`, 0.9431761242698371],
              UndirectedEdge[295, 351] -> 
             RGBColor[
              0.6694121408599306, 0.7384677850374681, 0.9699082105749879], 
             UndirectedEdge[358, 363] -> 
             RGBColor[
              0.20533835444542115`, 0.3331540080987284, 0.9350050875635693], 
             UndirectedEdge[111, 116] -> 
             RGBColor[
              0.1862942905711151, 0.31313748950344333`, 0.9339205562990953], 
             UndirectedEdge[147, 371] -> 
             RGBColor[
              0.18501189214807195`, 0.3117896074520688, 0.9338475256060415], 
             UndirectedEdge[33, 311] -> 
             RGBColor[
              0.28964287283882917`, 0.4217634021453914, 0.9398061051687154], 
             UndirectedEdge[137, 178] -> 
             RGBColor[
              0.3880768646119117, 0.5105544076416471, 0.9459488925435418], 
             UndirectedEdge[328, 386] -> 
             RGBColor[
              0.8151456848541535, 0.6567413505380229, 0.5948173850288303], 
             UndirectedEdge[20, 36] -> 
             RGBColor[
              0.19158305641128354`, 0.3186963177285822, 0.934221743689665], 
             UndirectedEdge[107, 212] -> 
             RGBColor[
              0.3829775514957524, 0.5061376389193594, 0.9456239688209257], 
             UndirectedEdge[21, 27] -> 
             RGBColor[
              0.8921201702935075, 0.5251244399562564, 0.23966354856549787`], 
             UndirectedEdge[138, 329] -> 
             RGBColor[
              0.18634787164566047`, 0.31319380661002694`, 0.9339236076620245],
              UndirectedEdge[3, 263] -> 
             RGBColor[
              0.48691076315351817`, 0.5926689051451934, 0.9532109250744729], 
             UndirectedEdge[239, 269] -> 
             RGBColor[
              0.785672209855677, 0.5070071531213871, 0.5746480096042236], 
             UndirectedEdge[74, 86] -> 
             RGBColor[
              0.6370413534700665, 0.7120367862892685, 0.9671058051428245], 
             UndirectedEdge[91, 179] -> 
             RGBColor[
              0.47362295187637204`, 0.5835474746608966, 0.9517044801911976], 
             UndirectedEdge[316, 358] -> 
             RGBColor[
              0.212564816221155, 0.34074947760916474`, 0.9354166238711052], 
             UndirectedEdge[154, 267] -> 
             RGBColor[
              0.23074964895808886`, 0.359862889800671, 0.9364522231934242], 
             UndirectedEdge[25, 357] -> 
             RGBColor[
              0.837209744608855, 0.2870159792435245, 0.18326539950082243`], 
             UndirectedEdge[118, 388] -> 
             RGBColor[
              0.2291977478565746, 0.35823174334676655`, 0.936363844721525], 
             UndirectedEdge[305, 340] -> 
             RGBColor[
              0.19258396167334632`, 0.31974833262006913`, 0.9342787437636328],
              UndirectedEdge[100, 213] -> 
             RGBColor[
              0.21638299645224862`, 0.344762627118653, 0.9356340635867745], 
             UndirectedEdge[51, 238] -> 
             RGBColor[
              0.3357800727610889, 0.463522711822467, 0.942680108320078], 
             UndirectedEdge[104, 242] -> 
             RGBColor[
              0.8356412746575417, 0.27496003188981555`, 0.1817634309041114], 
             UndirectedEdge[99, 337] -> 
             RGBColor[
              0.9798418672906987, 0.9817838609022704, 0.7682315700129669], 
             UndirectedEdge[143, 302] -> 
             RGBColor[
              0.1882090973662136, 0.3151500728508547, 0.9340296017133733], 
             UndirectedEdge[14, 327] -> 
             RGBColor[
              0.19007805312865012`, 0.317114463855815, 0.9341360359791719], 
             UndirectedEdge[162, 348] -> 
             RGBColor[
              0.3027342580511927, 0.4332679187418763, 0.9406342199418414], 
             UndirectedEdge[130, 391] -> 
             RGBColor[
              0.18156952589467779`, 0.3081714622611251, 0.9336514879404352], 
             UndirectedEdge[182, 386] -> 
             RGBColor[
              0.5546461678159978, 0.6446668165900299, 0.9601091386691207], 
             UndirectedEdge[32, 217] -> 
             RGBColor[
              0.975050917301262, 0.9271533469602427, 0.3873122304251019], 
             UndirectedEdge[3, 285] -> 
             RGBColor[
              0.7880339609127915, 0.8307135264515318, 0.7851026525209982], 
             UndirectedEdge[212, 274] -> 
             RGBColor[
              0.45520745425599235`, 0.5676199598754534, 0.950524688408067], 
             UndirectedEdge[234, 272] -> 
             RGBColor[
              0.7633280108193825, 0.8150369106506357, 0.9770450604787972], 
             UndirectedEdge[24, 104] -> 
             RGBColor[
              0.8198979870257355, 0.15395022439912315`, 0.1666876408883935], 
             UndirectedEdge[317, 327] -> 
             RGBColor[
              0.19548056477531295`, 0.3227928461354802, 0.9344437010251496], 
             UndirectedEdge[85, 263] -> 
             RGBColor[
              0.31634895902864796`, 0.44214016934946804`, 0.941608656513351], 
             UndirectedEdge[169, 300] -> 
             RGBColor[
              0.9052440838676142, 0.9272810765527117, 0.9908241829118685], 
             UndirectedEdge[34, 162] -> 
             RGBColor[
              0.2677884948207052, 0.39879306520074553`, 0.9385615306712383], 
             UndirectedEdge[62, 313] -> 
             RGBColor[
              0.20973650567435648`, 0.3377767438992335, 0.9352555557695754], 
             UndirectedEdge[337, 367] -> 
             RGBColor[
              0.6845644891406854, 0.7444870601720963, 0.7692660513213518], 
             UndirectedEdge[21, 240] -> 
             RGBColor[
              0.8974455137213154, 0.5660573631227573, 0.24476310344608182`], 
             UndirectedEdge[258, 378] -> 
             RGBColor[
              0.18711323001988966`, 0.3139982467878655, 0.9339671936891907], 
             UndirectedEdge[240, 242] -> 
             RGBColor[
              0.8419811748449504, 0.32369128289221516`, 0.18783452648346705`],
              UndirectedEdge[16, 380] -> 
             RGBColor[
              0.26894987250182517`, 0.3991789072508731, 0.9386582369767682], 
             UndirectedEdge[38, 222] -> 
             RGBColor[
              0.22765792346573496`, 0.35661329028148886`, 0.9362761540004327],
              UndirectedEdge[61, 147] -> 
             RGBColor[
              0.19642039468713995`, 0.32378066696146846`, 0.9344972229482744],
              UndirectedEdge[279, 288] -> 
             RGBColor[
              0.4888026931766387, 0.5910842948036721, 0.9543337450913586], 
             UndirectedEdge[192, 384] -> 
             RGBColor[
              0.1855895073220066, 0.3123967176227914, 0.933880419935692], 
             UndirectedEdge[196, 289] -> 
             RGBColor[
              0.18795157808443957`, 0.3148794037580448, 0.934014936371242], 
             UndirectedEdge[9, 384] -> 
             RGBColor[
              0.19029625552141455`, 0.3173438084054412, 0.9341484622826384], 
             UndirectedEdge[114, 187] -> 
             RGBColor[
              0.33810546577905015`, 0.4610349816709624, 0.9429931157731941], 
             UndirectedEdge[90, 274] -> 
             RGBColor[
              0.5507285778663977, 0.6461452954084659, 0.9577745175163469], 
             UndirectedEdge[270, 324] -> 
             RGBColor[
              0.49611443813109957`, 0.5992488163397677, 0.9541819472641316], 
             UndirectedEdge[42, 45] -> 
             RGBColor[
              0.2506616815740248, 0.3807916985758058, 0.9375861839936894], 
             UndirectedEdge[316, 363] -> 
             RGBColor[
              0.2271273365064473, 0.3560556097461213, 0.9362459378580343], 
             UndirectedEdge[44, 250] -> 
             RGBColor[
              0.24751102743025372`, 0.3774801613076919, 0.9374067589011768], 
             UndirectedEdge[213, 352] -> 
             RGBColor[
              0.23111045171034733`, 0.3602421163695104, 0.9364727703764056], 
             UndirectedEdge[80, 378] -> 
             RGBColor[
              0.18531329630253898`, 0.3121064023285408, 0.9338646901267509], 
             UndirectedEdge[238, 272] -> 
             RGBColor[
              0.5154577316990447, 0.6098310076277607, 0.9573191957441505], 
             UndirectedEdge[126, 196] -> 
             RGBColor[
              0.1881608487233165, 0.3150993604680292, 0.9340268540245378], 
             UndirectedEdge[112, 240] -> 
             RGBColor[
              0.8843983974342954, 0.516470613459494, 0.2231161879418313], 
             UndirectedEdge[52, 89] -> 
             RGBColor[
              0.18430520538442102`, 0.31104683485694296`, 0.933807280840301], 
             UndirectedEdge[99, 177] -> 
             RGBColor[
              0.9302447173684912, 0.9464438866842635, 0.9664424725007652], 
             UndirectedEdge[41, 206] -> 
             RGBColor[
              0.8010921103082493, 0.8449578955447232, 0.9806977415425538], 
             UndirectedEdge[1, 119] -> 
             RGBColor[
              0.18798137752672578`, 0.3149107248612813, 0.9340166334053959], 
             UndirectedEdge[2, 109] -> 
             RGBColor[
              0.1831541470606865, 0.30983699957738503`, 0.9337417297716024], 
             UndirectedEdge[8, 100] -> 
             RGBColor[
              0.22397988652346618`, 0.35274744025415317`, 0.9360666952377386],
              UndirectedEdge[203, 322] -> 
             RGBColor[
              0.2128310735235297, 0.3410293309156486, 0.935431786830583], 
             UndirectedEdge[98, 193] -> 
             RGBColor[
              0.1939801662783198, 0.32121583218438116`, 0.9343582555503864], 
             UndirectedEdge[141, 285] -> 
             RGBColor[
              0.9298982865463443, 0.7362961374607975, 0.4097714679426784], 
             UndirectedEdge[29, 231] -> 
             RGBColor[
              0.1818156421264654, 0.3084301460254042, 0.9336655038957391], 
             UndirectedEdge[225, 398] -> 
             RGBColor[
              0.6554022589203814, 0.7271955623129416, 0.9686184880711814], 
             UndirectedEdge[149, 359] -> 
             RGBColor[
              0.20190369877404518`, 0.3295439672183649, 0.9348094890042022], 
             UndirectedEdge[87, 235] -> 
             RGBColor[
              0.1948464738725398, 0.3221263763929803, 0.9344075904862901], 
             UndirectedEdge[162, 312] -> 
             RGBColor[
              0.28761893872861966`, 0.41963611907072695`, 0.9396908451152812],
              UndirectedEdge[392, 395] -> 
             RGBColor[
              0.729861417537885, 0.7850410988470374, 0.8743691386056183], 
             UndirectedEdge[212, 268] -> 
             RGBColor[
              0.5483496579696843, 0.6426701443947892, 0.9582447440009759], 
             UndirectedEdge[50, 271] -> 
             RGBColor[
              0.17906803055065768`, 0.3055422320505946, 0.933509031481224], 
             UndirectedEdge[200, 207] -> 
             RGBColor[
              0.1859857863076916, 0.31281323196228517`, 0.9339029874376845], 
             UndirectedEdge[360, 370] -> 
             RGBColor[
              0.18616848137367975`, 0.313005256060175, 0.9339133916514194], 
             UndirectedEdge[134, 246] -> 
             RGBColor[
              0.8756067697264411, 0.9036490867400013, 0.9879973494315406], 
             UndirectedEdge[88, 191] -> 
             RGBColor[
              0.19934659159346146`, 0.326856285441612, 0.9346638655331689], 
             UndirectedEdge[277, 278] -> 
             RGBColor[
              0.23299059780069237`, 0.3622182691186103, 0.9365798419148239], 
             UndirectedEdge[233, 242] -> 
             RGBColor[
              0.9058398899715292, 0.686023971327602, 0.5756445160215393], 
             UndirectedEdge[66, 123] -> 
             RGBColor[
              0.21298431371887483`, 0.3411903960769459, 0.9354405136330093], 
             UndirectedEdge[315, 316] -> 
             RGBColor[
              0.22659989124895852`, 0.3555012313385397, 0.9362159006309058], 
             UndirectedEdge[127, 216] -> 
             RGBColor[
              0.19725740387013102`, 0.32466041668223944`, 0.9345448893830015],
              UndirectedEdge[29, 326] -> 
             RGBColor[
              0.18672499245337307`, 0.31359018448977305`, 0.9339450841341236],
              UndirectedEdge[76, 145] -> 
             RGBColor[
              0.19557703724460856`, 0.3228942448174177, 0.9344491949895577], 
             UndirectedEdge[21, 104] -> 
             RGBColor[
              0.8911056135339068, 0.5173261121203578, 0.23869200786672617`], 
             UndirectedEdge[27, 112] -> 
             RGBColor[
              0.8790730540064875, 0.47553769029299303`, 0.21801663306124733`],
              UndirectedEdge[190, 221] -> 
             RGBColor[
              0.9292638455200164, 0.8080779972178733, 0.5995947563336426], 
             UndirectedEdge[310, 324] -> 
             RGBColor[
              0.45636436031597766`, 0.5621244658109066, 0.9517477784200521], 
             UndirectedEdge[11, 312] -> 
             RGBColor[
              0.30743684398278903`, 0.44016840506601096`, 0.9408303416909466],
              UndirectedEdge[177, 225] -> 
             RGBColor[
              0.8897813970600477, 0.9149515498158103, 0.9893493380404593], 
             UndirectedEdge[253, 316] -> 
             RGBColor[
              0.2127233679212677, 0.3409161254987416, 0.9354256531558705], 
             UndirectedEdge[17, 323] -> 
             RGBColor[
              0.3151837063156497, 0.44029240167692024`, 0.9415651086599703], 
             UndirectedEdge[315, 397] -> 
             RGBColor[
              0.21588466984352767`, 0.3442388542571554, 0.935605684623616], 
             UndirectedEdge[43, 296] -> 
             RGBColor[
              0.2526601828418626, 0.38289225012060224`, 0.937699995684375], 
             UndirectedEdge[50, 287] -> 
             RGBColor[
              0.18448432655099875`, 0.31123510255995407`, 0.9338174815257515],
              UndirectedEdge[253, 369] -> 
             RGBColor[
              0.19084530468760944`, 0.3179208938908398, 0.9341797298204076], 
             UndirectedEdge[187, 220] -> 
             RGBColor[
              0.5353714211663698, 0.63317812373389, 0.9567035702854296], 
             UndirectedEdge[211, 340] -> 
             RGBColor[
              0.21241214123474167`, 0.34058900651829105`, 0.9354079292564914],
              UndirectedEdge[213, 227] -> 
             RGBColor[
              0.2150440363795939, 0.343355295187321, 0.9355578117914507], 
             UndirectedEdge[17, 389] -> 
             RGBColor[
              0.21716250001380405`, 0.34558193478522814`, 0.9356784551614329],
              UndirectedEdge[117, 376] -> 
             RGBColor[
              0.217871456795024, 0.34632709331274647`, 0.9357188292013159], 
             UndirectedEdge[186, 330] -> 
             RGBColor[
              0.19639093276449526`, 0.3237497006127751, 0.9344955451353647], 
             UndirectedEdge[24, 337] -> 
             RGBColor[
              0.9074168352108218, 0.5752287479070755, 0.3804750196277067], 
             UndirectedEdge[73, 99] -> 
             RGBColor[
              0.9481261161147958, 0.8682562660194123, 0.6030407890629428], 
             UndirectedEdge[114, 155] -> 
             RGBColor[
              0.2241859587617661, 0.352964035242341, 0.9360784307468533], 
             UndirectedEdge[123, 232] -> 
             RGBColor[
              0.2533953304852037, 0.3836649369048065, 0.9377418612551098], 
             UndirectedEdge[53, 289] -> 
             RGBColor[
              0.18928237138329773`, 0.3162781518923132, 0.9340907230808797], 
             UndirectedEdge[126, 376] -> 
             RGBColor[
              0.19809406452812484`, 0.3255398000811405, 0.9345925359697458], 
             UndirectedEdge[207, 254] -> 
             RGBColor[
              0.18750231875154622`, 0.3144072037144869, 0.9339893517168534], 
             UndirectedEdge[291, 304] -> 
             RGBColor[
              0.1840328398717771, 0.3107605614341833, 0.9337917700272845], 
             UndirectedEdge[333, 368] -> 
             RGBColor[
              0.18664235406415453`, 0.3135033263031278, 0.9339403780001101], 
             UndirectedEdge[26, 171] -> 
             RGBColor[
              0.18798107467478986`, 0.3149104065446947, 0.9340166161584262], 
             UndirectedEdge[81, 384] -> 
             RGBColor[
              0.18455785037421688`, 0.3113123807598359, 0.9338216685987151], 
             UndirectedEdge[120, 233] -> 
             RGBColor[
              0.7388527640498924, 0.7945317751585553, 0.9544100950493892], 
             UndirectedEdge[224, 290] -> 
             RGBColor[
              0.18877579274929696`, 0.3157457056290379, 0.9340618741770893], 
             UndirectedEdge[393, 396] -> 
             RGBColor[
              0.19146055662429076`, 0.3185675626855177, 0.9342147675080179], 
             UndirectedEdge[2, 365] -> 
             RGBColor[
              0.18295812271216946`, 0.3096309655584321, 0.9337305664749465], 
             UndirectedEdge[210, 387] -> 
             RGBColor[
              0.4198898949581986, 0.5356292280658739, 0.9485927029346032], 
             UndirectedEdge[23, 307] -> 
             RGBColor[
              0.32070535665531497`, 0.4507499650286162, 0.9417091542503788], 
             UndirectedEdge[120, 244] -> 
             RGBColor[
              0.7365322986249497, 0.7928011758440465, 0.9583380377395063], 
             UndirectedEdge[42, 248] -> 
             RGBColor[
              0.21725641238251098`, 0.34568064263912723`, 0.9356838033318999],
              UndirectedEdge[49, 393] -> 
             RGBColor[
              0.1855205539729795, 0.3123242432810691, 0.9338764931444723], 
             UndirectedEdge[375, 377] -> 
             RGBColor[
              0.18266643619111367`, 0.3093243845308089, 0.9337139553590839], 
             UndirectedEdge[269, 350] -> 
             RGBColor[
              0.8687159863176557, 0.8956679071093385, 0.8633270413739342], 
             UndirectedEdge[77, 207] -> 
             RGBColor[
              0.18528324242742453`, 0.31207481380026975`, 0.9338629786030239],
              UndirectedEdge[200, 368] -> 
             RGBColor[
              0.18469320535133593`, 0.3114546474227893, 0.9338293768644222], 
             UndirectedEdge[384, 389] -> 
             RGBColor[
              0.1961032591776717, 0.32344733743346465`, 0.93447916255017], 
             UndirectedEdge[1, 361] -> 
             RGBColor[
              0.205591391562574, 0.33341996615233593`, 0.9350194976530564], 
             UndirectedEdge[150, 380] -> 
             RGBColor[
              0.20683506244234898`, 0.3347271431002675, 0.9350903228698133], 
             UndirectedEdge[150, 381] -> 
             RGBColor[
              0.19485465175919953`, 0.32213497187036766`, 0.9344080562048372],
              UndirectedEdge[232, 279] -> 
             RGBColor[
              0.48366351594508233`, 0.5856826936906501, 0.9540410765507529], 
             UndirectedEdge[132, 341] -> 
             RGBColor[
              0.34725423307667924`, 0.4751958960109486, 0.9433477105601525], 
             UndirectedEdge[1, 14] -> 
             RGBColor[
              0.18904790384743964`, 0.31603171164602595`, 0.9340773705015762],
              UndirectedEdge[171, 342] -> 
             RGBColor[
              0.18633859981298379`, 0.3131840613260155, 0.9339230796448701], 
             UndirectedEdge[140, 325] -> 
             RGBColor[
              0.25741913844630737`, 0.3878942141960865, 0.9379710111658044], 
             UndirectedEdge[89, 306] -> 
             RGBColor[
              0.1959786892882613, 0.3233164065815071, 0.9344720684792528], 
             UndirectedEdge[130, 147] -> 
             RGBColor[
              0.18274418895711692`, 0.3094061076176884, 0.9337183832640827], 
             UndirectedEdge[4, 183] -> 
             RGBColor[
              0.2914028738694214, 0.4198002713108441, 0.9400459473606144], 
             UndirectedEdge[80, 151] -> 
             RGBColor[
              0.18591365690063838`, 0.3127374193822037, 0.9338988797746588], 
             UndirectedEdge[236, 286] -> 
             RGBColor[
              0.22281035809500455`, 0.3515181917234548, 0.9360000923239], 
             UndirectedEdge[108, 180] -> 
             RGBColor[
              0.25734842126298235`, 0.38781988595268346`, 0.9379669839268308],
              UndirectedEdge[9, 320] -> 
             RGBColor[
              0.1934136507337484, 0.32062038842787655`, 0.9343259933282078], 
             UndirectedEdge[35, 97] -> 
             RGBColor[
              0.21457055736469166`, 0.3428576387223553, 0.9355308478620015], 
             UndirectedEdge[154, 236] -> 
             RGBColor[
              0.22814394288837742`, 0.3571241275100973, 0.936303832087551], 
             UndirectedEdge[60, 259] -> 
             RGBColor[
              0.18612091931381164`, 0.3129552653196448, 0.9339106830624717], 
             UndirectedEdge[179, 399] -> 
             RGBColor[
              0.6902620685345601, 0.6570900539452929, 0.6049675909800379], 
             UndirectedEdge[314, 352] -> 
             RGBColor[
              0.23613835462959704`, 0.3655267611250992, 0.9367591020095412], 
             UndirectedEdge[85, 88] -> 
             RGBColor[
              0.21610734049788477`, 0.34447289523301966`, 0.9356183653879699],
              UndirectedEdge[70, 267] -> 
             RGBColor[
              0.23945129119348169`, 0.3690088675060522, 0.9369477688458039], 
             UndirectedEdge[31, 192] -> 
             RGBColor[
              0.18904880805086632`, 0.3160326620211572, 0.9340774219946237], 
             UndirectedEdge[221, 255] -> 
             RGBColor[
              0.8688348859370216, 0.46104786848874635`, 0.21084573587576866`],
              UndirectedEdge[11, 211] -> 
             RGBColor[
              0.2669271143125195, 0.39759011071734907`, 0.9385233725149993], 
             UndirectedEdge[211, 312] -> 
             RGBColor[
              0.26239927833008236`, 0.39312865697304, 0.9382546227647286], 
             UndirectedEdge[123, 280] -> 
             RGBColor[
              0.23161694690439888`, 0.3607744749321087, 0.9365016145284144], 
             UndirectedEdge[178, 278] -> 
             RGBColor[
              0.349928065209785, 0.47283535767355744`, 0.9436893135230188], 
             UndirectedEdge[83, 364] -> 
             RGBColor[
              0.8813558056455749, 0.5477035315439278, 0.5712436925515461], 
             UndirectedEdge[10, 313] -> 
             RGBColor[
              0.22793409689467709`, 0.35690356606571383`, 0.9362918816686491],
              UndirectedEdge[32, 242] -> 
             RGBColor[
              0.9046528362573457, 0.6347619279421703, 0.24263460898170292`], 
             UndirectedEdge[44, 369] -> 
             RGBColor[
              0.21363611782330827`, 0.34187548351747254`, 0.9354776329124991],
              UndirectedEdge[110, 375] -> 
             RGBColor[
              0.18201536929507323`, 0.30864007194304494`, 0.9336768780625215],
              UndirectedEdge[275, 290] -> 
             RGBColor[
              0.21848378643908228`, 0.34697069059259356`, 0.9357537004686844],
              UndirectedEdge[362, 369] -> 
             RGBColor[
              0.18988137332818844`, 0.31690774091531027`, 0.9341248353554973],
              UndirectedEdge[266, 338] -> 
             RGBColor[
              0.23347632110247196`, 0.3627287951054168, 0.936607503138297], 
             UndirectedEdge[350, 395] -> 
             RGBColor[
              0.7312446954176929, 0.785613119798958, 0.8514446443288036], 
             UndirectedEdge[141, 172] -> 
             RGBColor[
              0.8447003804638847, 0.3332796121494973, 0.18999546480661883`], 
             UndirectedEdge[123, 275] -> 
             RGBColor[
              0.22522408057531274`, 0.3540551670891031, 0.9361375502483711], 
             UndirectedEdge[46, 315] -> 
             RGBColor[
              0.21006971303598748`, 0.3381269659628746, 0.9352745314358842], 
             UndirectedEdge[185, 205] -> 
             RGBColor[
              0.3748090292582385, 0.49906247551909, 0.9451034778070919], 
             UndirectedEdge[3, 86] -> 
             RGBColor[
              0.49644576954540676`, 0.6009276484384913, 0.9538184872502891], 
             UndirectedEdge[316, 397] -> 
             RGBColor[
              0.2236385768767503, 0.3523887021751733, 0.9360472581582806], 
             UndirectedEdge[11, 214] -> 
             RGBColor[
              0.2758548681185897, 0.40697374601981373`, 0.9390317948868268], 
             UndirectedEdge[3, 34] -> 
             RGBColor[
              0.4225585018257533, 0.5327236209657705, 0.9492644797482566], 
             UndirectedEdge[5, 100] -> 
             RGBColor[
              0.24629351933764826`, 0.37620048310789195`, 0.9373374236164447],
              UndirectedEdge[25, 245] -> 
             RGBColor[
              0.8180745277590571, 0.13993431743048723`, 0.16494149423531956`],
              UndirectedEdge[183, 325] -> 
             RGBColor[
              0.3195630144976964, 0.44939836456720006`, 0.9416496257101998], 
             UndirectedEdge[149, 266] -> 
             RGBColor[
              0.22467790350563632`, 0.35348110035924685`, 0.9361064462722496],
              UndirectedEdge[73, 78] -> 
             RGBColor[
              0.8752764478324426, 0.45843721309521324`, 0.21487760657063304`],
              UndirectedEdge[40, 167] -> 
             RGBColor[
              0.4156571514498516, 0.5326037138579458, 0.948214502475271], 
             UndirectedEdge[5, 175] -> 
             RGBColor[
              0.282045444074704, 0.41377802280949016`, 0.9393734428399871], 
             UndirectedEdge[279, 309] -> 
             RGBColor[
              0.48491537307549215`, 0.5869984749070372, 0.9541123679623731], 
             UndirectedEdge[66, 257] -> 
             RGBColor[
              0.268687595913645, 0.3984105456780595, 0.9386613405898359], 
             UndirectedEdge[238, 309] -> 
             RGBColor[
              0.29378936272937667`, 0.4261216259230004, 0.9400422416338], 
             UndirectedEdge[40, 355] -> 
             RGBColor[
              0.6433835290110301, 0.7194772226865849, 0.9663605408410356], 
             UndirectedEdge[31, 271] -> 
             RGBColor[
              0.18778814176396494`, 0.3147076218227647, 0.9340056289145733], 
             UndirectedEdge[271, 391] -> 
             RGBColor[
              0.1801133509320429, 0.3066409300485706, 0.9335685609305309], 
             UndirectedEdge[264, 348] -> 
             RGBColor[
              0.5282156563331551, 0.6233653822352514, 0.957751476691993], 
             UndirectedEdge[146, 302] -> 
             RGBColor[
              0.18875875182792845`, 0.3157277945402228, 0.9340609037218272], 
             UndirectedEdge[86, 91] -> 
             RGBColor[
              0.45216024233108254`, 0.5649746624056373, 0.950332168324746], 
             UndirectedEdge[232, 257] -> 
             RGBColor[
              0.30909861267997385`, 0.4408850865059202, 0.9409626882119364], 
             UndirectedEdge[201, 385] -> 
             RGBColor[
              0.9717345415002878, 0.9760010739812197, 0.8028741323146045], 
             UndirectedEdge[204, 297] -> 
             RGBColor[
              0.2002775476373886, 0.32783477926980176`, 0.9347168821026446], 
             UndirectedEdge[241, 323] -> 
             RGBColor[
              0.3309521511254019, 0.4568660369491151, 0.9424630982645621], 
             UndirectedEdge[269, 395] -> 
             RGBColor[
              0.6061102125080312, 0.6895560016714635, 0.9631945161165028], 
             UndirectedEdge[52, 342] -> 
             RGBColor[
              0.18153992013799802`, 0.30814034473374124`, 0.9336498019363901],
              UndirectedEdge[201, 245] -> 
             RGBColor[
              0.8839369101698967, 0.553629569307468, 0.5684023912498125], 
             UndirectedEdge[131, 330] -> 
             RGBColor[
              0.199593351679308, 0.3271156459373298, 0.9346779181550091], 
             UndirectedEdge[159, 349] -> 
             RGBColor[
              0.191248937492894, 0.31834513756099186`, 0.9342027161115474], 
             UndirectedEdge[15, 33] -> 
             RGBColor[
              0.28118366953987284`, 0.41287224313372134`, 0.9393243660551096],
              UndirectedEdge[16, 212] -> 
             RGBColor[
              0.36755596390986156`, 0.4927802348639901, 0.9446413188967272], 
             UndirectedEdge[246, 269] -> 
             RGBColor[
              0.8319134288403021, 0.869426735678431, 0.9836659653182612], 
             UndirectedEdge[150, 294] -> 
             RGBColor[
              0.19175282420721007`, 0.318874754446001, 0.9342314117144941], 
             UndirectedEdge[77, 200] -> 
             RGBColor[
              0.1835118014697444, 0.3102129170379042, 0.9337620976610961], 
             UndirectedEdge[21, 285] -> 
             RGBColor[
              0.9787005711665018, 0.9387674260406853, 0.4607634302742779], 
             UndirectedEdge[275, 280] -> 
             RGBColor[
              0.24514319627116127`, 0.3749914206303192, 0.9372719144195587], 
             UndirectedEdge[171, 353] -> 
             RGBColor[
              0.1894918158351776, 0.3164982912907842, 0.9341026506325689], 
             UndirectedEdge[197, 252] -> 
             RGBColor[
              0.6669388623748537, 0.7337127880117662, 0.9450324457252983], 
             UndirectedEdge[15, 361] -> 
             RGBColor[
              0.2517308007762076, 0.3819154106433724, 0.9376470687506336], 
             UndirectedEdge[348, 366] -> 
             RGBColor[
              0.3637695245894192, 0.4895006114365967, 0.9444000503314454], 
             UndirectedEdge[235, 298] -> 
             RGBColor[
              0.19425582793699694`, 0.3215055700656095, 0.9343739540740432], 
             UndirectedEdge[62, 298] -> 
             RGBColor[
              0.19905173523661984`, 0.32654637271559867`, 0.9346470738998478],
              UndirectedEdge[110, 308] -> 
             RGBColor[
              0.1924672891129, 0.3196257023615725, 0.9342720994339171], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.2089266760744028, 0.33692556164351994`, 0.9352094371718936], 
             UndirectedEdge[204, 290] -> 
             RGBColor[
              0.19592590704111568`, 0.32326092909316934`, 0.9344690626083623],
              UndirectedEdge[35, 93] -> 
             RGBColor[
              0.235285884487402, 0.3646307609559235, 0.9367105550960597], 
             UndirectedEdge[162, 211] -> 
             RGBColor[
              0.24710920905835015`, 0.37705782472206506`, 0.9373838759393338],
              UndirectedEdge[66, 275] -> 
             RGBColor[
              0.22651056308563722`, 0.3554073417751564, 0.9362108135241538], 
             UndirectedEdge[36, 277] -> 
             RGBColor[
              0.20034660319217895`, 0.3279073610362615, 0.9347208147143313], 
             UndirectedEdge[174, 246] -> 
             RGBColor[
              0.6321209059841302, 0.7058084285457353, 0.96769757273425], 
             UndirectedEdge[218, 329] -> 
             RGBColor[
              0.19065196008399016`, 0.31771767645368004`, 0.9341687191312593],
              UndirectedEdge[186, 188] -> 
             RGBColor[
              0.20431810644449144`, 0.33208166276229184`, 0.934946985949238], 
             UndirectedEdge[230, 245] -> 
             RGBColor[
              0.8182841860813337, 0.14154584316836838`, 0.16514226328150688`],
              UndirectedEdge[57, 368] -> 
             RGBColor[
              0.20142644533340448`, 0.3290423435926357, 0.9347823101267909], 
             UndirectedEdge[293, 316] -> 
             RGBColor[
              0.2916240499210687, 0.42013376007774095`, 0.9400548442196108], 
             UndirectedEdge[8, 308] -> 
             RGBColor[
              0.21965638014980107`, 0.34820316092929426`, 0.9358204779458129],
              UndirectedEdge[37, 361] -> 
             RGBColor[
              0.28321730845770904`, 0.41130658795806163`, 0.939575768828076], 
             UndirectedEdge[19, 331] -> 
             RGBColor[
              0.22977587045111889`, 0.35883938684872224`, 0.9363967679480286],
              UndirectedEdge[98, 276] -> 
             RGBColor[
              0.21193626472305038`, 0.34008883013219005`, 0.9353808287931467],
              UndirectedEdge[326, 336] -> 
             RGBColor[
              0.18618247361472157`, 0.3130199627926692, 0.9339141884888471], 
             UndirectedEdge[4, 13] -> 
             RGBColor[
              0.22349076802527734`, 0.3522333457006528, 0.9360388406628528], 
             UndirectedEdge[137, 300] -> 
             RGBColor[
              0.624581474397714, 0.6994688662935715, 0.9671293704856514], 
             UndirectedEdge[57, 163] -> 
             RGBColor[
              0.24223777275819017`, 0.37193763630369614`, 0.9371064548486839],
              UndirectedEdge[28, 304] -> 
             RGBColor[
              0.1939396212205168, 0.3211732167579251, 0.9343559465693256], 
             UndirectedEdge[83, 328] -> 
             RGBColor[
              0.9072826236616158, 0.729489427357416, 0.5953860262532737], 
             UndirectedEdge[206, 321] -> 
             RGBColor[
              0.6423373781810662, 0.7191701000468311, 0.9659074859341975], 
             UndirectedEdge[295, 373] -> 
             RGBColor[
              0.3504430057094734, 0.4745466699427852, 0.9436757963662827], 
             UndirectedEdge[29, 235] -> 
             RGBColor[
              0.18647615617022215`, 0.31332864177904984`, 0.9339309132759184],
              UndirectedEdge[234, 392] -> 
             RGBColor[
              0.888403326572227, 0.9115564131866241, 0.8883516579502622], 
             UndirectedEdge[42, 275] -> 
             RGBColor[
              0.2276321474655179, 0.3565861980709679, 0.9362746860953526], 
             UndirectedEdge[107, 324] -> 
             RGBColor[
              0.4908741561658506, 0.5947099474856988, 0.9538480411311054], 
             UndirectedEdge[75, 329] -> 
             RGBColor[
              0.20420501368883298`, 0.3319627951056, 0.934940545484109], 
             UndirectedEdge[267, 383] -> 
             RGBColor[
              0.23217032750693795`, 0.361356113031734, 0.9365331287350758], 
             UndirectedEdge[253, 362] -> 
             RGBColor[
              0.19012900620093326`, 0.31716801876539596`, 0.9341389376812601],
              UndirectedEdge[137, 252] -> 
             RGBColor[
              0.35201484785933657`, 0.47931930126023004`, 0.943651052724457], 
             UndirectedEdge[131, 203] -> 
             RGBColor[
              0.2195067441810682, 0.34804588403868764`, 0.9358119563987601], 
             UndirectedEdge[52, 199] -> 
             RGBColor[
              0.1829276009104009, 0.30959888520957934`, 0.9337288283034887], 
             UndirectedEdge[41, 386] -> 
             RGBColor[
              0.8163158098721861, 0.8568507653484726, 0.982215097641526], 
             UndirectedEdge[59, 122] -> 
             RGBColor[
              0.472237479074957, 0.5795226558414852, 0.9523966975119249], 
             UndirectedEdge[32, 172] -> 
             RGBColor[
              0.8904177362433487, 0.5253447113739889, 0.22900306113205354`], 
             UndirectedEdge[55, 156] -> 
             RGBColor[
              0.9013085960546312, 0.5775722343508322, 0.2607994456720959], 
             UndirectedEdge[97, 214] -> 
             RGBColor[
              0.21631731839459667`, 0.3446935953158315, 0.9356303233185532], 
             UndirectedEdge[133, 155] -> 
             RGBColor[
              0.1964342499678622, 0.3237952297399831, 0.9344980119860145], 
             UndirectedEdge[186, 273] -> 
             RGBColor[
              0.19433831903215518`, 0.3215922734368583, 0.9343786518198778], 
             UndirectedEdge[74, 179] -> 
             RGBColor[
              0.6585040630153561, 0.7306095985445278, 0.968478117009276], 
             UndirectedEdge[10, 62] -> 
             RGBColor[
              0.21930338871384658`, 0.34783214454915645`, 0.9358003756057394],
              UndirectedEdge[273, 322] -> 
             RGBColor[
              0.19086506728942945`, 0.31794166563837395`, 0.9341808552713451],
              UndirectedEdge[18, 148] -> 
             RGBColor[
              0.46955925293009415`, 0.5770080258985608, 0.9522798906351313], 
             UndirectedEdge[78, 172] -> 
             RGBColor[
              0.8218704023733945, 0.1691110730791465, 0.16857642805283624`], 
             UndirectedEdge[84, 269] -> 
             RGBColor[
              0.5412096627237364, 0.6337584063867442, 0.9589441687264177], 
             UndirectedEdge[103, 254] -> 
             RGBColor[
              0.19079740219879987`, 0.3178705453379077, 0.9341770018445352], 
             UndirectedEdge[46, 343] -> 
             RGBColor[
              0.19165716183089215`, 0.31877420722314587`, 0.9342259638836825],
              UndirectedEdge[1, 317] -> 
             RGBColor[
              0.19445041549410247`, 0.3217100939256911, 0.9343850355475539], 
             UndirectedEdge[27, 399] -> 
             RGBColor[
              0.873807149483661, 0.45466013361864505`, 0.21377956267551557`], 
             UndirectedEdge[247, 253] -> 
             RGBColor[
              0.19436046466415727`, 0.3216155499002067, 0.9343799129808589], 
             UndirectedEdge[27, 357] -> 
             RGBColor[
              0.8390693629151604, 0.3013098204357265, 0.18504617209107904`], 
             UndirectedEdge[41, 55] -> 
             RGBColor[
              0.9217511656674453, 0.9083191148939446, 0.6659672564832814], 
             UndirectedEdge[183, 272] -> 
             RGBColor[
              0.5454600938051113, 0.6375523889526532, 0.9591673986184688], 
             UndirectedEdge[131, 238] -> 
             RGBColor[
              0.2516193138752771, 0.38179823084181674`, 0.9376407197365557], 
             UndirectedEdge[13, 131] -> 
             RGBColor[
              0.21370957013719966`, 0.34195268655651806`, 0.9354818159131122],
              UndirectedEdge[55, 328] -> 
             RGBColor[
              0.9205810406494127, 0.7082097000834948, 0.27856954387058575`], 
             UndirectedEdge[40, 392] -> 
             RGBColor[
              0.7560719179586157, 0.8063199638581745, 0.8764325252109648], 
             UndirectedEdge[39, 347] -> 
             RGBColor[
              0.19051344323313968`, 0.3175720864609606, 0.9341608308015206], 
             UndirectedEdge[195, 362] -> 
             RGBColor[
              0.1955066853579723, 0.3228203005239958, 0.9344451885536901], 
             UndirectedEdge[46, 250] -> 
             RGBColor[
              0.22982046644249732`, 0.3588862600632101, 0.9363993076237638], 
             UndirectedEdge[22, 47] -> 
             RGBColor[
              0.4301895095994409, 0.5445652207348299, 0.9493133718661378], 
             UndirectedEdge[79, 100] -> 
             RGBColor[
              0.22059571881103596`, 0.3491904654197632, 0.9358739718929432], 
             UndirectedEdge[45, 148] -> 
             RGBColor[
              0.30939380782769543`, 0.44018999619208, 0.9410163102615399], 
             UndirectedEdge[65, 68] -> 
             RGBColor[
              0.2789862434779228, 0.41056260901775243`, 0.9391992258916821], 
             UndirectedEdge[86, 162] -> 
             RGBColor[
              0.3416757625403587, 0.46699709267346645`, 0.9431155381732708], 
             UndirectedEdge[3, 264] -> 
             RGBColor[
              0.652580274743898, 0.7275933060781521, 0.9666403041170564], 
             UndirectedEdge[55, 386] -> 
             RGBColor[
              0.8661959692237846, 0.8644995898414272, 0.6605413251423246], 
             UndirectedEdge[315, 362] -> 
             RGBColor[
              0.20400552952862408`, 0.3317531246051941, 0.9349291851562955], 
             UndirectedEdge[92, 182] -> 
             RGBColor[
              0.4229610876060558, 0.5395726978389508, 0.9485023279906137], 
             UndirectedEdge[202, 341] -> 
             RGBColor[
              0.2897972028384973, 0.4193840622352309, 0.9399079526486953], 
             UndirectedEdge[86, 125] -> 
             RGBColor[
              0.3362672755569396, 0.46131242993601224`, 0.9428075328407044], 
             UndirectedEdge[155, 353] -> 
             RGBColor[
              0.19855109199898685`, 0.3260201649302318, 0.9346185630080999], 
             UndirectedEdge[119, 235] -> 
             RGBColor[
              0.18696497458482364`, 0.31384242092567355`, 0.9339587507614879],
              UndirectedEdge[139, 204] -> 
             RGBColor[
              0.19084712474135193`, 0.31792280688272123`, 0.9341798334697757],
              UndirectedEdge[167, 174] -> 
             RGBColor[
              0.3271254190729118, 0.4577613290244936, 0.9420651203310438], 
             UndirectedEdge[218, 349] -> 
             RGBColor[
              0.19642311196174383`, 0.3237835229893623, 0.9344973776930432], 
             UndirectedEdge[362, 397] -> 
             RGBColor[
              0.20104421515641585`, 0.32864059544182767`, 0.9347605426836703],
              UndirectedEdge[70, 108] -> 
             RGBColor[
              0.2395346657598989, 0.3690964994616095, 0.9369525169040198], 
             UndirectedEdge[71, 157] -> 
             RGBColor[
              0.18316059011768585`, 0.3098437716388048, 0.933742096694167], 
             UndirectedEdge[186, 238] -> 
             RGBColor[
              0.24841689496046435`, 0.37843228551726205`, 0.9374583467169113],
              UndirectedEdge[51, 246] -> 
             RGBColor[
              0.6509116591793556, 0.7220840345127228, 0.9688949029118392], 
             UndirectedEdge[109, 305] -> 
             RGBColor[
              0.1817778659169268, 0.3083904408340291, 0.9336633525964908], 
             UndirectedEdge[125, 248] -> 
             RGBColor[
              0.2397553776330553, 0.3693284816342379, 0.936965086118682], 
             UndirectedEdge[106, 390] -> 
             RGBColor[
              0.24476481400135702`, 0.3745937168739334, 0.9372503661090598], 
             UndirectedEdge[1, 231] -> 
             RGBColor[
              0.1878698717924256, 0.3147935252646599, 0.9340102833187854], 
             UndirectedEdge[104, 399] -> 
             RGBColor[
              0.8727925927240603, 0.4468618057827464, 0.21280802197674387`], 
             UndirectedEdge[244, 366] -> 
             RGBColor[
              0.6745824127024198, 0.7409076895841773, 0.9539031392335773], 
             UndirectedEdge[64, 289] -> 
             RGBColor[
              0.18340551527321602`, 0.3101012035064188, 0.9337560448194401], 
             UndirectedEdge[160, 233] -> 
             RGBColor[
              0.7095149174779228, 0.7707139896565038, 0.9521005122991707], 
             UndirectedEdge[100, 302] -> 
             RGBColor[
              0.20076131207818187`, 0.3283432463695126, 0.9347444317718824], 
             UndirectedEdge[177, 337] -> 
             RGBColor[
              0.9444496695413749, 0.9543350995105044, 0.7916221237493946], 
             UndirectedEdge[124, 219] -> 
             RGBColor[
              0.32342751125618663`, 0.45455838713589725`, 0.9418294929148936],
              UndirectedEdge[2, 181] -> 
             RGBColor[
              0.1899547149925528, 0.3169848276546873, 0.9341290120547836], 
             UndirectedEdge[185, 198] -> 
             RGBColor[
              0.3764542800383526, 0.5004875090521163, 0.9452083117319626], 
             UndirectedEdge[11, 35] -> 
             RGBColor[
              0.27410810708868466`, 0.4051377894263376, 0.9389323194302751], 
             UndirectedEdge[5, 56] -> 
             RGBColor[
              0.3320449689742487, 0.4595901829717516, 0.9424676449298229], 
             UndirectedEdge[69, 107] -> 
             RGBColor[
              0.2952174792692931, 0.42393616514341426`, 0.9402585516481101], 
             UndirectedEdge[51, 350] -> 
             RGBColor[
              0.6877142166567092, 0.7483252059436304, 0.8485559789675121], 
             UndirectedEdge[226, 392] -> 
             RGBColor[
              0.7181621296927883, 0.7753237626808771, 0.8735087285822702], 
             UndirectedEdge[81, 292] -> 
             RGBColor[
              0.18697166352319156`, 0.31384945142400145`, 0.9339591316866327],
              UndirectedEdge[51, 272] -> 
             RGBColor[
              0.5612556230240568, 0.6512336824557214, 0.9601738757728618], 
             UndirectedEdge[10, 261] -> 
             RGBColor[
              0.24873551087533646`, 0.3787671710452084, 0.9374764914219134], 
             UndirectedEdge[132, 244] -> 
             RGBColor[
              0.656519419340629, 0.7252624326066381, 0.9527521812690418], 
             UndirectedEdge[53, 376] -> 
             RGBColor[
              0.20099948384788677`, 0.3285935800004348, 0.9347579953018235], 
             UndirectedEdge[242, 364] -> 
             RGBColor[
              0.8349752732346869, 0.2698408531100693, 0.18112566718944462`], 
             UndirectedEdge[29, 327] -> 
             RGBColor[
              0.18852270839333474`, 0.31547969792444663`, 0.934047461397422], 
             UndirectedEdge[328, 364] -> 
             RGBColor[
              0.8436039382637408, 0.3186655649666024, 0.18870327005536394`], 
             UndirectedEdge[257, 279] -> 
             RGBColor[
              0.4976692988631992, 0.5990761277778498, 0.9548872926096961], 
             UndirectedEdge[13, 322] -> 
             RGBColor[
              0.20703389947966117`, 0.33493613343347894`, 0.9351016463449351],
              UndirectedEdge[21, 24] -> 
             RGBColor[
              0.8919944774662327, 0.5241583098068742, 0.2395431849721498], 
             UndirectedEdge[56, 122] -> 
             RGBColor[
              0.48980661456960395`, 0.5947401579565226, 0.9535161872898672], 
             UndirectedEdge[87, 393] -> 
             RGBColor[
              0.1907711086239872, 0.3178429091236707, 0.9341755044643476], 
             UndirectedEdge[27, 74] -> 
             RGBColor[
              0.8420491439644571, 0.52817967821788, 0.5772900887047536], 
             UndirectedEdge[93, 288] -> 
             RGBColor[
              0.2698457094938153, 0.4009553282571281, 0.9386786860034955], 
             UndirectedEdge[125, 211] -> 
             RGBColor[
              0.24170072207493107`, 0.37137316198461084`, 0.9370758706067677],
              UndirectedEdge[265, 304] -> 
             RGBColor[
              0.18543662898340038`, 0.31223603279586976`, 0.9338717137404716],
              UndirectedEdge[195, 343] -> 
             RGBColor[
              0.19193458883998876`, 0.3190658005995948, 0.9342417629414341], 
             UndirectedEdge[199, 393] -> 
             RGBColor[
              0.1849265278957996, 0.3116998842105244, 0.9338426642381596], 
             UndirectedEdge[24, 208] -> 
             RGBColor[
              0.906901063221462, 0.5760810366232336, 0.4664786546523232], 
             UndirectedEdge[135, 386] -> 
             RGBColor[
              0.8778014359212141, 0.9022038387539937, 0.8283895042121832], 
             UndirectedEdge[32, 357] -> 
             RGBColor[
              0.9070663677553636, 0.6533133886521827, 0.2449458094698989], 
             UndirectedEdge[230, 233] -> 
             RGBColor[
              0.8885723351829689, 0.5532979785319709, 0.5591090860551002], 
             UndirectedEdge[46, 161] -> 
             RGBColor[
              0.20037426040526207`, 0.3279364305207805, 0.9347223897517012], 
             UndirectedEdge[114, 306] -> 
             RGBColor[
              0.2220014868268114, 0.35066801673518333`, 0.9359540283017942], 
             UndirectedEdge[233, 357] -> 
             RGBColor[
              0.9082534214695472, 0.7045754320376143, 0.5779557165097353], 
             UndirectedEdge[134, 395] -> 
             RGBColor[
              0.6498035533941702, 0.7237783527330339, 0.9675259002297822], 
             UndirectedEdge[108, 267] -> 
             RGBColor[
              0.2560701403937588, 0.38647633171144136`, 0.9378941877223754], 
             UndirectedEdge[217, 233] -> 
             RGBColor[
              0.9762379710154455, 0.9784153903456743, 0.7203221374649382], 
             UndirectedEdge[245, 400] -> 
             RGBColor[
              0.8345042681241085, 0.26622050143440795`, 0.18067463216363056`],
              UndirectedEdge[269, 392] -> 
             RGBColor[
              0.8673327084378479, 0.8950958861574181, 0.8862515356507488], 
             UndirectedEdge[232, 288] -> 
             RGBColor[
              0.30023200699341346`, 0.43289325353174246`, 0.9404091406935988],
              UndirectedEdge[260, 341] -> 
             RGBColor[
              0.2804084248139549, 0.4095158612485281, 0.93937327562965], 
             UndirectedEdge[47, 323] -> 
             RGBColor[
              0.4713973595467131, 0.580257389192397, 0.951939099626107], 
             UndirectedEdge[142, 377] -> 
             RGBColor[
              0.18361252498065594`, 0.31031878383411166`, 0.9337678337160353],
              UndirectedEdge[53, 117] -> 
             RGBColor[
              0.20926903428907379`, 0.33728540183390365`, 0.9352289339657456],
              UndirectedEdge[251, 308] -> 
             RGBColor[
              0.1958872147734443, 0.3232202610666153, 0.9344668591409584], 
             UndirectedEdge[85, 162] -> 
             RGBColor[
              0.2565370723370653, 0.38696710678905155`, 0.9379207788057828], 
             UndirectedEdge[249, 397] -> 
             RGBColor[
              0.26099988066146607`, 0.3916272530178875, 0.9381760476598446], 
             UndirectedEdge[262, 284] -> 
             RGBColor[
              0.24537509181412387`, 0.37523515754899955`, 0.9372851205276718],
              UndirectedEdge[307, 341] -> 
             RGBColor[
              0.3422947785820742, 0.4709002657971524, 0.9430316985052297], 
             UndirectedEdge[7, 387] -> 
             RGBColor[
              0.4913856837463006, 0.597841186558023, 0.9531378831854276], 
             UndirectedEdge[228, 368] -> 
             RGBColor[
              0.19438368850365684`, 0.3216399596279972, 0.9343812355441619], 
             UndirectedEdge[240, 399] -> 
             RGBColor[
              0.879132492911469, 0.49559305678514604`, 0.2188791175560995], 
             UndirectedEdge[105, 114] -> 
             RGBColor[
              0.22538318625918102`, 0.3542223972507317, 0.9361466110816916], 
             UndirectedEdge[78, 357] -> 
             RGBColor[
              0.8385190338854094, 0.29707975035734024`, 0.18451917639068158`],
              UndirectedEdge[359, 369] -> 
             RGBColor[
              0.18890080078567878`, 0.31587709700124245`, 0.9340689931998285],
              UndirectedEdge[48, 354] -> 
             RGBColor[
              0.22802037271409625`, 0.35699424742212627`, 0.9362967949489314],
              UndirectedEdge[280, 325] -> 
             RGBColor[
              0.2703375929737152, 0.4014723289817168, 0.9387066980399994], 
             UndirectedEdge[259, 262] -> 
             RGBColor[
              0.20019420515358305`, 0.3277471810351035, 0.934712135871486], 
             UndirectedEdge[120, 187] -> 
             RGBColor[
              0.47660974925846794`, 0.585472751295903, 0.952077636221743], 
             UndirectedEdge[70, 198] -> 
             RGBColor[
              0.2881120186842996, 0.4160342955793074, 0.9398697816662858], 
             UndirectedEdge[62, 235] -> 
             RGBColor[
              0.1963098901939031, 0.32366451973268695`, 0.9344909298808612], 
             UndirectedEdge[65, 176] -> 
             RGBColor[
              0.26080757186847375`, 0.39145567256187075`, 0.9381639774364586],
              UndirectedEdge[199, 342] -> 
             RGBColor[
              0.18510212262202141`, 0.31188444540113214`, 0.9338526640980489],
              UndirectedEdge[324, 390] -> 
             RGBColor[
              0.4479202761383373, 0.5532491979543472, 0.9512669003180385], 
             UndirectedEdge[226, 234] -> 
             RGBColor[
              0.6154815427973135, 0.6962991925345092, 0.964434228392668], 
             UndirectedEdge[47, 201] -> 
             RGBColor[
              0.7465737093465549, 0.8011421937069441, 0.9641963866302764], 
             UndirectedEdge[160, 264] -> 
             RGBColor[
              0.5914575736276367, 0.6779711437656651, 0.9618285011853527], 
             UndirectedEdge[277, 314] -> 
             RGBColor[
              0.22024480085065679`, 0.34882162839392095`, 0.9358539876342362],
              UndirectedEdge[4, 66] -> 
             RGBColor[
              0.22354481915991609`, 0.35229015687019793`, 0.9360419187950089],
              UndirectedEdge[23, 75] -> 
             RGBColor[0.255511442446525, 0.3858891047454028, 0.9378623707008],
              UndirectedEdge[287, 391] -> 
             RGBColor[
              0.18552964693238397`, 0.31233380055793014`, 0.9338770109750585],
              UndirectedEdge[45, 91] -> 
             RGBColor[
              0.38905361359871204`, 0.5081017700405416, 0.9463921022645131], 
             UndirectedEdge[175, 314] -> 
             RGBColor[
              0.25716282410855407`, 0.38762481157584006`, 0.9379564144434523],
              UndirectedEdge[195, 358] -> 
             RGBColor[
              0.1963120650172806, 0.3236668056099485, 0.9344910537338352], 
             UndirectedEdge[321, 341] -> 
             RGBColor[
              0.44529829620254, 0.5573731665864943, 0.9503530478730258], 
             UndirectedEdge[91, 148] -> 
             RGBColor[
              0.4136380232673186, 0.5316086524356322, 0.9478775665898638], 
             UndirectedEdge[115, 350] -> 
             RGBColor[
              0.9292292560607558, 0.7349117971309463, 0.4801575703138227], 
             UndirectedEdge[142, 277] -> 
             RGBColor[
              0.19515207298431664`, 0.32244758043556054`, 0.9344249939036124],
              UndirectedEdge[45, 66] -> 
             RGBColor[
              0.2495400971941441, 0.37961284227999426`, 0.9375223114224907], 
             UndirectedEdge[259, 335] -> 
             RGBColor[
              0.18286996403264408`, 0.3095383051966678, 0.9337255459685665], 
             UndirectedEdge[118, 173] -> 
             RGBColor[
              0.26068055800241224`, 0.3913221729354959, 0.9381567441846866], 
             UndirectedEdge[52, 128] -> 
             RGBColor[
              0.18698858591777334`, 0.3138672379336487, 0.9339600953919696], 
             UndirectedEdge[27, 225] -> 
             RGBColor[
              0.8528742555567694, 0.5368113283617635, 0.5783225975121196], 
             UndirectedEdge[302, 352] -> 
             RGBColor[
              0.21548876733628058`, 0.34382273562037, 0.9355831385615135], 
             UndirectedEdge[25, 242] -> 
             RGBColor[
              0.8347962131108371, 0.26846451853351216`, 0.18095419901262647`],
              UndirectedEdge[30, 224] -> 
             RGBColor[
              0.17977250803868983`, 0.30628268255696894`, 0.9335491504319864],
              UndirectedEdge[313, 361] -> 
             RGBColor[
              0.2180016041011253, 0.34646388638327474`, 0.9357262408978626], 
             UndirectedEdge[270, 310] -> 
             RGBColor[
              0.3193491673301014, 0.4483310995882432, 0.9416682954109477], 
             UndirectedEdge[72, 370] -> 
             RGBColor[
              0.18495091945082137`, 0.31172552128136616`, 0.9338440533011341],
              UndirectedEdge[283, 380] -> 
             RGBColor[
              0.2145522876760556, 0.34283843612123366`, 0.9355298074302612], 
             UndirectedEdge[34, 35] -> 
             RGBColor[
              0.24974982719833305`, 0.3798332818120472, 0.9375342552359615], 
             UndirectedEdge[25, 230] -> 
             RGBColor[
              0.8175286583222767, 0.13573852573788114`, 0.16441876904618735`],
              UndirectedEdge[191, 211] -> 
             RGBColor[
              0.2145566630341047, 0.342843034899957, 0.9355300566004294], 
             UndirectedEdge[17, 173] -> 
             RGBColor[
              0.25707808713188923`, 0.38753574764073073`, 0.9379515887979883],
              UndirectedEdge[40, 51] -> 
             RGBColor[
              0.4513189432678153, 0.5634921655168925, 0.9504868403154272], 
             UndirectedEdge[105, 202] -> 
             RGBColor[
              0.2264175602160962, 0.35530958986254624`, 0.9362055171483188], 
             UndirectedEdge[183, 309] -> 
             RGBColor[
              0.3237917248354433, 0.45384300724789295`, 0.9418904445081182], 
             UndirectedEdge[187, 261] -> 
             RGBColor[
              0.3474451829775207, 0.4708516166188276, 0.9435249988507737], 
             UndirectedEdge[190, 274] -> 
             RGBColor[
              0.7246489008143902, 0.7831056857849257, 0.9561147753018562], 
             UndirectedEdge[176, 354] -> 
             RGBColor[
              0.22476081103687653`, 0.35356824143122134`, 0.936111167733503], 
             UndirectedEdge[42, 148] -> 
             RGBColor[
              0.27524609124263133`, 0.40429858097089644`, 0.9390716483190401],
              UndirectedEdge[320, 380] -> 
             RGBColor[
              0.20795844756120663`, 0.3359078920869173, 0.9351542979904328], 
             UndirectedEdge[51, 222] -> 
             RGBColor[
              0.3069819930795281, 0.4332541041734357, 0.9410401002851541], 
             UndirectedEdge[122, 319] -> 
             RGBColor[
              0.5256622973684795, 0.6257953596771879, 0.9558012080947398], 
             UndirectedEdge[27, 78] -> 
             RGBColor[
              0.8204879075828598, 0.15848461230601768`, 0.16725254948011575`],
              UndirectedEdge[5, 178] -> 
             RGBColor[
              0.36206488822589933`, 0.4855919281825182, 0.9443804876389659], 
             UndirectedEdge[196, 336] -> 
             RGBColor[
              0.18504438325654066`, 0.31182375766712467`, 0.9338493759266024],
              UndirectedEdge[297, 318] -> 
             RGBColor[
              0.20065548392565413`, 0.32823201427131354`, 0.9347384050151546],
              UndirectedEdge[127, 235] -> 
             RGBColor[
              0.19315907110692182`, 0.32035280909880115`, 0.9343114953950769],
              UndirectedEdge[45, 203] -> 
             RGBColor[
              0.2552832201033739, 0.38564922859261863`, 0.9378493737759823], 
             UndirectedEdge[305, 370] -> 
             RGBColor[
              0.18466045373978385`, 0.311420223402476, 0.9338275117085959], 
             UndirectedEdge[122, 169] -> 
             RGBColor[
              0.7468757612194565, 0.8021168965628588, 0.9757076451280708], 
             UndirectedEdge[51, 226] -> 
             RGBColor[
              0.41340915500198794`, 0.532495964339595, 0.9475630436867326], 
             UndirectedEdge[226, 395] -> 
             RGBColor[
              0.45693963376297164`, 0.5697838781949226, 0.9504517090480242], 
             UndirectedEdge[61, 354] -> 
             RGBColor[
              0.21260864100273835`, 0.3407955402332605, 0.9354191196275834], 
             UndirectedEdge[211, 334] -> 
             RGBColor[
              0.20343525046697647`, 0.3311537251536216, 0.9348967086073869], 
             UndirectedEdge[10, 361] -> 
             RGBColor[
              0.22756848714061534`, 0.35651928703319763`, 0.9362710607340264],
              UndirectedEdge[44, 249] -> 
             RGBColor[
              0.27287548484168234`, 0.4041092659680885, 0.9388523457495259], 
             UndirectedEdge[302, 377] -> 
             RGBColor[
              0.18805566555367964`, 0.3149888062877428, 0.9340208639986316], 
             UndirectedEdge[149, 363] -> 
             RGBColor[
              0.21825217126115545`, 0.34672724835534197`, 0.9357405103269454],
              UndirectedEdge[358, 359] -> 
             RGBColor[
              0.18898988195831087`, 0.3159707269617513, 0.934074066240826], 
             UndirectedEdge[126, 317] -> 
             RGBColor[
              0.1909701324562666, 0.31805209579023613`, 0.9341868385771666], 
             UndirectedEdge[194, 364] -> 
             RGBColor[
              0.9061043939482173, 0.5637958920619978, 0.4053724452164604], 
             UndirectedEdge[184, 343] -> 
             RGBColor[
              0.18256566753029357`, 0.30921847027918486`, 0.933708216732924], 
             UndirectedEdge[118, 346] -> 
             RGBColor[
              0.2949738551719156, 0.42345379048504006`, 0.9402529639443298], 
             UndirectedEdge[169, 239] -> 
             RGBColor[
              0.8617758088916869, 0.5670725642786435, 0.5820707130728167], 
             UndirectedEdge[72, 157] -> 
             RGBColor[
              0.1851041505972344, 0.3118865769316621, 0.9338527795882372], 
             UndirectedEdge[162, 191] -> 
             RGBColor[
              0.239776323432642, 0.3693504969976439, 0.936966278950982], 
             UndirectedEdge[84, 272] -> 
             RGBColor[
              0.5398855520007457, 0.6327240010263296, 0.9588121937440683], 
             UndirectedEdge[21, 160] -> 
             RGBColor[
              0.7114127926044326, 0.7298581356264684, 0.631074971265499], 
             UndirectedEdge[29, 336] -> 
             RGBColor[
              0.18089581060751259`, 0.30746334477829806`, 0.9336131208515035],
              UndirectedEdge[275, 276] -> 
             RGBColor[
              0.2308037275414878, 0.35991972982060355`, 0.9364553028887468], 
             UndirectedEdge[38, 303] -> 
             RGBColor[
              0.21808265414273661`, 0.3465490751158777, 0.9357308565778295], 
             UndirectedEdge[172, 285] -> 
             RGBColor[
              0.9090011322761398, 0.5869841292419617, 0.39020330546201376`], 
             UndirectedEdge[73, 285] -> 
             RGBColor[
              0.9624071777351879, 0.8763102692580285, 0.43650448397981056`], 
             UndirectedEdge[5, 59] -> 
             RGBColor[
              0.31447583347960173`, 0.4443726808567142, 0.9413481551518805], 
             UndirectedEdge[73, 225] -> 
             RGBColor[
              0.9076627958063523, 0.836763929150959, 0.6259476546026368], 
             UndirectedEdge[64, 254] -> 
             RGBColor[
              0.1839453796797469, 0.3106686352270631, 0.9337867892987342], 
             UndirectedEdge[241, 390] -> 
             RGBColor[
              0.2629620790942533, 0.393720196259813, 0.938286673435659], 
             UndirectedEdge[58, 289] -> 
             RGBColor[
              0.19906319498854463`, 0.3265584176414619, 0.9346477265157667], 
             UndirectedEdge[262, 331] -> 
             RGBColor[
              0.20664951421908523`, 0.3345321201531805, 0.9350797561729924], 
             UndirectedEdge[22, 118] -> 
             RGBColor[
              0.2775783272389005, 0.4083866585141185, 0.9391445362866995], 
             UndirectedEdge[97, 360] -> 
             RGBColor[
              0.189069412661027, 0.31605431877284385`, 0.9340785953966906], 
             UndirectedEdge[301, 358] -> 
             RGBColor[
              0.18673627600332035`, 0.31360204421618604`, 0.9339457267156006],
              UndirectedEdge[16, 274] -> 
             RGBColor[
              0.4054269963890745, 0.5245026293096915, 0.9473527216519175], 
             UndirectedEdge[166, 319] -> 
             RGBColor[
              0.7215283330281927, 0.7785525624499918, 0.8852776399757938], 
             UndirectedEdge[82, 101] -> 
             RGBColor[
              0.181913405203708, 0.30853290121812327`, 0.9336710713583607], 
             UndirectedEdge[24, 399] -> 
             RGBColor[
              0.8736814566563863, 0.4536940034692628, 0.2136591990821675], 
             UndirectedEdge[328, 400] -> 
             RGBColor[
              0.8598546185049423, 0.443575414393966, 0.20426493980685678`], 
             UndirectedEdge[17, 371] -> 
             RGBColor[
              0.20911196002482746`, 0.33712030682309724`, 0.9352199888187673],
              UndirectedEdge[107, 158] -> 
             RGBColor[
              0.34368740964077826`, 0.4721064928245296, 0.9431204357248351], 
             UndirectedEdge[60, 394] -> 
             RGBColor[
              0.18321858514836378`, 0.3099047280931446, 0.933745399425368], 
             UndirectedEdge[219, 284] -> 
             RGBColor[
              0.3068620452246301, 0.43723797575946177`, 0.9408827842352088], 
             UndirectedEdge[124, 149] -> 
             RGBColor[
              0.2631665511656537, 0.3938441656371931, 0.9383016477132344], 
             UndirectedEdge[227, 296] -> 
             RGBColor[
              0.22621507415997788`, 0.35509676417920844`, 0.9361939858669741],
              UndirectedEdge[202, 229] -> 
             RGBColor[
              0.22512118954774685`, 0.35394702209546336`, 0.9361316907565649],
              UndirectedEdge[315, 358] -> 
             RGBColor[
              0.20481090918793238`, 0.33259962969114687`, 0.9349750503364407],
              UndirectedEdge[145, 222] -> 
             RGBColor[
              0.21482177415136725`, 0.3431216834932156, 0.9355451542863606], 
             UndirectedEdge[155, 299] -> 
             RGBColor[
              0.19737174909206562`, 0.3247806007603985, 0.9345514011742322], 
             UndirectedEdge[14, 29] -> 
             RGBColor[
              0.18299367418147944`, 0.3096683324067703, 0.9337325910785299], 
             UndirectedEdge[116, 151] -> 
             RGBColor[
              0.18767873323802545`, 0.31459262652510106`, 0.9339993982608765],
              UndirectedEdge[45, 257] -> 
             RGBColor[
              0.30395689687858984`, 0.4354808171950546, 0.9406698751035344], 
             UndirectedEdge[27, 240] -> 
             RGBColor[
              0.8263635800404189, 0.20364760555090494`, 0.1728791000610972], 
             UndirectedEdge[144, 188] -> 
             RGBColor[
              0.19616736828116454`, 0.3235147201659876, 0.934482813468773], 
             UndirectedEdge[76, 200] -> 
             RGBColor[
              0.1890554468047247, 0.31603963977238364`, 0.9340778000618348], 
             UndirectedEdge[90, 221] -> 
             RGBColor[
              0.755343522572024, 0.6711176068414135, 0.6012544985481333], 
             UndirectedEdge[271, 382] -> 
             RGBColor[
              0.18049565541513857`, 0.3070427562998084, 0.9335903326052744], 
             UndirectedEdge[242, 385] -> 
             RGBColor[
              0.9233493722002852, 0.696643340637751, 0.416149434312738], 
             UndirectedEdge[74, 112] -> 
             RGBColor[
              0.9000839613583336, 0.841002686126469, 0.6275271765854877], 
             UndirectedEdge[237, 251] -> 
             RGBColor[
              0.19380336074719554`, 0.32102999836105145`, 0.9343481867369493],
              UndirectedEdge[25, 223] -> 
             RGBColor[
              0.8736105747823911, 0.4469597061439798, 0.21333691400652116`], 
             UndirectedEdge[284, 332] -> 
             RGBColor[
              0.2524716906122939, 0.382694132836228, 0.9376892613307504], 
             UndirectedEdge[145, 333] -> 
             RGBColor[
              0.19268508450271393`, 0.3198546191252922, 0.9342845025591675], 
             UndirectedEdge[146, 227] -> 
             RGBColor[
              0.19680598858419968`, 0.3241859505953433, 0.934519181950277], 
             UndirectedEdge[108, 286] -> 
             RGBColor[
              0.22549943873113315`, 0.3543445859695858, 0.9361532314879892], 
             UndirectedEdge[127, 361] -> 
             RGBColor[
              0.2062200768333135, 0.33408075423283157`, 0.9350553003491684], 
             UndirectedEdge[143, 258] -> 
             RGBColor[
              0.1842254727690224, 0.31096303082281923`, 0.9338027401858078], 
             UndirectedEdge[212, 310] -> 
             RGBColor[
              0.34846775564587945`, 0.473552157244567, 0.9435237061098725], 
             UndirectedEdge[107, 310] -> 
             RGBColor[
              0.3141088853648525, 0.4437922307341744, 0.9413343892779213], 
             UndirectedEdge[253, 394] -> 
             RGBColor[
              0.1857625991924869, 0.31257864815332465`, 0.9338902772616493], 
             UndirectedEdge[152, 284] -> 
             RGBColor[
              0.26668400229217915`, 0.3976321735243937, 0.9384986314556889], 
             UndirectedEdge[230, 364] -> 
             RGBColor[
              0.8177077184461266, 0.13711486031443826`, 0.16459023722300553`],
              UndirectedEdge[158, 241] -> 
             RGBColor[
              0.3009846875478195, 0.43090972620672763`, 0.9405535979845862], 
             UndirectedEdge[44, 315] -> 
             RGBColor[
              0.22776027402374388`, 0.3567208672073564, 0.9362819827132973], 
             UndirectedEdge[357, 385] -> 
             RGBColor[
              0.9257629036983032, 0.7151948013477634, 0.418460634800934], 
             UndirectedEdge[99, 197] -> 
             RGBColor[
              0.9649742133445314, 0.9733984061785892, 0.9441737000062027], 
             UndirectedEdge[152, 267] -> 
             RGBColor[
              0.25637803396755154`, 0.3867999473790775, 0.9379117218059152], 
             UndirectedEdge[169, 197] -> 
             RGBColor[
              0.9300501065256308, 0.9463228877887528, 0.9676089006734437], 
             UndirectedEdge[263, 348] -> 
             RGBColor[
              0.36254614474277536`, 0.48844098130229274`, 0.9443220976494096],
              UndirectedEdge[314, 379] -> 
             RGBColor[
              0.21988806256935944`, 0.348446673841764, 0.9358336719168633], 
             UndirectedEdge[300, 319] -> 
             RGBColor[
              0.6840306200166372, 0.7509595396670409, 0.9709177458785374], 
             UndirectedEdge[25, 78] -> 
             RGBColor[
              0.8186282892765544, 0.1441907711138157, 0.16547177688985915`], 
             UndirectedEdge[44, 113] -> 
             RGBColor[
              0.27210008577250266`, 0.4033248206617401, 0.9388070693975159], 
             UndirectedEdge[115, 221] -> 
             RGBColor[
              0.8834582095203258, 0.5636927731060549, 0.2244670121341203], 
             UndirectedEdge[175, 319] -> 
             RGBColor[
              0.3675065660796395, 0.49023117564208835`, 0.944730223137449], 
             UndirectedEdge[176, 356] -> 
             RGBColor[
              0.21433034444536764`, 0.34260515971376704`, 0.9355171680916091],
              UndirectedEdge[84, 395] -> 
             RGBColor[
              0.4037383718237736, 0.5237036190763635, 0.9470617716812872], 
             UndirectedEdge[301, 359] -> 
             RGBColor[
              0.1849503238015024, 0.31172489521616553`, 0.9338440193797866], 
             UndirectedEdge[238, 280] -> 
             RGBColor[
              0.2707591220181621, 0.40191538273391547`, 0.9387307034954844], 
             UndirectedEdge[36, 168] -> 
             RGBColor[
              0.18854146293925098`, 0.3154994101413115, 0.9340485294410671], 
             UndirectedEdge[4, 232] -> 
             RGBColor[
              0.26395583592624494`, 0.3947646976980586, 0.9383432664171094], 
             UndirectedEdge[140, 339] -> 
             RGBColor[
              0.2386234653452058, 0.3681387700523239, 0.9369006253884031], 
             UndirectedEdge[18, 141] -> 
             RGBColor[
              0.7353689115489879, 0.586455396789142, 0.5858108169853278], 
             UndirectedEdge[123, 140] -> 
             RGBColor[
              0.21869849237699107`, 0.3471963601464784, 0.9357659276542193], 
             UndirectedEdge[24, 78] -> 
             RGBColor[
              0.8203622147555851, 0.15751848215663547`, 0.1671321858867677], 
             UndirectedEdge[62, 127] -> 
             RGBColor[
              0.1979549784065447, 0.32539361174879033`, 0.9345846152208812], 
             UndirectedEdge[299, 353] -> 
             RGBColor[
              0.188841530987085, 0.3158148006849981, 0.9340656178724803], 
             UndirectedEdge[256, 311] -> 
             RGBColor[
              0.32702639881790146`, 0.45712063802367703`, 0.942079129357128], 
             UndirectedEdge[47, 346] -> 
             RGBColor[
              0.44758503753245593`, 0.5596323527057516, 0.9504217995237683], 
             UndirectedEdge[34, 125] -> 
             RGBColor[
              0.2623800078372861, 0.3931084024632914, 0.9382535253386719], 
             UndirectedEdge[194, 387] -> 
             RGBColor[
              0.7643288542489235, 0.8116893614464729, 0.8013257295322668], 
             UndirectedEdge[117, 303] -> 
             RGBColor[
              0.21968824533158482`, 0.34823665325571823`, 0.9358222926207751],
              UndirectedEdge[287, 382] -> 
             RGBColor[
              0.18591195141547964`, 0.3127356268091679, 0.933898782649802], 
             UndirectedEdge[20, 168] -> 
             RGBColor[
              0.18724662483160132`, 0.31413845319269396`, 0.9339747903263778],
              UndirectedEdge[51, 355] -> 
             RGBColor[
              0.5736425498293158, 0.6609104438201203, 0.9614084888743977], 
             UndirectedEdge[183, 339] -> 
             RGBColor[
              0.30076734139659483`, 0.42964292042343744`, 0.9405792399327987],
              UndirectedEdge[118, 164] -> 
             RGBColor[
              0.21991695118991147`, 0.3484770376136085, 0.9358353170810669], 
             UndirectedEdge[51, 134] -> 
             RGBColor[
              0.6062730746331866, 0.6864904388777064, 0.9646372348684907], 
             UndirectedEdge[46, 356] -> 
             RGBColor[
              0.1981426064801053, 0.32559082075040946`, 0.9345953003620997], 
             UndirectedEdge[204, 276] -> 
             RGBColor[
              0.2082458481435212, 0.33620996832117933`, 0.9351706650284246], 
             UndirectedEdge[108, 154] -> 
             RGBColor[
              0.23083302352450608`, 0.3599505217562283, 0.9364569712516402], 
             UndirectedEdge[29, 119] -> 
             RGBColor[
              0.18192714786076558`, 0.30854734562202557`, 0.9336718539823496],
              UndirectedEdge[244, 264] -> 
             RGBColor[
              0.8390285444461558, 0.8747724603828321, 0.9672545655941249], 
             UndirectedEdge[217, 321] -> 
             RGBColor[
              0.7737155651854934, 0.8183397872541874, 0.7225530793389106], 
             UndirectedEdge[241, 346] -> 
             RGBColor[
              0.30713982911114474`, 0.4362410004624697, 0.9409457981622233], 
             UndirectedEdge[108, 284] -> 
             RGBColor[
              0.26637610871838646`, 0.39730855785675745`, 0.9384810973721491],
              UndirectedEdge[181, 334] -> 
             RGBColor[
              0.18995231521735206`, 0.3169823053387968, 0.934128875391136], 
             UndirectedEdge[8, 59] -> 
             RGBColor[
              0.2921622006654197, 0.4209196380029755, 0.9400774267731745], 
             UndirectedEdge[236, 383] -> 
             RGBColor[
              0.22956462143722656`, 0.3586173507411603, 0.9363847376292023], 
             UndirectedEdge[42, 290] -> 
             RGBColor[
              0.20736560396252507`, 0.33528477587624783`, 0.9351205364245214],
              UndirectedEdge[173, 209] -> 
             RGBColor[
              0.3086611648699239, 0.43934003290171275`, 0.940977513192154], 
             UndirectedEdge[154, 332] -> 
             RGBColor[
              0.2169286054184135, 0.3453360967356988, 0.9356651352102414], 
             UndirectedEdge[5, 352] -> 
             RGBColor[
              0.26102097459574697`, 0.3916799723587493, 0.9381761304060758], 
             UndirectedEdge[189, 226] -> 
             RGBColor[
              0.35594179006458193`, 0.47882793285764735`, 0.9440438043992346],
              UndirectedEdge[16, 390] -> 
             RGBColor[
              0.2902432136013212, 0.4215595588222458, 0.9398708612517093], 
             UndirectedEdge[119, 327] -> 
             RGBColor[
              0.18901152680793626`, 0.3159934770710704, 0.9340752988829915], 
             UndirectedEdge[129, 231] -> 
             RGBColor[
              0.18564063577461087`, 0.3124504568682096, 0.93388333162543], 
             UndirectedEdge[79, 352] -> 
             RGBColor[
              0.23532317406913467`, 0.3646699546706205, 0.9367126786825744], 
             UndirectedEdge[62, 361] -> 
             RGBColor[
              0.20937089592029476`, 0.33739246486671737`, 0.9352347348349528],
              UndirectedEdge[150, 347] -> 
             RGBColor[
              0.19569856946522865`, 0.3230219828868772, 0.9344561160697312], 
             UndirectedEdge[5, 90] -> 
             RGBColor[
              0.44540909938288953`, 0.5535702341777979, 0.950854414653335], 
             UndirectedEdge[24, 27] -> 
             RGBColor[
              0.8209125437853362, 0.16174855223502174`, 0.16765918158716517`],
              UndirectedEdge[62, 393] -> 
             RGBColor[
              0.19223452494535048`, 0.31938105246337734`, 0.9342588438589188],
              UndirectedEdge[199, 353] -> 
             RGBColor[
              0.18825533864421526`, 0.31519867536590085`, 0.9340322350857477],
              UndirectedEdge[96, 201] -> 
             RGBColor[
              0.8486214444306401, 0.8823678065342169, 0.9733384742305298], 
             UndirectedEdge[155, 170] -> 
             RGBColor[
              0.21937286170598153`, 0.34790516506873237`, 0.9358043319898652],
              UndirectedEdge[335, 394] -> 
             RGBColor[
              0.17996762986719622`, 0.30648776797016763`, 0.9335602623314629],
              UndirectedEdge[16, 310] -> 
             RGBColor[
              0.2986872977789616, 0.43043482667880517`, 0.9403517393537228], 
             UndirectedEdge[6, 277] -> 
             RGBColor[
              0.2567019144406389, 0.38714036629150045`, 0.9379301663197194], 
             UndirectedEdge[140, 232] -> 
             RGBColor[
              0.2603959916536444, 0.39102307566039235`, 0.9381405385521024], 
             UndirectedEdge[177, 300] -> 
             RGBColor[
              0.904775992937191, 0.9269078335507821, 0.990779535981055], 
             UndirectedEdge[24, 32] -> 
             RGBColor[
              0.8889095486255394, 0.5137521204514779, 0.227558818965985], 
             UndirectedEdge[102, 226] -> 
             RGBColor[
              0.3613558703292786, 0.48451847448835883`, 0.9443521282608951], 
             UndirectedEdge[187, 206] -> 
             RGBColor[
              0.5826167692195937, 0.6701866792756657, 0.9613440852325792], 
             UndirectedEdge[336, 396] -> 
             RGBColor[
              0.18995557631013382`, 0.31698573295407556`, 0.9341290611055455],
              UndirectedEdge[267, 332] -> 
             RGBColor[
              0.24216572228766625`, 0.37186190669091185`, 0.9371023516809767],
              UndirectedEdge[115, 300] -> 
             RGBColor[
              0.8896537545747043, 0.7064595554170632, 0.6002320083831638], 
             UndirectedEdge[149, 195] -> 
             RGBColor[
              0.20922588183301488`, 0.33724004586656203`, 0.9352264764972114],
              UndirectedEdge[127, 396] -> 
             RGBColor[
              0.197181010085485, 0.3245801219709307, 0.9345405388699805], 
             UndirectedEdge[206, 220] -> 
             RGBColor[
              0.6830678662474279, 0.7522369451466808, 0.9691139391554754], 
             UndirectedEdge[298, 361] -> 
             RGBColor[
              0.2073168336633886, 0.33523351519963984`, 0.9351177590281349], 
             UndirectedEdge[27, 141] -> 
             RGBColor[
              0.8433178856733501, 0.32265315137636846`, 0.18867158623389835`],
              UndirectedEdge[55, 221] -> 
             RGBColor[
              0.9369698505827507, 0.7826274582869746, 0.292244768605455], 
             UndirectedEdge[40, 269] -> 
             RGBColor[
              0.6323207129287618, 0.7108348666826005, 0.9652579027218493], 
             UndirectedEdge[191, 312] -> 
             RGBColor[
              0.25506639270437426`, 0.3854213292486189, 0.9378370257763766], 
             UndirectedEdge[78, 240] -> 
             RGBColor[
              0.8258132510106677, 0.19941753547251867`, 0.17235210436069973`],
              UndirectedEdge[183, 246] -> 
             RGBColor[
              0.63511612996041, 0.7084027410096546, 0.967888425757446], 
             UndirectedEdge[130, 164] -> 
             RGBColor[
              0.19148238974395732`, 0.318590510678587, 0.9342160108718838], 
             UndirectedEdge[190, 295] -> 
             RGBColor[
              0.6926270864337125, 0.7564495900659256, 0.953776079551644], 
             UndirectedEdge[18, 179] -> 
             RGBColor[
              0.5295441815391476, 0.6289468481238254, 0.9561068042364651], 
             UndirectedEdge[128, 199] -> 
             RGBColor[
              0.1905507884017967, 0.3176113386010396, 0.9341629575536283], 
             UndirectedEdge[350, 355] -> 
             RGBColor[
              0.879778802399924, 0.9043102631133229, 0.8644296794931206], 
             UndirectedEdge[233, 348] -> 
             RGBColor[
              0.6462730001834412, 0.7161082281260901, 0.948023487805811], 
             UndirectedEdge[247, 316] -> 
             RGBColor[
              0.21599089502507074`, 0.3443505036580227, 0.9356117339905587], 
             UndirectedEdge[74, 399] -> 
             RGBColor[
              0.8948180568355072, 0.820125129452121, 0.6232901061997559], 
             UndirectedEdge[155, 171] -> 
             RGBColor[
              0.19802203394015824`, 0.32546409136618454`, 0.9345884339343208],
              UndirectedEdge[21, 95] -> 
             RGBColor[
              0.7613060096832925, 0.7703636969149021, 0.6350027480788232], 
             UndirectedEdge[257, 325] -> 
             RGBColor[
              0.30612175947263687`, 0.43775622504161427`, 0.9407931608256381],
              UndirectedEdge[250, 372] -> 
             RGBColor[
              0.22620791914637717`, 0.35508924380626006`, 0.9361935783995345],
              UndirectedEdge[156, 400] -> 
             RGBColor[
              0.8405821739101607, 0.3129379486613033, 0.18649484160836693`], 
             UndirectedEdge[193, 360] -> 
             RGBColor[
              0.18609708652812662`, 0.31293021555080397`, 0.9339093258205844],
              UndirectedEdge[92, 135] -> 
             RGBColor[
              0.746116355711272, 0.7971097200029147, 0.816782693533676], 
             UndirectedEdge[102, 174] -> 
             RGBColor[
              0.3107339262181662, 0.44067229083220405`, 0.9411265427453626], 
             UndirectedEdge[140, 275] -> 
             RGBColor[
              0.23222474174375346`, 0.36141330584468895`, 0.9365362275453637],
              UndirectedEdge[101, 301] -> 
             RGBColor[
              0.1828984857165501, 0.3095682832948322, 0.9337271702362709], 
             UndirectedEdge[337, 398] -> 
             RGBColor[
              0.7100705314017086, 0.7665791120076357, 0.7708912737801167], 
             UndirectedEdge[149, 249] -> 
             RGBColor[
              0.2628399368216051, 0.3935612687084925, 0.9382808361360453], 
             UndirectedEdge[92, 165] -> 
             RGBColor[
              0.6970699985324673, 0.761675381939551, 0.9717947555325273], 
             UndirectedEdge[150, 320] -> 
             RGBColor[
              0.19466927104284892`, 0.32194012498366686`, 0.9343974990472872],
              UndirectedEdge[59, 175] -> 
             RGBColor[
              0.314081747786117, 0.4439584718063857, 0.9413257125546342], 
             UndirectedEdge[278, 379] -> 
             RGBColor[
              0.232633859519395, 0.36184331456645336`, 0.936559526197451], 
             UndirectedEdge[87, 317] -> 
             RGBColor[
              0.19676650353045996`, 0.3241444493003659, 0.9345169333348793], 
             UndirectedEdge[212, 324] -> 
             RGBColor[
              0.5252330264468776, 0.6244698739960914, 0.9560373579630563], 
             UndirectedEdge[135, 328] -> 
             RGBColor[
              0.932186507346842, 0.7459139489960613, 0.44641772294044424`], 
             UndirectedEdge[176, 344] -> 
             RGBColor[
              0.21245918803275743`, 0.3406384556859449, 0.9354106085020388], 
             UndirectedEdge[59, 213] -> 
             RGBColor[
              0.2845653105942021, 0.4129348248674753, 0.9396447951222104], 
             UndirectedEdge[371, 391] -> 
             RGBColor[
              0.18383722908563283`, 0.3105549620955055, 0.9337806302823939], 
             UndirectedEdge[98, 318] -> 
             RGBColor[
              0.1977029240139366, 0.3251286866009877, 0.9345702610961033], 
             UndirectedEdge[25, 244] -> 
             RGBColor[
              0.8860422114357496, 0.549955853479581, 0.56283625969903], 
             UndirectedEdge[204, 224] -> 
             RGBColor[
              0.1864844568543232, 0.3133373663243338, 0.9339313859875982], 
             UndirectedEdge[180, 236] -> 
             RGBColor[
              0.2546593406268537, 0.3849934917065525, 0.9378138447627414], 
             UndirectedEdge[102, 163] -> 
             RGBColor[
              0.272133057471457, 0.4033594760078676, 0.938808947086994], 
             UndirectedEdge[16, 107] -> 
             RGBColor[
              0.33319709362883454`, 0.4630203083535974, 0.9424520020647762], 
             UndirectedEdge[194, 223] -> 
             RGBColor[
              0.9622169086067585, 0.8752522636294204, 0.4543198910461633], 
             UndirectedEdge[111, 291] -> 
             RGBColor[
              0.18821279065920096`, 0.31515395473595276`, 0.9340298120409453],
              UndirectedEdge[108, 205] -> 
             RGBColor[
              0.3030856171044626, 0.43207672625167026`, 0.9407113666179867], 
             UndirectedEdge[66, 297] -> 
             RGBColor[
              0.21059566017891732`, 0.33867976975706876`, 0.935304483347605], 
             UndirectedEdge[19, 284] -> 
             RGBColor[
              0.2685014480461575, 0.3995424242445413, 0.938602132302708], 
             UndirectedEdge[23, 260] -> 
             RGBColor[
              0.2588190028871956, 0.3893655604799919, 0.938050731374799], 
             UndirectedEdge[10, 256] -> 
             RGBColor[
              0.29440488188335295`, 0.4228333554018322, 0.9402213822269152], 
             UndirectedEdge[230, 242] -> 
             RGBColor[
              0.8350058714331137, 0.2700760442713933, 0.18115496805881381`], 
             UndirectedEdge[29, 317] -> 
             RGBColor[
              0.1883961858281423, 0.3153467146864354, 0.9340402561245076], 
             UndirectedEdge[124, 316] -> 
             RGBColor[
              0.27204171641094554`, 0.40317252702797246`, 0.9388070752443234],
              UndirectedEdge[306, 361] -> 
             RGBColor[
              0.21017418029056079`, 0.33823676767103766`, 0.9352804806914867],
              UndirectedEdge[1, 393] -> 
             RGBColor[
              0.1884550205876297, 0.3154085537489959, 0.9340436066770222], 
             UndirectedEdge[74, 279] -> 
             RGBColor[
              0.7676471267223055, 0.8187592045069678, 0.9773831565887533], 
             UndirectedEdge[40, 234] -> 
             RGBColor[
              0.653391331063141, 0.7272953937118065, 0.9673580250213626], 
             UndirectedEdge[195, 316] -> 
             RGBColor[
              0.21810104707830674`, 0.3465684072573414, 0.9357319040283003], 
             UndirectedEdge[279, 325] -> 
             RGBColor[
              0.4806866627377453, 0.5825538322263442, 0.9538715491644547], 
             UndirectedEdge[172, 337] -> 
             RGBColor[
              0.9089250228286312, 0.5868213388295864, 0.3819192617937752], 
             UndirectedEdge[148, 275] -> 
             RGBColor[
              0.28636427371918854`, 0.4159844956872421, 0.939704812363203], 
             UndirectedEdge[13, 188] -> 
             RGBColor[
              0.20797364918202638`, 0.3359238699542373, 0.9351551637002498], 
             UndirectedEdge[220, 233] -> 
             RGBColor[
              0.7976144359577942, 0.8422371475965424, 0.9590360291130758], 
             UndirectedEdge[230, 244] -> 
             RGBColor[
              0.8862518697580262, 0.551567379217462, 0.5630370287452173], 
             UndirectedEdge[253, 358] -> 
             RGBColor[
              0.19093438586024153`, 0.31801452385134865`, 0.9341848028614053],
              UndirectedEdge[66, 140] -> 
             RGBColor[
              0.21998497488731555`, 0.3485485348325317, 0.9358391909300019], 
             UndirectedEdge[89, 128] -> 
             RGBColor[
              0.1919283928758168, 0.31905928824840313`, 0.9342414100904406], 
             UndirectedEdge[199, 298] -> 
             RGBColor[
              0.19174373818706897`, 0.31886520446274574`, 0.9342308942790887],
              UndirectedEdge[367, 398] -> 
             RGBColor[
              0.40058820107881166`, 0.5213910984512207, 0.9467461038398723], 
             UndirectedEdge[72, 181] -> 
             RGBColor[
              0.1888688995598306, 0.3158435667902215, 0.9340671764722099], 
             UndirectedEdge[229, 329] -> 
             RGBColor[
              0.1986631863683978, 0.3261379832196762, 0.934624946616609], 
             UndirectedEdge[196, 326] -> 
             RGBColor[
              0.19087356510240117`, 0.3179505973785997, 0.9341813392092224], 
             UndirectedEdge[247, 362] -> 
             RGBColor[
              0.19339653330473627`, 0.32060239692467707`, 0.9343250185159485],
              UndirectedEdge[276, 297] -> 
             RGBColor[
              0.21488882463476794`, 0.3431921578025159, 0.9355489727121981], 
             UndirectedEdge[7, 201] -> 
             RGBColor[
              0.698844545732584, 0.7622666344739716, 0.960474027707296], 
             UndirectedEdge[191, 214] -> 
             RGBColor[
              0.2234844168401749, 0.3522266702024217, 0.9360384789722569], 
             UndirectedEdge[25, 32] -> 
             RGBColor[
              0.8871756231465087, 0.5004244094086581, 0.22589840996907645`], 
             UndirectedEdge[190, 324] -> 
             RGBColor[
              0.7946744730052755, 0.8399555999055638, 0.9616274448568455], 
             UndirectedEdge[8, 296] -> 
             RGBColor[
              0.241386411848991, 0.3710428020087285, 0.9370579711043807], 
             UndirectedEdge[292, 382] -> 
             RGBColor[
              0.1881384932660469, 0.31507586346502103`, 0.9340255809143183], 
             UndirectedEdge[223, 328] -> 
             RGBColor[
              0.8997164529222819, 0.6301219365340252, 0.23765071588506692`], 
             UndirectedEdge[70, 262] -> 
             RGBColor[
              0.2185336488556363, 0.3470230991538516, 0.9357565400595423], 
             UndirectedEdge[78, 285] -> 
             RGBColor[
              0.907068308455854, 0.5721275983904466, 0.38835243118889584`], 
             UndirectedEdge[167, 272] -> 
             RGBColor[
              0.5255938312060932, 0.6203452307967748, 0.9579015379327056], 
             UndirectedEdge[93, 276] -> 
             RGBColor[
              0.22858867995178067`, 0.3575915743616926, 0.9363291592053822], 
             UndirectedEdge[56, 319] -> 
             RGBColor[
              0.4175060909791842, 0.5360433358043497, 0.9478244252272849], 
             UndirectedEdge[93, 162] -> 
             RGBColor[
              0.2533245521097741, 0.3835905443446218, 0.9377378305313364], 
             UndirectedEdge[106, 389] -> 
             RGBColor[
              0.21473367973065993`, 0.34302909067154336`, 0.9355401374394254],
              UndirectedEdge[68, 176] -> 
             RGBColor[
              0.2518475893962128, 0.38203816288782416`, 0.9376537196897696], 
             UndirectedEdge[253, 301] -> 
             RGBColor[
              0.18689482770343305`, 0.31376869210576286`, 0.9339547560003658],
              UndirectedEdge[217, 357] -> 
             RGBColor[
              0.9250850387636083, 0.713744916795109, 0.34467921995684786`], 
             UndirectedEdge[364, 385] -> 
             RGBColor[
              0.9060512192132981, 0.563682156680796, 0.3995847034769297], 
             UndirectedEdge[161, 372] -> 
             RGBColor[
              0.19676171310914198`, 0.3241394142638304, 0.934516660527472], 
             UndirectedEdge[4, 339] -> 
             RGBColor[
              0.24218330961780632`, 0.3718803920899902, 0.9371033532534101], 
             UndirectedEdge[183, 280] -> 
             RGBColor[
              0.30076148412422865`, 0.4296367640588081, 0.9405789063698025], 
             UndirectedEdge[94, 145] -> 
             RGBColor[
              0.18922208139469943`, 0.31621478329169034`, 0.9340872896552201],
              UndirectedEdge[107, 351] -> 
             RGBColor[
              0.6292040524803684, 0.703641559800374, 0.9673461867380587], 
             UndirectedEdge[90, 178] -> 
             RGBColor[
              0.5250344578406001, 0.6249699305004974, 0.9558390168550672], 
             UndirectedEdge[113, 124] -> 
             RGBColor[
              0.3086276211264817, 0.4416266325643382, 0.9408905883938774], 
             UndirectedEdge[191, 365] -> 
             RGBColor[
              0.19407713550409694`, 0.321317752988877, 0.9343637778043414], 
             UndirectedEdge[184, 356] -> 
             RGBColor[
              0.18905111217950674`, 0.3160350838064485, 0.9340775532113412], 
             UndirectedEdge[196, 327] -> 
             RGBColor[
              0.19267128104236286`, 0.3198401108132733, 0.9342837164725208], 
             UndirectedEdge[140, 288] -> 
             RGBColor[
              0.2655351688852008, 0.39642467677341436`, 0.9384332070927082], 
             UndirectedEdge[13, 232] -> 
             RGBColor[
              0.2546277618608894, 0.3849603004213146, 0.9378120463987364], 
             UndirectedEdge[34, 86] -> 
             RGBColor[
              0.3371353879041764, 0.46222487105446, 0.9428569705546225], 
             UndirectedEdge[287, 374] -> 
             RGBColor[
              0.19007574708878708`, 0.31711204006170757`, 0.9341359046536132],
              UndirectedEdge[201, 230] -> 
             RGBColor[
              0.8833910407331164, 0.5494337776148619, 0.5678796660606804], 
             UndirectedEdge[71, 138] -> 
             RGBColor[
              0.18058969715831197`, 0.30714160013447456`, 0.9335956881434259],
              UndirectedEdge[334, 360] -> 
             RGBColor[
              0.185115098539477, 0.3118980839130987, 0.9338534030573518], 
             UndirectedEdge[38, 58] -> 
             RGBColor[
              0.2174442667054725, 0.3458780894432118, 0.935694501357687], 
             UndirectedEdge[115, 239] -> 
             RGBColor[
              0.8461854795987771, 0.346251043142995, 0.19147853854411218`], 
             UndirectedEdge[32, 78] -> 
             RGBColor[
              0.888484912423063, 0.5104881805224738, 0.22715218685893562`], 
             UndirectedEdge[41, 83] -> 
             RGBColor[
              0.9084527486796484, 0.9295988421678656, 0.9827837388659694], 
             UndirectedEdge[90, 212] -> 
             RGBColor[
              0.5128575453871849, 0.6144229009627645, 0.9550631147611566], 
             UndirectedEdge[160, 263] -> 
             RGBColor[
              0.42578806203725694`, 0.5430467428327064, 0.9483991221427692], 
             UndirectedEdge[226, 350] -> 
             RGBColor[
              0.7195454075725961, 0.7758957836327975, 0.8505842343054555], 
             UndirectedEdge[159, 329] -> 
             RGBColor[
              0.18547778561514033`, 0.3122792910253096, 0.9338740575497635], 
             UndirectedEdge[132, 260] -> 
             RGBColor[
              0.29142760754703456`, 0.4190601234916939, 0.9400754082095211], 
             UndirectedEdge[7, 250] -> 
             RGBColor[
              0.35349640883612216`, 0.4759428684075872, 0.943916070428803], 
             UndirectedEdge[135, 281] -> 
             RGBColor[
              0.711765095722288, 0.768553055573181, 0.8142632180180123], 
             UndirectedEdge[240, 243] -> 
             RGBColor[
              0.9006075598972731, 0.6106868981753124, 0.5572235175535094], 
             UndirectedEdge[105, 349] -> 
             RGBColor[
              0.20573070891450085`, 0.3335663975224413, 0.935027431570147], 
             UndirectedEdge[111, 154] -> 
             RGBColor[
              0.19738148096805996`, 0.3247908295791051, 0.934551955390173], 
             UndirectedEdge[3, 233] -> 
             RGBColor[
              0.7706376185941841, 0.8203361519689907, 0.9569123152308744], 
             UndirectedEdge[125, 162] -> 
             RGBColor[
              0.2669203824734684, 0.39788062408229774`, 0.9385120929573202], 
             UndirectedEdge[301, 369] -> 
             RGBColor[
              0.18664719483068826`, 0.31350841425567716`, 0.9339406536746029],
              UndirectedEdge[268, 270] -> 
             RGBColor[
              0.5192310696539062, 0.6174490867384653, 0.9563893333020512], 
             UndirectedEdge[4, 188] -> 
             RGBColor[
              0.2173017232473819, 0.34572826723098127`, 0.9356863837186229], 
             UndirectedEdge[161, 176] -> 
             RGBColor[
              0.21656199837052442`, 0.34495076948413805`, 0.9356442574812107],
              UndirectedEdge[106, 270] -> 
             RGBColor[
              0.2929589759941193, 0.42059333525935383`, 0.9401654130551529], 
             UndirectedEdge[190, 268] -> 
             RGBColor[
              0.8177911045280821, 0.8581558703042615, 0.9638348308947651], 
             UndirectedEdge[220, 341] -> 
             RGBColor[
              0.4860287842689018, 0.590440011686344, 0.9535595010943037], 
             UndirectedEdge[76, 103] -> 
             RGBColor[
              0.19412197120965846`, 0.32136487815817005`, 0.9343663311314445],
              UndirectedEdge[84, 163] -> 
             RGBColor[
              0.3028162711208553, 0.4328272844297121, 0.940658180484038], 
             UndirectedEdge[356, 372] -> 
             RGBColor[
              0.1945300591839852, 0.3217938044934594, 0.9343895711378705], 
             UndirectedEdge[243, 398] -> 
             RGBColor[
              0.6978102198330773, 0.7601382089599893, 0.9424198532319874], 
             UndirectedEdge[141, 243] -> 
             RGBColor[
              0.9175618655302045, 0.7296924440007758, 0.5730160037263106], 
             UndirectedEdge[192, 320] -> 
             RGBColor[
              0.18870690253434044`, 0.31567329764522667`, 0.9340579509812614],
              UndirectedEdge[83, 245] -> 
             RGBColor[
              0.8819322732807819, 0.5521345143978579, 0.5717957186100475], 
             UndirectedEdge[256, 313] -> 
             RGBColor[
              0.28483799884386285`, 0.41277795475190926`, 0.9396765623907513],
              UndirectedEdge[144, 186] -> 
             RGBColor[
              0.19870087032152506`, 0.3261775914437136, 0.9346270926619912], 
             UndirectedEdge[271, 371] -> 
             RGBColor[
              0.1828236944867615, 0.3094896729702865, 0.9337229109863782], 
             UndirectedEdge[317, 326] -> 
             RGBColor[
              0.19368284883535128`, 0.3209033327008066, 0.9343413237618512], 
             UndirectedEdge[194, 242] -> 
             RGBColor[
              0.9234025469352043, 0.6967570760189528, 0.42193717605226866`], 
             UndirectedEdge[305, 334] -> 
             RGBColor[
              0.18360707090558112`, 0.31031305125539965`, 0.9337675231145284],
              UndirectedEdge[252, 282] -> 
             RGBColor[
              0.31835440977210794`, 0.4463178036126423, 0.941647079240882], 
             UndirectedEdge[134, 239] -> 
             RGBColor[
              0.8293655507418161, 0.5412295041829576, 0.578979393717503], 
             UndirectedEdge[267, 398] -> 
             RGBColor[
              0.34104050458358826`, 0.46493592502132197`, 0.9431303829813984],
              UndirectedEdge[4, 297] -> 
             RGBColor[
              0.2198696831096341, 0.34842735586426754`, 0.9358326252338219], 
             UndirectedEdge[40, 272] -> 
             RGBColor[
              0.6309966022057711, 0.7098004613221861, 0.9651259277394999], 
             UndirectedEdge[203, 325] -> 
             RGBColor[
              0.2574480826974209, 0.38792463643917835`, 0.9379726594980861], 
             UndirectedEdge[315, 359] -> 
             RGBColor[
              0.2030249569861144, 0.33072248069112636`, 0.9348733430006266], 
             UndirectedEdge[132, 160] -> 
             RGBColor[
              0.40894844852211004`, 0.5284611159894712, 0.9473261168602697], 
             UndirectedEdge[283, 381] -> 
             RGBColor[
              0.20257187699290616`, 0.3302462648913338, 0.9348475407652852], 
             UndirectedEdge[40, 183] -> 
             RGBColor[
              0.43552341404886974`, 0.5498108720138242, 0.9494803631610341], 
             UndirectedEdge[131, 339] -> 
             RGBColor[
              0.23240211172972863`, 0.36159973294585546`, 0.9365463285036696],
              UndirectedEdge[156, 165] -> 
             RGBColor[
              0.8638677055732559, 0.5798421452000351, 0.5836596867408057], 
             UndirectedEdge[352, 379] -> 
             RGBColor[
              0.22335212736306764`, 0.3520876255743447, 0.9360309452822404], 
             UndirectedEdge[25, 194] -> 
             RGBColor[
              0.9059253338243674, 0.5624195574854407, 0.4052009770396422], 
             UndirectedEdge[174, 238] -> 
             RGBColor[
              0.3169893195658634, 0.44724710585547944`, 0.9414827781424888], 
             UndirectedEdge[66, 339] -> 
             RGBColor[
              0.23290928668708955`, 0.3621328059827914, 0.9365752113671932], 
             UndirectedEdge[67, 387] -> 
             RGBColor[
              0.4796742864541198, 0.5876973628554791, 0.9523916433059518], 
             UndirectedEdge[90, 190] -> 
             RGBColor[
              0.7822989919455827, 0.8299086268722369, 0.9606532016549456], 
             UndirectedEdge[271, 389] -> 
             RGBColor[
              0.19087423447573804`, 0.31795130093241747`, 0.9341813773290437],
              UndirectedEdge[19, 293] -> 
             RGBColor[
              0.3046492475878372, 0.4338240686707453, 0.9407966099576801], 
             UndirectedEdge[126, 327] -> 
             RGBColor[
              0.19109665502145906`, 0.31818507902824733`, 0.9341940438500809],
              UndirectedEdge[12, 310] -> 
             RGBColor[
              0.2940376027932159, 0.42638254196942454`, 0.9400563785381975], 
             UndirectedEdge[272, 350] -> 
             RGBColor[
              0.867391875594665, 0.894633501748924, 0.8631950663915847], 
             UndirectedEdge[215, 229] -> 
             RGBColor[
              0.19493972789376507`, 0.3222243922819345, 0.9344129011648419], 
             UndirectedEdge[57, 189] -> 
             RGBColor[
              0.24216202976271878`, 0.3718580256130724, 0.9371021413971435], 
             UndirectedEdge[104, 337] -> 
             RGBColor[
              0.9065279712784959, 0.568396550220559, 0.3796238425222831], 
             UndirectedEdge[194, 385] -> 
             RGBColor[
              0.9944784929138155, 0.9905983795896796, 0.6403962123397537], 
             UndirectedEdge[56, 166] -> 
             RGBColor[
              0.6856726502293173, 0.7474973607293266, 0.8829926191709212], 
             UndirectedEdge[258, 379] -> 
             RGBColor[
              0.19525485067885182`, 0.32255560630899927`, 0.9344308469412701],
              UndirectedEdge[9, 150] -> 
             RGBColor[
              0.19229026561489077`, 0.3194396394412268, 0.9342620182075883], 
             UndirectedEdge[294, 380] -> 
             RGBColor[
              0.20504200072556777`, 0.3328425215492514, 0.9349882106576397], 
             UndirectedEdge[296, 308] -> 
             RGBColor[
              0.22323052785896746`, 0.35195981678568156`, 0.9360240203703722],
              UndirectedEdge[33, 92] -> 
             RGBColor[
              0.3869660924415177, 0.5054181375626268, 0.9463177797578736], 
             UndirectedEdge[39, 283] -> 
             RGBColor[
              0.19607798492560893`, 0.3234207725920666, 0.934477723218905], 
             UndirectedEdge[11, 34] -> 
             RGBColor[
              0.28760640007487454`, 0.41932535119602954`, 0.9397010272469036],
              UndirectedEdge[105, 171] -> 
             RGBColor[
              0.19921926143757313`, 0.32672245337457523`, 0.9346566142691592],
              UndirectedEdge[110, 237] -> 
             RGBColor[
              0.19038343508665123`, 0.3174354396560086, 0.9341534270299079], 
             UndirectedEdge[8, 175] -> 
             RGBColor[
              0.2597318112605219, 0.39032497995575144`, 0.938102714461281], 
             UndirectedEdge[90, 373] -> 
             RGBColor[
              0.44011491122134366`, 0.5480057067490964, 0.9505529184695845], 
             UndirectedEdge[73, 104] -> 
             RGBColor[
              0.874812220102593, 0.4548689553377009, 0.21443306157225883`], 
             UndirectedEdge[232, 339] -> 
             RGBColor[
              0.2733203034534184, 0.404607346810652, 0.9388765589892938], 
             UndirectedEdge[178, 274] -> 
             RGBColor[
              0.46738436670940764`, 0.5781669894131862, 0.9513005905019778], 
             UndirectedEdge[224, 318] -> 
             RGBColor[
              0.18686239314258873`, 0.3137346013258456, 0.9339529089001083], 
             UndirectedEdge[132, 307] -> 
             RGBColor[
              0.3533139613151539, 0.48044452804031823`, 0.9437338310851009]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {400}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.1972575262297792, 0.3246605452899877, 0.9345448963512025], 
             316 -> RGBColor[
              0.23435379828218117`, 0.36365107925655765`, 0.9366574741655703],
              308 -> 
             RGBColor[
              0.20150049615977755`, 0.32912017570624735`, 0.9347865272118044],
              160 -> RGBColor[
              0.4596234812344611, 0.572182073724828, 0.9506023905805157], 245 -> 
             RGBColor[
              0.818830055518114, 0.14574163486097447`, 0.1656649884706391], 
             155 -> RGBColor[
              0.2070813101039675, 0.3349859650056321, 0.9351043463098516], 
             213 -> RGBColor[
              0.22261848399738943`, 0.3513165198813409, 0.9359891653778931], 
             352 -> RGBColor[
              0.2396024194233052, 0.3691677128576799, 0.9369563753749182], 27 -> 
             RGBColor[
              0.821038236612611, 0.16271468238440395`, 0.16777954518051325`], 
             367 -> RGBColor[
              0.37508215881778845`, 0.49929904661568136`, 0.9451208813811075],
              19 -> RGBColor[
              0.26040419361571815`, 0.3910316964425663, 0.9381410056417089], 
             164 -> RGBColor[
              0.20095261322947336`, 0.32854431600871353`, 0.9347553260894438],
              190 -> RGBColor[
              0.9562193148935751, 0.9668690172486966, 0.9589934594404549], 
             103 -> RGBColor[
              0.19434739415987903`, 0.3216018119714924, 0.9343791686349763], 
             138 -> RGBColor[
              0.18225239431662393`, 0.3088892002689491, 0.9336903762868517], 
             291 -> RGBColor[
              0.18717515147111807`, 0.3140633301591533, 0.9339707200242335], 
             28 -> RGBColor[
              0.20698871416859752`, 0.3348886408066369, 0.9350990731083157], 
             337 -> RGBColor[
              0.9940468194635823, 0.9896750737285114, 0.5934112212615963], 
             195 -> RGBColor[
              0.20184829587443234`, 0.32948573525812513`, 0.9348063338910304],
              114 -> RGBColor[
              0.24129060741956473`, 0.3709421054790498, 0.9370525151838548], 
             93 -> RGBColor[
              0.2343202347626608, 0.3636158018694917, 0.9366555627727864], 34 -> 
             RGBColor[
              0.2632481201845229, 0.3940208435817391, 0.93830296305259], 161 -> 
             RGBColor[
              0.1994550789542851, 0.32697031253633363`, 0.9346700437278752], 
             22 -> RGBColor[
              0.3162753653274515, 0.4483635578097335, 0.9413737645007089], 
             124 -> RGBColor[
              0.3097296345397099, 0.44269397479938727`, 0.9409566763230764], 
             84 -> RGBColor[
              0.3388378220394789, 0.4679060237916442, 0.9428114242912021], 46 -> 
             RGBColor[
              0.20129344185623907`, 0.3289025485052273, 0.9347747357755273], 
             241 -> RGBColor[
              0.2632132370288079, 0.3939841791733627, 0.938300976508477], 185 -> 
             RGBColor[
              0.3996003392677278, 0.5205354622018381, 0.9466831581588019], 
             390 -> RGBColor[
              0.2627109211596987, 0.39345621334626335`, 0.938272370362841], 
             121 -> RGBColor[
              0.3109061797336599, 0.4437130391115059, 0.9410316447424569], 
             322 -> RGBColor[
              0.1999051049994005, 0.32744331844304914`, 0.9346956720453906], 
             126 -> RGBColor[
              0.1865862227024127, 0.3134443286830033, 0.9339371814020978], 
             236 -> RGBColor[
              0.25077535368791876`, 0.38091117517473666`, 0.9375926574524128],
              78 -> RGBColor[
              0.8199375785531087, 0.1542545422276314, 0.1667255537797183], 
             376 -> RGBColor[
              0.209601906353837, 0.3376352714792777, 0.9352478905373938], 254 -> 
             RGBColor[
              0.18724741023772068`, 0.314139278704323, 0.9339748350540943], 
             290 -> RGBColor[
              0.19821724293608944`, 0.32566926839787347`, 0.9345995507978533],
              251 -> RGBColor[
              0.19027393338711107`, 0.3173203464269832, 0.9341471910701123], 
             165 -> RGBColor[
              0.8967495440562933, 0.920507761085305, 0.9900139661214994], 100 -> 
             RGBColor[
              0.2101475089071078, 0.33820873435596516`, 0.9352789617956558], 
             235 -> RGBColor[
              0.1915139828942802, 0.31862371708269777`, 0.9342178100550568], 
             70 -> RGBColor[
              0.22291581655962178`, 0.35162903525622036`, 0.9360060980274482],
              234 -> RGBColor[
              0.7857227396767522, 0.8325318430402561, 0.9792771577606599], 
             257 -> RGBColor[
              0.32310439559809073`, 0.45427852059311985`, 0.9418089042708796],
              135 -> RGBColor[
              0.9948422584139026, 0.9913764372120322, 0.679989842123797], 265 -> 
             RGBColor[
              0.18998272969436467`, 0.3170142728825262, 0.9341306074506077], 
             111 -> RGBColor[
              0.18925042984728385`, 0.3162445793127523, 0.934088904057657], 
             381 -> RGBColor[
              0.19616341759440778`, 0.32351056774371817`, 0.9344825884830068],
              182 -> RGBColor[
              0.34853172220347034`, 0.47630239288410453`, 0.9434291110376724],
              188 -> 
             RGBColor[
              0.2017846044041309, 0.3294187914845658, 0.9348027067560198], 
             154 -> RGBColor[
              0.2055125320888361, 0.33333707984545796`, 0.935015006722689], 
             336 -> RGBColor[
              0.18035329176886106`, 0.3068931230811942, 0.933582225206227], 
             315 -> RGBColor[
              0.2188459842157359, 0.34735138342052185`, 0.9357743270962412], 
             368 -> RGBColor[
              0.1851720653526604, 0.311957959645659, 0.9338566472330878], 269 -> 
             RGBColor[
              0.743581503407994, 0.7996107889818441, 0.9750769131616334], 208 -> 
             RGBColor[
              0.9930152754848626, 0.9913796511608278, 0.7654184913108293], 86 -> 
             RGBColor[
              0.4110226556238299, 0.5304288985271809, 0.947410978056655], 119 -> 
             RGBColor[
              0.18241596627536708`, 0.30906112476864933`, 0.9336996914679191],
              377 -> RGBColor[
              0.18473621585810335`, 0.3114998541924255, 0.9338318262491543], 
             140 -> RGBColor[
              0.2256991535454318, 0.35455449890206425`, 0.9361646049512119], 
             85 -> RGBColor[
              0.24074527521724318`, 0.3703689267583512, 0.9370214593216792], 
             351 -> RGBColor[
              0.9097894237460113, 0.9309054071917814, 0.9912577214871428], 
             242 -> RGBColor[
              0.852273426221674, 0.40280203706702433`, 0.19769039802525293`], 
             117 -> RGBColor[
              0.22614100723621103`, 0.3550189151462153, 0.9361897678652379], 
             47 -> RGBColor[
              0.5441036538714303, 0.6407668836599264, 0.9572529792315668], 81 -> 
             RGBColor[
              0.17955783501139488`, 0.30605704759422586`, 0.9335369251206622],
              275 -> RGBColor[
              0.23875032994207512`, 0.36827211278731364`, 0.9369078501395155],
              23 -> RGBColor[
              0.2930562064900811, 0.4253510322307103, 0.9400004894705796], 
             328 -> RGBColor[
              0.8695307562797816, 0.5004514607800906, 0.21284560375709155`], 
             110 -> RGBColor[
              0.18343408206602244`, 0.3101312290168976, 0.9337576716560296], 
             6 -> RGBColor[
              0.30558851701585305`, 0.4385232851876776, 0.9407141860151303], 
             218 -> RGBColor[
              0.19086057119328328`, 0.3179369399562554, 0.934180599225321], 
             108 -> RGBColor[
              0.256153514960176, 0.38656396366699863`, 0.9378989357805914], 
             297 -> 
             RGBColor[
              0.20692052412863532`, 0.33481696875113837`, 0.935095189786418], 
             157 -> RGBColor[
              0.1873941802353717, 0.31429354327760956`, 0.9339831933883338], 
             354 -> RGBColor[
              0.2158527042869893, 0.34420525643050026`, 0.9356038642324599], 
             385 -> RGBColor[
              0.9944253181788963, 0.9904846442084778, 0.6346084706002231], 
             270 -> RGBColor[
              0.3590992451452233, 0.4854554501171043, 0.9441024642550272], 
             392 -> RGBColor[
              0.9910839134677017, 0.9905809833329919, 0.7974261581398643], 33 -> 
             RGBColor[
              0.2765417318743941, 0.4079932723314563, 0.939060014572192], 252 -> 
             RGBColor[
              0.3695662131784596, 0.4945214117423836, 0.9447694102025287], 
             394 -> RGBColor[
              0.18043226082461958`, 0.30697612456572376`, 0.9335867223771283],
              260 -> RGBColor[
              0.22458179928431016`, 0.35338008872927346`, 0.9361009732790185],
              159 -> RGBColor[
              0.1805122222555836, 0.3070601690995145, 0.9335912760623294], 
             183 -> RGBColor[
              0.3499869056482099, 0.4775627996442913, 0.943521834040003], 99 -> 
             RGBColor[
              0.965636915117815, 0.9738926480760296, 0.9430519187643377], 329 -> 
             RGBColor[
              0.19044334897469703`, 0.3174984129511047, 0.9341568390371975], 
             309 -> RGBColor[
              0.2975965440226766, 0.4301232148514946, 0.9402590549762334], 17 -> 
             RGBColor[
              0.2316763474093035, 0.360836908628973, 0.9365049972992935], 349 -> 
             RGBColor[
              0.2019856527302044, 0.3296301060224692, 0.9348141561607654], 
             347 -> RGBColor[
              0.19785125300646603`, 0.3252845897767374, 0.9345787082127948], 
             340 -> RGBColor[
              0.2029347338096705, 0.33062765041220404`, 0.9348682049242014], 
             277 -> RGBColor[
              0.20781531186542476`, 0.3357574473953233, 0.9351461466243084], 
             104 -> RGBColor[
              0.8190091230934095, 0.14711802671260676`, 0.16583646378296987`],
              79 -> RGBColor[
              0.23104392871496413`, 0.36017219648356114`, 0.9364689819902305],
              327 -> RGBColor[
              0.19560708734050541`, 0.3229258293734914, 0.9344509062980639], 
             191 -> RGBColor[
              0.20722377740839654`, 0.33513570717553587`, 0.9351124596120775],
              50 -> 
             RGBColor[
              0.1790362447681438, 0.3055088231778375, 0.9335072213279326], 
             225 -> RGBColor[
              0.884710274500928, 0.9109079743391231, 0.9888656498437259], 61 -> 
             RGBColor[
              0.20936457771848743`, 0.3373858240360207, 0.9352343750227069], 
             196 -> RGBColor[
              0.18973547474422028`, 0.3167543922530552, 0.9341165266469779], 
             1 -> RGBColor[
              0.19354678877808446`, 0.32076032495391327`, 0.9343335753428726],
              263 -> RGBColor[
              0.3919526428400527, 0.5139114119405849, 0.9461958537050229], 
             201 -> RGBColor[
              0.9490437648216794, 0.9615175037539616, 0.971139794028986], 371 -> 
             RGBColor[
              0.18654757264035143`, 0.3134037050172214, 0.9339349803382411], 
             293 -> RGBColor[
              0.3488943015599562, 0.47661644089892424`, 0.9434522142736513], 
             362 -> RGBColor[
              0.18916507484151227`, 0.3161548657898664, 0.9340840432163497], 
             184 -> RGBColor[
              0.18311045325504194`, 0.3097910746173054, 0.9337392414740102], 
             106 -> RGBColor[
              0.22681870684301533`, 0.35573122040160343`, 0.9362283618552786],
              206 -> RGBColor[
              0.7303132143006519, 0.7892455006884563, 0.9737544541026248], 
             358 -> RGBColor[
              0.19077583416012883`, 0.31784787596177183`, 0.9341757735766401],
              247 -> RGBColor[
              0.1976279917679603, 0.3250499280594878, 0.9345659938155473], 
             220 -> RGBColor[
              0.635822518194204, 0.7152283896049052, 0.9644734242083259], 107 -> 
             RGBColor[
              0.34861868121472545`, 0.4763777124089667, 0.9434346519889747], 
             375 -> RGBColor[
              0.180596656524124, 0.30714891486919227`, 0.9335960844690134], 
             131 -> RGBColor[
              0.21325644631447746`, 0.3414764246891273, 0.9354560111817448], 
             127 -> RGBColor[
              0.19480415931956344`, 0.32208190111490453`, 0.9344051807350968],
              210 -> RGBColor[
              0.3056537490672848, 0.4385918482096833, 0.9407179008839572], 
             357 -> RGBColor[
              0.85710048921771, 0.439904958487049, 0.20231279900164487`], 181 -> 
             RGBColor[
              0.19492367816056405`, 0.3222075229947284, 0.9344119871562795], 
             194 -> RGBColor[
              0.9945316676487347, 0.9907121149708813, 0.6461839540792844], 
             118 -> 
             RGBColor[
              0.2388812891503496, 0.36840975921850344`, 0.93691530807269], 
             348 -> RGBColor[
              0.33313964664549794`, 0.4629705506640006, 0.9424483415937963], 
             276 -> RGBColor[
              0.22285712514090053`, 0.35156734685389346`, 0.9360027556379781],
              305 -> RGBColor[
              0.18223318953702214`, 0.3088690148279342, 0.9336892826030643], 
             343 -> RGBColor[
              0.1820208818055452, 0.30864586594106436`, 0.9336771919918379], 
             280 -> RGBColor[
              0.2515360626002474, 0.3817107284733248, 0.937635978699602], 189 -> 
             RGBColor[
              0.266643234211289, 0.39758932368653244`, 0.9384963097737932], 
             168 -> RGBColor[
              0.18420503135956878`, 0.31094154560542325`, 0.9338015760777798],
              363 -> RGBColor[
              0.21990087473071346`, 0.348460140235685, 0.9358344015504985], 
             41 -> RGBColor[
              0.8718710063158469, 0.90067029040099, 0.9876410289824828], 14 -> 
             RGBColor[
              0.18454901891679482`, 0.31130309833813863`, 0.9338211656602798],
              77 -> RGBColor[
              0.18280925758947733`, 0.30947449887588874`, 0.9337220888264354],
              51 -> RGBColor[
              0.381577964086101, 0.5049253866504279, 0.9455347883487892], 179 -> 
             RGBColor[
              0.45394807471440896`, 0.5675745230376996, 0.950155601789558], 
             223 -> RGBColor[
              0.9299021495647822, 0.7597924122879596, 0.2624558280130423], 
             323 -> RGBColor[
              0.3986910652219958, 0.5197478947248675, 0.9466252200206473], 
             292 -> RGBColor[
              0.1943854920349882, 0.321641855253777, 0.934381338252603], 396 -> 
             RGBColor[
              0.19955786085140656`, 0.3270783428269569, 0.9346758970048641], 
             321 -> RGBColor[
              0.5543615420614805, 0.6490946994052059, 0.9580605177657702], 
             143 -> RGBColor[
              0.18504307948317125`, 0.3118223873186494, 0.9338493016786379], 
             112 -> RGBColor[
              0.937107871400364, 0.788360698201582, 0.2682537209419814], 197 -> 
             RGBColor[
              0.9643115115712477, 0.9729041642811488, 0.9452954812480678], 54 -> 
             RGBColor[
              0.1846123721443362, 0.31136968659711123`, 0.9338247735328656], 
             71 -> RGBColor[0.178927, 0.305394, 0.933501], 177 -> 
             RGBColor[
              0.8948525196191675, 0.9189951252924975, 0.9898330262371927], 
             158 -> RGBColor[
              0.3387561380668311, 0.4678352732400925, 0.9428062194606953], 
             226 -> RGBColor[
              0.44524034591787487`, 0.5600665420287623, 0.9495912990246761], 
             350 -> RGBColor[
              0.9938504692273173, 0.9917250252368329, 0.751577169586235], 203 -> 
             RGBColor[
              0.2257570420476589, 0.35461534338824796`, 0.9361679016157753], 
             115 -> RGBColor[
              0.8646080428941941, 0.47809856902505976`, 0.2087379710414105], 
             173 -> RGBColor[
              0.2824798268544749, 0.4142345866524884, 0.9393981802966833], 
             212 -> RGBColor[
              0.41733642177677943`, 0.535897565429752, 0.9478132856528767], 
             129 -> RGBColor[
              0.189088316742455, 0.3160741881610126, 0.9340796719561618], 279 -> 
             RGBColor[
              0.6722342021283076, 0.7438737349625797, 0.9679656809485127], 26 -> 
             RGBColor[
              0.18699939157323073`, 0.3138785953626525, 0.9339607107580624], 
             40 -> RGBColor[
              0.5210599224495296, 0.6220589443833571, 0.9554388922820652], 
             146 -> RGBColor[
              0.18614238840660097`, 0.3129778306973855, 0.9339119056955454], 
             386 -> RGBColor[
              0.7607606134285254, 0.8130312402959552, 0.9767891663005692], 
             192 -> RGBColor[
              0.18162114890697434`, 0.30822572132013676`, 0.933654427794616], 
             300 -> RGBColor[
              0.9146994662552146, 0.9348205418090667, 0.9917260457249173], 
             221 -> RGBColor[
              0.9023083761464576, 0.6492869771870501, 0.2401960532268301], 62 -> 
             RGBColor[
              0.20110579749352597`, 0.32870532238267614`, 0.9347640497066657],
              286 -> RGBColor[
              0.1948453625020903, 0.32212520827217295`, 0.9344075271953871], 
             152 -> RGBColor[
              0.25676930210776144`, 0.3872111950022711, 0.9379340039476709], 
             64 -> RGBColor[
              0.18064334912177313`, 0.30719799174980317`, 0.933598743543374], 
             307 -> RGBColor[
              0.3483545068205488, 0.47614889782652203`, 0.9434178190301781], 
             37 -> RGBColor[
              0.34879862256835453`, 0.4765335685653648, 0.9434461176929121], 
             148 -> RGBColor[
              0.33397821749630197`, 0.46369687858717057`, 0.9425017745868906],
              261 -> 
             RGBColor[
              0.2599700418165058, 0.39057537537478015`, 0.9381162813390138], 
             387 -> RGBColor[
              0.5341260408491124, 0.6326666079220644, 0.9564675049852491], 15 -> 
             RGBColor[
              0.28582560720535155`, 0.41775121393598635`, 0.9395887175380273],
              136 -> RGBColor[
              0.18458947116943916`, 0.3113456162204888, 0.9338234693562242], 
             198 -> RGBColor[
              0.3533082208089774, 0.4804395559023944, 0.9437334653051234], 63 -> 
             RGBColor[
              0.1811814280726413, 0.30776354684334156`, 0.9336293863436095], 
             310 -> RGBColor[
              0.27959908951497947`, 0.4112067490593821, 0.9392341265668681], 
             171 -> RGBColor[
              0.188962757776349, 0.315942217726737, 0.93407252155879], 395 -> 
             RGBColor[
              0.46863892160806836`, 0.5795012143610829, 0.9513121190713723], 
             311 -> RGBColor[
              0.3027440138032642, 0.4355335319593264, 0.9405521957652387], 
             353 -> RGBColor[
              0.19002087389400624`, 0.31705436485483146`, 0.934132779706348], 
             59 -> RGBColor[
              0.3465121371910148, 0.4745531298536097, 0.9433004248665277], 
             397 -> RGBColor[
              0.2129233554713194, 0.341126325093789, 0.9354370421509908], 229 -> 
             RGBColor[
              0.20688302376209858`, 0.33477755348824767`, 0.9350930541960206],
              102 -> RGBColor[
              0.2774713947406823, 0.40897040694795533`, 0.9391129574971142], 
             299 -> RGBColor[
              0.18766218808016377`, 0.31457523651516484`, 0.9339984560386126],
              128 -> RGBColor[
              0.19461177340916913`, 0.32187969132510885`, 0.9343942246421093],
              12 -> RGBColor[
              0.3084761160714523, 0.441558334879467, 0.9408786305095267], 222 -> 
             RGBColor[
              0.23238602207295528`, 0.3615828216964435, 0.9365454122215189], 
             92 -> RGBColor[
              0.49739045300864126`, 0.6028430027937971, 0.9535755449435551], 
             271 -> RGBColor[
              0.17909981633317154`, 0.30557564092335165`, 0.9335108416345153],
              361 -> RGBColor[
              0.21763599434706354`, 0.34607960735075854`, 0.93570541996324], 
             344 -> RGBColor[
              0.1912494582787511, 0.31834568493994736`, 0.9342027457695316], 
             132 -> RGBColor[
              0.35827341580975897`, 0.4847401582541144, 0.9440498431400237], 
             80 -> 
             RGBColor[
              0.1798079986201722, 0.3063199854083397, 0.9335511715680982], 
             324 -> RGBColor[
              0.6331296311169758, 0.713042182562431, 0.9642614302732361], 244 -> 
             RGBColor[
              0.9547654228714991, 0.9657847069591619, 0.9614545193980599], 
             150 -> RGBColor[
              0.19354588592399127`, 0.3207593759970171, 0.9343335239266677], 
             125 -> RGBColor[
              0.2615118954900493, 0.3921959613448436, 0.9382040876247539], 
             258 -> RGBColor[
              0.18340786605487358`, 0.31010367432698904`, 0.9337561786929778],
              133 -> RGBColor[
              0.18578718983175693`, 0.312604494474334, 0.9338916776621772], 
             255 -> RGBColor[
              0.8353613957275855, 0.2728087597904426, 0.18149541852470724`], 
             326 -> RGBColor[
              0.19201165546058205`, 0.31914680250414423`, 0.9342461517714671],
              176 -> RGBColor[
              0.23366891778676377`, 0.3629312264319425, 0.9366184712345461], 
             230 -> RGBColor[
              0.8177383166445533, 0.1373500514757623, 0.1646195380923747], 
             274 -> RGBColor[
              0.49307848673520527`, 0.5993423543211548, 0.9532360911632574], 
             87 -> RGBColor[
              0.19817896485079942`, 0.32562903570326285`, 0.9345973709175234],
              130 -> RGBColor[
              0.1820121662584413, 0.30863670534846055`, 0.9336766956543238], 
             35 -> RGBColor[
              0.2362515342121432, 0.36564572004235524`, 0.9367655474193329], 
             379 -> RGBColor[
              0.20710183530283005`, 0.33500753829100943`, 0.9351055151895625],
              31 -> RGBColor[
              0.19647646719475834`, 0.3238396027221777, 0.9345004161946314], 
             18 -> RGBColor[
              0.6051402883638863, 0.6903191732099512, 0.9620580066833722], 24 -> 
             RGBColor[
              0.8207868509580615, 0.16078242208563953`, 0.1675388179938171], 
             151 -> RGBColor[
              0.19201931518110454`, 0.3191548533560677, 0.9342465879812193], 
             137 -> RGBColor[
              0.33446348254021346`, 0.46411719077807645`, 0.9425326952463855],
              330 -> RGBColor[
              0.18593025704413854`, 0.31275486718553225`, 0.9338998251282734],
              296 -> RGBColor[
              0.2449605595581574, 0.37479945786511576`, 0.9372615135289399], 
             266 -> RGBColor[
              0.23275233921967517`, 0.3619678442434947, 0.9365662734411069], 
             302 -> 
             RGBColor[
              0.19137511524925596`, 0.3184777583830601, 0.9342099017481089], 
             283 -> RGBColor[
              0.20898033639140454`, 0.33698196203894937`, 0.9352124930475636],
              388 -> RGBColor[
              0.2195142065627996, 0.3480537274750297, 0.9358123813703602], 
             284 -> RGBColor[
              0.2765987024765969, 0.40805315204651627`, 0.939063258963707], 
             318 -> RGBColor[
              0.19439044372267295`, 0.3216470597914888, 0.9343816202438913], 
             238 -> RGBColor[
              0.28998218143607674`, 0.4221200369945062, 0.9398254282913666], 
             72 -> RGBColor[
              0.18281412095909713`, 0.3094796105857146, 0.9337223657881405], 
             288 -> RGBColor[
              0.30537118422496984`, 0.4382948546447645, 0.9407018092342045], 
             382 -> RGBColor[
              0.1818914944971056, 0.30850987167626515`, 0.9336698235760336], 
             389 -> RGBColor[
              0.20264865261830456`, 0.3303269609414833, 0.9348519130235723], 
             172 -> RGBColor[
              0.8238032261936802, 0.18396760393066158`, 0.17042730232595416`],
              243 -> RGBColor[
              0.9695261963263196, 0.9767932676332187, 0.9364683801653377], 88 -> 
             RGBColor[
              0.19146940577852636`, 0.3185768637076881, 0.9342152714542605], 
             273 -> RGBColor[
              0.1818250295794584, 0.30844001283369876`, 0.9336660384972996], 
             202 -> RGBColor[
              0.2433593553333951, 0.37311649070267905`, 0.9371703273171091], 
             393 -> RGBColor[
              0.18336325239717496`, 0.31005678254407854`, 0.9337536380111718],
              98 -> RGBColor[
              0.20101540430520026`, 0.32861031341048663`, 0.9347589019483153],
              30 -> RGBColor[
              0.18021067351487519`, 0.3067432222537355, 0.9335741033076473], 
             116 -> RGBColor[
              0.18333815129494635`, 0.31003039969413443`, 0.9337522085405336],
              373 -> RGBColor[
              0.271851153445097, 0.4030631770024157, 0.9387928930697325], 240 -> 
             RGBColor[
              0.8316889234682268, 0.24458052871740593`, 0.17797865494168116`],
              317 -> RGBColor[
              0.1953540422101205, 0.32265986289746895`, 0.9344364957522352], 
             391 -> RGBColor[
              0.18112688553091424`, 0.3077062191737896, 0.9336262802265466], 
             73 -> RGBColor[
              0.9306153171117766, 0.762619883962795, 0.26302965936154776`], 
             303 -> 
             RGBColor[
              0.21323548342695858`, 0.34145439136522115`, 0.9354548173763124],
              29 -> RGBColor[
              0.1814383294461641, 0.30803356647540187`, 0.9336440164967801], 
             360 -> RGBColor[
              0.18524924480481392`, 0.31203908014333226`, 0.9338610424887112],
              320 -> RGBColor[
              0.19579265616170655`, 0.32312087397031664`, 0.9344614741679068],
              75 -> RGBColor[
              0.21796667840296896`, 0.34642717726009525`, 0.9357242519310205],
              200 -> RGBColor[
              0.1842143453500115, 0.31095133519991963`, 0.9338021064957567], 
             301 -> RGBColor[
              0.18269671784651187`, 0.30935621247060024`, 0.933715679854561], 
             156 -> RGBColor[
              0.8309858670902185, 0.23917652931476524`, 0.17730540736011186`],
              25 -> RGBColor[0.817319, 0.134127, 0.164218], 38 -> 
             RGBColor[
              0.22292982485851465`, 0.3516437588665342, 0.9360068957793466], 
             365 -> RGBColor[
              0.18093049359979738`, 0.3074997988022181, 0.9336150959966053], 
             380 -> RGBColor[
              0.22012423896070668`, 0.348694910203518, 0.9358471218129588], 
             370 -> RGBColor[
              0.18708771794254558`, 0.3139714319770177, 0.9339657408141276], 
             3 -> RGBColor[
              0.5818688834669836, 0.6714263983498019, 0.960225996443923], 57 -> 
             RGBColor[
              0.21768082531414856`, 0.3461267275396124, 0.9357079730204939], 
             227 -> RGBColor[
              0.20746958876179836`, 0.3353940704933011, 0.9351264582050084], 
             39 -> RGBColor[
              0.18317563345981333`, 0.30985958314518375`, 0.9337429533902465],
              109 -> RGBColor[
              0.18132254229683142`, 0.30791186684012395`, 0.9336374225899173],
              256 -> RGBColor[
              0.3513087838325387, 0.47870774408802763`, 0.9436060629490174], 
             339 -> RGBColor[
              0.2515477771449798, 0.3817230412025836, 0.9376366458255944], 
             287 -> RGBColor[
              0.1899324083338537, 0.31696138194207063`, 0.9341277417235704], 
             239 -> RGBColor[
              0.82776291630336, 0.2144035172609302, 0.17421910604681382`], 
             285 -> RGBColor[
              0.9941990383585994, 0.9900006545532618, 0.6099793085980734], 
             345 -> RGBColor[
              0.1789871968344326, 0.3054572706896884, 0.9335044281206677], 
             366 -> 
             RGBColor[
              0.39439940253334044`, 0.5160306722091927, 0.9463517590690945], 
             216 -> RGBColor[
              0.1997106484206986, 0.3272389322495743, 0.9346845980309063], 21 -> 
             RGBColor[
              0.9632021039744041, 0.8875341975281088, 0.3115475519504825], 
             355 -> RGBColor[
              0.7657071355725306, 0.8168955009898127, 0.9772821894000061], 
             175 -> RGBColor[
              0.28165135838121924`, 0.41336381375916165`, 0.9393510002427407],
              7 -> RGBColor[
              0.4486453266434888, 0.5630157651939816, 0.9498082613856059], 13 -> 
             RGBColor[
              0.21416269395992185`, 0.3424289484239088, 0.9355076206444797], 
             294 -> RGBColor[
              0.1899597624904289, 0.3169901328949849, 0.9341292995023205], 
             193 -> RGBColor[
              0.18694492825143932`, 0.3138213509582757, 0.9339576091524576], 
             60 -> RGBColor[
              0.186004909472108, 0.3128333316205655, 0.9339040764736078], 65 -> 
             RGBColor[
              0.2879462259501837, 0.4199801186917991, 0.9397094836383711], 69 -> 
             RGBColor[
              0.2418162773238607, 0.37149461787786187`, 0.9370824513072455], 
             217 -> RGBColor[
              0.9930695883095065, 0.987584875103169, 0.4870456409120508], 214 -> 
             RGBColor[
              0.23974505627195325`, 0.36931763322930755`, 0.9369644983324363],
              170 -> RGBColor[
              0.2316644133079956, 0.36082436513183264`, 0.936504317669879], 
             359 -> RGBColor[
              0.18720392975649292`, 0.3140935779617309, 0.9339723589050121], 
             74 -> RGBColor[
              0.8630600513163033, 0.8936446740513561, 0.986800632228994], 246 -> 
             RGBColor[
              0.9202453542726101, 0.9392426823750178, 0.9922550174748891], 
             264 -> RGBColor[
              0.7232916660208124, 0.7837602138065023, 0.9730546117901898], 
             278 -> RGBColor[
              0.25816588373595994`, 0.3886790908418973, 0.9380135372053394], 
             45 -> RGBColor[
              0.2848093981590889, 0.41668311379698936`, 0.9395308459361892], 
             306 -> RGBColor[
              0.20271236623405806`, 0.3303939279913168, 0.9348555414197336], 
             237 -> RGBColor[
              0.19733278810728, 0.3247396502951197, 0.9345491824037863], 228 -> 
             RGBColor[
              0.20359531165465325`, 0.33132195961033534`, 0.9349058238552358],
              180 -> 
             RGBColor[
              0.2585433275657887, 0.3890758082383683, 0.93803503207307], 383 -> 
             RGBColor[
              0.20835388918653433`, 0.3363235263075839, 0.9351768178059918], 
             53 -> RGBColor[
              0.19239706134193654`, 0.319551888521592, 0.9342681000662533], 
             304 -> RGBColor[
              0.1808905282724361, 0.3074577927092133, 0.9336128200303355], 48 -> 
             RGBColor[
              0.24018804114120323`, 0.3697832384137522, 0.9369897256654027], 
             5 -> RGBColor[
              0.2824395297681887, 0.41419223185981874`, 0.9393958854372335], 
             101 -> RGBColor[
              0.1831002535865883, 0.30978035411906424`, 0.9337386606179808], 
             333 -> RGBColor[
              0.18811264277564865`, 0.31504869296059673`, 0.9340241087671325],
              267 -> RGBColor[
              0.2559867658273416, 0.386388699755884, 0.9378894396641596], 120 -> 
             RGBColor[
              0.5182991743784003, 0.6198176447289311, 0.9552215560809526], 
             147 -> RGBColor[
              0.1834762116557925, 0.31017550988691617`, 0.9337600708738418], 
             89 -> RGBColor[
              0.1892450123424645, 0.31623888517169746`, 0.934088595538772], 
             43 -> RGBColor[
              0.26035980612556775`, 0.3909850423760888, 0.9381384778398102], 
             199 -> RGBColor[
              0.18648980339442428`, 0.3133429858769703, 0.9339316904651475], 
             268 -> RGBColor[
              0.679362894162589, 0.7494427233598264, 0.9686762023490751], 169 -> 
             RGBColor[
              0.8957887014800139, 0.9197416112963568, 0.9899223200988196], 20 -> 
             RGBColor[
              0.19028821830363388`, 0.31733536077996466`, 0.9341480045749757],
              4 -> RGBColor[
              0.23281884209063286`, 0.36203774297739677`, 0.9365700606812258],
              167 -> RGBColor[
              0.3102543804501736, 0.4431484833325346, 0.9409901126684767], 
             142 -> RGBColor[
              0.18248883410320854`, 0.3091377134757978, 0.9337038411829164], 
             16 -> RGBColor[
              0.3177755060429437, 0.4496629042982282, 0.9414693521405777], 
             281 -> RGBColor[
              0.4286879330306734, 0.5457296739343299, 0.9485365939122276], 
             289 -> RGBColor[
              0.1861676814246589, 0.31300441526303435`, 0.9339133460955061], 
             398 -> RGBColor[
              0.4260942433398349, 0.54348315028676, 0.9483713262986371], 178 -> 
             RGBColor[
              0.44169024668361, 0.5569916245052177, 0.9493650898406981], 58 -> 
             RGBColor[
              0.21195870855243037`, 0.3401124200198894, 0.9353821069360272], 
             186 -> RGBColor[
              0.20685160848485196`, 0.33474453404001786`, 0.9350912651424561],
              122 -> RGBColor[
              0.5979628209588992, 0.6844921818293608, 0.9614929701573222], 
             249 -> RGBColor[
              0.3090764058516128, 0.442128180941986, 0.9409150531686984], 113 -> 
             RGBColor[
              0.30752560771325343`, 0.4405592903292892, 0.9408245004646784], 
             52 -> RGBColor[
              0.17936539842637753`, 0.30585478454218845`, 0.9335259661418299],
              187 -> RGBColor[
              0.43492032413853554`, 0.551127857862875, 0.9489337163625334], 
             259 -> RGBColor[
              0.18623692915551526`, 0.3130771990187241, 0.9339172896513356], 
             42 -> RGBColor[
              0.21651396498896067`, 0.34490028335462225`, 0.9356415220511897],
              134 -> RGBColor[
              0.830968185180272, 0.8680554911049849, 0.9837396813881922], 313 -> 
             RGBColor[
              0.218367213855187, 0.3468481654157909, 0.9357470618324852], 248 -> 
             RGBColor[
              0.21799885977606132`, 0.3464610019236322, 0.9357260846126101], 
             174 -> RGBColor[
              0.34399645769565007`, 0.4723741747164527, 0.943140127993611], 
             215 -> RGBColor[
              0.18299643202543156`, 0.30967123107562133`, 0.9337327481336631],
              399 -> RGBColor[
              0.9265760623547111, 0.7466055848528861, 0.2597795801705179], 83 -> 
             RGBColor[
              0.9450344910434499, 0.9585273939347413, 0.9779264487494559], 95 -> 
             RGBColor[
              0.559409915392181, 0.6531931963016955, 0.9584579442071637], 166 -> 
             RGBColor[
              0.9896948922783259, 0.9900065873749687, 0.82044583391943], 384 -> 
             RGBColor[
              0.18955786573703887`, 0.316567713925446, 0.9341064120767679], 
             233 -> RGBColor[
              0.9594063537213845, 0.9692459055881796, 0.9535986340178257], 
             295 -> RGBColor[
              0.4290348579738498, 0.5460301628831548, 0.9485586996628331], 
             141 -> RGBColor[
              0.8655975347340893, 0.482591620368333, 0.20956362728728348`], 
             319 -> RGBColor[
              0.4533617737780597, 0.567098537525015, 0.9501094460321575], 205 -> 
             RGBColor[
              0.3500177192487492, 0.4775894888363419, 0.943523797455382], 224 -> 
             RGBColor[
              0.1793343425625045, 0.3058221428602024, 0.9335241975563253], 
             231 -> RGBColor[
              0.18219295480676673`, 0.3088267255754066, 0.9336869912946982], 
             332 -> RGBColor[
              0.2283446787479909, 0.35733511362593967`, 0.9363152636977938], 
             68 -> RGBColor[
              0.27002626100566185`, 0.40114509934370585`, 0.9386889681449931],
              10 -> RGBColor[
              0.23750097993416716`, 0.3669589667156367, 0.9368367015048129], 
             250 -> RGBColor[
              0.25834749102875554`, 0.38886997162119286`, 0.9380238794720002],
              282 -> RGBColor[
              0.2671426063657563, 0.39811419548290095`, 0.9385247482792353], 
             374 -> RGBColor[
              0.19021908584372046`, 0.31726269818134456`, 0.934144067583656], 
             232 -> RGBColor[
              0.295092829761857, 0.42749165241872045`, 0.9401164721529931], 
             253 -> RGBColor[
              0.19109293756035423`, 0.31818117174092553`, 0.9341938321461705],
              55 -> RGBColor[
              0.9716313250190438, 0.9159679393868991, 0.3442934839840799], 
             325 -> RGBColor[
              0.289139123347183, 0.42123392949010874`, 0.9397774173803968], 
             91 -> RGBColor[
              0.4932978290383352, 0.5995204262840937, 0.953253358592837], 105 -> 
             RGBColor[
              0.20947576509879728`, 0.3375026890224135, 0.9352407069795285], 
             36 -> RGBColor[
              0.19287789451893317`, 0.32005727467719974`, 0.9342954828043544],
              123 -> RGBColor[
              0.21169783120855037`, 0.3398382213908926, 0.9353672503572267], 
             94 -> RGBColor[
              0.18118663655961964`, 0.30776902129339295`, 0.9336296829592377],
              312 -> RGBColor[
              0.3029090080003519, 0.4357069513217019, 0.9405615919406759], 96 -> 
             RGBColor[
              0.7481991240396009, 0.803218109314472, 0.9755371544320737], 2 -> 
             RGBColor[
              0.18498575182454155`, 0.3117621323146461, 0.9338460369532876], 
             262 -> RGBColor[
              0.2141514811516508, 0.34241716305148284`, 0.9355069820916365], 
             272 -> RGBColor[
              0.7409332819620127, 0.7975419782610151, 0.9748129631969344], 97 -> 
             RGBColor[
              0.19288958051724012`, 0.32006955740235543`, 0.93429614830467], 
             372 -> 
             RGBColor[
              0.19406834726399882`, 0.3213085159913272, 0.9343632773270688], 
             356 -> RGBColor[
              0.19499177110397153`, 0.3222790929955916, 0.9344158649486721], 
             346 -> RGBColor[
              0.3510664211934816, 0.47849782175157674`, 0.9435906198159696], 
             341 -> RGBColor[
              0.3362350503435996, 0.46565163376778274`, 0.9426455779802814], 
             209 -> RGBColor[
              0.33484250288537293`, 0.4644454791509371, 0.9425568460876246], 
             378 -> RGBColor[
              0.19081859398490578`, 0.3178928192487419, 0.9341782086854036], 
             66 -> RGBColor[
              0.2142707962291993, 0.34254257076299915`, 0.935513776908792], 
             139 -> RGBColor[
              0.18805967833656198`, 0.31499302397697726`, 0.9340210925206803],
              56 -> RGBColor[
              0.38165040818030865`, 0.5049881340836845, 0.9455394044224124], 
             335 -> RGBColor[
              0.1795029989097729, 0.3059994113746115, 0.9335338022857975], 
             314 -> RGBColor[
              0.23267428983588884`, 0.3618858093925185, 0.936561828644164], 
             144 -> RGBColor[
              0.1905501321581982, 0.3176106488474093, 0.9341629201815262], 
             298 -> RGBColor[
              0.19699767297971368`, 0.3243874230485212, 0.9345300980930298], 
             204 -> RGBColor[
              0.19363457114614188`, 0.3208525897884652, 0.9343385744188711], 
             207 -> RGBColor[
              0.18775722726537172`, 0.31467512872465075`, 0.9340038683796124],
              334 -> RGBColor[
              0.1849809522741401, 0.31175708768286514`, 0.9338457636259925], 
             149 -> RGBColor[
              0.21660346779159745`, 0.34499435647499893`, 0.9356466191033923],
              219 -> RGBColor[
              0.3371253879726633, 0.4664227994724073, 0.9427023095067106], 
             400 -> RGBColor[
              0.8501784807301029, 0.38669936800784144`, 0.19568427585662201`],
              9 -> RGBColor[
              0.19103464530579026`, 0.3181199028854364, 0.9341905124885087], 
             11 -> RGBColor[
              0.31196467996522614`, 0.44462985881031997`, 0.9410990914412173],
              44 -> RGBColor[
              0.2366745638317519, 0.36609035099419096`, 0.9367896383303533], 
             153 -> RGBColor[
              0.1824446187841665, 0.30909124037207153`, 0.9337013231859077], 
             32 -> RGBColor[
              0.9570322462930174, 0.8667218188173162, 0.28757881993815293`], 
             162 -> 
             RGBColor[
              0.27232886945688745`, 0.40356528681975196`, 0.9388200982898864],
              90 -> RGBColor[
              0.6083786689975903, 0.6929482364957771, 0.9623129438694364], 
             331 -> RGBColor[
              0.19914754728651962`, 0.3266470772548782, 0.9346525302543484], 
             8 -> RGBColor[
              0.2378122641398246, 0.36728614615234123`, 0.9368544286798214], 
             364 -> RGBColor[
              0.8176771202476999, 0.13687966915311423`, 0.16456093635363633`],
              342 -> RGBColor[
              0.18371444184961855`, 0.31042590492529404`, 0.9337736377309502],
              163 -> RGBColor[
              0.26679472020223177`, 0.3977485450677799, 0.938504936676874], 
             49 -> RGBColor[
              0.18767785554878408`, 0.3145917040180597, 0.9339993482777726], 
             338 -> RGBColor[
              0.23420030298526878`, 0.3634897459673388, 0.9366487328354871], 
             76 -> RGBColor[
              0.1938965482594379, 0.32112794434484765`, 0.9343534936279129], 
             369 -> RGBColor[
              0.19059767181486464`, 0.3176606160407541, 0.9341656274946448], 
             82 -> RGBColor[
              0.1807265568208277, 0.30728544831718235`, 0.9336034820987404], 
             67 -> RGBColor[
              0.42522253205912725`, 0.5427281177888938, 0.9483157816266544], 
             211 -> RGBColor[
              0.22188954865981286`, 0.3505503626243781, 
               0.9359476535887813]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9l2k4lWvYhs1zWMs8LNZoLbMSqfBetRslSppMScqwSaE2pQyZolBokCJT
JENtUlIZSkKyZSYyN6gQUcS3vuP4ju/98/x5f9zP/dz3dZ0XzcXH5jAfDw9P
Ai8Pz/+elo69Z87k6+EZlefErLsktniUNT+ZZOPCiayH+oNM1C/eOhdVwADF
RqXwwSsqpK3Za+fT2HB9/Vl1u70Map2EYrpGSWhfG5DscO43IfTIl3iRTgb1
gXe5XKwQ6lf01isOSuNh92snv/0qYHY8+mIcLw2J/pJ7eRXTRHoz6bH19Z/E
xPrnuy+8nSPoPlcYpbnaoNkqP80MJ0N6fCnd4xwLXhL+rWW5NDA193YYPhCG
LGlqsUd1GSLTzmYrvmPDbEtJvHumLBZD5h+9LdJH5Jk/Uv+liyJ6xQ1/L1dN
FHlYtPSsIYHOsq3QdJPAwiWPWst2QSSsu2ltNvWH+GKt/PNrlTSqLUqGmoYY
cKoVnPa+r4I18x/ZetnimIf4Cq8WGlQrW+579/BBzKlqsblMBqEcJcXEH1So
yZrbe46qoSTssCtpmyCSpvLcHdTI4Flzvzxyvwb4dCZ6G9hUfNM9OaD8RB3K
Cd6bjllTkLgrozuMoo725X8Y5GMqsJx9e4v3nA546xcPXx2kYMvb9vCTR9QR
V5yzRztDFWKi7uToX0JIdkuz5i2XRXiEs0V2oT42df3Tar9PAk3BdWJi/ZrI
EZwZ3chUxXiljFOq3gRhHwX7yFphXCa/Njy8jALnwj1Ry99Q8Lvwr4fadDZK
3B6tfuYjBe/4d4UHClmwEU9/pt5Fw4ZrX3Odr2og8tyJk4WLNPA9vpZI1hLA
nyNbWTO/SZjs5O1T7OHg7LInsdVGcjh7a5h+m08HScpViR5SPwiDz++z8g8v
Evv6ei/ZaH4lKtZ9Lw15wIKg8EXTml98YBX0VXRIMJHZ+DEjR1oWX9fY3r1i
yUZI3ctCuwo1xI5/CaaXSkP26v3DRuVzxLUPCWlWf5aIfQvlWb1JVGR3ZN2+
flADHzzEL+51UkLnx7o+8dszRMf1YmX9GiqiNc6R7W8tA1mSd73+fhmIMFIr
9v+7QIT0T4wJyclhT/hG+tczephsatnx6wUJPP/3Bb0IeFPlKYmR2P3NA+Ia
qE7zGmGf4EfxtLu5Ra8evDgx/UKv5SAcLeNq/FUPsiI2x3Qok0SJAqlV2EIT
//at9b18XQWLLyY28fvTEPk9UTzRkYRVh85470yRQcT9+HvEex5cCd6hceQx
B5ske1w7H/AhReDtgcBcPRxzC0qb8PxCRLbbGMwkcvdp8yon46EFYnxHBzHd
8oMwXu9z4flJFiZ2cJyva0wR2Rsjx4YiZPCwYEOx2YAu9spvzeLoSSGjtHc0
5qImXlxyvJmbrwZZdv7cel89SDceOFX7o5mYIxnZJLbzwaOnKOXmelX0XZP3
7mxmo8yfOR6xII8s/7VuJ96RUL3toHGuP3f/OQHMqR28+GxIWdUfpoJajOeY
NAti6Oa/qa25POCLS97l5CiBFSEn5JQaKWiqfhhw8ZkmWvK/ezg9ZeHJa6tr
FFMOtLYm8X6L0gBPqvep6RkKiKyJGgF5FbxI2/znmC8dfJkDsVrdFEjeTQ5G
GwdeH55EVSdT8bX022TvFS0cu75yPvnOJKEZnEu/YqWD4sb4T5zeHqLLdeO0
nxAVhOUzI5a1GhzcD+7O7JHCPs3aW1pkHihuvXhx7dgiYbx0OuXZTW5f5RYG
4/TeEXvzvl9y2CeACwdHGK28s4RvXv+m8XEWrL9JnJFOoINfrDNshYwyV9c+
f54o4tb9VoitdZwf36e3rxeS14Bt5Dn+Kj0Gtt4KK6AUMVGSXXyYeoDK1T2v
J+MW3HkZ6OTvlpZGycKHgopKNpqTWYw1PSw4d9eqW/TpQnj03wMxngoI+Cql
+7pOBuFU+/XnjvHjFbGhPOI8Ey/rW0W7HdQwmDR92fwQC2jwDPdtksYe2/tV
6dkaKI9gPOG5QMUKsanIlPc6/z/HTNrRANUBBgbTAw0dS6jYFjR0/70jGffu
7nAaL5cDqaHW524qG5yHE59U6Uy4+ezp5Zfl4CvvitUbw6g4ZPLbuSxECYvH
J3sCv8sBYSr/6bK4PrG7I+bG7E8iQXB9Dd/7T8QpNY+xxVQWDLIrlWg9bDD3
bSvO3MsDo/Z9g8bx2pi7bMbewztCyFRmDt7tUcfv6D+j7xdVEWN40++AkDaC
ku7XHcmn4Oiy+p8yczyoujBxM9lfEN1/D7s060hAcfCJnnyjMHY5Ga/aelQK
vrssonbupqCT98SDWyoc6F3yS2Nks1BvofSpM1AUKFQ4eOlkJZGhyl/zSUwA
EXtCxStbFZGqomUjG0jDVS8J8x5zVbSUGx+4WSMCT9fYaqujNFQyzsbPVGnh
x80H2vtTlLB7wLNa8DIFgSdbVy6tFwK15ueUtD8f/LuD7U9kK+CkepDj9kE9
8Jg0Xl917CNRoTlFa9zJg+bO4Pg2LRIqh9LbVK7q42KhZYPjUzEIPP3l2P2S
idaiPb9Emin4EO546XQDGWTdX2o7iucJKf/FqJ/Bcjj8Sr/D/TMvMsskYi9e
YUP2oORrz3tyyDl841lpvBg+rNhevrmQqys/9xYM0DSQ87vfXPolFZN+4SXL
eQ2gX9rwY4zFh5xw3SMTfXqIbOF194iTwtWTOwqqV+hiyG337bd/K2L8tPzl
hio9tEbE07YJSwFHaYZj9vWE/W5fMp+3NFCimuFK40B7PP7vnwpkqFb3V6wo
Z0H24q/gOFUqlv1cU/3MUA/NG8sZCV9lYbn70KWVwkxUq7HNvY8IoIKHOORr
QId0RKqKbIQkgvgGEhQdp4ifK5Ze8UyzIPkyRfyEnQyevvuZaLxGFF+EctyN
p7UQIxzY+CyTjjjBetc27v7vV+TVimVx/TPmvNArEzY6CeNCPhd5rNq6Y2TS
l4q1FV2xe/4oI8gzU/ofuhDGE0qv6p/iw5XEyy1lklyfFypMsBnmQ7P/8e3h
85ro+juEIHvwonPimWjbYW1QbeycR6MHicYlS6U6lijcu2b9JsRHicrrFw1u
K78nhjePvyXOk3H0cea/5BssdO4L25f0SBW955zTjLh6OPTrzCKH+x7Rhalp
R8XniaNPR28M/fOLKJY1Kb5Ry4ekV2OZmjnc/kwL5n96LIUqPxf57mgVVFqN
MVSeDBBg5+QoylFxzHWnjZCLKEq8LPYQ1coYfaMv+H5IB6yILuqnankoUA98
SR6iIs/1lHUmt54XDTE/tnpxsMsg/69IGw2UsEbbQrWEEXbR4NyxqmXQr0zf
JMOvg/UiM99nd9OwubijaMMsA8xiQ3sXKhVZNkqBHvRp4pzlz4ohjhqaDZ+G
bH7MQsyPUfPiv7j9j483VaWyYRI+ZmRexINKcRm3ucZxQnOgk6qqJIXOL1t+
vv3FwGjx5dOukdx5f0tqWzuriMTk9UeX9AURlrP459xnDRhl3JDKzxKE8lj2
21kxXjxIJtap9JJRP6Az8CtAEdWaNcEam8Rw7/cqZtRNbbjoZu1J1VSAHam7
8LyuLvKHQ7wPkpXhcYBXZchEHQnaq/yPyVIwQViNSJEFsCY28M8Fujy26F3W
TyzVgC5jhC9GXATNoV39yZMkOF8nfSvOXiTCQ1eETTjMEjrt6St9Nyvhv77o
ANUiRTzVZ2+6kCyH6MPd33beksWB7/ujYrYJoN2rYqDEmYmgkDxFqzQVDPC9
eNVwSAqD/BG6zh2qqBukb97pw4bQEJVVJsLC9oL+zR5iGrhgEe13aqc0Fp8W
Cld6cP1CLWFb7kkJFJ+JNNsq95FoFM+pMymkYvjZqQohNRJCPs9VhS6j4dWn
FRaZnRwEu7UrxRtz/0/1rfzKw0auqQx7kluv6p+5gaMVHHSZLkvvjVuGivzN
fiJ1XF7f7KW/IXCJ+DaS4xUXJoNF97VtuxxEYJLbZl1LZsORLa3vmMbEh+UR
ZU7LxwnTLt8n7EgetN5KLBoN5GDB/vxMvzEDydfvraqtVoJVVqpNuj0FHzf+
FRDydY74KW8W3OROwz3dHtUvTAMU3s6V+mDAj4bowNvnxRWhVx/KOuckiZN0
ySuZsdKoqGAr/ZuiBu0vWqoLInpwONM6cn6bHHYofC/OXqcNnvc+x1syvhEW
rYc+7NqsCFPR0m/hukpwwtqLjbwcjPMNjvnHq+PjvtUdwfvY4ImXpuW0ySH9
6oDq2AgHYlcI3y/lFFwzcp7aJSQJne7o1uXtVNDMf97NqGFCTOSuxFl5RQjl
VQkEdmsDHFJqglQ7MdzfMMwrpIJT3j7t+m/V4LRNqnfUTBjFtXcYRiwSkrRC
E8pcxLBwcsFSLYSGFQt5ahUZGqid/O9yx15uLthA6tH0lULFa6vr72WFEM4v
IqDKzRUfH9fMMmRmiNjQtZfcbDVQc3qdSeNDOlKrBQxDt2hDICbJMIBNg1Pw
JSuqrh7clw6YxkRxuapWYKNdAw290aSy9g8UkKIWyJMhWniwz2eHVz0Vla4r
ybMnJCHycm2N1yEa1BQ45PiDTExcXWzR+4frS+fuJtVrq+DMoUKlfSri8Dp7
uK5EWhPXlMmPjrr/Ih7LPju++ZoyGpefHAn9qIRXpvtc3nDzwfpnjyKfr1TD
UGprvKSHMtYoRRSc91ZGyVn+rSVBLBwmKa0p4+fDtfYjnaGBknBusk6pOjlB
8Jx/VhlqqInbWlJDcskioI6NDMyla8IqeWbtwggVp5eWEdYb1VE7TCr5b0QF
miMBjwtc9dGe5ndj1W0pjMhEXms/oAFDi+0Fc/cVMHtiN1PSjw6bxyURVWfU
IZ+43EpgGxPeEWP+Q4cEQGoaPuEkoo+TzWKeb45KIu67dCzpsyQY4ncME++p
oJ1muE73uig6pToqPUM+E0M/Ksi1BmxMJGf/DvosgcxIWpC9PQ3mewcbQgoF
Mfj0Ufc0Qx2LVcHd599y9Ztx46+gFn7oSfuXOL0Rxz9Wm5x9+NRxY5trLaeL
AjrH1dfaRwXKAkI7aHeUwS5Zs/b2XTqO6X9g8eSq4dPVjf/UFKtBSkzu4N5w
eUho3kt6PsBE1KRWhCa3fgcrQ+WVNfPElpKXpCAROv4OiJRvMWLjiLSFHL84
HU7D1e/I8aLwHXwz6rqDhsKy57nH1/BgZYovNU+Qgj1RkUs2ZwRQ3H0qoaFq
kIirfqjfyJbDmjX6Ic/ekZFq++HsSu154kXytNG1R3SMtIV+PC+iix3SLmlz
za0EX+F+CesDKggY/awStUESv3tvV3sVsRFaclkh/wEJS1eFz4rRNZA28qWK
Ua0IywHb2CVBQXhZXdZl/uaFiGTwt5ati8RcsUH++V1MOJio5A73s3HKzre+
sIGKyIHLnR/mtGAkqeMtNKYA33/5CtbuFcG7KTKTd4zLB0+OfPdvZ8JXfUY8
2oeGvaR56cBROpZfPLglwZOK0bUB0QFUPvCXmu7y1pXFb7WZxIMsIQxGGVz0
4ubPkog+RzyWxH8PHW9NNCphedXqxBsuMriUTW/hnRHChpSQ1U5CLHyoFmfW
TwvCOLdGWW5GHA6hcfd87ougkuXUGtzfQbjM3czfFCqCOpP9rboUFr6Qz/lr
uQmia/W2hvmDmkj/K91RME+SyyvUa3VCZOw+aPfLzIXLT5wNp2Q5bFRYHTZ7
8EkRzxXjXzzay0blcMGiZwoFBrQOg8eeYuh9tPoKKU8QQhkpoflc7iOV7llv
YcaHWx3pg0L6TBgfrwmtGFZC0HpaZOY6Nq5cORzokyQL4/9Uw9ubmIjjLO1X
3ysB76mVz8b0SEi3abO/qycHsc7wmgppPjgfvOf2ynWGmJ4JyLdslcQbj/3B
IjHqsLVvvGs2QYNv3I/jjyMpcFgpl32ALorfDLuWZkMuH99I7K8OGSJsL44P
2XG50XiVRmuTnAaGa/ZoOn5TgfWkii37jT42nHzOe/joFLFYlhPI8ePAzoy0
Uyiegj5+u6H68/x4WfMiU2VGHiEn7cJTmz4STavzd993EObeq9a8RmcZJgcD
h5Qu0hBQUWV7yPYPwbT59XWWf5qoqfuqdd1JCnbFFP4JP0EUXfCOP7AghUrT
nt6Aqz8JSaav/TJu3jC2C27/c0ERFtS2v6al9HBZwS/m7HYSmjO3lDry6cGS
JLtze5kCwtr4A59vVkBf2UiQGGkZbE0iZI5N/CDiVLOjFncx8O2dGyfigyg0
CIpRuO8CIX8wT53up4e5pLCIiKxR4vLwd2Xed7zIfZPq4HJMDjdNSNN1ERx8
rOPIR6tx8+m28nGquC6mBLIUbC0VUNxyr06LxUIiy3+nRB4Vqlf8r666uozL
Q7bd7+I+EqEHNZ/EcvOXvd7L6XddZNhpb7/9elIYWSfNFTPrxcBJvHG+QZGD
U3tVtMMKSZgpjO36wc9CXq9UWKsynevfRmdW/qODDLLr2PBdadydzgyOfyiF
sqDSEoFOXmxyyxNh2PKid8X+u4ptNOR66HxzK+fHX6uff7nE5c2goqjCPH99
HG+QSSpfEsXA9+Ku09kcdBr5jO4OV4Xy4oShfoEswmScHR5u4EeIiNiOu9R5
QrKVevcdVze+XCmNS7zKxGqZOG3JlRQwyH6ywkc4iD019GsrQwZTtdJM63ph
6J7A541ZJG4+owUXhZPAoG1L/zQuinE19SxagQbeqJVnr9OSxa+y/uYMewPM
H7OZSVknjO5LIjPnNQzgU2/Z77dZEOGves860mjIkt/FL+UpB1/zdculj2rh
SIPnobIMGkrfXRJa4aKJTe/TWXrcfRTwbIqvCeGFgMJ4yjMJJugF6X52TeKQ
XPXg1us4Ck5rbK1efK7Fza8OBWaVU8QtYwGLfEkOit90mLLkWKgLrDpj2jxD
DNuauzhcZ6GkNuBNaps+fFW3hIWGiuFIxiFnLWtVfEkd28+br4zhPvcLl2zE
wCN87bOpHh0WCUXz2hQ2brh2iR+/KosRXrdAYS02mqKVt3z8xoBE7G5TyWoW
Hhi9tj3/UR2UY2sF8kh68A9desKqUATVMbbFjTFJZN1P8Ek0p6Ou5LHVg75v
xEjixyi/PAUwGldl+8hqoZWgb6EmUyDw5MaRY8tF0GvwoH/1dUlImz4wGgpc
ILREHWItTv8m3kUZ+paeZ0Jn8YvIMS4vtkpEPPG+oAWz3WaLsbepKLx5NVcw
jIE3m2qEXwvyYzH9C/+/pTL4/t5GL/ShMEwq0wZtcqURPx/f+lmCm7OPnuHh
n9KBZTyfU1OoEgRioxXEqmaII0949i5GyiB9xeA7IXkmvo5aL9XcEUTv9ZeF
qmYTRNjDrvAL9yl48SBh+PYLdWzUF1Y++7capiMW+PJn5oj94azvwm9p8Coe
znJNnCP+2FuFZzyjQ8OgLVt/KweNmZH9qQFMMBhGl5Lu6OCGibXMBW8y3LMC
8p46/SJyxLVCXeToSOoTDti5YZ74feTWTNdurp9YDkvIlavh1YuqIkE1ZQhH
n/W7dYKDTyf4QwekNfCjl2/1Za6eOmn1ubBIVPAufH202ksW4tnqKz7LK+NV
todu/l9acJ29avP03DxxTy09zPvxT2LDxuQSxVIawjb1munWsNG1rFU21ZsF
kU6/1qWdo0RzxqmUgbeSGD5rqMgz9INoWLXKUaVJHcanQtRrVkuigHH6sPA2
HriH2z0xy/tECMQ2yjYYcP2JP//zlUfCSJef17RNbiKcJyzbzFfpo7P9jiwz
bJa4lm09cLdQCBKbU7JlK6cJu55PoTVbBVCXI/Zm5uMyWOT0Be2kiEOUcuDa
22382OBDMs/5Iwiyy0bG/RuzhGUH0ykmZIl44d4euCFmikhg7LnT7dtPFHh8
Eru1QRAwaT0yoiyCSKux1aYaCtig+L0o6cwEsXy+oMLvMx/cFfwKD8YpI+6M
+VpWCQXJe4M65U8x4el7R0JZjIy/f03sirstg+b53+80TaiQSDoSWdD4kxgd
raTZCciiMa26Ksh8lmA20X//nhXF2exSI8MaYVTeXEVpaBBByJvBnRZKeQTT
o8By4foyJEUf+R1whoG0LzLZZqX8cEy4N7Tujh7OromaNasiIdph2tJzfIL4
2B85rZ/BxHBARJFwKQurPb3NK6/zoy8hhTrvpocXcaqOJlpSyFi3TcPmOy8+
Rak2elrQUZ8cM8Z7XxYlDhZXMnOUYKQ8O3/OnIbDX6/0KIyp4ILzxEtTCRpc
I19oiweS8D+kNsXw
         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 14}], {
             RGBColor[
             0.18904790384743964`, 0.31603171164602595`, 0.9340773705015762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.18749255911212426`, 0.3143969457146576, 0.9339887959198263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 49}], {
             RGBColor[
             0.19061232216343427`, 0.3176760144859865, 0.9341664618103227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 62}], {
             RGBColor[
             0.19732629313580521`, 0.3247328236682947, 0.9345488125247692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 87}], {
             RGBColor[
             0.19586287681444192`, 0.32319468032858806`, 0.934465473130198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 119}], {
             RGBColor[
             0.18798137752672578`, 0.3149107248612813, 0.9340166334053959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 127}], {
             RGBColor[
             0.19417547404882396`, 0.3214211130344089, 0.9343693780389848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 129}], {
             RGBColor[
             0.19131755276026974`, 0.31841725655746295`, 0.9342066236495172]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 216}], {
             RGBColor[
             0.19662871859939152`, 0.3239996286017438, 0.9345090866868895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 231}], {
             RGBColor[
             0.1878698717924256, 0.3147935252646599, 0.9340102833187854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 235}], {
             RGBColor[
             0.19253038583618232`, 0.3196920210183055, 0.9342756926989647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 298}], {
             RGBColor[
             0.19527223087889906`, 0.32257387400121723`, 0.9344318367179512]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 313}], {
             RGBColor[
             0.20595700131663575`, 0.3338042451848521, 0.935040318587679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 317}], {
             RGBColor[
             0.19445041549410247`, 0.3217100939256911, 0.9343850355475539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 336}], {
             RGBColor[
             0.18695004027347276`, 0.31382672401755374`, 0.9339579002745498]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 361}], {
             RGBColor[
             0.205591391562574, 0.33341996615233593`, 0.9350194976530564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 393}], {
             RGBColor[
             0.1884550205876297, 0.3154085537489959, 0.9340436066770222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 396}], {
             RGBColor[
             0.1965523248147455, 0.3239193338904351, 0.9345047361738683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 97}], {
             RGBColor[
             0.18893766617089083`, 0.31591584485850077`, 0.9340710926289788]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 109}], {
             RGBColor[
             0.1831541470606865, 0.30983699957738503`, 0.9337417297716024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 181}], {
             RGBColor[
             0.1899547149925528, 0.3169848276546873, 0.9341290120547836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 191}], {
             RGBColor[
             0.19610476461646903`, 0.323448919745091, 0.9344792482826825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 193}], {
             RGBColor[
             0.18596534003799042`, 0.3127917416364609, 0.9339018230528726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 211}], {
             RGBColor[
             0.2034376502421772, 0.3311562474695121, 0.9348968452710344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 305}], {
             RGBColor[
             0.18360947068078184`, 0.31031557357129014`, 0.9337676597781759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 334}], {
             RGBColor[
             0.18498335204934083`, 0.3117596099987556, 0.93384590028964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 340}], {
             RGBColor[
             0.19396024281710603`, 0.32119489136342505`, 0.9343571209387445]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 360}], {
             RGBColor[
             0.18511749831467772`, 0.3119006062289892, 0.9338535397209994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 365}], {
             RGBColor[
             0.18295812271216946`, 0.3096309655584321, 0.9337305664749465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 370}], {
             RGBColor[
             0.18603673488354355`, 0.3128667821458319, 0.9339058888837076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 11}], {
             RGBColor[
             0.4469167817161049, 0.5580281285800609, 0.9506625439425702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 21}], {
             RGBColor[
             0.7725354937206939, 0.7794802979389553, 0.6358867741972027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 34}], {
             RGBColor[
             0.4225585018257533, 0.5327236209657705, 0.9492644797482566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 74}], {
             RGBColor[
             0.7224644673916434, 0.782535536200579, 0.9735133143364585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 86}], {
             RGBColor[
             0.49644576954540676`, 0.6009276484384913, 0.9538184872502891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 91}], {
             RGBColor[
             0.5375833562526594, 0.6354734123169479, 0.9567396775183801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 95}], {
             RGBColor[
             0.5706393994295823, 0.6623097973257487, 0.9593419703255434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 160}], {
             RGBColor[
             0.5207461823507223, 0.6218042360373149, 0.9554141935122193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[
             0.42709887646193556`, 0.5374958425847769, 0.9495230473669047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 233}], {
             RGBColor[
             0.7706376185941841, 0.8203361519689907, 0.9569123152308744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 263}], {
             RGBColor[
             0.48691076315351817`, 0.5926689051451934, 0.9532109250744729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 264}], {
             RGBColor[
             0.652580274743898, 0.7275933060781521, 0.9666403041170564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 285}], {
             RGBColor[
             0.7880339609127915, 0.8307135264515318, 0.7851026525209982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 312}], {
             RGBColor[
             0.44238894573366777`, 0.553566674835752, 0.9503937941922995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 348}], {
             RGBColor[
             0.45750426505624076`, 0.5671984745069012, 0.9513371690188597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 13}], {
             RGBColor[
             0.22349076802527734`, 0.3522333457006528, 0.9360388406628528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 66}], {
             RGBColor[
             0.22354481915991609`, 0.35229015687019793`, 0.9360419187950089]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 123}], {
             RGBColor[
             0.2222583366495916, 0.3509379821841447, 0.9359686555192263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 131}], {
             RGBColor[
             0.22303764420255517`, 0.35175708383326204`, 0.9360130359314853]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 140}], {
             RGBColor[
             0.22925899781803233`, 0.3582961209397305, 0.9363673328162189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 183}], {
             RGBColor[
             0.2914028738694214, 0.4198002713108441, 0.9400459473606144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 186}], {
             RGBColor[
             0.2198352252877424, 0.3483911385087073, 0.9358306629118409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 188}], {
             RGBColor[
             0.2173017232473819, 0.34572826723098127`, 0.9356863837186229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 203}], {
             RGBColor[
             0.22928794206914588`, 0.35832654318282237`, 0.9363689811485005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 232}], {
             RGBColor[
             0.26395583592624494`, 0.3947646976980586, 0.9383432664171094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 238}], {
             RGBColor[
             0.26140051176335477`, 0.3920788899859515, 0.9381977444862962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 275}], {
             RGBColor[
             0.235784586016354, 0.3651549278823552, 0.9367389554103707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 280}], {
             RGBColor[
             0.24217745234544014`, 0.3718742357253608, 0.937103019690414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 297}], {
             RGBColor[
             0.2198696831096341, 0.34842735586426754`, 0.9358326252338219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 309}], {
             RGBColor[
             0.2652076930566547, 0.39608047891444564`, 0.9384145578287296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 322}], {
             RGBColor[
             0.21636197354501668`, 0.3447405307102229, 0.9356328663633082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 325}], {
             RGBColor[
             0.26097898271890796`, 0.39163583623375275`, 0.9381737390308114]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 339}], {
             RGBColor[
             0.24218330961780632`, 0.3718803920899902, 0.9371033532534101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 8}], {
             RGBColor[
             0.2601258969540067, 0.39073918900607996`, 0.9381251570585274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 43}], {
             RGBColor[
             0.2713996679468782, 0.4025886371179538, 0.9387671816385219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 56}], {
             RGBColor[
             0.3320449689742487, 0.4595901829717516, 0.9424676449298229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.31447583347960173`, 0.4443726808567142, 0.9413481551518805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 90}], {
             RGBColor[
             0.44540909938288953`, 0.5535702341777979, 0.950854414653335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 100}], {
             RGBColor[
             0.24629351933764826`, 0.37620048310789195`, 0.9373374236164447]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 121}], {
             RGBColor[
             0.2966728547509243, 0.4289526354856623, 0.9402137650898452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 122}], {
             RGBColor[
             0.440201175363544, 0.5493422068445898, 0.9504444277972779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 175}], {
             RGBColor[
             0.282045444074704, 0.41377802280949016`, 0.9393734428399871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 178}], {
             RGBColor[
             0.36206488822589933`, 0.4855919281825182, 0.9443804876389659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 213}], {
             RGBColor[
             0.25252900688278906`, 0.3827543758705798, 0.9376925254075633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 227}], {
             RGBColor[
             0.24495455926499354`, 0.3747931511765599, 0.937261171821121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 274}], {
             RGBColor[
             0.38775900825169696`, 0.5067672930904867, 0.9463159883002454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 296}], {
             RGBColor[
             0.26370004466317304`, 0.39449584486246725`, 0.9383286994830867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 308}], {
             RGBColor[
             0.24197001296398313`, 0.37165620378303305`, 0.9370912063245189]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 319}], {
             RGBColor[
             0.3679006517731242, 0.4906453846924169, 0.9447526657346955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 352}], {
             RGBColor[
             0.26102097459574697`, 0.3916799723587493, 0.9381761304060758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 373}], {
             RGBColor[
             0.27714534160664284`, 0.4086277044311172, 0.939094389253483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 56}], {
             RGBColor[
             0.34361946259808085`, 0.47175570963568103`, 0.9431267952187714]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 79}], {
             RGBColor[
             0.26831622286540857`, 0.39934774083561936`, 0.9385915840026804]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 137}], {
             RGBColor[
             0.32002599977803325`, 0.451320237982877, 0.941623440630758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 169}], {
             RGBColor[
             0.6006886092479335, 0.6791324482420171, 0.965318253056975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 175}], {
             RGBColor[
             0.2936199376985361, 0.4259435494734196, 0.9400325931289355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 178}], {
             RGBColor[
             0.37363938184973156`, 0.4977574548464476, 0.9450396379279142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 252}], {
             RGBColor[
             0.3375773650971563, 0.4665223484650306, 0.9427417981088295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 277}], {
             RGBColor[
             0.2567019144406389, 0.38714036629150045`, 0.9379301663197194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 278}], {
             RGBColor[
             0.28187720037590647`, 0.4136011880147874, 0.9393638616102349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 300}], {
             RGBColor[
             0.6101439916355338, 0.6866719134983721, 0.9662201158700239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 314}], {
             RGBColor[
             0.26913140342587094`, 0.400204547290098, 0.9386380073296472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 319}], {
             RGBColor[
             0.37947514539695637`, 0.5028109113563464, 0.945411816023644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 352}], {
             RGBColor[
             0.27259546821957914`, 0.40384549902267874`, 0.9388352806950242]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 379}], {
             RGBColor[
             0.25634517615934155`, 0.38676541173934353`, 0.9379098506023464]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 65}], {
             RGBColor[
             0.36829577629683624`, 0.4914979419428903, 0.9447588725119885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 67}], {
             RGBColor[
             0.43693392935130804`, 0.5528719414914377, 0.9490620215061302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 68}], {
             RGBColor[
             0.3593357938245753, 0.4820804322688437, 0.9442486147652995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 96}], {
             RGBColor[
             0.5984222253415448, 0.6831169372542267, 0.9626727079088397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 173}], {
             RGBColor[
             0.36556257674898185`, 0.48862517592323496`, 0.9446032208411446]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[
             0.7215884971461117, 0.7768639400824314, 0.7979961077324451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 201}], {
             RGBColor[
             0.698844545732584, 0.7622666344739716, 0.960474027707296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 223}], {
             RGBColor[
             0.6892737381041355, 0.6614040887409706, 0.6061320446993241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 250}], {
             RGBColor[
             0.35349640883612216`, 0.4759428684075872, 0.943916070428803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 387}], {
             RGBColor[
             0.4913856837463006, 0.597841186558023, 0.9531378831854276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 43}], {
             RGBColor[
             0.24908603513269617`, 0.379135594264215, 0.9374964532598158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 56}], {
             RGBColor[
             0.30973133616006665`, 0.43613714011801286`, 0.9411969165511169]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 59}], {
             RGBColor[
             0.2921622006654197, 0.4209196380029755, 0.9400774267731745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 100}], {
             RGBColor[
             0.22397988652346618`, 0.35274744025415317`, 0.9360666952377386]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 121}], {
             RGBColor[
             0.2743592219367422, 0.4054995926319236, 0.9389430367111391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 175}], {
             RGBColor[
             0.2597318112605219, 0.39032497995575144`, 0.938102714461281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 213}], {
             RGBColor[
             0.230215374068607, 0.3593013330168411, 0.9364217970288573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 227}], {
             RGBColor[
             0.22264092645081146`, 0.35134010832282114`, 0.9359904434424149]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 237}], {
             RGBColor[
             0.2175725261235523, 0.3460128982237305, 0.9357018055418038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 296}], {
             RGBColor[
             0.241386411848991, 0.3710428020087285, 0.9370579711043807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 308}], {
             RGBColor[
             0.21965638014980107`, 0.34820316092929426`, 0.9358204779458129]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 352}], {
             RGBColor[
             0.23870734178156489`, 0.36822692950501057`, 0.9369054020273697]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 373}], {
             RGBColor[
             0.2548317087924608, 0.38517466157737845`, 0.937823660874777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 39}], {
             RGBColor[
             0.1871051393828018, 0.3139897430153101, 0.9339667329393776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.2089266760744028, 0.33692556164351994`, 0.9352094371718936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 150}], {
             RGBColor[
             0.19229026561489077`, 0.3194396394412268, 0.9342620182075883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 192}], {
             RGBColor[
             0.1863278971063823, 0.3131728121027866, 0.9339224701415624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 283}], {
             RGBColor[
             0.2000074908485974, 0.3275509324621929, 0.9347015027680361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 294}], {
             RGBColor[
             0.1904972038981096, 0.3175550178902107, 0.9341599059954147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 320}], {
             RGBColor[
             0.1934136507337484, 0.32062038842787655`, 0.9343259933282078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 347}], {
             RGBColor[
             0.19444294915612814`, 0.3217022463310869, 0.9343846103506517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 381}], {
             RGBColor[
             0.19359903145009902`, 0.3208152353145773, 0.9343365504857577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 384}], {
             RGBColor[
             0.19029625552141455`, 0.3173438084054412, 0.9341484622826384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.26166329356975937`, 0.3923550903258115, 0.9382127095214201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 37}], {
             RGBColor[
             0.29314980125126083`, 0.4217462676405007, 0.9401414095988625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 62}], {
             RGBColor[
             0.21930338871384658`, 0.34783214454915645`, 0.9358003756057394]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 87}], {
             RGBColor[
             0.2178399723924833, 0.34629400120944975`, 0.9357170362111682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 155}], {
             RGBColor[
             0.22229114501906733`, 0.3509724658606344, 0.9359705239073323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 170}], {
             RGBColor[
             0.2345826966210814, 0.3638916659237347, 0.936670509587346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 216}], {
             RGBColor[
             0.21860581417743288`, 0.3470989494826055, 0.9357606497678597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 256}], {
             RGBColor[
             0.29440488188335295`, 0.4228333554018322, 0.9402213822269152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 261}], {
             RGBColor[
             0.24873551087533646`, 0.3787671710452084, 0.9374764914219134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 298}], {
             RGBColor[
             0.21724932645694042`, 0.3456731948820789, 0.9356833997989213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 311}], {
             RGBColor[
             0.2701224968687157, 0.40124624933748154`, 0.9386944486350258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 313}], {
             RGBColor[
             0.22793409689467709`, 0.35690356606571383`, 0.9362918816686491]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 361}], {
             RGBColor[
             0.22756848714061534`, 0.35651928703319763`, 0.9362710607340264]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 396}], {
             RGBColor[
             0.21852942039278686`, 0.3470186547712968, 0.9357562992548385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 34}], {
             RGBColor[
             0.28760640007487454`, 0.41932535119602954`, 0.9397010272469036]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 35}], {
             RGBColor[
             0.27410810708868466`, 0.4051377894263376, 0.9389323194302751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 85}], {
             RGBColor[
             0.2763549775912347, 0.40749939278433556`, 0.9390602753814483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 86}], {
             RGBColor[
             0.361493667794528, 0.48752937866875046`, 0.9442550347489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 91}], {
             RGBColor[
             0.40263125450178067`, 0.5220751425472069, 0.9471762250170271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 93}], {
             RGBColor[
             0.2731424573639435, 0.4041228303399058, 0.9388773271070019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 95}], {
             RGBColor[
             0.43568729767870357`, 0.5489115275560077, 0.9497785178241904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 125}], {
             RGBColor[
             0.2867382877276377, 0.41841291007758175`, 0.9396515895329856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 162}], {
             RGBColor[
             0.29214677471105677`, 0.42409757281503596`, 0.9399595948655519]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 211}], {
             RGBColor[
             0.2669271143125195, 0.39759011071734907`, 0.9385233725149993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 214}], {
             RGBColor[
             0.2758548681185897, 0.40697374601981373`, 0.9390317948868268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 248}], {
             RGBColor[
             0.2649817698706437, 0.3955454303669761, 0.9384125880269136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 263}], {
             RGBColor[
             0.35195866140263943`, 0.47927063537545245`, 0.9436474725731201]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 312}], {
             RGBColor[
             0.30743684398278903`, 0.44016840506601096`, 0.9408303416909466]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.313125811057198, 0.4456106195888476, 0.9411739913250522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 17}], {
             RGBColor[
             0.2700762317403779, 0.40119762175422, 0.93869181390441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 22}], {
             RGBColor[
             0.3123757406994519, 0.44496094634460026`, 0.9411261975051177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 47}], {
             RGBColor[
             0.4262898849714413, 0.5411626092696967, 0.9490658048705467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 106}], {
             RGBColor[
             0.2676474114572338, 0.3986447776405352, 0.9385534961824027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 107}], {
             RGBColor[
             0.3285473986430889, 0.45896802364421685`, 0.9421566412492507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 118}], {
             RGBColor[
             0.27367870261090094`, 0.4049840470489852, 0.9388969692911083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 158}], {
             RGBColor[
             0.32361612706914167`, 0.45469680405977975`, 0.941842424985111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 209}], {
             RGBColor[
             0.3216593094784126, 0.45300190701520204`, 0.9417177382985756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 241}], {
             RGBColor[
             0.28584467655013013`, 0.4177712570264148, 0.9395898035090018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 270}], {
             RGBColor[
             0.3337876806083378, 0.46350689249828564`, 0.9424905473822769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 310}], {
             RGBColor[
             0.2940376027932159, 0.42638254196942454`, 0.9400563785381975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 323}], {
             RGBColor[
             0.35358359064672407`, 0.4806531148021672, 0.943751925265087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 324}], {
             RGBColor[
             0.4708028735942141, 0.577300258720949, 0.9525700303913813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 346}], {
             RGBColor[
             0.329771268632467, 0.46002807831552184`, 0.9422346251627481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 390}], {
             RGBColor[
             0.28559351861557547`, 0.41750727411286515`, 0.9395755004361839]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 66}], {
             RGBColor[
             0.21421674509456057`, 0.34248575959345395`, 0.9355106987766358]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 123}], {
             RGBColor[
             0.2129302625842361, 0.3411335849074007, 0.9354374355008532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 131}], {
             RGBColor[
             0.21370957013719966`, 0.34195268655651806`, 0.9354818159131122]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[
             0.2199309237526768, 0.34849172366298653`, 0.9358361127978458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 188}], {
             RGBColor[
             0.20797364918202638`, 0.3359238699542373, 0.9351551637002498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 203}], {
             RGBColor[
             0.21995986800379036`, 0.3485221459060784, 0.9358377611301275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 232}], {
             RGBColor[
             0.2546277618608894, 0.3849603004213146, 0.9378120463987364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 275}], {
             RGBColor[
             0.22645651195099847`, 0.3553505306056112, 0.9362077353919975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 280}], {
             RGBColor[
             0.23284937828008462`, 0.36206983844861684`, 0.9365717996720409]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 297}], {
             RGBColor[
             0.2105416090442786, 0.33862295858752356`, 0.9353014052154489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 309}], {
             RGBColor[
             0.25587961899129924`, 0.38627608163770166`, 0.9378833378103566]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 322}], {
             RGBColor[
             0.20703389947966117`, 0.33493613343347894`, 0.9351016463449351]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 325}], {
             RGBColor[
             0.25165090865355244`, 0.3818314389570088, 0.9376425190124382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 339}], {
             RGBColor[
             0.2328552355524508, 0.3620759948132462, 0.936572133235037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 29}], {
             RGBColor[
             0.18299367418147944`, 0.3096683324067703, 0.9337325910785299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 62}], {
             RGBColor[
             0.1928274082051604, 0.3200042103604074, 0.9342926076834728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 119}], {
             RGBColor[
             0.18348249259608096`, 0.310182111553394, 0.9337604285640995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 126}], {
             RGBColor[
             0.18556762080960376`, 0.31237371351057097`, 0.9338791735311889]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 127}], {
             RGBColor[
             0.18967658911817914`, 0.3166924997265216, 0.9341131731976884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 129}], {
             RGBColor[
             0.18681866782962492`, 0.3136886432495756, 0.9339504188082208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 196}], {
             RGBColor[
             0.18714224683050756`, 0.3140287452955969, 0.9339688461536289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 235}], {
             RGBColor[
             0.1880315009055375, 0.3149634077104182, 0.9340194878576683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 317}], {
             RGBColor[
             0.18995153056345765`, 0.3169814806178038, 0.9341288307062575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 326}], {
             RGBColor[
             0.18828033718868842`, 0.3152249504211414, 0.9340336587158735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 327}], {
             RGBColor[
             0.19007805312865012`, 0.317114463855815, 0.9341360359791719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 336}], {
             RGBColor[
             0.18245115534282794`, 0.3090981107096664, 0.9337016954332534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 396}], {
             RGBColor[
             0.19205343988410067`, 0.31919072058254777`, 0.9342485313325719]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 33}], {
             RGBColor[
             0.28118366953987284`, 0.41287224313372134`, 0.9393243660551096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 37}], {
             RGBColor[
             0.31731211488685307`, 0.44714239125067556`, 0.9415174176154697]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.24346570234943876`, 0.37322826815933124`, 0.9371763836223466]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 92}], {
             RGBColor[
             0.3916080301069964, 0.5102971083648917, 0.9465821312407912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 256}], {
             RGBColor[
             0.31856719551894513`, 0.448229479012007, 0.9415973902435224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 311}], {
             RGBColor[
             0.2942848105043079, 0.4266423729476564, 0.940070456651633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 313}], {
             RGBColor[
             0.25209641053026927`, 0.3822996896758886, 0.9376678896852563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 361}], {
             RGBColor[
             0.2517308007762076, 0.3819154106433724, 0.9376470687506336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 386}], {
             RGBColor[
             0.5232931103169385, 0.6153912271159707, 0.9581889419192983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 69}], {
             RGBColor[
             0.2797958916834022, 0.41057876108804503`, 0.9392759017239116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 106}], {
             RGBColor[
             0.2722971064429795, 0.4026970623499158, 0.9388488569979281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 107}], {
             RGBColor[
             0.33319709362883454`, 0.4630203083535974, 0.9424520020647762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 190}], {
             RGBColor[
             0.6369974104682594, 0.7082659607734624, 0.9502314057905163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 212}], {
             RGBColor[
             0.36755596390986156`, 0.4927802348639901, 0.9446413188967272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 241}], {
             RGBColor[
             0.29049437153587576`, 0.42182354173579545`, 0.9398851643245274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 268}], {
             RGBColor[
             0.49856920010276634`, 0.5995528138290274, 0.9550727772448264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 270}], {
             RGBColor[
             0.3384373755940835, 0.46755917720766627`, 0.9427859081978025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 274}], {
             RGBColor[
             0.4054269963890745, 0.5245026293096915, 0.9473527216519175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 295}], {
             RGBColor[
             0.3734051820083968, 0.4978465335906915, 0.9450140259017055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 310}], {
             RGBColor[
             0.2986872977789616, 0.43043482667880517`, 0.9403517393537228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 324}], {
             RGBColor[
             0.47545256857995977`, 0.5813525434303296, 0.9528653912069069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 351}], {
             RGBColor[
             0.6137824648944775, 0.6902841557450048, 0.9663635368138602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 373}], {
             RGBColor[
             0.29481332974402036`, 0.42636304065032193`, 0.9401311226051551]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 380}], {
             RGBColor[
             0.26894987250182517`, 0.3991789072508731, 0.9386582369767682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 390}], {
             RGBColor[
             0.2902432136013212, 0.4215595588222458, 0.9398708612517093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 22}], {
             RGBColor[
             0.2739758563683775, 0.40460023321935323`, 0.9389393809000012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 48}], {
             RGBColor[
             0.23593219427525336`, 0.3653100735213626, 0.936747361482348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 61}], {
             RGBColor[
             0.22052046256389546`, 0.34911136633249684`, 0.9358696861610002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 118}], {
             RGBColor[
             0.23527881827982655`, 0.36462333392373825`, 0.9367101526859918]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 158}], {
             RGBColor[
             0.2852162427380673, 0.4143360909345327, 0.9396556083799944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 164}], {
             RGBColor[
             0.21631448031938844`, 0.34469061231884324`, 0.9356301616943686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 173}], {
             RGBColor[
             0.25707808713188923`, 0.38753574764073073`, 0.9379515887979883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 209}], {
             RGBColor[
             0.2832594251473382, 0.412641193889955, 0.9395309216934591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 241}], {
             RGBColor[
             0.2474447922190557, 0.37741054390116785`, 0.9374029869038852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 287}], {
             RGBColor[
             0.2108043778715786, 0.3388991452855218, 0.9353163695114319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 323}], {
             RGBColor[
             0.3151837063156497, 0.44029240167692024`, 0.9415651086599703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 346}], {
             RGBColor[
             0.29137138430139253`, 0.41966736519027487`, 0.9400478085576316]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 354}], {
             RGBColor[
             0.2237645258481464, 0.35252108252973663`, 0.9360544307658767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 371}], {
             RGBColor[
             0.20911196002482746`, 0.33712030682309724`, 0.9352199888187673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 388}], {
             RGBColor[
             0.22559527698605156`, 0.35444531805200136`, 0.9361586893348268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 389}], {
             RGBColor[
             0.21716250001380405`, 0.34558193478522814`, 0.9356784551614329]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 45}], {
             RGBColor[
             0.4449748432614876, 0.5535011435034702, 0.9507944263097807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 74}], {
             RGBColor[
             0.7341001698400949, 0.7919819236306536, 0.974429319456183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 86}], {
             RGBColor[
             0.5080814719938581, 0.6103740358685661, 0.9547344923700136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 91}], {
             RGBColor[
             0.5492190587011108, 0.6449197997470224, 0.9576556826381046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 112}], {
             RGBColor[
             0.7711240798821252, 0.7393399357057666, 0.6151558638126768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 141}], {
             RGBColor[
             0.7353689115489879, 0.586455396789142, 0.5858108169853278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 148}], {
             RGBColor[
             0.46955925293009415`, 0.5770080258985608, 0.9522798906351313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 179}], {
             RGBColor[
             0.5295441815391476, 0.6289468481238254, 0.9561068042364651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 232}], {
             RGBColor[
             0.4501165590628717, 0.5589054128143358, 0.9510872394181826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 257}], {
             RGBColor[
             0.46412234198098856`, 0.5722988469015355, 0.9519334554771259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 279}], {
             RGBColor[
             0.638687245246097, 0.7170964540862654, 0.9650118438159424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 285}], {
             RGBColor[
             0.7996696633612428, 0.8401599138816065, 0.7860186576407228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 288}], {
             RGBColor[
             0.45525573629442806`, 0.5643070139273578, 0.9513799079587884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 399}], {
             RGBColor[
             0.7658581753592988, 0.7184623790314186, 0.610918793426945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 185}], {
             RGBColor[
             0.330002266441723, 0.4557835793222022, 0.9424120819002554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 198}], {
             RGBColor[
             0.30685620721234774`, 0.43573562617248035`, 0.9409372354734161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 205}], {
             RGBColor[
             0.30521095643223367`, 0.4343105926394541, 0.9408324015485454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 219}], {
             RGBColor[
             0.2987647907941907, 0.4287272479574868, 0.9404216575742097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 262}], {
             RGBColor[
             0.23727783738368446`, 0.36672442974702457`, 0.9368239938666727]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 284}], {
             RGBColor[
             0.2685014480461575, 0.3995424242445413, 0.938602132302708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 293}], {
             RGBColor[
             0.3046492475878372, 0.4338240686707453, 0.9407966099576801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 331}], {
             RGBColor[
             0.22977587045111889`, 0.35883938684872224`, 0.9363967679480286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 338}], {
             RGBColor[
             0.24730224830049347`, 0.3772607212049526, 0.937394869238598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.1986384662361157, 0.32611200079330077`, 0.9346235388416457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 36}], {
             RGBColor[
             0.19158305641128354`, 0.3186963177285822, 0.934221743689665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 80}], {
             RGBColor[
             0.18504810846190303`, 0.31182767309415216`, 0.933849588071537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 151}], {
             RGBColor[
             0.19115376674236922`, 0.3182451070680162, 0.9341972962780976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 168}], {
             RGBColor[
             0.18724662483160132`, 0.31413845319269396`, 0.9339747903263778]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 265}], {
             RGBColor[
             0.19013547399899927`, 0.31717481683124543`, 0.9341393060127917]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 291}], {
             RGBColor[
             0.18873168488737596`, 0.31569934546955897`, 0.9340593622996046]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 304}], {
             RGBColor[
             0.185589373288035, 0.312396576744589, 0.9338804123026556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 378}], {
             RGBColor[
             0.19055340614426983`, 0.31761409001435326`, 0.9341631066301896]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 383}], {
             RGBColor[
             0.1993210537450841, 0.3268294435437743, 0.9346624111904838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 24}], {
             RGBColor[
             0.8919944774662327, 0.5241583098068742, 0.2395431849721498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 25}], {
             RGBColor[
             0.890260551987202, 0.5108305987640545, 0.23788277597524127`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 27}], {
             RGBColor[
             0.8921201702935075, 0.5251244399562564, 0.23966354856549787`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 32}], {
             RGBColor[
             0.9601171751337108, 0.8771280081727125, 0.29956318594431774`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 78}], {
             RGBColor[
             0.8915698412637564, 0.5208943698778701, 0.23913655286510038`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 95}], {
             RGBColor[
             0.7613060096832925, 0.7703636969149021, 0.6350027480788232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 104}], {
             RGBColor[
             0.8911056135339068, 0.5173261121203578, 0.23869200786672617`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 160}], {
             RGBColor[
             0.7114127926044326, 0.7298581356264684, 0.631074971265499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 172}], {
             RGBColor[
             0.8935026650840421, 0.5357509007293852, 0.24098742713821833`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 208}], {
             RGBColor[
             0.9781086897296334, 0.9394569243444684, 0.5384830216306559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 217}], {
             RGBColor[
             0.9781358461419554, 0.9375595363156388, 0.3992965964312667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 230}], {
             RGBColor[
             0.8904702103094787, 0.5124421245019355, 0.2380835450214286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 233}], {
             RGBColor[
             0.9613042288478943, 0.9283900515581442, 0.6325730929841542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 240}], {
             RGBColor[
             0.8974455137213154, 0.5660573631227573, 0.24476310344608182`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 242}], {
             RGBColor[
             0.907737765098039, 0.6451681172975665, 0.25461897498786773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 244}], {
             RGBColor[
             0.9589837634229517, 0.9266594522436353, 0.6365010356742713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 264}], {
             RGBColor[
             0.8432468849976082, 0.8356472056673055, 0.6423010818703361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 285}], {
             RGBColor[
             0.9787005711665018, 0.9387674260406853, 0.4607634302742779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 357}], {
             RGBColor[
             0.910151296596057, 0.6637195780075789, 0.25693017547606367`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 47}], {
             RGBColor[
             0.4301895095994409, 0.5445652207348299, 0.9493133718661378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.27823170323432733`, 0.40907339811174287`, 0.9391817450830557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 96}], {
             RGBColor[
             0.5322372446835262, 0.6257908335621027, 0.9584554594663912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 118}], {
             RGBColor[
             0.2775783272389005, 0.4083866585141185, 0.9391445362866995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 158}], {
             RGBColor[
             0.3275157516971413, 0.458099415524913, 0.9420899919807021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 173}], {
             RGBColor[
             0.2993775960909632, 0.43129907223111097`, 0.940385972398696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 209}], {
             RGBColor[
             0.32555893410641223`, 0.4564045184803353, 0.9419653052941668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 241}], {
             RGBColor[
             0.28974430117812966`, 0.42117386849154814`, 0.9398373705045929]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 310}], {
             RGBColor[
             0.2979372274212155, 0.4297851534345578, 0.9403039455337885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 323}], {
             RGBColor[
             0.35748321527472365`, 0.48405572626730053`, 0.943999492260678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 346}], {
             RGBColor[
             0.3336708932604665, 0.46343068978065516`, 0.9424821921583393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 354}], {
             RGBColor[
             0.2660640348072204, 0.3962844071201169, 0.9384888143665844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 388}], {
             RGBColor[
             0.26789478594512556`, 0.39820864264238165`, 0.9385930729355345]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 75}], {
             RGBColor[
             0.255511442446525, 0.3858891047454028, 0.9378623707008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 120}], {
             RGBColor[
             0.40567769043424073`, 0.5225843384798207, 0.9476110227757661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 132}], {
             RGBColor[
             0.32566481114992, 0.45504559524241234`, 0.9420251663053016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 160}], {
             RGBColor[
             0.3763398438622711, 0.4987665529777692, 0.9453014400255476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 202}], {
             RGBColor[
             0.2682077809117381, 0.39923376146669465`, 0.9385854083938443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 220}], {
             RGBColor[
             0.46443936234214256`, 0.5702897109178078, 0.9522369568394528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 229}], {
             RGBColor[
             0.24996961512608984`, 0.38006429285947896`, 0.9375467718333002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 260}], {
             RGBColor[
             0.2588190028871956, 0.3893655604799919, 0.938050731374799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 307}], {
             RGBColor[
             0.32070535665531497`, 0.4507499650286162, 0.9417091542503788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 321}], {
             RGBColor[
             0.42370887427578074`, 0.5372228658179581, 0.9490305036181749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 341}], {
             RGBColor[
             0.3146456284168403, 0.44550133299924655`, 0.9413230337254305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 348}], {
             RGBColor[
             0.3130979265677895, 0.44416079144735543`, 0.9412244155321879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 366}], {
             RGBColor[
             0.34372780451171075`, 0.47069085221995155`, 0.9431761242698371]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.8209125437853362, 0.16174855223502174`, 0.16765918158716517`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 32}], {
             RGBColor[
             0.8889095486255394, 0.5137521204514779, 0.227558818965985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 73}], {
             RGBColor[
             0.8757010840349191, 0.46170115302421727`, 0.21528423867768243`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.8419234511371824, 0.5272135480684979, 0.5771697251114055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 78}], {
             RGBColor[
             0.8203622147555851, 0.15751848215663547`, 0.1671321858867677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 104}], {
             RGBColor[
             0.8198979870257355, 0.15395022439912315`, 0.1666876408883935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 112}], {
             RGBColor[
             0.8789473611792127, 0.4745715601436108, 0.21789626946789925`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 141}], {
             RGBColor[
             0.8431921928460754, 0.3216870212269862, 0.1885512226405503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 172}], {
             RGBColor[
             0.8222950385758708, 0.17237501300815056`, 0.16898306015988562`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 208}], {
             RGBColor[
             0.906901063221462, 0.5760810366232336, 0.4664786546523232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 240}], {
             RGBColor[
             0.8262378872131442, 0.20268147540152273`, 0.17275873646774914`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 242}], {
             RGBColor[
             0.8365301385898678, 0.28179222957633193`, 0.182614608009535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 243}], {
             RGBColor[
             0.8951565236421906, 0.5687878448594291, 0.5520035990795774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 285}], {
             RGBColor[
             0.9074929446583304, 0.5753915383194507, 0.38875906329594523`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 337}], {
             RGBColor[
             0.9074168352108218, 0.5752287479070755, 0.3804750196277067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 357}], {
             RGBColor[
             0.8389436700878857, 0.3003436902863443, 0.184925808497731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 399}], {
             RGBColor[
             0.8736814566563863, 0.4536940034692628, 0.2136591990821675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 32}], {
             RGBColor[
             0.8871756231465087, 0.5004244094086581, 0.22589840996907645`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 78}], {
             RGBColor[
             0.8186282892765544, 0.1441907711138157, 0.16547177688985915`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 83}], {
             RGBColor[
             0.881176745521725, 0.5463271969673706, 0.5710722243747279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 194}], {
             RGBColor[
             0.9059253338243674, 0.5624195574854407, 0.4052009770396422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 201}], {
             RGBColor[
             0.8831813824108397, 0.5478222518769809, 0.567678897014493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 217}], {
             RGBColor[
             0.9051942941547533, 0.5608559375515845, 0.32563182045602546`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 223}], {
             RGBColor[
             0.8736105747823911, 0.4469597061439798, 0.21333691400652116`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 230}], {
             RGBColor[
             0.8175286583222767, 0.13573852573788114`, 0.16441876904618735`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 242}], {
             RGBColor[
             0.8347962131108371, 0.26846451853351216`, 0.18095419901262647`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 244}], {
             RGBColor[
             0.8860422114357496, 0.549955853479581, 0.56283625969903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 245}], {
             RGBColor[
             0.8180745277590571, 0.13993431743048723`, 0.16494149423531956`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 328}], {
             RGBColor[
             0.8434248781398908, 0.3172892303900453, 0.1885318018785458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 357}], {
             RGBColor[
             0.837209744608855, 0.2870159792435245, 0.18326539950082243`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 364}], {
             RGBColor[
             0.81749806012385, 0.1355033345765571, 0.16438946817681815`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 385}], {
             RGBColor[
             0.9058721590894482, 0.562305822104239, 0.3994132353001115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 105}], {
             RGBColor[
             0.19823757833601402`, 0.32569064219253296`, 0.9346007088687955]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 128}], {
             RGBColor[
             0.19080558249119994`, 0.3178791433438807, 0.9341774677000858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 159}], {
             RGBColor[
             0.18375580691440718`, 0.3104693822310835, 0.9337759934101959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 171}], {
             RGBColor[
             0.18798107467478986`, 0.3149104065446947, 0.9340166161584262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 215}], {
             RGBColor[
             0.18499791179933114`, 0.3117749132191369, 0.9338467294458628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 218}], {
             RGBColor[
             0.188929981383257, 0.31590776765945394`, 0.9340706549916917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 342}], {
             RGBColor[
             0.18535691671142462`, 0.3121522501439733, 0.9338671742445064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 349}], {
             RGBColor[
             0.19449252215171758`, 0.32175435069256086`, 0.9343874334594139]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 353}], {
             RGBColor[
             0.1885101327336185, 0.315466480108742, 0.9340467452322052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 32}], {
             RGBColor[
             0.8890352414528142, 0.5147182506008601, 0.2276791825593331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 73}], {
             RGBColor[
             0.8758267768621938, 0.46266728317359945`, 0.2154046022710305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 74}], {
             RGBColor[
             0.8420491439644571, 0.52817967821788, 0.5772900887047536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 78}], {
             RGBColor[
             0.8204879075828598, 0.15848461230601768`, 0.16725254948011575`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 104}], {
             RGBColor[
             0.8200236798530103, 0.15491635454850536`, 0.16680800448174155`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 112}], {
             RGBColor[
             0.8790730540064875, 0.47553769029299303`, 0.21801663306124733`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 141}], {
             RGBColor[
             0.8433178856733501, 0.32265315137636846`, 0.18867158623389835`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 172}], {
             RGBColor[
             0.8224207314031455, 0.17334114315753277`, 0.1691034237532337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 208}], {
             RGBColor[
             0.9070267560487368, 0.5770471667726158, 0.46659901824567124`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 225}], {
             RGBColor[
             0.8528742555567694, 0.5368113283617635, 0.5783225975121196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 240}], {
             RGBColor[
             0.8263635800404189, 0.20364760555090494`, 0.1728791000610972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 243}], {
             RGBColor[
             0.8952822164694654, 0.5697539750088114, 0.5521239626729255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 285}], {
             RGBColor[
             0.9076186374856052, 0.576357668468833, 0.38887942688929333`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 337}], {
             RGBColor[
             0.9075425280380967, 0.5761948780564576, 0.3805953832210548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 357}], {
             RGBColor[
             0.8390693629151604, 0.3013098204357265, 0.18504617209107904`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 399}], {
             RGBColor[
             0.873807149483661, 0.45466013361864505`, 0.21377956267551557`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 36}], {
             RGBColor[
             0.19993330434376533`, 0.3274729577419183, 0.9346972779563351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 151}], {
             RGBColor[
             0.19950401467485102`, 0.3270217470813523, 0.9346728305447676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 168}], {
             RGBColor[
             0.19559687276408316`, 0.32291509320603007`, 0.9344503245930478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 265}], {
             RGBColor[
             0.1984857219314811, 0.32595145684458154`, 0.9346148402794617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 267}], {
             RGBColor[
             0.23148773999796957`, 0.36063867028126045`, 0.9364942563862377]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 282}], {
             RGBColor[
             0.2370656602671769, 0.3665014181447689, 0.9368119106937756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 291}], {
             RGBColor[
             0.1970819328198578, 0.3244759854828951, 0.9345348965662746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 304}], {
             RGBColor[
             0.1939396212205168, 0.3211732167579251, 0.9343559465693256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 378}], {
             RGBColor[
             0.19890365407675165`, 0.32639073002768937`, 0.9346386408968597]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 383}], {
             RGBColor[
             0.20767130167756592`, 0.3356060835571104, 0.9351379454571538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.19127206346984504`, 0.31836944442903903`, 0.934204033101723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 87}], {
             RGBColor[
             0.18980864714848175`, 0.31683130108933233`, 0.9341206937071518]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 119}], {
             RGBColor[
             0.18192714786076558`, 0.30854734562202557`, 0.9336718539823496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 127}], {
             RGBColor[
             0.18812124438286376`, 0.3150577337951532, 0.9340245986159385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 129}], {
             RGBColor[
             0.18526332309430954`, 0.3120538773182072, 0.933861844226471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 231}], {
             RGBColor[
             0.1818156421264654, 0.3084301460254042, 0.9336655038957391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 235}], {
             RGBColor[
             0.18647615617022215`, 0.31332864177904984`, 0.9339309132759184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 317}], {
             RGBColor[
             0.1883961858281423, 0.3153467146864354, 0.9340402561245076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 326}], {
             RGBColor[
             0.18672499245337307`, 0.31359018448977305`, 0.9339450841341236]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 327}], {
             RGBColor[
             0.18852270839333474`, 0.31547969792444663`, 0.934047461397422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 336}], {
             RGBColor[
             0.18089581060751259`, 0.30746334477829806`, 0.9336131208515035]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 396}], {
             RGBColor[
             0.19049809514878532`, 0.31755595465117936`, 0.9341599567508221]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 54}], {
             RGBColor[
             0.1824115228296057, 0.3090564544254234, 0.9336994384202565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 63}], {
             RGBColor[
             0.18069605079375822`, 0.30725338454853857`, 0.9336017448256284]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 224}], {
             RGBColor[
             0.17977250803868983`, 0.30628268255696894`, 0.9335491504319864]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 297}], {
             RGBColor[
             0.19356559882175525`, 0.3207800955024369, 0.9343346465470327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 318}], {
             RGBColor[
             0.18730055861877407`, 0.31419514102261215`, 0.9339778617757692]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 345}], {
             RGBColor[
             0.1795989351746539, 0.30610024647171197`, 0.9335392657141575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 81}], {
             RGBColor[
             0.1880171511030766, 0.3149483251582018, 0.9340186706576468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 106}], {
             RGBColor[
             0.21164758701888683`, 0.33978541156189057`, 0.935364389024955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 164}], {
             RGBColor[
             0.19871454021211585`, 0.32619195936544565`, 0.9346278711420376]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 192}], {
             RGBColor[
             0.18904880805086632`, 0.3160326620211572, 0.9340774219946237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 241}], {
             RGBColor[
             0.22984485211178313`, 0.3589118909477702, 0.9364006963515542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 271}], {
             RGBColor[
             0.18778814176396494`, 0.3147076218227647, 0.9340056289145733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 287}], {
             RGBColor[
             0.19320443776430601`, 0.3204004923321242, 0.9343140789591009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 292}], {
             RGBColor[
             0.19543097961487327`, 0.32274072898797734`, 0.9344408772236172]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 371}], {
             RGBColor[
             0.1915120199175549, 0.31862165386969954`, 0.9342176982664363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 374}], {
             RGBColor[
             0.1933477765192394, 0.32055115045176114`, 0.9343222418891437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 382}], {
             RGBColor[
             0.18918398084593196`, 0.3161747371992214, 0.9340851198853325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 384}], {
             RGBColor[
             0.19301716646589862`, 0.32020365832381187`, 0.9343034141356996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 389}], {
             RGBColor[
             0.19956255990653143`, 0.3270832818318305, 0.9346761646091019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 78}], {
             RGBColor[
             0.888484912423063, 0.5104881805224738, 0.22715218685893562`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 104}], {
             RGBColor[
             0.8880206846932135, 0.5069199227649615, 0.22670764186056142`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 172}], {
             RGBColor[
             0.8904177362433487, 0.5253447113739889, 0.22900306113205354`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 194}], {
             RGBColor[
             0.9757819569708761, 0.9287169668940988, 0.4668813870087187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 208}], {
             RGBColor[
             0.97502376088894, 0.929050734989072, 0.526498655624491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 217}], {
             RGBColor[
             0.975050917301262, 0.9271533469602427, 0.3873122304251019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 223}], {
             RGBColor[
             0.9434671979288998, 0.8132571155526379, 0.27501732397559764`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 230}], {
             RGBColor[
             0.8873852814687854, 0.5020359351465393, 0.22609917901526383`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 240}], {
             RGBColor[
             0.8943605848806221, 0.5556511737673611, 0.23277873743991706`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 242}], {
             RGBColor[
             0.9046528362573457, 0.6347619279421703, 0.24263460898170292`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 357}], {
             RGBColor[
             0.9070663677553636, 0.6533133886521827, 0.2449458094698989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 364}], {
             RGBColor[
             0.8873546832703587, 0.5018007439852152, 0.22606987814589463`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 385}], {
             RGBColor[
             0.9757287822359568, 0.928603231512897, 0.461093645269188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 387}], {
             RGBColor[
             0.7455791435710649, 0.7496942133696903, 0.622023162461701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 92}], {
             RGBColor[
             0.3869660924415177, 0.5054181375626268, 0.9463177797578736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 182}], {
             RGBColor[
             0.3125367270389322, 0.44214783260778046`, 0.9412445628049322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 256}], {
             RGBColor[
             0.3139252578534664, 0.443350508209742, 0.9413330387606047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 281}], {
             RGBColor[
             0.3526148324525338, 0.4768614731328931, 0.9437983042422098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 311}], {
             RGBColor[
             0.28964287283882917`, 0.4217634021453914, 0.9398061051687154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 35}], {
             RGBColor[
             0.24974982719833305`, 0.3798332818120472, 0.9375342552359615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 85}], {
             RGBColor[
             0.25199669770088307`, 0.3821948851700452, 0.9376622111871347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 86}], {
             RGBColor[
             0.3371353879041764, 0.46222487105446, 0.9428569705546225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 91}], {
             RGBColor[
             0.37827297461142906`, 0.4967706349329164, 0.9457781608227135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 93}], {
             RGBColor[
             0.24878417747359188`, 0.37881832272561544`, 0.9374792629126882]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 95}], {
             RGBColor[
             0.41132901778835196`, 0.5236070199417173, 0.9483804536298768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 125}], {
             RGBColor[
             0.2623800078372861, 0.3931084024632914, 0.9382535253386719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 162}], {
             RGBColor[
             0.2677884948207052, 0.39879306520074553`, 0.9385615306712383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 211}], {
             RGBColor[
             0.2425688344221679, 0.3722856031030586, 0.9371253083206856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 214}], {
             RGBColor[
             0.25149658822823806`, 0.38166923840552336`, 0.9376337306925131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 248}], {
             RGBColor[
             0.24062348998029212`, 0.37024092275268566`, 0.9370145238326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 263}], {
             RGBColor[
             0.3276003815122878, 0.45396612776116196`, 0.9422494083788064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 340}], {
             RGBColor[
             0.23309142699709673`, 0.3623242469969716, 0.9365855839883956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 42}], {
             RGBColor[
             0.22638274960055194`, 0.35527300169848874`, 0.9362035347352613]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 85}], {
             RGBColor[
             0.2384984047146932, 0.36800732340035325`, 0.9368935033705061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 86}], {
             RGBColor[
             0.32363709491798653`, 0.44803730928476804`, 0.942088262737994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 93}], {
             RGBColor[
             0.235285884487402, 0.3646307609559235, 0.9367105550960597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 97}], {
             RGBColor[
             0.21457055736469166`, 0.3428576387223553, 0.9355308478620015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 98}], {
             RGBColor[
             0.21863346925867172`, 0.3471280167264209, 0.9357622246838242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 125}], {
             RGBColor[
             0.24888171485109623`, 0.37892084069359944`, 0.9374848175220434]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 162}], {
             RGBColor[
             0.25429020183451534`, 0.3846055034310536, 0.9377928228546097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 211}], {
             RGBColor[
             0.22907054143597805`, 0.35809804133336665`, 0.9363566005040571]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 214}], {
             RGBColor[
             0.23799829524204824`, 0.3674816766358314, 0.9368650228758846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 248}], {
             RGBColor[
             0.22712519699410227`, 0.3560533609829937, 0.9362458160159715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 263}], {
             RGBColor[
             0.31410208852609794`, 0.43977856599147, 0.9414807005621779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 340}], {
             RGBColor[
             0.21959313401090685`, 0.34813668522727964`, 0.9358168761717671]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 80}], {
             RGBColor[
             0.1863429465695527, 0.31318863004276976`, 0.9339233271862263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 151}], {
             RGBColor[
             0.19244860485001886`, 0.3196060640166337, 0.9342710353927868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 168}], {
             RGBColor[
             0.18854146293925098`, 0.3154994101413115, 0.9340485294410671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 265}], {
             RGBColor[
             0.1914303121066489, 0.318535773779863, 0.934213045127481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 277}], {
             RGBColor[
             0.20034660319217895`, 0.3279073610362615, 0.9347208147143313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 304}], {
             RGBColor[
             0.18688421139568462`, 0.3137575336932065, 0.933954151417345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 378}], {
             RGBColor[
             0.1918482442519195, 0.31897504696297085`, 0.934236845744879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 383}], {
             RGBColor[
             0.20061589185273376`, 0.3281904004923918, 0.9347361503051731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 41}], {
             RGBColor[
             0.6103348144421008, 0.6886019294831773, 0.9655435733376975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 114}], {
             RGBColor[
             0.2950446149939596, 0.4237378370222073, 0.9402493164383834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 170}], {
             RGBColor[
             0.29023151793817503`, 0.41867896684859873`, 0.9399752176813956]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 187}], {
             RGBColor[
             0.39185947335344506`, 0.5138307132141199, 0.9461899170277228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 206}], {
             RGBColor[
             0.5395559184345032, 0.6328895346269106, 0.9586002858977685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 256}], {
             RGBColor[
             0.3500537032004466, 0.4776206563266962, 0.9435260903209648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 261}], {
             RGBColor[
             0.30438433219243016`, 0.43355447197007246`, 0.940781199515963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 311}], {
             RGBColor[
             0.3257713181858094, 0.4560335502623456, 0.9419991567290754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 361}], {
             RGBColor[
             0.28321730845770904`, 0.41130658795806163`, 0.939575768828076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 53}], {
             RGBColor[
             0.2076634431002256, 0.3355978236940631, 0.9351374979228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 58}], {
             RGBColor[
             0.2174442667054725, 0.3458780894432118, 0.935694501357687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 102}], {
             RGBColor[
             0.25020060979959846`, 0.3803070829072448, 0.9375599266382304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 103}], {
             RGBColor[
             0.20863860950919683`, 0.3366227854190133, 0.9351930322071614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 117}], {
             RGBColor[
             0.22453541604736282`, 0.35333133700637476`, 0.9360983318222922]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 145}], {
             RGBColor[
             0.21009367554414693`, 0.338152152078261, 0.9352758960652745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 189}], {
             RGBColor[
             0.24478652953490182`, 0.3746165412765333, 0.9372516027765698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 222}], {
             RGBColor[
             0.22765792346573496`, 0.35661329028148886`, 0.9362761540004327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 254}], {
             RGBColor[
             0.20508861754811766`, 0.3328915187854286, 0.9349908654167205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 303}], {
             RGBColor[
             0.21808265414273661`, 0.3465490751158777, 0.9357308565778295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 376}], {
             RGBColor[
             0.21626586560617583`, 0.3446395151729059, 0.9356273931583702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 150}], {
             RGBColor[
             0.1883607596919023, 0.31530947957110045`, 0.9340382386584571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 237}], {
             RGBColor[
             0.19025421078354665`, 0.3172996167201517, 0.9341460678970164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 251}], {
             RGBColor[
             0.18672478342346222`, 0.3135899647860835, 0.9339450722301794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 283}], {
             RGBColor[
             0.19607798492560893`, 0.3234207725920666, 0.934477723218905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 294}], {
             RGBColor[
             0.18656769797512113`, 0.31342485802008435`, 0.9339361264462835]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 320}], {
             RGBColor[
             0.18948414481075992`, 0.3164902285577502, 0.9341022137790767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 347}], {
             RGBColor[
             0.19051344323313968`, 0.3175720864609606, 0.9341608308015206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 381}], {
             RGBColor[
             0.18966952552711056`, 0.31668507544445096`, 0.9341127709366266]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 51}], {
             RGBColor[
             0.4513189432678153, 0.5634921655168925, 0.9504868403154272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 84}], {
             RGBColor[
             0.42994887224450423`, 0.5449824840875006, 0.9491251582866337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 102}], {
             RGBColor[
             0.39926565859510593`, 0.5155146756656562, 0.9472759248895897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 134}], {
             RGBColor[
             0.6760140538149009, 0.745057217744171, 0.9695892868351288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 163}], {
             RGBColor[
             0.3939273213258807, 0.5099037447255685, 0.9469719144794696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 167}], {
             RGBColor[
             0.4156571514498516, 0.5326037138579458, 0.948214502475271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 174}], {
             RGBColor[
             0.4325281900725898, 0.5472165595499049, 0.9492895101378381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 183}], {
             RGBColor[
             0.43552341404886974`, 0.5498108720138242, 0.9494803631610341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 189}], {
             RGBColor[
             0.3938515783304093, 0.5098241340349448, 0.9469676010279292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 226}], {
             RGBColor[
             0.48315013418370223`, 0.5910627432060597, 0.9525150956533707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 234}], {
             RGBColor[
             0.653391331063141, 0.7272953937118065, 0.9673580250213626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 246}], {
             RGBColor[
             0.7206526383610699, 0.7806508133791874, 0.9738469548784772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 269}], {
             RGBColor[
             0.6323207129287618, 0.7108348666826005, 0.9652579027218493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 272}], {
             RGBColor[
             0.6309966022057711, 0.7098004613221861, 0.9651259277394999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 350}], {
             RGBColor[
             0.7574551958384235, 0.806891984810095, 0.8535080309341501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 355}], {
             RGBColor[
             0.6433835290110301, 0.7194772226865849, 0.9663605408410356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 392}], {
             RGBColor[
             0.7560719179586157, 0.8063199638581745, 0.8764325252109648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 395}], {
             RGBColor[
             0.494849422028799, 0.60078007937222, 0.9533755056767188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 55}], {
             RGBColor[
             0.9217511656674453, 0.9083191148939446, 0.6659672564832814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 83}], {
             RGBColor[
             0.9084527486796484, 0.9295988421678656, 0.9827837388659694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.684630729662244, 0.7517566465973935, 0.970608286963019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 135}], {
             RGBColor[
             0.9333566323648748, 0.9460233638065111, 0.83381543555314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 156}], {
             RGBColor[
             0.8514284367030327, 0.5699234098578776, 0.5824732181712974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 165}], {
             RGBColor[
             0.8843102751860701, 0.9105890257431475, 0.9888274975519911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 187}], {
             RGBColor[
             0.6533956652271913, 0.7258990741319324, 0.9682873726725081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 206}], {
             RGBColor[
             0.8010921103082493, 0.8449578955447232, 0.9806977415425538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 245}], {
             RGBColor[
             0.8453505309169804, 0.5232059626309822, 0.576653008726561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 256}], {
             RGBColor[
             0.6115898950741928, 0.6896890172445088, 0.9656235459657501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 311}], {
             RGBColor[
             0.5873075100595555, 0.6681019111801583, 0.9640966123738608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 328}], {
             RGBColor[
             0.8707008812978143, 0.7005608755905404, 0.6002433163697872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 386}], {
             RGBColor[
             0.8163158098721861, 0.8568507653484726, 0.982215097641526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 400}], {
             RGBColor[
             0.861024743522975, 0.6436848292044157, 0.5916626524195524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 45}], {
             RGBColor[
             0.2506616815740248, 0.3807916985758058, 0.9375861839936894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 93}], {
             RGBColor[
             0.22541709987581074`, 0.35425804261205696`, 0.936148542411988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 98}], {
             RGBColor[
             0.20876468464708048`, 0.33675529838255447`, 0.9352002119997525]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 125}], {
             RGBColor[
             0.23901293023950498`, 0.3685481223497329, 0.9369228048379719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 139}], {
             RGBColor[
             0.20228682166276132`, 0.3299466536657998, 0.934831307285935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 148}], {
             RGBColor[
             0.27524609124263133`, 0.40429858097089644`, 0.9390716483190401]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 204}], {
             RGBColor[
             0.20507426806755127`, 0.33287643657154375`, 0.9349900482350304]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 248}], {
             RGBColor[
             0.21725641238251098`, 0.34568064263912723`, 0.9356838033318999]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 275}], {
             RGBColor[
             0.2276321474655179, 0.3565861980709679, 0.9362746860953526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 276}], {
             RGBColor[
             0.2196855450649306, 0.3482338151042579, 0.9358221388445839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 288}], {
             RGBColor[
             0.26094257460696524`, 0.39159756899969334`, 0.938171665642697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 290}], {
             RGBColor[
             0.20736560396252507`, 0.33528477587624783`, 0.9351205364245214]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 318}], {
             RGBColor[
             0.2054522043558168, 0.33327367157305554`, 0.9350115711475404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 56}], {
             RGBColor[
             0.3210051071529382, 0.44798658822988663`, 0.9418389411311112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 59}], {
             RGBColor[
             0.3034359716582913, 0.4327690861148492, 0.9407194513531689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[
             0.434369237561579, 0.5419666394359329, 0.9502257108546233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 121}], {
             RGBColor[
             0.28563299292961386`, 0.4173490407437973, 0.9395850612911336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 122}], {
             RGBColor[
             0.42916131354223347`, 0.5377386121027248, 0.9498157239985662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 175}], {
             RGBColor[
             0.2710055822533935, 0.4021744280676252, 0.9387447390412754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 213}], {
             RGBColor[
             0.2414891450614786, 0.3711507811287148, 0.9370638216088516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 227}], {
             RGBColor[
             0.23391469744368304`, 0.36318955643469497`, 0.9366324680224093]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 237}], {
             RGBColor[
             0.22884629711642387`, 0.3578623463356042, 0.9363438301217982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 274}], {
             RGBColor[
             0.3767191464303865, 0.4951636983486218, 0.9456872845015338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 296}], {
             RGBColor[
             0.2526601828418626, 0.38289225012060224`, 0.937699995684375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 308}], {
             RGBColor[
             0.23093015114267265`, 0.3600526090411681, 0.9364625025258073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 373}], {
             RGBColor[
             0.2661054797853324, 0.3970241096892522, 0.9384656854547713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 380}], {
             RGBColor[
             0.2402420225431372, 0.36983997628980336`, 0.9369927998263845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 46}], {
             RGBColor[
             0.2189840028439955, 0.34749644974970917`, 0.9357821870529404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 65}], {
             RGBColor[
             0.2623103948909678, 0.393035234842995, 0.9382495609843622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 68}], {
             RGBColor[
             0.25335041241870687`, 0.38361772516894843`, 0.9377393032376733]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 113}], {
             RGBColor[
             0.27210008577250266`, 0.4033248206617401, 0.9388070693975159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 149}], {
             RGBColor[
             0.22663901581167467`, 0.355542353734595, 0.9362181287168728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 161}], {
             RGBColor[
             0.2180648213930185, 0.34653033176526227`, 0.9357298410291143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 195}], {
             RGBColor[
             0.2192614298530921, 0.3477880431261581, 0.9357979861106919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 247}], {
             RGBColor[
             0.2171512777998561, 0.34557013952683935`, 0.9356778160729503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 249}], {
             RGBColor[
             0.27287548484168234`, 0.4041092659680885, 0.9388523457495259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 250}], {
             RGBColor[
             0.24751102743025372`, 0.3774801613076919, 0.9374067589011768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 266}], {
             RGBColor[
             0.23471345152571355`, 0.36402909761884283`, 0.9366779558857301]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 315}], {
             RGBColor[
             0.22776027402374388`, 0.3567208672073564, 0.9362819827132973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 316}], {
             RGBColor[
             0.23551418105696653`, 0.3648707151253743, 0.9367235562479619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 358}], {
             RGBColor[
             0.21372519899594036`, 0.3419691134779814, 0.9354827059534967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 362}], {
             RGBColor[
             0.21291981933663207`, 0.3411226083920287, 0.9354368407733515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 363}], {
             RGBColor[
             0.22828771928123268`, 0.35727524561493795`, 0.9363120199404259]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 369}], {
             RGBColor[
             0.21363611782330827`, 0.34187548351747254`, 0.9354776329124991]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 372}], {
             RGBColor[
             0.21537145554787535`, 0.3436994334927591, 0.9355764578287111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 66}], {
             RGBColor[
             0.2495400971941441, 0.37961284227999426`, 0.9375223114224907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 91}], {
             RGBColor[
             0.38905361359871204`, 0.5081017700405416, 0.9463921022645131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 123}], {
             RGBColor[
             0.24825361468381962`, 0.37826066759394095`, 0.9374490481467079]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 140}], {
             RGBColor[
             0.25525427585226035`, 0.38561880634952683`, 0.9378477254437005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 148}], {
             RGBColor[
             0.30939380782769543`, 0.44018999619208, 0.9410163102615399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 179}], {
             RGBColor[
             0.3693787364367489, 0.49212881841734446`, 0.9448432238628737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 203}], {
             RGBColor[
             0.2552832201033739, 0.38564922859261863`, 0.9378493737759823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 232}], {
             RGBColor[
             0.28995111396047296`, 0.4220873831078549, 0.9398236590445912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 257}], {
             RGBColor[
             0.30395689687858984`, 0.4354808171950546, 0.9406698751035344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 275}], {
             RGBColor[
             0.261779864050582, 0.3924776132921515, 0.9382193480378523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 276}], {
             RGBColor[
             0.2538332616499947, 0.38412523032544144`, 0.9377668007870836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 279}], {
             RGBColor[
             0.4785218001436983, 0.5802784243797845, 0.9537482634423509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 280}], {
             RGBColor[
             0.26817273037966816`, 0.3991969211351571, 0.9385834123178955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 288}], {
             RGBColor[
             0.29509029119202934`, 0.4274889842208769, 0.9401163275851969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 297}], {
             RGBColor[
             0.2458649611438621, 0.37575004127406386`, 0.9373130178613036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 325}], {
             RGBColor[
             0.2869742607531359, 0.4189585216435491, 0.9396541316582929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 339}], {
             RGBColor[
             0.26817858765203434`, 0.39920307749978645`, 0.9385837458808918]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 149}], {
             RGBColor[
             0.20894845482391827`, 0.3369484524901131, 0.9352106774394597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 153}], {
             RGBColor[
             0.1918690303202028, 0.3189968944386494, 0.9342380294807175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 161}], {
             RGBColor[
             0.20037426040526207`, 0.3279364305207805, 0.9347223897517012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 184}], {
             RGBColor[
             0.19220194755564052`, 0.3193468115612663, 0.9342569886247687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 195}], {
             RGBColor[
             0.2015708688653357, 0.3291941418816762, 0.9347905348332788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 247}], {
             RGBColor[
             0.1994607168120997, 0.32697623828235756`, 0.9346703647955372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 250}], {
             RGBColor[
             0.22982046644249732`, 0.3588862600632101, 0.9363993076237638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 315}], {
             RGBColor[
             0.21006971303598748`, 0.3381269659628746, 0.9352745314358842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 343}], {
             RGBColor[
             0.19165716183089215`, 0.31877420722314587`, 0.9342259638836825]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 356}], {
             RGBColor[
             0.1981426064801053, 0.32559082075040946`, 0.9345953003620997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 358}], {
             RGBColor[
             0.19603463800818394`, 0.3233752122334996, 0.9344752546760837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 362}], {
             RGBColor[
             0.19522925834887567`, 0.3225287071475469, 0.9344293894959386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 363}], {
             RGBColor[
             0.21059715829347625`, 0.33868134437045616`, 0.9353045686630128]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 369}], {
             RGBColor[
             0.19594555683555187`, 0.3232815822729907, 0.934470181635086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 372}], {
             RGBColor[
             0.19768089456011895`, 0.32510553224827726`, 0.934569006551298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.6461513889555156, 0.7219924964871992, 0.9663950668318202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.44142989596913074`, 0.5543010784500094, 0.9500295993461311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 173}], {
             RGBColor[
             0.41329174036295263`, 0.5275007351562074, 0.948325579764125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 201}], {
             RGBColor[
             0.7465737093465549, 0.8011421937069441, 0.9641963866302764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 209}], {
             RGBColor[
             0.43947307837840166`, 0.5526061814054317, 0.9499049126595958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 323}], {
             RGBColor[
             0.4713973595467131, 0.580257389192397, 0.951939099626107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 346}], {
             RGBColor[
             0.44758503753245593`, 0.5596323527057516, 0.9504217995237683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 61}], {
             RGBColor[
             0.22477630942984533`, 0.3535845312248864, 0.9361120503440548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 68}], {
             RGBColor[
             0.2551071510734325, 0.38546416887872903`, 0.937839346905198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 118}], {
             RGBColor[
             0.23953466514577643`, 0.3690964988161278, 0.9369525168690463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 173}], {
             RGBColor[
             0.2613339339978391, 0.3920089125331203, 0.938193952981043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 176}], {
             RGBColor[
             0.2369284794639835, 0.36635723242284735`, 0.9368040984499744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 209}], {
             RGBColor[
             0.2875152720132881, 0.41711435878234465`, 0.9397732858765137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 344}], {
             RGBColor[
             0.21571874970997718`, 0.3440644616768498, 0.9355962357174672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 354}], {
             RGBColor[
             0.22802037271409625`, 0.35699424742212627`, 0.9362967949489314]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 388}], {
             RGBColor[
             0.2298511238520014, 0.358918482944391, 0.9364010535178815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 52}], {
             RGBColor[
             0.1835216269875808, 0.31022324428012404`, 0.9337626572098012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 62}], {
             RGBColor[
             0.19439182652115503`, 0.3216485132003679, 0.9343816989922191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.19292841019979173`, 0.32011036986066127`, 0.934298359597648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 127}], {
             RGBColor[
             0.19124100743417377`, 0.3183368025664821, 0.9342022645064347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[
             0.18838308614561955`, 0.31533294608953616`, 0.9340395101169672]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 133}], {
             RGBColor[
             0.18673252269027052`, 0.31359809924619686`, 0.933945512969975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 199}], {
             RGBColor[
             0.18708382947160418`, 0.313967344947515, 0.93396551937146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 216}], {
             RGBColor[
             0.19369425198474133`, 0.320915318133817, 0.9343419731543394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 231}], {
             RGBColor[
             0.1849354051777754, 0.31170921479673314`, 0.9338431697862355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 235}], {
             RGBColor[
             0.18959591922153213`, 0.31660771055037873`, 0.9341085791664148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 298}], {
             RGBColor[
             0.19233776426424887`, 0.31948956353329044`, 0.9342647231854012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 313}], {
             RGBColor[
             0.20302253470198556`, 0.3307199347169253, 0.9348732050551289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 361}], {
             RGBColor[
             0.2026569249479238, 0.33033565568440915`, 0.9348523841205063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 393}], {
             RGBColor[
             0.1855205539729795, 0.3123242432810691, 0.9338764931444723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 396}], {
             RGBColor[
             0.1936178582000953, 0.3208350234225083, 0.9343376226413184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.18052420551329257`, 0.307072764263149, 0.9335919584911282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 147}], {
             RGBColor[
             0.18125622821196816`, 0.30784216653237684`, 0.9336336461008872]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 164}], {
             RGBColor[
             0.18999442899880858`, 0.3170265695932755, 0.9341312737086882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 271}], {
             RGBColor[
             0.17906803055065768`, 0.3055422320505946, 0.933509031481224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 287}], {
             RGBColor[
             0.18448432655099875`, 0.31123510255995407`, 0.9338174815257515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 371}], {
             RGBColor[
             0.1827919087042476, 0.30945626409752947`, 0.9337211008330868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 391}], {
             RGBColor[
             0.18008156514952903`, 0.3066075211758136, 0.9335667507772396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 84}], {
             RGBColor[
             0.36020789306278994`, 0.48641570522103605`, 0.9441731063199956]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 102}], {
             RGBColor[
             0.32952467941339164`, 0.45694789679919157`, 0.9423238729229517]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 134}], {
             RGBColor[
             0.6062730746331866, 0.6864904388777064, 0.9646372348684907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 163}], {
             RGBColor[
             0.3241863421441664, 0.4513369658591039, 0.9420198625128315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 167}], {
             RGBColor[
             0.3459161722681373, 0.47403693499148125`, 0.9432624505086329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 174}], {
             RGBColor[
             0.3627872108908755, 0.4886497806834403, 0.9443374581712001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 183}], {
             RGBColor[
             0.36578243486715545`, 0.4912440931473596, 0.9445283111943961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 189}], {
             RGBColor[
             0.324110599148695, 0.45125735516848015`, 0.9420155490612911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 222}], {
             RGBColor[
             0.3069819930795281, 0.4332541041734357, 0.9410401002851541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 226}], {
             RGBColor[
             0.41340915500198794`, 0.532495964339595, 0.9475630436867326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 234}], {
             RGBColor[
             0.5836503518814267, 0.668728614845342, 0.9624059730547245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 238}], {
             RGBColor[
             0.3357800727610889, 0.463522711822467, 0.942680108320078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 246}], {
             RGBColor[
             0.6509116591793556, 0.7220840345127228, 0.9688949029118392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 269}], {
             RGBColor[
             0.5625797337470475, 0.652268087816136, 0.9603058507552114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 272}], {
             RGBColor[
             0.5612556230240568, 0.6512336824557214, 0.9601738757728618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 350}], {
             RGBColor[
             0.6877142166567092, 0.7483252059436304, 0.8485559789675121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 355}], {
             RGBColor[
             0.5736425498293158, 0.6609104438201203, 0.9614084888743977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 392}], {
             RGBColor[
             0.6863309387769014, 0.7477531849917098, 0.8714804732443268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 395}], {
             RGBColor[
             0.4251084428470847, 0.5422133005057554, 0.9484234537100807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 89}], {
             RGBColor[
             0.18430520538442102`, 0.31104683485694296`, 0.933807280840301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 128}], {
             RGBColor[
             0.18698858591777334`, 0.3138672379336487, 0.9339600953919696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 133}], {
             RGBColor[
             0.18257629412906723`, 0.3092296395082612, 0.9337088219020035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 199}], {
             RGBColor[
             0.1829276009104009, 0.30959888520957934`, 0.9337288283034887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 299}], {
             RGBColor[
             0.18351379325327066`, 0.3102150105286766, 0.9337622110902213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 342}], {
             RGBColor[
             0.18153992013799802`, 0.30814034473374124`, 0.9336498019363901]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 393}], {
             RGBColor[
             0.18136432541177624`, 0.30795578354313347`, 0.9336398020765009]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 58}], {
             RGBColor[
             0.20217788494718347`, 0.3298321542707407, 0.9348251035011402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 64}], {
             RGBColor[
             0.18652020523185484`, 0.31337494013569756`, 0.9339334218048136]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 117}], {
             RGBColor[
             0.20926903428907379`, 0.33728540183390365`, 0.9352289339657456]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 126}], {
             RGBColor[
             0.1894916420221746, 0.31649810860229766`, 0.9341026407341755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 289}], {
             RGBColor[
             0.18928237138329773`, 0.3162781518923132, 0.9340907230808797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 303}], {
             RGBColor[
             0.20281627238444755`, 0.3305031399434066, 0.9348614587212829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 376}], {
             RGBColor[
             0.20099948384788677`, 0.3285935800004348, 0.9347579953018235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 63}], {
             RGBColor[
             0.18289690010848875`, 0.3095666167202264, 0.9337270799382376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 66}], {
             RGBColor[
             0.19944158418676777`, 0.3269561286800552, 0.9346692752208288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 204}], {
             RGBColor[
             0.18912347164523904`, 0.31611113819278824`, 0.9340816739758684]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 224}], {
             RGBColor[
             0.18197335735342035`, 0.3085959147286568, 0.9336744855445955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 290}], {
             RGBColor[
             0.19141480754021284`, 0.3185194774974923, 0.9342121621653594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 297}], {
             RGBColor[
             0.19576644813648575`, 0.3230933276741248, 0.9344599816596418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 318}], {
             RGBColor[
             0.18950140793350456`, 0.31650837319430003`, 0.9341031968883784]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 345}], {
             RGBColor[
             0.1817997844893844, 0.30841347864339985`, 0.9336646008267666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 92}], {
             RGBColor[
             0.7345108890138425, 0.7594054710903482, 0.6489345144638174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 135}], {
             RGBColor[
             0.9832367917164733, 0.9536721882994657, 0.5121416630539384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 156}], {
             RGBColor[
             0.9013085960546312, 0.5775722343508322, 0.2607994456720959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.9341904345376686, 0.918237850236102, 0.6671537250527897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 221}], {
             RGBColor[
             0.9369698505827507, 0.7826274582869746, 0.292244768605455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 245}], {
             RGBColor[
             0.8952306902685789, 0.5308547871239369, 0.2549792362273595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 255}], {
             RGBColor[
             0.9034963603733146, 0.5943883495886708, 0.2628944512543936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 328}], {
             RGBColor[
             0.9205810406494127, 0.7082097000834948, 0.27856954387058575`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 386}], {
             RGBColor[
             0.8661959692237846, 0.8644995898414272, 0.6605413251423246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 400}], {
             RGBColor[
             0.9109049028745734, 0.6513336536973703, 0.2699888799203509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 59}], {
             RGBColor[
             0.3640812726856617, 0.4897706319686471, 0.9444199146444701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 90}], {
             RGBColor[
             0.4950145385889495, 0.5989681852897308, 0.9539261741459244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 121}], {
             RGBColor[
             0.3462782939569843, 0.4743505865975952, 0.9432855245824346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 122}], {
             RGBColor[
             0.48980661456960395`, 0.5947401579565226, 0.9535161872898672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 137}], {
             RGBColor[
             0.35805694536026106`, 0.48455266243088047`, 0.9440360498343989]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 166}], {
             RGBColor[
             0.6856726502293173, 0.7474973607293266, 0.8829926191709212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 169}], {
             RGBColor[
             0.6387195548301612, 0.7123648726900207, 0.967730862260616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 175}], {
             RGBColor[
             0.331650883280764, 0.45917597392142306`, 0.9424452023325764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 178}], {
             RGBColor[
             0.4116703274319593, 0.5309898792944511, 0.9474522471315552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 213}], {
             RGBColor[
             0.30213444608884904`, 0.4281523269825127, 0.9407642849001527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 274}], {
             RGBColor[
             0.43736444745775693`, 0.5521652442024196, 0.9493877477928349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 278}], {
             RGBColor[
             0.3199081459581343, 0.44683361246279085`, 0.9417764708138758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 296}], {
             RGBColor[
             0.313305483869233, 0.43989379597440015`, 0.9414004589756761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 319}], {
             RGBColor[
             0.4175060909791842, 0.5360433358043497, 0.9478244252272849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 352}], {
             RGBColor[
             0.31062641380180694`, 0.4370779234706822, 0.9412478898986653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 76}], {
             RGBColor[
             0.20578868678679324`, 0.33362733594223004`, 0.9350307333242034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.2782593236768137, 0.4070163756656283, 0.939259698655848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 102}], {
             RGBColor[
             0.24757611002741542`, 0.37754856724378383`, 0.937410465258804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 144}], {
             RGBColor[
             0.20411547873617336`, 0.33186868819351084`, 0.93493544660101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 163}], {
             RGBColor[
             0.24223777275819017`, 0.37193763630369614`, 0.9371064548486839]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 167}], {
             RGBColor[
             0.2639676028821611, 0.3946376054360735, 0.9383490428444853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 174}], {
             RGBColor[
             0.28083864150489934`, 0.40925045112803254`, 0.9394240505070525]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 186}], {
             RGBColor[
             0.21226621689950026`, 0.3404356307898151, 0.9353996190814751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 188}], {
             RGBColor[
             0.20973271485913975`, 0.33777275951208907`, 0.9352553398882568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 189}], {
             RGBColor[
             0.24216202976271878`, 0.3718580256130724, 0.9371021413971435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 222}], {
             RGBColor[
             0.22503342369355192`, 0.35385477461802795`, 0.9361266926210063]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 228}], {
             RGBColor[
             0.21063806848440092`, 0.33872434357497383`, 0.9353068984378649]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 238}], {
             RGBColor[
             0.2538315033751126, 0.3841233822670593, 0.9377667006559303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 333}], {
             RGBColor[
             0.2028967340448986, 0.3305877102501046, 0.9348660408938132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 368}], {
             RGBColor[
             0.20142644533340448`, 0.3290423435926357, 0.9347823101267909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 117}], {
             RGBColor[
             0.2190498578943207, 0.34756566758305235`, 0.9357859374006325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 289}], {
             RGBColor[
             0.19906319498854463`, 0.3265584176414619, 0.9346477265157667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 303}], {
             RGBColor[
             0.21259709598969448`, 0.3407834056925553, 0.9354184621561699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 376}], {
             RGBColor[
             0.2107803074531337, 0.33887384574958357`, 0.9353149987367104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 90}], {
             RGBColor[
             0.47744540309430256`, 0.5837506831746934, 0.9528066843679821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 121}], {
             RGBColor[
             0.3287091584623374, 0.4591330844825578, 0.9421660348044922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 122}], {
             RGBColor[
             0.472237479074957, 0.5795226558414852, 0.9523966975119249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 175}], {
             RGBColor[
             0.314081747786117, 0.4439584718063857, 0.9413257125546342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 178}], {
             RGBColor[
             0.3941011919373124, 0.5157723771794137, 0.9463327573536129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 213}], {
             RGBColor[
             0.2845653105942021, 0.4129348248674753, 0.9396447951222104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 274}], {
             RGBColor[
             0.41979531196311004`, 0.5369477420873823, 0.9482682580148925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 296}], {
             RGBColor[
             0.2957363483745861, 0.42467629385936273`, 0.9402809691977339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 319}], {
             RGBColor[
             0.3999369554845372, 0.5208258336893123, 0.9467049354493426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 373}], {
             RGBColor[
             0.3091816453180559, 0.4388081534280127, 0.9410466589681301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.18336573314646784`, 0.31005938996887394`, 0.9337537792861741]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 101}], {
             RGBColor[
             0.18455258152934814`, 0.31130684286981486`, 0.9338213685457943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.18529719032077357`, 0.3120894739205271, 0.933863772914916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 259}], {
             RGBColor[
             0.18612091931381164`, 0.3129552653196448, 0.9339106830624717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 331}], {
             RGBColor[
             0.19257622837931382`, 0.31974020443772183`, 0.9342783033639781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 335}], {
             RGBColor[
             0.18275395419094043`, 0.3094163714975885, 0.9337189393797027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 394}], {
             RGBColor[
             0.18321858514836378`, 0.3099047280931446, 0.933745399425368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 118}], {
             RGBColor[
             0.22412293343441853`, 0.3528977916272621, 0.9360748415476985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 130}], {
             RGBColor[
             0.19568837198846437`, 0.3230112646922406, 0.9344555353385153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 147}], {
             RGBColor[
             0.19642039468713995`, 0.32378066696146846`, 0.9344972229482744]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 164}], {
             RGBColor[
             0.2051585954739804, 0.3329650700223671, 0.9349948505560753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 173}], {
             RGBColor[
             0.24592220228648118`, 0.3758102053442546, 0.937316277659695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 176}], {
             RGBColor[
             0.2215167477526256, 0.3501585252339816, 0.9359264231286265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 344}], {
             RGBColor[
             0.20030701799861927`, 0.32786575448798405`, 0.9347185603961192]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 354}], {
             RGBColor[
             0.21260864100273835`, 0.3407955402332605, 0.9354191196275834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 371}], {
             RGBColor[
             0.19795607517941943`, 0.3253947645266211, 0.934584677680474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 388}], {
             RGBColor[
             0.2144393921406435, 0.3427197757555252, 0.9355233781965335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 87}], {
             RGBColor[
             0.1996423811721627, 0.3271671790429695, 0.9346807103120945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 119}], {
             RGBColor[
             0.1917608818844465, 0.31888322357566273`, 0.9342318705872924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 127}], {
             RGBColor[
             0.1979549784065447, 0.32539361174879033`, 0.9345846152208812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 129}], {
             RGBColor[
             0.19509705711799047`, 0.3223897552718444, 0.9344218608314138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 216}], {
             RGBColor[
             0.2004082229571123, 0.32797212731612524`, 0.934724323868786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 231}], {
             RGBColor[
             0.19164937615014635`, 0.31876602397904136`, 0.934225520500682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 235}], {
             RGBColor[
             0.1963098901939031, 0.32366451973268695`, 0.9344909298808612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 298}], {
             RGBColor[
             0.19905173523661984`, 0.32654637271559867`, 0.9346470738998478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 313}], {
             RGBColor[
             0.20973650567435648`, 0.3377767438992335, 0.9352555557695754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 317}], {
             RGBColor[
             0.19822991985182326`, 0.32568259264007254`, 0.9346002727294505]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 336}], {
             RGBColor[
             0.19072954463119351`, 0.31779922273193517`, 0.9341731374564464]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 361}], {
             RGBColor[
             0.20937089592029476`, 0.33739246486671737`, 0.9352347348349528]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 393}], {
             RGBColor[
             0.19223452494535048`, 0.31938105246337734`, 0.9342588438589188]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 396}], {
             RGBColor[
             0.20033182917246628`, 0.3278918326048165, 0.934719973355765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 98}], {
             RGBColor[
             0.19109841618892076`, 0.3181869301269141, 0.9341941441459625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 139}], {
             RGBColor[
             0.18462055320460163`, 0.31137828541015944`, 0.9338252394321449]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 204}], {
             RGBColor[
             0.18740799960939158`, 0.3143080683159034, 0.9339839803812403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 224}], {
             RGBColor[
             0.1802578853175729, 0.30679284485177194`, 0.9335767919499673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 290}], {
             RGBColor[
             0.18969933550436535`, 0.3167164076206075, 0.9341144685707314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 318}], {
             RGBColor[
             0.18778593589765713`, 0.3147053033174152, 0.9340055032937504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 345}], {
             RGBColor[
             0.18008431245353695`, 0.306610408766515, 0.9335669072321386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 77}], {
             RGBColor[
             0.18172630335562523`, 0.308336245312846, 0.9336604161849047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 94}], {
             RGBColor[
             0.1809149928406964, 0.30748350652159806`, 0.9336142132513059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 254}], {
             RGBColor[
             0.1839453796797469, 0.3106686352270631, 0.9337867892987342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 289}], {
             RGBColor[
             0.18340551527321602`, 0.3101012035064188, 0.9337560448194401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 68}], {
             RGBColor[
             0.2789862434779228, 0.41056260901775243`, 0.9391992258916821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 173}], {
             RGBColor[
             0.2852130264023293, 0.4171073526721437, 0.9395538319675272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 176}], {
             RGBColor[
             0.26080757186847375`, 0.39145567256187075`, 0.9381639774364586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 250}], {
             RGBColor[
             0.2731468584894696, 0.40442504515649597`, 0.9388666815551856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 363}], {
             RGBColor[
             0.25392355034044856`, 0.38422012946374207`, 0.9377719425944349]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 123}], {
             RGBColor[
             0.21298431371887483`, 0.3411903960769459, 0.9354405136330093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 131}], {
             RGBColor[
             0.2137636212718384, 0.34200949772606326`, 0.9354848940452685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 140}], {
             RGBColor[
             0.21998497488731555`, 0.3485485348325317, 0.9358391909300019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 203}], {
             RGBColor[
             0.2200139191384291, 0.3485789570756236, 0.9358408392622837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 232}], {
             RGBColor[
             0.25468181299552817`, 0.38501711159085983`, 0.9378151245308926]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 257}], {
             RGBColor[
             0.268687595913645, 0.3984105456780595, 0.9386613405898359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 275}], {
             RGBColor[
             0.22651056308563722`, 0.3554073417751564, 0.9362108135241538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 280}], {
             RGBColor[
             0.23290342941472336`, 0.362126649618162, 0.936574877804197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 297}], {
             RGBColor[
             0.21059566017891732`, 0.33867976975706876`, 0.935304483347605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 318}], {
             RGBColor[
             0.20433061997593613`, 0.33209481527724394`, 0.9349476985763416]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 322}], {
             RGBColor[
             0.2070879506142999, 0.33499294460302415`, 0.9351047244770914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 325}], {
             RGBColor[
             0.2517049597881912, 0.3818882501265539, 0.9376455971445944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 339}], {
             RGBColor[
             0.23290928668708955`, 0.3621328059827914, 0.9365752113671932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 113}], {
             RGBColor[
             0.36637406988619037`, 0.4916437040590915, 0.9445701410456664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 124}], {
             RGBColor[
             0.3674760832994186, 0.49271104629414053`, 0.9446362289748654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 194}], {
             RGBColor[
             0.709877099853931, 0.7667201163798876, 0.7972498678529694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 208}], {
             RGBColor[
             0.7091189037719949, 0.7670538844748609, 0.8568671364687419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 210}], {
             RGBColor[
             0.365438140563206, 0.4906599829992886, 0.9445168412553058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 249}], {
             RGBColor[
             0.36714946895537004`, 0.49242814936543994`, 0.9446154173976764]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 266}], {
             RGBColor[
             0.3289874356394012, 0.4523479810161943, 0.9424410275338806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 293}], {
             RGBColor[
             0.3870584168095417, 0.509672279343909, 0.9458839979501529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 316}], {
             RGBColor[
             0.32978816517065423`, 0.4531895985227258, 0.9424866278961124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 385}], {
             RGBColor[
             0.7098239251190117, 0.7666063809986858, 0.7914621261134387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 387}], {
             RGBColor[
             0.4796742864541198, 0.5876973628554791, 0.9523916433059518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 161}], {
             RGBColor[
             0.23474066997997348`, 0.36405770594001974`, 0.9366795059364341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 173}], {
             RGBColor[
             0.2762530439300684, 0.40768984299809713`, 0.9390435742208383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 176}], {
             RGBColor[
             0.2518475893962128, 0.38203816288782416`, 0.9376537196897696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 250}], {
             RGBColor[
             0.2641868760172087, 0.3950075354824494, 0.9383564238084967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 363}], {
             RGBColor[
             0.24496356786818765`, 0.3748026197896954, 0.9372616848477457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 106}], {
             RGBColor[
             0.23431749208343802`, 0.36361291913973265`, 0.936655406581262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 107}], {
             RGBColor[
             0.2952174792692931, 0.42393616514341426`, 0.9402585516481101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 150}], {
             RGBColor[
             0.217681081623926, 0.3461269969374395, 0.9357079876169566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 212}], {
             RGBColor[
             0.32957634955032006`, 0.4536960916538069, 0.9424478684800611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 270}], {
             RGBColor[
             0.300457761234542, 0.4284750339974831, 0.9405924577811364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 283}], {
             RGBColor[
             0.22539830685763262`, 0.3542382899584056, 0.9361474721774046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 294}], {
             RGBColor[
             0.2158880199071448, 0.3442423753864234, 0.935605875404783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 295}], {
             RGBColor[
             0.3354255676488553, 0.4587623903805083, 0.9428205754850394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 320}], {
             RGBColor[
             0.21880446674278364`, 0.34730774592408925`, 0.9357719627375762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 347}], {
             RGBColor[
             0.21983376516516337`, 0.34838960382729967`, 0.9358305797600202]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 373}], {
             RGBColor[
             0.25683371538447886`, 0.38727889744013877`, 0.937937672188489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 380}], {
             RGBColor[
             0.2309702581422837, 0.36009476404068996`, 0.9364647865601021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 381}], {
             RGBColor[
             0.21898984745913425`, 0.34750259281079, 0.9357825198951262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 390}], {
             RGBColor[
             0.2522635992417797, 0.3824754156120626, 0.9376774108350432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 108}], {
             RGBColor[
             0.2395346657598989, 0.3690964994616095, 0.9369525169040198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 152}], {
             RGBColor[
             0.2398425593336916, 0.3694201151292457, 0.9369700509875596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 154}], {
             RGBColor[
             0.21421417432422896`, 0.3424830575508392, 0.9355105523750686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 180}], {
             RGBColor[
             0.24072957206270523`, 0.3703524217472943, 0.9370205650502591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 198}], {
             RGBColor[
             0.2881120186842996, 0.4160342955793074, 0.9398697816662858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 236}], {
             RGBColor[
             0.23684558512377027`, 0.36627010521547854`, 0.9367993777399305]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 262}], {
             RGBColor[
             0.2185336488556363, 0.3470230991538516, 0.9357565400595423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 267}], {
             RGBColor[
             0.23945129119348169`, 0.3690088675060522, 0.9369477688458039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 284}], {
             RGBColor[
             0.24975725951810934`, 0.3798410936513683, 0.9375346784955776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 286}], {
             RGBColor[
             0.20888058953085603`, 0.33687712176419665`, 0.9352068126114177]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 332}], {
             RGBColor[
             0.22563024765380635`, 0.35448207444108004`, 0.936160680862621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 72}], {
             RGBColor[
             0.18087056047954858`, 0.30743680529285733`, 0.9336116828940703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 88}], {
             RGBColor[
             0.1851982028892632, 0.3119854318538441, 0.9338581357271303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 138}], {
             RGBColor[
             0.18058969715831197`, 0.30714160013447456`, 0.9335956881434259]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 157}], {
             RGBColor[
             0.18316059011768585`, 0.3098437716388048, 0.933742096694167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 365}], {
             RGBColor[
             0.17992874679989868`, 0.30644689940110903`, 0.9335580479983027]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 88}], {
             RGBColor[
             0.18714176336881175`, 0.31402823714670136`, 0.9339688186212005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 109}], {
             RGBColor[
             0.18206833162796426`, 0.3086957387129193, 0.933679894189029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 157}], {
             RGBColor[
             0.1851041505972344, 0.3118865769316621, 0.9338527795882372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 181}], {
             RGBColor[
             0.1888688995598306, 0.3158435667902215, 0.9340671764722099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 191}], {
             RGBColor[
             0.19501894918374685`, 0.32230765888062524`, 0.934417412700109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 365}], {
             RGBColor[
             0.18187230727944725`, 0.30848970469396636`, 0.9336687308923729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 370}], {
             RGBColor[
             0.18495091945082137`, 0.31172552128136616`, 0.9338440533011341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 78}], {
             RGBColor[
             0.8752764478324426, 0.45843721309521324`, 0.21487760657063304`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 99}], {
             RGBColor[
             0.9481261161147958, 0.8682562660194123, 0.6030407890629428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 104}], {
             RGBColor[
             0.874812220102593, 0.4548689553377009, 0.21443306157225883`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 112}], {
             RGBColor[
             0.9338615942560703, 0.7754902910821886, 0.2656416901517646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 141}], {
             RGBColor[
             0.898106425922933, 0.622605752165564, 0.23629664332441563`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 172}], {
             RGBColor[
             0.8772092716527284, 0.4732937439467283, 0.21672848084375096`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 177}], {
             RGBColor[
             0.912733918365472, 0.8408075046276462, 0.6264313427993702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 208}], {
             RGBColor[
             0.9618152962983195, 0.8769997675618114, 0.5142240753361885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 225}], {
             RGBColor[
             0.9076627958063523, 0.836763929150959, 0.6259476546026368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 240}], {
             RGBColor[
             0.8811521202900017, 0.5036002063401005, 0.22050415715161448`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 243}], {
             RGBColor[
             0.9500707567190481, 0.8697065757980069, 0.5997490197634427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 285}], {
             RGBColor[
             0.9624071777351879, 0.8763102692580285, 0.43650448397981056`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 337}], {
             RGBColor[
             0.9623310682876794, 0.8761474788456531, 0.428220440311572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 399}], {
             RGBColor[
             0.9285956897332439, 0.7546127344078406, 0.2614046197660328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 86}], {
             RGBColor[
             0.6370413534700665, 0.7120367862892685, 0.9671058051428245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 91}], {
             RGBColor[
             0.6781789401773193, 0.7465825501677249, 0.9700269954109155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 95}], {
             RGBColor[
             0.7112349833542422, 0.7734189351765257, 0.9726292882180788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 104}], {
             RGBColor[
             0.8410345872048564, 0.5203813503819814, 0.5763185480059819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 112}], {
             RGBColor[
             0.9000839613583336, 0.841002686126469, 0.6275271765854877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 141}], {
             RGBColor[
             0.8643287930251963, 0.6881181472098445, 0.5981821297581387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 148}], {
             RGBColor[
             0.5985191344063026, 0.6786707763192633, 0.9646512034079422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 172}], {
             RGBColor[
             0.8434316387549917, 0.5388061389910088, 0.578613967277474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 179}], {
             RGBColor[
             0.6585040630153561, 0.7306095985445278, 0.968478117009276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 240}], {
             RGBColor[
             0.8473744873922651, 0.569112601384381, 0.5823896435853375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 263}], {
             RGBColor[
             0.627506347078178, 0.7037780429959705, 0.9664982429670084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 279}], {
             RGBColor[
             0.7676471267223055, 0.8187592045069678, 0.9773831565887533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 285}], {
             RGBColor[
             0.9286295448374513, 0.9418226643023089, 0.7983899704135337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 399}], {
             RGBColor[
             0.8948180568355072, 0.820125129452121, 0.6232901061997559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 105}], {
             RGBColor[
             0.21372122175088312`, 0.34196493314125437`, 0.9354824794552745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 132}], {
             RGBColor[
             0.28812004710636396`, 0.4155836677571048, 0.9398870475355221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 202}], {
             RGBColor[
             0.23066301686818202`, 0.3597718339813871, 0.9364472896240648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 215}], {
             RGBColor[
             0.20048155521420025`, 0.3280492041678583, 0.9347285000323418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 218}], {
             RGBColor[
             0.20441362479812614`, 0.3321820586081753, 0.9349524255781707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 229}], {
             RGBColor[
             0.21242485108253378`, 0.34060236537417143`, 0.9354086530635206]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 260}], {
             RGBColor[
             0.22127423884363956`, 0.34990363299468435`, 0.9359126126050195]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 329}], {
             RGBColor[
             0.20420501368883298`, 0.3319627951056, 0.934940545484109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 341}], {
             RGBColor[
             0.2771008643732843, 0.406039405513939, 0.9391849149556509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 349}], {
             RGBColor[
             0.2099761655665867, 0.3380286416412822, 0.935269204045893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 77}], {
             RGBColor[
             0.1883529029244576, 0.3153012216103682, 0.9340377912271741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 103}], {
             RGBColor[
             0.19412197120965846`, 0.32136487815817005`, 0.9343663311314445]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 144}], {
             RGBColor[
             0.19222334020881804`, 0.31936929659612845`, 0.9342582069047196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 145}], {
             RGBColor[
             0.19557703724460856`, 0.3228942448174177, 0.9344491949895577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 200}], {
             RGBColor[
             0.1890554468047247, 0.31603963977238364`, 0.9340778000618348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 207}], {
             RGBColor[
             0.1908268877624048, 0.3179015365347492, 0.9341786810037627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 222}], {
             RGBColor[
             0.21314128516619657`, 0.3413553830206456, 0.9354494529247159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 333}], {
             RGBColor[
             0.19100459551754329`, 0.3180883186527222, 0.9341888011975227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 368}], {
             RGBColor[
             0.18953430680604916`, 0.3165429519952533, 0.9341050704305003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 94}], {
             RGBColor[
             0.18199794707454847`, 0.3086217600846408, 0.9336758858928365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 103}], {
             RGBColor[
             0.18857832587467818`, 0.31553815542369057`, 0.9340506287307058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 145}], {
             RGBColor[
             0.19003339190962826`, 0.3170675220829382, 0.934133492588819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 200}], {
             RGBColor[
             0.1835118014697444, 0.3102129170379042, 0.9337620976610961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 207}], {
             RGBColor[
             0.18528324242742453`, 0.31207481380026975`, 0.9338629786030239]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 254}], {
             RGBColor[
             0.18502833391359902`, 0.3118068887901059, 0.9338484619402648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 333}], {
             RGBColor[
             0.18546095018256298`, 0.31226159591824276`, 0.9338730987967839]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 104}], {
             RGBColor[
             0.819473350823259, 0.1506862844701191, 0.16628100878134408`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 172}], {
             RGBColor[
             0.8218704023733945, 0.1691110730791465, 0.16857642805283624`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 194}], {
             RGBColor[
             0.9072346231009216, 0.5724833285992563, 0.40645475392950137`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 208}], {
             RGBColor[
             0.9064764270189856, 0.5728170966942296, 0.4660720225452738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 217}], {
             RGBColor[
             0.9065035834313075, 0.5709197086654001, 0.3268855973458845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 230}], {
             RGBColor[
             0.818837947598831, 0.14580229685169685`, 0.1656725459360465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 233}], {
             RGBColor[
             0.8896719661372465, 0.5617502239079055, 0.560162093898772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 240}], {
             RGBColor[
             0.8258132510106677, 0.19941753547251867`, 0.17235210436069973`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 242}], {
             RGBColor[
             0.8361055023873913, 0.2785282896473279, 0.1822079759024856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 244}], {
             RGBColor[
             0.8873515007123038, 0.5600196245933966, 0.5640900365888891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 264}], {
             RGBColor[
             0.7716146222869605, 0.4690073780170669, 0.569890082784954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 285}], {
             RGBColor[
             0.907068308455854, 0.5721275983904466, 0.38835243118889584`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 357}], {
             RGBColor[
             0.8385190338854094, 0.29707975035734024`, 0.18451917639068158`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 385}], {
             RGBColor[
             0.9071814483660026, 0.5723695932180546, 0.4006670121899707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 100}], {
             RGBColor[
             0.22059571881103596`, 0.3491904654197632, 0.9358739718929432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 137}], {
             RGBColor[
             0.2827537056275888, 0.4121446936308188, 0.939500838618308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 175}], {
             RGBColor[
             0.2563476435480917, 0.3867680051213614, 0.9379099911164857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 213}], {
             RGBColor[
             0.22683120635617676`, 0.355744358182451, 0.9362290736840618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 227}], {
             RGBColor[
             0.21925675873838124`, 0.34778313348843115`, 0.9357977200976195]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[
             0.21942962029019444`, 0.3479648219394422, 0.9358075643072694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 278}], {
             RGBColor[
             0.24460490622546205`, 0.37442564366272924`, 0.937241259597785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 302}], {
             RGBColor[
             0.21120952198211004`, 0.3393249774333106, 0.9353394418691697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 314}], {
             RGBColor[
             0.23185910927542647`, 0.36102900293803986`, 0.9365154053171973]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 352}], {
             RGBColor[
             0.23532317406913467`, 0.3646699546706205, 0.9367126786825744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 379}], {
             RGBColor[
             0.21907288200889707`, 0.34758986738728526`, 0.9357872485898966]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 151}], {
             RGBColor[
             0.18591365690063838`, 0.3127374193822037, 0.9338988797746588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 168}], {
             RGBColor[
             0.18200651498987047`, 0.3086307655068815, 0.933676373822939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 265}], {
             RGBColor[
             0.18489536415726843`, 0.31166712914543293`, 0.933840889509353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 304}], {
             RGBColor[
             0.18034926344630414`, 0.30688888905877654`, 0.9335819957992169]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 378}], {
             RGBColor[
             0.18531329630253898`, 0.3121064023285408, 0.9338646901267509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 192}], {
             RGBColor[
             0.1805894919591846, 0.3071413844571813, 0.9335956764576392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 271}], {
             RGBColor[
             0.1793288256722832, 0.3058163442587888, 0.9335238833775887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 287}], {
             RGBColor[
             0.1847451216726243, 0.31150921476814825`, 0.9338323334221164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 292}], {
             RGBColor[
             0.18697166352319156`, 0.31384945142400145`, 0.9339591316866327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 374}], {
             RGBColor[
             0.1848884604275577, 0.3116598728877852, 0.9338404963521592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 382}], {
             RGBColor[
             0.18072466475425025`, 0.3072834596352455, 0.9336033743483478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 384}], {
             RGBColor[
             0.18455785037421688`, 0.3113123807598359, 0.9338216685987151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 101}], {
             RGBColor[
             0.181913405203708, 0.30853290121812327`, 0.9336710713583607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 136}], {
             RGBColor[
             0.18265801399513343`, 0.30931553226883557`, 0.9337134757274823]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 259}], {
             RGBColor[
             0.1834817429881715, 0.31018132366795326`, 0.9337603858750381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 331}], {
             RGBColor[
             0.18993705205367367`, 0.31696626278603024`, 0.9341280061765445]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 335}], {
             RGBColor[
             0.18011477786530028`, 0.30664242984589696`, 0.933568642192269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 120}], {
             RGBColor[
             0.7316668327109251, 0.7891725193318362, 0.9665740024152043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 187}], {
             RGBColor[
             0.6899774075909928, 0.7548276258988081, 0.9634300825559947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 206}], {
             RGBColor[
             0.8376738526720509, 0.8738864473115988, 0.9758404514260404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 217}], {
             RGBColor[
             0.9690520396764782, 0.9730561345189551, 0.7324860448307533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 220}], {
             RGBColor[
             0.790428504618827, 0.8368778917698232, 0.9711999364788909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 230}], {
             RGBColor[
             0.8813864038440016, 0.5479387227052518, 0.5712729934209153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 244}], {
             RGBColor[
             0.9498999569574745, 0.9621560504469515, 0.9696904840737579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 245}], {
             RGBColor[
             0.8819322732807819, 0.5521345143978579, 0.5717957186100475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 321}], {
             RGBColor[
             0.7496980165524652, 0.8038110466699736, 0.967993483257613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 328}], {
             RGBColor[
             0.9072826236616158, 0.729489427357416, 0.5953860262532737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 364}], {
             RGBColor[
             0.8813558056455749, 0.5477035315439278, 0.5712436925515461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 102}], {
             RGBColor[
             0.3081546083900806, 0.43843821536979977`, 0.9409621908941581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 163}], {
             RGBColor[
             0.3028162711208553, 0.4328272844297121, 0.940658180484038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 167}], {
             RGBColor[
             0.32454610124482625`, 0.4555272535620894, 0.9419007684798394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 174}], {
             RGBColor[
             0.3414171398675645, 0.4701400992540484, 0.9429757761424066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 183}], {
             RGBColor[
             0.3444123638438444, 0.47273441171796776`, 0.9431666291656026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 189}], {
             RGBColor[
             0.30274052812538393`, 0.4327476737390883, 0.9406538670324976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 222}], {
             RGBColor[
             0.2856119220562171, 0.4147444227440439, 0.9396784182563604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 226}], {
             RGBColor[
             0.39203908397867687`, 0.5139862829102032, 0.9462013616579391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 234}], {
             RGBColor[
             0.5622802808581155, 0.6502189334159502, 0.961044291025931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 238}], {
             RGBColor[
             0.3144100017377778, 0.44501303039307516`, 0.9413184262912844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 246}], {
             RGBColor[
             0.6295415881560444, 0.703574353083331, 0.9675332208830456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 269}], {
             RGBColor[
             0.5412096627237364, 0.6337584063867442, 0.9589441687264177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 272}], {
             RGBColor[
             0.5398855520007457, 0.6327240010263296, 0.9588121937440683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 395}], {
             RGBColor[
             0.4037383718237736, 0.5237036190763635, 0.9470617716812872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 88}], {
             RGBColor[
             0.21610734049788477`, 0.34447289523301966`, 0.9356183653879699]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 162}], {
             RGBColor[
             0.2565370723370653, 0.38696710678905155`, 0.9379207788057828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 181}], {
             RGBColor[
             0.2178344766889036, 0.34628822487653976`, 0.9357167232389794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 191}], {
             RGBColor[
             0.22398452631281984`, 0.35275231696694354`, 0.9360669594668783]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 211}], {
             RGBColor[
             0.231317411938528, 0.36045964469136466`, 0.9364845564552302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 214}], {
             RGBColor[
             0.2402451657445982, 0.3698432799938294, 0.9369929788270578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 263}], {
             RGBColor[
             0.31634895902864796`, 0.44214016934946804`, 0.941608656513351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 307}], {
             RGBColor[
             0.294549891018896, 0.4232589122924366, 0.9402196391759287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 312}], {
             RGBColor[
             0.27182714160879756`, 0.40303793904002655`, 0.9387915256311776]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 340}], {
             RGBColor[
             0.22184000451345684`, 0.35049828858527765`, 0.9359448321229403]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 348}], {
             RGBColor[
             0.28694246093137055`, 0.4166697387111759, 0.9397349004577378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 91}], {
             RGBColor[
             0.45216024233108254`, 0.5649746624056373, 0.950332168324746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 93}], {
             RGBColor[
             0.32267144519324537`, 0.4470223501983363, 0.9420332704147207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 95}], {
             RGBColor[
             0.48521628550800544`, 0.5918110474144382, 0.9529344611319093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 125}], {
             RGBColor[
             0.3362672755569396, 0.46131242993601224`, 0.9428075328407044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 148}], {
             RGBColor[
             0.37250043656006593`, 0.49706288855717573`, 0.9449563763217728]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 162}], {
             RGBColor[
             0.3416757625403587, 0.46699709267346645`, 0.9431155381732708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 179}], {
             RGBColor[
             0.4324853651691194, 0.5490017107824403, 0.9487832899231066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 214}], {
             RGBColor[
             0.32538385594789154`, 0.4498732658782442, 0.9421877381945456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 263}], {
             RGBColor[
             0.4014876492319413, 0.5221701552338829, 0.9468034158808389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 264}], {
             RGBColor[
             0.5671571608223211, 0.6570945561668415, 0.9602327949234224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 285}], {
             RGBColor[
             0.7026108469912147, 0.7602147765402214, 0.7786951433273641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 119}], {
             RGBColor[
             0.19029746556308325`, 0.3173450802359561, 0.9341485311927212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 127}], {
             RGBColor[
             0.19649156208518143`, 0.3238554684090837, 0.93450127582631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 129}], {
             RGBColor[
             0.1936336407966272, 0.32085161193213774`, 0.9343385214368426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 216}], {
             RGBColor[
             0.198944806635749, 0.32643398397641854`, 0.9346409844742148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 231}], {
             RGBColor[
             0.19018595982878306`, 0.3172278806393347, 0.9341421811061108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 235}], {
             RGBColor[
             0.1948464738725398, 0.3221263763929803, 0.9344075904862901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 298}], {
             RGBColor[
             0.19758831891525655`, 0.325008229375892, 0.9345637345052766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 313}], {
             RGBColor[
             0.2082730893529932, 0.33623860055952687`, 0.9351722163750043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 317}], {
             RGBColor[
             0.19676650353045996`, 0.3241444493003659, 0.9345169333348793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 361}], {
             RGBColor[
             0.20790747959893147`, 0.33585432152701067`, 0.9351513954403816]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 393}], {
             RGBColor[
             0.1907711086239872, 0.3178429091236707, 0.9341755044643476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 396}], {
             RGBColor[
             0.198868412851103, 0.3263536892651099, 0.9346366339611938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 109}], {
             RGBColor[
             0.18639597403767888`, 0.31324436527390603`, 0.9339263470220889]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 157}], {
             RGBColor[
             0.189431793006949, 0.31643520349264886`, 0.9340992324212971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 181}], {
             RGBColor[
             0.19319654196954522`, 0.3203921933512083, 0.9343136293052701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 191}], {
             RGBColor[
             0.19934659159346146`, 0.326856285441612, 0.9346638655331689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 365}], {
             RGBColor[
             0.18619994968916187`, 0.3130383312549531, 0.9339151837254329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 370}], {
             RGBColor[
             0.189278561860536, 0.3162741478423529, 0.9340905061341941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 128}], {
             RGBColor[
             0.1919283928758168, 0.31905928824840313`, 0.9342414100904406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 133}], {
             RGBColor[
             0.1875161010871107, 0.31442168982301577`, 0.9339901366004746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 155}], {
             RGBColor[
             0.19816316122321598`, 0.3256124250886648, 0.9345964709243118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 170}], {
             RGBColor[
             0.21045471282523004`, 0.33853162515176505`, 0.9352964566043255]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 171}], {
             RGBColor[
             0.18910388505940673`, 0.3160905514492172, 0.934080558548781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 199}], {
             RGBColor[
             0.18786740786844439`, 0.3147909355243339, 0.9340101430019597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 299}], {
             RGBColor[
             0.18845360021131413`, 0.3154070608434312, 0.9340435257886923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 306}], {
             RGBColor[
             0.1959786892882613, 0.3233164065815071, 0.9344720684792528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 342}], {
             RGBColor[
             0.18647972709604152`, 0.31333239504849575`, 0.9339311166348612]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 353}], {
             RGBColor[
             0.18963294311823536`, 0.31664662501326446`, 0.93411068762256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 121}], {
             RGBColor[
             0.4596424243656251, 0.5683306378036415, 0.9516722943059467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 122}], {
             RGBColor[
             0.6031707449782447, 0.6887202091625689, 0.9619029570133792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.7990367806379581, 0.841477411935373, 0.8913793888944332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 178}], {
             RGBColor[
             0.5250344578406001, 0.6249699305004974, 0.9558390168550672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 190}], {
             RGBColor[
             0.7822989919455827, 0.8299086268722369, 0.9606532016549456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 212}], {
             RGBColor[
             0.5128575453871849, 0.6144229009627645, 0.9550631147611566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 221}], {
             RGBColor[
             0.755343522572024, 0.6711176068414135, 0.6012544985481333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 268}], {
             RGBColor[
             0.6438707815800897, 0.7211954799278018, 0.9654945731092558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 274}], {
             RGBColor[
             0.5507285778663977, 0.6461452954084659, 0.9577745175163469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 295}], {
             RGBColor[
             0.5187067634857201, 0.6194891996894659, 0.9554358217661347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 319}], {
             RGBColor[
             0.530870221387825, 0.6300233870103961, 0.956211194950797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 324}], {
             RGBColor[
             0.6207541500572831, 0.7029952095291041, 0.9632871870713362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 351}], {
             RGBColor[
             0.7590840463718008, 0.8119268218437792, 0.9767853326782896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 373}], {
             RGBColor[
             0.44011491122134366`, 0.5480057067490964, 0.9505529184695845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 95}], {
             RGBColor[
             0.5263538722152581, 0.6263568112928946, 0.9558556514000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 112}], {
             RGBColor[
             0.7152028502193496, 0.6939405622428378, 0.6107535397674092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 125}], {
             RGBColor[
             0.37740486226419223`, 0.49585819381446866`, 0.9457287231087954]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 148}], {
             RGBColor[
             0.4136380232673186, 0.5316086524356322, 0.9478775665898638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 179}], {
             RGBColor[
             0.47362295187637204`, 0.5835474746608966, 0.9517044801911976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 257}], {
             RGBColor[
             0.408201112318213, 0.5268994734386068, 0.9475311314318583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 263}], {
             RGBColor[
             0.44262523593919395`, 0.5567159191123393, 0.94972460614893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 279}], {
             RGBColor[
             0.5827660155833214, 0.6716970806233367, 0.9606095197706748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 285}], {
             RGBColor[
             0.7437484336984672, 0.7947605404186777, 0.7816163335954551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 288}], {
             RGBColor[
             0.3993345066316525, 0.518907640464429, 0.9469775839135208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 135}], {
             RGBColor[
             0.746116355711272, 0.7971097200029147, 0.816782693533676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 165}], {
             RGBColor[
             0.6970699985324673, 0.761675381939551, 0.9717947555325273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 182}], {
             RGBColor[
             0.4229610876060558, 0.5395726978389508, 0.9485023279906137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 256}], {
             RGBColor[
             0.42434961842059, 0.5407753734409124, 0.9485908039462863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 281}], {
             RGBColor[
             0.46303919301965735`, 0.5742863383640635, 0.9510560694278913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 311}], {
             RGBColor[
             0.40006723340595274`, 0.5191882673765618, 0.947063870354397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 386}], {
             RGBColor[
             0.6290755332185833, 0.7079371215448762, 0.9651823556220622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 98}], {
             RGBColor[
             0.21766781953393055`, 0.3461130576399892, 0.9357072323605509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 125}], {
             RGBColor[
             0.24791606512635506`, 0.37790588160716765`, 0.9374298251987702]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 148}], {
             RGBColor[
             0.2841492261294814, 0.41365634022833114`, 0.9395786686798384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 162}], {
             RGBColor[
             0.2533245521097741, 0.3835905443446218, 0.9377378305313364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 214}], {
             RGBColor[
             0.23703264551730702`, 0.36646671754939963`, 0.9368100305526114]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 248}], {
             RGBColor[
             0.22615954726936105`, 0.355038401896562, 0.9361908236926982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 276}], {
             RGBColor[
             0.22858867995178067`, 0.3575915743616926, 0.9363291592053822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 288}], {
             RGBColor[
             0.2698457094938153, 0.4009553282571281, 0.9386786860034955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 290}], {
             RGBColor[
             0.21626873884937514`, 0.3446425351336826, 0.9356275567853198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 103}], {
             RGBColor[
             0.18776701535974932`, 0.31468541663244265`, 0.934004425797107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 145}], {
             RGBColor[
             0.18922208139469943`, 0.31621478329169034`, 0.9340872896552201]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 207}], {
             RGBColor[
             0.18447193191249567`, 0.3112220750090219, 0.933816775669425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 254}], {
             RGBColor[
             0.18421702339867016`, 0.31095414999885795`, 0.9338022590066659]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 125}], {
             RGBColor[
             0.41046090544111513`, 0.5226945788232695, 0.9483310159159588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 162}], {
             RGBColor[
             0.41586939242453425`, 0.5283792415607237, 0.9486390212485251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 233}], {
             RGBColor[
             0.7594081345567827, 0.8112195509449376, 0.9560282891124947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 263}], {
             RGBColor[
             0.47568127911611685`, 0.5835523041211401, 0.9523268989560933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 264}], {
             RGBColor[
             0.6413507907064967, 0.7184767050540989, 0.9657562779986768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 285}], {
             RGBColor[
             0.7768044768753901, 0.8215969254274786, 0.7842186264026185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 312}], {
             RGBColor[
             0.43115946169626646`, 0.5444500738116986, 0.9495097680739197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 173}], {
             RGBColor[
             0.515339475447038, 0.6087263479834802, 0.9574676673643785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 201}], {
             RGBColor[
             0.8486214444306401, 0.8823678065342169, 0.9733384742305298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 209}], {
             RGBColor[
             0.5415208134624869, 0.6338317942327045, 0.9590470002598491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 223}], {
             RGBColor[
             0.8390506368021915, 0.7815052608012159, 0.618996491222558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 245}], {
             RGBColor[
             0.7835145897788575, 0.47447987208772324`, 0.5706010714513564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 323}], {
             RGBColor[
             0.5734450946307983, 0.6614830020196698, 0.9610811872263605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 109}], {
             RGBColor[
             0.18710606140703578`, 0.3139907121212397, 0.9339667854472937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 181}], {
             RGBColor[
             0.19390662933890207`, 0.32113854019854193`, 0.9343540677304747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 191}], {
             RGBColor[
             0.2000566789628183, 0.32760263228894565`, 0.9347043039583738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 193}], {
             RGBColor[
             0.1899172543843397, 0.31694545418031556`, 0.9341268787285638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 211}], {
             RGBColor[
             0.20738956458852648`, 0.33530996001336677`, 0.9351219009467256]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 214}], {
             RGBColor[
             0.21631731839459667`, 0.3446935953158315, 0.9356303233185532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 248}], {
             RGBColor[
             0.2054442201466507, 0.3332652796629938, 0.9350111164586401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 305}], {
             RGBColor[
             0.18756138502713113`, 0.3144692861151448, 0.9339927154538672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 334}], {
             RGBColor[
             0.1889352663956901, 0.3159133225426103, 0.9340709559653313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 340}], {
             RGBColor[
             0.1979121571634553, 0.3253486039072797, 0.9345821766144358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 360}], {
             RGBColor[
             0.189069412661027, 0.31605431877284385`, 0.9340785953966906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 370}], {
             RGBColor[
             0.18998864922989284`, 0.31702049468968657`, 0.9341309445593988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 125}], {
             RGBColor[
             0.23126364989762477`, 0.3604031373776651, 0.9364814947865346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 139}], {
             RGBColor[
             0.19453754132088114`, 0.32180166869373195`, 0.9343899972344978]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 193}], {
             RGBColor[
             0.1939801662783198, 0.32121583218438116`, 0.9343582555503864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 204}], {
             RGBColor[
             0.19732498772567109`, 0.3247314515994759, 0.9345487381835933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 248}], {
             RGBColor[
             0.2095071320406308, 0.3375356576670594, 0.9352424932804627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 276}], {
             RGBColor[
             0.21193626472305038`, 0.34008883013219005`, 0.9353808287931467]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 290}], {
             RGBColor[
             0.19961632362064485`, 0.32713979090418005`, 0.9346792263730843]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 318}], {
             RGBColor[
             0.1977029240139366, 0.3251286866009877, 0.9345702610961033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 141}], {
             RGBColor[
             0.9156172249259522, 0.7282421342221813, 0.5763077730258106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 169}], {
             RGBColor[
             0.9307128082989145, 0.9468171296861931, 0.9664871194315787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 177}], {
             RGBColor[
             0.9302447173684912, 0.9464438866842635, 0.9664424725007652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 197}], {
             RGBColor[
             0.9649742133445314, 0.9733984061785892, 0.9441737000062027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 225}], {
             RGBColor[
             0.9251735948093716, 0.9424003112075763, 0.9659587843040318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 243}], {
             RGBColor[
             0.9675815557220673, 0.9753429578546242, 0.9397601494648378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 252}], {
             RGBColor[
             0.6676015641481373, 0.7342070299092066, 0.9439106644834332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 300}], {
             RGBColor[
             0.9401681906865148, 0.9543565949425481, 0.9673889822446275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 337}], {
             RGBColor[
             0.9798418672906987, 0.9817838609022704, 0.7682315700129669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 367}], {
             RGBColor[
             0.6703595369678017, 0.7365958473458555, 0.9440864000727226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 398}], {
             RGBColor[
             0.695865579228825, 0.7586878991813948, 0.9457116225314874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 146}], {
             RGBColor[
             0.1981449486568544, 0.3255932825266753, 0.9345954337456006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 175}], {
             RGBColor[
             0.2458994336441635, 0.3757862740575634, 0.9373149810191983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 213}], {
             RGBColor[
             0.21638299645224862`, 0.344762627118653, 0.9356340635867745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 227}], {
             RGBColor[
             0.20880854883445307`, 0.33680140242463313`, 0.9352027100003322]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 278}], {
             RGBColor[
             0.23415669632153385`, 0.3634439125989312, 0.9366462495004977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 302}], {
             RGBColor[
             0.20076131207818187`, 0.3283432463695126, 0.9347444317718824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 314}], {
             RGBColor[
             0.22141089937149833`, 0.35004727187424184`, 0.93592039521991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 352}], {
             RGBColor[
             0.2248749641652065, 0.3536882236068225, 0.936117668585287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 377}], {
             RGBColor[
             0.19744186238260558`, 0.3248542942741953, 0.9345553940224051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 136}], {
             RGBColor[
             0.18384486237801373`, 0.31056298516977654`, 0.9337810649871026]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 301}], {
             RGBColor[
             0.1828984857165501, 0.3095682832948322, 0.9337271702362709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 335}], {
             RGBColor[
             0.18130162624818058`, 0.3078898827468379, 0.9336362314518891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 394}], {
             RGBColor[
             0.18176625720560394`, 0.308378239342394, 0.9336626914975545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 163}], {
             RGBColor[
             0.272133057471457, 0.4033594760078676, 0.938808947086994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 167}], {
             RGBColor[
             0.29386288759542795`, 0.42605944514024496`, 0.9400515350827954]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 174}], {
             RGBColor[
             0.3107339262181662, 0.44067229083220405`, 0.9411265427453626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 189}], {
             RGBColor[
             0.27205731447598563`, 0.4032798653172439, 0.9388046336354536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 222}], {
             RGBColor[
             0.2549287084068188, 0.3852766143221994, 0.9378291848593165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 226}], {
             RGBColor[
             0.3613558703292786, 0.48451847448835883`, 0.9443521282608951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 395}], {
             RGBColor[
             0.3730551581743753, 0.49423581065451916`, 0.9452125382842432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 145}], {
             RGBColor[
             0.1958024601948291, 0.32313117863074003`, 0.9344620324930895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 200}], {
             RGBColor[
             0.18928086975494526`, 0.31627657358570604`, 0.9340906375653665]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 207}], {
             RGBColor[
             0.19105231071262538`, 0.3181384703480716, 0.9341915185072943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 222}], {
             RGBColor[
             0.21336670811641717`, 0.34159231683396796`, 0.9354622904282476]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 254}], {
             RGBColor[
             0.19079740219879987`, 0.3178705453379077, 0.9341770018445352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 333}], {
             RGBColor[
             0.19123001846776383`, 0.3183252524660446, 0.9342016387010543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 112}], {
             RGBColor[
             0.8780584972468868, 0.4677393624570944, 0.21704509236247566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 141}], {
             RGBColor[
             0.8423033289137494, 0.3148548235404699, 0.18770004553512668`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 172}], {
             RGBColor[
             0.8214061746435448, 0.16554281532163417`, 0.16813188305446203`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 208}], {
             RGBColor[
             0.906012199289136, 0.5692488389367173, 0.4656274775468996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 240}], {
             RGBColor[
             0.825349023280818, 0.19584927771500635`, 0.17190755936232552`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 242}], {
             RGBColor[
             0.8356412746575417, 0.27496003188981555`, 0.1817634309041114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 243}], {
             RGBColor[
             0.8942676597098645, 0.5619556471729128, 0.5511524219741538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 285}], {
             RGBColor[
             0.9066040807260044, 0.5685593406329343, 0.38790788619052163`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 337}], {
             RGBColor[
             0.9065279712784959, 0.568396550220559, 0.3796238425222831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 357}], {
             RGBColor[
             0.8380548061555597, 0.2935114925998279, 0.18407463139230737`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 399}], {
             RGBColor[
             0.8727925927240603, 0.4468618057827464, 0.21280802197674387`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 114}], {
             RGBColor[
             0.22538318625918102`, 0.3542223972507317, 0.9361466110816916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 171}], {
             RGBColor[
             0.19921926143757313`, 0.32672245337457523`, 0.9346566142691592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 202}], {
             RGBColor[
             0.2264175602160962, 0.35530958986254624`, 0.9362055171483188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 218}], {
             RGBColor[
             0.20016816814604027`, 0.3277198144893344, 0.9347106531024247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 229}], {
             RGBColor[
             0.20817939443044792`, 0.33614012125533055`, 0.9351668805877746]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 261}], {
             RGBColor[
             0.23472290345765154`, 0.3640390321985968, 0.9366784941592712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 349}], {
             RGBColor[
             0.20573070891450085`, 0.3335663975224413, 0.935027431570147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 353}], {
             RGBColor[
             0.19974831949640176`, 0.32727852693862247`, 0.9346867433429382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.2877186940288704, 0.4160544664052851, 0.9398315069221266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 150}], {
             RGBColor[
             0.2101822963835033, 0.33824529819931026`, 0.9352809428909732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 158}], {
             RGBColor[
             0.2827874224549232, 0.411783246820848, 0.939517290657987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 241}], {
             RGBColor[
             0.24501597193591163`, 0.37485769978748307`, 0.9372646691818778]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 270}], {
             RGBColor[
             0.2929589759941193, 0.42059333525935383`, 0.9401654130551529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 292}], {
             RGBColor[
             0.21060209943900177`, 0.3386865378276902, 0.9353048500539408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 310}], {
             RGBColor[
             0.2532088981789974, 0.38346898473049273`, 0.9377312442110733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 320}], {
             RGBColor[
             0.21130568150236095`, 0.33942604718596003`, 0.9353449180115927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 347}], {
             RGBColor[
             0.21233497992474068`, 0.3405079050891704, 0.9354035350340366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 374}], {
             RGBColor[
             0.2085188963433679, 0.336496959291474, 0.9351862147194673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 384}], {
             RGBColor[
             0.2081882862900271, 0.33614946716352473`, 0.9351673869660233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 389}], {
             RGBColor[
             0.21473367973065993`, 0.34302909067154336`, 0.9355401374394254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 390}], {
             RGBColor[
             0.24476481400135702`, 0.3745937168739334, 0.9372503661090598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 158}], {
             RGBColor[
             0.34368740964077826`, 0.4721064928245296, 0.9431204357248351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 190}], {
             RGBColor[
             0.6524189980541504, 0.7216233648288316, 0.9512140557147148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 212}], {
             RGBColor[
             0.3829775514957524, 0.5061376389193594, 0.9456239688209257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 241}], {
             RGBColor[
             0.30591595912176667`, 0.43518094579116473`, 0.9408678142487259]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 268}], {
             RGBColor[
             0.5139907876886572, 0.6129102178843966, 0.9560554271690249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 270}], {
             RGBColor[
             0.35385896317997434`, 0.4809165812630355, 0.943768558122001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 295}], {
             RGBColor[
             0.38882676959428764`, 0.5112039376460608, 0.945996675825904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 310}], {
             RGBColor[
             0.3141088853648525, 0.4437922307341744, 0.9413343892779213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 324}], {
             RGBColor[
             0.4908741561658506, 0.5947099474856988, 0.9538480411311054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 346}], {
             RGBColor[
             0.3498425512041035, 0.47743776708027175`, 0.9435126359024721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 351}], {
             RGBColor[
             0.6292040524803684, 0.703641559800374, 0.9673461867380587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 373}], {
             RGBColor[
             0.31023491732991126`, 0.43972044470569116`, 0.9411137725293536]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 390}], {
             RGBColor[
             0.30566480118721207`, 0.43491696287761505`, 0.9408535111759078]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 152}], {
             RGBColor[
             0.2564614085339687, 0.38688757933463486`, 0.9379164698641311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 154}], {
             RGBColor[
             0.23083302352450608`, 0.3599505217562283, 0.9364569712516402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 180}], {
             RGBColor[
             0.25734842126298235`, 0.38781988595268346`, 0.9379669839268308]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 198}], {
             RGBColor[
             0.3047308678845767, 0.4335017597846965, 0.9408162005428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 205}], {
             RGBColor[
             0.3030856171044626, 0.43207672625167026`, 0.9407113666179867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 236}], {
             RGBColor[
             0.2534644343240474, 0.3837375694208677, 0.9377457966165021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 262}], {
             RGBColor[
             0.23515249805591343`, 0.36449056335924074`, 0.936702958936114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 267}], {
             RGBColor[
             0.2560701403937588, 0.38647633171144136`, 0.9378941877223754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 284}], {
             RGBColor[
             0.26637610871838646`, 0.39730855785675745`, 0.9384810973721491]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 286}], {
             RGBColor[
             0.22549943873113315`, 0.3543445859695858, 0.9361532314879892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 332}], {
             RGBColor[
             0.24224909685408347`, 0.3719495386464692, 0.9371070997391926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 367}], {
             RGBColor[
             0.31561783688898226`, 0.44293150514134, 0.9415099085808494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 398}], {
             RGBColor[
             0.34112387915000547`, 0.4650235569768793, 0.9431351310396142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 157}], {
             RGBColor[
             0.18435836126610156`, 0.3111027050588667, 0.9338103079891256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 181}], {
             RGBColor[
             0.18812311022869774`, 0.31505969491742614`, 0.9340247048730984]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 191}], {
             RGBColor[
             0.19427315985261398`, 0.3215237870078299, 0.9343749411009974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 305}], {
             RGBColor[
             0.1817778659169268, 0.3083904408340291, 0.9336633525964908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 334}], {
             RGBColor[
             0.18315174728548578`, 0.30983447726149455`, 0.9337415931079549]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 340}], {
             RGBColor[
             0.19212863805325098`, 0.319269758626164, 0.9342528137570594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 360}], {
             RGBColor[
             0.18328589355082267`, 0.3099754734917281, 0.9337492325393142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 365}], {
             RGBColor[
             0.1811265179483144, 0.30770583282117103`, 0.9336262592932614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 370}], {
             RGBColor[
             0.1842051301196885, 0.31094164940857083`, 0.9338015817020224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 227}], {
             RGBColor[
             0.1954518354139104, 0.3227626497550994, 0.934442064930519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 237}], {
             RGBColor[
             0.19038343508665123`, 0.3174354396560086, 0.9341534270299079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 251}], {
             RGBColor[
             0.18685400772656674`, 0.3137257877219404, 0.9339524313630709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 308}], {
             RGBColor[
             0.1924672891129, 0.3196257023615725, 0.9342720994339171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 375}], {
             RGBColor[
             0.18201536929507323`, 0.30864007194304494`, 0.9336768780625215]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 116}], {
             RGBColor[
             0.1862942905711151, 0.31313748950344333`, 0.9339205562990953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 151}], {
             RGBColor[
             0.1906348725141942, 0.31769971633440997`, 0.9341677460194382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 154}], {
             RGBColor[
             0.19738148096805996`, 0.3247908295791051, 0.934551955390173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 286}], {
             RGBColor[
             0.1920478961746871, 0.3191848937924626, 0.934248215626522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 291}], {
             RGBColor[
             0.18821279065920096`, 0.31515395473595276`, 0.9340298120409453]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 304}], {
             RGBColor[
             0.18507047905985996`, 0.31185118601098283`, 0.9338508620439963]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 383}], {
             RGBColor[
             0.1988021595169091, 0.3262840528101681, 0.9346328609318244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 141}], {
             RGBColor[
             0.9013527030672266, 0.6354761592849575, 0.23890867411463246`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 172}], {
             RGBColor[
             0.880455548797022, 0.4861641510661218, 0.21934051163396778`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 179}], {
             RGBColor[
             0.6955279730573865, 0.6779676106196408, 0.6092046613657698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 240}], {
             RGBColor[
             0.8843983974342954, 0.516470613459494, 0.2231161879418313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 279}], {
             RGBColor[
             0.8046710367643358, 0.7661172165820809, 0.618109700945247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 285}], {
             RGBColor[
             0.9656534548794817, 0.8891806763774219, 0.4391165147700274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 337}], {
             RGBColor[
             0.9655773454319732, 0.8890178859650467, 0.43083247110178885`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 399}], {
             RGBColor[
             0.9318419668775375, 0.7674831415272341, 0.2640166505562497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 124}], {
             RGBColor[
             0.3086276211264817, 0.4416266325643382, 0.9408905883938774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 149}], {
             RGBColor[
             0.26206453775242544`, 0.39277682340214404`, 0.9382355597840353]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 210}], {
             RGBColor[
             0.3065896783902691, 0.43957556926948627`, 0.9407712006743179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 249}], {
             RGBColor[
             0.3083010067824331, 0.4413437356356376, 0.9408697768166884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 266}], {
             RGBColor[
             0.2701389734664643, 0.40126356728639195`, 0.9386953869528927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 293}], {
             RGBColor[
             0.32820995463660485`, 0.4585878656141067, 0.9421383573691648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 315}], {
             RGBColor[
             0.26318579596449465`, 0.3939553368749055, 0.9382994137804598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 316}], {
             RGBColor[
             0.2709397029977173, 0.40210518479292345`, 0.9387409873151243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 387}], {
             RGBColor[
             0.4208258242811829, 0.5366129491256768, 0.9486460027249637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 397}], {
             RGBColor[
             0.2602244815922864, 0.3908428077115391, 0.9381307713078346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 128}], {
             RGBColor[
             0.21795119041436695`, 0.34641089840207934`, 0.9357233699129821]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 155}], {
             RGBColor[
             0.2241859587617661, 0.352964035242341, 0.9360784307468533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 170}], {
             RGBColor[
             0.23647751036378017`, 0.3658832353054412, 0.9367784164268669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 187}], {
             RGBColor[
             0.33810546577905015`, 0.4610349816709624, 0.9429931157731941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 202}], {
             RGBColor[
             0.2423249813764799, 0.37202929809086444`, 0.937111421250482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 261}], {
             RGBColor[
             0.25063032461803525`, 0.380758740426915, 0.9375843982614342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 306}], {
             RGBColor[
             0.2220014868268114, 0.35066801673518333`, 0.9359540283017942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 353}], {
             RGBColor[
             0.2156557406567855, 0.3439982351669406, 0.9355926474451014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 122}], {
             RGBColor[
             0.7312854319265467, 0.5812953754272103, 0.5851154705993664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 166}], {
             RGBColor[
             0.92715146758626, 0.7340525782000142, 0.5145919024804202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 169}], {
             RGBColor[
             0.8801983721871041, 0.6989200901607082, 0.599330145570115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 197}], {
             RGBColor[
             0.914459777232721, 0.7255013666531043, 0.5770167261447392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 221}], {
             RGBColor[
             0.8834582095203258, 0.5636927731060549, 0.2244670121341203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 239}], {
             RGBColor[
             0.8461854795987771, 0.346251043142995, 0.19147853854411218`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 300}], {
             RGBColor[
             0.8896537545747043, 0.7064595554170632, 0.6002320083831638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 350}], {
             RGBColor[
             0.9292292560607558, 0.7349117971309463, 0.4801575703138227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 392}], {
             RGBColor[
             0.9278459781809479, 0.7343397761790258, 0.5030820645906373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 151}], {
             RGBColor[
             0.18767873323802545`, 0.31459262652510106`, 0.9339993982608765]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 154}], {
             RGBColor[
             0.19442534169189124`, 0.3216837397697962, 0.9343836076316113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 265}], {
             RGBColor[
             0.18666044049465552`, 0.3135223362883303, 0.9339414079955707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 291}], {
             RGBColor[
             0.1852566513830322, 0.31204686492664385`, 0.9338614642823836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 304}], {
             RGBColor[
             0.18211433978369124`, 0.30874409620167387`, 0.9336825142854346]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 383}], {
             RGBColor[
             0.19584602024074033`, 0.3231769630008592, 0.9344645131732627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 289}], {
             RGBColor[
             0.20615434433043495`, 0.33401166520462483`, 0.935051556980372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 303}], {
             RGBColor[
             0.21968824533158482`, 0.34823665325571823`, 0.9358222926207751]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 376}], {
             RGBColor[
             0.217871456795024, 0.34632709331274647`, 0.9357188292013159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 158}], {
             RGBColor[
             0.28881871360859035`, 0.41812251622929797`, 0.9398607637666927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 164}], {
             RGBColor[
             0.21991695118991147`, 0.3484770376136085, 0.9358353170810669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 173}], {
             RGBColor[
             0.26068055800241224`, 0.3913221729354959, 0.9381567441846866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 209}], {
             RGBColor[
             0.2868618960178613, 0.41642761918472027`, 0.9397360770801573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 241}], {
             RGBColor[
             0.25104726308957875`, 0.38119696919593304`, 0.9376081422905835]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 323}], {
             RGBColor[
             0.3187861771861727, 0.44407882697168544`, 0.9417702640466686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 346}], {
             RGBColor[
             0.2949738551719156, 0.42345379048504006`, 0.9402529639443298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 354}], {
             RGBColor[
             0.22736699671866945`, 0.3563075078245018, 0.9362595861525749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 388}], {
             RGBColor[
             0.2291977478565746, 0.35823174334676655`, 0.936363844721525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 389}], {
             RGBColor[
             0.22076497088432706`, 0.3493683600799934, 0.9358836105481312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 126}], {
             RGBColor[
             0.1845010944888899, 0.3112527267258263, 0.9338184364350084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 127}], {
             RGBColor[
             0.18861006279746526`, 0.31557151294177693`, 0.9340524361015079]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 129}], {
             RGBColor[
             0.18575214150891103`, 0.312567656464831, 0.9338896817120405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 196}], {
             RGBColor[
             0.18607572050979368`, 0.3129077585108523, 0.9339081090574485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 231}], {
             RGBColor[
             0.18230446054106692`, 0.30894392517202796`, 0.9336933413813087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 235}], {
             RGBColor[
             0.18696497458482364`, 0.31384242092567355`, 0.9339587507614879]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 317}], {
             RGBColor[
             0.1888850042427438, 0.31586049383305914`, 0.9340680936100771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 326}], {
             RGBColor[
             0.18721381086797456`, 0.3141039636363968, 0.933972921619693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 327}], {
             RGBColor[
             0.18901152680793626`, 0.3159934770710704, 0.9340752988829915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 336}], {
             RGBColor[
             0.18138462902211405`, 0.30797712392492177`, 0.9336409583370731]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 396}], {
             RGBColor[
             0.19098691356338682`, 0.3180697337978031, 0.9341877942363916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 132}], {
             RGBColor[
             0.4382862950940797, 0.5522789014915227, 0.9496356996104882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 160}], {
             RGBColor[
             0.48896132780643076`, 0.5959998592268796, 0.9529119733307341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 187}], {
             RGBColor[
             0.47660974925846794`, 0.585472751295903, 0.952077636221743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 202}], {
             RGBColor[
             0.38082926485589774`, 0.49646706771580507`, 0.9461959416990309]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 206}], {
             RGBColor[
             0.624306194339526, 0.7045315727086937, 0.9644880050917888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 217}], {
             RGBColor[
             0.7556843813439534, 0.80370125991605, 0.7211335984965017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 220}], {
             RGBColor[
             0.5770608462863022, 0.6675230171669182, 0.9598474901446392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 233}], {
             RGBColor[
             0.7388527640498924, 0.7945317751585553, 0.9544100950493892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 244}], {
             RGBColor[
             0.7365322986249497, 0.7928011758440465, 0.9583380377395063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 307}], {
             RGBColor[
             0.43332684059947457`, 0.5479832712777266, 0.9493196875555654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 321}], {
             RGBColor[
             0.5363303582199404, 0.6344561720670685, 0.9566410369233613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 341}], {
             RGBColor[
             0.42726711236099996`, 0.542734639248357, 0.9489335670306169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 366}], {
             RGBColor[
             0.4563492884558704, 0.567924158469062, 0.9507866575750236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 122}], {
             RGBColor[
             0.4544345003462795, 0.5641026104704333, 0.9512623074498896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 175}], {
             RGBColor[
             0.29627876905743955`, 0.4285384264353338, 0.9401913224925988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 178}], {
             RGBColor[
             0.376298213208635, 0.5003523318083618, 0.9451983672915776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.26676233186552467`, 0.3975147794964234, 0.938510405060175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 274}], {
             RGBColor[
             0.4019923332344326, 0.5215276967163304, 0.9471338679528571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 296}], {
             RGBColor[
             0.27793336964590865`, 0.4092562484883108, 0.9391465791356984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 319}], {
             RGBColor[
             0.3821339767558598, 0.5054057883182604, 0.9455705453873072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 373}], {
             RGBColor[
             0.2913786665893785, 0.4233881080569608, 0.9399122689060947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 166}], {
             RGBColor[
             0.7938288566186125, 0.8372493846021647, 0.890969402038376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 169}], {
             RGBColor[
             0.7468757612194565, 0.8021168965628588, 0.9757076451280708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 175}], {
             RGBColor[
             0.4398070896700592, 0.5489279977942612, 0.9504219852000314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 178}], {
             RGBColor[
             0.5198265338212547, 0.6207419031672892, 0.9554290299990101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 268}], {
             RGBColor[
             0.638662857560744, 0.7169674525945936, 0.9650845862531987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 274}], {
             RGBColor[
             0.5455206538470523, 0.6419172680752578, 0.9573645306602898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 319}], {
             RGBColor[
             0.5256622973684795, 0.6257953596771879, 0.9558012080947398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 351}], {
             RGBColor[
             0.7538761223524553, 0.8076987945105711, 0.9763753458222324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 131}], {
             RGBColor[
             0.21247713876151392`, 0.34065732304000995`, 0.9354116307694857]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 140}], {
             RGBColor[
             0.21869849237699107`, 0.3471963601464784, 0.9357659276542193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 203}], {
             RGBColor[
             0.21872743662810462`, 0.3472267823895703, 0.935767575986501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 232}], {
             RGBColor[
             0.2533953304852037, 0.3836649369048065, 0.9377418612551098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 275}], {
             RGBColor[
             0.22522408057531274`, 0.3540551670891031, 0.9361375502483711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 280}], {
             RGBColor[
             0.23161694690439888`, 0.3607744749321087, 0.9365016145284144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 297}], {
             RGBColor[
             0.20930917766859286`, 0.3373275950710155, 0.9352312200718224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 309}], {
             RGBColor[
             0.2546471876156135, 0.3849807181211936, 0.93781315266673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 322}], {
             RGBColor[
             0.20580146810397543`, 0.3336407699169709, 0.9350314612013086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 325}], {
             RGBColor[
             0.2504184772778667, 0.38053607544050067`, 0.9375723338688118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 339}], {
             RGBColor[
             0.23162280417676506`, 0.3607806312967381, 0.9365019480914105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 149}], {
             RGBColor[
             0.2631665511656537, 0.3938441656371931, 0.9383016477132344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 185}], {
             RGBColor[
             0.35466498690371884`, 0.48161471850061266`, 0.9438199172409392]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 210}], {
             RGBColor[
             0.30769169180349737`, 0.4406429115045353, 0.9408372886035168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 219}], {
             RGBColor[
             0.32342751125618663`, 0.45455838713589725`, 0.9418294929148936]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 249}], {
             RGBColor[
             0.30940302019566135`, 0.4424110778706867, 0.9409358647458874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 266}], {
             RGBColor[
             0.27124098687969256`, 0.402330909521441, 0.9387614748820916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 293}], {
             RGBColor[
             0.3293119680498331, 0.45965520784915576`, 0.9422044452983639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 315}], {
             RGBColor[
             0.2642878093777229, 0.3950226791099546, 0.9383655017096588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 316}], {
             RGBColor[
             0.27204171641094554`, 0.40317252702797246`, 0.9388070752443234]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 338}], {
             RGBColor[
             0.2719649687624893, 0.40309186038336303`, 0.9388027045792817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 387}], {
             RGBColor[
             0.42192783769441117`, 0.5376802913607258, 0.9487120906541628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 397}], {
             RGBColor[
             0.26132649500551464`, 0.3919101499465881, 0.9381968592370336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 148}], {
             RGBColor[
             0.2977450564931756, 0.4279464199660071, 0.9403529311058223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 162}], {
             RGBColor[
             0.2669203824734684, 0.39788062408229774`, 0.9385120929573202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 211}], {
             RGBColor[
             0.24170072207493107`, 0.37137316198461084`, 0.9370758706067677]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 214}], {
             RGBColor[
             0.25062847588100123`, 0.38075679728707557`, 0.9375842929785951]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 248}], {
             RGBColor[
             0.2397553776330553, 0.3693284816342379, 0.936965086118682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 263}], {
             RGBColor[
             0.326732269165051, 0.4530536866427142, 0.9421999706648885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 276}], {
             RGBColor[
             0.2421845103154749, 0.3718816540993685, 0.9371034216313661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 288}], {
             RGBColor[
             0.28344153985750953`, 0.415245407994804, 0.9394529484294792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 196}], {
             RGBColor[
             0.1881608487233165, 0.3150993604680292, 0.9340268540245378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 289}], {
             RGBColor[
             0.1863769520635358, 0.31322437197301883`, 0.933925263748802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 317}], {
             RGBColor[
             0.1909701324562666, 0.31805209579023613`, 0.9341868385771666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 326}], {
             RGBColor[
             0.18929893908149736`, 0.31629556559357375`, 0.9340916665867824]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 327}], {
             RGBColor[
             0.19109665502145906`, 0.31818507902824733`, 0.9341940438500809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 336}], {
             RGBColor[
             0.18346975723563688`, 0.31016872588209876`, 0.9337597033041625]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 376}], {
             RGBColor[
             0.19809406452812484`, 0.3255398000811405, 0.9345925359697458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 129}], {
             RGBColor[
             0.19194623803100921`, 0.3190780446379586, 0.9342424263456293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 216}], {
             RGBColor[
             0.19725740387013102`, 0.32466041668223944`, 0.9345448893830015]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 231}], {
             RGBColor[
             0.1884985570631651, 0.31545431334515556`, 0.9340460860148976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 235}], {
             RGBColor[
             0.19315907110692182`, 0.32035280909880115`, 0.9343114953950769]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 298}], {
             RGBColor[
             0.19590091614963856`, 0.32323466208171286`, 0.9344676394140633]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 313}], {
             RGBColor[
             0.20658568658737522`, 0.3344650332653477, 0.935076121283791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 317}], {
             RGBColor[
             0.19507910076484197`, 0.32237088200618674`, 0.9344208382436661]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 336}], {
             RGBColor[
             0.18757872554421223`, 0.31448751209804937`, 0.933993702970662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 361}], {
             RGBColor[
             0.2062200768333135, 0.33408075423283157`, 0.9350553003491684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 393}], {
             RGBColor[
             0.1890837058583692, 0.31606934182949153`, 0.9340794093731344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 396}], {
             RGBColor[
             0.197181010085485, 0.3245801219709307, 0.9345405388699805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 133}], {
             RGBColor[
             0.19019948162046302`, 0.31724209289972144`, 0.9341429511521433]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 155}], {
             RGBColor[
             0.2008465417565683, 0.32843282816537045`, 0.9347492854759805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 170}], {
             RGBColor[
             0.21313809335858236`, 0.34135202822847077`, 0.9354492711559941]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 171}], {
             RGBColor[
             0.19178726559275905`, 0.3189109545259229, 0.9342333731004496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 199}], {
             RGBColor[
             0.1905507884017967, 0.3176113386010396, 0.9341629575536283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 261}], {
             RGBColor[
             0.22729090761283746`, 0.3562275333499445, 0.9362552529905616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 299}], {
             RGBColor[
             0.19113698074466645`, 0.31822746392013684`, 0.934196340340361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 306}], {
             RGBColor[
             0.1986620698216136, 0.3261368096582128, 0.9346248830309214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 342}], {
             RGBColor[
             0.18916310762939384`, 0.3161527981252015, 0.9340839311865298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 353}], {
             RGBColor[
             0.19231632365158768`, 0.3194670280899702, 0.9342635021742287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 216}], {
             RGBColor[
             0.1943994825815768, 0.32165656020529343`, 0.9343821349935341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 231}], {
             RGBColor[
             0.18564063577461087`, 0.3124504568682096, 0.93388333162543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 235}], {
             RGBColor[
             0.1903011498183676, 0.3173489526218552, 0.9341487410056093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 298}], {
             RGBColor[
             0.19304299486108434`, 0.3202308056047669, 0.9343048850245959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 313}], {
             RGBColor[
             0.203727765298821, 0.33146117678840176`, 0.9349133668943235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 317}], {
             RGBColor[
             0.19222117947628775`, 0.3193670255292408, 0.9342580838541985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 336}], {
             RGBColor[
             0.184720804255658, 0.3114836556211034, 0.9338309485811944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 361}], {
             RGBColor[
             0.20336215554475928`, 0.33107689775588556`, 0.9348925459597008]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 393}], {
             RGBColor[
             0.18622578456981498`, 0.3130654853525456, 0.9339166549836668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 396}], {
             RGBColor[
             0.19432308879693078`, 0.32157626549398477`, 0.934377784480513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 147}], {
             RGBColor[
             0.18274418895711692`, 0.3094061076176884, 0.9337183832640827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 164}], {
             RGBColor[
             0.19148238974395732`, 0.318590510678587, 0.9342160108718838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 287}], {
             RGBColor[
             0.1859722872961475, 0.31279904364526556`, 0.9339022186889471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 371}], {
             RGBColor[
             0.18427986944939637`, 0.311020205182841, 0.9338058379962824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 391}], {
             RGBColor[
             0.18156952589467779`, 0.3081714622611251, 0.9336514879404352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 140}], {
             RGBColor[
             0.21947779992995464`, 0.3480154617955958, 0.9358103080664784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 186}], {
             RGBColor[
             0.21005402739966472`, 0.3381104793645726, 0.9352736381621005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 188}], {
             RGBColor[
             0.20752052535930418`, 0.3354476080868466, 0.9351293589688823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 203}], {
             RGBColor[
             0.2195067441810682, 0.34804588403868764`, 0.9358119563987601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 228}], {
             RGBColor[
             0.20842587898456535`, 0.33639919214973135`, 0.9351809175184903]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 238}], {
             RGBColor[
             0.2516193138752771, 0.38179823084181674`, 0.9376407197365557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 273}], {
             RGBColor[
             0.19754073794696791`, 0.32495821876141306`, 0.9345610248395222]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 280}], {
             RGBColor[
             0.23239625445736245`, 0.36159357658122604`, 0.9365459949406734]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 309}], {
             RGBColor[
             0.255426495168577, 0.38579981977031097`, 0.9378575330789891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 322}], {
             RGBColor[
             0.206580775656939, 0.33445987156608825`, 0.9350758416135677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 325}], {
             RGBColor[
             0.2511977848308302, 0.381355177089618, 0.9376167142810707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 330}], {
             RGBColor[
             0.199593351679308, 0.3271156459373298, 0.9346779181550091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 339}], {
             RGBColor[
             0.23240211172972863`, 0.36159973294585546`, 0.9365463285036696]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 160}], {
             RGBColor[
             0.40894844852211004`, 0.5284611159894712, 0.9473261168602697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 202}], {
             RGBColor[
             0.300816385571577, 0.4289283244783967, 0.9406100852285664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 220}], {
             RGBColor[
             0.4970479670019815, 0.5999842739295098, 0.9542616336741748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 244}], {
             RGBColor[
             0.656519419340629, 0.7252624326066381, 0.9527521812690418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 260}], {
             RGBColor[
             0.29142760754703456`, 0.4190601234916939, 0.9400754082095211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 307}], {
             RGBColor[
             0.3533139613151539, 0.48044452804031823`, 0.9437338310851009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 321}], {
             RGBColor[
             0.4563174789356197, 0.5669174288296601, 0.9510551804528969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 341}], {
             RGBColor[
             0.34725423307667924`, 0.4751958960109486, 0.9433477105601525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 348}], {
             RGBColor[
             0.34570653122762846`, 0.47385535445905747`, 0.94324909236691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 366}], {
             RGBColor[
             0.3763364091715497, 0.5003854152316536, 0.9452008011045592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 155}], {
             RGBColor[
             0.1964342499678622, 0.3237952297399831, 0.9344980119860145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 199}], {
             RGBColor[
             0.18613849661309062`, 0.31297374017565216`, 0.9339116840636623]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 216}], {
             RGBColor[
             0.19274891912622777`, 0.3199217133619542, 0.9342881378465417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 298}], {
             RGBColor[
             0.1913924314057353, 0.3184959587614276, 0.9342108878776034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 299}], {
             RGBColor[
             0.18672468895596034`, 0.31358986549474943`, 0.9339450668503949]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 306}], {
             RGBColor[
             0.1942497780329075, 0.32149921123282543`, 0.9343736095409554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 342}], {
             RGBColor[
             0.18475081584068775`, 0.311515199699814, 0.9338326576965637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 361}], {
             RGBColor[
             0.20171159208941025`, 0.3293420509125463, 0.9347985488127086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 393}], {
             RGBColor[
             0.18457522111446595`, 0.3113306385092063, 0.9338226578366745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 135}], {
             RGBColor[
             0.9129052217970873, 0.9297159641585085, 0.8318647617559947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 226}], {
             RGBColor[
             0.6381042655490734, 0.7140610165668736, 0.9666654902064342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 234}], {
             RGBColor[
             0.8083454624285121, 0.8502936670726204, 0.9815084195744261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 239}], {
             RGBColor[
             0.8293655507418161, 0.5412295041829576, 0.578979393717503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 246}], {
             RGBColor[
             0.8756067697264411, 0.9036490867400013, 0.9879973494315406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 269}], {
             RGBColor[
             0.7872748442941331, 0.8338331400434145, 0.9794082972749127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 272}], {
             RGBColor[
             0.7859507335711424, 0.832798734683, 0.9792763222925633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 350}], {
             RGBColor[
             0.9124093272037948, 0.929890258170909, 0.8676584254872136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 355}], {
             RGBColor[
             0.7983376603764013, 0.8424754960473988, 0.9805109353940992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 392}], {
             RGBColor[
             0.9110260493239869, 0.9293182372189884, 0.8905829197640283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 395}], {
             RGBColor[
             0.6498035533941702, 0.7237783527330339, 0.9675259002297822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 156}], {
             RGBColor[
             0.9129140627520606, 0.6152764832633987, 0.4286476247419544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 165}], {
             RGBColor[
             0.9457959012350979, 0.9559420991486686, 0.8350019041226482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 221}], {
             RGBColor[
             0.9485753172801801, 0.8203317071995411, 0.46009294767531356`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 234}], {
             RGBColor[
             0.8902824990453274, 0.9119541401261442, 0.8296334999422285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 255}], {
             RGBColor[
             0.9151018270707441, 0.6320925985012373, 0.4307426303242521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 281}], {
             RGBColor[
             0.711765095722288, 0.768553055573181, 0.8142632180180123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 328}], {
             RGBColor[
             0.932186507346842, 0.7459139489960613, 0.44641772294044424`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 355}], {
             RGBColor[
             0.8802746969932166, 0.9041359691009224, 0.8286360157619015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 386}], {
             RGBColor[
             0.8778014359212141, 0.9022038387539937, 0.8283895042121832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 400}], {
             RGBColor[
             0.9225103695720027, 0.6890379026099368, 0.4378370589902095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 331}], {
             RGBColor[
             0.19186850922797938`, 0.3189963467376835, 0.9342379998052863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 335}], {
             RGBColor[
             0.18204623503960604`, 0.3086725137975501, 0.9336786358210108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 394}], {
             RGBColor[
             0.18251086599702937`, 0.30916087039310625`, 0.9337050958666762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 169}], {
             RGBColor[
             0.6151260920101136, 0.6919294010372166, 0.9662275076726026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 175}], {
             RGBColor[
             0.3080574204607164, 0.43874050226861905`, 0.940941847744563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 178}], {
             RGBColor[
             0.3880768646119117, 0.5105544076416471, 0.9459488925435418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 197}], {
             RGBColor[
             0.6493874970557305, 0.7185106775296126, 0.9439140882472267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 252}], {
             RGBColor[
             0.35201484785933657`, 0.47931930126023004`, 0.943651052724457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 278}], {
             RGBColor[
             0.29631468313808673`, 0.42639814080998684`, 0.9402731162258624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 282}], {
             RGBColor[
             0.3008030444529849, 0.4311156931304887, 0.9405287217628104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 300}], {
             RGBColor[
             0.624581474397714, 0.6994688662935715, 0.9671293704856514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 314}], {
             RGBColor[
             0.28356888618805115`, 0.41300150008529746`, 0.9395472619452747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 319}], {
             RGBColor[
             0.3939126281591366, 0.5156078641515458, 0.9463210706392715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 352}], {
             RGBColor[
             0.28703295098175935`, 0.4166424518178782, 0.9397445353106518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 159}], {
             RGBColor[
             0.18138230828610377`, 0.30797468468423184`, 0.9336408261745905]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 215}], {
             RGBColor[
             0.18262441317102773`, 0.30928021567228525`, 0.9337115622102574]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 218}], {
             RGBColor[
             0.18655648275495362`, 0.3134130701126022, 0.9339354877560864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 229}], {
             RGBColor[
             0.19456770903936127`, 0.32183337687859837`, 0.9343917152414362]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 329}], {
             RGBColor[
             0.18634787164566047`, 0.31319380661002694`, 0.9339236076620245]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 349}], {
             RGBColor[
             0.19211902352341417`, 0.31925965314570914`, 0.9342522662238085]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 193}], {
             RGBColor[
             0.18750230329400064`, 0.31440718746762647`, 0.933989350836569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 204}], {
             RGBColor[
             0.19084712474135193`, 0.31792280688272123`, 0.9341798334697757]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 224}], {
             RGBColor[
             0.18369701044953324`, 0.3104075834185898, 0.9337726450385029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 276}], {
             RGBColor[
             0.20545840173873126`, 0.33328018541543536`, 0.9350119240793292]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 290}], {
             RGBColor[
             0.19313846063632573`, 0.32033114618742536`, 0.9343103216592668]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 318}], {
             RGBColor[
             0.19122506102961745`, 0.318320041884233, 0.9342013563822857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 203}], {
             RGBColor[
             0.22572809779654535`, 0.3545849211451561, 0.9361662532834936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 232}], {
             RGBColor[
             0.2603959916536444, 0.39102307566039235`, 0.9381405385521024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 257}], {
             RGBColor[
             0.2744017745717613, 0.404416509747592, 0.9389867546110457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 275}], {
             RGBColor[
             0.23222474174375346`, 0.36141330584468895`, 0.9365362275453637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 280}], {
             RGBColor[
             0.2386176080728396, 0.36813261368769457`, 0.936900291825407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 288}], {
             RGBColor[
             0.2655351688852008, 0.39642467677341436`, 0.9384332070927082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 297}], {
             RGBColor[
             0.21630983883703356`, 0.3446857338266013, 0.935629897368815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 309}], {
             RGBColor[
             0.2616478487840542, 0.3923388568767794, 0.9382118299637227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 322}], {
             RGBColor[
             0.21280212927241615`, 0.34099890867255667`, 0.9354301384983013]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 325}], {
             RGBColor[
             0.25741913844630737`, 0.3878942141960865, 0.9379710111658044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 339}], {
             RGBColor[
             0.2386234653452058, 0.3681387700523239, 0.9369006253884031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 172}], {
             RGBColor[
             0.8447003804638847, 0.3332796121494973, 0.18999546480661883`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[
             0.8486432291011581, 0.36358607454286945`, 0.19377114111448232`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 243}], {
             RGBColor[
             0.9175618655302045, 0.7296924440007758, 0.5730160037263106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 279}], {
             RGBColor[
             0.7689158684311985, 0.6132326776654563, 0.588764654117898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 285}], {
             RGBColor[
             0.9298982865463443, 0.7362961374607975, 0.4097714679426784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 337}], {
             RGBColor[
             0.9298221770988357, 0.7361333470484221, 0.40148742427443984`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 399}], {
             RGBColor[
             0.8960867985444002, 0.6145986026106095, 0.23467160372890067`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 143}], {
             RGBColor[
             0.1837659567931899, 0.3104800503972236, 0.9337765714307771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 258}], {
             RGBColor[
             0.18294835007904106`, 0.30962069390139346`, 0.9337300099379471]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 277}], {
             RGBColor[
             0.19515207298431664`, 0.32244758043556054`, 0.9344249939036124]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 302}], {
             RGBColor[
             0.18693197467623224`, 0.31380773592942895`, 0.9339568714655127]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 377}], {
             RGBColor[
             0.18361252498065594`, 0.31031878383411166`, 0.9337678337160353]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 378}], {
             RGBColor[
             0.18665371404405717`, 0.3135152663622699, 0.93394102493416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 379}], {
             RGBColor[
             0.1947953347030193, 0.32207262588340363`, 0.9344046781862394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 258}], {
             RGBColor[
             0.1842254727690224, 0.31096303082281923`, 0.9338027401858078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 277}], {
             RGBColor[
             0.196429195674298, 0.32378991735698637`, 0.9344977241514731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 302}], {
             RGBColor[
             0.1882090973662136, 0.3151500728508547, 0.9340296017133733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 377}], {
             RGBColor[
             0.1848896476706373, 0.3116611207555374, 0.933840563963896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 378}], {
             RGBColor[
             0.18793083673403851`, 0.31485760328369566`, 0.9340137551820207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 379}], {
             RGBColor[
             0.19607245739300067`, 0.3234149628048294, 0.9344774084341002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 186}], {
             RGBColor[
             0.19870087032152506`, 0.3261775914437136, 0.9346270926619912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 188}], {
             RGBColor[
             0.19616736828116454`, 0.3235147201659876, 0.934482813468773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 200}], {
             RGBColor[
             0.18738223875410484`, 0.31428099202366444`, 0.9339825133386415]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 228}], {
             RGBColor[
             0.19707272190642572`, 0.32446630422887235`, 0.934534372018381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 333}], {
             RGBColor[
             0.1893313874669234, 0.316329670904003, 0.9340935144743294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 368}], {
             RGBColor[
             0.18786109875542928`, 0.31478430424653414`, 0.934009783707307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 200}], {
             RGBColor[
             0.19073593578989534`, 0.3178059402449537, 0.9341735014234795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 207}], {
             RGBColor[
             0.19250737674757545`, 0.31966783700731927`, 0.9342743823654074]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 222}], {
             RGBColor[
             0.21482177415136725`, 0.3431216834932156, 0.9355451542863606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 254}], {
             RGBColor[
             0.19225246823374995`, 0.31939991199715534`, 0.9342598657026484]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 333}], {
             RGBColor[
             0.19268508450271393`, 0.3198546191252922, 0.9342845025591675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 227}], {
             RGBColor[
             0.19680598858419968`, 0.3241859505953433, 0.934519181950277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 302}], {
             RGBColor[
             0.18875875182792845`, 0.3157277945402228, 0.9340609037218272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 375}], {
             RGBColor[
             0.18336952246536248`, 0.3100633727832889, 0.9337539950822794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 377}], {
             RGBColor[
             0.18543930213235216`, 0.3122388424449055, 0.9338718659723498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 344}], {
             RGBColor[
             0.1873628349672718, 0.31426059741343176`, 0.9339814083216866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 354}], {
             RGBColor[
             0.1996644579713909, 0.3271903831587082, 0.9346819675531508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 371}], {
             RGBColor[
             0.18501189214807195`, 0.3117896074520688, 0.9338475256060415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 388}], {
             RGBColor[
             0.20149520910929605`, 0.3291146186809729, 0.9347862261221009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 391}], {
             RGBColor[
             0.18230154859335337`, 0.30894086453035285`, 0.9336931755501943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 179}], {
             RGBColor[
             0.39396314610535543`, 0.515635700812435, 0.9463286881882242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 232}], {
             RGBColor[
             0.3145355236290795, 0.4455942655029455, 0.9413091233699418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 257}], {
             RGBColor[
             0.3285413065471964, 0.4589876995901452, 0.9421553394288851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 275}], {
             RGBColor[
             0.28636427371918854`, 0.4159844956872421, 0.939704812363203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 276}], {
             RGBColor[
             0.27841767131860123`, 0.407632112720532, 0.9392522651124343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 279}], {
             RGBColor[
             0.5031062098123048, 0.6037853067748751, 0.9552337277677017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 288}], {
             RGBColor[
             0.3196747008606359, 0.4509958666159675, 0.9416017919105475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 195}], {
             RGBColor[
             0.20922588183301488`, 0.33724004586656203`, 0.9352264764972114]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 210}], {
             RGBColor[
             0.26112860842944113`, 0.3917931023423411, 0.9381822599936748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 247}], {
             RGBColor[
             0.20711572977977888`, 0.33502214226724336`, 0.9351063064594698]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 249}], {
             RGBColor[
             0.2628399368216051, 0.3935612687084925, 0.9382808361360453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 253}], {
             RGBColor[
             0.20384820267597584`, 0.3315877641079622, 0.9349202256247814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 266}], {
             RGBColor[
             0.22467790350563632`, 0.35348110035924685`, 0.9361064462722496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 315}], {
             RGBColor[
             0.21772472600366666`, 0.3461728699477604, 0.9357104730998167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 316}], {
             RGBColor[
             0.2254786330368893, 0.3543227178657783, 0.9361520466344813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 358}], {
             RGBColor[
             0.20368965097586314`, 0.3314211162183854, 0.9349111963400162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 359}], {
             RGBColor[
             0.20190369877404518`, 0.3295439672183649, 0.9348094890042022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 362}], {
             RGBColor[
             0.20288427131655484`, 0.3305746111324327, 0.934865331159871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 363}], {
             RGBColor[
             0.21825217126115545`, 0.34672724835534197`, 0.9357405103269454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 369}], {
             RGBColor[
             0.20360056980323105`, 0.3313274862578765, 0.9349061232990186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 397}], {
             RGBColor[
             0.21476341163145843`, 0.34306034078439396`, 0.9355418306271915]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 192}], {
             RGBColor[
             0.1875835174154828, 0.3144925486585769, 0.9339939758606419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 283}], {
             RGBColor[
             0.2012631111576979, 0.32887066901798323`, 0.9347730084871156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 294}], {
             RGBColor[
             0.19175282420721007`, 0.318874754446001, 0.9342314117144941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 320}], {
             RGBColor[
             0.19466927104284892`, 0.32194012498366686`, 0.9343974990472872]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 347}], {
             RGBColor[
             0.19569856946522865`, 0.3230219828868772, 0.9344561160697312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 380}], {
             RGBColor[
             0.20683506244234898`, 0.3347271431002675, 0.9350903228698133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 381}], {
             RGBColor[
             0.19485465175919953`, 0.32213497187036766`, 0.9344080562048372]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 384}], {
             RGBColor[
             0.19155187583051508`, 0.31866354496123156`, 0.9342199680017178]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 168}], {
             RGBColor[
             0.18811217327033666`, 0.31504819948074547`, 0.9340240820294996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 265}], {
             RGBColor[
             0.1910010224377346, 0.31808456311929695`, 0.9341885977159134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 291}], {
             RGBColor[
             0.1895972333261113, 0.3166090917576105, 0.9341086540027264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 304}], {
             RGBColor[
             0.1864549217267703, 0.3133063230326405, 0.9339297040057775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 378}], {
             RGBColor[
             0.19141895458300517`, 0.3185238363024048, 0.9342123983333115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 383}], {
             RGBColor[
             0.20018660218381945`, 0.3277391898318258, 0.9347117028936056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 154}], {
             RGBColor[
             0.23114091709829876`, 0.3602741374238645, 0.93647450533518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 180}], {
             RGBColor[
             0.2576563148367751, 0.3881435016203197, 0.9379845180103705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 198}], {
             RGBColor[
             0.3050387614583694, 0.43382537545233274`, 0.9408337346263971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 236}], {
             RGBColor[
             0.2537723278978401, 0.38406118508850384`, 0.9377633307000419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 267}], {
             RGBColor[
             0.25637803396755154`, 0.3867999473790775, 0.9379117218059152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 284}], {
             RGBColor[
             0.26668400229217915`, 0.3976321735243937, 0.9384986314556889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 332}], {
             RGBColor[
             0.24255699042787615`, 0.37227315431410535`, 0.9371246338227324]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 367}], {
             RGBColor[
             0.31592573046277495`, 0.4432551208089762, 0.9415274426643891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 383}], {
             RGBColor[
             0.2325615956471479, 0.3617673606549275, 0.9365554108768314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 398}], {
             RGBColor[
             0.3414317727237982, 0.4653471726445155, 0.943152665123154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 161}], {
             RGBColor[
             0.1909498488692258, 0.3180307764542026, 0.9341856834568915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 184}], {
             RGBColor[
             0.18277753601960423`, 0.3094411574946885, 0.933720282329959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[
             0.18871819494406902`, 0.31568516668383156`, 0.9340585940672899]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 372}], {
             RGBColor[
             0.18825648302408265`, 0.31519987818169937`, 0.9340323002564883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 180}], {
             RGBColor[
             0.2320279298273124, 0.36120644404191316`, 0.9365250193978796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 236}], {
             RGBColor[
             0.22814394288837742`, 0.3571241275100973, 0.936303832087551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 267}], {
             RGBColor[
             0.23074964895808886`, 0.359862889800671, 0.9364522231934242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 286}], {
             RGBColor[
             0.2001789472954632, 0.3277311440588154, 0.9347112669590381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 291}], {
             RGBColor[
             0.1963438417799771, 0.3237002050023056, 0.9344928633734613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 332}], {
             RGBColor[
             0.2169286054184135, 0.3453360967356988, 0.9356651352102414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 383}], {
             RGBColor[
             0.20693321063768522`, 0.33483030307652095`, 0.9350959122643404]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 170}], {
             RGBColor[
             0.21937286170598153`, 0.34790516506873237`, 0.9358043319898652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 171}], {
             RGBColor[
             0.19802203394015824`, 0.32546409136618454`, 0.9345884339343208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 199}], {
             RGBColor[
             0.1967855567491959, 0.3241644754413012, 0.9345180183874995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 261}], {
             RGBColor[
             0.23352567596023666`, 0.3627806701902061, 0.9366103138244327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.19737174909206562`, 0.3247806007603985, 0.9345514011742322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 306}], {
             RGBColor[
             0.20489683816901277`, 0.33268994649847444`, 0.9349799438647926]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 342}], {
             RGBColor[
             0.19539787597679303`, 0.32270593496546307`, 0.9344389920204009]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 353}], {
             RGBColor[
             0.19855109199898685`, 0.3260201649302318, 0.9346185630080999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 361}], {
             RGBColor[
             0.21235865222551553`, 0.3405327861781953, 0.9354048831365458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 165}], {
             RGBColor[
             0.8638677055732559, 0.5798421452000351, 0.5836596867408057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 221}], {
             RGBColor[
             0.866647121618338, 0.4442317532509077, 0.20875073029347097`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 245}], {
             RGBColor[
             0.8249079613041663, 0.19245908208786985`, 0.17148519791537548`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 255}], {
             RGBColor[
             0.833173631408902, 0.25599264455260395`, 0.17940041294240955`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 328}], {
             RGBColor[
             0.850258311685, 0.36981399504742796`, 0.1950755055586017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 364}], {
             RGBColor[
             0.8243314936689592, 0.18802809923393973`, 0.1709331718568741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 386}], {
             RGBColor[
             0.795873240259372, 0.5261038848053603, 0.5770472868303405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 400}], {
             RGBColor[
             0.8405821739101607, 0.3129379486613033, 0.18649484160836693`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 181}], {
             RGBColor[
             0.19115892919796787`, 0.31825053313616897`, 0.9341975902723066]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 191}], {
             RGBColor[
             0.1973089788218841, 0.3247146252265727, 0.9345478265002056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 334}], {
             RGBColor[
             0.1861875662547559, 0.3130253154802374, 0.9339144785071631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 365}], {
             RGBColor[
             0.18416233691758455`, 0.3108966710399138, 0.9337991446924696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 370}], {
             RGBColor[
             0.18724094908895864`, 0.3141324876273136, 0.9339744671012307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 209}], {
             RGBColor[
             0.336799320476102, 0.4661403761955148, 0.94268153277416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 241}], {
             RGBColor[
             0.3009846875478195, 0.43090972620672763`, 0.9405535979845862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 270}], {
             RGBColor[
             0.3489276916060272, 0.4766453616785984, 0.9434543418578613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 310}], {
             RGBColor[
             0.30917761379090525`, 0.4395210111497373, 0.9410201730137817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 323}], {
             RGBColor[
             0.3687236016444134, 0.49379158398248, 0.9447157197406713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 324}], {
             RGBColor[
             0.4859428845919035, 0.5904387279012617, 0.9535338248669657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 346}], {
             RGBColor[
             0.34491127963015633`, 0.47316654749583464`, 0.9431984196383325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 390}], {
             RGBColor[
             0.3007335296132649, 0.43064574329317795`, 0.9405392949117681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 215}], {
             RGBColor[
             0.1817543271405076, 0.3083657000875679, 0.9336620120979963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 218}], {
             RGBColor[
             0.18568639672443343`, 0.31249855452788494`, 0.9338859376438252]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 329}], {
             RGBColor[
             0.18547778561514033`, 0.3122792910253096, 0.9338740575497635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 349}], {
             RGBColor[
             0.191248937492894, 0.31834513756099186`, 0.9342027161115474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 217}], {
             RGBColor[
             0.7263465347719837, 0.7798834744139984, 0.7188240157462833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 220}], {
             RGBColor[
             0.5477229997143326, 0.6437052316648666, 0.9575379073944208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 233}], {
             RGBColor[
             0.7095149174779228, 0.7707139896565038, 0.9521005122991707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 244}], {
             RGBColor[
             0.7071944520529801, 0.7689833903419949, 0.9560284549892878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 263}], {
             RGBColor[
             0.42578806203725694`, 0.5430467428327064, 0.9483991221427692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 264}], {
             RGBColor[
             0.5914575736276367, 0.6779711437656651, 0.9618285011853527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 307}], {
             RGBColor[
             0.403988994027505, 0.524165485775675, 0.9470101048053469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 312}], {
             RGBColor[
             0.38126624461740655`, 0.5039445125232649, 0.9455819912605958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 321}], {
             RGBColor[
             0.5069925116479708, 0.6106383865650169, 0.9543314541731429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 341}], {
             RGBColor[
             0.3979292657890303, 0.5189168537463054, 0.9466239842803985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 348}], {
             RGBColor[
             0.39638156393997953`, 0.5175763121944144, 0.946525366087156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 366}], {
             RGBColor[
             0.4270114418839008, 0.5441063729670104, 0.948477074824805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 176}], {
             RGBColor[
             0.21656199837052442`, 0.34495076948413805`, 0.9356442574812107]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 184}], {
             RGBColor[
             0.19128276610466352`, 0.31838069357681953`, 0.9342046426009427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 195}], {
             RGBColor[
             0.20065168741435874`, 0.3282280238972294, 0.9347381888094528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 250}], {
             RGBColor[
             0.22890128499152032`, 0.3579201420787632, 0.9363469615999377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 344}], {
             RGBColor[
             0.1953522686165181, 0.3226579987381405, 0.9344363947487033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.19722342502912832`, 0.3246247027659626, 0.9345429543382737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 363}], {
             RGBColor[
             0.20967797684249928`, 0.3377152263860093, 0.9352522226391868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 372}], {
             RGBColor[
             0.19676171310914198`, 0.3241394142638304, 0.934516660527472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 191}], {
             RGBColor[
             0.239776323432642, 0.3693504969976439, 0.936966278950982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 211}], {
             RGBColor[
             0.24710920905835015`, 0.37705782472206506`, 0.9373838759393338]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 214}], {
             RGBColor[
             0.25603696286442035`, 0.3864414600245297, 0.9378922983111614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 248}], {
             RGBColor[
             0.24516386461647438`, 0.3750131443716921, 0.9372730914512483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 263}], {
             RGBColor[
             0.33214075614847005`, 0.45873834938016844`, 0.9425079759974546]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 312}], {
             RGBColor[
             0.28761893872861966`, 0.41963611907072695`, 0.9396908451152812]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 340}], {
             RGBColor[
             0.23763180163327896`, 0.367096468615978, 0.9368441516070439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 348}], {
             RGBColor[
             0.3027342580511927, 0.4332679187418763, 0.9406342199418414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 167}], {
             RGBColor[
             0.2885245503262027, 0.4204485142001573, 0.9397475246726753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 174}], {
             RGBColor[
             0.3053955889489409, 0.4350613598921163, 0.9408225323352425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.2667189772067604, 0.39766893437715617`, 0.9385006232253336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 222}], {
             RGBColor[
             0.24959037113759353`, 0.3796656833821117, 0.9375251744491964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 226}], {
             RGBColor[
             0.35601753306005335`, 0.4789075435482711, 0.944048117850775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 395}], {
             RGBColor[
             0.36771682090515007`, 0.4886248797144314, 0.9449085278741232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 287}], {
             RGBColor[
             0.19544251078166353`, 0.3227528489753921, 0.9344415339065071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 292}], {
             RGBColor[
             0.19766905263223078`, 0.3250930856312453, 0.9345683321710234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 354}], {
             RGBColor[
             0.20840265875823133`, 0.3363747862196069, 0.9351795951609518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 371}], {
             RGBColor[
             0.1937500929349124, 0.3209740105129675, 0.9343451532138425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 374}], {
             RGBColor[
             0.1955858495365969, 0.322903507095029, 0.9344496968365499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 388}], {
             RGBColor[
             0.21023340989613648`, 0.33829902174187165`, 0.935283853729902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 389}], {
             RGBColor[
             0.20180063292388895`, 0.3294356384750984, 0.934803619556508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 391}], {
             RGBColor[
             0.1910397493801938, 0.3181252675912516, 0.9341908031579952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 182}], {
             RGBColor[
             0.6226406331298818, 0.6984050769847048, 0.9667215385795859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 256}], {
             RGBColor[
             0.624029163944416, 0.6996077525866663, 0.9668100145352584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 281}], {
             RGBColor[
             0.6627187385434833, 0.7331187175098175, 0.9692752800168635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 311}], {
             RGBColor[
             0.5997467789297788, 0.6780206465223158, 0.965283080943369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 328}], {
             RGBColor[
             0.8831401501680374, 0.7104796109326978, 0.6014297849392954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 386}], {
             RGBColor[
             0.8287550787424094, 0.8667695006906301, 0.9834015662110343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 400}], {
             RGBColor[
             0.873464012393198, 0.6536035645465732, 0.5928491209890607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 169}], {
             RGBColor[
             0.9427417968791698, 0.9548740993356628, 0.9051840770091248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 178}], {
             RGBColor[
             0.7156925694809679, 0.7734991059400932, 0.884905461880064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 197}], {
             RGBColor[
             0.9770032019247867, 0.9814553758280588, 0.8828706575837489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.9087289042908429, 0.6022050523179494, 0.4973324699831219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 300}], {
             RGBColor[
             0.9521971792667703, 0.9624135645920178, 0.9060859398221737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 319}], {
             RGBColor[
             0.7215283330281927, 0.7785525624499918, 0.8852776399757938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 174}], {
             RGBColor[
             0.3271254190729118, 0.4577613290244936, 0.9420651203310438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 183}], {
             RGBColor[
             0.33012064304919175`, 0.46035564148841296`, 0.9422559733542398]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 189}], {
             RGBColor[
             0.2884488073307313, 0.4203689035095335, 0.9397432112211349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 222}], {
             RGBColor[
             0.2713202012615644, 0.4023656525144891, 0.9387677624449977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 238}], {
             RGBColor[
             0.3001182809431252, 0.43263426016352036`, 0.9404077704799216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 246}], {
             RGBColor[
             0.6152498673613919, 0.6911955828537762, 0.9666225650716829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 269}], {
             RGBColor[
             0.5269179419290838, 0.6213796361571894, 0.958033512915055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 272}], {
             RGBColor[
             0.5255938312060932, 0.6203452307967748, 0.9579015379327056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 309}], {
             RGBColor[
             0.30392546223642514`, 0.4366358490920146, 0.940624583822355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 395}], {
             RGBColor[
             0.389446651029121, 0.5113248488468087, 0.9461511158699245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 265}], {
             RGBColor[
             0.18709388052696674`, 0.31397790924397473`, 0.9339660917641938]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 304}], {
             RGBColor[
             0.18254777981600245`, 0.3091996691573183, 0.9337071980540577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 378}], {
             RGBColor[
             0.18751181267223727`, 0.3144171824270826, 0.9339898923815917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 177}], {
             RGBColor[
             0.8953206105495907, 0.9193683682944271, 0.9898776731680061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 178}], {
             RGBColor[
             0.668739474081812, 0.7383666179007873, 0.9696437049697588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 197}], {
             RGBColor[
             0.9300501065256308, 0.9463228877887528, 0.9676089006734437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 239}], {
             RGBColor[
             0.8617758088916869, 0.5670725642786435, 0.5820707130728167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 300}], {
             RGBColor[
             0.9052440838676142, 0.9272810765527117, 0.9908241829118685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 319}], {
             RGBColor[
             0.6745752376290368, 0.7434200744106859, 0.9700158830654886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 171}], {
             RGBColor[
             0.21031358554217228`, 0.3383832914292848, 0.9352884196143345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 187}], {
             RGBColor[
             0.33329236872326556`, 0.45597611149735384`, 0.9427190170162062]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 261}], {
             RGBColor[
             0.2458172275622507, 0.3756998702533064, 0.9373102995044464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 299}], {
             RGBColor[
             0.20966330069407968`, 0.3376998008234987, 0.9352513868542458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 306}], {
             RGBColor[
             0.21718838977102684`, 0.3456091465615747, 0.9356799295448063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 353}], {
             RGBColor[
             0.2108426436010009, 0.33893936499333205`, 0.9353185486881135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 361}], {
             RGBColor[
             0.22465020382752957`, 0.3534519862412956, 0.9361048688165594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 299}], {
             RGBColor[
             0.18831247292825637`, 0.31525872712095093`, 0.9340354887987012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 306}], {
             RGBColor[
             0.19583756200520352`, 0.3231680728590269, 0.9344640314892618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 342}], {
             RGBColor[
             0.18633859981298379`, 0.3131840613260155, 0.9339230796448701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 353}], {
             RGBColor[
             0.1894918158351776, 0.3164982912907842, 0.9341026506325689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 208}], {
             RGBColor[
             0.9084092508392714, 0.5876736275457447, 0.4679228968183917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 225}], {
             RGBColor[
             0.8542567503473041, 0.5474377891348923, 0.5796464760848401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 240}], {
             RGBColor[
             0.8277460748309535, 0.21427406632403376`, 0.17420297863381767`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 243}], {
             RGBColor[
             0.8966647112599999, 0.5803804357819402, 0.5534478412456459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 285}], {
             RGBColor[
             0.9090011322761398, 0.5869841292419617, 0.39020330546201376`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 337}], {
             RGBColor[
             0.9089250228286312, 0.5868213388295864, 0.3819192617937752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 357}], {
             RGBColor[
             0.8404518577056951, 0.3119362812088553, 0.18637005066379952`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 399}], {
             RGBColor[
             0.8751896442741957, 0.46528659439177383`, 0.21510344124823602`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 176}], {
             RGBColor[
             0.25807437232061936`, 0.38858290654221544`, 0.9380083257656147]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 209}], {
             RGBColor[
             0.3086611648699239, 0.43934003290171275`, 0.940977513192154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 250}], {
             RGBColor[
             0.27041365894161523`, 0.40155227913684066`, 0.9387110298843417]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 323}], {
             RGBColor[
             0.3405854460382354, 0.4669912406886779, 0.9430117001586653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 354}], {
             RGBColor[
             0.24916626557073213`, 0.3792199215414943, 0.9375010222645717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 388}], {
             RGBColor[
             0.2509970167086373, 0.38114415706375904`, 0.9376052808335218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 183}], {
             RGBColor[
             0.34699168167192995`, 0.474968487180372, 0.943330981016807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 189}], {
             RGBColor[
             0.3053198459534695, 0.4349817492014926, 0.9408182188837021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 238}], {
             RGBColor[
             0.3169893195658634, 0.44724710585547944`, 0.9414827781424888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 246}], {
             RGBColor[
             0.6321209059841302, 0.7058084285457353, 0.96769757273425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 269}], {
             RGBColor[
             0.543788980551822, 0.6359924818491485, 0.9591085205776222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 272}], {
             RGBColor[
             0.5424648698288314, 0.6349580764887339, 0.9589765455952728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 309}], {
             RGBColor[
             0.32079650085916334`, 0.45124869478397367`, 0.9416995914849222]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 325}], {
             RGBColor[
             0.31656779052141654`, 0.4468040521032807, 0.9414587726870038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 395}], {
             RGBColor[
             0.4063176896518592, 0.5259376945387678, 0.9472261235324917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 178}], {
             RGBColor[
             0.3616708025324146, 0.48517771913218966`, 0.9443580450417194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 213}], {
             RGBColor[
             0.25213492118930436`, 0.3823401668202513, 0.9376700828103168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 227}], {
             RGBColor[
             0.24456047357150879`, 0.37437894212623135`, 0.9372387292238745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 278}], {
             RGBColor[
             0.2699086210585896, 0.40102145230052944`, 0.93868226872404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 296}], {
             RGBColor[
             0.26330595896968834`, 0.39408163581213873`, 0.9383062568858402]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 314}], {
             RGBColor[
             0.25716282410855407`, 0.38762481157584006`, 0.9379564144434523]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 319}], {
             RGBColor[
             0.3675065660796395, 0.49023117564208835`, 0.944730223137449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 352}], {
             RGBColor[
             0.2606268889022622, 0.3912657633084208, 0.9381536878088295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 250}], {
             RGBColor[
             0.24600820440775967`, 0.3759005990265677, 0.9373211753532731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 344}], {
             RGBColor[
             0.21245918803275743`, 0.3406384556859449, 0.9354106085020388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 354}], {
             RGBColor[
             0.22476081103687653`, 0.35356824143122134`, 0.936111167733503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 356}], {
             RGBColor[
             0.21433034444536764`, 0.34260515971376704`, 0.9355171680916091]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 372}], {
             RGBColor[
             0.2138686325253813, 0.34211987121163484`, 0.9354908742808075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 388}], {
             RGBColor[
             0.22659156217478169`, 0.35549247695348607`, 0.9362154263024531]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 197}], {
             RGBColor[
             0.9295820155952076, 0.9459496447868232, 0.9675642537426303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 225}], {
             RGBColor[
             0.8897813970600477, 0.9149515498158103, 0.9893493380404593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 243}], {
             RGBColor[
             0.9321893579727436, 0.9478941964628581, 0.9631507032012652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 252}], {
             RGBColor[
             0.6322093663988135, 0.7067582685174405, 0.9673012182198607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 300}], {
             RGBColor[
             0.904775992937191, 0.9269078335507821, 0.990779535981055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 337}], {
             RGBColor[
             0.9444496695413749, 0.9543350995105044, 0.7916221237493946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 367}], {
             RGBColor[
             0.6349673392184779, 0.7091470859540894, 0.9674769538091501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 398}], {
             RGBColor[
             0.6604733814795012, 0.7312391377896288, 0.9691021762679148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 197}], {
             RGBColor[
             0.7030008791274289, 0.7649478943931832, 0.947330285544383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 274}], {
             RGBColor[
             0.46738436670940764`, 0.5781669894131862, 0.9513005905019778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 278}], {
             RGBColor[
             0.349928065209785, 0.47283535767355744`, 0.9436893135230188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 300}], {
             RGBColor[
             0.6781948564694122, 0.7459060831571422, 0.9705455677828076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 319}], {
             RGBColor[
             0.4475260102308348, 0.5620450810151163, 0.9497372679364278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 352}], {
             RGBColor[
             0.3406463330534576, 0.4630796686814488, 0.9431607326078082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 232}], {
             RGBColor[
             0.374520452238133, 0.49753308772821003`, 0.9451360369712756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 257}], {
             RGBColor[
             0.38852623515624984`, 0.5109265218154098, 0.9459822530302189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 275}], {
             RGBColor[
             0.34634920232824207`, 0.46792331791250663`, 0.9435317259645368]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 279}], {
             RGBColor[
             0.5630911384213583, 0.6557241290001397, 0.9590606413690353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 285}], {
             RGBColor[
             0.7240735565365042, 0.7787875887954807, 0.7800674551938157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 288}], {
             RGBColor[
             0.3796596294696894, 0.502934688841232, 0.9454287055118813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 399}], {
             RGBColor[
             0.6902620685345601, 0.6570900539452929, 0.6049675909800379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 198}], {
             RGBColor[
             0.30592577418738304`, 0.43475768207038135`, 0.9408842486890967]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 236}], {
             RGBColor[
             0.2546593406268537, 0.3849934917065525, 0.9378138447627414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 262}], {
             RGBColor[
             0.23634740435871976`, 0.36574648564492557`, 0.9367710070823533]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 267}], {
             RGBColor[
             0.25726504669656514`, 0.3877322539971262, 0.9379622358686148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 284}], {
             RGBColor[
             0.2675710150211928, 0.3985644801424423, 0.9385491455183885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 286}], {
             RGBColor[
             0.22669434503393948`, 0.3556005082552706, 0.9362212796342286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 332}], {
             RGBColor[
             0.2434440031568898, 0.373205460932154, 0.937175147885432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 367}], {
             RGBColor[
             0.31681274319178854`, 0.44418742742702483`, 0.9415779567270888]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 398}], {
             RGBColor[
             0.3423187854528118, 0.46627947926256413`, 0.9432031791858535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 191}], {
             RGBColor[
             0.2010737277844803, 0.3286716150851321, 0.9347622233841785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 211}], {
             RGBColor[
             0.20840661341018846`, 0.33637894280955327`, 0.9351798203725303]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 214}], {
             RGBColor[
             0.21733436721625865`, 0.34576257811201794`, 0.9356882427443579]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 305}], {
             RGBColor[
             0.18857843384879308`, 0.3155382689113313, 0.9340506348796719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 334}], {
             RGBColor[
             0.18995231521735206`, 0.3169823053387968, 0.934128875391136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 340}], {
             RGBColor[
             0.19892920598511726`, 0.3264175867034662, 0.9346400960402405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 365}], {
             RGBColor[
             0.1879270858801807, 0.3148536608984732, 0.9340135415764423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 370}], {
             RGBColor[
             0.19100569805155482`, 0.318089477485873, 0.9341888639852036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 256}], {
             RGBColor[
             0.34992025301800456`, 0.4775050684860661, 0.9435175869933449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 281}], {
             RGBColor[
             0.38860982761707186`, 0.5110160334092172, 0.94598285247495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 311}], {
             RGBColor[
             0.32563786800336725`, 0.45591796242171545`, 0.9419906534014555]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 386}], {
             RGBColor[
             0.5546461678159978, 0.6446668165900299, 0.9601091386691207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 238}], {
             RGBColor[
             0.31998454354214334`, 0.4498414183193987, 0.9416736311656848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 246}], {
             RGBColor[
             0.63511612996041, 0.7084027410096546, 0.967888425757446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 269}], {
             RGBColor[
             0.546784204528102, 0.6385867943130678, 0.9592993736008182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 272}], {
             RGBColor[
             0.5454600938051113, 0.6375523889526532, 0.9591673986184688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 280}], {
             RGBColor[
             0.30076148412422865`, 0.4296367640588081, 0.9405789063698025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 309}], {
             RGBColor[
             0.3237917248354433, 0.45384300724789295`, 0.9418904445081182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 325}], {
             RGBColor[
             0.3195630144976964, 0.44939836456720006`, 0.9416496257101998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 339}], {
             RGBColor[
             0.30076734139659483`, 0.42964292042343744`, 0.9405792399327987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 395}], {
             RGBColor[
             0.40931291362813915`, 0.5285320070026871, 0.9474169765556877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 343}], {
             RGBColor[
             0.18256566753029357`, 0.30921847027918486`, 0.933708216732924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 356}], {
             RGBColor[
             0.18905111217950674`, 0.3160350838064485, 0.9340775532113412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 369}], {
             RGBColor[
             0.1868540625349533, 0.3137258453290297, 0.9339524344843275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 372}], {
             RGBColor[
             0.18858940025952037`, 0.31554979530431626`, 0.9340512594005395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 198}], {
             RGBColor[
             0.3764542800383526, 0.5004875090521163, 0.9452083117319626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 205}], {
             RGBColor[
             0.3748090292582385, 0.49906247551909, 0.9451034778070919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 208}], {
             RGBColor[
             0.6963078073762952, 0.755957556681333, 0.8560508247348155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 210}], {
             RGBColor[
             0.35262704416750634`, 0.4795636552057607, 0.9437005295213796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 219}], {
             RGBColor[
             0.36836286362019555`, 0.4934791308371227, 0.9446927338327562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 249}], {
             RGBColor[
             0.35433837255967027`, 0.48133182157191207`, 0.9437991056637501]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 284}], {
             RGBColor[
             0.33809952087216233`, 0.4642943071241772, 0.9428732085612545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 293}], {
             RGBColor[
             0.374247320413842, 0.49857595155038115`, 0.9450676862162266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 338}], {
             RGBColor[
             0.3169003211264983, 0.4420126040845884, 0.9416659454971446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 188}], {
             RGBColor[
             0.20431810644449144`, 0.33208166276229184`, 0.934946985949238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 228}], {
             RGBColor[
             0.20522346006975262`, 0.3330332468251766, 0.934998544498846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 238}], {
             RGBColor[
             0.24841689496046435`, 0.37843228551726205`, 0.9374583467169113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 273}], {
             RGBColor[
             0.19433831903215518`, 0.3215922734368583, 0.9343786518198778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 322}], {
             RGBColor[
             0.20337835674212623`, 0.3310939262415335, 0.9348934685939234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 330}], {
             RGBColor[
             0.19639093276449526`, 0.3237497006127751, 0.9344955451353647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 206}], {
             RGBColor[
             0.5826167692195937, 0.6701866792756657, 0.9613440852325792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 220}], {
             RGBColor[
             0.5353714211663698, 0.63317812373389, 0.9567035702854296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 261}], {
             RGBColor[
             0.3474451829775207, 0.4708516166188276, 0.9435249988507737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 321}], {
             RGBColor[
             0.494640933100008, 0.6001112786340405, 0.9534971170641517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 228}], {
             RGBColor[
             0.20268995802939208`, 0.3303703755474506, 0.9348542653056278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 238}], {
             RGBColor[
             0.2458833929201038, 0.375769414239536, 0.9373140675236933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 273}], {
             RGBColor[
             0.19180481699179464`, 0.3189294021591323, 0.9342343726266598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 322}], {
             RGBColor[
             0.20084485470176572`, 0.3284310549638075, 0.9347491894007052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 330}], {
             RGBColor[
             0.19385743072413472`, 0.32108682933504906`, 0.9343512659421467]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 222}], {
             RGBColor[
             0.24951462814212214`, 0.379586072691488, 0.937520860997656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 226}], {
             RGBColor[
             0.35594179006458193`, 0.47882793285764735`, 0.9440438043992346]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 395}], {
             RGBColor[
             0.3676410779096787, 0.4885452690238077, 0.9449042144225828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 212}], {
             RGBColor[
             0.6867778683351773, 0.7513832913392242, 0.9534033725466657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 221}], {
             RGBColor[
             0.9292638455200164, 0.8080779972178733, 0.5995947563336426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 255}], {
             RGBColor[
             0.8957903553105804, 0.6198388885195696, 0.570244438982581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 268}], {
             RGBColor[
             0.8177911045280821, 0.8581558703042615, 0.9638348308947651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 270}], {
             RGBColor[
             0.6576592800193992, 0.7261622336829004, 0.951547961847741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 274}], {
             RGBColor[
             0.7246489008143902, 0.7831056857849257, 0.9561147753018562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 295}], {
             RGBColor[
             0.6926270864337125, 0.7564495900659256, 0.953776079551644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 324}], {
             RGBColor[
             0.7946744730052755, 0.8399555999055638, 0.9616274448568455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 351}], {
             RGBColor[
             0.9330043693197932, 0.948887212220239, 0.9751255904637988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 211}], {
             RGBColor[
             0.2145566630341047, 0.342843034899957, 0.9355300566004294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 214}], {
             RGBColor[
             0.2234844168401749, 0.3522266702024217, 0.9360384789722569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 312}], {
             RGBColor[
             0.25506639270437426`, 0.3854213292486189, 0.9378370257763766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 334}], {
             RGBColor[
             0.1961023648412683, 0.3234463974292005, 0.934479111619035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 340}], {
             RGBColor[
             0.2050792556090335, 0.33288167879387, 0.9349903322681394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 365}], {
             RGBColor[
             0.19407713550409694`, 0.321317752988877, 0.9343637778043414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 370}], {
             RGBColor[
             0.19715574767547106`, 0.3245535695762768, 0.9345391002131025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 292}], {
             RGBColor[
             0.18800332047098128`, 0.31493378828695684`, 0.9340178830236096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 320}], {
             RGBColor[
             0.18870690253434044`, 0.31567329764522667`, 0.9340579509812614]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 347}], {
             RGBColor[
             0.18973620095672017`, 0.3167551555484371, 0.9341165680037053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 374}], {
             RGBColor[
             0.18592011737534742`, 0.3127442097507407, 0.933899247689136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 382}], {
             RGBColor[
             0.18175632170203998`, 0.30836779649820095`, 0.9336621256853248]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 384}], {
             RGBColor[
             0.1855895073220066, 0.3123967176227914, 0.933880419935692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 248}], {
             RGBColor[
             0.20247189401375032`, 0.330141176440954, 0.9348418468825339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 305}], {
             RGBColor[
             0.18458905889423072`, 0.311345182893105, 0.933823445877761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 334}], {
             RGBColor[
             0.1859629402627897, 0.3127892193205704, 0.9339016863892251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 360}], {
             RGBColor[
             0.18609708652812662`, 0.31293021555080397`, 0.9339093258205844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 201}], {
             RGBColor[
             0.9717877162352071, 0.9761148093624215, 0.8086618740541351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 208}], {
             RGBColor[
             0.9937734715667986, 0.9910458830658546, 0.7058012226950569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 223}], {
             RGBColor[
             0.9622169086067585, 0.8752522636294204, 0.4543198910461633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 230}], {
             RGBColor[
             0.906134992146644, 0.5640310832233217, 0.4054017460858296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 242}], {
             RGBColor[
             0.9234025469352043, 0.6967570760189528, 0.42193717605226866`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 357}], {
             RGBColor[
             0.9258160784332223, 0.7153085367289651, 0.42424837654046466`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 364}], {
             RGBColor[
             0.9061043939482173, 0.5637958920619978, 0.4053724452164604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 385}], {
             RGBColor[
             0.9944784929138155, 0.9905983795896796, 0.6403962123397537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 387}], {
             RGBColor[
             0.7643288542489235, 0.8116893614464729, 0.8013257295322668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 247}], {
             RGBColor[
             0.1997381438211963, 0.32726783165880646`, 0.9346861638532888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 253}], {
             RGBColor[
             0.1964706167173933, 0.3238334534995253, 0.9345000830186004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 315}], {
             RGBColor[
             0.21034714004508412`, 0.3384185593393235, 0.9352903304936357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 316}], {
             RGBColor[
             0.21810104707830674`, 0.3465684072573414, 0.9357319040283003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 343}], {
             RGBColor[
             0.19193458883998876`, 0.3190658005995948, 0.9342417629414341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 358}], {
             RGBColor[
             0.1963120650172806, 0.3236668056099485, 0.9344910537338352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 359}], {
             RGBColor[
             0.19452611281546262`, 0.321789656609928, 0.9343893463980213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 362}], {
             RGBColor[
             0.1955066853579723, 0.3228203005239958, 0.9344451885536901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 363}], {
             RGBColor[
             0.21087458530257291`, 0.33897293774690507`, 0.9353203677207644]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 369}], {
             RGBColor[
             0.19622298384464848`, 0.3235731756494396, 0.9344859806928376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 372}], {
             RGBColor[
             0.19795832156921558`, 0.32539712562472617`, 0.9345848056090496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 397}], {
             RGBColor[
             0.2073858256728759, 0.33530603017595706`, 0.9351216880210106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 289}], {
             RGBColor[
             0.18795157808443957`, 0.3148794037580448, 0.934014936371242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 317}], {
             RGBColor[
             0.1925447584771704, 0.3197071275752621, 0.9342765111996065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 326}], {
             RGBColor[
             0.19087356510240117`, 0.3179505973785997, 0.9341813392092224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 327}], {
             RGBColor[
             0.19267128104236286`, 0.3198401108132733, 0.9342837164725208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 336}], {
             RGBColor[
             0.18504438325654066`, 0.31182375766712467`, 0.9338493759266024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 376}], {
             RGBColor[
             0.19966869054902864`, 0.32719483186616644`, 0.9346822085921858]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 252}], {
             RGBColor[
             0.6669388623748537, 0.7337127880117662, 0.9450324457252983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 300}], {
             RGBColor[
             0.9395054889132312, 0.9538623530451078, 0.9685107634864926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 205}], {
             RGBColor[
             0.35166297002886326`, 0.47901452236936815`, 0.9436286313802527]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 219}], {
             RGBColor[
             0.34521680439082036`, 0.47343117768740084`, 0.9432178874059169]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 236}], {
             RGBColor[
             0.3020417872484481, 0.43067536553856556`, 0.9406630613787681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 284}], {
             RGBColor[
             0.31495346164278715`, 0.44424635397445533`, 0.9413983621344152]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 332}], {
             RGBColor[
             0.29082644977848415`, 0.41888733476416706`, 0.9400243645014585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 367}], {
             RGBColor[
             0.36419518981338295`, 0.4898693012590379, 0.9444271733431154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 398}], {
             RGBColor[
             0.38970123207440616`, 0.5119613530945772, 0.9460523958018803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 216}], {
             RGBColor[
             0.19310022590756143`, 0.3202909590632723, 0.9343081442480269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 298}], {
             RGBColor[
             0.19174373818706897`, 0.31886520446274574`, 0.9342308942790887]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 299}], {
             RGBColor[
             0.18707599573729403`, 0.31395911119606756`, 0.93396507325188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 306}], {
             RGBColor[
             0.19460108481424115`, 0.32186845693414357`, 0.9343936159424405]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 342}], {
             RGBColor[
             0.18510212262202141`, 0.31188444540113214`, 0.9338526640980489]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 353}], {
             RGBColor[
             0.18825533864421526`, 0.31519867536590085`, 0.9340322350857477]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 361}], {
             RGBColor[
             0.2020628988707439, 0.32971129661386445`, 0.9348185552141937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 393}], {
             RGBColor[
             0.1849265278957996, 0.3116998842105244, 0.9338426642381596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 207}], {
             RGBColor[
             0.1859857863076916, 0.31281323196228517`, 0.9339029874376845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 333}], {
             RGBColor[
             0.18616349406283006`, 0.3130000140802582, 0.9339131076314446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 368}], {
             RGBColor[
             0.18469320535133593`, 0.3114546474227893, 0.9338293768644222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 223}], {
             RGBColor[
             0.9394729571932308, 0.8606549580209606, 0.6167978110210142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 230}], {
             RGBColor[
             0.8833910407331164, 0.5494337776148619, 0.5678796660606804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 245}], {
             RGBColor[
             0.8839369101698967, 0.553629569307468, 0.5684023912498125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 364}], {
             RGBColor[
             0.8833604425346897, 0.5491985864535379, 0.5678503651913112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 385}], {
             RGBColor[
             0.9717345415002878, 0.9760010739812197, 0.8028741323146045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 218}], {
             RGBColor[
             0.2171099632633392, 0.3455267153294672, 0.9356754632712151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 229}], {
             RGBColor[
             0.22512118954774685`, 0.35394702209546336`, 0.9361316907565649]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 260}], {
             RGBColor[
             0.23397057730885262`, 0.3632482897159762, 0.9366356502980638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 307}], {
             RGBColor[
             0.295856931076972, 0.42463269426460054`, 0.9402940731736436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 341}], {
             RGBColor[
             0.2897972028384973, 0.4193840622352309, 0.9399079526486953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 349}], {
             RGBColor[
             0.22267250403179975`, 0.35137329836257414`, 0.9359922417389372]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 366}], {
             RGBColor[
             0.31887937893336776`, 0.4445735814559359, 0.9417610431931018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 232}], {
             RGBColor[
             0.26042493590475796`, 0.3910534979034842, 0.9381421868843842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 257}], {
             RGBColor[
             0.27443071882287484`, 0.40444693199068393`, 0.9389884029433275]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 275}], {
             RGBColor[
             0.232253685994867, 0.3614437280877808, 0.9365378758776455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 280}], {
             RGBColor[
             0.23864655232395315`, 0.36816303593078636`, 0.9369019401576887]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 297}], {
             RGBColor[
             0.2163387830881471, 0.3447161560696932, 0.9356315457010966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 309}], {
             RGBColor[
             0.2616767930351678, 0.3923692791198713, 0.9382134782960043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 322}], {
             RGBColor[
             0.2128310735235297, 0.3410293309156486, 0.935431786830583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 325}], {
             RGBColor[
             0.2574480826974209, 0.38792463643917835`, 0.9379726594980861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 339}], {
             RGBColor[
             0.23865240959631934`, 0.3681691922954158, 0.9369022737206849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 224}], {
             RGBColor[
             0.1864844568543232, 0.3133373663243338, 0.9339313859875982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 276}], {
             RGBColor[
             0.2082458481435212, 0.33620996832117933`, 0.9351706650284246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 290}], {
             RGBColor[
             0.19592590704111568`, 0.32326092909316934`, 0.9344690626083623]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 297}], {
             RGBColor[
             0.2002775476373886, 0.32783477926980176`, 0.9347168821026446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 318}], {
             RGBColor[
             0.1940125074344074, 0.321249824789977, 0.9343600973313813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 345}], {
             RGBColor[
             0.18631088399028722`, 0.3131549302390768, 0.9339215012697695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 219}], {
             RGBColor[
             0.34357155361070624`, 0.4720061441543746, 0.9431130534810463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 284}], {
             RGBColor[
             0.313308210862673, 0.4428213204414291, 0.9412935282095445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 293}], {
             RGBColor[
             0.3494560104043527, 0.47710296486763304`, 0.9434880058645166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 338}], {
             RGBColor[
             0.292109011117009, 0.4205396174018403, 0.9400862651454345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 220}], {
             RGBColor[
             0.6830678662474279, 0.7522369451466808, 0.9691139391554754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 321}], {
             RGBColor[
             0.6423373781810662, 0.7191701000468311, 0.9659074859341975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 328}], {
             RGBColor[
             0.7999219852902167, 0.6448484807342735, 0.5933000289298582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 386}], {
             RGBColor[
             0.7455369138645886, 0.8011383704922057, 0.975271810201597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 254}], {
             RGBColor[
             0.18750231875154622`, 0.3144072037144869, 0.9339893517168534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 333}], {
             RGBColor[
             0.18793493502051017`, 0.3148619108426237, 0.9340139885733725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 230}], {
             RGBColor[
             0.9053767960647079, 0.5643648513182951, 0.465019014701602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 240}], {
             RGBColor[
             0.9123520994765446, 0.6179800899391169, 0.47169857312625524`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 242}], {
             RGBColor[
             0.9226443508532682, 0.6970908441139261, 0.4815544446680411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 357}], {
             RGBColor[
             0.9250578823512863, 0.7156423048239384, 0.4838656451562371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 385}], {
             RGBColor[
             0.9937202968318795, 0.9909321476846529, 0.7000134809555262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 387}], {
             RGBColor[
             0.7635706581669874, 0.8120231295414462, 0.8609429981480392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 241}], {
             RGBColor[
             0.2990278699570904, 0.4292148291621499, 0.9404289112980508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 270}], {
             RGBColor[
             0.34697087401529814`, 0.4749504646340207, 0.9433296551713259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 310}], {
             RGBColor[
             0.30722079620017617`, 0.4378261141051596, 0.9408954863272463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 323}], {
             RGBColor[
             0.36676678405368435`, 0.4920966869379023, 0.9445910330541359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 346}], {
             RGBColor[
             0.34295446203942725`, 0.47147165045125694`, 0.9430737329517971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 390}], {
             RGBColor[
             0.2987767120225358, 0.42895084624860025`, 0.9404146082252327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 249}], {
             RGBColor[
             0.3073650774594488, 0.4403600145758346, 0.9408164770263279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 266}], {
             RGBColor[
             0.26920304414348, 0.40027984622658896`, 0.9386420871625321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 293}], {
             RGBColor[
             0.3272740253136205, 0.45760414455430376`, 0.9420850575788042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 315}], {
             RGBColor[
             0.26224986664151034`, 0.39297161581510254`, 0.9382461139900993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 316}], {
             RGBColor[
             0.270003773674733, 0.40112146373312046`, 0.9386876875247638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 387}], {
             RGBColor[
             0.4198898949581986, 0.5356292280658739, 0.9485927029346032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 397}], {
             RGBColor[
             0.25928855226930214`, 0.38985908665173613`, 0.938077471517474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 214}], {
             RGBColor[
             0.23081730246588306`, 0.35993399792684283`, 0.9364560759606089]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 248}], {
             RGBColor[
             0.2199442042179371, 0.34850568227400514`, 0.9358368691006957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 263}], {
             RGBColor[
             0.30692109574993276`, 0.4322308872824815, 0.9410717536469021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 312}], {
             RGBColor[
             0.26239927833008236`, 0.39312865697304, 0.9382546227647286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 334}], {
             RGBColor[
             0.20343525046697647`, 0.3311537251536216, 0.9348967086073869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 340}], {
             RGBColor[
             0.21241214123474167`, 0.34058900651829105`, 0.9354079292564914]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 370}], {
             RGBColor[
             0.20448863330117922`, 0.3322608973006979, 0.9349566972014545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 268}], {
             RGBColor[
             0.5483496579696843, 0.6426701443947892, 0.9582447440009759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 270}], {
             RGBColor[
             0.38821783346100136`, 0.5106765077734281, 0.9459578749539519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 274}], {
             RGBColor[
             0.45520745425599235`, 0.5676199598754534, 0.950524688408067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 295}], {
             RGBColor[
             0.42318563987531466`, 0.5409638641564534, 0.9481859926578549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 310}], {
             RGBColor[
             0.34846775564587945`, 0.473552157244567, 0.9435237061098725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 324}], {
             RGBColor[
             0.5252330264468776, 0.6244698739960914, 0.9560373579630563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 351}], {
             RGBColor[
             0.6635629227613954, 0.7334014863107667, 0.9695355035700097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 373}], {
             RGBColor[
             0.34459378761093823`, 0.4694803712160838, 0.9433030893613046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 390}], {
             RGBColor[
             0.3400236714682391, 0.46467688938800766`, 0.9430428280078589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 227}], {
             RGBColor[
             0.2150440363795939, 0.343355295187321, 0.9355578117914507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 296}], {
             RGBColor[
             0.2337895217777734, 0.3630579888732283, 0.9366253394534165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 308}], {
             RGBColor[
             0.2120594900785835, 0.3402183477937941, 0.9353878462948488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 352}], {
             RGBColor[
             0.23111045171034733`, 0.3602421163695104, 0.9364727703764056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 248}], {
             RGBColor[
             0.22887195802400728`, 0.3578893175764699, 0.9363452914725232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 263}], {
             RGBColor[
             0.315848849556003, 0.4416145225849462, 0.9415801760187297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 312}], {
             RGBColor[
             0.2713270321361526, 0.4025122922755047, 0.9387630451365561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 340}], {
             RGBColor[
             0.22133989504081186`, 0.3499726418207558, 0.9359163516283189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 218}], {
             RGBColor[
             0.18692850160935742`, 0.31380408551593836`, 0.9339566736794921]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 229}], {
             RGBColor[
             0.19493972789376507`, 0.3222243922819345, 0.9344129011648419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 329}], {
             RGBColor[
             0.1867198905000643, 0.313584822013363, 0.9339447935854304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 349}], {
             RGBColor[
             0.192491042377818, 0.3196506685490453, 0.9342734521472142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 231}], {
             RGBColor[
             0.19095180161373265`, 0.3180328289124904, 0.9341857946628023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 235}], {
             RGBColor[
             0.1956123156574894, 0.32293132466613605`, 0.9344512040429815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 298}], {
             RGBColor[
             0.19835416070020614`, 0.3258131776490477, 0.9346073480619681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 313}], {
             RGBColor[
             0.2090389311379428, 0.3370435488326826, 0.9352158299316957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 361}], {
             RGBColor[
             0.20867332138388106`, 0.3366592698001664, 0.9351950089970731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 393}], {
             RGBColor[
             0.19153695040893678`, 0.31864785739682644`, 0.9342191180210391]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 396}], {
             RGBColor[
             0.19963425463605258`, 0.3271586375382656, 0.9346802475178853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 220}], {
             RGBColor[
             0.8144460532518553, 0.851406632354037, 0.7257595325601884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 230}], {
             RGBColor[
             0.9054039524770299, 0.5624674632894656, 0.3258325895022128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 233}], {
             RGBColor[
             0.9762379710154455, 0.9784153903456743, 0.7203221374649382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 242}], {
             RGBColor[
             0.9226715072655902, 0.6951934560850966, 0.34236801946865186`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 244}], {
             RGBColor[
             0.9739175055905028, 0.9766847910311653, 0.7242500801550553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 264}], {
             RGBColor[
             0.8581806271651595, 0.8856725444548357, 0.7300501263511203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 321}], {
             RGBColor[
             0.7737155651854934, 0.8183397872541874, 0.7225530793389106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 357}], {
             RGBColor[
             0.9250850387636083, 0.713744916795109, 0.34467921995684786`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 364}], {
             RGBColor[
             0.9053733542786032, 0.5622322721281416, 0.3258032886328436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 366}], {
             RGBColor[
             0.6937344954214235, 0.7518077736561808, 0.7166986999905727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 229}], {
             RGBColor[
             0.19887179747769093`, 0.3263572467222515, 0.9346368267106708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 260}], {
             RGBColor[
             0.20772118523879674`, 0.3356585143427644, 0.9351407862521698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 329}], {
             RGBColor[
             0.19065196008399016`, 0.31771767645368004`, 0.9341687191312593]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 349}], {
             RGBColor[
             0.19642311196174383`, 0.3237835229893623, 0.9344973776930432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 284}], {
             RGBColor[
             0.3068620452246301, 0.43723797575946177`, 0.9408827842352088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 293}], {
             RGBColor[
             0.34300984476630975`, 0.47151962018566573`, 0.943077261890181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 338}], {
             RGBColor[
             0.28566284547896603`, 0.414956272719873, 0.9396755211710989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 233}], {
             RGBColor[
             0.7976144359577942, 0.8422371475965424, 0.9590360291130758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 244}], {
             RGBColor[
             0.7952939705328516, 0.8405065482820335, 0.9629639718031929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 321}], {
             RGBColor[
             0.5950920301278422, 0.6821615445050555, 0.961266970987048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 341}], {
             RGBColor[
             0.4860287842689018, 0.590440011686344, 0.9535595010943037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 366}], {
             RGBColor[
             0.5151109603637722, 0.615629530907049, 0.9554125916387102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 239}], {
             RGBColor[
             0.8650356462249088, 0.43184524722399015`, 0.20720757963682196`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 255}], {
             RGBColor[
             0.8688348859370216, 0.46104786848874635`, 0.21084573587576866`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 268}], {
             RGBColor[
             0.7908356351545234, 0.6993648502734382, 0.6044361277879526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 324}], {
             RGBColor[
             0.7677190036317167, 0.6811645798747406, 0.602228741750033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 351}], {
             RGBColor[
             0.9060488999462345, 0.7900961921894157, 0.6157268873569864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 400}], {
             RGBColor[
             0.8762434284382803, 0.5179931725974458, 0.21794016454172604`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 333}], {
             RGBColor[
             0.21024933242430197`, 0.33831575732852015`, 0.9352847604943257]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 230}], {
             RGBColor[
             0.8738202331046678, 0.44857123188186093`, 0.21353768305270848`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 242}], {
             RGBColor[
             0.8910877878932282, 0.5812972246774919, 0.23007311301914762`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 245}], {
             RGBColor[
             0.8743661025414482, 0.452767023574467, 0.2140604082418407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 328}], {
             RGBColor[
             0.8997164529222819, 0.6301219365340252, 0.23765071588506692`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 364}], {
             RGBColor[
             0.8737896349062411, 0.4483360407205369, 0.2135083821833393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 385}], {
             RGBColor[
             0.9621637338718393, 0.8751385282482187, 0.44853214930663265`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 290}], {
             RGBColor[
             0.18877579274929696`, 0.3157457056290379, 0.9340618741770893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 318}], {
             RGBColor[
             0.18686239314258873`, 0.3137346013258456, 0.9339529089001083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 345}], {
             RGBColor[
             0.17916076969846856`, 0.3056397067749454, 0.9335143128384965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 240}], {
             RGBColor[
             0.8581995989845774, 0.5777442515282645, 0.5834221523927036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 243}], {
             RGBColor[
             0.9271182354136238, 0.9438506209861709, 0.9626670150045318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 337}], {
             RGBColor[
             0.9393785469822551, 0.9502915240338172, 0.7911384355526612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 367}], {
             RGBColor[
             0.6298962166593582, 0.7051035104774022, 0.9669932656124167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 398}], {
             RGBColor[
             0.6554022589203814, 0.7271955623129416, 0.9686184880711814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 234}], {
             RGBColor[
             0.6154815427973135, 0.6962991925345092, 0.964434228392668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 281}], {
             RGBColor[
             0.43696413947427415`, 0.552898107981546, 0.9490639464684518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 350}], {
             RGBColor[
             0.7195454075725961, 0.7758957836327975, 0.8505842343054555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 355}], {
             RGBColor[
             0.6054737407452027, 0.6884810215092875, 0.963436744212341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 392}], {
             RGBColor[
             0.7181621296927883, 0.7753237626808771, 0.8735087285822702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 395}], {
             RGBColor[
             0.45693963376297164`, 0.5697838781949226, 0.9504517090480242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 296}], {
             RGBColor[
             0.22621507415997788`, 0.35509676417920844`, 0.9361939858669741]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 308}], {
             RGBColor[
             0.20448504246078797`, 0.33225712309977423`, 0.9349564927084064]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 352}], {
             RGBColor[
             0.22353600409255178`, 0.3522808916754905, 0.9360414167899633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 375}], {
             RGBColor[
             0.1940331226429612, 0.32127149268124666`, 0.9343612713370109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 238}], {
             RGBColor[
             0.24678874654536498`, 0.3767209983024208, 0.9373656260733012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 273}], {
             RGBColor[
             0.1927101706170558, 0.31988098622201705`, 0.9342859311762677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 330}], {
             RGBColor[
             0.1947627843493959, 0.3220384133979338, 0.9344028244917546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 368}], {
             RGBColor[
             0.19438368850365684`, 0.3216399596279972, 0.9343812355441619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 260}], {
             RGBColor[
             0.21573241152320438`, 0.34407882110876054`, 0.9355970137375196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[
             0.1986631863683978, 0.3261379832196762, 0.934624946616609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 349}], {
             RGBColor[
             0.20443433824615148`, 0.33220382975535845`, 0.934953605178393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 233}], {
             RGBColor[
             0.8885723351829689, 0.5532979785319709, 0.5591090860551002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 242}], {
             RGBColor[
             0.8350058714331137, 0.2700760442713933, 0.18115496805881381`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 244}], {
             RGBColor[
             0.8862518697580262, 0.551567379217462, 0.5630370287452173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 245}], {
             RGBColor[
             0.8182841860813337, 0.14154584316836838`, 0.16514226328150688`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 328}], {
             RGBColor[
             0.8436345364621675, 0.31890075612792645`, 0.1887325709247331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 357}], {
             RGBColor[
             0.8374194029311317, 0.28862750498140566`, 0.18346616854700978`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 364}], {
             RGBColor[
             0.8177077184461266, 0.13711486031443826`, 0.16459023722300553`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 385}], {
             RGBColor[
             0.9060818174117249, 0.56391734784212, 0.3996140043462989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 235}], {
             RGBColor[
             0.18685346885052345`, 0.3137252213290522, 0.9339524006748775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 298}], {
             RGBColor[
             0.1895953138932402, 0.3166070743119639, 0.934108544693864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 336}], {
             RGBColor[
             0.1812731232878139, 0.3078599243283004, 0.9336346082504626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 393}], {
             RGBColor[
             0.18277810360197083`, 0.30944175405974256`, 0.933720314652935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 396}], {
             RGBColor[
             0.19087540782908663`, 0.31795253420118175`, 0.9341814441497811]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 257}], {
             RGBColor[
             0.30909861267997385`, 0.4408850865059202, 0.9409626882119364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 275}], {
             RGBColor[
             0.2669215798519661, 0.39788188260301705`, 0.9385121611462544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 279}], {
             RGBColor[
             0.48366351594508233`, 0.5856826936906501, 0.9540410765507529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 280}], {
             RGBColor[
             0.2733144461810522, 0.4046011904460226, 0.9388762254262976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 288}], {
             RGBColor[
             0.30023200699341346`, 0.43289325353174246`, 0.9404091406935988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 297}], {
             RGBColor[
             0.25100667694524614`, 0.38115431058492943`, 0.9376058309697055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 309}], {
             RGBColor[
             0.2963446868922668, 0.42880743363510754`, 0.9401877635646132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 325}], {
             RGBColor[
             0.29211597655452004`, 0.4243627909544146, 0.9399469447666949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 339}], {
             RGBColor[
             0.2733203034534184, 0.404607346810652, 0.9388765589892938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 242}], {
             RGBColor[
             0.9058398899715292, 0.686023971327602, 0.5756445160215393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 244}], {
             RGBColor[
             0.9570858882964418, 0.9675153062736708, 0.9575265767079428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 264}], {
             RGBColor[
             0.8413490098710985, 0.8765030596973409, 0.9633266229040078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 307}], {
             RGBColor[
             0.6538804302709667, 0.7226974017073509, 0.9485082265240019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 348}], {
             RGBColor[
             0.6462730001834412, 0.7161082281260901, 0.948023487805811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 357}], {
             RGBColor[
             0.9082534214695472, 0.7045754320376143, 0.5779557165097353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 366}], {
             RGBColor[
             0.6769028781273625, 0.7426382888986862, 0.9499751965434602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[
             0.8067428279900561, 0.5234676801505931, 0.5767481319037369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 246}], {
             RGBColor[
             0.8529840469746812, 0.885887262707637, 0.9857660876177745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 269}], {
             RGBColor[
             0.7646521215423732, 0.8160713160110501, 0.9771770354611466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 272}], {
             RGBColor[
             0.7633280108193825, 0.8150369106506357, 0.9770450604787972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 350}], {
             RGBColor[
             0.8897866044520348, 0.9121284341385445, 0.8654271636734474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 355}], {
             RGBColor[
             0.7757149376246414, 0.8247136720150343, 0.978279673580333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 392}], {
             RGBColor[
             0.888403326572227, 0.9115564131866241, 0.8883516579502622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 395}], {
             RGBColor[
             0.6271808306424103, 0.7060165287006694, 0.9652946384160161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 298}], {
             RGBColor[
             0.19425582793699694`, 0.3215055700656095, 0.9343739540740432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 313}], {
             RGBColor[
             0.2049405983747336, 0.3327359412492443, 0.9349824359437711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 317}], {
             RGBColor[
             0.19343401255220036`, 0.32064178999008336`, 0.934327152903646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 336}], {
             RGBColor[
             0.18593363733157064`, 0.312758420081946, 0.9339000176306419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 393}], {
             RGBColor[
             0.18743861764572758`, 0.31434024981338815`, 0.9339857240331143]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 396}], {
             RGBColor[
             0.19553592187284338`, 0.32285102995482734`, 0.9344468535299604]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 267}], {
             RGBColor[
             0.25338105975763014`, 0.38364993746531034`, 0.9377410485582862]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 284}], {
             RGBColor[
             0.26368702808225786`, 0.3944821636106265, 0.9383279582080599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 286}], {
             RGBColor[
             0.22281035809500455`, 0.3515181917234548, 0.9360000923239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 332}], {
             RGBColor[
             0.2395600162179548, 0.36912314440033817`, 0.9369539605751034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 367}], {
             RGBColor[
             0.3129287562528536, 0.440105110895209, 0.9413567694167602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 383}], {
             RGBColor[
             0.22956462143722656`, 0.3586173507411603, 0.9363847376292023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 398}], {
             RGBColor[
             0.3384347985138768, 0.4621971627307483, 0.9429819918755249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 251}], {
             RGBColor[
             0.19380336074719554`, 0.32102999836105145`, 0.9343481867369493]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 296}], {
             RGBColor[
             0.2211466738327187, 0.34976955408011773`, 0.935905347966363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 308}], {
             RGBColor[
             0.19941664213352878`, 0.3269299130006835, 0.9346678548077954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 380}], {
             RGBColor[
             0.20872851353399335`, 0.33671728024931885`, 0.9351981521083725]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 269}], {
             RGBColor[
             0.5167818424220354, 0.6108654129881752, 0.9574511707265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 272}], {
             RGBColor[
             0.5154577316990447, 0.6098310076277607, 0.9573191957441505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 280}], {
             RGBColor[
             0.2707591220181621, 0.40191538273391547`, 0.9387307034954844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 309}], {
             RGBColor[
             0.29378936272937667`, 0.4261216259230004, 0.9400422416338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 325}], {
             RGBColor[
             0.28956065239162987`, 0.42167698324230746`, 0.9398014228358818]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 339}], {
             RGBColor[
             0.27076497929052823`, 0.4019215390985449, 0.9387310370584805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 246}], {
             RGBColor[
             0.874004135287985, 0.576823099817974, 0.5832370617608514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 269}], {
             RGBColor[
             0.785672209855677, 0.5070071531213871, 0.5746480096042236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 272}], {
             RGBColor[
             0.7843480991326863, 0.5059727477609727, 0.5745160346218742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 350}], {
             RGBColor[
             0.9108066927653387, 0.6030642712488816, 0.46289813781652445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 355}], {
             RGBColor[
             0.7967350259379453, 0.5156495091253714, 0.57575064772341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 392}], {
             RGBColor[
             0.9094234148855309, 0.6024922502969611, 0.4858226320933391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 242}], {
             RGBColor[
             0.8419811748449504, 0.32369128289221516`, 0.18783452648346705`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 243}], {
             RGBColor[
             0.9006075598972731, 0.6106868981753124, 0.5572235175535094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 285}], {
             RGBColor[
             0.912943980913413, 0.617290591635334, 0.3939789817698772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 337}], {
             RGBColor[
             0.9128678714659045, 0.6171278012229586, 0.3856949381016387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 357}], {
             RGBColor[
             0.8443947063429684, 0.3422427436022275, 0.19014572697166301`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 399}], {
             RGBColor[
             0.879132492911469, 0.49559305678514604`, 0.2188791175560995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 270}], {
             RGBColor[
             0.31115624108701556`, 0.43971981464523346`, 0.9412017203817521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 310}], {
             RGBColor[
             0.2714061632718937, 0.40259546411637237`, 0.9387675515376726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 323}], {
             RGBColor[
             0.3309521511254019, 0.4568660369491151, 0.9424630982645621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 346}], {
             RGBColor[
             0.30713982911114474`, 0.4362410004624697, 0.9409457981622233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 389}], {
             RGBColor[
             0.23293094482355622`, 0.362155570057423, 0.9365764447660246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 390}], {
             RGBColor[
             0.2629620790942533, 0.393720196259813, 0.938286673435659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 244}], {
             RGBColor[
             0.9035194245465865, 0.684293372013093, 0.5795724587116564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 357}], {
             RGBColor[
             0.854686957719692, 0.4213534977770367, 0.2000015985134489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 364}], {
             RGBColor[
             0.8349752732346869, 0.2698408531100693, 0.18112566718944462`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 385}], {
             RGBColor[
             0.9233493722002852, 0.696643340637751, 0.416149434312738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 337}], {
             RGBColor[
             0.981786507894951, 0.983234170680865, 0.764939800713467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 367}], {
             RGBColor[
             0.6723041775720541, 0.7380461571244501, 0.9407946307732227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 398}], {
             RGBColor[
             0.6978102198330773, 0.7601382089599893, 0.9424198532319874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 264}], {
             RGBColor[
             0.8390285444461558, 0.8747724603828321, 0.9672545655941249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 307}], {
             RGBColor[
             0.651559964846024, 0.7209668023928419, 0.952436169214119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 321}], {
             RGBColor[
             0.7545634824664897, 0.8074397031821838, 0.959757518581915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 341}], {
             RGBColor[
             0.6455002366075493, 0.7157181703634723, 0.9520500486891706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 348}], {
             RGBColor[
             0.6439525347584986, 0.7143776288115813, 0.9519514304959281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 357}], {
             RGBColor[
             0.9059329560446046, 0.7028448327231054, 0.5818836591998524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 366}], {
             RGBColor[
             0.6745824127024198, 0.7409076895841773, 0.9539031392335773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 328}], {
             RGBColor[
             0.8441804058989478, 0.32309654782053254`, 0.18925529611386532`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 364}], {
             RGBColor[
             0.8182535878829069, 0.14131065200704435`, 0.16511296241213771`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 400}], {
             RGBColor[
             0.8345042681241085, 0.26622050143440795`, 0.18067463216363056`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 269}], {
             RGBColor[
             0.8319134288403021, 0.869426735678431, 0.9836659653182612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 272}], {
             RGBColor[
             0.8305893181173114, 0.8683923303180165, 0.9835339903359117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 350}], {
             RGBColor[
             0.9570479117499637, 0.9654838538059254, 0.8719160935305621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 355}], {
             RGBColor[
             0.8429762449225704, 0.8780690916824152, 0.9847686034374477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 392}], {
             RGBColor[
             0.955664633870156, 0.964911832854005, 0.8948405878073766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 395}], {
             RGBColor[
             0.6944421379403393, 0.7593719483680503, 0.9717835682731306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 253}], {
             RGBColor[
             0.19436046466415727`, 0.3216155499002067, 0.9343799129808589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 266}], {
             RGBColor[
             0.21519016549381775`, 0.3435088861514912, 0.9355661336283271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 301}], {
             RGBColor[
             0.1901623548072361, 0.317203070265044, 0.9341408368350541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 315}], {
             RGBColor[
             0.2082369879918481, 0.3362006557400048, 0.9351701604558942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 316}], {
             RGBColor[
             0.21599089502507074`, 0.3443505036580227, 0.9356117339905587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 343}], {
             RGBColor[
             0.18982443678675276`, 0.31684789700027605`, 0.9341215929036926]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 358}], {
             RGBColor[
             0.19420191296404457`, 0.3214489020106298, 0.9343708836960937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 359}], {
             RGBColor[
             0.1924159607622266, 0.31957175301060936`, 0.9342691763602797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 362}], {
             RGBColor[
             0.19339653330473627`, 0.32060239692467707`, 0.9343250185159485]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 363}], {
             RGBColor[
             0.20876443324933688`, 0.3367550341475864, 0.9352001976830229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 369}], {
             RGBColor[
             0.19411283179141248`, 0.32135527205012093`, 0.934365810655096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 397}], {
             RGBColor[
             0.20527567361963986`, 0.3330881265766384, 0.935001517983269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 276}], {
             RGBColor[
             0.22042799245848094`, 0.3490141743887628, 0.9358644201252941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 340}], {
             RGBColor[
             0.2104667967928659, 0.33854432616791813`, 0.9352971447684058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 360}], {
             RGBColor[
             0.20162405229043762`, 0.3292500410334822, 0.9347935635506606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 266}], {
             RGBColor[
             0.270914372535644, 0.40204801259274037`, 0.9387406633049027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 293}], {
             RGBColor[
             0.3289853537057845, 0.45937231092045516`, 0.9421836337211749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 315}], {
             RGBColor[
             0.2639611950336743, 0.39473978218125394`, 0.9383446901324698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 316}], {
             RGBColor[
             0.271715102066897, 0.4028896300992718, 0.9387862636671344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 387}], {
             RGBColor[
             0.4216012233503626, 0.5373973944320252, 0.9486912790769737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 397}], {
             RGBColor[
             0.26099988066146607`, 0.3916272530178875, 0.9381760476598446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 356}], {
             RGBColor[
             0.22666963106636354`, 0.3555745323083922, 0.9362198722103361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 363}], {
             RGBColor[
             0.2391241828797345, 0.3686650559284389, 0.9369291405112493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 372}], {
             RGBColor[
             0.22620791914637717`, 0.35508924380626006`, 0.9361935783995345]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 283}], {
             RGBColor[
             0.19962713488925782`, 0.32715115423296626`, 0.934679842058838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 308}], {
             RGBColor[
             0.1958872147734443, 0.3232202610666153, 0.9344668591409584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 380}], {
             RGBColor[
             0.20519908617390886`, 0.3330076283152506, 0.9349971564415356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 381}], {
             RGBColor[
             0.19321867549075944`, 0.3204154570853507, 0.9343148897765596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 282}], {
             RGBColor[
             0.31835440977210794`, 0.4463178036126423, 0.941647079240882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 300}], {
             RGBColor[
             0.6421328397168371, 0.7146709767757251, 0.9682477279637229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 367}], {
             RGBColor[
             0.372324185998124, 0.4969102291790325, 0.9449451457918181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 398}], {
             RGBColor[
             0.39783022825914727`, 0.5190022810145718, 0.9465703682505828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 266}], {
             RGBColor[
             0.21192263839001468`, 0.3400745079922101, 0.9353800527936387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 301}], {
             RGBColor[
             0.18689482770343305`, 0.31376869210576286`, 0.9339547560003658]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 315}], {
             RGBColor[
             0.20496946088804507`, 0.3327662775807237, 0.9349840796212059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 316}], {
             RGBColor[
             0.2127233679212677, 0.3409161254987416, 0.9354256531558705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 343}], {
             RGBColor[
             0.18655690968294972`, 0.31341351884099494`, 0.9339355120690042]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 358}], {
             RGBColor[
             0.19093438586024153`, 0.31801452385134865`, 0.9341848028614053]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 359}], {
             RGBColor[
             0.18914843365842357`, 0.3161373748513282, 0.9340830955255912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 362}], {
             RGBColor[
             0.19012900620093326`, 0.31716801876539596`, 0.9341389376812601]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 369}], {
             RGBColor[
             0.19084530468760944`, 0.3179208938908398, 0.9341797298204076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 394}], {
             RGBColor[
             0.1857625991924869, 0.31257864815332465`, 0.9338902772616493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 397}], {
             RGBColor[
             0.20200814651583682`, 0.3296537484173573, 0.9348154371485806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 303}], {
             RGBColor[
             0.20024144683233963`, 0.3277968350347721, 0.9347148262152034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 268}], {
             RGBColor[
             0.7573621449450872, 0.5111257415751345, 0.5750858104368912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 324}], {
             RGBColor[
             0.7342455134222807, 0.4929254711764368, 0.5728784243989717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 328}], {
             RGBColor[
             0.8524460760036836, 0.3866301102852666, 0.1971705111408994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 351}], {
             RGBColor[
             0.8725754097367984, 0.601857083491112, 0.5863765700059249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 400}], {
             RGBColor[
             0.8427699382288443, 0.329754063899142, 0.18858984719066463`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 311}], {
             RGBColor[
             0.32702639881790146`, 0.45712063802367703`, 0.942079129357128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 313}], {
             RGBColor[
             0.28483799884386285`, 0.41277795475190926`, 0.9396765623907513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 386}], {
             RGBColor[
             0.556034698630532, 0.6458694921919914, 0.9601976146247932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 275}], {
             RGBColor[
             0.2809273627700829, 0.4112753166902168, 0.9393583772051975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 276}], {
             RGBColor[
             0.27298076036949565`, 0.4029229337235066, 0.9389058299544288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 279}], {
             RGBColor[
             0.4976692988631992, 0.5990761277778498, 0.9548872926096961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 280}], {
             RGBColor[
             0.2873202290991691, 0.41799462453322234`, 0.9397224414852408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 288}], {
             RGBColor[
             0.3142377899115303, 0.4462866876189422, 0.9412553567525421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 309}], {
             RGBColor[
             0.31035046981038367`, 0.4422008677223072, 0.9410339796235565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 325}], {
             RGBColor[
             0.30612175947263687`, 0.43775622504161427`, 0.9407931608256381]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 339}], {
             RGBColor[
             0.2873260863715352, 0.41800078089785175`, 0.939722775048237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 277}], {
             RGBColor[
             0.19561158896014919`, 0.3229305608611562, 0.9344511626586431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 302}], {
             RGBColor[
             0.18739149065206478`, 0.3142907163550246, 0.9339830402205433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 377}], {
             RGBColor[
             0.18407204095648846`, 0.3108017642597073, 0.933794002471066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 378}], {
             RGBColor[
             0.18711323001988966`, 0.3139982467878655, 0.9339671936891907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 379}], {
             RGBColor[
             0.19525485067885182`, 0.32255560630899927`, 0.9344308469412701]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 262}], {
             RGBColor[
             0.20019420515358305`, 0.3277471810351035, 0.934712135871486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 331}], {
             RGBColor[
             0.19269223822101744`, 0.31986213813680114`, 0.934284909952842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 335}], {
             RGBColor[
             0.18286996403264408`, 0.3095383051966678, 0.9337255459685665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 307}], {
             RGBColor[
             0.28646815305242945`, 0.41476449327789777`, 0.9397593961545982]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 329}], {
             RGBColor[
             0.20751257412950358`, 0.3354392508401891, 0.9351289061581081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 341}], {
             RGBColor[
             0.2804084248139549, 0.4095158612485281, 0.93937327562965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 349}], {
             RGBColor[
             0.21328372600725728`, 0.3415050973758713, 0.9354575647198919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 366}], {
             RGBColor[
             0.3094906009088253, 0.4347053804692331, 0.9412263661740565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 306}], {
             RGBColor[
             0.2313412040252819, 0.36048465168304844`, 0.9364859113793738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 284}], {
             RGBColor[
             0.24537509181412387`, 0.37523515754899955`, 0.9372851205276718]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 286}], {
             RGBColor[
             0.20449842182687056`, 0.3322711856618279, 0.9349572546435119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 331}], {
             RGBColor[
             0.20664951421908523`, 0.3345321201531805, 0.9350797561729924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 332}], {
             RGBColor[
             0.22124807994982085`, 0.34987613833871123`, 0.9359111228947152]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 338}], {
             RGBColor[
             0.22417589206845978`, 0.35295345450941085`, 0.9360778574635618]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 264}], {
             RGBColor[
             0.5576221544304325, 0.6488358128735436, 0.9596252327476064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 312}], {
             RGBColor[
             0.3474308254202023, 0.4748091816311434, 0.9433787228228494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 348}], {
             RGBColor[
             0.36254614474277536`, 0.48844098130229274`, 0.9443220976494096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 307}], {
             RGBColor[
             0.5358230864206805, 0.6299545558165122, 0.958236215410184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 312}], {
             RGBColor[
             0.5131003370105822, 0.6097335825641022, 0.9568081018654329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 348}], {
             RGBColor[
             0.5282156563331551, 0.6233653822352514, 0.957751476691993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 357}], {
             RGBColor[
             0.7901960776192611, 0.6118325861467757, 0.5876837053959174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 366}], {
             RGBColor[
             0.5588455342770764, 0.6498954430078475, 0.9597031854296422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 291}], {
             RGBColor[
             0.18857894058274138`, 0.31553880152083974`, 0.9340506637374206]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 304}], {
             RGBColor[
             0.18543662898340038`, 0.31223603279586976`, 0.9338717137404716]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 378}], {
             RGBColor[
             0.19040066183963522`, 0.31745354606563403`, 0.9341544080680056]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 383}], {
             RGBColor[
             0.1991683094404495, 0.3266688995950551, 0.9346537126282998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 293}], {
             RGBColor[
             0.2908233203898157, 0.4192921425712095, 0.940009243857379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 315}], {
             RGBColor[
             0.22579916171770553`, 0.3546596138320083, 0.9361703002686741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 316}], {
             RGBColor[
             0.23355306875092818`, 0.36280946175002615`, 0.9366118738033387]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 338}], {
             RGBColor[
             0.23347632110247196`, 0.3627287951054168, 0.936607503138297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 397}], {
             RGBColor[
             0.22283784734549728`, 0.3515470846686418, 0.9360016577960488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 282}], {
             RGBColor[
             0.2615646860965489, 0.39225144761939246`, 0.9382070939716974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 332}], {
             RGBColor[
             0.24216572228766625`, 0.37186190669091185`, 0.9371023516809767]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 367}], {
             RGBColor[
             0.315534462322565, 0.44284387318578267`, 0.9415051605226336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 383}], {
             RGBColor[
             0.23217032750693795`, 0.361356113031734, 0.9365331287350758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 398}], {
             RGBColor[
             0.34104050458358826`, 0.46493592502132197`, 0.9431303829813984]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 270}], {
             RGBColor[
             0.5192310696539062, 0.6174490867384653, 0.9563893333020512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 274}], {
             RGBColor[
             0.5862206904488971, 0.6743925388404906, 0.9609561467561663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 295}], {
             RGBColor[
             0.5541988760682194, 0.6477364431214906, 0.9586174510059542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 324}], {
             RGBColor[
             0.6562462626397825, 0.7312424529611288, 0.9664688163111557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 351}], {
             RGBColor[
             0.7945761589543001, 0.8401740652758038, 0.979966961918109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 373}], {
             RGBColor[
             0.475607023803843, 0.5762529501811211, 0.9537345477094038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 272}], {
             RGBColor[
             0.7422573926850033, 0.7985763836214297, 0.9749449381792838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 350}], {
             RGBColor[
             0.8687159863176557, 0.8956679071093385, 0.8633270413739342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 355}], {
             RGBColor[
             0.7546443194902623, 0.8082531449858283, 0.9761795512808198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 392}], {
             RGBColor[
             0.8673327084378479, 0.8950958861574181, 0.8862515356507488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 395}], {
             RGBColor[
             0.6061102125080312, 0.6895560016714635, 0.9631945161165028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 295}], {
             RGBColor[
             0.3940670515595366, 0.5157428065001295, 0.9463305819589302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 310}], {
             RGBColor[
             0.3193491673301014, 0.4483310995882432, 0.9416682954109477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 324}], {
             RGBColor[
             0.49611443813109957`, 0.5992488163397677, 0.9541819472641316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 346}], {
             RGBColor[
             0.3550828331693524, 0.4819766359343405, 0.9438465420354984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 351}], {
             RGBColor[
             0.6344443344456173, 0.7081804286544429, 0.9676800928710849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 373}], {
             RGBColor[
             0.31547519929516016`, 0.44425931355976, 0.9414476786623798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 390}], {
             RGBColor[
             0.310905083152461, 0.4394558317316838, 0.9411874173089341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 287}], {
             RGBColor[
             0.18451611233351262`, 0.31126851143271117`, 0.9338192916790429]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 292}], {
             RGBColor[
             0.18674265418407987`, 0.3136087480885643, 0.9339460899435592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 371}], {
             RGBColor[
             0.1828236944867615, 0.3094896729702865, 0.9337229109863782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 374}], {
             RGBColor[
             0.184659451088446, 0.3114191695523481, 0.9338274546090857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 382}], {
             RGBColor[
             0.18049565541513857`, 0.3070427562998084, 0.9335903326052744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 384}], {
             RGBColor[
             0.18432884103510522`, 0.31107167742439884`, 0.9338086268556416]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 389}], {
             RGBColor[
             0.19087423447573804`, 0.31795130093241747`, 0.9341813773290437]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 391}], {
             RGBColor[
             0.1801133509320429, 0.3066409300485706, 0.9335685609305309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 350}], {
             RGBColor[
             0.867391875594665, 0.894633501748924, 0.8631950663915847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 392}], {
             RGBColor[
             0.8660085977148573, 0.8940614807970035, 0.8861195606683994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 395}], {
             RGBColor[
             0.6047861017850406, 0.688521596311049, 0.9630625411341533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 322}], {
             RGBColor[
             0.19086506728942945`, 0.31794166563837395`, 0.9341808552713451]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 330}], {
             RGBColor[
             0.18387764331179846`, 0.31059744000961553`, 0.9337829318127865]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 295}], {
             RGBColor[
             0.4610566723545275, 0.5726862586021548, 0.9508973954130453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 296}], {
             RGBColor[
             0.36901952314668135`, 0.4870709060931353, 0.9452488023460986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 319}], {
             RGBColor[
             0.47322013025663245`, 0.583220445923085, 0.9516727685977074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 324}], {
             RGBColor[
             0.5631040589260905, 0.6561922684417929, 0.9587487607182468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 351}], {
             RGBColor[
             0.7014339552406084, 0.7651238807564681, 0.9722469063252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 373}], {
             RGBColor[
             0.38246482009015115`, 0.5012027656617852, 0.9460144921164949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 276}], {
             RGBColor[
             0.2308037275414878, 0.35991972982060355`, 0.9364553028887468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 280}], {
             RGBColor[
             0.24514319627116127`, 0.3749914206303192, 0.9372719144195587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 288}], {
             RGBColor[
             0.2720607570835225, 0.40328348371603906`, 0.9388048296868601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 290}], {
             RGBColor[
             0.21848378643908228`, 0.34697069059259356`, 0.9357537004686844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 297}], {
             RGBColor[
             0.22283542703535522`, 0.35154454076922603`, 0.9360015199629668]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 318}], {
             RGBColor[
             0.21657038683237403`, 0.3449595862894012, 0.9356447351917034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 325}], {
             RGBColor[
             0.2639447266446291, 0.3947530211387112, 0.9383426337599561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 339}], {
             RGBColor[
             0.24514905354352745`, 0.3749975769949486, 0.9372722479825549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 288}], {
             RGBColor[
             0.2641141546829352, 0.39493110074932897`, 0.9383522824360913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 290}], {
             RGBColor[
             0.21053718403849497`, 0.33861830762588346`, 0.9353011532179156]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 297}], {
             RGBColor[
             0.21488882463476794`, 0.3431921578025159, 0.9355489727121981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 318}], {
             RGBColor[
             0.20862378443178675`, 0.3366072033226911, 0.9351921879409346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 278}], {
             RGBColor[
             0.23299059780069237`, 0.3622182691186103, 0.9365798419148239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 302}], {
             RGBColor[
             0.19959521355734036`, 0.32711760288919167`, 0.9346780241862087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 314}], {
             RGBColor[
             0.22024480085065679`, 0.34882162839392095`, 0.9358539876342362]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 352}], {
             RGBColor[
             0.22370886564436498`, 0.3524625801265016, 0.9360512609996132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 378}], {
             RGBColor[
             0.19931695292516527`, 0.3268251333220326, 0.934662177654856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 379}], {
             RGBColor[
             0.2074585735841274, 0.33538249284316635`, 0.9351258309069355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 314}], {
             RGBColor[
             0.2454200867859244, 0.3752824501172079, 0.9372876829247517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 319}], {
             RGBColor[
             0.35576382875700985`, 0.4778888141834562, 0.9440614916187484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 352}], {
             RGBColor[
             0.24888415157963256`, 0.37892340184978857`, 0.9374849562901288]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 379}], {
             RGBColor[
             0.232633859519395, 0.36184331456645336`, 0.936559526197451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.8332166202434534, 0.8669371947579207, 0.788972494773293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 288}], {
             RGBColor[
             0.4888026931766387, 0.5910842948036721, 0.9543337450913586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 309}], {
             RGBColor[
             0.48491537307549215`, 0.5869984749070372, 0.9541123679623731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 325}], {
             RGBColor[
             0.4806866627377453, 0.5825538322263442, 0.9538715491644547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 399}], {
             RGBColor[
             0.7994051322415094, 0.7452396599077329, 0.6138726305595152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 297}], {
             RGBColor[
             0.22922829336444137`, 0.3582638486122316, 0.9363655842430101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 309}], {
             RGBColor[
             0.27456630331146203`, 0.4059169716624097, 0.9389475168379178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 322}], {
             RGBColor[
             0.22572058379982396`, 0.354577023458187, 0.9361658253724963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 325}], {
             RGBColor[
             0.2703375929737152, 0.4014723289817168, 0.9387066980399994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 339}], {
             RGBColor[
             0.2515419198726136, 0.3817168848379542, 0.9376363122625981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 355}], {
             RGBColor[
             0.5971975343016019, 0.6813125874620714, 0.9629093916561169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 386}], {
             RGBColor[
             0.5947242732295994, 0.6793804571151425, 0.9626628801063983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 367}], {
             RGBColor[
             0.3211123825917724, 0.44870662104929115`, 0.9418228148301714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 383}], {
             RGBColor[
             0.23774824777614534`, 0.3672188608952424, 0.9368507830426136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 398}], {
             RGBColor[
             0.3466184248527956, 0.47079867288483046`, 0.9434480372889362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 294}], {
             RGBColor[
             0.19947004944091673`, 0.32698604746696713`, 0.934670896274942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 320}], {
             RGBColor[
             0.20238649627655553`, 0.330051418004633, 0.9348369836077353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 347}], {
             RGBColor[
             0.20341579469893528`, 0.33113327590784336`, 0.9348956006301792]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 373}], {
             RGBColor[
             0.2404157449182508, 0.3700225695206825, 0.937002693058648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 380}], {
             RGBColor[
             0.2145522876760556, 0.34283843612123366`, 0.9355298074302612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 381}], {
             RGBColor[
             0.20257187699290616`, 0.3302462648913338, 0.9348475407652852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 332}], {
             RGBColor[
             0.2524716906122939, 0.382694132836228, 0.9376892613307504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 338}], {
             RGBColor[
             0.2553995027309328, 0.3857714490069275, 0.9378559958995971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 367}], {
             RGBColor[
             0.3258404306471927, 0.4536760993310988, 0.9420920701724073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 399}], {
             RGBColor[
             0.9603875503566552, 0.868303119703074, 0.4348794443842956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 332}], {
             RGBColor[
             0.2115950206250406, 0.3397301609490563, 0.9353613954465905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 292}], {
             RGBColor[
             0.19215895018442095`, 0.31930161859792383`, 0.9342545399880867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 371}], {
             RGBColor[
             0.18823999048710255`, 0.315182543479646, 0.9340313610309057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 374}], {
             RGBColor[
             0.19007574708878708`, 0.31711204006170757`, 0.9341359046536132]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 382}], {
             RGBColor[
             0.18591195141547964`, 0.3127356268091679, 0.933898782649802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 384}], {
             RGBColor[
             0.18974513703544627`, 0.3167645479337583, 0.9341170769001692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 389}], {
             RGBColor[
             0.19629053047607914`, 0.32364417144177693`, 0.9344898273735713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 391}], {
             RGBColor[
             0.18552964693238397`, 0.31233380055793014`, 0.9338770109750585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 303}], {
             RGBColor[
             0.19970158242580874`, 0.32722940331412775`, 0.9346840817359092]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 376}], {
             RGBColor[
             0.19788479388924796`, 0.32531984337115605`, 0.93458061831645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 297}], {
             RGBColor[
             0.20256888353236238`, 0.33024311857450594`, 0.9348473702921356]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 318}], {
             RGBColor[
             0.1963038433293812, 0.3236581640946811, 0.9344905855208723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 345}], {
             RGBColor[
             0.18860221988526102`, 0.31556326954378094`, 0.9340519894592605]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 304}], {
             RGBColor[
             0.1840328398717771, 0.3107605614341833, 0.9337917700272845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 383}], {
             RGBColor[
             0.1977645203288262, 0.3251934282333686, 0.9345737689151127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 371}], {
             RGBColor[
             0.1904665323376698, 0.31752278013549917`, 0.934158159295422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 374}], {
             RGBColor[
             0.19230228893935433`, 0.31945227671756077`, 0.9342627029181295]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 382}], {
             RGBColor[
             0.1881384932660469, 0.31507586346502103`, 0.9340255809143183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 384}], {
             RGBColor[
             0.19197167888601352`, 0.3191047845896115, 0.9342438751646855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 389}], {
             RGBColor[
             0.1985170723266464, 0.32598440809763013`, 0.9346166256380877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 316}], {
             RGBColor[
             0.2916240499210687, 0.42013376007774095`, 0.9400548442196108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 387}], {
             RGBColor[
             0.4415101712045343, 0.5546415244104943, 0.9499598596294503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 320}], {
             RGBColor[
             0.19287620932606772`, 0.32005550343265077`, 0.9342953868351136]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 347}], {
             RGBColor[
             0.19390550774844745`, 0.3211373613358611, 0.9343540038575576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 380}], {
             RGBColor[
             0.20504200072556777`, 0.3328425215492514, 0.9349882106576397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 381}], {
             RGBColor[
             0.19306159004241835`, 0.32025035031935156`, 0.9343059439926636]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 310}], {
             RGBColor[
             0.3543169737444146, 0.4786184559712684, 0.9438964131148506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 324}], {
             RGBColor[
             0.5310822445454129, 0.6295361727227928, 0.9564100649680346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 351}], {
             RGBColor[
             0.6694121408599306, 0.7384677850374681, 0.9699082105749879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 373}], {
             RGBColor[
             0.3504430057094734, 0.4745466699427852, 0.9436757963662827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 390}], {
             RGBColor[
             0.34587288956677426`, 0.46974318811470905`, 0.943415535012837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 308}], {
             RGBColor[
             0.22323052785896746`, 0.35195981678568156`, 0.9360240203703722]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 373}], {
             RGBColor[
             0.25840585650162723`, 0.38893131743376574`, 0.9380272032993362]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 380}], {
             RGBColor[
             0.23254239925943204`, 0.3617471840343169, 0.9365543176709494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 318}], {
             RGBColor[
             0.20065548392565413`, 0.32823201427131354`, 0.9347384050151546]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 322}], {
             RGBColor[
             0.2034128145640179, 0.33113014359709375`, 0.9348954309159043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 339}], {
             RGBColor[
             0.22923415063680755`, 0.358270004976861, 0.9363659178060062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 313}], {
             RGBColor[
             0.20768244341745035`, 0.33561779423215604`, 0.9351385799627575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 361}], {
             RGBColor[
             0.2073168336633886, 0.33523351519963984`, 0.9351177590281349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 393}], {
             RGBColor[
             0.19018046268844432`, 0.31722210279629987`, 0.9341418680521008]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 396}], {
             RGBColor[
             0.19827776691556012`, 0.32573288293773905`, 0.9346029975489469]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 306}], {
             RGBColor[
             0.19518727715711093`, 0.32248458225324084`, 0.9344269987291731]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 342}], {
             RGBColor[
             0.18568831496489116`, 0.3125005707202294, 0.9338860468847814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 353}], {
             RGBColor[
             0.188841530987085, 0.3158148006849981, 0.9340656178724803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 319}], {
             RGBColor[
             0.6840306200166372, 0.7509595396670409, 0.9709177458785374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 343}], {
             RGBColor[
             0.18235879982602854`, 0.30900103920583233`, 0.9336964359231994]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 358}], {
             RGBColor[
             0.18673627600332035`, 0.31360204421618604`, 0.9339457267156006]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 359}], {
             RGBColor[
             0.1849503238015024, 0.31172489521616553`, 0.9338440193797866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 362}], {
             RGBColor[
             0.18593089634401205`, 0.31275553913023335`, 0.9338998615354555]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 369}], {
             RGBColor[
             0.18664719483068826`, 0.31350841425567716`, 0.9339406536746029]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 394}], {
             RGBColor[
             0.18156448933556574`, 0.30816616851816203`, 0.9336512011158447]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 397}], {
             RGBColor[
             0.19781003665891564`, 0.3252412687821946, 0.934576361002776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 314}], {
             RGBColor[
             0.21202470254257239`, 0.3401817838877893, 0.9353858651961364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 352}], {
             RGBColor[
             0.21548876733628058`, 0.34382273562037, 0.9355831385615135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 377}], {
             RGBColor[
             0.18805566555367964`, 0.3149888062877428, 0.9340208639986316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 379}], {
             RGBColor[
             0.199238475276043, 0.32674264833703476`, 0.9346577084688357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 376}], {
             RGBColor[
             0.21141869489039777`, 0.33954483142224945`, 0.9353513539568531]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 383}], {
             RGBColor[
             0.1946222087294852, 0.32189065950839857`, 0.9343948189181637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 334}], {
             RGBColor[
             0.18360707090558112`, 0.31031305125539965`, 0.9337675231145284]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 340}], {
             RGBColor[
             0.19258396167334632`, 0.31974833262006913`, 0.9342787437636328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 360}], {
             RGBColor[
             0.18374121717091801`, 0.3104540474856332, 0.9337751625458877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 370}], {
             RGBColor[
             0.18466045373978385`, 0.311420223402476, 0.9338275117085959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 342}], {
             RGBColor[
             0.1932134040418383, 0.3204099164583054, 0.934314589575342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 353}], {
             RGBColor[
             0.19636662006403216`, 0.3237241464230741, 0.9344941605630408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 361}], {
             RGBColor[
             0.21017418029056079`, 0.33823676767103766`, 0.9352804806914867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 312}], {
             RGBColor[
             0.32563175741045036`, 0.45592792457411196`, 0.9419897054854269]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 341}], {
             RGBColor[
             0.3422947785820742, 0.4709002657971524, 0.9430316985052297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 348}], {
             RGBColor[
             0.3407470767330234, 0.4695597242452613, 0.9429330803119872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 366}], {
             RGBColor[
             0.37137695467694465`, 0.4960897850178574, 0.9448847890496364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 325}], {
             RGBColor[
             0.2933678336849298, 0.42567857217080163`, 0.9400182361783151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 339}], {
             RGBColor[
             0.27457216058382816`, 0.4059231280270391, 0.9389478504009139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 323}], {
             RGBColor[
             0.33914507736848765`, 0.46547732189212476`, 0.9429296732937578]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 324}], {
             RGBColor[
             0.45636436031597766`, 0.5621244658109066, 0.9517477784200521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 346}], {
             RGBColor[
             0.31533275535423055`, 0.4448522854054794, 0.9414123731914188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 389}], {
             RGBColor[
             0.24112387106664201`, 0.3707668550004327, 0.9370430197952202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 390}], {
             RGBColor[
             0.27115500533733905`, 0.4023314812028227, 0.9387532484648545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 313}], {
             RGBColor[
             0.2605556138292256, 0.39119084868755866`, 0.938149628798862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 361}], {
             RGBColor[
             0.2601900040751639, 0.39080656965504246`, 0.9381288078642394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 386}], {
             RGBColor[
             0.5317523136158948, 0.6242823861276408, 0.958670681032904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 348}], {
             RGBColor[
             0.31802432732292496`, 0.44933875099285125`, 0.9415049667672362]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 366}], {
             RGBColor[
             0.3486542052668462, 0.4758688117654473, 0.9434566755048852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 361}], {
             RGBColor[
             0.2180016041011253, 0.34646388638327474`, 0.9357262408978626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 393}], {
             RGBColor[
             0.200865233126181, 0.3284524739799347, 0.9347503499218286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 396}], {
             RGBColor[
             0.20896253735329678`, 0.3369632541213739, 0.9352114794186747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 352}], {
             RGBColor[
             0.23613835462959704`, 0.3655267611250992, 0.9367591020095412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 379}], {
             RGBColor[
             0.21988806256935944`, 0.348446673841764, 0.9358336719168633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 316}], {
             RGBColor[
             0.22659989124895852`, 0.3555012313385397, 0.9362159006309058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 358}], {
             RGBColor[
             0.20481090918793238`, 0.33259962969114687`, 0.9349750503364407]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 359}], {
             RGBColor[
             0.2030249569861144, 0.33072248069112636`, 0.9348733430006266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 362}], {
             RGBColor[
             0.20400552952862408`, 0.3317531246051941, 0.9349291851562955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 363}], {
             RGBColor[
             0.2193734294732247, 0.3479057618281034, 0.9358043643233698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 369}], {
             RGBColor[
             0.20472182801530026`, 0.332505999730638, 0.934969977295443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 397}], {
             RGBColor[
             0.21588466984352767`, 0.3442388542571554, 0.935605684623616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 358}], {
             RGBColor[
             0.212564816221155, 0.34074947760916474`, 0.9354166238711052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 359}], {
             RGBColor[
             0.21077886401933704`, 0.3388723286091443, 0.9353149165352912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 362}], {
             RGBColor[
             0.2117594365618467, 0.339902972523212, 0.9353707586909601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 363}], {
             RGBColor[
             0.2271273365064473, 0.3560556097461213, 0.9362459378580343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 369}], {
             RGBColor[
             0.2124757350485229, 0.34065584764865586`, 0.9354115508301075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 397}], {
             RGBColor[
             0.2236385768767503, 0.3523887021751733, 0.9360472581582806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 326}], {
             RGBColor[
             0.19368284883535128`, 0.3209033327008066, 0.9343413237618512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 327}], {
             RGBColor[
             0.19548056477531295`, 0.3227928461354802, 0.9344437010251496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 336}], {
             RGBColor[
             0.1878536669894908, 0.3147764929893316, 0.9340093604792311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 396}], {
             RGBColor[
             0.19745595153076353`, 0.32486910286221293`, 0.9345561963785496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 345}], {
             RGBColor[
             0.18668882027855277`, 0.3135521652405886, 0.9339430241822795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 347}], {
             RGBColor[
             0.1968219545840863, 0.324202731873527, 0.9345200911903508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 380}], {
             RGBColor[
             0.20795844756120663`, 0.3359078920869173, 0.9351542979904328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 381}], {
             RGBColor[
             0.19597803687805715`, 0.32331572085701743`, 0.9344720313254569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 384}], {
             RGBColor[
             0.1926752609493727, 0.31984429394788133`, 0.9342839431223373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 341}], {
             RGBColor[
             0.44529829620254, 0.5573731665864943, 0.9503530478730258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 366}], {
             RGBColor[
             0.4743804722974104, 0.5825626858071993, 0.9522061384174323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 330}], {
             RGBColor[
             0.19291768102176954`, 0.3200990928142907, 0.934297748586832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 339}], {
             RGBColor[
             0.22572644107219014`, 0.3545831798228164, 0.9361661589354925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 346}], {
             RGBColor[
             0.37487874320773873`, 0.4991228582382221, 0.9451079199183084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 346}], {
             RGBColor[
             0.4920980261552287, 0.5957700021570038, 0.9539260250446029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 351}], {
             RGBColor[
             0.7714595274314936, 0.8219737948771062, 0.9777595758801894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 390}], {
             RGBColor[
             0.4479202761383373, 0.5532491979543472, 0.9512669003180385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 339}], {
             RGBColor[
             0.2703434502460814, 0.40147848534634617`, 0.9387070316029955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 327}], {
             RGBColor[
             0.19380937140054372`, 0.3210363159388178, 0.9343485290347655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 336}], {
             RGBColor[
             0.18618247361472157`, 0.3130199627926692, 0.9339141884888471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 336}], {
             RGBColor[
             0.18798018955468324`, 0.3149094762273428, 0.9340165657521455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 376}], {
             RGBColor[
             0.2026044968471712, 0.33028055042638454`, 0.9348493984177288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 364}], {
             RGBColor[
             0.8436039382637408, 0.3186655649666024, 0.18870327005536394`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 386}], {
             RGBColor[
             0.8151456848541535, 0.6567413505380229, 0.5948173850288303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 400}], {
             RGBColor[
             0.8598546185049423, 0.443575414393966, 0.20426493980685678`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 349}], {
             RGBColor[
             0.19621450085245074`, 0.32356425948678696`, 0.9344854975989814]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 335}], {
             RGBColor[
             0.18932527309814626`, 0.31632324431474484`, 0.9340931662700729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 338}], {
             RGBColor[
             0.2166739251358942, 0.34506841161110846`, 0.9356506315449178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 368}], {
             RGBColor[
             0.18664235406415453`, 0.3135033263031278, 0.9339403780001101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 340}], {
             RGBColor[
             0.1939578430419053, 0.32119236904753456`, 0.934356984275097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 360}], {
             RGBColor[
             0.185115098539477, 0.3118980839130987, 0.9338534030573518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 365}], {
             RGBColor[
             0.18295572293696874`, 0.30962844324254163`, 0.933730429811299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 370}], {
             RGBColor[
             0.18603433510834283`, 0.3128642598299414, 0.93390575222006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 394}], {
             RGBColor[
             0.17996762986719622`, 0.30648776797016763`, 0.9335602623314629]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 396}], {
             RGBColor[
             0.18995557631013382`, 0.31698573295407556`, 0.9341290611055455]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 367}], {
             RGBColor[
             0.6845644891406854, 0.7444870601720963, 0.7692660513213518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 398}], {
             RGBColor[
             0.7100705314017086, 0.7665791120076357, 0.7708912737801167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 399}], {
             RGBColor[
             0.9603114409091467, 0.8681403292906987, 0.42659540071605706`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 360}], {
             RGBColor[
             0.1940919893072422, 0.3213333652777681, 0.9343646237064562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 370}], {
             RGBColor[
             0.19501122587610803`, 0.3222995411946109, 0.9344169728691645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 348}], {
             RGBColor[
             0.33468734849454873`, 0.4643110922158917, 0.9425469597870388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 366}], {
             RGBColor[
             0.36531722643847, 0.49084115298848774`, 0.9444986685246879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 353}], {
             RGBColor[
             0.1868676578718124, 0.31374013489006275`, 0.9339532087186491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 358}], {
             RGBColor[
             0.18639835798283702`, 0.3132468709514181, 0.933926482784239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 359}], {
             RGBColor[
             0.18461240578101906`, 0.3113697219513976, 0.933824775448425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 362}], {
             RGBColor[
             0.18559297832352872`, 0.3124003658654654, 0.9338806176040938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 369}], {
             RGBColor[
             0.18630927681020493`, 0.31315324099090924`, 0.9339214097432413]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 354}], {
             RGBColor[
             0.2035510812828702, 0.3312754706852238, 0.9349033050009957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 356}], {
             RGBColor[
             0.19312061469136133`, 0.3203123889677695, 0.9343093053591018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 388}], {
             RGBColor[
             0.20538183242077535`, 0.3331997062074885, 0.9350075635699459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 390}], {
             RGBColor[
             0.30688867117659013`, 0.43597701754892004`, 0.9409314950894052]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 380}], {
             RGBColor[
             0.20898774598358635`, 0.3369897499901277, 0.9352129150128767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 381}], {
             RGBColor[
             0.1970073353004369, 0.3243975787602278, 0.9345306483479008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 384}], {
             RGBColor[
             0.19370455937175246`, 0.32092615185109175`, 0.9343425601447813]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 366}], {
             RGBColor[
             0.3637695245894192, 0.4895006114365967, 0.9444000503314454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 355}], {
             RGBColor[
             0.879778802399924, 0.9043102631133229, 0.8644296794931206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 392}], {
             RGBColor[
             0.9924671913475096, 0.9911530042849124, 0.7745016638630496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 395}], {
             RGBColor[
             0.7312446954176929, 0.785613119798958, 0.8514446443288036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 379}], {
             RGBColor[
             0.22335212736306764`, 0.3520876255743447, 0.9360309452822404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 371}], {
             RGBColor[
             0.20120013846367035`, 0.3288044807238608, 0.9347694222853504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 388}], {
             RGBColor[
             0.21768345542489445`, 0.346129491952765, 0.93570812280141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 392}], {
             RGBColor[
             0.8783955245201162, 0.9037382421614023, 0.8873541737699352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 395}], {
             RGBColor[
             0.6171730285902994, 0.6981983576754478, 0.9642971542356892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 363}], {
             RGBColor[
             0.2074463229173425, 0.3353696166156383, 0.9351251332495853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 372}], {
             RGBColor[
             0.1945300591839852, 0.3217938044934594, 0.9343895711378705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 364}], {
             RGBColor[
             0.8373888047327049, 0.2883923138200816, 0.1834368676776406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 385}], {
             RGBColor[
             0.9257629036983032, 0.7151948013477634, 0.418460634800934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 359}], {
             RGBColor[
             0.18898988195831087`, 0.3159707269617513, 0.934074066240826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 362}], {
             RGBColor[
             0.18997045450082056`, 0.31700137087581914`, 0.9341299083964949]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 363}], {
             RGBColor[
             0.20533835444542115`, 0.3331540080987284, 0.9350050875635693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 369}], {
             RGBColor[
             0.19068675298749674`, 0.31775424600126295`, 0.9341707005356424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 372}], {
             RGBColor[
             0.19242209071206384`, 0.3195781959765495, 0.9342695254518545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 397}], {
             RGBColor[
             0.20184959481572412`, 0.3294871005277804, 0.9348064078638154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 362}], {
             RGBColor[
             0.18818450229900258`, 0.31512422187579864`, 0.9340282010606809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 369}], {
             RGBColor[
             0.18890080078567878`, 0.31587709700124245`, 0.9340689931998285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 394}], {
             RGBColor[
             0.18381809529055626`, 0.3105348512637273, 0.9337795406410702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 397}], {
             RGBColor[
             0.20006364261390616`, 0.32760995152775996`, 0.9347047005280014]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 370}], {
             RGBColor[
             0.18616848137367975`, 0.313005256060175, 0.9339133916514194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 393}], {
             RGBColor[
             0.20049962337211924`, 0.32806819494741857`, 0.934729528987206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 396}], {
             RGBColor[
             0.20859692759923504`, 0.3365789750888577, 0.935190658484052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 363}], {
             RGBColor[
             0.20453297478611288`, 0.3323075030127757, 0.9349592223834241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 369}], {
             RGBColor[
             0.18988137332818844`, 0.31690774091531027`, 0.9341248353554973]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 397}], {
             RGBColor[
             0.20104421515641585`, 0.32864059544182767`, 0.9347605426836703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 369}], {
             RGBColor[
             0.20524927327278905`, 0.33306037813821954`, 0.9350000145225716]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 372}], {
             RGBColor[
             0.20698461099735616`, 0.3348843281135061, 0.9350988394387836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 385}], {
             RGBColor[
             0.9060512192132981, 0.563682156680796, 0.3995847034769297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 370}], {
             RGBColor[
             0.18400910577117147`, 0.3107356153896179, 0.9337904184053665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 398}], {
             RGBColor[
             0.40058820107881166`, 0.5213910984512207, 0.9467461038398723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 372}], {
             RGBColor[
             0.19233300953943172`, 0.31948456601604064`, 0.9342644524108568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 389}], {
             RGBColor[
             0.194598112629328, 0.3218653329793524, 0.9343934466809067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 391}], {
             RGBColor[
             0.18383722908563283`, 0.3105549620955055, 0.9337806302823939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 380}], {
             RGBColor[
             0.24598769620290184`, 0.37587904360296687`, 0.9373200074413457]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 382}], {
             RGBColor[
             0.18605529017041303`, 0.3128862849288049, 0.9339069455798448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 384}], {
             RGBColor[
             0.18988847579037965`, 0.3169152060533953, 0.934125239830212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 389}], {
             RGBColor[
             0.19643386923101253`, 0.3237948295614139, 0.9344979903036141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 377}], {
             RGBColor[
             0.18266643619111367`, 0.3093243845308089, 0.9337139553590839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 379}], {
             RGBColor[
             0.19896021464386793`, 0.3264501787698757, 0.934641861937483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 381}], {
             RGBColor[
             0.20814382827755723`, 0.3361027389736181, 0.9351648551479828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 384}], {
             RGBColor[
             0.18572468011707222`, 0.3125387928008556, 0.9338881178264007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 389}], {
             RGBColor[
             0.1922700735577051, 0.31941841630887424`, 0.9342608682998029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 389}], {
             RGBColor[
             0.1961032591776717, 0.32344733743346465`, 0.93447916255017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 387}], {
             RGBColor[
             0.7642756795140044, 0.8115756260652711, 0.7955379877927361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 400}], {
             RGBColor[
             0.8054695470793142, 0.5998653041518983, 0.5862367210785956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 390}], {
             RGBColor[
             0.23267978688900162`, 0.3618915871438733, 0.9365621416932066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 395}], {
             RGBColor[
             0.729861417537885, 0.7850410988470374, 0.8743691386056183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 396}], {
             RGBColor[
             0.19146055662429076`, 0.3185675626855177, 0.9342147675080179]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.08420038484809576], {
             RGBColor[
             0.19354678877808446`, 0.32076032495391327`, 0.9343335753428726]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.08420038484809576], {
             RGBColor[
             0.18498575182454155`, 0.3117621323146461, 0.9338460369532876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.08420038484809576], {
             RGBColor[
             0.5818688834669836, 0.6714263983498019, 0.960225996443923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.08420038484809576], {
             RGBColor[
             0.23281884209063286`, 0.36203774297739677`, 0.9365700606812258]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.08420038484809576], {
             RGBColor[
             0.2824395297681887, 0.41419223185981874`, 0.9393958854372335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.08420038484809576], {
             RGBColor[
             0.30558851701585305`, 0.4385232851876776, 0.9407141860151303]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.08420038484809576], {
             RGBColor[
             0.4486453266434888, 0.5630157651939816, 0.9498082613856059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.08420038484809576], {
             RGBColor[
             0.2378122641398246, 0.36728614615234123`, 0.9368544286798214]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.08420038484809576], {
             RGBColor[
             0.19103464530579026`, 0.3181199028854364, 0.9341905124885087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.08420038484809576], {
             RGBColor[
             0.23750097993416716`, 0.3669589667156367, 0.9368367015048129]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.08420038484809576], {
             RGBColor[
             0.31196467996522614`, 0.44462985881031997`, 0.9410990914412173]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.08420038484809576], {
             RGBColor[
             0.3084761160714523, 0.441558334879467, 0.9408786305095267]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.08420038484809576], {
             RGBColor[
             0.21416269395992185`, 0.3424289484239088, 0.9355076206444797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.08420038484809576], {
             RGBColor[
             0.18454901891679482`, 0.31130309833813863`, 0.9338211656602798]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.08420038484809576], {
             RGBColor[
             0.28582560720535155`, 0.41775121393598635`, 0.9395887175380273]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.08420038484809576], {
             RGBColor[
             0.3177755060429437, 0.4496629042982282, 0.9414693521405777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.08420038484809576], {
             RGBColor[
             0.2316763474093035, 0.360836908628973, 0.9365049972992935]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.08420038484809576], {
             RGBColor[
             0.6051402883638863, 0.6903191732099512, 0.9620580066833722]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.08420038484809576], {
             RGBColor[
             0.26040419361571815`, 0.3910316964425663, 0.9381410056417089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.08420038484809576], {
             RGBColor[
             0.19028821830363388`, 0.31733536077996466`, 0.9341480045749757]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.08420038484809576], {
             RGBColor[
             0.9632021039744041, 0.8875341975281088, 0.3115475519504825]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.08420038484809576], {
             RGBColor[
             0.3162753653274515, 0.4483635578097335, 0.9413737645007089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.08420038484809576], {
             RGBColor[
             0.2930562064900811, 0.4253510322307103, 0.9400004894705796]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.08420038484809576], {
             RGBColor[
             0.8207868509580615, 0.16078242208563953`, 0.1675388179938171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.08420038484809576], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.08420038484809576], {
             RGBColor[
             0.18699939157323073`, 0.3138785953626525, 0.9339607107580624]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.08420038484809576], {
             RGBColor[
             0.821038236612611, 0.16271468238440395`, 0.16777954518051325`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.08420038484809576], {
             RGBColor[
             0.20698871416859752`, 0.3348886408066369, 0.9350990731083157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.08420038484809576], {
             RGBColor[
             0.1814383294461641, 0.30803356647540187`, 0.9336440164967801]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.08420038484809576], {
             RGBColor[
             0.18021067351487519`, 0.3067432222537355, 0.9335741033076473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.08420038484809576], {
             RGBColor[
             0.19647646719475834`, 0.3238396027221777, 0.9345004161946314]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.08420038484809576], {
             RGBColor[
             0.9570322462930174, 0.8667218188173162, 0.28757881993815293`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.08420038484809576], {
             RGBColor[
             0.2765417318743941, 0.4079932723314563, 0.939060014572192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.08420038484809576], {
             RGBColor[
             0.2632481201845229, 0.3940208435817391, 0.93830296305259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.08420038484809576], {
             RGBColor[
             0.2362515342121432, 0.36564572004235524`, 0.9367655474193329]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.08420038484809576], {
             RGBColor[
             0.19287789451893317`, 0.32005727467719974`, 0.9342954828043544]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.08420038484809576], {
             RGBColor[
             0.34879862256835453`, 0.4765335685653648, 0.9434461176929121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.08420038484809576], {
             RGBColor[
             0.22292982485851465`, 0.3516437588665342, 0.9360068957793466]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.08420038484809576], {
             RGBColor[
             0.18317563345981333`, 0.30985958314518375`, 0.9337429533902465]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.08420038484809576], {
             RGBColor[
             0.5210599224495296, 0.6220589443833571, 0.9554388922820652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.08420038484809576], {
             RGBColor[
             0.8718710063158469, 0.90067029040099, 0.9876410289824828]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.08420038484809576], {
             RGBColor[
             0.21651396498896067`, 0.34490028335462225`, 0.9356415220511897]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.08420038484809576], {
             RGBColor[
             0.26035980612556775`, 0.3909850423760888, 0.9381384778398102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.08420038484809576], {
             RGBColor[
             0.2366745638317519, 0.36609035099419096`, 0.9367896383303533]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.08420038484809576], {
             RGBColor[
             0.2848093981590889, 0.41668311379698936`, 0.9395308459361892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.08420038484809576], {
             RGBColor[
             0.20129344185623907`, 0.3289025485052273, 0.9347747357755273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.08420038484809576], {
             RGBColor[
             0.5441036538714303, 0.6407668836599264, 0.9572529792315668]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.08420038484809576], {
             RGBColor[
             0.24018804114120323`, 0.3697832384137522, 0.9369897256654027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.08420038484809576], {
             RGBColor[
             0.18767785554878408`, 0.3145917040180597, 0.9339993482777726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.08420038484809576], {
             RGBColor[
             0.1790362447681438, 0.3055088231778375, 0.9335072213279326]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.08420038484809576], {
             RGBColor[
             0.381577964086101, 0.5049253866504279, 0.9455347883487892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.08420038484809576], {
             RGBColor[
             0.17936539842637753`, 0.30585478454218845`, 0.9335259661418299]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.08420038484809576], {
             RGBColor[
             0.19239706134193654`, 0.319551888521592, 0.9342681000662533]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.08420038484809576], {
             RGBColor[
             0.1846123721443362, 0.31136968659711123`, 0.9338247735328656]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.08420038484809576], {
             RGBColor[
             0.9716313250190438, 0.9159679393868991, 0.3442934839840799]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.08420038484809576], {
             RGBColor[
             0.38165040818030865`, 0.5049881340836845, 0.9455394044224124]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.08420038484809576], {
             RGBColor[
             0.21768082531414856`, 0.3461267275396124, 0.9357079730204939]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.08420038484809576], {
             RGBColor[
             0.21195870855243037`, 0.3401124200198894, 0.9353821069360272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.08420038484809576], {
             RGBColor[
             0.3465121371910148, 0.4745531298536097, 0.9433004248665277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.08420038484809576], {
             RGBColor[
             0.186004909472108, 0.3128333316205655, 0.9339040764736078]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.08420038484809576], {
             RGBColor[
             0.20936457771848743`, 0.3373858240360207, 0.9352343750227069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.08420038484809576], {
             RGBColor[
             0.20110579749352597`, 0.32870532238267614`, 0.9347640497066657]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.08420038484809576], {
             RGBColor[
             0.1811814280726413, 0.30776354684334156`, 0.9336293863436095]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.08420038484809576], {
             RGBColor[
             0.18064334912177313`, 0.30719799174980317`, 0.933598743543374]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.08420038484809576], {
             RGBColor[
             0.2879462259501837, 0.4199801186917991, 0.9397094836383711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.08420038484809576], {
             RGBColor[
             0.2142707962291993, 0.34254257076299915`, 0.935513776908792]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.08420038484809576], {
             RGBColor[
             0.42522253205912725`, 0.5427281177888938, 0.9483157816266544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.08420038484809576], {
             RGBColor[
             0.27002626100566185`, 0.40114509934370585`, 0.9386889681449931]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.08420038484809576], {
             RGBColor[
             0.2418162773238607, 0.37149461787786187`, 0.9370824513072455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.08420038484809576], {
             RGBColor[
             0.22291581655962178`, 0.35162903525622036`, 0.9360060980274482]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.08420038484809576], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.08420038484809576], {
             RGBColor[
             0.18281412095909713`, 0.3094796105857146, 0.9337223657881405]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.08420038484809576], {
             RGBColor[
             0.9306153171117766, 0.762619883962795, 0.26302965936154776`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.08420038484809576], {
             RGBColor[
             0.8630600513163033, 0.8936446740513561, 0.986800632228994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.08420038484809576], {
             RGBColor[
             0.21796667840296896`, 0.34642717726009525`, 0.9357242519310205]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.08420038484809576], {
             RGBColor[
             0.1938965482594379, 0.32112794434484765`, 0.9343534936279129]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.08420038484809576], {
             RGBColor[
             0.18280925758947733`, 0.30947449887588874`, 0.9337220888264354]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.08420038484809576], {
             RGBColor[
             0.8199375785531087, 0.1542545422276314, 0.1667255537797183]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.08420038484809576], {
             RGBColor[
             0.23104392871496413`, 0.36017219648356114`, 0.9364689819902305]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.08420038484809576], {
             RGBColor[
             0.1798079986201722, 0.3063199854083397, 0.9335511715680982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.08420038484809576], {
             RGBColor[
             0.17955783501139488`, 0.30605704759422586`, 0.9335369251206622]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.08420038484809576], {
             RGBColor[
             0.1807265568208277, 0.30728544831718235`, 0.9336034820987404]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.08420038484809576], {
             RGBColor[
             0.9450344910434499, 0.9585273939347413, 0.9779264487494559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.08420038484809576], {
             RGBColor[
             0.3388378220394789, 0.4679060237916442, 0.9428114242912021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.08420038484809576], {
             RGBColor[
             0.24074527521724318`, 0.3703689267583512, 0.9370214593216792]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.08420038484809576], {
             RGBColor[
             0.4110226556238299, 0.5304288985271809, 0.947410978056655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.08420038484809576], {
             RGBColor[
             0.19817896485079942`, 0.32562903570326285`, 0.9345973709175234]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.08420038484809576], {
             RGBColor[
             0.19146940577852636`, 0.3185768637076881, 0.9342152714542605]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.08420038484809576], {
             RGBColor[
             0.1892450123424645, 0.31623888517169746`, 0.934088595538772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.08420038484809576], {
             RGBColor[
             0.6083786689975903, 0.6929482364957771, 0.9623129438694364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.08420038484809576], {
             RGBColor[
             0.4932978290383352, 0.5995204262840937, 0.953253358592837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.08420038484809576], {
             RGBColor[
             0.49739045300864126`, 0.6028430027937971, 0.9535755449435551]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.08420038484809576], {
             RGBColor[
             0.2343202347626608, 0.3636158018694917, 0.9366555627727864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.08420038484809576], {
             RGBColor[
             0.18118663655961964`, 0.30776902129339295`, 0.9336296829592377]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.08420038484809576], {
             RGBColor[
             0.559409915392181, 0.6531931963016955, 0.9584579442071637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.08420038484809576], {
             RGBColor[
             0.7481991240396009, 0.803218109314472, 0.9755371544320737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.08420038484809576], {
             RGBColor[
             0.19288958051724012`, 0.32006955740235543`, 0.93429614830467]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.08420038484809576], {
             RGBColor[
             0.20101540430520026`, 0.32861031341048663`, 0.9347589019483153]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.08420038484809576], {
             RGBColor[
             0.965636915117815, 0.9738926480760296, 0.9430519187643377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.08420038484809576], {
             RGBColor[
             0.2101475089071078, 0.33820873435596516`, 0.9352789617956558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.08420038484809576], {
             RGBColor[
             0.1831002535865883, 0.30978035411906424`, 0.9337386606179808]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.08420038484809576], {
             RGBColor[
             0.2774713947406823, 0.40897040694795533`, 0.9391129574971142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.08420038484809576], {
             RGBColor[
             0.19434739415987903`, 0.3216018119714924, 0.9343791686349763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.08420038484809576], {
             RGBColor[
             0.8190091230934095, 0.14711802671260676`, 0.16583646378296987`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.08420038484809576], {
             RGBColor[
             0.20947576509879728`, 0.3375026890224135, 0.9352407069795285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.08420038484809576], {
             RGBColor[
             0.22681870684301533`, 0.35573122040160343`, 0.9362283618552786]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.08420038484809576], {
             RGBColor[
             0.34861868121472545`, 0.4763777124089667, 0.9434346519889747]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.08420038484809576], {
             RGBColor[
             0.256153514960176, 0.38656396366699863`, 0.9378989357805914]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.08420038484809576], {
             RGBColor[
             0.18132254229683142`, 0.30791186684012395`, 0.9336374225899173]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.08420038484809576], {
             RGBColor[
             0.18343408206602244`, 0.3101312290168976, 0.9337576716560296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.08420038484809576], {
             RGBColor[
             0.18925042984728385`, 0.3162445793127523, 0.934088904057657]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.08420038484809576], {
             RGBColor[
             0.937107871400364, 0.788360698201582, 0.2682537209419814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.08420038484809576], {
             RGBColor[
             0.30752560771325343`, 0.4405592903292892, 0.9408245004646784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.08420038484809576], {
             RGBColor[
             0.24129060741956473`, 0.3709421054790498, 0.9370525151838548]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.08420038484809576], {
             RGBColor[
             0.8646080428941941, 0.47809856902505976`, 0.2087379710414105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.08420038484809576], {
             RGBColor[
             0.18333815129494635`, 0.31003039969413443`, 0.9337522085405336]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.08420038484809576], {
             RGBColor[
             0.22614100723621103`, 0.3550189151462153, 0.9361897678652379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.08420038484809576], {
             RGBColor[
             0.2388812891503496, 0.36840975921850344`, 0.93691530807269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.08420038484809576], {
             RGBColor[
             0.18241596627536708`, 0.30906112476864933`, 0.9336996914679191]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.08420038484809576], {
             RGBColor[
             0.5182991743784003, 0.6198176447289311, 0.9552215560809526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.08420038484809576], {
             RGBColor[
             0.3109061797336599, 0.4437130391115059, 0.9410316447424569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.08420038484809576], {
             RGBColor[
             0.5979628209588992, 0.6844921818293608, 0.9614929701573222]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.08420038484809576], {
             RGBColor[
             0.21169783120855037`, 0.3398382213908926, 0.9353672503572267]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.08420038484809576], {
             RGBColor[
             0.3097296345397099, 0.44269397479938727`, 0.9409566763230764]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.08420038484809576], {
             RGBColor[
             0.2615118954900493, 0.3921959613448436, 0.9382040876247539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.08420038484809576], {
             RGBColor[
             0.1865862227024127, 0.3134443286830033, 0.9339371814020978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.08420038484809576], {
             RGBColor[
             0.19480415931956344`, 0.32208190111490453`, 0.9344051807350968]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.08420038484809576], {
             RGBColor[
             0.19461177340916913`, 0.32187969132510885`, 0.9343942246421093]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.08420038484809576], {
             RGBColor[
             0.189088316742455, 0.3160741881610126, 0.9340796719561618]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.08420038484809576], {
             RGBColor[
             0.1820121662584413, 0.30863670534846055`, 0.9336766956543238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.08420038484809576], {
             RGBColor[
             0.21325644631447746`, 0.3414764246891273, 0.9354560111817448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.08420038484809576], {
             RGBColor[
             0.35827341580975897`, 0.4847401582541144, 0.9440498431400237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.08420038484809576], {
             RGBColor[
             0.18578718983175693`, 0.312604494474334, 0.9338916776621772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.08420038484809576], {
             RGBColor[
             0.830968185180272, 0.8680554911049849, 0.9837396813881922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.08420038484809576], {
             RGBColor[
             0.9948422584139026, 0.9913764372120322, 0.679989842123797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.08420038484809576], {
             RGBColor[
             0.18458947116943916`, 0.3113456162204888, 0.9338234693562242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.08420038484809576], {
             RGBColor[
             0.33446348254021346`, 0.46411719077807645`, 0.9425326952463855]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.08420038484809576], {
             RGBColor[
             0.18225239431662393`, 0.3088892002689491, 0.9336903762868517]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.08420038484809576], {
             RGBColor[
             0.18805967833656198`, 0.31499302397697726`, 0.9340210925206803]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.08420038484809576], {
             RGBColor[
             0.2256991535454318, 0.35455449890206425`, 0.9361646049512119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.08420038484809576], {
             RGBColor[
             0.8655975347340893, 0.482591620368333, 0.20956362728728348`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.08420038484809576], {
             RGBColor[
             0.18248883410320854`, 0.3091377134757978, 0.9337038411829164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.08420038484809576], {
             RGBColor[
             0.18504307948317125`, 0.3118223873186494, 0.9338493016786379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.08420038484809576], {
             RGBColor[
             0.1905501321581982, 0.3176106488474093, 0.9341629201815262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.08420038484809576], {
             RGBColor[
             0.1972575262297792, 0.3246605452899877, 0.9345448963512025]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.08420038484809576], {
             RGBColor[
             0.18614238840660097`, 0.3129778306973855, 0.9339119056955454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.08420038484809576], {
             RGBColor[
             0.1834762116557925, 0.31017550988691617`, 0.9337600708738418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.08420038484809576], {
             RGBColor[
             0.33397821749630197`, 0.46369687858717057`, 0.9425017745868906]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.08420038484809576], {
             RGBColor[
             0.21660346779159745`, 0.34499435647499893`, 0.9356466191033923]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.08420038484809576], {
             RGBColor[
             0.19354588592399127`, 0.3207593759970171, 0.9343335239266677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.08420038484809576], {
             RGBColor[
             0.19201931518110454`, 0.3191548533560677, 0.9342465879812193]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.08420038484809576], {
             RGBColor[
             0.25676930210776144`, 0.3872111950022711, 0.9379340039476709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.08420038484809576], {
             RGBColor[
             0.1824446187841665, 0.30909124037207153`, 0.9337013231859077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.08420038484809576], {
             RGBColor[
             0.2055125320888361, 0.33333707984545796`, 0.935015006722689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.08420038484809576], {
             RGBColor[
             0.2070813101039675, 0.3349859650056321, 0.9351043463098516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.08420038484809576], {
             RGBColor[
             0.8309858670902185, 0.23917652931476524`, 0.17730540736011186`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.08420038484809576], {
             RGBColor[
             0.1873941802353717, 0.31429354327760956`, 0.9339831933883338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.08420038484809576], {
             RGBColor[
             0.3387561380668311, 0.4678352732400925, 0.9428062194606953]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.08420038484809576], {
             RGBColor[
             0.1805122222555836, 0.3070601690995145, 0.9335912760623294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.08420038484809576], {
             RGBColor[
             0.4596234812344611, 0.572182073724828, 0.9506023905805157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.08420038484809576], {
             RGBColor[
             0.1994550789542851, 0.32697031253633363`, 0.9346700437278752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.08420038484809576], {
             RGBColor[
             0.27232886945688745`, 0.40356528681975196`, 0.9388200982898864]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.08420038484809576], {
             RGBColor[
             0.26679472020223177`, 0.3977485450677799, 0.938504936676874]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.08420038484809576], {
             RGBColor[
             0.20095261322947336`, 0.32854431600871353`, 0.9347553260894438]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.08420038484809576], {
             RGBColor[
             0.8967495440562933, 0.920507761085305, 0.9900139661214994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.08420038484809576], {
             RGBColor[
             0.9896948922783259, 0.9900065873749687, 0.82044583391943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.08420038484809576], {
             RGBColor[
             0.3102543804501736, 0.4431484833325346, 0.9409901126684767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.08420038484809576], {
             RGBColor[
             0.18420503135956878`, 0.31094154560542325`, 0.9338015760777798]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.08420038484809576], {
             RGBColor[
             0.8957887014800139, 0.9197416112963568, 0.9899223200988196]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.08420038484809576], {
             RGBColor[
             0.2316644133079956, 0.36082436513183264`, 0.936504317669879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.08420038484809576], {
             RGBColor[
             0.188962757776349, 0.315942217726737, 0.93407252155879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.08420038484809576], {
             RGBColor[
             0.8238032261936802, 0.18396760393066158`, 0.17042730232595416`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.08420038484809576], {
             RGBColor[
             0.2824798268544749, 0.4142345866524884, 0.9393981802966833]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.08420038484809576], {
             RGBColor[
             0.34399645769565007`, 0.4723741747164527, 0.943140127993611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.08420038484809576], {
             RGBColor[
             0.28165135838121924`, 0.41336381375916165`, 0.9393510002427407]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.08420038484809576], {
             RGBColor[
             0.23366891778676377`, 0.3629312264319425, 0.9366184712345461]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.08420038484809576], {
             RGBColor[
             0.8948525196191675, 0.9189951252924975, 0.9898330262371927]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.08420038484809576], {
             RGBColor[
             0.44169024668361, 0.5569916245052177, 0.9493650898406981]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.08420038484809576], {
             RGBColor[
             0.45394807471440896`, 0.5675745230376996, 0.950155601789558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.08420038484809576], {
             RGBColor[
             0.2585433275657887, 0.3890758082383683, 0.93803503207307]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.08420038484809576], {
             RGBColor[
             0.19492367816056405`, 0.3222075229947284, 0.9344119871562795]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.08420038484809576], {
             RGBColor[
             0.34853172220347034`, 0.47630239288410453`, 0.9434291110376724]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.08420038484809576], {
             RGBColor[
             0.3499869056482099, 0.4775627996442913, 0.943521834040003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.08420038484809576], {
             RGBColor[
             0.18311045325504194`, 0.3097910746173054, 0.9337392414740102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.08420038484809576], {
             RGBColor[
             0.3996003392677278, 0.5205354622018381, 0.9466831581588019]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.08420038484809576], {
             RGBColor[
             0.20685160848485196`, 0.33474453404001786`, 0.9350912651424561]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.08420038484809576], {
             RGBColor[
             0.43492032413853554`, 0.551127857862875, 0.9489337163625334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.08420038484809576], {
             RGBColor[
             0.2017846044041309, 0.3294187914845658, 0.9348027067560198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.08420038484809576], {
             RGBColor[
             0.266643234211289, 0.39758932368653244`, 0.9384963097737932]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.08420038484809576], {
             RGBColor[
             0.9562193148935751, 0.9668690172486966, 0.9589934594404549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.08420038484809576], {
             RGBColor[
             0.20722377740839654`, 0.33513570717553587`, 0.9351124596120775]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.08420038484809576], {
             RGBColor[
             0.18162114890697434`, 0.30822572132013676`, 0.933654427794616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.08420038484809576], {
             RGBColor[
             0.18694492825143932`, 0.3138213509582757, 0.9339576091524576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.08420038484809576], {
             RGBColor[
             0.9945316676487347, 0.9907121149708813, 0.6461839540792844]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.08420038484809576], {
             RGBColor[
             0.20184829587443234`, 0.32948573525812513`, 0.9348063338910304]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.08420038484809576], {
             RGBColor[
             0.18973547474422028`, 0.3167543922530552, 0.9341165266469779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.08420038484809576], {
             RGBColor[
             0.9643115115712477, 0.9729041642811488, 0.9452954812480678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.08420038484809576], {
             RGBColor[
             0.3533082208089774, 0.4804395559023944, 0.9437334653051234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.08420038484809576], {
             RGBColor[
             0.18648980339442428`, 0.3133429858769703, 0.9339316904651475]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.08420038484809576], {
             RGBColor[
             0.1842143453500115, 0.31095133519991963`, 0.9338021064957567]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.08420038484809576], {
             RGBColor[
             0.9490437648216794, 0.9615175037539616, 0.971139794028986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.08420038484809576], {
             RGBColor[
             0.2433593553333951, 0.37311649070267905`, 0.9371703273171091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.08420038484809576], {
             RGBColor[
             0.2257570420476589, 0.35461534338824796`, 0.9361679016157753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.08420038484809576], {
             RGBColor[
             0.19363457114614188`, 0.3208525897884652, 0.9343385744188711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.08420038484809576], {
             RGBColor[
             0.3500177192487492, 0.4775894888363419, 0.943523797455382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.08420038484809576], {
             RGBColor[
             0.7303132143006519, 0.7892455006884563, 0.9737544541026248]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.08420038484809576], {
             RGBColor[
             0.18775722726537172`, 0.31467512872465075`, 0.9340038683796124]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.08420038484809576], {
             RGBColor[
             0.9930152754848626, 0.9913796511608278, 0.7654184913108293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.08420038484809576], {
             RGBColor[
             0.33484250288537293`, 0.4644454791509371, 0.9425568460876246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.08420038484809576], {
             RGBColor[
             0.3056537490672848, 0.4385918482096833, 0.9407179008839572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.08420038484809576], {
             RGBColor[
             0.22188954865981286`, 0.3505503626243781, 0.9359476535887813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.08420038484809576], {
             RGBColor[
             0.41733642177677943`, 0.535897565429752, 0.9478132856528767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.08420038484809576], {
             RGBColor[
             0.22261848399738943`, 0.3513165198813409, 0.9359891653778931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.08420038484809576], {
             RGBColor[
             0.23974505627195325`, 0.36931763322930755`, 0.9369644983324363]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.08420038484809576], {
             RGBColor[
             0.18299643202543156`, 0.30967123107562133`, 0.9337327481336631]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.08420038484809576], {
             RGBColor[
             0.1997106484206986, 0.3272389322495743, 0.9346845980309063]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.08420038484809576], {
             RGBColor[
             0.9930695883095065, 0.987584875103169, 0.4870456409120508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.08420038484809576], {
             RGBColor[
             0.19086057119328328`, 0.3179369399562554, 0.934180599225321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.08420038484809576], {
             RGBColor[
             0.3371253879726633, 0.4664227994724073, 0.9427023095067106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.08420038484809576], {
             RGBColor[
             0.635822518194204, 0.7152283896049052, 0.9644734242083259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.08420038484809576], {
             RGBColor[
             0.9023083761464576, 0.6492869771870501, 0.2401960532268301]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.08420038484809576], {
             RGBColor[
             0.23238602207295528`, 0.3615828216964435, 0.9365454122215189]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.08420038484809576], {
             RGBColor[
             0.9299021495647822, 0.7597924122879596, 0.2624558280130423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.08420038484809576], {
             RGBColor[
             0.1793343425625045, 0.3058221428602024, 0.9335241975563253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.08420038484809576], {
             RGBColor[
             0.884710274500928, 0.9109079743391231, 0.9888656498437259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.08420038484809576], {
             RGBColor[
             0.44524034591787487`, 0.5600665420287623, 0.9495912990246761]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.08420038484809576], {
             RGBColor[
             0.20746958876179836`, 0.3353940704933011, 0.9351264582050084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.08420038484809576], {
             RGBColor[
             0.20359531165465325`, 0.33132195961033534`, 0.9349058238552358]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.08420038484809576], {
             RGBColor[
             0.20688302376209858`, 0.33477755348824767`, 0.9350930541960206]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.08420038484809576], {
             RGBColor[
             0.8177383166445533, 0.1373500514757623, 0.1646195380923747]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.08420038484809576], {
             RGBColor[
             0.18219295480676673`, 0.3088267255754066, 0.9336869912946982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.08420038484809576], {
             RGBColor[
             0.295092829761857, 0.42749165241872045`, 0.9401164721529931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.08420038484809576], {
             RGBColor[
             0.9594063537213845, 0.9692459055881796, 0.9535986340178257]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.08420038484809576], {
             RGBColor[
             0.7857227396767522, 0.8325318430402561, 0.9792771577606599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.08420038484809576], {
             RGBColor[
             0.1915139828942802, 0.31862371708269777`, 0.9342178100550568]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.08420038484809576], {
             RGBColor[
             0.25077535368791876`, 0.38091117517473666`, 0.9375926574524128]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.08420038484809576], {
             RGBColor[
             0.19733278810728, 0.3247396502951197, 0.9345491824037863]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.08420038484809576], {
             RGBColor[
             0.28998218143607674`, 0.4221200369945062, 0.9398254282913666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.08420038484809576], {
             RGBColor[
             0.82776291630336, 0.2144035172609302, 0.17421910604681382`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.08420038484809576], {
             RGBColor[
             0.8316889234682268, 0.24458052871740593`, 0.17797865494168116`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.08420038484809576], {
             RGBColor[
             0.2632132370288079, 0.3939841791733627, 0.938300976508477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.08420038484809576], {
             RGBColor[
             0.852273426221674, 0.40280203706702433`, 0.19769039802525293`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.08420038484809576], {
             RGBColor[
             0.9695261963263196, 0.9767932676332187, 0.9364683801653377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.08420038484809576], {
             RGBColor[
             0.9547654228714991, 0.9657847069591619, 0.9614545193980599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.08420038484809576], {
             RGBColor[
             0.818830055518114, 0.14574163486097447`, 0.1656649884706391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.08420038484809576], {
             RGBColor[
             0.9202453542726101, 0.9392426823750178, 0.9922550174748891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.08420038484809576], {
             RGBColor[
             0.1976279917679603, 0.3250499280594878, 0.9345659938155473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.08420038484809576], {
             RGBColor[
             0.21799885977606132`, 0.3464610019236322, 0.9357260846126101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.08420038484809576], {
             RGBColor[
             0.3090764058516128, 0.442128180941986, 0.9409150531686984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.08420038484809576], {
             RGBColor[
             0.25834749102875554`, 0.38886997162119286`, 0.9380238794720002]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.08420038484809576], {
             RGBColor[
             0.19027393338711107`, 0.3173203464269832, 0.9341471910701123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.08420038484809576], {
             RGBColor[
             0.3695662131784596, 0.4945214117423836, 0.9447694102025287]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.08420038484809576], {
             RGBColor[
             0.19109293756035423`, 0.31818117174092553`, 0.9341938321461705]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.08420038484809576], {
             RGBColor[
             0.18724741023772068`, 0.314139278704323, 0.9339748350540943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.08420038484809576], {
             RGBColor[
             0.8353613957275855, 0.2728087597904426, 0.18149541852470724`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.08420038484809576], {
             RGBColor[
             0.3513087838325387, 0.47870774408802763`, 0.9436060629490174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.08420038484809576], {
             RGBColor[
             0.32310439559809073`, 0.45427852059311985`, 0.9418089042708796]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.08420038484809576], {
             RGBColor[
             0.18340786605487358`, 0.31010367432698904`, 0.9337561786929778]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.08420038484809576], {
             RGBColor[
             0.18623692915551526`, 0.3130771990187241, 0.9339172896513356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.08420038484809576], {
             RGBColor[
             0.22458179928431016`, 0.35338008872927346`, 0.9361009732790185]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.08420038484809576], {
             RGBColor[
             0.2599700418165058, 0.39057537537478015`, 0.9381162813390138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.08420038484809576], {
             RGBColor[
             0.2141514811516508, 0.34241716305148284`, 0.9355069820916365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.08420038484809576], {
             RGBColor[
             0.3919526428400527, 0.5139114119405849, 0.9461958537050229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.08420038484809576], {
             RGBColor[
             0.7232916660208124, 0.7837602138065023, 0.9730546117901898]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.08420038484809576], {
             RGBColor[
             0.18998272969436467`, 0.3170142728825262, 0.9341306074506077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.08420038484809576], {
             RGBColor[
             0.23275233921967517`, 0.3619678442434947, 0.9365662734411069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.08420038484809576], {
             RGBColor[
             0.2559867658273416, 0.386388699755884, 0.9378894396641596]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.08420038484809576], {
             RGBColor[
             0.679362894162589, 0.7494427233598264, 0.9686762023490751]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.08420038484809576], {
             RGBColor[
             0.743581503407994, 0.7996107889818441, 0.9750769131616334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.08420038484809576], {
             RGBColor[
             0.3590992451452233, 0.4854554501171043, 0.9441024642550272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.08420038484809576], {
             RGBColor[
             0.17909981633317154`, 0.30557564092335165`, 0.9335108416345153]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.08420038484809576], {
             RGBColor[
             0.7409332819620127, 0.7975419782610151, 0.9748129631969344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.08420038484809576], {
             RGBColor[
             0.1818250295794584, 0.30844001283369876`, 0.9336660384972996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.08420038484809576], {
             RGBColor[
             0.49307848673520527`, 0.5993423543211548, 0.9532360911632574]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.08420038484809576], {
             RGBColor[
             0.23875032994207512`, 0.36827211278731364`, 0.9369078501395155]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.08420038484809576], {
             RGBColor[
             0.22285712514090053`, 0.35156734685389346`, 0.9360027556379781]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.08420038484809576], {
             RGBColor[
             0.20781531186542476`, 0.3357574473953233, 0.9351461466243084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.08420038484809576], {
             RGBColor[
             0.25816588373595994`, 0.3886790908418973, 0.9380135372053394]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.08420038484809576], {
             RGBColor[
             0.6722342021283076, 0.7438737349625797, 0.9679656809485127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.08420038484809576], {
             RGBColor[
             0.2515360626002474, 0.3817107284733248, 0.937635978699602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.08420038484809576], {
             RGBColor[
             0.4286879330306734, 0.5457296739343299, 0.9485365939122276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.08420038484809576], {
             RGBColor[
             0.2671426063657563, 0.39811419548290095`, 0.9385247482792353]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.08420038484809576], {
             RGBColor[
             0.20898033639140454`, 0.33698196203894937`, 0.9352124930475636]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.08420038484809576], {
             RGBColor[
             0.2765987024765969, 0.40805315204651627`, 0.939063258963707]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.08420038484809576], {
             RGBColor[
             0.9941990383585994, 0.9900006545532618, 0.6099793085980734]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.08420038484809576], {
             RGBColor[
             0.1948453625020903, 0.32212520827217295`, 0.9344075271953871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.08420038484809576], {
             RGBColor[
             0.1899324083338537, 0.31696138194207063`, 0.9341277417235704]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.08420038484809576], {
             RGBColor[
             0.30537118422496984`, 0.4382948546447645, 0.9407018092342045]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.08420038484809576], {
             RGBColor[
             0.1861676814246589, 0.31300441526303435`, 0.9339133460955061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.08420038484809576], {
             RGBColor[
             0.19821724293608944`, 0.32566926839787347`, 0.9345995507978533]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.08420038484809576], {
             RGBColor[
             0.18717515147111807`, 0.3140633301591533, 0.9339707200242335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.08420038484809576], {
             RGBColor[
             0.1943854920349882, 0.321641855253777, 0.934381338252603]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.08420038484809576], {
             RGBColor[
             0.3488943015599562, 0.47661644089892424`, 0.9434522142736513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.08420038484809576], {
             RGBColor[
             0.1899597624904289, 0.3169901328949849, 0.9341292995023205]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.08420038484809576], {
             RGBColor[
             0.4290348579738498, 0.5460301628831548, 0.9485586996628331]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.08420038484809576], {
             RGBColor[
             0.2449605595581574, 0.37479945786511576`, 0.9372615135289399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.08420038484809576], {
             RGBColor[
             0.20692052412863532`, 0.33481696875113837`, 0.935095189786418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.08420038484809576], {
             RGBColor[
             0.19699767297971368`, 0.3243874230485212, 0.9345300980930298]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.08420038484809576], {
             RGBColor[
             0.18766218808016377`, 0.31457523651516484`, 0.9339984560386126]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.08420038484809576], {
             RGBColor[
             0.9146994662552146, 0.9348205418090667, 0.9917260457249173]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.08420038484809576], {
             RGBColor[
             0.18269671784651187`, 0.30935621247060024`, 0.933715679854561]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.08420038484809576], {
             RGBColor[
             0.19137511524925596`, 0.3184777583830601, 0.9342099017481089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.08420038484809576], {
             RGBColor[
             0.21323548342695858`, 0.34145439136522115`, 0.9354548173763124]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.08420038484809576], {
             RGBColor[
             0.1808905282724361, 0.3074577927092133, 0.9336128200303355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.08420038484809576], {
             RGBColor[
             0.18223318953702214`, 0.3088690148279342, 0.9336892826030643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.08420038484809576], {
             RGBColor[
             0.20271236623405806`, 0.3303939279913168, 0.9348555414197336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.08420038484809576], {
             RGBColor[
             0.3483545068205488, 0.47614889782652203`, 0.9434178190301781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.08420038484809576], {
             RGBColor[
             0.20150049615977755`, 0.32912017570624735`, 0.9347865272118044]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.08420038484809576], {
             RGBColor[
             0.2975965440226766, 0.4301232148514946, 0.9402590549762334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.08420038484809576], {
             RGBColor[
             0.27959908951497947`, 0.4112067490593821, 0.9392341265668681]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.08420038484809576], {
             RGBColor[
             0.3027440138032642, 0.4355335319593264, 0.9405521957652387]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.08420038484809576], {
             RGBColor[
             0.3029090080003519, 0.4357069513217019, 0.9405615919406759]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.08420038484809576], {
             RGBColor[
             0.218367213855187, 0.3468481654157909, 0.9357470618324852]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.08420038484809576], {
             RGBColor[
             0.23267428983588884`, 0.3618858093925185, 0.936561828644164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.08420038484809576], {
             RGBColor[
             0.2188459842157359, 0.34735138342052185`, 0.9357743270962412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.08420038484809576], {
             RGBColor[
             0.23435379828218117`, 0.36365107925655765`, 0.9366574741655703]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.08420038484809576], {
             RGBColor[
             0.1953540422101205, 0.32265986289746895`, 0.9344364957522352]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.08420038484809576], {
             RGBColor[
             0.19439044372267295`, 0.3216470597914888, 0.9343816202438913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.08420038484809576], {
             RGBColor[
             0.4533617737780597, 0.567098537525015, 0.9501094460321575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.08420038484809576], {
             RGBColor[
             0.19579265616170655`, 0.32312087397031664`, 0.9344614741679068]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.08420038484809576], {
             RGBColor[
             0.5543615420614805, 0.6490946994052059, 0.9580605177657702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.08420038484809576], {
             RGBColor[
             0.1999051049994005, 0.32744331844304914`, 0.9346956720453906]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.08420038484809576], {
             RGBColor[
             0.3986910652219958, 0.5197478947248675, 0.9466252200206473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.08420038484809576], {
             RGBColor[
             0.6331296311169758, 0.713042182562431, 0.9642614302732361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.08420038484809576], {
             RGBColor[
             0.289139123347183, 0.42123392949010874`, 0.9397774173803968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.08420038484809576], {
             RGBColor[
             0.19201165546058205`, 0.31914680250414423`, 0.9342461517714671]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.08420038484809576], {
             RGBColor[
             0.19560708734050541`, 0.3229258293734914, 0.9344509062980639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.08420038484809576], {
             RGBColor[
             0.8695307562797816, 0.5004514607800906, 0.21284560375709155`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.08420038484809576], {
             RGBColor[
             0.19044334897469703`, 0.3174984129511047, 0.9341568390371975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.08420038484809576], {
             RGBColor[
             0.18593025704413854`, 0.31275486718553225`, 0.9338998251282734]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.08420038484809576], {
             RGBColor[
             0.19914754728651962`, 0.3266470772548782, 0.9346525302543484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.08420038484809576], {
             RGBColor[
             0.2283446787479909, 0.35733511362593967`, 0.9363152636977938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.08420038484809576], {
             RGBColor[
             0.18811264277564865`, 0.31504869296059673`, 0.9340241087671325]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.08420038484809576], {
             RGBColor[
             0.1849809522741401, 0.31175708768286514`, 0.9338457636259925]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.08420038484809576], {
             RGBColor[
             0.1795029989097729, 0.3059994113746115, 0.9335338022857975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.08420038484809576], {
             RGBColor[
             0.18035329176886106`, 0.3068931230811942, 0.933582225206227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.08420038484809576], {
             RGBColor[
             0.9940468194635823, 0.9896750737285114, 0.5934112212615963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.08420038484809576], {
             RGBColor[
             0.23420030298526878`, 0.3634897459673388, 0.9366487328354871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.08420038484809576], {
             RGBColor[
             0.2515477771449798, 0.3817230412025836, 0.9376366458255944]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.08420038484809576], {
             RGBColor[
             0.2029347338096705, 0.33062765041220404`, 0.9348682049242014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.08420038484809576], {
             RGBColor[
             0.3362350503435996, 0.46565163376778274`, 0.9426455779802814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.08420038484809576], {
             RGBColor[
             0.18371444184961855`, 0.31042590492529404`, 0.9337736377309502]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.08420038484809576], {
             RGBColor[
             0.1820208818055452, 0.30864586594106436`, 0.9336771919918379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.08420038484809576], {
             RGBColor[
             0.1912494582787511, 0.31834568493994736`, 0.9342027457695316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.08420038484809576], {
             RGBColor[
             0.1789871968344326, 0.3054572706896884, 0.9335044281206677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.08420038484809576], {
             RGBColor[
             0.3510664211934816, 0.47849782175157674`, 0.9435906198159696]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.08420038484809576], {
             RGBColor[
             0.19785125300646603`, 0.3252845897767374, 0.9345787082127948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.08420038484809576], {
             RGBColor[
             0.33313964664549794`, 0.4629705506640006, 0.9424483415937963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.08420038484809576], {
             RGBColor[
             0.2019856527302044, 0.3296301060224692, 0.9348141561607654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.08420038484809576], {
             RGBColor[
             0.9938504692273173, 0.9917250252368329, 0.751577169586235]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.08420038484809576], {
             RGBColor[
             0.9097894237460113, 0.9309054071917814, 0.9912577214871428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.08420038484809576], {
             RGBColor[
             0.2396024194233052, 0.3691677128576799, 0.9369563753749182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.08420038484809576], {
             RGBColor[
             0.19002087389400624`, 0.31705436485483146`, 0.934132779706348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.08420038484809576], {
             RGBColor[
             0.2158527042869893, 0.34420525643050026`, 0.9356038642324599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.08420038484809576], {
             RGBColor[
             0.7657071355725306, 0.8168955009898127, 0.9772821894000061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.08420038484809576], {
             RGBColor[
             0.19499177110397153`, 0.3222790929955916, 0.9344158649486721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.08420038484809576], {
             RGBColor[
             0.85710048921771, 0.439904958487049, 0.20231279900164487`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.08420038484809576], {
             RGBColor[
             0.19077583416012883`, 0.31784787596177183`, 0.9341757735766401]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.08420038484809576], {
             RGBColor[
             0.18720392975649292`, 0.3140935779617309, 0.9339723589050121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.08420038484809576], {
             RGBColor[
             0.18524924480481392`, 0.31203908014333226`, 0.9338610424887112]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.08420038484809576], {
             RGBColor[
             0.21763599434706354`, 0.34607960735075854`, 0.93570541996324]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.08420038484809576], {
             RGBColor[
             0.18916507484151227`, 0.3161548657898664, 0.9340840432163497]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.08420038484809576], {
             RGBColor[
             0.21990087473071346`, 0.348460140235685, 0.9358344015504985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.08420038484809576], {
             RGBColor[
             0.8176771202476999, 0.13687966915311423`, 0.16456093635363633`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.08420038484809576], {
             RGBColor[
             0.18093049359979738`, 0.3074997988022181, 0.9336150959966053]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.08420038484809576], {
             RGBColor[
             0.39439940253334044`, 0.5160306722091927, 0.9463517590690945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.08420038484809576], {
             RGBColor[
             0.37508215881778845`, 0.49929904661568136`, 0.9451208813811075]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.08420038484809576], {
             RGBColor[
             0.1851720653526604, 0.311957959645659, 0.9338566472330878]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.08420038484809576], {
             RGBColor[
             0.19059767181486464`, 0.3176606160407541, 0.9341656274946448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.08420038484809576], {
             RGBColor[
             0.18708771794254558`, 0.3139714319770177, 0.9339657408141276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.08420038484809576], {
             RGBColor[
             0.18654757264035143`, 0.3134037050172214, 0.9339349803382411]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.08420038484809576], {
             RGBColor[
             0.19406834726399882`, 0.3213085159913272, 0.9343632773270688]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.08420038484809576], {
             RGBColor[
             0.271851153445097, 0.4030631770024157, 0.9387928930697325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.08420038484809576], {
             RGBColor[
             0.19021908584372046`, 0.31726269818134456`, 0.934144067583656]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.08420038484809576], {
             RGBColor[
             0.180596656524124, 0.30714891486919227`, 0.9335960844690134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.08420038484809576], {
             RGBColor[
             0.209601906353837, 0.3376352714792777, 0.9352478905373938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.08420038484809576], {
             RGBColor[
             0.18473621585810335`, 0.3114998541924255, 0.9338318262491543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.08420038484809576], {
             RGBColor[
             0.19081859398490578`, 0.3178928192487419, 0.9341782086854036]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.08420038484809576], {
             RGBColor[
             0.20710183530283005`, 0.33500753829100943`, 0.9351055151895625]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.08420038484809576], {
             RGBColor[
             0.22012423896070668`, 0.348694910203518, 0.9358471218129588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.08420038484809576], {
             RGBColor[
             0.19616341759440778`, 0.32351056774371817`, 0.9344825884830068]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.08420038484809576], {
             RGBColor[
             0.1818914944971056, 0.30850987167626515`, 0.9336698235760336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.08420038484809576], {
             RGBColor[
             0.20835388918653433`, 0.3363235263075839, 0.9351768178059918]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.08420038484809576], {
             RGBColor[
             0.18955786573703887`, 0.316567713925446, 0.9341064120767679]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.08420038484809576], {
             RGBColor[
             0.9944253181788963, 0.9904846442084778, 0.6346084706002231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.08420038484809576], {
             RGBColor[
             0.7607606134285254, 0.8130312402959552, 0.9767891663005692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.08420038484809576], {
             RGBColor[
             0.5341260408491124, 0.6326666079220644, 0.9564675049852491]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.08420038484809576], {
             RGBColor[
             0.2195142065627996, 0.3480537274750297, 0.9358123813703602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.08420038484809576], {
             RGBColor[
             0.20264865261830456`, 0.3303269609414833, 0.9348519130235723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.08420038484809576], {
             RGBColor[
             0.2627109211596987, 0.39345621334626335`, 0.938272370362841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.08420038484809576], {
             RGBColor[
             0.18112688553091424`, 0.3077062191737896, 0.9336262802265466]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.08420038484809576], {
             RGBColor[
             0.9910839134677017, 0.9905809833329919, 0.7974261581398643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.08420038484809576], {
             RGBColor[
             0.18336325239717496`, 0.31005678254407854`, 0.9337536380111718]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.08420038484809576], {
             RGBColor[
             0.18043226082461958`, 0.30697612456572376`, 0.9335867223771283]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.08420038484809576], {
             RGBColor[
             0.46863892160806836`, 0.5795012143610829, 0.9513121190713723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.08420038484809576], {
             RGBColor[
             0.19955786085140656`, 0.3270783428269569, 0.9346758970048641]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.08420038484809576], {
             RGBColor[
             0.2129233554713194, 0.341126325093789, 0.9354370421509908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.08420038484809576], {
             RGBColor[
             0.4260942433398349, 0.54348315028676, 0.9483713262986371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.08420038484809576], {
             RGBColor[
             0.9265760623547111, 0.7466055848528861, 0.2597795801705179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.08420038484809576], {
             RGBColor[
             0.8501784807301029, 0.38669936800784144`, 0.19568427585662201`]},
             StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{{3.8349502435193233`*^9, 3.8349502581408367`*^9}, 
   3.8349577843740606`*^9, 3.8349599050989304`*^9, 3.8349611659205523`*^9, 
   3.8350239477098637`*^9},
 CellLabel->
  "Out[207]=",ExpressionUUID->"d8a1c255-43df-4fc7-8f10-dbee507dc7f8"]
}, Open  ]],

Cell["Estimated with Max-Min Deviation v Calculated: (r = 6)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 3.8349503922098827`*^9}, {3.8349504781120467`*^9, 
  3.834950521977162*^9}},ExpressionUUID->"62a508bc-4493-47aa-80f3-\
9bac93281806"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphin4b", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsi4b", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}],
      "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"mMDi6400b", ",", "kri4b"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502554527807`*^9}, {3.8349505249112787`*^9, 3.834950525026289*^9}, {
   3.834957796266032*^9, 3.834957804349044*^9}, {3.834959913675406*^9, 
   3.834959919755829*^9}},
 CellLabel->
  "In[208]:=",ExpressionUUID->"747d711f-e83a-4fe4-92e8-8c1ac999d3b6"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN2wucznW+wPHf/+zadNlSKJUyheimsIbchiJLGlM0NrNmJtWMMW5DaZZc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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[337, 399] -> 
             RGBColor[
              0.9736987978723404, 0.9772802127659574, 0.7848066914893617], 
             UndirectedEdge[15, 92] -> 
             RGBColor[
              0.9328469148936169, 0.7714674255319147, 0.2648252553191489], 
             UndirectedEdge[87, 313] -> 
             RGBColor[
              0.9202668723404255, 0.7187834468085104, 0.2545577872340425], 
             UndirectedEdge[35, 214] -> 
             RGBColor[
              0.9400426914893616, 0.8010229361702127, 0.5609211702127659], 
             UndirectedEdge[105, 218] -> 
             RGBColor[
              0.9418943510638298, 0.9528484468085107, 0.8360352340425531], 
             UndirectedEdge[149, 316] -> 
             RGBColor[
              0.9766162234042552, 0.9453845531914893, 0.6084544787234041], 
             UndirectedEdge[160, 348] -> 
             RGBColor[
              0.9360243723404256, 0.8203037659574468, 0.5933242978723404], 
             UndirectedEdge[17, 287] -> 
             RGBColor[
              0.9400426914893616, 0.8010229361702127, 0.5609211702127659], 
             UndirectedEdge[268, 295] -> 
             RGBColor[
              0.9477094574468086, 0.9358728723404255, 0.678528255319149], 
             UndirectedEdge[277, 379] -> 
             RGBColor[
              0.9693978085106383, 0.9053581702127659, 0.3632862021276594], 
             UndirectedEdge[10, 37] -> 
             RGBColor[
              0.9801821063829788, 0.9446657659574467, 0.38992361702127626`], 
             UndirectedEdge[118, 389] -> 
             RGBColor[
              0.9389665319148937, 0.7950399574468083, 0.27334126595744673`], 
             UndirectedEdge[127, 313] -> 
             RGBColor[
              0.9661697659574469, 0.8946151914893616, 0.33833390425531906`], 
             UndirectedEdge[92, 281] -> 
             RGBColor[
              0.9389665319148937, 0.7950399574468083, 0.27334126595744673`], 
             UndirectedEdge[2, 193] -> 
             RGBColor[
              0.9502653723404255, 0.8292782340425533, 0.4954867659574468], 
             UndirectedEdge[265, 378] -> 
             RGBColor[
              0.9934490425531916, 0.9883964893617022, 0.528346893617021], 
             UndirectedEdge[108, 367] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255319], 
             UndirectedEdge[26, 342] -> 
             RGBColor[
              0.9562835319148937, 0.9648260425531915, 0.8697451595744681], 
             UndirectedEdge[57, 144] -> 
             RGBColor[
              0.988777074468085, 0.978025574468085, 0.5977721808510639], 
             UndirectedEdge[341, 348] -> 
             RGBColor[
              0.9262423191489362, 0.7452824042553191, 0.25951104255319146`], 
             UndirectedEdge[232, 309] -> 
             RGBColor[
              0.9712871382978723, 0.9539014893617022, 0.6540257553191489], 
             UndirectedEdge[23, 202] -> 
             RGBColor[
              0.9808634574468085, 0.9471408936170211, 0.538066819148936], 
             UndirectedEdge[89, 170] -> 
             RGBColor[
              0.9944851595744681, 0.9916304255319148, 0.7151041808510636], 
             UndirectedEdge[291, 383] -> 
             RGBColor[
              0.9816187446808511, 0.9496578510638298, 0.38309272340425526`], 
             UndirectedEdge[45, 140] -> 
             RGBColor[
              0.9572529148936171, 0.8552645531914893, 0.4685000319148935], 
             UndirectedEdge[213, 308] -> 
             RGBColor[
              0.9629600212765956, 0.8867175957446807, 0.3106071063829785], 
             UndirectedEdge[165, 386] -> 
             RGBColor[
              0.9769540638297872, 0.9339227872340424, 0.364971319148936], 
             UndirectedEdge[347, 381] -> 
             RGBColor[
              0.9765817234042553, 0.9312071276595744, 0.4876444680851062], 
             UndirectedEdge[216, 396] -> 
             RGBColor[
              0.9855563191489362, 0.9619184468085107, 0.48527319148936165`], 
             UndirectedEdge[39, 150] -> 
             RGBColor[
              0.9322641063829787, 0.7479394680851065, 0.3712422659574467], 
             UndirectedEdge[20, 378] -> 
             RGBColor[
              0.7080035212765958, 0.7644083617021278, 0.7382464468085106], 
             UndirectedEdge[363, 372] -> 
             RGBColor[
              0.9329736382978724, 0.7494570851063831, 0.44847043617021265`], 
             UndirectedEdge[54, 318] -> 
             RGBColor[
              0.9057106063829787, 0.5629780638297872, 0.45581156382978716`], 
             UndirectedEdge[40, 246] -> 
             RGBColor[
              0.9708391276595745, 0.977066829787234, 0.902646829787234], 
             UndirectedEdge[59, 178] -> 
             RGBColor[
              0.988777074468085, 0.978025574468085, 0.5977721808510639], 
             UndirectedEdge[172, 357] -> 
             RGBColor[
              0.9403805319148937, 0.7895611702127658, 0.31743801063829785`], 
             UndirectedEdge[268, 274] -> 
             RGBColor[
              0.9676247021276596, 0.902452659574468, 0.3287285106382978], 
             UndirectedEdge[122, 175] -> 
             RGBColor[
              0.9841123936170213, 0.9622905106382978, 0.5796507765957446], 
             UndirectedEdge[120, 341] -> 
             RGBColor[
              0.969752574468085, 0.9061169787234042, 0.40190028723404236`], 
             UndirectedEdge[220, 366] -> 
             RGBColor[
              0.9676247021276596, 0.902452659574468, 0.3287285106382978], 
             UndirectedEdge[202, 366] -> 
             RGBColor[
              0.9722893829787234, 0.9181877234042553, 0.34684991489361683`], 
             UndirectedEdge[17, 61] -> 
             RGBColor[
              0.9263864893617021, 0.7423559787234041, 0.26307379787234036`], 
             UndirectedEdge[112, 279] -> 
             RGBColor[
              0.9506483191489362, 0.8290795319148937, 0.4631858191489361], 
             UndirectedEdge[129, 313] -> 
             RGBColor[
              0.9658319255319148, 0.9060769574468084, 0.5818170638297872], 
             UndirectedEdge[204, 318] -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425531], 
             UndirectedEdge[60, 335] -> 
             RGBColor[
              0.9728130531914894, 0.9427833617021275, 0.6254252872340423], 
             UndirectedEdge[256, 386] -> 
             RGBColor[
              0.9808634574468085, 0.9471408936170211, 0.538066819148936], 
             UndirectedEdge[7, 65] -> 
             RGBColor[
              0.9719515425531915, 0.9296494893617021, 0.590333074468085], 
             UndirectedEdge[66, 280] -> 
             RGBColor[
              0.9408300531914894, 0.9505720212765958, 0.720192978723404], 
             UndirectedEdge[147, 344] -> 
             RGBColor[
              0.9502358085106382, 0.8369600425531912, 0.2967768829787232], 
             UndirectedEdge[329, 349] -> 
             RGBColor[
              0.9646485319148936, 0.9724498936170213, 0.9131258936170212], 
             UndirectedEdge[170, 306] -> 
             RGBColor[
              0.993069414893617, 0.9910449787234042, 0.738566734042553], 
             UndirectedEdge[175, 178] -> 
             RGBColor[
              0.9816187446808511, 0.9496578510638298, 0.38309272340425526`], 
             UndirectedEdge[115, 166] -> 
             RGBColor[
              0.9934490425531914, 0.9883964893617021, 0.528346893617021], 
             UndirectedEdge[361, 396] -> 
             RGBColor[
              0.9852015531914894, 0.9611596382978724, 0.44665910638297857`], 
             UndirectedEdge[80, 265] -> 
             RGBColor[
              0.9895283936170213, 0.9883564680851065, 0.7082636702127658], 
             UndirectedEdge[18, 288] -> 
             RGBColor[
              0.9761987765957447, 0.931405829787234, 0.5199454148936169], 
             UndirectedEdge[225, 240] -> 
             RGBColor[
              0.9722893829787234, 0.9181877234042553, 0.34684991489361683`], 
             UndirectedEdge[110, 251] -> 
             RGBColor[
              0.9430447765957446, 0.9201378085106382, 0.6604068510638297], 
             UndirectedEdge[56, 169] -> 
             RGBColor[
              0.9027180212765957, 0.6390982127659572, 0.23991459574468077`], 
             UndirectedEdge[87, 231] -> 
             RGBColor[
              0.9176677340425532, 0.7845709361702127, 0.609329170212766], 
             UndirectedEdge[266, 315] -> 
             RGBColor[
              0.9801821063829788, 0.9446657659574467, 0.38992361702127626`], 
             UndirectedEdge[31, 292] -> 
             RGBColor[
              0.9253235319148936, 0.9406828085106382, 0.8903897553191489], 
             UndirectedEdge[1, 87] -> 
             RGBColor[
              0.8769287872340426, 0.5340441914893614, 0.21901870212765953`], 
             UndirectedEdge[231, 336] -> 
             RGBColor[
              0.9660642765957446, 0.9730353404255319, 0.889663340425532], 
             UndirectedEdge[13, 309] -> 
             RGBColor[
              0.9666224574468085, 0.9381664255319148, 0.6359043510638296], 
             UndirectedEdge[237, 296] -> 
             RGBColor[
              0.9756139787234042, 0.9810983191489362, 0.9156303191489361], 
             UndirectedEdge[95, 312] -> 
             RGBColor[
              0.9923598829787235, 0.9895273617021276, 0.6613385638297871], 
             UndirectedEdge[108, 236] -> 
             RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 
             UndirectedEdge[48, 176] -> 
             RGBColor[
              0.9857252234042553, 0.9857552765957447, 0.7252344787234041], 
             UndirectedEdge[49, 52] -> 
             RGBColor[
              0.9186141808510638, 0.6827537659574467, 0.5178045851063828], 
             UndirectedEdge[310, 390] -> 
             RGBColor[
              0.8953584468085106, 0.6132899148936171, 0.23416723404255319`], 
             UndirectedEdge[343, 358] -> 
             RGBColor[
              0.9482958936170213, 0.8265100851063829, 0.30958407446808506`], 
             UndirectedEdge[271, 374] -> 
             RGBColor[
              0.9769540638297872, 0.9339227872340424, 0.364971319148936], 
             UndirectedEdge[57, 167] -> 
             RGBColor[
              0.9747830319148936, 0.9308203829787234, 0.5434079680851063], 
             UndirectedEdge[34, 214] -> 
             RGBColor[
              0.981804574468085, 0.985715255319149, 0.9051512553191488], 
             UndirectedEdge[83, 220] -> 
             RGBColor[
              0.9629600212765956, 0.8867175957446807, 0.3106071063829785], 
             UndirectedEdge[9, 347] -> 
             RGBColor[
              0.9557671808510637, 0.9178144255319148, 0.6282620106382979], 
             UndirectedEdge[188, 238] -> 
             RGBColor[
              0.819952829787234, 0.8601165957446809, 0.9778173297872341], 
             UndirectedEdge[79, 137] -> 
             RGBColor[
              0.9697612234042553, 0.9650196170212766, 0.6826262234042553], 
             UndirectedEdge[115, 197] -> 
             RGBColor[
              0.9905893723404255, 0.9881831063829788, 0.6461870319148934], 
             UndirectedEdge[67, 194] -> 
             RGBColor[
              0.9606430744680851, 0.8804773829787234, 0.5530402978723403], 
             UndirectedEdge[75, 260] -> 
             RGBColor[
              0.9678629680851063, 0.973422085106383, 0.8338998404255318], 
             UndirectedEdge[32, 387] -> 
             RGBColor[
              0.8961116276595744, 0.8310874042553189, 0.6256372659574467], 
             UndirectedEdge[76, 144] -> 
             RGBColor[
              0.9463559787234044, 0.8160601276595745, 0.3223912659574468], 
             UndirectedEdge[50, 164] -> 
             RGBColor[
              0.9661697659574469, 0.8946151914893616, 0.33833390425531906`], 
             UndirectedEdge[279, 285] -> 
             RGBColor[
              0.8829042340425532, 0.5605431489361701, 0.2239719574468085], 
             UndirectedEdge[137, 352] -> 
             RGBColor[
              0.9650965425531914, 0.9492845531914893, 0.6645048191489362], 
             UndirectedEdge[4, 275] -> 
             RGBColor[
              0.9646485319148936, 0.9724498936170213, 0.9131258936170212], 
             UndirectedEdge[8, 373] -> 
             RGBColor[
              0.9323619361702128, 0.7688549361702128, 0.26802705319148934`], 
             UndirectedEdge[41, 135] -> 
             RGBColor[
              0.9934208617021276, 0.9893540000000001, 0.5992619255319147], 
             UndirectedEdge[85, 211] -> 
             RGBColor[
              0.9812464042553191, 0.9469421914893617, 0.5057658723404252], 
             UndirectedEdge[63, 139] -> 
             RGBColor[
              0.9123500957446808, 0.9292906595744681, 0.8332172765957446], 
             UndirectedEdge[55, 92] -> 
             RGBColor[
              0.9554542234042553, 0.8548778085106382, 0.5242635319148936], 
             UndirectedEdge[31, 371] -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 
             UndirectedEdge[99, 169] -> 
             RGBColor[0.918167, 0.6941408723404254, 0.28467341489361697`], 
             UndirectedEdge[71, 72] -> 
             RGBColor[
              0.9635706276595745, 0.9604026808510637, 0.6931052872340426], 
             UndirectedEdge[104, 112] -> 
             RGBColor[
              0.9864347553191489, 0.9872728936170213, 0.80246264893617], 
             UndirectedEdge[389, 390] -> 
             RGBColor[
              0.8953584468085106, 0.6132899148936171, 0.23416723404255319`], 
             UndirectedEdge[260, 349] -> 
             RGBColor[
              0.940857829787234, 0.9554124468085106, 0.9849964468085107], 
             UndirectedEdge[70, 284] -> 
             RGBColor[
              0.9722893829787234, 0.9181877234042553, 0.34684991489361694`], 
             UndirectedEdge[24, 172] -> 
             RGBColor[
              0.9661697659574469, 0.8946151914893616, 0.33833390425531906`], 
             UndirectedEdge[343, 362] -> 
             RGBColor[
              0.985911085106383, 0.9626772553191489, 0.5238872765957445], 
             UndirectedEdge[233, 307] -> 
             RGBColor[
              0.9937756276595745, 0.9901128085106383, 0.6378760106382977], 
             UndirectedEdge[79, 278] -> 
             RGBColor[
              0.9901928191489362, 0.9786110212765957, 0.5743096276595744], 
             UndirectedEdge[1, 216] -> 
             RGBColor[
              0.9267692553191489, 0.7221365319148935, 0.4049752872340425], 
             UndirectedEdge[192, 374] -> 
             RGBColor[
              0.9901928191489362, 0.9786110212765957, 0.5743096276595744], 
             UndirectedEdge[152, 383] -> 
             RGBColor[
              0.986283425531915, 0.965392914893617, 0.4012141276595744], 
             UndirectedEdge[43, 121] -> 
             RGBColor[
              0.9595651702127659, 0.8684301702127658, 0.3330196914893616], 
             UndirectedEdge[13, 280] -> 
             RGBColor[
              0.9282726489361701, 0.9083589148936169, 0.6589978723404254], 
             UndirectedEdge[246, 272] -> 
             RGBColor[
              0.9708391276595745, 0.977066829787234, 0.902646829787234], 
             UndirectedEdge[385, 387] -> 
             RGBColor[
              0.9186888723404255, 0.9369107234042553, 0.9542856702127659], 
             UndirectedEdge[90, 268] -> 
             RGBColor[
              0.9712871382978723, 0.9539014893617022, 0.6540257553191489], 
             UndirectedEdge[195, 363] -> 
             RGBColor[
              0.9329736382978724, 0.7494570851063831, 0.44847043617021265`], 
             UndirectedEdge[88, 109] -> 
             RGBColor[
              0.9394515106382978, 0.7976524468085104, 0.2701394680851063], 
             UndirectedEdge[63, 318] -> 
             RGBColor[
              0.9944851595744681, 0.9916304255319148, 0.7151041808510636], 
             UndirectedEdge[257, 276] -> 
             RGBColor[
              0.9224920425531915, 0.9395119148936171, 0.9373148617021276], 
             UndirectedEdge[16, 106] -> 
             RGBColor[
              0.8923090319148936, 0.913554829787234, 0.8312408936170211], 
             UndirectedEdge[100, 227] -> 
             RGBColor[
              0.9678629680851063, 0.973422085106383, 0.8338998404255318], 
             UndirectedEdge[195, 359] -> 
             RGBColor[
              0.9329736382978724, 0.7494570851063831, 0.44847043617021265`], 
             UndirectedEdge[216, 313] -> 
             RGBColor[
              0.9701073404255318, 0.9068757872340425, 0.44051437234042545`], 
             UndirectedEdge[12, 47] -> 
             RGBColor[
              0.9901928191489362, 0.9786110212765957, 0.5743096276595744], 
             UndirectedEdge[386, 400] -> 
             RGBColor[
              0.9436312127659574, 0.8107750212765956, 0.2914626702127658], 
             UndirectedEdge[180, 262] -> 
             RGBColor[
              0.9891736276595744, 0.9875976595744682, 0.6696495851063827], 
             UndirectedEdge[247, 359] -> 
             RGBColor[
              0.9283434574468085, 0.7478994468085107, 0.5511590425531914], 
             UndirectedEdge[74, 141] -> 
             RGBColor[
              0.9805368723404255, 0.945424574468085, 0.4285377021276593], 
             UndirectedEdge[170, 171] -> 
             RGBColor[
              0.9812464042553191, 0.9469421914893617, 0.5057658723404252], 
             UndirectedEdge[207, 333] -> 
             RGBColor[
              0.986079989361702, 0.9865140851063829, 0.7638485638297872], 
             UndirectedEdge[311, 313] -> 
             RGBColor[
              0.9322604787234042, 0.8808302127659573, 0.6337694361702128], 
             UndirectedEdge[161, 195] -> 
             RGBColor[
              0.9864347553191489, 0.9872728936170213, 0.80246264893617], 
             UndirectedEdge[87, 129] -> 
             RGBColor[
              0.9400426914893616, 0.8010229361702127, 0.5609211702127659], 
             UndirectedEdge[198, 367] -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 
             UndirectedEdge[322, 330] -> 
             RGBColor[
              0.9934490425531916, 0.9883964893617022, 0.528346893617021], 
             UndirectedEdge[79, 314] -> 
             RGBColor[
              0.9595651702127659, 0.8684301702127658, 0.3330196914893616], 
             UndirectedEdge[56, 274] -> 
             RGBColor[
              0.9521757234042553, 0.8474099999999998, 0.2839696914893616], 
             UndirectedEdge[249, 316] -> 
             RGBColor[
              0.9801821063829788, 0.9446657659574467, 0.38992361702127626`], 
             UndirectedEdge[69, 294] -> 
             RGBColor[
              0.9846360638297872, 0.9868861489361702, 0.8582261489361702], 
             UndirectedEdge[6, 300] -> 
             RGBColor[
              0.9502358085106382, 0.8369600425531912, 0.2967768829787232], 
             UndirectedEdge[36, 265] -> 
             RGBColor[
              0.9895283936170213, 0.9883564680851065, 0.7082636702127658], 
             UndirectedEdge[167, 395] -> 
             RGBColor[
              0.9747830319148936, 0.9308203829787234, 0.5434079680851063], 
             UndirectedEdge[261, 306] -> 
             RGBColor[
              0.9923598829787235, 0.9895273617021276, 0.6613385638297871], 
             UndirectedEdge[35, 211] -> 
             RGBColor[
              0.9446728723404255, 0.802580574468085, 0.45823256382978705`], 
             UndirectedEdge[54, 63] -> 
             RGBColor[
              0.9060935531914893, 0.5627793617021277, 0.42351061702127646`], 
             UndirectedEdge[302, 314] -> 
             RGBColor[
              0.9634745638297872, 0.8816482765957445, 0.5061151914893616], 
             UndirectedEdge[54, 224] -> 
             RGBColor[
              0.9060935531914893, 0.5627793617021277, 0.42351061702127646`], 
             UndirectedEdge[164, 389] -> 
             RGBColor[
              0.9328469148936169, 0.7714674255319147, 0.2648252553191489], 
             UndirectedEdge[113, 210] -> 
             RGBColor[
              0.8855729999999999, 0.5334282765957445, 0.2245669042553191], 
             UndirectedEdge[307, 348] -> 
             RGBColor[
              0.9499387872340426, 0.8275619148936171, 0.38595764893617013`], 
             UndirectedEdge[18, 74] -> 
             RGBColor[
              0.9758721914893618, 0.9296895106382979, 0.41041629787234024`], 
             UndirectedEdge[41, 328] -> 
             RGBColor[
              0.9755174255319149, 0.9289307021276596, 0.3718022127659572], 
             UndirectedEdge[63, 290] -> 
             RGBColor[
              0.9812464042553191, 0.9469421914893617, 0.5057658723404252], 
             UndirectedEdge[45, 288] -> 
             RGBColor[
              0.9944851595744681, 0.9916304255319148, 0.7151041808510636], 
             UndirectedEdge[249, 315] -> 
             RGBColor[
              0.9927395106382979, 0.9868788723404256, 0.45111872340425496`], 
             UndirectedEdge[306, 342] -> 
             RGBColor[
              0.9926864680851064, 0.9912436808510638, 0.7708676808510637], 
             UndirectedEdge[163, 395] -> 
             RGBColor[
              0.9926864680851064, 0.9912436808510638, 0.7708676808510637], 
             UndirectedEdge[378, 379] -> 
             RGBColor[
              0.9930942765957447, 0.9876376808510638, 0.489732808510638], 
             UndirectedEdge[216, 235] -> 
             RGBColor[
              0.9941303936170213, 0.9908716170212766, 0.6764900957446808], 
             UndirectedEdge[220, 321] -> 
             RGBColor[
              0.9088376382978722, 0.6626707446808509, 0.24843060638297865`], 
             UndirectedEdge[133, 199] -> 
             RGBColor[
              0.9912989042553191, 0.9897007234042554, 0.7234152021276594], 
             UndirectedEdge[317, 396] -> 
             RGBColor[
              0.9549004893617021, 0.8526951063829786, 0.31489828723404245`], 
             UndirectedEdge[177, 197] -> 
             RGBColor[
              0.9909441382978723, 0.9889419148936172, 0.6848011170212764], 
             UndirectedEdge[208, 242] -> 
             RGBColor[
              0.9812464042553191, 0.9469421914893617, 0.5057658723404252], 
             UndirectedEdge[51, 163] -> 
             RGBColor[
              0.9634745638297872, 0.8816482765957445, 0.5061151914893616], 
             UndirectedEdge[188, 228] -> 
             RGBColor[
              0.9635706276595745, 0.9604026808510637, 0.6931052872340426], 
             UndirectedEdge[95, 125] -> 
             RGBColor[
              0.9671534361702128, 0.9719044680851063, 0.7566716702127658], 
             UndirectedEdge[66, 203] -> 
             RGBColor[
              0.9436085744680851, 0.8003041489361702, 0.3423903085106381], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.9926864680851064, 0.9912436808510638, 0.7708676808510637], 
             UndirectedEdge[151, 265] -> 
             RGBColor[
              0.9565433829787234, 0.8537469361702128, 0.3912718617021275], 
             UndirectedEdge[76, 333] -> 
             RGBColor[
              0.9502935531914893, 0.8283207234042553, 0.4245717340425532], 
             UndirectedEdge[119, 336] -> 
             RGBColor[
              0.993069414893617, 0.9910449787234042, 0.738566734042553], 
             UndirectedEdge[183, 395] -> 
             RGBColor[
              0.9794477127659573, 0.9465554468085104, 0.5615293723404253], 
             UndirectedEdge[42, 204] -> 
             RGBColor[
              0.9646485319148936, 0.9724498936170213, 0.9131258936170212], 
             UndirectedEdge[12, 107] -> 
             RGBColor[
              0.9568699680851064, 0.8554632553191488, 0.5008009787234042], 
             UndirectedEdge[234, 239] -> 
             RGBColor[
              0.9434569680851064, 0.8896249574468084, 0.6302250638297873], 
             UndirectedEdge[164, 287] -> 
             RGBColor[
              0.9658319255319148, 0.9060769574468084, 0.581817063829787], 
             UndirectedEdge[32, 194] -> 
             RGBColor[
              0.9328469148936169, 0.7714674255319146, 0.26482525531914886`], 
             UndirectedEdge[6, 169] -> 
             RGBColor[
              0.8961134255319148, 0.6129131914893614, 0.23460038297872332`], 
             UndirectedEdge[24, 240] -> 
             RGBColor[
              0.9615050851063829, 0.8788801276595744, 0.3202124999999999], 
             UndirectedEdge[9, 381] -> 
             RGBColor[
              0.9740535638297871, 0.9780390212765957, 0.8234207765957446], 
             UndirectedEdge[43, 90] -> 
             RGBColor[
              0.9492335638297872, 0.8726738085106381, 0.6039527234042552], 
             UndirectedEdge[88, 157] -> 
             RGBColor[
              0.9455711276595744, 0.821224978723404, 0.2786554787234041], 
             UndirectedEdge[100, 314] -> 
             RGBColor[
              0.9638575106382978, 0.881449574468085, 0.47381424468085087`], 
             UndirectedEdge[56, 296] -> 
             RGBColor[
              0.9658319255319148, 0.9060769574468084, 0.581817063829787], 
             UndirectedEdge[49, 235] -> 
             RGBColor[
              0.921445670212766, 0.6839246595744679, 0.4708794787234042], 
             UndirectedEdge[359, 362] -> 
             RGBColor[
              0.9329736382978724, 0.7494570851063831, 0.44847043617021265`], 
             UndirectedEdge[104, 285] -> 
             RGBColor[
              0.918690670212766, 0.7187365106382977, 0.5632487872340425], 
             UndirectedEdge[80, 168] -> 
             RGBColor[
              0.9632327872340425, 0.9718644468085107, 0.9365884468085106], 
             UndirectedEdge[311, 386] -> 
             RGBColor[
              0.9430447765957446, 0.9201378085106382, 0.6604068510638297], 
             UndirectedEdge[61, 173] -> 
             RGBColor[
              0.9747830319148936, 0.9308203829787234, 0.5434079680851063], 
             UndirectedEdge[118, 354] -> 
             RGBColor[
              0.9755174255319149, 0.9289307021276596, 0.3718022127659572], 
             UndirectedEdge[154, 180] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255319], 
             UndirectedEdge[17, 158] -> 
             RGBColor[
              0.9446728723404255, 0.802580574468085, 0.45823256382978705`], 
             UndirectedEdge[8, 237] -> 
             RGBColor[
              0.9619577765957447, 0.9224313617021276, 0.6177829468085105], 
             UndirectedEdge[55, 255] -> 
             RGBColor[
              0.9920051170212766, 0.9887685531914894, 0.6227244787234041], 
             UndirectedEdge[93, 214] -> 
             RGBColor[
              0.9902379255319149, 0.989874085106383, 0.7854918404255318], 
             UndirectedEdge[129, 235] -> 
             RGBColor[
              0.9898549787234042, 0.9900727872340426, 0.8177927872340425], 
             UndirectedEdge[47, 158] -> 
             RGBColor[
              0.9905757659574468, 0.9784123191489362, 0.5420086808510637], 
             UndirectedEdge[106, 347] -> 
             RGBColor[
              0.9765817234042553, 0.9312071276595744, 0.4876444680851062], 
             UndirectedEdge[169, 178] -> 
             RGBColor[
              0.9228316808510638, 0.7098759361702126, 0.30279481914893613`], 
             UndirectedEdge[230, 385] -> 
             RGBColor[
              0.9245402872340425, 0.745298255319149, 0.5681298510638297], 
             UndirectedEdge[304, 383] -> 
             RGBColor[
              0.9595651702127659, 0.8684301702127658, 0.3330196914893616], 
             UndirectedEdge[100, 352] -> 
             RGBColor[
              0.985911085106383, 0.9626772553191489, 0.5238872765957445], 
             UndirectedEdge[87, 216] -> 
             RGBColor[
              0.9443181063829786, 0.8018217659574467, 0.4196184787234042], 
             UndirectedEdge[79, 277] -> 
             RGBColor[
              0.9661697659574469, 0.8946151914893616, 0.33833390425531906`], 
             UndirectedEdge[217, 220] -> 
             RGBColor[
              0.9455711276595744, 0.821224978723404, 0.2786554787234041], 
             UndirectedEdge[78, 104] -> 
             RGBColor[
              0.9728130531914894, 0.9427833617021275, 0.6254252872340423], 
             UndirectedEdge[170, 353] -> 
             RGBColor[
              0.9902379255319149, 0.989874085106383, 0.7854918404255318], 
             UndirectedEdge[78, 385] -> 
             RGBColor[
              0.9728130531914894, 0.9427833617021275, 0.6254252872340423], 
             UndirectedEdge[40, 102] -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425531], 
             UndirectedEdge[41, 256] -> 
             RGBColor[
              0.9934208617021276, 0.9893540000000001, 0.5992619255319147], 
             UndirectedEdge[120, 217] -> 
             RGBColor[
              0.9631479787234043, 0.8799319574468084, 0.3965860744680849], 
             UndirectedEdge[210, 315] -> 
             RGBColor[
              0.9155192978723404, 0.6411340000000001, 0.31771363829787214`], 
             UndirectedEdge[83, 187] -> 
             RGBColor[
              0.9722893829787234, 0.9181877234042553, 0.34684991489361683`], 
             UndirectedEdge[2, 305] -> 
             RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 
             UndirectedEdge[121, 175] -> 
             RGBColor[
              0.9816187446808511, 0.9496578510638298, 0.38309272340425526`], 
             UndirectedEdge[36, 151] -> 
             RGBColor[
              0.9526227340425532, 0.8537069148936169, 0.5711886382978723], 
             UndirectedEdge[70, 332] -> 
             RGBColor[
              0.9898662340425533, 0.9768947021276596, 0.46478051063829773`], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.6950913510638297, 0.7214364468085106, 0.6384372553191489], 
             UndirectedEdge[221, 400] -> 
             RGBColor[
              0.9540384787234042, 0.8542923617021276, 0.5477260851063829], 
             UndirectedEdge[49, 216] -> 
             RGBColor[
              0.9214738510638298, 0.6829671489361702, 0.3999644468085106], 
             UndirectedEdge[75, 349] -> 
             RGBColor[
              0.9678629680851063, 0.973422085106383, 0.8338998404255318], 
             UndirectedEdge[62, 87] -> 
             RGBColor[
              0.9357158510638297, 0.7738261063829786, 0.2993166063829787], 
             UndirectedEdge[38, 189] -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 
             UndirectedEdge[49, 361] -> 
             RGBColor[
              0.9211190851063831, 0.6822083404255319, 0.36135036170212753`], 
             UndirectedEdge[107, 270] -> 
             RGBColor[
              0.9554542234042553, 0.8548778085106382, 0.5242635319148936], 
             UndirectedEdge[5, 8] -> 
             RGBColor[
              0.9765817234042553, 0.9312071276595744, 0.4876444680851062], 
             UndirectedEdge[162, 340] -> 
             RGBColor[
              0.9808916382978723, 0.9461833829787233, 0.4671517872340424], 
             UndirectedEdge[34, 85] -> 
             RGBColor[
              0.9728130531914894, 0.9427833617021275, 0.6254252872340423], 
             UndirectedEdge[21, 172] -> 
             RGBColor[
              0.9898662340425533, 0.9768947021276596, 0.46478051063829773`], 
             UndirectedEdge[298, 393] -> 
             RGBColor[
              0.991653670212766, 0.9904595319148937, 0.7620292872340424], 
             UndirectedEdge[164, 371] -> 
             RGBColor[
              0.968663414893617, 0.9072478510638297, 0.5348919574468085], 
             UndirectedEdge[11, 85] -> 
             RGBColor[
              0.9766162234042552, 0.9453845531914893, 0.6084544787234041], 
             UndirectedEdge[202, 307] -> 
             RGBColor[
              0.9805368723404255, 0.945424574468085, 0.4285377021276593], 
             UndirectedEdge[20, 265] -> 
             RGBColor[
              0.7080035212765958, 0.7644083617021278, 0.7382464468085106], 
             UndirectedEdge[195, 247] -> 
             RGBColor[
              0.9902379255319149, 0.989874085106383, 0.7854918404255318], 
             UndirectedEdge[281, 355] -> 
             RGBColor[
              0.9765817234042553, 0.9312071276595744, 0.4876444680851062], 
             UndirectedEdge[298, 313] -> 
             RGBColor[
              0.9704621063829787, 0.9076345957446807, 0.4791284574468083], 
             UndirectedEdge[67, 210] -> 
             RGBColor[
              0.9133691595744681, 0.6424382340425533, 0.5127819468085105], 
             UndirectedEdge[11, 263] -> 
             RGBColor[
              0.9719515425531915, 0.9296494893617021, 0.590333074468085], 
             UndirectedEdge[88, 181] -> 
             RGBColor[
              0.9635027446808511, 0.8806907659574467, 0.435200159574468], 
             UndirectedEdge[212, 390] -> 
             RGBColor[
              0.9326188723404255, 0.7486982765957447, 0.4098563510638298], 
             UndirectedEdge[13, 203] -> 
             RGBColor[
              0.931051170212766, 0.7580910425531913, 0.2811952021276594], 
             UndirectedEdge[75, 105] -> 
             RGBColor[
              0.9948681063829787, 0.9914317234042553, 0.6828032340425529], 
             UndirectedEdge[12, 270] -> 
             RGBColor[
              0.9926864680851064, 0.9912436808510638, 0.7708676808510637], 
             UndirectedEdge[127, 393] -> 
             RGBColor[
              0.9873613297872341, 0.9774401276595746, 0.621234734042553], 
             UndirectedEdge[185, 208] -> 
             RGBColor[
              0.9329736382978724, 0.7494570851063831, 0.44847043617021265`], 
             UndirectedEdge[246, 355] -> 
             RGBColor[
              0.9740535638297871, 0.9780390212765957, 0.8234207765957446], 
             UndirectedEdge[62, 336] -> 
             RGBColor[
              0.9841123936170213, 0.9622905106382978, 0.5796507765957446], 
             UndirectedEdge[118, 209] -> 
             RGBColor[
              0.9719515425531915, 0.9296494893617021, 0.590333074468085], 
             UndirectedEdge[178, 352] -> 
             RGBColor[
              0.9816187446808511, 0.9496578510638298, 0.38309272340425526`], 
             UndirectedEdge[17, 22] -> 
             RGBColor[
              0.9439633404255319, 0.8010629574468084, 0.3810043936170211], 
             UndirectedEdge[12, 158] -> 
             RGBColor[
              0.9944851595744681, 0.9916304255319148, 0.7151041808510636], 
             UndirectedEdge[200, 333] -> 
             RGBColor[
              0.9736987978723404, 0.9772802127659574, 0.7848066914893617], 
             UndirectedEdge[69, 295] -> 
             RGBColor[
              0.9548677872340425, 0.9642405957446809, 0.8932077127659575], 
             UndirectedEdge[181, 340] -> 
             RGBColor[
              0.9941585744680851, 0.9899141063829787, 0.6055750638297872], 
             UndirectedEdge[205, 284] -> 
             RGBColor[
              0.9323619361702128, 0.7688549361702128, 0.26802705319148934`], 
             UndirectedEdge[283, 373] -> 
             RGBColor[
              0.9495840212765958, 0.8268031063829788, 0.3473435638297871], 
             UndirectedEdge[302, 379] -> 
             RGBColor[
              0.9934208617021276, 0.9893540000000001, 0.5992619255319147], 
             UndirectedEdge[254, 303] -> 
             RGBColor[
              0.938679914893617, 0.951876255319149, 0.9152612872340424], 
             UndirectedEdge[38, 254] -> 
             RGBColor[
              0.9898549787234042, 0.9900727872340426, 0.8177927872340425], 
             UndirectedEdge[158, 209] -> 
             RGBColor[
              0.9902379255319149, 0.989874085106383, 0.7854918404255318], 
             UndirectedEdge[365, 370] -> 
             RGBColor[
              0.9909441382978723, 0.9889419148936172, 0.6848011170212764], 
             UndirectedEdge[61, 164] -> 
             RGBColor[
              0.9521757234042553, 0.8474099999999998, 0.2839696914893616], 
             UndirectedEdge[163, 167] -> 
             RGBColor[
              0.9761987765957447, 0.931405829787234, 0.5199454148936169], 
             UndirectedEdge[62, 119] -> 
             RGBColor[
              0.985911085106383, 0.9626772553191489, 0.5238872765957445], 
             UndirectedEdge[137, 197] -> 
             RGBColor[
              0.9708391276595745, 0.977066829787234, 0.902646829787234], 
             UndirectedEdge[265, 383] -> 
             RGBColor[
              0.9898662340425533, 0.9768947021276596, 0.46478051063829773`], 
             UndirectedEdge[19, 338] -> 
             RGBColor[
              0.9420425319148936, 0.9558515744680851, 0.9675826914893617], 
             UndirectedEdge[69, 212] -> 
             RGBColor[
              0.9927146489361702, 0.9902861702127659, 0.6999526489361703], 
             UndirectedEdge[45, 275] -> 
             RGBColor[
              0.9678629680851063, 0.973422085106383, 0.8338998404255318], 
             UndirectedEdge[248, 360] -> 
             RGBColor[
              0.9895283936170213, 0.9883564680851065, 0.7082636702127658], 
             UndirectedEdge[188, 322] -> 
             RGBColor[
              0.9671534361702128, 0.9719044680851063, 0.7566716702127658], 
             UndirectedEdge[167, 183] -> 
             RGBColor[
              0.9629600212765956, 0.8867175957446807, 0.3106071063829785], 
             UndirectedEdge[141, 240] -> 
             RGBColor[
              0.9722893829787234, 0.9181877234042553, 0.34684991489361683`], 
             UndirectedEdge[23, 220] -> 
             RGBColor[
              0.9761987765957447, 0.931405829787234, 0.5199454148936169], 
             UndirectedEdge[123, 322] -> 
             RGBColor[
              0.9106290425531915, 0.6015772765957446, 0.3513050851063828], 
             UndirectedEdge[177, 398] -> 
             RGBColor[
              0.969752574468085, 0.9061169787234042, 0.40190028723404236`], 
             UndirectedEdge[272, 395] -> 
             RGBColor[
              0.9898549787234042, 0.9900727872340426, 0.8177927872340425], 
             UndirectedEdge[85, 312] -> 
             RGBColor[
              0.9794477127659573, 0.9465554468085104, 0.5615293723404253], 
             UndirectedEdge[25, 328] -> 
             RGBColor[
              0.9762269574468085, 0.9304483191489361, 0.44903038297872333`], 
             UndirectedEdge[8, 121] -> 
             RGBColor[
              0.9722893829787234, 0.9181877234042553, 0.34684991489361694`], 
             UndirectedEdge[169, 319] -> 
             RGBColor[
              0.923909585106383, 0.7219231489361702, 0.5228154255319147], 
             UndirectedEdge[84, 167] -> 
             RGBColor[
              0.9719515425531915, 0.9296494893617021, 0.590333074468085], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.9572529148936171, 0.8552645531914893, 0.4685000319148935], 
             UndirectedEdge[43, 213] -> 
             RGBColor[
              0.9455711276595744, 0.821224978723404, 0.2786554787234041], 
             UndirectedEdge[170, 187] -> 
             RGBColor[
              0.985911085106383, 0.9626772553191489, 0.5238872765957445], 
             UndirectedEdge[89, 199] -> 
             RGBColor[
              0.9941303936170213, 0.9908716170212766, 0.6764900957446808], 
             UndirectedEdge[16, 373] -> 
             RGBColor[
              0.8480892446808512, 0.7512026382978725, 0.6116234787234043], 
             UndirectedEdge[22, 158] -> 
             RGBColor[
              0.9941585744680852, 0.9899141063829788, 0.605575063829787], 
             UndirectedEdge[233, 264] -> 
             RGBColor[
              0.9860518085106382, 0.9874715957446809, 0.8347635957446807], 
             UndirectedEdge[274, 296] -> 
             RGBColor[
              0.9719515425531915, 0.9296494893617021, 0.590333074468085], 
             UndirectedEdge[97, 211] -> 
             RGBColor[
              0.993069414893617, 0.9910449787234042, 0.738566734042553], 
             UndirectedEdge[1, 129] -> 
             RGBColor[
              0.9224938404255318, 0.7213377021276595, 0.5462779787234041], 
             UndirectedEdge[24, 141] -> 
             RGBColor[
              0.9568404042553191, 0.8631450638297871, 0.3020910957446806], 
             UndirectedEdge[347, 384] -> 
             RGBColor[
              0.9263864893617021, 0.7423559787234041, 0.26307379787234036`], 
             UndirectedEdge[36, 378] -> 
             RGBColor[
              0.9895283936170213, 0.9883564680851065, 0.7082636702127658], 
             UndirectedEdge[174, 395] -> 
             RGBColor[
              0.9926864680851064, 0.9912436808510638, 0.7708676808510637], 
             UndirectedEdge[104, 357] -> 
             RGBColor[
              0.9362395212765957, 0.798421744680851, 0.5778919787234043], 
             UndirectedEdge[47, 173] -> 
             RGBColor[
              0.988777074468085, 0.978025574468085, 0.5977721808510639], 
             UndirectedEdge[127, 231] -> 
             RGBColor[
              0.9635706276595745, 0.9604026808510637, 0.6931052872340426], 
             UndirectedEdge[252, 367] -> 
             RGBColor[
              0.988777074468085, 0.978025574468085, 0.5977721808510639], 
             UndirectedEdge[158, 310] -> 
             RGBColor[
              0.9572529148936171, 0.8552645531914893, 0.4685000319148935], 
             UndirectedEdge[149, 397] -> 
             RGBColor[
              0.9756139787234042, 0.9810983191489362, 0.9156303191489361], 
             UndirectedEdge[204, 345] -> 
             RGBColor[
              0.9898549787234042, 0.9900727872340426, 0.8177927872340425], 
             UndirectedEdge[231, 396] -> 
             RGBColor[
              0.9589059468085106, 0.9446676170212766, 0.6749838829787234], 
             UndirectedEdge[162, 263] -> 
             RGBColor[
              0.9629600212765956, 0.8867175957446807, 0.3106071063829785], 
             UndirectedEdge[14, 196] -> 
             RGBColor[
              0.9506483191489362, 0.8290795319148937, 0.4631858191489361], 
             UndirectedEdge[43, 175] -> 
             RGBColor[
              0.9549004893617021, 0.8526951063829786, 0.31489828723404245`], 
             UndirectedEdge[113, 397] -> 
             RGBColor[
              0.9492335638297872, 0.8726738085106381, 0.6039527234042552], 
             UndirectedEdge[126, 336] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255319], 
             UndirectedEdge[48, 173] -> 
             RGBColor[
              0.9846360638297872, 0.9868861489361702, 0.8582261489361702], 
             UndirectedEdge[28, 168] -> 
             RGBColor[
              0.9542412659574467, 0.9289325531914892, 0.6568624787234041], 
             UndirectedEdge[253, 359] -> 
             RGBColor[
              0.8887538510638298, 0.5871048936170213, 0.2288530212765958], 
             UndirectedEdge[41, 187] -> 
             RGBColor[
              0.9848467872340425, 0.9604008297872341, 0.40804502127659553`], 
             UndirectedEdge[198, 398] -> 
             RGBColor[
              0.968663414893617, 0.9072478510638297, 0.5348919574468085], 
             UndirectedEdge[260, 329] -> 
             RGBColor[
              0.9646485319148936, 0.9724498936170213, 0.9131258936170212], 
             UndirectedEdge[60, 82] -> 
             RGBColor[
              0.9808916382978723, 0.9461833829787233, 0.4671517872340424], 
             UndirectedEdge[12, 17] -> 
             RGBColor[
              0.9442899255319148, 0.8027792765957446, 0.4905335106382978], 
             UndirectedEdge[268, 351] -> 
             RGBColor[
              0.9589059468085106, 0.9446676170212766, 0.6749838829787234], 
             UndirectedEdge[122, 274] -> 
             RGBColor[
              0.9747830319148936, 0.9308203829787234, 0.5434079680851063], 
             UndirectedEdge[150, 384] -> 
             RGBColor[
              0.8827784042553191, 0.5606059361702127, 0.22389976595744682`], 
             UndirectedEdge[179, 232] -> 
             RGBColor[
              0.9848467872340425, 0.9604008297872341, 0.40804502127659553`], 
             UndirectedEdge[4, 131] -> 
             RGBColor[
              0.9909441382978723, 0.9889419148936172, 0.6848011170212764], 
             UndirectedEdge[128, 155] -> 
             RGBColor[
              0.8769269893617021, 0.752218404255319, 0.6100555851063829], 
             UndirectedEdge[316, 362] -> 
             RGBColor[
              0.9812464042553191, 0.9469421914893617, 0.5057658723404252], 
             UndirectedEdge[283, 320] -> 
             RGBColor[
              0.9930942765957447, 0.9876376808510638, 0.489732808510638], 
             UndirectedEdge[49, 396] -> 
             RGBColor[
              0.9128715957446809, 0.654971489361702, 0.27966257446808507`], 
             UndirectedEdge[371, 389] -> 
             RGBColor[
              0.9554542234042553, 0.8548778085106382, 0.5242635319148936], 
             UndirectedEdge[53, 58] -> 
             RGBColor[
              0.9934208617021276, 0.9893540000000001, 0.5992619255319147], 
             UndirectedEdge[18, 399] -> 
             RGBColor[
              0.9762269574468085, 0.9304483191489361, 0.44903038297872333`], 
             UndirectedEdge[241, 270] -> 
             RGBColor[
              0.9927146489361702, 0.9902861702127659, 0.6999526489361703], 
             UndirectedEdge[137, 169] -> 
             RGBColor[
              0.9063094787234042, 0.7095026382978722, 0.5842069148936171], 
             UndirectedEdge[156, 386] -> 
             RGBColor[
              0.9801821063829788, 0.9446657659574467, 0.38992361702127626`], 
             UndirectedEdge[19, 262] -> 
             RGBColor[
              0.9791798617021277, 0.9803795319148936, 0.6970994574468083], 
             UndirectedEdge[85, 181] -> 
             RGBColor[
              0.9808916382978723, 0.9461833829787233, 0.4671517872340424], 
             UndirectedEdge[74, 240] -> 
             RGBColor[
              0.9852015531914894, 0.9611596382978724, 0.44665910638297857`], 
             UndirectedEdge[72, 88] -> 
             RGBColor[
              0.9368523723404254, 0.8634399361702125, 0.6249108510638298], 
             UndirectedEdge[63, 98] -> 
             RGBColor[
              0.9802441595744681, 0.9826559574468086, 0.8129417127659573], 
             UndirectedEdge[43, 56] -> 
             RGBColor[
              0.9394515106382978, 0.7976524468085104, 0.2701394680851063], 
             UndirectedEdge[174, 272] -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425531], 
             UndirectedEdge[180, 198] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255319], 
             UndirectedEdge[126, 289] -> 
             RGBColor[
              0.9520362978723405, 0.9630697021276596, 0.9401328191489361], 
             UndirectedEdge[233, 244] -> 
             RGBColor[
              0.9761987765957447, 0.931405829787234, 0.5199454148936169], 
             UndirectedEdge[51, 189] -> 
             RGBColor[
              0.9620588191489361, 0.8810628297872338, 0.529577744680851], 
             UndirectedEdge[199, 306] -> 
             RGBColor[
              0.9927146489361702, 0.9902861702127659, 0.6999526489361703], 
             UndirectedEdge[86, 214] -> 
             RGBColor[
              0.9898549787234042, 0.9900727872340426, 0.8177927872340425], 
             UndirectedEdge[104, 172] -> 
             RGBColor[
              0.9821424148936171, 0.9742534893617021, 0.6616680957446808], 
             UndirectedEdge[67, 293] -> 
             RGBColor[
              0.9832203191489362, 0.9863007021276596, 0.8816887021276594], 
             UndirectedEdge[296, 380] -> 
             RGBColor[
              0.959227329787234, 0.8798919361702127, 0.5765028510638297], 
             UndirectedEdge[290, 297] -> 
             RGBColor[
              0.9808634574468085, 0.9471408936170211, 0.538066819148936], 
             UndirectedEdge[206, 328] -> 
             RGBColor[
              0.9758721914893618, 0.9296895106382979, 0.41041629787234024`], 
             UndirectedEdge[5, 319] -> 
             RGBColor[
              0.991653670212766, 0.9904595319148937, 0.7620292872340424], 
             UndirectedEdge[235, 393] -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425531], 
             UndirectedEdge[40, 189] -> 
             RGBColor[
              0.9898549787234042, 0.9900727872340426, 0.8177927872340425], 
             UndirectedEdge[15, 256] -> 
             RGBColor[
              0.970079159574468, 0.9078332978723402, 0.511429404255319], 
             UndirectedEdge[71, 365] -> 
             RGBColor[
              0.9873613297872341, 0.9774401276595746, 0.621234734042553], 
             UndirectedEdge[53, 64] -> 
             RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 
             UndirectedEdge[231, 298] -> 
             RGBColor[
              0.9678629680851063, 0.973422085106383, 0.8338998404255318], 
             UndirectedEdge[81, 382] -> 
             RGBColor[
              0.9414584361702127, 0.8016083829787233, 0.5374586170212765], 
             UndirectedEdge[9, 294] -> 
             RGBColor[
              0.9656202127659574, 0.9738801914893618, 0.9430801914893616], 
             UndirectedEdge[175, 213] -> 
             RGBColor[
              0.9676247021276596, 0.902452659574468, 0.3287285106382978], 
             UndirectedEdge[174, 189] -> 
             RGBColor[
              0.9926864680851064, 0.9912436808510638, 0.7708676808510637], 
             UndirectedEdge[14, 127] -> 
             RGBColor[
              0.9463559787234044, 0.8160601276595745, 0.3223912659574468], 
             UndirectedEdge[86, 95] -> 
             RGBColor[
              0.9937756276595745, 0.9901128085106383, 0.6378760106382977], 
             UndirectedEdge[103, 200] -> 
             RGBColor[
              0.9298337765957447, 0.8156868297872342, 0.6038033617021277], 
             UndirectedEdge[24, 112] -> 
             RGBColor[
              0.9704621063829787, 0.9076345957446807, 0.4791284574468083], 
             UndirectedEdge[109, 360] -> 
             RGBColor[
              0.969752574468085, 0.9061169787234042, 0.40190028723404236`], 
             UndirectedEdge[90, 121] -> 
             RGBColor[
              0.9759518191489363, 0.9696365531914893, 0.672147159574468], 
             UndirectedEdge[75, 202] -> 
             RGBColor[
              0.9812464042553191, 0.9469421914893617, 0.5057658723404252], 
             UndirectedEdge[27, 32] -> 
             RGBColor[
              0.9620588191489361, 0.8810628297872338, 0.5295777446808511], 
             UndirectedEdge[131, 273] -> 
             RGBColor[
              0.9565433829787234, 0.8537469361702128, 0.3912718617021275], 
             UndirectedEdge[160, 220] -> 
             RGBColor[
              0.9619577765957447, 0.9224313617021276, 0.6177829468085105], 
             UndirectedEdge[50, 147] -> 
             RGBColor[
              0.9769540638297872, 0.9339227872340424, 0.364971319148936], 
             UndirectedEdge[13, 339] -> 
             RGBColor[
              0.9436312127659574, 0.8107750212765956, 0.2914626702127658], 
             UndirectedEdge[17, 209] -> 
             RGBColor[
              0.9400426914893616, 0.8010229361702127, 0.5609211702127659], 
             UndirectedEdge[174, 325] -> 
             RGBColor[
              0.9934208617021276, 0.9893540000000001, 0.5992619255319147], 
             UndirectedEdge[21, 78] -> 
             RGBColor[
              0.9805368723404255, 0.945424574468085, 0.4285377021276593], 
             UndirectedEdge[274, 373] -> 
             RGBColor[
              0.9323619361702128, 0.7688549361702128, 0.26802705319148934`], 
             UndirectedEdge[97, 305] -> 
             RGBColor[
              0.9926864680851064, 0.9912436808510638, 0.7708676808510637], 
             UndirectedEdge[11, 162] -> 
             RGBColor[
              0.9766162234042552, 0.9453845531914893, 0.6084544787234041], 
             UndirectedEdge[103, 207] -> 
             RGBColor[
              0.9422149680851064, 0.8249207021276597, 0.5828452340425532], 
             UndirectedEdge[210, 249] -> 
             RGBColor[
              0.9155192978723404, 0.6411340000000001, 0.31771363829787214`], 
             UndirectedEdge[52, 299] -> 
             RGBColor[
              0.9733672872340425, 0.9302349361702127, 0.5668705212765957], 
             UndirectedEdge[43, 373] -> 
             RGBColor[
              0.9196377234042553, 0.7190973829787233, 0.254196829787234], 
             UndirectedEdge[1, 336] -> 
             RGBColor[
              0.9253253297872339, 0.7225085957446806, 0.49935287234042547`], 
             UndirectedEdge[30, 345] -> 
             RGBColor[
              0.9841123936170213, 0.9622905106382978, 0.5796507765957446], 
             UndirectedEdge[247, 363] -> 
             RGBColor[
              0.9283434574468085, 0.7478994468085107, 0.5511590425531914], 
             UndirectedEdge[14, 119] -> 
             RGBColor[
              0.9506483191489362, 0.8290795319148937, 0.4631858191489361], 
             UndirectedEdge[74, 104] -> 
             RGBColor[
              0.9857252234042553, 0.9857552765957447, 0.7252344787234041], 
             UndirectedEdge[258, 277] -> 
             RGBColor[
              0.9521757234042553, 0.8474099999999998, 0.2839696914893616], 
             UndirectedEdge[152, 236] -> 
             RGBColor[
              0.985945585106383, 0.9768546808510639, 0.6446972872340424], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.9722893829787234, 0.9181877234042553, 0.34684991489361694`], 
             UndirectedEdge[120, 132] -> 
             RGBColor[
              0.9937756276595745, 0.9901128085106383, 0.6378760106382977], 
             UndirectedEdge[212, 270] -> 
             RGBColor[
              0.9927146489361702, 0.9902861702127659, 0.6999526489361703], 
             UndirectedEdge[69, 270] -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 
             UndirectedEdge[16, 270] -> 
             RGBColor[
              0.8905103404255319, 0.913168085106383, 0.8870043936170213], 
             UndirectedEdge[24, 73] -> 
             RGBColor[
              0.9460561063829787, 0.8238374680851062, 0.27545368085106375`], 
             UndirectedEdge[56, 178] -> 
             RGBColor[
              0.9661697659574469, 0.8946151914893616, 0.33833390425531906`], 
             UndirectedEdge[6, 319] -> 
             RGBColor[
              0.9606430744680851, 0.8804773829787234, 0.5530402978723403], 
             UndirectedEdge[231, 235] -> 
             RGBColor[
              0.9674800212765957, 0.9736207872340426, 0.8662007872340425], 
             UndirectedEdge[18, 86] -> 
             RGBColor[
              0.9761987765957447, 0.931405829787234, 0.5199454148936169], 
             UndirectedEdge[30, 63] -> 
             RGBColor[
              0.985911085106383, 0.9626772553191489, 0.5238872765957445], 
             UndirectedEdge[46, 358] -> 
             RGBColor[
              0.9540384787234042, 0.8542923617021276, 0.5477260851063829], 
             UndirectedEdge[241, 389] -> 
             RGBColor[
              0.9568981489361702, 0.854505744680851, 0.4298859468085106], 
             UndirectedEdge[286, 332] -> 
             RGBColor[
              0.9941585744680852, 0.9899141063829788, 0.605575063829787], 
             UndirectedEdge[40, 174] -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425531], 
             UndirectedEdge[157, 365] -> 
             RGBColor[
              0.9733672872340425, 0.9302349361702127, 0.5668705212765957], 
             UndirectedEdge[235, 336] -> 
             RGBColor[
              0.9926864680851064, 0.9912436808510638, 0.7708676808510637], 
             UndirectedEdge[76, 222] -> 
             RGBColor[
              0.9323619361702128, 0.7688549361702128, 0.26802705319148934`], 
             UndirectedEdge[115, 392] -> 
             RGBColor[
              0.585833255319149, 0.6461364361702128, 0.6923098617021275], 
             UndirectedEdge[76, 77] -> 
             RGBColor[
              0.9460181382978723, 0.8275218936170214, 0.5658744255319148], 
             UndirectedEdge[160, 366] -> 
             RGBColor[
              0.9712871382978723, 0.9539014893617022, 0.6540257553191489], 
             UndirectedEdge[3, 348] -> 
             RGBColor[
              0.9298337765957447, 0.8156868297872342, 0.6038033617021277], 
             UndirectedEdge[299, 306] -> 
             RGBColor[
              0.9747830319148936, 0.9308203829787234, 0.5434079680851063], 
             UndirectedEdge[56, 121] -> 
             RGBColor[
              0.9661697659574469, 0.8946151914893616, 0.33833390425531906`], 
             UndirectedEdge[280, 322] -> 
             RGBColor[
              0.9411848191489363, 0.951330829787234, 0.7588070638297871], 
             UndirectedEdge[81, 271] -> 
             RGBColor[0.9780319680851064, 0.94597, 0.5849919255319147], 
             UndirectedEdge[2, 191] -> 
             RGBColor[
              0.9898549787234042, 0.9900727872340426, 0.8177927872340425], 
             UndirectedEdge[146, 377] -> 
             RGBColor[
              0.9901928191489362, 0.9786110212765957, 0.5743096276595744], 
             UndirectedEdge[10, 396] -> 
             RGBColor[
              0.9722893829787234, 0.9181877234042553, 0.34684991489361683`], 
             UndirectedEdge[382, 384] -> 
             RGBColor[
              0.8944776382978723, 0.6137294255319147, 0.23366189361702125`], 
             UndirectedEdge[147, 391] -> 
             RGBColor[
              0.9812464042553191, 0.9469421914893617, 0.5057658723404252], 
             UndirectedEdge[133, 216] -> 
             RGBColor[
              0.9912989042553191, 0.9897007234042554, 0.7234152021276594], 
             UndirectedEdge[86, 264] -> 
             RGBColor[
              0.9860518085106382, 0.9874715957446809, 0.8347635957446807], 
             UndirectedEdge[6, 56] -> 
             RGBColor[
              0.9394515106382978, 0.7976524468085104, 0.2701394680851063], 
             UndirectedEdge[43, 308] -> 
             RGBColor[
              0.9502358085106382, 0.8369600425531912, 0.2967768829787232], 
             UndirectedEdge[201, 364] -> 
             RGBColor[
              0.9722893829787234, 0.9181877234042553, 0.34684991489361683`], 
             UndirectedEdge[109, 365] -> 
             RGBColor[
              0.9672476702127659, 0.9066624042553191, 0.5583545106382977], 
             UndirectedEdge[229, 349] -> 
             RGBColor[
              0.9542412659574467, 0.9289325531914892, 0.6568624787234041], 
             UndirectedEdge[216, 231] -> 
             RGBColor[
              0.9675082021276595, 0.9726632765957446, 0.795285755319149], 
             UndirectedEdge[114, 353] -> 
             RGBColor[
              0.985945585106383, 0.9768546808510639, 0.6446972872340424], 
             UndirectedEdge[70, 236] -> 
             RGBColor[
              0.985945585106383, 0.9768546808510639, 0.6446972872340424], 
             UndirectedEdge[64, 94] -> 
             RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 
             UndirectedEdge[240, 285] -> 
             RGBColor[0.918167, 0.6941408723404254, 0.28467341489361697`], 
             UndirectedEdge[56, 90] -> 
             RGBColor[
              0.955838159574468, 0.898858829787234, 0.6092669361702128], 
             UndirectedEdge[90, 295] -> 
             RGBColor[
              0.9420425319148936, 0.9558515744680851, 0.9675826914893617], 
             UndirectedEdge[165, 281] -> 
             RGBColor[
              0.9722893829787234, 0.9181877234042553, 0.34684991489361694`], 
             UndirectedEdge[54, 345] -> 
             RGBColor[
              0.9042948617021276, 0.5623926170212765, 0.47927411702127665`], 
             UndirectedEdge[101, 136] -> 
             RGBColor[
              0.9766162234042552, 0.9453845531914893, 0.6084544787234041], 
             UndirectedEdge[6, 314] -> 
             RGBColor[
              0.9328469148936169, 0.7714674255319146, 0.26482525531914886`], 
             UndirectedEdge[125, 276] -> 
             RGBColor[
              0.9001170851063829, 0.9230599148936169, 0.9857228617021276], 
             UndirectedEdge[244, 341] -> 
             RGBColor[
              0.9521757234042553, 0.8474099999999998, 0.2839696914893616], 
             UndirectedEdge[46, 153] -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425531], 
             UndirectedEdge[14, 336] -> 
             RGBColor[
              0.9488496276595745, 0.8286927872340426, 0.5189493191489362], 
             UndirectedEdge[109, 370] -> 
             RGBColor[
              0.969752574468085, 0.9061169787234042, 0.40190028723404236`], 
             UndirectedEdge[51, 234] -> 
             RGBColor[
              0.9368523723404254, 0.8634399361702125, 0.6249108510638297], 
             UndirectedEdge[144, 228] -> 
             RGBColor[
              0.986283425531915, 0.965392914893617, 0.4012141276595744], 
             UndirectedEdge[320, 347] -> 
             RGBColor[
              0.9758721914893618, 0.9296895106382979, 0.41041629787234024`], 
             UndirectedEdge[31, 106] -> 
             RGBColor[
              0.993069414893617, 0.9910449787234042, 0.738566734042553], 
             UndirectedEdge[77, 103] -> 
             RGBColor[
              0.9460181382978723, 0.8275218936170214, 0.5658744255319148], 
             UndirectedEdge[266, 316] -> 
             RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             UndirectedEdge[109, 334] -> 
             RGBColor[
              0.9620287553191489, 0.9034757659574467, 0.5987878723404254], 
             UndirectedEdge[45, 179] -> 
             RGBColor[
              0.9938038085106383, 0.9891552978723405, 0.566960978723404], 
             UndirectedEdge[181, 191] -> 
             RGBColor[
              0.989883159574468, 0.9891152765957447, 0.7468777553191488], 
             UndirectedEdge[125, 148] -> 
             RGBColor[
              0.940857829787234, 0.9554124468085106, 0.9849964468085107], 
             UndirectedEdge[18, 112] -> 
             RGBColor[
              0.9765817234042553, 0.9312071276595744, 0.4876444680851062], 
             UndirectedEdge[221, 239] -> 
             RGBColor[
              0.9672476702127659, 0.9066624042553191, 0.5583545106382978], 
             UndirectedEdge[57, 76] -> 
             RGBColor[
              0.9488496276595745, 0.8286927872340426, 0.5189493191489363], 
             UndirectedEdge[222, 333] -> 
             RGBColor[
              0.9762269574468085, 0.9304483191489361, 0.44903038297872333`], 
             UndirectedEdge[125, 214] -> 
             RGBColor[
              0.9632327872340425, 0.9718644468085107, 0.9365884468085106], 
             UndirectedEdge[220, 244] -> 
             RGBColor[
              0.9582953404255319, 0.8709825319148935, 0.29248570212765945`], 
             UndirectedEdge[143, 379] -> 
             RGBColor[
              0.9920051170212766, 0.9887685531914894, 0.6227244787234041], 
             UndirectedEdge[31, 241] -> 
             RGBColor[
              0.9927146489361702, 0.9902861702127659, 0.6999526489361703], 
             UndirectedEdge[81, 374] -> 
             RGBColor[
              0.9873613297872341, 0.9774401276595746, 0.621234734042553], 
             UndirectedEdge[168, 304] -> 
             RGBColor[
              0.9368523723404254, 0.8634399361702125, 0.6249108510638298], 
             UndirectedEdge[156, 328] -> 
             RGBColor[
              0.9755174255319149, 0.9289307021276596, 0.3718022127659572], 
             UndirectedEdge[46, 363] -> 
             RGBColor[
              0.9297592021276595, 0.7484848936170214, 0.527696489361702], 
             UndirectedEdge[51, 269] -> 
             RGBColor[
              0.9635027446808511, 0.8806907659574467, 0.435200159574468], 
             UndirectedEdge[13, 325] -> 
             RGBColor[
              0.9801821063829788, 0.9446657659574467, 0.38992361702127626`], 
             UndirectedEdge[164, 374] -> 
             RGBColor[
              0.9661697659574469, 0.8946151914893616, 0.33833390425531906`], 
             UndirectedEdge[49, 199] -> 
             RGBColor[
              0.9214738510638298, 0.6829671489361702, 0.3999644468085106], 
             UndirectedEdge[49, 313] -> 
             RGBColor[
              0.8974226170212766, 0.5999288297872338, 0.23490375531914887`], 
             UndirectedEdge[176, 388] -> 
             RGBColor[
              0.9805368723404255, 0.945424574468085, 0.4285377021276593], 
             UndirectedEdge[45, 232] -> 
             RGBColor[
              0.985911085106383, 0.9626772553191489, 0.5238872765957445], 
             UndirectedEdge[176, 250] -> 
             RGBColor[
              0.9805368723404255, 0.945424574468085, 0.4285377021276593], 
             UndirectedEdge[346, 390] -> 
             RGBColor[
              0.9286812978723404, 0.7364376808510639, 0.3076758829787234], 
             UndirectedEdge[331, 335] -> 
             RGBColor[
              0.955424159574468, 0.8772907446808509, 0.5934736595744681], 
             UndirectedEdge[135, 355] -> 
             RGBColor[
              0.9944851595744681, 0.9916304255319148, 0.7151041808510636], 
             UndirectedEdge[326, 327] -> 
             RGBColor[
              0.9798612127659574, 0.982854659574468, 0.845242659574468], 
             UndirectedEdge[80, 304] -> 
             RGBColor[
              0.959227329787234, 0.8798919361702127, 0.5765028510638297], 
             UndirectedEdge[65, 173] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255319], 
             UndirectedEdge[203, 257] -> 
             RGBColor[
              0.9400426914893616, 0.8010229361702127, 0.5609211702127659], 
             UndirectedEdge[275, 325] -> 
             RGBColor[
              0.966798670212766, 0.9711456595744681, 0.7180575851063828], 
             UndirectedEdge[240, 337] -> 
             RGBColor[
              0.9650965425531914, 0.9492845531914893, 0.6645048191489362], 
             UndirectedEdge[77, 254] -> 
             RGBColor[
              0.987023489361702, 0.9889018936170213, 0.8647178936170211], 
             UndirectedEdge[32, 364] -> 
             RGBColor[
              0.9502358085106382, 0.8369600425531912, 0.2967768829787232], 
             UndirectedEdge[38, 53] -> 
             RGBColor[
              0.9926864680851064, 0.9912436808510638, 0.7708676808510637], 
             UndirectedEdge[28, 291] -> 
             RGBColor[
              0.9722893829787234, 0.9181877234042553, 0.34684991489361683`], 
             UndirectedEdge[174, 269] -> 
             RGBColor[
              0.9941303936170213, 0.9908716170212766, 0.6764900957446808], 
             UndirectedEdge[216, 361] -> 
             RGBColor[
              0.9938038085106383, 0.9891552978723405, 0.5669609787234041], 
             UndirectedEdge[356, 363] -> 
             RGBColor[
              0.9311749468085107, 0.7490703404255319, 0.5042339361702128], 
             UndirectedEdge[151, 383] -> 
             RGBColor[
              0.9529605744680851, 0.8422451489361702, 0.3277054787234042], 
             UndirectedEdge[61, 130] -> 
             RGBColor[
              0.9582953404255319, 0.8709825319148935, 0.29248570212765945`], 
             UndirectedEdge[331, 338] -> 
             RGBColor[
              0.9256558829787234, 0.8546451914893616, 0.6284552234042553], 
             UndirectedEdge[239, 246] -> 
             RGBColor[
              0.9496475638297872, 0.8942418936170211, 0.6197459999999999], 
             UndirectedEdge[190, 212] -> 
             RGBColor[
              0.9927146489361702, 0.9902861702127659, 0.6999526489361703], 
             UndirectedEdge[111, 286] -> 
             RGBColor[
              0.9271240212765957, 0.7228953404255318, 0.4435893723404254], 
             UndirectedEdge[228, 273] -> 
             RGBColor[
              0.9529605744680851, 0.8422451489361702, 0.3277054787234042], 
             UndirectedEdge[199, 299] -> 
             RGBColor[
              0.9762269574468085, 0.9304483191489361, 0.44903038297872333`], 
             UndirectedEdge[50, 391] -> 
             RGBColor[
              0.9905757659574468, 0.9784123191489362, 0.5420086808510637], 
             UndirectedEdge[358, 362] -> 
             RGBColor[
              0.9572529148936171, 0.8552645531914893, 0.4685000319148935], 
             UndirectedEdge[42, 98] -> 
             RGBColor[
              0.9532390212765958, 0.9646463191489361, 0.9640383191489361], 
             UndirectedEdge[39, 251] -> 
             RGBColor[
              0.9559569468085107, 0.9631097234042554, 0.7602160425531914], 
             UndirectedEdge[148, 179] -> 
             RGBColor[
              0.966798670212766, 0.9711456595744681, 0.7180575851063828], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.9848467872340425, 0.9604008297872341, 0.40804502127659553`], 
             UndirectedEdge[77, 333] -> 
             RGBColor[
              0.989883159574468, 0.9891152765957447, 0.7468777553191488], 
             UndirectedEdge[173, 354] -> 
             RGBColor[
              0.9920051170212766, 0.9887685531914894, 0.6227244787234041], 
             UndirectedEdge[160, 217] -> 
             RGBColor[
              0.9492335638297872, 0.8726738085106381, 0.6039527234042552], 
             UndirectedEdge[59, 90] -> 
             RGBColor[
              0.9784454680851064, 0.9822692127659574, 0.8687052127659574], 
             UndirectedEdge[237, 380] -> 
             RGBColor[
              0.9492335638297872, 0.8726738085106381, 0.6039527234042552], 
             UndirectedEdge[285, 399] -> 
             RGBColor[
              0.9267692553191489, 0.7221365319148935, 0.4049752872340425], 
             UndirectedEdge[51, 392] -> 
             RGBColor[
              0.5558869574468085, 0.5384307127659573, 0.5991631276595744], 
             UndirectedEdge[264, 307] -> 
             RGBColor[
              0.9857252234042553, 0.9857552765957447, 0.7252344787234041], 
             UndirectedEdge[78, 208] -> 
             RGBColor[
              0.9812464042553191, 0.9469421914893617, 0.5057658723404252], 
             UndirectedEdge[28, 383] -> 
             RGBColor[
              0.9769540638297872, 0.9339227872340424, 0.364971319148936], 
             UndirectedEdge[255, 268] -> 
             RGBColor[
              0.9848467872340425, 0.9604008297872341, 0.40804502127659553`], 
             UndirectedEdge[46, 247] -> 
             RGBColor[
              0.987023489361702, 0.9889018936170213, 0.8647178936170211], 
             UndirectedEdge[272, 392] -> 
             RGBColor[
              0.5836831170212766, 0.647440670212766, 0.8873781702127659], 
             UndirectedEdge[316, 359] -> 
             RGBColor[
              0.9193519361702127, 0.7049675531914893, 0.27143307446808496`], 
             UndirectedEdge[223, 242] -> 
             RGBColor[
              0.9766162234042552, 0.9453845531914893, 0.6084544787234041], 
             UndirectedEdge[158, 390] -> 
             RGBColor[
              0.9329736382978724, 0.7494570851063831, 0.44847043617021265`], 
             UndirectedEdge[26, 128] -> 
             RGBColor[
              0.906471244680851, 0.7757761914893616, 0.6128735425531915], 
             UndirectedEdge[136, 335] -> 
             RGBColor[
              0.9728130531914894, 0.9427833617021275, 0.6254252872340423], 
             UndirectedEdge[193, 248] -> 
             RGBColor[
              0.9460181382978723, 0.8275218936170214, 0.5658744255319148], 
             UndirectedEdge[281, 386] -> 
             RGBColor[
              0.9629600212765956, 0.8867175957446807, 0.3106071063829785], 
             UndirectedEdge[225, 337] -> 
             RGBColor[
              0.9604318617021276, 0.933549489361702, 0.646383414893617], 
             UndirectedEdge[30, 297] -> 
             RGBColor[
              0.9855281382978723, 0.9628759574468084, 0.5561882234042552], 
             UndirectedEdge[32, 104] -> 
             RGBColor[
              0.955424159574468, 0.8772907446808509, 0.5934736595744681], 
             UndirectedEdge[264, 366] -> 
             RGBColor[
              0.9774777340425531, 0.9585184255319149, 0.6435466914893616], 
             UndirectedEdge[2, 97] -> 
             RGBColor[
              0.9926864680851064, 0.9912436808510638, 0.7708676808510637], 
             UndirectedEdge[258, 377] -> 
             RGBColor[
              0.9761987765957447, 0.931405829787234, 0.5199454148936169], 
             UndirectedEdge[134, 135] -> 
             RGBColor[
              0.9634745638297872, 0.8816482765957445, 0.5061151914893616], 
             UndirectedEdge[185, 338] -> 
             RGBColor[
              0.8947720106382979, 0.7226527021276596, 0.603111414893617], 
             UndirectedEdge[40, 84] -> 
             RGBColor[
              0.987023489361702, 0.9889018936170213, 0.8647178936170211], 
             UndirectedEdge[217, 242] -> 
             RGBColor[
              0.9502358085106382, 0.8369600425531912, 0.2967768829787232], 
             UndirectedEdge[124, 266] -> 
             RGBColor[
              0.9135023191489361, 0.678405808510638, 0.2665520106382977], 
             UndirectedEdge[219, 293] -> 
             RGBColor[
              0.9620287553191489, 0.9034757659574467, 0.5987878723404254], 
             UndirectedEdge[37, 170] -> 
             RGBColor[
              0.9938038085106383, 0.9891552978723405, 0.566960978723404], 
             UndirectedEdge[205, 293] -> 
             RGBColor[
              0.9422149680851064, 0.8249207021276597, 0.5828452340425532], 
             UndirectedEdge[122, 268] -> 
             RGBColor[
              0.9841123936170213, 0.9622905106382978, 0.5796507765957446], 
             UndirectedEdge[246, 392] -> 
             RGBColor[
              0.5660830106382978, 0.6350201595744681, 0.9487696595744681], 
             UndirectedEdge[282, 398] -> 
             RGBColor[
              0.9615050851063829, 0.8788801276595744, 0.3202124999999999], 
             UndirectedEdge[34, 248] -> 
             RGBColor[
              0.981804574468085, 0.985715255319149, 0.9051512553191488], 
             UndirectedEdge[263, 264] -> 
             RGBColor[
              0.9681483723404255, 0.9270482978723404, 0.6073038829787233], 
             UndirectedEdge[100, 377] -> 
             RGBColor[
              0.9944851595744681, 0.9916304255319148, 0.7151041808510636], 
             UndirectedEdge[107, 241] -> 
             RGBColor[
              0.9568981489361702, 0.854505744680851, 0.4298859468085106], 
             UndirectedEdge[11, 95] -> 
             RGBColor[
              0.9895283936170213, 0.9883564680851065, 0.7082636702127658], 
             UndirectedEdge[7, 96] -> 
             RGBColor[
              0.9719515425531915, 0.9296494893617021, 0.590333074468085], 
             UndirectedEdge[111, 383] -> 
             RGBColor[
              0.9228316808510638, 0.7098759361702126, 0.30279481914893613`], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255319], 
             UndirectedEdge[121, 122] -> 
             RGBColor[
              0.988777074468085, 0.978025574468085, 0.5977721808510639], 
             UndirectedEdge[156, 221] -> 
             RGBColor[
              0.9905893723404255, 0.9881831063829788, 0.6461870319148934], 
             UndirectedEdge[61, 176] -> 
             RGBColor[
              0.9758721914893618, 0.9296895106382979, 0.41041629787234024`], 
             UndirectedEdge[128, 261] -> 
             RGBColor[
              0.9439633404255319, 0.8010629574468084, 0.3810043936170211], 
             UndirectedEdge[69, 381] -> 
             RGBColor[
              0.993069414893617, 0.9910449787234042, 0.738566734042553], 
             UndirectedEdge[166, 178] -> 
             RGBColor[0.990221, 0.9776535106382979, 0.5033945957446808], 
             UndirectedEdge[114, 202] -> 
             RGBColor[
              0.9769540638297872, 0.9339227872340424, 0.364971319148936], 
             UndirectedEdge[40, 134] -> 
             RGBColor[
              0.9606430744680851, 0.8804773829787234, 0.5530402978723403], 
             UndirectedEdge[84, 234] -> 
             RGBColor[
              0.9632327872340425, 0.9718644468085107, 0.9365884468085106], 
             UndirectedEdge[236, 367] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255319], 
             UndirectedEdge[307, 366] -> 
             RGBColor[
              0.9852015531914894, 0.9611596382978724, 0.44665910638297857`], 
             UndirectedEdge[129, 396] -> 
             RGBColor[
              0.9812809042553191, 0.9611196170212766, 0.6265758829787234], 
             UndirectedEdge[67, 208] -> 
             RGBColor[
              0.991653670212766, 0.9904595319148937, 0.7620292872340424], 
             UndirectedEdge[203, 309] -> 
             RGBColor[
              0.9300489255319149, 0.7938048085106382, 0.5883710425531914], 
             UndirectedEdge[142, 302] -> 
             RGBColor[
              0.9761987765957447, 0.931405829787234, 0.5199454148936169], 
             UndirectedEdge[93, 248] -> 
             RGBColor[
              0.9902379255319149, 0.989874085106383, 0.7854918404255318], 
             UndirectedEdge[110, 227] -> 
             RGBColor[
              0.9542412659574467, 0.9289325531914892, 0.6568624787234041], 
             UndirectedEdge[129, 361] -> 
             RGBColor[
              0.9895283936170213, 0.9883564680851065, 0.7082636702127658], 
             UndirectedEdge[236, 332] -> 
             RGBColor[
              0.9895283936170213, 0.9883564680851065, 0.7082636702127658], 
             UndirectedEdge[306, 353] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255319], 
             UndirectedEdge[257, 280] -> 
             RGBColor[
              0.937264170212766, 0.9512908085106384, 0.9387238404255318], 
             UndirectedEdge[208, 385] -> 
             RGBColor[
              0.9864347553191489, 0.9872728936170213, 0.80246264893617], 
             UndirectedEdge[79, 302] -> 
             RGBColor[
              0.9901928191489362, 0.9786110212765957, 0.5743096276595744], 
             UndirectedEdge[21, 242] -> 
             RGBColor[
              0.9805368723404255, 0.945424574468085, 0.4285377021276593], 
             UndirectedEdge[94, 103] -> 
             RGBColor[
              0.9502653723404255, 0.8292782340425533, 0.4954867659574468], 
             UndirectedEdge[237, 308] -> 
             RGBColor[
              0.9666224574468085, 0.9381664255319148, 0.6359043510638296], 
             UndirectedEdge[1, 235] -> 
             RGBColor[
              0.9267410744680851, 0.7230940425531913, 0.4758903191489361], 
             UndirectedEdge[31, 374] -> 
             RGBColor[
              0.988777074468085, 0.978025574468085, 0.5977721808510639], 
             UndirectedEdge[324, 351] -> 
             RGBColor[
              0.9470484255319148, 0.9600293829787234, 0.9745173829787235], 
             UndirectedEdge[62, 396] -> 
             RGBColor[
              0.9769540638297872, 0.9339227872340425, 0.3649713191489361], 
             UndirectedEdge[13, 123] -> 
             RGBColor[
              0.8977168723404254, 0.5586053617021274, 0.25149589361702107`], 
             UndirectedEdge[112, 337] -> 
             RGBColor[
              0.9740535638297871, 0.9780390212765957, 0.8234207765957446], 
             UndirectedEdge[262, 286] -> 
             RGBColor[
              0.9938038085106383, 0.9891552978723405, 0.566960978723404], 
             UndirectedEdge[56, 59] -> 
             RGBColor[
              0.968663414893617, 0.9072478510638297, 0.5348919574468085], 
             UndirectedEdge[61, 118] -> 
             RGBColor[
              0.9582953404255319, 0.8709825319148935, 0.29248570212765945`], 
             UndirectedEdge[14, 235] -> 
             RGBColor[
              0.9502653723404255, 0.8292782340425533, 0.4954867659574468], 
             UndirectedEdge[154, 286] -> 
             RGBColor[
              0.993069414893617, 0.9910449787234042, 0.738566734042553], 
             UndirectedEdge[159, 215] -> 
             RGBColor[
              0.9756139787234042, 0.9810983191489362, 0.9156303191489361], 
             UndirectedEdge[25, 385] -> 
             RGBColor[
              0.986079989361702, 0.9865140851063829, 0.7638485638297872], 
             UndirectedEdge[165, 256] -> 
             RGBColor[
              0.9901928191489362, 0.9786110212765957, 0.5743096276595744], 
             UndirectedEdge[292, 384] -> 
             RGBColor[
              0.8769269893617021, 0.752218404255319, 0.6100555851063829], 
             UndirectedEdge[1, 49] -> 
             RGBColor[
              0.8540845319148935, 0.41518957446808485`, 0.1993646702127659], 
             UndirectedEdge[93, 125] -> 
             RGBColor[
              0.9678629680851063, 0.973422085106383, 0.8338998404255318], 
             UndirectedEdge[15, 37] -> 
             RGBColor[
              0.9693978085106383, 0.9053581702127659, 0.3632862021276594], 
             UndirectedEdge[141, 399] -> 
             RGBColor[
              0.9808916382978723, 0.9461833829787233, 0.4671517872340424], 
             UndirectedEdge[42, 288] -> 
             RGBColor[
              0.9674800212765957, 0.9736207872340426, 0.8662007872340425], 
             UndirectedEdge[26, 218] -> 
             RGBColor[
              0.9036927234042553, 0.9260440638297873, 0.9906762127659574], 
             UndirectedEdge[292, 389] -> 
             RGBColor[
              0.8895070319148937, 0.8049023829787233, 0.6203230531914894], 
             UndirectedEdge[87, 361] -> 
             RGBColor[
              0.9439633404255319, 0.8010629574468084, 0.3810043936170211], 
             UndirectedEdge[3, 11] -> 
             RGBColor[
              0.9694233829787233, 0.9764813829787234, 0.9261093829787234], 
             UndirectedEdge[217, 364] -> 
             RGBColor[
              0.9502358085106382, 0.8369600425531912, 0.2967768829787232], 
             UndirectedEdge[83, 120] -> 
             RGBColor[
              0.9805368723404255, 0.945424574468085, 0.4285377021276593], 
             UndirectedEdge[251, 380] -> 
             RGBColor[
              0.9256558829787234, 0.8546451914893616, 0.6284552234042553], 
             UndirectedEdge[209, 390] -> 
             RGBColor[
              0.9283434574468085, 0.7478994468085107, 0.5511590425531914], 
             UndirectedEdge[149, 315] -> 
             RGBColor[
              0.9891736276595744, 0.9875976595744682, 0.6696495851063827], 
             UndirectedEdge[34, 263] -> 
             RGBColor[
              0.9681483723404255, 0.9270482978723404, 0.6073038829787233], 
             UndirectedEdge[327, 376] -> 
             RGBColor[
              0.9791798617021277, 0.9803795319148936, 0.6970994574468083], 
             UndirectedEdge[113, 316] -> 
             RGBColor[
              0.9502358085106382, 0.8369600425531912, 0.2967768829787232], 
             UndirectedEdge[85, 307] -> 
             RGBColor[
              0.9805368723404255, 0.945424574468085, 0.4285377021276593], 
             UndirectedEdge[140, 257] -> 
             RGBColor[
              0.9526227340425532, 0.8537069148936169, 0.5711886382978723], 
             UndirectedEdge[228, 330] -> 
             RGBColor[
              0.9898662340425533, 0.9768947021276596, 0.46478051063829773`], 
             UndirectedEdge[22, 96] -> 
             RGBColor[
              0.9895283936170213, 0.9883564680851065, 0.7082636702127658], 
             UndirectedEdge[22, 323] -> 
             RGBColor[
              0.9923598829787235, 0.9895273617021276, 0.6613385638297871], 
             UndirectedEdge[167, 269] -> 
             RGBColor[
              0.9762269574468085, 0.9304483191489361, 0.44903038297872333`], 
             UndirectedEdge[85, 214] -> 
             RGBColor[
              0.9766162234042552, 0.9453845531914893, 0.6084544787234041], 
             UndirectedEdge[89, 155] -> 
             RGBColor[
              0.9267392765957447, 0.9412682553191489, 0.8669272021276595], 
             UndirectedEdge[1, 396] -> 
             RGBColor[0.918167, 0.6941408723404254, 0.28467341489361697`], 
             UndirectedEdge[172, 208] -> 
             RGBColor[
              0.9905757659574468, 0.9784123191489362, 0.5420086808510637], 
             UndirectedEdge[45, 339] -> 
             RGBColor[
              0.9572529148936171, 0.8552645531914893, 0.4685000319148935], 
             UndirectedEdge[250, 363] -> 
             RGBColor[
              0.9193519361702127, 0.7049675531914893, 0.27143307446808496`], 
             UndirectedEdge[167, 222] -> 
             RGBColor[
              0.9582953404255319, 0.8709825319148935, 0.29248570212765945`], 
             UndirectedEdge[73, 208] -> 
             RGBColor[
              0.9704621063829787, 0.9076345957446807, 0.4791284574468083], 
             UndirectedEdge[14, 317] -> 
             RGBColor[
              0.9196377234042553, 0.7190973829787233, 0.254196829787234], 
             UndirectedEdge[157, 334] -> 
             RGBColor[
              0.9681483723404255, 0.9270482978723404, 0.6073038829787233], 
             UndirectedEdge[107, 190] -> 
             RGBColor[
              0.9554542234042553, 0.8548778085106382, 0.5242635319148936], 
             UndirectedEdge[12, 209] -> 
             RGBColor[
              0.9898549787234042, 0.9900727872340426, 0.8177927872340425], 
             UndirectedEdge[185, 219] -> 
             RGBColor[
              0.9085676382978722, 0.6656599574468085, 0.24479565957446806`], 
             UndirectedEdge[318, 345] -> 
             RGBColor[
              0.9926864680851064, 0.9912436808510638, 0.7708676808510637], 
             UndirectedEdge[36, 383] -> 
             RGBColor[
              0.985945585106383, 0.9768546808510639, 0.6446972872340424], 
             UndirectedEdge[24, 357] -> 
             RGBColor[
              0.9202668723404255, 0.7187834468085104, 0.2545577872340425], 
             UndirectedEdge[344, 354] -> 
             RGBColor[
              0.9627932127659574, 0.87917314893617, 0.35797198936170194`], 
             UndirectedEdge[7, 194] -> 
             RGBColor[
              0.9455711276595744, 0.821224978723404, 0.2786554787234041], 
             UndirectedEdge[97, 248] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255319], 
             UndirectedEdge[14, 129] -> 
             RGBColor[
              0.9460181382978723, 0.8275218936170214, 0.5658744255319148], 
             UndirectedEdge[160, 307] -> 
             RGBColor[
              0.9795346276595744, 0.9811383404255319, 0.7357135425531913], 
             UndirectedEdge[165, 400] -> 
             RGBColor[
              0.9529605744680851, 0.8422451489361702, 0.3277054787234042], 
             UndirectedEdge[310, 323] -> 
             RGBColor[
              0.9554542234042553, 0.8548778085106382, 0.5242635319148936], 
             UndirectedEdge[309, 339] -> 
             RGBColor[
              0.9426289680851063, 0.8464887872340425, 0.5986385106382979], 
             UndirectedEdge[355, 395] -> 
             RGBColor[
              0.993069414893617, 0.9910449787234042, 0.738566734042553], 
             UndirectedEdge[32, 240] -> 
             RGBColor[
              0.9549004893617021, 0.8526951063829786, 0.31489828723404245`], 
             UndirectedEdge[66, 322] -> 
             RGBColor[
              0.9930942765957447, 0.9876376808510638, 0.489732808510638], 
             UndirectedEdge[28, 267] -> 
             RGBColor[
              0.9808916382978723, 0.9461833829787233, 0.4671517872340424], 
             UndirectedEdge[51, 102] -> 
             RGBColor[
              0.9634745638297872, 0.8816482765957445, 0.5061151914893616], 
             UndirectedEdge[244, 321] -> 
             RGBColor[
              0.9088376382978722, 0.6626707446808509, 0.24843060638297865`], 
             UndirectedEdge[140, 309] -> 
             RGBColor[
              0.9426289680851063, 0.8464887872340425, 0.5986385106382979], 
             UndirectedEdge[12, 324] -> 
             RGBColor[
              0.9736706170212766, 0.9782377234042553, 0.8557217234042553], 
             UndirectedEdge[130, 287] -> 
             RGBColor[
              0.9719515425531915, 0.9296494893617021, 0.590333074468085], 
             UndirectedEdge[267, 367] -> 
             RGBColor[
              0.9927146489361702, 0.9902861702127659, 0.6999526489361703], 
             UndirectedEdge[138, 229] -> 
             RGBColor[
              0.9769540638297872, 0.9339227872340424, 0.364971319148936], 
             UndirectedEdge[97, 193] -> 
             RGBColor[
              0.9488496276595745, 0.8286927872340426, 0.5189493191489363], 
             UndirectedEdge[248, 340] -> 
             RGBColor[
              0.989883159574468, 0.9891152765957447, 0.7468777553191488], 
             UndirectedEdge[162, 248] -> 
             RGBColor[
              0.9766162234042552, 0.9453845531914893, 0.6084544787234041], 
             UndirectedEdge[127, 317] -> 
             RGBColor[
              0.9595651702127659, 0.8684301702127658, 0.3330196914893616], 
             UndirectedEdge[269, 355] -> 
             RGBColor[
              0.994513340425532, 0.9906729148936171, 0.6441891489361701], 
             UndirectedEdge[161, 184] -> 
             RGBColor[
              0.986079989361702, 0.9865140851063829, 0.7638485638297872], 
             UndirectedEdge[340, 360] -> 
             RGBColor[
              0.9938038085106383, 0.9891552978723405, 0.5669609787234041], 
             UndirectedEdge[19, 185] -> 
             RGBColor[
              0.9183496914893616, 0.7406813191489362, 0.578608914893617], 
             UndirectedEdge[240, 357] -> 
             RGBColor[
              0.9357158510638297, 0.7738261063829786, 0.2993166063829787], 
             UndirectedEdge[75, 132] -> 
             RGBColor[
              0.9944851595744681, 0.9916304255319148, 0.7151041808510636], 
             UndirectedEdge[89, 353] -> 
             RGBColor[
              0.9898549787234042, 0.9900727872340426, 0.8177927872340425], 
             UndirectedEdge[214, 312] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255319], 
             UndirectedEdge[119, 129] -> 
             RGBColor[
              0.9902379255319149, 0.989874085106383, 0.7854918404255318], 
             UndirectedEdge[143, 377] -> 
             RGBColor[
              0.9926864680851064, 0.9912436808510638, 0.7708676808510637], 
             UndirectedEdge[5, 122] -> 
             RGBColor[
              0.993069414893617, 0.9910449787234042, 0.738566734042553], 
             UndirectedEdge[42, 318] -> 
             RGBColor[
              0.9674800212765957, 0.9736207872340426, 0.8662007872340425], 
             UndirectedEdge[6, 137] -> 
             RGBColor[
              0.9430429680851062, 0.8680568723404254, 0.6144317872340426], 
             UndirectedEdge[113, 149] -> 
             RGBColor[
              0.959227329787234, 0.8798919361702127, 0.5765028510638297], 
             UndirectedEdge[67, 124] -> 
             RGBColor[
              0.923909585106383, 0.7219231489361702, 0.5228154255319148], 
             UndirectedEdge[141, 337] -> 
             RGBColor[
              0.9604318617021276, 0.933549489361702, 0.646383414893617], 
             UndirectedEdge[63, 224] -> 
             RGBColor[
              0.9948681063829787, 0.9914317234042553, 0.6828032340425529], 
             UndirectedEdge[244, 357] -> 
             RGBColor[
              0.9263864893617021, 0.7423559787234041, 0.26307379787234036`], 
             UndirectedEdge[9, 192] -> 
             RGBColor[
              0.9736706170212766, 0.9782377234042553, 0.8557217234042553], 
             UndirectedEdge[46, 369] -> 
             RGBColor[
              0.9832203191489362, 0.9863007021276596, 0.8816887021276594], 
             UndirectedEdge[350, 392] -> 
             RGBColor[
              0.5779405319148936, 0.6196583936170212, 0.649236159574468], 
             UndirectedEdge[275, 339] -> 
             RGBColor[
              0.9302477765957446, 0.8372549148936169, 0.6195966382978724], 
             UndirectedEdge[119, 127] -> 
             RGBColor[
              0.9905757659574468, 0.9784123191489362, 0.5420086808510637], 
             UndirectedEdge[152, 398] -> 
             RGBColor[
              0.9661697659574469, 0.8946151914893616, 0.33833390425531906`], 
             UndirectedEdge[105, 229] -> 
             RGBColor[
              0.9812464042553191, 0.9469421914893617, 0.5057658723404252], 
             UndirectedEdge[181, 365] -> 
             RGBColor[
              0.9912989042553191, 0.9897007234042554, 0.7234152021276594], 
             UndirectedEdge[24, 285] -> 
             RGBColor[
              0.9027180212765957, 0.6390982127659572, 0.23991459574468077`], 
             UndirectedEdge[167, 189] -> 
             RGBColor[
              0.9747830319148936, 0.9308203829787234, 0.5434079680851063], 
             UndirectedEdge[157, 191] -> 
             RGBColor[
              0.9719515425531915, 0.9296494893617021, 0.590333074468085], 
             UndirectedEdge[78, 194] -> 
             RGBColor[
              0.9502358085106382, 0.8369600425531912, 0.2967768829787232], 
             UndirectedEdge[107, 268] -> 
             RGBColor[
              0.9482958936170213, 0.8265100851063829, 0.30958407446808506`], 
             UndirectedEdge[5, 274] -> 
             RGBColor[
              0.9765817234042553, 0.9312071276595744, 0.4876444680851062], 
             UndirectedEdge[12, 118] -> 
             RGBColor[
              0.9761987765957447, 0.931405829787234, 0.5199454148936169], 
             UndirectedEdge[20, 291] -> 
             RGBColor[
              0.6997560319148937, 0.7371715106382979, 0.6565586595744681], 
             UndirectedEdge[6, 379] -> 
             RGBColor[
              0.9627932127659574, 0.87917314893617, 0.35797198936170194`], 
             UndirectedEdge[97, 181] -> 
             RGBColor[
              0.9927146489361702, 0.9902861702127659, 0.6999526489361703], 
             UndirectedEdge[39, 320] -> 
             RGBColor[
              0.9934490425531916, 0.9883964893617022, 0.528346893617021], 
             UndirectedEdge[202, 218] -> 
             RGBColor[
              0.9282726489361701, 0.9083589148936169, 0.6589978723404254], 
             UndirectedEdge[61, 344] -> 
             RGBColor[
              0.9455711276595744, 0.821224978723404, 0.2786554787234041], 
             UndirectedEdge[181, 214] -> 
             RGBColor[
              0.989883159574468, 0.9891152765957447, 0.7468777553191488], 
             UndirectedEdge[274, 324] -> 
             RGBColor[
              0.9557671808510637, 0.9178144255319148, 0.6282620106382979], 
             UndirectedEdge[62, 231] -> 
             RGBColor[
              0.9589059468085106, 0.9446676170212766, 0.6749838829787234], 
             UndirectedEdge[117, 289] -> 
             RGBColor[
              0.9430447765957446, 0.9201378085106382, 0.6604068510638297], 
             UndirectedEdge[14, 396] -> 
             RGBColor[
              0.9416912978723404, 0.8003250638297873, 0.30426986170212766`], 
             UndirectedEdge[79, 175] -> 
             RGBColor[
              0.9816187446808511, 0.9496578510638298, 0.38309272340425526`], 
             UndirectedEdge[246, 395] -> 
             RGBColor[
              0.9722548723404254, 0.9776522765957447, 0.8791842765957447], 
             UndirectedEdge[87, 396] -> 
             RGBColor[
              0.9357158510638297, 0.7738261063829786, 0.2993166063829787], 
             UndirectedEdge[341, 366] -> 
             RGBColor[
              0.9615050851063829, 0.8788801276595744, 0.3202124999999999], 
             UndirectedEdge[40, 226] -> 
             RGBColor[
              0.987023489361702, 0.9889018936170213, 0.8647178936170211], 
             UndirectedEdge[67, 316] -> 
             RGBColor[0.9780319680851064, 0.94597, 0.5849919255319147], 
             UndirectedEdge[303, 376] -> 
             RGBColor[
              0.9408300531914894, 0.9505720212765958, 0.720192978723404], 
             UndirectedEdge[208, 357] -> 
             RGBColor[
              0.9446728723404255, 0.802580574468085, 0.4582325638297871], 
             UndirectedEdge[54, 66] -> 
             RGBColor[
              0.905029255319149, 0.5605029361702127, 0.3076683617021275], 
             UndirectedEdge[3, 160] -> 
             RGBColor[
              0.9594296170212766, 0.9692632553191489, 0.953559255319149], 
             UndirectedEdge[230, 328] -> 
             RGBColor[
              0.914687255319149, 0.6892324893617021, 0.2533116702127659], 
             UndirectedEdge[282, 383] -> 
             RGBColor[
              0.9816187446808511, 0.9496578510638298, 0.38309272340425526`], 
             UndirectedEdge[106, 150] -> 
             RGBColor[
              0.9329736382978724, 0.7494570851063831, 0.44847043617021265`], 
             UndirectedEdge[1, 298] -> 
             RGBColor[
              0.9271240212765957, 0.7228953404255318, 0.4435893723404254], 
             UndirectedEdge[66, 131] -> 
             RGBColor[
              0.9930942765957447, 0.9876376808510638, 0.489732808510638], 
             UndirectedEdge[53, 126] -> 
             RGBColor[
              0.9898549787234042, 0.9900727872340426, 0.8177927872340425], 
             UndirectedEdge[182, 281] -> 
             RGBColor[
              0.9263864893617021, 0.7423559787234041, 0.26307379787234036`], 
             UndirectedEdge[74, 263] -> 
             RGBColor[
              0.9758721914893618, 0.9296895106382979, 0.41041629787234024`], 
             UndirectedEdge[24, 243] -> 
             RGBColor[
              0.9661697659574469, 0.8946151914893616, 0.33833390425531906`], 
             UndirectedEdge[177, 252] -> 
             RGBColor[
              0.9898662340425533, 0.9768947021276596, 0.46478051063829773`], 
             UndirectedEdge[10, 216] -> 
             RGBColor[
              0.9808916382978723, 0.9461833829787233, 0.4671517872340424], 
             UndirectedEdge[280, 339] -> 
             RGBColor[
              0.9042791595744681, 0.8166812765957446, 0.6217320319148936], 
             UndirectedEdge[152, 154] -> 
             RGBColor[
              0.988777074468085, 0.978025574468085, 0.5977721808510639], 
             UndirectedEdge[36, 304] -> 
             RGBColor[
              0.959227329787234, 0.8798919361702127, 0.5765028510638297], 
             UndirectedEdge[128, 299] -> 
             RGBColor[
              0.9263864893617021, 0.7423559787234041, 0.26307379787234036`], 
             UndirectedEdge[95, 162] -> 
             RGBColor[
              0.9805368723404255, 0.945424574468085, 0.4285377021276593], 
             UndirectedEdge[215, 329] -> 
             RGBColor[
              0.9770297234042553, 0.9816837659574469, 0.8921677659574467], 
             UndirectedEdge[208, 387] -> 
             RGBColor[
              0.9271222234042553, 0.9410695531914893, 0.8346262553191488], 
             UndirectedEdge[178, 197] -> 
             RGBColor[
              0.9873613297872341, 0.9774401276595746, 0.621234734042553], 
             UndirectedEdge[53, 303] -> 
             RGBColor[
              0.9415114042553192, 0.9530471489361703, 0.8683361808510638], 
             UndirectedEdge[59, 121] -> 
             RGBColor[
              0.988777074468085, 0.978025574468085, 0.5977721808510639], 
             UndirectedEdge[134, 269] -> 
             RGBColor[
              0.9635027446808511, 0.8806907659574467, 0.435200159574468], 
             UndirectedEdge[44, 362] -> 
             RGBColor[
              0.994513340425532, 0.9906729148936171, 0.6441891489361701], 
             UndirectedEdge[284, 338] -> 
             RGBColor[
              0.9383800957446808, 0.904402744680851, 0.6422854468085106], 
             UndirectedEdge[12, 346] -> 
             RGBColor[
              0.9901928191489362, 0.9786110212765957, 0.5743096276595744], 
             UndirectedEdge[113, 387] -> 
             RGBColor[
              0.8961116276595744, 0.8310874042553189, 0.6256372659574467], 
             UndirectedEdge[55, 400] -> 
             RGBColor[
              0.9554542234042553, 0.8548778085106382, 0.5242635319148936], 
             UndirectedEdge[25, 201] -> 
             RGBColor[
              0.9855563191489362, 0.9619184468085107, 0.48527319148936165`], 
             UndirectedEdge[123, 309] -> 
             RGBColor[
              0.8967146276595744, 0.5943191276595743, 0.5586717340425531], 
             UndirectedEdge[35, 162] -> 
             RGBColor[
              0.931051170212766, 0.7580910425531913, 0.2811952021276594], 
             UndirectedEdge[73, 172] -> 
             RGBColor[
              0.9661697659574469, 0.8946151914893616, 0.33833390425531906`], 
             UndirectedEdge[137, 282] -> 
             RGBColor[
              0.9650965425531914, 0.9492845531914893, 0.6645048191489362], 
             UndirectedEdge[37, 114] -> 
             RGBColor[
              0.9895114680851065, 0.9761358936170212, 0.4261664255319147], 
             UndirectedEdge[214, 248] -> 
             RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 
             UndirectedEdge[161, 363] -> 
             RGBColor[
              0.9245402872340425, 0.745298255319149, 0.5681298510638297], 
             UndirectedEdge[51, 84] -> 
             RGBColor[
              0.959227329787234, 0.8798919361702127, 0.5765028510638297], 
             UndirectedEdge[56, 278] -> 
             RGBColor[
              0.970079159574468, 0.9078332978723402, 0.511429404255319], 
             UndirectedEdge[4, 140] -> 
             RGBColor[
              0.9540384787234042, 0.8542923617021276, 0.5477260851063829], 
             UndirectedEdge[221, 351] -> 
             RGBColor[
              0.9646485319148936, 0.9724498936170213, 0.9131258936170212], 
             UndirectedEdge[54, 204] -> 
             RGBColor[
              0.9028791170212767, 0.561807170212766, 0.5027366702127659], 
             UndirectedEdge[10, 298] -> 
             RGBColor[
              0.9812464042553191, 0.9469421914893617, 0.5057658723404252], 
             UndirectedEdge[134, 226] -> 
             RGBColor[
              0.959227329787234, 0.8798919361702127, 0.5765028510638297], 
             UndirectedEdge[35, 98] -> 
             RGBColor[
              0.9300489255319149, 0.7938048085106382, 0.5883710425531914], 
             UndirectedEdge[70, 180] -> 
             RGBColor[
              0.985945585106383, 0.9768546808510639, 0.6446972872340424], 
             UndirectedEdge[165, 328] -> 
             RGBColor[
              0.9722893829787234, 0.9181877234042553, 0.34684991489361694`], 
             UndirectedEdge[162, 214] -> 
             RGBColor[
              0.9766162234042552, 0.9453845531914893, 0.6084544787234041], 
             UndirectedEdge[211, 370] -> 
             RGBColor[
              0.9941585744680852, 0.9899141063829788, 0.605575063829787], 
             UndirectedEdge[55, 245] -> 
             RGBColor[
              0.9105514042553191, 0.928903914893617, 0.8889807765957447], 
             UndirectedEdge[247, 315] -> 
             RGBColor[
              0.9891736276595744, 0.9875976595744682, 0.6696495851063827], 
             UndirectedEdge[16, 268] -> 
             RGBColor[
              0.8833520106382979, 0.8848003617021276, 0.6723249361702127], 
             UndirectedEdge[154, 291] -> 
             RGBColor[
              0.9841123936170213, 0.9622905106382978, 0.5796507765957446], 
             UndirectedEdge[296, 373] -> 
             RGBColor[
              0.9460181382978723, 0.8275218936170214, 0.5658744255319148], 
             UndirectedEdge[101, 394] -> 
             RGBColor[
              0.9895283936170213, 0.9883564680851065, 0.7082636702127658], 
             UndirectedEdge[173, 388] -> 
             RGBColor[
              0.9794477127659573, 0.9465554468085104, 0.5615293723404253], 
             UndirectedEdge[84, 102] -> 
             RGBColor[
              0.9898549787234042, 0.9900727872340426, 0.8177927872340425], 
             UndirectedEdge[216, 298] -> 
             RGBColor[
              0.994513340425532, 0.9906729148936171, 0.6441891489361701], 
             UndirectedEdge[209, 310] -> 
             RGBColor[
              0.9526227340425532, 0.8537069148936169, 0.5711886382978723], 
             UndirectedEdge[34, 93] -> 
             RGBColor[
              0.9864347553191489, 0.9872728936170213, 0.80246264893617], 
             UndirectedEdge[112, 285] -> 
             RGBColor[
              0.9271240212765957, 0.7228953404255318, 0.4435893723404254], 
             UndirectedEdge[131, 309] -> 
             RGBColor[
              0.9795346276595744, 0.9811383404255319, 0.7357135425531913], 
             UndirectedEdge[116, 265] -> 
             RGBColor[
              0.9938038085106383, 0.9891552978723405, 0.5669609787234041], 
             UndirectedEdge[49, 129] -> 
             RGBColor[
              0.9171984361702128, 0.682168319148936, 0.5412671382978722], 
             UndirectedEdge[238, 325] -> 
             RGBColor[
              0.8458936702127661, 0.8758498085106384, 0.7108784680851061], 
             UndirectedEdge[112, 399] -> 
             RGBColor[
              0.994513340425532, 0.9906729148936171, 0.6441891489361701], 
             UndirectedEdge[186, 322] -> 
             RGBColor[
              0.9805368723404255, 0.945424574468085, 0.4285377021276593], 
             UndirectedEdge[180, 332] -> 
             RGBColor[
              0.9895283936170213, 0.9883564680851065, 0.7082636702127658], 
             UndirectedEdge[60, 331] -> 
             RGBColor[
              0.9502358085106382, 0.8369600425531912, 0.2967768829787232], 
             UndirectedEdge[14, 126] -> 
             RGBColor[
              0.9460181382978723, 0.8275218936170214, 0.5658744255319148], 
             UndirectedEdge[275, 288] -> 
             RGBColor[
              0.9674800212765957, 0.9736207872340426, 0.8662007872340425], 
             UndirectedEdge[276, 290] -> 
             RGBColor[
              0.9135005212765956, 0.8965800212765955, 0.6575888936170211], 
             UndirectedEdge[18, 232] -> 
             RGBColor[
              0.9676247021276596, 0.902452659574468, 0.3287285106382978], 
             UndirectedEdge[4, 325] -> 
             RGBColor[
              0.9905893723404255, 0.9881831063829788, 0.6461870319148934], 
             UndirectedEdge[1, 62] -> 
             RGBColor[0.918167, 0.6941408723404254, 0.28467341489361697`], 
             UndirectedEdge[20, 304] -> 
             RGBColor[
              0.6777024574468085, 0.655943829787234, 0.6064856276595745], 
             UndirectedEdge[255, 328] -> 
             RGBColor[
              0.9755174255319149, 0.9289307021276596, 0.3718022127659572], 
             UndirectedEdge[3, 74] -> 
             RGBColor[
              0.9733440319148936, 0.9765214042553192, 0.7461926063829787], 
             UndirectedEdge[18, 279] -> 
             RGBColor[
              0.9323619361702128, 0.7688549361702128, 0.26802705319148934`], 
             UndirectedEdge[163, 226] -> 
             RGBColor[
              0.9898549787234042, 0.9900727872340426, 0.8177927872340425], 
             UndirectedEdge[145, 254] -> 
             RGBColor[
              0.9672476702127659, 0.9066624042553191, 0.5583545106382977], 
             UndirectedEdge[23, 348] -> 
             RGBColor[
              0.9502653723404255, 0.8292782340425533, 0.4954867659574468], 
             UndirectedEdge[119, 396] -> 
             RGBColor[
              0.985911085106383, 0.9626772553191489, 0.5238872765957445], 
             UndirectedEdge[73, 141] -> 
             RGBColor[
              0.9568404042553191, 0.8631450638297871, 0.3020910957446806], 
             UndirectedEdge[29, 396] -> 
             RGBColor[
              0.9848467872340425, 0.9604008297872341, 0.40804502127659553`], 
             UndirectedEdge[160, 312] -> 
             RGBColor[
              0.9784454680851064, 0.9822692127659574, 0.8687052127659574], 
             UndirectedEdge[210, 397] -> 
             RGBColor[
              0.9019596489361702, 0.6346346595744681, 0.5636943723404255], 
             UndirectedEdge[11, 86] -> 
             RGBColor[
              0.9898549787234042, 0.9900727872340426, 0.8177927872340425], 
             UndirectedEdge[113, 315] -> 
             RGBColor[
              0.9627932127659574, 0.87917314893617, 0.35797198936170194`], 
             UndirectedEdge[120, 160] -> 
             RGBColor[
              0.9795346276595744, 0.9811383404255319, 0.7357135425531913], 
             UndirectedEdge[5, 308] -> 
             RGBColor[
              0.9812464042553191, 0.9469421914893617, 0.5057658723404252], 
             UndirectedEdge[37, 261] -> 
             RGBColor[
              0.9930942765957447, 0.9876376808510638, 0.489732808510638], 
             UndirectedEdge[22, 241] -> 
             RGBColor[
              0.9938038085106383, 0.9891552978723405, 0.5669609787234041], 
             UndirectedEdge[55, 165] -> 
             RGBColor[
              0.988777074468085, 0.978025574468085, 0.5977721808510639], 
             UndirectedEdge[251, 283] -> 
             RGBColor[
              0.9556021808510639, 0.9623509148936171, 0.7216019574468083], 
             UndirectedEdge[334, 365] -> 
             RGBColor[
              0.9832203191489362, 0.9863007021276596, 0.8816887021276594], 
             UndirectedEdge[44, 358] -> 
             RGBColor[
              0.9568981489361702, 0.854505744680851, 0.4298859468085106], 
             UndirectedEdge[225, 367] -> 
             RGBColor[
              0.9794477127659573, 0.9465554468085104, 0.5615293723404253], 
             UndirectedEdge[23, 321] -> 
             RGBColor[
              0.9267410744680851, 0.7230940425531913, 0.4758903191489361], 
             UndirectedEdge[234, 269] -> 
             RGBColor[
              0.9675082021276595, 0.9726632765957446, 0.795285755319149], 
             UndirectedEdge[21, 208] -> 
             RGBColor[
              0.9941585744680852, 0.9899141063829788, 0.605575063829787], 
             UndirectedEdge[208, 240] -> 
             RGBColor[
              0.985911085106383, 0.9626772553191489, 0.5238872765957445], 
             UndirectedEdge[15, 313] -> 
             RGBColor[
              0.9460561063829787, 0.8238374680851062, 0.27545368085106375`], 
             UndirectedEdge[63, 204] -> 
             RGBColor[
              0.991653670212766, 0.9904595319148937, 0.7620292872340424], 
             UndirectedEdge[241, 310] -> 
             RGBColor[
              0.9568981489361702, 0.854505744680851, 0.4298859468085106], 
             UndirectedEdge[182, 256] -> 
             RGBColor[
              0.9442899255319148, 0.8027792765957446, 0.49053351063829775`], 
             UndirectedEdge[373, 380] -> 
             RGBColor[
              0.9196377234042553, 0.7190973829787233, 0.254196829787234], 
             UndirectedEdge[185, 210] -> 
             RGBColor[
              0.8546891276595745, 0.40143578723404266`, 0.19922309574468086`],
              UndirectedEdge[96, 223] -> 
             RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 
             UndirectedEdge[103, 222] -> 
             RGBColor[
              0.9323619361702128, 0.7688549361702128, 0.26802705319148934`], 
             UndirectedEdge[146, 375] -> 
             RGBColor[
              0.9661697659574469, 0.8946151914893616, 0.33833390425531906`], 
             UndirectedEdge[42, 276] -> 
             RGBColor[
              0.9001170851063829, 0.9230599148936169, 0.9857228617021276], 
             UndirectedEdge[46, 372] -> 
             RGBColor[
              0.991653670212766, 0.9904595319148937, 0.7620292872340424], 
             UndirectedEdge[95, 285] -> 
             RGBColor[
              0.9264144893617021, 0.7213777234042552, 0.36636120212765944`], 
             UndirectedEdge[14, 326] -> 
             RGBColor[
              0.9502653723404255, 0.8292782340425533, 0.4954867659574468], 
             UndirectedEdge[22, 310] -> 
             RGBColor[
              0.9565433829787234, 0.8537469361702128, 0.3912718617021275], 
             UndirectedEdge[23, 229] -> 
             RGBColor[
              0.9808634574468085, 0.9471408936170211, 0.538066819148936], 
             UndirectedEdge[23, 160] -> 
             RGBColor[
              0.9798612127659574, 0.982854659574468, 0.845242659574468], 
             UndirectedEdge[165, 311] -> 
             RGBColor[
              0.9523741382978723, 0.9516079361702128, 0.696649659574468], 
             UndirectedEdge[179, 288] -> 
             RGBColor[
              0.9934208617021276, 0.9893540000000001, 0.5992619255319147], 
             UndirectedEdge[51, 167] -> 
             RGBColor[
              0.9455711276595744, 0.821224978723404, 0.2786554787234041], 
             UndirectedEdge[310, 346] -> 
             RGBColor[
              0.9529605744680851, 0.8422451489361702, 0.3277054787234042], 
             UndirectedEdge[79, 379] -> 
             RGBColor[
              0.9895114680851065, 0.9761358936170212, 0.4261664255319147], 
             UndirectedEdge[78, 264] -> 
             RGBColor[
              0.9728130531914894, 0.9427833617021275, 0.6254252872340423], 
             UndirectedEdge[309, 325] -> 
             RGBColor[
              0.9791798617021277, 0.9803795319148936, 0.6970994574468083], 
             UndirectedEdge[149, 358] -> 
             RGBColor[
              0.9526227340425532, 0.8537069148936169, 0.5711886382978723], 
             UndirectedEdge[6, 79] -> 
             RGBColor[
              0.9595651702127659, 0.8684301702127658, 0.3330196914893616], 
             UndirectedEdge[134, 234] -> 
             RGBColor[
              0.9368523723404254, 0.8634399361702125, 0.6249108510638297], 
             UndirectedEdge[96, 209] -> 
             RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 
             UndirectedEdge[216, 393] -> 
             RGBColor[
              0.9912989042553191, 0.9897007234042554, 0.7234152021276594], 
             UndirectedEdge[164, 388] -> 
             RGBColor[
              0.9568404042553191, 0.8631450638297871, 0.3020910957446806], 
             UndirectedEdge[155, 261] -> 
             RGBColor[
              0.9264126914893618, 0.9395519361702127, 0.7573980851063828], 
             UndirectedEdge[125, 288] -> 
             RGBColor[
              0.9674800212765957, 0.9736207872340426, 0.8662007872340425], 
             UndirectedEdge[287, 384] -> 
             RGBColor[
              0.9400426914893616, 0.8010229361702127, 0.5609211702127659], 
             UndirectedEdge[69, 320] -> 
             RGBColor[
              0.9923598829787235, 0.9895273617021276, 0.6613385638297871], 
             UndirectedEdge[123, 339] -> 
             RGBColor[
              0.8737233829787234, 0.4669277234042551, 0.21423005319148933`], 
             UndirectedEdge[132, 202] -> 
             RGBColor[
              0.9808634574468085, 0.9471408936170211, 0.538066819148936], 
             UndirectedEdge[67, 249] -> 
             RGBColor[
              0.9905893723404255, 0.9881831063829788, 0.6461870319148934], 
             UndirectedEdge[374, 384] -> 
             RGBColor[
              0.9403805319148937, 0.7895611702127658, 0.31743801063829785`], 
             UndirectedEdge[99, 252] -> 
             RGBColor[
              0.9816187446808511, 0.9496578510638298, 0.38309272340425526`], 
             UndirectedEdge[44, 65] -> 
             RGBColor[
              0.989883159574468, 0.9891152765957447, 0.7468777553191488], 
             UndirectedEdge[88, 370] -> 
             RGBColor[
              0.9631479787234043, 0.8799319574468084, 0.3965860744680849], 
             UndirectedEdge[13, 275] -> 
             RGBColor[
              0.9542412659574467, 0.9289325531914892, 0.6568624787234041], 
             UndirectedEdge[183, 269] -> 
             RGBColor[
              0.9808916382978723, 0.9461833829787233, 0.4671517872340424], 
             UndirectedEdge[122, 178] -> 
             RGBColor[
              0.988777074468085, 0.978025574468085, 0.5977721808510639], 
             UndirectedEdge[199, 216] -> 
             RGBColor[
              0.9941585744680851, 0.9899141063829787, 0.6055750638297872], 
             UndirectedEdge[107, 295] -> 
             RGBColor[
              0.9190512872340426, 0.8284601702127659, 0.6231410106382979], 
             UndirectedEdge[89, 171] -> 
             RGBColor[
              0.9808634574468085, 0.9471408936170211, 0.538066819148936], 
             UndirectedEdge[18, 91] -> 
             RGBColor[
              0.9619577765957447, 0.9224313617021276, 0.6177829468085105], 
             UndirectedEdge[194, 357] -> 
             RGBColor[
              0.9136622765957446, 0.6925984255319146, 0.24924357446808504`], 
             UndirectedEdge[147, 388] -> 
             RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             UndirectedEdge[96, 323] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255319], 
             UndirectedEdge[168, 265] -> 
             RGBColor[
              0.9671534361702128, 0.9719044680851063, 0.7566716702127658], 
             UndirectedEdge[44, 372] -> 
             RGBColor[
              0.994513340425532, 0.9906729148936171, 0.6441891489361701], 
             UndirectedEdge[180, 286] -> 
             RGBColor[
              0.9902379255319149, 0.989874085106383, 0.7854918404255318], 
             UndirectedEdge[18, 45] -> 
             RGBColor[
              0.9765817234042553, 0.9312071276595744, 0.4876444680851062], 
             UndirectedEdge[83, 217] -> 
             RGBColor[
              0.9502358085106382, 0.8369600425531912, 0.2967768829787232], 
             UndirectedEdge[137, 314] -> 
             RGBColor[
              0.9430429680851062, 0.8680568723404254, 0.6144317872340426], 
             UndirectedEdge[205, 338] -> 
             RGBColor[
              0.9124466914893617, 0.8022751489361704, 0.6178267978723404], 
             UndirectedEdge[210, 293] -> 
             RGBColor[
              0.908150244680851, 0.6392515957446809, 0.5532153085106382], 
             UndirectedEdge[295, 324] -> 
             RGBColor[
              0.9358519361702127, 0.9512346382978724, 0.978061755319149], 
             UndirectedEdge[270, 346] -> 
             RGBColor[
              0.988777074468085, 0.978025574468085, 0.5977721808510639], 
             UndirectedEdge[26, 349] -> 
             RGBColor[
              0.9296613404255318, 0.9466177021276596, 0.9885408191489362], 
             UndirectedEdge[27, 208] -> 
             RGBColor[
              0.993069414893617, 0.9910449787234042, 0.738566734042553], 
             UndirectedEdge[139, 193] -> 
             RGBColor[
              0.8681303085106384, 0.7669384680851065, 0.6135998617021277], 
             UndirectedEdge[5, 296] -> 
             RGBColor[
              0.9902379255319149, 0.989874085106383, 0.7854918404255318], 
             UndirectedEdge[42, 125] -> 
             RGBColor[
              0.940857829787234, 0.9554124468085106, 0.9849964468085107], 
             UndirectedEdge[12, 106] -> 
             RGBColor[
              0.9944851595744681, 0.9916304255319148, 0.7151041808510636], 
             UndirectedEdge[242, 357] -> 
             RGBColor[
              0.931051170212766, 0.7580910425531913, 0.2811952021276594], 
             UndirectedEdge[148, 279] -> 
             RGBColor[
              0.9236431808510639, 0.8110698936170213, 0.614282425531915], 
             UndirectedEdge[292, 374] -> 
             RGBColor[
              0.9228298829787234, 0.9280501489361701, 0.6938317021276595], 
             UndirectedEdge[195, 369] -> 
             RGBColor[
              0.9864347553191489, 0.9872728936170213, 0.80246264893617], 
             UndirectedEdge[50, 371] -> 
             RGBColor[
              0.988777074468085, 0.978025574468085, 0.5977721808510639], 
             UndirectedEdge[29, 127] -> 
             RGBColor[
              0.9895114680851065, 0.9761358936170212, 0.4261664255319147], 
             UndirectedEdge[87, 127] -> 
             RGBColor[
              0.9403805319148937, 0.7895611702127658, 0.31743801063829785`], 
             UndirectedEdge[264, 357] -> 
             RGBColor[
              0.9362395212765957, 0.798421744680851, 0.5778919787234043], 
             UndirectedEdge[171, 306] -> 
             RGBColor[
              0.9794477127659573, 0.9465554468085104, 0.5615293723404253], 
             UndirectedEdge[114, 170] -> 
             RGBColor[
              0.9905757659574468, 0.9784123191489362, 0.5420086808510637], 
             UndirectedEdge[57, 222] -> 
             RGBColor[
              0.9747830319148936, 0.9308203829787234, 0.5434079680851063], 
             UndirectedEdge[38, 102] -> 
             RGBColor[
              0.9926864680851064, 0.9912436808510638, 0.7708676808510637], 
             UndirectedEdge[82, 331] -> 
             RGBColor[
              0.9635027446808511, 0.8806907659574467, 0.435200159574468], 
             UndirectedEdge[90, 324] -> 
             RGBColor[
              0.9594296170212766, 0.9692632553191489, 0.953559255319149], 
             UndirectedEdge[160, 341] -> 
             RGBColor[
              0.955838159574468, 0.898858829787234, 0.6092669361702127], 
             UndirectedEdge[15, 311] -> 
             RGBColor[
              0.9322604787234042, 0.8808302127659573, 0.6337694361702126], 
             UndirectedEdge[271, 292] -> 
             RGBColor[
              0.9135005212765956, 0.8965800212765955, 0.6575888936170211], 
             UndirectedEdge[41, 156] -> 
             RGBColor[
              0.9927395106382979, 0.9868788723404256, 0.45111872340425496`], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.9568404042553191, 0.8631450638297871, 0.3020910957446806], 
             UndirectedEdge[129, 317] -> 
             RGBColor[
              0.959227329787234, 0.8798919361702127, 0.5765028510638297], 
             UndirectedEdge[164, 354] -> 
             RGBColor[
              0.9693978085106383, 0.9053581702127659, 0.3632862021276594], 
             UndirectedEdge[78, 230] -> 
             RGBColor[
              0.9193519361702127, 0.7049675531914893, 0.27143307446808496`], 
             UndirectedEdge[315, 363] -> 
             RGBColor[
              0.9319093404255319, 0.7471806595744681, 0.33262818085106366`], 
             UndirectedEdge[5, 121] -> 
             RGBColor[
              0.9905757659574468, 0.9784123191489362, 0.5420086808510637], 
             UndirectedEdge[43, 380] -> 
             RGBColor[
              0.9328469148936169, 0.7714674255319146, 0.26482525531914886`], 
             UndirectedEdge[135, 234] -> 
             RGBColor[
              0.9674800212765957, 0.9736207872340426, 0.8662007872340425], 
             UndirectedEdge[344, 356] -> 
             RGBColor[
              0.9620588191489361, 0.8810628297872338, 0.529577744680851], 
             UndirectedEdge[186, 228] -> 
             RGBColor[
              0.9769540638297872, 0.9339227872340424, 0.364971319148936], 
             UndirectedEdge[298, 396] -> 
             RGBColor[
              0.985911085106383, 0.9626772553191489, 0.5238872765957445], 
             UndirectedEdge[86, 93] -> 
             RGBColor[
              0.9944851595744681, 0.9916304255319148, 0.7151041808510636], 
             UndirectedEdge[249, 266] -> 
             RGBColor[
              0.9801821063829788, 0.9446657659574467, 0.38992361702127626`], 
             UndirectedEdge[156, 364] -> 
             RGBColor[
              0.9801821063829788, 0.9446657659574467, 0.38992361702127626`], 
             UndirectedEdge[10, 311] -> 
             RGBColor[
              0.9430447765957446, 0.9201378085106382, 0.6604068510638297], 
             UndirectedEdge[27, 73] -> 
             RGBColor[
              0.968663414893617, 0.9072478510638297, 0.5348919574468085], 
             UndirectedEdge[56, 213] -> 
             RGBColor[
              0.9521757234042553, 0.8474099999999998, 0.2839696914893616], 
             UndirectedEdge[27, 243] -> 
             RGBColor[
              0.988777074468085, 0.978025574468085, 0.5977721808510639], 
             UndirectedEdge[109, 157] -> 
             RGBColor[
              0.9521757234042553, 0.8474099999999998, 0.2839696914893616], 
             UndirectedEdge[12, 241] -> 
             RGBColor[
              0.9941303936170213, 0.9908716170212766, 0.6764900957446808], 
             UndirectedEdge[192, 382] -> 
             RGBColor[
              0.9442899255319148, 0.8027792765957446, 0.4905335106382978], 
             UndirectedEdge[140, 280] -> 
             RGBColor[
              0.9042791595744681, 0.8166812765957446, 0.6217320319148936], 
             UndirectedEdge[199, 361] -> 
             RGBColor[
              0.9938038085106383, 0.9891552978723405, 0.5669609787234041], 
             UndirectedEdge[16, 351] -> 
             RGBColor[
              0.8653038936170213, 0.8955451914893617, 0.9823375000000001], 
             UndirectedEdge[140, 322] -> 
             RGBColor[
              0.9565433829787234, 0.8537469361702128, 0.3912718617021275], 
             UndirectedEdge[57, 238] -> 
             RGBColor[
              0.8451592765957447, 0.8777394893617022, 0.8824842234042554], 
             UndirectedEdge[49, 127] -> 
             RGBColor[
              0.9175362765957447, 0.6707065531914893, 0.29778397872340423`], 
             UndirectedEdge[165, 182] -> 
             RGBColor[
              0.9403805319148937, 0.7895611702127658, 0.31743801063829785`], 
             UndirectedEdge[253, 343] -> 
             RGBColor[
              0.9416912978723404, 0.8003250638297873, 0.30426986170212766`], 
             UndirectedEdge[104, 240] -> 
             RGBColor[
              0.9774777340425531, 0.9585184255319149, 0.6435466914893616], 
             UndirectedEdge[312, 348] -> 
             RGBColor[
              0.9488496276595745, 0.8286927872340426, 0.5189493191489363], 
             UndirectedEdge[242, 244] -> 
             RGBColor[
              0.9629600212765956, 0.8867175957446807, 0.3106071063829785], 
             UndirectedEdge[41, 165] -> 
             RGBColor[
              0.9895114680851065, 0.9761358936170212, 0.4261664255319147], 
             UndirectedEdge[54, 297] -> 
             RGBColor[
              0.9057106063829787, 0.5629780638297872, 0.45581156382978716`], 
             UndirectedEdge[77, 145] -> 
             RGBColor[
              0.9658319255319148, 0.9060769574468084, 0.5818170638297872], 
             UndirectedEdge[69, 150] -> 
             RGBColor[
              0.9311749468085107, 0.7490703404255319, 0.5042339361702128], 
             UndirectedEdge[106, 241] -> 
             RGBColor[
              0.994513340425532, 0.9906729148936171, 0.6441891489361701], 
             UndirectedEdge[139, 276] -> 
             RGBColor[
              0.8446042127659574, 0.8789284893617021, 0.9850402978723405], 
             UndirectedEdge[313, 393] -> 
             RGBColor[
              0.9672476702127659, 0.9066624042553191, 0.5583545106382977], 
             UndirectedEdge[209, 323] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255319], 
             UndirectedEdge[8, 213] -> 
             RGBColor[
              0.9582953404255319, 0.8709825319148935, 0.29248570212765945`], 
             UndirectedEdge[160, 244] -> 
             RGBColor[
              0.9619577765957447, 0.9224313617021276, 0.6177829468085105], 
             UndirectedEdge[180, 284] -> 
             RGBColor[
              0.9719515425531915, 0.9296494893617021, 0.590333074468085], 
             UndirectedEdge[24, 242] -> 
             RGBColor[
              0.9568404042553191, 0.8631450638297871, 0.3020910957446806], 
             UndirectedEdge[81, 192] -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425531], 
             UndirectedEdge[124, 249] -> 
             RGBColor[
              0.9260597234042554, 0.7206189148936168, 0.3277471170212764], 
             UndirectedEdge[195, 253] -> 
             RGBColor[
              0.9506483191489362, 0.8290795319148937, 0.4631858191489361], 
             UndirectedEdge[31, 81] -> 
             RGBColor[
              0.9898549787234042, 0.9900727872340426, 0.8177927872340425], 
             UndirectedEdge[172, 399] -> 
             RGBColor[0.990221, 0.9776535106382979, 0.5033945957446808], 
             UndirectedEdge[124, 315] -> 
             RGBColor[
              0.9260597234042554, 0.7206189148936168, 0.3277471170212764], 
             UndirectedEdge[181, 370] -> 
             RGBColor[
              0.9938038085106383, 0.9891552978723405, 0.5669609787234041], 
             UndirectedEdge[244, 348] -> 
             RGBColor[
              0.9323619361702128, 0.7688549361702128, 0.26802705319148934`], 
             UndirectedEdge[284, 367] -> 
             RGBColor[
              0.9747830319148936, 0.9308203829787234, 0.5434079680851063], 
             UndirectedEdge[148, 232] -> 
             RGBColor[
              0.9589059468085106, 0.9446676170212766, 0.6749838829787234], 
             UndirectedEdge[34, 211] -> 
             RGBColor[
              0.9864347553191489, 0.9872728936170213, 0.80246264893617], 
             UndirectedEdge[355, 392] -> 
             RGBColor[
              0.5868975531914894, 0.6484128617021276, 0.8081521170212764], 
             UndirectedEdge[262, 338] -> 
             RGBColor[
              0.9556021808510639, 0.9623509148936171, 0.7216019574468083], 
             UndirectedEdge[87, 119] -> 
             RGBColor[
              0.9446728723404255, 0.802580574468085, 0.45823256382978705`], 
             UndirectedEdge[180, 367] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255319], 
             UndirectedEdge[69, 380] -> 
             RGBColor[
              0.9620588191489361, 0.8810628297872338, 0.5295777446808511], 
             UndirectedEdge[124, 338] -> 
             RGBColor[
              0.8889223936170212, 0.6960909574468084, 0.5982303510638297], 
             UndirectedEdge[249, 293] -> 
             RGBColor[
              0.9853704574468085, 0.9849964680851064, 0.686620393617021], 
             UndirectedEdge[212, 373] -> 
             RGBColor[
              0.9502935531914893, 0.8283207234042553, 0.4245717340425532], 
             UndirectedEdge[287, 292] -> 
             RGBColor[
              0.9224920425531915, 0.9395119148936171, 0.9373148617021276], 
             UndirectedEdge[12, 323] -> 
             RGBColor[
              0.9926864680851064, 0.9912436808510638, 0.7708676808510637], 
             UndirectedEdge[120, 307] -> 
             RGBColor[
              0.9934490425531916, 0.9883964893617022, 0.528346893617021], 
             UndirectedEdge[99, 398] -> 
             RGBColor[
              0.9615050851063829, 0.8788801276595744, 0.3202124999999999], 
             UndirectedEdge[134, 350] -> 
             RGBColor[
              0.9549004893617021, 0.8526951063829786, 0.31489828723404245`], 
             UndirectedEdge[45, 280] -> 
             RGBColor[
              0.9418943510638298, 0.9528484468085107, 0.8360352340425531], 
             UndirectedEdge[188, 330] -> 
             RGBColor[
              0.9671534361702128, 0.9719044680851063, 0.7566716702127658], 
             UndirectedEdge[236, 284] -> 
             RGBColor[
              0.9719515425531915, 0.9296494893617021, 0.590333074468085], 
             UndirectedEdge[374, 389] -> 
             RGBColor[
              0.9529605744680851, 0.8422451489361702, 0.3277054787234042], 
             UndirectedEdge[278, 319] -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425531], 
             UndirectedEdge[78, 242] -> 
             RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             UndirectedEdge[84, 189] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255319], 
             UndirectedEdge[223, 385] -> 
             RGBColor[
              0.981804574468085, 0.985715255319149, 0.9051512553191488], 
             UndirectedEdge[175, 278] -> 
             RGBColor[
              0.9855281382978723, 0.9628759574468084, 0.5561882234042552], 
             UndirectedEdge[151, 168] -> 
             RGBColor[
              0.9302477765957446, 0.8372549148936169, 0.6195966382978724], 
             UndirectedEdge[322, 339] -> 
             RGBColor[
              0.9565433829787234, 0.8537469361702128, 0.3912718617021275], 
             UndirectedEdge[177, 367] -> 
             RGBColor[
              0.9923598829787235, 0.9895273617021276, 0.6613385638297871], 
             UndirectedEdge[294, 320] -> 
             RGBColor[
              0.9857252234042553, 0.9857552765957447, 0.7252344787234041], 
             UndirectedEdge[179, 279] -> 
             RGBColor[
              0.9495840212765958, 0.8268031063829788, 0.3473435638297871], 
             UndirectedEdge[18, 285] -> 
             RGBColor[
              0.9088376382978722, 0.6626707446808509, 0.24843060638297865`], 
             UndirectedEdge[121, 296] -> 
             RGBColor[
              0.985945585106383, 0.9768546808510639, 0.6446972872340424], 
             UndirectedEdge[212, 351] -> 
             RGBColor[
              0.9675082021276595, 0.9726632765957446, 0.795285755319149], 
             UndirectedEdge[29, 87] -> 
             RGBColor[
              0.9436085744680851, 0.8003041489361702, 0.3423903085106381], 
             UndirectedEdge[99, 141] -> 
             RGBColor[
              0.9722893829787234, 0.9181877234042553, 0.34684991489361683`], 
             UndirectedEdge[121, 274] -> 
             RGBColor[
              0.9722893829787234, 0.9181877234042553, 0.34684991489361694`], 
             UndirectedEdge[138, 218] -> 
             RGBColor[
              0.9376020106382978, 0.9398290425531914, 0.6952406808510638], 
             UndirectedEdge[61, 388] -> 
             RGBColor[
              0.9629600212765956, 0.8867175957446807, 0.3106071063829785], 
             UndirectedEdge[283, 347] -> 
             RGBColor[
              0.9755174255319149, 0.9289307021276596, 0.3718022127659572], 
             UndirectedEdge[253, 315] -> 
             RGBColor[
              0.9495840212765958, 0.8268031063829788, 0.3473435638297871], 
             UndirectedEdge[321, 366] -> 
             RGBColor[0.918167, 0.6941408723404254, 0.28467341489361697`], 
             UndirectedEdge[164, 391] -> 
             RGBColor[
              0.9704621063829787, 0.9076345957446807, 0.4791284574468083], 
             UndirectedEdge[74, 91] -> 
             RGBColor[
              0.9795346276595744, 0.9811383404255319, 0.7357135425531913], 
             UndirectedEdge[91, 285] -> 
             RGBColor[
              0.9125000744680851, 0.7141195744680849, 0.5737278510638297], 
             UndirectedEdge[51, 183] -> 
             RGBColor[
              0.9502358085106382, 0.8369600425531912, 0.2967768829787232], 
             UndirectedEdge[30, 54] -> 
             RGBColor[
              0.8971365319148936, 0.5340248936170213, 0.26459465957446804`], 
             UndirectedEdge[68, 250] -> 
             RGBColor[
              0.9794477127659573, 0.9465554468085104, 0.5615293723404253], 
             UndirectedEdge[32, 230] -> 
             RGBColor[
              0.9019630425531915, 0.6394749361702127, 0.2394814468085106], 
             UndirectedEdge[275, 318] -> 
             RGBColor[
              0.9674800212765957, 0.9736207872340426, 0.8662007872340425], 
             UndirectedEdge[131, 186] -> 
             RGBColor[
              0.9805368723404255, 0.945424574468085, 0.4285377021276593], 
             UndirectedEdge[192, 292] -> 
             RGBColor[
              0.9267392765957447, 0.9412682553191489, 0.8669272021276595], 
             UndirectedEdge[144, 200] -> 
             RGBColor[
              0.9697612234042553, 0.9650196170212766, 0.6826262234042553], 
             UndirectedEdge[139, 318] -> 
             RGBColor[
              0.9119671489361703, 0.9294893617021276, 0.8655182234042553], 
             UndirectedEdge[93, 148] -> 
             RGBColor[
              0.9678629680851063, 0.973422085106383, 0.8338998404255318], 
             UndirectedEdge[92, 311] -> 
             RGBColor[
              0.9190512872340426, 0.8284601702127659, 0.6231410106382979], 
             UndirectedEdge[334, 370] -> 
             RGBColor[
              0.9857252234042553, 0.9857552765957447, 0.7252344787234041], 
             UndirectedEdge[62, 129] -> 
             RGBColor[
              0.9812809042553191, 0.9611196170212766, 0.6265758829787234], 
             UndirectedEdge[97, 191] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255319], 
             UndirectedEdge[120, 366] -> 
             RGBColor[
              0.9852015531914894, 0.9611596382978724, 0.44665910638297857`], 
             UndirectedEdge[91, 288] -> 
             RGBColor[
              0.9798612127659574, 0.982854659574468, 0.845242659574468], 
             UndirectedEdge[21, 32] -> 
             RGBColor[
              0.9631479787234043, 0.8799319574468084, 0.3965860744680849], 
             UndirectedEdge[121, 178] -> 
             RGBColor[
              0.986283425531915, 0.965392914893617, 0.4012141276595744], 
             UndirectedEdge[294, 381] -> 
             RGBColor[
              0.9864347553191489, 0.9872728936170213, 0.80246264893617], 
             UndirectedEdge[46, 149] -> 
             RGBColor[
              0.987023489361702, 0.9889018936170213, 0.8647178936170211], 
             UndirectedEdge[66, 232] -> 
             RGBColor[
              0.9848467872340425, 0.9604008297872341, 0.40804502127659553`], 
             UndirectedEdge[114, 261] -> 
             RGBColor[
              0.9898662340425533, 0.9768947021276596, 0.46478051063829773`], 
             UndirectedEdge[189, 395] -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 
             UndirectedEdge[54, 290] -> 
             RGBColor[
              0.8924718510638298, 0.5182898297872339, 0.24647325531914877`], 
             UndirectedEdge[4, 309] -> 
             RGBColor[
              0.9770297234042553, 0.9816837659574469, 0.8921677659574467], 
             UndirectedEdge[195, 315] -> 
             RGBColor[
              0.9938038085106383, 0.9891552978723405, 0.566960978723404], 
             UndirectedEdge[181, 305] -> 
             RGBColor[
              0.9941303936170213, 0.9908716170212766, 0.6764900957446808], 
             UndirectedEdge[153, 372] -> 
             RGBColor[
              0.9944851595744681, 0.9916304255319148, 0.7151041808510636], 
             UndirectedEdge[175, 227] -> 
             RGBColor[
              0.9589059468085106, 0.9446676170212766, 0.6749838829787234], 
             UndirectedEdge[271, 287] -> 
             RGBColor[
              0.9766162234042552, 0.9453845531914893, 0.6084544787234041], 
             UndirectedEdge[232, 297] -> 
             RGBColor[
              0.9855281382978723, 0.9628759574468084, 0.5561882234042552], 
             UndirectedEdge[21, 25] -> 
             RGBColor[
              0.9938038085106383, 0.9891552978723405, 0.5669609787234041], 
             UndirectedEdge[123, 297] -> 
             RGBColor[
              0.9109556276595745, 0.6032935957446807, 0.4608342021276595], 
             UndirectedEdge[6, 178] -> 
             RGBColor[
              0.9595651702127659, 0.8684301702127658, 0.3330196914893616], 
             UndirectedEdge[90, 319] -> 
             RGBColor[
              0.9770297234042553, 0.9816837659574469, 0.8921677659574467], 
             UndirectedEdge[258, 302] -> 
             RGBColor[
              0.9761987765957447, 0.931405829787234, 0.5199454148936169], 
             UndirectedEdge[253, 397] -> 
             RGBColor[
              0.9360243723404256, 0.8203037659574468, 0.5933242978723404], 
             UndirectedEdge[169, 177] -> 
             RGBColor[
              0.9264144893617021, 0.7213777234042552, 0.36636120212765944`], 
             UndirectedEdge[198, 332] -> 
             RGBColor[
              0.9923598829787235, 0.9895273617021276, 0.6613385638297871], 
             UndirectedEdge[45, 123] -> 
             RGBColor[
              0.9113385744680851, 0.6030948936170211, 0.42853325531914876`], 
             UndirectedEdge[223, 245] -> 
             RGBColor[
              0.907719914893617, 0.9277330212765957, 0.9359058829787233], 
             UndirectedEdge[380, 381] -> 
             RGBColor[
              0.9638575106382978, 0.881449574468085, 0.47381424468085087`], 
             UndirectedEdge[277, 378] -> 
             RGBColor[
              0.969752574468085, 0.9061169787234042, 0.40190028723404236`], 
             UndirectedEdge[119, 326] -> 
             RGBColor[
              0.9944851595744681, 0.9916304255319148, 0.7151041808510636], 
             UndirectedEdge[89, 133] -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425531], 
             UndirectedEdge[22, 346] -> 
             RGBColor[
              0.9898662340425533, 0.9768947021276596, 0.46478051063829773`], 
             UndirectedEdge[73, 243] -> 
             RGBColor[
              0.9661697659574469, 0.8946151914893616, 0.33833390425531906`], 
             UndirectedEdge[26, 353] -> 
             RGBColor[
              0.9520362978723405, 0.9630697021276596, 0.9401328191489361], 
             UndirectedEdge[21, 230] -> 
             RGBColor[
              0.9322641063829787, 0.7479394680851065, 0.3712422659574467], 
             UndirectedEdge[107, 390] -> 
             RGBColor[
              0.8953584468085106, 0.6132899148936171, 0.23416723404255319`], 
             UndirectedEdge[223, 364] -> 
             RGBColor[
              0.9766162234042552, 0.9453845531914893, 0.6084544787234041], 
             UndirectedEdge[2, 211] -> 
             RGBColor[
              0.9944851595744681, 0.9916304255319148, 0.7151041808510636], 
             UndirectedEdge[128, 353] -> 
             RGBColor[
              0.9400426914893616, 0.8010229361702127, 0.5609211702127659], 
             UndirectedEdge[259, 331] -> 
             RGBColor[
              0.9634745638297872, 0.8816482765957445, 0.5061151914893616], 
             UndirectedEdge[2, 334] -> 
             RGBColor[
              0.9860518085106382, 0.9874715957446809, 0.8347635957446807], 
             UndirectedEdge[72, 191] -> 
             RGBColor[
              0.9632327872340425, 0.9718644468085107, 0.9365884468085106], 
             UndirectedEdge[247, 301] -> 
             RGBColor[
              0.9895283936170213, 0.9883564680851065, 0.7082636702127658], 
             UndirectedEdge[247, 397] -> 
             RGBColor[
              0.9756139787234042, 0.9810983191489362, 0.9156303191489361], 
             UndirectedEdge[125, 263] -> 
             RGBColor[
              0.9495765851063829, 0.9131974893617021, 0.638741074468085], 
             UndirectedEdge[123, 325] -> 
             RGBColor[
              0.9102742765957447, 0.6008184680851063, 0.31269099999999983`], 
             UndirectedEdge[129, 393] -> 
             RGBColor[
              0.987023489361702, 0.9889018936170213, 0.8647178936170211], 
             UndirectedEdge[19, 205] -> 
             RGBColor[
              0.9360243723404256, 0.8203037659574468, 0.5933242978723404], 
             UndirectedEdge[277, 352] -> 
             RGBColor[
              0.9615050851063829, 0.8788801276595744, 0.3202124999999999], 
             UndirectedEdge[139, 224] -> 
             RGBColor[
              0.9123500957446808, 0.9292906595744681, 0.8332172765957446], 
             UndirectedEdge[65, 250] -> 
             RGBColor[
              0.9766162234042552, 0.9453845531914893, 0.6084544787234041], 
             UndirectedEdge[58, 117] -> 
             RGBColor[
              0.9801821063829788, 0.9446657659574467, 0.38992361702127626`], 
             UndirectedEdge[134, 272] -> 
             RGBColor[
              0.9606430744680851, 0.8804773829787234, 0.5530402978723403], 
             UndirectedEdge[74, 95] -> 
             RGBColor[
              0.9934490425531916, 0.9883964893617022, 0.528346893617021], 
             UndirectedEdge[156, 245] -> 
             RGBColor[
              0.9112857978723405, 0.9270142340425532, 0.7173750212765956], 
             UndirectedEdge[221, 324] -> 
             RGBColor[
              0.9708391276595745, 0.977066829787234, 0.902646829787234], 
             UndirectedEdge[227, 375] -> 
             RGBColor[
              0.9434569680851064, 0.8896249574468084, 0.6302250638297873], 
             UndirectedEdge[132, 348] -> 
             RGBColor[
              0.9502653723404255, 0.8292782340425533, 0.4954867659574468], 
             UndirectedEdge[137, 319] -> 
             RGBColor[
              0.9708391276595745, 0.977066829787234, 0.902646829787234], 
             UndirectedEdge[128, 170] -> 
             RGBColor[
              0.9446728723404255, 0.802580574468085, 0.45823256382978705`], 
             UndirectedEdge[120, 220] -> 
             RGBColor[
              0.9758721914893618, 0.9296895106382979, 0.41041629787234024`], 
             UndirectedEdge[292, 371] -> 
             RGBColor[
              0.9253235319148936, 0.9406828085106382, 0.8903897553191489], 
             UndirectedEdge[143, 378] -> 
             RGBColor[
              0.9923598829787235, 0.9895273617021276, 0.6613385638297871], 
             UndirectedEdge[59, 373] -> 
             RGBColor[
              0.9488496276595745, 0.8286927872340426, 0.5189493191489363], 
             UndirectedEdge[2, 340] -> 
             RGBColor[
              0.9941303936170213, 0.9908716170212766, 0.6764900957446808], 
             UndirectedEdge[131, 322] -> 
             RGBColor[
              0.9934490425531916, 0.9883964893617022, 0.528346893617021], 
             UndirectedEdge[62, 317] -> 
             RGBColor[
              0.9549004893617021, 0.8526951063829786, 0.31489828723404245`], 
             UndirectedEdge[243, 337] -> 
             RGBColor[
              0.9697612234042553, 0.9650196170212766, 0.6826262234042553], 
             UndirectedEdge[21, 217] -> 
             RGBColor[
              0.9631479787234043, 0.8799319574468084, 0.3965860744680849], 
             UndirectedEdge[24, 74] -> 
             RGBColor[
              0.969752574468085, 0.9061169787234042, 0.40190028723404236`], 
             UndirectedEdge[1, 127] -> 
             RGBColor[
              0.9228316808510638, 0.7098759361702126, 0.30279481914893613`], 
             UndirectedEdge[226, 355] -> 
             RGBColor[
              0.9902379255319149, 0.989874085106383, 0.7854918404255318], 
             UndirectedEdge[97, 370] -> 
             RGBColor[
              0.9923598829787235, 0.9895273617021276, 0.6613385638297871], 
             UndirectedEdge[148, 257] -> 
             RGBColor[
              0.9632327872340425, 0.9718644468085107, 0.9365884468085106], 
             UndirectedEdge[48, 344] -> 
             RGBColor[
              0.955424159574468, 0.8772907446808509, 0.593473659574468], 
             UndirectedEdge[74, 148] -> 
             RGBColor[
              0.9671534361702128, 0.9719044680851063, 0.7566716702127658], 
             UndirectedEdge[266, 293] -> 
             RGBColor[
              0.9728130531914894, 0.9427833617021275, 0.6254252872340423], 
             UndirectedEdge[84, 226] -> 
             RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 
             UndirectedEdge[354, 371] -> 
             RGBColor[
              0.9920051170212766, 0.9887685531914894, 0.6227244787234041], 
             UndirectedEdge[57, 188] -> 
             RGBColor[
              0.9660642765957446, 0.9730353404255319, 0.889663340425532], 
             UndirectedEdge[134, 355] -> 
             RGBColor[
              0.9638575106382978, 0.881449574468085, 0.47381424468085087`], 
             UndirectedEdge[151, 378] -> 
             RGBColor[
              0.9565433829787234, 0.8537469361702128, 0.3912718617021275], 
             UndirectedEdge[167, 238] -> 
             RGBColor[
              0.8286715851063831, 0.8179016382978723, 0.6315619574468084], 
             UndirectedEdge[41, 311] -> 
             RGBColor[
              0.9556021808510639, 0.9623509148936171, 0.7216019574468083], 
             UndirectedEdge[212, 295] -> 
             RGBColor[
              0.9563117127659575, 0.9638685319148936, 0.7988301276595744], 
             UndirectedEdge[179, 285] -> 
             RGBColor[
              0.9260597234042554, 0.7206189148936168, 0.3277471170212764], 
             UndirectedEdge[85, 348] -> 
             RGBColor[
              0.9370266170212767, 0.7845899999999999, 0.2861484574468084], 
             UndirectedEdge[108, 152] -> 
             RGBColor[
              0.985945585106383, 0.9768546808510639, 0.6446972872340424], 
             UndirectedEdge[86, 148] -> 
             RGBColor[
              0.9674800212765957, 0.9736207872340426, 0.8662007872340425], 
             UndirectedEdge[113, 293] -> 
             RGBColor[
              0.955424159574468, 0.8772907446808509, 0.5934736595744681], 
             UndirectedEdge[229, 260] -> 
             RGBColor[
              0.9542412659574467, 0.9289325531914892, 0.6568624787234041], 
             UndirectedEdge[6, 278] -> 
             RGBColor[
              0.9634745638297872, 0.8816482765957445, 0.5061151914893616], 
             UndirectedEdge[142, 378] -> 
             RGBColor[
              0.9758721914893618, 0.9296895106382979, 0.41041629787234024`], 
             UndirectedEdge[289, 303] -> 
             RGBColor[
              0.9036927234042553, 0.9260440638297873, 0.9906762127659574], 
             UndirectedEdge[5, 213] -> 
             RGBColor[
              0.9765817234042553, 0.9312071276595744, 0.4876444680851062], 
             UndirectedEdge[104, 243] -> 
             RGBColor[
              0.9821424148936171, 0.9742534893617021, 0.6616680957446808], 
             UndirectedEdge[121, 373] -> 
             RGBColor[
              0.9463559787234044, 0.8160601276595745, 0.3223912659574468], 
             UndirectedEdge[120, 202] -> 
             RGBColor[
              0.9805368723404255, 0.945424574468085, 0.4285377021276593], 
             UndirectedEdge[270, 351] -> 
             RGBColor[
              0.9660642765957446, 0.9730353404255319, 0.889663340425532], 
             UndirectedEdge[91, 125] -> 
             RGBColor[
              0.9532390212765958, 0.9646463191489361, 0.9640383191489361], 
             UndirectedEdge[280, 297] -> 
             RGBColor[
              0.9415114042553192, 0.9530471489361703, 0.8683361808510638], 
             UndirectedEdge[33, 281] -> 
             RGBColor[
              0.9629600212765956, 0.8867175957446807, 0.3106071063829785], 
             UndirectedEdge[16, 241] -> 
             RGBColor[
              0.8919542659574469, 0.9127960212765958, 0.7926268085106383], 
             UndirectedEdge[89, 342] -> 
             RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 
             UndirectedEdge[157, 370] -> 
             RGBColor[
              0.9758721914893618, 0.9296895106382979, 0.41041629787234024`], 
             UndirectedEdge[90, 122] -> 
             RGBColor[
              0.9784454680851064, 0.9822692127659574, 0.8687052127659574], 
             UndirectedEdge[135, 156] -> 
             RGBColor[
              0.9934208617021276, 0.9893540000000001, 0.5992619255319147], 
             UndirectedEdge[12, 22] -> 
             RGBColor[
              0.9937756276595745, 0.9901128085106383, 0.6378760106382977], 
             UndirectedEdge[271, 384] -> 
             RGBColor[
              0.931051170212766, 0.7580910425531913, 0.2811952021276594], 
             UndirectedEdge[158, 324] -> 
             RGBColor[
              0.9740535638297871, 0.9780390212765957, 0.8234207765957446], 
             UndirectedEdge[301, 397] -> 
             RGBColor[
              0.9795346276595744, 0.9811383404255319, 0.7357135425531913], 
             UndirectedEdge[95, 233] -> 
             RGBColor[
              0.9937756276595745, 0.9901128085106383, 0.6378760106382977], 
             UndirectedEdge[123, 203] -> 
             RGBColor[
              0.8611433404255319, 0.4142437446808508, 0.20396258510638293`], 
             UndirectedEdge[103, 145] -> 
             RGBColor[
              0.9262423191489362, 0.7452824042553191, 0.25951104255319146`], 
             UndirectedEdge[20, 80] -> 
             RGBColor[
              0.7040828723404255, 0.7643683404255319, 0.9181632234042553], 
             UndirectedEdge[73, 337] -> 
             RGBColor[
              0.9496475638297872, 0.8942418936170211, 0.6197459999999999], 
             UndirectedEdge[122, 166] -> 
             RGBColor[
              0.9927146489361702, 0.9902861702127659, 0.6999526489361703], 
             UndirectedEdge[62, 216] -> 
             RGBColor[
              0.9855563191489362, 0.9619184468085107, 0.48527319148936165`], 
             UndirectedEdge[128, 342] -> 
             RGBColor[
              0.9442899255319148, 0.8027792765957446, 0.49053351063829775`], 
             UndirectedEdge[280, 309] -> 
             RGBColor[
              0.9272704042553191, 0.9440726808510638, 0.9661737127659574], 
             UndirectedEdge[104, 141] -> 
             RGBColor[
              0.9728130531914894, 0.9427833617021275, 0.6254252872340423], 
             UndirectedEdge[148, 276] -> 
             RGBColor[
              0.9001170851063829, 0.9230599148936169, 0.9857228617021276], 
             UndirectedEdge[359, 394] -> 
             RGBColor[
              0.9322641063829787, 0.7479394680851065, 0.3712422659574467], 
             UndirectedEdge[8, 43] -> 
             RGBColor[
              0.9455711276595744, 0.821224978723404, 0.2786554787234041], 
             UndirectedEdge[56, 352] -> 
             RGBColor[
              0.9615050851063829, 0.8788801276595744, 0.3202124999999999], 
             UndirectedEdge[70, 152] -> 
             RGBColor[
              0.986283425531915, 0.965392914893617, 0.4012141276595744], 
             UndirectedEdge[359, 397] -> 
             RGBColor[
              0.9183496914893616, 0.7406813191489362, 0.578608914893617], 
             UndirectedEdge[118, 241] -> 
             RGBColor[
              0.9762269574468085, 0.9304483191489361, 0.44903038297872333`], 
             UndirectedEdge[43, 227] -> 
             RGBColor[
              0.9368523723404254, 0.8634399361702125, 0.6249108510638297], 
             UndirectedEdge[234, 246] -> 
             RGBColor[
              0.9470484255319148, 0.9600293829787234, 0.9745173829787235], 
             UndirectedEdge[196, 317] -> 
             RGBColor[
              0.9638575106382978, 0.881449574468085, 0.47381424468085087`], 
             UndirectedEdge[46, 184] -> 
             RGBColor[
              0.9912989042553191, 0.9897007234042554, 0.7234152021276594], 
             UndirectedEdge[136, 331] -> 
             RGBColor[
              0.9502358085106382, 0.8369600425531912, 0.2967768829787232], 
             UndirectedEdge[106, 320] -> 
             RGBColor[
              0.9941585744680852, 0.9899141063829788, 0.605575063829787], 
             UndirectedEdge[68, 161] -> 
             RGBColor[
              0.9846360638297872, 0.9868861489361702, 0.8582261489361702], 
             UndirectedEdge[45, 297] -> 
             RGBColor[
              0.9944851595744681, 0.9916304255319148, 0.7151041808510636], 
             UndirectedEdge[140, 203] -> 
             RGBColor[
              0.9070576808510638, 0.6664134042553189, 0.24392936170212765`], 
             UndirectedEdge[225, 243] -> 
             RGBColor[
              0.9769540638297872, 0.9339227872340424, 0.364971319148936], 
             UndirectedEdge[107, 373] -> 
             RGBColor[
              0.9130331276595745, 0.6929123617021277, 0.24888261702127662`], 
             UndirectedEdge[187, 321] -> 
             RGBColor[0.918167, 0.6941408723404254, 0.28467341489361697`], 
             UndirectedEdge[297, 322] -> 
             RGBColor[
              0.9937756276595745, 0.9901128085106383, 0.6378760106382977], 
             UndirectedEdge[106, 374] -> 
             RGBColor[
              0.9905757659574468, 0.9784123191489362, 0.5420086808510637], 
             UndirectedEdge[154, 383] -> 
             RGBColor[
              0.988777074468085, 0.978025574468085, 0.5977721808510639], 
             UndirectedEdge[111, 151] -> 
             RGBColor[
              0.889508829787234, 0.5867281702127658, 0.22928617021276593`], 
             UndirectedEdge[79, 227] -> 
             RGBColor[
              0.9635706276595745, 0.9604026808510637, 0.6931052872340426], 
             UndirectedEdge[93, 290] -> 
             RGBColor[
              0.9812464042553191, 0.9469421914893617, 0.5057658723404252], 
             UndirectedEdge[150, 283] -> 
             RGBColor[
              0.9319093404255319, 0.7471806595744681, 0.33262818085106366`], 
             UndirectedEdge[46, 195] -> 
             RGBColor[
              0.991653670212766, 0.9904595319148937, 0.7620292872340424], 
             UndirectedEdge[73, 177] -> 
             RGBColor[
              0.969752574468085, 0.9061169787234042, 0.40190028723404236`], 
             UndirectedEdge[102, 189] -> 
             RGBColor[
              0.9926864680851064, 0.9912436808510638, 0.7708676808510637], 
             UndirectedEdge[3, 95] -> 
             RGBColor[
              0.9733440319148936, 0.9765214042553192, 0.7461926063829787], 
             UndirectedEdge[39, 294] -> 
             RGBColor[
              0.9857252234042553, 0.9857552765957447, 0.7252344787234041], 
             UndirectedEdge[5, 227] -> 
             RGBColor[
              0.9678629680851063, 0.973422085106383, 0.8338998404255318], 
             UndirectedEdge[166, 169] -> 
             RGBColor[
              0.9267692553191489, 0.7221365319148935, 0.4049752872340425], 
             UndirectedEdge[27, 337] -> 
             RGBColor[
              0.9722548723404254, 0.9776522765957447, 0.8791842765957447], 
             UndirectedEdge[84, 174] -> 
             RGBColor[
              0.9898549787234042, 0.9900727872340426, 0.8177927872340425], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.891926085106383, 0.9137535319148936, 0.8635418404255318], 
             UndirectedEdge[138, 349] -> 
             RGBColor[
              0.9635706276595745, 0.9604026808510637, 0.6931052872340426], 
             UndirectedEdge[26, 159] -> 
             RGBColor[
              0.9520362978723405, 0.9630697021276596, 0.9401328191489361], 
             UndirectedEdge[81, 287] -> 
             RGBColor[
              0.987023489361702, 0.9889018936170213, 0.8647178936170211], 
             UndirectedEdge[311, 361] -> 
             RGBColor[
              0.9559569468085107, 0.9631097234042554, 0.7602160425531914], 
             UndirectedEdge[231, 393] -> 
             RGBColor[
              0.9646485319148936, 0.9724498936170213, 0.9131258936170212], 
             UndirectedEdge[201, 223] -> 
             RGBColor[
              0.9812809042553191, 0.9611196170212766, 0.6265758829787234], 
             UndirectedEdge[180, 267] -> 
             RGBColor[
              0.989883159574468, 0.9891152765957447, 0.7468777553191488], 
             UndirectedEdge[217, 264] -> 
             RGBColor[
              0.955424159574468, 0.8772907446808509, 0.5934736595744681], 
             UndirectedEdge[163, 174] -> 
             RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 
             UndirectedEdge[203, 280] -> 
             RGBColor[
              0.8916991170212766, 0.7639972978723404, 0.6114645638297872], 
             UndirectedEdge[40, 163] -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425531], 
             UndirectedEdge[14, 62] -> 
             RGBColor[
              0.9416912978723404, 0.8003250638297873, 0.30426986170212766`], 
             UndirectedEdge[49, 133] -> 
             RGBColor[
              0.9186141808510638, 0.6827537659574467, 0.5178045851063828], 
             UndirectedEdge[276, 288] -> 
             RGBColor[
              0.9267392765957447, 0.9412682553191489, 0.8669272021276595], 
             UndirectedEdge[312, 366] -> 
             RGBColor[
              0.9841123936170213, 0.9622905106382978, 0.5796507765957446], 
             UndirectedEdge[23, 120] -> 
             RGBColor[
              0.9937756276595745, 0.9901128085106383, 0.6378760106382977], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.9722893829787234, 0.9181877234042553, 0.34684991489361694`], 
             UndirectedEdge[73, 399] -> 
             RGBColor[
              0.9701073404255318, 0.9068757872340425, 0.44051437234042545`], 
             UndirectedEdge[269, 272] -> 
             RGBColor[
              0.9912989042553191, 0.9897007234042554, 0.7234152021276594], 
             UndirectedEdge[20, 151] -> 
             RGBColor[
              0.6710978617021277, 0.6297588085106383, 0.601171414893617], 
             UndirectedEdge[239, 355] -> 
             RGBColor[
              0.9704621063829787, 0.9076345957446807, 0.4791284574468083], 
             UndirectedEdge[274, 319] -> 
             RGBColor[
              0.9733672872340425, 0.9302349361702127, 0.5668705212765957], 
             UndirectedEdge[6, 352] -> 
             RGBColor[
              0.9549004893617021, 0.8526951063829786, 0.31489828723404245`], 
             UndirectedEdge[133, 342] -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425531], 
             UndirectedEdge[290, 318] -> 
             RGBColor[
              0.9808634574468085, 0.9471408936170211, 0.538066819148936], 
             UndirectedEdge[87, 298] -> 
             RGBColor[
              0.9446728723404255, 0.802580574468085, 0.45823256382978705`], 
             UndirectedEdge[86, 263] -> 
             RGBColor[
              0.9761987765957447, 0.931405829787234, 0.5199454148936169], 
             UndirectedEdge[109, 191] -> 
             RGBColor[
              0.9658319255319148, 0.9060769574468084, 0.581817063829787], 
             UndirectedEdge[84, 238] -> 
             RGBColor[
              0.8423277872340427, 0.8765685957446809, 0.9294093297872339], 
             UndirectedEdge[21, 244] -> 
             RGBColor[
              0.9758721914893618, 0.9296895106382979, 0.41041629787234024`], 
             UndirectedEdge[137, 175] -> 
             RGBColor[
              0.9650965425531914, 0.9492845531914893, 0.6645048191489362], 
             UndirectedEdge[363, 369] -> 
             RGBColor[
              0.9245402872340425, 0.745298255319149, 0.5681298510638297], 
             UndirectedEdge[98, 290] -> 
             RGBColor[
              0.9666224574468085, 0.9381664255319148, 0.6359043510638296], 
             UndirectedEdge[175, 352] -> 
             RGBColor[
              0.9769540638297872, 0.9339227872340425, 0.3649713191489361], 
             UndirectedEdge[121, 319] -> 
             RGBColor[
              0.9873613297872341, 0.9774401276595746, 0.621234734042553], 
             UndirectedEdge[249, 387] -> 
             RGBColor[
              0.9260579255319149, 0.9387931276595745, 0.7187839999999999], 
             UndirectedEdge[310, 389] -> 
             RGBColor[
              0.9196377234042553, 0.7190973829787233, 0.254196829787234], 
             UndirectedEdge[228, 238] -> 
             RGBColor[
              0.8426656276595745, 0.8651068297872342, 0.6859261702127659], 
             UndirectedEdge[268, 324] -> 
             RGBColor[
              0.9650965425531914, 0.9492845531914893, 0.6645048191489362], 
             UndirectedEdge[144, 368] -> 
             RGBColor[
              0.9895114680851065, 0.9761358936170212, 0.4261664255319147], 
             UndirectedEdge[137, 278] -> 
             RGBColor[
              0.9736706170212766, 0.9782377234042553, 0.8557217234042553], 
             UndirectedEdge[127, 298] -> 
             RGBColor[
              0.9905757659574468, 0.9784123191489362, 0.5420086808510637], 
             UndirectedEdge[131, 228] -> 
             RGBColor[
              0.9898662340425533, 0.9768947021276596, 0.46478051063829773`], 
             UndirectedEdge[278, 314] -> 
             RGBColor[
              0.9634745638297872, 0.8816482765957445, 0.5061151914893616], 
             UndirectedEdge[182, 311] -> 
             RGBColor[
              0.906471244680851, 0.7757761914893616, 0.6128735425531915], 
             UndirectedEdge[77, 94] -> 
             RGBColor[
              0.9898549787234042, 0.9900727872340426, 0.8177927872340425], 
             UndirectedEdge[144, 333] -> 
             RGBColor[0.990221, 0.9776535106382979, 0.5033945957446808], 
             UndirectedEdge[166, 197] -> 
             RGBColor[
              0.9912989042553191, 0.9897007234042554, 0.7234152021276594], 
             UndirectedEdge[106, 384] -> 
             RGBColor[
              0.9446728723404255, 0.802580574468085, 0.4582325638297871], 
             UndirectedEdge[28, 265] -> 
             RGBColor[
              0.9805368723404255, 0.945424574468085, 0.4285377021276593], 
             UndirectedEdge[113, 266] -> 
             RGBColor[
              0.9502358085106382, 0.8369600425531912, 0.2967768829787232], 
             UndirectedEdge[164, 292] -> 
             RGBColor[
              0.9027162234042553, 0.8572724255319147, 0.6309514787234043], 
             UndirectedEdge[98, 248] -> 
             RGBColor[
              0.9756139787234042, 0.9810983191489362, 0.9156303191489361], 
             UndirectedEdge[91, 95] -> 
             RGBColor[
              0.9795346276595744, 0.9811383404255319, 0.7357135425531913], 
             UndirectedEdge[155, 342] -> 
             RGBColor[
              0.9267392765957447, 0.9412682553191489, 0.8669272021276595], 
             UndirectedEdge[47, 209] -> 
             RGBColor[
              0.985945585106383, 0.9768546808510639, 0.6446972872340424], 
             UndirectedEdge[2, 360] -> 
             RGBColor[
              0.9937756276595745, 0.9901128085106383, 0.6378760106382977], 
             UndirectedEdge[75, 341] -> 
             RGBColor[
              0.9704621063829787, 0.9076345957446807, 0.4791284574468083], 
             UndirectedEdge[12, 390] -> 
             RGBColor[
              0.9325906914893617, 0.7496557872340426, 0.48077138297872335`], 
             UndirectedEdge[19, 198] -> 
             RGBColor[
              0.9784454680851064, 0.9822692127659574, 0.8687052127659574], 
             UndirectedEdge[8, 56] -> 
             RGBColor[
              0.9521757234042553, 0.8474099999999998, 0.2839696914893616], 
             UndirectedEdge[70, 154] -> 
             RGBColor[
              0.988777074468085, 0.978025574468085, 0.5977721808510639], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.9260597234042554, 0.7206189148936168, 0.3277471170212764], 
             UndirectedEdge[177, 243] -> 
             RGBColor[
              0.9898662340425533, 0.9768947021276596, 0.46478051063829773`], 
             UndirectedEdge[109, 340] -> 
             RGBColor[
              0.9701073404255318, 0.9068757872340425, 0.44051437234042545`], 
             UndirectedEdge[28, 36] -> 
             RGBColor[
              0.9766162234042552, 0.9453845531914893, 0.6084544787234041], 
             UndirectedEdge[203, 339] -> 
             RGBColor[
              0.9070576808510638, 0.6664134042553189, 0.24392936170212765`], 
             UndirectedEdge[247, 369] -> 
             RGBColor[
              0.981804574468085, 0.985715255319149, 0.9051512553191488], 
             UndirectedEdge[223, 230] -> 
             RGBColor[
              0.9283434574468085, 0.7478994468085107, 0.5511590425531914], 
             UndirectedEdge[22, 173] -> 
             RGBColor[
              0.9923598829787235, 0.9895273617021276, 0.6613385638297871], 
             UndirectedEdge[69, 283] -> 
             RGBColor[
              0.9920051170212766, 0.9887685531914894, 0.6227244787234041], 
             UndirectedEdge[59, 274] -> 
             RGBColor[
              0.9747830319148936, 0.9308203829787234, 0.5434079680851063], 
             UndirectedEdge[31, 164] -> 
             RGBColor[
              0.968663414893617, 0.9072478510638297, 0.5348919574468085], 
             UndirectedEdge[116, 154] -> 
             RGBColor[
              0.9927146489361702, 0.9902861702127659, 0.6999526489361703], 
             UndirectedEdge[10, 170] -> 
             RGBColor[
              0.9812464042553191, 0.9469421914893617, 0.5057658723404252], 
             UndirectedEdge[301, 394] -> 
             RGBColor[
              0.9934490425531916, 0.9883964893617022, 0.528346893617021], 
             UndirectedEdge[90, 351] -> 
             RGBColor[
              0.9532390212765958, 0.9646463191489361, 0.9640383191489361], 
             UndirectedEdge[4, 203] -> 
             RGBColor[
              0.9414584361702127, 0.8016083829787233, 0.5374586170212765], 
             UndirectedEdge[274, 351] -> 
             RGBColor[
              0.9495765851063829, 0.9131974893617021, 0.638741074468085], 
             UndirectedEdge[238, 269] -> 
             RGBColor[
              0.8466032021276597, 0.877367425531915, 0.7881066382978723], 
             UndirectedEdge[66, 325] -> 
             RGBColor[
              0.9927395106382979, 0.9868788723404256, 0.45111872340425496`], 
             UndirectedEdge[128, 171] -> 
             RGBColor[
              0.931051170212766, 0.7580910425531913, 0.2811952021276594], 
             UndirectedEdge[198, 205] -> 
             RGBColor[
              0.9488496276595745, 0.8286927872340426, 0.5189493191489363], 
             UndirectedEdge[202, 349] -> 
             RGBColor[
              0.9542412659574467, 0.9289325531914892, 0.6568624787234041], 
             UndirectedEdge[295, 390] -> 
             RGBColor[
              0.8947720106382979, 0.7226527021276596, 0.603111414893617], 
             UndirectedEdge[250, 356] -> 
             RGBColor[
              0.9794477127659573, 0.9465554468085104, 0.5615293723404253], 
             UndirectedEdge[133, 393] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255317], 
             UndirectedEdge[124, 293] -> 
             RGBColor[
              0.918690670212766, 0.7187365106382977, 0.5632487872340425], 
             UndirectedEdge[45, 325] -> 
             RGBColor[
              0.9938038085106383, 0.9891552978723405, 0.566960978723404], 
             UndirectedEdge[116, 304] -> 
             RGBColor[
              0.9635027446808511, 0.8806907659574467, 0.435200159574468], 
             UndirectedEdge[213, 296] -> 
             RGBColor[
              0.9719515425531915, 0.9296494893617021, 0.590333074468085], 
             UndirectedEdge[248, 276] -> 
             RGBColor[
              0.9224920425531915, 0.9395119148936171, 0.9373148617021276], 
             UndirectedEdge[209, 346] -> 
             RGBColor[
              0.985945585106383, 0.9768546808510639, 0.6446972872340424], 
             UndirectedEdge[31, 382] -> 
             RGBColor[
              0.9428741808510638, 0.802193829787234, 0.5139960638297872], 
             UndirectedEdge[69, 373] -> 
             RGBColor[
              0.9488496276595745, 0.8286927872340426, 0.5189493191489363], 
             UndirectedEdge[166, 239] -> 
             RGBColor[
              0.9701073404255318, 0.9068757872340425, 0.44051437234042545`], 
             UndirectedEdge[235, 317] -> 
             RGBColor[
              0.9634745638297872, 0.8816482765957445, 0.5061151914893616], 
             UndirectedEdge[43, 59] -> 
             RGBColor[
              0.9620588191489361, 0.8810628297872338, 0.529577744680851], 
             UndirectedEdge[94, 207] -> 
             RGBColor[
              0.9860518085106382, 0.9874715957446809, 0.8347635957446807], 
             UndirectedEdge[209, 270] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255319], 
             UndirectedEdge[23, 341] -> 
             RGBColor[
              0.970079159574468, 0.9078332978723402, 0.511429404255319], 
             UndirectedEdge[264, 312] -> 
             RGBColor[
              0.9846360638297872, 0.9868861489361702, 0.8582261489361702], 
             UndirectedEdge[48, 118] -> 
             RGBColor[
              0.9681483723404255, 0.9270482978723404, 0.6073038829787233], 
             UndirectedEdge[106, 310] -> 
             RGBColor[
              0.9572529148936171, 0.8552645531914893, 0.4685000319148935], 
             UndirectedEdge[267, 282] -> 
             RGBColor[
              0.9855563191489362, 0.9619184468085107, 0.48527319148936165`], 
             UndirectedEdge[43, 274] -> 
             RGBColor[
              0.9455711276595744, 0.821224978723404, 0.2786554787234041], 
             UndirectedEdge[46, 362] -> 
             RGBColor[
              0.991653670212766, 0.9904595319148937, 0.7620292872340424], 
             UndirectedEdge[38, 117] -> 
             RGBColor[
              0.9794477127659573, 0.9465554468085104, 0.5615293723404253], 
             UndirectedEdge[252, 300] -> 
             RGBColor[
              0.9769540638297872, 0.9339227872340424, 0.364971319148936], 
             UndirectedEdge[7, 67] -> 
             RGBColor[
              0.9733672872340425, 0.9302349361702127, 0.5668705212765957], 
             UndirectedEdge[150, 192] -> 
             RGBColor[
              0.9325906914893617, 0.7496557872340426, 0.48077138297872335`], 
             UndirectedEdge[239, 272] -> 
             RGBColor[
              0.9672476702127659, 0.9066624042553191, 0.5583545106382977], 
             UndirectedEdge[22, 209] -> 
             RGBColor[
              0.9895283936170213, 0.9883564680851065, 0.7082636702127658], 
             UndirectedEdge[167, 246] -> 
             RGBColor[
              0.9557671808510637, 0.9178144255319148, 0.6282620106382979], 
             UndirectedEdge[131, 140] -> 
             RGBColor[
              0.9565433829787234, 0.8537469361702128, 0.3912718617021275], 
             UndirectedEdge[67, 385] -> 
             RGBColor[
              0.9832203191489362, 0.9863007021276596, 0.8816887021276594], 
             UndirectedEdge[60, 101] -> 
             RGBColor[
              0.9766162234042552, 0.9453845531914893, 0.6084544787234041], 
             UndirectedEdge[113, 249] -> 
             RGBColor[
              0.9627932127659574, 0.87917314893617, 0.35797198936170194`], 
             UndirectedEdge[52, 393] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255317], 
             UndirectedEdge[99, 367] -> 
             RGBColor[
              0.9841123936170213, 0.9622905106382978, 0.5796507765957446], 
             UndirectedEdge[5, 43] -> 
             RGBColor[
              0.9638575106382978, 0.881449574468085, 0.47381424468085087`], 
             UndirectedEdge[26, 105] -> 
             RGBColor[
              0.9566664787234043, 0.9646273404255319, 0.8374442127659574], 
             UndirectedEdge[128, 306] -> 
             RGBColor[
              0.9428741808510638, 0.802193829787234, 0.5139960638297872], 
             UndirectedEdge[226, 281] -> 
             RGBColor[
              0.9719515425531915, 0.9296494893617021, 0.590333074468085], 
             UndirectedEdge[63, 345] -> 
             RGBColor[
              0.993069414893617, 0.9910449787234042, 0.738566734042553], 
             UndirectedEdge[4, 280] -> 
             RGBColor[
              0.938679914893617, 0.951876255319149, 0.9152612872340424], 
             UndirectedEdge[7, 223] -> 
             RGBColor[
              0.9719515425531915, 0.9296494893617021, 0.590333074468085], 
             UndirectedEdge[155, 361] -> 
             RGBColor[
              0.9264126914893618, 0.9395519361702127, 0.7573980851063828], 
             UndirectedEdge[252, 398] -> 
             RGBColor[
              0.9661697659574469, 0.8946151914893616, 0.33833390425531906`], 
             UndirectedEdge[6, 252] -> 
             RGBColor[
              0.9595651702127659, 0.8684301702127658, 0.3330196914893616], 
             UndirectedEdge[260, 307] -> 
             RGBColor[
              0.9671534361702128, 0.9719044680851063, 0.7566716702127658], 
             UndirectedEdge[21, 357] -> 
             RGBColor[
              0.9439633404255319, 0.8010629574468084, 0.38100439361702115`], 
             UndirectedEdge[233, 366] -> 
             RGBColor[
              0.9855281382978723, 0.9628759574468084, 0.5561882234042552], 
             UndirectedEdge[37, 41] -> 
             RGBColor[
              0.9927395106382979, 0.9868788723404256, 0.45111872340425496`], 
             UndirectedEdge[173, 176] -> 
             RGBColor[
              0.9923598829787235, 0.9895273617021276, 0.6613385638297871], 
             UndirectedEdge[60, 136] -> 
             RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             UndirectedEdge[74, 285] -> 
             RGBColor[
              0.9264144893617021, 0.7213777234042552, 0.36636120212765944`], 
             UndirectedEdge[234, 395] -> 
             RGBColor[
              0.9660642765957446, 0.9730353404255319, 0.889663340425532], 
             UndirectedEdge[17, 164] -> 
             RGBColor[
              0.9202668723404255, 0.7187834468085104, 0.2545577872340425], 
             UndirectedEdge[20, 383] -> 
             RGBColor[
              0.7044207127659574, 0.7529065744680852, 0.6746800638297872], 
             UndirectedEdge[19, 219] -> 
             RGBColor[
              0.955838159574468, 0.898858829787234, 0.6092669361702127], 
             UndirectedEdge[91, 279] -> 
             RGBColor[
              0.9360243723404256, 0.8203037659574468, 0.5933242978723404], 
             UndirectedEdge[76, 207] -> 
             RGBColor[
              0.9422149680851064, 0.8249207021276597, 0.5828452340425532], 
             UndirectedEdge[238, 339] -> 
             RGBColor[
              0.8093427765957448, 0.7419590638297873, 0.6124175212765957], 
             UndirectedEdge[142, 379] -> 
             RGBColor[
              0.9755174255319149, 0.9289307021276596, 0.3718022127659572], 
             UndirectedEdge[205, 219] -> 
             RGBColor[
              0.9262423191489362, 0.7452824042553191, 0.25951104255319146`], 
             UndirectedEdge[7, 68] -> 
             RGBColor[
              0.9747830319148936, 0.9308203829787234, 0.5434079680851063], 
             UndirectedEdge[188, 273] -> 
             RGBColor[
              0.9302477765957446, 0.8372549148936169, 0.6195966382978724], 
             UndirectedEdge[16, 69] -> 
             RGBColor[
              0.8905103404255319, 0.913168085106383, 0.8870043936170213], 
             UndirectedEdge[118, 323] -> 
             RGBColor[
              0.9747830319148936, 0.9308203829787234, 0.5434079680851063], 
             UndirectedEdge[211, 263] -> 
             RGBColor[
              0.9765817234042553, 0.9312071276595744, 0.4876444680851062], 
             UndirectedEdge[191, 340] -> 
             RGBColor[
              0.989883159574468, 0.9891152765957447, 0.7468777553191488], 
             UndirectedEdge[33, 182] -> 
             RGBColor[
              0.931051170212766, 0.7580910425531913, 0.2811952021276594], 
             UndirectedEdge[99, 300] -> 
             RGBColor[
              0.9722893829787234, 0.9181877234042553, 0.34684991489361683`], 
             UndirectedEdge[11, 91] -> 
             RGBColor[
              0.9756139787234042, 0.9810983191489362, 0.9156303191489361], 
             UndirectedEdge[78, 233] -> 
             RGBColor[
              0.9808634574468085, 0.9471408936170211, 0.538066819148936], 
             UndirectedEdge[27, 172] -> 
             RGBColor[
              0.988777074468085, 0.978025574468085, 0.5977721808510639], 
             UndirectedEdge[313, 396] -> 
             RGBColor[
              0.9615050851063829, 0.8788801276595744, 0.3202124999999999], 
             UndirectedEdge[74, 172] -> 
             RGBColor[
              0.9898662340425533, 0.9768947021276596, 0.46478051063829773`], 
             UndirectedEdge[217, 366] -> 
             RGBColor[
              0.9549004893617021, 0.8526951063829786, 0.31489828723404245`], 
             UndirectedEdge[277, 302] -> 
             RGBColor[
              0.970079159574468, 0.9078332978723402, 0.511429404255319], 
             UndirectedEdge[203, 232] -> 
             RGBColor[
              0.9357158510638297, 0.7738261063829786, 0.2993166063829787], 
             UndirectedEdge[27, 285] -> 
             RGBColor[
              0.9253253297872339, 0.7225085957446806, 0.4993528723404255], 
             UndirectedEdge[193, 334] -> 
             RGBColor[
              0.9422149680851064, 0.8249207021276597, 0.5828452340425532], 
             UndirectedEdge[39, 381] -> 
             RGBColor[
              0.9941585744680852, 0.9899141063829788, 0.605575063829787], 
             UndirectedEdge[270, 390] -> 
             RGBColor[
              0.9311749468085107, 0.7490703404255319, 0.5042339361702128], 
             UndirectedEdge[35, 42] -> 
             RGBColor[
              0.9176677340425532, 0.7845709361702127, 0.609329170212766], 
             UndirectedEdge[41, 245] -> 
             RGBColor[
              0.9112857978723405, 0.9270142340425532, 0.7173750212765956], 
             UndirectedEdge[45, 276] -> 
             RGBColor[
              0.9271222234042553, 0.9410695531914893, 0.8346262553191488], 
             UndirectedEdge[17, 241] -> 
             RGBColor[
              0.9443181063829786, 0.8018217659574467, 0.4196184787234042], 
             UndirectedEdge[69, 347] -> 
             RGBColor[
              0.9747830319148936, 0.9308203829787234, 0.5434079680851063], 
             UndirectedEdge[16, 295] -> 
             RGBColor[
              0.8541074042553192, 0.8867504468085107, 0.9858818723404255], 
             UndirectedEdge[190, 351] -> 
             RGBColor[
              0.9660642765957446, 0.9730353404255319, 0.889663340425532], 
             UndirectedEdge[112, 141] -> 
             RGBColor[
              0.9812464042553191, 0.9469421914893617, 0.5057658723404252], 
             UndirectedEdge[135, 400] -> 
             RGBColor[
              0.9568699680851064, 0.8554632553191488, 0.5008009787234042], 
             UndirectedEdge[295, 310] -> 
             RGBColor[
              0.9190512872340426, 0.8284601702127659, 0.6231410106382979], 
             UndirectedEdge[185, 249] -> 
             RGBColor[
              0.9319093404255319, 0.7471806595744681, 0.33262818085106366`], 
             UndirectedEdge[93, 98] -> 
             RGBColor[
              0.9802441595744681, 0.9826559574468086, 0.8129417127659573], 
             UndirectedEdge[221, 268] -> 
             RGBColor[
              0.9826966489361701, 0.9617050638297873, 0.603113329787234], 
             UndirectedEdge[265, 291] -> 
             RGBColor[
              0.9852015531914894, 0.9611596382978724, 0.44665910638297857`], 
             UndirectedEdge[128, 133] -> 
             RGBColor[
              0.9414584361702127, 0.8016083829787233, 0.5374586170212765], 
             UndirectedEdge[57, 333] -> 
             RGBColor[
              0.9927146489361702, 0.9902861702127659, 0.6999526489361703], 
             UndirectedEdge[28, 378] -> 
             RGBColor[
              0.9805368723404255, 0.945424574468085, 0.4285377021276593], 
             UndirectedEdge[92, 386] -> 
             RGBColor[
              0.9436312127659574, 0.8107750212765956, 0.2914626702127658], 
             UndirectedEdge[35, 248] -> 
             RGBColor[
              0.9400426914893616, 0.8010229361702127, 0.5609211702127659], 
             UndirectedEdge[56, 175] -> 
             RGBColor[
              0.9615050851063829, 0.8788801276595744, 0.3202124999999999], 
             UndirectedEdge[3, 21] -> 
             RGBColor[
              0.9733440319148936, 0.9765214042553192, 0.7461926063829787], 
             UndirectedEdge[98, 204] -> 
             RGBColor[
              0.9770297234042553, 0.9816837659574469, 0.8921677659574467], 
             UndirectedEdge[243, 367] -> 
             RGBColor[
              0.988777074468085, 0.978025574468085, 0.5977721808510639], 
             UndirectedEdge[48, 209] -> 
             RGBColor[
              0.981804574468085, 0.985715255319149, 0.9051512553191488], 
             UndirectedEdge[116, 291] -> 
             RGBColor[
              0.9855563191489362, 0.9619184468085107, 0.48527319148936165`], 
             UndirectedEdge[214, 340] -> 
             RGBColor[
              0.989883159574468, 0.9891152765957447, 0.7468777553191488], 
             UndirectedEdge[138, 159] -> 
             RGBColor[
              0.985945585106383, 0.9768546808510639, 0.6446972872340424], 
             UndirectedEdge[22, 48] -> 
             RGBColor[
              0.9857252234042553, 0.9857552765957447, 0.7252344787234041], 
             UndirectedEdge[13, 297] -> 
             RGBColor[
              0.9808634574468085, 0.9471408936170211, 0.538066819148936], 
             UndirectedEdge[192, 347] -> 
             RGBColor[
              0.9761987765957447, 0.931405829787234, 0.5199454148936169], 
             UndirectedEdge[4, 322] -> 
             RGBColor[
              0.9909441382978723, 0.9889419148936172, 0.6848011170212764], 
             UndirectedEdge[111, 304] -> 
             RGBColor[
              0.8961134255319148, 0.6129131914893614, 0.23460038297872332`], 
             UndirectedEdge[133, 361] -> 
             RGBColor[
              0.9909441382978723, 0.9889419148936172, 0.6848011170212764], 
             UndirectedEdge[4, 186] -> 
             RGBColor[0.9780319680851064, 0.94597, 0.5849919255319147], 
             UndirectedEdge[73, 240] -> 
             RGBColor[
              0.9615050851063829, 0.8788801276595744, 0.3202124999999999], 
             UndirectedEdge[82, 335] -> 
             RGBColor[
              0.986079989361702, 0.9865140851063829, 0.7638485638297872], 
             UndirectedEdge[184, 372] -> 
             RGBColor[
              0.994513340425532, 0.9906729148936171, 0.6441891489361701], 
             UndirectedEdge[85, 340] -> 
             RGBColor[
              0.9808916382978723, 0.9461833829787233, 0.4671517872340424], 
             UndirectedEdge[344, 388] -> 
             RGBColor[
              0.9502358085106382, 0.8369600425531912, 0.2967768829787232], 
             UndirectedEdge[57, 228] -> 
             RGBColor[
              0.988777074468085, 0.978025574468085, 0.5977721808510639], 
             UndirectedEdge[36, 80] -> 
             RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 
             UndirectedEdge[88, 365] -> 
             RGBColor[
              0.9606430744680851, 0.8804773829787234, 0.5530402978723403], 
             UndirectedEdge[209, 241] -> 
             RGBColor[
              0.989883159574468, 0.9891152765957447, 0.7468777553191488], 
             UndirectedEdge[49, 62] -> 
             RGBColor[
              0.9128715957446809, 0.654971489361702, 0.27966257446808507`], 
             UndirectedEdge[161, 250] -> 
             RGBColor[
              0.9728130531914894, 0.9427833617021275, 0.6254252872340423], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.8716333829787234, 0.4948748085106381, 0.21400786170212763`], 
             UndirectedEdge[324, 346] -> 
             RGBColor[
              0.9697612234042553, 0.9650196170212766, 0.6826262234042553], 
             UndirectedEdge[142, 258] -> 
             RGBColor[
              0.9582953404255319, 0.8709825319148935, 0.29248570212765945`], 
             UndirectedEdge[44, 46] -> 
             RGBColor[
              0.9912989042553191, 0.9897007234042554, 0.7234152021276594], 
             UndirectedEdge[85, 191] -> 
             RGBColor[
              0.9766162234042552, 0.9453845531914893, 0.6084544787234041], 
             UndirectedEdge[112, 172] -> 
             RGBColor[
              0.9905757659574468, 0.9784123191489362, 0.5420086808510637], 
             UndirectedEdge[133, 298] -> 
             RGBColor[
              0.991653670212766, 0.9904595319148937, 0.7620292872340424], 
             UndirectedEdge[26, 215] -> 
             RGBColor[
              0.9420425319148936, 0.9558515744680851, 0.9675826914893617], 
             UndirectedEdge[127, 129] -> 
             RGBColor[
              0.985945585106383, 0.9768546808510639, 0.6446972872340424], 
             UndirectedEdge[172, 225] -> 
             RGBColor[
              0.9769540638297872, 0.9339227872340424, 0.364971319148936], 
             UndirectedEdge[38, 376] -> 
             RGBColor[
              0.9920051170212766, 0.9887685531914894, 0.6227244787234041], 
             UndirectedEdge[158, 346] -> 
             RGBColor[
              0.9905757659574468, 0.9784123191489362, 0.5420086808510637], 
             UndirectedEdge[340, 370] -> 
             RGBColor[
              0.9938038085106383, 0.9891552978723405, 0.5669609787234041], 
             UndirectedEdge[44, 266] -> 
             RGBColor[
              0.9808916382978723, 0.9461833829787233, 0.4671517872340424], 
             UndirectedEdge[183, 238] -> 
             RGBColor[
              0.8333362659574468, 0.8336367021276596, 0.6496833617021275], 
             UndirectedEdge[21, 264] -> 
             RGBColor[
              0.9857252234042553, 0.9857552765957447, 0.7252344787234041], 
             UndirectedEdge[13, 140] -> 
             RGBColor[
              0.9436312127659574, 0.8107750212765956, 0.2914626702127658], 
             UndirectedEdge[210, 266] -> 
             RGBColor[
              0.9029618936170212, 0.5989208936170212, 0.2565185319148935], 
             UndirectedEdge[51, 395] -> 
             RGBColor[
              0.9620588191489361, 0.8810628297872338, 0.529577744680851], 
             UndirectedEdge[358, 372] -> 
             RGBColor[
              0.9572529148936171, 0.8552645531914893, 0.4685000319148935], 
             UndirectedEdge[174, 309] -> 
             RGBColor[
              0.9798612127659574, 0.982854659574468, 0.845242659574468], 
             UndirectedEdge[65, 363] -> 
             RGBColor[
              0.9283434574468085, 0.7478994468085107, 0.5511590425531914], 
             UndirectedEdge[236, 267] -> 
             RGBColor[
              0.989883159574468, 0.9891152765957447, 0.7468777553191488], 
             UndirectedEdge[227, 352] -> 
             RGBColor[
              0.9589059468085106, 0.9446676170212766, 0.6749838829787234], 
             UndirectedEdge[2, 370] -> 
             RGBColor[
              0.9937756276595745, 0.9901128085106383, 0.6378760106382977], 
             UndirectedEdge[17, 354] -> 
             RGBColor[
              0.9436085744680851, 0.8003041489361702, 0.3423903085106381], 
             UndirectedEdge[133, 306] -> 
             RGBColor[
              0.9898549787234042, 0.9900727872340426, 0.8177927872340425], 
             UndirectedEdge[105, 261] -> 
             RGBColor[
              0.9941585744680852, 0.9899141063829788, 0.605575063829787], 
             UndirectedEdge[120, 206] -> 
             RGBColor[
              0.9934490425531916, 0.9883964893617022, 0.528346893617021], 
             UndirectedEdge[361, 393] -> 
             RGBColor[
              0.9909441382978723, 0.9889419148936172, 0.6848011170212764], 
             UndirectedEdge[270, 295] -> 
             RGBColor[
              0.9548677872340425, 0.9642405957446809, 0.8932077127659575], 
             UndirectedEdge[9, 283] -> 
             RGBColor[
              0.9729892659574468, 0.9757625957446809, 0.7075785212765956], 
             UndirectedEdge[43, 122] -> 
             RGBColor[
              0.9620588191489361, 0.8810628297872338, 0.529577744680851], 
             UndirectedEdge[127, 336] -> 
             RGBColor[
              0.988777074468085, 0.978025574468085, 0.5977721808510639], 
             UndirectedEdge[4, 123] -> 
             RGBColor[
              0.9081241382978723, 0.6021227021276594, 0.5077593085106382], 
             UndirectedEdge[45, 279] -> 
             RGBColor[
              0.9506483191489362, 0.8290795319148937, 0.4631858191489361], 
             UndirectedEdge[135, 255] -> 
             RGBColor[
              0.9934208617021276, 0.9893540000000001, 0.5992619255319147], 
             UndirectedEdge[152, 180] -> 
             RGBColor[
              0.985945585106383, 0.9768546808510639, 0.6446972872340424], 
             UndirectedEdge[48, 68] -> 
             RGBColor[
              0.9846360638297872, 0.9868861489361702, 0.8582261489361702], 
             UndirectedEdge[362, 363] -> 
             RGBColor[
              0.9329736382978724, 0.7494570851063831, 0.44847043617021265`], 
             UndirectedEdge[18, 257] -> 
             RGBColor[
              0.9719515425531915, 0.9296494893617021, 0.590333074468085], 
             UndirectedEdge[72, 109] -> 
             RGBColor[
              0.9434569680851064, 0.8896249574468084, 0.6302250638297873], 
             UndirectedEdge[181, 211] -> 
             RGBColor[
              0.994513340425532, 0.9906729148936171, 0.6441891489361701], 
             UndirectedEdge[82, 259] -> 
             RGBColor[
              0.9941303936170213, 0.9908716170212766, 0.6764900957446808], 
             UndirectedEdge[282, 367] -> 
             RGBColor[
              0.9841123936170213, 0.9622905106382978, 0.5796507765957446], 
             UndirectedEdge[44, 363] -> 
             RGBColor[
              0.9326188723404255, 0.7486982765957447, 0.4098563510638298], 
             UndirectedEdge[139, 290] -> 
             RGBColor[
              0.8987283936170213, 0.8848011276595744, 0.6561799148936169], 
             UndirectedEdge[255, 351] -> 
             RGBColor[
              0.966798670212766, 0.9711456595744681, 0.7180575851063828], 
             UndirectedEdge[290, 345] -> 
             RGBColor[
              0.9794477127659573, 0.9465554468085104, 0.5615293723404253], 
             UndirectedEdge[145, 200] -> 
             RGBColor[
              0.9496475638297872, 0.8942418936170211, 0.6197459999999999], 
             UndirectedEdge[44, 316] -> 
             RGBColor[
              0.9808916382978723, 0.9461833829787233, 0.4671517872340424], 
             UndirectedEdge[172, 240] -> 
             RGBColor[
              0.9816187446808511, 0.9496578510638298, 0.38309272340425526`], 
             UndirectedEdge[89, 299] -> 
             RGBColor[
              0.9761987765957447, 0.931405829787234, 0.5199454148936169], 
             UndirectedEdge[119, 196] -> 
             RGBColor[
              0.9948681063829787, 0.9914317234042553, 0.6828032340425529], 
             UndirectedEdge[149, 369] -> 
             RGBColor[
              0.981804574468085, 0.985715255319149, 0.9051512553191488], 
             UndirectedEdge[32, 385] -> 
             RGBColor[
              0.955424159574468, 0.8772907446808509, 0.5934736595744681], 
             UndirectedEdge[149, 253] -> 
             RGBColor[
              0.9460181382978723, 0.8275218936170214, 0.5658744255319148], 
             UndirectedEdge[317, 336] -> 
             RGBColor[
              0.9620588191489361, 0.8810628297872338, 0.529577744680851], 
             UndirectedEdge[138, 215] -> 
             RGBColor[
              0.9759518191489363, 0.9696365531914893, 0.672147159574468], 
             UndirectedEdge[157, 181] -> 
             RGBColor[
              0.9762269574468085, 0.9304483191489361, 0.44903038297872333`], 
             UndirectedEdge[299, 342] -> 
             RGBColor[
              0.9761987765957447, 0.931405829787234, 0.5199454148936169], 
             UndirectedEdge[108, 198] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255319], 
             UndirectedEdge[152, 367] -> 
             RGBColor[
              0.988777074468085, 0.978025574468085, 0.5977721808510639], 
             UndirectedEdge[17, 118] -> 
             RGBColor[
              0.9263864893617021, 0.7423559787234041, 0.26307379787234036`], 
             UndirectedEdge[44, 68] -> 
             RGBColor[
              0.9927146489361702, 0.9902861702127659, 0.6999526489361703], 
             UndirectedEdge[158, 323] -> 
             RGBColor[
              0.993069414893617, 0.9910449787234042, 0.738566734042553], 
             UndirectedEdge[343, 359] -> 
             RGBColor[
              0.9240166170212766, 0.7207026170212767, 0.28955447872340423`], 
             UndirectedEdge[354, 388] -> 
             RGBColor[
              0.9801821063829788, 0.9446657659574467, 0.38992361702127626`], 
             UndirectedEdge[382, 389] -> 
             RGBColor[
              0.9070576808510638, 0.6664134042553189, 0.24392936170212765`], 
             UndirectedEdge[178, 319] -> 
             RGBColor[
              0.9873613297872341, 0.9774401276595746, 0.621234734042553], 
             UndirectedEdge[15, 386] -> 
             RGBColor[
              0.9568404042553191, 0.8631450638297871, 0.3020910957446806], 
             UndirectedEdge[27, 104] -> 
             RGBColor[
              0.9846360638297872, 0.9868861489361702, 0.8582261489361702], 
             UndirectedEdge[236, 398] -> 
             RGBColor[
              0.9658319255319148, 0.9060769574468084, 0.5818170638297872], 
             UndirectedEdge[151, 304] -> 
             RGBColor[
              0.9262423191489362, 0.745282404255319, 0.25951104255319146`], 
             UndirectedEdge[21, 233] -> 
             RGBColor[
              0.9937756276595745, 0.9901128085106383, 0.6378760106382977], 
             UndirectedEdge[120, 321] -> 
             RGBColor[
              0.9264144893617021, 0.7213777234042552, 0.36636120212765944`], 
             UndirectedEdge[170, 299] -> 
             RGBColor[
              0.9765817234042553, 0.9312071276595744, 0.4876444680851062], 
             UndirectedEdge[97, 109] -> 
             RGBColor[
              0.968663414893617, 0.9072478510638297, 0.5348919574468085], 
             UndirectedEdge[251, 381] -> 
             RGBColor[
              0.9566664787234043, 0.9646273404255319, 0.8374442127659574], 
             UndirectedEdge[134, 392] -> 
             RGBColor[
              0.5558869574468085, 0.5384307127659573, 0.5991631276595744], 
             UndirectedEdge[132, 220] -> 
             RGBColor[
              0.9761987765957447, 0.931405829787234, 0.5199454148936169], 
             UndirectedEdge[102, 167] -> 
             RGBColor[
              0.9761987765957447, 0.931405829787234, 0.5199454148936169], 
             UndirectedEdge[270, 373] -> 
             RGBColor[
              0.9488496276595745, 0.8286927872340426, 0.5189493191489363], 
             UndirectedEdge[122, 351] -> 
             RGBColor[
              0.9660642765957446, 0.9730353404255319, 0.889663340425532], 
             UndirectedEdge[96, 173] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255319], 
             UndirectedEdge[253, 266] -> 
             RGBColor[
              0.9370266170212767, 0.7845899999999999, 0.2861484574468084], 
             UndirectedEdge[217, 230] -> 
             RGBColor[
              0.9019630425531915, 0.6394749361702127, 0.2394814468085106], 
             UndirectedEdge[118, 158] -> 
             RGBColor[
              0.9765817234042553, 0.9312071276595744, 0.4876444680851062], 
             UndirectedEdge[208, 230] -> 
             RGBColor[
              0.9329736382978724, 0.7494570851063831, 0.44847043617021265`], 
             UndirectedEdge[86, 179] -> 
             RGBColor[
              0.9934208617021276, 0.9893540000000001, 0.5992619255319147], 
             UndirectedEdge[185, 284] -> 
             RGBColor[
              0.914687255319149, 0.6892324893617021, 0.2533116702127659], 
             UndirectedEdge[279, 399] -> 
             RGBColor[
              0.9502935531914893, 0.8283207234042553, 0.4245717340425532], 
             UndirectedEdge[167, 309] -> 
             RGBColor[
              0.9619577765957447, 0.9224313617021276, 0.6177829468085105], 
             UndirectedEdge[174, 183] -> 
             RGBColor[
              0.9808634574468085, 0.9471408936170211, 0.538066819148936], 
             UndirectedEdge[149, 247] -> 
             RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 
             UndirectedEdge[297, 339] -> 
             RGBColor[
              0.9568699680851064, 0.8554632553191488, 0.5008009787234042], 
             UndirectedEdge[28, 282] -> 
             RGBColor[
              0.9722893829787234, 0.9181877234042553, 0.34684991489361683`], 
             UndirectedEdge[35, 125] -> 
             RGBColor[
              0.9176677340425532, 0.7845709361702127, 0.609329170212766], 
             UndirectedEdge[119, 231] -> 
             RGBColor[
              0.9678629680851063, 0.973422085106383, 0.8338998404255318], 
             UndirectedEdge[257, 309] -> 
             RGBColor[
              0.9756139787234042, 0.9810983191489362, 0.9156303191489361], 
             UndirectedEdge[153, 161] -> 
             RGBColor[
              0.9860518085106382, 0.9874715957446809, 0.8347635957446807], 
             UndirectedEdge[315, 369] -> 
             RGBColor[
              0.9853704574468085, 0.9849964680851064, 0.686620393617021], 
             UndirectedEdge[145, 207] -> 
             RGBColor[
              0.9620287553191489, 0.9034757659574467, 0.5987878723404254], 
             UndirectedEdge[75, 215] -> 
             RGBColor[
              0.9802441595744681, 0.9826559574468086, 0.8129417127659573], 
             UndirectedEdge[155, 199] -> 
             RGBColor[
              0.9267674574468086, 0.940310744680851, 0.7960121702127659], 
             UndirectedEdge[28, 151] -> 
             RGBColor[
              0.9436312127659574, 0.8107750212765956, 0.2914626702127658], 
             UndirectedEdge[141, 279] -> 
             RGBColor[
              0.9370266170212767, 0.7845899999999999, 0.2861484574468084], 
             UndirectedEdge[347, 380] -> 
             RGBColor[
              0.9455711276595744, 0.821224978723404, 0.2786554787234041], 
             UndirectedEdge[107, 346] -> 
             RGBColor[
              0.9529605744680851, 0.8422451489361702, 0.3277054787234042], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.9561886170212766, 0.8529881276595744, 0.3526577765957445], 
             UndirectedEdge[171, 299] -> 
             RGBColor[
              0.9629600212765956, 0.8867175957446807, 0.3106071063829785], 
             UndirectedEdge[283, 294] -> 
             RGBColor[
              0.9853704574468085, 0.9849964680851064, 0.686620393617021], 
             UndirectedEdge[83, 244] -> 
             RGBColor[
              0.9629600212765956, 0.8867175957446807, 0.3106071063829785], 
             UndirectedEdge[112, 179] -> 
             RGBColor[
              0.9938038085106383, 0.9891552978723405, 0.566960978723404], 
             UndirectedEdge[42, 93] -> 
             RGBColor[
              0.9678629680851063, 0.973422085106383, 0.8338998404255318], 
             UndirectedEdge[94, 254] -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425531], 
             UndirectedEdge[84, 222] -> 
             RGBColor[
              0.9719515425531915, 0.9296494893617021, 0.590333074468085], 
             UndirectedEdge[132, 366] -> 
             RGBColor[
              0.9855281382978723, 0.9628759574468084, 0.5561882234042552], 
             UndirectedEdge[52, 133] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255317], 
             UndirectedEdge[255, 400] -> 
             RGBColor[
              0.9561886170212766, 0.8529881276595744, 0.3526577765957445], 
             UndirectedEdge[276, 318] -> 
             RGBColor[
              0.9267392765957447, 0.9412682553191489, 0.8669272021276595], 
             UndirectedEdge[235, 313] -> 
             RGBColor[
              0.970079159574468, 0.9078332978723402, 0.511429404255319], 
             UndirectedEdge[218, 229] -> 
             RGBColor[
              0.9282726489361701, 0.9083589148936169, 0.6589978723404254], 
             UndirectedEdge[202, 260] -> 
             RGBColor[
              0.9542412659574467, 0.9289325531914892, 0.6568624787234041], 
             UndirectedEdge[129, 216] -> 
             RGBColor[
              0.989883159574468, 0.9891152765957447, 0.7468777553191488], 
             UndirectedEdge[307, 312] -> 
             RGBColor[
              0.9923598829787235, 0.9895273617021276, 0.6613385638297871], 
             UndirectedEdge[215, 349] -> 
             RGBColor[
              0.9532390212765958, 0.9646463191489361, 0.9640383191489361], 
             UndirectedEdge[48, 61] -> 
             RGBColor[
              0.9681483723404255, 0.9270482978723404, 0.6073038829787233], 
             UndirectedEdge[198, 284] -> 
             RGBColor[
              0.9747830319148936, 0.9308203829787234, 0.5434079680851063], 
             UndirectedEdge[37, 256] -> 
             RGBColor[
              0.9934208617021276, 0.9893540000000001, 0.5992619255319147], 
             UndirectedEdge[260, 366] -> 
             RGBColor[
              0.9589059468085106, 0.9446676170212766, 0.6749838829787234], 
             UndirectedEdge[35, 263] -> 
             RGBColor[
              0.9263864893617021, 0.7423559787234041, 0.26307379787234036`], 
             UndirectedEdge[124, 185] -> 
             RGBColor[
              0.8652295531914893, 0.48092070212765947`, 0.2092565744680851], 
             UndirectedEdge[17, 48] -> 
             RGBColor[
              0.9362395212765957, 0.798421744680851, 0.5778919787234041], 
             UndirectedEdge[98, 139] -> 
             RGBColor[
              0.8977261489361703, 0.9205148936170213, 0.963355755319149], 
             UndirectedEdge[98, 125] -> 
             RGBColor[
              0.9532390212765958, 0.9646463191489361, 0.9640383191489361], 
             UndirectedEdge[195, 397] -> 
             RGBColor[
              0.9802441595744681, 0.9826559574468086, 0.8129417127659573], 
             UndirectedEdge[152, 198] -> 
             RGBColor[
              0.988777074468085, 0.978025574468085, 0.5977721808510639], 
             UndirectedEdge[29, 129] -> 
             RGBColor[
              0.9891736276595744, 0.9875976595744682, 0.6696495851063827], 
             UndirectedEdge[83, 230] -> 
             RGBColor[
              0.9193519361702127, 0.7049675531914893, 0.27143307446808496`], 
             UndirectedEdge[10, 155] -> 
             RGBColor[
              0.9135005212765956, 0.8965800212765955, 0.6575888936170211], 
             UndirectedEdge[210, 316] -> 
             RGBColor[
              0.9029618936170212, 0.5989208936170212, 0.2565185319148935], 
             UndirectedEdge[6, 175] -> 
             RGBColor[
              0.9549004893617021, 0.8526951063829786, 0.31489828723404245`], 
             UndirectedEdge[301, 343] -> 
             RGBColor[
              0.9852015531914894, 0.9611596382978724, 0.44665910638297857`], 
             UndirectedEdge[140, 297] -> 
             RGBColor[
              0.9568699680851064, 0.8554632553191488, 0.5008009787234042], 
             UndirectedEdge[274, 295] -> 
             RGBColor[
              0.9383800957446808, 0.904402744680851, 0.6422854468085106], 
             UndirectedEdge[61, 371] -> 
             RGBColor[
              0.9747830319148936, 0.9308203829787234, 0.5434079680851063], 
             UndirectedEdge[266, 397] -> 
             RGBColor[
              0.9666224574468085, 0.9381664255319148, 0.6359043510638296], 
             UndirectedEdge[71, 88] -> 
             RGBColor[
              0.9595651702127659, 0.8684301702127658, 0.3330196914893616], 
             UndirectedEdge[156, 255] -> 
             RGBColor[
              0.9927395106382979, 0.9868788723404256, 0.45111872340425496`], 
             UndirectedEdge[22, 388] -> 
             RGBColor[
              0.9805368723404255, 0.945424574468085, 0.4285377021276593], 
             UndirectedEdge[17, 346] -> 
             RGBColor[
              0.9403805319148937, 0.7895611702127658, 0.31743801063829785`], 
             UndirectedEdge[72, 365] -> 
             RGBColor[
              0.9646485319148936, 0.9724498936170213, 0.9131258936170212], 
             UndirectedEdge[194, 230] -> 
             RGBColor[
              0.9019630425531915, 0.6394749361702127, 0.2394814468085106], 
             UndirectedEdge[95, 264] -> 
             RGBColor[
              0.9857252234042553, 0.9857552765957447, 0.7252344787234041], 
             UndirectedEdge[131, 325] -> 
             RGBColor[
              0.9930942765957447, 0.9876376808510638, 0.489732808510638], 
             UndirectedEdge[369, 372] -> 
             RGBColor[
              0.9864347553191489, 0.9872728936170213, 0.80246264893617], 
             UndirectedEdge[11, 248] -> 
             RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 
             UndirectedEdge[32, 223] -> 
             RGBColor[
              0.959227329787234, 0.8798919361702127, 0.5765028510638297], 
             UndirectedEdge[75, 229] -> 
             RGBColor[
              0.9812464042553191, 0.9469421914893617, 0.5057658723404252], 
             UndirectedEdge[123, 131] -> 
             RGBColor[
              0.9106290425531915, 0.6015772765957446, 0.3513050851063828], 
             UndirectedEdge[35, 340] -> 
             RGBColor[
              0.9443181063829786, 0.8018217659574467, 0.4196184787234042], 
             UndirectedEdge[316, 369] -> 
             RGBColor[
              0.9728130531914894, 0.9427833617021275, 0.6254252872340423], 
             UndirectedEdge[232, 280] -> 
             RGBColor[
              0.9329373297872341, 0.9240939787234043, 0.6771192765957447], 
             UndirectedEdge[30, 318] -> 
             RGBColor[
              0.9855281382978723, 0.9628759574468084, 0.5561882234042552], 
             UndirectedEdge[219, 338] -> 
             RGBColor[
              0.9322604787234042, 0.8808302127659573, 0.6337694361702126], 
             UndirectedEdge[124, 397] -> 
             RGBColor[
              0.9125000744680851, 0.7141195744680849, 0.5737278510638297], 
             UndirectedEdge[131, 280] -> 
             RGBColor[
              0.9411848191489363, 0.951330829787234, 0.7588070638297871], 
             UndirectedEdge[224, 345] -> 
             RGBColor[
              0.993069414893617, 0.9910449787234042, 0.738566734042553], 
             UndirectedEdge[44, 195] -> 
             RGBColor[
              0.994513340425532, 0.9906729148936171, 0.6441891489361701], 
             UndirectedEdge[57, 102] -> 
             RGBColor[
              0.9926864680851064, 0.9912436808510638, 0.7708676808510637], 
             UndirectedEdge[102, 222] -> 
             RGBColor[
              0.9761987765957447, 0.931405829787234, 0.5199454148936169], 
             UndirectedEdge[86, 285] -> 
             RGBColor[
              0.9267410744680851, 0.7230940425531913, 0.4758903191489361], 
             UndirectedEdge[97, 340] -> 
             RGBColor[
              0.9927146489361702, 0.9902861702127659, 0.6999526489361703], 
             UndirectedEdge[84, 183] -> 
             RGBColor[
              0.9766162234042552, 0.9453845531914893, 0.6084544787234041], 
             UndirectedEdge[23, 132] -> 
             RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 
             UndirectedEdge[124, 210] -> 
             RGBColor[
              0.8488395106382978, 0.3748740425531914, 0.19434203191489358`], 
             UndirectedEdge[257, 288] -> 
             RGBColor[
              0.9898549787234042, 0.9900727872340426, 0.8177927872340425], 
             UndirectedEdge[31, 287] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255319], 
             UndirectedEdge[163, 222] -> 
             RGBColor[
              0.9761987765957447, 0.931405829787234, 0.5199454148936169], 
             UndirectedEdge[206, 386] -> 
             RGBColor[
              0.9805368723404255, 0.945424574468085, 0.4285377021276593], 
             UndirectedEdge[95, 263] -> 
             RGBColor[
              0.9758721914893618, 0.9296895106382979, 0.41041629787234024`], 
             UndirectedEdge[103, 333] -> 
             RGBColor[
              0.9502935531914893, 0.8283207234042553, 0.4245717340425532], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.9846360638297872, 0.9868861489361702, 0.8582261489361702], 
             UndirectedEdge[57, 174] -> 
             RGBColor[
              0.9926864680851064, 0.9912436808510638, 0.7708676808510637], 
             UndirectedEdge[32, 208] -> 
             RGBColor[
              0.9638575106382978, 0.881449574468085, 0.47381424468085087`], 
             UndirectedEdge[11, 125] -> 
             RGBColor[
              0.9632327872340425, 0.9718644468085107, 0.9365884468085106], 
             UndirectedEdge[82, 136] -> 
             RGBColor[
              0.9808916382978723, 0.9461833829787233, 0.4671517872340424], 
             UndirectedEdge[129, 298] -> 
             RGBColor[
              0.9902379255319149, 0.989874085106383, 0.7854918404255318], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.9615050851063829, 0.8788801276595744, 0.3202124999999999], 
             UndirectedEdge[155, 306] -> 
             RGBColor[
              0.9253235319148936, 0.9406828085106382, 0.8903897553191489], 
             UndirectedEdge[247, 358] -> 
             RGBColor[
              0.9526227340425532, 0.8537069148936169, 0.5711886382978723], 
             UndirectedEdge[5, 373] -> 
             RGBColor[
              0.9506483191489362, 0.8290795319148937, 0.4631858191489361], 
             UndirectedEdge[194, 201] -> 
             RGBColor[
              0.9549004893617021, 0.8526951063829786, 0.31489828723404245`], 
             UndirectedEdge[7, 173] -> 
             RGBColor[
              0.9747830319148936, 0.9308203829787234, 0.5434079680851063], 
             UndirectedEdge[25, 364] -> 
             RGBColor[
              0.9808916382978723, 0.9461833829787233, 0.4671517872340424], 
             UndirectedEdge[1, 313] -> 
             RGBColor[
              0.9027180212765957, 0.6390982127659572, 0.23991459574468077`], 
             UndirectedEdge[189, 222] -> 
             RGBColor[
              0.9747830319148936, 0.9308203829787234, 0.5434079680851063], 
             UndirectedEdge[232, 275] -> 
             RGBColor[
              0.9589059468085106, 0.9446676170212766, 0.6749838829787234], 
             UndirectedEdge[289, 376] -> 
             RGBColor[
              0.9556021808510639, 0.9623509148936171, 0.7216019574468083], 
             UndirectedEdge[194, 208] -> 
             RGBColor[
              0.9638575106382978, 0.881449574468085, 0.47381424468085087`], 
             UndirectedEdge[320, 384] -> 
             RGBColor[
              0.9439633404255319, 0.8010629574468084, 0.38100439361702115`], 
             UndirectedEdge[262, 332] -> 
             RGBColor[
              0.9930942765957447, 0.9876376808510638, 0.489732808510638], 
             UndirectedEdge[39, 237] -> 
             RGBColor[
              0.9795346276595744, 0.9811383404255319, 0.7357135425531913], 
             UndirectedEdge[105, 353] -> 
             RGBColor[
              0.9902379255319149, 0.989874085106383, 0.7854918404255318], 
             UndirectedEdge[160, 321] -> 
             RGBColor[
              0.9125000744680851, 0.7141195744680849, 0.5737278510638297], 
             UndirectedEdge[22, 354] -> 
             RGBColor[
              0.9930942765957447, 0.9876376808510638, 0.489732808510638], 
             UndirectedEdge[70, 286] -> 
             RGBColor[
              0.9905757659574468, 0.9784123191489362, 0.5420086808510637], 
             UndirectedEdge[97, 334] -> 
             RGBColor[
              0.9846360638297872, 0.9868861489361702, 0.8582261489361702], 
             UndirectedEdge[301, 362] -> 
             RGBColor[
              0.9941585744680852, 0.9899141063829788, 0.605575063829787], 
             UndirectedEdge[166, 300] -> 
             RGBColor[
              0.9808916382978723, 0.9461833829787233, 0.4671517872340424], 
             UndirectedEdge[357, 364] -> 
             RGBColor[
              0.931051170212766, 0.7580910425531913, 0.2811952021276594], 
             UndirectedEdge[13, 66] -> 
             RGBColor[
              0.9801821063829788, 0.9446657659574467, 0.38992361702127626`], 
             UndirectedEdge[102, 395] -> 
             RGBColor[
              0.9926864680851064, 0.9912436808510638, 0.7708676808510637], 
             UndirectedEdge[129, 336] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255319], 
             UndirectedEdge[257, 275] -> 
             RGBColor[
              0.9632327872340425, 0.9718644468085107, 0.9365884468085106], 
             UndirectedEdge[358, 369] -> 
             RGBColor[
              0.9488195638297872, 0.8511057234042553, 0.5881594468085105], 
             UndirectedEdge[42, 139] -> 
             RGBColor[
              0.8853449574468085, 0.9112810212765957, 0.9843138829787235], 
             UndirectedEdge[37, 206] -> 
             RGBColor[
              0.9930942765957447, 0.9876376808510638, 0.489732808510638], 
             UndirectedEdge[3, 162] -> 
             RGBColor[
              0.9604318617021276, 0.933549489361702, 0.646383414893617], 
             UndirectedEdge[44, 161] -> 
             RGBColor[
              0.986079989361702, 0.9865140851063829, 0.7638485638297872], 
             UndirectedEdge[67, 266] -> 
             RGBColor[0.9780319680851064, 0.94597, 0.5849919255319147], 
             UndirectedEdge[305, 360] -> 
             RGBColor[
              0.9937756276595745, 0.9901128085106383, 0.6378760106382977], 
             UndirectedEdge[51, 174] -> 
             RGBColor[
              0.9634745638297872, 0.8816482765957445, 0.5061151914893616], 
             UndirectedEdge[132, 321] -> 
             RGBColor[
              0.9267410744680851, 0.7230940425531913, 0.4758903191489361], 
             UndirectedEdge[198, 236] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255319], 
             UndirectedEdge[153, 356] -> 
             RGBColor[
              0.9926864680851064, 0.9912436808510638, 0.7708676808510637], 
             UndirectedEdge[78, 217] -> 
             RGBColor[
              0.9502358085106382, 0.8369600425531912, 0.2967768829787232], 
             UndirectedEdge[16, 324] -> 
             RGBColor[
              0.8714944893617022, 0.9001621276595745, 0.9718584361702127], 
             UndirectedEdge[263, 312] -> 
             RGBColor[
              0.9747830319148936, 0.9308203829787234, 0.5434079680851063], 
             UndirectedEdge[49, 231] -> 
             RGBColor[
              0.8948234787234042, 0.665716319148936, 0.5896751382978723], 
             UndirectedEdge[58, 303] -> 
             RGBColor[
              0.9408300531914894, 0.9505720212765958, 0.720192978723404], 
             UndirectedEdge[287, 371] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255319], 
             UndirectedEdge[108, 332] -> 
             RGBColor[
              0.9895283936170213, 0.9883564680851065, 0.7082636702127658], 
             UndirectedEdge[55, 135] -> 
             RGBColor[
              0.9926864680851064, 0.9912436808510638, 0.7708676808510637], 
             UndirectedEdge[38, 145] -> 
             RGBColor[
              0.968663414893617, 0.9072478510638297, 0.5348919574468085], 
             UndirectedEdge[41, 400] -> 
             RGBColor[
              0.9561886170212766, 0.8529881276595744, 0.3526577765957445], 
             UndirectedEdge[184, 369] -> 
             RGBColor[
              0.986079989361702, 0.9865140851063829, 0.7638485638297872], 
             UndirectedEdge[68, 363] -> 
             RGBColor[
              0.9311749468085107, 0.7490703404255319, 0.5042339361702128], 
             UndirectedEdge[239, 350] -> 
             RGBColor[
              0.9615050851063829, 0.8788801276595744, 0.3202124999999999], 
             UndirectedEdge[197, 300] -> 
             RGBColor[0.9780319680851064, 0.94597, 0.5849919255319147], 
             UndirectedEdge[34, 340] -> 
             RGBColor[
              0.986079989361702, 0.9865140851063829, 0.7638485638297872], 
             UndirectedEdge[99, 225] -> 
             RGBColor[
              0.9722893829787234, 0.9181877234042553, 0.34684991489361683`], 
             UndirectedEdge[75, 218] -> 
             RGBColor[
              0.9418943510638298, 0.9528484468085107, 0.8360352340425531], 
             UndirectedEdge[33, 256] -> 
             RGBColor[
              0.9808634574468085, 0.9471408936170211, 0.538066819148936], 
             UndirectedEdge[68, 173] -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 
             UndirectedEdge[76, 368] -> 
             RGBColor[
              0.9495840212765958, 0.8268031063829788, 0.3473435638297871], 
             UndirectedEdge[343, 369] -> 
             RGBColor[
              0.9774777340425531, 0.9585184255319149, 0.6435466914893616], 
             UndirectedEdge[172, 243] -> 
             RGBColor[
              0.986283425531915, 0.965392914893617, 0.4012141276595744], 
             UndirectedEdge[25, 83] -> 
             RGBColor[
              0.9808916382978723, 0.9461833829787233, 0.4671517872340424], 
             UndirectedEdge[176, 372] -> 
             RGBColor[
              0.9941585744680852, 0.9899141063829788, 0.605575063829787], 
             UndirectedEdge[211, 214] -> 
             RGBColor[
              0.9902379255319149, 0.989874085106383, 0.7854918404255318], 
             UndirectedEdge[273, 330] -> 
             RGBColor[
              0.9565433829787234, 0.8537469361702128, 0.3912718617021275], 
             UndirectedEdge[247, 266] -> 
             RGBColor[
              0.9766162234042552, 0.9453845531914893, 0.6084544787234041], 
             UndirectedEdge[294, 347] -> 
             RGBColor[
              0.9681483723404255, 0.9270482978723404, 0.6073038829787233], 
             UndirectedEdge[247, 343] -> 
             RGBColor[
              0.9812809042553191, 0.9611196170212766, 0.6265758829787234], 
             UndirectedEdge[147, 354] -> 
             RGBColor[
              0.9801821063829788, 0.9446657659574467, 0.38992361702127626`], 
             UndirectedEdge[83, 206] -> 
             RGBColor[
              0.9805368723404255, 0.945424574468085, 0.4285377021276593], 
             UndirectedEdge[178, 300] -> 
             RGBColor[
              0.9769540638297872, 0.9339227872340424, 0.364971319148936], 
             UndirectedEdge[31, 384] -> 
             RGBColor[
              0.9428741808510638, 0.802193829787234, 0.5139960638297872], 
             UndirectedEdge[325, 339] -> 
             RGBColor[
              0.9561886170212766, 0.8529881276595744, 0.3526577765957445], 
             UndirectedEdge[43, 237] -> 
             RGBColor[
              0.9492335638297872, 0.8726738085106381, 0.6039527234042552], 
             UndirectedEdge[114, 128] -> 
             RGBColor[
              0.9403805319148937, 0.7895611702127658, 0.31743801063829785`], 
             UndirectedEdge[131, 188] -> 
             RGBColor[
              0.9671534361702128, 0.9719044680851063, 0.7566716702127658], 
             UndirectedEdge[8, 352] -> 
             RGBColor[
              0.9676247021276596, 0.902452659574468, 0.3287285106382978], 
             UndirectedEdge[56, 137] -> 
             RGBColor[
              0.9496475638297872, 0.8942418936170211, 0.6197459999999999], 
             UndirectedEdge[11, 93] -> 
             RGBColor[
              0.9902379255319149, 0.989874085106383, 0.7854918404255318], 
             UndirectedEdge[232, 325] -> 
             RGBColor[
              0.9848467872340425, 0.9604008297872341, 0.40804502127659553`], 
             UndirectedEdge[293, 387] -> 
             RGBColor[
              0.9186888723404255, 0.9369107234042553, 0.9542856702127659], 
             UndirectedEdge[100, 175] -> 
             RGBColor[
              0.985911085106383, 0.9626772553191489, 0.5238872765957445], 
             UndirectedEdge[327, 336] -> 
             RGBColor[
              0.9784454680851064, 0.9822692127659574, 0.8687052127659574], 
             UndirectedEdge[230, 357] -> 
             RGBColor[
              0.8827784042553191, 0.5606059361702127, 0.22389976595744682`], 
             UndirectedEdge[151, 291] -> 
             RGBColor[
              0.9482958936170213, 0.8265100851063829, 0.30958407446808506`], 
             UndirectedEdge[10, 87] -> 
             RGBColor[
              0.931051170212766, 0.7580910425531913, 0.2811952021276594], 
             UndirectedEdge[44, 247] -> 
             RGBColor[
              0.989883159574468, 0.9891152765957447, 0.7468777553191488], 
             UndirectedEdge[191, 334] -> 
             RGBColor[
              0.981804574468085, 0.985715255319149, 0.9051512553191488], 
             UndirectedEdge[31, 389] -> 
             RGBColor[
              0.9554542234042553, 0.8548778085106382, 0.5242635319148936], 
             UndirectedEdge[323, 346] -> 
             RGBColor[
              0.988777074468085, 0.978025574468085, 0.5977721808510639], 
             UndirectedEdge[91, 257] -> 
             RGBColor[
              0.9756139787234042, 0.9810983191489362, 0.9156303191489361], 
             UndirectedEdge[25, 217] -> 
             RGBColor[
              0.9635027446808511, 0.8806907659574467, 0.435200159574468], 
             UndirectedEdge[4, 238] -> 
             RGBColor[
              0.8437435319148937, 0.8771540425531916, 0.9059467765957445], 
             UndirectedEdge[49, 298] -> 
             RGBColor[
              0.9218286170212766, 0.6837259574468084, 0.4385785319148935], 
             UndirectedEdge[96, 245] -> 
             RGBColor[
              0.907719914893617, 0.9277330212765957, 0.9359058829787233], 
             UndirectedEdge[198, 219] -> 
             RGBColor[
              0.968663414893617, 0.9072478510638297, 0.5348919574468085], 
             UndirectedEdge[69, 106] -> 
             RGBColor[
              0.993069414893617, 0.9910449787234042, 0.738566734042553], 
             UndirectedEdge[246, 350] -> 
             RGBColor[
              0.9650965425531914, 0.9492845531914893, 0.6645048191489362], 
             UndirectedEdge[91, 263] -> 
             RGBColor[
              0.9619577765957447, 0.9224313617021276, 0.6177829468085105], 
             UndirectedEdge[193, 305] -> 
             RGBColor[
              0.9502653723404255, 0.8292782340425533, 0.4954867659574468], 
             UndirectedEdge[217, 244] -> 
             RGBColor[
              0.9455711276595744, 0.821224978723404, 0.2786554787234041], 
             UndirectedEdge[218, 260] -> 
             RGBColor[
              0.9148892127659574, 0.9348388085106383, 0.987131840425532], 
             UndirectedEdge[115, 169] -> 
             RGBColor[
              0.9260597234042554, 0.7206189148936168, 0.3277471170212764], 
             UndirectedEdge[152, 332] -> 
             RGBColor[
              0.9898662340425533, 0.9768947021276596, 0.46478051063829773`], 
             UndirectedEdge[8, 227] -> 
             RGBColor[
              0.9495765851063829, 0.9131974893617021, 0.638741074468085], 
             UndirectedEdge[161, 344] -> 
             RGBColor[
              0.955424159574468, 0.8772907446808509, 0.593473659574468], 
             UndirectedEdge[255, 324] -> 
             RGBColor[
              0.9729892659574468, 0.9757625957446809, 0.7075785212765956], 
             UndirectedEdge[135, 221] -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425531], 
             UndirectedEdge[179, 257] -> 
             RGBColor[
              0.9891736276595744, 0.9875976595744682, 0.6696495851063827], 
             UndirectedEdge[40, 350] -> 
             RGBColor[
              0.9826966489361701, 0.9617050638297873, 0.603113329787234], 
             UndirectedEdge[358, 397] -> 
             RGBColor[
              0.9426289680851063, 0.8464887872340425, 0.5986385106382979], 
             UndirectedEdge[44, 149] -> 
             RGBColor[
              0.989883159574468, 0.9891152765957447, 0.7468777553191488], 
             UndirectedEdge[215, 218] -> 
             RGBColor[
              0.9272704042553191, 0.9440726808510638, 0.9661737127659574], 
             UndirectedEdge[211, 248] -> 
             RGBColor[
              0.9902379255319149, 0.989874085106383, 0.7854918404255318], 
             UndirectedEdge[38, 103] -> 
             RGBColor[
              0.9488496276595745, 0.8286927872340426, 0.5189493191489363], 
             UndirectedEdge[79, 213] -> 
             RGBColor[
              0.9722893829787234, 0.9181877234042553, 0.34684991489361694`], 
             UndirectedEdge[116, 383] -> 
             RGBColor[0.990221, 0.9776535106382979, 0.5033945957446808], 
             UndirectedEdge[214, 263] -> 
             RGBColor[
              0.9719515425531915, 0.9296494893617021, 0.590333074468085], 
             UndirectedEdge[203, 275] -> 
             RGBColor[
              0.9176677340425532, 0.7845709361702127, 0.609329170212766], 
             UndirectedEdge[235, 396] -> 
             RGBColor[
              0.9855281382978723, 0.9628759574468084, 0.5561882234042552], 
             UndirectedEdge[170, 361] -> 
             RGBColor[
              0.9941585744680852, 0.9899141063829788, 0.605575063829787], 
             UndirectedEdge[190, 255] -> 
             RGBColor[
              0.9920051170212766, 0.9887685531914894, 0.6227244787234041], 
             UndirectedEdge[67, 113] -> 
             RGBColor[
              0.9606430744680851, 0.8804773829787234, 0.5530402978723403], 
             UndirectedEdge[244, 307] -> 
             RGBColor[
              0.9758721914893618, 0.9296895106382979, 0.41041629787234024`], 
             UndirectedEdge[106, 292] -> 
             RGBColor[
              0.9271222234042553, 0.9410695531914893, 0.8346262553191488], 
             UndirectedEdge[119, 126] -> 
             RGBColor[
              0.9902379255319149, 0.989874085106383, 0.7854918404255318], 
             UndirectedEdge[148, 288] -> 
             RGBColor[
              0.9674800212765957, 0.9736207872340426, 0.8662007872340425], 
             UndirectedEdge[143, 277] -> 
             RGBColor[
              0.968663414893617, 0.9072478510638297, 0.5348919574468085], 
             UndirectedEdge[245, 364] -> 
             RGBColor[
              0.8987283936170213, 0.8848011276595744, 0.6561799148936169], 
             UndirectedEdge[101, 335] -> 
             RGBColor[
              0.981804574468085, 0.985715255319149, 0.9051512553191488], 
             UndirectedEdge[175, 296] -> 
             RGBColor[
              0.9812809042553191, 0.9611196170212766, 0.6265758829787234], 
             UndirectedEdge[106, 158] -> 
             RGBColor[
              0.9948681063829787, 0.9914317234042553, 0.6828032340425529], 
             UndirectedEdge[59, 319] -> 
             RGBColor[
              0.9898549787234042, 0.9900727872340426, 0.8177927872340425], 
             UndirectedEdge[159, 218] -> 
             RGBColor[
              0.937264170212766, 0.9512908085106384, 0.9387238404255318], 
             UndirectedEdge[126, 326] -> 
             RGBColor[
              0.9898549787234042, 0.9900727872340426, 0.8177927872340425], 
             UndirectedEdge[130, 371] -> 
             RGBColor[
              0.9747830319148936, 0.9308203829787234, 0.5434079680851063], 
             UndirectedEdge[108, 262] -> 
             RGBColor[
              0.9891736276595744, 0.9875976595744682, 0.6696495851063827], 
             UndirectedEdge[34, 91] -> 
             RGBColor[
              0.9718108085106383, 0.9784971276595744, 0.9326011276595744], 
             UndirectedEdge[173, 323] -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 
             UndirectedEdge[104, 208] -> 
             RGBColor[
              0.9864347553191489, 0.9872728936170213, 0.80246264893617], 
             UndirectedEdge[115, 122] -> 
             RGBColor[
              0.9920051170212766, 0.9887685531914894, 0.6227244787234041], 
             UndirectedEdge[275, 297] -> 
             RGBColor[
              0.9674800212765957, 0.9736207872340426, 0.8662007872340425], 
             UndirectedEdge[185, 293] -> 
             RGBColor[
              0.9245402872340425, 0.745298255319149, 0.5681298510638297], 
             UndirectedEdge[92, 256] -> 
             RGBColor[
              0.9568699680851064, 0.8554632553191488, 0.5008009787234042], 
             UndirectedEdge[135, 165] -> 
             RGBColor[
              0.9901928191489362, 0.9786110212765957, 0.5743096276595744], 
             UndirectedEdge[158, 270] -> 
             RGBColor[
              0.993069414893617, 0.9910449787234042, 0.738566734042553], 
             UndirectedEdge[35, 86] -> 
             RGBColor[
              0.9442899255319148, 0.8027792765957446, 0.49053351063829775`], 
             UndirectedEdge[124, 387] -> 
             RGBColor[
              0.8593781382978722, 0.6725331702127657, 0.5954123936170213], 
             UndirectedEdge[170, 261] -> 
             RGBColor[
              0.9941585744680852, 0.9899141063829788, 0.605575063829787], 
             UndirectedEdge[78, 244] -> 
             RGBColor[
              0.9629600212765956, 0.8867175957446807, 0.3106071063829785], 
             UndirectedEdge[320, 381] -> 
             RGBColor[
              0.9941585744680852, 0.9899141063829788, 0.605575063829787], 
             UndirectedEdge[90, 166] -> 
             RGBColor[
              0.9798893936170212, 0.9818971489361702, 0.7743276276595744], 
             UndirectedEdge[119, 317] -> 
             RGBColor[
              0.9638575106382978, 0.881449574468085, 0.47381424468085087`], 
             UndirectedEdge[173, 250] -> 
             RGBColor[
              0.9794477127659573, 0.9465554468085104, 0.5615293723404253], 
             UndirectedEdge[234, 355] -> 
             RGBColor[
              0.9678629680851063, 0.973422085106383, 0.8338998404255318], 
             UndirectedEdge[203, 297] -> 
             RGBColor[
              0.9442899255319148, 0.8027792765957446, 0.49053351063829775`], 
             UndirectedEdge[48, 388] -> 
             RGBColor[
              0.9728130531914894, 0.9427833617021275, 0.6254252872340423], 
             UndirectedEdge[34, 95] -> 
             RGBColor[
              0.9857252234042553, 0.9857552765957447, 0.7252344787234041], 
             UndirectedEdge[133, 299] -> 
             RGBColor[
              0.9733672872340425, 0.9302349361702127, 0.5668705212765957], 
             UndirectedEdge[58, 376] -> 
             RGBColor[
              0.9927395106382979, 0.9868788723404256, 0.45111872340425496`], 
             UndirectedEdge[239, 392] -> 
             RGBColor[
              0.5624915531914894, 0.564615734042553, 0.6044773404255319], 
             UndirectedEdge[64, 77] -> 
             RGBColor[
              0.9898549787234042, 0.9900727872340426, 0.8177927872340425], 
             UndirectedEdge[73, 112] -> 
             RGBColor[
              0.9704621063829787, 0.9076345957446807, 0.4791284574468083], 
             UndirectedEdge[257, 339] -> 
             RGBColor[
              0.9526227340425532, 0.8537069148936169, 0.5711886382978723], 
             UndirectedEdge[35, 85] -> 
             RGBColor[
              0.931051170212766, 0.7580910425531913, 0.2811952021276594], 
             UndirectedEdge[37, 187] -> 
             RGBColor[
              0.9848467872340425, 0.9604008297872341, 0.40804502127659553`], 
             UndirectedEdge[9, 39] -> 
             RGBColor[
              0.9733440319148936, 0.9765214042553192, 0.7461926063829787], 
             UndirectedEdge[136, 394] -> 
             RGBColor[
              0.9805368723404255, 0.945424574468085, 0.4285377021276593], 
             UndirectedEdge[287, 389] -> 
             RGBColor[
              0.9526227340425532, 0.8537069148936169, 0.5711886382978723], 
             UndirectedEdge[195, 372] -> 
             RGBColor[
              0.9948681063829787, 0.9914317234042553, 0.6828032340425529], 
             UndirectedEdge[149, 362] -> 
             RGBColor[
              0.9902379255319149, 0.989874085106383, 0.7854918404255318], 
             UndirectedEdge[83, 321] -> 
             RGBColor[
              0.9135023191489361, 0.678405808510638, 0.2665520106382977], 
             UndirectedEdge[227, 308] -> 
             RGBColor[
              0.9542412659574467, 0.9289325531914892, 0.6568624787234041], 
             UndirectedEdge[100, 146] -> 
             RGBColor[
              0.9905757659574468, 0.9784123191489362, 0.5420086808510637], 
             UndirectedEdge[100, 278] -> 
             RGBColor[
              0.9944851595744681, 0.9916304255319148, 0.7151041808510636], 
             UndirectedEdge[234, 350] -> 
             RGBColor[
              0.9589059468085106, 0.9446676170212766, 0.6749838829787234], 
             UndirectedEdge[278, 352] -> 
             RGBColor[
              0.9855281382978723, 0.9628759574468084, 0.5561882234042552], 
             UndirectedEdge[342, 353] -> 
             RGBColor[
              0.9898549787234042, 0.9900727872340426, 0.8177927872340425], 
             UndirectedEdge[109, 181] -> 
             RGBColor[
              0.9701073404255318, 0.9068757872340425, 0.44051437234042545`], 
             UndirectedEdge[59, 296] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255319], 
             UndirectedEdge[168, 378] -> 
             RGBColor[
              0.9671534361702128, 0.9719044680851063, 0.7566716702127658], 
             UndirectedEdge[191, 370] -> 
             RGBColor[
              0.9895283936170213, 0.9883564680851065, 0.7082636702127658], 
             UndirectedEdge[153, 184] -> 
             RGBColor[
              0.9941303936170213, 0.9908716170212766, 0.6764900957446808], 
             UndirectedEdge[3, 91] -> 
             RGBColor[
              0.9594296170212766, 0.9692632553191489, 0.953559255319149], 
             UndirectedEdge[149, 210] -> 
             RGBColor[
              0.911953414893617, 0.6418527872340427, 0.5362444999999999], 
             UndirectedEdge[3, 312] -> 
             RGBColor[
              0.9722548723404254, 0.9776522765957447, 0.8791842765957447], 
             UndirectedEdge[17, 388] -> 
             RGBColor[
              0.931051170212766, 0.7580910425531913, 0.2811952021276594], 
             UndirectedEdge[99, 243] -> 
             RGBColor[
              0.9816187446808511, 0.9496578510638298, 0.38309272340425526`], 
             UndirectedEdge[108, 398] -> 
             RGBColor[
              0.9658319255319148, 0.9060769574468084, 0.5818170638297872], 
             UndirectedEdge[57, 186] -> 
             RGBColor[
              0.9794477127659573, 0.9465554468085104, 0.5615293723404253], 
             UndirectedEdge[180, 398] -> 
             RGBColor[
              0.9658319255319148, 0.9060769574468084, 0.5818170638297872], 
             UndirectedEdge[66, 318] -> 
             RGBColor[
              0.9934208617021276, 0.9893540000000001, 0.5992619255319147], 
             UndirectedEdge[374, 382] -> 
             RGBColor[
              0.9403805319148937, 0.7895611702127658, 0.31743801063829785`], 
             UndirectedEdge[190, 270] -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 
             UndirectedEdge[47, 96] -> 
             RGBColor[
              0.985945585106383, 0.9768546808510639, 0.6446972872340424], 
             UndirectedEdge[245, 328] -> 
             RGBColor[
              0.8940637127659574, 0.8690660638297871, 0.6380585106382979], 
             UndirectedEdge[142, 143] -> 
             RGBColor[
              0.9747830319148936, 0.9308203829787234, 0.5434079680851063], 
             UndirectedEdge[268, 373] -> 
             RGBColor[
              0.9416912978723404, 0.8003250638297873, 0.30426986170212766`], 
             UndirectedEdge[69, 390] -> 
             RGBColor[
              0.9311749468085107, 0.7490703404255319, 0.5042339361702128], 
             UndirectedEdge[91, 112] -> 
             RGBColor[
              0.9802441595744681, 0.9826559574468086, 0.8129417127659573], 
             UndirectedEdge[16, 190] -> 
             RGBColor[
              0.8905103404255319, 0.913168085106383, 0.8870043936170213], 
             UndirectedEdge[40, 395] -> 
             RGBColor[
              0.9898549787234042, 0.9900727872340426, 0.8177927872340425], 
             UndirectedEdge[84, 246] -> 
             RGBColor[
              0.9694233829787233, 0.9764813829787234, 0.9261093829787234], 
             UndirectedEdge[196, 376] -> 
             RGBColor[
              0.9938038085106383, 0.9891552978723405, 0.566960978723404], 
             UndirectedEdge[37, 311] -> 
             RGBColor[
              0.9556021808510639, 0.9623509148936171, 0.7216019574468083], 
             UndirectedEdge[179, 275] -> 
             RGBColor[
              0.966798670212766, 0.9711456595744681, 0.7180575851063828], 
             UndirectedEdge[334, 340] -> 
             RGBColor[
              0.986079989361702, 0.9865140851063829, 0.7638485638297872], 
             UndirectedEdge[23, 366] -> 
             RGBColor[
              0.9855281382978723, 0.9628759574468084, 0.5561882234042552], 
             UndirectedEdge[295, 351] -> 
             RGBColor[
              0.9296613404255318, 0.9466177021276596, 0.9885408191489362], 
             UndirectedEdge[358, 363] -> 
             RGBColor[
              0.8953584468085106, 0.6132899148936171, 0.23416723404255319`], 
             UndirectedEdge[111, 116] -> 
             RGBColor[
              0.9267692553191489, 0.7221365319148935, 0.4049752872340425], 
             UndirectedEdge[147, 371] -> 
             RGBColor[
              0.9794477127659573, 0.9465554468085104, 0.5615293723404253], 
             UndirectedEdge[33, 311] -> 
             RGBColor[
              0.9430447765957446, 0.9201378085106382, 0.6604068510638297], 
             UndirectedEdge[137, 178] -> 
             RGBColor[
              0.9697612234042553, 0.9650196170212766, 0.6826262234042553], 
             UndirectedEdge[328, 386] -> 
             RGBColor[
              0.9629600212765956, 0.8867175957446807, 0.3106071063829785], 
             UndirectedEdge[20, 36] -> 
             RGBColor[
              0.7040828723404255, 0.7643683404255319, 0.9181632234042553], 
             UndirectedEdge[107, 212] -> 
             RGBColor[
              0.9568981489361702, 0.854505744680851, 0.4298859468085106], 
             UndirectedEdge[21, 27] -> 
             RGBColor[
              0.9923598829787235, 0.9895273617021276, 0.6613385638297871], 
             UndirectedEdge[138, 329] -> 
             RGBColor[
              0.9873613297872341, 0.9774401276595746, 0.621234734042553], 
             UndirectedEdge[3, 263] -> 
             RGBColor[
              0.9557671808510637, 0.9178144255319148, 0.6282620106382979], 
             UndirectedEdge[239, 269] -> 
             RGBColor[
              0.9701073404255318, 0.9068757872340425, 0.44051437234042545`], 
             UndirectedEdge[74, 86] -> 
             RGBColor[
              0.9937756276595745, 0.9901128085106383, 0.6378760106382977], 
             UndirectedEdge[91, 179] -> 
             RGBColor[
              0.9791798617021277, 0.9803795319148936, 0.6970994574468083], 
             UndirectedEdge[316, 358] -> 
             RGBColor[
              0.9436312127659574, 0.8107750212765956, 0.2914626702127658], 
             UndirectedEdge[154, 267] -> 
             RGBColor[
              0.9927146489361702, 0.9902861702127659, 0.6999526489361703], 
             UndirectedEdge[25, 357] -> 
             RGBColor[
              0.9443181063829786, 0.8018217659574467, 0.41961847872340424`], 
             UndirectedEdge[118, 388] -> 
             RGBColor[
              0.9629600212765956, 0.8867175957446807, 0.3106071063829785], 
             UndirectedEdge[305, 340] -> 
             RGBColor[
              0.9941303936170213, 0.9908716170212766, 0.6764900957446808], 
             UndirectedEdge[100, 213] -> 
             RGBColor[
              0.9765817234042553, 0.9312071276595744, 0.4876444680851062], 
             UndirectedEdge[51, 238] -> 
             RGBColor[
              0.8159473723404256, 0.768144085106383, 0.6177317340425532], 
             UndirectedEdge[104, 242] -> 
             RGBColor[
              0.9728130531914894, 0.9427833617021275, 0.6254252872340423], 
             UndirectedEdge[99, 337] -> 
             RGBColor[
              0.9650965425531914, 0.9492845531914893, 0.6645048191489362], 
             UndirectedEdge[143, 302] -> 
             RGBColor[
              0.9926864680851064, 0.9912436808510638, 0.7708676808510637], 
             UndirectedEdge[14, 327] -> 
             RGBColor[
              0.9360243723404256, 0.8203037659574468, 0.5933242978723404], 
             UndirectedEdge[162, 348] -> 
             RGBColor[
              0.9370266170212767, 0.7845899999999999, 0.2861484574468084], 
             UndirectedEdge[130, 391] -> 
             RGBColor[
              0.9765817234042553, 0.9312071276595744, 0.4876444680851062], 
             UndirectedEdge[182, 386] -> 
             RGBColor[
              0.931051170212766, 0.7580910425531913, 0.2811952021276594], 
             UndirectedEdge[32, 217] -> 
             RGBColor[
              0.9328469148936169, 0.7714674255319146, 0.26482525531914886`], 
             UndirectedEdge[3, 285] -> 
             RGBColor[
              0.9063094787234042, 0.7095026382978722, 0.5842069148936171], 
             UndirectedEdge[212, 274] -> 
             RGBColor[
              0.9762269574468085, 0.9304483191489361, 0.44903038297872333`], 
             UndirectedEdge[234, 272] -> 
             RGBColor[
              0.9646485319148936, 0.9724498936170213, 0.9131258936170212], 
             UndirectedEdge[24, 104] -> 
             RGBColor[
              0.9620287553191489, 0.9034757659574467, 0.5987878723404254], 
             UndirectedEdge[317, 327] -> 
             RGBColor[
              0.9492335638297872, 0.8726738085106381, 0.6039527234042552], 
             UndirectedEdge[85, 263] -> 
             RGBColor[
              0.9629600212765956, 0.8867175957446807, 0.3106071063829785], 
             UndirectedEdge[169, 300] -> 
             RGBColor[
              0.9135023191489361, 0.678405808510638, 0.2665520106382977], 
             UndirectedEdge[34, 162] -> 
             RGBColor[
              0.9728130531914894, 0.9427833617021275, 0.6254252872340423], 
             UndirectedEdge[62, 313] -> 
             RGBColor[
              0.9615050851063829, 0.8788801276595744, 0.3202124999999999], 
             UndirectedEdge[337, 367] -> 
             RGBColor[
              0.9722548723404254, 0.9776522765957447, 0.8791842765957447], 
             UndirectedEdge[21, 240] -> 
             RGBColor[
              0.9852015531914894, 0.9611596382978724, 0.44665910638297857`], 
             UndirectedEdge[258, 378] -> 
             RGBColor[
              0.9758721914893618, 0.9296895106382979, 0.41041629787234024`], 
             UndirectedEdge[240, 242] -> 
             RGBColor[
              0.9722893829787234, 0.9181877234042553, 0.34684991489361683`], 
             UndirectedEdge[16, 380] -> 
             RGBColor[
              0.8612984361702127, 0.8035726808510637, 0.6222519042553191], 
             UndirectedEdge[38, 222] -> 
             RGBColor[
              0.9747830319148936, 0.9308203829787234, 0.5434079680851063], 
             UndirectedEdge[61, 147] -> 
             RGBColor[
              0.9629600212765956, 0.8867175957446807, 0.3106071063829785], 
             UndirectedEdge[279, 288] -> 
             RGBColor[
              0.9502653723404255, 0.8292782340425533, 0.4954867659574468], 
             UndirectedEdge[192, 384] -> 
             RGBColor[
              0.9442899255319148, 0.8027792765957446, 0.4905335106382978], 
             UndirectedEdge[196, 289] -> 
             RGBColor[
              0.9566664787234043, 0.9646273404255319, 0.8374442127659574], 
             UndirectedEdge[9, 384] -> 
             RGBColor[
              0.923858329787234, 0.7891878723404254, 0.5988501063829788], 
             UndirectedEdge[114, 187] -> 
             RGBColor[
              0.9816187446808511, 0.9496578510638298, 0.38309272340425526`], 
             UndirectedEdge[90, 274] -> 
             RGBColor[
              0.9619577765957447, 0.9224313617021276, 0.6177829468085105], 
             UndirectedEdge[270, 324] -> 
             RGBColor[
              0.9722548723404254, 0.9776522765957447, 0.8791842765957447], 
             UndirectedEdge[42, 45] -> 
             RGBColor[
              0.9678629680851063, 0.973422085106383, 0.8338998404255318], 
             UndirectedEdge[316, 363] -> 
             RGBColor[
              0.9193519361702127, 0.7049675531914893, 0.27143307446808496`], 
             UndirectedEdge[44, 250] -> 
             RGBColor[
              0.9808916382978723, 0.9461833829787233, 0.4671517872340424], 
             UndirectedEdge[213, 352] -> 
             RGBColor[
              0.9676247021276596, 0.902452659574468, 0.3287285106382978], 
             UndirectedEdge[80, 378] -> 
             RGBColor[
              0.9895283936170213, 0.9883564680851065, 0.7082636702127658], 
             UndirectedEdge[238, 272] -> 
             RGBColor[
              0.8437435319148937, 0.8771540425531916, 0.9059467765957445], 
             UndirectedEdge[126, 196] -> 
             RGBColor[
              0.9902379255319149, 0.989874085106383, 0.7854918404255318], 
             UndirectedEdge[112, 240] -> 
             RGBColor[
              0.985911085106383, 0.9626772553191489, 0.5238872765957445], 
             UndirectedEdge[52, 89] -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425531], 
             UndirectedEdge[99, 177] -> 
             RGBColor[
              0.9852015531914894, 0.9611596382978724, 0.44665910638297857`], 
             UndirectedEdge[41, 206] -> 
             RGBColor[
              0.9930942765957447, 0.9876376808510638, 0.489732808510638], 
             UndirectedEdge[1, 119] -> 
             RGBColor[
              0.9271240212765957, 0.7228953404255318, 0.4435893723404254], 
             UndirectedEdge[2, 109] -> 
             RGBColor[
              0.970079159574468, 0.9078332978723402, 0.511429404255319], 
             UndirectedEdge[8, 100] -> 
             RGBColor[
              0.9765817234042553, 0.9312071276595744, 0.4876444680851062], 
             UndirectedEdge[203, 322] -> 
             RGBColor[
              0.9439633404255319, 0.8010629574468084, 0.3810043936170211], 
             UndirectedEdge[98, 193] -> 
             RGBColor[
              0.9360243723404256, 0.8203037659574468, 0.5933242978723404], 
             UndirectedEdge[141, 285] -> 
             RGBColor[
              0.9135023191489361, 0.678405808510638, 0.2665520106382977], 
             UndirectedEdge[29, 231] -> 
             RGBColor[
              0.966798670212766, 0.9711456595744681, 0.7180575851063828], 
             UndirectedEdge[225, 398] -> 
             RGBColor[
              0.9568404042553191, 0.8631450638297871, 0.3020910957446806], 
             UndirectedEdge[149, 359] -> 
             RGBColor[
              0.9283434574468085, 0.7478994468085107, 0.5511590425531914], 
             UndirectedEdge[87, 235] -> 
             RGBColor[
              0.9442899255319148, 0.8027792765957446, 0.49053351063829775`], 
             UndirectedEdge[162, 312] -> 
             RGBColor[
              0.9794477127659573, 0.9465554468085104, 0.5615293723404253], 
             UndirectedEdge[392, 395] -> 
             RGBColor[
              0.5850988617021275, 0.6480261170212767, 0.8639156170212766], 
             UndirectedEdge[212, 268] -> 
             RGBColor[
              0.9855563191489362, 0.9619184468085107, 0.48527319148936165`], 
             UndirectedEdge[50, 271] -> 
             RGBColor[
              0.9769540638297872, 0.9339227872340424, 0.364971319148936], 
             UndirectedEdge[200, 207] -> 
             RGBColor[
              0.9656202127659574, 0.9738801914893618, 0.9430801914893616], 
             UndirectedEdge[360, 370] -> 
             RGBColor[
              0.9934490425531916, 0.9883964893617022, 0.528346893617021], 
             UndirectedEdge[134, 246] -> 
             RGBColor[
              0.9430429680851062, 0.8680568723404254, 0.6144317872340426], 
             UndirectedEdge[88, 191] -> 
             RGBColor[
              0.959227329787234, 0.8798919361702127, 0.5765028510638297], 
             UndirectedEdge[277, 278] -> 
             RGBColor[
              0.970079159574468, 0.9078332978723402, 0.511429404255319], 
             UndirectedEdge[233, 242] -> 
             RGBColor[
              0.9808634574468085, 0.9471408936170211, 0.538066819148936], 
             UndirectedEdge[66, 123] -> 
             RGBColor[
              0.9102742765957447, 0.6008184680851063, 0.31269099999999983`], 
             UndirectedEdge[315, 316] -> 
             RGBColor[
              0.9801821063829788, 0.9446657659574467, 0.38992361702127626`], 
             UndirectedEdge[127, 216] -> 
             RGBColor[0.990221, 0.9776535106382979, 0.5033945957446808], 
             UndirectedEdge[29, 326] -> 
             RGBColor[
              0.9934208617021276, 0.9893540000000001, 0.5992619255319147], 
             UndirectedEdge[76, 145] -> 
             RGBColor[
              0.9262423191489362, 0.7452824042553191, 0.25951104255319146`], 
             UndirectedEdge[21, 104] -> 
             RGBColor[
              0.9857252234042553, 0.9857552765957447, 0.7252344787234041], 
             UndirectedEdge[27, 112] -> 
             RGBColor[
              0.993069414893617, 0.9910449787234042, 0.738566734042553], 
             UndirectedEdge[190, 221] -> 
             RGBColor[
              0.9898549787234042, 0.9900727872340426, 0.8177927872340425], 
             UndirectedEdge[310, 324] -> 
             RGBColor[
              0.9364383723404255, 0.8418718510638297, 0.6091175744680851], 
             UndirectedEdge[11, 312] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255319], 
             UndirectedEdge[177, 225] -> 
             RGBColor[
              0.9805368723404255, 0.945424574468085, 0.4285377021276593], 
             UndirectedEdge[253, 316] -> 
             RGBColor[
              0.9370266170212767, 0.7845899999999999, 0.2861484574468084], 
             UndirectedEdge[17, 323] -> 
             RGBColor[
              0.9428741808510638, 0.802193829787234, 0.5139960638297872], 
             UndirectedEdge[315, 397] -> 
             RGBColor[
              0.9791798617021277, 0.9803795319148936, 0.6970994574468083], 
             UndirectedEdge[43, 296] -> 
             RGBColor[
              0.959227329787234, 0.8798919361702127, 0.5765028510638297], 
             UndirectedEdge[50, 287] -> 
             RGBColor[
              0.985945585106383, 0.9768546808510639, 0.6446972872340424], 
             UndirectedEdge[253, 369] -> 
             RGBColor[
              0.9422149680851064, 0.8249207021276597, 0.5828452340425532], 
             UndirectedEdge[187, 220] -> 
             RGBColor[
              0.9676247021276596, 0.902452659574468, 0.3287285106382978], 
             UndirectedEdge[211, 340] -> 
             RGBColor[
              0.994513340425532, 0.9906729148936171, 0.6441891489361701], 
             UndirectedEdge[213, 227] -> 
             RGBColor[
              0.9495765851063829, 0.9131974893617021, 0.638741074468085], 
             UndirectedEdge[17, 389] -> 
             RGBColor[
              0.9070576808510638, 0.6664134042553189, 0.24392936170212765`], 
             UndirectedEdge[117, 376] -> 
             RGBColor[
              0.9801821063829788, 0.9446657659574467, 0.38992361702127626`], 
             UndirectedEdge[186, 330] -> 
             RGBColor[
              0.9805368723404255, 0.945424574468085, 0.4285377021276593], 
             UndirectedEdge[24, 337] -> 
             RGBColor[
              0.9496475638297872, 0.8942418936170211, 0.6197459999999999], 
             UndirectedEdge[73, 99] -> 
             RGBColor[
              0.9615050851063829, 0.8788801276595744, 0.3202124999999999], 
             UndirectedEdge[114, 155] -> 
             RGBColor[
              0.9228298829787234, 0.9280501489361701, 0.6938317021276595], 
             UndirectedEdge[123, 232] -> 
             RGBColor[
              0.9023815531914894, 0.5743404255319147, 0.26961729787234034`], 
             UndirectedEdge[53, 289] -> 
             RGBColor[
              0.9562835319148937, 0.9648260425531915, 0.8697451595744681], 
             UndirectedEdge[126, 376] -> 
             RGBColor[
              0.9891736276595744, 0.9875976595744682, 0.6696495851063827], 
             UndirectedEdge[207, 254] -> 
             RGBColor[
              0.9832203191489362, 0.9863007021276596, 0.8816887021276594], 
             UndirectedEdge[291, 304] -> 
             RGBColor[
              0.9549004893617021, 0.8526951063829786, 0.31489828723404245`], 
             UndirectedEdge[333, 368] -> 
             RGBColor[
              0.9934490425531914, 0.9883964893617021, 0.528346893617021], 
             UndirectedEdge[26, 171] -> 
             RGBColor[
              0.9430447765957446, 0.9201378085106382, 0.6604068510638297], 
             UndirectedEdge[81, 384] -> 
             RGBColor[
              0.9414584361702127, 0.8016083829787233, 0.5374586170212765], 
             UndirectedEdge[120, 233] -> 
             RGBColor[
              0.9937756276595745, 0.9901128085106383, 0.6378760106382977], 
             UndirectedEdge[224, 290] -> 
             RGBColor[
              0.9812464042553191, 0.9469421914893617, 0.5057658723404252], 
             UndirectedEdge[393, 396] -> 
             RGBColor[
              0.9826966489361701, 0.9617050638297873, 0.603113329787234], 
             UndirectedEdge[2, 365] -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425531], 
             UndirectedEdge[210, 387] -> 
             RGBColor[
              0.8488377127659574, 0.593048255319149, 0.585378914893617], 
             UndirectedEdge[23, 307] -> 
             RGBColor[
              0.9937756276595745, 0.9901128085106383, 0.6378760106382977], 
             UndirectedEdge[120, 244] -> 
             RGBColor[
              0.9758721914893618, 0.9296895106382979, 0.41041629787234024`], 
             UndirectedEdge[42, 248] -> 
             RGBColor[
              0.9632327872340425, 0.9718644468085107, 0.9365884468085106], 
             UndirectedEdge[49, 393] -> 
             RGBColor[
              0.9186141808510638, 0.6827537659574467, 0.5178045851063828], 
             UndirectedEdge[375, 377] -> 
             RGBColor[
              0.970079159574468, 0.9078332978723402, 0.511429404255319], 
             UndirectedEdge[269, 350] -> 
             RGBColor[
              0.9855563191489362, 0.9619184468085107, 0.48527319148936165`], 
             UndirectedEdge[77, 207] -> 
             RGBColor[
              0.981804574468085, 0.985715255319149, 0.9051512553191488], 
             UndirectedEdge[200, 368] -> 
             RGBColor[
              0.9729892659574468, 0.9757625957446809, 0.7075785212765956], 
             UndirectedEdge[384, 389] -> 
             RGBColor[
              0.9070576808510638, 0.6664134042553189, 0.24392936170212765`], 
             UndirectedEdge[1, 361] -> 
             RGBColor[
              0.9264144893617021, 0.7213777234042552, 0.36636120212765944`], 
             UndirectedEdge[150, 380] -> 
             RGBColor[
              0.9019630425531915, 0.6394749361702127, 0.2394814468085106], 
             UndirectedEdge[150, 381] -> 
             RGBColor[
              0.9329736382978724, 0.7494570851063831, 0.44847043617021265`], 
             UndirectedEdge[232, 279] -> 
             RGBColor[
              0.9416912978723404, 0.8003250638297873, 0.30426986170212766`], 
             UndirectedEdge[132, 341] -> 
             RGBColor[
              0.970079159574468, 0.9078332978723402, 0.511429404255319], 
             UndirectedEdge[1, 14] -> 
             RGBColor[
              0.8829042340425532, 0.5605431489361701, 0.2239719574468085], 
             UndirectedEdge[171, 342] -> 
             RGBColor[
              0.9808634574468085, 0.9471408936170211, 0.538066819148936], 
             UndirectedEdge[140, 325] -> 
             RGBColor[
              0.9561886170212766, 0.8529881276595744, 0.3526577765957445], 
             UndirectedEdge[89, 306] -> 
             RGBColor[
              0.9926864680851064, 0.9912436808510638, 0.7708676808510637], 
             UndirectedEdge[130, 147] -> 
             RGBColor[
              0.9629600212765956, 0.8867175957446807, 0.3106071063829785], 
             UndirectedEdge[4, 183] -> 
             RGBColor[0.9780319680851064, 0.94597, 0.5849919255319147], 
             UndirectedEdge[80, 151] -> 
             RGBColor[
              0.9526227340425532, 0.8537069148936169, 0.5711886382978723], 
             UndirectedEdge[236, 286] -> 
             RGBColor[
              0.9902379255319149, 0.989874085106383, 0.7854918404255318], 
             UndirectedEdge[108, 180] -> 
             RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 
             UndirectedEdge[9, 320] -> 
             RGBColor[
              0.9733440319148936, 0.9765214042553192, 0.7461926063829787], 
             UndirectedEdge[35, 97] -> 
             RGBColor[
              0.9428741808510638, 0.802193829787234, 0.5139960638297872], 
             UndirectedEdge[154, 236] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255319], 
             UndirectedEdge[60, 259] -> 
             RGBColor[
              0.9808634574468085, 0.9471408936170211, 0.538066819148936], 
             UndirectedEdge[179, 399] -> 
             RGBColor[
              0.9934490425531914, 0.9883964893617021, 0.528346893617021], 
             UndirectedEdge[314, 352] -> 
             RGBColor[
              0.9549004893617021, 0.8526951063829786, 0.31489828723404245`], 
             UndirectedEdge[85, 88] -> 
             RGBColor[
              0.9502358085106382, 0.8369600425531912, 0.2967768829787232], 
             UndirectedEdge[70, 267] -> 
             RGBColor[0.990221, 0.9776535106382979, 0.5033945957446808], 
             UndirectedEdge[31, 192] -> 
             RGBColor[
              0.9926864680851064, 0.9912436808510638, 0.7708676808510637], 
             UndirectedEdge[221, 255] -> 
             RGBColor[
              0.9905893723404255, 0.9881831063829788, 0.6461870319148934], 
             UndirectedEdge[11, 211] -> 
             RGBColor[
              0.9902379255319149, 0.989874085106383, 0.7854918404255318], 
             UndirectedEdge[211, 312] -> 
             RGBColor[
              0.993069414893617, 0.9910449787234042, 0.738566734042553], 
             UndirectedEdge[123, 280] -> 
             RGBColor[
              0.8583648191489361, 0.5645116170212765, 0.581765255319149], 
             UndirectedEdge[178, 278] -> 
             RGBColor[
              0.9901928191489362, 0.9786110212765957, 0.5743096276595744], 
             UndirectedEdge[83, 364] -> 
             RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             UndirectedEdge[10, 313] -> 
             RGBColor[
              0.9568404042553191, 0.8631450638297871, 0.3020910957446806], 
             UndirectedEdge[32, 242] -> 
             RGBColor[
              0.9502358085106382, 0.8369600425531912, 0.2967768829787232], 
             UndirectedEdge[44, 369] -> 
             RGBColor[
              0.986079989361702, 0.9865140851063829, 0.7638485638297872], 
             UndirectedEdge[110, 375] -> 
             RGBColor[
              0.9568404042553191, 0.8631450638297871, 0.3020910957446806], 
             UndirectedEdge[275, 290] -> 
             RGBColor[
              0.9542412659574467, 0.9289325531914892, 0.6568624787234041], 
             UndirectedEdge[362, 369] -> 
             RGBColor[
              0.9864347553191489, 0.9872728936170213, 0.80246264893617], 
             UndirectedEdge[266, 338] -> 
             RGBColor[
              0.9430447765957446, 0.9201378085106382, 0.6604068510638297], 
             UndirectedEdge[350, 395] -> 
             RGBColor[
              0.9841123936170213, 0.9622905106382978, 0.5796507765957446], 
             UndirectedEdge[141, 172] -> 
             RGBColor[
              0.9769540638297872, 0.9339227872340424, 0.364971319148936], 
             UndirectedEdge[123, 275] -> 
             RGBColor[
              0.8843334361702127, 0.5850852553191488, 0.5796298617021276], 
             UndirectedEdge[46, 315] -> 
             RGBColor[
              0.9905893723404255, 0.9881831063829788, 0.6461870319148934], 
             UndirectedEdge[185, 205] -> 
             RGBColor[
              0.8887538510638298, 0.5871048936170213, 0.2288530212765958], 
             UndirectedEdge[3, 86] -> 
             RGBColor[
              0.9736706170212766, 0.9782377234042553, 0.8557217234042553], 
             UndirectedEdge[316, 397] -> 
             RGBColor[
              0.9666224574468085, 0.9381664255319148, 0.6359043510638296], 
             UndirectedEdge[11, 214] -> 
             RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 
             UndirectedEdge[3, 34] -> 
             RGBColor[
              0.9656202127659574, 0.9738801914893618, 0.9430801914893616], 
             UndirectedEdge[5, 100] -> 
             RGBColor[
              0.9948681063829787, 0.9914317234042553, 0.6828032340425529], 
             UndirectedEdge[25, 245] -> 
             RGBColor[
              0.9119953297872341, 0.9285318510638298, 0.7946031914893616], 
             UndirectedEdge[183, 325] -> 
             RGBColor[
              0.9801821063829788, 0.9446657659574467, 0.38992361702127626`], 
             UndirectedEdge[149, 266] -> 
             RGBColor[
              0.9766162234042552, 0.9453845531914893, 0.6084544787234041], 
             UndirectedEdge[73, 78] -> 
             RGBColor[
              0.9568404042553191, 0.8631450638297871, 0.3020910957446806], 
             UndirectedEdge[40, 167] -> 
             RGBColor[
              0.9733672872340425, 0.9302349361702127, 0.5668705212765957], 
             UndirectedEdge[5, 175] -> 
             RGBColor[
              0.985911085106383, 0.9626772553191489, 0.5238872765957445], 
             UndirectedEdge[279, 309] -> 
             RGBColor[
              0.9360243723404256, 0.8203037659574468, 0.5933242978723404], 
             UndirectedEdge[66, 257] -> 
             RGBColor[
              0.9891736276595744, 0.9875976595744682, 0.6696495851063827], 
             UndirectedEdge[238, 309] -> 
             RGBColor[
              0.8323340212765958, 0.8693504680851065, 0.9568592021276595], 
             UndirectedEdge[40, 355] -> 
             RGBColor[
              0.991653670212766, 0.9904595319148937, 0.7620292872340424], 
             UndirectedEdge[31, 271] -> 
             RGBColor[
              0.9794477127659573, 0.9465554468085104, 0.5615293723404253], 
             UndirectedEdge[271, 391] -> 
             RGBColor[
              0.9812464042553191, 0.9469421914893617, 0.5057658723404252], 
             UndirectedEdge[264, 348] -> 
             RGBColor[
              0.9422149680851064, 0.8249207021276597, 0.5828452340425532], 
             UndirectedEdge[146, 302] -> 
             RGBColor[
              0.9901928191489362, 0.9786110212765957, 0.5743096276595744], 
             UndirectedEdge[86, 91] -> 
             RGBColor[
              0.9798612127659574, 0.982854659574468, 0.845242659574468], 
             UndirectedEdge[232, 257] -> 
             RGBColor[
              0.9812809042553191, 0.9611196170212766, 0.6265758829787234], 
             UndirectedEdge[201, 385] -> 
             RGBColor[
              0.9774777340425531, 0.9585184255319149, 0.6435466914893616], 
             UndirectedEdge[204, 297] -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425531], 
             UndirectedEdge[241, 323] -> 
             RGBColor[
              0.9927146489361702, 0.9902861702127659, 0.6999526489361703], 
             UndirectedEdge[269, 395] -> 
             RGBColor[
              0.9927146489361702, 0.9902861702127659, 0.6999526489361703], 
             UndirectedEdge[52, 342] -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425531], 
             UndirectedEdge[201, 245] -> 
             RGBColor[
              0.9033930744680851, 0.9005361914893617, 0.6743013191489362], 
             UndirectedEdge[131, 330] -> 
             RGBColor[
              0.9934490425531916, 0.9883964893617022, 0.528346893617021], 
             UndirectedEdge[159, 349] -> 
             RGBColor[
              0.9632327872340425, 0.9718644468085107, 0.9365884468085106], 
             UndirectedEdge[15, 33] -> 
             RGBColor[
              0.9568404042553191, 0.8631450638297871, 0.3020910957446806], 
             UndirectedEdge[16, 212] -> 
             RGBColor[
              0.8919542659574469, 0.9127960212765958, 0.7926268085106383], 
             UndirectedEdge[246, 269] -> 
             RGBColor[
              0.9736987978723404, 0.9772802127659574, 0.7848066914893617], 
             UndirectedEdge[150, 294] -> 
             RGBColor[
              0.9245402872340425, 0.745298255319149, 0.5681298510638297], 
             UndirectedEdge[77, 200] -> 
             RGBColor[
              0.9694233829787233, 0.9764813829787234, 0.9261093829787234], 
             UndirectedEdge[21, 285] -> 
             RGBColor[
              0.9264144893617021, 0.7213777234042552, 0.36636120212765944`], 
             UndirectedEdge[275, 280] -> 
             RGBColor[
              0.9148892127659574, 0.9348388085106383, 0.987131840425532], 
             UndirectedEdge[171, 353] -> 
             RGBColor[
              0.9766162234042552, 0.9453845531914893, 0.6084544787234041], 
             UndirectedEdge[197, 252] -> 
             RGBColor[
              0.9873613297872341, 0.9774401276595746, 0.621234734042553], 
             UndirectedEdge[15, 361] -> 
             RGBColor[
              0.969752574468085, 0.9061169787234042, 0.40190028723404236`], 
             UndirectedEdge[348, 366] -> 
             RGBColor[
              0.9416912978723404, 0.8003250638297873, 0.30426986170212766`], 
             UndirectedEdge[235, 298] -> 
             RGBColor[
              0.9944851595744681, 0.9916304255319148, 0.7151041808510636], 
             UndirectedEdge[62, 298] -> 
             RGBColor[
              0.985911085106383, 0.9626772553191489, 0.5238872765957445], 
             UndirectedEdge[110, 308] -> 
             RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.9740535638297871, 0.9780390212765957, 0.8234207765957446], 
             UndirectedEdge[204, 290] -> 
             RGBColor[0.9780319680851064, 0.94597, 0.5849919255319147], 
             UndirectedEdge[35, 93] -> 
             RGBColor[
              0.9446728723404255, 0.802580574468085, 0.45823256382978705`], 
             UndirectedEdge[162, 211] -> 
             RGBColor[
              0.9812464042553191, 0.9469421914893617, 0.5057658723404252], 
             UndirectedEdge[66, 275] -> 
             RGBColor[
              0.966798670212766, 0.9711456595744681, 0.7180575851063828], 
             UndirectedEdge[36, 277] -> 
             RGBColor[
              0.9658319255319148, 0.9060769574468084, 0.5818170638297872], 
             UndirectedEdge[174, 246] -> 
             RGBColor[
              0.9736706170212766, 0.9782377234042553, 0.8557217234042553], 
             UndirectedEdge[218, 329] -> 
             RGBColor[
              0.938679914893617, 0.951876255319149, 0.9152612872340424], 
             UndirectedEdge[186, 188] -> 
             RGBColor[
              0.9542412659574467, 0.9289325531914892, 0.6568624787234041], 
             UndirectedEdge[230, 245] -> 
             RGBColor[
              0.8504556276595745, 0.6873160212765959, 0.5988844787234042], 
             UndirectedEdge[57, 368] -> 
             RGBColor[
              0.9920051170212766, 0.9887685531914894, 0.6227244787234041], 
             UndirectedEdge[293, 316] -> 
             RGBColor[
              0.9728130531914894, 0.9427833617021275, 0.6254252872340423], 
             UndirectedEdge[8, 308] -> 
             RGBColor[
              0.9629600212765956, 0.8867175957446807, 0.3106071063829785], 
             UndirectedEdge[37, 361] -> 
             RGBColor[
              0.9930942765957447, 0.9876376808510638, 0.489732808510638], 
             UndirectedEdge[19, 331] -> 
             RGBColor[
              0.9492335638297872, 0.8726738085106381, 0.6039527234042552], 
             UndirectedEdge[98, 276] -> 
             RGBColor[
              0.9124982765957447, 0.9322937872340424, 0.9647647340425531], 
             UndirectedEdge[326, 336] -> 
             RGBColor[
              0.9926864680851064, 0.9912436808510638, 0.7708676808510637], 
             UndirectedEdge[4, 13] -> 
             RGBColor[0.9780319680851064, 0.94597, 0.5849919255319147], 
             UndirectedEdge[137, 300] -> 
             RGBColor[
              0.9604318617021276, 0.933549489361702, 0.646383414893617], 
             UndirectedEdge[57, 163] -> 
             RGBColor[
              0.9926864680851064, 0.9912436808510638, 0.7708676808510637], 
             UndirectedEdge[28, 304] -> 
             RGBColor[
              0.9502358085106382, 0.8369600425531912, 0.2967768829787232], 
             UndirectedEdge[83, 328] -> 
             RGBColor[
              0.9629600212765956, 0.8867175957446807, 0.3106071063829785], 
             UndirectedEdge[206, 321] -> 
             RGBColor[
              0.9264144893617021, 0.7213777234042552, 0.36636120212765944`], 
             UndirectedEdge[295, 373] -> 
             RGBColor[
              0.9124466914893617, 0.8022751489361704, 0.6178267978723404], 
             UndirectedEdge[29, 235] -> 
             RGBColor[
              0.9934208617021276, 0.9893540000000001, 0.5992619255319147], 
             UndirectedEdge[234, 392] -> 
             RGBColor[
              0.559892414893617, 0.6304032234042553, 0.9592487234042554], 
             UndirectedEdge[42, 275] -> 
             RGBColor[
              0.940857829787234, 0.9554124468085106, 0.9849964468085107], 
             UndirectedEdge[107, 324] -> 
             RGBColor[
              0.9364383723404255, 0.8418718510638297, 0.6091175744680851], 
             UndirectedEdge[75, 329] -> 
             RGBColor[
              0.991653670212766, 0.9904595319148937, 0.7620292872340424], 
             UndirectedEdge[267, 383] -> 
             RGBColor[0.990221, 0.9776535106382979, 0.5033945957446808], 
             UndirectedEdge[253, 362] -> 
             RGBColor[
              0.9506483191489362, 0.8290795319148937, 0.4631858191489361], 
             UndirectedEdge[137, 252] -> 
             RGBColor[
              0.9697612234042553, 0.9650196170212766, 0.6826262234042553], 
             UndirectedEdge[131, 203] -> 
             RGBColor[
              0.9439633404255319, 0.8010629574468084, 0.38100439361702115`], 
             UndirectedEdge[52, 199] -> 
             RGBColor[
              0.9912989042553191, 0.9897007234042554, 0.7234152021276594], 
             UndirectedEdge[41, 386] -> 
             RGBColor[
              0.9801821063829788, 0.9446657659574467, 0.38992361702127626`], 
             UndirectedEdge[59, 122] -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 
             UndirectedEdge[32, 172] -> 
             RGBColor[
              0.9595651702127659, 0.8684301702127658, 0.3330196914893616], 
             UndirectedEdge[55, 156] -> 
             RGBColor[
              0.9920051170212766, 0.9887685531914894, 0.6227244787234041], 
             UndirectedEdge[97, 214] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255319], 
             UndirectedEdge[133, 155] -> 
             RGBColor[
              0.9239077872340425, 0.9400973617021277, 0.9138523085106383], 
             UndirectedEdge[186, 273] -> 
             RGBColor[
              0.9436312127659574, 0.8107750212765956, 0.2914626702127658], 
             UndirectedEdge[74, 179] -> 
             RGBColor[
              0.9930942765957447, 0.9876376808510638, 0.489732808510638], 
             UndirectedEdge[10, 62] -> 
             RGBColor[
              0.9722893829787234, 0.9181877234042553, 0.34684991489361683`], 
             UndirectedEdge[273, 322] -> 
             RGBColor[
              0.9565433829787234, 0.8537469361702128, 0.3912718617021275], 
             UndirectedEdge[18, 148] -> 
             RGBColor[
              0.9495765851063829, 0.9131974893617021, 0.638741074468085], 
             UndirectedEdge[78, 172] -> 
             RGBColor[
              0.9769540638297872, 0.9339227872340424, 0.364971319148936], 
             UndirectedEdge[84, 269] -> 
             RGBColor[
              0.989883159574468, 0.9891152765957447, 0.7468777553191488], 
             UndirectedEdge[103, 254] -> 
             RGBColor[
              0.9474338829787234, 0.828107340425532, 0.5424118723404254], 
             UndirectedEdge[46, 343] -> 
             RGBColor[
              0.9826966489361701, 0.9617050638297873, 0.603113329787234], 
             UndirectedEdge[1, 317] -> 
             RGBColor[
              0.8961134255319148, 0.6129131914893614, 0.23460038297872332`], 
             UndirectedEdge[27, 399] -> 
             RGBColor[
              0.9927146489361702, 0.9902861702127659, 0.6999526489361703], 
             UndirectedEdge[247, 253] -> 
             RGBColor[
              0.9460181382978723, 0.8275218936170214, 0.5658744255319148], 
             UndirectedEdge[27, 357] -> 
             RGBColor[
              0.9428741808510638, 0.802193829787234, 0.5139960638297872], 
             UndirectedEdge[41, 55] -> 
             RGBColor[
              0.9920051170212766, 0.9887685531914894, 0.6227244787234041], 
             UndirectedEdge[183, 272] -> 
             RGBColor[0.9780319680851064, 0.94597, 0.5849919255319147], 
             UndirectedEdge[131, 238] -> 
             RGBColor[
              0.846248436170213, 0.8766086170212768, 0.7494925531914892], 
             UndirectedEdge[13, 131] -> 
             RGBColor[
              0.9805368723404255, 0.945424574468085, 0.4285377021276593], 
             UndirectedEdge[55, 328] -> 
             RGBColor[
              0.9747830319148936, 0.9308203829787234, 0.5434079680851063], 
             UndirectedEdge[40, 392] -> 
             RGBColor[
              0.5836831170212766, 0.647440670212766, 0.8873781702127659], 
             UndirectedEdge[39, 347] -> 
             RGBColor[
              0.9758721914893618, 0.9296895106382979, 0.41041629787234024`], 
             UndirectedEdge[195, 362] -> 
             RGBColor[
              0.9948681063829787, 0.9914317234042553, 0.6828032340425529], 
             UndirectedEdge[46, 250] -> 
             RGBColor[0.9780319680851064, 0.94597, 0.5849919255319147], 
             UndirectedEdge[22, 47] -> 
             RGBColor[
              0.9898662340425533, 0.9768947021276596, 0.46478051063829773`], 
             UndirectedEdge[79, 100] -> 
             RGBColor[
              0.9905757659574468, 0.9784123191489362, 0.5420086808510637], 
             UndirectedEdge[45, 148] -> 
             RGBColor[
              0.9678629680851063, 0.973422085106383, 0.8338998404255318], 
             UndirectedEdge[65, 68] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255319], 
             UndirectedEdge[86, 162] -> 
             RGBColor[
              0.9808634574468085, 0.9471408936170211, 0.538066819148936], 
             UndirectedEdge[3, 264] -> 
             RGBColor[
              0.9656202127659574, 0.9738801914893618, 0.9430801914893616], 
             UndirectedEdge[55, 386] -> 
             RGBColor[
              0.9794477127659573, 0.9465554468085104, 0.5615293723404253], 
             UndirectedEdge[315, 362] -> 
             RGBColor[
              0.9938038085106383, 0.9891552978723405, 0.566960978723404], 
             UndirectedEdge[92, 182] -> 
             RGBColor[
              0.9070576808510638, 0.6664134042553189, 0.24392936170212765`], 
             UndirectedEdge[202, 341] -> 
             RGBColor[
              0.9568404042553191, 0.8631450638297871, 0.3020910957446806], 
             UndirectedEdge[86, 125] -> 
             RGBColor[
              0.9674800212765957, 0.9736207872340426, 0.8662007872340425], 
             UndirectedEdge[155, 353] -> 
             RGBColor[
              0.9224920425531915, 0.9395119148936171, 0.9373148617021276], 
             UndirectedEdge[119, 235] -> 
             RGBColor[
              0.9944851595744681, 0.9916304255319148, 0.7151041808510636], 
             UndirectedEdge[139, 204] -> 
             RGBColor[
              0.9091356595744682, 0.9283184680851064, 0.912443329787234], 
             UndirectedEdge[167, 174] -> 
             RGBColor[
              0.9761987765957447, 0.931405829787234, 0.5199454148936169], 
             UndirectedEdge[218, 349] -> 
             RGBColor[
              0.9148892127659574, 0.9348388085106383, 0.987131840425532], 
             UndirectedEdge[362, 397] -> 
             RGBColor[
              0.9802441595744681, 0.9826559574468086, 0.8129417127659573], 
             UndirectedEdge[70, 108] -> 
             RGBColor[
              0.985945585106383, 0.9768546808510639, 0.6446972872340424], 
             UndirectedEdge[71, 157] -> 
             RGBColor[
              0.9722893829787234, 0.9181877234042553, 0.34684991489361694`], 
             UndirectedEdge[186, 238] -> 
             RGBColor[
              0.8333362659574468, 0.8336367021276596, 0.6496833617021275], 
             UndirectedEdge[51, 246] -> 
             RGBColor[
              0.9430429680851062, 0.8680568723404254, 0.6144317872340426], 
             UndirectedEdge[109, 305] -> 
             RGBColor[
              0.970079159574468, 0.9078332978723402, 0.511429404255319], 
             UndirectedEdge[125, 248] -> 
             RGBColor[
              0.9632327872340425, 0.9718644468085107, 0.9365884468085106], 
             UndirectedEdge[106, 390] -> 
             RGBColor[
              0.9329736382978724, 0.7494570851063831, 0.44847043617021265`], 
             UndirectedEdge[1, 231] -> 
             RGBColor[
              0.9001188829787233, 0.7048857021276593, 0.5946859787234042], 
             UndirectedEdge[104, 399] -> 
             RGBColor[
              0.986079989361702, 0.9865140851063829, 0.7638485638297872], 
             UndirectedEdge[244, 366] -> 
             RGBColor[
              0.9676247021276596, 0.902452659574468, 0.3287285106382978], 
             UndirectedEdge[64, 289] -> 
             RGBColor[
              0.9562835319148937, 0.9648260425531915, 0.8697451595744681], 
             UndirectedEdge[160, 233] -> 
             RGBColor[
              0.9798612127659574, 0.982854659574468, 0.845242659574468], 
             UndirectedEdge[100, 302] -> 
             RGBColor[
              0.9944851595744681, 0.9916304255319148, 0.7151041808510636], 
             UndirectedEdge[177, 337] -> 
             RGBColor[
              0.9733440319148936, 0.9765214042553192, 0.7461926063829787], 
             UndirectedEdge[124, 219] -> 
             RGBColor[
              0.9027180212765957, 0.6390982127659572, 0.23991459574468077`], 
             UndirectedEdge[2, 181] -> 
             RGBColor[
              0.9941303936170213, 0.9908716170212766, 0.6764900957446808], 
             UndirectedEdge[185, 198] -> 
             RGBColor[
              0.9311749468085107, 0.7490703404255319, 0.5042339361702128], 
             UndirectedEdge[11, 35] -> 
             RGBColor[
              0.9400426914893616, 0.8010229361702127, 0.5609211702127659], 
             UndirectedEdge[5, 56] -> 
             RGBColor[
              0.9704621063829787, 0.9076345957446807, 0.4791284574468083], 
             UndirectedEdge[69, 107] -> 
             RGBColor[
              0.9554542234042553, 0.8548778085106382, 0.5242635319148936], 
             UndirectedEdge[51, 350] -> 
             RGBColor[
              0.9549004893617021, 0.8526951063829786, 0.31489828723404245`], 
             UndirectedEdge[226, 392] -> 
             RGBColor[
              0.5822673723404255, 0.6468552234042554, 0.9108407234042553], 
             UndirectedEdge[81, 292] -> 
             RGBColor[
              0.9239077872340425, 0.9400973617021277, 0.9138523085106383], 
             UndirectedEdge[51, 272] -> 
             RGBColor[
              0.9606430744680851, 0.8804773829787234, 0.5530402978723403], 
             UndirectedEdge[10, 261] -> 
             RGBColor[
              0.9805368723404255, 0.945424574468085, 0.4285377021276593], 
             UndirectedEdge[132, 244] -> 
             RGBColor[
              0.9761987765957447, 0.931405829787234, 0.5199454148936169], 
             UndirectedEdge[53, 376] -> 
             RGBColor[
              0.9934208617021276, 0.9893540000000001, 0.5992619255319147], 
             UndirectedEdge[242, 364] -> 
             RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             UndirectedEdge[29, 327] -> 
             RGBColor[
              0.9791798617021277, 0.9803795319148936, 0.6970994574468083], 
             UndirectedEdge[328, 364] -> 
             RGBColor[
              0.9629600212765956, 0.8867175957446807, 0.3106071063829785], 
             UndirectedEdge[257, 279] -> 
             RGBColor[
              0.9460181382978723, 0.8275218936170214, 0.5658744255319148], 
             UndirectedEdge[13, 322] -> 
             RGBColor[
              0.9805368723404255, 0.945424574468085, 0.4285377021276593], 
             UndirectedEdge[21, 24] -> 
             RGBColor[
              0.969752574468085, 0.9061169787234042, 0.40190028723404236`], 
             UndirectedEdge[56, 122] -> 
             RGBColor[
              0.968663414893617, 0.9072478510638297, 0.5348919574468085], 
             UndirectedEdge[87, 393] -> 
             RGBColor[
              0.9414584361702127, 0.8016083829787233, 0.5374586170212765], 
             UndirectedEdge[27, 74] -> 
             RGBColor[
              0.9923598829787235, 0.9895273617021276, 0.6613385638297871], 
             UndirectedEdge[93, 288] -> 
             RGBColor[
              0.9944851595744681, 0.9916304255319148, 0.7151041808510636], 
             UndirectedEdge[125, 211] -> 
             RGBColor[
              0.9678629680851063, 0.973422085106383, 0.8338998404255318], 
             UndirectedEdge[265, 304] -> 
             RGBColor[
              0.9631479787234043, 0.8799319574468084, 0.3965860744680849], 
             UndirectedEdge[195, 343] -> 
             RGBColor[
              0.985911085106383, 0.9626772553191489, 0.5238872765957445], 
             UndirectedEdge[199, 393] -> 
             RGBColor[
              0.9912989042553191, 0.9897007234042554, 0.7234152021276594], 
             UndirectedEdge[24, 208] -> 
             RGBColor[
              0.9704621063829787, 0.9076345957446807, 0.4791284574468083], 
             UndirectedEdge[135, 386] -> 
             RGBColor[
              0.9808634574468085, 0.9471408936170211, 0.538066819148936], 
             UndirectedEdge[32, 357] -> 
             RGBColor[
              0.9136622765957446, 0.6925984255319146, 0.24924357446808504`], 
             UndirectedEdge[230, 233] -> 
             RGBColor[
              0.9325906914893617, 0.7496557872340426, 0.48077138297872335`], 
             UndirectedEdge[46, 161] -> 
             RGBColor[
              0.9832203191489362, 0.9863007021276596, 0.8816887021276594], 
             UndirectedEdge[114, 306] -> 
             RGBColor[
              0.988777074468085, 0.978025574468085, 0.5977721808510639], 
             UndirectedEdge[233, 357] -> 
             RGBColor[
              0.9442899255319148, 0.8027792765957446, 0.4905335106382978], 
             UndirectedEdge[134, 395] -> 
             RGBColor[
              0.9620588191489361, 0.8810628297872338, 0.529577744680851], 
             UndirectedEdge[108, 267] -> 
             RGBColor[
              0.989883159574468, 0.9891152765957447, 0.7468777553191488], 
             UndirectedEdge[217, 233] -> 
             RGBColor[
              0.9634745638297872, 0.8816482765957445, 0.5061151914893616], 
             UndirectedEdge[245, 400] -> 
             RGBColor[
              0.8747349042553192, 0.7931234893617021, 0.6189140744680851], 
             UndirectedEdge[269, 392] -> 
             RGBColor[
              0.5865427872340425, 0.6476540531914894, 0.7695380319148937], 
             UndirectedEdge[232, 288] -> 
             RGBColor[
              0.9855281382978723, 0.9628759574468084, 0.5561882234042552], 
             UndirectedEdge[260, 341] -> 
             RGBColor[
              0.9434569680851064, 0.8896249574468084, 0.6302250638297873], 
             UndirectedEdge[47, 323] -> 
             RGBColor[
              0.988777074468085, 0.978025574468085, 0.5977721808510639], 
             UndirectedEdge[142, 377] -> 
             RGBColor[
              0.9761987765957447, 0.931405829787234, 0.5199454148936169], 
             UndirectedEdge[53, 117] -> 
             RGBColor[
              0.9808634574468085, 0.9471408936170211, 0.538066819148936], 
             UndirectedEdge[251, 308] -> 
             RGBColor[
              0.9430447765957446, 0.9201378085106382, 0.6604068510638297], 
             UndirectedEdge[85, 162] -> 
             RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             UndirectedEdge[249, 397] -> 
             RGBColor[
              0.9791798617021277, 0.9803795319148936, 0.6970994574468083], 
             UndirectedEdge[262, 284] -> 
             RGBColor[
              0.9755174255319149, 0.9289307021276596, 0.3718022127659572], 
             UndirectedEdge[307, 341] -> 
             RGBColor[
              0.969752574468085, 0.9061169787234042, 0.40190028723404236`], 
             UndirectedEdge[7, 387] -> 
             RGBColor[
              0.9088358404255319, 0.8808449574468085, 0.6394674893617021], 
             UndirectedEdge[228, 368] -> 
             RGBColor[
              0.9895114680851065, 0.9761358936170212, 0.4261664255319147], 
             UndirectedEdge[240, 399] -> 
             RGBColor[
              0.9855563191489362, 0.9619184468085107, 0.48527319148936165`], 
             UndirectedEdge[105, 114] -> 
             RGBColor[
              0.9905757659574468, 0.9784123191489362, 0.5420086808510637], 
             UndirectedEdge[78, 357] -> 
             RGBColor[
              0.931051170212766, 0.7580910425531913, 0.2811952021276594], 
             UndirectedEdge[359, 369] -> 
             RGBColor[
              0.9245402872340425, 0.745298255319149, 0.5681298510638297], 
             UndirectedEdge[48, 354] -> 
             RGBColor[
              0.9853704574468085, 0.9849964680851064, 0.686620393617021], 
             UndirectedEdge[280, 325] -> 
             RGBColor[
              0.9408300531914894, 0.9505720212765958, 0.720192978723404], 
             UndirectedEdge[259, 262] -> 
             RGBColor[
              0.9934208617021276, 0.9893540000000001, 0.5992619255319147], 
             UndirectedEdge[120, 187] -> 
             RGBColor[
              0.9852015531914894, 0.9611596382978724, 0.44665910638297857`], 
             UndirectedEdge[70, 198] -> 
             RGBColor[
              0.988777074468085, 0.978025574468085, 0.5977721808510639], 
             UndirectedEdge[62, 235] -> 
             RGBColor[
              0.9855281382978723, 0.9628759574468084, 0.5561882234042552], 
             UndirectedEdge[65, 176] -> 
             RGBColor[
              0.9895283936170213, 0.9883564680851065, 0.7082636702127658], 
             UndirectedEdge[199, 342] -> 
             RGBColor[
              0.9941303936170213, 0.9908716170212766, 0.6764900957446808], 
             UndirectedEdge[324, 390] -> 
             RGBColor[
              0.9121590957446808, 0.7360643829787235, 0.5890879787234042], 
             UndirectedEdge[226, 234] -> 
             RGBColor[
              0.9632327872340425, 0.9718644468085107, 0.9365884468085106], 
             UndirectedEdge[47, 201] -> 
             RGBColor[
              0.9816187446808511, 0.9496578510638298, 0.38309272340425526`], 
             UndirectedEdge[160, 264] -> 
             RGBColor[
              0.9718108085106383, 0.9784971276595744, 0.9326011276595744], 
             UndirectedEdge[277, 314] -> 
             RGBColor[
              0.9394515106382978, 0.7976524468085104, 0.2701394680851063], 
             UndirectedEdge[4, 66] -> 
             RGBColor[
              0.9905893723404255, 0.9881831063829788, 0.6461870319148934], 
             UndirectedEdge[23, 75] -> 
             RGBColor[
              0.9944851595744681, 0.9916304255319148, 0.7151041808510636], 
             UndirectedEdge[287, 391] -> 
             RGBColor[
              0.9902379255319149, 0.989874085106383, 0.7854918404255318], 
             UndirectedEdge[45, 91] -> 
             RGBColor[
              0.9802441595744681, 0.9826559574468086, 0.8129417127659573], 
             UndirectedEdge[175, 314] -> 
             RGBColor[
              0.9549004893617021, 0.8526951063829786, 0.31489828723404245`], 
             UndirectedEdge[195, 358] -> 
             RGBColor[
              0.9572529148936171, 0.8552645531914893, 0.4685000319148935], 
             UndirectedEdge[321, 341] -> 
             RGBColor[
              0.9027180212765957, 0.6390982127659572, 0.23991459574468077`], 
             UndirectedEdge[91, 148] -> 
             RGBColor[
              0.9532390212765958, 0.9646463191489361, 0.9640383191489361], 
             UndirectedEdge[115, 350] -> 
             RGBColor[
              0.9848467872340425, 0.9604008297872341, 0.40804502127659553`], 
             UndirectedEdge[142, 277] -> 
             RGBColor[
              0.9521757234042553, 0.8474099999999998, 0.2839696914893616], 
             UndirectedEdge[45, 66] -> 
             RGBColor[
              0.9938038085106383, 0.9891552978723405, 0.566960978723404], 
             UndirectedEdge[259, 335] -> 
             RGBColor[
              0.9860518085106382, 0.9874715957446809, 0.8347635957446807], 
             UndirectedEdge[118, 173] -> 
             RGBColor[
              0.9747830319148936, 0.9308203829787234, 0.5434079680851063], 
             UndirectedEdge[52, 128] -> 
             RGBColor[
              0.9414584361702127, 0.8016083829787233, 0.5374586170212765], 
             UndirectedEdge[27, 225] -> 
             RGBColor[
              0.9794477127659573, 0.9465554468085104, 0.5615293723404253], 
             UndirectedEdge[302, 352] -> 
             RGBColor[
              0.9855281382978723, 0.9628759574468084, 0.5561882234042552], 
             UndirectedEdge[25, 242] -> 
             RGBColor[
              0.9808916382978723, 0.9461833829787233, 0.4671517872340424], 
             UndirectedEdge[30, 224] -> 
             RGBColor[
              0.985911085106383, 0.9626772553191489, 0.5238872765957445], 
             UndirectedEdge[313, 361] -> 
             RGBColor[
              0.969752574468085, 0.9061169787234042, 0.40190028723404236`], 
             UndirectedEdge[270, 310] -> 
             RGBColor[
              0.9554542234042553, 0.8548778085106382, 0.5242635319148936], 
             UndirectedEdge[72, 370] -> 
             RGBColor[
              0.9671534361702128, 0.9719044680851063, 0.7566716702127658], 
             UndirectedEdge[283, 380] -> 
             RGBColor[
              0.9627932127659574, 0.87917314893617, 0.35797198936170194`], 
             UndirectedEdge[34, 35] -> 
             RGBColor[
              0.9362395212765957, 0.798421744680851, 0.5778919787234043], 
             UndirectedEdge[25, 230] -> 
             RGBColor[
              0.9326188723404255, 0.7486982765957447, 0.4098563510638298], 
             UndirectedEdge[191, 211] -> 
             RGBColor[
              0.9902379255319149, 0.989874085106383, 0.7854918404255318], 
             UndirectedEdge[17, 173] -> 
             RGBColor[
              0.9428741808510638, 0.802193829787234, 0.5139960638297872], 
             UndirectedEdge[40, 51] -> 
             RGBColor[
              0.9606430744680851, 0.8804773829787234, 0.5530402978723403], 
             UndirectedEdge[105, 202] -> 
             RGBColor[
              0.9812464042553191, 0.9469421914893617, 0.5057658723404252], 
             UndirectedEdge[183, 309] -> 
             RGBColor[
              0.9666224574468085, 0.9381664255319148, 0.6359043510638296], 
             UndirectedEdge[187, 261] -> 
             RGBColor[
              0.9852015531914894, 0.9611596382978724, 0.44665910638297857`], 
             UndirectedEdge[190, 274] -> 
             RGBColor[
              0.9747830319148936, 0.9308203829787234, 0.5434079680851063], 
             UndirectedEdge[176, 354] -> 
             RGBColor[
              0.9930942765957447, 0.9876376808510638, 0.489732808510638], 
             UndirectedEdge[42, 148] -> 
             RGBColor[
              0.940857829787234, 0.9554124468085106, 0.9849964468085107], 
             UndirectedEdge[320, 380] -> 
             RGBColor[
              0.9631479787234043, 0.8799319574468084, 0.3965860744680849], 
             UndirectedEdge[51, 222] -> 
             RGBColor[
              0.9455711276595744, 0.821224978723404, 0.2786554787234041], 
             UndirectedEdge[122, 319] -> 
             RGBColor[
              0.9898549787234042, 0.9900727872340426, 0.8177927872340425], 
             UndirectedEdge[27, 78] -> 
             RGBColor[
              0.9794477127659573, 0.9465554468085104, 0.5615293723404253], 
             UndirectedEdge[5, 178] -> 
             RGBColor[
              0.9905757659574468, 0.9784123191489362, 0.5420086808510637], 
             UndirectedEdge[196, 336] -> 
             RGBColor[
              0.993069414893617, 0.9910449787234042, 0.738566734042553], 
             UndirectedEdge[297, 318] -> 
             RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 
             UndirectedEdge[127, 235] -> 
             RGBColor[
              0.9901928191489362, 0.9786110212765957, 0.5743096276595744], 
             UndirectedEdge[45, 203] -> 
             RGBColor[
              0.9446728723404255, 0.802580574468085, 0.4582325638297871], 
             UndirectedEdge[305, 370] -> 
             RGBColor[
              0.9937756276595745, 0.9901128085106383, 0.6378760106382977], 
             UndirectedEdge[122, 169] -> 
             RGBColor[
              0.9253253297872339, 0.7225085957446806, 0.4993528723404255], 
             UndirectedEdge[51, 226] -> 
             RGBColor[
              0.959227329787234, 0.8798919361702127, 0.5765028510638297], 
             UndirectedEdge[226, 395] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255319], 
             UndirectedEdge[61, 354] -> 
             RGBColor[
              0.9755174255319149, 0.9289307021276596, 0.3718022127659572], 
             UndirectedEdge[211, 334] -> 
             RGBColor[
              0.9864347553191489, 0.9872728936170213, 0.80246264893617], 
             UndirectedEdge[10, 361] -> 
             RGBColor[
              0.9805368723404255, 0.945424574468085, 0.4285377021276593], 
             UndirectedEdge[44, 249] -> 
             RGBColor[
              0.9934490425531914, 0.9883964893617021, 0.528346893617021], 
             UndirectedEdge[302, 377] -> 
             RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 
             UndirectedEdge[149, 363] -> 
             RGBColor[
              0.9283434574468085, 0.7478994468085107, 0.5511590425531914], 
             UndirectedEdge[358, 359] -> 
             RGBColor[
              0.8953584468085106, 0.6132899148936171, 0.23416723404255319`], 
             UndirectedEdge[126, 317] -> 
             RGBColor[
              0.959227329787234, 0.8798919361702127, 0.5765028510638297], 
             UndirectedEdge[194, 364] -> 
             RGBColor[
              0.9502358085106382, 0.8369600425531912, 0.2967768829787232], 
             UndirectedEdge[184, 343] -> 
             RGBColor[
              0.9855563191489362, 0.9619184468085107, 0.48527319148936165`], 
             UndirectedEdge[118, 346] -> 
             RGBColor[
              0.9722893829787234, 0.9181877234042553, 0.34684991489361694`], 
             UndirectedEdge[169, 239] -> 
             RGBColor[
              0.9027180212765957, 0.6390982127659572, 0.23991459574468077`], 
             UndirectedEdge[72, 157] -> 
             RGBColor[
              0.9495765851063829, 0.9131974893617021, 0.638741074468085], 
             UndirectedEdge[162, 191] -> 
             RGBColor[
              0.9766162234042552, 0.9453845531914893, 0.6084544787234041], 
             UndirectedEdge[84, 272] -> 
             RGBColor[
              0.987023489361702, 0.9889018936170213, 0.8647178936170211], 
             UndirectedEdge[21, 160] -> 
             RGBColor[
              0.9795346276595744, 0.9811383404255319, 0.7357135425531913], 
             UndirectedEdge[29, 336] -> 
             RGBColor[
              0.9920051170212766, 0.9887685531914894, 0.6227244787234041], 
             UndirectedEdge[275, 276] -> 
             RGBColor[
              0.9001170851063829, 0.9230599148936169, 0.9857228617021276], 
             UndirectedEdge[38, 303] -> 
             RGBColor[
              0.9400956595744681, 0.9524617021276596, 0.8917987340425533], 
             UndirectedEdge[172, 285] -> 
             RGBColor[
              0.9228316808510638, 0.7098759361702126, 0.30279481914893613`], 
             UndirectedEdge[73, 285] -> 
             RGBColor[
              0.9027180212765957, 0.6390982127659572, 0.23991459574468077`], 
             UndirectedEdge[5, 59] -> 
             RGBColor[
              0.993069414893617, 0.9910449787234042, 0.738566734042553], 
             UndirectedEdge[73, 225] -> 
             RGBColor[
              0.9568404042553191, 0.8631450638297871, 0.3020910957446806], 
             UndirectedEdge[64, 254] -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425531], 
             UndirectedEdge[241, 390] -> 
             RGBColor[
              0.9326188723404255, 0.7486982765957447, 0.4098563510638298], 
             UndirectedEdge[58, 289] -> 
             RGBColor[
              0.9556021808510639, 0.9623509148936171, 0.7216019574468083], 
             UndirectedEdge[262, 331] -> 
             RGBColor[
              0.9627932127659574, 0.87917314893617, 0.35797198936170194`], 
             UndirectedEdge[22, 118] -> 
             RGBColor[
              0.9758721914893618, 0.9296895106382979, 0.41041629787234024`], 
             UndirectedEdge[97, 360] -> 
             RGBColor[
              0.9923598829787235, 0.9895273617021276, 0.6613385638297871], 
             UndirectedEdge[301, 358] -> 
             RGBColor[
              0.9565433829787234, 0.8537469361702128, 0.3912718617021275], 
             UndirectedEdge[16, 274] -> 
             RGBColor[
              0.8740226489361702, 0.8533302340425531, 0.6360821276595744], 
             UndirectedEdge[166, 319] -> 
             RGBColor[
              0.9912989042553191, 0.9897007234042554, 0.7234152021276594], 
             UndirectedEdge[82, 101] -> 
             RGBColor[
              0.989883159574468, 0.9891152765957447, 0.7468777553191488], 
             UndirectedEdge[24, 399] -> 
             RGBColor[
              0.9701073404255318, 0.9068757872340425, 0.44051437234042545`], 
             UndirectedEdge[328, 400] -> 
             RGBColor[
              0.9389665319148937, 0.7950399574468083, 0.27334126595744673`], 
             UndirectedEdge[17, 371] -> 
             RGBColor[
              0.9428741808510638, 0.802193829787234, 0.5139960638297872], 
             UndirectedEdge[107, 158] -> 
             RGBColor[
              0.9572529148936171, 0.8552645531914893, 0.4685000319148935], 
             UndirectedEdge[60, 394] -> 
             RGBColor[
              0.9805368723404255, 0.945424574468085, 0.4285377021276593], 
             UndirectedEdge[219, 284] -> 
             RGBColor[
              0.9521757234042553, 0.8474099999999998, 0.2839696914893616], 
             UndirectedEdge[124, 149] -> 
             RGBColor[
              0.9224938404255318, 0.7213377021276595, 0.5462779787234041], 
             UndirectedEdge[227, 296] -> 
             RGBColor[
              0.9632327872340425, 0.9718644468085107, 0.9365884468085106], 
             UndirectedEdge[202, 229] -> 
             RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             UndirectedEdge[315, 358] -> 
             RGBColor[
              0.9561886170212766, 0.8529881276595744, 0.3526577765957445], 
             UndirectedEdge[145, 222] -> 
             RGBColor[
              0.9521757234042553, 0.8474099999999998, 0.2839696914893616], 
             UndirectedEdge[155, 299] -> 
             RGBColor[
              0.9088358404255319, 0.8808449574468085, 0.6394674893617021], 
             UndirectedEdge[14, 29] -> 
             RGBColor[
              0.9495840212765958, 0.8268031063829788, 0.3473435638297871], 
             UndirectedEdge[116, 151] -> 
             RGBColor[
              0.9568981489361702, 0.854505744680851, 0.4298859468085106], 
             UndirectedEdge[45, 257] -> 
             RGBColor[
              0.9902379255319149, 0.989874085106383, 0.7854918404255318], 
             UndirectedEdge[27, 240] -> 
             RGBColor[
              0.9841123936170213, 0.9622905106382978, 0.5796507765957446], 
             UndirectedEdge[144, 188] -> 
             RGBColor[
              0.9635706276595745, 0.9604026808510637, 0.6931052872340426], 
             UndirectedEdge[76, 200] -> 
             RGBColor[
              0.9298337765957447, 0.8156868297872342, 0.6038033617021277], 
             UndirectedEdge[90, 221] -> 
             RGBColor[
              0.9770297234042553, 0.9816837659574469, 0.8921677659574467], 
             UndirectedEdge[271, 382] -> 
             RGBColor[
              0.931051170212766, 0.7580910425531913, 0.2811952021276594], 
             UndirectedEdge[242, 385] -> 
             RGBColor[
              0.9728130531914894, 0.9427833617021275, 0.6254252872340423], 
             UndirectedEdge[74, 112] -> 
             RGBColor[
              0.9941585744680852, 0.9899141063829788, 0.605575063829787], 
             UndirectedEdge[237, 251] -> 
             RGBColor[
              0.9420425319148936, 0.9558515744680851, 0.9675826914893617], 
             UndirectedEdge[25, 223] -> 
             RGBColor[
              0.989883159574468, 0.9891152765957447, 0.7468777553191488], 
             UndirectedEdge[284, 332] -> 
             RGBColor[
              0.9758721914893618, 0.9296895106382979, 0.41041629787234024`], 
             UndirectedEdge[145, 333] -> 
             RGBColor[
              0.9701073404255318, 0.9068757872340425, 0.44051437234042545`], 
             UndirectedEdge[146, 227] -> 
             RGBColor[
              0.9635706276595745, 0.9604026808510637, 0.6931052872340426], 
             UndirectedEdge[108, 286] -> 
             RGBColor[
              0.9902379255319149, 0.989874085106383, 0.7854918404255318], 
             UndirectedEdge[127, 361] -> 
             RGBColor[
              0.9898662340425533, 0.9768947021276596, 0.46478051063829773`], 
             UndirectedEdge[143, 258] -> 
             RGBColor[
              0.9747830319148936, 0.9308203829787234, 0.5434079680851063], 
             UndirectedEdge[212, 310] -> 
             RGBColor[
              0.9568981489361702, 0.854505744680851, 0.4298859468085106], 
             UndirectedEdge[107, 310] -> 
             RGBColor[
              0.9196377234042553, 0.7190973829787233, 0.254196829787234], 
             UndirectedEdge[253, 394] -> 
             RGBColor[
              0.9499387872340426, 0.8275619148936171, 0.38595764893617013`], 
             UndirectedEdge[152, 284] -> 
             RGBColor[
              0.9722893829787234, 0.9181877234042553, 0.34684991489361694`], 
             UndirectedEdge[230, 364] -> 
             RGBColor[
              0.9193519361702127, 0.7049675531914893, 0.27143307446808496`], 
             UndirectedEdge[158, 241] -> 
             RGBColor[
              0.994513340425532, 0.9906729148936171, 0.6441891489361701], 
             UndirectedEdge[44, 315] -> 
             RGBColor[
              0.9934490425531914, 0.9883964893617021, 0.528346893617021], 
             UndirectedEdge[357, 385] -> 
             RGBColor[
              0.9362395212765957, 0.798421744680851, 0.5778919787234041], 
             UndirectedEdge[99, 197] -> 
             RGBColor[
              0.9826966489361701, 0.9617050638297873, 0.603113329787234], 
             UndirectedEdge[152, 267] -> 
             RGBColor[0.990221, 0.9776535106382979, 0.5033945957446808], 
             UndirectedEdge[169, 197] -> 
             RGBColor[
              0.923909585106383, 0.7219231489361702, 0.5228154255319147], 
             UndirectedEdge[263, 348] -> 
             RGBColor[
              0.9323619361702128, 0.7688549361702128, 0.26802705319148934`], 
             UndirectedEdge[314, 379] -> 
             RGBColor[
              0.9627932127659574, 0.87917314893617, 0.35797198936170194`], 
             UndirectedEdge[300, 319] -> 
             RGBColor[0.9780319680851064, 0.94597, 0.5849919255319147], 
             UndirectedEdge[25, 78] -> 
             RGBColor[
              0.9808916382978723, 0.9461833829787233, 0.4671517872340424], 
             UndirectedEdge[44, 113] -> 
             RGBColor[
              0.9635027446808511, 0.8806907659574467, 0.435200159574468], 
             UndirectedEdge[115, 221] -> 
             RGBColor[
              0.9905893723404255, 0.9881831063829788, 0.6461870319148934], 
             UndirectedEdge[175, 319] -> 
             RGBColor[
              0.9826966489361701, 0.9617050638297873, 0.603113329787234], 
             UndirectedEdge[176, 356] -> 
             RGBColor[
              0.9923598829787235, 0.9895273617021276, 0.6613385638297871], 
             UndirectedEdge[84, 395] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255319], 
             UndirectedEdge[301, 359] -> 
             RGBColor[
              0.9322641063829787, 0.7479394680851065, 0.3712422659574467], 
             UndirectedEdge[238, 280] -> 
             RGBColor[
              0.7939842127659575, 0.8395429574468086, 0.9799527234042553], 
             UndirectedEdge[36, 168] -> 
             RGBColor[
              0.9632327872340425, 0.9718644468085107, 0.9365884468085106], 
             UndirectedEdge[4, 232] -> 
             RGBColor[
              0.9826966489361701, 0.9617050638297873, 0.603113329787234], 
             UndirectedEdge[140, 339] -> 
             RGBColor[
              0.9196377234042553, 0.7190973829787233, 0.254196829787234], 
             UndirectedEdge[18, 141] -> 
             RGBColor[
              0.9629600212765956, 0.8867175957446807, 0.3106071063829785], 
             UndirectedEdge[123, 140] -> 
             RGBColor[
              0.8737233829787234, 0.4669277234042551, 0.21423005319148933`], 
             UndirectedEdge[24, 78] -> 
             RGBColor[
              0.9568404042553191, 0.8631450638297871, 0.3020910957446806], 
             UndirectedEdge[62, 127] -> 
             RGBColor[
              0.9816187446808511, 0.9496578510638298, 0.38309272340425526`], 
             UndirectedEdge[299, 353] -> 
             RGBColor[
              0.9719515425531915, 0.9296494893617021, 0.590333074468085], 
             UndirectedEdge[256, 311] -> 
             RGBColor[
              0.9562835319148937, 0.9648260425531915, 0.8697451595744681], 
             UndirectedEdge[47, 346] -> 
             RGBColor[
              0.986283425531915, 0.965392914893617, 0.4012141276595744], 
             UndirectedEdge[34, 125] -> 
             RGBColor[
              0.9594296170212766, 0.9692632553191489, 0.953559255319149], 
             UndirectedEdge[194, 387] -> 
             RGBColor[
              0.8961116276595744, 0.8310874042553189, 0.6256372659574467], 
             UndirectedEdge[117, 303] -> 
             RGBColor[
              0.9282726489361701, 0.9083589148936169, 0.6589978723404254], 
             UndirectedEdge[287, 382] -> 
             RGBColor[
              0.9400426914893616, 0.8010229361702127, 0.5609211702127659], 
             UndirectedEdge[20, 168] -> 
             RGBColor[
              0.6817079148936169, 0.7479163404255319, 0.9665712234042554], 
             UndirectedEdge[51, 355] -> 
             RGBColor[
              0.9638575106382978, 0.881449574468085, 0.47381424468085087`], 
             UndirectedEdge[183, 339] -> 
             RGBColor[
              0.9436312127659574, 0.8107750212765956, 0.2914626702127658], 
             UndirectedEdge[118, 164] -> 
             RGBColor[
              0.9521757234042553, 0.8474099999999998, 0.2839696914893616], 
             UndirectedEdge[51, 134] -> 
             RGBColor[
              0.9328469148936169, 0.7714674255319146, 0.26482525531914886`], 
             UndirectedEdge[46, 356] -> 
             RGBColor[
              0.9898549787234042, 0.9900727872340426, 0.8177927872340425], 
             UndirectedEdge[204, 276] -> 
             RGBColor[
              0.9239077872340425, 0.9400973617021277, 0.9138523085106383], 
             UndirectedEdge[108, 154] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255319], 
             UndirectedEdge[29, 119] -> 
             RGBColor[
              0.9938038085106383, 0.9891552978723405, 0.566960978723404], 
             UndirectedEdge[244, 264] -> 
             RGBColor[
              0.9681483723404255, 0.9270482978723404, 0.6073038829787233], 
             UndirectedEdge[217, 321] -> 
             RGBColor[
              0.8961134255319148, 0.6129131914893614, 0.23460038297872332`], 
             UndirectedEdge[241, 346] -> 
             RGBColor[0.990221, 0.9776535106382979, 0.5033945957446808], 
             UndirectedEdge[108, 284] -> 
             RGBColor[
              0.9719515425531915, 0.9296494893617021, 0.590333074468085], 
             UndirectedEdge[181, 334] -> 
             RGBColor[
              0.986079989361702, 0.9865140851063829, 0.7638485638297872], 
             UndirectedEdge[8, 59] -> 
             RGBColor[
              0.9747830319148936, 0.9308203829787234, 0.5434079680851063], 
             UndirectedEdge[236, 383] -> 
             RGBColor[
              0.985945585106383, 0.9768546808510639, 0.6446972872340424], 
             UndirectedEdge[42, 290] -> 
             RGBColor[
              0.9542412659574467, 0.9289325531914892, 0.6568624787234041], 
             UndirectedEdge[173, 209] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255319], 
             UndirectedEdge[154, 332] -> 
             RGBColor[
              0.9923598829787235, 0.9895273617021276, 0.6613385638297871], 
             UndirectedEdge[5, 352] -> 
             RGBColor[
              0.985911085106383, 0.9626772553191489, 0.5238872765957445], 
             UndirectedEdge[189, 226] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255319], 
             UndirectedEdge[16, 390] -> 
             RGBColor[
              0.8304145638297873, 0.6715801914893618, 0.5969080957446808], 
             UndirectedEdge[119, 327] -> 
             RGBColor[
              0.9802441595744681, 0.9826559574468086, 0.8129417127659573], 
             UndirectedEdge[129, 231] -> 
             RGBColor[
              0.9632327872340425, 0.9718644468085107, 0.9365884468085106], 
             UndirectedEdge[79, 352] -> 
             RGBColor[
              0.9816187446808511, 0.9496578510638298, 0.38309272340425526`], 
             UndirectedEdge[62, 361] -> 
             RGBColor[
              0.9852015531914894, 0.9611596382978724, 0.44665910638297857`], 
             UndirectedEdge[150, 347] -> 
             RGBColor[
              0.914687255319149, 0.6892324893617021, 0.2533116702127659], 
             UndirectedEdge[5, 90] -> 
             RGBColor[
              0.9802441595744681, 0.9826559574468086, 0.8129417127659573], 
             UndirectedEdge[24, 27] -> 
             RGBColor[
              0.968663414893617, 0.9072478510638297, 0.5348919574468085], 
             UndirectedEdge[62, 393] -> 
             RGBColor[
              0.9826966489361701, 0.9617050638297873, 0.603113329787234], 
             UndirectedEdge[199, 353] -> 
             RGBColor[
              0.989883159574468, 0.9891152765957447, 0.7468777553191488], 
             UndirectedEdge[96, 201] -> 
             RGBColor[
              0.9812809042553191, 0.9611196170212766, 0.6265758829787234], 
             UndirectedEdge[155, 170] -> 
             RGBColor[
              0.9271222234042553, 0.9410695531914893, 0.8346262553191488], 
             UndirectedEdge[335, 394] -> 
             RGBColor[
              0.9857252234042553, 0.9857552765957447, 0.7252344787234041], 
             UndirectedEdge[16, 310] -> 
             RGBColor[
              0.854693840425532, 0.777387659574468, 0.6169376914893616], 
             UndirectedEdge[6, 277] -> 
             RGBColor[
              0.9394515106382978, 0.7976524468085104, 0.2701394680851063], 
             UndirectedEdge[140, 232] -> 
             RGBColor[
              0.9482958936170213, 0.8265100851063829, 0.30958407446808506`], 
             UndirectedEdge[177, 300] -> 
             RGBColor[
              0.9805368723404255, 0.945424574468085, 0.4285377021276593], 
             UndirectedEdge[24, 32] -> 
             RGBColor[
              0.9394515106382978, 0.7976524468085104, 0.2701394680851063], 
             UndirectedEdge[102, 226] -> 
             RGBColor[
              0.9898549787234042, 0.9900727872340426, 0.8177927872340425], 
             UndirectedEdge[187, 206] -> 
             RGBColor[
              0.9852015531914894, 0.9611596382978724, 0.44665910638297857`], 
             UndirectedEdge[336, 396] -> 
             RGBColor[
              0.9841123936170213, 0.9622905106382978, 0.5796507765957446], 
             UndirectedEdge[267, 332] -> 
             RGBColor[
              0.9938038085106383, 0.9891552978723405, 0.5669609787234041], 
             UndirectedEdge[115, 300] -> 
             RGBColor[
              0.9801821063829788, 0.9446657659574467, 0.38992361702127626`], 
             UndirectedEdge[149, 195] -> 
             RGBColor[
              0.9902379255319149, 0.989874085106383, 0.7854918404255318], 
             UndirectedEdge[127, 396] -> 
             RGBColor[
              0.9816187446808511, 0.9496578510638298, 0.38309272340425526`], 
             UndirectedEdge[206, 220] -> 
             RGBColor[
              0.9758721914893618, 0.9296895106382979, 0.41041629787234024`], 
             UndirectedEdge[298, 361] -> 
             RGBColor[
              0.9941585744680852, 0.9899141063829788, 0.605575063829787], 
             UndirectedEdge[27, 141] -> 
             RGBColor[
              0.9794477127659573, 0.9465554468085104, 0.5615293723404253], 
             UndirectedEdge[55, 221] -> 
             RGBColor[
              0.9898549787234042, 0.9900727872340426, 0.8177927872340425], 
             UndirectedEdge[40, 269] -> 
             RGBColor[
              0.9912989042553191, 0.9897007234042554, 0.7234152021276594], 
             UndirectedEdge[191, 312] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255319], 
             UndirectedEdge[78, 240] -> 
             RGBColor[
              0.9722893829787234, 0.9181877234042553, 0.34684991489361683`], 
             UndirectedEdge[183, 246] -> 
             RGBColor[
              0.9604318617021276, 0.933549489361702, 0.646383414893617], 
             UndirectedEdge[130, 164] -> 
             RGBColor[
              0.9521757234042553, 0.8474099999999998, 0.2839696914893616], 
             UndirectedEdge[190, 295] -> 
             RGBColor[
              0.9548677872340425, 0.9642405957446809, 0.8932077127659575], 
             UndirectedEdge[18, 179] -> 
             RGBColor[
              0.9755174255319149, 0.9289307021276596, 0.3718022127659572], 
             UndirectedEdge[128, 199] -> 
             RGBColor[
              0.9443181063829786, 0.8018217659574467, 0.4196184787234042], 
             UndirectedEdge[350, 355] -> 
             RGBColor[
              0.985911085106383, 0.9626772553191489, 0.5238872765957445], 
             UndirectedEdge[233, 348] -> 
             RGBColor[
              0.9502653723404255, 0.8292782340425533, 0.4954867659574468], 
             UndirectedEdge[247, 316] -> 
             RGBColor[
              0.9766162234042552, 0.9453845531914893, 0.6084544787234041], 
             UndirectedEdge[74, 399] -> 
             RGBColor[
              0.9938038085106383, 0.9891552978723405, 0.5669609787234041], 
             UndirectedEdge[155, 171] -> 
             RGBColor[
              0.9135005212765956, 0.8965800212765955, 0.6575888936170211], 
             UndirectedEdge[21, 95] -> 
             RGBColor[
              0.9934490425531916, 0.9883964893617022, 0.528346893617021], 
             UndirectedEdge[257, 325] -> 
             RGBColor[
              0.9891736276595744, 0.9875976595744682, 0.6696495851063827], 
             UndirectedEdge[250, 372] -> 
             RGBColor[
              0.9812464042553191, 0.9469421914893617, 0.5057658723404252], 
             UndirectedEdge[156, 400] -> 
             RGBColor[
              0.9561886170212766, 0.8529881276595744, 0.3526577765957445], 
             UndirectedEdge[193, 360] -> 
             RGBColor[
              0.9499387872340426, 0.8275619148936171, 0.38595764893617013`], 
             UndirectedEdge[92, 135] -> 
             RGBColor[
              0.9568699680851064, 0.8554632553191488, 0.5008009787234042], 
             UndirectedEdge[102, 174] -> 
             RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 
             UndirectedEdge[140, 275] -> 
             RGBColor[
              0.9302477765957446, 0.8372549148936169, 0.6195966382978724], 
             UndirectedEdge[101, 301] -> 
             RGBColor[
              0.9895283936170213, 0.9883564680851065, 0.7082636702127658], 
             UndirectedEdge[337, 398] -> 
             RGBColor[0.9496475638297872, 0.8942418936170211, 0.619746], 
             UndirectedEdge[149, 249] -> 
             RGBColor[
              0.9891736276595744, 0.9875976595744682, 0.6696495851063827], 
             UndirectedEdge[92, 165] -> 
             RGBColor[
              0.9529605744680851, 0.8422451489361702, 0.3277054787234042], 
             UndirectedEdge[150, 320] -> 
             RGBColor[
              0.9322641063829787, 0.7479394680851065, 0.3712422659574467], 
             UndirectedEdge[59, 175] -> 
             RGBColor[
              0.9841123936170213, 0.9622905106382978, 0.5796507765957446], 
             UndirectedEdge[278, 379] -> 
             RGBColor[
              0.9934208617021276, 0.9893540000000001, 0.5992619255319147], 
             UndirectedEdge[87, 317] -> 
             RGBColor[
              0.9136622765957446, 0.6925984255319146, 0.24924357446808504`], 
             UndirectedEdge[212, 324] -> 
             RGBColor[
              0.9736987978723404, 0.9772802127659574, 0.7848066914893617], 
             UndirectedEdge[135, 328] -> 
             RGBColor[
              0.9761987765957447, 0.931405829787234, 0.5199454148936169], 
             UndirectedEdge[176, 344] -> 
             RGBColor[
              0.9631479787234043, 0.8799319574468084, 0.3965860744680849], 
             UndirectedEdge[59, 213] -> 
             RGBColor[
              0.9747830319148936, 0.9308203829787234, 0.5434079680851063], 
             UndirectedEdge[371, 391] -> 
             RGBColor[
              0.993069414893617, 0.9910449787234042, 0.738566734042553], 
             UndirectedEdge[98, 318] -> 
             RGBColor[
              0.9798612127659574, 0.982854659574468, 0.845242659574468], 
             UndirectedEdge[25, 244] -> 
             RGBColor[
              0.9762269574468085, 0.9304483191489361, 0.44903038297872333`], 
             UndirectedEdge[204, 224] -> 
             RGBColor[
              0.991653670212766, 0.9904595319148937, 0.7620292872340424], 
             UndirectedEdge[180, 236] -> 
             RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 
             UndirectedEdge[102, 163] -> 
             RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 
             UndirectedEdge[16, 107] -> 
             RGBColor[
              0.854693840425532, 0.777387659574468, 0.6169376914893616], 
             UndirectedEdge[194, 223] -> 
             RGBColor[
              0.959227329787234, 0.8798919361702127, 0.5765028510638297], 
             UndirectedEdge[111, 291] -> 
             RGBColor[0.918167, 0.6941408723404254, 0.28467341489361697`], 
             UndirectedEdge[108, 205] -> 
             RGBColor[
              0.9460181382978723, 0.8275218936170214, 0.5658744255319148], 
             UndirectedEdge[66, 297] -> 
             RGBColor[
              0.9934208617021276, 0.9893540000000001, 0.5992619255319147], 
             UndirectedEdge[19, 284] -> 
             RGBColor[
              0.9619577765957447, 0.9224313617021276, 0.6177829468085105], 
             UndirectedEdge[23, 260] -> 
             RGBColor[
              0.9674800212765957, 0.9736207872340426, 0.8662007872340425], 
             UndirectedEdge[10, 256] -> 
             RGBColor[
              0.9808634574468085, 0.9471408936170211, 0.538066819148936], 
             UndirectedEdge[230, 242] -> 
             RGBColor[
              0.9193519361702127, 0.7049675531914893, 0.27143307446808496`], 
             UndirectedEdge[29, 317] -> 
             RGBColor[
              0.9627932127659574, 0.87917314893617, 0.35797198936170194`], 
             UndirectedEdge[124, 316] -> 
             RGBColor[
              0.9135023191489361, 0.678405808510638, 0.2665520106382977], 
             UndirectedEdge[306, 361] -> 
             RGBColor[
              0.9923598829787235, 0.9895273617021276, 0.6613385638297871], 
             UndirectedEdge[1, 393] -> 
             RGBColor[
              0.923909585106383, 0.7219231489361702, 0.5228154255319147], 
             UndirectedEdge[74, 279] -> 
             RGBColor[
              0.9499387872340426, 0.8275619148936171, 0.38595764893617013`], 
             UndirectedEdge[40, 234] -> 
             RGBColor[
              0.9646485319148936, 0.9724498936170213, 0.9131258936170212], 
             UndirectedEdge[195, 316] -> 
             RGBColor[
              0.9812464042553191, 0.9469421914893617, 0.5057658723404252], 
             UndirectedEdge[279, 325] -> 
             RGBColor[
              0.9495840212765958, 0.8268031063829788, 0.3473435638297871], 
             UndirectedEdge[172, 337] -> 
             RGBColor[
              0.9697612234042553, 0.9650196170212766, 0.6826262234042553], 
             UndirectedEdge[148, 275] -> 
             RGBColor[
              0.940857829787234, 0.9554124468085106, 0.9849964468085107], 
             UndirectedEdge[13, 188] -> 
             RGBColor[
              0.9542412659574467, 0.9289325531914892, 0.6568624787234041], 
             UndirectedEdge[220, 233] -> 
             RGBColor[
              0.9761987765957447, 0.931405829787234, 0.5199454148936169], 
             UndirectedEdge[230, 244] -> 
             RGBColor[
              0.914687255319149, 0.6892324893617021, 0.2533116702127659], 
             UndirectedEdge[253, 358] -> 
             RGBColor[
              0.9130331276595745, 0.6929123617021277, 0.24888261702127662`], 
             UndirectedEdge[66, 140] -> 
             RGBColor[
              0.9561886170212766, 0.8529881276595744, 0.3526577765957445], 
             UndirectedEdge[89, 128] -> 
             RGBColor[
              0.9442899255319148, 0.8027792765957446, 0.4905335106382978], 
             UndirectedEdge[199, 298] -> 
             RGBColor[
              0.994513340425532, 0.9906729148936171, 0.6441891489361701], 
             UndirectedEdge[367, 398] -> 
             RGBColor[
              0.968663414893617, 0.9072478510638297, 0.5348919574468085], 
             UndirectedEdge[72, 181] -> 
             RGBColor[
              0.9675082021276595, 0.9726632765957446, 0.795285755319149], 
             UndirectedEdge[229, 329] -> 
             RGBColor[0.9780319680851064, 0.94597, 0.5849919255319147], 
             UndirectedEdge[196, 326] -> 
             RGBColor[
              0.9944851595744681, 0.9916304255319148, 0.7151041808510636], 
             UndirectedEdge[247, 362] -> 
             RGBColor[
              0.9902379255319149, 0.989874085106383, 0.7854918404255318], 
             UndirectedEdge[276, 297] -> 
             RGBColor[
              0.9267392765957447, 0.9412682553191489, 0.8669272021276595], 
             UndirectedEdge[7, 201] -> 
             RGBColor[
              0.9676247021276596, 0.902452659574468, 0.3287285106382978], 
             UndirectedEdge[191, 214] -> 
             RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 
             UndirectedEdge[25, 32] -> 
             RGBColor[
              0.9635027446808511, 0.8806907659574467, 0.435200159574468], 
             UndirectedEdge[190, 324] -> 
             RGBColor[
              0.9722548723404254, 0.9776522765957447, 0.8791842765957447], 
             UndirectedEdge[8, 296] -> 
             RGBColor[
              0.9719515425531915, 0.9296494893617021, 0.590333074468085], 
             UndirectedEdge[292, 382] -> 
             RGBColor[
              0.8769269893617021, 0.752218404255319, 0.6100555851063829], 
             UndirectedEdge[223, 328] -> 
             RGBColor[
              0.9719515425531915, 0.9296494893617021, 0.590333074468085], 
             UndirectedEdge[70, 262] -> 
             RGBColor[
              0.9895114680851065, 0.9761358936170212, 0.4261664255319147], 
             UndirectedEdge[78, 285] -> 
             RGBColor[
              0.9135023191489361, 0.678405808510638, 0.2665520106382977], 
             UndirectedEdge[167, 272] -> 
             RGBColor[
              0.9733672872340425, 0.9302349361702127, 0.5668705212765957], 
             UndirectedEdge[93, 276] -> 
             RGBColor[
              0.9271222234042553, 0.9410695531914893, 0.8346262553191488], 
             UndirectedEdge[56, 319] -> 
             RGBColor[
              0.9672476702127659, 0.9066624042553191, 0.5583545106382977], 
             UndirectedEdge[93, 162] -> 
             RGBColor[
              0.9812464042553191, 0.9469421914893617, 0.5057658723404252], 
             UndirectedEdge[106, 389] -> 
             RGBColor[
              0.9572529148936171, 0.8552645531914893, 0.4685000319148935], 
             UndirectedEdge[68, 176] -> 
             RGBColor[
              0.9923598829787235, 0.9895273617021276, 0.6613385638297871], 
             UndirectedEdge[253, 301] -> 
             RGBColor[
              0.9499387872340426, 0.8275619148936171, 0.38595764893617013`], 
             UndirectedEdge[217, 357] -> 
             RGBColor[
              0.9136622765957446, 0.6925984255319146, 0.24924357446808504`], 
             UndirectedEdge[364, 385] -> 
             RGBColor[
              0.9728130531914894, 0.9427833617021275, 0.6254252872340423], 
             UndirectedEdge[161, 372] -> 
             RGBColor[
              0.9864347553191489, 0.9872728936170213, 0.80246264893617], 
             UndirectedEdge[4, 339] -> 
             RGBColor[
              0.9540384787234042, 0.8542923617021276, 0.5477260851063829], 
             UndirectedEdge[183, 280] -> 
             RGBColor[
              0.9282726489361701, 0.9083589148936169, 0.6589978723404254], 
             UndirectedEdge[94, 145] -> 
             RGBColor[
              0.970079159574468, 0.9078332978723402, 0.511429404255319], 
             UndirectedEdge[107, 351] -> 
             RGBColor[
              0.9302477765957446, 0.8372549148936169, 0.6195966382978724], 
             UndirectedEdge[90, 178] -> 
             RGBColor[
              0.9759518191489363, 0.9696365531914893, 0.672147159574468], 
             UndirectedEdge[113, 124] -> 
             RGBColor[
              0.8961134255319148, 0.6129131914893614, 0.23460038297872332`], 
             UndirectedEdge[191, 365] -> 
             RGBColor[
              0.987023489361702, 0.9889018936170213, 0.8647178936170211], 
             UndirectedEdge[184, 356] -> 
             RGBColor[
              0.9927146489361702, 0.9902861702127659, 0.6999526489361703], 
             UndirectedEdge[196, 327] -> 
             RGBColor[
              0.9802441595744681, 0.9826559574468086, 0.8129417127659573], 
             UndirectedEdge[140, 288] -> 
             RGBColor[
              0.9568699680851064, 0.8554632553191488, 0.5008009787234042], 
             UndirectedEdge[13, 232] -> 
             RGBColor[
              0.9722893829787234, 0.9181877234042553, 0.34684991489361683`], 
             UndirectedEdge[34, 86] -> 
             RGBColor[
              0.9860518085106382, 0.9874715957446809, 0.8347635957446807], 
             UndirectedEdge[287, 374] -> 
             RGBColor[
              0.985945585106383, 0.9768546808510639, 0.6446972872340424], 
             UndirectedEdge[201, 230] -> 
             RGBColor[
              0.9240166170212766, 0.7207026170212767, 0.28955447872340423`], 
             UndirectedEdge[71, 138] -> 
             RGBColor[
              0.986283425531915, 0.965392914893617, 0.4012141276595744], 
             UndirectedEdge[334, 360] -> 
             RGBColor[
              0.9857252234042553, 0.9857552765957447, 0.7252344787234041], 
             UndirectedEdge[38, 58] -> 
             RGBColor[
              0.9920051170212766, 0.9887685531914894, 0.6227244787234041], 
             UndirectedEdge[115, 239] -> 
             RGBColor[
              0.9693978085106383, 0.9053581702127659, 0.3632862021276594], 
             UndirectedEdge[32, 78] -> 
             RGBColor[
              0.9502358085106382, 0.8369600425531912, 0.2967768829787232], 
             UndirectedEdge[41, 83] -> 
             RGBColor[
              0.9801821063829788, 0.9446657659574467, 0.38992361702127626`], 
             UndirectedEdge[90, 212] -> 
             RGBColor[
              0.9798893936170212, 0.9818971489361702, 0.7743276276595744], 
             UndirectedEdge[160, 263] -> 
             RGBColor[
              0.9619577765957447, 0.9224313617021276, 0.6177829468085105], 
             UndirectedEdge[226, 350] -> 
             RGBColor[
              0.9812809042553191, 0.9611196170212766, 0.6265758829787234], 
             UndirectedEdge[159, 329] -> 
             RGBColor[
              0.987023489361702, 0.9889018936170213, 0.8647178936170211], 
             UndirectedEdge[132, 260] -> 
             RGBColor[
              0.9674800212765957, 0.9736207872340426, 0.8662007872340425], 
             UndirectedEdge[7, 250] -> 
             RGBColor[
              0.9629600212765956, 0.8867175957446807, 0.3106071063829785], 
             UndirectedEdge[135, 281] -> 
             RGBColor[
              0.9761987765957447, 0.931405829787234, 0.5199454148936169], 
             UndirectedEdge[240, 243] -> 
             RGBColor[
              0.9816187446808511, 0.9496578510638298, 0.38309272340425526`], 
             UndirectedEdge[105, 349] -> 
             RGBColor[
              0.9678629680851063, 0.973422085106383, 0.8338998404255318], 
             UndirectedEdge[111, 154] -> 
             RGBColor[
              0.9253253297872339, 0.7225085957446806, 0.49935287234042547`], 
             UndirectedEdge[3, 233] -> 
             RGBColor[
              0.9736706170212766, 0.9782377234042553, 0.8557217234042553], 
             UndirectedEdge[125, 162] -> 
             RGBColor[
              0.9542412659574467, 0.9289325531914892, 0.6568624787234041], 
             UndirectedEdge[301, 369] -> 
             RGBColor[
              0.9857252234042553, 0.9857552765957447, 0.7252344787234041], 
             UndirectedEdge[268, 270] -> 
             RGBColor[
              0.9841123936170213, 0.9622905106382978, 0.5796507765957446], 
             UndirectedEdge[4, 188] -> 
             RGBColor[
              0.9646485319148936, 0.9724498936170213, 0.9131258936170212], 
             UndirectedEdge[161, 176] -> 
             RGBColor[
              0.9857252234042553, 0.9857552765957447, 0.7252344787234041], 
             UndirectedEdge[106, 270] -> 
             RGBColor[
              0.993069414893617, 0.9910449787234042, 0.738566734042553], 
             UndirectedEdge[190, 268] -> 
             RGBColor[
              0.9841123936170213, 0.9622905106382978, 0.5796507765957446], 
             UndirectedEdge[220, 341] -> 
             RGBColor[
              0.9521757234042553, 0.8474099999999998, 0.2839696914893616], 
             UndirectedEdge[76, 103] -> 
             RGBColor[
              0.9064285319148937, 0.6667273404255321, 0.2435684042553192], 
             UndirectedEdge[84, 163] -> 
             RGBColor[
              0.9898549787234042, 0.9900727872340426, 0.8177927872340425], 
             UndirectedEdge[356, 372] -> 
             RGBColor[
              0.993069414893617, 0.9910449787234042, 0.738566734042553], 
             UndirectedEdge[243, 398] -> 
             RGBColor[
              0.9661697659574469, 0.8946151914893616, 0.33833390425531906`], 
             UndirectedEdge[141, 243] -> 
             RGBColor[
              0.9769540638297872, 0.9339227872340424, 0.364971319148936], 
             UndirectedEdge[192, 320] -> 
             RGBColor[
              0.9937756276595745, 0.9901128085106383, 0.6378760106382977], 
             UndirectedEdge[83, 245] -> 
             RGBColor[
              0.8987283936170213, 0.8848011276595744, 0.6561799148936169], 
             UndirectedEdge[256, 313] -> 
             RGBColor[
              0.970079159574468, 0.9078332978723402, 0.511429404255319], 
             UndirectedEdge[144, 186] -> 
             RGBColor[
              0.9769540638297872, 0.9339227872340424, 0.364971319148936], 
             UndirectedEdge[271, 371] -> 
             RGBColor[
              0.9794477127659573, 0.9465554468085104, 0.5615293723404253], 
             UndirectedEdge[317, 326] -> 
             RGBColor[
              0.9634745638297872, 0.8816482765957445, 0.5061151914893616], 
             UndirectedEdge[194, 242] -> 
             RGBColor[
              0.9502358085106382, 0.8369600425531912, 0.2967768829787232], 
             UndirectedEdge[305, 334] -> 
             RGBColor[
              0.9860518085106382, 0.9874715957446809, 0.8347635957446807], 
             UndirectedEdge[252, 282] -> 
             RGBColor[
              0.9816187446808511, 0.9496578510638298, 0.38309272340425526`], 
             UndirectedEdge[134, 239] -> 
             RGBColor[
              0.9394515106382978, 0.7976524468085104, 0.2701394680851063], 
             UndirectedEdge[267, 398] -> 
             RGBColor[
              0.9701073404255318, 0.9068757872340425, 0.44051437234042545`], 
             UndirectedEdge[4, 297] -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425531], 
             UndirectedEdge[40, 272] -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255317], 
             UndirectedEdge[203, 325] -> 
             RGBColor[
              0.9436085744680851, 0.8003041489361702, 0.3423903085106381], 
             UndirectedEdge[315, 359] -> 
             RGBColor[
              0.9319093404255319, 0.7471806595744681, 0.33262818085106366`], 
             UndirectedEdge[132, 160] -> 
             RGBColor[
              0.9798612127659574, 0.982854659574468, 0.845242659574468], 
             UndirectedEdge[283, 381] -> 
             RGBColor[
              0.9938038085106383, 0.9891552978723405, 0.566960978723404], 
             UndirectedEdge[40, 183] -> 
             RGBColor[0.9780319680851064, 0.94597, 0.5849919255319147], 
             UndirectedEdge[131, 339] -> 
             RGBColor[
              0.9565433829787234, 0.8537469361702128, 0.3912718617021275], 
             UndirectedEdge[156, 165] -> 
             RGBColor[
              0.9895114680851065, 0.9761358936170212, 0.4261664255319147], 
             UndirectedEdge[352, 379] -> 
             RGBColor[
              0.9848467872340425, 0.9604008297872341, 0.40804502127659553`], 
             UndirectedEdge[25, 194] -> 
             RGBColor[
              0.9635027446808511, 0.8806907659574467, 0.435200159574468], 
             UndirectedEdge[174, 238] -> 
             RGBColor[
              0.8465750212765959, 0.8783249361702128, 0.8590216702127659], 
             UndirectedEdge[66, 339] -> 
             RGBColor[
              0.9561886170212766, 0.8529881276595744, 0.3526577765957445], 
             UndirectedEdge[67, 387] -> 
             RGBColor[
              0.9239077872340425, 0.9400973617021277, 0.9138523085106383], 
             UndirectedEdge[90, 190] -> 
             RGBColor[
              0.9784454680851064, 0.9822692127659574, 0.8687052127659574], 
             UndirectedEdge[271, 389] -> 
             RGBColor[
              0.9436312127659574, 0.8107750212765956, 0.2914626702127658], 
             UndirectedEdge[19, 293] -> 
             RGBColor[
              0.9718108085106383, 0.9784971276595744, 0.9326011276595744], 
             UndirectedEdge[126, 327] -> 
             RGBColor[
              0.9756139787234042, 0.9810983191489362, 0.9156303191489361], 
             UndirectedEdge[12, 310] -> 
             RGBColor[
              0.9568699680851064, 0.8554632553191488, 0.5008009787234042], 
             UndirectedEdge[272, 350] -> 
             RGBColor[
              0.9826966489361701, 0.9617050638297873, 0.603113329787234], 
             UndirectedEdge[215, 229] -> 
             RGBColor[
              0.9666224574468085, 0.9381664255319148, 0.6359043510638296], 
             UndirectedEdge[57, 189] -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 
             UndirectedEdge[104, 337] -> 
             RGBColor[
              0.9656202127659574, 0.9738801914893618, 0.9430801914893616], 
             UndirectedEdge[194, 385] -> 
             RGBColor[
              0.955424159574468, 0.8772907446808509, 0.5934736595744681], 
             UndirectedEdge[56, 166] -> 
             RGBColor[
              0.9701073404255318, 0.9068757872340425, 0.44051437234042545`], 
             UndirectedEdge[258, 379] -> 
             RGBColor[
              0.9755174255319149, 0.9289307021276596, 0.3718022127659572], 
             UndirectedEdge[9, 150] -> 
             RGBColor[
              0.9121590957446808, 0.7360643829787235, 0.5890879787234042], 
             UndirectedEdge[294, 380] -> 
             RGBColor[
              0.955424159574468, 0.8772907446808509, 0.593473659574468], 
             UndirectedEdge[296, 308] -> 
             RGBColor[
              0.9766162234042552, 0.9453845531914893, 0.6084544787234041], 
             UndirectedEdge[33, 92] -> 
             RGBColor[
              0.9436312127659574, 0.8107750212765956, 0.2914626702127658], 
             UndirectedEdge[39, 283] -> 
             RGBColor[
              0.9930942765957447, 0.9876376808510638, 0.489732808510638], 
             UndirectedEdge[11, 34] -> 
             RGBColor[
              0.981804574468085, 0.985715255319149, 0.9051512553191488], 
             UndirectedEdge[105, 171] -> 
             RGBColor[
              0.9812464042553191, 0.9469421914893617, 0.5057658723404252], 
             UndirectedEdge[110, 237] -> 
             RGBColor[
              0.9666224574468085, 0.9381664255319148, 0.6359043510638296], 
             UndirectedEdge[8, 175] -> 
             RGBColor[
              0.9676247021276596, 0.902452659574468, 0.3287285106382978], 
             UndirectedEdge[90, 373] -> 
             RGBColor[
              0.9360243723404256, 0.8203037659574468, 0.5933242978723404], 
             UndirectedEdge[73, 104] -> 
             RGBColor[
              0.9620287553191489, 0.9034757659574467, 0.5987878723404254], 
             UndirectedEdge[232, 339] -> 
             RGBColor[
              0.9482958936170213, 0.8265100851063829, 0.30958407446808506`], 
             UndirectedEdge[178, 274] -> 
             RGBColor[
              0.9722893829787234, 0.9181877234042553, 0.34684991489361694`], 
             UndirectedEdge[224, 318] -> 
             RGBColor[
              0.9944851595744681, 0.9916304255319148, 0.7151041808510636], 
             UndirectedEdge[132, 307] -> 
             RGBColor[
              0.9937756276595745, 0.9901128085106383, 0.6378760106382977]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.9460561063829787, 0.8238374680851062, 0.27545368085106375`], 
             316 -> RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             308 -> RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             160 -> RGBColor[
              0.9656202127659574, 0.9738801914893617, 0.9430801914893616], 
             245 -> RGBColor[
              0.8298320851063831, 0.8671495957446809, 0.9836313191489362], 
             155 -> RGBColor[
              0.8593763404255319, 0.8907073829787233, 0.9864492765957447], 
             213 -> RGBColor[
              0.9582953404255319, 0.8709825319148935, 0.29248570212765945`], 
             352 -> RGBColor[
              0.9769540638297872, 0.9339227872340425, 0.3649713191489361], 27 -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 
             367 -> RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 19 -> 
             RGBColor[
              0.9656202127659574, 0.9738801914893617, 0.9430801914893616], 
             164 -> RGBColor[
              0.9460561063829787, 0.8238374680851062, 0.27545368085106375`], 
             190 -> RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 
             103 -> RGBColor[
              0.9064285319148937, 0.6667273404255321, 0.2435684042553192], 
             138 -> RGBColor[
              0.986283425531915, 0.965392914893617, 0.4012141276595744], 291 -> 
             RGBColor[
              0.9769540638297872, 0.9339227872340425, 0.3649713191489361], 28 -> 
             RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             337 -> RGBColor[
              0.9532390212765957, 0.9646463191489362, 0.9640383191489362], 
             195 -> RGBColor[
              0.9948681063829787, 0.9914317234042553, 0.6828032340425529], 
             114 -> RGBColor[
              0.986283425531915, 0.965392914893617, 0.4012141276595744], 93 -> 
             RGBColor[
              0.9948681063829787, 0.9914317234042553, 0.6828032340425529], 34 -> 
             RGBColor[
              0.9780014042553191, 0.9831140638297873, 0.9221220638297871], 
             161 -> RGBColor[
              0.9780014042553191, 0.9831140638297873, 0.9221220638297871], 22 -> 
             RGBColor[
              0.9934490425531916, 0.9883964893617022, 0.528346893617021], 124 -> 
             RGBColor[
              0.8593799361702127, 0.4543589574468082, 0.2043755106382978], 84 -> 
             RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 46 -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255317], 241 -> 
             RGBColor[
              0.9941585744680851, 0.9899141063829787, 0.6055750638297872], 
             185 -> RGBColor[
              0.8710791702127659, 0.5074824468085107, 0.21413763829787236`], 
             390 -> RGBColor[
              0.8710791702127659, 0.5074824468085107, 0.21413763829787236`], 
             121 -> RGBColor[
              0.986283425531915, 0.965392914893617, 0.4012141276595744], 322 -> 
             RGBColor[
              0.9934490425531916, 0.9883964893617022, 0.528346893617021], 126 -> 
             RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 236 -> 
             RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 78 -> 
             RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             376 -> RGBColor[
              0.9927395106382979, 0.9868788723404256, 0.45111872340425496`], 
             254 -> RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255317], 290 -> 
             RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             251 -> RGBColor[
              0.9184648510638298, 0.9378229574468085, 0.9920851914893617], 
             165 -> RGBColor[
              0.986283425531915, 0.965392914893617, 0.4012141276595744], 100 -> 
             RGBColor[
              0.9948681063829787, 0.9914317234042553, 0.6828032340425529], 
             235 -> RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 70 -> 
             RGBColor[
              0.986283425531915, 0.965392914893617, 0.4012141276595744], 234 -> 
             RGBColor[
              0.940857829787234, 0.9554124468085106, 0.9849964468085107], 257 -> 
             RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 135 -> 
             RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 
             265 -> RGBColor[
              0.9934490425531916, 0.9883964893617022, 0.528346893617021], 111 -> 
             RGBColor[
              0.8593799361702127, 0.4543589574468082, 0.2043755106382978], 
             381 -> 
             RGBColor[
              0.9948681063829787, 0.9914317234042553, 0.6828032340425529], 
             182 -> RGBColor[
              0.8944776382978723, 0.6137294255319147, 0.23366189361702125`], 
             188 -> RGBColor[
              0.940857829787234, 0.9554124468085106, 0.9849964468085107], 154 -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 
             336 -> RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 
             315 -> RGBColor[
              0.9927395106382979, 0.9868788723404256, 0.45111872340425496`], 
             368 -> RGBColor[
              0.9927395106382979, 0.9868788723404256, 0.45111872340425496`], 
             269 -> RGBColor[
              0.9941585744680851, 0.9899141063829787, 0.6055750638297872], 
             208 -> RGBColor[
              0.9948681063829787, 0.9914317234042553, 0.6828032340425529], 86 -> 
             RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 
             119 -> RGBColor[
              0.9948681063829787, 0.9914317234042553, 0.6828032340425529], 
             377 -> RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 
             140 -> RGBColor[
              0.9196377234042553, 0.7190973829787233, 0.254196829787234], 85 -> 
             RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             351 -> RGBColor[
              0.940857829787234, 0.9554124468085106, 0.9849964468085107], 242 -> 
             RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             117 -> RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             47 -> RGBColor[
              0.986283425531915, 0.965392914893617, 0.4012141276595744], 81 -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255317], 275 -> 
             RGBColor[
              0.940857829787234, 0.9554124468085106, 0.9849964468085107], 23 -> 
             RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 
             328 -> RGBColor[
              0.9582953404255319, 0.8709825319148935, 0.29248570212765945`], 
             110 -> RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             6 -> RGBColor[
              0.9328469148936169, 0.7714674255319146, 0.26482525531914886`], 
             218 -> 
             RGBColor[
              0.8889205957446809, 0.914265170212766, 0.9892672340425532], 108 -> 
             RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 297 -> 
             RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 
             157 -> RGBColor[
              0.9582953404255319, 0.8709825319148935, 0.29248570212765945`], 
             354 -> RGBColor[
              0.9927395106382979, 0.9868788723404256, 0.45111872340425496`], 
             385 -> RGBColor[
              0.9780014042553191, 0.9831140638297873, 0.9221220638297871], 
             270 -> RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 
             392 -> RGBColor[0.178927, 0.305394, 0.933501], 33 -> 
             RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             252 -> RGBColor[
              0.986283425531915, 0.965392914893617, 0.4012141276595744], 394 -> 
             RGBColor[
              0.9934490425531916, 0.9883964893617022, 0.528346893617021], 260 -> 
             RGBColor[
              0.940857829787234, 0.9554124468085106, 0.9849964468085107], 159 -> 
             RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 183 -> 
             RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             99 -> RGBColor[
              0.9769540638297872, 0.9339227872340425, 0.3649713191489361], 
             329 -> RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255317], 309 -> 
             RGBColor[
              0.9656202127659574, 0.9738801914893617, 0.9430801914893616], 17 -> 
             RGBColor[
              0.8944776382978723, 0.6137294255319147, 0.23366189361702125`], 
             349 -> RGBColor[
              0.940857829787234, 0.9554124468085106, 0.9849964468085107], 347 -> 
             RGBColor[
              0.9582953404255319, 0.8709825319148935, 0.29248570212765945`], 
             340 -> RGBColor[
              0.9941585744680851, 0.9899141063829787, 0.6055750638297872], 
             277 -> RGBColor[
              0.9460561063829787, 0.8238374680851062, 0.27545368085106375`], 
             104 -> RGBColor[
              0.9780014042553191, 0.9831140638297873, 0.9221220638297871], 79 -> 
             RGBColor[
              0.986283425531915, 0.965392914893617, 0.4012141276595744], 327 -> 
             RGBColor[
              0.9656202127659574, 0.9738801914893617, 0.9430801914893616], 
             191 -> 
             RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 50 -> 
             RGBColor[
              0.986283425531915, 0.965392914893617, 0.4012141276595744], 225 -> 
             RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             61 -> RGBColor[
              0.9582953404255319, 0.8709825319148935, 0.29248570212765945`], 
             196 -> RGBColor[
              0.9948681063829787, 0.9914317234042553, 0.6828032340425529], 1 -> 
             RGBColor[
              0.8593799361702127, 0.4543589574468082, 0.2043755106382978], 
             263 -> RGBColor[
              0.9582953404255319, 0.8709825319148935, 0.29248570212765945`], 
             201 -> RGBColor[
              0.9769540638297872, 0.9339227872340425, 0.3649713191489361], 
             371 -> RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 
             293 -> RGBColor[
              0.9780014042553191, 0.9831140638297873, 0.9221220638297871], 
             362 -> RGBColor[
              0.9948681063829787, 0.9914317234042553, 0.6828032340425529], 
             184 -> RGBColor[
              0.9941585744680851, 0.9899141063829787, 0.6055750638297872], 
             106 -> RGBColor[
              0.9948681063829787, 0.9914317234042553, 0.6828032340425529], 
             206 -> RGBColor[
              0.9934490425531916, 0.9883964893617022, 0.528346893617021], 358 -> 
             RGBColor[
              0.9196377234042553, 0.7190973829787233, 0.254196829787234], 247 -> 
             RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 220 -> 
             RGBColor[
              0.9582953404255319, 0.8709825319148935, 0.29248570212765945`], 
             107 -> RGBColor[
              0.9196377234042553, 0.7190973829787233, 0.254196829787234], 375 -> 
             RGBColor[
              0.9460561063829787, 0.8238374680851062, 0.27545368085106375`], 
             131 -> RGBColor[
              0.9934490425531916, 0.9883964893617022, 0.528346893617021], 127 -> 
             RGBColor[
              0.986283425531915, 0.965392914893617, 0.4012141276595744], 210 -> 
             RGBColor[
              0.838299085106383, 0.2953891276595746, 0.18430855319148937`], 
             357 -> RGBColor[
              0.8944776382978723, 0.6137294255319147, 0.23366189361702125`], 
             181 -> RGBColor[
              0.9941585744680851, 0.9899141063829787, 0.6055750638297872], 
             194 -> RGBColor[
              0.9328469148936169, 0.7714674255319146, 0.26482525531914886`], 
             118 -> RGBColor[
              0.9582953404255319, 0.8709825319148935, 0.29248570212765945`], 
             348 -> RGBColor[
              0.9064285319148937, 0.6667273404255321, 0.2435684042553192], 
             276 -> RGBColor[
              0.8593763404255319, 0.8907073829787233, 0.9864492765957447], 
             305 -> RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 
             343 -> RGBColor[
              0.9769540638297872, 0.9339227872340425, 0.3649713191489361], 
             280 -> RGBColor[
              0.8889205957446809, 0.914265170212766, 0.9892672340425532], 189 -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 
             168 -> RGBColor[
              0.940857829787234, 0.9554124468085106, 0.9849964468085107], 363 -> 
             RGBColor[
              0.8710791702127659, 0.5074824468085107, 0.21413763829787236`], 
             41 -> RGBColor[
              0.9927395106382979, 0.9868788723404256, 0.45111872340425496`], 
             14 -> RGBColor[
              0.9064285319148937, 0.6667273404255321, 0.2435684042553192], 77 -> 
             RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 51 -> 
             RGBColor[
              0.9328469148936169, 0.7714674255319146, 0.26482525531914886`], 
             179 -> RGBColor[
              0.9927395106382979, 0.9868788723404256, 0.45111872340425496`], 
             223 -> RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 323 -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 
             292 -> RGBColor[
              0.8593763404255319, 0.8907073829787233, 0.9864492765957447], 
             396 -> RGBColor[
              0.9769540638297872, 0.9339227872340425, 0.3649713191489361], 
             321 -> RGBColor[
              0.8593799361702127, 0.4543589574468082, 0.2043755106382978], 
             143 -> RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 
             112 -> RGBColor[
              0.9948681063829787, 0.9914317234042553, 0.6828032340425529], 
             197 -> RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255317], 54 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 71 -> 
             RGBColor[
              0.986283425531915, 0.965392914893617, 0.4012141276595744], 177 -> 
             RGBColor[
              0.9934490425531916, 0.9883964893617022, 0.528346893617021], 158 -> 
             RGBColor[
              0.9948681063829787, 0.9914317234042553, 0.6828032340425529], 
             226 -> RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 350 -> 
             RGBColor[
              0.9769540638297872, 0.9339227872340425, 0.3649713191489361], 
             203 -> RGBColor[
              0.8944776382978723, 0.6137294255319147, 0.23366189361702125`], 
             115 -> RGBColor[
              0.9927395106382979, 0.9868788723404256, 0.45111872340425496`], 
             173 -> RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 
             212 -> RGBColor[
              0.9941585744680851, 0.9899141063829787, 0.6055750638297872], 
             129 -> RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 279 -> 
             RGBColor[
              0.9064285319148937, 0.6667273404255321, 0.2435684042553192], 26 -> 
             RGBColor[
              0.9184648510638298, 0.9378229574468085, 0.9920851914893617], 40 -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255317], 146 -> 
             RGBColor[
              0.986283425531915, 0.965392914893617, 0.4012141276595744], 386 -> 
             RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             192 -> RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 
             300 -> RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             221 -> RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255317], 62 -> 
             RGBColor[
              0.9769540638297872, 0.9339227872340425, 0.3649713191489361], 
             286 -> RGBColor[
              0.9948681063829787, 0.9914317234042553, 0.6828032340425529], 
             152 -> RGBColor[
              0.986283425531915, 0.965392914893617, 0.4012141276595744], 64 -> 
             RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 
             307 -> RGBColor[
              0.9934490425531916, 0.9883964893617022, 0.528346893617021], 37 -> 
             RGBColor[
              0.9927395106382979, 0.9868788723404256, 0.45111872340425496`], 
             148 -> RGBColor[
              0.940857829787234, 0.9554124468085106, 0.9849964468085107], 261 -> 
             RGBColor[
              0.9934490425531916, 0.9883964893617022, 0.528346893617021], 387 -> 
             RGBColor[
              0.8593763404255319, 0.8907073829787233, 0.9864492765957447], 15 -> 
             RGBColor[
              0.9460561063829787, 0.8238374680851062, 0.27545368085106375`], 
             136 -> RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             198 -> RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 63 -> 
             RGBColor[
              0.9948681063829787, 0.9914317234042553, 0.6828032340425529], 
             310 -> RGBColor[
              0.9196377234042553, 0.7190973829787233, 0.254196829787234], 171 -> 
             RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             395 -> RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 
             311 -> RGBColor[
              0.9184648510638298, 0.9378229574468085, 0.9920851914893617], 
             353 -> RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 59 -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 
             397 -> RGBColor[
              0.9656202127659574, 0.9738801914893617, 0.9430801914893616], 
             229 -> RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             102 -> RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 
             299 -> RGBColor[
              0.9582953404255319, 0.8709825319148935, 0.29248570212765945`], 
             128 -> RGBColor[
              0.8944776382978723, 0.6137294255319147, 0.23366189361702125`], 
             12 -> RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 
             222 -> RGBColor[
              0.9582953404255319, 0.8709825319148935, 0.29248570212765945`], 
             92 -> RGBColor[
              0.9196377234042553, 0.7190973829787233, 0.254196829787234], 271 -> 
             RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             361 -> RGBColor[
              0.9934490425531916, 0.9883964893617022, 0.528346893617021], 344 -> 
             RGBColor[
              0.9328469148936169, 0.7714674255319146, 0.26482525531914886`], 
             132 -> RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 80 -> 
             RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 324 -> 
             RGBColor[
              0.9532390212765957, 0.9646463191489362, 0.9640383191489362], 
             244 -> RGBColor[
              0.9582953404255319, 0.8709825319148935, 0.29248570212765945`], 
             150 -> RGBColor[
              0.8710791702127659, 0.5074824468085107, 0.21413763829787236`], 
             125 -> RGBColor[
              0.940857829787234, 0.9554124468085106, 0.9849964468085107], 258 -> 
             RGBColor[
              0.9582953404255319, 0.8709825319148935, 0.29248570212765945`], 
             133 -> RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255317], 255 -> 
             RGBColor[
              0.9927395106382979, 0.9868788723404256, 0.45111872340425496`], 
             326 -> RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 
             176 -> RGBColor[
              0.9934490425531916, 0.9883964893617022, 0.528346893617021], 230 -> 
             RGBColor[
              0.8710791702127659, 0.5074824468085107, 0.21413763829787236`], 
             274 -> RGBColor[
              0.9582953404255319, 0.8709825319148935, 0.29248570212765945`], 
             87 -> RGBColor[
              0.8944776382978723, 0.6137294255319147, 0.23366189361702125`], 
             130 -> RGBColor[
              0.9582953404255319, 0.8709825319148935, 0.29248570212765945`], 
             35 -> RGBColor[
              0.8944776382978723, 0.6137294255319147, 0.23366189361702125`], 
             379 -> RGBColor[
              0.9927395106382979, 0.9868788723404256, 0.45111872340425496`], 
             31 -> RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 18 -> 
             RGBColor[
              0.9582953404255319, 0.8709825319148935, 0.29248570212765945`], 
             24 -> RGBColor[
              0.9460561063829787, 0.8238374680851062, 0.27545368085106375`], 
             151 -> RGBColor[
              0.9196377234042553, 0.7190973829787233, 0.254196829787234], 137 -> 
             RGBColor[
              0.9532390212765957, 0.9646463191489362, 0.9640383191489362], 
             330 -> RGBColor[
              0.9934490425531916, 0.9883964893617022, 0.528346893617021], 296 -> 
             RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 266 -> 
             RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             302 -> RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 
             283 -> RGBColor[
              0.9927395106382979, 0.9868788723404256, 0.45111872340425496`], 
             388 -> RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             284 -> RGBColor[
              0.9582953404255319, 0.8709825319148935, 0.29248570212765945`], 
             318 -> RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 
             238 -> RGBColor[
              0.6990478297872342, 0.7648207446808513, 0.9706382127659574], 72 -> 
             RGBColor[
              0.940857829787234, 0.9554124468085106, 0.9849964468085107], 288 -> 
             RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 
             382 -> RGBColor[
              0.8944776382978723, 0.6137294255319147, 0.23366189361702125`], 
             389 -> RGBColor[
              0.9196377234042553, 0.7190973829787233, 0.254196829787234], 172 -> 
             RGBColor[
              0.986283425531915, 0.965392914893617, 0.4012141276595744], 243 -> 
             RGBColor[
              0.986283425531915, 0.965392914893617, 0.4012141276595744], 88 -> 
             RGBColor[
              0.9328469148936169, 0.7714674255319146, 0.26482525531914886`], 
             273 -> RGBColor[
              0.9196377234042553, 0.7190973829787233, 0.254196829787234], 202 -> 
             RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             393 -> RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255317], 98 -> 
             RGBColor[
              0.9656202127659574, 0.9738801914893617, 0.9430801914893616], 30 -> 
             RGBColor[
              0.9769540638297872, 0.9339227872340425, 0.3649713191489361], 
             116 -> RGBColor[
              0.9941585744680851, 0.9899141063829787, 0.6055750638297872], 
             373 -> RGBColor[
              0.9064285319148937, 0.6667273404255321, 0.2435684042553192], 
             240 -> RGBColor[
              0.9769540638297872, 0.9339227872340425, 0.3649713191489361], 
             317 -> RGBColor[
              0.9328469148936169, 0.7714674255319146, 0.26482525531914886`], 
             391 -> RGBColor[
              0.9948681063829787, 0.9914317234042553, 0.6828032340425529], 73 -> 
             RGBColor[
              0.9460561063829787, 0.8238374680851062, 0.27545368085106375`], 
             303 -> RGBColor[
              0.8889205957446809, 0.914265170212766, 0.9892672340425532], 29 -> 
             RGBColor[
              0.9927395106382979, 0.9868788723404256, 0.45111872340425496`], 
             360 -> RGBColor[
              0.9934490425531916, 0.9883964893617022, 0.528346893617021], 320 -> 
             RGBColor[
              0.9934490425531916, 0.9883964893617022, 0.528346893617021], 75 -> 
             RGBColor[
              0.9948681063829787, 0.9914317234042553, 0.6828032340425529], 
             200 -> RGBColor[
              0.9532390212765957, 0.9646463191489362, 0.9640383191489362], 
             301 -> RGBColor[
              0.9934490425531916, 0.9883964893617022, 0.528346893617021], 156 -> 
             RGBColor[
              0.9927395106382979, 0.9868788723404256, 0.45111872340425496`], 
             25 -> RGBColor[
              0.9941585744680851, 0.9899141063829787, 0.6055750638297872], 38 -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 
             365 -> RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255317], 380 -> 
             RGBColor[
              0.9328469148936169, 0.7714674255319146, 0.26482525531914886`], 
             370 -> RGBColor[
              0.9934490425531916, 0.9883964893617022, 0.528346893617021], 3 -> 
             RGBColor[
              0.9532390212765957, 0.9646463191489362, 0.9640383191489362], 57 -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 
             227 -> RGBColor[
              0.940857829787234, 0.9554124468085106, 0.9849964468085107], 39 -> 
             RGBColor[
              0.9934490425531916, 0.9883964893617022, 0.528346893617021], 109 -> 
             RGBColor[
              0.9460561063829787, 0.8238374680851062, 0.27545368085106375`], 
             256 -> RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 
             339 -> RGBColor[
              0.9196377234042553, 0.7190973829787233, 0.254196829787234], 287 -> 
             RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 239 -> 
             RGBColor[
              0.9460561063829787, 0.8238374680851062, 0.27545368085106375`], 
             285 -> RGBColor[
              0.8593799361702127, 0.4543589574468082, 0.2043755106382978], 
             345 -> RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 
             366 -> RGBColor[
              0.9769540638297872, 0.9339227872340425, 0.3649713191489361], 
             216 -> 
             RGBColor[
              0.9941585744680851, 0.9899141063829787, 0.6055750638297872], 21 -> 
             RGBColor[
              0.9934490425531916, 0.9883964893617022, 0.528346893617021], 355 -> 
             RGBColor[
              0.9948681063829787, 0.9914317234042553, 0.6828032340425529], 
             175 -> RGBColor[
              0.9769540638297872, 0.9339227872340425, 0.3649713191489361], 7 -> 
             RGBColor[
              0.9582953404255319, 0.8709825319148935, 0.29248570212765945`], 
             13 -> RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             294 -> RGBColor[
              0.9780014042553191, 0.9831140638297873, 0.9221220638297871], 
             193 -> RGBColor[
              0.9064285319148937, 0.6667273404255321, 0.2435684042553192], 60 -> 
             RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             65 -> RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 69 -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 
             217 -> RGBColor[
              0.9328469148936169, 0.7714674255319146, 0.26482525531914886`], 
             214 -> RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 170 -> 
             RGBColor[
              0.9948681063829787, 0.9914317234042553, 0.6828032340425529], 
             359 -> RGBColor[
              0.8710791702127659, 0.5074824468085107, 0.21413763829787236`], 
             74 -> RGBColor[
              0.9934490425531916, 0.9883964893617022, 0.528346893617021], 246 -> 
             RGBColor[
              0.9532390212765957, 0.9646463191489362, 0.9640383191489362], 
             264 -> RGBColor[
              0.9780014042553191, 0.9831140638297873, 0.9221220638297871], 
             278 -> RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 45 -> 
             RGBColor[
              0.9948681063829787, 0.9914317234042553, 0.6828032340425529], 
             306 -> RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 
             237 -> RGBColor[
              0.9656202127659574, 0.9738801914893617, 0.9430801914893616], 
             228 -> RGBColor[
              0.986283425531915, 0.965392914893617, 0.4012141276595744], 180 -> 
             RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 383 -> 
             RGBColor[
              0.986283425531915, 0.965392914893617, 0.4012141276595744], 53 -> 
             RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 
             304 -> RGBColor[
              0.9328469148936169, 0.7714674255319146, 0.26482525531914886`], 
             48 -> RGBColor[
              0.9780014042553191, 0.9831140638297873, 0.9221220638297871], 5 -> 
             RGBColor[
              0.9948681063829787, 0.9914317234042553, 0.6828032340425529], 
             101 -> RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 333 -> 
             RGBColor[
              0.9941585744680851, 0.9899141063829787, 0.6055750638297872], 
             267 -> RGBColor[
              0.9941585744680851, 0.9899141063829787, 0.6055750638297872], 
             120 -> RGBColor[
              0.9934490425531916, 0.9883964893617022, 0.528346893617021], 147 -> 
             RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             89 -> RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 43 -> 
             RGBColor[
              0.9328469148936169, 0.7714674255319146, 0.26482525531914886`], 
             199 -> RGBColor[
              0.9941585744680851, 0.9899141063829787, 0.6055750638297872], 
             268 -> RGBColor[
              0.9769540638297872, 0.9339227872340425, 0.3649713191489361], 
             169 -> RGBColor[
              0.8593799361702127, 0.4543589574468082, 0.2043755106382978], 20 -> 
             RGBColor[0.42255800000000004`, 0.5404202340425532, 0.948146], 4 -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255317], 167 -> 
             RGBColor[
              0.9582953404255319, 0.8709825319148935, 0.29248570212765945`], 
             142 -> RGBColor[
              0.9582953404255319, 0.8709825319148935, 0.29248570212765945`], 
             16 -> RGBColor[
              0.7897499574468086, 0.8356779361702128, 0.9796785531914893], 
             281 -> RGBColor[
              0.9582953404255319, 0.8709825319148935, 0.29248570212765945`], 
             289 -> RGBColor[
              0.9184648510638298, 0.9378229574468085, 0.9920851914893617], 
             398 -> RGBColor[
              0.9460561063829787, 0.8238374680851062, 0.27545368085106375`], 
             178 -> RGBColor[
              0.986283425531915, 0.965392914893617, 0.4012141276595744], 58 -> 
             RGBColor[
              0.9927395106382979, 0.9868788723404256, 0.45111872340425496`], 
             186 -> 
             RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             122 -> RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 
             249 -> RGBColor[
              0.9927395106382979, 0.9868788723404256, 0.45111872340425496`], 
             113 -> RGBColor[
              0.9328469148936169, 0.7714674255319146, 0.26482525531914886`], 
             52 -> RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255317], 187 -> 
             RGBColor[
              0.9769540638297872, 0.9339227872340425, 0.3649713191489361], 
             259 -> RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 42 -> 
             RGBColor[
              0.940857829787234, 0.9554124468085106, 0.9849964468085107], 134 -> 
             RGBColor[
              0.9328469148936169, 0.7714674255319146, 0.26482525531914886`], 
             313 -> RGBColor[
              0.9460561063829787, 0.8238374680851062, 0.27545368085106375`], 
             248 -> RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 174 -> 
             RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 
             215 -> RGBColor[
              0.9656202127659574, 0.9738801914893617, 0.9430801914893616], 
             399 -> RGBColor[
              0.9941585744680851, 0.9899141063829787, 0.6055750638297872], 83 -> 
             RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             95 -> RGBColor[
              0.9934490425531916, 0.9883964893617022, 0.528346893617021], 166 -> 
             RGBColor[
              0.9941585744680851, 0.9899141063829787, 0.6055750638297872], 
             384 -> RGBColor[
              0.8944776382978723, 0.6137294255319147, 0.23366189361702125`], 
             233 -> RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 
             295 -> RGBColor[
              0.9184648510638298, 0.9378229574468085, 0.9920851914893617], 
             141 -> RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             319 -> RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255317], 205 -> 
             RGBColor[
              0.9064285319148937, 0.6667273404255321, 0.2435684042553192], 
             224 -> RGBColor[
              0.9948681063829787, 0.9914317234042553, 0.6828032340425529], 
             231 -> 
             RGBColor[
              0.940857829787234, 0.9554124468085106, 0.9849964468085107], 332 -> 
             RGBColor[
              0.9934490425531916, 0.9883964893617022, 0.528346893617021], 68 -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 10 -> 
             RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             250 -> RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             282 -> RGBColor[
              0.9769540638297872, 0.9339227872340425, 0.3649713191489361], 
             374 -> RGBColor[
              0.986283425531915, 0.965392914893617, 0.4012141276595744], 232 -> 
             RGBColor[
              0.9769540638297872, 0.9339227872340425, 0.3649713191489361], 
             253 -> RGBColor[
              0.9064285319148937, 0.6667273404255321, 0.2435684042553192], 55 -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 
             325 -> RGBColor[
              0.9927395106382979, 0.9868788723404256, 0.45111872340425496`], 
             91 -> RGBColor[
              0.9656202127659574, 0.9738801914893617, 0.9430801914893616], 
             105 -> RGBColor[
              0.9948681063829787, 0.9914317234042553, 0.6828032340425529], 36 -> 
             RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 123 -> 
             RGBColor[
              0.8278090425531914, 0.2147580638297869, 0.17426327659574464`], 
             94 -> RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 
             312 -> RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 96 -> 
             RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 2 -> 
             RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 
             262 -> RGBColor[
              0.9927395106382979, 0.9868788723404256, 0.45111872340425496`], 
             272 -> RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255317], 97 -> 
             RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 
             372 -> RGBColor[
              0.9948681063829787, 0.9914317234042553, 0.6828032340425529], 
             356 -> RGBColor[
              0.9912707234042553, 0.9906582340425532, 0.7943302340425532], 
             346 -> RGBColor[
              0.986283425531915, 0.965392914893617, 0.4012141276595744], 341 -> 
             RGBColor[
              0.9460561063829787, 0.8238374680851062, 0.27545368085106375`], 
             209 -> RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 378 -> 
             RGBColor[
              0.9934490425531916, 0.9883964893617022, 0.528346893617021], 66 -> 
             RGBColor[
              0.9927395106382979, 0.9868788723404256, 0.45111872340425496`], 
             139 -> RGBColor[
              0.8298320851063831, 0.8671495957446809, 0.9836313191489362], 56 -> 
             RGBColor[
              0.9460561063829787, 0.8238374680851062, 0.27545368085106375`], 
             335 -> RGBColor[
              0.9780014042553191, 0.9831140638297873, 0.9221220638297871], 
             314 -> RGBColor[
              0.9328469148936169, 0.7714674255319146, 0.26482525531914886`], 
             144 -> RGBColor[
              0.986283425531915, 0.965392914893617, 0.4012141276595744], 298 -> 
             RGBColor[
              0.9948681063829787, 0.9914317234042553, 0.6828032340425529], 
             204 -> RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255317], 207 -> 
             RGBColor[
              0.9780014042553191, 0.9831140638297873, 0.9221220638297871], 
             334 -> RGBColor[
              0.9780014042553191, 0.9831140638297873, 0.9221220638297871], 
             149 -> RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 219 -> 
             RGBColor[
              0.9460561063829787, 0.8238374680851062, 0.27545368085106375`], 
             400 -> RGBColor[
              0.9196377234042553, 0.7190973829787233, 0.254196829787234], 9 -> 
             RGBColor[
              0.9532390212765957, 0.9646463191489362, 0.9640383191489362], 11 -> 
             RGBColor[
              0.985607744680851, 0.9883164468085107, 0.8881804468085105], 44 -> 
             RGBColor[
              0.9941585744680851, 0.9899141063829787, 0.6055750638297872], 
             153 -> RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 32 -> 
             RGBColor[
              0.9328469148936169, 0.7714674255319146, 0.26482525531914886`], 
             162 -> RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             90 -> RGBColor[
              0.9656202127659574, 0.9738801914893617, 0.9430801914893616], 
             331 -> RGBColor[
              0.9328469148936169, 0.7714674255319146, 0.26482525531914886`], 
             8 -> 
             RGBColor[
              0.9582953404255319, 0.8709825319148935, 0.29248570212765945`], 
             364 -> RGBColor[
              0.9676247021276595, 0.9024526595744679, 0.32872851063829756`], 
             342 -> RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 
             163 -> RGBColor[
              0.9941022127659574, 0.9918291276595744, 0.7474051276595743], 49 -> 
             RGBColor[
              0.8487891276595745, 0.3760201914893615, 0.194353829787234], 338 -> 
             RGBColor[
              0.9184648510638298, 0.9378229574468085, 0.9920851914893617], 76 -> 
             RGBColor[
              0.9064285319148937, 0.6667273404255321, 0.2435684042553192], 
             369 -> RGBColor[
              0.9780014042553191, 0.9831140638297873, 0.9221220638297871], 82 -> 
             RGBColor[
              0.9941585744680851, 0.9899141063829787, 0.6055750638297872], 67 -> 
             RGBColor[
              0.9884392340425532, 0.989487340425532, 0.8412553404255317], 211 -> 
             RGBColor[
              0.9948681063829787, 0.9914317234042553, 
               0.6828032340425529]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9l2k4lWvYhs1zWMs8LNZoLbMSqfBetRslSppMScqwSaE2pQyZolBokCJT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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 14}], {
             RGBColor[
             0.8829042340425532, 0.5605431489361701, 0.2239719574468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.9260597234042554, 0.7206189148936168, 0.3277471170212764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 49}], {
             RGBColor[
             0.8540845319148935, 0.41518957446808485`, 0.1993646702127659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 62}], {
             RGBColor[0.918167, 0.6941408723404254, 0.28467341489361697`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 87}], {
             RGBColor[
             0.8769287872340426, 0.5340441914893614, 0.21901870212765953`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 119}], {
             RGBColor[
             0.9271240212765957, 0.7228953404255318, 0.4435893723404254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 127}], {
             RGBColor[
             0.9228316808510638, 0.7098759361702126, 0.30279481914893613`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 129}], {
             RGBColor[
             0.9224938404255318, 0.7213377021276595, 0.5462779787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 216}], {
             RGBColor[
             0.9267692553191489, 0.7221365319148935, 0.4049752872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 231}], {
             RGBColor[
             0.9001188829787233, 0.7048857021276593, 0.5946859787234042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 235}], {
             RGBColor[
             0.9267410744680851, 0.7230940425531913, 0.4758903191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 298}], {
             RGBColor[
             0.9271240212765957, 0.7228953404255318, 0.4435893723404254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 313}], {
             RGBColor[
             0.9027180212765957, 0.6390982127659572, 0.23991459574468077`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 317}], {
             RGBColor[
             0.8961134255319148, 0.6129131914893614, 0.23460038297872332`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 336}], {
             RGBColor[
             0.9253253297872339, 0.7225085957446806, 0.49935287234042547`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 361}], {
             RGBColor[
             0.9264144893617021, 0.7213777234042552, 0.36636120212765944`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 393}], {
             RGBColor[
             0.923909585106383, 0.7219231489361702, 0.5228154255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 396}], {
             RGBColor[0.918167, 0.6941408723404254, 0.28467341489361697`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 97}], {
             RGBColor[
             0.9926864680851064, 0.9912436808510638, 0.7708676808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 109}], {
             RGBColor[
             0.970079159574468, 0.9078332978723402, 0.511429404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 181}], {
             RGBColor[
             0.9941303936170213, 0.9908716170212766, 0.6764900957446808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 191}], {
             RGBColor[
             0.9898549787234042, 0.9900727872340426, 0.8177927872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 193}], {
             RGBColor[
             0.9502653723404255, 0.8292782340425533, 0.4954867659574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 211}], {
             RGBColor[
             0.9944851595744681, 0.9916304255319148, 0.7151041808510636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 305}], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 334}], {
             RGBColor[
             0.9860518085106382, 0.9874715957446809, 0.8347635957446807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 340}], {
             RGBColor[
             0.9941303936170213, 0.9908716170212766, 0.6764900957446808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 360}], {
             RGBColor[
             0.9937756276595745, 0.9901128085106383, 0.6378760106382977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 365}], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 370}], {
             RGBColor[
             0.9937756276595745, 0.9901128085106383, 0.6378760106382977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 11}], {
             RGBColor[
             0.9694233829787233, 0.9764813829787234, 0.9261093829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 21}], {
             RGBColor[
             0.9733440319148936, 0.9765214042553192, 0.7461926063829787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 34}], {
             RGBColor[
             0.9656202127659574, 0.9738801914893618, 0.9430801914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 74}], {
             RGBColor[
             0.9733440319148936, 0.9765214042553192, 0.7461926063829787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 86}], {
             RGBColor[
             0.9736706170212766, 0.9782377234042553, 0.8557217234042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 91}], {
             RGBColor[
             0.9594296170212766, 0.9692632553191489, 0.953559255319149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 95}], {
             RGBColor[
             0.9733440319148936, 0.9765214042553192, 0.7461926063829787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 160}], {
             RGBColor[
             0.9594296170212766, 0.9692632553191489, 0.953559255319149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[
             0.9604318617021276, 0.933549489361702, 0.646383414893617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 233}], {
             RGBColor[
             0.9736706170212766, 0.9782377234042553, 0.8557217234042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 263}], {
             RGBColor[
             0.9557671808510637, 0.9178144255319148, 0.6282620106382979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 264}], {
             RGBColor[
             0.9656202127659574, 0.9738801914893618, 0.9430801914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 285}], {
             RGBColor[
             0.9063094787234042, 0.7095026382978722, 0.5842069148936171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 312}], {
             RGBColor[
             0.9722548723404254, 0.9776522765957447, 0.8791842765957447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 348}], {
             RGBColor[
             0.9298337765957447, 0.8156868297872342, 0.6038033617021277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 13}], {
             RGBColor[0.9780319680851064, 0.94597, 0.5849919255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 66}], {
             RGBColor[
             0.9905893723404255, 0.9881831063829788, 0.6461870319148934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 123}], {
             RGBColor[
             0.9081241382978723, 0.6021227021276594, 0.5077593085106382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 131}], {
             RGBColor[
             0.9909441382978723, 0.9889419148936172, 0.6848011170212764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 140}], {
             RGBColor[
             0.9540384787234042, 0.8542923617021276, 0.5477260851063829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 183}], {
             RGBColor[0.9780319680851064, 0.94597, 0.5849919255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 186}], {
             RGBColor[0.9780319680851064, 0.94597, 0.5849919255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 188}], {
             RGBColor[
             0.9646485319148936, 0.9724498936170213, 0.9131258936170212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 203}], {
             RGBColor[
             0.9414584361702127, 0.8016083829787233, 0.5374586170212765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 232}], {
             RGBColor[
             0.9826966489361701, 0.9617050638297873, 0.603113329787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 238}], {
             RGBColor[
             0.8437435319148937, 0.8771540425531916, 0.9059467765957445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 275}], {
             RGBColor[
             0.9646485319148936, 0.9724498936170213, 0.9131258936170212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 280}], {
             RGBColor[
             0.938679914893617, 0.951876255319149, 0.9152612872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 297}], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 309}], {
             RGBColor[
             0.9770297234042553, 0.9816837659574469, 0.8921677659574467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 322}], {
             RGBColor[
             0.9909441382978723, 0.9889419148936172, 0.6848011170212764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 325}], {
             RGBColor[
             0.9905893723404255, 0.9881831063829788, 0.6461870319148934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 339}], {
             RGBColor[
             0.9540384787234042, 0.8542923617021276, 0.5477260851063829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 8}], {
             RGBColor[
             0.9765817234042553, 0.9312071276595744, 0.4876444680851062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 43}], {
             RGBColor[
             0.9638575106382978, 0.881449574468085, 0.47381424468085087`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 56}], {
             RGBColor[
             0.9704621063829787, 0.9076345957446807, 0.4791284574468083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.993069414893617, 0.9910449787234042, 0.738566734042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 90}], {
             RGBColor[
             0.9802441595744681, 0.9826559574468086, 0.8129417127659573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 100}], {
             RGBColor[
             0.9948681063829787, 0.9914317234042553, 0.6828032340425529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 121}], {
             RGBColor[
             0.9905757659574468, 0.9784123191489362, 0.5420086808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 122}], {
             RGBColor[
             0.993069414893617, 0.9910449787234042, 0.738566734042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 175}], {
             RGBColor[
             0.985911085106383, 0.9626772553191489, 0.5238872765957445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 178}], {
             RGBColor[
             0.9905757659574468, 0.9784123191489362, 0.5420086808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 213}], {
             RGBColor[
             0.9765817234042553, 0.9312071276595744, 0.4876444680851062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 227}], {
             RGBColor[
             0.9678629680851063, 0.973422085106383, 0.8338998404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 274}], {
             RGBColor[
             0.9765817234042553, 0.9312071276595744, 0.4876444680851062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 296}], {
             RGBColor[
             0.9902379255319149, 0.989874085106383, 0.7854918404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 308}], {
             RGBColor[
             0.9812464042553191, 0.9469421914893617, 0.5057658723404252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 319}], {
             RGBColor[
             0.991653670212766, 0.9904595319148937, 0.7620292872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 352}], {
             RGBColor[
             0.985911085106383, 0.9626772553191489, 0.5238872765957445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 373}], {
             RGBColor[
             0.9506483191489362, 0.8290795319148937, 0.4631858191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 56}], {
             RGBColor[
             0.9394515106382978, 0.7976524468085104, 0.2701394680851063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 79}], {
             RGBColor[
             0.9595651702127659, 0.8684301702127658, 0.3330196914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 137}], {
             RGBColor[
             0.9430429680851062, 0.8680568723404254, 0.6144317872340426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 169}], {
             RGBColor[
             0.8961134255319148, 0.6129131914893614, 0.23460038297872332`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 175}], {
             RGBColor[
             0.9549004893617021, 0.8526951063829786, 0.31489828723404245`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 178}], {
             RGBColor[
             0.9595651702127659, 0.8684301702127658, 0.3330196914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 252}], {
             RGBColor[
             0.9595651702127659, 0.8684301702127658, 0.3330196914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 277}], {
             RGBColor[
             0.9394515106382978, 0.7976524468085104, 0.2701394680851063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 278}], {
             RGBColor[
             0.9634745638297872, 0.8816482765957445, 0.5061151914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 300}], {
             RGBColor[
             0.9502358085106382, 0.8369600425531912, 0.2967768829787232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 314}], {
             RGBColor[
             0.9328469148936169, 0.7714674255319146, 0.26482525531914886`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 319}], {
             RGBColor[
             0.9606430744680851, 0.8804773829787234, 0.5530402978723403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 352}], {
             RGBColor[
             0.9549004893617021, 0.8526951063829786, 0.31489828723404245`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 379}], {
             RGBColor[
             0.9627932127659574, 0.87917314893617, 0.35797198936170194`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 65}], {
             RGBColor[
             0.9719515425531915, 0.9296494893617021, 0.590333074468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 67}], {
             RGBColor[
             0.9733672872340425, 0.9302349361702127, 0.5668705212765957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 68}], {
             RGBColor[
             0.9747830319148936, 0.9308203829787234, 0.5434079680851063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 96}], {
             RGBColor[
             0.9719515425531915, 0.9296494893617021, 0.590333074468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 173}], {
             RGBColor[
             0.9747830319148936, 0.9308203829787234, 0.5434079680851063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[
             0.9455711276595744, 0.821224978723404, 0.2786554787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 201}], {
             RGBColor[
             0.9676247021276596, 0.902452659574468, 0.3287285106382978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 223}], {
             RGBColor[
             0.9719515425531915, 0.9296494893617021, 0.590333074468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 250}], {
             RGBColor[
             0.9629600212765956, 0.8867175957446807, 0.3106071063829785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 387}], {
             RGBColor[
             0.9088358404255319, 0.8808449574468085, 0.6394674893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 43}], {
             RGBColor[
             0.9455711276595744, 0.821224978723404, 0.2786554787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 56}], {
             RGBColor[
             0.9521757234042553, 0.8474099999999998, 0.2839696914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 59}], {
             RGBColor[
             0.9747830319148936, 0.9308203829787234, 0.5434079680851063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 100}], {
             RGBColor[
             0.9765817234042553, 0.9312071276595744, 0.4876444680851062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 121}], {
             RGBColor[
             0.9722893829787234, 0.9181877234042553, 0.34684991489361694`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 175}], {
             RGBColor[
             0.9676247021276596, 0.902452659574468, 0.3287285106382978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 213}], {
             RGBColor[
             0.9582953404255319, 0.8709825319148935, 0.29248570212765945`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 227}], {
             RGBColor[
             0.9495765851063829, 0.9131974893617021, 0.638741074468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 237}], {
             RGBColor[
             0.9619577765957447, 0.9224313617021276, 0.6177829468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 296}], {
             RGBColor[
             0.9719515425531915, 0.9296494893617021, 0.590333074468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 308}], {
             RGBColor[
             0.9629600212765956, 0.8867175957446807, 0.3106071063829785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 352}], {
             RGBColor[
             0.9676247021276596, 0.902452659574468, 0.3287285106382978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 373}], {
             RGBColor[
             0.9323619361702128, 0.7688549361702128, 0.26802705319148934`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 39}], {
             RGBColor[
             0.9733440319148936, 0.9765214042553192, 0.7461926063829787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.9740535638297871, 0.9780390212765957, 0.8234207765957446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 150}], {
             RGBColor[
             0.9121590957446808, 0.7360643829787235, 0.5890879787234042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 192}], {
             RGBColor[
             0.9736706170212766, 0.9782377234042553, 0.8557217234042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 283}], {
             RGBColor[
             0.9729892659574468, 0.9757625957446809, 0.7075785212765956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 294}], {
             RGBColor[
             0.9656202127659574, 0.9738801914893618, 0.9430801914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 320}], {
             RGBColor[
             0.9733440319148936, 0.9765214042553192, 0.7461926063829787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 347}], {
             RGBColor[
             0.9557671808510637, 0.9178144255319148, 0.6282620106382979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 381}], {
             RGBColor[
             0.9740535638297871, 0.9780390212765957, 0.8234207765957446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 384}], {
             RGBColor[
             0.923858329787234, 0.7891878723404254, 0.5988501063829788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.9568404042553191, 0.8631450638297871, 0.3020910957446806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 37}], {
             RGBColor[
             0.9801821063829788, 0.9446657659574467, 0.38992361702127626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 62}], {
             RGBColor[
             0.9722893829787234, 0.9181877234042553, 0.34684991489361683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 87}], {
             RGBColor[
             0.931051170212766, 0.7580910425531913, 0.2811952021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 155}], {
             RGBColor[
             0.9135005212765956, 0.8965800212765955, 0.6575888936170211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 170}], {
             RGBColor[
             0.9812464042553191, 0.9469421914893617, 0.5057658723404252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 216}], {
             RGBColor[
             0.9808916382978723, 0.9461833829787233, 0.4671517872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 256}], {
             RGBColor[
             0.9808634574468085, 0.9471408936170211, 0.538066819148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 261}], {
             RGBColor[
             0.9805368723404255, 0.945424574468085, 0.4285377021276593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 298}], {
             RGBColor[
             0.9812464042553191, 0.9469421914893617, 0.5057658723404252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 311}], {
             RGBColor[
             0.9430447765957446, 0.9201378085106382, 0.6604068510638297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 313}], {
             RGBColor[
             0.9568404042553191, 0.8631450638297871, 0.3020910957446806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 361}], {
             RGBColor[
             0.9805368723404255, 0.945424574468085, 0.4285377021276593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 396}], {
             RGBColor[
             0.9722893829787234, 0.9181877234042553, 0.34684991489361683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 34}], {
             RGBColor[
             0.981804574468085, 0.985715255319149, 0.9051512553191488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 35}], {
             RGBColor[
             0.9400426914893616, 0.8010229361702127, 0.5609211702127659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 85}], {
             RGBColor[
             0.9766162234042552, 0.9453845531914893, 0.6084544787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 86}], {
             RGBColor[
             0.9898549787234042, 0.9900727872340426, 0.8177927872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 91}], {
             RGBColor[
             0.9756139787234042, 0.9810983191489362, 0.9156303191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 93}], {
             RGBColor[
             0.9902379255319149, 0.989874085106383, 0.7854918404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 95}], {
             RGBColor[
             0.9895283936170213, 0.9883564680851065, 0.7082636702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 125}], {
             RGBColor[
             0.9632327872340425, 0.9718644468085107, 0.9365884468085106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 162}], {
             RGBColor[
             0.9766162234042552, 0.9453845531914893, 0.6084544787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 211}], {
             RGBColor[
             0.9902379255319149, 0.989874085106383, 0.7854918404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 214}], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 248}], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 263}], {
             RGBColor[
             0.9719515425531915, 0.9296494893617021, 0.590333074468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 312}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.891926085106383, 0.9137535319148936, 0.8635418404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 17}], {
             RGBColor[
             0.9442899255319148, 0.8027792765957446, 0.4905335106382978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 22}], {
             RGBColor[
             0.9937756276595745, 0.9901128085106383, 0.6378760106382977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 47}], {
             RGBColor[
             0.9901928191489362, 0.9786110212765957, 0.5743096276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 106}], {
             RGBColor[
             0.9944851595744681, 0.9916304255319148, 0.7151041808510636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 107}], {
             RGBColor[
             0.9568699680851064, 0.8554632553191488, 0.5008009787234042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 118}], {
             RGBColor[
             0.9761987765957447, 0.931405829787234, 0.5199454148936169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 158}], {
             RGBColor[
             0.9944851595744681, 0.9916304255319148, 0.7151041808510636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 209}], {
             RGBColor[
             0.9898549787234042, 0.9900727872340426, 0.8177927872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 241}], {
             RGBColor[
             0.9941303936170213, 0.9908716170212766, 0.6764900957446808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 270}], {
             RGBColor[
             0.9926864680851064, 0.9912436808510638, 0.7708676808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 310}], {
             RGBColor[
             0.9568699680851064, 0.8554632553191488, 0.5008009787234042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 323}], {
             RGBColor[
             0.9926864680851064, 0.9912436808510638, 0.7708676808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 324}], {
             RGBColor[
             0.9736706170212766, 0.9782377234042553, 0.8557217234042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 346}], {
             RGBColor[
             0.9901928191489362, 0.9786110212765957, 0.5743096276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 390}], {
             RGBColor[
             0.9325906914893617, 0.7496557872340426, 0.48077138297872335`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 66}], {
             RGBColor[
             0.9801821063829788, 0.9446657659574467, 0.38992361702127626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 123}], {
             RGBColor[
             0.8977168723404254, 0.5586053617021274, 0.25149589361702107`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 131}], {
             RGBColor[
             0.9805368723404255, 0.945424574468085, 0.4285377021276593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[
             0.9436312127659574, 0.8107750212765956, 0.2914626702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 188}], {
             RGBColor[
             0.9542412659574467, 0.9289325531914892, 0.6568624787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 203}], {
             RGBColor[
             0.931051170212766, 0.7580910425531913, 0.2811952021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 232}], {
             RGBColor[
             0.9722893829787234, 0.9181877234042553, 0.34684991489361683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 275}], {
             RGBColor[
             0.9542412659574467, 0.9289325531914892, 0.6568624787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 280}], {
             RGBColor[
             0.9282726489361701, 0.9083589148936169, 0.6589978723404254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 297}], {
             RGBColor[
             0.9808634574468085, 0.9471408936170211, 0.538066819148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 309}], {
             RGBColor[
             0.9666224574468085, 0.9381664255319148, 0.6359043510638296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 322}], {
             RGBColor[
             0.9805368723404255, 0.945424574468085, 0.4285377021276593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 325}], {
             RGBColor[
             0.9801821063829788, 0.9446657659574467, 0.38992361702127626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 339}], {
             RGBColor[
             0.9436312127659574, 0.8107750212765956, 0.2914626702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 29}], {
             RGBColor[
             0.9495840212765958, 0.8268031063829788, 0.3473435638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 62}], {
             RGBColor[
             0.9416912978723404, 0.8003250638297873, 0.30426986170212766`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 119}], {
             RGBColor[
             0.9506483191489362, 0.8290795319148937, 0.4631858191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 126}], {
             RGBColor[
             0.9460181382978723, 0.8275218936170214, 0.5658744255319148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 127}], {
             RGBColor[
             0.9463559787234044, 0.8160601276595745, 0.3223912659574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 129}], {
             RGBColor[
             0.9460181382978723, 0.8275218936170214, 0.5658744255319148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 196}], {
             RGBColor[
             0.9506483191489362, 0.8290795319148937, 0.4631858191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 235}], {
             RGBColor[
             0.9502653723404255, 0.8292782340425533, 0.4954867659574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 317}], {
             RGBColor[
             0.9196377234042553, 0.7190973829787233, 0.254196829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 326}], {
             RGBColor[
             0.9502653723404255, 0.8292782340425533, 0.4954867659574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 327}], {
             RGBColor[
             0.9360243723404256, 0.8203037659574468, 0.5933242978723404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 336}], {
             RGBColor[
             0.9488496276595745, 0.8286927872340426, 0.5189493191489362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 396}], {
             RGBColor[
             0.9416912978723404, 0.8003250638297873, 0.30426986170212766`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 33}], {
             RGBColor[
             0.9568404042553191, 0.8631450638297871, 0.3020910957446806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 37}], {
             RGBColor[
             0.9693978085106383, 0.9053581702127659, 0.3632862021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.9615050851063829, 0.8788801276595744, 0.3202124999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 92}], {
             RGBColor[
             0.9328469148936169, 0.7714674255319147, 0.2648252553191489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 256}], {
             RGBColor[
             0.970079159574468, 0.9078332978723402, 0.511429404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 311}], {
             RGBColor[
             0.9322604787234042, 0.8808302127659573, 0.6337694361702126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 313}], {
             RGBColor[
             0.9460561063829787, 0.8238374680851062, 0.27545368085106375`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 361}], {
             RGBColor[
             0.969752574468085, 0.9061169787234042, 0.40190028723404236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 386}], {
             RGBColor[
             0.9568404042553191, 0.8631450638297871, 0.3020910957446806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 69}], {
             RGBColor[
             0.8905103404255319, 0.913168085106383, 0.8870043936170213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 106}], {
             RGBColor[
             0.8923090319148936, 0.913554829787234, 0.8312408936170211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 107}], {
             RGBColor[
             0.854693840425532, 0.777387659574468, 0.6169376914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 190}], {
             RGBColor[
             0.8905103404255319, 0.913168085106383, 0.8870043936170213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 212}], {
             RGBColor[
             0.8919542659574469, 0.9127960212765958, 0.7926268085106383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 241}], {
             RGBColor[
             0.8919542659574469, 0.9127960212765958, 0.7926268085106383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 268}], {
             RGBColor[
             0.8833520106382979, 0.8848003617021276, 0.6723249361702127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 270}], {
             RGBColor[
             0.8905103404255319, 0.913168085106383, 0.8870043936170213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 274}], {
             RGBColor[
             0.8740226489361702, 0.8533302340425531, 0.6360821276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 295}], {
             RGBColor[
             0.8541074042553192, 0.8867504468085107, 0.9858818723404255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 310}], {
             RGBColor[
             0.854693840425532, 0.777387659574468, 0.6169376914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 324}], {
             RGBColor[
             0.8714944893617022, 0.9001621276595745, 0.9718584361702127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 351}], {
             RGBColor[
             0.8653038936170213, 0.8955451914893617, 0.9823375000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 373}], {
             RGBColor[
             0.8480892446808512, 0.7512026382978725, 0.6116234787234043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 380}], {
             RGBColor[
             0.8612984361702127, 0.8035726808510637, 0.6222519042553191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 390}], {
             RGBColor[
             0.8304145638297873, 0.6715801914893618, 0.5969080957446808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 22}], {
             RGBColor[
             0.9439633404255319, 0.8010629574468084, 0.3810043936170211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 48}], {
             RGBColor[
             0.9362395212765957, 0.798421744680851, 0.5778919787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 61}], {
             RGBColor[
             0.9263864893617021, 0.7423559787234041, 0.26307379787234036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 118}], {
             RGBColor[
             0.9263864893617021, 0.7423559787234041, 0.26307379787234036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 158}], {
             RGBColor[
             0.9446728723404255, 0.802580574468085, 0.45823256382978705`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 164}], {
             RGBColor[
             0.9202668723404255, 0.7187834468085104, 0.2545577872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 173}], {
             RGBColor[
             0.9428741808510638, 0.802193829787234, 0.5139960638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 209}], {
             RGBColor[
             0.9400426914893616, 0.8010229361702127, 0.5609211702127659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 241}], {
             RGBColor[
             0.9443181063829786, 0.8018217659574467, 0.4196184787234042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 287}], {
             RGBColor[
             0.9400426914893616, 0.8010229361702127, 0.5609211702127659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 323}], {
             RGBColor[
             0.9428741808510638, 0.802193829787234, 0.5139960638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 346}], {
             RGBColor[
             0.9403805319148937, 0.7895611702127658, 0.31743801063829785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 354}], {
             RGBColor[
             0.9436085744680851, 0.8003041489361702, 0.3423903085106381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 371}], {
             RGBColor[
             0.9428741808510638, 0.802193829787234, 0.5139960638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 388}], {
             RGBColor[
             0.931051170212766, 0.7580910425531913, 0.2811952021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 389}], {
             RGBColor[
             0.9070576808510638, 0.6664134042553189, 0.24392936170212765`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 45}], {
             RGBColor[
             0.9765817234042553, 0.9312071276595744, 0.4876444680851062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 74}], {
             RGBColor[
             0.9758721914893618, 0.9296895106382979, 0.41041629787234024`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 86}], {
             RGBColor[
             0.9761987765957447, 0.931405829787234, 0.5199454148936169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 91}], {
             RGBColor[
             0.9619577765957447, 0.9224313617021276, 0.6177829468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 112}], {
             RGBColor[
             0.9765817234042553, 0.9312071276595744, 0.4876444680851062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 141}], {
             RGBColor[
             0.9629600212765956, 0.8867175957446807, 0.3106071063829785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 148}], {
             RGBColor[
             0.9495765851063829, 0.9131974893617021, 0.638741074468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 179}], {
             RGBColor[
             0.9755174255319149, 0.9289307021276596, 0.3718022127659572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 232}], {
             RGBColor[
             0.9676247021276596, 0.902452659574468, 0.3287285106382978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 257}], {
             RGBColor[
             0.9719515425531915, 0.9296494893617021, 0.590333074468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 279}], {
             RGBColor[
             0.9323619361702128, 0.7688549361702128, 0.26802705319148934`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 285}], {
             RGBColor[
             0.9088376382978722, 0.6626707446808509, 0.24843060638297865`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 288}], {
             RGBColor[
             0.9761987765957447, 0.931405829787234, 0.5199454148936169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 399}], {
             RGBColor[
             0.9762269574468085, 0.9304483191489361, 0.44903038297872333`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 185}], {
             RGBColor[
             0.9183496914893616, 0.7406813191489362, 0.578608914893617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 198}], {
             RGBColor[
             0.9784454680851064, 0.9822692127659574, 0.8687052127659574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 205}], {
             RGBColor[
             0.9360243723404256, 0.8203037659574468, 0.5933242978723404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 219}], {
             RGBColor[
             0.955838159574468, 0.898858829787234, 0.6092669361702127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 262}], {
             RGBColor[
             0.9791798617021277, 0.9803795319148936, 0.6970994574468083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 284}], {
             RGBColor[
             0.9619577765957447, 0.9224313617021276, 0.6177829468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 293}], {
             RGBColor[
             0.9718108085106383, 0.9784971276595744, 0.9326011276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 331}], {
             RGBColor[
             0.9492335638297872, 0.8726738085106381, 0.6039527234042552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 338}], {
             RGBColor[
             0.9420425319148936, 0.9558515744680851, 0.9675826914893617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.6950913510638297, 0.7214364468085106, 0.6384372553191489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 36}], {
             RGBColor[
             0.7040828723404255, 0.7643683404255319, 0.9181632234042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 80}], {
             RGBColor[
             0.7040828723404255, 0.7643683404255319, 0.9181632234042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 151}], {
             RGBColor[
             0.6710978617021277, 0.6297588085106383, 0.601171414893617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 168}], {
             RGBColor[
             0.6817079148936169, 0.7479163404255319, 0.9665712234042554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 265}], {
             RGBColor[
             0.7080035212765958, 0.7644083617021278, 0.7382464468085106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 291}], {
             RGBColor[
             0.6997560319148937, 0.7371715106382979, 0.6565586595744681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 304}], {
             RGBColor[
             0.6777024574468085, 0.655943829787234, 0.6064856276595745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 378}], {
             RGBColor[
             0.7080035212765958, 0.7644083617021278, 0.7382464468085106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 383}], {
             RGBColor[
             0.7044207127659574, 0.7529065744680852, 0.6746800638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 24}], {
             RGBColor[
             0.969752574468085, 0.9061169787234042, 0.40190028723404236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 25}], {
             RGBColor[
             0.9938038085106383, 0.9891552978723405, 0.5669609787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 27}], {
             RGBColor[
             0.9923598829787235, 0.9895273617021276, 0.6613385638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 32}], {
             RGBColor[
             0.9631479787234043, 0.8799319574468084, 0.3965860744680849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 78}], {
             RGBColor[
             0.9805368723404255, 0.945424574468085, 0.4285377021276593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 95}], {
             RGBColor[
             0.9934490425531916, 0.9883964893617022, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 104}], {
             RGBColor[
             0.9857252234042553, 0.9857552765957447, 0.7252344787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 160}], {
             RGBColor[
             0.9795346276595744, 0.9811383404255319, 0.7357135425531913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 172}], {
             RGBColor[
             0.9898662340425533, 0.9768947021276596, 0.46478051063829773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 208}], {
             RGBColor[
             0.9941585744680852, 0.9899141063829788, 0.605575063829787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 217}], {
             RGBColor[
             0.9631479787234043, 0.8799319574468084, 0.3965860744680849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 230}], {
             RGBColor[
             0.9322641063829787, 0.7479394680851065, 0.3712422659574467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 233}], {
             RGBColor[
             0.9937756276595745, 0.9901128085106383, 0.6378760106382977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 240}], {
             RGBColor[
             0.9852015531914894, 0.9611596382978724, 0.44665910638297857`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 242}], {
             RGBColor[
             0.9805368723404255, 0.945424574468085, 0.4285377021276593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 244}], {
             RGBColor[
             0.9758721914893618, 0.9296895106382979, 0.41041629787234024`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 264}], {
             RGBColor[
             0.9857252234042553, 0.9857552765957447, 0.7252344787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 285}], {
             RGBColor[
             0.9264144893617021, 0.7213777234042552, 0.36636120212765944`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 357}], {
             RGBColor[
             0.9439633404255319, 0.8010629574468084, 0.38100439361702115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 47}], {
             RGBColor[
             0.9898662340425533, 0.9768947021276596, 0.46478051063829773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.9857252234042553, 0.9857552765957447, 0.7252344787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 96}], {
             RGBColor[
             0.9895283936170213, 0.9883564680851065, 0.7082636702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 118}], {
             RGBColor[
             0.9758721914893618, 0.9296895106382979, 0.41041629787234024`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 158}], {
             RGBColor[
             0.9941585744680852, 0.9899141063829788, 0.605575063829787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 173}], {
             RGBColor[
             0.9923598829787235, 0.9895273617021276, 0.6613385638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 209}], {
             RGBColor[
             0.9895283936170213, 0.9883564680851065, 0.7082636702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 241}], {
             RGBColor[
             0.9938038085106383, 0.9891552978723405, 0.5669609787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 310}], {
             RGBColor[
             0.9565433829787234, 0.8537469361702128, 0.3912718617021275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 323}], {
             RGBColor[
             0.9923598829787235, 0.9895273617021276, 0.6613385638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 346}], {
             RGBColor[
             0.9898662340425533, 0.9768947021276596, 0.46478051063829773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 354}], {
             RGBColor[
             0.9930942765957447, 0.9876376808510638, 0.489732808510638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 388}], {
             RGBColor[
             0.9805368723404255, 0.945424574468085, 0.4285377021276593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 75}], {
             RGBColor[
             0.9944851595744681, 0.9916304255319148, 0.7151041808510636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 120}], {
             RGBColor[
             0.9937756276595745, 0.9901128085106383, 0.6378760106382977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 132}], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 160}], {
             RGBColor[
             0.9798612127659574, 0.982854659574468, 0.845242659574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 202}], {
             RGBColor[
             0.9808634574468085, 0.9471408936170211, 0.538066819148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 220}], {
             RGBColor[
             0.9761987765957447, 0.931405829787234, 0.5199454148936169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 229}], {
             RGBColor[
             0.9808634574468085, 0.9471408936170211, 0.538066819148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 260}], {
             RGBColor[
             0.9674800212765957, 0.9736207872340426, 0.8662007872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 307}], {
             RGBColor[
             0.9937756276595745, 0.9901128085106383, 0.6378760106382977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 321}], {
             RGBColor[
             0.9267410744680851, 0.7230940425531913, 0.4758903191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 341}], {
             RGBColor[
             0.970079159574468, 0.9078332978723402, 0.511429404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 348}], {
             RGBColor[
             0.9502653723404255, 0.8292782340425533, 0.4954867659574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 366}], {
             RGBColor[
             0.9855281382978723, 0.9628759574468084, 0.5561882234042552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.968663414893617, 0.9072478510638297, 0.5348919574468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 32}], {
             RGBColor[
             0.9394515106382978, 0.7976524468085104, 0.2701394680851063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 73}], {
             RGBColor[
             0.9460561063829787, 0.8238374680851062, 0.27545368085106375`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.969752574468085, 0.9061169787234042, 0.40190028723404236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 78}], {
             RGBColor[
             0.9568404042553191, 0.8631450638297871, 0.3020910957446806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 104}], {
             RGBColor[
             0.9620287553191489, 0.9034757659574467, 0.5987878723404254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 112}], {
             RGBColor[
             0.9704621063829787, 0.9076345957446807, 0.4791284574468083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 141}], {
             RGBColor[
             0.9568404042553191, 0.8631450638297871, 0.3020910957446806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 172}], {
             RGBColor[
             0.9661697659574469, 0.8946151914893616, 0.33833390425531906`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 208}], {
             RGBColor[
             0.9704621063829787, 0.9076345957446807, 0.4791284574468083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 240}], {
             RGBColor[
             0.9615050851063829, 0.8788801276595744, 0.3202124999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 242}], {
             RGBColor[
             0.9568404042553191, 0.8631450638297871, 0.3020910957446806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 243}], {
             RGBColor[
             0.9661697659574469, 0.8946151914893616, 0.33833390425531906`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 285}], {
             RGBColor[
             0.9027180212765957, 0.6390982127659572, 0.23991459574468077`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 337}], {
             RGBColor[
             0.9496475638297872, 0.8942418936170211, 0.6197459999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 357}], {
             RGBColor[
             0.9202668723404255, 0.7187834468085104, 0.2545577872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 399}], {
             RGBColor[
             0.9701073404255318, 0.9068757872340425, 0.44051437234042545`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 32}], {
             RGBColor[
             0.9635027446808511, 0.8806907659574467, 0.435200159574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 78}], {
             RGBColor[
             0.9808916382978723, 0.9461833829787233, 0.4671517872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 83}], {
             RGBColor[
             0.9808916382978723, 0.9461833829787233, 0.4671517872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 194}], {
             RGBColor[
             0.9635027446808511, 0.8806907659574467, 0.435200159574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 201}], {
             RGBColor[
             0.9855563191489362, 0.9619184468085107, 0.48527319148936165`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 217}], {
             RGBColor[
             0.9635027446808511, 0.8806907659574467, 0.435200159574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 223}], {
             RGBColor[
             0.989883159574468, 0.9891152765957447, 0.7468777553191488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 230}], {
             RGBColor[
             0.9326188723404255, 0.7486982765957447, 0.4098563510638298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 242}], {
             RGBColor[
             0.9808916382978723, 0.9461833829787233, 0.4671517872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 244}], {
             RGBColor[
             0.9762269574468085, 0.9304483191489361, 0.44903038297872333`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 245}], {
             RGBColor[
             0.9119953297872341, 0.9285318510638298, 0.7946031914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 328}], {
             RGBColor[
             0.9762269574468085, 0.9304483191489361, 0.44903038297872333`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 357}], {
             RGBColor[
             0.9443181063829786, 0.8018217659574467, 0.41961847872340424`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 364}], {
             RGBColor[
             0.9808916382978723, 0.9461833829787233, 0.4671517872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 385}], {
             RGBColor[
             0.986079989361702, 0.9865140851063829, 0.7638485638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 105}], {
             RGBColor[
             0.9566664787234043, 0.9646273404255319, 0.8374442127659574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 128}], {
             RGBColor[
             0.906471244680851, 0.7757761914893616, 0.6128735425531915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 159}], {
             RGBColor[
             0.9520362978723405, 0.9630697021276596, 0.9401328191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 171}], {
             RGBColor[
             0.9430447765957446, 0.9201378085106382, 0.6604068510638297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 215}], {
             RGBColor[
             0.9420425319148936, 0.9558515744680851, 0.9675826914893617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 218}], {
             RGBColor[
             0.9036927234042553, 0.9260440638297873, 0.9906762127659574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 342}], {
             RGBColor[
             0.9562835319148937, 0.9648260425531915, 0.8697451595744681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 349}], {
             RGBColor[
             0.9296613404255318, 0.9466177021276596, 0.9885408191489362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 353}], {
             RGBColor[
             0.9520362978723405, 0.9630697021276596, 0.9401328191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 32}], {
             RGBColor[
             0.9620588191489361, 0.8810628297872338, 0.5295777446808511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 73}], {
             RGBColor[
             0.968663414893617, 0.9072478510638297, 0.5348919574468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 74}], {
             RGBColor[
             0.9923598829787235, 0.9895273617021276, 0.6613385638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 78}], {
             RGBColor[
             0.9794477127659573, 0.9465554468085104, 0.5615293723404253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 104}], {
             RGBColor[
             0.9846360638297872, 0.9868861489361702, 0.8582261489361702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 112}], {
             RGBColor[
             0.993069414893617, 0.9910449787234042, 0.738566734042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 141}], {
             RGBColor[
             0.9794477127659573, 0.9465554468085104, 0.5615293723404253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 172}], {
             RGBColor[
             0.988777074468085, 0.978025574468085, 0.5977721808510639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 208}], {
             RGBColor[
             0.993069414893617, 0.9910449787234042, 0.738566734042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 225}], {
             RGBColor[
             0.9794477127659573, 0.9465554468085104, 0.5615293723404253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 240}], {
             RGBColor[
             0.9841123936170213, 0.9622905106382978, 0.5796507765957446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 243}], {
             RGBColor[
             0.988777074468085, 0.978025574468085, 0.5977721808510639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 285}], {
             RGBColor[
             0.9253253297872339, 0.7225085957446806, 0.4993528723404255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 337}], {
             RGBColor[
             0.9722548723404254, 0.9776522765957447, 0.8791842765957447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 357}], {
             RGBColor[
             0.9428741808510638, 0.802193829787234, 0.5139960638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 399}], {
             RGBColor[
             0.9927146489361702, 0.9902861702127659, 0.6999526489361703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 36}], {
             RGBColor[
             0.9766162234042552, 0.9453845531914893, 0.6084544787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 151}], {
             RGBColor[
             0.9436312127659574, 0.8107750212765956, 0.2914626702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 168}], {
             RGBColor[
             0.9542412659574467, 0.9289325531914892, 0.6568624787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 265}], {
             RGBColor[
             0.9805368723404255, 0.945424574468085, 0.4285377021276593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 267}], {
             RGBColor[
             0.9808916382978723, 0.9461833829787233, 0.4671517872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 282}], {
             RGBColor[
             0.9722893829787234, 0.9181877234042553, 0.34684991489361683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 291}], {
             RGBColor[
             0.9722893829787234, 0.9181877234042553, 0.34684991489361683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 304}], {
             RGBColor[
             0.9502358085106382, 0.8369600425531912, 0.2967768829787232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 378}], {
             RGBColor[
             0.9805368723404255, 0.945424574468085, 0.4285377021276593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 383}], {
             RGBColor[
             0.9769540638297872, 0.9339227872340424, 0.364971319148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.9848467872340425, 0.9604008297872341, 0.40804502127659553`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 87}], {
             RGBColor[
             0.9436085744680851, 0.8003041489361702, 0.3423903085106381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 119}], {
             RGBColor[
             0.9938038085106383, 0.9891552978723405, 0.566960978723404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 127}], {
             RGBColor[
             0.9895114680851065, 0.9761358936170212, 0.4261664255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 129}], {
             RGBColor[
             0.9891736276595744, 0.9875976595744682, 0.6696495851063827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 231}], {
             RGBColor[
             0.966798670212766, 0.9711456595744681, 0.7180575851063828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 235}], {
             RGBColor[
             0.9934208617021276, 0.9893540000000001, 0.5992619255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 317}], {
             RGBColor[
             0.9627932127659574, 0.87917314893617, 0.35797198936170194`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 326}], {
             RGBColor[
             0.9934208617021276, 0.9893540000000001, 0.5992619255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 327}], {
             RGBColor[
             0.9791798617021277, 0.9803795319148936, 0.6970994574468083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 336}], {
             RGBColor[
             0.9920051170212766, 0.9887685531914894, 0.6227244787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 396}], {
             RGBColor[
             0.9848467872340425, 0.9604008297872341, 0.40804502127659553`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 54}], {
             RGBColor[
             0.8971365319148936, 0.5340248936170213, 0.26459465957446804`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 63}], {
             RGBColor[
             0.985911085106383, 0.9626772553191489, 0.5238872765957445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 224}], {
             RGBColor[
             0.985911085106383, 0.9626772553191489, 0.5238872765957445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 297}], {
             RGBColor[
             0.9855281382978723, 0.9628759574468084, 0.5561882234042552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 318}], {
             RGBColor[
             0.9855281382978723, 0.9628759574468084, 0.5561882234042552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 345}], {
             RGBColor[
             0.9841123936170213, 0.9622905106382978, 0.5796507765957446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 81}], {
             RGBColor[
             0.9898549787234042, 0.9900727872340426, 0.8177927872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 106}], {
             RGBColor[
             0.993069414893617, 0.9910449787234042, 0.738566734042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 164}], {
             RGBColor[
             0.968663414893617, 0.9072478510638297, 0.5348919574468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 192}], {
             RGBColor[
             0.9926864680851064, 0.9912436808510638, 0.7708676808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 241}], {
             RGBColor[
             0.9927146489361702, 0.9902861702127659, 0.6999526489361703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 271}], {
             RGBColor[
             0.9794477127659573, 0.9465554468085104, 0.5615293723404253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 287}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 292}], {
             RGBColor[
             0.9253235319148936, 0.9406828085106382, 0.8903897553191489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 371}], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 374}], {
             RGBColor[
             0.988777074468085, 0.978025574468085, 0.5977721808510639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 382}], {
             RGBColor[
             0.9428741808510638, 0.802193829787234, 0.5139960638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 384}], {
             RGBColor[
             0.9428741808510638, 0.802193829787234, 0.5139960638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 389}], {
             RGBColor[
             0.9554542234042553, 0.8548778085106382, 0.5242635319148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 78}], {
             RGBColor[
             0.9502358085106382, 0.8369600425531912, 0.2967768829787232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 104}], {
             RGBColor[
             0.955424159574468, 0.8772907446808509, 0.5934736595744681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 172}], {
             RGBColor[
             0.9595651702127659, 0.8684301702127658, 0.3330196914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 194}], {
             RGBColor[
             0.9328469148936169, 0.7714674255319146, 0.26482525531914886`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 208}], {
             RGBColor[
             0.9638575106382978, 0.881449574468085, 0.47381424468085087`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 217}], {
             RGBColor[
             0.9328469148936169, 0.7714674255319146, 0.26482525531914886`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 223}], {
             RGBColor[
             0.959227329787234, 0.8798919361702127, 0.5765028510638297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 230}], {
             RGBColor[
             0.9019630425531915, 0.6394749361702127, 0.2394814468085106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 240}], {
             RGBColor[
             0.9549004893617021, 0.8526951063829786, 0.31489828723404245`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 242}], {
             RGBColor[
             0.9502358085106382, 0.8369600425531912, 0.2967768829787232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 357}], {
             RGBColor[
             0.9136622765957446, 0.6925984255319146, 0.24924357446808504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 364}], {
             RGBColor[
             0.9502358085106382, 0.8369600425531912, 0.2967768829787232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 385}], {
             RGBColor[
             0.955424159574468, 0.8772907446808509, 0.5934736595744681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 387}], {
             RGBColor[
             0.8961116276595744, 0.8310874042553189, 0.6256372659574467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 92}], {
             RGBColor[
             0.9436312127659574, 0.8107750212765956, 0.2914626702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 182}], {
             RGBColor[
             0.931051170212766, 0.7580910425531913, 0.2811952021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 256}], {
             RGBColor[
             0.9808634574468085, 0.9471408936170211, 0.538066819148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 281}], {
             RGBColor[
             0.9629600212765956, 0.8867175957446807, 0.3106071063829785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 311}], {
             RGBColor[
             0.9430447765957446, 0.9201378085106382, 0.6604068510638297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 35}], {
             RGBColor[
             0.9362395212765957, 0.798421744680851, 0.5778919787234043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 85}], {
             RGBColor[
             0.9728130531914894, 0.9427833617021275, 0.6254252872340423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 86}], {
             RGBColor[
             0.9860518085106382, 0.9874715957446809, 0.8347635957446807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 91}], {
             RGBColor[
             0.9718108085106383, 0.9784971276595744, 0.9326011276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 93}], {
             RGBColor[
             0.9864347553191489, 0.9872728936170213, 0.80246264893617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 95}], {
             RGBColor[
             0.9857252234042553, 0.9857552765957447, 0.7252344787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 125}], {
             RGBColor[
             0.9594296170212766, 0.9692632553191489, 0.953559255319149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 162}], {
             RGBColor[
             0.9728130531914894, 0.9427833617021275, 0.6254252872340423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 211}], {
             RGBColor[
             0.9864347553191489, 0.9872728936170213, 0.80246264893617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 214}], {
             RGBColor[
             0.981804574468085, 0.985715255319149, 0.9051512553191488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 248}], {
             RGBColor[
             0.981804574468085, 0.985715255319149, 0.9051512553191488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 263}], {
             RGBColor[
             0.9681483723404255, 0.9270482978723404, 0.6073038829787233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 340}], {
             RGBColor[
             0.986079989361702, 0.9865140851063829, 0.7638485638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 42}], {
             RGBColor[
             0.9176677340425532, 0.7845709361702127, 0.609329170212766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 85}], {
             RGBColor[
             0.931051170212766, 0.7580910425531913, 0.2811952021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 86}], {
             RGBColor[
             0.9442899255319148, 0.8027792765957446, 0.49053351063829775`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 93}], {
             RGBColor[
             0.9446728723404255, 0.802580574468085, 0.45823256382978705`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 97}], {
             RGBColor[
             0.9428741808510638, 0.802193829787234, 0.5139960638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 98}], {
             RGBColor[
             0.9300489255319149, 0.7938048085106382, 0.5883710425531914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 125}], {
             RGBColor[
             0.9176677340425532, 0.7845709361702127, 0.609329170212766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 162}], {
             RGBColor[
             0.931051170212766, 0.7580910425531913, 0.2811952021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 211}], {
             RGBColor[
             0.9446728723404255, 0.802580574468085, 0.45823256382978705`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 214}], {
             RGBColor[
             0.9400426914893616, 0.8010229361702127, 0.5609211702127659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 248}], {
             RGBColor[
             0.9400426914893616, 0.8010229361702127, 0.5609211702127659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 263}], {
             RGBColor[
             0.9263864893617021, 0.7423559787234041, 0.26307379787234036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 340}], {
             RGBColor[
             0.9443181063829786, 0.8018217659574467, 0.4196184787234042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 80}], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 151}], {
             RGBColor[
             0.9526227340425532, 0.8537069148936169, 0.5711886382978723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 168}], {
             RGBColor[
             0.9632327872340425, 0.9718644468085107, 0.9365884468085106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 265}], {
             RGBColor[
             0.9895283936170213, 0.9883564680851065, 0.7082636702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 277}], {
             RGBColor[
             0.9658319255319148, 0.9060769574468084, 0.5818170638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 304}], {
             RGBColor[
             0.959227329787234, 0.8798919361702127, 0.5765028510638297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 378}], {
             RGBColor[
             0.9895283936170213, 0.9883564680851065, 0.7082636702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 383}], {
             RGBColor[
             0.985945585106383, 0.9768546808510639, 0.6446972872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 41}], {
             RGBColor[
             0.9927395106382979, 0.9868788723404256, 0.45111872340425496`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 114}], {
             RGBColor[
             0.9895114680851065, 0.9761358936170212, 0.4261664255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 170}], {
             RGBColor[
             0.9938038085106383, 0.9891552978723405, 0.566960978723404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 187}], {
             RGBColor[
             0.9848467872340425, 0.9604008297872341, 0.40804502127659553`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 206}], {
             RGBColor[
             0.9930942765957447, 0.9876376808510638, 0.489732808510638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 256}], {
             RGBColor[
             0.9934208617021276, 0.9893540000000001, 0.5992619255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 261}], {
             RGBColor[
             0.9930942765957447, 0.9876376808510638, 0.489732808510638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 311}], {
             RGBColor[
             0.9556021808510639, 0.9623509148936171, 0.7216019574468083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 361}], {
             RGBColor[
             0.9930942765957447, 0.9876376808510638, 0.489732808510638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 53}], {
             RGBColor[
             0.9926864680851064, 0.9912436808510638, 0.7708676808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 58}], {
             RGBColor[
             0.9920051170212766, 0.9887685531914894, 0.6227244787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 102}], {
             RGBColor[
             0.9926864680851064, 0.9912436808510638, 0.7708676808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 103}], {
             RGBColor[
             0.9488496276595745, 0.8286927872340426, 0.5189493191489363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 117}], {
             RGBColor[
             0.9794477127659573, 0.9465554468085104, 0.5615293723404253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 145}], {
             RGBColor[
             0.968663414893617, 0.9072478510638297, 0.5348919574468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 189}], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 222}], {
             RGBColor[
             0.9747830319148936, 0.9308203829787234, 0.5434079680851063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 254}], {
             RGBColor[
             0.9898549787234042, 0.9900727872340426, 0.8177927872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 303}], {
             RGBColor[
             0.9400956595744681, 0.9524617021276596, 0.8917987340425533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 376}], {
             RGBColor[
             0.9920051170212766, 0.9887685531914894, 0.6227244787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 150}], {
             RGBColor[
             0.9322641063829787, 0.7479394680851065, 0.3712422659574467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 237}], {
             RGBColor[
             0.9795346276595744, 0.9811383404255319, 0.7357135425531913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 251}], {
             RGBColor[
             0.9559569468085107, 0.9631097234042554, 0.7602160425531914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 283}], {
             RGBColor[
             0.9930942765957447, 0.9876376808510638, 0.489732808510638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 294}], {
             RGBColor[
             0.9857252234042553, 0.9857552765957447, 0.7252344787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 320}], {
             RGBColor[
             0.9934490425531916, 0.9883964893617022, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 347}], {
             RGBColor[
             0.9758721914893618, 0.9296895106382979, 0.41041629787234024`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 381}], {
             RGBColor[
             0.9941585744680852, 0.9899141063829788, 0.605575063829787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 51}], {
             RGBColor[
             0.9606430744680851, 0.8804773829787234, 0.5530402978723403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 84}], {
             RGBColor[
             0.987023489361702, 0.9889018936170213, 0.8647178936170211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 102}], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 134}], {
             RGBColor[
             0.9606430744680851, 0.8804773829787234, 0.5530402978723403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 163}], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 167}], {
             RGBColor[
             0.9733672872340425, 0.9302349361702127, 0.5668705212765957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 174}], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 183}], {
             RGBColor[0.9780319680851064, 0.94597, 0.5849919255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 189}], {
             RGBColor[
             0.9898549787234042, 0.9900727872340426, 0.8177927872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 226}], {
             RGBColor[
             0.987023489361702, 0.9889018936170213, 0.8647178936170211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 234}], {
             RGBColor[
             0.9646485319148936, 0.9724498936170213, 0.9131258936170212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 246}], {
             RGBColor[
             0.9708391276595745, 0.977066829787234, 0.902646829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 269}], {
             RGBColor[
             0.9912989042553191, 0.9897007234042554, 0.7234152021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 272}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 350}], {
             RGBColor[
             0.9826966489361701, 0.9617050638297873, 0.603113329787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 355}], {
             RGBColor[
             0.991653670212766, 0.9904595319148937, 0.7620292872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 392}], {
             RGBColor[
             0.5836831170212766, 0.647440670212766, 0.8873781702127659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 395}], {
             RGBColor[
             0.9898549787234042, 0.9900727872340426, 0.8177927872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 55}], {
             RGBColor[
             0.9920051170212766, 0.9887685531914894, 0.6227244787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 83}], {
             RGBColor[
             0.9801821063829788, 0.9446657659574467, 0.38992361702127626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.9561886170212766, 0.8529881276595744, 0.3526577765957445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 135}], {
             RGBColor[
             0.9934208617021276, 0.9893540000000001, 0.5992619255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 156}], {
             RGBColor[
             0.9927395106382979, 0.9868788723404256, 0.45111872340425496`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 165}], {
             RGBColor[
             0.9895114680851065, 0.9761358936170212, 0.4261664255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 187}], {
             RGBColor[
             0.9848467872340425, 0.9604008297872341, 0.40804502127659553`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 206}], {
             RGBColor[
             0.9930942765957447, 0.9876376808510638, 0.489732808510638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 245}], {
             RGBColor[
             0.9112857978723405, 0.9270142340425532, 0.7173750212765956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 256}], {
             RGBColor[
             0.9934208617021276, 0.9893540000000001, 0.5992619255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 311}], {
             RGBColor[
             0.9556021808510639, 0.9623509148936171, 0.7216019574468083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 328}], {
             RGBColor[
             0.9755174255319149, 0.9289307021276596, 0.3718022127659572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 386}], {
             RGBColor[
             0.9801821063829788, 0.9446657659574467, 0.38992361702127626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 400}], {
             RGBColor[
             0.9561886170212766, 0.8529881276595744, 0.3526577765957445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 45}], {
             RGBColor[
             0.9678629680851063, 0.973422085106383, 0.8338998404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 93}], {
             RGBColor[
             0.9678629680851063, 0.973422085106383, 0.8338998404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 98}], {
             RGBColor[
             0.9532390212765958, 0.9646463191489361, 0.9640383191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 125}], {
             RGBColor[
             0.940857829787234, 0.9554124468085106, 0.9849964468085107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 139}], {
             RGBColor[
             0.8853449574468085, 0.9112810212765957, 0.9843138829787235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 148}], {
             RGBColor[
             0.940857829787234, 0.9554124468085106, 0.9849964468085107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 204}], {
             RGBColor[
             0.9646485319148936, 0.9724498936170213, 0.9131258936170212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 248}], {
             RGBColor[
             0.9632327872340425, 0.9718644468085107, 0.9365884468085106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 275}], {
             RGBColor[
             0.940857829787234, 0.9554124468085106, 0.9849964468085107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 276}], {
             RGBColor[
             0.9001170851063829, 0.9230599148936169, 0.9857228617021276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 288}], {
             RGBColor[
             0.9674800212765957, 0.9736207872340426, 0.8662007872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 290}], {
             RGBColor[
             0.9542412659574467, 0.9289325531914892, 0.6568624787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 318}], {
             RGBColor[
             0.9674800212765957, 0.9736207872340426, 0.8662007872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 56}], {
             RGBColor[
             0.9394515106382978, 0.7976524468085104, 0.2701394680851063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 59}], {
             RGBColor[
             0.9620588191489361, 0.8810628297872338, 0.529577744680851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[
             0.9492335638297872, 0.8726738085106381, 0.6039527234042552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 121}], {
             RGBColor[
             0.9595651702127659, 0.8684301702127658, 0.3330196914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 122}], {
             RGBColor[
             0.9620588191489361, 0.8810628297872338, 0.529577744680851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 175}], {
             RGBColor[
             0.9549004893617021, 0.8526951063829786, 0.31489828723404245`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 213}], {
             RGBColor[
             0.9455711276595744, 0.821224978723404, 0.2786554787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 227}], {
             RGBColor[
             0.9368523723404254, 0.8634399361702125, 0.6249108510638297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 237}], {
             RGBColor[
             0.9492335638297872, 0.8726738085106381, 0.6039527234042552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 274}], {
             RGBColor[
             0.9455711276595744, 0.821224978723404, 0.2786554787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 296}], {
             RGBColor[
             0.959227329787234, 0.8798919361702127, 0.5765028510638297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 308}], {
             RGBColor[
             0.9502358085106382, 0.8369600425531912, 0.2967768829787232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 373}], {
             RGBColor[
             0.9196377234042553, 0.7190973829787233, 0.254196829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 380}], {
             RGBColor[
             0.9328469148936169, 0.7714674255319146, 0.26482525531914886`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 46}], {
             RGBColor[
             0.9912989042553191, 0.9897007234042554, 0.7234152021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 65}], {
             RGBColor[
             0.989883159574468, 0.9891152765957447, 0.7468777553191488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 68}], {
             RGBColor[
             0.9927146489361702, 0.9902861702127659, 0.6999526489361703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 113}], {
             RGBColor[
             0.9635027446808511, 0.8806907659574467, 0.435200159574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 149}], {
             RGBColor[
             0.989883159574468, 0.9891152765957447, 0.7468777553191488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 161}], {
             RGBColor[
             0.986079989361702, 0.9865140851063829, 0.7638485638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 195}], {
             RGBColor[
             0.994513340425532, 0.9906729148936171, 0.6441891489361701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 247}], {
             RGBColor[
             0.989883159574468, 0.9891152765957447, 0.7468777553191488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 249}], {
             RGBColor[
             0.9934490425531914, 0.9883964893617021, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 250}], {
             RGBColor[
             0.9808916382978723, 0.9461833829787233, 0.4671517872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 266}], {
             RGBColor[
             0.9808916382978723, 0.9461833829787233, 0.4671517872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 315}], {
             RGBColor[
             0.9934490425531914, 0.9883964893617021, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 316}], {
             RGBColor[
             0.9808916382978723, 0.9461833829787233, 0.4671517872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 358}], {
             RGBColor[
             0.9568981489361702, 0.854505744680851, 0.4298859468085106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 362}], {
             RGBColor[
             0.994513340425532, 0.9906729148936171, 0.6441891489361701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 363}], {
             RGBColor[
             0.9326188723404255, 0.7486982765957447, 0.4098563510638298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 369}], {
             RGBColor[
             0.986079989361702, 0.9865140851063829, 0.7638485638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 372}], {
             RGBColor[
             0.994513340425532, 0.9906729148936171, 0.6441891489361701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 66}], {
             RGBColor[
             0.9938038085106383, 0.9891552978723405, 0.566960978723404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 91}], {
             RGBColor[
             0.9802441595744681, 0.9826559574468086, 0.8129417127659573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 123}], {
             RGBColor[
             0.9113385744680851, 0.6030948936170211, 0.42853325531914876`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 140}], {
             RGBColor[
             0.9572529148936171, 0.8552645531914893, 0.4685000319148935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 148}], {
             RGBColor[
             0.9678629680851063, 0.973422085106383, 0.8338998404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 179}], {
             RGBColor[
             0.9938038085106383, 0.9891552978723405, 0.566960978723404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 203}], {
             RGBColor[
             0.9446728723404255, 0.802580574468085, 0.4582325638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 232}], {
             RGBColor[
             0.985911085106383, 0.9626772553191489, 0.5238872765957445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 257}], {
             RGBColor[
             0.9902379255319149, 0.989874085106383, 0.7854918404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 275}], {
             RGBColor[
             0.9678629680851063, 0.973422085106383, 0.8338998404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 276}], {
             RGBColor[
             0.9271222234042553, 0.9410695531914893, 0.8346262553191488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 279}], {
             RGBColor[
             0.9506483191489362, 0.8290795319148937, 0.4631858191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 280}], {
             RGBColor[
             0.9418943510638298, 0.9528484468085107, 0.8360352340425531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 288}], {
             RGBColor[
             0.9944851595744681, 0.9916304255319148, 0.7151041808510636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 297}], {
             RGBColor[
             0.9944851595744681, 0.9916304255319148, 0.7151041808510636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 325}], {
             RGBColor[
             0.9938038085106383, 0.9891552978723405, 0.566960978723404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 339}], {
             RGBColor[
             0.9572529148936171, 0.8552645531914893, 0.4685000319148935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 149}], {
             RGBColor[
             0.987023489361702, 0.9889018936170213, 0.8647178936170211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 153}], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 161}], {
             RGBColor[
             0.9832203191489362, 0.9863007021276596, 0.8816887021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 184}], {
             RGBColor[
             0.9912989042553191, 0.9897007234042554, 0.7234152021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 195}], {
             RGBColor[
             0.991653670212766, 0.9904595319148937, 0.7620292872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 247}], {
             RGBColor[
             0.987023489361702, 0.9889018936170213, 0.8647178936170211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 250}], {
             RGBColor[0.9780319680851064, 0.94597, 0.5849919255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 315}], {
             RGBColor[
             0.9905893723404255, 0.9881831063829788, 0.6461870319148934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 343}], {
             RGBColor[
             0.9826966489361701, 0.9617050638297873, 0.603113329787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 356}], {
             RGBColor[
             0.9898549787234042, 0.9900727872340426, 0.8177927872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 358}], {
             RGBColor[
             0.9540384787234042, 0.8542923617021276, 0.5477260851063829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 362}], {
             RGBColor[
             0.991653670212766, 0.9904595319148937, 0.7620292872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 363}], {
             RGBColor[
             0.9297592021276595, 0.7484848936170214, 0.527696489361702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 369}], {
             RGBColor[
             0.9832203191489362, 0.9863007021276596, 0.8816887021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 372}], {
             RGBColor[
             0.991653670212766, 0.9904595319148937, 0.7620292872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.985945585106383, 0.9768546808510639, 0.6446972872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.9905757659574468, 0.9784123191489362, 0.5420086808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 173}], {
             RGBColor[
             0.988777074468085, 0.978025574468085, 0.5977721808510639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 201}], {
             RGBColor[
             0.9816187446808511, 0.9496578510638298, 0.38309272340425526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 209}], {
             RGBColor[
             0.985945585106383, 0.9768546808510639, 0.6446972872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 323}], {
             RGBColor[
             0.988777074468085, 0.978025574468085, 0.5977721808510639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 346}], {
             RGBColor[
             0.986283425531915, 0.965392914893617, 0.4012141276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 61}], {
             RGBColor[
             0.9681483723404255, 0.9270482978723404, 0.6073038829787233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 68}], {
             RGBColor[
             0.9846360638297872, 0.9868861489361702, 0.8582261489361702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 118}], {
             RGBColor[
             0.9681483723404255, 0.9270482978723404, 0.6073038829787233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 173}], {
             RGBColor[
             0.9846360638297872, 0.9868861489361702, 0.8582261489361702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 176}], {
             RGBColor[
             0.9857252234042553, 0.9857552765957447, 0.7252344787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 209}], {
             RGBColor[
             0.981804574468085, 0.985715255319149, 0.9051512553191488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 344}], {
             RGBColor[
             0.955424159574468, 0.8772907446808509, 0.593473659574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 354}], {
             RGBColor[
             0.9853704574468085, 0.9849964680851064, 0.686620393617021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 388}], {
             RGBColor[
             0.9728130531914894, 0.9427833617021275, 0.6254252872340423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 52}], {
             RGBColor[
             0.9186141808510638, 0.6827537659574467, 0.5178045851063828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 62}], {
             RGBColor[
             0.9128715957446809, 0.654971489361702, 0.27966257446808507`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.8716333829787234, 0.4948748085106381, 0.21400786170212763`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 127}], {
             RGBColor[
             0.9175362765957447, 0.6707065531914893, 0.29778397872340423`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[
             0.9171984361702128, 0.682168319148936, 0.5412671382978722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 133}], {
             RGBColor[
             0.9186141808510638, 0.6827537659574467, 0.5178045851063828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 199}], {
             RGBColor[
             0.9214738510638298, 0.6829671489361702, 0.3999644468085106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 216}], {
             RGBColor[
             0.9214738510638298, 0.6829671489361702, 0.3999644468085106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 231}], {
             RGBColor[
             0.8948234787234042, 0.665716319148936, 0.5896751382978723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 235}], {
             RGBColor[
             0.921445670212766, 0.6839246595744679, 0.4708794787234042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 298}], {
             RGBColor[
             0.9218286170212766, 0.6837259574468084, 0.4385785319148935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 313}], {
             RGBColor[
             0.8974226170212766, 0.5999288297872338, 0.23490375531914887`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 361}], {
             RGBColor[
             0.9211190851063831, 0.6822083404255319, 0.36135036170212753`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 393}], {
             RGBColor[
             0.9186141808510638, 0.6827537659574467, 0.5178045851063828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 396}], {
             RGBColor[
             0.9128715957446809, 0.654971489361702, 0.27966257446808507`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.9722893829787234, 0.9181877234042553, 0.34684991489361694`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 147}], {
             RGBColor[
             0.9769540638297872, 0.9339227872340424, 0.364971319148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 164}], {
             RGBColor[
             0.9661697659574469, 0.8946151914893616, 0.33833390425531906`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 271}], {
             RGBColor[
             0.9769540638297872, 0.9339227872340424, 0.364971319148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 287}], {
             RGBColor[
             0.985945585106383, 0.9768546808510639, 0.6446972872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 371}], {
             RGBColor[
             0.988777074468085, 0.978025574468085, 0.5977721808510639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 391}], {
             RGBColor[
             0.9905757659574468, 0.9784123191489362, 0.5420086808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 84}], {
             RGBColor[
             0.959227329787234, 0.8798919361702127, 0.5765028510638297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 102}], {
             RGBColor[
             0.9634745638297872, 0.8816482765957445, 0.5061151914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 134}], {
             RGBColor[
             0.9328469148936169, 0.7714674255319146, 0.26482525531914886`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 163}], {
             RGBColor[
             0.9634745638297872, 0.8816482765957445, 0.5061151914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 167}], {
             RGBColor[
             0.9455711276595744, 0.821224978723404, 0.2786554787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 174}], {
             RGBColor[
             0.9634745638297872, 0.8816482765957445, 0.5061151914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 183}], {
             RGBColor[
             0.9502358085106382, 0.8369600425531912, 0.2967768829787232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 189}], {
             RGBColor[
             0.9620588191489361, 0.8810628297872338, 0.529577744680851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 222}], {
             RGBColor[
             0.9455711276595744, 0.821224978723404, 0.2786554787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 226}], {
             RGBColor[
             0.959227329787234, 0.8798919361702127, 0.5765028510638297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 234}], {
             RGBColor[
             0.9368523723404254, 0.8634399361702125, 0.6249108510638297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 238}], {
             RGBColor[
             0.8159473723404256, 0.768144085106383, 0.6177317340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 246}], {
             RGBColor[
             0.9430429680851062, 0.8680568723404254, 0.6144317872340426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 269}], {
             RGBColor[
             0.9635027446808511, 0.8806907659574467, 0.435200159574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 272}], {
             RGBColor[
             0.9606430744680851, 0.8804773829787234, 0.5530402978723403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 350}], {
             RGBColor[
             0.9549004893617021, 0.8526951063829786, 0.31489828723404245`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 355}], {
             RGBColor[
             0.9638575106382978, 0.881449574468085, 0.47381424468085087`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 392}], {
             RGBColor[
             0.5558869574468085, 0.5384307127659573, 0.5991631276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 395}], {
             RGBColor[
             0.9620588191489361, 0.8810628297872338, 0.529577744680851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 89}], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 128}], {
             RGBColor[
             0.9414584361702127, 0.8016083829787233, 0.5374586170212765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 133}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 199}], {
             RGBColor[
             0.9912989042553191, 0.9897007234042554, 0.7234152021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 299}], {
             RGBColor[
             0.9733672872340425, 0.9302349361702127, 0.5668705212765957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 342}], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 393}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 58}], {
             RGBColor[
             0.9934208617021276, 0.9893540000000001, 0.5992619255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 64}], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 117}], {
             RGBColor[
             0.9808634574468085, 0.9471408936170211, 0.538066819148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 126}], {
             RGBColor[
             0.9898549787234042, 0.9900727872340426, 0.8177927872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 289}], {
             RGBColor[
             0.9562835319148937, 0.9648260425531915, 0.8697451595744681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 303}], {
             RGBColor[
             0.9415114042553192, 0.9530471489361703, 0.8683361808510638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 376}], {
             RGBColor[
             0.9934208617021276, 0.9893540000000001, 0.5992619255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 63}], {
             RGBColor[
             0.9060935531914893, 0.5627793617021277, 0.42351061702127646`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 66}], {
             RGBColor[
             0.905029255319149, 0.5605029361702127, 0.3076683617021275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 204}], {
             RGBColor[
             0.9028791170212767, 0.561807170212766, 0.5027366702127659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 224}], {
             RGBColor[
             0.9060935531914893, 0.5627793617021277, 0.42351061702127646`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 290}], {
             RGBColor[
             0.8924718510638298, 0.5182898297872339, 0.24647325531914877`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 297}], {
             RGBColor[
             0.9057106063829787, 0.5629780638297872, 0.45581156382978716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 318}], {
             RGBColor[
             0.9057106063829787, 0.5629780638297872, 0.45581156382978716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 345}], {
             RGBColor[
             0.9042948617021276, 0.5623926170212765, 0.47927411702127665`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 92}], {
             RGBColor[
             0.9554542234042553, 0.8548778085106382, 0.5242635319148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 135}], {
             RGBColor[
             0.9926864680851064, 0.9912436808510638, 0.7708676808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 156}], {
             RGBColor[
             0.9920051170212766, 0.9887685531914894, 0.6227244787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.988777074468085, 0.978025574468085, 0.5977721808510639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 221}], {
             RGBColor[
             0.9898549787234042, 0.9900727872340426, 0.8177927872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 245}], {
             RGBColor[
             0.9105514042553191, 0.928903914893617, 0.8889807765957447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 255}], {
             RGBColor[
             0.9920051170212766, 0.9887685531914894, 0.6227244787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 328}], {
             RGBColor[
             0.9747830319148936, 0.9308203829787234, 0.5434079680851063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 386}], {
             RGBColor[
             0.9794477127659573, 0.9465554468085104, 0.5615293723404253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 400}], {
             RGBColor[
             0.9554542234042553, 0.8548778085106382, 0.5242635319148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 59}], {
             RGBColor[
             0.968663414893617, 0.9072478510638297, 0.5348919574468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 90}], {
             RGBColor[
             0.955838159574468, 0.898858829787234, 0.6092669361702128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 121}], {
             RGBColor[
             0.9661697659574469, 0.8946151914893616, 0.33833390425531906`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 122}], {
             RGBColor[
             0.968663414893617, 0.9072478510638297, 0.5348919574468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 137}], {
             RGBColor[
             0.9496475638297872, 0.8942418936170211, 0.6197459999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 166}], {
             RGBColor[
             0.9701073404255318, 0.9068757872340425, 0.44051437234042545`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 169}], {
             RGBColor[
             0.9027180212765957, 0.6390982127659572, 0.23991459574468077`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 175}], {
             RGBColor[
             0.9615050851063829, 0.8788801276595744, 0.3202124999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 178}], {
             RGBColor[
             0.9661697659574469, 0.8946151914893616, 0.33833390425531906`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 213}], {
             RGBColor[
             0.9521757234042553, 0.8474099999999998, 0.2839696914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 274}], {
             RGBColor[
             0.9521757234042553, 0.8474099999999998, 0.2839696914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 278}], {
             RGBColor[
             0.970079159574468, 0.9078332978723402, 0.511429404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 296}], {
             RGBColor[
             0.9658319255319148, 0.9060769574468084, 0.581817063829787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 319}], {
             RGBColor[
             0.9672476702127659, 0.9066624042553191, 0.5583545106382977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 352}], {
             RGBColor[
             0.9615050851063829, 0.8788801276595744, 0.3202124999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 76}], {
             RGBColor[
             0.9488496276595745, 0.8286927872340426, 0.5189493191489363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 102}], {
             RGBColor[
             0.9926864680851064, 0.9912436808510638, 0.7708676808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 144}], {
             RGBColor[
             0.988777074468085, 0.978025574468085, 0.5977721808510639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 163}], {
             RGBColor[
             0.9926864680851064, 0.9912436808510638, 0.7708676808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 167}], {
             RGBColor[
             0.9747830319148936, 0.9308203829787234, 0.5434079680851063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 174}], {
             RGBColor[
             0.9926864680851064, 0.9912436808510638, 0.7708676808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 186}], {
             RGBColor[
             0.9794477127659573, 0.9465554468085104, 0.5615293723404253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 188}], {
             RGBColor[
             0.9660642765957446, 0.9730353404255319, 0.889663340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 189}], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 222}], {
             RGBColor[
             0.9747830319148936, 0.9308203829787234, 0.5434079680851063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 228}], {
             RGBColor[
             0.988777074468085, 0.978025574468085, 0.5977721808510639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 238}], {
             RGBColor[
             0.8451592765957447, 0.8777394893617022, 0.8824842234042554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 333}], {
             RGBColor[
             0.9927146489361702, 0.9902861702127659, 0.6999526489361703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 368}], {
             RGBColor[
             0.9920051170212766, 0.9887685531914894, 0.6227244787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 117}], {
             RGBColor[
             0.9801821063829788, 0.9446657659574467, 0.38992361702127626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 289}], {
             RGBColor[
             0.9556021808510639, 0.9623509148936171, 0.7216019574468083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 303}], {
             RGBColor[
             0.9408300531914894, 0.9505720212765958, 0.720192978723404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 376}], {
             RGBColor[
             0.9927395106382979, 0.9868788723404256, 0.45111872340425496`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 90}], {
             RGBColor[
             0.9784454680851064, 0.9822692127659574, 0.8687052127659574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 121}], {
             RGBColor[
             0.988777074468085, 0.978025574468085, 0.5977721808510639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 122}], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 175}], {
             RGBColor[
             0.9841123936170213, 0.9622905106382978, 0.5796507765957446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 178}], {
             RGBColor[
             0.988777074468085, 0.978025574468085, 0.5977721808510639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 213}], {
             RGBColor[
             0.9747830319148936, 0.9308203829787234, 0.5434079680851063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 274}], {
             RGBColor[
             0.9747830319148936, 0.9308203829787234, 0.5434079680851063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 296}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 319}], {
             RGBColor[
             0.9898549787234042, 0.9900727872340426, 0.8177927872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 373}], {
             RGBColor[
             0.9488496276595745, 0.8286927872340426, 0.5189493191489363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.9808916382978723, 0.9461833829787233, 0.4671517872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 101}], {
             RGBColor[
             0.9766162234042552, 0.9453845531914893, 0.6084544787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 259}], {
             RGBColor[
             0.9808634574468085, 0.9471408936170211, 0.538066819148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 331}], {
             RGBColor[
             0.9502358085106382, 0.8369600425531912, 0.2967768829787232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 335}], {
             RGBColor[
             0.9728130531914894, 0.9427833617021275, 0.6254252872340423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 394}], {
             RGBColor[
             0.9805368723404255, 0.945424574468085, 0.4285377021276593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 118}], {
             RGBColor[
             0.9582953404255319, 0.8709825319148935, 0.29248570212765945`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 130}], {
             RGBColor[
             0.9582953404255319, 0.8709825319148935, 0.29248570212765945`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 147}], {
             RGBColor[
             0.9629600212765956, 0.8867175957446807, 0.3106071063829785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 164}], {
             RGBColor[
             0.9521757234042553, 0.8474099999999998, 0.2839696914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 173}], {
             RGBColor[
             0.9747830319148936, 0.9308203829787234, 0.5434079680851063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 176}], {
             RGBColor[
             0.9758721914893618, 0.9296895106382979, 0.41041629787234024`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 344}], {
             RGBColor[
             0.9455711276595744, 0.821224978723404, 0.2786554787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 354}], {
             RGBColor[
             0.9755174255319149, 0.9289307021276596, 0.3718022127659572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 371}], {
             RGBColor[
             0.9747830319148936, 0.9308203829787234, 0.5434079680851063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 388}], {
             RGBColor[
             0.9629600212765956, 0.8867175957446807, 0.3106071063829785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 87}], {
             RGBColor[
             0.9357158510638297, 0.7738261063829786, 0.2993166063829787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 119}], {
             RGBColor[
             0.985911085106383, 0.9626772553191489, 0.5238872765957445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 127}], {
             RGBColor[
             0.9816187446808511, 0.9496578510638298, 0.38309272340425526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 129}], {
             RGBColor[
             0.9812809042553191, 0.9611196170212766, 0.6265758829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 216}], {
             RGBColor[
             0.9855563191489362, 0.9619184468085107, 0.48527319148936165`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 231}], {
             RGBColor[
             0.9589059468085106, 0.9446676170212766, 0.6749838829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 235}], {
             RGBColor[
             0.9855281382978723, 0.9628759574468084, 0.5561882234042552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 298}], {
             RGBColor[
             0.985911085106383, 0.9626772553191489, 0.5238872765957445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 313}], {
             RGBColor[
             0.9615050851063829, 0.8788801276595744, 0.3202124999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 317}], {
             RGBColor[
             0.9549004893617021, 0.8526951063829786, 0.31489828723404245`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 336}], {
             RGBColor[
             0.9841123936170213, 0.9622905106382978, 0.5796507765957446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 361}], {
             RGBColor[
             0.9852015531914894, 0.9611596382978724, 0.44665910638297857`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 393}], {
             RGBColor[
             0.9826966489361701, 0.9617050638297873, 0.603113329787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 396}], {
             RGBColor[
             0.9769540638297872, 0.9339227872340425, 0.3649713191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 98}], {
             RGBColor[
             0.9802441595744681, 0.9826559574468086, 0.8129417127659573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 139}], {
             RGBColor[
             0.9123500957446808, 0.9292906595744681, 0.8332172765957446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 204}], {
             RGBColor[
             0.991653670212766, 0.9904595319148937, 0.7620292872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 224}], {
             RGBColor[
             0.9948681063829787, 0.9914317234042553, 0.6828032340425529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 290}], {
             RGBColor[
             0.9812464042553191, 0.9469421914893617, 0.5057658723404252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 318}], {
             RGBColor[
             0.9944851595744681, 0.9916304255319148, 0.7151041808510636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 345}], {
             RGBColor[
             0.993069414893617, 0.9910449787234042, 0.738566734042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 77}], {
             RGBColor[
             0.9898549787234042, 0.9900727872340426, 0.8177927872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 94}], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 254}], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 289}], {
             RGBColor[
             0.9562835319148937, 0.9648260425531915, 0.8697451595744681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 68}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 173}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 176}], {
             RGBColor[
             0.9895283936170213, 0.9883564680851065, 0.7082636702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 250}], {
             RGBColor[
             0.9766162234042552, 0.9453845531914893, 0.6084544787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 363}], {
             RGBColor[
             0.9283434574468085, 0.7478994468085107, 0.5511590425531914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 123}], {
             RGBColor[
             0.9102742765957447, 0.6008184680851063, 0.31269099999999983`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 131}], {
             RGBColor[
             0.9930942765957447, 0.9876376808510638, 0.489732808510638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 140}], {
             RGBColor[
             0.9561886170212766, 0.8529881276595744, 0.3526577765957445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 203}], {
             RGBColor[
             0.9436085744680851, 0.8003041489361702, 0.3423903085106381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 232}], {
             RGBColor[
             0.9848467872340425, 0.9604008297872341, 0.40804502127659553`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 257}], {
             RGBColor[
             0.9891736276595744, 0.9875976595744682, 0.6696495851063827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 275}], {
             RGBColor[
             0.966798670212766, 0.9711456595744681, 0.7180575851063828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 280}], {
             RGBColor[
             0.9408300531914894, 0.9505720212765958, 0.720192978723404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 297}], {
             RGBColor[
             0.9934208617021276, 0.9893540000000001, 0.5992619255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 318}], {
             RGBColor[
             0.9934208617021276, 0.9893540000000001, 0.5992619255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 322}], {
             RGBColor[
             0.9930942765957447, 0.9876376808510638, 0.489732808510638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 325}], {
             RGBColor[
             0.9927395106382979, 0.9868788723404256, 0.45111872340425496`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 339}], {
             RGBColor[
             0.9561886170212766, 0.8529881276595744, 0.3526577765957445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 113}], {
             RGBColor[
             0.9606430744680851, 0.8804773829787234, 0.5530402978723403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 124}], {
             RGBColor[
             0.923909585106383, 0.7219231489361702, 0.5228154255319148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 194}], {
             RGBColor[
             0.9606430744680851, 0.8804773829787234, 0.5530402978723403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 208}], {
             RGBColor[
             0.991653670212766, 0.9904595319148937, 0.7620292872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 210}], {
             RGBColor[
             0.9133691595744681, 0.6424382340425533, 0.5127819468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 249}], {
             RGBColor[
             0.9905893723404255, 0.9881831063829788, 0.6461870319148934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 266}], {
             RGBColor[0.9780319680851064, 0.94597, 0.5849919255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 293}], {
             RGBColor[
             0.9832203191489362, 0.9863007021276596, 0.8816887021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 316}], {
             RGBColor[0.9780319680851064, 0.94597, 0.5849919255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 385}], {
             RGBColor[
             0.9832203191489362, 0.9863007021276596, 0.8816887021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 387}], {
             RGBColor[
             0.9239077872340425, 0.9400973617021277, 0.9138523085106383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 161}], {
             RGBColor[
             0.9846360638297872, 0.9868861489361702, 0.8582261489361702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 173}], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 176}], {
             RGBColor[
             0.9923598829787235, 0.9895273617021276, 0.6613385638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 250}], {
             RGBColor[
             0.9794477127659573, 0.9465554468085104, 0.5615293723404253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 363}], {
             RGBColor[
             0.9311749468085107, 0.7490703404255319, 0.5042339361702128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 106}], {
             RGBColor[
             0.993069414893617, 0.9910449787234042, 0.738566734042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 107}], {
             RGBColor[
             0.9554542234042553, 0.8548778085106382, 0.5242635319148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 150}], {
             RGBColor[
             0.9311749468085107, 0.7490703404255319, 0.5042339361702128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 212}], {
             RGBColor[
             0.9927146489361702, 0.9902861702127659, 0.6999526489361703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 270}], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 283}], {
             RGBColor[
             0.9920051170212766, 0.9887685531914894, 0.6227244787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 294}], {
             RGBColor[
             0.9846360638297872, 0.9868861489361702, 0.8582261489361702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 295}], {
             RGBColor[
             0.9548677872340425, 0.9642405957446809, 0.8932077127659575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 320}], {
             RGBColor[
             0.9923598829787235, 0.9895273617021276, 0.6613385638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 347}], {
             RGBColor[
             0.9747830319148936, 0.9308203829787234, 0.5434079680851063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 373}], {
             RGBColor[
             0.9488496276595745, 0.8286927872340426, 0.5189493191489363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 380}], {
             RGBColor[
             0.9620588191489361, 0.8810628297872338, 0.5295777446808511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 381}], {
             RGBColor[
             0.993069414893617, 0.9910449787234042, 0.738566734042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 390}], {
             RGBColor[
             0.9311749468085107, 0.7490703404255319, 0.5042339361702128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 108}], {
             RGBColor[
             0.985945585106383, 0.9768546808510639, 0.6446972872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 152}], {
             RGBColor[
             0.986283425531915, 0.965392914893617, 0.4012141276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 154}], {
             RGBColor[
             0.988777074468085, 0.978025574468085, 0.5977721808510639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 180}], {
             RGBColor[
             0.985945585106383, 0.9768546808510639, 0.6446972872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 198}], {
             RGBColor[
             0.988777074468085, 0.978025574468085, 0.5977721808510639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 236}], {
             RGBColor[
             0.985945585106383, 0.9768546808510639, 0.6446972872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 262}], {
             RGBColor[
             0.9895114680851065, 0.9761358936170212, 0.4261664255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 267}], {
             RGBColor[0.990221, 0.9776535106382979, 0.5033945957446808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 284}], {
             RGBColor[
             0.9722893829787234, 0.9181877234042553, 0.34684991489361694`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 286}], {
             RGBColor[
             0.9905757659574468, 0.9784123191489362, 0.5420086808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 332}], {
             RGBColor[
             0.9898662340425533, 0.9768947021276596, 0.46478051063829773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 72}], {
             RGBColor[
             0.9635706276595745, 0.9604026808510637, 0.6931052872340426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 88}], {
             RGBColor[
             0.9595651702127659, 0.8684301702127658, 0.3330196914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 138}], {
             RGBColor[
             0.986283425531915, 0.965392914893617, 0.4012141276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 157}], {
             RGBColor[
             0.9722893829787234, 0.9181877234042553, 0.34684991489361694`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 365}], {
             RGBColor[
             0.9873613297872341, 0.9774401276595746, 0.621234734042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 88}], {
             RGBColor[
             0.9368523723404254, 0.8634399361702125, 0.6249108510638298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 109}], {
             RGBColor[
             0.9434569680851064, 0.8896249574468084, 0.6302250638297873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 157}], {
             RGBColor[
             0.9495765851063829, 0.9131974893617021, 0.638741074468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 181}], {
             RGBColor[
             0.9675082021276595, 0.9726632765957446, 0.795285755319149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 191}], {
             RGBColor[
             0.9632327872340425, 0.9718644468085107, 0.9365884468085106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 365}], {
             RGBColor[
             0.9646485319148936, 0.9724498936170213, 0.9131258936170212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 370}], {
             RGBColor[
             0.9671534361702128, 0.9719044680851063, 0.7566716702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 78}], {
             RGBColor[
             0.9568404042553191, 0.8631450638297871, 0.3020910957446806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 99}], {
             RGBColor[
             0.9615050851063829, 0.8788801276595744, 0.3202124999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 104}], {
             RGBColor[
             0.9620287553191489, 0.9034757659574467, 0.5987878723404254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 112}], {
             RGBColor[
             0.9704621063829787, 0.9076345957446807, 0.4791284574468083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 141}], {
             RGBColor[
             0.9568404042553191, 0.8631450638297871, 0.3020910957446806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 172}], {
             RGBColor[
             0.9661697659574469, 0.8946151914893616, 0.33833390425531906`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 177}], {
             RGBColor[
             0.969752574468085, 0.9061169787234042, 0.40190028723404236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 208}], {
             RGBColor[
             0.9704621063829787, 0.9076345957446807, 0.4791284574468083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 225}], {
             RGBColor[
             0.9568404042553191, 0.8631450638297871, 0.3020910957446806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 240}], {
             RGBColor[
             0.9615050851063829, 0.8788801276595744, 0.3202124999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 243}], {
             RGBColor[
             0.9661697659574469, 0.8946151914893616, 0.33833390425531906`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 285}], {
             RGBColor[
             0.9027180212765957, 0.6390982127659572, 0.23991459574468077`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 337}], {
             RGBColor[
             0.9496475638297872, 0.8942418936170211, 0.6197459999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 399}], {
             RGBColor[
             0.9701073404255318, 0.9068757872340425, 0.44051437234042545`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 86}], {
             RGBColor[
             0.9937756276595745, 0.9901128085106383, 0.6378760106382977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 91}], {
             RGBColor[
             0.9795346276595744, 0.9811383404255319, 0.7357135425531913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 95}], {
             RGBColor[
             0.9934490425531916, 0.9883964893617022, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 104}], {
             RGBColor[
             0.9857252234042553, 0.9857552765957447, 0.7252344787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 112}], {
             RGBColor[
             0.9941585744680852, 0.9899141063829788, 0.605575063829787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 141}], {
             RGBColor[
             0.9805368723404255, 0.945424574468085, 0.4285377021276593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 148}], {
             RGBColor[
             0.9671534361702128, 0.9719044680851063, 0.7566716702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 172}], {
             RGBColor[
             0.9898662340425533, 0.9768947021276596, 0.46478051063829773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 179}], {
             RGBColor[
             0.9930942765957447, 0.9876376808510638, 0.489732808510638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 240}], {
             RGBColor[
             0.9852015531914894, 0.9611596382978724, 0.44665910638297857`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 263}], {
             RGBColor[
             0.9758721914893618, 0.9296895106382979, 0.41041629787234024`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 279}], {
             RGBColor[
             0.9499387872340426, 0.8275619148936171, 0.38595764893617013`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 285}], {
             RGBColor[
             0.9264144893617021, 0.7213777234042552, 0.36636120212765944`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 399}], {
             RGBColor[
             0.9938038085106383, 0.9891552978723405, 0.5669609787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 105}], {
             RGBColor[
             0.9948681063829787, 0.9914317234042553, 0.6828032340425529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 132}], {
             RGBColor[
             0.9944851595744681, 0.9916304255319148, 0.7151041808510636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 202}], {
             RGBColor[
             0.9812464042553191, 0.9469421914893617, 0.5057658723404252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 215}], {
             RGBColor[
             0.9802441595744681, 0.9826559574468086, 0.8129417127659573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 218}], {
             RGBColor[
             0.9418943510638298, 0.9528484468085107, 0.8360352340425531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 229}], {
             RGBColor[
             0.9812464042553191, 0.9469421914893617, 0.5057658723404252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 260}], {
             RGBColor[
             0.9678629680851063, 0.973422085106383, 0.8338998404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 329}], {
             RGBColor[
             0.991653670212766, 0.9904595319148937, 0.7620292872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 341}], {
             RGBColor[
             0.9704621063829787, 0.9076345957446807, 0.4791284574468083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 349}], {
             RGBColor[
             0.9678629680851063, 0.973422085106383, 0.8338998404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 77}], {
             RGBColor[
             0.9460181382978723, 0.8275218936170214, 0.5658744255319148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 103}], {
             RGBColor[
             0.9064285319148937, 0.6667273404255321, 0.2435684042553192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 144}], {
             RGBColor[
             0.9463559787234044, 0.8160601276595745, 0.3223912659574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 145}], {
             RGBColor[
             0.9262423191489362, 0.7452824042553191, 0.25951104255319146`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 200}], {
             RGBColor[
             0.9298337765957447, 0.8156868297872342, 0.6038033617021277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 207}], {
             RGBColor[
             0.9422149680851064, 0.8249207021276597, 0.5828452340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 222}], {
             RGBColor[
             0.9323619361702128, 0.7688549361702128, 0.26802705319148934`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 333}], {
             RGBColor[
             0.9502935531914893, 0.8283207234042553, 0.4245717340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 368}], {
             RGBColor[
             0.9495840212765958, 0.8268031063829788, 0.3473435638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 94}], {
             RGBColor[
             0.9898549787234042, 0.9900727872340426, 0.8177927872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 103}], {
             RGBColor[
             0.9460181382978723, 0.8275218936170214, 0.5658744255319148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 145}], {
             RGBColor[
             0.9658319255319148, 0.9060769574468084, 0.5818170638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 200}], {
             RGBColor[
             0.9694233829787233, 0.9764813829787234, 0.9261093829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 207}], {
             RGBColor[
             0.981804574468085, 0.985715255319149, 0.9051512553191488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 254}], {
             RGBColor[
             0.987023489361702, 0.9889018936170213, 0.8647178936170211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 333}], {
             RGBColor[
             0.989883159574468, 0.9891152765957447, 0.7468777553191488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 104}], {
             RGBColor[
             0.9728130531914894, 0.9427833617021275, 0.6254252872340423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 172}], {
             RGBColor[
             0.9769540638297872, 0.9339227872340424, 0.364971319148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 194}], {
             RGBColor[
             0.9502358085106382, 0.8369600425531912, 0.2967768829787232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 208}], {
             RGBColor[
             0.9812464042553191, 0.9469421914893617, 0.5057658723404252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 217}], {
             RGBColor[
             0.9502358085106382, 0.8369600425531912, 0.2967768829787232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 230}], {
             RGBColor[
             0.9193519361702127, 0.7049675531914893, 0.27143307446808496`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 233}], {
             RGBColor[
             0.9808634574468085, 0.9471408936170211, 0.538066819148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 240}], {
             RGBColor[
             0.9722893829787234, 0.9181877234042553, 0.34684991489361683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 242}], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 244}], {
             RGBColor[
             0.9629600212765956, 0.8867175957446807, 0.3106071063829785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 264}], {
             RGBColor[
             0.9728130531914894, 0.9427833617021275, 0.6254252872340423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 285}], {
             RGBColor[
             0.9135023191489361, 0.678405808510638, 0.2665520106382977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 357}], {
             RGBColor[
             0.931051170212766, 0.7580910425531913, 0.2811952021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 385}], {
             RGBColor[
             0.9728130531914894, 0.9427833617021275, 0.6254252872340423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 100}], {
             RGBColor[
             0.9905757659574468, 0.9784123191489362, 0.5420086808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 137}], {
             RGBColor[
             0.9697612234042553, 0.9650196170212766, 0.6826262234042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 175}], {
             RGBColor[
             0.9816187446808511, 0.9496578510638298, 0.38309272340425526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 213}], {
             RGBColor[
             0.9722893829787234, 0.9181877234042553, 0.34684991489361694`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 227}], {
             RGBColor[
             0.9635706276595745, 0.9604026808510637, 0.6931052872340426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[
             0.9661697659574469, 0.8946151914893616, 0.33833390425531906`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 278}], {
             RGBColor[
             0.9901928191489362, 0.9786110212765957, 0.5743096276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 302}], {
             RGBColor[
             0.9901928191489362, 0.9786110212765957, 0.5743096276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 314}], {
             RGBColor[
             0.9595651702127659, 0.8684301702127658, 0.3330196914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 352}], {
             RGBColor[
             0.9816187446808511, 0.9496578510638298, 0.38309272340425526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 379}], {
             RGBColor[
             0.9895114680851065, 0.9761358936170212, 0.4261664255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 151}], {
             RGBColor[
             0.9526227340425532, 0.8537069148936169, 0.5711886382978723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 168}], {
             RGBColor[
             0.9632327872340425, 0.9718644468085107, 0.9365884468085106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 265}], {
             RGBColor[
             0.9895283936170213, 0.9883564680851065, 0.7082636702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 304}], {
             RGBColor[
             0.959227329787234, 0.8798919361702127, 0.5765028510638297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 378}], {
             RGBColor[
             0.9895283936170213, 0.9883564680851065, 0.7082636702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 192}], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 271}], {
             RGBColor[0.9780319680851064, 0.94597, 0.5849919255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 287}], {
             RGBColor[
             0.987023489361702, 0.9889018936170213, 0.8647178936170211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 292}], {
             RGBColor[
             0.9239077872340425, 0.9400973617021277, 0.9138523085106383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 374}], {
             RGBColor[
             0.9873613297872341, 0.9774401276595746, 0.621234734042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 382}], {
             RGBColor[
             0.9414584361702127, 0.8016083829787233, 0.5374586170212765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 384}], {
             RGBColor[
             0.9414584361702127, 0.8016083829787233, 0.5374586170212765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 101}], {
             RGBColor[
             0.989883159574468, 0.9891152765957447, 0.7468777553191488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 136}], {
             RGBColor[
             0.9808916382978723, 0.9461833829787233, 0.4671517872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 259}], {
             RGBColor[
             0.9941303936170213, 0.9908716170212766, 0.6764900957446808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 331}], {
             RGBColor[
             0.9635027446808511, 0.8806907659574467, 0.435200159574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 335}], {
             RGBColor[
             0.986079989361702, 0.9865140851063829, 0.7638485638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 120}], {
             RGBColor[
             0.9805368723404255, 0.945424574468085, 0.4285377021276593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 187}], {
             RGBColor[
             0.9722893829787234, 0.9181877234042553, 0.34684991489361683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 206}], {
             RGBColor[
             0.9805368723404255, 0.945424574468085, 0.4285377021276593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 217}], {
             RGBColor[
             0.9502358085106382, 0.8369600425531912, 0.2967768829787232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 220}], {
             RGBColor[
             0.9629600212765956, 0.8867175957446807, 0.3106071063829785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 230}], {
             RGBColor[
             0.9193519361702127, 0.7049675531914893, 0.27143307446808496`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 244}], {
             RGBColor[
             0.9629600212765956, 0.8867175957446807, 0.3106071063829785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 245}], {
             RGBColor[
             0.8987283936170213, 0.8848011276595744, 0.6561799148936169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 321}], {
             RGBColor[
             0.9135023191489361, 0.678405808510638, 0.2665520106382977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 328}], {
             RGBColor[
             0.9629600212765956, 0.8867175957446807, 0.3106071063829785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 364}], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 102}], {
             RGBColor[
             0.9898549787234042, 0.9900727872340426, 0.8177927872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 163}], {
             RGBColor[
             0.9898549787234042, 0.9900727872340426, 0.8177927872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 167}], {
             RGBColor[
             0.9719515425531915, 0.9296494893617021, 0.590333074468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 174}], {
             RGBColor[
             0.9898549787234042, 0.9900727872340426, 0.8177927872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 183}], {
             RGBColor[
             0.9766162234042552, 0.9453845531914893, 0.6084544787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 189}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 222}], {
             RGBColor[
             0.9719515425531915, 0.9296494893617021, 0.590333074468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 226}], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 234}], {
             RGBColor[
             0.9632327872340425, 0.9718644468085107, 0.9365884468085106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 238}], {
             RGBColor[
             0.8423277872340427, 0.8765685957446809, 0.9294093297872339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 246}], {
             RGBColor[
             0.9694233829787233, 0.9764813829787234, 0.9261093829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 269}], {
             RGBColor[
             0.989883159574468, 0.9891152765957447, 0.7468777553191488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 272}], {
             RGBColor[
             0.987023489361702, 0.9889018936170213, 0.8647178936170211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 395}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 88}], {
             RGBColor[
             0.9502358085106382, 0.8369600425531912, 0.2967768829787232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 162}], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 181}], {
             RGBColor[
             0.9808916382978723, 0.9461833829787233, 0.4671517872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 191}], {
             RGBColor[
             0.9766162234042552, 0.9453845531914893, 0.6084544787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 211}], {
             RGBColor[
             0.9812464042553191, 0.9469421914893617, 0.5057658723404252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 214}], {
             RGBColor[
             0.9766162234042552, 0.9453845531914893, 0.6084544787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 263}], {
             RGBColor[
             0.9629600212765956, 0.8867175957446807, 0.3106071063829785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 307}], {
             RGBColor[
             0.9805368723404255, 0.945424574468085, 0.4285377021276593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 312}], {
             RGBColor[
             0.9794477127659573, 0.9465554468085104, 0.5615293723404253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 340}], {
             RGBColor[
             0.9808916382978723, 0.9461833829787233, 0.4671517872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 348}], {
             RGBColor[
             0.9370266170212767, 0.7845899999999999, 0.2861484574468084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 91}], {
             RGBColor[
             0.9798612127659574, 0.982854659574468, 0.845242659574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 93}], {
             RGBColor[
             0.9944851595744681, 0.9916304255319148, 0.7151041808510636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 95}], {
             RGBColor[
             0.9937756276595745, 0.9901128085106383, 0.6378760106382977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 125}], {
             RGBColor[
             0.9674800212765957, 0.9736207872340426, 0.8662007872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 148}], {
             RGBColor[
             0.9674800212765957, 0.9736207872340426, 0.8662007872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 162}], {
             RGBColor[
             0.9808634574468085, 0.9471408936170211, 0.538066819148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 179}], {
             RGBColor[
             0.9934208617021276, 0.9893540000000001, 0.5992619255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 214}], {
             RGBColor[
             0.9898549787234042, 0.9900727872340426, 0.8177927872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 263}], {
             RGBColor[
             0.9761987765957447, 0.931405829787234, 0.5199454148936169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 264}], {
             RGBColor[
             0.9860518085106382, 0.9874715957446809, 0.8347635957446807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 285}], {
             RGBColor[
             0.9267410744680851, 0.7230940425531913, 0.4758903191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 119}], {
             RGBColor[
             0.9446728723404255, 0.802580574468085, 0.45823256382978705`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 127}], {
             RGBColor[
             0.9403805319148937, 0.7895611702127658, 0.31743801063829785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 129}], {
             RGBColor[
             0.9400426914893616, 0.8010229361702127, 0.5609211702127659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 216}], {
             RGBColor[
             0.9443181063829786, 0.8018217659574467, 0.4196184787234042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 231}], {
             RGBColor[
             0.9176677340425532, 0.7845709361702127, 0.609329170212766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 235}], {
             RGBColor[
             0.9442899255319148, 0.8027792765957446, 0.49053351063829775`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 298}], {
             RGBColor[
             0.9446728723404255, 0.802580574468085, 0.45823256382978705`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 313}], {
             RGBColor[
             0.9202668723404255, 0.7187834468085104, 0.2545577872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 317}], {
             RGBColor[
             0.9136622765957446, 0.6925984255319146, 0.24924357446808504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 361}], {
             RGBColor[
             0.9439633404255319, 0.8010629574468084, 0.3810043936170211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 393}], {
             RGBColor[
             0.9414584361702127, 0.8016083829787233, 0.5374586170212765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 396}], {
             RGBColor[
             0.9357158510638297, 0.7738261063829786, 0.2993166063829787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 109}], {
             RGBColor[
             0.9394515106382978, 0.7976524468085104, 0.2701394680851063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 157}], {
             RGBColor[
             0.9455711276595744, 0.821224978723404, 0.2786554787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 181}], {
             RGBColor[
             0.9635027446808511, 0.8806907659574467, 0.435200159574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 191}], {
             RGBColor[
             0.959227329787234, 0.8798919361702127, 0.5765028510638297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 365}], {
             RGBColor[
             0.9606430744680851, 0.8804773829787234, 0.5530402978723403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 370}], {
             RGBColor[
             0.9631479787234043, 0.8799319574468084, 0.3965860744680849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 128}], {
             RGBColor[
             0.9442899255319148, 0.8027792765957446, 0.4905335106382978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 133}], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 155}], {
             RGBColor[
             0.9267392765957447, 0.9412682553191489, 0.8669272021276595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 170}], {
             RGBColor[
             0.9944851595744681, 0.9916304255319148, 0.7151041808510636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 171}], {
             RGBColor[
             0.9808634574468085, 0.9471408936170211, 0.538066819148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 199}], {
             RGBColor[
             0.9941303936170213, 0.9908716170212766, 0.6764900957446808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 299}], {
             RGBColor[
             0.9761987765957447, 0.931405829787234, 0.5199454148936169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 306}], {
             RGBColor[
             0.9926864680851064, 0.9912436808510638, 0.7708676808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 342}], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 353}], {
             RGBColor[
             0.9898549787234042, 0.9900727872340426, 0.8177927872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 121}], {
             RGBColor[
             0.9759518191489363, 0.9696365531914893, 0.672147159574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 122}], {
             RGBColor[
             0.9784454680851064, 0.9822692127659574, 0.8687052127659574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.9798893936170212, 0.9818971489361702, 0.7743276276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 178}], {
             RGBColor[
             0.9759518191489363, 0.9696365531914893, 0.672147159574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 190}], {
             RGBColor[
             0.9784454680851064, 0.9822692127659574, 0.8687052127659574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 212}], {
             RGBColor[
             0.9798893936170212, 0.9818971489361702, 0.7743276276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 221}], {
             RGBColor[
             0.9770297234042553, 0.9816837659574469, 0.8921677659574467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 268}], {
             RGBColor[
             0.9712871382978723, 0.9539014893617022, 0.6540257553191489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 274}], {
             RGBColor[
             0.9619577765957447, 0.9224313617021276, 0.6177829468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 295}], {
             RGBColor[
             0.9420425319148936, 0.9558515744680851, 0.9675826914893617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 319}], {
             RGBColor[
             0.9770297234042553, 0.9816837659574469, 0.8921677659574467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 324}], {
             RGBColor[
             0.9594296170212766, 0.9692632553191489, 0.953559255319149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 351}], {
             RGBColor[
             0.9532390212765958, 0.9646463191489361, 0.9640383191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 373}], {
             RGBColor[
             0.9360243723404256, 0.8203037659574468, 0.5933242978723404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 95}], {
             RGBColor[
             0.9795346276595744, 0.9811383404255319, 0.7357135425531913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 112}], {
             RGBColor[
             0.9802441595744681, 0.9826559574468086, 0.8129417127659573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 125}], {
             RGBColor[
             0.9532390212765958, 0.9646463191489361, 0.9640383191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 148}], {
             RGBColor[
             0.9532390212765958, 0.9646463191489361, 0.9640383191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 179}], {
             RGBColor[
             0.9791798617021277, 0.9803795319148936, 0.6970994574468083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 257}], {
             RGBColor[
             0.9756139787234042, 0.9810983191489362, 0.9156303191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 263}], {
             RGBColor[
             0.9619577765957447, 0.9224313617021276, 0.6177829468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 279}], {
             RGBColor[
             0.9360243723404256, 0.8203037659574468, 0.5933242978723404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 285}], {
             RGBColor[
             0.9125000744680851, 0.7141195744680849, 0.5737278510638297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 288}], {
             RGBColor[
             0.9798612127659574, 0.982854659574468, 0.845242659574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 135}], {
             RGBColor[
             0.9568699680851064, 0.8554632553191488, 0.5008009787234042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 165}], {
             RGBColor[
             0.9529605744680851, 0.8422451489361702, 0.3277054787234042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 182}], {
             RGBColor[
             0.9070576808510638, 0.6664134042553189, 0.24392936170212765`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 256}], {
             RGBColor[
             0.9568699680851064, 0.8554632553191488, 0.5008009787234042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 281}], {
             RGBColor[
             0.9389665319148937, 0.7950399574468083, 0.27334126595744673`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 311}], {
             RGBColor[
             0.9190512872340426, 0.8284601702127659, 0.6231410106382979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 386}], {
             RGBColor[
             0.9436312127659574, 0.8107750212765956, 0.2914626702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 98}], {
             RGBColor[
             0.9802441595744681, 0.9826559574468086, 0.8129417127659573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 125}], {
             RGBColor[
             0.9678629680851063, 0.973422085106383, 0.8338998404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 148}], {
             RGBColor[
             0.9678629680851063, 0.973422085106383, 0.8338998404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 162}], {
             RGBColor[
             0.9812464042553191, 0.9469421914893617, 0.5057658723404252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 214}], {
             RGBColor[
             0.9902379255319149, 0.989874085106383, 0.7854918404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 248}], {
             RGBColor[
             0.9902379255319149, 0.989874085106383, 0.7854918404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 276}], {
             RGBColor[
             0.9271222234042553, 0.9410695531914893, 0.8346262553191488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 288}], {
             RGBColor[
             0.9944851595744681, 0.9916304255319148, 0.7151041808510636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 290}], {
             RGBColor[
             0.9812464042553191, 0.9469421914893617, 0.5057658723404252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 103}], {
             RGBColor[
             0.9502653723404255, 0.8292782340425533, 0.4954867659574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 145}], {
             RGBColor[
             0.970079159574468, 0.9078332978723402, 0.511429404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 207}], {
             RGBColor[
             0.9860518085106382, 0.9874715957446809, 0.8347635957446807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 254}], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 125}], {
             RGBColor[
             0.9671534361702128, 0.9719044680851063, 0.7566716702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 162}], {
             RGBColor[
             0.9805368723404255, 0.945424574468085, 0.4285377021276593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 233}], {
             RGBColor[
             0.9937756276595745, 0.9901128085106383, 0.6378760106382977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 263}], {
             RGBColor[
             0.9758721914893618, 0.9296895106382979, 0.41041629787234024`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 264}], {
             RGBColor[
             0.9857252234042553, 0.9857552765957447, 0.7252344787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 285}], {
             RGBColor[
             0.9264144893617021, 0.7213777234042552, 0.36636120212765944`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 312}], {
             RGBColor[
             0.9923598829787235, 0.9895273617021276, 0.6613385638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 173}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 201}], {
             RGBColor[
             0.9812809042553191, 0.9611196170212766, 0.6265758829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 209}], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 223}], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 245}], {
             RGBColor[
             0.907719914893617, 0.9277330212765957, 0.9359058829787233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 323}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 109}], {
             RGBColor[
             0.968663414893617, 0.9072478510638297, 0.5348919574468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 181}], {
             RGBColor[
             0.9927146489361702, 0.9902861702127659, 0.6999526489361703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 191}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 193}], {
             RGBColor[
             0.9488496276595745, 0.8286927872340426, 0.5189493191489363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 211}], {
             RGBColor[
             0.993069414893617, 0.9910449787234042, 0.738566734042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 214}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 248}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 305}], {
             RGBColor[
             0.9926864680851064, 0.9912436808510638, 0.7708676808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 334}], {
             RGBColor[
             0.9846360638297872, 0.9868861489361702, 0.8582261489361702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 340}], {
             RGBColor[
             0.9927146489361702, 0.9902861702127659, 0.6999526489361703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 360}], {
             RGBColor[
             0.9923598829787235, 0.9895273617021276, 0.6613385638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 370}], {
             RGBColor[
             0.9923598829787235, 0.9895273617021276, 0.6613385638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 125}], {
             RGBColor[
             0.9532390212765958, 0.9646463191489361, 0.9640383191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 139}], {
             RGBColor[
             0.8977261489361703, 0.9205148936170213, 0.963355755319149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 193}], {
             RGBColor[
             0.9360243723404256, 0.8203037659574468, 0.5933242978723404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 204}], {
             RGBColor[
             0.9770297234042553, 0.9816837659574469, 0.8921677659574467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 248}], {
             RGBColor[
             0.9756139787234042, 0.9810983191489362, 0.9156303191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 276}], {
             RGBColor[
             0.9124982765957447, 0.9322937872340424, 0.9647647340425531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 290}], {
             RGBColor[
             0.9666224574468085, 0.9381664255319148, 0.6359043510638296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 318}], {
             RGBColor[
             0.9798612127659574, 0.982854659574468, 0.845242659574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 141}], {
             RGBColor[
             0.9722893829787234, 0.9181877234042553, 0.34684991489361683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 169}], {
             RGBColor[0.918167, 0.6941408723404254, 0.28467341489361697`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 177}], {
             RGBColor[
             0.9852015531914894, 0.9611596382978724, 0.44665910638297857`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 197}], {
             RGBColor[
             0.9826966489361701, 0.9617050638297873, 0.603113329787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 225}], {
             RGBColor[
             0.9722893829787234, 0.9181877234042553, 0.34684991489361683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 243}], {
             RGBColor[
             0.9816187446808511, 0.9496578510638298, 0.38309272340425526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 252}], {
             RGBColor[
             0.9816187446808511, 0.9496578510638298, 0.38309272340425526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 300}], {
             RGBColor[
             0.9722893829787234, 0.9181877234042553, 0.34684991489361683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 337}], {
             RGBColor[
             0.9650965425531914, 0.9492845531914893, 0.6645048191489362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 367}], {
             RGBColor[
             0.9841123936170213, 0.9622905106382978, 0.5796507765957446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 398}], {
             RGBColor[
             0.9615050851063829, 0.8788801276595744, 0.3202124999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 146}], {
             RGBColor[
             0.9905757659574468, 0.9784123191489362, 0.5420086808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 175}], {
             RGBColor[
             0.985911085106383, 0.9626772553191489, 0.5238872765957445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 213}], {
             RGBColor[
             0.9765817234042553, 0.9312071276595744, 0.4876444680851062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 227}], {
             RGBColor[
             0.9678629680851063, 0.973422085106383, 0.8338998404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 278}], {
             RGBColor[
             0.9944851595744681, 0.9916304255319148, 0.7151041808510636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 302}], {
             RGBColor[
             0.9944851595744681, 0.9916304255319148, 0.7151041808510636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 314}], {
             RGBColor[
             0.9638575106382978, 0.881449574468085, 0.47381424468085087`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 352}], {
             RGBColor[
             0.985911085106383, 0.9626772553191489, 0.5238872765957445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 377}], {
             RGBColor[
             0.9944851595744681, 0.9916304255319148, 0.7151041808510636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 136}], {
             RGBColor[
             0.9766162234042552, 0.9453845531914893, 0.6084544787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 301}], {
             RGBColor[
             0.9895283936170213, 0.9883564680851065, 0.7082636702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 335}], {
             RGBColor[
             0.981804574468085, 0.985715255319149, 0.9051512553191488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 394}], {
             RGBColor[
             0.9895283936170213, 0.9883564680851065, 0.7082636702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 163}], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 167}], {
             RGBColor[
             0.9761987765957447, 0.931405829787234, 0.5199454148936169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 174}], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 189}], {
             RGBColor[
             0.9926864680851064, 0.9912436808510638, 0.7708676808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 222}], {
             RGBColor[
             0.9761987765957447, 0.931405829787234, 0.5199454148936169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 226}], {
             RGBColor[
             0.9898549787234042, 0.9900727872340426, 0.8177927872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 395}], {
             RGBColor[
             0.9926864680851064, 0.9912436808510638, 0.7708676808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 145}], {
             RGBColor[
             0.9262423191489362, 0.7452824042553191, 0.25951104255319146`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 200}], {
             RGBColor[
             0.9298337765957447, 0.8156868297872342, 0.6038033617021277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 207}], {
             RGBColor[
             0.9422149680851064, 0.8249207021276597, 0.5828452340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 222}], {
             RGBColor[
             0.9323619361702128, 0.7688549361702128, 0.26802705319148934`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 254}], {
             RGBColor[
             0.9474338829787234, 0.828107340425532, 0.5424118723404254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 333}], {
             RGBColor[
             0.9502935531914893, 0.8283207234042553, 0.4245717340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 112}], {
             RGBColor[
             0.9864347553191489, 0.9872728936170213, 0.80246264893617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 141}], {
             RGBColor[
             0.9728130531914894, 0.9427833617021275, 0.6254252872340423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 172}], {
             RGBColor[
             0.9821424148936171, 0.9742534893617021, 0.6616680957446808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 208}], {
             RGBColor[
             0.9864347553191489, 0.9872728936170213, 0.80246264893617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 240}], {
             RGBColor[
             0.9774777340425531, 0.9585184255319149, 0.6435466914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 242}], {
             RGBColor[
             0.9728130531914894, 0.9427833617021275, 0.6254252872340423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 243}], {
             RGBColor[
             0.9821424148936171, 0.9742534893617021, 0.6616680957446808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 285}], {
             RGBColor[
             0.918690670212766, 0.7187365106382977, 0.5632487872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 337}], {
             RGBColor[
             0.9656202127659574, 0.9738801914893618, 0.9430801914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 357}], {
             RGBColor[
             0.9362395212765957, 0.798421744680851, 0.5778919787234043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 399}], {
             RGBColor[
             0.986079989361702, 0.9865140851063829, 0.7638485638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 114}], {
             RGBColor[
             0.9905757659574468, 0.9784123191489362, 0.5420086808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 171}], {
             RGBColor[
             0.9812464042553191, 0.9469421914893617, 0.5057658723404252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 202}], {
             RGBColor[
             0.9812464042553191, 0.9469421914893617, 0.5057658723404252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 218}], {
             RGBColor[
             0.9418943510638298, 0.9528484468085107, 0.8360352340425531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 229}], {
             RGBColor[
             0.9812464042553191, 0.9469421914893617, 0.5057658723404252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 261}], {
             RGBColor[
             0.9941585744680852, 0.9899141063829788, 0.605575063829787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 349}], {
             RGBColor[
             0.9678629680851063, 0.973422085106383, 0.8338998404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 353}], {
             RGBColor[
             0.9902379255319149, 0.989874085106383, 0.7854918404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.9572529148936171, 0.8552645531914893, 0.4685000319148935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 150}], {
             RGBColor[
             0.9329736382978724, 0.7494570851063831, 0.44847043617021265`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 158}], {
             RGBColor[
             0.9948681063829787, 0.9914317234042553, 0.6828032340425529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 241}], {
             RGBColor[
             0.994513340425532, 0.9906729148936171, 0.6441891489361701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 270}], {
             RGBColor[
             0.993069414893617, 0.9910449787234042, 0.738566734042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 292}], {
             RGBColor[
             0.9271222234042553, 0.9410695531914893, 0.8346262553191488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 310}], {
             RGBColor[
             0.9572529148936171, 0.8552645531914893, 0.4685000319148935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 320}], {
             RGBColor[
             0.9941585744680852, 0.9899141063829788, 0.605575063829787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 347}], {
             RGBColor[
             0.9765817234042553, 0.9312071276595744, 0.4876444680851062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 374}], {
             RGBColor[
             0.9905757659574468, 0.9784123191489362, 0.5420086808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 384}], {
             RGBColor[
             0.9446728723404255, 0.802580574468085, 0.4582325638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 389}], {
             RGBColor[
             0.9572529148936171, 0.8552645531914893, 0.4685000319148935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 390}], {
             RGBColor[
             0.9329736382978724, 0.7494570851063831, 0.44847043617021265`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 158}], {
             RGBColor[
             0.9572529148936171, 0.8552645531914893, 0.4685000319148935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 190}], {
             RGBColor[
             0.9554542234042553, 0.8548778085106382, 0.5242635319148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 212}], {
             RGBColor[
             0.9568981489361702, 0.854505744680851, 0.4298859468085106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 241}], {
             RGBColor[
             0.9568981489361702, 0.854505744680851, 0.4298859468085106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 268}], {
             RGBColor[
             0.9482958936170213, 0.8265100851063829, 0.30958407446808506`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 270}], {
             RGBColor[
             0.9554542234042553, 0.8548778085106382, 0.5242635319148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 295}], {
             RGBColor[
             0.9190512872340426, 0.8284601702127659, 0.6231410106382979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 310}], {
             RGBColor[
             0.9196377234042553, 0.7190973829787233, 0.254196829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 324}], {
             RGBColor[
             0.9364383723404255, 0.8418718510638297, 0.6091175744680851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 346}], {
             RGBColor[
             0.9529605744680851, 0.8422451489361702, 0.3277054787234042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 351}], {
             RGBColor[
             0.9302477765957446, 0.8372549148936169, 0.6195966382978724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 373}], {
             RGBColor[
             0.9130331276595745, 0.6929123617021277, 0.24888261702127662`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 390}], {
             RGBColor[
             0.8953584468085106, 0.6132899148936171, 0.23416723404255319`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 152}], {
             RGBColor[
             0.985945585106383, 0.9768546808510639, 0.6446972872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 154}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 180}], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 198}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 205}], {
             RGBColor[
             0.9460181382978723, 0.8275218936170214, 0.5658744255319148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 236}], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 262}], {
             RGBColor[
             0.9891736276595744, 0.9875976595744682, 0.6696495851063827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 267}], {
             RGBColor[
             0.989883159574468, 0.9891152765957447, 0.7468777553191488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 284}], {
             RGBColor[
             0.9719515425531915, 0.9296494893617021, 0.590333074468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 286}], {
             RGBColor[
             0.9902379255319149, 0.989874085106383, 0.7854918404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 332}], {
             RGBColor[
             0.9895283936170213, 0.9883564680851065, 0.7082636702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 367}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 398}], {
             RGBColor[
             0.9658319255319148, 0.9060769574468084, 0.5818170638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 157}], {
             RGBColor[
             0.9521757234042553, 0.8474099999999998, 0.2839696914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 181}], {
             RGBColor[
             0.9701073404255318, 0.9068757872340425, 0.44051437234042545`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 191}], {
             RGBColor[
             0.9658319255319148, 0.9060769574468084, 0.581817063829787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 305}], {
             RGBColor[
             0.970079159574468, 0.9078332978723402, 0.511429404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 334}], {
             RGBColor[
             0.9620287553191489, 0.9034757659574467, 0.5987878723404254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 340}], {
             RGBColor[
             0.9701073404255318, 0.9068757872340425, 0.44051437234042545`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 360}], {
             RGBColor[
             0.969752574468085, 0.9061169787234042, 0.40190028723404236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 365}], {
             RGBColor[
             0.9672476702127659, 0.9066624042553191, 0.5583545106382977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 370}], {
             RGBColor[
             0.969752574468085, 0.9061169787234042, 0.40190028723404236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 227}], {
             RGBColor[
             0.9542412659574467, 0.9289325531914892, 0.6568624787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 237}], {
             RGBColor[
             0.9666224574468085, 0.9381664255319148, 0.6359043510638296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 251}], {
             RGBColor[
             0.9430447765957446, 0.9201378085106382, 0.6604068510638297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 308}], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 375}], {
             RGBColor[
             0.9568404042553191, 0.8631450638297871, 0.3020910957446806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 116}], {
             RGBColor[
             0.9267692553191489, 0.7221365319148935, 0.4049752872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 151}], {
             RGBColor[
             0.889508829787234, 0.5867281702127658, 0.22928617021276593`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 154}], {
             RGBColor[
             0.9253253297872339, 0.7225085957446806, 0.49935287234042547`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 286}], {
             RGBColor[
             0.9271240212765957, 0.7228953404255318, 0.4435893723404254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 291}], {
             RGBColor[0.918167, 0.6941408723404254, 0.28467341489361697`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 304}], {
             RGBColor[
             0.8961134255319148, 0.6129131914893614, 0.23460038297872332`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 383}], {
             RGBColor[
             0.9228316808510638, 0.7098759361702126, 0.30279481914893613`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 141}], {
             RGBColor[
             0.9812464042553191, 0.9469421914893617, 0.5057658723404252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 172}], {
             RGBColor[
             0.9905757659574468, 0.9784123191489362, 0.5420086808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 179}], {
             RGBColor[
             0.9938038085106383, 0.9891552978723405, 0.566960978723404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 240}], {
             RGBColor[
             0.985911085106383, 0.9626772553191489, 0.5238872765957445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 279}], {
             RGBColor[
             0.9506483191489362, 0.8290795319148937, 0.4631858191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 285}], {
             RGBColor[
             0.9271240212765957, 0.7228953404255318, 0.4435893723404254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 337}], {
             RGBColor[
             0.9740535638297871, 0.9780390212765957, 0.8234207765957446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 399}], {
             RGBColor[
             0.994513340425532, 0.9906729148936171, 0.6441891489361701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 124}], {
             RGBColor[
             0.8961134255319148, 0.6129131914893614, 0.23460038297872332`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 149}], {
             RGBColor[
             0.959227329787234, 0.8798919361702127, 0.5765028510638297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 210}], {
             RGBColor[
             0.8855729999999999, 0.5334282765957445, 0.2245669042553191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 249}], {
             RGBColor[
             0.9627932127659574, 0.87917314893617, 0.35797198936170194`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 266}], {
             RGBColor[
             0.9502358085106382, 0.8369600425531912, 0.2967768829787232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 293}], {
             RGBColor[
             0.955424159574468, 0.8772907446808509, 0.5934736595744681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 315}], {
             RGBColor[
             0.9627932127659574, 0.87917314893617, 0.35797198936170194`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 316}], {
             RGBColor[
             0.9502358085106382, 0.8369600425531912, 0.2967768829787232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 387}], {
             RGBColor[
             0.8961116276595744, 0.8310874042553189, 0.6256372659574467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 397}], {
             RGBColor[
             0.9492335638297872, 0.8726738085106381, 0.6039527234042552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 128}], {
             RGBColor[
             0.9403805319148937, 0.7895611702127658, 0.31743801063829785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 155}], {
             RGBColor[
             0.9228298829787234, 0.9280501489361701, 0.6938317021276595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 170}], {
             RGBColor[
             0.9905757659574468, 0.9784123191489362, 0.5420086808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 187}], {
             RGBColor[
             0.9816187446808511, 0.9496578510638298, 0.38309272340425526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 202}], {
             RGBColor[
             0.9769540638297872, 0.9339227872340424, 0.364971319148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 261}], {
             RGBColor[
             0.9898662340425533, 0.9768947021276596, 0.46478051063829773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 306}], {
             RGBColor[
             0.988777074468085, 0.978025574468085, 0.5977721808510639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 353}], {
             RGBColor[
             0.985945585106383, 0.9768546808510639, 0.6446972872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 122}], {
             RGBColor[
             0.9920051170212766, 0.9887685531914894, 0.6227244787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 166}], {
             RGBColor[
             0.9934490425531914, 0.9883964893617021, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 169}], {
             RGBColor[
             0.9260597234042554, 0.7206189148936168, 0.3277471170212764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 197}], {
             RGBColor[
             0.9905893723404255, 0.9881831063829788, 0.6461870319148934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 221}], {
             RGBColor[
             0.9905893723404255, 0.9881831063829788, 0.6461870319148934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 239}], {
             RGBColor[
             0.9693978085106383, 0.9053581702127659, 0.3632862021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 300}], {
             RGBColor[
             0.9801821063829788, 0.9446657659574467, 0.38992361702127626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 350}], {
             RGBColor[
             0.9848467872340425, 0.9604008297872341, 0.40804502127659553`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 392}], {
             RGBColor[
             0.585833255319149, 0.6461364361702128, 0.6923098617021275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 151}], {
             RGBColor[
             0.9568981489361702, 0.854505744680851, 0.4298859468085106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 154}], {
             RGBColor[
             0.9927146489361702, 0.9902861702127659, 0.6999526489361703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 265}], {
             RGBColor[
             0.9938038085106383, 0.9891552978723405, 0.5669609787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 291}], {
             RGBColor[
             0.9855563191489362, 0.9619184468085107, 0.48527319148936165`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 304}], {
             RGBColor[
             0.9635027446808511, 0.8806907659574467, 0.435200159574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 383}], {
             RGBColor[0.990221, 0.9776535106382979, 0.5033945957446808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 289}], {
             RGBColor[
             0.9430447765957446, 0.9201378085106382, 0.6604068510638297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 303}], {
             RGBColor[
             0.9282726489361701, 0.9083589148936169, 0.6589978723404254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 376}], {
             RGBColor[
             0.9801821063829788, 0.9446657659574467, 0.38992361702127626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 158}], {
             RGBColor[
             0.9765817234042553, 0.9312071276595744, 0.4876444680851062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 164}], {
             RGBColor[
             0.9521757234042553, 0.8474099999999998, 0.2839696914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 173}], {
             RGBColor[
             0.9747830319148936, 0.9308203829787234, 0.5434079680851063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 209}], {
             RGBColor[
             0.9719515425531915, 0.9296494893617021, 0.590333074468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 241}], {
             RGBColor[
             0.9762269574468085, 0.9304483191489361, 0.44903038297872333`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 323}], {
             RGBColor[
             0.9747830319148936, 0.9308203829787234, 0.5434079680851063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 346}], {
             RGBColor[
             0.9722893829787234, 0.9181877234042553, 0.34684991489361694`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 354}], {
             RGBColor[
             0.9755174255319149, 0.9289307021276596, 0.3718022127659572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 388}], {
             RGBColor[
             0.9629600212765956, 0.8867175957446807, 0.3106071063829785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 389}], {
             RGBColor[
             0.9389665319148937, 0.7950399574468083, 0.27334126595744673`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 126}], {
             RGBColor[
             0.9902379255319149, 0.989874085106383, 0.7854918404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 127}], {
             RGBColor[
             0.9905757659574468, 0.9784123191489362, 0.5420086808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 129}], {
             RGBColor[
             0.9902379255319149, 0.989874085106383, 0.7854918404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 196}], {
             RGBColor[
             0.9948681063829787, 0.9914317234042553, 0.6828032340425529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 231}], {
             RGBColor[
             0.9678629680851063, 0.973422085106383, 0.8338998404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 235}], {
             RGBColor[
             0.9944851595744681, 0.9916304255319148, 0.7151041808510636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 317}], {
             RGBColor[
             0.9638575106382978, 0.881449574468085, 0.47381424468085087`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 326}], {
             RGBColor[
             0.9944851595744681, 0.9916304255319148, 0.7151041808510636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 327}], {
             RGBColor[
             0.9802441595744681, 0.9826559574468086, 0.8129417127659573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 336}], {
             RGBColor[
             0.993069414893617, 0.9910449787234042, 0.738566734042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 396}], {
             RGBColor[
             0.985911085106383, 0.9626772553191489, 0.5238872765957445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 132}], {
             RGBColor[
             0.9937756276595745, 0.9901128085106383, 0.6378760106382977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 160}], {
             RGBColor[
             0.9795346276595744, 0.9811383404255319, 0.7357135425531913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 187}], {
             RGBColor[
             0.9852015531914894, 0.9611596382978724, 0.44665910638297857`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 202}], {
             RGBColor[
             0.9805368723404255, 0.945424574468085, 0.4285377021276593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 206}], {
             RGBColor[
             0.9934490425531916, 0.9883964893617022, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 217}], {
             RGBColor[
             0.9631479787234043, 0.8799319574468084, 0.3965860744680849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 220}], {
             RGBColor[
             0.9758721914893618, 0.9296895106382979, 0.41041629787234024`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 233}], {
             RGBColor[
             0.9937756276595745, 0.9901128085106383, 0.6378760106382977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 244}], {
             RGBColor[
             0.9758721914893618, 0.9296895106382979, 0.41041629787234024`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 307}], {
             RGBColor[
             0.9934490425531916, 0.9883964893617022, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 321}], {
             RGBColor[
             0.9264144893617021, 0.7213777234042552, 0.36636120212765944`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 341}], {
             RGBColor[
             0.969752574468085, 0.9061169787234042, 0.40190028723404236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 366}], {
             RGBColor[
             0.9852015531914894, 0.9611596382978724, 0.44665910638297857`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 122}], {
             RGBColor[
             0.988777074468085, 0.978025574468085, 0.5977721808510639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 175}], {
             RGBColor[
             0.9816187446808511, 0.9496578510638298, 0.38309272340425526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 178}], {
             RGBColor[
             0.986283425531915, 0.965392914893617, 0.4012141276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.9722893829787234, 0.9181877234042553, 0.34684991489361694`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 274}], {
             RGBColor[
             0.9722893829787234, 0.9181877234042553, 0.34684991489361694`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 296}], {
             RGBColor[
             0.985945585106383, 0.9768546808510639, 0.6446972872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 319}], {
             RGBColor[
             0.9873613297872341, 0.9774401276595746, 0.621234734042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 373}], {
             RGBColor[
             0.9463559787234044, 0.8160601276595745, 0.3223912659574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 166}], {
             RGBColor[
             0.9927146489361702, 0.9902861702127659, 0.6999526489361703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 169}], {
             RGBColor[
             0.9253253297872339, 0.7225085957446806, 0.4993528723404255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 175}], {
             RGBColor[
             0.9841123936170213, 0.9622905106382978, 0.5796507765957446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 178}], {
             RGBColor[
             0.988777074468085, 0.978025574468085, 0.5977721808510639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 268}], {
             RGBColor[
             0.9841123936170213, 0.9622905106382978, 0.5796507765957446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 274}], {
             RGBColor[
             0.9747830319148936, 0.9308203829787234, 0.5434079680851063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 319}], {
             RGBColor[
             0.9898549787234042, 0.9900727872340426, 0.8177927872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 351}], {
             RGBColor[
             0.9660642765957446, 0.9730353404255319, 0.889663340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 131}], {
             RGBColor[
             0.9106290425531915, 0.6015772765957446, 0.3513050851063828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 140}], {
             RGBColor[
             0.8737233829787234, 0.4669277234042551, 0.21423005319148933`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 203}], {
             RGBColor[
             0.8611433404255319, 0.4142437446808508, 0.20396258510638293`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 232}], {
             RGBColor[
             0.9023815531914894, 0.5743404255319147, 0.26961729787234034`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 275}], {
             RGBColor[
             0.8843334361702127, 0.5850852553191488, 0.5796298617021276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 280}], {
             RGBColor[
             0.8583648191489361, 0.5645116170212765, 0.581765255319149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 297}], {
             RGBColor[
             0.9109556276595745, 0.6032935957446807, 0.4608342021276595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 309}], {
             RGBColor[
             0.8967146276595744, 0.5943191276595743, 0.5586717340425531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 322}], {
             RGBColor[
             0.9106290425531915, 0.6015772765957446, 0.3513050851063828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 325}], {
             RGBColor[
             0.9102742765957447, 0.6008184680851063, 0.31269099999999983`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 339}], {
             RGBColor[
             0.8737233829787234, 0.4669277234042551, 0.21423005319148933`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 149}], {
             RGBColor[
             0.9224938404255318, 0.7213377021276595, 0.5462779787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 185}], {
             RGBColor[
             0.8652295531914893, 0.48092070212765947`, 0.2092565744680851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 210}], {
             RGBColor[
             0.8488395106382978, 0.3748740425531914, 0.19434203191489358`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 219}], {
             RGBColor[
             0.9027180212765957, 0.6390982127659572, 0.23991459574468077`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 249}], {
             RGBColor[
             0.9260597234042554, 0.7206189148936168, 0.3277471170212764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 266}], {
             RGBColor[
             0.9135023191489361, 0.678405808510638, 0.2665520106382977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 293}], {
             RGBColor[
             0.918690670212766, 0.7187365106382977, 0.5632487872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 315}], {
             RGBColor[
             0.9260597234042554, 0.7206189148936168, 0.3277471170212764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 316}], {
             RGBColor[
             0.9135023191489361, 0.678405808510638, 0.2665520106382977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 338}], {
             RGBColor[
             0.8889223936170212, 0.6960909574468084, 0.5982303510638297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 387}], {
             RGBColor[
             0.8593781382978722, 0.6725331702127657, 0.5954123936170213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 397}], {
             RGBColor[
             0.9125000744680851, 0.7141195744680849, 0.5737278510638297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 148}], {
             RGBColor[
             0.940857829787234, 0.9554124468085106, 0.9849964468085107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 162}], {
             RGBColor[
             0.9542412659574467, 0.9289325531914892, 0.6568624787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 211}], {
             RGBColor[
             0.9678629680851063, 0.973422085106383, 0.8338998404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 214}], {
             RGBColor[
             0.9632327872340425, 0.9718644468085107, 0.9365884468085106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 248}], {
             RGBColor[
             0.9632327872340425, 0.9718644468085107, 0.9365884468085106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 263}], {
             RGBColor[
             0.9495765851063829, 0.9131974893617021, 0.638741074468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 276}], {
             RGBColor[
             0.9001170851063829, 0.9230599148936169, 0.9857228617021276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 288}], {
             RGBColor[
             0.9674800212765957, 0.9736207872340426, 0.8662007872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 196}], {
             RGBColor[
             0.9902379255319149, 0.989874085106383, 0.7854918404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 289}], {
             RGBColor[
             0.9520362978723405, 0.9630697021276596, 0.9401328191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 317}], {
             RGBColor[
             0.959227329787234, 0.8798919361702127, 0.5765028510638297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 326}], {
             RGBColor[
             0.9898549787234042, 0.9900727872340426, 0.8177927872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 327}], {
             RGBColor[
             0.9756139787234042, 0.9810983191489362, 0.9156303191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 336}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 376}], {
             RGBColor[
             0.9891736276595744, 0.9875976595744682, 0.6696495851063827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 129}], {
             RGBColor[
             0.985945585106383, 0.9768546808510639, 0.6446972872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 216}], {
             RGBColor[0.990221, 0.9776535106382979, 0.5033945957446808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 231}], {
             RGBColor[
             0.9635706276595745, 0.9604026808510637, 0.6931052872340426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 235}], {
             RGBColor[
             0.9901928191489362, 0.9786110212765957, 0.5743096276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 298}], {
             RGBColor[
             0.9905757659574468, 0.9784123191489362, 0.5420086808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 313}], {
             RGBColor[
             0.9661697659574469, 0.8946151914893616, 0.33833390425531906`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 317}], {
             RGBColor[
             0.9595651702127659, 0.8684301702127658, 0.3330196914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 336}], {
             RGBColor[
             0.988777074468085, 0.978025574468085, 0.5977721808510639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 361}], {
             RGBColor[
             0.9898662340425533, 0.9768947021276596, 0.46478051063829773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 393}], {
             RGBColor[
             0.9873613297872341, 0.9774401276595746, 0.621234734042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 396}], {
             RGBColor[
             0.9816187446808511, 0.9496578510638298, 0.38309272340425526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 133}], {
             RGBColor[
             0.9414584361702127, 0.8016083829787233, 0.5374586170212765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 155}], {
             RGBColor[
             0.8769269893617021, 0.752218404255319, 0.6100555851063829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 170}], {
             RGBColor[
             0.9446728723404255, 0.802580574468085, 0.45823256382978705`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 171}], {
             RGBColor[
             0.931051170212766, 0.7580910425531913, 0.2811952021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 199}], {
             RGBColor[
             0.9443181063829786, 0.8018217659574467, 0.4196184787234042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 261}], {
             RGBColor[
             0.9439633404255319, 0.8010629574468084, 0.3810043936170211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 299}], {
             RGBColor[
             0.9263864893617021, 0.7423559787234041, 0.26307379787234036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 306}], {
             RGBColor[
             0.9428741808510638, 0.802193829787234, 0.5139960638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 342}], {
             RGBColor[
             0.9442899255319148, 0.8027792765957446, 0.49053351063829775`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 353}], {
             RGBColor[
             0.9400426914893616, 0.8010229361702127, 0.5609211702127659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 216}], {
             RGBColor[
             0.989883159574468, 0.9891152765957447, 0.7468777553191488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 231}], {
             RGBColor[
             0.9632327872340425, 0.9718644468085107, 0.9365884468085106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 235}], {
             RGBColor[
             0.9898549787234042, 0.9900727872340426, 0.8177927872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 298}], {
             RGBColor[
             0.9902379255319149, 0.989874085106383, 0.7854918404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 313}], {
             RGBColor[
             0.9658319255319148, 0.9060769574468084, 0.5818170638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 317}], {
             RGBColor[
             0.959227329787234, 0.8798919361702127, 0.5765028510638297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 336}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 361}], {
             RGBColor[
             0.9895283936170213, 0.9883564680851065, 0.7082636702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 393}], {
             RGBColor[
             0.987023489361702, 0.9889018936170213, 0.8647178936170211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 396}], {
             RGBColor[
             0.9812809042553191, 0.9611196170212766, 0.6265758829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 147}], {
             RGBColor[
             0.9629600212765956, 0.8867175957446807, 0.3106071063829785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 164}], {
             RGBColor[
             0.9521757234042553, 0.8474099999999998, 0.2839696914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 287}], {
             RGBColor[
             0.9719515425531915, 0.9296494893617021, 0.590333074468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 371}], {
             RGBColor[
             0.9747830319148936, 0.9308203829787234, 0.5434079680851063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 391}], {
             RGBColor[
             0.9765817234042553, 0.9312071276595744, 0.4876444680851062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 140}], {
             RGBColor[
             0.9565433829787234, 0.8537469361702128, 0.3912718617021275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 186}], {
             RGBColor[
             0.9805368723404255, 0.945424574468085, 0.4285377021276593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 188}], {
             RGBColor[
             0.9671534361702128, 0.9719044680851063, 0.7566716702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 203}], {
             RGBColor[
             0.9439633404255319, 0.8010629574468084, 0.38100439361702115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 228}], {
             RGBColor[
             0.9898662340425533, 0.9768947021276596, 0.46478051063829773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 238}], {
             RGBColor[
             0.846248436170213, 0.8766086170212768, 0.7494925531914892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 273}], {
             RGBColor[
             0.9565433829787234, 0.8537469361702128, 0.3912718617021275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 280}], {
             RGBColor[
             0.9411848191489363, 0.951330829787234, 0.7588070638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 309}], {
             RGBColor[
             0.9795346276595744, 0.9811383404255319, 0.7357135425531913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 322}], {
             RGBColor[
             0.9934490425531916, 0.9883964893617022, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 325}], {
             RGBColor[
             0.9930942765957447, 0.9876376808510638, 0.489732808510638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 330}], {
             RGBColor[
             0.9934490425531916, 0.9883964893617022, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 339}], {
             RGBColor[
             0.9565433829787234, 0.8537469361702128, 0.3912718617021275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 160}], {
             RGBColor[
             0.9798612127659574, 0.982854659574468, 0.845242659574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 202}], {
             RGBColor[
             0.9808634574468085, 0.9471408936170211, 0.538066819148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 220}], {
             RGBColor[
             0.9761987765957447, 0.931405829787234, 0.5199454148936169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 244}], {
             RGBColor[
             0.9761987765957447, 0.931405829787234, 0.5199454148936169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 260}], {
             RGBColor[
             0.9674800212765957, 0.9736207872340426, 0.8662007872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 307}], {
             RGBColor[
             0.9937756276595745, 0.9901128085106383, 0.6378760106382977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 321}], {
             RGBColor[
             0.9267410744680851, 0.7230940425531913, 0.4758903191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 341}], {
             RGBColor[
             0.970079159574468, 0.9078332978723402, 0.511429404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 348}], {
             RGBColor[
             0.9502653723404255, 0.8292782340425533, 0.4954867659574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 366}], {
             RGBColor[
             0.9855281382978723, 0.9628759574468084, 0.5561882234042552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 155}], {
             RGBColor[
             0.9239077872340425, 0.9400973617021277, 0.9138523085106383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 199}], {
             RGBColor[
             0.9912989042553191, 0.9897007234042554, 0.7234152021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 216}], {
             RGBColor[
             0.9912989042553191, 0.9897007234042554, 0.7234152021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 298}], {
             RGBColor[
             0.991653670212766, 0.9904595319148937, 0.7620292872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 299}], {
             RGBColor[
             0.9733672872340425, 0.9302349361702127, 0.5668705212765957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 306}], {
             RGBColor[
             0.9898549787234042, 0.9900727872340426, 0.8177927872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 342}], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 361}], {
             RGBColor[
             0.9909441382978723, 0.9889419148936172, 0.6848011170212764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 393}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 135}], {
             RGBColor[
             0.9634745638297872, 0.8816482765957445, 0.5061151914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 226}], {
             RGBColor[
             0.959227329787234, 0.8798919361702127, 0.5765028510638297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 234}], {
             RGBColor[
             0.9368523723404254, 0.8634399361702125, 0.6249108510638297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 239}], {
             RGBColor[
             0.9394515106382978, 0.7976524468085104, 0.2701394680851063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 246}], {
             RGBColor[
             0.9430429680851062, 0.8680568723404254, 0.6144317872340426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 269}], {
             RGBColor[
             0.9635027446808511, 0.8806907659574467, 0.435200159574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 272}], {
             RGBColor[
             0.9606430744680851, 0.8804773829787234, 0.5530402978723403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 350}], {
             RGBColor[
             0.9549004893617021, 0.8526951063829786, 0.31489828723404245`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 355}], {
             RGBColor[
             0.9638575106382978, 0.881449574468085, 0.47381424468085087`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 392}], {
             RGBColor[
             0.5558869574468085, 0.5384307127659573, 0.5991631276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 395}], {
             RGBColor[
             0.9620588191489361, 0.8810628297872338, 0.529577744680851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 156}], {
             RGBColor[
             0.9934208617021276, 0.9893540000000001, 0.5992619255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 165}], {
             RGBColor[
             0.9901928191489362, 0.9786110212765957, 0.5743096276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 221}], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 234}], {
             RGBColor[
             0.9674800212765957, 0.9736207872340426, 0.8662007872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 255}], {
             RGBColor[
             0.9934208617021276, 0.9893540000000001, 0.5992619255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 281}], {
             RGBColor[
             0.9761987765957447, 0.931405829787234, 0.5199454148936169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 328}], {
             RGBColor[
             0.9761987765957447, 0.931405829787234, 0.5199454148936169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 355}], {
             RGBColor[
             0.9944851595744681, 0.9916304255319148, 0.7151041808510636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 386}], {
             RGBColor[
             0.9808634574468085, 0.9471408936170211, 0.538066819148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 400}], {
             RGBColor[
             0.9568699680851064, 0.8554632553191488, 0.5008009787234042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 331}], {
             RGBColor[
             0.9502358085106382, 0.8369600425531912, 0.2967768829787232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 335}], {
             RGBColor[
             0.9728130531914894, 0.9427833617021275, 0.6254252872340423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 394}], {
             RGBColor[
             0.9805368723404255, 0.945424574468085, 0.4285377021276593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 169}], {
             RGBColor[
             0.9063094787234042, 0.7095026382978722, 0.5842069148936171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 175}], {
             RGBColor[
             0.9650965425531914, 0.9492845531914893, 0.6645048191489362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 178}], {
             RGBColor[
             0.9697612234042553, 0.9650196170212766, 0.6826262234042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 197}], {
             RGBColor[
             0.9708391276595745, 0.977066829787234, 0.902646829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 252}], {
             RGBColor[
             0.9697612234042553, 0.9650196170212766, 0.6826262234042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 278}], {
             RGBColor[
             0.9736706170212766, 0.9782377234042553, 0.8557217234042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 282}], {
             RGBColor[
             0.9650965425531914, 0.9492845531914893, 0.6645048191489362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 300}], {
             RGBColor[
             0.9604318617021276, 0.933549489361702, 0.646383414893617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 314}], {
             RGBColor[
             0.9430429680851062, 0.8680568723404254, 0.6144317872340426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 319}], {
             RGBColor[
             0.9708391276595745, 0.977066829787234, 0.902646829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 352}], {
             RGBColor[
             0.9650965425531914, 0.9492845531914893, 0.6645048191489362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 159}], {
             RGBColor[
             0.985945585106383, 0.9768546808510639, 0.6446972872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 215}], {
             RGBColor[
             0.9759518191489363, 0.9696365531914893, 0.672147159574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 218}], {
             RGBColor[
             0.9376020106382978, 0.9398290425531914, 0.6952406808510638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 229}], {
             RGBColor[
             0.9769540638297872, 0.9339227872340424, 0.364971319148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 329}], {
             RGBColor[
             0.9873613297872341, 0.9774401276595746, 0.621234734042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 349}], {
             RGBColor[
             0.9635706276595745, 0.9604026808510637, 0.6931052872340426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 193}], {
             RGBColor[
             0.8681303085106384, 0.7669384680851065, 0.6135998617021277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 204}], {
             RGBColor[
             0.9091356595744682, 0.9283184680851064, 0.912443329787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 224}], {
             RGBColor[
             0.9123500957446808, 0.9292906595744681, 0.8332172765957446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 276}], {
             RGBColor[
             0.8446042127659574, 0.8789284893617021, 0.9850402978723405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 290}], {
             RGBColor[
             0.8987283936170213, 0.8848011276595744, 0.6561799148936169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 318}], {
             RGBColor[
             0.9119671489361703, 0.9294893617021276, 0.8655182234042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 203}], {
             RGBColor[
             0.9070576808510638, 0.6664134042553189, 0.24392936170212765`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 232}], {
             RGBColor[
             0.9482958936170213, 0.8265100851063829, 0.30958407446808506`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 257}], {
             RGBColor[
             0.9526227340425532, 0.8537069148936169, 0.5711886382978723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 275}], {
             RGBColor[
             0.9302477765957446, 0.8372549148936169, 0.6195966382978724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 280}], {
             RGBColor[
             0.9042791595744681, 0.8166812765957446, 0.6217320319148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 288}], {
             RGBColor[
             0.9568699680851064, 0.8554632553191488, 0.5008009787234042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 297}], {
             RGBColor[
             0.9568699680851064, 0.8554632553191488, 0.5008009787234042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 309}], {
             RGBColor[
             0.9426289680851063, 0.8464887872340425, 0.5986385106382979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 322}], {
             RGBColor[
             0.9565433829787234, 0.8537469361702128, 0.3912718617021275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 325}], {
             RGBColor[
             0.9561886170212766, 0.8529881276595744, 0.3526577765957445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 339}], {
             RGBColor[
             0.9196377234042553, 0.7190973829787233, 0.254196829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 172}], {
             RGBColor[
             0.9769540638297872, 0.9339227872340424, 0.364971319148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[
             0.9722893829787234, 0.9181877234042553, 0.34684991489361683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 243}], {
             RGBColor[
             0.9769540638297872, 0.9339227872340424, 0.364971319148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 279}], {
             RGBColor[
             0.9370266170212767, 0.7845899999999999, 0.2861484574468084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 285}], {
             RGBColor[
             0.9135023191489361, 0.678405808510638, 0.2665520106382977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 337}], {
             RGBColor[
             0.9604318617021276, 0.933549489361702, 0.646383414893617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 399}], {
             RGBColor[
             0.9808916382978723, 0.9461833829787233, 0.4671517872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 143}], {
             RGBColor[
             0.9747830319148936, 0.9308203829787234, 0.5434079680851063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 258}], {
             RGBColor[
             0.9582953404255319, 0.8709825319148935, 0.29248570212765945`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 277}], {
             RGBColor[
             0.9521757234042553, 0.8474099999999998, 0.2839696914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 302}], {
             RGBColor[
             0.9761987765957447, 0.931405829787234, 0.5199454148936169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 377}], {
             RGBColor[
             0.9761987765957447, 0.931405829787234, 0.5199454148936169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 378}], {
             RGBColor[
             0.9758721914893618, 0.9296895106382979, 0.41041629787234024`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 379}], {
             RGBColor[
             0.9755174255319149, 0.9289307021276596, 0.3718022127659572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 258}], {
             RGBColor[
             0.9747830319148936, 0.9308203829787234, 0.5434079680851063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 277}], {
             RGBColor[
             0.968663414893617, 0.9072478510638297, 0.5348919574468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 302}], {
             RGBColor[
             0.9926864680851064, 0.9912436808510638, 0.7708676808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 377}], {
             RGBColor[
             0.9926864680851064, 0.9912436808510638, 0.7708676808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 378}], {
             RGBColor[
             0.9923598829787235, 0.9895273617021276, 0.6613385638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 379}], {
             RGBColor[
             0.9920051170212766, 0.9887685531914894, 0.6227244787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 186}], {
             RGBColor[
             0.9769540638297872, 0.9339227872340424, 0.364971319148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 188}], {
             RGBColor[
             0.9635706276595745, 0.9604026808510637, 0.6931052872340426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 200}], {
             RGBColor[
             0.9697612234042553, 0.9650196170212766, 0.6826262234042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 228}], {
             RGBColor[
             0.986283425531915, 0.965392914893617, 0.4012141276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 333}], {
             RGBColor[0.990221, 0.9776535106382979, 0.5033945957446808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 368}], {
             RGBColor[
             0.9895114680851065, 0.9761358936170212, 0.4261664255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 200}], {
             RGBColor[
             0.9496475638297872, 0.8942418936170211, 0.6197459999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 207}], {
             RGBColor[
             0.9620287553191489, 0.9034757659574467, 0.5987878723404254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 222}], {
             RGBColor[
             0.9521757234042553, 0.8474099999999998, 0.2839696914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 254}], {
             RGBColor[
             0.9672476702127659, 0.9066624042553191, 0.5583545106382977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 333}], {
             RGBColor[
             0.9701073404255318, 0.9068757872340425, 0.44051437234042545`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 227}], {
             RGBColor[
             0.9635706276595745, 0.9604026808510637, 0.6931052872340426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 302}], {
             RGBColor[
             0.9901928191489362, 0.9786110212765957, 0.5743096276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 375}], {
             RGBColor[
             0.9661697659574469, 0.8946151914893616, 0.33833390425531906`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 377}], {
             RGBColor[
             0.9901928191489362, 0.9786110212765957, 0.5743096276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 344}], {
             RGBColor[
             0.9502358085106382, 0.8369600425531912, 0.2967768829787232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 354}], {
             RGBColor[
             0.9801821063829788, 0.9446657659574467, 0.38992361702127626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 371}], {
             RGBColor[
             0.9794477127659573, 0.9465554468085104, 0.5615293723404253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 388}], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 391}], {
             RGBColor[
             0.9812464042553191, 0.9469421914893617, 0.5057658723404252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 179}], {
             RGBColor[
             0.966798670212766, 0.9711456595744681, 0.7180575851063828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 232}], {
             RGBColor[
             0.9589059468085106, 0.9446676170212766, 0.6749838829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 257}], {
             RGBColor[
             0.9632327872340425, 0.9718644468085107, 0.9365884468085106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 275}], {
             RGBColor[
             0.940857829787234, 0.9554124468085106, 0.9849964468085107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 276}], {
             RGBColor[
             0.9001170851063829, 0.9230599148936169, 0.9857228617021276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 279}], {
             RGBColor[
             0.9236431808510639, 0.8110698936170213, 0.614282425531915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 288}], {
             RGBColor[
             0.9674800212765957, 0.9736207872340426, 0.8662007872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 195}], {
             RGBColor[
             0.9902379255319149, 0.989874085106383, 0.7854918404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 210}], {
             RGBColor[
             0.911953414893617, 0.6418527872340427, 0.5362444999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 247}], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 249}], {
             RGBColor[
             0.9891736276595744, 0.9875976595744682, 0.6696495851063827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 253}], {
             RGBColor[
             0.9460181382978723, 0.8275218936170214, 0.5658744255319148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 266}], {
             RGBColor[
             0.9766162234042552, 0.9453845531914893, 0.6084544787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 315}], {
             RGBColor[
             0.9891736276595744, 0.9875976595744682, 0.6696495851063827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 316}], {
             RGBColor[
             0.9766162234042552, 0.9453845531914893, 0.6084544787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 358}], {
             RGBColor[
             0.9526227340425532, 0.8537069148936169, 0.5711886382978723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 359}], {
             RGBColor[
             0.9283434574468085, 0.7478994468085107, 0.5511590425531914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 362}], {
             RGBColor[
             0.9902379255319149, 0.989874085106383, 0.7854918404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 363}], {
             RGBColor[
             0.9283434574468085, 0.7478994468085107, 0.5511590425531914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 369}], {
             RGBColor[
             0.981804574468085, 0.985715255319149, 0.9051512553191488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 397}], {
             RGBColor[
             0.9756139787234042, 0.9810983191489362, 0.9156303191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 192}], {
             RGBColor[
             0.9325906914893617, 0.7496557872340426, 0.48077138297872335`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 283}], {
             RGBColor[
             0.9319093404255319, 0.7471806595744681, 0.33262818085106366`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 294}], {
             RGBColor[
             0.9245402872340425, 0.745298255319149, 0.5681298510638297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 320}], {
             RGBColor[
             0.9322641063829787, 0.7479394680851065, 0.3712422659574467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 347}], {
             RGBColor[
             0.914687255319149, 0.6892324893617021, 0.2533116702127659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 380}], {
             RGBColor[
             0.9019630425531915, 0.6394749361702127, 0.2394814468085106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 381}], {
             RGBColor[
             0.9329736382978724, 0.7494570851063831, 0.44847043617021265`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 384}], {
             RGBColor[
             0.8827784042553191, 0.5606059361702127, 0.22389976595744682`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 168}], {
             RGBColor[
             0.9302477765957446, 0.8372549148936169, 0.6195966382978724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 265}], {
             RGBColor[
             0.9565433829787234, 0.8537469361702128, 0.3912718617021275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 291}], {
             RGBColor[
             0.9482958936170213, 0.8265100851063829, 0.30958407446808506`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 304}], {
             RGBColor[
             0.9262423191489362, 0.745282404255319, 0.25951104255319146`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 378}], {
             RGBColor[
             0.9565433829787234, 0.8537469361702128, 0.3912718617021275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 383}], {
             RGBColor[
             0.9529605744680851, 0.8422451489361702, 0.3277054787234042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 154}], {
             RGBColor[
             0.988777074468085, 0.978025574468085, 0.5977721808510639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 180}], {
             RGBColor[
             0.985945585106383, 0.9768546808510639, 0.6446972872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 198}], {
             RGBColor[
             0.988777074468085, 0.978025574468085, 0.5977721808510639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 236}], {
             RGBColor[
             0.985945585106383, 0.9768546808510639, 0.6446972872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 267}], {
             RGBColor[0.990221, 0.9776535106382979, 0.5033945957446808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 284}], {
             RGBColor[
             0.9722893829787234, 0.9181877234042553, 0.34684991489361694`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 332}], {
             RGBColor[
             0.9898662340425533, 0.9768947021276596, 0.46478051063829773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 367}], {
             RGBColor[
             0.988777074468085, 0.978025574468085, 0.5977721808510639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 383}], {
             RGBColor[
             0.986283425531915, 0.965392914893617, 0.4012141276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 398}], {
             RGBColor[
             0.9661697659574469, 0.8946151914893616, 0.33833390425531906`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 161}], {
             RGBColor[
             0.9860518085106382, 0.9874715957446809, 0.8347635957446807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 184}], {
             RGBColor[
             0.9941303936170213, 0.9908716170212766, 0.6764900957446808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[
             0.9926864680851064, 0.9912436808510638, 0.7708676808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 372}], {
             RGBColor[
             0.9944851595744681, 0.9916304255319148, 0.7151041808510636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 180}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 236}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 267}], {
             RGBColor[
             0.9927146489361702, 0.9902861702127659, 0.6999526489361703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 286}], {
             RGBColor[
             0.993069414893617, 0.9910449787234042, 0.738566734042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 291}], {
             RGBColor[
             0.9841123936170213, 0.9622905106382978, 0.5796507765957446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 332}], {
             RGBColor[
             0.9923598829787235, 0.9895273617021276, 0.6613385638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 383}], {
             RGBColor[
             0.988777074468085, 0.978025574468085, 0.5977721808510639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 170}], {
             RGBColor[
             0.9271222234042553, 0.9410695531914893, 0.8346262553191488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 171}], {
             RGBColor[
             0.9135005212765956, 0.8965800212765955, 0.6575888936170211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 199}], {
             RGBColor[
             0.9267674574468086, 0.940310744680851, 0.7960121702127659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 261}], {
             RGBColor[
             0.9264126914893618, 0.9395519361702127, 0.7573980851063828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.9088358404255319, 0.8808449574468085, 0.6394674893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 306}], {
             RGBColor[
             0.9253235319148936, 0.9406828085106382, 0.8903897553191489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 342}], {
             RGBColor[
             0.9267392765957447, 0.9412682553191489, 0.8669272021276595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 353}], {
             RGBColor[
             0.9224920425531915, 0.9395119148936171, 0.9373148617021276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 361}], {
             RGBColor[
             0.9264126914893618, 0.9395519361702127, 0.7573980851063828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 165}], {
             RGBColor[
             0.9895114680851065, 0.9761358936170212, 0.4261664255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 221}], {
             RGBColor[
             0.9905893723404255, 0.9881831063829788, 0.6461870319148934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 245}], {
             RGBColor[
             0.9112857978723405, 0.9270142340425532, 0.7173750212765956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 255}], {
             RGBColor[
             0.9927395106382979, 0.9868788723404256, 0.45111872340425496`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 328}], {
             RGBColor[
             0.9755174255319149, 0.9289307021276596, 0.3718022127659572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 364}], {
             RGBColor[
             0.9801821063829788, 0.9446657659574467, 0.38992361702127626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 386}], {
             RGBColor[
             0.9801821063829788, 0.9446657659574467, 0.38992361702127626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 400}], {
             RGBColor[
             0.9561886170212766, 0.8529881276595744, 0.3526577765957445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 181}], {
             RGBColor[
             0.9762269574468085, 0.9304483191489361, 0.44903038297872333`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 191}], {
             RGBColor[
             0.9719515425531915, 0.9296494893617021, 0.590333074468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 334}], {
             RGBColor[
             0.9681483723404255, 0.9270482978723404, 0.6073038829787233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 365}], {
             RGBColor[
             0.9733672872340425, 0.9302349361702127, 0.5668705212765957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 370}], {
             RGBColor[
             0.9758721914893618, 0.9296895106382979, 0.41041629787234024`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 209}], {
             RGBColor[
             0.9902379255319149, 0.989874085106383, 0.7854918404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 241}], {
             RGBColor[
             0.994513340425532, 0.9906729148936171, 0.6441891489361701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 270}], {
             RGBColor[
             0.993069414893617, 0.9910449787234042, 0.738566734042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 310}], {
             RGBColor[
             0.9572529148936171, 0.8552645531914893, 0.4685000319148935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 323}], {
             RGBColor[
             0.993069414893617, 0.9910449787234042, 0.738566734042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 324}], {
             RGBColor[
             0.9740535638297871, 0.9780390212765957, 0.8234207765957446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 346}], {
             RGBColor[
             0.9905757659574468, 0.9784123191489362, 0.5420086808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 390}], {
             RGBColor[
             0.9329736382978724, 0.7494570851063831, 0.44847043617021265`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 215}], {
             RGBColor[
             0.9756139787234042, 0.9810983191489362, 0.9156303191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 218}], {
             RGBColor[
             0.937264170212766, 0.9512908085106384, 0.9387238404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 329}], {
             RGBColor[
             0.987023489361702, 0.9889018936170213, 0.8647178936170211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 349}], {
             RGBColor[
             0.9632327872340425, 0.9718644468085107, 0.9365884468085106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 217}], {
             RGBColor[
             0.9492335638297872, 0.8726738085106381, 0.6039527234042552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 220}], {
             RGBColor[
             0.9619577765957447, 0.9224313617021276, 0.6177829468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 233}], {
             RGBColor[
             0.9798612127659574, 0.982854659574468, 0.845242659574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 244}], {
             RGBColor[
             0.9619577765957447, 0.9224313617021276, 0.6177829468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 263}], {
             RGBColor[
             0.9619577765957447, 0.9224313617021276, 0.6177829468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 264}], {
             RGBColor[
             0.9718108085106383, 0.9784971276595744, 0.9326011276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 307}], {
             RGBColor[
             0.9795346276595744, 0.9811383404255319, 0.7357135425531913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 312}], {
             RGBColor[
             0.9784454680851064, 0.9822692127659574, 0.8687052127659574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 321}], {
             RGBColor[
             0.9125000744680851, 0.7141195744680849, 0.5737278510638297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 341}], {
             RGBColor[
             0.955838159574468, 0.898858829787234, 0.6092669361702127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 348}], {
             RGBColor[
             0.9360243723404256, 0.8203037659574468, 0.5933242978723404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 366}], {
             RGBColor[
             0.9712871382978723, 0.9539014893617022, 0.6540257553191489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 176}], {
             RGBColor[
             0.9857252234042553, 0.9857552765957447, 0.7252344787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 184}], {
             RGBColor[
             0.986079989361702, 0.9865140851063829, 0.7638485638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 195}], {
             RGBColor[
             0.9864347553191489, 0.9872728936170213, 0.80246264893617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 250}], {
             RGBColor[
             0.9728130531914894, 0.9427833617021275, 0.6254252872340423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 344}], {
             RGBColor[
             0.955424159574468, 0.8772907446808509, 0.593473659574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.9846360638297872, 0.9868861489361702, 0.8582261489361702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 363}], {
             RGBColor[
             0.9245402872340425, 0.745298255319149, 0.5681298510638297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 372}], {
             RGBColor[
             0.9864347553191489, 0.9872728936170213, 0.80246264893617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 191}], {
             RGBColor[
             0.9766162234042552, 0.9453845531914893, 0.6084544787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 211}], {
             RGBColor[
             0.9812464042553191, 0.9469421914893617, 0.5057658723404252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 214}], {
             RGBColor[
             0.9766162234042552, 0.9453845531914893, 0.6084544787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 248}], {
             RGBColor[
             0.9766162234042552, 0.9453845531914893, 0.6084544787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 263}], {
             RGBColor[
             0.9629600212765956, 0.8867175957446807, 0.3106071063829785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 312}], {
             RGBColor[
             0.9794477127659573, 0.9465554468085104, 0.5615293723404253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 340}], {
             RGBColor[
             0.9808916382978723, 0.9461833829787233, 0.4671517872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 348}], {
             RGBColor[
             0.9370266170212767, 0.7845899999999999, 0.2861484574468084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 167}], {
             RGBColor[
             0.9761987765957447, 0.931405829787234, 0.5199454148936169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 174}], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.9926864680851064, 0.9912436808510638, 0.7708676808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 222}], {
             RGBColor[
             0.9761987765957447, 0.931405829787234, 0.5199454148936169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 226}], {
             RGBColor[
             0.9898549787234042, 0.9900727872340426, 0.8177927872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 395}], {
             RGBColor[
             0.9926864680851064, 0.9912436808510638, 0.7708676808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 287}], {
             RGBColor[
             0.9658319255319148, 0.9060769574468084, 0.581817063829787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 292}], {
             RGBColor[
             0.9027162234042553, 0.8572724255319147, 0.6309514787234043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 354}], {
             RGBColor[
             0.9693978085106383, 0.9053581702127659, 0.3632862021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 371}], {
             RGBColor[
             0.968663414893617, 0.9072478510638297, 0.5348919574468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 374}], {
             RGBColor[
             0.9661697659574469, 0.8946151914893616, 0.33833390425531906`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 388}], {
             RGBColor[
             0.9568404042553191, 0.8631450638297871, 0.3020910957446806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 389}], {
             RGBColor[
             0.9328469148936169, 0.7714674255319147, 0.2648252553191489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 391}], {
             RGBColor[
             0.9704621063829787, 0.9076345957446807, 0.4791284574468083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 182}], {
             RGBColor[
             0.9403805319148937, 0.7895611702127658, 0.31743801063829785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 256}], {
             RGBColor[
             0.9901928191489362, 0.9786110212765957, 0.5743096276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 281}], {
             RGBColor[
             0.9722893829787234, 0.9181877234042553, 0.34684991489361694`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 311}], {
             RGBColor[
             0.9523741382978723, 0.9516079361702128, 0.696649659574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 328}], {
             RGBColor[
             0.9722893829787234, 0.9181877234042553, 0.34684991489361694`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 386}], {
             RGBColor[
             0.9769540638297872, 0.9339227872340424, 0.364971319148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 400}], {
             RGBColor[
             0.9529605744680851, 0.8422451489361702, 0.3277054787234042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 169}], {
             RGBColor[
             0.9267692553191489, 0.7221365319148935, 0.4049752872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 178}], {
             RGBColor[0.990221, 0.9776535106382979, 0.5033945957446808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 197}], {
             RGBColor[
             0.9912989042553191, 0.9897007234042554, 0.7234152021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.9701073404255318, 0.9068757872340425, 0.44051437234042545`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 300}], {
             RGBColor[
             0.9808916382978723, 0.9461833829787233, 0.4671517872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 319}], {
             RGBColor[
             0.9912989042553191, 0.9897007234042554, 0.7234152021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 174}], {
             RGBColor[
             0.9761987765957447, 0.931405829787234, 0.5199454148936169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 183}], {
             RGBColor[
             0.9629600212765956, 0.8867175957446807, 0.3106071063829785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 189}], {
             RGBColor[
             0.9747830319148936, 0.9308203829787234, 0.5434079680851063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 222}], {
             RGBColor[
             0.9582953404255319, 0.8709825319148935, 0.29248570212765945`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 238}], {
             RGBColor[
             0.8286715851063831, 0.8179016382978723, 0.6315619574468084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 246}], {
             RGBColor[
             0.9557671808510637, 0.9178144255319148, 0.6282620106382979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 269}], {
             RGBColor[
             0.9762269574468085, 0.9304483191489361, 0.44903038297872333`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 272}], {
             RGBColor[
             0.9733672872340425, 0.9302349361702127, 0.5668705212765957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 309}], {
             RGBColor[
             0.9619577765957447, 0.9224313617021276, 0.6177829468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 395}], {
             RGBColor[
             0.9747830319148936, 0.9308203829787234, 0.5434079680851063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 265}], {
             RGBColor[
             0.9671534361702128, 0.9719044680851063, 0.7566716702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 304}], {
             RGBColor[
             0.9368523723404254, 0.8634399361702125, 0.6249108510638298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 378}], {
             RGBColor[
             0.9671534361702128, 0.9719044680851063, 0.7566716702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 177}], {
             RGBColor[
             0.9264144893617021, 0.7213777234042552, 0.36636120212765944`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 178}], {
             RGBColor[
             0.9228316808510638, 0.7098759361702126, 0.30279481914893613`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 197}], {
             RGBColor[
             0.923909585106383, 0.7219231489361702, 0.5228154255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 239}], {
             RGBColor[
             0.9027180212765957, 0.6390982127659572, 0.23991459574468077`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 300}], {
             RGBColor[
             0.9135023191489361, 0.678405808510638, 0.2665520106382977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 319}], {
             RGBColor[
             0.923909585106383, 0.7219231489361702, 0.5228154255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 171}], {
             RGBColor[
             0.9812464042553191, 0.9469421914893617, 0.5057658723404252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 187}], {
             RGBColor[
             0.985911085106383, 0.9626772553191489, 0.5238872765957445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 261}], {
             RGBColor[
             0.9941585744680852, 0.9899141063829788, 0.605575063829787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 299}], {
             RGBColor[
             0.9765817234042553, 0.9312071276595744, 0.4876444680851062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 306}], {
             RGBColor[
             0.993069414893617, 0.9910449787234042, 0.738566734042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 353}], {
             RGBColor[
             0.9902379255319149, 0.989874085106383, 0.7854918404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 361}], {
             RGBColor[
             0.9941585744680852, 0.9899141063829788, 0.605575063829787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 299}], {
             RGBColor[
             0.9629600212765956, 0.8867175957446807, 0.3106071063829785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 306}], {
             RGBColor[
             0.9794477127659573, 0.9465554468085104, 0.5615293723404253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 342}], {
             RGBColor[
             0.9808634574468085, 0.9471408936170211, 0.538066819148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 353}], {
             RGBColor[
             0.9766162234042552, 0.9453845531914893, 0.6084544787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 208}], {
             RGBColor[
             0.9905757659574468, 0.9784123191489362, 0.5420086808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 225}], {
             RGBColor[
             0.9769540638297872, 0.9339227872340424, 0.364971319148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 240}], {
             RGBColor[
             0.9816187446808511, 0.9496578510638298, 0.38309272340425526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 243}], {
             RGBColor[
             0.986283425531915, 0.965392914893617, 0.4012141276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 285}], {
             RGBColor[
             0.9228316808510638, 0.7098759361702126, 0.30279481914893613`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 337}], {
             RGBColor[
             0.9697612234042553, 0.9650196170212766, 0.6826262234042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 357}], {
             RGBColor[
             0.9403805319148937, 0.7895611702127658, 0.31743801063829785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 399}], {
             RGBColor[0.990221, 0.9776535106382979, 0.5033945957446808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 176}], {
             RGBColor[
             0.9923598829787235, 0.9895273617021276, 0.6613385638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 209}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 250}], {
             RGBColor[
             0.9794477127659573, 0.9465554468085104, 0.5615293723404253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 323}], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 354}], {
             RGBColor[
             0.9920051170212766, 0.9887685531914894, 0.6227244787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 388}], {
             RGBColor[
             0.9794477127659573, 0.9465554468085104, 0.5615293723404253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 183}], {
             RGBColor[
             0.9808634574468085, 0.9471408936170211, 0.538066819148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 189}], {
             RGBColor[
             0.9926864680851064, 0.9912436808510638, 0.7708676808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 238}], {
             RGBColor[
             0.8465750212765959, 0.8783249361702128, 0.8590216702127659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 246}], {
             RGBColor[
             0.9736706170212766, 0.9782377234042553, 0.8557217234042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 269}], {
             RGBColor[
             0.9941303936170213, 0.9908716170212766, 0.6764900957446808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 272}], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 309}], {
             RGBColor[
             0.9798612127659574, 0.982854659574468, 0.845242659574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 325}], {
             RGBColor[
             0.9934208617021276, 0.9893540000000001, 0.5992619255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 395}], {
             RGBColor[
             0.9926864680851064, 0.9912436808510638, 0.7708676808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 178}], {
             RGBColor[
             0.9816187446808511, 0.9496578510638298, 0.38309272340425526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 213}], {
             RGBColor[
             0.9676247021276596, 0.902452659574468, 0.3287285106382978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 227}], {
             RGBColor[
             0.9589059468085106, 0.9446676170212766, 0.6749838829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 278}], {
             RGBColor[
             0.9855281382978723, 0.9628759574468084, 0.5561882234042552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 296}], {
             RGBColor[
             0.9812809042553191, 0.9611196170212766, 0.6265758829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 314}], {
             RGBColor[
             0.9549004893617021, 0.8526951063829786, 0.31489828723404245`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 319}], {
             RGBColor[
             0.9826966489361701, 0.9617050638297873, 0.603113329787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 352}], {
             RGBColor[
             0.9769540638297872, 0.9339227872340425, 0.3649713191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 250}], {
             RGBColor[
             0.9805368723404255, 0.945424574468085, 0.4285377021276593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 344}], {
             RGBColor[
             0.9631479787234043, 0.8799319574468084, 0.3965860744680849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 354}], {
             RGBColor[
             0.9930942765957447, 0.9876376808510638, 0.489732808510638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 356}], {
             RGBColor[
             0.9923598829787235, 0.9895273617021276, 0.6613385638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 372}], {
             RGBColor[
             0.9941585744680852, 0.9899141063829788, 0.605575063829787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 388}], {
             RGBColor[
             0.9805368723404255, 0.945424574468085, 0.4285377021276593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 197}], {
             RGBColor[
             0.9909441382978723, 0.9889419148936172, 0.6848011170212764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 225}], {
             RGBColor[
             0.9805368723404255, 0.945424574468085, 0.4285377021276593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 243}], {
             RGBColor[
             0.9898662340425533, 0.9768947021276596, 0.46478051063829773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 252}], {
             RGBColor[
             0.9898662340425533, 0.9768947021276596, 0.46478051063829773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 300}], {
             RGBColor[
             0.9805368723404255, 0.945424574468085, 0.4285377021276593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 337}], {
             RGBColor[
             0.9733440319148936, 0.9765214042553192, 0.7461926063829787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 367}], {
             RGBColor[
             0.9923598829787235, 0.9895273617021276, 0.6613385638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 398}], {
             RGBColor[
             0.969752574468085, 0.9061169787234042, 0.40190028723404236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 197}], {
             RGBColor[
             0.9873613297872341, 0.9774401276595746, 0.621234734042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 274}], {
             RGBColor[
             0.9722893829787234, 0.9181877234042553, 0.34684991489361694`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 278}], {
             RGBColor[
             0.9901928191489362, 0.9786110212765957, 0.5743096276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 300}], {
             RGBColor[
             0.9769540638297872, 0.9339227872340424, 0.364971319148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 319}], {
             RGBColor[
             0.9873613297872341, 0.9774401276595746, 0.621234734042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 352}], {
             RGBColor[
             0.9816187446808511, 0.9496578510638298, 0.38309272340425526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 232}], {
             RGBColor[
             0.9848467872340425, 0.9604008297872341, 0.40804502127659553`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 257}], {
             RGBColor[
             0.9891736276595744, 0.9875976595744682, 0.6696495851063827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 275}], {
             RGBColor[
             0.966798670212766, 0.9711456595744681, 0.7180575851063828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 279}], {
             RGBColor[
             0.9495840212765958, 0.8268031063829788, 0.3473435638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 285}], {
             RGBColor[
             0.9260597234042554, 0.7206189148936168, 0.3277471170212764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 288}], {
             RGBColor[
             0.9934208617021276, 0.9893540000000001, 0.5992619255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 399}], {
             RGBColor[
             0.9934490425531914, 0.9883964893617021, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 198}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 236}], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 262}], {
             RGBColor[
             0.9891736276595744, 0.9875976595744682, 0.6696495851063827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 267}], {
             RGBColor[
             0.989883159574468, 0.9891152765957447, 0.7468777553191488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 284}], {
             RGBColor[
             0.9719515425531915, 0.9296494893617021, 0.590333074468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 286}], {
             RGBColor[
             0.9902379255319149, 0.989874085106383, 0.7854918404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 332}], {
             RGBColor[
             0.9895283936170213, 0.9883564680851065, 0.7082636702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 367}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 398}], {
             RGBColor[
             0.9658319255319148, 0.9060769574468084, 0.5818170638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 191}], {
             RGBColor[
             0.989883159574468, 0.9891152765957447, 0.7468777553191488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 211}], {
             RGBColor[
             0.994513340425532, 0.9906729148936171, 0.6441891489361701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 214}], {
             RGBColor[
             0.989883159574468, 0.9891152765957447, 0.7468777553191488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 305}], {
             RGBColor[
             0.9941303936170213, 0.9908716170212766, 0.6764900957446808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 334}], {
             RGBColor[
             0.986079989361702, 0.9865140851063829, 0.7638485638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 340}], {
             RGBColor[
             0.9941585744680851, 0.9899141063829787, 0.6055750638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 365}], {
             RGBColor[
             0.9912989042553191, 0.9897007234042554, 0.7234152021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 370}], {
             RGBColor[
             0.9938038085106383, 0.9891552978723405, 0.5669609787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 256}], {
             RGBColor[
             0.9442899255319148, 0.8027792765957446, 0.49053351063829775`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 281}], {
             RGBColor[
             0.9263864893617021, 0.7423559787234041, 0.26307379787234036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 311}], {
             RGBColor[
             0.906471244680851, 0.7757761914893616, 0.6128735425531915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 386}], {
             RGBColor[
             0.931051170212766, 0.7580910425531913, 0.2811952021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 238}], {
             RGBColor[
             0.8333362659574468, 0.8336367021276596, 0.6496833617021275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 246}], {
             RGBColor[
             0.9604318617021276, 0.933549489361702, 0.646383414893617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 269}], {
             RGBColor[
             0.9808916382978723, 0.9461833829787233, 0.4671517872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 272}], {
             RGBColor[0.9780319680851064, 0.94597, 0.5849919255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 280}], {
             RGBColor[
             0.9282726489361701, 0.9083589148936169, 0.6589978723404254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 309}], {
             RGBColor[
             0.9666224574468085, 0.9381664255319148, 0.6359043510638296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 325}], {
             RGBColor[
             0.9801821063829788, 0.9446657659574467, 0.38992361702127626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 339}], {
             RGBColor[
             0.9436312127659574, 0.8107750212765956, 0.2914626702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 395}], {
             RGBColor[
             0.9794477127659573, 0.9465554468085104, 0.5615293723404253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 343}], {
             RGBColor[
             0.9855563191489362, 0.9619184468085107, 0.48527319148936165`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 356}], {
             RGBColor[
             0.9927146489361702, 0.9902861702127659, 0.6999526489361703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 369}], {
             RGBColor[
             0.986079989361702, 0.9865140851063829, 0.7638485638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 372}], {
             RGBColor[
             0.994513340425532, 0.9906729148936171, 0.6441891489361701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 198}], {
             RGBColor[
             0.9311749468085107, 0.7490703404255319, 0.5042339361702128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 205}], {
             RGBColor[
             0.8887538510638298, 0.5871048936170213, 0.2288530212765958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 208}], {
             RGBColor[
             0.9329736382978724, 0.7494570851063831, 0.44847043617021265`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 210}], {
             RGBColor[
             0.8546891276595745, 0.40143578723404266`, 0.19922309574468086`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 219}], {
             RGBColor[
             0.9085676382978722, 0.6656599574468085, 0.24479565957446806`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 249}], {
             RGBColor[
             0.9319093404255319, 0.7471806595744681, 0.33262818085106366`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 284}], {
             RGBColor[
             0.914687255319149, 0.6892324893617021, 0.2533116702127659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 293}], {
             RGBColor[
             0.9245402872340425, 0.745298255319149, 0.5681298510638297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 338}], {
             RGBColor[
             0.8947720106382979, 0.7226527021276596, 0.603111414893617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 188}], {
             RGBColor[
             0.9542412659574467, 0.9289325531914892, 0.6568624787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 228}], {
             RGBColor[
             0.9769540638297872, 0.9339227872340424, 0.364971319148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 238}], {
             RGBColor[
             0.8333362659574468, 0.8336367021276596, 0.6496833617021275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 273}], {
             RGBColor[
             0.9436312127659574, 0.8107750212765956, 0.2914626702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 322}], {
             RGBColor[
             0.9805368723404255, 0.945424574468085, 0.4285377021276593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 330}], {
             RGBColor[
             0.9805368723404255, 0.945424574468085, 0.4285377021276593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 206}], {
             RGBColor[
             0.9852015531914894, 0.9611596382978724, 0.44665910638297857`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 220}], {
             RGBColor[
             0.9676247021276596, 0.902452659574468, 0.3287285106382978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 261}], {
             RGBColor[
             0.9852015531914894, 0.9611596382978724, 0.44665910638297857`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 321}], {
             RGBColor[0.918167, 0.6941408723404254, 0.28467341489361697`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 228}], {
             RGBColor[
             0.9635706276595745, 0.9604026808510637, 0.6931052872340426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 238}], {
             RGBColor[
             0.819952829787234, 0.8601165957446809, 0.9778173297872341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 273}], {
             RGBColor[
             0.9302477765957446, 0.8372549148936169, 0.6195966382978724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 322}], {
             RGBColor[
             0.9671534361702128, 0.9719044680851063, 0.7566716702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 330}], {
             RGBColor[
             0.9671534361702128, 0.9719044680851063, 0.7566716702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 222}], {
             RGBColor[
             0.9747830319148936, 0.9308203829787234, 0.5434079680851063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 226}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 395}], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 212}], {
             RGBColor[
             0.9927146489361702, 0.9902861702127659, 0.6999526489361703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 221}], {
             RGBColor[
             0.9898549787234042, 0.9900727872340426, 0.8177927872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 255}], {
             RGBColor[
             0.9920051170212766, 0.9887685531914894, 0.6227244787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 268}], {
             RGBColor[
             0.9841123936170213, 0.9622905106382978, 0.5796507765957446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 270}], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 274}], {
             RGBColor[
             0.9747830319148936, 0.9308203829787234, 0.5434079680851063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 295}], {
             RGBColor[
             0.9548677872340425, 0.9642405957446809, 0.8932077127659575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 324}], {
             RGBColor[
             0.9722548723404254, 0.9776522765957447, 0.8791842765957447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 351}], {
             RGBColor[
             0.9660642765957446, 0.9730353404255319, 0.889663340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 211}], {
             RGBColor[
             0.9902379255319149, 0.989874085106383, 0.7854918404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 214}], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 312}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 334}], {
             RGBColor[
             0.981804574468085, 0.985715255319149, 0.9051512553191488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 340}], {
             RGBColor[
             0.989883159574468, 0.9891152765957447, 0.7468777553191488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 365}], {
             RGBColor[
             0.987023489361702, 0.9889018936170213, 0.8647178936170211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 370}], {
             RGBColor[
             0.9895283936170213, 0.9883564680851065, 0.7082636702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 292}], {
             RGBColor[
             0.9267392765957447, 0.9412682553191489, 0.8669272021276595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 320}], {
             RGBColor[
             0.9937756276595745, 0.9901128085106383, 0.6378760106382977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 347}], {
             RGBColor[
             0.9761987765957447, 0.931405829787234, 0.5199454148936169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 374}], {
             RGBColor[
             0.9901928191489362, 0.9786110212765957, 0.5743096276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 382}], {
             RGBColor[
             0.9442899255319148, 0.8027792765957446, 0.4905335106382978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 384}], {
             RGBColor[
             0.9442899255319148, 0.8027792765957446, 0.4905335106382978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 248}], {
             RGBColor[
             0.9460181382978723, 0.8275218936170214, 0.5658744255319148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 305}], {
             RGBColor[
             0.9502653723404255, 0.8292782340425533, 0.4954867659574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 334}], {
             RGBColor[
             0.9422149680851064, 0.8249207021276597, 0.5828452340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 360}], {
             RGBColor[
             0.9499387872340426, 0.8275619148936171, 0.38595764893617013`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 201}], {
             RGBColor[
             0.9549004893617021, 0.8526951063829786, 0.31489828723404245`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 208}], {
             RGBColor[
             0.9638575106382978, 0.881449574468085, 0.47381424468085087`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 223}], {
             RGBColor[
             0.959227329787234, 0.8798919361702127, 0.5765028510638297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 230}], {
             RGBColor[
             0.9019630425531915, 0.6394749361702127, 0.2394814468085106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 242}], {
             RGBColor[
             0.9502358085106382, 0.8369600425531912, 0.2967768829787232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 357}], {
             RGBColor[
             0.9136622765957446, 0.6925984255319146, 0.24924357446808504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 364}], {
             RGBColor[
             0.9502358085106382, 0.8369600425531912, 0.2967768829787232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 385}], {
             RGBColor[
             0.955424159574468, 0.8772907446808509, 0.5934736595744681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 387}], {
             RGBColor[
             0.8961116276595744, 0.8310874042553189, 0.6256372659574467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 247}], {
             RGBColor[
             0.9902379255319149, 0.989874085106383, 0.7854918404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 253}], {
             RGBColor[
             0.9506483191489362, 0.8290795319148937, 0.4631858191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 315}], {
             RGBColor[
             0.9938038085106383, 0.9891552978723405, 0.566960978723404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 316}], {
             RGBColor[
             0.9812464042553191, 0.9469421914893617, 0.5057658723404252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 343}], {
             RGBColor[
             0.985911085106383, 0.9626772553191489, 0.5238872765957445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 358}], {
             RGBColor[
             0.9572529148936171, 0.8552645531914893, 0.4685000319148935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 359}], {
             RGBColor[
             0.9329736382978724, 0.7494570851063831, 0.44847043617021265`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 362}], {
             RGBColor[
             0.9948681063829787, 0.9914317234042553, 0.6828032340425529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 363}], {
             RGBColor[
             0.9329736382978724, 0.7494570851063831, 0.44847043617021265`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 369}], {
             RGBColor[
             0.9864347553191489, 0.9872728936170213, 0.80246264893617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 372}], {
             RGBColor[
             0.9948681063829787, 0.9914317234042553, 0.6828032340425529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 397}], {
             RGBColor[
             0.9802441595744681, 0.9826559574468086, 0.8129417127659573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 289}], {
             RGBColor[
             0.9566664787234043, 0.9646273404255319, 0.8374442127659574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 317}], {
             RGBColor[
             0.9638575106382978, 0.881449574468085, 0.47381424468085087`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 326}], {
             RGBColor[
             0.9944851595744681, 0.9916304255319148, 0.7151041808510636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 327}], {
             RGBColor[
             0.9802441595744681, 0.9826559574468086, 0.8129417127659573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 336}], {
             RGBColor[
             0.993069414893617, 0.9910449787234042, 0.738566734042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 376}], {
             RGBColor[
             0.9938038085106383, 0.9891552978723405, 0.566960978723404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 252}], {
             RGBColor[
             0.9873613297872341, 0.9774401276595746, 0.621234734042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 300}], {
             RGBColor[0.9780319680851064, 0.94597, 0.5849919255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 205}], {
             RGBColor[
             0.9488496276595745, 0.8286927872340426, 0.5189493191489363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 219}], {
             RGBColor[
             0.968663414893617, 0.9072478510638297, 0.5348919574468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 236}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 284}], {
             RGBColor[
             0.9747830319148936, 0.9308203829787234, 0.5434079680851063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 332}], {
             RGBColor[
             0.9923598829787235, 0.9895273617021276, 0.6613385638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 367}], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 398}], {
             RGBColor[
             0.968663414893617, 0.9072478510638297, 0.5348919574468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 216}], {
             RGBColor[
             0.9941585744680851, 0.9899141063829787, 0.6055750638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 298}], {
             RGBColor[
             0.994513340425532, 0.9906729148936171, 0.6441891489361701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 299}], {
             RGBColor[
             0.9762269574468085, 0.9304483191489361, 0.44903038297872333`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 306}], {
             RGBColor[
             0.9927146489361702, 0.9902861702127659, 0.6999526489361703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 342}], {
             RGBColor[
             0.9941303936170213, 0.9908716170212766, 0.6764900957446808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 353}], {
             RGBColor[
             0.989883159574468, 0.9891152765957447, 0.7468777553191488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 361}], {
             RGBColor[
             0.9938038085106383, 0.9891552978723405, 0.5669609787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 393}], {
             RGBColor[
             0.9912989042553191, 0.9897007234042554, 0.7234152021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 207}], {
             RGBColor[
             0.9656202127659574, 0.9738801914893618, 0.9430801914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 333}], {
             RGBColor[
             0.9736987978723404, 0.9772802127659574, 0.7848066914893617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 368}], {
             RGBColor[
             0.9729892659574468, 0.9757625957446809, 0.7075785212765956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 223}], {
             RGBColor[
             0.9812809042553191, 0.9611196170212766, 0.6265758829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 230}], {
             RGBColor[
             0.9240166170212766, 0.7207026170212767, 0.28955447872340423`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 245}], {
             RGBColor[
             0.9033930744680851, 0.9005361914893617, 0.6743013191489362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 364}], {
             RGBColor[
             0.9722893829787234, 0.9181877234042553, 0.34684991489361683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 385}], {
             RGBColor[
             0.9774777340425531, 0.9585184255319149, 0.6435466914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 218}], {
             RGBColor[
             0.9282726489361701, 0.9083589148936169, 0.6589978723404254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 229}], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 260}], {
             RGBColor[
             0.9542412659574467, 0.9289325531914892, 0.6568624787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 307}], {
             RGBColor[
             0.9805368723404255, 0.945424574468085, 0.4285377021276593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 341}], {
             RGBColor[
             0.9568404042553191, 0.8631450638297871, 0.3020910957446806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 349}], {
             RGBColor[
             0.9542412659574467, 0.9289325531914892, 0.6568624787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 366}], {
             RGBColor[
             0.9722893829787234, 0.9181877234042553, 0.34684991489361683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 232}], {
             RGBColor[
             0.9357158510638297, 0.7738261063829786, 0.2993166063829787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 257}], {
             RGBColor[
             0.9400426914893616, 0.8010229361702127, 0.5609211702127659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 275}], {
             RGBColor[
             0.9176677340425532, 0.7845709361702127, 0.609329170212766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 280}], {
             RGBColor[
             0.8916991170212766, 0.7639972978723404, 0.6114645638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 297}], {
             RGBColor[
             0.9442899255319148, 0.8027792765957446, 0.49053351063829775`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 309}], {
             RGBColor[
             0.9300489255319149, 0.7938048085106382, 0.5883710425531914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 322}], {
             RGBColor[
             0.9439633404255319, 0.8010629574468084, 0.3810043936170211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 325}], {
             RGBColor[
             0.9436085744680851, 0.8003041489361702, 0.3423903085106381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 339}], {
             RGBColor[
             0.9070576808510638, 0.6664134042553189, 0.24392936170212765`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 224}], {
             RGBColor[
             0.991653670212766, 0.9904595319148937, 0.7620292872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 276}], {
             RGBColor[
             0.9239077872340425, 0.9400973617021277, 0.9138523085106383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 290}], {
             RGBColor[0.9780319680851064, 0.94597, 0.5849919255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 297}], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 318}], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 345}], {
             RGBColor[
             0.9898549787234042, 0.9900727872340426, 0.8177927872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 219}], {
             RGBColor[
             0.9262423191489362, 0.7452824042553191, 0.25951104255319146`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 284}], {
             RGBColor[
             0.9323619361702128, 0.7688549361702128, 0.26802705319148934`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 293}], {
             RGBColor[
             0.9422149680851064, 0.8249207021276597, 0.5828452340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 338}], {
             RGBColor[
             0.9124466914893617, 0.8022751489361704, 0.6178267978723404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 220}], {
             RGBColor[
             0.9758721914893618, 0.9296895106382979, 0.41041629787234024`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 321}], {
             RGBColor[
             0.9264144893617021, 0.7213777234042552, 0.36636120212765944`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 328}], {
             RGBColor[
             0.9758721914893618, 0.9296895106382979, 0.41041629787234024`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 386}], {
             RGBColor[
             0.9805368723404255, 0.945424574468085, 0.4285377021276593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 254}], {
             RGBColor[
             0.9832203191489362, 0.9863007021276596, 0.8816887021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 333}], {
             RGBColor[
             0.986079989361702, 0.9865140851063829, 0.7638485638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 230}], {
             RGBColor[
             0.9329736382978724, 0.7494570851063831, 0.44847043617021265`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 240}], {
             RGBColor[
             0.985911085106383, 0.9626772553191489, 0.5238872765957445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 242}], {
             RGBColor[
             0.9812464042553191, 0.9469421914893617, 0.5057658723404252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 357}], {
             RGBColor[
             0.9446728723404255, 0.802580574468085, 0.4582325638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 385}], {
             RGBColor[
             0.9864347553191489, 0.9872728936170213, 0.80246264893617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 387}], {
             RGBColor[
             0.9271222234042553, 0.9410695531914893, 0.8346262553191488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 241}], {
             RGBColor[
             0.989883159574468, 0.9891152765957447, 0.7468777553191488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 270}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 310}], {
             RGBColor[
             0.9526227340425532, 0.8537069148936169, 0.5711886382978723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 323}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 346}], {
             RGBColor[
             0.985945585106383, 0.9768546808510639, 0.6446972872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 390}], {
             RGBColor[
             0.9283434574468085, 0.7478994468085107, 0.5511590425531914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 249}], {
             RGBColor[
             0.9155192978723404, 0.6411340000000001, 0.31771363829787214`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 266}], {
             RGBColor[
             0.9029618936170212, 0.5989208936170212, 0.2565185319148935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 293}], {
             RGBColor[
             0.908150244680851, 0.6392515957446809, 0.5532153085106382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 315}], {
             RGBColor[
             0.9155192978723404, 0.6411340000000001, 0.31771363829787214`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 316}], {
             RGBColor[
             0.9029618936170212, 0.5989208936170212, 0.2565185319148935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 387}], {
             RGBColor[
             0.8488377127659574, 0.593048255319149, 0.585378914893617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 397}], {
             RGBColor[
             0.9019596489361702, 0.6346346595744681, 0.5636943723404255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 214}], {
             RGBColor[
             0.9902379255319149, 0.989874085106383, 0.7854918404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 248}], {
             RGBColor[
             0.9902379255319149, 0.989874085106383, 0.7854918404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 263}], {
             RGBColor[
             0.9765817234042553, 0.9312071276595744, 0.4876444680851062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 312}], {
             RGBColor[
             0.993069414893617, 0.9910449787234042, 0.738566734042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 334}], {
             RGBColor[
             0.9864347553191489, 0.9872728936170213, 0.80246264893617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 340}], {
             RGBColor[
             0.994513340425532, 0.9906729148936171, 0.6441891489361701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 370}], {
             RGBColor[
             0.9941585744680852, 0.9899141063829788, 0.605575063829787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 268}], {
             RGBColor[
             0.9855563191489362, 0.9619184468085107, 0.48527319148936165`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 270}], {
             RGBColor[
             0.9927146489361702, 0.9902861702127659, 0.6999526489361703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 274}], {
             RGBColor[
             0.9762269574468085, 0.9304483191489361, 0.44903038297872333`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 295}], {
             RGBColor[
             0.9563117127659575, 0.9638685319148936, 0.7988301276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 310}], {
             RGBColor[
             0.9568981489361702, 0.854505744680851, 0.4298859468085106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 324}], {
             RGBColor[
             0.9736987978723404, 0.9772802127659574, 0.7848066914893617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 351}], {
             RGBColor[
             0.9675082021276595, 0.9726632765957446, 0.795285755319149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 373}], {
             RGBColor[
             0.9502935531914893, 0.8283207234042553, 0.4245717340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 390}], {
             RGBColor[
             0.9326188723404255, 0.7486982765957447, 0.4098563510638298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 227}], {
             RGBColor[
             0.9495765851063829, 0.9131974893617021, 0.638741074468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 296}], {
             RGBColor[
             0.9719515425531915, 0.9296494893617021, 0.590333074468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 308}], {
             RGBColor[
             0.9629600212765956, 0.8867175957446807, 0.3106071063829785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 352}], {
             RGBColor[
             0.9676247021276596, 0.902452659574468, 0.3287285106382978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 248}], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 263}], {
             RGBColor[
             0.9719515425531915, 0.9296494893617021, 0.590333074468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 312}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 340}], {
             RGBColor[
             0.989883159574468, 0.9891152765957447, 0.7468777553191488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 218}], {
             RGBColor[
             0.9272704042553191, 0.9440726808510638, 0.9661737127659574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 229}], {
             RGBColor[
             0.9666224574468085, 0.9381664255319148, 0.6359043510638296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 329}], {
             RGBColor[
             0.9770297234042553, 0.9816837659574469, 0.8921677659574467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 349}], {
             RGBColor[
             0.9532390212765958, 0.9646463191489361, 0.9640383191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 231}], {
             RGBColor[
             0.9675082021276595, 0.9726632765957446, 0.795285755319149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 235}], {
             RGBColor[
             0.9941303936170213, 0.9908716170212766, 0.6764900957446808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 298}], {
             RGBColor[
             0.994513340425532, 0.9906729148936171, 0.6441891489361701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 313}], {
             RGBColor[
             0.9701073404255318, 0.9068757872340425, 0.44051437234042545`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 361}], {
             RGBColor[
             0.9938038085106383, 0.9891552978723405, 0.5669609787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 393}], {
             RGBColor[
             0.9912989042553191, 0.9897007234042554, 0.7234152021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 396}], {
             RGBColor[
             0.9855563191489362, 0.9619184468085107, 0.48527319148936165`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 220}], {
             RGBColor[
             0.9455711276595744, 0.821224978723404, 0.2786554787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 230}], {
             RGBColor[
             0.9019630425531915, 0.6394749361702127, 0.2394814468085106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 233}], {
             RGBColor[
             0.9634745638297872, 0.8816482765957445, 0.5061151914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 242}], {
             RGBColor[
             0.9502358085106382, 0.8369600425531912, 0.2967768829787232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 244}], {
             RGBColor[
             0.9455711276595744, 0.821224978723404, 0.2786554787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 264}], {
             RGBColor[
             0.955424159574468, 0.8772907446808509, 0.5934736595744681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 321}], {
             RGBColor[
             0.8961134255319148, 0.6129131914893614, 0.23460038297872332`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 357}], {
             RGBColor[
             0.9136622765957446, 0.6925984255319146, 0.24924357446808504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 364}], {
             RGBColor[
             0.9502358085106382, 0.8369600425531912, 0.2967768829787232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 366}], {
             RGBColor[
             0.9549004893617021, 0.8526951063829786, 0.31489828723404245`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 229}], {
             RGBColor[
             0.9282726489361701, 0.9083589148936169, 0.6589978723404254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 260}], {
             RGBColor[
             0.9148892127659574, 0.9348388085106383, 0.987131840425532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 329}], {
             RGBColor[
             0.938679914893617, 0.951876255319149, 0.9152612872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 349}], {
             RGBColor[
             0.9148892127659574, 0.9348388085106383, 0.987131840425532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 284}], {
             RGBColor[
             0.9521757234042553, 0.8474099999999998, 0.2839696914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 293}], {
             RGBColor[
             0.9620287553191489, 0.9034757659574467, 0.5987878723404254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 338}], {
             RGBColor[
             0.9322604787234042, 0.8808302127659573, 0.6337694361702126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 233}], {
             RGBColor[
             0.9761987765957447, 0.931405829787234, 0.5199454148936169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 244}], {
             RGBColor[
             0.9582953404255319, 0.8709825319148935, 0.29248570212765945`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 321}], {
             RGBColor[
             0.9088376382978722, 0.6626707446808509, 0.24843060638297865`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 341}], {
             RGBColor[
             0.9521757234042553, 0.8474099999999998, 0.2839696914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 366}], {
             RGBColor[
             0.9676247021276596, 0.902452659574468, 0.3287285106382978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 239}], {
             RGBColor[
             0.9672476702127659, 0.9066624042553191, 0.5583545106382978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 255}], {
             RGBColor[
             0.9905893723404255, 0.9881831063829788, 0.6461870319148934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 268}], {
             RGBColor[
             0.9826966489361701, 0.9617050638297873, 0.603113329787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 324}], {
             RGBColor[
             0.9708391276595745, 0.977066829787234, 0.902646829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 351}], {
             RGBColor[
             0.9646485319148936, 0.9724498936170213, 0.9131258936170212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 400}], {
             RGBColor[
             0.9540384787234042, 0.8542923617021276, 0.5477260851063829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 333}], {
             RGBColor[
             0.9762269574468085, 0.9304483191489361, 0.44903038297872333`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 230}], {
             RGBColor[
             0.9283434574468085, 0.7478994468085107, 0.5511590425531914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 242}], {
             RGBColor[
             0.9766162234042552, 0.9453845531914893, 0.6084544787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 245}], {
             RGBColor[
             0.907719914893617, 0.9277330212765957, 0.9359058829787233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 328}], {
             RGBColor[
             0.9719515425531915, 0.9296494893617021, 0.590333074468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 364}], {
             RGBColor[
             0.9766162234042552, 0.9453845531914893, 0.6084544787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 385}], {
             RGBColor[
             0.981804574468085, 0.985715255319149, 0.9051512553191488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 290}], {
             RGBColor[
             0.9812464042553191, 0.9469421914893617, 0.5057658723404252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 318}], {
             RGBColor[
             0.9944851595744681, 0.9916304255319148, 0.7151041808510636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 345}], {
             RGBColor[
             0.993069414893617, 0.9910449787234042, 0.738566734042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 240}], {
             RGBColor[
             0.9722893829787234, 0.9181877234042553, 0.34684991489361683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 243}], {
             RGBColor[
             0.9769540638297872, 0.9339227872340424, 0.364971319148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 337}], {
             RGBColor[
             0.9604318617021276, 0.933549489361702, 0.646383414893617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 367}], {
             RGBColor[
             0.9794477127659573, 0.9465554468085104, 0.5615293723404253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 398}], {
             RGBColor[
             0.9568404042553191, 0.8631450638297871, 0.3020910957446806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 234}], {
             RGBColor[
             0.9632327872340425, 0.9718644468085107, 0.9365884468085106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 281}], {
             RGBColor[
             0.9719515425531915, 0.9296494893617021, 0.590333074468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 350}], {
             RGBColor[
             0.9812809042553191, 0.9611196170212766, 0.6265758829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 355}], {
             RGBColor[
             0.9902379255319149, 0.989874085106383, 0.7854918404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 392}], {
             RGBColor[
             0.5822673723404255, 0.6468552234042554, 0.9108407234042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 395}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 296}], {
             RGBColor[
             0.9632327872340425, 0.9718644468085107, 0.9365884468085106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 308}], {
             RGBColor[
             0.9542412659574467, 0.9289325531914892, 0.6568624787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 352}], {
             RGBColor[
             0.9589059468085106, 0.9446676170212766, 0.6749838829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 375}], {
             RGBColor[
             0.9434569680851064, 0.8896249574468084, 0.6302250638297873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 238}], {
             RGBColor[
             0.8426656276595745, 0.8651068297872342, 0.6859261702127659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 273}], {
             RGBColor[
             0.9529605744680851, 0.8422451489361702, 0.3277054787234042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 330}], {
             RGBColor[
             0.9898662340425533, 0.9768947021276596, 0.46478051063829773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 368}], {
             RGBColor[
             0.9895114680851065, 0.9761358936170212, 0.4261664255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 260}], {
             RGBColor[
             0.9542412659574467, 0.9289325531914892, 0.6568624787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[0.9780319680851064, 0.94597, 0.5849919255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 349}], {
             RGBColor[
             0.9542412659574467, 0.9289325531914892, 0.6568624787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 233}], {
             RGBColor[
             0.9325906914893617, 0.7496557872340426, 0.48077138297872335`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 242}], {
             RGBColor[
             0.9193519361702127, 0.7049675531914893, 0.27143307446808496`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 244}], {
             RGBColor[
             0.914687255319149, 0.6892324893617021, 0.2533116702127659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 245}], {
             RGBColor[
             0.8504556276595745, 0.6873160212765959, 0.5988844787234042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 328}], {
             RGBColor[
             0.914687255319149, 0.6892324893617021, 0.2533116702127659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 357}], {
             RGBColor[
             0.8827784042553191, 0.5606059361702127, 0.22389976595744682`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 364}], {
             RGBColor[
             0.9193519361702127, 0.7049675531914893, 0.27143307446808496`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 385}], {
             RGBColor[
             0.9245402872340425, 0.745298255319149, 0.5681298510638297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 235}], {
             RGBColor[
             0.9674800212765957, 0.9736207872340426, 0.8662007872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 298}], {
             RGBColor[
             0.9678629680851063, 0.973422085106383, 0.8338998404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 336}], {
             RGBColor[
             0.9660642765957446, 0.9730353404255319, 0.889663340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 393}], {
             RGBColor[
             0.9646485319148936, 0.9724498936170213, 0.9131258936170212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 396}], {
             RGBColor[
             0.9589059468085106, 0.9446676170212766, 0.6749838829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 257}], {
             RGBColor[
             0.9812809042553191, 0.9611196170212766, 0.6265758829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 275}], {
             RGBColor[
             0.9589059468085106, 0.9446676170212766, 0.6749838829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 279}], {
             RGBColor[
             0.9416912978723404, 0.8003250638297873, 0.30426986170212766`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 280}], {
             RGBColor[
             0.9329373297872341, 0.9240939787234043, 0.6771192765957447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 288}], {
             RGBColor[
             0.9855281382978723, 0.9628759574468084, 0.5561882234042552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 297}], {
             RGBColor[
             0.9855281382978723, 0.9628759574468084, 0.5561882234042552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 309}], {
             RGBColor[
             0.9712871382978723, 0.9539014893617022, 0.6540257553191489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 325}], {
             RGBColor[
             0.9848467872340425, 0.9604008297872341, 0.40804502127659553`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 339}], {
             RGBColor[
             0.9482958936170213, 0.8265100851063829, 0.30958407446808506`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 242}], {
             RGBColor[
             0.9808634574468085, 0.9471408936170211, 0.538066819148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 244}], {
             RGBColor[
             0.9761987765957447, 0.931405829787234, 0.5199454148936169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 264}], {
             RGBColor[
             0.9860518085106382, 0.9874715957446809, 0.8347635957446807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 307}], {
             RGBColor[
             0.9937756276595745, 0.9901128085106383, 0.6378760106382977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 348}], {
             RGBColor[
             0.9502653723404255, 0.8292782340425533, 0.4954867659574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 357}], {
             RGBColor[
             0.9442899255319148, 0.8027792765957446, 0.4905335106382978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 366}], {
             RGBColor[
             0.9855281382978723, 0.9628759574468084, 0.5561882234042552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[
             0.9434569680851064, 0.8896249574468084, 0.6302250638297873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 246}], {
             RGBColor[
             0.9470484255319148, 0.9600293829787234, 0.9745173829787235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 269}], {
             RGBColor[
             0.9675082021276595, 0.9726632765957446, 0.795285755319149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 272}], {
             RGBColor[
             0.9646485319148936, 0.9724498936170213, 0.9131258936170212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 350}], {
             RGBColor[
             0.9589059468085106, 0.9446676170212766, 0.6749838829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 355}], {
             RGBColor[
             0.9678629680851063, 0.973422085106383, 0.8338998404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 392}], {
             RGBColor[
             0.559892414893617, 0.6304032234042553, 0.9592487234042554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 395}], {
             RGBColor[
             0.9660642765957446, 0.9730353404255319, 0.889663340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 298}], {
             RGBColor[
             0.9944851595744681, 0.9916304255319148, 0.7151041808510636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 313}], {
             RGBColor[
             0.970079159574468, 0.9078332978723402, 0.511429404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 317}], {
             RGBColor[
             0.9634745638297872, 0.8816482765957445, 0.5061151914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 336}], {
             RGBColor[
             0.9926864680851064, 0.9912436808510638, 0.7708676808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 393}], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 396}], {
             RGBColor[
             0.9855281382978723, 0.9628759574468084, 0.5561882234042552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 267}], {
             RGBColor[
             0.989883159574468, 0.9891152765957447, 0.7468777553191488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 284}], {
             RGBColor[
             0.9719515425531915, 0.9296494893617021, 0.590333074468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 286}], {
             RGBColor[
             0.9902379255319149, 0.989874085106383, 0.7854918404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 332}], {
             RGBColor[
             0.9895283936170213, 0.9883564680851065, 0.7082636702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 367}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 383}], {
             RGBColor[
             0.985945585106383, 0.9768546808510639, 0.6446972872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 398}], {
             RGBColor[
             0.9658319255319148, 0.9060769574468084, 0.5818170638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 251}], {
             RGBColor[
             0.9420425319148936, 0.9558515744680851, 0.9675826914893617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 296}], {
             RGBColor[
             0.9756139787234042, 0.9810983191489362, 0.9156303191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 308}], {
             RGBColor[
             0.9666224574468085, 0.9381664255319148, 0.6359043510638296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 380}], {
             RGBColor[
             0.9492335638297872, 0.8726738085106381, 0.6039527234042552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 269}], {
             RGBColor[
             0.8466032021276597, 0.877367425531915, 0.7881066382978723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 272}], {
             RGBColor[
             0.8437435319148937, 0.8771540425531916, 0.9059467765957445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 280}], {
             RGBColor[
             0.7939842127659575, 0.8395429574468086, 0.9799527234042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 309}], {
             RGBColor[
             0.8323340212765958, 0.8693504680851065, 0.9568592021276595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 325}], {
             RGBColor[
             0.8458936702127661, 0.8758498085106384, 0.7108784680851061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 339}], {
             RGBColor[
             0.8093427765957448, 0.7419590638297873, 0.6124175212765957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 246}], {
             RGBColor[
             0.9496475638297872, 0.8942418936170211, 0.6197459999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 269}], {
             RGBColor[
             0.9701073404255318, 0.9068757872340425, 0.44051437234042545`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 272}], {
             RGBColor[
             0.9672476702127659, 0.9066624042553191, 0.5583545106382977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 350}], {
             RGBColor[
             0.9615050851063829, 0.8788801276595744, 0.3202124999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 355}], {
             RGBColor[
             0.9704621063829787, 0.9076345957446807, 0.4791284574468083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 392}], {
             RGBColor[
             0.5624915531914894, 0.564615734042553, 0.6044773404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 242}], {
             RGBColor[
             0.9722893829787234, 0.9181877234042553, 0.34684991489361683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 243}], {
             RGBColor[
             0.9816187446808511, 0.9496578510638298, 0.38309272340425526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 285}], {
             RGBColor[0.918167, 0.6941408723404254, 0.28467341489361697`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 337}], {
             RGBColor[
             0.9650965425531914, 0.9492845531914893, 0.6645048191489362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 357}], {
             RGBColor[
             0.9357158510638297, 0.7738261063829786, 0.2993166063829787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 399}], {
             RGBColor[
             0.9855563191489362, 0.9619184468085107, 0.48527319148936165`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 270}], {
             RGBColor[
             0.9927146489361702, 0.9902861702127659, 0.6999526489361703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 310}], {
             RGBColor[
             0.9568981489361702, 0.854505744680851, 0.4298859468085106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 323}], {
             RGBColor[
             0.9927146489361702, 0.9902861702127659, 0.6999526489361703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 346}], {
             RGBColor[0.990221, 0.9776535106382979, 0.5033945957446808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 389}], {
             RGBColor[
             0.9568981489361702, 0.854505744680851, 0.4298859468085106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 390}], {
             RGBColor[
             0.9326188723404255, 0.7486982765957447, 0.4098563510638298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 244}], {
             RGBColor[
             0.9629600212765956, 0.8867175957446807, 0.3106071063829785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 357}], {
             RGBColor[
             0.931051170212766, 0.7580910425531913, 0.2811952021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 364}], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 385}], {
             RGBColor[
             0.9728130531914894, 0.9427833617021275, 0.6254252872340423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 337}], {
             RGBColor[
             0.9697612234042553, 0.9650196170212766, 0.6826262234042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 367}], {
             RGBColor[
             0.988777074468085, 0.978025574468085, 0.5977721808510639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 398}], {
             RGBColor[
             0.9661697659574469, 0.8946151914893616, 0.33833390425531906`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 264}], {
             RGBColor[
             0.9681483723404255, 0.9270482978723404, 0.6073038829787233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 307}], {
             RGBColor[
             0.9758721914893618, 0.9296895106382979, 0.41041629787234024`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 321}], {
             RGBColor[
             0.9088376382978722, 0.6626707446808509, 0.24843060638297865`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 341}], {
             RGBColor[
             0.9521757234042553, 0.8474099999999998, 0.2839696914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 348}], {
             RGBColor[
             0.9323619361702128, 0.7688549361702128, 0.26802705319148934`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 357}], {
             RGBColor[
             0.9263864893617021, 0.7423559787234041, 0.26307379787234036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 366}], {
             RGBColor[
             0.9676247021276596, 0.902452659574468, 0.3287285106382978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 328}], {
             RGBColor[
             0.8940637127659574, 0.8690660638297871, 0.6380585106382979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 364}], {
             RGBColor[
             0.8987283936170213, 0.8848011276595744, 0.6561799148936169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 400}], {
             RGBColor[
             0.8747349042553192, 0.7931234893617021, 0.6189140744680851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 269}], {
             RGBColor[
             0.9736987978723404, 0.9772802127659574, 0.7848066914893617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 272}], {
             RGBColor[
             0.9708391276595745, 0.977066829787234, 0.902646829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 350}], {
             RGBColor[
             0.9650965425531914, 0.9492845531914893, 0.6645048191489362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 355}], {
             RGBColor[
             0.9740535638297871, 0.9780390212765957, 0.8234207765957446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 392}], {
             RGBColor[
             0.5660830106382978, 0.6350201595744681, 0.9487696595744681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 395}], {
             RGBColor[
             0.9722548723404254, 0.9776522765957447, 0.8791842765957447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 253}], {
             RGBColor[
             0.9460181382978723, 0.8275218936170214, 0.5658744255319148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 266}], {
             RGBColor[
             0.9766162234042552, 0.9453845531914893, 0.6084544787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 301}], {
             RGBColor[
             0.9895283936170213, 0.9883564680851065, 0.7082636702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 315}], {
             RGBColor[
             0.9891736276595744, 0.9875976595744682, 0.6696495851063827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 316}], {
             RGBColor[
             0.9766162234042552, 0.9453845531914893, 0.6084544787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 343}], {
             RGBColor[
             0.9812809042553191, 0.9611196170212766, 0.6265758829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 358}], {
             RGBColor[
             0.9526227340425532, 0.8537069148936169, 0.5711886382978723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 359}], {
             RGBColor[
             0.9283434574468085, 0.7478994468085107, 0.5511590425531914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 362}], {
             RGBColor[
             0.9902379255319149, 0.989874085106383, 0.7854918404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 363}], {
             RGBColor[
             0.9283434574468085, 0.7478994468085107, 0.5511590425531914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 369}], {
             RGBColor[
             0.981804574468085, 0.985715255319149, 0.9051512553191488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 397}], {
             RGBColor[
             0.9756139787234042, 0.9810983191489362, 0.9156303191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 276}], {
             RGBColor[
             0.9224920425531915, 0.9395119148936171, 0.9373148617021276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 340}], {
             RGBColor[
             0.989883159574468, 0.9891152765957447, 0.7468777553191488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 360}], {
             RGBColor[
             0.9895283936170213, 0.9883564680851065, 0.7082636702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 266}], {
             RGBColor[
             0.9801821063829788, 0.9446657659574467, 0.38992361702127626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 293}], {
             RGBColor[
             0.9853704574468085, 0.9849964680851064, 0.686620393617021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 315}], {
             RGBColor[
             0.9927395106382979, 0.9868788723404256, 0.45111872340425496`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 316}], {
             RGBColor[
             0.9801821063829788, 0.9446657659574467, 0.38992361702127626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 387}], {
             RGBColor[
             0.9260579255319149, 0.9387931276595745, 0.7187839999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 397}], {
             RGBColor[
             0.9791798617021277, 0.9803795319148936, 0.6970994574468083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 356}], {
             RGBColor[
             0.9794477127659573, 0.9465554468085104, 0.5615293723404253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 363}], {
             RGBColor[
             0.9193519361702127, 0.7049675531914893, 0.27143307446808496`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 372}], {
             RGBColor[
             0.9812464042553191, 0.9469421914893617, 0.5057658723404252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 283}], {
             RGBColor[
             0.9556021808510639, 0.9623509148936171, 0.7216019574468083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 308}], {
             RGBColor[
             0.9430447765957446, 0.9201378085106382, 0.6604068510638297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 380}], {
             RGBColor[
             0.9256558829787234, 0.8546451914893616, 0.6284552234042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 381}], {
             RGBColor[
             0.9566664787234043, 0.9646273404255319, 0.8374442127659574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 282}], {
             RGBColor[
             0.9816187446808511, 0.9496578510638298, 0.38309272340425526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 300}], {
             RGBColor[
             0.9769540638297872, 0.9339227872340424, 0.364971319148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 367}], {
             RGBColor[
             0.988777074468085, 0.978025574468085, 0.5977721808510639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 398}], {
             RGBColor[
             0.9661697659574469, 0.8946151914893616, 0.33833390425531906`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 266}], {
             RGBColor[
             0.9370266170212767, 0.7845899999999999, 0.2861484574468084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 301}], {
             RGBColor[
             0.9499387872340426, 0.8275619148936171, 0.38595764893617013`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 315}], {
             RGBColor[
             0.9495840212765958, 0.8268031063829788, 0.3473435638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 316}], {
             RGBColor[
             0.9370266170212767, 0.7845899999999999, 0.2861484574468084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 343}], {
             RGBColor[
             0.9416912978723404, 0.8003250638297873, 0.30426986170212766`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 358}], {
             RGBColor[
             0.9130331276595745, 0.6929123617021277, 0.24888261702127662`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 359}], {
             RGBColor[
             0.8887538510638298, 0.5871048936170213, 0.2288530212765958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 362}], {
             RGBColor[
             0.9506483191489362, 0.8290795319148937, 0.4631858191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 369}], {
             RGBColor[
             0.9422149680851064, 0.8249207021276597, 0.5828452340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 394}], {
             RGBColor[
             0.9499387872340426, 0.8275619148936171, 0.38595764893617013`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 397}], {
             RGBColor[
             0.9360243723404256, 0.8203037659574468, 0.5933242978723404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 303}], {
             RGBColor[
             0.938679914893617, 0.951876255319149, 0.9152612872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 268}], {
             RGBColor[
             0.9848467872340425, 0.9604008297872341, 0.40804502127659553`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 324}], {
             RGBColor[
             0.9729892659574468, 0.9757625957446809, 0.7075785212765956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 328}], {
             RGBColor[
             0.9755174255319149, 0.9289307021276596, 0.3718022127659572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 351}], {
             RGBColor[
             0.966798670212766, 0.9711456595744681, 0.7180575851063828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 400}], {
             RGBColor[
             0.9561886170212766, 0.8529881276595744, 0.3526577765957445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 311}], {
             RGBColor[
             0.9562835319148937, 0.9648260425531915, 0.8697451595744681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 313}], {
             RGBColor[
             0.970079159574468, 0.9078332978723402, 0.511429404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 386}], {
             RGBColor[
             0.9808634574468085, 0.9471408936170211, 0.538066819148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 275}], {
             RGBColor[
             0.9632327872340425, 0.9718644468085107, 0.9365884468085106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 276}], {
             RGBColor[
             0.9224920425531915, 0.9395119148936171, 0.9373148617021276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 279}], {
             RGBColor[
             0.9460181382978723, 0.8275218936170214, 0.5658744255319148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 280}], {
             RGBColor[
             0.937264170212766, 0.9512908085106384, 0.9387238404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 288}], {
             RGBColor[
             0.9898549787234042, 0.9900727872340426, 0.8177927872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 309}], {
             RGBColor[
             0.9756139787234042, 0.9810983191489362, 0.9156303191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 325}], {
             RGBColor[
             0.9891736276595744, 0.9875976595744682, 0.6696495851063827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 339}], {
             RGBColor[
             0.9526227340425532, 0.8537069148936169, 0.5711886382978723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 277}], {
             RGBColor[
             0.9521757234042553, 0.8474099999999998, 0.2839696914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 302}], {
             RGBColor[
             0.9761987765957447, 0.931405829787234, 0.5199454148936169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 377}], {
             RGBColor[
             0.9761987765957447, 0.931405829787234, 0.5199454148936169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 378}], {
             RGBColor[
             0.9758721914893618, 0.9296895106382979, 0.41041629787234024`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 379}], {
             RGBColor[
             0.9755174255319149, 0.9289307021276596, 0.3718022127659572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 262}], {
             RGBColor[
             0.9934208617021276, 0.9893540000000001, 0.5992619255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 331}], {
             RGBColor[
             0.9634745638297872, 0.8816482765957445, 0.5061151914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 335}], {
             RGBColor[
             0.9860518085106382, 0.9874715957446809, 0.8347635957446807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 307}], {
             RGBColor[
             0.9671534361702128, 0.9719044680851063, 0.7566716702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 329}], {
             RGBColor[
             0.9646485319148936, 0.9724498936170213, 0.9131258936170212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 341}], {
             RGBColor[
             0.9434569680851064, 0.8896249574468084, 0.6302250638297873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 349}], {
             RGBColor[
             0.940857829787234, 0.9554124468085106, 0.9849964468085107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 366}], {
             RGBColor[
             0.9589059468085106, 0.9446676170212766, 0.6749838829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 306}], {
             RGBColor[
             0.9923598829787235, 0.9895273617021276, 0.6613385638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 284}], {
             RGBColor[
             0.9755174255319149, 0.9289307021276596, 0.3718022127659572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 286}], {
             RGBColor[
             0.9938038085106383, 0.9891552978723405, 0.566960978723404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 331}], {
             RGBColor[
             0.9627932127659574, 0.87917314893617, 0.35797198936170194`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 332}], {
             RGBColor[
             0.9930942765957447, 0.9876376808510638, 0.489732808510638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 338}], {
             RGBColor[
             0.9556021808510639, 0.9623509148936171, 0.7216019574468083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 264}], {
             RGBColor[
             0.9681483723404255, 0.9270482978723404, 0.6073038829787233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 312}], {
             RGBColor[
             0.9747830319148936, 0.9308203829787234, 0.5434079680851063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 348}], {
             RGBColor[
             0.9323619361702128, 0.7688549361702128, 0.26802705319148934`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 307}], {
             RGBColor[
             0.9857252234042553, 0.9857552765957447, 0.7252344787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 312}], {
             RGBColor[
             0.9846360638297872, 0.9868861489361702, 0.8582261489361702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 348}], {
             RGBColor[
             0.9422149680851064, 0.8249207021276597, 0.5828452340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 357}], {
             RGBColor[
             0.9362395212765957, 0.798421744680851, 0.5778919787234043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 366}], {
             RGBColor[
             0.9774777340425531, 0.9585184255319149, 0.6435466914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 291}], {
             RGBColor[
             0.9852015531914894, 0.9611596382978724, 0.44665910638297857`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 304}], {
             RGBColor[
             0.9631479787234043, 0.8799319574468084, 0.3965860744680849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 378}], {
             RGBColor[
             0.9934490425531916, 0.9883964893617022, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 383}], {
             RGBColor[
             0.9898662340425533, 0.9768947021276596, 0.46478051063829773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 293}], {
             RGBColor[
             0.9728130531914894, 0.9427833617021275, 0.6254252872340423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 315}], {
             RGBColor[
             0.9801821063829788, 0.9446657659574467, 0.38992361702127626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 316}], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 338}], {
             RGBColor[
             0.9430447765957446, 0.9201378085106382, 0.6604068510638297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 397}], {
             RGBColor[
             0.9666224574468085, 0.9381664255319148, 0.6359043510638296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 282}], {
             RGBColor[
             0.9855563191489362, 0.9619184468085107, 0.48527319148936165`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 332}], {
             RGBColor[
             0.9938038085106383, 0.9891552978723405, 0.5669609787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 367}], {
             RGBColor[
             0.9927146489361702, 0.9902861702127659, 0.6999526489361703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 383}], {
             RGBColor[0.990221, 0.9776535106382979, 0.5033945957446808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 398}], {
             RGBColor[
             0.9701073404255318, 0.9068757872340425, 0.44051437234042545`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 270}], {
             RGBColor[
             0.9841123936170213, 0.9622905106382978, 0.5796507765957446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 274}], {
             RGBColor[
             0.9676247021276596, 0.902452659574468, 0.3287285106382978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 295}], {
             RGBColor[
             0.9477094574468086, 0.9358728723404255, 0.678528255319149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 324}], {
             RGBColor[
             0.9650965425531914, 0.9492845531914893, 0.6645048191489362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 351}], {
             RGBColor[
             0.9589059468085106, 0.9446676170212766, 0.6749838829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 373}], {
             RGBColor[
             0.9416912978723404, 0.8003250638297873, 0.30426986170212766`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 272}], {
             RGBColor[
             0.9912989042553191, 0.9897007234042554, 0.7234152021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 350}], {
             RGBColor[
             0.9855563191489362, 0.9619184468085107, 0.48527319148936165`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 355}], {
             RGBColor[
             0.994513340425532, 0.9906729148936171, 0.6441891489361701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 392}], {
             RGBColor[
             0.5865427872340425, 0.6476540531914894, 0.7695380319148937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 395}], {
             RGBColor[
             0.9927146489361702, 0.9902861702127659, 0.6999526489361703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 295}], {
             RGBColor[
             0.9548677872340425, 0.9642405957446809, 0.8932077127659575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 310}], {
             RGBColor[
             0.9554542234042553, 0.8548778085106382, 0.5242635319148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 324}], {
             RGBColor[
             0.9722548723404254, 0.9776522765957447, 0.8791842765957447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 346}], {
             RGBColor[
             0.988777074468085, 0.978025574468085, 0.5977721808510639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 351}], {
             RGBColor[
             0.9660642765957446, 0.9730353404255319, 0.889663340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 373}], {
             RGBColor[
             0.9488496276595745, 0.8286927872340426, 0.5189493191489363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 390}], {
             RGBColor[
             0.9311749468085107, 0.7490703404255319, 0.5042339361702128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 287}], {
             RGBColor[
             0.9766162234042552, 0.9453845531914893, 0.6084544787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 292}], {
             RGBColor[
             0.9135005212765956, 0.8965800212765955, 0.6575888936170211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 371}], {
             RGBColor[
             0.9794477127659573, 0.9465554468085104, 0.5615293723404253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 374}], {
             RGBColor[
             0.9769540638297872, 0.9339227872340424, 0.364971319148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 382}], {
             RGBColor[
             0.931051170212766, 0.7580910425531913, 0.2811952021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 384}], {
             RGBColor[
             0.931051170212766, 0.7580910425531913, 0.2811952021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 389}], {
             RGBColor[
             0.9436312127659574, 0.8107750212765956, 0.2914626702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 391}], {
             RGBColor[
             0.9812464042553191, 0.9469421914893617, 0.5057658723404252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 350}], {
             RGBColor[
             0.9826966489361701, 0.9617050638297873, 0.603113329787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 392}], {
             RGBColor[
             0.5836831170212766, 0.647440670212766, 0.8873781702127659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 395}], {
             RGBColor[
             0.9898549787234042, 0.9900727872340426, 0.8177927872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 322}], {
             RGBColor[
             0.9565433829787234, 0.8537469361702128, 0.3912718617021275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 330}], {
             RGBColor[
             0.9565433829787234, 0.8537469361702128, 0.3912718617021275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 295}], {
             RGBColor[
             0.9383800957446808, 0.904402744680851, 0.6422854468085106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 296}], {
             RGBColor[
             0.9719515425531915, 0.9296494893617021, 0.590333074468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 319}], {
             RGBColor[
             0.9733672872340425, 0.9302349361702127, 0.5668705212765957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 324}], {
             RGBColor[
             0.9557671808510637, 0.9178144255319148, 0.6282620106382979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 351}], {
             RGBColor[
             0.9495765851063829, 0.9131974893617021, 0.638741074468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 373}], {
             RGBColor[
             0.9323619361702128, 0.7688549361702128, 0.26802705319148934`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 276}], {
             RGBColor[
             0.9001170851063829, 0.9230599148936169, 0.9857228617021276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 280}], {
             RGBColor[
             0.9148892127659574, 0.9348388085106383, 0.987131840425532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 288}], {
             RGBColor[
             0.9674800212765957, 0.9736207872340426, 0.8662007872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 290}], {
             RGBColor[
             0.9542412659574467, 0.9289325531914892, 0.6568624787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 297}], {
             RGBColor[
             0.9674800212765957, 0.9736207872340426, 0.8662007872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 318}], {
             RGBColor[
             0.9674800212765957, 0.9736207872340426, 0.8662007872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 325}], {
             RGBColor[
             0.966798670212766, 0.9711456595744681, 0.7180575851063828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 339}], {
             RGBColor[
             0.9302477765957446, 0.8372549148936169, 0.6195966382978724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 288}], {
             RGBColor[
             0.9267392765957447, 0.9412682553191489, 0.8669272021276595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 290}], {
             RGBColor[
             0.9135005212765956, 0.8965800212765955, 0.6575888936170211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 297}], {
             RGBColor[
             0.9267392765957447, 0.9412682553191489, 0.8669272021276595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 318}], {
             RGBColor[
             0.9267392765957447, 0.9412682553191489, 0.8669272021276595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 278}], {
             RGBColor[
             0.970079159574468, 0.9078332978723402, 0.511429404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 302}], {
             RGBColor[
             0.970079159574468, 0.9078332978723402, 0.511429404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 314}], {
             RGBColor[
             0.9394515106382978, 0.7976524468085104, 0.2701394680851063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 352}], {
             RGBColor[
             0.9615050851063829, 0.8788801276595744, 0.3202124999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 378}], {
             RGBColor[
             0.969752574468085, 0.9061169787234042, 0.40190028723404236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 379}], {
             RGBColor[
             0.9693978085106383, 0.9053581702127659, 0.3632862021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 314}], {
             RGBColor[
             0.9634745638297872, 0.8816482765957445, 0.5061151914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 319}], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 352}], {
             RGBColor[
             0.9855281382978723, 0.9628759574468084, 0.5561882234042552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 379}], {
             RGBColor[
             0.9934208617021276, 0.9893540000000001, 0.5992619255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.8829042340425532, 0.5605431489361701, 0.2239719574468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 288}], {
             RGBColor[
             0.9502653723404255, 0.8292782340425533, 0.4954867659574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 309}], {
             RGBColor[
             0.9360243723404256, 0.8203037659574468, 0.5933242978723404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 325}], {
             RGBColor[
             0.9495840212765958, 0.8268031063829788, 0.3473435638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 399}], {
             RGBColor[
             0.9502935531914893, 0.8283207234042553, 0.4245717340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 297}], {
             RGBColor[
             0.9415114042553192, 0.9530471489361703, 0.8683361808510638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 309}], {
             RGBColor[
             0.9272704042553191, 0.9440726808510638, 0.9661737127659574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 322}], {
             RGBColor[
             0.9411848191489363, 0.951330829787234, 0.7588070638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 325}], {
             RGBColor[
             0.9408300531914894, 0.9505720212765958, 0.720192978723404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 339}], {
             RGBColor[
             0.9042791595744681, 0.8166812765957446, 0.6217320319148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 355}], {
             RGBColor[
             0.9765817234042553, 0.9312071276595744, 0.4876444680851062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 386}], {
             RGBColor[
             0.9629600212765956, 0.8867175957446807, 0.3106071063829785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 367}], {
             RGBColor[
             0.9841123936170213, 0.9622905106382978, 0.5796507765957446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 383}], {
             RGBColor[
             0.9816187446808511, 0.9496578510638298, 0.38309272340425526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 398}], {
             RGBColor[
             0.9615050851063829, 0.8788801276595744, 0.3202124999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 294}], {
             RGBColor[
             0.9853704574468085, 0.9849964680851064, 0.686620393617021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 320}], {
             RGBColor[
             0.9930942765957447, 0.9876376808510638, 0.489732808510638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 347}], {
             RGBColor[
             0.9755174255319149, 0.9289307021276596, 0.3718022127659572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 373}], {
             RGBColor[
             0.9495840212765958, 0.8268031063829788, 0.3473435638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 380}], {
             RGBColor[
             0.9627932127659574, 0.87917314893617, 0.35797198936170194`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 381}], {
             RGBColor[
             0.9938038085106383, 0.9891552978723405, 0.566960978723404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 332}], {
             RGBColor[
             0.9758721914893618, 0.9296895106382979, 0.41041629787234024`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 338}], {
             RGBColor[
             0.9383800957446808, 0.904402744680851, 0.6422854468085106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 367}], {
             RGBColor[
             0.9747830319148936, 0.9308203829787234, 0.5434079680851063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 399}], {
             RGBColor[
             0.9267692553191489, 0.7221365319148935, 0.4049752872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 332}], {
             RGBColor[
             0.9941585744680852, 0.9899141063829788, 0.605575063829787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 292}], {
             RGBColor[
             0.9224920425531915, 0.9395119148936171, 0.9373148617021276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 371}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 374}], {
             RGBColor[
             0.985945585106383, 0.9768546808510639, 0.6446972872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 382}], {
             RGBColor[
             0.9400426914893616, 0.8010229361702127, 0.5609211702127659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 384}], {
             RGBColor[
             0.9400426914893616, 0.8010229361702127, 0.5609211702127659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 389}], {
             RGBColor[
             0.9526227340425532, 0.8537069148936169, 0.5711886382978723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 391}], {
             RGBColor[
             0.9902379255319149, 0.989874085106383, 0.7854918404255318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 303}], {
             RGBColor[
             0.9036927234042553, 0.9260440638297873, 0.9906762127659574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 376}], {
             RGBColor[
             0.9556021808510639, 0.9623509148936171, 0.7216019574468083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 297}], {
             RGBColor[
             0.9808634574468085, 0.9471408936170211, 0.538066819148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 318}], {
             RGBColor[
             0.9808634574468085, 0.9471408936170211, 0.538066819148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 345}], {
             RGBColor[
             0.9794477127659573, 0.9465554468085104, 0.5615293723404253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 304}], {
             RGBColor[
             0.9549004893617021, 0.8526951063829786, 0.31489828723404245`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 383}], {
             RGBColor[
             0.9816187446808511, 0.9496578510638298, 0.38309272340425526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 371}], {
             RGBColor[
             0.9253235319148936, 0.9406828085106382, 0.8903897553191489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 374}], {
             RGBColor[
             0.9228298829787234, 0.9280501489361701, 0.6938317021276595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 382}], {
             RGBColor[
             0.8769269893617021, 0.752218404255319, 0.6100555851063829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 384}], {
             RGBColor[
             0.8769269893617021, 0.752218404255319, 0.6100555851063829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 389}], {
             RGBColor[
             0.8895070319148937, 0.8049023829787233, 0.6203230531914894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 316}], {
             RGBColor[
             0.9728130531914894, 0.9427833617021275, 0.6254252872340423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 387}], {
             RGBColor[
             0.9186888723404255, 0.9369107234042553, 0.9542856702127659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 320}], {
             RGBColor[
             0.9857252234042553, 0.9857552765957447, 0.7252344787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 347}], {
             RGBColor[
             0.9681483723404255, 0.9270482978723404, 0.6073038829787233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 380}], {
             RGBColor[
             0.955424159574468, 0.8772907446808509, 0.593473659574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 381}], {
             RGBColor[
             0.9864347553191489, 0.9872728936170213, 0.80246264893617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 310}], {
             RGBColor[
             0.9190512872340426, 0.8284601702127659, 0.6231410106382979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 324}], {
             RGBColor[
             0.9358519361702127, 0.9512346382978724, 0.978061755319149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 351}], {
             RGBColor[
             0.9296613404255318, 0.9466177021276596, 0.9885408191489362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 373}], {
             RGBColor[
             0.9124466914893617, 0.8022751489361704, 0.6178267978723404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 390}], {
             RGBColor[
             0.8947720106382979, 0.7226527021276596, 0.603111414893617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 308}], {
             RGBColor[
             0.9766162234042552, 0.9453845531914893, 0.6084544787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 373}], {
             RGBColor[
             0.9460181382978723, 0.8275218936170214, 0.5658744255319148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 380}], {
             RGBColor[
             0.959227329787234, 0.8798919361702127, 0.5765028510638297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 318}], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 322}], {
             RGBColor[
             0.9937756276595745, 0.9901128085106383, 0.6378760106382977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 339}], {
             RGBColor[
             0.9568699680851064, 0.8554632553191488, 0.5008009787234042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 313}], {
             RGBColor[
             0.9704621063829787, 0.9076345957446807, 0.4791284574468083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 361}], {
             RGBColor[
             0.9941585744680852, 0.9899141063829788, 0.605575063829787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 393}], {
             RGBColor[
             0.991653670212766, 0.9904595319148937, 0.7620292872340424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 396}], {
             RGBColor[
             0.985911085106383, 0.9626772553191489, 0.5238872765957445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 306}], {
             RGBColor[
             0.9747830319148936, 0.9308203829787234, 0.5434079680851063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 342}], {
             RGBColor[
             0.9761987765957447, 0.931405829787234, 0.5199454148936169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 353}], {
             RGBColor[
             0.9719515425531915, 0.9296494893617021, 0.590333074468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 319}], {
             RGBColor[0.9780319680851064, 0.94597, 0.5849919255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 343}], {
             RGBColor[
             0.9852015531914894, 0.9611596382978724, 0.44665910638297857`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 358}], {
             RGBColor[
             0.9565433829787234, 0.8537469361702128, 0.3912718617021275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 359}], {
             RGBColor[
             0.9322641063829787, 0.7479394680851065, 0.3712422659574467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 362}], {
             RGBColor[
             0.9941585744680852, 0.9899141063829788, 0.605575063829787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 369}], {
             RGBColor[
             0.9857252234042553, 0.9857552765957447, 0.7252344787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 394}], {
             RGBColor[
             0.9934490425531916, 0.9883964893617022, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 397}], {
             RGBColor[
             0.9795346276595744, 0.9811383404255319, 0.7357135425531913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 314}], {
             RGBColor[
             0.9634745638297872, 0.8816482765957445, 0.5061151914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 352}], {
             RGBColor[
             0.9855281382978723, 0.9628759574468084, 0.5561882234042552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 377}], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 379}], {
             RGBColor[
             0.9934208617021276, 0.9893540000000001, 0.5992619255319147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 376}], {
             RGBColor[
             0.9408300531914894, 0.9505720212765958, 0.720192978723404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 383}], {
             RGBColor[
             0.9595651702127659, 0.8684301702127658, 0.3330196914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 334}], {
             RGBColor[
             0.9860518085106382, 0.9874715957446809, 0.8347635957446807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 340}], {
             RGBColor[
             0.9941303936170213, 0.9908716170212766, 0.6764900957446808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 360}], {
             RGBColor[
             0.9937756276595745, 0.9901128085106383, 0.6378760106382977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 370}], {
             RGBColor[
             0.9937756276595745, 0.9901128085106383, 0.6378760106382977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 342}], {
             RGBColor[
             0.9926864680851064, 0.9912436808510638, 0.7708676808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 353}], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 361}], {
             RGBColor[
             0.9923598829787235, 0.9895273617021276, 0.6613385638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 312}], {
             RGBColor[
             0.9923598829787235, 0.9895273617021276, 0.6613385638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 341}], {
             RGBColor[
             0.969752574468085, 0.9061169787234042, 0.40190028723404236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 348}], {
             RGBColor[
             0.9499387872340426, 0.8275619148936171, 0.38595764893617013`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 366}], {
             RGBColor[
             0.9852015531914894, 0.9611596382978724, 0.44665910638297857`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 325}], {
             RGBColor[
             0.9791798617021277, 0.9803795319148936, 0.6970994574468083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 339}], {
             RGBColor[
             0.9426289680851063, 0.8464887872340425, 0.5986385106382979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 323}], {
             RGBColor[
             0.9554542234042553, 0.8548778085106382, 0.5242635319148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 324}], {
             RGBColor[
             0.9364383723404255, 0.8418718510638297, 0.6091175744680851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 346}], {
             RGBColor[
             0.9529605744680851, 0.8422451489361702, 0.3277054787234042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 389}], {
             RGBColor[
             0.9196377234042553, 0.7190973829787233, 0.254196829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 390}], {
             RGBColor[
             0.8953584468085106, 0.6132899148936171, 0.23416723404255319`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 313}], {
             RGBColor[
             0.9322604787234042, 0.8808302127659573, 0.6337694361702128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 361}], {
             RGBColor[
             0.9559569468085107, 0.9631097234042554, 0.7602160425531914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 386}], {
             RGBColor[
             0.9430447765957446, 0.9201378085106382, 0.6604068510638297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 348}], {
             RGBColor[
             0.9488496276595745, 0.8286927872340426, 0.5189493191489363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 366}], {
             RGBColor[
             0.9841123936170213, 0.9622905106382978, 0.5796507765957446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 361}], {
             RGBColor[
             0.969752574468085, 0.9061169787234042, 0.40190028723404236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 393}], {
             RGBColor[
             0.9672476702127659, 0.9066624042553191, 0.5583545106382977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 396}], {
             RGBColor[
             0.9615050851063829, 0.8788801276595744, 0.3202124999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 352}], {
             RGBColor[
             0.9549004893617021, 0.8526951063829786, 0.31489828723404245`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 379}], {
             RGBColor[
             0.9627932127659574, 0.87917314893617, 0.35797198936170194`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 316}], {
             RGBColor[
             0.9801821063829788, 0.9446657659574467, 0.38992361702127626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 358}], {
             RGBColor[
             0.9561886170212766, 0.8529881276595744, 0.3526577765957445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 359}], {
             RGBColor[
             0.9319093404255319, 0.7471806595744681, 0.33262818085106366`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 362}], {
             RGBColor[
             0.9938038085106383, 0.9891552978723405, 0.566960978723404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 363}], {
             RGBColor[
             0.9319093404255319, 0.7471806595744681, 0.33262818085106366`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 369}], {
             RGBColor[
             0.9853704574468085, 0.9849964680851064, 0.686620393617021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 397}], {
             RGBColor[
             0.9791798617021277, 0.9803795319148936, 0.6970994574468083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 358}], {
             RGBColor[
             0.9436312127659574, 0.8107750212765956, 0.2914626702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 359}], {
             RGBColor[
             0.9193519361702127, 0.7049675531914893, 0.27143307446808496`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 362}], {
             RGBColor[
             0.9812464042553191, 0.9469421914893617, 0.5057658723404252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 363}], {
             RGBColor[
             0.9193519361702127, 0.7049675531914893, 0.27143307446808496`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 369}], {
             RGBColor[
             0.9728130531914894, 0.9427833617021275, 0.6254252872340423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 397}], {
             RGBColor[
             0.9666224574468085, 0.9381664255319148, 0.6359043510638296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 326}], {
             RGBColor[
             0.9634745638297872, 0.8816482765957445, 0.5061151914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 327}], {
             RGBColor[
             0.9492335638297872, 0.8726738085106381, 0.6039527234042552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 336}], {
             RGBColor[
             0.9620588191489361, 0.8810628297872338, 0.529577744680851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 396}], {
             RGBColor[
             0.9549004893617021, 0.8526951063829786, 0.31489828723404245`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 345}], {
             RGBColor[
             0.9926864680851064, 0.9912436808510638, 0.7708676808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 347}], {
             RGBColor[
             0.9758721914893618, 0.9296895106382979, 0.41041629787234024`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 380}], {
             RGBColor[
             0.9631479787234043, 0.8799319574468084, 0.3965860744680849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 381}], {
             RGBColor[
             0.9941585744680852, 0.9899141063829788, 0.605575063829787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 384}], {
             RGBColor[
             0.9439633404255319, 0.8010629574468084, 0.38100439361702115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 341}], {
             RGBColor[
             0.9027180212765957, 0.6390982127659572, 0.23991459574468077`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 366}], {
             RGBColor[0.918167, 0.6941408723404254, 0.28467341489361697`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 330}], {
             RGBColor[
             0.9934490425531916, 0.9883964893617022, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 339}], {
             RGBColor[
             0.9565433829787234, 0.8537469361702128, 0.3912718617021275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 346}], {
             RGBColor[
             0.988777074468085, 0.978025574468085, 0.5977721808510639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 346}], {
             RGBColor[
             0.9697612234042553, 0.9650196170212766, 0.6826262234042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 351}], {
             RGBColor[
             0.9470484255319148, 0.9600293829787234, 0.9745173829787235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 390}], {
             RGBColor[
             0.9121590957446808, 0.7360643829787235, 0.5890879787234042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 339}], {
             RGBColor[
             0.9561886170212766, 0.8529881276595744, 0.3526577765957445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 327}], {
             RGBColor[
             0.9798612127659574, 0.982854659574468, 0.845242659574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 336}], {
             RGBColor[
             0.9926864680851064, 0.9912436808510638, 0.7708676808510637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 336}], {
             RGBColor[
             0.9784454680851064, 0.9822692127659574, 0.8687052127659574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 376}], {
             RGBColor[
             0.9791798617021277, 0.9803795319148936, 0.6970994574468083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 364}], {
             RGBColor[
             0.9629600212765956, 0.8867175957446807, 0.3106071063829785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 386}], {
             RGBColor[
             0.9629600212765956, 0.8867175957446807, 0.3106071063829785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 400}], {
             RGBColor[
             0.9389665319148937, 0.7950399574468083, 0.27334126595744673`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 349}], {
             RGBColor[
             0.9646485319148936, 0.9724498936170213, 0.9131258936170212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 335}], {
             RGBColor[
             0.955424159574468, 0.8772907446808509, 0.5934736595744681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 338}], {
             RGBColor[
             0.9256558829787234, 0.8546451914893616, 0.6284552234042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 368}], {
             RGBColor[
             0.9934490425531914, 0.9883964893617021, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 340}], {
             RGBColor[
             0.986079989361702, 0.9865140851063829, 0.7638485638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 360}], {
             RGBColor[
             0.9857252234042553, 0.9857552765957447, 0.7252344787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 365}], {
             RGBColor[
             0.9832203191489362, 0.9863007021276596, 0.8816887021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 370}], {
             RGBColor[
             0.9857252234042553, 0.9857552765957447, 0.7252344787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 394}], {
             RGBColor[
             0.9857252234042553, 0.9857552765957447, 0.7252344787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 396}], {
             RGBColor[
             0.9841123936170213, 0.9622905106382978, 0.5796507765957446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 367}], {
             RGBColor[
             0.9722548723404254, 0.9776522765957447, 0.8791842765957447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 398}], {
             RGBColor[0.9496475638297872, 0.8942418936170211, 0.619746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 399}], {
             RGBColor[
             0.9736987978723404, 0.9772802127659574, 0.7848066914893617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 360}], {
             RGBColor[
             0.9938038085106383, 0.9891552978723405, 0.5669609787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 370}], {
             RGBColor[
             0.9938038085106383, 0.9891552978723405, 0.5669609787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 348}], {
             RGBColor[
             0.9262423191489362, 0.7452824042553191, 0.25951104255319146`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 366}], {
             RGBColor[
             0.9615050851063829, 0.8788801276595744, 0.3202124999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 353}], {
             RGBColor[
             0.9898549787234042, 0.9900727872340426, 0.8177927872340425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 358}], {
             RGBColor[
             0.9482958936170213, 0.8265100851063829, 0.30958407446808506`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 359}], {
             RGBColor[
             0.9240166170212766, 0.7207026170212767, 0.28955447872340423`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 362}], {
             RGBColor[
             0.985911085106383, 0.9626772553191489, 0.5238872765957445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 369}], {
             RGBColor[
             0.9774777340425531, 0.9585184255319149, 0.6435466914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 354}], {
             RGBColor[
             0.9627932127659574, 0.87917314893617, 0.35797198936170194`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 356}], {
             RGBColor[
             0.9620588191489361, 0.8810628297872338, 0.529577744680851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 388}], {
             RGBColor[
             0.9502358085106382, 0.8369600425531912, 0.2967768829787232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 390}], {
             RGBColor[
             0.9286812978723404, 0.7364376808510639, 0.3076758829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 380}], {
             RGBColor[
             0.9455711276595744, 0.821224978723404, 0.2786554787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 381}], {
             RGBColor[
             0.9765817234042553, 0.9312071276595744, 0.4876444680851062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 384}], {
             RGBColor[
             0.9263864893617021, 0.7423559787234041, 0.26307379787234036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 366}], {
             RGBColor[
             0.9416912978723404, 0.8003250638297873, 0.30426986170212766`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 355}], {
             RGBColor[
             0.985911085106383, 0.9626772553191489, 0.5238872765957445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 392}], {
             RGBColor[
             0.5779405319148936, 0.6196583936170212, 0.649236159574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 395}], {
             RGBColor[
             0.9841123936170213, 0.9622905106382978, 0.5796507765957446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 379}], {
             RGBColor[
             0.9848467872340425, 0.9604008297872341, 0.40804502127659553`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 371}], {
             RGBColor[
             0.9920051170212766, 0.9887685531914894, 0.6227244787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 388}], {
             RGBColor[
             0.9801821063829788, 0.9446657659574467, 0.38992361702127626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 392}], {
             RGBColor[
             0.5868975531914894, 0.6484128617021276, 0.8081521170212764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 395}], {
             RGBColor[
             0.993069414893617, 0.9910449787234042, 0.738566734042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 363}], {
             RGBColor[
             0.9311749468085107, 0.7490703404255319, 0.5042339361702128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 372}], {
             RGBColor[
             0.993069414893617, 0.9910449787234042, 0.738566734042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 364}], {
             RGBColor[
             0.931051170212766, 0.7580910425531913, 0.2811952021276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 385}], {
             RGBColor[
             0.9362395212765957, 0.798421744680851, 0.5778919787234041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 359}], {
             RGBColor[
             0.8953584468085106, 0.6132899148936171, 0.23416723404255319`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 362}], {
             RGBColor[
             0.9572529148936171, 0.8552645531914893, 0.4685000319148935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 363}], {
             RGBColor[
             0.8953584468085106, 0.6132899148936171, 0.23416723404255319`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 369}], {
             RGBColor[
             0.9488195638297872, 0.8511057234042553, 0.5881594468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 372}], {
             RGBColor[
             0.9572529148936171, 0.8552645531914893, 0.4685000319148935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 397}], {
             RGBColor[
             0.9426289680851063, 0.8464887872340425, 0.5986385106382979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 362}], {
             RGBColor[
             0.9329736382978724, 0.7494570851063831, 0.44847043617021265`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 369}], {
             RGBColor[
             0.9245402872340425, 0.745298255319149, 0.5681298510638297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 394}], {
             RGBColor[
             0.9322641063829787, 0.7479394680851065, 0.3712422659574467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 397}], {
             RGBColor[
             0.9183496914893616, 0.7406813191489362, 0.578608914893617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 370}], {
             RGBColor[
             0.9934490425531916, 0.9883964893617022, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 393}], {
             RGBColor[
             0.9909441382978723, 0.9889419148936172, 0.6848011170212764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 396}], {
             RGBColor[
             0.9852015531914894, 0.9611596382978724, 0.44665910638297857`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 363}], {
             RGBColor[
             0.9329736382978724, 0.7494570851063831, 0.44847043617021265`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 369}], {
             RGBColor[
             0.9864347553191489, 0.9872728936170213, 0.80246264893617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 397}], {
             RGBColor[
             0.9802441595744681, 0.9826559574468086, 0.8129417127659573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 369}], {
             RGBColor[
             0.9245402872340425, 0.745298255319149, 0.5681298510638297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 372}], {
             RGBColor[
             0.9329736382978724, 0.7494570851063831, 0.44847043617021265`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 385}], {
             RGBColor[
             0.9728130531914894, 0.9427833617021275, 0.6254252872340423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 370}], {
             RGBColor[
             0.9909441382978723, 0.9889419148936172, 0.6848011170212764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 398}], {
             RGBColor[
             0.968663414893617, 0.9072478510638297, 0.5348919574468085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 372}], {
             RGBColor[
             0.9864347553191489, 0.9872728936170213, 0.80246264893617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 389}], {
             RGBColor[
             0.9554542234042553, 0.8548778085106382, 0.5242635319148936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 391}], {
             RGBColor[
             0.993069414893617, 0.9910449787234042, 0.738566734042553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 380}], {
             RGBColor[
             0.9196377234042553, 0.7190973829787233, 0.254196829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 382}], {
             RGBColor[
             0.9403805319148937, 0.7895611702127658, 0.31743801063829785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 384}], {
             RGBColor[
             0.9403805319148937, 0.7895611702127658, 0.31743801063829785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 389}], {
             RGBColor[
             0.9529605744680851, 0.8422451489361702, 0.3277054787234042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 377}], {
             RGBColor[
             0.970079159574468, 0.9078332978723402, 0.511429404255319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 379}], {
             RGBColor[
             0.9930942765957447, 0.9876376808510638, 0.489732808510638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 381}], {
             RGBColor[
             0.9638575106382978, 0.881449574468085, 0.47381424468085087`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 384}], {
             RGBColor[
             0.8944776382978723, 0.6137294255319147, 0.23366189361702125`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 389}], {
             RGBColor[
             0.9070576808510638, 0.6664134042553189, 0.24392936170212765`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 389}], {
             RGBColor[
             0.9070576808510638, 0.6664134042553189, 0.24392936170212765`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 387}], {
             RGBColor[
             0.9186888723404255, 0.9369107234042553, 0.9542856702127659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 400}], {
             RGBColor[
             0.9436312127659574, 0.8107750212765956, 0.2914626702127658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 390}], {
             RGBColor[
             0.8953584468085106, 0.6132899148936171, 0.23416723404255319`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 395}], {
             RGBColor[
             0.5850988617021275, 0.6480261170212767, 0.8639156170212766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 396}], {
             RGBColor[
             0.9826966489361701, 0.9617050638297873, 0.603113329787234]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.0002105009621202394], {
             RGBColor[
             0.8593799361702127, 0.4543589574468082, 0.2043755106382978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.0002105009621202394], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.0002105009621202394], {
             RGBColor[
             0.9532390212765957, 0.9646463191489362, 0.9640383191489362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.0002105009621202394], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.0002105009621202394], {
             RGBColor[
             0.9948681063829787, 0.9914317234042553, 0.6828032340425529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.0002105009621202394], {
             RGBColor[
             0.9328469148936169, 0.7714674255319146, 0.26482525531914886`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.0002105009621202394], {
             RGBColor[
             0.9582953404255319, 0.8709825319148935, 0.29248570212765945`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.0002105009621202394], {
             RGBColor[
             0.9582953404255319, 0.8709825319148935, 0.29248570212765945`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.0002105009621202394], {
             RGBColor[
             0.9532390212765957, 0.9646463191489362, 0.9640383191489362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.0002105009621202394], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.0002105009621202394], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.0002105009621202394], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.0002105009621202394], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.0002105009621202394], {
             RGBColor[
             0.9064285319148937, 0.6667273404255321, 0.2435684042553192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.0002105009621202394], {
             RGBColor[
             0.9460561063829787, 0.8238374680851062, 0.27545368085106375`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.0002105009621202394], {
             RGBColor[
             0.7897499574468086, 0.8356779361702128, 0.9796785531914893]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.0002105009621202394], {
             RGBColor[
             0.8944776382978723, 0.6137294255319147, 0.23366189361702125`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.0002105009621202394], {
             RGBColor[
             0.9582953404255319, 0.8709825319148935, 0.29248570212765945`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.0002105009621202394], {
             RGBColor[
             0.9656202127659574, 0.9738801914893617, 0.9430801914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.0002105009621202394], {
             RGBColor[0.42255800000000004`, 0.5404202340425532, 0.948146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.0002105009621202394], {
             RGBColor[
             0.9934490425531916, 0.9883964893617022, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.0002105009621202394], {
             RGBColor[
             0.9934490425531916, 0.9883964893617022, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.0002105009621202394], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.0002105009621202394], {
             RGBColor[
             0.9460561063829787, 0.8238374680851062, 0.27545368085106375`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.0002105009621202394], {
             RGBColor[
             0.9941585744680851, 0.9899141063829787, 0.6055750638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.0002105009621202394], {
             RGBColor[
             0.9184648510638298, 0.9378229574468085, 0.9920851914893617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.0002105009621202394], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.0002105009621202394], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.0002105009621202394], {
             RGBColor[
             0.9927395106382979, 0.9868788723404256, 0.45111872340425496`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.0002105009621202394], {
             RGBColor[
             0.9769540638297872, 0.9339227872340425, 0.3649713191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.0002105009621202394], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.0002105009621202394], {
             RGBColor[
             0.9328469148936169, 0.7714674255319146, 0.26482525531914886`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.0002105009621202394], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.0002105009621202394], {
             RGBColor[
             0.9780014042553191, 0.9831140638297873, 0.9221220638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.0002105009621202394], {
             RGBColor[
             0.8944776382978723, 0.6137294255319147, 0.23366189361702125`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.0002105009621202394], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.0002105009621202394], {
             RGBColor[
             0.9927395106382979, 0.9868788723404256, 0.45111872340425496`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.0002105009621202394], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.0002105009621202394], {
             RGBColor[
             0.9934490425531916, 0.9883964893617022, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.0002105009621202394], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.0002105009621202394], {
             RGBColor[
             0.9927395106382979, 0.9868788723404256, 0.45111872340425496`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.0002105009621202394], {
             RGBColor[
             0.940857829787234, 0.9554124468085106, 0.9849964468085107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.0002105009621202394], {
             RGBColor[
             0.9328469148936169, 0.7714674255319146, 0.26482525531914886`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.0002105009621202394], {
             RGBColor[
             0.9941585744680851, 0.9899141063829787, 0.6055750638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.0002105009621202394], {
             RGBColor[
             0.9948681063829787, 0.9914317234042553, 0.6828032340425529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.0002105009621202394], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.0002105009621202394], {
             RGBColor[
             0.986283425531915, 0.965392914893617, 0.4012141276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.0002105009621202394], {
             RGBColor[
             0.9780014042553191, 0.9831140638297873, 0.9221220638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.0002105009621202394], {
             RGBColor[
             0.8487891276595745, 0.3760201914893615, 0.194353829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.0002105009621202394], {
             RGBColor[
             0.986283425531915, 0.965392914893617, 0.4012141276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.0002105009621202394], {
             RGBColor[
             0.9328469148936169, 0.7714674255319146, 0.26482525531914886`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.0002105009621202394], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.0002105009621202394], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.0002105009621202394], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.0002105009621202394], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.0002105009621202394], {
             RGBColor[
             0.9460561063829787, 0.8238374680851062, 0.27545368085106375`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.0002105009621202394], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.0002105009621202394], {
             RGBColor[
             0.9927395106382979, 0.9868788723404256, 0.45111872340425496`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.0002105009621202394], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.0002105009621202394], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.0002105009621202394], {
             RGBColor[
             0.9582953404255319, 0.8709825319148935, 0.29248570212765945`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.0002105009621202394], {
             RGBColor[
             0.9769540638297872, 0.9339227872340425, 0.3649713191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.0002105009621202394], {
             RGBColor[
             0.9948681063829787, 0.9914317234042553, 0.6828032340425529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.0002105009621202394], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.0002105009621202394], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.0002105009621202394], {
             RGBColor[
             0.9927395106382979, 0.9868788723404256, 0.45111872340425496`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.0002105009621202394], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.0002105009621202394], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.0002105009621202394], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.0002105009621202394], {
             RGBColor[
             0.986283425531915, 0.965392914893617, 0.4012141276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.0002105009621202394], {
             RGBColor[
             0.986283425531915, 0.965392914893617, 0.4012141276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.0002105009621202394], {
             RGBColor[
             0.940857829787234, 0.9554124468085106, 0.9849964468085107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.0002105009621202394], {
             RGBColor[
             0.9460561063829787, 0.8238374680851062, 0.27545368085106375`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.0002105009621202394], {
             RGBColor[
             0.9934490425531916, 0.9883964893617022, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.0002105009621202394], {
             RGBColor[
             0.9948681063829787, 0.9914317234042553, 0.6828032340425529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.0002105009621202394], {
             RGBColor[
             0.9064285319148937, 0.6667273404255321, 0.2435684042553192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.0002105009621202394], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.0002105009621202394], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.0002105009621202394], {
             RGBColor[
             0.986283425531915, 0.965392914893617, 0.4012141276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.0002105009621202394], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.0002105009621202394], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.0002105009621202394], {
             RGBColor[
             0.9941585744680851, 0.9899141063829787, 0.6055750638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.0002105009621202394], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.0002105009621202394], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.0002105009621202394], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.0002105009621202394], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.0002105009621202394], {
             RGBColor[
             0.8944776382978723, 0.6137294255319147, 0.23366189361702125`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.0002105009621202394], {
             RGBColor[
             0.9328469148936169, 0.7714674255319146, 0.26482525531914886`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.0002105009621202394], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.0002105009621202394], {
             RGBColor[
             0.9656202127659574, 0.9738801914893617, 0.9430801914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.0002105009621202394], {
             RGBColor[
             0.9656202127659574, 0.9738801914893617, 0.9430801914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.0002105009621202394], {
             RGBColor[
             0.9196377234042553, 0.7190973829787233, 0.254196829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.0002105009621202394], {
             RGBColor[
             0.9948681063829787, 0.9914317234042553, 0.6828032340425529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.0002105009621202394], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.0002105009621202394], {
             RGBColor[
             0.9934490425531916, 0.9883964893617022, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.0002105009621202394], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.0002105009621202394], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.0002105009621202394], {
             RGBColor[
             0.9656202127659574, 0.9738801914893617, 0.9430801914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.0002105009621202394], {
             RGBColor[
             0.9769540638297872, 0.9339227872340425, 0.3649713191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.0002105009621202394], {
             RGBColor[
             0.9948681063829787, 0.9914317234042553, 0.6828032340425529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.0002105009621202394], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.0002105009621202394], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.0002105009621202394], {
             RGBColor[
             0.9064285319148937, 0.6667273404255321, 0.2435684042553192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.0002105009621202394], {
             RGBColor[
             0.9780014042553191, 0.9831140638297873, 0.9221220638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.0002105009621202394], {
             RGBColor[
             0.9948681063829787, 0.9914317234042553, 0.6828032340425529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.0002105009621202394], {
             RGBColor[
             0.9948681063829787, 0.9914317234042553, 0.6828032340425529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.0002105009621202394], {
             RGBColor[
             0.9196377234042553, 0.7190973829787233, 0.254196829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.0002105009621202394], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.0002105009621202394], {
             RGBColor[
             0.9460561063829787, 0.8238374680851062, 0.27545368085106375`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.0002105009621202394], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.0002105009621202394], {
             RGBColor[
             0.8593799361702127, 0.4543589574468082, 0.2043755106382978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.0002105009621202394], {
             RGBColor[
             0.9948681063829787, 0.9914317234042553, 0.6828032340425529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.0002105009621202394], {
             RGBColor[
             0.9328469148936169, 0.7714674255319146, 0.26482525531914886`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.0002105009621202394], {
             RGBColor[
             0.986283425531915, 0.965392914893617, 0.4012141276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.0002105009621202394], {
             RGBColor[
             0.9927395106382979, 0.9868788723404256, 0.45111872340425496`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.0002105009621202394], {
             RGBColor[
             0.9941585744680851, 0.9899141063829787, 0.6055750638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.0002105009621202394], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.0002105009621202394], {
             RGBColor[
             0.9582953404255319, 0.8709825319148935, 0.29248570212765945`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.0002105009621202394], {
             RGBColor[
             0.9948681063829787, 0.9914317234042553, 0.6828032340425529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.0002105009621202394], {
             RGBColor[
             0.9934490425531916, 0.9883964893617022, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.0002105009621202394], {
             RGBColor[
             0.986283425531915, 0.965392914893617, 0.4012141276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.0002105009621202394], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.0002105009621202394], {
             RGBColor[
             0.8278090425531914, 0.2147580638297869, 0.17426327659574464`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.0002105009621202394], {
             RGBColor[
             0.8593799361702127, 0.4543589574468082, 0.2043755106382978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.0002105009621202394], {
             RGBColor[
             0.940857829787234, 0.9554124468085106, 0.9849964468085107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.0002105009621202394], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.0002105009621202394], {
             RGBColor[
             0.986283425531915, 0.965392914893617, 0.4012141276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.0002105009621202394], {
             RGBColor[
             0.8944776382978723, 0.6137294255319147, 0.23366189361702125`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.0002105009621202394], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.0002105009621202394], {
             RGBColor[
             0.9582953404255319, 0.8709825319148935, 0.29248570212765945`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.0002105009621202394], {
             RGBColor[
             0.9934490425531916, 0.9883964893617022, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.0002105009621202394], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.0002105009621202394], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.0002105009621202394], {
             RGBColor[
             0.9328469148936169, 0.7714674255319146, 0.26482525531914886`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.0002105009621202394], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.0002105009621202394], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.0002105009621202394], {
             RGBColor[
             0.9532390212765957, 0.9646463191489362, 0.9640383191489362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.0002105009621202394], {
             RGBColor[
             0.986283425531915, 0.965392914893617, 0.4012141276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.0002105009621202394], {
             RGBColor[
             0.8298320851063831, 0.8671495957446809, 0.9836313191489362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.0002105009621202394], {
             RGBColor[
             0.9196377234042553, 0.7190973829787233, 0.254196829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.0002105009621202394], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.0002105009621202394], {
             RGBColor[
             0.9582953404255319, 0.8709825319148935, 0.29248570212765945`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.0002105009621202394], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.0002105009621202394], {
             RGBColor[
             0.986283425531915, 0.965392914893617, 0.4012141276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.0002105009621202394], {
             RGBColor[
             0.9460561063829787, 0.8238374680851062, 0.27545368085106375`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.0002105009621202394], {
             RGBColor[
             0.986283425531915, 0.965392914893617, 0.4012141276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.0002105009621202394], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.0002105009621202394], {
             RGBColor[
             0.940857829787234, 0.9554124468085106, 0.9849964468085107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.0002105009621202394], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.0002105009621202394], {
             RGBColor[
             0.8710791702127659, 0.5074824468085107, 0.21413763829787236`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.0002105009621202394], {
             RGBColor[
             0.9196377234042553, 0.7190973829787233, 0.254196829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.0002105009621202394], {
             RGBColor[
             0.986283425531915, 0.965392914893617, 0.4012141276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.0002105009621202394], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.0002105009621202394], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.0002105009621202394], {
             RGBColor[
             0.8593763404255319, 0.8907073829787233, 0.9864492765957447]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.0002105009621202394], {
             RGBColor[
             0.9927395106382979, 0.9868788723404256, 0.45111872340425496`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.0002105009621202394], {
             RGBColor[
             0.9582953404255319, 0.8709825319148935, 0.29248570212765945`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.0002105009621202394], {
             RGBColor[
             0.9948681063829787, 0.9914317234042553, 0.6828032340425529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.0002105009621202394], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.0002105009621202394], {
             RGBColor[
             0.9656202127659574, 0.9738801914893617, 0.9430801914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.0002105009621202394], {
             RGBColor[
             0.9780014042553191, 0.9831140638297873, 0.9221220638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.0002105009621202394], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.0002105009621202394], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.0002105009621202394], {
             RGBColor[
             0.9460561063829787, 0.8238374680851062, 0.27545368085106375`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.0002105009621202394], {
             RGBColor[
             0.986283425531915, 0.965392914893617, 0.4012141276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.0002105009621202394], {
             RGBColor[
             0.9941585744680851, 0.9899141063829787, 0.6055750638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.0002105009621202394], {
             RGBColor[
             0.9582953404255319, 0.8709825319148935, 0.29248570212765945`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.0002105009621202394], {
             RGBColor[
             0.940857829787234, 0.9554124468085106, 0.9849964468085107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.0002105009621202394], {
             RGBColor[
             0.8593799361702127, 0.4543589574468082, 0.2043755106382978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.0002105009621202394], {
             RGBColor[
             0.9948681063829787, 0.9914317234042553, 0.6828032340425529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.0002105009621202394], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.0002105009621202394], {
             RGBColor[
             0.986283425531915, 0.965392914893617, 0.4012141276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.0002105009621202394], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.0002105009621202394], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.0002105009621202394], {
             RGBColor[
             0.9769540638297872, 0.9339227872340425, 0.3649713191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.0002105009621202394], {
             RGBColor[
             0.9934490425531916, 0.9883964893617022, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.0002105009621202394], {
             RGBColor[
             0.9934490425531916, 0.9883964893617022, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.0002105009621202394], {
             RGBColor[
             0.986283425531915, 0.965392914893617, 0.4012141276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.0002105009621202394], {
             RGBColor[
             0.9927395106382979, 0.9868788723404256, 0.45111872340425496`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.0002105009621202394], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.0002105009621202394], {
             RGBColor[
             0.9941585744680851, 0.9899141063829787, 0.6055750638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.0002105009621202394], {
             RGBColor[
             0.8944776382978723, 0.6137294255319147, 0.23366189361702125`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.0002105009621202394], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.0002105009621202394], {
             RGBColor[
             0.9941585744680851, 0.9899141063829787, 0.6055750638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.0002105009621202394], {
             RGBColor[
             0.8710791702127659, 0.5074824468085107, 0.21413763829787236`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.0002105009621202394], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.0002105009621202394], {
             RGBColor[
             0.9769540638297872, 0.9339227872340425, 0.3649713191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.0002105009621202394], {
             RGBColor[
             0.940857829787234, 0.9554124468085106, 0.9849964468085107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.0002105009621202394], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.0002105009621202394], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.0002105009621202394], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.0002105009621202394], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.0002105009621202394], {
             RGBColor[
             0.9064285319148937, 0.6667273404255321, 0.2435684042553192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.0002105009621202394], {
             RGBColor[
             0.9328469148936169, 0.7714674255319146, 0.26482525531914886`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.0002105009621202394], {
             RGBColor[
             0.9948681063829787, 0.9914317234042553, 0.6828032340425529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.0002105009621202394], {
             RGBColor[
             0.9948681063829787, 0.9914317234042553, 0.6828032340425529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.0002105009621202394], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.0002105009621202394], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.0002105009621202394], {
             RGBColor[
             0.9941585744680851, 0.9899141063829787, 0.6055750638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.0002105009621202394], {
             RGBColor[
             0.9532390212765957, 0.9646463191489362, 0.9640383191489362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.0002105009621202394], {
             RGBColor[
             0.9769540638297872, 0.9339227872340425, 0.3649713191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.0002105009621202394], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.0002105009621202394], {
             RGBColor[
             0.8944776382978723, 0.6137294255319147, 0.23366189361702125`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.0002105009621202394], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.0002105009621202394], {
             RGBColor[
             0.9064285319148937, 0.6667273404255321, 0.2435684042553192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.0002105009621202394], {
             RGBColor[
             0.9934490425531916, 0.9883964893617022, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.0002105009621202394], {
             RGBColor[
             0.9780014042553191, 0.9831140638297873, 0.9221220638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.0002105009621202394], {
             RGBColor[
             0.9948681063829787, 0.9914317234042553, 0.6828032340425529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.0002105009621202394], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.0002105009621202394], {
             RGBColor[
             0.838299085106383, 0.2953891276595746, 0.18430855319148937`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.0002105009621202394], {
             RGBColor[
             0.9948681063829787, 0.9914317234042553, 0.6828032340425529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.0002105009621202394], {
             RGBColor[
             0.9941585744680851, 0.9899141063829787, 0.6055750638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.0002105009621202394], {
             RGBColor[
             0.9582953404255319, 0.8709825319148935, 0.29248570212765945`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.0002105009621202394], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.0002105009621202394], {
             RGBColor[
             0.9656202127659574, 0.9738801914893617, 0.9430801914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.0002105009621202394], {
             RGBColor[
             0.9941585744680851, 0.9899141063829787, 0.6055750638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.0002105009621202394], {
             RGBColor[
             0.9328469148936169, 0.7714674255319146, 0.26482525531914886`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.0002105009621202394], {
             RGBColor[
             0.8889205957446809, 0.914265170212766, 0.9892672340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.0002105009621202394], {
             RGBColor[
             0.9460561063829787, 0.8238374680851062, 0.27545368085106375`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.0002105009621202394], {
             RGBColor[
             0.9582953404255319, 0.8709825319148935, 0.29248570212765945`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.0002105009621202394], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.0002105009621202394], {
             RGBColor[
             0.9582953404255319, 0.8709825319148935, 0.29248570212765945`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.0002105009621202394], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.0002105009621202394], {
             RGBColor[
             0.9948681063829787, 0.9914317234042553, 0.6828032340425529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.0002105009621202394], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.0002105009621202394], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.0002105009621202394], {
             RGBColor[
             0.940857829787234, 0.9554124468085106, 0.9849964468085107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.0002105009621202394], {
             RGBColor[
             0.986283425531915, 0.965392914893617, 0.4012141276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.0002105009621202394], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.0002105009621202394], {
             RGBColor[
             0.8710791702127659, 0.5074824468085107, 0.21413763829787236`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.0002105009621202394], {
             RGBColor[
             0.940857829787234, 0.9554124468085106, 0.9849964468085107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.0002105009621202394], {
             RGBColor[
             0.9769540638297872, 0.9339227872340425, 0.3649713191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.0002105009621202394], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.0002105009621202394], {
             RGBColor[
             0.940857829787234, 0.9554124468085106, 0.9849964468085107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.0002105009621202394], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.0002105009621202394], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.0002105009621202394], {
             RGBColor[
             0.9656202127659574, 0.9738801914893617, 0.9430801914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.0002105009621202394], {
             RGBColor[
             0.6990478297872342, 0.7648207446808513, 0.9706382127659574]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.0002105009621202394], {
             RGBColor[
             0.9460561063829787, 0.8238374680851062, 0.27545368085106375`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.0002105009621202394], {
             RGBColor[
             0.9769540638297872, 0.9339227872340425, 0.3649713191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.0002105009621202394], {
             RGBColor[
             0.9941585744680851, 0.9899141063829787, 0.6055750638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.0002105009621202394], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.0002105009621202394], {
             RGBColor[
             0.986283425531915, 0.965392914893617, 0.4012141276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.0002105009621202394], {
             RGBColor[
             0.9582953404255319, 0.8709825319148935, 0.29248570212765945`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.0002105009621202394], {
             RGBColor[
             0.8298320851063831, 0.8671495957446809, 0.9836313191489362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.0002105009621202394], {
             RGBColor[
             0.9532390212765957, 0.9646463191489362, 0.9640383191489362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.0002105009621202394], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.0002105009621202394], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.0002105009621202394], {
             RGBColor[
             0.9927395106382979, 0.9868788723404256, 0.45111872340425496`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.0002105009621202394], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.0002105009621202394], {
             RGBColor[
             0.9184648510638298, 0.9378229574468085, 0.9920851914893617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.0002105009621202394], {
             RGBColor[
             0.986283425531915, 0.965392914893617, 0.4012141276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.0002105009621202394], {
             RGBColor[
             0.9064285319148937, 0.6667273404255321, 0.2435684042553192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.0002105009621202394], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.0002105009621202394], {
             RGBColor[
             0.9927395106382979, 0.9868788723404256, 0.45111872340425496`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.0002105009621202394], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.0002105009621202394], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.0002105009621202394], {
             RGBColor[
             0.9582953404255319, 0.8709825319148935, 0.29248570212765945`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.0002105009621202394], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.0002105009621202394], {
             RGBColor[
             0.940857829787234, 0.9554124468085106, 0.9849964468085107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.0002105009621202394], {
             RGBColor[
             0.9934490425531916, 0.9883964893617022, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.0002105009621202394], {
             RGBColor[
             0.9927395106382979, 0.9868788723404256, 0.45111872340425496`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.0002105009621202394], {
             RGBColor[
             0.9582953404255319, 0.8709825319148935, 0.29248570212765945`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.0002105009621202394], {
             RGBColor[
             0.9780014042553191, 0.9831140638297873, 0.9221220638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.0002105009621202394], {
             RGBColor[
             0.9934490425531916, 0.9883964893617022, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.0002105009621202394], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.0002105009621202394], {
             RGBColor[
             0.9941585744680851, 0.9899141063829787, 0.6055750638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.0002105009621202394], {
             RGBColor[
             0.9769540638297872, 0.9339227872340425, 0.3649713191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.0002105009621202394], {
             RGBColor[
             0.9941585744680851, 0.9899141063829787, 0.6055750638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.0002105009621202394], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.0002105009621202394], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.0002105009621202394], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.0002105009621202394], {
             RGBColor[
             0.9196377234042553, 0.7190973829787233, 0.254196829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.0002105009621202394], {
             RGBColor[
             0.9582953404255319, 0.8709825319148935, 0.29248570212765945`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.0002105009621202394], {
             RGBColor[
             0.940857829787234, 0.9554124468085106, 0.9849964468085107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.0002105009621202394], {
             RGBColor[
             0.8593763404255319, 0.8907073829787233, 0.9864492765957447]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.0002105009621202394], {
             RGBColor[
             0.9460561063829787, 0.8238374680851062, 0.27545368085106375`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.0002105009621202394], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.0002105009621202394], {
             RGBColor[
             0.9064285319148937, 0.6667273404255321, 0.2435684042553192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.0002105009621202394], {
             RGBColor[
             0.8889205957446809, 0.914265170212766, 0.9892672340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.0002105009621202394], {
             RGBColor[
             0.9582953404255319, 0.8709825319148935, 0.29248570212765945`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.0002105009621202394], {
             RGBColor[
             0.9769540638297872, 0.9339227872340425, 0.3649713191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.0002105009621202394], {
             RGBColor[
             0.9927395106382979, 0.9868788723404256, 0.45111872340425496`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.0002105009621202394], {
             RGBColor[
             0.9582953404255319, 0.8709825319148935, 0.29248570212765945`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.0002105009621202394], {
             RGBColor[
             0.8593799361702127, 0.4543589574468082, 0.2043755106382978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.0002105009621202394], {
             RGBColor[
             0.9948681063829787, 0.9914317234042553, 0.6828032340425529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.0002105009621202394], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.0002105009621202394], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.0002105009621202394], {
             RGBColor[
             0.9184648510638298, 0.9378229574468085, 0.9920851914893617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.0002105009621202394], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.0002105009621202394], {
             RGBColor[
             0.9769540638297872, 0.9339227872340425, 0.3649713191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.0002105009621202394], {
             RGBColor[
             0.8593763404255319, 0.8907073829787233, 0.9864492765957447]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.0002105009621202394], {
             RGBColor[
             0.9780014042553191, 0.9831140638297873, 0.9221220638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.0002105009621202394], {
             RGBColor[
             0.9780014042553191, 0.9831140638297873, 0.9221220638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.0002105009621202394], {
             RGBColor[
             0.9184648510638298, 0.9378229574468085, 0.9920851914893617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.0002105009621202394], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.0002105009621202394], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.0002105009621202394], {
             RGBColor[
             0.9948681063829787, 0.9914317234042553, 0.6828032340425529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.0002105009621202394], {
             RGBColor[
             0.9582953404255319, 0.8709825319148935, 0.29248570212765945`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.0002105009621202394], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.0002105009621202394], {
             RGBColor[
             0.9934490425531916, 0.9883964893617022, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.0002105009621202394], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.0002105009621202394], {
             RGBColor[
             0.8889205957446809, 0.914265170212766, 0.9892672340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.0002105009621202394], {
             RGBColor[
             0.9328469148936169, 0.7714674255319146, 0.26482525531914886`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.0002105009621202394], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.0002105009621202394], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.0002105009621202394], {
             RGBColor[
             0.9934490425531916, 0.9883964893617022, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.0002105009621202394], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.0002105009621202394], {
             RGBColor[
             0.9656202127659574, 0.9738801914893617, 0.9430801914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.0002105009621202394], {
             RGBColor[
             0.9196377234042553, 0.7190973829787233, 0.254196829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.0002105009621202394], {
             RGBColor[
             0.9184648510638298, 0.9378229574468085, 0.9920851914893617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.0002105009621202394], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.0002105009621202394], {
             RGBColor[
             0.9460561063829787, 0.8238374680851062, 0.27545368085106375`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.0002105009621202394], {
             RGBColor[
             0.9328469148936169, 0.7714674255319146, 0.26482525531914886`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.0002105009621202394], {
             RGBColor[
             0.9927395106382979, 0.9868788723404256, 0.45111872340425496`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.0002105009621202394], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.0002105009621202394], {
             RGBColor[
             0.9328469148936169, 0.7714674255319146, 0.26482525531914886`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.0002105009621202394], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.0002105009621202394], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.0002105009621202394], {
             RGBColor[
             0.9934490425531916, 0.9883964893617022, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.0002105009621202394], {
             RGBColor[
             0.8593799361702127, 0.4543589574468082, 0.2043755106382978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.0002105009621202394], {
             RGBColor[
             0.9934490425531916, 0.9883964893617022, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.0002105009621202394], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.0002105009621202394], {
             RGBColor[
             0.9532390212765957, 0.9646463191489362, 0.9640383191489362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.0002105009621202394], {
             RGBColor[
             0.9927395106382979, 0.9868788723404256, 0.45111872340425496`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.0002105009621202394], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.0002105009621202394], {
             RGBColor[
             0.9656202127659574, 0.9738801914893617, 0.9430801914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.0002105009621202394], {
             RGBColor[
             0.9582953404255319, 0.8709825319148935, 0.29248570212765945`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.0002105009621202394], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.0002105009621202394], {
             RGBColor[
             0.9934490425531916, 0.9883964893617022, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.0002105009621202394], {
             RGBColor[
             0.9328469148936169, 0.7714674255319146, 0.26482525531914886`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.0002105009621202394], {
             RGBColor[
             0.9934490425531916, 0.9883964893617022, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.0002105009621202394], {
             RGBColor[
             0.9941585744680851, 0.9899141063829787, 0.6055750638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.0002105009621202394], {
             RGBColor[
             0.9780014042553191, 0.9831140638297873, 0.9221220638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.0002105009621202394], {
             RGBColor[
             0.9780014042553191, 0.9831140638297873, 0.9221220638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.0002105009621202394], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.0002105009621202394], {
             RGBColor[
             0.9532390212765957, 0.9646463191489362, 0.9640383191489362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.0002105009621202394], {
             RGBColor[
             0.9184648510638298, 0.9378229574468085, 0.9920851914893617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.0002105009621202394], {
             RGBColor[
             0.9196377234042553, 0.7190973829787233, 0.254196829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.0002105009621202394], {
             RGBColor[
             0.9941585744680851, 0.9899141063829787, 0.6055750638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.0002105009621202394], {
             RGBColor[
             0.9460561063829787, 0.8238374680851062, 0.27545368085106375`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.0002105009621202394], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.0002105009621202394], {
             RGBColor[
             0.9769540638297872, 0.9339227872340425, 0.3649713191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.0002105009621202394], {
             RGBColor[
             0.9328469148936169, 0.7714674255319146, 0.26482525531914886`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.0002105009621202394], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.0002105009621202394], {
             RGBColor[
             0.986283425531915, 0.965392914893617, 0.4012141276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.0002105009621202394], {
             RGBColor[
             0.9582953404255319, 0.8709825319148935, 0.29248570212765945`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.0002105009621202394], {
             RGBColor[
             0.9064285319148937, 0.6667273404255321, 0.2435684042553192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.0002105009621202394], {
             RGBColor[
             0.940857829787234, 0.9554124468085106, 0.9849964468085107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.0002105009621202394], {
             RGBColor[
             0.9769540638297872, 0.9339227872340425, 0.3649713191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.0002105009621202394], {
             RGBColor[
             0.940857829787234, 0.9554124468085106, 0.9849964468085107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.0002105009621202394], {
             RGBColor[
             0.9769540638297872, 0.9339227872340425, 0.3649713191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.0002105009621202394], {
             RGBColor[
             0.985607744680851, 0.9883164468085107, 0.8881804468085105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.0002105009621202394], {
             RGBColor[
             0.9927395106382979, 0.9868788723404256, 0.45111872340425496`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.0002105009621202394], {
             RGBColor[
             0.9948681063829787, 0.9914317234042553, 0.6828032340425529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.0002105009621202394], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.0002105009621202394], {
             RGBColor[
             0.8944776382978723, 0.6137294255319147, 0.23366189361702125`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.0002105009621202394], {
             RGBColor[
             0.9196377234042553, 0.7190973829787233, 0.254196829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.0002105009621202394], {
             RGBColor[
             0.8710791702127659, 0.5074824468085107, 0.21413763829787236`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.0002105009621202394], {
             RGBColor[
             0.9934490425531916, 0.9883964893617022, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.0002105009621202394], {
             RGBColor[
             0.9934490425531916, 0.9883964893617022, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.0002105009621202394], {
             RGBColor[
             0.9948681063829787, 0.9914317234042553, 0.6828032340425529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.0002105009621202394], {
             RGBColor[
             0.8710791702127659, 0.5074824468085107, 0.21413763829787236`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.0002105009621202394], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.0002105009621202394], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.0002105009621202394], {
             RGBColor[
             0.9769540638297872, 0.9339227872340425, 0.3649713191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.0002105009621202394], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.0002105009621202394], {
             RGBColor[
             0.9927395106382979, 0.9868788723404256, 0.45111872340425496`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.0002105009621202394], {
             RGBColor[
             0.9780014042553191, 0.9831140638297873, 0.9221220638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.0002105009621202394], {
             RGBColor[
             0.9934490425531916, 0.9883964893617022, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.0002105009621202394], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.0002105009621202394], {
             RGBColor[
             0.9948681063829787, 0.9914317234042553, 0.6828032340425529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.0002105009621202394], {
             RGBColor[
             0.9064285319148937, 0.6667273404255321, 0.2435684042553192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.0002105009621202394], {
             RGBColor[
             0.986283425531915, 0.965392914893617, 0.4012141276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.0002105009621202394], {
             RGBColor[
             0.9460561063829787, 0.8238374680851062, 0.27545368085106375`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.0002105009621202394], {
             RGBColor[
             0.9927395106382979, 0.9868788723404256, 0.45111872340425496`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.0002105009621202394], {
             RGBColor[
             0.9941022127659574, 0.9918291276595744, 0.7474051276595743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.0002105009621202394], {
             RGBColor[
             0.9934490425531916, 0.9883964893617022, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.0002105009621202394], {
             RGBColor[
             0.9927395106382979, 0.9868788723404256, 0.45111872340425496`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.0002105009621202394], {
             RGBColor[
             0.9328469148936169, 0.7714674255319146, 0.26482525531914886`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.0002105009621202394], {
             RGBColor[
             0.9948681063829787, 0.9914317234042553, 0.6828032340425529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.0002105009621202394], {
             RGBColor[
             0.8944776382978723, 0.6137294255319147, 0.23366189361702125`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.0002105009621202394], {
             RGBColor[
             0.986283425531915, 0.965392914893617, 0.4012141276595744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.0002105009621202394], {
             RGBColor[
             0.8944776382978723, 0.6137294255319147, 0.23366189361702125`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.0002105009621202394], {
             RGBColor[
             0.9780014042553191, 0.9831140638297873, 0.9221220638297871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.0002105009621202394], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.0002105009621202394], {
             RGBColor[
             0.8593763404255319, 0.8907073829787233, 0.9864492765957447]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.0002105009621202394], {
             RGBColor[
             0.9676247021276595, 0.9024526595744679, 0.32872851063829756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.0002105009621202394], {
             RGBColor[
             0.9196377234042553, 0.7190973829787233, 0.254196829787234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.0002105009621202394], {
             RGBColor[
             0.8710791702127659, 0.5074824468085107, 0.21413763829787236`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.0002105009621202394], {
             RGBColor[
             0.9948681063829787, 0.9914317234042553, 0.6828032340425529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.0002105009621202394], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.0002105009621202394], {
             RGBColor[
             0.9884392340425532, 0.989487340425532, 0.8412553404255317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.0002105009621202394], {
             RGBColor[
             0.9934490425531916, 0.9883964893617022, 0.528346893617021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.0002105009621202394], {
             RGBColor[
             0.9912707234042553, 0.9906582340425532, 0.7943302340425532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.0002105009621202394], {
             RGBColor[
             0.9769540638297872, 0.9339227872340425, 0.3649713191489361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.0002105009621202394], {
             RGBColor[
             0.9656202127659574, 0.9738801914893617, 0.9430801914893616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.0002105009621202394], {
             RGBColor[
             0.9460561063829787, 0.8238374680851062, 0.27545368085106375`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.0002105009621202394], {
             RGBColor[
             0.9941585744680851, 0.9899141063829787, 0.6055750638297872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.0002105009621202394], {
             RGBColor[
             0.9196377234042553, 0.7190973829787233, 0.254196829787234]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN2wucznW+wPHf/+zadNlSKJUyheimsIbchiJLGlM0NrNmJtWMMW5DaZZc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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[337, 399] -> 
             RGBColor[
              0.9603114409091467, 0.8681403292906987, 0.42659540071605706`], 
             UndirectedEdge[15, 92] -> 
             RGBColor[
              0.3916080301069964, 0.5102971083648917, 0.9465821312407912], 
             UndirectedEdge[87, 313] -> 
             RGBColor[
              0.2082730893529932, 0.33623860055952687`, 0.9351722163750043], 
             UndirectedEdge[35, 214] -> 
             RGBColor[
              0.23799829524204824`, 0.3674816766358314, 0.9368650228758846], 
             UndirectedEdge[105, 218] -> 
             RGBColor[
              0.20016816814604027`, 0.3277198144893344, 0.9347106531024247], 
             UndirectedEdge[149, 316] -> 
             RGBColor[
              0.2254786330368893, 0.3543227178657783, 0.9361520466344813], 
             UndirectedEdge[160, 348] -> 
             RGBColor[
              0.39638156393997953`, 0.5175763121944144, 0.946525366087156], 
             UndirectedEdge[17, 287] -> 
             RGBColor[
              0.2108043778715786, 0.3388991452855218, 0.9353163695114319], 
             UndirectedEdge[268, 295] -> 
             RGBColor[
              0.5541988760682194, 0.6477364431214906, 0.9586174510059542], 
             UndirectedEdge[277, 379] -> 
             RGBColor[
              0.2074585735841274, 0.33538249284316635`, 0.9351258309069355], 
             UndirectedEdge[10, 37] -> 
             RGBColor[
              0.29314980125126083`, 0.4217462676405007, 0.9401414095988625], 
             UndirectedEdge[118, 389] -> 
             RGBColor[
              0.22076497088432706`, 0.3493683600799934, 0.9358836105481312], 
             UndirectedEdge[127, 313] -> 
             RGBColor[
              0.20658568658737522`, 0.3344650332653477, 0.935076121283791], 
             UndirectedEdge[92, 281] -> 
             RGBColor[
              0.46303919301965735`, 0.5742863383640635, 0.9510560694278913], 
             UndirectedEdge[2, 193] -> 
             RGBColor[
              0.18596534003799042`, 0.3127917416364609, 0.9339018230528726], 
             UndirectedEdge[265, 378] -> 
             RGBColor[
              0.19040066183963522`, 0.31745354606563403`, 0.9341544080680056],
              UndirectedEdge[108, 367] -> 
             RGBColor[
              0.31561783688898226`, 0.44293150514134, 0.9415099085808494], 
             UndirectedEdge[26, 342] -> 
             RGBColor[
              0.18535691671142462`, 0.3121522501439733, 0.9338671742445064], 
             UndirectedEdge[57, 144] -> 
             RGBColor[
              0.20411547873617336`, 0.33186868819351084`, 0.93493544660101], 
             UndirectedEdge[341, 348] -> 
             RGBColor[
              0.33468734849454873`, 0.4643110922158917, 0.9425469597870388], 
             UndirectedEdge[232, 309] -> 
             RGBColor[
              0.2963446868922668, 0.42880743363510754`, 0.9401877635646132], 
             UndirectedEdge[23, 202] -> 
             RGBColor[
              0.2682077809117381, 0.39923376146669465`, 0.9385854083938443], 
             UndirectedEdge[89, 170] -> 
             RGBColor[
              0.21045471282523004`, 0.33853162515176505`, 0.9352964566043255],
              UndirectedEdge[291, 383] -> 
             RGBColor[
              0.1977645203288262, 0.3251934282333686, 0.9345737689151127], 
             UndirectedEdge[45, 140] -> 
             RGBColor[
              0.25525427585226035`, 0.38561880634952683`, 0.9378477254437005],
              UndirectedEdge[213, 308] -> 
             RGBColor[
              0.2120594900785835, 0.3402183477937941, 0.9353878462948488], 
             UndirectedEdge[165, 386] -> 
             RGBColor[
              0.8287550787424094, 0.8667695006906301, 0.9834015662110343], 
             UndirectedEdge[347, 381] -> 
             RGBColor[
              0.1970073353004369, 0.3243975787602278, 0.9345306483479008], 
             UndirectedEdge[216, 396] -> 
             RGBColor[
              0.19963425463605258`, 0.3271586375382656, 0.9346802475178853], 
             UndirectedEdge[39, 150] -> 
             RGBColor[
              0.1883607596919023, 0.31530947957110045`, 0.9340382386584571], 
             UndirectedEdge[20, 378] -> 
             RGBColor[
              0.19055340614426983`, 0.31761409001435326`, 0.9341631066301896],
              UndirectedEdge[363, 372] -> 
             RGBColor[
              0.20698461099735616`, 0.3348843281135061, 0.9350988394387836], 
             UndirectedEdge[54, 318] -> 
             RGBColor[
              0.18950140793350456`, 0.31650837319430003`, 0.9341031968883784],
              UndirectedEdge[40, 246] -> 
             RGBColor[
              0.7206526383610699, 0.7806508133791874, 0.9738469548784772], 
             UndirectedEdge[59, 178] -> 
             RGBColor[
              0.3941011919373124, 0.5157723771794137, 0.9463327573536129], 
             UndirectedEdge[172, 357] -> 
             RGBColor[
              0.8404518577056951, 0.3119362812088553, 0.18637005066379952`], 
             UndirectedEdge[268, 274] -> 
             RGBColor[
              0.5862206904488971, 0.6743925388404906, 0.9609561467561663], 
             UndirectedEdge[122, 175] -> 
             RGBColor[
              0.4398070896700592, 0.5489279977942612, 0.9504219852000314], 
             UndirectedEdge[120, 341] -> 
             RGBColor[
              0.42726711236099996`, 0.542734639248357, 0.9489335670306169], 
             UndirectedEdge[220, 366] -> 
             RGBColor[
              0.5151109603637722, 0.615629530907049, 0.9554125916387102], 
             UndirectedEdge[202, 366] -> 
             RGBColor[
              0.31887937893336776`, 0.4445735814559359, 0.9417610431931018], 
             UndirectedEdge[17, 61] -> 
             RGBColor[
              0.22052046256389546`, 0.34911136633249684`, 0.9358696861610002],
              UndirectedEdge[112, 279] -> 
             RGBColor[
              0.8046710367643358, 0.7661172165820809, 0.618109700945247], 
             UndirectedEdge[129, 313] -> 
             RGBColor[
              0.203727765298821, 0.33146117678840176`, 0.9349133668943235], 
             UndirectedEdge[204, 318] -> 
             RGBColor[
              0.1940125074344074, 0.321249824789977, 0.9343600973313813], 
             UndirectedEdge[60, 335] -> 
             RGBColor[
              0.18275395419094043`, 0.3094163714975885, 0.9337189393797027], 
             UndirectedEdge[256, 386] -> 
             RGBColor[
              0.556034698630532, 0.6458694921919914, 0.9601976146247932], 
             UndirectedEdge[7, 65] -> 
             RGBColor[
              0.36829577629683624`, 0.4914979419428903, 0.9447588725119885], 
             UndirectedEdge[66, 280] -> 
             RGBColor[
              0.23290342941472336`, 0.362126649618162, 0.936574877804197], 
             UndirectedEdge[147, 344] -> 
             RGBColor[
              0.1873628349672718, 0.31426059741343176`, 0.9339814083216866], 
             UndirectedEdge[329, 349] -> 
             RGBColor[
              0.19621450085245074`, 0.32356425948678696`, 0.9344854975989814],
              UndirectedEdge[170, 306] -> 
             RGBColor[
              0.21718838977102684`, 0.3456091465615747, 0.9356799295448063], 
             UndirectedEdge[175, 178] -> 
             RGBColor[
              0.3616708025324146, 0.48517771913218966`, 0.9443580450417194], 
             UndirectedEdge[115, 166] -> 
             RGBColor[
              0.92715146758626, 0.7340525782000142, 0.5145919024804202], 
             UndirectedEdge[361, 396] -> 
             RGBColor[
              0.20859692759923504`, 0.3365789750888577, 0.935190658484052], 
             UndirectedEdge[80, 265] -> 
             RGBColor[
              0.18489536415726843`, 0.31166712914543293`, 0.933840889509353], 
             UndirectedEdge[18, 288] -> 
             RGBColor[
              0.45525573629442806`, 0.5643070139273578, 0.9513799079587884], 
             UndirectedEdge[225, 240] -> 
             RGBColor[
              0.8581995989845774, 0.5777442515282645, 0.5834221523927036], 
             UndirectedEdge[110, 251] -> 
             RGBColor[
              0.18685400772656674`, 0.3137257877219404, 0.9339524313630709], 
             UndirectedEdge[56, 169] -> 
             RGBColor[
              0.6387195548301612, 0.7123648726900207, 0.967730862260616], 
             UndirectedEdge[87, 231] -> 
             RGBColor[
              0.19018595982878306`, 0.3172278806393347, 0.9341421811061108], 
             UndirectedEdge[266, 315] -> 
             RGBColor[
              0.22579916171770553`, 0.3546596138320083, 0.9361703002686741], 
             UndirectedEdge[31, 292] -> 
             RGBColor[
              0.19543097961487327`, 0.32274072898797734`, 0.9344408772236172],
              UndirectedEdge[1, 87] -> 
             RGBColor[
              0.19586287681444192`, 0.32319468032858806`, 0.934465473130198], 
             UndirectedEdge[231, 336] -> 
             RGBColor[
              0.1812731232878139, 0.3078599243283004, 0.9336346082504626], 
             UndirectedEdge[13, 309] -> 
             RGBColor[
              0.25587961899129924`, 0.38627608163770166`, 0.9378833378103566],
              UndirectedEdge[237, 296] -> 
             RGBColor[
              0.2211466738327187, 0.34976955408011773`, 0.935905347966363], 
             UndirectedEdge[95, 312] -> 
             RGBColor[
              0.43115946169626646`, 0.5444500738116986, 0.9495097680739197], 
             UndirectedEdge[108, 236] -> 
             RGBColor[
              0.2534644343240474, 0.3837375694208677, 0.9377457966165021], 
             UndirectedEdge[48, 176] -> 
             RGBColor[
              0.2369284794639835, 0.36635723242284735`, 0.9368040984499744], 
             UndirectedEdge[49, 52] -> 
             RGBColor[
              0.1835216269875808, 0.31022324428012404`, 0.9337626572098012], 
             UndirectedEdge[310, 390] -> 
             RGBColor[
              0.27115500533733905`, 0.4023314812028227, 0.9387532484648545], 
             UndirectedEdge[343, 358] -> 
             RGBColor[
              0.18639835798283702`, 0.3132468709514181, 0.933926482784239], 
             UndirectedEdge[271, 374] -> 
             RGBColor[
              0.184659451088446, 0.3114191695523481, 0.9338274546090857], 
             UndirectedEdge[57, 167] -> 
             RGBColor[
              0.2639676028821611, 0.3946376054360735, 0.9383490428444853], 
             UndirectedEdge[34, 214] -> 
             RGBColor[
              0.25149658822823806`, 0.38166923840552336`, 0.9376337306925131],
              UndirectedEdge[83, 220] -> 
             RGBColor[
              0.790428504618827, 0.8368778917698232, 0.9711999364788909], 
             UndirectedEdge[9, 347] -> 
             RGBColor[
              0.19444294915612814`, 0.3217022463310869, 0.9343846103506517], 
             UndirectedEdge[188, 238] -> 
             RGBColor[
              0.2458833929201038, 0.375769414239536, 0.9373140675236933], 
             UndirectedEdge[79, 137] -> 
             RGBColor[
              0.2827537056275888, 0.4121446936308188, 0.939500838618308], 
             UndirectedEdge[115, 197] -> 
             RGBColor[
              0.914459777232721, 0.7255013666531043, 0.5770167261447392], 
             UndirectedEdge[67, 194] -> 
             RGBColor[
              0.709877099853931, 0.7667201163798876, 0.7972498678529694], 
             UndirectedEdge[75, 260] -> 
             RGBColor[
              0.22127423884363956`, 0.34990363299468435`, 0.9359126126050195],
              UndirectedEdge[32, 387] -> 
             RGBColor[
              0.7455791435710649, 0.7496942133696903, 0.622023162461701], 
             UndirectedEdge[76, 144] -> 
             RGBColor[
              0.19222334020881804`, 0.31936929659612845`, 0.9342582069047196],
              UndirectedEdge[50, 164] -> 
             RGBColor[
              0.18999442899880858`, 0.3170265695932755, 0.9341312737086882], 
             UndirectedEdge[279, 285] -> 
             RGBColor[
              0.8332166202434534, 0.8669371947579207, 0.788972494773293], 
             UndirectedEdge[137, 352] -> 
             RGBColor[
              0.28703295098175935`, 0.4166424518178782, 0.9397445353106518], 
             UndirectedEdge[4, 275] -> 
             RGBColor[
              0.235784586016354, 0.3651549278823552, 0.9367389554103707], 
             UndirectedEdge[8, 373] -> 
             RGBColor[
              0.2548317087924608, 0.38517466157737845`, 0.937823660874777], 
             UndirectedEdge[41, 135] -> 
             RGBColor[
              0.9333566323648748, 0.9460233638065111, 0.83381543555314], 
             UndirectedEdge[85, 211] -> 
             RGBColor[
              0.231317411938528, 0.36045964469136466`, 0.9364845564552302], 
             UndirectedEdge[63, 139] -> 
             RGBColor[
              0.18462055320460163`, 0.31137828541015944`, 0.9338252394321449],
              UndirectedEdge[55, 92] -> 
             RGBColor[
              0.7345108890138425, 0.7594054710903482, 0.6489345144638174], 
             UndirectedEdge[31, 371] -> 
             RGBColor[
              0.1915120199175549, 0.31862165386969954`, 0.9342176982664363], 
             UndirectedEdge[99, 169] -> 
             RGBColor[
              0.9307128082989145, 0.9468171296861931, 0.9664871194315787], 
             UndirectedEdge[71, 72] -> 
             RGBColor[
              0.18087056047954858`, 0.30743680529285733`, 0.9336116828940703],
              UndirectedEdge[104, 112] -> 
             RGBColor[
              0.8780584972468868, 0.4677393624570944, 0.21704509236247566`], 
             UndirectedEdge[389, 390] -> 
             RGBColor[
              0.23267978688900162`, 0.3618915871438733, 0.9365621416932066], 
             UndirectedEdge[260, 349] -> 
             RGBColor[
              0.21328372600725728`, 0.3415050973758713, 0.9354575647198919], 
             UndirectedEdge[70, 284] -> 
             RGBColor[
              0.24975725951810934`, 0.3798410936513683, 0.9375346784955776], 
             UndirectedEdge[24, 172] -> 
             RGBColor[
              0.8222950385758708, 0.17237501300815056`, 0.16898306015988562`],
              UndirectedEdge[343, 362] -> 
             RGBColor[
              0.18559297832352872`, 0.3124003658654654, 0.9338806176040938], 
             UndirectedEdge[233, 307] -> 
             RGBColor[
              0.6538804302709667, 0.7226974017073509, 0.9485082265240019], 
             UndirectedEdge[79, 278] -> 
             RGBColor[
              0.24460490622546205`, 0.37442564366272924`, 0.937241259597785], 
             UndirectedEdge[1, 216] -> 
             RGBColor[
              0.19662871859939152`, 0.3239996286017438, 0.9345090866868895], 
             UndirectedEdge[192, 374] -> 
             RGBColor[
              0.18592011737534742`, 0.3127442097507407, 0.933899247689136], 
             UndirectedEdge[152, 383] -> 
             RGBColor[
              0.2325615956471479, 0.3617673606549275, 0.9365554108768314], 
             UndirectedEdge[43, 121] -> 
             RGBColor[
              0.28563299292961386`, 0.4173490407437973, 0.9395850612911336], 
             UndirectedEdge[13, 280] -> 
             RGBColor[
              0.23284937828008462`, 0.36206983844861684`, 0.9365717996720409],
              UndirectedEdge[246, 272] -> 
             RGBColor[
              0.8305893181173114, 0.8683923303180165, 0.9835339903359117], 
             UndirectedEdge[385, 387] -> 
             RGBColor[
              0.7642756795140044, 0.8115756260652711, 0.7955379877927361], 
             UndirectedEdge[90, 268] -> 
             RGBColor[
              0.6438707815800897, 0.7211954799278018, 0.9654945731092558], 
             UndirectedEdge[195, 363] -> 
             RGBColor[
              0.21087458530257291`, 0.33897293774690507`, 0.9353203677207644],
              UndirectedEdge[88, 109] -> 
             RGBColor[
              0.18639597403767888`, 0.31324436527390603`, 0.9339263470220889],
              UndirectedEdge[63, 318] -> 
             RGBColor[
              0.18778593589765713`, 0.3147053033174152, 0.9340055032937504], 
             UndirectedEdge[257, 276] -> 
             RGBColor[
              0.27298076036949565`, 0.4029229337235066, 0.9389058299544288], 
             UndirectedEdge[16, 106] -> 
             RGBColor[
              0.2722971064429795, 0.4026970623499158, 0.9388488569979281], 
             UndirectedEdge[100, 227] -> 
             RGBColor[
              0.20880854883445307`, 0.33680140242463313`, 0.9352027100003322],
              UndirectedEdge[195, 359] -> 
             RGBColor[
              0.19452611281546262`, 0.321789656609928, 0.9343893463980213], 
             UndirectedEdge[216, 313] -> 
             RGBColor[
              0.2090389311379428, 0.3370435488326826, 0.9352158299316957], 
             UndirectedEdge[12, 47] -> 
             RGBColor[
              0.4262898849714413, 0.5411626092696967, 0.9490658048705467], 
             UndirectedEdge[386, 400] -> 
             RGBColor[
              0.8054695470793142, 0.5998653041518983, 0.5862367210785956], 
             UndirectedEdge[180, 262] -> 
             RGBColor[
              0.23634740435871976`, 0.36574648564492557`, 0.9367710070823533],
              UndirectedEdge[247, 359] -> 
             RGBColor[
              0.1924159607622266, 0.31957175301060936`, 0.9342691763602797], 
             UndirectedEdge[74, 141] -> 
             RGBColor[
              0.8643287930251963, 0.6881181472098445, 0.5981821297581387], 
             UndirectedEdge[170, 171] -> 
             RGBColor[
              0.21031358554217228`, 0.3383832914292848, 0.9352884196143345], 
             UndirectedEdge[207, 333] -> 
             RGBColor[
              0.18793493502051017`, 0.3148619108426237, 0.9340139885733725], 
             UndirectedEdge[311, 313] -> 
             RGBColor[
              0.2605556138292256, 0.39119084868755866`, 0.938149628798862], 
             UndirectedEdge[161, 195] -> 
             RGBColor[
              0.20065168741435874`, 0.3282280238972294, 0.9347381888094528], 
             UndirectedEdge[87, 129] -> 
             RGBColor[
              0.1936336407966272, 0.32085161193213774`, 0.9343385214368426], 
             UndirectedEdge[198, 367] -> 
             RGBColor[
              0.36419518981338295`, 0.4898693012590379, 0.9444271733431154], 
             UndirectedEdge[322, 330] -> 
             RGBColor[
              0.19291768102176954`, 0.3200990928142907, 0.934297748586832], 
             UndirectedEdge[79, 314] -> 
             RGBColor[
              0.23185910927542647`, 0.36102900293803986`, 0.9365154053171973],
              UndirectedEdge[56, 274] -> 
             RGBColor[
              0.43736444745775693`, 0.5521652442024196, 0.9493877477928349], 
             UndirectedEdge[249, 316] -> 
             RGBColor[
              0.271715102066897, 0.4028896300992718, 0.9387862636671344], 
             UndirectedEdge[69, 294] -> 
             RGBColor[
              0.2158880199071448, 0.3442423753864234, 0.935605875404783], 
             UndirectedEdge[6, 300] -> 
             RGBColor[
              0.6101439916355338, 0.6866719134983721, 0.9662201158700239], 
             UndirectedEdge[36, 265] -> 
             RGBColor[
              0.1914303121066489, 0.318535773779863, 0.934213045127481], 
             UndirectedEdge[167, 395] -> 
             RGBColor[
              0.389446651029121, 0.5113248488468087, 0.9461511158699245], 
             UndirectedEdge[261, 306] -> 
             RGBColor[
              0.2313412040252819, 0.36048465168304844`, 0.9364859113793738], 
             UndirectedEdge[35, 211] -> 
             RGBColor[
              0.22907054143597805`, 0.35809804133336665`, 0.9363566005040571],
              UndirectedEdge[54, 63] -> 
             RGBColor[
              0.18289690010848875`, 0.3095666167202264, 0.9337270799382376], 
             UndirectedEdge[302, 314] -> 
             RGBColor[
              0.21202470254257239`, 0.3401817838877893, 0.9353858651961364], 
             UndirectedEdge[54, 224] -> 
             RGBColor[
              0.18197335735342035`, 0.3085959147286568, 0.9336744855445955], 
             UndirectedEdge[164, 389] -> 
             RGBColor[
              0.20180063292388895`, 0.3294356384750984, 0.934803619556508], 
             UndirectedEdge[113, 210] -> 
             RGBColor[
              0.3065896783902691, 0.43957556926948627`, 0.9407712006743179], 
             UndirectedEdge[307, 348] -> 
             RGBColor[
              0.3407470767330234, 0.4695597242452613, 0.9429330803119872], 
             UndirectedEdge[18, 74] -> 
             RGBColor[
              0.7341001698400949, 0.7919819236306536, 0.974429319456183], 
             UndirectedEdge[41, 328] -> 
             RGBColor[
              0.8707008812978143, 0.7005608755905404, 0.6002433163697872], 
             UndirectedEdge[63, 290] -> 
             RGBColor[
              0.18969933550436535`, 0.3167164076206075, 0.9341144685707314], 
             UndirectedEdge[45, 288] -> 
             RGBColor[
              0.29509029119202934`, 0.4274889842208769, 0.9401163275851969], 
             UndirectedEdge[249, 315] -> 
             RGBColor[
              0.2639611950336743, 0.39473978218125394`, 0.9383446901324698], 
             UndirectedEdge[306, 342] -> 
             RGBColor[
              0.1932134040418383, 0.3204099164583054, 0.934314589575342], 
             UndirectedEdge[163, 395] -> 
             RGBColor[
              0.36771682090515007`, 0.4886248797144314, 0.9449085278741232], 
             UndirectedEdge[378, 379] -> 
             RGBColor[
              0.19896021464386793`, 0.3264501787698757, 0.934641861937483], 
             UndirectedEdge[216, 235] -> 
             RGBColor[
              0.1956123156574894, 0.32293132466613605`, 0.9344512040429815], 
             UndirectedEdge[220, 321] -> 
             RGBColor[
              0.5950920301278422, 0.6821615445050555, 0.961266970987048], 
             UndirectedEdge[133, 199] -> 
             RGBColor[
              0.18613849661309062`, 0.31297374017565216`, 0.9339116840636623],
              UndirectedEdge[317, 396] -> 
             RGBColor[
              0.19745595153076353`, 0.32486910286221293`, 0.9345561963785496],
              UndirectedEdge[177, 197] -> 
             RGBColor[
              0.9295820155952076, 0.9459496447868232, 0.9675642537426303], 
             UndirectedEdge[208, 242] -> 
             RGBColor[
              0.9226443508532682, 0.6970908441139261, 0.4815544446680411], 
             UndirectedEdge[51, 163] -> 
             RGBColor[
              0.3241863421441664, 0.4513369658591039, 0.9420198625128315], 
             UndirectedEdge[188, 228] -> 
             RGBColor[
              0.20268995802939208`, 0.3303703755474506, 0.9348542653056278], 
             UndirectedEdge[95, 125] -> 
             RGBColor[
              0.41046090544111513`, 0.5226945788232695, 0.9483310159159588], 
             UndirectedEdge[66, 203] -> 
             RGBColor[
              0.2200139191384291, 0.3485789570756236, 0.9358408392622837], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.2667189772067604, 0.39766893437715617`, 0.9385006232253336], 
             UndirectedEdge[151, 265] -> 
             RGBColor[
              0.1910010224377346, 0.31808456311929695`, 0.9341885977159134], 
             UndirectedEdge[76, 333] -> 
             RGBColor[
              0.19100459551754329`, 0.3180883186527222, 0.9341888011975227], 
             UndirectedEdge[119, 336] -> 
             RGBColor[
              0.18138462902211405`, 0.30797712392492177`, 0.9336409583370731],
              UndirectedEdge[183, 395] -> 
             RGBColor[
              0.40931291362813915`, 0.5285320070026871, 0.9474169765556877], 
             UndirectedEdge[42, 204] -> 
             RGBColor[
              0.20507426806755127`, 0.33287643657154375`, 0.9349900482350304],
              UndirectedEdge[12, 107] -> 
             RGBColor[
              0.3285473986430889, 0.45896802364421685`, 0.9421566412492507], 
             UndirectedEdge[234, 239] -> 
             RGBColor[
              0.8067428279900561, 0.5234676801505931, 0.5767481319037369], 
             UndirectedEdge[164, 287] -> 
             RGBColor[
              0.19544251078166353`, 0.3227528489753921, 0.9344415339065071], 
             UndirectedEdge[32, 194] -> 
             RGBColor[
              0.9757819569708761, 0.9287169668940988, 0.4668813870087187], 
             UndirectedEdge[6, 169] -> 
             RGBColor[
              0.6006886092479335, 0.6791324482420171, 0.965318253056975], 
             UndirectedEdge[24, 240] -> 
             RGBColor[
              0.8262378872131442, 0.20268147540152273`, 0.17275873646774914`],
              UndirectedEdge[9, 381] -> 
             RGBColor[
              0.19359903145009902`, 0.3208152353145773, 0.9343365504857577], 
             UndirectedEdge[43, 90] -> 
             RGBColor[
              0.434369237561579, 0.5419666394359329, 0.9502257108546233], 
             UndirectedEdge[88, 157] -> 
             RGBColor[
              0.189431793006949, 0.31643520349264886`, 0.9340992324212971], 
             UndirectedEdge[100, 314] -> 
             RGBColor[
              0.22141089937149833`, 0.35004727187424184`, 0.93592039521991], 
             UndirectedEdge[56, 296] -> 
             RGBColor[
              0.313305483869233, 0.43989379597440015`, 0.9414004589756761], 
             UndirectedEdge[49, 235] -> 
             RGBColor[
              0.18959591922153213`, 0.31660771055037873`, 0.9341085791664148],
              UndirectedEdge[359, 362] -> 
             RGBColor[
              0.18818450229900258`, 0.31512422187579864`, 0.9340282010606809],
              UndirectedEdge[104, 285] -> 
             RGBColor[
              0.9066040807260044, 0.5685593406329343, 0.38790788619052163`], 
             UndirectedEdge[80, 168] -> 
             RGBColor[
              0.18200651498987047`, 0.3086307655068815, 0.933676373822939], 
             UndirectedEdge[311, 386] -> 
             RGBColor[
              0.5317523136158948, 0.6242823861276408, 0.958670681032904], 
             UndirectedEdge[61, 173] -> 
             RGBColor[
              0.24592220228648118`, 0.3758102053442546, 0.937316277659695], 
             UndirectedEdge[118, 354] -> 
             RGBColor[
              0.22736699671866945`, 0.3563075078245018, 0.9362595861525749], 
             UndirectedEdge[154, 180] -> 
             RGBColor[
              0.2320279298273124, 0.36120644404191316`, 0.9365250193978796], 
             UndirectedEdge[17, 158] -> 
             RGBColor[
              0.2852162427380673, 0.4143360909345327, 0.9396556083799944], 
             UndirectedEdge[8, 237] -> 
             RGBColor[
              0.2175725261235523, 0.3460128982237305, 0.9357018055418038], 
             UndirectedEdge[55, 255] -> 
             RGBColor[
              0.9034963603733146, 0.5943883495886708, 0.2628944512543936], 
             UndirectedEdge[93, 214] -> 
             RGBColor[
              0.23703264551730702`, 0.36646671754939963`, 0.9368100305526114],
              UndirectedEdge[129, 235] -> 
             RGBColor[
              0.1903011498183676, 0.3173489526218552, 0.9341487410056093], 
             UndirectedEdge[47, 158] -> 
             RGBColor[
              0.44142989596913074`, 0.5543010784500094, 0.9500295993461311], 
             UndirectedEdge[106, 347] -> 
             RGBColor[
              0.21233497992474068`, 0.3405079050891704, 0.9354035350340366], 
             UndirectedEdge[169, 178] -> 
             RGBColor[
              0.668739474081812, 0.7383666179007873, 0.9696437049697588], 
             UndirectedEdge[230, 385] -> 
             RGBColor[
              0.9060818174117249, 0.56391734784212, 0.3996140043462989], 
             UndirectedEdge[304, 383] -> 
             RGBColor[
              0.1946222087294852, 0.32189065950839857`, 0.9343948189181637], 
             UndirectedEdge[100, 352] -> 
             RGBColor[
              0.2248749641652065, 0.3536882236068225, 0.936117668585287], 
             UndirectedEdge[87, 216] -> 
             RGBColor[
              0.198944806635749, 0.32643398397641854`, 0.9346409844742148], 
             UndirectedEdge[79, 277] -> 
             RGBColor[
              0.21942962029019444`, 0.3479648219394422, 0.9358075643072694], 
             UndirectedEdge[217, 220] -> 
             RGBColor[
              0.8144460532518553, 0.851406632354037, 0.7257595325601884], 
             UndirectedEdge[78, 104] -> 
             RGBColor[
              0.819473350823259, 0.1506862844701191, 0.16628100878134408`], 
             UndirectedEdge[170, 353] -> 
             RGBColor[
              0.2108426436010009, 0.33893936499333205`, 0.9353185486881135], 
             UndirectedEdge[78, 385] -> 
             RGBColor[
              0.9071814483660026, 0.5723695932180546, 0.4006670121899707], 
             UndirectedEdge[40, 102] -> 
             RGBColor[
              0.39926565859510593`, 0.5155146756656562, 0.9472759248895897], 
             UndirectedEdge[41, 256] -> 
             RGBColor[
              0.6115898950741928, 0.6896890172445088, 0.9656235459657501], 
             UndirectedEdge[120, 217] -> 
             RGBColor[
              0.7556843813439534, 0.80370125991605, 0.7211335984965017], 
             UndirectedEdge[210, 315] -> 
             RGBColor[
              0.26224986664151034`, 0.39297161581510254`, 0.9382461139900993],
              UndirectedEdge[83, 187] -> 
             RGBColor[
              0.6899774075909928, 0.7548276258988081, 0.9634300825559947], 
             UndirectedEdge[2, 305] -> 
             RGBColor[
              0.18360947068078184`, 0.31031557357129014`, 0.9337676597781759],
              UndirectedEdge[121, 175] -> 
             RGBColor[
              0.29627876905743955`, 0.4285384264353338, 0.9401913224925988], 
             UndirectedEdge[36, 151] -> 
             RGBColor[
              0.19244860485001886`, 0.3196060640166337, 0.9342710353927868], 
             UndirectedEdge[70, 332] -> 
             RGBColor[
              0.22563024765380635`, 0.35448207444108004`, 0.936160680862621], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.1986384662361157, 0.32611200079330077`, 0.9346235388416457], 
             UndirectedEdge[221, 400] -> 
             RGBColor[
              0.8762434284382803, 0.5179931725974458, 0.21794016454172604`], 
             UndirectedEdge[49, 216] -> 
             RGBColor[
              0.19369425198474133`, 0.320915318133817, 0.9343419731543394], 
             UndirectedEdge[75, 349] -> 
             RGBColor[
              0.2099761655665867, 0.3380286416412822, 0.935269204045893], 
             UndirectedEdge[62, 87] -> 
             RGBColor[
              0.1996423811721627, 0.3271671790429695, 0.9346807103120945], 
             UndirectedEdge[38, 189] -> 
             RGBColor[
              0.24478652953490182`, 0.3746165412765333, 0.9372516027765698], 
             UndirectedEdge[49, 361] -> 
             RGBColor[
              0.2026569249479238, 0.33033565568440915`, 0.9348523841205063], 
             UndirectedEdge[107, 270] -> 
             RGBColor[
              0.35385896317997434`, 0.4809165812630355, 0.943768558122001], 
             UndirectedEdge[5, 8] -> 
             RGBColor[
              0.2601258969540067, 0.39073918900607996`, 0.9381251570585274], 
             UndirectedEdge[162, 340] -> 
             RGBColor[
              0.23763180163327896`, 0.367096468615978, 0.9368441516070439], 
             UndirectedEdge[34, 85] -> 
             RGBColor[
              0.25199669770088307`, 0.3821948851700452, 0.9376622111871347], 
             UndirectedEdge[21, 172] -> 
             RGBColor[
              0.8935026650840421, 0.5357509007293852, 0.24098742713821833`], 
             UndirectedEdge[298, 393] -> 
             RGBColor[
              0.19018046268844432`, 0.31722210279629987`, 0.9341418680521008],
              UndirectedEdge[164, 371] -> 
             RGBColor[
              0.1937500929349124, 0.3209740105129675, 0.9343451532138425], 
             UndirectedEdge[11, 85] -> 
             RGBColor[
              0.2763549775912347, 0.40749939278433556`, 0.9390602753814483], 
             UndirectedEdge[202, 307] -> 
             RGBColor[
              0.295856931076972, 0.42463269426460054`, 0.9402940731736436], 
             UndirectedEdge[20, 265] -> 
             RGBColor[
              0.19013547399899927`, 0.31717481683124543`, 0.9341393060127917],
              UndirectedEdge[195, 247] -> 
             RGBColor[
              0.1997381438211963, 0.32726783165880646`, 0.9346861638532888], 
             UndirectedEdge[281, 355] -> 
             RGBColor[
              0.5971975343016019, 0.6813125874620714, 0.9629093916561169], 
             UndirectedEdge[298, 313] -> 
             RGBColor[
              0.20768244341745035`, 0.33561779423215604`, 0.9351385799627575],
              UndirectedEdge[67, 210] -> 
             RGBColor[
              0.365438140563206, 0.4906599829992886, 0.9445168412553058], 
             UndirectedEdge[11, 263] -> 
             RGBColor[
              0.35195866140263943`, 0.47927063537545245`, 0.9436474725731201],
              UndirectedEdge[88, 181] -> 
             RGBColor[
              0.19319654196954522`, 0.3203921933512083, 0.9343136293052701], 
             UndirectedEdge[212, 390] -> 
             RGBColor[
              0.3400236714682391, 0.46467688938800766`, 0.9430428280078589], 
             UndirectedEdge[13, 203] -> 
             RGBColor[
              0.21995986800379036`, 0.3485221459060784, 0.9358377611301275], 
             UndirectedEdge[75, 105] -> 
             RGBColor[
              0.21372122175088312`, 0.34196493314125437`, 0.9354824794552745],
              UndirectedEdge[12, 270] -> 
             RGBColor[
              0.3337876806083378, 0.46350689249828564`, 0.9424905473822769], 
             UndirectedEdge[127, 393] -> 
             RGBColor[
              0.1890837058583692, 0.31606934182949153`, 0.9340794093731344], 
             UndirectedEdge[185, 208] -> 
             RGBColor[
              0.6963078073762952, 0.755957556681333, 0.8560508247348155], 
             UndirectedEdge[246, 355] -> 
             RGBColor[
              0.8429762449225704, 0.8780690916824152, 0.9847686034374477], 
             UndirectedEdge[62, 336] -> 
             RGBColor[
              0.19072954463119351`, 0.31779922273193517`, 0.9341731374564464],
              UndirectedEdge[118, 209] -> 
             RGBColor[
              0.2868618960178613, 0.41642761918472027`, 0.9397360770801573], 
             UndirectedEdge[178, 352] -> 
             RGBColor[
              0.3406463330534576, 0.4630796686814488, 0.9431607326078082], 
             UndirectedEdge[17, 22] -> 
             RGBColor[
              0.2739758563683775, 0.40460023321935323`, 0.9389393809000012], 
             UndirectedEdge[12, 158] -> 
             RGBColor[
              0.32361612706914167`, 0.45469680405977975`, 0.941842424985111], 
             UndirectedEdge[200, 333] -> 
             RGBColor[
              0.18616349406283006`, 0.3130000140802582, 0.9339131076314446], 
             UndirectedEdge[69, 295] -> 
             RGBColor[
              0.3354255676488553, 0.4587623903805083, 0.9428205754850394], 
             UndirectedEdge[181, 340] -> 
             RGBColor[
              0.19892920598511726`, 0.3264175867034662, 0.9346400960402405], 
             UndirectedEdge[205, 284] -> 
             RGBColor[
              0.313308210862673, 0.4428213204414291, 0.9412935282095445], 
             UndirectedEdge[283, 373] -> 
             RGBColor[
              0.2404157449182508, 0.3700225695206825, 0.937002693058648], 
             UndirectedEdge[302, 379] -> 
             RGBColor[
              0.199238475276043, 0.32674264833703476`, 0.9346577084688357], 
             UndirectedEdge[254, 303] -> 
             RGBColor[
              0.20024144683233963`, 0.3277968350347721, 0.9347148262152034], 
             UndirectedEdge[38, 254] -> 
             RGBColor[
              0.20508861754811766`, 0.3328915187854286, 0.9349908654167205], 
             UndirectedEdge[158, 209] -> 
             RGBColor[
              0.336799320476102, 0.4661403761955148, 0.94268153277416], 
             UndirectedEdge[365, 370] -> 
             RGBColor[
              0.18400910577117147`, 0.3107356153896179, 0.9337904184053665], 
             UndirectedEdge[61, 164] -> 
             RGBColor[
              0.2051585954739804, 0.3329650700223671, 0.9349948505560753], 
             UndirectedEdge[163, 167] -> 
             RGBColor[
              0.2885245503262027, 0.4204485142001573, 0.9397475246726753], 
             UndirectedEdge[62, 119] -> 
             RGBColor[
              0.1917608818844465, 0.31888322357566273`, 0.9342318705872924], 
             UndirectedEdge[137, 197] -> 
             RGBColor[
              0.6493874970557305, 0.7185106775296126, 0.9439140882472267], 
             UndirectedEdge[265, 383] -> 
             RGBColor[
              0.1991683094404495, 0.3266688995950551, 0.9346537126282998], 
             UndirectedEdge[19, 338] -> 
             RGBColor[
              0.24730224830049347`, 0.3772607212049526, 0.937394869238598], 
             UndirectedEdge[69, 212] -> 
             RGBColor[
              0.32957634955032006`, 0.4536960916538069, 0.9424478684800611], 
             UndirectedEdge[45, 275] -> 
             RGBColor[
              0.261779864050582, 0.3924776132921515, 0.9382193480378523], 
             UndirectedEdge[248, 360] -> 
             RGBColor[
              0.20162405229043762`, 0.3292500410334822, 0.9347935635506606], 
             UndirectedEdge[188, 322] -> 
             RGBColor[
              0.20084485470176572`, 0.3284310549638075, 0.9347491894007052], 
             UndirectedEdge[167, 183] -> 
             RGBColor[
              0.33012064304919175`, 0.46035564148841296`, 0.9422559733542398],
              UndirectedEdge[141, 240] -> 
             RGBColor[
              0.8486432291011581, 0.36358607454286945`, 0.19377114111448232`],
              UndirectedEdge[23, 220] -> 
             RGBColor[
              0.46443936234214256`, 0.5702897109178078, 0.9522369568394528], 
             UndirectedEdge[123, 322] -> 
             RGBColor[
              0.20580146810397543`, 0.3336407699169709, 0.9350314612013086], 
             UndirectedEdge[177, 398] -> 
             RGBColor[
              0.6604733814795012, 0.7312391377896288, 0.9691021762679148], 
             UndirectedEdge[272, 395] -> 
             RGBColor[
              0.6047861017850406, 0.688521596311049, 0.9630625411341533], 
             UndirectedEdge[85, 312] -> 
             RGBColor[
              0.27182714160879756`, 0.40303793904002655`, 0.9387915256311776],
              UndirectedEdge[25, 328] -> 
             RGBColor[
              0.8434248781398908, 0.3172892303900453, 0.1885318018785458], 
             UndirectedEdge[8, 121] -> 
             RGBColor[
              0.2743592219367422, 0.4054995926319236, 0.9389430367111391], 
             UndirectedEdge[169, 319] -> 
             RGBColor[
              0.6745752376290368, 0.7434200744106859, 0.9700158830654886], 
             UndirectedEdge[84, 167] -> 
             RGBColor[
              0.32454610124482625`, 0.4555272535620894, 0.9419007684798394], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.2877186940288704, 0.4160544664052851, 0.9398315069221266], 
             UndirectedEdge[43, 213] -> 
             RGBColor[
              0.2414891450614786, 0.3711507811287148, 0.9370638216088516], 
             UndirectedEdge[170, 187] -> 
             RGBColor[
              0.33329236872326556`, 0.45597611149735384`, 0.9427190170162062],
              UndirectedEdge[89, 199] -> 
             RGBColor[
              0.18786740786844439`, 0.3147909355243339, 0.9340101430019597], 
             UndirectedEdge[16, 373] -> 
             RGBColor[
              0.29481332974402036`, 0.42636304065032193`, 0.9401311226051551],
              UndirectedEdge[22, 158] -> 
             RGBColor[
              0.3275157516971413, 0.458099415524913, 0.9420899919807021], 
             UndirectedEdge[233, 264] -> 
             RGBColor[
              0.8413490098710985, 0.8765030596973409, 0.9633266229040078], 
             UndirectedEdge[274, 296] -> 
             RGBColor[
              0.36901952314668135`, 0.4870709060931353, 0.9452488023460986], 
             UndirectedEdge[97, 211] -> 
             RGBColor[
              0.20738956458852648`, 0.33530996001336677`, 0.9351219009467256],
              UndirectedEdge[1, 129] -> 
             RGBColor[
              0.19131755276026974`, 0.31841725655746295`, 0.9342066236495172],
              UndirectedEdge[24, 141] -> 
             RGBColor[
              0.8431921928460754, 0.3216870212269862, 0.1885512226405503], 
             UndirectedEdge[347, 384] -> 
             RGBColor[
              0.19370455937175246`, 0.32092615185109175`, 0.9343425601447813],
              UndirectedEdge[36, 378] -> 
             RGBColor[
              0.1918482442519195, 0.31897504696297085`, 0.934236845744879], 
             UndirectedEdge[174, 395] -> 
             RGBColor[
              0.4063176896518592, 0.5259376945387678, 0.9472261235324917], 
             UndirectedEdge[104, 357] -> 
             RGBColor[
              0.8380548061555597, 0.2935114925998279, 0.18407463139230737`], 
             UndirectedEdge[47, 173] -> 
             RGBColor[
              0.41329174036295263`, 0.5275007351562074, 0.948325579764125], 
             UndirectedEdge[127, 231] -> 
             RGBColor[
              0.1884985570631651, 0.31545431334515556`, 0.9340460860148976], 
             UndirectedEdge[252, 367] -> 
             RGBColor[
              0.372324185998124, 0.4969102291790325, 0.9449451457918181], 
             UndirectedEdge[158, 310] -> 
             RGBColor[
              0.30917761379090525`, 0.4395210111497373, 0.9410201730137817], 
             UndirectedEdge[149, 397] -> 
             RGBColor[
              0.21476341163145843`, 0.34306034078439396`, 0.9355418306271915],
              UndirectedEdge[204, 345] -> 
             RGBColor[
              0.18631088399028722`, 0.3131549302390768, 0.9339215012697695], 
             UndirectedEdge[231, 396] -> 
             RGBColor[
              0.19087540782908663`, 0.31795253420118175`, 0.9341814441497811],
              UndirectedEdge[162, 263] -> 
             RGBColor[
              0.33214075614847005`, 0.45873834938016844`, 0.9425079759974546],
              UndirectedEdge[14, 196] -> 
             RGBColor[
              0.18714224683050756`, 0.3140287452955969, 0.9339688461536289], 
             UndirectedEdge[43, 175] -> 
             RGBColor[
              0.2710055822533935, 0.4021744280676252, 0.9387447390412754], 
             UndirectedEdge[113, 397] -> 
             RGBColor[
              0.2602244815922864, 0.3908428077115391, 0.9381307713078346], 
             UndirectedEdge[126, 336] -> 
             RGBColor[
              0.18346975723563688`, 0.31016872588209876`, 0.9337597033041625],
              UndirectedEdge[48, 173] -> 
             RGBColor[
              0.2613339339978391, 0.3920089125331203, 0.938193952981043], 
             UndirectedEdge[28, 168] -> 
             RGBColor[
              0.19559687276408316`, 0.32291509320603007`, 0.9344503245930478],
              UndirectedEdge[253, 359] -> 
             RGBColor[
              0.18914843365842357`, 0.3161373748513282, 0.9340830955255912], 
             UndirectedEdge[41, 187] -> 
             RGBColor[
              0.6533956652271913, 0.7258990741319324, 0.9682873726725081], 
             UndirectedEdge[198, 398] -> 
             RGBColor[
              0.38970123207440616`, 0.5119613530945772, 0.9460523958018803], 
             UndirectedEdge[260, 329] -> 
             RGBColor[
              0.20751257412950358`, 0.3354392508401891, 0.9351289061581081], 
             UndirectedEdge[60, 82] -> 
             RGBColor[
              0.18336573314646784`, 0.31005938996887394`, 0.9337537792861741],
              UndirectedEdge[12, 17] -> 
             RGBColor[0.2700762317403779, 0.40119762175422, 0.93869181390441],
              UndirectedEdge[268, 351] -> 
             RGBColor[
              0.7945761589543001, 0.8401740652758038, 0.979966961918109], 
             UndirectedEdge[122, 274] -> 
             RGBColor[
              0.5455206538470523, 0.6419172680752578, 0.9573645306602898], 
             UndirectedEdge[150, 384] -> 
             RGBColor[
              0.19155187583051508`, 0.31866354496123156`, 0.9342199680017178],
              UndirectedEdge[179, 232] -> 
             RGBColor[
              0.374520452238133, 0.49753308772821003`, 0.9451360369712756], 
             UndirectedEdge[4, 131] -> 
             RGBColor[
              0.22303764420255517`, 0.35175708383326204`, 0.9360130359314853],
              UndirectedEdge[128, 155] -> 
             RGBColor[
              0.2008465417565683, 0.32843282816537045`, 0.9347492854759805], 
             UndirectedEdge[316, 362] -> 
             RGBColor[
              0.2117594365618467, 0.339902972523212, 0.9353707586909601], 
             UndirectedEdge[283, 320] -> 
             RGBColor[
              0.20238649627655553`, 0.330051418004633, 0.9348369836077353], 
             UndirectedEdge[49, 396] -> 
             RGBColor[
              0.1936178582000953, 0.3208350234225083, 0.9343376226413184], 
             UndirectedEdge[371, 389] -> 
             RGBColor[
              0.194598112629328, 0.3218653329793524, 0.9343934466809067], 
             UndirectedEdge[53, 58] -> 
             RGBColor[
              0.20217788494718347`, 0.3298321542707407, 0.9348251035011402], 
             UndirectedEdge[18, 399] -> 
             RGBColor[
              0.7658581753592988, 0.7184623790314186, 0.610918793426945], 
             UndirectedEdge[241, 270] -> 
             RGBColor[
              0.31115624108701556`, 0.43971981464523346`, 0.9412017203817521],
              UndirectedEdge[137, 169] -> 
             RGBColor[
              0.6151260920101136, 0.6919294010372166, 0.9662275076726026], 
             UndirectedEdge[156, 386] -> 
             RGBColor[
              0.795873240259372, 0.5261038848053603, 0.5770472868303405], 
             UndirectedEdge[19, 262] -> 
             RGBColor[
              0.23727783738368446`, 0.36672442974702457`, 0.9368239938666727],
              UndirectedEdge[85, 181] -> 
             RGBColor[
              0.2178344766889036, 0.34628822487653976`, 0.9357167232389794], 
             UndirectedEdge[74, 240] -> 
             RGBColor[
              0.8473744873922651, 0.569112601384381, 0.5823896435853375], 
             UndirectedEdge[72, 88] -> 
             RGBColor[
              0.18714176336881175`, 0.31402823714670136`, 0.9339688186212005],
              UndirectedEdge[63, 98] -> 
             RGBColor[
              0.19109841618892076`, 0.3181869301269141, 0.9341941441459625], 
             UndirectedEdge[43, 56] -> 
             RGBColor[
              0.3210051071529382, 0.44798658822988663`, 0.9418389411311112], 
             UndirectedEdge[174, 272] -> 
             RGBColor[
              0.5424648698288314, 0.6349580764887339, 0.9589765455952728], 
             UndirectedEdge[180, 198] -> 
             RGBColor[
              0.30592577418738304`, 0.43475768207038135`, 0.9408842486890967],
              UndirectedEdge[126, 289] -> 
             RGBColor[
              0.1863769520635358, 0.31322437197301883`, 0.933925263748802], 
             UndirectedEdge[233, 244] -> 
             RGBColor[
              0.9570858882964418, 0.9675153062736708, 0.9575265767079428], 
             UndirectedEdge[51, 189] -> 
             RGBColor[
              0.324110599148695, 0.45125735516848015`, 0.9420155490612911], 
             UndirectedEdge[199, 306] -> 
             RGBColor[
              0.19460108481424115`, 0.32186845693414357`, 0.9343936159424405],
              UndirectedEdge[86, 214] -> 
             RGBColor[
              0.32538385594789154`, 0.4498732658782442, 0.9421877381945456], 
             UndirectedEdge[104, 172] -> 
             RGBColor[
              0.8214061746435448, 0.16554281532163417`, 0.16813188305446203`],
              UndirectedEdge[67, 293] -> 
             RGBColor[
              0.3870584168095417, 0.509672279343909, 0.9458839979501529], 
             UndirectedEdge[296, 380] -> 
             RGBColor[
              0.23254239925943204`, 0.3617471840343169, 0.9365543176709494], 
             UndirectedEdge[290, 297] -> 
             RGBColor[
              0.20256888353236238`, 0.33024311857450594`, 0.9348473702921356],
              UndirectedEdge[206, 328] -> 
             RGBColor[
              0.7999219852902167, 0.6448484807342735, 0.5933000289298582], 
             UndirectedEdge[5, 319] -> 
             RGBColor[
              0.3679006517731242, 0.4906453846924169, 0.9447526657346955], 
             UndirectedEdge[235, 393] -> 
             RGBColor[
              0.18743861764572758`, 0.31434024981338815`, 0.9339857240331143],
              UndirectedEdge[40, 189] -> 
             RGBColor[
              0.3938515783304093, 0.5098241340349448, 0.9469676010279292], 
             UndirectedEdge[15, 256] -> 
             RGBColor[
              0.31856719551894513`, 0.448229479012007, 0.9415973902435224], 
             UndirectedEdge[71, 365] -> 
             RGBColor[
              0.17992874679989868`, 0.30644689940110903`, 0.9335580479983027],
              UndirectedEdge[53, 64] -> 
             RGBColor[
              0.18652020523185484`, 0.31337494013569756`, 0.9339334218048136],
              UndirectedEdge[231, 298] -> 
             RGBColor[
              0.1895953138932402, 0.3166070743119639, 0.934108544693864], 
             UndirectedEdge[81, 382] -> 
             RGBColor[
              0.18072466475425025`, 0.3072834596352455, 0.9336033743483478], 
             UndirectedEdge[9, 294] -> 
             RGBColor[
              0.1904972038981096, 0.3175550178902107, 0.9341599059954147], 
             UndirectedEdge[175, 213] -> 
             RGBColor[
              0.25213492118930436`, 0.3823401668202513, 0.9376700828103168], 
             UndirectedEdge[174, 189] -> 
             RGBColor[
              0.3053198459534695, 0.4349817492014926, 0.9408182188837021], 
             UndirectedEdge[14, 127] -> 
             RGBColor[
              0.18967658911817914`, 0.3166924997265216, 0.9341131731976884], 
             UndirectedEdge[86, 95] -> 
             RGBColor[
              0.48521628550800544`, 0.5918110474144382, 0.9529344611319093], 
             UndirectedEdge[103, 200] -> 
             RGBColor[
              0.18928086975494526`, 0.31627657358570604`, 0.9340906375653665],
              UndirectedEdge[24, 112] -> 
             RGBColor[
              0.8789473611792127, 0.4745715601436108, 0.21789626946789925`], 
             UndirectedEdge[109, 360] -> 
             RGBColor[
              0.18328589355082267`, 0.3099754734917281, 0.9337492325393142], 
             UndirectedEdge[90, 121] -> 
             RGBColor[
              0.4596424243656251, 0.5683306378036415, 0.9516722943059467], 
             UndirectedEdge[75, 202] -> 
             RGBColor[
              0.23066301686818202`, 0.3597718339813871, 0.9364472896240648], 
             UndirectedEdge[27, 32] -> 
             RGBColor[
              0.8890352414528142, 0.5147182506008601, 0.2276791825593331], 
             UndirectedEdge[131, 273] -> 
             RGBColor[
              0.19754073794696791`, 0.32495821876141306`, 0.9345610248395222],
              UndirectedEdge[160, 220] -> 
             RGBColor[
              0.5477229997143326, 0.6437052316648666, 0.9575379073944208], 
             UndirectedEdge[50, 147] -> 
             RGBColor[
              0.18125622821196816`, 0.30784216653237684`, 0.9336336461008872],
              UndirectedEdge[13, 339] -> 
             RGBColor[
              0.2328552355524508, 0.3620759948132462, 0.936572133235037], 
             UndirectedEdge[17, 209] -> 
             RGBColor[
              0.2832594251473382, 0.412641193889955, 0.9395309216934591], 
             UndirectedEdge[174, 325] -> 
             RGBColor[
              0.31656779052141654`, 0.4468040521032807, 0.9414587726870038], 
             UndirectedEdge[21, 78] -> 
             RGBColor[
              0.8915698412637564, 0.5208943698778701, 0.23913655286510038`], 
             UndirectedEdge[274, 373] -> 
             RGBColor[
              0.38246482009015115`, 0.5012027656617852, 0.9460144921164949], 
             UndirectedEdge[97, 305] -> 
             RGBColor[
              0.18756138502713113`, 0.3144692861151448, 0.9339927154538672], 
             UndirectedEdge[11, 162] -> 
             RGBColor[
              0.29214677471105677`, 0.42409757281503596`, 0.9399595948655519],
              UndirectedEdge[103, 207] -> 
             RGBColor[
              0.19105231071262538`, 0.3181384703480716, 0.9341915185072943], 
             UndirectedEdge[210, 249] -> 
             RGBColor[
              0.3073650774594488, 0.4403600145758346, 0.9408164770263279], 
             UndirectedEdge[52, 299] -> 
             RGBColor[
              0.18351379325327066`, 0.3102150105286766, 0.9337622110902213], 
             UndirectedEdge[43, 373] -> 
             RGBColor[
              0.2661054797853324, 0.3970241096892522, 0.9384656854547713], 
             UndirectedEdge[1, 336] -> 
             RGBColor[
              0.18695004027347276`, 0.31382672401755374`, 0.9339579002745498],
              UndirectedEdge[30, 345] -> 
             RGBColor[
              0.1795989351746539, 0.30610024647171197`, 0.9335392657141575], 
             UndirectedEdge[247, 363] -> 
             RGBColor[
              0.20876443324933688`, 0.3367550341475864, 0.9352001976830229], 
             UndirectedEdge[14, 119] -> 
             RGBColor[
              0.18348249259608096`, 0.310182111553394, 0.9337604285640995], 
             UndirectedEdge[74, 104] -> 
             RGBColor[
              0.8410345872048564, 0.5203813503819814, 0.5763185480059819], 
             UndirectedEdge[258, 277] -> 
             RGBColor[
              0.19561158896014919`, 0.3229305608611562, 0.9344511626586431], 
             UndirectedEdge[152, 236] -> 
             RGBColor[
              0.2537723278978401, 0.38406118508850384`, 0.9377633307000419], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.26676233186552467`, 0.3975147794964234, 0.938510405060175], 
             UndirectedEdge[120, 132] -> 
             RGBColor[
              0.4382862950940797, 0.5522789014915227, 0.9496356996104882], 
             UndirectedEdge[212, 270] -> 
             RGBColor[
              0.38821783346100136`, 0.5106765077734281, 0.9459578749539519], 
             UndirectedEdge[69, 270] -> 
             RGBColor[
              0.300457761234542, 0.4284750339974831, 0.9405924577811364], 
             UndirectedEdge[16, 270] -> 
             RGBColor[
              0.3384373755940835, 0.46755917720766627`, 0.9427859081978025], 
             UndirectedEdge[24, 73] -> 
             RGBColor[
              0.8757010840349191, 0.46170115302421727`, 0.21528423867768243`],
              UndirectedEdge[56, 178] -> 
             RGBColor[
              0.4116703274319593, 0.5309898792944511, 0.9474522471315552], 
             UndirectedEdge[6, 319] -> 
             RGBColor[
              0.37947514539695637`, 0.5028109113563464, 0.945411816023644], 
             UndirectedEdge[231, 235] -> 
             RGBColor[
              0.18685346885052345`, 0.3137252213290522, 0.9339524006748775], 
             UndirectedEdge[18, 86] -> 
             RGBColor[
              0.5080814719938581, 0.6103740358685661, 0.9547344923700136], 
             UndirectedEdge[30, 63] -> 
             RGBColor[
              0.18069605079375822`, 0.30725338454853857`, 0.9336017448256284],
              UndirectedEdge[46, 358] -> 
             RGBColor[
              0.19603463800818394`, 0.3233752122334996, 0.9344752546760837], 
             UndirectedEdge[241, 389] -> 
             RGBColor[
              0.23293094482355622`, 0.362155570057423, 0.9365764447660246], 
             UndirectedEdge[286, 332] -> 
             RGBColor[
              0.2115950206250406, 0.3397301609490563, 0.9353613954465905], 
             UndirectedEdge[40, 174] -> 
             RGBColor[
              0.4325281900725898, 0.5472165595499049, 0.9492895101378381], 
             UndirectedEdge[157, 365] -> 
             RGBColor[
              0.18416233691758455`, 0.3108966710399138, 0.9337991446924696], 
             UndirectedEdge[235, 336] -> 
             RGBColor[
              0.18593363733157064`, 0.312758420081946, 0.9339000176306419], 
             UndirectedEdge[76, 222] -> 
             RGBColor[
              0.21314128516619657`, 0.3413553830206456, 0.9354494529247159], 
             UndirectedEdge[115, 392] -> 
             RGBColor[
              0.9278459781809479, 0.7343397761790258, 0.5030820645906373], 
             UndirectedEdge[76, 77] -> 
             RGBColor[
              0.1883529029244576, 0.3153012216103682, 0.9340377912271741], 
             UndirectedEdge[160, 366] -> 
             RGBColor[
              0.4270114418839008, 0.5441063729670104, 0.948477074824805], 
             UndirectedEdge[3, 348] -> 
             RGBColor[
              0.45750426505624076`, 0.5671984745069012, 0.9513371690188597], 
             UndirectedEdge[299, 306] -> 
             RGBColor[
              0.19518727715711093`, 0.32248458225324084`, 0.9344269987291731],
              UndirectedEdge[56, 121] -> 
             RGBColor[
              0.3462782939569843, 0.4743505865975952, 0.9432855245824346], 
             UndirectedEdge[280, 322] -> 
             RGBColor[
              0.22572058379982396`, 0.354577023458187, 0.9361658253724963], 
             UndirectedEdge[81, 271] -> 
             RGBColor[
              0.1793288256722832, 0.3058163442587888, 0.9335238833775887], 
             UndirectedEdge[2, 191] -> 
             RGBColor[
              0.19610476461646903`, 0.323448919745091, 0.9344792482826825], 
             UndirectedEdge[146, 377] -> 
             RGBColor[
              0.18543930213235216`, 0.3122388424449055, 0.9338718659723498], 
             UndirectedEdge[10, 396] -> 
             RGBColor[
              0.21852942039278686`, 0.3470186547712968, 0.9357562992548385], 
             UndirectedEdge[382, 384] -> 
             RGBColor[
              0.18572468011707222`, 0.3125387928008556, 0.9338881178264007], 
             UndirectedEdge[147, 391] -> 
             RGBColor[
              0.18230154859335337`, 0.30894086453035285`, 0.9336931755501943],
              UndirectedEdge[133, 216] -> 
             RGBColor[
              0.19274891912622777`, 0.3199217133619542, 0.9342881378465417], 
             UndirectedEdge[86, 264] -> 
             RGBColor[
              0.5671571608223211, 0.6570945561668415, 0.9602327949234224], 
             UndirectedEdge[6, 56] -> 
             RGBColor[
              0.34361946259808085`, 0.47175570963568103`, 0.9431267952187714],
              UndirectedEdge[43, 308] -> 
             RGBColor[
              0.23093015114267265`, 0.3600526090411681, 0.9364625025258073], 
             UndirectedEdge[201, 364] -> 
             RGBColor[
              0.8833604425346897, 0.5491985864535379, 0.5678503651913112], 
             UndirectedEdge[109, 365] -> 
             RGBColor[
              0.1811265179483144, 0.30770583282117103`, 0.9336262592932614], 
             UndirectedEdge[229, 349] -> 
             RGBColor[
              0.20443433824615148`, 0.33220382975535845`, 0.934953605178393], 
             UndirectedEdge[216, 231] -> 
             RGBColor[
              0.19095180161373265`, 0.3180328289124904, 0.9341857946628023], 
             UndirectedEdge[114, 353] -> 
             RGBColor[
              0.2156557406567855, 0.3439982351669406, 0.9355926474451014], 
             UndirectedEdge[70, 236] -> 
             RGBColor[
              0.23684558512377027`, 0.36627010521547854`, 0.9367993777399305],
              UndirectedEdge[64, 94] -> 
             RGBColor[
              0.1809149928406964, 0.30748350652159806`, 0.9336142132513059], 
             UndirectedEdge[240, 285] -> 
             RGBColor[
              0.912943980913413, 0.617290591635334, 0.3939789817698772], 
             UndirectedEdge[56, 90] -> 
             RGBColor[
              0.4950145385889495, 0.5989681852897308, 0.9539261741459244], 
             UndirectedEdge[90, 295] -> 
             RGBColor[
              0.5187067634857201, 0.6194891996894659, 0.9554358217661347], 
             UndirectedEdge[165, 281] -> 
             RGBColor[
              0.6627187385434833, 0.7331187175098175, 0.9692752800168635], 
             UndirectedEdge[54, 345] -> 
             RGBColor[
              0.1817997844893844, 0.30841347864339985`, 0.9336646008267666], 
             UndirectedEdge[101, 136] -> 
             RGBColor[
              0.18384486237801373`, 0.31056298516977654`, 0.9337810649871026],
              UndirectedEdge[6, 314] -> 
             RGBColor[
              0.26913140342587094`, 0.400204547290098, 0.9386380073296472], 
             UndirectedEdge[125, 276] -> 
             RGBColor[
              0.2421845103154749, 0.3718816540993685, 0.9371034216313661], 
             UndirectedEdge[244, 341] -> 
             RGBColor[
              0.6455002366075493, 0.7157181703634723, 0.9520500486891706], 
             UndirectedEdge[46, 153] -> 
             RGBColor[
              0.1918690303202028, 0.3189968944386494, 0.9342380294807175], 
             UndirectedEdge[14, 336] -> 
             RGBColor[
              0.18245115534282794`, 0.3090981107096664, 0.9337016954332534], 
             UndirectedEdge[109, 370] -> 
             RGBColor[
              0.1842051301196885, 0.31094164940857083`, 0.9338015817020224], 
             UndirectedEdge[51, 234] -> 
             RGBColor[
              0.5836503518814267, 0.668728614845342, 0.9624059730547245], 
             UndirectedEdge[144, 228] -> 
             RGBColor[
              0.19707272190642572`, 0.32446630422887235`, 0.934534372018381], 
             UndirectedEdge[320, 347] -> 
             RGBColor[
              0.1968219545840863, 0.324202731873527, 0.9345200911903508], 
             UndirectedEdge[31, 106] -> 
             RGBColor[
              0.21164758701888683`, 0.33978541156189057`, 0.935364389024955], 
             UndirectedEdge[77, 103] -> 
             RGBColor[
              0.18857832587467818`, 0.31553815542369057`, 0.9340506287307058],
              UndirectedEdge[266, 316] -> 
             RGBColor[
              0.23355306875092818`, 0.36280946175002615`, 0.9366118738033387],
              UndirectedEdge[109, 334] -> 
             RGBColor[
              0.18315174728548578`, 0.30983447726149455`, 0.9337415931079549],
              UndirectedEdge[45, 179] -> 
             RGBColor[
              0.3693787364367489, 0.49212881841734446`, 0.9448432238628737], 
             UndirectedEdge[181, 191] -> 
             RGBColor[
              0.2010737277844803, 0.3286716150851321, 0.9347622233841785], 
             UndirectedEdge[125, 148] -> 
             RGBColor[
              0.2977450564931756, 0.4279464199660071, 0.9403529311058223], 
             UndirectedEdge[18, 112] -> 
             RGBColor[
              0.7711240798821252, 0.7393399357057666, 0.6151558638126768], 
             UndirectedEdge[221, 239] -> 
             RGBColor[
              0.8650356462249088, 0.43184524722399015`, 0.20720757963682196`],
              UndirectedEdge[57, 76] -> 
             RGBColor[
              0.20578868678679324`, 0.33362733594223004`, 0.9350307333242034],
              UndirectedEdge[222, 333] -> 
             RGBColor[
              0.21024933242430197`, 0.33831575732852015`, 0.9352847604943257],
              UndirectedEdge[125, 214] -> 
             RGBColor[
              0.25062847588100123`, 0.38075679728707557`, 0.9375842929785951],
              UndirectedEdge[220, 244] -> 
             RGBColor[
              0.7952939705328516, 0.8405065482820335, 0.9629639718031929], 
             UndirectedEdge[143, 379] -> 
             RGBColor[
              0.19607245739300067`, 0.3234149628048294, 0.9344774084341002], 
             UndirectedEdge[31, 241] -> 
             RGBColor[
              0.22984485211178313`, 0.3589118909477702, 0.9364006963515542], 
             UndirectedEdge[81, 374] -> 
             RGBColor[
              0.1848884604275577, 0.3116598728877852, 0.9338404963521592], 
             UndirectedEdge[168, 304] -> 
             RGBColor[
              0.18254777981600245`, 0.3091996691573183, 0.9337071980540577], 
             UndirectedEdge[156, 328] -> 
             RGBColor[
              0.850258311685, 0.36981399504742796`, 0.1950755055586017], 
             UndirectedEdge[46, 363] -> 
             RGBColor[
              0.21059715829347625`, 0.33868134437045616`, 0.9353045686630128],
              UndirectedEdge[51, 269] -> 
             RGBColor[
              0.5625797337470475, 0.652268087816136, 0.9603058507552114], 
             UndirectedEdge[13, 325] -> 
             RGBColor[
              0.25165090865355244`, 0.3818314389570088, 0.9376425190124382], 
             UndirectedEdge[164, 374] -> 
             RGBColor[
              0.1955858495365969, 0.322903507095029, 0.9344496968365499], 
             UndirectedEdge[49, 199] -> 
             RGBColor[
              0.18708382947160418`, 0.313967344947515, 0.93396551937146], 
             UndirectedEdge[49, 313] -> 
             RGBColor[
              0.20302253470198556`, 0.3307199347169253, 0.9348732050551289], 
             UndirectedEdge[176, 388] -> 
             RGBColor[
              0.22659156217478169`, 0.35549247695348607`, 0.9362154263024531],
              UndirectedEdge[45, 232] -> 
             RGBColor[
              0.28995111396047296`, 0.4220873831078549, 0.9398236590445912], 
             UndirectedEdge[176, 250] -> 
             RGBColor[
              0.24600820440775967`, 0.3759005990265677, 0.9373211753532731], 
             UndirectedEdge[346, 390] -> 
             RGBColor[
              0.30688867117659013`, 0.43597701754892004`, 0.9409314950894052],
              UndirectedEdge[331, 335] -> 
             RGBColor[
              0.18932527309814626`, 0.31632324431474484`, 0.9340931662700729],
              UndirectedEdge[135, 355] -> 
             RGBColor[
              0.8802746969932166, 0.9041359691009224, 0.8286360157619015], 
             UndirectedEdge[326, 327] -> 
             RGBColor[
              0.19380937140054372`, 0.3210363159388178, 0.9343485290347655], 
             UndirectedEdge[80, 304] -> 
             RGBColor[
              0.18034926344630414`, 0.30688888905877654`, 0.9335819957992169],
              UndirectedEdge[65, 173] -> 
             RGBColor[
              0.2852130264023293, 0.4171073526721437, 0.9395538319675272], 
             UndirectedEdge[203, 257] -> 
             RGBColor[
              0.27443071882287484`, 0.40444693199068393`, 0.9389884029433275],
              UndirectedEdge[275, 325] -> 
             RGBColor[
              0.2639447266446291, 0.3947530211387112, 0.9383426337599561], 
             UndirectedEdge[240, 337] -> 
             RGBColor[
              0.9128678714659045, 0.6171278012229586, 0.3856949381016387], 
             UndirectedEdge[77, 254] -> 
             RGBColor[
              0.18502833391359902`, 0.3118068887901059, 0.9338484619402648], 
             UndirectedEdge[32, 364] -> 
             RGBColor[
              0.8873546832703587, 0.5018007439852152, 0.22606987814589463`], 
             UndirectedEdge[38, 53] -> 
             RGBColor[
              0.2076634431002256, 0.3355978236940631, 0.9351374979228], 
             UndirectedEdge[28, 291] -> 
             RGBColor[
              0.1970819328198578, 0.3244759854828951, 0.9345348965662746], 
             UndirectedEdge[174, 269] -> 
             RGBColor[
              0.543788980551822, 0.6359924818491485, 0.9591085205776222], 
             UndirectedEdge[216, 361] -> 
             RGBColor[
              0.20867332138388106`, 0.3366592698001664, 0.9351950089970731], 
             UndirectedEdge[356, 363] -> 
             RGBColor[
              0.2074463229173425, 0.3353696166156383, 0.9351251332495853], 
             UndirectedEdge[151, 383] -> 
             RGBColor[
              0.20018660218381945`, 0.3277391898318258, 0.9347117028936056], 
             UndirectedEdge[61, 130] -> 
             RGBColor[
              0.19568837198846437`, 0.3230112646922406, 0.9344555353385153], 
             UndirectedEdge[331, 338] -> 
             RGBColor[
              0.2166739251358942, 0.34506841161110846`, 0.9356506315449178], 
             UndirectedEdge[239, 246] -> 
             RGBColor[
              0.874004135287985, 0.576823099817974, 0.5832370617608514], 
             UndirectedEdge[190, 212] -> 
             RGBColor[
              0.6867778683351773, 0.7513832913392242, 0.9534033725466657], 
             UndirectedEdge[111, 286] -> 
             RGBColor[
              0.1920478961746871, 0.3191848937924626, 0.934248215626522], 
             UndirectedEdge[228, 273] -> 
             RGBColor[
              0.1927101706170558, 0.31988098622201705`, 0.9342859311762677], 
             UndirectedEdge[199, 299] -> 
             RGBColor[
              0.18707599573729403`, 0.31395911119606756`, 0.93396507325188], 
             UndirectedEdge[50, 391] -> 
             RGBColor[
              0.18008156514952903`, 0.3066075211758136, 0.9335667507772396], 
             UndirectedEdge[358, 362] -> 
             RGBColor[
              0.18997045450082056`, 0.31700137087581914`, 0.9341299083964949],
              UndirectedEdge[42, 98] -> 
             RGBColor[
              0.20876468464708048`, 0.33675529838255447`, 0.9352002119997525],
              UndirectedEdge[39, 251] -> 
             RGBColor[
              0.18672478342346222`, 0.3135899647860835, 0.9339450722301794], 
             UndirectedEdge[148, 179] -> 
             RGBColor[
              0.39396314610535543`, 0.515635700812435, 0.9463286881882242], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.19127206346984504`, 0.31836944442903903`, 0.934204033101723], 
             UndirectedEdge[77, 333] -> 
             RGBColor[
              0.18546095018256298`, 0.31226159591824276`, 0.9338730987967839],
              UndirectedEdge[173, 354] -> 
             RGBColor[
              0.24916626557073213`, 0.3792199215414943, 0.9375010222645717], 
             UndirectedEdge[160, 217] -> 
             RGBColor[
              0.7263465347719837, 0.7798834744139984, 0.7188240157462833], 
             UndirectedEdge[59, 90] -> 
             RGBColor[
              0.47744540309430256`, 0.5837506831746934, 0.9528066843679821], 
             UndirectedEdge[237, 380] -> 
             RGBColor[
              0.20872851353399335`, 0.33671728024931885`, 0.9351981521083725],
              UndirectedEdge[285, 399] -> 
             RGBColor[
              0.9603875503566552, 0.868303119703074, 0.4348794443842956], 
             UndirectedEdge[51, 392] -> 
             RGBColor[
              0.6863309387769014, 0.7477531849917098, 0.8714804732443268], 
             UndirectedEdge[264, 307] -> 
             RGBColor[
              0.5358230864206805, 0.6299545558165122, 0.958236215410184], 
             UndirectedEdge[78, 208] -> 
             RGBColor[
              0.9064764270189856, 0.5728170966942296, 0.4660720225452738], 
             UndirectedEdge[28, 383] -> 
             RGBColor[
              0.20767130167756592`, 0.3356060835571104, 0.9351379454571538], 
             UndirectedEdge[255, 268] -> 
             RGBColor[
              0.7573621449450872, 0.5111257415751345, 0.5750858104368912], 
             UndirectedEdge[46, 247] -> 
             RGBColor[
              0.1994607168120997, 0.32697623828235756`, 0.9346703647955372], 
             UndirectedEdge[272, 392] -> 
             RGBColor[
              0.8660085977148573, 0.8940614807970035, 0.8861195606683994], 
             UndirectedEdge[316, 359] -> 
             RGBColor[
              0.21077886401933704`, 0.3388723286091443, 0.9353149165352912], 
             UndirectedEdge[223, 242] -> 
             RGBColor[
              0.8910877878932282, 0.5812972246774919, 0.23007311301914762`], 
             UndirectedEdge[158, 390] -> 
             RGBColor[
              0.3007335296132649, 0.43064574329317795`, 0.9405392949117681], 
             UndirectedEdge[26, 128] -> 
             RGBColor[
              0.19080558249119994`, 0.3178791433438807, 0.9341774677000858], 
             UndirectedEdge[136, 335] -> 
             RGBColor[
              0.18204623503960604`, 0.3086725137975501, 0.9336786358210108], 
             UndirectedEdge[193, 248] -> 
             RGBColor[
              0.20247189401375032`, 0.330141176440954, 0.9348418468825339], 
             UndirectedEdge[281, 386] -> 
             RGBColor[
              0.5947242732295994, 0.6793804571151425, 0.9626628801063983], 
             UndirectedEdge[225, 337] -> 
             RGBColor[
              0.9393785469822551, 0.9502915240338172, 0.7911384355526612], 
             UndirectedEdge[30, 297] -> 
             RGBColor[
              0.19356559882175525`, 0.3207800955024369, 0.9343346465470327], 
             UndirectedEdge[32, 104] -> 
             RGBColor[
              0.8880206846932135, 0.5069199227649615, 0.22670764186056142`], 
             UndirectedEdge[264, 366] -> 
             RGBColor[
              0.5588455342770764, 0.6498954430078475, 0.9597031854296422], 
             UndirectedEdge[2, 97] -> 
             RGBColor[
              0.18893766617089083`, 0.31591584485850077`, 0.9340710926289788],
              UndirectedEdge[258, 377] -> 
             RGBColor[
              0.18407204095648846`, 0.3108017642597073, 0.933794002471066], 
             UndirectedEdge[134, 135] -> 
             RGBColor[
              0.9129052217970873, 0.9297159641585085, 0.8318647617559947], 
             UndirectedEdge[185, 338] -> 
             RGBColor[
              0.3169003211264983, 0.4420126040845884, 0.9416659454971446], 
             UndirectedEdge[40, 84] -> 
             RGBColor[
              0.42994887224450423`, 0.5449824840875006, 0.9491251582866337], 
             UndirectedEdge[217, 242] -> 
             RGBColor[
              0.9226715072655902, 0.6951934560850966, 0.34236801946865186`], 
             UndirectedEdge[124, 266] -> 
             RGBColor[
              0.27124098687969256`, 0.402330909521441, 0.9387614748820916], 
             UndirectedEdge[219, 293] -> 
             RGBColor[
              0.34300984476630975`, 0.47151962018566573`, 0.943077261890181], 
             UndirectedEdge[37, 170] -> 
             RGBColor[
              0.29023151793817503`, 0.41867896684859873`, 0.9399752176813956],
              UndirectedEdge[205, 293] -> 
             RGBColor[
              0.3494560104043527, 0.47710296486763304`, 0.9434880058645166], 
             UndirectedEdge[122, 268] -> 
             RGBColor[
              0.638662857560744, 0.7169674525945936, 0.9650845862531987], 
             UndirectedEdge[246, 392] -> 
             RGBColor[
              0.955664633870156, 0.964911832854005, 0.8948405878073766], 
             UndirectedEdge[282, 398] -> 
             RGBColor[
              0.3466184248527956, 0.47079867288483046`, 0.9434480372889362], 
             UndirectedEdge[34, 248] -> 
             RGBColor[
              0.24062348998029212`, 0.37024092275268566`, 0.9370145238326], 
             UndirectedEdge[263, 264] -> 
             RGBColor[
              0.5576221544304325, 0.6488358128735436, 0.9596252327476064], 
             UndirectedEdge[100, 377] -> 
             RGBColor[
              0.19744186238260558`, 0.3248542942741953, 0.9345553940224051], 
             UndirectedEdge[107, 241] -> 
             RGBColor[
              0.30591595912176667`, 0.43518094579116473`, 0.9408678142487259],
              UndirectedEdge[11, 95] -> 
             RGBColor[
              0.43568729767870357`, 0.5489115275560077, 0.9497785178241904], 
             UndirectedEdge[7, 96] -> 
             RGBColor[
              0.5984222253415448, 0.6831169372542267, 0.9626727079088397], 
             UndirectedEdge[111, 383] -> 
             RGBColor[
              0.1988021595169091, 0.3262840528101681, 0.9346328609318244], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.2782593236768137, 0.4070163756656283, 0.939259698655848], 
             UndirectedEdge[121, 122] -> 
             RGBColor[
              0.4544345003462795, 0.5641026104704333, 0.9512623074498896], 
             UndirectedEdge[156, 221] -> 
             RGBColor[
              0.866647121618338, 0.4442317532509077, 0.20875073029347097`], 
             UndirectedEdge[61, 176] -> 
             RGBColor[
              0.2215167477526256, 0.3501585252339816, 0.9359264231286265], 
             UndirectedEdge[128, 261] -> 
             RGBColor[
              0.22729090761283746`, 0.3562275333499445, 0.9362552529905616], 
             UndirectedEdge[69, 381] -> 
             RGBColor[
              0.21898984745913425`, 0.34750259281079, 0.9357825198951262], 
             UndirectedEdge[166, 178] -> 
             RGBColor[
              0.7156925694809679, 0.7734991059400932, 0.884905461880064], 
             UndirectedEdge[114, 202] -> 
             RGBColor[
              0.2423249813764799, 0.37202929809086444`, 0.937111421250482], 
             UndirectedEdge[40, 134] -> 
             RGBColor[
              0.6760140538149009, 0.745057217744171, 0.9695892868351288], 
             UndirectedEdge[84, 234] -> 
             RGBColor[
              0.5622802808581155, 0.6502189334159502, 0.961044291025931], 
             UndirectedEdge[236, 367] -> 
             RGBColor[
              0.3129287562528536, 0.440105110895209, 0.9413567694167602], 
             UndirectedEdge[307, 366] -> 
             RGBColor[
              0.37137695467694465`, 0.4960897850178574, 0.9448847890496364], 
             UndirectedEdge[129, 396] -> 
             RGBColor[
              0.19432308879693078`, 0.32157626549398477`, 0.934377784480513], 
             UndirectedEdge[67, 208] -> 
             RGBColor[
              0.7091189037719949, 0.7670538844748609, 0.8568671364687419], 
             UndirectedEdge[203, 309] -> 
             RGBColor[
              0.2616767930351678, 0.3923692791198713, 0.9382134782960043], 
             UndirectedEdge[142, 302] -> 
             RGBColor[
              0.18693197467623224`, 0.31380773592942895`, 0.9339568714655127],
              UndirectedEdge[93, 248] -> 
             RGBColor[
              0.22615954726936105`, 0.355038401896562, 0.9361908236926982], 
             UndirectedEdge[110, 227] -> 
             RGBColor[
              0.1954518354139104, 0.3227626497550994, 0.934442064930519], 
             UndirectedEdge[129, 361] -> 
             RGBColor[
              0.20336215554475928`, 0.33107689775588556`, 0.9348925459597008],
              UndirectedEdge[236, 332] -> 
             RGBColor[
              0.2395600162179548, 0.36912314440033817`, 0.9369539605751034], 
             UndirectedEdge[306, 353] -> 
             RGBColor[
              0.19636662006403216`, 0.3237241464230741, 0.9344941605630408], 
             UndirectedEdge[257, 280] -> 
             RGBColor[
              0.2873202290991691, 0.41799462453322234`, 0.9397224414852408], 
             UndirectedEdge[208, 385] -> 
             RGBColor[
              0.9937202968318795, 0.9909321476846529, 0.7000134809555262], 
             UndirectedEdge[79, 302] -> 
             RGBColor[
              0.21120952198211004`, 0.3393249774333106, 0.9353394418691697], 
             UndirectedEdge[21, 242] -> 
             RGBColor[
              0.907737765098039, 0.6451681172975665, 0.25461897498786773`], 
             UndirectedEdge[94, 103] -> 
             RGBColor[
              0.18776701535974932`, 0.31468541663244265`, 0.934004425797107], 
             UndirectedEdge[237, 308] -> 
             RGBColor[
              0.19941664213352878`, 0.3269299130006835, 0.9346678548077954], 
             UndirectedEdge[1, 235] -> 
             RGBColor[
              0.19253038583618232`, 0.3196920210183055, 0.9342756926989647], 
             UndirectedEdge[31, 374] -> 
             RGBColor[
              0.1933477765192394, 0.32055115045176114`, 0.9343222418891437], 
             UndirectedEdge[324, 351] -> 
             RGBColor[
              0.7714595274314936, 0.8219737948771062, 0.9777595758801894], 
             UndirectedEdge[62, 396] -> 
             RGBColor[
              0.20033182917246628`, 0.3278918326048165, 0.934719973355765], 
             UndirectedEdge[13, 123] -> 
             RGBColor[
              0.2129302625842361, 0.3411335849074007, 0.9354374355008532], 
             UndirectedEdge[112, 337] -> 
             RGBColor[
              0.9655773454319732, 0.8890178859650467, 0.43083247110178885`], 
             UndirectedEdge[262, 286] -> 
             RGBColor[
              0.20449842182687056`, 0.3322711856618279, 0.9349572546435119], 
             UndirectedEdge[56, 59] -> 
             RGBColor[
              0.3640812726856617, 0.4897706319686471, 0.9444199146444701], 
             UndirectedEdge[61, 118] -> 
             RGBColor[
              0.22412293343441853`, 0.3528977916272621, 0.9360748415476985], 
             UndirectedEdge[14, 235] -> 
             RGBColor[
              0.1880315009055375, 0.3149634077104182, 0.9340194878576683], 
             UndirectedEdge[154, 286] -> 
             RGBColor[
              0.2001789472954632, 0.3277311440588154, 0.9347112669590381], 
             UndirectedEdge[159, 215] -> 
             RGBColor[
              0.1817543271405076, 0.3083657000875679, 0.9336620120979963], 
             UndirectedEdge[25, 385] -> 
             RGBColor[
              0.9058721590894482, 0.562305822104239, 0.3994132353001115], 
             UndirectedEdge[165, 256] -> 
             RGBColor[
              0.624029163944416, 0.6996077525866663, 0.9668100145352584], 
             UndirectedEdge[292, 384] -> 
             RGBColor[
              0.19197167888601352`, 0.3191047845896115, 0.9342438751646855], 
             UndirectedEdge[1, 49] -> 
             RGBColor[
              0.19061232216343427`, 0.3176760144859865, 0.9341664618103227], 
             UndirectedEdge[93, 125] -> 
             RGBColor[
              0.24791606512635506`, 0.37790588160716765`, 0.9374298251987702],
              UndirectedEdge[15, 37] -> 
             RGBColor[
              0.31731211488685307`, 0.44714239125067556`, 0.9415174176154697],
              UndirectedEdge[141, 399] -> 
             RGBColor[
              0.8960867985444002, 0.6145986026106095, 0.23467160372890067`], 
             UndirectedEdge[42, 288] -> 
             RGBColor[
              0.26094257460696524`, 0.39159756899969334`, 0.938171665642697], 
             UndirectedEdge[26, 218] -> 
             RGBColor[
              0.188929981383257, 0.31590776765945394`, 0.9340706549916917], 
             UndirectedEdge[292, 389] -> 
             RGBColor[
              0.1985170723266464, 0.32598440809763013`, 0.9346166256380877], 
             UndirectedEdge[87, 361] -> 
             RGBColor[
              0.20790747959893147`, 0.33585432152701067`, 0.9351513954403816],
              UndirectedEdge[3, 11] -> 
             RGBColor[
              0.4469167817161049, 0.5580281285800609, 0.9506625439425702], 
             UndirectedEdge[217, 364] -> 
             RGBColor[
              0.9053733542786032, 0.5622322721281416, 0.3258032886328436], 
             UndirectedEdge[83, 120] -> 
             RGBColor[
              0.7316668327109251, 0.7891725193318362, 0.9665740024152043], 
             UndirectedEdge[251, 380] -> 
             RGBColor[
              0.20519908617390886`, 0.3330076283152506, 0.9349971564415356], 
             UndirectedEdge[209, 390] -> 
             RGBColor[
              0.2987767120225358, 0.42895084624860025`, 0.9404146082252327], 
             UndirectedEdge[149, 315] -> 
             RGBColor[
              0.21772472600366666`, 0.3461728699477604, 0.9357104730998167], 
             UndirectedEdge[34, 263] -> 
             RGBColor[
              0.3276003815122878, 0.45396612776116196`, 0.9422494083788064], 
             UndirectedEdge[327, 376] -> 
             RGBColor[
              0.2026044968471712, 0.33028055042638454`, 0.9348493984177288], 
             UndirectedEdge[113, 316] -> 
             RGBColor[
              0.2709397029977173, 0.40210518479292345`, 0.9387409873151243], 
             UndirectedEdge[85, 307] -> 
             RGBColor[
              0.294549891018896, 0.4232589122924366, 0.9402196391759287], 
             UndirectedEdge[140, 257] -> 
             RGBColor[
              0.2744017745717613, 0.404416509747592, 0.9389867546110457], 
             UndirectedEdge[228, 330] -> 
             RGBColor[
              0.1947627843493959, 0.3220384133979338, 0.9344028244917546], 
             UndirectedEdge[22, 96] -> 
             RGBColor[
              0.5322372446835262, 0.6257908335621027, 0.9584554594663912], 
             UndirectedEdge[22, 323] -> 
             RGBColor[
              0.35748321527472365`, 0.48405572626730053`, 0.943999492260678], 
             UndirectedEdge[167, 269] -> 
             RGBColor[
              0.5269179419290838, 0.6213796361571894, 0.958033512915055], 
             UndirectedEdge[85, 214] -> 
             RGBColor[
              0.2402451657445982, 0.3698432799938294, 0.9369929788270578], 
             UndirectedEdge[89, 155] -> 
             RGBColor[
              0.19816316122321598`, 0.3256124250886648, 0.9345964709243118], 
             UndirectedEdge[1, 396] -> 
             RGBColor[
              0.1965523248147455, 0.3239193338904351, 0.9345047361738683], 
             UndirectedEdge[172, 208] -> 
             RGBColor[
              0.9084092508392714, 0.5876736275457447, 0.4679228968183917], 
             UndirectedEdge[45, 339] -> 
             RGBColor[
              0.26817858765203434`, 0.39920307749978645`, 0.9385837458808918],
              UndirectedEdge[250, 363] -> 
             RGBColor[
              0.2391241828797345, 0.3686650559284389, 0.9369291405112493], 
             UndirectedEdge[167, 222] -> 
             RGBColor[
              0.2713202012615644, 0.4023656525144891, 0.9387677624449977], 
             UndirectedEdge[73, 208] -> 
             RGBColor[
              0.9618152962983195, 0.8769997675618114, 0.5142240753361885], 
             UndirectedEdge[14, 317] -> 
             RGBColor[
              0.18995153056345765`, 0.3169814806178038, 0.9341288307062575], 
             UndirectedEdge[157, 334] -> 
             RGBColor[
              0.1861875662547559, 0.3130253154802374, 0.9339144785071631], 
             UndirectedEdge[107, 190] -> 
             RGBColor[
              0.6524189980541504, 0.7216233648288316, 0.9512140557147148], 
             UndirectedEdge[12, 209] -> 
             RGBColor[
              0.3216593094784126, 0.45300190701520204`, 0.9417177382985756], 
             UndirectedEdge[185, 219] -> 
             RGBColor[
              0.36836286362019555`, 0.4934791308371227, 0.9446927338327562], 
             UndirectedEdge[318, 345] -> 
             RGBColor[
              0.18668882027855277`, 0.3135521652405886, 0.9339430241822795], 
             UndirectedEdge[36, 383] -> 
             RGBColor[
              0.20061589185273376`, 0.3281904004923918, 0.9347361503051731], 
             UndirectedEdge[24, 357] -> 
             RGBColor[
              0.8389436700878857, 0.3003436902863443, 0.184925808497731], 
             UndirectedEdge[344, 354] -> 
             RGBColor[
              0.2035510812828702, 0.3312754706852238, 0.9349033050009957], 
             UndirectedEdge[7, 194] -> 
             RGBColor[
              0.7215884971461117, 0.7768639400824314, 0.7979961077324451], 
             UndirectedEdge[97, 248] -> 
             RGBColor[
              0.2054442201466507, 0.3332652796629938, 0.9350111164586401], 
             UndirectedEdge[14, 129] -> 
             RGBColor[
              0.18681866782962492`, 0.3136886432495756, 0.9339504188082208], 
             UndirectedEdge[160, 307] -> 
             RGBColor[
              0.403988994027505, 0.524165485775675, 0.9470101048053469], 
             UndirectedEdge[165, 400] -> 
             RGBColor[
              0.873464012393198, 0.6536035645465732, 0.5928491209890607], 
             UndirectedEdge[310, 323] -> 
             RGBColor[
              0.33914507736848765`, 0.46547732189212476`, 0.9429296732937578],
              UndirectedEdge[309, 339] -> 
             RGBColor[
              0.27457216058382816`, 0.4059231280270391, 0.9389478504009139], 
             UndirectedEdge[355, 395] -> 
             RGBColor[
              0.6171730285902994, 0.6981983576754478, 0.9642971542356892], 
             UndirectedEdge[32, 240] -> 
             RGBColor[
              0.8943605848806221, 0.5556511737673611, 0.23277873743991706`], 
             UndirectedEdge[66, 322] -> 
             RGBColor[
              0.2070879506142999, 0.33499294460302415`, 0.9351047244770914], 
             UndirectedEdge[28, 267] -> 
             RGBColor[
              0.23148773999796957`, 0.36063867028126045`, 0.9364942563862377],
              UndirectedEdge[51, 102] -> 
             RGBColor[
              0.32952467941339164`, 0.45694789679919157`, 0.9423238729229517],
              UndirectedEdge[244, 321] -> 
             RGBColor[
              0.7545634824664897, 0.8074397031821838, 0.959757518581915], 
             UndirectedEdge[140, 309] -> 
             RGBColor[
              0.2616478487840542, 0.3923388568767794, 0.9382118299637227], 
             UndirectedEdge[12, 324] -> 
             RGBColor[
              0.4708028735942141, 0.577300258720949, 0.9525700303913813], 
             UndirectedEdge[130, 287] -> 
             RGBColor[
              0.1859722872961475, 0.31279904364526556`, 0.9339022186889471], 
             UndirectedEdge[267, 367] -> 
             RGBColor[
              0.315534462322565, 0.44284387318578267`, 0.9415051605226336], 
             UndirectedEdge[138, 229] -> 
             RGBColor[
              0.19456770903936127`, 0.32183337687859837`, 0.9343917152414362],
              UndirectedEdge[97, 193] -> 
             RGBColor[
              0.1899172543843397, 0.31694545418031556`, 0.9341268787285638], 
             UndirectedEdge[248, 340] -> 
             RGBColor[
              0.2104667967928659, 0.33854432616791813`, 0.9352971447684058], 
             UndirectedEdge[162, 248] -> 
             RGBColor[
              0.24516386461647438`, 0.3750131443716921, 0.9372730914512483], 
             UndirectedEdge[127, 317] -> 
             RGBColor[
              0.19507910076484197`, 0.32237088200618674`, 0.9344208382436661],
              UndirectedEdge[269, 355] -> 
             RGBColor[
              0.7546443194902623, 0.8082531449858283, 0.9761795512808198], 
             UndirectedEdge[161, 184] -> 
             RGBColor[
              0.19128276610466352`, 0.31838069357681953`, 0.9342046426009427],
              UndirectedEdge[340, 360] -> 
             RGBColor[
              0.1940919893072422, 0.3213333652777681, 0.9343646237064562], 
             UndirectedEdge[19, 185] -> 
             RGBColor[
              0.330002266441723, 0.4557835793222022, 0.9424120819002554], 
             UndirectedEdge[240, 357] -> 
             RGBColor[
              0.8443947063429684, 0.3422427436022275, 0.19014572697166301`], 
             UndirectedEdge[75, 132] -> 
             RGBColor[
              0.28812004710636396`, 0.4155836677571048, 0.9398870475355221], 
             UndirectedEdge[89, 353] -> 
             RGBColor[
              0.18963294311823536`, 0.31664662501326446`, 0.93411068762256], 
             UndirectedEdge[214, 312] -> 
             RGBColor[
              0.2713270321361526, 0.4025122922755047, 0.9387630451365561], 
             UndirectedEdge[119, 129] -> 
             RGBColor[
              0.18575214150891103`, 0.312567656464831, 0.9338896817120405], 
             UndirectedEdge[143, 377] -> 
             RGBColor[
              0.1848896476706373, 0.3116611207555374, 0.933840563963896], 
             UndirectedEdge[5, 122] -> 
             RGBColor[
              0.440201175363544, 0.5493422068445898, 0.9504444277972779], 
             UndirectedEdge[42, 318] -> 
             RGBColor[
              0.2054522043558168, 0.33327367157305554`, 0.9350115711475404], 
             UndirectedEdge[6, 137] -> 
             RGBColor[
              0.32002599977803325`, 0.451320237982877, 0.941623440630758], 
             UndirectedEdge[113, 149] -> 
             RGBColor[
              0.26206453775242544`, 0.39277682340214404`, 0.9382355597840353],
              UndirectedEdge[67, 124] -> 
             RGBColor[
              0.3674760832994186, 0.49271104629414053`, 0.9446362289748654], 
             UndirectedEdge[141, 337] -> 
             RGBColor[
              0.9298221770988357, 0.7361333470484221, 0.40148742427443984`], 
             UndirectedEdge[63, 224] -> 
             RGBColor[
              0.1802578853175729, 0.30679284485177194`, 0.9335767919499673], 
             UndirectedEdge[244, 357] -> 
             RGBColor[
              0.9059329560446046, 0.7028448327231054, 0.5818836591998524], 
             UndirectedEdge[9, 192] -> 
             RGBColor[
              0.1863278971063823, 0.3131728121027866, 0.9339224701415624], 
             UndirectedEdge[46, 369] -> 
             RGBColor[
              0.19594555683555187`, 0.3232815822729907, 0.934470181635086], 
             UndirectedEdge[350, 392] -> 
             RGBColor[
              0.9924671913475096, 0.9911530042849124, 0.7745016638630496], 
             UndirectedEdge[275, 339] -> 
             RGBColor[
              0.24514905354352745`, 0.3749975769949486, 0.9372722479825549], 
             UndirectedEdge[119, 127] -> 
             RGBColor[
              0.18861006279746526`, 0.31557151294177693`, 0.9340524361015079],
              UndirectedEdge[152, 398] -> 
             RGBColor[
              0.3414317727237982, 0.4653471726445155, 0.943152665123154], 
             UndirectedEdge[105, 229] -> 
             RGBColor[
              0.20817939443044792`, 0.33614012125533055`, 0.9351668805877746],
              UndirectedEdge[181, 365] -> 
             RGBColor[
              0.1879270858801807, 0.3148536608984732, 0.9340135415764423], 
             UndirectedEdge[24, 285] -> 
             RGBColor[
              0.9074929446583304, 0.5753915383194507, 0.38875906329594523`], 
             UndirectedEdge[167, 189] -> 
             RGBColor[
              0.2884488073307313, 0.4203689035095335, 0.9397432112211349], 
             UndirectedEdge[157, 191] -> 
             RGBColor[
              0.1973089788218841, 0.3247146252265727, 0.9345478265002056], 
             UndirectedEdge[78, 194] -> 
             RGBColor[
              0.9072346231009216, 0.5724833285992563, 0.40645475392950137`], 
             UndirectedEdge[107, 268] -> 
             RGBColor[
              0.5139907876886572, 0.6129102178843966, 0.9560554271690249], 
             UndirectedEdge[5, 274] -> 
             RGBColor[
              0.38775900825169696`, 0.5067672930904867, 0.9463159883002454], 
             UndirectedEdge[12, 118] -> 
             RGBColor[
              0.27367870261090094`, 0.4049840470489852, 0.9388969692911083], 
             UndirectedEdge[20, 291] -> 
             RGBColor[
              0.18873168488737596`, 0.31569934546955897`, 0.9340593622996046],
              UndirectedEdge[6, 379] -> 
             RGBColor[
              0.25634517615934155`, 0.38676541173934353`, 0.9379098506023464],
              UndirectedEdge[97, 181] -> 
             RGBColor[
              0.19390662933890207`, 0.32113854019854193`, 0.9343540677304747],
              UndirectedEdge[39, 320] -> 
             RGBColor[
              0.18948414481075992`, 0.3164902285577502, 0.9341022137790767], 
             UndirectedEdge[202, 218] -> 
             RGBColor[
              0.2171099632633392, 0.3455267153294672, 0.9356754632712151], 
             UndirectedEdge[61, 344] -> 
             RGBColor[
              0.20030701799861927`, 0.32786575448798405`, 0.9347185603961192],
              UndirectedEdge[181, 214] -> 
             RGBColor[
              0.21733436721625865`, 0.34576257811201794`, 0.9356882427443579],
              UndirectedEdge[274, 324] -> 
             RGBColor[
              0.5631040589260905, 0.6561922684417929, 0.9587487607182468], 
             UndirectedEdge[62, 231] -> 
             RGBColor[
              0.19164937615014635`, 0.31876602397904136`, 0.934225520500682], 
             UndirectedEdge[117, 289] -> 
             RGBColor[
              0.20615434433043495`, 0.33401166520462483`, 0.935051556980372], 
             UndirectedEdge[14, 396] -> 
             RGBColor[
              0.19205343988410067`, 0.31919072058254777`, 0.9342485313325719],
              UndirectedEdge[79, 175] -> 
             RGBColor[
              0.2563476435480917, 0.3867680051213614, 0.9379099911164857], 
             UndirectedEdge[246, 395] -> 
             RGBColor[
              0.6944421379403393, 0.7593719483680503, 0.9717835682731306], 
             UndirectedEdge[87, 396] -> 
             RGBColor[
              0.198868412851103, 0.3263536892651099, 0.9346366339611938], 
             UndirectedEdge[341, 366] -> 
             RGBColor[
              0.36531722643847, 0.49084115298848774`, 0.9444986685246879], 
             UndirectedEdge[40, 226] -> 
             RGBColor[
              0.48315013418370223`, 0.5910627432060597, 0.9525150956533707], 
             UndirectedEdge[67, 316] -> 
             RGBColor[
              0.32978816517065423`, 0.4531895985227258, 0.9424866278961124], 
             UndirectedEdge[303, 376] -> 
             RGBColor[
              0.21141869489039777`, 0.33954483142224945`, 0.9353513539568531],
              UndirectedEdge[208, 357] -> 
             RGBColor[
              0.9250578823512863, 0.7156423048239384, 0.4838656451562371], 
             UndirectedEdge[54, 66] -> 
             RGBColor[
              0.19944158418676777`, 0.3269561286800552, 0.9346692752208288], 
             UndirectedEdge[3, 160] -> 
             RGBColor[
              0.5207461823507223, 0.6218042360373149, 0.9554141935122193], 
             UndirectedEdge[230, 328] -> 
             RGBColor[
              0.8436345364621675, 0.31890075612792645`, 0.1887325709247331], 
             UndirectedEdge[282, 383] -> 
             RGBColor[
              0.23774824777614534`, 0.3672188608952424, 0.9368507830426136], 
             UndirectedEdge[106, 150] -> 
             RGBColor[
              0.2101822963835033, 0.33824529819931026`, 0.9352809428909732], 
             UndirectedEdge[1, 298] -> 
             RGBColor[
              0.19527223087889906`, 0.32257387400121723`, 0.9344318367179512],
              UndirectedEdge[66, 131] -> 
             RGBColor[
              0.2137636212718384, 0.34200949772606326`, 0.9354848940452685], 
             UndirectedEdge[53, 126] -> 
             RGBColor[
              0.1894916420221746, 0.31649810860229766`, 0.9341026407341755], 
             UndirectedEdge[182, 281] -> 
             RGBColor[
              0.38860982761707186`, 0.5110160334092172, 0.94598285247495], 
             UndirectedEdge[74, 263] -> 
             RGBColor[
              0.627506347078178, 0.7037780429959705, 0.9664982429670084], 
             UndirectedEdge[24, 243] -> 
             RGBColor[
              0.8951565236421906, 0.5687878448594291, 0.5520035990795774], 
             UndirectedEdge[177, 252] -> 
             RGBColor[
              0.6322093663988135, 0.7067582685174405, 0.9673012182198607], 
             UndirectedEdge[10, 216] -> 
             RGBColor[
              0.21860581417743288`, 0.3470989494826055, 0.9357606497678597], 
             UndirectedEdge[280, 339] -> 
             RGBColor[
              0.2515419198726136, 0.3817168848379542, 0.9376363122625981], 
             UndirectedEdge[152, 154] -> 
             RGBColor[
              0.23114091709829876`, 0.3602741374238645, 0.93647450533518], 
             UndirectedEdge[36, 304] -> 
             RGBColor[
              0.18688421139568462`, 0.3137575336932065, 0.933954151417345], 
             UndirectedEdge[128, 299] -> 
             RGBColor[
              0.19113698074466645`, 0.31822746392013684`, 0.934196340340361], 
             UndirectedEdge[95, 162] -> 
             RGBColor[
              0.41586939242453425`, 0.5283792415607237, 0.9486390212485251], 
             UndirectedEdge[215, 329] -> 
             RGBColor[
              0.1867198905000643, 0.313584822013363, 0.9339447935854304], 
             UndirectedEdge[208, 387] -> 
             RGBColor[
              0.7635706581669874, 0.8120231295414462, 0.8609429981480392], 
             UndirectedEdge[178, 197] -> 
             RGBColor[
              0.7030008791274289, 0.7649478943931832, 0.947330285544383], 
             UndirectedEdge[53, 303] -> 
             RGBColor[
              0.20281627238444755`, 0.3305031399434066, 0.9348614587212829], 
             UndirectedEdge[59, 121] -> 
             RGBColor[
              0.3287091584623374, 0.4591330844825578, 0.9421660348044922], 
             UndirectedEdge[134, 269] -> 
             RGBColor[
              0.7872748442941331, 0.8338331400434145, 0.9794082972749127], 
             UndirectedEdge[44, 362] -> 
             RGBColor[
              0.21291981933663207`, 0.3411226083920287, 0.9354368407733515], 
             UndirectedEdge[284, 338] -> 
             RGBColor[
              0.2553995027309328, 0.3857714490069275, 0.9378559958995971], 
             UndirectedEdge[12, 346] -> 
             RGBColor[
              0.329771268632467, 0.46002807831552184`, 0.9422346251627481], 
             UndirectedEdge[113, 387] -> 
             RGBColor[
              0.4208258242811829, 0.5366129491256768, 0.9486460027249637], 
             UndirectedEdge[55, 400] -> 
             RGBColor[
              0.9109049028745734, 0.6513336536973703, 0.2699888799203509], 
             UndirectedEdge[25, 201] -> 
             RGBColor[
              0.8831813824108397, 0.5478222518769809, 0.567678897014493], 
             UndirectedEdge[123, 309] -> 
             RGBColor[
              0.2546471876156135, 0.3849807181211936, 0.93781315266673], 
             UndirectedEdge[35, 162] -> 
             RGBColor[
              0.25429020183451534`, 0.3846055034310536, 0.9377928228546097], 
             UndirectedEdge[73, 172] -> 
             RGBColor[
              0.8772092716527284, 0.4732937439467283, 0.21672848084375096`], 
             UndirectedEdge[137, 282] -> 
             RGBColor[
              0.3008030444529849, 0.4311156931304887, 0.9405287217628104], 
             UndirectedEdge[37, 114] -> 
             RGBColor[
              0.2950446149939596, 0.4237378370222073, 0.9402493164383834], 
             UndirectedEdge[214, 248] -> 
             RGBColor[
              0.22887195802400728`, 0.3578893175764699, 0.9363452914725232], 
             UndirectedEdge[161, 363] -> 
             RGBColor[
              0.20967797684249928`, 0.3377152263860093, 0.9352522226391868], 
             UndirectedEdge[51, 84] -> 
             RGBColor[
              0.36020789306278994`, 0.48641570522103605`, 0.9441731063199956],
              UndirectedEdge[56, 278] -> 
             RGBColor[
              0.3199081459581343, 0.44683361246279085`, 0.9417764708138758], 
             UndirectedEdge[4, 140] -> 
             RGBColor[
              0.22925899781803233`, 0.3582961209397305, 0.9363673328162189], 
             UndirectedEdge[221, 351] -> 
             RGBColor[
              0.9060488999462345, 0.7900961921894157, 0.6157268873569864], 
             UndirectedEdge[54, 204] -> 
             RGBColor[
              0.18912347164523904`, 0.31611113819278824`, 0.9340816739758684],
              UndirectedEdge[10, 298] -> 
             RGBColor[
              0.21724932645694042`, 0.3456731948820789, 0.9356833997989213], 
             UndirectedEdge[134, 226] -> 
             RGBColor[
              0.6381042655490734, 0.7140610165668736, 0.9666654902064342], 
             UndirectedEdge[35, 98] -> 
             RGBColor[
              0.21863346925867172`, 0.3471280167264209, 0.9357622246838242], 
             UndirectedEdge[70, 180] -> 
             RGBColor[
              0.24072957206270523`, 0.3703524217472943, 0.9370205650502591], 
             UndirectedEdge[165, 328] -> 
             RGBColor[
              0.8831401501680374, 0.7104796109326978, 0.6014297849392954], 
             UndirectedEdge[162, 214] -> 
             RGBColor[
              0.25603696286442035`, 0.3864414600245297, 0.9378922983111614], 
             UndirectedEdge[211, 370] -> 
             RGBColor[
              0.20448863330117922`, 0.3322608973006979, 0.9349566972014545], 
             UndirectedEdge[55, 245] -> 
             RGBColor[
              0.8952306902685789, 0.5308547871239369, 0.2549792362273595], 
             UndirectedEdge[247, 315] -> 
             RGBColor[
              0.2082369879918481, 0.3362006557400048, 0.9351701604558942], 
             UndirectedEdge[16, 268] -> 
             RGBColor[
              0.49856920010276634`, 0.5995528138290274, 0.9550727772448264], 
             UndirectedEdge[154, 291] -> 
             RGBColor[
              0.1963438417799771, 0.3237002050023056, 0.9344928633734613], 
             UndirectedEdge[296, 373] -> 
             RGBColor[
              0.25840585650162723`, 0.38893131743376574`, 0.9380272032993362],
              UndirectedEdge[101, 394] -> 
             RGBColor[
              0.18176625720560394`, 0.308378239342394, 0.9336626914975545], 
             UndirectedEdge[173, 388] -> 
             RGBColor[
              0.2509970167086373, 0.38114415706375904`, 0.9376052808335218], 
             UndirectedEdge[84, 102] -> 
             RGBColor[
              0.3081546083900806, 0.43843821536979977`, 0.9409621908941581], 
             UndirectedEdge[216, 298] -> 
             RGBColor[
              0.19835416070020614`, 0.3258131776490477, 0.9346073480619681], 
             UndirectedEdge[209, 310] -> 
             RGBColor[
              0.30722079620017617`, 0.4378261141051596, 0.9408954863272463], 
             UndirectedEdge[34, 93] -> 
             RGBColor[
              0.24878417747359188`, 0.37881832272561544`, 0.9374792629126882],
              UndirectedEdge[112, 285] -> 
             RGBColor[
              0.9656534548794817, 0.8891806763774219, 0.4391165147700274], 
             UndirectedEdge[131, 309] -> 
             RGBColor[
              0.255426495168577, 0.38579981977031097`, 0.9378575330789891], 
             UndirectedEdge[116, 265] -> 
             RGBColor[
              0.18666044049465552`, 0.3135223362883303, 0.9339414079955707], 
             UndirectedEdge[49, 129] -> 
             RGBColor[
              0.18838308614561955`, 0.31533294608953616`, 0.9340395101169672],
              UndirectedEdge[238, 325] -> 
             RGBColor[
              0.28956065239162987`, 0.42167698324230746`, 0.9398014228358818],
              UndirectedEdge[112, 399] -> 
             RGBColor[
              0.9318419668775375, 0.7674831415272341, 0.2640166505562497], 
             UndirectedEdge[186, 322] -> 
             RGBColor[
              0.20337835674212623`, 0.3310939262415335, 0.9348934685939234], 
             UndirectedEdge[180, 332] -> 
             RGBColor[
              0.2434440031568898, 0.373205460932154, 0.937175147885432], 
             UndirectedEdge[60, 331] -> 
             RGBColor[
              0.19257622837931382`, 0.31974020443772183`, 0.9342783033639781],
              UndirectedEdge[14, 126] -> 
             RGBColor[
              0.18556762080960376`, 0.31237371351057097`, 0.9338791735311889],
              UndirectedEdge[275, 288] -> 
             RGBColor[
              0.2720607570835225, 0.40328348371603906`, 0.9388048296868601], 
             UndirectedEdge[276, 290] -> 
             RGBColor[
              0.21053718403849497`, 0.33861830762588346`, 0.9353011532179156],
              UndirectedEdge[18, 232] -> 
             RGBColor[
              0.4501165590628717, 0.5589054128143358, 0.9510872394181826], 
             UndirectedEdge[4, 325] -> 
             RGBColor[
              0.26097898271890796`, 0.39163583623375275`, 0.9381737390308114],
              UndirectedEdge[1, 62] -> 
             RGBColor[
              0.19732629313580521`, 0.3247328236682947, 0.9345488125247692], 
             UndirectedEdge[20, 304] -> 
             RGBColor[
              0.185589373288035, 0.312396576744589, 0.9338804123026556], 
             UndirectedEdge[255, 328] -> 
             RGBColor[
              0.8524460760036836, 0.3866301102852666, 0.1971705111408994], 
             UndirectedEdge[3, 74] -> 
             RGBColor[
              0.7224644673916434, 0.782535536200579, 0.9735133143364585], 
             UndirectedEdge[18, 279] -> 
             RGBColor[
              0.638687245246097, 0.7170964540862654, 0.9650118438159424], 
             UndirectedEdge[163, 226] -> 
             RGBColor[
              0.35601753306005335`, 0.4789075435482711, 0.944048117850775], 
             UndirectedEdge[145, 254] -> 
             RGBColor[
              0.19225246823374995`, 0.31939991199715534`, 0.9342598657026484],
              UndirectedEdge[23, 348] -> 
             RGBColor[
              0.3130979265677895, 0.44416079144735543`, 0.9412244155321879], 
             UndirectedEdge[119, 396] -> 
             RGBColor[
              0.19098691356338682`, 0.3180697337978031, 0.9341877942363916], 
             UndirectedEdge[73, 141] -> 
             RGBColor[
              0.898106425922933, 0.622605752165564, 0.23629664332441563`], 
             UndirectedEdge[29, 396] -> 
             RGBColor[
              0.19049809514878532`, 0.31755595465117936`, 0.9341599567508221],
              UndirectedEdge[160, 312] -> 
             RGBColor[
              0.38126624461740655`, 0.5039445125232649, 0.9455819912605958], 
             UndirectedEdge[210, 397] -> 
             RGBColor[
              0.25928855226930214`, 0.38985908665173613`, 0.938077471517474], 
             UndirectedEdge[11, 86] -> 
             RGBColor[
              0.361493667794528, 0.48752937866875046`, 0.9442550347489361], 
             UndirectedEdge[113, 315] -> 
             RGBColor[
              0.26318579596449465`, 0.3939553368749055, 0.9382994137804598], 
             UndirectedEdge[120, 160] -> 
             RGBColor[
              0.48896132780643076`, 0.5959998592268796, 0.9529119733307341], 
             UndirectedEdge[5, 308] -> 
             RGBColor[
              0.24197001296398313`, 0.37165620378303305`, 0.9370912063245189],
              UndirectedEdge[37, 261] -> 
             RGBColor[
              0.30438433219243016`, 0.43355447197007246`, 0.940781199515963], 
             UndirectedEdge[22, 241] -> 
             RGBColor[
              0.28974430117812966`, 0.42117386849154814`, 0.9398373705045929],
              UndirectedEdge[55, 165] -> 
             RGBColor[
              0.9341904345376686, 0.918237850236102, 0.6671537250527897], 
             UndirectedEdge[251, 283] -> 
             RGBColor[
              0.19962713488925782`, 0.32715115423296626`, 0.934679842058838], 
             UndirectedEdge[334, 365] -> 
             RGBColor[
              0.18295572293696874`, 0.30962844324254163`, 0.933730429811299], 
             UndirectedEdge[44, 358] -> 
             RGBColor[
              0.21372519899594036`, 0.3419691134779814, 0.9354827059534967], 
             UndirectedEdge[225, 367] -> 
             RGBColor[
              0.6298962166593582, 0.7051035104774022, 0.9669932656124167], 
             UndirectedEdge[23, 321] -> 
             RGBColor[
              0.42370887427578074`, 0.5372228658179581, 0.9490305036181749], 
             UndirectedEdge[234, 269] -> 
             RGBColor[
              0.7646521215423732, 0.8160713160110501, 0.9771770354611466], 
             UndirectedEdge[21, 208] -> 
             RGBColor[
              0.9781086897296334, 0.9394569243444684, 0.5384830216306559], 
             UndirectedEdge[208, 240] -> 
             RGBColor[
              0.9123520994765446, 0.6179800899391169, 0.47169857312625524`], 
             UndirectedEdge[15, 313] -> 
             RGBColor[
              0.25209641053026927`, 0.3822996896758886, 0.9376678896852563], 
             UndirectedEdge[63, 204] -> 
             RGBColor[
              0.18740799960939158`, 0.3143080683159034, 0.9339839803812403], 
             UndirectedEdge[241, 310] -> 
             RGBColor[
              0.2714061632718937, 0.40259546411637237`, 0.9387675515376726], 
             UndirectedEdge[182, 256] -> 
             RGBColor[
              0.34992025301800456`, 0.4775050684860661, 0.9435175869933449], 
             UndirectedEdge[373, 380] -> 
             RGBColor[
              0.24598769620290184`, 0.37587904360296687`, 0.9373200074413457],
              UndirectedEdge[185, 210] -> 
             RGBColor[
              0.35262704416750634`, 0.4795636552057607, 0.9437005295213796], 
             UndirectedEdge[96, 223] -> 
             RGBColor[
              0.8390506368021915, 0.7815052608012159, 0.618996491222558], 
             UndirectedEdge[103, 222] -> 
             RGBColor[
              0.21336670811641717`, 0.34159231683396796`, 0.9354622904282476],
              UndirectedEdge[146, 375] -> 
             RGBColor[
              0.18336952246536248`, 0.3100633727832889, 0.9337539950822794], 
             UndirectedEdge[42, 276] -> 
             RGBColor[
              0.2196855450649306, 0.3482338151042579, 0.9358221388445839], 
             UndirectedEdge[46, 372] -> 
             RGBColor[
              0.19768089456011895`, 0.32510553224827726`, 0.934569006551298], 
             UndirectedEdge[95, 285] -> 
             RGBColor[
              0.7768044768753901, 0.8215969254274786, 0.7842186264026185], 
             UndirectedEdge[14, 326] -> 
             RGBColor[
              0.18828033718868842`, 0.3152249504211414, 0.9340336587158735], 
             UndirectedEdge[22, 310] -> 
             RGBColor[
              0.2979372274212155, 0.4297851534345578, 0.9403039455337885], 
             UndirectedEdge[23, 229] -> 
             RGBColor[
              0.24996961512608984`, 0.38006429285947896`, 0.9375467718333002],
              UndirectedEdge[23, 160] -> 
             RGBColor[
              0.3763398438622711, 0.4987665529777692, 0.9453014400255476], 
             UndirectedEdge[165, 311] -> 
             RGBColor[
              0.5997467789297788, 0.6780206465223158, 0.965283080943369], 
             UndirectedEdge[179, 288] -> 
             RGBColor[
              0.3796596294696894, 0.502934688841232, 0.9454287055118813], 
             UndirectedEdge[51, 167] -> 
             RGBColor[
              0.3459161722681373, 0.47403693499148125`, 0.9432624505086329], 
             UndirectedEdge[310, 346] -> 
             RGBColor[
              0.31533275535423055`, 0.4448522854054794, 0.9414123731914188], 
             UndirectedEdge[79, 379] -> 
             RGBColor[
              0.21907288200889707`, 0.34758986738728526`, 0.9357872485898966],
              UndirectedEdge[78, 264] -> 
             RGBColor[
              0.7716146222869605, 0.4690073780170669, 0.569890082784954], 
             UndirectedEdge[309, 325] -> 
             RGBColor[
              0.2933678336849298, 0.42567857217080163`, 0.9400182361783151], 
             UndirectedEdge[149, 358] -> 
             RGBColor[
              0.20368965097586314`, 0.3314211162183854, 0.9349111963400162], 
             UndirectedEdge[6, 79] -> 
             RGBColor[
              0.26831622286540857`, 0.39934774083561936`, 0.9385915840026804],
              UndirectedEdge[134, 234] -> 
             RGBColor[
              0.8083454624285121, 0.8502936670726204, 0.9815084195744261], 
             UndirectedEdge[96, 209] -> 
             RGBColor[
              0.5415208134624869, 0.6338317942327045, 0.9590470002598491], 
             UndirectedEdge[216, 393] -> 
             RGBColor[
              0.19153695040893678`, 0.31864785739682644`, 0.9342191180210391],
              UndirectedEdge[164, 388] -> 
             RGBColor[
              0.21023340989613648`, 0.33829902174187165`, 0.935283853729902], 
             UndirectedEdge[155, 261] -> 
             RGBColor[
              0.23352567596023666`, 0.3627806701902061, 0.9366103138244327], 
             UndirectedEdge[125, 288] -> 
             RGBColor[
              0.28344153985750953`, 0.415245407994804, 0.9394529484294792], 
             UndirectedEdge[287, 384] -> 
             RGBColor[
              0.18974513703544627`, 0.3167645479337583, 0.9341170769001692], 
             UndirectedEdge[69, 320] -> 
             RGBColor[
              0.21880446674278364`, 0.34730774592408925`, 0.9357719627375762],
              UndirectedEdge[123, 339] -> 
             RGBColor[
              0.23162280417676506`, 0.3607806312967381, 0.9365019480914105], 
             UndirectedEdge[132, 202] -> 
             RGBColor[
              0.300816385571577, 0.4289283244783967, 0.9406100852285664], 
             UndirectedEdge[67, 249] -> 
             RGBColor[
              0.36714946895537004`, 0.49242814936543994`, 0.9446154173976764],
              UndirectedEdge[374, 384] -> 
             RGBColor[
              0.18988847579037965`, 0.3169152060533953, 0.934125239830212], 
             UndirectedEdge[99, 252] -> 
             RGBColor[
              0.6676015641481373, 0.7342070299092066, 0.9439106644834332], 
             UndirectedEdge[44, 65] -> 
             RGBColor[
              0.2623103948909678, 0.393035234842995, 0.9382495609843622], 
             UndirectedEdge[88, 370] -> 
             RGBColor[
              0.189278561860536, 0.3162741478423529, 0.9340905061341941], 
             UndirectedEdge[13, 275] -> 
             RGBColor[
              0.22645651195099847`, 0.3553505306056112, 0.9362077353919975], 
             UndirectedEdge[183, 269] -> 
             RGBColor[
              0.546784204528102, 0.6385867943130678, 0.9592993736008182], 
             UndirectedEdge[122, 178] -> 
             RGBColor[
              0.5198265338212547, 0.6207419031672892, 0.9554290299990101], 
             UndirectedEdge[199, 216] -> 
             RGBColor[
              0.19310022590756143`, 0.3202909590632723, 0.9343081442480269], 
             UndirectedEdge[107, 295] -> 
             RGBColor[
              0.38882676959428764`, 0.5112039376460608, 0.945996675825904], 
             UndirectedEdge[89, 171] -> 
             RGBColor[
              0.18910388505940673`, 0.3160905514492172, 0.934080558548781], 
             UndirectedEdge[18, 91] -> 
             RGBColor[
              0.5492190587011108, 0.6449197997470224, 0.9576556826381046], 
             UndirectedEdge[194, 357] -> 
             RGBColor[
              0.9258160784332223, 0.7153085367289651, 0.42424837654046466`], 
             UndirectedEdge[147, 388] -> 
             RGBColor[
              0.20149520910929605`, 0.3291146186809729, 0.9347862261221009], 
             UndirectedEdge[96, 323] -> 
             RGBColor[
              0.5734450946307983, 0.6614830020196698, 0.9610811872263605], 
             UndirectedEdge[168, 265] -> 
             RGBColor[
              0.18709388052696674`, 0.31397790924397473`, 0.9339660917641938],
              UndirectedEdge[44, 372] -> 
             RGBColor[
              0.21537145554787535`, 0.3436994334927591, 0.9355764578287111], 
             UndirectedEdge[180, 286] -> 
             RGBColor[
              0.22669434503393948`, 0.3556005082552706, 0.9362212796342286], 
             UndirectedEdge[18, 45] -> 
             RGBColor[
              0.4449748432614876, 0.5535011435034702, 0.9507944263097807], 
             UndirectedEdge[83, 217] -> 
             RGBColor[
              0.9690520396764782, 0.9730561345189551, 0.7324860448307533], 
             UndirectedEdge[137, 314] -> 
             RGBColor[
              0.28356888618805115`, 0.41300150008529746`, 0.9395472619452747],
              UndirectedEdge[205, 338] -> 
             RGBColor[
              0.292109011117009, 0.4205396174018403, 0.9400862651454345], 
             UndirectedEdge[210, 293] -> 
             RGBColor[
              0.3272740253136205, 0.45760414455430376`, 0.9420850575788042], 
             UndirectedEdge[295, 324] -> 
             RGBColor[
              0.5310822445454129, 0.6295361727227928, 0.9564100649680346], 
             UndirectedEdge[270, 346] -> 
             RGBColor[
              0.3550828331693524, 0.4819766359343405, 0.9438465420354984], 
             UndirectedEdge[26, 349] -> 
             RGBColor[
              0.19449252215171758`, 0.32175435069256086`, 0.9343874334594139],
              UndirectedEdge[27, 208] -> 
             RGBColor[
              0.9070267560487368, 0.5770471667726158, 0.46659901824567124`], 
             UndirectedEdge[139, 193] -> 
             RGBColor[
              0.18750230329400064`, 0.31440718746762647`, 0.933989350836569], 
             UndirectedEdge[5, 296] -> 
             RGBColor[
              0.26370004466317304`, 0.39449584486246725`, 0.9383286994830867],
              UndirectedEdge[42, 125] -> 
             RGBColor[
              0.23901293023950498`, 0.3685481223497329, 0.9369228048379719], 
             UndirectedEdge[12, 106] -> 
             RGBColor[
              0.2676474114572338, 0.3986447776405352, 0.9385534961824027], 
             UndirectedEdge[242, 357] -> 
             RGBColor[
              0.854686957719692, 0.4213534977770367, 0.2000015985134489], 
             UndirectedEdge[148, 279] -> 
             RGBColor[
              0.5031062098123048, 0.6037853067748751, 0.9552337277677017], 
             UndirectedEdge[292, 374] -> 
             RGBColor[
              0.19230228893935433`, 0.31945227671756077`, 0.9342627029181295],
              UndirectedEdge[195, 369] -> 
             RGBColor[
              0.19622298384464848`, 0.3235731756494396, 0.9344859806928376], 
             UndirectedEdge[50, 371] -> 
             RGBColor[
              0.1827919087042476, 0.30945626409752947`, 0.9337211008330868], 
             UndirectedEdge[29, 127] -> 
             RGBColor[
              0.18812124438286376`, 0.3150577337951532, 0.9340245986159385], 
             UndirectedEdge[87, 127] -> 
             RGBColor[
              0.19649156208518143`, 0.3238554684090837, 0.93450127582631], 
             UndirectedEdge[264, 357] -> 
             RGBColor[
              0.7901960776192611, 0.6118325861467757, 0.5876837053959174], 
             UndirectedEdge[171, 306] -> 
             RGBColor[
              0.19583756200520352`, 0.3231680728590269, 0.9344640314892618], 
             UndirectedEdge[114, 170] -> 
             RGBColor[
              0.23647751036378017`, 0.3658832353054412, 0.9367784164268669], 
             UndirectedEdge[57, 222] -> 
             RGBColor[
              0.22503342369355192`, 0.35385477461802795`, 0.9361266926210063],
              UndirectedEdge[38, 102] -> 
             RGBColor[
              0.25020060979959846`, 0.3803070829072448, 0.9375599266382304], 
             UndirectedEdge[82, 331] -> 
             RGBColor[
              0.18993705205367367`, 0.31696626278603024`, 0.9341280061765445],
              UndirectedEdge[90, 324] -> 
             RGBColor[
              0.6207541500572831, 0.7029952095291041, 0.9632871870713362], 
             UndirectedEdge[160, 341] -> 
             RGBColor[
              0.3979292657890303, 0.5189168537463054, 0.9466239842803985], 
             UndirectedEdge[15, 311] -> 
             RGBColor[
              0.2942848105043079, 0.4266423729476564, 0.940070456651633], 
             UndirectedEdge[271, 292] -> 
             RGBColor[
              0.18674265418407987`, 0.3136087480885643, 0.9339460899435592], 
             UndirectedEdge[41, 156] -> 
             RGBColor[
              0.8514284367030327, 0.5699234098578776, 0.5824732181712974], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.26166329356975937`, 0.3923550903258115, 0.9382127095214201], 
             UndirectedEdge[129, 317] -> 
             RGBColor[
              0.19222117947628775`, 0.3193670255292408, 0.9342580838541985], 
             UndirectedEdge[164, 354] -> 
             RGBColor[
              0.20840265875823133`, 0.3363747862196069, 0.9351795951609518], 
             UndirectedEdge[78, 230] -> 
             RGBColor[
              0.818837947598831, 0.14580229685169685`, 0.1656725459360465], 
             UndirectedEdge[315, 363] -> 
             RGBColor[
              0.2193734294732247, 0.3479057618281034, 0.9358043643233698], 
             UndirectedEdge[5, 121] -> 
             RGBColor[
              0.2966728547509243, 0.4289526354856623, 0.9402137650898452], 
             UndirectedEdge[43, 380] -> 
             RGBColor[
              0.2402420225431372, 0.36983997628980336`, 0.9369927998263845], 
             UndirectedEdge[135, 234] -> 
             RGBColor[
              0.8902824990453274, 0.9119541401261442, 0.8296334999422285], 
             UndirectedEdge[344, 356] -> 
             RGBColor[
              0.19312061469136133`, 0.3203123889677695, 0.9343093053591018], 
             UndirectedEdge[186, 228] -> 
             RGBColor[
              0.20522346006975262`, 0.3330332468251766, 0.934998544498846], 
             UndirectedEdge[298, 396] -> 
             RGBColor[
              0.19827776691556012`, 0.32573288293773905`, 0.9346029975489469],
              UndirectedEdge[86, 93] -> 
             RGBColor[
              0.32267144519324537`, 0.4470223501983363, 0.9420332704147207], 
             UndirectedEdge[249, 266] -> 
             RGBColor[
              0.270914372535644, 0.40204801259274037`, 0.9387406633049027], 
             UndirectedEdge[156, 364] -> 
             RGBColor[
              0.8243314936689592, 0.18802809923393973`, 0.1709331718568741], 
             UndirectedEdge[10, 311] -> 
             RGBColor[
              0.2701224968687157, 0.40124624933748154`, 0.9386944486350258], 
             UndirectedEdge[27, 73] -> 
             RGBColor[
              0.8758267768621938, 0.46266728317359945`, 0.2154046022710305], 
             UndirectedEdge[56, 213] -> 
             RGBColor[
              0.30213444608884904`, 0.4281523269825127, 0.9407642849001527], 
             UndirectedEdge[27, 243] -> 
             RGBColor[
              0.8952822164694654, 0.5697539750088114, 0.5521239626729255], 
             UndirectedEdge[109, 157] -> 
             RGBColor[
              0.18435836126610156`, 0.3111027050588667, 0.9338103079891256], 
             UndirectedEdge[12, 241] -> 
             RGBColor[
              0.28584467655013013`, 0.4177712570264148, 0.9395898035090018], 
             UndirectedEdge[192, 382] -> 
             RGBColor[
              0.18175632170203998`, 0.30836779649820095`, 0.9336621256853248],
              UndirectedEdge[140, 280] -> 
             RGBColor[
              0.2386176080728396, 0.36813261368769457`, 0.936900291825407], 
             UndirectedEdge[199, 361] -> 
             RGBColor[
              0.2020628988707439, 0.32971129661386445`, 0.9348185552141937], 
             UndirectedEdge[16, 351] -> 
             RGBColor[
              0.6137824648944775, 0.6902841557450048, 0.9663635368138602], 
             UndirectedEdge[140, 322] -> 
             RGBColor[
              0.21280212927241615`, 0.34099890867255667`, 0.9354301384983013],
              UndirectedEdge[57, 238] -> 
             RGBColor[
              0.2538315033751126, 0.3841233822670593, 0.9377667006559303], 
             UndirectedEdge[49, 127] -> 
             RGBColor[
              0.19124100743417377`, 0.3183368025664821, 0.9342022645064347], 
             UndirectedEdge[165, 182] -> 
             RGBColor[
              0.6226406331298818, 0.6984050769847048, 0.9667215385795859], 
             UndirectedEdge[253, 343] -> 
             RGBColor[
              0.18655690968294972`, 0.31341351884099494`, 0.9339355120690042],
              UndirectedEdge[104, 240] -> 
             RGBColor[
              0.825349023280818, 0.19584927771500635`, 0.17190755936232552`], 
             UndirectedEdge[312, 348] -> 
             RGBColor[
              0.31802432732292496`, 0.44933875099285125`, 0.9415049667672362],
              UndirectedEdge[242, 244] -> 
             RGBColor[
              0.9035194245465865, 0.684293372013093, 0.5795724587116564], 
             UndirectedEdge[41, 165] -> 
             RGBColor[
              0.8843102751860701, 0.9105890257431475, 0.9888274975519911], 
             UndirectedEdge[54, 297] -> 
             RGBColor[
              0.19576644813648575`, 0.3230933276741248, 0.9344599816596418], 
             UndirectedEdge[77, 145] -> 
             RGBColor[
              0.19003339190962826`, 0.3170675220829382, 0.934133492588819], 
             UndirectedEdge[69, 150] -> 
             RGBColor[
              0.217681081623926, 0.3461269969374395, 0.9357079876169566], 
             UndirectedEdge[106, 241] -> 
             RGBColor[
              0.24501597193591163`, 0.37485769978748307`, 0.9372646691818778],
              UndirectedEdge[139, 276] -> 
             RGBColor[
              0.20545840173873126`, 0.33328018541543536`, 0.9350119240793292],
              UndirectedEdge[313, 393] -> 
             RGBColor[
              0.200865233126181, 0.3284524739799347, 0.9347503499218286], 
             UndirectedEdge[209, 323] -> 
             RGBColor[
              0.36676678405368435`, 0.4920966869379023, 0.9445910330541359], 
             UndirectedEdge[8, 213] -> 
             RGBColor[
              0.230215374068607, 0.3593013330168411, 0.9364217970288573], 
             UndirectedEdge[160, 244] -> 
             RGBColor[
              0.7071944520529801, 0.7689833903419949, 0.9560284549892878], 
             UndirectedEdge[180, 284] -> 
             RGBColor[
              0.2675710150211928, 0.3985644801424423, 0.9385491455183885], 
             UndirectedEdge[24, 242] -> 
             RGBColor[
              0.8365301385898678, 0.28179222957633193`, 0.182614608009535], 
             UndirectedEdge[81, 192] -> 
             RGBColor[
              0.1805894919591846, 0.3071413844571813, 0.9335956764576392], 
             UndirectedEdge[124, 249] -> 
             RGBColor[
              0.30940302019566135`, 0.4424110778706867, 0.9409358647458874], 
             UndirectedEdge[195, 253] -> 
             RGBColor[
              0.1964706167173933, 0.3238334534995253, 0.9345000830186004], 
             UndirectedEdge[31, 81] -> 
             RGBColor[
              0.1880171511030766, 0.3149483251582018, 0.9340186706576468], 
             UndirectedEdge[172, 399] -> 
             RGBColor[
              0.8751896442741957, 0.46528659439177383`, 0.21510344124823602`],
              UndirectedEdge[124, 315] -> 
             RGBColor[
              0.2642878093777229, 0.3950226791099546, 0.9383655017096588], 
             UndirectedEdge[181, 370] -> 
             RGBColor[
              0.19100569805155482`, 0.318089477485873, 0.9341888639852036], 
             UndirectedEdge[244, 348] -> 
             RGBColor[
              0.6439525347584986, 0.7143776288115813, 0.9519514304959281], 
             UndirectedEdge[284, 367] -> 
             RGBColor[
              0.3258404306471927, 0.4536760993310988, 0.9420920701724073], 
             UndirectedEdge[148, 232] -> 
             RGBColor[
              0.3145355236290795, 0.4455942655029455, 0.9413091233699418], 
             UndirectedEdge[34, 211] -> 
             RGBColor[
              0.2425688344221679, 0.3722856031030586, 0.9371253083206856], 
             UndirectedEdge[355, 392] -> 
             RGBColor[
              0.8783955245201162, 0.9037382421614023, 0.8873541737699352], 
             UndirectedEdge[262, 338] -> 
             RGBColor[
              0.22417589206845978`, 0.35295345450941085`, 0.9360778574635618],
              UndirectedEdge[87, 119] -> 
             RGBColor[
              0.19029746556308325`, 0.3173450802359561, 0.9341485311927212], 
             UndirectedEdge[180, 367] -> 
             RGBColor[
              0.31681274319178854`, 0.44418742742702483`, 0.9415779567270888],
              UndirectedEdge[69, 380] -> 
             RGBColor[
              0.2309702581422837, 0.36009476404068996`, 0.9364647865601021], 
             UndirectedEdge[124, 338] -> 
             RGBColor[
              0.2719649687624893, 0.40309186038336303`, 0.9388027045792817], 
             UndirectedEdge[249, 293] -> 
             RGBColor[
              0.3289853537057845, 0.45937231092045516`, 0.9421836337211749], 
             UndirectedEdge[212, 373] -> 
             RGBColor[
              0.34459378761093823`, 0.4694803712160838, 0.9433030893613046], 
             UndirectedEdge[287, 292] -> 
             RGBColor[
              0.19215895018442095`, 0.31930161859792383`, 0.9342545399880867],
              UndirectedEdge[12, 323] -> 
             RGBColor[
              0.35358359064672407`, 0.4806531148021672, 0.943751925265087], 
             UndirectedEdge[120, 307] -> 
             RGBColor[
              0.43332684059947457`, 0.5479832712777266, 0.9493196875555654], 
             UndirectedEdge[99, 398] -> 
             RGBColor[
              0.695865579228825, 0.7586878991813948, 0.9457116225314874], 
             UndirectedEdge[134, 350] -> 
             RGBColor[
              0.9124093272037948, 0.929890258170909, 0.8676584254872136], 
             UndirectedEdge[45, 280] -> 
             RGBColor[
              0.26817273037966816`, 0.3991969211351571, 0.9385834123178955], 
             UndirectedEdge[188, 330] -> 
             RGBColor[
              0.19385743072413472`, 0.32108682933504906`, 0.9343512659421467],
              UndirectedEdge[236, 284] -> 
             RGBColor[
              0.26368702808225786`, 0.3944821636106265, 0.9383279582080599], 
             UndirectedEdge[374, 389] -> 
             RGBColor[
              0.19643386923101253`, 0.3237948295614139, 0.9344979903036141], 
             UndirectedEdge[278, 319] -> 
             RGBColor[
              0.35576382875700985`, 0.4778888141834562, 0.9440614916187484], 
             UndirectedEdge[78, 242] -> 
             RGBColor[
              0.8361055023873913, 0.2785282896473279, 0.1822079759024856], 
             UndirectedEdge[84, 189] -> 
             RGBColor[
              0.30274052812538393`, 0.4327476737390883, 0.9406538670324976], 
             UndirectedEdge[223, 385] -> 
             RGBColor[
              0.9621637338718393, 0.8751385282482187, 0.44853214930663265`], 
             UndirectedEdge[175, 278] -> 
             RGBColor[
              0.2699086210585896, 0.40102145230052944`, 0.93868226872404], 
             UndirectedEdge[151, 168] -> 
             RGBColor[
              0.18811217327033666`, 0.31504819948074547`, 0.9340240820294996],
              UndirectedEdge[322, 339] -> 
             RGBColor[
              0.22572644107219014`, 0.3545831798228164, 0.9361661589354925], 
             UndirectedEdge[177, 367] -> 
             RGBColor[
              0.6349673392184779, 0.7091470859540894, 0.9674769538091501], 
             UndirectedEdge[294, 320] -> 
             RGBColor[
              0.19287620932606772`, 0.32005550343265077`, 0.9342953868351136],
              UndirectedEdge[179, 279] -> 
             RGBColor[
              0.5630911384213583, 0.6557241290001397, 0.9590606413690353], 
             UndirectedEdge[18, 285] -> 
             RGBColor[
              0.7996696633612428, 0.8401599138816065, 0.7860186576407228], 
             UndirectedEdge[121, 296] -> 
             RGBColor[
              0.27793336964590865`, 0.4092562484883108, 0.9391465791356984], 
             UndirectedEdge[212, 351] -> 
             RGBColor[
              0.6635629227613954, 0.7334014863107667, 0.9695355035700097], 
             UndirectedEdge[29, 87] -> 
             RGBColor[
              0.18980864714848175`, 0.31683130108933233`, 0.9341206937071518],
              UndirectedEdge[99, 141] -> 
             RGBColor[
              0.9156172249259522, 0.7282421342221813, 0.5763077730258106], 
             UndirectedEdge[121, 274] -> 
             RGBColor[
              0.4019923332344326, 0.5215276967163304, 0.9471338679528571], 
             UndirectedEdge[138, 218] -> 
             RGBColor[
              0.18655648275495362`, 0.3134130701126022, 0.9339354877560864], 
             UndirectedEdge[61, 388] -> 
             RGBColor[
              0.2144393921406435, 0.3427197757555252, 0.9355233781965335], 
             UndirectedEdge[283, 347] -> 
             RGBColor[
              0.20341579469893528`, 0.33113327590784336`, 0.9348956006301792],
              UndirectedEdge[253, 315] -> 
             RGBColor[
              0.20496946088804507`, 0.3327662775807237, 0.9349840796212059], 
             UndirectedEdge[321, 366] -> 
             RGBColor[
              0.4743804722974104, 0.5825626858071993, 0.9522061384174323], 
             UndirectedEdge[164, 391] -> 
             RGBColor[
              0.1910397493801938, 0.3181252675912516, 0.9341908031579952], 
             UndirectedEdge[74, 91] -> 
             RGBColor[
              0.6781789401773193, 0.7465825501677249, 0.9700269954109155], 
             UndirectedEdge[91, 285] -> 
             RGBColor[
              0.7437484336984672, 0.7947605404186777, 0.7816163335954551], 
             UndirectedEdge[51, 183] -> 
             RGBColor[
              0.36578243486715545`, 0.4912440931473596, 0.9445283111943961], 
             UndirectedEdge[30, 54] -> 
             RGBColor[
              0.1824115228296057, 0.3090564544254234, 0.9336994384202565], 
             UndirectedEdge[68, 250] -> 
             RGBColor[
              0.2641868760172087, 0.3950075354824494, 0.9383564238084967], 
             UndirectedEdge[32, 230] -> 
             RGBColor[
              0.8873852814687854, 0.5020359351465393, 0.22609917901526383`], 
             UndirectedEdge[275, 318] -> 
             RGBColor[
              0.21657038683237403`, 0.3449595862894012, 0.9356447351917034], 
             UndirectedEdge[131, 186] -> 
             RGBColor[
              0.21005402739966472`, 0.3381104793645726, 0.9352736381621005], 
             UndirectedEdge[192, 292] -> 
             RGBColor[
              0.18800332047098128`, 0.31493378828695684`, 0.9340178830236096],
              UndirectedEdge[144, 200] -> 
             RGBColor[
              0.18738223875410484`, 0.31428099202366444`, 0.9339825133386415],
              UndirectedEdge[139, 318] -> 
             RGBColor[
              0.19122506102961745`, 0.318320041884233, 0.9342013563822857], 
             UndirectedEdge[93, 148] -> 
             RGBColor[
              0.2841492261294814, 0.41365634022833114`, 0.9395786686798384], 
             UndirectedEdge[92, 311] -> 
             RGBColor[
              0.40006723340595274`, 0.5191882673765618, 0.947063870354397], 
             UndirectedEdge[334, 370] -> 
             RGBColor[
              0.18603433510834283`, 0.3128642598299414, 0.93390575222006], 
             UndirectedEdge[62, 129] -> 
             RGBColor[
              0.19509705711799047`, 0.3223897552718444, 0.9344218608314138], 
             UndirectedEdge[97, 191] -> 
             RGBColor[
              0.2000566789628183, 0.32760263228894565`, 0.9347043039583738], 
             UndirectedEdge[120, 366] -> 
             RGBColor[
              0.4563492884558704, 0.567924158469062, 0.9507866575750236], 
             UndirectedEdge[91, 288] -> 
             RGBColor[
              0.3993345066316525, 0.518907640464429, 0.9469775839135208], 
             UndirectedEdge[21, 32] -> 
             RGBColor[
              0.9601171751337108, 0.8771280081727125, 0.29956318594431774`], 
             UndirectedEdge[121, 178] -> 
             RGBColor[
              0.376298213208635, 0.5003523318083618, 0.9451983672915776], 
             UndirectedEdge[294, 381] -> 
             RGBColor[
              0.19306159004241835`, 0.32025035031935156`, 0.9343059439926636],
              UndirectedEdge[46, 149] -> 
             RGBColor[
              0.20894845482391827`, 0.3369484524901131, 0.9352106774394597], 
             UndirectedEdge[66, 232] -> 
             RGBColor[
              0.25468181299552817`, 0.38501711159085983`, 0.9378151245308926],
              UndirectedEdge[114, 261] -> 
             RGBColor[
              0.25063032461803525`, 0.380758740426915, 0.9375843982614342], 
             UndirectedEdge[189, 395] -> 
             RGBColor[
              0.3676410779096787, 0.4885452690238077, 0.9449042144225828], 
             UndirectedEdge[54, 290] -> 
             RGBColor[
              0.19141480754021284`, 0.3185194774974923, 0.9342121621653594], 
             UndirectedEdge[4, 309] -> 
             RGBColor[
              0.2652076930566547, 0.39608047891444564`, 0.9384145578287296], 
             UndirectedEdge[195, 315] -> 
             RGBColor[
              0.21034714004508412`, 0.3384185593393235, 0.9352903304936357], 
             UndirectedEdge[181, 305] -> 
             RGBColor[
              0.18857843384879308`, 0.3155382689113313, 0.9340506348796719], 
             UndirectedEdge[153, 372] -> 
             RGBColor[
              0.18825648302408265`, 0.31519987818169937`, 0.9340323002564883],
              UndirectedEdge[175, 227] -> 
             RGBColor[
              0.24456047357150879`, 0.37437894212623135`, 0.9372387292238745],
              UndirectedEdge[271, 287] -> 
             RGBColor[
              0.18451611233351262`, 0.31126851143271117`, 0.9338192916790429],
              UndirectedEdge[232, 297] -> 
             RGBColor[
              0.25100667694524614`, 0.38115431058492943`, 0.9376058309697055],
              UndirectedEdge[21, 25] -> 
             RGBColor[
              0.890260551987202, 0.5108305987640545, 0.23788277597524127`], 
             UndirectedEdge[123, 297] -> 
             RGBColor[
              0.20930917766859286`, 0.3373275950710155, 0.9352312200718224], 
             UndirectedEdge[6, 178] -> 
             RGBColor[
              0.37363938184973156`, 0.4977574548464476, 0.9450396379279142], 
             UndirectedEdge[90, 319] -> 
             RGBColor[
              0.530870221387825, 0.6300233870103961, 0.956211194950797], 
             UndirectedEdge[258, 302] -> 
             RGBColor[
              0.18739149065206478`, 0.3142907163550246, 0.9339830402205433], 
             UndirectedEdge[253, 397] -> 
             RGBColor[
              0.20200814651583682`, 0.3296537484173573, 0.9348154371485806], 
             UndirectedEdge[169, 177] -> 
             RGBColor[
              0.8953206105495907, 0.9193683682944271, 0.9898776731680061], 
             UndirectedEdge[198, 332] -> 
             RGBColor[
              0.29082644977848415`, 0.41888733476416706`, 0.9400243645014585],
              UndirectedEdge[45, 123] -> 
             RGBColor[
              0.24825361468381962`, 0.37826066759394095`, 0.9374490481467079],
              UndirectedEdge[223, 245] -> 
             RGBColor[
              0.8743661025414482, 0.452767023574467, 0.2140604082418407], 
             UndirectedEdge[380, 381] -> 
             RGBColor[
              0.20814382827755723`, 0.3361027389736181, 0.9351648551479828], 
             UndirectedEdge[277, 378] -> 
             RGBColor[
              0.19931695292516527`, 0.3268251333220326, 0.934662177654856], 
             UndirectedEdge[119, 326] -> 
             RGBColor[
              0.18721381086797456`, 0.3141039636363968, 0.933972921619693], 
             UndirectedEdge[89, 133] -> 
             RGBColor[
              0.1875161010871107, 0.31442168982301577`, 0.9339901366004746], 
             UndirectedEdge[22, 346] -> 
             RGBColor[
              0.3336708932604665, 0.46343068978065516`, 0.9424821921583393], 
             UndirectedEdge[73, 243] -> 
             RGBColor[
              0.9500707567190481, 0.8697065757980069, 0.5997490197634427], 
             UndirectedEdge[26, 353] -> 
             RGBColor[
              0.1885101327336185, 0.315466480108742, 0.9340467452322052], 
             UndirectedEdge[21, 230] -> 
             RGBColor[
              0.8904702103094787, 0.5124421245019355, 0.2380835450214286], 
             UndirectedEdge[107, 390] -> 
             RGBColor[
              0.30566480118721207`, 0.43491696287761505`, 0.9408535111759078],
              UndirectedEdge[223, 364] -> 
             RGBColor[
              0.8737896349062411, 0.4483360407205369, 0.2135083821833393], 
             UndirectedEdge[2, 211] -> 
             RGBColor[
              0.2034376502421772, 0.3311562474695121, 0.9348968452710344], 
             UndirectedEdge[128, 353] -> 
             RGBColor[
              0.19231632365158768`, 0.3194670280899702, 0.9342635021742287], 
             UndirectedEdge[259, 331] -> 
             RGBColor[
              0.19269223822101744`, 0.31986213813680114`, 0.934284909952842], 
             UndirectedEdge[2, 334] -> 
             RGBColor[
              0.18498335204934083`, 0.3117596099987556, 0.93384590028964], 
             UndirectedEdge[72, 191] -> 
             RGBColor[
              0.19501894918374685`, 0.32230765888062524`, 0.934417412700109], 
             UndirectedEdge[247, 301] -> 
             RGBColor[
              0.1901623548072361, 0.317203070265044, 0.9341408368350541], 
             UndirectedEdge[247, 397] -> 
             RGBColor[
              0.20527567361963986`, 0.3330881265766384, 0.935001517983269], 
             UndirectedEdge[125, 263] -> 
             RGBColor[
              0.326732269165051, 0.4530536866427142, 0.9421999706648885], 
             UndirectedEdge[123, 325] -> 
             RGBColor[
              0.2504184772778667, 0.38053607544050067`, 0.9375723338688118], 
             UndirectedEdge[129, 393] -> 
             RGBColor[
              0.18622578456981498`, 0.3130654853525456, 0.9339166549836668], 
             UndirectedEdge[19, 205] -> 
             RGBColor[
              0.30521095643223367`, 0.4343105926394541, 0.9408324015485454], 
             UndirectedEdge[277, 352] -> 
             RGBColor[
              0.22370886564436498`, 0.3524625801265016, 0.9360512609996132], 
             UndirectedEdge[139, 224] -> 
             RGBColor[
              0.18369701044953324`, 0.3104075834185898, 0.9337726450385029], 
             UndirectedEdge[65, 250] -> 
             RGBColor[
              0.2731468584894696, 0.40442504515649597`, 0.9388666815551856], 
             UndirectedEdge[58, 117] -> 
             RGBColor[
              0.2190498578943207, 0.34756566758305235`, 0.9357859374006325], 
             UndirectedEdge[134, 272] -> 
             RGBColor[0.7859507335711424, 0.832798734683, 0.9792763222925633],
              UndirectedEdge[74, 95] -> 
             RGBColor[
              0.7112349833542422, 0.7734189351765257, 0.9726292882180788], 
             UndirectedEdge[156, 245] -> 
             RGBColor[
              0.8249079613041663, 0.19245908208786985`, 0.17148519791537548`],
              UndirectedEdge[221, 324] -> 
             RGBColor[
              0.7677190036317167, 0.6811645798747406, 0.602228741750033], 
             UndirectedEdge[227, 375] -> 
             RGBColor[
              0.1940331226429612, 0.32127149268124666`, 0.9343612713370109], 
             UndirectedEdge[132, 348] -> 
             RGBColor[
              0.34570653122762846`, 0.47385535445905747`, 0.94324909236691], 
             UndirectedEdge[137, 319] -> 
             RGBColor[
              0.3939126281591366, 0.5156078641515458, 0.9463210706392715], 
             UndirectedEdge[128, 170] -> 
             RGBColor[
              0.21313809335858236`, 0.34135202822847077`, 0.9354492711559941],
              UndirectedEdge[120, 220] -> 
             RGBColor[
              0.5770608462863022, 0.6675230171669182, 0.9598474901446392], 
             UndirectedEdge[292, 371] -> 
             RGBColor[
              0.1904665323376698, 0.31752278013549917`, 0.934158159295422], 
             UndirectedEdge[143, 378] -> 
             RGBColor[
              0.18793083673403851`, 0.31485760328369566`, 0.9340137551820207],
              UndirectedEdge[59, 373] -> 
             RGBColor[
              0.3091816453180559, 0.4388081534280127, 0.9410466589681301], 
             UndirectedEdge[2, 340] -> 
             RGBColor[
              0.19396024281710603`, 0.32119489136342505`, 0.9343571209387445],
              UndirectedEdge[131, 322] -> 
             RGBColor[
              0.206580775656939, 0.33445987156608825`, 0.9350758416135677], 
             UndirectedEdge[62, 317] -> 
             RGBColor[
              0.19822991985182326`, 0.32568259264007254`, 0.9346002727294505],
              UndirectedEdge[243, 337] -> 
             RGBColor[
              0.981786507894951, 0.983234170680865, 0.764939800713467], 
             UndirectedEdge[21, 217] -> 
             RGBColor[
              0.9781358461419554, 0.9375595363156388, 0.3992965964312667], 
             UndirectedEdge[24, 74] -> 
             RGBColor[
              0.8419234511371824, 0.5272135480684979, 0.5771697251114055], 
             UndirectedEdge[1, 127] -> 
             RGBColor[
              0.19417547404882396`, 0.3214211130344089, 0.9343693780389848], 
             UndirectedEdge[226, 355] -> 
             RGBColor[
              0.6054737407452027, 0.6884810215092875, 0.963436744212341], 
             UndirectedEdge[97, 370] -> 
             RGBColor[
              0.18998864922989284`, 0.31702049468968657`, 0.9341309445593988],
              UndirectedEdge[148, 257] -> 
             RGBColor[
              0.3285413065471964, 0.4589876995901452, 0.9421553394288851], 
             UndirectedEdge[48, 344] -> 
             RGBColor[
              0.21571874970997718`, 0.3440644616768498, 0.9355962357174672], 
             UndirectedEdge[74, 148] -> 
             RGBColor[
              0.5985191344063026, 0.6786707763192633, 0.9646512034079422], 
             UndirectedEdge[266, 293] -> 
             RGBColor[
              0.2908233203898157, 0.4192921425712095, 0.940009243857379], 
             UndirectedEdge[84, 226] -> 
             RGBColor[
              0.39203908397867687`, 0.5139862829102032, 0.9462013616579391], 
             UndirectedEdge[354, 371] -> 
             RGBColor[
              0.20120013846367035`, 0.3288044807238608, 0.9347694222853504], 
             UndirectedEdge[57, 188] -> 
             RGBColor[
              0.20973271485913975`, 0.33777275951208907`, 0.9352553398882568],
              UndirectedEdge[134, 355] -> 
             RGBColor[
              0.7983376603764013, 0.8424754960473988, 0.9805109353940992], 
             UndirectedEdge[151, 378] -> 
             RGBColor[
              0.19141895458300517`, 0.3185238363024048, 0.9342123983333115], 
             UndirectedEdge[167, 238] -> 
             RGBColor[
              0.3001182809431252, 0.43263426016352036`, 0.9404077704799216], 
             UndirectedEdge[41, 311] -> 
             RGBColor[
              0.5873075100595555, 0.6681019111801583, 0.9640966123738608], 
             UndirectedEdge[212, 295] -> 
             RGBColor[
              0.42318563987531466`, 0.5409638641564534, 0.9481859926578549], 
             UndirectedEdge[179, 285] -> 
             RGBColor[
              0.7240735565365042, 0.7787875887954807, 0.7800674551938157], 
             UndirectedEdge[85, 348] -> 
             RGBColor[
              0.28694246093137055`, 0.4166697387111759, 0.9397349004577378], 
             UndirectedEdge[108, 152] -> 
             RGBColor[
              0.2564614085339687, 0.38688757933463486`, 0.9379164698641311], 
             UndirectedEdge[86, 148] -> 
             RGBColor[
              0.37250043656006593`, 0.49706288855717573`, 0.9449563763217728],
              UndirectedEdge[113, 293] -> 
             RGBColor[
              0.32820995463660485`, 0.4585878656141067, 0.9421383573691648], 
             UndirectedEdge[229, 260] -> 
             RGBColor[
              0.21573241152320438`, 0.34407882110876054`, 0.9355970137375196],
              UndirectedEdge[6, 278] -> 
             RGBColor[
              0.28187720037590647`, 0.4136011880147874, 0.9393638616102349], 
             UndirectedEdge[142, 378] -> 
             RGBColor[
              0.18665371404405717`, 0.3135152663622699, 0.93394102493416], 
             UndirectedEdge[289, 303] -> 
             RGBColor[
              0.19970158242580874`, 0.32722940331412775`, 0.9346840817359092],
              UndirectedEdge[5, 213] -> 
             RGBColor[
              0.25252900688278906`, 0.3827543758705798, 0.9376925254075633], 
             UndirectedEdge[104, 243] -> 
             RGBColor[
              0.8942676597098645, 0.5619556471729128, 0.5511524219741538], 
             UndirectedEdge[121, 373] -> 
             RGBColor[
              0.2913786665893785, 0.4233881080569608, 0.9399122689060947], 
             UndirectedEdge[120, 202] -> 
             RGBColor[
              0.38082926485589774`, 0.49646706771580507`, 0.9461959416990309],
              UndirectedEdge[270, 351] -> 
             RGBColor[
              0.6344443344456173, 0.7081804286544429, 0.9676800928710849], 
             UndirectedEdge[91, 125] -> 
             RGBColor[
              0.37740486226419223`, 0.49585819381446866`, 0.9457287231087954],
              UndirectedEdge[280, 297] -> 
             RGBColor[
              0.22922829336444137`, 0.3582638486122316, 0.9363655842430101], 
             UndirectedEdge[33, 281] -> 
             RGBColor[
              0.3526148324525338, 0.4768614731328931, 0.9437983042422098], 
             UndirectedEdge[16, 241] -> 
             RGBColor[
              0.29049437153587576`, 0.42182354173579545`, 0.9398851643245274],
              UndirectedEdge[89, 342] -> 
             RGBColor[
              0.18647972709604152`, 0.31333239504849575`, 0.9339311166348612],
              UndirectedEdge[157, 370] -> 
             RGBColor[
              0.18724094908895864`, 0.3141324876273136, 0.9339744671012307], 
             UndirectedEdge[90, 122] -> 
             RGBColor[
              0.6031707449782447, 0.6887202091625689, 0.9619029570133792], 
             UndirectedEdge[135, 156] -> 
             RGBColor[
              0.9129140627520606, 0.6152764832633987, 0.4286476247419544], 
             UndirectedEdge[12, 22] -> 
             RGBColor[
              0.3123757406994519, 0.44496094634460026`, 0.9411261975051177], 
             UndirectedEdge[271, 384] -> 
             RGBColor[
              0.18432884103510522`, 0.31107167742439884`, 0.9338086268556416],
              UndirectedEdge[158, 324] -> 
             RGBColor[
              0.4859428845919035, 0.5904387279012617, 0.9535338248669657], 
             UndirectedEdge[301, 397] -> 
             RGBColor[
              0.19781003665891564`, 0.3252412687821946, 0.934576361002776], 
             UndirectedEdge[95, 233] -> 
             RGBColor[
              0.7594081345567827, 0.8112195509449376, 0.9560282891124947], 
             UndirectedEdge[123, 203] -> 
             RGBColor[
              0.21872743662810462`, 0.3472267823895703, 0.935767575986501], 
             UndirectedEdge[103, 145] -> 
             RGBColor[
              0.1958024601948291, 0.32313117863074003`, 0.9344620324930895], 
             UndirectedEdge[20, 80] -> 
             RGBColor[
              0.18504810846190303`, 0.31182767309415216`, 0.933849588071537], 
             UndirectedEdge[73, 337] -> 
             RGBColor[
              0.9623310682876794, 0.8761474788456531, 0.428220440311572], 
             UndirectedEdge[122, 166] -> 
             RGBColor[
              0.7938288566186125, 0.8372493846021647, 0.890969402038376], 
             UndirectedEdge[62, 216] -> 
             RGBColor[
              0.2004082229571123, 0.32797212731612524`, 0.934724323868786], 
             UndirectedEdge[128, 342] -> 
             RGBColor[
              0.18916310762939384`, 0.3161527981252015, 0.9340839311865298], 
             UndirectedEdge[280, 309] -> 
             RGBColor[
              0.27456630331146203`, 0.4059169716624097, 0.9389475168379178], 
             UndirectedEdge[104, 141] -> 
             RGBColor[
              0.8423033289137494, 0.3148548235404699, 0.18770004553512668`], 
             UndirectedEdge[148, 276] -> 
             RGBColor[
              0.27841767131860123`, 0.407632112720532, 0.9392522651124343], 
             UndirectedEdge[359, 394] -> 
             RGBColor[
              0.18381809529055626`, 0.3105348512637273, 0.9337795406410702], 
             UndirectedEdge[8, 43] -> 
             RGBColor[
              0.24908603513269617`, 0.379135594264215, 0.9374964532598158], 
             UndirectedEdge[56, 352] -> 
             RGBColor[
              0.31062641380180694`, 0.4370779234706822, 0.9412478898986653], 
             UndirectedEdge[70, 152] -> 
             RGBColor[
              0.2398425593336916, 0.3694201151292457, 0.9369700509875596], 
             UndirectedEdge[359, 397] -> 
             RGBColor[
              0.20006364261390616`, 0.32760995152775996`, 0.9347047005280014],
              UndirectedEdge[118, 241] -> 
             RGBColor[
              0.25104726308957875`, 0.38119696919593304`, 0.9376081422905835],
              UndirectedEdge[43, 227] -> 
             RGBColor[
              0.23391469744368304`, 0.36318955643469497`, 0.9366324680224093],
              UndirectedEdge[234, 246] -> 
             RGBColor[
              0.8529840469746812, 0.885887262707637, 0.9857660876177745], 
             UndirectedEdge[196, 317] -> 
             RGBColor[
              0.1925447584771704, 0.3197071275752621, 0.9342765111996065], 
             UndirectedEdge[46, 184] -> 
             RGBColor[
              0.19220194755564052`, 0.3193468115612663, 0.9342569886247687], 
             UndirectedEdge[136, 331] -> 
             RGBColor[
              0.19186850922797938`, 0.3189963467376835, 0.9342379998052863], 
             UndirectedEdge[106, 320] -> 
             RGBColor[
              0.21130568150236095`, 0.33942604718596003`, 0.9353449180115927],
              UndirectedEdge[68, 161] -> 
             RGBColor[
              0.23474066997997348`, 0.36405770594001974`, 0.9366795059364341],
              UndirectedEdge[45, 297] -> 
             RGBColor[
              0.2458649611438621, 0.37575004127406386`, 0.9373130178613036], 
             UndirectedEdge[140, 203] -> 
             RGBColor[
              0.22572809779654535`, 0.3545849211451561, 0.9361662532834936], 
             UndirectedEdge[225, 243] -> 
             RGBColor[
              0.9271182354136238, 0.9438506209861709, 0.9626670150045318], 
             UndirectedEdge[107, 373] -> 
             RGBColor[
              0.31023491732991126`, 0.43972044470569116`, 0.9411137725293536],
              UndirectedEdge[187, 321] -> 
             RGBColor[
              0.494640933100008, 0.6001112786340405, 0.9534971170641517], 
             UndirectedEdge[297, 322] -> 
             RGBColor[
              0.2034128145640179, 0.33113014359709375`, 0.9348954309159043], 
             UndirectedEdge[106, 374] -> 
             RGBColor[
              0.2085188963433679, 0.336496959291474, 0.9351862147194673], 
             UndirectedEdge[154, 383] -> 
             RGBColor[
              0.20693321063768522`, 0.33483030307652095`, 0.9350959122643404],
              UndirectedEdge[111, 151] -> 
             RGBColor[
              0.1906348725141942, 0.31769971633440997`, 0.9341677460194382], 
             UndirectedEdge[79, 227] -> 
             RGBColor[
              0.21925675873838124`, 0.34778313348843115`, 0.9357977200976195],
              UndirectedEdge[93, 290] -> 
             RGBColor[
              0.21626873884937514`, 0.3446425351336826, 0.9356275567853198], 
             UndirectedEdge[150, 283] -> 
             RGBColor[
              0.2012631111576979, 0.32887066901798323`, 0.9347730084871156], 
             UndirectedEdge[46, 195] -> 
             RGBColor[
              0.2015708688653357, 0.3291941418816762, 0.9347905348332788], 
             UndirectedEdge[73, 177] -> 
             RGBColor[
              0.912733918365472, 0.8408075046276462, 0.6264313427993702], 
             UndirectedEdge[102, 189] -> 
             RGBColor[
              0.27205731447598563`, 0.4032798653172439, 0.9388046336354536], 
             UndirectedEdge[3, 95] -> 
             RGBColor[
              0.5706393994295823, 0.6623097973257487, 0.9593419703255434], 
             UndirectedEdge[39, 294] -> 
             RGBColor[
              0.18656769797512113`, 0.31342485802008435`, 0.9339361264462835],
              UndirectedEdge[5, 227] -> 
             RGBColor[
              0.24495455926499354`, 0.3747931511765599, 0.937261171821121], 
             UndirectedEdge[166, 169] -> 
             RGBColor[
              0.9427417968791698, 0.9548740993356628, 0.9051840770091248], 
             UndirectedEdge[27, 337] -> 
             RGBColor[
              0.9075425280380967, 0.5761948780564576, 0.3805953832210548], 
             UndirectedEdge[84, 174] -> 
             RGBColor[
              0.3414171398675645, 0.4701400992540484, 0.9429757761424066], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.313125811057198, 0.4456106195888476, 0.9411739913250522], 
             UndirectedEdge[138, 349] -> 
             RGBColor[
              0.19211902352341417`, 0.31925965314570914`, 0.9342522662238085],
              UndirectedEdge[26, 159] -> 
             RGBColor[
              0.18375580691440718`, 0.3104693822310835, 0.9337759934101959], 
             UndirectedEdge[81, 287] -> 
             RGBColor[
              0.1847451216726243, 0.31150921476814825`, 0.9338323334221164], 
             UndirectedEdge[311, 361] -> 
             RGBColor[
              0.2601900040751639, 0.39080656965504246`, 0.9381288078642394], 
             UndirectedEdge[231, 393] -> 
             RGBColor[
              0.18277810360197083`, 0.30944175405974256`, 0.933720314652935], 
             UndirectedEdge[201, 223] -> 
             RGBColor[
              0.9394729571932308, 0.8606549580209606, 0.6167978110210142], 
             UndirectedEdge[180, 267] -> 
             RGBColor[
              0.25726504669656514`, 0.3877322539971262, 0.9379622358686148], 
             UndirectedEdge[217, 264] -> 
             RGBColor[
              0.8581806271651595, 0.8856725444548357, 0.7300501263511203], 
             UndirectedEdge[163, 174] -> 
             RGBColor[
              0.3053955889489409, 0.4350613598921163, 0.9408225323352425], 
             UndirectedEdge[203, 280] -> 
             RGBColor[
              0.23864655232395315`, 0.36816303593078636`, 0.9369019401576887],
              UndirectedEdge[40, 163] -> 
             RGBColor[
              0.3939273213258807, 0.5099037447255685, 0.9469719144794696], 
             UndirectedEdge[14, 62] -> 
             RGBColor[
              0.1928274082051604, 0.3200042103604074, 0.9342926076834728], 
             UndirectedEdge[49, 133] -> 
             RGBColor[
              0.18673252269027052`, 0.31359809924619686`, 0.933945512969975], 
             UndirectedEdge[276, 288] -> 
             RGBColor[
              0.2641141546829352, 0.39493110074932897`, 0.9383522824360913], 
             UndirectedEdge[312, 366] -> 
             RGBColor[
              0.3486542052668462, 0.4758688117654473, 0.9434566755048852], 
             UndirectedEdge[23, 120] -> 
             RGBColor[
              0.40567769043424073`, 0.5225843384798207, 0.9476110227757661], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.18052420551329257`, 0.307072764263149, 0.9335919584911282], 
             UndirectedEdge[73, 399] -> 
             RGBColor[
              0.9285956897332439, 0.7546127344078406, 0.2614046197660328], 
             UndirectedEdge[269, 272] -> 
             RGBColor[
              0.7422573926850033, 0.7985763836214297, 0.9749449381792838], 
             UndirectedEdge[20, 151] -> 
             RGBColor[
              0.19115376674236922`, 0.3182451070680162, 0.9341972962780976], 
             UndirectedEdge[239, 355] -> 
             RGBColor[
              0.7967350259379453, 0.5156495091253714, 0.57575064772341], 
             UndirectedEdge[274, 319] -> 
             RGBColor[
              0.47322013025663245`, 0.583220445923085, 0.9516727685977074], 
             UndirectedEdge[6, 352] -> 
             RGBColor[
              0.27259546821957914`, 0.40384549902267874`, 0.9388352806950242],
              UndirectedEdge[133, 342] -> 
             RGBColor[
              0.18475081584068775`, 0.311515199699814, 0.9338326576965637], 
             UndirectedEdge[290, 318] -> 
             RGBColor[
              0.1963038433293812, 0.3236581640946811, 0.9344905855208723], 
             UndirectedEdge[87, 298] -> 
             RGBColor[
              0.19758831891525655`, 0.325008229375892, 0.9345637345052766], 
             UndirectedEdge[86, 263] -> 
             RGBColor[
              0.4014876492319413, 0.5221701552338829, 0.9468034158808389], 
             UndirectedEdge[109, 191] -> 
             RGBColor[
              0.19427315985261398`, 0.3215237870078299, 0.9343749411009974], 
             UndirectedEdge[84, 238] -> 
             RGBColor[
              0.3144100017377778, 0.44501303039307516`, 0.9413184262912844], 
             UndirectedEdge[21, 244] -> 
             RGBColor[
              0.9589837634229517, 0.9266594522436353, 0.6365010356742713], 
             UndirectedEdge[137, 175] -> 
             RGBColor[
              0.3080574204607164, 0.43874050226861905`, 0.940941847744563], 
             UndirectedEdge[363, 369] -> 
             RGBColor[
              0.20524927327278905`, 0.33306037813821954`, 0.9350000145225716],
              UndirectedEdge[98, 290] -> 
             RGBColor[
              0.19961632362064485`, 0.32713979090418005`, 0.9346792263730843],
              UndirectedEdge[175, 352] -> 
             RGBColor[
              0.2606268889022622, 0.3912657633084208, 0.9381536878088295], 
             UndirectedEdge[121, 319] -> 
             RGBColor[
              0.3821339767558598, 0.5054057883182604, 0.9455705453873072], 
             UndirectedEdge[249, 387] -> 
             RGBColor[
              0.4216012233503626, 0.5373973944320252, 0.9486912790769737], 
             UndirectedEdge[310, 389] -> 
             RGBColor[
              0.24112387106664201`, 0.3707668550004327, 0.9370430197952202], 
             UndirectedEdge[228, 238] -> 
             RGBColor[
              0.24678874654536498`, 0.3767209983024208, 0.9373656260733012], 
             UndirectedEdge[268, 324] -> 
             RGBColor[
              0.6562462626397825, 0.7312424529611288, 0.9664688163111557], 
             UndirectedEdge[144, 368] -> 
             RGBColor[
              0.18786109875542928`, 0.31478430424653414`, 0.934009783707307], 
             UndirectedEdge[137, 278] -> 
             RGBColor[
              0.29631468313808673`, 0.42639814080998684`, 0.9402731162258624],
              UndirectedEdge[127, 298] -> 
             RGBColor[
              0.19590091614963856`, 0.32323466208171286`, 0.9344676394140633],
              UndirectedEdge[131, 228] -> 
             RGBColor[
              0.20842587898456535`, 0.33639919214973135`, 0.9351809175184903],
              UndirectedEdge[278, 314] -> 
             RGBColor[
              0.2454200867859244, 0.3752824501172079, 0.9372876829247517], 
             UndirectedEdge[182, 311] -> 
             RGBColor[
              0.32563786800336725`, 0.45591796242171545`, 0.9419906534014555],
              UndirectedEdge[77, 94] -> 
             RGBColor[
              0.18199794707454847`, 0.3086217600846408, 0.9336758858928365], 
             UndirectedEdge[144, 333] -> 
             RGBColor[
              0.1893313874669234, 0.316329670904003, 0.9340935144743294], 
             UndirectedEdge[166, 197] -> 
             RGBColor[
              0.9770032019247867, 0.9814553758280588, 0.8828706575837489], 
             UndirectedEdge[106, 384] -> 
             RGBColor[
              0.2081882862900271, 0.33614946716352473`, 0.9351673869660233], 
             UndirectedEdge[28, 265] -> 
             RGBColor[
              0.1984857219314811, 0.32595145684458154`, 0.9346148402794617], 
             UndirectedEdge[113, 266] -> 
             RGBColor[
              0.2701389734664643, 0.40126356728639195`, 0.9386953869528927], 
             UndirectedEdge[164, 292] -> 
             RGBColor[
              0.19766905263223078`, 0.3250930856312453, 0.9345683321710234], 
             UndirectedEdge[98, 248] -> 
             RGBColor[
              0.2095071320406308, 0.3375356576670594, 0.9352424932804627], 
             UndirectedEdge[91, 95] -> 
             RGBColor[
              0.5263538722152581, 0.6263568112928946, 0.9558556514000003], 
             UndirectedEdge[155, 342] -> 
             RGBColor[
              0.19539787597679303`, 0.32270593496546307`, 0.9344389920204009],
              UndirectedEdge[47, 209] -> 
             RGBColor[
              0.43947307837840166`, 0.5526061814054317, 0.9499049126595958], 
             UndirectedEdge[2, 360] -> 
             RGBColor[
              0.18511749831467772`, 0.3119006062289892, 0.9338535397209994], 
             UndirectedEdge[75, 341] -> 
             RGBColor[
              0.2771008643732843, 0.406039405513939, 0.9391849149556509], 
             UndirectedEdge[12, 390] -> 
             RGBColor[
              0.28559351861557547`, 0.41750727411286515`, 0.9395755004361839],
              UndirectedEdge[19, 198] -> 
             RGBColor[
              0.30685620721234774`, 0.43573562617248035`, 0.9409372354734161],
              UndirectedEdge[8, 56] -> 
             RGBColor[
              0.30973133616006665`, 0.43613714011801286`, 0.9411969165511169],
              UndirectedEdge[70, 154] -> 
             RGBColor[
              0.21421417432422896`, 0.3424830575508392, 0.9355105523750686], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.18749255911212426`, 0.3143969457146576, 0.9339887959198263], 
             UndirectedEdge[177, 243] -> 
             RGBColor[
              0.9321893579727436, 0.9478941964628581, 0.9631507032012652], 
             UndirectedEdge[109, 340] -> 
             RGBColor[
              0.19212863805325098`, 0.319269758626164, 0.9342528137570594], 
             UndirectedEdge[28, 36] -> 
             RGBColor[
              0.19993330434376533`, 0.3274729577419183, 0.9346972779563351], 
             UndirectedEdge[203, 339] -> 
             RGBColor[
              0.23865240959631934`, 0.3681691922954158, 0.9369022737206849], 
             UndirectedEdge[247, 369] -> 
             RGBColor[
              0.19411283179141248`, 0.32135527205012093`, 0.934365810655096], 
             UndirectedEdge[223, 230] -> 
             RGBColor[
              0.8738202331046678, 0.44857123188186093`, 0.21353768305270848`],
              UndirectedEdge[22, 173] -> 
             RGBColor[
              0.2993775960909632, 0.43129907223111097`, 0.940385972398696], 
             UndirectedEdge[69, 283] -> 
             RGBColor[
              0.22539830685763262`, 0.3542382899584056, 0.9361474721774046], 
             UndirectedEdge[59, 274] -> 
             RGBColor[
              0.41979531196311004`, 0.5369477420873823, 0.9482682580148925], 
             UndirectedEdge[31, 164] -> 
             RGBColor[
              0.19871454021211585`, 0.32619195936544565`, 0.9346278711420376],
              UndirectedEdge[116, 154] -> 
             RGBColor[
              0.19442534169189124`, 0.3216837397697962, 0.9343836076316113], 
             UndirectedEdge[10, 170] -> 
             RGBColor[
              0.2345826966210814, 0.3638916659237347, 0.936670509587346], 
             UndirectedEdge[301, 394] -> 
             RGBColor[
              0.18156448933556574`, 0.30816616851816203`, 0.9336512011158447],
              UndirectedEdge[90, 351] -> 
             RGBColor[
              0.7590840463718008, 0.8119268218437792, 0.9767853326782896], 
             UndirectedEdge[4, 203] -> 
             RGBColor[
              0.22928794206914588`, 0.35832654318282237`, 0.9363689811485005],
              UndirectedEdge[274, 351] -> 
             RGBColor[
              0.7014339552406084, 0.7651238807564681, 0.9722469063252], 
             UndirectedEdge[238, 269] -> 
             RGBColor[
              0.5167818424220354, 0.6108654129881752, 0.9574511707265], 
             UndirectedEdge[66, 325] -> 
             RGBColor[
              0.2517049597881912, 0.3818882501265539, 0.9376455971445944], 
             UndirectedEdge[128, 171] -> 
             RGBColor[
              0.19178726559275905`, 0.3189109545259229, 0.9342333731004496], 
             UndirectedEdge[198, 205] -> 
             RGBColor[
              0.35166297002886326`, 0.47901452236936815`, 0.9436286313802527],
              UndirectedEdge[202, 349] -> 
             RGBColor[
              0.22267250403179975`, 0.35137329836257414`, 0.9359922417389372],
              UndirectedEdge[295, 390] -> 
             RGBColor[
              0.34587288956677426`, 0.46974318811470905`, 0.943415535012837], 
             UndirectedEdge[250, 356] -> 
             RGBColor[
              0.22666963106636354`, 0.3555745323083922, 0.9362198722103361], 
             UndirectedEdge[133, 393] -> 
             RGBColor[
              0.18457522111446595`, 0.3113306385092063, 0.9338226578366745], 
             UndirectedEdge[124, 293] -> 
             RGBColor[
              0.3293119680498331, 0.45965520784915576`, 0.9422044452983639], 
             UndirectedEdge[45, 325] -> 
             RGBColor[
              0.2869742607531359, 0.4189585216435491, 0.9396541316582929], 
             UndirectedEdge[116, 304] -> 
             RGBColor[
              0.18211433978369124`, 0.30874409620167387`, 0.9336825142854346],
              UndirectedEdge[213, 296] -> 
             RGBColor[
              0.2337895217777734, 0.3630579888732283, 0.9366253394534165], 
             UndirectedEdge[248, 276] -> 
             RGBColor[
              0.22042799245848094`, 0.3490141743887628, 0.9358644201252941], 
             UndirectedEdge[209, 346] -> 
             RGBColor[
              0.34295446203942725`, 0.47147165045125694`, 0.9430737329517971],
              UndirectedEdge[31, 382] -> 
             RGBColor[
              0.18918398084593196`, 0.3161747371992214, 0.9340851198853325], 
             UndirectedEdge[69, 373] -> 
             RGBColor[
              0.25683371538447886`, 0.38727889744013877`, 0.937937672188489], 
             UndirectedEdge[166, 239] -> 
             RGBColor[
              0.9087289042908429, 0.6022050523179494, 0.4973324699831219], 
             UndirectedEdge[235, 317] -> 
             RGBColor[
              0.19343401255220036`, 0.32064178999008336`, 0.934327152903646], 
             UndirectedEdge[43, 59] -> 
             RGBColor[
              0.3034359716582913, 0.4327690861148492, 0.9407194513531689], 
             UndirectedEdge[94, 207] -> 
             RGBColor[
              0.18447193191249567`, 0.3112220750090219, 0.933816775669425], 
             UndirectedEdge[209, 270] -> 
             RGBColor[
              0.34697087401529814`, 0.4749504646340207, 0.9433296551713259], 
             UndirectedEdge[23, 341] -> 
             RGBColor[
              0.3146456284168403, 0.44550133299924655`, 0.9413230337254305], 
             UndirectedEdge[264, 312] -> 
             RGBColor[
              0.5131003370105822, 0.6097335825641022, 0.9568081018654329], 
             UndirectedEdge[48, 118] -> 
             RGBColor[
              0.23953466514577643`, 0.3690964988161278, 0.9369525168690463], 
             UndirectedEdge[106, 310] -> 
             RGBColor[
              0.2532088981789974, 0.38346898473049273`, 0.9377312442110733], 
             UndirectedEdge[267, 282] -> 
             RGBColor[
              0.2615646860965489, 0.39225144761939246`, 0.9382070939716974], 
             UndirectedEdge[43, 274] -> 
             RGBColor[
              0.3767191464303865, 0.4951636983486218, 0.9456872845015338], 
             UndirectedEdge[46, 362] -> 
             RGBColor[
              0.19522925834887567`, 0.3225287071475469, 0.9344293894959386], 
             UndirectedEdge[38, 117] -> 
             RGBColor[
              0.22453541604736282`, 0.35333133700637476`, 0.9360983318222922],
              UndirectedEdge[252, 300] -> 
             RGBColor[
              0.6421328397168371, 0.7146709767757251, 0.9682477279637229], 
             UndirectedEdge[7, 67] -> 
             RGBColor[
              0.43693392935130804`, 0.5528719414914377, 0.9490620215061302], 
             UndirectedEdge[150, 192] -> 
             RGBColor[
              0.1875835174154828, 0.3144925486585769, 0.9339939758606419], 
             UndirectedEdge[239, 272] -> 
             RGBColor[
              0.7843480991326863, 0.5059727477609727, 0.5745160346218742], 
             UndirectedEdge[22, 209] -> 
             RGBColor[
              0.32555893410641223`, 0.4564045184803353, 0.9419653052941668], 
             UndirectedEdge[167, 246] -> 
             RGBColor[
              0.6152498673613919, 0.6911955828537762, 0.9666225650716829], 
             UndirectedEdge[131, 140] -> 
             RGBColor[
              0.21947779992995464`, 0.3480154617955958, 0.9358103080664784], 
             UndirectedEdge[67, 385] -> 
             RGBColor[
              0.7098239251190117, 0.7666063809986858, 0.7914621261134387], 
             UndirectedEdge[60, 101] -> 
             RGBColor[
              0.18455258152934814`, 0.31130684286981486`, 0.9338213685457943],
              UndirectedEdge[113, 249] -> 
             RGBColor[
              0.3083010067824331, 0.4413437356356376, 0.9408697768166884], 
             UndirectedEdge[52, 393] -> 
             RGBColor[
              0.18136432541177624`, 0.30795578354313347`, 0.9336398020765009],
              UndirectedEdge[99, 367] -> 
             RGBColor[
              0.6703595369678017, 0.7365958473458555, 0.9440864000727226], 
             UndirectedEdge[5, 43] -> 
             RGBColor[
              0.2713996679468782, 0.4025886371179538, 0.9387671816385219], 
             UndirectedEdge[26, 105] -> 
             RGBColor[
              0.19823757833601402`, 0.32569064219253296`, 0.9346007088687955],
              UndirectedEdge[128, 306] -> 
             RGBColor[
              0.1986620698216136, 0.3261368096582128, 0.9346248830309214], 
             UndirectedEdge[226, 281] -> 
             RGBColor[
              0.43696413947427415`, 0.552898107981546, 0.9490639464684518], 
             UndirectedEdge[63, 345] -> 
             RGBColor[
              0.18008431245353695`, 0.306610408766515, 0.9335669072321386], 
             UndirectedEdge[4, 280] -> 
             RGBColor[
              0.24217745234544014`, 0.3718742357253608, 0.937103019690414], 
             UndirectedEdge[7, 223] -> 
             RGBColor[
              0.6892737381041355, 0.6614040887409706, 0.6061320446993241], 
             UndirectedEdge[155, 361] -> 
             RGBColor[
              0.21235865222551553`, 0.3405327861781953, 0.9354048831365458], 
             UndirectedEdge[252, 398] -> 
             RGBColor[
              0.39783022825914727`, 0.5190022810145718, 0.9465703682505828], 
             UndirectedEdge[6, 252] -> 
             RGBColor[
              0.3375773650971563, 0.4665223484650306, 0.9427417981088295], 
             UndirectedEdge[260, 307] -> 
             RGBColor[
              0.28646815305242945`, 0.41476449327789777`, 0.9397593961545982],
              UndirectedEdge[21, 357] -> 
             RGBColor[
              0.910151296596057, 0.6637195780075789, 0.25693017547606367`], 
             UndirectedEdge[233, 366] -> 
             RGBColor[
              0.6769028781273625, 0.7426382888986862, 0.9499751965434602], 
             UndirectedEdge[37, 41] -> 
             RGBColor[
              0.6103348144421008, 0.6886019294831773, 0.9655435733376975], 
             UndirectedEdge[173, 176] -> 
             RGBColor[
              0.25807437232061936`, 0.38858290654221544`, 0.9380083257656147],
              UndirectedEdge[60, 136] -> 
             RGBColor[
              0.18529719032077357`, 0.3120894739205271, 0.933863772914916], 
             UndirectedEdge[74, 285] -> 
             RGBColor[
              0.9286295448374513, 0.9418226643023089, 0.7983899704135337], 
             UndirectedEdge[234, 395] -> 
             RGBColor[
              0.6271808306424103, 0.7060165287006694, 0.9652946384160161], 
             UndirectedEdge[17, 164] -> 
             RGBColor[
              0.21631448031938844`, 0.34469061231884324`, 0.9356301616943686],
              UndirectedEdge[20, 383] -> 
             RGBColor[
              0.1993210537450841, 0.3268294435437743, 0.9346624111904838], 
             UndirectedEdge[19, 219] -> 
             RGBColor[
              0.2987647907941907, 0.4287272479574868, 0.9404216575742097], 
             UndirectedEdge[91, 279] -> 
             RGBColor[
              0.5827660155833214, 0.6716970806233367, 0.9606095197706748], 
             UndirectedEdge[76, 207] -> 
             RGBColor[
              0.1908268877624048, 0.3179015365347492, 0.9341786810037627], 
             UndirectedEdge[238, 339] -> 
             RGBColor[
              0.27076497929052823`, 0.4019215390985449, 0.9387310370584805], 
             UndirectedEdge[142, 379] -> 
             RGBColor[
              0.1947953347030193, 0.32207262588340363`, 0.9344046781862394], 
             UndirectedEdge[205, 219] -> 
             RGBColor[
              0.34357155361070624`, 0.4720061441543746, 0.9431130534810463], 
             UndirectedEdge[7, 68] -> 
             RGBColor[
              0.3593357938245753, 0.4820804322688437, 0.9442486147652995], 
             UndirectedEdge[188, 273] -> 
             RGBColor[
              0.19180481699179464`, 0.3189294021591323, 0.9342343726266598], 
             UndirectedEdge[16, 69] -> 
             RGBColor[
              0.2797958916834022, 0.41057876108804503`, 0.9392759017239116], 
             UndirectedEdge[118, 323] -> 
             RGBColor[
              0.3187861771861727, 0.44407882697168544`, 0.9417702640466686], 
             UndirectedEdge[211, 263] -> 
             RGBColor[
              0.30692109574993276`, 0.4322308872824815, 0.9410717536469021], 
             UndirectedEdge[191, 340] -> 
             RGBColor[
              0.2050792556090335, 0.33288167879387, 0.9349903322681394], 
             UndirectedEdge[33, 182] -> 
             RGBColor[
              0.3125367270389322, 0.44214783260778046`, 0.9412445628049322], 
             UndirectedEdge[99, 300] -> 
             RGBColor[
              0.9401681906865148, 0.9543565949425481, 0.9673889822446275], 
             UndirectedEdge[11, 91] -> 
             RGBColor[
              0.40263125450178067`, 0.5220751425472069, 0.9471762250170271], 
             UndirectedEdge[78, 233] -> 
             RGBColor[
              0.8896719661372465, 0.5617502239079055, 0.560162093898772], 
             UndirectedEdge[27, 172] -> 
             RGBColor[
              0.8224207314031455, 0.17334114315753277`, 0.1691034237532337], 
             UndirectedEdge[313, 396] -> 
             RGBColor[
              0.20896253735329678`, 0.3369632541213739, 0.9352114794186747], 
             UndirectedEdge[74, 172] -> 
             RGBColor[
              0.8434316387549917, 0.5388061389910088, 0.578613967277474], 
             UndirectedEdge[217, 366] -> 
             RGBColor[
              0.6937344954214235, 0.7518077736561808, 0.7166986999905727], 
             UndirectedEdge[277, 302] -> 
             RGBColor[
              0.19959521355734036`, 0.32711760288919167`, 0.9346780241862087],
              UndirectedEdge[203, 232] -> 
             RGBColor[
              0.26042493590475796`, 0.3910534979034842, 0.9381421868843842], 
             UndirectedEdge[27, 285] -> 
             RGBColor[
              0.9076186374856052, 0.576357668468833, 0.38887942688929333`], 
             UndirectedEdge[193, 334] -> 
             RGBColor[
              0.1859629402627897, 0.3127892193205704, 0.9339016863892251], 
             UndirectedEdge[39, 381] -> 
             RGBColor[
              0.18966952552711056`, 0.31668507544445096`, 0.9341127709366266],
              UndirectedEdge[270, 390] -> 
             RGBColor[
              0.310905083152461, 0.4394558317316838, 0.9411874173089341], 
             UndirectedEdge[35, 42] -> 
             RGBColor[
              0.22638274960055194`, 0.35527300169848874`, 0.9362035347352613],
              UndirectedEdge[41, 245] -> 
             RGBColor[
              0.8453505309169804, 0.5232059626309822, 0.576653008726561], 
             UndirectedEdge[45, 276] -> 
             RGBColor[
              0.2538332616499947, 0.38412523032544144`, 0.9377668007870836], 
             UndirectedEdge[17, 241] -> 
             RGBColor[
              0.2474447922190557, 0.37741054390116785`, 0.9374029869038852], 
             UndirectedEdge[69, 347] -> 
             RGBColor[
              0.21983376516516337`, 0.34838960382729967`, 0.9358305797600202],
              UndirectedEdge[16, 295] -> 
             RGBColor[
              0.3734051820083968, 0.4978465335906915, 0.9450140259017055], 
             UndirectedEdge[190, 351] -> 
             RGBColor[
              0.9330043693197932, 0.948887212220239, 0.9751255904637988], 
             UndirectedEdge[112, 141] -> 
             RGBColor[
              0.9013527030672266, 0.6354761592849575, 0.23890867411463246`], 
             UndirectedEdge[135, 400] -> 
             RGBColor[
              0.9225103695720027, 0.6890379026099368, 0.4378370589902095], 
             UndirectedEdge[295, 310] -> 
             RGBColor[
              0.3543169737444146, 0.4786184559712684, 0.9438964131148506], 
             UndirectedEdge[185, 249] -> 
             RGBColor[
              0.35433837255967027`, 0.48133182157191207`, 0.9437991056637501],
              UndirectedEdge[93, 98] -> 
             RGBColor[
              0.21766781953393055`, 0.3461130576399892, 0.9357072323605509], 
             UndirectedEdge[221, 268] -> 
             RGBColor[
              0.7908356351545234, 0.6993648502734382, 0.6044361277879526], 
             UndirectedEdge[265, 291] -> 
             RGBColor[
              0.18857894058274138`, 0.31553880152083974`, 0.9340506637374206],
              UndirectedEdge[128, 133] -> 
             RGBColor[
              0.19019948162046302`, 0.31724209289972144`, 0.9341429511521433],
              UndirectedEdge[57, 333] -> 
             RGBColor[
              0.2028967340448986, 0.3305877102501046, 0.9348660408938132], 
             UndirectedEdge[28, 378] -> 
             RGBColor[
              0.19890365407675165`, 0.32639073002768937`, 0.9346386408968597],
              UndirectedEdge[92, 386] -> 
             RGBColor[
              0.6290755332185833, 0.7079371215448762, 0.9651823556220622], 
             UndirectedEdge[35, 248] -> 
             RGBColor[
              0.22712519699410227`, 0.3560533609829937, 0.9362458160159715], 
             UndirectedEdge[56, 175] -> 
             RGBColor[
              0.331650883280764, 0.45917597392142306`, 0.9424452023325764], 
             UndirectedEdge[3, 21] -> 
             RGBColor[
              0.7725354937206939, 0.7794802979389553, 0.6358867741972027], 
             UndirectedEdge[98, 204] -> 
             RGBColor[
              0.19732498772567109`, 0.3247314515994759, 0.9345487381835933], 
             UndirectedEdge[243, 367] -> 
             RGBColor[
              0.6723041775720541, 0.7380461571244501, 0.9407946307732227], 
             UndirectedEdge[48, 209] -> 
             RGBColor[
              0.2875152720132881, 0.41711435878234465`, 0.9397732858765137], 
             UndirectedEdge[116, 291] -> 
             RGBColor[
              0.1852566513830322, 0.31204686492664385`, 0.9338614642823836], 
             UndirectedEdge[214, 340] -> 
             RGBColor[
              0.22133989504081186`, 0.3499726418207558, 0.9359163516283189], 
             UndirectedEdge[138, 159] -> 
             RGBColor[
              0.18138230828610377`, 0.30797468468423184`, 0.9336408261745905],
              UndirectedEdge[22, 48] -> 
             RGBColor[
              0.27823170323432733`, 0.40907339811174287`, 0.9391817450830557],
              UndirectedEdge[13, 297] -> 
             RGBColor[
              0.2105416090442786, 0.33862295858752356`, 0.9353014052154489], 
             UndirectedEdge[192, 347] -> 
             RGBColor[
              0.18973620095672017`, 0.3167551555484371, 0.9341165680037053], 
             UndirectedEdge[4, 322] -> 
             RGBColor[
              0.21636197354501668`, 0.3447405307102229, 0.9356328663633082], 
             UndirectedEdge[111, 304] -> 
             RGBColor[
              0.18507047905985996`, 0.31185118601098283`, 0.9338508620439963],
              UndirectedEdge[133, 361] -> 
             RGBColor[
              0.20171159208941025`, 0.3293420509125463, 0.9347985488127086], 
             UndirectedEdge[4, 186] -> 
             RGBColor[
              0.2198352252877424, 0.3483911385087073, 0.9358306629118409], 
             UndirectedEdge[73, 240] -> 
             RGBColor[
              0.8811521202900017, 0.5036002063401005, 0.22050415715161448`], 
             UndirectedEdge[82, 335] -> 
             RGBColor[
              0.18011477786530028`, 0.30664242984589696`, 0.933568642192269], 
             UndirectedEdge[184, 372] -> 
             RGBColor[
              0.18858940025952037`, 0.31554979530431626`, 0.9340512594005395],
              UndirectedEdge[85, 340] -> 
             RGBColor[
              0.22184000451345684`, 0.35049828858527765`, 0.9359448321229403],
              UndirectedEdge[344, 388] -> 
             RGBColor[
              0.20538183242077535`, 0.3331997062074885, 0.9350075635699459], 
             UndirectedEdge[57, 228] -> 
             RGBColor[
              0.21063806848440092`, 0.33872434357497383`, 0.9353068984378649],
              UndirectedEdge[36, 80] -> 
             RGBColor[
              0.1863429465695527, 0.31318863004276976`, 0.9339233271862263], 
             UndirectedEdge[88, 365] -> 
             RGBColor[
              0.18619994968916187`, 0.3130383312549531, 0.9339151837254329], 
             UndirectedEdge[209, 241] -> 
             RGBColor[
              0.2990278699570904, 0.4292148291621499, 0.9404289112980508], 
             UndirectedEdge[49, 62] -> 
             RGBColor[
              0.19439182652115503`, 0.3216485132003679, 0.9343816989922191], 
             UndirectedEdge[161, 250] -> 
             RGBColor[
              0.22890128499152032`, 0.3579201420787632, 0.9363469615999377], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.19292841019979173`, 0.32011036986066127`, 0.934298359597648], 
             UndirectedEdge[324, 346] -> 
             RGBColor[
              0.4920980261552287, 0.5957700021570038, 0.9539260250446029], 
             UndirectedEdge[142, 258] -> 
             RGBColor[
              0.18294835007904106`, 0.30962069390139346`, 0.9337300099379471],
              UndirectedEdge[44, 46] -> 
             RGBColor[
              0.2189840028439955, 0.34749644974970917`, 0.9357821870529404], 
             UndirectedEdge[85, 191] -> 
             RGBColor[
              0.22398452631281984`, 0.35275231696694354`, 0.9360669594668783],
              UndirectedEdge[112, 172] -> 
             RGBColor[
              0.880455548797022, 0.4861641510661218, 0.21934051163396778`], 
             UndirectedEdge[133, 298] -> 
             RGBColor[
              0.1913924314057353, 0.3184959587614276, 0.9342108878776034], 
             UndirectedEdge[26, 215] -> 
             RGBColor[
              0.18499791179933114`, 0.3117749132191369, 0.9338467294458628], 
             UndirectedEdge[127, 129] -> 
             RGBColor[
              0.19194623803100921`, 0.3190780446379586, 0.9342424263456293], 
             UndirectedEdge[172, 225] -> 
             RGBColor[
              0.8542567503473041, 0.5474377891348923, 0.5796464760848401], 
             UndirectedEdge[38, 376] -> 
             RGBColor[
              0.21626586560617583`, 0.3446395151729059, 0.9356273931583702], 
             UndirectedEdge[158, 346] -> 
             RGBColor[
              0.34491127963015633`, 0.47316654749583464`, 0.9431984196383325],
              UndirectedEdge[340, 370] -> 
             RGBColor[
              0.19501122587610803`, 0.3222995411946109, 0.9344169728691645], 
             UndirectedEdge[44, 266] -> 
             RGBColor[
              0.23471345152571355`, 0.36402909761884283`, 0.9366779558857301],
              UndirectedEdge[183, 238] -> 
             RGBColor[
              0.31998454354214334`, 0.4498414183193987, 0.9416736311656848], 
             UndirectedEdge[21, 264] -> 
             RGBColor[
              0.8432468849976082, 0.8356472056673055, 0.6423010818703361], 
             UndirectedEdge[13, 140] -> 
             RGBColor[
              0.2199309237526768, 0.34849172366298653`, 0.9358361127978458], 
             UndirectedEdge[210, 266] -> 
             RGBColor[
              0.26920304414348, 0.40027984622658896`, 0.9386420871625321], 
             UndirectedEdge[51, 395] -> 
             RGBColor[
              0.4251084428470847, 0.5422133005057554, 0.9484234537100807], 
             UndirectedEdge[358, 372] -> 
             RGBColor[
              0.19242209071206384`, 0.3195781959765495, 0.9342695254518545], 
             UndirectedEdge[174, 309] -> 
             RGBColor[
              0.32079650085916334`, 0.45124869478397367`, 0.9416995914849222],
              UndirectedEdge[65, 363] -> 
             RGBColor[
              0.25392355034044856`, 0.38422012946374207`, 0.9377719425944349],
              UndirectedEdge[236, 267] -> 
             RGBColor[
              0.25338105975763014`, 0.38364993746531034`, 0.9377410485582862],
              UndirectedEdge[227, 352] -> 
             RGBColor[
              0.22353600409255178`, 0.3522808916754905, 0.9360414167899633], 
             UndirectedEdge[2, 370] -> 
             RGBColor[
              0.18603673488354355`, 0.3128667821458319, 0.9339058888837076], 
             UndirectedEdge[17, 354] -> 
             RGBColor[
              0.2237645258481464, 0.35252108252973663`, 0.9360544307658767], 
             UndirectedEdge[133, 306] -> 
             RGBColor[
              0.1942497780329075, 0.32149921123282543`, 0.9343736095409554], 
             UndirectedEdge[105, 261] -> 
             RGBColor[
              0.23472290345765154`, 0.3640390321985968, 0.9366784941592712], 
             UndirectedEdge[120, 206] -> 
             RGBColor[
              0.624306194339526, 0.7045315727086937, 0.9644880050917888], 
             UndirectedEdge[361, 393] -> 
             RGBColor[
              0.20049962337211924`, 0.32806819494741857`, 0.934729528987206], 
             UndirectedEdge[270, 295] -> 
             RGBColor[
              0.3940670515595366, 0.5157428065001295, 0.9463305819589302], 
             UndirectedEdge[9, 283] -> 
             RGBColor[
              0.2000074908485974, 0.3275509324621929, 0.9347015027680361], 
             UndirectedEdge[43, 122] -> 
             RGBColor[
              0.42916131354223347`, 0.5377386121027248, 0.9498157239985662], 
             UndirectedEdge[127, 336] -> 
             RGBColor[
              0.18757872554421223`, 0.31448751209804937`, 0.933993702970662], 
             UndirectedEdge[4, 123] -> 
             RGBColor[
              0.2222583366495916, 0.3509379821841447, 0.9359686555192263], 
             UndirectedEdge[45, 279] -> 
             RGBColor[
              0.4785218001436983, 0.5802784243797845, 0.9537482634423509], 
             UndirectedEdge[135, 255] -> 
             RGBColor[
              0.9151018270707441, 0.6320925985012373, 0.4307426303242521], 
             UndirectedEdge[152, 180] -> 
             RGBColor[
              0.2576563148367751, 0.3881435016203197, 0.9379845180103705], 
             UndirectedEdge[48, 68] -> 
             RGBColor[
              0.2551071510734325, 0.38546416887872903`, 0.937839346905198], 
             UndirectedEdge[362, 363] -> 
             RGBColor[
              0.20453297478611288`, 0.3323075030127757, 0.9349592223834241], 
             UndirectedEdge[18, 257] -> 
             RGBColor[
              0.46412234198098856`, 0.5722988469015355, 0.9519334554771259], 
             UndirectedEdge[72, 109] -> 
             RGBColor[
              0.18206833162796426`, 0.3086957387129193, 0.933679894189029], 
             UndirectedEdge[181, 211] -> 
             RGBColor[
              0.20840661341018846`, 0.33637894280955327`, 0.9351798203725303],
              UndirectedEdge[82, 259] -> 
             RGBColor[
              0.1834817429881715, 0.31018132366795326`, 0.9337603858750381], 
             UndirectedEdge[282, 367] -> 
             RGBColor[
              0.3211123825917724, 0.44870662104929115`, 0.9418228148301714], 
             UndirectedEdge[44, 363] -> 
             RGBColor[
              0.22828771928123268`, 0.35727524561493795`, 0.9363120199404259],
              UndirectedEdge[139, 290] -> 
             RGBColor[
              0.19313846063632573`, 0.32033114618742536`, 0.9343103216592668],
              UndirectedEdge[255, 351] -> 
             RGBColor[
              0.8725754097367984, 0.601857083491112, 0.5863765700059249], 
             UndirectedEdge[290, 345] -> 
             RGBColor[
              0.18860221988526102`, 0.31556326954378094`, 0.9340519894592605],
              UndirectedEdge[145, 200] -> 
             RGBColor[
              0.19073593578989534`, 0.3178059402449537, 0.9341735014234795], 
             UndirectedEdge[44, 316] -> 
             RGBColor[
              0.23551418105696653`, 0.3648707151253743, 0.9367235562479619], 
             UndirectedEdge[172, 240] -> 
             RGBColor[
              0.8277460748309535, 0.21427406632403376`, 0.17420297863381767`],
              UndirectedEdge[89, 299] -> 
             RGBColor[
              0.18845360021131413`, 0.3154070608434312, 0.9340435257886923], 
             UndirectedEdge[119, 196] -> 
             RGBColor[
              0.18607572050979368`, 0.3129077585108523, 0.9339081090574485], 
             UndirectedEdge[149, 369] -> 
             RGBColor[
              0.20360056980323105`, 0.3313274862578765, 0.9349061232990186], 
             UndirectedEdge[32, 385] -> 
             RGBColor[
              0.9757287822359568, 0.928603231512897, 0.461093645269188], 
             UndirectedEdge[149, 253] -> 
             RGBColor[
              0.20384820267597584`, 0.3315877641079622, 0.9349202256247814], 
             UndirectedEdge[317, 336] -> 
             RGBColor[
              0.1878536669894908, 0.3147764929893316, 0.9340093604792311], 
             UndirectedEdge[138, 215] -> 
             RGBColor[
              0.18262441317102773`, 0.30928021567228525`, 0.9337115622102574],
              UndirectedEdge[157, 181] -> 
             RGBColor[
              0.19115892919796787`, 0.31825053313616897`, 0.9341975902723066],
              UndirectedEdge[299, 342] -> 
             RGBColor[
              0.18568831496489116`, 0.3125005707202294, 0.9338860468847814], 
             UndirectedEdge[108, 198] -> 
             RGBColor[
              0.3047308678845767, 0.4335017597846965, 0.9408162005428573], 
             UndirectedEdge[152, 367] -> 
             RGBColor[
              0.31592573046277495`, 0.4432551208089762, 0.9415274426643891], 
             UndirectedEdge[17, 118] -> 
             RGBColor[
              0.23527881827982655`, 0.36462333392373825`, 0.9367101526859918],
              UndirectedEdge[44, 68] -> 
             RGBColor[
              0.25335041241870687`, 0.38361772516894843`, 0.9377393032376733],
              UndirectedEdge[158, 323] -> 
             RGBColor[
              0.3687236016444134, 0.49379158398248, 0.9447157197406713], 
             UndirectedEdge[343, 359] -> 
             RGBColor[
              0.18461240578101906`, 0.3113697219513976, 0.933824775448425], 
             UndirectedEdge[354, 388] -> 
             RGBColor[
              0.21768345542489445`, 0.346129491952765, 0.93570812280141], 
             UndirectedEdge[382, 389] -> 
             RGBColor[
              0.1922700735577051, 0.31941841630887424`, 0.9342608682998029], 
             UndirectedEdge[178, 319] -> 
             RGBColor[
              0.4475260102308348, 0.5620450810151163, 0.9497372679364278], 
             UndirectedEdge[15, 386] -> 
             RGBColor[
              0.5232931103169385, 0.6153912271159707, 0.9581889419192983], 
             UndirectedEdge[27, 104] -> 
             RGBColor[
              0.8200236798530103, 0.15491635454850536`, 0.16680800448174155`],
              UndirectedEdge[236, 398] -> 
             RGBColor[
              0.3384347985138768, 0.4621971627307483, 0.9429819918755249], 
             UndirectedEdge[151, 304] -> 
             RGBColor[
              0.1864549217267703, 0.3133063230326405, 0.9339297040057775], 
             UndirectedEdge[21, 233] -> 
             RGBColor[
              0.9613042288478943, 0.9283900515581442, 0.6325730929841542], 
             UndirectedEdge[120, 321] -> 
             RGBColor[
              0.5363303582199404, 0.6344561720670685, 0.9566410369233613], 
             UndirectedEdge[170, 299] -> 
             RGBColor[
              0.20966330069407968`, 0.3376998008234987, 0.9352513868542458], 
             UndirectedEdge[97, 109] -> 
             RGBColor[
              0.18710606140703578`, 0.3139907121212397, 0.9339667854472937], 
             UndirectedEdge[251, 381] -> 
             RGBColor[
              0.19321867549075944`, 0.3204154570853507, 0.9343148897765596], 
             UndirectedEdge[134, 392] -> 
             RGBColor[
              0.9110260493239869, 0.9293182372189884, 0.8905829197640283], 
             UndirectedEdge[132, 220] -> 
             RGBColor[
              0.4970479670019815, 0.5999842739295098, 0.9542616336741748], 
             UndirectedEdge[102, 167] -> 
             RGBColor[
              0.29386288759542795`, 0.42605944514024496`, 0.9400515350827954],
              UndirectedEdge[270, 373] -> 
             RGBColor[
              0.31547519929516016`, 0.44425931355976, 0.9414476786623798], 
             UndirectedEdge[122, 351] -> 
             RGBColor[
              0.7538761223524553, 0.8076987945105711, 0.9763753458222324], 
             UndirectedEdge[96, 173] -> 
             RGBColor[
              0.515339475447038, 0.6087263479834802, 0.9574676673643785], 
             UndirectedEdge[253, 266] -> 
             RGBColor[
              0.21192263839001468`, 0.3400745079922101, 0.9353800527936387], 
             UndirectedEdge[217, 230] -> 
             RGBColor[
              0.9054039524770299, 0.5624674632894656, 0.3258325895022128], 
             UndirectedEdge[118, 158] -> 
             RGBColor[
              0.28881871360859035`, 0.41812251622929797`, 0.9398607637666927],
              UndirectedEdge[208, 230] -> 
             RGBColor[
              0.9053767960647079, 0.5643648513182951, 0.465019014701602], 
             UndirectedEdge[86, 179] -> 
             RGBColor[
              0.4324853651691194, 0.5490017107824403, 0.9487832899231066], 
             UndirectedEdge[185, 284] -> 
             RGBColor[
              0.33809952087216233`, 0.4642943071241772, 0.9428732085612545], 
             UndirectedEdge[279, 399] -> 
             RGBColor[
              0.7994051322415094, 0.7452396599077329, 0.6138726305595152], 
             UndirectedEdge[167, 309] -> 
             RGBColor[
              0.30392546223642514`, 0.4366358490920146, 0.940624583822355], 
             UndirectedEdge[174, 183] -> 
             RGBColor[
              0.34699168167192995`, 0.474968487180372, 0.943330981016807], 
             UndirectedEdge[149, 247] -> 
             RGBColor[
              0.20711572977977888`, 0.33502214226724336`, 0.9351063064594698],
              UndirectedEdge[297, 339] -> 
             RGBColor[
              0.22923415063680755`, 0.358270004976861, 0.9363659178060062], 
             UndirectedEdge[28, 282] -> 
             RGBColor[
              0.2370656602671769, 0.3665014181447689, 0.9368119106937756], 
             UndirectedEdge[35, 125] -> 
             RGBColor[
              0.24888171485109623`, 0.37892084069359944`, 0.9374848175220434],
              UndirectedEdge[119, 231] -> 
             RGBColor[
              0.18230446054106692`, 0.30894392517202796`, 0.9336933413813087],
              UndirectedEdge[257, 309] -> 
             RGBColor[
              0.31035046981038367`, 0.4422008677223072, 0.9410339796235565], 
             UndirectedEdge[153, 161] -> 
             RGBColor[
              0.1909498488692258, 0.3180307764542026, 0.9341856834568915], 
             UndirectedEdge[315, 369] -> 
             RGBColor[
              0.20472182801530026`, 0.332505999730638, 0.934969977295443], 
             UndirectedEdge[145, 207] -> 
             RGBColor[
              0.19250737674757545`, 0.31966783700731927`, 0.9342743823654074],
              UndirectedEdge[75, 215] -> 
             RGBColor[
              0.20048155521420025`, 0.3280492041678583, 0.9347285000323418], 
             UndirectedEdge[155, 199] -> 
             RGBColor[
              0.1967855567491959, 0.3241644754413012, 0.9345180183874995], 
             UndirectedEdge[28, 151] -> 
             RGBColor[
              0.19950401467485102`, 0.3270217470813523, 0.9346728305447676], 
             UndirectedEdge[141, 279] -> 
             RGBColor[
              0.7689158684311985, 0.6132326776654563, 0.588764654117898], 
             UndirectedEdge[347, 380] -> 
             RGBColor[
              0.20898774598358635`, 0.3369897499901277, 0.9352129150128767], 
             UndirectedEdge[107, 346] -> 
             RGBColor[
              0.3498425512041035, 0.47743776708027175`, 0.9435126359024721], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.684630729662244, 0.7517566465973935, 0.970608286963019], 
             UndirectedEdge[171, 299] -> 
             RGBColor[
              0.18831247292825637`, 0.31525872712095093`, 0.9340354887987012],
              UndirectedEdge[283, 294] -> 
             RGBColor[
              0.19947004944091673`, 0.32698604746696713`, 0.934670896274942], 
             UndirectedEdge[83, 244] -> 
             RGBColor[
              0.9498999569574745, 0.9621560504469515, 0.9696904840737579], 
             UndirectedEdge[112, 179] -> 
             RGBColor[
              0.6955279730573865, 0.6779676106196408, 0.6092046613657698], 
             UndirectedEdge[42, 93] -> 
             RGBColor[
              0.22541709987581074`, 0.35425804261205696`, 0.936148542411988], 
             UndirectedEdge[94, 254] -> 
             RGBColor[
              0.18421702339867016`, 0.31095414999885795`, 0.9338022590066659],
              UndirectedEdge[84, 222] -> 
             RGBColor[
              0.2856119220562171, 0.4147444227440439, 0.9396784182563604], 
             UndirectedEdge[132, 366] -> 
             RGBColor[
              0.3763364091715497, 0.5003854152316536, 0.9452008011045592], 
             UndirectedEdge[52, 133] -> 
             RGBColor[
              0.18257629412906723`, 0.3092296395082612, 0.9337088219020035], 
             UndirectedEdge[255, 400] -> 
             RGBColor[
              0.8427699382288443, 0.329754063899142, 0.18858984719066463`], 
             UndirectedEdge[276, 318] -> 
             RGBColor[
              0.20862378443178675`, 0.3366072033226911, 0.9351921879409346], 
             UndirectedEdge[235, 313] -> 
             RGBColor[
              0.2049405983747336, 0.3327359412492443, 0.9349824359437711], 
             UndirectedEdge[218, 229] -> 
             RGBColor[
              0.19887179747769093`, 0.3263572467222515, 0.9346368267106708], 
             UndirectedEdge[202, 260] -> 
             RGBColor[
              0.23397057730885262`, 0.3632482897159762, 0.9366356502980638], 
             UndirectedEdge[129, 216] -> 
             RGBColor[
              0.1943994825815768, 0.32165656020529343`, 0.9343821349935341], 
             UndirectedEdge[307, 312] -> 
             RGBColor[
              0.32563175741045036`, 0.45592792457411196`, 0.9419897054854269],
              UndirectedEdge[215, 349] -> 
             RGBColor[
              0.192491042377818, 0.3196506685490453, 0.9342734521472142], 
             UndirectedEdge[48, 61] -> 
             RGBColor[
              0.22477630942984533`, 0.3535845312248864, 0.9361120503440548], 
             UndirectedEdge[198, 284] -> 
             RGBColor[
              0.31495346164278715`, 0.44424635397445533`, 0.9413983621344152],
              UndirectedEdge[37, 256] -> 
             RGBColor[
              0.3500537032004466, 0.4776206563266962, 0.9435260903209648], 
             UndirectedEdge[260, 366] -> 
             RGBColor[
              0.3094906009088253, 0.4347053804692331, 0.9412263661740565], 
             UndirectedEdge[35, 263] -> 
             RGBColor[
              0.31410208852609794`, 0.43977856599147, 0.9414807005621779], 
             UndirectedEdge[124, 185] -> 
             RGBColor[
              0.35466498690371884`, 0.48161471850061266`, 0.9438199172409392],
              UndirectedEdge[17, 48] -> 
             RGBColor[
              0.23593219427525336`, 0.3653100735213626, 0.936747361482348], 
             UndirectedEdge[98, 139] -> 
             RGBColor[
              0.19453754132088114`, 0.32180166869373195`, 0.9343899972344978],
              UndirectedEdge[98, 125] -> 
             RGBColor[
              0.23126364989762477`, 0.3604031373776651, 0.9364814947865346], 
             UndirectedEdge[195, 397] -> 
             RGBColor[
              0.2073858256728759, 0.33530603017595706`, 0.9351216880210106], 
             UndirectedEdge[152, 198] -> 
             RGBColor[
              0.3050387614583694, 0.43382537545233274`, 0.9408337346263971], 
             UndirectedEdge[29, 129] -> 
             RGBColor[
              0.18526332309430954`, 0.3120538773182072, 0.933861844226471], 
             UndirectedEdge[83, 230] -> 
             RGBColor[
              0.8813864038440016, 0.5479387227052518, 0.5712729934209153], 
             UndirectedEdge[10, 155] -> 
             RGBColor[
              0.22229114501906733`, 0.3509724658606344, 0.9359705239073323], 
             UndirectedEdge[210, 316] -> 
             RGBColor[
              0.270003773674733, 0.40112146373312046`, 0.9386876875247638], 
             UndirectedEdge[6, 175] -> 
             RGBColor[
              0.2936199376985361, 0.4259435494734196, 0.9400325931289355], 
             UndirectedEdge[301, 343] -> 
             RGBColor[
              0.18235879982602854`, 0.30900103920583233`, 0.9336964359231994],
              UndirectedEdge[140, 297] -> 
             RGBColor[
              0.21630983883703356`, 0.3446857338266013, 0.935629897368815], 
             UndirectedEdge[274, 295] -> 
             RGBColor[
              0.4610566723545275, 0.5726862586021548, 0.9508973954130453], 
             UndirectedEdge[61, 371] -> 
             RGBColor[
              0.19795607517941943`, 0.3253947645266211, 0.934584677680474], 
             UndirectedEdge[266, 397] -> 
             RGBColor[
              0.22283784734549728`, 0.3515470846686418, 0.9360016577960488], 
             UndirectedEdge[71, 88] -> 
             RGBColor[
              0.1851982028892632, 0.3119854318538441, 0.9338581357271303], 
             UndirectedEdge[156, 255] -> 
             RGBColor[
              0.833173631408902, 0.25599264455260395`, 0.17940041294240955`], 
             UndirectedEdge[22, 388] -> 
             RGBColor[
              0.26789478594512556`, 0.39820864264238165`, 0.9385930729355345],
              UndirectedEdge[17, 346] -> 
             RGBColor[
              0.29137138430139253`, 0.41966736519027487`, 0.9400478085576316],
              UndirectedEdge[72, 365] -> 
             RGBColor[
              0.18187230727944725`, 0.30848970469396636`, 0.9336687308923729],
              UndirectedEdge[194, 230] -> 
             RGBColor[
              0.906134992146644, 0.5640310832233217, 0.4054017460858296], 
             UndirectedEdge[95, 264] -> 
             RGBColor[
              0.6413507907064967, 0.7184767050540989, 0.9657562779986768], 
             UndirectedEdge[131, 325] -> 
             RGBColor[
              0.2511977848308302, 0.381355177089618, 0.9376167142810707], 
             UndirectedEdge[369, 372] -> 
             RGBColor[
              0.19233300953943172`, 0.31948456601604064`, 0.9342644524108568],
              UndirectedEdge[11, 248] -> 
             RGBColor[
              0.2649817698706437, 0.3955454303669761, 0.9384125880269136], 
             UndirectedEdge[32, 223] -> 
             RGBColor[
              0.9434671979288998, 0.8132571155526379, 0.27501732397559764`], 
             UndirectedEdge[75, 229] -> 
             RGBColor[
              0.21242485108253378`, 0.34060236537417143`, 0.9354086530635206],
              UndirectedEdge[123, 131] -> 
             RGBColor[
              0.21247713876151392`, 0.34065732304000995`, 0.9354116307694857],
              UndirectedEdge[35, 340] -> 
             RGBColor[
              0.21959313401090685`, 0.34813668522727964`, 0.9358168761717671],
              UndirectedEdge[316, 369] -> 
             RGBColor[
              0.2124757350485229, 0.34065584764865586`, 0.9354115508301075], 
             UndirectedEdge[232, 280] -> 
             RGBColor[
              0.2733144461810522, 0.4046011904460226, 0.9388762254262976], 
             UndirectedEdge[30, 318] -> 
             RGBColor[
              0.18730055861877407`, 0.31419514102261215`, 0.9339778617757692],
              UndirectedEdge[219, 338] -> 
             RGBColor[
              0.28566284547896603`, 0.414956272719873, 0.9396755211710989], 
             UndirectedEdge[124, 397] -> 
             RGBColor[
              0.26132649500551464`, 0.3919101499465881, 0.9381968592370336], 
             UndirectedEdge[131, 280] -> 
             RGBColor[
              0.23239625445736245`, 0.36159357658122604`, 0.9365459949406734],
              UndirectedEdge[224, 345] -> 
             RGBColor[
              0.17916076969846856`, 0.3056397067749454, 0.9335143128384965], 
             UndirectedEdge[44, 195] -> 
             RGBColor[
              0.2192614298530921, 0.3477880431261581, 0.9357979861106919], 
             UndirectedEdge[57, 102] -> 
             RGBColor[
              0.24757611002741542`, 0.37754856724378383`, 0.937410465258804], 
             UndirectedEdge[102, 222] -> 
             RGBColor[
              0.2549287084068188, 0.3852766143221994, 0.9378291848593165], 
             UndirectedEdge[86, 285] -> 
             RGBColor[
              0.7026108469912147, 0.7602147765402214, 0.7786951433273641], 
             UndirectedEdge[97, 340] -> 
             RGBColor[
              0.1979121571634553, 0.3253486039072797, 0.9345821766144358], 
             UndirectedEdge[84, 183] -> 
             RGBColor[
              0.3444123638438444, 0.47273441171796776`, 0.9431666291656026], 
             UndirectedEdge[23, 132] -> 
             RGBColor[
              0.32566481114992, 0.45504559524241234`, 0.9420251663053016], 
             UndirectedEdge[124, 210] -> 
             RGBColor[
              0.30769169180349737`, 0.4406429115045353, 0.9408372886035168], 
             UndirectedEdge[257, 288] -> 
             RGBColor[
              0.3142377899115303, 0.4462866876189422, 0.9412553567525421], 
             UndirectedEdge[31, 287] -> 
             RGBColor[
              0.19320443776430601`, 0.3204004923321242, 0.9343140789591009], 
             UndirectedEdge[163, 222] -> 
             RGBColor[
              0.24959037113759353`, 0.3796656833821117, 0.9375251744491964], 
             UndirectedEdge[206, 386] -> 
             RGBColor[
              0.7455369138645886, 0.8011383704922057, 0.975271810201597], 
             UndirectedEdge[95, 263] -> 
             RGBColor[
              0.47568127911611685`, 0.5835523041211401, 0.9523268989560933], 
             UndirectedEdge[103, 333] -> 
             RGBColor[
              0.19123001846776383`, 0.3183252524660446, 0.9342016387010543], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.19722342502912832`, 0.3246247027659626, 0.9345429543382737], 
             UndirectedEdge[57, 174] -> 
             RGBColor[
              0.28083864150489934`, 0.40925045112803254`, 0.9394240505070525],
              UndirectedEdge[32, 208] -> 
             RGBColor[0.97502376088894, 0.929050734989072, 0.526498655624491],
              UndirectedEdge[11, 125] -> 
             RGBColor[
              0.2867382877276377, 0.41841291007758175`, 0.9396515895329856], 
             UndirectedEdge[82, 136] -> 
             RGBColor[
              0.18265801399513343`, 0.30931553226883557`, 0.9337134757274823],
              UndirectedEdge[129, 298] -> 
             RGBColor[
              0.19304299486108434`, 0.3202308056047669, 0.9343048850245959], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.24346570234943876`, 0.37322826815933124`, 0.9371763836223466],
              UndirectedEdge[155, 306] -> 
             RGBColor[
              0.20489683816901277`, 0.33268994649847444`, 0.9349799438647926],
              UndirectedEdge[247, 358] -> 
             RGBColor[
              0.19420191296404457`, 0.3214489020106298, 0.9343708836960937], 
             UndirectedEdge[5, 373] -> 
             RGBColor[
              0.27714534160664284`, 0.4086277044311172, 0.939094389253483], 
             UndirectedEdge[194, 201] -> 
             RGBColor[
              0.9717877162352071, 0.9761148093624215, 0.8086618740541351], 
             UndirectedEdge[7, 173] -> 
             RGBColor[
              0.36556257674898185`, 0.48862517592323496`, 0.9446032208411446],
              UndirectedEdge[25, 364] -> 
             RGBColor[
              0.81749806012385, 0.1355033345765571, 0.16438946817681815`], 
             UndirectedEdge[1, 313] -> 
             RGBColor[
              0.20595700131663575`, 0.3338042451848521, 0.935040318587679], 
             UndirectedEdge[189, 222] -> 
             RGBColor[
              0.24951462814212214`, 0.379586072691488, 0.937520860997656], 
             UndirectedEdge[232, 275] -> 
             RGBColor[
              0.2669215798519661, 0.39788188260301705`, 0.9385121611462544], 
             UndirectedEdge[289, 376] -> 
             RGBColor[
              0.19788479388924796`, 0.32531984337115605`, 0.93458061831645], 
             UndirectedEdge[194, 208] -> 
             RGBColor[
              0.9937734715667986, 0.9910458830658546, 0.7058012226950569], 
             UndirectedEdge[320, 384] -> 
             RGBColor[
              0.1926752609493727, 0.31984429394788133`, 0.9342839431223373], 
             UndirectedEdge[262, 332] -> 
             RGBColor[
              0.22124807994982085`, 0.34987613833871123`, 0.9359111228947152],
              UndirectedEdge[39, 237] -> 
             RGBColor[
              0.19025421078354665`, 0.3172996167201517, 0.9341460678970164], 
             UndirectedEdge[105, 353] -> 
             RGBColor[
              0.19974831949640176`, 0.32727852693862247`, 0.9346867433429382],
              UndirectedEdge[160, 321] -> 
             RGBColor[
              0.5069925116479708, 0.6106383865650169, 0.9543314541731429], 
             UndirectedEdge[22, 354] -> 
             RGBColor[
              0.2660640348072204, 0.3962844071201169, 0.9384888143665844], 
             UndirectedEdge[70, 286] -> 
             RGBColor[
              0.20888058953085603`, 0.33687712176419665`, 0.9352068126114177],
              UndirectedEdge[97, 334] -> 
             RGBColor[
              0.1889352663956901, 0.3159133225426103, 0.9340709559653313], 
             UndirectedEdge[301, 362] -> 
             RGBColor[
              0.18593089634401205`, 0.31275553913023335`, 0.9338998615354555],
              UndirectedEdge[166, 300] -> 
             RGBColor[
              0.9521971792667703, 0.9624135645920178, 0.9060859398221737], 
             UndirectedEdge[357, 364] -> 
             RGBColor[
              0.8373888047327049, 0.2883923138200816, 0.1834368676776406], 
             UndirectedEdge[13, 66] -> 
             RGBColor[
              0.21421674509456057`, 0.34248575959345395`, 0.9355106987766358],
              UndirectedEdge[102, 395] -> 
             RGBColor[
              0.3730551581743753, 0.49423581065451916`, 0.9452125382842432], 
             UndirectedEdge[129, 336] -> 
             RGBColor[
              0.184720804255658, 0.3114836556211034, 0.9338309485811944], 
             UndirectedEdge[257, 275] -> 
             RGBColor[
              0.2809273627700829, 0.4112753166902168, 0.9393583772051975], 
             UndirectedEdge[358, 369] -> 
             RGBColor[
              0.19068675298749674`, 0.31775424600126295`, 0.9341707005356424],
              UndirectedEdge[42, 139] -> 
             RGBColor[
              0.20228682166276132`, 0.3299466536657998, 0.934831307285935], 
             UndirectedEdge[37, 206] -> 
             RGBColor[
              0.5395559184345032, 0.6328895346269106, 0.9586002858977685], 
             UndirectedEdge[3, 162] -> 
             RGBColor[
              0.42709887646193556`, 0.5374958425847769, 0.9495230473669047], 
             UndirectedEdge[44, 161] -> 
             RGBColor[
              0.2180648213930185, 0.34653033176526227`, 0.9357298410291143], 
             UndirectedEdge[67, 266] -> 
             RGBColor[
              0.3289874356394012, 0.4523479810161943, 0.9424410275338806], 
             UndirectedEdge[305, 360] -> 
             RGBColor[
              0.18374121717091801`, 0.3104540474856332, 0.9337751625458877], 
             UndirectedEdge[51, 174] -> 
             RGBColor[
              0.3627872108908755, 0.4886497806834403, 0.9443374581712001], 
             UndirectedEdge[132, 321] -> 
             RGBColor[
              0.4563174789356197, 0.5669174288296601, 0.9510551804528969], 
             UndirectedEdge[198, 236] -> 
             RGBColor[
              0.3020417872484481, 0.43067536553856556`, 0.9406630613787681], 
             UndirectedEdge[153, 356] -> 
             RGBColor[
              0.18871819494406902`, 0.31568516668383156`, 0.9340585940672899],
              UndirectedEdge[78, 217] -> 
             RGBColor[
              0.9065035834313075, 0.5709197086654001, 0.3268855973458845], 
             UndirectedEdge[16, 324] -> 
             RGBColor[
              0.47545256857995977`, 0.5813525434303296, 0.9528653912069069], 
             UndirectedEdge[263, 312] -> 
             RGBColor[
              0.3474308254202023, 0.4748091816311434, 0.9433787228228494], 
             UndirectedEdge[49, 231] -> 
             RGBColor[
              0.1849354051777754, 0.31170921479673314`, 0.9338431697862355], 
             UndirectedEdge[58, 303] -> 
             RGBColor[
              0.21259709598969448`, 0.3407834056925553, 0.9354184621561699], 
             UndirectedEdge[287, 371] -> 
             RGBColor[
              0.18823999048710255`, 0.315182543479646, 0.9340313610309057], 
             UndirectedEdge[108, 332] -> 
             RGBColor[
              0.24224909685408347`, 0.3719495386464692, 0.9371070997391926], 
             UndirectedEdge[55, 135] -> 
             RGBColor[
              0.9832367917164733, 0.9536721882994657, 0.5121416630539384], 
             UndirectedEdge[38, 145] -> 
             RGBColor[
              0.21009367554414693`, 0.338152152078261, 0.9352758960652745], 
             UndirectedEdge[41, 400] -> 
             RGBColor[
              0.861024743522975, 0.6436848292044157, 0.5916626524195524], 
             UndirectedEdge[184, 369] -> 
             RGBColor[
              0.1868540625349533, 0.3137258453290297, 0.9339524344843275], 
             UndirectedEdge[68, 363] -> 
             RGBColor[
              0.24496356786818765`, 0.3748026197896954, 0.9372616848477457], 
             UndirectedEdge[239, 350] -> 
             RGBColor[
              0.9108066927653387, 0.6030642712488816, 0.46289813781652445`], 
             UndirectedEdge[197, 300] -> 
             RGBColor[
              0.9395054889132312, 0.9538623530451078, 0.9685107634864926], 
             UndirectedEdge[34, 340] -> 
             RGBColor[
              0.23309142699709673`, 0.3623242469969716, 0.9365855839883956], 
             UndirectedEdge[99, 225] -> 
             RGBColor[
              0.9251735948093716, 0.9424003112075763, 0.9659587843040318], 
             UndirectedEdge[75, 218] -> 
             RGBColor[
              0.20441362479812614`, 0.3321820586081753, 0.9349524255781707], 
             UndirectedEdge[33, 256] -> 
             RGBColor[
              0.3139252578534664, 0.443350508209742, 0.9413330387606047], 
             UndirectedEdge[68, 173] -> 
             RGBColor[
              0.2762530439300684, 0.40768984299809713`, 0.9390435742208383], 
             UndirectedEdge[76, 368] -> 
             RGBColor[
              0.18953430680604916`, 0.3165429519952533, 0.9341050704305003], 
             UndirectedEdge[343, 369] -> 
             RGBColor[
              0.18630927681020493`, 0.31315324099090924`, 0.9339214097432413],
              UndirectedEdge[172, 243] -> 
             RGBColor[
              0.8966647112599999, 0.5803804357819402, 0.5534478412456459], 
             UndirectedEdge[25, 83] -> 
             RGBColor[
              0.881176745521725, 0.5463271969673706, 0.5710722243747279], 
             UndirectedEdge[176, 372] -> 
             RGBColor[
              0.2138686325253813, 0.34211987121163484`, 0.9354908742808075], 
             UndirectedEdge[211, 214] -> 
             RGBColor[
              0.23081730246588306`, 0.35993399792684283`, 0.9364560759606089],
              UndirectedEdge[273, 330] -> 
             RGBColor[
              0.18387764331179846`, 0.31059744000961553`, 0.9337829318127865],
              UndirectedEdge[247, 266] -> 
             RGBColor[
              0.21519016549381775`, 0.3435088861514912, 0.9355661336283271], 
             UndirectedEdge[294, 347] -> 
             RGBColor[
              0.19390550774844745`, 0.3211373613358611, 0.9343540038575576], 
             UndirectedEdge[247, 343] -> 
             RGBColor[
              0.18982443678675276`, 0.31684789700027605`, 0.9341215929036926],
              UndirectedEdge[147, 354] -> 
             RGBColor[
              0.1996644579713909, 0.3271903831587082, 0.9346819675531508], 
             UndirectedEdge[83, 206] -> 
             RGBColor[
              0.8376738526720509, 0.8738864473115988, 0.9758404514260404], 
             UndirectedEdge[178, 300] -> 
             RGBColor[
              0.6781948564694122, 0.7459060831571422, 0.9705455677828076], 
             UndirectedEdge[31, 384] -> 
             RGBColor[
              0.19301716646589862`, 0.32020365832381187`, 0.9343034141356996],
              UndirectedEdge[325, 339] -> 
             RGBColor[
              0.2703434502460814, 0.40147848534634617`, 0.9387070316029955], 
             UndirectedEdge[43, 237] -> 
             RGBColor[
              0.22884629711642387`, 0.3578623463356042, 0.9363438301217982], 
             UndirectedEdge[114, 128] -> 
             RGBColor[
              0.21795119041436695`, 0.34641089840207934`, 0.9357233699129821],
              UndirectedEdge[131, 188] -> 
             RGBColor[
              0.20752052535930418`, 0.3354476080868466, 0.9351293589688823], 
             UndirectedEdge[8, 352] -> 
             RGBColor[
              0.23870734178156489`, 0.36822692950501057`, 0.9369054020273697],
              UndirectedEdge[56, 137] -> 
             RGBColor[
              0.35805694536026106`, 0.48455266243088047`, 0.9440360498343989],
              UndirectedEdge[11, 93] -> 
             RGBColor[
              0.2731424573639435, 0.4041228303399058, 0.9388773271070019], 
             UndirectedEdge[232, 325] -> 
             RGBColor[
              0.29211597655452004`, 0.4243627909544146, 0.9399469447666949], 
             UndirectedEdge[293, 387] -> 
             RGBColor[
              0.4415101712045343, 0.5546415244104943, 0.9499598596294503], 
             UndirectedEdge[100, 175] -> 
             RGBColor[
              0.2458994336441635, 0.3757862740575634, 0.9373149810191983], 
             UndirectedEdge[327, 336] -> 
             RGBColor[
              0.18798018955468324`, 0.3149094762273428, 0.9340165657521455], 
             UndirectedEdge[230, 357] -> 
             RGBColor[
              0.8374194029311317, 0.28862750498140566`, 0.18346616854700978`],
              UndirectedEdge[151, 291] -> 
             RGBColor[
              0.1895972333261113, 0.3166090917576105, 0.9341086540027264], 
             UndirectedEdge[10, 87] -> 
             RGBColor[
              0.2178399723924833, 0.34629400120944975`, 0.9357170362111682], 
             UndirectedEdge[44, 247] -> 
             RGBColor[
              0.2171512777998561, 0.34557013952683935`, 0.9356778160729503], 
             UndirectedEdge[191, 334] -> 
             RGBColor[
              0.1961023648412683, 0.3234463974292005, 0.934479111619035], 
             UndirectedEdge[31, 389] -> 
             RGBColor[
              0.19956255990653143`, 0.3270832818318305, 0.9346761646091019], 
             UndirectedEdge[323, 346] -> 
             RGBColor[
              0.37487874320773873`, 0.4991228582382221, 0.9451079199183084], 
             UndirectedEdge[91, 257] -> 
             RGBColor[
              0.408201112318213, 0.5268994734386068, 0.9475311314318583], 
             UndirectedEdge[25, 217] -> 
             RGBColor[
              0.9051942941547533, 0.5608559375515845, 0.32563182045602546`], 
             UndirectedEdge[4, 238] -> 
             RGBColor[
              0.26140051176335477`, 0.3920788899859515, 0.9381977444862962], 
             UndirectedEdge[49, 298] -> 
             RGBColor[
              0.19233776426424887`, 0.31948956353329044`, 0.9342647231854012],
              UndirectedEdge[96, 245] -> 
             RGBColor[
              0.7835145897788575, 0.47447987208772324`, 0.5706010714513564], 
             UndirectedEdge[198, 219] -> 
             RGBColor[
              0.34521680439082036`, 0.47343117768740084`, 0.9432178874059169],
              UndirectedEdge[69, 106] -> 
             RGBColor[
              0.23431749208343802`, 0.36361291913973265`, 0.936655406581262], 
             UndirectedEdge[246, 350] -> 
             RGBColor[
              0.9570479117499637, 0.9654838538059254, 0.8719160935305621], 
             UndirectedEdge[91, 263] -> 
             RGBColor[
              0.44262523593919395`, 0.5567159191123393, 0.94972460614893], 
             UndirectedEdge[193, 305] -> 
             RGBColor[
              0.18458905889423072`, 0.311345182893105, 0.933823445877761], 
             UndirectedEdge[217, 244] -> 
             RGBColor[
              0.9739175055905028, 0.9766847910311653, 0.7242500801550553], 
             UndirectedEdge[218, 260] -> 
             RGBColor[
              0.20772118523879674`, 0.3356585143427644, 0.9351407862521698], 
             UndirectedEdge[115, 169] -> 
             RGBColor[
              0.8801983721871041, 0.6989200901607082, 0.599330145570115], 
             UndirectedEdge[152, 332] -> 
             RGBColor[
              0.24255699042787615`, 0.37227315431410535`, 0.9371246338227324],
              UndirectedEdge[8, 227] -> 
             RGBColor[
              0.22264092645081146`, 0.35134010832282114`, 0.9359904434424149],
              UndirectedEdge[161, 344] -> 
             RGBColor[
              0.1953522686165181, 0.3226579987381405, 0.9344363947487033], 
             UndirectedEdge[255, 324] -> 
             RGBColor[
              0.7342455134222807, 0.4929254711764368, 0.5728784243989717], 
             UndirectedEdge[135, 221] -> 
             RGBColor[
              0.9485753172801801, 0.8203317071995411, 0.46009294767531356`], 
             UndirectedEdge[179, 257] -> 
             RGBColor[
              0.38852623515624984`, 0.5109265218154098, 0.9459822530302189], 
             UndirectedEdge[40, 350] -> 
             RGBColor[
              0.7574551958384235, 0.806891984810095, 0.8535080309341501], 
             UndirectedEdge[358, 397] -> 
             RGBColor[
              0.20184959481572412`, 0.3294871005277804, 0.9348064078638154], 
             UndirectedEdge[44, 149] -> 
             RGBColor[
              0.22663901581167467`, 0.355542353734595, 0.9362181287168728], 
             UndirectedEdge[215, 218] -> 
             RGBColor[
              0.18692850160935742`, 0.31380408551593836`, 0.9339566736794921],
              UndirectedEdge[211, 248] -> 
             RGBColor[
              0.2199442042179371, 0.34850568227400514`, 0.9358368691006957], 
             UndirectedEdge[38, 103] -> 
             RGBColor[
              0.20863860950919683`, 0.3366227854190133, 0.9351930322071614], 
             UndirectedEdge[79, 213] -> 
             RGBColor[
              0.22683120635617676`, 0.355744358182451, 0.9362290736840618], 
             UndirectedEdge[116, 383] -> 
             RGBColor[
              0.19584602024074033`, 0.3231769630008592, 0.9344645131732627], 
             UndirectedEdge[214, 263] -> 
             RGBColor[
              0.315848849556003, 0.4416145225849462, 0.9415801760187297], 
             UndirectedEdge[203, 275] -> 
             RGBColor[
              0.232253685994867, 0.3614437280877808, 0.9365378758776455], 
             UndirectedEdge[235, 396] -> 
             RGBColor[
              0.19553592187284338`, 0.32285102995482734`, 0.9344468535299604],
              UndirectedEdge[170, 361] -> 
             RGBColor[
              0.22465020382752957`, 0.3534519862412956, 0.9361048688165594], 
             UndirectedEdge[190, 255] -> 
             RGBColor[
              0.8957903553105804, 0.6198388885195696, 0.570244438982581], 
             UndirectedEdge[67, 113] -> 
             RGBColor[
              0.36637406988619037`, 0.4916437040590915, 0.9445701410456664], 
             UndirectedEdge[244, 307] -> 
             RGBColor[
              0.651559964846024, 0.7209668023928419, 0.952436169214119], 
             UndirectedEdge[106, 292] -> 
             RGBColor[
              0.21060209943900177`, 0.3386865378276902, 0.9353048500539408], 
             UndirectedEdge[119, 126] -> 
             RGBColor[
              0.1845010944888899, 0.3112527267258263, 0.9338184364350084], 
             UndirectedEdge[148, 288] -> 
             RGBColor[
              0.3196747008606359, 0.4509958666159675, 0.9416017919105475], 
             UndirectedEdge[143, 277] -> 
             RGBColor[
              0.196429195674298, 0.32378991735698637`, 0.9344977241514731], 
             UndirectedEdge[245, 364] -> 
             RGBColor[
              0.8182535878829069, 0.14131065200704435`, 0.16511296241213771`],
              UndirectedEdge[101, 335] -> 
             RGBColor[
              0.18130162624818058`, 0.3078898827468379, 0.9336362314518891], 
             UndirectedEdge[175, 296] -> 
             RGBColor[
              0.26330595896968834`, 0.39408163581213873`, 0.9383062568858402],
              UndirectedEdge[106, 158] -> 
             RGBColor[
              0.2827874224549232, 0.411783246820848, 0.939517290657987], 
             UndirectedEdge[59, 319] -> 
             RGBColor[
              0.3999369554845372, 0.5208258336893123, 0.9467049354493426], 
             UndirectedEdge[159, 218] -> 
             RGBColor[
              0.18568639672443343`, 0.31249855452788494`, 0.9338859376438252],
              UndirectedEdge[126, 326] -> 
             RGBColor[
              0.18929893908149736`, 0.31629556559357375`, 0.9340916665867824],
              UndirectedEdge[130, 371] -> 
             RGBColor[
              0.18427986944939637`, 0.311020205182841, 0.9338058379962824], 
             UndirectedEdge[108, 262] -> 
             RGBColor[
              0.23515249805591343`, 0.36449056335924074`, 0.936702958936114], 
             UndirectedEdge[34, 91] -> 
             RGBColor[
              0.37827297461142906`, 0.4967706349329164, 0.9457781608227135], 
             UndirectedEdge[173, 323] -> 
             RGBColor[
              0.3405854460382354, 0.4669912406886779, 0.9430117001586653], 
             UndirectedEdge[104, 208] -> 
             RGBColor[
              0.906012199289136, 0.5692488389367173, 0.4656274775468996], 
             UndirectedEdge[115, 122] -> 
             RGBColor[
              0.7312854319265467, 0.5812953754272103, 0.5851154705993664], 
             UndirectedEdge[275, 297] -> 
             RGBColor[
              0.22283542703535522`, 0.35154454076922603`, 0.9360015199629668],
              UndirectedEdge[185, 293] -> 
             RGBColor[
              0.374247320413842, 0.49857595155038115`, 0.9450676862162266], 
             UndirectedEdge[92, 256] -> 
             RGBColor[
              0.42434961842059, 0.5407753734409124, 0.9485908039462863], 
             UndirectedEdge[135, 165] -> 
             RGBColor[
              0.9457959012350979, 0.9559420991486686, 0.8350019041226482], 
             UndirectedEdge[158, 270] -> 
             RGBColor[
              0.3489276916060272, 0.4766453616785984, 0.9434543418578613], 
             UndirectedEdge[35, 86] -> 
             RGBColor[
              0.32363709491798653`, 0.44803730928476804`, 0.942088262737994], 
             UndirectedEdge[124, 387] -> 
             RGBColor[
              0.42192783769441117`, 0.5376802913607258, 0.9487120906541628], 
             UndirectedEdge[170, 261] -> 
             RGBColor[
              0.2458172275622507, 0.3756998702533064, 0.9373102995044464], 
             UndirectedEdge[78, 244] -> 
             RGBColor[
              0.8873515007123038, 0.5600196245933966, 0.5640900365888891], 
             UndirectedEdge[320, 381] -> 
             RGBColor[
              0.19597803687805715`, 0.32331572085701743`, 0.9344720313254569],
              UndirectedEdge[90, 166] -> 
             RGBColor[
              0.7990367806379581, 0.841477411935373, 0.8913793888944332], 
             UndirectedEdge[119, 317] -> 
             RGBColor[
              0.1888850042427438, 0.31586049383305914`, 0.9340680936100771], 
             UndirectedEdge[173, 250] -> 
             RGBColor[
              0.27041365894161523`, 0.40155227913684066`, 0.9387110298843417],
              UndirectedEdge[234, 355] -> 
             RGBColor[
              0.7757149376246414, 0.8247136720150343, 0.978279673580333], 
             UndirectedEdge[203, 297] -> 
             RGBColor[
              0.2163387830881471, 0.3447161560696932, 0.9356315457010966], 
             UndirectedEdge[48, 388] -> 
             RGBColor[
              0.2298511238520014, 0.358918482944391, 0.9364010535178815], 
             UndirectedEdge[34, 95] -> 
             RGBColor[
              0.41132901778835196`, 0.5236070199417173, 0.9483804536298768], 
             UndirectedEdge[133, 299] -> 
             RGBColor[
              0.18672468895596034`, 0.31358986549474943`, 0.9339450668503949],
              UndirectedEdge[58, 376] -> 
             RGBColor[
              0.2107803074531337, 0.33887384574958357`, 0.9353149987367104], 
             UndirectedEdge[239, 392] -> 
             RGBColor[
              0.9094234148855309, 0.6024922502969611, 0.4858226320933391], 
             UndirectedEdge[64, 77] -> 
             RGBColor[
              0.18172630335562523`, 0.308336245312846, 0.9336604161849047], 
             UndirectedEdge[73, 112] -> 
             RGBColor[
              0.9338615942560703, 0.7754902910821886, 0.2656416901517646], 
             UndirectedEdge[257, 339] -> 
             RGBColor[
              0.2873260863715352, 0.41800078089785175`, 0.939722775048237], 
             UndirectedEdge[35, 85] -> 
             RGBColor[
              0.2384984047146932, 0.36800732340035325`, 0.9368935033705061], 
             UndirectedEdge[37, 187] -> 
             RGBColor[
              0.39185947335344506`, 0.5138307132141199, 0.9461899170277228], 
             UndirectedEdge[9, 39] -> 
             RGBColor[
              0.1871051393828018, 0.3139897430153101, 0.9339667329393776], 
             UndirectedEdge[136, 394] -> 
             RGBColor[
              0.18251086599702937`, 0.30916087039310625`, 0.9337050958666762],
              UndirectedEdge[287, 389] -> 
             RGBColor[
              0.19629053047607914`, 0.32364417144177693`, 0.9344898273735713],
              UndirectedEdge[195, 372] -> 
             RGBColor[
              0.19795832156921558`, 0.32539712562472617`, 0.9345848056090496],
              UndirectedEdge[149, 362] -> 
             RGBColor[
              0.20288427131655484`, 0.3305746111324327, 0.934865331159871], 
             UndirectedEdge[83, 321] -> 
             RGBColor[
              0.7496980165524652, 0.8038110466699736, 0.967993483257613], 
             UndirectedEdge[227, 308] -> 
             RGBColor[
              0.20448504246078797`, 0.33225712309977423`, 0.9349564927084064],
              UndirectedEdge[100, 146] -> 
             RGBColor[
              0.1981449486568544, 0.3255932825266753, 0.9345954337456006], 
             UndirectedEdge[100, 278] -> 
             RGBColor[
              0.23415669632153385`, 0.3634439125989312, 0.9366462495004977], 
             UndirectedEdge[234, 350] -> 
             RGBColor[
              0.8897866044520348, 0.9121284341385445, 0.8654271636734474], 
             UndirectedEdge[278, 352] -> 
             RGBColor[
              0.24888415157963256`, 0.37892340184978857`, 0.9374849562901288],
              UndirectedEdge[342, 353] -> 
             RGBColor[
              0.1868676578718124, 0.31374013489006275`, 0.9339532087186491], 
             UndirectedEdge[109, 181] -> 
             RGBColor[
              0.18812311022869774`, 0.31505969491742614`, 0.9340247048730984],
              UndirectedEdge[59, 296] -> 
             RGBColor[
              0.2957363483745861, 0.42467629385936273`, 0.9402809691977339], 
             UndirectedEdge[168, 378] -> 
             RGBColor[
              0.18751181267223727`, 0.3144171824270826, 0.9339898923815917], 
             UndirectedEdge[191, 370] -> 
             RGBColor[
              0.19715574767547106`, 0.3245535695762768, 0.9345391002131025], 
             UndirectedEdge[153, 184] -> 
             RGBColor[
              0.18277753601960423`, 0.3094411574946885, 0.933720282329959], 
             UndirectedEdge[3, 91] -> 
             RGBColor[
              0.5375833562526594, 0.6354734123169479, 0.9567396775183801], 
             UndirectedEdge[149, 210] -> 
             RGBColor[
              0.26112860842944113`, 0.3917931023423411, 0.9381822599936748], 
             UndirectedEdge[3, 312] -> 
             RGBColor[
              0.44238894573366777`, 0.553566674835752, 0.9503937941922995], 
             UndirectedEdge[17, 388] -> 
             RGBColor[
              0.22559527698605156`, 0.35444531805200136`, 0.9361586893348268],
              UndirectedEdge[99, 243] -> 
             RGBColor[
              0.9675815557220673, 0.9753429578546242, 0.9397601494648378], 
             UndirectedEdge[108, 398] -> 
             RGBColor[
              0.34112387915000547`, 0.4650235569768793, 0.9431351310396142], 
             UndirectedEdge[57, 186] -> 
             RGBColor[
              0.21226621689950026`, 0.3404356307898151, 0.9353996190814751], 
             UndirectedEdge[180, 398] -> 
             RGBColor[
              0.3423187854528118, 0.46627947926256413`, 0.9432031791858535], 
             UndirectedEdge[66, 318] -> 
             RGBColor[
              0.20433061997593613`, 0.33209481527724394`, 0.9349476985763416],
              UndirectedEdge[374, 382] -> 
             RGBColor[
              0.18605529017041303`, 0.3128862849288049, 0.9339069455798448], 
             UndirectedEdge[190, 270] -> 
             RGBColor[
              0.6576592800193992, 0.7261622336829004, 0.951547961847741], 
             UndirectedEdge[47, 96] -> 
             RGBColor[
              0.6461513889555156, 0.7219924964871992, 0.9663950668318202], 
             UndirectedEdge[245, 328] -> 
             RGBColor[
              0.8441804058989478, 0.32309654782053254`, 0.18925529611386532`],
              UndirectedEdge[142, 143] -> 
             RGBColor[
              0.1837659567931899, 0.3104800503972236, 0.9337765714307771], 
             UndirectedEdge[268, 373] -> 
             RGBColor[
              0.475607023803843, 0.5762529501811211, 0.9537345477094038], 
             UndirectedEdge[69, 390] -> 
             RGBColor[
              0.2522635992417797, 0.3824754156120626, 0.9376774108350432], 
             UndirectedEdge[91, 112] -> 
             RGBColor[
              0.7152028502193496, 0.6939405622428378, 0.6107535397674092], 
             UndirectedEdge[16, 190] -> 
             RGBColor[
              0.6369974104682594, 0.7082659607734624, 0.9502314057905163], 
             UndirectedEdge[40, 395] -> 
             RGBColor[
              0.494849422028799, 0.60078007937222, 0.9533755056767188], 
             UndirectedEdge[84, 246] -> 
             RGBColor[
              0.6295415881560444, 0.703574353083331, 0.9675332208830456], 
             UndirectedEdge[196, 376] -> 
             RGBColor[
              0.19966869054902864`, 0.32719483186616644`, 0.9346822085921858],
              UndirectedEdge[37, 311] -> 
             RGBColor[
              0.3257713181858094, 0.4560335502623456, 0.9419991567290754], 
             UndirectedEdge[179, 275] -> 
             RGBColor[
              0.34634920232824207`, 0.46792331791250663`, 0.9435317259645368],
              UndirectedEdge[334, 340] -> 
             RGBColor[
              0.1939578430419053, 0.32119236904753456`, 0.934356984275097], 
             UndirectedEdge[23, 366] -> 
             RGBColor[
              0.34372780451171075`, 0.47069085221995155`, 0.9431761242698371],
              UndirectedEdge[295, 351] -> 
             RGBColor[
              0.6694121408599306, 0.7384677850374681, 0.9699082105749879], 
             UndirectedEdge[358, 363] -> 
             RGBColor[
              0.20533835444542115`, 0.3331540080987284, 0.9350050875635693], 
             UndirectedEdge[111, 116] -> 
             RGBColor[
              0.1862942905711151, 0.31313748950344333`, 0.9339205562990953], 
             UndirectedEdge[147, 371] -> 
             RGBColor[
              0.18501189214807195`, 0.3117896074520688, 0.9338475256060415], 
             UndirectedEdge[33, 311] -> 
             RGBColor[
              0.28964287283882917`, 0.4217634021453914, 0.9398061051687154], 
             UndirectedEdge[137, 178] -> 
             RGBColor[
              0.3880768646119117, 0.5105544076416471, 0.9459488925435418], 
             UndirectedEdge[328, 386] -> 
             RGBColor[
              0.8151456848541535, 0.6567413505380229, 0.5948173850288303], 
             UndirectedEdge[20, 36] -> 
             RGBColor[
              0.19158305641128354`, 0.3186963177285822, 0.934221743689665], 
             UndirectedEdge[107, 212] -> 
             RGBColor[
              0.3829775514957524, 0.5061376389193594, 0.9456239688209257], 
             UndirectedEdge[21, 27] -> 
             RGBColor[
              0.8921201702935075, 0.5251244399562564, 0.23966354856549787`], 
             UndirectedEdge[138, 329] -> 
             RGBColor[
              0.18634787164566047`, 0.31319380661002694`, 0.9339236076620245],
              UndirectedEdge[3, 263] -> 
             RGBColor[
              0.48691076315351817`, 0.5926689051451934, 0.9532109250744729], 
             UndirectedEdge[239, 269] -> 
             RGBColor[
              0.785672209855677, 0.5070071531213871, 0.5746480096042236], 
             UndirectedEdge[74, 86] -> 
             RGBColor[
              0.6370413534700665, 0.7120367862892685, 0.9671058051428245], 
             UndirectedEdge[91, 179] -> 
             RGBColor[
              0.47362295187637204`, 0.5835474746608966, 0.9517044801911976], 
             UndirectedEdge[316, 358] -> 
             RGBColor[
              0.212564816221155, 0.34074947760916474`, 0.9354166238711052], 
             UndirectedEdge[154, 267] -> 
             RGBColor[
              0.23074964895808886`, 0.359862889800671, 0.9364522231934242], 
             UndirectedEdge[25, 357] -> 
             RGBColor[
              0.837209744608855, 0.2870159792435245, 0.18326539950082243`], 
             UndirectedEdge[118, 388] -> 
             RGBColor[
              0.2291977478565746, 0.35823174334676655`, 0.936363844721525], 
             UndirectedEdge[305, 340] -> 
             RGBColor[
              0.19258396167334632`, 0.31974833262006913`, 0.9342787437636328],
              UndirectedEdge[100, 213] -> 
             RGBColor[
              0.21638299645224862`, 0.344762627118653, 0.9356340635867745], 
             UndirectedEdge[51, 238] -> 
             RGBColor[
              0.3357800727610889, 0.463522711822467, 0.942680108320078], 
             UndirectedEdge[104, 242] -> 
             RGBColor[
              0.8356412746575417, 0.27496003188981555`, 0.1817634309041114], 
             UndirectedEdge[99, 337] -> 
             RGBColor[
              0.9798418672906987, 0.9817838609022704, 0.7682315700129669], 
             UndirectedEdge[143, 302] -> 
             RGBColor[
              0.1882090973662136, 0.3151500728508547, 0.9340296017133733], 
             UndirectedEdge[14, 327] -> 
             RGBColor[
              0.19007805312865012`, 0.317114463855815, 0.9341360359791719], 
             UndirectedEdge[162, 348] -> 
             RGBColor[
              0.3027342580511927, 0.4332679187418763, 0.9406342199418414], 
             UndirectedEdge[130, 391] -> 
             RGBColor[
              0.18156952589467779`, 0.3081714622611251, 0.9336514879404352], 
             UndirectedEdge[182, 386] -> 
             RGBColor[
              0.5546461678159978, 0.6446668165900299, 0.9601091386691207], 
             UndirectedEdge[32, 217] -> 
             RGBColor[
              0.975050917301262, 0.9271533469602427, 0.3873122304251019], 
             UndirectedEdge[3, 285] -> 
             RGBColor[
              0.7880339609127915, 0.8307135264515318, 0.7851026525209982], 
             UndirectedEdge[212, 274] -> 
             RGBColor[
              0.45520745425599235`, 0.5676199598754534, 0.950524688408067], 
             UndirectedEdge[234, 272] -> 
             RGBColor[
              0.7633280108193825, 0.8150369106506357, 0.9770450604787972], 
             UndirectedEdge[24, 104] -> 
             RGBColor[
              0.8198979870257355, 0.15395022439912315`, 0.1666876408883935], 
             UndirectedEdge[317, 327] -> 
             RGBColor[
              0.19548056477531295`, 0.3227928461354802, 0.9344437010251496], 
             UndirectedEdge[85, 263] -> 
             RGBColor[
              0.31634895902864796`, 0.44214016934946804`, 0.941608656513351], 
             UndirectedEdge[169, 300] -> 
             RGBColor[
              0.9052440838676142, 0.9272810765527117, 0.9908241829118685], 
             UndirectedEdge[34, 162] -> 
             RGBColor[
              0.2677884948207052, 0.39879306520074553`, 0.9385615306712383], 
             UndirectedEdge[62, 313] -> 
             RGBColor[
              0.20973650567435648`, 0.3377767438992335, 0.9352555557695754], 
             UndirectedEdge[337, 367] -> 
             RGBColor[
              0.6845644891406854, 0.7444870601720963, 0.7692660513213518], 
             UndirectedEdge[21, 240] -> 
             RGBColor[
              0.8974455137213154, 0.5660573631227573, 0.24476310344608182`], 
             UndirectedEdge[258, 378] -> 
             RGBColor[
              0.18711323001988966`, 0.3139982467878655, 0.9339671936891907], 
             UndirectedEdge[240, 242] -> 
             RGBColor[
              0.8419811748449504, 0.32369128289221516`, 0.18783452648346705`],
              UndirectedEdge[16, 380] -> 
             RGBColor[
              0.26894987250182517`, 0.3991789072508731, 0.9386582369767682], 
             UndirectedEdge[38, 222] -> 
             RGBColor[
              0.22765792346573496`, 0.35661329028148886`, 0.9362761540004327],
              UndirectedEdge[61, 147] -> 
             RGBColor[
              0.19642039468713995`, 0.32378066696146846`, 0.9344972229482744],
              UndirectedEdge[279, 288] -> 
             RGBColor[
              0.4888026931766387, 0.5910842948036721, 0.9543337450913586], 
             UndirectedEdge[192, 384] -> 
             RGBColor[
              0.1855895073220066, 0.3123967176227914, 0.933880419935692], 
             UndirectedEdge[196, 289] -> 
             RGBColor[
              0.18795157808443957`, 0.3148794037580448, 0.934014936371242], 
             UndirectedEdge[9, 384] -> 
             RGBColor[
              0.19029625552141455`, 0.3173438084054412, 0.9341484622826384], 
             UndirectedEdge[114, 187] -> 
             RGBColor[
              0.33810546577905015`, 0.4610349816709624, 0.9429931157731941], 
             UndirectedEdge[90, 274] -> 
             RGBColor[
              0.5507285778663977, 0.6461452954084659, 0.9577745175163469], 
             UndirectedEdge[270, 324] -> 
             RGBColor[
              0.49611443813109957`, 0.5992488163397677, 0.9541819472641316], 
             UndirectedEdge[42, 45] -> 
             RGBColor[
              0.2506616815740248, 0.3807916985758058, 0.9375861839936894], 
             UndirectedEdge[316, 363] -> 
             RGBColor[
              0.2271273365064473, 0.3560556097461213, 0.9362459378580343], 
             UndirectedEdge[44, 250] -> 
             RGBColor[
              0.24751102743025372`, 0.3774801613076919, 0.9374067589011768], 
             UndirectedEdge[213, 352] -> 
             RGBColor[
              0.23111045171034733`, 0.3602421163695104, 0.9364727703764056], 
             UndirectedEdge[80, 378] -> 
             RGBColor[
              0.18531329630253898`, 0.3121064023285408, 0.9338646901267509], 
             UndirectedEdge[238, 272] -> 
             RGBColor[
              0.5154577316990447, 0.6098310076277607, 0.9573191957441505], 
             UndirectedEdge[126, 196] -> 
             RGBColor[
              0.1881608487233165, 0.3150993604680292, 0.9340268540245378], 
             UndirectedEdge[112, 240] -> 
             RGBColor[
              0.8843983974342954, 0.516470613459494, 0.2231161879418313], 
             UndirectedEdge[52, 89] -> 
             RGBColor[
              0.18430520538442102`, 0.31104683485694296`, 0.933807280840301], 
             UndirectedEdge[99, 177] -> 
             RGBColor[
              0.9302447173684912, 0.9464438866842635, 0.9664424725007652], 
             UndirectedEdge[41, 206] -> 
             RGBColor[
              0.8010921103082493, 0.8449578955447232, 0.9806977415425538], 
             UndirectedEdge[1, 119] -> 
             RGBColor[
              0.18798137752672578`, 0.3149107248612813, 0.9340166334053959], 
             UndirectedEdge[2, 109] -> 
             RGBColor[
              0.1831541470606865, 0.30983699957738503`, 0.9337417297716024], 
             UndirectedEdge[8, 100] -> 
             RGBColor[
              0.22397988652346618`, 0.35274744025415317`, 0.9360666952377386],
              UndirectedEdge[203, 322] -> 
             RGBColor[
              0.2128310735235297, 0.3410293309156486, 0.935431786830583], 
             UndirectedEdge[98, 193] -> 
             RGBColor[
              0.1939801662783198, 0.32121583218438116`, 0.9343582555503864], 
             UndirectedEdge[141, 285] -> 
             RGBColor[
              0.9298982865463443, 0.7362961374607975, 0.4097714679426784], 
             UndirectedEdge[29, 231] -> 
             RGBColor[
              0.1818156421264654, 0.3084301460254042, 0.9336655038957391], 
             UndirectedEdge[225, 398] -> 
             RGBColor[
              0.6554022589203814, 0.7271955623129416, 0.9686184880711814], 
             UndirectedEdge[149, 359] -> 
             RGBColor[
              0.20190369877404518`, 0.3295439672183649, 0.9348094890042022], 
             UndirectedEdge[87, 235] -> 
             RGBColor[
              0.1948464738725398, 0.3221263763929803, 0.9344075904862901], 
             UndirectedEdge[162, 312] -> 
             RGBColor[
              0.28761893872861966`, 0.41963611907072695`, 0.9396908451152812],
              UndirectedEdge[392, 395] -> 
             RGBColor[
              0.729861417537885, 0.7850410988470374, 0.8743691386056183], 
             UndirectedEdge[212, 268] -> 
             RGBColor[
              0.5483496579696843, 0.6426701443947892, 0.9582447440009759], 
             UndirectedEdge[50, 271] -> 
             RGBColor[
              0.17906803055065768`, 0.3055422320505946, 0.933509031481224], 
             UndirectedEdge[200, 207] -> 
             RGBColor[
              0.1859857863076916, 0.31281323196228517`, 0.9339029874376845], 
             UndirectedEdge[360, 370] -> 
             RGBColor[
              0.18616848137367975`, 0.313005256060175, 0.9339133916514194], 
             UndirectedEdge[134, 246] -> 
             RGBColor[
              0.8756067697264411, 0.9036490867400013, 0.9879973494315406], 
             UndirectedEdge[88, 191] -> 
             RGBColor[
              0.19934659159346146`, 0.326856285441612, 0.9346638655331689], 
             UndirectedEdge[277, 278] -> 
             RGBColor[
              0.23299059780069237`, 0.3622182691186103, 0.9365798419148239], 
             UndirectedEdge[233, 242] -> 
             RGBColor[
              0.9058398899715292, 0.686023971327602, 0.5756445160215393], 
             UndirectedEdge[66, 123] -> 
             RGBColor[
              0.21298431371887483`, 0.3411903960769459, 0.9354405136330093], 
             UndirectedEdge[315, 316] -> 
             RGBColor[
              0.22659989124895852`, 0.3555012313385397, 0.9362159006309058], 
             UndirectedEdge[127, 216] -> 
             RGBColor[
              0.19725740387013102`, 0.32466041668223944`, 0.9345448893830015],
              UndirectedEdge[29, 326] -> 
             RGBColor[
              0.18672499245337307`, 0.31359018448977305`, 0.9339450841341236],
              UndirectedEdge[76, 145] -> 
             RGBColor[
              0.19557703724460856`, 0.3228942448174177, 0.9344491949895577], 
             UndirectedEdge[21, 104] -> 
             RGBColor[
              0.8911056135339068, 0.5173261121203578, 0.23869200786672617`], 
             UndirectedEdge[27, 112] -> 
             RGBColor[
              0.8790730540064875, 0.47553769029299303`, 0.21801663306124733`],
              UndirectedEdge[190, 221] -> 
             RGBColor[
              0.9292638455200164, 0.8080779972178733, 0.5995947563336426], 
             UndirectedEdge[310, 324] -> 
             RGBColor[
              0.45636436031597766`, 0.5621244658109066, 0.9517477784200521], 
             UndirectedEdge[11, 312] -> 
             RGBColor[
              0.30743684398278903`, 0.44016840506601096`, 0.9408303416909466],
              UndirectedEdge[177, 225] -> 
             RGBColor[
              0.8897813970600477, 0.9149515498158103, 0.9893493380404593], 
             UndirectedEdge[253, 316] -> 
             RGBColor[
              0.2127233679212677, 0.3409161254987416, 0.9354256531558705], 
             UndirectedEdge[17, 323] -> 
             RGBColor[
              0.3151837063156497, 0.44029240167692024`, 0.9415651086599703], 
             UndirectedEdge[315, 397] -> 
             RGBColor[
              0.21588466984352767`, 0.3442388542571554, 0.935605684623616], 
             UndirectedEdge[43, 296] -> 
             RGBColor[
              0.2526601828418626, 0.38289225012060224`, 0.937699995684375], 
             UndirectedEdge[50, 287] -> 
             RGBColor[
              0.18448432655099875`, 0.31123510255995407`, 0.9338174815257515],
              UndirectedEdge[253, 369] -> 
             RGBColor[
              0.19084530468760944`, 0.3179208938908398, 0.9341797298204076], 
             UndirectedEdge[187, 220] -> 
             RGBColor[
              0.5353714211663698, 0.63317812373389, 0.9567035702854296], 
             UndirectedEdge[211, 340] -> 
             RGBColor[
              0.21241214123474167`, 0.34058900651829105`, 0.9354079292564914],
              UndirectedEdge[213, 227] -> 
             RGBColor[
              0.2150440363795939, 0.343355295187321, 0.9355578117914507], 
             UndirectedEdge[17, 389] -> 
             RGBColor[
              0.21716250001380405`, 0.34558193478522814`, 0.9356784551614329],
              UndirectedEdge[117, 376] -> 
             RGBColor[
              0.217871456795024, 0.34632709331274647`, 0.9357188292013159], 
             UndirectedEdge[186, 330] -> 
             RGBColor[
              0.19639093276449526`, 0.3237497006127751, 0.9344955451353647], 
             UndirectedEdge[24, 337] -> 
             RGBColor[
              0.9074168352108218, 0.5752287479070755, 0.3804750196277067], 
             UndirectedEdge[73, 99] -> 
             RGBColor[
              0.9481261161147958, 0.8682562660194123, 0.6030407890629428], 
             UndirectedEdge[114, 155] -> 
             RGBColor[
              0.2241859587617661, 0.352964035242341, 0.9360784307468533], 
             UndirectedEdge[123, 232] -> 
             RGBColor[
              0.2533953304852037, 0.3836649369048065, 0.9377418612551098], 
             UndirectedEdge[53, 289] -> 
             RGBColor[
              0.18928237138329773`, 0.3162781518923132, 0.9340907230808797], 
             UndirectedEdge[126, 376] -> 
             RGBColor[
              0.19809406452812484`, 0.3255398000811405, 0.9345925359697458], 
             UndirectedEdge[207, 254] -> 
             RGBColor[
              0.18750231875154622`, 0.3144072037144869, 0.9339893517168534], 
             UndirectedEdge[291, 304] -> 
             RGBColor[
              0.1840328398717771, 0.3107605614341833, 0.9337917700272845], 
             UndirectedEdge[333, 368] -> 
             RGBColor[
              0.18664235406415453`, 0.3135033263031278, 0.9339403780001101], 
             UndirectedEdge[26, 171] -> 
             RGBColor[
              0.18798107467478986`, 0.3149104065446947, 0.9340166161584262], 
             UndirectedEdge[81, 384] -> 
             RGBColor[
              0.18455785037421688`, 0.3113123807598359, 0.9338216685987151], 
             UndirectedEdge[120, 233] -> 
             RGBColor[
              0.7388527640498924, 0.7945317751585553, 0.9544100950493892], 
             UndirectedEdge[224, 290] -> 
             RGBColor[
              0.18877579274929696`, 0.3157457056290379, 0.9340618741770893], 
             UndirectedEdge[393, 396] -> 
             RGBColor[
              0.19146055662429076`, 0.3185675626855177, 0.9342147675080179], 
             UndirectedEdge[2, 365] -> 
             RGBColor[
              0.18295812271216946`, 0.3096309655584321, 0.9337305664749465], 
             UndirectedEdge[210, 387] -> 
             RGBColor[
              0.4198898949581986, 0.5356292280658739, 0.9485927029346032], 
             UndirectedEdge[23, 307] -> 
             RGBColor[
              0.32070535665531497`, 0.4507499650286162, 0.9417091542503788], 
             UndirectedEdge[120, 244] -> 
             RGBColor[
              0.7365322986249497, 0.7928011758440465, 0.9583380377395063], 
             UndirectedEdge[42, 248] -> 
             RGBColor[
              0.21725641238251098`, 0.34568064263912723`, 0.9356838033318999],
              UndirectedEdge[49, 393] -> 
             RGBColor[
              0.1855205539729795, 0.3123242432810691, 0.9338764931444723], 
             UndirectedEdge[375, 377] -> 
             RGBColor[
              0.18266643619111367`, 0.3093243845308089, 0.9337139553590839], 
             UndirectedEdge[269, 350] -> 
             RGBColor[
              0.8687159863176557, 0.8956679071093385, 0.8633270413739342], 
             UndirectedEdge[77, 207] -> 
             RGBColor[
              0.18528324242742453`, 0.31207481380026975`, 0.9338629786030239],
              UndirectedEdge[200, 368] -> 
             RGBColor[
              0.18469320535133593`, 0.3114546474227893, 0.9338293768644222], 
             UndirectedEdge[384, 389] -> 
             RGBColor[
              0.1961032591776717, 0.32344733743346465`, 0.93447916255017], 
             UndirectedEdge[1, 361] -> 
             RGBColor[
              0.205591391562574, 0.33341996615233593`, 0.9350194976530564], 
             UndirectedEdge[150, 380] -> 
             RGBColor[
              0.20683506244234898`, 0.3347271431002675, 0.9350903228698133], 
             UndirectedEdge[150, 381] -> 
             RGBColor[
              0.19485465175919953`, 0.32213497187036766`, 0.9344080562048372],
              UndirectedEdge[232, 279] -> 
             RGBColor[
              0.48366351594508233`, 0.5856826936906501, 0.9540410765507529], 
             UndirectedEdge[132, 341] -> 
             RGBColor[
              0.34725423307667924`, 0.4751958960109486, 0.9433477105601525], 
             UndirectedEdge[1, 14] -> 
             RGBColor[
              0.18904790384743964`, 0.31603171164602595`, 0.9340773705015762],
              UndirectedEdge[171, 342] -> 
             RGBColor[
              0.18633859981298379`, 0.3131840613260155, 0.9339230796448701], 
             UndirectedEdge[140, 325] -> 
             RGBColor[
              0.25741913844630737`, 0.3878942141960865, 0.9379710111658044], 
             UndirectedEdge[89, 306] -> 
             RGBColor[
              0.1959786892882613, 0.3233164065815071, 0.9344720684792528], 
             UndirectedEdge[130, 147] -> 
             RGBColor[
              0.18274418895711692`, 0.3094061076176884, 0.9337183832640827], 
             UndirectedEdge[4, 183] -> 
             RGBColor[
              0.2914028738694214, 0.4198002713108441, 0.9400459473606144], 
             UndirectedEdge[80, 151] -> 
             RGBColor[
              0.18591365690063838`, 0.3127374193822037, 0.9338988797746588], 
             UndirectedEdge[236, 286] -> 
             RGBColor[
              0.22281035809500455`, 0.3515181917234548, 0.9360000923239], 
             UndirectedEdge[108, 180] -> 
             RGBColor[
              0.25734842126298235`, 0.38781988595268346`, 0.9379669839268308],
              UndirectedEdge[9, 320] -> 
             RGBColor[
              0.1934136507337484, 0.32062038842787655`, 0.9343259933282078], 
             UndirectedEdge[35, 97] -> 
             RGBColor[
              0.21457055736469166`, 0.3428576387223553, 0.9355308478620015], 
             UndirectedEdge[154, 236] -> 
             RGBColor[
              0.22814394288837742`, 0.3571241275100973, 0.936303832087551], 
             UndirectedEdge[60, 259] -> 
             RGBColor[
              0.18612091931381164`, 0.3129552653196448, 0.9339106830624717], 
             UndirectedEdge[179, 399] -> 
             RGBColor[
              0.6902620685345601, 0.6570900539452929, 0.6049675909800379], 
             UndirectedEdge[314, 352] -> 
             RGBColor[
              0.23613835462959704`, 0.3655267611250992, 0.9367591020095412], 
             UndirectedEdge[85, 88] -> 
             RGBColor[
              0.21610734049788477`, 0.34447289523301966`, 0.9356183653879699],
              UndirectedEdge[70, 267] -> 
             RGBColor[
              0.23945129119348169`, 0.3690088675060522, 0.9369477688458039], 
             UndirectedEdge[31, 192] -> 
             RGBColor[
              0.18904880805086632`, 0.3160326620211572, 0.9340774219946237], 
             UndirectedEdge[221, 255] -> 
             RGBColor[
              0.8688348859370216, 0.46104786848874635`, 0.21084573587576866`],
              UndirectedEdge[11, 211] -> 
             RGBColor[
              0.2669271143125195, 0.39759011071734907`, 0.9385233725149993], 
             UndirectedEdge[211, 312] -> 
             RGBColor[
              0.26239927833008236`, 0.39312865697304, 0.9382546227647286], 
             UndirectedEdge[123, 280] -> 
             RGBColor[
              0.23161694690439888`, 0.3607744749321087, 0.9365016145284144], 
             UndirectedEdge[178, 278] -> 
             RGBColor[
              0.349928065209785, 0.47283535767355744`, 0.9436893135230188], 
             UndirectedEdge[83, 364] -> 
             RGBColor[
              0.8813558056455749, 0.5477035315439278, 0.5712436925515461], 
             UndirectedEdge[10, 313] -> 
             RGBColor[
              0.22793409689467709`, 0.35690356606571383`, 0.9362918816686491],
              UndirectedEdge[32, 242] -> 
             RGBColor[
              0.9046528362573457, 0.6347619279421703, 0.24263460898170292`], 
             UndirectedEdge[44, 369] -> 
             RGBColor[
              0.21363611782330827`, 0.34187548351747254`, 0.9354776329124991],
              UndirectedEdge[110, 375] -> 
             RGBColor[
              0.18201536929507323`, 0.30864007194304494`, 0.9336768780625215],
              UndirectedEdge[275, 290] -> 
             RGBColor[
              0.21848378643908228`, 0.34697069059259356`, 0.9357537004686844],
              UndirectedEdge[362, 369] -> 
             RGBColor[
              0.18988137332818844`, 0.31690774091531027`, 0.9341248353554973],
              UndirectedEdge[266, 338] -> 
             RGBColor[
              0.23347632110247196`, 0.3627287951054168, 0.936607503138297], 
             UndirectedEdge[350, 395] -> 
             RGBColor[
              0.7312446954176929, 0.785613119798958, 0.8514446443288036], 
             UndirectedEdge[141, 172] -> 
             RGBColor[
              0.8447003804638847, 0.3332796121494973, 0.18999546480661883`], 
             UndirectedEdge[123, 275] -> 
             RGBColor[
              0.22522408057531274`, 0.3540551670891031, 0.9361375502483711], 
             UndirectedEdge[46, 315] -> 
             RGBColor[
              0.21006971303598748`, 0.3381269659628746, 0.9352745314358842], 
             UndirectedEdge[185, 205] -> 
             RGBColor[
              0.3748090292582385, 0.49906247551909, 0.9451034778070919], 
             UndirectedEdge[3, 86] -> 
             RGBColor[
              0.49644576954540676`, 0.6009276484384913, 0.9538184872502891], 
             UndirectedEdge[316, 397] -> 
             RGBColor[
              0.2236385768767503, 0.3523887021751733, 0.9360472581582806], 
             UndirectedEdge[11, 214] -> 
             RGBColor[
              0.2758548681185897, 0.40697374601981373`, 0.9390317948868268], 
             UndirectedEdge[3, 34] -> 
             RGBColor[
              0.4225585018257533, 0.5327236209657705, 0.9492644797482566], 
             UndirectedEdge[5, 100] -> 
             RGBColor[
              0.24629351933764826`, 0.37620048310789195`, 0.9373374236164447],
              UndirectedEdge[25, 245] -> 
             RGBColor[
              0.8180745277590571, 0.13993431743048723`, 0.16494149423531956`],
              UndirectedEdge[183, 325] -> 
             RGBColor[
              0.3195630144976964, 0.44939836456720006`, 0.9416496257101998], 
             UndirectedEdge[149, 266] -> 
             RGBColor[
              0.22467790350563632`, 0.35348110035924685`, 0.9361064462722496],
              UndirectedEdge[73, 78] -> 
             RGBColor[
              0.8752764478324426, 0.45843721309521324`, 0.21487760657063304`],
              UndirectedEdge[40, 167] -> 
             RGBColor[
              0.4156571514498516, 0.5326037138579458, 0.948214502475271], 
             UndirectedEdge[5, 175] -> 
             RGBColor[
              0.282045444074704, 0.41377802280949016`, 0.9393734428399871], 
             UndirectedEdge[279, 309] -> 
             RGBColor[
              0.48491537307549215`, 0.5869984749070372, 0.9541123679623731], 
             UndirectedEdge[66, 257] -> 
             RGBColor[
              0.268687595913645, 0.3984105456780595, 0.9386613405898359], 
             UndirectedEdge[238, 309] -> 
             RGBColor[
              0.29378936272937667`, 0.4261216259230004, 0.9400422416338], 
             UndirectedEdge[40, 355] -> 
             RGBColor[
              0.6433835290110301, 0.7194772226865849, 0.9663605408410356], 
             UndirectedEdge[31, 271] -> 
             RGBColor[
              0.18778814176396494`, 0.3147076218227647, 0.9340056289145733], 
             UndirectedEdge[271, 391] -> 
             RGBColor[
              0.1801133509320429, 0.3066409300485706, 0.9335685609305309], 
             UndirectedEdge[264, 348] -> 
             RGBColor[
              0.5282156563331551, 0.6233653822352514, 0.957751476691993], 
             UndirectedEdge[146, 302] -> 
             RGBColor[
              0.18875875182792845`, 0.3157277945402228, 0.9340609037218272], 
             UndirectedEdge[86, 91] -> 
             RGBColor[
              0.45216024233108254`, 0.5649746624056373, 0.950332168324746], 
             UndirectedEdge[232, 257] -> 
             RGBColor[
              0.30909861267997385`, 0.4408850865059202, 0.9409626882119364], 
             UndirectedEdge[201, 385] -> 
             RGBColor[
              0.9717345415002878, 0.9760010739812197, 0.8028741323146045], 
             UndirectedEdge[204, 297] -> 
             RGBColor[
              0.2002775476373886, 0.32783477926980176`, 0.9347168821026446], 
             UndirectedEdge[241, 323] -> 
             RGBColor[
              0.3309521511254019, 0.4568660369491151, 0.9424630982645621], 
             UndirectedEdge[269, 395] -> 
             RGBColor[
              0.6061102125080312, 0.6895560016714635, 0.9631945161165028], 
             UndirectedEdge[52, 342] -> 
             RGBColor[
              0.18153992013799802`, 0.30814034473374124`, 0.9336498019363901],
              UndirectedEdge[201, 245] -> 
             RGBColor[
              0.8839369101698967, 0.553629569307468, 0.5684023912498125], 
             UndirectedEdge[131, 330] -> 
             RGBColor[
              0.199593351679308, 0.3271156459373298, 0.9346779181550091], 
             UndirectedEdge[159, 349] -> 
             RGBColor[
              0.191248937492894, 0.31834513756099186`, 0.9342027161115474], 
             UndirectedEdge[15, 33] -> 
             RGBColor[
              0.28118366953987284`, 0.41287224313372134`, 0.9393243660551096],
              UndirectedEdge[16, 212] -> 
             RGBColor[
              0.36755596390986156`, 0.4927802348639901, 0.9446413188967272], 
             UndirectedEdge[246, 269] -> 
             RGBColor[
              0.8319134288403021, 0.869426735678431, 0.9836659653182612], 
             UndirectedEdge[150, 294] -> 
             RGBColor[
              0.19175282420721007`, 0.318874754446001, 0.9342314117144941], 
             UndirectedEdge[77, 200] -> 
             RGBColor[
              0.1835118014697444, 0.3102129170379042, 0.9337620976610961], 
             UndirectedEdge[21, 285] -> 
             RGBColor[
              0.9787005711665018, 0.9387674260406853, 0.4607634302742779], 
             UndirectedEdge[275, 280] -> 
             RGBColor[
              0.24514319627116127`, 0.3749914206303192, 0.9372719144195587], 
             UndirectedEdge[171, 353] -> 
             RGBColor[
              0.1894918158351776, 0.3164982912907842, 0.9341026506325689], 
             UndirectedEdge[197, 252] -> 
             RGBColor[
              0.6669388623748537, 0.7337127880117662, 0.9450324457252983], 
             UndirectedEdge[15, 361] -> 
             RGBColor[
              0.2517308007762076, 0.3819154106433724, 0.9376470687506336], 
             UndirectedEdge[348, 366] -> 
             RGBColor[
              0.3637695245894192, 0.4895006114365967, 0.9444000503314454], 
             UndirectedEdge[235, 298] -> 
             RGBColor[
              0.19425582793699694`, 0.3215055700656095, 0.9343739540740432], 
             UndirectedEdge[62, 298] -> 
             RGBColor[
              0.19905173523661984`, 0.32654637271559867`, 0.9346470738998478],
              UndirectedEdge[110, 308] -> 
             RGBColor[
              0.1924672891129, 0.3196257023615725, 0.9342720994339171], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.2089266760744028, 0.33692556164351994`, 0.9352094371718936], 
             UndirectedEdge[204, 290] -> 
             RGBColor[
              0.19592590704111568`, 0.32326092909316934`, 0.9344690626083623],
              UndirectedEdge[35, 93] -> 
             RGBColor[
              0.235285884487402, 0.3646307609559235, 0.9367105550960597], 
             UndirectedEdge[162, 211] -> 
             RGBColor[
              0.24710920905835015`, 0.37705782472206506`, 0.9373838759393338],
              UndirectedEdge[66, 275] -> 
             RGBColor[
              0.22651056308563722`, 0.3554073417751564, 0.9362108135241538], 
             UndirectedEdge[36, 277] -> 
             RGBColor[
              0.20034660319217895`, 0.3279073610362615, 0.9347208147143313], 
             UndirectedEdge[174, 246] -> 
             RGBColor[
              0.6321209059841302, 0.7058084285457353, 0.96769757273425], 
             UndirectedEdge[218, 329] -> 
             RGBColor[
              0.19065196008399016`, 0.31771767645368004`, 0.9341687191312593],
              UndirectedEdge[186, 188] -> 
             RGBColor[
              0.20431810644449144`, 0.33208166276229184`, 0.934946985949238], 
             UndirectedEdge[230, 245] -> 
             RGBColor[
              0.8182841860813337, 0.14154584316836838`, 0.16514226328150688`],
              UndirectedEdge[57, 368] -> 
             RGBColor[
              0.20142644533340448`, 0.3290423435926357, 0.9347823101267909], 
             UndirectedEdge[293, 316] -> 
             RGBColor[
              0.2916240499210687, 0.42013376007774095`, 0.9400548442196108], 
             UndirectedEdge[8, 308] -> 
             RGBColor[
              0.21965638014980107`, 0.34820316092929426`, 0.9358204779458129],
              UndirectedEdge[37, 361] -> 
             RGBColor[
              0.28321730845770904`, 0.41130658795806163`, 0.939575768828076], 
             UndirectedEdge[19, 331] -> 
             RGBColor[
              0.22977587045111889`, 0.35883938684872224`, 0.9363967679480286],
              UndirectedEdge[98, 276] -> 
             RGBColor[
              0.21193626472305038`, 0.34008883013219005`, 0.9353808287931467],
              UndirectedEdge[326, 336] -> 
             RGBColor[
              0.18618247361472157`, 0.3130199627926692, 0.9339141884888471], 
             UndirectedEdge[4, 13] -> 
             RGBColor[
              0.22349076802527734`, 0.3522333457006528, 0.9360388406628528], 
             UndirectedEdge[137, 300] -> 
             RGBColor[
              0.624581474397714, 0.6994688662935715, 0.9671293704856514], 
             UndirectedEdge[57, 163] -> 
             RGBColor[
              0.24223777275819017`, 0.37193763630369614`, 0.9371064548486839],
              UndirectedEdge[28, 304] -> 
             RGBColor[
              0.1939396212205168, 0.3211732167579251, 0.9343559465693256], 
             UndirectedEdge[83, 328] -> 
             RGBColor[
              0.9072826236616158, 0.729489427357416, 0.5953860262532737], 
             UndirectedEdge[206, 321] -> 
             RGBColor[
              0.6423373781810662, 0.7191701000468311, 0.9659074859341975], 
             UndirectedEdge[295, 373] -> 
             RGBColor[
              0.3504430057094734, 0.4745466699427852, 0.9436757963662827], 
             UndirectedEdge[29, 235] -> 
             RGBColor[
              0.18647615617022215`, 0.31332864177904984`, 0.9339309132759184],
              UndirectedEdge[234, 392] -> 
             RGBColor[
              0.888403326572227, 0.9115564131866241, 0.8883516579502622], 
             UndirectedEdge[42, 275] -> 
             RGBColor[
              0.2276321474655179, 0.3565861980709679, 0.9362746860953526], 
             UndirectedEdge[107, 324] -> 
             RGBColor[
              0.4908741561658506, 0.5947099474856988, 0.9538480411311054], 
             UndirectedEdge[75, 329] -> 
             RGBColor[
              0.20420501368883298`, 0.3319627951056, 0.934940545484109], 
             UndirectedEdge[267, 383] -> 
             RGBColor[
              0.23217032750693795`, 0.361356113031734, 0.9365331287350758], 
             UndirectedEdge[253, 362] -> 
             RGBColor[
              0.19012900620093326`, 0.31716801876539596`, 0.9341389376812601],
              UndirectedEdge[137, 252] -> 
             RGBColor[
              0.35201484785933657`, 0.47931930126023004`, 0.943651052724457], 
             UndirectedEdge[131, 203] -> 
             RGBColor[
              0.2195067441810682, 0.34804588403868764`, 0.9358119563987601], 
             UndirectedEdge[52, 199] -> 
             RGBColor[
              0.1829276009104009, 0.30959888520957934`, 0.9337288283034887], 
             UndirectedEdge[41, 386] -> 
             RGBColor[
              0.8163158098721861, 0.8568507653484726, 0.982215097641526], 
             UndirectedEdge[59, 122] -> 
             RGBColor[
              0.472237479074957, 0.5795226558414852, 0.9523966975119249], 
             UndirectedEdge[32, 172] -> 
             RGBColor[
              0.8904177362433487, 0.5253447113739889, 0.22900306113205354`], 
             UndirectedEdge[55, 156] -> 
             RGBColor[
              0.9013085960546312, 0.5775722343508322, 0.2607994456720959], 
             UndirectedEdge[97, 214] -> 
             RGBColor[
              0.21631731839459667`, 0.3446935953158315, 0.9356303233185532], 
             UndirectedEdge[133, 155] -> 
             RGBColor[
              0.1964342499678622, 0.3237952297399831, 0.9344980119860145], 
             UndirectedEdge[186, 273] -> 
             RGBColor[
              0.19433831903215518`, 0.3215922734368583, 0.9343786518198778], 
             UndirectedEdge[74, 179] -> 
             RGBColor[
              0.6585040630153561, 0.7306095985445278, 0.968478117009276], 
             UndirectedEdge[10, 62] -> 
             RGBColor[
              0.21930338871384658`, 0.34783214454915645`, 0.9358003756057394],
              UndirectedEdge[273, 322] -> 
             RGBColor[
              0.19086506728942945`, 0.31794166563837395`, 0.9341808552713451],
              UndirectedEdge[18, 148] -> 
             RGBColor[
              0.46955925293009415`, 0.5770080258985608, 0.9522798906351313], 
             UndirectedEdge[78, 172] -> 
             RGBColor[
              0.8218704023733945, 0.1691110730791465, 0.16857642805283624`], 
             UndirectedEdge[84, 269] -> 
             RGBColor[
              0.5412096627237364, 0.6337584063867442, 0.9589441687264177], 
             UndirectedEdge[103, 254] -> 
             RGBColor[
              0.19079740219879987`, 0.3178705453379077, 0.9341770018445352], 
             UndirectedEdge[46, 343] -> 
             RGBColor[
              0.19165716183089215`, 0.31877420722314587`, 0.9342259638836825],
              UndirectedEdge[1, 317] -> 
             RGBColor[
              0.19445041549410247`, 0.3217100939256911, 0.9343850355475539], 
             UndirectedEdge[27, 399] -> 
             RGBColor[
              0.873807149483661, 0.45466013361864505`, 0.21377956267551557`], 
             UndirectedEdge[247, 253] -> 
             RGBColor[
              0.19436046466415727`, 0.3216155499002067, 0.9343799129808589], 
             UndirectedEdge[27, 357] -> 
             RGBColor[
              0.8390693629151604, 0.3013098204357265, 0.18504617209107904`], 
             UndirectedEdge[41, 55] -> 
             RGBColor[
              0.9217511656674453, 0.9083191148939446, 0.6659672564832814], 
             UndirectedEdge[183, 272] -> 
             RGBColor[
              0.5454600938051113, 0.6375523889526532, 0.9591673986184688], 
             UndirectedEdge[131, 238] -> 
             RGBColor[
              0.2516193138752771, 0.38179823084181674`, 0.9376407197365557], 
             UndirectedEdge[13, 131] -> 
             RGBColor[
              0.21370957013719966`, 0.34195268655651806`, 0.9354818159131122],
              UndirectedEdge[55, 328] -> 
             RGBColor[
              0.9205810406494127, 0.7082097000834948, 0.27856954387058575`], 
             UndirectedEdge[40, 392] -> 
             RGBColor[
              0.7560719179586157, 0.8063199638581745, 0.8764325252109648], 
             UndirectedEdge[39, 347] -> 
             RGBColor[
              0.19051344323313968`, 0.3175720864609606, 0.9341608308015206], 
             UndirectedEdge[195, 362] -> 
             RGBColor[
              0.1955066853579723, 0.3228203005239958, 0.9344451885536901], 
             UndirectedEdge[46, 250] -> 
             RGBColor[
              0.22982046644249732`, 0.3588862600632101, 0.9363993076237638], 
             UndirectedEdge[22, 47] -> 
             RGBColor[
              0.4301895095994409, 0.5445652207348299, 0.9493133718661378], 
             UndirectedEdge[79, 100] -> 
             RGBColor[
              0.22059571881103596`, 0.3491904654197632, 0.9358739718929432], 
             UndirectedEdge[45, 148] -> 
             RGBColor[
              0.30939380782769543`, 0.44018999619208, 0.9410163102615399], 
             UndirectedEdge[65, 68] -> 
             RGBColor[
              0.2789862434779228, 0.41056260901775243`, 0.9391992258916821], 
             UndirectedEdge[86, 162] -> 
             RGBColor[
              0.3416757625403587, 0.46699709267346645`, 0.9431155381732708], 
             UndirectedEdge[3, 264] -> 
             RGBColor[
              0.652580274743898, 0.7275933060781521, 0.9666403041170564], 
             UndirectedEdge[55, 386] -> 
             RGBColor[
              0.8661959692237846, 0.8644995898414272, 0.6605413251423246], 
             UndirectedEdge[315, 362] -> 
             RGBColor[
              0.20400552952862408`, 0.3317531246051941, 0.9349291851562955], 
             UndirectedEdge[92, 182] -> 
             RGBColor[
              0.4229610876060558, 0.5395726978389508, 0.9485023279906137], 
             UndirectedEdge[202, 341] -> 
             RGBColor[
              0.2897972028384973, 0.4193840622352309, 0.9399079526486953], 
             UndirectedEdge[86, 125] -> 
             RGBColor[
              0.3362672755569396, 0.46131242993601224`, 0.9428075328407044], 
             UndirectedEdge[155, 353] -> 
             RGBColor[
              0.19855109199898685`, 0.3260201649302318, 0.9346185630080999], 
             UndirectedEdge[119, 235] -> 
             RGBColor[
              0.18696497458482364`, 0.31384242092567355`, 0.9339587507614879],
              UndirectedEdge[139, 204] -> 
             RGBColor[
              0.19084712474135193`, 0.31792280688272123`, 0.9341798334697757],
              UndirectedEdge[167, 174] -> 
             RGBColor[
              0.3271254190729118, 0.4577613290244936, 0.9420651203310438], 
             UndirectedEdge[218, 349] -> 
             RGBColor[
              0.19642311196174383`, 0.3237835229893623, 0.9344973776930432], 
             UndirectedEdge[362, 397] -> 
             RGBColor[
              0.20104421515641585`, 0.32864059544182767`, 0.9347605426836703],
              UndirectedEdge[70, 108] -> 
             RGBColor[
              0.2395346657598989, 0.3690964994616095, 0.9369525169040198], 
             UndirectedEdge[71, 157] -> 
             RGBColor[
              0.18316059011768585`, 0.3098437716388048, 0.933742096694167], 
             UndirectedEdge[186, 238] -> 
             RGBColor[
              0.24841689496046435`, 0.37843228551726205`, 0.9374583467169113],
              UndirectedEdge[51, 246] -> 
             RGBColor[
              0.6509116591793556, 0.7220840345127228, 0.9688949029118392], 
             UndirectedEdge[109, 305] -> 
             RGBColor[
              0.1817778659169268, 0.3083904408340291, 0.9336633525964908], 
             UndirectedEdge[125, 248] -> 
             RGBColor[
              0.2397553776330553, 0.3693284816342379, 0.936965086118682], 
             UndirectedEdge[106, 390] -> 
             RGBColor[
              0.24476481400135702`, 0.3745937168739334, 0.9372503661090598], 
             UndirectedEdge[1, 231] -> 
             RGBColor[
              0.1878698717924256, 0.3147935252646599, 0.9340102833187854], 
             UndirectedEdge[104, 399] -> 
             RGBColor[
              0.8727925927240603, 0.4468618057827464, 0.21280802197674387`], 
             UndirectedEdge[244, 366] -> 
             RGBColor[
              0.6745824127024198, 0.7409076895841773, 0.9539031392335773], 
             UndirectedEdge[64, 289] -> 
             RGBColor[
              0.18340551527321602`, 0.3101012035064188, 0.9337560448194401], 
             UndirectedEdge[160, 233] -> 
             RGBColor[
              0.7095149174779228, 0.7707139896565038, 0.9521005122991707], 
             UndirectedEdge[100, 302] -> 
             RGBColor[
              0.20076131207818187`, 0.3283432463695126, 0.9347444317718824], 
             UndirectedEdge[177, 337] -> 
             RGBColor[
              0.9444496695413749, 0.9543350995105044, 0.7916221237493946], 
             UndirectedEdge[124, 219] -> 
             RGBColor[
              0.32342751125618663`, 0.45455838713589725`, 0.9418294929148936],
              UndirectedEdge[2, 181] -> 
             RGBColor[
              0.1899547149925528, 0.3169848276546873, 0.9341290120547836], 
             UndirectedEdge[185, 198] -> 
             RGBColor[
              0.3764542800383526, 0.5004875090521163, 0.9452083117319626], 
             UndirectedEdge[11, 35] -> 
             RGBColor[
              0.27410810708868466`, 0.4051377894263376, 0.9389323194302751], 
             UndirectedEdge[5, 56] -> 
             RGBColor[
              0.3320449689742487, 0.4595901829717516, 0.9424676449298229], 
             UndirectedEdge[69, 107] -> 
             RGBColor[
              0.2952174792692931, 0.42393616514341426`, 0.9402585516481101], 
             UndirectedEdge[51, 350] -> 
             RGBColor[
              0.6877142166567092, 0.7483252059436304, 0.8485559789675121], 
             UndirectedEdge[226, 392] -> 
             RGBColor[
              0.7181621296927883, 0.7753237626808771, 0.8735087285822702], 
             UndirectedEdge[81, 292] -> 
             RGBColor[
              0.18697166352319156`, 0.31384945142400145`, 0.9339591316866327],
              UndirectedEdge[51, 272] -> 
             RGBColor[
              0.5612556230240568, 0.6512336824557214, 0.9601738757728618], 
             UndirectedEdge[10, 261] -> 
             RGBColor[
              0.24873551087533646`, 0.3787671710452084, 0.9374764914219134], 
             UndirectedEdge[132, 244] -> 
             RGBColor[
              0.656519419340629, 0.7252624326066381, 0.9527521812690418], 
             UndirectedEdge[53, 376] -> 
             RGBColor[
              0.20099948384788677`, 0.3285935800004348, 0.9347579953018235], 
             UndirectedEdge[242, 364] -> 
             RGBColor[
              0.8349752732346869, 0.2698408531100693, 0.18112566718944462`], 
             UndirectedEdge[29, 327] -> 
             RGBColor[
              0.18852270839333474`, 0.31547969792444663`, 0.934047461397422], 
             UndirectedEdge[328, 364] -> 
             RGBColor[
              0.8436039382637408, 0.3186655649666024, 0.18870327005536394`], 
             UndirectedEdge[257, 279] -> 
             RGBColor[
              0.4976692988631992, 0.5990761277778498, 0.9548872926096961], 
             UndirectedEdge[13, 322] -> 
             RGBColor[
              0.20703389947966117`, 0.33493613343347894`, 0.9351016463449351],
              UndirectedEdge[21, 24] -> 
             RGBColor[
              0.8919944774662327, 0.5241583098068742, 0.2395431849721498], 
             UndirectedEdge[56, 122] -> 
             RGBColor[
              0.48980661456960395`, 0.5947401579565226, 0.9535161872898672], 
             UndirectedEdge[87, 393] -> 
             RGBColor[
              0.1907711086239872, 0.3178429091236707, 0.9341755044643476], 
             UndirectedEdge[27, 74] -> 
             RGBColor[
              0.8420491439644571, 0.52817967821788, 0.5772900887047536], 
             UndirectedEdge[93, 288] -> 
             RGBColor[
              0.2698457094938153, 0.4009553282571281, 0.9386786860034955], 
             UndirectedEdge[125, 211] -> 
             RGBColor[
              0.24170072207493107`, 0.37137316198461084`, 0.9370758706067677],
              UndirectedEdge[265, 304] -> 
             RGBColor[
              0.18543662898340038`, 0.31223603279586976`, 0.9338717137404716],
              UndirectedEdge[195, 343] -> 
             RGBColor[
              0.19193458883998876`, 0.3190658005995948, 0.9342417629414341], 
             UndirectedEdge[199, 393] -> 
             RGBColor[
              0.1849265278957996, 0.3116998842105244, 0.9338426642381596], 
             UndirectedEdge[24, 208] -> 
             RGBColor[
              0.906901063221462, 0.5760810366232336, 0.4664786546523232], 
             UndirectedEdge[135, 386] -> 
             RGBColor[
              0.8778014359212141, 0.9022038387539937, 0.8283895042121832], 
             UndirectedEdge[32, 357] -> 
             RGBColor[
              0.9070663677553636, 0.6533133886521827, 0.2449458094698989], 
             UndirectedEdge[230, 233] -> 
             RGBColor[
              0.8885723351829689, 0.5532979785319709, 0.5591090860551002], 
             UndirectedEdge[46, 161] -> 
             RGBColor[
              0.20037426040526207`, 0.3279364305207805, 0.9347223897517012], 
             UndirectedEdge[114, 306] -> 
             RGBColor[
              0.2220014868268114, 0.35066801673518333`, 0.9359540283017942], 
             UndirectedEdge[233, 357] -> 
             RGBColor[
              0.9082534214695472, 0.7045754320376143, 0.5779557165097353], 
             UndirectedEdge[134, 395] -> 
             RGBColor[
              0.6498035533941702, 0.7237783527330339, 0.9675259002297822], 
             UndirectedEdge[108, 267] -> 
             RGBColor[
              0.2560701403937588, 0.38647633171144136`, 0.9378941877223754], 
             UndirectedEdge[217, 233] -> 
             RGBColor[
              0.9762379710154455, 0.9784153903456743, 0.7203221374649382], 
             UndirectedEdge[245, 400] -> 
             RGBColor[
              0.8345042681241085, 0.26622050143440795`, 0.18067463216363056`],
              UndirectedEdge[269, 392] -> 
             RGBColor[
              0.8673327084378479, 0.8950958861574181, 0.8862515356507488], 
             UndirectedEdge[232, 288] -> 
             RGBColor[
              0.30023200699341346`, 0.43289325353174246`, 0.9404091406935988],
              UndirectedEdge[260, 341] -> 
             RGBColor[
              0.2804084248139549, 0.4095158612485281, 0.93937327562965], 
             UndirectedEdge[47, 323] -> 
             RGBColor[
              0.4713973595467131, 0.580257389192397, 0.951939099626107], 
             UndirectedEdge[142, 377] -> 
             RGBColor[
              0.18361252498065594`, 0.31031878383411166`, 0.9337678337160353],
              UndirectedEdge[53, 117] -> 
             RGBColor[
              0.20926903428907379`, 0.33728540183390365`, 0.9352289339657456],
              UndirectedEdge[251, 308] -> 
             RGBColor[
              0.1958872147734443, 0.3232202610666153, 0.9344668591409584], 
             UndirectedEdge[85, 162] -> 
             RGBColor[
              0.2565370723370653, 0.38696710678905155`, 0.9379207788057828], 
             UndirectedEdge[249, 397] -> 
             RGBColor[
              0.26099988066146607`, 0.3916272530178875, 0.9381760476598446], 
             UndirectedEdge[262, 284] -> 
             RGBColor[
              0.24537509181412387`, 0.37523515754899955`, 0.9372851205276718],
              UndirectedEdge[307, 341] -> 
             RGBColor[
              0.3422947785820742, 0.4709002657971524, 0.9430316985052297], 
             UndirectedEdge[7, 387] -> 
             RGBColor[
              0.4913856837463006, 0.597841186558023, 0.9531378831854276], 
             UndirectedEdge[228, 368] -> 
             RGBColor[
              0.19438368850365684`, 0.3216399596279972, 0.9343812355441619], 
             UndirectedEdge[240, 399] -> 
             RGBColor[
              0.879132492911469, 0.49559305678514604`, 0.2188791175560995], 
             UndirectedEdge[105, 114] -> 
             RGBColor[
              0.22538318625918102`, 0.3542223972507317, 0.9361466110816916], 
             UndirectedEdge[78, 357] -> 
             RGBColor[
              0.8385190338854094, 0.29707975035734024`, 0.18451917639068158`],
              UndirectedEdge[359, 369] -> 
             RGBColor[
              0.18890080078567878`, 0.31587709700124245`, 0.9340689931998285],
              UndirectedEdge[48, 354] -> 
             RGBColor[
              0.22802037271409625`, 0.35699424742212627`, 0.9362967949489314],
              UndirectedEdge[280, 325] -> 
             RGBColor[
              0.2703375929737152, 0.4014723289817168, 0.9387066980399994], 
             UndirectedEdge[259, 262] -> 
             RGBColor[
              0.20019420515358305`, 0.3277471810351035, 0.934712135871486], 
             UndirectedEdge[120, 187] -> 
             RGBColor[
              0.47660974925846794`, 0.585472751295903, 0.952077636221743], 
             UndirectedEdge[70, 198] -> 
             RGBColor[
              0.2881120186842996, 0.4160342955793074, 0.9398697816662858], 
             UndirectedEdge[62, 235] -> 
             RGBColor[
              0.1963098901939031, 0.32366451973268695`, 0.9344909298808612], 
             UndirectedEdge[65, 176] -> 
             RGBColor[
              0.26080757186847375`, 0.39145567256187075`, 0.9381639774364586],
              UndirectedEdge[199, 342] -> 
             RGBColor[
              0.18510212262202141`, 0.31188444540113214`, 0.9338526640980489],
              UndirectedEdge[324, 390] -> 
             RGBColor[
              0.4479202761383373, 0.5532491979543472, 0.9512669003180385], 
             UndirectedEdge[226, 234] -> 
             RGBColor[
              0.6154815427973135, 0.6962991925345092, 0.964434228392668], 
             UndirectedEdge[47, 201] -> 
             RGBColor[
              0.7465737093465549, 0.8011421937069441, 0.9641963866302764], 
             UndirectedEdge[160, 264] -> 
             RGBColor[
              0.5914575736276367, 0.6779711437656651, 0.9618285011853527], 
             UndirectedEdge[277, 314] -> 
             RGBColor[
              0.22024480085065679`, 0.34882162839392095`, 0.9358539876342362],
              UndirectedEdge[4, 66] -> 
             RGBColor[
              0.22354481915991609`, 0.35229015687019793`, 0.9360419187950089],
              UndirectedEdge[23, 75] -> 
             RGBColor[0.255511442446525, 0.3858891047454028, 0.9378623707008],
              UndirectedEdge[287, 391] -> 
             RGBColor[
              0.18552964693238397`, 0.31233380055793014`, 0.9338770109750585],
              UndirectedEdge[45, 91] -> 
             RGBColor[
              0.38905361359871204`, 0.5081017700405416, 0.9463921022645131], 
             UndirectedEdge[175, 314] -> 
             RGBColor[
              0.25716282410855407`, 0.38762481157584006`, 0.9379564144434523],
              UndirectedEdge[195, 358] -> 
             RGBColor[
              0.1963120650172806, 0.3236668056099485, 0.9344910537338352], 
             UndirectedEdge[321, 341] -> 
             RGBColor[
              0.44529829620254, 0.5573731665864943, 0.9503530478730258], 
             UndirectedEdge[91, 148] -> 
             RGBColor[
              0.4136380232673186, 0.5316086524356322, 0.9478775665898638], 
             UndirectedEdge[115, 350] -> 
             RGBColor[
              0.9292292560607558, 0.7349117971309463, 0.4801575703138227], 
             UndirectedEdge[142, 277] -> 
             RGBColor[
              0.19515207298431664`, 0.32244758043556054`, 0.9344249939036124],
              UndirectedEdge[45, 66] -> 
             RGBColor[
              0.2495400971941441, 0.37961284227999426`, 0.9375223114224907], 
             UndirectedEdge[259, 335] -> 
             RGBColor[
              0.18286996403264408`, 0.3095383051966678, 0.9337255459685665], 
             UndirectedEdge[118, 173] -> 
             RGBColor[
              0.26068055800241224`, 0.3913221729354959, 0.9381567441846866], 
             UndirectedEdge[52, 128] -> 
             RGBColor[
              0.18698858591777334`, 0.3138672379336487, 0.9339600953919696], 
             UndirectedEdge[27, 225] -> 
             RGBColor[
              0.8528742555567694, 0.5368113283617635, 0.5783225975121196], 
             UndirectedEdge[302, 352] -> 
             RGBColor[
              0.21548876733628058`, 0.34382273562037, 0.9355831385615135], 
             UndirectedEdge[25, 242] -> 
             RGBColor[
              0.8347962131108371, 0.26846451853351216`, 0.18095419901262647`],
              UndirectedEdge[30, 224] -> 
             RGBColor[
              0.17977250803868983`, 0.30628268255696894`, 0.9335491504319864],
              UndirectedEdge[313, 361] -> 
             RGBColor[
              0.2180016041011253, 0.34646388638327474`, 0.9357262408978626], 
             UndirectedEdge[270, 310] -> 
             RGBColor[
              0.3193491673301014, 0.4483310995882432, 0.9416682954109477], 
             UndirectedEdge[72, 370] -> 
             RGBColor[
              0.18495091945082137`, 0.31172552128136616`, 0.9338440533011341],
              UndirectedEdge[283, 380] -> 
             RGBColor[
              0.2145522876760556, 0.34283843612123366`, 0.9355298074302612], 
             UndirectedEdge[34, 35] -> 
             RGBColor[
              0.24974982719833305`, 0.3798332818120472, 0.9375342552359615], 
             UndirectedEdge[25, 230] -> 
             RGBColor[
              0.8175286583222767, 0.13573852573788114`, 0.16441876904618735`],
              UndirectedEdge[191, 211] -> 
             RGBColor[
              0.2145566630341047, 0.342843034899957, 0.9355300566004294], 
             UndirectedEdge[17, 173] -> 
             RGBColor[
              0.25707808713188923`, 0.38753574764073073`, 0.9379515887979883],
              UndirectedEdge[40, 51] -> 
             RGBColor[
              0.4513189432678153, 0.5634921655168925, 0.9504868403154272], 
             UndirectedEdge[105, 202] -> 
             RGBColor[
              0.2264175602160962, 0.35530958986254624`, 0.9362055171483188], 
             UndirectedEdge[183, 309] -> 
             RGBColor[
              0.3237917248354433, 0.45384300724789295`, 0.9418904445081182], 
             UndirectedEdge[187, 261] -> 
             RGBColor[
              0.3474451829775207, 0.4708516166188276, 0.9435249988507737], 
             UndirectedEdge[190, 274] -> 
             RGBColor[
              0.7246489008143902, 0.7831056857849257, 0.9561147753018562], 
             UndirectedEdge[176, 354] -> 
             RGBColor[
              0.22476081103687653`, 0.35356824143122134`, 0.936111167733503], 
             UndirectedEdge[42, 148] -> 
             RGBColor[
              0.27524609124263133`, 0.40429858097089644`, 0.9390716483190401],
              UndirectedEdge[320, 380] -> 
             RGBColor[
              0.20795844756120663`, 0.3359078920869173, 0.9351542979904328], 
             UndirectedEdge[51, 222] -> 
             RGBColor[
              0.3069819930795281, 0.4332541041734357, 0.9410401002851541], 
             UndirectedEdge[122, 319] -> 
             RGBColor[
              0.5256622973684795, 0.6257953596771879, 0.9558012080947398], 
             UndirectedEdge[27, 78] -> 
             RGBColor[
              0.8204879075828598, 0.15848461230601768`, 0.16725254948011575`],
              UndirectedEdge[5, 178] -> 
             RGBColor[
              0.36206488822589933`, 0.4855919281825182, 0.9443804876389659], 
             UndirectedEdge[196, 336] -> 
             RGBColor[
              0.18504438325654066`, 0.31182375766712467`, 0.9338493759266024],
              UndirectedEdge[297, 318] -> 
             RGBColor[
              0.20065548392565413`, 0.32823201427131354`, 0.9347384050151546],
              UndirectedEdge[127, 235] -> 
             RGBColor[
              0.19315907110692182`, 0.32035280909880115`, 0.9343114953950769],
              UndirectedEdge[45, 203] -> 
             RGBColor[
              0.2552832201033739, 0.38564922859261863`, 0.9378493737759823], 
             UndirectedEdge[305, 370] -> 
             RGBColor[
              0.18466045373978385`, 0.311420223402476, 0.9338275117085959], 
             UndirectedEdge[122, 169] -> 
             RGBColor[
              0.7468757612194565, 0.8021168965628588, 0.9757076451280708], 
             UndirectedEdge[51, 226] -> 
             RGBColor[
              0.41340915500198794`, 0.532495964339595, 0.9475630436867326], 
             UndirectedEdge[226, 395] -> 
             RGBColor[
              0.45693963376297164`, 0.5697838781949226, 0.9504517090480242], 
             UndirectedEdge[61, 354] -> 
             RGBColor[
              0.21260864100273835`, 0.3407955402332605, 0.9354191196275834], 
             UndirectedEdge[211, 334] -> 
             RGBColor[
              0.20343525046697647`, 0.3311537251536216, 0.9348967086073869], 
             UndirectedEdge[10, 361] -> 
             RGBColor[
              0.22756848714061534`, 0.35651928703319763`, 0.9362710607340264],
              UndirectedEdge[44, 249] -> 
             RGBColor[
              0.27287548484168234`, 0.4041092659680885, 0.9388523457495259], 
             UndirectedEdge[302, 377] -> 
             RGBColor[
              0.18805566555367964`, 0.3149888062877428, 0.9340208639986316], 
             UndirectedEdge[149, 363] -> 
             RGBColor[
              0.21825217126115545`, 0.34672724835534197`, 0.9357405103269454],
              UndirectedEdge[358, 359] -> 
             RGBColor[
              0.18898988195831087`, 0.3159707269617513, 0.934074066240826], 
             UndirectedEdge[126, 317] -> 
             RGBColor[
              0.1909701324562666, 0.31805209579023613`, 0.9341868385771666], 
             UndirectedEdge[194, 364] -> 
             RGBColor[
              0.9061043939482173, 0.5637958920619978, 0.4053724452164604], 
             UndirectedEdge[184, 343] -> 
             RGBColor[
              0.18256566753029357`, 0.30921847027918486`, 0.933708216732924], 
             UndirectedEdge[118, 346] -> 
             RGBColor[
              0.2949738551719156, 0.42345379048504006`, 0.9402529639443298], 
             UndirectedEdge[169, 239] -> 
             RGBColor[
              0.8617758088916869, 0.5670725642786435, 0.5820707130728167], 
             UndirectedEdge[72, 157] -> 
             RGBColor[
              0.1851041505972344, 0.3118865769316621, 0.9338527795882372], 
             UndirectedEdge[162, 191] -> 
             RGBColor[
              0.239776323432642, 0.3693504969976439, 0.936966278950982], 
             UndirectedEdge[84, 272] -> 
             RGBColor[
              0.5398855520007457, 0.6327240010263296, 0.9588121937440683], 
             UndirectedEdge[21, 160] -> 
             RGBColor[
              0.7114127926044326, 0.7298581356264684, 0.631074971265499], 
             UndirectedEdge[29, 336] -> 
             RGBColor[
              0.18089581060751259`, 0.30746334477829806`, 0.9336131208515035],
              UndirectedEdge[275, 276] -> 
             RGBColor[
              0.2308037275414878, 0.35991972982060355`, 0.9364553028887468], 
             UndirectedEdge[38, 303] -> 
             RGBColor[
              0.21808265414273661`, 0.3465490751158777, 0.9357308565778295], 
             UndirectedEdge[172, 285] -> 
             RGBColor[
              0.9090011322761398, 0.5869841292419617, 0.39020330546201376`], 
             UndirectedEdge[73, 285] -> 
             RGBColor[
              0.9624071777351879, 0.8763102692580285, 0.43650448397981056`], 
             UndirectedEdge[5, 59] -> 
             RGBColor[
              0.31447583347960173`, 0.4443726808567142, 0.9413481551518805], 
             UndirectedEdge[73, 225] -> 
             RGBColor[
              0.9076627958063523, 0.836763929150959, 0.6259476546026368], 
             UndirectedEdge[64, 254] -> 
             RGBColor[
              0.1839453796797469, 0.3106686352270631, 0.9337867892987342], 
             UndirectedEdge[241, 390] -> 
             RGBColor[
              0.2629620790942533, 0.393720196259813, 0.938286673435659], 
             UndirectedEdge[58, 289] -> 
             RGBColor[
              0.19906319498854463`, 0.3265584176414619, 0.9346477265157667], 
             UndirectedEdge[262, 331] -> 
             RGBColor[
              0.20664951421908523`, 0.3345321201531805, 0.9350797561729924], 
             UndirectedEdge[22, 118] -> 
             RGBColor[
              0.2775783272389005, 0.4083866585141185, 0.9391445362866995], 
             UndirectedEdge[97, 360] -> 
             RGBColor[
              0.189069412661027, 0.31605431877284385`, 0.9340785953966906], 
             UndirectedEdge[301, 358] -> 
             RGBColor[
              0.18673627600332035`, 0.31360204421618604`, 0.9339457267156006],
              UndirectedEdge[16, 274] -> 
             RGBColor[
              0.4054269963890745, 0.5245026293096915, 0.9473527216519175], 
             UndirectedEdge[166, 319] -> 
             RGBColor[
              0.7215283330281927, 0.7785525624499918, 0.8852776399757938], 
             UndirectedEdge[82, 101] -> 
             RGBColor[
              0.181913405203708, 0.30853290121812327`, 0.9336710713583607], 
             UndirectedEdge[24, 399] -> 
             RGBColor[
              0.8736814566563863, 0.4536940034692628, 0.2136591990821675], 
             UndirectedEdge[328, 400] -> 
             RGBColor[
              0.8598546185049423, 0.443575414393966, 0.20426493980685678`], 
             UndirectedEdge[17, 371] -> 
             RGBColor[
              0.20911196002482746`, 0.33712030682309724`, 0.9352199888187673],
              UndirectedEdge[107, 158] -> 
             RGBColor[
              0.34368740964077826`, 0.4721064928245296, 0.9431204357248351], 
             UndirectedEdge[60, 394] -> 
             RGBColor[
              0.18321858514836378`, 0.3099047280931446, 0.933745399425368], 
             UndirectedEdge[219, 284] -> 
             RGBColor[
              0.3068620452246301, 0.43723797575946177`, 0.9408827842352088], 
             UndirectedEdge[124, 149] -> 
             RGBColor[
              0.2631665511656537, 0.3938441656371931, 0.9383016477132344], 
             UndirectedEdge[227, 296] -> 
             RGBColor[
              0.22621507415997788`, 0.35509676417920844`, 0.9361939858669741],
              UndirectedEdge[202, 229] -> 
             RGBColor[
              0.22512118954774685`, 0.35394702209546336`, 0.9361316907565649],
              UndirectedEdge[315, 358] -> 
             RGBColor[
              0.20481090918793238`, 0.33259962969114687`, 0.9349750503364407],
              UndirectedEdge[145, 222] -> 
             RGBColor[
              0.21482177415136725`, 0.3431216834932156, 0.9355451542863606], 
             UndirectedEdge[155, 299] -> 
             RGBColor[
              0.19737174909206562`, 0.3247806007603985, 0.9345514011742322], 
             UndirectedEdge[14, 29] -> 
             RGBColor[
              0.18299367418147944`, 0.3096683324067703, 0.9337325910785299], 
             UndirectedEdge[116, 151] -> 
             RGBColor[
              0.18767873323802545`, 0.31459262652510106`, 0.9339993982608765],
              UndirectedEdge[45, 257] -> 
             RGBColor[
              0.30395689687858984`, 0.4354808171950546, 0.9406698751035344], 
             UndirectedEdge[27, 240] -> 
             RGBColor[
              0.8263635800404189, 0.20364760555090494`, 0.1728791000610972], 
             UndirectedEdge[144, 188] -> 
             RGBColor[
              0.19616736828116454`, 0.3235147201659876, 0.934482813468773], 
             UndirectedEdge[76, 200] -> 
             RGBColor[
              0.1890554468047247, 0.31603963977238364`, 0.9340778000618348], 
             UndirectedEdge[90, 221] -> 
             RGBColor[
              0.755343522572024, 0.6711176068414135, 0.6012544985481333], 
             UndirectedEdge[271, 382] -> 
             RGBColor[
              0.18049565541513857`, 0.3070427562998084, 0.9335903326052744], 
             UndirectedEdge[242, 385] -> 
             RGBColor[
              0.9233493722002852, 0.696643340637751, 0.416149434312738], 
             UndirectedEdge[74, 112] -> 
             RGBColor[
              0.9000839613583336, 0.841002686126469, 0.6275271765854877], 
             UndirectedEdge[237, 251] -> 
             RGBColor[
              0.19380336074719554`, 0.32102999836105145`, 0.9343481867369493],
              UndirectedEdge[25, 223] -> 
             RGBColor[
              0.8736105747823911, 0.4469597061439798, 0.21333691400652116`], 
             UndirectedEdge[284, 332] -> 
             RGBColor[
              0.2524716906122939, 0.382694132836228, 0.9376892613307504], 
             UndirectedEdge[145, 333] -> 
             RGBColor[
              0.19268508450271393`, 0.3198546191252922, 0.9342845025591675], 
             UndirectedEdge[146, 227] -> 
             RGBColor[
              0.19680598858419968`, 0.3241859505953433, 0.934519181950277], 
             UndirectedEdge[108, 286] -> 
             RGBColor[
              0.22549943873113315`, 0.3543445859695858, 0.9361532314879892], 
             UndirectedEdge[127, 361] -> 
             RGBColor[
              0.2062200768333135, 0.33408075423283157`, 0.9350553003491684], 
             UndirectedEdge[143, 258] -> 
             RGBColor[
              0.1842254727690224, 0.31096303082281923`, 0.9338027401858078], 
             UndirectedEdge[212, 310] -> 
             RGBColor[
              0.34846775564587945`, 0.473552157244567, 0.9435237061098725], 
             UndirectedEdge[107, 310] -> 
             RGBColor[
              0.3141088853648525, 0.4437922307341744, 0.9413343892779213], 
             UndirectedEdge[253, 394] -> 
             RGBColor[
              0.1857625991924869, 0.31257864815332465`, 0.9338902772616493], 
             UndirectedEdge[152, 284] -> 
             RGBColor[
              0.26668400229217915`, 0.3976321735243937, 0.9384986314556889], 
             UndirectedEdge[230, 364] -> 
             RGBColor[
              0.8177077184461266, 0.13711486031443826`, 0.16459023722300553`],
              UndirectedEdge[158, 241] -> 
             RGBColor[
              0.3009846875478195, 0.43090972620672763`, 0.9405535979845862], 
             UndirectedEdge[44, 315] -> 
             RGBColor[
              0.22776027402374388`, 0.3567208672073564, 0.9362819827132973], 
             UndirectedEdge[357, 385] -> 
             RGBColor[
              0.9257629036983032, 0.7151948013477634, 0.418460634800934], 
             UndirectedEdge[99, 197] -> 
             RGBColor[
              0.9649742133445314, 0.9733984061785892, 0.9441737000062027], 
             UndirectedEdge[152, 267] -> 
             RGBColor[
              0.25637803396755154`, 0.3867999473790775, 0.9379117218059152], 
             UndirectedEdge[169, 197] -> 
             RGBColor[
              0.9300501065256308, 0.9463228877887528, 0.9676089006734437], 
             UndirectedEdge[263, 348] -> 
             RGBColor[
              0.36254614474277536`, 0.48844098130229274`, 0.9443220976494096],
              UndirectedEdge[314, 379] -> 
             RGBColor[
              0.21988806256935944`, 0.348446673841764, 0.9358336719168633], 
             UndirectedEdge[300, 319] -> 
             RGBColor[
              0.6840306200166372, 0.7509595396670409, 0.9709177458785374], 
             UndirectedEdge[25, 78] -> 
             RGBColor[
              0.8186282892765544, 0.1441907711138157, 0.16547177688985915`], 
             UndirectedEdge[44, 113] -> 
             RGBColor[
              0.27210008577250266`, 0.4033248206617401, 0.9388070693975159], 
             UndirectedEdge[115, 221] -> 
             RGBColor[
              0.8834582095203258, 0.5636927731060549, 0.2244670121341203], 
             UndirectedEdge[175, 319] -> 
             RGBColor[
              0.3675065660796395, 0.49023117564208835`, 0.944730223137449], 
             UndirectedEdge[176, 356] -> 
             RGBColor[
              0.21433034444536764`, 0.34260515971376704`, 0.9355171680916091],
              UndirectedEdge[84, 395] -> 
             RGBColor[
              0.4037383718237736, 0.5237036190763635, 0.9470617716812872], 
             UndirectedEdge[301, 359] -> 
             RGBColor[
              0.1849503238015024, 0.31172489521616553`, 0.9338440193797866], 
             UndirectedEdge[238, 280] -> 
             RGBColor[
              0.2707591220181621, 0.40191538273391547`, 0.9387307034954844], 
             UndirectedEdge[36, 168] -> 
             RGBColor[
              0.18854146293925098`, 0.3154994101413115, 0.9340485294410671], 
             UndirectedEdge[4, 232] -> 
             RGBColor[
              0.26395583592624494`, 0.3947646976980586, 0.9383432664171094], 
             UndirectedEdge[140, 339] -> 
             RGBColor[
              0.2386234653452058, 0.3681387700523239, 0.9369006253884031], 
             UndirectedEdge[18, 141] -> 
             RGBColor[
              0.7353689115489879, 0.586455396789142, 0.5858108169853278], 
             UndirectedEdge[123, 140] -> 
             RGBColor[
              0.21869849237699107`, 0.3471963601464784, 0.9357659276542193], 
             UndirectedEdge[24, 78] -> 
             RGBColor[
              0.8203622147555851, 0.15751848215663547`, 0.1671321858867677], 
             UndirectedEdge[62, 127] -> 
             RGBColor[
              0.1979549784065447, 0.32539361174879033`, 0.9345846152208812], 
             UndirectedEdge[299, 353] -> 
             RGBColor[
              0.188841530987085, 0.3158148006849981, 0.9340656178724803], 
             UndirectedEdge[256, 311] -> 
             RGBColor[
              0.32702639881790146`, 0.45712063802367703`, 0.942079129357128], 
             UndirectedEdge[47, 346] -> 
             RGBColor[
              0.44758503753245593`, 0.5596323527057516, 0.9504217995237683], 
             UndirectedEdge[34, 125] -> 
             RGBColor[
              0.2623800078372861, 0.3931084024632914, 0.9382535253386719], 
             UndirectedEdge[194, 387] -> 
             RGBColor[
              0.7643288542489235, 0.8116893614464729, 0.8013257295322668], 
             UndirectedEdge[117, 303] -> 
             RGBColor[
              0.21968824533158482`, 0.34823665325571823`, 0.9358222926207751],
              UndirectedEdge[287, 382] -> 
             RGBColor[
              0.18591195141547964`, 0.3127356268091679, 0.933898782649802], 
             UndirectedEdge[20, 168] -> 
             RGBColor[
              0.18724662483160132`, 0.31413845319269396`, 0.9339747903263778],
              UndirectedEdge[51, 355] -> 
             RGBColor[
              0.5736425498293158, 0.6609104438201203, 0.9614084888743977], 
             UndirectedEdge[183, 339] -> 
             RGBColor[
              0.30076734139659483`, 0.42964292042343744`, 0.9405792399327987],
              UndirectedEdge[118, 164] -> 
             RGBColor[
              0.21991695118991147`, 0.3484770376136085, 0.9358353170810669], 
             UndirectedEdge[51, 134] -> 
             RGBColor[
              0.6062730746331866, 0.6864904388777064, 0.9646372348684907], 
             UndirectedEdge[46, 356] -> 
             RGBColor[
              0.1981426064801053, 0.32559082075040946`, 0.9345953003620997], 
             UndirectedEdge[204, 276] -> 
             RGBColor[
              0.2082458481435212, 0.33620996832117933`, 0.9351706650284246], 
             UndirectedEdge[108, 154] -> 
             RGBColor[
              0.23083302352450608`, 0.3599505217562283, 0.9364569712516402], 
             UndirectedEdge[29, 119] -> 
             RGBColor[
              0.18192714786076558`, 0.30854734562202557`, 0.9336718539823496],
              UndirectedEdge[244, 264] -> 
             RGBColor[
              0.8390285444461558, 0.8747724603828321, 0.9672545655941249], 
             UndirectedEdge[217, 321] -> 
             RGBColor[
              0.7737155651854934, 0.8183397872541874, 0.7225530793389106], 
             UndirectedEdge[241, 346] -> 
             RGBColor[
              0.30713982911114474`, 0.4362410004624697, 0.9409457981622233], 
             UndirectedEdge[108, 284] -> 
             RGBColor[
              0.26637610871838646`, 0.39730855785675745`, 0.9384810973721491],
              UndirectedEdge[181, 334] -> 
             RGBColor[
              0.18995231521735206`, 0.3169823053387968, 0.934128875391136], 
             UndirectedEdge[8, 59] -> 
             RGBColor[
              0.2921622006654197, 0.4209196380029755, 0.9400774267731745], 
             UndirectedEdge[236, 383] -> 
             RGBColor[
              0.22956462143722656`, 0.3586173507411603, 0.9363847376292023], 
             UndirectedEdge[42, 290] -> 
             RGBColor[
              0.20736560396252507`, 0.33528477587624783`, 0.9351205364245214],
              UndirectedEdge[173, 209] -> 
             RGBColor[
              0.3086611648699239, 0.43934003290171275`, 0.940977513192154], 
             UndirectedEdge[154, 332] -> 
             RGBColor[
              0.2169286054184135, 0.3453360967356988, 0.9356651352102414], 
             UndirectedEdge[5, 352] -> 
             RGBColor[
              0.26102097459574697`, 0.3916799723587493, 0.9381761304060758], 
             UndirectedEdge[189, 226] -> 
             RGBColor[
              0.35594179006458193`, 0.47882793285764735`, 0.9440438043992346],
              UndirectedEdge[16, 390] -> 
             RGBColor[
              0.2902432136013212, 0.4215595588222458, 0.9398708612517093], 
             UndirectedEdge[119, 327] -> 
             RGBColor[
              0.18901152680793626`, 0.3159934770710704, 0.9340752988829915], 
             UndirectedEdge[129, 231] -> 
             RGBColor[
              0.18564063577461087`, 0.3124504568682096, 0.93388333162543], 
             UndirectedEdge[79, 352] -> 
             RGBColor[
              0.23532317406913467`, 0.3646699546706205, 0.9367126786825744], 
             UndirectedEdge[62, 361] -> 
             RGBColor[
              0.20937089592029476`, 0.33739246486671737`, 0.9352347348349528],
              UndirectedEdge[150, 347] -> 
             RGBColor[
              0.19569856946522865`, 0.3230219828868772, 0.9344561160697312], 
             UndirectedEdge[5, 90] -> 
             RGBColor[
              0.44540909938288953`, 0.5535702341777979, 0.950854414653335], 
             UndirectedEdge[24, 27] -> 
             RGBColor[
              0.8209125437853362, 0.16174855223502174`, 0.16765918158716517`],
              UndirectedEdge[62, 393] -> 
             RGBColor[
              0.19223452494535048`, 0.31938105246337734`, 0.9342588438589188],
              UndirectedEdge[199, 353] -> 
             RGBColor[
              0.18825533864421526`, 0.31519867536590085`, 0.9340322350857477],
              UndirectedEdge[96, 201] -> 
             RGBColor[
              0.8486214444306401, 0.8823678065342169, 0.9733384742305298], 
             UndirectedEdge[155, 170] -> 
             RGBColor[
              0.21937286170598153`, 0.34790516506873237`, 0.9358043319898652],
              UndirectedEdge[335, 394] -> 
             RGBColor[
              0.17996762986719622`, 0.30648776797016763`, 0.9335602623314629],
              UndirectedEdge[16, 310] -> 
             RGBColor[
              0.2986872977789616, 0.43043482667880517`, 0.9403517393537228], 
             UndirectedEdge[6, 277] -> 
             RGBColor[
              0.2567019144406389, 0.38714036629150045`, 0.9379301663197194], 
             UndirectedEdge[140, 232] -> 
             RGBColor[
              0.2603959916536444, 0.39102307566039235`, 0.9381405385521024], 
             UndirectedEdge[177, 300] -> 
             RGBColor[
              0.904775992937191, 0.9269078335507821, 0.990779535981055], 
             UndirectedEdge[24, 32] -> 
             RGBColor[
              0.8889095486255394, 0.5137521204514779, 0.227558818965985], 
             UndirectedEdge[102, 226] -> 
             RGBColor[
              0.3613558703292786, 0.48451847448835883`, 0.9443521282608951], 
             UndirectedEdge[187, 206] -> 
             RGBColor[
              0.5826167692195937, 0.6701866792756657, 0.9613440852325792], 
             UndirectedEdge[336, 396] -> 
             RGBColor[
              0.18995557631013382`, 0.31698573295407556`, 0.9341290611055455],
              UndirectedEdge[267, 332] -> 
             RGBColor[
              0.24216572228766625`, 0.37186190669091185`, 0.9371023516809767],
              UndirectedEdge[115, 300] -> 
             RGBColor[
              0.8896537545747043, 0.7064595554170632, 0.6002320083831638], 
             UndirectedEdge[149, 195] -> 
             RGBColor[
              0.20922588183301488`, 0.33724004586656203`, 0.9352264764972114],
              UndirectedEdge[127, 396] -> 
             RGBColor[
              0.197181010085485, 0.3245801219709307, 0.9345405388699805], 
             UndirectedEdge[206, 220] -> 
             RGBColor[
              0.6830678662474279, 0.7522369451466808, 0.9691139391554754], 
             UndirectedEdge[298, 361] -> 
             RGBColor[
              0.2073168336633886, 0.33523351519963984`, 0.9351177590281349], 
             UndirectedEdge[27, 141] -> 
             RGBColor[
              0.8433178856733501, 0.32265315137636846`, 0.18867158623389835`],
              UndirectedEdge[55, 221] -> 
             RGBColor[
              0.9369698505827507, 0.7826274582869746, 0.292244768605455], 
             UndirectedEdge[40, 269] -> 
             RGBColor[
              0.6323207129287618, 0.7108348666826005, 0.9652579027218493], 
             UndirectedEdge[191, 312] -> 
             RGBColor[
              0.25506639270437426`, 0.3854213292486189, 0.9378370257763766], 
             UndirectedEdge[78, 240] -> 
             RGBColor[
              0.8258132510106677, 0.19941753547251867`, 0.17235210436069973`],
              UndirectedEdge[183, 246] -> 
             RGBColor[
              0.63511612996041, 0.7084027410096546, 0.967888425757446], 
             UndirectedEdge[130, 164] -> 
             RGBColor[
              0.19148238974395732`, 0.318590510678587, 0.9342160108718838], 
             UndirectedEdge[190, 295] -> 
             RGBColor[
              0.6926270864337125, 0.7564495900659256, 0.953776079551644], 
             UndirectedEdge[18, 179] -> 
             RGBColor[
              0.5295441815391476, 0.6289468481238254, 0.9561068042364651], 
             UndirectedEdge[128, 199] -> 
             RGBColor[
              0.1905507884017967, 0.3176113386010396, 0.9341629575536283], 
             UndirectedEdge[350, 355] -> 
             RGBColor[
              0.879778802399924, 0.9043102631133229, 0.8644296794931206], 
             UndirectedEdge[233, 348] -> 
             RGBColor[
              0.6462730001834412, 0.7161082281260901, 0.948023487805811], 
             UndirectedEdge[247, 316] -> 
             RGBColor[
              0.21599089502507074`, 0.3443505036580227, 0.9356117339905587], 
             UndirectedEdge[74, 399] -> 
             RGBColor[
              0.8948180568355072, 0.820125129452121, 0.6232901061997559], 
             UndirectedEdge[155, 171] -> 
             RGBColor[
              0.19802203394015824`, 0.32546409136618454`, 0.9345884339343208],
              UndirectedEdge[21, 95] -> 
             RGBColor[
              0.7613060096832925, 0.7703636969149021, 0.6350027480788232], 
             UndirectedEdge[257, 325] -> 
             RGBColor[
              0.30612175947263687`, 0.43775622504161427`, 0.9407931608256381],
              UndirectedEdge[250, 372] -> 
             RGBColor[
              0.22620791914637717`, 0.35508924380626006`, 0.9361935783995345],
              UndirectedEdge[156, 400] -> 
             RGBColor[
              0.8405821739101607, 0.3129379486613033, 0.18649484160836693`], 
             UndirectedEdge[193, 360] -> 
             RGBColor[
              0.18609708652812662`, 0.31293021555080397`, 0.9339093258205844],
              UndirectedEdge[92, 135] -> 
             RGBColor[
              0.746116355711272, 0.7971097200029147, 0.816782693533676], 
             UndirectedEdge[102, 174] -> 
             RGBColor[
              0.3107339262181662, 0.44067229083220405`, 0.9411265427453626], 
             UndirectedEdge[140, 275] -> 
             RGBColor[
              0.23222474174375346`, 0.36141330584468895`, 0.9365362275453637],
              UndirectedEdge[101, 301] -> 
             RGBColor[
              0.1828984857165501, 0.3095682832948322, 0.9337271702362709], 
             UndirectedEdge[337, 398] -> 
             RGBColor[
              0.7100705314017086, 0.7665791120076357, 0.7708912737801167], 
             UndirectedEdge[149, 249] -> 
             RGBColor[
              0.2628399368216051, 0.3935612687084925, 0.9382808361360453], 
             UndirectedEdge[92, 165] -> 
             RGBColor[
              0.6970699985324673, 0.761675381939551, 0.9717947555325273], 
             UndirectedEdge[150, 320] -> 
             RGBColor[
              0.19466927104284892`, 0.32194012498366686`, 0.9343974990472872],
              UndirectedEdge[59, 175] -> 
             RGBColor[
              0.314081747786117, 0.4439584718063857, 0.9413257125546342], 
             UndirectedEdge[278, 379] -> 
             RGBColor[
              0.232633859519395, 0.36184331456645336`, 0.936559526197451], 
             UndirectedEdge[87, 317] -> 
             RGBColor[
              0.19676650353045996`, 0.3241444493003659, 0.9345169333348793], 
             UndirectedEdge[212, 324] -> 
             RGBColor[
              0.5252330264468776, 0.6244698739960914, 0.9560373579630563], 
             UndirectedEdge[135, 328] -> 
             RGBColor[
              0.932186507346842, 0.7459139489960613, 0.44641772294044424`], 
             UndirectedEdge[176, 344] -> 
             RGBColor[
              0.21245918803275743`, 0.3406384556859449, 0.9354106085020388], 
             UndirectedEdge[59, 213] -> 
             RGBColor[
              0.2845653105942021, 0.4129348248674753, 0.9396447951222104], 
             UndirectedEdge[371, 391] -> 
             RGBColor[
              0.18383722908563283`, 0.3105549620955055, 0.9337806302823939], 
             UndirectedEdge[98, 318] -> 
             RGBColor[
              0.1977029240139366, 0.3251286866009877, 0.9345702610961033], 
             UndirectedEdge[25, 244] -> 
             RGBColor[
              0.8860422114357496, 0.549955853479581, 0.56283625969903], 
             UndirectedEdge[204, 224] -> 
             RGBColor[
              0.1864844568543232, 0.3133373663243338, 0.9339313859875982], 
             UndirectedEdge[180, 236] -> 
             RGBColor[
              0.2546593406268537, 0.3849934917065525, 0.9378138447627414], 
             UndirectedEdge[102, 163] -> 
             RGBColor[
              0.272133057471457, 0.4033594760078676, 0.938808947086994], 
             UndirectedEdge[16, 107] -> 
             RGBColor[
              0.33319709362883454`, 0.4630203083535974, 0.9424520020647762], 
             UndirectedEdge[194, 223] -> 
             RGBColor[
              0.9622169086067585, 0.8752522636294204, 0.4543198910461633], 
             UndirectedEdge[111, 291] -> 
             RGBColor[
              0.18821279065920096`, 0.31515395473595276`, 0.9340298120409453],
              UndirectedEdge[108, 205] -> 
             RGBColor[
              0.3030856171044626, 0.43207672625167026`, 0.9407113666179867], 
             UndirectedEdge[66, 297] -> 
             RGBColor[
              0.21059566017891732`, 0.33867976975706876`, 0.935304483347605], 
             UndirectedEdge[19, 284] -> 
             RGBColor[
              0.2685014480461575, 0.3995424242445413, 0.938602132302708], 
             UndirectedEdge[23, 260] -> 
             RGBColor[
              0.2588190028871956, 0.3893655604799919, 0.938050731374799], 
             UndirectedEdge[10, 256] -> 
             RGBColor[
              0.29440488188335295`, 0.4228333554018322, 0.9402213822269152], 
             UndirectedEdge[230, 242] -> 
             RGBColor[
              0.8350058714331137, 0.2700760442713933, 0.18115496805881381`], 
             UndirectedEdge[29, 317] -> 
             RGBColor[
              0.1883961858281423, 0.3153467146864354, 0.9340402561245076], 
             UndirectedEdge[124, 316] -> 
             RGBColor[
              0.27204171641094554`, 0.40317252702797246`, 0.9388070752443234],
              UndirectedEdge[306, 361] -> 
             RGBColor[
              0.21017418029056079`, 0.33823676767103766`, 0.9352804806914867],
              UndirectedEdge[1, 393] -> 
             RGBColor[
              0.1884550205876297, 0.3154085537489959, 0.9340436066770222], 
             UndirectedEdge[74, 279] -> 
             RGBColor[
              0.7676471267223055, 0.8187592045069678, 0.9773831565887533], 
             UndirectedEdge[40, 234] -> 
             RGBColor[
              0.653391331063141, 0.7272953937118065, 0.9673580250213626], 
             UndirectedEdge[195, 316] -> 
             RGBColor[
              0.21810104707830674`, 0.3465684072573414, 0.9357319040283003], 
             UndirectedEdge[279, 325] -> 
             RGBColor[
              0.4806866627377453, 0.5825538322263442, 0.9538715491644547], 
             UndirectedEdge[172, 337] -> 
             RGBColor[
              0.9089250228286312, 0.5868213388295864, 0.3819192617937752], 
             UndirectedEdge[148, 275] -> 
             RGBColor[
              0.28636427371918854`, 0.4159844956872421, 0.939704812363203], 
             UndirectedEdge[13, 188] -> 
             RGBColor[
              0.20797364918202638`, 0.3359238699542373, 0.9351551637002498], 
             UndirectedEdge[220, 233] -> 
             RGBColor[
              0.7976144359577942, 0.8422371475965424, 0.9590360291130758], 
             UndirectedEdge[230, 244] -> 
             RGBColor[
              0.8862518697580262, 0.551567379217462, 0.5630370287452173], 
             UndirectedEdge[253, 358] -> 
             RGBColor[
              0.19093438586024153`, 0.31801452385134865`, 0.9341848028614053],
              UndirectedEdge[66, 140] -> 
             RGBColor[
              0.21998497488731555`, 0.3485485348325317, 0.9358391909300019], 
             UndirectedEdge[89, 128] -> 
             RGBColor[
              0.1919283928758168, 0.31905928824840313`, 0.9342414100904406], 
             UndirectedEdge[199, 298] -> 
             RGBColor[
              0.19174373818706897`, 0.31886520446274574`, 0.9342308942790887],
              UndirectedEdge[367, 398] -> 
             RGBColor[
              0.40058820107881166`, 0.5213910984512207, 0.9467461038398723], 
             UndirectedEdge[72, 181] -> 
             RGBColor[
              0.1888688995598306, 0.3158435667902215, 0.9340671764722099], 
             UndirectedEdge[229, 329] -> 
             RGBColor[
              0.1986631863683978, 0.3261379832196762, 0.934624946616609], 
             UndirectedEdge[196, 326] -> 
             RGBColor[
              0.19087356510240117`, 0.3179505973785997, 0.9341813392092224], 
             UndirectedEdge[247, 362] -> 
             RGBColor[
              0.19339653330473627`, 0.32060239692467707`, 0.9343250185159485],
              UndirectedEdge[276, 297] -> 
             RGBColor[
              0.21488882463476794`, 0.3431921578025159, 0.9355489727121981], 
             UndirectedEdge[7, 201] -> 
             RGBColor[
              0.698844545732584, 0.7622666344739716, 0.960474027707296], 
             UndirectedEdge[191, 214] -> 
             RGBColor[
              0.2234844168401749, 0.3522266702024217, 0.9360384789722569], 
             UndirectedEdge[25, 32] -> 
             RGBColor[
              0.8871756231465087, 0.5004244094086581, 0.22589840996907645`], 
             UndirectedEdge[190, 324] -> 
             RGBColor[
              0.7946744730052755, 0.8399555999055638, 0.9616274448568455], 
             UndirectedEdge[8, 296] -> 
             RGBColor[
              0.241386411848991, 0.3710428020087285, 0.9370579711043807], 
             UndirectedEdge[292, 382] -> 
             RGBColor[
              0.1881384932660469, 0.31507586346502103`, 0.9340255809143183], 
             UndirectedEdge[223, 328] -> 
             RGBColor[
              0.8997164529222819, 0.6301219365340252, 0.23765071588506692`], 
             UndirectedEdge[70, 262] -> 
             RGBColor[
              0.2185336488556363, 0.3470230991538516, 0.9357565400595423], 
             UndirectedEdge[78, 285] -> 
             RGBColor[
              0.907068308455854, 0.5721275983904466, 0.38835243118889584`], 
             UndirectedEdge[167, 272] -> 
             RGBColor[
              0.5255938312060932, 0.6203452307967748, 0.9579015379327056], 
             UndirectedEdge[93, 276] -> 
             RGBColor[
              0.22858867995178067`, 0.3575915743616926, 0.9363291592053822], 
             UndirectedEdge[56, 319] -> 
             RGBColor[
              0.4175060909791842, 0.5360433358043497, 0.9478244252272849], 
             UndirectedEdge[93, 162] -> 
             RGBColor[
              0.2533245521097741, 0.3835905443446218, 0.9377378305313364], 
             UndirectedEdge[106, 389] -> 
             RGBColor[
              0.21473367973065993`, 0.34302909067154336`, 0.9355401374394254],
              UndirectedEdge[68, 176] -> 
             RGBColor[
              0.2518475893962128, 0.38203816288782416`, 0.9376537196897696], 
             UndirectedEdge[253, 301] -> 
             RGBColor[
              0.18689482770343305`, 0.31376869210576286`, 0.9339547560003658],
              UndirectedEdge[217, 357] -> 
             RGBColor[
              0.9250850387636083, 0.713744916795109, 0.34467921995684786`], 
             UndirectedEdge[364, 385] -> 
             RGBColor[
              0.9060512192132981, 0.563682156680796, 0.3995847034769297], 
             UndirectedEdge[161, 372] -> 
             RGBColor[
              0.19676171310914198`, 0.3241394142638304, 0.934516660527472], 
             UndirectedEdge[4, 339] -> 
             RGBColor[
              0.24218330961780632`, 0.3718803920899902, 0.9371033532534101], 
             UndirectedEdge[183, 280] -> 
             RGBColor[
              0.30076148412422865`, 0.4296367640588081, 0.9405789063698025], 
             UndirectedEdge[94, 145] -> 
             RGBColor[
              0.18922208139469943`, 0.31621478329169034`, 0.9340872896552201],
              UndirectedEdge[107, 351] -> 
             RGBColor[
              0.6292040524803684, 0.703641559800374, 0.9673461867380587], 
             UndirectedEdge[90, 178] -> 
             RGBColor[
              0.5250344578406001, 0.6249699305004974, 0.9558390168550672], 
             UndirectedEdge[113, 124] -> 
             RGBColor[
              0.3086276211264817, 0.4416266325643382, 0.9408905883938774], 
             UndirectedEdge[191, 365] -> 
             RGBColor[
              0.19407713550409694`, 0.321317752988877, 0.9343637778043414], 
             UndirectedEdge[184, 356] -> 
             RGBColor[
              0.18905111217950674`, 0.3160350838064485, 0.9340775532113412], 
             UndirectedEdge[196, 327] -> 
             RGBColor[
              0.19267128104236286`, 0.3198401108132733, 0.9342837164725208], 
             UndirectedEdge[140, 288] -> 
             RGBColor[
              0.2655351688852008, 0.39642467677341436`, 0.9384332070927082], 
             UndirectedEdge[13, 232] -> 
             RGBColor[
              0.2546277618608894, 0.3849603004213146, 0.9378120463987364], 
             UndirectedEdge[34, 86] -> 
             RGBColor[
              0.3371353879041764, 0.46222487105446, 0.9428569705546225], 
             UndirectedEdge[287, 374] -> 
             RGBColor[
              0.19007574708878708`, 0.31711204006170757`, 0.9341359046536132],
              UndirectedEdge[201, 230] -> 
             RGBColor[
              0.8833910407331164, 0.5494337776148619, 0.5678796660606804], 
             UndirectedEdge[71, 138] -> 
             RGBColor[
              0.18058969715831197`, 0.30714160013447456`, 0.9335956881434259],
              UndirectedEdge[334, 360] -> 
             RGBColor[
              0.185115098539477, 0.3118980839130987, 0.9338534030573518], 
             UndirectedEdge[38, 58] -> 
             RGBColor[
              0.2174442667054725, 0.3458780894432118, 0.935694501357687], 
             UndirectedEdge[115, 239] -> 
             RGBColor[
              0.8461854795987771, 0.346251043142995, 0.19147853854411218`], 
             UndirectedEdge[32, 78] -> 
             RGBColor[
              0.888484912423063, 0.5104881805224738, 0.22715218685893562`], 
             UndirectedEdge[41, 83] -> 
             RGBColor[
              0.9084527486796484, 0.9295988421678656, 0.9827837388659694], 
             UndirectedEdge[90, 212] -> 
             RGBColor[
              0.5128575453871849, 0.6144229009627645, 0.9550631147611566], 
             UndirectedEdge[160, 263] -> 
             RGBColor[
              0.42578806203725694`, 0.5430467428327064, 0.9483991221427692], 
             UndirectedEdge[226, 350] -> 
             RGBColor[
              0.7195454075725961, 0.7758957836327975, 0.8505842343054555], 
             UndirectedEdge[159, 329] -> 
             RGBColor[
              0.18547778561514033`, 0.3122792910253096, 0.9338740575497635], 
             UndirectedEdge[132, 260] -> 
             RGBColor[
              0.29142760754703456`, 0.4190601234916939, 0.9400754082095211], 
             UndirectedEdge[7, 250] -> 
             RGBColor[
              0.35349640883612216`, 0.4759428684075872, 0.943916070428803], 
             UndirectedEdge[135, 281] -> 
             RGBColor[
              0.711765095722288, 0.768553055573181, 0.8142632180180123], 
             UndirectedEdge[240, 243] -> 
             RGBColor[
              0.9006075598972731, 0.6106868981753124, 0.5572235175535094], 
             UndirectedEdge[105, 349] -> 
             RGBColor[
              0.20573070891450085`, 0.3335663975224413, 0.935027431570147], 
             UndirectedEdge[111, 154] -> 
             RGBColor[
              0.19738148096805996`, 0.3247908295791051, 0.934551955390173], 
             UndirectedEdge[3, 233] -> 
             RGBColor[
              0.7706376185941841, 0.8203361519689907, 0.9569123152308744], 
             UndirectedEdge[125, 162] -> 
             RGBColor[
              0.2669203824734684, 0.39788062408229774`, 0.9385120929573202], 
             UndirectedEdge[301, 369] -> 
             RGBColor[
              0.18664719483068826`, 0.31350841425567716`, 0.9339406536746029],
              UndirectedEdge[268, 270] -> 
             RGBColor[
              0.5192310696539062, 0.6174490867384653, 0.9563893333020512], 
             UndirectedEdge[4, 188] -> 
             RGBColor[
              0.2173017232473819, 0.34572826723098127`, 0.9356863837186229], 
             UndirectedEdge[161, 176] -> 
             RGBColor[
              0.21656199837052442`, 0.34495076948413805`, 0.9356442574812107],
              UndirectedEdge[106, 270] -> 
             RGBColor[
              0.2929589759941193, 0.42059333525935383`, 0.9401654130551529], 
             UndirectedEdge[190, 268] -> 
             RGBColor[
              0.8177911045280821, 0.8581558703042615, 0.9638348308947651], 
             UndirectedEdge[220, 341] -> 
             RGBColor[
              0.4860287842689018, 0.590440011686344, 0.9535595010943037], 
             UndirectedEdge[76, 103] -> 
             RGBColor[
              0.19412197120965846`, 0.32136487815817005`, 0.9343663311314445],
              UndirectedEdge[84, 163] -> 
             RGBColor[
              0.3028162711208553, 0.4328272844297121, 0.940658180484038], 
             UndirectedEdge[356, 372] -> 
             RGBColor[
              0.1945300591839852, 0.3217938044934594, 0.9343895711378705], 
             UndirectedEdge[243, 398] -> 
             RGBColor[
              0.6978102198330773, 0.7601382089599893, 0.9424198532319874], 
             UndirectedEdge[141, 243] -> 
             RGBColor[
              0.9175618655302045, 0.7296924440007758, 0.5730160037263106], 
             UndirectedEdge[192, 320] -> 
             RGBColor[
              0.18870690253434044`, 0.31567329764522667`, 0.9340579509812614],
              UndirectedEdge[83, 245] -> 
             RGBColor[
              0.8819322732807819, 0.5521345143978579, 0.5717957186100475], 
             UndirectedEdge[256, 313] -> 
             RGBColor[
              0.28483799884386285`, 0.41277795475190926`, 0.9396765623907513],
              UndirectedEdge[144, 186] -> 
             RGBColor[
              0.19870087032152506`, 0.3261775914437136, 0.9346270926619912], 
             UndirectedEdge[271, 371] -> 
             RGBColor[
              0.1828236944867615, 0.3094896729702865, 0.9337229109863782], 
             UndirectedEdge[317, 326] -> 
             RGBColor[
              0.19368284883535128`, 0.3209033327008066, 0.9343413237618512], 
             UndirectedEdge[194, 242] -> 
             RGBColor[
              0.9234025469352043, 0.6967570760189528, 0.42193717605226866`], 
             UndirectedEdge[305, 334] -> 
             RGBColor[
              0.18360707090558112`, 0.31031305125539965`, 0.9337675231145284],
              UndirectedEdge[252, 282] -> 
             RGBColor[
              0.31835440977210794`, 0.4463178036126423, 0.941647079240882], 
             UndirectedEdge[134, 239] -> 
             RGBColor[
              0.8293655507418161, 0.5412295041829576, 0.578979393717503], 
             UndirectedEdge[267, 398] -> 
             RGBColor[
              0.34104050458358826`, 0.46493592502132197`, 0.9431303829813984],
              UndirectedEdge[4, 297] -> 
             RGBColor[
              0.2198696831096341, 0.34842735586426754`, 0.9358326252338219], 
             UndirectedEdge[40, 272] -> 
             RGBColor[
              0.6309966022057711, 0.7098004613221861, 0.9651259277394999], 
             UndirectedEdge[203, 325] -> 
             RGBColor[
              0.2574480826974209, 0.38792463643917835`, 0.9379726594980861], 
             UndirectedEdge[315, 359] -> 
             RGBColor[
              0.2030249569861144, 0.33072248069112636`, 0.9348733430006266], 
             UndirectedEdge[132, 160] -> 
             RGBColor[
              0.40894844852211004`, 0.5284611159894712, 0.9473261168602697], 
             UndirectedEdge[283, 381] -> 
             RGBColor[
              0.20257187699290616`, 0.3302462648913338, 0.9348475407652852], 
             UndirectedEdge[40, 183] -> 
             RGBColor[
              0.43552341404886974`, 0.5498108720138242, 0.9494803631610341], 
             UndirectedEdge[131, 339] -> 
             RGBColor[
              0.23240211172972863`, 0.36159973294585546`, 0.9365463285036696],
              UndirectedEdge[156, 165] -> 
             RGBColor[
              0.8638677055732559, 0.5798421452000351, 0.5836596867408057], 
             UndirectedEdge[352, 379] -> 
             RGBColor[
              0.22335212736306764`, 0.3520876255743447, 0.9360309452822404], 
             UndirectedEdge[25, 194] -> 
             RGBColor[
              0.9059253338243674, 0.5624195574854407, 0.4052009770396422], 
             UndirectedEdge[174, 238] -> 
             RGBColor[
              0.3169893195658634, 0.44724710585547944`, 0.9414827781424888], 
             UndirectedEdge[66, 339] -> 
             RGBColor[
              0.23290928668708955`, 0.3621328059827914, 0.9365752113671932], 
             UndirectedEdge[67, 387] -> 
             RGBColor[
              0.4796742864541198, 0.5876973628554791, 0.9523916433059518], 
             UndirectedEdge[90, 190] -> 
             RGBColor[
              0.7822989919455827, 0.8299086268722369, 0.9606532016549456], 
             UndirectedEdge[271, 389] -> 
             RGBColor[
              0.19087423447573804`, 0.31795130093241747`, 0.9341813773290437],
              UndirectedEdge[19, 293] -> 
             RGBColor[
              0.3046492475878372, 0.4338240686707453, 0.9407966099576801], 
             UndirectedEdge[126, 327] -> 
             RGBColor[
              0.19109665502145906`, 0.31818507902824733`, 0.9341940438500809],
              UndirectedEdge[12, 310] -> 
             RGBColor[
              0.2940376027932159, 0.42638254196942454`, 0.9400563785381975], 
             UndirectedEdge[272, 350] -> 
             RGBColor[
              0.867391875594665, 0.894633501748924, 0.8631950663915847], 
             UndirectedEdge[215, 229] -> 
             RGBColor[
              0.19493972789376507`, 0.3222243922819345, 0.9344129011648419], 
             UndirectedEdge[57, 189] -> 
             RGBColor[
              0.24216202976271878`, 0.3718580256130724, 0.9371021413971435], 
             UndirectedEdge[104, 337] -> 
             RGBColor[
              0.9065279712784959, 0.568396550220559, 0.3796238425222831], 
             UndirectedEdge[194, 385] -> 
             RGBColor[
              0.9944784929138155, 0.9905983795896796, 0.6403962123397537], 
             UndirectedEdge[56, 166] -> 
             RGBColor[
              0.6856726502293173, 0.7474973607293266, 0.8829926191709212], 
             UndirectedEdge[258, 379] -> 
             RGBColor[
              0.19525485067885182`, 0.32255560630899927`, 0.9344308469412701],
              UndirectedEdge[9, 150] -> 
             RGBColor[
              0.19229026561489077`, 0.3194396394412268, 0.9342620182075883], 
             UndirectedEdge[294, 380] -> 
             RGBColor[
              0.20504200072556777`, 0.3328425215492514, 0.9349882106576397], 
             UndirectedEdge[296, 308] -> 
             RGBColor[
              0.22323052785896746`, 0.35195981678568156`, 0.9360240203703722],
              UndirectedEdge[33, 92] -> 
             RGBColor[
              0.3869660924415177, 0.5054181375626268, 0.9463177797578736], 
             UndirectedEdge[39, 283] -> 
             RGBColor[
              0.19607798492560893`, 0.3234207725920666, 0.934477723218905], 
             UndirectedEdge[11, 34] -> 
             RGBColor[
              0.28760640007487454`, 0.41932535119602954`, 0.9397010272469036],
              UndirectedEdge[105, 171] -> 
             RGBColor[
              0.19921926143757313`, 0.32672245337457523`, 0.9346566142691592],
              UndirectedEdge[110, 237] -> 
             RGBColor[
              0.19038343508665123`, 0.3174354396560086, 0.9341534270299079], 
             UndirectedEdge[8, 175] -> 
             RGBColor[
              0.2597318112605219, 0.39032497995575144`, 0.938102714461281], 
             UndirectedEdge[90, 373] -> 
             RGBColor[
              0.44011491122134366`, 0.5480057067490964, 0.9505529184695845], 
             UndirectedEdge[73, 104] -> 
             RGBColor[
              0.874812220102593, 0.4548689553377009, 0.21443306157225883`], 
             UndirectedEdge[232, 339] -> 
             RGBColor[
              0.2733203034534184, 0.404607346810652, 0.9388765589892938], 
             UndirectedEdge[178, 274] -> 
             RGBColor[
              0.46738436670940764`, 0.5781669894131862, 0.9513005905019778], 
             UndirectedEdge[224, 318] -> 
             RGBColor[
              0.18686239314258873`, 0.3137346013258456, 0.9339529089001083], 
             UndirectedEdge[132, 307] -> 
             RGBColor[
              0.3533139613151539, 0.48044452804031823`, 0.9437338310851009]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.1972575262297792, 0.3246605452899877, 0.9345448963512025], 
             316 -> RGBColor[
              0.23435379828218117`, 0.36365107925655765`, 0.9366574741655703],
              308 -> RGBColor[
              0.20150049615977755`, 0.32912017570624735`, 0.9347865272118044],
              160 -> RGBColor[
              0.4596234812344611, 0.572182073724828, 0.9506023905805157], 245 -> 
             RGBColor[
              0.818830055518114, 0.14574163486097447`, 0.1656649884706391], 
             155 -> RGBColor[
              0.2070813101039675, 0.3349859650056321, 0.9351043463098516], 
             213 -> RGBColor[
              0.22261848399738943`, 0.3513165198813409, 0.9359891653778931], 
             352 -> RGBColor[
              0.2396024194233052, 0.3691677128576799, 0.9369563753749182], 27 -> 
             RGBColor[
              0.821038236612611, 0.16271468238440395`, 0.16777954518051325`], 
             367 -> RGBColor[
              0.37508215881778845`, 0.49929904661568136`, 0.9451208813811075],
              19 -> RGBColor[
              0.26040419361571815`, 0.3910316964425663, 0.9381410056417089], 
             164 -> RGBColor[
              0.20095261322947336`, 0.32854431600871353`, 0.9347553260894438],
              190 -> RGBColor[
              0.9562193148935751, 0.9668690172486966, 0.9589934594404549], 
             103 -> RGBColor[
              0.19434739415987903`, 0.3216018119714924, 0.9343791686349763], 
             138 -> RGBColor[
              0.18225239431662393`, 0.3088892002689491, 0.9336903762868517], 
             291 -> RGBColor[
              0.18717515147111807`, 0.3140633301591533, 0.9339707200242335], 
             28 -> 
             RGBColor[
              0.20698871416859752`, 0.3348886408066369, 0.9350990731083157], 
             337 -> RGBColor[
              0.9940468194635823, 0.9896750737285114, 0.5934112212615963], 
             195 -> RGBColor[
              0.20184829587443234`, 0.32948573525812513`, 0.9348063338910304],
              114 -> RGBColor[
              0.24129060741956473`, 0.3709421054790498, 0.9370525151838548], 
             93 -> RGBColor[
              0.2343202347626608, 0.3636158018694917, 0.9366555627727864], 34 -> 
             RGBColor[
              0.2632481201845229, 0.3940208435817391, 0.93830296305259], 161 -> 
             RGBColor[
              0.1994550789542851, 0.32697031253633363`, 0.9346700437278752], 
             22 -> RGBColor[
              0.3162753653274515, 0.4483635578097335, 0.9413737645007089], 
             124 -> RGBColor[
              0.3097296345397099, 0.44269397479938727`, 0.9409566763230764], 
             84 -> RGBColor[
              0.3388378220394789, 0.4679060237916442, 0.9428114242912021], 46 -> 
             RGBColor[
              0.20129344185623907`, 0.3289025485052273, 0.9347747357755273], 
             241 -> RGBColor[
              0.2632132370288079, 0.3939841791733627, 0.938300976508477], 185 -> 
             RGBColor[
              0.3996003392677278, 0.5205354622018381, 0.9466831581588019], 
             390 -> RGBColor[
              0.2627109211596987, 0.39345621334626335`, 0.938272370362841], 
             121 -> RGBColor[
              0.3109061797336599, 0.4437130391115059, 0.9410316447424569], 
             322 -> RGBColor[
              0.1999051049994005, 0.32744331844304914`, 0.9346956720453906], 
             126 -> RGBColor[
              0.1865862227024127, 0.3134443286830033, 0.9339371814020978], 
             236 -> RGBColor[
              0.25077535368791876`, 0.38091117517473666`, 0.9375926574524128],
              78 -> RGBColor[
              0.8199375785531087, 0.1542545422276314, 0.1667255537797183], 
             376 -> RGBColor[
              0.209601906353837, 0.3376352714792777, 0.9352478905373938], 254 -> 
             RGBColor[
              0.18724741023772068`, 0.314139278704323, 0.9339748350540943], 
             290 -> RGBColor[
              0.19821724293608944`, 0.32566926839787347`, 0.9345995507978533],
              251 -> RGBColor[
              0.19027393338711107`, 0.3173203464269832, 0.9341471910701123], 
             165 -> RGBColor[
              0.8967495440562933, 0.920507761085305, 0.9900139661214994], 100 -> 
             RGBColor[
              0.2101475089071078, 0.33820873435596516`, 0.9352789617956558], 
             235 -> RGBColor[
              0.1915139828942802, 0.31862371708269777`, 0.9342178100550568], 
             70 -> RGBColor[
              0.22291581655962178`, 0.35162903525622036`, 0.9360060980274482],
              234 -> RGBColor[
              0.7857227396767522, 0.8325318430402561, 0.9792771577606599], 
             257 -> RGBColor[
              0.32310439559809073`, 0.45427852059311985`, 0.9418089042708796],
              135 -> RGBColor[
              0.9948422584139026, 0.9913764372120322, 0.679989842123797], 265 -> 
             RGBColor[
              0.18998272969436467`, 0.3170142728825262, 0.9341306074506077], 
             111 -> RGBColor[
              0.18925042984728385`, 0.3162445793127523, 0.934088904057657], 
             381 -> RGBColor[
              0.19616341759440778`, 0.32351056774371817`, 0.9344825884830068],
              182 -> RGBColor[
              0.34853172220347034`, 0.47630239288410453`, 0.9434291110376724],
              188 -> RGBColor[
              0.2017846044041309, 0.3294187914845658, 0.9348027067560198], 
             154 -> RGBColor[
              0.2055125320888361, 0.33333707984545796`, 0.935015006722689], 
             336 -> RGBColor[
              0.18035329176886106`, 0.3068931230811942, 0.933582225206227], 
             315 -> RGBColor[
              0.2188459842157359, 0.34735138342052185`, 0.9357743270962412], 
             368 -> RGBColor[
              0.1851720653526604, 0.311957959645659, 0.9338566472330878], 269 -> 
             RGBColor[
              0.743581503407994, 0.7996107889818441, 0.9750769131616334], 208 -> 
             RGBColor[
              0.9930152754848626, 0.9913796511608278, 0.7654184913108293], 86 -> 
             RGBColor[
              0.4110226556238299, 0.5304288985271809, 0.947410978056655], 119 -> 
             RGBColor[
              0.18241596627536708`, 0.30906112476864933`, 0.9336996914679191],
              377 -> RGBColor[
              0.18473621585810335`, 0.3114998541924255, 0.9338318262491543], 
             140 -> RGBColor[
              0.2256991535454318, 0.35455449890206425`, 0.9361646049512119], 
             85 -> RGBColor[
              0.24074527521724318`, 0.3703689267583512, 0.9370214593216792], 
             351 -> RGBColor[
              0.9097894237460113, 0.9309054071917814, 0.9912577214871428], 
             242 -> RGBColor[
              0.852273426221674, 0.40280203706702433`, 0.19769039802525293`], 
             117 -> 
             RGBColor[
              0.22614100723621103`, 0.3550189151462153, 0.9361897678652379], 
             47 -> RGBColor[
              0.5441036538714303, 0.6407668836599264, 0.9572529792315668], 81 -> 
             RGBColor[
              0.17955783501139488`, 0.30605704759422586`, 0.9335369251206622],
              275 -> RGBColor[
              0.23875032994207512`, 0.36827211278731364`, 0.9369078501395155],
              23 -> RGBColor[
              0.2930562064900811, 0.4253510322307103, 0.9400004894705796], 
             328 -> RGBColor[
              0.8695307562797816, 0.5004514607800906, 0.21284560375709155`], 
             110 -> RGBColor[
              0.18343408206602244`, 0.3101312290168976, 0.9337576716560296], 
             6 -> RGBColor[
              0.30558851701585305`, 0.4385232851876776, 0.9407141860151303], 
             218 -> RGBColor[
              0.19086057119328328`, 0.3179369399562554, 0.934180599225321], 
             108 -> RGBColor[
              0.256153514960176, 0.38656396366699863`, 0.9378989357805914], 
             297 -> RGBColor[
              0.20692052412863532`, 0.33481696875113837`, 0.935095189786418], 
             157 -> RGBColor[
              0.1873941802353717, 0.31429354327760956`, 0.9339831933883338], 
             354 -> RGBColor[
              0.2158527042869893, 0.34420525643050026`, 0.9356038642324599], 
             385 -> RGBColor[
              0.9944253181788963, 0.9904846442084778, 0.6346084706002231], 
             270 -> RGBColor[
              0.3590992451452233, 0.4854554501171043, 0.9441024642550272], 
             392 -> RGBColor[
              0.9910839134677017, 0.9905809833329919, 0.7974261581398643], 33 -> 
             RGBColor[
              0.2765417318743941, 0.4079932723314563, 0.939060014572192], 252 -> 
             RGBColor[
              0.3695662131784596, 0.4945214117423836, 0.9447694102025287], 
             394 -> RGBColor[
              0.18043226082461958`, 0.30697612456572376`, 0.9335867223771283],
              260 -> RGBColor[
              0.22458179928431016`, 0.35338008872927346`, 0.9361009732790185],
              159 -> RGBColor[
              0.1805122222555836, 0.3070601690995145, 0.9335912760623294], 
             183 -> RGBColor[
              0.3499869056482099, 0.4775627996442913, 0.943521834040003], 99 -> 
             RGBColor[
              0.965636915117815, 0.9738926480760296, 0.9430519187643377], 329 -> 
             RGBColor[
              0.19044334897469703`, 0.3174984129511047, 0.9341568390371975], 
             309 -> 
             RGBColor[
              0.2975965440226766, 0.4301232148514946, 0.9402590549762334], 17 -> 
             RGBColor[
              0.2316763474093035, 0.360836908628973, 0.9365049972992935], 349 -> 
             RGBColor[
              0.2019856527302044, 0.3296301060224692, 0.9348141561607654], 
             347 -> RGBColor[
              0.19785125300646603`, 0.3252845897767374, 0.9345787082127948], 
             340 -> RGBColor[
              0.2029347338096705, 0.33062765041220404`, 0.9348682049242014], 
             277 -> RGBColor[
              0.20781531186542476`, 0.3357574473953233, 0.9351461466243084], 
             104 -> RGBColor[
              0.8190091230934095, 0.14711802671260676`, 0.16583646378296987`],
              79 -> RGBColor[
              0.23104392871496413`, 0.36017219648356114`, 0.9364689819902305],
              327 -> RGBColor[
              0.19560708734050541`, 0.3229258293734914, 0.9344509062980639], 
             191 -> RGBColor[
              0.20722377740839654`, 0.33513570717553587`, 0.9351124596120775],
              50 -> RGBColor[
              0.1790362447681438, 0.3055088231778375, 0.9335072213279326], 
             225 -> RGBColor[
              0.884710274500928, 0.9109079743391231, 0.9888656498437259], 61 -> 
             RGBColor[
              0.20936457771848743`, 0.3373858240360207, 0.9352343750227069], 
             196 -> RGBColor[
              0.18973547474422028`, 0.3167543922530552, 0.9341165266469779], 
             1 -> RGBColor[
              0.19354678877808446`, 0.32076032495391327`, 0.9343335753428726],
              263 -> RGBColor[
              0.3919526428400527, 0.5139114119405849, 0.9461958537050229], 
             201 -> RGBColor[
              0.9490437648216794, 0.9615175037539616, 0.971139794028986], 371 -> 
             RGBColor[
              0.18654757264035143`, 0.3134037050172214, 0.9339349803382411], 
             293 -> RGBColor[
              0.3488943015599562, 0.47661644089892424`, 0.9434522142736513], 
             362 -> RGBColor[
              0.18916507484151227`, 0.3161548657898664, 0.9340840432163497], 
             184 -> RGBColor[
              0.18311045325504194`, 0.3097910746173054, 0.9337392414740102], 
             106 -> RGBColor[
              0.22681870684301533`, 0.35573122040160343`, 0.9362283618552786],
              206 -> RGBColor[
              0.7303132143006519, 0.7892455006884563, 0.9737544541026248], 
             358 -> RGBColor[
              0.19077583416012883`, 0.31784787596177183`, 0.9341757735766401],
              247 -> 
             RGBColor[
              0.1976279917679603, 0.3250499280594878, 0.9345659938155473], 
             220 -> RGBColor[
              0.635822518194204, 0.7152283896049052, 0.9644734242083259], 107 -> 
             RGBColor[
              0.34861868121472545`, 0.4763777124089667, 0.9434346519889747], 
             375 -> RGBColor[
              0.180596656524124, 0.30714891486919227`, 0.9335960844690134], 
             131 -> RGBColor[
              0.21325644631447746`, 0.3414764246891273, 0.9354560111817448], 
             127 -> RGBColor[
              0.19480415931956344`, 0.32208190111490453`, 0.9344051807350968],
              210 -> RGBColor[
              0.3056537490672848, 0.4385918482096833, 0.9407179008839572], 
             357 -> RGBColor[
              0.85710048921771, 0.439904958487049, 0.20231279900164487`], 181 -> 
             RGBColor[
              0.19492367816056405`, 0.3222075229947284, 0.9344119871562795], 
             194 -> RGBColor[
              0.9945316676487347, 0.9907121149708813, 0.6461839540792844], 
             118 -> RGBColor[
              0.2388812891503496, 0.36840975921850344`, 0.93691530807269], 
             348 -> RGBColor[
              0.33313964664549794`, 0.4629705506640006, 0.9424483415937963], 
             276 -> RGBColor[
              0.22285712514090053`, 0.35156734685389346`, 0.9360027556379781],
              305 -> RGBColor[
              0.18223318953702214`, 0.3088690148279342, 0.9336892826030643], 
             343 -> RGBColor[
              0.1820208818055452, 0.30864586594106436`, 0.9336771919918379], 
             280 -> RGBColor[
              0.2515360626002474, 0.3817107284733248, 0.937635978699602], 189 -> 
             RGBColor[
              0.266643234211289, 0.39758932368653244`, 0.9384963097737932], 
             168 -> RGBColor[
              0.18420503135956878`, 0.31094154560542325`, 0.9338015760777798],
              363 -> RGBColor[
              0.21990087473071346`, 0.348460140235685, 0.9358344015504985], 
             41 -> RGBColor[
              0.8718710063158469, 0.90067029040099, 0.9876410289824828], 14 -> 
             RGBColor[
              0.18454901891679482`, 0.31130309833813863`, 0.9338211656602798],
              77 -> RGBColor[
              0.18280925758947733`, 0.30947449887588874`, 0.9337220888264354],
              51 -> RGBColor[
              0.381577964086101, 0.5049253866504279, 0.9455347883487892], 179 -> 
             RGBColor[
              0.45394807471440896`, 0.5675745230376996, 0.950155601789558], 
             223 -> 
             RGBColor[
              0.9299021495647822, 0.7597924122879596, 0.2624558280130423], 
             323 -> RGBColor[
              0.3986910652219958, 0.5197478947248675, 0.9466252200206473], 
             292 -> RGBColor[
              0.1943854920349882, 0.321641855253777, 0.934381338252603], 396 -> 
             RGBColor[
              0.19955786085140656`, 0.3270783428269569, 0.9346758970048641], 
             321 -> RGBColor[
              0.5543615420614805, 0.6490946994052059, 0.9580605177657702], 
             143 -> RGBColor[
              0.18504307948317125`, 0.3118223873186494, 0.9338493016786379], 
             112 -> RGBColor[
              0.937107871400364, 0.788360698201582, 0.2682537209419814], 197 -> 
             RGBColor[
              0.9643115115712477, 0.9729041642811488, 0.9452954812480678], 54 -> 
             RGBColor[
              0.1846123721443362, 0.31136968659711123`, 0.9338247735328656], 
             71 -> RGBColor[0.178927, 0.305394, 0.933501], 177 -> 
             RGBColor[
              0.8948525196191675, 0.9189951252924975, 0.9898330262371927], 
             158 -> RGBColor[
              0.3387561380668311, 0.4678352732400925, 0.9428062194606953], 
             226 -> RGBColor[
              0.44524034591787487`, 0.5600665420287623, 0.9495912990246761], 
             350 -> RGBColor[
              0.9938504692273173, 0.9917250252368329, 0.751577169586235], 203 -> 
             RGBColor[
              0.2257570420476589, 0.35461534338824796`, 0.9361679016157753], 
             115 -> RGBColor[
              0.8646080428941941, 0.47809856902505976`, 0.2087379710414105], 
             173 -> RGBColor[
              0.2824798268544749, 0.4142345866524884, 0.9393981802966833], 
             212 -> RGBColor[
              0.41733642177677943`, 0.535897565429752, 0.9478132856528767], 
             129 -> RGBColor[
              0.189088316742455, 0.3160741881610126, 0.9340796719561618], 279 -> 
             RGBColor[
              0.6722342021283076, 0.7438737349625797, 0.9679656809485127], 26 -> 
             RGBColor[
              0.18699939157323073`, 0.3138785953626525, 0.9339607107580624], 
             40 -> RGBColor[
              0.5210599224495296, 0.6220589443833571, 0.9554388922820652], 
             146 -> RGBColor[
              0.18614238840660097`, 0.3129778306973855, 0.9339119056955454], 
             386 -> RGBColor[
              0.7607606134285254, 0.8130312402959552, 0.9767891663005692], 
             192 -> RGBColor[
              0.18162114890697434`, 0.30822572132013676`, 0.933654427794616], 
             300 -> 
             RGBColor[
              0.9146994662552146, 0.9348205418090667, 0.9917260457249173], 
             221 -> RGBColor[
              0.9023083761464576, 0.6492869771870501, 0.2401960532268301], 62 -> 
             RGBColor[
              0.20110579749352597`, 0.32870532238267614`, 0.9347640497066657],
              286 -> RGBColor[
              0.1948453625020903, 0.32212520827217295`, 0.9344075271953871], 
             152 -> RGBColor[
              0.25676930210776144`, 0.3872111950022711, 0.9379340039476709], 
             64 -> RGBColor[
              0.18064334912177313`, 0.30719799174980317`, 0.933598743543374], 
             307 -> RGBColor[
              0.3483545068205488, 0.47614889782652203`, 0.9434178190301781], 
             37 -> RGBColor[
              0.34879862256835453`, 0.4765335685653648, 0.9434461176929121], 
             148 -> RGBColor[
              0.33397821749630197`, 0.46369687858717057`, 0.9425017745868906],
              261 -> RGBColor[
              0.2599700418165058, 0.39057537537478015`, 0.9381162813390138], 
             387 -> RGBColor[
              0.5341260408491124, 0.6326666079220644, 0.9564675049852491], 15 -> 
             RGBColor[
              0.28582560720535155`, 0.41775121393598635`, 0.9395887175380273],
              136 -> RGBColor[
              0.18458947116943916`, 0.3113456162204888, 0.9338234693562242], 
             198 -> RGBColor[
              0.3533082208089774, 0.4804395559023944, 0.9437334653051234], 63 -> 
             RGBColor[
              0.1811814280726413, 0.30776354684334156`, 0.9336293863436095], 
             310 -> RGBColor[
              0.27959908951497947`, 0.4112067490593821, 0.9392341265668681], 
             171 -> RGBColor[
              0.188962757776349, 0.315942217726737, 0.93407252155879], 395 -> 
             RGBColor[
              0.46863892160806836`, 0.5795012143610829, 0.9513121190713723], 
             311 -> RGBColor[
              0.3027440138032642, 0.4355335319593264, 0.9405521957652387], 
             353 -> RGBColor[
              0.19002087389400624`, 0.31705436485483146`, 0.934132779706348], 
             59 -> RGBColor[
              0.3465121371910148, 0.4745531298536097, 0.9433004248665277], 
             397 -> RGBColor[
              0.2129233554713194, 0.341126325093789, 0.9354370421509908], 229 -> 
             RGBColor[
              0.20688302376209858`, 0.33477755348824767`, 0.9350930541960206],
              102 -> RGBColor[
              0.2774713947406823, 0.40897040694795533`, 0.9391129574971142], 
             299 -> 
             RGBColor[
              0.18766218808016377`, 0.31457523651516484`, 0.9339984560386126],
              128 -> RGBColor[
              0.19461177340916913`, 0.32187969132510885`, 0.9343942246421093],
              12 -> RGBColor[
              0.3084761160714523, 0.441558334879467, 0.9408786305095267], 222 -> 
             RGBColor[
              0.23238602207295528`, 0.3615828216964435, 0.9365454122215189], 
             92 -> RGBColor[
              0.49739045300864126`, 0.6028430027937971, 0.9535755449435551], 
             271 -> RGBColor[
              0.17909981633317154`, 0.30557564092335165`, 0.9335108416345153],
              361 -> RGBColor[
              0.21763599434706354`, 0.34607960735075854`, 0.93570541996324], 
             344 -> RGBColor[
              0.1912494582787511, 0.31834568493994736`, 0.9342027457695316], 
             132 -> RGBColor[
              0.35827341580975897`, 0.4847401582541144, 0.9440498431400237], 
             80 -> RGBColor[
              0.1798079986201722, 0.3063199854083397, 0.9335511715680982], 
             324 -> RGBColor[
              0.6331296311169758, 0.713042182562431, 0.9642614302732361], 244 -> 
             RGBColor[
              0.9547654228714991, 0.9657847069591619, 0.9614545193980599], 
             150 -> RGBColor[
              0.19354588592399127`, 0.3207593759970171, 0.9343335239266677], 
             125 -> RGBColor[
              0.2615118954900493, 0.3921959613448436, 0.9382040876247539], 
             258 -> RGBColor[
              0.18340786605487358`, 0.31010367432698904`, 0.9337561786929778],
              133 -> RGBColor[
              0.18578718983175693`, 0.312604494474334, 0.9338916776621772], 
             255 -> RGBColor[
              0.8353613957275855, 0.2728087597904426, 0.18149541852470724`], 
             326 -> RGBColor[
              0.19201165546058205`, 0.31914680250414423`, 0.9342461517714671],
              176 -> RGBColor[
              0.23366891778676377`, 0.3629312264319425, 0.9366184712345461], 
             230 -> RGBColor[
              0.8177383166445533, 0.1373500514757623, 0.1646195380923747], 
             274 -> RGBColor[
              0.49307848673520527`, 0.5993423543211548, 0.9532360911632574], 
             87 -> RGBColor[
              0.19817896485079942`, 0.32562903570326285`, 0.9345973709175234],
              130 -> RGBColor[
              0.1820121662584413, 0.30863670534846055`, 0.9336766956543238], 
             35 -> RGBColor[
              0.2362515342121432, 0.36564572004235524`, 0.9367655474193329], 
             379 -> 
             RGBColor[
              0.20710183530283005`, 0.33500753829100943`, 0.9351055151895625],
              31 -> RGBColor[
              0.19647646719475834`, 0.3238396027221777, 0.9345004161946314], 
             18 -> RGBColor[
              0.6051402883638863, 0.6903191732099512, 0.9620580066833722], 24 -> 
             RGBColor[
              0.8207868509580615, 0.16078242208563953`, 0.1675388179938171], 
             151 -> RGBColor[
              0.19201931518110454`, 0.3191548533560677, 0.9342465879812193], 
             137 -> RGBColor[
              0.33446348254021346`, 0.46411719077807645`, 0.9425326952463855],
              330 -> RGBColor[
              0.18593025704413854`, 0.31275486718553225`, 0.9338998251282734],
              296 -> RGBColor[
              0.2449605595581574, 0.37479945786511576`, 0.9372615135289399], 
             266 -> RGBColor[
              0.23275233921967517`, 0.3619678442434947, 0.9365662734411069], 
             302 -> RGBColor[
              0.19137511524925596`, 0.3184777583830601, 0.9342099017481089], 
             283 -> RGBColor[
              0.20898033639140454`, 0.33698196203894937`, 0.9352124930475636],
              388 -> RGBColor[
              0.2195142065627996, 0.3480537274750297, 0.9358123813703602], 
             284 -> RGBColor[
              0.2765987024765969, 0.40805315204651627`, 0.939063258963707], 
             318 -> RGBColor[
              0.19439044372267295`, 0.3216470597914888, 0.9343816202438913], 
             238 -> RGBColor[
              0.28998218143607674`, 0.4221200369945062, 0.9398254282913666], 
             72 -> RGBColor[
              0.18281412095909713`, 0.3094796105857146, 0.9337223657881405], 
             288 -> RGBColor[
              0.30537118422496984`, 0.4382948546447645, 0.9407018092342045], 
             382 -> RGBColor[
              0.1818914944971056, 0.30850987167626515`, 0.9336698235760336], 
             389 -> RGBColor[
              0.20264865261830456`, 0.3303269609414833, 0.9348519130235723], 
             172 -> RGBColor[
              0.8238032261936802, 0.18396760393066158`, 0.17042730232595416`],
              243 -> RGBColor[
              0.9695261963263196, 0.9767932676332187, 0.9364683801653377], 88 -> 
             RGBColor[
              0.19146940577852636`, 0.3185768637076881, 0.9342152714542605], 
             273 -> RGBColor[
              0.1818250295794584, 0.30844001283369876`, 0.9336660384972996], 
             202 -> RGBColor[
              0.2433593553333951, 0.37311649070267905`, 0.9371703273171091], 
             393 -> 
             RGBColor[
              0.18336325239717496`, 0.31005678254407854`, 0.9337536380111718],
              98 -> RGBColor[
              0.20101540430520026`, 0.32861031341048663`, 0.9347589019483153],
              30 -> RGBColor[
              0.18021067351487519`, 0.3067432222537355, 0.9335741033076473], 
             116 -> RGBColor[
              0.18333815129494635`, 0.31003039969413443`, 0.9337522085405336],
              373 -> RGBColor[
              0.271851153445097, 0.4030631770024157, 0.9387928930697325], 240 -> 
             RGBColor[
              0.8316889234682268, 0.24458052871740593`, 0.17797865494168116`],
              317 -> RGBColor[
              0.1953540422101205, 0.32265986289746895`, 0.9344364957522352], 
             391 -> RGBColor[
              0.18112688553091424`, 0.3077062191737896, 0.9336262802265466], 
             73 -> RGBColor[
              0.9306153171117766, 0.762619883962795, 0.26302965936154776`], 
             303 -> RGBColor[
              0.21323548342695858`, 0.34145439136522115`, 0.9354548173763124],
              29 -> RGBColor[
              0.1814383294461641, 0.30803356647540187`, 0.9336440164967801], 
             360 -> RGBColor[
              0.18524924480481392`, 0.31203908014333226`, 0.9338610424887112],
              320 -> RGBColor[
              0.19579265616170655`, 0.32312087397031664`, 0.9344614741679068],
              75 -> RGBColor[
              0.21796667840296896`, 0.34642717726009525`, 0.9357242519310205],
              200 -> RGBColor[
              0.1842143453500115, 0.31095133519991963`, 0.9338021064957567], 
             301 -> RGBColor[
              0.18269671784651187`, 0.30935621247060024`, 0.933715679854561], 
             156 -> RGBColor[
              0.8309858670902185, 0.23917652931476524`, 0.17730540736011186`],
              25 -> RGBColor[0.817319, 0.134127, 0.164218], 38 -> 
             RGBColor[
              0.22292982485851465`, 0.3516437588665342, 0.9360068957793466], 
             365 -> RGBColor[
              0.18093049359979738`, 0.3074997988022181, 0.9336150959966053], 
             380 -> RGBColor[
              0.22012423896070668`, 0.348694910203518, 0.9358471218129588], 
             370 -> RGBColor[
              0.18708771794254558`, 0.3139714319770177, 0.9339657408141276], 
             3 -> RGBColor[
              0.5818688834669836, 0.6714263983498019, 0.960225996443923], 57 -> 
             RGBColor[
              0.21768082531414856`, 0.3461267275396124, 0.9357079730204939], 
             227 -> 
             RGBColor[
              0.20746958876179836`, 0.3353940704933011, 0.9351264582050084], 
             39 -> RGBColor[
              0.18317563345981333`, 0.30985958314518375`, 0.9337429533902465],
              109 -> RGBColor[
              0.18132254229683142`, 0.30791186684012395`, 0.9336374225899173],
              256 -> RGBColor[
              0.3513087838325387, 0.47870774408802763`, 0.9436060629490174], 
             339 -> RGBColor[
              0.2515477771449798, 0.3817230412025836, 0.9376366458255944], 
             287 -> RGBColor[
              0.1899324083338537, 0.31696138194207063`, 0.9341277417235704], 
             239 -> RGBColor[
              0.82776291630336, 0.2144035172609302, 0.17421910604681382`], 
             285 -> RGBColor[
              0.9941990383585994, 0.9900006545532618, 0.6099793085980734], 
             345 -> RGBColor[
              0.1789871968344326, 0.3054572706896884, 0.9335044281206677], 
             366 -> RGBColor[
              0.39439940253334044`, 0.5160306722091927, 0.9463517590690945], 
             216 -> RGBColor[
              0.1997106484206986, 0.3272389322495743, 0.9346845980309063], 21 -> 
             RGBColor[
              0.9632021039744041, 0.8875341975281088, 0.3115475519504825], 
             355 -> RGBColor[
              0.7657071355725306, 0.8168955009898127, 0.9772821894000061], 
             175 -> RGBColor[
              0.28165135838121924`, 0.41336381375916165`, 0.9393510002427407],
              7 -> RGBColor[
              0.4486453266434888, 0.5630157651939816, 0.9498082613856059], 13 -> 
             RGBColor[
              0.21416269395992185`, 0.3424289484239088, 0.9355076206444797], 
             294 -> RGBColor[
              0.1899597624904289, 0.3169901328949849, 0.9341292995023205], 
             193 -> RGBColor[
              0.18694492825143932`, 0.3138213509582757, 0.9339576091524576], 
             60 -> RGBColor[
              0.186004909472108, 0.3128333316205655, 0.9339040764736078], 65 -> 
             RGBColor[
              0.2879462259501837, 0.4199801186917991, 0.9397094836383711], 69 -> 
             RGBColor[
              0.2418162773238607, 0.37149461787786187`, 0.9370824513072455], 
             217 -> RGBColor[
              0.9930695883095065, 0.987584875103169, 0.4870456409120508], 214 -> 
             RGBColor[
              0.23974505627195325`, 0.36931763322930755`, 0.9369644983324363],
              170 -> RGBColor[
              0.2316644133079956, 0.36082436513183264`, 0.936504317669879], 
             359 -> 
             RGBColor[
              0.18720392975649292`, 0.3140935779617309, 0.9339723589050121], 
             74 -> RGBColor[
              0.8630600513163033, 0.8936446740513561, 0.986800632228994], 246 -> 
             RGBColor[
              0.9202453542726101, 0.9392426823750178, 0.9922550174748891], 
             264 -> RGBColor[
              0.7232916660208124, 0.7837602138065023, 0.9730546117901898], 
             278 -> RGBColor[
              0.25816588373595994`, 0.3886790908418973, 0.9380135372053394], 
             45 -> RGBColor[
              0.2848093981590889, 0.41668311379698936`, 0.9395308459361892], 
             306 -> RGBColor[
              0.20271236623405806`, 0.3303939279913168, 0.9348555414197336], 
             237 -> RGBColor[
              0.19733278810728, 0.3247396502951197, 0.9345491824037863], 228 -> 
             RGBColor[
              0.20359531165465325`, 0.33132195961033534`, 0.9349058238552358],
              180 -> RGBColor[
              0.2585433275657887, 0.3890758082383683, 0.93803503207307], 383 -> 
             RGBColor[
              0.20835388918653433`, 0.3363235263075839, 0.9351768178059918], 
             53 -> RGBColor[
              0.19239706134193654`, 0.319551888521592, 0.9342681000662533], 
             304 -> RGBColor[
              0.1808905282724361, 0.3074577927092133, 0.9336128200303355], 48 -> 
             RGBColor[
              0.24018804114120323`, 0.3697832384137522, 0.9369897256654027], 
             5 -> RGBColor[
              0.2824395297681887, 0.41419223185981874`, 0.9393958854372335], 
             101 -> RGBColor[
              0.1831002535865883, 0.30978035411906424`, 0.9337386606179808], 
             333 -> RGBColor[
              0.18811264277564865`, 0.31504869296059673`, 0.9340241087671325],
              267 -> RGBColor[
              0.2559867658273416, 0.386388699755884, 0.9378894396641596], 120 -> 
             RGBColor[
              0.5182991743784003, 0.6198176447289311, 0.9552215560809526], 
             147 -> RGBColor[
              0.1834762116557925, 0.31017550988691617`, 0.9337600708738418], 
             89 -> RGBColor[
              0.1892450123424645, 0.31623888517169746`, 0.934088595538772], 
             43 -> RGBColor[
              0.26035980612556775`, 0.3909850423760888, 0.9381384778398102], 
             199 -> RGBColor[
              0.18648980339442428`, 0.3133429858769703, 0.9339316904651475], 
             268 -> RGBColor[
              0.679362894162589, 0.7494427233598264, 0.9686762023490751], 169 -> 
             RGBColor[
              0.8957887014800139, 0.9197416112963568, 0.9899223200988196], 20 -> 
             RGBColor[
              0.19028821830363388`, 0.31733536077996466`, 0.9341480045749757],
              4 -> RGBColor[
              0.23281884209063286`, 0.36203774297739677`, 0.9365700606812258],
              167 -> RGBColor[
              0.3102543804501736, 0.4431484833325346, 0.9409901126684767], 
             142 -> RGBColor[
              0.18248883410320854`, 0.3091377134757978, 0.9337038411829164], 
             16 -> RGBColor[
              0.3177755060429437, 0.4496629042982282, 0.9414693521405777], 
             281 -> RGBColor[
              0.4286879330306734, 0.5457296739343299, 0.9485365939122276], 
             289 -> RGBColor[
              0.1861676814246589, 0.31300441526303435`, 0.9339133460955061], 
             398 -> RGBColor[
              0.4260942433398349, 0.54348315028676, 0.9483713262986371], 178 -> 
             RGBColor[
              0.44169024668361, 0.5569916245052177, 0.9493650898406981], 58 -> 
             RGBColor[
              0.21195870855243037`, 0.3401124200198894, 0.9353821069360272], 
             186 -> RGBColor[
              0.20685160848485196`, 0.33474453404001786`, 0.9350912651424561],
              122 -> RGBColor[
              0.5979628209588992, 0.6844921818293608, 0.9614929701573222], 
             249 -> RGBColor[
              0.3090764058516128, 0.442128180941986, 0.9409150531686984], 113 -> 
             RGBColor[
              0.30752560771325343`, 0.4405592903292892, 0.9408245004646784], 
             52 -> RGBColor[
              0.17936539842637753`, 0.30585478454218845`, 0.9335259661418299],
              187 -> RGBColor[
              0.43492032413853554`, 0.551127857862875, 0.9489337163625334], 
             259 -> RGBColor[
              0.18623692915551526`, 0.3130771990187241, 0.9339172896513356], 
             42 -> RGBColor[
              0.21651396498896067`, 0.34490028335462225`, 0.9356415220511897],
              134 -> RGBColor[
              0.830968185180272, 0.8680554911049849, 0.9837396813881922], 313 -> 
             RGBColor[
              0.218367213855187, 0.3468481654157909, 0.9357470618324852], 248 -> 
             RGBColor[
              0.21799885977606132`, 0.3464610019236322, 0.9357260846126101], 
             174 -> RGBColor[
              0.34399645769565007`, 0.4723741747164527, 0.943140127993611], 
             215 -> RGBColor[
              0.18299643202543156`, 0.30967123107562133`, 0.9337327481336631],
              399 -> 
             RGBColor[
              0.9265760623547111, 0.7466055848528861, 0.2597795801705179], 83 -> 
             RGBColor[
              0.9450344910434499, 0.9585273939347413, 0.9779264487494559], 95 -> 
             RGBColor[
              0.559409915392181, 0.6531931963016955, 0.9584579442071637], 166 -> 
             RGBColor[
              0.9896948922783259, 0.9900065873749687, 0.82044583391943], 384 -> 
             RGBColor[
              0.18955786573703887`, 0.316567713925446, 0.9341064120767679], 
             233 -> RGBColor[
              0.9594063537213845, 0.9692459055881796, 0.9535986340178257], 
             295 -> RGBColor[
              0.4290348579738498, 0.5460301628831548, 0.9485586996628331], 
             141 -> RGBColor[
              0.8655975347340893, 0.482591620368333, 0.20956362728728348`], 
             319 -> RGBColor[
              0.4533617737780597, 0.567098537525015, 0.9501094460321575], 205 -> 
             RGBColor[
              0.3500177192487492, 0.4775894888363419, 0.943523797455382], 224 -> 
             RGBColor[
              0.1793343425625045, 0.3058221428602024, 0.9335241975563253], 
             231 -> RGBColor[
              0.18219295480676673`, 0.3088267255754066, 0.9336869912946982], 
             332 -> RGBColor[
              0.2283446787479909, 0.35733511362593967`, 0.9363152636977938], 
             68 -> RGBColor[
              0.27002626100566185`, 0.40114509934370585`, 0.9386889681449931],
              10 -> RGBColor[
              0.23750097993416716`, 0.3669589667156367, 0.9368367015048129], 
             250 -> RGBColor[
              0.25834749102875554`, 0.38886997162119286`, 0.9380238794720002],
              282 -> RGBColor[
              0.2671426063657563, 0.39811419548290095`, 0.9385247482792353], 
             374 -> RGBColor[
              0.19021908584372046`, 0.31726269818134456`, 0.934144067583656], 
             232 -> RGBColor[
              0.295092829761857, 0.42749165241872045`, 0.9401164721529931], 
             253 -> RGBColor[
              0.19109293756035423`, 0.31818117174092553`, 0.9341938321461705],
              55 -> RGBColor[
              0.9716313250190438, 0.9159679393868991, 0.3442934839840799], 
             325 -> RGBColor[
              0.289139123347183, 0.42123392949010874`, 0.9397774173803968], 
             91 -> RGBColor[
              0.4932978290383352, 0.5995204262840937, 0.953253358592837], 105 -> 
             RGBColor[
              0.20947576509879728`, 0.3375026890224135, 0.9352407069795285], 
             36 -> 
             RGBColor[
              0.19287789451893317`, 0.32005727467719974`, 0.9342954828043544],
              123 -> RGBColor[
              0.21169783120855037`, 0.3398382213908926, 0.9353672503572267], 
             94 -> RGBColor[
              0.18118663655961964`, 0.30776902129339295`, 0.9336296829592377],
              312 -> RGBColor[
              0.3029090080003519, 0.4357069513217019, 0.9405615919406759], 96 -> 
             RGBColor[
              0.7481991240396009, 0.803218109314472, 0.9755371544320737], 2 -> 
             RGBColor[
              0.18498575182454155`, 0.3117621323146461, 0.9338460369532876], 
             262 -> RGBColor[
              0.2141514811516508, 0.34241716305148284`, 0.9355069820916365], 
             272 -> RGBColor[
              0.7409332819620127, 0.7975419782610151, 0.9748129631969344], 97 -> 
             RGBColor[
              0.19288958051724012`, 0.32006955740235543`, 0.93429614830467], 
             372 -> RGBColor[
              0.19406834726399882`, 0.3213085159913272, 0.9343632773270688], 
             356 -> RGBColor[
              0.19499177110397153`, 0.3222790929955916, 0.9344158649486721], 
             346 -> RGBColor[
              0.3510664211934816, 0.47849782175157674`, 0.9435906198159696], 
             341 -> RGBColor[
              0.3362350503435996, 0.46565163376778274`, 0.9426455779802814], 
             209 -> RGBColor[
              0.33484250288537293`, 0.4644454791509371, 0.9425568460876246], 
             378 -> RGBColor[
              0.19081859398490578`, 0.3178928192487419, 0.9341782086854036], 
             66 -> RGBColor[
              0.2142707962291993, 0.34254257076299915`, 0.935513776908792], 
             139 -> RGBColor[
              0.18805967833656198`, 0.31499302397697726`, 0.9340210925206803],
              56 -> RGBColor[
              0.38165040818030865`, 0.5049881340836845, 0.9455394044224124], 
             335 -> RGBColor[
              0.1795029989097729, 0.3059994113746115, 0.9335338022857975], 
             314 -> RGBColor[
              0.23267428983588884`, 0.3618858093925185, 0.936561828644164], 
             144 -> RGBColor[
              0.1905501321581982, 0.3176106488474093, 0.9341629201815262], 
             298 -> RGBColor[
              0.19699767297971368`, 0.3243874230485212, 0.9345300980930298], 
             204 -> RGBColor[
              0.19363457114614188`, 0.3208525897884652, 0.9343385744188711], 
             207 -> RGBColor[
              0.18775722726537172`, 0.31467512872465075`, 0.9340038683796124],
              334 -> 
             RGBColor[
              0.1849809522741401, 0.31175708768286514`, 0.9338457636259925], 
             149 -> RGBColor[
              0.21660346779159745`, 0.34499435647499893`, 0.9356466191033923],
              219 -> RGBColor[
              0.3371253879726633, 0.4664227994724073, 0.9427023095067106], 
             400 -> RGBColor[
              0.8501784807301029, 0.38669936800784144`, 0.19568427585662201`],
              9 -> RGBColor[
              0.19103464530579026`, 0.3181199028854364, 0.9341905124885087], 
             11 -> RGBColor[
              0.31196467996522614`, 0.44462985881031997`, 0.9410990914412173],
              44 -> RGBColor[
              0.2366745638317519, 0.36609035099419096`, 0.9367896383303533], 
             153 -> RGBColor[
              0.1824446187841665, 0.30909124037207153`, 0.9337013231859077], 
             32 -> RGBColor[
              0.9570322462930174, 0.8667218188173162, 0.28757881993815293`], 
             162 -> RGBColor[
              0.27232886945688745`, 0.40356528681975196`, 0.9388200982898864],
              90 -> RGBColor[
              0.6083786689975903, 0.6929482364957771, 0.9623129438694364], 
             331 -> RGBColor[
              0.19914754728651962`, 0.3266470772548782, 0.9346525302543484], 
             8 -> RGBColor[
              0.2378122641398246, 0.36728614615234123`, 0.9368544286798214], 
             364 -> RGBColor[
              0.8176771202476999, 0.13687966915311423`, 0.16456093635363633`],
              342 -> RGBColor[
              0.18371444184961855`, 0.31042590492529404`, 0.9337736377309502],
              163 -> RGBColor[
              0.26679472020223177`, 0.3977485450677799, 0.938504936676874], 
             49 -> RGBColor[
              0.18767785554878408`, 0.3145917040180597, 0.9339993482777726], 
             338 -> RGBColor[
              0.23420030298526878`, 0.3634897459673388, 0.9366487328354871], 
             76 -> RGBColor[
              0.1938965482594379, 0.32112794434484765`, 0.9343534936279129], 
             369 -> RGBColor[
              0.19059767181486464`, 0.3176606160407541, 0.9341656274946448], 
             82 -> RGBColor[
              0.1807265568208277, 0.30728544831718235`, 0.9336034820987404], 
             67 -> RGBColor[
              0.42522253205912725`, 0.5427281177888938, 0.9483157816266544], 
             211 -> RGBColor[
              0.22188954865981286`, 0.3505503626243781, 
               0.9359476535887813]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9l2k4lWvYhs1zWMs8LNZoLbMSqfBetRslSppMScqwSaE2pQyZolBokCJT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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 14}], {
             RGBColor[
             0.18904790384743964`, 0.31603171164602595`, 0.9340773705015762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.18749255911212426`, 0.3143969457146576, 0.9339887959198263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 49}], {
             RGBColor[
             0.19061232216343427`, 0.3176760144859865, 0.9341664618103227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 62}], {
             RGBColor[
             0.19732629313580521`, 0.3247328236682947, 0.9345488125247692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 87}], {
             RGBColor[
             0.19586287681444192`, 0.32319468032858806`, 0.934465473130198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 119}], {
             RGBColor[
             0.18798137752672578`, 0.3149107248612813, 0.9340166334053959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 127}], {
             RGBColor[
             0.19417547404882396`, 0.3214211130344089, 0.9343693780389848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 129}], {
             RGBColor[
             0.19131755276026974`, 0.31841725655746295`, 0.9342066236495172]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 216}], {
             RGBColor[
             0.19662871859939152`, 0.3239996286017438, 0.9345090866868895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 231}], {
             RGBColor[
             0.1878698717924256, 0.3147935252646599, 0.9340102833187854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 235}], {
             RGBColor[
             0.19253038583618232`, 0.3196920210183055, 0.9342756926989647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 298}], {
             RGBColor[
             0.19527223087889906`, 0.32257387400121723`, 0.9344318367179512]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 313}], {
             RGBColor[
             0.20595700131663575`, 0.3338042451848521, 0.935040318587679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 317}], {
             RGBColor[
             0.19445041549410247`, 0.3217100939256911, 0.9343850355475539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 336}], {
             RGBColor[
             0.18695004027347276`, 0.31382672401755374`, 0.9339579002745498]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 361}], {
             RGBColor[
             0.205591391562574, 0.33341996615233593`, 0.9350194976530564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 393}], {
             RGBColor[
             0.1884550205876297, 0.3154085537489959, 0.9340436066770222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 396}], {
             RGBColor[
             0.1965523248147455, 0.3239193338904351, 0.9345047361738683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 97}], {
             RGBColor[
             0.18893766617089083`, 0.31591584485850077`, 0.9340710926289788]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 109}], {
             RGBColor[
             0.1831541470606865, 0.30983699957738503`, 0.9337417297716024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 181}], {
             RGBColor[
             0.1899547149925528, 0.3169848276546873, 0.9341290120547836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 191}], {
             RGBColor[
             0.19610476461646903`, 0.323448919745091, 0.9344792482826825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 193}], {
             RGBColor[
             0.18596534003799042`, 0.3127917416364609, 0.9339018230528726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 211}], {
             RGBColor[
             0.2034376502421772, 0.3311562474695121, 0.9348968452710344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 305}], {
             RGBColor[
             0.18360947068078184`, 0.31031557357129014`, 0.9337676597781759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 334}], {
             RGBColor[
             0.18498335204934083`, 0.3117596099987556, 0.93384590028964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 340}], {
             RGBColor[
             0.19396024281710603`, 0.32119489136342505`, 0.9343571209387445]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 360}], {
             RGBColor[
             0.18511749831467772`, 0.3119006062289892, 0.9338535397209994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 365}], {
             RGBColor[
             0.18295812271216946`, 0.3096309655584321, 0.9337305664749465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 370}], {
             RGBColor[
             0.18603673488354355`, 0.3128667821458319, 0.9339058888837076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 11}], {
             RGBColor[
             0.4469167817161049, 0.5580281285800609, 0.9506625439425702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 21}], {
             RGBColor[
             0.7725354937206939, 0.7794802979389553, 0.6358867741972027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 34}], {
             RGBColor[
             0.4225585018257533, 0.5327236209657705, 0.9492644797482566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 74}], {
             RGBColor[
             0.7224644673916434, 0.782535536200579, 0.9735133143364585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 86}], {
             RGBColor[
             0.49644576954540676`, 0.6009276484384913, 0.9538184872502891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 91}], {
             RGBColor[
             0.5375833562526594, 0.6354734123169479, 0.9567396775183801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 95}], {
             RGBColor[
             0.5706393994295823, 0.6623097973257487, 0.9593419703255434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 160}], {
             RGBColor[
             0.5207461823507223, 0.6218042360373149, 0.9554141935122193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[
             0.42709887646193556`, 0.5374958425847769, 0.9495230473669047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 233}], {
             RGBColor[
             0.7706376185941841, 0.8203361519689907, 0.9569123152308744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 263}], {
             RGBColor[
             0.48691076315351817`, 0.5926689051451934, 0.9532109250744729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 264}], {
             RGBColor[
             0.652580274743898, 0.7275933060781521, 0.9666403041170564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 285}], {
             RGBColor[
             0.7880339609127915, 0.8307135264515318, 0.7851026525209982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 312}], {
             RGBColor[
             0.44238894573366777`, 0.553566674835752, 0.9503937941922995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 348}], {
             RGBColor[
             0.45750426505624076`, 0.5671984745069012, 0.9513371690188597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 13}], {
             RGBColor[
             0.22349076802527734`, 0.3522333457006528, 0.9360388406628528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 66}], {
             RGBColor[
             0.22354481915991609`, 0.35229015687019793`, 0.9360419187950089]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 123}], {
             RGBColor[
             0.2222583366495916, 0.3509379821841447, 0.9359686555192263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 131}], {
             RGBColor[
             0.22303764420255517`, 0.35175708383326204`, 0.9360130359314853]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 140}], {
             RGBColor[
             0.22925899781803233`, 0.3582961209397305, 0.9363673328162189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 183}], {
             RGBColor[
             0.2914028738694214, 0.4198002713108441, 0.9400459473606144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 186}], {
             RGBColor[
             0.2198352252877424, 0.3483911385087073, 0.9358306629118409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 188}], {
             RGBColor[
             0.2173017232473819, 0.34572826723098127`, 0.9356863837186229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 203}], {
             RGBColor[
             0.22928794206914588`, 0.35832654318282237`, 0.9363689811485005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 232}], {
             RGBColor[
             0.26395583592624494`, 0.3947646976980586, 0.9383432664171094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 238}], {
             RGBColor[
             0.26140051176335477`, 0.3920788899859515, 0.9381977444862962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 275}], {
             RGBColor[
             0.235784586016354, 0.3651549278823552, 0.9367389554103707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 280}], {
             RGBColor[
             0.24217745234544014`, 0.3718742357253608, 0.937103019690414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 297}], {
             RGBColor[
             0.2198696831096341, 0.34842735586426754`, 0.9358326252338219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 309}], {
             RGBColor[
             0.2652076930566547, 0.39608047891444564`, 0.9384145578287296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 322}], {
             RGBColor[
             0.21636197354501668`, 0.3447405307102229, 0.9356328663633082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 325}], {
             RGBColor[
             0.26097898271890796`, 0.39163583623375275`, 0.9381737390308114]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 339}], {
             RGBColor[
             0.24218330961780632`, 0.3718803920899902, 0.9371033532534101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 8}], {
             RGBColor[
             0.2601258969540067, 0.39073918900607996`, 0.9381251570585274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 43}], {
             RGBColor[
             0.2713996679468782, 0.4025886371179538, 0.9387671816385219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 56}], {
             RGBColor[
             0.3320449689742487, 0.4595901829717516, 0.9424676449298229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.31447583347960173`, 0.4443726808567142, 0.9413481551518805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 90}], {
             RGBColor[
             0.44540909938288953`, 0.5535702341777979, 0.950854414653335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 100}], {
             RGBColor[
             0.24629351933764826`, 0.37620048310789195`, 0.9373374236164447]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 121}], {
             RGBColor[
             0.2966728547509243, 0.4289526354856623, 0.9402137650898452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 122}], {
             RGBColor[
             0.440201175363544, 0.5493422068445898, 0.9504444277972779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 175}], {
             RGBColor[
             0.282045444074704, 0.41377802280949016`, 0.9393734428399871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 178}], {
             RGBColor[
             0.36206488822589933`, 0.4855919281825182, 0.9443804876389659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 213}], {
             RGBColor[
             0.25252900688278906`, 0.3827543758705798, 0.9376925254075633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 227}], {
             RGBColor[
             0.24495455926499354`, 0.3747931511765599, 0.937261171821121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 274}], {
             RGBColor[
             0.38775900825169696`, 0.5067672930904867, 0.9463159883002454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 296}], {
             RGBColor[
             0.26370004466317304`, 0.39449584486246725`, 0.9383286994830867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 308}], {
             RGBColor[
             0.24197001296398313`, 0.37165620378303305`, 0.9370912063245189]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 319}], {
             RGBColor[
             0.3679006517731242, 0.4906453846924169, 0.9447526657346955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 352}], {
             RGBColor[
             0.26102097459574697`, 0.3916799723587493, 0.9381761304060758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 373}], {
             RGBColor[
             0.27714534160664284`, 0.4086277044311172, 0.939094389253483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 56}], {
             RGBColor[
             0.34361946259808085`, 0.47175570963568103`, 0.9431267952187714]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 79}], {
             RGBColor[
             0.26831622286540857`, 0.39934774083561936`, 0.9385915840026804]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 137}], {
             RGBColor[
             0.32002599977803325`, 0.451320237982877, 0.941623440630758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 169}], {
             RGBColor[
             0.6006886092479335, 0.6791324482420171, 0.965318253056975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 175}], {
             RGBColor[
             0.2936199376985361, 0.4259435494734196, 0.9400325931289355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 178}], {
             RGBColor[
             0.37363938184973156`, 0.4977574548464476, 0.9450396379279142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 252}], {
             RGBColor[
             0.3375773650971563, 0.4665223484650306, 0.9427417981088295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 277}], {
             RGBColor[
             0.2567019144406389, 0.38714036629150045`, 0.9379301663197194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 278}], {
             RGBColor[
             0.28187720037590647`, 0.4136011880147874, 0.9393638616102349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 300}], {
             RGBColor[
             0.6101439916355338, 0.6866719134983721, 0.9662201158700239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 314}], {
             RGBColor[
             0.26913140342587094`, 0.400204547290098, 0.9386380073296472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 319}], {
             RGBColor[
             0.37947514539695637`, 0.5028109113563464, 0.945411816023644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 352}], {
             RGBColor[
             0.27259546821957914`, 0.40384549902267874`, 0.9388352806950242]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 379}], {
             RGBColor[
             0.25634517615934155`, 0.38676541173934353`, 0.9379098506023464]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 65}], {
             RGBColor[
             0.36829577629683624`, 0.4914979419428903, 0.9447588725119885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 67}], {
             RGBColor[
             0.43693392935130804`, 0.5528719414914377, 0.9490620215061302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 68}], {
             RGBColor[
             0.3593357938245753, 0.4820804322688437, 0.9442486147652995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 96}], {
             RGBColor[
             0.5984222253415448, 0.6831169372542267, 0.9626727079088397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 173}], {
             RGBColor[
             0.36556257674898185`, 0.48862517592323496`, 0.9446032208411446]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[
             0.7215884971461117, 0.7768639400824314, 0.7979961077324451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 201}], {
             RGBColor[
             0.698844545732584, 0.7622666344739716, 0.960474027707296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 223}], {
             RGBColor[
             0.6892737381041355, 0.6614040887409706, 0.6061320446993241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 250}], {
             RGBColor[
             0.35349640883612216`, 0.4759428684075872, 0.943916070428803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 387}], {
             RGBColor[
             0.4913856837463006, 0.597841186558023, 0.9531378831854276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 43}], {
             RGBColor[
             0.24908603513269617`, 0.379135594264215, 0.9374964532598158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 56}], {
             RGBColor[
             0.30973133616006665`, 0.43613714011801286`, 0.9411969165511169]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 59}], {
             RGBColor[
             0.2921622006654197, 0.4209196380029755, 0.9400774267731745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 100}], {
             RGBColor[
             0.22397988652346618`, 0.35274744025415317`, 0.9360666952377386]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 121}], {
             RGBColor[
             0.2743592219367422, 0.4054995926319236, 0.9389430367111391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 175}], {
             RGBColor[
             0.2597318112605219, 0.39032497995575144`, 0.938102714461281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 213}], {
             RGBColor[
             0.230215374068607, 0.3593013330168411, 0.9364217970288573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 227}], {
             RGBColor[
             0.22264092645081146`, 0.35134010832282114`, 0.9359904434424149]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 237}], {
             RGBColor[
             0.2175725261235523, 0.3460128982237305, 0.9357018055418038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 296}], {
             RGBColor[
             0.241386411848991, 0.3710428020087285, 0.9370579711043807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 308}], {
             RGBColor[
             0.21965638014980107`, 0.34820316092929426`, 0.9358204779458129]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 352}], {
             RGBColor[
             0.23870734178156489`, 0.36822692950501057`, 0.9369054020273697]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 373}], {
             RGBColor[
             0.2548317087924608, 0.38517466157737845`, 0.937823660874777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 39}], {
             RGBColor[
             0.1871051393828018, 0.3139897430153101, 0.9339667329393776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.2089266760744028, 0.33692556164351994`, 0.9352094371718936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 150}], {
             RGBColor[
             0.19229026561489077`, 0.3194396394412268, 0.9342620182075883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 192}], {
             RGBColor[
             0.1863278971063823, 0.3131728121027866, 0.9339224701415624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 283}], {
             RGBColor[
             0.2000074908485974, 0.3275509324621929, 0.9347015027680361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 294}], {
             RGBColor[
             0.1904972038981096, 0.3175550178902107, 0.9341599059954147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 320}], {
             RGBColor[
             0.1934136507337484, 0.32062038842787655`, 0.9343259933282078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 347}], {
             RGBColor[
             0.19444294915612814`, 0.3217022463310869, 0.9343846103506517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 381}], {
             RGBColor[
             0.19359903145009902`, 0.3208152353145773, 0.9343365504857577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 384}], {
             RGBColor[
             0.19029625552141455`, 0.3173438084054412, 0.9341484622826384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.26166329356975937`, 0.3923550903258115, 0.9382127095214201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 37}], {
             RGBColor[
             0.29314980125126083`, 0.4217462676405007, 0.9401414095988625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 62}], {
             RGBColor[
             0.21930338871384658`, 0.34783214454915645`, 0.9358003756057394]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 87}], {
             RGBColor[
             0.2178399723924833, 0.34629400120944975`, 0.9357170362111682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 155}], {
             RGBColor[
             0.22229114501906733`, 0.3509724658606344, 0.9359705239073323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 170}], {
             RGBColor[
             0.2345826966210814, 0.3638916659237347, 0.936670509587346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 216}], {
             RGBColor[
             0.21860581417743288`, 0.3470989494826055, 0.9357606497678597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 256}], {
             RGBColor[
             0.29440488188335295`, 0.4228333554018322, 0.9402213822269152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 261}], {
             RGBColor[
             0.24873551087533646`, 0.3787671710452084, 0.9374764914219134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 298}], {
             RGBColor[
             0.21724932645694042`, 0.3456731948820789, 0.9356833997989213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 311}], {
             RGBColor[
             0.2701224968687157, 0.40124624933748154`, 0.9386944486350258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 313}], {
             RGBColor[
             0.22793409689467709`, 0.35690356606571383`, 0.9362918816686491]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 361}], {
             RGBColor[
             0.22756848714061534`, 0.35651928703319763`, 0.9362710607340264]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 396}], {
             RGBColor[
             0.21852942039278686`, 0.3470186547712968, 0.9357562992548385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 34}], {
             RGBColor[
             0.28760640007487454`, 0.41932535119602954`, 0.9397010272469036]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 35}], {
             RGBColor[
             0.27410810708868466`, 0.4051377894263376, 0.9389323194302751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 85}], {
             RGBColor[
             0.2763549775912347, 0.40749939278433556`, 0.9390602753814483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 86}], {
             RGBColor[
             0.361493667794528, 0.48752937866875046`, 0.9442550347489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 91}], {
             RGBColor[
             0.40263125450178067`, 0.5220751425472069, 0.9471762250170271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 93}], {
             RGBColor[
             0.2731424573639435, 0.4041228303399058, 0.9388773271070019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 95}], {
             RGBColor[
             0.43568729767870357`, 0.5489115275560077, 0.9497785178241904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 125}], {
             RGBColor[
             0.2867382877276377, 0.41841291007758175`, 0.9396515895329856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 162}], {
             RGBColor[
             0.29214677471105677`, 0.42409757281503596`, 0.9399595948655519]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 211}], {
             RGBColor[
             0.2669271143125195, 0.39759011071734907`, 0.9385233725149993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 214}], {
             RGBColor[
             0.2758548681185897, 0.40697374601981373`, 0.9390317948868268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 248}], {
             RGBColor[
             0.2649817698706437, 0.3955454303669761, 0.9384125880269136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 263}], {
             RGBColor[
             0.35195866140263943`, 0.47927063537545245`, 0.9436474725731201]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 312}], {
             RGBColor[
             0.30743684398278903`, 0.44016840506601096`, 0.9408303416909466]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.313125811057198, 0.4456106195888476, 0.9411739913250522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 17}], {
             RGBColor[
             0.2700762317403779, 0.40119762175422, 0.93869181390441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 22}], {
             RGBColor[
             0.3123757406994519, 0.44496094634460026`, 0.9411261975051177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 47}], {
             RGBColor[
             0.4262898849714413, 0.5411626092696967, 0.9490658048705467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 106}], {
             RGBColor[
             0.2676474114572338, 0.3986447776405352, 0.9385534961824027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 107}], {
             RGBColor[
             0.3285473986430889, 0.45896802364421685`, 0.9421566412492507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 118}], {
             RGBColor[
             0.27367870261090094`, 0.4049840470489852, 0.9388969692911083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 158}], {
             RGBColor[
             0.32361612706914167`, 0.45469680405977975`, 0.941842424985111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 209}], {
             RGBColor[
             0.3216593094784126, 0.45300190701520204`, 0.9417177382985756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 241}], {
             RGBColor[
             0.28584467655013013`, 0.4177712570264148, 0.9395898035090018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 270}], {
             RGBColor[
             0.3337876806083378, 0.46350689249828564`, 0.9424905473822769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 310}], {
             RGBColor[
             0.2940376027932159, 0.42638254196942454`, 0.9400563785381975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 323}], {
             RGBColor[
             0.35358359064672407`, 0.4806531148021672, 0.943751925265087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 324}], {
             RGBColor[
             0.4708028735942141, 0.577300258720949, 0.9525700303913813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 346}], {
             RGBColor[
             0.329771268632467, 0.46002807831552184`, 0.9422346251627481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 390}], {
             RGBColor[
             0.28559351861557547`, 0.41750727411286515`, 0.9395755004361839]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 66}], {
             RGBColor[
             0.21421674509456057`, 0.34248575959345395`, 0.9355106987766358]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 123}], {
             RGBColor[
             0.2129302625842361, 0.3411335849074007, 0.9354374355008532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 131}], {
             RGBColor[
             0.21370957013719966`, 0.34195268655651806`, 0.9354818159131122]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[
             0.2199309237526768, 0.34849172366298653`, 0.9358361127978458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 188}], {
             RGBColor[
             0.20797364918202638`, 0.3359238699542373, 0.9351551637002498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 203}], {
             RGBColor[
             0.21995986800379036`, 0.3485221459060784, 0.9358377611301275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 232}], {
             RGBColor[
             0.2546277618608894, 0.3849603004213146, 0.9378120463987364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 275}], {
             RGBColor[
             0.22645651195099847`, 0.3553505306056112, 0.9362077353919975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 280}], {
             RGBColor[
             0.23284937828008462`, 0.36206983844861684`, 0.9365717996720409]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 297}], {
             RGBColor[
             0.2105416090442786, 0.33862295858752356`, 0.9353014052154489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 309}], {
             RGBColor[
             0.25587961899129924`, 0.38627608163770166`, 0.9378833378103566]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 322}], {
             RGBColor[
             0.20703389947966117`, 0.33493613343347894`, 0.9351016463449351]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 325}], {
             RGBColor[
             0.25165090865355244`, 0.3818314389570088, 0.9376425190124382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 339}], {
             RGBColor[
             0.2328552355524508, 0.3620759948132462, 0.936572133235037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 29}], {
             RGBColor[
             0.18299367418147944`, 0.3096683324067703, 0.9337325910785299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 62}], {
             RGBColor[
             0.1928274082051604, 0.3200042103604074, 0.9342926076834728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 119}], {
             RGBColor[
             0.18348249259608096`, 0.310182111553394, 0.9337604285640995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 126}], {
             RGBColor[
             0.18556762080960376`, 0.31237371351057097`, 0.9338791735311889]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 127}], {
             RGBColor[
             0.18967658911817914`, 0.3166924997265216, 0.9341131731976884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 129}], {
             RGBColor[
             0.18681866782962492`, 0.3136886432495756, 0.9339504188082208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 196}], {
             RGBColor[
             0.18714224683050756`, 0.3140287452955969, 0.9339688461536289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 235}], {
             RGBColor[
             0.1880315009055375, 0.3149634077104182, 0.9340194878576683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 317}], {
             RGBColor[
             0.18995153056345765`, 0.3169814806178038, 0.9341288307062575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 326}], {
             RGBColor[
             0.18828033718868842`, 0.3152249504211414, 0.9340336587158735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 327}], {
             RGBColor[
             0.19007805312865012`, 0.317114463855815, 0.9341360359791719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 336}], {
             RGBColor[
             0.18245115534282794`, 0.3090981107096664, 0.9337016954332534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 396}], {
             RGBColor[
             0.19205343988410067`, 0.31919072058254777`, 0.9342485313325719]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 33}], {
             RGBColor[
             0.28118366953987284`, 0.41287224313372134`, 0.9393243660551096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 37}], {
             RGBColor[
             0.31731211488685307`, 0.44714239125067556`, 0.9415174176154697]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.24346570234943876`, 0.37322826815933124`, 0.9371763836223466]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 92}], {
             RGBColor[
             0.3916080301069964, 0.5102971083648917, 0.9465821312407912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 256}], {
             RGBColor[
             0.31856719551894513`, 0.448229479012007, 0.9415973902435224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 311}], {
             RGBColor[
             0.2942848105043079, 0.4266423729476564, 0.940070456651633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 313}], {
             RGBColor[
             0.25209641053026927`, 0.3822996896758886, 0.9376678896852563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 361}], {
             RGBColor[
             0.2517308007762076, 0.3819154106433724, 0.9376470687506336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 386}], {
             RGBColor[
             0.5232931103169385, 0.6153912271159707, 0.9581889419192983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 69}], {
             RGBColor[
             0.2797958916834022, 0.41057876108804503`, 0.9392759017239116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 106}], {
             RGBColor[
             0.2722971064429795, 0.4026970623499158, 0.9388488569979281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 107}], {
             RGBColor[
             0.33319709362883454`, 0.4630203083535974, 0.9424520020647762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 190}], {
             RGBColor[
             0.6369974104682594, 0.7082659607734624, 0.9502314057905163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 212}], {
             RGBColor[
             0.36755596390986156`, 0.4927802348639901, 0.9446413188967272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 241}], {
             RGBColor[
             0.29049437153587576`, 0.42182354173579545`, 0.9398851643245274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 268}], {
             RGBColor[
             0.49856920010276634`, 0.5995528138290274, 0.9550727772448264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 270}], {
             RGBColor[
             0.3384373755940835, 0.46755917720766627`, 0.9427859081978025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 274}], {
             RGBColor[
             0.4054269963890745, 0.5245026293096915, 0.9473527216519175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 295}], {
             RGBColor[
             0.3734051820083968, 0.4978465335906915, 0.9450140259017055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 310}], {
             RGBColor[
             0.2986872977789616, 0.43043482667880517`, 0.9403517393537228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 324}], {
             RGBColor[
             0.47545256857995977`, 0.5813525434303296, 0.9528653912069069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 351}], {
             RGBColor[
             0.6137824648944775, 0.6902841557450048, 0.9663635368138602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 373}], {
             RGBColor[
             0.29481332974402036`, 0.42636304065032193`, 0.9401311226051551]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 380}], {
             RGBColor[
             0.26894987250182517`, 0.3991789072508731, 0.9386582369767682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 390}], {
             RGBColor[
             0.2902432136013212, 0.4215595588222458, 0.9398708612517093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 22}], {
             RGBColor[
             0.2739758563683775, 0.40460023321935323`, 0.9389393809000012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 48}], {
             RGBColor[
             0.23593219427525336`, 0.3653100735213626, 0.936747361482348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 61}], {
             RGBColor[
             0.22052046256389546`, 0.34911136633249684`, 0.9358696861610002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 118}], {
             RGBColor[
             0.23527881827982655`, 0.36462333392373825`, 0.9367101526859918]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 158}], {
             RGBColor[
             0.2852162427380673, 0.4143360909345327, 0.9396556083799944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 164}], {
             RGBColor[
             0.21631448031938844`, 0.34469061231884324`, 0.9356301616943686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 173}], {
             RGBColor[
             0.25707808713188923`, 0.38753574764073073`, 0.9379515887979883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 209}], {
             RGBColor[
             0.2832594251473382, 0.412641193889955, 0.9395309216934591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 241}], {
             RGBColor[
             0.2474447922190557, 0.37741054390116785`, 0.9374029869038852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 287}], {
             RGBColor[
             0.2108043778715786, 0.3388991452855218, 0.9353163695114319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 323}], {
             RGBColor[
             0.3151837063156497, 0.44029240167692024`, 0.9415651086599703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 346}], {
             RGBColor[
             0.29137138430139253`, 0.41966736519027487`, 0.9400478085576316]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 354}], {
             RGBColor[
             0.2237645258481464, 0.35252108252973663`, 0.9360544307658767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 371}], {
             RGBColor[
             0.20911196002482746`, 0.33712030682309724`, 0.9352199888187673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 388}], {
             RGBColor[
             0.22559527698605156`, 0.35444531805200136`, 0.9361586893348268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 389}], {
             RGBColor[
             0.21716250001380405`, 0.34558193478522814`, 0.9356784551614329]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 45}], {
             RGBColor[
             0.4449748432614876, 0.5535011435034702, 0.9507944263097807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 74}], {
             RGBColor[
             0.7341001698400949, 0.7919819236306536, 0.974429319456183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 86}], {
             RGBColor[
             0.5080814719938581, 0.6103740358685661, 0.9547344923700136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 91}], {
             RGBColor[
             0.5492190587011108, 0.6449197997470224, 0.9576556826381046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 112}], {
             RGBColor[
             0.7711240798821252, 0.7393399357057666, 0.6151558638126768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 141}], {
             RGBColor[
             0.7353689115489879, 0.586455396789142, 0.5858108169853278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 148}], {
             RGBColor[
             0.46955925293009415`, 0.5770080258985608, 0.9522798906351313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 179}], {
             RGBColor[
             0.5295441815391476, 0.6289468481238254, 0.9561068042364651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 232}], {
             RGBColor[
             0.4501165590628717, 0.5589054128143358, 0.9510872394181826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 257}], {
             RGBColor[
             0.46412234198098856`, 0.5722988469015355, 0.9519334554771259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 279}], {
             RGBColor[
             0.638687245246097, 0.7170964540862654, 0.9650118438159424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 285}], {
             RGBColor[
             0.7996696633612428, 0.8401599138816065, 0.7860186576407228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 288}], {
             RGBColor[
             0.45525573629442806`, 0.5643070139273578, 0.9513799079587884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 399}], {
             RGBColor[
             0.7658581753592988, 0.7184623790314186, 0.610918793426945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 185}], {
             RGBColor[
             0.330002266441723, 0.4557835793222022, 0.9424120819002554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 198}], {
             RGBColor[
             0.30685620721234774`, 0.43573562617248035`, 0.9409372354734161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 205}], {
             RGBColor[
             0.30521095643223367`, 0.4343105926394541, 0.9408324015485454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 219}], {
             RGBColor[
             0.2987647907941907, 0.4287272479574868, 0.9404216575742097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 262}], {
             RGBColor[
             0.23727783738368446`, 0.36672442974702457`, 0.9368239938666727]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 284}], {
             RGBColor[
             0.2685014480461575, 0.3995424242445413, 0.938602132302708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 293}], {
             RGBColor[
             0.3046492475878372, 0.4338240686707453, 0.9407966099576801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 331}], {
             RGBColor[
             0.22977587045111889`, 0.35883938684872224`, 0.9363967679480286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 338}], {
             RGBColor[
             0.24730224830049347`, 0.3772607212049526, 0.937394869238598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.1986384662361157, 0.32611200079330077`, 0.9346235388416457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 36}], {
             RGBColor[
             0.19158305641128354`, 0.3186963177285822, 0.934221743689665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 80}], {
             RGBColor[
             0.18504810846190303`, 0.31182767309415216`, 0.933849588071537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 151}], {
             RGBColor[
             0.19115376674236922`, 0.3182451070680162, 0.9341972962780976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 168}], {
             RGBColor[
             0.18724662483160132`, 0.31413845319269396`, 0.9339747903263778]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 265}], {
             RGBColor[
             0.19013547399899927`, 0.31717481683124543`, 0.9341393060127917]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 291}], {
             RGBColor[
             0.18873168488737596`, 0.31569934546955897`, 0.9340593622996046]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 304}], {
             RGBColor[
             0.185589373288035, 0.312396576744589, 0.9338804123026556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 378}], {
             RGBColor[
             0.19055340614426983`, 0.31761409001435326`, 0.9341631066301896]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 383}], {
             RGBColor[
             0.1993210537450841, 0.3268294435437743, 0.9346624111904838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 24}], {
             RGBColor[
             0.8919944774662327, 0.5241583098068742, 0.2395431849721498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 25}], {
             RGBColor[
             0.890260551987202, 0.5108305987640545, 0.23788277597524127`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 27}], {
             RGBColor[
             0.8921201702935075, 0.5251244399562564, 0.23966354856549787`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 32}], {
             RGBColor[
             0.9601171751337108, 0.8771280081727125, 0.29956318594431774`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 78}], {
             RGBColor[
             0.8915698412637564, 0.5208943698778701, 0.23913655286510038`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 95}], {
             RGBColor[
             0.7613060096832925, 0.7703636969149021, 0.6350027480788232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 104}], {
             RGBColor[
             0.8911056135339068, 0.5173261121203578, 0.23869200786672617`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 160}], {
             RGBColor[
             0.7114127926044326, 0.7298581356264684, 0.631074971265499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 172}], {
             RGBColor[
             0.8935026650840421, 0.5357509007293852, 0.24098742713821833`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 208}], {
             RGBColor[
             0.9781086897296334, 0.9394569243444684, 0.5384830216306559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 217}], {
             RGBColor[
             0.9781358461419554, 0.9375595363156388, 0.3992965964312667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 230}], {
             RGBColor[
             0.8904702103094787, 0.5124421245019355, 0.2380835450214286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 233}], {
             RGBColor[
             0.9613042288478943, 0.9283900515581442, 0.6325730929841542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 240}], {
             RGBColor[
             0.8974455137213154, 0.5660573631227573, 0.24476310344608182`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 242}], {
             RGBColor[
             0.907737765098039, 0.6451681172975665, 0.25461897498786773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 244}], {
             RGBColor[
             0.9589837634229517, 0.9266594522436353, 0.6365010356742713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 264}], {
             RGBColor[
             0.8432468849976082, 0.8356472056673055, 0.6423010818703361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 285}], {
             RGBColor[
             0.9787005711665018, 0.9387674260406853, 0.4607634302742779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 357}], {
             RGBColor[
             0.910151296596057, 0.6637195780075789, 0.25693017547606367`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 47}], {
             RGBColor[
             0.4301895095994409, 0.5445652207348299, 0.9493133718661378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 48}], {
             RGBColor[
             0.27823170323432733`, 0.40907339811174287`, 0.9391817450830557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 96}], {
             RGBColor[
             0.5322372446835262, 0.6257908335621027, 0.9584554594663912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 118}], {
             RGBColor[
             0.2775783272389005, 0.4083866585141185, 0.9391445362866995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 158}], {
             RGBColor[
             0.3275157516971413, 0.458099415524913, 0.9420899919807021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 173}], {
             RGBColor[
             0.2993775960909632, 0.43129907223111097`, 0.940385972398696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 209}], {
             RGBColor[
             0.32555893410641223`, 0.4564045184803353, 0.9419653052941668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 241}], {
             RGBColor[
             0.28974430117812966`, 0.42117386849154814`, 0.9398373705045929]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 310}], {
             RGBColor[
             0.2979372274212155, 0.4297851534345578, 0.9403039455337885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 323}], {
             RGBColor[
             0.35748321527472365`, 0.48405572626730053`, 0.943999492260678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 346}], {
             RGBColor[
             0.3336708932604665, 0.46343068978065516`, 0.9424821921583393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 354}], {
             RGBColor[
             0.2660640348072204, 0.3962844071201169, 0.9384888143665844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 388}], {
             RGBColor[
             0.26789478594512556`, 0.39820864264238165`, 0.9385930729355345]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 75}], {
             RGBColor[
             0.255511442446525, 0.3858891047454028, 0.9378623707008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 120}], {
             RGBColor[
             0.40567769043424073`, 0.5225843384798207, 0.9476110227757661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 132}], {
             RGBColor[
             0.32566481114992, 0.45504559524241234`, 0.9420251663053016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 160}], {
             RGBColor[
             0.3763398438622711, 0.4987665529777692, 0.9453014400255476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 202}], {
             RGBColor[
             0.2682077809117381, 0.39923376146669465`, 0.9385854083938443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 220}], {
             RGBColor[
             0.46443936234214256`, 0.5702897109178078, 0.9522369568394528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 229}], {
             RGBColor[
             0.24996961512608984`, 0.38006429285947896`, 0.9375467718333002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 260}], {
             RGBColor[
             0.2588190028871956, 0.3893655604799919, 0.938050731374799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 307}], {
             RGBColor[
             0.32070535665531497`, 0.4507499650286162, 0.9417091542503788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 321}], {
             RGBColor[
             0.42370887427578074`, 0.5372228658179581, 0.9490305036181749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 341}], {
             RGBColor[
             0.3146456284168403, 0.44550133299924655`, 0.9413230337254305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 348}], {
             RGBColor[
             0.3130979265677895, 0.44416079144735543`, 0.9412244155321879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 366}], {
             RGBColor[
             0.34372780451171075`, 0.47069085221995155`, 0.9431761242698371]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.8209125437853362, 0.16174855223502174`, 0.16765918158716517`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 32}], {
             RGBColor[
             0.8889095486255394, 0.5137521204514779, 0.227558818965985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 73}], {
             RGBColor[
             0.8757010840349191, 0.46170115302421727`, 0.21528423867768243`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.8419234511371824, 0.5272135480684979, 0.5771697251114055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 78}], {
             RGBColor[
             0.8203622147555851, 0.15751848215663547`, 0.1671321858867677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 104}], {
             RGBColor[
             0.8198979870257355, 0.15395022439912315`, 0.1666876408883935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 112}], {
             RGBColor[
             0.8789473611792127, 0.4745715601436108, 0.21789626946789925`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 141}], {
             RGBColor[
             0.8431921928460754, 0.3216870212269862, 0.1885512226405503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 172}], {
             RGBColor[
             0.8222950385758708, 0.17237501300815056`, 0.16898306015988562`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 208}], {
             RGBColor[
             0.906901063221462, 0.5760810366232336, 0.4664786546523232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 240}], {
             RGBColor[
             0.8262378872131442, 0.20268147540152273`, 0.17275873646774914`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 242}], {
             RGBColor[
             0.8365301385898678, 0.28179222957633193`, 0.182614608009535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 243}], {
             RGBColor[
             0.8951565236421906, 0.5687878448594291, 0.5520035990795774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 285}], {
             RGBColor[
             0.9074929446583304, 0.5753915383194507, 0.38875906329594523`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 337}], {
             RGBColor[
             0.9074168352108218, 0.5752287479070755, 0.3804750196277067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 357}], {
             RGBColor[
             0.8389436700878857, 0.3003436902863443, 0.184925808497731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 399}], {
             RGBColor[
             0.8736814566563863, 0.4536940034692628, 0.2136591990821675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 32}], {
             RGBColor[
             0.8871756231465087, 0.5004244094086581, 0.22589840996907645`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 78}], {
             RGBColor[
             0.8186282892765544, 0.1441907711138157, 0.16547177688985915`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 83}], {
             RGBColor[
             0.881176745521725, 0.5463271969673706, 0.5710722243747279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 194}], {
             RGBColor[
             0.9059253338243674, 0.5624195574854407, 0.4052009770396422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 201}], {
             RGBColor[
             0.8831813824108397, 0.5478222518769809, 0.567678897014493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 217}], {
             RGBColor[
             0.9051942941547533, 0.5608559375515845, 0.32563182045602546`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 223}], {
             RGBColor[
             0.8736105747823911, 0.4469597061439798, 0.21333691400652116`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 230}], {
             RGBColor[
             0.8175286583222767, 0.13573852573788114`, 0.16441876904618735`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 242}], {
             RGBColor[
             0.8347962131108371, 0.26846451853351216`, 0.18095419901262647`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 244}], {
             RGBColor[
             0.8860422114357496, 0.549955853479581, 0.56283625969903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 245}], {
             RGBColor[
             0.8180745277590571, 0.13993431743048723`, 0.16494149423531956`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 328}], {
             RGBColor[
             0.8434248781398908, 0.3172892303900453, 0.1885318018785458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 357}], {
             RGBColor[
             0.837209744608855, 0.2870159792435245, 0.18326539950082243`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 364}], {
             RGBColor[
             0.81749806012385, 0.1355033345765571, 0.16438946817681815`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 385}], {
             RGBColor[
             0.9058721590894482, 0.562305822104239, 0.3994132353001115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 105}], {
             RGBColor[
             0.19823757833601402`, 0.32569064219253296`, 0.9346007088687955]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 128}], {
             RGBColor[
             0.19080558249119994`, 0.3178791433438807, 0.9341774677000858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 159}], {
             RGBColor[
             0.18375580691440718`, 0.3104693822310835, 0.9337759934101959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 171}], {
             RGBColor[
             0.18798107467478986`, 0.3149104065446947, 0.9340166161584262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 215}], {
             RGBColor[
             0.18499791179933114`, 0.3117749132191369, 0.9338467294458628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 218}], {
             RGBColor[
             0.188929981383257, 0.31590776765945394`, 0.9340706549916917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 342}], {
             RGBColor[
             0.18535691671142462`, 0.3121522501439733, 0.9338671742445064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 349}], {
             RGBColor[
             0.19449252215171758`, 0.32175435069256086`, 0.9343874334594139]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 353}], {
             RGBColor[
             0.1885101327336185, 0.315466480108742, 0.9340467452322052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 32}], {
             RGBColor[
             0.8890352414528142, 0.5147182506008601, 0.2276791825593331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 73}], {
             RGBColor[
             0.8758267768621938, 0.46266728317359945`, 0.2154046022710305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 74}], {
             RGBColor[
             0.8420491439644571, 0.52817967821788, 0.5772900887047536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 78}], {
             RGBColor[
             0.8204879075828598, 0.15848461230601768`, 0.16725254948011575`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 104}], {
             RGBColor[
             0.8200236798530103, 0.15491635454850536`, 0.16680800448174155`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 112}], {
             RGBColor[
             0.8790730540064875, 0.47553769029299303`, 0.21801663306124733`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 141}], {
             RGBColor[
             0.8433178856733501, 0.32265315137636846`, 0.18867158623389835`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 172}], {
             RGBColor[
             0.8224207314031455, 0.17334114315753277`, 0.1691034237532337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 208}], {
             RGBColor[
             0.9070267560487368, 0.5770471667726158, 0.46659901824567124`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 225}], {
             RGBColor[
             0.8528742555567694, 0.5368113283617635, 0.5783225975121196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 240}], {
             RGBColor[
             0.8263635800404189, 0.20364760555090494`, 0.1728791000610972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 243}], {
             RGBColor[
             0.8952822164694654, 0.5697539750088114, 0.5521239626729255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 285}], {
             RGBColor[
             0.9076186374856052, 0.576357668468833, 0.38887942688929333`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 337}], {
             RGBColor[
             0.9075425280380967, 0.5761948780564576, 0.3805953832210548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 357}], {
             RGBColor[
             0.8390693629151604, 0.3013098204357265, 0.18504617209107904`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 399}], {
             RGBColor[
             0.873807149483661, 0.45466013361864505`, 0.21377956267551557`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 36}], {
             RGBColor[
             0.19993330434376533`, 0.3274729577419183, 0.9346972779563351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 151}], {
             RGBColor[
             0.19950401467485102`, 0.3270217470813523, 0.9346728305447676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 168}], {
             RGBColor[
             0.19559687276408316`, 0.32291509320603007`, 0.9344503245930478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 265}], {
             RGBColor[
             0.1984857219314811, 0.32595145684458154`, 0.9346148402794617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 267}], {
             RGBColor[
             0.23148773999796957`, 0.36063867028126045`, 0.9364942563862377]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 282}], {
             RGBColor[
             0.2370656602671769, 0.3665014181447689, 0.9368119106937756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 291}], {
             RGBColor[
             0.1970819328198578, 0.3244759854828951, 0.9345348965662746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 304}], {
             RGBColor[
             0.1939396212205168, 0.3211732167579251, 0.9343559465693256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 378}], {
             RGBColor[
             0.19890365407675165`, 0.32639073002768937`, 0.9346386408968597]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 383}], {
             RGBColor[
             0.20767130167756592`, 0.3356060835571104, 0.9351379454571538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.19127206346984504`, 0.31836944442903903`, 0.934204033101723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 87}], {
             RGBColor[
             0.18980864714848175`, 0.31683130108933233`, 0.9341206937071518]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 119}], {
             RGBColor[
             0.18192714786076558`, 0.30854734562202557`, 0.9336718539823496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 127}], {
             RGBColor[
             0.18812124438286376`, 0.3150577337951532, 0.9340245986159385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 129}], {
             RGBColor[
             0.18526332309430954`, 0.3120538773182072, 0.933861844226471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 231}], {
             RGBColor[
             0.1818156421264654, 0.3084301460254042, 0.9336655038957391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 235}], {
             RGBColor[
             0.18647615617022215`, 0.31332864177904984`, 0.9339309132759184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 317}], {
             RGBColor[
             0.1883961858281423, 0.3153467146864354, 0.9340402561245076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 326}], {
             RGBColor[
             0.18672499245337307`, 0.31359018448977305`, 0.9339450841341236]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 327}], {
             RGBColor[
             0.18852270839333474`, 0.31547969792444663`, 0.934047461397422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 336}], {
             RGBColor[
             0.18089581060751259`, 0.30746334477829806`, 0.9336131208515035]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 396}], {
             RGBColor[
             0.19049809514878532`, 0.31755595465117936`, 0.9341599567508221]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 54}], {
             RGBColor[
             0.1824115228296057, 0.3090564544254234, 0.9336994384202565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 63}], {
             RGBColor[
             0.18069605079375822`, 0.30725338454853857`, 0.9336017448256284]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 224}], {
             RGBColor[
             0.17977250803868983`, 0.30628268255696894`, 0.9335491504319864]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 297}], {
             RGBColor[
             0.19356559882175525`, 0.3207800955024369, 0.9343346465470327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 318}], {
             RGBColor[
             0.18730055861877407`, 0.31419514102261215`, 0.9339778617757692]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 345}], {
             RGBColor[
             0.1795989351746539, 0.30610024647171197`, 0.9335392657141575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 81}], {
             RGBColor[
             0.1880171511030766, 0.3149483251582018, 0.9340186706576468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 106}], {
             RGBColor[
             0.21164758701888683`, 0.33978541156189057`, 0.935364389024955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 164}], {
             RGBColor[
             0.19871454021211585`, 0.32619195936544565`, 0.9346278711420376]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 192}], {
             RGBColor[
             0.18904880805086632`, 0.3160326620211572, 0.9340774219946237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 241}], {
             RGBColor[
             0.22984485211178313`, 0.3589118909477702, 0.9364006963515542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 271}], {
             RGBColor[
             0.18778814176396494`, 0.3147076218227647, 0.9340056289145733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 287}], {
             RGBColor[
             0.19320443776430601`, 0.3204004923321242, 0.9343140789591009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 292}], {
             RGBColor[
             0.19543097961487327`, 0.32274072898797734`, 0.9344408772236172]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 371}], {
             RGBColor[
             0.1915120199175549, 0.31862165386969954`, 0.9342176982664363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 374}], {
             RGBColor[
             0.1933477765192394, 0.32055115045176114`, 0.9343222418891437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 382}], {
             RGBColor[
             0.18918398084593196`, 0.3161747371992214, 0.9340851198853325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 384}], {
             RGBColor[
             0.19301716646589862`, 0.32020365832381187`, 0.9343034141356996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 389}], {
             RGBColor[
             0.19956255990653143`, 0.3270832818318305, 0.9346761646091019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 78}], {
             RGBColor[
             0.888484912423063, 0.5104881805224738, 0.22715218685893562`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 104}], {
             RGBColor[
             0.8880206846932135, 0.5069199227649615, 0.22670764186056142`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 172}], {
             RGBColor[
             0.8904177362433487, 0.5253447113739889, 0.22900306113205354`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 194}], {
             RGBColor[
             0.9757819569708761, 0.9287169668940988, 0.4668813870087187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 208}], {
             RGBColor[
             0.97502376088894, 0.929050734989072, 0.526498655624491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 217}], {
             RGBColor[
             0.975050917301262, 0.9271533469602427, 0.3873122304251019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 223}], {
             RGBColor[
             0.9434671979288998, 0.8132571155526379, 0.27501732397559764`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 230}], {
             RGBColor[
             0.8873852814687854, 0.5020359351465393, 0.22609917901526383`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 240}], {
             RGBColor[
             0.8943605848806221, 0.5556511737673611, 0.23277873743991706`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 242}], {
             RGBColor[
             0.9046528362573457, 0.6347619279421703, 0.24263460898170292`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 357}], {
             RGBColor[
             0.9070663677553636, 0.6533133886521827, 0.2449458094698989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 364}], {
             RGBColor[
             0.8873546832703587, 0.5018007439852152, 0.22606987814589463`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 385}], {
             RGBColor[
             0.9757287822359568, 0.928603231512897, 0.461093645269188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 387}], {
             RGBColor[
             0.7455791435710649, 0.7496942133696903, 0.622023162461701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 92}], {
             RGBColor[
             0.3869660924415177, 0.5054181375626268, 0.9463177797578736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 182}], {
             RGBColor[
             0.3125367270389322, 0.44214783260778046`, 0.9412445628049322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 256}], {
             RGBColor[
             0.3139252578534664, 0.443350508209742, 0.9413330387606047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 281}], {
             RGBColor[
             0.3526148324525338, 0.4768614731328931, 0.9437983042422098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 311}], {
             RGBColor[
             0.28964287283882917`, 0.4217634021453914, 0.9398061051687154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 35}], {
             RGBColor[
             0.24974982719833305`, 0.3798332818120472, 0.9375342552359615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 85}], {
             RGBColor[
             0.25199669770088307`, 0.3821948851700452, 0.9376622111871347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 86}], {
             RGBColor[
             0.3371353879041764, 0.46222487105446, 0.9428569705546225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 91}], {
             RGBColor[
             0.37827297461142906`, 0.4967706349329164, 0.9457781608227135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 93}], {
             RGBColor[
             0.24878417747359188`, 0.37881832272561544`, 0.9374792629126882]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 95}], {
             RGBColor[
             0.41132901778835196`, 0.5236070199417173, 0.9483804536298768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 125}], {
             RGBColor[
             0.2623800078372861, 0.3931084024632914, 0.9382535253386719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 162}], {
             RGBColor[
             0.2677884948207052, 0.39879306520074553`, 0.9385615306712383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 211}], {
             RGBColor[
             0.2425688344221679, 0.3722856031030586, 0.9371253083206856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 214}], {
             RGBColor[
             0.25149658822823806`, 0.38166923840552336`, 0.9376337306925131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 248}], {
             RGBColor[
             0.24062348998029212`, 0.37024092275268566`, 0.9370145238326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 263}], {
             RGBColor[
             0.3276003815122878, 0.45396612776116196`, 0.9422494083788064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 340}], {
             RGBColor[
             0.23309142699709673`, 0.3623242469969716, 0.9365855839883956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 42}], {
             RGBColor[
             0.22638274960055194`, 0.35527300169848874`, 0.9362035347352613]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 85}], {
             RGBColor[
             0.2384984047146932, 0.36800732340035325`, 0.9368935033705061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 86}], {
             RGBColor[
             0.32363709491798653`, 0.44803730928476804`, 0.942088262737994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 93}], {
             RGBColor[
             0.235285884487402, 0.3646307609559235, 0.9367105550960597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 97}], {
             RGBColor[
             0.21457055736469166`, 0.3428576387223553, 0.9355308478620015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 98}], {
             RGBColor[
             0.21863346925867172`, 0.3471280167264209, 0.9357622246838242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 125}], {
             RGBColor[
             0.24888171485109623`, 0.37892084069359944`, 0.9374848175220434]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 162}], {
             RGBColor[
             0.25429020183451534`, 0.3846055034310536, 0.9377928228546097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 211}], {
             RGBColor[
             0.22907054143597805`, 0.35809804133336665`, 0.9363566005040571]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 214}], {
             RGBColor[
             0.23799829524204824`, 0.3674816766358314, 0.9368650228758846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 248}], {
             RGBColor[
             0.22712519699410227`, 0.3560533609829937, 0.9362458160159715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 263}], {
             RGBColor[
             0.31410208852609794`, 0.43977856599147, 0.9414807005621779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 340}], {
             RGBColor[
             0.21959313401090685`, 0.34813668522727964`, 0.9358168761717671]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 80}], {
             RGBColor[
             0.1863429465695527, 0.31318863004276976`, 0.9339233271862263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 151}], {
             RGBColor[
             0.19244860485001886`, 0.3196060640166337, 0.9342710353927868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 168}], {
             RGBColor[
             0.18854146293925098`, 0.3154994101413115, 0.9340485294410671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 265}], {
             RGBColor[
             0.1914303121066489, 0.318535773779863, 0.934213045127481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 277}], {
             RGBColor[
             0.20034660319217895`, 0.3279073610362615, 0.9347208147143313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 304}], {
             RGBColor[
             0.18688421139568462`, 0.3137575336932065, 0.933954151417345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 378}], {
             RGBColor[
             0.1918482442519195, 0.31897504696297085`, 0.934236845744879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 383}], {
             RGBColor[
             0.20061589185273376`, 0.3281904004923918, 0.9347361503051731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 41}], {
             RGBColor[
             0.6103348144421008, 0.6886019294831773, 0.9655435733376975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 114}], {
             RGBColor[
             0.2950446149939596, 0.4237378370222073, 0.9402493164383834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 170}], {
             RGBColor[
             0.29023151793817503`, 0.41867896684859873`, 0.9399752176813956]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 187}], {
             RGBColor[
             0.39185947335344506`, 0.5138307132141199, 0.9461899170277228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 206}], {
             RGBColor[
             0.5395559184345032, 0.6328895346269106, 0.9586002858977685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 256}], {
             RGBColor[
             0.3500537032004466, 0.4776206563266962, 0.9435260903209648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 261}], {
             RGBColor[
             0.30438433219243016`, 0.43355447197007246`, 0.940781199515963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 311}], {
             RGBColor[
             0.3257713181858094, 0.4560335502623456, 0.9419991567290754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 361}], {
             RGBColor[
             0.28321730845770904`, 0.41130658795806163`, 0.939575768828076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 53}], {
             RGBColor[
             0.2076634431002256, 0.3355978236940631, 0.9351374979228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 58}], {
             RGBColor[
             0.2174442667054725, 0.3458780894432118, 0.935694501357687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 102}], {
             RGBColor[
             0.25020060979959846`, 0.3803070829072448, 0.9375599266382304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 103}], {
             RGBColor[
             0.20863860950919683`, 0.3366227854190133, 0.9351930322071614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 117}], {
             RGBColor[
             0.22453541604736282`, 0.35333133700637476`, 0.9360983318222922]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 145}], {
             RGBColor[
             0.21009367554414693`, 0.338152152078261, 0.9352758960652745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 189}], {
             RGBColor[
             0.24478652953490182`, 0.3746165412765333, 0.9372516027765698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 222}], {
             RGBColor[
             0.22765792346573496`, 0.35661329028148886`, 0.9362761540004327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 254}], {
             RGBColor[
             0.20508861754811766`, 0.3328915187854286, 0.9349908654167205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 303}], {
             RGBColor[
             0.21808265414273661`, 0.3465490751158777, 0.9357308565778295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 376}], {
             RGBColor[
             0.21626586560617583`, 0.3446395151729059, 0.9356273931583702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 150}], {
             RGBColor[
             0.1883607596919023, 0.31530947957110045`, 0.9340382386584571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 237}], {
             RGBColor[
             0.19025421078354665`, 0.3172996167201517, 0.9341460678970164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 251}], {
             RGBColor[
             0.18672478342346222`, 0.3135899647860835, 0.9339450722301794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 283}], {
             RGBColor[
             0.19607798492560893`, 0.3234207725920666, 0.934477723218905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 294}], {
             RGBColor[
             0.18656769797512113`, 0.31342485802008435`, 0.9339361264462835]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 320}], {
             RGBColor[
             0.18948414481075992`, 0.3164902285577502, 0.9341022137790767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 347}], {
             RGBColor[
             0.19051344323313968`, 0.3175720864609606, 0.9341608308015206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 381}], {
             RGBColor[
             0.18966952552711056`, 0.31668507544445096`, 0.9341127709366266]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 51}], {
             RGBColor[
             0.4513189432678153, 0.5634921655168925, 0.9504868403154272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 84}], {
             RGBColor[
             0.42994887224450423`, 0.5449824840875006, 0.9491251582866337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 102}], {
             RGBColor[
             0.39926565859510593`, 0.5155146756656562, 0.9472759248895897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 134}], {
             RGBColor[
             0.6760140538149009, 0.745057217744171, 0.9695892868351288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 163}], {
             RGBColor[
             0.3939273213258807, 0.5099037447255685, 0.9469719144794696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 167}], {
             RGBColor[
             0.4156571514498516, 0.5326037138579458, 0.948214502475271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 174}], {
             RGBColor[
             0.4325281900725898, 0.5472165595499049, 0.9492895101378381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 183}], {
             RGBColor[
             0.43552341404886974`, 0.5498108720138242, 0.9494803631610341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 189}], {
             RGBColor[
             0.3938515783304093, 0.5098241340349448, 0.9469676010279292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 226}], {
             RGBColor[
             0.48315013418370223`, 0.5910627432060597, 0.9525150956533707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 234}], {
             RGBColor[
             0.653391331063141, 0.7272953937118065, 0.9673580250213626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 246}], {
             RGBColor[
             0.7206526383610699, 0.7806508133791874, 0.9738469548784772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 269}], {
             RGBColor[
             0.6323207129287618, 0.7108348666826005, 0.9652579027218493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 272}], {
             RGBColor[
             0.6309966022057711, 0.7098004613221861, 0.9651259277394999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 350}], {
             RGBColor[
             0.7574551958384235, 0.806891984810095, 0.8535080309341501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 355}], {
             RGBColor[
             0.6433835290110301, 0.7194772226865849, 0.9663605408410356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 392}], {
             RGBColor[
             0.7560719179586157, 0.8063199638581745, 0.8764325252109648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 395}], {
             RGBColor[
             0.494849422028799, 0.60078007937222, 0.9533755056767188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 55}], {
             RGBColor[
             0.9217511656674453, 0.9083191148939446, 0.6659672564832814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 83}], {
             RGBColor[
             0.9084527486796484, 0.9295988421678656, 0.9827837388659694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.684630729662244, 0.7517566465973935, 0.970608286963019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 135}], {
             RGBColor[
             0.9333566323648748, 0.9460233638065111, 0.83381543555314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 156}], {
             RGBColor[
             0.8514284367030327, 0.5699234098578776, 0.5824732181712974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 165}], {
             RGBColor[
             0.8843102751860701, 0.9105890257431475, 0.9888274975519911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 187}], {
             RGBColor[
             0.6533956652271913, 0.7258990741319324, 0.9682873726725081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 206}], {
             RGBColor[
             0.8010921103082493, 0.8449578955447232, 0.9806977415425538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 245}], {
             RGBColor[
             0.8453505309169804, 0.5232059626309822, 0.576653008726561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 256}], {
             RGBColor[
             0.6115898950741928, 0.6896890172445088, 0.9656235459657501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 311}], {
             RGBColor[
             0.5873075100595555, 0.6681019111801583, 0.9640966123738608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 328}], {
             RGBColor[
             0.8707008812978143, 0.7005608755905404, 0.6002433163697872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 386}], {
             RGBColor[
             0.8163158098721861, 0.8568507653484726, 0.982215097641526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 400}], {
             RGBColor[
             0.861024743522975, 0.6436848292044157, 0.5916626524195524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 45}], {
             RGBColor[
             0.2506616815740248, 0.3807916985758058, 0.9375861839936894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 93}], {
             RGBColor[
             0.22541709987581074`, 0.35425804261205696`, 0.936148542411988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 98}], {
             RGBColor[
             0.20876468464708048`, 0.33675529838255447`, 0.9352002119997525]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 125}], {
             RGBColor[
             0.23901293023950498`, 0.3685481223497329, 0.9369228048379719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 139}], {
             RGBColor[
             0.20228682166276132`, 0.3299466536657998, 0.934831307285935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 148}], {
             RGBColor[
             0.27524609124263133`, 0.40429858097089644`, 0.9390716483190401]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 204}], {
             RGBColor[
             0.20507426806755127`, 0.33287643657154375`, 0.9349900482350304]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 248}], {
             RGBColor[
             0.21725641238251098`, 0.34568064263912723`, 0.9356838033318999]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 275}], {
             RGBColor[
             0.2276321474655179, 0.3565861980709679, 0.9362746860953526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 276}], {
             RGBColor[
             0.2196855450649306, 0.3482338151042579, 0.9358221388445839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 288}], {
             RGBColor[
             0.26094257460696524`, 0.39159756899969334`, 0.938171665642697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 290}], {
             RGBColor[
             0.20736560396252507`, 0.33528477587624783`, 0.9351205364245214]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 318}], {
             RGBColor[
             0.2054522043558168, 0.33327367157305554`, 0.9350115711475404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 56}], {
             RGBColor[
             0.3210051071529382, 0.44798658822988663`, 0.9418389411311112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 59}], {
             RGBColor[
             0.3034359716582913, 0.4327690861148492, 0.9407194513531689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[
             0.434369237561579, 0.5419666394359329, 0.9502257108546233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 121}], {
             RGBColor[
             0.28563299292961386`, 0.4173490407437973, 0.9395850612911336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 122}], {
             RGBColor[
             0.42916131354223347`, 0.5377386121027248, 0.9498157239985662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 175}], {
             RGBColor[
             0.2710055822533935, 0.4021744280676252, 0.9387447390412754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 213}], {
             RGBColor[
             0.2414891450614786, 0.3711507811287148, 0.9370638216088516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 227}], {
             RGBColor[
             0.23391469744368304`, 0.36318955643469497`, 0.9366324680224093]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 237}], {
             RGBColor[
             0.22884629711642387`, 0.3578623463356042, 0.9363438301217982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 274}], {
             RGBColor[
             0.3767191464303865, 0.4951636983486218, 0.9456872845015338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 296}], {
             RGBColor[
             0.2526601828418626, 0.38289225012060224`, 0.937699995684375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 308}], {
             RGBColor[
             0.23093015114267265`, 0.3600526090411681, 0.9364625025258073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 373}], {
             RGBColor[
             0.2661054797853324, 0.3970241096892522, 0.9384656854547713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 380}], {
             RGBColor[
             0.2402420225431372, 0.36983997628980336`, 0.9369927998263845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 46}], {
             RGBColor[
             0.2189840028439955, 0.34749644974970917`, 0.9357821870529404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 65}], {
             RGBColor[
             0.2623103948909678, 0.393035234842995, 0.9382495609843622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 68}], {
             RGBColor[
             0.25335041241870687`, 0.38361772516894843`, 0.9377393032376733]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 113}], {
             RGBColor[
             0.27210008577250266`, 0.4033248206617401, 0.9388070693975159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 149}], {
             RGBColor[
             0.22663901581167467`, 0.355542353734595, 0.9362181287168728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 161}], {
             RGBColor[
             0.2180648213930185, 0.34653033176526227`, 0.9357298410291143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 195}], {
             RGBColor[
             0.2192614298530921, 0.3477880431261581, 0.9357979861106919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 247}], {
             RGBColor[
             0.2171512777998561, 0.34557013952683935`, 0.9356778160729503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 249}], {
             RGBColor[
             0.27287548484168234`, 0.4041092659680885, 0.9388523457495259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 250}], {
             RGBColor[
             0.24751102743025372`, 0.3774801613076919, 0.9374067589011768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 266}], {
             RGBColor[
             0.23471345152571355`, 0.36402909761884283`, 0.9366779558857301]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 315}], {
             RGBColor[
             0.22776027402374388`, 0.3567208672073564, 0.9362819827132973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 316}], {
             RGBColor[
             0.23551418105696653`, 0.3648707151253743, 0.9367235562479619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 358}], {
             RGBColor[
             0.21372519899594036`, 0.3419691134779814, 0.9354827059534967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 362}], {
             RGBColor[
             0.21291981933663207`, 0.3411226083920287, 0.9354368407733515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 363}], {
             RGBColor[
             0.22828771928123268`, 0.35727524561493795`, 0.9363120199404259]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 369}], {
             RGBColor[
             0.21363611782330827`, 0.34187548351747254`, 0.9354776329124991]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 372}], {
             RGBColor[
             0.21537145554787535`, 0.3436994334927591, 0.9355764578287111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 66}], {
             RGBColor[
             0.2495400971941441, 0.37961284227999426`, 0.9375223114224907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 91}], {
             RGBColor[
             0.38905361359871204`, 0.5081017700405416, 0.9463921022645131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 123}], {
             RGBColor[
             0.24825361468381962`, 0.37826066759394095`, 0.9374490481467079]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 140}], {
             RGBColor[
             0.25525427585226035`, 0.38561880634952683`, 0.9378477254437005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 148}], {
             RGBColor[
             0.30939380782769543`, 0.44018999619208, 0.9410163102615399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 179}], {
             RGBColor[
             0.3693787364367489, 0.49212881841734446`, 0.9448432238628737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 203}], {
             RGBColor[
             0.2552832201033739, 0.38564922859261863`, 0.9378493737759823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 232}], {
             RGBColor[
             0.28995111396047296`, 0.4220873831078549, 0.9398236590445912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 257}], {
             RGBColor[
             0.30395689687858984`, 0.4354808171950546, 0.9406698751035344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 275}], {
             RGBColor[
             0.261779864050582, 0.3924776132921515, 0.9382193480378523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 276}], {
             RGBColor[
             0.2538332616499947, 0.38412523032544144`, 0.9377668007870836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 279}], {
             RGBColor[
             0.4785218001436983, 0.5802784243797845, 0.9537482634423509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 280}], {
             RGBColor[
             0.26817273037966816`, 0.3991969211351571, 0.9385834123178955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 288}], {
             RGBColor[
             0.29509029119202934`, 0.4274889842208769, 0.9401163275851969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 297}], {
             RGBColor[
             0.2458649611438621, 0.37575004127406386`, 0.9373130178613036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 325}], {
             RGBColor[
             0.2869742607531359, 0.4189585216435491, 0.9396541316582929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 339}], {
             RGBColor[
             0.26817858765203434`, 0.39920307749978645`, 0.9385837458808918]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 149}], {
             RGBColor[
             0.20894845482391827`, 0.3369484524901131, 0.9352106774394597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 153}], {
             RGBColor[
             0.1918690303202028, 0.3189968944386494, 0.9342380294807175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 161}], {
             RGBColor[
             0.20037426040526207`, 0.3279364305207805, 0.9347223897517012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 184}], {
             RGBColor[
             0.19220194755564052`, 0.3193468115612663, 0.9342569886247687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 195}], {
             RGBColor[
             0.2015708688653357, 0.3291941418816762, 0.9347905348332788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 247}], {
             RGBColor[
             0.1994607168120997, 0.32697623828235756`, 0.9346703647955372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 250}], {
             RGBColor[
             0.22982046644249732`, 0.3588862600632101, 0.9363993076237638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 315}], {
             RGBColor[
             0.21006971303598748`, 0.3381269659628746, 0.9352745314358842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 343}], {
             RGBColor[
             0.19165716183089215`, 0.31877420722314587`, 0.9342259638836825]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 356}], {
             RGBColor[
             0.1981426064801053, 0.32559082075040946`, 0.9345953003620997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 358}], {
             RGBColor[
             0.19603463800818394`, 0.3233752122334996, 0.9344752546760837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 362}], {
             RGBColor[
             0.19522925834887567`, 0.3225287071475469, 0.9344293894959386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 363}], {
             RGBColor[
             0.21059715829347625`, 0.33868134437045616`, 0.9353045686630128]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 369}], {
             RGBColor[
             0.19594555683555187`, 0.3232815822729907, 0.934470181635086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 372}], {
             RGBColor[
             0.19768089456011895`, 0.32510553224827726`, 0.934569006551298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.6461513889555156, 0.7219924964871992, 0.9663950668318202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.44142989596913074`, 0.5543010784500094, 0.9500295993461311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 173}], {
             RGBColor[
             0.41329174036295263`, 0.5275007351562074, 0.948325579764125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 201}], {
             RGBColor[
             0.7465737093465549, 0.8011421937069441, 0.9641963866302764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 209}], {
             RGBColor[
             0.43947307837840166`, 0.5526061814054317, 0.9499049126595958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 323}], {
             RGBColor[
             0.4713973595467131, 0.580257389192397, 0.951939099626107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 346}], {
             RGBColor[
             0.44758503753245593`, 0.5596323527057516, 0.9504217995237683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 61}], {
             RGBColor[
             0.22477630942984533`, 0.3535845312248864, 0.9361120503440548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 68}], {
             RGBColor[
             0.2551071510734325, 0.38546416887872903`, 0.937839346905198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 118}], {
             RGBColor[
             0.23953466514577643`, 0.3690964988161278, 0.9369525168690463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 173}], {
             RGBColor[
             0.2613339339978391, 0.3920089125331203, 0.938193952981043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 176}], {
             RGBColor[
             0.2369284794639835, 0.36635723242284735`, 0.9368040984499744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 209}], {
             RGBColor[
             0.2875152720132881, 0.41711435878234465`, 0.9397732858765137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 344}], {
             RGBColor[
             0.21571874970997718`, 0.3440644616768498, 0.9355962357174672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 354}], {
             RGBColor[
             0.22802037271409625`, 0.35699424742212627`, 0.9362967949489314]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 388}], {
             RGBColor[
             0.2298511238520014, 0.358918482944391, 0.9364010535178815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 52}], {
             RGBColor[
             0.1835216269875808, 0.31022324428012404`, 0.9337626572098012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 62}], {
             RGBColor[
             0.19439182652115503`, 0.3216485132003679, 0.9343816989922191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.19292841019979173`, 0.32011036986066127`, 0.934298359597648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 127}], {
             RGBColor[
             0.19124100743417377`, 0.3183368025664821, 0.9342022645064347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[
             0.18838308614561955`, 0.31533294608953616`, 0.9340395101169672]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 133}], {
             RGBColor[
             0.18673252269027052`, 0.31359809924619686`, 0.933945512969975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 199}], {
             RGBColor[
             0.18708382947160418`, 0.313967344947515, 0.93396551937146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 216}], {
             RGBColor[
             0.19369425198474133`, 0.320915318133817, 0.9343419731543394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 231}], {
             RGBColor[
             0.1849354051777754, 0.31170921479673314`, 0.9338431697862355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 235}], {
             RGBColor[
             0.18959591922153213`, 0.31660771055037873`, 0.9341085791664148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 298}], {
             RGBColor[
             0.19233776426424887`, 0.31948956353329044`, 0.9342647231854012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 313}], {
             RGBColor[
             0.20302253470198556`, 0.3307199347169253, 0.9348732050551289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 361}], {
             RGBColor[
             0.2026569249479238, 0.33033565568440915`, 0.9348523841205063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 393}], {
             RGBColor[
             0.1855205539729795, 0.3123242432810691, 0.9338764931444723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 396}], {
             RGBColor[
             0.1936178582000953, 0.3208350234225083, 0.9343376226413184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.18052420551329257`, 0.307072764263149, 0.9335919584911282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 147}], {
             RGBColor[
             0.18125622821196816`, 0.30784216653237684`, 0.9336336461008872]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 164}], {
             RGBColor[
             0.18999442899880858`, 0.3170265695932755, 0.9341312737086882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 271}], {
             RGBColor[
             0.17906803055065768`, 0.3055422320505946, 0.933509031481224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 287}], {
             RGBColor[
             0.18448432655099875`, 0.31123510255995407`, 0.9338174815257515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 371}], {
             RGBColor[
             0.1827919087042476, 0.30945626409752947`, 0.9337211008330868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 391}], {
             RGBColor[
             0.18008156514952903`, 0.3066075211758136, 0.9335667507772396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 84}], {
             RGBColor[
             0.36020789306278994`, 0.48641570522103605`, 0.9441731063199956]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 102}], {
             RGBColor[
             0.32952467941339164`, 0.45694789679919157`, 0.9423238729229517]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 134}], {
             RGBColor[
             0.6062730746331866, 0.6864904388777064, 0.9646372348684907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 163}], {
             RGBColor[
             0.3241863421441664, 0.4513369658591039, 0.9420198625128315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 167}], {
             RGBColor[
             0.3459161722681373, 0.47403693499148125`, 0.9432624505086329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 174}], {
             RGBColor[
             0.3627872108908755, 0.4886497806834403, 0.9443374581712001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 183}], {
             RGBColor[
             0.36578243486715545`, 0.4912440931473596, 0.9445283111943961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 189}], {
             RGBColor[
             0.324110599148695, 0.45125735516848015`, 0.9420155490612911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 222}], {
             RGBColor[
             0.3069819930795281, 0.4332541041734357, 0.9410401002851541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 226}], {
             RGBColor[
             0.41340915500198794`, 0.532495964339595, 0.9475630436867326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 234}], {
             RGBColor[
             0.5836503518814267, 0.668728614845342, 0.9624059730547245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 238}], {
             RGBColor[
             0.3357800727610889, 0.463522711822467, 0.942680108320078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 246}], {
             RGBColor[
             0.6509116591793556, 0.7220840345127228, 0.9688949029118392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 269}], {
             RGBColor[
             0.5625797337470475, 0.652268087816136, 0.9603058507552114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 272}], {
             RGBColor[
             0.5612556230240568, 0.6512336824557214, 0.9601738757728618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 350}], {
             RGBColor[
             0.6877142166567092, 0.7483252059436304, 0.8485559789675121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 355}], {
             RGBColor[
             0.5736425498293158, 0.6609104438201203, 0.9614084888743977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 392}], {
             RGBColor[
             0.6863309387769014, 0.7477531849917098, 0.8714804732443268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 395}], {
             RGBColor[
             0.4251084428470847, 0.5422133005057554, 0.9484234537100807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 89}], {
             RGBColor[
             0.18430520538442102`, 0.31104683485694296`, 0.933807280840301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 128}], {
             RGBColor[
             0.18698858591777334`, 0.3138672379336487, 0.9339600953919696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 133}], {
             RGBColor[
             0.18257629412906723`, 0.3092296395082612, 0.9337088219020035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 199}], {
             RGBColor[
             0.1829276009104009, 0.30959888520957934`, 0.9337288283034887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 299}], {
             RGBColor[
             0.18351379325327066`, 0.3102150105286766, 0.9337622110902213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 342}], {
             RGBColor[
             0.18153992013799802`, 0.30814034473374124`, 0.9336498019363901]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 393}], {
             RGBColor[
             0.18136432541177624`, 0.30795578354313347`, 0.9336398020765009]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 58}], {
             RGBColor[
             0.20217788494718347`, 0.3298321542707407, 0.9348251035011402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 64}], {
             RGBColor[
             0.18652020523185484`, 0.31337494013569756`, 0.9339334218048136]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 117}], {
             RGBColor[
             0.20926903428907379`, 0.33728540183390365`, 0.9352289339657456]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 126}], {
             RGBColor[
             0.1894916420221746, 0.31649810860229766`, 0.9341026407341755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 289}], {
             RGBColor[
             0.18928237138329773`, 0.3162781518923132, 0.9340907230808797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 303}], {
             RGBColor[
             0.20281627238444755`, 0.3305031399434066, 0.9348614587212829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 376}], {
             RGBColor[
             0.20099948384788677`, 0.3285935800004348, 0.9347579953018235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 63}], {
             RGBColor[
             0.18289690010848875`, 0.3095666167202264, 0.9337270799382376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 66}], {
             RGBColor[
             0.19944158418676777`, 0.3269561286800552, 0.9346692752208288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 204}], {
             RGBColor[
             0.18912347164523904`, 0.31611113819278824`, 0.9340816739758684]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 224}], {
             RGBColor[
             0.18197335735342035`, 0.3085959147286568, 0.9336744855445955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 290}], {
             RGBColor[
             0.19141480754021284`, 0.3185194774974923, 0.9342121621653594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 297}], {
             RGBColor[
             0.19576644813648575`, 0.3230933276741248, 0.9344599816596418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 318}], {
             RGBColor[
             0.18950140793350456`, 0.31650837319430003`, 0.9341031968883784]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 345}], {
             RGBColor[
             0.1817997844893844, 0.30841347864339985`, 0.9336646008267666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 92}], {
             RGBColor[
             0.7345108890138425, 0.7594054710903482, 0.6489345144638174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 135}], {
             RGBColor[
             0.9832367917164733, 0.9536721882994657, 0.5121416630539384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 156}], {
             RGBColor[
             0.9013085960546312, 0.5775722343508322, 0.2607994456720959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.9341904345376686, 0.918237850236102, 0.6671537250527897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 221}], {
             RGBColor[
             0.9369698505827507, 0.7826274582869746, 0.292244768605455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 245}], {
             RGBColor[
             0.8952306902685789, 0.5308547871239369, 0.2549792362273595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 255}], {
             RGBColor[
             0.9034963603733146, 0.5943883495886708, 0.2628944512543936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 328}], {
             RGBColor[
             0.9205810406494127, 0.7082097000834948, 0.27856954387058575`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 386}], {
             RGBColor[
             0.8661959692237846, 0.8644995898414272, 0.6605413251423246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 400}], {
             RGBColor[
             0.9109049028745734, 0.6513336536973703, 0.2699888799203509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 59}], {
             RGBColor[
             0.3640812726856617, 0.4897706319686471, 0.9444199146444701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 90}], {
             RGBColor[
             0.4950145385889495, 0.5989681852897308, 0.9539261741459244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 121}], {
             RGBColor[
             0.3462782939569843, 0.4743505865975952, 0.9432855245824346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 122}], {
             RGBColor[
             0.48980661456960395`, 0.5947401579565226, 0.9535161872898672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 137}], {
             RGBColor[
             0.35805694536026106`, 0.48455266243088047`, 0.9440360498343989]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 166}], {
             RGBColor[
             0.6856726502293173, 0.7474973607293266, 0.8829926191709212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 169}], {
             RGBColor[
             0.6387195548301612, 0.7123648726900207, 0.967730862260616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 175}], {
             RGBColor[
             0.331650883280764, 0.45917597392142306`, 0.9424452023325764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 178}], {
             RGBColor[
             0.4116703274319593, 0.5309898792944511, 0.9474522471315552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 213}], {
             RGBColor[
             0.30213444608884904`, 0.4281523269825127, 0.9407642849001527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 274}], {
             RGBColor[
             0.43736444745775693`, 0.5521652442024196, 0.9493877477928349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 278}], {
             RGBColor[
             0.3199081459581343, 0.44683361246279085`, 0.9417764708138758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 296}], {
             RGBColor[
             0.313305483869233, 0.43989379597440015`, 0.9414004589756761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 319}], {
             RGBColor[
             0.4175060909791842, 0.5360433358043497, 0.9478244252272849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 352}], {
             RGBColor[
             0.31062641380180694`, 0.4370779234706822, 0.9412478898986653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 76}], {
             RGBColor[
             0.20578868678679324`, 0.33362733594223004`, 0.9350307333242034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.2782593236768137, 0.4070163756656283, 0.939259698655848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 102}], {
             RGBColor[
             0.24757611002741542`, 0.37754856724378383`, 0.937410465258804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 144}], {
             RGBColor[
             0.20411547873617336`, 0.33186868819351084`, 0.93493544660101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 163}], {
             RGBColor[
             0.24223777275819017`, 0.37193763630369614`, 0.9371064548486839]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 167}], {
             RGBColor[
             0.2639676028821611, 0.3946376054360735, 0.9383490428444853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 174}], {
             RGBColor[
             0.28083864150489934`, 0.40925045112803254`, 0.9394240505070525]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 186}], {
             RGBColor[
             0.21226621689950026`, 0.3404356307898151, 0.9353996190814751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 188}], {
             RGBColor[
             0.20973271485913975`, 0.33777275951208907`, 0.9352553398882568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 189}], {
             RGBColor[
             0.24216202976271878`, 0.3718580256130724, 0.9371021413971435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 222}], {
             RGBColor[
             0.22503342369355192`, 0.35385477461802795`, 0.9361266926210063]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 228}], {
             RGBColor[
             0.21063806848440092`, 0.33872434357497383`, 0.9353068984378649]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 238}], {
             RGBColor[
             0.2538315033751126, 0.3841233822670593, 0.9377667006559303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 333}], {
             RGBColor[
             0.2028967340448986, 0.3305877102501046, 0.9348660408938132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 368}], {
             RGBColor[
             0.20142644533340448`, 0.3290423435926357, 0.9347823101267909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 117}], {
             RGBColor[
             0.2190498578943207, 0.34756566758305235`, 0.9357859374006325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 289}], {
             RGBColor[
             0.19906319498854463`, 0.3265584176414619, 0.9346477265157667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 303}], {
             RGBColor[
             0.21259709598969448`, 0.3407834056925553, 0.9354184621561699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 376}], {
             RGBColor[
             0.2107803074531337, 0.33887384574958357`, 0.9353149987367104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 90}], {
             RGBColor[
             0.47744540309430256`, 0.5837506831746934, 0.9528066843679821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 121}], {
             RGBColor[
             0.3287091584623374, 0.4591330844825578, 0.9421660348044922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 122}], {
             RGBColor[
             0.472237479074957, 0.5795226558414852, 0.9523966975119249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 175}], {
             RGBColor[
             0.314081747786117, 0.4439584718063857, 0.9413257125546342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 178}], {
             RGBColor[
             0.3941011919373124, 0.5157723771794137, 0.9463327573536129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 213}], {
             RGBColor[
             0.2845653105942021, 0.4129348248674753, 0.9396447951222104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 274}], {
             RGBColor[
             0.41979531196311004`, 0.5369477420873823, 0.9482682580148925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 296}], {
             RGBColor[
             0.2957363483745861, 0.42467629385936273`, 0.9402809691977339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 319}], {
             RGBColor[
             0.3999369554845372, 0.5208258336893123, 0.9467049354493426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 373}], {
             RGBColor[
             0.3091816453180559, 0.4388081534280127, 0.9410466589681301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.18336573314646784`, 0.31005938996887394`, 0.9337537792861741]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 101}], {
             RGBColor[
             0.18455258152934814`, 0.31130684286981486`, 0.9338213685457943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.18529719032077357`, 0.3120894739205271, 0.933863772914916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 259}], {
             RGBColor[
             0.18612091931381164`, 0.3129552653196448, 0.9339106830624717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 331}], {
             RGBColor[
             0.19257622837931382`, 0.31974020443772183`, 0.9342783033639781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 335}], {
             RGBColor[
             0.18275395419094043`, 0.3094163714975885, 0.9337189393797027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 394}], {
             RGBColor[
             0.18321858514836378`, 0.3099047280931446, 0.933745399425368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 118}], {
             RGBColor[
             0.22412293343441853`, 0.3528977916272621, 0.9360748415476985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 130}], {
             RGBColor[
             0.19568837198846437`, 0.3230112646922406, 0.9344555353385153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 147}], {
             RGBColor[
             0.19642039468713995`, 0.32378066696146846`, 0.9344972229482744]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 164}], {
             RGBColor[
             0.2051585954739804, 0.3329650700223671, 0.9349948505560753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 173}], {
             RGBColor[
             0.24592220228648118`, 0.3758102053442546, 0.937316277659695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 176}], {
             RGBColor[
             0.2215167477526256, 0.3501585252339816, 0.9359264231286265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 344}], {
             RGBColor[
             0.20030701799861927`, 0.32786575448798405`, 0.9347185603961192]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 354}], {
             RGBColor[
             0.21260864100273835`, 0.3407955402332605, 0.9354191196275834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 371}], {
             RGBColor[
             0.19795607517941943`, 0.3253947645266211, 0.934584677680474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 388}], {
             RGBColor[
             0.2144393921406435, 0.3427197757555252, 0.9355233781965335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 87}], {
             RGBColor[
             0.1996423811721627, 0.3271671790429695, 0.9346807103120945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 119}], {
             RGBColor[
             0.1917608818844465, 0.31888322357566273`, 0.9342318705872924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 127}], {
             RGBColor[
             0.1979549784065447, 0.32539361174879033`, 0.9345846152208812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 129}], {
             RGBColor[
             0.19509705711799047`, 0.3223897552718444, 0.9344218608314138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 216}], {
             RGBColor[
             0.2004082229571123, 0.32797212731612524`, 0.934724323868786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 231}], {
             RGBColor[
             0.19164937615014635`, 0.31876602397904136`, 0.934225520500682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 235}], {
             RGBColor[
             0.1963098901939031, 0.32366451973268695`, 0.9344909298808612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 298}], {
             RGBColor[
             0.19905173523661984`, 0.32654637271559867`, 0.9346470738998478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 313}], {
             RGBColor[
             0.20973650567435648`, 0.3377767438992335, 0.9352555557695754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 317}], {
             RGBColor[
             0.19822991985182326`, 0.32568259264007254`, 0.9346002727294505]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 336}], {
             RGBColor[
             0.19072954463119351`, 0.31779922273193517`, 0.9341731374564464]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 361}], {
             RGBColor[
             0.20937089592029476`, 0.33739246486671737`, 0.9352347348349528]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 393}], {
             RGBColor[
             0.19223452494535048`, 0.31938105246337734`, 0.9342588438589188]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 396}], {
             RGBColor[
             0.20033182917246628`, 0.3278918326048165, 0.934719973355765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 98}], {
             RGBColor[
             0.19109841618892076`, 0.3181869301269141, 0.9341941441459625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 139}], {
             RGBColor[
             0.18462055320460163`, 0.31137828541015944`, 0.9338252394321449]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 204}], {
             RGBColor[
             0.18740799960939158`, 0.3143080683159034, 0.9339839803812403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 224}], {
             RGBColor[
             0.1802578853175729, 0.30679284485177194`, 0.9335767919499673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 290}], {
             RGBColor[
             0.18969933550436535`, 0.3167164076206075, 0.9341144685707314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 318}], {
             RGBColor[
             0.18778593589765713`, 0.3147053033174152, 0.9340055032937504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 345}], {
             RGBColor[
             0.18008431245353695`, 0.306610408766515, 0.9335669072321386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 77}], {
             RGBColor[
             0.18172630335562523`, 0.308336245312846, 0.9336604161849047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 94}], {
             RGBColor[
             0.1809149928406964, 0.30748350652159806`, 0.9336142132513059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 254}], {
             RGBColor[
             0.1839453796797469, 0.3106686352270631, 0.9337867892987342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 289}], {
             RGBColor[
             0.18340551527321602`, 0.3101012035064188, 0.9337560448194401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 68}], {
             RGBColor[
             0.2789862434779228, 0.41056260901775243`, 0.9391992258916821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 173}], {
             RGBColor[
             0.2852130264023293, 0.4171073526721437, 0.9395538319675272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 176}], {
             RGBColor[
             0.26080757186847375`, 0.39145567256187075`, 0.9381639774364586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 250}], {
             RGBColor[
             0.2731468584894696, 0.40442504515649597`, 0.9388666815551856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 363}], {
             RGBColor[
             0.25392355034044856`, 0.38422012946374207`, 0.9377719425944349]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 123}], {
             RGBColor[
             0.21298431371887483`, 0.3411903960769459, 0.9354405136330093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 131}], {
             RGBColor[
             0.2137636212718384, 0.34200949772606326`, 0.9354848940452685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 140}], {
             RGBColor[
             0.21998497488731555`, 0.3485485348325317, 0.9358391909300019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 203}], {
             RGBColor[
             0.2200139191384291, 0.3485789570756236, 0.9358408392622837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 232}], {
             RGBColor[
             0.25468181299552817`, 0.38501711159085983`, 0.9378151245308926]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 257}], {
             RGBColor[
             0.268687595913645, 0.3984105456780595, 0.9386613405898359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 275}], {
             RGBColor[
             0.22651056308563722`, 0.3554073417751564, 0.9362108135241538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 280}], {
             RGBColor[
             0.23290342941472336`, 0.362126649618162, 0.936574877804197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 297}], {
             RGBColor[
             0.21059566017891732`, 0.33867976975706876`, 0.935304483347605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 318}], {
             RGBColor[
             0.20433061997593613`, 0.33209481527724394`, 0.9349476985763416]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 322}], {
             RGBColor[
             0.2070879506142999, 0.33499294460302415`, 0.9351047244770914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 325}], {
             RGBColor[
             0.2517049597881912, 0.3818882501265539, 0.9376455971445944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 339}], {
             RGBColor[
             0.23290928668708955`, 0.3621328059827914, 0.9365752113671932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 113}], {
             RGBColor[
             0.36637406988619037`, 0.4916437040590915, 0.9445701410456664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 124}], {
             RGBColor[
             0.3674760832994186, 0.49271104629414053`, 0.9446362289748654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 194}], {
             RGBColor[
             0.709877099853931, 0.7667201163798876, 0.7972498678529694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 208}], {
             RGBColor[
             0.7091189037719949, 0.7670538844748609, 0.8568671364687419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 210}], {
             RGBColor[
             0.365438140563206, 0.4906599829992886, 0.9445168412553058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 249}], {
             RGBColor[
             0.36714946895537004`, 0.49242814936543994`, 0.9446154173976764]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 266}], {
             RGBColor[
             0.3289874356394012, 0.4523479810161943, 0.9424410275338806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 293}], {
             RGBColor[
             0.3870584168095417, 0.509672279343909, 0.9458839979501529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 316}], {
             RGBColor[
             0.32978816517065423`, 0.4531895985227258, 0.9424866278961124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 385}], {
             RGBColor[
             0.7098239251190117, 0.7666063809986858, 0.7914621261134387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 387}], {
             RGBColor[
             0.4796742864541198, 0.5876973628554791, 0.9523916433059518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 161}], {
             RGBColor[
             0.23474066997997348`, 0.36405770594001974`, 0.9366795059364341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 173}], {
             RGBColor[
             0.2762530439300684, 0.40768984299809713`, 0.9390435742208383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 176}], {
             RGBColor[
             0.2518475893962128, 0.38203816288782416`, 0.9376537196897696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 250}], {
             RGBColor[
             0.2641868760172087, 0.3950075354824494, 0.9383564238084967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 363}], {
             RGBColor[
             0.24496356786818765`, 0.3748026197896954, 0.9372616848477457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 106}], {
             RGBColor[
             0.23431749208343802`, 0.36361291913973265`, 0.936655406581262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 107}], {
             RGBColor[
             0.2952174792692931, 0.42393616514341426`, 0.9402585516481101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 150}], {
             RGBColor[
             0.217681081623926, 0.3461269969374395, 0.9357079876169566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 212}], {
             RGBColor[
             0.32957634955032006`, 0.4536960916538069, 0.9424478684800611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 270}], {
             RGBColor[
             0.300457761234542, 0.4284750339974831, 0.9405924577811364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 283}], {
             RGBColor[
             0.22539830685763262`, 0.3542382899584056, 0.9361474721774046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 294}], {
             RGBColor[
             0.2158880199071448, 0.3442423753864234, 0.935605875404783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 295}], {
             RGBColor[
             0.3354255676488553, 0.4587623903805083, 0.9428205754850394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 320}], {
             RGBColor[
             0.21880446674278364`, 0.34730774592408925`, 0.9357719627375762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 347}], {
             RGBColor[
             0.21983376516516337`, 0.34838960382729967`, 0.9358305797600202]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 373}], {
             RGBColor[
             0.25683371538447886`, 0.38727889744013877`, 0.937937672188489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 380}], {
             RGBColor[
             0.2309702581422837, 0.36009476404068996`, 0.9364647865601021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 381}], {
             RGBColor[
             0.21898984745913425`, 0.34750259281079, 0.9357825198951262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 390}], {
             RGBColor[
             0.2522635992417797, 0.3824754156120626, 0.9376774108350432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 108}], {
             RGBColor[
             0.2395346657598989, 0.3690964994616095, 0.9369525169040198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 152}], {
             RGBColor[
             0.2398425593336916, 0.3694201151292457, 0.9369700509875596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 154}], {
             RGBColor[
             0.21421417432422896`, 0.3424830575508392, 0.9355105523750686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 180}], {
             RGBColor[
             0.24072957206270523`, 0.3703524217472943, 0.9370205650502591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 198}], {
             RGBColor[
             0.2881120186842996, 0.4160342955793074, 0.9398697816662858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 236}], {
             RGBColor[
             0.23684558512377027`, 0.36627010521547854`, 0.9367993777399305]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 262}], {
             RGBColor[
             0.2185336488556363, 0.3470230991538516, 0.9357565400595423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 267}], {
             RGBColor[
             0.23945129119348169`, 0.3690088675060522, 0.9369477688458039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 284}], {
             RGBColor[
             0.24975725951810934`, 0.3798410936513683, 0.9375346784955776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 286}], {
             RGBColor[
             0.20888058953085603`, 0.33687712176419665`, 0.9352068126114177]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 332}], {
             RGBColor[
             0.22563024765380635`, 0.35448207444108004`, 0.936160680862621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 72}], {
             RGBColor[
             0.18087056047954858`, 0.30743680529285733`, 0.9336116828940703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 88}], {
             RGBColor[
             0.1851982028892632, 0.3119854318538441, 0.9338581357271303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 138}], {
             RGBColor[
             0.18058969715831197`, 0.30714160013447456`, 0.9335956881434259]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 157}], {
             RGBColor[
             0.18316059011768585`, 0.3098437716388048, 0.933742096694167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 365}], {
             RGBColor[
             0.17992874679989868`, 0.30644689940110903`, 0.9335580479983027]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 88}], {
             RGBColor[
             0.18714176336881175`, 0.31402823714670136`, 0.9339688186212005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 109}], {
             RGBColor[
             0.18206833162796426`, 0.3086957387129193, 0.933679894189029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 157}], {
             RGBColor[
             0.1851041505972344, 0.3118865769316621, 0.9338527795882372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 181}], {
             RGBColor[
             0.1888688995598306, 0.3158435667902215, 0.9340671764722099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 191}], {
             RGBColor[
             0.19501894918374685`, 0.32230765888062524`, 0.934417412700109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 365}], {
             RGBColor[
             0.18187230727944725`, 0.30848970469396636`, 0.9336687308923729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 370}], {
             RGBColor[
             0.18495091945082137`, 0.31172552128136616`, 0.9338440533011341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 78}], {
             RGBColor[
             0.8752764478324426, 0.45843721309521324`, 0.21487760657063304`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 99}], {
             RGBColor[
             0.9481261161147958, 0.8682562660194123, 0.6030407890629428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 104}], {
             RGBColor[
             0.874812220102593, 0.4548689553377009, 0.21443306157225883`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 112}], {
             RGBColor[
             0.9338615942560703, 0.7754902910821886, 0.2656416901517646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 141}], {
             RGBColor[
             0.898106425922933, 0.622605752165564, 0.23629664332441563`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 172}], {
             RGBColor[
             0.8772092716527284, 0.4732937439467283, 0.21672848084375096`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 177}], {
             RGBColor[
             0.912733918365472, 0.8408075046276462, 0.6264313427993702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 208}], {
             RGBColor[
             0.9618152962983195, 0.8769997675618114, 0.5142240753361885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 225}], {
             RGBColor[
             0.9076627958063523, 0.836763929150959, 0.6259476546026368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 240}], {
             RGBColor[
             0.8811521202900017, 0.5036002063401005, 0.22050415715161448`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 243}], {
             RGBColor[
             0.9500707567190481, 0.8697065757980069, 0.5997490197634427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 285}], {
             RGBColor[
             0.9624071777351879, 0.8763102692580285, 0.43650448397981056`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 337}], {
             RGBColor[
             0.9623310682876794, 0.8761474788456531, 0.428220440311572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 399}], {
             RGBColor[
             0.9285956897332439, 0.7546127344078406, 0.2614046197660328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 86}], {
             RGBColor[
             0.6370413534700665, 0.7120367862892685, 0.9671058051428245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 91}], {
             RGBColor[
             0.6781789401773193, 0.7465825501677249, 0.9700269954109155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 95}], {
             RGBColor[
             0.7112349833542422, 0.7734189351765257, 0.9726292882180788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 104}], {
             RGBColor[
             0.8410345872048564, 0.5203813503819814, 0.5763185480059819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 112}], {
             RGBColor[
             0.9000839613583336, 0.841002686126469, 0.6275271765854877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 141}], {
             RGBColor[
             0.8643287930251963, 0.6881181472098445, 0.5981821297581387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 148}], {
             RGBColor[
             0.5985191344063026, 0.6786707763192633, 0.9646512034079422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 172}], {
             RGBColor[
             0.8434316387549917, 0.5388061389910088, 0.578613967277474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 179}], {
             RGBColor[
             0.6585040630153561, 0.7306095985445278, 0.968478117009276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 240}], {
             RGBColor[
             0.8473744873922651, 0.569112601384381, 0.5823896435853375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 263}], {
             RGBColor[
             0.627506347078178, 0.7037780429959705, 0.9664982429670084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 279}], {
             RGBColor[
             0.7676471267223055, 0.8187592045069678, 0.9773831565887533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 285}], {
             RGBColor[
             0.9286295448374513, 0.9418226643023089, 0.7983899704135337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 399}], {
             RGBColor[
             0.8948180568355072, 0.820125129452121, 0.6232901061997559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 105}], {
             RGBColor[
             0.21372122175088312`, 0.34196493314125437`, 0.9354824794552745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 132}], {
             RGBColor[
             0.28812004710636396`, 0.4155836677571048, 0.9398870475355221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 202}], {
             RGBColor[
             0.23066301686818202`, 0.3597718339813871, 0.9364472896240648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 215}], {
             RGBColor[
             0.20048155521420025`, 0.3280492041678583, 0.9347285000323418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 218}], {
             RGBColor[
             0.20441362479812614`, 0.3321820586081753, 0.9349524255781707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 229}], {
             RGBColor[
             0.21242485108253378`, 0.34060236537417143`, 0.9354086530635206]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 260}], {
             RGBColor[
             0.22127423884363956`, 0.34990363299468435`, 0.9359126126050195]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 329}], {
             RGBColor[
             0.20420501368883298`, 0.3319627951056, 0.934940545484109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 341}], {
             RGBColor[
             0.2771008643732843, 0.406039405513939, 0.9391849149556509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 349}], {
             RGBColor[
             0.2099761655665867, 0.3380286416412822, 0.935269204045893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 77}], {
             RGBColor[
             0.1883529029244576, 0.3153012216103682, 0.9340377912271741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 103}], {
             RGBColor[
             0.19412197120965846`, 0.32136487815817005`, 0.9343663311314445]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 144}], {
             RGBColor[
             0.19222334020881804`, 0.31936929659612845`, 0.9342582069047196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 145}], {
             RGBColor[
             0.19557703724460856`, 0.3228942448174177, 0.9344491949895577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 200}], {
             RGBColor[
             0.1890554468047247, 0.31603963977238364`, 0.9340778000618348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 207}], {
             RGBColor[
             0.1908268877624048, 0.3179015365347492, 0.9341786810037627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 222}], {
             RGBColor[
             0.21314128516619657`, 0.3413553830206456, 0.9354494529247159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 333}], {
             RGBColor[
             0.19100459551754329`, 0.3180883186527222, 0.9341888011975227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 368}], {
             RGBColor[
             0.18953430680604916`, 0.3165429519952533, 0.9341050704305003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 94}], {
             RGBColor[
             0.18199794707454847`, 0.3086217600846408, 0.9336758858928365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 103}], {
             RGBColor[
             0.18857832587467818`, 0.31553815542369057`, 0.9340506287307058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 145}], {
             RGBColor[
             0.19003339190962826`, 0.3170675220829382, 0.934133492588819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 200}], {
             RGBColor[
             0.1835118014697444, 0.3102129170379042, 0.9337620976610961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 207}], {
             RGBColor[
             0.18528324242742453`, 0.31207481380026975`, 0.9338629786030239]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 254}], {
             RGBColor[
             0.18502833391359902`, 0.3118068887901059, 0.9338484619402648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 333}], {
             RGBColor[
             0.18546095018256298`, 0.31226159591824276`, 0.9338730987967839]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 104}], {
             RGBColor[
             0.819473350823259, 0.1506862844701191, 0.16628100878134408`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 172}], {
             RGBColor[
             0.8218704023733945, 0.1691110730791465, 0.16857642805283624`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 194}], {
             RGBColor[
             0.9072346231009216, 0.5724833285992563, 0.40645475392950137`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 208}], {
             RGBColor[
             0.9064764270189856, 0.5728170966942296, 0.4660720225452738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 217}], {
             RGBColor[
             0.9065035834313075, 0.5709197086654001, 0.3268855973458845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 230}], {
             RGBColor[
             0.818837947598831, 0.14580229685169685`, 0.1656725459360465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 233}], {
             RGBColor[
             0.8896719661372465, 0.5617502239079055, 0.560162093898772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 240}], {
             RGBColor[
             0.8258132510106677, 0.19941753547251867`, 0.17235210436069973`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 242}], {
             RGBColor[
             0.8361055023873913, 0.2785282896473279, 0.1822079759024856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 244}], {
             RGBColor[
             0.8873515007123038, 0.5600196245933966, 0.5640900365888891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 264}], {
             RGBColor[
             0.7716146222869605, 0.4690073780170669, 0.569890082784954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 285}], {
             RGBColor[
             0.907068308455854, 0.5721275983904466, 0.38835243118889584`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 357}], {
             RGBColor[
             0.8385190338854094, 0.29707975035734024`, 0.18451917639068158`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 385}], {
             RGBColor[
             0.9071814483660026, 0.5723695932180546, 0.4006670121899707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 100}], {
             RGBColor[
             0.22059571881103596`, 0.3491904654197632, 0.9358739718929432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 137}], {
             RGBColor[
             0.2827537056275888, 0.4121446936308188, 0.939500838618308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 175}], {
             RGBColor[
             0.2563476435480917, 0.3867680051213614, 0.9379099911164857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 213}], {
             RGBColor[
             0.22683120635617676`, 0.355744358182451, 0.9362290736840618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 227}], {
             RGBColor[
             0.21925675873838124`, 0.34778313348843115`, 0.9357977200976195]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[
             0.21942962029019444`, 0.3479648219394422, 0.9358075643072694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 278}], {
             RGBColor[
             0.24460490622546205`, 0.37442564366272924`, 0.937241259597785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 302}], {
             RGBColor[
             0.21120952198211004`, 0.3393249774333106, 0.9353394418691697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 314}], {
             RGBColor[
             0.23185910927542647`, 0.36102900293803986`, 0.9365154053171973]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 352}], {
             RGBColor[
             0.23532317406913467`, 0.3646699546706205, 0.9367126786825744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 379}], {
             RGBColor[
             0.21907288200889707`, 0.34758986738728526`, 0.9357872485898966]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 151}], {
             RGBColor[
             0.18591365690063838`, 0.3127374193822037, 0.9338988797746588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 168}], {
             RGBColor[
             0.18200651498987047`, 0.3086307655068815, 0.933676373822939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 265}], {
             RGBColor[
             0.18489536415726843`, 0.31166712914543293`, 0.933840889509353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 304}], {
             RGBColor[
             0.18034926344630414`, 0.30688888905877654`, 0.9335819957992169]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 378}], {
             RGBColor[
             0.18531329630253898`, 0.3121064023285408, 0.9338646901267509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 192}], {
             RGBColor[
             0.1805894919591846, 0.3071413844571813, 0.9335956764576392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 271}], {
             RGBColor[
             0.1793288256722832, 0.3058163442587888, 0.9335238833775887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 287}], {
             RGBColor[
             0.1847451216726243, 0.31150921476814825`, 0.9338323334221164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 292}], {
             RGBColor[
             0.18697166352319156`, 0.31384945142400145`, 0.9339591316866327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 374}], {
             RGBColor[
             0.1848884604275577, 0.3116598728877852, 0.9338404963521592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 382}], {
             RGBColor[
             0.18072466475425025`, 0.3072834596352455, 0.9336033743483478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 384}], {
             RGBColor[
             0.18455785037421688`, 0.3113123807598359, 0.9338216685987151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 101}], {
             RGBColor[
             0.181913405203708, 0.30853290121812327`, 0.9336710713583607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 136}], {
             RGBColor[
             0.18265801399513343`, 0.30931553226883557`, 0.9337134757274823]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 259}], {
             RGBColor[
             0.1834817429881715, 0.31018132366795326`, 0.9337603858750381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 331}], {
             RGBColor[
             0.18993705205367367`, 0.31696626278603024`, 0.9341280061765445]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 335}], {
             RGBColor[
             0.18011477786530028`, 0.30664242984589696`, 0.933568642192269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 120}], {
             RGBColor[
             0.7316668327109251, 0.7891725193318362, 0.9665740024152043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 187}], {
             RGBColor[
             0.6899774075909928, 0.7548276258988081, 0.9634300825559947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 206}], {
             RGBColor[
             0.8376738526720509, 0.8738864473115988, 0.9758404514260404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 217}], {
             RGBColor[
             0.9690520396764782, 0.9730561345189551, 0.7324860448307533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 220}], {
             RGBColor[
             0.790428504618827, 0.8368778917698232, 0.9711999364788909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 230}], {
             RGBColor[
             0.8813864038440016, 0.5479387227052518, 0.5712729934209153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 244}], {
             RGBColor[
             0.9498999569574745, 0.9621560504469515, 0.9696904840737579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 245}], {
             RGBColor[
             0.8819322732807819, 0.5521345143978579, 0.5717957186100475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 321}], {
             RGBColor[
             0.7496980165524652, 0.8038110466699736, 0.967993483257613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 328}], {
             RGBColor[
             0.9072826236616158, 0.729489427357416, 0.5953860262532737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 364}], {
             RGBColor[
             0.8813558056455749, 0.5477035315439278, 0.5712436925515461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 102}], {
             RGBColor[
             0.3081546083900806, 0.43843821536979977`, 0.9409621908941581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 163}], {
             RGBColor[
             0.3028162711208553, 0.4328272844297121, 0.940658180484038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 167}], {
             RGBColor[
             0.32454610124482625`, 0.4555272535620894, 0.9419007684798394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 174}], {
             RGBColor[
             0.3414171398675645, 0.4701400992540484, 0.9429757761424066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 183}], {
             RGBColor[
             0.3444123638438444, 0.47273441171796776`, 0.9431666291656026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 189}], {
             RGBColor[
             0.30274052812538393`, 0.4327476737390883, 0.9406538670324976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 222}], {
             RGBColor[
             0.2856119220562171, 0.4147444227440439, 0.9396784182563604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 226}], {
             RGBColor[
             0.39203908397867687`, 0.5139862829102032, 0.9462013616579391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 234}], {
             RGBColor[
             0.5622802808581155, 0.6502189334159502, 0.961044291025931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 238}], {
             RGBColor[
             0.3144100017377778, 0.44501303039307516`, 0.9413184262912844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 246}], {
             RGBColor[
             0.6295415881560444, 0.703574353083331, 0.9675332208830456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 269}], {
             RGBColor[
             0.5412096627237364, 0.6337584063867442, 0.9589441687264177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 272}], {
             RGBColor[
             0.5398855520007457, 0.6327240010263296, 0.9588121937440683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 395}], {
             RGBColor[
             0.4037383718237736, 0.5237036190763635, 0.9470617716812872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 88}], {
             RGBColor[
             0.21610734049788477`, 0.34447289523301966`, 0.9356183653879699]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 162}], {
             RGBColor[
             0.2565370723370653, 0.38696710678905155`, 0.9379207788057828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 181}], {
             RGBColor[
             0.2178344766889036, 0.34628822487653976`, 0.9357167232389794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 191}], {
             RGBColor[
             0.22398452631281984`, 0.35275231696694354`, 0.9360669594668783]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 211}], {
             RGBColor[
             0.231317411938528, 0.36045964469136466`, 0.9364845564552302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 214}], {
             RGBColor[
             0.2402451657445982, 0.3698432799938294, 0.9369929788270578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 263}], {
             RGBColor[
             0.31634895902864796`, 0.44214016934946804`, 0.941608656513351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 307}], {
             RGBColor[
             0.294549891018896, 0.4232589122924366, 0.9402196391759287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 312}], {
             RGBColor[
             0.27182714160879756`, 0.40303793904002655`, 0.9387915256311776]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 340}], {
             RGBColor[
             0.22184000451345684`, 0.35049828858527765`, 0.9359448321229403]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 348}], {
             RGBColor[
             0.28694246093137055`, 0.4166697387111759, 0.9397349004577378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 91}], {
             RGBColor[
             0.45216024233108254`, 0.5649746624056373, 0.950332168324746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 93}], {
             RGBColor[
             0.32267144519324537`, 0.4470223501983363, 0.9420332704147207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 95}], {
             RGBColor[
             0.48521628550800544`, 0.5918110474144382, 0.9529344611319093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 125}], {
             RGBColor[
             0.3362672755569396, 0.46131242993601224`, 0.9428075328407044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 148}], {
             RGBColor[
             0.37250043656006593`, 0.49706288855717573`, 0.9449563763217728]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 162}], {
             RGBColor[
             0.3416757625403587, 0.46699709267346645`, 0.9431155381732708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 179}], {
             RGBColor[
             0.4324853651691194, 0.5490017107824403, 0.9487832899231066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 214}], {
             RGBColor[
             0.32538385594789154`, 0.4498732658782442, 0.9421877381945456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 263}], {
             RGBColor[
             0.4014876492319413, 0.5221701552338829, 0.9468034158808389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 264}], {
             RGBColor[
             0.5671571608223211, 0.6570945561668415, 0.9602327949234224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 285}], {
             RGBColor[
             0.7026108469912147, 0.7602147765402214, 0.7786951433273641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 119}], {
             RGBColor[
             0.19029746556308325`, 0.3173450802359561, 0.9341485311927212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 127}], {
             RGBColor[
             0.19649156208518143`, 0.3238554684090837, 0.93450127582631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 129}], {
             RGBColor[
             0.1936336407966272, 0.32085161193213774`, 0.9343385214368426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 216}], {
             RGBColor[
             0.198944806635749, 0.32643398397641854`, 0.9346409844742148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 231}], {
             RGBColor[
             0.19018595982878306`, 0.3172278806393347, 0.9341421811061108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 235}], {
             RGBColor[
             0.1948464738725398, 0.3221263763929803, 0.9344075904862901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 298}], {
             RGBColor[
             0.19758831891525655`, 0.325008229375892, 0.9345637345052766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 313}], {
             RGBColor[
             0.2082730893529932, 0.33623860055952687`, 0.9351722163750043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 317}], {
             RGBColor[
             0.19676650353045996`, 0.3241444493003659, 0.9345169333348793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 361}], {
             RGBColor[
             0.20790747959893147`, 0.33585432152701067`, 0.9351513954403816]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 393}], {
             RGBColor[
             0.1907711086239872, 0.3178429091236707, 0.9341755044643476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 396}], {
             RGBColor[
             0.198868412851103, 0.3263536892651099, 0.9346366339611938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 109}], {
             RGBColor[
             0.18639597403767888`, 0.31324436527390603`, 0.9339263470220889]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 157}], {
             RGBColor[
             0.189431793006949, 0.31643520349264886`, 0.9340992324212971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 181}], {
             RGBColor[
             0.19319654196954522`, 0.3203921933512083, 0.9343136293052701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 191}], {
             RGBColor[
             0.19934659159346146`, 0.326856285441612, 0.9346638655331689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 365}], {
             RGBColor[
             0.18619994968916187`, 0.3130383312549531, 0.9339151837254329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 370}], {
             RGBColor[
             0.189278561860536, 0.3162741478423529, 0.9340905061341941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 128}], {
             RGBColor[
             0.1919283928758168, 0.31905928824840313`, 0.9342414100904406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 133}], {
             RGBColor[
             0.1875161010871107, 0.31442168982301577`, 0.9339901366004746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 155}], {
             RGBColor[
             0.19816316122321598`, 0.3256124250886648, 0.9345964709243118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 170}], {
             RGBColor[
             0.21045471282523004`, 0.33853162515176505`, 0.9352964566043255]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 171}], {
             RGBColor[
             0.18910388505940673`, 0.3160905514492172, 0.934080558548781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 199}], {
             RGBColor[
             0.18786740786844439`, 0.3147909355243339, 0.9340101430019597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 299}], {
             RGBColor[
             0.18845360021131413`, 0.3154070608434312, 0.9340435257886923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 306}], {
             RGBColor[
             0.1959786892882613, 0.3233164065815071, 0.9344720684792528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 342}], {
             RGBColor[
             0.18647972709604152`, 0.31333239504849575`, 0.9339311166348612]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 353}], {
             RGBColor[
             0.18963294311823536`, 0.31664662501326446`, 0.93411068762256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 121}], {
             RGBColor[
             0.4596424243656251, 0.5683306378036415, 0.9516722943059467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 122}], {
             RGBColor[
             0.6031707449782447, 0.6887202091625689, 0.9619029570133792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 166}], {
             RGBColor[
             0.7990367806379581, 0.841477411935373, 0.8913793888944332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 178}], {
             RGBColor[
             0.5250344578406001, 0.6249699305004974, 0.9558390168550672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 190}], {
             RGBColor[
             0.7822989919455827, 0.8299086268722369, 0.9606532016549456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 212}], {
             RGBColor[
             0.5128575453871849, 0.6144229009627645, 0.9550631147611566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 221}], {
             RGBColor[
             0.755343522572024, 0.6711176068414135, 0.6012544985481333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 268}], {
             RGBColor[
             0.6438707815800897, 0.7211954799278018, 0.9654945731092558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 274}], {
             RGBColor[
             0.5507285778663977, 0.6461452954084659, 0.9577745175163469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 295}], {
             RGBColor[
             0.5187067634857201, 0.6194891996894659, 0.9554358217661347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 319}], {
             RGBColor[
             0.530870221387825, 0.6300233870103961, 0.956211194950797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 324}], {
             RGBColor[
             0.6207541500572831, 0.7029952095291041, 0.9632871870713362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 351}], {
             RGBColor[
             0.7590840463718008, 0.8119268218437792, 0.9767853326782896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 373}], {
             RGBColor[
             0.44011491122134366`, 0.5480057067490964, 0.9505529184695845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 95}], {
             RGBColor[
             0.5263538722152581, 0.6263568112928946, 0.9558556514000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 112}], {
             RGBColor[
             0.7152028502193496, 0.6939405622428378, 0.6107535397674092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 125}], {
             RGBColor[
             0.37740486226419223`, 0.49585819381446866`, 0.9457287231087954]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 148}], {
             RGBColor[
             0.4136380232673186, 0.5316086524356322, 0.9478775665898638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 179}], {
             RGBColor[
             0.47362295187637204`, 0.5835474746608966, 0.9517044801911976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 257}], {
             RGBColor[
             0.408201112318213, 0.5268994734386068, 0.9475311314318583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 263}], {
             RGBColor[
             0.44262523593919395`, 0.5567159191123393, 0.94972460614893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 279}], {
             RGBColor[
             0.5827660155833214, 0.6716970806233367, 0.9606095197706748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 285}], {
             RGBColor[
             0.7437484336984672, 0.7947605404186777, 0.7816163335954551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 288}], {
             RGBColor[
             0.3993345066316525, 0.518907640464429, 0.9469775839135208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 135}], {
             RGBColor[
             0.746116355711272, 0.7971097200029147, 0.816782693533676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 165}], {
             RGBColor[
             0.6970699985324673, 0.761675381939551, 0.9717947555325273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 182}], {
             RGBColor[
             0.4229610876060558, 0.5395726978389508, 0.9485023279906137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 256}], {
             RGBColor[
             0.42434961842059, 0.5407753734409124, 0.9485908039462863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 281}], {
             RGBColor[
             0.46303919301965735`, 0.5742863383640635, 0.9510560694278913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 311}], {
             RGBColor[
             0.40006723340595274`, 0.5191882673765618, 0.947063870354397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 386}], {
             RGBColor[
             0.6290755332185833, 0.7079371215448762, 0.9651823556220622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 98}], {
             RGBColor[
             0.21766781953393055`, 0.3461130576399892, 0.9357072323605509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 125}], {
             RGBColor[
             0.24791606512635506`, 0.37790588160716765`, 0.9374298251987702]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 148}], {
             RGBColor[
             0.2841492261294814, 0.41365634022833114`, 0.9395786686798384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 162}], {
             RGBColor[
             0.2533245521097741, 0.3835905443446218, 0.9377378305313364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 214}], {
             RGBColor[
             0.23703264551730702`, 0.36646671754939963`, 0.9368100305526114]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 248}], {
             RGBColor[
             0.22615954726936105`, 0.355038401896562, 0.9361908236926982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 276}], {
             RGBColor[
             0.22858867995178067`, 0.3575915743616926, 0.9363291592053822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 288}], {
             RGBColor[
             0.2698457094938153, 0.4009553282571281, 0.9386786860034955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 290}], {
             RGBColor[
             0.21626873884937514`, 0.3446425351336826, 0.9356275567853198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 103}], {
             RGBColor[
             0.18776701535974932`, 0.31468541663244265`, 0.934004425797107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 145}], {
             RGBColor[
             0.18922208139469943`, 0.31621478329169034`, 0.9340872896552201]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 207}], {
             RGBColor[
             0.18447193191249567`, 0.3112220750090219, 0.933816775669425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 254}], {
             RGBColor[
             0.18421702339867016`, 0.31095414999885795`, 0.9338022590066659]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 125}], {
             RGBColor[
             0.41046090544111513`, 0.5226945788232695, 0.9483310159159588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 162}], {
             RGBColor[
             0.41586939242453425`, 0.5283792415607237, 0.9486390212485251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 233}], {
             RGBColor[
             0.7594081345567827, 0.8112195509449376, 0.9560282891124947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 263}], {
             RGBColor[
             0.47568127911611685`, 0.5835523041211401, 0.9523268989560933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 264}], {
             RGBColor[
             0.6413507907064967, 0.7184767050540989, 0.9657562779986768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 285}], {
             RGBColor[
             0.7768044768753901, 0.8215969254274786, 0.7842186264026185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 312}], {
             RGBColor[
             0.43115946169626646`, 0.5444500738116986, 0.9495097680739197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 173}], {
             RGBColor[
             0.515339475447038, 0.6087263479834802, 0.9574676673643785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 201}], {
             RGBColor[
             0.8486214444306401, 0.8823678065342169, 0.9733384742305298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 209}], {
             RGBColor[
             0.5415208134624869, 0.6338317942327045, 0.9590470002598491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 223}], {
             RGBColor[
             0.8390506368021915, 0.7815052608012159, 0.618996491222558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 245}], {
             RGBColor[
             0.7835145897788575, 0.47447987208772324`, 0.5706010714513564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 323}], {
             RGBColor[
             0.5734450946307983, 0.6614830020196698, 0.9610811872263605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 109}], {
             RGBColor[
             0.18710606140703578`, 0.3139907121212397, 0.9339667854472937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 181}], {
             RGBColor[
             0.19390662933890207`, 0.32113854019854193`, 0.9343540677304747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 191}], {
             RGBColor[
             0.2000566789628183, 0.32760263228894565`, 0.9347043039583738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 193}], {
             RGBColor[
             0.1899172543843397, 0.31694545418031556`, 0.9341268787285638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 211}], {
             RGBColor[
             0.20738956458852648`, 0.33530996001336677`, 0.9351219009467256]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 214}], {
             RGBColor[
             0.21631731839459667`, 0.3446935953158315, 0.9356303233185532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 248}], {
             RGBColor[
             0.2054442201466507, 0.3332652796629938, 0.9350111164586401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 305}], {
             RGBColor[
             0.18756138502713113`, 0.3144692861151448, 0.9339927154538672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 334}], {
             RGBColor[
             0.1889352663956901, 0.3159133225426103, 0.9340709559653313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 340}], {
             RGBColor[
             0.1979121571634553, 0.3253486039072797, 0.9345821766144358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 360}], {
             RGBColor[
             0.189069412661027, 0.31605431877284385`, 0.9340785953966906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 370}], {
             RGBColor[
             0.18998864922989284`, 0.31702049468968657`, 0.9341309445593988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 125}], {
             RGBColor[
             0.23126364989762477`, 0.3604031373776651, 0.9364814947865346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 139}], {
             RGBColor[
             0.19453754132088114`, 0.32180166869373195`, 0.9343899972344978]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 193}], {
             RGBColor[
             0.1939801662783198, 0.32121583218438116`, 0.9343582555503864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 204}], {
             RGBColor[
             0.19732498772567109`, 0.3247314515994759, 0.9345487381835933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 248}], {
             RGBColor[
             0.2095071320406308, 0.3375356576670594, 0.9352424932804627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 276}], {
             RGBColor[
             0.21193626472305038`, 0.34008883013219005`, 0.9353808287931467]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 290}], {
             RGBColor[
             0.19961632362064485`, 0.32713979090418005`, 0.9346792263730843]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 318}], {
             RGBColor[
             0.1977029240139366, 0.3251286866009877, 0.9345702610961033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 141}], {
             RGBColor[
             0.9156172249259522, 0.7282421342221813, 0.5763077730258106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 169}], {
             RGBColor[
             0.9307128082989145, 0.9468171296861931, 0.9664871194315787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 177}], {
             RGBColor[
             0.9302447173684912, 0.9464438866842635, 0.9664424725007652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 197}], {
             RGBColor[
             0.9649742133445314, 0.9733984061785892, 0.9441737000062027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 225}], {
             RGBColor[
             0.9251735948093716, 0.9424003112075763, 0.9659587843040318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 243}], {
             RGBColor[
             0.9675815557220673, 0.9753429578546242, 0.9397601494648378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 252}], {
             RGBColor[
             0.6676015641481373, 0.7342070299092066, 0.9439106644834332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 300}], {
             RGBColor[
             0.9401681906865148, 0.9543565949425481, 0.9673889822446275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 337}], {
             RGBColor[
             0.9798418672906987, 0.9817838609022704, 0.7682315700129669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 367}], {
             RGBColor[
             0.6703595369678017, 0.7365958473458555, 0.9440864000727226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 398}], {
             RGBColor[
             0.695865579228825, 0.7586878991813948, 0.9457116225314874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 146}], {
             RGBColor[
             0.1981449486568544, 0.3255932825266753, 0.9345954337456006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 175}], {
             RGBColor[
             0.2458994336441635, 0.3757862740575634, 0.9373149810191983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 213}], {
             RGBColor[
             0.21638299645224862`, 0.344762627118653, 0.9356340635867745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 227}], {
             RGBColor[
             0.20880854883445307`, 0.33680140242463313`, 0.9352027100003322]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 278}], {
             RGBColor[
             0.23415669632153385`, 0.3634439125989312, 0.9366462495004977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 302}], {
             RGBColor[
             0.20076131207818187`, 0.3283432463695126, 0.9347444317718824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 314}], {
             RGBColor[
             0.22141089937149833`, 0.35004727187424184`, 0.93592039521991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 352}], {
             RGBColor[
             0.2248749641652065, 0.3536882236068225, 0.936117668585287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 377}], {
             RGBColor[
             0.19744186238260558`, 0.3248542942741953, 0.9345553940224051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 136}], {
             RGBColor[
             0.18384486237801373`, 0.31056298516977654`, 0.9337810649871026]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 301}], {
             RGBColor[
             0.1828984857165501, 0.3095682832948322, 0.9337271702362709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 335}], {
             RGBColor[
             0.18130162624818058`, 0.3078898827468379, 0.9336362314518891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 394}], {
             RGBColor[
             0.18176625720560394`, 0.308378239342394, 0.9336626914975545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 163}], {
             RGBColor[
             0.272133057471457, 0.4033594760078676, 0.938808947086994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 167}], {
             RGBColor[
             0.29386288759542795`, 0.42605944514024496`, 0.9400515350827954]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 174}], {
             RGBColor[
             0.3107339262181662, 0.44067229083220405`, 0.9411265427453626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 189}], {
             RGBColor[
             0.27205731447598563`, 0.4032798653172439, 0.9388046336354536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 222}], {
             RGBColor[
             0.2549287084068188, 0.3852766143221994, 0.9378291848593165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 226}], {
             RGBColor[
             0.3613558703292786, 0.48451847448835883`, 0.9443521282608951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 395}], {
             RGBColor[
             0.3730551581743753, 0.49423581065451916`, 0.9452125382842432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 145}], {
             RGBColor[
             0.1958024601948291, 0.32313117863074003`, 0.9344620324930895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 200}], {
             RGBColor[
             0.18928086975494526`, 0.31627657358570604`, 0.9340906375653665]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 207}], {
             RGBColor[
             0.19105231071262538`, 0.3181384703480716, 0.9341915185072943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 222}], {
             RGBColor[
             0.21336670811641717`, 0.34159231683396796`, 0.9354622904282476]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 254}], {
             RGBColor[
             0.19079740219879987`, 0.3178705453379077, 0.9341770018445352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 333}], {
             RGBColor[
             0.19123001846776383`, 0.3183252524660446, 0.9342016387010543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 112}], {
             RGBColor[
             0.8780584972468868, 0.4677393624570944, 0.21704509236247566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 141}], {
             RGBColor[
             0.8423033289137494, 0.3148548235404699, 0.18770004553512668`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 172}], {
             RGBColor[
             0.8214061746435448, 0.16554281532163417`, 0.16813188305446203`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 208}], {
             RGBColor[
             0.906012199289136, 0.5692488389367173, 0.4656274775468996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 240}], {
             RGBColor[
             0.825349023280818, 0.19584927771500635`, 0.17190755936232552`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 242}], {
             RGBColor[
             0.8356412746575417, 0.27496003188981555`, 0.1817634309041114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 243}], {
             RGBColor[
             0.8942676597098645, 0.5619556471729128, 0.5511524219741538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 285}], {
             RGBColor[
             0.9066040807260044, 0.5685593406329343, 0.38790788619052163`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 337}], {
             RGBColor[
             0.9065279712784959, 0.568396550220559, 0.3796238425222831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 357}], {
             RGBColor[
             0.8380548061555597, 0.2935114925998279, 0.18407463139230737`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 399}], {
             RGBColor[
             0.8727925927240603, 0.4468618057827464, 0.21280802197674387`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 114}], {
             RGBColor[
             0.22538318625918102`, 0.3542223972507317, 0.9361466110816916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 171}], {
             RGBColor[
             0.19921926143757313`, 0.32672245337457523`, 0.9346566142691592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 202}], {
             RGBColor[
             0.2264175602160962, 0.35530958986254624`, 0.9362055171483188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 218}], {
             RGBColor[
             0.20016816814604027`, 0.3277198144893344, 0.9347106531024247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 229}], {
             RGBColor[
             0.20817939443044792`, 0.33614012125533055`, 0.9351668805877746]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 261}], {
             RGBColor[
             0.23472290345765154`, 0.3640390321985968, 0.9366784941592712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 349}], {
             RGBColor[
             0.20573070891450085`, 0.3335663975224413, 0.935027431570147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 353}], {
             RGBColor[
             0.19974831949640176`, 0.32727852693862247`, 0.9346867433429382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.2877186940288704, 0.4160544664052851, 0.9398315069221266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 150}], {
             RGBColor[
             0.2101822963835033, 0.33824529819931026`, 0.9352809428909732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 158}], {
             RGBColor[
             0.2827874224549232, 0.411783246820848, 0.939517290657987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 241}], {
             RGBColor[
             0.24501597193591163`, 0.37485769978748307`, 0.9372646691818778]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 270}], {
             RGBColor[
             0.2929589759941193, 0.42059333525935383`, 0.9401654130551529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 292}], {
             RGBColor[
             0.21060209943900177`, 0.3386865378276902, 0.9353048500539408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 310}], {
             RGBColor[
             0.2532088981789974, 0.38346898473049273`, 0.9377312442110733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 320}], {
             RGBColor[
             0.21130568150236095`, 0.33942604718596003`, 0.9353449180115927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 347}], {
             RGBColor[
             0.21233497992474068`, 0.3405079050891704, 0.9354035350340366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 374}], {
             RGBColor[
             0.2085188963433679, 0.336496959291474, 0.9351862147194673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 384}], {
             RGBColor[
             0.2081882862900271, 0.33614946716352473`, 0.9351673869660233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 389}], {
             RGBColor[
             0.21473367973065993`, 0.34302909067154336`, 0.9355401374394254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 390}], {
             RGBColor[
             0.24476481400135702`, 0.3745937168739334, 0.9372503661090598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 158}], {
             RGBColor[
             0.34368740964077826`, 0.4721064928245296, 0.9431204357248351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 190}], {
             RGBColor[
             0.6524189980541504, 0.7216233648288316, 0.9512140557147148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 212}], {
             RGBColor[
             0.3829775514957524, 0.5061376389193594, 0.9456239688209257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 241}], {
             RGBColor[
             0.30591595912176667`, 0.43518094579116473`, 0.9408678142487259]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 268}], {
             RGBColor[
             0.5139907876886572, 0.6129102178843966, 0.9560554271690249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 270}], {
             RGBColor[
             0.35385896317997434`, 0.4809165812630355, 0.943768558122001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 295}], {
             RGBColor[
             0.38882676959428764`, 0.5112039376460608, 0.945996675825904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 310}], {
             RGBColor[
             0.3141088853648525, 0.4437922307341744, 0.9413343892779213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 324}], {
             RGBColor[
             0.4908741561658506, 0.5947099474856988, 0.9538480411311054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 346}], {
             RGBColor[
             0.3498425512041035, 0.47743776708027175`, 0.9435126359024721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 351}], {
             RGBColor[
             0.6292040524803684, 0.703641559800374, 0.9673461867380587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 373}], {
             RGBColor[
             0.31023491732991126`, 0.43972044470569116`, 0.9411137725293536]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 390}], {
             RGBColor[
             0.30566480118721207`, 0.43491696287761505`, 0.9408535111759078]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 152}], {
             RGBColor[
             0.2564614085339687, 0.38688757933463486`, 0.9379164698641311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 154}], {
             RGBColor[
             0.23083302352450608`, 0.3599505217562283, 0.9364569712516402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 180}], {
             RGBColor[
             0.25734842126298235`, 0.38781988595268346`, 0.9379669839268308]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 198}], {
             RGBColor[
             0.3047308678845767, 0.4335017597846965, 0.9408162005428573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 205}], {
             RGBColor[
             0.3030856171044626, 0.43207672625167026`, 0.9407113666179867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 236}], {
             RGBColor[
             0.2534644343240474, 0.3837375694208677, 0.9377457966165021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 262}], {
             RGBColor[
             0.23515249805591343`, 0.36449056335924074`, 0.936702958936114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 267}], {
             RGBColor[
             0.2560701403937588, 0.38647633171144136`, 0.9378941877223754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 284}], {
             RGBColor[
             0.26637610871838646`, 0.39730855785675745`, 0.9384810973721491]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 286}], {
             RGBColor[
             0.22549943873113315`, 0.3543445859695858, 0.9361532314879892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 332}], {
             RGBColor[
             0.24224909685408347`, 0.3719495386464692, 0.9371070997391926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 367}], {
             RGBColor[
             0.31561783688898226`, 0.44293150514134, 0.9415099085808494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 398}], {
             RGBColor[
             0.34112387915000547`, 0.4650235569768793, 0.9431351310396142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 157}], {
             RGBColor[
             0.18435836126610156`, 0.3111027050588667, 0.9338103079891256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 181}], {
             RGBColor[
             0.18812311022869774`, 0.31505969491742614`, 0.9340247048730984]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 191}], {
             RGBColor[
             0.19427315985261398`, 0.3215237870078299, 0.9343749411009974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 305}], {
             RGBColor[
             0.1817778659169268, 0.3083904408340291, 0.9336633525964908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 334}], {
             RGBColor[
             0.18315174728548578`, 0.30983447726149455`, 0.9337415931079549]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 340}], {
             RGBColor[
             0.19212863805325098`, 0.319269758626164, 0.9342528137570594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 360}], {
             RGBColor[
             0.18328589355082267`, 0.3099754734917281, 0.9337492325393142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 365}], {
             RGBColor[
             0.1811265179483144, 0.30770583282117103`, 0.9336262592932614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 370}], {
             RGBColor[
             0.1842051301196885, 0.31094164940857083`, 0.9338015817020224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 227}], {
             RGBColor[
             0.1954518354139104, 0.3227626497550994, 0.934442064930519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 237}], {
             RGBColor[
             0.19038343508665123`, 0.3174354396560086, 0.9341534270299079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 251}], {
             RGBColor[
             0.18685400772656674`, 0.3137257877219404, 0.9339524313630709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 308}], {
             RGBColor[
             0.1924672891129, 0.3196257023615725, 0.9342720994339171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 375}], {
             RGBColor[
             0.18201536929507323`, 0.30864007194304494`, 0.9336768780625215]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 116}], {
             RGBColor[
             0.1862942905711151, 0.31313748950344333`, 0.9339205562990953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 151}], {
             RGBColor[
             0.1906348725141942, 0.31769971633440997`, 0.9341677460194382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 154}], {
             RGBColor[
             0.19738148096805996`, 0.3247908295791051, 0.934551955390173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 286}], {
             RGBColor[
             0.1920478961746871, 0.3191848937924626, 0.934248215626522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 291}], {
             RGBColor[
             0.18821279065920096`, 0.31515395473595276`, 0.9340298120409453]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 304}], {
             RGBColor[
             0.18507047905985996`, 0.31185118601098283`, 0.9338508620439963]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 383}], {
             RGBColor[
             0.1988021595169091, 0.3262840528101681, 0.9346328609318244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 141}], {
             RGBColor[
             0.9013527030672266, 0.6354761592849575, 0.23890867411463246`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 172}], {
             RGBColor[
             0.880455548797022, 0.4861641510661218, 0.21934051163396778`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 179}], {
             RGBColor[
             0.6955279730573865, 0.6779676106196408, 0.6092046613657698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 240}], {
             RGBColor[
             0.8843983974342954, 0.516470613459494, 0.2231161879418313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 279}], {
             RGBColor[
             0.8046710367643358, 0.7661172165820809, 0.618109700945247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 285}], {
             RGBColor[
             0.9656534548794817, 0.8891806763774219, 0.4391165147700274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 337}], {
             RGBColor[
             0.9655773454319732, 0.8890178859650467, 0.43083247110178885`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 399}], {
             RGBColor[
             0.9318419668775375, 0.7674831415272341, 0.2640166505562497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 124}], {
             RGBColor[
             0.3086276211264817, 0.4416266325643382, 0.9408905883938774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 149}], {
             RGBColor[
             0.26206453775242544`, 0.39277682340214404`, 0.9382355597840353]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 210}], {
             RGBColor[
             0.3065896783902691, 0.43957556926948627`, 0.9407712006743179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 249}], {
             RGBColor[
             0.3083010067824331, 0.4413437356356376, 0.9408697768166884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 266}], {
             RGBColor[
             0.2701389734664643, 0.40126356728639195`, 0.9386953869528927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 293}], {
             RGBColor[
             0.32820995463660485`, 0.4585878656141067, 0.9421383573691648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 315}], {
             RGBColor[
             0.26318579596449465`, 0.3939553368749055, 0.9382994137804598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 316}], {
             RGBColor[
             0.2709397029977173, 0.40210518479292345`, 0.9387409873151243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 387}], {
             RGBColor[
             0.4208258242811829, 0.5366129491256768, 0.9486460027249637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 397}], {
             RGBColor[
             0.2602244815922864, 0.3908428077115391, 0.9381307713078346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 128}], {
             RGBColor[
             0.21795119041436695`, 0.34641089840207934`, 0.9357233699129821]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 155}], {
             RGBColor[
             0.2241859587617661, 0.352964035242341, 0.9360784307468533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 170}], {
             RGBColor[
             0.23647751036378017`, 0.3658832353054412, 0.9367784164268669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 187}], {
             RGBColor[
             0.33810546577905015`, 0.4610349816709624, 0.9429931157731941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 202}], {
             RGBColor[
             0.2423249813764799, 0.37202929809086444`, 0.937111421250482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 261}], {
             RGBColor[
             0.25063032461803525`, 0.380758740426915, 0.9375843982614342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 306}], {
             RGBColor[
             0.2220014868268114, 0.35066801673518333`, 0.9359540283017942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 353}], {
             RGBColor[
             0.2156557406567855, 0.3439982351669406, 0.9355926474451014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 122}], {
             RGBColor[
             0.7312854319265467, 0.5812953754272103, 0.5851154705993664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 166}], {
             RGBColor[
             0.92715146758626, 0.7340525782000142, 0.5145919024804202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 169}], {
             RGBColor[
             0.8801983721871041, 0.6989200901607082, 0.599330145570115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 197}], {
             RGBColor[
             0.914459777232721, 0.7255013666531043, 0.5770167261447392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 221}], {
             RGBColor[
             0.8834582095203258, 0.5636927731060549, 0.2244670121341203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 239}], {
             RGBColor[
             0.8461854795987771, 0.346251043142995, 0.19147853854411218`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 300}], {
             RGBColor[
             0.8896537545747043, 0.7064595554170632, 0.6002320083831638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 350}], {
             RGBColor[
             0.9292292560607558, 0.7349117971309463, 0.4801575703138227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 392}], {
             RGBColor[
             0.9278459781809479, 0.7343397761790258, 0.5030820645906373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 151}], {
             RGBColor[
             0.18767873323802545`, 0.31459262652510106`, 0.9339993982608765]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 154}], {
             RGBColor[
             0.19442534169189124`, 0.3216837397697962, 0.9343836076316113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 265}], {
             RGBColor[
             0.18666044049465552`, 0.3135223362883303, 0.9339414079955707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 291}], {
             RGBColor[
             0.1852566513830322, 0.31204686492664385`, 0.9338614642823836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 304}], {
             RGBColor[
             0.18211433978369124`, 0.30874409620167387`, 0.9336825142854346]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 383}], {
             RGBColor[
             0.19584602024074033`, 0.3231769630008592, 0.9344645131732627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 289}], {
             RGBColor[
             0.20615434433043495`, 0.33401166520462483`, 0.935051556980372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 303}], {
             RGBColor[
             0.21968824533158482`, 0.34823665325571823`, 0.9358222926207751]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 376}], {
             RGBColor[
             0.217871456795024, 0.34632709331274647`, 0.9357188292013159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 158}], {
             RGBColor[
             0.28881871360859035`, 0.41812251622929797`, 0.9398607637666927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 164}], {
             RGBColor[
             0.21991695118991147`, 0.3484770376136085, 0.9358353170810669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 173}], {
             RGBColor[
             0.26068055800241224`, 0.3913221729354959, 0.9381567441846866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 209}], {
             RGBColor[
             0.2868618960178613, 0.41642761918472027`, 0.9397360770801573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 241}], {
             RGBColor[
             0.25104726308957875`, 0.38119696919593304`, 0.9376081422905835]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 323}], {
             RGBColor[
             0.3187861771861727, 0.44407882697168544`, 0.9417702640466686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 346}], {
             RGBColor[
             0.2949738551719156, 0.42345379048504006`, 0.9402529639443298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 354}], {
             RGBColor[
             0.22736699671866945`, 0.3563075078245018, 0.9362595861525749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 388}], {
             RGBColor[
             0.2291977478565746, 0.35823174334676655`, 0.936363844721525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 389}], {
             RGBColor[
             0.22076497088432706`, 0.3493683600799934, 0.9358836105481312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 126}], {
             RGBColor[
             0.1845010944888899, 0.3112527267258263, 0.9338184364350084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 127}], {
             RGBColor[
             0.18861006279746526`, 0.31557151294177693`, 0.9340524361015079]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 129}], {
             RGBColor[
             0.18575214150891103`, 0.312567656464831, 0.9338896817120405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 196}], {
             RGBColor[
             0.18607572050979368`, 0.3129077585108523, 0.9339081090574485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 231}], {
             RGBColor[
             0.18230446054106692`, 0.30894392517202796`, 0.9336933413813087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 235}], {
             RGBColor[
             0.18696497458482364`, 0.31384242092567355`, 0.9339587507614879]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 317}], {
             RGBColor[
             0.1888850042427438, 0.31586049383305914`, 0.9340680936100771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 326}], {
             RGBColor[
             0.18721381086797456`, 0.3141039636363968, 0.933972921619693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 327}], {
             RGBColor[
             0.18901152680793626`, 0.3159934770710704, 0.9340752988829915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 336}], {
             RGBColor[
             0.18138462902211405`, 0.30797712392492177`, 0.9336409583370731]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 396}], {
             RGBColor[
             0.19098691356338682`, 0.3180697337978031, 0.9341877942363916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 132}], {
             RGBColor[
             0.4382862950940797, 0.5522789014915227, 0.9496356996104882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 160}], {
             RGBColor[
             0.48896132780643076`, 0.5959998592268796, 0.9529119733307341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 187}], {
             RGBColor[
             0.47660974925846794`, 0.585472751295903, 0.952077636221743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 202}], {
             RGBColor[
             0.38082926485589774`, 0.49646706771580507`, 0.9461959416990309]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 206}], {
             RGBColor[
             0.624306194339526, 0.7045315727086937, 0.9644880050917888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 217}], {
             RGBColor[
             0.7556843813439534, 0.80370125991605, 0.7211335984965017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 220}], {
             RGBColor[
             0.5770608462863022, 0.6675230171669182, 0.9598474901446392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 233}], {
             RGBColor[
             0.7388527640498924, 0.7945317751585553, 0.9544100950493892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 244}], {
             RGBColor[
             0.7365322986249497, 0.7928011758440465, 0.9583380377395063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 307}], {
             RGBColor[
             0.43332684059947457`, 0.5479832712777266, 0.9493196875555654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 321}], {
             RGBColor[
             0.5363303582199404, 0.6344561720670685, 0.9566410369233613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 341}], {
             RGBColor[
             0.42726711236099996`, 0.542734639248357, 0.9489335670306169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 366}], {
             RGBColor[
             0.4563492884558704, 0.567924158469062, 0.9507866575750236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 122}], {
             RGBColor[
             0.4544345003462795, 0.5641026104704333, 0.9512623074498896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 175}], {
             RGBColor[
             0.29627876905743955`, 0.4285384264353338, 0.9401913224925988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 178}], {
             RGBColor[
             0.376298213208635, 0.5003523318083618, 0.9451983672915776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.26676233186552467`, 0.3975147794964234, 0.938510405060175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 274}], {
             RGBColor[
             0.4019923332344326, 0.5215276967163304, 0.9471338679528571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 296}], {
             RGBColor[
             0.27793336964590865`, 0.4092562484883108, 0.9391465791356984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 319}], {
             RGBColor[
             0.3821339767558598, 0.5054057883182604, 0.9455705453873072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 373}], {
             RGBColor[
             0.2913786665893785, 0.4233881080569608, 0.9399122689060947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 166}], {
             RGBColor[
             0.7938288566186125, 0.8372493846021647, 0.890969402038376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 169}], {
             RGBColor[
             0.7468757612194565, 0.8021168965628588, 0.9757076451280708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 175}], {
             RGBColor[
             0.4398070896700592, 0.5489279977942612, 0.9504219852000314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 178}], {
             RGBColor[
             0.5198265338212547, 0.6207419031672892, 0.9554290299990101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 268}], {
             RGBColor[
             0.638662857560744, 0.7169674525945936, 0.9650845862531987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 274}], {
             RGBColor[
             0.5455206538470523, 0.6419172680752578, 0.9573645306602898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 319}], {
             RGBColor[
             0.5256622973684795, 0.6257953596771879, 0.9558012080947398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 351}], {
             RGBColor[
             0.7538761223524553, 0.8076987945105711, 0.9763753458222324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 131}], {
             RGBColor[
             0.21247713876151392`, 0.34065732304000995`, 0.9354116307694857]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 140}], {
             RGBColor[
             0.21869849237699107`, 0.3471963601464784, 0.9357659276542193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 203}], {
             RGBColor[
             0.21872743662810462`, 0.3472267823895703, 0.935767575986501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 232}], {
             RGBColor[
             0.2533953304852037, 0.3836649369048065, 0.9377418612551098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 275}], {
             RGBColor[
             0.22522408057531274`, 0.3540551670891031, 0.9361375502483711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 280}], {
             RGBColor[
             0.23161694690439888`, 0.3607744749321087, 0.9365016145284144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 297}], {
             RGBColor[
             0.20930917766859286`, 0.3373275950710155, 0.9352312200718224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 309}], {
             RGBColor[
             0.2546471876156135, 0.3849807181211936, 0.93781315266673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 322}], {
             RGBColor[
             0.20580146810397543`, 0.3336407699169709, 0.9350314612013086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 325}], {
             RGBColor[
             0.2504184772778667, 0.38053607544050067`, 0.9375723338688118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 339}], {
             RGBColor[
             0.23162280417676506`, 0.3607806312967381, 0.9365019480914105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 149}], {
             RGBColor[
             0.2631665511656537, 0.3938441656371931, 0.9383016477132344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 185}], {
             RGBColor[
             0.35466498690371884`, 0.48161471850061266`, 0.9438199172409392]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 210}], {
             RGBColor[
             0.30769169180349737`, 0.4406429115045353, 0.9408372886035168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 219}], {
             RGBColor[
             0.32342751125618663`, 0.45455838713589725`, 0.9418294929148936]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 249}], {
             RGBColor[
             0.30940302019566135`, 0.4424110778706867, 0.9409358647458874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 266}], {
             RGBColor[
             0.27124098687969256`, 0.402330909521441, 0.9387614748820916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 293}], {
             RGBColor[
             0.3293119680498331, 0.45965520784915576`, 0.9422044452983639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 315}], {
             RGBColor[
             0.2642878093777229, 0.3950226791099546, 0.9383655017096588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 316}], {
             RGBColor[
             0.27204171641094554`, 0.40317252702797246`, 0.9388070752443234]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 338}], {
             RGBColor[
             0.2719649687624893, 0.40309186038336303`, 0.9388027045792817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 387}], {
             RGBColor[
             0.42192783769441117`, 0.5376802913607258, 0.9487120906541628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 397}], {
             RGBColor[
             0.26132649500551464`, 0.3919101499465881, 0.9381968592370336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 148}], {
             RGBColor[
             0.2977450564931756, 0.4279464199660071, 0.9403529311058223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 162}], {
             RGBColor[
             0.2669203824734684, 0.39788062408229774`, 0.9385120929573202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 211}], {
             RGBColor[
             0.24170072207493107`, 0.37137316198461084`, 0.9370758706067677]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 214}], {
             RGBColor[
             0.25062847588100123`, 0.38075679728707557`, 0.9375842929785951]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 248}], {
             RGBColor[
             0.2397553776330553, 0.3693284816342379, 0.936965086118682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 263}], {
             RGBColor[
             0.326732269165051, 0.4530536866427142, 0.9421999706648885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 276}], {
             RGBColor[
             0.2421845103154749, 0.3718816540993685, 0.9371034216313661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 288}], {
             RGBColor[
             0.28344153985750953`, 0.415245407994804, 0.9394529484294792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 196}], {
             RGBColor[
             0.1881608487233165, 0.3150993604680292, 0.9340268540245378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 289}], {
             RGBColor[
             0.1863769520635358, 0.31322437197301883`, 0.933925263748802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 317}], {
             RGBColor[
             0.1909701324562666, 0.31805209579023613`, 0.9341868385771666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 326}], {
             RGBColor[
             0.18929893908149736`, 0.31629556559357375`, 0.9340916665867824]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 327}], {
             RGBColor[
             0.19109665502145906`, 0.31818507902824733`, 0.9341940438500809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 336}], {
             RGBColor[
             0.18346975723563688`, 0.31016872588209876`, 0.9337597033041625]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 376}], {
             RGBColor[
             0.19809406452812484`, 0.3255398000811405, 0.9345925359697458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 129}], {
             RGBColor[
             0.19194623803100921`, 0.3190780446379586, 0.9342424263456293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 216}], {
             RGBColor[
             0.19725740387013102`, 0.32466041668223944`, 0.9345448893830015]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 231}], {
             RGBColor[
             0.1884985570631651, 0.31545431334515556`, 0.9340460860148976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 235}], {
             RGBColor[
             0.19315907110692182`, 0.32035280909880115`, 0.9343114953950769]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 298}], {
             RGBColor[
             0.19590091614963856`, 0.32323466208171286`, 0.9344676394140633]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 313}], {
             RGBColor[
             0.20658568658737522`, 0.3344650332653477, 0.935076121283791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 317}], {
             RGBColor[
             0.19507910076484197`, 0.32237088200618674`, 0.9344208382436661]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 336}], {
             RGBColor[
             0.18757872554421223`, 0.31448751209804937`, 0.933993702970662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 361}], {
             RGBColor[
             0.2062200768333135, 0.33408075423283157`, 0.9350553003491684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 393}], {
             RGBColor[
             0.1890837058583692, 0.31606934182949153`, 0.9340794093731344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 396}], {
             RGBColor[
             0.197181010085485, 0.3245801219709307, 0.9345405388699805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 133}], {
             RGBColor[
             0.19019948162046302`, 0.31724209289972144`, 0.9341429511521433]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 155}], {
             RGBColor[
             0.2008465417565683, 0.32843282816537045`, 0.9347492854759805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 170}], {
             RGBColor[
             0.21313809335858236`, 0.34135202822847077`, 0.9354492711559941]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 171}], {
             RGBColor[
             0.19178726559275905`, 0.3189109545259229, 0.9342333731004496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 199}], {
             RGBColor[
             0.1905507884017967, 0.3176113386010396, 0.9341629575536283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 261}], {
             RGBColor[
             0.22729090761283746`, 0.3562275333499445, 0.9362552529905616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 299}], {
             RGBColor[
             0.19113698074466645`, 0.31822746392013684`, 0.934196340340361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 306}], {
             RGBColor[
             0.1986620698216136, 0.3261368096582128, 0.9346248830309214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 342}], {
             RGBColor[
             0.18916310762939384`, 0.3161527981252015, 0.9340839311865298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 353}], {
             RGBColor[
             0.19231632365158768`, 0.3194670280899702, 0.9342635021742287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 216}], {
             RGBColor[
             0.1943994825815768, 0.32165656020529343`, 0.9343821349935341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 231}], {
             RGBColor[
             0.18564063577461087`, 0.3124504568682096, 0.93388333162543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 235}], {
             RGBColor[
             0.1903011498183676, 0.3173489526218552, 0.9341487410056093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 298}], {
             RGBColor[
             0.19304299486108434`, 0.3202308056047669, 0.9343048850245959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 313}], {
             RGBColor[
             0.203727765298821, 0.33146117678840176`, 0.9349133668943235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 317}], {
             RGBColor[
             0.19222117947628775`, 0.3193670255292408, 0.9342580838541985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 336}], {
             RGBColor[
             0.184720804255658, 0.3114836556211034, 0.9338309485811944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 361}], {
             RGBColor[
             0.20336215554475928`, 0.33107689775588556`, 0.9348925459597008]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 393}], {
             RGBColor[
             0.18622578456981498`, 0.3130654853525456, 0.9339166549836668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 396}], {
             RGBColor[
             0.19432308879693078`, 0.32157626549398477`, 0.934377784480513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 147}], {
             RGBColor[
             0.18274418895711692`, 0.3094061076176884, 0.9337183832640827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 164}], {
             RGBColor[
             0.19148238974395732`, 0.318590510678587, 0.9342160108718838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 287}], {
             RGBColor[
             0.1859722872961475, 0.31279904364526556`, 0.9339022186889471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 371}], {
             RGBColor[
             0.18427986944939637`, 0.311020205182841, 0.9338058379962824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 391}], {
             RGBColor[
             0.18156952589467779`, 0.3081714622611251, 0.9336514879404352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 140}], {
             RGBColor[
             0.21947779992995464`, 0.3480154617955958, 0.9358103080664784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 186}], {
             RGBColor[
             0.21005402739966472`, 0.3381104793645726, 0.9352736381621005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 188}], {
             RGBColor[
             0.20752052535930418`, 0.3354476080868466, 0.9351293589688823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 203}], {
             RGBColor[
             0.2195067441810682, 0.34804588403868764`, 0.9358119563987601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 228}], {
             RGBColor[
             0.20842587898456535`, 0.33639919214973135`, 0.9351809175184903]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 238}], {
             RGBColor[
             0.2516193138752771, 0.38179823084181674`, 0.9376407197365557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 273}], {
             RGBColor[
             0.19754073794696791`, 0.32495821876141306`, 0.9345610248395222]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 280}], {
             RGBColor[
             0.23239625445736245`, 0.36159357658122604`, 0.9365459949406734]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 309}], {
             RGBColor[
             0.255426495168577, 0.38579981977031097`, 0.9378575330789891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 322}], {
             RGBColor[
             0.206580775656939, 0.33445987156608825`, 0.9350758416135677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 325}], {
             RGBColor[
             0.2511977848308302, 0.381355177089618, 0.9376167142810707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 330}], {
             RGBColor[
             0.199593351679308, 0.3271156459373298, 0.9346779181550091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 339}], {
             RGBColor[
             0.23240211172972863`, 0.36159973294585546`, 0.9365463285036696]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 160}], {
             RGBColor[
             0.40894844852211004`, 0.5284611159894712, 0.9473261168602697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 202}], {
             RGBColor[
             0.300816385571577, 0.4289283244783967, 0.9406100852285664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 220}], {
             RGBColor[
             0.4970479670019815, 0.5999842739295098, 0.9542616336741748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 244}], {
             RGBColor[
             0.656519419340629, 0.7252624326066381, 0.9527521812690418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 260}], {
             RGBColor[
             0.29142760754703456`, 0.4190601234916939, 0.9400754082095211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 307}], {
             RGBColor[
             0.3533139613151539, 0.48044452804031823`, 0.9437338310851009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 321}], {
             RGBColor[
             0.4563174789356197, 0.5669174288296601, 0.9510551804528969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 341}], {
             RGBColor[
             0.34725423307667924`, 0.4751958960109486, 0.9433477105601525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 348}], {
             RGBColor[
             0.34570653122762846`, 0.47385535445905747`, 0.94324909236691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 366}], {
             RGBColor[
             0.3763364091715497, 0.5003854152316536, 0.9452008011045592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 155}], {
             RGBColor[
             0.1964342499678622, 0.3237952297399831, 0.9344980119860145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 199}], {
             RGBColor[
             0.18613849661309062`, 0.31297374017565216`, 0.9339116840636623]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 216}], {
             RGBColor[
             0.19274891912622777`, 0.3199217133619542, 0.9342881378465417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 298}], {
             RGBColor[
             0.1913924314057353, 0.3184959587614276, 0.9342108878776034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 299}], {
             RGBColor[
             0.18672468895596034`, 0.31358986549474943`, 0.9339450668503949]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 306}], {
             RGBColor[
             0.1942497780329075, 0.32149921123282543`, 0.9343736095409554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 342}], {
             RGBColor[
             0.18475081584068775`, 0.311515199699814, 0.9338326576965637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 361}], {
             RGBColor[
             0.20171159208941025`, 0.3293420509125463, 0.9347985488127086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 393}], {
             RGBColor[
             0.18457522111446595`, 0.3113306385092063, 0.9338226578366745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 135}], {
             RGBColor[
             0.9129052217970873, 0.9297159641585085, 0.8318647617559947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 226}], {
             RGBColor[
             0.6381042655490734, 0.7140610165668736, 0.9666654902064342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 234}], {
             RGBColor[
             0.8083454624285121, 0.8502936670726204, 0.9815084195744261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 239}], {
             RGBColor[
             0.8293655507418161, 0.5412295041829576, 0.578979393717503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 246}], {
             RGBColor[
             0.8756067697264411, 0.9036490867400013, 0.9879973494315406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 269}], {
             RGBColor[
             0.7872748442941331, 0.8338331400434145, 0.9794082972749127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 272}], {
             RGBColor[
             0.7859507335711424, 0.832798734683, 0.9792763222925633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 350}], {
             RGBColor[
             0.9124093272037948, 0.929890258170909, 0.8676584254872136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 355}], {
             RGBColor[
             0.7983376603764013, 0.8424754960473988, 0.9805109353940992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 392}], {
             RGBColor[
             0.9110260493239869, 0.9293182372189884, 0.8905829197640283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 395}], {
             RGBColor[
             0.6498035533941702, 0.7237783527330339, 0.9675259002297822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 156}], {
             RGBColor[
             0.9129140627520606, 0.6152764832633987, 0.4286476247419544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 165}], {
             RGBColor[
             0.9457959012350979, 0.9559420991486686, 0.8350019041226482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 221}], {
             RGBColor[
             0.9485753172801801, 0.8203317071995411, 0.46009294767531356`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 234}], {
             RGBColor[
             0.8902824990453274, 0.9119541401261442, 0.8296334999422285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 255}], {
             RGBColor[
             0.9151018270707441, 0.6320925985012373, 0.4307426303242521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 281}], {
             RGBColor[
             0.711765095722288, 0.768553055573181, 0.8142632180180123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 328}], {
             RGBColor[
             0.932186507346842, 0.7459139489960613, 0.44641772294044424`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 355}], {
             RGBColor[
             0.8802746969932166, 0.9041359691009224, 0.8286360157619015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 386}], {
             RGBColor[
             0.8778014359212141, 0.9022038387539937, 0.8283895042121832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 400}], {
             RGBColor[
             0.9225103695720027, 0.6890379026099368, 0.4378370589902095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 331}], {
             RGBColor[
             0.19186850922797938`, 0.3189963467376835, 0.9342379998052863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 335}], {
             RGBColor[
             0.18204623503960604`, 0.3086725137975501, 0.9336786358210108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 394}], {
             RGBColor[
             0.18251086599702937`, 0.30916087039310625`, 0.9337050958666762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 169}], {
             RGBColor[
             0.6151260920101136, 0.6919294010372166, 0.9662275076726026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 175}], {
             RGBColor[
             0.3080574204607164, 0.43874050226861905`, 0.940941847744563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 178}], {
             RGBColor[
             0.3880768646119117, 0.5105544076416471, 0.9459488925435418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 197}], {
             RGBColor[
             0.6493874970557305, 0.7185106775296126, 0.9439140882472267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 252}], {
             RGBColor[
             0.35201484785933657`, 0.47931930126023004`, 0.943651052724457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 278}], {
             RGBColor[
             0.29631468313808673`, 0.42639814080998684`, 0.9402731162258624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 282}], {
             RGBColor[
             0.3008030444529849, 0.4311156931304887, 0.9405287217628104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 300}], {
             RGBColor[
             0.624581474397714, 0.6994688662935715, 0.9671293704856514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 314}], {
             RGBColor[
             0.28356888618805115`, 0.41300150008529746`, 0.9395472619452747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 319}], {
             RGBColor[
             0.3939126281591366, 0.5156078641515458, 0.9463210706392715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 352}], {
             RGBColor[
             0.28703295098175935`, 0.4166424518178782, 0.9397445353106518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 159}], {
             RGBColor[
             0.18138230828610377`, 0.30797468468423184`, 0.9336408261745905]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 215}], {
             RGBColor[
             0.18262441317102773`, 0.30928021567228525`, 0.9337115622102574]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 218}], {
             RGBColor[
             0.18655648275495362`, 0.3134130701126022, 0.9339354877560864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 229}], {
             RGBColor[
             0.19456770903936127`, 0.32183337687859837`, 0.9343917152414362]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 329}], {
             RGBColor[
             0.18634787164566047`, 0.31319380661002694`, 0.9339236076620245]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 349}], {
             RGBColor[
             0.19211902352341417`, 0.31925965314570914`, 0.9342522662238085]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 193}], {
             RGBColor[
             0.18750230329400064`, 0.31440718746762647`, 0.933989350836569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 204}], {
             RGBColor[
             0.19084712474135193`, 0.31792280688272123`, 0.9341798334697757]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 224}], {
             RGBColor[
             0.18369701044953324`, 0.3104075834185898, 0.9337726450385029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 276}], {
             RGBColor[
             0.20545840173873126`, 0.33328018541543536`, 0.9350119240793292]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 290}], {
             RGBColor[
             0.19313846063632573`, 0.32033114618742536`, 0.9343103216592668]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 318}], {
             RGBColor[
             0.19122506102961745`, 0.318320041884233, 0.9342013563822857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 203}], {
             RGBColor[
             0.22572809779654535`, 0.3545849211451561, 0.9361662532834936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 232}], {
             RGBColor[
             0.2603959916536444, 0.39102307566039235`, 0.9381405385521024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 257}], {
             RGBColor[
             0.2744017745717613, 0.404416509747592, 0.9389867546110457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 275}], {
             RGBColor[
             0.23222474174375346`, 0.36141330584468895`, 0.9365362275453637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 280}], {
             RGBColor[
             0.2386176080728396, 0.36813261368769457`, 0.936900291825407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 288}], {
             RGBColor[
             0.2655351688852008, 0.39642467677341436`, 0.9384332070927082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 297}], {
             RGBColor[
             0.21630983883703356`, 0.3446857338266013, 0.935629897368815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 309}], {
             RGBColor[
             0.2616478487840542, 0.3923388568767794, 0.9382118299637227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 322}], {
             RGBColor[
             0.21280212927241615`, 0.34099890867255667`, 0.9354301384983013]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 325}], {
             RGBColor[
             0.25741913844630737`, 0.3878942141960865, 0.9379710111658044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 339}], {
             RGBColor[
             0.2386234653452058, 0.3681387700523239, 0.9369006253884031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 172}], {
             RGBColor[
             0.8447003804638847, 0.3332796121494973, 0.18999546480661883`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[
             0.8486432291011581, 0.36358607454286945`, 0.19377114111448232`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 243}], {
             RGBColor[
             0.9175618655302045, 0.7296924440007758, 0.5730160037263106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 279}], {
             RGBColor[
             0.7689158684311985, 0.6132326776654563, 0.588764654117898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 285}], {
             RGBColor[
             0.9298982865463443, 0.7362961374607975, 0.4097714679426784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 337}], {
             RGBColor[
             0.9298221770988357, 0.7361333470484221, 0.40148742427443984`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 399}], {
             RGBColor[
             0.8960867985444002, 0.6145986026106095, 0.23467160372890067`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 143}], {
             RGBColor[
             0.1837659567931899, 0.3104800503972236, 0.9337765714307771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 258}], {
             RGBColor[
             0.18294835007904106`, 0.30962069390139346`, 0.9337300099379471]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 277}], {
             RGBColor[
             0.19515207298431664`, 0.32244758043556054`, 0.9344249939036124]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 302}], {
             RGBColor[
             0.18693197467623224`, 0.31380773592942895`, 0.9339568714655127]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 377}], {
             RGBColor[
             0.18361252498065594`, 0.31031878383411166`, 0.9337678337160353]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 378}], {
             RGBColor[
             0.18665371404405717`, 0.3135152663622699, 0.93394102493416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 379}], {
             RGBColor[
             0.1947953347030193, 0.32207262588340363`, 0.9344046781862394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 258}], {
             RGBColor[
             0.1842254727690224, 0.31096303082281923`, 0.9338027401858078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 277}], {
             RGBColor[
             0.196429195674298, 0.32378991735698637`, 0.9344977241514731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 302}], {
             RGBColor[
             0.1882090973662136, 0.3151500728508547, 0.9340296017133733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 377}], {
             RGBColor[
             0.1848896476706373, 0.3116611207555374, 0.933840563963896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 378}], {
             RGBColor[
             0.18793083673403851`, 0.31485760328369566`, 0.9340137551820207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 379}], {
             RGBColor[
             0.19607245739300067`, 0.3234149628048294, 0.9344774084341002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 186}], {
             RGBColor[
             0.19870087032152506`, 0.3261775914437136, 0.9346270926619912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 188}], {
             RGBColor[
             0.19616736828116454`, 0.3235147201659876, 0.934482813468773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 200}], {
             RGBColor[
             0.18738223875410484`, 0.31428099202366444`, 0.9339825133386415]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 228}], {
             RGBColor[
             0.19707272190642572`, 0.32446630422887235`, 0.934534372018381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 333}], {
             RGBColor[
             0.1893313874669234, 0.316329670904003, 0.9340935144743294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 368}], {
             RGBColor[
             0.18786109875542928`, 0.31478430424653414`, 0.934009783707307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 200}], {
             RGBColor[
             0.19073593578989534`, 0.3178059402449537, 0.9341735014234795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 207}], {
             RGBColor[
             0.19250737674757545`, 0.31966783700731927`, 0.9342743823654074]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 222}], {
             RGBColor[
             0.21482177415136725`, 0.3431216834932156, 0.9355451542863606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 254}], {
             RGBColor[
             0.19225246823374995`, 0.31939991199715534`, 0.9342598657026484]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 333}], {
             RGBColor[
             0.19268508450271393`, 0.3198546191252922, 0.9342845025591675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 227}], {
             RGBColor[
             0.19680598858419968`, 0.3241859505953433, 0.934519181950277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 302}], {
             RGBColor[
             0.18875875182792845`, 0.3157277945402228, 0.9340609037218272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 375}], {
             RGBColor[
             0.18336952246536248`, 0.3100633727832889, 0.9337539950822794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 377}], {
             RGBColor[
             0.18543930213235216`, 0.3122388424449055, 0.9338718659723498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 344}], {
             RGBColor[
             0.1873628349672718, 0.31426059741343176`, 0.9339814083216866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 354}], {
             RGBColor[
             0.1996644579713909, 0.3271903831587082, 0.9346819675531508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 371}], {
             RGBColor[
             0.18501189214807195`, 0.3117896074520688, 0.9338475256060415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 388}], {
             RGBColor[
             0.20149520910929605`, 0.3291146186809729, 0.9347862261221009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 391}], {
             RGBColor[
             0.18230154859335337`, 0.30894086453035285`, 0.9336931755501943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 179}], {
             RGBColor[
             0.39396314610535543`, 0.515635700812435, 0.9463286881882242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 232}], {
             RGBColor[
             0.3145355236290795, 0.4455942655029455, 0.9413091233699418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 257}], {
             RGBColor[
             0.3285413065471964, 0.4589876995901452, 0.9421553394288851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 275}], {
             RGBColor[
             0.28636427371918854`, 0.4159844956872421, 0.939704812363203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 276}], {
             RGBColor[
             0.27841767131860123`, 0.407632112720532, 0.9392522651124343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 279}], {
             RGBColor[
             0.5031062098123048, 0.6037853067748751, 0.9552337277677017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 288}], {
             RGBColor[
             0.3196747008606359, 0.4509958666159675, 0.9416017919105475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 195}], {
             RGBColor[
             0.20922588183301488`, 0.33724004586656203`, 0.9352264764972114]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 210}], {
             RGBColor[
             0.26112860842944113`, 0.3917931023423411, 0.9381822599936748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 247}], {
             RGBColor[
             0.20711572977977888`, 0.33502214226724336`, 0.9351063064594698]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 249}], {
             RGBColor[
             0.2628399368216051, 0.3935612687084925, 0.9382808361360453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 253}], {
             RGBColor[
             0.20384820267597584`, 0.3315877641079622, 0.9349202256247814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 266}], {
             RGBColor[
             0.22467790350563632`, 0.35348110035924685`, 0.9361064462722496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 315}], {
             RGBColor[
             0.21772472600366666`, 0.3461728699477604, 0.9357104730998167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 316}], {
             RGBColor[
             0.2254786330368893, 0.3543227178657783, 0.9361520466344813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 358}], {
             RGBColor[
             0.20368965097586314`, 0.3314211162183854, 0.9349111963400162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 359}], {
             RGBColor[
             0.20190369877404518`, 0.3295439672183649, 0.9348094890042022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 362}], {
             RGBColor[
             0.20288427131655484`, 0.3305746111324327, 0.934865331159871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 363}], {
             RGBColor[
             0.21825217126115545`, 0.34672724835534197`, 0.9357405103269454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 369}], {
             RGBColor[
             0.20360056980323105`, 0.3313274862578765, 0.9349061232990186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 397}], {
             RGBColor[
             0.21476341163145843`, 0.34306034078439396`, 0.9355418306271915]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 192}], {
             RGBColor[
             0.1875835174154828, 0.3144925486585769, 0.9339939758606419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 283}], {
             RGBColor[
             0.2012631111576979, 0.32887066901798323`, 0.9347730084871156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 294}], {
             RGBColor[
             0.19175282420721007`, 0.318874754446001, 0.9342314117144941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 320}], {
             RGBColor[
             0.19466927104284892`, 0.32194012498366686`, 0.9343974990472872]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 347}], {
             RGBColor[
             0.19569856946522865`, 0.3230219828868772, 0.9344561160697312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 380}], {
             RGBColor[
             0.20683506244234898`, 0.3347271431002675, 0.9350903228698133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 381}], {
             RGBColor[
             0.19485465175919953`, 0.32213497187036766`, 0.9344080562048372]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 384}], {
             RGBColor[
             0.19155187583051508`, 0.31866354496123156`, 0.9342199680017178]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 168}], {
             RGBColor[
             0.18811217327033666`, 0.31504819948074547`, 0.9340240820294996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 265}], {
             RGBColor[
             0.1910010224377346, 0.31808456311929695`, 0.9341885977159134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 291}], {
             RGBColor[
             0.1895972333261113, 0.3166090917576105, 0.9341086540027264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 304}], {
             RGBColor[
             0.1864549217267703, 0.3133063230326405, 0.9339297040057775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 378}], {
             RGBColor[
             0.19141895458300517`, 0.3185238363024048, 0.9342123983333115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 383}], {
             RGBColor[
             0.20018660218381945`, 0.3277391898318258, 0.9347117028936056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 154}], {
             RGBColor[
             0.23114091709829876`, 0.3602741374238645, 0.93647450533518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 180}], {
             RGBColor[
             0.2576563148367751, 0.3881435016203197, 0.9379845180103705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 198}], {
             RGBColor[
             0.3050387614583694, 0.43382537545233274`, 0.9408337346263971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 236}], {
             RGBColor[
             0.2537723278978401, 0.38406118508850384`, 0.9377633307000419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 267}], {
             RGBColor[
             0.25637803396755154`, 0.3867999473790775, 0.9379117218059152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 284}], {
             RGBColor[
             0.26668400229217915`, 0.3976321735243937, 0.9384986314556889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 332}], {
             RGBColor[
             0.24255699042787615`, 0.37227315431410535`, 0.9371246338227324]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 367}], {
             RGBColor[
             0.31592573046277495`, 0.4432551208089762, 0.9415274426643891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 383}], {
             RGBColor[
             0.2325615956471479, 0.3617673606549275, 0.9365554108768314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 398}], {
             RGBColor[
             0.3414317727237982, 0.4653471726445155, 0.943152665123154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 161}], {
             RGBColor[
             0.1909498488692258, 0.3180307764542026, 0.9341856834568915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 184}], {
             RGBColor[
             0.18277753601960423`, 0.3094411574946885, 0.933720282329959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[
             0.18871819494406902`, 0.31568516668383156`, 0.9340585940672899]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 372}], {
             RGBColor[
             0.18825648302408265`, 0.31519987818169937`, 0.9340323002564883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 180}], {
             RGBColor[
             0.2320279298273124, 0.36120644404191316`, 0.9365250193978796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 236}], {
             RGBColor[
             0.22814394288837742`, 0.3571241275100973, 0.936303832087551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 267}], {
             RGBColor[
             0.23074964895808886`, 0.359862889800671, 0.9364522231934242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 286}], {
             RGBColor[
             0.2001789472954632, 0.3277311440588154, 0.9347112669590381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 291}], {
             RGBColor[
             0.1963438417799771, 0.3237002050023056, 0.9344928633734613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 332}], {
             RGBColor[
             0.2169286054184135, 0.3453360967356988, 0.9356651352102414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 383}], {
             RGBColor[
             0.20693321063768522`, 0.33483030307652095`, 0.9350959122643404]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 170}], {
             RGBColor[
             0.21937286170598153`, 0.34790516506873237`, 0.9358043319898652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 171}], {
             RGBColor[
             0.19802203394015824`, 0.32546409136618454`, 0.9345884339343208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 199}], {
             RGBColor[
             0.1967855567491959, 0.3241644754413012, 0.9345180183874995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 261}], {
             RGBColor[
             0.23352567596023666`, 0.3627806701902061, 0.9366103138244327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 299}], {
             RGBColor[
             0.19737174909206562`, 0.3247806007603985, 0.9345514011742322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 306}], {
             RGBColor[
             0.20489683816901277`, 0.33268994649847444`, 0.9349799438647926]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 342}], {
             RGBColor[
             0.19539787597679303`, 0.32270593496546307`, 0.9344389920204009]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 353}], {
             RGBColor[
             0.19855109199898685`, 0.3260201649302318, 0.9346185630080999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 361}], {
             RGBColor[
             0.21235865222551553`, 0.3405327861781953, 0.9354048831365458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 165}], {
             RGBColor[
             0.8638677055732559, 0.5798421452000351, 0.5836596867408057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 221}], {
             RGBColor[
             0.866647121618338, 0.4442317532509077, 0.20875073029347097`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 245}], {
             RGBColor[
             0.8249079613041663, 0.19245908208786985`, 0.17148519791537548`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 255}], {
             RGBColor[
             0.833173631408902, 0.25599264455260395`, 0.17940041294240955`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 328}], {
             RGBColor[
             0.850258311685, 0.36981399504742796`, 0.1950755055586017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 364}], {
             RGBColor[
             0.8243314936689592, 0.18802809923393973`, 0.1709331718568741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 386}], {
             RGBColor[
             0.795873240259372, 0.5261038848053603, 0.5770472868303405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 400}], {
             RGBColor[
             0.8405821739101607, 0.3129379486613033, 0.18649484160836693`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 181}], {
             RGBColor[
             0.19115892919796787`, 0.31825053313616897`, 0.9341975902723066]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 191}], {
             RGBColor[
             0.1973089788218841, 0.3247146252265727, 0.9345478265002056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 334}], {
             RGBColor[
             0.1861875662547559, 0.3130253154802374, 0.9339144785071631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 365}], {
             RGBColor[
             0.18416233691758455`, 0.3108966710399138, 0.9337991446924696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 370}], {
             RGBColor[
             0.18724094908895864`, 0.3141324876273136, 0.9339744671012307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 209}], {
             RGBColor[
             0.336799320476102, 0.4661403761955148, 0.94268153277416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 241}], {
             RGBColor[
             0.3009846875478195, 0.43090972620672763`, 0.9405535979845862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 270}], {
             RGBColor[
             0.3489276916060272, 0.4766453616785984, 0.9434543418578613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 310}], {
             RGBColor[
             0.30917761379090525`, 0.4395210111497373, 0.9410201730137817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 323}], {
             RGBColor[
             0.3687236016444134, 0.49379158398248, 0.9447157197406713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 324}], {
             RGBColor[
             0.4859428845919035, 0.5904387279012617, 0.9535338248669657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 346}], {
             RGBColor[
             0.34491127963015633`, 0.47316654749583464`, 0.9431984196383325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 390}], {
             RGBColor[
             0.3007335296132649, 0.43064574329317795`, 0.9405392949117681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 215}], {
             RGBColor[
             0.1817543271405076, 0.3083657000875679, 0.9336620120979963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 218}], {
             RGBColor[
             0.18568639672443343`, 0.31249855452788494`, 0.9338859376438252]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 329}], {
             RGBColor[
             0.18547778561514033`, 0.3122792910253096, 0.9338740575497635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 349}], {
             RGBColor[
             0.191248937492894, 0.31834513756099186`, 0.9342027161115474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 217}], {
             RGBColor[
             0.7263465347719837, 0.7798834744139984, 0.7188240157462833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 220}], {
             RGBColor[
             0.5477229997143326, 0.6437052316648666, 0.9575379073944208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 233}], {
             RGBColor[
             0.7095149174779228, 0.7707139896565038, 0.9521005122991707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 244}], {
             RGBColor[
             0.7071944520529801, 0.7689833903419949, 0.9560284549892878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 263}], {
             RGBColor[
             0.42578806203725694`, 0.5430467428327064, 0.9483991221427692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 264}], {
             RGBColor[
             0.5914575736276367, 0.6779711437656651, 0.9618285011853527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 307}], {
             RGBColor[
             0.403988994027505, 0.524165485775675, 0.9470101048053469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 312}], {
             RGBColor[
             0.38126624461740655`, 0.5039445125232649, 0.9455819912605958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 321}], {
             RGBColor[
             0.5069925116479708, 0.6106383865650169, 0.9543314541731429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 341}], {
             RGBColor[
             0.3979292657890303, 0.5189168537463054, 0.9466239842803985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 348}], {
             RGBColor[
             0.39638156393997953`, 0.5175763121944144, 0.946525366087156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 366}], {
             RGBColor[
             0.4270114418839008, 0.5441063729670104, 0.948477074824805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 176}], {
             RGBColor[
             0.21656199837052442`, 0.34495076948413805`, 0.9356442574812107]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 184}], {
             RGBColor[
             0.19128276610466352`, 0.31838069357681953`, 0.9342046426009427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 195}], {
             RGBColor[
             0.20065168741435874`, 0.3282280238972294, 0.9347381888094528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 250}], {
             RGBColor[
             0.22890128499152032`, 0.3579201420787632, 0.9363469615999377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 344}], {
             RGBColor[
             0.1953522686165181, 0.3226579987381405, 0.9344363947487033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.19722342502912832`, 0.3246247027659626, 0.9345429543382737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 363}], {
             RGBColor[
             0.20967797684249928`, 0.3377152263860093, 0.9352522226391868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 372}], {
             RGBColor[
             0.19676171310914198`, 0.3241394142638304, 0.934516660527472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 191}], {
             RGBColor[
             0.239776323432642, 0.3693504969976439, 0.936966278950982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 211}], {
             RGBColor[
             0.24710920905835015`, 0.37705782472206506`, 0.9373838759393338]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 214}], {
             RGBColor[
             0.25603696286442035`, 0.3864414600245297, 0.9378922983111614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 248}], {
             RGBColor[
             0.24516386461647438`, 0.3750131443716921, 0.9372730914512483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 263}], {
             RGBColor[
             0.33214075614847005`, 0.45873834938016844`, 0.9425079759974546]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 312}], {
             RGBColor[
             0.28761893872861966`, 0.41963611907072695`, 0.9396908451152812]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 340}], {
             RGBColor[
             0.23763180163327896`, 0.367096468615978, 0.9368441516070439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 348}], {
             RGBColor[
             0.3027342580511927, 0.4332679187418763, 0.9406342199418414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 167}], {
             RGBColor[
             0.2885245503262027, 0.4204485142001573, 0.9397475246726753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 174}], {
             RGBColor[
             0.3053955889489409, 0.4350613598921163, 0.9408225323352425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.2667189772067604, 0.39766893437715617`, 0.9385006232253336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 222}], {
             RGBColor[
             0.24959037113759353`, 0.3796656833821117, 0.9375251744491964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 226}], {
             RGBColor[
             0.35601753306005335`, 0.4789075435482711, 0.944048117850775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 395}], {
             RGBColor[
             0.36771682090515007`, 0.4886248797144314, 0.9449085278741232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 287}], {
             RGBColor[
             0.19544251078166353`, 0.3227528489753921, 0.9344415339065071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 292}], {
             RGBColor[
             0.19766905263223078`, 0.3250930856312453, 0.9345683321710234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 354}], {
             RGBColor[
             0.20840265875823133`, 0.3363747862196069, 0.9351795951609518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 371}], {
             RGBColor[
             0.1937500929349124, 0.3209740105129675, 0.9343451532138425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 374}], {
             RGBColor[
             0.1955858495365969, 0.322903507095029, 0.9344496968365499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 388}], {
             RGBColor[
             0.21023340989613648`, 0.33829902174187165`, 0.935283853729902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 389}], {
             RGBColor[
             0.20180063292388895`, 0.3294356384750984, 0.934803619556508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 391}], {
             RGBColor[
             0.1910397493801938, 0.3181252675912516, 0.9341908031579952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 182}], {
             RGBColor[
             0.6226406331298818, 0.6984050769847048, 0.9667215385795859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 256}], {
             RGBColor[
             0.624029163944416, 0.6996077525866663, 0.9668100145352584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 281}], {
             RGBColor[
             0.6627187385434833, 0.7331187175098175, 0.9692752800168635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 311}], {
             RGBColor[
             0.5997467789297788, 0.6780206465223158, 0.965283080943369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 328}], {
             RGBColor[
             0.8831401501680374, 0.7104796109326978, 0.6014297849392954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 386}], {
             RGBColor[
             0.8287550787424094, 0.8667695006906301, 0.9834015662110343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 400}], {
             RGBColor[
             0.873464012393198, 0.6536035645465732, 0.5928491209890607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 169}], {
             RGBColor[
             0.9427417968791698, 0.9548740993356628, 0.9051840770091248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 178}], {
             RGBColor[
             0.7156925694809679, 0.7734991059400932, 0.884905461880064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 197}], {
             RGBColor[
             0.9770032019247867, 0.9814553758280588, 0.8828706575837489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.9087289042908429, 0.6022050523179494, 0.4973324699831219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 300}], {
             RGBColor[
             0.9521971792667703, 0.9624135645920178, 0.9060859398221737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 319}], {
             RGBColor[
             0.7215283330281927, 0.7785525624499918, 0.8852776399757938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 174}], {
             RGBColor[
             0.3271254190729118, 0.4577613290244936, 0.9420651203310438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 183}], {
             RGBColor[
             0.33012064304919175`, 0.46035564148841296`, 0.9422559733542398]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 189}], {
             RGBColor[
             0.2884488073307313, 0.4203689035095335, 0.9397432112211349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 222}], {
             RGBColor[
             0.2713202012615644, 0.4023656525144891, 0.9387677624449977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 238}], {
             RGBColor[
             0.3001182809431252, 0.43263426016352036`, 0.9404077704799216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 246}], {
             RGBColor[
             0.6152498673613919, 0.6911955828537762, 0.9666225650716829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 269}], {
             RGBColor[
             0.5269179419290838, 0.6213796361571894, 0.958033512915055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 272}], {
             RGBColor[
             0.5255938312060932, 0.6203452307967748, 0.9579015379327056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 309}], {
             RGBColor[
             0.30392546223642514`, 0.4366358490920146, 0.940624583822355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 395}], {
             RGBColor[
             0.389446651029121, 0.5113248488468087, 0.9461511158699245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 265}], {
             RGBColor[
             0.18709388052696674`, 0.31397790924397473`, 0.9339660917641938]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 304}], {
             RGBColor[
             0.18254777981600245`, 0.3091996691573183, 0.9337071980540577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 378}], {
             RGBColor[
             0.18751181267223727`, 0.3144171824270826, 0.9339898923815917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 177}], {
             RGBColor[
             0.8953206105495907, 0.9193683682944271, 0.9898776731680061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 178}], {
             RGBColor[
             0.668739474081812, 0.7383666179007873, 0.9696437049697588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 197}], {
             RGBColor[
             0.9300501065256308, 0.9463228877887528, 0.9676089006734437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 239}], {
             RGBColor[
             0.8617758088916869, 0.5670725642786435, 0.5820707130728167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 300}], {
             RGBColor[
             0.9052440838676142, 0.9272810765527117, 0.9908241829118685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 319}], {
             RGBColor[
             0.6745752376290368, 0.7434200744106859, 0.9700158830654886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 171}], {
             RGBColor[
             0.21031358554217228`, 0.3383832914292848, 0.9352884196143345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 187}], {
             RGBColor[
             0.33329236872326556`, 0.45597611149735384`, 0.9427190170162062]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 261}], {
             RGBColor[
             0.2458172275622507, 0.3756998702533064, 0.9373102995044464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 299}], {
             RGBColor[
             0.20966330069407968`, 0.3376998008234987, 0.9352513868542458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 306}], {
             RGBColor[
             0.21718838977102684`, 0.3456091465615747, 0.9356799295448063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 353}], {
             RGBColor[
             0.2108426436010009, 0.33893936499333205`, 0.9353185486881135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 361}], {
             RGBColor[
             0.22465020382752957`, 0.3534519862412956, 0.9361048688165594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 299}], {
             RGBColor[
             0.18831247292825637`, 0.31525872712095093`, 0.9340354887987012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 306}], {
             RGBColor[
             0.19583756200520352`, 0.3231680728590269, 0.9344640314892618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 342}], {
             RGBColor[
             0.18633859981298379`, 0.3131840613260155, 0.9339230796448701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 353}], {
             RGBColor[
             0.1894918158351776, 0.3164982912907842, 0.9341026506325689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 208}], {
             RGBColor[
             0.9084092508392714, 0.5876736275457447, 0.4679228968183917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 225}], {
             RGBColor[
             0.8542567503473041, 0.5474377891348923, 0.5796464760848401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 240}], {
             RGBColor[
             0.8277460748309535, 0.21427406632403376`, 0.17420297863381767`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 243}], {
             RGBColor[
             0.8966647112599999, 0.5803804357819402, 0.5534478412456459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 285}], {
             RGBColor[
             0.9090011322761398, 0.5869841292419617, 0.39020330546201376`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 337}], {
             RGBColor[
             0.9089250228286312, 0.5868213388295864, 0.3819192617937752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 357}], {
             RGBColor[
             0.8404518577056951, 0.3119362812088553, 0.18637005066379952`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 399}], {
             RGBColor[
             0.8751896442741957, 0.46528659439177383`, 0.21510344124823602`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 176}], {
             RGBColor[
             0.25807437232061936`, 0.38858290654221544`, 0.9380083257656147]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 209}], {
             RGBColor[
             0.3086611648699239, 0.43934003290171275`, 0.940977513192154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 250}], {
             RGBColor[
             0.27041365894161523`, 0.40155227913684066`, 0.9387110298843417]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 323}], {
             RGBColor[
             0.3405854460382354, 0.4669912406886779, 0.9430117001586653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 354}], {
             RGBColor[
             0.24916626557073213`, 0.3792199215414943, 0.9375010222645717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 388}], {
             RGBColor[
             0.2509970167086373, 0.38114415706375904`, 0.9376052808335218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 183}], {
             RGBColor[
             0.34699168167192995`, 0.474968487180372, 0.943330981016807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 189}], {
             RGBColor[
             0.3053198459534695, 0.4349817492014926, 0.9408182188837021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 238}], {
             RGBColor[
             0.3169893195658634, 0.44724710585547944`, 0.9414827781424888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 246}], {
             RGBColor[
             0.6321209059841302, 0.7058084285457353, 0.96769757273425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 269}], {
             RGBColor[
             0.543788980551822, 0.6359924818491485, 0.9591085205776222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 272}], {
             RGBColor[
             0.5424648698288314, 0.6349580764887339, 0.9589765455952728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 309}], {
             RGBColor[
             0.32079650085916334`, 0.45124869478397367`, 0.9416995914849222]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 325}], {
             RGBColor[
             0.31656779052141654`, 0.4468040521032807, 0.9414587726870038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 395}], {
             RGBColor[
             0.4063176896518592, 0.5259376945387678, 0.9472261235324917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 178}], {
             RGBColor[
             0.3616708025324146, 0.48517771913218966`, 0.9443580450417194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 213}], {
             RGBColor[
             0.25213492118930436`, 0.3823401668202513, 0.9376700828103168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 227}], {
             RGBColor[
             0.24456047357150879`, 0.37437894212623135`, 0.9372387292238745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 278}], {
             RGBColor[
             0.2699086210585896, 0.40102145230052944`, 0.93868226872404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 296}], {
             RGBColor[
             0.26330595896968834`, 0.39408163581213873`, 0.9383062568858402]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 314}], {
             RGBColor[
             0.25716282410855407`, 0.38762481157584006`, 0.9379564144434523]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 319}], {
             RGBColor[
             0.3675065660796395, 0.49023117564208835`, 0.944730223137449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 352}], {
             RGBColor[
             0.2606268889022622, 0.3912657633084208, 0.9381536878088295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 250}], {
             RGBColor[
             0.24600820440775967`, 0.3759005990265677, 0.9373211753532731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 344}], {
             RGBColor[
             0.21245918803275743`, 0.3406384556859449, 0.9354106085020388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 354}], {
             RGBColor[
             0.22476081103687653`, 0.35356824143122134`, 0.936111167733503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 356}], {
             RGBColor[
             0.21433034444536764`, 0.34260515971376704`, 0.9355171680916091]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 372}], {
             RGBColor[
             0.2138686325253813, 0.34211987121163484`, 0.9354908742808075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 388}], {
             RGBColor[
             0.22659156217478169`, 0.35549247695348607`, 0.9362154263024531]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 197}], {
             RGBColor[
             0.9295820155952076, 0.9459496447868232, 0.9675642537426303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 225}], {
             RGBColor[
             0.8897813970600477, 0.9149515498158103, 0.9893493380404593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 243}], {
             RGBColor[
             0.9321893579727436, 0.9478941964628581, 0.9631507032012652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 252}], {
             RGBColor[
             0.6322093663988135, 0.7067582685174405, 0.9673012182198607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 300}], {
             RGBColor[
             0.904775992937191, 0.9269078335507821, 0.990779535981055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 337}], {
             RGBColor[
             0.9444496695413749, 0.9543350995105044, 0.7916221237493946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 367}], {
             RGBColor[
             0.6349673392184779, 0.7091470859540894, 0.9674769538091501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 398}], {
             RGBColor[
             0.6604733814795012, 0.7312391377896288, 0.9691021762679148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 197}], {
             RGBColor[
             0.7030008791274289, 0.7649478943931832, 0.947330285544383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 274}], {
             RGBColor[
             0.46738436670940764`, 0.5781669894131862, 0.9513005905019778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 278}], {
             RGBColor[
             0.349928065209785, 0.47283535767355744`, 0.9436893135230188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 300}], {
             RGBColor[
             0.6781948564694122, 0.7459060831571422, 0.9705455677828076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 319}], {
             RGBColor[
             0.4475260102308348, 0.5620450810151163, 0.9497372679364278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 352}], {
             RGBColor[
             0.3406463330534576, 0.4630796686814488, 0.9431607326078082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 232}], {
             RGBColor[
             0.374520452238133, 0.49753308772821003`, 0.9451360369712756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 257}], {
             RGBColor[
             0.38852623515624984`, 0.5109265218154098, 0.9459822530302189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 275}], {
             RGBColor[
             0.34634920232824207`, 0.46792331791250663`, 0.9435317259645368]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 279}], {
             RGBColor[
             0.5630911384213583, 0.6557241290001397, 0.9590606413690353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 285}], {
             RGBColor[
             0.7240735565365042, 0.7787875887954807, 0.7800674551938157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 288}], {
             RGBColor[
             0.3796596294696894, 0.502934688841232, 0.9454287055118813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 399}], {
             RGBColor[
             0.6902620685345601, 0.6570900539452929, 0.6049675909800379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 198}], {
             RGBColor[
             0.30592577418738304`, 0.43475768207038135`, 0.9408842486890967]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 236}], {
             RGBColor[
             0.2546593406268537, 0.3849934917065525, 0.9378138447627414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 262}], {
             RGBColor[
             0.23634740435871976`, 0.36574648564492557`, 0.9367710070823533]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 267}], {
             RGBColor[
             0.25726504669656514`, 0.3877322539971262, 0.9379622358686148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 284}], {
             RGBColor[
             0.2675710150211928, 0.3985644801424423, 0.9385491455183885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 286}], {
             RGBColor[
             0.22669434503393948`, 0.3556005082552706, 0.9362212796342286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 332}], {
             RGBColor[
             0.2434440031568898, 0.373205460932154, 0.937175147885432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 367}], {
             RGBColor[
             0.31681274319178854`, 0.44418742742702483`, 0.9415779567270888]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 398}], {
             RGBColor[
             0.3423187854528118, 0.46627947926256413`, 0.9432031791858535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 191}], {
             RGBColor[
             0.2010737277844803, 0.3286716150851321, 0.9347622233841785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 211}], {
             RGBColor[
             0.20840661341018846`, 0.33637894280955327`, 0.9351798203725303]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 214}], {
             RGBColor[
             0.21733436721625865`, 0.34576257811201794`, 0.9356882427443579]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 305}], {
             RGBColor[
             0.18857843384879308`, 0.3155382689113313, 0.9340506348796719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 334}], {
             RGBColor[
             0.18995231521735206`, 0.3169823053387968, 0.934128875391136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 340}], {
             RGBColor[
             0.19892920598511726`, 0.3264175867034662, 0.9346400960402405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 365}], {
             RGBColor[
             0.1879270858801807, 0.3148536608984732, 0.9340135415764423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 370}], {
             RGBColor[
             0.19100569805155482`, 0.318089477485873, 0.9341888639852036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 256}], {
             RGBColor[
             0.34992025301800456`, 0.4775050684860661, 0.9435175869933449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 281}], {
             RGBColor[
             0.38860982761707186`, 0.5110160334092172, 0.94598285247495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 311}], {
             RGBColor[
             0.32563786800336725`, 0.45591796242171545`, 0.9419906534014555]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 386}], {
             RGBColor[
             0.5546461678159978, 0.6446668165900299, 0.9601091386691207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 238}], {
             RGBColor[
             0.31998454354214334`, 0.4498414183193987, 0.9416736311656848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 246}], {
             RGBColor[
             0.63511612996041, 0.7084027410096546, 0.967888425757446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 269}], {
             RGBColor[
             0.546784204528102, 0.6385867943130678, 0.9592993736008182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 272}], {
             RGBColor[
             0.5454600938051113, 0.6375523889526532, 0.9591673986184688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 280}], {
             RGBColor[
             0.30076148412422865`, 0.4296367640588081, 0.9405789063698025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 309}], {
             RGBColor[
             0.3237917248354433, 0.45384300724789295`, 0.9418904445081182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 325}], {
             RGBColor[
             0.3195630144976964, 0.44939836456720006`, 0.9416496257101998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 339}], {
             RGBColor[
             0.30076734139659483`, 0.42964292042343744`, 0.9405792399327987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 395}], {
             RGBColor[
             0.40931291362813915`, 0.5285320070026871, 0.9474169765556877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 343}], {
             RGBColor[
             0.18256566753029357`, 0.30921847027918486`, 0.933708216732924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 356}], {
             RGBColor[
             0.18905111217950674`, 0.3160350838064485, 0.9340775532113412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 369}], {
             RGBColor[
             0.1868540625349533, 0.3137258453290297, 0.9339524344843275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 372}], {
             RGBColor[
             0.18858940025952037`, 0.31554979530431626`, 0.9340512594005395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 198}], {
             RGBColor[
             0.3764542800383526, 0.5004875090521163, 0.9452083117319626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 205}], {
             RGBColor[
             0.3748090292582385, 0.49906247551909, 0.9451034778070919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 208}], {
             RGBColor[
             0.6963078073762952, 0.755957556681333, 0.8560508247348155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 210}], {
             RGBColor[
             0.35262704416750634`, 0.4795636552057607, 0.9437005295213796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 219}], {
             RGBColor[
             0.36836286362019555`, 0.4934791308371227, 0.9446927338327562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 249}], {
             RGBColor[
             0.35433837255967027`, 0.48133182157191207`, 0.9437991056637501]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 284}], {
             RGBColor[
             0.33809952087216233`, 0.4642943071241772, 0.9428732085612545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 293}], {
             RGBColor[
             0.374247320413842, 0.49857595155038115`, 0.9450676862162266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 338}], {
             RGBColor[
             0.3169003211264983, 0.4420126040845884, 0.9416659454971446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 188}], {
             RGBColor[
             0.20431810644449144`, 0.33208166276229184`, 0.934946985949238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 228}], {
             RGBColor[
             0.20522346006975262`, 0.3330332468251766, 0.934998544498846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 238}], {
             RGBColor[
             0.24841689496046435`, 0.37843228551726205`, 0.9374583467169113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 273}], {
             RGBColor[
             0.19433831903215518`, 0.3215922734368583, 0.9343786518198778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 322}], {
             RGBColor[
             0.20337835674212623`, 0.3310939262415335, 0.9348934685939234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 330}], {
             RGBColor[
             0.19639093276449526`, 0.3237497006127751, 0.9344955451353647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 206}], {
             RGBColor[
             0.5826167692195937, 0.6701866792756657, 0.9613440852325792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 220}], {
             RGBColor[
             0.5353714211663698, 0.63317812373389, 0.9567035702854296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 261}], {
             RGBColor[
             0.3474451829775207, 0.4708516166188276, 0.9435249988507737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 321}], {
             RGBColor[
             0.494640933100008, 0.6001112786340405, 0.9534971170641517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 228}], {
             RGBColor[
             0.20268995802939208`, 0.3303703755474506, 0.9348542653056278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 238}], {
             RGBColor[
             0.2458833929201038, 0.375769414239536, 0.9373140675236933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 273}], {
             RGBColor[
             0.19180481699179464`, 0.3189294021591323, 0.9342343726266598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 322}], {
             RGBColor[
             0.20084485470176572`, 0.3284310549638075, 0.9347491894007052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 330}], {
             RGBColor[
             0.19385743072413472`, 0.32108682933504906`, 0.9343512659421467]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 222}], {
             RGBColor[
             0.24951462814212214`, 0.379586072691488, 0.937520860997656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 226}], {
             RGBColor[
             0.35594179006458193`, 0.47882793285764735`, 0.9440438043992346]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 395}], {
             RGBColor[
             0.3676410779096787, 0.4885452690238077, 0.9449042144225828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 212}], {
             RGBColor[
             0.6867778683351773, 0.7513832913392242, 0.9534033725466657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 221}], {
             RGBColor[
             0.9292638455200164, 0.8080779972178733, 0.5995947563336426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 255}], {
             RGBColor[
             0.8957903553105804, 0.6198388885195696, 0.570244438982581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 268}], {
             RGBColor[
             0.8177911045280821, 0.8581558703042615, 0.9638348308947651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 270}], {
             RGBColor[
             0.6576592800193992, 0.7261622336829004, 0.951547961847741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 274}], {
             RGBColor[
             0.7246489008143902, 0.7831056857849257, 0.9561147753018562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 295}], {
             RGBColor[
             0.6926270864337125, 0.7564495900659256, 0.953776079551644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 324}], {
             RGBColor[
             0.7946744730052755, 0.8399555999055638, 0.9616274448568455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 351}], {
             RGBColor[
             0.9330043693197932, 0.948887212220239, 0.9751255904637988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 211}], {
             RGBColor[
             0.2145566630341047, 0.342843034899957, 0.9355300566004294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 214}], {
             RGBColor[
             0.2234844168401749, 0.3522266702024217, 0.9360384789722569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 312}], {
             RGBColor[
             0.25506639270437426`, 0.3854213292486189, 0.9378370257763766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 334}], {
             RGBColor[
             0.1961023648412683, 0.3234463974292005, 0.934479111619035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 340}], {
             RGBColor[
             0.2050792556090335, 0.33288167879387, 0.9349903322681394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 365}], {
             RGBColor[
             0.19407713550409694`, 0.321317752988877, 0.9343637778043414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 370}], {
             RGBColor[
             0.19715574767547106`, 0.3245535695762768, 0.9345391002131025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 292}], {
             RGBColor[
             0.18800332047098128`, 0.31493378828695684`, 0.9340178830236096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 320}], {
             RGBColor[
             0.18870690253434044`, 0.31567329764522667`, 0.9340579509812614]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 347}], {
             RGBColor[
             0.18973620095672017`, 0.3167551555484371, 0.9341165680037053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 374}], {
             RGBColor[
             0.18592011737534742`, 0.3127442097507407, 0.933899247689136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 382}], {
             RGBColor[
             0.18175632170203998`, 0.30836779649820095`, 0.9336621256853248]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 384}], {
             RGBColor[
             0.1855895073220066, 0.3123967176227914, 0.933880419935692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 248}], {
             RGBColor[
             0.20247189401375032`, 0.330141176440954, 0.9348418468825339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 305}], {
             RGBColor[
             0.18458905889423072`, 0.311345182893105, 0.933823445877761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 334}], {
             RGBColor[
             0.1859629402627897, 0.3127892193205704, 0.9339016863892251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 360}], {
             RGBColor[
             0.18609708652812662`, 0.31293021555080397`, 0.9339093258205844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 201}], {
             RGBColor[
             0.9717877162352071, 0.9761148093624215, 0.8086618740541351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 208}], {
             RGBColor[
             0.9937734715667986, 0.9910458830658546, 0.7058012226950569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 223}], {
             RGBColor[
             0.9622169086067585, 0.8752522636294204, 0.4543198910461633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 230}], {
             RGBColor[
             0.906134992146644, 0.5640310832233217, 0.4054017460858296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 242}], {
             RGBColor[
             0.9234025469352043, 0.6967570760189528, 0.42193717605226866`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 357}], {
             RGBColor[
             0.9258160784332223, 0.7153085367289651, 0.42424837654046466`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 364}], {
             RGBColor[
             0.9061043939482173, 0.5637958920619978, 0.4053724452164604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 385}], {
             RGBColor[
             0.9944784929138155, 0.9905983795896796, 0.6403962123397537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 387}], {
             RGBColor[
             0.7643288542489235, 0.8116893614464729, 0.8013257295322668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 247}], {
             RGBColor[
             0.1997381438211963, 0.32726783165880646`, 0.9346861638532888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 253}], {
             RGBColor[
             0.1964706167173933, 0.3238334534995253, 0.9345000830186004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 315}], {
             RGBColor[
             0.21034714004508412`, 0.3384185593393235, 0.9352903304936357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 316}], {
             RGBColor[
             0.21810104707830674`, 0.3465684072573414, 0.9357319040283003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 343}], {
             RGBColor[
             0.19193458883998876`, 0.3190658005995948, 0.9342417629414341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 358}], {
             RGBColor[
             0.1963120650172806, 0.3236668056099485, 0.9344910537338352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 359}], {
             RGBColor[
             0.19452611281546262`, 0.321789656609928, 0.9343893463980213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 362}], {
             RGBColor[
             0.1955066853579723, 0.3228203005239958, 0.9344451885536901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 363}], {
             RGBColor[
             0.21087458530257291`, 0.33897293774690507`, 0.9353203677207644]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 369}], {
             RGBColor[
             0.19622298384464848`, 0.3235731756494396, 0.9344859806928376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 372}], {
             RGBColor[
             0.19795832156921558`, 0.32539712562472617`, 0.9345848056090496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 397}], {
             RGBColor[
             0.2073858256728759, 0.33530603017595706`, 0.9351216880210106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 289}], {
             RGBColor[
             0.18795157808443957`, 0.3148794037580448, 0.934014936371242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 317}], {
             RGBColor[
             0.1925447584771704, 0.3197071275752621, 0.9342765111996065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 326}], {
             RGBColor[
             0.19087356510240117`, 0.3179505973785997, 0.9341813392092224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 327}], {
             RGBColor[
             0.19267128104236286`, 0.3198401108132733, 0.9342837164725208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 336}], {
             RGBColor[
             0.18504438325654066`, 0.31182375766712467`, 0.9338493759266024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 376}], {
             RGBColor[
             0.19966869054902864`, 0.32719483186616644`, 0.9346822085921858]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 252}], {
             RGBColor[
             0.6669388623748537, 0.7337127880117662, 0.9450324457252983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 300}], {
             RGBColor[
             0.9395054889132312, 0.9538623530451078, 0.9685107634864926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 205}], {
             RGBColor[
             0.35166297002886326`, 0.47901452236936815`, 0.9436286313802527]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 219}], {
             RGBColor[
             0.34521680439082036`, 0.47343117768740084`, 0.9432178874059169]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 236}], {
             RGBColor[
             0.3020417872484481, 0.43067536553856556`, 0.9406630613787681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 284}], {
             RGBColor[
             0.31495346164278715`, 0.44424635397445533`, 0.9413983621344152]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 332}], {
             RGBColor[
             0.29082644977848415`, 0.41888733476416706`, 0.9400243645014585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 367}], {
             RGBColor[
             0.36419518981338295`, 0.4898693012590379, 0.9444271733431154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 398}], {
             RGBColor[
             0.38970123207440616`, 0.5119613530945772, 0.9460523958018803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 216}], {
             RGBColor[
             0.19310022590756143`, 0.3202909590632723, 0.9343081442480269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 298}], {
             RGBColor[
             0.19174373818706897`, 0.31886520446274574`, 0.9342308942790887]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 299}], {
             RGBColor[
             0.18707599573729403`, 0.31395911119606756`, 0.93396507325188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 306}], {
             RGBColor[
             0.19460108481424115`, 0.32186845693414357`, 0.9343936159424405]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 342}], {
             RGBColor[
             0.18510212262202141`, 0.31188444540113214`, 0.9338526640980489]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 353}], {
             RGBColor[
             0.18825533864421526`, 0.31519867536590085`, 0.9340322350857477]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 361}], {
             RGBColor[
             0.2020628988707439, 0.32971129661386445`, 0.9348185552141937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 393}], {
             RGBColor[
             0.1849265278957996, 0.3116998842105244, 0.9338426642381596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 207}], {
             RGBColor[
             0.1859857863076916, 0.31281323196228517`, 0.9339029874376845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 333}], {
             RGBColor[
             0.18616349406283006`, 0.3130000140802582, 0.9339131076314446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 368}], {
             RGBColor[
             0.18469320535133593`, 0.3114546474227893, 0.9338293768644222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 223}], {
             RGBColor[
             0.9394729571932308, 0.8606549580209606, 0.6167978110210142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 230}], {
             RGBColor[
             0.8833910407331164, 0.5494337776148619, 0.5678796660606804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 245}], {
             RGBColor[
             0.8839369101698967, 0.553629569307468, 0.5684023912498125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 364}], {
             RGBColor[
             0.8833604425346897, 0.5491985864535379, 0.5678503651913112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 385}], {
             RGBColor[
             0.9717345415002878, 0.9760010739812197, 0.8028741323146045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 218}], {
             RGBColor[
             0.2171099632633392, 0.3455267153294672, 0.9356754632712151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 229}], {
             RGBColor[
             0.22512118954774685`, 0.35394702209546336`, 0.9361316907565649]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 260}], {
             RGBColor[
             0.23397057730885262`, 0.3632482897159762, 0.9366356502980638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 307}], {
             RGBColor[
             0.295856931076972, 0.42463269426460054`, 0.9402940731736436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 341}], {
             RGBColor[
             0.2897972028384973, 0.4193840622352309, 0.9399079526486953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 349}], {
             RGBColor[
             0.22267250403179975`, 0.35137329836257414`, 0.9359922417389372]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 366}], {
             RGBColor[
             0.31887937893336776`, 0.4445735814559359, 0.9417610431931018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 232}], {
             RGBColor[
             0.26042493590475796`, 0.3910534979034842, 0.9381421868843842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 257}], {
             RGBColor[
             0.27443071882287484`, 0.40444693199068393`, 0.9389884029433275]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 275}], {
             RGBColor[
             0.232253685994867, 0.3614437280877808, 0.9365378758776455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 280}], {
             RGBColor[
             0.23864655232395315`, 0.36816303593078636`, 0.9369019401576887]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 297}], {
             RGBColor[
             0.2163387830881471, 0.3447161560696932, 0.9356315457010966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 309}], {
             RGBColor[
             0.2616767930351678, 0.3923692791198713, 0.9382134782960043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 322}], {
             RGBColor[
             0.2128310735235297, 0.3410293309156486, 0.935431786830583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 325}], {
             RGBColor[
             0.2574480826974209, 0.38792463643917835`, 0.9379726594980861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 339}], {
             RGBColor[
             0.23865240959631934`, 0.3681691922954158, 0.9369022737206849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 224}], {
             RGBColor[
             0.1864844568543232, 0.3133373663243338, 0.9339313859875982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 276}], {
             RGBColor[
             0.2082458481435212, 0.33620996832117933`, 0.9351706650284246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 290}], {
             RGBColor[
             0.19592590704111568`, 0.32326092909316934`, 0.9344690626083623]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 297}], {
             RGBColor[
             0.2002775476373886, 0.32783477926980176`, 0.9347168821026446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 318}], {
             RGBColor[
             0.1940125074344074, 0.321249824789977, 0.9343600973313813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 345}], {
             RGBColor[
             0.18631088399028722`, 0.3131549302390768, 0.9339215012697695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 219}], {
             RGBColor[
             0.34357155361070624`, 0.4720061441543746, 0.9431130534810463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 284}], {
             RGBColor[
             0.313308210862673, 0.4428213204414291, 0.9412935282095445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 293}], {
             RGBColor[
             0.3494560104043527, 0.47710296486763304`, 0.9434880058645166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 338}], {
             RGBColor[
             0.292109011117009, 0.4205396174018403, 0.9400862651454345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 220}], {
             RGBColor[
             0.6830678662474279, 0.7522369451466808, 0.9691139391554754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 321}], {
             RGBColor[
             0.6423373781810662, 0.7191701000468311, 0.9659074859341975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 328}], {
             RGBColor[
             0.7999219852902167, 0.6448484807342735, 0.5933000289298582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 386}], {
             RGBColor[
             0.7455369138645886, 0.8011383704922057, 0.975271810201597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 254}], {
             RGBColor[
             0.18750231875154622`, 0.3144072037144869, 0.9339893517168534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 333}], {
             RGBColor[
             0.18793493502051017`, 0.3148619108426237, 0.9340139885733725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 230}], {
             RGBColor[
             0.9053767960647079, 0.5643648513182951, 0.465019014701602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 240}], {
             RGBColor[
             0.9123520994765446, 0.6179800899391169, 0.47169857312625524`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 242}], {
             RGBColor[
             0.9226443508532682, 0.6970908441139261, 0.4815544446680411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 357}], {
             RGBColor[
             0.9250578823512863, 0.7156423048239384, 0.4838656451562371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 385}], {
             RGBColor[
             0.9937202968318795, 0.9909321476846529, 0.7000134809555262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 387}], {
             RGBColor[
             0.7635706581669874, 0.8120231295414462, 0.8609429981480392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 241}], {
             RGBColor[
             0.2990278699570904, 0.4292148291621499, 0.9404289112980508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 270}], {
             RGBColor[
             0.34697087401529814`, 0.4749504646340207, 0.9433296551713259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 310}], {
             RGBColor[
             0.30722079620017617`, 0.4378261141051596, 0.9408954863272463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 323}], {
             RGBColor[
             0.36676678405368435`, 0.4920966869379023, 0.9445910330541359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 346}], {
             RGBColor[
             0.34295446203942725`, 0.47147165045125694`, 0.9430737329517971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 390}], {
             RGBColor[
             0.2987767120225358, 0.42895084624860025`, 0.9404146082252327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 249}], {
             RGBColor[
             0.3073650774594488, 0.4403600145758346, 0.9408164770263279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 266}], {
             RGBColor[
             0.26920304414348, 0.40027984622658896`, 0.9386420871625321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 293}], {
             RGBColor[
             0.3272740253136205, 0.45760414455430376`, 0.9420850575788042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 315}], {
             RGBColor[
             0.26224986664151034`, 0.39297161581510254`, 0.9382461139900993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 316}], {
             RGBColor[
             0.270003773674733, 0.40112146373312046`, 0.9386876875247638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 387}], {
             RGBColor[
             0.4198898949581986, 0.5356292280658739, 0.9485927029346032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 397}], {
             RGBColor[
             0.25928855226930214`, 0.38985908665173613`, 0.938077471517474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 214}], {
             RGBColor[
             0.23081730246588306`, 0.35993399792684283`, 0.9364560759606089]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 248}], {
             RGBColor[
             0.2199442042179371, 0.34850568227400514`, 0.9358368691006957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 263}], {
             RGBColor[
             0.30692109574993276`, 0.4322308872824815, 0.9410717536469021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 312}], {
             RGBColor[
             0.26239927833008236`, 0.39312865697304, 0.9382546227647286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 334}], {
             RGBColor[
             0.20343525046697647`, 0.3311537251536216, 0.9348967086073869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 340}], {
             RGBColor[
             0.21241214123474167`, 0.34058900651829105`, 0.9354079292564914]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 370}], {
             RGBColor[
             0.20448863330117922`, 0.3322608973006979, 0.9349566972014545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 268}], {
             RGBColor[
             0.5483496579696843, 0.6426701443947892, 0.9582447440009759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 270}], {
             RGBColor[
             0.38821783346100136`, 0.5106765077734281, 0.9459578749539519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 274}], {
             RGBColor[
             0.45520745425599235`, 0.5676199598754534, 0.950524688408067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 295}], {
             RGBColor[
             0.42318563987531466`, 0.5409638641564534, 0.9481859926578549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 310}], {
             RGBColor[
             0.34846775564587945`, 0.473552157244567, 0.9435237061098725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 324}], {
             RGBColor[
             0.5252330264468776, 0.6244698739960914, 0.9560373579630563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 351}], {
             RGBColor[
             0.6635629227613954, 0.7334014863107667, 0.9695355035700097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 373}], {
             RGBColor[
             0.34459378761093823`, 0.4694803712160838, 0.9433030893613046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 390}], {
             RGBColor[
             0.3400236714682391, 0.46467688938800766`, 0.9430428280078589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 227}], {
             RGBColor[
             0.2150440363795939, 0.343355295187321, 0.9355578117914507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 296}], {
             RGBColor[
             0.2337895217777734, 0.3630579888732283, 0.9366253394534165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 308}], {
             RGBColor[
             0.2120594900785835, 0.3402183477937941, 0.9353878462948488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 352}], {
             RGBColor[
             0.23111045171034733`, 0.3602421163695104, 0.9364727703764056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 248}], {
             RGBColor[
             0.22887195802400728`, 0.3578893175764699, 0.9363452914725232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 263}], {
             RGBColor[
             0.315848849556003, 0.4416145225849462, 0.9415801760187297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 312}], {
             RGBColor[
             0.2713270321361526, 0.4025122922755047, 0.9387630451365561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 340}], {
             RGBColor[
             0.22133989504081186`, 0.3499726418207558, 0.9359163516283189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 218}], {
             RGBColor[
             0.18692850160935742`, 0.31380408551593836`, 0.9339566736794921]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 229}], {
             RGBColor[
             0.19493972789376507`, 0.3222243922819345, 0.9344129011648419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 329}], {
             RGBColor[
             0.1867198905000643, 0.313584822013363, 0.9339447935854304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 349}], {
             RGBColor[
             0.192491042377818, 0.3196506685490453, 0.9342734521472142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 231}], {
             RGBColor[
             0.19095180161373265`, 0.3180328289124904, 0.9341857946628023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 235}], {
             RGBColor[
             0.1956123156574894, 0.32293132466613605`, 0.9344512040429815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 298}], {
             RGBColor[
             0.19835416070020614`, 0.3258131776490477, 0.9346073480619681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 313}], {
             RGBColor[
             0.2090389311379428, 0.3370435488326826, 0.9352158299316957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 361}], {
             RGBColor[
             0.20867332138388106`, 0.3366592698001664, 0.9351950089970731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 393}], {
             RGBColor[
             0.19153695040893678`, 0.31864785739682644`, 0.9342191180210391]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 396}], {
             RGBColor[
             0.19963425463605258`, 0.3271586375382656, 0.9346802475178853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 220}], {
             RGBColor[
             0.8144460532518553, 0.851406632354037, 0.7257595325601884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 230}], {
             RGBColor[
             0.9054039524770299, 0.5624674632894656, 0.3258325895022128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 233}], {
             RGBColor[
             0.9762379710154455, 0.9784153903456743, 0.7203221374649382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 242}], {
             RGBColor[
             0.9226715072655902, 0.6951934560850966, 0.34236801946865186`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 244}], {
             RGBColor[
             0.9739175055905028, 0.9766847910311653, 0.7242500801550553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 264}], {
             RGBColor[
             0.8581806271651595, 0.8856725444548357, 0.7300501263511203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 321}], {
             RGBColor[
             0.7737155651854934, 0.8183397872541874, 0.7225530793389106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 357}], {
             RGBColor[
             0.9250850387636083, 0.713744916795109, 0.34467921995684786`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 364}], {
             RGBColor[
             0.9053733542786032, 0.5622322721281416, 0.3258032886328436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 366}], {
             RGBColor[
             0.6937344954214235, 0.7518077736561808, 0.7166986999905727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 229}], {
             RGBColor[
             0.19887179747769093`, 0.3263572467222515, 0.9346368267106708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 260}], {
             RGBColor[
             0.20772118523879674`, 0.3356585143427644, 0.9351407862521698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 329}], {
             RGBColor[
             0.19065196008399016`, 0.31771767645368004`, 0.9341687191312593]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 349}], {
             RGBColor[
             0.19642311196174383`, 0.3237835229893623, 0.9344973776930432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 284}], {
             RGBColor[
             0.3068620452246301, 0.43723797575946177`, 0.9408827842352088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 293}], {
             RGBColor[
             0.34300984476630975`, 0.47151962018566573`, 0.943077261890181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 338}], {
             RGBColor[
             0.28566284547896603`, 0.414956272719873, 0.9396755211710989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 233}], {
             RGBColor[
             0.7976144359577942, 0.8422371475965424, 0.9590360291130758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 244}], {
             RGBColor[
             0.7952939705328516, 0.8405065482820335, 0.9629639718031929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 321}], {
             RGBColor[
             0.5950920301278422, 0.6821615445050555, 0.961266970987048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 341}], {
             RGBColor[
             0.4860287842689018, 0.590440011686344, 0.9535595010943037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 366}], {
             RGBColor[
             0.5151109603637722, 0.615629530907049, 0.9554125916387102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 239}], {
             RGBColor[
             0.8650356462249088, 0.43184524722399015`, 0.20720757963682196`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 255}], {
             RGBColor[
             0.8688348859370216, 0.46104786848874635`, 0.21084573587576866`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 268}], {
             RGBColor[
             0.7908356351545234, 0.6993648502734382, 0.6044361277879526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 324}], {
             RGBColor[
             0.7677190036317167, 0.6811645798747406, 0.602228741750033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 351}], {
             RGBColor[
             0.9060488999462345, 0.7900961921894157, 0.6157268873569864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 400}], {
             RGBColor[
             0.8762434284382803, 0.5179931725974458, 0.21794016454172604`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 333}], {
             RGBColor[
             0.21024933242430197`, 0.33831575732852015`, 0.9352847604943257]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 230}], {
             RGBColor[
             0.8738202331046678, 0.44857123188186093`, 0.21353768305270848`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 242}], {
             RGBColor[
             0.8910877878932282, 0.5812972246774919, 0.23007311301914762`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 245}], {
             RGBColor[
             0.8743661025414482, 0.452767023574467, 0.2140604082418407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 328}], {
             RGBColor[
             0.8997164529222819, 0.6301219365340252, 0.23765071588506692`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 364}], {
             RGBColor[
             0.8737896349062411, 0.4483360407205369, 0.2135083821833393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 385}], {
             RGBColor[
             0.9621637338718393, 0.8751385282482187, 0.44853214930663265`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 290}], {
             RGBColor[
             0.18877579274929696`, 0.3157457056290379, 0.9340618741770893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 318}], {
             RGBColor[
             0.18686239314258873`, 0.3137346013258456, 0.9339529089001083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 345}], {
             RGBColor[
             0.17916076969846856`, 0.3056397067749454, 0.9335143128384965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 240}], {
             RGBColor[
             0.8581995989845774, 0.5777442515282645, 0.5834221523927036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 243}], {
             RGBColor[
             0.9271182354136238, 0.9438506209861709, 0.9626670150045318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 337}], {
             RGBColor[
             0.9393785469822551, 0.9502915240338172, 0.7911384355526612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 367}], {
             RGBColor[
             0.6298962166593582, 0.7051035104774022, 0.9669932656124167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 398}], {
             RGBColor[
             0.6554022589203814, 0.7271955623129416, 0.9686184880711814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 234}], {
             RGBColor[
             0.6154815427973135, 0.6962991925345092, 0.964434228392668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 281}], {
             RGBColor[
             0.43696413947427415`, 0.552898107981546, 0.9490639464684518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 350}], {
             RGBColor[
             0.7195454075725961, 0.7758957836327975, 0.8505842343054555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 355}], {
             RGBColor[
             0.6054737407452027, 0.6884810215092875, 0.963436744212341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 392}], {
             RGBColor[
             0.7181621296927883, 0.7753237626808771, 0.8735087285822702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 395}], {
             RGBColor[
             0.45693963376297164`, 0.5697838781949226, 0.9504517090480242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 296}], {
             RGBColor[
             0.22621507415997788`, 0.35509676417920844`, 0.9361939858669741]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 308}], {
             RGBColor[
             0.20448504246078797`, 0.33225712309977423`, 0.9349564927084064]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 352}], {
             RGBColor[
             0.22353600409255178`, 0.3522808916754905, 0.9360414167899633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 375}], {
             RGBColor[
             0.1940331226429612, 0.32127149268124666`, 0.9343612713370109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 238}], {
             RGBColor[
             0.24678874654536498`, 0.3767209983024208, 0.9373656260733012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 273}], {
             RGBColor[
             0.1927101706170558, 0.31988098622201705`, 0.9342859311762677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 330}], {
             RGBColor[
             0.1947627843493959, 0.3220384133979338, 0.9344028244917546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 368}], {
             RGBColor[
             0.19438368850365684`, 0.3216399596279972, 0.9343812355441619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 260}], {
             RGBColor[
             0.21573241152320438`, 0.34407882110876054`, 0.9355970137375196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[
             0.1986631863683978, 0.3261379832196762, 0.934624946616609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 349}], {
             RGBColor[
             0.20443433824615148`, 0.33220382975535845`, 0.934953605178393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 233}], {
             RGBColor[
             0.8885723351829689, 0.5532979785319709, 0.5591090860551002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 242}], {
             RGBColor[
             0.8350058714331137, 0.2700760442713933, 0.18115496805881381`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 244}], {
             RGBColor[
             0.8862518697580262, 0.551567379217462, 0.5630370287452173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 245}], {
             RGBColor[
             0.8182841860813337, 0.14154584316836838`, 0.16514226328150688`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 328}], {
             RGBColor[
             0.8436345364621675, 0.31890075612792645`, 0.1887325709247331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 357}], {
             RGBColor[
             0.8374194029311317, 0.28862750498140566`, 0.18346616854700978`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 364}], {
             RGBColor[
             0.8177077184461266, 0.13711486031443826`, 0.16459023722300553`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 385}], {
             RGBColor[
             0.9060818174117249, 0.56391734784212, 0.3996140043462989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 235}], {
             RGBColor[
             0.18685346885052345`, 0.3137252213290522, 0.9339524006748775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 298}], {
             RGBColor[
             0.1895953138932402, 0.3166070743119639, 0.934108544693864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 336}], {
             RGBColor[
             0.1812731232878139, 0.3078599243283004, 0.9336346082504626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 393}], {
             RGBColor[
             0.18277810360197083`, 0.30944175405974256`, 0.933720314652935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 396}], {
             RGBColor[
             0.19087540782908663`, 0.31795253420118175`, 0.9341814441497811]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 257}], {
             RGBColor[
             0.30909861267997385`, 0.4408850865059202, 0.9409626882119364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 275}], {
             RGBColor[
             0.2669215798519661, 0.39788188260301705`, 0.9385121611462544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 279}], {
             RGBColor[
             0.48366351594508233`, 0.5856826936906501, 0.9540410765507529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 280}], {
             RGBColor[
             0.2733144461810522, 0.4046011904460226, 0.9388762254262976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 288}], {
             RGBColor[
             0.30023200699341346`, 0.43289325353174246`, 0.9404091406935988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 297}], {
             RGBColor[
             0.25100667694524614`, 0.38115431058492943`, 0.9376058309697055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 309}], {
             RGBColor[
             0.2963446868922668, 0.42880743363510754`, 0.9401877635646132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 325}], {
             RGBColor[
             0.29211597655452004`, 0.4243627909544146, 0.9399469447666949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 339}], {
             RGBColor[
             0.2733203034534184, 0.404607346810652, 0.9388765589892938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 242}], {
             RGBColor[
             0.9058398899715292, 0.686023971327602, 0.5756445160215393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 244}], {
             RGBColor[
             0.9570858882964418, 0.9675153062736708, 0.9575265767079428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 264}], {
             RGBColor[
             0.8413490098710985, 0.8765030596973409, 0.9633266229040078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 307}], {
             RGBColor[
             0.6538804302709667, 0.7226974017073509, 0.9485082265240019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 348}], {
             RGBColor[
             0.6462730001834412, 0.7161082281260901, 0.948023487805811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 357}], {
             RGBColor[
             0.9082534214695472, 0.7045754320376143, 0.5779557165097353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 366}], {
             RGBColor[
             0.6769028781273625, 0.7426382888986862, 0.9499751965434602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[
             0.8067428279900561, 0.5234676801505931, 0.5767481319037369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 246}], {
             RGBColor[
             0.8529840469746812, 0.885887262707637, 0.9857660876177745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 269}], {
             RGBColor[
             0.7646521215423732, 0.8160713160110501, 0.9771770354611466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 272}], {
             RGBColor[
             0.7633280108193825, 0.8150369106506357, 0.9770450604787972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 350}], {
             RGBColor[
             0.8897866044520348, 0.9121284341385445, 0.8654271636734474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 355}], {
             RGBColor[
             0.7757149376246414, 0.8247136720150343, 0.978279673580333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 392}], {
             RGBColor[
             0.888403326572227, 0.9115564131866241, 0.8883516579502622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 395}], {
             RGBColor[
             0.6271808306424103, 0.7060165287006694, 0.9652946384160161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 298}], {
             RGBColor[
             0.19425582793699694`, 0.3215055700656095, 0.9343739540740432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 313}], {
             RGBColor[
             0.2049405983747336, 0.3327359412492443, 0.9349824359437711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 317}], {
             RGBColor[
             0.19343401255220036`, 0.32064178999008336`, 0.934327152903646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 336}], {
             RGBColor[
             0.18593363733157064`, 0.312758420081946, 0.9339000176306419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 393}], {
             RGBColor[
             0.18743861764572758`, 0.31434024981338815`, 0.9339857240331143]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 396}], {
             RGBColor[
             0.19553592187284338`, 0.32285102995482734`, 0.9344468535299604]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 267}], {
             RGBColor[
             0.25338105975763014`, 0.38364993746531034`, 0.9377410485582862]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 284}], {
             RGBColor[
             0.26368702808225786`, 0.3944821636106265, 0.9383279582080599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 286}], {
             RGBColor[
             0.22281035809500455`, 0.3515181917234548, 0.9360000923239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 332}], {
             RGBColor[
             0.2395600162179548, 0.36912314440033817`, 0.9369539605751034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 367}], {
             RGBColor[
             0.3129287562528536, 0.440105110895209, 0.9413567694167602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 383}], {
             RGBColor[
             0.22956462143722656`, 0.3586173507411603, 0.9363847376292023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 398}], {
             RGBColor[
             0.3384347985138768, 0.4621971627307483, 0.9429819918755249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 251}], {
             RGBColor[
             0.19380336074719554`, 0.32102999836105145`, 0.9343481867369493]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 296}], {
             RGBColor[
             0.2211466738327187, 0.34976955408011773`, 0.935905347966363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 308}], {
             RGBColor[
             0.19941664213352878`, 0.3269299130006835, 0.9346678548077954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 380}], {
             RGBColor[
             0.20872851353399335`, 0.33671728024931885`, 0.9351981521083725]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 269}], {
             RGBColor[
             0.5167818424220354, 0.6108654129881752, 0.9574511707265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 272}], {
             RGBColor[
             0.5154577316990447, 0.6098310076277607, 0.9573191957441505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 280}], {
             RGBColor[
             0.2707591220181621, 0.40191538273391547`, 0.9387307034954844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 309}], {
             RGBColor[
             0.29378936272937667`, 0.4261216259230004, 0.9400422416338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 325}], {
             RGBColor[
             0.28956065239162987`, 0.42167698324230746`, 0.9398014228358818]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 339}], {
             RGBColor[
             0.27076497929052823`, 0.4019215390985449, 0.9387310370584805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 246}], {
             RGBColor[
             0.874004135287985, 0.576823099817974, 0.5832370617608514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 269}], {
             RGBColor[
             0.785672209855677, 0.5070071531213871, 0.5746480096042236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 272}], {
             RGBColor[
             0.7843480991326863, 0.5059727477609727, 0.5745160346218742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 350}], {
             RGBColor[
             0.9108066927653387, 0.6030642712488816, 0.46289813781652445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 355}], {
             RGBColor[
             0.7967350259379453, 0.5156495091253714, 0.57575064772341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 392}], {
             RGBColor[
             0.9094234148855309, 0.6024922502969611, 0.4858226320933391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 242}], {
             RGBColor[
             0.8419811748449504, 0.32369128289221516`, 0.18783452648346705`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 243}], {
             RGBColor[
             0.9006075598972731, 0.6106868981753124, 0.5572235175535094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 285}], {
             RGBColor[
             0.912943980913413, 0.617290591635334, 0.3939789817698772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 337}], {
             RGBColor[
             0.9128678714659045, 0.6171278012229586, 0.3856949381016387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 357}], {
             RGBColor[
             0.8443947063429684, 0.3422427436022275, 0.19014572697166301`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 399}], {
             RGBColor[
             0.879132492911469, 0.49559305678514604`, 0.2188791175560995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 270}], {
             RGBColor[
             0.31115624108701556`, 0.43971981464523346`, 0.9412017203817521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 310}], {
             RGBColor[
             0.2714061632718937, 0.40259546411637237`, 0.9387675515376726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 323}], {
             RGBColor[
             0.3309521511254019, 0.4568660369491151, 0.9424630982645621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 346}], {
             RGBColor[
             0.30713982911114474`, 0.4362410004624697, 0.9409457981622233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 389}], {
             RGBColor[
             0.23293094482355622`, 0.362155570057423, 0.9365764447660246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 390}], {
             RGBColor[
             0.2629620790942533, 0.393720196259813, 0.938286673435659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 244}], {
             RGBColor[
             0.9035194245465865, 0.684293372013093, 0.5795724587116564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 357}], {
             RGBColor[
             0.854686957719692, 0.4213534977770367, 0.2000015985134489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 364}], {
             RGBColor[
             0.8349752732346869, 0.2698408531100693, 0.18112566718944462`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 385}], {
             RGBColor[
             0.9233493722002852, 0.696643340637751, 0.416149434312738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 337}], {
             RGBColor[
             0.981786507894951, 0.983234170680865, 0.764939800713467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 367}], {
             RGBColor[
             0.6723041775720541, 0.7380461571244501, 0.9407946307732227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 398}], {
             RGBColor[
             0.6978102198330773, 0.7601382089599893, 0.9424198532319874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 264}], {
             RGBColor[
             0.8390285444461558, 0.8747724603828321, 0.9672545655941249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 307}], {
             RGBColor[
             0.651559964846024, 0.7209668023928419, 0.952436169214119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 321}], {
             RGBColor[
             0.7545634824664897, 0.8074397031821838, 0.959757518581915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 341}], {
             RGBColor[
             0.6455002366075493, 0.7157181703634723, 0.9520500486891706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 348}], {
             RGBColor[
             0.6439525347584986, 0.7143776288115813, 0.9519514304959281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 357}], {
             RGBColor[
             0.9059329560446046, 0.7028448327231054, 0.5818836591998524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 366}], {
             RGBColor[
             0.6745824127024198, 0.7409076895841773, 0.9539031392335773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 328}], {
             RGBColor[
             0.8441804058989478, 0.32309654782053254`, 0.18925529611386532`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 364}], {
             RGBColor[
             0.8182535878829069, 0.14131065200704435`, 0.16511296241213771`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 400}], {
             RGBColor[
             0.8345042681241085, 0.26622050143440795`, 0.18067463216363056`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 269}], {
             RGBColor[
             0.8319134288403021, 0.869426735678431, 0.9836659653182612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 272}], {
             RGBColor[
             0.8305893181173114, 0.8683923303180165, 0.9835339903359117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 350}], {
             RGBColor[
             0.9570479117499637, 0.9654838538059254, 0.8719160935305621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 355}], {
             RGBColor[
             0.8429762449225704, 0.8780690916824152, 0.9847686034374477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 392}], {
             RGBColor[
             0.955664633870156, 0.964911832854005, 0.8948405878073766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 395}], {
             RGBColor[
             0.6944421379403393, 0.7593719483680503, 0.9717835682731306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 253}], {
             RGBColor[
             0.19436046466415727`, 0.3216155499002067, 0.9343799129808589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 266}], {
             RGBColor[
             0.21519016549381775`, 0.3435088861514912, 0.9355661336283271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 301}], {
             RGBColor[
             0.1901623548072361, 0.317203070265044, 0.9341408368350541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 315}], {
             RGBColor[
             0.2082369879918481, 0.3362006557400048, 0.9351701604558942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 316}], {
             RGBColor[
             0.21599089502507074`, 0.3443505036580227, 0.9356117339905587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 343}], {
             RGBColor[
             0.18982443678675276`, 0.31684789700027605`, 0.9341215929036926]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 358}], {
             RGBColor[
             0.19420191296404457`, 0.3214489020106298, 0.9343708836960937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 359}], {
             RGBColor[
             0.1924159607622266, 0.31957175301060936`, 0.9342691763602797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 362}], {
             RGBColor[
             0.19339653330473627`, 0.32060239692467707`, 0.9343250185159485]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 363}], {
             RGBColor[
             0.20876443324933688`, 0.3367550341475864, 0.9352001976830229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 369}], {
             RGBColor[
             0.19411283179141248`, 0.32135527205012093`, 0.934365810655096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 397}], {
             RGBColor[
             0.20527567361963986`, 0.3330881265766384, 0.935001517983269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 276}], {
             RGBColor[
             0.22042799245848094`, 0.3490141743887628, 0.9358644201252941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 340}], {
             RGBColor[
             0.2104667967928659, 0.33854432616791813`, 0.9352971447684058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 360}], {
             RGBColor[
             0.20162405229043762`, 0.3292500410334822, 0.9347935635506606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 266}], {
             RGBColor[
             0.270914372535644, 0.40204801259274037`, 0.9387406633049027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 293}], {
             RGBColor[
             0.3289853537057845, 0.45937231092045516`, 0.9421836337211749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 315}], {
             RGBColor[
             0.2639611950336743, 0.39473978218125394`, 0.9383446901324698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 316}], {
             RGBColor[
             0.271715102066897, 0.4028896300992718, 0.9387862636671344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 387}], {
             RGBColor[
             0.4216012233503626, 0.5373973944320252, 0.9486912790769737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 397}], {
             RGBColor[
             0.26099988066146607`, 0.3916272530178875, 0.9381760476598446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 356}], {
             RGBColor[
             0.22666963106636354`, 0.3555745323083922, 0.9362198722103361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 363}], {
             RGBColor[
             0.2391241828797345, 0.3686650559284389, 0.9369291405112493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 372}], {
             RGBColor[
             0.22620791914637717`, 0.35508924380626006`, 0.9361935783995345]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 283}], {
             RGBColor[
             0.19962713488925782`, 0.32715115423296626`, 0.934679842058838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 308}], {
             RGBColor[
             0.1958872147734443, 0.3232202610666153, 0.9344668591409584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 380}], {
             RGBColor[
             0.20519908617390886`, 0.3330076283152506, 0.9349971564415356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 381}], {
             RGBColor[
             0.19321867549075944`, 0.3204154570853507, 0.9343148897765596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 282}], {
             RGBColor[
             0.31835440977210794`, 0.4463178036126423, 0.941647079240882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 300}], {
             RGBColor[
             0.6421328397168371, 0.7146709767757251, 0.9682477279637229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 367}], {
             RGBColor[
             0.372324185998124, 0.4969102291790325, 0.9449451457918181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 398}], {
             RGBColor[
             0.39783022825914727`, 0.5190022810145718, 0.9465703682505828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 266}], {
             RGBColor[
             0.21192263839001468`, 0.3400745079922101, 0.9353800527936387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 301}], {
             RGBColor[
             0.18689482770343305`, 0.31376869210576286`, 0.9339547560003658]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 315}], {
             RGBColor[
             0.20496946088804507`, 0.3327662775807237, 0.9349840796212059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 316}], {
             RGBColor[
             0.2127233679212677, 0.3409161254987416, 0.9354256531558705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 343}], {
             RGBColor[
             0.18655690968294972`, 0.31341351884099494`, 0.9339355120690042]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 358}], {
             RGBColor[
             0.19093438586024153`, 0.31801452385134865`, 0.9341848028614053]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 359}], {
             RGBColor[
             0.18914843365842357`, 0.3161373748513282, 0.9340830955255912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 362}], {
             RGBColor[
             0.19012900620093326`, 0.31716801876539596`, 0.9341389376812601]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 369}], {
             RGBColor[
             0.19084530468760944`, 0.3179208938908398, 0.9341797298204076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 394}], {
             RGBColor[
             0.1857625991924869, 0.31257864815332465`, 0.9338902772616493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 397}], {
             RGBColor[
             0.20200814651583682`, 0.3296537484173573, 0.9348154371485806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 303}], {
             RGBColor[
             0.20024144683233963`, 0.3277968350347721, 0.9347148262152034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 268}], {
             RGBColor[
             0.7573621449450872, 0.5111257415751345, 0.5750858104368912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 324}], {
             RGBColor[
             0.7342455134222807, 0.4929254711764368, 0.5728784243989717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 328}], {
             RGBColor[
             0.8524460760036836, 0.3866301102852666, 0.1971705111408994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 351}], {
             RGBColor[
             0.8725754097367984, 0.601857083491112, 0.5863765700059249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 400}], {
             RGBColor[
             0.8427699382288443, 0.329754063899142, 0.18858984719066463`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 311}], {
             RGBColor[
             0.32702639881790146`, 0.45712063802367703`, 0.942079129357128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 313}], {
             RGBColor[
             0.28483799884386285`, 0.41277795475190926`, 0.9396765623907513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 386}], {
             RGBColor[
             0.556034698630532, 0.6458694921919914, 0.9601976146247932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 275}], {
             RGBColor[
             0.2809273627700829, 0.4112753166902168, 0.9393583772051975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 276}], {
             RGBColor[
             0.27298076036949565`, 0.4029229337235066, 0.9389058299544288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 279}], {
             RGBColor[
             0.4976692988631992, 0.5990761277778498, 0.9548872926096961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 280}], {
             RGBColor[
             0.2873202290991691, 0.41799462453322234`, 0.9397224414852408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 288}], {
             RGBColor[
             0.3142377899115303, 0.4462866876189422, 0.9412553567525421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 309}], {
             RGBColor[
             0.31035046981038367`, 0.4422008677223072, 0.9410339796235565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 325}], {
             RGBColor[
             0.30612175947263687`, 0.43775622504161427`, 0.9407931608256381]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 339}], {
             RGBColor[
             0.2873260863715352, 0.41800078089785175`, 0.939722775048237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 277}], {
             RGBColor[
             0.19561158896014919`, 0.3229305608611562, 0.9344511626586431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 302}], {
             RGBColor[
             0.18739149065206478`, 0.3142907163550246, 0.9339830402205433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 377}], {
             RGBColor[
             0.18407204095648846`, 0.3108017642597073, 0.933794002471066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 378}], {
             RGBColor[
             0.18711323001988966`, 0.3139982467878655, 0.9339671936891907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 379}], {
             RGBColor[
             0.19525485067885182`, 0.32255560630899927`, 0.9344308469412701]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 262}], {
             RGBColor[
             0.20019420515358305`, 0.3277471810351035, 0.934712135871486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 331}], {
             RGBColor[
             0.19269223822101744`, 0.31986213813680114`, 0.934284909952842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 335}], {
             RGBColor[
             0.18286996403264408`, 0.3095383051966678, 0.9337255459685665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 307}], {
             RGBColor[
             0.28646815305242945`, 0.41476449327789777`, 0.9397593961545982]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 329}], {
             RGBColor[
             0.20751257412950358`, 0.3354392508401891, 0.9351289061581081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 341}], {
             RGBColor[
             0.2804084248139549, 0.4095158612485281, 0.93937327562965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 349}], {
             RGBColor[
             0.21328372600725728`, 0.3415050973758713, 0.9354575647198919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 366}], {
             RGBColor[
             0.3094906009088253, 0.4347053804692331, 0.9412263661740565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 306}], {
             RGBColor[
             0.2313412040252819, 0.36048465168304844`, 0.9364859113793738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 284}], {
             RGBColor[
             0.24537509181412387`, 0.37523515754899955`, 0.9372851205276718]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 286}], {
             RGBColor[
             0.20449842182687056`, 0.3322711856618279, 0.9349572546435119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 331}], {
             RGBColor[
             0.20664951421908523`, 0.3345321201531805, 0.9350797561729924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 332}], {
             RGBColor[
             0.22124807994982085`, 0.34987613833871123`, 0.9359111228947152]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 338}], {
             RGBColor[
             0.22417589206845978`, 0.35295345450941085`, 0.9360778574635618]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 264}], {
             RGBColor[
             0.5576221544304325, 0.6488358128735436, 0.9596252327476064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 312}], {
             RGBColor[
             0.3474308254202023, 0.4748091816311434, 0.9433787228228494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 348}], {
             RGBColor[
             0.36254614474277536`, 0.48844098130229274`, 0.9443220976494096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 307}], {
             RGBColor[
             0.5358230864206805, 0.6299545558165122, 0.958236215410184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 312}], {
             RGBColor[
             0.5131003370105822, 0.6097335825641022, 0.9568081018654329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 348}], {
             RGBColor[
             0.5282156563331551, 0.6233653822352514, 0.957751476691993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 357}], {
             RGBColor[
             0.7901960776192611, 0.6118325861467757, 0.5876837053959174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 366}], {
             RGBColor[
             0.5588455342770764, 0.6498954430078475, 0.9597031854296422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 291}], {
             RGBColor[
             0.18857894058274138`, 0.31553880152083974`, 0.9340506637374206]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 304}], {
             RGBColor[
             0.18543662898340038`, 0.31223603279586976`, 0.9338717137404716]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 378}], {
             RGBColor[
             0.19040066183963522`, 0.31745354606563403`, 0.9341544080680056]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 383}], {
             RGBColor[
             0.1991683094404495, 0.3266688995950551, 0.9346537126282998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 293}], {
             RGBColor[
             0.2908233203898157, 0.4192921425712095, 0.940009243857379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 315}], {
             RGBColor[
             0.22579916171770553`, 0.3546596138320083, 0.9361703002686741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 316}], {
             RGBColor[
             0.23355306875092818`, 0.36280946175002615`, 0.9366118738033387]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 338}], {
             RGBColor[
             0.23347632110247196`, 0.3627287951054168, 0.936607503138297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 397}], {
             RGBColor[
             0.22283784734549728`, 0.3515470846686418, 0.9360016577960488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 282}], {
             RGBColor[
             0.2615646860965489, 0.39225144761939246`, 0.9382070939716974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 332}], {
             RGBColor[
             0.24216572228766625`, 0.37186190669091185`, 0.9371023516809767]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 367}], {
             RGBColor[
             0.315534462322565, 0.44284387318578267`, 0.9415051605226336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 383}], {
             RGBColor[
             0.23217032750693795`, 0.361356113031734, 0.9365331287350758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 398}], {
             RGBColor[
             0.34104050458358826`, 0.46493592502132197`, 0.9431303829813984]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 270}], {
             RGBColor[
             0.5192310696539062, 0.6174490867384653, 0.9563893333020512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 274}], {
             RGBColor[
             0.5862206904488971, 0.6743925388404906, 0.9609561467561663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 295}], {
             RGBColor[
             0.5541988760682194, 0.6477364431214906, 0.9586174510059542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 324}], {
             RGBColor[
             0.6562462626397825, 0.7312424529611288, 0.9664688163111557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 351}], {
             RGBColor[
             0.7945761589543001, 0.8401740652758038, 0.979966961918109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 373}], {
             RGBColor[
             0.475607023803843, 0.5762529501811211, 0.9537345477094038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 272}], {
             RGBColor[
             0.7422573926850033, 0.7985763836214297, 0.9749449381792838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 350}], {
             RGBColor[
             0.8687159863176557, 0.8956679071093385, 0.8633270413739342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 355}], {
             RGBColor[
             0.7546443194902623, 0.8082531449858283, 0.9761795512808198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 392}], {
             RGBColor[
             0.8673327084378479, 0.8950958861574181, 0.8862515356507488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 395}], {
             RGBColor[
             0.6061102125080312, 0.6895560016714635, 0.9631945161165028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 295}], {
             RGBColor[
             0.3940670515595366, 0.5157428065001295, 0.9463305819589302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 310}], {
             RGBColor[
             0.3193491673301014, 0.4483310995882432, 0.9416682954109477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 324}], {
             RGBColor[
             0.49611443813109957`, 0.5992488163397677, 0.9541819472641316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 346}], {
             RGBColor[
             0.3550828331693524, 0.4819766359343405, 0.9438465420354984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 351}], {
             RGBColor[
             0.6344443344456173, 0.7081804286544429, 0.9676800928710849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 373}], {
             RGBColor[
             0.31547519929516016`, 0.44425931355976, 0.9414476786623798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 390}], {
             RGBColor[
             0.310905083152461, 0.4394558317316838, 0.9411874173089341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 287}], {
             RGBColor[
             0.18451611233351262`, 0.31126851143271117`, 0.9338192916790429]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 292}], {
             RGBColor[
             0.18674265418407987`, 0.3136087480885643, 0.9339460899435592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 371}], {
             RGBColor[
             0.1828236944867615, 0.3094896729702865, 0.9337229109863782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 374}], {
             RGBColor[
             0.184659451088446, 0.3114191695523481, 0.9338274546090857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 382}], {
             RGBColor[
             0.18049565541513857`, 0.3070427562998084, 0.9335903326052744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 384}], {
             RGBColor[
             0.18432884103510522`, 0.31107167742439884`, 0.9338086268556416]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 389}], {
             RGBColor[
             0.19087423447573804`, 0.31795130093241747`, 0.9341813773290437]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 391}], {
             RGBColor[
             0.1801133509320429, 0.3066409300485706, 0.9335685609305309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 350}], {
             RGBColor[
             0.867391875594665, 0.894633501748924, 0.8631950663915847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 392}], {
             RGBColor[
             0.8660085977148573, 0.8940614807970035, 0.8861195606683994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 395}], {
             RGBColor[
             0.6047861017850406, 0.688521596311049, 0.9630625411341533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 322}], {
             RGBColor[
             0.19086506728942945`, 0.31794166563837395`, 0.9341808552713451]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 330}], {
             RGBColor[
             0.18387764331179846`, 0.31059744000961553`, 0.9337829318127865]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 295}], {
             RGBColor[
             0.4610566723545275, 0.5726862586021548, 0.9508973954130453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 296}], {
             RGBColor[
             0.36901952314668135`, 0.4870709060931353, 0.9452488023460986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 319}], {
             RGBColor[
             0.47322013025663245`, 0.583220445923085, 0.9516727685977074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 324}], {
             RGBColor[
             0.5631040589260905, 0.6561922684417929, 0.9587487607182468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 351}], {
             RGBColor[
             0.7014339552406084, 0.7651238807564681, 0.9722469063252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 373}], {
             RGBColor[
             0.38246482009015115`, 0.5012027656617852, 0.9460144921164949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 276}], {
             RGBColor[
             0.2308037275414878, 0.35991972982060355`, 0.9364553028887468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 280}], {
             RGBColor[
             0.24514319627116127`, 0.3749914206303192, 0.9372719144195587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 288}], {
             RGBColor[
             0.2720607570835225, 0.40328348371603906`, 0.9388048296868601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 290}], {
             RGBColor[
             0.21848378643908228`, 0.34697069059259356`, 0.9357537004686844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 297}], {
             RGBColor[
             0.22283542703535522`, 0.35154454076922603`, 0.9360015199629668]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 318}], {
             RGBColor[
             0.21657038683237403`, 0.3449595862894012, 0.9356447351917034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 325}], {
             RGBColor[
             0.2639447266446291, 0.3947530211387112, 0.9383426337599561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 339}], {
             RGBColor[
             0.24514905354352745`, 0.3749975769949486, 0.9372722479825549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 288}], {
             RGBColor[
             0.2641141546829352, 0.39493110074932897`, 0.9383522824360913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 290}], {
             RGBColor[
             0.21053718403849497`, 0.33861830762588346`, 0.9353011532179156]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 297}], {
             RGBColor[
             0.21488882463476794`, 0.3431921578025159, 0.9355489727121981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 318}], {
             RGBColor[
             0.20862378443178675`, 0.3366072033226911, 0.9351921879409346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 278}], {
             RGBColor[
             0.23299059780069237`, 0.3622182691186103, 0.9365798419148239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 302}], {
             RGBColor[
             0.19959521355734036`, 0.32711760288919167`, 0.9346780241862087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 314}], {
             RGBColor[
             0.22024480085065679`, 0.34882162839392095`, 0.9358539876342362]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 352}], {
             RGBColor[
             0.22370886564436498`, 0.3524625801265016, 0.9360512609996132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 378}], {
             RGBColor[
             0.19931695292516527`, 0.3268251333220326, 0.934662177654856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 379}], {
             RGBColor[
             0.2074585735841274, 0.33538249284316635`, 0.9351258309069355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 314}], {
             RGBColor[
             0.2454200867859244, 0.3752824501172079, 0.9372876829247517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 319}], {
             RGBColor[
             0.35576382875700985`, 0.4778888141834562, 0.9440614916187484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 352}], {
             RGBColor[
             0.24888415157963256`, 0.37892340184978857`, 0.9374849562901288]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 379}], {
             RGBColor[
             0.232633859519395, 0.36184331456645336`, 0.936559526197451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.8332166202434534, 0.8669371947579207, 0.788972494773293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 288}], {
             RGBColor[
             0.4888026931766387, 0.5910842948036721, 0.9543337450913586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 309}], {
             RGBColor[
             0.48491537307549215`, 0.5869984749070372, 0.9541123679623731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 325}], {
             RGBColor[
             0.4806866627377453, 0.5825538322263442, 0.9538715491644547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 399}], {
             RGBColor[
             0.7994051322415094, 0.7452396599077329, 0.6138726305595152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 297}], {
             RGBColor[
             0.22922829336444137`, 0.3582638486122316, 0.9363655842430101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 309}], {
             RGBColor[
             0.27456630331146203`, 0.4059169716624097, 0.9389475168379178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 322}], {
             RGBColor[
             0.22572058379982396`, 0.354577023458187, 0.9361658253724963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 325}], {
             RGBColor[
             0.2703375929737152, 0.4014723289817168, 0.9387066980399994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 339}], {
             RGBColor[
             0.2515419198726136, 0.3817168848379542, 0.9376363122625981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 355}], {
             RGBColor[
             0.5971975343016019, 0.6813125874620714, 0.9629093916561169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 386}], {
             RGBColor[
             0.5947242732295994, 0.6793804571151425, 0.9626628801063983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 367}], {
             RGBColor[
             0.3211123825917724, 0.44870662104929115`, 0.9418228148301714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 383}], {
             RGBColor[
             0.23774824777614534`, 0.3672188608952424, 0.9368507830426136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 398}], {
             RGBColor[
             0.3466184248527956, 0.47079867288483046`, 0.9434480372889362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 294}], {
             RGBColor[
             0.19947004944091673`, 0.32698604746696713`, 0.934670896274942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 320}], {
             RGBColor[
             0.20238649627655553`, 0.330051418004633, 0.9348369836077353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 347}], {
             RGBColor[
             0.20341579469893528`, 0.33113327590784336`, 0.9348956006301792]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 373}], {
             RGBColor[
             0.2404157449182508, 0.3700225695206825, 0.937002693058648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 380}], {
             RGBColor[
             0.2145522876760556, 0.34283843612123366`, 0.9355298074302612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 381}], {
             RGBColor[
             0.20257187699290616`, 0.3302462648913338, 0.9348475407652852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 332}], {
             RGBColor[
             0.2524716906122939, 0.382694132836228, 0.9376892613307504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 338}], {
             RGBColor[
             0.2553995027309328, 0.3857714490069275, 0.9378559958995971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 367}], {
             RGBColor[
             0.3258404306471927, 0.4536760993310988, 0.9420920701724073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 399}], {
             RGBColor[
             0.9603875503566552, 0.868303119703074, 0.4348794443842956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 332}], {
             RGBColor[
             0.2115950206250406, 0.3397301609490563, 0.9353613954465905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 292}], {
             RGBColor[
             0.19215895018442095`, 0.31930161859792383`, 0.9342545399880867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 371}], {
             RGBColor[
             0.18823999048710255`, 0.315182543479646, 0.9340313610309057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 374}], {
             RGBColor[
             0.19007574708878708`, 0.31711204006170757`, 0.9341359046536132]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 382}], {
             RGBColor[
             0.18591195141547964`, 0.3127356268091679, 0.933898782649802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 384}], {
             RGBColor[
             0.18974513703544627`, 0.3167645479337583, 0.9341170769001692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 389}], {
             RGBColor[
             0.19629053047607914`, 0.32364417144177693`, 0.9344898273735713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 391}], {
             RGBColor[
             0.18552964693238397`, 0.31233380055793014`, 0.9338770109750585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 303}], {
             RGBColor[
             0.19970158242580874`, 0.32722940331412775`, 0.9346840817359092]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 376}], {
             RGBColor[
             0.19788479388924796`, 0.32531984337115605`, 0.93458061831645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 297}], {
             RGBColor[
             0.20256888353236238`, 0.33024311857450594`, 0.9348473702921356]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 318}], {
             RGBColor[
             0.1963038433293812, 0.3236581640946811, 0.9344905855208723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 345}], {
             RGBColor[
             0.18860221988526102`, 0.31556326954378094`, 0.9340519894592605]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 304}], {
             RGBColor[
             0.1840328398717771, 0.3107605614341833, 0.9337917700272845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 383}], {
             RGBColor[
             0.1977645203288262, 0.3251934282333686, 0.9345737689151127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 371}], {
             RGBColor[
             0.1904665323376698, 0.31752278013549917`, 0.934158159295422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 374}], {
             RGBColor[
             0.19230228893935433`, 0.31945227671756077`, 0.9342627029181295]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 382}], {
             RGBColor[
             0.1881384932660469, 0.31507586346502103`, 0.9340255809143183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 384}], {
             RGBColor[
             0.19197167888601352`, 0.3191047845896115, 0.9342438751646855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 389}], {
             RGBColor[
             0.1985170723266464, 0.32598440809763013`, 0.9346166256380877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 316}], {
             RGBColor[
             0.2916240499210687, 0.42013376007774095`, 0.9400548442196108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 387}], {
             RGBColor[
             0.4415101712045343, 0.5546415244104943, 0.9499598596294503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 320}], {
             RGBColor[
             0.19287620932606772`, 0.32005550343265077`, 0.9342953868351136]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 347}], {
             RGBColor[
             0.19390550774844745`, 0.3211373613358611, 0.9343540038575576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 380}], {
             RGBColor[
             0.20504200072556777`, 0.3328425215492514, 0.9349882106576397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 381}], {
             RGBColor[
             0.19306159004241835`, 0.32025035031935156`, 0.9343059439926636]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 310}], {
             RGBColor[
             0.3543169737444146, 0.4786184559712684, 0.9438964131148506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 324}], {
             RGBColor[
             0.5310822445454129, 0.6295361727227928, 0.9564100649680346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 351}], {
             RGBColor[
             0.6694121408599306, 0.7384677850374681, 0.9699082105749879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 373}], {
             RGBColor[
             0.3504430057094734, 0.4745466699427852, 0.9436757963662827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 390}], {
             RGBColor[
             0.34587288956677426`, 0.46974318811470905`, 0.943415535012837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 308}], {
             RGBColor[
             0.22323052785896746`, 0.35195981678568156`, 0.9360240203703722]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 373}], {
             RGBColor[
             0.25840585650162723`, 0.38893131743376574`, 0.9380272032993362]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 380}], {
             RGBColor[
             0.23254239925943204`, 0.3617471840343169, 0.9365543176709494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 318}], {
             RGBColor[
             0.20065548392565413`, 0.32823201427131354`, 0.9347384050151546]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 322}], {
             RGBColor[
             0.2034128145640179, 0.33113014359709375`, 0.9348954309159043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 339}], {
             RGBColor[
             0.22923415063680755`, 0.358270004976861, 0.9363659178060062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 313}], {
             RGBColor[
             0.20768244341745035`, 0.33561779423215604`, 0.9351385799627575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 361}], {
             RGBColor[
             0.2073168336633886, 0.33523351519963984`, 0.9351177590281349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 393}], {
             RGBColor[
             0.19018046268844432`, 0.31722210279629987`, 0.9341418680521008]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 396}], {
             RGBColor[
             0.19827776691556012`, 0.32573288293773905`, 0.9346029975489469]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 306}], {
             RGBColor[
             0.19518727715711093`, 0.32248458225324084`, 0.9344269987291731]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 342}], {
             RGBColor[
             0.18568831496489116`, 0.3125005707202294, 0.9338860468847814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 353}], {
             RGBColor[
             0.188841530987085, 0.3158148006849981, 0.9340656178724803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 319}], {
             RGBColor[
             0.6840306200166372, 0.7509595396670409, 0.9709177458785374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 343}], {
             RGBColor[
             0.18235879982602854`, 0.30900103920583233`, 0.9336964359231994]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 358}], {
             RGBColor[
             0.18673627600332035`, 0.31360204421618604`, 0.9339457267156006]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 359}], {
             RGBColor[
             0.1849503238015024, 0.31172489521616553`, 0.9338440193797866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 362}], {
             RGBColor[
             0.18593089634401205`, 0.31275553913023335`, 0.9338998615354555]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 369}], {
             RGBColor[
             0.18664719483068826`, 0.31350841425567716`, 0.9339406536746029]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 394}], {
             RGBColor[
             0.18156448933556574`, 0.30816616851816203`, 0.9336512011158447]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 397}], {
             RGBColor[
             0.19781003665891564`, 0.3252412687821946, 0.934576361002776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 314}], {
             RGBColor[
             0.21202470254257239`, 0.3401817838877893, 0.9353858651961364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 352}], {
             RGBColor[
             0.21548876733628058`, 0.34382273562037, 0.9355831385615135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 377}], {
             RGBColor[
             0.18805566555367964`, 0.3149888062877428, 0.9340208639986316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 379}], {
             RGBColor[
             0.199238475276043, 0.32674264833703476`, 0.9346577084688357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 376}], {
             RGBColor[
             0.21141869489039777`, 0.33954483142224945`, 0.9353513539568531]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 383}], {
             RGBColor[
             0.1946222087294852, 0.32189065950839857`, 0.9343948189181637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 334}], {
             RGBColor[
             0.18360707090558112`, 0.31031305125539965`, 0.9337675231145284]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 340}], {
             RGBColor[
             0.19258396167334632`, 0.31974833262006913`, 0.9342787437636328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 360}], {
             RGBColor[
             0.18374121717091801`, 0.3104540474856332, 0.9337751625458877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 370}], {
             RGBColor[
             0.18466045373978385`, 0.311420223402476, 0.9338275117085959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 342}], {
             RGBColor[
             0.1932134040418383, 0.3204099164583054, 0.934314589575342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 353}], {
             RGBColor[
             0.19636662006403216`, 0.3237241464230741, 0.9344941605630408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 361}], {
             RGBColor[
             0.21017418029056079`, 0.33823676767103766`, 0.9352804806914867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 312}], {
             RGBColor[
             0.32563175741045036`, 0.45592792457411196`, 0.9419897054854269]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 341}], {
             RGBColor[
             0.3422947785820742, 0.4709002657971524, 0.9430316985052297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 348}], {
             RGBColor[
             0.3407470767330234, 0.4695597242452613, 0.9429330803119872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 366}], {
             RGBColor[
             0.37137695467694465`, 0.4960897850178574, 0.9448847890496364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 325}], {
             RGBColor[
             0.2933678336849298, 0.42567857217080163`, 0.9400182361783151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 339}], {
             RGBColor[
             0.27457216058382816`, 0.4059231280270391, 0.9389478504009139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 323}], {
             RGBColor[
             0.33914507736848765`, 0.46547732189212476`, 0.9429296732937578]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 324}], {
             RGBColor[
             0.45636436031597766`, 0.5621244658109066, 0.9517477784200521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 346}], {
             RGBColor[
             0.31533275535423055`, 0.4448522854054794, 0.9414123731914188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 389}], {
             RGBColor[
             0.24112387106664201`, 0.3707668550004327, 0.9370430197952202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 390}], {
             RGBColor[
             0.27115500533733905`, 0.4023314812028227, 0.9387532484648545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 313}], {
             RGBColor[
             0.2605556138292256, 0.39119084868755866`, 0.938149628798862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 361}], {
             RGBColor[
             0.2601900040751639, 0.39080656965504246`, 0.9381288078642394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 386}], {
             RGBColor[
             0.5317523136158948, 0.6242823861276408, 0.958670681032904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 348}], {
             RGBColor[
             0.31802432732292496`, 0.44933875099285125`, 0.9415049667672362]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 366}], {
             RGBColor[
             0.3486542052668462, 0.4758688117654473, 0.9434566755048852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 361}], {
             RGBColor[
             0.2180016041011253, 0.34646388638327474`, 0.9357262408978626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 393}], {
             RGBColor[
             0.200865233126181, 0.3284524739799347, 0.9347503499218286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 396}], {
             RGBColor[
             0.20896253735329678`, 0.3369632541213739, 0.9352114794186747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 352}], {
             RGBColor[
             0.23613835462959704`, 0.3655267611250992, 0.9367591020095412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 379}], {
             RGBColor[
             0.21988806256935944`, 0.348446673841764, 0.9358336719168633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 316}], {
             RGBColor[
             0.22659989124895852`, 0.3555012313385397, 0.9362159006309058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 358}], {
             RGBColor[
             0.20481090918793238`, 0.33259962969114687`, 0.9349750503364407]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 359}], {
             RGBColor[
             0.2030249569861144, 0.33072248069112636`, 0.9348733430006266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 362}], {
             RGBColor[
             0.20400552952862408`, 0.3317531246051941, 0.9349291851562955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 363}], {
             RGBColor[
             0.2193734294732247, 0.3479057618281034, 0.9358043643233698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 369}], {
             RGBColor[
             0.20472182801530026`, 0.332505999730638, 0.934969977295443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 397}], {
             RGBColor[
             0.21588466984352767`, 0.3442388542571554, 0.935605684623616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 358}], {
             RGBColor[
             0.212564816221155, 0.34074947760916474`, 0.9354166238711052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 359}], {
             RGBColor[
             0.21077886401933704`, 0.3388723286091443, 0.9353149165352912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 362}], {
             RGBColor[
             0.2117594365618467, 0.339902972523212, 0.9353707586909601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 363}], {
             RGBColor[
             0.2271273365064473, 0.3560556097461213, 0.9362459378580343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 369}], {
             RGBColor[
             0.2124757350485229, 0.34065584764865586`, 0.9354115508301075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 397}], {
             RGBColor[
             0.2236385768767503, 0.3523887021751733, 0.9360472581582806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 326}], {
             RGBColor[
             0.19368284883535128`, 0.3209033327008066, 0.9343413237618512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 327}], {
             RGBColor[
             0.19548056477531295`, 0.3227928461354802, 0.9344437010251496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 336}], {
             RGBColor[
             0.1878536669894908, 0.3147764929893316, 0.9340093604792311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 396}], {
             RGBColor[
             0.19745595153076353`, 0.32486910286221293`, 0.9345561963785496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 345}], {
             RGBColor[
             0.18668882027855277`, 0.3135521652405886, 0.9339430241822795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 347}], {
             RGBColor[
             0.1968219545840863, 0.324202731873527, 0.9345200911903508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 380}], {
             RGBColor[
             0.20795844756120663`, 0.3359078920869173, 0.9351542979904328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 381}], {
             RGBColor[
             0.19597803687805715`, 0.32331572085701743`, 0.9344720313254569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 384}], {
             RGBColor[
             0.1926752609493727, 0.31984429394788133`, 0.9342839431223373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 341}], {
             RGBColor[
             0.44529829620254, 0.5573731665864943, 0.9503530478730258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 366}], {
             RGBColor[
             0.4743804722974104, 0.5825626858071993, 0.9522061384174323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 330}], {
             RGBColor[
             0.19291768102176954`, 0.3200990928142907, 0.934297748586832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 339}], {
             RGBColor[
             0.22572644107219014`, 0.3545831798228164, 0.9361661589354925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 346}], {
             RGBColor[
             0.37487874320773873`, 0.4991228582382221, 0.9451079199183084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 346}], {
             RGBColor[
             0.4920980261552287, 0.5957700021570038, 0.9539260250446029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 351}], {
             RGBColor[
             0.7714595274314936, 0.8219737948771062, 0.9777595758801894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 390}], {
             RGBColor[
             0.4479202761383373, 0.5532491979543472, 0.9512669003180385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 339}], {
             RGBColor[
             0.2703434502460814, 0.40147848534634617`, 0.9387070316029955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 327}], {
             RGBColor[
             0.19380937140054372`, 0.3210363159388178, 0.9343485290347655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 336}], {
             RGBColor[
             0.18618247361472157`, 0.3130199627926692, 0.9339141884888471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 336}], {
             RGBColor[
             0.18798018955468324`, 0.3149094762273428, 0.9340165657521455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 376}], {
             RGBColor[
             0.2026044968471712, 0.33028055042638454`, 0.9348493984177288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 364}], {
             RGBColor[
             0.8436039382637408, 0.3186655649666024, 0.18870327005536394`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 386}], {
             RGBColor[
             0.8151456848541535, 0.6567413505380229, 0.5948173850288303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 400}], {
             RGBColor[
             0.8598546185049423, 0.443575414393966, 0.20426493980685678`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 349}], {
             RGBColor[
             0.19621450085245074`, 0.32356425948678696`, 0.9344854975989814]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 335}], {
             RGBColor[
             0.18932527309814626`, 0.31632324431474484`, 0.9340931662700729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 338}], {
             RGBColor[
             0.2166739251358942, 0.34506841161110846`, 0.9356506315449178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 368}], {
             RGBColor[
             0.18664235406415453`, 0.3135033263031278, 0.9339403780001101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 340}], {
             RGBColor[
             0.1939578430419053, 0.32119236904753456`, 0.934356984275097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 360}], {
             RGBColor[
             0.185115098539477, 0.3118980839130987, 0.9338534030573518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 365}], {
             RGBColor[
             0.18295572293696874`, 0.30962844324254163`, 0.933730429811299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 370}], {
             RGBColor[
             0.18603433510834283`, 0.3128642598299414, 0.93390575222006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 394}], {
             RGBColor[
             0.17996762986719622`, 0.30648776797016763`, 0.9335602623314629]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 396}], {
             RGBColor[
             0.18995557631013382`, 0.31698573295407556`, 0.9341290611055455]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 367}], {
             RGBColor[
             0.6845644891406854, 0.7444870601720963, 0.7692660513213518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 398}], {
             RGBColor[
             0.7100705314017086, 0.7665791120076357, 0.7708912737801167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 399}], {
             RGBColor[
             0.9603114409091467, 0.8681403292906987, 0.42659540071605706`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 360}], {
             RGBColor[
             0.1940919893072422, 0.3213333652777681, 0.9343646237064562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 370}], {
             RGBColor[
             0.19501122587610803`, 0.3222995411946109, 0.9344169728691645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 348}], {
             RGBColor[
             0.33468734849454873`, 0.4643110922158917, 0.9425469597870388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 366}], {
             RGBColor[
             0.36531722643847, 0.49084115298848774`, 0.9444986685246879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 353}], {
             RGBColor[
             0.1868676578718124, 0.31374013489006275`, 0.9339532087186491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 358}], {
             RGBColor[
             0.18639835798283702`, 0.3132468709514181, 0.933926482784239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 359}], {
             RGBColor[
             0.18461240578101906`, 0.3113697219513976, 0.933824775448425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 362}], {
             RGBColor[
             0.18559297832352872`, 0.3124003658654654, 0.9338806176040938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 369}], {
             RGBColor[
             0.18630927681020493`, 0.31315324099090924`, 0.9339214097432413]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 354}], {
             RGBColor[
             0.2035510812828702, 0.3312754706852238, 0.9349033050009957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 356}], {
             RGBColor[
             0.19312061469136133`, 0.3203123889677695, 0.9343093053591018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 388}], {
             RGBColor[
             0.20538183242077535`, 0.3331997062074885, 0.9350075635699459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 390}], {
             RGBColor[
             0.30688867117659013`, 0.43597701754892004`, 0.9409314950894052]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 380}], {
             RGBColor[
             0.20898774598358635`, 0.3369897499901277, 0.9352129150128767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 381}], {
             RGBColor[
             0.1970073353004369, 0.3243975787602278, 0.9345306483479008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 384}], {
             RGBColor[
             0.19370455937175246`, 0.32092615185109175`, 0.9343425601447813]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 366}], {
             RGBColor[
             0.3637695245894192, 0.4895006114365967, 0.9444000503314454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 355}], {
             RGBColor[
             0.879778802399924, 0.9043102631133229, 0.8644296794931206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 392}], {
             RGBColor[
             0.9924671913475096, 0.9911530042849124, 0.7745016638630496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 395}], {
             RGBColor[
             0.7312446954176929, 0.785613119798958, 0.8514446443288036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 379}], {
             RGBColor[
             0.22335212736306764`, 0.3520876255743447, 0.9360309452822404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 371}], {
             RGBColor[
             0.20120013846367035`, 0.3288044807238608, 0.9347694222853504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 388}], {
             RGBColor[
             0.21768345542489445`, 0.346129491952765, 0.93570812280141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 392}], {
             RGBColor[
             0.8783955245201162, 0.9037382421614023, 0.8873541737699352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 395}], {
             RGBColor[
             0.6171730285902994, 0.6981983576754478, 0.9642971542356892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 363}], {
             RGBColor[
             0.2074463229173425, 0.3353696166156383, 0.9351251332495853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 372}], {
             RGBColor[
             0.1945300591839852, 0.3217938044934594, 0.9343895711378705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 364}], {
             RGBColor[
             0.8373888047327049, 0.2883923138200816, 0.1834368676776406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 385}], {
             RGBColor[
             0.9257629036983032, 0.7151948013477634, 0.418460634800934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 359}], {
             RGBColor[
             0.18898988195831087`, 0.3159707269617513, 0.934074066240826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 362}], {
             RGBColor[
             0.18997045450082056`, 0.31700137087581914`, 0.9341299083964949]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 363}], {
             RGBColor[
             0.20533835444542115`, 0.3331540080987284, 0.9350050875635693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 369}], {
             RGBColor[
             0.19068675298749674`, 0.31775424600126295`, 0.9341707005356424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 372}], {
             RGBColor[
             0.19242209071206384`, 0.3195781959765495, 0.9342695254518545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 397}], {
             RGBColor[
             0.20184959481572412`, 0.3294871005277804, 0.9348064078638154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 362}], {
             RGBColor[
             0.18818450229900258`, 0.31512422187579864`, 0.9340282010606809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 369}], {
             RGBColor[
             0.18890080078567878`, 0.31587709700124245`, 0.9340689931998285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 394}], {
             RGBColor[
             0.18381809529055626`, 0.3105348512637273, 0.9337795406410702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 397}], {
             RGBColor[
             0.20006364261390616`, 0.32760995152775996`, 0.9347047005280014]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 370}], {
             RGBColor[
             0.18616848137367975`, 0.313005256060175, 0.9339133916514194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 393}], {
             RGBColor[
             0.20049962337211924`, 0.32806819494741857`, 0.934729528987206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 396}], {
             RGBColor[
             0.20859692759923504`, 0.3365789750888577, 0.935190658484052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 363}], {
             RGBColor[
             0.20453297478611288`, 0.3323075030127757, 0.9349592223834241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 369}], {
             RGBColor[
             0.18988137332818844`, 0.31690774091531027`, 0.9341248353554973]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 397}], {
             RGBColor[
             0.20104421515641585`, 0.32864059544182767`, 0.9347605426836703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 369}], {
             RGBColor[
             0.20524927327278905`, 0.33306037813821954`, 0.9350000145225716]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 372}], {
             RGBColor[
             0.20698461099735616`, 0.3348843281135061, 0.9350988394387836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 385}], {
             RGBColor[
             0.9060512192132981, 0.563682156680796, 0.3995847034769297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{365, 370}], {
             RGBColor[
             0.18400910577117147`, 0.3107356153896179, 0.9337904184053665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 398}], {
             RGBColor[
             0.40058820107881166`, 0.5213910984512207, 0.9467461038398723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 372}], {
             RGBColor[
             0.19233300953943172`, 0.31948456601604064`, 0.9342644524108568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 389}], {
             RGBColor[
             0.194598112629328, 0.3218653329793524, 0.9343934466809067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 391}], {
             RGBColor[
             0.18383722908563283`, 0.3105549620955055, 0.9337806302823939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 380}], {
             RGBColor[
             0.24598769620290184`, 0.37587904360296687`, 0.9373200074413457]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 382}], {
             RGBColor[
             0.18605529017041303`, 0.3128862849288049, 0.9339069455798448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 384}], {
             RGBColor[
             0.18988847579037965`, 0.3169152060533953, 0.934125239830212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 389}], {
             RGBColor[
             0.19643386923101253`, 0.3237948295614139, 0.9344979903036141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 377}], {
             RGBColor[
             0.18266643619111367`, 0.3093243845308089, 0.9337139553590839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 379}], {
             RGBColor[
             0.19896021464386793`, 0.3264501787698757, 0.934641861937483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 381}], {
             RGBColor[
             0.20814382827755723`, 0.3361027389736181, 0.9351648551479828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 384}], {
             RGBColor[
             0.18572468011707222`, 0.3125387928008556, 0.9338881178264007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 389}], {
             RGBColor[
             0.1922700735577051, 0.31941841630887424`, 0.9342608682998029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 389}], {
             RGBColor[
             0.1961032591776717, 0.32344733743346465`, 0.93447916255017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 387}], {
             RGBColor[
             0.7642756795140044, 0.8115756260652711, 0.7955379877927361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 400}], {
             RGBColor[
             0.8054695470793142, 0.5998653041518983, 0.5862367210785956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 390}], {
             RGBColor[
             0.23267978688900162`, 0.3618915871438733, 0.9365621416932066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 395}], {
             RGBColor[
             0.729861417537885, 0.7850410988470374, 0.8743691386056183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 396}], {
             RGBColor[
             0.19146055662429076`, 0.3185675626855177, 0.9342147675080179]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.0002105009621202394], {
             RGBColor[
             0.19354678877808446`, 0.32076032495391327`, 0.9343335753428726]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.0002105009621202394], {
             RGBColor[
             0.18498575182454155`, 0.3117621323146461, 0.9338460369532876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.0002105009621202394], {
             RGBColor[
             0.5818688834669836, 0.6714263983498019, 0.960225996443923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.0002105009621202394], {
             RGBColor[
             0.23281884209063286`, 0.36203774297739677`, 0.9365700606812258]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.0002105009621202394], {
             RGBColor[
             0.2824395297681887, 0.41419223185981874`, 0.9393958854372335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.0002105009621202394], {
             RGBColor[
             0.30558851701585305`, 0.4385232851876776, 0.9407141860151303]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.0002105009621202394], {
             RGBColor[
             0.4486453266434888, 0.5630157651939816, 0.9498082613856059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.0002105009621202394], {
             RGBColor[
             0.2378122641398246, 0.36728614615234123`, 0.9368544286798214]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.0002105009621202394], {
             RGBColor[
             0.19103464530579026`, 0.3181199028854364, 0.9341905124885087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.0002105009621202394], {
             RGBColor[
             0.23750097993416716`, 0.3669589667156367, 0.9368367015048129]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.0002105009621202394], {
             RGBColor[
             0.31196467996522614`, 0.44462985881031997`, 0.9410990914412173]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.0002105009621202394], {
             RGBColor[
             0.3084761160714523, 0.441558334879467, 0.9408786305095267]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.0002105009621202394], {
             RGBColor[
             0.21416269395992185`, 0.3424289484239088, 0.9355076206444797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.0002105009621202394], {
             RGBColor[
             0.18454901891679482`, 0.31130309833813863`, 0.9338211656602798]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.0002105009621202394], {
             RGBColor[
             0.28582560720535155`, 0.41775121393598635`, 0.9395887175380273]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.0002105009621202394], {
             RGBColor[
             0.3177755060429437, 0.4496629042982282, 0.9414693521405777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.0002105009621202394], {
             RGBColor[
             0.2316763474093035, 0.360836908628973, 0.9365049972992935]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.0002105009621202394], {
             RGBColor[
             0.6051402883638863, 0.6903191732099512, 0.9620580066833722]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.0002105009621202394], {
             RGBColor[
             0.26040419361571815`, 0.3910316964425663, 0.9381410056417089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.0002105009621202394], {
             RGBColor[
             0.19028821830363388`, 0.31733536077996466`, 0.9341480045749757]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.0002105009621202394], {
             RGBColor[
             0.9632021039744041, 0.8875341975281088, 0.3115475519504825]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.0002105009621202394], {
             RGBColor[
             0.3162753653274515, 0.4483635578097335, 0.9413737645007089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.0002105009621202394], {
             RGBColor[
             0.2930562064900811, 0.4253510322307103, 0.9400004894705796]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.0002105009621202394], {
             RGBColor[
             0.8207868509580615, 0.16078242208563953`, 0.1675388179938171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.0002105009621202394], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.0002105009621202394], {
             RGBColor[
             0.18699939157323073`, 0.3138785953626525, 0.9339607107580624]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.0002105009621202394], {
             RGBColor[
             0.821038236612611, 0.16271468238440395`, 0.16777954518051325`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.0002105009621202394], {
             RGBColor[
             0.20698871416859752`, 0.3348886408066369, 0.9350990731083157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.0002105009621202394], {
             RGBColor[
             0.1814383294461641, 0.30803356647540187`, 0.9336440164967801]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.0002105009621202394], {
             RGBColor[
             0.18021067351487519`, 0.3067432222537355, 0.9335741033076473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.0002105009621202394], {
             RGBColor[
             0.19647646719475834`, 0.3238396027221777, 0.9345004161946314]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.0002105009621202394], {
             RGBColor[
             0.9570322462930174, 0.8667218188173162, 0.28757881993815293`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.0002105009621202394], {
             RGBColor[
             0.2765417318743941, 0.4079932723314563, 0.939060014572192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.0002105009621202394], {
             RGBColor[
             0.2632481201845229, 0.3940208435817391, 0.93830296305259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.0002105009621202394], {
             RGBColor[
             0.2362515342121432, 0.36564572004235524`, 0.9367655474193329]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.0002105009621202394], {
             RGBColor[
             0.19287789451893317`, 0.32005727467719974`, 0.9342954828043544]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.0002105009621202394], {
             RGBColor[
             0.34879862256835453`, 0.4765335685653648, 0.9434461176929121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.0002105009621202394], {
             RGBColor[
             0.22292982485851465`, 0.3516437588665342, 0.9360068957793466]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.0002105009621202394], {
             RGBColor[
             0.18317563345981333`, 0.30985958314518375`, 0.9337429533902465]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.0002105009621202394], {
             RGBColor[
             0.5210599224495296, 0.6220589443833571, 0.9554388922820652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.0002105009621202394], {
             RGBColor[
             0.8718710063158469, 0.90067029040099, 0.9876410289824828]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.0002105009621202394], {
             RGBColor[
             0.21651396498896067`, 0.34490028335462225`, 0.9356415220511897]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.0002105009621202394], {
             RGBColor[
             0.26035980612556775`, 0.3909850423760888, 0.9381384778398102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.0002105009621202394], {
             RGBColor[
             0.2366745638317519, 0.36609035099419096`, 0.9367896383303533]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.0002105009621202394], {
             RGBColor[
             0.2848093981590889, 0.41668311379698936`, 0.9395308459361892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.0002105009621202394], {
             RGBColor[
             0.20129344185623907`, 0.3289025485052273, 0.9347747357755273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.0002105009621202394], {
             RGBColor[
             0.5441036538714303, 0.6407668836599264, 0.9572529792315668]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.0002105009621202394], {
             RGBColor[
             0.24018804114120323`, 0.3697832384137522, 0.9369897256654027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.0002105009621202394], {
             RGBColor[
             0.18767785554878408`, 0.3145917040180597, 0.9339993482777726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.0002105009621202394], {
             RGBColor[
             0.1790362447681438, 0.3055088231778375, 0.9335072213279326]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.0002105009621202394], {
             RGBColor[
             0.381577964086101, 0.5049253866504279, 0.9455347883487892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.0002105009621202394], {
             RGBColor[
             0.17936539842637753`, 0.30585478454218845`, 0.9335259661418299]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.0002105009621202394], {
             RGBColor[
             0.19239706134193654`, 0.319551888521592, 0.9342681000662533]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.0002105009621202394], {
             RGBColor[
             0.1846123721443362, 0.31136968659711123`, 0.9338247735328656]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.0002105009621202394], {
             RGBColor[
             0.9716313250190438, 0.9159679393868991, 0.3442934839840799]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.0002105009621202394], {
             RGBColor[
             0.38165040818030865`, 0.5049881340836845, 0.9455394044224124]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.0002105009621202394], {
             RGBColor[
             0.21768082531414856`, 0.3461267275396124, 0.9357079730204939]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.0002105009621202394], {
             RGBColor[
             0.21195870855243037`, 0.3401124200198894, 0.9353821069360272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.0002105009621202394], {
             RGBColor[
             0.3465121371910148, 0.4745531298536097, 0.9433004248665277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.0002105009621202394], {
             RGBColor[
             0.186004909472108, 0.3128333316205655, 0.9339040764736078]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.0002105009621202394], {
             RGBColor[
             0.20936457771848743`, 0.3373858240360207, 0.9352343750227069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.0002105009621202394], {
             RGBColor[
             0.20110579749352597`, 0.32870532238267614`, 0.9347640497066657]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.0002105009621202394], {
             RGBColor[
             0.1811814280726413, 0.30776354684334156`, 0.9336293863436095]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.0002105009621202394], {
             RGBColor[
             0.18064334912177313`, 0.30719799174980317`, 0.933598743543374]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.0002105009621202394], {
             RGBColor[
             0.2879462259501837, 0.4199801186917991, 0.9397094836383711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.0002105009621202394], {
             RGBColor[
             0.2142707962291993, 0.34254257076299915`, 0.935513776908792]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.0002105009621202394], {
             RGBColor[
             0.42522253205912725`, 0.5427281177888938, 0.9483157816266544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.0002105009621202394], {
             RGBColor[
             0.27002626100566185`, 0.40114509934370585`, 0.9386889681449931]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.0002105009621202394], {
             RGBColor[
             0.2418162773238607, 0.37149461787786187`, 0.9370824513072455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.0002105009621202394], {
             RGBColor[
             0.22291581655962178`, 0.35162903525622036`, 0.9360060980274482]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.0002105009621202394], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.0002105009621202394], {
             RGBColor[
             0.18281412095909713`, 0.3094796105857146, 0.9337223657881405]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.0002105009621202394], {
             RGBColor[
             0.9306153171117766, 0.762619883962795, 0.26302965936154776`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.0002105009621202394], {
             RGBColor[
             0.8630600513163033, 0.8936446740513561, 0.986800632228994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.0002105009621202394], {
             RGBColor[
             0.21796667840296896`, 0.34642717726009525`, 0.9357242519310205]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.0002105009621202394], {
             RGBColor[
             0.1938965482594379, 0.32112794434484765`, 0.9343534936279129]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.0002105009621202394], {
             RGBColor[
             0.18280925758947733`, 0.30947449887588874`, 0.9337220888264354]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.0002105009621202394], {
             RGBColor[
             0.8199375785531087, 0.1542545422276314, 0.1667255537797183]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.0002105009621202394], {
             RGBColor[
             0.23104392871496413`, 0.36017219648356114`, 0.9364689819902305]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.0002105009621202394], {
             RGBColor[
             0.1798079986201722, 0.3063199854083397, 0.9335511715680982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.0002105009621202394], {
             RGBColor[
             0.17955783501139488`, 0.30605704759422586`, 0.9335369251206622]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.0002105009621202394], {
             RGBColor[
             0.1807265568208277, 0.30728544831718235`, 0.9336034820987404]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.0002105009621202394], {
             RGBColor[
             0.9450344910434499, 0.9585273939347413, 0.9779264487494559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.0002105009621202394], {
             RGBColor[
             0.3388378220394789, 0.4679060237916442, 0.9428114242912021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.0002105009621202394], {
             RGBColor[
             0.24074527521724318`, 0.3703689267583512, 0.9370214593216792]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.0002105009621202394], {
             RGBColor[
             0.4110226556238299, 0.5304288985271809, 0.947410978056655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.0002105009621202394], {
             RGBColor[
             0.19817896485079942`, 0.32562903570326285`, 0.9345973709175234]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.0002105009621202394], {
             RGBColor[
             0.19146940577852636`, 0.3185768637076881, 0.9342152714542605]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.0002105009621202394], {
             RGBColor[
             0.1892450123424645, 0.31623888517169746`, 0.934088595538772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.0002105009621202394], {
             RGBColor[
             0.6083786689975903, 0.6929482364957771, 0.9623129438694364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.0002105009621202394], {
             RGBColor[
             0.4932978290383352, 0.5995204262840937, 0.953253358592837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.0002105009621202394], {
             RGBColor[
             0.49739045300864126`, 0.6028430027937971, 0.9535755449435551]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.0002105009621202394], {
             RGBColor[
             0.2343202347626608, 0.3636158018694917, 0.9366555627727864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.0002105009621202394], {
             RGBColor[
             0.18118663655961964`, 0.30776902129339295`, 0.9336296829592377]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.0002105009621202394], {
             RGBColor[
             0.559409915392181, 0.6531931963016955, 0.9584579442071637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.0002105009621202394], {
             RGBColor[
             0.7481991240396009, 0.803218109314472, 0.9755371544320737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.0002105009621202394], {
             RGBColor[
             0.19288958051724012`, 0.32006955740235543`, 0.93429614830467]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.0002105009621202394], {
             RGBColor[
             0.20101540430520026`, 0.32861031341048663`, 0.9347589019483153]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.0002105009621202394], {
             RGBColor[
             0.965636915117815, 0.9738926480760296, 0.9430519187643377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.0002105009621202394], {
             RGBColor[
             0.2101475089071078, 0.33820873435596516`, 0.9352789617956558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.0002105009621202394], {
             RGBColor[
             0.1831002535865883, 0.30978035411906424`, 0.9337386606179808]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.0002105009621202394], {
             RGBColor[
             0.2774713947406823, 0.40897040694795533`, 0.9391129574971142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.0002105009621202394], {
             RGBColor[
             0.19434739415987903`, 0.3216018119714924, 0.9343791686349763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.0002105009621202394], {
             RGBColor[
             0.8190091230934095, 0.14711802671260676`, 0.16583646378296987`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.0002105009621202394], {
             RGBColor[
             0.20947576509879728`, 0.3375026890224135, 0.9352407069795285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.0002105009621202394], {
             RGBColor[
             0.22681870684301533`, 0.35573122040160343`, 0.9362283618552786]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.0002105009621202394], {
             RGBColor[
             0.34861868121472545`, 0.4763777124089667, 0.9434346519889747]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.0002105009621202394], {
             RGBColor[
             0.256153514960176, 0.38656396366699863`, 0.9378989357805914]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.0002105009621202394], {
             RGBColor[
             0.18132254229683142`, 0.30791186684012395`, 0.9336374225899173]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.0002105009621202394], {
             RGBColor[
             0.18343408206602244`, 0.3101312290168976, 0.9337576716560296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.0002105009621202394], {
             RGBColor[
             0.18925042984728385`, 0.3162445793127523, 0.934088904057657]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.0002105009621202394], {
             RGBColor[
             0.937107871400364, 0.788360698201582, 0.2682537209419814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.0002105009621202394], {
             RGBColor[
             0.30752560771325343`, 0.4405592903292892, 0.9408245004646784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.0002105009621202394], {
             RGBColor[
             0.24129060741956473`, 0.3709421054790498, 0.9370525151838548]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.0002105009621202394], {
             RGBColor[
             0.8646080428941941, 0.47809856902505976`, 0.2087379710414105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.0002105009621202394], {
             RGBColor[
             0.18333815129494635`, 0.31003039969413443`, 0.9337522085405336]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.0002105009621202394], {
             RGBColor[
             0.22614100723621103`, 0.3550189151462153, 0.9361897678652379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.0002105009621202394], {
             RGBColor[
             0.2388812891503496, 0.36840975921850344`, 0.93691530807269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.0002105009621202394], {
             RGBColor[
             0.18241596627536708`, 0.30906112476864933`, 0.9336996914679191]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.0002105009621202394], {
             RGBColor[
             0.5182991743784003, 0.6198176447289311, 0.9552215560809526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.0002105009621202394], {
             RGBColor[
             0.3109061797336599, 0.4437130391115059, 0.9410316447424569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.0002105009621202394], {
             RGBColor[
             0.5979628209588992, 0.6844921818293608, 0.9614929701573222]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.0002105009621202394], {
             RGBColor[
             0.21169783120855037`, 0.3398382213908926, 0.9353672503572267]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.0002105009621202394], {
             RGBColor[
             0.3097296345397099, 0.44269397479938727`, 0.9409566763230764]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.0002105009621202394], {
             RGBColor[
             0.2615118954900493, 0.3921959613448436, 0.9382040876247539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.0002105009621202394], {
             RGBColor[
             0.1865862227024127, 0.3134443286830033, 0.9339371814020978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.0002105009621202394], {
             RGBColor[
             0.19480415931956344`, 0.32208190111490453`, 0.9344051807350968]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.0002105009621202394], {
             RGBColor[
             0.19461177340916913`, 0.32187969132510885`, 0.9343942246421093]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.0002105009621202394], {
             RGBColor[
             0.189088316742455, 0.3160741881610126, 0.9340796719561618]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.0002105009621202394], {
             RGBColor[
             0.1820121662584413, 0.30863670534846055`, 0.9336766956543238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.0002105009621202394], {
             RGBColor[
             0.21325644631447746`, 0.3414764246891273, 0.9354560111817448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.0002105009621202394], {
             RGBColor[
             0.35827341580975897`, 0.4847401582541144, 0.9440498431400237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.0002105009621202394], {
             RGBColor[
             0.18578718983175693`, 0.312604494474334, 0.9338916776621772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.0002105009621202394], {
             RGBColor[
             0.830968185180272, 0.8680554911049849, 0.9837396813881922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.0002105009621202394], {
             RGBColor[
             0.9948422584139026, 0.9913764372120322, 0.679989842123797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.0002105009621202394], {
             RGBColor[
             0.18458947116943916`, 0.3113456162204888, 0.9338234693562242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.0002105009621202394], {
             RGBColor[
             0.33446348254021346`, 0.46411719077807645`, 0.9425326952463855]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.0002105009621202394], {
             RGBColor[
             0.18225239431662393`, 0.3088892002689491, 0.9336903762868517]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.0002105009621202394], {
             RGBColor[
             0.18805967833656198`, 0.31499302397697726`, 0.9340210925206803]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.0002105009621202394], {
             RGBColor[
             0.2256991535454318, 0.35455449890206425`, 0.9361646049512119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.0002105009621202394], {
             RGBColor[
             0.8655975347340893, 0.482591620368333, 0.20956362728728348`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.0002105009621202394], {
             RGBColor[
             0.18248883410320854`, 0.3091377134757978, 0.9337038411829164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.0002105009621202394], {
             RGBColor[
             0.18504307948317125`, 0.3118223873186494, 0.9338493016786379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.0002105009621202394], {
             RGBColor[
             0.1905501321581982, 0.3176106488474093, 0.9341629201815262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.0002105009621202394], {
             RGBColor[
             0.1972575262297792, 0.3246605452899877, 0.9345448963512025]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.0002105009621202394], {
             RGBColor[
             0.18614238840660097`, 0.3129778306973855, 0.9339119056955454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.0002105009621202394], {
             RGBColor[
             0.1834762116557925, 0.31017550988691617`, 0.9337600708738418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.0002105009621202394], {
             RGBColor[
             0.33397821749630197`, 0.46369687858717057`, 0.9425017745868906]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.0002105009621202394], {
             RGBColor[
             0.21660346779159745`, 0.34499435647499893`, 0.9356466191033923]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.0002105009621202394], {
             RGBColor[
             0.19354588592399127`, 0.3207593759970171, 0.9343335239266677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.0002105009621202394], {
             RGBColor[
             0.19201931518110454`, 0.3191548533560677, 0.9342465879812193]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.0002105009621202394], {
             RGBColor[
             0.25676930210776144`, 0.3872111950022711, 0.9379340039476709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.0002105009621202394], {
             RGBColor[
             0.1824446187841665, 0.30909124037207153`, 0.9337013231859077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.0002105009621202394], {
             RGBColor[
             0.2055125320888361, 0.33333707984545796`, 0.935015006722689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.0002105009621202394], {
             RGBColor[
             0.2070813101039675, 0.3349859650056321, 0.9351043463098516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.0002105009621202394], {
             RGBColor[
             0.8309858670902185, 0.23917652931476524`, 0.17730540736011186`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.0002105009621202394], {
             RGBColor[
             0.1873941802353717, 0.31429354327760956`, 0.9339831933883338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.0002105009621202394], {
             RGBColor[
             0.3387561380668311, 0.4678352732400925, 0.9428062194606953]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.0002105009621202394], {
             RGBColor[
             0.1805122222555836, 0.3070601690995145, 0.9335912760623294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.0002105009621202394], {
             RGBColor[
             0.4596234812344611, 0.572182073724828, 0.9506023905805157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.0002105009621202394], {
             RGBColor[
             0.1994550789542851, 0.32697031253633363`, 0.9346700437278752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.0002105009621202394], {
             RGBColor[
             0.27232886945688745`, 0.40356528681975196`, 0.9388200982898864]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.0002105009621202394], {
             RGBColor[
             0.26679472020223177`, 0.3977485450677799, 0.938504936676874]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.0002105009621202394], {
             RGBColor[
             0.20095261322947336`, 0.32854431600871353`, 0.9347553260894438]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.0002105009621202394], {
             RGBColor[
             0.8967495440562933, 0.920507761085305, 0.9900139661214994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.0002105009621202394], {
             RGBColor[
             0.9896948922783259, 0.9900065873749687, 0.82044583391943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.0002105009621202394], {
             RGBColor[
             0.3102543804501736, 0.4431484833325346, 0.9409901126684767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.0002105009621202394], {
             RGBColor[
             0.18420503135956878`, 0.31094154560542325`, 0.9338015760777798]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.0002105009621202394], {
             RGBColor[
             0.8957887014800139, 0.9197416112963568, 0.9899223200988196]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.0002105009621202394], {
             RGBColor[
             0.2316644133079956, 0.36082436513183264`, 0.936504317669879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.0002105009621202394], {
             RGBColor[
             0.188962757776349, 0.315942217726737, 0.93407252155879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.0002105009621202394], {
             RGBColor[
             0.8238032261936802, 0.18396760393066158`, 0.17042730232595416`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.0002105009621202394], {
             RGBColor[
             0.2824798268544749, 0.4142345866524884, 0.9393981802966833]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.0002105009621202394], {
             RGBColor[
             0.34399645769565007`, 0.4723741747164527, 0.943140127993611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.0002105009621202394], {
             RGBColor[
             0.28165135838121924`, 0.41336381375916165`, 0.9393510002427407]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.0002105009621202394], {
             RGBColor[
             0.23366891778676377`, 0.3629312264319425, 0.9366184712345461]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.0002105009621202394], {
             RGBColor[
             0.8948525196191675, 0.9189951252924975, 0.9898330262371927]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.0002105009621202394], {
             RGBColor[
             0.44169024668361, 0.5569916245052177, 0.9493650898406981]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.0002105009621202394], {
             RGBColor[
             0.45394807471440896`, 0.5675745230376996, 0.950155601789558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.0002105009621202394], {
             RGBColor[
             0.2585433275657887, 0.3890758082383683, 0.93803503207307]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.0002105009621202394], {
             RGBColor[
             0.19492367816056405`, 0.3222075229947284, 0.9344119871562795]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.0002105009621202394], {
             RGBColor[
             0.34853172220347034`, 0.47630239288410453`, 0.9434291110376724]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.0002105009621202394], {
             RGBColor[
             0.3499869056482099, 0.4775627996442913, 0.943521834040003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.0002105009621202394], {
             RGBColor[
             0.18311045325504194`, 0.3097910746173054, 0.9337392414740102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.0002105009621202394], {
             RGBColor[
             0.3996003392677278, 0.5205354622018381, 0.9466831581588019]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.0002105009621202394], {
             RGBColor[
             0.20685160848485196`, 0.33474453404001786`, 0.9350912651424561]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.0002105009621202394], {
             RGBColor[
             0.43492032413853554`, 0.551127857862875, 0.9489337163625334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.0002105009621202394], {
             RGBColor[
             0.2017846044041309, 0.3294187914845658, 0.9348027067560198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.0002105009621202394], {
             RGBColor[
             0.266643234211289, 0.39758932368653244`, 0.9384963097737932]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.0002105009621202394], {
             RGBColor[
             0.9562193148935751, 0.9668690172486966, 0.9589934594404549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.0002105009621202394], {
             RGBColor[
             0.20722377740839654`, 0.33513570717553587`, 0.9351124596120775]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.0002105009621202394], {
             RGBColor[
             0.18162114890697434`, 0.30822572132013676`, 0.933654427794616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.0002105009621202394], {
             RGBColor[
             0.18694492825143932`, 0.3138213509582757, 0.9339576091524576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.0002105009621202394], {
             RGBColor[
             0.9945316676487347, 0.9907121149708813, 0.6461839540792844]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.0002105009621202394], {
             RGBColor[
             0.20184829587443234`, 0.32948573525812513`, 0.9348063338910304]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.0002105009621202394], {
             RGBColor[
             0.18973547474422028`, 0.3167543922530552, 0.9341165266469779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.0002105009621202394], {
             RGBColor[
             0.9643115115712477, 0.9729041642811488, 0.9452954812480678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.0002105009621202394], {
             RGBColor[
             0.3533082208089774, 0.4804395559023944, 0.9437334653051234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.0002105009621202394], {
             RGBColor[
             0.18648980339442428`, 0.3133429858769703, 0.9339316904651475]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.0002105009621202394], {
             RGBColor[
             0.1842143453500115, 0.31095133519991963`, 0.9338021064957567]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.0002105009621202394], {
             RGBColor[
             0.9490437648216794, 0.9615175037539616, 0.971139794028986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.0002105009621202394], {
             RGBColor[
             0.2433593553333951, 0.37311649070267905`, 0.9371703273171091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.0002105009621202394], {
             RGBColor[
             0.2257570420476589, 0.35461534338824796`, 0.9361679016157753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.0002105009621202394], {
             RGBColor[
             0.19363457114614188`, 0.3208525897884652, 0.9343385744188711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.0002105009621202394], {
             RGBColor[
             0.3500177192487492, 0.4775894888363419, 0.943523797455382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.0002105009621202394], {
             RGBColor[
             0.7303132143006519, 0.7892455006884563, 0.9737544541026248]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.0002105009621202394], {
             RGBColor[
             0.18775722726537172`, 0.31467512872465075`, 0.9340038683796124]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.0002105009621202394], {
             RGBColor[
             0.9930152754848626, 0.9913796511608278, 0.7654184913108293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.0002105009621202394], {
             RGBColor[
             0.33484250288537293`, 0.4644454791509371, 0.9425568460876246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.0002105009621202394], {
             RGBColor[
             0.3056537490672848, 0.4385918482096833, 0.9407179008839572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.0002105009621202394], {
             RGBColor[
             0.22188954865981286`, 0.3505503626243781, 0.9359476535887813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.0002105009621202394], {
             RGBColor[
             0.41733642177677943`, 0.535897565429752, 0.9478132856528767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.0002105009621202394], {
             RGBColor[
             0.22261848399738943`, 0.3513165198813409, 0.9359891653778931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.0002105009621202394], {
             RGBColor[
             0.23974505627195325`, 0.36931763322930755`, 0.9369644983324363]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.0002105009621202394], {
             RGBColor[
             0.18299643202543156`, 0.30967123107562133`, 0.9337327481336631]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.0002105009621202394], {
             RGBColor[
             0.1997106484206986, 0.3272389322495743, 0.9346845980309063]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.0002105009621202394], {
             RGBColor[
             0.9930695883095065, 0.987584875103169, 0.4870456409120508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.0002105009621202394], {
             RGBColor[
             0.19086057119328328`, 0.3179369399562554, 0.934180599225321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.0002105009621202394], {
             RGBColor[
             0.3371253879726633, 0.4664227994724073, 0.9427023095067106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.0002105009621202394], {
             RGBColor[
             0.635822518194204, 0.7152283896049052, 0.9644734242083259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.0002105009621202394], {
             RGBColor[
             0.9023083761464576, 0.6492869771870501, 0.2401960532268301]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.0002105009621202394], {
             RGBColor[
             0.23238602207295528`, 0.3615828216964435, 0.9365454122215189]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.0002105009621202394], {
             RGBColor[
             0.9299021495647822, 0.7597924122879596, 0.2624558280130423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.0002105009621202394], {
             RGBColor[
             0.1793343425625045, 0.3058221428602024, 0.9335241975563253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.0002105009621202394], {
             RGBColor[
             0.884710274500928, 0.9109079743391231, 0.9888656498437259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.0002105009621202394], {
             RGBColor[
             0.44524034591787487`, 0.5600665420287623, 0.9495912990246761]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.0002105009621202394], {
             RGBColor[
             0.20746958876179836`, 0.3353940704933011, 0.9351264582050084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.0002105009621202394], {
             RGBColor[
             0.20359531165465325`, 0.33132195961033534`, 0.9349058238552358]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.0002105009621202394], {
             RGBColor[
             0.20688302376209858`, 0.33477755348824767`, 0.9350930541960206]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.0002105009621202394], {
             RGBColor[
             0.8177383166445533, 0.1373500514757623, 0.1646195380923747]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.0002105009621202394], {
             RGBColor[
             0.18219295480676673`, 0.3088267255754066, 0.9336869912946982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.0002105009621202394], {
             RGBColor[
             0.295092829761857, 0.42749165241872045`, 0.9401164721529931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.0002105009621202394], {
             RGBColor[
             0.9594063537213845, 0.9692459055881796, 0.9535986340178257]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.0002105009621202394], {
             RGBColor[
             0.7857227396767522, 0.8325318430402561, 0.9792771577606599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.0002105009621202394], {
             RGBColor[
             0.1915139828942802, 0.31862371708269777`, 0.9342178100550568]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.0002105009621202394], {
             RGBColor[
             0.25077535368791876`, 0.38091117517473666`, 0.9375926574524128]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.0002105009621202394], {
             RGBColor[
             0.19733278810728, 0.3247396502951197, 0.9345491824037863]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.0002105009621202394], {
             RGBColor[
             0.28998218143607674`, 0.4221200369945062, 0.9398254282913666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.0002105009621202394], {
             RGBColor[
             0.82776291630336, 0.2144035172609302, 0.17421910604681382`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.0002105009621202394], {
             RGBColor[
             0.8316889234682268, 0.24458052871740593`, 0.17797865494168116`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.0002105009621202394], {
             RGBColor[
             0.2632132370288079, 0.3939841791733627, 0.938300976508477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.0002105009621202394], {
             RGBColor[
             0.852273426221674, 0.40280203706702433`, 0.19769039802525293`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.0002105009621202394], {
             RGBColor[
             0.9695261963263196, 0.9767932676332187, 0.9364683801653377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.0002105009621202394], {
             RGBColor[
             0.9547654228714991, 0.9657847069591619, 0.9614545193980599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.0002105009621202394], {
             RGBColor[
             0.818830055518114, 0.14574163486097447`, 0.1656649884706391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.0002105009621202394], {
             RGBColor[
             0.9202453542726101, 0.9392426823750178, 0.9922550174748891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.0002105009621202394], {
             RGBColor[
             0.1976279917679603, 0.3250499280594878, 0.9345659938155473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.0002105009621202394], {
             RGBColor[
             0.21799885977606132`, 0.3464610019236322, 0.9357260846126101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.0002105009621202394], {
             RGBColor[
             0.3090764058516128, 0.442128180941986, 0.9409150531686984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.0002105009621202394], {
             RGBColor[
             0.25834749102875554`, 0.38886997162119286`, 0.9380238794720002]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.0002105009621202394], {
             RGBColor[
             0.19027393338711107`, 0.3173203464269832, 0.9341471910701123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.0002105009621202394], {
             RGBColor[
             0.3695662131784596, 0.4945214117423836, 0.9447694102025287]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.0002105009621202394], {
             RGBColor[
             0.19109293756035423`, 0.31818117174092553`, 0.9341938321461705]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.0002105009621202394], {
             RGBColor[
             0.18724741023772068`, 0.314139278704323, 0.9339748350540943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.0002105009621202394], {
             RGBColor[
             0.8353613957275855, 0.2728087597904426, 0.18149541852470724`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.0002105009621202394], {
             RGBColor[
             0.3513087838325387, 0.47870774408802763`, 0.9436060629490174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.0002105009621202394], {
             RGBColor[
             0.32310439559809073`, 0.45427852059311985`, 0.9418089042708796]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.0002105009621202394], {
             RGBColor[
             0.18340786605487358`, 0.31010367432698904`, 0.9337561786929778]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.0002105009621202394], {
             RGBColor[
             0.18623692915551526`, 0.3130771990187241, 0.9339172896513356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.0002105009621202394], {
             RGBColor[
             0.22458179928431016`, 0.35338008872927346`, 0.9361009732790185]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.0002105009621202394], {
             RGBColor[
             0.2599700418165058, 0.39057537537478015`, 0.9381162813390138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.0002105009621202394], {
             RGBColor[
             0.2141514811516508, 0.34241716305148284`, 0.9355069820916365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.0002105009621202394], {
             RGBColor[
             0.3919526428400527, 0.5139114119405849, 0.9461958537050229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.0002105009621202394], {
             RGBColor[
             0.7232916660208124, 0.7837602138065023, 0.9730546117901898]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.0002105009621202394], {
             RGBColor[
             0.18998272969436467`, 0.3170142728825262, 0.9341306074506077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.0002105009621202394], {
             RGBColor[
             0.23275233921967517`, 0.3619678442434947, 0.9365662734411069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.0002105009621202394], {
             RGBColor[
             0.2559867658273416, 0.386388699755884, 0.9378894396641596]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.0002105009621202394], {
             RGBColor[
             0.679362894162589, 0.7494427233598264, 0.9686762023490751]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.0002105009621202394], {
             RGBColor[
             0.743581503407994, 0.7996107889818441, 0.9750769131616334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.0002105009621202394], {
             RGBColor[
             0.3590992451452233, 0.4854554501171043, 0.9441024642550272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.0002105009621202394], {
             RGBColor[
             0.17909981633317154`, 0.30557564092335165`, 0.9335108416345153]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.0002105009621202394], {
             RGBColor[
             0.7409332819620127, 0.7975419782610151, 0.9748129631969344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.0002105009621202394], {
             RGBColor[
             0.1818250295794584, 0.30844001283369876`, 0.9336660384972996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.0002105009621202394], {
             RGBColor[
             0.49307848673520527`, 0.5993423543211548, 0.9532360911632574]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.0002105009621202394], {
             RGBColor[
             0.23875032994207512`, 0.36827211278731364`, 0.9369078501395155]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.0002105009621202394], {
             RGBColor[
             0.22285712514090053`, 0.35156734685389346`, 0.9360027556379781]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.0002105009621202394], {
             RGBColor[
             0.20781531186542476`, 0.3357574473953233, 0.9351461466243084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.0002105009621202394], {
             RGBColor[
             0.25816588373595994`, 0.3886790908418973, 0.9380135372053394]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.0002105009621202394], {
             RGBColor[
             0.6722342021283076, 0.7438737349625797, 0.9679656809485127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.0002105009621202394], {
             RGBColor[
             0.2515360626002474, 0.3817107284733248, 0.937635978699602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.0002105009621202394], {
             RGBColor[
             0.4286879330306734, 0.5457296739343299, 0.9485365939122276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.0002105009621202394], {
             RGBColor[
             0.2671426063657563, 0.39811419548290095`, 0.9385247482792353]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.0002105009621202394], {
             RGBColor[
             0.20898033639140454`, 0.33698196203894937`, 0.9352124930475636]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.0002105009621202394], {
             RGBColor[
             0.2765987024765969, 0.40805315204651627`, 0.939063258963707]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.0002105009621202394], {
             RGBColor[
             0.9941990383585994, 0.9900006545532618, 0.6099793085980734]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.0002105009621202394], {
             RGBColor[
             0.1948453625020903, 0.32212520827217295`, 0.9344075271953871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.0002105009621202394], {
             RGBColor[
             0.1899324083338537, 0.31696138194207063`, 0.9341277417235704]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.0002105009621202394], {
             RGBColor[
             0.30537118422496984`, 0.4382948546447645, 0.9407018092342045]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.0002105009621202394], {
             RGBColor[
             0.1861676814246589, 0.31300441526303435`, 0.9339133460955061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.0002105009621202394], {
             RGBColor[
             0.19821724293608944`, 0.32566926839787347`, 0.9345995507978533]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.0002105009621202394], {
             RGBColor[
             0.18717515147111807`, 0.3140633301591533, 0.9339707200242335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.0002105009621202394], {
             RGBColor[
             0.1943854920349882, 0.321641855253777, 0.934381338252603]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.0002105009621202394], {
             RGBColor[
             0.3488943015599562, 0.47661644089892424`, 0.9434522142736513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.0002105009621202394], {
             RGBColor[
             0.1899597624904289, 0.3169901328949849, 0.9341292995023205]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.0002105009621202394], {
             RGBColor[
             0.4290348579738498, 0.5460301628831548, 0.9485586996628331]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.0002105009621202394], {
             RGBColor[
             0.2449605595581574, 0.37479945786511576`, 0.9372615135289399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.0002105009621202394], {
             RGBColor[
             0.20692052412863532`, 0.33481696875113837`, 0.935095189786418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.0002105009621202394], {
             RGBColor[
             0.19699767297971368`, 0.3243874230485212, 0.9345300980930298]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.0002105009621202394], {
             RGBColor[
             0.18766218808016377`, 0.31457523651516484`, 0.9339984560386126]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.0002105009621202394], {
             RGBColor[
             0.9146994662552146, 0.9348205418090667, 0.9917260457249173]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.0002105009621202394], {
             RGBColor[
             0.18269671784651187`, 0.30935621247060024`, 0.933715679854561]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.0002105009621202394], {
             RGBColor[
             0.19137511524925596`, 0.3184777583830601, 0.9342099017481089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.0002105009621202394], {
             RGBColor[
             0.21323548342695858`, 0.34145439136522115`, 0.9354548173763124]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.0002105009621202394], {
             RGBColor[
             0.1808905282724361, 0.3074577927092133, 0.9336128200303355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.0002105009621202394], {
             RGBColor[
             0.18223318953702214`, 0.3088690148279342, 0.9336892826030643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.0002105009621202394], {
             RGBColor[
             0.20271236623405806`, 0.3303939279913168, 0.9348555414197336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.0002105009621202394], {
             RGBColor[
             0.3483545068205488, 0.47614889782652203`, 0.9434178190301781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.0002105009621202394], {
             RGBColor[
             0.20150049615977755`, 0.32912017570624735`, 0.9347865272118044]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.0002105009621202394], {
             RGBColor[
             0.2975965440226766, 0.4301232148514946, 0.9402590549762334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.0002105009621202394], {
             RGBColor[
             0.27959908951497947`, 0.4112067490593821, 0.9392341265668681]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.0002105009621202394], {
             RGBColor[
             0.3027440138032642, 0.4355335319593264, 0.9405521957652387]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.0002105009621202394], {
             RGBColor[
             0.3029090080003519, 0.4357069513217019, 0.9405615919406759]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.0002105009621202394], {
             RGBColor[
             0.218367213855187, 0.3468481654157909, 0.9357470618324852]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.0002105009621202394], {
             RGBColor[
             0.23267428983588884`, 0.3618858093925185, 0.936561828644164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.0002105009621202394], {
             RGBColor[
             0.2188459842157359, 0.34735138342052185`, 0.9357743270962412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.0002105009621202394], {
             RGBColor[
             0.23435379828218117`, 0.36365107925655765`, 0.9366574741655703]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.0002105009621202394], {
             RGBColor[
             0.1953540422101205, 0.32265986289746895`, 0.9344364957522352]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.0002105009621202394], {
             RGBColor[
             0.19439044372267295`, 0.3216470597914888, 0.9343816202438913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.0002105009621202394], {
             RGBColor[
             0.4533617737780597, 0.567098537525015, 0.9501094460321575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.0002105009621202394], {
             RGBColor[
             0.19579265616170655`, 0.32312087397031664`, 0.9344614741679068]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.0002105009621202394], {
             RGBColor[
             0.5543615420614805, 0.6490946994052059, 0.9580605177657702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.0002105009621202394], {
             RGBColor[
             0.1999051049994005, 0.32744331844304914`, 0.9346956720453906]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.0002105009621202394], {
             RGBColor[
             0.3986910652219958, 0.5197478947248675, 0.9466252200206473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.0002105009621202394], {
             RGBColor[
             0.6331296311169758, 0.713042182562431, 0.9642614302732361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.0002105009621202394], {
             RGBColor[
             0.289139123347183, 0.42123392949010874`, 0.9397774173803968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.0002105009621202394], {
             RGBColor[
             0.19201165546058205`, 0.31914680250414423`, 0.9342461517714671]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.0002105009621202394], {
             RGBColor[
             0.19560708734050541`, 0.3229258293734914, 0.9344509062980639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.0002105009621202394], {
             RGBColor[
             0.8695307562797816, 0.5004514607800906, 0.21284560375709155`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.0002105009621202394], {
             RGBColor[
             0.19044334897469703`, 0.3174984129511047, 0.9341568390371975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.0002105009621202394], {
             RGBColor[
             0.18593025704413854`, 0.31275486718553225`, 0.9338998251282734]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.0002105009621202394], {
             RGBColor[
             0.19914754728651962`, 0.3266470772548782, 0.9346525302543484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.0002105009621202394], {
             RGBColor[
             0.2283446787479909, 0.35733511362593967`, 0.9363152636977938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.0002105009621202394], {
             RGBColor[
             0.18811264277564865`, 0.31504869296059673`, 0.9340241087671325]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.0002105009621202394], {
             RGBColor[
             0.1849809522741401, 0.31175708768286514`, 0.9338457636259925]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.0002105009621202394], {
             RGBColor[
             0.1795029989097729, 0.3059994113746115, 0.9335338022857975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.0002105009621202394], {
             RGBColor[
             0.18035329176886106`, 0.3068931230811942, 0.933582225206227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.0002105009621202394], {
             RGBColor[
             0.9940468194635823, 0.9896750737285114, 0.5934112212615963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.0002105009621202394], {
             RGBColor[
             0.23420030298526878`, 0.3634897459673388, 0.9366487328354871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.0002105009621202394], {
             RGBColor[
             0.2515477771449798, 0.3817230412025836, 0.9376366458255944]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.0002105009621202394], {
             RGBColor[
             0.2029347338096705, 0.33062765041220404`, 0.9348682049242014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.0002105009621202394], {
             RGBColor[
             0.3362350503435996, 0.46565163376778274`, 0.9426455779802814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.0002105009621202394], {
             RGBColor[
             0.18371444184961855`, 0.31042590492529404`, 0.9337736377309502]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.0002105009621202394], {
             RGBColor[
             0.1820208818055452, 0.30864586594106436`, 0.9336771919918379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.0002105009621202394], {
             RGBColor[
             0.1912494582787511, 0.31834568493994736`, 0.9342027457695316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.0002105009621202394], {
             RGBColor[
             0.1789871968344326, 0.3054572706896884, 0.9335044281206677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.0002105009621202394], {
             RGBColor[
             0.3510664211934816, 0.47849782175157674`, 0.9435906198159696]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.0002105009621202394], {
             RGBColor[
             0.19785125300646603`, 0.3252845897767374, 0.9345787082127948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.0002105009621202394], {
             RGBColor[
             0.33313964664549794`, 0.4629705506640006, 0.9424483415937963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.0002105009621202394], {
             RGBColor[
             0.2019856527302044, 0.3296301060224692, 0.9348141561607654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.0002105009621202394], {
             RGBColor[
             0.9938504692273173, 0.9917250252368329, 0.751577169586235]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.0002105009621202394], {
             RGBColor[
             0.9097894237460113, 0.9309054071917814, 0.9912577214871428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.0002105009621202394], {
             RGBColor[
             0.2396024194233052, 0.3691677128576799, 0.9369563753749182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.0002105009621202394], {
             RGBColor[
             0.19002087389400624`, 0.31705436485483146`, 0.934132779706348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.0002105009621202394], {
             RGBColor[
             0.2158527042869893, 0.34420525643050026`, 0.9356038642324599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.0002105009621202394], {
             RGBColor[
             0.7657071355725306, 0.8168955009898127, 0.9772821894000061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.0002105009621202394], {
             RGBColor[
             0.19499177110397153`, 0.3222790929955916, 0.9344158649486721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.0002105009621202394], {
             RGBColor[
             0.85710048921771, 0.439904958487049, 0.20231279900164487`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.0002105009621202394], {
             RGBColor[
             0.19077583416012883`, 0.31784787596177183`, 0.9341757735766401]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.0002105009621202394], {
             RGBColor[
             0.18720392975649292`, 0.3140935779617309, 0.9339723589050121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.0002105009621202394], {
             RGBColor[
             0.18524924480481392`, 0.31203908014333226`, 0.9338610424887112]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.0002105009621202394], {
             RGBColor[
             0.21763599434706354`, 0.34607960735075854`, 0.93570541996324]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.0002105009621202394], {
             RGBColor[
             0.18916507484151227`, 0.3161548657898664, 0.9340840432163497]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.0002105009621202394], {
             RGBColor[
             0.21990087473071346`, 0.348460140235685, 0.9358344015504985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.0002105009621202394], {
             RGBColor[
             0.8176771202476999, 0.13687966915311423`, 0.16456093635363633`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.0002105009621202394], {
             RGBColor[
             0.18093049359979738`, 0.3074997988022181, 0.9336150959966053]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.0002105009621202394], {
             RGBColor[
             0.39439940253334044`, 0.5160306722091927, 0.9463517590690945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.0002105009621202394], {
             RGBColor[
             0.37508215881778845`, 0.49929904661568136`, 0.9451208813811075]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.0002105009621202394], {
             RGBColor[
             0.1851720653526604, 0.311957959645659, 0.9338566472330878]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.0002105009621202394], {
             RGBColor[
             0.19059767181486464`, 0.3176606160407541, 0.9341656274946448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.0002105009621202394], {
             RGBColor[
             0.18708771794254558`, 0.3139714319770177, 0.9339657408141276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.0002105009621202394], {
             RGBColor[
             0.18654757264035143`, 0.3134037050172214, 0.9339349803382411]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.0002105009621202394], {
             RGBColor[
             0.19406834726399882`, 0.3213085159913272, 0.9343632773270688]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.0002105009621202394], {
             RGBColor[
             0.271851153445097, 0.4030631770024157, 0.9387928930697325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.0002105009621202394], {
             RGBColor[
             0.19021908584372046`, 0.31726269818134456`, 0.934144067583656]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.0002105009621202394], {
             RGBColor[
             0.180596656524124, 0.30714891486919227`, 0.9335960844690134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.0002105009621202394], {
             RGBColor[
             0.209601906353837, 0.3376352714792777, 0.9352478905373938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.0002105009621202394], {
             RGBColor[
             0.18473621585810335`, 0.3114998541924255, 0.9338318262491543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.0002105009621202394], {
             RGBColor[
             0.19081859398490578`, 0.3178928192487419, 0.9341782086854036]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.0002105009621202394], {
             RGBColor[
             0.20710183530283005`, 0.33500753829100943`, 0.9351055151895625]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.0002105009621202394], {
             RGBColor[
             0.22012423896070668`, 0.348694910203518, 0.9358471218129588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.0002105009621202394], {
             RGBColor[
             0.19616341759440778`, 0.32351056774371817`, 0.9344825884830068]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.0002105009621202394], {
             RGBColor[
             0.1818914944971056, 0.30850987167626515`, 0.9336698235760336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.0002105009621202394], {
             RGBColor[
             0.20835388918653433`, 0.3363235263075839, 0.9351768178059918]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.0002105009621202394], {
             RGBColor[
             0.18955786573703887`, 0.316567713925446, 0.9341064120767679]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.0002105009621202394], {
             RGBColor[
             0.9944253181788963, 0.9904846442084778, 0.6346084706002231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.0002105009621202394], {
             RGBColor[
             0.7607606134285254, 0.8130312402959552, 0.9767891663005692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.0002105009621202394], {
             RGBColor[
             0.5341260408491124, 0.6326666079220644, 0.9564675049852491]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.0002105009621202394], {
             RGBColor[
             0.2195142065627996, 0.3480537274750297, 0.9358123813703602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.0002105009621202394], {
             RGBColor[
             0.20264865261830456`, 0.3303269609414833, 0.9348519130235723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.0002105009621202394], {
             RGBColor[
             0.2627109211596987, 0.39345621334626335`, 0.938272370362841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.0002105009621202394], {
             RGBColor[
             0.18112688553091424`, 0.3077062191737896, 0.9336262802265466]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.0002105009621202394], {
             RGBColor[
             0.9910839134677017, 0.9905809833329919, 0.7974261581398643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.0002105009621202394], {
             RGBColor[
             0.18336325239717496`, 0.31005678254407854`, 0.9337536380111718]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.0002105009621202394], {
             RGBColor[
             0.18043226082461958`, 0.30697612456572376`, 0.9335867223771283]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.0002105009621202394], {
             RGBColor[
             0.46863892160806836`, 0.5795012143610829, 0.9513121190713723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.0002105009621202394], {
             RGBColor[
             0.19955786085140656`, 0.3270783428269569, 0.9346758970048641]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.0002105009621202394], {
             RGBColor[
             0.2129233554713194, 0.341126325093789, 0.9354370421509908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.0002105009621202394], {
             RGBColor[
             0.4260942433398349, 0.54348315028676, 0.9483713262986371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.0002105009621202394], {
             RGBColor[
             0.9265760623547111, 0.7466055848528861, 0.2597795801705179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.0002105009621202394], {
             RGBColor[
             0.8501784807301029, 0.38669936800784144`, 0.19568427585662201`]},
             StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{{3.8349502435193233`*^9, 3.8349502581408367`*^9}, 
   3.834950528174912*^9, 3.8349578088972807`*^9, 3.8349599247259827`*^9, 
   3.835023953872756*^9},
 CellLabel->
  "Out[208]=",ExpressionUUID->"7ee1f39f-f4d9-420c-9635-d15173e6690d"]
}, Open  ]],

Cell["r = 3 :", "Text",
 CellChangeTimes->{{3.834793779215767*^9, 3.8347938725231647`*^9}, {
  3.8347953347101345`*^9, 3.8347953431477337`*^9}, {3.8348851911359825`*^9, 
  3.83488519180678*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"1e7a4694-b9a6-44c2-9350-6aa5f4ecce93"],

Cell["Cubic Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.834795179278664*^9}},ExpressionUUID->"e269e12f-3f8f-400d-b534-\
67e1433b8d0c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c\[Rho]3i4b", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"CMDi3400b", ",", "kri4b"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.834947911760502*^9, 
   3.834947914304406*^9}, {3.834947957535968*^9, 3.8349479704802837`*^9}, {
   3.8349480487781425`*^9, 3.834948105065866*^9}, {3.8349497992119355`*^9, 
   3.83494980454772*^9}, {3.8349578354451995`*^9, 3.83495784069214*^9}, {
   3.8349599319657245`*^9, 3.834959936443318*^9}},
 CellLabel->
  "In[209]:=",ExpressionUUID->"021e7b2c-46a4-4a4e-97aa-5b07ce38b04e"],

Cell[BoxData["0.05627458731660898`"], "Output",
 CellChangeTimes->{
  3.834948013482303*^9, {3.834948049945756*^9, 3.834948058990469*^9}, 
   3.8349481059508953`*^9, 3.8349499476386404`*^9, 3.834957841643118*^9, 
   3.8349599379579067`*^9, 3.835023954857345*^9},
 CellLabel->
  "Out[209]=",ExpressionUUID->"3a1cc889-def0-4978-a4e2-88eca3ab87aa"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CP3i4b", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"CMDi3400b", ",", "kri4b"}], "}"}], "]"}], ",", "c\[Rho]3i4b"}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.8349481210775223`*^9, 3.834948150679065*^9}, {
  3.8349481924167476`*^9, 3.8349481986802473`*^9}, {3.834949807949147*^9, 
  3.834949815491851*^9}, {3.8349578438231587`*^9, 3.8349578533989754`*^9}, {
  3.834959942835306*^9, 3.8349599504511766`*^9}},
 CellLabel->
  "In[210]:=",ExpressionUUID->"539b67a8-b6f7-4e98-881b-0f2dd06d6c8b"],

Cell[BoxData["0.8860196038591143`"], "Output",
 CellChangeTimes->{3.8349481513130674`*^9, 3.8349482002632475`*^9, 
  3.8349499490044084`*^9, 3.8349578559445095`*^9, 3.8349599510791645`*^9, 
  3.8350239548993464`*^9},
 CellLabel->
  "Out[210]=",ExpressionUUID->"f78090e9-c5fa-432d-ba8e-8c169558b1b3"]
}, Open  ]],

Cell["Absolute Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.8347951985065947`*^9}},ExpressionUUID->"50509af0-ec2c-49a4-b12f-\
84aaf02601cc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a\[Rho]3i4b", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"AMDi3400b", ",", "kri4b"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.8348873709111376`*^9, 
   3.8348873755217657`*^9}, {3.8349481641806583`*^9, 
   3.8349481824982553`*^9}, {3.834949818653184*^9, 3.8349498238056817`*^9}, {
   3.834957866337153*^9, 3.834957872254816*^9}, {3.8349599558860984`*^9, 
   3.834959960688223*^9}},
 CellLabel->
  "In[211]:=",ExpressionUUID->"b73504d9-d6c7-4e86-9a27-39df685be355"],

Cell[BoxData["0.036231495846565404`"], "Output",
 CellChangeTimes->{3.834948182946122*^9, 3.83494995054953*^9, 
  3.834957874365346*^9, 3.834959961213229*^9, 3.8350239549233437`*^9},
 CellLabel->
  "Out[211]=",ExpressionUUID->"a4c1c8e8-be66-4788-bc03-b059cfa15745"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"aP3i4b", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"AMDi3400b", ",", "kri4b"}], "}"}], "]"}], ",", "a\[Rho]3i4b"}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8349482041094093`*^9, 
  3.8349482202691827`*^9}, {3.8349498269490285`*^9, 3.8349498405604887`*^9}, {
  3.8349578796796703`*^9, 3.834957886620027*^9}, {3.834959967114936*^9, 
  3.834959972411192*^9}},
 CellLabel->
  "In[212]:=",ExpressionUUID->"82985208-345c-44ed-b366-3774a9970ec1"],

Cell[BoxData["0.6783235215596152`"], "Output",
 CellChangeTimes->{3.834887440036944*^9, 3.8349482220989213`*^9, 
  3.8349499520491343`*^9, 3.8349578874036503`*^9, 3.834959973000204*^9, 
  3.8350239549546766`*^9},
 CellLabel->
  "Out[212]=",ExpressionUUID->"f94fb8b0-2387-4f53-a1ac-78ab2e5e5ab9"]
}, Open  ]],

Cell["Max-min Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 3.8347951985065947`*^9}, {
  3.8348543263190746`*^9, 
  3.834854330052075*^9}},ExpressionUUID->"83950b7e-7ecb-4bbd-ab3c-\
0f7d85239b11"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mM\[Rho]3i4b", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"mMDi3400b", ",", "kri4b"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8348874651734295`*^9, 3.8348874872060013`*^9}, {
  3.8349482319487157`*^9, 3.834948245258479*^9}, {3.834949844516972*^9, 
  3.8349498489188633`*^9}, {3.834957895209076*^9, 3.834957899999796*^9}, {
  3.834959978361562*^9, 3.834959981935949*^9}},
 CellLabel->
  "In[213]:=",ExpressionUUID->"2d22c03d-fa87-4829-830f-ebade5efc2ce"],

Cell[BoxData["0.08676373889639935`"], "Output",
 CellChangeTimes->{3.834948246413353*^9, 3.834949953689977*^9, 
  3.834957900696502*^9, 3.834959982440987*^9, 3.8350239549703045`*^9},
 CellLabel->
  "Out[213]=",ExpressionUUID->"caaad27e-0ff9-4283-bb9c-f8ef3cf5bf01"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mMP3i4b", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"mMDi3400b", ",", "kri4b"}], "}"}], "]"}], ",", 
    "mM\[Rho]3i4b"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8348875260806427`*^9, 
  3.8348875488478312`*^9}, {3.8349482525846663`*^9, 3.8349482707073736`*^9}, {
  3.8349498532537427`*^9, 3.834949860995207*^9}, {3.834957902898573*^9, 
  3.8349579090270967`*^9}, {3.834959985194945*^9, 3.8349599908316746`*^9}},
 CellLabel->
  "In[214]:=",ExpressionUUID->"2194f5b0-2dec-4a74-b708-c573270a0420"],

Cell[BoxData["0.6676200590663575`"], "Output",
 CellChangeTimes->{3.834887440036944*^9, 3.8348875533996215`*^9, 
  3.834948277702903*^9, 3.834949955989804*^9, 3.834957909480212*^9, 
  3.834959991339159*^9, 3.8350239549859304`*^9},
 CellLabel->
  "Out[214]=",ExpressionUUID->"ba965e69-61fa-4fdd-84a1-fd7a197cf144"]
}, Open  ]],

Cell["r = 6 :", "Text",
 CellChangeTimes->{{3.834793779215767*^9, 3.8347938725231647`*^9}, {
  3.8347953347101345`*^9, 3.8347953431477337`*^9}, {3.8348851911359825`*^9, 
  3.83488519180678*^9}, {3.834948305866973*^9, 3.8349483068980722`*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"9a0facfc-8fed-42ef-947d-0acaf9d00f19"],

Cell["Cubic Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.834795179278664*^9}},ExpressionUUID->"f1d1da29-bfb4-4262-8702-\
804c88ce7a4c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c\[Rho]6i4b", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"CMDi6400b", ",", "kri4b"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.834947911760502*^9, 
   3.834947914304406*^9}, {3.834947957535968*^9, 3.8349479704802837`*^9}, {
   3.8349480487781425`*^9, 3.834948105065866*^9}, {3.8349483158342133`*^9, 
   3.8349483193845987`*^9}, {3.834949864783629*^9, 3.834949869574106*^9}, {
   3.834957963470776*^9, 3.834957967378231*^9}, {3.8349599948375783`*^9, 
   3.8349599978979335`*^9}},
 CellLabel->
  "In[215]:=",ExpressionUUID->"49519ffb-7f98-4bfe-9b2f-1a1b1e6a5dd7"],

Cell[BoxData["0.0938646317835916`"], "Output",
 CellChangeTimes->{
  3.834948013482303*^9, {3.834948049945756*^9, 3.834948058990469*^9}, 
   3.8349481059508953`*^9, 3.834948360850016*^9, 3.8349499580565577`*^9, 
   3.834957967763415*^9, 3.8349599984661875`*^9, 3.8350239550205283`*^9},
 CellLabel->
  "Out[215]=",ExpressionUUID->"9f721757-9b05-4b39-b13b-84cf0c84e1e9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CP6i4b", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"CMDi6400b", ",", "kri4b"}], "}"}], "]"}], ",", "c\[Rho]6i4b"}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.8349481210775223`*^9, 3.834948150679065*^9}, {
  3.8349481924167476`*^9, 3.8349481986802473`*^9}, {3.8349483230197706`*^9, 
  3.834948338654296*^9}, {3.8349498724373255`*^9, 3.8349498802583637`*^9}, {
  3.8349579696959915`*^9, 3.834957975592292*^9}, {3.8349600006874633`*^9, 
  3.8349600065635686`*^9}},
 CellLabel->
  "In[216]:=",ExpressionUUID->"c43fcb26-51b5-4448-bb05-c7f40cb6f5bb"],

Cell[BoxData["0.568249090926707`"], "Output",
 CellChangeTimes->{3.8349481513130674`*^9, 3.8349482002632475`*^9, 
  3.834948361143017*^9, 3.8349499593900194`*^9, 3.8349579759739666`*^9, 
  3.8349600070949645`*^9, 3.835023955048536*^9},
 CellLabel->
  "Out[216]=",ExpressionUUID->"cd5e8901-aa24-4318-ad31-684d577f1a6a"]
}, Open  ]],

Cell["Absolute Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.8347951985065947`*^9}},ExpressionUUID->"634afaed-6fef-48d3-bcd3-\
abc68909f126"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a\[Rho]6i4b", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"AMDi6400b", ",", "kri4b"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.8348873709111376`*^9, 
   3.8348873755217657`*^9}, {3.8349481641806583`*^9, 
   3.8349481824982553`*^9}, {3.834948329127375*^9, 3.834948332212267*^9}, {
   3.834949883458797*^9, 3.8349498875077024`*^9}, {3.834957978394422*^9, 
   3.8349579827581863`*^9}, {3.8349600106550846`*^9, 3.8349600137518945`*^9}},
 CellLabel->
  "In[217]:=",ExpressionUUID->"f60e5dc3-523b-4cba-b884-ee40d614f218"],

Cell[BoxData["0.03053475278757897`"], "Output",
 CellChangeTimes->{3.834948182946122*^9, 3.8349483612910123`*^9, 
  3.8349499607430162`*^9, 3.834957983223776*^9, 3.8349600149698515`*^9, 
  3.83502395507353*^9},
 CellLabel->
  "Out[217]=",ExpressionUUID->"362a8054-57f3-4cc6-8137-45e30c656b87"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"aP6i4b", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"AMDi6400b", ",", "kri4b"}], "}"}], "]"}], ",", "a\[Rho]6i4b"}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8349482041094093`*^9, 
  3.8349482202691827`*^9}, {3.834948340881687*^9, 3.834948354997751*^9}, {
  3.8349498907390194`*^9, 3.8349498979971194`*^9}, {3.8349579853563895`*^9, 
  3.8349579919125147`*^9}, {3.834960018002163*^9, 3.834960023981127*^9}},
 CellLabel->
  "In[218]:=",ExpressionUUID->"c2bcc717-ce00-4c40-8313-03d3e1378fc0"],

Cell[BoxData["0.7000883467371395`"], "Output",
 CellChangeTimes->{3.834887440036944*^9, 3.8349482220989213`*^9, 
  3.834948361458013*^9, 3.834949962307019*^9, 3.834957992381853*^9, 
  3.8349600245340567`*^9, 3.8350239551035547`*^9},
 CellLabel->
  "Out[218]=",ExpressionUUID->"71103c7a-25df-425c-80e9-b78205d24133"]
}, Open  ]],

Cell["Max-min Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 3.8347951985065947`*^9}, {
  3.8348543263190746`*^9, 
  3.834854330052075*^9}},ExpressionUUID->"59d81141-f31a-4162-995d-\
07bf2cc7c2cb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mM\[Rho]6i4b", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"mMDi6400b", ",", "kri4b"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8348874651734295`*^9, 3.8348874872060013`*^9}, {
   3.8349482319487157`*^9, 3.834948245258479*^9}, 3.8349483527075925`*^9, {
   3.8349499042423377`*^9, 3.8349499090679235`*^9}, {3.834949978751977*^9, 
   3.8349499794842105`*^9}, {3.834957994342047*^9, 3.834957998175455*^9}, {
   3.834960028916318*^9, 3.834960032765731*^9}},
 CellLabel->
  "In[219]:=",ExpressionUUID->"5d22d1cb-5d1b-4f9d-b987-31bdcef81b27"],

Cell[BoxData["0.05996371581767121`"], "Output",
 CellChangeTimes->{
  3.834948246413353*^9, 3.8349483615970154`*^9, {3.834949963955017*^9, 
   3.8349499810066743`*^9}, 3.834957999014784*^9, 3.8349600332282467`*^9, 
   3.835023955124531*^9},
 CellLabel->
  "Out[219]=",ExpressionUUID->"679163b0-0d82-4ddb-88f2-d3497595f36c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mMP6i4b", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"mMDi6400b", ",", "kri4b"}], "}"}], "]"}], ",", 
    "mM\[Rho]6i4b"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8348875260806427`*^9, 
  3.8348875488478312`*^9}, {3.8349482525846663`*^9, 3.8349482707073736`*^9}, {
  3.83494834565068*^9, 3.8349483504716325`*^9}, {3.8349499122654495`*^9, 
  3.83494991854418*^9}, {3.834958000997678*^9, 3.8349580074869604`*^9}, {
  3.8349600359953957`*^9, 3.834960041249071*^9}},
 CellLabel->
  "In[220]:=",ExpressionUUID->"c5416687-6114-47b1-920a-0946768de353"],

Cell[BoxData["0.8892928062054839`"], "Output",
 CellChangeTimes->{
  3.834887440036944*^9, 3.8348875533996215`*^9, 3.834948277702903*^9, 
   3.8349483617580156`*^9, {3.834949965578516*^9, 3.8349499927811513`*^9}, 
   3.834958007945059*^9, 3.8349600416626554`*^9, 3.835023955145528*^9},
 CellLabel->
  "Out[220]=",ExpressionUUID->"c4de6a9c-3342-4a1d-9ca7-8a2323300db8"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5th imported file", "Subsection",
 CellChangeTimes->{{3.834947473073307*^9, 3.8349474798089457`*^9}, {
   3.8349497159535103`*^9, 3.8349497173354855`*^9}, {3.834956622993673*^9, 
   3.834956623710862*^9}, {3.8350187834860272`*^9, 3.835018783813758*^9}, 
   3.835201755445879*^9},
 Background->RGBColor[
  1, 1, 0],ExpressionUUID->"f010d430-1c90-4ed7-81e4-8fac5055d5a6"],

Cell["Dividing stuff", "Text",
 CellChangeTimes->{{3.83494752022309*^9, 
  3.834947523245259*^9}},ExpressionUUID->"1586e777-c654-46f9-a015-\
aafbe5c204f5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetDirectory", "[", 
  RowBox[{"NotebookDirectory", "[", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.835018964424471*^9, 3.8350189800655127`*^9}},
 CellLabel->"In[38]:=",ExpressionUUID->"b4b7d1e9-b3bc-415c-9599-b79c4a8c55e2"],

Cell[BoxData["\<\"C:\\\\Users\\\\Ariadna\\\\Desktop\\\\wolf\\\\cososchidos\"\>\
"], "Output",
 CellChangeTimes->{3.8350189805365133`*^9},
 CellLabel->"Out[38]=",ExpressionUUID->"03aff2b5-51f9-4705-a319-e5c44b0706ba"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"data5", "=", 
   RowBox[{"StringSplit", "[", 
    RowBox[{
     RowBox[{"Import", "[", "\"\<ariadnaComputation5.txt\>\"", "]"}], ",", 
     "\"\<]\n{\>\""}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8349434033501863`*^9, 3.834943479535334*^9}, {
   3.834943567297134*^9, 3.8349435736474867`*^9}, {3.8349441109152327`*^9, 
   3.8349441401892223`*^9}, 3.834944204627252*^9, {3.834949720382628*^9, 
   3.8349497230261507`*^9}, {3.834956627593688*^9, 3.834956631231691*^9}, {
   3.8350187858989725`*^9, 3.8350187908769827`*^9}},
 CellLabel->"In[39]:=",ExpressionUUID->"07d3457e-7b2a-427a-b5ab-3e2acc9d7fe7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"graphi5", "=", 
   RowBox[{"ToExpression", "@", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"data5", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
       "<>", "\"\<]\>\""}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834944474381714*^9, 3.83494454689666*^9}, 
   3.8349475108233376`*^9, {3.834949726505718*^9, 3.8349497324197383`*^9}, {
   3.8349566345564103`*^9, 3.834956636582815*^9}, {3.8350188037132354`*^9, 
   3.8350188065525265`*^9}},
 CellLabel->"In[40]:=",ExpressionUUID->"2e6343e7-601f-47d2-b727-e9d7f7200786"],

Cell[BoxData[
 RowBox[{
  RowBox[{"otheri5", "=", 
   RowBox[{"ToExpression", "@", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "<>", "\"\<}}\>\""}], "&"}], ",", 
      RowBox[{"StringSplit", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\"\<{\>\"", "<>", 
          RowBox[{
          "data5", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
         ")"}], ",", "\"\<}}\>\""}], "]"}]}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834944518155362*^9, 3.8349445533517303`*^9}, 
   3.8349446259294133`*^9, {3.8349447635371876`*^9, 3.8349447780382657`*^9}, {
   3.834944820013957*^9, 3.8349448816359477`*^9}, {3.834944915595456*^9, 
   3.834944918286141*^9}, {3.8349449615053425`*^9, 3.834944967406804*^9}, {
   3.834945029266304*^9, 3.834945031628281*^9}, {3.834945108799203*^9, 
   3.8349451822852197`*^9}, 3.834945584171259*^9, {3.834949734758335*^9, 
   3.8349497379503355`*^9}, {3.834956638769047*^9, 3.8349566423540664`*^9}, {
   3.8350188094708586`*^9, 3.8350188125204616`*^9}},
 CellLabel->"In[41]:=",ExpressionUUID->"9d6a3b6c-6a2a-453e-ab7a-493da085f7be"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "CMDi3500", "}"}], ",", 
     RowBox[{"{", "AMDi3500", "}"}], ",", 
     RowBox[{"{", "mMDi3500", "}"}], ",", 
     RowBox[{"{", "CMDi6500", "}"}], ",", 
     RowBox[{"{", "AMDi6500", "}"}], ",", 
     RowBox[{"{", "mMDi6500", "}"}]}], "}"}], "=", "otheri5"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.834945694541313*^9, 3.834945753140644*^9}, {
  3.8349459487260857`*^9, 3.8349459670133495`*^9}, {3.8349471029719105`*^9, 
  3.8349471182020655`*^9}, {3.83494974203613*^9, 3.8349497544188104`*^9}, {
  3.834956647753375*^9, 3.8349566844693546`*^9}, {3.8350188134722548`*^9, 
  3.835018816812196*^9}},
 CellLabel->"In[42]:=",ExpressionUUID->"ad049d4a-c4e6-4e8f-8461-cbc3e8da1dfe"],

Cell["\[OpenCurlyDoubleQuote]Cleaning\[CloseCurlyDoubleQuote] the graph:", \
"Text",
 CellChangeTimes->{{3.8349477786156034`*^9, 
  3.8349478283202667`*^9}},ExpressionUUID->"ee8345ed-bbc3-497b-a282-\
4f61929df246"],

Cell[BoxData[
 RowBox[{
  RowBox[{"graphin5", "=", 
   RowBox[{"IndexGraph", "@", "graphi5"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834946654863307*^9, 3.834946693639777*^9}, {
  3.834949757637121*^9, 3.834949759707878*^9}, {3.8349566892836237`*^9, 
  3.834956691608691*^9}, {3.83501881773997*^9, 3.8350188182388163`*^9}},
 CellLabel->"In[43]:=",ExpressionUUID->"937967e4-ee8e-4dc6-986d-7d90947cf059"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pointsi5", "=", 
   RowBox[{"VertexList", "@", "graphin5"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834784420352569*^9, 3.8347844264642625`*^9}, {
  3.8348756828269844`*^9, 3.8348756865131674`*^9}, {3.834878831782991*^9, 
  3.8348788488376627`*^9}, {3.8349467020325813`*^9, 3.834946739879963*^9}, {
  3.8349497621629615`*^9, 3.8349497641865125`*^9}, {3.834956695197647*^9, 
  3.834956697830969*^9}, {3.835018818796376*^9, 3.8350188192932053`*^9}},
 CellLabel->"In[44]:=",ExpressionUUID->"b3856751-5e0b-4486-be9e-322350ce9e3f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"coordpointsi5", "=", 
   RowBox[{"VertexList", "@", "graphi5"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834879134322084*^9, 3.834879146224797*^9}, {
  3.834946724882841*^9, 3.834946736706849*^9}, {3.834949767417904*^9, 
  3.8349497706963253`*^9}, {3.8349567000470257`*^9, 3.8349567019660654`*^9}, {
  3.835018819834511*^9, 3.835018820572505*^9}},
 CellLabel->"In[45]:=",ExpressionUUID->"ad4b39a8-3019-47c6-80a0-5c8b88da99b2"],

Cell["Kretchmann \[OpenCurlyDoubleQuote]real\[CloseCurlyDoubleQuote] \
values:", "Text",
 CellChangeTimes->{
  3.8347933561184683`*^9, {3.8347935444076195`*^9, 
   3.834793546974228*^9}},ExpressionUUID->"89097339-fe69-4f73-964e-\
aa6544022ac0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rvali5", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Sinh", "[", "\[Nu]", "]"}], "\[Equal]", "#"}], ",", 
       RowBox[{"{", "\[Nu]", "}"}]}], "]"}], "&"}], "/@", 
    RowBox[{"coordpointsi5", "\[LeftDoubleBracket]", 
     RowBox[{";;", ",", "3"}], "\[RightDoubleBracket]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834105426841242*^9, 3.8341054487325706`*^9}, {
   3.8341407674337025`*^9, 3.834140799285215*^9}, {3.8341408938375945`*^9, 
   3.834140946496229*^9}, {3.8341410168099756`*^9, 3.8341410671886864`*^9}, {
   3.8341411610986195`*^9, 3.834141210381962*^9}, {3.834141332672348*^9, 
   3.834141336755044*^9}, {3.834141461053176*^9, 3.834141468978607*^9}, {
   3.834141967115094*^9, 3.8341420256686225`*^9}, {3.8341640069512*^9, 
   3.834164012603241*^9}, {3.834164792400744*^9, 3.8341647947633886`*^9}, {
   3.83466546628111*^9, 3.834665483801684*^9}, {3.8347933895124626`*^9, 
   3.834793417249506*^9}, 3.8347960586942053`*^9, 3.834879156483405*^9, {
   3.8348862453609915`*^9, 3.8348862641404076`*^9}, 3.834886374221485*^9, {
   3.834946768449996*^9, 3.8349467823353415`*^9}, {3.8349468446168528`*^9, 
   3.834946857637892*^9}, 3.8349474594107084`*^9, {3.834949773350379*^9, 
   3.8349497766098785`*^9}, {3.8349567056279964`*^9, 
   3.8349567091770997`*^9}, {3.8350188215027976`*^9, 3.835018822410869*^9}},
 CellLabel->"In[71]:=",ExpressionUUID->"049814c9-8ce4-4f06-b869-512b8d087396"],

Cell[BoxData[
 RowBox[{
  RowBox[{"kri5", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"KHyperboloid", "/.", "rvali5"}], ")"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834792366597866*^9, 3.834792376019791*^9}, {
   3.834793346399704*^9, 3.8347933590872536`*^9}, {3.834793445378667*^9, 
   3.8347934527754736`*^9}, {3.834793487784485*^9, 3.834793489659489*^9}, 
   3.8348550102643666`*^9, {3.8348863808528233`*^9, 3.83488645374378*^9}, {
   3.834886485165092*^9, 3.834886521271514*^9}, 3.8348865820814276`*^9, {
   3.83494679091998*^9, 3.8349467979310513`*^9}, {3.8349468742957215`*^9, 
   3.834946904080855*^9}, 3.8349474644429636`*^9, {3.834949779141443*^9, 
   3.834949781745859*^9}, {3.8349567110647635`*^9, 3.8349567138998594`*^9}, {
   3.8350188233356256`*^9, 3.8350188239955263`*^9}},
 CellLabel->"In[72]:=",ExpressionUUID->"4e5b7f33-52cd-4b92-bb98-f214b43060a3"],

Cell["Estimated with cubic Mean Deviation v Calculated: (r=3)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 
  3.8349503319477153`*^9}},ExpressionUUID->"71b69caa-46f3-48fa-8e00-\
dea727532b39"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraphc", "[", 
     RowBox[{"graphin5", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsi5", ",", "#"}], "}"}], "]"}], ",", "500", ",", "3"}], 
     "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"CMDi3500", ",", "kri5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349567344957485`*^9, 3.834956749729442*^9}, {
   3.8349587420893497`*^9, 3.834958755264699*^9}, {3.835018825281867*^9, 
   3.835018828052806*^9}, 3.8350518927275763`*^9, {3.8350558643117256`*^9, 
   3.8350558645596995`*^9}, {3.83505601160785*^9, 3.8350560120502586`*^9}, {
   3.8350560778426647`*^9, 3.835056078543024*^9}},
 Background->RGBColor[1, 1, 0.85],
 CellLabel->
  "In[510]:=",ExpressionUUID->"ab1b5084-de27-499b-b61a-d1b87869b355"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1dOWGAgQBNBMbNu2bds2J+bEtm3btm3btu01sjdnH271F1R1ssCg6p0C
ggUL9l38vMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEIS
kZgkJCUZyUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpR
mCIUpRjFKUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGY
JjSlGYE0pwUtaUVr2tCWdrSnAx3pRBCd6UJXutGdHvSkF73pQ1/60Z8BDGQQ
gxnCUIYxnBGMZBSjGcNYxjGeCUxkEpOZwlSmMZ0ZzGQWs5nDXOYxnwUsZBGL
WcJSlrGcFaxkFatZw1rWsZ4NbGQTm9nCVraxnR3sZBe72cNe9rGfAxzkEIc5
wlGOcZwTnOQUpznDWc5xngtc5BKXucJVrnGdG9zkFre5w13ucZ8HPOQRj3nC
U57xnBe85BWvecNb3vGeD3zkE5/5wle+8Z1f+JXf+J0/+JO/+Jt/+Jcf/Cx/
AMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEISkZgkJCUZ
yUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpRmCIUpRjF
KUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGYJjSlGYE0
pwUtaUVr2tCWdrSnAx35Od5BdKYLXelGd3rQk170pg996Ud/BjCQQQxmCEMZ
xnBGMJJRjGYMYxnHeCYwkUlMZgpTmcZ0ZjCTWcxmDnOZx3wWsJBFLGYJS1nG
clawklWsZg1rWcd6NrCRTWxmC1vZxnZ2sJNd7GYPe9nHfg5wkEMc5ghHOcZx
TnCSU5zmDGc5x3kucJFLXOYKV7nGdW5wk1vc5g53ucd9HvCQRzzmCU95xnNe
8JJXvOYNb3nHez7wkU985gtf+Rbw/z//Dz189+A=
          "], {Null, CompressedData["
1:eJxF3Al0ldW5gOF/21YsVqt2QFCqdkClVEWUGRVRJmWoghGKIgREKWUqk4DM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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[13, 59] -> 
             RGBColor[
              0.8762955154472972, 0.419453515707833, 0.3146013156838614], 
             UndirectedEdge[210, 309] -> 
             RGBColor[
              0.551606910018279, 0.6371521859089969, 0.9610676201165934], 
             UndirectedEdge[88, 427] -> 
             RGBColor[
              0.9625916333128837, 0.9583852931829853, 0.6920298699453031], 
             UndirectedEdge[293, 483] -> 
             RGBColor[
              0.7010378126880227, 0.764543116645884, 0.9705091287592928], 
             UndirectedEdge[46, 150] -> 
             RGBColor[
              0.8426137997756449, 0.29206580132365323`, 0.18701154579507184`],
              UndirectedEdge[400, 444] -> 
             RGBColor[
              0.6902406432358092, 0.753839915276441, 0.9457042451644624], 
             UndirectedEdge[98, 105] -> 
             RGBColor[
              0.6705736842259354, 0.2564287067697931, 0.42456145885618224`], 
             UndirectedEdge[128, 439] -> 
             RGBColor[
              0.7938791369412646, 0.7474459292680824, 0.6147663681961599], 
             UndirectedEdge[23, 62] -> 
             RGBColor[
              0.6410358437860526, 0.7180620114019811, 0.965840197189024], 
             UndirectedEdge[201, 236] -> 
             RGBColor[
              0.8795236247841236, 0.9059844633112636, 0.9498754275303936], 
             UndirectedEdge[40, 477] -> 
             RGBColor[
              0.3017447193068194, 0.430740209091131, 0.9406323370239056], 
             UndirectedEdge[455, 482] -> 
             RGBColor[
              0.5823802102443625, 0.6577957576959257, 0.9645927528711051], 
             UndirectedEdge[60, 131] -> 
             RGBColor[
              0.6356958777519701, 0.7021782909701936, 0.8921377060479421], 
             UndirectedEdge[179, 222] -> 
             RGBColor[
              0.6146045338644772, 0.6788661543746903, 0.8611017815584795], 
             UndirectedEdge[111, 175] -> 
             RGBColor[
              0.5967362895950796, 0.6817266377028615, 0.9625356655761559], 
             UndirectedEdge[51, 110] -> 
             RGBColor[
              0.6187583138466675, 0.6922331423247292, 0.962361044680548], 
             UndirectedEdge[84, 261] -> 
             RGBColor[
              0.6984248476196209, 0.2804195075964744, 0.42637271416751843`], 
             UndirectedEdge[156, 479] -> 
             RGBColor[
              0.9054892498383735, 0.6380089387172945, 0.34991482372739113`], 
             UndirectedEdge[158, 437] -> 
             RGBColor[
              0.6909564240274537, 0.6685139642145062, 0.6075908462519746], 
             UndirectedEdge[103, 355] -> 
             RGBColor[
              0.566641764416217, 0.649140570695662, 0.9625016579508416], 
             UndirectedEdge[13, 228] -> 
             RGBColor[
              0.8561700630101069, 0.3479287652771972, 0.19802873831860587`], 
             UndirectedEdge[59, 409] -> 
             RGBColor[
              0.8900933096011159, 0.5255094078060346, 0.32781409894793784`], 
             UndirectedEdge[243, 430] -> 
             RGBColor[
              0.9089480415477251, 0.7359768277829247, 0.5960599069340393], 
             UndirectedEdge[333, 441] -> 
             RGBColor[
              0.9471693709138729, 0.8224146456028043, 0.30674626713457676`], 
             UndirectedEdge[179, 385] -> 
             RGBColor[
              0.6118933733470251, 0.6777450198270768, 0.9060327275911662], 
             UndirectedEdge[81, 447] -> 
             RGBColor[
              0.46525283508770876`, 0.566056164870037, 0.9530362685570384], 
             UndirectedEdge[69, 404] -> 
             RGBColor[
              0.9306591454739993, 0.7613088556091931, 0.565298747591365], 
             UndirectedEdge[113, 380] -> 
             RGBColor[
              0.9394083350164297, 0.9260547902704581, 0.6730303501298298], 
             UndirectedEdge[85, 489] -> 
             RGBColor[
              0.8418862167969121, 0.876809164054289, 0.9576314856571986], 
             UndirectedEdge[277, 498] -> 
             RGBColor[
              0.6933071663888846, 0.6632808313096366, 0.606063482635282], 
             UndirectedEdge[18, 160] -> 
             RGBColor[
              0.7034342055745679, 0.7637982372116092, 0.9178182682002112], 
             UndirectedEdge[355, 431] -> 
             RGBColor[
              0.6383092952644802, 0.7016784687910107, 0.7339382245913388], 
             UndirectedEdge[357, 492] -> 
             RGBColor[
              0.8736245523133166, 0.4189433682214191, 0.402070105230136], 
             UndirectedEdge[165, 386] -> 
             RGBColor[
              0.590349382338125, 0.6687880180856969, 0.9646502559177205], 
             UndirectedEdge[218, 274] -> 
             RGBColor[
              0.8571216128090124, 0.4068618534053179, 0.44014171254874046`], 
             UndirectedEdge[116, 441] -> 
             RGBColor[
              0.6361289763166988, 0.6793620588886213, 0.6501497074705821], 
             UndirectedEdge[258, 435] -> 
             RGBColor[
              0.6502283296288609, 0.5652459812369222, 0.5894006966361973], 
             UndirectedEdge[112, 445] -> 
             RGBColor[
              0.9728586121056348, 0.9779075485267765, 0.869429974536861], 
             UndirectedEdge[114, 179] -> 
             RGBColor[
              0.47692237117677583`, 0.5726317967163046, 0.9546016087041642], 
             UndirectedEdge[155, 467] -> 
             RGBColor[
              0.873653880405358, 0.8681432001795395, 0.6580974554107051], 
             UndirectedEdge[243, 421] -> 
             RGBColor[
              0.8487083574735882, 0.6881986832494589, 0.5991671421975833], 
             UndirectedEdge[172, 289] -> 
             RGBColor[
              0.9764658834420723, 0.9694944212916154, 0.670161402871517], 
             UndirectedEdge[381, 468] -> 
             RGBColor[
              0.27617108857113315`, 0.40760370271958635`, 0.939038906984389], 
             UndirectedEdge[17, 277] -> 
             RGBColor[
              0.45770456093733436`, 0.5706242077812463, 0.9504513261454892], 
             UndirectedEdge[279, 477] -> 
             RGBColor[
              0.3531495062965594, 0.4752644519019258, 0.9439078045954234], 
             UndirectedEdge[4, 405] -> 
             RGBColor[
              0.8738647142805717, 0.7434723883355705, 0.6085188808442994], 
             UndirectedEdge[36, 379] -> 
             RGBColor[
              0.7677777734055307, 0.8135914469520185, 0.7280053110482472], 
             UndirectedEdge[278, 401] -> 
             RGBColor[
              0.8489551154563462, 0.3193239024652833, 0.1922234221602645], 
             UndirectedEdge[152, 399] -> 
             RGBColor[
              0.9735385263289145, 0.976216458130901, 0.7101578234356423], 
             UndirectedEdge[173, 406] -> 
             RGBColor[
              0.27512306965500655`, 0.40650216839050013`, 0.9389792238575205],
              UndirectedEdge[239, 332] -> 
             RGBColor[
              0.6068147561330957, 0.6916785815789086, 0.9621898269199418], 
             UndirectedEdge[116, 361] -> 
             RGBColor[
              0.6431971390199129, 0.7095483325098262, 0.879150940422549], 
             UndirectedEdge[288, 498] -> 
             RGBColor[
              0.7640148927816351, 0.7206845489420455, 0.6116298538678555], 
             UndirectedEdge[16, 386] -> 
             RGBColor[
              0.5877084124279985, 0.6660121912629904, 0.9644998565883036], 
             UndirectedEdge[216, 464] -> 
             RGBColor[
              0.4395811329787508, 0.5541241159979331, 0.949518247552899], 
             UndirectedEdge[379, 400] -> 
             RGBColor[
              0.753807154645231, 0.8064798689840067, 0.9504227928499394], 
             UndirectedEdge[22, 24] -> 
             RGBColor[
              0.6528363172399572, 0.7170451407200673, 0.7706142463137766], 
             UndirectedEdge[231, 355] -> 
             RGBColor[
              0.49269717021104276`, 0.5911309554417679, 0.9551961788876278], 
             UndirectedEdge[434, 495] -> 
             RGBColor[
              0.7884687484771117, 0.8350284925125513, 0.9641155258582736], 
             UndirectedEdge[75, 323] -> 
             RGBColor[
              0.8765941761626568, 0.4200923207787567, 0.3471086914304604], 
             UndirectedEdge[165, 288] -> 
             RGBColor[
              0.44406302498464556`, 0.5532658603867183, 0.9506766789392624], 
             UndirectedEdge[90, 229] -> 
             RGBColor[
              0.8809625038532098, 0.9053337098684094, 0.8690245055067778], 
             UndirectedEdge[267, 424] -> 
             RGBColor[
              0.909285347796637, 0.9211993701574914, 0.6983496996359704], 
             UndirectedEdge[258, 403] -> 
             RGBColor[
              0.7074409746864387, 0.6129104450582472, 0.5935685185274915], 
             UndirectedEdge[274, 305] -> 
             RGBColor[
              0.8623837911144627, 0.3725641266088242, 0.20302844980631513`], 
             UndirectedEdge[399, 478] -> 
             RGBColor[
              0.9139335258659771, 0.9291680481080211, 0.7210798555765846], 
             UndirectedEdge[359, 463] -> 
             RGBColor[
              0.35830081622144627`, 0.4797998199449326, 0.9442747422430637], 
             UndirectedEdge[302, 422] -> 
             RGBColor[
              0.902317888146422, 0.9238275765172681, 0.9517059678618727], 
             UndirectedEdge[21, 335] -> 
             RGBColor[
              0.6893277508028837, 0.7532065995861418, 0.9479430313577204], 
             UndirectedEdge[266, 445] -> 
             RGBColor[
              0.6362676306314246, 0.7014335946433976, 0.8570704599327624], 
             UndirectedEdge[200, 452] -> 
             RGBColor[
              0.9544980135121521, 0.9638765327146966, 0.890166867376915], 
             UndirectedEdge[112, 471] -> 
             RGBColor[
              0.9543277925912953, 0.9654583230127397, 0.9621953133101876], 
             UndirectedEdge[481, 496] -> 
             RGBColor[
              0.4379389983148827, 0.5508373855202984, 0.9499287503450965], 
             UndirectedEdge[6, 422] -> 
             RGBColor[
              0.8547916030060821, 0.7151214519842524, 0.6041049869780739], 
             UndirectedEdge[137, 424] -> 
             RGBColor[
              0.8746625967006936, 0.4146634942018086, 0.24718745832676925`], 
             UndirectedEdge[89, 482] -> 
             RGBColor[
              0.9394120533893776, 0.9537305945707032, 0.9665167665659977], 
             UndirectedEdge[142, 254] -> 
             RGBColor[
              0.8465798531156105, 0.30990677879352013`, 0.19031223032633562`],
              UndirectedEdge[178, 321] -> 
             RGBColor[
              0.9279466431484612, 0.8853104225831074, 0.6351314681428323], 
             UndirectedEdge[151, 456] -> 
             RGBColor[
              0.774594683810235, 0.8238184918679697, 0.9644606679601928], 
             UndirectedEdge[346, 431] -> 
             RGBColor[
              0.9194119334857566, 0.9339702896224301, 0.7567763786260653], 
             UndirectedEdge[65, 297] -> 
             RGBColor[
              0.7775775320473333, 0.8255929399523709, 0.9473377021738361], 
             UndirectedEdge[79, 253] -> 
             RGBColor[
              0.9159537339026246, 0.7044915922214849, 0.2512326053598743], 
             UndirectedEdge[376, 475] -> 
             RGBColor[
              0.796045069584049, 0.837302161330931, 0.7926880965973337], 
             UndirectedEdge[209, 259] -> 
             RGBColor[
              0.8680639172778383, 0.3924045990649092, 0.22155283482502497`], 
             UndirectedEdge[464, 496] -> 
             RGBColor[
              0.40360686235336274`, 0.5229650109016369, 0.9472259988394478], 
             UndirectedEdge[101, 103] -> 
             RGBColor[
              0.922532695339228, 0.9374652971038049, 0.8386720298020295], 
             UndirectedEdge[69, 348] -> 
             RGBColor[
              0.8142453016422985, 0.8548881977786338, 0.9383024895797681], 
             UndirectedEdge[116, 277] -> 
             RGBColor[
              0.3771186522286071, 0.4998176660368958, 0.945324625128917], 
             UndirectedEdge[171, 471] -> 
             RGBColor[
              0.9427506513373574, 0.9566802044559308, 0.9768030973595725], 
             UndirectedEdge[133, 429] -> 
             RGBColor[
              0.8575676612554359, 0.839122523430877, 0.6324663349334958], 
             UndirectedEdge[37, 203] -> 
             RGBColor[
              0.9792597199861195, 0.9840525136415152, 0.9199920635188459], 
             UndirectedEdge[299, 399] -> 
             RGBColor[
              0.9669522450984391, 0.8956043660060178, 0.36474822066539725`], 
             UndirectedEdge[311, 429] -> 
             RGBColor[
              0.7669088916144736, 0.8178343219434628, 0.9774019692112181], 
             UndirectedEdge[327, 446] -> 
             RGBColor[
              0.499004099438482, 0.6030944117079092, 0.9539950775008803], 
             UndirectedEdge[15, 249] -> 
             RGBColor[
              0.8090710746029803, 0.38000974722087777`, 0.4375355956319553], 
             UndirectedEdge[50, 242] -> 
             RGBColor[
              0.4025029997654348, 0.5186930986114536, 0.9474806972966326], 
             UndirectedEdge[163, 355] -> 
             RGBColor[
              0.28079394391378154`, 0.41246261679066754`, 0.9393021717572512],
              UndirectedEdge[192, 435] -> 
             RGBColor[
              0.6666279157104444, 0.6338020247560632, 0.6027791616260796], 
             UndirectedEdge[31, 191] -> 
             RGBColor[
              0.5137834753909873, 0.6156824509598513, 0.9549956901254293], 
             UndirectedEdge[385, 415] -> 
             RGBColor[
              0.9756477714136943, 0.9809937428567495, 0.9097613559893434], 
             UndirectedEdge[207, 257] -> 
             RGBColor[
              0.7264543679424922, 0.7449032828124071, 0.6364698528584342], 
             UndirectedEdge[359, 408] -> 
             RGBColor[
              0.2874293698342333, 0.41858723551590094`, 0.9397111587329374], 
             UndirectedEdge[183, 202] -> 
             RGBColor[
              0.5458284950832304, 0.6362423900727359, 0.959880380730501], 
             UndirectedEdge[170, 223] -> 
             RGBColor[
              0.9680347003291887, 0.9756212572080198, 0.9363216142262197], 
             UndirectedEdge[40, 430] -> 
             RGBColor[
              0.6474153661400555, 0.7179284369298591, 0.9602205739326298], 
             UndirectedEdge[69, 444] -> 
             RGBColor[
              0.6997246196587982, 0.7609108636532578, 0.929552466299463], 
             UndirectedEdge[215, 417] -> 
             RGBColor[
              0.6803918783249044, 0.2649327330215362, 0.42518706550228047`], 
             UndirectedEdge[423, 429] -> 
             RGBColor[
              0.8397898949219099, 0.8755916148755404, 0.9844479066502225], 
             UndirectedEdge[5, 83] -> 
             RGBColor[
              0.6187218938638257, 0.7007076467928366, 0.9635631895511492], 
             UndirectedEdge[311, 366] -> 
             RGBColor[
              0.6306024790373697, 0.7089443300124044, 0.9654614794256872], 
             UndirectedEdge[133, 366] -> 
             RGBColor[
              0.7212612486783319, 0.7302325314998186, 0.6205258451479647], 
             UndirectedEdge[76, 359] -> 
             RGBColor[
              0.5765746288599001, 0.5045207497933621, 0.5865317882851302], 
             UndirectedEdge[172, 218] -> 
             RGBColor[
              0.9613051194508044, 0.9581875483304005, 0.6958246217482049], 
             UndirectedEdge[177, 484] -> 
             RGBColor[
              0.6406388231648579, 0.7051965884158382, 0.8356329759002744], 
             UndirectedEdge[45, 328] -> 
             RGBColor[
              0.8600564213910482, 0.8830885584501127, 0.6940788724637669], 
             UndirectedEdge[115, 144] -> 
             RGBColor[
              0.6520233779995794, 0.7263441914045977, 0.9671413769710265], 
             UndirectedEdge[63, 72] -> 
             RGBColor[
              0.5120616587133314, 0.605773602383513, 0.957203038866674], 
             UndirectedEdge[248, 387] -> 
             RGBColor[
              0.6897257210482876, 0.367122174755417, 0.4381154097285268], 
             UndirectedEdge[34, 44] -> 
             RGBColor[
              0.6283077003865569, 0.7018177662337881, 0.965416260834189], 
             UndirectedEdge[279, 285] -> 
             RGBColor[
              0.7161963381549648, 0.755672407292884, 0.6641006833898425], 
             UndirectedEdge[13, 77] -> 
             RGBColor[
              0.8111538619767299, 0.3703401079011869, 0.4363396425602779], 
             UndirectedEdge[53, 445] -> 
             RGBColor[
              0.7088268313068931, 0.7669300939695933, 0.8615968617475598], 
             UndirectedEdge[91, 298] -> 
             RGBColor[
              0.4305298012672219, 0.5379098100653481, 0.9500090029906565], 
             UndirectedEdge[6, 451] -> 
             RGBColor[
              0.570505460817033, 0.4769620752009126, 0.5814675257012399], 
             UndirectedEdge[87, 256] -> 
             RGBColor[
              0.9945412381687965, 0.9907325853455653, 0.6472256461256007], 
             UndirectedEdge[153, 172] -> 
             RGBColor[
              0.6481675615951217, 0.703681473864523, 0.6703313964966598], 
             UndirectedEdge[72, 438] -> 
             RGBColor[
              0.35125966763092575`, 0.4759680423827581, 0.9437016895377981], 
             UndirectedEdge[207, 440] -> 
             RGBColor[
              0.5955079610461278, 0.6815622778548509, 0.9619403042934822], 
             UndirectedEdge[19, 228] -> 
             RGBColor[
              0.6210388187177587, 0.6084030709162513, 0.603256715671084], 
             UndirectedEdge[8, 63] -> 
             RGBColor[
              0.6477095428871742, 0.7233133849340458, 0.9664795052028408], 
             UndirectedEdge[72, 128] -> 
             RGBColor[
              0.6051240802108884, 0.5870169200518782, 0.6011548883058155], 
             UndirectedEdge[229, 485] -> 
             RGBColor[
              0.8403801744619386, 0.8736304857108212, 0.864979638176486], 
             UndirectedEdge[32, 407] -> 
             RGBColor[
              0.46918136236923424`, 0.5799415922076752, 0.9513548219951171], 
             UndirectedEdge[475, 478] -> 
             RGBColor[
              0.7164136321671444, 0.7778257773578264, 0.9728038025099397], 
             UndirectedEdge[194, 412] -> 
             RGBColor[
              0.7665955854287625, 0.8030372656243709, 0.6775892070799767], 
             UndirectedEdge[370, 390] -> 
             RGBColor[
              0.724017823666693, 0.6263682778389541, 0.5948735088022157], 
             UndirectedEdge[231, 233] -> 
             RGBColor[
              0.8416797092213149, 0.8763767287533446, 0.9438873584135166], 
             UndirectedEdge[114, 385] -> 
             RGBColor[
              0.8514179011155956, 0.8835262528557638, 0.9238035082630943], 
             UndirectedEdge[271, 442] -> 
             RGBColor[
              0.9484400309008251, 0.912598469563262, 0.641192738476269], 
             UndirectedEdge[206, 254] -> 
             RGBColor[
              0.8455097718064859, 0.7470753529889802, 0.6108986544478363], 
             UndirectedEdge[262, 455] -> 
             RGBColor[
              0.5408445173336519, 0.6246763236252741, 0.9606310414019307], 
             UndirectedEdge[7, 341] -> 
             RGBColor[
              0.3684022045047527, 0.4935132059339958, 0.9446952405991325], 
             UndirectedEdge[187, 328] -> 
             RGBColor[
              0.8405447602146771, 0.8678459004450142, 0.6921341324245467], 
             UndirectedEdge[44, 56] -> 
             RGBColor[0.747392179383467, 0.802161508143024, 0.97377821182333],
              UndirectedEdge[142, 388] -> 
             RGBColor[
              0.87623643642312, 0.42002344942318254`, 0.35878442619129436`], 
             UndirectedEdge[282, 419] -> 
             RGBColor[
              0.986828791312871, 0.9888213809703181, 0.8679445441485489], 
             UndirectedEdge[7, 244] -> 
             RGBColor[
              0.6032558030789592, 0.681895984248644, 0.9653569611270121], 
             UndirectedEdge[107, 470] -> 
             RGBColor[
              0.8577907964742272, 0.4073609294871473, 0.43900895915458427`], 
             UndirectedEdge[10, 383] -> 
             RGBColor[
              0.5555625367357498, 0.6456672959921272, 0.9600800154184659], 
             UndirectedEdge[249, 419] -> 
             RGBColor[
              0.8877134641146383, 0.911628631403228, 0.9159947632824877], 
             UndirectedEdge[191, 271] -> 
             RGBColor[
              0.6872175943034309, 0.7528367218847515, 0.969084809734056], 
             UndirectedEdge[297, 490] -> 
             RGBColor[
              0.41839509158974497`, 0.5280541911231562, 0.9490540887635182], 
             UndirectedEdge[32, 176] -> 
             RGBColor[
              0.7067045459119439, 0.7689162741892326, 0.9648573481034742], 
             UndirectedEdge[353, 487] -> 
             RGBColor[
              0.618105547737928, 0.5788055133229484, 0.5965862963905544], 
             UndirectedEdge[281, 324] -> 
             RGBColor[
              0.529285595835787, 0.628736916600684, 0.9560864474226658], 
             UndirectedEdge[19, 59] -> 
             RGBColor[
              0.6512269973735443, 0.7156901965622051, 0.7781155817189673], 
             UndirectedEdge[197, 411] -> 
             RGBColor[
              0.5593444026268143, 0.6505260556676609, 0.9596509506664849], 
             UndirectedEdge[163, 343] -> 
             RGBColor[
              0.5176322848402325, 0.6099696144155339, 0.957782932788994], 
             UndirectedEdge[12, 396] -> 
             RGBColor[
              0.6287232588872621, 0.6913281319069376, 0.7059109860748966], 
             UndirectedEdge[51, 397] -> 
             RGBColor[
              0.643674152663608, 0.2323677451937748, 0.42287534282328], 
             UndirectedEdge[448, 482] -> 
             RGBColor[
              0.9148609959536795, 0.9349493412060157, 0.9917414525717562], 
             UndirectedEdge[183, 285] -> 
             RGBColor[
              0.6463597061385933, 0.6951834267314886, 0.6596507549518682], 
             UndirectedEdge[155, 365] -> 
             RGBColor[
              0.8505777214097441, 0.8840361129125903, 0.985518634123346], 
             UndirectedEdge[122, 217] -> 
             RGBColor[
              0.35451854254358195`, 0.48093238595630156`, 0.9438309251385215],
              UndirectedEdge[249, 269] -> 
             RGBColor[
              0.7559874891548986, 0.8093024393363097, 0.9763134258803565], 
             UndirectedEdge[101, 331] -> 
             RGBColor[
              0.9917742414051649, 0.990580525629069, 0.7652018324996268], 
             UndirectedEdge[246, 458] -> 
             RGBColor[
              0.4786511590621577, 0.5858922936549792, 0.9525803419363619], 
             UndirectedEdge[35, 437] -> 
             RGBColor[
              0.6753248009478091, 0.6059810774459706, 0.5949843739016569], 
             UndirectedEdge[354, 473] -> 
             RGBColor[
              0.8383333924060355, 0.391898306530586, 0.43896230814776604`], 
             UndirectedEdge[230, 484] -> 
             RGBColor[
              0.9831452581544292, 0.9851459987529049, 0.8326126996935255], 
             UndirectedEdge[108, 190] -> 
             RGBColor[
              0.9507420777926051, 0.8315512260095923, 0.4977445798229541], 
             UndirectedEdge[55, 136] -> 
             RGBColor[
              0.6802030233221255, 0.7482332941651091, 0.9701777038520114], 
             UndirectedEdge[59, 279] -> 
             RGBColor[
              0.7231439443448686, 0.7780310190662025, 0.7826962360583307], 
             UndirectedEdge[24, 170] -> 
             RGBColor[
              0.972813552196417, 0.9765853117077878, 0.7835529733507656], 
             UndirectedEdge[184, 388] -> 
             RGBColor[
              0.8773144804193893, 0.42830976798040027`, 0.3598167623395985], 
             UndirectedEdge[173, 242] -> 
             RGBColor[
              0.38958124096274493`, 0.5051115108229988, 0.9467448222488486], 
             UndirectedEdge[4, 345] -> 
             RGBColor[
              0.8983099877016473, 0.7629643858122659, 0.6108504928457548], 
             UndirectedEdge[59, 256] -> 
             RGBColor[
              0.9943409804361678, 0.9903042543046352, 0.6254288277764344], 
             UndirectedEdge[232, 480] -> 
             RGBColor[
              0.8753326341536383, 0.4196497039580931, 0.3737627687619018], 
             UndirectedEdge[3, 437] -> 
             RGBColor[
              0.5503751825774095, 0.6455701989512743, 0.9578889165520516], 
             UndirectedEdge[199, 448] -> 
             RGBColor[
              0.6474346016728458, 0.7191692080041016, 0.9686287735827708], 
             UndirectedEdge[151, 226] -> 
             RGBColor[
              0.8947338991663235, 0.9184998869999934, 0.9759308015618878], 
             UndirectedEdge[241, 442] -> 
             RGBColor[
              0.6287273900863372, 0.6515939594777995, 0.6167790913247135], 
             UndirectedEdge[303, 400] -> 
             RGBColor[
              0.9791016312750264, 0.9804789902975437, 0.7097528351429394], 
             UndirectedEdge[42, 378] -> 
             RGBColor[
              0.9488912200205759, 0.9060044863892691, 0.630589955533924], 
             UndirectedEdge[15, 499] -> 
             RGBColor[
              0.6371824650941648, 0.23639982344747373`, 0.42397908866863177`],
              UndirectedEdge[341, 374] -> 
             RGBColor[
              0.6845022937569156, 0.2684929682732576, 0.42544897753891053`], 
             UndirectedEdge[312, 334] -> 
             RGBColor[
              0.6936347940069739, 0.7593053546030997, 0.9710422620846062], 
             UndirectedEdge[7, 482] -> 
             RGBColor[
              0.6151139095256866, 0.6913513164495395, 0.9664879979057575], 
             UndirectedEdge[219, 403] -> 
             RGBColor[
              0.6642695408036059, 0.7358222514108544, 0.9684226289445921], 
             UndirectedEdge[50, 449] -> 
             RGBColor[
              0.2666858680060453, 0.39763413450796004`, 0.9384987377053335], 
             UndirectedEdge[318, 430] -> 
             RGBColor[
              0.6151274782571485, 0.6877348205880947, 0.9582447768814322], 
             UndirectedEdge[242, 449] -> 
             RGBColor[
              0.38711746192326124`, 0.5025219228398878, 0.9466045136773844], 
             UndirectedEdge[356, 365] -> 
             RGBColor[
              0.614842790588304, 0.690456930552975, 0.9666624859417987], 
             UndirectedEdge[154, 219] -> 
             RGBColor[
              0.9001964822605517, 0.9200882656340124, 0.8586453723067089], 
             UndirectedEdge[69, 275] -> 
             RGBColor[
              0.9884770276668357, 0.9873176969667923, 0.6817827899623143], 
             UndirectedEdge[173, 310] -> 
             RGBColor[
              0.5983947012167505, 0.6709167949121878, 0.9617006015255178], 
             UndirectedEdge[351, 460] -> 
             RGBColor[
              0.6078472502692301, 0.6733577314161604, 0.9022925340531591], 
             UndirectedEdge[97, 207] -> 
             RGBColor[
              0.40455766137868654`, 0.5239012871874162, 0.9472554319735089], 
             UndirectedEdge[122, 212] -> 
             RGBColor[
              0.4892174167429309, 0.5910529766302282, 0.9544313305990805], 
             UndirectedEdge[45, 224] -> 
             RGBColor[
              0.5545640015941451, 0.6458835013375726, 0.9595588226832394], 
             UndirectedEdge[144, 215] -> 
             RGBColor[
              0.5909285919087475, 0.675474495179094, 0.9626827307142585], 
             UndirectedEdge[22, 214] -> 
             RGBColor[
              0.5901807457327354, 0.671251176616632, 0.9642107196900024], 
             UndirectedEdge[142, 150] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[149, 419] -> 
             RGBColor[
              0.9633249310089038, 0.9715756652888253, 0.9204227926712268], 
             UndirectedEdge[11, 418] -> 
             RGBColor[
              0.7233427139035882, 0.3006489539828829, 0.4283343398785442], 
             UndirectedEdge[189, 346] -> 
             RGBColor[
              0.5846173551651417, 0.6672379503658015, 0.9634854080705555], 
             UndirectedEdge[185, 224] -> 
             RGBColor[
              0.6852266485963909, 0.7466430546047356, 0.8657626753142491], 
             UndirectedEdge[17, 386] -> 
             RGBColor[
              0.6746986446835642, 0.7435500831126338, 0.9699912743565207], 
             UndirectedEdge[194, 476] -> 
             RGBColor[
              0.9902149815714352, 0.9770715719294865, 0.5511287833412719], 
             UndirectedEdge[258, 471] -> 
             RGBColor[
              0.9236650760055982, 0.7842425731200169, 0.5959800154855948], 
             UndirectedEdge[203, 397] -> 
             RGBColor[
              0.8728602401664325, 0.4185996959188447, 0.41350032172406087`], 
             UndirectedEdge[126, 173] -> 
             RGBColor[
              0.5945718452509778, 0.6679939441859628, 0.9656833536719491], 
             UndirectedEdge[30, 366] -> 
             RGBColor[
              0.7349422558756886, 0.7904546129767513, 0.9286401929391294], 
             UndirectedEdge[95, 368] -> 
             RGBColor[
              0.9317981571022802, 0.9433705596964534, 0.7193580320693305], 
             UndirectedEdge[15, 242] -> 
             RGBColor[
              0.7208268314526661, 0.30985305406329755`, 0.4295740948326925], 
             UndirectedEdge[150, 392] -> 
             RGBColor[
              0.6996176845011868, 0.2813879063136187, 0.42646661865634083`], 
             UndirectedEdge[179, 296] -> 
             RGBColor[
              0.406042787071209, 0.5162234893708559, 0.9482457489138031], 
             UndirectedEdge[3, 123] -> 
             RGBColor[
              0.8231149547172004, 0.8588031711895721, 0.7685405829110616], 
             UndirectedEdge[37, 257] -> 
             RGBColor[
              0.9699957325006392, 0.937778948284482, 0.6240312042153622], 
             UndirectedEdge[17, 178] -> 
             RGBColor[
              0.704393479781411, 0.7071548800792343, 0.6149654890969882], 
             UndirectedEdge[68, 367] -> 
             RGBColor[
              0.5568654609192059, 0.6409776411874577, 0.961624869792477], 
             UndirectedEdge[1, 363] -> 
             RGBColor[
              0.6429310621163171, 0.7134617907542732, 0.9514326056966897], 
             UndirectedEdge[227, 329] -> 
             RGBColor[
              0.9050109179049626, 0.9265039275901015, 0.9703036713174349], 
             UndirectedEdge[121, 420] -> 
             RGBColor[
              0.6418942551119127, 0.7057796905551246, 0.7674635698578476], 
             UndirectedEdge[82, 149] -> 
             RGBColor[
              0.603691308568178, 0.6767389532721511, 0.9634643246040372], 
             UndirectedEdge[129, 355] -> 
             RGBColor[
              0.24850532717960577`, 0.3785252333865062, 0.9374633828009677], 
             UndirectedEdge[87, 388] -> 
             RGBColor[
              0.9943601855382544, 0.9913897787374535, 0.7034394311619], 
             UndirectedEdge[91, 228] -> 
             RGBColor[
              0.5931873608082812, 0.5791294227689665, 0.6016706163456789], 
             UndirectedEdge[12, 161] -> 
             RGBColor[
              0.8804325299931155, 0.9029710908123094, 0.7254751988240777], 
             UndirectedEdge[64, 115] -> 
             RGBColor[
              0.7393871564289644, 0.733972020988589, 0.6173537108019795], 
             UndirectedEdge[56, 342] -> 
             RGBColor[
              0.4198272652156909, 0.5328889643708387, 0.9488325800502899], 
             UndirectedEdge[378, 416] -> 
             RGBColor[
              0.9666592060043044, 0.9738145725549461, 0.9036822117896162], 
             UndirectedEdge[119, 363] -> 
             RGBColor[
              0.6343148726292896, 0.7070358507425637, 0.9660175670361022], 
             UndirectedEdge[391, 455] -> 
             RGBColor[
              0.34746535703221637`, 0.4701754872901418, 0.9435516805301896], 
             UndirectedEdge[249, 282] -> 
             RGBColor[
              0.8867826503318262, 0.9112437159832122, 0.9314207565325334], 
             UndirectedEdge[226, 429] -> 
             RGBColor[
              0.7980579118219896, 0.8423156643361682, 0.9804674728475711], 
             UndirectedEdge[181, 189] -> 
             RGBColor[
              0.6142168915409589, 0.690839817213867, 0.966308638273899], 
             UndirectedEdge[160, 167] -> 
             RGBColor[
              0.9521414954007847, 0.851734153555843, 0.5704842777036921], 
             UndirectedEdge[16, 277] -> 
             RGBColor[
              0.3707143286817686, 0.493086315931603, 0.9449599083772722], 
             UndirectedEdge[295, 341] -> 
             RGBColor[
              0.37343599463447025`, 0.49787322193870875`, 0.9450159892549923],
              UndirectedEdge[69, 129] -> 
             RGBColor[
              0.5990235545451871, 0.6649141348481513, 0.9234571619149028], 
             UndirectedEdge[352, 368] -> 
             RGBColor[
              0.83828064481907, 0.8740016599819558, 0.9844065235063331], 
             UndirectedEdge[194, 297] -> 
             RGBColor[
              0.7848417097624681, 0.8178502913370073, 0.6790256088252817], 
             UndirectedEdge[188, 228] -> 
             RGBColor[
              0.9263565636442077, 0.7457353456093492, 0.25960296635574986`], 
             UndirectedEdge[273, 430] -> 
             RGBColor[
              0.9555798161265476, 0.9663920801153305, 0.9600759640450417], 
             UndirectedEdge[200, 468] -> 
             RGBColor[
              0.5871439373005811, 0.6621593305350648, 0.9649615117113444], 
             UndirectedEdge[93, 172] -> 
             RGBColor[
              0.9702393635140732, 0.9648506929243044, 0.6807012769731344], 
             UndirectedEdge[61, 341] -> 
             RGBColor[
              0.6853146824297973, 0.750384266491035, 0.9572260152033178], 
             UndirectedEdge[121, 442] -> 
             RGBColor[
              0.6241053076433724, 0.6467358577732905, 0.6165158705673448], 
             UndirectedEdge[287, 336] -> 
             RGBColor[
              0.7564493590061208, 0.8096632555744254, 0.9763594607507071], 
             UndirectedEdge[403, 497] -> 
             RGBColor[
              0.7363040840305322, 0.7308802050903189, 0.6169754268908807], 
             UndirectedEdge[17, 407] -> 
             RGBColor[
              0.46371868686576767`, 0.5755067461432339, 0.9509247801690446], 
             UndirectedEdge[135, 470] -> 
             RGBColor[
              0.8541477246285679, 0.4045082257762207, 0.4404706932727722], 
             UndirectedEdge[322, 471] -> 
             RGBColor[
              0.9662042820954406, 0.9502049024326061, 0.662829671494769], 
             UndirectedEdge[24, 52] -> 
             RGBColor[
              0.8478011497693432, 0.878269466693018, 0.785518458897847], 
             UndirectedEdge[163, 440] -> 
             RGBColor[
              0.4909705590831239, 0.5891412716174599, 0.9551255411335183], 
             UndirectedEdge[274, 432] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[89, 261] -> 
             RGBColor[
              0.7135841791625017, 0.7737822930399847, 0.9461096142022847], 
             UndirectedEdge[255, 312] -> 
             RGBColor[
              0.7361909611884674, 0.7932384871572373, 0.975101307300716], 
             UndirectedEdge[370, 422] -> 
             RGBColor[
              0.8587214259990164, 0.732965860361688, 0.6073841276121545], 
             UndirectedEdge[43, 90] -> 
             RGBColor[
              0.8268937877946114, 0.5608643648276925, 0.46005214689361806`], 
             UndirectedEdge[373, 449] -> 
             RGBColor[
              0.5539947819513793, 0.6350138578913773, 0.9619077660236246], 
             UndirectedEdge[49, 457] -> 
             RGBColor[
              0.592952901650484, 0.5330961790972895, 0.589995601595384], 
             UndirectedEdge[234, 449] -> 
             RGBColor[
              0.5937559361583286, 0.6667051059173654, 0.9652419769569112], 
             UndirectedEdge[245, 299] -> 
             RGBColor[
              0.9535625274029986, 0.8891875351210745, 0.6069322487446674], 
             UndirectedEdge[398, 464] -> 
             RGBColor[
              0.649438873328825, 0.7237571228249214, 0.9672721455705031], 
             UndirectedEdge[245, 262] -> 
             RGBColor[
              0.8976222360328932, 0.920421634904484, 0.9629852214972481], 
             UndirectedEdge[288, 321] -> 
             RGBColor[
              0.7519654506971352, 0.8061834679175284, 0.9761836764239067], 
             UndirectedEdge[433, 465] -> 
             RGBColor[
              0.9642431898715769, 0.9719085513058832, 0.9031073825831607], 
             UndirectedEdge[330, 367] -> 
             RGBColor[
              0.8976600033549247, 0.9205591164550124, 0.9667113020555926], 
             UndirectedEdge[106, 156] -> 
             RGBColor[
              0.765741677405664, 0.8127881870029627, 0.7974891169256599], 
             UndirectedEdge[85, 239] -> 
             RGBColor[
              0.6720813189865296, 0.7435069351819532, 0.9681195686817003], 
             UndirectedEdge[336, 388] -> 
             RGBColor[
              0.853209790364737, 0.8835137495361767, 0.8599405775330495], 
             UndirectedEdge[69, 355] -> 
             RGBColor[
              0.6336869287625047, 0.7013475389354156, 0.9254311897967124], 
             UndirectedEdge[102, 383] -> 
             RGBColor[
              0.8580814597375953, 0.889559273447118, 0.9642197087556186], 
             UndirectedEdge[296, 327] -> 
             RGBColor[
              0.5791830816131228, 0.6692459434108431, 0.9600145602835707], 
             UndirectedEdge[61, 288] -> 
             RGBColor[
              0.7754276425613834, 0.8244774014088013, 0.9640615908023367], 
             UndirectedEdge[141, 472] -> 
             RGBColor[
              0.849397307244682, 0.48999774702694654`, 0.4511913537420824], 
             UndirectedEdge[43, 485] -> 
             RGBColor[
              0.7998389015337638, 0.5397288820559671, 0.45735556867342353`], 
             UndirectedEdge[9, 358] -> 
             RGBColor[
              0.7955755310954822, 0.8406608811955653, 0.9801445623333183], 
             UndirectedEdge[70, 359] -> 
             RGBColor[
              0.45001792062012574`, 0.5542483524643874, 0.951502941805475], 
             UndirectedEdge[466, 470] -> 
             RGBColor[
              0.8351814873133276, 0.2583174062929483, 0.18080984209386503`], 
             UndirectedEdge[41, 356] -> 
             RGBColor[
              0.4340294725619381, 0.5471367079490956, 0.949703243159497], 
             UndirectedEdge[79, 436] -> 
             RGBColor[
              0.779222431894177, 0.7190216849808859, 0.609601634197917], 
             UndirectedEdge[33, 175] -> 
             RGBColor[
              0.7207775092015738, 0.7762266325567049, 0.8035109580738835], 
             UndirectedEdge[176, 448] -> 
             RGBColor[
              0.9310918341427242, 0.9476578683193746, 0.9851938797634889], 
             UndirectedEdge[118, 481] -> 
             RGBColor[
              0.5396831034326456, 0.6371780816701931, 0.9569049773080158], 
             UndirectedEdge[326, 346] -> 
             RGBColor[
              0.8779565389712698, 0.9055227289530408, 0.9882214725197762], 
             UndirectedEdge[63, 435] -> 
             RGBColor[
              0.5765293591716537, 0.6643094439997569, 0.9612121075036134], 
             UndirectedEdge[194, 350] -> 
             RGBColor[
              0.8832507041356967, 0.4864097467559071, 0.25151978755142124`], 
             UndirectedEdge[275, 486] -> 
             RGBColor[
              0.9174463167242819, 0.9319327620559563, 0.7184731131241524], 
             UndirectedEdge[407, 478] -> 
             RGBColor[
              0.6523858251858823, 0.7258451192306039, 0.9677632990027897], 
             UndirectedEdge[62, 356] -> 
             RGBColor[
              0.4271454202132112, 0.541547924129375, 0.9491613053414905], 
             UndirectedEdge[150, 426] -> 
             RGBColor[
              0.6675143175567845, 0.2537788371292143, 0.4243665187173157], 
             UndirectedEdge[372, 444] -> 
             RGBColor[
              0.5253299032816131, 0.6244917110765948, 0.9560606817590984], 
             UndirectedEdge[106, 329] -> 
             RGBColor[
              0.7478252287291094, 0.8018417902499654, 0.9558074677959101], 
             UndirectedEdge[128, 294] -> 
             RGBColor[
              0.9499347786898753, 0.8697000247193089, 0.600052793197893], 
             UndirectedEdge[379, 440] -> 
             RGBColor[
              0.6229495188719809, 0.7038405707259706, 0.964100604247272], 
             UndirectedEdge[227, 267] -> 
             RGBColor[
              0.8403082823942811, 0.8755030310932508, 0.9846305481984676], 
             UndirectedEdge[151, 345] -> 
             RGBColor[
              0.9283732103880743, 0.9453229606534395, 0.979139349096386], 
             UndirectedEdge[275, 418] -> 
             RGBColor[
              0.8757956330685285, 0.418384317845508, 0.2601922036713271], 
             UndirectedEdge[10, 232] -> 
             RGBColor[
              0.6732963877140363, 0.7364008523701295, 0.8683542043622225], 
             UndirectedEdge[5, 431] -> 
             RGBColor[
              0.8387183707532508, 0.8707266473832892, 0.7487880568950946], 
             UndirectedEdge[42, 416] -> 
             RGBColor[
              0.9714831024210195, 0.922012976902328, 0.5547085563765277], 
             UndirectedEdge[37, 97] -> 
             RGBColor[
              0.6480990259368336, 0.7167769526594913, 0.934816783330437], 
             UndirectedEdge[441, 450] -> 
             RGBColor[
              0.6624648826464835, 0.7032997652406274, 0.651786547977497], 
             UndirectedEdge[5, 259] -> 
             RGBColor[
              0.8267703021039895, 0.8310073959265276, 0.6526797898826817], 
             UndirectedEdge[279, 318] -> 
             RGBColor[
              0.36834666747519873`, 0.4912376318563468, 0.9447732604423618], 
             UndirectedEdge[275, 355] -> 
             RGBColor[
              0.6379588003012544, 0.7009287955051471, 0.6957890108483793], 
             UndirectedEdge[344, 387] -> 
             RGBColor[
              0.8602941736757238, 0.5044631429765994, 0.4529536844101387], 
             UndirectedEdge[239, 489] -> 
             RGBColor[
              0.7960159276149233, 0.8407275792098949, 0.9532286896097478], 
             UndirectedEdge[21, 336] -> 
             RGBColor[
              0.8374850177822697, 0.8734275520949528, 0.9600598297224463], 
             UndirectedEdge[32, 312] -> 
             RGBColor[
              0.5085276644774921, 0.6118846927898691, 0.954452307027333], 
             UndirectedEdge[77, 436] -> 
             RGBColor[
              0.7186100634695075, 0.7800422104938909, 0.9726294941970415], 
             UndirectedEdge[66, 294] -> 
             RGBColor[
              0.9644898750309125, 0.9262760675501557, 0.6176495576929568], 
             UndirectedEdge[197, 201] -> 
             RGBColor[
              0.6893661525356798, 0.7522746908103639, 0.9338593777364053], 
             UndirectedEdge[228, 256] -> 
             RGBColor[
              0.9641528017803822, 0.8830171286586814, 0.45056996172855107`], 
             UndirectedEdge[292, 481] -> 
             RGBColor[
              0.690099435274948, 0.7565733119205738, 0.9706056554357938], 
             UndirectedEdge[444, 486] -> 
             RGBColor[
              0.6286939087162444, 0.7055259287424218, 0.9662427894613009], 
             UndirectedEdge[154, 244] -> 
             RGBColor[
              0.941682277507851, 0.9530516884193831, 0.862633166832704], 
             UndirectedEdge[288, 386] -> 
             RGBColor[
              0.7453811588873981, 0.800933332354284, 0.9755556607932272], 
             UndirectedEdge[273, 285] -> 
             RGBColor[
              0.9729560011517169, 0.9596118076675606, 0.6606806059307365], 
             UndirectedEdge[190, 487] -> 
             RGBColor[
              0.6137166220852354, 0.5614048856327964, 0.593054863789072], 
             UndirectedEdge[83, 343] -> 
             RGBColor[
              0.6551511593015062, 0.7291664658254243, 0.9671941182791362], 
             UndirectedEdge[1, 315] -> 
             RGBColor[
              0.9547994024132473, 0.9658100488457614, 0.9613970008971638], 
             UndirectedEdge[4, 429] -> 
             RGBColor[
              0.8244966780471059, 0.704609588184155, 0.6036769161886248], 
             UndirectedEdge[189, 451] -> 
             RGBColor[
              0.2903919722102577, 0.42115329278928837`, 0.9398999331366114], 
             UndirectedEdge[10, 102] -> 
             RGBColor[
              0.6577517959690033, 0.725998570320971, 0.9479957957758924], 
             UndirectedEdge[357, 368] -> 
             RGBColor[
              0.9285459863539212, 0.9442186541826747, 0.9326592812913009], 
             UndirectedEdge[128, 138] -> 
             RGBColor[
              0.8960973222643052, 0.8276352756804537, 0.6248654310241664], 
             UndirectedEdge[336, 436] -> 
             RGBColor[
              0.6753724062344697, 0.7462646240435133, 0.9683199686027326], 
             UndirectedEdge[196, 454] -> 
             RGBColor[
              0.5952751301834793, 0.5418863767250925, 0.5916692687014323], 
             UndirectedEdge[25, 164] -> 
             RGBColor[
              0.3639731156876163, 0.4845092160900788, 0.9447117862195582], 
             UndirectedEdge[125, 282] -> 
             RGBColor[
              0.7725603059004676, 0.820738809300402, 0.9209068690749279], 
             UndirectedEdge[9, 286] -> 
             RGBColor[
              0.8505918699672086, 0.8676396945910481, 0.6813726848799199], 
             UndirectedEdge[421, 477] -> 
             RGBColor[
              0.5396906330043723, 0.6239834961002078, 0.9604865562980378], 
             UndirectedEdge[105, 484] -> 
             RGBColor[
              0.6860678343028312, 0.746627132050323, 0.8384514321354605], 
             UndirectedEdge[299, 475] -> 
             RGBColor[
              0.7694323513996064, 0.744262095255823, 0.6164721675987523], 
             UndirectedEdge[247, 252] -> 
             RGBColor[
              0.453619279815286, 0.5622128472183828, 0.9513207713877652], 
             UndirectedEdge[261, 478] -> 
             RGBColor[
              0.6478502963126713, 0.722162972568084, 0.9674062455557009], 
             UndirectedEdge[104, 303] -> 
             RGBColor[
              0.9385077928875379, 0.7768706211946034, 0.3503687825838242], 
             UndirectedEdge[32, 66] -> 
             RGBColor[
              0.7142197872930924, 0.727760008999047, 0.6247920039915218], 
             UndirectedEdge[213, 454] -> 
             RGBColor[
              0.5511633949198826, 0.6368835546577365, 0.96101114337903], 
             UndirectedEdge[129, 331] -> 
             RGBColor[
              0.6012199362648365, 0.6658223951336619, 0.8870574327666294], 
             UndirectedEdge[245, 475] -> 
             RGBColor[
              0.7818933905712009, 0.8292555722341595, 0.9519373375569482], 
             UndirectedEdge[90, 148] -> 
             RGBColor[
              0.6269413340074379, 0.706084215689289, 0.9650965707044491], 
             UndirectedEdge[195, 496] -> 
             RGBColor[
              0.3670671994505009, 0.49235689165530794`, 0.9446101752575742], 
             UndirectedEdge[241, 371] -> 
             RGBColor[
              0.30358781934518186`, 0.43642042508424317`, 0.9406002492425526],
              UndirectedEdge[13, 243] -> 
             RGBColor[
              0.8356443730612351, 0.26041926236448254`, 0.18119608530828687`],
              UndirectedEdge[246, 384] -> 
             RGBColor[
              0.7241650728306965, 0.7837909644481187, 0.9737912949679131], 
             UndirectedEdge[22, 268] -> 
             RGBColor[
              0.5355184641994792, 0.6281540444011002, 0.958867193745488], 
             UndirectedEdge[69, 306] -> 
             RGBColor[
              0.979329136196549, 0.9566114721223515, 0.6333402895173752], 
             UndirectedEdge[66, 128] -> 
             RGBColor[
              0.9452293541119634, 0.81942960686636, 0.2806738488944785], 
             UndirectedEdge[220, 413] -> 
             RGBColor[
              0.628746648242053, 0.21667799158827522`, 0.42202524352973625`], 
             UndirectedEdge[319, 492] -> 
             RGBColor[
              0.7489831937980256, 0.3214650506516431, 0.43035285238000687`], 
             UndirectedEdge[61, 186] -> 
             RGBColor[
              0.973047579424607, 0.9769171981667215, 0.7956418230456664], 
             UndirectedEdge[94, 401] -> 
             RGBColor[
              0.8752435595050384, 0.419612869301783, 0.3752389662070031], 
             UndirectedEdge[429, 488] -> 
             RGBColor[
              0.5131881368017153, 0.6051584063592443, 0.9575520292445316], 
             UndirectedEdge[11, 431] -> 
             RGBColor[
              0.7644200154214009, 0.8110455810284498, 0.7425030290677666], 
             UndirectedEdge[349, 487] -> 
             RGBColor[
              0.6569107985451017, 0.7216141591725129, 0.8454657736810218], 
             UndirectedEdge[156, 198] -> 
             RGBColor[
              0.9882666160595417, 0.98835418065115, 0.776755261222219], 
             UndirectedEdge[12, 188] -> 
             RGBColor[
              0.9558927974983625, 0.8516280272463455, 0.3635016640830715], 
             UndirectedEdge[70, 111] -> 
             RGBColor[
              0.6948321011490015, 0.7615273854279394, 0.9702180283335224], 
             UndirectedEdge[212, 286] -> 
             RGBColor[
              0.8295784747035009, 0.8512238705033206, 0.679278266021377], 
             UndirectedEdge[242, 282] -> 
             RGBColor[
              0.754416285606355, 0.8060086762468419, 0.9194785053336391], 
             UndirectedEdge[70, 175] -> 
             RGBColor[
              0.5450168177566218, 0.6413229932201137, 0.9573807519692421], 
             UndirectedEdge[188, 298] -> 
             RGBColor[
              0.7636990041031484, 0.7045157329057308, 0.6079413530007274], 
             UndirectedEdge[286, 367] -> 
             RGBColor[
              0.9084600117431101, 0.9129556483044992, 0.6871115360148767], 
             UndirectedEdge[9, 492] -> 
             RGBColor[
              0.7841205743262611, 0.3492214981280449, 0.43364521708771553`], 
             UndirectedEdge[37, 343] -> 
             RGBColor[
              0.8657110513613833, 0.8952662861249998, 0.9521590473058859], 
             UndirectedEdge[376, 391] -> 
             RGBColor[
              0.7183947547443058, 0.7739673876661234, 0.7866566196658924], 
             UndirectedEdge[230, 490] -> 
             RGBColor[
              0.6118530147785565, 0.6803801216277671, 0.9356299850984526], 
             UndirectedEdge[346, 355] -> 
             RGBColor[
              0.5642713396181996, 0.6472504583051899, 0.9622755647175036], 
             UndirectedEdge[30, 465] -> 
             RGBColor[
              0.9872457345715964, 0.9889937977227539, 0.8610347153369078], 
             UndirectedEdge[119, 124] -> 
             RGBColor[
              0.8835089685444621, 0.9098894676437339, 0.9866494063743614], 
             UndirectedEdge[301, 436] -> 
             RGBColor[
              0.718425456438113, 0.7798979940779001, 0.9726110942934028], 
             UndirectedEdge[39, 108] -> 
             RGBColor[
              0.9936409166781283, 0.9900107680823705, 0.6367405293273175], 
             UndirectedEdge[98, 382] -> 
             RGBColor[
              0.8324827379096514, 0.38723315344695486`, 0.43840426749896], 
             UndirectedEdge[81, 208] -> 
             RGBColor[
              0.8079151577404473, 0.8507003753867552, 0.9759949302169106], 
             UndirectedEdge[154, 203] -> 
             RGBColor[
              0.9893655985479199, 0.9898290015731157, 0.8240484625825499], 
             UndirectedEdge[145, 367] -> 
             RGBColor[
              0.9005355585266559, 0.8862246068553006, 0.656326531676374], 
             UndirectedEdge[44, 132] -> 
             RGBColor[
              0.866717205125131, 0.4769815996653913, 0.4479419569918527], 
             UndirectedEdge[319, 357] -> 
             RGBColor[
              0.7992736191670133, 0.8423586283095932, 0.9201984364152143], 
             UndirectedEdge[364, 378] -> 
             RGBColor[
              0.7692261063490704, 0.819696768799778, 0.9703874566007777], 
             UndirectedEdge[213, 251] -> 
             RGBColor[
              0.9068642247561827, 0.9251174766297626, 0.8480714090527117], 
             UndirectedEdge[73, 136] -> 
             RGBColor[
              0.920999100265104, 0.9184654025942094, 0.681704244506637], 
             UndirectedEdge[441, 461] -> 
             RGBColor[
              0.9420010837999259, 0.929706018528752, 0.6756076859972597], 
             UndirectedEdge[90, 480] -> 
             RGBColor[
              0.8010831932599617, 0.3624728249597305, 0.43533589241834025`], 
             UndirectedEdge[118, 446] -> 
             RGBColor[
              0.46669275560217105`, 0.5768626071721401, 0.9514514101537335], 
             UndirectedEdge[210, 480] -> 
             RGBColor[
              0.6392689004656411, 0.22773754582459013`, 0.4226244702275924], 
             UndirectedEdge[95, 492] -> 
             RGBColor[
              0.875792666145556, 0.41837797189727155`, 0.259869272415489], 
             UndirectedEdge[261, 328] -> 
             RGBColor[
              0.7251559187158538, 0.7749195042034107, 0.6825365204427107], 
             UndirectedEdge[152, 496] -> 
             RGBColor[
              0.6349207926381203, 0.7065843563943843, 0.9518074732393003], 
             UndirectedEdge[86, 177] -> 
             RGBColor[
              0.5459650021360537, 0.6331565746516146, 0.9604401321093234], 
             UndirectedEdge[45, 217] -> 
             RGBColor[
              0.5683683661309606, 0.6578401480718267, 0.9604384245848051], 
             UndirectedEdge[306, 331] -> 
             RGBColor[
              0.9815255179161984, 0.9575197324078621, 0.5969405603691018], 
             UndirectedEdge[103, 129] -> 
             RGBColor[
              0.5319783901988995, 0.6127071666083979, 0.9605276300690322], 
             UndirectedEdge[50, 126] -> 
             RGBColor[
              0.6074936040536676, 0.6815755319744177, 0.9664192287197332], 
             UndirectedEdge[172, 308] -> 
             RGBColor[
              0.6125077807856717, 0.6663584889926204, 0.6682948503545476], 
             UndirectedEdge[112, 266] -> 
             RGBColor[
              0.6166818073874106, 0.6881975490751796, 0.9516216448313864], 
             UndirectedEdge[129, 275] -> 
             RGBColor[
              0.6032954260839367, 0.6644953914178828, 0.6938149829665697], 
             UndirectedEdge[297, 325] -> 
             RGBColor[
              0.7863277750549075, 0.8314308038884638, 0.9017134053414076], 
             UndirectedEdge[202, 396] -> 
             RGBColor[
              0.5218963864436261, 0.6114229274838238, 0.9585052275056026], 
             UndirectedEdge[167, 236] -> 
             RGBColor[
              0.8495125107587314, 0.7717498618244656, 0.6160691486154402], 
             UndirectedEdge[184, 301] -> 
             RGBColor[
              0.8121088346187362, 0.37853028218107737`, 0.4373597121061562], 
             UndirectedEdge[78, 258] -> 
             RGBColor[
              0.8960653709349553, 0.7627429083792242, 0.6109460264174775], 
             UndirectedEdge[172, 470] -> 
             RGBColor[
              0.8735071334915239, 0.4107658454816159, 0.24269870195006282`], 
             UndirectedEdge[72, 159] -> 
             RGBColor[
              0.30785652001586894`, 0.4383744174242251, 0.9409360793516632], 
             UndirectedEdge[304, 337] -> 
             RGBColor[
              0.7572682611376783, 0.3281912415560034, 0.43100508323018594`], 
             UndirectedEdge[88, 271] -> 
             RGBColor[
              0.9391375847334702, 0.9541294908640563, 0.9879083729727666], 
             UndirectedEdge[392, 413] -> 
             RGBColor[
              0.35790849911485945`, 0.47884484685284096`, 0.9443017932791157],
              UndirectedEdge[187, 216] -> 
             RGBColor[
              0.5394651508455853, 0.6344629979307432, 0.9578952630223845], 
             UndirectedEdge[33, 432] -> 
             RGBColor[
              0.876424004066816, 0.41972833987279146`, 0.3285865089786305], 
             UndirectedEdge[36, 75] -> 
             RGBColor[
              0.9941614846453388, 0.9899203309578604, 0.6058918186643216], 
             UndirectedEdge[243, 335] -> 
             RGBColor[
              0.6441644283425235, 0.5238865164393156, 0.5814412678438126], 
             UndirectedEdge[323, 499] -> 
             RGBColor[
              0.6355464982023822, 0.22382506503197, 0.42241248492550043`], 
             UndirectedEdge[168, 480] -> 
             RGBColor[
              0.6348970070714917, 0.22314240867328783`, 0.4223754973664323], 
             UndirectedEdge[301, 388] -> 
             RGBColor[
              0.8962628405683801, 0.9171471195705634, 0.8642317032237198], 
             UndirectedEdge[111, 371] -> 
             RGBColor[
              0.527378510696328, 0.6216024379557992, 0.9581180791633933], 
             UndirectedEdge[103, 231] -> 
             RGBColor[
              0.7761702332303364, 0.8253128886636594, 0.9782604261556922], 
             UndirectedEdge[99, 131] -> 
             RGBColor[
              0.9041340863733258, 0.9243718394054201, 0.9137679154817583], 
             UndirectedEdge[193, 428] -> 
             RGBColor[
              0.6689118178473651, 0.7384159962141496, 0.9697006747277614], 
             UndirectedEdge[189, 370] -> 
             RGBColor[
              0.6079040440905171, 0.5285868123840534, 0.5867038305875903], 
             UndirectedEdge[45, 187] -> 
             RGBColor[
              0.7109258870328801, 0.7740999732777285, 0.9718221065054475], 
             UndirectedEdge[346, 443] -> 
             RGBColor[
              0.8636886145563702, 0.8941458733170908, 0.9868605851519565], 
             UndirectedEdge[19, 318] -> 
             RGBColor[
              0.2964297205038743, 0.4288968093523493, 0.9401926061029984], 
             UndirectedEdge[5, 129] -> 
             RGBColor[
              0.44891440266837623`, 0.5475734119787847, 0.9523132151047233], 
             UndirectedEdge[29, 46] -> 
             RGBColor[
              0.8398465432473405, 0.7205371961100986, 0.6059761186521231], 
             UndirectedEdge[227, 263] -> 
             RGBColor[
              0.8384455778025875, 0.8740177610136036, 0.9844528817716558], 
             UndirectedEdge[272, 435] -> 
             RGBColor[
              0.6810491011891651, 0.26550198643357703`, 0.42522894316203175`],
              UndirectedEdge[208, 483] -> 
             RGBColor[
              0.7028793844301428, 0.7659165578358602, 0.9673918281587182], 
             UndirectedEdge[244, 475] -> 
             RGBColor[
              0.743169646493484, 0.7991602969089885, 0.9753558150417619], 
             UndirectedEdge[350, 412] -> 
             RGBColor[
              0.7374068507405005, 0.38024619719302555`, 0.4381578598475686], 
             UndirectedEdge[217, 398] -> 
             RGBColor[
              0.60676537029374, 0.6878361795518299, 0.9642654791193461], 
             UndirectedEdge[370, 451] -> 
             RGBColor[
              0.5744352838099672, 0.4948064835783481, 0.5847466663353205], 
             UndirectedEdge[265, 424] -> 
             RGBColor[
              0.8924376142172781, 0.907963134169401, 0.6966902870657714], 
             UndirectedEdge[28, 419] -> 
             RGBColor[
              0.969831726897647, 0.9764284230087497, 0.9094084844757475], 
             UndirectedEdge[67, 381] -> 
             RGBColor[
              0.4287936373659061, 0.541633513186941, 0.949405070090807], 
             UndirectedEdge[239, 435] -> 
             RGBColor[
              0.5173601666860179, 0.617838654819145, 0.9554838010601725], 
             UndirectedEdge[302, 370] -> 
             RGBColor[
              0.9355438178376322, 0.7931017193286933, 0.5758724040360177], 
             UndirectedEdge[2, 66] -> 
             RGBColor[
              0.8375817975558117, 0.8267922708390886, 0.6352682894985326], 
             UndirectedEdge[36, 408] -> 
             RGBColor[
              0.6555569842707331, 0.7188096033138347, 0.7201865558093976], 
             UndirectedEdge[76, 483] -> 
             RGBColor[
              0.6802161405510309, 0.5987855477694044, 0.5930419847272986], 
             UndirectedEdge[9, 367] -> 
             RGBColor[
              0.7755918647546849, 0.8247264480975858, 0.9782385023981034], 
             UndirectedEdge[133, 469] -> 
             RGBColor[
              0.7659695699279426, 0.7665287607771725, 0.6240454479687111], 
             UndirectedEdge[46, 297] -> 
             RGBColor[
              0.7387627266651571, 0.6406806983381405, 0.5965088782000116], 
             UndirectedEdge[159, 435] -> 
             RGBColor[
              0.3723242204741912, 0.4969102590404691, 0.9449451479886026], 
             UndirectedEdge[126, 340] -> 
             RGBColor[
              0.9097182614506079, 0.9308486643090756, 0.9912509339638799], 
             UndirectedEdge[27, 290] -> 
             RGBColor[
              0.3730027867973105, 0.49749799908382, 0.944988385634679], 
             UndirectedEdge[326, 338] -> 
             RGBColor[
              0.9333875724897409, 0.897769611625808, 0.637907477036004], 
             UndirectedEdge[179, 438] -> 
             RGBColor[
              0.33017163800960325`, 0.4538031861924453, 0.9425007574478079], 
             UndirectedEdge[138, 339] -> 
             RGBColor[
              0.8320527955858947, 0.38689032910846477`, 0.43836325921630603`],
              UndirectedEdge[475, 482] -> 
             RGBColor[
              0.7550277529402114, 0.808615629109884, 0.9764868518205074], 
             UndirectedEdge[94, 428] -> 
             RGBColor[
              0.9448931721401223, 0.9563212794347509, 0.8937401484033177], 
             UndirectedEdge[186, 295] -> 
             RGBColor[
              0.6611688916292797, 0.7244061536143953, 0.7834317970973408], 
             UndirectedEdge[348, 372] -> 
             RGBColor[
              0.6398505852651133, 0.718469045201971, 0.9648107050394037], 
             UndirectedEdge[293, 343] -> 
             RGBColor[
              0.8473573866569506, 0.8815781530398017, 0.983227014248085], 
             UndirectedEdge[385, 446] -> 
             RGBColor[
              0.7003593348353878, 0.7609664138073813, 0.9114281656900427], 
             UndirectedEdge[7, 288] -> 
             RGBColor[
              0.4585151646363388, 0.5676063408517622, 0.9515308161981513], 
             UndirectedEdge[242, 323] -> 
             RGBColor[
              0.7191908645608835, 0.29727829564779384`, 0.42800749108956115`],
              UndirectedEdge[464, 481] -> 
             RGBColor[
              0.52597832608436, 0.6260519260256711, 0.9558260870329053], 
             UndirectedEdge[42, 108] -> 
             RGBColor[
              0.9738008080861629, 0.9229714077571834, 0.5162981754751155], 
             UndirectedEdge[101, 276] -> 
             RGBColor[
              0.6847118915810397, 0.7451898523189412, 0.8184301173590507], 
             UndirectedEdge[86, 426] -> 
             RGBColor[
              0.5868049632703004, 0.6706123138252311, 0.9629661781362095], 
             UndirectedEdge[37, 324] -> 
             RGBColor[
              0.7159925467614783, 0.775471844724775, 0.9391735855471302], 
             UndirectedEdge[290, 297] -> 
             RGBColor[
              0.4475034536957324, 0.5584696650302381, 0.9507183305191179], 
             UndirectedEdge[315, 380] -> 
             RGBColor[
              0.9643934862575085, 0.9454971716335785, 0.6587680866428361], 
             UndirectedEdge[181, 390] -> 
             RGBColor[
              0.7303306711171348, 0.7886212826687677, 0.9744783164885245], 
             UndirectedEdge[283, 421] -> 
             RGBColor[
              0.891024715932308, 0.9153955053053375, 0.970488073159136], 
             UndirectedEdge[97, 355] -> 
             RGBColor[
              0.30239501689882453`, 0.43397630163312817`, 0.940575907739071], 
             UndirectedEdge[192, 219] -> 
             RGBColor[
              0.8651755078889775, 0.7937078530448614, 0.6197831391932822], 
             UndirectedEdge[171, 192] -> 
             RGBColor[
              0.9274325171035696, 0.8432336780281682, 0.6257521106501593], 
             UndirectedEdge[122, 216] -> 
             RGBColor[
              0.3451269884345777, 0.47279789382031656`, 0.9432325036153208], 
             UndirectedEdge[18, 28] -> 
             RGBColor[
              0.6865640069751608, 0.751457741525184, 0.9571797136411155], 
             UndirectedEdge[178, 288] -> 
             RGBColor[
              0.7750759939852448, 0.7645381293208845, 0.6205298755336948], 
             UndirectedEdge[165, 185] -> 
             RGBColor[
              0.6403970453245578, 0.7059911419676421, 0.8629729129352214], 
             UndirectedEdge[264, 281] -> 
             RGBColor[
              0.43520083693872536`, 0.5437037851528338, 0.9501945061129676], 
             UndirectedEdge[80, 192] -> 
             RGBColor[
              0.9379471794467487, 0.7916882749226708, 0.2689290478971945], 
             UndirectedEdge[74, 402] -> 
             RGBColor[
              0.5236561603133059, 0.6236568326282375, 0.9557841519854748], 
             UndirectedEdge[3, 158] -> 
             RGBColor[
              0.7929693744256, 0.7513136001679697, 0.6156895399473501], 
             UndirectedEdge[426, 476] -> 
             RGBColor[
              0.6814867751458333, 0.7424715326389613, 0.8246445120993677], 
             UndirectedEdge[27, 177] -> 
             RGBColor[
              0.3607728753041977, 0.48482284692644745`, 0.9442853466720524], 
             UndirectedEdge[355, 443] -> 
             RGBColor[
              0.582585976335094, 0.6618540524856713, 0.9640224311172302], 
             UndirectedEdge[21, 256] -> 
             RGBColor[
              0.9785275893174346, 0.9810729574364356, 0.7918227457269805], 
             UndirectedEdge[331, 404] -> 
             RGBColor[
              0.9328555271936487, 0.7622171158947038, 0.5288990184430916], 
             UndirectedEdge[142, 285] -> 
             RGBColor[
              0.8716637779873613, 0.40454777452562063`, 0.23553761390486924`],
              UndirectedEdge[232, 267] -> 
             RGBColor[
              0.910290403976054, 0.9286786847919182, 0.888212665288669], 
             UndirectedEdge[133, 488] -> 
             RGBColor[
              0.6128718846679522, 0.6334969894286179, 0.613515920453088], 
             UndirectedEdge[148, 393] -> 
             RGBColor[
              0.706636362744997, 0.2870859854997955, 0.42701915471795915`], 
             UndirectedEdge[84, 89] -> 
             RGBColor[
              0.8670566051553803, 0.41427135443018204`, 0.4233243619673379], 
             UndirectedEdge[27, 350] -> 
             RGBColor[
              0.699903822364023, 0.34947377037050437`, 0.4352954977548128], 
             UndirectedEdge[8, 435] -> 
             RGBColor[
              0.4796894872830156, 0.5872559002350201, 0.9525182271853226], 
             UndirectedEdge[20, 220] -> 
             RGBColor[
              0.6606605239059232, 0.2478424255505235, 0.4239298010464546], 
             UndirectedEdge[35, 422] -> 
             RGBColor[
              0.8638914330120806, 0.7564416547221966, 0.6116981081923236], 
             UndirectedEdge[65, 177] -> 
             RGBColor[
              0.6285290202465735, 0.6979694601199151, 0.9369338747155196], 
             UndirectedEdge[93, 160] -> 
             RGBColor[
              0.9701197862260001, 0.9769946952018886, 0.924658987633632], 
             UndirectedEdge[277, 373] -> 
             RGBColor[
              0.6571842912436522, 0.729584248218424, 0.9683211596553931], 
             UndirectedEdge[15, 126] -> 
             RGBColor[
              0.8574872343114881, 0.41844134297194024`, 0.44219978244809277`],
              UndirectedEdge[95, 367] -> 
             RGBColor[
              0.9131000024836271, 0.9284611587514258, 0.7175745853897637], 
             UndirectedEdge[304, 465] -> 
             RGBColor[
              0.8748386818756022, 0.4194454419971306, 0.38194883631647814`], 
             UndirectedEdge[218, 305] -> 
             RGBColor[
              0.9446201058852126, 0.9008849700212131, 0.6363192435325833], 
             UndirectedEdge[137, 265] -> 
             RGBColor[
              0.8100544794441585, 0.3694812619111254, 0.43623006638374506`], 
             UndirectedEdge[325, 392] -> 
             RGBColor[
              0.7262742748049978, 0.7826766670062313, 0.896985773818515], 
             UndirectedEdge[263, 393] -> 
             RGBColor[
              0.8200444987692688, 0.3773152391834209, 0.4372178971460031], 
             UndirectedEdge[228, 335] -> 
             RGBColor[
              0.6749529632658313, 0.6551507708083875, 0.606690247359291], 
             UndirectedEdge[104, 408] -> 
             RGBColor[
              0.6009925271229449, 0.5080896562428827, 0.5832199850519748], 
             UndirectedEdge[145, 375] -> 
             RGBColor[
              0.9099053123698384, 0.8936957942346617, 0.6572202271624148], 
             UndirectedEdge[181, 451] -> 
             RGBColor[
              0.580748131260409, 0.6570594884081618, 0.9643514740216292], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.5541517533119414, 0.6400245088006558, 0.9611813259685777], 
             UndirectedEdge[387, 439] -> 
             RGBColor[
              0.7777051328576863, 0.43948665693175204`, 0.44484333392837816`],
              UndirectedEdge[163, 231] -> 
             RGBColor[
              0.49032241272790095`, 0.5886349347586649, 0.9550609399621017], 
             UndirectedEdge[143, 288] -> 
             RGBColor[
              0.767910819980478, 0.8188713674356295, 0.9767856107304953], 
             UndirectedEdge[128, 312] -> 
             RGBColor[
              0.7395372312963631, 0.7035542906571821, 0.6103341519302896], 
             UndirectedEdge[270, 479] -> 
             RGBColor[
              0.7040365636869146, 0.4785925324233068, 0.45251325734523273`], 
             UndirectedEdge[119, 120] -> 
             RGBColor[
              0.8246417800766562, 0.8638293563159276, 0.9808013453035449], 
             UndirectedEdge[105, 462] -> 
             RGBColor[
              0.3968889771415355, 0.5181870166051533, 0.9465103925616843], 
             UndirectedEdge[14, 159] -> 
             RGBColor[
              0.6047284177444421, 0.4916078189697436, 0.5793224936680512], 
             UndirectedEdge[58, 417] -> 
             RGBColor[
              0.85382680401199, 0.33863852419443574`, 0.19614329712536308`], 
             UndirectedEdge[66, 299] -> 
             RGBColor[
              0.9504429693422023, 0.8400998539199724, 0.2848688460880069], 
             UndirectedEdge[11, 348] -> 
             RGBColor[
              0.5898377944336379, 0.6778664085544278, 0.9608735149422607], 
             UndirectedEdge[4, 31] -> 
             RGBColor[
              0.7413183383971343, 0.6388513592477532, 0.5959188629184613], 
             UndirectedEdge[259, 400] -> 
             RGBColor[
              0.9673954775578113, 0.9412771704190774, 0.6399755155578608], 
             UndirectedEdge[247, 451] -> 
             RGBColor[
              0.27794670110743736`, 0.40946998407557916`, 0.9391400254915481],
              UndirectedEdge[17, 261] -> 
             RGBColor[
              0.4591831579925568, 0.5718245994807141, 0.9505677267219557], 
             UndirectedEdge[361, 386] -> 
             RGBColor[
              0.9407519192859535, 0.9532602811948053, 0.9038156048542858], 
             UndirectedEdge[212, 492] -> 
             RGBColor[
              0.7701116441504561, 0.33827761540289325`, 0.4322489378486869], 
             UndirectedEdge[287, 388] -> 
             RGBColor[
              0.8973108779107435, 0.9179658543077964, 0.8643361617915408], 
             UndirectedEdge[383, 480] -> 
             RGBColor[
              0.796843400168114, 0.3591606663727581, 0.434913309466064], 
             UndirectedEdge[403, 440] -> 
             RGBColor[
              0.6132282627091294, 0.6959484170353682, 0.9633353113519976], 
             UndirectedEdge[13, 354] -> 
             RGBColor[
              0.8383333924060355, 0.39189830653058594`, 0.43896230814776604`],
              UndirectedEdge[1, 42] -> 
             RGBColor[
              0.9544985948719407, 0.9101864573721832, 0.6210981325481504], 
             UndirectedEdge[161, 188] -> 
             RGBColor[
              0.8433806707528477, 0.7672814589530708, 0.6155292524966884], 
             UndirectedEdge[194, 426] -> 
             RGBColor[
              0.6766331590959551, 0.727682550678168, 0.6711478273938514], 
             UndirectedEdge[257, 324] -> 
             RGBColor[
              0.7114115597891761, 0.7326908534827605, 0.6352856278969832], 
             UndirectedEdge[198, 479] -> 
             RGBColor[
              0.9013609446342911, 0.6365404963452257, 0.44222995201615933`], 
             UndirectedEdge[372, 431] -> 
             RGBColor[
              0.8144328062528765, 0.851648217675993, 0.7464402191649095], 
             UndirectedEdge[107, 466] -> 
             RGBColor[
              0.9048204256813321, 0.7302635036701435, 0.6012922018726738], 
             UndirectedEdge[122, 330] -> 
             RGBColor[
              0.6322989506068784, 0.7033014690753824, 0.9449985491151125], 
             UndirectedEdge[4, 472] -> 
             RGBColor[
              0.8828927516908874, 0.7506711003070091, 0.6093799831119194], 
             UndirectedEdge[145, 458] -> 
             RGBColor[
              0.6784727301018771, 0.7070251949525217, 0.6373523640999417], 
             UndirectedEdge[3, 451] -> 
             RGBColor[
              0.4546556724526318, 0.5578713994441605, 0.9519651895658843], 
             UndirectedEdge[146, 239] -> 
             RGBColor[
              0.7572794308716941, 0.646660378422895, 0.5961319027849987], 
             UndirectedEdge[15, 282] -> 
             RGBColor[
              0.8751479594018022, 0.4314715802656045, 0.4055021162093295], 
             UndirectedEdge[82, 126] -> 
             RGBColor[
              0.600704081236674, 0.6744393130131474, 0.9660325754395043], 
             UndirectedEdge[413, 474] -> 
             RGBColor[
              0.6223639722427834, 0.6847427541276307, 0.7154127048459648], 
             UndirectedEdge[160, 235] -> 
             RGBColor[
              0.8811485567064488, 0.9068889654867588, 0.9329743424187407], 
             UndirectedEdge[161, 183] -> 
             RGBColor[
              0.5401432407813516, 0.6318010262025751, 0.9593137277134117], 
             UndirectedEdge[366, 429] -> 
             RGBColor[
              0.621577500812095, 0.701893948430445, 0.9645619539394084], 
             UndirectedEdge[7, 313] -> 
             RGBColor[
              0.6165284788494865, 0.5754966457434468, 0.5960212313263299], 
             UndirectedEdge[129, 444] -> 
             RGBColor[
              0.31454301807589935`, 0.4380885581043484, 0.9415846593037183], 
             UndirectedEdge[18, 493] -> 
             RGBColor[
              0.6187661624191934, 0.6978451694778366, 0.9651933179048102], 
             UndirectedEdge[149, 411] -> 
             RGBColor[
              0.8287538650291612, 0.8670268664935883, 0.980457883185109], 
             UndirectedEdge[221, 301] -> 
             RGBColor[
              0.8124112453785619, 0.8534327069909768, 0.9819235254162142], 
             UndirectedEdge[45, 496] -> 
             RGBColor[
              0.5230025413965683, 0.6185465508395456, 0.9575477543481533], 
             UndirectedEdge[478, 482] -> 
             RGBColor[
              0.8736781705395473, 0.9021112740988027, 0.9878133979194139], 
             UndirectedEdge[69, 331] -> 
             RGBColor[
              0.9864015378477353, 0.9886447006825712, 0.8750252397623741], 
             UndirectedEdge[16, 143] -> 
             RGBColor[
              0.6102380735210784, 0.683950226344336, 0.9657298065255717], 
             UndirectedEdge[210, 280] -> 
             RGBColor[
              0.6110677907933402, 0.60534484302367, 0.6045934668666244], 
             UndirectedEdge[101, 390] -> 
             RGBColor[
              0.7755194274430522, 0.8210523213974257, 0.8249873041016424], 
             UndirectedEdge[400, 418] -> 
             RGBColor[
              0.8666250677607027, 0.41394951454780915`, 0.42405484221354883`],
              UndirectedEdge[84, 299] -> 
             RGBColor[
              0.8585798294104681, 0.3574826860475793, 0.19996769292882383`], 
             UndirectedEdge[333, 386] -> 
             RGBColor[
              0.9051531305720109, 0.8157961280824662, 0.621461133003943], 
             UndirectedEdge[244, 341] -> 
             RGBColor[
              0.6537224798449532, 0.7256076831344209, 0.968572653144611], 
             UndirectedEdge[143, 373] -> 
             RGBColor[
              0.896708036082962, 0.920448158631157, 0.9890910578036927], 
             UndirectedEdge[160, 284] -> 
             RGBColor[
              0.9687049158219394, 0.9759394871711777, 0.927053994170405], 
             UndirectedEdge[281, 343] -> 
             RGBColor[
              0.679004100435692, 0.7485313580009089, 0.9690719091814217], 
             UndirectedEdge[207, 445] -> 
             RGBColor[
              0.7399692128531481, 0.7929761013386706, 0.863837624394945], 
             UndirectedEdge[260, 334] -> 
             RGBColor[
              0.6797925725623698, 0.7480676156494002, 0.9699525517067591], 
             UndirectedEdge[66, 114] -> 
             RGBColor[
              0.8381156746991734, 0.8272093397210992, 0.6353215013828173], 
             UndirectedEdge[364, 381] -> 
             RGBColor[
              0.4449019271534192, 0.5547109485066293, 0.9506731736694897], 
             UndirectedEdge[204, 306] -> 
             RGBColor[
              0.9810604991231573, 0.9573274351865018, 0.6046471251998506], 
             UndirectedEdge[358, 361] -> 
             RGBColor[
              0.9316318307716053, 0.9459881701716719, 0.9029457226701882], 
             UndirectedEdge[294, 415] -> 
             RGBColor[
              0.9670509695751841, 0.9749472475750337, 0.9406582934124808], 
             UndirectedEdge[2, 255] -> 
             RGBColor[
              0.819680431106879, 0.8599004245082971, 0.982438680373895], 
             UndirectedEdge[326, 443] -> 
             RGBColor[
              0.8962711756881642, 0.9201263231335224, 0.9899683389195029], 
             UndirectedEdge[58, 145] -> 
             RGBColor[
              0.9472267612793476, 0.8250341922414357, 0.2943348005978884], 
             UndirectedEdge[103, 346] -> 
             RGBColor[
              0.8477444026374934, 0.8814323915270814, 0.9853398119855681], 
             UndirectedEdge[62, 108] -> 
             RGBColor[
              0.7711433522784172, 0.8179974710282835, 0.85428563514528], 
             UndirectedEdge[91, 336] -> 
             RGBColor[
              0.482425402023178, 0.5789688502545736, 0.954827447113878], 
             UndirectedEdge[338, 395] -> 
             RGBColor[
              0.6455470123867983, 0.6642474645214049, 0.6135217800269084], 
             UndirectedEdge[19, 335] -> 
             RGBColor[
              0.36211959295326934`, 0.4880215458930473, 0.9442967480745574], 
             UndirectedEdge[2, 195] -> 
             RGBColor[
              0.5669730044878697, 0.657271102447661, 0.960078826985516], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.9190618332333773, 0.850501689131971, 0.6280758244030951], 
             UndirectedEdge[150, 325] -> 
             RGBColor[
              0.8743238320354785, 0.4192325383572021, 0.3904812305560025], 
             UndirectedEdge[208, 238] -> 
             RGBColor[
              0.9324929915911995, 0.8450383641826283, 0.6205357273788283], 
             UndirectedEdge[318, 335] -> 
             RGBColor[
              0.3503438650519469, 0.4756445092444855, 0.9436261377912054], 
             UndirectedEdge[12, 421] -> 
             RGBColor[
              0.9090331262510508, 0.9253556192555271, 0.7283148194403833], 
             UndirectedEdge[102, 278] -> 
             RGBColor[
              0.9362490326699436, 0.8298041275859058, 0.6001848777969194], 
             UndirectedEdge[5, 209] -> 
             RGBColor[
              0.7728749507914882, 0.34043633155277586`, 0.4325243584300962], 
             UndirectedEdge[76, 463] -> 
             RGBColor[
              0.6779522331516386, 0.5969476057547117, 0.5928637616438525], 
             UndirectedEdge[293, 445] -> 
             RGBColor[
              0.9651569127068624, 0.9721636337255475, 0.8824669426940721], 
             UndirectedEdge[48, 250] -> 
             RGBColor[
              0.4914616871056165, 0.5941880020793316, 0.9542849522618653], 
             UndirectedEdge[459, 477] -> 
             RGBColor[
              0.5798511009218767, 0.5236957952655135, 0.5902830646910504], 
             UndirectedEdge[400, 404] -> 
             RGBColor[
              0.9211751690510104, 0.7542379072323766, 0.5814505264563645], 
             UndirectedEdge[144, 246] -> 
             RGBColor[
              0.671643758643034, 0.7422729002990294, 0.9686859652071018], 
             UndirectedEdge[90, 393] -> 
             RGBColor[
              0.8010831932599617, 0.3624728249597305, 0.43533589241834025`], 
             UndirectedEdge[157, 360] -> 
             RGBColor[
              0.9476536784864769, 0.9604807796412249, 0.9734928476019025], 
             UndirectedEdge[156, 250] -> 
             RGBColor[
              0.65832622213599, 0.722023140285357, 0.7900167116701573], 
             UndirectedEdge[25, 220] -> 
             RGBColor[
              0.7015961483529711, 0.2829941123972781, 0.42662237057810526`], 
             UndirectedEdge[261, 407] -> 
             RGBColor[
              0.4651720717320734, 0.576686669451943, 0.9510391959496443], 
             UndirectedEdge[42, 364] -> 
             RGBColor[
              0.7740500027657855, 0.76789517314716, 0.6214138011876893], 
             UndirectedEdge[83, 257] -> 
             RGBColor[
              0.7594358404407622, 0.7716791279849066, 0.6390662751886125], 
             UndirectedEdge[137, 263] -> 
             RGBColor[
              0.8200444987692688, 0.3773152391834209, 0.4372178971460031], 
             UndirectedEdge[27, 65] -> 
             RGBColor[
              0.7030768651489114, 0.7646212740059528, 0.9416077572893973], 
             UndirectedEdge[318, 421] -> 
             RGBColor[
              0.5548877941830115, 0.6399566760546287, 0.9613520121449761], 
             UndirectedEdge[203, 341] -> 
             RGBColor[
              0.7014058008850221, 0.7623849962881533, 0.9299879488944571], 
             UndirectedEdge[80, 483] -> 
             RGBColor[
              0.7076770331760364, 0.7099635097848069, 0.6152568818985017], 
             UndirectedEdge[95, 319] -> 
             RGBColor[
              0.8025257899153724, 0.8415105338233719, 0.7068971871932439], 
             UndirectedEdge[84, 376] -> 
             RGBColor[
              0.8763216415334298, 0.4195093967643181, 0.31744497892787804`], 
             UndirectedEdge[260, 446] -> 
             RGBColor[
              0.46752276415876126`, 0.5775364455098394, 0.9515167514677298], 
             UndirectedEdge[174, 393] -> 
             RGBColor[
              0.678821507336482, 0.2635725566005056, 0.4250870028515227], 
             UndirectedEdge[185, 216] -> 
             RGBColor[
              0.6896394590242023, 0.7504652092030046, 0.8660438556926142], 
             UndirectedEdge[143, 321] -> 
             RGBColor[
              0.9207814691436944, 0.9396436606978524, 0.9913872033396327], 
             UndirectedEdge[296, 415] -> 
             RGBColor[
              0.7697971851378781, 0.8194722124005287, 0.9519743773119802], 
             UndirectedEdge[42, 113] -> 
             RGBColor[
              0.9290307727375189, 0.8903841008471088, 0.6361774319568427], 
             UndirectedEdge[54, 264] -> 
             RGBColor[
              0.6310137451327313, 0.6936507146458982, 0.6975548129111753], 
             UndirectedEdge[9, 95] -> 
             RGBColor[
              0.8552318607077256, 0.8831452050379747, 0.7118357342548067], 
             UndirectedEdge[47, 55] -> 
             RGBColor[
              0.7467031357797586, 0.7977063620376514, 0.8266859940739327], 
             UndirectedEdge[212, 330] -> 
             RGBColor[
              0.8187784663153156, 0.8588273386538339, 0.9588780320620927], 
             UndirectedEdge[89, 244] -> 
             RGBColor[
              0.9275539469426503, 0.9442752623698076, 0.9653857297872522], 
             UndirectedEdge[3, 247] -> 
             RGBColor[
              0.47567916163036134`, 0.5799684195361566, 0.953162446173091], 
             UndirectedEdge[26, 318] -> 
             RGBColor[
              0.6191160617425963, 0.6350897806819902, 0.6105140370738731], 
             UndirectedEdge[46, 426] -> 
             RGBColor[
              0.6305541759986439, 0.5505129576793012, 0.5886310967685813], 
             UndirectedEdge[102, 247] -> 
             RGBColor[
              0.6296204546280079, 0.7007287759717685, 0.9462363856059], 
             UndirectedEdge[285, 287] -> 
             RGBColor[
              0.8904518902571056, 0.8947523419614536, 0.679465943361903], 
             UndirectedEdge[346, 390] -> 
             RGBColor[
              0.7007311347413177, 0.7650194158207022, 0.9716550862851809], 
             UndirectedEdge[388, 473] -> 
             RGBColor[
              0.87623643642312, 0.4200234494231826, 0.35878442619129436`], 
             UndirectedEdge[377, 412] -> 
             RGBColor[
              0.7652993005407005, 0.7986645923147723, 0.6725533850727168], 
             UndirectedEdge[7, 321] -> 
             RGBColor[
              0.6113858137995551, 0.688378634113985, 0.9661324088072887], 
             UndirectedEdge[209, 275] -> 
             RGBColor[
              0.8757956330685285, 0.4183843178455079, 0.2601922036713271], 
             UndirectedEdge[204, 346] -> 
             RGBColor[
              0.9165209299103892, 0.9343553228309852, 0.9195761795139141], 
             UndirectedEdge[220, 297] -> 
             RGBColor[
              0.7396533513344599, 0.3138906642351071, 0.4296183730049359], 
             UndirectedEdge[16, 185] -> 
             RGBColor[
              0.6377560754144314, 0.7032153151449356, 0.8628225136058045], 
             UndirectedEdge[323, 449] -> 
             RGBColor[
              0.6286461100546239, 0.21657231957879808`, 0.4220195180286951], 
             UndirectedEdge[224, 481] -> 
             RGBColor[
              0.46950045851245936`, 0.5781743360183254, 0.9519398186801826], 
             UndirectedEdge[86, 476] -> 
             RGBColor[
              0.9003867857457805, 0.9200013350765495, 0.8429471340836303], 
             UndirectedEdge[66, 385] -> 
             RGBColor[
              0.9730866768694226, 0.9323225628318714, 0.5867526202698192], 
             UndirectedEdge[184, 316] -> 
             RGBColor[
              0.6315984479728387, 0.22682863988507873`, 0.42315859244308457`],
              UndirectedEdge[308, 362] -> 
             RGBColor[
              0.35167360730016606`, 0.47229158024062484`, 0.9439467254139647],
              UndirectedEdge[216, 361] -> 
             RGBColor[
              0.6886761990828456, 0.7500668764626024, 0.882007565757714], 
             UndirectedEdge[123, 410] -> 
             RGBColor[
              0.8694774397466345, 0.8950218968625029, 0.7731615621367399], 
             UndirectedEdge[174, 225] -> 
             RGBColor[
              0.678821507336482, 0.2635725566005056, 0.4250870028515227], 
             UndirectedEdge[3, 139] -> 
             RGBColor[
              0.7967736799291522, 0.7663964037798958, 0.6187505734540353], 
             UndirectedEdge[226, 472] -> 
             RGBColor[
              0.8564539854657711, 0.8883771764590223, 0.9861705397708656], 
             UndirectedEdge[9, 441] -> 
             RGBColor[
              0.8467118599516924, 0.8545515097390366, 0.6662995786480495], 
             UndirectedEdge[253, 354] -> 
             RGBColor[
              0.8961106611219136, 0.7978494156785887, 0.6181944637402309], 
             UndirectedEdge[47, 73] -> 
             RGBColor[
              0.9874992127227371, 0.9679384704667517, 0.5382125347285582], 
             UndirectedEdge[305, 432] -> 
             RGBColor[
              0.8623837911144627, 0.3725641266088242, 0.20302844980631513`], 
             UndirectedEdge[4, 226] -> 
             RGBColor[
              0.8646706764798965, 0.7361413121588198, 0.6076419453112565], 
             UndirectedEdge[112, 359] -> 
             RGBColor[
              0.6050980003956643, 0.6760222334710708, 0.9509619641599132], 
             UndirectedEdge[101, 204] -> 
             RGBColor[
              0.9913092226121238, 0.9903882284077087, 0.7729083973303756], 
             UndirectedEdge[256, 409] -> 
             RGBColor[
              0.8901549323306334, 0.5256412125934586, 0.33452135276450456`], 
             UndirectedEdge[64, 268] -> 
             RGBColor[
              0.8547600884228992, 0.8258429264696776, 0.6276628843510104], 
             UndirectedEdge[97, 395] -> 
             RGBColor[
              0.32823965614895223`, 0.45872642517657597`, 0.9421361185322479],
              UndirectedEdge[117, 156] -> 
             RGBColor[
              0.7206900400341826, 0.7760395448521443, 0.7939904790004713], 
             UndirectedEdge[48, 117] -> 
             RGBColor[
              0.5538255050038091, 0.648204406646119, 0.9582587195921792], 
             UndirectedEdge[5, 103] -> 
             RGBColor[
              0.7670508399049876, 0.8181887492879405, 0.9773514902545974], 
             UndirectedEdge[344, 438] -> 
             RGBColor[
              0.6638982855883582, 0.7338617806662333, 0.9694786951507833], 
             UndirectedEdge[42, 381] -> 
             RGBColor[
              0.6245670408249248, 0.6410186660961203, 0.6108756726026359], 
             UndirectedEdge[224, 398] -> 
             RGBColor[
              0.5929610057569243, 0.6758795328175757, 0.9633858772177805], 
             UndirectedEdge[226, 405] -> 
             RGBColor[
              0.8474259480554553, 0.8811784644875837, 0.9853094375032456], 
             UndirectedEdge[231, 346] -> 
             RGBColor[
              0.773799808432319, 0.8234227762731873, 0.9780343329223542], 
             UndirectedEdge[168, 181] -> 
             RGBColor[
              0.5873130359027925, 0.663959619426302, 0.9647253356291069], 
             UndirectedEdge[178, 391] -> 
             RGBColor[
              0.6967598856624466, 0.700662834512878, 0.6144459849003856], 
             UndirectedEdge[30, 133] -> 
             RGBColor[
              0.9709324163190295, 0.9276831879771833, 0.5965445739332167], 
             UndirectedEdge[120, 363] -> 
             RGBColor[
              0.5209069583734105, 0.617547063074195, 0.957069024685357], 
             UndirectedEdge[452, 468] -> 
             RGBColor[
              0.6242772881412788, 0.6890901661632148, 0.8631481245499122], 
             UndirectedEdge[159, 344] -> 
             RGBColor[
              0.6204951379733014, 0.6962681557077004, 0.9667130849646484], 
             UndirectedEdge[68, 330] -> 
             RGBColor[
              0.6210654577435442, 0.6914943558314333, 0.9443588183150091], 
             UndirectedEdge[359, 440] -> 
             RGBColor[
              0.48022257183265793`, 0.577844455555469, 0.9545134591598265], 
             UndirectedEdge[180, 413] -> 
             RGBColor[
              0.4236392854951955, 0.5322080603745792, 0.9494763615627798], 
             UndirectedEdge[81, 442] -> 
             RGBColor[
              0.8163811859100429, 0.8085455549127408, 0.6306951332178679], 
             UndirectedEdge[165, 277] -> 
             RGBColor[
              0.373355298591895, 0.4958621427543094, 0.945110307706689], 
             UndirectedEdge[28, 310] -> 
             RGBColor[
              0.9462326814451365, 0.9594210023744625, 0.975898224937507], 
             UndirectedEdge[71, 470] -> 
             RGBColor[
              0.7419794203483685, 0.31577907184881315`, 0.4298014896783824], 
             UndirectedEdge[129, 276] -> 
             RGBColor[
              0.2941575864407113, 0.42043172182353405`, 0.9402857176260535], 
             UndirectedEdge[192, 251] -> 
             RGBColor[
              0.9599487480705569, 0.8656944133140831, 0.4859492502591747], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.6388114444653155, 0.7122933365161837, 0.9678062891503332], 
             UndirectedEdge[15, 323] -> 
             RGBColor[
              0.8189549668917826, 0.14670175841550373`, 0.1657846037431313], 
             UndirectedEdge[20, 473] -> 
             RGBColor[
              0.6606605239059232, 0.2478424255505235, 0.4239298010464546], 
             UndirectedEdge[336, 354] -> 
             RGBColor[
              0.7963552243391103, 0.8413260351972818, 0.980207400467757], 
             UndirectedEdge[36, 440] -> 
             RGBColor[
              0.8483501862691578, 0.8780668233534028, 0.7349888562362867], 
             UndirectedEdge[31, 311] -> 
             RGBColor[
              0.683730551964502, 0.752076093007061, 0.9696439159410546], 
             UndirectedEdge[366, 405] -> 
             RGBColor[
              0.6709455370455608, 0.7407567485818605, 0.9694039185950829], 
             UndirectedEdge[257, 374] -> 
             RGBColor[
              0.8666842485094457, 0.3877506523474892, 0.2161930821884051], 
             UndirectedEdge[194, 254] -> 
             RGBColor[
              0.9452314624341942, 0.8118744631746269, 0.3200663948073812], 
             UndirectedEdge[284, 456] -> 
             RGBColor[
              0.7748595326440283, 0.8240160156945626, 0.9640123479682197], 
             UndirectedEdge[30, 429] -> 
             RGBColor[
              0.8712486684527926, 0.8993446049078098, 0.9405806827246603], 
             UndirectedEdge[182, 463] -> 
             RGBColor[
              0.7134473570062846, 0.7366508386393358, 0.6388743179203662], 
             UndirectedEdge[130, 238] -> 
             RGBColor[
              0.8526904832113609, 0.3341333908764013, 0.19522898673629963`], 
             UndirectedEdge[19, 67] -> 
             RGBColor[
              0.4351868789622252, 0.5483532154596017, 0.949769155741764], 
             UndirectedEdge[114, 446] -> 
             RGBColor[
              0.5653883326651385, 0.6558531906966091, 0.9599970468030408], 
             UndirectedEdge[164, 418] -> 
             RGBColor[
              0.6308112621054398, 0.21884803166277444`, 0.42214282023493366`],
              UndirectedEdge[96, 457] -> 
             RGBColor[
              0.9479474940653562, 0.8195037280702481, 0.36860505839571944`], 
             UndirectedEdge[285, 354] -> 
             RGBColor[
              0.9303577555900953, 0.9264151215843099, 0.6833138830789529], 
             UndirectedEdge[432, 460] -> 
             RGBColor[
              0.8738163388043336, 0.4190226768641425, 0.3988917067464562], 
             UndirectedEdge[82, 249] -> 
             RGBColor[
              0.5280798416739124, 0.6167919193865536, 0.9590362952152981], 
             UndirectedEdge[176, 262] -> 
             RGBColor[
              0.8869874365909485, 0.9124902188935675, 0.9809871629525401], 
             UndirectedEdge[216, 358] -> 
             RGBColor[
              0.6304717075234213, 0.7059899742979261, 0.9668513164910157], 
             UndirectedEdge[54, 374] -> 
             RGBColor[
              0.8758088780031903, 0.4184126474214812, 0.2616338330709987], 
             UndirectedEdge[214, 491] -> 
             RGBColor[
              0.928684449553274, 0.9438808027426198, 0.9132075677549962], 
             UndirectedEdge[68, 357] -> 
             RGBColor[
              0.6332532861238875, 0.7002444926140678, 0.9085233508711507], 
             UndirectedEdge[260, 328] -> 
             RGBColor[
              0.7551955282527184, 0.7993070124944253, 0.6849013485441683], 
             UndirectedEdge[224, 286] -> 
             RGBColor[
              0.6810752359673363, 0.7291466330951398, 0.6677982586592522], 
             UndirectedEdge[219, 293] -> 
             RGBColor[
              0.8717369389943185, 0.9006236446172139, 0.985656940185204], 
             UndirectedEdge[209, 404] -> 
             RGBColor[
              0.8372503782733043, 0.2677117569404419, 0.1825361754240275], 
             UndirectedEdge[197, 289] -> 
             RGBColor[
              0.683559849263502, 0.7479443593369227, 0.943687934649774], 
             UndirectedEdge[227, 424] -> 
             RGBColor[
              0.9203727246997249, 0.9300401435411851, 0.699407223542805], 
             UndirectedEdge[458, 461] -> 
             RGBColor[
              0.6488182601781396, 0.7206815449845223, 0.9685724421708813], 
             UndirectedEdge[292, 464] -> 
             RGBColor[
              0.655767299313428, 0.7287009373019124, 0.9679029039301451], 
             UndirectedEdge[386, 441] -> 
             RGBColor[
              0.9336837565827394, 0.9230740075736005, 0.6748143719023189], 
             UndirectedEdge[257, 343] -> 
             RGBColor[
              0.8611300643890811, 0.8524852948829853, 0.648271089655739], 
             UndirectedEdge[132, 457] -> 
             RGBColor[
              0.8548633958489873, 0.37622493156628034`, 0.19835032975156372`],
              UndirectedEdge[69, 259] -> 
             RGBColor[
              0.9768794539808003, 0.9483481187958942, 0.6238237366928612], 
             UndirectedEdge[68, 95] -> 
             RGBColor[
              0.6365054568722466, 0.6993963981278466, 0.6952221016491802], 
             UndirectedEdge[247, 278] -> 
             RGBColor[
              0.6055987683271027, 0.5606423557817126, 0.5942857742897741], 
             UndirectedEdge[293, 440] -> 
             RGBColor[
              0.820695660899842, 0.8607498102417277, 0.9805696225926094], 
             UndirectedEdge[307, 442] -> 
             RGBColor[
              0.786806508743961, 0.7850244546953666, 0.6280326050712517], 
             UndirectedEdge[406, 493] -> 
             RGBColor[
              0.555163205327425, 0.6413938038054274, 0.9611904515332044], 
             UndirectedEdge[155, 479] -> 
             RGBColor[
              0.8331230576323193, 0.5831563892139201, 0.46330186332600576`], 
             UndirectedEdge[311, 488] -> 
             RGBColor[
              0.5222131150269899, 0.6122087879412037, 0.9584515547308105], 
             UndirectedEdge[226, 345] -> 
             RGBColor[
              0.871871221476531, 0.9006704619642791, 0.987641049504701], 
             UndirectedEdge[183, 273] -> 
             RGBColor[
              0.6389623733282263, 0.7094059108221873, 0.942154519167997], 
             UndirectedEdge[384, 499] -> 
             RGBColor[
              0.5761818359126266, 0.655331057343834, 0.9636261896098998], 
             UndirectedEdge[20, 325] -> 
             RGBColor[
              0.6678385339121027, 0.7323584458615884, 0.8931805474036856], 
             UndirectedEdge[252, 424] -> 
             RGBColor[
              0.7988090797237428, 0.8342975864373081, 0.6877153178285416], 
             UndirectedEdge[285, 473] -> 
             RGBColor[
              0.8716637779873613, 0.40454777452562063`, 0.23553761390486927`],
              UndirectedEdge[71, 236] -> 
             RGBColor[
              0.685843268829712, 0.7537230865418503, 0.9698568690149132], 
             UndirectedEdge[2, 446] -> 
             RGBColor[
              0.5648544555217769, 0.6554361218145984, 0.959943834918756], 
             UndirectedEdge[33, 351] -> 
             RGBColor[
              0.6117587481629536, 0.6744162259291338, 0.7968347374014205], 
             UndirectedEdge[172, 466] -> 
             RGBColor[
              0.9283949312072772, 0.7353708776618462, 0.30682681606589174`], 
             UndirectedEdge[12, 279] -> 
             RGBColor[
              0.722491999543238, 0.7766365750572451, 0.7117360677377691], 
             UndirectedEdge[171, 219] -> 
             RGBColor[
              0.867861497139153, 0.8975894408616343, 0.9872277560773777], 
             UndirectedEdge[153, 223] -> 
             RGBColor[
              0.6475013981032092, 0.7155994487001949, 0.923347455074528], 
             UndirectedEdge[121, 489] -> 
             RGBColor[
              0.6277734254122715, 0.697940304420394, 0.9412757235846317], 
             UndirectedEdge[362, 470] -> 
             RGBColor[
              0.6996176845011868, 0.28138790631361876`, 0.42646661865634083`],
              UndirectedEdge[168, 232] -> 
             RGBColor[
              0.6307064618376947, 0.6959341689470713, 0.8657713991925011], 
             UndirectedEdge[285, 409] -> 
             RGBColor[
              0.88546157214118, 0.5106036666238222, 0.24875039716894565`], 
             UndirectedEdge[159, 439] -> 
             RGBColor[
              0.4966115767462451, 0.5988034266404293, 0.9545475592420076], 
             UndirectedEdge[156, 263] -> 
             RGBColor[
              0.9099772850867357, 0.927124280879758, 0.8107501301135381], 
             UndirectedEdge[149, 314] -> 
             RGBColor[
              0.9378085476745809, 0.9531382972016351, 0.9901580860450858], 
             UndirectedEdge[110, 457] -> 
             RGBColor[
              0.9219346358032778, 0.8034253848944712, 0.6125429266996234], 
             UndirectedEdge[43, 263] -> 
             RGBColor[
              0.8458550933039185, 0.575706779051383, 0.46193415162128093`], 
             UndirectedEdge[141, 160] -> 
             RGBColor[
              0.8863867023185696, 0.5184726058245481, 0.417747003608634], 
             UndirectedEdge[345, 389] -> 
             RGBColor[
              0.9498106355091234, 0.9586526626584257, 0.7956089956782988], 
             UndirectedEdge[225, 247] -> 
             RGBColor[
              0.644536063428389, 0.23327366805585842`, 0.4229244273662516], 
             UndirectedEdge[171, 293] -> 
             RGBColor[
              0.9339939482089106, 0.9501494696005206, 0.9916259116420809], 
             UndirectedEdge[179, 415] -> 
             RGBColor[
              0.6011522414748747, 0.6700992867172902, 0.9405594564304133], 
             UndirectedEdge[143, 414] -> 
             RGBColor[
              0.9390001528758138, 0.9540269944096402, 0.9881410092598095], 
             UndirectedEdge[77, 388] -> 
             RGBColor[
              0.8964474475997748, 0.9172913359865542, 0.8642501031273584], 
             UndirectedEdge[305, 406] -> 
             RGBColor[
              0.623265812205281, 0.6379002909524284, 0.6103523129524865], 
             UndirectedEdge[55, 256] -> 
             RGBColor[
              0.7464080863609621, 0.7970752811649181, 0.7945716856718832], 
             UndirectedEdge[367, 450] -> 
             RGBColor[
              0.591344887449476, 0.6734747035991766, 0.963725471727551], 
             UndirectedEdge[171, 258] -> 
             RGBColor[
              0.9110329310219858, 0.774677634509027, 0.6123736456602771], 
             UndirectedEdge[366, 423] -> 
             RGBColor[
              0.703483482344806, 0.766701622944482, 0.9725074168646916], 
             UndirectedEdge[309, 393] -> 
             RGBColor[
              0.8182277062132116, 0.37586657811474117`, 0.4370446098501366], 
             UndirectedEdge[324, 360] -> 
             RGBColor[
              0.7044811808353634, 0.7668866868652102, 0.958659325414968], 
             UndirectedEdge[125, 310] -> 
             RGBColor[
              0.7498920742307691, 0.8041163040861307, 0.9719706162866416], 
             UndirectedEdge[33, 463] -> 
             RGBColor[
              0.7271562163568163, 0.7815788477623282, 0.8039651212688388], 
             UndirectedEdge[137, 280] -> 
             RGBColor[
              0.8578682933965857, 0.3546616828578565, 0.19939517435015722`], 
             UndirectedEdge[72, 179] -> 
             RGBColor[
              0.258485873029528, 0.38901541987793037`, 0.9380317601222263], 
             UndirectedEdge[17, 165] -> 
             RGBColor[
              0.37338051078081175`, 0.49588261114506815`, 0.9451122925025559],
              UndirectedEdge[402, 417] -> 
             RGBColor[
              0.6897261487089852, 0.27301760887415616`, 0.42578183695718286`],
              UndirectedEdge[102, 225] -> 
             RGBColor[
              0.864969572990283, 0.412714849258654, 0.42685716303768173`], 
             UndirectedEdge[83, 231] -> 
             RGBColor[
              0.6278412871891746, 0.7078317861685555, 0.964472125452244], 
             UndirectedEdge[194, 377] -> 
             RGBColor[
              0.984065080633495, 0.9579099166590945, 0.3925962766284956], 
             UndirectedEdge[131, 495] -> 
             RGBColor[
              0.8061509346745783, 0.8475461334836236, 0.9041934591532225], 
             UndirectedEdge[213, 447] -> 
             RGBColor[
              0.5374026847337424, 0.6224201757726853, 0.9602274912910758], 
             UndirectedEdge[146, 166] -> 
             RGBColor[
              0.5758451444541747, 0.4900077020161404, 0.5834276841643418], 
             UndirectedEdge[422, 428] -> 
             RGBColor[
              0.8620945810364677, 0.8928748342572079, 0.9867085448118178], 
             UndirectedEdge[232, 338] -> 
             RGBColor[
              0.9737979736686664, 0.9273655781782114, 0.5386690170351955], 
             UndirectedEdge[366, 469] -> 
             RGBColor[
              0.5299794094846018, 0.6293001857767404, 0.9561410669746238], 
             UndirectedEdge[245, 482] -> 
             RGBColor[
              0.9391579289436037, 0.9535410689751356, 0.9669469329664224], 
             UndirectedEdge[40, 243] -> 
             RGBColor[
              0.6107624437760353, 0.49495539624038204`, 0.579312922923451], 
             UndirectedEdge[174, 320] -> 
             RGBColor[
              0.5793359526296358, 0.6662181512625098, 0.9616119706504154], 
             UndirectedEdge[30, 31] -> 
             RGBColor[
              0.788070328802821, 0.833586375971408, 0.9328226294544968], 
             UndirectedEdge[77, 354] -> 
             RGBColor[
              0.8395928815741481, 0.8751036216476593, 0.9845169260620659], 
             UndirectedEdge[24, 223] -> 
             RGBColor[
              0.9893299253579746, 0.9888435406159594, 0.7529235821304705], 
             UndirectedEdge[261, 391] -> 
             RGBColor[
              0.4515495638735924, 0.5653325539143579, 0.950048222525353], 
             UndirectedEdge[125, 323] -> 
             RGBColor[
              0.731286878090292, 0.3070983843501673, 0.4289597335837537], 
             UndirectedEdge[1, 364] -> 
             RGBColor[
              0.774833481200435, 0.8238787397826922, 0.9608956336150041], 
             UndirectedEdge[88, 133] -> 
             RGBColor[
              0.9485655533372352, 0.9110720319449315, 0.6375411978428598], 
             UndirectedEdge[178, 407] -> 
             RGBColor[
              0.7103823935209276, 0.7120169500504632, 0.6154369583246768], 
             UndirectedEdge[103, 486] -> 
             RGBColor[
              0.8461292808392445, 0.8801445372464712, 0.9851857602266149], 
             UndirectedEdge[204, 486] -> 
             RGBColor[
              0.9149058081121404, 0.933067468550375, 0.919422127754961], 
             UndirectedEdge[89, 407] -> 
             RGBColor[
              0.7181197080357126, 0.7774644397025046, 0.9464666676493735], 
             UndirectedEdge[38, 301] -> 
             RGBColor[
              0.8941140734147632, 0.9162585491317458, 0.8998423357902883], 
             UndirectedEdge[92, 132] -> 
             RGBColor[
              0.8074100350851449, 0.43005754928983375`, 0.4437493766668593], 
             UndirectedEdge[8, 146] -> 
             RGBColor[
              0.7196087514686917, 0.6160776238387701, 0.5931663289101489], 
             UndirectedEdge[44, 110] -> 
             RGBColor[
              0.9397153497174934, 0.9545603870431376, 0.9869303675600567], 
             UndirectedEdge[102, 252] -> 
             RGBColor[
              0.7842695441581269, 0.8313746190225761, 0.9572198748949103], 
             UndirectedEdge[273, 283] -> 
             RGBColor[
              0.9612432522212473, 0.9706158614817322, 0.9504892439974157], 
             UndirectedEdge[158, 428] -> 
             RGBColor[
              0.9161221408203868, 0.8481576581976772, 0.6277954339164495], 
             UndirectedEdge[176, 328] -> 
             RGBColor[
              0.9672146311317744, 0.9675763328474882, 0.6963960999981567], 
             UndirectedEdge[45, 398] -> 
             RGBColor[
              0.7688345523720306, 0.8193386627628301, 0.9775939010792086], 
             UndirectedEdge[233, 275] -> 
             RGBColor[
              0.9869413393115265, 0.9861745688167238, 0.684480190374268], 
             UndirectedEdge[250, 485] -> 
             RGBColor[
              0.5048201457018284, 0.6046237314627381, 0.9556163985728425], 
             UndirectedEdge[29, 65] -> 
             RGBColor[
              0.8786613486295168, 0.905449437724329, 0.9568049426259474], 
             UndirectedEdge[166, 453] -> 
             RGBColor[
              0.6556960207416265, 0.3978551115542002, 0.44430728541045394`], 
             UndirectedEdge[222, 294] -> 
             RGBColor[
              0.9805032619647867, 0.9837141152324338, 0.861200618540547], 
             UndirectedEdge[150, 220] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[311, 423] -> 
             RGBColor[
              0.8488148731471845, 0.8826419964574999, 0.9853474321365013], 
             UndirectedEdge[210, 424] -> 
             RGBColor[
              0.636259245749502, 0.6953475600395981, 0.6762818928315425], 
             UndirectedEdge[179, 312] -> 
             RGBColor[
              0.39289902411500277`, 0.5055527904832343, 0.9472110237467004], 
             UndirectedEdge[310, 323] -> 
             RGBColor[
              0.858399838063554, 0.40781515170725324`, 0.43797801060734065`], 
             UndirectedEdge[108, 349] -> 
             RGBColor[
              0.9939362542524715, 0.9917604995493088, 0.7501554897149039], 
             UndirectedEdge[355, 395] -> 
             RGBColor[
              0.309013340647051, 0.43970876101721823`, 0.9409976214759541], 
             UndirectedEdge[47, 200] -> 
             RGBColor[
              0.9561940880197455, 0.9643549101588924, 0.8458492899218654], 
             UndirectedEdge[152, 217] -> 
             RGBColor[
              0.6802866173725126, 0.7458779536266654, 0.954698143475952], 
             UndirectedEdge[174, 210] -> 
             RGBColor[
              0.3424976117031848, 0.46871115363764354`, 0.9431312096186726], 
             UndirectedEdge[135, 211] -> 
             RGBColor[
              0.9433711443797754, 0.9570833126763281, 0.9736845064039656], 
             UndirectedEdge[52, 491] -> 
             RGBColor[
              0.845032393604636, 0.8781366384233458, 0.9049746120216013], 
             UndirectedEdge[41, 250] -> 
             RGBColor[
              0.4421808399627842, 0.5544610106398766, 0.9502129748242125], 
             UndirectedEdge[220, 392] -> 
             RGBColor[
              0.6996176845011868, 0.2813879063136187, 0.42646661865634083`], 
             UndirectedEdge[182, 359] -> 
             RGBColor[
              0.612069752714546, 0.6442239826779863, 0.632542344561644], 
             UndirectedEdge[89, 391] -> 
             RGBColor[
              0.7044972001772316, 0.7661103241649193, 0.9454756942250822], 
             UndirectedEdge[62, 190] -> 
             RGBColor[
              0.7279989303359877, 0.6578087722601598, 0.6010501641388388], 
             UndirectedEdge[21, 87] -> 
             RGBColor[
              0.9786354129557872, 0.9813035812962297, 0.8035586833512967], 
             UndirectedEdge[185, 286] -> 
             RGBColor[
              0.9876114295846885, 0.9733653163075572, 0.5882101351516902], 
             UndirectedEdge[114, 294] -> 
             RGBColor[
              0.8428210992770853, 0.8774797575740481, 0.9547004456862318], 
             UndirectedEdge[48, 156] -> 
             RGBColor[
              0.8275945388352918, 0.8627217060032277, 0.8025508093807748], 
             UndirectedEdge[68, 450] -> 
             RGBColor[
              0.31475034183809547`, 0.44440994297559744`, 0.9413729879869674],
              UndirectedEdge[149, 406] -> 
             RGBColor[
              0.6164542539946491, 0.6901536181328505, 0.964191155464989], 
             UndirectedEdge[123, 158] -> 
             RGBColor[
              0.9636961961672447, 0.8817469364528039, 0.4182425126109846], 
             UndirectedEdge[55, 91] -> 
             RGBColor[
              0.3754426453888612, 0.4931875752752032, 0.945672340289011], 
             UndirectedEdge[135, 169] -> 
             RGBColor[
              0.9140269101049336, 0.7926024512273983, 0.6157267219964133], 
             UndirectedEdge[141, 456] -> 
             RGBColor[
              0.757156446866629, 0.4171902915068046, 0.44238590614051043`], 
             UndirectedEdge[287, 354] -> 
             RGBColor[
              0.8404563118851169, 0.8757781399689015, 0.9846029847262483], 
             UndirectedEdge[223, 411] -> 
             RGBColor[
              0.8515842733134722, 0.8839940924580256, 0.9391404774660961], 
             UndirectedEdge[127, 301] -> 
             RGBColor[
              0.5600378521340631, 0.6477359283320324, 0.9611302663344606], 
             UndirectedEdge[167, 201] -> 
             RGBColor[
              0.9486498589285366, 0.849371367598468, 0.5871993071511545], 
             UndirectedEdge[28, 218] -> 
             RGBColor[
              0.944315343563324, 0.9579910549215594, 0.9791437778496066], 
             UndirectedEdge[112, 317] -> 
             RGBColor[
              0.6182207451292722, 0.6898150702161645, 0.9517092850591311], 
             UndirectedEdge[275, 372] -> 
             RGBColor[
              0.8140823112896505, 0.8508985443901294, 0.7082910054219499], 
             UndirectedEdge[85, 146] -> 
             RGBColor[
              0.8031497200536829, 0.6827419632672893, 0.6005346988324494], 
             UndirectedEdge[7, 262] -> 
             RGBColor[
              0.5735782166149759, 0.658231882378888, 0.9625262864365831], 
             UndirectedEdge[448, 455] -> 
             RGBColor[
              0.5849489148854277, 0.6598439730510811, 0.9648377582128795], 
             UndirectedEdge[9, 368] -> 
             RGBColor[
              0.794290019373338, 0.8396358490426136, 0.9800219490776703], 
             UndirectedEdge[216, 399] -> 
             RGBColor[
              0.6901595389000679, 0.7485416772290769, 0.7019712610614323], 
             UndirectedEdge[205, 474] -> 
             RGBColor[
              0.6852827512551775, 0.744523196468734, 0.7192283841773659], 
             UndirectedEdge[125, 242] -> 
             RGBColor[
              0.5410786139767634, 0.6383110199969416, 0.9570148370099724], 
             UndirectedEdge[280, 338] -> 
             RGBColor[
              0.9476014625330875, 0.8298835465278567, 0.2771176254175787], 
             UndirectedEdge[232, 393] -> 
             RGBColor[
              0.8753326341536383, 0.4196497039580931, 0.3737627687619018], 
             UndirectedEdge[403, 483] -> 
             RGBColor[
              0.49357041449731, 0.5997417234395246, 0.9532748175186809], 
             UndirectedEdge[427, 433] -> 
             RGBColor[
              0.9619559515946586, 0.9579112027983663, 0.6931059132819131], 
             UndirectedEdge[269, 310] -> 
             RGBColor[
              0.8324345846834329, 0.8698726836891285, 0.9793269539581313], 
             UndirectedEdge[212, 357] -> 
             RGBColor[
              0.8309662946956589, 0.8675774754364685, 0.9230425646182343], 
             UndirectedEdge[88, 307] -> 
             RGBColor[
              0.7775040625766061, 0.826555475996161, 0.9747482395677493], 
             UndirectedEdge[212, 217] -> 
             RGBColor[
              0.5409980582520191, 0.6364582555347531, 0.9577104080855017], 
             UndirectedEdge[67, 124] -> 
             RGBColor[
              0.6955682761378212, 0.7609466881107319, 0.9711120100958051], 
             UndirectedEdge[364, 380] -> 
             RGBColor[
              0.7844275650446962, 0.8035658625705093, 0.6582667193606764], 
             UndirectedEdge[82, 384] -> 
             RGBColor[
              0.5744272687161691, 0.6534868959743716, 0.963526269603711], 
             UndirectedEdge[222, 439] -> 
             RGBColor[
              0.8244476202161758, 0.8614600197812073, 0.8759141935388141], 
             UndirectedEdge[337, 420] -> 
             RGBColor[
              0.8156146341188115, 0.853014152509851, 0.7798477744111179], 
             UndirectedEdge[61, 99] -> 
             RGBColor[
              0.8859028011142414, 0.9114446812532604, 0.9746194636701568], 
             UndirectedEdge[63, 439] -> 
             RGBColor[
              0.7008167154437076, 0.7662026115997171, 0.9708145187570184], 
             UndirectedEdge[37, 53] -> 
             RGBColor[
              0.6998929733685393, 0.7616382666853443, 0.9381170478611959], 
             UndirectedEdge[39, 62] -> 
             RGBColor[
              0.7708977692215109, 0.8162683143329381, 0.7400461136432022], 
             UndirectedEdge[130, 182] -> 
             RGBColor[
              0.8672847644997947, 0.38977633379079646`, 0.21852597341298213`],
              UndirectedEdge[152, 398] -> 
             RGBColor[
              0.8807528036135824, 0.9073764683176688, 0.9718536199703556], 
             UndirectedEdge[23, 110] -> 
             RGBColor[
              0.8374018262264082, 0.8737430272966226, 0.9793106179040696], 
             UndirectedEdge[322, 440] -> 
             RGBColor[
              0.8402738498027599, 0.8512403044628233, 0.6681670126199797], 
             UndirectedEdge[141, 432] -> 
             RGBColor[
              0.8302782870190946, 0.23373775882454273`, 0.17662782788490622`],
              UndirectedEdge[161, 459] -> 
             RGBColor[
              0.8366814674230405, 0.740721350127558, 0.6101389162470129], 
             UndirectedEdge[185, 333] -> 
             RGBColor[
              0.9552007935584437, 0.8529992519644114, 0.519783790021444], 
             UndirectedEdge[297, 474] -> 
             RGBColor[
              0.7887240268813938, 0.8305617630978785, 0.7268023990587642], 
             UndirectedEdge[265, 329] -> 
             RGBColor[
              0.8770758074225158, 0.9044269182183173, 0.9675867348404013], 
             UndirectedEdge[90, 280] -> 
             RGBColor[
              0.853789229984821, 0.8074477617263804, 0.6236606001527463], 
             UndirectedEdge[183, 430] -> 
             RGBColor[
              0.6289835211134238, 0.7019636991792586, 0.9590461130661734], 
             UndirectedEdge[86, 194] -> 
             RGBColor[
              0.8955331696959021, 0.9052123531157563, 0.6894504493781138], 
             UndirectedEdge[143, 186] -> 
             RGBColor[
              0.9655307568437015, 0.9713111641935497, 0.808365842973825], 
             UndirectedEdge[1, 416] -> 
             RGBColor[
              0.9722665808556692, 0.9779965435378601, 0.8941903888038425], 
             UndirectedEdge[27, 86] -> 
             RGBColor[
              0.6205128470383916, 0.6998083885376523, 0.9651140146832011], 
             UndirectedEdge[66, 415] -> 
             RGBColor[
              0.9623455449972722, 0.9246768297220849, 0.6212793491090663], 
             UndirectedEdge[413, 490] -> 
             RGBColor[
              0.25203503695113466`, 0.3822351821529084, 0.9376643945507186], 
             UndirectedEdge[226, 284] -> 
             RGBColor[
              0.8949987480001168, 0.9186974108265863, 0.9754824815699147], 
             UndirectedEdge[245, 438] -> 
             RGBColor[
              0.694484499592797, 0.757468410398342, 0.9452840527831216], 
             UndirectedEdge[53, 163] -> 
             RGBColor[
              0.35181420684738857`, 0.47634159497587836`, 0.9437409333443039],
              UndirectedEdge[367, 368] -> 
             RGBColor[
              0.8521581611492395, 0.8849518027560646, 0.9857608002126272], 
             UndirectedEdge[112, 175] -> 
             RGBColor[
              0.7000968975321604, 0.7630968742267972, 0.9568397743236803], 
             UndirectedEdge[277, 288] -> 
             RGBColor[
              0.5283870751411682, 0.6280074570228965, 0.9560157125821958], 
             UndirectedEdge[249, 323] -> 
             RGBColor[
              0.8074351077111978, 0.36743498880537406`, 0.4359689918888241], 
             UndirectedEdge[416, 452] -> 
             RGBColor[
              0.9904412263787991, 0.9903152157054258, 0.8080771464238513], 
             UndirectedEdge[13, 87] -> 
             RGBColor[
              0.876429020602383, 0.41973906973511976`, 0.32913252791663894`], 
             UndirectedEdge[471, 497] -> 
             RGBColor[
              0.9525281853496916, 0.9022123331520886, 0.6193869238489841], 
             UndirectedEdge[17, 321] -> 
             RGBColor[
              0.6812829364933013, 0.7488002186758782, 0.9706192899872], 
             UndirectedEdge[106, 227] -> 
             RGBColor[
              0.6942099701215159, 0.7596816671368085, 0.9711918685837776], 
             UndirectedEdge[37, 100] -> 
             RGBColor[
              0.9759979009073974, 0.9816198543133429, 0.9255134724004572], 
             UndirectedEdge[9, 375] -> 
             RGBColor[
              0.7849616185978674, 0.8321976354769469, 0.9791321978841441], 
             UndirectedEdge[10, 302] -> 
             RGBColor[
              0.6671865764760978, 0.7330350141751267, 0.9320251733622378], 
             UndirectedEdge[14, 272] -> 
             RGBColor[
              0.8359852327026656, 0.2619670263864267, 0.18148050694833087`], 
             UndirectedEdge[63, 387] -> 
             RGBColor[
              0.8068602657457562, 0.4622628683311291, 0.4477492451044536], 
             UndirectedEdge[471, 483] -> 
             RGBColor[
              0.7097945158164695, 0.7710738515012943, 0.9556863144767842], 
             UndirectedEdge[46, 392] -> 
             RGBColor[
              0.6787092264152474, 0.5919265614559079, 0.5917812466771191], 
             UndirectedEdge[122, 357] -> 
             RGBColor[
              0.6444867789872217, 0.7120516058580169, 0.9091630816712541], 
             UndirectedEdge[75, 125] -> 
             RGBColor[
              0.7771835813794232, 0.8225320576933859, 0.8356666375213212], 
             UndirectedEdge[244, 261] -> 
             RGBColor[
              0.6746063106390111, 0.7434974921192461, 0.969958258087523], 
             UndirectedEdge[7, 178] -> 
             RGBColor[
              0.6344963570876647, 0.6467332955173413, 0.610478607917077], 
             UndirectedEdge[108, 487] -> 
             RGBColor[
              0.6568610440276649, 0.72159358440092, 0.8462903347955133], 
             UndirectedEdge[338, 480] -> 
             RGBColor[
              0.8636246816254727, 0.37743001482738125`, 0.20430724259489524`],
              UndirectedEdge[237, 284] -> 
             RGBColor[
              0.9728699631488453, 0.9765337410041128, 0.7760274001096451], 
             UndirectedEdge[162, 456] -> 
             RGBColor[
              0.5398937209441421, 0.6373490704542368, 0.9569215578900383], 
             UndirectedEdge[104, 310] -> 
             RGBColor[
              0.9123055203488966, 0.760784630279653, 0.6052292266722191], 
             UndirectedEdge[168, 390] -> 
             RGBColor[
              0.4130706564288171, 0.5258348892623292, 0.9484434729587143], 
             UndirectedEdge[164, 431] -> 
             RGBColor[
              0.6256228377241784, 0.6883441975482871, 0.7332157496023508], 
             UndirectedEdge[57, 60] -> 
             RGBColor[
              0.23104785069846168`, 0.36017631873688516`, 0.9364692053413886],
              UndirectedEdge[158, 247] -> 
             RGBColor[
              0.6162604030804055, 0.6029121847993884, 0.6028643758730139], 
             UndirectedEdge[32, 475] -> 
             RGBColor[
              0.5332091693504963, 0.6319222503348976, 0.9563953255022672], 
             UndirectedEdge[53, 293] -> 
             RGBColor[
              0.6815393086641066, 0.7479501336001462, 0.9691850148033949], 
             UndirectedEdge[72, 294] -> 
             RGBColor[
              0.6243846011298375, 0.6938633807356738, 0.9381305971042939], 
             UndirectedEdge[87, 287] -> 
             RGBColor[
              0.8975997541796381, 0.9175392847757022, 0.8198583143795577], 
             UndirectedEdge[154, 374] -> 
             RGBColor[
              0.8764754921988475, 0.4201223051298991, 0.3548226533309724], 
             UndirectedEdge[119, 364] -> 
             RGBColor[
              0.7662172917134076, 0.8174527997709826, 0.9754805949544165], 
             UndirectedEdge[90, 342] -> 
             RGBColor[
              0.5258901405884041, 0.617061556176481, 0.9585045439688991], 
             UndirectedEdge[401, 428] -> 
             RGBColor[
              0.8444438885883765, 0.3967706503213843, 0.439545132728542], 
             UndirectedEdge[183, 477] -> 
             RGBColor[
              0.28331287428018787`, 0.4147754713405304, 0.9394578761574492], 
             UndirectedEdge[82, 269] -> 
             RGBColor[
              0.4964000076952176, 0.5920433923067414, 0.9558787454291824], 
             UndirectedEdge[202, 273] -> 
             RGBColor[
              0.8724247900963542, 0.9006707710088079, 0.9609102317093692], 
             UndirectedEdge[147, 242] -> 
             RGBColor[
              0.3725342155416136, 0.4871940062615514, 0.9457740193699292], 
             UndirectedEdge[117, 198] -> 
             RGBColor[
              0.714497582228059, 0.7738368812940413, 0.9324631714336235], 
             UndirectedEdge[240, 434] -> 
             RGBColor[
              0.8647557746132781, 0.8949045262489868, 0.9715276462447537], 
             UndirectedEdge[249, 310] -> 
             RGBColor[
              0.8641144186621277, 0.8946212107689409, 0.9824845037442471], 
             UndirectedEdge[448, 478] -> 
             RGBColor[
              0.8762468751806125, 0.904159489453958, 0.9880584032611884], 
             UndirectedEdge[121, 196] -> 
             RGBColor[
              0.5982634885755381, 0.5450273308680118, 0.5918394512909799], 
             UndirectedEdge[200, 256] -> 
             RGBColor[
              0.9558990386009492, 0.963723829286159, 0.8137349815198158], 
             UndirectedEdge[79, 184] -> 
             RGBColor[
              0.8526401515894455, 0.33794607611640126`, 0.1953534053758324], 
             UndirectedEdge[51, 240] -> 
             RGBColor[
              0.5365186627526481, 0.6271478127774129, 0.9592815930680691], 
             UndirectedEdge[339, 387] -> 
             RGBColor[
              0.8242178970769094, 0.18715494604910077`, 0.1708243916320382], 
             UndirectedEdge[46, 142] -> 
             RGBColor[
              0.8426137997756449, 0.29206580132365323`, 0.18701154579507184`],
              UndirectedEdge[233, 259] -> 
             RGBColor[
              0.9753437656254911, 0.9472049906458258, 0.6265211371048148], 
             UndirectedEdge[266, 471] -> 
             RGBColor[
              0.6177368111170849, 0.6889843691293607, 0.949835798706089], 
             UndirectedEdge[167, 456] -> 
             RGBColor[
              0.7582961122228737, 0.6998106820792278, 0.6074426315015067], 
             UndirectedEdge[10, 181] -> 
             RGBColor[
              0.6299029617791341, 0.7044263028493603, 0.9673081407988283], 
             UndirectedEdge[31, 429] -> 
             RGBColor[
              0.6747055737392275, 0.7450257114251015, 0.9687443904547759], 
             UndirectedEdge[317, 322] -> 
             RGBColor[
              0.6300972346334175, 0.6745616496360309, 0.6523436432437124], 
             UndirectedEdge[52, 466] -> 
             RGBColor[
              0.7861999921267331, 0.6367147785745768, 0.5924377514111365], 
             UndirectedEdge[207, 281] -> 
             RGBColor[
              0.5443284039891032, 0.6409493459303306, 0.9572706723841169], 
             UndirectedEdge[358, 398] -> 
             RGBColor[
              0.8403294478734954, 0.8756229811249145, 0.9846052145086198], 
             UndirectedEdge[155, 250] -> 
             RGBColor[
              0.5497769338269086, 0.6397443160302954, 0.9600972710680793], 
             UndirectedEdge[243, 285] -> 
             RGBColor[
              0.9263242265728945, 0.7291965553351547, 0.29666454881973414`], 
             UndirectedEdge[378, 452] -> 
             RGBColor[
              0.9678493439783553, 0.9743067251923669, 0.8839585455812476], 
             UndirectedEdge[100, 264] -> 
             RGBColor[
              0.6233289692988726, 0.691498628063771, 0.9308759547723799], 
             UndirectedEdge[81, 130] -> 
             RGBColor[
              0.7696385939775261, 0.33790806501248594`, 0.43220178862835446`],
              UndirectedEdge[1, 120] -> 
             RGBColor[
              0.8332579695636837, 0.8702552963276371, 0.9662163839641325], 
             UndirectedEdge[390, 422] -> 
             RGBColor[
              0.6907918939754827, 0.7570941350275289, 0.9707070726280707], 
             UndirectedEdge[118, 255] -> 
             RGBColor[
              0.721518731187273, 0.7813269098658386, 0.9739462556088725], 
             UndirectedEdge[137, 229] -> 
             RGBColor[
              0.875983809308845, 0.41991898161920915`, 0.3629711112528449], 
             UndirectedEdge[367, 375] -> 
             RGBColor[
              0.8428297603737689, 0.877513589190398, 0.984871049019101], 
             UndirectedEdge[230, 382] -> 
             RGBColor[
              0.9170240570549784, 0.9357576570277039, 0.9601738570907785], 
             UndirectedEdge[114, 334] -> 
             RGBColor[
              0.7776581410687471, 0.8263843608361698, 0.97843284704207], 
             UndirectedEdge[52, 170] -> 
             RGBColor[
              0.8265059247405572, 0.8650471832850786, 0.9689164909935963], 
             UndirectedEdge[4, 389] -> 
             RGBColor[
              0.9426100905124889, 0.7941235128529665, 0.4156098914848544], 
             UndirectedEdge[190, 378] -> 
             RGBColor[
              0.9258324897270183, 0.8145843046416779, 0.6120363598817626], 
             UndirectedEdge[89, 328] -> 
             RGBColor[
              0.978103555019493, 0.9756972744539723, 0.67796399214244], 
             UndirectedEdge[93, 300] -> 
             RGBColor[
              0.6892875520421153, 0.7536547778413759, 0.9549895212515527], 
             UndirectedEdge[104, 125] -> 
             RGBColor[
              0.7216360803890036, 0.6097094792440243, 0.5917018111368387], 
             UndirectedEdge[59, 228] -> 
             RGBColor[
              0.9640603676861061, 0.8828194214775453, 0.44050908100370095`], 
             UndirectedEdge[96, 136] -> 
             RGBColor[
              0.927590587339719, 0.9402958614529204, 0.7416790345724946], 
             UndirectedEdge[332, 420] -> 
             RGBColor[
              0.7907404836431193, 0.8328201965859751, 0.7778895901686559], 
             UndirectedEdge[40, 283] -> 
             RGBColor[
              0.6530788022347551, 0.7221522182962608, 0.9506338538850039], 
             UndirectedEdge[17, 288] -> 
             RGBColor[
              0.5284122873300849, 0.6280279254136553, 0.9560176973780625], 
             UndirectedEdge[325, 413] -> 
             RGBColor[
              0.6199677204162971, 0.685611794918216, 0.8903237111286082], 
             UndirectedEdge[421, 459] -> 
             RGBColor[
              0.8652820636809759, 0.7631058785707757, 0.6129785368633184], 
             UndirectedEdge[148, 342] -> 
             RGBColor[
              0.3842198948159572, 0.5039812969865785, 0.9460294374183273], 
             UndirectedEdge[262, 478] -> 
             RGBColor[
              0.8321424776288366, 0.8689918400281511, 0.9838516864502396], 
             UndirectedEdge[133, 405] -> 
             RGBColor[
              0.9069356974889017, 0.8779853235822925, 0.6373082995891703], 
             UndirectedEdge[374, 397] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[151, 389] -> 
             RGBColor[
              0.9726733131989159, 0.97648208769414, 0.7838987477354857], 
             UndirectedEdge[235, 305] -> 
             RGBColor[
              0.8645831204289303, 0.837442384899987, 0.6295112535426217], 
             UndirectedEdge[204, 348] -> 
             RGBColor[
              0.8159766645689068, 0.855604160842784, 0.9096093252622436], 
             UndirectedEdge[191, 429] -> 
             RGBColor[
              0.596961815040959, 0.6814406798962531, 0.9627537433955928], 
             UndirectedEdge[15, 414] -> 
             RGBColor[
              0.860273122666646, 0.42056690128327934`, 0.43914289736759726`], 
             UndirectedEdge[277, 414] -> 
             RGBColor[
              0.6994764080365039, 0.7631630839969072, 0.9673711111115101], 
             UndirectedEdge[317, 440] -> 
             RGBColor[
              0.4933453165662657, 0.5916372923005627, 0.9552607800590444], 
             UndirectedEdge[76, 182] -> 
             RGBColor[
              0.9317211696447383, 0.7613717684877654, 0.2811313639624327], 
             UndirectedEdge[199, 376] -> 
             RGBColor[
              0.6858832136756181, 0.7458075248699931, 0.7845850130178226], 
             UndirectedEdge[375, 402] -> 
             RGBColor[
              0.6433699801719535, 0.7178918015961138, 0.9673371276883451], 
             UndirectedEdge[45, 195] -> 
             RGBColor[
              0.5745022062631837, 0.6631529720985891, 0.9608292674540885], 
             UndirectedEdge[149, 269] -> 
             RGBColor[
              0.8315989560491641, 0.8692494732219072, 0.9807414552690956], 
             UndirectedEdge[45, 152] -> 
             RGBColor[
              0.8423557994508031, 0.8773804368376656, 0.9680265654358144], 
             UndirectedEdge[356, 494] -> 
             RGBColor[
              0.34094798118733605`, 0.46946973963802935`, 0.9429555480242583],
              UndirectedEdge[44, 360] -> 
             RGBColor[
              0.9449262586765936, 0.9584466744127542, 0.9781096579150212], 
             UndirectedEdge[284, 432] -> 
             RGBColor[
              0.8621345285818178, 0.4106004777807799, 0.43165615372320887`], 
             UndirectedEdge[151, 237] -> 
             RGBColor[
              0.972605114315052, 0.97633621717752, 0.7764757201016182], 
             UndirectedEdge[207, 343] -> 
             RGBColor[
              0.6221696868032363, 0.7023906206529249, 0.9645976959489578], 
             UndirectedEdge[33, 371] -> 
             RGBColor[
              0.6514197303028223, 0.7161024328096426, 0.7990933716611209], 
             UndirectedEdge[280, 480] -> 
             RGBColor[
              0.8578682933965857, 0.35466168285785654`, 0.19939517435015724`],
              UndirectedEdge[420, 454] -> 
             RGBColor[
              0.6389058967198539, 0.7026387364122051, 0.7672933872682999], 
             UndirectedEdge[267, 393] -> 
             RGBColor[
              0.8212863018303977, 0.37830541923651906`, 0.43733634143054434`],
              UndirectedEdge[337, 427] -> 
             RGBColor[
              0.8112351762430023, 0.8392036768221842, 0.6809934100187485], 
             UndirectedEdge[267, 480] -> 
             RGBColor[
              0.8212863018303977, 0.37830541923651906`, 0.43733634143054434`],
              UndirectedEdge[234, 336] -> 
             RGBColor[
              0.8242799068064497, 0.8635792019505711, 0.9824126381599765], 
             UndirectedEdge[122, 492] -> 
             RGBColor[
              0.6457919670114979, 0.23459370235059224`, 0.42299594921736683`],
              UndirectedEdge[80, 272] -> 
             RGBColor[
              0.8619286103467011, 0.3707594865446488, 0.20266220067610835`], 
             UndirectedEdge[331, 444] -> 
             RGBColor[
              0.7019210013784476, 0.7618191239387683, 0.8931527371511896], 
             UndirectedEdge[77, 184] -> 
             RGBColor[
              0.8122319059729992, 0.37862642645840466`, 0.437371978708582], 
             UndirectedEdge[266, 359] -> 
             RGBColor[
              0.268507018921454, 0.3995482795876918, 0.9386024495558147], 
             UndirectedEdge[32, 478] -> 
             RGBColor[
              0.6518595869498323, 0.7254178953238162, 0.9677218716011737], 
             UndirectedEdge[14, 447] -> 
             RGBColor[
              0.564772793175418, 0.4521446069309481, 0.576954346037003], 
             UndirectedEdge[16, 358] -> 
             RGBColor[
              0.5785883239136502, 0.6587400802398571, 0.9636299744042061], 
             UndirectedEdge[50, 323] -> 
             RGBColor[
              0.6389031352827396, 0.2273531034265086, 0.4226036404415273], 
             UndirectedEdge[92, 365] -> 
             RGBColor[
              0.8420859825922514, 0.8774023020087597, 0.9846722569578293], 
             UndirectedEdge[296, 438] -> 
             RGBColor[
              0.49881658167260673`, 0.6031761118756838, 0.953915678329375], 
             UndirectedEdge[181, 422] -> 
             RGBColor[
              0.8650342734494583, 0.8952188651915016, 0.9869889352984632], 
             UndirectedEdge[35, 428] -> 
             RGBColor[
              0.9004905177407423, 0.7856247714291418, 0.6151889615661319], 
             UndirectedEdge[19, 298] -> 
             RGBColor[
              0.45838125917669936`, 0.5671834582126329, 0.9515951023160616], 
             UndirectedEdge[209, 348] -> 
             RGBColor[
              0.7596411490521704, 0.3300979850534023, 0.4312053367496296], 
             UndirectedEdge[27, 194] -> 
             RGBColor[
              0.7103410428640462, 0.7568786253905891, 0.6732956639408428], 
             UndirectedEdge[253, 287] -> 
             RGBColor[
              0.8562047957889241, 0.7661866360557323, 0.6143465240231811], 
             UndirectedEdge[412, 476] -> 
             RGBColor[
              0.7714492014786407, 0.8178262475851642, 0.8310858917854931], 
             UndirectedEdge[221, 336] -> 
             RGBColor[
              0.7693581951749188, 0.8197993369565901, 0.977632399725544], 
             UndirectedEdge[146, 248] -> 
             RGBColor[
              0.640746806311127, 0.5504201272399387, 0.5874094561645493], 
             UndirectedEdge[17, 455] -> 
             RGBColor[
              0.35509895115118084`, 0.4766675328564981, 0.9440711847267922], 
             UndirectedEdge[102, 393] -> 
             RGBColor[
              0.864969572990283, 0.412714849258654, 0.42685716303768173`], 
             UndirectedEdge[80, 497] -> 
             RGBColor[
              0.9504107027092585, 0.8411019914356014, 0.2789574912707015], 
             UndirectedEdge[108, 416] -> 
             RGBColor[
              0.9915687940698914, 0.9907814939228605, 0.7893904317308076], 
             UndirectedEdge[8, 453] -> 
             RGBColor[
              0.7515384254179711, 0.48190172610262, 0.45079971524099205`], 
             UndirectedEdge[58, 402] -> 
             RGBColor[
              0.6806914290814626, 0.6492301996028877, 0.6044517011238189], 
             UndirectedEdge[95, 357] -> 
             RGBColor[
              0.9894878276883088, 0.9877280101780359, 0.6644730664684374], 
             UndirectedEdge[183, 283] -> 
             RGBColor[
              0.6346469572081237, 0.70618748054566, 0.9494593930185475], 
             UndirectedEdge[179, 294] -> 
             RGBColor[
              0.603296571508515, 0.671698524545361, 0.9369296650143037], 
             UndirectedEdge[136, 240] -> 
             RGBColor[
              0.8193380779836215, 0.8591321887298273, 0.9825374512639196], 
             UndirectedEdge[153, 289] -> 
             RGBColor[
              0.6387500445626224, 0.709132358711291, 0.9408326935179885], 
             UndirectedEdge[73, 200] -> 
             RGBColor[
              0.9486697873744458, 0.9405292573944061, 0.68434349934504], 
             UndirectedEdge[196, 447] -> 
             RGBColor[
              0.5815144199973391, 0.5274229978400413, 0.590885616613478], 
             UndirectedEdge[68, 492] -> 
             RGBColor[
              0.6383029717692752, 0.22672229352129283`, 0.42256946201729784`],
              UndirectedEdge[25, 413] -> 
             RGBColor[
              0.36087619489253603`, 0.48125415597833, 0.9445354211617623], 
             UndirectedEdge[220, 426] -> 
             RGBColor[
              0.6675143175567845, 0.2537788371292143, 0.4243665187173157], 
             UndirectedEdge[21, 354] -> 
             RGBColor[
              0.9214919706612659, 0.9395424364894289, 0.9683033536979873], 
             UndirectedEdge[125, 269] -> 
             RGBColor[
              0.64176514472354, 0.7187975326534997, 0.9657995384227509], 
             UndirectedEdge[241, 304] -> 
             RGBColor[
              0.644536063428389, 0.23327366805585842`, 0.4229244273662516], 
             UndirectedEdge[93, 456] -> 
             RGBColor[
              0.776274403048089, 0.8250712237252735, 0.9616173414314466], 
             UndirectedEdge[295, 455] -> 
             RGBColor[
              0.2902356185871522, 0.42060596429931796`, 0.9399050522027408], 
             UndirectedEdge[185, 386] -> 
             RGBColor[
              0.9417151792273102, 0.9536586139352077, 0.8878518947891861], 
             UndirectedEdge[233, 400] -> 
             RGBColor[
              0.9731854913497877, 0.9795223638701755, 0.9302741481876007], 
             UndirectedEdge[83, 317] -> 
             RGBColor[
              0.4183128183750553, 0.531659468200558, 0.9487133572473935], 
             UndirectedEdge[88, 465] -> 
             RGBColor[
              0.964878871589802, 0.9723826416905021, 0.9020313392465509], 
             UndirectedEdge[418, 431] -> 
             RGBColor[
              0.8760292963773457, 0.4188841000360836, 0.2856250128333002], 
             UndirectedEdge[121, 307] -> 
             RGBColor[
              0.4524272264998259, 0.5601393976806334, 0.9513275750879243], 
             UndirectedEdge[64, 74] -> 
             RGBColor[
              0.7814094901006038, 0.7680876445477844, 0.6206618628414913], 
             UndirectedEdge[185, 358] -> 
             RGBColor[
              0.9325950907129621, 0.9463865029120744, 0.8869820126050885], 
             UndirectedEdge[113, 315] -> 
             RGBColor[
              0.9293315802788258, 0.946007692320687, 0.9764763003058561], 
             UndirectedEdge[47, 91] -> 
             RGBColor[
              0.6237630229771394, 0.6872453364687897, 0.8187046715204619], 
             UndirectedEdge[158, 401] -> 
             RGBColor[
              0.8560628719585481, 0.34750378847706714`, 0.19794248988242436`],
              UndirectedEdge[90, 232] -> 
             RGBColor[
              0.8799857411203998, 0.9049297933767353, 0.8852119917703631], 
             UndirectedEdge[58, 115] -> 
             RGBColor[
              0.7277848095961736, 0.6879725820494615, 0.6080181901982333], 
             UndirectedEdge[132, 494] -> 
             RGBColor[
              0.679286137470989, 0.32584657409139733`, 0.4332256338578002], 
             UndirectedEdge[167, 300] -> 
             RGBColor[0.6713092612169, 0.6283942361953303, 0.600814811321613],
              UndirectedEdge[284, 389] -> 
             RGBColor[
              0.9729381620327092, 0.9766796115207329, 0.7834504277435126], 
             UndirectedEdge[103, 233] -> 
             RGBColor[
              0.9156243034264892, 0.9343863440072387, 0.9511928374767304], 
             UndirectedEdge[172, 300] -> 
             RGBColor[
              0.7049315890026135, 0.752847621361919, 0.6739483501286067], 
             UndirectedEdge[70, 76] -> 
             RGBColor[
              0.7696693375503181, 0.6713961382741664, 0.6000919612062638], 
             UndirectedEdge[57, 73] -> 
             RGBColor[
              0.5794509560387187, 0.6247534088511328, 0.6551038720758664], 
             UndirectedEdge[287, 473] -> 
             RGBColor[
              0.8117294821840424, 0.3707897867820151, 0.43639701500306616`], 
             UndirectedEdge[395, 443] -> 
             RGBColor[
              0.6084306155852217, 0.6866041760291192, 0.9655826419104071], 
             UndirectedEdge[100, 397] -> 
             RGBColor[
              0.8706856941139511, 0.4169779230333964, 0.4171812609784685], 
             UndirectedEdge[57, 234] -> 
             RGBColor[
              0.5575692710763926, 0.6286706265491684, 0.9631811999138686], 
             UndirectedEdge[343, 403] -> 
             RGBColor[
              0.6398899884662379, 0.7167767598334422, 0.9659927030074731], 
             UndirectedEdge[105, 425] -> 
             RGBColor[
              0.6195669094896554, 0.6969360089431234, 0.9659763711459151], 
             UndirectedEdge[133, 423] -> 
             RGBColor[
              0.9394736427881468, 0.9039301979449139, 0.6404117978587789], 
             UndirectedEdge[92, 494] -> 
             RGBColor[
              0.5681911731912834, 0.6564151110938141, 0.9609653190402889], 
             UndirectedEdge[51, 100] -> 
             RGBColor[
              0.6369017701663386, 0.7057645023407568, 0.9316489057026227], 
             UndirectedEdge[6, 347] -> 
             RGBColor[
              0.561609935400565, 0.4676123139793178, 0.5809609386885226], 
             UndirectedEdge[333, 461] -> 
             RGBColor[
              0.9134704577891973, 0.8224281390376178, 0.622254447098884], 
             UndirectedEdge[291, 394] -> 
             RGBColor[
              0.7923616391629353, 0.6365843289963622, 0.5920856551504262], 
             UndirectedEdge[143, 386] -> 
             RGBColor[
              0.9141971773339573, 0.934393525134608, 0.9907591877089532], 
             UndirectedEdge[123, 437] -> 
             RGBColor[
              0.7211020043190541, 0.7760035352361085, 0.7604418892156861], 
             UndirectedEdge[72, 453] -> 
             RGBColor[
              0.6611065026354093, 0.40354187106893136`, 0.4446154043502142], 
             UndirectedEdge[391, 478] -> 
             RGBColor[
              0.6387633173274012, 0.7144910036930188, 0.9667723255784983], 
             UndirectedEdge[328, 464] -> 
             RGBColor[
              0.7406607423478426, 0.787507018512204, 0.6837571169550614], 
             UndirectedEdge[149, 173] -> 
             RGBColor[
              0.5975590725824819, 0.6702935844449665, 0.9631151028364819], 
             UndirectedEdge[54, 186] -> 
             RGBColor[
              0.9935616546349683, 0.9886373552177947, 0.5406040237572124], 
             UndirectedEdge[355, 444] -> 
             RGBColor[
              0.3492063922932169, 0.4745219621916126, 0.9435586871855277], 
             UndirectedEdge[7, 448] -> 
             RGBColor[
              0.6176826141667517, 0.693399531804695, 0.9667330032475321], 
             UndirectedEdge[47, 416] -> 
             RGBColor[
              0.9921373008863925, 0.9907935931496216, 0.7637595689688017], 
             UndirectedEdge[48, 155] -> 
             RGBColor[
              0.7190452505262104, 0.7804428817481661, 0.9726313687786968], 
             UndirectedEdge[346, 486] -> 
             RGBColor[
              0.843758856041227, 0.8782544248559991, 0.9849596669932768], 
             UndirectedEdge[24, 491] -> 
             RGBColor[
              0.9913400210604957, 0.989674766846055, 0.7196110943787705], 
             UndirectedEdge[321, 373] -> 
             RGBColor[
              0.8807626667996191, 0.9077602591130558, 0.988489123497104], 
             UndirectedEdge[209, 231] -> 
             RGBColor[
              0.7789545463417207, 0.34518575780325506`, 0.4331303156974927], 
             UndirectedEdge[210, 393] -> 
             RGBColor[
              0.6392689004656411, 0.22773754582459013`, 0.4226244702275924], 
             UndirectedEdge[188, 409] -> 
             RGBColor[
              0.8649574402398503, 0.4341200238939038, 0.20721002251597043`], 
             UndirectedEdge[307, 427] -> 
             RGBColor[
              0.8002159983366922, 0.8302578117895338, 0.6801259399693851], 
             UndirectedEdge[178, 186] -> 
             RGBColor[
              0.9726959308484684, 0.9169779260788047, 0.4521101077770246], 
             UndirectedEdge[328, 475] -> 
             RGBColor[
              0.7937192545703269, 0.8305823089931532, 0.6879340773969497], 
             UndirectedEdge[213, 337] -> 
             RGBColor[
              0.7278721323188402, 0.7872589707553823, 0.973565530521848], 
             UndirectedEdge[384, 458] -> 
             RGBColor[
              0.6348482634495678, 0.7095422487986185, 0.9672399714117468], 
             UndirectedEdge[87, 473] -> 
             RGBColor[
              0.876429020602383, 0.4197390697351199, 0.32913252791663894`], 
             UndirectedEdge[112, 440] -> 
             RGBColor[
              0.8283973602986145, 0.8664937250429569, 0.9675326544353983], 
             UndirectedEdge[237, 429] -> 
             RGBColor[
              0.8759291269707181, 0.9001519945136947, 0.7810123913873015], 
             UndirectedEdge[109, 230] -> 
             RGBColor[
              0.9686776028662558, 0.9377188550047311, 0.6282217352478134], 
             UndirectedEdge[89, 262] -> 
             RGBColor[
              0.897876360478667, 0.9206111605000517, 0.9625550550968234], 
             UndirectedEdge[280, 383] -> 
             RGBColor[
              0.8474295403470494, 0.8024795238459219, 0.6230267257243318], 
             UndirectedEdge[196, 489] -> 
             RGBColor[
              0.9363108885885725, 0.8211168345298486, 0.5933043342915942], 
             UndirectedEdge[279, 459] -> 
             RGBColor[
              0.678740936973163, 0.6143868343724938, 0.5963997851607041], 
             UndirectedEdge[191, 423] -> 
             RGBColor[
              0.6788677965736698, 0.7462483544102901, 0.9706992063208759], 
             UndirectedEdge[116, 165] -> 
             RGBColor[
              0.2927946020720844, 0.4250760694007177, 0.9399855914859837], 
             UndirectedEdge[176, 313] -> 
             RGBColor[
              0.9299376988254588, 0.8297549822581264, 0.6144821078422869], 
             UndirectedEdge[180, 490] -> 
             RGBColor[
              0.42407237772017137`, 0.5326632677626619, 0.9495010255242897], 
             UndirectedEdge[17, 498] -> 
             RGBColor[
              0.6933323785778013, 0.6633012997003953, 0.6060654674311489], 
             UndirectedEdge[108, 364] -> 
             RGBColor[
              0.7941356944146573, 0.8366636901676925, 0.8560956765419692], 
             UndirectedEdge[29, 254] -> 
             RGBColor[
              0.845795623257289, 0.747298662314899, 0.6109271454490187], 
             UndirectedEdge[7, 261] -> 
             RGBColor[
              0.3892860352988107, 0.511403014918821, 0.9460808455420444], 
             UndirectedEdge[122, 224] -> 
             RGBColor[
              0.3407141780067663, 0.46897573922204744`, 0.9429513232369557], 
             UndirectedEdge[116, 386] -> 
             RGBColor[
              0.5941127359748368, 0.6727435413682833, 0.9648645733399485], 
             UndirectedEdge[8, 439] -> 
             RGBColor[
              0.6039768435550694, 0.6891490678349803, 0.9621206384387276], 
             UndirectedEdge[226, 488] -> 
             RGBColor[
              0.5533621352345058, 0.6366901303339092, 0.9615170583671633], 
             UndirectedEdge[64, 170] -> 
             RGBColor[
              0.9507827164345911, 0.9015117393807053, 0.6228079690150481], 
             UndirectedEdge[178, 313] -> 
             RGBColor[
              0.9330893081983925, 0.7724284342125691, 0.2650202906618734], 
             UndirectedEdge[81, 251] -> 
             RGBColor[
              0.8347143751101491, 0.8687534657271143, 0.8408801863186743], 
             UndirectedEdge[186, 288] -> 
             RGBColor[
              0.7967147383971422, 0.8378509714132256, 0.793162316058099], 
             UndirectedEdge[45, 118] -> 
             RGBColor[
              0.6247466465143312, 0.7048872469894403, 0.9645239813110726], 
             UndirectedEdge[224, 330] -> 
             RGBColor[
              0.670275227579151, 0.7367501012456532, 0.947398024699968], 
             UndirectedEdge[35, 410] -> 
             RGBColor[
              0.8237002363753895, 0.724999439072365, 0.6077040468227106], 
             UndirectedEdge[163, 379] -> 
             RGBColor[
              0.41039814621949683`, 0.5246658952160754, 0.9481419959454787], 
             UndirectedEdge[181, 443] -> 
             RGBColor[
              0.8932881509321875, 0.9177477401651564, 0.9896838153553], 
             UndirectedEdge[167, 235] -> 
             RGBColor[
              0.8476458062088084, 0.7702915780425857, 0.6158830929512495], 
             UndirectedEdge[202, 279] -> 
             RGBColor[
              0.615665127099602, 0.6967313706341313, 0.9643303091684752], 
             UndirectedEdge[242, 310] -> 
             RGBColor[
              0.7317480539366563, 0.7893861710325705, 0.9705422525453528], 
             UndirectedEdge[299, 482] -> 
             RGBColor[
              0.9266968897720093, 0.8685475919967991, 0.6314817630082266], 
             UndirectedEdge[56, 110] -> 
             RGBColor[
              0.7488089993684848, 0.8032181701680204, 0.9713799051545292], 
             UndirectedEdge[125, 419] -> 
             RGBColor[
              0.7734911196832797, 0.8211237247204178, 0.9054808758248822], 
             UndirectedEdge[262, 448] -> 
             RGBColor[
              0.8733253030429691, 0.9018299071353642, 0.9877797411025817], 
             UndirectedEdge[95, 212] -> 
             RGBColor[
              0.8342184654440179, 0.8667293809502472, 0.7097413153962637], 
             UndirectedEdge[32, 260] -> 
             RGBColor[
              0.494685443032888, 0.6006469538361698, 0.9533625966494859], 
             UndirectedEdge[421, 430] -> 
             RGBColor[
              0.8853612798376083, 0.9111717239389359, 0.9800747932067619], 
             UndirectedEdge[129, 346] -> 
             RGBColor[
              0.5296079654008821, 0.6108170542179256, 0.9603015368356941], 
             UndirectedEdge[16, 17] -> 
             RGBColor[
              0.3707395408706854, 0.49310678432236177`, 0.9449618931731391], 
             UndirectedEdge[153, 466] -> 
             RGBColor[
              0.5906790923278273, 0.47500881508152165`, 0.5774981067123632], 
             UndirectedEdge[244, 391] -> 
             RGBColor[
              0.6655193316537409, 0.7358255232441808, 0.9693243381103207], 
             UndirectedEdge[218, 406] -> 
             RGBColor[
              0.6153725447471057, 0.6893468811471688, 0.9660222070661244], 
             UndirectedEdge[99, 288] -> 
             RGBColor[
              0.7095699600867768, 0.7723784544997645, 0.9721399566825895], 
             UndirectedEdge[399, 481] -> 
             RGBColor[
              0.776556732005677, 0.820469487256815, 0.7082791005414385], 
             UndirectedEdge[278, 451] -> 
             RGBColor[
              0.5845752791493731, 0.5385453356897165, 0.5930885176825675], 
             UndirectedEdge[179, 327] -> 
             RGBColor[
              0.4105381379501194, 0.5198730177276047, 0.9485996394020038], 
             UndirectedEdge[38, 473] -> 
             RGBColor[
              0.8748039249873754, 0.41943106913063755`, 0.3825248479023401], 
             UndirectedEdge[17, 176] -> 
             RGBColor[
              0.7012418704084774, 0.7644814281247916, 0.9644273062774016], 
             UndirectedEdge[186, 373] -> 
             RGBColor[
              0.9255119544996262, 0.9394277626087532, 0.8054677631312963], 
             UndirectedEdge[399, 496] -> 
             RGBColor[
              0.6541852682746797, 0.7173825721327809, 0.699679012347981], 
             UndirectedEdge[116, 358] -> 
             RGBColor[
              0.5849926474604887, 0.6654714303451499, 0.9639946911558508], 
             UndirectedEdge[71, 135] -> 
             RGBColor[
              0.7595527174654046, 0.8121769464375507, 0.976972274426732], 
             UndirectedEdge[53, 374] -> 
             RGBColor[
              0.6866157424213791, 0.2703235312813974, 0.4255836446189609], 
             UndirectedEdge[228, 409] -> 
             RGBColor[
              0.8699678571639256, 0.4539846573753987, 0.21124152158268228`], 
             UndirectedEdge[440, 471] -> 
             RGBColor[
              0.8294523640282889, 0.8672805450971379, 0.9657468083101008], 
             UndirectedEdge[403, 471] -> 
             RGBColor[
              0.7391586950018102, 0.7949130150051511, 0.9579979702267869], 
             UndirectedEdge[63, 166] -> 
             RGBColor[
              0.5039459358726572, 0.5972434631114162, 0.9567408604570337], 
             UndirectedEdge[159, 272] -> 
             RGBColor[
              0.6569257124602959, 0.24460751959340238`, 0.42369182216370327`],
              UndirectedEdge[130, 351] -> 
             RGBColor[
              0.6211738280418199, 0.20871847741329774`, 0.4215939826223165], 
             UndirectedEdge[113, 378] -> 
             RGBColor[
              0.9242068763208038, 0.9421856964997268, 0.9851510873699312], 
             UndirectedEdge[145, 417] -> 
             RGBColor[
              0.8674163701742418, 0.3902202706331881, 0.21903723660656255`], 
             UndirectedEdge[38, 354] -> 
             RGBColor[
              0.9350679760901164, 0.9487400634918353, 0.9037947340751591], 
             UndirectedEdge[334, 446] -> 
             RGBColor[
              0.6265995747885393, 0.7038245217877874, 0.9660575044690184], 
             UndirectedEdge[305, 310] -> 
             RGBColor[
              0.9465374437670251, 0.9023149174741161, 0.6330736906204837], 
             UndirectedEdge[338, 383] -> 
             RGBColor[
              0.8560641226903799, 0.836632021800209, 0.6303948280914389], 
             UndirectedEdge[243, 477] -> 
             RGBColor[
              0.5632773947144891, 0.4487885999441966, 0.5764716700253152], 
             UndirectedEdge[38, 221] -> 
             RGBColor[
              0.9080709469259247, 0.9272133652511436, 0.9012197333329461], 
             UndirectedEdge[330, 357] -> 
             RGBColor[
              0.9740478285596064, 0.9798259678816226, 0.9136097831342663], 
             UndirectedEdge[48, 365] -> 
             RGBColor[
              0.7922624746884519, 0.8384797989616266, 0.9797063153171319], 
             UndirectedEdge[384, 411] -> 
             RGBColor[
              0.7994898251771523, 0.8437748091958088, 0.9805198281847827], 
             UndirectedEdge[38, 436] -> 
             RGBColor[
              0.8140851579854758, 0.8536786523380668, 0.8919073022101347], 
             UndirectedEdge[117, 155] -> 
             RGBColor[
              0.6121407517251012, 0.6937607205970827, 0.9640710383983933], 
             UndirectedEdge[68, 286] -> 
             RGBColor[
              0.6318654661317296, 0.68389088768092, 0.6647590522742933], 
             UndirectedEdge[378, 380] -> 
             RGBColor[
              0.9592687822994868, 0.9416751758126183, 0.6674428737069111], 
             UndirectedEdge[12, 285] -> 
             RGBColor[
              0.9866489953503571, 0.9663534913412231, 0.4258122260625343], 
             UndirectedEdge[93, 432] -> 
             RGBColor[
              0.8630777755178584, 0.41130394980125384`, 0.43005948269869354`],
              UndirectedEdge[340, 499] -> 
             RGBColor[
              0.5792611076246229, 0.6577863850223757, 0.9639198932946883], 
             UndirectedEdge[389, 456] -> 
             RGBColor[
              0.7960321089312841, 0.8371481938729559, 0.7809303145421055], 
             UndirectedEdge[390, 451] -> 
             RGBColor[
              0.40650575178643356`, 0.518934758244189, 0.9480696113512368], 
             UndirectedEdge[92, 485] -> 
             RGBColor[
              0.7239119703049297, 0.7842448002277418, 0.9731164379241575], 
             UndirectedEdge[293, 471] -> 
             RGBColor[
              0.9466260931925228, 0.9597144082115106, 0.9752322814673987], 
             UndirectedEdge[111, 359] -> 
             RGBColor[
              0.5017373924585835, 0.5946519969471351, 0.9566578554123888], 
             UndirectedEdge[357, 441] -> 
             RGBColor[
              0.9809678269322756, 0.9591343148790978, 0.6189369108616802], 
             UndirectedEdge[52, 268] -> 
             RGBColor[
              0.7304832967288653, 0.7893783703740509, 0.9737714063295585], 
             UndirectedEdge[30, 311] -> 
             RGBColor[
              0.8802736466780672, 0.9063949864897691, 0.9414802082109391], 
             UndirectedEdge[164, 486] -> 
             RGBColor[
              0.5499697602796487, 0.632628332781856, 0.9613990379695623], 
             UndirectedEdge[194, 290] -> 
             RGBColor[
              0.6480231094548211, 0.702901963661924, 0.6693248203295918], 
             UndirectedEdge[238, 445] -> 
             RGBColor[
              0.9579389424918657, 0.8626448833620992, 0.5160648749235679], 
             UndirectedEdge[269, 406] -> 
             RGBColor[
              0.5091629531216888, 0.6054580571674408, 0.9566055762901342], 
             UndirectedEdge[99, 341] -> 
             RGBColor[
              0.6194569999551907, 0.698285319581998, 0.9653043810835706], 
             UndirectedEdge[41, 457] -> 
             RGBColor[
              0.7324527057116492, 0.6533331528195505, 0.5996144438025841], 
             UndirectedEdge[217, 292] -> 
             RGBColor[
              0.6130937962783432, 0.6927799940288208, 0.9648962374789881], 
             UndirectedEdge[176, 299] -> 
             RGBColor[
              0.942927727961054, 0.881256119110158, 0.6249341901999594], 
             UndirectedEdge[218, 314] -> 
             RGBColor[
              0.9367268384270373, 0.9523315602159536, 0.9919891376462213], 
             UndirectedEdge[355, 486] -> 
             RGBColor[
              0.5626562178199508, 0.6459626040245796, 0.9621215129585503], 
             UndirectedEdge[213, 420] -> 
             RGBColor[
              0.9063199830246169, 0.9239533985972231, 0.7888340552424078], 
             UndirectedEdge[299, 407] -> 
             RGBColor[
              0.7054045444183442, 0.6922814371286005, 0.6114316640916024], 
             UndirectedEdge[201, 314] -> 
             RGBColor[
              0.9576939056904832, 0.9679687646506097, 0.9564973618561647], 
             UndirectedEdge[160, 300] -> 
             RGBColor[
              0.7048120117145404, 0.7649916236395033, 0.9179060607891041], 
             UndirectedEdge[21, 200] -> 
             RGBColor[
              0.9399932133879398, 0.9542948252368233, 0.9700680187455119], 
             UndirectedEdge[25, 180] -> 
             RGBColor[
              0.5329135356615727, 0.6316822415880835, 0.9563720521353332], 
             UndirectedEdge[45, 185] -> 
             RGBColor[
              0.8611001952114972, 0.8901021845499899, 0.8799706991756773], 
             UndirectedEdge[191, 226] -> 
             RGBColor[
              0.6371358134737495, 0.712972403870918, 0.9667187725182245], 
             UndirectedEdge[50, 82] -> 
             RGBColor[
              0.27528188303122514`, 0.4066690913182555, 0.9389882680443529], 
             UndirectedEdge[22, 491] -> 
             RGBColor[
              0.65006756107525, 0.7169123124503951, 0.8900703994375307], 
             UndirectedEdge[99, 277] -> 
             RGBColor[
              0.6388622336940262, 0.7149747368673556, 0.9665735854500159], 
             UndirectedEdge[17, 391] -> 
             RGBColor[
              0.4500961790072867, 0.5641526306056488, 0.9499338067447534], 
             UndirectedEdge[211, 362] -> 
             RGBColor[
              0.7115760841887037, 0.7724028334824252, 0.9526783944793186], 
             UndirectedEdge[4, 162] -> 
             RGBColor[
              0.686471702525347, 0.5943243894342474, 0.5916011348327871], 
             UndirectedEdge[259, 444] -> 
             RGBColor[
              0.6923989175115126, 0.7215225420520912, 0.6419512340816766], 
             UndirectedEdge[347, 382] -> 
             RGBColor[
              0.5509711874128631, 0.6310594509406291, 0.9618531986778935], 
             UndirectedEdge[66, 179] -> 
             RGBColor[
              0.598591146930603, 0.6214281066924122, 0.6175507207108892], 
             UndirectedEdge[343, 471] -> 
             RGBColor[
              0.8561140897853974, 0.8881088878952119, 0.9684041999655764], 
             UndirectedEdge[97, 322] -> 
             RGBColor[
              0.6493235501353187, 0.6935793137953887, 0.6534821403000063], 
             UndirectedEdge[363, 381] -> 
             RGBColor[
              0.3129995080693012, 0.44429399947821036`, 0.9412101457511753], 
             UndirectedEdge[238, 471] -> 
             RGBColor[
              0.9394081229775262, 0.8501956578480624, 0.6088302136968946], 
             UndirectedEdge[40, 285] -> 
             RGBColor[
              0.6647915511652247, 0.7111481644820892, 0.6608252158183247], 
             UndirectedEdge[70, 208] -> 
             RGBColor[
              0.79233258142943, 0.8385271483406223, 0.9744418046376833], 
             UndirectedEdge[84, 448] -> 
             RGBColor[
              0.8506892335315817, 0.4017505188537237, 0.4401408193045102], 
             UndirectedEdge[152, 195] -> 
             RGBColor[
              0.6864204575047357, 0.7511907776534279, 0.9550889863452354], 
             UndirectedEdge[93, 308] -> 
             RGBColor[
              0.5968637438251735, 0.6671656454720774, 0.9493360214774937], 
             UndirectedEdge[255, 478] -> 
             RGBColor[
              0.8795228836608076, 0.9067716896911844, 0.9883708718745567], 
             UndirectedEdge[112, 293] -> 
             RGBColor[
              0.9455710894628484, 0.9589275881573295, 0.9770181275926961], 
             UndirectedEdge[87, 184] -> 
             RGBColor[
              0.8775070645986524, 0.4280253882923376, 0.33016486406494305`], 
             UndirectedEdge[149, 323] -> 
             RGBColor[
              0.8578427523073748, 0.40739967806243893`, 0.4389210114813168], 
             UndirectedEdge[272, 497] -> 
             RGBColor[
              0.8614371914594713, 0.3688111744124188, 0.20226679350435933`], 
             UndirectedEdge[80, 471] -> 
             RGBColor[
              0.9532653136805365, 0.9051348013504336, 0.6199800346066076], 
             UndirectedEdge[339, 344] -> 
             RGBColor[
              0.8464963795219052, 0.39840725087839785`, 0.43974090114606224`],
              UndirectedEdge[137, 393] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[11, 316] -> 
             RGBColor[
              0.39615667682023625`, 0.5105329129661158, 0.947254894259987], 
             UndirectedEdge[88, 423] -> 
             RGBColor[
              0.9307877870037091, 0.947541123389595, 0.9895227695595865], 
             UndirectedEdge[70, 351] -> 
             RGBColor[
              0.4359980567180016, 0.5395125865925425, 0.9507045312967791], 
             UndirectedEdge[55, 298] -> 
             RGBColor[
              0.5534699140698411, 0.6483708356342098, 0.9579903255441273], 
             UndirectedEdge[428, 437] -> 
             RGBColor[
              0.6735279489721964, 0.742414256980982, 0.9699948105211511], 
             UndirectedEdge[90, 137] -> 
             RGBColor[
              0.8010831932599617, 0.3624728249597305, 0.43533589241834025`], 
             UndirectedEdge[344, 439] -> 
             RGBColor[
              0.7809675773386591, 0.8295030235679226, 0.978621177715546], 
             UndirectedEdge[93, 274] -> 
             RGBColor[
              0.8630777755178584, 0.41130394980125384`, 0.43005948269869354`],
              UndirectedEdge[60, 434] -> 
             RGBColor[
              0.6180136915545036, 0.6896606499991212, 0.9520597727529931], 
             UndirectedEdge[54, 244] -> 
             RGBColor[
              0.9406823562143651, 0.9504872018567563, 0.7228499364427434], 
             UndirectedEdge[243, 318] -> 
             RGBColor[
              0.5784745558931285, 0.46476177989861756`, 0.5773371258722535], 
             UndirectedEdge[384, 402] -> 
             RGBColor[
              0.657451311672531, 0.7291198731071131, 0.9686802176574233], 
             UndirectedEdge[83, 233] -> 
             RGBColor[
              0.7672953573853274, 0.8169052415121347, 0.9374045367732822], 
             UndirectedEdge[153, 201] -> 
             RGBColor[
              0.6445563478348004, 0.7134626901847321, 0.9310041366046197], 
             UndirectedEdge[275, 331] -> 
             RGBColor[
              0.9906734093864851, 0.9882259572523028, 0.645383060814041], 
             UndirectedEdge[312, 327] -> 
             RGBColor[
              0.5660393186569166, 0.6585752445232215, 0.958979835116468], 
             UndirectedEdge[181, 370] -> 
             RGBColor[
              0.8982602031406685, 0.7644930080029269, 0.6111553714726082], 
             UndirectedEdge[32, 245] -> 
             RGBColor[
              0.7173393453538887, 0.7768476902001491, 0.9468554066481822], 
             UndirectedEdge[176, 391] -> 
             RGBColor[
              0.6936082762895129, 0.7579893825584352, 0.963907802080799], 
             UndirectedEdge[148, 232] -> 
             RGBColor[
              0.7383154953479529, 0.7918495341868328, 0.8727368852197914], 
             UndirectedEdge[430, 477] -> 
             RGBColor[
              0.5999303170785092, 0.6717616406336737, 0.9573793210344939], 
             UndirectedEdge[7, 475] -> 
             RGBColor[
              0.4578493711532836, 0.5670658197085634, 0.9514784024962832], 
             UndirectedEdge[15, 50] -> 
             RGBColor[
              0.6405391021745221, 0.23992786184201234`, 0.42417024418465854`],
              UndirectedEdge[168, 395] -> 
             RGBColor[
              0.30245550055582676`, 0.4328160552902648, 0.940624162184214], 
             UndirectedEdge[97, 440] -> 
             RGBColor[
              0.5125716320681669, 0.6106549564599205, 0.9563992771153382], 
             UndirectedEdge[71, 308] -> 
             RGBColor[
              0.41521621107093876`, 0.5238783285434164, 0.9489490319470271], 
             UndirectedEdge[253, 436] -> 
             RGBColor[
              0.775127843017273, 0.7027880045248203, 0.6063070318752065], 
             UndirectedEdge[13, 430] -> 
             RGBColor[
              0.8600796546372484, 0.40906795615746727`, 0.43513451931440605`],
              UndirectedEdge[209, 233] -> 
             RGBColor[
              0.8719239264724892, 0.4179013946989746, 0.41508525657818485`], 
             UndirectedEdge[254, 350] -> 
             RGBColor[
              0.8564974354107883, 0.3861376622265295, 0.199809318332505], 
             UndirectedEdge[115, 268] -> 
             RGBColor[
              0.6441001391503123, 0.7201544969967046, 0.9663516625694084], 
             UndirectedEdge[42, 468] -> 
             RGBColor[
              0.6053191641834994, 0.620787927360117, 0.6097795345025885], 
             UndirectedEdge[51, 60] -> 
             RGBColor[
              0.2897765796938736, 0.4219039365275473, 0.9398137195763085], 
             UndirectedEdge[331, 348] -> 
             RGBColor[
              0.8164416833619479, 0.8557964580641444, 0.9019027604314948], 
             UndirectedEdge[310, 406] -> 
             RGBColor[
              0.6172898826289179, 0.6907768286000718, 0.9627766541540248], 
             UndirectedEdge[70, 130] -> 
             RGBColor[
              0.7592502097701812, 0.3297925803150639, 0.4311663715755363], 
             UndirectedEdge[83, 440] -> 
             RGBColor[
              0.6284894335443976, 0.7083381230273503, 0.9645367266236606], 
             UndirectedEdge[100, 374] -> 
             RGBColor[
              0.8706856941139511, 0.4169779230333964, 0.4171812609784685], 
             UndirectedEdge[207, 374] -> 
             RGBColor[
              0.7073773301188825, 0.2876875361941156, 0.4270774863838843], 
             UndirectedEdge[51, 324] -> 
             RGBColor[
              0.37689641602041957`, 0.4996164927521889, 0.9453090188492955], 
             UndirectedEdge[164, 180] -> 
             RGBColor[
              0.42673620629027575`, 0.535463120486328, 0.9496527266205759], 
             UndirectedEdge[56, 132] -> 
             RGBColor[
              0.7394463048924586, 0.3760867884153132, 0.43757498205483436`], 
             UndirectedEdge[30, 423] -> 
             RGBColor[
              0.9531546499855035, 0.9641522794218467, 0.9485261456499435], 
             UndirectedEdge[104, 379] -> 
             RGBColor[
              0.7132133162577425, 0.6028714998810665, 0.5910387402908243], 
             UndirectedEdge[324, 457] -> 
             RGBColor[
              0.6800727379770299, 0.610808735321931, 0.5954909008683709], 
             UndirectedEdge[283, 459] -> 
             RGBColor[
              0.9311851838498126, 0.8151078044706432, 0.6002845815521486], 
             UndirectedEdge[128, 245] -> 
             RGBColor[
              0.9483489121727597, 0.8685172880674621, 0.602737251551139], 
             UndirectedEdge[34, 62] -> 
             RGBColor[
              0.43335853793121903`, 0.5471934123641431, 0.9495475334503426], 
             UndirectedEdge[320, 424] -> 
             RGBColor[
              0.8730975866759529, 0.8928545576644644, 0.6947626538632852], 
             UndirectedEdge[111, 351] -> 
             RGBColor[
              0.4877175285564594, 0.5799162310752902, 0.9558594449036929], 
             UndirectedEdge[79, 316] -> 
             RGBColor[
              0.5884857673546181, 0.5540491183305668, 0.5962349882834632], 
             UndirectedEdge[43, 250] -> 
             RGBColor[
              0.6780877180034214, 0.43897268532178235`, 0.44811187265902697`],
              UndirectedEdge[116, 313] -> 
             RGBColor[
              0.6058396928345053, 0.5651116885609895, 0.595381411489669], 
             UndirectedEdge[87, 436] -> 
             RGBColor[
              0.8165228014079873, 0.8541406532447903, 0.811818822231583], 
             UndirectedEdge[280, 393] -> 
             RGBColor[
              0.8578682933965857, 0.35466168285785654`, 0.19939517435015724`],
              UndirectedEdge[295, 321] -> 
             RGBColor[
              0.6164196039292726, 0.6927386501186981, 0.9664531574631485], 
             UndirectedEdge[131, 186] -> 
             RGBColor[
              0.9912788646836914, 0.9898443563188813, 0.7347902748572679], 
             UndirectedEdge[165, 313] -> 
             RGBColor[
              0.6020763391977932, 0.5611561652784031, 0.5951670940674411], 
             UndirectedEdge[140, 270] -> 
             RGBColor[
              0.6749130051370963, 0.26018720844243, 0.42483795654753065`], 
             UndirectedEdge[322, 445] -> 
             RGBColor[
              0.9847351016097803, 0.962654127946643, 0.5700643327214423], 
             UndirectedEdge[112, 463] -> 
             RGBColor[
              0.7064756046874029, 0.7684490894324204, 0.9572939375186356], 
             UndirectedEdge[115, 223] -> 
             RGBColor[
              0.7566391403235619, 0.8080815388159037, 0.9308673560131511], 
             UndirectedEdge[102, 451] -> 
             RGBColor[
              0.6085969654502783, 0.6786317558797724, 0.9450391289986934], 
             UndirectedEdge[148, 267] -> 
             RGBColor[
              0.6572459968630922, 0.7298331071044719, 0.9680972442227551], 
             UndirectedEdge[447, 500] -> 
             RGBColor[
              0.4257168951187049, 0.5344480627594754, 0.9495895533132683], 
             UndirectedEdge[238, 293] -> 
             RGBColor[
              0.9306514198490794, 0.8436649229926522, 0.623653027979403], 
             UndirectedEdge[56, 457] -> 
             RGBColor[
              0.7296114654692516, 0.6510265059943579, 0.5993907709628967], 
             UndirectedEdge[204, 331] -> 
             RGBColor[
              0.9881329007743436, 0.9893606637467214, 0.8463320754448496], 
             UndirectedEdge[66, 260] -> 
             RGBColor[
              0.7402501061927962, 0.7488925945343295, 0.6268412060475064], 
             UndirectedEdge[225, 424] -> 
             RGBColor[
              0.8746625967006936, 0.4146634942018086, 0.24718745832676925`], 
             UndirectedEdge[178, 244] -> 
             RGBColor[
              0.9198166324278653, 0.8788277727177662, 0.6343560204625556], 
             UndirectedEdge[139, 247] -> 
             RGBColor[
              0.6200647085839577, 0.6179949884113145, 0.6059254093796992], 
             UndirectedEdge[244, 448] -> 
             RGBColor[
              0.9030028895069522, 0.92549400900512, 0.9906104157930107], 
             UndirectedEdge[259, 275] -> 
             RGBColor[
              0.9811513255195501, 0.9479293753656257, 0.3941815577445281], 
             UndirectedEdge[282, 406] -> 
             RGBColor[
              0.6399581142986166, 0.7073993338143432, 0.9117129069423111], 
             UndirectedEdge[286, 357] -> 
             RGBColor[
              0.9848478369477918, 0.9722224997311093, 0.6340100170935505], 
             UndirectedEdge[206, 396] -> 
             RGBColor[
              0.5252099226510171, 0.6140114871528455, 0.9588354898279989], 
             UndirectedEdge[154, 295] -> 
             RGBColor[
              0.6613957922973681, 0.7253172272236711, 0.8390765029430851], 
             UndirectedEdge[410, 428] -> 
             RGBColor[
              0.8219033843997767, 0.8614326186073762, 0.9827144834422049], 
             UndirectedEdge[104, 147] -> 
             RGBColor[
              0.5530916819538538, 0.458592465508634, 0.5804609934967956], 
             UndirectedEdge[32, 255] -> 
             RGBColor[
              0.6963184208441595, 0.7608681626682555, 0.9719623948668842], 
             UndirectedEdge[165, 498] -> 
             RGBColor[
              0.608983116232362, 0.5885392346734584, 0.6007244489923487], 
             UndirectedEdge[248, 439] -> 
             RGBColor[
              0.5251148983975047, 0.6234915712361488, 0.9563637656931281], 
             UndirectedEdge[141, 389] -> 
             RGBColor[
              0.8892088664590829, 0.5189660220575848, 0.3220112926573724], 
             UndirectedEdge[328, 478] -> 
             RGBColor[
              0.9123696721696626, 0.9240779539820716, 0.6992606234958562], 
             UndirectedEdge[178, 261] -> 
             RGBColor[
              0.7058468646477167, 0.7083348033879433, 0.6150799048775879], 
             UndirectedEdge[120, 315] -> 
             RGBColor[
              0.8327752986703408, 0.8698953211656832, 0.967033419885831], 
             UndirectedEdge[47, 136] -> 
             RGBColor[
              0.9285234009104036, 0.9422910553586956, 0.8432100350834624], 
             UndirectedEdge[74, 144] -> 
             RGBColor[
              0.6940457116712189, 0.7604598149637931, 0.9704495290105383], 
             UndirectedEdge[165, 361] -> 
             RGBColor[
              0.6394337853832011, 0.7055928092272397, 0.878936623000321], 
             UndirectedEdge[32, 482] -> 
             RGBColor[
              0.6904737077228993, 0.7562077470758738, 0.9714049209117415], 
             UndirectedEdge[67, 119] -> 
             RGBColor[
              0.7501090019258945, 0.8043753644512943, 0.9742124913757338], 
             UndirectedEdge[97, 326] -> 
             RGBColor[
              0.6160802162518948, 0.6922485722809791, 0.9665218155413436], 
             UndirectedEdge[409, 430] -> 
             RGBColor[
              0.8738774487910671, 0.5151238482556688, 0.44834730257848243`], 
             UndirectedEdge[113, 190] -> 
             RGBColor[
              0.9059720424439612, 0.7989639190995177, 0.6176238363046813], 
             UndirectedEdge[292, 496] -> 
             RGBColor[
              0.5677279715439508, 0.6534863967965397, 0.9620055672423363], 
             UndirectedEdge[15, 82] -> 
             RGBColor[
              0.6360127536298598, 0.2351703825344988, 0.4239124753311726], 
             UndirectedEdge[340, 414] -> 
             RGBColor[
              0.9138970939833447, 0.9340370017760842, 0.9866656063431365], 
             UndirectedEdge[149, 282] -> 
             RGBColor[
              0.9623941172260918, 0.9711907498688095, 0.9358487859212725], 
             UndirectedEdge[330, 368] -> 
             RGBColor[
              0.9163581579735778, 0.9354685174000402, 0.9684947487351594], 
             UndirectedEdge[331, 431] -> 
             RGBColor[
              0.9910239043497109, 0.9889756305381663, 0.6835322745570007], 
             UndirectedEdge[4, 488] -> 
             RGBColor[
              0.5798009014596222, 0.49898405418189595`, 0.5847265017082172], 
             UndirectedEdge[87, 409] -> 
             RGBColor[
              0.8902268147562017, 0.5257949618333213, 0.3423453111807154], 
             UndirectedEdge[440, 445] -> 
             RGBColor[
              0.8479831835426284, 0.8797297706111749, 0.8729814695367742], 
             UndirectedEdge[55, 200] -> 
             RGBColor[
              0.7078737104314674, 0.7702971489653058, 0.9728169586904145], 
             UndirectedEdge[64, 215] -> 
             RGBColor[
              0.6782923703381323, 0.6831023247630853, 0.6128950645452114], 
             UndirectedEdge[167, 493] -> 
             RGBColor[
              0.8674734522454102, 0.7857810858220704, 0.6178593274082911], 
             UndirectedEdge[153, 470] -> 
             RGBColor[
              0.648363240905224, 0.2371911370947328, 0.4231462290477105], 
             UndirectedEdge[185, 187] -> 
             RGBColor[
              0.8415885340351261, 0.8748595265448915, 0.8780259591364572], 
             UndirectedEdge[18, 310] -> 
             RGBColor[
              0.6808928397206864, 0.747228194272481, 0.9667795205256305], 
             UndirectedEdge[226, 366] -> 
             RGBColor[
              0.6617514992448856, 0.7334256724051098, 0.96852698306204], 
             UndirectedEdge[333, 361] -> 
             RGBColor[
              0.954237533617087, 0.8526009192240092, 0.5357475000865437], 
             UndirectedEdge[236, 300] -> 
             RGBColor[
              0.602183027072487, 0.6850073319081259, 0.963490931700852], 
             UndirectedEdge[161, 335] -> 
             RGBColor[
              0.5919770703744713, 0.676696884152109, 0.9626165335002295], 
             UndirectedEdge[61, 397] -> 
             RGBColor[
              0.8621328278629493, 0.41059920938743244`, 0.43165903259663474`],
              UndirectedEdge[393, 480] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[349, 378] -> 
             RGBColor[
              0.9690266661868845, 0.9747935781813943, 0.8644472697737124], 
             UndirectedEdge[97, 163] -> 
             RGBColor[
              0.3000202594156828, 0.4314802809500253, 0.9404406688135449], 
             UndirectedEdge[229, 267] -> 
             RGBColor[
              0.9112671667088641, 0.9290826012835923, 0.8720251790250838], 
             UndirectedEdge[77, 287] -> 
             RGBColor[
              0.7996870162411585, 0.843440842024803, 0.980668986345016], 
             UndirectedEdge[41, 485] -> 
             RGBColor[
              0.624807615258298, 0.7055953057411537, 0.9640785188458074], 
             UndirectedEdge[7, 89] -> 
             RGBColor[
              0.6422336716024497, 0.7121807851693824, 0.9415083172417735], 
             UndirectedEdge[41, 44] -> 
             RGBColor[
              0.7502334196258647, 0.8044681549682167, 0.9740018846630175], 
             UndirectedEdge[147, 234] -> 
             RGBColor[
              0.5791726897766809, 0.651377189339029, 0.9644114826494561], 
             UndirectedEdge[259, 331] -> 
             RGBColor[
              0.9790758357004496, 0.9492563790814047, 0.5874240075445878], 
             UndirectedEdge[77, 409] -> 
             RGBColor[
              0.8249516561305485, 0.4763959999993885, 0.4495524258243543], 
             UndirectedEdge[2, 334] -> 
             RGBColor[
              0.7771242639253855, 0.8259672919541592, 0.9783796351577853], 
             UndirectedEdge[315, 487] -> 
             RGBColor[
              0.6370761599200999, 0.7084486588539658, 0.9519073277902469], 
             UndirectedEdge[251, 258] -> 
             RGBColor[
              0.9435491619889732, 0.7971383697949419, 0.4725707852692924], 
             UndirectedEdge[39, 96] -> 
             RGBColor[
              0.9932766099239447, 0.9880276734033564, 0.5095786660543439], 
             UndirectedEdge[219, 497] -> 
             RGBColor[
              0.8776390311514873, 0.8431215695577919, 0.6298115825667894], 
             UndirectedEdge[447, 454] -> 
             RGBColor[
              0.2699885984289794, 0.4011055135876673, 0.9386868233169678], 
             UndirectedEdge[417, 458] -> 
             RGBColor[
              0.6746574498936764, 0.25996585933515964`, 0.42482167279339855`],
              UndirectedEdge[189, 422] -> 
             RGBColor[
              0.5746781143993069, 0.6593126695726281, 0.9625373944134452], 
             UndirectedEdge[431, 444] -> 
             RGBColor[
              0.7043469861607738, 0.7612417935088529, 0.7380595010940895], 
             UndirectedEdge[161, 273] -> 
             RGBColor[
              0.8667395357944753, 0.896229407138647, 0.96034357869228], 
             UndirectedEdge[109, 413] -> 
             RGBColor[
              0.6088596250388341, 0.6395739155298725, 0.6302561447000794], 
             UndirectedEdge[236, 470] -> 
             RGBColor[
              0.8050080922047728, 0.3655389858457538, 0.43572708966489304`], 
             UndirectedEdge[287, 436] -> 
             RGBColor[
              0.7194734937804763, 0.7807167288151331, 0.9727155528612238], 
             UndirectedEdge[253, 473] -> 
             RGBColor[
              0.8488323816752402, 0.3188373039218065, 0.1921246676790546], 
             UndirectedEdge[166, 435] -> 
             RGBColor[
              0.33592588026849857`, 0.4611859784123904, 0.9427795824395155], 
             UndirectedEdge[114, 312] -> 
             RGBColor[
              0.632423551883573, 0.7113340235119213, 0.9649818044186285], 
             UndirectedEdge[222, 296] -> 
             RGBColor[
              0.7832494775274805, 0.8282390800579288, 0.8725167024400464], 
             UndirectedEdge[5, 346] -> 
             RGBColor[
              0.7646804151069702, 0.8162986368974684, 0.9771253970212592], 
             UndirectedEdge[86, 220] -> 
             RGBColor[
              0.8134476579567492, 0.37213203875427314`, 0.436568266706824], 
             UndirectedEdge[195, 255] -> 
             RGBColor[
              0.6712742909361256, 0.7395926349749876, 0.9702515417518882], 
             UndirectedEdge[313, 407] -> 
             RGBColor[
              0.6924145152827492, 0.6407803002765688, 0.6009795817339298], 
             UndirectedEdge[224, 441] -> 
             RGBColor[
              0.6771952259518201, 0.7160584482431284, 0.6527251524273818], 
             UndirectedEdge[172, 211] -> 
             RGBColor[
              0.9724102576742093, 0.9664697422344208, 0.6770265194199014], 
             UndirectedEdge[204, 355] -> 
             RGBColor[
              0.635418291689113, 0.7020635019995658, 0.8967380254791878], 
             UndirectedEdge[109, 180] -> 
             RGBColor[
              0.7808969658078708, 0.790002001139626, 0.6420927756736504], 
             UndirectedEdge[96, 157] -> 
             RGBColor[
              0.9684556277894549, 0.9726728354473851, 0.738375688943034], 
             UndirectedEdge[316, 372] -> 
             RGBColor[
              0.4461694676517117, 0.551135549613659, 0.95119208435713], 
             UndirectedEdge[53, 112] -> 
             RGBColor[
              0.6892410080628791, 0.7536940484013754, 0.9561480466461838], 
             UndirectedEdge[28, 305] -> 
             RGBColor[
              0.9522086110214995, 0.906544464726819, 0.6234738837359686], 
             UndirectedEdge[186, 341] -> 
             RGBColor[
              0.7066017782655563, 0.7637578364954594, 0.7863267404590801], 
             UndirectedEdge[65, 86] -> 
             RGBColor[
              0.8882689919807674, 0.9129550017311199, 0.9577625427266683], 
             UndirectedEdge[10, 390] -> 
             RGBColor[
              0.4556605823051586, 0.5663015726853875, 0.9510262781284358], 
             UndirectedEdge[48, 140] -> 
             RGBColor[
              0.7651226679349727, 0.33438018926573415`, 0.4317516833241609], 
             UndirectedEdge[231, 404] -> 
             RGBColor[
              0.7896693869225374, 0.6510922721155454, 0.5950637366822804], 
             UndirectedEdge[87, 354] -> 
             RGBColor[
              0.9375056195126279, 0.9492020643985586, 0.8237062540966075], 
             UndirectedEdge[136, 434] -> 
             RGBColor[
              0.9074409850824272, 0.9285903250053127, 0.9756919398423751], 
             UndirectedEdge[205, 413] -> 
             RGBColor[
              0.3145207237385528, 0.44156041710592886`, 0.9414554099206098], 
             UndirectedEdge[20, 490] -> 
             RGBColor[
              0.2999058504469402, 0.4289818330962808, 0.9405212308257962], 
             UndirectedEdge[390, 443] -> 
             RGBColor[
              0.7190457714582119, 0.7796230100011836, 0.9734019526849076], 
             UndirectedEdge[296, 385] -> 
             RGBColor[
              0.7805383170100286, 0.8271179455103153, 0.9174476484727332], 
             UndirectedEdge[86, 290] -> 
             RGBColor[
              0.5581949136291665, 0.645831726808987, 0.96114317107195], 
             UndirectedEdge[24, 74] -> 
             RGBColor[
              0.8034403258624296, 0.843161216874867, 0.7814068671772086], 
             UndirectedEdge[38, 336] -> 
             RGBColor[
              0.8510610232111201, 0.8826251790973592, 0.8955512100996181], 
             UndirectedEdge[383, 443] -> 
             RGBColor[
              0.8189477258888032, 0.8589887333079234, 0.9824556899749376], 
             UndirectedEdge[14, 435] -> 
             RGBColor[
              0.6409135008377458, 0.5229495192300055, 0.5816281751655439], 
             UndirectedEdge[282, 323] -> 
             RGBColor[
              0.8735119925100198, 0.4188968218501008, 0.4039355124661982], 
             UndirectedEdge[307, 337] -> 
             RGBColor[
              0.6261476055067248, 0.7073738596353598, 0.9637117796411946], 
             UndirectedEdge[157, 356] -> 
             RGBColor[
              0.6248220024784323, 0.698206383227491, 0.9604132224122182], 
             UndirectedEdge[166, 439] -> 
             RGBColor[
              0.46021323654055246`, 0.5630791460123507, 0.9523819936929205], 
             UndirectedEdge[266, 293] -> 
             RGBColor[
              0.6089801079886381, 0.6824536342739504, 0.9646586129885976], 
             UndirectedEdge[2, 260] -> 
             RGBColor[
              0.6180474532956074, 0.6996792156762113, 0.9638388821564967], 
             UndirectedEdge[135, 466] -> 
             RGBColor[
              0.8993558179128434, 0.7259844481037534, 0.6034848030499558], 
             UndirectedEdge[60, 495] -> 
             RGBColor[
              0.4536237583195315, 0.5603264799872003, 0.9514931637880576], 
             UndirectedEdge[217, 464] -> 
             RGBColor[
              0.4489726870877551, 0.562258608133918, 0.9501166690760996], 
             UndirectedEdge[435, 453] -> 
             RGBColor[
              0.7040849696076241, 0.4425657654797607, 0.4472881167748405], 
             UndirectedEdge[82, 411] -> 
             RGBColor[
              0.49355491667521467`, 0.5898207855784225, 0.9555951733451957], 
             UndirectedEdge[94, 193] -> 
             RGBColor[
              0.7151113242223579, 0.7726793246847474, 0.873241424945453], 
             UndirectedEdge[88, 469] -> 
             RGBColor[
              0.7572837141435049, 0.8101396862218534, 0.9731564196695186], 
             UndirectedEdge[36, 76] -> 
             RGBColor[
              0.9447022432963998, 0.804743117591296, 0.3670071853615905], 
             UndirectedEdge[163, 326] -> 
             RGBColor[
              0.5944791432668517, 0.6707348874385184, 0.9652480795595237], 
             UndirectedEdge[151, 472] -> 
             RGBColor[
              0.9129559743773145, 0.9330296751481827, 0.9776688393625508], 
             UndirectedEdge[114, 138] -> 
             RGBColor[
              0.7889836428515151, 0.8354150085351929, 0.9795130835125052], 
             UndirectedEdge[448, 475] -> 
             RGBColor[
              0.7575964575812767, 0.8106638444650396, 0.976731857162282], 
             UndirectedEdge[169, 362] -> 
             RGBColor[
              0.6822318499138619, 0.6079219720334954, 0.5947206100717662], 
             UndirectedEdge[20, 25] -> 
             RGBColor[
              0.40874700838834155`, 0.5280008069217024, 0.9473922574368396], 
             UndirectedEdge[113, 349] -> 
             RGBColor[
              0.9491662189038275, 0.9591731926392342, 0.8700347461966311], 
             UndirectedEdge[457, 494] -> 
             RGBColor[
              0.6393712143370471, 0.5756661845084841, 0.5928667486673456], 
             UndirectedEdge[364, 452] -> 
             RGBColor[
              0.7930081267235649, 0.8361974119502579, 0.8747823912350129], 
             UndirectedEdge[351, 442] -> 
             RGBColor[
              0.5936840370064834, 0.6147611735139585, 0.6147834242088109], 
             UndirectedEdge[71, 466] -> 
             RGBColor[
              0.7311033614925442, 0.5928907172126421, 0.5874809976583711], 
             UndirectedEdge[87, 285] -> 
             RGBColor[
              0.9875011978846164, 0.9681762663911107, 0.5185692127322623], 
             UndirectedEdge[211, 369] -> 
             RGBColor[
              0.837787125923145, 0.8737287965808082, 0.9633921417571862], 
             UndirectedEdge[164, 316] -> 
             RGBColor[
              0.2573594991230136, 0.3878315294859532, 0.9379676147945712], 
             UndirectedEdge[27, 297] -> 
             RGBColor[
              0.5098213871049575, 0.6124463267589032, 0.9546891741303689], 
             UndirectedEdge[238, 483] -> 
             RGBColor[
              0.693819842473026, 0.6550243662824358, 0.6041070609887886], 
             UndirectedEdge[109, 164] -> 
             RGBColor[
              0.6119565458339143, 0.6428289756416212, 0.6304325097578755], 
             UndirectedEdge[83, 355] -> 
             RGBColor[
              0.4183128183750553, 0.531659468200558, 0.9487133572473935], 
             UndirectedEdge[85, 166] -> 
             RGBColor[
              0.4906470325690102, 0.5868542587751986, 0.9554153500610434], 
             UndirectedEdge[34, 190] -> 
             RGBColor[
              0.6129572634454068, 0.5607471673454519, 0.5930064781280167], 
             UndirectedEdge[232, 383] -> 
             RGBColor[
              0.8736260514826283, 0.8999615554962768, 0.8845781173419487], 
             UndirectedEdge[185, 441] -> 
             RGBColor[
              0.9837314195691722, 0.9602771314555457, 0.5731370289198198], 
             UndirectedEdge[83, 207] -> 
             RGBColor[
              0.5204754628549173, 0.6215844537548461, 0.9553928814818313], 
             UndirectedEdge[138, 385] -> 
             RGBColor[
              0.9239546450217644, 0.9405282316459651, 0.9309442023995071], 
             UndirectedEdge[131, 234] -> 
             RGBColor[
              0.9622172981299011, 0.9706725987824767, 0.918849700620422], 
             UndirectedEdge[80, 81] -> 
             RGBColor[
              0.8127128064863409, 0.7947473273357021, 0.6238599839566942], 
             UndirectedEdge[5, 486] -> 
             RGBColor[
              0.7630652933087213, 0.8150107826168582, 0.9769713452623061], 
             UndirectedEdge[94, 139] -> 
             RGBColor[
              0.9661259526989319, 0.8975037902802012, 0.5343972176408265], 
             UndirectedEdge[126, 249] -> 
             RGBColor[
              0.860291562696355, 0.8916983600427159, 0.9864672558906784], 
             UndirectedEdge[359, 483] -> 
             RGBColor[
              0.3605647236208386, 0.4816377619596254, 0.9444529653265099], 
             UndirectedEdge[275, 404] -> 
             RGBColor[
              0.934931017012749, 0.7608901121789248, 0.3356565686430319], 
             UndirectedEdge[313, 391] -> 
             RGBColor[
              0.6787920074242682, 0.6294261847389837, 0.5999886083096384], 
             UndirectedEdge[1, 487] -> 
             RGBColor[
              0.6375588308134427, 0.7088086340159198, 0.9510902918685482], 
             UndirectedEdge[71, 172] -> 
             RGBColor[
              0.7885918307598385, 0.8215633759956433, 0.6803142874426678], 
             UndirectedEdge[44, 494] -> 
             RGBColor[
              0.6571519282512627, 0.7268011866571504, 0.9672541895277789], 
             UndirectedEdge[85, 387] -> 
             RGBColor[
              0.7979943302099916, 0.455336732106984, 0.4468655715071268], 
             UndirectedEdge[414, 499] -> 
             RGBColor[
              0.6066374809658684, 0.6794718118496185, 0.9615471678249496], 
             UndirectedEdge[89, 376] -> 
             RGBColor[
              0.9804293700332152, 0.9824171267917502, 0.782718011342824], 
             UndirectedEdge[171, 403] -> 
             RGBColor[
              0.7265265500181979, 0.7853480763941612, 0.9743916004014691], 
             UndirectedEdge[161, 279] -> 
             RGBColor[
              0.609979872797723, 0.6922900067639703, 0.963763656151386], 
             UndirectedEdge[149, 310] -> 
             RGBColor[
              0.9397258855563932, 0.9545682446545382, 0.9869125331329862], 
             UndirectedEdge[333, 367] -> 
             RGBColor[
              0.8760493757168654, 0.7925895839613535, 0.6186851908846307], 
             UndirectedEdge[43, 227] -> 
             RGBColor[
              0.8544884809671061, 0.5825908080269435, 0.4627576118437119], 
             UndirectedEdge[71, 369] -> 
             RGBColor[
              0.6539686990087742, 0.7288224303420308, 0.9666799097799526], 
             UndirectedEdge[134, 174] -> 
             RGBColor[
              0.6751751231107243, 0.7417966640601347, 0.9594225478437121], 
             UndirectedEdge[158, 370] -> 
             RGBColor[
              0.9127489857829354, 0.6882486843021572, 0.24847101671678626`], 
             UndirectedEdge[7, 391] -> 
             RGBColor[
              0.38019905631354045`, 0.5037310460437556, 0.945446925564842], 
             UndirectedEdge[200, 228] -> 
             RGBColor[
              0.9256184258508875, 0.8562389964590691, 0.6288152347470823], 
             UndirectedEdge[201, 300] -> 
             RGBColor[
              0.7013203752422923, 0.7626288376821282, 0.9346210902365665], 
             UndirectedEdge[210, 320] -> 
             RGBColor[
              0.5200070423233742, 0.6124656350986367, 0.95791817171452], 
             UndirectedEdge[69, 103] -> 
             RGBColor[
              0.9171599917817983, 0.9355294721573071, 0.9484954370647769], 
             UndirectedEdge[97, 281] -> 
             RGBColor[
              0.4613920750111423, 0.5700420245354003, 0.9517296452059727], 
             UndirectedEdge[192, 272] -> 
             RGBColor[
              0.8531281759511313, 0.3358686967371318, 0.195581164588688], 
             UndirectedEdge[70, 463] -> 
             RGBColor[
              0.5513955249118643, 0.646675208425737, 0.9578349151641974], 
             UndirectedEdge[285, 477] -> 
             RGBColor[
              0.6173065021036785, 0.6649813681859037, 0.6579839629201887], 
             UndirectedEdge[10, 168] -> 
             RGBColor[
              0.31264294709081636`, 0.4416399094429218, 0.9412732972690182], 
             UndirectedEdge[298, 468] -> 
             RGBColor[
              0.43274014093895485`, 0.5402330172039689, 0.9501348785650572], 
             UndirectedEdge[37, 264] -> 
             RGBColor[
              0.6219077878644166, 0.6904387132769247, 0.9332816442374319], 
             UndirectedEdge[191, 405] -> 
             RGBColor[
              0.6463298512744247, 0.7203034800476686, 0.9675957080512673], 
             UndirectedEdge[349, 380] -> 
             RGBColor[
              0.9842281248825104, 0.9586626719521256, 0.5523265325336112], 
             UndirectedEdge[94, 410] -> 
             RGBColor[
              0.8681028907747694, 0.8956959470779742, 0.8862552336598964], 
             UndirectedEdge[335, 409] -> 
             RGBColor[
              0.6973550399875994, 0.3737303073599294, 0.4386015431849979], 
             UndirectedEdge[168, 189] -> 
             RGBColor[
              0.2969568768526412, 0.42805342380742856`, 0.9402737947440889], 
             UndirectedEdge[187, 399] -> 
             RGBColor[
              0.8421086139109915, 0.8729359945709637, 0.7139533645052751], 
             UndirectedEdge[153, 314] -> 
             RGBColor[
              0.6235892805713545, 0.697825485750076, 0.9664959123946764], 
             UndirectedEdge[233, 355] -> 
             RGBColor[
              0.6321512404071954, 0.7002044107853471, 0.928128590208666], 
             UndirectedEdge[233, 486] -> 
             RGBColor[
              0.9116387568302229, 0.9312083773361564, 0.9508126924844391], 
             UndirectedEdge[49, 264] -> 
             RGBColor[
              0.2762037788264076, 0.40763806225056165`, 0.9390407686460659], 
             UndirectedEdge[205, 331] -> 
             RGBColor[
              0.6830187111591657, 0.7454469102075569, 0.8919482999330559], 
             UndirectedEdge[308, 456] -> 
             RGBColor[
              0.4185428203196876, 0.5265790197935896, 0.9492109148128598], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.4875817672358143, 0.5872131038726742, 0.9546739209355748], 
             UndirectedEdge[175, 371] -> 
             RGBColor[
              0.3775632273039483, 0.5013980457479734, 0.945280802799113], 
             UndirectedEdge[21, 188] -> 
             RGBColor[
              0.9407313511812601, 0.8437911743871034, 0.6008557503541794], 
             UndirectedEdge[79, 221] -> 
             RGBColor[
              0.8732082208346259, 0.7925563978939626, 0.6189140653207285], 
             UndirectedEdge[158, 193] -> 
             RGBColor[
              0.6863402929026224, 0.6645157034476737, 0.6072967104585848], 
             UndirectedEdge[266, 483] -> 
             RGBColor[
              0.3721485306125848, 0.49381307756373405`, 0.9451126459979831], 
             UndirectedEdge[290, 484] -> 
             RGBColor[
              0.6528687346579707, 0.7178717405732107, 0.8363360148629011], 
             UndirectedEdge[153, 411] -> 
             RGBColor[
              0.5145345979259348, 0.611714055042029, 0.9567957095346993], 
             UndirectedEdge[176, 475] -> 
             RGBColor[
              0.7712585911292561, 0.821324156223243, 0.9699392790122403], 
             UndirectedEdge[20, 474] -> 
             RGBColor[
              0.6702347857385889, 0.7314894050710032, 0.7182695411210422], 
             UndirectedEdge[70, 483] -> 
             RGBColor[
              0.5536594323112565, 0.6485131504404297, 0.9580131382476436], 
             UndirectedEdge[163, 266] -> 
             RGBColor[
              0.27925500617192, 0.4108450956496826, 0.9392145315295065], 
             UndirectedEdge[69, 486] -> 
             RGBColor[
              0.9131744451855321, 0.9323515054862248, 0.9481152920724856], 
             UndirectedEdge[262, 475] -> 
             RGBColor[
              0.7134920600295009, 0.7754961950392325, 0.9725251403513331], 
             UndirectedEdge[18, 167] -> 
             RGBColor[
              0.6699314550769275, 0.6272008497674362, 0.60072701873272], 
             UndirectedEdge[281, 374] -> 
             RGBColor[
              0.7452669392071862, 0.31844802775943826`, 0.4300602952055269], 
             UndirectedEdge[138, 294] -> 
             RGBColor[
              0.9153578431832543, 0.9344817363642494, 0.9618411398226447], 
             UndirectedEdge[291, 349] -> 
             RGBColor[
              0.8552164538576272, 0.8850970520329466, 0.8608516589882524], 
             UndirectedEdge[288, 455] -> 
             RGBColor[
              0.4257814653550147, 0.5340507820981483, 0.9496355711634988], 
             UndirectedEdge[12, 459] -> 
             RGBColor[
              0.9491935941685554, 0.8250679184208328, 0.35811132783339594`], 
             UndirectedEdge[93, 305] -> 
             RGBColor[
              0.9535543499484815, 0.907548114615117, 0.621195898757513], 
             UndirectedEdge[127, 184] -> 
             RGBColor[
              0.6531644881298446, 0.24870230715471303`, 0.42441580441342575`],
              UndirectedEdge[204, 431] -> 
             RGBColor[
              0.9905588855566699, 0.988783333316806, 0.6912388393877495], 
             UndirectedEdge[397, 495] -> 
             RGBColor[
              0.7529056050807132, 0.3246494408335434, 0.430661638964446], 
             UndirectedEdge[28, 493] -> 
             RGBColor[
              0.8841060041436435, 0.910037977579818, 0.9743120223166866], 
             UndirectedEdge[267, 485] -> 
             RGBColor[
              0.7583339132442677, 0.8112101421367861, 0.9765274834430351], 
             UndirectedEdge[110, 494] -> 
             RGBColor[
              0.6585687482362803, 0.7278578486821468, 0.964855882858978], 
             UndirectedEdge[337, 500] -> 
             RGBColor[
              0.6161863427038028, 0.6992868577421725, 0.9629275925440406], 
             UndirectedEdge[43, 393] -> 
             RGBColor[
              0.8431295945346498, 0.3325185398679621, 0.18893425447527779`], 
             UndirectedEdge[167, 432] -> 
             RGBColor[
              0.8510922483010481, 0.3277969220372233, 0.193943009412067], 
             UndirectedEdge[230, 474] -> 
             RGBColor[
              0.9821819500702051, 0.9828876936024895, 0.7133782953936988], 
             UndirectedEdge[40, 421] -> 
             RGBColor[
              0.5871756820659184, 0.6701502923963932, 0.9633278091961737], 
             UndirectedEdge[254, 476] -> 
             RGBColor[
              0.9500850784840724, 0.82666344513542, 0.47356307951289767`], 
             UndirectedEdge[107, 197] -> 
             RGBColor[
              0.6694028607700562, 0.7373861004984519, 0.9676520234352275], 
             UndirectedEdge[231, 395] -> 
             RGBColor[
              0.5185418094611705, 0.6158810789852156, 0.9567563896808047], 
             UndirectedEdge[420, 427] -> 
             RGBColor[
              0.9896830269487791, 0.9758981046640249, 0.4962619347393083], 
             UndirectedEdge[317, 374] -> 
             RGBColor[
              0.6392689004656411, 0.22773754582459013`, 0.4226244702275924], 
             UndirectedEdge[188, 200] -> 
             RGBColor[
              0.9181028004647745, 0.8264420462368267, 0.6227679861470146], 
             UndirectedEdge[84, 260] -> 
             RGBColor[
              0.7184512539775306, 0.29667784645715073`, 0.42794926623515683`],
              UndirectedEdge[33, 160] -> 
             RGBColor[
              0.9901391290494366, 0.9896312803091951, 0.7724495270535374], 
             UndirectedEdge[135, 362] -> 
             RGBColor[
              0.696010113694632, 0.7605901981347591, 0.9719699678936695], 
             UndirectedEdge[123, 193] -> 
             RGBColor[
              0.7164858731942229, 0.7720052744692762, 0.7601477534222965], 
             UndirectedEdge[439, 453] -> 
             RGBColor[
              0.7869432071223268, 0.5104945438797341, 0.4536897242771105], 
             UndirectedEdge[269, 282] -> 
             RGBColor[
              0.8551028163531313, 0.8864951889033998, 0.9282632067464176], 
             UndirectedEdge[202, 459] -> 
             RGBColor[
              0.8423667217249193, 0.7451627139977189, 0.610705569264102], 
             UndirectedEdge[25, 474] -> 
             RGBColor[
              0.7316382224091607, 0.784216935341135, 0.7223083954185181], 
             UndirectedEdge[103, 259] -> 
             RGBColor[
              0.9098342896345127, 0.8961411505561406, 0.6608942048469906], 
             UndirectedEdge[352, 375] -> 
             RGBColor[
              0.8289522440435995, 0.8665634464162892, 0.983516772312807], 
             UndirectedEdge[300, 308] -> 
             RGBColor[
              0.3315559693137138, 0.455162573909692, 0.9425830946329659], 
             UndirectedEdge[32, 328] -> 
             RGBColor[
              0.7291652093530147, 0.7781744269591429, 0.6828521464881836], 
             UndirectedEdge[209, 486] -> 
             RGBColor[
              0.8255939114143261, 0.3817401901917963, 0.4377472050781078], 
             UndirectedEdge[118, 496] -> 
             RGBColor[
              0.4173116397016484, 0.534091166546159, 0.9483048891145585], 
             UndirectedEdge[31, 405] -> 
             RGBColor[
              0.7240736099726932, 0.7838885115765171, 0.9735863551104504], 
             UndirectedEdge[21, 228] -> 
             RGBColor[
              0.9482469765673729, 0.8735881246093458, 0.6069029989542472], 
             UndirectedEdge[92, 250] -> 
             RGBColor[
              0.541285195009416, 0.6331105051264647, 0.9592508939025626], 
             UndirectedEdge[177, 290] -> 
             RGBColor[
              0.2984549418949726, 0.4308461851977823, 0.9403145030608013], 
             UndirectedEdge[9, 333] -> 
             RGBColor[
              0.8181812339409639, 0.7472736302479024, 0.6129463397496737], 
             UndirectedEdge[11, 444] -> 
             RGBColor[
              0.47531711245013764`, 0.5838890744290517, 0.9521234916619554], 
             UndirectedEdge[11, 25] -> 
             RGBColor[
              0.502770293384839, 0.6072105995702415, 0.9539990656849741], 
             UndirectedEdge[168, 338] -> 
             RGBColor[
              0.6131445330454464, 0.6326046352510036, 0.6115881099419913], 
             UndirectedEdge[283, 430] -> 
             RGBColor[
              0.951264400006445, 0.9631736498388034, 0.9673808378955921], 
             UndirectedEdge[139, 410] -> 
             RGBColor[
              0.8431361649585862, 0.8026151294528265, 0.6233715526797137], 
             UndirectedEdge[195, 260] -> 
             RGBColor[
              0.469641313124854, 0.5793714261429019, 0.9516517435344899], 
             UndirectedEdge[391, 407] -> 
             RGBColor[
              0.45608509274680326`, 0.5690147005768778, 0.950405275972442], 
             UndirectedEdge[33, 111] -> 
             RGBColor[
              0.8705927925939535, 0.8964310247645306, 0.8163482344381638], 
             UndirectedEdge[2, 114] -> 
             RGBColor[
              0.7159130218019847, 0.777995960862981, 0.9723191774918076], 
             UndirectedEdge[101, 306] -> 
             RGBColor[
              0.9847018397539786, 0.9585472970688493, 0.5235168822546279], 
             UndirectedEdge[264, 374] -> 
             RGBColor[
              0.6346256187519639, 0.222857162342451, 0.4223600422031182], 
             UndirectedEdge[172, 235] -> 
             RGBColor[
              0.8812681339945219, 0.8947449632091744, 0.6890166317582433], 
             UndirectedEdge[84, 475] -> 
             RGBColor[
              0.7441337381892695, 0.3175280441229693, 0.42997108547034435`], 
             UndirectedEdge[37, 397] -> 
             RGBColor[
              0.8697382398243138, 0.4162713131754989, 0.41878505395516974`], 
             UndirectedEdge[228, 287] -> 
             RGBColor[
              0.867211317791224, 0.8098238280888184, 0.623202629982508], 
             UndirectedEdge[68, 375] -> 
             RGBColor[
              0.5662352147623884, 0.6484488285668188, 0.9625185652785176], 
             UndirectedEdge[197, 236] -> 
             RGBColor[
              0.5902288043658745, 0.6746531850363616, 0.9627292192006908], 
             UndirectedEdge[107, 214] -> 
             RGBColor[
              0.9037660118167203, 0.9260242276851492, 0.9879693827356102], 
             UndirectedEdge[207, 317] -> 
             RGBColor[
              0.3853313458767854, 0.5048836230280584, 0.9461169349172152], 
             UndirectedEdge[98, 462] -> 
             RGBColor[
              0.6837776338684216, 0.2678653043003091, 0.42540280285160725`], 
             UndirectedEdge[21, 59] -> 
             RGBColor[
              0.9784351552231585, 0.9808752502552995, 0.7817618650021304], 
             UndirectedEdge[46, 350] -> 
             RGBColor[
              0.8525313820708227, 0.36829668475666255`, 0.19650863380124123`],
              UndirectedEdge[271, 429] -> 
             RGBColor[
              0.8481396926516709, 0.8821799823500017, 0.9828335100634027], 
             UndirectedEdge[304, 423] -> 
             RGBColor[
              0.8521112921515402, 0.4028844297965258, 0.44027645652516856`], 
             UndirectedEdge[299, 328] -> 
             RGBColor[
              0.9653883914021246, 0.8905142718800683, 0.3429289885846688], 
             UndirectedEdge[55, 73] -> 
             RGBColor[
              0.7391788351344589, 0.7738807092731652, 0.6651802034971074], 
             UndirectedEdge[53, 440] -> 
             RGBColor[
              0.5643655794998728, 0.6555162704857735, 0.959699541646097], 
             UndirectedEdge[206, 377] -> 
             RGBColor[
              0.8843433900057867, 0.8931108064734479, 0.6834285362689507], 
             UndirectedEdge[39, 113] -> 
             RGBColor[
              0.9488708813294844, 0.9574234611722959, 0.7566197858090447], 
             UndirectedEdge[9, 450] -> 
             RGBColor[
              0.5334767456735745, 0.6281587498857256, 0.957986620592594], 
             UndirectedEdge[61, 321] -> 
             RGBColor[
              0.9282982917245998, 0.9452496946710243, 0.9786631834114741], 
             UndirectedEdge[76, 460] -> 
             RGBColor[
              0.9415185311015466, 0.8052412830977844, 0.5516799639626437], 
             UndirectedEdge[141, 167] -> 
             RGBColor[
              0.8640515353201427, 0.42740768086176606`, 0.2063528372969732], 
             UndirectedEdge[29, 476] -> 
             RGBColor[
              0.8907791423945299, 0.9124957710697585, 0.8419895339829094], 
             UndirectedEdge[39, 190] -> 
             RGBColor[
              0.9504964947356987, 0.8298220693142468, 0.3835050583208763], 
             UndirectedEdge[115, 215] -> 
             RGBColor[
              0.46763242106554537`, 0.5774138952901122, 0.9515838427636094], 
             UndirectedEdge[208, 471] -> 
             RGBColor[
              0.9484676649346429, 0.9610878494014867, 0.972114980866824], 
             UndirectedEdge[139, 401] -> 
             RGBColor[
              0.8585990756275829, 0.3575589908850179, 0.19998317888688122`], 
             UndirectedEdge[34, 356] -> 
             RGBColor[
              0.3121037533226303, 0.4444863192146672, 0.9411176193306685], 
             UndirectedEdge[288, 313] -> 
             RGBColor[
              0.7571081157470665, 0.6933014795469901, 0.6060724989429478], 
             UndirectedEdge[66, 334] -> 
             RGBColor[
              0.8993269168225742, 0.8751806708122776, 0.641381959048795], 
             UndirectedEdge[17, 328] -> 
             RGBColor[
              0.7237025338495482, 0.7737395808947017, 0.6824221046621111], 
             UndirectedEdge[318, 459] -> 
             RGBColor[
              0.5950482621005162, 0.5396689752199344, 0.5911485205379887], 
             UndirectedEdge[163, 233] -> 
             RGBColor[
              0.6297764829240536, 0.6977083901022443, 0.92799335128314], 
             UndirectedEdge[141, 300] -> 
             RGBColor[
              0.6991652128626464, 0.3695793275842062, 0.4379673593539145], 
             UndirectedEdge[354, 436] -> 
             RGBColor[
              0.759379359113466, 0.8123795084379895, 0.9765634925782736], 
             UndirectedEdge[29, 290] -> 
             RGBColor[
              0.548587270277916, 0.6383261628021962, 0.9601855709712293], 
             UndirectedEdge[110, 360] -> 
             RGBColor[
              0.9463430786616113, 0.9595033364377505, 0.9757113512462205], 
             UndirectedEdge[289, 308] -> 
             RGBColor[
              0.6030902637531727, 0.6718093738393884, 0.9387961473758762], 
             UndirectedEdge[264, 324] -> 
             RGBColor[
              0.3633236151529535, 0.4853506184752032, 0.9445360679190529], 
             UndirectedEdge[109, 382] -> 
             RGBColor[
              0.9144637595402318, 0.8954066583178919, 0.6548246806539151], 
             UndirectedEdge[293, 497] -> 
             RGBColor[
              0.9437714822212449, 0.8956815982966784, 0.6342097381314926], 
             UndirectedEdge[160, 237] -> 
             RGBColor[
              0.9898092932253312, 0.9889257948329511, 0.7365489331104234], 
             UndirectedEdge[35, 123] -> 
             RGBColor[
              0.9480645730876001, 0.8192140496842684, 0.405636040260667], 
             UndirectedEdge[218, 432] -> 
             RGBColor[
              0.8571216128090124, 0.4068618534053179, 0.44014171254874046`], 
             UndirectedEdge[46, 476] -> 
             RGBColor[
              0.944135998474124, 0.7999019789306197, 0.4686120527160019], 
             UndirectedEdge[288, 391] -> 
             RGBColor[
              0.5207786932111205, 0.621535879847299, 0.9554981931814599], 
             UndirectedEdge[259, 486] -> 
             RGBColor[
              0.9058487430382465, 0.8929631838850582, 0.6605140598546992], 
             UndirectedEdge[138, 296] -> 
             RGBColor[
              0.7181040587459482, 0.7790067011897444, 0.9731572237221441], 
             UndirectedEdge[56, 494] -> 
             RGBColor[
              0.466245577902254, 0.5754589697820333, 0.9517037271222514], 
             UndirectedEdge[91, 200] -> 
             RGBColor[
              0.5849335976288481, 0.659836123396444, 0.9648356361369437], 
             UndirectedEdge[172, 493] -> 
             RGBColor[
              0.9010957800311238, 0.9102344709886591, 0.6909928662152849], 
             UndirectedEdge[340, 461] -> 
             RGBColor[
              0.8974114456586748, 0.9210355434562036, 0.9900770988872212], 
             UndirectedEdge[33, 274] -> 
             RGBColor[
              0.876424004066816, 0.41972833987279146`, 0.3285865089786305], 
             UndirectedEdge[235, 345] -> 
             RGBColor[
              0.8410817001063771, 0.8764699627956134, 0.9846113773527487], 
             UndirectedEdge[205, 490] -> 
             RGBColor[
              0.31495381596352867`, 0.44201562449401155`, 0.9414800738821197],
              UndirectedEdge[141, 284] -> 
             RGBColor[
              0.8750938156009124, 0.5102112366053225, 0.44406598160811506`], 
             UndirectedEdge[489, 500] -> 
             RGBColor[
              0.7805133637099382, 0.8281418994492827, 0.9520082709913846], 
             UndirectedEdge[155, 198] -> 
             RGBColor[
              0.8797173277504603, 0.9060753563960884, 0.946835820620141], 
             UndirectedEdge[23, 157] -> 
             RGBColor[
              0.8387124260512737, 0.874720470500097, 0.9770921142597515], 
             UndirectedEdge[248, 344] -> 
             RGBColor[
              0.6489984596245609, 0.72095630030342, 0.9685292914157689], 
             UndirectedEdge[50, 131] -> 
             RGBColor[
              0.635147229977618, 0.7016016273730713, 0.8921064613688443], 
             UndirectedEdge[442, 500] -> 
             RGBColor[
              0.776845245941039, 0.7769374528021793, 0.6272484179740978], 
             UndirectedEdge[18, 305] -> 
             RGBColor[
              0.6868687692970494, 0.6943516566248376, 0.6143551793240922], 
             UndirectedEdge[134, 278] -> 
             RGBColor[
              0.9303755352905203, 0.8254236828573013, 0.6101271768068248], 
             UndirectedEdge[158, 422] -> 
             RGBColor[
              0.8795230560917252, 0.8189745414907321, 0.6243045805426413], 
             UndirectedEdge[229, 393] -> 
             RGBColor[
              0.875983809308845, 0.41991898161920915`, 0.3629711112528449], 
             UndirectedEdge[17, 143] -> 
             RGBColor[
              0.6972283057766442, 0.7614881181939793, 0.9712212242937887], 
             UndirectedEdge[53, 83] -> 
             RGBColor[
              0.48933308130866227`, 0.5955384463857689, 0.9531521188344462], 
             UndirectedEdge[166, 239] -> 
             RGBColor[
              0.44477674338702144`, 0.5507726739308044, 0.9510125540135927], 
             UndirectedEdge[46, 194] -> 
             RGBColor[
              0.9392823824242458, 0.7851129969698264, 0.31511536801048556`], 
             UndirectedEdge[319, 368] -> 
             RGBColor[
              0.7415839485809848, 0.7980011778280107, 0.9750834020161073], 
             UndirectedEdge[51, 360] -> 
             RGBColor[
              0.6239692228057677, 0.6961194296943458, 0.9535403350355125], 
             UndirectedEdge[132, 250] -> 
             RGBColor[
              0.6613488186830774, 0.3103101701131645, 0.4320826837659827], 
             UndirectedEdge[80, 447] -> 
             RGBColor[
              0.6036878596414713, 0.6153332971682812, 0.6087268866286693], 
             UndirectedEdge[128, 179] -> 
             RGBColor[
              0.5840360505895659, 0.5648520638615654, 0.5999539562158254], 
             UndirectedEdge[218, 300] -> 
             RGBColor[
              0.6803533079788464, 0.746991633247472, 0.9701128660266232], 
             UndirectedEdge[130, 241] -> 
             RGBColor[
              0.644536063428389, 0.23327366805585842`, 0.4229244273662516], 
             UndirectedEdge[134, 252] -> 
             RGBColor[
              0.7783960467787037, 0.8269941742939715, 0.9671621739048157], 
             UndirectedEdge[266, 317] -> 
             RGBColor[
              0.2816297636550618, 0.4133411163327855, 0.9393497704550325], 
             UndirectedEdge[156, 485] -> 
             RGBColor[
              0.8409529974315038, 0.873157435386634, 0.8038822556917522], 
             UndirectedEdge[96, 110] -> 
             RGBColor[
              0.9671450279645892, 0.9716953922439107, 0.740594192587352], 
             UndirectedEdge[50, 373] -> 
             RGBColor[
              0.5693803197935527, 0.6511850336629431, 0.962783949642873], 
             UndirectedEdge[37, 322] -> 
             RGBColor[
              0.9758012436714265, 0.957362300662394, 0.6465845188350784], 
             UndirectedEdge[65, 290] -> 
             RGBColor[
              0.6407589317396863, 0.7106446122772876, 0.9376369136781462], 
             UndirectedEdge[333, 450] -> 
             RGBColor[
              0.633934256635755, 0.5960218857494932, 0.5984333090791212], 
             UndirectedEdge[238, 266] -> 
             RGBColor[
              0.6017621377736415, 0.5729348839105023, 0.5982565452180935], 
             UndirectedEdge[312, 446] -> 
             RGBColor[
              0.4813649856033654, 0.5887741844635388, 0.952606461845577], 
             UndirectedEdge[407, 448] -> 
             RGBColor[
              0.6935686506000145, 0.758683186337817, 0.9716913536551319], 
             UndirectedEdge[14, 454] -> 
             RGBColor[
              0.5785335033615582, 0.46660798581599927`, 0.5777379981249573], 
             UndirectedEdge[77, 473] -> 
             RGBColor[
              0.8111538619767299, 0.37034010790118693`, 0.4363396425602779], 
             UndirectedEdge[57, 136] -> 
             RGBColor[
              0.5204751442263853, 0.5991059937430767, 0.9601013724307705], 
             UndirectedEdge[364, 487] -> 
             RGBColor[
              0.4571102387072875, 0.5665173497908966, 0.9514059605080871], 
             UndirectedEdge[80, 403] -> 
             RGBColor[
              0.737041212361377, 0.7338026732886639, 0.6175685376485043], 
             UndirectedEdge[330, 352] -> 
             RGBColor[
              0.8837824870247553, 0.9096089736809037, 0.9653570253492985], 
             UndirectedEdge[239, 272] -> 
             RGBColor[
              0.7536163432681803, 0.3252264501125197, 0.43071759087808326`], 
             UndirectedEdge[53, 97] -> 
             RGBColor[
              0.3734152798324315, 0.497855279818339, 0.9450146693261237], 
             UndirectedEdge[304, 311] -> 
             RGBColor[
              0.8035239566132494, 0.3643795678418074, 0.4355791648991656], 
             UndirectedEdge[237, 241] -> 
             RGBColor[
              0.6464722654187021, 0.7105435264167307, 0.7629298105742092], 
             UndirectedEdge[361, 441] -> 
             RGBColor[
              0.9827681596278155, 0.9598787987151434, 0.5891007389849194], 
             UndirectedEdge[276, 347] -> 
             RGBColor[
              0.30680269050795317`, 0.4337225279441098, 0.9410058375959278], 
             UndirectedEdge[11, 180] -> 
             RGBColor[
              0.5655333839874984, 0.6581645039664907, 0.9589400060859916], 
             UndirectedEdge[56, 360] -> 
             RGBColor[
              0.7540199083275849, 0.807104457537637, 0.9625591955094939], 
             UndirectedEdge[15, 269] -> 
             RGBColor[
              0.7879511852838504, 0.3635107291676696, 0.4354305624412115], 
             UndirectedEdge[8, 387] -> 
             RGBColor[
              0.7423003511533307, 0.4108938391546379, 0.4419533248922598], 
             UndirectedEdge[139, 278] -> 
             RGBColor[
              0.9266932866258935, 0.7470703400254518, 0.25987390157071855`], 
             UndirectedEdge[15, 449] -> 
             RGBColor[
              0.6302820769464065, 0.22914707799430184`, 0.4235861217718264], 
             UndirectedEdge[348, 355] -> 
             RGBColor[
              0.4637270742767172, 0.5684992963169887, 0.952308710465833], 
             UndirectedEdge[173, 499] -> 
             RGBColor[
              0.2641146914249929, 0.39493166489926307`, 0.9383523130027576], 
             UndirectedEdge[130, 483] -> 
             RGBColor[
              0.6996147451039898, 0.2813855199785559, 0.4264663872562261], 
             UndirectedEdge[173, 282] -> 
             RGBColor[
              0.6210629328864492, 0.6875393001264591, 0.9106368543138041], 
             UndirectedEdge[84, 244] -> 
             RGBColor[
              0.8410713594730532, 0.39408148714968966`, 0.43922345789083017`],
              UndirectedEdge[183, 279] -> 
             RGBColor[
              0.38220271033147407`, 0.5054665104475107, 0.945574596627103], 
             UndirectedEdge[124, 381] -> 
             RGBColor[
              0.5621936039844737, 0.6471476163793806, 0.9618419850894344], 
             UndirectedEdge[81, 213] -> 
             RGBColor[
              0.746427631578612, 0.8018342059401061, 0.9753605886191006], 
             UndirectedEdge[134, 210] -> 
             RGBColor[
              0.6158462128044627, 0.6880441478962616, 0.9557287489078166], 
             UndirectedEdge[103, 275] -> 
             RGBColor[
              0.921431863320548, 0.9351107287270387, 0.7188532581164437], 
             UndirectedEdge[256, 298] -> 
             RGBColor[
              0.8014952422393229, 0.841797515955063, 0.7989083483735286], 
             UndirectedEdge[18, 235] -> 
             RGBColor[
              0.5989385163825915, 0.6823556616983519, 0.9632170834477687], 
             UndirectedEdge[255, 334] -> 
             RGBColor[
              0.8814255503736415, 0.908288824481486, 0.9885523499241574], 
             UndirectedEdge[209, 372] -> 
             RGBColor[
              0.7566845744579053, 0.32771737841457826`, 0.4309591332766395], 
             UndirectedEdge[112, 238] -> 
             RGBColor[
              0.9383531192478518, 0.8494088377938813, 0.6106160598221919], 
             UndirectedEdge[360, 457] -> 
             RGBColor[
              0.9271455447623782, 0.8073116722640878, 0.603722217054588], 
             UndirectedEdge[233, 404] -> 
             RGBColor[
              0.9291234571186902, 0.7601657274591248, 0.5679961480033187], 
             UndirectedEdge[259, 348] -> 
             RGBColor[
              0.8069195994950129, 0.8154998761774673, 0.6507012573619819], 
             UndirectedEdge[244, 376] -> 
             RGBColor[
              0.9414515015097245, 0.9521323258710117, 0.8065666552280624], 
             UndirectedEdge[182, 371] -> 
             RGBColor[
              0.6377108709522905, 0.6711744236866504, 0.6340025683126485], 
             UndirectedEdge[21, 77] -> 
             RGBColor[
              0.8807226750173074, 0.9072051385453304, 0.9643693553167552], 
             UndirectedEdge[153, 493] -> 
             RGBColor[
              0.563379941151674, 0.6498724084083345, 0.9616641568617563], 
             UndirectedEdge[276, 382] -> 
             RGBColor[
              0.6186417168240443, 0.6961085373443454, 0.9659294414149144], 
             UndirectedEdge[80, 219] -> 
             RGBColor[
              0.8783761594823322, 0.8460440377561369, 0.6304046933244128], 
             UndirectedEdge[60, 136] -> 
             RGBColor[
              0.5725959949248469, 0.6538883124799618, 0.9630695777721592], 
             UndirectedEdge[23, 96] -> 
             RGBColor[
              0.8634146844884865, 0.8898213704723994, 0.7353727496001656], 
             UndirectedEdge[53, 281] -> 
             RGBColor[
              0.5131860224428482, 0.6149033385612535, 0.9550299097367316], 
             UndirectedEdge[141, 162] -> 
             RGBColor[
              0.7184499411343216, 0.3857666064451054, 0.4393387882226608], 
             UndirectedEdge[28, 149] -> 
             RGBColor[
              0.9453970528108677, 0.958797791907241, 0.9773127262484711], 
             UndirectedEdge[37, 317] -> 
             RGBColor[
              0.6288727104349323, 0.6977592885001335, 0.9336782862741432], 
             UndirectedEdge[372, 486] -> 
             RGBColor[
              0.738779728808347, 0.7959323529095619, 0.974623507532121], 
             UndirectedEdge[63, 453] -> 
             RGBColor[
              0.8160983400103966, 0.5332707552791112, 0.45659563545318593`], 
             UndirectedEdge[82, 242] -> 
             RGBColor[
              0.3957134769484411, 0.5115568796501833, 0.9470940440164037], 
             UndirectedEdge[4, 191] -> 
             RGBColor[
              0.6635745796988659, 0.5752663277189047, 0.5899282158592782], 
             UndirectedEdge[70, 403] -> 
             RGBColor[
              0.5830236114965972, 0.6723523139442866, 0.960324793997646], 
             UndirectedEdge[144, 458] -> 
             RGBColor[
              0.5823269492619052, 0.6680241846495292, 0.9621346416509355], 
             UndirectedEdge[16, 224] -> 
             RGBColor[
              0.33121988179707923`, 0.45899663193251833`, 0.9424106371133667],
              UndirectedEdge[40, 206] -> 
             RGBColor[
              0.5675738763172529, 0.6547956874923582, 0.9613851039193536], 
             UndirectedEdge[148, 485] -> 
             RGBColor[
              0.5863590046161666, 0.6743809915317008, 0.9610517033741575], 
             UndirectedEdge[34, 291] -> 
             RGBColor[
              0.5173818849929921, 0.6142724185972134, 0.9569381184078065], 
             UndirectedEdge[222, 339] -> 
             RGBColor[
              0.8754830747735829, 0.4197119150205878, 0.37126957836157426`], 
             UndirectedEdge[197, 314] -> 
             RGBColor[
              0.6683990852722341, 0.7366374863757077, 0.9693511535264618], 
             UndirectedEdge[330, 358] -> 
             RGBColor[
              0.917643669695722, 0.9364935495529919, 0.9686173619908074], 
             UndirectedEdge[312, 415] -> 
             RGBColor[
              0.7566534221816719, 0.808801513512907, 0.9509396521448775], 
             UndirectedEdge[370, 443] -> 
             RGBColor[
              0.8869753034817456, 0.7554947353353427, 0.6100790076689913], 
             UndirectedEdge[160, 305] -> 
             RGBColor[
              0.9690788096209066, 0.9188849604132443, 0.5841124382950643], 
             UndirectedEdge[266, 343] -> 
             RGBColor[
              0.5184681045815127, 0.6108481139576518, 0.9578305314867752], 
             UndirectedEdge[47, 468] -> 
             RGBColor[
              0.6259733626488723, 0.6895685436074106, 0.8188305470948625], 
             UndirectedEdge[388, 436] -> 
             RGBColor[
              0.8162339251390927, 0.8545672227768843, 0.8562966696435661], 
             UndirectedEdge[69, 209] -> 
             RGBColor[
              0.8729477187093619, 0.41866348013235355`, 0.4132869896368825], 
             UndirectedEdge[197, 470] -> 
             RGBColor[
              0.6782364440391435, 0.26306580417848735`, 0.42504972313556744`],
              UndirectedEdge[13, 298] -> 
             RGBColor[
              0.747731689982734, 0.3204490234747849, 0.43025432941525754`], 
             UndirectedEdge[168, 383] -> 
             RGBColor[
              0.5129726108594084, 0.605200612569069, 0.9574972102487445], 
             UndirectedEdge[123, 428] -> 
             RGBColor[
              0.9462677211119872, 0.9556472292192797, 0.7806464768801612], 
             UndirectedEdge[137, 485] -> 
             RGBColor[
              0.7740283069991141, 0.34133734218800504`, 0.43263931419814583`],
              UndirectedEdge[394, 467] -> 
             RGBColor[
              0.919111821471869, 0.7025214164538409, 0.27477507208062973`], 
             UndirectedEdge[232, 395] -> 
             RGBColor[
              0.6631089411790467, 0.7275769982174726, 0.8677050692774182], 
             UndirectedEdge[414, 461] -> 
             RGBColor[
              0.9247878189999204, 0.9427209702834463, 0.9877043734174824], 
             UndirectedEdge[224, 333] -> 
             RGBColor[
              0.6486645999410916, 0.608780568751994, 0.5993719135290061], 
             UndirectedEdge[33, 182] -> 
             RGBColor[
              0.9809251528499161, 0.9460030104953818, 0.492232723587419], 
             UndirectedEdge[158, 451] -> 
             RGBColor[
              0.5952369139026761, 0.5808151647073923, 0.6016671192658072], 
             UndirectedEdge[235, 274] -> 
             RGBColor[
              0.8037636225048241, 0.36456679665783387`, 0.43560305255543275`],
              UndirectedEdge[284, 345] -> 
             RGBColor[
              0.9286380592218676, 0.9455204844800323, 0.9786910291044129], 
             UndirectedEdge[70, 238] -> 
             RGBColor[
              0.7832730394723132, 0.7276349567871978, 0.6111570374677537], 
             UndirectedEdge[21, 55] -> 
             RGBColor[
              0.7305022611479528, 0.7876462771155825, 0.9509047228975792], 
             UndirectedEdge[55, 60] -> 
             RGBColor[
              0.3907757297942019, 0.5093036191589176, 0.9465455367626295], 
             UndirectedEdge[219, 258] -> 
             RGBColor[
              0.8487759218073938, 0.7251518095257203, 0.6064046742034], 
             UndirectedEdge[175, 463] -> 
             RGBColor[
              0.4532997133579424, 0.5668744607006588, 0.9501525524068308], 
             UndirectedEdge[101, 431] -> 
             RGBColor[
              0.9942002261874912, 0.9900031951991536, 0.6101085964425267], 
             UndirectedEdge[14, 213] -> 
             RGBColor[
              0.8459475896663211, 0.6879226480010172, 0.5992786660990652], 
             UndirectedEdge[378, 487] -> 
             RGBColor[
              0.631951455962078, 0.7046266630330056, 0.9605821148543219], 
             UndirectedEdge[8, 159] -> 
             RGBColor[
              0.44350440418971177`, 0.5559141999747581, 0.9502125456878299], 
             UndirectedEdge[311, 469] -> 
             RGBColor[
              0.6753108002869803, 0.7452405592897584, 0.9689810822464335], 
             UndirectedEdge[343, 440] -> 
             RGBColor[
              0.7301836574927166, 0.7891442899254291, 0.973741541090787], 
             UndirectedEdge[371, 460] -> 
             RGBColor[
              0.6475082324090988, 0.7150439382966693, 0.9045511683128595], 
             UndirectedEdge[224, 358] -> 
             RGBColor[
              0.6260588970956099, 0.702167819699657, 0.9665701361126506], 
             UndirectedEdge[455, 475] -> 
             RGBColor[
              0.42511567187195953`, 0.5335102609549496, 0.9495831574616309], 
             UndirectedEdge[310, 408] -> 
             RGBColor[
              0.6292485209647104, 0.7024964810849892, 0.9634887902017777], 
             UndirectedEdge[154, 376] -> 
             RGBColor[
              0.9945577005984159, 0.9911935528413258, 0.6799654483882758], 
             UndirectedEdge[282, 499] -> 
             RGBColor[
              0.6289497360686029, 0.6958288303231062, 0.911085996087548], 
             UndirectedEdge[14, 192] -> 
             RGBColor[
              0.8990321129806953, 0.6284995846853377, 0.23715650730552826`], 
             UndirectedEdge[75, 147] -> 
             RGBColor[
              0.6086391829442732, 0.6714150439579957, 0.824425819881278], 
             UndirectedEdge[175, 351] -> 
             RGBColor[
              0.33790224516407974`, 0.4597118388674644, 0.9430221685394126], 
             UndirectedEdge[109, 205] -> 
             RGBColor[
              0.6717784040512281, 0.6993543578709756, 0.6340718240314804], 
             UndirectedEdge[43, 148] -> 
             RGBColor[
              0.7324469572796468, 0.48547752536775757`, 0.45173540919323685`],
              UndirectedEdge[56, 92] -> 
             RGBColor[
              0.6584314243234879, 0.7317754325796877, 0.9674893413358401], 
             UndirectedEdge[46, 412] -> 
             RGBColor[
              0.7205166023314513, 0.6258676726255041, 0.5950724764547066], 
             UndirectedEdge[170, 214] -> 
             RGBColor[
              0.9101579806891951, 0.9307913476043524, 0.9771494467269913], 
             UndirectedEdge[94, 437] -> 
             RGBColor[
              0.7197274553471891, 0.7766775854515797, 0.8735355607388426], 
             UndirectedEdge[173, 249] -> 
             RGBColor[
              0.5219476056882162, 0.610346550559369, 0.9586870734477428], 
             UndirectedEdge[181, 302] -> 
             RGBColor[
              0.941856665288074, 0.955354724158507, 0.9554772117223265], 
             UndirectedEdge[188, 279] -> 
             RGBColor[
              0.6854401403029702, 0.6409469431980064, 0.6017901214103797], 
             UndirectedEdge[317, 471] -> 
             RGBColor[
              0.6192757488589464, 0.6906018902703456, 0.9499234389338337], 
             UndirectedEdge[8, 344] -> 
             RGBColor[
              0.7278604047821258, 0.7866137969022513, 0.9742861641613685], 
             UndirectedEdge[236, 493] -> 
             RGBColor[
              0.7983472181009972, 0.842394181534866, 0.9805354477875302], 
             UndirectedEdge[31, 366] -> 
             RGBColor[
              0.5383991611621235, 0.6361357194940431, 0.9568039006692448], 
             UndirectedEdge[176, 261] -> 
             RGBColor[
              0.7026952552747832, 0.7656613514335006, 0.9645417220580014], 
             UndirectedEdge[144, 145] -> 
             RGBColor[
              0.8714653296827535, 0.8634058015965719, 0.6534579873706815], 
             UndirectedEdge[144, 375] -> 
             RGBColor[
              0.8137595315298665, 0.8546947839316693, 0.9820025047134087], 
             UndirectedEdge[258, 293] -> 
             RGBColor[
              0.9149083728771513, 0.7777118382646067, 0.6108028297681034], 
             UndirectedEdge[242, 269] -> 
             RGBColor[
              0.6236211244294272, 0.7040673995999395, 0.964371174681462], 
             UndirectedEdge[45, 216] -> 
             RGBColor[
              0.5589768120219564, 0.6497056559358416, 0.9598400030616046], 
             UndirectedEdge[82, 323] -> 
             RGBColor[
              0.6343767867380772, 0.22259562411899508`, 0.4223458715880414], 
             UndirectedEdge[258, 272] -> 
             RGBColor[
              0.8421951185634089, 0.29016466772437105`, 0.18666218792876652`],
              UndirectedEdge[92, 356] -> 
             RGBColor[
              0.5331338276085699, 0.6257862024356838, 0.958741162237847], 
             UndirectedEdge[114, 327] -> 
             RGBColor[
              0.6500626657186896, 0.7256542507562918, 0.9663704200739318], 
             UndirectedEdge[188, 459] -> 
             RGBColor[
              0.9121417349282877, 0.6893782865615941, 0.24816538150600656`], 
             UndirectedEdge[465, 469] -> 
             RGBColor[
              0.7822828881805095, 0.8278393705227431, 0.8885355893724022], 
             UndirectedEdge[44, 62] -> 
             RGBColor[
              0.7433493672771379, 0.798879371148496, 0.9734599468450111], 
             UndirectedEdge[88, 337] -> 
             RGBColor[
              0.7885232404829162, 0.8355013410288112, 0.9756157096171126], 
             UndirectedEdge[253, 388] -> 
             RGBColor[
              0.9529652271475403, 0.8400371300174836, 0.49792764080552343`], 
             UndirectedEdge[80, 238] -> 
             RGBColor[
              0.9372906403370931, 0.7890853161315752, 0.268400781118612], 
             UndirectedEdge[171, 272] -> 
             RGBColor[
              0.8549188354512484, 0.40512308861498036`, 0.4405442425114182], 
             UndirectedEdge[297, 392] -> 
             RGBColor[
              0.5242685537534698, 0.6246638558230888, 0.9556914874919151], 
             UndirectedEdge[82, 499] -> 
             RGBColor[
              0.27024692741068906`, 0.4013770337264476, 0.9387015347703127], 
             UndirectedEdge[297, 484] -> 
             RGBColor[
              0.7896873349656177, 0.832820068248294, 0.846036803358591], 
             UndirectedEdge[73, 240] -> 
             RGBColor[
              0.8783138897959549, 0.8847796038378835, 0.6775399509090155], 
             UndirectedEdge[229, 263] -> 
             RGBColor[
              0.9094044621171705, 0.9275973312039452, 0.8718475125982721], 
             UndirectedEdge[87, 91] -> 
             RGBColor[
              0.6235757971966955, 0.6868448794558504, 0.7983263007427286], 
             UndirectedEdge[296, 339] -> 
             RGBColor[
              0.7364419102447375, 0.31128347168469817`, 0.42936555659845665`],
              UndirectedEdge[62, 157] -> 
             RGBColor[
              0.7460767870870211, 0.800913476376967, 0.9688431365318922], 
             UndirectedEdge[227, 265] -> 
             RGBColor[
              0.8234605488149223, 0.8622667951051604, 0.9829711356282687], 
             UndirectedEdge[38, 127] -> 
             RGBColor[
              0.6556975536814259, 0.7215165865921992, 0.8804264742511925], 
             UndirectedEdge[302, 451] -> 
             RGBColor[
              0.6180317459573728, 0.6856681997339282, 0.9290685065850387], 
             UndirectedEdge[141, 151] -> 
             RGBColor[
              0.8749172497117169, 0.5100795540542606, 0.4443648616027639], 
             UndirectedEdge[72, 439] -> 
             RGBColor[
              0.46832895938122665`, 0.5716092852844473, 0.9528441721025609], 
             UndirectedEdge[277, 340] -> 
             RGBColor[
              0.6721000346952584, 0.7414776571696646, 0.9697438365812487], 
             UndirectedEdge[53, 322] -> 
             RGBColor[
              0.7011174975670245, 0.7384406278212419, 0.6567824048307651], 
             UndirectedEdge[450, 461] -> 
             RGBColor[
              0.628765969521808, 0.703313258675441, 0.9672947279418043], 
             UndirectedEdge[352, 367] -> 
             RGBColor[
              0.819582490200417, 0.8590922590369281, 0.9826230768267663], 
             UndirectedEdge[239, 251] -> 
             RGBColor[
              0.8106809990461303, 0.849731043377165, 0.8386538896932675], 
             UndirectedEdge[83, 163] -> 
             RGBColor[
              0.4159380608919135, 0.5291634475174551, 0.9485781183218674], 
             UndirectedEdge[179, 245] -> 
             RGBColor[
              0.6017107049913992, 0.6705157878935142, 0.9396141233675497], 
             UndirectedEdge[133, 237] -> 
             RGBColor[
              0.975612874836955, 0.9284905775830683, 0.43697628259585786`], 
             UndirectedEdge[199, 244] -> 
             RGBColor[
              0.6330077905850533, 0.7076656604480505, 0.9672527314622508], 
             UndirectedEdge[173, 269] -> 
             RGBColor[
              0.4902677717095214, 0.5855980234795568, 0.9555295236616271], 
             UndirectedEdge[209, 379] -> 
             RGBColor[
              0.7256717020027846, 0.3025397314415287, 0.4285176863530774], 
             UndirectedEdge[139, 451] -> 
             RGBColor[
              0.5990412194062282, 0.5958979683193184, 0.6047281527724926], 
             UndirectedEdge[18, 218] -> 
             RGBColor[
              0.6789755018388739, 0.7457982468195781, 0.9700250734377303], 
             UndirectedEdge[59, 287] -> 
             RGBColor[
              0.8973994964470094, 0.9171109537347721, 0.7980614960303913], 
             UndirectedEdge[167, 274] -> 
             RGBColor[
              0.8510922483010481, 0.3277969220372233, 0.193943009412067], 
             UndirectedEdge[402, 461] -> 
             RGBColor[
              0.6714213084011029, 0.7402591692930169, 0.9700126884165579], 
             UndirectedEdge[472, 488] -> 
             RGBColor[
              0.5715842104454968, 0.6512199184820984, 0.9632550961678262], 
             UndirectedEdge[227, 270] -> 
             RGBColor[
              0.6207483373543288, 0.6983257149021173, 0.9658829708739471], 
             UndirectedEdge[124, 363] -> 
             RGBColor[
              0.5797741468412164, 0.6636071744020012, 0.9629170857561735], 
             UndirectedEdge[118, 195] -> 
             RGBColor[
              0.4688113045682638, 0.5786975878052025, 0.9515864022204936], 
             UndirectedEdge[54, 154] -> 
             RGBColor[
              0.9937885553030565, 0.9895484288270704, 0.5962487296029566], 
             UndirectedEdge[313, 498] -> 
             RGBColor[
              0.9220282069947828, 0.7285748538337302, 0.256120268996034], 
             UndirectedEdge[243, 283] -> 
             RGBColor[
              0.9146114776424249, 0.7402006091493263, 0.5864731868864135], 
             UndirectedEdge[302, 346] -> 
             RGBColor[
              0.9122571289122567, 0.9317528573104414, 0.952653981518983], 
             UndirectedEdge[13, 477] -> 
             RGBColor[
              0.6296325567484244, 0.21760913759831518`, 0.42207569470858985`],
              UndirectedEdge[140, 479] -> 
             RGBColor[
              0.8318807792749092, 0.24332966199043837`, 0.17805565039885107`],
              UndirectedEdge[174, 309] -> 
             RGBColor[
              0.6109358203245405, 0.69090470207287, 0.9647614190524889], 
             UndirectedEdge[299, 312] -> 
             RGBColor[
              0.7447508465266021, 0.7242245377107945, 0.6145291491238181], 
             UndirectedEdge[215, 402] -> 
             RGBColor[
              0.42053904055083435`, 0.5386715128435384, 0.9480173536891949], 
             UndirectedEdge[372, 400] -> 
             RGBColor[
              0.8003264633279119, 0.8442463394435811, 0.9540849632352826], 
             UndirectedEdge[29, 426] -> 
             RGBColor[
              0.5771973199190499, 0.6631067498184402, 0.9620085780354888], 
             UndirectedEdge[361, 481] -> 
             RGBColor[
              0.7750733921884547, 0.8219946864903404, 0.8883154052377202], 
             UndirectedEdge[188, 335] -> 
             RGBColor[
              0.6674373378797184, 0.6253538205861451, 0.6006429987592232], 
             UndirectedEdge[168, 443] -> 
             RGBColor[
              0.5760281362438697, 0.6549613467587179, 0.9636489718254899], 
             UndirectedEdge[81, 500] -> 
             RGBColor[
              0.6347418419635744, 0.7138620929268963, 0.9647226506412933], 
             UndirectedEdge[75, 310] -> 
             RGBColor[
              0.9678530213393162, 0.9736072087290149, 0.8491940530567016], 
             UndirectedEdge[348, 444] -> 
             RGBColor[
              0.5297647651730107, 0.6280626210348309, 0.9564299869685835], 
             UndirectedEdge[262, 482] -> 
             RGBColor[
              0.8707565984019038, 0.8997816917802087, 0.9875347357608073], 
             UndirectedEdge[83, 395] -> 
             RGBColor[
              0.44415745762518294`, 0.5564095917440058, 0.9502735680405704], 
             UndirectedEdge[26, 459] -> 
             RGBColor[
              0.9295103312405606, 0.7582389831981371, 0.2621405617922154], 
             UndirectedEdge[186, 498] -> 
             RGBColor[
              0.9616348296448587, 0.8731243456999658, 0.44321008611118523`], 
             UndirectedEdge[167, 284] -> 
             RGBColor[
              0.9352021653242989, 0.8393420997270047, 0.6099627447029139], 
             UndirectedEdge[175, 359] -> 
             RGBColor[
              0.35192210906620386`, 0.47444760473930936`, 0.9438205790481085],
              UndirectedEdge[65, 484] -> 
             RGBColor[
              0.9829428130095716, 0.9849950154953435, 0.8329553865176191], 
             UndirectedEdge[266, 322] -> 
             RGBColor[
              0.628558296891556, 0.6729441284950459, 0.6522560030159678], 
             UndirectedEdge[210, 252] -> 
             RGBColor[
              0.44571853537116424`, 0.5539086638714803, 0.9508708356797764], 
             UndirectedEdge[133, 271] -> 
             RGBColor[
              0.9478234405179078, 0.9105185654193753, 0.638797401271959], 
             UndirectedEdge[190, 467] -> 
             RGBColor[
              0.9387724597066944, 0.7908248659507089, 0.2911301660265061], 
             UndirectedEdge[216, 481] -> 
             RGBColor[
              0.47391326894027075`, 0.5819964906165944, 0.9522209990585477], 
             UndirectedEdge[18, 406] -> 
             RGBColor[
              0.35762120815894227`, 0.4828135677507933, 0.9440581428576333], 
             UndirectedEdge[315, 364] -> 
             RGBColor[
              0.7743508103070922, 0.8235187646207383, 0.9617126695367028], 
             UndirectedEdge[152, 464] -> 
             RGBColor[
              0.7229601204075975, 0.781798896899757, 0.957704809927109], 
             UndirectedEdge[229, 280] -> 
             RGBColor[
              0.966140154058146, 0.8936169967155985, 0.5151134284045032], 
             UndirectedEdge[164, 259] -> 
             RGBColor[
              0.6136747690749169, 0.6486249460915254, 0.6371074825899379], 
             UndirectedEdge[238, 497] -> 
             RGBColor[
              0.9365535120062483, 0.7861628479332302, 0.2678076703609884], 
             UndirectedEdge[7, 478] -> 
             RGBColor[
              0.5764997887526195, 0.6605614646974819, 0.9628049485951897], 
             UndirectedEdge[137, 227] -> 
             RGBColor[
              0.8286778864324563, 0.3841992681589815, 0.4380413573684341], 
             UndirectedEdge[44, 157] -> 
             RGBColor[
              0.941025949542359, 0.955537830246612, 0.9847118639157386], 
             UndirectedEdge[105, 205] -> 
             RGBColor[
              0.37726127771437656`, 0.5011864898782057, 0.945259732910279], 
             UndirectedEdge[305, 460] -> 
             RGBColor[
              0.9696621948781944, 0.9191262052094501, 0.574444234829157], 
             UndirectedEdge[330, 492] -> 
             RGBColor[
              0.8654993333930877, 0.4131099436996627, 0.4259604168593749], 
             UndirectedEdge[94, 123] -> 
             RGBColor[
              0.9924672274869801, 0.9899105576898775, 0.6841872270978527], 
             UndirectedEdge[418, 444] -> 
             RGBColor[
              0.6832940277298368, 0.26744642896981824`, 0.42537198789609276`],
              UndirectedEdge[203, 295] -> 
             RGBColor[
              0.6559729142487456, 0.7230333134070894, 0.9270930055327178], 
             UndirectedEdge[342, 485] -> 
             RGBColor[
              0.48530781119713273`, 0.5853583320188928, 0.9544596766386073], 
             UndirectedEdge[279, 430] -> 
             RGBColor[
              0.6988201531297954, 0.7624526797406539, 0.9634960415041477], 
             UndirectedEdge[391, 448] -> 
             RGBColor[
              0.6799461427415335, 0.7473290708002318, 0.9707003802308407], 
             UndirectedEdge[174, 252] -> 
             RGBColor[
              0.5050474456774257, 0.6076611800353535, 0.9545646346156718], 
             UndirectedEdge[14, 489] -> 
             RGBColor[
              0.9195692617666513, 0.7458384436207555, 0.5793730637151193], 
             UndirectedEdge[6, 158] -> 
             RGBColor[
              0.9088191627900012, 0.6704042759247217, 0.24519187608270565`], 
             UndirectedEdge[201, 493] -> 
             RGBColor[
              0.8974845662708025, 0.9200156873088683, 0.9516656063232447], 
             UndirectedEdge[66, 446] -> 
             RGBColor[
              0.6870571084189656, 0.7046495006727167, 0.6229461588097658], 
             UndirectedEdge[449, 499] -> 
             RGBColor[
              0.2616509123855092, 0.3923420769161522, 0.9382120044312934], 
             UndirectedEdge[202, 477] -> 
             RGBColor[
              0.5167752910483158, 0.606040331527151, 0.9582135886988215], 
             UndirectedEdge[89, 299] -> 
             RGBColor[
              0.9538166518487725, 0.889377060716642, 0.6065020823442426], 
             UndirectedEdge[57, 91] -> 
             RGBColor[
              0.21571476629312095`, 0.3440602748531707, 0.9355960088677702], 
             UndirectedEdge[222, 438] -> 
             RGBColor[
              0.7073783284658749, 0.7658187768795182, 0.8667717109740514], 
             UndirectedEdge[83, 346] -> 
             RGBColor[
              0.6994154565963315, 0.7639512890319775, 0.9715515112821198], 
             UndirectedEdge[38, 388] -> 
             RGBColor[
              0.9919225421157429, 0.9909277778307302, 0.7835279111404516], 
             UndirectedEdge[345, 472] -> 
             RGBColor[
              0.8900932966875219, 0.9152002501124683, 0.9893790873053638], 
             UndirectedEdge[231, 486] -> 
             RGBColor[
              0.7721846866340702, 0.8221349219925771, 0.9778802811634009], 
             UndirectedEdge[14, 251] -> 
             RGBColor[
              0.9342343331978582, 0.7548419077880255, 0.464798263798639], 
             UndirectedEdge[404, 418] -> 
             RGBColor[
              0.8372503782733043, 0.2677117569404419, 0.1825361754240275], 
             UndirectedEdge[10, 370] -> 
             RGBColor[
              0.6235901143286923, 0.5421732980195466, 0.5877033331125195], 
             UndirectedEdge[216, 224] -> 
             RGBColor[
              0.38310326540685025`, 0.5062465259905873, 0.9456319792001764], 
             UndirectedEdge[116, 143] -> 
             RGBColor[
              0.6166423970679169, 0.6906815764496288, 0.9660945232772165], 
             UndirectedEdge[142, 477] -> 
             RGBColor[
              0.6296325567484244, 0.21760913759831518`, 0.42207569470858985`],
              UndirectedEdge[1, 378] -> 
             RGBColor[
              0.9496746984552256, 0.9619880530248013, 0.9700717879612388], 
             UndirectedEdge[47, 298] -> 
             RGBColor[
              0.8017902916581193, 0.8424285968277965, 0.8310226567755782], 
             UndirectedEdge[50, 340] -> 
             RGBColor[
              0.584296063245159, 0.6630784426141837, 0.9642066265687285], 
             UndirectedEdge[144, 417] -> 
             RGBColor[
              0.8033191829475939, 0.36421959709785984`, 0.43555875497389185`],
              UndirectedEdge[326, 395] -> 
             RGBColor[
              0.6226985400001213, 0.6979810316650692, 0.9669435292782267], 
             UndirectedEdge[14, 166] -> 
             RGBColor[
              0.5683300775387493, 0.45588353834166495`, 0.5771569281189641], 
             UndirectedEdge[41, 132] -> 
             RGBColor[
              0.7413404650540569, 0.3776245529654416, 0.4377240972812927], 
             UndirectedEdge[6, 35] -> 
             RGBColor[
              0.8931875397103566, 0.6078713891561862, 0.23258540373238806`], 
             UndirectedEdge[95, 286] -> 
             RGBColor[
              0.9881000076961508, 0.971374405244888, 0.4207087678715801], 
             UndirectedEdge[435, 439] -> 
             RGBColor[
              0.5327966598395489, 0.6301451269006912, 0.9568532407395003], 
             UndirectedEdge[354, 388] -> 
             RGBColor[
              0.9372167432437333, 0.9496286339306528, 0.8681841015085906], 
             UndirectedEdge[47, 59] -> 
             RGBColor[
              0.9946360298549641, 0.9909353351773686, 0.6575431361784839], 
             UndirectedEdge[305, 493] -> 
             RGBColor[
              0.8844107664655321, 0.8529318926794717, 0.6314874879996633], 
             UndirectedEdge[26, 335] -> 
             RGBColor[
              0.6848059341919914, 0.6942145172226881, 0.6146181790454321], 
             UndirectedEdge[24, 115] -> 
             RGBColor[
              0.7614179921907902, 0.8090455933156716, 0.7780987151376969], 
             UndirectedEdge[271, 351] -> 
             RGBColor[
              0.5836394780198011, 0.6557387282891967, 0.9627552621344078], 
             UndirectedEdge[12, 40] -> 
             RGBColor[
              0.6710872125534979, 0.7321123322464503, 0.7084606001662512], 
             UndirectedEdge[228, 468] -> 
             RGBColor[
              0.5953977004800142, 0.5814526299075873, 0.6017964919200796], 
             UndirectedEdge[1, 108] -> 
             RGBColor[
              0.9745842865208124, 0.9789549743927156, 0.8557800079024303], 
             UndirectedEdge[97, 343] -> 
             RGBColor[
              0.5392333578252755, 0.6314832992579945, 0.9590566687708137], 
             UndirectedEdge[314, 411] -> 
             RGBColor[
              0.8276721557816176, 0.8662201295079066, 0.9822889347862443], 
             UndirectedEdge[211, 466] -> 
             RGBColor[
              0.914921788406915, 0.7377970834514196, 0.5841932296356048], 
             UndirectedEdge[12, 202] -> 
             RGBColor[
              0.8861177842949943, 0.9074124546824703, 0.726041851841167], 
             UndirectedEdge[96, 360] -> 
             RGBColor[
              0.9723559369236896, 0.9755816796135273, 0.7317734829423166], 
             UndirectedEdge[199, 482] -> 
             RGBColor[
              0.6448658970317807, 0.7171209926489461, 0.9683837682409964], 
             UndirectedEdge[9, 357] -> 
             RGBColor[
              0.8519796899593666, 0.8839932995241959, 0.9251369834767771], 
             UndirectedEdge[330, 441] -> 
             RGBColor[
              0.9687799985519323, 0.9503841780964633, 0.6547723783055386], 
             UndirectedEdge[375, 461] -> 
             RGBColor[
              0.8802508424461009, 0.9073521442666623, 0.9884403052333545], 
             UndirectedEdge[170, 268] -> 
             RGBColor[
              0.855495699155939, 0.8876942153888208, 0.971805920782477], 
             UndirectedEdge[66, 245] -> 
             RGBColor[
              0.9629040085137968, 0.9250933308983089, 0.6203340160462028], 
             UndirectedEdge[235, 308] -> 
             RGBColor[
              0.5078925143056222, 0.5970599157569475, 0.9576513762626025], 
             UndirectedEdge[42, 315] -> 
             RGBColor[
              0.9540159239785978, 0.9098264822102292, 0.621915168469849], 
             UndirectedEdge[238, 403] -> 
             RGBColor[
              0.7231840216583667, 0.6788635297862927, 0.6064187167387911], 
             UndirectedEdge[382, 425] -> 
             RGBColor[
              0.8624304900152295, 0.8931426789588661, 0.9867405841100816], 
             UndirectedEdge[74, 215] -> 
             RGBColor[
              0.5096547547371848, 0.6115295188493075, 0.9548919948031211], 
             UndirectedEdge[350, 426] -> 
             RGBColor[
              0.6774318998519623, 0.3300097205622236, 0.433863606723485], 
             UndirectedEdge[78, 497] -> 
             RGBColor[
              0.9249284802790488, 0.8807126684112958, 0.6343529347808667], 
             UndirectedEdge[109, 490] -> 
             RGBColor[
              0.60929271726381, 0.6400291229179552, 0.6302808086615892], 
             UndirectedEdge[281, 317] -> 
             RGBColor[
              0.4421657595092411, 0.5510243603760425, 0.9505911481496789], 
             UndirectedEdge[219, 471] -> 
             RGBColor[
              0.8804936421227654, 0.9071543794726241, 0.9708341259026954], 
             UndirectedEdge[183, 243] -> 
             RGBColor[
              0.5923305987494039, 0.47899065848978145`, 0.5781384620569947], 
             UndirectedEdge[93, 151] -> 
             RGBColor[
              0.952915607315721, 0.9644051175464576, 0.9645857746248268], 
             UndirectedEdge[176, 478] -> 
             RGBColor[
              0.8899090087285919, 0.9148198012121614, 0.9812658251111468], 
             UndirectedEdge[28, 282] -> 
             RGBColor[
              0.968900913114835, 0.9760435075887338, 0.9248344777257933], 
             UndirectedEdge[125, 305] -> 
             RGBColor[
              0.7558680038071321, 0.7512397664384872, 0.6195462750851033], 
             UndirectedEdge[22, 466] -> 
             RGBColor[
              0.5912351595973472, 0.47549045260162615`, 0.5775335388270659], 
             UndirectedEdge[78, 154] -> 
             RGBColor[
              0.9474859313881132, 0.9576793644875163, 0.8631867245207864], 
             UndirectedEdge[273, 421] -> 
             RGBColor[
              0.8953401320524106, 0.9186139355818647, 0.9631831993085855], 
             UndirectedEdge[221, 234] -> 
             RGBColor[
              0.8812898305212544, 0.9081673881043556, 0.9880811613933046], 
             UndirectedEdge[384, 461] -> 
             RGBColor[
              0.8943321739466785, 0.9185802157776617, 0.9897833952024326], 
             UndirectedEdge[3, 428] -> 
             RGBColor[
              0.7755408993703425, 0.8252138929344455, 0.9780935042165266], 
             UndirectedEdge[209, 431] -> 
             RGBColor[
              0.8760292963773457, 0.4188841000360836, 0.2856250128333002], 
             UndirectedEdge[33, 237] -> 
             RGBColor[
              0.9943041763763425, 0.9902255341421301, 0.6214229329927775], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.6612726645658855, 0.7340820794048803, 0.9677130141755275], 
             UndirectedEdge[202, 243] -> 
             RGBColor[
              0.8257930155175317, 0.6702555186764021, 0.5968941745983668], 
             UndirectedEdge[169, 456] -> 
             RGBColor[
              0.7491010629333834, 0.6622094115864601, 0.5999847994706612], 
             UndirectedEdge[86, 297] -> 
             RGBColor[
              0.6950135139368134, 0.7607800544840704, 0.9708439595676399], 
             UndirectedEdge[40, 202] -> 
             RGBColor[
              0.564260340109862, 0.6522071278233365, 0.9610548415969573], 
             UndirectedEdge[396, 477] -> 
             RGBColor[
              0.25938076564058354`, 0.3899560087516183, 0.938082722932551], 
             UndirectedEdge[209, 355] -> 
             RGBColor[
              0.6392689004656411, 0.2277375458245901, 0.4226244702275924], 
             UndirectedEdge[131, 434] -> 
             RGBColor[
              0.9705408679095504, 0.9768803034955444, 0.904760068118158], 
             UndirectedEdge[87, 228] -> 
             RGBColor[
              0.9642606254187348, 0.8832477525184754, 0.46230589935286726`], 
             UndirectedEdge[17, 116] -> 
             RGBColor[
              0.3771438644175238, 0.49983813442765457`, 0.9453266099247839], 
             UndirectedEdge[104, 323] -> 
             RGBColor[
              0.8395625088357104, 0.27821060181251556`, 0.18446547384080544`],
              UndirectedEdge[101, 347] -> 
             RGBColor[
              0.6170413621698586, 0.6801407659152249, 0.8143538746220298], 
             UndirectedEdge[92, 342] -> 
             RGBColor[
              0.5217728605047203, 0.6138451056826195, 0.9580941719683274], 
             UndirectedEdge[399, 464] -> 
             RGBColor[
              0.742224596044157, 0.7925971126381535, 0.7055763490357898], 
             UndirectedEdge[423, 469] -> 
             RGBColor[
              0.7481918035944166, 0.802997852221836, 0.9760270196854379], 
             UndirectedEdge[114, 415] -> 
             RGBColor[
              0.8406767692434449, 0.8758805197459772, 0.9583302371023414], 
             UndirectedEdge[244, 478] -> 
             RGBColor[
              0.86182006409282, 0.892655941897907, 0.9866823611406684], 
             UndirectedEdge[129, 486] -> 
             RGBColor[
              0.5279928436026333, 0.6095291999373154, 0.9601474850767409], 
             UndirectedEdge[202, 421] -> 
             RGBColor[
              0.8022062538074148, 0.8454504148324132, 0.9809090608710894], 
             UndirectedEdge[62, 378] -> 
             RGBColor[
              0.7462337642128304, 0.8010305496603691, 0.9685774152040886], 
             UndirectedEdge[263, 485] -> 
             RGBColor[
              0.7564712086525742, 0.809724872057139, 0.9763498170162235], 
             UndirectedEdge[275, 346] -> 
             RGBColor[
              0.9190614385225306, 0.9332206163365666, 0.7186271648831056], 
             UndirectedEdge[127, 303] -> 
             RGBColor[
              0.6572936958343352, 0.7201787013720731, 0.7087457742202985], 
             UndirectedEdge[260, 312] -> 
             RGBColor[
              0.5345579833771958, 0.6330172783251516, 0.9565015090833175], 
             UndirectedEdge[32, 299] -> 
             RGBColor[
              0.7048783061822942, 0.6918542132218126, 0.6113902366899864], 
             UndirectedEdge[283, 396] -> 
             RGBColor[
              0.6107148485685193, 0.6813680179567481, 0.9480842397936492], 
             UndirectedEdge[87, 253] -> 
             RGBColor[
              0.9532541034164349, 0.8396105604853894, 0.4534497933935403], 
             UndirectedEdge[298, 409] -> 
             RGBColor[
              0.7615294841365526, 0.4265049155729865, 0.44346711267933403`], 
             UndirectedEdge[208, 258] -> 
             RGBColor[
              0.9167499446192714, 0.7790852794545828, 0.6076855291675287], 
             UndirectedEdge[142, 161] -> 
             RGBColor[
              0.8008528010825335, 0.3622928408396782, 0.4353129290792316], 
             UndirectedEdge[71, 211] -> 
             RGBColor[
              0.7751186879594764, 0.8239895817852168, 0.9576807010123809], 
             UndirectedEdge[14, 453] -> 
             RGBColor[
              0.8590211011211247, 0.43903080543261036`, 0.20353968056113955`],
              UndirectedEdge[89, 478] -> 
             RGBColor[
              0.9007979326163105, 0.9229407428186456, 0.96283371725543], 
             UndirectedEdge[159, 251] -> 
             RGBColor[
              0.6656450528343036, 0.728802647598489, 0.8281152366216976], 
             UndirectedEdge[300, 305] -> 
             RGBColor[
              0.6882465754370218, 0.6955450430527316, 0.6144429719129851], 
             UndirectedEdge[327, 385] -> 
             RGBColor[
              0.785033667888939, 0.830767473867064, 0.9178015389609337], 
             UndirectedEdge[156, 270] -> 
             RGBColor[
              0.6922800446384769, 0.7514322347682716, 0.7921802192158294], 
             UndirectedEdge[418, 486] -> 
             RGBColor[
              0.8255939114143261, 0.3817401901917963, 0.4377472050781078], 
             UndirectedEdge[366, 465] -> 
             RGBColor[
              0.7375745669308987, 0.7915431412453892, 0.8850159865516558], 
             UndirectedEdge[337, 433] -> 
             RGBColor[
              0.7878875587646912, 0.8350272506441924, 0.9766917529537225], 
             UndirectedEdge[118, 152] -> 
             RGBColor[
              0.7366648977558832, 0.792925052544279, 0.9587837002022196], 
             UndirectedEdge[151, 162] -> 
             RGBColor[
              0.716534925211774, 0.7766829642754209, 0.9598899910834184], 
             UndirectedEdge[80, 251] -> 
             RGBColor[
              0.9731493996639116, 0.9180305980253586, 0.4965708043903052], 
             UndirectedEdge[348, 486] -> 
             RGBColor[
              0.7432145906997447, 0.7995032628677979, 0.9749928127416061], 
             UndirectedEdge[376, 455] -> 
             RGBColor[
              0.6233975268881999, 0.6864822899169727, 0.7807939976479313], 
             UndirectedEdge[153, 197] -> 
             RGBColor[
              0.35526152741655126`, 0.48213141190983017`, 0.9438579282749169],
              UndirectedEdge[9, 319] -> 
             RGBColor[
              0.6650176521864302, 0.7377758231695319, 0.9675611042015835], 
             UndirectedEdge[184, 336] -> 
             RGBColor[
              0.7834068011496408, 0.3561080354914863, 0.4344989616457094], 
             UndirectedEdge[41, 56] -> 
             RGBColor[
              0.559327069276856, 0.6531259380930996, 0.95845142225749], 
             UndirectedEdge[99, 313] -> 
             RGBColor[
              0.8675832742999244, 0.7802687593914491, 0.616630371810768], 
             UndirectedEdge[111, 130] -> 
             RGBColor[
              0.7937298576624864, 0.3567283433035624, 0.43460298064681213`], 
             UndirectedEdge[255, 327] -> 
             RGBColor[
              0.753830075023584, 0.8075587144016079, 0.9764899229560193], 
             UndirectedEdge[32, 84] -> 
             RGBColor[
              0.7010977080443948, 0.2825894561002958, 0.4265831315311671], 
             UndirectedEdge[196, 420] -> 
             RGBColor[
              0.9504317182882136, 0.8289562206645792, 0.4194921805648101], 
             UndirectedEdge[55, 57] -> 
             RGBColor[
              0.3386548790957402, 0.4545213004220324, 0.943577331421241], 
             UndirectedEdge[10, 480] -> 
             RGBColor[
              0.6632902909890526, 0.2501201976219934, 0.42409736747957993`], 
             UndirectedEdge[152, 216] -> 
             RGBColor[
              0.6708950632635083, 0.7377434614906804, 0.9540997219527514], 
             UndirectedEdge[244, 482] -> 
             RGBColor[
              0.900434184865887, 0.9234457936499647, 0.9903654104512362], 
             UndirectedEdge[111, 463] -> 
             RGBColor[
              0.603114996750322, 0.6870788529084847, 0.9629898287711112], 
             UndirectedEdge[58, 74] -> 
             RGBColor[
              0.7698071432678131, 0.7220882056086569, 0.6113263422377451], 
             UndirectedEdge[66, 327] -> 
             RGBColor[
              0.7717314414725169, 0.7744505607323994, 0.6293195320806568], 
             UndirectedEdge[168, 346] -> 
             RGBColor[
              0.5577134995269754, 0.6403577525782365, 0.9619021054257634], 
             UndirectedEdge[53, 471] -> 
             RGBColor[
              0.6902960117925535, 0.7544808684555564, 0.9543622005208864], 
             UndirectedEdge[28, 125] -> 
             RGBColor[
              0.7555632414852436, 0.8083458513388335, 0.9623708094021266], 
             UndirectedEdge[405, 423] -> 
             RGBColor[
              0.8891579311553757, 0.9144544150269559, 0.9892898713058971], 
             UndirectedEdge[314, 493] -> 
             RGBColor[
              0.8765174990073568, 0.9043784828742121, 0.9871573821133013], 
             UndirectedEdge[43, 229] -> 
             RGBColor[
              0.9017944038434947, 0.6183105214871712, 0.3876873657281227], 
             UndirectedEdge[281, 397] -> 
             RGBColor[
              0.7452669392071862, 0.31844802775943826`, 0.4300602952055269], 
             UndirectedEdge[203, 324] -> 
             RGBColor[
              0.7206755472746564, 0.7789644188397937, 0.9312464872004669], 
             UndirectedEdge[403, 445] -> 
             RGBColor[
              0.7576895145161497, 0.807362240519188, 0.8652326314534602], 
             UndirectedEdge[147, 303] -> 
             RGBColor[
              0.6075499483342606, 0.6690852812656907, 0.7058693545582035], 
             UndirectedEdge[356, 457] -> 
             RGBColor[
              0.6043138687543337, 0.5450372758503539, 0.5906425918649036], 
             UndirectedEdge[8, 85] -> 
             RGBColor[
              0.6344106395835273, 0.7129241805978281, 0.9651539948068505], 
             UndirectedEdge[301, 336] -> 
             RGBColor[
              0.7554013216637574, 0.8088445208371924, 0.9762550021828862], 
             UndirectedEdge[24, 64] -> 
             RGBColor[
              0.9720779414633771, 0.9147340227886447, 0.43940993691929886`], 
             UndirectedEdge[30, 488] -> 
             RGBColor[
              0.6265528918653088, 0.6937190709055506, 0.9216302682442526], 
             UndirectedEdge[191, 366] -> 
             RGBColor[
              0.46065540246385495`, 0.5725506879651947, 0.9508132536100617], 
             UndirectedEdge[185, 481] -> 
             RGBColor[
              0.7760366521298114, 0.8223930192307427, 0.8723516951726205], 
             UndirectedEdge[308, 389] -> 
             RGBColor[
              0.6166214497083684, 0.67924261561976, 0.7686489945881527], 
             UndirectedEdge[96, 240] -> 
             RGBColor[
              0.8849053768705699, 0.9066100626965945, 0.7375147409748731], 
             UndirectedEdge[108, 113] -> 
             RGBColor[
              0.9491164643863907, 0.9591526178676413, 0.8708593073111226], 
             UndirectedEdge[85, 332] -> 
             RGBColor[
              0.6526850453150845, 0.7277601664233029, 0.9665926229673926], 
             UndirectedEdge[232, 280] -> 
             RGBColor[
              0.9651633913253359, 0.8932130802239243, 0.5313009146680885], 
             UndirectedEdge[310, 419] -> 
             RGBColor[
              0.9641605596431726, 0.9721988757560467, 0.9190082913602626], 
             UndirectedEdge[39, 378] -> 
             RGBColor[
              0.9687313286125414, 0.9730438467144562, 0.7510323093861261], 
             UndirectedEdge[53, 257] -> 
             RGBColor[
              0.6953119863962371, 0.7188572754433298, 0.634229090211049], 
             UndirectedEdge[248, 339] -> 
             RGBColor[
              0.6759279268944689, 0.26106628265721543`, 0.4249026264644503], 
             UndirectedEdge[327, 334] -> 
             RGBColor[
              0.7112739078420905, 0.77362558184747, 0.9724308777399095], 
             UndirectedEdge[165, 358] -> 
             RGBColor[
              0.5812292938237766, 0.6615159070625635, 0.9637803737336228], 
             UndirectedEdge[69, 204] -> 
             RGBColor[
              0.9859365190546943, 0.9884524034612109, 0.882731804593123], 
             UndirectedEdge[208, 293] -> 
             RGBColor[
              0.9397109618061961, 0.9545571145460765, 0.9869377951493326], 
             UndirectedEdge[265, 320] -> 
             RGBColor[
              0.7761854107911503, 0.8250812092284396, 0.9783265659487489], 
             UndirectedEdge[239, 453] -> 
             RGBColor[
              0.7766522116866394, 0.5022902291587034, 0.4527767644908919], 
             UndirectedEdge[108, 452] -> 
             RGBColor[
              0.9927589320439423, 0.9912736465602813, 0.7696667655224391], 
             UndirectedEdge[331, 418] -> 
             RGBColor[
              0.8744119731891282, 0.41926898698936066`, 0.3890205035380336], 
             UndirectedEdge[28, 201] -> 
             RGBColor[
              0.9652824108267699, 0.9736282593562156, 0.94365200205955], 
             UndirectedEdge[431, 486] -> 
             RGBColor[
              0.9177968116875077, 0.9326824353418199, 0.7566223268671121], 
             UndirectedEdge[269, 419] -> 
             RGBColor[
              0.8560336301359434, 0.8868801043234157, 0.912837213496372], 
             UndirectedEdge[315, 378] -> 
             RGBColor[
              0.9491920275618827, 0.9616280778628472, 0.9708888238829375], 
             UndirectedEdge[57, 240] -> 
             RGBColor[
              0.47778993375723616`, 0.5654201949867508, 0.9559370788331492], 
             UndirectedEdge[7, 176] -> 
             RGBColor[
              0.6313447477147311, 0.7040598435628984, 0.9599404250974903], 
             UndirectedEdge[6, 302] -> 
             RGBColor[
              0.931613994844698, 0.7752573109512577, 0.5725932634019372], 
             UndirectedEdge[176, 455] -> 
             RGBColor[
              0.5986110484334071, 0.6705042848092846, 0.9580451800628379], 
             UndirectedEdge[161, 396] -> 
             RGBColor[
              0.5162111321417472, 0.6069815636136628, 0.9579385744885134], 
             UndirectedEdge[36, 463] -> 
             RGBColor[
              0.7264284306579462, 0.7800221877428664, 0.7247501393195239], 
             UndirectedEdge[131, 373] -> 
             RGBColor[
              0.9224561439229518, 0.9389813507564886, 0.9155154896871355], 
             UndirectedEdge[54, 341] -> 
             RGBColor[
              0.7058287576401587, 0.7621044235421081, 0.7021882159148638], 
             UndirectedEdge[272, 453] -> 
             RGBColor[
              0.8288369342092295, 0.22265888952309182`, 0.17524758680640434`],
              UndirectedEdge[169, 236] -> 
             RGBColor[
              0.840317461469241, 0.7341485913316979, 0.6086113165845946], 
             UndirectedEdge[69, 101] -> 
             RGBColor[
              0.9895778596855156, 0.9896722653435585, 0.8016015616479002], 
             UndirectedEdge[286, 330] -> 
             RGBColor[
              0.9726600085674484, 0.9634723629484747, 0.6698454845374091], 
             UndirectedEdge[86, 254] -> 
             RGBColor[
              0.8554032666085395, 0.7548042263216899, 0.6118847455497395], 
             UndirectedEdge[68, 319] -> 
             RGBColor[
              0.44629124835095113`, 0.5540270162594039, 0.950947471595957], 
             UndirectedEdge[37, 207] -> 
             RGBColor[
              0.7310353549147943, 0.7876842740544217, 0.940357810508581], 
             UndirectedEdge[257, 317] -> 
             RGBColor[
              0.6242917234626302, 0.654978297258119, 0.6297903286239963], 
             UndirectedEdge[94, 158] -> 
             RGBColor[
              0.9623216471953797, 0.8824209866682751, 0.5313361841341411], 
             UndirectedEdge[253, 336] -> 
             RGBColor[
              0.8121037082429174, 0.7317345312841126, 0.6099509397646898], 
             UndirectedEdge[67, 363] -> 
             RGBColor[
              0.44637418022264885`, 0.5580930712095616, 0.9504801707575459], 
             UndirectedEdge[61, 295] -> 
             RGBColor[
              0.6398817957935209, 0.711032583609971, 0.9543310718415785], 
             UndirectedEdge[16, 116] -> 
             RGBColor[
              0.290153632161958, 0.42230024257801124`, 0.9398351921565669], 
             UndirectedEdge[294, 439] -> 
             RGBColor[
              0.8131396578602137, 0.854292389951878, 0.9517420769946383], 
             UndirectedEdge[69, 346] -> 
             RGBColor[
              0.9147895669837809, 0.933639359766835, 0.9482693438314387], 
             UndirectedEdge[327, 415] -> 
             RGBColor[
              0.7742925360167885, 0.8231217407572774, 0.9523282678001809], 
             UndirectedEdge[54, 61] -> 
             RGBColor[
              0.9722745587992094, 0.9752637852133703, 0.71150329850145], 
             UndirectedEdge[244, 262] -> 
             RGBColor[
              0.8588984919551764, 0.8903263595793132, 0.9864036989820617], 
             UndirectedEdge[295, 397] -> 
             RGBColor[
              0.6542137026660646, 0.24225851301921494`, 0.42351901529775104`],
              UndirectedEdge[61, 264] -> 
             RGBColor[
              0.6104996699223699, 0.6819305575948251, 0.9525926121996293], 
             UndirectedEdge[162, 226] -> 
             RGBColor[
              0.6600329363002306, 0.7320304655862606, 0.9683916914917333], 
             UndirectedEdge[237, 351] -> 
             RGBColor[
              0.6114289123388483, 0.6737107404528897, 0.7609341434583066], 
             UndirectedEdge[243, 273] -> 
             RGBColor[
              0.9189268937625275, 0.7434190394258535, 0.5791683130358629], 
             UndirectedEdge[53, 343] -> 
             RGBColor[
              0.5910273052569812, 0.6763446132838475, 0.9623569333015727], 
             UndirectedEdge[37, 445] -> 
             RGBColor[
              0.9835105774112951, 0.9858517668107456, 0.8513989757518731], 
             UndirectedEdge[144, 402] -> 
             RGBColor[
              0.6049299974848685, 0.6876018089580239, 0.9635748878966119], 
             UndirectedEdge[235, 456] -> 
             RGBColor[
              0.6873031735285378, 0.7549654940101436, 0.9699326962165553], 
             UndirectedEdge[369, 456] -> 
             RGBColor[
              0.657295308257523, 0.7315231215922038, 0.9669417926457853], 
             UndirectedEdge[7, 61] -> 
             RGBColor[
              0.6348480056638033, 0.7066725676052581, 0.9540103231857188], 
             UndirectedEdge[76, 175] -> 
             RGBColor[
              0.6715735259963962, 0.5915953905490885, 0.5924095984488973], 
             UndirectedEdge[259, 372] -> 
             RGBColor[
              0.8024847376036152, 0.8119289662192313, 0.6503319521524966], 
             UndirectedEdge[187, 224] -> 
             RGBColor[
              0.5350523404177739, 0.6306408433324742, 0.9576140826440194], 
             UndirectedEdge[142, 183] -> 
             RGBColor[
              0.6490013594383676, 0.23774384329537174`, 0.4231868893963763], 
             UndirectedEdge[255, 299] -> 
             RGBColor[
              0.9325416028932696, 0.8732080075891808, 0.6320392369633694], 
             UndirectedEdge[233, 444] -> 
             RGBColor[
              0.698188931303489, 0.7597677355031893, 0.9322498667114165], 
             UndirectedEdge[148, 280] -> 
             RGBColor[
              0.7121189842123741, 0.694367502536478, 0.6111854936021746], 
             UndirectedEdge[7, 376] -> 
             RGBColor[
              0.656131226169524, 0.7200378486705865, 0.7826892426825838], 
             UndirectedEdge[73, 256] -> 
             RGBColor[
              0.9872041633039407, 0.9673073895940184, 0.5060982263265087], 
             UndirectedEdge[207, 403] -> 
             RGBColor[
              0.5052142920196491, 0.6091947477628641, 0.9541914662101683], 
             UndirectedEdge[233, 346] -> 
             RGBColor[
              0.9132538786284716, 0.9324962316167666, 0.9509667442433923], 
             UndirectedEdge[293, 403] -> 
             RGBColor[
              0.7304019918733633, 0.7883822801497409, 0.9728207845092953], 
             UndirectedEdge[321, 391] -> 
             RGBColor[
              0.6736493423743368, 0.7423081731095219, 0.9700997857905973], 
             UndirectedEdge[228, 298] -> 
             RGBColor[
              0.7712146294892612, 0.7343126831279732, 0.6139886016007952], 
             UndirectedEdge[54, 455] -> 
             RGBColor[
              0.6226283815928406, 0.6848371659027173, 0.6970772788626123], 
             UndirectedEdge[323, 419] -> 
             RGBColor[
              0.8741325350318944, 0.41915343213011125`, 0.39365151696616774`],
              UndirectedEdge[65, 194] -> 
             RGBColor[
              0.978097187806422, 0.9700252385840569, 0.6659441919843099], 
             UndirectedEdge[40, 273] -> 
             RGBColor[
              0.6573942183548578, 0.7253706485727879, 0.9433289800344534], 
             UndirectedEdge[209, 400] -> 
             RGBColor[
              0.8666250677607027, 0.4139495145478091, 0.42405484221354883`], 
             UndirectedEdge[31, 488] -> 
             RGBColor[
              0.4300097971517437, 0.5394001774228425, 0.9497939759743681], 
             UndirectedEdge[399, 407] -> 
             RGBColor[
              0.7312553012853791, 0.7836917449918801, 0.7047128059705281], 
             UndirectedEdge[292, 399] -> 
             RGBColor[
              0.906345705234745, 0.9231184985330563, 0.7203559174386783], 
             UndirectedEdge[93, 218] -> 
             RGBColor[
              0.9456610824903062, 0.9589947048098575, 0.9768657928711509], 
             UndirectedEdge[198, 270] -> 
             RGBColor[
              0.6860875868323534, 0.7492295712101684, 0.9306529116489817], 
             UndirectedEdge[78, 192] -> 
             RGBColor[
              0.912464957016539, 0.8312989518983653, 0.6243244914073597], 
             UndirectedEdge[286, 492] -> 
             RGBColor[
              0.8726993389852112, 0.40804096493265385`, 0.2395605728322311], 
             UndirectedEdge[317, 343] -> 
             RGBColor[
              0.5200070423233742, 0.6124656350986367, 0.95791817171452], 
             UndirectedEdge[51, 203] -> 
             RGBColor[
              0.6401635892450608, 0.7081971616689291, 0.9261274968210114], 
             UndirectedEdge[212, 216] -> 
             RGBColor[
              0.5316065041430148, 0.6283237633987682, 0.957111986562301], 
             UndirectedEdge[100, 257] -> 
             RGBColor[
              0.9714169139350952, 0.9388388630713284, 0.6216255147503104], 
             UndirectedEdge[189, 302] -> 
             RGBColor[
              0.6515005062379227, 0.7194485285396335, 0.9310256708373086], 
             UndirectedEdge[306, 382] -> 
             RGBColor[
              0.9186316649969832, 0.9094659820942536, 0.6710162063104915], 
             UndirectedEdge[20, 150] -> 
             RGBColor[
              0.6606605239059232, 0.2478424255505235, 0.4239298010464546], 
             UndirectedEdge[255, 446] -> 
             RGBColor[
              0.6691557419700329, 0.7377576543419251, 0.9701165496851282], 
             UndirectedEdge[182, 237] -> 
             RGBColor[
              0.9805953170258107, 0.9452975250191378, 0.45633212964430503`], 
             UndirectedEdge[4, 366] -> 
             RGBColor[
              0.6881902654700018, 0.5957195962530966, 0.5917364264030939], 
             UndirectedEdge[231, 275] -> 
             RGBColor[
              0.8474872691153738, 0.8771011134731446, 0.7115477790532299], 
             UndirectedEdge[97, 231] -> 
             RGBColor[
              0.5119234857129439, 0.6101486196011255, 0.9563346759439215], 
             UndirectedEdge[114, 128] -> 
             RGBColor[
              0.8235605783581362, 0.7706332968902524, 0.6177247368877535], 
             UndirectedEdge[207, 471] -> 
             RGBColor[
              0.7214383933388085, 0.7805268758246338, 0.9566029631682715], 
             UndirectedEdge[54, 391] -> 
             RGBColor[
              0.7176256094489465, 0.772322263651868, 0.7029399008805733], 
             UndirectedEdge[299, 478] -> 
             RGBColor[
              0.8880827689989421, 0.8377577402447415, 0.6277987136976588], 
             UndirectedEdge[44, 365] -> 
             RGBColor[
              0.9310467376522307, 0.947788377572096, 0.9909611274453194], 
             UndirectedEdge[6, 101] -> 
             RGBColor[
              0.9395191364736517, 0.7790796383541492, 0.4583852184516456], 
             UndirectedEdge[236, 308] -> 
             RGBColor[
              0.5097592188555452, 0.5985181995388273, 0.957837431926793], 
             UndirectedEdge[47, 256] -> 
             RGBColor[
              0.9947284639492403, 0.9911330423585047, 0.667604016903334], 
             UndirectedEdge[304, 427] -> 
             RGBColor[
              0.8733138563576567, 0.4101138763254527, 0.24194785678231298`], 
             UndirectedEdge[54, 397] -> 
             RGBColor[
              0.8758088780031903, 0.4184126474214812, 0.2616338330709987], 
             UndirectedEdge[220, 254] -> 
             RGBColor[
              0.8465798531156105, 0.30990677879352013`, 0.19031223032633562`],
              UndirectedEdge[377, 426] -> 
             RGBColor[
              0.6753368742078931, 0.7233098773685693, 0.6661120053865914], 
             UndirectedEdge[216, 292] -> 
             RGBColor[
              0.6037022421693389, 0.6846455018928358, 0.9642978159557876], 
             UndirectedEdge[42, 119] -> 
             RGBColor[
              0.9458824053849132, 0.9037605173604737, 0.6356830938875628], 
             UndirectedEdge[170, 491] -> 
             RGBColor[
              0.9700447960317098, 0.9764524834381156, 0.9030091264745197], 
             UndirectedEdge[257, 326] -> 
             RGBColor[
              0.9379769228157004, 0.9132505679059699, 0.6557362364262689], 
             UndirectedEdge[98, 347] -> 
             RGBColor[
              0.624590053698924, 0.21230914718013116`, 0.4217885316196356], 
             UndirectedEdge[271, 311] -> 
             RGBColor[
              0.8571646708769455, 0.8892303639319612, 0.9837330355496814], 
             UndirectedEdge[156, 227] -> 
             RGBColor[
              0.9229273665815171, 0.9374503243430987, 0.8119853204471845], 
             UndirectedEdge[151, 160] -> 
             RGBColor[
              0.9684400669881461, 0.975741963344585, 0.9275023141623782], 
             UndirectedEdge[93, 167] -> 
             RGBColor[
              0.9366170357283596, 0.8403973077577156, 0.6075677381661407], 
             UndirectedEdge[275, 348] -> 
             RGBColor[
              0.8185171731810482, 0.8544694543483654, 0.7086603106314351], 
             UndirectedEdge[34, 394] -> 
             RGBColor[
              0.5932966252105814, 0.47244371784858397`, 0.5766513841821403], 
             UndirectedEdge[405, 488] -> 
             RGBColor[
              0.562556173035181, 0.6440212065106599, 0.9623939939002062], 
             UndirectedEdge[338, 443] -> 
             RGBColor[
              0.9191196480748414, 0.8863927559898581, 0.6365465896681844], 
             UndirectedEdge[301, 316] -> 
             RGBColor[
              0.5276887918985542, 0.614925427427581, 0.959244448378949], 
             UndirectedEdge[103, 209] -> 
             RGBColor[
              0.8282509424785036, 0.3838588346391846, 0.4380006350729687], 
             UndirectedEdge[126, 414] -> 
             RGBColor[
              0.9370946347918534, 0.9525340911363183, 0.9888782084941412], 
             UndirectedEdge[154, 341] -> 
             RGBColor[
              0.7068286789336446, 0.764668910104735, 0.8419714463048245], 
             UndirectedEdge[306, 347] -> 
             RGBColor[
              0.6067926386808921, 0.647079972694018, 0.646092602491505], 
             UndirectedEdge[20, 388] -> 
             RGBColor[
              0.6707074404935648, 0.733544812460559, 0.8456353408566235], 
             UndirectedEdge[286, 319] -> 
             RGBColor[
              0.7978857991748554, 0.8260050233764453, 0.6764341378183569], 
             UndirectedEdge[62, 96] -> 
             RGBColor[
              0.7707790455242338, 0.8160143763492693, 0.7271237718723064], 
             UndirectedEdge[149, 242] -> 
             RGBColor[
              0.7309124253023875, 0.7887629605653491, 0.971956753856317], 
             UndirectedEdge[212, 319] -> 
             RGBColor[
              0.6440042569227225, 0.7213599990818045, 0.9654666853430407], 
             UndirectedEdge[289, 470] -> 
             RGBColor[
              0.8672287888031911, 0.4143997687127945, 0.42303289996428184`], 
             UndirectedEdge[291, 353] -> 
             RGBColor[
              0.8164112030504536, 0.7422884061833821, 0.611972181697785], 
             UndirectedEdge[21, 91] -> 
             RGBColor[
              0.6075621483453335, 0.6771852515467207, 0.9429234003441084], 
             UndirectedEdge[95, 224] -> 
             RGBColor[
              0.6857152267078532, 0.7446521435420664, 0.6982613080341391], 
             UndirectedEdge[218, 235] -> 
             RGBColor[
              0.8566898529707548, 0.8888889750947275, 0.9851811476562597], 
             UndirectedEdge[108, 315] -> 
             RGBColor[
              0.9741016156274696, 0.9785949992307617, 0.8565970438241289], 
             UndirectedEdge[61, 154] -> 
             RGBColor[
              0.9732744800926952, 0.9778282717759973, 0.8512865288914107], 
             UndirectedEdge[297, 413] -> 
             RGBColor[
              0.4179619993647691, 0.5275989837350735, 0.9490294248020084], 
             UndirectedEdge[294, 438] -> 
             RGBColor[
              0.6960703661099128, 0.7586511470501888, 0.9425995944298755], 
             UndirectedEdge[277, 386] -> 
             RGBColor[
              0.6746734324946475, 0.7435296147218751, 0.9699892895606538], 
             UndirectedEdge[125, 249] -> 
             RGBColor[
              0.6734449787022347, 0.7435460597333119, 0.9689570882088667], 
             UndirectedEdge[211, 308] -> 
             RGBColor[
              0.5990346379853095, 0.6687846947821938, 0.9456612639242608], 
             UndirectedEdge[273, 477] -> 
             RGBColor[
              0.6099091692933116, 0.6792038522766024, 0.9404877271363175], 
             UndirectedEdge[154, 397] -> 
             RGBColor[
              0.8764754921988475, 0.4201223051298991, 0.3548226533309724], 
             UndirectedEdge[105, 230] -> 
             RGBColor[
              0.6741604765294043, 0.7395509870119612, 0.9394096441266119], 
             UndirectedEdge[355, 404] -> 
             RGBColor[
              0.5801409181084181, 0.47491995414754806`, 0.5793049684774298], 
             UndirectedEdge[250, 263] -> 
             RGBColor[
              0.5738444333570605, 0.6585905769558619, 0.9624842729946286], 
             UndirectedEdge[11, 259] -> 
             RGBColor[
              0.7524719467721397, 0.7713263295716881, 0.6463947620553537], 
             UndirectedEdge[339, 439] -> 
             RGBColor[
              0.7639073387038676, 0.3334307648335505, 0.4316305506643018], 
             UndirectedEdge[303, 379] -> 
             RGBColor[
              0.7676715826381493, 0.8133643156381232, 0.7164471013522322], 
             UndirectedEdge[416, 468] -> 
             RGBColor[
              0.6230871501672279, 0.6885980135257941, 0.8828717907582806], 
             UndirectedEdge[77, 336] -> 
             RGBColor[
              0.7555859286951518, 0.8089887372531832, 0.9762734020865248], 
             UndirectedEdge[297, 412] -> 
             RGBColor[
              0.5660759296696738, 0.658604966992685, 0.9589827172695028], 
             UndirectedEdge[69, 418] -> 
             RGBColor[
              0.8729477187093619, 0.41866348013235355`, 0.4132869896368825], 
             UndirectedEdge[281, 322] -> 
             RGBColor[
              0.7890942927457353, 0.8106273725383031, 0.6634973807106141], 
             UndirectedEdge[51, 495] -> 
             RGBColor[
              0.46023163661648175`, 0.5672717790409774, 0.9518694726815891], 
             UndirectedEdge[227, 229] -> 
             RGBColor[
              0.9223545436119519, 0.9379233746672859, 0.8730827029319186], 
             UndirectedEdge[192, 497] -> 
             RGBColor[
              0.9372100511159038, 0.788765806724326, 0.26833593713957093`], 
             UndirectedEdge[143, 277] -> 
             RGBColor[
              0.6972030935877275, 0.7614676498032206, 0.9712192394979218], 
             UndirectedEdge[87, 161] -> 
             RGBColor[
              0.8812847325273748, 0.904793865862197, 0.8182321854938057], 
             UndirectedEdge[114, 255] -> 
             RGBColor[
              0.8202143082502406, 0.8603174933903077, 0.9824918922581798], 
             UndirectedEdge[341, 391] -> 
             RGBColor[
              0.4306657330795345, 0.5474427449295326, 0.9486626175824411], 
             UndirectedEdge[35, 347] -> 
             RGBColor[
              0.5707097654065635, 0.508932516717262, 0.5885540599027723], 
             UndirectedEdge[99, 498] -> 
             RGBColor[
              0.8744900513344931, 0.8076518287865044, 0.6221877267356757], 
             UndirectedEdge[89, 448] -> 
             RGBColor[
              0.9419807580304429, 0.9557788099258586, 0.9667617719077722], 
             UndirectedEdge[130, 371] -> 
             RGBColor[
              0.6476144828017323, 0.2365092820003037, 0.42309973879545015`], 
             UndirectedEdge[187, 481] -> 
             RGBColor[
              0.6258623439511944, 0.7063908079584813, 0.9642031025023907], 
             UndirectedEdge[427, 500] -> 
             RGBColor[
              0.7902547355337702, 0.8221708098963465, 0.6793417528722311], 
             UndirectedEdge[134, 247] -> 
             RGBColor[
              0.6237469572485845, 0.696348331243164, 0.9561786846158054], 
             UndirectedEdge[79, 301] -> 
             RGBColor[
              0.8592513473234644, 0.7816015817745647, 0.6175366677780707], 
             UndirectedEdge[173, 323] -> 
             RGBColor[
              0.6302886294142798, 0.21829871156753872`, 0.42211305707633784`],
              UndirectedEdge[84, 262] -> 
             RGBColor[
              0.8212863018303977, 0.37830541923651906`, 0.43733634143054423`],
              UndirectedEdge[262, 391] -> 
             RGBColor[
              0.6358417451897578, 0.7121614213744248, 0.9664936634198917], 
             UndirectedEdge[205, 382] -> 
             RGBColor[
              0.6201248582399506, 0.6973931598939483, 0.9660239458744455], 
             UndirectedEdge[50, 499] -> 
             RGBColor[
              0.27703645022768275`, 0.40851325268771793`, 0.9390881880505416],
              UndirectedEdge[108, 380] -> 
             RGBColor[
              0.9841783703650736, 0.9586420971805327, 0.5531510936481026], 
             UndirectedEdge[300, 493] -> 
             RGBColor[
              0.6201439685591659, 0.6990385559057306, 0.9652811104937031], 
             UndirectedEdge[331, 382] -> 
             RGBColor[
              0.9257040666481695, 0.9414992106544733, 0.9127011565554903], 
             UndirectedEdge[186, 495] -> 
             RGBColor[
              0.8092067452512527, 0.8479925453358881, 0.7941457325973833], 
             UndirectedEdge[93, 235] -> 
             RGBColor[
              0.8656240970340237, 0.8955521196886314, 0.9700578028811894], 
             UndirectedEdge[18, 300] -> 
             RGBColor[
              0.4226019713906831, 0.5404583198510965, 0.948148801818132], 
             UndirectedEdge[223, 246] -> 
             RGBColor[
              0.7762595209670164, 0.8240102477103355, 0.9324119442492264], 
             UndirectedEdge[233, 431] -> 
             RGBColor[
              0.9872918342747523, 0.9869242421025874, 0.7226294041172276], 
             UndirectedEdge[182, 351] -> 
             RGBColor[
              0.5980498888124219, 0.6294882168061413, 0.631743934052948], 
             UndirectedEdge[163, 209] -> 
             RGBColor[
              0.6376857288102132, 0.2260735320358549, 0.42253431094390836`], 
             UndirectedEdge[70, 182] -> 
             RGBColor[
              0.805164461404964, 0.8110993711587906, 0.6461025174827776], 
             UndirectedEdge[59, 335] -> 
             RGBColor[
              0.7051411419216168, 0.7624378964543412, 0.7815491134071744], 
             UndirectedEdge[258, 453] -> 
             RGBColor[
              0.8652309869818681, 0.4672284467705547, 0.2087213615415752], 
             UndirectedEdge[161, 354] -> 
             RGBColor[
              0.8241412902328535, 0.8630327210553963, 0.9829768558404963], 
             UndirectedEdge[213, 489] -> 
             RGBColor[
              0.8921991533249758, 0.9161140124624926, 0.9626462089691921], 
             UndirectedEdge[260, 407] -> 
             RGBColor[
              0.495211681268938, 0.6010741777429576, 0.9534040240511018], 
             UndirectedEdge[95, 185] -> 
             RGBColor[
              0.9922514203252054, 0.9888708267544838, 0.618673184526577], 
             UndirectedEdge[117, 479] -> 
             RGBColor[
              0.722976560617385, 0.49499740581255536`, 0.45372009720166073`], 
             UndirectedEdge[164, 444] -> 
             RGBColor[
              0.3365199347529149, 0.461187690948889, 0.9428362121965397], 
             UndirectedEdge[32, 334] -> 
             RGBColor[
              0.653762253662666, 0.7269350301141178, 0.9679033496507744], 
             UndirectedEdge[46, 325] -> 
             RGBColor[
              0.9407684477166851, 0.7986935095212829, 0.5378031645266115], 
             UndirectedEdge[18, 201] -> 
             RGBColor[
              0.6999425691023198, 0.7614354512542342, 0.9345332976476736], 
             UndirectedEdge[328, 398] -> 
             RGBColor[
              0.8984534255538275, 0.9130845899301159, 0.6979059269983079], 
             UndirectedEdge[376, 448] -> 
             RGBColor[
              0.9558783125975171, 0.9636358734270627, 0.8079426973485824], 
             UndirectedEdge[326, 355] -> 
             RGBColor[
              0.5968539007499936, 0.6732309081216213, 0.9653833184850498], 
             UndirectedEdge[257, 281] -> 
             RGBColor[
              0.783288781574948, 0.7910440201603911, 0.640944066090898], 
             UndirectedEdge[32, 89] -> 
             RGBColor[
              0.7175934697996625, 0.7770372157957167, 0.9464252402477575], 
             UndirectedEdge[341, 397] -> 
             RGBColor[
              0.6845022937569156, 0.2684929682732576, 0.42544897753891053`], 
             UndirectedEdge[160, 274] -> 
             RGBColor[
              0.8734274152994751, 0.4188618470000054, 0.40533717572372774`], 
             UndirectedEdge[151, 235] -> 
             RGBColor[
              0.8639443777961696, 0.8942993878313277, 0.9729011294099356], 
             UndirectedEdge[11, 372] -> 
             RGBColor[
              0.5854029325422402, 0.6742954985961918, 0.9605042097327755], 
             UndirectedEdge[99, 295] -> 
             RGBColor[
              0.5740241133189142, 0.6589336367009342, 0.9624094377218313], 
             UndirectedEdge[154, 199] -> 
             RGBColor[
              0.6861139896737447, 0.7467268874183647, 0.8406515246224642], 
             UndirectedEdge[169, 308] -> 
             RGBColor[
              0.5696904037104678, 0.504303833333264, 0.5877034795167084], 
             UndirectedEdge[158, 410] -> 
             RGBColor[
              0.8393318594550341, 0.7875323258409004, 0.6203105191730283], 
             UndirectedEdge[311, 465] -> 
             RGBColor[
              0.8829059577332774, 0.907483514758407, 0.8978560018234656], 
             UndirectedEdge[139, 428] -> 
             RGBColor[
              0.9199264463239389, 0.8632404618096033, 0.630856467423135], 
             UndirectedEdge[113, 364] -> 
             RGBColor[
              0.7493656590660134, 0.8040763832576179, 0.9759749330236964], 
             UndirectedEdge[89, 475] -> 
             RGBColor[
              0.7821475150169748, 0.829445097829727, 0.9515071711565235], 
             UndirectedEdge[375, 441] -> 
             RGBColor[
              0.9139497555707765, 0.9073386508318488, 0.6729321252690472], 
             UndirectedEdge[244, 295] -> 
             RGBColor[
              0.6082895932086767, 0.6862560002533569, 0.9656777097828718], 
             UndirectedEdge[187, 260] -> 
             RGBColor[
              0.6060649938945504, 0.6903184273220411, 0.962644582585849], 
             UndirectedEdge[207, 322] -> 
             RGBColor[
              0.7322598791132795, 0.764486635190319, 0.6590231674781504], 
             UndirectedEdge[100, 457] -> 
             RGBColor[
              0.940078092122949, 0.8169567449104989, 0.5818307877216982], 
             UndirectedEdge[364, 416] -> 
             RGBColor[
              0.791817988749514, 0.8357052593128371, 0.8945060574433814], 
             UndirectedEdge[313, 386] -> 
             RGBColor[
              0.9033944731005458, 0.8088236372459686, 0.6200460759214057], 
             UndirectedEdge[31, 472] -> 
             RGBColor[
              0.733101647383009, 0.7910872235479556, 0.9744474573780704], 
             UndirectedEdge[37, 49] -> 
             RGBColor[
              0.6288727104349323, 0.6977592885001335, 0.9336782862741432], 
             UndirectedEdge[201, 406] -> 
             RGBColor[
              0.6363396120105514, 0.704984085581825, 0.9305304312760678], 
             UndirectedEdge[245, 376] -> 
             RGBColor[
              0.9801752455874413, 0.9822276011961826, 0.7831481777432487], 
             UndirectedEdge[58, 215] -> 
             RGBColor[
              0.6666900235053416, 0.6371028858239578, 0.6035595439414653], 
             UndirectedEdge[84, 407] -> 
             RGBColor[
              0.7014485335350947, 0.2828742720381543, 0.426610749798911], 
             UndirectedEdge[100, 324] -> 
             RGBColor[
              0.7174137281959343, 0.7765317595116212, 0.9367678960820782], 
             UndirectedEdge[89, 176] -> 
             RGBColor[
              0.9556428915784223, 0.966439121684062, 0.9599691937577306], 
             UndirectedEdge[75, 379] -> 
             RGBColor[
              0.768760817248162, 0.8156940783304281, 0.8350035666753067], 
             UndirectedEdge[123, 422] -> 
             RGBColor[
              0.9096686363833256, 0.9264641125123345, 0.7771556235063528], 
             UndirectedEdge[407, 455] -> 
             RGBColor[
              0.36108786489069744`, 0.48152960282772705`, 0.9445426539544808],
              UndirectedEdge[333, 358] -> 
             RGBColor[
              0.8960330420576627, 0.8085240170593329, 0.6205912508198455], 
             UndirectedEdge[120, 124] -> 
             RGBColor[
              0.7701010542885829, 0.8204006799753651, 0.9777008640236161], 
             UndirectedEdge[88, 433] -> 
             RGBColor[
              0.9392440158345725, 0.9542088670049935, 0.9877282128802771], 
             UndirectedEdge[345, 456] -> 
             RGBColor[
              0.7517320061204424, 0.8059890668322554, 0.9761709159030059], 
             UndirectedEdge[392, 474] -> 
             RGBColor[
              0.7286705266314841, 0.781807626215646, 0.7220747675358716], 
             UndirectedEdge[165, 333] -> 
             RGBColor[
              0.6038349966692584, 0.5681286561149006, 0.5965821511499784], 
             UndirectedEdge[31, 133] -> 
             RGBColor[
              0.7743893216054644, 0.7733642944944752, 0.6247082816633323], 
             UndirectedEdge[171, 208] -> 
             RGBColor[
              0.9358355199510306, 0.9515229107904968, 0.9885086110415062], 
             UndirectedEdge[284, 472] -> 
             RGBColor[
              0.9132208232111078, 0.9332271989747756, 0.9772205193705776], 
             UndirectedEdge[196, 427] -> 
             RGBColor[
              0.9460522604124044, 0.8151457449769124, 0.32063781617244075`], 
             UndirectedEdge[179, 334] -> 
             RGBColor[
              0.5381336133001766, 0.6206031278074828, 0.960662066370142], 
             UndirectedEdge[97, 233] -> 
             RGBColor[
              0.6513775559090966, 0.7192220749447049, 0.9292670872649598], 
             UndirectedEdge[21, 409] -> 
             RGBColor[
              0.8795510488552938, 0.5193552098939016, 0.4387433775816353], 
             UndirectedEdge[63, 344] -> 
             RGBColor[
              0.8247002766707638, 0.8636673406669881, 0.9829800444796593], 
             UndirectedEdge[292, 398] -> 
             RGBColor[
              0.813559982519413, 0.8542785087198241, 0.9820517139733916], 
             UndirectedEdge[71, 197] -> 
             RGBColor[
              0.4956857965812682, 0.6000133140409507, 0.9538408192209248], 
             UndirectedEdge[81, 121] -> 
             RGBColor[
              0.48200190366590784`, 0.5836604978980074, 0.9539901032345404], 
             UndirectedEdge[163, 317] -> 
             RGBColor[
              0.28079394391378154`, 0.41246261679066754`, 0.9393021717572512],
              UndirectedEdge[167, 172] -> 
             RGBColor[
              0.9522610726888578, 0.8395901512782586, 0.3265265670431947], 
             UndirectedEdge[191, 488] -> 
             RGBColor[
              0.3522660384534752, 0.47581514589399404`, 0.943803328915185], 
             UndirectedEdge[392, 490] -> 
             RGBColor[
              0.35834159133983534`, 0.4793000542409237, 0.9443264572406256], 
             UndirectedEdge[251, 272] -> 
             RGBColor[
              0.8765963227625733, 0.42009691213892364`, 0.3473423355840951], 
             UndirectedEdge[66, 255] -> 
             RGBColor[
              0.9418830840040677, 0.9091138033664152, 0.6454410042649048], 
             UndirectedEdge[177, 194] -> 
             RGBColor[
              0.6357931979617084, 0.6902268115045516, 0.6686217813669652], 
             UndirectedEdge[36, 359] -> 
             RGBColor[
              0.6250508263662076, 0.6875953317815169, 0.7184181659608018], 
             UndirectedEdge[46, 377] -> 
             RGBColor[
              0.9379860975361838, 0.7807403236602277, 0.3100795460032256], 
             UndirectedEdge[6, 306] -> 
             RGBColor[
              0.9292704129846852, 0.7460188451329423, 0.29012394632112065`], 
             UndirectedEdge[7, 455] -> 
             RGBColor[
              0.28520182845743464`, 0.41624594829460504`, 0.9395843035468809],
              UndirectedEdge[84, 482] -> 
             RGBColor[
              0.8489767637708715, 0.40038504195028674`, 0.4399774824099939], 
             UndirectedEdge[83, 97] -> 
             RGBColor[
              0.4375391338769564, 0.5506771323599158, 0.9498518543036873], 
             UndirectedEdge[125, 408] -> 
             RGBColor[
              0.43857908100481746`, 0.5514213300493603, 0.9499613746663973], 
             UndirectedEdge[184, 473] -> 
             RGBColor[
              0.8183970439962693, 0.14241331855721773`, 0.1652503361483041], 
             UndirectedEdge[410, 422] -> 
             RGBColor[
              0.785304299671115, 0.8322495019004311, 0.9792236300683965], 
             UndirectedEdge[202, 283] -> 
             RGBColor[
              0.8681093739762515, 0.8974523407322808, 0.9682151055599196], 
             UndirectedEdge[320, 329] -> 
             RGBColor[
              0.8577357798811907, 0.8893183417133808, 0.965659101637915], 
             UndirectedEdge[146, 387] -> 
             RGBColor[
              0.8547930714667679, 0.3907723609342786, 0.19887379424265894`], 
             UndirectedEdge[107, 170] -> 
             RGBColor[
              0.9451263582951562, 0.9585959083806451, 0.9777709414551337], 
             UndirectedEdge[273, 459] -> 
             RGBColor[
              0.9355005999699152, 0.8183262347471704, 0.5929797077015981], 
             UndirectedEdge[5, 395] -> 
             RGBColor[
              0.5094224161358215, 0.6087569396094967, 0.9558474537797098], 
             UndirectedEdge[104, 242] -> 
             RGBColor[
              0.703492060094891, 0.594979346190464, 0.5902734473955499], 
             UndirectedEdge[422, 437] -> 
             RGBColor[
              0.6369288642435347, 0.7132311402740368, 0.9665039571473427], 
             UndirectedEdge[29, 177] -> 
             RGBColor[
              0.5363573587848032, 0.6256510106448236, 0.9594825320086027], 
             UndirectedEdge[202, 285] -> 
             RGBColor[
              0.8798221229067211, 0.8864482869181092, 0.6784064674932404], 
             UndirectedEdge[182, 460] -> 
             RGBColor[
              0.9770136549561925, 0.9449445159824086, 0.5976905202391576], 
             UndirectedEdge[116, 333] -> 
             RGBColor[
              0.6075983503059703, 0.572084179397487, 0.5967964685722064], 
             UndirectedEdge[405, 472] -> 
             RGBColor[
              0.8656480232664463, 0.8957082526357729, 0.9870474753039085], 
             UndirectedEdge[51, 96] -> 
             RGBColor[
              0.6447711721087457, 0.7083114855005059, 0.718423176376644], 
             UndirectedEdge[115, 402] -> 
             RGBColor[
              0.48163382664166643`, 0.5895412090690422, 0.9524759999459631], 
             UndirectedEdge[67, 120] -> 
             RGBColor[
              0.6367010876700154, 0.7148865767829256, 0.9652639490249886], 
             UndirectedEdge[72, 222] -> 
             RGBColor[
              0.6356925634857997, 0.7010310105650032, 0.8623027136484697], 
             UndirectedEdge[84, 328] -> 
             RGBColor[
              0.8747710981909483, 0.41502949520579946`, 0.24760896612762207`],
              UndirectedEdge[123, 401] -> 
             RGBColor[
              0.8761599254862817, 0.41916350249146883`, 0.2998431851915654], 
             UndirectedEdge[143, 178] -> 
             RGBColor[
              0.9438920124318041, 0.8979983221012086, 0.6357334024494209], 
             UndirectedEdge[2, 385] -> 
             RGBColor[
              0.850884023972234, 0.8831091839737532, 0.9237502963788096], 
             UndirectedEdge[113, 487] -> 
             RGBColor[
              0.612091008679021, 0.6890062774908454, 0.9661695912772406], 
             UndirectedEdge[12, 430] -> 
             RGBColor[
              0.9692728103251878, 0.973133763788993, 0.7252075841768395], 
             UndirectedEdge[72, 344] -> 
             RGBColor[
              0.5922125206082829, 0.6690740143517184, 0.9650096978252016], 
             UndirectedEdge[127, 221] -> 
             RGBColor[
              0.5739947256452245, 0.6586907444514303, 0.9625076638771184], 
             UndirectedEdge[466, 491] -> 
             RGBColor[
              0.9297388634178858, 0.7481200787276139, 0.5265303868920599], 
             UndirectedEdge[236, 289] -> 
             RGBColor[
              0.8737173215119458, 0.9016541318378224, 0.9597039844437624], 
             UndirectedEdge[200, 298] -> 
             RGBColor[
              0.7629608663098282, 0.8150193837554507, 0.97715362139206], 
             UndirectedEdge[231, 431] -> 
             RGBColor[
              0.8478377640785997, 0.8778507867590081, 0.7496969927961894], 
             UndirectedEdge[171, 238] -> 
             RGBColor[
              0.9267759779939139, 0.8406307192370726, 0.6252238438715768], 
             UndirectedEdge[276, 306] -> 
             RGBColor[
              0.6744631680920732, 0.7121290590977343, 0.6501688452285259], 
             UndirectedEdge[294, 296] -> 
             RGBColor[
              0.7719415151715184, 0.8210714502285994, 0.9483445858958706], 
             UndirectedEdge[1, 119] -> 
             RGBColor[
              0.9466658838195627, 0.9597440839960059, 0.9751649263148776], 
             UndirectedEdge[103, 444] -> 
             RGBColor[
              0.6326794553125107, 0.7087038954135042, 0.9666229344535923], 
             UndirectedEdge[331, 486] -> 
             RGBColor[
              0.9153708269051815, 0.9332597657717353, 0.9117155629242122], 
             UndirectedEdge[100, 281] -> 
             RGBColor[
              0.7892909499817061, 0.8348849261892519, 0.9424263342759931], 
             UndirectedEdge[161, 477] -> 
             RGBColor[
              0.5110900367464368, 0.6015989676569902, 0.9576469356817322], 
             UndirectedEdge[391, 475] -> 
             RGBColor[
              0.5201128997280654, 0.6209953587041002, 0.9554457794795919], 
             UndirectedEdge[2, 312] -> 
             RGBColor[
              0.6318896747402115, 0.7109169546299107, 0.9649285925343438], 
             UndirectedEdge[264, 341] -> 
             RGBColor[
              0.34405386876331934`, 0.46877119592356287`, 0.9432775296130431],
              UndirectedEdge[73, 434] -> 
             RGBColor[
              0.9664167968947606, 0.9542377401133688, 0.670694439487471], 
             UndirectedEdge[241, 271] -> 
             RGBColor[
              0.6186828310996548, 0.6925715142530378, 0.9647509292503103], 
             UndirectedEdge[49, 51] -> 
             RGBColor[
              0.2897765796938736, 0.4219039365275473, 0.9398137195763085], 
             UndirectedEdge[5, 275] -> 
             RGBColor[
              0.8383678757900248, 0.8699769740974257, 0.7106388431521349], 
             UndirectedEdge[18, 274] -> 
             RGBColor[
              0.6852873884169035, 0.2691729778077342, 0.4254990030764131], 
             UndirectedEdge[219, 445] -> 
             RGBColor[
              0.8990244616371048, 0.9196036049866609, 0.8780687871293689], 
             UndirectedEdge[177, 297] -> 
             RGBColor[
              0.4352735422026196, 0.5457945128728656, 0.9500152915564912], 
             UndirectedEdge[250, 365] -> 
             RGBColor[
              0.6229941579891501, 0.6977812332437558, 0.9671722176065144], 
             UndirectedEdge[325, 474] -> 
             RGBColor[
              0.9907297479329218, 0.988574574281021, 0.668096685385364], 
             UndirectedEdge[266, 403] -> 
             RGBColor[
              0.4015127097979255, 0.517652241067591, 0.9474243017479858], 
             UndirectedEdge[214, 470] -> 
             RGBColor[
              0.8344785447369197, 0.3888245556362856, 0.4385946293358226], 
             UndirectedEdge[152, 481] -> 
             RGBColor[
              0.7572922563691175, 0.8096712715184184, 0.9604075614327576], 
             UndirectedEdge[289, 466] -> 
             RGBColor[
              0.9189774141747781, 0.7408217625086142, 0.5773281130872203], 
             UndirectedEdge[126, 269] -> 
             RGBColor[
              0.8286117287176601, 0.8669498329629035, 0.9833097061045626], 
             UndirectedEdge[183, 396] -> 
             RGBColor[
              0.28843396967549817`, 0.4201580672972032, 0.9397495149642305], 
             UndirectedEdge[54, 99] -> 
             RGBColor[
              0.9064168763246028, 0.9231648383043334, 0.7195816643817028], 
             UndirectedEdge[129, 306] -> 
             RGBColor[
              0.5941475346136502, 0.6337891665734422, 0.6453724825216306], 
             UndirectedEdge[172, 236] -> 
             RGBColor[
              0.8831348385444449, 0.8962032469910544, 0.6892026874224337], 
             UndirectedEdge[162, 284] -> 
             RGBColor[
              0.7167997740455673, 0.7768804881020137, 0.9594416710914453], 
             UndirectedEdge[10, 189] -> 
             RGBColor[
              0.33954680272898274`, 0.46852010723048687`, 0.9428565999138103],
              UndirectedEdge[213, 332] -> 
             RGBColor[
              0.7029979818431481, 0.7670650148315064, 0.971607346279386], 
             UndirectedEdge[199, 245] -> 
             RGBColor[
              0.6717315346627699, 0.7377609357732214, 0.9438342539774371], 
             UndirectedEdge[123, 139] -> 
             RGBColor[
              0.9675005016707968, 0.89682974006473, 0.4213035461176699], 
             UndirectedEdge[391, 482] -> 
             RGBColor[
              0.6773774381004682, 0.7452808554450764, 0.9704553748890661], 
             UndirectedEdge[184, 354] -> 
             RGBColor[
              0.8394114364023049, 0.40018462508780367`, 0.4399946442960701], 
             UndirectedEdge[25, 316] -> 
             RGBColor[
              0.36353682849431057`, 0.4840506505877087, 0.9446869403093285], 
             UndirectedEdge[106, 479] -> 
             RGBColor[
              0.753010985531706, 0.5194965005797676, 0.45605252248511985`], 
             UndirectedEdge[118, 260] -> 
             RGBColor[
              0.5198857533760015, 0.621105701033753, 0.9553464573914741], 
             UndirectedEdge[304, 469] -> 
             RGBColor[
              0.7364419102447375, 0.3112834716846981, 0.42936555659845665`], 
             UndirectedEdge[93, 236] -> 
             RGBColor[
              0.8674908015839466, 0.8970104034705113, 0.9702438585453799], 
             UndirectedEdge[343, 445] -> 
             RGBColor[
              0.874644909299737, 0.9005581134092489, 0.8756388611922499], 
             UndirectedEdge[204, 444] -> 
             RGBColor[
              0.7014559825854065, 0.761626826717408, 0.9008593019819384], 
             UndirectedEdge[150, 412] -> 
             RGBColor[
              0.7274892684453227, 0.3040153137600162, 0.4286607718413993], 
             UndirectedEdge[14, 239] -> 
             RGBColor[
              0.7497643639562688, 0.6125362147484196, 0.5898611467396211], 
             UndirectedEdge[70, 442] -> 
             RGBColor[
              0.8007986095990256, 0.7963723278666077, 0.6291420076386405], 
             UndirectedEdge[93, 493] -> 
             RGBColor[
              0.8854517430706256, 0.911041627468116, 0.9720340373382309], 
             UndirectedEdge[228, 279] -> 
             RGBColor[
              0.692955765689083, 0.6707438934202488, 0.6078373700104475], 
             UndirectedEdge[300, 456] -> 
             RGBColor[
              0.5109666285366294, 0.613068152162888, 0.9548644145869187], 
             UndirectedEdge[168, 326] -> 
             RGBColor[
              0.5902960606587693, 0.6663382023946679, 0.9650098591933096], 
             UndirectedEdge[193, 437] -> 
             RGBColor[
              0.4437461010544319, 0.5587723022309785, 0.9494960870632863], 
             UndirectedEdge[224, 361] -> 
             RGBColor[
              0.6842633886550342, 0.7462447218643332, 0.8817263853793489], 
             UndirectedEdge[12, 477] -> 
             RGBColor[
              0.6236021634919517, 0.6859455359502649, 0.7056193472681154], 
             UndirectedEdge[212, 224] -> 
             RGBColor[
              0.5271936937152035, 0.624501608800499, 0.9568308061839359], 
             UndirectedEdge[220, 490] -> 
             RGBColor[
              0.6290353763920369, 0.21698146318033038`, 0.4220416861707428], 
             UndirectedEdge[175, 208] -> 
             RGBColor[
              0.6942367698755081, 0.7587264006155441, 0.9667594418803167], 
             UndirectedEdge[242, 419] -> 
             RGBColor[
              0.7553470993891669, 0.8063935916668576, 0.9040525120835934], 
             UndirectedEdge[164, 205] -> 
             RGBColor[
              0.31761764453363306`, 0.44481547721767767`, 0.941631774978406], 
             UndirectedEdge[257, 322] -> 
             RGBColor[
              0.9712202566991244, 0.9145813094203795, 0.3426965611849315], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.6553620808741647, 0.7183927246563311, 0.6989725238972647], 
             UndirectedEdge[26, 67] -> 
             RGBColor[
              0.7578732202009473, 0.7545461867892426, 0.6200905867126387], 
             UndirectedEdge[366, 488] -> 
             RGBColor[
              0.37688172422461125`, 0.49626841442818587`, 0.9456115394590007],
              UndirectedEdge[12, 243] -> 
             RGBColor[
              0.9326198879611677, 0.750160723099516, 0.3442999331676607], 
             UndirectedEdge[271, 307] -> 
             RGBColor[
              0.7767619497572786, 0.8260020094706049, 0.9760044429968485], 
             UndirectedEdge[9, 352] -> 
             RGBColor[
              0.7617143484245155, 0.813776305323477, 0.9768842256918093], 
             UndirectedEdge[404, 431] -> 
             RGBColor[
              0.935281511975975, 0.7616397854647883, 0.37380578238599155`], 
             UndirectedEdge[256, 287] -> 
             RGBColor[
              0.8974919305412856, 0.9173086609159082, 0.8081223767552415], 
             UndirectedEdge[254, 412] -> 
             RGBColor[
              0.7264656823413997, 0.6526291388303047, 0.6000235032516024], 
             UndirectedEdge[42, 380] -> 
             RGBColor[
              0.9640926787162019, 0.8898735801600003, 0.3184692182938227], 
             UndirectedEdge[379, 404] -> 
             RGBColor[
              0.7097451204141333, 0.587123232572956, 0.5881447926656573], 
             UndirectedEdge[134, 424] -> 
             RGBColor[
              0.9689367571570414, 0.9684330704620892, 0.692573231056582], 
             UndirectedEdge[38, 253] -> 
             RGBColor[
              0.9508164599939234, 0.839148559578666, 0.5335382733720919], 
             UndirectedEdge[103, 348] -> 
             RGBColor[
              0.7472001372960109, 0.8026812295388803, 0.9753729577338974], 
             UndirectedEdge[42, 452] -> 
             RGBColor[
              0.9726732403950704, 0.9225051295397488, 0.5349848901681591], 
             UndirectedEdge[164, 331] -> 
             RGBColor[
              0.6231968529418519, 0.6889215279782026, 0.8883089856594508], 
             UndirectedEdge[6, 181] -> 
             RGBColor[
              0.8943303801477342, 0.7466485996254912, 0.6078762308385277], 
             UndirectedEdge[172, 197] -> 
             RGBColor[
              0.6929773662960012, 0.7424934744901547, 0.6731866376284454], 
             UndirectedEdge[80, 258] -> 
             RGBColor[
              0.921547593365165, 0.7231322314035298, 0.25555058290731225`], 
             UndirectedEdge[223, 268] -> 
             RGBColor[
              0.8720120723174968, 0.8999524442969924, 0.9411765295621819], 
             UndirectedEdge[5, 69] -> 
             RGBColor[
              0.8340960042512751, 0.8703957175276941, 0.940281022100468], 
             UndirectedEdge[306, 486] -> 
             RGBColor[
              0.9082984252539952, 0.9012265372115156, 0.6700306126792133], 
             UndirectedEdge[5, 348] -> 
             RGBColor[
              0.6641361497654876, 0.7375474749092672, 0.9671585427695887], 
             UndirectedEdge[279, 409] -> 
             RGBColor[
              0.7093569082697673, 0.3841257224345036, 0.43936629161910223`], 
             UndirectedEdge[463, 483] -> 
             RGBColor[
              0.46194232791257706`, 0.574064617920975, 0.9507849386852322], 
             UndirectedEdge[351, 371] -> 
             RGBColor[
              0.26854446626532813`, 0.3995876391204022, 0.93860458212665], 
             UndirectedEdge[335, 421] -> 
             RGBColor[
              0.6205776666324067, 0.6990814125953267, 0.9654561541165351], 
             UndirectedEdge[259, 418] -> 
             RGBColor[
              0.8680639172778383, 0.3924045990649092, 0.22155283482502497`], 
             UndirectedEdge[168, 302] -> 
             RGBColor[
              0.6245966505997562, 0.6925683307520685, 0.9294423681925164], 
             UndirectedEdge[87, 336] -> 
             RGBColor[
              0.8534986666336316, 0.8830871800040825, 0.8154627301210664], 
             UndirectedEdge[36, 266] -> 
             RGBColor[
              0.6366346333579539, 0.6997706473856256, 0.7190778466322749], 
             UndirectedEdge[161, 430] -> 
             RGBColor[
              0.8567606835796728, 0.8887871954957183, 0.9772351725904564], 
             UndirectedEdge[220, 412] -> 
             RGBColor[
              0.7274892684453227, 0.3040153137600162, 0.4286607718413993], 
             UndirectedEdge[372, 404] -> 
             RGBColor[
              0.7562644290968141, 0.6248897030325303, 0.5918069630510006], 
             UndirectedEdge[38, 287] -> 
             RGBColor[
              0.8951621107571266, 0.9170772838689789, 0.8999467943581093], 
             UndirectedEdge[171, 497] -> 
             RGBColor[
              0.9398960403660794, 0.8926473945410986, 0.6357805540236663], 
             UndirectedEdge[246, 411] -> 
             RGBColor[
              0.6432927207897422, 0.7201248540521696, 0.9658601987093978], 
             UndirectedEdge[75, 303] -> 
             RGBColor[
              0.9940552938779574, 0.9896931996439651, 0.5943336089683067], 
             UndirectedEdge[23, 39] -> 
             RGBColor[
              0.8635334081857636, 0.8900753084560682, 0.7482950913710615], 
             UndirectedEdge[61, 391] -> 
             RGBColor[
              0.6971115342385852, 0.7606021066007949, 0.9579777001690274], 
             UndirectedEdge[19, 200] -> 
             RGBColor[
              0.6127850555383256, 0.6891097715437289, 0.9664217354623488], 
             UndirectedEdge[208, 403] -> 
             RGBColor[
              0.7322435636154834, 0.789755721339717, 0.9697034839087206], 
             UndirectedEdge[108, 378] -> 
             RGBColor[
              0.9689769116694478, 0.9747730034098014, 0.8652718308882039], 
             UndirectedEdge[10, 451] -> 
             RGBColor[
              0.30607804244843284`, 0.4347397784247816, 0.9408994356615406], 
             UndirectedEdge[199, 262] -> 
             RGBColor[
              0.60333020412107, 0.6840015585782946, 0.9644220567718219], 
             UndirectedEdge[3, 401] -> 
             RGBColor[
              0.7623420443251853, 0.332207944968246, 0.4314745367491424], 
             UndirectedEdge[241, 311] -> 
             RGBColor[
              0.5374520300624576, 0.6282258538464988, 0.9593193883981259], 
             UndirectedEdge[179, 255] -> 
             RGBColor[
              0.5806897804816702, 0.6545362603616207, 0.9647211115862517], 
             UndirectedEdge[276, 462] -> 
             RGBColor[
              0.39558406076219954`, 0.5170567636243767, 0.9464272444438853], 
             UndirectedEdge[167, 289] -> 
             RGBColor[
              0.9428435556563588, 0.8450410361250267, 0.5970278640645232], 
             UndirectedEdge[164, 348] -> 
             RGBColor[
              0.45104061673641516`, 0.5551650250742651, 0.9515862354768448], 
             UndirectedEdge[18, 172] -> 
             RGBColor[
              0.703553782862641, 0.751654234934025, 0.6738605575397137], 
             UndirectedEdge[289, 300] -> 
             RGBColor[
              0.6955140719701145, 0.758298506208687, 0.9444496471499353], 
             UndirectedEdge[59, 188] -> 
             RGBColor[
              0.9565447422999932, 0.853022471255303, 0.4344618324036332], 
             UndirectedEdge[352, 357] -> 
             RGBColor[
              0.8959703154050986, 0.9183591104635382, 0.92952155790544], 
             UndirectedEdge[161, 409] -> 
             RGBColor[
              0.8146505952363522, 0.4683487329378798, 0.44852571234330796`], 
             UndirectedEdge[39, 157] -> 
             RGBColor[
              0.968574351486732, 0.972926773431054, 0.7512980307139298], 
             UndirectedEdge[216, 398] -> 
             RGBColor[
              0.5973738161847357, 0.6797016874158448, 0.9636670575961456], 
             UndirectedEdge[279, 396] -> 
             RGBColor[
              0.35827060169186975`, 0.4806470478585986, 0.9441994434022047], 
             UndirectedEdge[103, 390] -> 
             RGBColor[
              0.7031015595393351, 0.7669095282111743, 0.9718811795185192], 
             UndirectedEdge[128, 296] -> 
             RGBColor[
              0.7526809942525694, 0.7142249895448038, 0.6113688770973924], 
             UndirectedEdge[362, 369] -> 
             RGBColor[
              0.5904260952380015, 0.6772356820392391, 0.9616776032468902], 
             UndirectedEdge[86, 412] -> 
             RGBColor[
              0.6767673896031079, 0.7459670287714341, 0.9694075578223349], 
             UndirectedEdge[261, 299] -> 
             RGBColor[
              0.7008690155451334, 0.6885992904660806, 0.6110746106445135], 
             UndirectedEdge[208, 266] -> 
             RGBColor[
              0.6108216797307582, 0.6838270754639266, 0.9615413123880229], 
             UndirectedEdge[211, 236] -> 
             RGBColor[
              0.8696616957440828, 0.8986294527806278, 0.9665691009921469], 
             UndirectedEdge[19, 124] -> 
             RGBColor[
              0.5685868455807928, 0.6538673186520413, 0.9622060707403914], 
             UndirectedEdge[319, 330] -> 
             RGBColor[
              0.78708579078667, 0.8336084915269586, 0.9560339038590727], 
             UndirectedEdge[137, 267] -> 
             RGBColor[
              0.8212863018303977, 0.37830541923651906`, 0.43733634143054423`],
              UndirectedEdge[23, 240] -> 
             RGBColor[
              0.7551621751323889, 0.8086576977493063, 0.9762311662915908], 
             UndirectedEdge[135, 369] -> 
             RGBColor[
              0.8222211554290733, 0.8619161612331421, 0.9826837151715373], 
             UndirectedEdge[13, 335] -> 
             RGBColor[
              0.6835572458337806, 0.2676744152617278, 0.4253887599209214], 
             UndirectedEdge[176, 178] -> 
             RGBColor[
              0.9479055770636373, 0.9009916320320208, 0.6289394844330338], 
             UndirectedEdge[335, 459] -> 
             RGBColor[
              0.6607381345499113, 0.5987937117606325, 0.5952526625095477], 
             UndirectedEdge[83, 326] -> 
             RGBColor[
              0.7319980177281254, 0.789931738848409, 0.9746592650496662], 
             UndirectedEdge[33, 76] -> 
             RGBColor[
              0.9454300289952701, 0.8062997776107577, 0.44622216731090525`], 
             UndirectedEdge[13, 285] -> 
             RGBColor[
              0.8716637779873613, 0.40454777452562063`, 0.23553761390486924`],
              UndirectedEdge[225, 309] -> 
             RGBColor[
              0.8182277062132116, 0.3758665781147411, 0.4370446098501365], 
             UndirectedEdge[242, 499] -> 
             RGBColor[
              0.39746804414489867`, 0.5134010410196457, 0.9471939640225925], 
             UndirectedEdge[13, 287] -> 
             RGBColor[
              0.8117294821840424, 0.370789786782015, 0.43639701500306616`], 
             UndirectedEdge[265, 270] -> 
             RGBColor[
              0.5928132268718821, 0.6762487055303331, 0.9631660343969135], 
             UndirectedEdge[191, 311] -> 
             RGBColor[
              0.6059867932662335, 0.6884910614782126, 0.9636532688818715], 
             UndirectedEdge[47, 452] -> 
             RGBColor[
              0.9933274388604434, 0.9912857457870423, 0.7440359027604332], 
             UndirectedEdge[14, 80] -> 
             RGBColor[
              0.91223276457405, 0.6808357693966132, 0.24777806143665881`], 
             UndirectedEdge[152, 292] -> 
             RGBColor[
              0.8870812295981856, 0.9123202827946597, 0.9724843783299975], 
             UndirectedEdge[133, 311] -> 
             RGBColor[
              0.8665926394807105, 0.8461729050128364, 0.6333658604197745], 
             UndirectedEdge[187, 398] -> 
             RGBColor[
              0.7493228911956594, 0.8040960047577317, 0.9756491610399884], 
             UndirectedEdge[130, 442] -> 
             RGBColor[
              0.8643741966291691, 0.37995830492934124`, 0.2072189668502241], 
             UndirectedEdge[304, 433] -> 
             RGBColor[
              0.8577487780387825, 0.4073295922067915, 0.43908008540562904`], 
             UndirectedEdge[354, 409] -> 
             RGBColor[
              0.8521311865598542, 0.49795419862878754`, 0.4521750914118424], 
             UndirectedEdge[29, 412] -> 
             RGBColor[
              0.6671597462518573, 0.7384614647646432, 0.9684499577216141], 
             UndirectedEdge[295, 391] -> 
             RGBColor[
              0.385232846443258, 0.5080910620484687, 0.9457676742207017], 
             UndirectedEdge[21, 298] -> 
             RGBColor[
              0.7855894170263136, 0.8323685119057274, 0.9552413855992247], 
             UndirectedEdge[383, 395] -> 
             RGBColor[
              0.5453750902007602, 0.6368434418394702, 0.9594308803336615], 
             UndirectedEdge[133, 241] -> 
             RGBColor[
              0.6281107997034199, 0.6495140553339129, 0.6143837541204035], 
             UndirectedEdge[142, 473] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[95, 330] -> 
             RGBColor[
              0.9772999993079654, 0.9789778733954013, 0.7003085339122959], 
             UndirectedEdge[275, 431] -> 
             RGBColor[
              0.9930993941688113, 0.9876486268223874, 0.49028982475694094`], 
             UndirectedEdge[180, 474] -> 
             RGBColor[
              0.7944013130118202, 0.8351708397373843, 0.7272493358195358], 
             UndirectedEdge[82, 173] -> 
             RGBColor[
              0.2623601242285354, 0.39308750352980065`, 0.9382523929965687], 
             UndirectedEdge[205, 230] -> 
             RGBColor[
              0.6743387015659745, 0.7397053565807875, 0.9394210004683439], 
             UndirectedEdge[460, 463] -> 
             RGBColor[
              0.7232447184630928, 0.7805203532493549, 0.9094229179205773], 
             UndirectedEdge[121, 500] -> 
             RGBColor[
              0.44246596369690394`, 0.5520523957874459, 0.9505433879907703], 
             UndirectedEdge[88, 241] -> 
             RGBColor[
              0.6194249439189823, 0.6931249807785939, 0.963494725821211], 
             UndirectedEdge[60, 73] -> 
             RGBColor[
              0.6315718067371805, 0.679535727588018, 0.658072077417255], 
             UndirectedEdge[75, 400] -> 
             RGBColor[
              0.9801908658850391, 0.9828087529898487, 0.8283093004660138], 
             UndirectedEdge[141, 274] -> 
             RGBColor[
              0.8302782870190946, 0.23373775882454273`, 0.17662782788490622`],
              UndirectedEdge[299, 448] -> 
             RGBColor[
              0.9292655944130745, 0.8705958073519546, 0.6317267683500012], 
             UndirectedEdge[160, 389] -> 
             RGBColor[
              0.9898774921091951, 0.9890716653495712, 0.7439719607442908], 
             UndirectedEdge[24, 268] -> 
             RGBColor[
              0.8767909241847249, 0.9009164987967602, 0.7884078886867276], 
             UndirectedEdge[386, 498] -> 
             RGBColor[
              0.9103012501351144, 0.8362067066410239, 0.6256034308463134], 
             UndirectedEdge[350, 476] -> 
             RGBColor[
              0.886486448168949, 0.49626906806310256`, 0.3538509106884321], 
             UndirectedEdge[180, 331] -> 
             RGBColor[
              0.7921372729158084, 0.8360945534762072, 0.8999692515752258], 
             UndirectedEdge[225, 252] -> 
             RGBColor[
              0.7476354564484684, 0.32037089675639674`, 0.43024675355892517`],
              UndirectedEdge[100, 203] -> 
             RGBColor[
              0.9806809014205755, 0.9851124284283616, 0.917586374053794], 
             UndirectedEdge[445, 471] -> 
             RGBColor[
              0.9739136158353092, 0.9786943685809577, 0.8676441284115636], 
             UndirectedEdge[373, 498] -> 
             RGBColor[
              0.8928121088841191, 0.8222613401375729, 0.6239353009410529], 
             UndirectedEdge[102, 309] -> 
             RGBColor[
              0.8901579188052418, 0.9146181410600926, 0.9674166593317275], 
             UndirectedEdge[46, 86] -> 
             RGBColor[
              0.8494541865985911, 0.7280427601168895, 0.6069337187528439], 
             UndirectedEdge[294, 385] -> 
             RGBColor[
              0.9777921014473346, 0.9825929806848203, 0.9061315645732337], 
             UndirectedEdge[27, 29] -> 
             RGBColor[
              0.6109052036871411, 0.6923028245308613, 0.9641564145824804], 
             UndirectedEdge[274, 284] -> 
             RGBColor[
              0.8621345285818178, 0.4106004777807798, 0.43165615372320887`], 
             UndirectedEdge[284, 300] -> 
             RGBColor[
              0.6878726816380545, 0.752599569810665, 0.9573845277883257], 
             UndirectedEdge[159, 453] -> 
             RGBColor[
              0.6799615808787549, 0.421671298639586, 0.445750995776512], 
             UndirectedEdge[229, 232] -> 
             RGBColor[
              0.9923366651937249, 0.9910990283659533, 0.77666482002212], 
             UndirectedEdge[259, 431] -> 
             RGBColor[
              0.9815018204827759, 0.9486790486514893, 0.4323307714874878], 
             UndirectedEdge[112, 483] -> 
             RGBColor[
              0.7087395120867951, 0.7702870314471131, 0.9574721606020817], 
             UndirectedEdge[78, 376] -> 
             RGBColor[
              0.9472551553899866, 0.9567600019391448, 0.8071202129161448], 
             UndirectedEdge[76, 351] -> 
             RGBColor[
              0.562554764957776, 0.48978498392151726`, 0.5857333777764343], 
             UndirectedEdge[178, 498] -> 
             RGBColor[
              0.9399960852329612, 0.7998115036076245, 0.2705776455867811], 
             UndirectedEdge[400, 431] -> 
             RGBColor[
              0.9793435462070726, 0.9809964218758391, 0.7360837825702735], 
             UndirectedEdge[18, 432] -> 
             RGBColor[
              0.6852873884169035, 0.2691729778077342, 0.4254990030764131], 
             UndirectedEdge[220, 325] -> 
             RGBColor[
              0.8743238320354785, 0.4192325383572021, 0.3904812305560025], 
             UndirectedEdge[353, 380] -> 
             RGBColor[
              0.9454228740753368, 0.8158540261025611, 0.30344705524314364`], 
             UndirectedEdge[5, 355] -> 
             RGBColor[
              0.4835777768856938, 0.584006816066049, 0.9542872429865329], 
             UndirectedEdge[367, 441] -> 
             RGBColor[
              0.9045800017275939, 0.8998674634524877, 0.6720384297830064], 
             UndirectedEdge[21, 287] -> 
             RGBColor[
              0.8815861053282763, 0.9078796568665726, 0.9644554139809375], 
             UndirectedEdge[175, 182] -> 
             RGBColor[
              0.7070686498510421, 0.7312986234337125, 0.638420154725411], 
             UndirectedEdge[70, 371] -> 
             RGBColor[
              0.4756590388578702, 0.5811987934730514, 0.9529631655564795], 
             UndirectedEdge[217, 496] -> 
             RGBColor[
              0.36093335931827786`, 0.48704406762854535`, 0.9442193323882908],
              UndirectedEdge[195, 292] -> 
             RGBColor[
              0.6192276364105662, 0.6980928180555833, 0.9652870803482715], 
             UndirectedEdge[161, 285] -> 
             RGBColor[
              0.8741368686048423, 0.8820069230479484, 0.6778398144761513], 
             UndirectedEdge[168, 370] -> 
             RGBColor[
              0.5810001884523508, 0.5017066145964884, 0.5851205279427981], 
             UndirectedEdge[50, 173] -> 
             RGBColor[
              0.269149647045529, 0.40022372249107097`, 0.9386390462767977], 
             UndirectedEdge[19, 188] -> 
             RGBColor[
              0.6135231933316458, 0.578606120694009, 0.5972094670710162], 
             UndirectedEdge[147, 323] -> 
             RGBColor[
              0.6189239458001922, 0.20635370852657378`, 0.42146585515705837`],
              UndirectedEdge[255, 260] -> 
             RGBColor[
              0.7223487397438633, 0.782000748203538, 0.9740115969228689], 
             UndirectedEdge[29, 350] -> 
             RGBColor[
              0.8169601446844267, 0.4433592128494219, 0.44542695464584625`], 
             UndirectedEdge[348, 400] -> 
             RGBColor[
              0.8047613252193095, 0.8478172494018172, 0.9544542684447677], 
             UndirectedEdge[26, 124] -> 
             RGBColor[
              0.8912731868195147, 0.8600602899816822, 0.6325275017112661], 
             UndirectedEdge[18, 93] -> 
             RGBColor[
              0.6879097459021428, 0.7524613914134819, 0.9549017286626598], 
             UndirectedEdge[64, 223] -> 
             RGBColor[
              0.9672990895961489, 0.9137699682888768, 0.592178577794753], 
             UndirectedEdge[12, 335] -> 
             RGBColor[
              0.7044891971199861, 0.7610434524453839, 0.7105889450866126], 
             UndirectedEdge[143, 498] -> 
             RGBColor[
              0.9328309112281944, 0.8541447417223695, 0.6268333807835815], 
             UndirectedEdge[44, 92] -> 
             RGBColor[
              0.8493377746724965, 0.8831176494548049, 0.9830398037413675], 
             UndirectedEdge[274, 389] -> 
             RGBColor[
              0.8762495794399884, 0.41935526323304206`, 0.30960146477246614`],
              UndirectedEdge[247, 401] -> 
             RGBColor[
              0.644536063428389, 0.23327366805585842`, 0.4229244273662516], 
             UndirectedEdge[111, 182] -> 
             RGBColor[
              0.8568839332434217, 0.8515030156415384, 0.6512574310896914], 
             UndirectedEdge[157, 190] -> 
             RGBColor[
              0.9256755126012088, 0.8144672313582757, 0.6123020812095663], 
             UndirectedEdge[100, 360] -> 
             RGBColor[
              0.9644865349812825, 0.9730346964537782, 0.9449992122682953], 
             UndirectedEdge[59, 468] -> 
             RGBColor[
              0.6255858791357998, 0.688739755553541, 0.7766553579679629], 
             UndirectedEdge[101, 129] -> 
             RGBColor[
              0.6043962581026167, 0.6668499597946491, 0.8136337546521555], 
             UndirectedEdge[180, 382] -> 
             RGBColor[
              0.7292434199965933, 0.7880408031625987, 0.9740448975166154], 
             UndirectedEdge[145, 402] -> 
             RGBColor[
              0.7010757783248404, 0.7266028192610163, 0.6387926103456181], 
             UndirectedEdge[90, 263] -> 
             RGBColor[
              0.7970535380438455, 0.8414280962147271, 0.9803946843465151], 
             UndirectedEdge[98, 276] -> 
             RGBColor[
              0.6697037399730448, 0.25567520478260874`, 0.4245060267776496], 
             UndirectedEdge[224, 464] -> 
             RGBColor[
              0.43516832255093946`, 0.5503019613996639, 0.9492370671745339], 
             UndirectedEdge[261, 313] -> 
             RGBColor[
              0.6878789864095384, 0.637098153614049, 0.6006225282868409], 
             UndirectedEdge[78, 219] -> 
             RGBColor[
              0.8528939370521225, 0.8856547147318314, 0.9858001368345781], 
             UndirectedEdge[393, 424] -> 
             RGBColor[
              0.8746625967006936, 0.4146634942018086, 0.24718745832676925`], 
             UndirectedEdge[169, 211] -> 
             RGBColor[
              0.9295928805990054, 0.8044150865750643, 0.5964351485820623], 
             UndirectedEdge[176, 482] -> 
             RGBColor[
              0.9285231295016589, 0.9456096529642191, 0.9849488744217145], 
             UndirectedEdge[35, 94] -> 
             RGBColor[
              0.946690024115735, 0.8198880998997395, 0.5187297117838234], 
             UndirectedEdge[114, 296] -> 
             RGBColor[
              0.6455673148397794, 0.7220047223995429, 0.9660165295857313], 
             UndirectedEdge[130, 175] -> 
             RGBColor[
              0.6938530020675666, 0.2765920818316785, 0.42604479640395854`], 
             UndirectedEdge[189, 383] -> 
             RGBColor[
              0.5398764664975747, 0.632080810356634, 0.9590805128935366], 
             UndirectedEdge[139, 437] -> 
             RGBColor[
              0.6947607295310059, 0.6835967678264323, 0.6106518797586598], 
             UndirectedEdge[56, 324] -> 
             RGBColor[
              0.5069471015422369, 0.6106015205954802, 0.9543278793232768], 
             UndirectedEdge[398, 399] -> 
             RGBColor[
              0.900017279250142, 0.9181746840560654, 0.7197251590790363], 
             UndirectedEdge[405, 429] -> 
             RGBColor[
              0.8072519496226648, 0.8496467405129189, 0.981344408380614], 
             UndirectedEdge[12, 318] -> 
             RGBColor[
              0.6387993246705911, 0.7019187159046858, 0.7064848031150537], 
             UndirectedEdge[11, 205] -> 
             RGBColor[
              0.4564148222308558, 0.5675168606978402, 0.9509190544438217], 
             UndirectedEdge[226, 389] -> 
             RGBColor[
              0.9161713242873726, 0.9318295890049797, 0.7924004481438005], 
             UndirectedEdge[294, 327] -> 
             RGBColor[
              0.7764368660504288, 0.8247209785853482, 0.9486984763840713], 
             UndirectedEdge[167, 218] -> 
             RGBColor[
              0.9276827916650908, 0.8337341631638118, 0.6226910829412111], 
             UndirectedEdge[217, 481] -> 
             RGBColor[
              0.483304823049275, 0.5901309827525795, 0.9528194205817483], 
             UndirectedEdge[247, 309] -> 
             RGBColor[
              0.5595076544624008, 0.6454563692558993, 0.9615175558245822], 
             UndirectedEdge[79, 234] -> 
             RGBColor[
              0.9281299324661569, 0.8363362628879436, 0.623694303755161], 
             UndirectedEdge[331, 372] -> 
             RGBColor[
              0.8120068214705501, 0.8522255481059083, 0.9015334552220096], 
             UndirectedEdge[27, 484] -> 
             RGBColor[
              0.7151866680671959, 0.7718484023018759, 0.8403068584741521], 
             UndirectedEdge[103, 326] -> 
             RGBColor[
              0.8803269637692872, 0.907412841343513, 0.9884475657531143], 
             UndirectedEdge[155, 394] -> 
             RGBColor[
              0.8228184383140136, 0.6603774119734314, 0.5951213042548354], 
             UndirectedEdge[433, 469] -> 
             RGBColor[
              0.7566480324252799, 0.8096655958372345, 0.9742324630061285], 
             UndirectedEdge[65, 412] -> 
             RGBColor[
              0.7593314077136277, 0.8107799142397346, 0.945901300428531], 
             UndirectedEdge[13, 161] -> 
             RGBColor[
              0.8008528010825335, 0.3622928408396782, 0.4353129290792316], 
             UndirectedEdge[229, 480] -> 
             RGBColor[
              0.875983809308845, 0.41991898161920915`, 0.3629711112528449], 
             UndirectedEdge[32, 448] -> 
             RGBColor[
              0.6930424123639645, 0.7582559624310292, 0.9716499262535159], 
             UndirectedEdge[251, 453] -> 
             RGBColor[
              0.8996321911810324, 0.5971606911851073, 0.36940150919690384`], 
             UndirectedEdge[282, 310] -> 
             RGBColor[
              0.9632297458603606, 0.971813960336031, 0.9344342846103083], 
             UndirectedEdge[392, 473] -> 
             RGBColor[
              0.6996176845011868, 0.28138790631361876`, 0.42646661865634083`],
              UndirectedEdge[222, 344] -> 
             RGBColor[
              0.948331181443232, 0.9589247488484784, 0.8880797192614549], 
             UndirectedEdge[266, 440] -> 
             RGBColor[
              0.49180637882440414`, 0.5900197711595778, 0.9551731398312997], 
             UndirectedEdge[16, 361] -> 
             RGBColor[
              0.6367928154730746, 0.7028169824045334, 0.8787862236709043], 
             UndirectedEdge[412, 426] -> 
             RGBColor[
              0.4578673790031607, 0.5684372263338459, 0.9511049358380724], 
             UndirectedEdge[274, 460] -> 
             RGBColor[
              0.8738163388043336, 0.4190226768641425, 0.3988917067464562], 
             UndirectedEdge[180, 230] -> 
             RGBColor[
              0.7834572633226172, 0.8303529998494379, 0.9474419521105139], 
             UndirectedEdge[375, 450] -> 
             RGBColor[
              0.6007146412926585, 0.6809458909785377, 0.9646191672135918], 
             UndirectedEdge[6, 123] -> 
             RGBColor[
              0.9389647430816016, 0.7778938469463241, 0.3980429190464173], 
             UndirectedEdge[170, 466] -> 
             RGBColor[
              0.9112123945538069, 0.7350306235893467, 0.5904722658640549], 
             UndirectedEdge[267, 280] -> 
             RGBColor[
              0.8840938928404751, 0.8311966531415633, 0.6266612736710523], 
             UndirectedEdge[52, 214] -> 
             RGBColor[
              0.7851455782621213, 0.8324755025895827, 0.9791149322740729], 
             UndirectedEdge[358, 386] -> 
             RGBColor[
              0.8825474277265292, 0.9091833790301291, 0.9886593555875876], 
             UndirectedEdge[230, 413] -> 
             RGBColor[
              0.6114199225535806, 0.6799249142396844, 0.9356053211369428], 
             UndirectedEdge[53, 207] -> 
             RGBColor[
              0.4563516088103924, 0.5687626012132694, 0.9505556965042679], 
             UndirectedEdge[188, 256] -> 
             RGBColor[
              0.9566371763942694, 0.853220178436439, 0.4445227131284833], 
             UndirectedEdge[38, 87] -> 
             RGBColor[
              0.9922114183846376, 0.990501208298636, 0.7390500637284685], 
             UndirectedEdge[22, 52] -> 
             RGBColor[
              0.5065286897840975, 0.605507012297358, 0.9559777639566074], 
             UndirectedEdge[160, 460] -> 
             RGBColor[
              0.986227631155713, 0.9885727857962219, 0.8779073237052759], 
             UndirectedEdge[63, 159] -> 
             RGBColor[
              0.5403442760783499, 0.6329677437394949, 0.9589064260061206], 
             UndirectedEdge[285, 430] -> 
             RGBColor[
              0.9629771489369146, 0.9521695960246319, 0.6775721998289129], 
             UndirectedEdge[132, 356] -> 
             RGBColor[
              0.6559145737491799, 0.30542730165264387`, 0.43174286265617223`],
              UndirectedEdge[99, 373] -> 
             RGBColor[
              0.8383671761892607, 0.8739552456952919, 0.9844454037557868], 
             UndirectedEdge[243, 396] -> 
             RGBColor[
              0.5683984901097995, 0.45417119590086935`, 0.5767633088320965], 
             UndirectedEdge[118, 292] -> 
             RGBColor[
              0.6694720766617137, 0.7398270929464343, 0.9689817942052557], 
             UndirectedEdge[84, 176] -> 
             RGBColor[
              0.8597973225635679, 0.40885739335919263`, 0.4356124338711491], 
             UndirectedEdge[334, 385] -> 
             RGBColor[
              0.9126291432389964, 0.9314975839469422, 0.929863965929072], 
             UndirectedEdge[25, 325] -> 
             RGBColor[
              0.7292419705826745, 0.7850859761317203, 0.8972194017011615], 
             UndirectedEdge[321, 397] -> 
             RGBColor[
              0.8464913666201171, 0.3984032537265838, 0.4397404230110147], 
             UndirectedEdge[201, 235] -> 
             RGBColor[
              0.8776569202342006, 0.9045261795293837, 0.9496893718662032], 
             UndirectedEdge[321, 498] -> 
             RGBColor[
              0.9168855419448515, 0.8414568422042684, 0.6262314464769929], 
             UndirectedEdge[368, 492] -> 
             RGBColor[
              0.8351647719226308, 0.3893717345670308, 0.43866008229739806`], 
             UndirectedEdge[239, 387] -> 
             RGBColor[
              0.7674141374219989, 0.43128234221072126`, 0.44393037414215963`],
              UndirectedEdge[196, 500] -> 
             RGBColor[
              0.7510034268732048, 0.6752289258969006, 0.6025719986977329], 
             UndirectedEdge[122, 185] -> 
             RGBColor[
              0.6472503716241185, 0.7131944224344648, 0.8633631997293937], 
             UndirectedEdge[350, 377] -> 
             RGBColor[
              0.8823865142103221, 0.4834946312161746, 0.24816257287991458`], 
             UndirectedEdge[315, 353] -> 
             RGBColor[0.9353461193377328, 0.83580692815279, 0.60689300541917],
              UndirectedEdge[102, 480] -> 
             RGBColor[
              0.864969572990283, 0.412714849258654, 0.42685716303768173`], 
             UndirectedEdge[127, 253] -> 
             RGBColor[
              0.6167402387132233, 0.5706259387789526, 0.5948262039162643], 
             UndirectedEdge[159, 192] -> 
             RGBColor[
              0.6304428326171407, 0.6024603244958012, 0.6004734801285869], 
             UndirectedEdge[201, 289] -> 
             RGBColor[
              0.972854669681751, 0.9792756376118247, 0.9308341429794769], 
             UndirectedEdge[29, 194] -> 
             RGBColor[
              0.8859255263446517, 0.8977067891089654, 0.688492849277393], 
             UndirectedEdge[79, 388] -> 
             RGBColor[
              0.9570598160244441, 0.8562708104735491, 0.501222243128234], 
             UndirectedEdge[246, 402] -> 
             RGBColor[
              0.501254207285121, 0.6054699179634739, 0.9540205881820383], 
             UndirectedEdge[185, 398] -> 
             RGBColor[
              0.8994971993742764, 0.9200982160299931, 0.8837977537102184], 
             UndirectedEdge[133, 304] -> 
             RGBColor[
              0.863963136373891, 0.3785717021667502, 0.20562207538068406`], 
             UndirectedEdge[107, 314] -> 
             RGBColor[
              0.9377306139248593, 0.9530801743386977, 0.990290007554987], 
             UndirectedEdge[13, 279] -> 
             RGBColor[
              0.6955591141159485, 0.278069830336302, 0.42615350835502575`], 
             UndirectedEdge[180, 418] -> 
             RGBColor[
              0.743438208754744, 0.3169633819947776, 0.42991633084545033`], 
             UndirectedEdge[112, 207] -> 
             RGBColor[
              0.7203833896091342, 0.7797400557704526, 0.9583888092935691], 
             UndirectedEdge[308, 369] -> 
             RGBColor[
              0.47788464903460737`, 0.5736175433390078, 0.9546604726918324], 
             UndirectedEdge[45, 292] -> 
             RGBColor[
              0.7751629783566336, 0.824282477239821, 0.9782246594388506], 
             UndirectedEdge[348, 418] -> 
             RGBColor[
              0.7596411490521704, 0.3300979850534024, 0.4312053367496296], 
             UndirectedEdge[51, 264] -> 
             RGBColor[
              0.2828116571233579, 0.41458336130433865`, 0.9394170775395974], 
             UndirectedEdge[201, 218] -> 
             RGBColor[
              0.9576939056904832, 0.9679687646506097, 0.9564973618561647], 
             UndirectedEdge[262, 376] -> 
             RGBColor[
              0.9117739150457413, 0.9284682240012557, 0.8037359805376335], 
             UndirectedEdge[304, 307] -> 
             RGBColor[
              0.7499221425334716, 0.3222273315342365, 0.4304267698639437], 
             UndirectedEdge[8, 166] -> 
             RGBColor[
              0.40710606398401905`, 0.5201899193466794, 0.9480469801387429], 
             UndirectedEdge[66, 312] -> 
             RGBColor[
              0.7540923276374003, 0.7601303334880289, 0.6279309164253535], 
             UndirectedEdge[202, 430] -> 
             RGBColor[
              0.8624459378815518, 0.8932285593658791, 0.9778018256075456], 
             UndirectedEdge[348, 404] -> 
             RGBColor[
              0.7606992909882119, 0.6284606129907664, 0.5921762682604856], 
             UndirectedEdge[1, 113] -> 
             RGBColor[
              0.9298142511721685, 0.946367667482641, 0.9756592643841575], 
             UndirectedEdge[29, 377] -> 
             RGBColor[
              0.8846292414565897, 0.8933341157993666, 0.683457027270133], 
             UndirectedEdge[259, 404] -> 
             RGBColor[
              0.9233334433267137, 0.7219205340080267, 0.2776975153735787], 
             UndirectedEdge[131, 449] -> 
             RGBColor[
              0.6197616921354443, 0.6854304516015055, 0.8912302777495962], 
             UndirectedEdge[423, 465] -> 
             RGBColor[
              0.9557869610407137, 0.9652408076904846, 0.90490193926247], 
             UndirectedEdge[177, 412] -> 
             RGBColor[
              0.41702741786891395`, 0.5309814871602293, 0.9485788898111862], 
             UndirectedEdge[139, 158] -> 
             RGBColor[
              0.9373549213791964, 0.7893401690431275, 0.2684525031539583], 
             UndirectedEdge[454, 500] -> 
             RGBColor[
              0.4394776053048451, 0.5489114416445267, 0.9503732054012226], 
             UndirectedEdge[430, 459] -> 
             RGBColor[
              0.9255217477551128, 0.8108840231042416, 0.6098713015997745], 
             UndirectedEdge[474, 490] -> 
             RGBColor[
              0.6227970644677593, 0.6851979615157135, 0.7154373688074747], 
             UndirectedEdge[443, 451] -> 
             RGBColor[
              0.5694632316014863, 0.6480612157405777, 0.9632751102180124], 
             UndirectedEdge[182, 483] -> 
             RGBColor[
              0.7157112644056768, 0.7384887806540286, 0.6390525410038124], 
             UndirectedEdge[92, 457] -> 
             RGBColor[
              0.831557060758281, 0.7319826473061386, 0.6086523628809342], 
             UndirectedEdge[38, 184] -> 
             RGBColor[
              0.8758819689836447, 0.4277173876878553, 0.38355718405064415`], 
             UndirectedEdge[51, 457] -> 
             RGBColor[
              0.5995607799474343, 0.5400414781510665, 0.5903719104889154], 
             UndirectedEdge[321, 455] -> 
             RGBColor[
              0.5786521145182311, 0.6548230753603712, 0.9642371637726364], 
             UndirectedEdge[251, 435] -> 
             RGBColor[
              0.7018301359276073, 0.760144347858751, 0.8304209181191904], 
             UndirectedEdge[16, 441] -> 
             RGBColor[
              0.6297246527698606, 0.6726307087833285, 0.6497849907189372], 
             UndirectedEdge[302, 390] -> 
             RGBColor[
              0.7676142858140985, 0.8172299939945342, 0.939195349051934], 
             UndirectedEdge[186, 455] -> 
             RGBColor[
              0.6234014022182381, 0.6864905788560686, 0.7812158034068286], 
             UndirectedEdge[349, 353] -> 
             RGBColor[
              0.9551807579627345, 0.8489724284713371, 0.500451451309945], 
             UndirectedEdge[125, 406] -> 
             RGBColor[
              0.42662044266902505`, 0.539701677564443, 0.9492492386186444], 
             UndirectedEdge[307, 433] -> 
             RGBColor[
              0.776868380858381, 0.8260813856115421, 0.9758242829043591], 
             UndirectedEdge[406, 419] -> 
             RGBColor[
              0.6408889280814285, 0.707784249234359, 0.8962869136922654], 
             UndirectedEdge[237, 274] -> 
             RGBColor[
              0.8762041135174123, 0.419258016221962, 0.3046527796832212], 
             UndirectedEdge[203, 264] -> 
             RGBColor[
              0.6265907883775947, 0.6939312873919434, 0.9253545458907686], 
             UndirectedEdge[69, 231] -> 
             RGBColor[
              0.843215397576624, 0.8775198569034129, 0.9411899580015629], 
             UndirectedEdge[328, 399] -> 
             RGBColor[
              0.9912391482691596, 0.9819245797433479, 0.4362101304635946], 
             UndirectedEdge[78, 262] -> 
             RGBColor[
              0.8647021458354386, 0.8949540356474462, 0.9869572566701441], 
             UndirectedEdge[27, 412] -> 
             RGBColor[
              0.49157526277125185`, 0.5976333010462669, 0.9532527723850639], 
             UndirectedEdge[147, 221] -> 
             RGBColor[
              0.5242509781451499, 0.6075973243450479, 0.9596312442150234], 
             UndirectedEdge[93, 289] -> 
             RGBColor[
              0.9608218464815741, 0.9703015777710724, 0.9512025739944631], 
             UndirectedEdge[141, 235] -> 
             RGBColor[
              0.8167229095239187, 0.46417755548237655`, 0.44801288044033893`],
              UndirectedEdge[185, 464] -> 
             RGBColor[
              0.7417045161682916, 0.7945206446120813, 0.8696489436669719], 
             UndirectedEdge[6, 189] -> 
             RGBColor[
              0.6039742210975829, 0.5107424040066179, 0.5834246899535097], 
             UndirectedEdge[38, 316] -> 
             RGBColor[
              0.6233484934459169, 0.6887060856877478, 0.8785406562956808], 
             UndirectedEdge[322, 343] -> 
             RGBColor[
              0.8669355755598684, 0.8720686472608973, 0.6708244042754552], 
             UndirectedEdge[93, 141] -> 
             RGBColor[
              0.8760370625369529, 0.5109147086257966, 0.44246931058359973`], 
             UndirectedEdge[191, 237] -> 
             RGBColor[
              0.715007028622478, 0.7708087340484444, 0.7672636910579549], 
             UndirectedEdge[145, 461] -> 
             RGBColor[
              0.9379566405989879, 0.9160631619315649, 0.6598957878906273], 
             UndirectedEdge[420, 500] -> 
             RGBColor[
              0.7946341934095793, 0.8359812855840133, 0.7781961172646004], 
             UndirectedEdge[402, 458] -> 
             RGBColor[
              0.4119373979039922, 0.5312212023139737, 0.947469264625872], 
             UndirectedEdge[148, 263] -> 
             RGBColor[
              0.6553832922713986, 0.7283478370248246, 0.9679195777959434], 
             UndirectedEdge[126, 499] -> 
             RGBColor[
              0.6024586484331316, 0.6762834743826098, 0.966132495445693], 
             UndirectedEdge[133, 371] -> 
             RGBColor[
              0.6327284287634348, 0.6543674762505809, 0.6146467212642013], 
             UndirectedEdge[72, 245] -> 
             RGBColor[
              0.6227987346127217, 0.692680644083827, 0.9408150554575399], 
             UndirectedEdge[57, 131] -> 
             RGBColor[
              0.5835750270535085, 0.6473959722333085, 0.8891695007065534], 
             UndirectedEdge[15, 173] -> 
             RGBColor[
              0.6319245963060623, 0.23087346998304242`, 0.4236796608194692], 
             UndirectedEdge[138, 415] -> 
             RGBColor[
              0.913213513149614, 0.9328824985361786, 0.9654709312387543], 
             UndirectedEdge[105, 109] -> 
             RGBColor[
              0.671600179014658, 0.6991999883021494, 0.6340604676897484], 
             UndirectedEdge[235, 284] -> 
             RGBColor[
              0.8642092266299629, 0.8944969116579204, 0.9724528094179624], 
             UndirectedEdge[150, 473] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[74, 417] -> 
             RGBColor[
              0.7491366248332187, 0.32158961287800225`, 0.43036493103313367`],
              UndirectedEdge[20, 413] -> 
             RGBColor[
              0.2994727582219643, 0.4285266257081981, 0.9404965668642863], 
             UndirectedEdge[34, 467] -> 
             RGBColor[
              0.6441320673019257, 0.6802095060546922, 0.63962753533801], 
             UndirectedEdge[62, 110] -> 
             RGBColor[
              0.7447661872621555, 0.7999360331734925, 0.9710616401762102], 
             UndirectedEdge[93, 389] -> 
             RGBColor[
              0.97435303243677, 0.9777348195514438, 0.7810554212067395], 
             UndirectedEdge[28, 408] -> 
             RGBColor[
              0.6349196882191848, 0.7067260283376922, 0.9538889833172626], 
             UndirectedEdge[93, 284] -> 
             RGBColor[
              0.9531804561495143, 0.9646026413730504, 0.9641374546328536], 
             UndirectedEdge[143, 313] -> 
             RGBColor[
              0.9259241341936257, 0.8267616723273141, 0.6212760258586738], 
             UndirectedEdge[361, 398] -> 
             RGBColor[
              0.8985339394329197, 0.9196998832895907, 0.899761463775318], 
             UndirectedEdge[105, 382] -> 
             RGBColor[
              0.6199466332033804, 0.697238790325122, 0.9660125895327134], 
             UndirectedEdge[240, 495] -> 
             RGBColor[
              0.700365841378306, 0.7655703562370659, 0.9709610372798181], 
             UndirectedEdge[13, 21] -> 
             RGBColor[
              0.8657532547014751, 0.4132993177957, 0.4255305943175588], 
             UndirectedEdge[32, 179] -> 
             RGBColor[
              0.3530264837706949, 0.47318246599425245`, 0.9440721113128687], 
             UndirectedEdge[38, 79] -> 
             RGBColor[
              0.9549110488708272, 0.8553822400347315, 0.5368328756948025], 
             UndirectedEdge[328, 407] -> 
             RGBColor[
              0.7296914475890647, 0.7786016508659306, 0.6828935738897997], 
             UndirectedEdge[357, 367] -> 
             RGBColor[
              0.9098478317352681, 0.929309253237647, 0.9308758346117341], 
             UndirectedEdge[196, 213] -> 
             RGBColor[
              0.8626892164882423, 0.7632010389101105, 0.6132099366755402], 
             UndirectedEdge[233, 326] -> 
             RGBColor[
              0.9458364397602657, 0.9584766814331981, 0.9540744980109386], 
             UndirectedEdge[164, 372] -> 
             RGBColor[
              0.4466057548450175, 0.5515941151160291, 0.9512169302673597], 
             UndirectedEdge[3, 278] -> 
             RGBColor[
              0.782307739672297, 0.7090437711502939, 0.6071109383641102], 
             UndirectedEdge[195, 399] -> 
             RGBColor[
              0.7056849331412951, 0.7619889933918245, 0.7029605254539162], 
             UndirectedEdge[118, 187] -> 
             RGBColor[
              0.6052349853379602, 0.6896445889843419, 0.9625792412718526], 
             UndirectedEdge[61, 178] -> 
             RGBColor[
              0.9514088350127095, 0.9036043560743804, 0.6230093825212624], 
             UndirectedEdge[2, 496] -> 
             RGBColor[
              0.5154733396212543, 0.6126646811886173, 0.9567973138795809], 
             UndirectedEdge[103, 404] -> 
             RGBColor[
              0.8636139811277117, 0.7091018873694397, 0.6023692157454943], 
             UndirectedEdge[37, 374] -> 
             RGBColor[
              0.8697382398243138, 0.4162713131754989, 0.41878505395516974`], 
             UndirectedEdge[236, 466] -> 
             RGBColor[
              0.8256463692771506, 0.6675305882080531, 0.5963693976381371], 
             UndirectedEdge[150, 254] -> 
             RGBColor[
              0.8465798531156105, 0.30990677879352013`, 0.19031223032633562`],
              UndirectedEdge[148, 229] -> 
             RGBColor[
              0.7392922580807629, 0.792253450678507, 0.8565493989562061], 
             UndirectedEdge[160, 432] -> 
             RGBColor[
              0.8734274152994751, 0.4188618470000054, 0.40533717572372774`], 
             UndirectedEdge[48, 198] -> 
             RGBColor[
              0.8214020810291682, 0.8605190424451246, 0.941023501813927], 
             UndirectedEdge[89, 178] -> 
             RGBColor[
              0.9587945009513559, 0.9091125736385048, 0.6105073765773171], 
             UndirectedEdge[63, 239] -> 
             RGBColor[
              0.6853802222901766, 0.7538961395181709, 0.9694450790776905], 
             UndirectedEdge[425, 462] -> 
             RGBColor[
              0.6393728339533846, 0.7140909052388973, 0.9672383871390524], 
             UndirectedEdge[44, 457] -> 
             RGBColor[
              0.9205178158182603, 0.8023687228694749, 0.6149412333684241], 
             UndirectedEdge[46, 254] -> 
             RGBColor[
              0.899152479336883, 0.63470487017576, 0.2375496641821112], 
             UndirectedEdge[1, 452] -> 
             RGBColor[
              0.9734567188297201, 0.978488696175281, 0.874466722595474], 
             UndirectedEdge[260, 299] -> 
             RGBColor[
              0.7309086250819979, 0.7129867987570951, 0.613439438745971], 
             UndirectedEdge[321, 341] -> 
             RGBColor[
              0.6618524905655492, 0.732090332999762, 0.9693481008248879], 
             UndirectedEdge[249, 406] -> 
             RGBColor[
              0.5408427871003836, 0.6302065842472531, 0.9597631260762499], 
             UndirectedEdge[398, 496] -> 
             RGBColor[
              0.5613995455593477, 0.6485425823195488, 0.9613748088826943], 
             UndirectedEdge[382, 462] -> 
             RGBColor[
              0.6397525576671095, 0.714393686620896, 0.967274605525851], 
             UndirectedEdge[63, 272] -> 
             RGBColor[
              0.7930624715919374, 0.3562069762329276, 0.4345364618403772], 
             UndirectedEdge[117, 270] -> 
             RGBColor[
              0.4185110108069943, 0.5369149354111629, 0.9478881294272337], 
             UndirectedEdge[164, 404] -> 
             RGBColor[
              0.567454460568116, 0.4615856829048245, 0.5785824934884417], 
             UndirectedEdge[133, 191] -> 
             RGBColor[
              0.6966455629071959, 0.7097792629656268, 0.6187176346041492], 
             UndirectedEdge[307, 469] -> 
             RGBColor[
              0.5949080791673135, 0.682012204828402, 0.9612524896936006], 
             UndirectedEdge[31, 237] -> 
             RGBColor[
              0.7927507873207464, 0.8343937655772928, 0.773254338117138], 
             UndirectedEdge[1, 468] -> 
             RGBColor[
              0.6061026426181491, 0.6767714939956492, 0.9492613669299033], 
             UndirectedEdge[346, 395] -> 
             RGBColor[
              0.5901159788683272, 0.6720005818486376, 0.9638357755106806], 
             UndirectedEdge[214, 223] -> 
             RGBColor[
              0.9266743538507529, 0.943049576512524, 0.9465200555066963], 
             UndirectedEdge[264, 397] -> 
             RGBColor[
              0.6346256187519639, 0.222857162342451, 0.4223600422031182], 
             UndirectedEdge[103, 204] -> 
             RGBColor[
              0.9188913547084068, 0.9362454352214573, 0.9198022727472523], 
             UndirectedEdge[110, 356] -> 
             RGBColor[
              0.6235114026535667, 0.6972289400240166, 0.9626317260565361], 
             UndirectedEdge[184, 253] -> 
             RGBColor[
              0.8499104256715097, 0.32712362247902416`, 0.19315700382735868`],
              UndirectedEdge[115, 417] -> 
             RGBColor[
              0.7211217357187925, 0.2988458638385387, 0.42815949634012584`], 
             UndirectedEdge[243, 459] -> 
             RGBColor[
              0.8888688253910928, 0.5879109824147646, 0.2289636505905958], 
             UndirectedEdge[190, 349] -> 
             RGBColor[
              0.9507918323100419, 0.8315718007811852, 0.4969200187084627], 
             UndirectedEdge[128, 222] -> 
             RGBColor[
              0.9612427410458375, 0.8768676545486382, 0.5242249097420688], 
             UndirectedEdge[204, 275] -> 
             RGBColor[
              0.990208390593444, 0.9880336600309425, 0.6530896256447898], 
             UndirectedEdge[178, 455] -> 
             RGBColor[
              0.6017626578063408, 0.6131777367637273, 0.6085833628824244], 
             UndirectedEdge[84, 391] -> 
             RGBColor[
              0.6923668616294407, 0.27530486167976415`, 0.42595010084938356`],
              UndirectedEdge[54, 203] -> 
             RGBColor[
              0.9883656772544341, 0.9872645150104886, 0.6842652321925893], 
             UndirectedEdge[236, 314] -> 
             RGBColor[
              0.8585565575206778, 0.8903472588766075, 0.9853672033204502], 
             UndirectedEdge[277, 313] -> 
             RGBColor[
              0.6864003893543159, 0.6358977619145811, 0.6005061277103744], 
             UndirectedEdge[186, 397] -> 
             RGBColor[
              0.8763242250867886, 0.4195149227237154, 0.31772618276714293`], 
             UndirectedEdge[29, 297] -> 
             RGBColor[
              0.685405870585563, 0.7532744904772795, 0.9698863594669191], 
             UndirectedEdge[130, 208] -> 
             RGBColor[
              0.8587301778494387, 0.4080615185786842, 0.4374188315162526], 
             UndirectedEdge[145, 450] -> 
             RGBColor[
              0.6584204394455455, 0.6896569086434403, 0.6360746498708645], 
             UndirectedEdge[86, 350] -> 
             RGBColor[
              0.823365240251927, 0.4483629221872824, 0.44606535471299347`], 
             UndirectedEdge[37, 281] -> 
             RGBColor[
              0.7878697685472501, 0.8338250114024056, 0.9448320237410449], 
             UndirectedEdge[281, 445] -> 
             RGBColor[
              0.7968036264856038, 0.8391168386866545, 0.8683118376274088], 
             UndirectedEdge[116, 224] -> 
             RGBColor[
              0.3376242053439177, 0.4657279820378112, 0.9427753538650114], 
             UndirectedEdge[112, 163] -> 
             RGBColor[
              0.6158459876461304, 0.6873190495330617, 0.9515740461336051], 
             UndirectedEdge[148, 480] -> 
             RGBColor[
              0.706636362744997, 0.2870859854997955, 0.42701915471795915`], 
             UndirectedEdge[42, 487] -> 
             RGBColor[
              0.6367753523787931, 0.6528250673803876, 0.6116084594412334], 
             UndirectedEdge[122, 319] -> 
             RGBColor[
              0.4575247412142853, 0.5658341295033529, 0.9515872023960605], 
             UndirectedEdge[129, 348] -> 
             RGBColor[
              0.42906370005939964`, 0.5320658922297246, 0.9503346825840235], 
             UndirectedEdge[93, 201] -> 
             RGBColor[
              0.966628149753752, 0.9746319092445136, 0.9413740170810942], 
             UndirectedEdge[121, 427] -> 
             RGBColor[
              0.6375147972361036, 0.6919692148674577, 0.6686092054654782], 
             UndirectedEdge[269, 411] -> 
             RGBColor[
              0.7214625641562007, 0.7823313055281786, 0.972872304010254], 
             UndirectedEdge[76, 371] -> 
             RGBColor[
              0.6022157470976446, 0.5314711908020262, 0.5879920120361347], 
             UndirectedEdge[61, 244] -> 
             RGBColor[
              0.9201682810040038, 0.9387670448056831, 0.9778877357311975], 
             UndirectedEdge[184, 436] -> 
             RGBColor[
              0.7587562243325445, 0.33681035098529144`, 0.43206968971938714`],
              UndirectedEdge[80, 293] -> 
             RGBColor[
              0.9445086105520897, 0.8986040664950233, 0.6348028488891162], 
             UndirectedEdge[111, 460] -> 
             RGBColor[
              0.86668129470023, 0.8953725302515574, 0.9218060310899023], 
             UndirectedEdge[286, 358] -> 
             RGBColor[
              0.9284436780839074, 0.9288900814024785, 0.6890175959500917], 
             UndirectedEdge[176, 244] -> 
             RGBColor[
              0.9166650230549316, 0.9361543207633235, 0.9838178376429689], 
             UndirectedEdge[99, 321] -> 
             RGBColor[
              0.8624406092499931, 0.8931507477619873, 0.9867415492917269], 
             UndirectedEdge[187, 478] -> 
             RGBColor[
              0.7632391378114947, 0.8150893688096874, 0.9770038575375368], 
             UndirectedEdge[116, 185] -> 
             RGBColor[
              0.6441603989612699, 0.7099466652502284, 0.8631872303574494], 
             UndirectedEdge[97, 257] -> 
             RGBColor[
              0.6435180389645314, 0.6739959614174768, 0.6309288256802901], 
             UndirectedEdge[16, 313] -> 
             RGBColor[
              0.5994353692876668, 0.5583803384556967, 0.5950166947380242], 
             UndirectedEdge[166, 344] -> 
             RGBColor[
              0.5840967977676086, 0.6605438750796218, 0.9645475194155613], 
             UndirectedEdge[103, 443] -> 
             RGBColor[
              0.8660590393543877, 0.896035985707563, 0.9870866783852947], 
             UndirectedEdge[74, 115] -> 
             RGBColor[
              0.5707495408280169, 0.6623992150748113, 0.9593506410598893], 
             UndirectedEdge[196, 332] -> 
             RGBColor[
              0.7471097171067448, 0.6720678368988624, 0.6022654716017883], 
             UndirectedEdge[49, 203] -> 
             RGBColor[
              0.6335557109481105, 0.7012518626151522, 0.9257511879274799], 
             UndirectedEdge[95, 122] -> 
             RGBColor[
              0.6477389497355808, 0.7112035113717956, 0.6958618324492837], 
             UndirectedEdge[97, 209] -> 
             RGBColor[
              0.6520864441335752, 0.2404159885974953, 0.42338346826512163`], 
             UndirectedEdge[484, 490] -> 
             RGBColor[
              0.6237603725519834, 0.6874562666661289, 0.8346717731073012], 
             UndirectedEdge[128, 415] -> 
             RGBColor[
              0.947790448656235, 0.868100786891238, 0.6036825846140026], 
             UndirectedEdge[371, 442] -> 
             RGBColor[
              0.6333450191463521, 0.6564473803944675, 0.6170420584685113], 
             UndirectedEdge[88, 311] -> 
             RGBColor[
              0.8579067836962728, 0.8897838304575174, 0.9824768321205821], 
             UndirectedEdge[15, 149] -> 
             RGBColor[
              0.8594787191991574, 0.41997443647794264`, 0.4404876152244481], 
             UndirectedEdge[117, 140] -> 
             RGBColor[
              0.6938530020675666, 0.27659208183167855`, 0.42604479640395854`],
              UndirectedEdge[199, 475] -> 
             RGBColor[
              0.4876013586593777, 0.59283549590797, 0.9533741728315221], 
             UndirectedEdge[71, 169] -> 
             RGBColor[
              0.7457744536846346, 0.6595087203362869, 0.5997229166048286], 
             UndirectedEdge[23, 51] -> 
             RGBColor[
              0.5150279703705647, 0.6103591205532177, 0.9571396016933617], 
             UndirectedEdge[381, 416] -> 
             RGBColor[
              0.6423350268086534, 0.7088287522617973, 0.8839679288583281], 
             UndirectedEdge[121, 447] -> 
             RGBColor[
              0.2729769568210383, 0.4042464677305866, 0.9388570059065156], 
             UndirectedEdge[244, 407] -> 
             RGBColor[
              0.679141839512222, 0.747179638781766, 0.9703153115346119], 
             UndirectedEdge[255, 385] -> 
             RGBColor[
              0.9551853104204899, 0.9654307165010798, 0.9339230111451817], 
             UndirectedEdge[30, 469] -> 
             RGBColor[
              0.7796505771252993, 0.8267508422541052, 0.9321597957598757], 
             UndirectedEdge[80, 171] -> 
             RGBColor[
              0.9406331686969243, 0.8955698627394437, 0.6363736647812899], 
             UndirectedEdge[214, 466] -> 
             RGBColor[
              0.8698520480753711, 0.7024589428938508, 0.6006707071445314], 
             UndirectedEdge[199, 455] -> 
             RGBColor[
              0.31495381596352867`, 0.44201562449401155`, 0.9414800738821197],
              UndirectedEdge[175, 483] -> 
             RGBColor[
              0.4555636207573346, 0.5687124027153516, 0.950330775490277], 
             UndirectedEdge[124, 416] -> 
             RGBColor[
              0.9091096655805685, 0.9281419271855882, 0.9056748688633263], 
             UndirectedEdge[142, 396] -> 
             RGBColor[
              0.633046620345298, 0.22119753490276367`, 0.4222701205797774], 
             UndirectedEdge[185, 361] -> 
             RGBColor[
              0.9907995822723863, 0.9904634050767506, 0.8021382618717867], 
             UndirectedEdge[19, 26] -> 
             RGBColor[
              0.6308917896439188, 0.647466817330552, 0.6111846473572251], 
             UndirectedEdge[341, 455] -> 
             RGBColor[
              0.3356685052234286, 0.4599576471803819, 0.94279999556448], 
             UndirectedEdge[159, 239] -> 
             RGBColor[
              0.4811750835927141, 0.5864969545588831, 0.9531781195626797], 
             UndirectedEdge[261, 482] -> 
             RGBColor[
              0.6864644170857385, 0.7529528243201418, 0.9710892948662686], 
             UndirectedEdge[5, 97] -> 
             RGBColor[
              0.502804092387595, 0.6030244802254067, 0.9554257400428268], 
             UndirectedEdge[285, 396] -> 
             RGBColor[
              0.6224275974989889, 0.6703639641425765, 0.65827560172697], 
             UndirectedEdge[174, 424] -> 
             RGBColor[
              0.6955881560557635, 0.7491000762034712, 0.679975691767438], 
             UndirectedEdge[99, 186] -> 
             RGBColor[
              0.9071898969500003, 0.9248182512576847, 0.8037201889259191], 
             UndirectedEdge[79, 127] -> 
             RGBColor[
              0.6208348275901271, 0.5868596192350183, 0.5981208062389749], 
             UndirectedEdge[29, 86] -> 
             RGBColor[
              0.796097330518997, 0.8406365522560284, 0.9803112000197514], 
             UndirectedEdge[127, 316] -> 
             RGBColor[
              0.2892722721652168, 0.4201834648880345, 0.9398285868398532], 
             UndirectedEdge[197, 466] -> 
             RGBColor[
              0.6354888970287068, 0.5138208157071534, 0.5803533478441487], 
             UndirectedEdge[183, 206] -> 
             RGBColor[
              0.5491420312906214, 0.6388309497417576, 0.9602106430528972], 
             UndirectedEdge[25, 392] -> 
             RGBColor[
              0.4671827492812367, 0.5783190280663453, 0.951197483851669], 
             UndirectedEdge[73, 91] -> 
             RGBColor[
              0.6162387223318397, 0.6634196837043035, 0.6571988809436365], 
             UndirectedEdge[187, 464] -> 
             RGBColor[
              0.5915302079896745, 0.6785184333398198, 0.9615003509967419], 
             UndirectedEdge[17, 99] -> 
             RGBColor[
              0.6388874458829429, 0.7149952052581143, 0.9665755702458828], 
             UndirectedEdge[110, 157] -> 
             RGBColor[
              0.9424427695273766, 0.9565944922716083, 0.9823135572469379], 
             UndirectedEdge[241, 429] -> 
             RGBColor[
              0.528427051837183, 0.6211754722645393, 0.9584198629118471], 
             UndirectedEdge[27, 490] -> 
             RGBColor[
              0.3438944246913231, 0.4670825251767381, 0.9433241438790794], 
             UndirectedEdge[372, 418] -> 
             RGBColor[
              0.7566845744579053, 0.3277173784145783, 0.4309591332766395], 
             UndirectedEdge[65, 350] -> 
             RGBColor[
              0.8784079189922736, 0.4915715124994828, 0.43039451645045756`], 
             UndirectedEdge[189, 390] -> 
             RGBColor[
              0.43997451206698346`, 0.5527150870498942, 0.9500267756035066], 
             UndirectedEdge[263, 267] -> 
             RGBColor[
              0.8273582008994997, 0.86517698762991, 0.9833953578648211], 
             UndirectedEdge[25, 490] -> 
             RGBColor[
              0.3613092871175119, 0.4817093633664127, 0.944560085123272], 
             UndirectedEdge[360, 494] -> 
             RGBColor[
              0.6637796571953806, 0.7317441360517634, 0.9560351732139427], 
             UndirectedEdge[61, 203] -> 
             RGBColor[
              0.9678516020440728, 0.9755443579594156, 0.9393030314810433], 
             UndirectedEdge[36, 104] -> 
             RGBColor[
              0.9386139836549193, 0.7770977525084987, 0.36192699227983915`], 
             UndirectedEdge[33, 241] -> 
             RGBColor[
              0.6468021012428073, 0.7112490118929747, 0.7988304045173231], 
             UndirectedEdge[82, 419] -> 
             RGBColor[
              0.6281259826549572, 0.6943695843736595, 0.8955600828313136], 
             UndirectedEdge[5, 404] -> 
             RGBColor[
              0.7805499935971885, 0.6439681327398266, 0.5941548007811855], 
             UndirectedEdge[40, 396] -> 
             RGBColor[
              0.3068658147021297, 0.43612280504780376`, 0.9409239758306869], 
             UndirectedEdge[169, 369] -> 
             RGBColor[
              0.8084428916483032, 0.7092479351318783, 0.6054343573496339], 
             UndirectedEdge[268, 491] -> 
             RGBColor[
              0.8740221680200179, 0.9007836705270881, 0.907864041810482], 
             UndirectedEdge[4, 151] -> 
             RGBColor[
              0.9211726653914398, 0.7807938108479803, 0.5991402449029416], 
             UndirectedEdge[6, 390] -> 
             RGBColor[
              0.7200880006737587, 0.6085238694615185, 0.5915943681681352], 
             UndirectedEdge[376, 482] -> 
             RGBColor[
              0.9533096079564518, 0.9615876580719073, 0.807697692006808], 
             UndirectedEdge[158, 278] -> 
             RGBColor[
              0.9228889811223413, 0.7319875364135257, 0.25681286806403325`], 
             UndirectedEdge[317, 445] -> 
             RGBColor[
              0.6378065683732861, 0.7030511157843824, 0.8571581001605071], 
             UndirectedEdge[133, 351] -> 
             RGBColor[
              0.5930674466235661, 0.6126812693700718, 0.6123880870045009], 
             UndirectedEdge[239, 454] -> 
             RGBColor[
              0.4549801692098302, 0.5614971214051387, 0.9515936240195859], 
             UndirectedEdge[140, 198] -> 
             RGBColor[
              0.8722373860844727, 0.41813517236434894`, 0.41455465121845714`],
              UndirectedEdge[252, 309] -> 
             RGBColor[
              0.7141567439925198, 0.776102212306707, 0.9725010451135925], 
             UndirectedEdge[161, 243] -> 
             RGBColor[
              0.8201077612156529, 0.6658141548062412, 0.5963275215812777], 
             UndirectedEdge[244, 455] -> 
             RGBColor[
              0.5705221037976351, 0.6483404254950301, 0.9634617160923595], 
             UndirectedEdge[401, 451] -> 
             RGBColor[
              0.6305204039765693, 0.218542321327861, 0.4221262562947805], 
             UndirectedEdge[210, 225] -> 
             RGBColor[
              0.6392689004656411, 0.22773754582459013`, 0.4226244702275924], 
             UndirectedEdge[107, 223] -> 
             RGBColor[
              0.961642731456714, 0.9708541372888166, 0.9471415502348386], 
             UndirectedEdge[5, 204] -> 
             RGBColor[
              0.8358273671778835, 0.8711116805918443, 0.9115878577829435], 
             UndirectedEdge[59, 200] -> 
             RGBColor[
              0.955806604506673, 0.9635261221050229, 0.8036741007949657], 
             UndirectedEdge[328, 481] -> 
             RGBColor[
              0.7749928783093625, 0.8153793931308655, 0.68645986846071], 
             UndirectedEdge[55, 434] -> 
             RGBColor[
              0.7256207199517821, 0.7840056316842685, 0.9591678988328456], 
             UndirectedEdge[269, 499] -> 
             RGBColor[
              0.49815457489167514`, 0.5938875536762038, 0.955978665435371], 
             UndirectedEdge[377, 476] -> 
             RGBColor[
              0.9889186966833732, 0.9726988986198877, 0.546092961334012], 
             UndirectedEdge[260, 478] -> 
             RGBColor[
              0.677889905849536, 0.7465504808590986, 0.9697710736571583], 
             UndirectedEdge[163, 207] -> 
             RGBColor[
              0.3829565883936436, 0.5023876023449556, 0.9459816959916891], 
             UndirectedEdge[238, 258] -> 
             RGBColor[
              0.9076904026621546, 0.6681930879011586, 0.2444007619975992], 
             UndirectedEdge[10, 443] -> 
             RGBColor[
              0.6186180621202113, 0.6954280301817762, 0.9662317769952113], 
             UndirectedEdge[231, 326] -> 
             RGBColor[
              0.8063823695641129, 0.8494032260896187, 0.9811420866899003], 
             UndirectedEdge[91, 287] -> 
             RGBColor[
              0.5265264895691846, 0.6134209550261933, 0.9592230313723693], 
             UndirectedEdge[242, 249] -> 
             RGBColor[
              0.655300958408122, 0.7288159266797518, 0.9675287244675779], 
             UndirectedEdge[83, 209] -> 
             RGBColor[
              0.7293649784510624, 0.30553809964244855`, 0.4288084346040033], 
             UndirectedEdge[306, 431] -> 
             RGBColor[
              0.9839515026985246, 0.9569424019779467, 0.4418473243120018], 
             UndirectedEdge[176, 376] -> 
             RGBColor[
              0.9695404461454965, 0.9742961851852661, 0.8011501191985407], 
             UndirectedEdge[30, 191] -> 
             RGBColor[
              0.7103265701045525, 0.7700013444425595, 0.9268319823953137], 
             UndirectedEdge[209, 444] -> 
             RGBColor[
              0.6832940277298368, 0.26744642896981824`, 0.42537198789609276`],
              UndirectedEdge[169, 289] -> 
             RGBColor[
              0.9336485063668685, 0.8074397656322589, 0.5895700320336777], 
             UndirectedEdge[20, 46] -> 
             RGBColor[
              0.6202734855223522, 0.541608340311265, 0.5879760202622897], 
             UndirectedEdge[49, 100] -> 
             RGBColor[
              0.6302938918693883, 0.6988192032869798, 0.9312725968090914], 
             UndirectedEdge[404, 486] -> 
             RGBColor[
              0.8596284345314456, 0.7059239206983573, 0.601989070753203], 
             UndirectedEdge[103, 431] -> 
             RGBColor[
              0.9217823582837741, 0.9358604020129022, 0.7570024718594034], 
             UndirectedEdge[219, 238] -> 
             RGBColor[
              0.8645189687793218, 0.7911048942537657, 0.6192548724146998], 
             UndirectedEdge[249, 499] -> 
             RGBColor[
              0.5298344088703699, 0.6186360807560161, 0.9591362152214868], 
             UndirectedEdge[254, 377] -> 
             RGBColor[
              0.9439351775461322, 0.8075017898650281, 0.31503057280012126`], 
             UndirectedEdge[57, 434] -> 
             RGBColor[
              0.565892840856042, 0.6348783312622361, 0.9490915674116046], 
             UndirectedEdge[75, 104] -> 
             RGBColor[
              0.9395970274975507, 0.7792003838869084, 0.46892524790689877`], 
             UndirectedEdge[132, 365] -> 
             RGBColor[
              0.8618826770716342, 0.4731713680346944, 0.44903025913616046`], 
             UndirectedEdge[38, 77] -> 
             RGBColor[
              0.8942986804461579, 0.9164027655477367, 0.899860735693927], 
             UndirectedEdge[172, 314] -> 
             RGBColor[
              0.9613051194508044, 0.9581875483304005, 0.6958246217482049], 
             UndirectedEdge[398, 481] -> 
             RGBColor[
              0.6837710092903448, 0.7516294974435829, 0.9699748970761518], 
             UndirectedEdge[143, 165] -> 
             RGBColor[
              0.6128790434312048, 0.6867260531670424, 0.9658802058549885], 
             UndirectedEdge[261, 475] -> 
             RGBColor[
              0.5291998787133356, 0.6286673275791655, 0.9560796994567944], 
             UndirectedEdge[288, 373] -> 
             RGBColor[
              0.7278920176364028, 0.786987965850833, 0.9738875308879666], 
             UndirectedEdge[78, 171] -> 
             RGBColor[
              0.9151509462667144, 0.9351805397151381, 0.991769108291455], 
             UndirectedEdge[6, 370] -> 
             RGBColor[
              0.8880175326972923, 0.5843955947956776, 0.22827142315221893`], 
             UndirectedEdge[264, 295] -> 
             RGBColor[
              0.2986209821270428, 0.4294195130424989, 0.9403825862513038], 
             UndirectedEdge[45, 464] -> 
             RGBColor[
              0.6110418691660456, 0.6937610913449183, 0.9634450910359621], 
             UndirectedEdge[228, 318] -> 
             RGBColor[
              0.6092630908164361, 0.5960260342676895, 0.6025861053877319], 
             UndirectedEdge[7, 295] -> 
             RGBColor[
              0.32296931786847627`, 0.45416152305293184`, 0.9418002972373931],
              UndirectedEdge[225, 320] -> 
             RGBColor[
              0.7971611277499417, 0.359408877574501, 0.4349449775820875], 
             UndirectedEdge[137, 148] -> 
             RGBColor[
              0.706636362744997, 0.28708598549979547`, 0.42701915471795915`], 
             UndirectedEdge[61, 455] -> 
             RGBColor[
              0.6021143063824793, 0.6731170088516442, 0.9521150781510663], 
             UndirectedEdge[11, 331] -> 
             RGBColor[
              0.7619940306390747, 0.8116229114583652, 0.8975962651248666], 
             UndirectedEdge[20, 392] -> 
             RGBColor[
              0.40577931261066497`, 0.5255914977962133, 0.9471586295541932], 
             UndirectedEdge[348, 431] -> 
             RGBColor[
              0.8188676681442741, 0.8552191276342289, 0.7468095243743946], 
             UndirectedEdge[241, 351] -> 
             RGBColor[
              0.26392683720531324`, 0.3947342182037342, 0.9383416149828522], 
             UndirectedEdge[343, 374] -> 
             RGBColor[
              0.7971611277499417, 0.359408877574501, 0.4349449775820876], 
             UndirectedEdge[162, 389] -> 
             RGBColor[
              0.737972350332823, 0.7900126662804072, 0.7763596376653312], 
             UndirectedEdge[207, 266] -> 
             RGBColor[
              0.3837924081349239, 0.5032661018870735, 0.9460292946894704], 
             UndirectedEdge[98, 425] -> 
             RGBColor[
              0.8322295887671682, 0.3870312991922891, 0.438380121907761], 
             UndirectedEdge[151, 284] -> 
             RGBColor[
              0.9515007369116601, 0.9633499095157467, 0.9669807811615998], 
             UndirectedEdge[41, 365] -> 
             RGBColor[
              0.7429816275456196, 0.7987528075221715, 0.9756343378794794], 
             UndirectedEdge[436, 473] -> 
             RGBColor[
              0.7576781803362751, 0.3285240324280737, 0.4310373535710831], 
             UndirectedEdge[311, 405] -> 
             RGBColor[
              0.8162769278479394, 0.8566971220948784, 0.9822439338668927], 
             UndirectedEdge[235, 432] -> 
             RGBColor[
              0.8037636225048241, 0.36456679665783387`, 0.43560305255543275`],
              UndirectedEdge[109, 474] -> 
             RGBColor[
              0.9796216525554587, 0.9425366948926776, 0.40802911895683536`], 
             UndirectedEdge[364, 468] -> 
             RGBColor[
              0.42565405051199384`, 0.534480209770626, 0.9495770355694422], 
             UndirectedEdge[203, 374] -> 
             RGBColor[
              0.8728602401664325, 0.4185996959188447, 0.41350032172406087`], 
             UndirectedEdge[36, 112] -> 
             RGBColor[
              0.9732256148321642, 0.9762446012690047, 0.7314373612363735], 
             UndirectedEdge[324, 342] -> 
             RGBColor[
              0.37028853772346926`, 0.4926711936984119, 0.9449327099557641], 
             UndirectedEdge[374, 445] -> 
             RGBColor[
              0.8756941451165496, 0.4197991980316648, 0.367771596546079], 
             UndirectedEdge[2, 327] -> 
             RGBColor[
              0.6495287885753281, 0.7252371818742811, 0.9663172081896472], 
             UndirectedEdge[128, 438] -> 
             RGBColor[
              0.6768098451909637, 0.6518046863663931, 0.6056238856313972], 
             UndirectedEdge[33, 460] -> 
             RGBColor[
              0.9907225143067242, 0.9898725251054008, 0.76278132358763], 
             UndirectedEdge[298, 335] -> 
             RGBColor[
              0.512295403724772, 0.6139311581047691, 0.9550286340042686], 
             UndirectedEdge[112, 343] -> 
             RGBColor[
              0.855059086055723, 0.8873220678410308, 0.9701900460908739], 
             UndirectedEdge[106, 265] -> 
             RGBColor[
              0.6662748596390691, 0.7376046577650244, 0.9684749321067441], 
             UndirectedEdge[19, 468] -> 
             RGBColor[
              0.2825643301674523, 0.41432340499224707`, 0.939402992635346], 
             UndirectedEdge[161, 202] -> 
             RGBColor[
              0.7736056575494794, 0.8230658863891955, 0.9780694402547838], 
             UndirectedEdge[204, 390] -> 
             RGBColor[
              0.771878086812231, 0.8198324595150781, 0.9061175470468652], 
             UndirectedEdge[211, 289] -> 
             RGBColor[
              0.9629927406417103, 0.9719206270811889, 0.9475278164412301], 
             UndirectedEdge[48, 479] -> 
             RGBColor[
              0.7942462264847912, 0.552785513246611, 0.4594269841218631], 
             UndirectedEdge[57, 495] -> 
             RGBColor[
              0.40150290762106977`, 0.5055441612503152, 0.9485249584466691], 
             UndirectedEdge[10, 280] -> 
             RGBColor[
              0.6470998765784575, 0.6389188207197749, 0.6068028127446057], 
             UndirectedEdge[206, 476] -> 
             RGBColor[
              0.8904932909437269, 0.9122724617438398, 0.841961042981727], 
             UndirectedEdge[13, 256] -> 
             RGBColor[
              0.8763571381768146, 0.4195853204952571, 0.3213085695004282], 
             UndirectedEdge[184, 221] -> 
             RGBColor[
              0.8214134169595105, 0.3858334929273426, 0.43827797713459477`], 
             UndirectedEdge[126, 282] -> 
             RGBColor[
              0.9594068898945878, 0.968891109609806, 0.9384170367567396], 
             UndirectedEdge[53, 266] -> 
             RGBColor[
              0.35265002658866884`, 0.4772200945179963, 0.9437885320420852], 
             UndirectedEdge[194, 220] -> 
             RGBColor[
              0.8733331218405189, 0.41017886332289777`, 0.24202269954525185`],
              UndirectedEdge[375, 417] -> 
             RGBColor[
              0.8289458380723171, 0.3844129255232531, 0.43806691483504734`], 
             UndirectedEdge[245, 448] -> 
             RGBColor[
              0.941726633584669, 0.955589284330291, 0.967191938308197], 
             UndirectedEdge[79, 147] -> 
             RGBColor[
              0.5710910800900524, 0.535766199128636, 0.59524438657688], 
             UndirectedEdge[77, 253] -> 
             RGBColor[
              0.8553413654779551, 0.7655121177344901, 0.6142604653589987], 
             UndirectedEdge[180, 205] -> 
             RGBColor[
              0.4865580645075895, 0.5919885027156824, 0.953292040894181], 
             UndirectedEdge[28, 432] -> 
             RGBColor[
              0.8621806162332036, 0.41063484987572185`, 0.4315781393509973], 
             UndirectedEdge[84, 245] -> 
             RGBColor[
              0.8668871888581977, 0.4141450040331369, 0.4236111395676211], 
             UndirectedEdge[19, 459] -> 
             RGBColor[
              0.6068239900018386, 0.5520460118684962, 0.5918191308213407], 
             UndirectedEdge[153, 236] -> 
             RGBColor[
              0.5454189996649951, 0.6358411844107299, 0.9598739780689052], 
             UndirectedEdge[315, 349] -> 
             RGBColor[
              0.9741513701449064, 0.9786155740023545, 0.8557724827096376], 
             UndirectedEdge[18, 460] -> 
             RGBColor[
              0.7040175908318558, 0.764039482007815, 0.9081500647343038], 
             UndirectedEdge[126, 449] -> 
             RGBColor[
              0.5921080662114941, 0.665404356202852, 0.9655430451004849], 
             UndirectedEdge[49, 324] -> 
             RGBColor[
              0.37028853772346926`, 0.4926711936984119, 0.9449327099557641], 
             UndirectedEdge[334, 415] -> 
             RGBColor[
              0.9018880113668458, 0.9238518508371556, 0.964390694768319], 
             UndirectedEdge[5, 444] -> 
             RGBColor[
              0.5496154677819874, 0.6435701407838912, 0.9584085194892835], 
             UndirectedEdge[147, 449] -> 
             RGBColor[
              0.23671708378222406`, 0.3661350421580578, 0.9367920597786301], 
             UndirectedEdge[254, 426] -> 
             RGBColor[
              0.6365032560085924, 0.5772744238841017, 0.593582123565477], 
             UndirectedEdge[186, 321] -> 
             RGBColor[
              0.9495853875603586, 0.9586232646754487, 0.8077639086672364], 
             UndirectedEdge[260, 399] -> 
             RGBColor[
              0.7567593819490328, 0.8043971066203748, 0.7067205806248967], 
             UndirectedEdge[184, 287] -> 
             RGBColor[
              0.8128075261803118, 0.37907610533923275`, 0.4374293511513702], 
             UndirectedEdge[129, 431] -> 
             RGBColor[
              0.6036459210471627, 0.6652450647037464, 0.7319641967095294], 
             UndirectedEdge[300, 432] -> 
             RGBColor[
              0.6862059258435519, 0.2699685687596635, 0.4255575314690083], 
             UndirectedEdge[207, 293] -> 
             RGBColor[
              0.7126816902103617, 0.7739961409692235, 0.9714257774507802], 
             UndirectedEdge[118, 399] -> 
             RGBColor[
              0.7559293733924426, 0.8037232682826756, 0.7066552393109005], 
             UndirectedEdge[138, 179] -> 
             RGBColor[
              0.5494591150829448, 0.6296337755065059, 0.9617423028405772], 
             UndirectedEdge[40, 161] -> 
             RGBColor[
              0.5585750858079831, 0.6477657639531755, 0.9604881885798682], 
             UndirectedEdge[243, 279] -> 
             RGBColor[
              0.6621672307657753, 0.5394796390511769, 0.5825883904949689], 
             UndirectedEdge[69, 233] -> 
             RGBColor[
              0.9826694677727768, 0.9865933122469923, 0.914122369322601], 
             UndirectedEdge[237, 460] -> 
             RGBColor[
              0.9903926784826189, 0.9891670396291568, 0.7268807296445161], 
             UndirectedEdge[54, 295] -> 
             RGBColor[
              0.6603958710038822, 0.7227527406610441, 0.6992932725531245], 
             UndirectedEdge[102, 210] -> 
             RGBColor[
              0.621719710183886, 0.6924245926248661, 0.9457864498979112], 
             UndirectedEdge[137, 156] -> 
             RGBColor[
              0.8763656912885551, 0.41960361473641766`, 0.32223952292968894`],
              UndirectedEdge[231, 444] -> 
             RGBColor[
              0.5587348611073363, 0.6506942801596101, 0.9593174553903783], 
             UndirectedEdge[383, 393] -> 
             RGBColor[
              0.796843400168114, 0.3591606663727581, 0.434913309466064], 
             UndirectedEdge[43, 137] -> 
             RGBColor[
              0.8431295945346498, 0.3325185398679621, 0.18893425447527779`], 
             UndirectedEdge[233, 348] -> 
             RGBColor[
              0.8127096132869893, 0.8537450696285654, 0.9409998899917218], 
             UndirectedEdge[193, 410] -> 
             RGBColor[
              0.5921215364820123, 0.6777906638573727, 0.9622157599843402], 
             UndirectedEdge[126, 384] -> 
             RGBColor[
              0.9066389897386116, 0.9283933366305337, 0.9909572302790913], 
             UndirectedEdge[162, 345] -> 
             RGBColor[
              0.6936722475219814, 0.7588535392397067, 0.9716002390262315], 
             UndirectedEdge[165, 178] -> 
             RGBColor[
              0.6200442174359717, 0.6323928150522974, 0.6096244706581881], 
             UndirectedEdge[154, 455] -> 
             RGBColor[
              0.6236283028863265, 0.6874016524653442, 0.8368605092525729], 
             UndirectedEdge[211, 470] -> 
             RGBColor[
              0.8645250382912824, 0.41238331600799816`, 0.4276096443298716], 
             UndirectedEdge[201, 305] -> 
             RGBColor[
              0.9655871731486585, 0.9165221744558693, 0.6008274677425267], 
             UndirectedEdge[220, 474] -> 
             RGBColor[
              0.875921333253136, 0.4186531778301453, 0.27387389303424026`], 
             UndirectedEdge[125, 173] -> 
             RGBColor[
              0.4077252612568577, 0.519841643876559, 0.9481731859901374], 
             UndirectedEdge[189, 443] -> 
             RGBColor[
              0.6029319918820362, 0.681841544546283, 0.9652322744702821], 
             UndirectedEdge[307, 500] -> 
             RGBColor[
              0.6051671647974926, 0.6903409927095221, 0.9620601224946772], 
             UndirectedEdge[102, 134] -> 
             RGBColor[
              0.9543972215914255, 0.9655101030473572, 0.9620777881229506], 
             UndirectedEdge[102, 174] -> 
             RGBColor[
              0.6810486204901476, 0.7461771087887392, 0.9494802488338067], 
             UndirectedEdge[203, 281] -> 
             RGBColor[
              0.7925527690604282, 0.8373175855174243, 0.9369049253943816], 
             UndirectedEdge[279, 421] -> 
             RGBColor[
              0.6385804690556585, 0.714674535207188, 0.9666032767676915], 
             UndirectedEdge[335, 430] -> 
             RGBColor[
              0.6808173507065436, 0.7468595571287926, 0.9623489188529912], 
             UndirectedEdge[69, 431] -> 
             RGBColor[
              0.9888275226300616, 0.9880673702526558, 0.7199320037052741], 
             UndirectedEdge[149, 249] -> 
             RGBColor[
              0.8632787900278589, 0.8939980003017194, 0.9838990050552113], 
             UndirectedEdge[141, 345] -> 
             RGBColor[
              0.8596754645851885, 0.4981932706971178, 0.45217169356463927`], 
             UndirectedEdge[12, 283] -> 
             RGBColor[
              0.9749362464198875, 0.9773575451553946, 0.7156208641292136], 
             UndirectedEdge[119, 381] -> 
             RGBColor[
              0.6167343297725469, 0.6905762927199429, 0.9649424663693633], 
             UndirectedEdge[396, 430] -> 
             RGBColor[
              0.6050514124738195, 0.6771442365903464, 0.9576709598412751], 
             UndirectedEdge[49, 360] -> 
             RGBColor[
              0.6173613445088175, 0.6891741306405688, 0.9531640261419811], 
             UndirectedEdge[208, 497] -> 
             RGBColor[
              0.9456130539633649, 0.8970550394866545, 0.6310924375309179], 
             UndirectedEdge[275, 444] -> 
             RGBColor[
              0.7039964911975479, 0.7604921202229893, 0.6999102873511298], 
             UndirectedEdge[269, 323] -> 
             RGBColor[
              0.7863152183920679, 0.35093597075216587`, 0.43386395869808025`],
              UndirectedEdge[273, 279] -> 
             RGBColor[
              0.7087990053445978, 0.7698948913835827, 0.9466044476059713], 
             UndirectedEdge[107, 289] -> 
             RGBColor[
              0.9528913779161274, 0.9643870472999128, 0.9646267886782991], 
             UndirectedEdge[289, 314] -> 
             RGBColor[
              0.9518876024183053, 0.9636384331771686, 0.9663259187695334], 
             UndirectedEdge[6, 428] -> 
             RGBColor[
              0.8913906877347437, 0.7443045686911975, 0.6075958403518823], 
             UndirectedEdge[7, 17] -> 
             RGBColor[
              0.3878326504325049, 0.510223091610112, 0.9459664297614447], 
             UndirectedEdge[309, 424] -> 
             RGBColor[
              0.9046974543708577, 0.9175411084748246, 0.6979121022653587], 
             UndirectedEdge[128, 385] -> 
             RGBColor[
              0.9585315805283856, 0.8757465200010246, 0.5691558557747555], 
             UndirectedEdge[71, 362] -> 
             RGBColor[
              0.5277576572743329, 0.6274964672436478, 0.9559661625020849], 
             UndirectedEdge[43, 156] -> 
             RGBColor[
              0.9021762858232049, 0.6179951546043798, 0.34695577740496675`], 
             UndirectedEdge[59, 298] -> 
             RGBColor[
              0.8014028081450468, 0.8415998087739269, 0.7888474676486785], 
             UndirectedEdge[261, 455] -> 
             RGBColor[
              0.3565523360174866, 0.4778474561652072, 0.944185600507392], 
             UndirectedEdge[17, 89] -> 
             RGBColor[
              0.7121307942961961, 0.7726023697312756, 0.9459951984216849], 
             UndirectedEdge[9, 68] -> 
             RGBColor[
              0.49899731914330436`, 0.5956616874740066, 0.95588601865752], 
             UndirectedEdge[73, 298] -> 
             RGBColor[
              0.7942659910128197, 0.8186029440633101, 0.6695168661987528], 
             UndirectedEdge[16, 333] -> 
             RGBColor[
              0.601194026759132, 0.5653528292921942, 0.5964317518205615], 
             UndirectedEdge[257, 445] -> 
             RGBColor[
              0.978929590438993, 0.9430707755687311, 0.5475110181017262], 
             UndirectedEdge[428, 451] -> 
             RGBColor[
              0.5778084388474186, 0.6547154574738681, 0.9640710835349838], 
             UndirectedEdge[15, 419] -> 
             RGBColor[
              0.875768501923677, 0.431728190545615, 0.39521812070929907`], 
             UndirectedEdge[17, 313] -> 
             RGBColor[
              0.6864256015432326, 0.6359182303053399, 0.6005081125062411], 
             UndirectedEdge[5, 326] -> 
             RGBColor[
              0.797262976238764, 0.8422790867138998, 0.9802331507888056], 
             UndirectedEdge[216, 217] -> 
             RGBColor[
              0.3969076299436659, 0.5182031727248415, 0.946511581101742], 
             UndirectedEdge[138, 222] -> 
             RGBColor[
              0.9266658055392164, 0.9416493661935788, 0.8860132563668205], 
             UndirectedEdge[251, 447] -> 
             RGBColor[
              0.6256894282652795, 0.6893394355596935, 0.8257470889906495], 
             UndirectedEdge[58, 144] -> 
             RGBColor[
              0.8510809804393757, 0.7860331819384434, 0.6191170781488824], 
             UndirectedEdge[11, 404] -> 
             RGBColor[
              0.7062516382653388, 0.5842870663849872, 0.5878697729538576], 
             UndirectedEdge[270, 329] -> 
             RGBColor[
              0.6743635959619225, 0.7404858380152741, 0.9504985700860796], 
             UndirectedEdge[314, 406] -> 
             RGBColor[
              0.6153725447471057, 0.6893468811471688, 0.9660222070661244], 
             UndirectedEdge[13, 409] -> 
             RGBColor[
              0.8242178970769094, 0.18715494604910077`, 0.1708243916320382], 
             UndirectedEdge[279, 335] -> 
             RGBColor[
              0.4340365399245938, 0.5503623683970448, 0.9488774024139208], 
             UndirectedEdge[195, 446] -> 
             RGBColor[
              0.41644831535102356`, 0.535128332281289, 0.9477566962967492], 
             UndirectedEdge[22, 170] -> 
             RGBColor[
              0.6315410922111713, 0.7038228573121279, 0.9540122784095258], 
             UndirectedEdge[159, 166] -> 
             RGBColor[
              0.29974079717519475`, 0.42984427815212845`, 0.9404739009420229],
              UndirectedEdge[59, 87] -> 
             RGBColor[
              0.9944488040745203, 0.9905348781644292, 0.6371647654007506], 
             UndirectedEdge[176, 407] -> 
             RGBColor[
              0.7072307841479939, 0.7693434980960204, 0.9648987755050902], 
             UndirectedEdge[169, 470] -> 
             RGBColor[
              0.8449622154413878, 0.3027294083753782, 0.1889711213915033], 
             UndirectedEdge[13, 188] -> 
             RGBColor[
              0.8511596460860316, 0.32806413179570226`, 0.19399723925189402`],
              UndirectedEdge[273, 396] -> 
             RGBColor[
              0.6150302646886219, 0.6845864482332752, 0.9407793659430987], 
             UndirectedEdge[30, 405] -> 
             RGBColor[
              0.9206167046862583, 0.9382074050592253, 0.9454226473803349], 
             UndirectedEdge[258, 497] -> 
             RGBColor[
              0.9208104650343202, 0.7202097632051847, 0.2549574721496888], 
             UndirectedEdge[90, 485] -> 
             RGBColor[
              0.7280292503886135, 0.7874612507216032, 0.9735268099247292], 
             UndirectedEdge[89, 455] -> 
             RGBColor[
              0.6094999723211257, 0.6786252264157686, 0.9396130722071212], 
             UndirectedEdge[422, 451] -> 
             RGBColor[
              0.541209354118757, 0.6255323407669229, 0.9605802301611754], 
             UndirectedEdge[99, 178] -> 
             RGBColor[
              0.8855511525381028, 0.8515054091653436, 0.631087748401515], 
             UndirectedEdge[119, 416] -> 
             RGBColor[
              0.9636503913686418, 0.9715706035261507, 0.908775350143255], 
             UndirectedEdge[129, 204] -> 
             RGBColor[
              0.6007549174717954, 0.6656300979123015, 0.8947639975973782], 
             UndirectedEdge[1, 381] -> 
             RGBColor[
              0.6253505192595743, 0.6970022327316525, 0.9503575050299508], 
             UndirectedEdge[287, 409] -> 
             RGBColor[
              0.8255272763378612, 0.4768456788802166, 0.44960979826714254`], 
             UndirectedEdge[340, 384] -> 
             RGBColor[
              0.8834414489301029, 0.9098962472702997, 0.9887446281280866], 
             UndirectedEdge[233, 379] -> 
             RGBColor[
              0.7617554427129107, 0.812407689210755, 0.9369684143968935], 
             UndirectedEdge[1, 124] -> 
             RGBColor[
              0.8921251580314895, 0.9163154076554434, 0.9720644450349489], 
             UndirectedEdge[134, 309] -> 
             RGBColor[
              0.8842844214258184, 0.910237696331488, 0.9773589583416329], 
             UndirectedEdge[1, 380] -> 
             RGBColor[
              0.9648761571508514, 0.9458571467955325, 0.6579510507211375], 
             UndirectedEdge[112, 403] -> 
             RGBColor[
              0.7381036912721358, 0.79412619495097, 0.9597838163520842], 
             UndirectedEdge[214, 268] -> 
             RGBColor[
              0.8141353526775033, 0.8551225346933249, 0.9820043620629535], 
             UndirectedEdge[404, 444] -> 
             RGBColor[
              0.6461786090047116, 0.5344832788653903, 0.5834262449801804], 
             UndirectedEdge[252, 320] -> 
             RGBColor[
              0.6825568762976151, 0.7514156614963468, 0.969351596711519], 
             UndirectedEdge[173, 419] -> 
             RGBColor[
              0.6219937466692611, 0.687924215546475, 0.8952108610637584], 
             UndirectedEdge[407, 475] -> 
             RGBColor[
              0.5337354075865464, 0.6323494742416854, 0.9564367529038832], 
             UndirectedEdge[167, 305] -> 
             RGBColor[
              0.9355760591232662, 0.7822875729690713, 0.2670211888275732], 
             UndirectedEdge[407, 482] -> 
             RGBColor[
              0.6909999459589493, 0.7566349709826616, 0.9714463483133574], 
             UndirectedEdge[197, 493] -> 
             RGBColor[
              0.6081897458525535, 0.6886844090339663, 0.9645193979935418], 
             UndirectedEdge[235, 300] -> 
             RGBColor[
              0.6003163225225641, 0.6835490481262461, 0.9633048760366616], 
             UndirectedEdge[312, 385] -> 
             RGBColor[
              0.7673945540538224, 0.8164472466226935, 0.9164129233056304], 
             UndirectedEdge[188, 318] -> 
             RGBColor[
              0.6017474654303233, 0.5662290840454471, 0.5965388567876642], 
             UndirectedEdge[71, 153] -> 
             RGBColor[
              0.4508759918803886, 0.5612013134153189, 0.9509855780891392], 
             UndirectedEdge[45, 481] -> 
             RGBColor[
              0.6453740051275656, 0.7216334659635797, 0.9661478425416108], 
             UndirectedEdge[53, 317] -> 
             RGBColor[
              0.3541889643305304, 0.47883761565898125`, 0.9438761722698299], 
             UndirectedEdge[253, 301] -> 
             RGBColor[
              0.8551567584465607, 0.7653679013184992, 0.6142420654553601], 
             UndirectedEdge[442, 447] -> 
             RGBColor[
              0.6073562390651733, 0.62913152474532, 0.6155620358898429], 
             UndirectedEdge[118, 464] -> 
             RGBColor[
              0.5053509674711256, 0.6093057070515316, 0.9542022258023672], 
             UndirectedEdge[2, 118] -> 
             RGBColor[
              0.6172174447390172, 0.699005377338512, 0.9637735408425003], 
             UndirectedEdge[332, 454] -> 
             RGBColor[
              0.4355838955383851, 0.5457503526464884, 0.9500666783052781], 
             UndirectedEdge[84, 455] -> 
             RGBColor[
              0.6290353763920369, 0.21698146318033038`, 0.4220416861707428], 
             UndirectedEdge[423, 488] -> 
             RGBColor[
              0.5950941183344262, 0.6699660808732812, 0.9654974921698148], 
             UndirectedEdge[5, 231] -> 
             RGBColor[
              0.6931062456998132, 0.7601791340340464, 0.9700460111913835], 
             UndirectedEdge[121, 337] -> 
             RGBColor[
              0.4634464044061361, 0.5690852627132836, 0.9521950451372877], 
             UndirectedEdge[23, 360] -> 
             RGBColor[
              0.8426127351855084, 0.8776293146662392, 0.9704899082590341], 
             UndirectedEdge[79, 336] -> 
             RGBColor[
              0.8161982971198213, 0.7479682117401781, 0.6132455420874003], 
             UndirectedEdge[237, 371] -> 
             RGBColor[
              0.6510898944787169, 0.7153969473333985, 0.763192777718007], 
             UndirectedEdge[9, 330] -> 
             RGBColor[
              0.8397918615790232, 0.8752431627415614, 0.9609724509206357], 
             UndirectedEdge[76, 111] -> 
             RGBColor[
              0.8213888093887758, 0.7117997827569142, 0.6052468748131776], 
             UndirectedEdge[91, 256] -> 
             RGBColor[
              0.6234679735583428, 0.6866142555960564, 0.7865903631184124], 
             UndirectedEdge[35, 193] -> 
             RGBColor[
              0.6707086698229778, 0.6019828166791383, 0.5946902381082673], 
             UndirectedEdge[43, 267] -> 
             RGBColor[
              0.8470968963650475, 0.576696959104481, 0.46205259590582204`], 
             UndirectedEdge[261, 448] -> 
             RGBColor[
              0.6890331217268038, 0.7550010396752971, 0.971334300208043], 
             UndirectedEdge[322, 374] -> 
             RGBColor[
              0.8705545892899705, 0.4008062205994305, 0.23122862526821591`], 
             UndirectedEdge[76, 130] -> 
             RGBColor[
              0.8436213485966975, 0.2966408452010471, 0.18785226922863968`], 
             UndirectedEdge[107, 153] -> 
             RGBColor[
              0.6245930560691766, 0.6985740998728202, 0.964796782303442], 
             UndirectedEdge[410, 437] -> 
             RGBColor[
              0.5967376676068435, 0.6817889246242052, 0.9625098957777298], 
             UndirectedEdge[11, 164] -> 
             RGBColor[
              0.39659296401354205`, 0.5109914784684859, 0.9472797401702167], 
             UndirectedEdge[213, 500] -> 
             RGBColor[
              0.7068916916096081, 0.7702261038295446, 0.9719138733753305], 
             UndirectedEdge[251, 454] -> 
             RGBColor[
              0.6394501384514197, 0.7038028144447446, 0.8265307410786038], 
             UndirectedEdge[111, 483] -> 
             RGBColor[
              0.6053789041497143, 0.6889167949231774, 0.9631680518545573], 
             UndirectedEdge[5, 233] -> 
             RGBColor[
              0.8325603158959659, 0.8692525893776257, 0.9429784225124216], 
             UndirectedEdge[69, 372] -> 
             RGBColor[
              0.8098104397509007, 0.8513172878203978, 0.937933184370283], 
             UndirectedEdge[454, 489] -> 
             RGBColor[
              0.6247850670202127, 0.6947993502774745, 0.9411055409950841], 
             UndirectedEdge[289, 493] -> 
             RGBColor[
              0.8916782629986246, 0.9156853558354271, 0.9614941632366134], 
             UndirectedEdge[74, 268] -> 
             RGBColor[
              0.6861224728219517, 0.7542701205558999, 0.9696598146089201], 
             UndirectedEdge[192, 258] -> 
             RGBColor[
              0.9083469417718103, 0.6707960466922542, 0.24492902877618172`], 
             UndirectedEdge[68, 368] -> 
             RGBColor[
              0.575563615537859, 0.6558870421324854, 0.9634083164720437], 
             UndirectedEdge[50, 414] -> 
             RGBColor[
              0.6116724365864046, 0.6847638694414264, 0.9618339010989898], 
             UndirectedEdge[358, 441] -> 
             RGBColor[
              0.9245636680683912, 0.9158018965504671, 0.6739444897182212], 
             UndirectedEdge[71, 289] -> 
             RGBColor[
              0.7791743137273395, 0.8270142608424114, 0.9508155844639964], 
             UndirectedEdge[54, 321] -> 
             RGBColor[
              0.9488123669349611, 0.9569698517220974, 0.72362538412302], 
             UndirectedEdge[75, 408] -> 
             RGBColor[
              0.6565400281133644, 0.7209122346922445, 0.8271848114364573], 
             UndirectedEdge[8, 239] -> 
             RGBColor[
              0.5885403504015385, 0.6768425957534341, 0.9607511987593997], 
             UndirectedEdge[389, 472] -> 
             RGBColor[
              0.9343933994983635, 0.9463593771531689, 0.7941384859444635], 
             UndirectedEdge[178, 475] -> 
             RGBColor[
              0.7744102005021898, 0.7639976081776858, 0.6204774618318268], 
             UndirectedEdge[332, 489] -> 
             RGBColor[
              0.7766196539434782, 0.8249808104512445, 0.95170174389544], 
             UndirectedEdge[28, 406] -> 
             RGBColor[
              0.6229610498833924, 0.6950063758527747, 0.9531768472695097], 
             UndirectedEdge[77, 87] -> 
             RGBColor[
              0.8967363238686694, 0.91686476645446, 0.8197722557153753], 
             UndirectedEdge[274, 300] -> 
             RGBColor[
              0.6862059258435519, 0.26996856875966346`, 0.4255575314690083], 
             UndirectedEdge[330, 333] -> 
             RGBColor[
              0.9402493725412038, 0.843106298605329, 0.6014191394071629], 
             UndirectedEdge[325, 490] -> 
             RGBColor[
              0.620400812641273, 0.6860670023062987, 0.890348375090118], 
             UndirectedEdge[420, 489] -> 
             RGBColor[
              0.979941655124947, 0.9818691942169613, 0.7689284528584619], 
             UndirectedEdge[271, 304] -> 
             RGBColor[
              0.8576778239713809, 0.4072766747795, 0.43920019213395534`], 
             UndirectedEdge[166, 387] -> 
             RGBColor[
              0.646457946476986, 0.3268472246062181, 0.4354608950617217], 
             UndirectedEdge[16, 165] -> 
             RGBColor[
              0.286390278525246, 0.4183447192954248, 0.9396208747343389], 
             UndirectedEdge[44, 356] -> 
             RGBColor[
              0.6220945826685491, 0.6961722779990202, 0.9650300327253369], 
             UndirectedEdge[86, 377] -> 
             RGBColor[
              0.8942368848078402, 0.9008396798061575, 0.6844146273708539], 
             UndirectedEdge[113, 353] -> 
             RGBColor[
              0.9103609680966539, 0.8163645467896696, 0.6211552689061637], 
             UndirectedEdge[63, 222] -> 
             RGBColor[
              0.8681803195482806, 0.895624336880273, 0.8802730603029272], 
             UndirectedEdge[71, 493] -> 
             RGBColor[
              0.7038042103163908, 0.7677543105394551, 0.9716470478077642], 
             UndirectedEdge[106, 270] -> 
             RGBColor[
              0.4635626481784757, 0.5736635775619812, 0.9513867673524223], 
             UndirectedEdge[414, 498] -> 
             RGBColor[
              0.9351042256769708, 0.8558401759160562, 0.6229852523971697], 
             UndirectedEdge[46, 220] -> 
             RGBColor[
              0.8426137997756449, 0.29206580132365323`, 0.18701154579507184`],
              UndirectedEdge[302, 443] -> 
             RGBColor[
              0.9305717656291512, 0.9463564514909228, 0.9544008479187096], 
             UndirectedEdge[90, 267] -> 
             RGBColor[
              0.7989162426355391, 0.8429133662943743, 0.9805723507733268], 
             UndirectedEdge[116, 187] -> 
             RGBColor[
              0.49398609078265276`, 0.593944453977967, 0.9550386376872195], 
             UndirectedEdge[162, 472] -> 
             RGBColor[
              0.6782550115112216, 0.7465602537344498, 0.9701297292923963], 
             UndirectedEdge[271, 371] -> 
             RGBColor[
              0.6233004601596698, 0.6974249351697056, 0.9650138963941082], 
             UndirectedEdge[84, 478] -> 
             RGBColor[
              0.8232340165888268, 0.3798584741155816, 0.4375221162029487], 
             UndirectedEdge[5, 163] -> 
             RGBColor[
              0.48120301940255206`, 0.581510795382946, 0.9541520040610069], 
             UndirectedEdge[188, 430] -> 
             RGBColor[
              0.93222095108492, 0.8374441319297543, 0.6152616378494501], 
             UndirectedEdge[380, 487] -> 
             RGBColor[
              0.6471529146577039, 0.6884957568037369, 0.6484613776142205], 
             UndirectedEdge[88, 304] -> 
             RGBColor[
              0.8581725658509325, 0.40764565246320417`, 0.4383627231812225], 
             UndirectedEdge[41, 494] -> 
             RGBColor[
              0.46908681814465164`, 0.5777656166072259, 0.9519273999619389], 
             UndirectedEdge[23, 136] -> 
             RGBColor[
              0.797847385601538, 0.8423434965056322, 0.9803954598892122], 
             UndirectedEdge[7, 84] -> 
             RGBColor[
              0.6508578425795862, 0.23935183568273963`, 0.4233051828605111], 
             UndirectedEdge[218, 493] -> 
             RGBColor[
              0.8765174990073568, 0.9043784828742121, 0.9871573821133013], 
             UndirectedEdge[40, 183] -> 
             RGBColor[
              0.3307979233417341, 0.46094226763671586`, 0.9422991290555851], 
             UndirectedEdge[192, 453] -> 
             RGBColor[
              0.8761640443695905, 0.5129324757833155, 0.21764033820149667`], 
             UndirectedEdge[49, 397] -> 
             RGBColor[
              0.6392689004656411, 0.22773754582459013`, 0.4226244702275924], 
             UndirectedEdge[291, 467] -> 
             RGBColor[
              0.8431970812542797, 0.8443501172024703, 0.6550618063062958], 
             UndirectedEdge[347, 462] -> 
             RGBColor[
              0.3279135313510183, 0.4520076772206604, 0.9423510017068644], 
             UndirectedEdge[31, 226] -> 
             RGBColor[
              0.714879572172018, 0.7765574353997664, 0.9727094195774075], 
             UndirectedEdge[120, 381] -> 
             RGBColor[
              0.5033264155166678, 0.6010875050515743, 0.9559939240186179], 
             UndirectedEdge[151, 274] -> 
             RGBColor[
              0.8619579626926223, 0.410468795229718, 0.4319550337178577], 
             UndirectedEdge[316, 418] -> 
             RGBColor[
              0.6305204039765693, 0.21854232132786103`, 0.4221262562947805], 
             UndirectedEdge[235, 389] -> 
             RGBColor[
              0.8853818029172187, 0.907629089836314, 0.7893707759918482], 
             UndirectedEdge[218, 310] -> 
             RGBColor[
              0.9386441763088497, 0.9537615076688566, 0.9887435847341217], 
             UndirectedEdge[408, 463] -> 
             RGBColor[
              0.38880697412597176`, 0.5110140914772505, 0.9460431320916597], 
             UndirectedEdge[12, 273] -> 
             RGBColor[
              0.9792516625399901, 0.9805759754319218, 0.7083159902786631], 
             UndirectedEdge[121, 454] -> 
             RGBColor[
              0.28673766700717845`, 0.4187098466156378, 0.9396406579944698], 
             UndirectedEdge[47, 228] -> 
             RGBColor[
              0.9644478511991786, 0.8836482095314149, 0.4826842701306006], 
             UndirectedEdge[438, 439] -> 
             RGBColor[
              0.5400147243613019, 0.6363970515989623, 0.9573131694281425], 
             UndirectedEdge[172, 201] -> 
             RGBColor[
              0.9822721867142502, 0.9738247527650566, 0.6603328459581482], 
             UndirectedEdge[58, 375] -> 
             RGBColor[
              0.8895209631264607, 0.8163231745765331, 0.6228793179406156], 
             UndirectedEdge[168, 280] -> 
             RGBColor[
              0.6045099507021159, 0.5984521372967165, 0.6042200075748843], 
             UndirectedEdge[77, 301] -> 
             RGBColor[
              0.7986389788987951, 0.8426221072875699, 0.980564527777195], 
             UndirectedEdge[283, 477] -> 
             RGBColor[
              0.605593753173209, 0.6759854220000753, 0.947792600986868], 
             UndirectedEdge[125, 149] -> 
             RGBColor[
              0.7490564455965003, 0.8034930936189093, 0.9733851175976058], 
             UndirectedEdge[7, 407] -> 
             RGBColor[
              0.3938215641720215, 0.5150851615813409, 0.9464378989891333], 
             UndirectedEdge[401, 437] -> 
             RGBColor[
              0.6943334107264211, 0.27700818766593693`, 0.42607540761889195`],
              UndirectedEdge[138, 438] -> 
             RGBColor[
              0.6422329096843425, 0.7165863980113336, 0.9674122322561489], 
             UndirectedEdge[45, 399] -> 
             RGBColor[
              0.8616202750873626, 0.8881786525760622, 0.7158981045444953], 
             UndirectedEdge[97, 317] -> 
             RGBColor[
              0.30239501689882453`, 0.43397630163312817`, 0.940575907739071], 
             UndirectedEdge[71, 201] -> 
             RGBColor[
              0.7849806169995173, 0.8313445923158527, 0.9409870275506276], 
             UndirectedEdge[107, 236] -> 
             RGBColor[
              0.8595603330185, 0.8910958729993517, 0.9836680732292159], 
             UndirectedEdge[134, 225] -> 
             RGBColor[
              0.8610539080706674, 0.40979455277291754`, 0.4334853623776187], 
             UndirectedEdge[59, 91] -> 
             RGBColor[
              0.6233755394640668, 0.6864165484149203, 0.7765294823935622], 
             UndirectedEdge[161, 287] -> 
             RGBColor[
              0.784235424899864, 0.83136994143254, 0.9791289161234465], 
             UndirectedEdge[101, 486] -> 
             RGBColor[
              0.9185471487429617, 0.9342873304327226, 0.8382918848097382], 
             UndirectedEdge[185, 330] -> 
             RGBColor[
              0.9768114211965031, 0.9809687844580706, 0.8678099011924059], 
             UndirectedEdge[237, 432] -> 
             RGBColor[
              0.8762041135174123, 0.419258016221962, 0.3046527796832212], 
             UndirectedEdge[99, 143] -> 
             RGBColor[
              0.878385978533336, 0.9058386472800886, 0.9873434835983155], 
             UndirectedEdge[107, 411] -> 
             RGBColor[
              0.8286759312794396, 0.8669687436306508, 0.98058980469501], 
             UndirectedEdge[187, 407] -> 
             RGBColor[
              0.5805609132308966, 0.6696130656935464, 0.9606368079314802], 
             UndirectedEdge[185, 357] -> 
             RGBColor[
              0.9889992495768465, 0.9897189212407049, 0.8319744337485475], 
             UndirectedEdge[80, 208] -> 
             RGBColor[
              0.9463501822942098, 0.8999775076849995, 0.6316855482885415], 
             UndirectedEdge[60, 240] -> 
             RGBColor[
              0.5299107844556978, 0.620202513723636, 0.9589052841745377], 
             UndirectedEdge[262, 299] -> 
             RGBColor[
              0.8851611968612987, 0.8354281579261476, 0.6275200515390522], 
             UndirectedEdge[82, 282] -> 
             RGBColor[
              0.6271951688721453, 0.6939846689536437, 0.9109860760813593], 
             UndirectedEdge[286, 368] -> 
             RGBColor[
              0.9271581663617632, 0.9278650492495268, 0.6888949826944437], 
             UndirectedEdge[81, 454] -> 
             RGBColor[
              0.479013545273849, 0.5805195437550881, 0.9538199206449927], 
             UndirectedEdge[68, 352] -> 
             RGBColor[
              0.5429879445890364, 0.6300274984133489, 0.9602705930861828], 
             UndirectedEdge[196, 337] -> 
             RGBColor[
              0.7719838675824369, 0.6922617928227384, 0.6042236558442502], 
             UndirectedEdge[261, 262] -> 
             RGBColor[
              0.6449287241750279, 0.7198333902494902, 0.9671275833970941], 
             UndirectedEdge[122, 286] -> 
             RGBColor[
              0.6430989589950638, 0.695698000924869, 0.6653987830743968]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {3}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.9676111105227253, 0.9024068118995643, 0.3286757098196876], 
             316 -> RGBColor[
              0.2569232119297078, 0.38737296398358306`, 0.9379427688843415], 
             308 -> RGBColor[
              0.239132161096772, 0.3686734415403935, 0.9369295948589069], 160 -> 
             RGBColor[
              0.9856442458984253, 0.9883315410000161, 0.8875755271711833], 
             245 -> RGBColor[
              0.9660235665745931, 0.9741810120994109, 0.9423974187028633], 
             155 -> RGBColor[
              0.7773604972475026, 0.8259991956991298, 0.9784436875849108], 
             425 -> RGBColor[
              0.8620507663015046, 0.8928398975768674, 0.9867043657232831], 
             213 -> RGBColor[
              0.8185774812246456, 0.8581982168427544, 0.982551811353138], 352 -> 
             RGBColor[
              0.8057049738702475, 0.8481421162628193, 0.9812688001204721], 27 -> 
             RGBColor[
              0.4353207202065356, 0.5514746608124851, 0.9489592292459301], 
             485 -> RGBColor[
              0.6874469209973422, 0.7557580265640151, 0.9694819425944374], 
             454 -> RGBColor[
              0.2837493086151196, 0.41556889247271844`, 0.9394704754049221], 
             367 -> RGBColor[
              0.8334600065305864, 0.8700424018110369, 0.9839773535330604], 19 -> 
             RGBColor[
              0.30820544840519676`, 0.44127384600091113`, 0.9408632163863504],
              164 -> RGBColor[
              0.25779578631631933`, 0.3882900949883233, 0.9379924607048009], 
             190 -> RGBColor[
              0.9075976558501756, 0.6713625272414686, 0.2445091088165129], 
             103 -> RGBColor[
              0.8501148274355108, 0.8833225039175536, 0.9855659052189062], 
             138 -> RGBColor[
              0.861520386757684, 0.8924169873253942, 0.9866537776489182], 416 -> 
             RGBColor[
              0.9892510884047482, 0.989823063068005, 0.8278008126322198], 476 -> 
             RGBColor[
              0.9950685976213134, 0.9918605538902796, 0.7046254680467884], 
             291 -> RGBColor[
              0.7164468989453462, 0.7784130297449916, 0.9723723893760924], 28 -> 
             RGBColor[
              0.9519038486996109, 0.9636505496271653, 0.9662984180529919], 
             337 -> RGBColor[
              0.6371667834130349, 0.7163197246680102, 0.964579249690558], 195 -> 
             RGBColor[
              0.4185668643171163, 0.5369633129143515, 0.9478916883635093], 
             114 -> RGBColor[
              0.7164468989453462, 0.7784130297449916, 0.9723723893760924], 
             479 -> RGBColor[
              0.8610043378247276, 0.4617349859713152, 0.2057309511965532], 93 -> 
             RGBColor[
              0.954595326553575, 0.9656578494037613, 0.9617424480960806], 34 -> 
             RGBColor[
              0.3183168710406381, 0.4501318074494352, 0.9415038474395205], 
             161 -> RGBColor[
              0.7679204032476006, 0.8186245225190347, 0.9775027872376947], 22 -> 
             RGBColor[
              0.3115638572547115, 0.44428268632440737`, 0.9410735513725369], 
             124 -> RGBColor[
              0.8289682427563888, 0.8664607913031714, 0.9835489250944326], 84 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 46 -> 
             RGBColor[
              0.8932033993269346, 0.6079434039709596, 0.23259863738521555`], 
             241 -> RGBColor[
              0.2989701902851669, 0.43156700416757526`, 0.9403372820987548], 
             185 -> RGBColor[
              0.9917628422137431, 0.9908617378171529, 0.786174551806687], 426 -> 
             RGBColor[
              0.3679049526703533, 0.49308251138764286`, 0.9446635561519471], 
             390 -> RGBColor[
              0.5560882916431593, 0.650496552504795, 0.958196453818132], 121 -> 
             RGBColor[
              0.2897260253992373, 0.42185080075855713`, 0.9398108405840174], 
             322 -> RGBColor[
              0.9770257678699117, 0.9341646617982915, 0.3652498758046477], 
             488 -> RGBColor[
              0.2684923602142315, 0.3995328723569852, 0.938601614764124], 126 -> 
             RGBColor[
              0.9329158022591165, 0.9493457536693096, 0.9934635361148846], 
             433 -> RGBColor[
              0.9386083341163474, 0.9537347766203745, 0.9888042562168871], 
             236 -> RGBColor[
              0.7803862766143184, 0.8283629575372613, 0.9787452689946792], 78 -> 
             RGBColor[
              0.900183386179684, 0.9232458135853353, 0.9903414890486555], 376 -> 
             RGBColor[
              0.9943269246002894, 0.9902741902929543, 0.6238989367836342], 
             458 -> RGBColor[
              0.38933434968102887`, 0.511643578005479, 0.9460290183801956], 
             254 -> 
             RGBColor[
              0.9051015593468315, 0.6614663363805605, 0.2425006909790069], 
             290 -> RGBColor[
              0.31068485338808544`, 0.4435213373551548, 0.941017542023428], 
             251 -> RGBColor[
              0.9951509682877198, 0.9920367364167708, 0.7135910067522854], 
             165 -> RGBColor[
              0.28903124843537237`, 0.42112054611813127`, 0.9397712740637557],
              460 -> RGBColor[
              0.9868110164130007, 0.9888140305924276, 0.8682391202393686], 
             100 -> RGBColor[
              0.9774190823418534, 0.9826797691001892, 0.9231077829354054], 
             235 -> RGBColor[
              0.7766528675144724, 0.8254463899735015, 0.9783731576662982], 70 -> 
             RGBColor[
              0.6431126293105437, 0.7211237409451917, 0.9650631147266087], 
             234 -> RGBColor[
              0.9362115421527853, 0.9519472530983366, 0.9928613998277371], 
             435 -> RGBColor[
              0.40850930356749504`, 0.5282519593007311, 0.9472508294860953], 
             257 -> RGBColor[
              0.9654147455283371, 0.8949979570424675, 0.3201432465652153], 
             135 -> RGBColor[
              0.9278051738857038, 0.945270677328662, 0.9929760798183166], 265 -> 
             RGBColor[
              0.7955254383324755, 0.8401897857333762, 0.9802541991512351], 
             111 -> RGBColor[
              0.7465515729874592, 0.8019310299106872, 0.9753729419404362], 
             497 -> RGBColor[
              0.9496735743784137, 0.8381795232372564, 0.278364380513078], 481 -> 
             RGBColor[
              0.5603104620458799, 0.6539243006443325, 0.958528838538554], 381 -> 
             RGBColor[
              0.2954189652125585, 0.4278344414555896, 0.9401350450844363], 
             182 -> RGBColor[
              0.9672162934993843, 0.9010750013723895, 0.32714192023894645`], 
             188 -> RGBColor[
              0.9188409382580948, 0.7159383953871068, 0.2535557177556821], 
             154 -> RGBColor[
              0.9947884765965425, 0.9921129153896974, 0.7360319599929173], 
             336 -> RGBColor[
              0.7123482714601141, 0.7752111508028057, 0.9719638764922159], 
             463 -> RGBColor[
              0.4596784205131848, 0.5722266759062822, 0.950606715601786], 315 -> 
             RGBColor[
              0.9543167315199046, 0.9654500736838074, 0.9622140368188625], 
             368 -> RGBColor[
              0.8708563157678926, 0.8998612037010923, 0.987544246892194], 269 -> 
             RGBColor[
              0.7243076551762037, 0.7845539122564975, 0.9731558760942407], 
             208 -> RGBColor[
              0.9415525335483161, 0.9559305557360527, 0.9838204945487579], 86 -> 
             RGBColor[
              0.8057049738702475, 0.8481421162628193, 0.9812688001204721], 
             119 -> RGBColor[
              0.9380496943325354, 0.9533181439842963, 0.9897498876542902], 
             436 -> RGBColor[
              0.6383965410088254, 0.7173180972842211, 0.9646760607132492], 
             377 -> RGBColor[
              0.982768795745433, 0.9535372433494957, 0.3875604546212357], 140 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 85 -> 
             RGBColor[
              0.7179516081685184, 0.7795885200263474, 0.972522364729151], 351 -> 
             RGBColor[
              0.22888348412545953`, 0.35790143223989324`, 0.9363459478669496],
              443 -> RGBColor[
              0.8820032512732646, 0.9087494674975723, 0.9886074515516832], 
             242 -> RGBColor[
              0.5229345936826507, 0.6235808869433814, 0.9555864732686835], 
             117 -> RGBColor[
              0.4469210062026999, 0.5615222454950356, 0.9496983892118755], 47 -> 
             RGBColor[
              0.9950235133680367, 0.9917641232312381, 0.6997183253053836], 
             451 -> RGBColor[
              0.2569232119297078, 0.38737296398358306`, 0.9379427688843415], 
             81 -> RGBColor[
              0.6742777819325784, 0.7454701950374578, 0.9681693658850633], 
             275 -> RGBColor[
              0.9927488992055854, 0.9868989535365238, 0.4521406110139813], 23 -> 
             RGBColor[
              0.7336714827503054, 0.7918690055251112, 0.9740891749168833], 
             328 -> RGBColor[
              0.9896752945728451, 0.9768344856173984, 0.41439089838286614`], 
             418 -> RGBColor[0.817319, 0.134127, 0.164218], 110 -> 
             RGBColor[
              0.941132169702511, 0.9556170490681339, 0.9845320608912559], 6 -> 
             RGBColor[
              0.8840877097043581, 0.5665511864182421, 0.22499228251813833`], 
             218 -> RGBColor[
              0.9367268384270373, 0.9523315602159536, 0.9919891376462213], 
             108 -> RGBColor[
              0.9938864997350346, 0.9917399247777159, 0.7509800508293953], 
             297 -> RGBColor[
              0.5843220540033794, 0.6734179927053213, 0.9604191190148078], 
             487 -> RGBColor[
              0.3198355883202952, 0.4514472440241242, 0.9416006187616313], 
             464 -> 
             RGBColor[
              0.49164619012284005`, 0.5981795514070096, 0.9531233355272566], 
             157 -> RGBColor[
              0.9437533693522422, 0.9575719354750828, 0.9800950536026198], 
             441 -> RGBColor[
              0.9756999969246014, 0.9296925250939385, 0.3600995060329525], 
             354 -> RGBColor[
              0.8803621772181066, 0.9074409195917579, 0.9884509244432981], 
             385 -> RGBColor[
              0.9863889032858448, 0.988639475966536, 0.8752346271500963], 270 -> 
             RGBColor[
              0.3901010154112887, 0.51230762532729, 0.9460778696425919], 392 -> 
             RGBColor[
              0.4642150535035602, 0.5759097189408562, 0.9509638559690226], 33 -> 
             RGBColor[
              0.9946340122004478, 0.9909310196183742, 0.6573235269358915], 
             252 -> RGBColor[
              0.6082683693454051, 0.6928586902691903, 0.9623042606767754], 
             394 -> RGBColor[
              0.8682763793805246, 0.4947556282477328, 0.2117989209247601], 
             260 -> RGBColor[
              0.5207157619325917, 0.6217795393714523, 0.9554117987054704], 
             159 -> RGBColor[
              0.3361391373808874, 0.4655685587802071, 0.9426394664911099], 
             183 -> RGBColor[
              0.31236607831510255`, 0.4449775298861153, 0.9411246681891288], 
             99 -> RGBColor[
              0.8200451186396347, 0.8593457343442235, 0.9826978295504096], 
             329 -> RGBColor[
              0.9586261765125562, 0.9686640507032583, 0.9549192705295674], 
             309 -> RGBColor[
              0.8200451186396347, 0.8593457343442235, 0.9826978295504096], 17 -> 
             RGBColor[
              0.4577297731262511, 0.5706446761720051, 0.950453310941356], 349 -> 
             RGBColor[
              0.9939860087699082, 0.9917810743209017, 0.7493309286004125], 
             495 -> RGBColor[
              0.6240788152421396, 0.7056943225006304, 0.963548916893338], 347 -> 
             RGBColor[
              0.239132161096772, 0.3686734415403935, 0.9369295948589069], 340 -> 
             RGBColor[
              0.8865207206420992, 0.9123515749488416, 0.9890383318128751], 
             404 -> RGBColor[
              0.8771131348199127, 0.5348812708213257, 0.2191725262720825], 
             277 -> RGBColor[
              0.45767934874841765`, 0.5706037393904876, 0.9504493413496223], 
             104 -> RGBColor[
              0.8840495265071312, 0.5663778054375467, 0.22496042152241633`], 
             79 -> RGBColor[
              0.9200483227795284, 0.7207252726775506, 0.25452720768258486`], 
             327 -> RGBColor[
              0.5836784324920332, 0.6728954717675919, 0.9603684507717714], 
             191 -> RGBColor[
              0.4360397166927189, 0.5520974194310029, 0.9490050430662461], 50 -> 
             RGBColor[
              0.2820714058482188, 0.41380531027952583`, 0.9393749213245818], 
             225 -> RGBColor[0.817319, 0.134127, 0.164218], 405 -> 
             RGBColor[
              0.8566199858561305, 0.8885095406643344, 0.9861863730362884], 61 -> 
             RGBColor[
              0.951760483588848, 0.9635436281622972, 0.9665410977899042], 196 -> 
             RGBColor[
              0.906800951751839, 0.6682038609774665, 0.24386806199794253`], 1 -> 
             RGBColor[
              0.9552820733065902, 0.9661700240077153, 0.9605799649754652], 
             263 -> RGBColor[
              0.8254954963078062, 0.8636917175502627, 0.9832176914380094], 
             201 -> RGBColor[
              0.978660972953929, 0.9836059690852659, 0.921005586066108], 371 -> 
             RGBColor[
              0.30820544840519676`, 0.44127384600091113`, 0.9408632163863504],
              293 -> RGBColor[
              0.937869390064076, 0.9531836733561003, 0.9900550957499072], 362 -> 
             RGBColor[
              0.4642150535035602, 0.5759097189408562, 0.9509638559690226], 
             184 -> RGBColor[
              0.818936065994404, 0.1465564778358266, 0.16576650422245615`], 
             106 -> RGBColor[
              0.5370242809456627, 0.6350195297966724, 0.9566956650622529], 
             206 -> RGBColor[
              0.7859179842661402, 0.8326843695973999, 0.9792966179166657], 
             358 -> RGBColor[
              0.873427339212181, 0.9019112680069957, 0.98778947340349], 247 -> 
             RGBColor[
              0.2989701902851669, 0.43156700416757526`, 0.9403372820987548], 
             220 -> RGBColor[0.817319, 0.134127, 0.164218], 407 -> 
             RGBColor[
              0.46970760060528427`, 0.5803688161144629, 0.9513962493967332], 
             107 -> RGBColor[
              0.9387343894226815, 0.9538287884614419, 0.9885908774637526], 
             375 -> RGBColor[
              0.8521995142169515, 0.8849847765697592, 0.9857647445051418], 
             131 -> RGBColor[
              0.9882230541070169, 0.9893979444666168, 0.8448380014131069], 
             411 -> RGBColor[
              0.7186174731361978, 0.7801086987998598, 0.9725887319262674], 
             462 -> 
             RGBColor[
              0.4166949016052647, 0.5353419129009273, 0.9477724085548218], 
             127 -> RGBColor[
              0.3216213324007257, 0.4529939657924859, 0.9417144047953648], 
             210 -> RGBColor[
              0.28316870139692335`, 0.4149586374737704, 0.9394374106827772], 
             357 -> RGBColor[
              0.9862356569399497, 0.988576104664257, 0.8777743156904079], 181 -> 
             RGBColor[
              0.9045730505911103, 0.9267460128327405, 0.990760179158917], 194 -> 
             RGBColor[
              0.9853613655215568, 0.9622825899686932, 0.39763209863575555`], 
             440 -> RGBColor[
              0.7035219317356081, 0.7683159471273551, 0.9710841494353115], 
             490 -> RGBColor[
              0.25246812917611056`, 0.38269038954099116`, 0.9376890585122285],
              118 -> RGBColor[
              0.5190557448194113, 0.6204318626960537, 0.9552811160774778], 
             348 -> RGBColor[
              0.644285447156511, 0.722039955160207, 0.9651800102488888], 276 -> 
             RGBColor[
              0.3744732199191344, 0.4987716143478262, 0.9450820803329487], 
             305 -> RGBColor[
              0.952513373343388, 0.8494383798264726, 0.28064934941894537`], 
             343 -> RGBColor[
              0.7568453832498252, 0.8099726327235031, 0.9763989327462627], 
             280 -> RGBColor[
              0.938966880189757, 0.7957310485735696, 0.2697495230504717], 474 -> 
             RGBColor[
              0.9931259997594081, 0.9877055334904359, 0.4931856791027207], 
             189 -> RGBColor[
              0.3238607324908076, 0.4549336215949936, 0.9418570973888811], 
             168 -> RGBColor[
              0.27005302121447483`, 0.4011732260198635, 0.9386904920992968], 
             363 -> RGBColor[
              0.330580050926044, 0.4607535575008311, 0.9422852464179143], 41 -> 
             RGBColor[
              0.5621683095192537, 0.6554325849182923, 0.9586750950971775], 14 -> 
             RGBColor[
              0.8733176981079966, 0.5176470791592801, 0.21600552084499258`], 
             77 -> RGBColor[
              0.7988235859301897, 0.8427663237035607, 0.9805829276808337], 51 -> 
             RGBColor[
              0.2963844579908239, 0.4288492355813243, 0.94019002846984], 438 -> 
             RGBColor[
              0.42294543261100104`, 0.540755808697273, 0.9481706868633798], 
             179 -> RGBColor[
              0.23739784340820552`, 0.3668505636876176, 0.9368308280322362], 
             467 -> 
             RGBColor[
              0.9699472635632133, 0.9102872046599492, 0.33775122323649936`], 
             223 -> RGBColor[
              0.9845510734907464, 0.9878794861161915, 0.9056922230059247], 
             456 -> RGBColor[
              0.5979534795426031, 0.6844845980467856, 0.9614922347668126], 
             323 -> RGBColor[0.817319, 0.134127, 0.164218], 500 -> 
             RGBColor[
              0.5952059019945706, 0.6822539908163348, 0.9612759353975232], 
             478 -> RGBColor[
              0.8350640497664802, 0.8713214223467449, 0.9841303486088462], 
             292 -> RGBColor[
              0.8198884085040161, 0.8592223231968151, 0.9826824723330336], 
             491 -> RGBColor[
              0.9885712648957886, 0.989541938576383, 0.8390672475025247], 396 -> 
             RGBColor[
              0.26450186103589385`, 0.3953386047082911, 0.9383743617393322], 
             321 -> RGBColor[
              0.9048360998603515, 0.9269557611797513, 0.9907852690330441], 
             143 -> RGBColor[
              0.9367268384270373, 0.9523315602159536, 0.9919891376462213], 
             112 -> RGBColor[
              0.9532727888616209, 0.9646715029585586, 0.963981159435485], 197 -> 
             RGBColor[
              0.4000713321174308, 0.520943412535462, 0.9467131694067024], 421 -> 
             RGBColor[
              0.8251215957634713, 0.86339357940547, 0.9831820284703058], 54 -> 
             RGBColor[
              0.9927886340095707, 0.9869839422644434, 0.456465499212996], 71 -> 
             RGBColor[
              0.5913002610451056, 0.6790832155464394, 0.9609684690351472], 
             177 -> RGBColor[
              0.2862250304018598, 0.4181710330404098, 0.9396114640981748], 
             158 -> RGBColor[
              0.9335506158756443, 0.7742573654312014, 0.265391469647273], 226 -> 
             RGBColor[
              0.8382319102547802, 0.8738473883108331, 0.9844325019702027], 
             432 -> RGBColor[0.817319, 0.134127, 0.164218], 350 -> 
             RGBColor[
              0.8321953734427667, 0.24847332514951398`, 0.17846363200925405`],
              203 -> RGBColor[
              0.9839427204992975, 0.9875450877565339, 0.9120649651721826], 
             475 -> RGBColor[
              0.5977632145678086, 0.6843301323689079, 0.9614772564110332], 
             115 -> RGBColor[
              0.5287272071563774, 0.628283591515616, 0.9560424890203776], 173 -> 
             RGBColor[
              0.2562278882428392, 0.3866421347026161, 0.9379031712290136], 
             212 -> 
             RGBColor[
              0.6756969324513681, 0.7465788462086798, 0.9683108135460606], 
             129 -> RGBColor[
              0.2138419529622882, 0.342091829299242, 0.9354893549191582], 279 -> 
             RGBColor[
              0.4520393423478456, 0.5659554910089061, 0.9500245250650773], 26 -> 
             RGBColor[
              0.9535781308826408, 0.8536597886601929, 0.28150607832809976`], 
             40 -> RGBColor[
              0.3492297683683656, 0.47690700538731645`, 0.9434735899220416], 
             146 -> RGBColor[
              0.8883478319388474, 0.5858954065082311, 0.22854703293574768`], 
             386 -> RGBColor[
              0.8916675162408774, 0.9164554900532624, 0.9895292377716852], 
             192 -> RGBColor[
              0.924746527853394, 0.7393520902113954, 0.25830749376606393`], 
             300 -> RGBColor[
              0.42397977753065563`, 0.5416517062789905, 0.9482365944070249], 
             221 -> RGBColor[
              0.8263681188897234, 0.8643875231103746, 0.9833009229588721], 62 -> 
             RGBColor[0.5484002048218, 0.644255017278851, 0.9575912194611647],
              286 -> RGBColor[
              0.9834600169556338, 0.9558688947979614, 0.39024571849669326`], 
             472 -> RGBColor[
              0.8746760606767621, 0.9029069646072115, 0.9879085775715285], 
             152 -> RGBColor[
              0.954274050692355, 0.9654182423925044, 0.9622862843269614], 64 -> 
             RGBColor[
              0.9500471057015513, 0.8396604504615621, 0.27866493258358155`], 
             307 -> RGBColor[
              0.6151284276004145, 0.6984279946027095, 0.9628443095918312], 37 -> 
             RGBColor[
              0.9745767194729413, 0.9805599395264966, 0.9279191618655092], 
             148 -> RGBColor[
              0.485271088234991, 0.5930039564993865, 0.9526214641538774], 261 -> 
             RGBColor[
              0.4606365428588626, 0.5730045227894232, 0.9506821425025554], 
             387 -> RGBColor[
              0.838015691230728, 0.2932108381473023, 0.18403717489611457`], 
             15 -> RGBColor[
              0.8197729503376738, 0.1529891376232556, 0.16656790561469695`], 
             136 -> RGBColor[
              0.8620232884527705, 0.8928179874861533, 0.986701744861541], 198 -> 
             RGBColor[
              0.982074158253418, 0.9861515170930468, 0.9152279536553714], 63 -> 
             RGBColor[
              0.7445494147758124, 0.8003669286987827, 0.9751733855211315], 
             444 -> 
             RGBColor[
              0.4152440831895105, 0.5340852869094548, 0.9476799636882783], 
             310 -> RGBColor[
              0.940561514190662, 0.9551914551217595, 0.985498031822022], 171 -> 
             RGBColor[
              0.930118506353745, 0.947115265844941, 0.9931967275342547], 395 -> 
             RGBColor[
              0.3348579798971787, 0.46445888456066603`, 0.942557832269131], 
             311 -> RGBColor[
              0.7759338698397482, 0.8248847035254223, 0.9783014946974969], 
             353 -> RGBColor[
              0.9163755071555609, 0.7061637826217726, 0.2515719740194775], 59 -> 
             RGBColor[
              0.9942485463418916, 0.9901065471234991, 0.6153679470515843], 
             397 -> RGBColor[0.817319, 0.134127, 0.164218], 229 -> 
             RGBColor[
              0.9933134279265349, 0.9915029448576275, 0.7604773337585348], 
             102 -> RGBColor[
              0.9602707189708488, 0.9698905477759618, 0.9521354891130452], 
             453 -> RGBColor[
              0.8518728026276887, 0.39972266856927546`, 0.19730676041921302`],
              299 -> RGBColor[
              0.9411014882314042, 0.804194058142738, 0.2714670787864715], 128 -> 
             RGBColor[
              0.9306742577709263, 0.7628535640355132, 0.2630770843994147], 12 -> 
             RGBColor[
              0.9929446567386303, 0.9873176591055842, 0.4734476104104609], 
             222 -> RGBColor[
              0.9918112243207488, 0.9908817450617632, 0.7853727350847228], 
             483 -> RGBColor[
              0.4642062353119693, 0.5759025599356676, 0.9509631617686783], 92 -> 
             RGBColor[
              0.7603770196125172, 0.8127315738914686, 0.9767509332538775], 
             271 -> RGBColor[
              0.9383954719141427, 0.9535760243385001, 0.9891645764018658], 
             361 -> RGBColor[
              0.9898363223310296, 0.9900650723363482, 0.8181019719368864], 
             344 -> RGBColor[
              0.9048511385657153, 0.9269677526351936, 0.9907867034381869], 
             132 -> RGBColor[
              0.8309265428214586, 0.23872053698901624`, 0.1772485983733502], 
             80 -> RGBColor[
              0.9511478310401034, 0.8440244596339463, 0.27955060202832505`], 
             324 -> RGBColor[
              0.4574083740500152, 0.5703837499230534, 0.950428009228751], 244 -> 
             RGBColor[
              0.8885760784191596, 0.913990461449069, 0.9892343736724907], 150 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 125 -> 
             RGBColor[
              0.5592226342708762, 0.6530411530505018, 0.9584432007512612], 
             258 -> RGBColor[
              0.8919473556902267, 0.6022400031731131, 0.2315505637862995], 
             133 -> RGBColor[
              0.9572514091216728, 0.8674611065002505, 0.28843022614205216`], 
             469 -> RGBColor[
              0.5746877307342124, 0.6655964150540944, 0.95966066979537], 255 -> 
             RGBColor[
              0.9239817175551349, 0.9422219570356237, 0.9926113951402672], 
             408 -> RGBColor[
              0.3179355277387587, 0.44980150704821886`, 0.9414795485815334], 
             326 -> RGBColor[
              0.9105391001030637, 0.9315031787694723, 0.9913292262873225], 
             176 -> RGBColor[
              0.9447539676907036, 0.958318180077578, 0.9784013016134473], 230 -> 
             RGBColor[
              0.9712379003810023, 0.978069853714543, 0.9335709116846769], 274 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 87 -> 
             RGBColor[
              0.9946490618071491, 0.9909632092053594, 0.6589615837499169], 
             439 -> RGBColor[
              0.6570840161116028, 0.7320382945006515, 0.9664556519929053], 
             130 -> RGBColor[0.817319, 0.134127, 0.164218], 35 -> 
             RGBColor[
              0.902287369716355, 0.6491915918941304, 0.24017852494663777`], 
             379 -> RGBColor[
              0.5423771060083539, 0.6393651943245862, 0.9571170590592323], 31 -> 
             RGBColor[
              0.5915272340892559, 0.6792674824886997, 0.9609863371846123], 18 -> 
             RGBColor[
              0.42122416525071066`, 0.5392649334232025, 0.9480610092292391], 
             24 -> RGBColor[
              0.9941087772252029, 0.9898075951157272, 0.6001549412550162], 
             151 -> RGBColor[
              0.9512358880778669, 0.9631523856891538, 0.967429101153573], 137 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 330 -> 
             RGBColor[
              0.9618600001792631, 0.9710758310989881, 0.9494452505781248], 
             296 -> RGBColor[
              0.5746877307342124, 0.6655964150540944, 0.95966066979537], 266 -> 
             RGBColor[
              0.2800908259132003, 0.4117235951918005, 0.9392621302272879], 
             302 -> RGBColor[
              0.9791402799850377, 0.9839634354842735, 0.9201942442857359], 
             442 -> RGBColor[
              0.9584845898875074, 0.8716209147880238, 0.2932209005506723], 
             283 -> RGBColor[
              0.9569278361011447, 0.9673974312052049, 0.9577941178479662], 
             388 -> 
             RGBColor[
              0.9940713092693598, 0.9918163482695477, 0.7479172785738831], 
             284 -> RGBColor[
              0.9517655857454534, 0.9635474333423395, 0.9665324611696267], 
             417 -> RGBColor[0.817319, 0.134127, 0.164218], 318 -> 
             RGBColor[
              0.2846539926025518, 0.4165197727037875, 0.9395219958196463], 
             413 -> RGBColor[
              0.25160194472615877`, 0.3817799747648257, 0.9376397305892088], 
             238 -> RGBColor[
              0.9234334496340827, 0.734146172629204, 0.25725096020889887`], 
             72 -> RGBColor[
              0.2795739026508505, 0.41118027606824314`, 0.9392326922122165], 
             437 -> RGBColor[
              0.4483622321792632, 0.5627705629978108, 0.949790222856676], 288 -> 
             RGBColor[
              0.5990948015339188, 0.6854111746553054, 0.9615820838147692], 
             382 -> RGBColor[
              0.8628102137289544, 0.8934454603408647, 0.98677680249688], 461 -> 
             RGBColor[
              0.9083021706752503, 0.9297195119635656, 0.9911158659615671], 
             389 -> RGBColor[
              0.994110738319965, 0.9898117896991263, 0.6003683943173984], 172 -> 
             RGBColor[
              0.9858834004745715, 0.9640435364448474, 0.3996601058501884], 
             447 -> RGBColor[
              0.2562278882428392, 0.3866421347026161, 0.9379031712290136], 
             243 -> RGBColor[
              0.8722951191837051, 0.5130037870934476, 0.2151522559248606], 
             410 -> RGBColor[
              0.7451131030344239, 0.8008072862505995, 0.9752295686987836], 88 -> 
             RGBColor[
              0.9398796975527975, 0.9546829573896124, 0.9866521695436673], 
             273 -> RGBColor[
              0.96555866834135, 0.9738342917582593, 0.9431843701468653], 477 -> 
             RGBColor[
              0.2542596702452732, 0.38457341279494556`, 0.9377910841257697], 
             202 -> RGBColor[
              0.7792909118513583, 0.8275072502593565, 0.9786360932718731], 
             393 -> RGBColor[0.817319, 0.134127, 0.164218], 98 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 30 -> 
             RGBColor[
              0.9846134235163861, 0.987905269454116, 0.9046589217243813], 116 -> 
             RGBColor[
              0.29655795570879645`, 0.4290315926833041, 0.9401999089082117], 
             373 -> RGBColor[
              0.8566892337388867, 0.8885647570463604, 0.986192977961164], 434 -> 
             RGBColor[
              0.9528586817120838, 0.9643626625244721, 0.9646821348232092], 
             401 -> RGBColor[0.817319, 0.134127, 0.164218], 240 -> 
             RGBColor[
              0.7766528675144724, 0.8254463899735015, 0.9783731576662982], 
             480 -> RGBColor[0.817319, 0.134127, 0.164218], 403 -> 
             RGBColor[
              0.5229345936826507, 0.6235808869433814, 0.9555864732686835], 
             317 -> RGBColor[
              0.28316870139692335`, 0.4149586374737704, 0.9394374106827772], 
             429 -> RGBColor[
              0.757883913389199, 0.8107839403615034, 0.9765024437249394], 391 -> 
             RGBColor[
              0.44246258488832224`, 0.5576605850392925, 0.9494143025481506], 
             73 -> RGBColor[
              0.9799749120774375, 0.9441128177022655, 0.3767067441517329], 
             303 -> RGBColor[
              0.9929660592679447, 0.9873634369516601, 0.47577714364523216`], 
             449 -> RGBColor[
              0.25130033016387177`, 0.3814629587363943, 0.9376225540860853], 
             29 -> RGBColor[
              0.7864896871677465, 0.8331309882492376, 0.9793535999190305], 
             360 -> RGBColor[
              0.9515539876207115, 0.9633896238073671, 0.9668906416011851], 
             320 -> RGBColor[
              0.7568453832498252, 0.8099726327235031, 0.9763989327462627], 
             482 -> RGBColor[
              0.9122922913126144, 0.9329011258508603, 0.9914964472299816], 75 -> 
             RGBColor[
              0.9951445284879702, 0.9920229623362701, 0.7128900742913812], 
             200 -> RGBColor[
              0.9173646626714543, 0.9369456970865466, 0.9919802545383472], 
             301 -> RGBColor[
              0.7984543718674005, 0.842477890871579, 0.9805461278735564], 156 -> 
             RGBColor[
              0.9944590738656652, 0.990556844209253, 0.6382825687890669], 25 -> 
             RGBColor[
              0.4701504450589133, 0.5807283371918343, 0.9514311117343156], 38 -> 
             RGBColor[
              0.989773774962126, 0.9900392073919125, 0.8191385437070202], 365 -> 
             RGBColor[
              0.9237949455719856, 0.9420730301260508, 0.9925935806617812], 
             380 -> RGBColor[
              0.9744702409951126, 0.9255442695833496, 0.3553221364668098], 
             370 -> RGBColor[
              0.8919473556902267, 0.6022400031731131, 0.2315505637862995], 3 -> 
             RGBColor[
              0.6523881329755558, 0.728369834904738, 0.9659876102474271], 57 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 227 -> 
             RGBColor[
              0.8513956592973689, 0.8843438044769445, 0.9856880721053023], 
             494 -> 
             RGBColor[
              0.3760053267700496, 0.5000986482961596, 0.9451797048267002], 39 -> 
             RGBColor[
              0.9933953336212219, 0.9882816113870252, 0.5225010078252397], 
             424 -> RGBColor[
              0.9893497901020807, 0.9757364826054258, 0.4131263749803078], 
             109 -> RGBColor[
              0.9661173053515094, 0.8973678562949192, 0.32287255881095], 465 -> 
             RGBColor[
              0.9898780456268065, 0.9900823259913918, 0.8174105089494343], 
             256 -> RGBColor[
              0.9944334145304439, 0.9905019614857713, 0.6354897085012845], 
             457 -> RGBColor[
              0.9027371019040448, 0.6512337207208087, 0.2405537925079908], 
             339 -> RGBColor[0.817319, 0.134127, 0.164218], 420 -> 
             RGBColor[
              0.9940624848245881, 0.9897085803516918, 0.5951162991316776], 
             287 -> RGBColor[
              0.8005504465521273, 0.8441153603460452, 0.9807550450091984], 
             239 -> RGBColor[
              0.6262110298045408, 0.707425350337559, 0.9637167726342496], 427 -> 
             RGBColor[
              0.9853035690729699, 0.9620876289763581, 0.39740757034693897`], 
             285 -> RGBColor[
              0.9803533339620839, 0.9453893235768619, 0.37817684171460775`], 
             345 -> RGBColor[
              0.9055105326982817, 0.9274935356177252, 0.9908495970391992], 
             366 -> RGBColor[
              0.485271088234991, 0.5930039564993865, 0.9526214641538774], 216 -> 
             RGBColor[
              0.3875160758346616, 0.5100686805888565, 0.9459131595785415], 21 -> 
             RGBColor[
              0.9626217641044252, 0.9716439533871001, 0.9481557829526766], 
             355 -> RGBColor[
              0.28316870139692335`, 0.4149586374737704, 0.9394374106827772], 
             175 -> RGBColor[
              0.4469210062026999, 0.5615222454950356, 0.9496983892118755], 7 -> 
             RGBColor[
              0.3179355277387587, 0.44980150704821886`, 0.9414795485815334], 
             13 -> RGBColor[0.817319, 0.134127, 0.164218], 294 -> 
             RGBColor[
              0.9691952996088244, 0.9765464854031045, 0.9370285019963712], 
             412 -> RGBColor[
              0.5478298053359681, 0.6437919412800488, 0.9575463155241978], 
             193 -> RGBColor[
              0.4391299699296007, 0.5547740414641461, 0.9492019512698966], 60 -> 
             RGBColor[
              0.28316870139692335`, 0.4149586374737704, 0.9394374106827772], 
             65 -> 
             RGBColor[
              0.9708330100912872, 0.9777678871994204, 0.9342562853328643], 
             448 -> RGBColor[
              0.9174297005947448, 0.9369975565611711, 0.9919864579135307], 69 -> 
             RGBColor[
              0.9842051561280859, 0.9877364403970607, 0.9114249689106475], 
             217 -> RGBColor[
              0.4062991840526702, 0.5263376648608264, 0.9471100026249426], 
             214 -> RGBColor[
              0.8687976342107593, 0.8982196669088566, 0.9873478880074679], 
             170 -> RGBColor[
              0.951518327167631, 0.9633630282998483, 0.9669510054465148], 359 -> 
             RGBColor[
              0.2569232119297078, 0.38737296398358306`, 0.9379427688843415], 
             74 -> RGBColor[
              0.6127718744996563, 0.6965148386340066, 0.9626587930994011], 
             246 -> RGBColor[
              0.5679679684432866, 0.6601410093044794, 0.959131665492528], 264 -> 
             RGBColor[
              0.2692388562558919, 0.400317487027353, 0.9386441266093546], 278 -> 
             RGBColor[
              0.9122273463690385, 0.6897177073958499, 0.24823426648079353`], 
             45 -> RGBColor[
              0.7304375482092512, 0.7893426312828269, 0.9737668465446676], 
             492 -> RGBColor[0.817319, 0.134127, 0.164218], 306 -> 
             RGBColor[
              0.9744531162650121, 0.9254865038476424, 0.355255610124103], 237 -> 
             RGBColor[
              0.9939743405522371, 0.989520048665886, 0.5855223390496636], 228 -> 
             RGBColor[
              0.9338721890303205, 0.7755322958315916, 0.26565021495581764`], 
             180 -> RGBColor[
              0.5956766262642321, 0.6826361459843328, 0.9613129925363508], 
             383 -> RGBColor[
              0.7558922005043418, 0.8092279991182744, 0.976303928398192], 53 -> 
             RGBColor[
              0.42520922726413735`, 0.5427165938441921, 0.9483149338568826], 
             304 -> RGBColor[0.817319, 0.134127, 0.164218], 48 -> 
             RGBColor[
              0.6607300038049183, 0.7348865677972024, 0.9668190499724828], 5 -> 
             RGBColor[
              0.6839868523744643, 0.7530549946583275, 0.9691370752902886], 
             101 -> RGBColor[
              0.9949505632429452, 0.9916080902900563, 0.6917781543851528], 
             333 -> RGBColor[
              0.9186387449031443, 0.71513676611167, 0.25339302823620097`], 
             267 -> RGBColor[
              0.8292209054911932, 0.8666622577095572, 0.9835730242916328], 
             120 -> 
             RGBColor[
              0.7112338658207771, 0.774340568647559, 0.9718528029527996], 147 -> 
             RGBColor[
              0.22213383740057638`, 0.3508071255797213, 0.9359615654711749], 
             89 -> RGBColor[
              0.9665318154661409, 0.9745600632905461, 0.9415370859020138], 43 -> 
             RGBColor[
              0.8560348918019747, 0.4317143098019431, 0.20129238171291666`], 
             199 -> RGBColor[
              0.37743950275094684`, 0.501340859447032, 0.945271089252011], 
             268 -> RGBColor[
              0.7594730711442471, 0.8120254024777932, 0.9766608361184391], 
             169 -> RGBColor[
              0.9002486463241636, 0.6399342251261345, 0.2384773641745099], 20 -> 
             RGBColor[
              0.34734357171776975`, 0.4752732766515705, 0.9433534031393638], 
             4 -> RGBColor[
              0.8911094427050128, 0.5984352360068067, 0.23085138865231034`], 
             167 -> RGBColor[
              0.9186387449031443, 0.71513676611167, 0.25339302823620097`], 
             431 -> RGBColor[
              0.9934498891320372, 0.9883983001082509, 0.5284390384999006], 
             142 -> RGBColor[0.817319, 0.134127, 0.164218], 16 -> 
             RGBColor[
              0.2837493086151196, 0.41556889247271844`, 0.9394704754049221], 
             414 -> RGBColor[
              0.9412734673245903, 0.9557224286033269, 0.9842928808733978], 
             281 -> RGBColor[
              0.6011628176215589, 0.6870900832783147, 0.9617448856165807], 
             289 -> RGBColor[
              0.9670483664095733, 0.9749453061383835, 0.9406626998928456], 
             398 -> RGBColor[
              0.8072315565348098, 0.8493346942428333, 0.9814209556137496], 
             178 -> RGBColor[
              0.9510571864365709, 0.8436650839864636, 0.27947766725262047`], 
             58 -> RGBColor[
              0.9268424120359698, 0.7476615725833072, 0.2599938913760892], 
             186 -> RGBColor[
              0.9943346752603658, 0.9902907681711459, 0.6247425483014287], 
             122 -> RGBColor[
              0.3027379010344937, 0.43552710705177666`, 0.9405518476521003], 
             249 -> RGBColor[
              0.7876673231335933, 0.8340509664161221, 0.9794709756664722], 
             113 -> RGBColor[
              0.9043464290377469, 0.9265653109575667, 0.9907385637928497], 52 -> 
             RGBColor[
              0.7014935223134834, 0.7667313382703087, 0.9708819765406779], 
             409 -> RGBColor[
              0.838015691230728, 0.2932108381473023, 0.18403717489611457`], 
             187 -> 
             RGBColor[
              0.691414225856509, 0.75885731527263, 0.9698773664662274], 259 -> 
             RGBColor[
              0.9695537518335147, 0.9089597971947276, 0.3362225044750749], 42 -> 
             RGBColor[
              0.953715116437291, 0.854202890736651, 0.28161630012083555`], 
             134 -> RGBColor[
              0.9485237242120022, 0.9611296583187526, 0.972020087132856], 470 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 313 -> 
             RGBColor[
              0.9151214299602142, 0.7011917844386748, 0.25056291407112635`], 
             248 -> RGBColor[
              0.39314578068340655`, 0.5149448479716463, 0.946271879393351], 
             174 -> RGBColor[
              0.40182652200944635`, 0.5224636698015167, 0.9468250085545681], 
             215 -> RGBColor[
              0.4065376349747133, 0.5265441990646085, 0.9471251965068413], 
             399 -> RGBColor[
              0.992803001965474, 0.9870146738692974, 0.458029362544323], 422 -> 
             RGBColor[
              0.8254954963078062, 0.8636917175502627, 0.9832176914380094], 83 -> 
             RGBColor[
              0.5534569353531872, 0.6483602989273456, 0.9579893038120098], 95 -> 
             RGBColor[
              0.9927399984366677, 0.9868799156918147, 0.451171817246467], 166 -> 
             RGBColor[
              0.26334245696950204`, 0.39411999752404975`, 0.9383083353929358],
              384 -> RGBColor[
              0.8803621772181066, 0.9074409195917579, 0.9884509244432981], 
             233 -> RGBColor[
              0.9811337794174675, 0.9854501840969239, 0.9168197697345547], 
             295 -> RGBColor[
              0.32800310799819377`, 0.4585215390576448, 0.942121045893253], 
             499 -> RGBColor[
              0.2720014946071466, 0.40322119509591003`, 0.9388014547765015], 
             141 -> RGBColor[
              0.8367579305286419, 0.2835431382368141, 0.18283274182735934`], 
             319 -> RGBColor[
              0.6123115813940769, 0.6961411519549292, 0.9626225571400207], 
             205 -> RGBColor[
              0.37743950275094684`, 0.501340859447032, 0.945271089252011], 
             468 -> RGBColor[
              0.2569232119297078, 0.38737296398358306`, 0.9379427688843415], 
             486 -> RGBColor[
              0.8421437342429783, 0.8769665705753888, 0.9848056152343235], 
             224 -> RGBColor[
              0.37869045497903886`, 0.5024243713923182, 0.9453507988218113], 
             231 -> RGBColor[
              0.7022256390251621, 0.7673032734097652, 0.9709549470924783], 
             332 -> 
             RGBColor[
              0.5874184824616506, 0.6759318128202583, 0.9606628812056341], 68 -> 
             RGBColor[
              0.2802709153078253, 0.4119128805638785, 0.9392723860518934], 
             484 -> RGBColor[
              0.9950526159278561, 0.9922221437912667, 0.7316544877023741], 10 -> 
             RGBColor[
              0.3552328729671579, 0.4821065928659801, 0.9438561024387396], 
             250 -> RGBColor[
              0.3221933704063147, 0.45348943636146094`, 0.9417508545512476], 
             282 -> RGBColor[
              0.9858979775300591, 0.9884364655503023, 0.8833705373985946], 
             374 -> RGBColor[0.817319, 0.134127, 0.164218], 232 -> 
             RGBColor[
              0.9913599024609148, 0.990695111874279, 0.7928523062857054], 489 -> 
             RGBColor[
              0.9658208254253059, 0.9740298080822307, 0.942740606585246], 253 -> 
             RGBColor[
              0.9118591450257207, 0.6882579117654194, 0.24793800303716376`], 
             459 -> RGBColor[
              0.9054425315984804, 0.6628181777360814, 0.24277504525633103`], 
             415 -> RGBColor[
              0.9649066395415438, 0.9733480097469629, 0.9442880848285904], 55 -> 
             RGBColor[
              0.4983827581914804, 0.6036486008440649, 0.9536536628424819], 
             446 -> RGBColor[
              0.4143297663849308, 0.5332933516482266, 0.9476217042299891], 
             325 -> RGBColor[
              0.9883334961064355, 0.9894436150716063, 0.8430076916680075], 91 -> 
             RGBColor[
              0.2525025325862419, 0.3827265497063414, 0.9376910177355402], 
             450 -> RGBColor[
              0.3492297683683656, 0.47690700538731645`, 0.9434735899220416], 
             423 -> RGBColor[
              0.9216958764546208, 0.9403992893895774, 0.9923933695755057], 
             105 -> RGBColor[
              0.37708305267780634`, 0.5010321203093794, 0.9452483765685469], 
             36 -> RGBColor[
              0.9931784408027075, 0.9878176995794506, 0.49889356303726196`], 
             123 -> RGBColor[
              0.9938417764588451, 0.9892365074744063, 0.5710935555746962], 94 -> 
             RGBColor[
              0.9910926785151151, 0.9905846079053487, 0.7972808986210093], 
             473 -> RGBColor[0.817319, 0.134127, 0.164218], 312 -> 
             RGBColor[0.5484002048218, 0.644255017278851, 0.9575912194611647],
              96 -> RGBColor[
              0.9931578862266676, 0.9877737354196875, 0.4966563242834481], 
             496 -> 
             RGBColor[
              0.3155675345838855, 0.4477504703962643, 0.941328662151639], 2 -> 
             RGBColor[
              0.7153791446586231, 0.7775788919809703, 0.9722659656075229], 
             262 -> RGBColor[
              0.8292209054911932, 0.8666622577095572, 0.9835730242916328], 
             272 -> RGBColor[0.817319, 0.134127, 0.164218], 97 -> 
             RGBColor[
              0.3216213324007257, 0.4529939657924859, 0.9417144047953648], 
             372 -> RGBColor[
              0.6354157233737157, 0.7148981352437349, 0.9644413998299185], 
             356 -> RGBColor[
              0.3058906356046225, 0.4388408309798991, 0.9407313912218164], 
             402 -> RGBColor[
              0.43454044612695547`, 0.5507988266224684, 0.9489095108715485], 
             455 -> RGBColor[
              0.25246812917611056`, 0.38269038954099116`, 0.9376890585122285],
              428 -> RGBColor[
              0.8986936657651294, 0.922057950964153, 0.9901993981856262], 346 -> 
             RGBColor[
              0.8453739778394759, 0.8795422791366093, 0.98511371875223], 341 -> 
             RGBColor[
              0.41886888127074673`, 0.5372249048197727, 0.9479109326167315], 
             209 -> RGBColor[0.817319, 0.134127, 0.164218], 498 -> 
             RGBColor[
              0.9289349840293515, 0.7559579232287855, 0.26167762392094174`], 
             378 -> RGBColor[
              0.9440673236038608, 0.9578060820418871, 0.9795636109470125], 
             419 -> RGBColor[
              0.9877596050956831, 0.9892062963903339, 0.8525185508985033], 66 -> 
             RGBColor[
              0.9597844504530005, 0.8760056496972068, 0.2982706133895423], 
             139 -> RGBColor[
              0.9411592268827486, 0.8044229726550537, 0.2715135366606436], 56 -> 
             RGBColor[
              0.5564858290344584, 0.6508192912679069, 0.9582277494178025], 
             335 -> RGBColor[
              0.416033737501342, 0.5347692457851835, 0.9477302797627644], 314 -> 
             RGBColor[
              0.9367268384270373, 0.9523315602159536, 0.9919891376462213], 
             144 -> RGBColor[
              0.7753195488427815, 0.8244047912935795, 0.9782402649216755], 
             298 -> RGBColor[
              0.6085570699482019, 0.6930930704243548, 0.9623269882457728], 
             204 -> RGBColor[
              0.9876678819813026, 0.9891683665253611, 0.8540386402755984], 
             452 -> RGBColor[
              0.9916313643528499, 0.9908073683428467, 0.7883534802154828], 
             466 -> 
             RGBColor[
              0.8709064619399829, 0.5066982188788449, 0.21399352628159504`], 
             207 -> RGBColor[
              0.4874939903566474, 0.5948086085823466, 0.952796459151653], 334 -> 
             RGBColor[
              0.8388693831921479, 0.8743556919273482, 0.9844933047080476], 
             149 -> RGBColor[
              0.9388902569221245, 0.9539450341873168, 0.9883270344439504], 
             219 -> RGBColor[
              0.805604487924561, 0.8480636158783275, 0.9812587846205006], 400 -> 
             RGBColor[
              0.965237203282108, 0.9735945436434273, 0.9437285266406465], 9 -> 
             RGBColor[
              0.7177237229787834, 0.7794104943841348, 0.9724996512631464], 11 -> 
             RGBColor[
              0.5353901417107647, 0.6336928619486486, 0.9565670196356325], 44 -> 
             RGBColor[
              0.9382985297324757, 0.9535037250181412, 0.9893286742288575], 
             153 -> RGBColor[
              0.31045172271567173`, 0.4433194112841984, 0.9410026871431313], 
             471 -> RGBColor[
              0.9553827963209697, 0.9662451430669208, 0.9604094671848902], 
             406 -> RGBColor[
              0.29401825106717394`, 0.42636220207838416`, 0.9400552764860276],
              32 -> RGBColor[
              0.4686551241331842, 0.5795143683008873, 0.9513133945935012], 
             162 -> RGBColor[
              0.48183396234568104`, 0.590213542861688, 0.9523508810132639], 
             493 -> RGBColor[
              0.8163081595876761, 0.8564254055324707, 0.9823256265803813], 90 -> 
             RGBColor[
              0.7686115797798849, 0.8191644748791914, 0.9775716772550208], 
             331 -> RGBColor[
              0.9885979195673846, 0.9895529609680818, 0.8386255106141007], 8 -> 
             RGBColor[
              0.5508696709985361, 0.646259841169309, 0.95778562488455], 364 -> 
             RGBColor[
              0.5943848890942799, 0.6815874555576691, 0.961211302254543], 342 -> 
             RGBColor[
              0.28316870139692335`, 0.4149586374737704, 0.9394374106827772], 
             163 -> RGBColor[
              0.2784191864306398, 0.40996659610756464`, 0.9391669328317251], 
             49 -> RGBColor[
              0.28316870139692335`, 0.4149586374737704, 0.9394374106827772], 
             338 -> RGBColor[
              0.956236044876418, 0.8640360444821438, 0.2844857277846857], 76 -> 
             RGBColor[
              0.8962260457900924, 0.6216685356031413, 0.235120807685919], 369 -> 
             RGBColor[
              0.7166371369724428, 0.778561645137622, 0.9723913505247579], 445 -> 
             RGBColor[
              0.9924444353496488, 0.9911435940949945, 0.774878789638237], 82 -> 
             RGBColor[
              0.2684923602142315, 0.3995328723569852, 0.938601614764124], 67 -> 
             RGBColor[
              0.5621683095192537, 0.6554325849182923, 0.9586750950971775], 
             430 -> RGBColor[
              0.9456009639117452, 0.9589498684724018, 0.9769675579432181], 
             211 -> RGBColor[
              0.9589371148738471, 0.9688959480239943, 
               0.9543929329896146]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw1l3k4VA/cxYfs69jHPjOGGTNjV1rUPZUi6hcVbZKtXVmyRook2RJlqUih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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 42}], {
             RGBColor[
             0.9544985948719407, 0.9101864573721832, 0.6210981325481504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 108}], {
             RGBColor[
             0.9745842865208124, 0.9789549743927156, 0.8557800079024303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[
             0.9298142511721685, 0.946367667482641, 0.9756592643841575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 119}], {
             RGBColor[
             0.9466658838195627, 0.9597440839960059, 0.9751649263148776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 120}], {
             RGBColor[
             0.8332579695636837, 0.8702552963276371, 0.9662163839641325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 124}], {
             RGBColor[
             0.8921251580314895, 0.9163154076554434, 0.9720644450349489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 315}], {
             RGBColor[
             0.9547994024132473, 0.9658100488457614, 0.9613970008971638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 363}], {
             RGBColor[
             0.6429310621163171, 0.7134617907542732, 0.9514326056966897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 364}], {
             RGBColor[
             0.774833481200435, 0.8238787397826922, 0.9608956336150041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 378}], {
             RGBColor[
             0.9496746984552256, 0.9619880530248013, 0.9700717879612388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 380}], {
             RGBColor[
             0.9648761571508514, 0.9458571467955325, 0.6579510507211375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 381}], {
             RGBColor[
             0.6253505192595743, 0.6970022327316525, 0.9503575050299508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 416}], {
             RGBColor[
             0.9722665808556692, 0.9779965435378601, 0.8941903888038425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 452}], {
             RGBColor[
             0.9734567188297201, 0.978488696175281, 0.874466722595474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 468}], {
             RGBColor[
             0.6061026426181491, 0.6767714939956492, 0.9492613669299033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 487}], {
             RGBColor[
             0.6375588308134427, 0.7088086340159198, 0.9510902918685482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[
             0.8375817975558117, 0.8267922708390886, 0.6352682894985326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 114}], {
             RGBColor[
             0.7159130218019847, 0.777995960862981, 0.9723191774918076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 118}], {
             RGBColor[
             0.6172174447390172, 0.699005377338512, 0.9637735408425003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 195}], {
             RGBColor[
             0.5669730044878697, 0.657271102447661, 0.960078826985516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 255}], {
             RGBColor[
             0.819680431106879, 0.8599004245082971, 0.982438680373895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 260}], {
             RGBColor[
             0.6180474532956074, 0.6996792156762113, 0.9638388821564967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 312}], {
             RGBColor[
             0.6318896747402115, 0.7109169546299107, 0.9649285925343438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 327}], {
             RGBColor[
             0.6495287885753281, 0.7252371818742811, 0.9663172081896472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 334}], {
             RGBColor[
             0.7771242639253855, 0.8259672919541592, 0.9783796351577853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 385}], {
             RGBColor[
             0.850884023972234, 0.8831091839737532, 0.9237502963788096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 446}], {
             RGBColor[
             0.5648544555217769, 0.6554361218145984, 0.959943834918756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 496}], {
             RGBColor[
             0.5154733396212543, 0.6126646811886173, 0.9567973138795809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[
             0.8231149547172004, 0.8588031711895721, 0.7685405829110616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 139}], {
             RGBColor[
             0.7967736799291522, 0.7663964037798958, 0.6187505734540353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 158}], {
             RGBColor[
             0.7929693744256, 0.7513136001679697, 0.6156895399473501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 247}], {
             RGBColor[
             0.47567916163036134`, 0.5799684195361566, 0.953162446173091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 278}], {
             RGBColor[
             0.782307739672297, 0.7090437711502939, 0.6071109383641102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 401}], {
             RGBColor[
             0.7623420443251853, 0.332207944968246, 0.4314745367491424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 428}], {
             RGBColor[
             0.7755408993703425, 0.8252138929344455, 0.9780935042165266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 437}], {
             RGBColor[
             0.5503751825774095, 0.6455701989512743, 0.9578889165520516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 451}], {
             RGBColor[
             0.4546556724526318, 0.5578713994441605, 0.9519651895658843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 31}], {
             RGBColor[
             0.7413183383971343, 0.6388513592477532, 0.5959188629184613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 151}], {
             RGBColor[
             0.9211726653914398, 0.7807938108479803, 0.5991402449029416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 162}], {
             RGBColor[
             0.686471702525347, 0.5943243894342474, 0.5916011348327871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 191}], {
             RGBColor[
             0.6635745796988659, 0.5752663277189047, 0.5899282158592782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.8646706764798965, 0.7361413121588198, 0.6076419453112565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 345}], {
             RGBColor[
             0.8983099877016473, 0.7629643858122659, 0.6108504928457548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 366}], {
             RGBColor[
             0.6881902654700018, 0.5957195962530966, 0.5917364264030939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 389}], {
             RGBColor[
             0.9426100905124889, 0.7941235128529665, 0.4156098914848544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 405}], {
             RGBColor[
             0.8738647142805717, 0.7434723883355705, 0.6085188808442994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 429}], {
             RGBColor[
             0.8244966780471059, 0.704609588184155, 0.6036769161886248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 472}], {
             RGBColor[
             0.8828927516908874, 0.7506711003070091, 0.6093799831119194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 488}], {
             RGBColor[
             0.5798009014596222, 0.49898405418189595`, 0.5847265017082172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 69}], {
             RGBColor[
             0.8340960042512751, 0.8703957175276941, 0.940281022100468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[
             0.6187218938638257, 0.7007076467928366, 0.9635631895511492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 97}], {
             RGBColor[
             0.502804092387595, 0.6030244802254067, 0.9554257400428268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 103}], {
             RGBColor[
             0.7670508399049876, 0.8181887492879405, 0.9773514902545974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 129}], {
             RGBColor[
             0.44891440266837623`, 0.5475734119787847, 0.9523132151047233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 163}], {
             RGBColor[
             0.48120301940255206`, 0.581510795382946, 0.9541520040610069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 204}], {
             RGBColor[
             0.8358273671778835, 0.8711116805918443, 0.9115878577829435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 209}], {
             RGBColor[
             0.7728749507914882, 0.34043633155277586`, 0.4325243584300962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 231}], {
             RGBColor[
             0.6931062456998132, 0.7601791340340464, 0.9700460111913835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 233}], {
             RGBColor[
             0.8325603158959659, 0.8692525893776257, 0.9429784225124216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 259}], {
             RGBColor[
             0.8267703021039895, 0.8310073959265276, 0.6526797898826817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 275}], {
             RGBColor[
             0.8383678757900248, 0.8699769740974257, 0.7106388431521349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 326}], {
             RGBColor[
             0.797262976238764, 0.8422790867138998, 0.9802331507888056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 346}], {
             RGBColor[
             0.7646804151069702, 0.8162986368974684, 0.9771253970212592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 348}], {
             RGBColor[
             0.6641361497654876, 0.7375474749092672, 0.9671585427695887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 355}], {
             RGBColor[
             0.4835777768856938, 0.584006816066049, 0.9542872429865329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 395}], {
             RGBColor[
             0.5094224161358215, 0.6087569396094967, 0.9558474537797098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 404}], {
             RGBColor[
             0.7805499935971885, 0.6439681327398266, 0.5941548007811855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 431}], {
             RGBColor[
             0.8387183707532508, 0.8707266473832892, 0.7487880568950946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 444}], {
             RGBColor[
             0.5496154677819874, 0.6435701407838912, 0.9584085194892835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 486}], {
             RGBColor[
             0.7630652933087213, 0.8150107826168582, 0.9769713452623061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 35}], {
             RGBColor[
             0.8931875397103566, 0.6078713891561862, 0.23258540373238806`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 101}], {
             RGBColor[
             0.9395191364736517, 0.7790796383541492, 0.4583852184516456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 123}], {
             RGBColor[
             0.9389647430816016, 0.7778938469463241, 0.3980429190464173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 158}], {
             RGBColor[
             0.9088191627900012, 0.6704042759247217, 0.24519187608270565`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 181}], {
             RGBColor[
             0.8943303801477342, 0.7466485996254912, 0.6078762308385277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 189}], {
             RGBColor[
             0.6039742210975829, 0.5107424040066179, 0.5834246899535097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 302}], {
             RGBColor[
             0.931613994844698, 0.7752573109512577, 0.5725932634019372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 306}], {
             RGBColor[
             0.9292704129846852, 0.7460188451329423, 0.29012394632112065`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 347}], {
             RGBColor[
             0.561609935400565, 0.4676123139793178, 0.5809609386885226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 370}], {
             RGBColor[
             0.8880175326972923, 0.5843955947956776, 0.22827142315221893`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 390}], {
             RGBColor[
             0.7200880006737587, 0.6085238694615185, 0.5915943681681352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 422}], {
             RGBColor[
             0.8547916030060821, 0.7151214519842524, 0.6041049869780739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 428}], {
             RGBColor[
             0.8913906877347437, 0.7443045686911975, 0.6075958403518823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 451}], {
             RGBColor[
             0.570505460817033, 0.4769620752009126, 0.5814675257012399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 17}], {
             RGBColor[
             0.3878326504325049, 0.510223091610112, 0.9459664297614447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.6553620808741647, 0.7183927246563311, 0.6989725238972647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.6348480056638033, 0.7066725676052581, 0.9540103231857188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.6508578425795862, 0.23935183568273963`, 0.4233051828605111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 89}], {
             RGBColor[
             0.6422336716024497, 0.7121807851693824, 0.9415083172417735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 176}], {
             RGBColor[
             0.6313447477147311, 0.7040598435628984, 0.9599404250974903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 178}], {
             RGBColor[
             0.6344963570876647, 0.6467332955173413, 0.610478607917077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 244}], {
             RGBColor[
             0.6032558030789592, 0.681895984248644, 0.9653569611270121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 261}], {
             RGBColor[
             0.3892860352988107, 0.511403014918821, 0.9460808455420444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 262}], {
             RGBColor[
             0.5735782166149759, 0.658231882378888, 0.9625262864365831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 288}], {
             RGBColor[
             0.4585151646363388, 0.5676063408517622, 0.9515308161981513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 295}], {
             RGBColor[
             0.32296931786847627`, 0.45416152305293184`, 0.9418002972373931]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 313}], {
             RGBColor[
             0.6165284788494865, 0.5754966457434468, 0.5960212313263299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 321}], {
             RGBColor[
             0.6113858137995551, 0.688378634113985, 0.9661324088072887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 341}], {
             RGBColor[
             0.3684022045047527, 0.4935132059339958, 0.9446952405991325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 376}], {
             RGBColor[
             0.656131226169524, 0.7200378486705865, 0.7826892426825838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 391}], {
             RGBColor[
             0.38019905631354045`, 0.5037310460437556, 0.945446925564842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 407}], {
             RGBColor[
             0.3938215641720215, 0.5150851615813409, 0.9464378989891333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 448}], {
             RGBColor[
             0.6176826141667517, 0.693399531804695, 0.9667330032475321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 455}], {
             RGBColor[
             0.28520182845743464`, 0.41624594829460504`, 0.9395843035468809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 475}], {
             RGBColor[
             0.4578493711532836, 0.5670658197085634, 0.9514784024962832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 478}], {
             RGBColor[
             0.5764997887526195, 0.6605614646974819, 0.9628049485951897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 482}], {
             RGBColor[
             0.6151139095256866, 0.6913513164495395, 0.9664879979057575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 63}], {
             RGBColor[
             0.6477095428871742, 0.7233133849340458, 0.9664795052028408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 85}], {
             RGBColor[
             0.6344106395835273, 0.7129241805978281, 0.9651539948068505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 146}], {
             RGBColor[
             0.7196087514686917, 0.6160776238387701, 0.5931663289101489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 159}], {
             RGBColor[
             0.44350440418971177`, 0.5559141999747581, 0.9502125456878299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 166}], {
             RGBColor[
             0.40710606398401905`, 0.5201899193466794, 0.9480469801387429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 239}], {
             RGBColor[
             0.5885403504015385, 0.6768425957534341, 0.9607511987593997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 344}], {
             RGBColor[
             0.7278604047821258, 0.7866137969022513, 0.9742861641613685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 387}], {
             RGBColor[
             0.7423003511533307, 0.4108938391546379, 0.4419533248922598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 435}], {
             RGBColor[
             0.4796894872830156, 0.5872559002350201, 0.9525182271853226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 439}], {
             RGBColor[
             0.6039768435550694, 0.6891490678349803, 0.9621206384387276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 453}], {
             RGBColor[
             0.7515384254179711, 0.48190172610262, 0.45079971524099205`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 68}], {
             RGBColor[
             0.49899731914330436`, 0.5956616874740066, 0.95588601865752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 95}], {
             RGBColor[
             0.8552318607077256, 0.8831452050379747, 0.7118357342548067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 286}], {
             RGBColor[
             0.8505918699672086, 0.8676396945910481, 0.6813726848799199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 319}], {
             RGBColor[
             0.6650176521864302, 0.7377758231695319, 0.9675611042015835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 330}], {
             RGBColor[
             0.8397918615790232, 0.8752431627415614, 0.9609724509206357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 333}], {
             RGBColor[
             0.8181812339409639, 0.7472736302479024, 0.6129463397496737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 352}], {
             RGBColor[
             0.7617143484245155, 0.813776305323477, 0.9768842256918093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 357}], {
             RGBColor[
             0.8519796899593666, 0.8839932995241959, 0.9251369834767771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 358}], {
             RGBColor[
             0.7955755310954822, 0.8406608811955653, 0.9801445623333183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 367}], {
             RGBColor[
             0.7755918647546849, 0.8247264480975858, 0.9782385023981034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 368}], {
             RGBColor[
             0.794290019373338, 0.8396358490426136, 0.9800219490776703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 375}], {
             RGBColor[
             0.7849616185978674, 0.8321976354769469, 0.9791321978841441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 441}], {
             RGBColor[
             0.8467118599516924, 0.8545515097390366, 0.6662995786480495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 450}], {
             RGBColor[
             0.5334767456735745, 0.6281587498857256, 0.957986620592594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 492}], {
             RGBColor[
             0.7841205743262611, 0.3492214981280449, 0.43364521708771553`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 102}], {
             RGBColor[
             0.6577517959690033, 0.725998570320971, 0.9479957957758924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 168}], {
             RGBColor[
             0.31264294709081636`, 0.4416399094429218, 0.9412732972690182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 181}], {
             RGBColor[
             0.6299029617791341, 0.7044263028493603, 0.9673081407988283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.33954680272898274`, 0.46852010723048687`, 0.9428565999138103]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 232}], {
             RGBColor[
             0.6732963877140363, 0.7364008523701295, 0.8683542043622225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 280}], {
             RGBColor[
             0.6470998765784575, 0.6389188207197749, 0.6068028127446057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 302}], {
             RGBColor[
             0.6671865764760978, 0.7330350141751267, 0.9320251733622378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 370}], {
             RGBColor[
             0.6235901143286923, 0.5421732980195466, 0.5877033331125195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 383}], {
             RGBColor[
             0.5555625367357498, 0.6456672959921272, 0.9600800154184659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 390}], {
             RGBColor[
             0.4556605823051586, 0.5663015726853875, 0.9510262781284358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 443}], {
             RGBColor[
             0.6186180621202113, 0.6954280301817762, 0.9662317769952113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 451}], {
             RGBColor[
             0.30607804244843284`, 0.4347397784247816, 0.9408994356615406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 480}], {
             RGBColor[
             0.6632902909890526, 0.2501201976219934, 0.42409736747957993`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 25}], {
             RGBColor[
             0.502770293384839, 0.6072105995702415, 0.9539990656849741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 164}], {
             RGBColor[
             0.39659296401354205`, 0.5109914784684859, 0.9472797401702167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 180}], {
             RGBColor[
             0.5655333839874984, 0.6581645039664907, 0.9589400060859916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 205}], {
             RGBColor[
             0.4564148222308558, 0.5675168606978402, 0.9509190544438217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 259}], {
             RGBColor[
             0.7524719467721397, 0.7713263295716881, 0.6463947620553537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 316}], {
             RGBColor[
             0.39615667682023625`, 0.5105329129661158, 0.947254894259987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 331}], {
             RGBColor[
             0.7619940306390747, 0.8116229114583652, 0.8975962651248666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 348}], {
             RGBColor[
             0.5898377944336379, 0.6778664085544278, 0.9608735149422607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 372}], {
             RGBColor[
             0.5854029325422402, 0.6742954985961918, 0.9605042097327755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 404}], {
             RGBColor[
             0.7062516382653388, 0.5842870663849872, 0.5878697729538576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 418}], {
             RGBColor[
             0.7233427139035882, 0.3006489539828829, 0.4283343398785442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 431}], {
             RGBColor[
             0.7644200154214009, 0.8110455810284498, 0.7425030290677666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 444}], {
             RGBColor[
             0.47531711245013764`, 0.5838890744290517, 0.9521234916619554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 40}], {
             RGBColor[
             0.6710872125534979, 0.7321123322464503, 0.7084606001662512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 161}], {
             RGBColor[
             0.8804325299931155, 0.9029710908123094, 0.7254751988240777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 188}], {
             RGBColor[
             0.9558927974983625, 0.8516280272463455, 0.3635016640830715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 202}], {
             RGBColor[
             0.8861177842949943, 0.9074124546824703, 0.726041851841167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 243}], {
             RGBColor[
             0.9326198879611677, 0.750160723099516, 0.3442999331676607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 273}], {
             RGBColor[
             0.9792516625399901, 0.9805759754319218, 0.7083159902786631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 279}], {
             RGBColor[
             0.722491999543238, 0.7766365750572451, 0.7117360677377691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 283}], {
             RGBColor[
             0.9749362464198875, 0.9773575451553946, 0.7156208641292136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 285}], {
             RGBColor[
             0.9866489953503571, 0.9663534913412231, 0.4258122260625343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 318}], {
             RGBColor[
             0.6387993246705911, 0.7019187159046858, 0.7064848031150537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 335}], {
             RGBColor[
             0.7044891971199861, 0.7610434524453839, 0.7105889450866126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 396}], {
             RGBColor[
             0.6287232588872621, 0.6913281319069376, 0.7059109860748966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 421}], {
             RGBColor[
             0.9090331262510508, 0.9253556192555271, 0.7283148194403833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 430}], {
             RGBColor[
             0.9692728103251878, 0.973133763788993, 0.7252075841768395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 459}], {
             RGBColor[
             0.9491935941685554, 0.8250679184208328, 0.35811132783339594`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 477}], {
             RGBColor[
             0.6236021634919517, 0.6859455359502649, 0.7056193472681154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 21}], {
             RGBColor[
             0.8657532547014751, 0.4132993177957, 0.4255305943175588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 59}], {
             RGBColor[
             0.8762955154472972, 0.419453515707833, 0.3146013156838614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 77}], {
             RGBColor[
             0.8111538619767299, 0.3703401079011869, 0.4363396425602779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 87}], {
             RGBColor[
             0.876429020602383, 0.41973906973511976`, 0.32913252791663894`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 161}], {
             RGBColor[
             0.8008528010825335, 0.3622928408396782, 0.4353129290792316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 188}], {
             RGBColor[
             0.8511596460860316, 0.32806413179570226`, 0.19399723925189402`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 228}], {
             RGBColor[
             0.8561700630101069, 0.3479287652771972, 0.19802873831860587`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 243}], {
             RGBColor[
             0.8356443730612351, 0.26041926236448254`, 0.18119608530828687`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 256}], {
             RGBColor[
             0.8763571381768146, 0.4195853204952571, 0.3213085695004282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 279}], {
             RGBColor[
             0.6955591141159485, 0.278069830336302, 0.42615350835502575`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 285}], {
             RGBColor[
             0.8716637779873613, 0.40454777452562063`, 0.23553761390486924`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 287}], {
             RGBColor[
             0.8117294821840424, 0.370789786782015, 0.43639701500306616`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 298}], {
             RGBColor[
             0.747731689982734, 0.3204490234747849, 0.43025432941525754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 335}], {
             RGBColor[
             0.6835572458337806, 0.2676744152617278, 0.4253887599209214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 354}], {
             RGBColor[
             0.8383333924060355, 0.39189830653058594`, 0.43896230814776604`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 409}], {
             RGBColor[
             0.8242178970769094, 0.18715494604910077`, 0.1708243916320382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 430}], {
             RGBColor[
             0.8600796546372484, 0.40906795615746727`, 0.43513451931440605`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 477}], {
             RGBColor[
             0.6296325567484244, 0.21760913759831518`, 0.42207569470858985`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 80}], {
             RGBColor[
             0.91223276457405, 0.6808357693966132, 0.24777806143665881`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 159}], {
             RGBColor[
             0.6047284177444421, 0.4916078189697436, 0.5793224936680512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 166}], {
             RGBColor[
             0.5683300775387493, 0.45588353834166495`, 0.5771569281189641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 192}], {
             RGBColor[
             0.8990321129806953, 0.6284995846853377, 0.23715650730552826`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.8459475896663211, 0.6879226480010172, 0.5992786660990652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 239}], {
             RGBColor[
             0.7497643639562688, 0.6125362147484196, 0.5898611467396211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 251}], {
             RGBColor[
             0.9342343331978582, 0.7548419077880255, 0.464798263798639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 272}], {
             RGBColor[
             0.8359852327026656, 0.2619670263864267, 0.18148050694833087`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 435}], {
             RGBColor[
             0.6409135008377458, 0.5229495192300055, 0.5816281751655439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 447}], {
             RGBColor[
             0.564772793175418, 0.4521446069309481, 0.576954346037003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 453}], {
             RGBColor[
             0.8590211011211247, 0.43903080543261036`, 0.20353968056113955`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 454}], {
             RGBColor[
             0.5785335033615582, 0.46660798581599927`, 0.5777379981249573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 489}], {
             RGBColor[
             0.9195692617666513, 0.7458384436207555, 0.5793730637151193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 50}], {
             RGBColor[
             0.6405391021745221, 0.23992786184201234`, 0.42417024418465854`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 82}], {
             RGBColor[
             0.6360127536298598, 0.2351703825344988, 0.4239124753311726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 126}], {
             RGBColor[
             0.8574872343114881, 0.41844134297194024`, 0.44219978244809277`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 149}], {
             RGBColor[
             0.8594787191991574, 0.41997443647794264`, 0.4404876152244481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 173}], {
             RGBColor[
             0.6319245963060623, 0.23087346998304242`, 0.4236796608194692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 242}], {
             RGBColor[
             0.7208268314526661, 0.30985305406329755`, 0.4295740948326925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 249}], {
             RGBColor[
             0.8090710746029803, 0.38000974722087777`, 0.4375355956319553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 269}], {
             RGBColor[
             0.7879511852838504, 0.3635107291676696, 0.4354305624412115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 282}], {
             RGBColor[
             0.8751479594018022, 0.4314715802656045, 0.4055021162093295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 323}], {
             RGBColor[
             0.8189549668917826, 0.14670175841550373`, 0.1657846037431313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 414}], {
             RGBColor[
             0.860273122666646, 0.42056690128327934`, 0.43914289736759726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 419}], {
             RGBColor[
             0.875768501923677, 0.431728190545615, 0.39521812070929907`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 449}], {
             RGBColor[
             0.6302820769464065, 0.22914707799430184`, 0.4235861217718264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 499}], {
             RGBColor[
             0.6371824650941648, 0.23639982344747373`, 0.42397908866863177`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 17}], {
             RGBColor[
             0.3707395408706854, 0.49310678432236177`, 0.9449618931731391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 116}], {
             RGBColor[
             0.290153632161958, 0.42230024257801124`, 0.9398351921565669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 143}], {
             RGBColor[
             0.6102380735210784, 0.683950226344336, 0.9657298065255717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 165}], {
             RGBColor[
             0.286390278525246, 0.4183447192954248, 0.9396208747343389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 185}], {
             RGBColor[
             0.6377560754144314, 0.7032153151449356, 0.8628225136058045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.4875817672358143, 0.5872131038726742, 0.9546739209355748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 224}], {
             RGBColor[
             0.33121988179707923`, 0.45899663193251833`, 0.9424106371133667]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 277}], {
             RGBColor[
             0.3707143286817686, 0.493086315931603, 0.9449599083772722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 313}], {
             RGBColor[
             0.5994353692876668, 0.5583803384556967, 0.5950166947380242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 333}], {
             RGBColor[
             0.601194026759132, 0.5653528292921942, 0.5964317518205615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 358}], {
             RGBColor[
             0.5785883239136502, 0.6587400802398571, 0.9636299744042061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 361}], {
             RGBColor[
             0.6367928154730746, 0.7028169824045334, 0.8787862236709043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 386}], {
             RGBColor[
             0.5877084124279985, 0.6660121912629904, 0.9644998565883036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 441}], {
             RGBColor[
             0.6297246527698606, 0.6726307087833285, 0.6497849907189372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 89}], {
             RGBColor[
             0.7121307942961961, 0.7726023697312756, 0.9459951984216849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.6388874458829429, 0.7149952052581143, 0.9665755702458828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 116}], {
             RGBColor[
             0.3771438644175238, 0.49983813442765457`, 0.9453266099247839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 143}], {
             RGBColor[
             0.6972283057766442, 0.7614881181939793, 0.9712212242937887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 165}], {
             RGBColor[
             0.37338051078081175`, 0.49588261114506815`, 0.9451122925025559]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 176}], {
             RGBColor[
             0.7012418704084774, 0.7644814281247916, 0.9644273062774016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 178}], {
             RGBColor[
             0.704393479781411, 0.7071548800792343, 0.6149654890969882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 261}], {
             RGBColor[
             0.4591831579925568, 0.5718245994807141, 0.9505677267219557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 277}], {
             RGBColor[
             0.45770456093733436`, 0.5706242077812463, 0.9504513261454892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 288}], {
             RGBColor[
             0.5284122873300849, 0.6280279254136553, 0.9560176973780625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 313}], {
             RGBColor[
             0.6864256015432326, 0.6359182303053399, 0.6005081125062411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 321}], {
             RGBColor[
             0.6812829364933013, 0.7488002186758782, 0.9706192899872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 328}], {
             RGBColor[
             0.7237025338495482, 0.7737395808947017, 0.6824221046621111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 386}], {
             RGBColor[
             0.6746986446835642, 0.7435500831126338, 0.9699912743565207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 391}], {
             RGBColor[
             0.4500961790072867, 0.5641526306056488, 0.9499338067447534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 407}], {
             RGBColor[
             0.46371868686576767`, 0.5755067461432339, 0.9509247801690446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 455}], {
             RGBColor[
             0.35509895115118084`, 0.4766675328564981, 0.9440711847267922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 498}], {
             RGBColor[
             0.6933323785778013, 0.6633012997003953, 0.6060654674311489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 28}], {
             RGBColor[
             0.6865640069751608, 0.751457741525184, 0.9571797136411155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 93}], {
             RGBColor[
             0.6879097459021428, 0.7524613914134819, 0.9549017286626598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 160}], {
             RGBColor[
             0.7034342055745679, 0.7637982372116092, 0.9178182682002112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 167}], {
             RGBColor[
             0.6699314550769275, 0.6272008497674362, 0.60072701873272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 172}], {
             RGBColor[
             0.703553782862641, 0.751654234934025, 0.6738605575397137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 201}], {
             RGBColor[
             0.6999425691023198, 0.7614354512542342, 0.9345332976476736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 218}], {
             RGBColor[
             0.6789755018388739, 0.7457982468195781, 0.9700250734377303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 235}], {
             RGBColor[
             0.5989385163825915, 0.6823556616983519, 0.9632170834477687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 274}], {
             RGBColor[
             0.6852873884169035, 0.2691729778077342, 0.4254990030764131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 300}], {
             RGBColor[
             0.4226019713906831, 0.5404583198510965, 0.948148801818132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 305}], {
             RGBColor[
             0.6868687692970494, 0.6943516566248376, 0.6143551793240922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 310}], {
             RGBColor[
             0.6808928397206864, 0.747228194272481, 0.9667795205256305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 406}], {
             RGBColor[
             0.35762120815894227`, 0.4828135677507933, 0.9440581428576333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 432}], {
             RGBColor[
             0.6852873884169035, 0.2691729778077342, 0.4254990030764131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 460}], {
             RGBColor[
             0.7040175908318558, 0.764039482007815, 0.9081500647343038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 493}], {
             RGBColor[
             0.6187661624191934, 0.6978451694778366, 0.9651933179048102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 26}], {
             RGBColor[
             0.6308917896439188, 0.647466817330552, 0.6111846473572251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 59}], {
             RGBColor[
             0.6512269973735443, 0.7156901965622051, 0.7781155817189673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 67}], {
             RGBColor[
             0.4351868789622252, 0.5483532154596017, 0.949769155741764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 124}], {
             RGBColor[
             0.5685868455807928, 0.6538673186520413, 0.9622060707403914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 188}], {
             RGBColor[
             0.6135231933316458, 0.578606120694009, 0.5972094670710162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 200}], {
             RGBColor[
             0.6127850555383256, 0.6891097715437289, 0.9664217354623488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 228}], {
             RGBColor[
             0.6210388187177587, 0.6084030709162513, 0.603256715671084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 298}], {
             RGBColor[
             0.45838125917669936`, 0.5671834582126329, 0.9515951023160616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 318}], {
             RGBColor[
             0.2964297205038743, 0.4288968093523493, 0.9401926061029984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 335}], {
             RGBColor[
             0.36211959295326934`, 0.4880215458930473, 0.9442967480745574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 459}], {
             RGBColor[
             0.6068239900018386, 0.5520460118684962, 0.5918191308213407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 468}], {
             RGBColor[
             0.2825643301674523, 0.41432340499224707`, 0.939402992635346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 25}], {
             RGBColor[
             0.40874700838834155`, 0.5280008069217024, 0.9473922574368396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 46}], {
             RGBColor[
             0.6202734855223522, 0.541608340311265, 0.5879760202622897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 150}], {
             RGBColor[
             0.6606605239059232, 0.2478424255505235, 0.4239298010464546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 220}], {
             RGBColor[
             0.6606605239059232, 0.2478424255505235, 0.4239298010464546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 325}], {
             RGBColor[
             0.6678385339121027, 0.7323584458615884, 0.8931805474036856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 388}], {
             RGBColor[
             0.6707074404935648, 0.733544812460559, 0.8456353408566235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 392}], {
             RGBColor[
             0.40577931261066497`, 0.5255914977962133, 0.9471586295541932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 413}], {
             RGBColor[
             0.2994727582219643, 0.4285266257081981, 0.9404965668642863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 473}], {
             RGBColor[
             0.6606605239059232, 0.2478424255505235, 0.4239298010464546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 474}], {
             RGBColor[
             0.6702347857385889, 0.7314894050710032, 0.7182695411210422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 490}], {
             RGBColor[
             0.2999058504469402, 0.4289818330962808, 0.9405212308257962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 55}], {
             RGBColor[
             0.7305022611479528, 0.7876462771155825, 0.9509047228975792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 59}], {
             RGBColor[
             0.9784351552231585, 0.9808752502552995, 0.7817618650021304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 77}], {
             RGBColor[
             0.8807226750173074, 0.9072051385453304, 0.9643693553167552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[
             0.9786354129557872, 0.9813035812962297, 0.8035586833512967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 91}], {
             RGBColor[
             0.6075621483453335, 0.6771852515467207, 0.9429234003441084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 188}], {
             RGBColor[
             0.9407313511812601, 0.8437911743871034, 0.6008557503541794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 200}], {
             RGBColor[
             0.9399932133879398, 0.9542948252368233, 0.9700680187455119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 228}], {
             RGBColor[
             0.9482469765673729, 0.8735881246093458, 0.6069029989542472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 256}], {
             RGBColor[
             0.9785275893174346, 0.9810729574364356, 0.7918227457269805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 287}], {
             RGBColor[
             0.8815861053282763, 0.9078796568665726, 0.9644554139809375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 298}], {
             RGBColor[
             0.7855894170263136, 0.8323685119057274, 0.9552413855992247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 335}], {
             RGBColor[
             0.6893277508028837, 0.7532065995861418, 0.9479430313577204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 336}], {
             RGBColor[
             0.8374850177822697, 0.8734275520949528, 0.9600598297224463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 354}], {
             RGBColor[
             0.9214919706612659, 0.9395424364894289, 0.9683033536979873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 409}], {
             RGBColor[
             0.8795510488552938, 0.5193552098939016, 0.4387433775816353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 24}], {
             RGBColor[
             0.6528363172399572, 0.7170451407200673, 0.7706142463137766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 52}], {
             RGBColor[
             0.5065286897840975, 0.605507012297358, 0.9559777639566074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 170}], {
             RGBColor[
             0.6315410922111713, 0.7038228573121279, 0.9540122784095258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 214}], {
             RGBColor[
             0.5901807457327354, 0.671251176616632, 0.9642107196900024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 268}], {
             RGBColor[
             0.5355184641994792, 0.6281540444011002, 0.958867193745488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 466}], {
             RGBColor[
             0.5912351595973472, 0.47549045260162615`, 0.5775335388270659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 491}], {
             RGBColor[
             0.65006756107525, 0.7169123124503951, 0.8900703994375307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 39}], {
             RGBColor[
             0.8635334081857636, 0.8900753084560682, 0.7482950913710615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 51}], {
             RGBColor[
             0.5150279703705647, 0.6103591205532177, 0.9571396016933617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 62}], {
             RGBColor[
             0.6410358437860526, 0.7180620114019811, 0.965840197189024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 96}], {
             RGBColor[
             0.8634146844884865, 0.8898213704723994, 0.7353727496001656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 110}], {
             RGBColor[
             0.8374018262264082, 0.8737430272966226, 0.9793106179040696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 136}], {
             RGBColor[
             0.797847385601538, 0.8423434965056322, 0.9803954598892122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 157}], {
             RGBColor[
             0.8387124260512737, 0.874720470500097, 0.9770921142597515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 240}], {
             RGBColor[
             0.7551621751323889, 0.8086576977493063, 0.9762311662915908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 360}], {
             RGBColor[
             0.8426127351855084, 0.8776293146662392, 0.9704899082590341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 52}], {
             RGBColor[
             0.8478011497693432, 0.878269466693018, 0.785518458897847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 64}], {
             RGBColor[
             0.9720779414633771, 0.9147340227886447, 0.43940993691929886`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.8034403258624296, 0.843161216874867, 0.7814068671772086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 115}], {
             RGBColor[
             0.7614179921907902, 0.8090455933156716, 0.7780987151376969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 170}], {
             RGBColor[
             0.972813552196417, 0.9765853117077878, 0.7835529733507656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 223}], {
             RGBColor[
             0.9893299253579746, 0.9888435406159594, 0.7529235821304705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 268}], {
             RGBColor[
             0.8767909241847249, 0.9009164987967602, 0.7884078886867276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 491}], {
             RGBColor[
             0.9913400210604957, 0.989674766846055, 0.7196110943787705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 164}], {
             RGBColor[
             0.3639731156876163, 0.4845092160900788, 0.9447117862195582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.5329135356615727, 0.6316822415880835, 0.9563720521353332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 220}], {
             RGBColor[
             0.7015961483529711, 0.2829941123972781, 0.42662237057810526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 316}], {
             RGBColor[
             0.36353682849431057`, 0.4840506505877087, 0.9446869403093285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 325}], {
             RGBColor[
             0.7292419705826745, 0.7850859761317203, 0.8972194017011615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 392}], {
             RGBColor[
             0.4671827492812367, 0.5783190280663453, 0.951197483851669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 413}], {
             RGBColor[
             0.36087619489253603`, 0.48125415597833, 0.9445354211617623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 474}], {
             RGBColor[
             0.7316382224091607, 0.784216935341135, 0.7223083954185181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 490}], {
             RGBColor[
             0.3613092871175119, 0.4817093633664127, 0.944560085123272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 67}], {
             RGBColor[
             0.7578732202009473, 0.7545461867892426, 0.6200905867126387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 124}], {
             RGBColor[
             0.8912731868195147, 0.8600602899816822, 0.6325275017112661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 318}], {
             RGBColor[
             0.6191160617425963, 0.6350897806819902, 0.6105140370738731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 335}], {
             RGBColor[
             0.6848059341919914, 0.6942145172226881, 0.6146181790454321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 459}], {
             RGBColor[
             0.9295103312405606, 0.7582389831981371, 0.2621405617922154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 29}], {
             RGBColor[
             0.6109052036871411, 0.6923028245308613, 0.9641564145824804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 65}], {
             RGBColor[
             0.7030768651489114, 0.7646212740059528, 0.9416077572893973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 86}], {
             RGBColor[
             0.6205128470383916, 0.6998083885376523, 0.9651140146832011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 177}], {
             RGBColor[
             0.3607728753041977, 0.48482284692644745`, 0.9442853466720524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[
             0.7103410428640462, 0.7568786253905891, 0.6732956639408428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 290}], {
             RGBColor[
             0.3730027867973105, 0.49749799908382, 0.944988385634679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 297}], {
             RGBColor[
             0.5098213871049575, 0.6124463267589032, 0.9546891741303689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 350}], {
             RGBColor[
             0.699903822364023, 0.34947377037050437`, 0.4352954977548128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 412}], {
             RGBColor[
             0.49157526277125185`, 0.5976333010462669, 0.9532527723850639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 484}], {
             RGBColor[
             0.7151866680671959, 0.7718484023018759, 0.8403068584741521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 490}], {
             RGBColor[
             0.3438944246913231, 0.4670825251767381, 0.9433241438790794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 125}], {
             RGBColor[
             0.7555632414852436, 0.8083458513388335, 0.9623708094021266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 149}], {
             RGBColor[
             0.9453970528108677, 0.958797791907241, 0.9773127262484711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 201}], {
             RGBColor[
             0.9652824108267699, 0.9736282593562156, 0.94365200205955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 218}], {
             RGBColor[
             0.944315343563324, 0.9579910549215594, 0.9791437778496066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 282}], {
             RGBColor[
             0.968900913114835, 0.9760435075887338, 0.9248344777257933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 305}], {
             RGBColor[
             0.9522086110214995, 0.906544464726819, 0.6234738837359686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 310}], {
             RGBColor[
             0.9462326814451365, 0.9594210023744625, 0.975898224937507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 406}], {
             RGBColor[
             0.6229610498833924, 0.6950063758527747, 0.9531768472695097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 408}], {
             RGBColor[
             0.6349196882191848, 0.7067260283376922, 0.9538889833172626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 419}], {
             RGBColor[
             0.969831726897647, 0.9764284230087497, 0.9094084844757475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 432}], {
             RGBColor[
             0.8621806162332036, 0.41063484987572185`, 0.4315781393509973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 493}], {
             RGBColor[
             0.8841060041436435, 0.910037977579818, 0.9743120223166866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 46}], {
             RGBColor[
             0.8398465432473405, 0.7205371961100986, 0.6059761186521231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 65}], {
             RGBColor[
             0.8786613486295168, 0.905449437724329, 0.9568049426259474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 86}], {
             RGBColor[
             0.796097330518997, 0.8406365522560284, 0.9803112000197514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 177}], {
             RGBColor[
             0.5363573587848032, 0.6256510106448236, 0.9594825320086027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 194}], {
             RGBColor[
             0.8859255263446517, 0.8977067891089654, 0.688492849277393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 254}], {
             RGBColor[
             0.845795623257289, 0.747298662314899, 0.6109271454490187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 290}], {
             RGBColor[
             0.548587270277916, 0.6383261628021962, 0.9601855709712293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 297}], {
             RGBColor[
             0.685405870585563, 0.7532744904772795, 0.9698863594669191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 350}], {
             RGBColor[
             0.8169601446844267, 0.4433592128494219, 0.44542695464584625`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 377}], {
             RGBColor[
             0.8846292414565897, 0.8933341157993666, 0.683457027270133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 412}], {
             RGBColor[
             0.6671597462518573, 0.7384614647646432, 0.9684499577216141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 426}], {
             RGBColor[
             0.5771973199190499, 0.6631067498184402, 0.9620085780354888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 476}], {
             RGBColor[
             0.8907791423945299, 0.9124957710697585, 0.8419895339829094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 31}], {
             RGBColor[
             0.788070328802821, 0.833586375971408, 0.9328226294544968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 133}], {
             RGBColor[
             0.9709324163190295, 0.9276831879771833, 0.5965445739332167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 191}], {
             RGBColor[
             0.7103265701045525, 0.7700013444425595, 0.9268319823953137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 311}], {
             RGBColor[
             0.8802736466780672, 0.9063949864897691, 0.9414802082109391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 366}], {
             RGBColor[
             0.7349422558756886, 0.7904546129767513, 0.9286401929391294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 405}], {
             RGBColor[
             0.9206167046862583, 0.9382074050592253, 0.9454226473803349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 423}], {
             RGBColor[
             0.9531546499855035, 0.9641522794218467, 0.9485261456499435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 429}], {
             RGBColor[
             0.8712486684527926, 0.8993446049078098, 0.9405806827246603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 465}], {
             RGBColor[
             0.9872457345715964, 0.9889937977227539, 0.8610347153369078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 469}], {
             RGBColor[
             0.7796505771252993, 0.8267508422541052, 0.9321597957598757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 488}], {
             RGBColor[
             0.6265528918653088, 0.6937190709055506, 0.9216302682442526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 133}], {
             RGBColor[
             0.7743893216054644, 0.7733642944944752, 0.6247082816633323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 191}], {
             RGBColor[
             0.5137834753909873, 0.6156824509598513, 0.9549956901254293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 226}], {
             RGBColor[
             0.714879572172018, 0.7765574353997664, 0.9727094195774075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 237}], {
             RGBColor[
             0.7927507873207464, 0.8343937655772928, 0.773254338117138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 311}], {
             RGBColor[
             0.683730551964502, 0.752076093007061, 0.9696439159410546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 366}], {
             RGBColor[
             0.5383991611621235, 0.6361357194940431, 0.9568039006692448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 405}], {
             RGBColor[
             0.7240736099726932, 0.7838885115765171, 0.9735863551104504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 429}], {
             RGBColor[
             0.6747055737392275, 0.7450257114251015, 0.9687443904547759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 472}], {
             RGBColor[
             0.733101647383009, 0.7910872235479556, 0.9744474573780704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 488}], {
             RGBColor[
             0.4300097971517437, 0.5394001774228425, 0.9497939759743681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 66}], {
             RGBColor[
             0.7142197872930924, 0.727760008999047, 0.6247920039915218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 84}], {
             RGBColor[
             0.7010977080443948, 0.2825894561002958, 0.4265831315311671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 89}], {
             RGBColor[
             0.7175934697996625, 0.7770372157957167, 0.9464252402477575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 176}], {
             RGBColor[
             0.7067045459119439, 0.7689162741892326, 0.9648573481034742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 179}], {
             RGBColor[
             0.3530264837706949, 0.47318246599425245`, 0.9440721113128687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 245}], {
             RGBColor[
             0.7173393453538887, 0.7768476902001491, 0.9468554066481822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 255}], {
             RGBColor[
             0.6963184208441595, 0.7608681626682555, 0.9719623948668842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 260}], {
             RGBColor[
             0.494685443032888, 0.6006469538361698, 0.9533625966494859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 299}], {
             RGBColor[
             0.7048783061822942, 0.6918542132218126, 0.6113902366899864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 312}], {
             RGBColor[
             0.5085276644774921, 0.6118846927898691, 0.954452307027333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 328}], {
             RGBColor[
             0.7291652093530147, 0.7781744269591429, 0.6828521464881836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 334}], {
             RGBColor[
             0.653762253662666, 0.7269350301141178, 0.9679033496507744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 407}], {
             RGBColor[
             0.46918136236923424`, 0.5799415922076752, 0.9513548219951171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 448}], {
             RGBColor[
             0.6930424123639645, 0.7582559624310292, 0.9716499262535159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 475}], {
             RGBColor[
             0.5332091693504963, 0.6319222503348976, 0.9563953255022672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 478}], {
             RGBColor[
             0.6518595869498323, 0.7254178953238162, 0.9677218716011737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 482}], {
             RGBColor[
             0.6904737077228993, 0.7562077470758738, 0.9714049209117415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 76}], {
             RGBColor[
             0.9454300289952701, 0.8062997776107577, 0.44622216731090525`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 111}], {
             RGBColor[
             0.8705927925939535, 0.8964310247645306, 0.8163482344381638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 160}], {
             RGBColor[
             0.9901391290494366, 0.9896312803091951, 0.7724495270535374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 175}], {
             RGBColor[
             0.7207775092015738, 0.7762266325567049, 0.8035109580738835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 182}], {
             RGBColor[
             0.9809251528499161, 0.9460030104953818, 0.492232723587419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 237}], {
             RGBColor[
             0.9943041763763425, 0.9902255341421301, 0.6214229329927775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 241}], {
             RGBColor[
             0.6468021012428073, 0.7112490118929747, 0.7988304045173231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 274}], {
             RGBColor[
             0.876424004066816, 0.41972833987279146`, 0.3285865089786305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 351}], {
             RGBColor[
             0.6117587481629536, 0.6744162259291338, 0.7968347374014205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 371}], {
             RGBColor[
             0.6514197303028223, 0.7161024328096426, 0.7990933716611209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 432}], {
             RGBColor[
             0.876424004066816, 0.41972833987279146`, 0.3285865089786305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 460}], {
             RGBColor[
             0.9907225143067242, 0.9898725251054008, 0.76278132358763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 463}], {
             RGBColor[
             0.7271562163568163, 0.7815788477623282, 0.8039651212688388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 44}], {
             RGBColor[
             0.6283077003865569, 0.7018177662337881, 0.965416260834189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 62}], {
             RGBColor[
             0.43335853793121903`, 0.5471934123641431, 0.9495475334503426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 190}], {
             RGBColor[
             0.6129572634454068, 0.5607471673454519, 0.5930064781280167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 291}], {
             RGBColor[
             0.5173818849929921, 0.6142724185972134, 0.9569381184078065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 356}], {
             RGBColor[
             0.3121037533226303, 0.4444863192146672, 0.9411176193306685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 394}], {
             RGBColor[
             0.5932966252105814, 0.47244371784858397`, 0.5766513841821403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 467}], {
             RGBColor[
             0.6441320673019257, 0.6802095060546922, 0.63962753533801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.946690024115735, 0.8198880998997395, 0.5187297117838234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 123}], {
             RGBColor[
             0.9480645730876001, 0.8192140496842684, 0.405636040260667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 193}], {
             RGBColor[
             0.6707086698229778, 0.6019828166791383, 0.5946902381082673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 347}], {
             RGBColor[
             0.5707097654065635, 0.508932516717262, 0.5885540599027723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 410}], {
             RGBColor[
             0.8237002363753895, 0.724999439072365, 0.6077040468227106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 422}], {
             RGBColor[
             0.8638914330120806, 0.7564416547221966, 0.6116981081923236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 428}], {
             RGBColor[
             0.9004905177407423, 0.7856247714291418, 0.6151889615661319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 437}], {
             RGBColor[
             0.6753248009478091, 0.6059810774459706, 0.5949843739016569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 75}], {
             RGBColor[
             0.9941614846453388, 0.9899203309578604, 0.6058918186643216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 76}], {
             RGBColor[
             0.9447022432963998, 0.804743117591296, 0.3670071853615905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 104}], {
             RGBColor[
             0.9386139836549193, 0.7770977525084987, 0.36192699227983915`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 112}], {
             RGBColor[
             0.9732256148321642, 0.9762446012690047, 0.7314373612363735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 266}], {
             RGBColor[
             0.6366346333579539, 0.6997706473856256, 0.7190778466322749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 359}], {
             RGBColor[
             0.6250508263662076, 0.6875953317815169, 0.7184181659608018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 379}], {
             RGBColor[
             0.7677777734055307, 0.8135914469520185, 0.7280053110482472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 408}], {
             RGBColor[
             0.6555569842707331, 0.7188096033138347, 0.7201865558093976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 440}], {
             RGBColor[
             0.8483501862691578, 0.8780668233534028, 0.7349888562362867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 463}], {
             RGBColor[
             0.7264284306579462, 0.7800221877428664, 0.7247501393195239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 49}], {
             RGBColor[
             0.6288727104349323, 0.6977592885001335, 0.9336782862741432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 53}], {
             RGBColor[
             0.6998929733685393, 0.7616382666853443, 0.9381170478611959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 97}], {
             RGBColor[
             0.6480990259368336, 0.7167769526594913, 0.934816783330437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 100}], {
             RGBColor[
             0.9759979009073974, 0.9816198543133429, 0.9255134724004572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 203}], {
             RGBColor[
             0.9792597199861195, 0.9840525136415152, 0.9199920635188459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 207}], {
             RGBColor[
             0.7310353549147943, 0.7876842740544217, 0.940357810508581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 257}], {
             RGBColor[
             0.9699957325006392, 0.937778948284482, 0.6240312042153622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 264}], {
             RGBColor[
             0.6219077878644166, 0.6904387132769247, 0.9332816442374319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 281}], {
             RGBColor[
             0.7878697685472501, 0.8338250114024056, 0.9448320237410449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 317}], {
             RGBColor[
             0.6288727104349323, 0.6977592885001335, 0.9336782862741432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 322}], {
             RGBColor[
             0.9758012436714265, 0.957362300662394, 0.6465845188350784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 324}], {
             RGBColor[
             0.7159925467614783, 0.775471844724775, 0.9391735855471302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 343}], {
             RGBColor[
             0.8657110513613833, 0.8952662861249998, 0.9521590473058859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 374}], {
             RGBColor[
             0.8697382398243138, 0.4162713131754989, 0.41878505395516974`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 397}], {
             RGBColor[
             0.8697382398243138, 0.4162713131754989, 0.41878505395516974`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 445}], {
             RGBColor[
             0.9835105774112951, 0.9858517668107456, 0.8513989757518731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 77}], {
             RGBColor[
             0.8942986804461579, 0.9164027655477367, 0.899860735693927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 79}], {
             RGBColor[
             0.9549110488708272, 0.8553822400347315, 0.5368328756948025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 87}], {
             RGBColor[
             0.9922114183846376, 0.990501208298636, 0.7390500637284685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 127}], {
             RGBColor[
             0.6556975536814259, 0.7215165865921992, 0.8804264742511925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 184}], {
             RGBColor[
             0.8758819689836447, 0.4277173876878553, 0.38355718405064415`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 221}], {
             RGBColor[
             0.9080709469259247, 0.9272133652511436, 0.9012197333329461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 253}], {
             RGBColor[
             0.9508164599939234, 0.839148559578666, 0.5335382733720919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 287}], {
             RGBColor[
             0.8951621107571266, 0.9170772838689789, 0.8999467943581093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 301}], {
             RGBColor[
             0.8941140734147632, 0.9162585491317458, 0.8998423357902883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 316}], {
             RGBColor[
             0.6233484934459169, 0.6887060856877478, 0.8785406562956808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 336}], {
             RGBColor[
             0.8510610232111201, 0.8826251790973592, 0.8955512100996181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 354}], {
             RGBColor[
             0.9350679760901164, 0.9487400634918353, 0.9037947340751591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 388}], {
             RGBColor[
             0.9919225421157429, 0.9909277778307302, 0.7835279111404516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 436}], {
             RGBColor[
             0.8140851579854758, 0.8536786523380668, 0.8919073022101347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 473}], {
             RGBColor[
             0.8748039249873754, 0.41943106913063755`, 0.3825248479023401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 62}], {
             RGBColor[
             0.7708977692215109, 0.8162683143329381, 0.7400461136432022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 96}], {
             RGBColor[
             0.9932766099239447, 0.9880276734033564, 0.5095786660543439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 108}], {
             RGBColor[
             0.9936409166781283, 0.9900107680823705, 0.6367405293273175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 113}], {
             RGBColor[
             0.9488708813294844, 0.9574234611722959, 0.7566197858090447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 157}], {
             RGBColor[
             0.968574351486732, 0.972926773431054, 0.7512980307139298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 190}], {
             RGBColor[
             0.9504964947356987, 0.8298220693142468, 0.3835050583208763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 378}], {
             RGBColor[
             0.9687313286125414, 0.9730438467144562, 0.7510323093861261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 161}], {
             RGBColor[
             0.5585750858079831, 0.6477657639531755, 0.9604881885798682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 183}], {
             RGBColor[
             0.3307979233417341, 0.46094226763671586`, 0.9422991290555851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 202}], {
             RGBColor[
             0.564260340109862, 0.6522071278233365, 0.9610548415969573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 206}], {
             RGBColor[
             0.5675738763172529, 0.6547956874923582, 0.9613851039193536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 243}], {
             RGBColor[
             0.6107624437760353, 0.49495539624038204`, 0.579312922923451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 273}], {
             RGBColor[
             0.6573942183548578, 0.7253706485727879, 0.9433289800344534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 283}], {
             RGBColor[
             0.6530788022347551, 0.7221522182962608, 0.9506338538850039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 285}], {
             RGBColor[
             0.6647915511652247, 0.7111481644820892, 0.6608252158183247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 396}], {
             RGBColor[
             0.3068658147021297, 0.43612280504780376`, 0.9409239758306869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 421}], {
             RGBColor[
             0.5871756820659184, 0.6701502923963932, 0.9633278091961737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 430}], {
             RGBColor[
             0.6474153661400555, 0.7179284369298591, 0.9602205739326298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 477}], {
             RGBColor[
             0.3017447193068194, 0.430740209091131, 0.9406323370239056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 44}], {
             RGBColor[
             0.7502334196258647, 0.8044681549682167, 0.9740018846630175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 56}], {
             RGBColor[
             0.559327069276856, 0.6531259380930996, 0.95845142225749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.6612726645658855, 0.7340820794048803, 0.9677130141755275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 132}], {
             RGBColor[
             0.7413404650540569, 0.3776245529654416, 0.4377240972812927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.4421808399627842, 0.5544610106398766, 0.9502129748242125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 356}], {
             RGBColor[
             0.4340294725619381, 0.5471367079490956, 0.949703243159497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 365}], {
             RGBColor[
             0.7429816275456196, 0.7987528075221715, 0.9756343378794794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 457}], {
             RGBColor[
             0.7324527057116492, 0.6533331528195505, 0.5996144438025841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 485}], {
             RGBColor[
             0.624807615258298, 0.7055953057411537, 0.9640785188458074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 494}], {
             RGBColor[
             0.46908681814465164`, 0.5777656166072259, 0.9519273999619389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 108}], {
             RGBColor[
             0.9738008080861629, 0.9229714077571834, 0.5162981754751155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 113}], {
             RGBColor[
             0.9290307727375189, 0.8903841008471088, 0.6361774319568427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 119}], {
             RGBColor[
             0.9458824053849132, 0.9037605173604737, 0.6356830938875628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 315}], {
             RGBColor[
             0.9540159239785978, 0.9098264822102292, 0.621915168469849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 364}], {
             RGBColor[
             0.7740500027657855, 0.76789517314716, 0.6214138011876893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 378}], {
             RGBColor[
             0.9488912200205759, 0.9060044863892691, 0.630589955533924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 380}], {
             RGBColor[
             0.9640926787162019, 0.8898735801600003, 0.3184692182938227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 381}], {
             RGBColor[
             0.6245670408249248, 0.6410186660961203, 0.6108756726026359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 416}], {
             RGBColor[
             0.9714831024210195, 0.922012976902328, 0.5547085563765277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 452}], {
             RGBColor[
             0.9726732403950704, 0.9225051295397488, 0.5349848901681591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 468}], {
             RGBColor[
             0.6053191641834994, 0.620787927360117, 0.6097795345025885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 487}], {
             RGBColor[
             0.6367753523787931, 0.6528250673803876, 0.6116084594412334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[
             0.8268937877946114, 0.5608643648276925, 0.46005214689361806`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 137}], {
             RGBColor[
             0.8431295945346498, 0.3325185398679621, 0.18893425447527779`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 148}], {
             RGBColor[
             0.7324469572796468, 0.48547752536775757`, 0.45173540919323685`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 156}], {
             RGBColor[
             0.9021762858232049, 0.6179951546043798, 0.34695577740496675`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 227}], {
             RGBColor[
             0.8544884809671061, 0.5825908080269435, 0.4627576118437119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 229}], {
             RGBColor[
             0.9017944038434947, 0.6183105214871712, 0.3876873657281227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 250}], {
             RGBColor[
             0.6780877180034214, 0.43897268532178235`, 0.44811187265902697`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 263}], {
             RGBColor[
             0.8458550933039185, 0.575706779051383, 0.46193415162128093`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 267}], {
             RGBColor[
             0.8470968963650475, 0.576696959104481, 0.46205259590582204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 393}], {
             RGBColor[
             0.8431295945346498, 0.3325185398679621, 0.18893425447527779`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 485}], {
             RGBColor[
             0.7998389015337638, 0.5397288820559671, 0.45735556867342353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 56}], {
             RGBColor[
             0.747392179383467, 0.802161508143024, 0.97377821182333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 62}], {
             RGBColor[
             0.7433493672771379, 0.798879371148496, 0.9734599468450111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 92}], {
             RGBColor[
             0.8493377746724965, 0.8831176494548049, 0.9830398037413675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 110}], {
             RGBColor[
             0.9397153497174934, 0.9545603870431376, 0.9869303675600567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 132}], {
             RGBColor[
             0.866717205125131, 0.4769815996653913, 0.4479419569918527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 157}], {
             RGBColor[
             0.941025949542359, 0.955537830246612, 0.9847118639157386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 356}], {
             RGBColor[
             0.6220945826685491, 0.6961722779990202, 0.9650300327253369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 360}], {
             RGBColor[
             0.9449262586765936, 0.9584466744127542, 0.9781096579150212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 365}], {
             RGBColor[
             0.9310467376522307, 0.947788377572096, 0.9909611274453194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 457}], {
             RGBColor[
             0.9205178158182603, 0.8023687228694749, 0.6149412333684241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 494}], {
             RGBColor[
             0.6571519282512627, 0.7268011866571504, 0.9672541895277789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 118}], {
             RGBColor[
             0.6247466465143312, 0.7048872469894403, 0.9645239813110726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 152}], {
             RGBColor[
             0.8423557994508031, 0.8773804368376656, 0.9680265654358144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 185}], {
             RGBColor[
             0.8611001952114972, 0.8901021845499899, 0.8799706991756773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 187}], {
             RGBColor[
             0.7109258870328801, 0.7740999732777285, 0.9718221065054475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 195}], {
             RGBColor[
             0.5745022062631837, 0.6631529720985891, 0.9608292674540885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 216}], {
             RGBColor[
             0.5589768120219564, 0.6497056559358416, 0.9598400030616046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 217}], {
             RGBColor[
             0.5683683661309606, 0.6578401480718267, 0.9604384245848051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 224}], {
             RGBColor[
             0.5545640015941451, 0.6458835013375726, 0.9595588226832394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 292}], {
             RGBColor[
             0.7751629783566336, 0.824282477239821, 0.9782246594388506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 328}], {
             RGBColor[
             0.8600564213910482, 0.8830885584501127, 0.6940788724637669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 398}], {
             RGBColor[
             0.7688345523720306, 0.8193386627628301, 0.9775939010792086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 399}], {
             RGBColor[
             0.8616202750873626, 0.8881786525760622, 0.7158981045444953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 464}], {
             RGBColor[
             0.6110418691660456, 0.6937610913449183, 0.9634450910359621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 481}], {
             RGBColor[
             0.6453740051275656, 0.7216334659635797, 0.9661478425416108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 496}], {
             RGBColor[
             0.5230025413965683, 0.6185465508395456, 0.9575477543481533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 86}], {
             RGBColor[
             0.8494541865985911, 0.7280427601168895, 0.6069337187528439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 142}], {
             RGBColor[
             0.8426137997756449, 0.29206580132365323`, 0.18701154579507184`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 150}], {
             RGBColor[
             0.8426137997756449, 0.29206580132365323`, 0.18701154579507184`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 194}], {
             RGBColor[
             0.9392823824242458, 0.7851129969698264, 0.31511536801048556`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 220}], {
             RGBColor[
             0.8426137997756449, 0.29206580132365323`, 0.18701154579507184`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 254}], {
             RGBColor[
             0.899152479336883, 0.63470487017576, 0.2375496641821112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 297}], {
             RGBColor[
             0.7387627266651571, 0.6406806983381405, 0.5965088782000116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 325}], {
             RGBColor[
             0.9407684477166851, 0.7986935095212829, 0.5378031645266115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 350}], {
             RGBColor[
             0.8525313820708227, 0.36829668475666255`, 0.19650863380124123`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 377}], {
             RGBColor[
             0.9379860975361838, 0.7807403236602277, 0.3100795460032256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 392}], {
             RGBColor[
             0.6787092264152474, 0.5919265614559079, 0.5917812466771191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 412}], {
             RGBColor[
             0.7205166023314513, 0.6258676726255041, 0.5950724764547066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 426}], {
             RGBColor[
             0.6305541759986439, 0.5505129576793012, 0.5886310967685813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 476}], {
             RGBColor[
             0.944135998474124, 0.7999019789306197, 0.4686120527160019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 55}], {
             RGBColor[
             0.7467031357797586, 0.7977063620376514, 0.8266859940739327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 59}], {
             RGBColor[
             0.9946360298549641, 0.9909353351773686, 0.6575431361784839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 73}], {
             RGBColor[
             0.9874992127227371, 0.9679384704667517, 0.5382125347285582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 91}], {
             RGBColor[
             0.6237630229771394, 0.6872453364687897, 0.8187046715204619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 136}], {
             RGBColor[
             0.9285234009104036, 0.9422910553586956, 0.8432100350834624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 200}], {
             RGBColor[
             0.9561940880197455, 0.9643549101588924, 0.8458492899218654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 228}], {
             RGBColor[
             0.9644478511991786, 0.8836482095314149, 0.4826842701306006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 256}], {
             RGBColor[
             0.9947284639492403, 0.9911330423585047, 0.667604016903334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 298}], {
             RGBColor[
             0.8017902916581193, 0.8424285968277965, 0.8310226567755782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 416}], {
             RGBColor[
             0.9921373008863925, 0.9907935931496216, 0.7637595689688017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 452}], {
             RGBColor[
             0.9933274388604434, 0.9912857457870423, 0.7440359027604332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 468}], {
             RGBColor[
             0.6259733626488723, 0.6895685436074106, 0.8188305470948625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 117}], {
             RGBColor[
             0.5538255050038091, 0.648204406646119, 0.9582587195921792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 140}], {
             RGBColor[
             0.7651226679349727, 0.33438018926573415`, 0.4317516833241609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 155}], {
             RGBColor[
             0.7190452505262104, 0.7804428817481661, 0.9726313687786968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 156}], {
             RGBColor[
             0.8275945388352918, 0.8627217060032277, 0.8025508093807748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 198}], {
             RGBColor[
             0.8214020810291682, 0.8605190424451246, 0.941023501813927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 250}], {
             RGBColor[
             0.4914616871056165, 0.5941880020793316, 0.9542849522618653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 365}], {
             RGBColor[
             0.7922624746884519, 0.8384797989616266, 0.9797063153171319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 479}], {
             RGBColor[
             0.7942462264847912, 0.552785513246611, 0.4594269841218631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 51}], {
             RGBColor[
             0.2897765796938736, 0.4219039365275473, 0.9398137195763085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 100}], {
             RGBColor[
             0.6302938918693883, 0.6988192032869798, 0.9312725968090914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 203}], {
             RGBColor[
             0.6335557109481105, 0.7012518626151522, 0.9257511879274799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 264}], {
             RGBColor[
             0.2762037788264076, 0.40763806225056165`, 0.9390407686460659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 324}], {
             RGBColor[
             0.37028853772346926`, 0.4926711936984119, 0.9449327099557641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 360}], {
             RGBColor[
             0.6173613445088175, 0.6891741306405688, 0.9531640261419811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 397}], {
             RGBColor[
             0.6392689004656411, 0.22773754582459013`, 0.4226244702275924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 457}], {
             RGBColor[
             0.592952901650484, 0.5330961790972895, 0.589995601595384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 82}], {
             RGBColor[
             0.27528188303122514`, 0.4066690913182555, 0.9389882680443529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 126}], {
             RGBColor[
             0.6074936040536676, 0.6815755319744177, 0.9664192287197332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 131}], {
             RGBColor[
             0.635147229977618, 0.7016016273730713, 0.8921064613688443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 173}], {
             RGBColor[
             0.269149647045529, 0.40022372249107097`, 0.9386390462767977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 242}], {
             RGBColor[
             0.4025029997654348, 0.5186930986114536, 0.9474806972966326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 323}], {
             RGBColor[
             0.6389031352827396, 0.2273531034265086, 0.4226036404415273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 340}], {
             RGBColor[
             0.584296063245159, 0.6630784426141837, 0.9642066265687285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 373}], {
             RGBColor[
             0.5693803197935527, 0.6511850336629431, 0.962783949642873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 414}], {
             RGBColor[
             0.6116724365864046, 0.6847638694414264, 0.9618339010989898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 449}], {
             RGBColor[
             0.2666858680060453, 0.39763413450796004`, 0.9384987377053335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 499}], {
             RGBColor[
             0.27703645022768275`, 0.40851325268771793`, 0.9390881880505416]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 60}], {
             RGBColor[
             0.2897765796938736, 0.4219039365275473, 0.9398137195763085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 96}], {
             RGBColor[
             0.6447711721087457, 0.7083114855005059, 0.718423176376644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 100}], {
             RGBColor[
             0.6369017701663386, 0.7057645023407568, 0.9316489057026227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 110}], {
             RGBColor[
             0.6187583138466675, 0.6922331423247292, 0.962361044680548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 203}], {
             RGBColor[
             0.6401635892450608, 0.7081971616689291, 0.9261274968210114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 240}], {
             RGBColor[
             0.5365186627526481, 0.6271478127774129, 0.9592815930680691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 264}], {
             RGBColor[
             0.2828116571233579, 0.41458336130433865`, 0.9394170775395974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 324}], {
             RGBColor[
             0.37689641602041957`, 0.4996164927521889, 0.9453090188492955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 360}], {
             RGBColor[
             0.6239692228057677, 0.6961194296943458, 0.9535403350355125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 397}], {
             RGBColor[
             0.643674152663608, 0.2323677451937748, 0.42287534282328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 457}], {
             RGBColor[
             0.5995607799474343, 0.5400414781510665, 0.5903719104889154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 495}], {
             RGBColor[
             0.46023163661648175`, 0.5672717790409774, 0.9518694726815891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 170}], {
             RGBColor[
             0.8265059247405572, 0.8650471832850786, 0.9689164909935963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 214}], {
             RGBColor[
             0.7851455782621213, 0.8324755025895827, 0.9791149322740729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 268}], {
             RGBColor[
             0.7304832967288653, 0.7893783703740509, 0.9737714063295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 466}], {
             RGBColor[
             0.7861999921267331, 0.6367147785745768, 0.5924377514111365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 491}], {
             RGBColor[
             0.845032393604636, 0.8781366384233458, 0.9049746120216013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 83}], {
             RGBColor[
             0.48933308130866227`, 0.5955384463857689, 0.9531521188344462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 97}], {
             RGBColor[
             0.3734152798324315, 0.497855279818339, 0.9450146693261237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 112}], {
             RGBColor[
             0.6892410080628791, 0.7536940484013754, 0.9561480466461838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 163}], {
             RGBColor[
             0.35181420684738857`, 0.47634159497587836`, 0.9437409333443039]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 207}], {
             RGBColor[
             0.4563516088103924, 0.5687626012132694, 0.9505556965042679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 257}], {
             RGBColor[
             0.6953119863962371, 0.7188572754433298, 0.634229090211049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 266}], {
             RGBColor[
             0.35265002658866884`, 0.4772200945179963, 0.9437885320420852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 281}], {
             RGBColor[
             0.5131860224428482, 0.6149033385612535, 0.9550299097367316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[
             0.6815393086641066, 0.7479501336001462, 0.9691850148033949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 317}], {
             RGBColor[
             0.3541889643305304, 0.47883761565898125`, 0.9438761722698299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 322}], {
             RGBColor[
             0.7011174975670245, 0.7384406278212419, 0.6567824048307651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 343}], {
             RGBColor[
             0.5910273052569812, 0.6763446132838475, 0.9623569333015727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 374}], {
             RGBColor[
             0.6866157424213791, 0.2703235312813974, 0.4255836446189609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 440}], {
             RGBColor[
             0.5643655794998728, 0.6555162704857735, 0.959699541646097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 445}], {
             RGBColor[
             0.7088268313068931, 0.7669300939695933, 0.8615968617475598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 471}], {
             RGBColor[
             0.6902960117925535, 0.7544808684555564, 0.9543622005208864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 61}], {
             RGBColor[
             0.9722745587992094, 0.9752637852133703, 0.71150329850145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 99}], {
             RGBColor[
             0.9064168763246028, 0.9231648383043334, 0.7195816643817028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 154}], {
             RGBColor[
             0.9937885553030565, 0.9895484288270704, 0.5962487296029566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 186}], {
             RGBColor[
             0.9935616546349683, 0.9886373552177947, 0.5406040237572124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 203}], {
             RGBColor[
             0.9883656772544341, 0.9872645150104886, 0.6842652321925893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 244}], {
             RGBColor[
             0.9406823562143651, 0.9504872018567563, 0.7228499364427434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 264}], {
             RGBColor[
             0.6310137451327313, 0.6936507146458982, 0.6975548129111753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 295}], {
             RGBColor[
             0.6603958710038822, 0.7227527406610441, 0.6992932725531245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 321}], {
             RGBColor[
             0.9488123669349611, 0.9569698517220974, 0.72362538412302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 341}], {
             RGBColor[
             0.7058287576401587, 0.7621044235421081, 0.7021882159148638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 374}], {
             RGBColor[
             0.8758088780031903, 0.4184126474214812, 0.2616338330709987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 391}], {
             RGBColor[
             0.7176256094489465, 0.772322263651868, 0.7029399008805733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 397}], {
             RGBColor[
             0.8758088780031903, 0.4184126474214812, 0.2616338330709987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 455}], {
             RGBColor[
             0.6226283815928406, 0.6848371659027173, 0.6970772788626123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 57}], {
             RGBColor[
             0.3386548790957402, 0.4545213004220324, 0.943577331421241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 60}], {
             RGBColor[
             0.3907757297942019, 0.5093036191589176, 0.9465455367626295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 73}], {
             RGBColor[
             0.7391788351344589, 0.7738807092731652, 0.6651802034971074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 91}], {
             RGBColor[
             0.3754426453888612, 0.4931875752752032, 0.945672340289011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 136}], {
             RGBColor[
             0.6802030233221255, 0.7482332941651091, 0.9701777038520114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 200}], {
             RGBColor[
             0.7078737104314674, 0.7702971489653058, 0.9728169586904145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 256}], {
             RGBColor[
             0.7464080863609621, 0.7970752811649181, 0.7945716856718832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 298}], {
             RGBColor[
             0.5534699140698411, 0.6483708356342098, 0.9579903255441273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 434}], {
             RGBColor[
             0.7256207199517821, 0.7840056316842685, 0.9591678988328456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 92}], {
             RGBColor[
             0.6584314243234879, 0.7317754325796877, 0.9674893413358401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 110}], {
             RGBColor[
             0.7488089993684848, 0.8032181701680204, 0.9713799051545292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 132}], {
             RGBColor[
             0.7394463048924586, 0.3760867884153132, 0.43757498205483436`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 324}], {
             RGBColor[
             0.5069471015422369, 0.6106015205954802, 0.9543278793232768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 342}], {
             RGBColor[
             0.4198272652156909, 0.5328889643708387, 0.9488325800502899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 360}], {
             RGBColor[
             0.7540199083275849, 0.807104457537637, 0.9625591955094939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 457}], {
             RGBColor[
             0.7296114654692516, 0.6510265059943579, 0.5993907709628967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 494}], {
             RGBColor[
             0.466245577902254, 0.5754589697820333, 0.9517037271222514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 60}], {
             RGBColor[
             0.23104785069846168`, 0.36017631873688516`, 0.9364692053413886]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 73}], {
             RGBColor[
             0.5794509560387187, 0.6247534088511328, 0.6551038720758664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 91}], {
             RGBColor[
             0.21571476629312095`, 0.3440602748531707, 0.9355960088677702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 131}], {
             RGBColor[
             0.5835750270535085, 0.6473959722333085, 0.8891695007065534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 136}], {
             RGBColor[
             0.5204751442263853, 0.5991059937430767, 0.9601013724307705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 234}], {
             RGBColor[
             0.5575692710763926, 0.6286706265491684, 0.9631811999138686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 240}], {
             RGBColor[
             0.47778993375723616`, 0.5654201949867508, 0.9559370788331492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 434}], {
             RGBColor[
             0.565892840856042, 0.6348783312622361, 0.9490915674116046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 495}], {
             RGBColor[
             0.40150290762106977`, 0.5055441612503152, 0.9485249584466691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 74}], {
             RGBColor[
             0.7698071432678131, 0.7220882056086569, 0.6113263422377451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 115}], {
             RGBColor[
             0.7277848095961736, 0.6879725820494615, 0.6080181901982333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 144}], {
             RGBColor[
             0.8510809804393757, 0.7860331819384434, 0.6191170781488824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 145}], {
             RGBColor[
             0.9472267612793476, 0.8250341922414357, 0.2943348005978884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 215}], {
             RGBColor[
             0.6666900235053416, 0.6371028858239578, 0.6035595439414653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 375}], {
             RGBColor[
             0.8895209631264607, 0.8163231745765331, 0.6228793179406156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 402}], {
             RGBColor[
             0.6806914290814626, 0.6492301996028877, 0.6044517011238189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 417}], {
             RGBColor[
             0.85382680401199, 0.33863852419443574`, 0.19614329712536308`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 87}], {
             RGBColor[
             0.9944488040745203, 0.9905348781644292, 0.6371647654007506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 91}], {
             RGBColor[
             0.6233755394640668, 0.6864165484149203, 0.7765294823935622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 188}], {
             RGBColor[
             0.9565447422999932, 0.853022471255303, 0.4344618324036332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 200}], {
             RGBColor[
             0.955806604506673, 0.9635261221050229, 0.8036741007949657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 228}], {
             RGBColor[
             0.9640603676861061, 0.8828194214775453, 0.44050908100370095`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 256}], {
             RGBColor[
             0.9943409804361678, 0.9903042543046352, 0.6254288277764344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 279}], {
             RGBColor[
             0.7231439443448686, 0.7780310190662025, 0.7826962360583307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 287}], {
             RGBColor[
             0.8973994964470094, 0.9171109537347721, 0.7980614960303913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 298}], {
             RGBColor[
             0.8014028081450468, 0.8415998087739269, 0.7888474676486785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 335}], {
             RGBColor[
             0.7051411419216168, 0.7624378964543412, 0.7815491134071744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 409}], {
             RGBColor[
             0.8900933096011159, 0.5255094078060346, 0.32781409894793784`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 468}], {
             RGBColor[
             0.6255858791357998, 0.688739755553541, 0.7766553579679629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 73}], {
             RGBColor[
             0.6315718067371805, 0.679535727588018, 0.658072077417255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 131}], {
             RGBColor[
             0.6356958777519701, 0.7021782909701936, 0.8921377060479421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.5725959949248469, 0.6538883124799618, 0.9630695777721592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 240}], {
             RGBColor[
             0.5299107844556978, 0.620202513723636, 0.9589052841745377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 434}], {
             RGBColor[
             0.6180136915545036, 0.6896606499991212, 0.9520597727529931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 495}], {
             RGBColor[
             0.4536237583195315, 0.5603264799872003, 0.9514931637880576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 99}], {
             RGBColor[
             0.8859028011142414, 0.9114446812532604, 0.9746194636701568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 154}], {
             RGBColor[
             0.9732744800926952, 0.9778282717759973, 0.8512865288914107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 178}], {
             RGBColor[
             0.9514088350127095, 0.9036043560743804, 0.6230093825212624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 186}], {
             RGBColor[
             0.973047579424607, 0.9769171981667215, 0.7956418230456664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 203}], {
             RGBColor[
             0.9678516020440728, 0.9755443579594156, 0.9393030314810433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 244}], {
             RGBColor[
             0.9201682810040038, 0.9387670448056831, 0.9778877357311975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 264}], {
             RGBColor[
             0.6104996699223699, 0.6819305575948251, 0.9525926121996293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 288}], {
             RGBColor[
             0.7754276425613834, 0.8244774014088013, 0.9640615908023367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 295}], {
             RGBColor[
             0.6398817957935209, 0.711032583609971, 0.9543310718415785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 321}], {
             RGBColor[
             0.9282982917245998, 0.9452496946710243, 0.9786631834114741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 341}], {
             RGBColor[
             0.6853146824297973, 0.750384266491035, 0.9572260152033178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 391}], {
             RGBColor[
             0.6971115342385852, 0.7606021066007949, 0.9579777001690274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 397}], {
             RGBColor[
             0.8621328278629493, 0.41059920938743244`, 0.43165903259663474`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 455}], {
             RGBColor[
             0.6021143063824793, 0.6731170088516442, 0.9521150781510663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 96}], {
             RGBColor[
             0.7707790455242338, 0.8160143763492693, 0.7271237718723064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 108}], {
             RGBColor[
             0.7711433522784172, 0.8179974710282835, 0.85428563514528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 110}], {
             RGBColor[
             0.7447661872621555, 0.7999360331734925, 0.9710616401762102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 157}], {
             RGBColor[
             0.7460767870870211, 0.800913476376967, 0.9688431365318922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 190}], {
             RGBColor[
             0.7279989303359877, 0.6578087722601598, 0.6010501641388388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 356}], {
             RGBColor[
             0.4271454202132112, 0.541547924129375, 0.9491613053414905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 378}], {
             RGBColor[
             0.7462337642128304, 0.8010305496603691, 0.9685774152040886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 72}], {
             RGBColor[
             0.5120616587133314, 0.605773602383513, 0.957203038866674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 159}], {
             RGBColor[
             0.5403442760783499, 0.6329677437394949, 0.9589064260061206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 166}], {
             RGBColor[
             0.5039459358726572, 0.5972434631114162, 0.9567408604570337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 222}], {
             RGBColor[
             0.8681803195482806, 0.895624336880273, 0.8802730603029272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 239}], {
             RGBColor[
             0.6853802222901766, 0.7538961395181709, 0.9694450790776905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 272}], {
             RGBColor[
             0.7930624715919374, 0.3562069762329276, 0.4345364618403772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 344}], {
             RGBColor[
             0.8247002766707638, 0.8636673406669881, 0.9829800444796593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 387}], {
             RGBColor[
             0.8068602657457562, 0.4622628683311291, 0.4477492451044536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 435}], {
             RGBColor[
             0.5765293591716537, 0.6643094439997569, 0.9612121075036134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 439}], {
             RGBColor[
             0.7008167154437076, 0.7662026115997171, 0.9708145187570184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 453}], {
             RGBColor[
             0.8160983400103966, 0.5332707552791112, 0.45659563545318593`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 74}], {
             RGBColor[
             0.7814094901006038, 0.7680876445477844, 0.6206618628414913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 115}], {
             RGBColor[
             0.7393871564289644, 0.733972020988589, 0.6173537108019795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 170}], {
             RGBColor[
             0.9507827164345911, 0.9015117393807053, 0.6228079690150481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 215}], {
             RGBColor[
             0.6782923703381323, 0.6831023247630853, 0.6128950645452114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 223}], {
             RGBColor[
             0.9672990895961489, 0.9137699682888768, 0.592178577794753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 268}], {
             RGBColor[
             0.8547600884228992, 0.8258429264696776, 0.6276628843510104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 86}], {
             RGBColor[
             0.8882689919807674, 0.9129550017311199, 0.9577625427266683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 177}], {
             RGBColor[
             0.6285290202465735, 0.6979694601199151, 0.9369338747155196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 194}], {
             RGBColor[
             0.978097187806422, 0.9700252385840569, 0.6659441919843099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 290}], {
             RGBColor[
             0.6407589317396863, 0.7106446122772876, 0.9376369136781462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 297}], {
             RGBColor[
             0.7775775320473333, 0.8255929399523709, 0.9473377021738361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 350}], {
             RGBColor[
             0.8784079189922736, 0.4915715124994828, 0.43039451645045756`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 412}], {
             RGBColor[
             0.7593314077136277, 0.8107799142397346, 0.945901300428531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 484}], {
             RGBColor[
             0.9829428130095716, 0.9849950154953435, 0.8329553865176191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 114}], {
             RGBColor[
             0.8381156746991734, 0.8272093397210992, 0.6353215013828173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 128}], {
             RGBColor[
             0.9452293541119634, 0.81942960686636, 0.2806738488944785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 179}], {
             RGBColor[
             0.598591146930603, 0.6214281066924122, 0.6175507207108892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 245}], {
             RGBColor[
             0.9629040085137968, 0.9250933308983089, 0.6203340160462028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 255}], {
             RGBColor[
             0.9418830840040677, 0.9091138033664152, 0.6454410042649048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 260}], {
             RGBColor[
             0.7402501061927962, 0.7488925945343295, 0.6268412060475064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 294}], {
             RGBColor[
             0.9644898750309125, 0.9262760675501557, 0.6176495576929568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 299}], {
             RGBColor[
             0.9504429693422023, 0.8400998539199724, 0.2848688460880069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 312}], {
             RGBColor[
             0.7540923276374003, 0.7601303334880289, 0.6279309164253535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 327}], {
             RGBColor[
             0.7717314414725169, 0.7744505607323994, 0.6293195320806568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 334}], {
             RGBColor[
             0.8993269168225742, 0.8751806708122776, 0.641381959048795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 385}], {
             RGBColor[
             0.9730866768694226, 0.9323225628318714, 0.5867526202698192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 415}], {
             RGBColor[
             0.9623455449972722, 0.9246768297220849, 0.6212793491090663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 446}], {
             RGBColor[
             0.6870571084189656, 0.7046495006727167, 0.6229461588097658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 119}], {
             RGBColor[
             0.7501090019258945, 0.8043753644512943, 0.9742124913757338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 120}], {
             RGBColor[
             0.6367010876700154, 0.7148865767829256, 0.9652639490249886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 124}], {
             RGBColor[
             0.6955682761378212, 0.7609466881107319, 0.9711120100958051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 363}], {
             RGBColor[
             0.44637418022264885`, 0.5580930712095616, 0.9504801707575459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 381}], {
             RGBColor[
             0.4287936373659061, 0.541633513186941, 0.949405070090807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 95}], {
             RGBColor[
             0.6365054568722466, 0.6993963981278466, 0.6952221016491802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 286}], {
             RGBColor[
             0.6318654661317296, 0.68389088768092, 0.6647590522742933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 319}], {
             RGBColor[
             0.44629124835095113`, 0.5540270162594039, 0.950947471595957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 330}], {
             RGBColor[
             0.6210654577435442, 0.6914943558314333, 0.9443588183150091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 352}], {
             RGBColor[
             0.5429879445890364, 0.6300274984133489, 0.9602705930861828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 357}], {
             RGBColor[
             0.6332532861238875, 0.7002444926140678, 0.9085233508711507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 367}], {
             RGBColor[
             0.5568654609192059, 0.6409776411874577, 0.961624869792477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 368}], {
             RGBColor[
             0.575563615537859, 0.6558870421324854, 0.9634083164720437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 375}], {
             RGBColor[
             0.5662352147623884, 0.6484488285668188, 0.9625185652785176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 450}], {
             RGBColor[
             0.31475034183809547`, 0.44440994297559744`, 0.9413729879869674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 492}], {
             RGBColor[
             0.6383029717692752, 0.22672229352129283`, 0.42256946201729784`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 101}], {
             RGBColor[
             0.9895778596855156, 0.9896722653435585, 0.8016015616479002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 103}], {
             RGBColor[
             0.9171599917817983, 0.9355294721573071, 0.9484954370647769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 129}], {
             RGBColor[
             0.5990235545451871, 0.6649141348481513, 0.9234571619149028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 204}], {
             RGBColor[
             0.9859365190546943, 0.9884524034612109, 0.882731804593123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 209}], {
             RGBColor[
             0.8729477187093619, 0.41866348013235355`, 0.4132869896368825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 231}], {
             RGBColor[
             0.843215397576624, 0.8775198569034129, 0.9411899580015629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 233}], {
             RGBColor[
             0.9826694677727768, 0.9865933122469923, 0.914122369322601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 259}], {
             RGBColor[
             0.9768794539808003, 0.9483481187958942, 0.6238237366928612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 275}], {
             RGBColor[
             0.9884770276668357, 0.9873176969667923, 0.6817827899623143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 306}], {
             RGBColor[
             0.979329136196549, 0.9566114721223515, 0.6333402895173752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 331}], {
             RGBColor[
             0.9864015378477353, 0.9886447006825712, 0.8750252397623741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 346}], {
             RGBColor[
             0.9147895669837809, 0.933639359766835, 0.9482693438314387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 348}], {
             RGBColor[
             0.8142453016422985, 0.8548881977786338, 0.9383024895797681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 355}], {
             RGBColor[
             0.6336869287625047, 0.7013475389354156, 0.9254311897967124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 372}], {
             RGBColor[
             0.8098104397509007, 0.8513172878203978, 0.937933184370283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 404}], {
             RGBColor[
             0.9306591454739993, 0.7613088556091931, 0.565298747591365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 418}], {
             RGBColor[
             0.8729477187093619, 0.41866348013235355`, 0.4132869896368825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 431}], {
             RGBColor[
             0.9888275226300616, 0.9880673702526558, 0.7199320037052741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 444}], {
             RGBColor[
             0.6997246196587982, 0.7609108636532578, 0.929552466299463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 486}], {
             RGBColor[
             0.9131744451855321, 0.9323515054862248, 0.9481152920724856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 76}], {
             RGBColor[
             0.7696693375503181, 0.6713961382741664, 0.6000919612062638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 111}], {
             RGBColor[
             0.6948321011490015, 0.7615273854279394, 0.9702180283335224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 130}], {
             RGBColor[
             0.7592502097701812, 0.3297925803150639, 0.4311663715755363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 175}], {
             RGBColor[
             0.5450168177566218, 0.6413229932201137, 0.9573807519692421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 182}], {
             RGBColor[
             0.805164461404964, 0.8110993711587906, 0.6461025174827776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 208}], {
             RGBColor[
             0.79233258142943, 0.8385271483406223, 0.9744418046376833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[
             0.7832730394723132, 0.7276349567871978, 0.6111570374677537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 351}], {
             RGBColor[
             0.4359980567180016, 0.5395125865925425, 0.9507045312967791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 359}], {
             RGBColor[
             0.45001792062012574`, 0.5542483524643874, 0.951502941805475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 371}], {
             RGBColor[
             0.4756590388578702, 0.5811987934730514, 0.9529631655564795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 403}], {
             RGBColor[
             0.5830236114965972, 0.6723523139442866, 0.960324793997646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 442}], {
             RGBColor[
             0.8007986095990256, 0.7963723278666077, 0.6291420076386405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 463}], {
             RGBColor[
             0.5513955249118643, 0.646675208425737, 0.9578349151641974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 483}], {
             RGBColor[
             0.5536594323112565, 0.6485131504404297, 0.9580131382476436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 135}], {
             RGBColor[
             0.7595527174654046, 0.8121769464375507, 0.976972274426732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 153}], {
             RGBColor[
             0.4508759918803886, 0.5612013134153189, 0.9509855780891392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 169}], {
             RGBColor[
             0.7457744536846346, 0.6595087203362869, 0.5997229166048286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 172}], {
             RGBColor[
             0.7885918307598385, 0.8215633759956433, 0.6803142874426678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 197}], {
             RGBColor[
             0.4956857965812682, 0.6000133140409507, 0.9538408192209248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 201}], {
             RGBColor[
             0.7849806169995173, 0.8313445923158527, 0.9409870275506276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 211}], {
             RGBColor[
             0.7751186879594764, 0.8239895817852168, 0.9576807010123809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 236}], {
             RGBColor[
             0.685843268829712, 0.7537230865418503, 0.9698568690149132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 289}], {
             RGBColor[
             0.7791743137273395, 0.8270142608424114, 0.9508155844639964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 308}], {
             RGBColor[
             0.41521621107093876`, 0.5238783285434164, 0.9489490319470271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 362}], {
             RGBColor[
             0.5277576572743329, 0.6274964672436478, 0.9559661625020849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 369}], {
             RGBColor[
             0.6539686990087742, 0.7288224303420308, 0.9666799097799526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 466}], {
             RGBColor[
             0.7311033614925442, 0.5928907172126421, 0.5874809976583711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 470}], {
             RGBColor[
             0.7419794203483685, 0.31577907184881315`, 0.4298014896783824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 493}], {
             RGBColor[
             0.7038042103163908, 0.7677543105394551, 0.9716470478077642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 128}], {
             RGBColor[
             0.6051240802108884, 0.5870169200518782, 0.6011548883058155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 159}], {
             RGBColor[
             0.30785652001586894`, 0.4383744174242251, 0.9409360793516632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 179}], {
             RGBColor[
             0.258485873029528, 0.38901541987793037`, 0.9380317601222263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 222}], {
             RGBColor[
             0.6356925634857997, 0.7010310105650032, 0.8623027136484697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 245}], {
             RGBColor[
             0.6227987346127217, 0.692680644083827, 0.9408150554575399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 294}], {
             RGBColor[
             0.6243846011298375, 0.6938633807356738, 0.9381305971042939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 344}], {
             RGBColor[
             0.5922125206082829, 0.6690740143517184, 0.9650096978252016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 438}], {
             RGBColor[
             0.35125966763092575`, 0.4759680423827581, 0.9437016895377981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 439}], {
             RGBColor[
             0.46832895938122665`, 0.5716092852844473, 0.9528441721025609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 453}], {
             RGBColor[
             0.6611065026354093, 0.40354187106893136`, 0.4446154043502142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 91}], {
             RGBColor[
             0.6162387223318397, 0.6634196837043035, 0.6571988809436365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 136}], {
             RGBColor[
             0.920999100265104, 0.9184654025942094, 0.681704244506637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 200}], {
             RGBColor[
             0.9486697873744458, 0.9405292573944061, 0.68434349934504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 240}], {
             RGBColor[
             0.8783138897959549, 0.8847796038378835, 0.6775399509090155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 256}], {
             RGBColor[
             0.9872041633039407, 0.9673073895940184, 0.5060982263265087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 298}], {
             RGBColor[
             0.7942659910128197, 0.8186029440633101, 0.6695168661987528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 434}], {
             RGBColor[
             0.9664167968947606, 0.9542377401133688, 0.670694439487471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 115}], {
             RGBColor[
             0.5707495408280169, 0.6623992150748113, 0.9593506410598893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 144}], {
             RGBColor[
             0.6940457116712189, 0.7604598149637931, 0.9704495290105383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 215}], {
             RGBColor[
             0.5096547547371848, 0.6115295188493075, 0.9548919948031211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 268}], {
             RGBColor[
             0.6861224728219517, 0.7542701205558999, 0.9696598146089201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 402}], {
             RGBColor[
             0.5236561603133059, 0.6236568326282375, 0.9557841519854748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 417}], {
             RGBColor[
             0.7491366248332187, 0.32158961287800225`, 0.43036493103313367`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 104}], {
             RGBColor[
             0.9395970274975507, 0.7792003838869084, 0.46892524790689877`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 125}], {
             RGBColor[
             0.7771835813794232, 0.8225320576933859, 0.8356666375213212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 147}], {
             RGBColor[
             0.6086391829442732, 0.6714150439579957, 0.824425819881278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 303}], {
             RGBColor[
             0.9940552938779574, 0.9896931996439651, 0.5943336089683067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 310}], {
             RGBColor[
             0.9678530213393162, 0.9736072087290149, 0.8491940530567016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 323}], {
             RGBColor[
             0.8765941761626568, 0.4200923207787567, 0.3471086914304604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 379}], {
             RGBColor[
             0.768760817248162, 0.8156940783304281, 0.8350035666753067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 400}], {
             RGBColor[
             0.9801908658850391, 0.9828087529898487, 0.8283093004660138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 408}], {
             RGBColor[
             0.6565400281133644, 0.7209122346922445, 0.8271848114364573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 111}], {
             RGBColor[
             0.8213888093887758, 0.7117997827569142, 0.6052468748131776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 130}], {
             RGBColor[
             0.8436213485966975, 0.2966408452010471, 0.18785226922863968`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 175}], {
             RGBColor[
             0.6715735259963962, 0.5915953905490885, 0.5924095984488973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.9317211696447383, 0.7613717684877654, 0.2811313639624327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 351}], {
             RGBColor[
             0.562554764957776, 0.48978498392151726`, 0.5857333777764343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 359}], {
             RGBColor[
             0.5765746288599001, 0.5045207497933621, 0.5865317882851302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 371}], {
             RGBColor[
             0.6022157470976446, 0.5314711908020262, 0.5879920120361347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 460}], {
             RGBColor[
             0.9415185311015466, 0.8052412830977844, 0.5516799639626437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 463}], {
             RGBColor[
             0.6779522331516386, 0.5969476057547117, 0.5928637616438525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 483}], {
             RGBColor[
             0.6802161405510309, 0.5987855477694044, 0.5930419847272986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 87}], {
             RGBColor[
             0.8967363238686694, 0.91686476645446, 0.8197722557153753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 184}], {
             RGBColor[
             0.8122319059729992, 0.37862642645840466`, 0.437371978708582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 253}], {
             RGBColor[
             0.8553413654779551, 0.7655121177344901, 0.6142604653589987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 287}], {
             RGBColor[
             0.7996870162411585, 0.843440842024803, 0.980668986345016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 301}], {
             RGBColor[
             0.7986389788987951, 0.8426221072875699, 0.980564527777195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 336}], {
             RGBColor[
             0.7555859286951518, 0.8089887372531832, 0.9762734020865248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 354}], {
             RGBColor[
             0.8395928815741481, 0.8751036216476593, 0.9845169260620659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 388}], {
             RGBColor[
             0.8964474475997748, 0.9172913359865542, 0.8642501031273584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 409}], {
             RGBColor[
             0.8249516561305485, 0.4763959999993885, 0.4495524258243543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 436}], {
             RGBColor[
             0.7186100634695075, 0.7800422104938909, 0.9726294941970415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 473}], {
             RGBColor[
             0.8111538619767299, 0.37034010790118693`, 0.4363396425602779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 154}], {
             RGBColor[
             0.9474859313881132, 0.9576793644875163, 0.8631867245207864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 171}], {
             RGBColor[
             0.9151509462667144, 0.9351805397151381, 0.991769108291455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 192}], {
             RGBColor[
             0.912464957016539, 0.8312989518983653, 0.6243244914073597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.6388114444653155, 0.7122933365161837, 0.9678062891503332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 219}], {
             RGBColor[
             0.8528939370521225, 0.8856547147318314, 0.9858001368345781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 258}], {
             RGBColor[
             0.8960653709349553, 0.7627429083792242, 0.6109460264174775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 262}], {
             RGBColor[
             0.8647021458354386, 0.8949540356474462, 0.9869572566701441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 376}], {
             RGBColor[
             0.9472551553899866, 0.9567600019391448, 0.8071202129161448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 497}], {
             RGBColor[
             0.9249284802790488, 0.8807126684112958, 0.6343529347808667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 127}], {
             RGBColor[
             0.6208348275901271, 0.5868596192350183, 0.5981208062389749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 147}], {
             RGBColor[
             0.5710910800900524, 0.535766199128636, 0.59524438657688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 184}], {
             RGBColor[
             0.8526401515894455, 0.33794607611640126`, 0.1953534053758324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 221}], {
             RGBColor[
             0.8732082208346259, 0.7925563978939626, 0.6189140653207285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 234}], {
             RGBColor[
             0.9281299324661569, 0.8363362628879436, 0.623694303755161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 253}], {
             RGBColor[
             0.9159537339026246, 0.7044915922214849, 0.2512326053598743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 301}], {
             RGBColor[
             0.8592513473234644, 0.7816015817745647, 0.6175366677780707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 316}], {
             RGBColor[
             0.5884857673546181, 0.5540491183305668, 0.5962349882834632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 336}], {
             RGBColor[
             0.8161982971198213, 0.7479682117401781, 0.6132455420874003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 388}], {
             RGBColor[
             0.9570598160244441, 0.8562708104735491, 0.501222243128234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 436}], {
             RGBColor[
             0.779222431894177, 0.7190216849808859, 0.609601634197917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 81}], {
             RGBColor[
             0.8127128064863409, 0.7947473273357021, 0.6238599839566942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 171}], {
             RGBColor[
             0.9406331686969243, 0.8955698627394437, 0.6363736647812899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 192}], {
             RGBColor[
             0.9379471794467487, 0.7916882749226708, 0.2689290478971945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 208}], {
             RGBColor[
             0.9463501822942098, 0.8999775076849995, 0.6316855482885415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 219}], {
             RGBColor[
             0.8783761594823322, 0.8460440377561369, 0.6304046933244128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 238}], {
             RGBColor[
             0.9372906403370931, 0.7890853161315752, 0.268400781118612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 251}], {
             RGBColor[
             0.9731493996639116, 0.9180305980253586, 0.4965708043903052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 258}], {
             RGBColor[
             0.921547593365165, 0.7231322314035298, 0.25555058290731225`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 272}], {
             RGBColor[
             0.8619286103467011, 0.3707594865446488, 0.20266220067610835`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 293}], {
             RGBColor[
             0.9445086105520897, 0.8986040664950233, 0.6348028488891162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 403}], {
             RGBColor[
             0.737041212361377, 0.7338026732886639, 0.6175685376485043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 447}], {
             RGBColor[
             0.6036878596414713, 0.6153332971682812, 0.6087268866286693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 471}], {
             RGBColor[
             0.9532653136805365, 0.9051348013504336, 0.6199800346066076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 483}], {
             RGBColor[
             0.7076770331760364, 0.7099635097848069, 0.6152568818985017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 497}], {
             RGBColor[
             0.9504107027092585, 0.8411019914356014, 0.2789574912707015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 121}], {
             RGBColor[
             0.48200190366590784`, 0.5836604978980074, 0.9539901032345404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.7696385939775261, 0.33790806501248594`, 0.43220178862835446`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 208}], {
             RGBColor[
             0.8079151577404473, 0.8507003753867552, 0.9759949302169106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 213}], {
             RGBColor[
             0.746427631578612, 0.8018342059401061, 0.9753605886191006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 251}], {
             RGBColor[
             0.8347143751101491, 0.8687534657271143, 0.8408801863186743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 442}], {
             RGBColor[
             0.8163811859100429, 0.8085455549127408, 0.6306951332178679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 447}], {
             RGBColor[
             0.46525283508770876`, 0.566056164870037, 0.9530362685570384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 454}], {
             RGBColor[
             0.479013545273849, 0.5805195437550881, 0.9538199206449927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 500}], {
             RGBColor[
             0.6347418419635744, 0.7138620929268963, 0.9647226506412933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 126}], {
             RGBColor[
             0.600704081236674, 0.6744393130131474, 0.9660325754395043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 149}], {
             RGBColor[
             0.603691308568178, 0.6767389532721511, 0.9634643246040372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 173}], {
             RGBColor[
             0.2623601242285354, 0.39308750352980065`, 0.9382523929965687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 242}], {
             RGBColor[
             0.3957134769484411, 0.5115568796501833, 0.9470940440164037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 249}], {
             RGBColor[
             0.5280798416739124, 0.6167919193865536, 0.9590362952152981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 269}], {
             RGBColor[
             0.4964000076952176, 0.5920433923067414, 0.9558787454291824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 282}], {
             RGBColor[
             0.6271951688721453, 0.6939846689536437, 0.9109860760813593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 323}], {
             RGBColor[
             0.6343767867380772, 0.22259562411899508`, 0.4223458715880414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 384}], {
             RGBColor[
             0.5744272687161691, 0.6534868959743716, 0.963526269603711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 411}], {
             RGBColor[
             0.49355491667521467`, 0.5898207855784225, 0.9555951733451957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 419}], {
             RGBColor[
             0.6281259826549572, 0.6943695843736595, 0.8955600828313136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 499}], {
             RGBColor[
             0.27024692741068906`, 0.4013770337264476, 0.9387015347703127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 97}], {
             RGBColor[
             0.4375391338769564, 0.5506771323599158, 0.9498518543036873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 163}], {
             RGBColor[
             0.4159380608919135, 0.5291634475174551, 0.9485781183218674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 207}], {
             RGBColor[
             0.5204754628549173, 0.6215844537548461, 0.9553928814818313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 209}], {
             RGBColor[
             0.7293649784510624, 0.30553809964244855`, 0.4288084346040033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 231}], {
             RGBColor[
             0.6278412871891746, 0.7078317861685555, 0.964472125452244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 233}], {
             RGBColor[
             0.7672953573853274, 0.8169052415121347, 0.9374045367732822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 257}], {
             RGBColor[
             0.7594358404407622, 0.7716791279849066, 0.6390662751886125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 317}], {
             RGBColor[
             0.4183128183750553, 0.531659468200558, 0.9487133572473935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 326}], {
             RGBColor[
             0.7319980177281254, 0.789931738848409, 0.9746592650496662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 343}], {
             RGBColor[
             0.6551511593015062, 0.7291664658254243, 0.9671941182791362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 346}], {
             RGBColor[
             0.6994154565963315, 0.7639512890319775, 0.9715515112821198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 355}], {
             RGBColor[
             0.4183128183750553, 0.531659468200558, 0.9487133572473935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 395}], {
             RGBColor[
             0.44415745762518294`, 0.5564095917440058, 0.9502735680405704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 440}], {
             RGBColor[
             0.6284894335443976, 0.7083381230273503, 0.9645367266236606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 89}], {
             RGBColor[
             0.8670566051553803, 0.41427135443018204`, 0.4233243619673379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 176}], {
             RGBColor[
             0.8597973225635679, 0.40885739335919263`, 0.4356124338711491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 244}], {
             RGBColor[
             0.8410713594730532, 0.39408148714968966`, 0.43922345789083017`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 245}], {
             RGBColor[
             0.8668871888581977, 0.4141450040331369, 0.4236111395676211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 260}], {
             RGBColor[
             0.7184512539775306, 0.29667784645715073`, 0.42794926623515683`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 261}], {
             RGBColor[
             0.6984248476196209, 0.2804195075964744, 0.42637271416751843`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 262}], {
             RGBColor[
             0.8212863018303977, 0.37830541923651906`, 0.43733634143054423`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 299}], {
             RGBColor[
             0.8585798294104681, 0.3574826860475793, 0.19996769292882383`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 328}], {
             RGBColor[
             0.8747710981909483, 0.41502949520579946`, 0.24760896612762207`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 376}], {
             RGBColor[
             0.8763216415334298, 0.4195093967643181, 0.31744497892787804`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 391}], {
             RGBColor[
             0.6923668616294407, 0.27530486167976415`, 0.42595010084938356`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 407}], {
             RGBColor[
             0.7014485335350947, 0.2828742720381543, 0.426610749798911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 448}], {
             RGBColor[
             0.8506892335315817, 0.4017505188537237, 0.4401408193045102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 455}], {
             RGBColor[
             0.6290353763920369, 0.21698146318033038`, 0.4220416861707428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 475}], {
             RGBColor[
             0.7441337381892695, 0.3175280441229693, 0.42997108547034435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 478}], {
             RGBColor[
             0.8232340165888268, 0.3798584741155816, 0.4375221162029487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 482}], {
             RGBColor[
             0.8489767637708715, 0.40038504195028674`, 0.4399774824099939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 146}], {
             RGBColor[
             0.8031497200536829, 0.6827419632672893, 0.6005346988324494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 166}], {
             RGBColor[
             0.4906470325690102, 0.5868542587751986, 0.9554153500610434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 239}], {
             RGBColor[
             0.6720813189865296, 0.7435069351819532, 0.9681195686817003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 332}], {
             RGBColor[
             0.6526850453150845, 0.7277601664233029, 0.9665926229673926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 387}], {
             RGBColor[
             0.7979943302099916, 0.455336732106984, 0.4468655715071268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 489}], {
             RGBColor[
             0.8418862167969121, 0.876809164054289, 0.9576314856571986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 177}], {
             RGBColor[
             0.5459650021360537, 0.6331565746516146, 0.9604401321093234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 194}], {
             RGBColor[
             0.8955331696959021, 0.9052123531157563, 0.6894504493781138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 220}], {
             RGBColor[
             0.8134476579567492, 0.37213203875427314`, 0.436568266706824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 254}], {
             RGBColor[
             0.8554032666085395, 0.7548042263216899, 0.6118847455497395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 290}], {
             RGBColor[
             0.5581949136291665, 0.645831726808987, 0.96114317107195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 297}], {
             RGBColor[
             0.6950135139368134, 0.7607800544840704, 0.9708439595676399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 350}], {
             RGBColor[
             0.823365240251927, 0.4483629221872824, 0.44606535471299347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 377}], {
             RGBColor[
             0.8942368848078402, 0.9008396798061575, 0.6844146273708539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 412}], {
             RGBColor[
             0.6767673896031079, 0.7459670287714341, 0.9694075578223349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 426}], {
             RGBColor[
             0.5868049632703004, 0.6706123138252311, 0.9629661781362095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 476}], {
             RGBColor[
             0.9003867857457805, 0.9200013350765495, 0.8429471340836303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 91}], {
             RGBColor[
             0.6235757971966955, 0.6868448794558504, 0.7983263007427286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 161}], {
             RGBColor[
             0.8812847325273748, 0.904793865862197, 0.8182321854938057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 184}], {
             RGBColor[
             0.8775070645986524, 0.4280253882923376, 0.33016486406494305`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 228}], {
             RGBColor[
             0.9642606254187348, 0.8832477525184754, 0.46230589935286726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 253}], {
             RGBColor[
             0.9532541034164349, 0.8396105604853894, 0.4534497933935403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 256}], {
             RGBColor[
             0.9945412381687965, 0.9907325853455653, 0.6472256461256007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 285}], {
             RGBColor[
             0.9875011978846164, 0.9681762663911107, 0.5185692127322623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 287}], {
             RGBColor[
             0.8975997541796381, 0.9175392847757022, 0.8198583143795577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 336}], {
             RGBColor[
             0.8534986666336316, 0.8830871800040825, 0.8154627301210664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 354}], {
             RGBColor[
             0.9375056195126279, 0.9492020643985586, 0.8237062540966075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 388}], {
             RGBColor[
             0.9943601855382544, 0.9913897787374535, 0.7034394311619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 409}], {
             RGBColor[
             0.8902268147562017, 0.5257949618333213, 0.3423453111807154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 436}], {
             RGBColor[
             0.8165228014079873, 0.8541406532447903, 0.811818822231583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 473}], {
             RGBColor[
             0.876429020602383, 0.4197390697351199, 0.32913252791663894`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 133}], {
             RGBColor[
             0.9485655533372352, 0.9110720319449315, 0.6375411978428598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 241}], {
             RGBColor[
             0.6194249439189823, 0.6931249807785939, 0.963494725821211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 271}], {
             RGBColor[
             0.9391375847334702, 0.9541294908640563, 0.9879083729727666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 304}], {
             RGBColor[
             0.8581725658509325, 0.40764565246320417`, 0.4383627231812225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 307}], {
             RGBColor[
             0.7775040625766061, 0.826555475996161, 0.9747482395677493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 311}], {
             RGBColor[
             0.8579067836962728, 0.8897838304575174, 0.9824768321205821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 337}], {
             RGBColor[
             0.7885232404829162, 0.8355013410288112, 0.9756157096171126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 423}], {
             RGBColor[
             0.9307877870037091, 0.947541123389595, 0.9895227695595865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 427}], {
             RGBColor[
             0.9625916333128837, 0.9583852931829853, 0.6920298699453031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 433}], {
             RGBColor[
             0.9392440158345725, 0.9542088670049935, 0.9877282128802771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 465}], {
             RGBColor[
             0.964878871589802, 0.9723826416905021, 0.9020313392465509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 469}], {
             RGBColor[
             0.7572837141435049, 0.8101396862218534, 0.9731564196695186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 176}], {
             RGBColor[
             0.9556428915784223, 0.966439121684062, 0.9599691937577306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 178}], {
             RGBColor[
             0.9587945009513559, 0.9091125736385048, 0.6105073765773171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 244}], {
             RGBColor[
             0.9275539469426503, 0.9442752623698076, 0.9653857297872522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 261}], {
             RGBColor[
             0.7135841791625017, 0.7737822930399847, 0.9461096142022847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 262}], {
             RGBColor[
             0.897876360478667, 0.9206111605000517, 0.9625550550968234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 299}], {
             RGBColor[
             0.9538166518487725, 0.889377060716642, 0.6065020823442426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 328}], {
             RGBColor[
             0.978103555019493, 0.9756972744539723, 0.67796399214244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 376}], {
             RGBColor[
             0.9804293700332152, 0.9824171267917502, 0.782718011342824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 391}], {
             RGBColor[
             0.7044972001772316, 0.7661103241649193, 0.9454756942250822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 407}], {
             RGBColor[
             0.7181197080357126, 0.7774644397025046, 0.9464666676493735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 448}], {
             RGBColor[
             0.9419807580304429, 0.9557788099258586, 0.9667617719077722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 455}], {
             RGBColor[
             0.6094999723211257, 0.6786252264157686, 0.9396130722071212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 475}], {
             RGBColor[
             0.7821475150169748, 0.829445097829727, 0.9515071711565235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 478}], {
             RGBColor[
             0.9007979326163105, 0.9229407428186456, 0.96283371725543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 482}], {
             RGBColor[
             0.9394120533893776, 0.9537305945707032, 0.9665167665659977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 137}], {
             RGBColor[
             0.8010831932599617, 0.3624728249597305, 0.43533589241834025`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 148}], {
             RGBColor[
             0.6269413340074379, 0.706084215689289, 0.9650965707044491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 229}], {
             RGBColor[
             0.8809625038532098, 0.9053337098684094, 0.8690245055067778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 232}], {
             RGBColor[
             0.8799857411203998, 0.9049297933767353, 0.8852119917703631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 263}], {
             RGBColor[
             0.7970535380438455, 0.8414280962147271, 0.9803946843465151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 267}], {
             RGBColor[
             0.7989162426355391, 0.8429133662943743, 0.9805723507733268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 280}], {
             RGBColor[
             0.853789229984821, 0.8074477617263804, 0.6236606001527463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 342}], {
             RGBColor[
             0.5258901405884041, 0.617061556176481, 0.9585045439688991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 393}], {
             RGBColor[
             0.8010831932599617, 0.3624728249597305, 0.43533589241834025`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 480}], {
             RGBColor[
             0.8010831932599617, 0.3624728249597305, 0.43533589241834025`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 485}], {
             RGBColor[
             0.7280292503886135, 0.7874612507216032, 0.9735268099247292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 200}], {
             RGBColor[
             0.5849335976288481, 0.659836123396444, 0.9648356361369437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 228}], {
             RGBColor[
             0.5931873608082812, 0.5791294227689665, 0.6016706163456789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 256}], {
             RGBColor[
             0.6234679735583428, 0.6866142555960564, 0.7865903631184124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 287}], {
             RGBColor[
             0.5265264895691846, 0.6134209550261933, 0.9592230313723693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 298}], {
             RGBColor[
             0.4305298012672219, 0.5379098100653481, 0.9500090029906565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 336}], {
             RGBColor[
             0.482425402023178, 0.5789688502545736, 0.954827447113878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 132}], {
             RGBColor[
             0.8074100350851449, 0.43005754928983375`, 0.4437493766668593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 250}], {
             RGBColor[
             0.541285195009416, 0.6331105051264647, 0.9592508939025626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 342}], {
             RGBColor[
             0.5217728605047203, 0.6138451056826195, 0.9580941719683274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 356}], {
             RGBColor[
             0.5331338276085699, 0.6257862024356838, 0.958741162237847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 365}], {
             RGBColor[
             0.8420859825922514, 0.8774023020087597, 0.9846722569578293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 457}], {
             RGBColor[
             0.831557060758281, 0.7319826473061386, 0.6086523628809342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 485}], {
             RGBColor[
             0.7239119703049297, 0.7842448002277418, 0.9731164379241575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 494}], {
             RGBColor[
             0.5681911731912834, 0.6564151110938141, 0.9609653190402889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 141}], {
             RGBColor[
             0.8760370625369529, 0.5109147086257966, 0.44246931058359973`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 151}], {
             RGBColor[
             0.952915607315721, 0.9644051175464576, 0.9645857746248268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 160}], {
             RGBColor[
             0.9701197862260001, 0.9769946952018886, 0.924658987633632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 167}], {
             RGBColor[
             0.9366170357283596, 0.8403973077577156, 0.6075677381661407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 172}], {
             RGBColor[
             0.9702393635140732, 0.9648506929243044, 0.6807012769731344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 201}], {
             RGBColor[
             0.966628149753752, 0.9746319092445136, 0.9413740170810942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 218}], {
             RGBColor[
             0.9456610824903062, 0.9589947048098575, 0.9768657928711509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 235}], {
             RGBColor[
             0.8656240970340237, 0.8955521196886314, 0.9700578028811894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 236}], {
             RGBColor[
             0.8674908015839466, 0.8970104034705113, 0.9702438585453799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 274}], {
             RGBColor[
             0.8630777755178584, 0.41130394980125384`, 0.43005948269869354`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 284}], {
             RGBColor[
             0.9531804561495143, 0.9646026413730504, 0.9641374546328536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 289}], {
             RGBColor[
             0.9608218464815741, 0.9703015777710724, 0.9512025739944631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 300}], {
             RGBColor[
             0.6892875520421153, 0.7536547778413759, 0.9549895212515527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 305}], {
             RGBColor[
             0.9535543499484815, 0.907548114615117, 0.621195898757513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 308}], {
             RGBColor[
             0.5968637438251735, 0.6671656454720774, 0.9493360214774937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 389}], {
             RGBColor[
             0.97435303243677, 0.9777348195514438, 0.7810554212067395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 432}], {
             RGBColor[
             0.8630777755178584, 0.41130394980125384`, 0.43005948269869354`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 456}], {
             RGBColor[
             0.776274403048089, 0.8250712237252735, 0.9616173414314466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 493}], {
             RGBColor[
             0.8854517430706256, 0.911041627468116, 0.9720340373382309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 123}], {
             RGBColor[
             0.9924672274869801, 0.9899105576898775, 0.6841872270978527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 139}], {
             RGBColor[
             0.9661259526989319, 0.8975037902802012, 0.5343972176408265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 158}], {
             RGBColor[
             0.9623216471953797, 0.8824209866682751, 0.5313361841341411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 193}], {
             RGBColor[
             0.7151113242223579, 0.7726793246847474, 0.873241424945453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 401}], {
             RGBColor[
             0.8752435595050384, 0.419612869301783, 0.3752389662070031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 410}], {
             RGBColor[
             0.8681028907747694, 0.8956959470779742, 0.8862552336598964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 428}], {
             RGBColor[
             0.9448931721401223, 0.9563212794347509, 0.8937401484033177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 437}], {
             RGBColor[
             0.7197274553471891, 0.7766775854515797, 0.8735355607388426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 122}], {
             RGBColor[
             0.6477389497355808, 0.7112035113717956, 0.6958618324492837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 185}], {
             RGBColor[
             0.9922514203252054, 0.9888708267544838, 0.618673184526577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 212}], {
             RGBColor[
             0.8342184654440179, 0.8667293809502472, 0.7097413153962637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 224}], {
             RGBColor[
             0.6857152267078532, 0.7446521435420664, 0.6982613080341391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 286}], {
             RGBColor[
             0.9881000076961508, 0.971374405244888, 0.4207087678715801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 319}], {
             RGBColor[
             0.8025257899153724, 0.8415105338233719, 0.7068971871932439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 330}], {
             RGBColor[
             0.9772999993079654, 0.9789778733954013, 0.7003085339122959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 357}], {
             RGBColor[
             0.9894878276883088, 0.9877280101780359, 0.6644730664684374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 367}], {
             RGBColor[
             0.9131000024836271, 0.9284611587514258, 0.7175745853897637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 368}], {
             RGBColor[
             0.9317981571022802, 0.9433705596964534, 0.7193580320693305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 492}], {
             RGBColor[
             0.875792666145556, 0.41837797189727155`, 0.259869272415489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 110}], {
             RGBColor[
             0.9671450279645892, 0.9716953922439107, 0.740594192587352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 136}], {
             RGBColor[
             0.927590587339719, 0.9402958614529204, 0.7416790345724946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.9684556277894549, 0.9726728354473851, 0.738375688943034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 240}], {
             RGBColor[
             0.8849053768705699, 0.9066100626965945, 0.7375147409748731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 360}], {
             RGBColor[
             0.9723559369236896, 0.9755816796135273, 0.7317734829423166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 457}], {
             RGBColor[
             0.9479474940653562, 0.8195037280702481, 0.36860505839571944`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 163}], {
             RGBColor[
             0.3000202594156828, 0.4314802809500253, 0.9404406688135449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 207}], {
             RGBColor[
             0.40455766137868654`, 0.5239012871874162, 0.9472554319735089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 209}], {
             RGBColor[
             0.6520864441335752, 0.2404159885974953, 0.42338346826512163`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 231}], {
             RGBColor[
             0.5119234857129439, 0.6101486196011255, 0.9563346759439215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 233}], {
             RGBColor[
             0.6513775559090966, 0.7192220749447049, 0.9292670872649598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 257}], {
             RGBColor[
             0.6435180389645314, 0.6739959614174768, 0.6309288256802901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 281}], {
             RGBColor[
             0.4613920750111423, 0.5700420245354003, 0.9517296452059727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 317}], {
             RGBColor[
             0.30239501689882453`, 0.43397630163312817`, 0.940575907739071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 322}], {
             RGBColor[
             0.6493235501353187, 0.6935793137953887, 0.6534821403000063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 326}], {
             RGBColor[
             0.6160802162518948, 0.6922485722809791, 0.9665218155413436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 343}], {
             RGBColor[
             0.5392333578252755, 0.6314832992579945, 0.9590566687708137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 355}], {
             RGBColor[
             0.30239501689882453`, 0.43397630163312817`, 0.940575907739071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 395}], {
             RGBColor[
             0.32823965614895223`, 0.45872642517657597`, 0.9421361185322479]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 440}], {
             RGBColor[
             0.5125716320681669, 0.6106549564599205, 0.9563992771153382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 105}], {
             RGBColor[
             0.6705736842259354, 0.2564287067697931, 0.42456145885618224`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 276}], {
             RGBColor[
             0.6697037399730448, 0.25567520478260874`, 0.4245060267776496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 347}], {
             RGBColor[
             0.624590053698924, 0.21230914718013116`, 0.4217885316196356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 382}], {
             RGBColor[
             0.8324827379096514, 0.38723315344695486`, 0.43840426749896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 425}], {
             RGBColor[
             0.8322295887671682, 0.3870312991922891, 0.438380121907761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 462}], {
             RGBColor[
             0.6837776338684216, 0.2678653043003091, 0.42540280285160725`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 131}], {
             RGBColor[
             0.9041340863733258, 0.9243718394054201, 0.9137679154817583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 143}], {
             RGBColor[
             0.878385978533336, 0.9058386472800886, 0.9873434835983155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 178}], {
             RGBColor[
             0.8855511525381028, 0.8515054091653436, 0.631087748401515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 186}], {
             RGBColor[
             0.9071898969500003, 0.9248182512576847, 0.8037201889259191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 277}], {
             RGBColor[
             0.6388622336940262, 0.7149747368673556, 0.9665735854500159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 288}], {
             RGBColor[
             0.7095699600867768, 0.7723784544997645, 0.9721399566825895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 295}], {
             RGBColor[
             0.5740241133189142, 0.6589336367009342, 0.9624094377218313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 313}], {
             RGBColor[
             0.8675832742999244, 0.7802687593914491, 0.616630371810768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 321}], {
             RGBColor[
             0.8624406092499931, 0.8931507477619873, 0.9867415492917269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 341}], {
             RGBColor[
             0.6194569999551907, 0.698285319581998, 0.9653043810835706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 373}], {
             RGBColor[
             0.8383671761892607, 0.8739552456952919, 0.9844454037557868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 498}], {
             RGBColor[
             0.8744900513344931, 0.8076518287865044, 0.6221877267356757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 203}], {
             RGBColor[
             0.9806809014205755, 0.9851124284283616, 0.917586374053794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 257}], {
             RGBColor[
             0.9714169139350952, 0.9388388630713284, 0.6216255147503104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 264}], {
             RGBColor[
             0.6233289692988726, 0.691498628063771, 0.9308759547723799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 281}], {
             RGBColor[
             0.7892909499817061, 0.8348849261892519, 0.9424263342759931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 324}], {
             RGBColor[
             0.7174137281959343, 0.7765317595116212, 0.9367678960820782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 360}], {
             RGBColor[
             0.9644865349812825, 0.9730346964537782, 0.9449992122682953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 374}], {
             RGBColor[
             0.8706856941139511, 0.4169779230333964, 0.4171812609784685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 397}], {
             RGBColor[
             0.8706856941139511, 0.4169779230333964, 0.4171812609784685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 457}], {
             RGBColor[
             0.940078092122949, 0.8169567449104989, 0.5818307877216982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 103}], {
             RGBColor[
             0.922532695339228, 0.9374652971038049, 0.8386720298020295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 129}], {
             RGBColor[
             0.6043962581026167, 0.6668499597946491, 0.8136337546521555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[
             0.9913092226121238, 0.9903882284077087, 0.7729083973303756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 276}], {
             RGBColor[
             0.6847118915810397, 0.7451898523189412, 0.8184301173590507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 306}], {
             RGBColor[
             0.9847018397539786, 0.9585472970688493, 0.5235168822546279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 331}], {
             RGBColor[
             0.9917742414051649, 0.990580525629069, 0.7652018324996268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 347}], {
             RGBColor[
             0.6170413621698586, 0.6801407659152249, 0.8143538746220298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 390}], {
             RGBColor[
             0.7755194274430522, 0.8210523213974257, 0.8249873041016424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 431}], {
             RGBColor[
             0.9942002261874912, 0.9900031951991536, 0.6101085964425267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 486}], {
             RGBColor[
             0.9185471487429617, 0.9342873304327226, 0.8382918848097382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 134}], {
             RGBColor[
             0.9543972215914255, 0.9655101030473572, 0.9620777881229506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 174}], {
             RGBColor[
             0.6810486204901476, 0.7461771087887392, 0.9494802488338067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 210}], {
             RGBColor[
             0.621719710183886, 0.6924245926248661, 0.9457864498979112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 225}], {
             RGBColor[
             0.864969572990283, 0.412714849258654, 0.42685716303768173`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 247}], {
             RGBColor[
             0.6296204546280079, 0.7007287759717685, 0.9462363856059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 252}], {
             RGBColor[
             0.7842695441581269, 0.8313746190225761, 0.9572198748949103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 278}], {
             RGBColor[
             0.9362490326699436, 0.8298041275859058, 0.6001848777969194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 309}], {
             RGBColor[
             0.8901579188052418, 0.9146181410600926, 0.9674166593317275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 383}], {
             RGBColor[
             0.8580814597375953, 0.889559273447118, 0.9642197087556186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 393}], {
             RGBColor[
             0.864969572990283, 0.412714849258654, 0.42685716303768173`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 451}], {
             RGBColor[
             0.6085969654502783, 0.6786317558797724, 0.9450391289986934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 480}], {
             RGBColor[
             0.864969572990283, 0.412714849258654, 0.42685716303768173`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 129}], {
             RGBColor[
             0.5319783901988995, 0.6127071666083979, 0.9605276300690322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 204}], {
             RGBColor[
             0.9188913547084068, 0.9362454352214573, 0.9198022727472523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 209}], {
             RGBColor[
             0.8282509424785036, 0.3838588346391846, 0.4380006350729687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 231}], {
             RGBColor[
             0.7761702332303364, 0.8253128886636594, 0.9782604261556922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 233}], {
             RGBColor[
             0.9156243034264892, 0.9343863440072387, 0.9511928374767304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 259}], {
             RGBColor[
             0.9098342896345127, 0.8961411505561406, 0.6608942048469906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 275}], {
             RGBColor[
             0.921431863320548, 0.9351107287270387, 0.7188532581164437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 326}], {
             RGBColor[
             0.8803269637692872, 0.907412841343513, 0.9884475657531143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 346}], {
             RGBColor[
             0.8477444026374934, 0.8814323915270814, 0.9853398119855681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 348}], {
             RGBColor[
             0.7472001372960109, 0.8026812295388803, 0.9753729577338974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 355}], {
             RGBColor[
             0.566641764416217, 0.649140570695662, 0.9625016579508416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 390}], {
             RGBColor[
             0.7031015595393351, 0.7669095282111743, 0.9718811795185192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 404}], {
             RGBColor[
             0.8636139811277117, 0.7091018873694397, 0.6023692157454943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 431}], {
             RGBColor[
             0.9217823582837741, 0.9358604020129022, 0.7570024718594034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 443}], {
             RGBColor[
             0.8660590393543877, 0.896035985707563, 0.9870866783852947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 444}], {
             RGBColor[
             0.6326794553125107, 0.7087038954135042, 0.9666229344535923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 486}], {
             RGBColor[
             0.8461292808392445, 0.8801445372464712, 0.9851857602266149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 125}], {
             RGBColor[
             0.7216360803890036, 0.6097094792440243, 0.5917018111368387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 147}], {
             RGBColor[
             0.5530916819538538, 0.458592465508634, 0.5804609934967956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 242}], {
             RGBColor[
             0.703492060094891, 0.594979346190464, 0.5902734473955499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 303}], {
             RGBColor[
             0.9385077928875379, 0.7768706211946034, 0.3503687825838242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 310}], {
             RGBColor[
             0.9123055203488966, 0.760784630279653, 0.6052292266722191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 323}], {
             RGBColor[
             0.8395625088357104, 0.27821060181251556`, 0.18446547384080544`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 379}], {
             RGBColor[
             0.7132133162577425, 0.6028714998810665, 0.5910387402908243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 408}], {
             RGBColor[
             0.6009925271229449, 0.5080896562428827, 0.5832199850519748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 109}], {
             RGBColor[
             0.671600179014658, 0.6991999883021494, 0.6340604676897484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 205}], {
             RGBColor[
             0.37726127771437656`, 0.5011864898782057, 0.945259732910279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 230}], {
             RGBColor[
             0.6741604765294043, 0.7395509870119612, 0.9394096441266119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 382}], {
             RGBColor[
             0.6199466332033804, 0.697238790325122, 0.9660125895327134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 425}], {
             RGBColor[
             0.6195669094896554, 0.6969360089431234, 0.9659763711459151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 462}], {
             RGBColor[
             0.3968889771415355, 0.5181870166051533, 0.9465103925616843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 484}], {
             RGBColor[
             0.6860678343028312, 0.746627132050323, 0.8384514321354605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 156}], {
             RGBColor[
             0.765741677405664, 0.8127881870029627, 0.7974891169256599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 227}], {
             RGBColor[
             0.6942099701215159, 0.7596816671368085, 0.9711918685837776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 265}], {
             RGBColor[
             0.6662748596390691, 0.7376046577650244, 0.9684749321067441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 270}], {
             RGBColor[
             0.4635626481784757, 0.5736635775619812, 0.9513867673524223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 329}], {
             RGBColor[
             0.7478252287291094, 0.8018417902499654, 0.9558074677959101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 479}], {
             RGBColor[
             0.753010985531706, 0.5194965005797676, 0.45605252248511985`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 153}], {
             RGBColor[
             0.6245930560691766, 0.6985740998728202, 0.964796782303442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 170}], {
             RGBColor[
             0.9451263582951562, 0.9585959083806451, 0.9777709414551337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 197}], {
             RGBColor[
             0.6694028607700562, 0.7373861004984519, 0.9676520234352275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 214}], {
             RGBColor[
             0.9037660118167203, 0.9260242276851492, 0.9879693827356102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 223}], {
             RGBColor[
             0.961642731456714, 0.9708541372888166, 0.9471415502348386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 236}], {
             RGBColor[
             0.8595603330185, 0.8910958729993517, 0.9836680732292159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 289}], {
             RGBColor[
             0.9528913779161274, 0.9643870472999128, 0.9646267886782991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 314}], {
             RGBColor[
             0.9377306139248593, 0.9530801743386977, 0.990290007554987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 411}], {
             RGBColor[
             0.8286759312794396, 0.8669687436306508, 0.98058980469501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 466}], {
             RGBColor[
             0.9048204256813321, 0.7302635036701435, 0.6012922018726738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 470}], {
             RGBColor[
             0.8577907964742272, 0.4073609294871473, 0.43900895915458427`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 113}], {
             RGBColor[
             0.9491164643863907, 0.9591526178676413, 0.8708593073111226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 190}], {
             RGBColor[
             0.9507420777926051, 0.8315512260095923, 0.4977445798229541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 315}], {
             RGBColor[
             0.9741016156274696, 0.9785949992307617, 0.8565970438241289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 349}], {
             RGBColor[
             0.9939362542524715, 0.9917604995493088, 0.7501554897149039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 364}], {
             RGBColor[
             0.7941356944146573, 0.8366636901676925, 0.8560956765419692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 378}], {
             RGBColor[
             0.9689769116694478, 0.9747730034098014, 0.8652718308882039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 380}], {
             RGBColor[
             0.9841783703650736, 0.9586420971805327, 0.5531510936481026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 416}], {
             RGBColor[
             0.9915687940698914, 0.9907814939228605, 0.7893904317308076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 452}], {
             RGBColor[
             0.9927589320439423, 0.9912736465602813, 0.7696667655224391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 487}], {
             RGBColor[
             0.6568610440276649, 0.72159358440092, 0.8462903347955133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 164}], {
             RGBColor[
             0.6119565458339143, 0.6428289756416212, 0.6304325097578755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 180}], {
             RGBColor[
             0.7808969658078708, 0.790002001139626, 0.6420927756736504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 205}], {
             RGBColor[
             0.6717784040512281, 0.6993543578709756, 0.6340718240314804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 230}], {
             RGBColor[
             0.9686776028662558, 0.9377188550047311, 0.6282217352478134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 382}], {
             RGBColor[
             0.9144637595402318, 0.8954066583178919, 0.6548246806539151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 413}], {
             RGBColor[
             0.6088596250388341, 0.6395739155298725, 0.6302561447000794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 474}], {
             RGBColor[
             0.9796216525554587, 0.9425366948926776, 0.40802911895683536`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 490}], {
             RGBColor[
             0.60929271726381, 0.6400291229179552, 0.6302808086615892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 157}], {
             RGBColor[
             0.9424427695273766, 0.9565944922716083, 0.9823135572469379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 356}], {
             RGBColor[
             0.6235114026535667, 0.6972289400240166, 0.9626317260565361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 360}], {
             RGBColor[
             0.9463430786616113, 0.9595033364377505, 0.9757113512462205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 457}], {
             RGBColor[
             0.9219346358032778, 0.8034253848944712, 0.6125429266996234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 494}], {
             RGBColor[
             0.6585687482362803, 0.7278578486821468, 0.964855882858978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 130}], {
             RGBColor[
             0.7937298576624864, 0.3567283433035624, 0.43460298064681213`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 175}], {
             RGBColor[
             0.5967362895950796, 0.6817266377028615, 0.9625356655761559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 182}], {
             RGBColor[
             0.8568839332434217, 0.8515030156415384, 0.6512574310896914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 351}], {
             RGBColor[
             0.4877175285564594, 0.5799162310752902, 0.9558594449036929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 359}], {
             RGBColor[
             0.5017373924585835, 0.5946519969471351, 0.9566578554123888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 371}], {
             RGBColor[
             0.527378510696328, 0.6216024379557992, 0.9581180791633933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 460}], {
             RGBColor[
             0.86668129470023, 0.8953725302515574, 0.9218060310899023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 463}], {
             RGBColor[
             0.603114996750322, 0.6870788529084847, 0.9629898287711112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 483}], {
             RGBColor[
             0.6053789041497143, 0.6889167949231774, 0.9631680518545573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 163}], {
             RGBColor[
             0.6158459876461304, 0.6873190495330617, 0.9515740461336051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 175}], {
             RGBColor[
             0.7000968975321604, 0.7630968742267972, 0.9568397743236803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 207}], {
             RGBColor[
             0.7203833896091342, 0.7797400557704526, 0.9583888092935691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 238}], {
             RGBColor[
             0.9383531192478518, 0.8494088377938813, 0.6106160598221919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 266}], {
             RGBColor[
             0.6166818073874106, 0.6881975490751796, 0.9516216448313864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 293}], {
             RGBColor[
             0.9455710894628484, 0.9589275881573295, 0.9770181275926961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 317}], {
             RGBColor[
             0.6182207451292722, 0.6898150702161645, 0.9517092850591311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 343}], {
             RGBColor[
             0.855059086055723, 0.8873220678410308, 0.9701900460908739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 359}], {
             RGBColor[
             0.6050980003956643, 0.6760222334710708, 0.9509619641599132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 403}], {
             RGBColor[
             0.7381036912721358, 0.79412619495097, 0.9597838163520842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 440}], {
             RGBColor[
             0.8283973602986145, 0.8664937250429569, 0.9675326544353983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 445}], {
             RGBColor[
             0.9728586121056348, 0.9779075485267765, 0.869429974536861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 463}], {
             RGBColor[
             0.7064756046874029, 0.7684490894324204, 0.9572939375186356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 471}], {
             RGBColor[
             0.9543277925912953, 0.9654583230127397, 0.9621953133101876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 483}], {
             RGBColor[
             0.7087395120867951, 0.7702870314471131, 0.9574721606020817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 190}], {
             RGBColor[
             0.9059720424439612, 0.7989639190995177, 0.6176238363046813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 315}], {
             RGBColor[
             0.9293315802788258, 0.946007692320687, 0.9764763003058561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 349}], {
             RGBColor[
             0.9491662189038275, 0.9591731926392342, 0.8700347461966311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 353}], {
             RGBColor[
             0.9103609680966539, 0.8163645467896696, 0.6211552689061637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 364}], {
             RGBColor[
             0.7493656590660134, 0.8040763832576179, 0.9759749330236964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 378}], {
             RGBColor[
             0.9242068763208038, 0.9421856964997268, 0.9851510873699312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 380}], {
             RGBColor[
             0.9394083350164297, 0.9260547902704581, 0.6730303501298298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 487}], {
             RGBColor[
             0.612091008679021, 0.6890062774908454, 0.9661695912772406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 128}], {
             RGBColor[
             0.8235605783581362, 0.7706332968902524, 0.6177247368877535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 138}], {
             RGBColor[
             0.7889836428515151, 0.8354150085351929, 0.9795130835125052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 179}], {
             RGBColor[
             0.47692237117677583`, 0.5726317967163046, 0.9546016087041642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 255}], {
             RGBColor[
             0.8202143082502406, 0.8603174933903077, 0.9824918922581798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 294}], {
             RGBColor[
             0.8428210992770853, 0.8774797575740481, 0.9547004456862318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 296}], {
             RGBColor[
             0.6455673148397794, 0.7220047223995429, 0.9660165295857313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 312}], {
             RGBColor[
             0.632423551883573, 0.7113340235119213, 0.9649818044186285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 327}], {
             RGBColor[
             0.6500626657186896, 0.7256542507562918, 0.9663704200739318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 334}], {
             RGBColor[
             0.7776581410687471, 0.8263843608361698, 0.97843284704207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 385}], {
             RGBColor[
             0.8514179011155956, 0.8835262528557638, 0.9238035082630943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 415}], {
             RGBColor[
             0.8406767692434449, 0.8758805197459772, 0.9583302371023414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 446}], {
             RGBColor[
             0.5653883326651385, 0.6558531906966091, 0.9599970468030408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 144}], {
             RGBColor[
             0.6520233779995794, 0.7263441914045977, 0.9671413769710265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 215}], {
             RGBColor[
             0.46763242106554537`, 0.5774138952901122, 0.9515838427636094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 223}], {
             RGBColor[
             0.7566391403235619, 0.8080815388159037, 0.9308673560131511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 268}], {
             RGBColor[
             0.6441001391503123, 0.7201544969967046, 0.9663516625694084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 402}], {
             RGBColor[
             0.48163382664166643`, 0.5895412090690422, 0.9524759999459631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 417}], {
             RGBColor[
             0.7211217357187925, 0.2988458638385387, 0.42815949634012584`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 143}], {
             RGBColor[
             0.6166423970679169, 0.6906815764496288, 0.9660945232772165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 165}], {
             RGBColor[
             0.2927946020720844, 0.4250760694007177, 0.9399855914859837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 185}], {
             RGBColor[
             0.6441603989612699, 0.7099466652502284, 0.8631872303574494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 187}], {
             RGBColor[
             0.49398609078265276`, 0.593944453977967, 0.9550386376872195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 224}], {
             RGBColor[
             0.3376242053439177, 0.4657279820378112, 0.9427753538650114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 277}], {
             RGBColor[
             0.3771186522286071, 0.4998176660368958, 0.945324625128917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 313}], {
             RGBColor[
             0.6058396928345053, 0.5651116885609895, 0.595381411489669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 333}], {
             RGBColor[
             0.6075983503059703, 0.572084179397487, 0.5967964685722064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 358}], {
             RGBColor[
             0.5849926474604887, 0.6654714303451499, 0.9639946911558508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 361}], {
             RGBColor[
             0.6431971390199129, 0.7095483325098262, 0.879150940422549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 386}], {
             RGBColor[
             0.5941127359748368, 0.6727435413682833, 0.9648645733399485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 441}], {
             RGBColor[
             0.6361289763166988, 0.6793620588886213, 0.6501497074705821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 140}], {
             RGBColor[
             0.6938530020675666, 0.27659208183167855`, 0.42604479640395854`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 155}], {
             RGBColor[
             0.6121407517251012, 0.6937607205970827, 0.9640710383983933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 156}], {
             RGBColor[
             0.7206900400341826, 0.7760395448521443, 0.7939904790004713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 198}], {
             RGBColor[
             0.714497582228059, 0.7738368812940413, 0.9324631714336235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 270}], {
             RGBColor[
             0.4185110108069943, 0.5369149354111629, 0.9478881294272337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 479}], {
             RGBColor[
             0.722976560617385, 0.49499740581255536`, 0.45372009720166073`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 152}], {
             RGBColor[
             0.7366648977558832, 0.792925052544279, 0.9587837002022196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 187}], {
             RGBColor[
             0.6052349853379602, 0.6896445889843419, 0.9625792412718526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.4688113045682638, 0.5786975878052025, 0.9515864022204936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 255}], {
             RGBColor[
             0.721518731187273, 0.7813269098658386, 0.9739462556088725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 260}], {
             RGBColor[
             0.5198857533760015, 0.621105701033753, 0.9553464573914741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 292}], {
             RGBColor[
             0.6694720766617137, 0.7398270929464343, 0.9689817942052557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 399}], {
             RGBColor[
             0.7559293733924426, 0.8037232682826756, 0.7066552393109005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 446}], {
             RGBColor[
             0.46669275560217105`, 0.5768626071721401, 0.9514514101537335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 464}], {
             RGBColor[
             0.5053509674711256, 0.6093057070515316, 0.9542022258023672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 481}], {
             RGBColor[
             0.5396831034326456, 0.6371780816701931, 0.9569049773080158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 496}], {
             RGBColor[
             0.4173116397016484, 0.534091166546159, 0.9483048891145585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 120}], {
             RGBColor[
             0.8246417800766562, 0.8638293563159276, 0.9808013453035449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 124}], {
             RGBColor[
             0.8835089685444621, 0.9098894676437339, 0.9866494063743614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 363}], {
             RGBColor[
             0.6343148726292896, 0.7070358507425637, 0.9660175670361022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 364}], {
             RGBColor[
             0.7662172917134076, 0.8174527997709826, 0.9754805949544165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 381}], {
             RGBColor[
             0.6167343297725469, 0.6905762927199429, 0.9649424663693633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 416}], {
             RGBColor[
             0.9636503913686418, 0.9715706035261507, 0.908775350143255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 124}], {
             RGBColor[
             0.7701010542885829, 0.8204006799753651, 0.9777008640236161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 315}], {
             RGBColor[
             0.8327752986703408, 0.8698953211656832, 0.967033419885831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 363}], {
             RGBColor[
             0.5209069583734105, 0.617547063074195, 0.957069024685357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 381}], {
             RGBColor[
             0.5033264155166678, 0.6010875050515743, 0.9559939240186179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 196}], {
             RGBColor[
             0.5982634885755381, 0.5450273308680118, 0.5918394512909799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.5541517533119414, 0.6400245088006558, 0.9611813259685777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 307}], {
             RGBColor[
             0.4524272264998259, 0.5601393976806334, 0.9513275750879243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 337}], {
             RGBColor[
             0.4634464044061361, 0.5690852627132836, 0.9521950451372877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 420}], {
             RGBColor[
             0.6418942551119127, 0.7057796905551246, 0.7674635698578476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 427}], {
             RGBColor[
             0.6375147972361036, 0.6919692148674577, 0.6686092054654782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 442}], {
             RGBColor[
             0.6241053076433724, 0.6467358577732905, 0.6165158705673448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 447}], {
             RGBColor[
             0.2729769568210383, 0.4042464677305866, 0.9388570059065156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 454}], {
             RGBColor[
             0.28673766700717845`, 0.4187098466156378, 0.9396406579944698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 489}], {
             RGBColor[
             0.6277734254122715, 0.697940304420394, 0.9412757235846317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 500}], {
             RGBColor[
             0.44246596369690394`, 0.5520523957874459, 0.9505433879907703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 185}], {
             RGBColor[
             0.6472503716241185, 0.7131944224344648, 0.8633631997293937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 212}], {
             RGBColor[
             0.4892174167429309, 0.5910529766302282, 0.9544313305990805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 216}], {
             RGBColor[
             0.3451269884345777, 0.47279789382031656`, 0.9432325036153208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 217}], {
             RGBColor[
             0.35451854254358195`, 0.48093238595630156`, 0.9438309251385215]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 224}], {
             RGBColor[
             0.3407141780067663, 0.46897573922204744`, 0.9429513232369557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 286}], {
             RGBColor[
             0.6430989589950638, 0.695698000924869, 0.6653987830743968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 319}], {
             RGBColor[
             0.4575247412142853, 0.5658341295033529, 0.9515872023960605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 330}], {
             RGBColor[
             0.6322989506068784, 0.7033014690753824, 0.9449985491151125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 357}], {
             RGBColor[
             0.6444867789872217, 0.7120516058580169, 0.9091630816712541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 492}], {
             RGBColor[
             0.6457919670114979, 0.23459370235059224`, 0.42299594921736683`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 139}], {
             RGBColor[
             0.9675005016707968, 0.89682974006473, 0.4213035461176699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 158}], {
             RGBColor[
             0.9636961961672447, 0.8817469364528039, 0.4182425126109846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 193}], {
             RGBColor[
             0.7164858731942229, 0.7720052744692762, 0.7601477534222965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 401}], {
             RGBColor[
             0.8761599254862817, 0.41916350249146883`, 0.2998431851915654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 410}], {
             RGBColor[
             0.8694774397466345, 0.8950218968625029, 0.7731615621367399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 422}], {
             RGBColor[
             0.9096686363833256, 0.9264641125123345, 0.7771556235063528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 428}], {
             RGBColor[
             0.9462677211119872, 0.9556472292192797, 0.7806464768801612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 437}], {
             RGBColor[
             0.7211020043190541, 0.7760035352361085, 0.7604418892156861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 363}], {
             RGBColor[
             0.5797741468412164, 0.6636071744020012, 0.9629170857561735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 381}], {
             RGBColor[
             0.5621936039844737, 0.6471476163793806, 0.9618419850894344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 416}], {
             RGBColor[
             0.9091096655805685, 0.9281419271855882, 0.9056748688633263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.7490564455965003, 0.8034930936189093, 0.9733851175976058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 173}], {
             RGBColor[
             0.4077252612568577, 0.519841643876559, 0.9481731859901374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 242}], {
             RGBColor[
             0.5410786139767634, 0.6383110199969416, 0.9570148370099724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 249}], {
             RGBColor[
             0.6734449787022347, 0.7435460597333119, 0.9689570882088667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 269}], {
             RGBColor[
             0.64176514472354, 0.7187975326534997, 0.9657995384227509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 282}], {
             RGBColor[
             0.7725603059004676, 0.820738809300402, 0.9209068690749279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 305}], {
             RGBColor[
             0.7558680038071321, 0.7512397664384872, 0.6195462750851033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 310}], {
             RGBColor[
             0.7498920742307691, 0.8041163040861307, 0.9719706162866416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 323}], {
             RGBColor[
             0.731286878090292, 0.3070983843501673, 0.4289597335837537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 406}], {
             RGBColor[
             0.42662044266902505`, 0.539701677564443, 0.9492492386186444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 408}], {
             RGBColor[
             0.43857908100481746`, 0.5514213300493603, 0.9499613746663973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 419}], {
             RGBColor[
             0.7734911196832797, 0.8211237247204178, 0.9054808758248822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 173}], {
             RGBColor[
             0.5945718452509778, 0.6679939441859628, 0.9656833536719491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 249}], {
             RGBColor[
             0.860291562696355, 0.8916983600427159, 0.9864672558906784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 269}], {
             RGBColor[
             0.8286117287176601, 0.8669498329629035, 0.9833097061045626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 282}], {
             RGBColor[
             0.9594068898945878, 0.968891109609806, 0.9384170367567396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 340}], {
             RGBColor[
             0.9097182614506079, 0.9308486643090756, 0.9912509339638799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 384}], {
             RGBColor[
             0.9066389897386116, 0.9283933366305337, 0.9909572302790913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 414}], {
             RGBColor[
             0.9370946347918534, 0.9525340911363183, 0.9888782084941412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 449}], {
             RGBColor[
             0.5921080662114941, 0.665404356202852, 0.9655430451004849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 499}], {
             RGBColor[
             0.6024586484331316, 0.6762834743826098, 0.966132495445693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 184}], {
             RGBColor[
             0.6531644881298446, 0.24870230715471303`, 0.42441580441342575`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 221}], {
             RGBColor[
             0.5739947256452245, 0.6586907444514303, 0.9625076638771184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 253}], {
             RGBColor[
             0.6167402387132233, 0.5706259387789526, 0.5948262039162643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 301}], {
             RGBColor[
             0.5600378521340631, 0.6477359283320324, 0.9611302663344606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 303}], {
             RGBColor[
             0.6572936958343352, 0.7201787013720731, 0.7087457742202985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 316}], {
             RGBColor[
             0.2892722721652168, 0.4201834648880345, 0.9398285868398532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 138}], {
             RGBColor[
             0.8960973222643052, 0.8276352756804537, 0.6248654310241664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 179}], {
             RGBColor[
             0.5840360505895659, 0.5648520638615654, 0.5999539562158254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 222}], {
             RGBColor[
             0.9612427410458375, 0.8768676545486382, 0.5242249097420688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 245}], {
             RGBColor[
             0.9483489121727597, 0.8685172880674621, 0.602737251551139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 294}], {
             RGBColor[
             0.9499347786898753, 0.8697000247193089, 0.600052793197893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 296}], {
             RGBColor[
             0.7526809942525694, 0.7142249895448038, 0.6113688770973924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 312}], {
             RGBColor[
             0.7395372312963631, 0.7035542906571821, 0.6103341519302896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 385}], {
             RGBColor[
             0.9585315805283856, 0.8757465200010246, 0.5691558557747555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 415}], {
             RGBColor[
             0.947790448656235, 0.868100786891238, 0.6036825846140026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 438}], {
             RGBColor[
             0.6768098451909637, 0.6518046863663931, 0.6056238856313972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 439}], {
             RGBColor[
             0.7938791369412646, 0.7474459292680824, 0.6147663681961599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 204}], {
             RGBColor[
             0.6007549174717954, 0.6656300979123015, 0.8947639975973782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 275}], {
             RGBColor[
             0.6032954260839367, 0.6644953914178828, 0.6938149829665697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 276}], {
             RGBColor[
             0.2941575864407113, 0.42043172182353405`, 0.9402857176260535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 306}], {
             RGBColor[
             0.5941475346136502, 0.6337891665734422, 0.6453724825216306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 331}], {
             RGBColor[
             0.6012199362648365, 0.6658223951336619, 0.8870574327666294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 346}], {
             RGBColor[
             0.5296079654008821, 0.6108170542179256, 0.9603015368356941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 348}], {
             RGBColor[
             0.42906370005939964`, 0.5320658922297246, 0.9503346825840235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 355}], {
             RGBColor[
             0.24850532717960577`, 0.3785252333865062, 0.9374633828009677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 431}], {
             RGBColor[
             0.6036459210471627, 0.6652450647037464, 0.7319641967095294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 444}], {
             RGBColor[
             0.31454301807589935`, 0.4380885581043484, 0.9415846593037183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 486}], {
             RGBColor[
             0.5279928436026333, 0.6095291999373154, 0.9601474850767409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 175}], {
             RGBColor[
             0.6938530020675666, 0.2765920818316785, 0.42604479640395854`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 182}], {
             RGBColor[
             0.8672847644997947, 0.38977633379079646`, 0.21852597341298213`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 208}], {
             RGBColor[
             0.8587301778494387, 0.4080615185786842, 0.4374188315162526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 238}], {
             RGBColor[
             0.8526904832113609, 0.3341333908764013, 0.19522898673629963`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 241}], {
             RGBColor[
             0.644536063428389, 0.23327366805585842`, 0.4229244273662516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 351}], {
             RGBColor[
             0.6211738280418199, 0.20871847741329774`, 0.4215939826223165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 371}], {
             RGBColor[
             0.6476144828017323, 0.2365092820003037, 0.42309973879545015`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 442}], {
             RGBColor[
             0.8643741966291691, 0.37995830492934124`, 0.2072189668502241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 483}], {
             RGBColor[
             0.6996147451039898, 0.2813855199785559, 0.4264663872562261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 186}], {
             RGBColor[
             0.9912788646836914, 0.9898443563188813, 0.7347902748572679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 234}], {
             RGBColor[
             0.9622172981299011, 0.9706725987824767, 0.918849700620422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 373}], {
             RGBColor[
             0.9224561439229518, 0.9389813507564886, 0.9155154896871355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 434}], {
             RGBColor[
             0.9705408679095504, 0.9768803034955444, 0.904760068118158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 449}], {
             RGBColor[
             0.6197616921354443, 0.6854304516015055, 0.8912302777495962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 495}], {
             RGBColor[
             0.8061509346745783, 0.8475461334836236, 0.9041934591532225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 250}], {
             RGBColor[
             0.6613488186830774, 0.3103101701131645, 0.4320826837659827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 356}], {
             RGBColor[
             0.6559145737491799, 0.30542730165264387`, 0.43174286265617223`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 365}], {
             RGBColor[
             0.8618826770716342, 0.4731713680346944, 0.44903025913616046`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 457}], {
             RGBColor[
             0.8548633958489873, 0.37622493156628034`, 0.19835032975156372`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 494}], {
             RGBColor[
             0.679286137470989, 0.32584657409139733`, 0.4332256338578002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 191}], {
             RGBColor[
             0.6966455629071959, 0.7097792629656268, 0.6187176346041492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 237}], {
             RGBColor[
             0.975612874836955, 0.9284905775830683, 0.43697628259585786`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 241}], {
             RGBColor[
             0.6281107997034199, 0.6495140553339129, 0.6143837541204035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 271}], {
             RGBColor[
             0.9478234405179078, 0.9105185654193753, 0.638797401271959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 304}], {
             RGBColor[
             0.863963136373891, 0.3785717021667502, 0.20562207538068406`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 311}], {
             RGBColor[
             0.8665926394807105, 0.8461729050128364, 0.6333658604197745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 351}], {
             RGBColor[
             0.5930674466235661, 0.6126812693700718, 0.6123880870045009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 366}], {
             RGBColor[
             0.7212612486783319, 0.7302325314998186, 0.6205258451479647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 371}], {
             RGBColor[
             0.6327284287634348, 0.6543674762505809, 0.6146467212642013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 405}], {
             RGBColor[
             0.9069356974889017, 0.8779853235822925, 0.6373082995891703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 423}], {
             RGBColor[
             0.9394736427881468, 0.9039301979449139, 0.6404117978587789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 429}], {
             RGBColor[
             0.8575676612554359, 0.839122523430877, 0.6324663349334958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 469}], {
             RGBColor[
             0.7659695699279426, 0.7665287607771725, 0.6240454479687111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 488}], {
             RGBColor[
             0.6128718846679522, 0.6334969894286179, 0.613515920453088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 174}], {
             RGBColor[
             0.6751751231107243, 0.7417966640601347, 0.9594225478437121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 210}], {
             RGBColor[
             0.6158462128044627, 0.6880441478962616, 0.9557287489078166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 225}], {
             RGBColor[
             0.8610539080706674, 0.40979455277291754`, 0.4334853623776187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 247}], {
             RGBColor[
             0.6237469572485845, 0.696348331243164, 0.9561786846158054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 252}], {
             RGBColor[
             0.7783960467787037, 0.8269941742939715, 0.9671621739048157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 278}], {
             RGBColor[
             0.9303755352905203, 0.8254236828573013, 0.6101271768068248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 309}], {
             RGBColor[
             0.8842844214258184, 0.910237696331488, 0.9773589583416329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 424}], {
             RGBColor[
             0.9689367571570414, 0.9684330704620892, 0.692573231056582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 169}], {
             RGBColor[
             0.9140269101049336, 0.7926024512273983, 0.6157267219964133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 211}], {
             RGBColor[
             0.9433711443797754, 0.9570833126763281, 0.9736845064039656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 362}], {
             RGBColor[
             0.696010113694632, 0.7605901981347591, 0.9719699678936695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 369}], {
             RGBColor[
             0.8222211554290733, 0.8619161612331421, 0.9826837151715373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 466}], {
             RGBColor[
             0.8993558179128434, 0.7259844481037534, 0.6034848030499558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 470}], {
             RGBColor[
             0.8541477246285679, 0.4045082257762207, 0.4404706932727722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 240}], {
             RGBColor[
             0.8193380779836215, 0.8591321887298273, 0.9825374512639196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 434}], {
             RGBColor[
             0.9074409850824272, 0.9285903250053127, 0.9756919398423751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 148}], {
             RGBColor[
             0.706636362744997, 0.28708598549979547`, 0.42701915471795915`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 156}], {
             RGBColor[
             0.8763656912885551, 0.41960361473641766`, 0.32223952292968894`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 227}], {
             RGBColor[
             0.8286778864324563, 0.3841992681589815, 0.4380413573684341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 229}], {
             RGBColor[
             0.875983809308845, 0.41991898161920915`, 0.3629711112528449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 263}], {
             RGBColor[
             0.8200444987692688, 0.3773152391834209, 0.4372178971460031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 265}], {
             RGBColor[
             0.8100544794441585, 0.3694812619111254, 0.43623006638374506`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 267}], {
             RGBColor[
             0.8212863018303977, 0.37830541923651906`, 0.43733634143054423`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 280}], {
             RGBColor[
             0.8578682933965857, 0.3546616828578565, 0.19939517435015722`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 393}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 424}], {
             RGBColor[
             0.8746625967006936, 0.4146634942018086, 0.24718745832676925`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 485}], {
             RGBColor[
             0.7740283069991141, 0.34133734218800504`, 0.43263931419814583`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 179}], {
             RGBColor[
             0.5494591150829448, 0.6296337755065059, 0.9617423028405772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 222}], {
             RGBColor[
             0.9266658055392164, 0.9416493661935788, 0.8860132563668205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 294}], {
             RGBColor[
             0.9153578431832543, 0.9344817363642494, 0.9618411398226447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 296}], {
             RGBColor[
             0.7181040587459482, 0.7790067011897444, 0.9731572237221441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 339}], {
             RGBColor[
             0.8320527955858947, 0.38689032910846477`, 0.43836325921630603`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 385}], {
             RGBColor[
             0.9239546450217644, 0.9405282316459651, 0.9309442023995071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 415}], {
             RGBColor[
             0.913213513149614, 0.9328824985361786, 0.9654709312387543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 438}], {
             RGBColor[
             0.6422329096843425, 0.7165863980113336, 0.9674122322561489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 158}], {
             RGBColor[
             0.9373549213791964, 0.7893401690431275, 0.2684525031539583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 247}], {
             RGBColor[
             0.6200647085839577, 0.6179949884113145, 0.6059254093796992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 278}], {
             RGBColor[
             0.9266932866258935, 0.7470703400254518, 0.25987390157071855`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 401}], {
             RGBColor[
             0.8585990756275829, 0.3575589908850179, 0.19998317888688122`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 410}], {
             RGBColor[
             0.8431361649585862, 0.8026151294528265, 0.6233715526797137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 428}], {
             RGBColor[
             0.9199264463239389, 0.8632404618096033, 0.630856467423135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 437}], {
             RGBColor[
             0.6947607295310059, 0.6835967678264323, 0.6106518797586598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 451}], {
             RGBColor[
             0.5990412194062282, 0.5958979683193184, 0.6047281527724926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 198}], {
             RGBColor[
             0.8722373860844727, 0.41813517236434894`, 0.41455465121845714`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 270}], {
             RGBColor[
             0.6749130051370963, 0.26018720844243, 0.42483795654753065`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 479}], {
             RGBColor[
             0.8318807792749092, 0.24332966199043837`, 0.17805565039885107`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 151}], {
             RGBColor[
             0.8749172497117169, 0.5100795540542606, 0.4443648616027639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 160}], {
             RGBColor[
             0.8863867023185696, 0.5184726058245481, 0.417747003608634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 162}], {
             RGBColor[
             0.7184499411343216, 0.3857666064451054, 0.4393387882226608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 167}], {
             RGBColor[
             0.8640515353201427, 0.42740768086176606`, 0.2063528372969732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 235}], {
             RGBColor[
             0.8167229095239187, 0.46417755548237655`, 0.44801288044033893`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 274}], {
             RGBColor[
             0.8302782870190946, 0.23373775882454273`, 0.17662782788490622`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 284}], {
             RGBColor[
             0.8750938156009124, 0.5102112366053225, 0.44406598160811506`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 300}], {
             RGBColor[
             0.6991652128626464, 0.3695793275842062, 0.4379673593539145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 345}], {
             RGBColor[
             0.8596754645851885, 0.4981932706971178, 0.45217169356463927`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 389}], {
             RGBColor[
             0.8892088664590829, 0.5189660220575848, 0.3220112926573724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 432}], {
             RGBColor[
             0.8302782870190946, 0.23373775882454273`, 0.17662782788490622`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 456}], {
             RGBColor[
             0.757156446866629, 0.4171902915068046, 0.44238590614051043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 472}], {
             RGBColor[
             0.849397307244682, 0.48999774702694654`, 0.4511913537420824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 161}], {
             RGBColor[
             0.8008528010825335, 0.3622928408396782, 0.4353129290792316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 183}], {
             RGBColor[
             0.6490013594383676, 0.23774384329537174`, 0.4231868893963763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 254}], {
             RGBColor[
             0.8465798531156105, 0.30990677879352013`, 0.19031223032633562`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 285}], {
             RGBColor[
             0.8716637779873613, 0.40454777452562063`, 0.23553761390486924`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 388}], {
             RGBColor[
             0.87623643642312, 0.42002344942318254`, 0.35878442619129436`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 396}], {
             RGBColor[
             0.633046620345298, 0.22119753490276367`, 0.4222701205797774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 473}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 477}], {
             RGBColor[
             0.6296325567484244, 0.21760913759831518`, 0.42207569470858985`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 165}], {
             RGBColor[
             0.6128790434312048, 0.6867260531670424, 0.9658802058549885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 178}], {
             RGBColor[
             0.9438920124318041, 0.8979983221012086, 0.6357334024494209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 186}], {
             RGBColor[
             0.9655307568437015, 0.9713111641935497, 0.808365842973825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 277}], {
             RGBColor[
             0.6972030935877275, 0.7614676498032206, 0.9712192394979218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 288}], {
             RGBColor[
             0.767910819980478, 0.8188713674356295, 0.9767856107304953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 313}], {
             RGBColor[
             0.9259241341936257, 0.8267616723273141, 0.6212760258586738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 321}], {
             RGBColor[
             0.9207814691436944, 0.9396436606978524, 0.9913872033396327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 373}], {
             RGBColor[
             0.896708036082962, 0.920448158631157, 0.9890910578036927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 386}], {
             RGBColor[
             0.9141971773339573, 0.934393525134608, 0.9907591877089532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 414}], {
             RGBColor[
             0.9390001528758138, 0.9540269944096402, 0.9881410092598095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 498}], {
             RGBColor[
             0.9328309112281944, 0.8541447417223695, 0.6268333807835815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 145}], {
             RGBColor[
             0.8714653296827535, 0.8634058015965719, 0.6534579873706815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 215}], {
             RGBColor[
             0.5909285919087475, 0.675474495179094, 0.9626827307142585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 246}], {
             RGBColor[
             0.671643758643034, 0.7422729002990294, 0.9686859652071018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 375}], {
             RGBColor[
             0.8137595315298665, 0.8546947839316693, 0.9820025047134087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 402}], {
             RGBColor[
             0.6049299974848685, 0.6876018089580239, 0.9635748878966119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 417}], {
             RGBColor[
             0.8033191829475939, 0.36421959709785984`, 0.43555875497389185`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 458}], {
             RGBColor[
             0.5823269492619052, 0.6680241846495292, 0.9621346416509355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 367}], {
             RGBColor[
             0.9005355585266559, 0.8862246068553006, 0.656326531676374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 375}], {
             RGBColor[
             0.9099053123698384, 0.8936957942346617, 0.6572202271624148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 402}], {
             RGBColor[
             0.7010757783248404, 0.7266028192610163, 0.6387926103456181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 417}], {
             RGBColor[
             0.8674163701742418, 0.3902202706331881, 0.21903723660656255`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 450}], {
             RGBColor[
             0.6584204394455455, 0.6896569086434403, 0.6360746498708645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 458}], {
             RGBColor[
             0.6784727301018771, 0.7070251949525217, 0.6373523640999417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 461}], {
             RGBColor[
             0.9379566405989879, 0.9160631619315649, 0.6598957878906273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 166}], {
             RGBColor[
             0.5758451444541747, 0.4900077020161404, 0.5834276841643418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 239}], {
             RGBColor[
             0.7572794308716941, 0.646660378422895, 0.5961319027849987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 248}], {
             RGBColor[
             0.640746806311127, 0.5504201272399387, 0.5874094561645493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 387}], {
             RGBColor[
             0.8547930714667679, 0.3907723609342786, 0.19887379424265894`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 221}], {
             RGBColor[
             0.5242509781451499, 0.6075973243450479, 0.9596312442150234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 234}], {
             RGBColor[
             0.5791726897766809, 0.651377189339029, 0.9644114826494561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 242}], {
             RGBColor[
             0.3725342155416136, 0.4871940062615514, 0.9457740193699292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 303}], {
             RGBColor[
             0.6075499483342606, 0.6690852812656907, 0.7058693545582035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 323}], {
             RGBColor[
             0.6189239458001922, 0.20635370852657378`, 0.42146585515705837`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 449}], {
             RGBColor[
             0.23671708378222406`, 0.3661350421580578, 0.9367920597786301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 229}], {
             RGBColor[
             0.7392922580807629, 0.792253450678507, 0.8565493989562061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 232}], {
             RGBColor[
             0.7383154953479529, 0.7918495341868328, 0.8727368852197914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 263}], {
             RGBColor[
             0.6553832922713986, 0.7283478370248246, 0.9679195777959434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 267}], {
             RGBColor[
             0.6572459968630922, 0.7298331071044719, 0.9680972442227551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 280}], {
             RGBColor[
             0.7121189842123741, 0.694367502536478, 0.6111854936021746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 342}], {
             RGBColor[
             0.3842198948159572, 0.5039812969865785, 0.9460294374183273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 393}], {
             RGBColor[
             0.706636362744997, 0.2870859854997955, 0.42701915471795915`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 480}], {
             RGBColor[
             0.706636362744997, 0.2870859854997955, 0.42701915471795915`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 485}], {
             RGBColor[
             0.5863590046161666, 0.6743809915317008, 0.9610517033741575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 173}], {
             RGBColor[
             0.5975590725824819, 0.6702935844449665, 0.9631151028364819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 242}], {
             RGBColor[
             0.7309124253023875, 0.7887629605653491, 0.971956753856317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 249}], {
             RGBColor[
             0.8632787900278589, 0.8939980003017194, 0.9838990050552113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 269}], {
             RGBColor[
             0.8315989560491641, 0.8692494732219072, 0.9807414552690956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 282}], {
             RGBColor[
             0.9623941172260918, 0.9711907498688095, 0.9358487859212725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 310}], {
             RGBColor[
             0.9397258855563932, 0.9545682446545382, 0.9869125331329862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 314}], {
             RGBColor[
             0.9378085476745809, 0.9531382972016351, 0.9901580860450858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 323}], {
             RGBColor[
             0.8578427523073748, 0.40739967806243893`, 0.4389210114813168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 406}], {
             RGBColor[
             0.6164542539946491, 0.6901536181328505, 0.964191155464989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 411}], {
             RGBColor[
             0.8287538650291612, 0.8670268664935883, 0.980457883185109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 419}], {
             RGBColor[
             0.9633249310089038, 0.9715756652888253, 0.9204227926712268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 220}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 254}], {
             RGBColor[
             0.8465798531156105, 0.30990677879352013`, 0.19031223032633562`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 325}], {
             RGBColor[
             0.8743238320354785, 0.4192325383572021, 0.3904812305560025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 392}], {
             RGBColor[
             0.6996176845011868, 0.2813879063136187, 0.42646661865634083`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 412}], {
             RGBColor[
             0.7274892684453227, 0.3040153137600162, 0.4286607718413993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 426}], {
             RGBColor[
             0.6675143175567845, 0.2537788371292143, 0.4243665187173157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 473}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 160}], {
             RGBColor[
             0.9684400669881461, 0.975741963344585, 0.9275023141623782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 162}], {
             RGBColor[
             0.716534925211774, 0.7766829642754209, 0.9598899910834184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 226}], {
             RGBColor[
             0.8947338991663235, 0.9184998869999934, 0.9759308015618878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 235}], {
             RGBColor[
             0.8639443777961696, 0.8942993878313277, 0.9729011294099356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 237}], {
             RGBColor[
             0.972605114315052, 0.97633621717752, 0.7764757201016182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 274}], {
             RGBColor[
             0.8619579626926223, 0.410468795229718, 0.4319550337178577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 284}], {
             RGBColor[
             0.9515007369116601, 0.9633499095157467, 0.9669807811615998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 345}], {
             RGBColor[
             0.9283732103880743, 0.9453229606534395, 0.979139349096386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 389}], {
             RGBColor[
             0.9726733131989159, 0.97648208769414, 0.7838987477354857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 456}], {
             RGBColor[
             0.774594683810235, 0.8238184918679697, 0.9644606679601928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 472}], {
             RGBColor[
             0.9129559743773145, 0.9330296751481827, 0.9776688393625508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 195}], {
             RGBColor[
             0.6864204575047357, 0.7511907776534279, 0.9550889863452354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 216}], {
             RGBColor[
             0.6708950632635083, 0.7377434614906804, 0.9540997219527514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 217}], {
             RGBColor[
             0.6802866173725126, 0.7458779536266654, 0.954698143475952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 292}], {
             RGBColor[
             0.8870812295981856, 0.9123202827946597, 0.9724843783299975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 398}], {
             RGBColor[
             0.8807528036135824, 0.9073764683176688, 0.9718536199703556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 399}], {
             RGBColor[
             0.9735385263289145, 0.976216458130901, 0.7101578234356423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 464}], {
             RGBColor[
             0.7229601204075975, 0.781798896899757, 0.957704809927109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 481}], {
             RGBColor[
             0.7572922563691175, 0.8096712715184184, 0.9604075614327576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 496}], {
             RGBColor[
             0.6349207926381203, 0.7065843563943843, 0.9518074732393003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 172}], {
             RGBColor[
             0.6481675615951217, 0.703681473864523, 0.6703313964966598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 197}], {
             RGBColor[
             0.35526152741655126`, 0.48213141190983017`, 0.9438579282749169]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 201}], {
             RGBColor[
             0.6445563478348004, 0.7134626901847321, 0.9310041366046197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 223}], {
             RGBColor[
             0.6475013981032092, 0.7155994487001949, 0.923347455074528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 236}], {
             RGBColor[
             0.5454189996649951, 0.6358411844107299, 0.9598739780689052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 289}], {
             RGBColor[
             0.6387500445626224, 0.709132358711291, 0.9408326935179885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 314}], {
             RGBColor[
             0.6235892805713545, 0.697825485750076, 0.9664959123946764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 411}], {
             RGBColor[
             0.5145345979259348, 0.611714055042029, 0.9567957095346993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 466}], {
             RGBColor[
             0.5906790923278273, 0.47500881508152165`, 0.5774981067123632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 470}], {
             RGBColor[
             0.648363240905224, 0.2371911370947328, 0.4231462290477105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 493}], {
             RGBColor[
             0.563379941151674, 0.6498724084083345, 0.9616641568617563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 199}], {
             RGBColor[
             0.6861139896737447, 0.7467268874183647, 0.8406515246224642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[
             0.9893655985479199, 0.9898290015731157, 0.8240484625825499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 219}], {
             RGBColor[
             0.9001964822605517, 0.9200882656340124, 0.8586453723067089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 244}], {
             RGBColor[
             0.941682277507851, 0.9530516884193831, 0.862633166832704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 295}], {
             RGBColor[
             0.6613957922973681, 0.7253172272236711, 0.8390765029430851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 341}], {
             RGBColor[
             0.7068286789336446, 0.764668910104735, 0.8419714463048245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 374}], {
             RGBColor[
             0.8764754921988475, 0.4201223051298991, 0.3548226533309724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 376}], {
             RGBColor[
             0.9945577005984159, 0.9911935528413258, 0.6799654483882758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 397}], {
             RGBColor[
             0.8764754921988475, 0.4201223051298991, 0.3548226533309724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 455}], {
             RGBColor[
             0.6236283028863265, 0.6874016524653442, 0.8368605092525729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 198}], {
             RGBColor[
             0.8797173277504603, 0.9060753563960884, 0.946835820620141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 250}], {
             RGBColor[
             0.5497769338269086, 0.6397443160302954, 0.9600972710680793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 365}], {
             RGBColor[
             0.8505777214097441, 0.8840361129125903, 0.985518634123346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 394}], {
             RGBColor[
             0.8228184383140136, 0.6603774119734314, 0.5951213042548354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 467}], {
             RGBColor[
             0.873653880405358, 0.8681432001795395, 0.6580974554107051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 479}], {
             RGBColor[
             0.8331230576323193, 0.5831563892139201, 0.46330186332600576`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 198}], {
             RGBColor[
             0.9882666160595417, 0.98835418065115, 0.776755261222219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 227}], {
             RGBColor[
             0.9229273665815171, 0.9374503243430987, 0.8119853204471845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 250}], {
             RGBColor[
             0.65832622213599, 0.722023140285357, 0.7900167116701573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 263}], {
             RGBColor[
             0.9099772850867357, 0.927124280879758, 0.8107501301135381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 270}], {
             RGBColor[
             0.6922800446384769, 0.7514322347682716, 0.7921802192158294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 479}], {
             RGBColor[
             0.9054892498383735, 0.6380089387172945, 0.34991482372739113`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 485}], {
             RGBColor[
             0.8409529974315038, 0.873157435386634, 0.8038822556917522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 190}], {
             RGBColor[
             0.9256755126012088, 0.8144672313582757, 0.6123020812095663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 356}], {
             RGBColor[
             0.6248220024784323, 0.698206383227491, 0.9604132224122182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 360}], {
             RGBColor[
             0.9476536784864769, 0.9604807796412249, 0.9734928476019025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.9190618332333773, 0.850501689131971, 0.6280758244030951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 193}], {
             RGBColor[
             0.6863402929026224, 0.6645157034476737, 0.6072967104585848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 247}], {
             RGBColor[
             0.6162604030804055, 0.6029121847993884, 0.6028643758730139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 278}], {
             RGBColor[
             0.9228889811223413, 0.7319875364135257, 0.25681286806403325`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 370}], {
             RGBColor[
             0.9127489857829354, 0.6882486843021572, 0.24847101671678626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 401}], {
             RGBColor[
             0.8560628719585481, 0.34750378847706714`, 0.19794248988242436`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 410}], {
             RGBColor[
             0.8393318594550341, 0.7875323258409004, 0.6203105191730283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 422}], {
             RGBColor[
             0.8795230560917252, 0.8189745414907321, 0.6243045805426413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 428}], {
             RGBColor[
             0.9161221408203868, 0.8481576581976772, 0.6277954339164495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 437}], {
             RGBColor[
             0.6909564240274537, 0.6685139642145062, 0.6075908462519746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 451}], {
             RGBColor[
             0.5952369139026761, 0.5808151647073923, 0.6016671192658072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 166}], {
             RGBColor[
             0.29974079717519475`, 0.42984427815212845`, 0.9404739009420229]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 192}], {
             RGBColor[
             0.6304428326171407, 0.6024603244958012, 0.6004734801285869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 239}], {
             RGBColor[
             0.4811750835927141, 0.5864969545588831, 0.9531781195626797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 251}], {
             RGBColor[
             0.6656450528343036, 0.728802647598489, 0.8281152366216976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 272}], {
             RGBColor[
             0.6569257124602959, 0.24460751959340238`, 0.42369182216370327`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 344}], {
             RGBColor[
             0.6204951379733014, 0.6962681557077004, 0.9667130849646484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 435}], {
             RGBColor[
             0.3723242204741912, 0.4969102590404691, 0.9449451479886026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 439}], {
             RGBColor[
             0.4966115767462451, 0.5988034266404293, 0.9545475592420076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 453}], {
             RGBColor[
             0.6799615808787549, 0.421671298639586, 0.445750995776512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 167}], {
             RGBColor[
             0.9521414954007847, 0.851734153555843, 0.5704842777036921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 235}], {
             RGBColor[
             0.8811485567064488, 0.9068889654867588, 0.9329743424187407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 237}], {
             RGBColor[
             0.9898092932253312, 0.9889257948329511, 0.7365489331104234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 274}], {
             RGBColor[
             0.8734274152994751, 0.4188618470000054, 0.40533717572372774`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 284}], {
             RGBColor[
             0.9687049158219394, 0.9759394871711777, 0.927053994170405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 300}], {
             RGBColor[
             0.7048120117145404, 0.7649916236395033, 0.9179060607891041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 305}], {
             RGBColor[
             0.9690788096209066, 0.9188849604132443, 0.5841124382950643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 389}], {
             RGBColor[
             0.9898774921091951, 0.9890716653495712, 0.7439719607442908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 432}], {
             RGBColor[
             0.8734274152994751, 0.4188618470000054, 0.40533717572372774`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 460}], {
             RGBColor[
             0.986227631155713, 0.9885727857962219, 0.8779073237052759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 183}], {
             RGBColor[
             0.5401432407813516, 0.6318010262025751, 0.9593137277134117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 188}], {
             RGBColor[
             0.8433806707528477, 0.7672814589530708, 0.6155292524966884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 202}], {
             RGBColor[
             0.7736056575494794, 0.8230658863891955, 0.9780694402547838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 243}], {
             RGBColor[
             0.8201077612156529, 0.6658141548062412, 0.5963275215812777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 273}], {
             RGBColor[
             0.8667395357944753, 0.896229407138647, 0.96034357869228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 279}], {
             RGBColor[
             0.609979872797723, 0.6922900067639703, 0.963763656151386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 285}], {
             RGBColor[
             0.8741368686048423, 0.8820069230479484, 0.6778398144761513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 287}], {
             RGBColor[
             0.784235424899864, 0.83136994143254, 0.9791289161234465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 335}], {
             RGBColor[
             0.5919770703744713, 0.676696884152109, 0.9626165335002295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 354}], {
             RGBColor[
             0.8241412902328535, 0.8630327210553963, 0.9829768558404963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 396}], {
             RGBColor[
             0.5162111321417472, 0.6069815636136628, 0.9579385744885134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 409}], {
             RGBColor[
             0.8146505952363522, 0.4683487329378798, 0.44852571234330796`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 430}], {
             RGBColor[
             0.8567606835796728, 0.8887871954957183, 0.9772351725904564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 459}], {
             RGBColor[
             0.8366814674230405, 0.740721350127558, 0.6101389162470129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 477}], {
             RGBColor[
             0.5110900367464368, 0.6015989676569902, 0.9576469356817322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 226}], {
             RGBColor[
             0.6600329363002306, 0.7320304655862606, 0.9683916914917333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 284}], {
             RGBColor[
             0.7167997740455673, 0.7768804881020137, 0.9594416710914453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 345}], {
             RGBColor[
             0.6936722475219814, 0.7588535392397067, 0.9716002390262315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 389}], {
             RGBColor[
             0.737972350332823, 0.7900126662804072, 0.7763596376653312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 456}], {
             RGBColor[
             0.5398937209441421, 0.6373490704542368, 0.9569215578900383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 472}], {
             RGBColor[
             0.6782550115112216, 0.7465602537344498, 0.9701297292923963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 207}], {
             RGBColor[
             0.3829565883936436, 0.5023876023449556, 0.9459816959916891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 209}], {
             RGBColor[
             0.6376857288102132, 0.2260735320358549, 0.42253431094390836`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 231}], {
             RGBColor[
             0.49032241272790095`, 0.5886349347586649, 0.9550609399621017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 233}], {
             RGBColor[
             0.6297764829240536, 0.6977083901022443, 0.92799335128314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 266}], {
             RGBColor[
             0.27925500617192, 0.4108450956496826, 0.9392145315295065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 317}], {
             RGBColor[
             0.28079394391378154`, 0.41246261679066754`, 0.9393021717572512]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 326}], {
             RGBColor[
             0.5944791432668517, 0.6707348874385184, 0.9652480795595237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 343}], {
             RGBColor[
             0.5176322848402325, 0.6099696144155339, 0.957782932788994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 355}], {
             RGBColor[
             0.28079394391378154`, 0.41246261679066754`, 0.9393021717572512]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 379}], {
             RGBColor[
             0.41039814621949683`, 0.5246658952160754, 0.9481419959454787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 440}], {
             RGBColor[
             0.4909705590831239, 0.5891412716174599, 0.9551255411335183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 180}], {
             RGBColor[
             0.42673620629027575`, 0.535463120486328, 0.9496527266205759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 205}], {
             RGBColor[
             0.31761764453363306`, 0.44481547721767767`, 0.941631774978406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 259}], {
             RGBColor[
             0.6136747690749169, 0.6486249460915254, 0.6371074825899379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 316}], {
             RGBColor[
             0.2573594991230136, 0.3878315294859532, 0.9379676147945712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 331}], {
             RGBColor[
             0.6231968529418519, 0.6889215279782026, 0.8883089856594508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 348}], {
             RGBColor[
             0.45104061673641516`, 0.5551650250742651, 0.9515862354768448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 372}], {
             RGBColor[
             0.4466057548450175, 0.5515941151160291, 0.9512169302673597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 404}], {
             RGBColor[
             0.567454460568116, 0.4615856829048245, 0.5785824934884417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 418}], {
             RGBColor[
             0.6308112621054398, 0.21884803166277444`, 0.42214282023493366`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 431}], {
             RGBColor[
             0.6256228377241784, 0.6883441975482871, 0.7332157496023508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 444}], {
             RGBColor[
             0.3365199347529149, 0.461187690948889, 0.9428362121965397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 486}], {
             RGBColor[
             0.5499697602796487, 0.632628332781856, 0.9613990379695623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 178}], {
             RGBColor[
             0.6200442174359717, 0.6323928150522974, 0.6096244706581881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 185}], {
             RGBColor[
             0.6403970453245578, 0.7059911419676421, 0.8629729129352214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 277}], {
             RGBColor[
             0.373355298591895, 0.4958621427543094, 0.945110307706689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 288}], {
             RGBColor[
             0.44406302498464556`, 0.5532658603867183, 0.9506766789392624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 313}], {
             RGBColor[
             0.6020763391977932, 0.5611561652784031, 0.5951670940674411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 333}], {
             RGBColor[
             0.6038349966692584, 0.5681286561149006, 0.5965821511499784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 358}], {
             RGBColor[
             0.5812292938237766, 0.6615159070625635, 0.9637803737336228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 361}], {
             RGBColor[
             0.6394337853832011, 0.7055928092272397, 0.878936623000321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 386}], {
             RGBColor[
             0.590349382338125, 0.6687880180856969, 0.9646502559177205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 498}], {
             RGBColor[
             0.608983116232362, 0.5885392346734584, 0.6007244489923487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.44477674338702144`, 0.5507726739308044, 0.9510125540135927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 344}], {
             RGBColor[
             0.5840967977676086, 0.6605438750796218, 0.9645475194155613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 387}], {
             RGBColor[
             0.646457946476986, 0.3268472246062181, 0.4354608950617217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 435}], {
             RGBColor[
             0.33592588026849857`, 0.4611859784123904, 0.9427795824395155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 439}], {
             RGBColor[
             0.46021323654055246`, 0.5630791460123507, 0.9523819936929205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 453}], {
             RGBColor[
             0.6556960207416265, 0.3978551115542002, 0.44430728541045394`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 172}], {
             RGBColor[
             0.9522610726888578, 0.8395901512782586, 0.3265265670431947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[
             0.9486498589285366, 0.849371367598468, 0.5871993071511545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 218}], {
             RGBColor[
             0.9276827916650908, 0.8337341631638118, 0.6226910829412111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 235}], {
             RGBColor[
             0.8476458062088084, 0.7702915780425857, 0.6158830929512495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 236}], {
             RGBColor[
             0.8495125107587314, 0.7717498618244656, 0.6160691486154402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 274}], {
             RGBColor[
             0.8510922483010481, 0.3277969220372233, 0.193943009412067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 284}], {
             RGBColor[
             0.9352021653242989, 0.8393420997270047, 0.6099627447029139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 289}], {
             RGBColor[
             0.9428435556563588, 0.8450410361250267, 0.5970278640645232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 300}], {
             RGBColor[
             0.6713092612169, 0.6283942361953303, 0.600814811321613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 305}], {
             RGBColor[
             0.9355760591232662, 0.7822875729690713, 0.2670211888275732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 432}], {
             RGBColor[
             0.8510922483010481, 0.3277969220372233, 0.193943009412067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 456}], {
             RGBColor[
             0.7582961122228737, 0.6998106820792278, 0.6074426315015067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 493}], {
             RGBColor[
             0.8674734522454102, 0.7857810858220704, 0.6178593274082911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 181}], {
             RGBColor[
             0.5873130359027925, 0.663959619426302, 0.9647253356291069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 189}], {
             RGBColor[
             0.2969568768526412, 0.42805342380742856`, 0.9402737947440889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 232}], {
             RGBColor[
             0.6307064618376947, 0.6959341689470713, 0.8657713991925011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 280}], {
             RGBColor[
             0.6045099507021159, 0.5984521372967165, 0.6042200075748843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 302}], {
             RGBColor[
             0.6245966505997562, 0.6925683307520685, 0.9294423681925164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 326}], {
             RGBColor[
             0.5902960606587693, 0.6663382023946679, 0.9650098591933096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 338}], {
             RGBColor[
             0.6131445330454464, 0.6326046352510036, 0.6115881099419913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 346}], {
             RGBColor[
             0.5577134995269754, 0.6403577525782365, 0.9619021054257634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 370}], {
             RGBColor[
             0.5810001884523508, 0.5017066145964884, 0.5851205279427981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 383}], {
             RGBColor[
             0.5129726108594084, 0.605200612569069, 0.9574972102487445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 390}], {
             RGBColor[
             0.4130706564288171, 0.5258348892623292, 0.9484434729587143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 395}], {
             RGBColor[
             0.30245550055582676`, 0.4328160552902648, 0.940624162184214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 443}], {
             RGBColor[
             0.5760281362438697, 0.6549613467587179, 0.9636489718254899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 480}], {
             RGBColor[
             0.6348970070714917, 0.22314240867328783`, 0.4223754973664323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 211}], {
             RGBColor[
             0.9295928805990054, 0.8044150865750643, 0.5964351485820623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 236}], {
             RGBColor[
             0.840317461469241, 0.7341485913316979, 0.6086113165845946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 289}], {
             RGBColor[
             0.9336485063668685, 0.8074397656322589, 0.5895700320336777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 308}], {
             RGBColor[
             0.5696904037104678, 0.504303833333264, 0.5877034795167084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 362}], {
             RGBColor[
             0.6822318499138619, 0.6079219720334954, 0.5947206100717662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 369}], {
             RGBColor[
             0.8084428916483032, 0.7092479351318783, 0.6054343573496339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 456}], {
             RGBColor[
             0.7491010629333834, 0.6622094115864601, 0.5999847994706612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 470}], {
             RGBColor[
             0.8449622154413878, 0.3027294083753782, 0.1889711213915033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 214}], {
             RGBColor[
             0.9101579806891951, 0.9307913476043524, 0.9771494467269913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 223}], {
             RGBColor[
             0.9680347003291887, 0.9756212572080198, 0.9363216142262197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 268}], {
             RGBColor[
             0.855495699155939, 0.8876942153888208, 0.971805920782477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 466}], {
             RGBColor[
             0.9112123945538069, 0.7350306235893467, 0.5904722658640549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 491}], {
             RGBColor[
             0.9700447960317098, 0.9764524834381156, 0.9030091264745197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 192}], {
             RGBColor[
             0.9274325171035696, 0.8432336780281682, 0.6257521106501593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 208}], {
             RGBColor[
             0.9358355199510306, 0.9515229107904968, 0.9885086110415062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 219}], {
             RGBColor[
             0.867861497139153, 0.8975894408616343, 0.9872277560773777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 238}], {
             RGBColor[
             0.9267759779939139, 0.8406307192370726, 0.6252238438715768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 258}], {
             RGBColor[
             0.9110329310219858, 0.774677634509027, 0.6123736456602771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 272}], {
             RGBColor[
             0.8549188354512484, 0.40512308861498036`, 0.4405442425114182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 293}], {
             RGBColor[
             0.9339939482089106, 0.9501494696005206, 0.9916259116420809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 403}], {
             RGBColor[
             0.7265265500181979, 0.7853480763941612, 0.9743916004014691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 471}], {
             RGBColor[
             0.9427506513373574, 0.9566802044559308, 0.9768030973595725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 497}], {
             RGBColor[
             0.9398960403660794, 0.8926473945410986, 0.6357805540236663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 197}], {
             RGBColor[
             0.6929773662960012, 0.7424934744901547, 0.6731866376284454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 201}], {
             RGBColor[
             0.9822721867142502, 0.9738247527650566, 0.6603328459581482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 211}], {
             RGBColor[
             0.9724102576742093, 0.9664697422344208, 0.6770265194199014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 218}], {
             RGBColor[
             0.9613051194508044, 0.9581875483304005, 0.6958246217482049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 235}], {
             RGBColor[
             0.8812681339945219, 0.8947449632091744, 0.6890166317582433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 236}], {
             RGBColor[
             0.8831348385444449, 0.8962032469910544, 0.6892026874224337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 289}], {
             RGBColor[
             0.9764658834420723, 0.9694944212916154, 0.670161402871517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 300}], {
             RGBColor[
             0.7049315890026135, 0.752847621361919, 0.6739483501286067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 308}], {
             RGBColor[
             0.6125077807856717, 0.6663584889926204, 0.6682948503545476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 314}], {
             RGBColor[
             0.9613051194508044, 0.9581875483304005, 0.6958246217482049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 466}], {
             RGBColor[
             0.9283949312072772, 0.7353708776618462, 0.30682681606589174`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 470}], {
             RGBColor[
             0.8735071334915239, 0.4107658454816159, 0.24269870195006282`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 493}], {
             RGBColor[
             0.9010957800311238, 0.9102344709886591, 0.6909928662152849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 242}], {
             RGBColor[
             0.38958124096274493`, 0.5051115108229988, 0.9467448222488486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 249}], {
             RGBColor[
             0.5219476056882162, 0.610346550559369, 0.9586870734477428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 269}], {
             RGBColor[
             0.4902677717095214, 0.5855980234795568, 0.9555295236616271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 282}], {
             RGBColor[
             0.6210629328864492, 0.6875393001264591, 0.9106368543138041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 310}], {
             RGBColor[
             0.5983947012167505, 0.6709167949121878, 0.9617006015255178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 323}], {
             RGBColor[
             0.6302886294142798, 0.21829871156753872`, 0.42211305707633784`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 406}], {
             RGBColor[
             0.27512306965500655`, 0.40650216839050013`, 0.9389792238575205]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 419}], {
             RGBColor[
             0.6219937466692611, 0.687924215546475, 0.8952108610637584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 499}], {
             RGBColor[
             0.2641146914249929, 0.39493166489926307`, 0.9383523130027576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 210}], {
             RGBColor[
             0.3424976117031848, 0.46871115363764354`, 0.9431312096186726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 225}], {
             RGBColor[
             0.678821507336482, 0.2635725566005056, 0.4250870028515227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 252}], {
             RGBColor[
             0.5050474456774257, 0.6076611800353535, 0.9545646346156718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 309}], {
             RGBColor[
             0.6109358203245405, 0.69090470207287, 0.9647614190524889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 320}], {
             RGBColor[
             0.5793359526296358, 0.6662181512625098, 0.9616119706504154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 393}], {
             RGBColor[
             0.678821507336482, 0.2635725566005056, 0.4250870028515227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 424}], {
             RGBColor[
             0.6955881560557635, 0.7491000762034712, 0.679975691767438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 182}], {
             RGBColor[
             0.7070686498510421, 0.7312986234337125, 0.638420154725411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 208}], {
             RGBColor[
             0.6942367698755081, 0.7587264006155441, 0.9667594418803167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 351}], {
             RGBColor[
             0.33790224516407974`, 0.4597118388674644, 0.9430221685394126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 359}], {
             RGBColor[
             0.35192210906620386`, 0.47444760473930936`, 0.9438205790481085]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 371}], {
             RGBColor[
             0.3775632273039483, 0.5013980457479734, 0.945280802799113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 463}], {
             RGBColor[
             0.4532997133579424, 0.5668744607006588, 0.9501525524068308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 483}], {
             RGBColor[
             0.4555636207573346, 0.5687124027153516, 0.950330775490277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 178}], {
             RGBColor[
             0.9479055770636373, 0.9009916320320208, 0.6289394844330338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 244}], {
             RGBColor[
             0.9166650230549316, 0.9361543207633235, 0.9838178376429689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 261}], {
             RGBColor[
             0.7026952552747832, 0.7656613514335006, 0.9645417220580014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 262}], {
             RGBColor[
             0.8869874365909485, 0.9124902188935675, 0.9809871629525401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 299}], {
             RGBColor[
             0.942927727961054, 0.881256119110158, 0.6249341901999594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 313}], {
             RGBColor[
             0.9299376988254588, 0.8297549822581264, 0.6144821078422869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 328}], {
             RGBColor[
             0.9672146311317744, 0.9675763328474882, 0.6963960999981567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 376}], {
             RGBColor[
             0.9695404461454965, 0.9742961851852661, 0.8011501191985407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 391}], {
             RGBColor[
             0.6936082762895129, 0.7579893825584352, 0.963907802080799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 407}], {
             RGBColor[
             0.7072307841479939, 0.7693434980960204, 0.9648987755050902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 448}], {
             RGBColor[
             0.9310918341427242, 0.9476578683193746, 0.9851938797634889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 455}], {
             RGBColor[
             0.5986110484334071, 0.6705042848092846, 0.9580451800628379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 475}], {
             RGBColor[
             0.7712585911292561, 0.821324156223243, 0.9699392790122403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 478}], {
             RGBColor[
             0.8899090087285919, 0.9148198012121614, 0.9812658251111468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 482}], {
             RGBColor[
             0.9285231295016589, 0.9456096529642191, 0.9849488744217145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 194}], {
             RGBColor[
             0.6357931979617084, 0.6902268115045516, 0.6686217813669652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 290}], {
             RGBColor[
             0.2984549418949726, 0.4308461851977823, 0.9403145030608013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 297}], {
             RGBColor[
             0.4352735422026196, 0.5457945128728656, 0.9500152915564912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 412}], {
             RGBColor[
             0.41702741786891395`, 0.5309814871602293, 0.9485788898111862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 484}], {
             RGBColor[
             0.6406388231648579, 0.7051965884158382, 0.8356329759002744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 186}], {
             RGBColor[
             0.9726959308484684, 0.9169779260788047, 0.4521101077770246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 244}], {
             RGBColor[
             0.9198166324278653, 0.8788277727177662, 0.6343560204625556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 261}], {
             RGBColor[
             0.7058468646477167, 0.7083348033879433, 0.6150799048775879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 288}], {
             RGBColor[
             0.7750759939852448, 0.7645381293208845, 0.6205298755336948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 313}], {
             RGBColor[
             0.9330893081983925, 0.7724284342125691, 0.2650202906618734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 321}], {
             RGBColor[
             0.9279466431484612, 0.8853104225831074, 0.6351314681428323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 391}], {
             RGBColor[
             0.6967598856624466, 0.700662834512878, 0.6144459849003856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 407}], {
             RGBColor[
             0.7103823935209276, 0.7120169500504632, 0.6154369583246768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 455}], {
             RGBColor[
             0.6017626578063408, 0.6131777367637273, 0.6085833628824244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 475}], {
             RGBColor[
             0.7744102005021898, 0.7639976081776858, 0.6204774618318268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 498}], {
             RGBColor[
             0.9399960852329612, 0.7998115036076245, 0.2705776455867811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 222}], {
             RGBColor[
             0.6146045338644772, 0.6788661543746903, 0.8611017815584795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 245}], {
             RGBColor[
             0.6017107049913992, 0.6705157878935142, 0.9396141233675497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 255}], {
             RGBColor[
             0.5806897804816702, 0.6545362603616207, 0.9647211115862517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 294}], {
             RGBColor[
             0.603296571508515, 0.671698524545361, 0.9369296650143037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 296}], {
             RGBColor[
             0.406042787071209, 0.5162234893708559, 0.9482457489138031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 312}], {
             RGBColor[
             0.39289902411500277`, 0.5055527904832343, 0.9472110237467004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 327}], {
             RGBColor[
             0.4105381379501194, 0.5198730177276047, 0.9485996394020038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 334}], {
             RGBColor[
             0.5381336133001766, 0.6206031278074828, 0.960662066370142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 385}], {
             RGBColor[
             0.6118933733470251, 0.6777450198270768, 0.9060327275911662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 415}], {
             RGBColor[
             0.6011522414748747, 0.6700992867172902, 0.9405594564304133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 438}], {
             RGBColor[
             0.33017163800960325`, 0.4538031861924453, 0.9425007574478079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 205}], {
             RGBColor[
             0.4865580645075895, 0.5919885027156824, 0.953292040894181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 230}], {
             RGBColor[
             0.7834572633226172, 0.8303529998494379, 0.9474419521105139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 331}], {
             RGBColor[
             0.7921372729158084, 0.8360945534762072, 0.8999692515752258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 382}], {
             RGBColor[
             0.7292434199965933, 0.7880408031625987, 0.9740448975166154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 413}], {
             RGBColor[
             0.4236392854951955, 0.5322080603745792, 0.9494763615627798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 418}], {
             RGBColor[
             0.743438208754744, 0.3169633819947776, 0.42991633084545033`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 474}], {
             RGBColor[
             0.7944013130118202, 0.8351708397373843, 0.7272493358195358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 490}], {
             RGBColor[
             0.42407237772017137`, 0.5326632677626619, 0.9495010255242897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 189}], {
             RGBColor[
             0.6142168915409589, 0.690839817213867, 0.966308638273899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 302}], {
             RGBColor[
             0.941856665288074, 0.955354724158507, 0.9554772117223265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 370}], {
             RGBColor[
             0.8982602031406685, 0.7644930080029269, 0.6111553714726082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 390}], {
             RGBColor[
             0.7303306711171348, 0.7886212826687677, 0.9744783164885245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 422}], {
             RGBColor[
             0.8650342734494583, 0.8952188651915016, 0.9869889352984632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 443}], {
             RGBColor[
             0.8932881509321875, 0.9177477401651564, 0.9896838153553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 451}], {
             RGBColor[
             0.580748131260409, 0.6570594884081618, 0.9643514740216292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 237}], {
             RGBColor[
             0.9805953170258107, 0.9452975250191378, 0.45633212964430503`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 351}], {
             RGBColor[
             0.5980498888124219, 0.6294882168061413, 0.631743934052948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 359}], {
             RGBColor[
             0.612069752714546, 0.6442239826779863, 0.632542344561644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 371}], {
             RGBColor[
             0.6377108709522905, 0.6711744236866504, 0.6340025683126485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 460}], {
             RGBColor[
             0.9770136549561925, 0.9449445159824086, 0.5976905202391576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 463}], {
             RGBColor[
             0.7134473570062846, 0.7366508386393358, 0.6388743179203662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 483}], {
             RGBColor[
             0.7157112644056768, 0.7384887806540286, 0.6390525410038124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 202}], {
             RGBColor[
             0.5458284950832304, 0.6362423900727359, 0.959880380730501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 206}], {
             RGBColor[
             0.5491420312906214, 0.6388309497417576, 0.9602106430528972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 243}], {
             RGBColor[
             0.5923305987494039, 0.47899065848978145`, 0.5781384620569947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 273}], {
             RGBColor[
             0.6389623733282263, 0.7094059108221873, 0.942154519167997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 279}], {
             RGBColor[
             0.38220271033147407`, 0.5054665104475107, 0.945574596627103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 283}], {
             RGBColor[
             0.6346469572081237, 0.70618748054566, 0.9494593930185475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 285}], {
             RGBColor[
             0.6463597061385933, 0.6951834267314886, 0.6596507549518682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 396}], {
             RGBColor[
             0.28843396967549817`, 0.4201580672972032, 0.9397495149642305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 430}], {
             RGBColor[
             0.6289835211134238, 0.7019636991792586, 0.9590461130661734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 477}], {
             RGBColor[
             0.28331287428018787`, 0.4147754713405304, 0.9394578761574492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 221}], {
             RGBColor[
             0.8214134169595105, 0.3858334929273426, 0.43827797713459477`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 253}], {
             RGBColor[
             0.8499104256715097, 0.32712362247902416`, 0.19315700382735868`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 287}], {
             RGBColor[
             0.8128075261803118, 0.37907610533923275`, 0.4374293511513702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 301}], {
             RGBColor[
             0.8121088346187362, 0.37853028218107737`, 0.4373597121061562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 316}], {
             RGBColor[
             0.6315984479728387, 0.22682863988507873`, 0.42315859244308457`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 336}], {
             RGBColor[
             0.7834068011496408, 0.3561080354914863, 0.4344989616457094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 354}], {
             RGBColor[
             0.8394114364023049, 0.40018462508780367`, 0.4399946442960701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 388}], {
             RGBColor[
             0.8773144804193893, 0.42830976798040027`, 0.3598167623395985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 436}], {
             RGBColor[
             0.7587562243325445, 0.33681035098529144`, 0.43206968971938714`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 473}], {
             RGBColor[
             0.8183970439962693, 0.14241331855721773`, 0.1652503361483041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 187}], {
             RGBColor[
             0.8415885340351261, 0.8748595265448915, 0.8780259591364572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 216}], {
             RGBColor[
             0.6896394590242023, 0.7504652092030046, 0.8660438556926142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 224}], {
             RGBColor[
             0.6852266485963909, 0.7466430546047356, 0.8657626753142491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 286}], {
             RGBColor[
             0.9876114295846885, 0.9733653163075572, 0.5882101351516902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 330}], {
             RGBColor[
             0.9768114211965031, 0.9809687844580706, 0.8678099011924059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 333}], {
             RGBColor[
             0.9552007935584437, 0.8529992519644114, 0.519783790021444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 357}], {
             RGBColor[
             0.9889992495768465, 0.9897189212407049, 0.8319744337485475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 358}], {
             RGBColor[
             0.9325950907129621, 0.9463865029120744, 0.8869820126050885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 361}], {
             RGBColor[
             0.9907995822723863, 0.9904634050767506, 0.8021382618717867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 386}], {
             RGBColor[
             0.9417151792273102, 0.9536586139352077, 0.8878518947891861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 398}], {
             RGBColor[
             0.8994971993742764, 0.9200982160299931, 0.8837977537102184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 441}], {
             RGBColor[
             0.9837314195691722, 0.9602771314555457, 0.5731370289198198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 464}], {
             RGBColor[
             0.7417045161682916, 0.7945206446120813, 0.8696489436669719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 481}], {
             RGBColor[
             0.7760366521298114, 0.8223930192307427, 0.8723516951726205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 288}], {
             RGBColor[
             0.7967147383971422, 0.8378509714132256, 0.793162316058099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 295}], {
             RGBColor[
             0.6611688916292797, 0.7244061536143953, 0.7834317970973408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 321}], {
             RGBColor[
             0.9495853875603586, 0.9586232646754487, 0.8077639086672364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 341}], {
             RGBColor[
             0.7066017782655563, 0.7637578364954594, 0.7863267404590801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 373}], {
             RGBColor[
             0.9255119544996262, 0.9394277626087532, 0.8054677631312963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 397}], {
             RGBColor[
             0.8763242250867886, 0.4195149227237154, 0.31772618276714293`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 455}], {
             RGBColor[
             0.6234014022182381, 0.6864905788560686, 0.7812158034068286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 495}], {
             RGBColor[
             0.8092067452512527, 0.8479925453358881, 0.7941457325973833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 498}], {
             RGBColor[
             0.9616348296448587, 0.8731243456999658, 0.44321008611118523`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 216}], {
             RGBColor[
             0.5394651508455853, 0.6344629979307432, 0.9578952630223845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 224}], {
             RGBColor[
             0.5350523404177739, 0.6306408433324742, 0.9576140826440194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 260}], {
             RGBColor[
             0.6060649938945504, 0.6903184273220411, 0.962644582585849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 328}], {
             RGBColor[
             0.8405447602146771, 0.8678459004450142, 0.6921341324245467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 398}], {
             RGBColor[
             0.7493228911956594, 0.8040960047577317, 0.9756491610399884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 399}], {
             RGBColor[
             0.8421086139109915, 0.8729359945709637, 0.7139533645052751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 407}], {
             RGBColor[
             0.5805609132308966, 0.6696130656935464, 0.9606368079314802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 464}], {
             RGBColor[
             0.5915302079896745, 0.6785184333398198, 0.9615003509967419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 478}], {
             RGBColor[
             0.7632391378114947, 0.8150893688096874, 0.9770038575375368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 481}], {
             RGBColor[
             0.6258623439511944, 0.7063908079584813, 0.9642031025023907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 200}], {
             RGBColor[
             0.9181028004647745, 0.8264420462368267, 0.6227679861470146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 228}], {
             RGBColor[
             0.9263565636442077, 0.7457353456093492, 0.25960296635574986`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 256}], {
             RGBColor[
             0.9566371763942694, 0.853220178436439, 0.4445227131284833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 279}], {
             RGBColor[
             0.6854401403029702, 0.6409469431980064, 0.6017901214103797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 298}], {
             RGBColor[
             0.7636990041031484, 0.7045157329057308, 0.6079413530007274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 318}], {
             RGBColor[
             0.6017474654303233, 0.5662290840454471, 0.5965388567876642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 335}], {
             RGBColor[
             0.6674373378797184, 0.6253538205861451, 0.6006429987592232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 409}], {
             RGBColor[
             0.8649574402398503, 0.4341200238939038, 0.20721002251597043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 430}], {
             RGBColor[
             0.93222095108492, 0.8374441319297543, 0.6152616378494501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 459}], {
             RGBColor[
             0.9121417349282877, 0.6893782865615941, 0.24816538150600656`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 302}], {
             RGBColor[
             0.6515005062379227, 0.7194485285396335, 0.9310256708373086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 346}], {
             RGBColor[
             0.5846173551651417, 0.6672379503658015, 0.9634854080705555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 370}], {
             RGBColor[
             0.6079040440905171, 0.5285868123840534, 0.5867038305875903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 383}], {
             RGBColor[
             0.5398764664975747, 0.632080810356634, 0.9590805128935366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 390}], {
             RGBColor[
             0.43997451206698346`, 0.5527150870498942, 0.9500267756035066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 422}], {
             RGBColor[
             0.5746781143993069, 0.6593126695726281, 0.9625373944134452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 443}], {
             RGBColor[
             0.6029319918820362, 0.681841544546283, 0.9652322744702821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 451}], {
             RGBColor[
             0.2903919722102577, 0.42115329278928837`, 0.9398999331366114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 349}], {
             RGBColor[
             0.9507918323100419, 0.8315718007811852, 0.4969200187084627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 378}], {
             RGBColor[
             0.9258324897270183, 0.8145843046416779, 0.6120363598817626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 467}], {
             RGBColor[
             0.9387724597066944, 0.7908248659507089, 0.2911301660265061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 487}], {
             RGBColor[
             0.6137166220852354, 0.5614048856327964, 0.593054863789072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 226}], {
             RGBColor[
             0.6371358134737495, 0.712972403870918, 0.9667187725182245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 237}], {
             RGBColor[
             0.715007028622478, 0.7708087340484444, 0.7672636910579549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 271}], {
             RGBColor[
             0.6872175943034309, 0.7528367218847515, 0.969084809734056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 311}], {
             RGBColor[
             0.6059867932662335, 0.6884910614782126, 0.9636532688818715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 366}], {
             RGBColor[
             0.46065540246385495`, 0.5725506879651947, 0.9508132536100617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 405}], {
             RGBColor[
             0.6463298512744247, 0.7203034800476686, 0.9675957080512673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 423}], {
             RGBColor[
             0.6788677965736698, 0.7462483544102901, 0.9706992063208759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 429}], {
             RGBColor[
             0.596961815040959, 0.6814406798962531, 0.9627537433955928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 488}], {
             RGBColor[
             0.3522660384534752, 0.47581514589399404`, 0.943803328915185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 219}], {
             RGBColor[
             0.8651755078889775, 0.7937078530448614, 0.6197831391932822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 251}], {
             RGBColor[
             0.9599487480705569, 0.8656944133140831, 0.4859492502591747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 258}], {
             RGBColor[
             0.9083469417718103, 0.6707960466922542, 0.24492902877618172`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 272}], {
             RGBColor[
             0.8531281759511313, 0.3358686967371318, 0.195581164588688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 435}], {
             RGBColor[
             0.6666279157104444, 0.6338020247560632, 0.6027791616260796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 453}], {
             RGBColor[
             0.8761640443695905, 0.5129324757833155, 0.21764033820149667`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 497}], {
             RGBColor[
             0.9372100511159038, 0.788765806724326, 0.26833593713957093`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 410}], {
             RGBColor[
             0.5921215364820123, 0.6777906638573727, 0.9622157599843402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 428}], {
             RGBColor[
             0.6689118178473651, 0.7384159962141496, 0.9697006747277614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 437}], {
             RGBColor[
             0.4437461010544319, 0.5587723022309785, 0.9494960870632863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 220}], {
             RGBColor[
             0.8733331218405189, 0.41017886332289777`, 0.24202269954525185`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 254}], {
             RGBColor[
             0.9452314624341942, 0.8118744631746269, 0.3200663948073812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 290}], {
             RGBColor[
             0.6480231094548211, 0.702901963661924, 0.6693248203295918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 297}], {
             RGBColor[
             0.7848417097624681, 0.8178502913370073, 0.6790256088252817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 350}], {
             RGBColor[
             0.8832507041356967, 0.4864097467559071, 0.25151978755142124`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 377}], {
             RGBColor[
             0.984065080633495, 0.9579099166590945, 0.3925962766284956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 412}], {
             RGBColor[
             0.7665955854287625, 0.8030372656243709, 0.6775892070799767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 426}], {
             RGBColor[
             0.6766331590959551, 0.727682550678168, 0.6711478273938514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 476}], {
             RGBColor[
             0.9902149815714352, 0.9770715719294865, 0.5511287833412719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.6712742909361256, 0.7395926349749876, 0.9702515417518882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 260}], {
             RGBColor[
             0.469641313124854, 0.5793714261429019, 0.9516517435344899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 292}], {
             RGBColor[
             0.6192276364105662, 0.6980928180555833, 0.9652870803482715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 399}], {
             RGBColor[
             0.7056849331412951, 0.7619889933918245, 0.7029605254539162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 446}], {
             RGBColor[
             0.41644831535102356`, 0.535128332281289, 0.9477566962967492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 496}], {
             RGBColor[
             0.3670671994505009, 0.49235689165530794`, 0.9446101752575742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 213}], {
             RGBColor[
             0.8626892164882423, 0.7632010389101105, 0.6132099366755402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 332}], {
             RGBColor[
             0.7471097171067448, 0.6720678368988624, 0.6022654716017883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 337}], {
             RGBColor[
             0.7719838675824369, 0.6922617928227384, 0.6042236558442502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 420}], {
             RGBColor[
             0.9504317182882136, 0.8289562206645792, 0.4194921805648101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 427}], {
             RGBColor[
             0.9460522604124044, 0.8151457449769124, 0.32063781617244075`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 447}], {
             RGBColor[
             0.5815144199973391, 0.5274229978400413, 0.590885616613478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 454}], {
             RGBColor[
             0.5952751301834793, 0.5418863767250925, 0.5916692687014323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 489}], {
             RGBColor[
             0.9363108885885725, 0.8211168345298486, 0.5933043342915942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 500}], {
             RGBColor[
             0.7510034268732048, 0.6752289258969006, 0.6025719986977329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 201}], {
             RGBColor[
             0.6893661525356798, 0.7522746908103639, 0.9338593777364053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 236}], {
             RGBColor[
             0.5902288043658745, 0.6746531850363616, 0.9627292192006908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 289}], {
             RGBColor[
             0.683559849263502, 0.7479443593369227, 0.943687934649774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 314}], {
             RGBColor[
             0.6683990852722341, 0.7366374863757077, 0.9693511535264618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 411}], {
             RGBColor[
             0.5593444026268143, 0.6505260556676609, 0.9596509506664849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 466}], {
             RGBColor[
             0.6354888970287068, 0.5138208157071534, 0.5803533478441487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 470}], {
             RGBColor[
             0.6782364440391435, 0.26306580417848735`, 0.42504972313556744`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 493}], {
             RGBColor[
             0.6081897458525535, 0.6886844090339663, 0.9645193979935418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 270}], {
             RGBColor[
             0.6860875868323534, 0.7492295712101684, 0.9306529116489817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 479}], {
             RGBColor[
             0.9013609446342911, 0.6365404963452257, 0.44222995201615933`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 244}], {
             RGBColor[
             0.6330077905850533, 0.7076656604480505, 0.9672527314622508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 245}], {
             RGBColor[
             0.6717315346627699, 0.7377609357732214, 0.9438342539774371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 262}], {
             RGBColor[
             0.60333020412107, 0.6840015585782946, 0.9644220567718219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 376}], {
             RGBColor[
             0.6858832136756181, 0.7458075248699931, 0.7845850130178226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 448}], {
             RGBColor[
             0.6474346016728458, 0.7191692080041016, 0.9686287735827708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 455}], {
             RGBColor[
             0.31495381596352867`, 0.44201562449401155`, 0.9414800738821197]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 475}], {
             RGBColor[
             0.4876013586593777, 0.59283549590797, 0.9533741728315221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 482}], {
             RGBColor[
             0.6448658970317807, 0.7171209926489461, 0.9683837682409964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 228}], {
             RGBColor[
             0.9256184258508875, 0.8562389964590691, 0.6288152347470823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 256}], {
             RGBColor[
             0.9558990386009492, 0.963723829286159, 0.8137349815198158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 298}], {
             RGBColor[
             0.7629608663098282, 0.8150193837554507, 0.97715362139206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 452}], {
             RGBColor[
             0.9544980135121521, 0.9638765327146966, 0.890166867376915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 468}], {
             RGBColor[
             0.5871439373005811, 0.6621593305350648, 0.9649615117113444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 218}], {
             RGBColor[
             0.9576939056904832, 0.9679687646506097, 0.9564973618561647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 235}], {
             RGBColor[
             0.8776569202342006, 0.9045261795293837, 0.9496893718662032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 236}], {
             RGBColor[
             0.8795236247841236, 0.9059844633112636, 0.9498754275303936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 289}], {
             RGBColor[
             0.972854669681751, 0.9792756376118247, 0.9308341429794769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 300}], {
             RGBColor[
             0.7013203752422923, 0.7626288376821282, 0.9346210902365665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 305}], {
             RGBColor[
             0.9655871731486585, 0.9165221744558693, 0.6008274677425267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 314}], {
             RGBColor[
             0.9576939056904832, 0.9679687646506097, 0.9564973618561647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 406}], {
             RGBColor[
             0.6363396120105514, 0.704984085581825, 0.9305304312760678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 493}], {
             RGBColor[
             0.8974845662708025, 0.9200156873088683, 0.9516656063232447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 243}], {
             RGBColor[
             0.8257930155175317, 0.6702555186764021, 0.5968941745983668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 273}], {
             RGBColor[
             0.8724247900963542, 0.9006707710088079, 0.9609102317093692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 279}], {
             RGBColor[
             0.615665127099602, 0.6967313706341313, 0.9643303091684752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 283}], {
             RGBColor[
             0.8681093739762515, 0.8974523407322808, 0.9682151055599196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 285}], {
             RGBColor[
             0.8798221229067211, 0.8864482869181092, 0.6784064674932404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 396}], {
             RGBColor[
             0.5218963864436261, 0.6114229274838238, 0.9585052275056026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 421}], {
             RGBColor[
             0.8022062538074148, 0.8454504148324132, 0.9809090608710894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 430}], {
             RGBColor[
             0.8624459378815518, 0.8932285593658791, 0.9778018256075456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 459}], {
             RGBColor[
             0.8423667217249193, 0.7451627139977189, 0.610705569264102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 477}], {
             RGBColor[
             0.5167752910483158, 0.606040331527151, 0.9582135886988215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 264}], {
             RGBColor[
             0.6265907883775947, 0.6939312873919434, 0.9253545458907686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 281}], {
             RGBColor[
             0.7925527690604282, 0.8373175855174243, 0.9369049253943816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 295}], {
             RGBColor[
             0.6559729142487456, 0.7230333134070894, 0.9270930055327178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 324}], {
             RGBColor[
             0.7206755472746564, 0.7789644188397937, 0.9312464872004669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 341}], {
             RGBColor[
             0.7014058008850221, 0.7623849962881533, 0.9299879488944571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 374}], {
             RGBColor[
             0.8728602401664325, 0.4185996959188447, 0.41350032172406087`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 397}], {
             RGBColor[
             0.8728602401664325, 0.4185996959188447, 0.41350032172406087`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 275}], {
             RGBColor[
             0.990208390593444, 0.9880336600309425, 0.6530896256447898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 306}], {
             RGBColor[
             0.9810604991231573, 0.9573274351865018, 0.6046471251998506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 331}], {
             RGBColor[
             0.9881329007743436, 0.9893606637467214, 0.8463320754448496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 346}], {
             RGBColor[
             0.9165209299103892, 0.9343553228309852, 0.9195761795139141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 348}], {
             RGBColor[
             0.8159766645689068, 0.855604160842784, 0.9096093252622436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 355}], {
             RGBColor[
             0.635418291689113, 0.7020635019995658, 0.8967380254791878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 390}], {
             RGBColor[
             0.771878086812231, 0.8198324595150781, 0.9061175470468652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 431}], {
             RGBColor[
             0.9905588855566699, 0.988783333316806, 0.6912388393877495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 444}], {
             RGBColor[
             0.7014559825854065, 0.761626826717408, 0.9008593019819384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 486}], {
             RGBColor[
             0.9149058081121404, 0.933067468550375, 0.919422127754961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 230}], {
             RGBColor[
             0.6743387015659745, 0.7397053565807875, 0.9394210004683439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 331}], {
             RGBColor[
             0.6830187111591657, 0.7454469102075569, 0.8919482999330559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 382}], {
             RGBColor[
             0.6201248582399506, 0.6973931598939483, 0.9660239458744455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 413}], {
             RGBColor[
             0.3145207237385528, 0.44156041710592886`, 0.9414554099206098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 474}], {
             RGBColor[
             0.6852827512551775, 0.744523196468734, 0.7192283841773659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 490}], {
             RGBColor[
             0.31495381596352867`, 0.44201562449401155`, 0.9414800738821197]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 254}], {
             RGBColor[
             0.8455097718064859, 0.7470753529889802, 0.6108986544478363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 377}], {
             RGBColor[
             0.8843433900057867, 0.8931108064734479, 0.6834285362689507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 396}], {
             RGBColor[
             0.5252099226510171, 0.6140114871528455, 0.9588354898279989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 476}], {
             RGBColor[
             0.8904932909437269, 0.9122724617438398, 0.841961042981727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 257}], {
             RGBColor[
             0.7264543679424922, 0.7449032828124071, 0.6364698528584342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 266}], {
             RGBColor[
             0.3837924081349239, 0.5032661018870735, 0.9460292946894704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 281}], {
             RGBColor[
             0.5443284039891032, 0.6409493459303306, 0.9572706723841169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 293}], {
             RGBColor[
             0.7126816902103617, 0.7739961409692235, 0.9714257774507802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 317}], {
             RGBColor[
             0.3853313458767854, 0.5048836230280584, 0.9461169349172152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 322}], {
             RGBColor[
             0.7322598791132795, 0.764486635190319, 0.6590231674781504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 343}], {
             RGBColor[
             0.6221696868032363, 0.7023906206529249, 0.9645976959489578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 374}], {
             RGBColor[
             0.7073773301188825, 0.2876875361941156, 0.4270774863838843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 403}], {
             RGBColor[
             0.5052142920196491, 0.6091947477628641, 0.9541914662101683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 440}], {
             RGBColor[
             0.5955079610461278, 0.6815622778548509, 0.9619403042934822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 445}], {
             RGBColor[
             0.7399692128531481, 0.7929761013386706, 0.863837624394945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 471}], {
             RGBColor[
             0.7214383933388085, 0.7805268758246338, 0.9566029631682715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 238}], {
             RGBColor[
             0.9324929915911995, 0.8450383641826283, 0.6205357273788283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[
             0.9167499446192714, 0.7790852794545828, 0.6076855291675287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 266}], {
             RGBColor[
             0.6108216797307582, 0.6838270754639266, 0.9615413123880229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 293}], {
             RGBColor[
             0.9397109618061961, 0.9545571145460765, 0.9869377951493326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 403}], {
             RGBColor[
             0.7322435636154834, 0.789755721339717, 0.9697034839087206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 471}], {
             RGBColor[
             0.9484676649346429, 0.9610878494014867, 0.972114980866824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 483}], {
             RGBColor[
             0.7028793844301428, 0.7659165578358602, 0.9673918281587182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 497}], {
             RGBColor[
             0.9456130539633649, 0.8970550394866545, 0.6310924375309179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 231}], {
             RGBColor[
             0.7789545463417207, 0.34518575780325506`, 0.4331303156974927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 233}], {
             RGBColor[
             0.8719239264724892, 0.4179013946989746, 0.41508525657818485`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 259}], {
             RGBColor[
             0.8680639172778383, 0.3924045990649092, 0.22155283482502497`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 275}], {
             RGBColor[
             0.8757956330685285, 0.4183843178455079, 0.2601922036713271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 348}], {
             RGBColor[
             0.7596411490521704, 0.3300979850534023, 0.4312053367496296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 355}], {
             RGBColor[
             0.6392689004656411, 0.2277375458245901, 0.4226244702275924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 372}], {
             RGBColor[
             0.7566845744579053, 0.32771737841457826`, 0.4309591332766395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 379}], {
             RGBColor[
             0.7256717020027846, 0.3025397314415287, 0.4285176863530774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 400}], {
             RGBColor[
             0.8666250677607027, 0.4139495145478091, 0.42405484221354883`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 404}], {
             RGBColor[
             0.8372503782733043, 0.2677117569404419, 0.1825361754240275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 431}], {
             RGBColor[
             0.8760292963773457, 0.4188841000360836, 0.2856250128333002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 444}], {
             RGBColor[
             0.6832940277298368, 0.26744642896981824`, 0.42537198789609276`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 486}], {
             RGBColor[
             0.8255939114143261, 0.3817401901917963, 0.4377472050781078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 225}], {
             RGBColor[
             0.6392689004656411, 0.22773754582459013`, 0.4226244702275924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 252}], {
             RGBColor[
             0.44571853537116424`, 0.5539086638714803, 0.9508708356797764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 280}], {
             RGBColor[
             0.6110677907933402, 0.60534484302367, 0.6045934668666244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 309}], {
             RGBColor[
             0.551606910018279, 0.6371521859089969, 0.9610676201165934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 320}], {
             RGBColor[
             0.5200070423233742, 0.6124656350986367, 0.95791817171452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 393}], {
             RGBColor[
             0.6392689004656411, 0.22773754582459013`, 0.4226244702275924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 424}], {
             RGBColor[
             0.636259245749502, 0.6953475600395981, 0.6762818928315425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 480}], {
             RGBColor[
             0.6392689004656411, 0.22773754582459013`, 0.4226244702275924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 236}], {
             RGBColor[
             0.8696616957440828, 0.8986294527806278, 0.9665691009921469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 289}], {
             RGBColor[
             0.9629927406417103, 0.9719206270811889, 0.9475278164412301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 308}], {
             RGBColor[
             0.5990346379853095, 0.6687846947821938, 0.9456612639242608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 362}], {
             RGBColor[
             0.7115760841887037, 0.7724028334824252, 0.9526783944793186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 369}], {
             RGBColor[
             0.837787125923145, 0.8737287965808082, 0.9633921417571862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 466}], {
             RGBColor[
             0.914921788406915, 0.7377970834514196, 0.5841932296356048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 470}], {
             RGBColor[
             0.8645250382912824, 0.41238331600799816`, 0.4276096443298716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 216}], {
             RGBColor[
             0.5316065041430148, 0.6283237633987682, 0.957111986562301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 217}], {
             RGBColor[
             0.5409980582520191, 0.6364582555347531, 0.9577104080855017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 224}], {
             RGBColor[
             0.5271936937152035, 0.624501608800499, 0.9568308061839359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 286}], {
             RGBColor[
             0.8295784747035009, 0.8512238705033206, 0.679278266021377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 319}], {
             RGBColor[
             0.6440042569227225, 0.7213599990818045, 0.9654666853430407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 330}], {
             RGBColor[
             0.8187784663153156, 0.8588273386538339, 0.9588780320620927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 357}], {
             RGBColor[
             0.8309662946956589, 0.8675774754364685, 0.9230425646182343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 492}], {
             RGBColor[
             0.7701116441504561, 0.33827761540289325`, 0.4322489378486869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 251}], {
             RGBColor[
             0.9068642247561827, 0.9251174766297626, 0.8480714090527117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 332}], {
             RGBColor[
             0.7029979818431481, 0.7670650148315064, 0.971607346279386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 337}], {
             RGBColor[
             0.7278721323188402, 0.7872589707553823, 0.973565530521848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 420}], {
             RGBColor[
             0.9063199830246169, 0.9239533985972231, 0.7888340552424078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 447}], {
             RGBColor[
             0.5374026847337424, 0.6224201757726853, 0.9602274912910758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 454}], {
             RGBColor[
             0.5511633949198826, 0.6368835546577365, 0.96101114337903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 489}], {
             RGBColor[
             0.8921991533249758, 0.9161140124624926, 0.9626462089691921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 500}], {
             RGBColor[
             0.7068916916096081, 0.7702261038295446, 0.9719138733753305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 223}], {
             RGBColor[
             0.9266743538507529, 0.943049576512524, 0.9465200555066963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 268}], {
             RGBColor[
             0.8141353526775033, 0.8551225346933249, 0.9820043620629535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 466}], {
             RGBColor[
             0.8698520480753711, 0.7024589428938508, 0.6006707071445314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 470}], {
             RGBColor[
             0.8344785447369197, 0.3888245556362856, 0.4385946293358226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 491}], {
             RGBColor[
             0.928684449553274, 0.9438808027426198, 0.9132075677549962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 402}], {
             RGBColor[
             0.42053904055083435`, 0.5386715128435384, 0.9480173536891949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 417}], {
             RGBColor[
             0.6803918783249044, 0.2649327330215362, 0.42518706550228047`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 217}], {
             RGBColor[
             0.3969076299436659, 0.5182031727248415, 0.946511581101742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 224}], {
             RGBColor[
             0.38310326540685025`, 0.5062465259905873, 0.9456319792001764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 292}], {
             RGBColor[
             0.6037022421693389, 0.6846455018928358, 0.9642978159557876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 358}], {
             RGBColor[
             0.6304717075234213, 0.7059899742979261, 0.9668513164910157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 361}], {
             RGBColor[
             0.6886761990828456, 0.7500668764626024, 0.882007565757714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 398}], {
             RGBColor[
             0.5973738161847357, 0.6797016874158448, 0.9636670575961456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 399}], {
             RGBColor[
             0.6901595389000679, 0.7485416772290769, 0.7019712610614323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 464}], {
             RGBColor[
             0.4395811329787508, 0.5541241159979331, 0.949518247552899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 481}], {
             RGBColor[
             0.47391326894027075`, 0.5819964906165944, 0.9522209990585477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 292}], {
             RGBColor[
             0.6130937962783432, 0.6927799940288208, 0.9648962374789881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 398}], {
             RGBColor[
             0.60676537029374, 0.6878361795518299, 0.9642654791193461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 464}], {
             RGBColor[
             0.4489726870877551, 0.562258608133918, 0.9501166690760996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 481}], {
             RGBColor[
             0.483304823049275, 0.5901309827525795, 0.9528194205817483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 496}], {
             RGBColor[
             0.36093335931827786`, 0.48704406762854535`, 0.9442193323882908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 235}], {
             RGBColor[
             0.8566898529707548, 0.8888889750947275, 0.9851811476562597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 274}], {
             RGBColor[
             0.8571216128090124, 0.4068618534053179, 0.44014171254874046`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.6803533079788464, 0.746991633247472, 0.9701128660266232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 305}], {
             RGBColor[
             0.9446201058852126, 0.9008849700212131, 0.6363192435325833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 310}], {
             RGBColor[
             0.9386441763088497, 0.9537615076688566, 0.9887435847341217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 314}], {
             RGBColor[
             0.9367268384270373, 0.9523315602159536, 0.9919891376462213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 406}], {
             RGBColor[
             0.6153725447471057, 0.6893468811471688, 0.9660222070661244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 432}], {
             RGBColor[
             0.8571216128090124, 0.4068618534053179, 0.44014171254874046`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 493}], {
             RGBColor[
             0.8765174990073568, 0.9043784828742121, 0.9871573821133013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 238}], {
             RGBColor[
             0.8645189687793218, 0.7911048942537657, 0.6192548724146998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 258}], {
             RGBColor[
             0.8487759218073938, 0.7251518095257203, 0.6064046742034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 293}], {
             RGBColor[
             0.8717369389943185, 0.9006236446172139, 0.985656940185204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 403}], {
             RGBColor[
             0.6642695408036059, 0.7358222514108544, 0.9684226289445921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 445}], {
             RGBColor[
             0.8990244616371048, 0.9196036049866609, 0.8780687871293689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 471}], {
             RGBColor[
             0.8804936421227654, 0.9071543794726241, 0.9708341259026954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 497}], {
             RGBColor[
             0.8776390311514873, 0.8431215695577919, 0.6298115825667894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 254}], {
             RGBColor[
             0.8465798531156105, 0.30990677879352013`, 0.19031223032633562`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 297}], {
             RGBColor[
             0.7396533513344599, 0.3138906642351071, 0.4296183730049359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 325}], {
             RGBColor[
             0.8743238320354785, 0.4192325383572021, 0.3904812305560025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 392}], {
             RGBColor[
             0.6996176845011868, 0.2813879063136187, 0.42646661865634083`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 412}], {
             RGBColor[
             0.7274892684453227, 0.3040153137600162, 0.4286607718413993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 413}], {
             RGBColor[
             0.628746648242053, 0.21667799158827522`, 0.42202524352973625`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 426}], {
             RGBColor[
             0.6675143175567845, 0.2537788371292143, 0.4243665187173157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 474}], {
             RGBColor[
             0.875921333253136, 0.4186531778301453, 0.27387389303424026`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 490}], {
             RGBColor[
             0.6290353763920369, 0.21698146318033038`, 0.4220416861707428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 234}], {
             RGBColor[
             0.8812898305212544, 0.9081673881043556, 0.9880811613933046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 301}], {
             RGBColor[
             0.8124112453785619, 0.8534327069909768, 0.9819235254162142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 336}], {
             RGBColor[
             0.7693581951749188, 0.8197993369565901, 0.977632399725544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 294}], {
             RGBColor[
             0.9805032619647867, 0.9837141152324338, 0.861200618540547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 296}], {
             RGBColor[
             0.7832494775274805, 0.8282390800579288, 0.8725167024400464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 339}], {
             RGBColor[
             0.8754830747735829, 0.4197119150205878, 0.37126957836157426`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 344}], {
             RGBColor[
             0.948331181443232, 0.9589247488484784, 0.8880797192614549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 438}], {
             RGBColor[
             0.7073783284658749, 0.7658187768795182, 0.8667717109740514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 439}], {
             RGBColor[
             0.8244476202161758, 0.8614600197812073, 0.8759141935388141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 246}], {
             RGBColor[
             0.7762595209670164, 0.8240102477103355, 0.9324119442492264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 268}], {
             RGBColor[
             0.8720120723174968, 0.8999524442969924, 0.9411765295621819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 411}], {
             RGBColor[
             0.8515842733134722, 0.8839940924580256, 0.9391404774660961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 286}], {
             RGBColor[
             0.6810752359673363, 0.7291466330951398, 0.6677982586592522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 330}], {
             RGBColor[
             0.670275227579151, 0.7367501012456532, 0.947398024699968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 333}], {
             RGBColor[
             0.6486645999410916, 0.608780568751994, 0.5993719135290061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 358}], {
             RGBColor[
             0.6260588970956099, 0.702167819699657, 0.9665701361126506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 361}], {
             RGBColor[
             0.6842633886550342, 0.7462447218643332, 0.8817263853793489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 398}], {
             RGBColor[
             0.5929610057569243, 0.6758795328175757, 0.9633858772177805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 441}], {
             RGBColor[
             0.6771952259518201, 0.7160584482431284, 0.6527251524273818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 464}], {
             RGBColor[
             0.43516832255093946`, 0.5503019613996639, 0.9492370671745339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 481}], {
             RGBColor[
             0.46950045851245936`, 0.5781743360183254, 0.9519398186801826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 247}], {
             RGBColor[
             0.644536063428389, 0.23327366805585842`, 0.4229244273662516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 252}], {
             RGBColor[
             0.7476354564484684, 0.32037089675639674`, 0.43024675355892517`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 309}], {
             RGBColor[
             0.8182277062132116, 0.3758665781147411, 0.4370446098501365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 320}], {
             RGBColor[
             0.7971611277499417, 0.359408877574501, 0.4349449775820875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 424}], {
             RGBColor[
             0.8746625967006936, 0.4146634942018086, 0.24718745832676925`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 284}], {
             RGBColor[
             0.8949987480001168, 0.9186974108265863, 0.9754824815699147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 345}], {
             RGBColor[
             0.871871221476531, 0.9006704619642791, 0.987641049504701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 366}], {
             RGBColor[
             0.6617514992448856, 0.7334256724051098, 0.96852698306204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 389}], {
             RGBColor[
             0.9161713242873726, 0.9318295890049797, 0.7924004481438005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 405}], {
             RGBColor[
             0.8474259480554553, 0.8811784644875837, 0.9853094375032456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 429}], {
             RGBColor[
             0.7980579118219896, 0.8423156643361682, 0.9804674728475711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 472}], {
             RGBColor[
             0.8564539854657711, 0.8883771764590223, 0.9861705397708656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 488}], {
             RGBColor[
             0.5533621352345058, 0.6366901303339092, 0.9615170583671633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 229}], {
             RGBColor[
             0.9223545436119519, 0.9379233746672859, 0.8730827029319186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 263}], {
             RGBColor[
             0.8384455778025875, 0.8740177610136036, 0.9844528817716558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 265}], {
             RGBColor[
             0.8234605488149223, 0.8622667951051604, 0.9829711356282687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 267}], {
             RGBColor[
             0.8403082823942811, 0.8755030310932508, 0.9846305481984676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 270}], {
             RGBColor[
             0.6207483373543288, 0.6983257149021173, 0.9658829708739471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 329}], {
             RGBColor[
             0.9050109179049626, 0.9265039275901015, 0.9703036713174349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 424}], {
             RGBColor[
             0.9203727246997249, 0.9300401435411851, 0.699407223542805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 256}], {
             RGBColor[
             0.9641528017803822, 0.8830171286586814, 0.45056996172855107`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 279}], {
             RGBColor[
             0.692955765689083, 0.6707438934202488, 0.6078373700104475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 287}], {
             RGBColor[
             0.867211317791224, 0.8098238280888184, 0.623202629982508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 298}], {
             RGBColor[
             0.7712146294892612, 0.7343126831279732, 0.6139886016007952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 318}], {
             RGBColor[
             0.6092630908164361, 0.5960260342676895, 0.6025861053877319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 335}], {
             RGBColor[
             0.6749529632658313, 0.6551507708083875, 0.606690247359291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 409}], {
             RGBColor[
             0.8699678571639256, 0.4539846573753987, 0.21124152158268228`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 468}], {
             RGBColor[
             0.5953977004800142, 0.5814526299075873, 0.6017964919200796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 232}], {
             RGBColor[
             0.9923366651937249, 0.9910990283659533, 0.77666482002212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 263}], {
             RGBColor[
             0.9094044621171705, 0.9275973312039452, 0.8718475125982721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 267}], {
             RGBColor[
             0.9112671667088641, 0.9290826012835923, 0.8720251790250838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 280}], {
             RGBColor[
             0.966140154058146, 0.8936169967155985, 0.5151134284045032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 393}], {
             RGBColor[
             0.875983809308845, 0.41991898161920915`, 0.3629711112528449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 480}], {
             RGBColor[
             0.875983809308845, 0.41991898161920915`, 0.3629711112528449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 485}], {
             RGBColor[
             0.8403801744619386, 0.8736304857108212, 0.864979638176486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 382}], {
             RGBColor[
             0.9170240570549784, 0.9357576570277039, 0.9601738570907785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 413}], {
             RGBColor[
             0.6114199225535806, 0.6799249142396844, 0.9356053211369428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 474}], {
             RGBColor[
             0.9821819500702051, 0.9828876936024895, 0.7133782953936988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 484}], {
             RGBColor[
             0.9831452581544292, 0.9851459987529049, 0.8326126996935255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 490}], {
             RGBColor[
             0.6118530147785565, 0.6803801216277671, 0.9356299850984526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 233}], {
             RGBColor[
             0.8416797092213149, 0.8763767287533446, 0.9438873584135166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 275}], {
             RGBColor[
             0.8474872691153738, 0.8771011134731446, 0.7115477790532299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 326}], {
             RGBColor[
             0.8063823695641129, 0.8494032260896187, 0.9811420866899003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 346}], {
             RGBColor[
             0.773799808432319, 0.8234227762731873, 0.9780343329223542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 355}], {
             RGBColor[
             0.49269717021104276`, 0.5911309554417679, 0.9551961788876278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 395}], {
             RGBColor[
             0.5185418094611705, 0.6158810789852156, 0.9567563896808047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 404}], {
             RGBColor[
             0.7896693869225374, 0.6510922721155454, 0.5950637366822804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 431}], {
             RGBColor[
             0.8478377640785997, 0.8778507867590081, 0.7496969927961894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 444}], {
             RGBColor[
             0.5587348611073363, 0.6506942801596101, 0.9593174553903783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 486}], {
             RGBColor[
             0.7721846866340702, 0.8221349219925771, 0.9778802811634009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 267}], {
             RGBColor[
             0.910290403976054, 0.9286786847919182, 0.888212665288669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 280}], {
             RGBColor[
             0.9651633913253359, 0.8932130802239243, 0.5313009146680885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 338}], {
             RGBColor[
             0.9737979736686664, 0.9273655781782114, 0.5386690170351955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 383}], {
             RGBColor[
             0.8736260514826283, 0.8999615554962768, 0.8845781173419487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 393}], {
             RGBColor[
             0.8753326341536383, 0.4196497039580931, 0.3737627687619018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 395}], {
             RGBColor[
             0.6631089411790467, 0.7275769982174726, 0.8677050692774182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 480}], {
             RGBColor[
             0.8753326341536383, 0.4196497039580931, 0.3737627687619018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 259}], {
             RGBColor[
             0.9753437656254911, 0.9472049906458258, 0.6265211371048148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 275}], {
             RGBColor[
             0.9869413393115265, 0.9861745688167238, 0.684480190374268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 326}], {
             RGBColor[
             0.9458364397602657, 0.9584766814331981, 0.9540744980109386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 346}], {
             RGBColor[
             0.9132538786284716, 0.9324962316167666, 0.9509667442433923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 348}], {
             RGBColor[
             0.8127096132869893, 0.8537450696285654, 0.9409998899917218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 355}], {
             RGBColor[
             0.6321512404071954, 0.7002044107853471, 0.928128590208666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 379}], {
             RGBColor[
             0.7617554427129107, 0.812407689210755, 0.9369684143968935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 400}], {
             RGBColor[
             0.9731854913497877, 0.9795223638701755, 0.9302741481876007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 404}], {
             RGBColor[
             0.9291234571186902, 0.7601657274591248, 0.5679961480033187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 431}], {
             RGBColor[
             0.9872918342747523, 0.9869242421025874, 0.7226294041172276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 444}], {
             RGBColor[
             0.698188931303489, 0.7597677355031893, 0.9322498667114165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 486}], {
             RGBColor[
             0.9116387568302229, 0.9312083773361564, 0.9508126924844391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 336}], {
             RGBColor[
             0.8242799068064497, 0.8635792019505711, 0.9824126381599765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 449}], {
             RGBColor[
             0.5937559361583286, 0.6667051059173654, 0.9652419769569112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 274}], {
             RGBColor[
             0.8037636225048241, 0.36456679665783387`, 0.43560305255543275`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 284}], {
             RGBColor[
             0.8642092266299629, 0.8944969116579204, 0.9724528094179624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 300}], {
             RGBColor[
             0.6003163225225641, 0.6835490481262461, 0.9633048760366616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 305}], {
             RGBColor[
             0.8645831204289303, 0.837442384899987, 0.6295112535426217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 308}], {
             RGBColor[
             0.5078925143056222, 0.5970599157569475, 0.9576513762626025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 345}], {
             RGBColor[
             0.8410817001063771, 0.8764699627956134, 0.9846113773527487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 389}], {
             RGBColor[
             0.8853818029172187, 0.907629089836314, 0.7893707759918482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 432}], {
             RGBColor[
             0.8037636225048241, 0.36456679665783387`, 0.43560305255543275`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 456}], {
             RGBColor[
             0.6873031735285378, 0.7549654940101436, 0.9699326962165553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 289}], {
             RGBColor[
             0.8737173215119458, 0.9016541318378224, 0.9597039844437624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 300}], {
             RGBColor[
             0.602183027072487, 0.6850073319081259, 0.963490931700852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 308}], {
             RGBColor[
             0.5097592188555452, 0.5985181995388273, 0.957837431926793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 314}], {
             RGBColor[
             0.8585565575206778, 0.8903472588766075, 0.9853672033204502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 466}], {
             RGBColor[
             0.8256463692771506, 0.6675305882080531, 0.5963693976381371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 470}], {
             RGBColor[
             0.8050080922047728, 0.3655389858457538, 0.43572708966489304`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 493}], {
             RGBColor[
             0.7983472181009972, 0.842394181534866, 0.9805354477875302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 241}], {
             RGBColor[
             0.6464722654187021, 0.7105435264167307, 0.7629298105742092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 274}], {
             RGBColor[
             0.8762041135174123, 0.419258016221962, 0.3046527796832212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 284}], {
             RGBColor[
             0.9728699631488453, 0.9765337410041128, 0.7760274001096451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 351}], {
             RGBColor[
             0.6114289123388483, 0.6737107404528897, 0.7609341434583066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 371}], {
             RGBColor[
             0.6510898944787169, 0.7153969473333985, 0.763192777718007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 429}], {
             RGBColor[
             0.8759291269707181, 0.9001519945136947, 0.7810123913873015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 432}], {
             RGBColor[
             0.8762041135174123, 0.419258016221962, 0.3046527796832212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 460}], {
             RGBColor[
             0.9903926784826189, 0.9891670396291568, 0.7268807296445161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 258}], {
             RGBColor[
             0.9076904026621546, 0.6681930879011586, 0.2444007619975992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 266}], {
             RGBColor[
             0.6017621377736415, 0.5729348839105023, 0.5982565452180935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 293}], {
             RGBColor[
             0.9306514198490794, 0.8436649229926522, 0.623653027979403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 403}], {
             RGBColor[
             0.7231840216583667, 0.6788635297862927, 0.6064187167387911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 445}], {
             RGBColor[
             0.9579389424918657, 0.8626448833620992, 0.5160648749235679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 471}], {
             RGBColor[
             0.9394081229775262, 0.8501956578480624, 0.6088302136968946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 483}], {
             RGBColor[
             0.693819842473026, 0.6550243662824358, 0.6041070609887886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 497}], {
             RGBColor[
             0.9365535120062483, 0.7861628479332302, 0.2678076703609884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 251}], {
             RGBColor[
             0.8106809990461303, 0.849731043377165, 0.8386538896932675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 272}], {
             RGBColor[
             0.7536163432681803, 0.3252264501125197, 0.43071759087808326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 332}], {
             RGBColor[
             0.6068147561330957, 0.6916785815789086, 0.9621898269199418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 387}], {
             RGBColor[
             0.7674141374219989, 0.43128234221072126`, 0.44393037414215963`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 435}], {
             RGBColor[
             0.5173601666860179, 0.617838654819145, 0.9554838010601725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 453}], {
             RGBColor[
             0.7766522116866394, 0.5022902291587034, 0.4527767644908919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 454}], {
             RGBColor[
             0.4549801692098302, 0.5614971214051387, 0.9515936240195859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 489}], {
             RGBColor[
             0.7960159276149233, 0.8407275792098949, 0.9532286896097478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 434}], {
             RGBColor[
             0.8647557746132781, 0.8949045262489868, 0.9715276462447537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 495}], {
             RGBColor[
             0.700365841378306, 0.7655703562370659, 0.9709610372798181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 271}], {
             RGBColor[
             0.6186828310996548, 0.6925715142530378, 0.9647509292503103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 304}], {
             RGBColor[
             0.644536063428389, 0.23327366805585842`, 0.4229244273662516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 311}], {
             RGBColor[
             0.5374520300624576, 0.6282258538464988, 0.9593193883981259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 351}], {
             RGBColor[
             0.26392683720531324`, 0.3947342182037342, 0.9383416149828522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 371}], {
             RGBColor[
             0.30358781934518186`, 0.43642042508424317`, 0.9406002492425526]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 429}], {
             RGBColor[
             0.528427051837183, 0.6211754722645393, 0.9584198629118471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 442}], {
             RGBColor[
             0.6287273900863372, 0.6515939594777995, 0.6167790913247135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 249}], {
             RGBColor[
             0.655300958408122, 0.7288159266797518, 0.9675287244675779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 269}], {
             RGBColor[
             0.6236211244294272, 0.7040673995999395, 0.964371174681462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 282}], {
             RGBColor[
             0.754416285606355, 0.8060086762468419, 0.9194785053336391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 310}], {
             RGBColor[
             0.7317480539366563, 0.7893861710325705, 0.9705422525453528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 323}], {
             RGBColor[
             0.7191908645608835, 0.29727829564779384`, 0.42800749108956115`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 419}], {
             RGBColor[
             0.7553470993891669, 0.8063935916668576, 0.9040525120835934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 449}], {
             RGBColor[
             0.38711746192326124`, 0.5025219228398878, 0.9466045136773844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 499}], {
             RGBColor[
             0.39746804414489867`, 0.5134010410196457, 0.9471939640225925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 273}], {
             RGBColor[
             0.9189268937625275, 0.7434190394258535, 0.5791683130358629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 279}], {
             RGBColor[
             0.6621672307657753, 0.5394796390511769, 0.5825883904949689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 283}], {
             RGBColor[
             0.9146114776424249, 0.7402006091493263, 0.5864731868864135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 285}], {
             RGBColor[
             0.9263242265728945, 0.7291965553351547, 0.29666454881973414`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 318}], {
             RGBColor[
             0.5784745558931285, 0.46476177989861756`, 0.5773371258722535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 335}], {
             RGBColor[
             0.6441644283425235, 0.5238865164393156, 0.5814412678438126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 396}], {
             RGBColor[
             0.5683984901097995, 0.45417119590086935`, 0.5767633088320965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 421}], {
             RGBColor[
             0.8487083574735882, 0.6881986832494589, 0.5991671421975833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 430}], {
             RGBColor[
             0.9089480415477251, 0.7359768277829247, 0.5960599069340393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 459}], {
             RGBColor[
             0.8888688253910928, 0.5879109824147646, 0.2289636505905958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 477}], {
             RGBColor[
             0.5632773947144891, 0.4487885999441966, 0.5764716700253152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 261}], {
             RGBColor[
             0.6746063106390111, 0.7434974921192461, 0.969958258087523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 262}], {
             RGBColor[
             0.8588984919551764, 0.8903263595793132, 0.9864036989820617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 295}], {
             RGBColor[
             0.6082895932086767, 0.6862560002533569, 0.9656777097828718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 341}], {
             RGBColor[
             0.6537224798449532, 0.7256076831344209, 0.968572653144611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 376}], {
             RGBColor[
             0.9414515015097245, 0.9521323258710117, 0.8065666552280624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 391}], {
             RGBColor[
             0.6655193316537409, 0.7358255232441808, 0.9693243381103207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 407}], {
             RGBColor[
             0.679141839512222, 0.747179638781766, 0.9703153115346119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 448}], {
             RGBColor[
             0.9030028895069522, 0.92549400900512, 0.9906104157930107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 455}], {
             RGBColor[
             0.5705221037976351, 0.6483404254950301, 0.9634617160923595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 475}], {
             RGBColor[
             0.743169646493484, 0.7991602969089885, 0.9753558150417619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 478}], {
             RGBColor[
             0.86182006409282, 0.892655941897907, 0.9866823611406684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 482}], {
             RGBColor[
             0.900434184865887, 0.9234457936499647, 0.9903654104512362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 262}], {
             RGBColor[
             0.8976222360328932, 0.920421634904484, 0.9629852214972481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 299}], {
             RGBColor[
             0.9535625274029986, 0.8891875351210745, 0.6069322487446674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 376}], {
             RGBColor[
             0.9801752455874413, 0.9822276011961826, 0.7831481777432487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 438}], {
             RGBColor[
             0.694484499592797, 0.757468410398342, 0.9452840527831216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 448}], {
             RGBColor[
             0.941726633584669, 0.955589284330291, 0.967191938308197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 475}], {
             RGBColor[
             0.7818933905712009, 0.8292555722341595, 0.9519373375569482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 482}], {
             RGBColor[
             0.9391579289436037, 0.9535410689751356, 0.9669469329664224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 384}], {
             RGBColor[
             0.7241650728306965, 0.7837909644481187, 0.9737912949679131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 402}], {
             RGBColor[
             0.501254207285121, 0.6054699179634739, 0.9540205881820383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 411}], {
             RGBColor[
             0.6432927207897422, 0.7201248540521696, 0.9658601987093978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 458}], {
             RGBColor[
             0.4786511590621577, 0.5858922936549792, 0.9525803419363619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 252}], {
             RGBColor[
             0.453619279815286, 0.5622128472183828, 0.9513207713877652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 278}], {
             RGBColor[
             0.6055987683271027, 0.5606423557817126, 0.5942857742897741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 309}], {
             RGBColor[
             0.5595076544624008, 0.6454563692558993, 0.9615175558245822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 401}], {
             RGBColor[
             0.644536063428389, 0.23327366805585842`, 0.4229244273662516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 451}], {
             RGBColor[
             0.27794670110743736`, 0.40946998407557916`, 0.9391400254915481]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 339}], {
             RGBColor[
             0.6759279268944689, 0.26106628265721543`, 0.4249026264644503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 344}], {
             RGBColor[
             0.6489984596245609, 0.72095630030342, 0.9685292914157689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 387}], {
             RGBColor[
             0.6897257210482876, 0.367122174755417, 0.4381154097285268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 439}], {
             RGBColor[
             0.5251148983975047, 0.6234915712361488, 0.9563637656931281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 269}], {
             RGBColor[
             0.7559874891548986, 0.8093024393363097, 0.9763134258803565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 282}], {
             RGBColor[
             0.8867826503318262, 0.9112437159832122, 0.9314207565325334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 310}], {
             RGBColor[
             0.8641144186621277, 0.8946212107689409, 0.9824845037442471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 323}], {
             RGBColor[
             0.8074351077111978, 0.36743498880537406`, 0.4359689918888241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 406}], {
             RGBColor[
             0.5408427871003836, 0.6302065842472531, 0.9597631260762499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 419}], {
             RGBColor[
             0.8877134641146383, 0.911628631403228, 0.9159947632824877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 499}], {
             RGBColor[
             0.5298344088703699, 0.6186360807560161, 0.9591362152214868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 263}], {
             RGBColor[
             0.5738444333570605, 0.6585905769558619, 0.9624842729946286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 365}], {
             RGBColor[
             0.6229941579891501, 0.6977812332437558, 0.9671722176065144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 485}], {
             RGBColor[
             0.5048201457018284, 0.6046237314627381, 0.9556163985728425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 258}], {
             RGBColor[
             0.9435491619889732, 0.7971383697949419, 0.4725707852692924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 272}], {
             RGBColor[
             0.8765963227625733, 0.42009691213892364`, 0.3473423355840951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 435}], {
             RGBColor[
             0.7018301359276073, 0.760144347858751, 0.8304209181191904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 447}], {
             RGBColor[
             0.6256894282652795, 0.6893394355596935, 0.8257470889906495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 453}], {
             RGBColor[
             0.8996321911810324, 0.5971606911851073, 0.36940150919690384`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 454}], {
             RGBColor[
             0.6394501384514197, 0.7038028144447446, 0.8265307410786038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 309}], {
             RGBColor[
             0.7141567439925198, 0.776102212306707, 0.9725010451135925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 320}], {
             RGBColor[
             0.6825568762976151, 0.7514156614963468, 0.969351596711519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 424}], {
             RGBColor[
             0.7988090797237428, 0.8342975864373081, 0.6877153178285416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 287}], {
             RGBColor[
             0.8562047957889241, 0.7661866360557323, 0.6143465240231811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 301}], {
             RGBColor[
             0.8551567584465607, 0.7653679013184992, 0.6142420654553601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 336}], {
             RGBColor[
             0.8121037082429174, 0.7317345312841126, 0.6099509397646898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 354}], {
             RGBColor[
             0.8961106611219136, 0.7978494156785887, 0.6181944637402309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 388}], {
             RGBColor[
             0.9529652271475403, 0.8400371300174836, 0.49792764080552343`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 436}], {
             RGBColor[
             0.775127843017273, 0.7027880045248203, 0.6063070318752065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 473}], {
             RGBColor[
             0.8488323816752402, 0.3188373039218065, 0.1921246676790546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 350}], {
             RGBColor[
             0.8564974354107883, 0.3861376622265295, 0.199809318332505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 377}], {
             RGBColor[
             0.9439351775461322, 0.8075017898650281, 0.31503057280012126`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 412}], {
             RGBColor[
             0.7264656823413997, 0.6526291388303047, 0.6000235032516024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 426}], {
             RGBColor[
             0.6365032560085924, 0.5772744238841017, 0.593582123565477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 476}], {
             RGBColor[
             0.9500850784840724, 0.82666344513542, 0.47356307951289767`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 260}], {
             RGBColor[
             0.7223487397438633, 0.782000748203538, 0.9740115969228689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 299}], {
             RGBColor[
             0.9325416028932696, 0.8732080075891808, 0.6320392369633694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 312}], {
             RGBColor[
             0.7361909611884674, 0.7932384871572373, 0.975101307300716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 327}], {
             RGBColor[
             0.753830075023584, 0.8075587144016079, 0.9764899229560193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 334}], {
             RGBColor[
             0.8814255503736415, 0.908288824481486, 0.9885523499241574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 385}], {
             RGBColor[
             0.9551853104204899, 0.9654307165010798, 0.9339230111451817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 446}], {
             RGBColor[
             0.6691557419700329, 0.7377576543419251, 0.9701165496851282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 478}], {
             RGBColor[
             0.8795228836608076, 0.9067716896911844, 0.9883708718745567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 287}], {
             RGBColor[
             0.8974919305412856, 0.9173086609159082, 0.8081223767552415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 298}], {
             RGBColor[
             0.8014952422393229, 0.841797515955063, 0.7989083483735286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 409}], {
             RGBColor[
             0.8901549323306334, 0.5256412125934586, 0.33452135276450456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 281}], {
             RGBColor[
             0.783288781574948, 0.7910440201603911, 0.640944066090898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 317}], {
             RGBColor[
             0.6242917234626302, 0.654978297258119, 0.6297903286239963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 322}], {
             RGBColor[
             0.9712202566991244, 0.9145813094203795, 0.3426965611849315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 324}], {
             RGBColor[
             0.7114115597891761, 0.7326908534827605, 0.6352856278969832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 326}], {
             RGBColor[
             0.9379769228157004, 0.9132505679059699, 0.6557362364262689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 343}], {
             RGBColor[
             0.8611300643890811, 0.8524852948829853, 0.648271089655739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 374}], {
             RGBColor[
             0.8666842485094457, 0.3877506523474892, 0.2161930821884051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 445}], {
             RGBColor[
             0.978929590438993, 0.9430707755687311, 0.5475110181017262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 272}], {
             RGBColor[
             0.8421951185634089, 0.29016466772437105`, 0.18666218792876652`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 293}], {
             RGBColor[
             0.9149083728771513, 0.7777118382646067, 0.6108028297681034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 403}], {
             RGBColor[
             0.7074409746864387, 0.6129104450582472, 0.5935685185274915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 435}], {
             RGBColor[
             0.6502283296288609, 0.5652459812369222, 0.5894006966361973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 453}], {
             RGBColor[
             0.8652309869818681, 0.4672284467705547, 0.2087213615415752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 471}], {
             RGBColor[
             0.9236650760055982, 0.7842425731200169, 0.5959800154855948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 497}], {
             RGBColor[
             0.9208104650343202, 0.7202097632051847, 0.2549574721496888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 275}], {
             RGBColor[
             0.9811513255195501, 0.9479293753656257, 0.3941815577445281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 331}], {
             RGBColor[
             0.9790758357004496, 0.9492563790814047, 0.5874240075445878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 348}], {
             RGBColor[
             0.8069195994950129, 0.8154998761774673, 0.6507012573619819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 372}], {
             RGBColor[
             0.8024847376036152, 0.8119289662192313, 0.6503319521524966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 400}], {
             RGBColor[
             0.9673954775578113, 0.9412771704190774, 0.6399755155578608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 404}], {
             RGBColor[
             0.9233334433267137, 0.7219205340080267, 0.2776975153735787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 418}], {
             RGBColor[
             0.8680639172778383, 0.3924045990649092, 0.22155283482502497`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 431}], {
             RGBColor[
             0.9815018204827759, 0.9486790486514893, 0.4323307714874878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 444}], {
             RGBColor[
             0.6923989175115126, 0.7215225420520912, 0.6419512340816766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 486}], {
             RGBColor[
             0.9058487430382465, 0.8929631838850582, 0.6605140598546992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 299}], {
             RGBColor[
             0.7309086250819979, 0.7129867987570951, 0.613439438745971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 312}], {
             RGBColor[
             0.5345579833771958, 0.6330172783251516, 0.9565015090833175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 328}], {
             RGBColor[
             0.7551955282527184, 0.7993070124944253, 0.6849013485441683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 334}], {
             RGBColor[
             0.6797925725623698, 0.7480676156494002, 0.9699525517067591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 399}], {
             RGBColor[
             0.7567593819490328, 0.8043971066203748, 0.7067205806248967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 407}], {
             RGBColor[
             0.495211681268938, 0.6010741777429576, 0.9534040240511018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 446}], {
             RGBColor[
             0.46752276415876126`, 0.5775364455098394, 0.9515167514677298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 478}], {
             RGBColor[
             0.677889905849536, 0.7465504808590986, 0.9697710736571583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 262}], {
             RGBColor[
             0.6449287241750279, 0.7198333902494902, 0.9671275833970941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 299}], {
             RGBColor[
             0.7008690155451334, 0.6885992904660806, 0.6110746106445135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 313}], {
             RGBColor[
             0.6878789864095384, 0.637098153614049, 0.6006225282868409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 328}], {
             RGBColor[
             0.7251559187158538, 0.7749195042034107, 0.6825365204427107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 391}], {
             RGBColor[
             0.4515495638735924, 0.5653325539143579, 0.950048222525353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 407}], {
             RGBColor[
             0.4651720717320734, 0.576686669451943, 0.9510391959496443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 448}], {
             RGBColor[
             0.6890331217268038, 0.7550010396752971, 0.971334300208043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 455}], {
             RGBColor[
             0.3565523360174866, 0.4778474561652072, 0.944185600507392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 475}], {
             RGBColor[
             0.5291998787133356, 0.6286673275791655, 0.9560796994567944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 478}], {
             RGBColor[
             0.6478502963126713, 0.722162972568084, 0.9674062455557009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 482}], {
             RGBColor[
             0.6864644170857385, 0.7529528243201418, 0.9710892948662686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 299}], {
             RGBColor[
             0.8851611968612987, 0.8354281579261476, 0.6275200515390522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 376}], {
             RGBColor[
             0.9117739150457413, 0.9284682240012557, 0.8037359805376335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 391}], {
             RGBColor[
             0.6358417451897578, 0.7121614213744248, 0.9664936634198917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 448}], {
             RGBColor[
             0.8733253030429691, 0.9018299071353642, 0.9877797411025817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 455}], {
             RGBColor[
             0.5408445173336519, 0.6246763236252741, 0.9606310414019307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 475}], {
             RGBColor[
             0.7134920600295009, 0.7754961950392325, 0.9725251403513331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 478}], {
             RGBColor[
             0.8321424776288366, 0.8689918400281511, 0.9838516864502396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 482}], {
             RGBColor[
             0.8707565984019038, 0.8997816917802087, 0.9875347357608073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 267}], {
             RGBColor[
             0.8273582008994997, 0.86517698762991, 0.9833953578648211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 393}], {
             RGBColor[
             0.8200444987692688, 0.3773152391834209, 0.4372178971460031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 485}], {
             RGBColor[
             0.7564712086525742, 0.809724872057139, 0.9763498170162235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 281}], {
             RGBColor[
             0.43520083693872536`, 0.5437037851528338, 0.9501945061129676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 295}], {
             RGBColor[
             0.2986209821270428, 0.4294195130424989, 0.9403825862513038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 324}], {
             RGBColor[
             0.3633236151529535, 0.4853506184752032, 0.9445360679190529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 341}], {
             RGBColor[
             0.34405386876331934`, 0.46877119592356287`, 0.9432775296130431]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 374}], {
             RGBColor[
             0.6346256187519639, 0.222857162342451, 0.4223600422031182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 397}], {
             RGBColor[
             0.6346256187519639, 0.222857162342451, 0.4223600422031182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 270}], {
             RGBColor[
             0.5928132268718821, 0.6762487055303331, 0.9631660343969135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 320}], {
             RGBColor[
             0.7761854107911503, 0.8250812092284396, 0.9783265659487489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 329}], {
             RGBColor[
             0.8770758074225158, 0.9044269182183173, 0.9675867348404013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 424}], {
             RGBColor[
             0.8924376142172781, 0.907963134169401, 0.6966902870657714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 293}], {
             RGBColor[
             0.6089801079886381, 0.6824536342739504, 0.9646586129885976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 317}], {
             RGBColor[
             0.2816297636550618, 0.4133411163327855, 0.9393497704550325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 322}], {
             RGBColor[
             0.628558296891556, 0.6729441284950459, 0.6522560030159678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 343}], {
             RGBColor[
             0.5184681045815127, 0.6108481139576518, 0.9578305314867752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 359}], {
             RGBColor[
             0.268507018921454, 0.3995482795876918, 0.9386024495558147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 403}], {
             RGBColor[
             0.4015127097979255, 0.517652241067591, 0.9474243017479858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 440}], {
             RGBColor[
             0.49180637882440414`, 0.5900197711595778, 0.9551731398312997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 445}], {
             RGBColor[
             0.6362676306314246, 0.7014335946433976, 0.8570704599327624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 471}], {
             RGBColor[
             0.6177368111170849, 0.6889843691293607, 0.949835798706089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 483}], {
             RGBColor[
             0.3721485306125848, 0.49381307756373405`, 0.9451126459979831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 280}], {
             RGBColor[
             0.8840938928404751, 0.8311966531415633, 0.6266612736710523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 393}], {
             RGBColor[
             0.8212863018303977, 0.37830541923651906`, 0.43733634143054434`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 424}], {
             RGBColor[
             0.909285347796637, 0.9211993701574914, 0.6983496996359704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 480}], {
             RGBColor[
             0.8212863018303977, 0.37830541923651906`, 0.43733634143054434`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 485}], {
             RGBColor[
             0.7583339132442677, 0.8112101421367861, 0.9765274834430351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 491}], {
             RGBColor[
             0.8740221680200179, 0.9007836705270881, 0.907864041810482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 282}], {
             RGBColor[
             0.8551028163531313, 0.8864951889033998, 0.9282632067464176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 310}], {
             RGBColor[
             0.8324345846834329, 0.8698726836891285, 0.9793269539581313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 323}], {
             RGBColor[
             0.7863152183920679, 0.35093597075216587`, 0.43386395869808025`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 406}], {
             RGBColor[
             0.5091629531216888, 0.6054580571674408, 0.9566055762901342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 411}], {
             RGBColor[
             0.7214625641562007, 0.7823313055281786, 0.972872304010254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 419}], {
             RGBColor[
             0.8560336301359434, 0.8868801043234157, 0.912837213496372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 499}], {
             RGBColor[
             0.49815457489167514`, 0.5938875536762038, 0.955978665435371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 329}], {
             RGBColor[
             0.6743635959619225, 0.7404858380152741, 0.9504985700860796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 479}], {
             RGBColor[
             0.7040365636869146, 0.4785925324233068, 0.45251325734523273`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 304}], {
             RGBColor[
             0.8576778239713809, 0.4072766747795, 0.43920019213395534`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 307}], {
             RGBColor[
             0.7767619497572786, 0.8260020094706049, 0.9760044429968485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 311}], {
             RGBColor[
             0.8571646708769455, 0.8892303639319612, 0.9837330355496814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 351}], {
             RGBColor[
             0.5836394780198011, 0.6557387282891967, 0.9627552621344078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 371}], {
             RGBColor[
             0.6233004601596698, 0.6974249351697056, 0.9650138963941082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 429}], {
             RGBColor[
             0.8481396926516709, 0.8821799823500017, 0.9828335100634027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 442}], {
             RGBColor[
             0.9484400309008251, 0.912598469563262, 0.641192738476269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 435}], {
             RGBColor[
             0.6810491011891651, 0.26550198643357703`, 0.42522894316203175`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 453}], {
             RGBColor[
             0.8288369342092295, 0.22265888952309182`, 0.17524758680640434`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 497}], {
             RGBColor[
             0.8614371914594713, 0.3688111744124188, 0.20226679350435933`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 279}], {
             RGBColor[
             0.7087990053445978, 0.7698948913835827, 0.9466044476059713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 283}], {
             RGBColor[
             0.9612432522212473, 0.9706158614817322, 0.9504892439974157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 285}], {
             RGBColor[
             0.9729560011517169, 0.9596118076675606, 0.6606806059307365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 396}], {
             RGBColor[
             0.6150302646886219, 0.6845864482332752, 0.9407793659430987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 421}], {
             RGBColor[
             0.8953401320524106, 0.9186139355818647, 0.9631831993085855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 430}], {
             RGBColor[
             0.9555798161265476, 0.9663920801153305, 0.9600759640450417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 459}], {
             RGBColor[
             0.9355005999699152, 0.8183262347471704, 0.5929797077015981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 477}], {
             RGBColor[
             0.6099091692933116, 0.6792038522766024, 0.9404877271363175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 284}], {
             RGBColor[
             0.8621345285818178, 0.4106004777807798, 0.43165615372320887`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 300}], {
             RGBColor[
             0.6862059258435519, 0.26996856875966346`, 0.4255575314690083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 305}], {
             RGBColor[
             0.8623837911144627, 0.3725641266088242, 0.20302844980631513`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 389}], {
             RGBColor[
             0.8762495794399884, 0.41935526323304206`, 0.30960146477246614`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 432}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 460}], {
             RGBColor[
             0.8738163388043336, 0.4190226768641425, 0.3988917067464562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 331}], {
             RGBColor[
             0.9906734093864851, 0.9882259572523028, 0.645383060814041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 346}], {
             RGBColor[
             0.9190614385225306, 0.9332206163365666, 0.7186271648831056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 348}], {
             RGBColor[
             0.8185171731810482, 0.8544694543483654, 0.7086603106314351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 355}], {
             RGBColor[
             0.6379588003012544, 0.7009287955051471, 0.6957890108483793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 372}], {
             RGBColor[
             0.8140823112896505, 0.8508985443901294, 0.7082910054219499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 404}], {
             RGBColor[
             0.934931017012749, 0.7608901121789248, 0.3356565686430319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 418}], {
             RGBColor[
             0.8757956330685285, 0.418384317845508, 0.2601922036713271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 431}], {
             RGBColor[
             0.9930993941688113, 0.9876486268223874, 0.49028982475694094`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 444}], {
             RGBColor[
             0.7039964911975479, 0.7604921202229893, 0.6999102873511298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 486}], {
             RGBColor[
             0.9174463167242819, 0.9319327620559563, 0.7184731131241524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 306}], {
             RGBColor[
             0.6744631680920732, 0.7121290590977343, 0.6501688452285259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 347}], {
             RGBColor[
             0.30680269050795317`, 0.4337225279441098, 0.9410058375959278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 382}], {
             RGBColor[
             0.6186417168240443, 0.6961085373443454, 0.9659294414149144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 462}], {
             RGBColor[
             0.39558406076219954`, 0.5170567636243767, 0.9464272444438853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 288}], {
             RGBColor[
             0.5283870751411682, 0.6280074570228965, 0.9560157125821958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 313}], {
             RGBColor[
             0.6864003893543159, 0.6358977619145811, 0.6005061277103744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 340}], {
             RGBColor[
             0.6721000346952584, 0.7414776571696646, 0.9697438365812487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 373}], {
             RGBColor[
             0.6571842912436522, 0.729584248218424, 0.9683211596553931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 386}], {
             RGBColor[
             0.6746734324946475, 0.7435296147218751, 0.9699892895606538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 414}], {
             RGBColor[
             0.6994764080365039, 0.7631630839969072, 0.9673711111115101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 498}], {
             RGBColor[
             0.6933071663888846, 0.6632808313096366, 0.606063482635282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 401}], {
             RGBColor[
             0.8489551154563462, 0.3193239024652833, 0.1922234221602645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 451}], {
             RGBColor[
             0.5845752791493731, 0.5385453356897165, 0.5930885176825675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.7161963381549648, 0.755672407292884, 0.6641006833898425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 318}], {
             RGBColor[
             0.36834666747519873`, 0.4912376318563468, 0.9447732604423618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 335}], {
             RGBColor[
             0.4340365399245938, 0.5503623683970448, 0.9488774024139208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 396}], {
             RGBColor[
             0.35827060169186975`, 0.4806470478585986, 0.9441994434022047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 409}], {
             RGBColor[
             0.7093569082697673, 0.3841257224345036, 0.43936629161910223`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 421}], {
             RGBColor[
             0.6385804690556585, 0.714674535207188, 0.9666032767676915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 430}], {
             RGBColor[
             0.6988201531297954, 0.7624526797406539, 0.9634960415041477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 459}], {
             RGBColor[
             0.678740936973163, 0.6143868343724938, 0.5963997851607041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 477}], {
             RGBColor[
             0.3531495062965594, 0.4752644519019258, 0.9439078045954234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 338}], {
             RGBColor[
             0.9476014625330875, 0.8298835465278567, 0.2771176254175787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 383}], {
             RGBColor[
             0.8474295403470494, 0.8024795238459219, 0.6230267257243318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 393}], {
             RGBColor[
             0.8578682933965857, 0.35466168285785654`, 0.19939517435015724`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 480}], {
             RGBColor[
             0.8578682933965857, 0.35466168285785654`, 0.19939517435015724`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 317}], {
             RGBColor[
             0.4421657595092411, 0.5510243603760425, 0.9505911481496789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 322}], {
             RGBColor[
             0.7890942927457353, 0.8106273725383031, 0.6634973807106141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 324}], {
             RGBColor[
             0.529285595835787, 0.628736916600684, 0.9560864474226658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 343}], {
             RGBColor[
             0.679004100435692, 0.7485313580009089, 0.9690719091814217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 374}], {
             RGBColor[
             0.7452669392071862, 0.31844802775943826`, 0.4300602952055269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 397}], {
             RGBColor[
             0.7452669392071862, 0.31844802775943826`, 0.4300602952055269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 445}], {
             RGBColor[
             0.7968036264856038, 0.8391168386866545, 0.8683118376274088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 310}], {
             RGBColor[
             0.9632297458603606, 0.971813960336031, 0.9344342846103083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 323}], {
             RGBColor[
             0.8735119925100198, 0.4188968218501008, 0.4039355124661982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 406}], {
             RGBColor[
             0.6399581142986166, 0.7073993338143432, 0.9117129069423111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 419}], {
             RGBColor[
             0.986828791312871, 0.9888213809703181, 0.8679445441485489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 499}], {
             RGBColor[
             0.6289497360686029, 0.6958288303231062, 0.911085996087548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 396}], {
             RGBColor[
             0.6107148485685193, 0.6813680179567481, 0.9480842397936492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 421}], {
             RGBColor[
             0.891024715932308, 0.9153955053053375, 0.970488073159136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 430}], {
             RGBColor[
             0.951264400006445, 0.9631736498388034, 0.9673808378955921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 459}], {
             RGBColor[
             0.9311851838498126, 0.8151078044706432, 0.6002845815521486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 477}], {
             RGBColor[
             0.605593753173209, 0.6759854220000753, 0.947792600986868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 300}], {
             RGBColor[
             0.6878726816380545, 0.752599569810665, 0.9573845277883257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 345}], {
             RGBColor[
             0.9286380592218676, 0.9455204844800323, 0.9786910291044129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 389}], {
             RGBColor[
             0.9729381620327092, 0.9766796115207329, 0.7834504277435126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 432}], {
             RGBColor[
             0.8621345285818178, 0.4106004777807799, 0.43165615372320887`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 456}], {
             RGBColor[
             0.7748595326440283, 0.8240160156945626, 0.9640123479682197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 472}], {
             RGBColor[
             0.9132208232111078, 0.9332271989747756, 0.9772205193705776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 287}], {
             RGBColor[
             0.8904518902571056, 0.8947523419614536, 0.679465943361903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 354}], {
             RGBColor[
             0.9303577555900953, 0.9264151215843099, 0.6833138830789529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 396}], {
             RGBColor[
             0.6224275974989889, 0.6703639641425765, 0.65827560172697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 409}], {
             RGBColor[
             0.88546157214118, 0.5106036666238222, 0.24875039716894565`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 430}], {
             RGBColor[
             0.9629771489369146, 0.9521695960246319, 0.6775721998289129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 473}], {
             RGBColor[
             0.8716637779873613, 0.40454777452562063`, 0.23553761390486927`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 477}], {
             RGBColor[
             0.6173065021036785, 0.6649813681859037, 0.6579839629201887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 319}], {
             RGBColor[
             0.7978857991748554, 0.8260050233764453, 0.6764341378183569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 330}], {
             RGBColor[
             0.9726600085674484, 0.9634723629484747, 0.6698454845374091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 357}], {
             RGBColor[
             0.9848478369477918, 0.9722224997311093, 0.6340100170935505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 358}], {
             RGBColor[
             0.9284436780839074, 0.9288900814024785, 0.6890175959500917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 367}], {
             RGBColor[
             0.9084600117431101, 0.9129556483044992, 0.6871115360148767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 368}], {
             RGBColor[
             0.9271581663617632, 0.9278650492495268, 0.6888949826944437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 492}], {
             RGBColor[
             0.8726993389852112, 0.40804096493265385`, 0.2395605728322311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 336}], {
             RGBColor[
             0.7564493590061208, 0.8096632555744254, 0.9763594607507071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 354}], {
             RGBColor[
             0.8404563118851169, 0.8757781399689015, 0.9846029847262483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 388}], {
             RGBColor[
             0.8973108779107435, 0.9179658543077964, 0.8643361617915408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 409}], {
             RGBColor[
             0.8255272763378612, 0.4768456788802166, 0.44960979826714254`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 436}], {
             RGBColor[
             0.7194734937804763, 0.7807167288151331, 0.9727155528612238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 473}], {
             RGBColor[
             0.8117294821840424, 0.3707897867820151, 0.43639701500306616`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 313}], {
             RGBColor[
             0.7571081157470665, 0.6933014795469901, 0.6060724989429478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 321}], {
             RGBColor[
             0.7519654506971352, 0.8061834679175284, 0.9761836764239067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 373}], {
             RGBColor[
             0.7278920176364028, 0.786987965850833, 0.9738875308879666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 386}], {
             RGBColor[
             0.7453811588873981, 0.800933332354284, 0.9755556607932272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 391}], {
             RGBColor[
             0.5207786932111205, 0.621535879847299, 0.9554981931814599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 455}], {
             RGBColor[
             0.4257814653550147, 0.5340507820981483, 0.9496355711634988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 498}], {
             RGBColor[
             0.7640148927816351, 0.7206845489420455, 0.6116298538678555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 300}], {
             RGBColor[
             0.6955140719701145, 0.758298506208687, 0.9444496471499353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 308}], {
             RGBColor[
             0.6030902637531727, 0.6718093738393884, 0.9387961473758762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 314}], {
             RGBColor[
             0.9518876024183053, 0.9636384331771686, 0.9663259187695334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 466}], {
             RGBColor[
             0.9189774141747781, 0.7408217625086142, 0.5773281130872203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 470}], {
             RGBColor[
             0.8672287888031911, 0.4143997687127945, 0.42303289996428184`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 493}], {
             RGBColor[
             0.8916782629986246, 0.9156853558354271, 0.9614941632366134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 297}], {
             RGBColor[
             0.4475034536957324, 0.5584696650302381, 0.9507183305191179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 484}], {
             RGBColor[
             0.6528687346579707, 0.7178717405732107, 0.8363360148629011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 349}], {
             RGBColor[
             0.8552164538576272, 0.8850970520329466, 0.8608516589882524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 353}], {
             RGBColor[
             0.8164112030504536, 0.7422884061833821, 0.611972181697785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 394}], {
             RGBColor[
             0.7923616391629353, 0.6365843289963622, 0.5920856551504262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 467}], {
             RGBColor[
             0.8431970812542797, 0.8443501172024703, 0.6550618063062958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 398}], {
             RGBColor[
             0.813559982519413, 0.8542785087198241, 0.9820517139733916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 399}], {
             RGBColor[
             0.906345705234745, 0.9231184985330563, 0.7203559174386783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 464}], {
             RGBColor[
             0.655767299313428, 0.7287009373019124, 0.9679029039301451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 481}], {
             RGBColor[
             0.690099435274948, 0.7565733119205738, 0.9706056554357938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 496}], {
             RGBColor[
             0.5677279715439508, 0.6534863967965397, 0.9620055672423363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 343}], {
             RGBColor[
             0.8473573866569506, 0.8815781530398017, 0.983227014248085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 403}], {
             RGBColor[
             0.7304019918733633, 0.7883822801497409, 0.9728207845092953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 440}], {
             RGBColor[
             0.820695660899842, 0.8607498102417277, 0.9805696225926094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 445}], {
             RGBColor[
             0.9651569127068624, 0.9721636337255475, 0.8824669426940721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 471}], {
             RGBColor[
             0.9466260931925228, 0.9597144082115106, 0.9752322814673987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 483}], {
             RGBColor[
             0.7010378126880227, 0.764543116645884, 0.9705091287592928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 497}], {
             RGBColor[
             0.9437714822212449, 0.8956815982966784, 0.6342097381314926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 296}], {
             RGBColor[
             0.7719415151715184, 0.8210714502285994, 0.9483445858958706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 327}], {
             RGBColor[
             0.7764368660504288, 0.8247209785853482, 0.9486984763840713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 385}], {
             RGBColor[
             0.9777921014473346, 0.9825929806848203, 0.9061315645732337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 415}], {
             RGBColor[
             0.9670509695751841, 0.9749472475750337, 0.9406582934124808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 438}], {
             RGBColor[
             0.6960703661099128, 0.7586511470501888, 0.9425995944298755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 439}], {
             RGBColor[
             0.8131396578602137, 0.854292389951878, 0.9517420769946383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 321}], {
             RGBColor[
             0.6164196039292726, 0.6927386501186981, 0.9664531574631485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 341}], {
             RGBColor[
             0.37343599463447025`, 0.49787322193870875`, 0.9450159892549923]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 391}], {
             RGBColor[
             0.385232846443258, 0.5080910620484687, 0.9457676742207017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 397}], {
             RGBColor[
             0.6542137026660646, 0.24225851301921494`, 0.42351901529775104`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 455}], {
             RGBColor[
             0.2902356185871522, 0.42060596429931796`, 0.9399050522027408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 327}], {
             RGBColor[
             0.5791830816131228, 0.6692459434108431, 0.9600145602835707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 339}], {
             RGBColor[
             0.7364419102447375, 0.31128347168469817`, 0.42936555659845665`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 385}], {
             RGBColor[
             0.7805383170100286, 0.8271179455103153, 0.9174476484727332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 415}], {
             RGBColor[
             0.7697971851378781, 0.8194722124005287, 0.9519743773119802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 438}], {
             RGBColor[
             0.49881658167260673`, 0.6031761118756838, 0.953915678329375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 325}], {
             RGBColor[
             0.7863277750549075, 0.8314308038884638, 0.9017134053414076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 392}], {
             RGBColor[
             0.5242685537534698, 0.6246638558230888, 0.9556914874919151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 412}], {
             RGBColor[
             0.5660759296696738, 0.658604966992685, 0.9589827172695028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 413}], {
             RGBColor[
             0.4179619993647691, 0.5275989837350735, 0.9490294248020084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 474}], {
             RGBColor[
             0.7887240268813938, 0.8305617630978785, 0.7268023990587642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 484}], {
             RGBColor[
             0.7896873349656177, 0.832820068248294, 0.846036803358591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 490}], {
             RGBColor[
             0.41839509158974497`, 0.5280541911231562, 0.9490540887635182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 335}], {
             RGBColor[
             0.512295403724772, 0.6139311581047691, 0.9550286340042686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 409}], {
             RGBColor[
             0.7615294841365526, 0.4265049155729865, 0.44346711267933403`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 468}], {
             RGBColor[
             0.43274014093895485`, 0.5402330172039689, 0.9501348785650572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 312}], {
             RGBColor[
             0.7447508465266021, 0.7242245377107945, 0.6145291491238181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 328}], {
             RGBColor[
             0.9653883914021246, 0.8905142718800683, 0.3429289885846688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 399}], {
             RGBColor[
             0.9669522450984391, 0.8956043660060178, 0.36474822066539725`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 407}], {
             RGBColor[
             0.7054045444183442, 0.6922814371286005, 0.6114316640916024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 448}], {
             RGBColor[
             0.9292655944130745, 0.8705958073519546, 0.6317267683500012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 475}], {
             RGBColor[
             0.7694323513996064, 0.744262095255823, 0.6164721675987523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 478}], {
             RGBColor[
             0.8880827689989421, 0.8377577402447415, 0.6277987136976588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 482}], {
             RGBColor[
             0.9266968897720093, 0.8685475919967991, 0.6314817630082266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 305}], {
             RGBColor[
             0.6882465754370218, 0.6955450430527316, 0.6144429719129851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 308}], {
             RGBColor[
             0.3315559693137138, 0.455162573909692, 0.9425830946329659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 432}], {
             RGBColor[
             0.6862059258435519, 0.2699685687596635, 0.4255575314690083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 456}], {
             RGBColor[
             0.5109666285366294, 0.613068152162888, 0.9548644145869187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 493}], {
             RGBColor[
             0.6201439685591659, 0.6990385559057306, 0.9652811104937031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 316}], {
             RGBColor[
             0.5276887918985542, 0.614925427427581, 0.959244448378949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 336}], {
             RGBColor[
             0.7554013216637574, 0.8088445208371924, 0.9762550021828862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 388}], {
             RGBColor[
             0.8962628405683801, 0.9171471195705634, 0.8642317032237198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 436}], {
             RGBColor[
             0.718425456438113, 0.7798979940779001, 0.9726110942934028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 346}], {
             RGBColor[
             0.9122571289122567, 0.9317528573104414, 0.952653981518983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 370}], {
             RGBColor[
             0.9355438178376322, 0.7931017193286933, 0.5758724040360177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 390}], {
             RGBColor[
             0.7676142858140985, 0.8172299939945342, 0.939195349051934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 422}], {
             RGBColor[
             0.902317888146422, 0.9238275765172681, 0.9517059678618727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 443}], {
             RGBColor[
             0.9305717656291512, 0.9463564514909228, 0.9544008479187096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 451}], {
             RGBColor[
             0.6180317459573728, 0.6856681997339282, 0.9290685065850387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 379}], {
             RGBColor[
             0.7676715826381493, 0.8133643156381232, 0.7164471013522322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 400}], {
             RGBColor[
             0.9791016312750264, 0.9804789902975437, 0.7097528351429394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 307}], {
             RGBColor[
             0.7499221425334716, 0.3222273315342365, 0.4304267698639437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 311}], {
             RGBColor[
             0.8035239566132494, 0.3643795678418074, 0.4355791648991656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 337}], {
             RGBColor[
             0.7572682611376783, 0.3281912415560034, 0.43100508323018594`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 423}], {
             RGBColor[
             0.8521112921515402, 0.4028844297965258, 0.44027645652516856`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 427}], {
             RGBColor[
             0.8733138563576567, 0.4101138763254527, 0.24194785678231298`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 433}], {
             RGBColor[
             0.8577487780387825, 0.4073295922067915, 0.43908008540562904`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 465}], {
             RGBColor[
             0.8748386818756022, 0.4194454419971306, 0.38194883631647814`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 469}], {
             RGBColor[
             0.7364419102447375, 0.3112834716846981, 0.42936555659845665`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 310}], {
             RGBColor[
             0.9465374437670251, 0.9023149174741161, 0.6330736906204837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 406}], {
             RGBColor[
             0.623265812205281, 0.6379002909524284, 0.6103523129524865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 432}], {
             RGBColor[
             0.8623837911144627, 0.3725641266088242, 0.20302844980631513`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 460}], {
             RGBColor[
             0.9696621948781944, 0.9191262052094501, 0.574444234829157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 493}], {
             RGBColor[
             0.8844107664655321, 0.8529318926794717, 0.6314874879996633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 331}], {
             RGBColor[
             0.9815255179161984, 0.9575197324078621, 0.5969405603691018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 347}], {
             RGBColor[
             0.6067926386808921, 0.647079972694018, 0.646092602491505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 382}], {
             RGBColor[
             0.9186316649969832, 0.9094659820942536, 0.6710162063104915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 431}], {
             RGBColor[
             0.9839515026985246, 0.9569424019779467, 0.4418473243120018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 486}], {
             RGBColor[
             0.9082984252539952, 0.9012265372115156, 0.6700306126792133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 337}], {
             RGBColor[
             0.6261476055067248, 0.7073738596353598, 0.9637117796411946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 427}], {
             RGBColor[
             0.8002159983366922, 0.8302578117895338, 0.6801259399693851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 433}], {
             RGBColor[
             0.776868380858381, 0.8260813856115421, 0.9758242829043591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 442}], {
             RGBColor[
             0.786806508743961, 0.7850244546953666, 0.6280326050712517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 469}], {
             RGBColor[
             0.5949080791673135, 0.682012204828402, 0.9612524896936006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 500}], {
             RGBColor[
             0.6051671647974926, 0.6903409927095221, 0.9620601224946772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 362}], {
             RGBColor[
             0.35167360730016606`, 0.47229158024062484`, 0.9439467254139647]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 369}], {
             RGBColor[
             0.47788464903460737`, 0.5736175433390078, 0.9546604726918324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 389}], {
             RGBColor[
             0.6166214497083684, 0.67924261561976, 0.7686489945881527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 456}], {
             RGBColor[
             0.4185428203196876, 0.5265790197935896, 0.9492109148128598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 393}], {
             RGBColor[
             0.8182277062132116, 0.37586657811474117`, 0.4370446098501366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 424}], {
             RGBColor[
             0.9046974543708577, 0.9175411084748246, 0.6979121022653587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 323}], {
             RGBColor[
             0.858399838063554, 0.40781515170725324`, 0.43797801060734065`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 406}], {
             RGBColor[
             0.6172898826289179, 0.6907768286000718, 0.9627766541540248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 408}], {
             RGBColor[
             0.6292485209647104, 0.7024964810849892, 0.9634887902017777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 419}], {
             RGBColor[
             0.9641605596431726, 0.9721988757560467, 0.9190082913602626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 366}], {
             RGBColor[
             0.6306024790373697, 0.7089443300124044, 0.9654614794256872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 405}], {
             RGBColor[
             0.8162769278479394, 0.8566971220948784, 0.9822439338668927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 423}], {
             RGBColor[
             0.8488148731471845, 0.8826419964574999, 0.9853474321365013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 429}], {
             RGBColor[
             0.7669088916144736, 0.8178343219434628, 0.9774019692112181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 465}], {
             RGBColor[
             0.8829059577332774, 0.907483514758407, 0.8978560018234656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 469}], {
             RGBColor[
             0.6753108002869803, 0.7452405592897584, 0.9689810822464335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 488}], {
             RGBColor[
             0.5222131150269899, 0.6122087879412037, 0.9584515547308105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 327}], {
             RGBColor[
             0.5660393186569166, 0.6585752445232215, 0.958979835116468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 334}], {
             RGBColor[
             0.6936347940069739, 0.7593053546030997, 0.9710422620846062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 385}], {
             RGBColor[
             0.7673945540538224, 0.8164472466226935, 0.9164129233056304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 415}], {
             RGBColor[
             0.7566534221816719, 0.808801513512907, 0.9509396521448775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 446}], {
             RGBColor[
             0.4813649856033654, 0.5887741844635388, 0.952606461845577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 386}], {
             RGBColor[
             0.9033944731005458, 0.8088236372459686, 0.6200460759214057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 391}], {
             RGBColor[
             0.6787920074242682, 0.6294261847389837, 0.5999886083096384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 407}], {
             RGBColor[
             0.6924145152827492, 0.6407803002765688, 0.6009795817339298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 498}], {
             RGBColor[
             0.9220282069947828, 0.7285748538337302, 0.256120268996034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 406}], {
             RGBColor[
             0.6153725447471057, 0.6893468811471688, 0.9660222070661244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 411}], {
             RGBColor[
             0.8276721557816176, 0.8662201295079066, 0.9822889347862443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 493}], {
             RGBColor[
             0.8765174990073568, 0.9043784828742121, 0.9871573821133013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 349}], {
             RGBColor[
             0.9741513701449064, 0.9786155740023545, 0.8557724827096376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 353}], {
             RGBColor[
             0.9353461193377328, 0.83580692815279, 0.60689300541917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 364}], {
             RGBColor[
             0.7743508103070922, 0.8235187646207383, 0.9617126695367028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 378}], {
             RGBColor[
             0.9491920275618827, 0.9616280778628472, 0.9708888238829375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 380}], {
             RGBColor[
             0.9643934862575085, 0.9454971716335785, 0.6587680866428361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 487}], {
             RGBColor[
             0.6370761599200999, 0.7084486588539658, 0.9519073277902469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 372}], {
             RGBColor[
             0.4461694676517117, 0.551135549613659, 0.95119208435713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 418}], {
             RGBColor[
             0.6305204039765693, 0.21854232132786103`, 0.4221262562947805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 322}], {
             RGBColor[
             0.6300972346334175, 0.6745616496360309, 0.6523436432437124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 343}], {
             RGBColor[
             0.5200070423233742, 0.6124656350986367, 0.95791817171452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 374}], {
             RGBColor[
             0.6392689004656411, 0.22773754582459013`, 0.4226244702275924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 440}], {
             RGBColor[
             0.4933453165662657, 0.5916372923005627, 0.9552607800590444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 445}], {
             RGBColor[
             0.6378065683732861, 0.7030511157843824, 0.8571581001605071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 471}], {
             RGBColor[
             0.6192757488589464, 0.6906018902703456, 0.9499234389338337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 335}], {
             RGBColor[
             0.3503438650519469, 0.4756445092444855, 0.9436261377912054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 421}], {
             RGBColor[
             0.5548877941830115, 0.6399566760546287, 0.9613520121449761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 430}], {
             RGBColor[
             0.6151274782571485, 0.6877348205880947, 0.9582447768814322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 459}], {
             RGBColor[
             0.5950482621005162, 0.5396689752199344, 0.5911485205379887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 330}], {
             RGBColor[
             0.78708579078667, 0.8336084915269586, 0.9560339038590727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 357}], {
             RGBColor[
             0.7992736191670133, 0.8423586283095932, 0.9201984364152143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 368}], {
             RGBColor[
             0.7415839485809848, 0.7980011778280107, 0.9750834020161073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 492}], {
             RGBColor[
             0.7489831937980256, 0.3214650506516431, 0.43035285238000687`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 329}], {
             RGBColor[
             0.8577357798811907, 0.8893183417133808, 0.965659101637915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 424}], {
             RGBColor[
             0.8730975866759529, 0.8928545576644644, 0.6947626538632852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 341}], {
             RGBColor[
             0.6618524905655492, 0.732090332999762, 0.9693481008248879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 373}], {
             RGBColor[
             0.8807626667996191, 0.9077602591130558, 0.988489123497104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 391}], {
             RGBColor[
             0.6736493423743368, 0.7423081731095219, 0.9700997857905973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 397}], {
             RGBColor[
             0.8464913666201171, 0.3984032537265838, 0.4397404230110147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 455}], {
             RGBColor[
             0.5786521145182311, 0.6548230753603712, 0.9642371637726364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 498}], {
             RGBColor[
             0.9168855419448515, 0.8414568422042684, 0.6262314464769929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 343}], {
             RGBColor[
             0.8669355755598684, 0.8720686472608973, 0.6708244042754552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 374}], {
             RGBColor[
             0.8705545892899705, 0.4008062205994305, 0.23122862526821591`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 440}], {
             RGBColor[
             0.8402738498027599, 0.8512403044628233, 0.6681670126199797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 445}], {
             RGBColor[
             0.9847351016097803, 0.962654127946643, 0.5700643327214423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 471}], {
             RGBColor[
             0.9662042820954406, 0.9502049024326061, 0.662829671494769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 419}], {
             RGBColor[
             0.8741325350318944, 0.41915343213011125`, 0.39365151696616774`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 449}], {
             RGBColor[
             0.6286461100546239, 0.21657231957879808`, 0.4220195180286951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 499}], {
             RGBColor[
             0.6355464982023822, 0.22382506503197, 0.42241248492550043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 342}], {
             RGBColor[
             0.37028853772346926`, 0.4926711936984119, 0.9449327099557641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 360}], {
             RGBColor[
             0.7044811808353634, 0.7668866868652102, 0.958659325414968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 457}], {
             RGBColor[
             0.6800727379770299, 0.610808735321931, 0.5954909008683709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 392}], {
             RGBColor[
             0.7262742748049978, 0.7826766670062313, 0.896985773818515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 413}], {
             RGBColor[
             0.6199677204162971, 0.685611794918216, 0.8903237111286082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 474}], {
             RGBColor[
             0.9907297479329218, 0.988574574281021, 0.668096685385364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 490}], {
             RGBColor[
             0.620400812641273, 0.6860670023062987, 0.890348375090118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 338}], {
             RGBColor[
             0.9333875724897409, 0.897769611625808, 0.637907477036004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 346}], {
             RGBColor[
             0.8779565389712698, 0.9055227289530408, 0.9882214725197762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 355}], {
             RGBColor[
             0.5968539007499936, 0.6732309081216213, 0.9653833184850498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 395}], {
             RGBColor[
             0.6226985400001213, 0.6979810316650692, 0.9669435292782267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 443}], {
             RGBColor[
             0.8962711756881642, 0.9201263231335224, 0.9899683389195029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 334}], {
             RGBColor[
             0.7112739078420905, 0.77362558184747, 0.9724308777399095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 385}], {
             RGBColor[
             0.785033667888939, 0.830767473867064, 0.9178015389609337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 415}], {
             RGBColor[
             0.7742925360167885, 0.8231217407572774, 0.9523282678001809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 446}], {
             RGBColor[
             0.499004099438482, 0.6030944117079092, 0.9539950775008803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 398}], {
             RGBColor[
             0.8984534255538275, 0.9130845899301159, 0.6979059269983079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 399}], {
             RGBColor[
             0.9912391482691596, 0.9819245797433479, 0.4362101304635946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 407}], {
             RGBColor[
             0.7296914475890647, 0.7786016508659306, 0.6828935738897997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 464}], {
             RGBColor[
             0.7406607423478426, 0.787507018512204, 0.6837571169550614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 475}], {
             RGBColor[
             0.7937192545703269, 0.8305823089931532, 0.6879340773969497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 478}], {
             RGBColor[
             0.9123696721696626, 0.9240779539820716, 0.6992606234958562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 481}], {
             RGBColor[
             0.7749928783093625, 0.8153793931308655, 0.68645986846071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 333}], {
             RGBColor[
             0.9402493725412038, 0.843106298605329, 0.6014191394071629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 352}], {
             RGBColor[
             0.8837824870247553, 0.9096089736809037, 0.9653570253492985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 357}], {
             RGBColor[
             0.9740478285596064, 0.9798259678816226, 0.9136097831342663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 358}], {
             RGBColor[
             0.917643669695722, 0.9364935495529919, 0.9686173619908074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 367}], {
             RGBColor[
             0.8976600033549247, 0.9205591164550124, 0.9667113020555926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 368}], {
             RGBColor[
             0.9163581579735778, 0.9354685174000402, 0.9684947487351594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 441}], {
             RGBColor[
             0.9687799985519323, 0.9503841780964633, 0.6547723783055386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 492}], {
             RGBColor[
             0.8654993333930877, 0.4131099436996627, 0.4259604168593749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 348}], {
             RGBColor[
             0.8164416833619479, 0.8557964580641444, 0.9019027604314948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 372}], {
             RGBColor[
             0.8120068214705501, 0.8522255481059083, 0.9015334552220096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 382}], {
             RGBColor[
             0.9257040666481695, 0.9414992106544733, 0.9127011565554903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 404}], {
             RGBColor[
             0.9328555271936487, 0.7622171158947038, 0.5288990184430916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 418}], {
             RGBColor[
             0.8744119731891282, 0.41926898698936066`, 0.3890205035380336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 431}], {
             RGBColor[
             0.9910239043497109, 0.9889756305381663, 0.6835322745570007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 444}], {
             RGBColor[
             0.7019210013784476, 0.7618191239387683, 0.8931527371511896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 486}], {
             RGBColor[
             0.9153708269051815, 0.9332597657717353, 0.9117155629242122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 420}], {
             RGBColor[
             0.7907404836431193, 0.8328201965859751, 0.7778895901686559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 454}], {
             RGBColor[
             0.4355838955383851, 0.5457503526464884, 0.9500666783052781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 489}], {
             RGBColor[
             0.7766196539434782, 0.8249808104512445, 0.95170174389544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 358}], {
             RGBColor[
             0.8960330420576627, 0.8085240170593329, 0.6205912508198455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 361}], {
             RGBColor[
             0.954237533617087, 0.8526009192240092, 0.5357475000865437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 367}], {
             RGBColor[
             0.8760493757168654, 0.7925895839613535, 0.6186851908846307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 386}], {
             RGBColor[
             0.9051531305720109, 0.8157961280824662, 0.621461133003943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 441}], {
             RGBColor[
             0.9471693709138729, 0.8224146456028043, 0.30674626713457676`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 450}], {
             RGBColor[
             0.633934256635755, 0.5960218857494932, 0.5984333090791212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 461}], {
             RGBColor[
             0.9134704577891973, 0.8224281390376178, 0.622254447098884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 385}], {
             RGBColor[
             0.9126291432389964, 0.9314975839469422, 0.929863965929072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 415}], {
             RGBColor[
             0.9018880113668458, 0.9238518508371556, 0.964390694768319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 446}], {
             RGBColor[
             0.6265995747885393, 0.7038245217877874, 0.9660575044690184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 409}], {
             RGBColor[
             0.6973550399875994, 0.3737303073599294, 0.4386015431849979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 421}], {
             RGBColor[
             0.6205776666324067, 0.6990814125953267, 0.9654561541165351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 430}], {
             RGBColor[
             0.6808173507065436, 0.7468595571287926, 0.9623489188529912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 459}], {
             RGBColor[
             0.6607381345499113, 0.5987937117606325, 0.5952526625095477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 354}], {
             RGBColor[
             0.7963552243391103, 0.8413260351972818, 0.980207400467757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 388}], {
             RGBColor[
             0.853209790364737, 0.8835137495361767, 0.8599405775330495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 436}], {
             RGBColor[
             0.6753724062344697, 0.7462646240435133, 0.9683199686027326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 420}], {
             RGBColor[
             0.8156146341188115, 0.853014152509851, 0.7798477744111179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 427}], {
             RGBColor[
             0.8112351762430023, 0.8392036768221842, 0.6809934100187485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 433}], {
             RGBColor[
             0.7878875587646912, 0.8350272506441924, 0.9766917529537225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 500}], {
             RGBColor[
             0.6161863427038028, 0.6992868577421725, 0.9629275925440406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 383}], {
             RGBColor[
             0.8560641226903799, 0.836632021800209, 0.6303948280914389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 395}], {
             RGBColor[
             0.6455470123867983, 0.6642474645214049, 0.6135217800269084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 443}], {
             RGBColor[
             0.9191196480748414, 0.8863927559898581, 0.6365465896681844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 480}], {
             RGBColor[
             0.8636246816254727, 0.37743001482738125`, 0.20430724259489524`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 344}], {
             RGBColor[
             0.8464963795219052, 0.39840725087839785`, 0.43974090114606224`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 387}], {
             RGBColor[
             0.8242178970769094, 0.18715494604910077`, 0.1708243916320382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 439}], {
             RGBColor[
             0.7639073387038676, 0.3334307648335505, 0.4316305506643018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 384}], {
             RGBColor[
             0.8834414489301029, 0.9098962472702997, 0.9887446281280866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 414}], {
             RGBColor[
             0.9138970939833447, 0.9340370017760842, 0.9866656063431365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 461}], {
             RGBColor[
             0.8974114456586748, 0.9210355434562036, 0.9900770988872212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 499}], {
             RGBColor[
             0.5792611076246229, 0.6577863850223757, 0.9639198932946883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 374}], {
             RGBColor[
             0.6845022937569156, 0.2684929682732576, 0.42544897753891053`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 391}], {
             RGBColor[
             0.4306657330795345, 0.5474427449295326, 0.9486626175824411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 397}], {
             RGBColor[
             0.6845022937569156, 0.2684929682732576, 0.42544897753891053`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 455}], {
             RGBColor[
             0.3356685052234286, 0.4599576471803819, 0.94279999556448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 485}], {
             RGBColor[
             0.48530781119713273`, 0.5853583320188928, 0.9544596766386073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 374}], {
             RGBColor[
             0.7971611277499417, 0.359408877574501, 0.4349449775820876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 403}], {
             RGBColor[
             0.6398899884662379, 0.7167767598334422, 0.9659927030074731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 440}], {
             RGBColor[
             0.7301836574927166, 0.7891442899254291, 0.973741541090787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 445}], {
             RGBColor[
             0.874644909299737, 0.9005581134092489, 0.8756388611922499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 471}], {
             RGBColor[
             0.8561140897853974, 0.8881088878952119, 0.9684041999655764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 387}], {
             RGBColor[
             0.8602941736757238, 0.5044631429765994, 0.4529536844101387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 438}], {
             RGBColor[
             0.6638982855883582, 0.7338617806662333, 0.9694786951507833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 439}], {
             RGBColor[
             0.7809675773386591, 0.8295030235679226, 0.978621177715546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 389}], {
             RGBColor[
             0.9498106355091234, 0.9586526626584257, 0.7956089956782988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 456}], {
             RGBColor[
             0.7517320061204424, 0.8059890668322554, 0.9761709159030059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 472}], {
             RGBColor[
             0.8900932966875219, 0.9152002501124683, 0.9893790873053638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 355}], {
             RGBColor[
             0.5642713396181996, 0.6472504583051899, 0.9622755647175036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 390}], {
             RGBColor[
             0.7007311347413177, 0.7650194158207022, 0.9716550862851809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 395}], {
             RGBColor[
             0.5901159788683272, 0.6720005818486376, 0.9638357755106806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 431}], {
             RGBColor[
             0.9194119334857566, 0.9339702896224301, 0.7567763786260653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 443}], {
             RGBColor[
             0.8636886145563702, 0.8941458733170908, 0.9868605851519565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 486}], {
             RGBColor[
             0.843758856041227, 0.8782544248559991, 0.9849596669932768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 382}], {
             RGBColor[
             0.5509711874128631, 0.6310594509406291, 0.9618531986778935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 462}], {
             RGBColor[
             0.3279135313510183, 0.4520076772206604, 0.9423510017068644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 355}], {
             RGBColor[
             0.4637270742767172, 0.5684992963169887, 0.952308710465833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 372}], {
             RGBColor[
             0.6398505852651133, 0.718469045201971, 0.9648107050394037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 400}], {
             RGBColor[
             0.8047613252193095, 0.8478172494018172, 0.9544542684447677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 404}], {
             RGBColor[
             0.7606992909882119, 0.6284606129907664, 0.5921762682604856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 418}], {
             RGBColor[
             0.7596411490521704, 0.3300979850534024, 0.4312053367496296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 431}], {
             RGBColor[
             0.8188676681442741, 0.8552191276342289, 0.7468095243743946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 444}], {
             RGBColor[
             0.5297647651730107, 0.6280626210348309, 0.9564299869685835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 486}], {
             RGBColor[
             0.7432145906997447, 0.7995032628677979, 0.9749928127416061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 353}], {
             RGBColor[
             0.9551807579627345, 0.8489724284713371, 0.500451451309945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 378}], {
             RGBColor[
             0.9690266661868845, 0.9747935781813943, 0.8644472697737124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 380}], {
             RGBColor[
             0.9842281248825104, 0.9586626719521256, 0.5523265325336112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 487}], {
             RGBColor[
             0.6569107985451017, 0.7216141591725129, 0.8454657736810218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 377}], {
             RGBColor[
             0.8823865142103221, 0.4834946312161746, 0.24816257287991458`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 412}], {
             RGBColor[
             0.7374068507405005, 0.38024619719302555`, 0.4381578598475686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 426}], {
             RGBColor[
             0.6774318998519623, 0.3300097205622236, 0.433863606723485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 476}], {
             RGBColor[
             0.886486448168949, 0.49626906806310256`, 0.3538509106884321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 371}], {
             RGBColor[
             0.26854446626532813`, 0.3995876391204022, 0.93860458212665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 442}], {
             RGBColor[
             0.5936840370064834, 0.6147611735139585, 0.6147834242088109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 460}], {
             RGBColor[
             0.6078472502692301, 0.6733577314161604, 0.9022925340531591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 357}], {
             RGBColor[
             0.8959703154050986, 0.9183591104635382, 0.92952155790544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 367}], {
             RGBColor[
             0.819582490200417, 0.8590922590369281, 0.9826230768267663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 368}], {
             RGBColor[
             0.83828064481907, 0.8740016599819558, 0.9844065235063331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 375}], {
             RGBColor[
             0.8289522440435995, 0.8665634464162892, 0.983516772312807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 380}], {
             RGBColor[
             0.9454228740753368, 0.8158540261025611, 0.30344705524314364`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 487}], {
             RGBColor[
             0.618105547737928, 0.5788055133229484, 0.5965862963905544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 388}], {
             RGBColor[
             0.9372167432437333, 0.9496286339306528, 0.8681841015085906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 409}], {
             RGBColor[
             0.8521311865598542, 0.49795419862878754`, 0.4521750914118424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 436}], {
             RGBColor[
             0.759379359113466, 0.8123795084379895, 0.9765634925782736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 473}], {
             RGBColor[
             0.8383333924060355, 0.391898306530586, 0.43896230814776604`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 395}], {
             RGBColor[
             0.309013340647051, 0.43970876101721823`, 0.9409976214759541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 404}], {
             RGBColor[
             0.5801409181084181, 0.47491995414754806`, 0.5793049684774298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 431}], {
             RGBColor[
             0.6383092952644802, 0.7016784687910107, 0.7339382245913388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 443}], {
             RGBColor[
             0.582585976335094, 0.6618540524856713, 0.9640224311172302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 444}], {
             RGBColor[
             0.3492063922932169, 0.4745219621916126, 0.9435586871855277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 486}], {
             RGBColor[
             0.5626562178199508, 0.6459626040245796, 0.9621215129585503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 365}], {
             RGBColor[
             0.614842790588304, 0.690456930552975, 0.9666624859417987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 457}], {
             RGBColor[
             0.6043138687543337, 0.5450372758503539, 0.5906425918649036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 494}], {
             RGBColor[
             0.34094798118733605`, 0.46946973963802935`, 0.9429555480242583]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 367}], {
             RGBColor[
             0.9098478317352681, 0.929309253237647, 0.9308758346117341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 368}], {
             RGBColor[
             0.9285459863539212, 0.9442186541826747, 0.9326592812913009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 441}], {
             RGBColor[
             0.9809678269322756, 0.9591343148790978, 0.6189369108616802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 492}], {
             RGBColor[
             0.8736245523133166, 0.4189433682214191, 0.402070105230136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 361}], {
             RGBColor[
             0.9316318307716053, 0.9459881701716719, 0.9029457226701882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 386}], {
             RGBColor[
             0.8825474277265292, 0.9091833790301291, 0.9886593555875876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 398}], {
             RGBColor[
             0.8403294478734954, 0.8756229811249145, 0.9846052145086198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 441}], {
             RGBColor[
             0.9245636680683912, 0.9158018965504671, 0.6739444897182212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 408}], {
             RGBColor[
             0.2874293698342333, 0.41858723551590094`, 0.9397111587329374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 440}], {
             RGBColor[
             0.48022257183265793`, 0.577844455555469, 0.9545134591598265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 463}], {
             RGBColor[
             0.35830081622144627`, 0.4797998199449326, 0.9442747422430637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 483}], {
             RGBColor[
             0.3605647236208386, 0.4816377619596254, 0.9444529653265099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 457}], {
             RGBColor[
             0.9271455447623782, 0.8073116722640878, 0.603722217054588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 494}], {
             RGBColor[
             0.6637796571953806, 0.7317441360517634, 0.9560351732139427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 386}], {
             RGBColor[
             0.9407519192859535, 0.9532602811948053, 0.9038156048542858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 398}], {
             RGBColor[
             0.8985339394329197, 0.9196998832895907, 0.899761463775318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 441}], {
             RGBColor[
             0.9827681596278155, 0.9598787987151434, 0.5891007389849194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 481}], {
             RGBColor[
             0.7750733921884547, 0.8219946864903404, 0.8883154052377202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 369}], {
             RGBColor[
             0.5904260952380015, 0.6772356820392391, 0.9616776032468902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 470}], {
             RGBColor[
             0.6996176845011868, 0.28138790631361876`, 0.42646661865634083`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 381}], {
             RGBColor[
             0.3129995080693012, 0.44429399947821036`, 0.9412101457511753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 378}], {
             RGBColor[
             0.7692261063490704, 0.819696768799778, 0.9703874566007777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 380}], {
             RGBColor[
             0.7844275650446962, 0.8035658625705093, 0.6582667193606764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 381}], {
             RGBColor[
             0.4449019271534192, 0.5547109485066293, 0.9506731736694897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 416}], {
             RGBColor[
             0.791817988749514, 0.8357052593128371, 0.8945060574433814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 452}], {
             RGBColor[
             0.7930081267235649, 0.8361974119502579, 0.8747823912350129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 468}], {
             RGBColor[
             0.42565405051199384`, 0.534480209770626, 0.9495770355694422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 487}], {
             RGBColor[
             0.4571102387072875, 0.5665173497908966, 0.9514059605080871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 405}], {
             RGBColor[
             0.6709455370455608, 0.7407567485818605, 0.9694039185950829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 423}], {
             RGBColor[
             0.703483482344806, 0.766701622944482, 0.9725074168646916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 429}], {
             RGBColor[
             0.621577500812095, 0.701893948430445, 0.9645619539394084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 465}], {
             RGBColor[
             0.7375745669308987, 0.7915431412453892, 0.8850159865516558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 469}], {
             RGBColor[
             0.5299794094846018, 0.6293001857767404, 0.9561410669746238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 488}], {
             RGBColor[
             0.37688172422461125`, 0.49626841442818587`, 0.9456115394590007]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 368}], {
             RGBColor[
             0.8521581611492395, 0.8849518027560646, 0.9857608002126272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 375}], {
             RGBColor[
             0.8428297603737689, 0.877513589190398, 0.984871049019101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 441}], {
             RGBColor[
             0.9045800017275939, 0.8998674634524877, 0.6720384297830064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 450}], {
             RGBColor[
             0.591344887449476, 0.6734747035991766, 0.963725471727551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 492}], {
             RGBColor[
             0.8351647719226308, 0.3893717345670308, 0.43866008229739806`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 456}], {
             RGBColor[
             0.657295308257523, 0.7315231215922038, 0.9669417926457853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 390}], {
             RGBColor[
             0.724017823666693, 0.6263682778389541, 0.5948735088022157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 422}], {
             RGBColor[
             0.8587214259990164, 0.732965860361688, 0.6073841276121545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 443}], {
             RGBColor[
             0.8869753034817456, 0.7554947353353427, 0.6100790076689913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 451}], {
             RGBColor[
             0.5744352838099672, 0.4948064835783481, 0.5847466663353205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 442}], {
             RGBColor[
             0.6333450191463521, 0.6564473803944675, 0.6170420584685113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 460}], {
             RGBColor[
             0.6475082324090988, 0.7150439382966693, 0.9045511683128595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 400}], {
             RGBColor[
             0.8003264633279119, 0.8442463394435811, 0.9540849632352826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 404}], {
             RGBColor[
             0.7562644290968141, 0.6248897030325303, 0.5918069630510006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 418}], {
             RGBColor[
             0.7566845744579053, 0.3277173784145783, 0.4309591332766395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 431}], {
             RGBColor[
             0.8144328062528765, 0.851648217675993, 0.7464402191649095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 444}], {
             RGBColor[
             0.5253299032816131, 0.6244917110765948, 0.9560606817590984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 486}], {
             RGBColor[
             0.738779728808347, 0.7959323529095619, 0.974623507532121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 449}], {
             RGBColor[
             0.5539947819513793, 0.6350138578913773, 0.9619077660236246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 498}], {
             RGBColor[
             0.8928121088841191, 0.8222613401375729, 0.6239353009410529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 397}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 445}], {
             RGBColor[
             0.8756941451165496, 0.4197991980316648, 0.367771596546079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 402}], {
             RGBColor[
             0.6433699801719535, 0.7178918015961138, 0.9673371276883451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 417}], {
             RGBColor[
             0.8289458380723171, 0.3844129255232531, 0.43806691483504734`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 441}], {
             RGBColor[
             0.9139497555707765, 0.9073386508318488, 0.6729321252690472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 450}], {
             RGBColor[
             0.6007146412926585, 0.6809458909785377, 0.9646191672135918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 461}], {
             RGBColor[
             0.8802508424461009, 0.9073521442666623, 0.9884403052333545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 391}], {
             RGBColor[
             0.7183947547443058, 0.7739673876661234, 0.7866566196658924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 448}], {
             RGBColor[
             0.9558783125975171, 0.9636358734270627, 0.8079426973485824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 455}], {
             RGBColor[
             0.6233975268881999, 0.6864822899169727, 0.7807939976479313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 475}], {
             RGBColor[
             0.796045069584049, 0.837302161330931, 0.7926880965973337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 482}], {
             RGBColor[
             0.9533096079564518, 0.9615876580719073, 0.807697692006808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 412}], {
             RGBColor[
             0.7652993005407005, 0.7986645923147723, 0.6725533850727168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 426}], {
             RGBColor[
             0.6753368742078931, 0.7233098773685693, 0.6661120053865914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 476}], {
             RGBColor[
             0.9889186966833732, 0.9726988986198877, 0.546092961334012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 380}], {
             RGBColor[
             0.9592687822994868, 0.9416751758126183, 0.6674428737069111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 416}], {
             RGBColor[
             0.9666592060043044, 0.9738145725549461, 0.9036822117896162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 452}], {
             RGBColor[
             0.9678493439783553, 0.9743067251923669, 0.8839585455812476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 487}], {
             RGBColor[
             0.631951455962078, 0.7046266630330056, 0.9605821148543219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 400}], {
             RGBColor[
             0.753807154645231, 0.8064798689840067, 0.9504227928499394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 404}], {
             RGBColor[
             0.7097451204141333, 0.587123232572956, 0.5881447926656573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 440}], {
             RGBColor[
             0.6229495188719809, 0.7038405707259706, 0.964100604247272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 487}], {
             RGBColor[
             0.6471529146577039, 0.6884957568037369, 0.6484613776142205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 416}], {
             RGBColor[
             0.6423350268086534, 0.7088287522617973, 0.8839679288583281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 468}], {
             RGBColor[
             0.27617108857113315`, 0.40760370271958635`, 0.939038906984389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 425}], {
             RGBColor[
             0.8624304900152295, 0.8931426789588661, 0.9867405841100816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 462}], {
             RGBColor[
             0.6397525576671095, 0.714393686620896, 0.967274605525851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 393}], {
             RGBColor[
             0.796843400168114, 0.3591606663727581, 0.434913309466064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 395}], {
             RGBColor[
             0.5453750902007602, 0.6368434418394702, 0.9594308803336615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 443}], {
             RGBColor[
             0.8189477258888032, 0.8589887333079234, 0.9824556899749376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 480}], {
             RGBColor[
             0.796843400168114, 0.3591606663727581, 0.434913309466064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 402}], {
             RGBColor[
             0.657451311672531, 0.7291198731071131, 0.9686802176574233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 411}], {
             RGBColor[
             0.7994898251771523, 0.8437748091958088, 0.9805198281847827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 458}], {
             RGBColor[
             0.6348482634495678, 0.7095422487986185, 0.9672399714117468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 461}], {
             RGBColor[
             0.8943321739466785, 0.9185802157776617, 0.9897833952024326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 499}], {
             RGBColor[
             0.5761818359126266, 0.655331057343834, 0.9636261896098998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 415}], {
             RGBColor[
             0.9756477714136943, 0.9809937428567495, 0.9097613559893434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 446}], {
             RGBColor[
             0.7003593348353878, 0.7609664138073813, 0.9114281656900427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 441}], {
             RGBColor[
             0.9336837565827394, 0.9230740075736005, 0.6748143719023189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 498}], {
             RGBColor[
             0.9103012501351144, 0.8362067066410239, 0.6256034308463134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 439}], {
             RGBColor[
             0.7777051328576863, 0.43948665693175204`, 0.44484333392837816`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 436}], {
             RGBColor[
             0.8162339251390927, 0.8545672227768843, 0.8562966696435661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 473}], {
             RGBColor[
             0.87623643642312, 0.4200234494231826, 0.35878442619129436`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 456}], {
             RGBColor[
             0.7960321089312841, 0.8371481938729559, 0.7809303145421055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 472}], {
             RGBColor[
             0.9343933994983635, 0.9463593771531689, 0.7941384859444635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 422}], {
             RGBColor[
             0.6907918939754827, 0.7570941350275289, 0.9707070726280707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 443}], {
             RGBColor[
             0.7190457714582119, 0.7796230100011836, 0.9734019526849076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 451}], {
             RGBColor[
             0.40650575178643356`, 0.518934758244189, 0.9480696113512368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 407}], {
             RGBColor[
             0.45608509274680326`, 0.5690147005768778, 0.950405275972442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 448}], {
             RGBColor[
             0.6799461427415335, 0.7473290708002318, 0.9707003802308407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 455}], {
             RGBColor[
             0.34746535703221637`, 0.4701754872901418, 0.9435516805301896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 475}], {
             RGBColor[
             0.5201128997280654, 0.6209953587041002, 0.9554457794795919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 478}], {
             RGBColor[
             0.6387633173274012, 0.7144910036930188, 0.9667723255784983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 482}], {
             RGBColor[
             0.6773774381004682, 0.7452808554450764, 0.9704553748890661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 413}], {
             RGBColor[
             0.35790849911485945`, 0.47884484685284096`, 0.9443017932791157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 473}], {
             RGBColor[
             0.6996176845011868, 0.28138790631361876`, 0.42646661865634083`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 474}], {
             RGBColor[
             0.7286705266314841, 0.781807626215646, 0.7220747675358716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 490}], {
             RGBColor[
             0.35834159133983534`, 0.4793000542409237, 0.9443264572406256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 424}], {
             RGBColor[
             0.8746625967006936, 0.4146634942018086, 0.24718745832676925`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 480}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 467}], {
             RGBColor[
             0.919111821471869, 0.7025214164538409, 0.27477507208062973`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 443}], {
             RGBColor[
             0.6084306155852217, 0.6866041760291192, 0.9655826419104071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 430}], {
             RGBColor[
             0.6050514124738195, 0.6771442365903464, 0.9576709598412751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 477}], {
             RGBColor[
             0.25938076564058354`, 0.3899560087516183, 0.938082722932551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 495}], {
             RGBColor[
             0.7529056050807132, 0.3246494408335434, 0.430661638964446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 399}], {
             RGBColor[
             0.900017279250142, 0.9181746840560654, 0.7197251590790363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 464}], {
             RGBColor[
             0.649438873328825, 0.7237571228249214, 0.9672721455705031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 481}], {
             RGBColor[
             0.6837710092903448, 0.7516294974435829, 0.9699748970761518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 496}], {
             RGBColor[
             0.5613995455593477, 0.6485425823195488, 0.9613748088826943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 407}], {
             RGBColor[
             0.7312553012853791, 0.7836917449918801, 0.7047128059705281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 464}], {
             RGBColor[
             0.742224596044157, 0.7925971126381535, 0.7055763490357898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 478}], {
             RGBColor[
             0.9139335258659771, 0.9291680481080211, 0.7210798555765846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 481}], {
             RGBColor[
             0.776556732005677, 0.820469487256815, 0.7082791005414385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 496}], {
             RGBColor[
             0.6541852682746797, 0.7173825721327809, 0.699679012347981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 404}], {
             RGBColor[
             0.9211751690510104, 0.7542379072323766, 0.5814505264563645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 418}], {
             RGBColor[
             0.8666250677607027, 0.41394951454780915`, 0.42405484221354883`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 431}], {
             RGBColor[
             0.9793435462070726, 0.9809964218758391, 0.7360837825702735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 444}], {
             RGBColor[
             0.6902406432358092, 0.753839915276441, 0.9457042451644624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 428}], {
             RGBColor[
             0.8444438885883765, 0.3967706503213843, 0.439545132728542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 437}], {
             RGBColor[
             0.6943334107264211, 0.27700818766593693`, 0.42607540761889195`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 451}], {
             RGBColor[
             0.6305204039765693, 0.218542321327861, 0.4221262562947805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 417}], {
             RGBColor[
             0.6897261487089852, 0.27301760887415616`, 0.42578183695718286`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 458}], {
             RGBColor[
             0.4119373979039922, 0.5312212023139737, 0.947469264625872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 461}], {
             RGBColor[
             0.6714213084011029, 0.7402591692930169, 0.9700126884165579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 440}], {
             RGBColor[
             0.6132282627091294, 0.6959484170353682, 0.9633353113519976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 445}], {
             RGBColor[
             0.7576895145161497, 0.807362240519188, 0.8652326314534602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 471}], {
             RGBColor[
             0.7391586950018102, 0.7949130150051511, 0.9579979702267869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 483}], {
             RGBColor[
             0.49357041449731, 0.5997417234395246, 0.9532748175186809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 497}], {
             RGBColor[
             0.7363040840305322, 0.7308802050903189, 0.6169754268908807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 418}], {
             RGBColor[
             0.8372503782733043, 0.2677117569404419, 0.1825361754240275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 431}], {
             RGBColor[
             0.935281511975975, 0.7616397854647883, 0.37380578238599155`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 444}], {
             RGBColor[
             0.6461786090047116, 0.5344832788653903, 0.5834262449801804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 486}], {
             RGBColor[
             0.8596284345314456, 0.7059239206983573, 0.601989070753203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 423}], {
             RGBColor[
             0.8891579311553757, 0.9144544150269559, 0.9892898713058971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 429}], {
             RGBColor[
             0.8072519496226648, 0.8496467405129189, 0.981344408380614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 472}], {
             RGBColor[
             0.8656480232664463, 0.8957082526357729, 0.9870474753039085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 488}], {
             RGBColor[
             0.562556173035181, 0.6440212065106599, 0.9623939939002062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 419}], {
             RGBColor[
             0.6408889280814285, 0.707784249234359, 0.8962869136922654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 493}], {
             RGBColor[
             0.555163205327425, 0.6413938038054274, 0.9611904515332044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 448}], {
             RGBColor[
             0.6935686506000145, 0.758683186337817, 0.9716913536551319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 455}], {
             RGBColor[
             0.36108786489069744`, 0.48152960282772705`, 0.9445426539544808]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 475}], {
             RGBColor[
             0.5337354075865464, 0.6323494742416854, 0.9564367529038832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 478}], {
             RGBColor[
             0.6523858251858823, 0.7258451192306039, 0.9677632990027897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 482}], {
             RGBColor[
             0.6909999459589493, 0.7566349709826616, 0.9714463483133574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{408, 463}], {
             RGBColor[
             0.38880697412597176`, 0.5110140914772505, 0.9460431320916597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 430}], {
             RGBColor[
             0.8738774487910671, 0.5151238482556688, 0.44834730257848243`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 422}], {
             RGBColor[
             0.785304299671115, 0.8322495019004311, 0.9792236300683965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 428}], {
             RGBColor[
             0.8219033843997767, 0.8614326186073762, 0.9827144834422049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 437}], {
             RGBColor[
             0.5967376676068435, 0.6817889246242052, 0.9625098957777298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{412, 426}], {
             RGBColor[
             0.4578673790031607, 0.5684372263338459, 0.9511049358380724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{412, 476}], {
             RGBColor[
             0.7714492014786407, 0.8178262475851642, 0.8310858917854931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 474}], {
             RGBColor[
             0.6223639722427834, 0.6847427541276307, 0.7154127048459648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 490}], {
             RGBColor[
             0.25203503695113466`, 0.3822351821529084, 0.9376643945507186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 461}], {
             RGBColor[
             0.9247878189999204, 0.9427209702834463, 0.9877043734174824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 498}], {
             RGBColor[
             0.9351042256769708, 0.8558401759160562, 0.6229852523971697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 499}], {
             RGBColor[
             0.6066374809658684, 0.6794718118496185, 0.9615471678249496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 452}], {
             RGBColor[
             0.9904412263787991, 0.9903152157054258, 0.8080771464238513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 468}], {
             RGBColor[
             0.6230871501672279, 0.6885980135257941, 0.8828717907582806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{417, 458}], {
             RGBColor[
             0.6746574498936764, 0.25996585933515964`, 0.42482167279339855`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 431}], {
             RGBColor[
             0.8760292963773457, 0.4188841000360836, 0.2856250128333002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 444}], {
             RGBColor[
             0.6832940277298368, 0.26744642896981824`, 0.42537198789609276`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 486}], {
             RGBColor[
             0.8255939114143261, 0.3817401901917963, 0.4377472050781078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 427}], {
             RGBColor[
             0.9896830269487791, 0.9758981046640249, 0.4962619347393083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 454}], {
             RGBColor[
             0.6389058967198539, 0.7026387364122051, 0.7672933872682999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 489}], {
             RGBColor[
             0.979941655124947, 0.9818691942169613, 0.7689284528584619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 500}], {
             RGBColor[
             0.7946341934095793, 0.8359812855840133, 0.7781961172646004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 430}], {
             RGBColor[
             0.8853612798376083, 0.9111717239389359, 0.9800747932067619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 459}], {
             RGBColor[
             0.8652820636809759, 0.7631058785707757, 0.6129785368633184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 477}], {
             RGBColor[
             0.5396906330043723, 0.6239834961002078, 0.9604865562980378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 428}], {
             RGBColor[
             0.8620945810364677, 0.8928748342572079, 0.9867085448118178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 437}], {
             RGBColor[
             0.6369288642435347, 0.7132311402740368, 0.9665039571473427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 451}], {
             RGBColor[
             0.541209354118757, 0.6255323407669229, 0.9605802301611754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 429}], {
             RGBColor[
             0.8397898949219099, 0.8755916148755404, 0.9844479066502225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 465}], {
             RGBColor[
             0.9557869610407137, 0.9652408076904846, 0.90490193926247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 469}], {
             RGBColor[
             0.7481918035944166, 0.802997852221836, 0.9760270196854379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 488}], {
             RGBColor[
             0.5950941183344262, 0.6699660808732812, 0.9654974921698148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{425, 462}], {
             RGBColor[
             0.6393728339533846, 0.7140909052388973, 0.9672383871390524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 476}], {
             RGBColor[
             0.6814867751458333, 0.7424715326389613, 0.8246445120993677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 433}], {
             RGBColor[
             0.9619559515946586, 0.9579112027983663, 0.6931059132819131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 500}], {
             RGBColor[
             0.7902547355337702, 0.8221708098963465, 0.6793417528722311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 437}], {
             RGBColor[
             0.6735279489721964, 0.742414256980982, 0.9699948105211511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 451}], {
             RGBColor[
             0.5778084388474186, 0.6547154574738681, 0.9640710835349838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{429, 488}], {
             RGBColor[
             0.5131881368017153, 0.6051584063592443, 0.9575520292445316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{430, 459}], {
             RGBColor[
             0.9255217477551128, 0.8108840231042416, 0.6098713015997745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{430, 477}], {
             RGBColor[
             0.5999303170785092, 0.6717616406336737, 0.9573793210344939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 444}], {
             RGBColor[
             0.7043469861607738, 0.7612417935088529, 0.7380595010940895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 486}], {
             RGBColor[
             0.9177968116875077, 0.9326824353418199, 0.7566223268671121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{432, 460}], {
             RGBColor[
             0.8738163388043336, 0.4190226768641425, 0.3988917067464562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 465}], {
             RGBColor[
             0.9642431898715769, 0.9719085513058832, 0.9031073825831607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 469}], {
             RGBColor[
             0.7566480324252799, 0.8096655958372345, 0.9742324630061285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 495}], {
             RGBColor[
             0.7884687484771117, 0.8350284925125513, 0.9641155258582736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{435, 439}], {
             RGBColor[
             0.5327966598395489, 0.6301451269006912, 0.9568532407395003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{435, 453}], {
             RGBColor[
             0.7040849696076241, 0.4425657654797607, 0.4472881167748405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 473}], {
             RGBColor[
             0.7576781803362751, 0.3285240324280737, 0.4310373535710831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 439}], {
             RGBColor[
             0.5400147243613019, 0.6363970515989623, 0.9573131694281425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{439, 453}], {
             RGBColor[
             0.7869432071223268, 0.5104945438797341, 0.4536897242771105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 445}], {
             RGBColor[
             0.8479831835426284, 0.8797297706111749, 0.8729814695367742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 471}], {
             RGBColor[
             0.8294523640282889, 0.8672805450971379, 0.9657468083101008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 450}], {
             RGBColor[
             0.6624648826464835, 0.7032997652406274, 0.651786547977497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 461}], {
             RGBColor[
             0.9420010837999259, 0.929706018528752, 0.6756076859972597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 447}], {
             RGBColor[
             0.6073562390651733, 0.62913152474532, 0.6155620358898429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 500}], {
             RGBColor[
             0.776845245941039, 0.7769374528021793, 0.6272484179740978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{443, 451}], {
             RGBColor[
             0.5694632316014863, 0.6480612157405777, 0.9632751102180124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{444, 486}], {
             RGBColor[
             0.6286939087162444, 0.7055259287424218, 0.9662427894613009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{445, 471}], {
             RGBColor[
             0.9739136158353092, 0.9786943685809577, 0.8676441284115636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 454}], {
             RGBColor[
             0.2699885984289794, 0.4011055135876673, 0.9386868233169678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 500}], {
             RGBColor[
             0.4257168951187049, 0.5344480627594754, 0.9495895533132683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 455}], {
             RGBColor[
             0.5849489148854277, 0.6598439730510811, 0.9648377582128795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 475}], {
             RGBColor[
             0.7575964575812767, 0.8106638444650396, 0.976731857162282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 478}], {
             RGBColor[
             0.8762468751806125, 0.904159489453958, 0.9880584032611884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 482}], {
             RGBColor[
             0.9148609959536795, 0.9349493412060157, 0.9917414525717562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{449, 499}], {
             RGBColor[
             0.2616509123855092, 0.3923420769161522, 0.9382120044312934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 461}], {
             RGBColor[
             0.628765969521808, 0.703313258675441, 0.9672947279418043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{452, 468}], {
             RGBColor[
             0.6242772881412788, 0.6890901661632148, 0.8631481245499122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 489}], {
             RGBColor[
             0.6247850670202127, 0.6947993502774745, 0.9411055409950841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 500}], {
             RGBColor[
             0.4394776053048451, 0.5489114416445267, 0.9503732054012226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{455, 475}], {
             RGBColor[
             0.42511567187195953`, 0.5335102609549496, 0.9495831574616309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{455, 482}], {
             RGBColor[
             0.5823802102443625, 0.6577957576959257, 0.9645927528711051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{457, 494}], {
             RGBColor[
             0.6393712143370471, 0.5756661845084841, 0.5928667486673456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{458, 461}], {
             RGBColor[
             0.6488182601781396, 0.7206815449845223, 0.9685724421708813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{459, 477}], {
             RGBColor[
             0.5798511009218767, 0.5236957952655135, 0.5902830646910504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{460, 463}], {
             RGBColor[
             0.7232447184630928, 0.7805203532493549, 0.9094229179205773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{463, 483}], {
             RGBColor[
             0.46194232791257706`, 0.574064617920975, 0.9507849386852322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 481}], {
             RGBColor[
             0.52597832608436, 0.6260519260256711, 0.9558260870329053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 496}], {
             RGBColor[
             0.40360686235336274`, 0.5229650109016369, 0.9472259988394478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{465, 469}], {
             RGBColor[
             0.7822828881805095, 0.8278393705227431, 0.8885355893724022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 470}], {
             RGBColor[
             0.8351814873133276, 0.2583174062929483, 0.18080984209386503`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 491}], {
             RGBColor[
             0.9297388634178858, 0.7481200787276139, 0.5265303868920599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 483}], {
             RGBColor[
             0.7097945158164695, 0.7710738515012943, 0.9556863144767842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 497}], {
             RGBColor[
             0.9525281853496916, 0.9022123331520886, 0.6193869238489841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{472, 488}], {
             RGBColor[
             0.5715842104454968, 0.6512199184820984, 0.9632550961678262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{474, 490}], {
             RGBColor[
             0.6227970644677593, 0.6851979615157135, 0.7154373688074747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{475, 478}], {
             RGBColor[
             0.7164136321671444, 0.7778257773578264, 0.9728038025099397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{475, 482}], {
             RGBColor[
             0.7550277529402114, 0.808615629109884, 0.9764868518205074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{478, 482}], {
             RGBColor[
             0.8736781705395473, 0.9021112740988027, 0.9878133979194139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{481, 496}], {
             RGBColor[
             0.4379389983148827, 0.5508373855202984, 0.9499287503450965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{484, 490}], {
             RGBColor[
             0.6237603725519834, 0.6874562666661289, 0.8346717731073012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{489, 500}], {
             RGBColor[
             0.7805133637099382, 0.8281418994492827, 0.9520082709913846]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.0860569014282922], {
             RGBColor[
             0.9552820733065902, 0.9661700240077153, 0.9605799649754652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.0860569014282922], {
             RGBColor[
             0.7153791446586231, 0.7775788919809703, 0.9722659656075229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.0860569014282922], {
             RGBColor[
             0.6523881329755558, 0.728369834904738, 0.9659876102474271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.0860569014282922], {
             RGBColor[
             0.8911094427050128, 0.5984352360068067, 0.23085138865231034`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.0860569014282922], {
             RGBColor[
             0.6839868523744643, 0.7530549946583275, 0.9691370752902886]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.0860569014282922], {
             RGBColor[
             0.8840877097043581, 0.5665511864182421, 0.22499228251813833`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.0860569014282922], {
             RGBColor[
             0.3179355277387587, 0.44980150704821886`, 0.9414795485815334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.0860569014282922], {
             RGBColor[
             0.5508696709985361, 0.646259841169309, 0.95778562488455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.0860569014282922], {
             RGBColor[
             0.7177237229787834, 0.7794104943841348, 0.9724996512631464]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.0860569014282922], {
             RGBColor[
             0.3552328729671579, 0.4821065928659801, 0.9438561024387396]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.0860569014282922], {
             RGBColor[
             0.5353901417107647, 0.6336928619486486, 0.9565670196356325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.0860569014282922], {
             RGBColor[
             0.9929446567386303, 0.9873176591055842, 0.4734476104104609]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.0860569014282922], {
             RGBColor[
             0.8733176981079966, 0.5176470791592801, 0.21600552084499258`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.0860569014282922], {
             RGBColor[
             0.8197729503376738, 0.1529891376232556, 0.16656790561469695`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.0860569014282922], {
             RGBColor[
             0.2837493086151196, 0.41556889247271844`, 0.9394704754049221]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.0860569014282922], {
             RGBColor[
             0.4577297731262511, 0.5706446761720051, 0.950453310941356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.0860569014282922], {
             RGBColor[
             0.42122416525071066`, 0.5392649334232025, 0.9480610092292391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.0860569014282922], {
             RGBColor[
             0.30820544840519676`, 0.44127384600091113`, 0.9408632163863504]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.0860569014282922], {
             RGBColor[
             0.34734357171776975`, 0.4752732766515705, 0.9433534031393638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.0860569014282922], {
             RGBColor[
             0.9626217641044252, 0.9716439533871001, 0.9481557829526766]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.0860569014282922], {
             RGBColor[
             0.3115638572547115, 0.44428268632440737`, 0.9410735513725369]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.0860569014282922], {
             RGBColor[
             0.7336714827503054, 0.7918690055251112, 0.9740891749168833]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.0860569014282922], {
             RGBColor[
             0.9941087772252029, 0.9898075951157272, 0.6001549412550162]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.0860569014282922], {
             RGBColor[
             0.4701504450589133, 0.5807283371918343, 0.9514311117343156]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.0860569014282922], {
             RGBColor[
             0.9535781308826408, 0.8536597886601929, 0.28150607832809976`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.0860569014282922], {
             RGBColor[
             0.4353207202065356, 0.5514746608124851, 0.9489592292459301]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.0860569014282922], {
             RGBColor[
             0.9519038486996109, 0.9636505496271653, 0.9662984180529919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.0860569014282922], {
             RGBColor[
             0.7864896871677465, 0.8331309882492376, 0.9793535999190305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.0860569014282922], {
             RGBColor[
             0.9846134235163861, 0.987905269454116, 0.9046589217243813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.0860569014282922], {
             RGBColor[
             0.5915272340892559, 0.6792674824886997, 0.9609863371846123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.0860569014282922], {
             RGBColor[
             0.4686551241331842, 0.5795143683008873, 0.9513133945935012]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.0860569014282922], {
             RGBColor[
             0.9946340122004478, 0.9909310196183742, 0.6573235269358915]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.0860569014282922], {
             RGBColor[
             0.3183168710406381, 0.4501318074494352, 0.9415038474395205]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.0860569014282922], {
             RGBColor[
             0.902287369716355, 0.6491915918941304, 0.24017852494663777`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.0860569014282922], {
             RGBColor[
             0.9931784408027075, 0.9878176995794506, 0.49889356303726196`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.0860569014282922], {
             RGBColor[
             0.9745767194729413, 0.9805599395264966, 0.9279191618655092]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.0860569014282922], {
             RGBColor[
             0.989773774962126, 0.9900392073919125, 0.8191385437070202]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.0860569014282922], {
             RGBColor[
             0.9933953336212219, 0.9882816113870252, 0.5225010078252397]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.0860569014282922], {
             RGBColor[
             0.3492297683683656, 0.47690700538731645`, 0.9434735899220416]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.0860569014282922], {
             RGBColor[
             0.5621683095192537, 0.6554325849182923, 0.9586750950971775]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.0860569014282922], {
             RGBColor[
             0.953715116437291, 0.854202890736651, 0.28161630012083555`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.0860569014282922], {
             RGBColor[
             0.8560348918019747, 0.4317143098019431, 0.20129238171291666`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.0860569014282922], {
             RGBColor[
             0.9382985297324757, 0.9535037250181412, 0.9893286742288575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.0860569014282922], {
             RGBColor[
             0.7304375482092512, 0.7893426312828269, 0.9737668465446676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.0860569014282922], {
             RGBColor[
             0.8932033993269346, 0.6079434039709596, 0.23259863738521555`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.0860569014282922], {
             RGBColor[
             0.9950235133680367, 0.9917641232312381, 0.6997183253053836]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.0860569014282922], {
             RGBColor[
             0.6607300038049183, 0.7348865677972024, 0.9668190499724828]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.0860569014282922], {
             RGBColor[
             0.28316870139692335`, 0.4149586374737704, 0.9394374106827772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.0860569014282922], {
             RGBColor[
             0.2820714058482188, 0.41380531027952583`, 0.9393749213245818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.0860569014282922], {
             RGBColor[
             0.2963844579908239, 0.4288492355813243, 0.94019002846984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.0860569014282922], {
             RGBColor[
             0.7014935223134834, 0.7667313382703087, 0.9708819765406779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.0860569014282922], {
             RGBColor[
             0.42520922726413735`, 0.5427165938441921, 0.9483149338568826]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.0860569014282922], {
             RGBColor[
             0.9927886340095707, 0.9869839422644434, 0.456465499212996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.0860569014282922], {
             RGBColor[
             0.4983827581914804, 0.6036486008440649, 0.9536536628424819]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.0860569014282922], {
             RGBColor[
             0.5564858290344584, 0.6508192912679069, 0.9582277494178025]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.0860569014282922], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.0860569014282922], {
             RGBColor[
             0.9268424120359698, 0.7476615725833072, 0.2599938913760892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.0860569014282922], {
             RGBColor[
             0.9942485463418916, 0.9901065471234991, 0.6153679470515843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.0860569014282922], {
             RGBColor[
             0.28316870139692335`, 0.4149586374737704, 0.9394374106827772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.0860569014282922], {
             RGBColor[
             0.951760483588848, 0.9635436281622972, 0.9665410977899042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.0860569014282922], {
             RGBColor[
             0.5484002048218, 0.644255017278851, 0.9575912194611647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.0860569014282922], {
             RGBColor[
             0.7445494147758124, 0.8003669286987827, 0.9751733855211315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.0860569014282922], {
             RGBColor[
             0.9500471057015513, 0.8396604504615621, 0.27866493258358155`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.0860569014282922], {
             RGBColor[
             0.9708330100912872, 0.9777678871994204, 0.9342562853328643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.0860569014282922], {
             RGBColor[
             0.9597844504530005, 0.8760056496972068, 0.2982706133895423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.0860569014282922], {
             RGBColor[
             0.5621683095192537, 0.6554325849182923, 0.9586750950971775]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.0860569014282922], {
             RGBColor[
             0.2802709153078253, 0.4119128805638785, 0.9392723860518934]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.0860569014282922], {
             RGBColor[
             0.9842051561280859, 0.9877364403970607, 0.9114249689106475]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.0860569014282922], {
             RGBColor[
             0.6431126293105437, 0.7211237409451917, 0.9650631147266087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.0860569014282922], {
             RGBColor[
             0.5913002610451056, 0.6790832155464394, 0.9609684690351472]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.0860569014282922], {
             RGBColor[
             0.2795739026508505, 0.41118027606824314`, 0.9392326922122165]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.0860569014282922], {
             RGBColor[
             0.9799749120774375, 0.9441128177022655, 0.3767067441517329]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.0860569014282922], {
             RGBColor[
             0.6127718744996563, 0.6965148386340066, 0.9626587930994011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.0860569014282922], {
             RGBColor[
             0.9951445284879702, 0.9920229623362701, 0.7128900742913812]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.0860569014282922], {
             RGBColor[
             0.8962260457900924, 0.6216685356031413, 0.235120807685919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.0860569014282922], {
             RGBColor[
             0.7988235859301897, 0.8427663237035607, 0.9805829276808337]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.0860569014282922], {
             RGBColor[
             0.900183386179684, 0.9232458135853353, 0.9903414890486555]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.0860569014282922], {
             RGBColor[
             0.9200483227795284, 0.7207252726775506, 0.25452720768258486`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.0860569014282922], {
             RGBColor[
             0.9511478310401034, 0.8440244596339463, 0.27955060202832505`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.0860569014282922], {
             RGBColor[
             0.6742777819325784, 0.7454701950374578, 0.9681693658850633]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.0860569014282922], {
             RGBColor[
             0.2684923602142315, 0.3995328723569852, 0.938601614764124]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.0860569014282922], {
             RGBColor[
             0.5534569353531872, 0.6483602989273456, 0.9579893038120098]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.0860569014282922], {
             RGBColor[
             0.7179516081685184, 0.7795885200263474, 0.972522364729151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.0860569014282922], {
             RGBColor[
             0.8057049738702475, 0.8481421162628193, 0.9812688001204721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.0860569014282922], {
             RGBColor[
             0.9946490618071491, 0.9909632092053594, 0.6589615837499169]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.0860569014282922], {
             RGBColor[
             0.9398796975527975, 0.9546829573896124, 0.9866521695436673]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.0860569014282922], {
             RGBColor[
             0.9665318154661409, 0.9745600632905461, 0.9415370859020138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.0860569014282922], {
             RGBColor[
             0.7686115797798849, 0.8191644748791914, 0.9775716772550208]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.0860569014282922], {
             RGBColor[
             0.2525025325862419, 0.3827265497063414, 0.9376910177355402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.0860569014282922], {
             RGBColor[
             0.7603770196125172, 0.8127315738914686, 0.9767509332538775]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.0860569014282922], {
             RGBColor[
             0.954595326553575, 0.9656578494037613, 0.9617424480960806]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.0860569014282922], {
             RGBColor[
             0.9910926785151151, 0.9905846079053487, 0.7972808986210093]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.0860569014282922], {
             RGBColor[
             0.9927399984366677, 0.9868799156918147, 0.451171817246467]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.0860569014282922], {
             RGBColor[
             0.9931578862266676, 0.9877737354196875, 0.4966563242834481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.0860569014282922], {
             RGBColor[
             0.3216213324007257, 0.4529939657924859, 0.9417144047953648]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.0860569014282922], {
             RGBColor[
             0.8200451186396347, 0.8593457343442235, 0.9826978295504096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.0860569014282922], {
             RGBColor[
             0.9774190823418534, 0.9826797691001892, 0.9231077829354054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.0860569014282922], {
             RGBColor[
             0.9949505632429452, 0.9916080902900563, 0.6917781543851528]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.0860569014282922], {
             RGBColor[
             0.9602707189708488, 0.9698905477759618, 0.9521354891130452]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.0860569014282922], {
             RGBColor[
             0.8501148274355108, 0.8833225039175536, 0.9855659052189062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.0860569014282922], {
             RGBColor[
             0.8840495265071312, 0.5663778054375467, 0.22496042152241633`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.0860569014282922], {
             RGBColor[
             0.37708305267780634`, 0.5010321203093794, 0.9452483765685469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.0860569014282922], {
             RGBColor[
             0.5370242809456627, 0.6350195297966724, 0.9566956650622529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.0860569014282922], {
             RGBColor[
             0.9387343894226815, 0.9538287884614419, 0.9885908774637526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.0860569014282922], {
             RGBColor[
             0.9938864997350346, 0.9917399247777159, 0.7509800508293953]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.0860569014282922], {
             RGBColor[
             0.9661173053515094, 0.8973678562949192, 0.32287255881095]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.0860569014282922], {
             RGBColor[
             0.941132169702511, 0.9556170490681339, 0.9845320608912559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.0860569014282922], {
             RGBColor[
             0.7465515729874592, 0.8019310299106872, 0.9753729419404362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.0860569014282922], {
             RGBColor[
             0.9532727888616209, 0.9646715029585586, 0.963981159435485]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.0860569014282922], {
             RGBColor[
             0.9043464290377469, 0.9265653109575667, 0.9907385637928497]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.0860569014282922], {
             RGBColor[
             0.7164468989453462, 0.7784130297449916, 0.9723723893760924]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.0860569014282922], {
             RGBColor[
             0.5287272071563774, 0.628283591515616, 0.9560424890203776]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.0860569014282922], {
             RGBColor[
             0.29655795570879645`, 0.4290315926833041, 0.9401999089082117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.0860569014282922], {
             RGBColor[
             0.4469210062026999, 0.5615222454950356, 0.9496983892118755]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.0860569014282922], {
             RGBColor[
             0.5190557448194113, 0.6204318626960537, 0.9552811160774778]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.0860569014282922], {
             RGBColor[
             0.9380496943325354, 0.9533181439842963, 0.9897498876542902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.0860569014282922], {
             RGBColor[
             0.7112338658207771, 0.774340568647559, 0.9718528029527996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.0860569014282922], {
             RGBColor[
             0.2897260253992373, 0.42185080075855713`, 0.9398108405840174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.0860569014282922], {
             RGBColor[
             0.3027379010344937, 0.43552710705177666`, 0.9405518476521003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.0860569014282922], {
             RGBColor[
             0.9938417764588451, 0.9892365074744063, 0.5710935555746962]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.0860569014282922], {
             RGBColor[
             0.8289682427563888, 0.8664607913031714, 0.9835489250944326]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.0860569014282922], {
             RGBColor[
             0.5592226342708762, 0.6530411530505018, 0.9584432007512612]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.0860569014282922], {
             RGBColor[
             0.9329158022591165, 0.9493457536693096, 0.9934635361148846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.0860569014282922], {
             RGBColor[
             0.3216213324007257, 0.4529939657924859, 0.9417144047953648]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.0860569014282922], {
             RGBColor[
             0.9306742577709263, 0.7628535640355132, 0.2630770843994147]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.0860569014282922], {
             RGBColor[
             0.2138419529622882, 0.342091829299242, 0.9354893549191582]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.0860569014282922], {
             RGBColor[
             0.9882230541070169, 0.9893979444666168, 0.8448380014131069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.0860569014282922], {
             RGBColor[
             0.8309265428214586, 0.23872053698901624`, 0.1772485983733502]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.0860569014282922], {
             RGBColor[
             0.9572514091216728, 0.8674611065002505, 0.28843022614205216`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.0860569014282922], {
             RGBColor[
             0.9485237242120022, 0.9611296583187526, 0.972020087132856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.0860569014282922], {
             RGBColor[
             0.9278051738857038, 0.945270677328662, 0.9929760798183166]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.0860569014282922], {
             RGBColor[
             0.8620232884527705, 0.8928179874861533, 0.986701744861541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.0860569014282922], {
             RGBColor[
             0.861520386757684, 0.8924169873253942, 0.9866537776489182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.0860569014282922], {
             RGBColor[
             0.9411592268827486, 0.8044229726550537, 0.2715135366606436]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.0860569014282922], {
             RGBColor[
             0.8367579305286419, 0.2835431382368141, 0.18283274182735934`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.0860569014282922], {
             RGBColor[
             0.9367268384270373, 0.9523315602159536, 0.9919891376462213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.0860569014282922], {
             RGBColor[
             0.7753195488427815, 0.8244047912935795, 0.9782402649216755]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.0860569014282922], {
             RGBColor[
             0.9676111105227253, 0.9024068118995643, 0.3286757098196876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.0860569014282922], {
             RGBColor[
             0.8883478319388474, 0.5858954065082311, 0.22854703293574768`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.0860569014282922], {
             RGBColor[
             0.22213383740057638`, 0.3508071255797213, 0.9359615654711749]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.0860569014282922], {
             RGBColor[
             0.485271088234991, 0.5930039564993865, 0.9526214641538774]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.0860569014282922], {
             RGBColor[
             0.9388902569221245, 0.9539450341873168, 0.9883270344439504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.0860569014282922], {
             RGBColor[
             0.9512358880778669, 0.9631523856891538, 0.967429101153573]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.0860569014282922], {
             RGBColor[
             0.954274050692355, 0.9654182423925044, 0.9622862843269614]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.0860569014282922], {
             RGBColor[
             0.31045172271567173`, 0.4433194112841984, 0.9410026871431313]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.0860569014282922], {
             RGBColor[
             0.9947884765965425, 0.9921129153896974, 0.7360319599929173]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.0860569014282922], {
             RGBColor[
             0.7773604972475026, 0.8259991956991298, 0.9784436875849108]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.0860569014282922], {
             RGBColor[
             0.9944590738656652, 0.990556844209253, 0.6382825687890669]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.0860569014282922], {
             RGBColor[
             0.9437533693522422, 0.9575719354750828, 0.9800950536026198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.0860569014282922], {
             RGBColor[
             0.9335506158756443, 0.7742573654312014, 0.265391469647273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.0860569014282922], {
             RGBColor[
             0.3361391373808874, 0.4655685587802071, 0.9426394664911099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.0860569014282922], {
             RGBColor[
             0.9856442458984253, 0.9883315410000161, 0.8875755271711833]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.0860569014282922], {
             RGBColor[
             0.7679204032476006, 0.8186245225190347, 0.9775027872376947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.0860569014282922], {
             RGBColor[
             0.48183396234568104`, 0.590213542861688, 0.9523508810132639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.0860569014282922], {
             RGBColor[
             0.2784191864306398, 0.40996659610756464`, 0.9391669328317251]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.0860569014282922], {
             RGBColor[
             0.25779578631631933`, 0.3882900949883233, 0.9379924607048009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.0860569014282922], {
             RGBColor[
             0.28903124843537237`, 0.42112054611813127`, 0.9397712740637557]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.0860569014282922], {
             RGBColor[
             0.26334245696950204`, 0.39411999752404975`, 0.9383083353929358]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.0860569014282922], {
             RGBColor[
             0.9186387449031443, 0.71513676611167, 0.25339302823620097`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.0860569014282922], {
             RGBColor[
             0.27005302121447483`, 0.4011732260198635, 0.9386904920992968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.0860569014282922], {
             RGBColor[
             0.9002486463241636, 0.6399342251261345, 0.2384773641745099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.0860569014282922], {
             RGBColor[
             0.951518327167631, 0.9633630282998483, 0.9669510054465148]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.0860569014282922], {
             RGBColor[
             0.930118506353745, 0.947115265844941, 0.9931967275342547]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.0860569014282922], {
             RGBColor[
             0.9858834004745715, 0.9640435364448474, 0.3996601058501884]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.0860569014282922], {
             RGBColor[
             0.2562278882428392, 0.3866421347026161, 0.9379031712290136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.0860569014282922], {
             RGBColor[
             0.40182652200944635`, 0.5224636698015167, 0.9468250085545681]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.0860569014282922], {
             RGBColor[
             0.4469210062026999, 0.5615222454950356, 0.9496983892118755]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.0860569014282922], {
             RGBColor[
             0.9447539676907036, 0.958318180077578, 0.9784013016134473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.0860569014282922], {
             RGBColor[
             0.2862250304018598, 0.4181710330404098, 0.9396114640981748]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.0860569014282922], {
             RGBColor[
             0.9510571864365709, 0.8436650839864636, 0.27947766725262047`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.0860569014282922], {
             RGBColor[
             0.23739784340820552`, 0.3668505636876176, 0.9368308280322362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.0860569014282922], {
             RGBColor[
             0.5956766262642321, 0.6826361459843328, 0.9613129925363508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.0860569014282922], {
             RGBColor[
             0.9045730505911103, 0.9267460128327405, 0.990760179158917]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.0860569014282922], {
             RGBColor[
             0.9672162934993843, 0.9010750013723895, 0.32714192023894645`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.0860569014282922], {
             RGBColor[
             0.31236607831510255`, 0.4449775298861153, 0.9411246681891288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.0860569014282922], {
             RGBColor[
             0.818936065994404, 0.1465564778358266, 0.16576650422245615`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.0860569014282922], {
             RGBColor[
             0.9917628422137431, 0.9908617378171529, 0.786174551806687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.0860569014282922], {
             RGBColor[
             0.9943346752603658, 0.9902907681711459, 0.6247425483014287]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.0860569014282922], {
             RGBColor[
             0.691414225856509, 0.75885731527263, 0.9698773664662274]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.0860569014282922], {
             RGBColor[
             0.9188409382580948, 0.7159383953871068, 0.2535557177556821]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.0860569014282922], {
             RGBColor[
             0.3238607324908076, 0.4549336215949936, 0.9418570973888811]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.0860569014282922], {
             RGBColor[
             0.9075976558501756, 0.6713625272414686, 0.2445091088165129]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.0860569014282922], {
             RGBColor[
             0.4360397166927189, 0.5520974194310029, 0.9490050430662461]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.0860569014282922], {
             RGBColor[
             0.924746527853394, 0.7393520902113954, 0.25830749376606393`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.0860569014282922], {
             RGBColor[
             0.4391299699296007, 0.5547740414641461, 0.9492019512698966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.0860569014282922], {
             RGBColor[
             0.9853613655215568, 0.9622825899686932, 0.39763209863575555`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.0860569014282922], {
             RGBColor[
             0.4185668643171163, 0.5369633129143515, 0.9478916883635093]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.0860569014282922], {
             RGBColor[
             0.906800951751839, 0.6682038609774665, 0.24386806199794253`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.0860569014282922], {
             RGBColor[
             0.4000713321174308, 0.520943412535462, 0.9467131694067024]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.0860569014282922], {
             RGBColor[
             0.982074158253418, 0.9861515170930468, 0.9152279536553714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.0860569014282922], {
             RGBColor[
             0.37743950275094684`, 0.501340859447032, 0.945271089252011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.0860569014282922], {
             RGBColor[
             0.9173646626714543, 0.9369456970865466, 0.9919802545383472]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.0860569014282922], {
             RGBColor[
             0.978660972953929, 0.9836059690852659, 0.921005586066108]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.0860569014282922], {
             RGBColor[
             0.7792909118513583, 0.8275072502593565, 0.9786360932718731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.0860569014282922], {
             RGBColor[
             0.9839427204992975, 0.9875450877565339, 0.9120649651721826]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.0860569014282922], {
             RGBColor[
             0.9876678819813026, 0.9891683665253611, 0.8540386402755984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.0860569014282922], {
             RGBColor[
             0.37743950275094684`, 0.501340859447032, 0.945271089252011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.0860569014282922], {
             RGBColor[
             0.7859179842661402, 0.8326843695973999, 0.9792966179166657]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.0860569014282922], {
             RGBColor[
             0.4874939903566474, 0.5948086085823466, 0.952796459151653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.0860569014282922], {
             RGBColor[
             0.9415525335483161, 0.9559305557360527, 0.9838204945487579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.0860569014282922], {
             RGBColor[
             0.28316870139692335`, 0.4149586374737704, 0.9394374106827772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.0860569014282922], {
             RGBColor[
             0.9589371148738471, 0.9688959480239943, 0.9543929329896146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.0860569014282922], {
             RGBColor[
             0.6756969324513681, 0.7465788462086798, 0.9683108135460606]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.0860569014282922], {
             RGBColor[
             0.8185774812246456, 0.8581982168427544, 0.982551811353138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.0860569014282922], {
             RGBColor[
             0.8687976342107593, 0.8982196669088566, 0.9873478880074679]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.0860569014282922], {
             RGBColor[
             0.4065376349747133, 0.5265441990646085, 0.9471251965068413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.0860569014282922], {
             RGBColor[
             0.3875160758346616, 0.5100686805888565, 0.9459131595785415]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.0860569014282922], {
             RGBColor[
             0.4062991840526702, 0.5263376648608264, 0.9471100026249426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.0860569014282922], {
             RGBColor[
             0.9367268384270373, 0.9523315602159536, 0.9919891376462213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.0860569014282922], {
             RGBColor[
             0.805604487924561, 0.8480636158783275, 0.9812587846205006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.0860569014282922], {
             RGBColor[
             0.8263681188897234, 0.8643875231103746, 0.9833009229588721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.0860569014282922], {
             RGBColor[
             0.9918112243207488, 0.9908817450617632, 0.7853727350847228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.0860569014282922], {
             RGBColor[
             0.9845510734907464, 0.9878794861161915, 0.9056922230059247]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.0860569014282922], {
             RGBColor[
             0.37869045497903886`, 0.5024243713923182, 0.9453507988218113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.0860569014282922], {
             RGBColor[
             0.8382319102547802, 0.8738473883108331, 0.9844325019702027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.0860569014282922], {
             RGBColor[
             0.8513956592973689, 0.8843438044769445, 0.9856880721053023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.0860569014282922], {
             RGBColor[
             0.9338721890303205, 0.7755322958315916, 0.26565021495581764`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.0860569014282922], {
             RGBColor[
             0.9933134279265349, 0.9915029448576275, 0.7604773337585348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.0860569014282922], {
             RGBColor[
             0.9712379003810023, 0.978069853714543, 0.9335709116846769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.0860569014282922], {
             RGBColor[
             0.7022256390251621, 0.7673032734097652, 0.9709549470924783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.0860569014282922], {
             RGBColor[
             0.9913599024609148, 0.990695111874279, 0.7928523062857054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.0860569014282922], {
             RGBColor[
             0.9811337794174675, 0.9854501840969239, 0.9168197697345547]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.0860569014282922], {
             RGBColor[
             0.9362115421527853, 0.9519472530983366, 0.9928613998277371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.0860569014282922], {
             RGBColor[
             0.7766528675144724, 0.8254463899735015, 0.9783731576662982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.0860569014282922], {
             RGBColor[
             0.7803862766143184, 0.8283629575372613, 0.9787452689946792]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.0860569014282922], {
             RGBColor[
             0.9939743405522371, 0.989520048665886, 0.5855223390496636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.0860569014282922], {
             RGBColor[
             0.9234334496340827, 0.734146172629204, 0.25725096020889887`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.0860569014282922], {
             RGBColor[
             0.6262110298045408, 0.707425350337559, 0.9637167726342496]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.0860569014282922], {
             RGBColor[
             0.7766528675144724, 0.8254463899735015, 0.9783731576662982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.0860569014282922], {
             RGBColor[
             0.2989701902851669, 0.43156700416757526`, 0.9403372820987548]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.0860569014282922], {
             RGBColor[
             0.5229345936826507, 0.6235808869433814, 0.9555864732686835]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.0860569014282922], {
             RGBColor[
             0.8722951191837051, 0.5130037870934476, 0.2151522559248606]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.0860569014282922], {
             RGBColor[
             0.8885760784191596, 0.913990461449069, 0.9892343736724907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.0860569014282922], {
             RGBColor[
             0.9660235665745931, 0.9741810120994109, 0.9423974187028633]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.0860569014282922], {
             RGBColor[
             0.5679679684432866, 0.6601410093044794, 0.959131665492528]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.0860569014282922], {
             RGBColor[
             0.2989701902851669, 0.43156700416757526`, 0.9403372820987548]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.0860569014282922], {
             RGBColor[
             0.39314578068340655`, 0.5149448479716463, 0.946271879393351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.0860569014282922], {
             RGBColor[
             0.7876673231335933, 0.8340509664161221, 0.9794709756664722]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.0860569014282922], {
             RGBColor[
             0.3221933704063147, 0.45348943636146094`, 0.9417508545512476]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.0860569014282922], {
             RGBColor[
             0.9951509682877198, 0.9920367364167708, 0.7135910067522854]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.0860569014282922], {
             RGBColor[
             0.6082683693454051, 0.6928586902691903, 0.9623042606767754]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.0860569014282922], {
             RGBColor[
             0.9118591450257207, 0.6882579117654194, 0.24793800303716376`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.0860569014282922], {
             RGBColor[
             0.9051015593468315, 0.6614663363805605, 0.2425006909790069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.0860569014282922], {
             RGBColor[
             0.9239817175551349, 0.9422219570356237, 0.9926113951402672]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.0860569014282922], {
             RGBColor[
             0.9944334145304439, 0.9905019614857713, 0.6354897085012845]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.0860569014282922], {
             RGBColor[
             0.9654147455283371, 0.8949979570424675, 0.3201432465652153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.0860569014282922], {
             RGBColor[
             0.8919473556902267, 0.6022400031731131, 0.2315505637862995]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.0860569014282922], {
             RGBColor[
             0.9695537518335147, 0.9089597971947276, 0.3362225044750749]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.0860569014282922], {
             RGBColor[
             0.5207157619325917, 0.6217795393714523, 0.9554117987054704]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.0860569014282922], {
             RGBColor[
             0.4606365428588626, 0.5730045227894232, 0.9506821425025554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.0860569014282922], {
             RGBColor[
             0.8292209054911932, 0.8666622577095572, 0.9835730242916328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.0860569014282922], {
             RGBColor[
             0.8254954963078062, 0.8636917175502627, 0.9832176914380094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.0860569014282922], {
             RGBColor[
             0.2692388562558919, 0.400317487027353, 0.9386441266093546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.0860569014282922], {
             RGBColor[
             0.7955254383324755, 0.8401897857333762, 0.9802541991512351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.0860569014282922], {
             RGBColor[
             0.2800908259132003, 0.4117235951918005, 0.9392621302272879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.0860569014282922], {
             RGBColor[
             0.8292209054911932, 0.8666622577095572, 0.9835730242916328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.0860569014282922], {
             RGBColor[
             0.7594730711442471, 0.8120254024777932, 0.9766608361184391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.0860569014282922], {
             RGBColor[
             0.7243076551762037, 0.7845539122564975, 0.9731558760942407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.0860569014282922], {
             RGBColor[
             0.3901010154112887, 0.51230762532729, 0.9460778696425919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.0860569014282922], {
             RGBColor[
             0.9383954719141427, 0.9535760243385001, 0.9891645764018658]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.0860569014282922], {
             RGBColor[
             0.96555866834135, 0.9738342917582593, 0.9431843701468653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.0860569014282922], {
             RGBColor[
             0.9927488992055854, 0.9868989535365238, 0.4521406110139813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.0860569014282922], {
             RGBColor[
             0.3744732199191344, 0.4987716143478262, 0.9450820803329487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.0860569014282922], {
             RGBColor[
             0.45767934874841765`, 0.5706037393904876, 0.9504493413496223]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.0860569014282922], {
             RGBColor[
             0.9122273463690385, 0.6897177073958499, 0.24823426648079353`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.0860569014282922], {
             RGBColor[
             0.4520393423478456, 0.5659554910089061, 0.9500245250650773]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.0860569014282922], {
             RGBColor[
             0.938966880189757, 0.7957310485735696, 0.2697495230504717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.0860569014282922], {
             RGBColor[
             0.6011628176215589, 0.6870900832783147, 0.9617448856165807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.0860569014282922], {
             RGBColor[
             0.9858979775300591, 0.9884364655503023, 0.8833705373985946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.0860569014282922], {
             RGBColor[
             0.9569278361011447, 0.9673974312052049, 0.9577941178479662]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.0860569014282922], {
             RGBColor[
             0.9517655857454534, 0.9635474333423395, 0.9665324611696267]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.0860569014282922], {
             RGBColor[
             0.9803533339620839, 0.9453893235768619, 0.37817684171460775`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.0860569014282922], {
             RGBColor[
             0.9834600169556338, 0.9558688947979614, 0.39024571849669326`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.0860569014282922], {
             RGBColor[
             0.8005504465521273, 0.8441153603460452, 0.9807550450091984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.0860569014282922], {
             RGBColor[
             0.5990948015339188, 0.6854111746553054, 0.9615820838147692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.0860569014282922], {
             RGBColor[
             0.9670483664095733, 0.9749453061383835, 0.9406626998928456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.0860569014282922], {
             RGBColor[
             0.31068485338808544`, 0.4435213373551548, 0.941017542023428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.0860569014282922], {
             RGBColor[
             0.7164468989453462, 0.7784130297449916, 0.9723723893760924]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.0860569014282922], {
             RGBColor[
             0.8198884085040161, 0.8592223231968151, 0.9826824723330336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.0860569014282922], {
             RGBColor[
             0.937869390064076, 0.9531836733561003, 0.9900550957499072]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.0860569014282922], {
             RGBColor[
             0.9691952996088244, 0.9765464854031045, 0.9370285019963712]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.0860569014282922], {
             RGBColor[
             0.32800310799819377`, 0.4585215390576448, 0.942121045893253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.0860569014282922], {
             RGBColor[
             0.5746877307342124, 0.6655964150540944, 0.95966066979537]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.0860569014282922], {
             RGBColor[
             0.5843220540033794, 0.6734179927053213, 0.9604191190148078]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.0860569014282922], {
             RGBColor[
             0.6085570699482019, 0.6930930704243548, 0.9623269882457728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.0860569014282922], {
             RGBColor[
             0.9411014882314042, 0.804194058142738, 0.2714670787864715]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.0860569014282922], {
             RGBColor[
             0.42397977753065563`, 0.5416517062789905, 0.9482365944070249]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.0860569014282922], {
             RGBColor[
             0.7984543718674005, 0.842477890871579, 0.9805461278735564]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.0860569014282922], {
             RGBColor[
             0.9791402799850377, 0.9839634354842735, 0.9201942442857359]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.0860569014282922], {
             RGBColor[
             0.9929660592679447, 0.9873634369516601, 0.47577714364523216`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.0860569014282922], {
             RGBColor[
             0.952513373343388, 0.8494383798264726, 0.28064934941894537`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.0860569014282922], {
             RGBColor[
             0.9744531162650121, 0.9254865038476424, 0.355255610124103]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.0860569014282922], {
             RGBColor[
             0.6151284276004145, 0.6984279946027095, 0.9628443095918312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.0860569014282922], {
             RGBColor[
             0.239132161096772, 0.3686734415403935, 0.9369295948589069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.0860569014282922], {
             RGBColor[
             0.8200451186396347, 0.8593457343442235, 0.9826978295504096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.0860569014282922], {
             RGBColor[
             0.940561514190662, 0.9551914551217595, 0.985498031822022]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.0860569014282922], {
             RGBColor[
             0.7759338698397482, 0.8248847035254223, 0.9783014946974969]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.0860569014282922], {
             RGBColor[
             0.5484002048218, 0.644255017278851, 0.9575912194611647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.0860569014282922], {
             RGBColor[
             0.9151214299602142, 0.7011917844386748, 0.25056291407112635`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.0860569014282922], {
             RGBColor[
             0.9367268384270373, 0.9523315602159536, 0.9919891376462213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.0860569014282922], {
             RGBColor[
             0.9543167315199046, 0.9654500736838074, 0.9622140368188625]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.0860569014282922], {
             RGBColor[
             0.2569232119297078, 0.38737296398358306`, 0.9379427688843415]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.0860569014282922], {
             RGBColor[
             0.28316870139692335`, 0.4149586374737704, 0.9394374106827772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.0860569014282922], {
             RGBColor[
             0.2846539926025518, 0.4165197727037875, 0.9395219958196463]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.0860569014282922], {
             RGBColor[
             0.6123115813940769, 0.6961411519549292, 0.9626225571400207]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.0860569014282922], {
             RGBColor[
             0.7568453832498252, 0.8099726327235031, 0.9763989327462627]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.0860569014282922], {
             RGBColor[
             0.9048360998603515, 0.9269557611797513, 0.9907852690330441]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.0860569014282922], {
             RGBColor[
             0.9770257678699117, 0.9341646617982915, 0.3652498758046477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.0860569014282922], {
             RGBColor[
             0.4574083740500152, 0.5703837499230534, 0.950428009228751]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.0860569014282922], {
             RGBColor[
             0.9883334961064355, 0.9894436150716063, 0.8430076916680075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.0860569014282922], {
             RGBColor[
             0.9105391001030637, 0.9315031787694723, 0.9913292262873225]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.0860569014282922], {
             RGBColor[
             0.5836784324920332, 0.6728954717675919, 0.9603684507717714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.0860569014282922], {
             RGBColor[
             0.9896752945728451, 0.9768344856173984, 0.41439089838286614`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.0860569014282922], {
             RGBColor[
             0.9586261765125562, 0.9686640507032583, 0.9549192705295674]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.0860569014282922], {
             RGBColor[
             0.9618600001792631, 0.9710758310989881, 0.9494452505781248]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.0860569014282922], {
             RGBColor[
             0.9885979195673846, 0.9895529609680818, 0.8386255106141007]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.0860569014282922], {
             RGBColor[
             0.5874184824616506, 0.6759318128202583, 0.9606628812056341]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.0860569014282922], {
             RGBColor[
             0.9186387449031443, 0.71513676611167, 0.25339302823620097`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.0860569014282922], {
             RGBColor[
             0.8388693831921479, 0.8743556919273482, 0.9844933047080476]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.0860569014282922], {
             RGBColor[
             0.416033737501342, 0.5347692457851835, 0.9477302797627644]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.0860569014282922], {
             RGBColor[
             0.7123482714601141, 0.7752111508028057, 0.9719638764922159]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.0860569014282922], {
             RGBColor[
             0.6371667834130349, 0.7163197246680102, 0.964579249690558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.0860569014282922], {
             RGBColor[
             0.956236044876418, 0.8640360444821438, 0.2844857277846857]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.0860569014282922], {
             RGBColor[
             0.8865207206420992, 0.9123515749488416, 0.9890383318128751]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.0860569014282922], {
             RGBColor[
             0.41886888127074673`, 0.5372249048197727, 0.9479109326167315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.0860569014282922], {
             RGBColor[
             0.28316870139692335`, 0.4149586374737704, 0.9394374106827772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.0860569014282922], {
             RGBColor[
             0.7568453832498252, 0.8099726327235031, 0.9763989327462627]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.0860569014282922], {
             RGBColor[
             0.9048511385657153, 0.9269677526351936, 0.9907867034381869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.0860569014282922], {
             RGBColor[
             0.9055105326982817, 0.9274935356177252, 0.9908495970391992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.0860569014282922], {
             RGBColor[
             0.8453739778394759, 0.8795422791366093, 0.98511371875223]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.0860569014282922], {
             RGBColor[
             0.239132161096772, 0.3686734415403935, 0.9369295948589069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.0860569014282922], {
             RGBColor[
             0.644285447156511, 0.722039955160207, 0.9651800102488888]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.0860569014282922], {
             RGBColor[
             0.9939860087699082, 0.9917810743209017, 0.7493309286004125]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.0860569014282922], {
             RGBColor[
             0.8321953734427667, 0.24847332514951398`, 0.17846363200925405`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.0860569014282922], {
             RGBColor[
             0.22888348412545953`, 0.35790143223989324`, 0.9363459478669496]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.0860569014282922], {
             RGBColor[
             0.8057049738702475, 0.8481421162628193, 0.9812688001204721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.0860569014282922], {
             RGBColor[
             0.9163755071555609, 0.7061637826217726, 0.2515719740194775]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.0860569014282922], {
             RGBColor[
             0.8803621772181066, 0.9074409195917579, 0.9884509244432981]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.0860569014282922], {
             RGBColor[
             0.28316870139692335`, 0.4149586374737704, 0.9394374106827772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.0860569014282922], {
             RGBColor[
             0.3058906356046225, 0.4388408309798991, 0.9407313912218164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.0860569014282922], {
             RGBColor[
             0.9862356569399497, 0.988576104664257, 0.8777743156904079]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.0860569014282922], {
             RGBColor[
             0.873427339212181, 0.9019112680069957, 0.98778947340349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.0860569014282922], {
             RGBColor[
             0.2569232119297078, 0.38737296398358306`, 0.9379427688843415]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.0860569014282922], {
             RGBColor[
             0.9515539876207115, 0.9633896238073671, 0.9668906416011851]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.0860569014282922], {
             RGBColor[
             0.9898363223310296, 0.9900650723363482, 0.8181019719368864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.0860569014282922], {
             RGBColor[
             0.4642150535035602, 0.5759097189408562, 0.9509638559690226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.0860569014282922], {
             RGBColor[
             0.330580050926044, 0.4607535575008311, 0.9422852464179143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.0860569014282922], {
             RGBColor[
             0.5943848890942799, 0.6815874555576691, 0.961211302254543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.0860569014282922], {
             RGBColor[
             0.9237949455719856, 0.9420730301260508, 0.9925935806617812]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.0860569014282922], {
             RGBColor[
             0.485271088234991, 0.5930039564993865, 0.9526214641538774]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.0860569014282922], {
             RGBColor[
             0.8334600065305864, 0.8700424018110369, 0.9839773535330604]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.0860569014282922], {
             RGBColor[
             0.8708563157678926, 0.8998612037010923, 0.987544246892194]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.0860569014282922], {
             RGBColor[
             0.7166371369724428, 0.778561645137622, 0.9723913505247579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.0860569014282922], {
             RGBColor[
             0.8919473556902267, 0.6022400031731131, 0.2315505637862995]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.0860569014282922], {
             RGBColor[
             0.30820544840519676`, 0.44127384600091113`, 0.9408632163863504]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.0860569014282922], {
             RGBColor[
             0.6354157233737157, 0.7148981352437349, 0.9644413998299185]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.0860569014282922], {
             RGBColor[
             0.8566892337388867, 0.8885647570463604, 0.986192977961164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.0860569014282922], {
             RGBColor[
             0.8521995142169515, 0.8849847765697592, 0.9857647445051418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.0860569014282922], {
             RGBColor[
             0.9943269246002894, 0.9902741902929543, 0.6238989367836342]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.0860569014282922], {
             RGBColor[
             0.982768795745433, 0.9535372433494957, 0.3875604546212357]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.0860569014282922], {
             RGBColor[
             0.9440673236038608, 0.9578060820418871, 0.9795636109470125]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.0860569014282922], {
             RGBColor[
             0.5423771060083539, 0.6393651943245862, 0.9571170590592323]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.0860569014282922], {
             RGBColor[
             0.9744702409951126, 0.9255442695833496, 0.3553221364668098]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.0860569014282922], {
             RGBColor[
             0.2954189652125585, 0.4278344414555896, 0.9401350450844363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.0860569014282922], {
             RGBColor[
             0.8628102137289544, 0.8934454603408647, 0.98677680249688]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.0860569014282922], {
             RGBColor[
             0.7558922005043418, 0.8092279991182744, 0.976303928398192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.0860569014282922], {
             RGBColor[
             0.8803621772181066, 0.9074409195917579, 0.9884509244432981]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.0860569014282922], {
             RGBColor[
             0.9863889032858448, 0.988639475966536, 0.8752346271500963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.0860569014282922], {
             RGBColor[
             0.8916675162408774, 0.9164554900532624, 0.9895292377716852]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.0860569014282922], {
             RGBColor[
             0.838015691230728, 0.2932108381473023, 0.18403717489611457`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.0860569014282922], {
             RGBColor[
             0.9940713092693598, 0.9918163482695477, 0.7479172785738831]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.0860569014282922], {
             RGBColor[
             0.994110738319965, 0.9898117896991263, 0.6003683943173984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.0860569014282922], {
             RGBColor[
             0.5560882916431593, 0.650496552504795, 0.958196453818132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.0860569014282922], {
             RGBColor[
             0.44246258488832224`, 0.5576605850392925, 0.9494143025481506]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.0860569014282922], {
             RGBColor[
             0.4642150535035602, 0.5759097189408562, 0.9509638559690226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.0860569014282922], {
             RGBColor[
             0.8682763793805246, 0.4947556282477328, 0.2117989209247601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.0860569014282922], {
             RGBColor[
             0.3348579798971787, 0.46445888456066603`, 0.942557832269131]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.0860569014282922], {
             RGBColor[
             0.26450186103589385`, 0.3953386047082911, 0.9383743617393322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.0860569014282922], {
             RGBColor[
             0.8072315565348098, 0.8493346942428333, 0.9814209556137496]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.0860569014282922], {
             RGBColor[
             0.992803001965474, 0.9870146738692974, 0.458029362544323]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.0860569014282922], {
             RGBColor[
             0.965237203282108, 0.9735945436434273, 0.9437285266406465]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[401, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[402, 0.0860569014282922], {
             RGBColor[
             0.43454044612695547`, 0.5507988266224684, 0.9489095108715485]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[403, 0.0860569014282922], {
             RGBColor[
             0.5229345936826507, 0.6235808869433814, 0.9555864732686835]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[404, 0.0860569014282922], {
             RGBColor[
             0.8771131348199127, 0.5348812708213257, 0.2191725262720825]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[405, 0.0860569014282922], {
             RGBColor[
             0.8566199858561305, 0.8885095406643344, 0.9861863730362884]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[406, 0.0860569014282922], {
             RGBColor[
             0.29401825106717394`, 0.42636220207838416`, 0.9400552764860276]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[407, 0.0860569014282922], {
             RGBColor[
             0.46970760060528427`, 0.5803688161144629, 0.9513962493967332]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[408, 0.0860569014282922], {
             RGBColor[
             0.3179355277387587, 0.44980150704821886`, 0.9414795485815334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[409, 0.0860569014282922], {
             RGBColor[
             0.838015691230728, 0.2932108381473023, 0.18403717489611457`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[410, 0.0860569014282922], {
             RGBColor[
             0.7451131030344239, 0.8008072862505995, 0.9752295686987836]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[411, 0.0860569014282922], {
             RGBColor[
             0.7186174731361978, 0.7801086987998598, 0.9725887319262674]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[412, 0.0860569014282922], {
             RGBColor[
             0.5478298053359681, 0.6437919412800488, 0.9575463155241978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[413, 0.0860569014282922], {
             RGBColor[
             0.25160194472615877`, 0.3817799747648257, 0.9376397305892088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[414, 0.0860569014282922], {
             RGBColor[
             0.9412734673245903, 0.9557224286033269, 0.9842928808733978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[415, 0.0860569014282922], {
             RGBColor[
             0.9649066395415438, 0.9733480097469629, 0.9442880848285904]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[416, 0.0860569014282922], {
             RGBColor[
             0.9892510884047482, 0.989823063068005, 0.8278008126322198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[417, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[418, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[419, 0.0860569014282922], {
             RGBColor[
             0.9877596050956831, 0.9892062963903339, 0.8525185508985033]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[420, 0.0860569014282922], {
             RGBColor[
             0.9940624848245881, 0.9897085803516918, 0.5951162991316776]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[421, 0.0860569014282922], {
             RGBColor[
             0.8251215957634713, 0.86339357940547, 0.9831820284703058]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[422, 0.0860569014282922], {
             RGBColor[
             0.8254954963078062, 0.8636917175502627, 0.9832176914380094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[423, 0.0860569014282922], {
             RGBColor[
             0.9216958764546208, 0.9403992893895774, 0.9923933695755057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[424, 0.0860569014282922], {
             RGBColor[
             0.9893497901020807, 0.9757364826054258, 0.4131263749803078]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[425, 0.0860569014282922], {
             RGBColor[
             0.8620507663015046, 0.8928398975768674, 0.9867043657232831]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[426, 0.0860569014282922], {
             RGBColor[
             0.3679049526703533, 0.49308251138764286`, 0.9446635561519471]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[427, 0.0860569014282922], {
             RGBColor[
             0.9853035690729699, 0.9620876289763581, 0.39740757034693897`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[428, 0.0860569014282922], {
             RGBColor[
             0.8986936657651294, 0.922057950964153, 0.9901993981856262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[429, 0.0860569014282922], {
             RGBColor[
             0.757883913389199, 0.8107839403615034, 0.9765024437249394]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[430, 0.0860569014282922], {
             RGBColor[
             0.9456009639117452, 0.9589498684724018, 0.9769675579432181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[431, 0.0860569014282922], {
             RGBColor[
             0.9934498891320372, 0.9883983001082509, 0.5284390384999006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[432, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[433, 0.0860569014282922], {
             RGBColor[
             0.9386083341163474, 0.9537347766203745, 0.9888042562168871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[434, 0.0860569014282922], {
             RGBColor[
             0.9528586817120838, 0.9643626625244721, 0.9646821348232092]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[435, 0.0860569014282922], {
             RGBColor[
             0.40850930356749504`, 0.5282519593007311, 0.9472508294860953]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[436, 0.0860569014282922], {
             RGBColor[
             0.6383965410088254, 0.7173180972842211, 0.9646760607132492]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[437, 0.0860569014282922], {
             RGBColor[
             0.4483622321792632, 0.5627705629978108, 0.949790222856676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[438, 0.0860569014282922], {
             RGBColor[
             0.42294543261100104`, 0.540755808697273, 0.9481706868633798]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[439, 0.0860569014282922], {
             RGBColor[
             0.6570840161116028, 0.7320382945006515, 0.9664556519929053]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[440, 0.0860569014282922], {
             RGBColor[
             0.7035219317356081, 0.7683159471273551, 0.9710841494353115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[441, 0.0860569014282922], {
             RGBColor[
             0.9756999969246014, 0.9296925250939385, 0.3600995060329525]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[442, 0.0860569014282922], {
             RGBColor[
             0.9584845898875074, 0.8716209147880238, 0.2932209005506723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[443, 0.0860569014282922], {
             RGBColor[
             0.8820032512732646, 0.9087494674975723, 0.9886074515516832]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[444, 0.0860569014282922], {
             RGBColor[
             0.4152440831895105, 0.5340852869094548, 0.9476799636882783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[445, 0.0860569014282922], {
             RGBColor[
             0.9924444353496488, 0.9911435940949945, 0.774878789638237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[446, 0.0860569014282922], {
             RGBColor[
             0.4143297663849308, 0.5332933516482266, 0.9476217042299891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[447, 0.0860569014282922], {
             RGBColor[
             0.2562278882428392, 0.3866421347026161, 0.9379031712290136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[448, 0.0860569014282922], {
             RGBColor[
             0.9174297005947448, 0.9369975565611711, 0.9919864579135307]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[449, 0.0860569014282922], {
             RGBColor[
             0.25130033016387177`, 0.3814629587363943, 0.9376225540860853]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[450, 0.0860569014282922], {
             RGBColor[
             0.3492297683683656, 0.47690700538731645`, 0.9434735899220416]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[451, 0.0860569014282922], {
             RGBColor[
             0.2569232119297078, 0.38737296398358306`, 0.9379427688843415]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[452, 0.0860569014282922], {
             RGBColor[
             0.9916313643528499, 0.9908073683428467, 0.7883534802154828]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[453, 0.0860569014282922], {
             RGBColor[
             0.8518728026276887, 0.39972266856927546`, 0.19730676041921302`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[454, 0.0860569014282922], {
             RGBColor[
             0.2837493086151196, 0.41556889247271844`, 0.9394704754049221]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[455, 0.0860569014282922], {
             RGBColor[
             0.25246812917611056`, 0.38269038954099116`, 0.9376890585122285]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[456, 0.0860569014282922], {
             RGBColor[
             0.5979534795426031, 0.6844845980467856, 0.9614922347668126]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[457, 0.0860569014282922], {
             RGBColor[
             0.9027371019040448, 0.6512337207208087, 0.2405537925079908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[458, 0.0860569014282922], {
             RGBColor[
             0.38933434968102887`, 0.511643578005479, 0.9460290183801956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[459, 0.0860569014282922], {
             RGBColor[
             0.9054425315984804, 0.6628181777360814, 0.24277504525633103`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[460, 0.0860569014282922], {
             RGBColor[
             0.9868110164130007, 0.9888140305924276, 0.8682391202393686]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[461, 0.0860569014282922], {
             RGBColor[
             0.9083021706752503, 0.9297195119635656, 0.9911158659615671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[462, 0.0860569014282922], {
             RGBColor[
             0.4166949016052647, 0.5353419129009273, 0.9477724085548218]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[463, 0.0860569014282922], {
             RGBColor[
             0.4596784205131848, 0.5722266759062822, 0.950606715601786]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[464, 0.0860569014282922], {
             RGBColor[
             0.49164619012284005`, 0.5981795514070096, 0.9531233355272566]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[465, 0.0860569014282922], {
             RGBColor[
             0.9898780456268065, 0.9900823259913918, 0.8174105089494343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[466, 0.0860569014282922], {
             RGBColor[
             0.8709064619399829, 0.5066982188788449, 0.21399352628159504`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[467, 0.0860569014282922], {
             RGBColor[
             0.9699472635632133, 0.9102872046599492, 0.33775122323649936`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[468, 0.0860569014282922], {
             RGBColor[
             0.2569232119297078, 0.38737296398358306`, 0.9379427688843415]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[469, 0.0860569014282922], {
             RGBColor[
             0.5746877307342124, 0.6655964150540944, 0.95966066979537]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[470, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[471, 0.0860569014282922], {
             RGBColor[
             0.9553827963209697, 0.9662451430669208, 0.9604094671848902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[472, 0.0860569014282922], {
             RGBColor[
             0.8746760606767621, 0.9029069646072115, 0.9879085775715285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[473, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[474, 0.0860569014282922], {
             RGBColor[
             0.9931259997594081, 0.9877055334904359, 0.4931856791027207]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[475, 0.0860569014282922], {
             RGBColor[
             0.5977632145678086, 0.6843301323689079, 0.9614772564110332]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[476, 0.0860569014282922], {
             RGBColor[
             0.9950685976213134, 0.9918605538902796, 0.7046254680467884]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[477, 0.0860569014282922], {
             RGBColor[
             0.2542596702452732, 0.38457341279494556`, 0.9377910841257697]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[478, 0.0860569014282922], {
             RGBColor[
             0.8350640497664802, 0.8713214223467449, 0.9841303486088462]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[479, 0.0860569014282922], {
             RGBColor[
             0.8610043378247276, 0.4617349859713152, 0.2057309511965532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[480, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[481, 0.0860569014282922], {
             RGBColor[
             0.5603104620458799, 0.6539243006443325, 0.958528838538554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[482, 0.0860569014282922], {
             RGBColor[
             0.9122922913126144, 0.9329011258508603, 0.9914964472299816]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[483, 0.0860569014282922], {
             RGBColor[
             0.4642062353119693, 0.5759025599356676, 0.9509631617686783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[484, 0.0860569014282922], {
             RGBColor[
             0.9950526159278561, 0.9922221437912667, 0.7316544877023741]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[485, 0.0860569014282922], {
             RGBColor[
             0.6874469209973422, 0.7557580265640151, 0.9694819425944374]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[486, 0.0860569014282922], {
             RGBColor[
             0.8421437342429783, 0.8769665705753888, 0.9848056152343235]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[487, 0.0860569014282922], {
             RGBColor[
             0.3198355883202952, 0.4514472440241242, 0.9416006187616313]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[488, 0.0860569014282922], {
             RGBColor[
             0.2684923602142315, 0.3995328723569852, 0.938601614764124]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[489, 0.0860569014282922], {
             RGBColor[
             0.9658208254253059, 0.9740298080822307, 0.942740606585246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[490, 0.0860569014282922], {
             RGBColor[
             0.25246812917611056`, 0.38269038954099116`, 0.9376890585122285]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[491, 0.0860569014282922], {
             RGBColor[
             0.9885712648957886, 0.989541938576383, 0.8390672475025247]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[492, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[493, 0.0860569014282922], {
             RGBColor[
             0.8163081595876761, 0.8564254055324707, 0.9823256265803813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[494, 0.0860569014282922], {
             RGBColor[
             0.3760053267700496, 0.5000986482961596, 0.9451797048267002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[495, 0.0860569014282922], {
             RGBColor[
             0.6240788152421396, 0.7056943225006304, 0.963548916893338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[496, 0.0860569014282922], {
             RGBColor[
             0.3155675345838855, 0.4477504703962643, 0.941328662151639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[497, 0.0860569014282922], {
             RGBColor[
             0.9496735743784137, 0.8381795232372564, 0.278364380513078]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[498, 0.0860569014282922], {
             RGBColor[
             0.9289349840293515, 0.7559579232287855, 0.26167762392094174`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[499, 0.0860569014282922], {
             RGBColor[
             0.2720014946071466, 0.40322119509591003`, 0.9388014547765015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[500, 0.0860569014282922], {
             RGBColor[
             0.5952059019945706, 0.6822539908163348, 0.9612759353975232]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1dOWGAgQBNBMbNu2bds2J+bEtm3btm3btu01sjdnH271F1R1ssCg6p0C
ggUL9l38vMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEIS
kZgkJCUZyUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpR
mCIUpRjFKUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGY
JjSlGYE0pwUtaUVr2tCWdrSnAx3pRBCd6UJXutGdHvSkF73pQ1/60Z8BDGQQ
gxnCUIYxnBGMZBSjGcNYxjGeCUxkEpOZwlSmMZ0ZzGQWs5nDXOYxnwUsZBGL
WcJSlrGcFaxkFatZw1rWsZ4NbGQTm9nCVraxnR3sZBe72cNe9rGfAxzkEIc5
wlGOcZwTnOQUpznDWc5xngtc5BKXucJVrnGdG9zkFre5w13ucZ8HPOQRj3nC
U57xnBe85BWvecNb3vGeD3zkE5/5wle+8Z1f+JXf+J0/+JO/+Jt/+Jcf/Cx/
AMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEISkZgkJCUZ
yUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpRmCIUpRjF
KUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGYJjSlGYE0
pwUtaUVr2tCWdrSnAx35Od5BdKYLXelGd3rQk170pg996Ud/BjCQQQxmCEMZ
xnBGMJJRjGYMYxnHeCYwkUlMZgpTmcZ0ZjCTWcxmDnOZx3wWsJBFLGYJS1nG
clawklWsZg1rWcd6NrCRTWxmC1vZxnZ2sJNd7GYPe9nHfg5wkEMc5ghHOcZx
TnCSU5zmDGc5x3kucJFLXOYKV7nGdW5wk1vc5g53ucd9HvCQRzzmCU95xnNe
8JJXvOYNb3nHez7wkU985gtf+Rbw/z//Dz189+A=
          "], {Null, CompressedData["
1:eJxF3Al0ldW5gOF/21YsVqt2QFCqdkClVEWUGRVRJmWoghGKIgREKWUqk4DM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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[13, 59] -> 
             RGBColor[
              0.5710396459203946, 0.662634735457889, 0.9593734791954514], 
             UndirectedEdge[210, 309] -> 
             RGBColor[
              0.23463499011461536`, 0.36394662970103786`, 0.9366734876244414],
              UndirectedEdge[88, 427] -> 
             RGBColor[
              0.21816644071600988`, 0.3466371401167634, 0.9357356280992264], 
             UndirectedEdge[293, 483] -> 
             RGBColor[
              0.8686864922225178, 0.39450469054086185`, 0.22397142092169176`],
              UndirectedEdge[46, 150] -> 
             RGBColor[
              0.31231365721932186`, 0.44279963411631207`, 0.9411994089142401],
              UndirectedEdge[400, 444] -> 
             RGBColor[
              0.8285562969045, 0.22050178822288907`, 0.17497884820646079`], 
             UndirectedEdge[98, 105] -> 
             RGBColor[
              0.22603623939872042`, 0.3549087975063481, 0.9361838014918828], 
             UndirectedEdge[128, 439] -> 
             RGBColor[
              0.25567022753416335`, 0.38605599794006673`, 0.9378714132766395],
              UndirectedEdge[23, 62] -> 
             RGBColor[
              0.7605455492253483, 0.8073117539135573, 0.693976057126175], 
             UndirectedEdge[201, 236] -> 
             RGBColor[
              0.4367458916891245, 0.5493200603220583, 0.9499190884728695], 
             UndirectedEdge[40, 477] -> 
             RGBColor[
              0.2326598513128163, 0.36187063358931404`, 0.936561006391635], 
             UndirectedEdge[455, 482] -> 
             RGBColor[
              0.8569637840361095, 0.40674414496490774`, 0.4404088754929284], 
             UndirectedEdge[60, 131] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[179, 222] -> 
             RGBColor[
              0.26369928279436383`, 0.3944950440900435, 0.9383286560957851], 
             UndirectedEdge[111, 175] -> 
             RGBColor[
              0.9896715252435591, 0.9899969245055872, 0.8208330861574638], 
             UndirectedEdge[51, 110] -> 
             RGBColor[
              0.8761442527887697, 0.4191299801762435, 0.29813730878806594`], 
             UndirectedEdge[84, 261] -> 
             RGBColor[
              0.802578407870131, 0.8465597844769306, 0.9807289118084384], 
             UndirectedEdge[156, 479] -> 
             RGBColor[
              0.23031326123812593`, 0.35940421863841043`, 0.9364273715583502],
              UndirectedEdge[158, 437] -> 
             RGBColor[
              0.21289783238492682`, 0.3410994987117332, 0.9354355886489787], 
             UndirectedEdge[103, 355] -> 
             RGBColor[
              0.9026605789160858, 0.621832678187201, 0.34518239114594756`], 
             UndirectedEdge[13, 228] -> 
             RGBColor[
              0.5560506747276076, 0.6504660133981275, 0.9581934924767446], 
             UndirectedEdge[59, 409] -> 
             RGBColor[
              0.5719438498096561, 0.6633688089091125, 0.9594446614378219], 
             UndirectedEdge[243, 430] -> 
             RGBColor[
              0.26568330364733933`, 0.3965803758007084, 0.9384416431482663], 
             UndirectedEdge[333, 441] -> 
             RGBColor[
              0.39299597634942995`, 0.5148150949869406, 0.9462623339936568], 
             UndirectedEdge[179, 385] -> 
             RGBColor[
              0.2302154045308226, 0.35930136503456106`, 0.9364217987636353], 
             UndirectedEdge[81, 447] -> 
             RGBColor[
              0.4381615348855533, 0.5539352317039529, 0.9491402434452434], 
             UndirectedEdge[69, 404] -> 
             RGBColor[
              0.8720195914369621, 0.405748016840095, 0.23691988196683633`], 
             UndirectedEdge[113, 380] -> 
             RGBColor[
              0.23563903739034964`, 0.36500194704810873`, 0.9367306666314397],
              UndirectedEdge[85, 489] -> 
             RGBColor[
              0.2242348495004033, 0.3530154225085005, 0.9360812150020913], 
             UndirectedEdge[277, 498] -> 
             RGBColor[
              0.8718851812720558, 0.40529461979285863`, 0.23639772385740537`],
              UndirectedEdge[18, 160] -> 
             RGBColor[
              0.6045200328244643, 0.6881026838156832, 0.9631803229645852], 
             UndirectedEdge[355, 431] -> 
             RGBColor[
              0.9023446175940999, 0.6211568688680633, 0.310791951135041], 
             UndirectedEdge[357, 492] -> 
             RGBColor[
              0.2075698466489869, 0.3354994478894535, 0.9351321677433655], 
             UndirectedEdge[165, 386] -> 
             RGBColor[
              0.8441187916914372, 0.8785414277732838, 0.9849939979769122], 
             UndirectedEdge[218, 274] -> 
             RGBColor[
              0.6118775615619095, 0.6942958574577106, 0.963609119130596], 
             UndirectedEdge[116, 441] -> 
             RGBColor[
              0.5263358260398556, 0.6233876711354238, 0.9569331242963761], 
             UndirectedEdge[258, 435] -> 
             RGBColor[
              0.7217057517642607, 0.7765964094692765, 0.7664579098908495], 
             UndirectedEdge[112, 445] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[114, 179] -> 
             RGBColor[
              0.22995443980472458`, 0.3590270745613128, 0.9364069372085467], 
             UndirectedEdge[155, 467] -> 
             RGBColor[
              0.2375425676300431, 0.36700267802081454`, 0.9368390698625695], 
             UndirectedEdge[243, 421] -> 
             RGBColor[
              0.22859686998161965`, 0.35760018260233123`, 0.9363296256154655],
              UndirectedEdge[172, 289] -> 
             RGBColor[
              0.345767570655903, 0.47390822374389807`, 0.9432529817453046], 
             UndirectedEdge[381, 468] -> 
             RGBColor[
              0.29385090543136283`, 0.42067047076940983`, 0.9402477083379865],
              UndirectedEdge[17, 277] -> 
             RGBColor[
              0.9842391011275806, 0.968356266821895, 0.6191150211106053], 
             UndirectedEdge[279, 477] -> 
             RGBColor[
              0.28214014924959957`, 0.4138775639529604, 0.9393788361595936], 
             UndirectedEdge[4, 405] -> 
             RGBColor[
              0.19037905734984562`, 0.31743083837706143`, 0.9341531777242731],
              UndirectedEdge[36, 379] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[278, 401] -> 
             RGBColor[
              0.19472994713122652`, 0.3220038993996379, 0.9344009544607581], 
             UndirectedEdge[152, 399] -> 
             RGBColor[
              0.2527153156861724, 0.38295019823559606`, 0.9377031354182968], 
             UndirectedEdge[173, 406] -> 
             RGBColor[
              0.8761600890568056, 0.41916385235227993`, 0.29986098883365586`],
              UndirectedEdge[239, 332] -> 
             RGBColor[
              0.23367112063916273`, 0.36293354176948267`, 0.9366185966837315],
              UndirectedEdge[116, 361] -> 
             RGBColor[
              0.5470425558222825, 0.6413227997224619, 0.9582525388078701], 
             UndirectedEdge[288, 498] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[16, 386] -> 
             RGBColor[
              0.7452144755917458, 0.8010765223541869, 0.9751892409747631], 
             UndirectedEdge[216, 464] -> 
             RGBColor[
              0.27480140758027954`, 0.40616408115540853`, 0.9389609056782213],
              UndirectedEdge[379, 400] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[22, 24] -> 
             RGBColor[
              0.1988170752865331, 0.32629973022975733`, 0.9346337103628386], 
             UndirectedEdge[231, 355] -> 
             RGBColor[
              0.8304768118928137, 0.23526370799810264`, 0.17681793552818148`],
              UndirectedEdge[434, 495] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[75, 323] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[165, 288] -> 
             RGBColor[
              0.8264596817975027, 0.3824305319946304, 0.43782978303013764`], 
             UndirectedEdge[90, 229] -> 
             RGBColor[
              0.5154543184856579, 0.616939902632804, 0.9551545828836118], 
             UndirectedEdge[267, 424] -> 
             RGBColor[
              0.32359321236073335`, 0.4484918511970504, 0.9420674318834557], 
             UndirectedEdge[258, 403] -> 
             RGBColor[
              0.8761965593307338, 0.419241858580502, 0.3038305530822916], 
             UndirectedEdge[274, 305] -> 
             RGBColor[
              0.6728698608332448, 0.742281504128438, 0.9695985669953169], 
             UndirectedEdge[399, 478] -> 
             RGBColor[
              0.41018828225715515`, 0.5275118706354188, 0.9478509075255593], 
             UndirectedEdge[359, 463] -> 
             RGBColor[
              0.831998657058118, 0.24386491747293382`, 0.17815401051060936`], 
             UndirectedEdge[302, 422] -> 
             RGBColor[
              0.3930257524734591, 0.5128887624932172, 0.9465625995891717], 
             UndirectedEdge[21, 335] -> 
             RGBColor[
              0.5685137758712531, 0.6540937496535268, 0.9620892181770329], 
             UndirectedEdge[266, 445] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[200, 452] -> 
             RGBColor[
              0.4981470175789616, 0.6018428315420548, 0.9540811637122809], 
             UndirectedEdge[112, 471] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[481, 496] -> 
             RGBColor[
              0.2504961406533446, 0.38061770457227034`, 0.9375767566831525], 
             UndirectedEdge[6, 422] -> 
             RGBColor[
              0.3160911696209566, 0.44719850519152415`, 0.9413988444168244], 
             UndirectedEdge[137, 424] -> 
             RGBColor[
              0.2813766900403703, 0.41192602142725965`, 0.939377432411807], 
             UndirectedEdge[89, 482] -> 
             RGBColor[
              0.8975224519572722, 0.9211097616510341, 0.9895920627069863], 
             UndirectedEdge[142, 254] -> 
             RGBColor[
              0.28886221876631657`, 0.41799448677368717`, 0.9398696033843243],
              UndirectedEdge[178, 321] -> 
             RGBColor[
              0.8637848357389819, 0.37797025225822195`, 0.20492941108331195`],
              UndirectedEdge[151, 456] -> 
             RGBColor[
              0.268244426651874, 0.3992722784630517, 0.9385874953145326], 
             UndirectedEdge[346, 431] -> 
             RGBColor[
              0.9882192232946517, 0.971338985864578, 0.45837897693901886`], 
             UndirectedEdge[65, 297] -> 
             RGBColor[
              0.22326792573678073`, 0.35199912432642566`, 0.9360261501241884],
              UndirectedEdge[79, 253] -> 
             RGBColor[
              0.8742585681452911, 0.4192055500614041, 0.39156282211394233`], 
             UndirectedEdge[376, 475] -> 
             RGBColor[
              0.9641436958902179, 0.97247391328753, 0.9319168018252305], 
             UndirectedEdge[209, 259] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[464, 496] -> 
             RGBColor[
              0.24443386678924475`, 0.3742458703707382, 0.9372315191549225], 
             UndirectedEdge[101, 103] -> 
             RGBColor[
              0.7423876612860338, 0.7937870676334219, 0.792267547607473], 
             UndirectedEdge[69, 348] -> 
             RGBColor[
              0.9720780588899567, 0.9174748776315893, 0.3460289607139636], 
             UndirectedEdge[116, 277] -> 
             RGBColor[
              0.8327236905210305, 0.8505154585848247, 0.6749691997262832], 
             UndirectedEdge[171, 471] -> 
             RGBColor[
              0.8633448747725185, 0.37637450305087206`, 0.2038017602771198], 
             UndirectedEdge[133, 429] -> 
             RGBColor[
              0.24801000575022464`, 0.37800461915903416`, 0.9374351749783268],
              UndirectedEdge[37, 203] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[299, 399] -> 
             RGBColor[
              0.38120820226977115`, 0.5039845361639349, 0.9455694894714217], 
             UndirectedEdge[311, 429] -> 
             RGBColor[
              0.23078867443938234`, 0.35990390805586886`, 0.936454445636851], 
             UndirectedEdge[327, 446] -> 
             RGBColor[
              0.19902638409040874`, 0.32651972705357524`, 0.9346456301895747],
              UndirectedEdge[15, 249] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[50, 242] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[163, 355] -> 
             RGBColor[
              0.8304768118928137, 0.23526370799810264`, 0.17681793552818148`],
              UndirectedEdge[192, 435] -> 
             RGBColor[
              0.6598277871485738, 0.73152786434866, 0.9686707009780946], 
             UndirectedEdge[31, 191] -> 
             RGBColor[
              0.23217546467365527`, 0.361361512519669, 0.9365334212891205], 
             UndirectedEdge[385, 415] -> 
             RGBColor[
              0.18775866061236085`, 0.31467663526321576`, 0.9340039500066029],
              UndirectedEdge[207, 257] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[359, 408] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[183, 202] -> 
             RGBColor[
              0.23464668265559618`, 0.36395891930295865`, 0.9366741534973526],
              UndirectedEdge[170, 223] -> 
             RGBColor[
              0.26091102585046255`, 0.3915644092563023, 0.9381698689876865], 
             UndirectedEdge[40, 430] -> 
             RGBColor[
              0.24076319340362162`, 0.37038775990831363`, 0.9370224797358859],
              UndirectedEdge[69, 444] -> 
             RGBColor[
              0.894494185245962, 0.578497593285873, 0.2584415783797579], 
             UndirectedEdge[215, 417] -> 
             RGBColor[
              0.23113355417435436`, 0.36026639852396264`, 0.9364740860275538],
              UndirectedEdge[423, 429] -> 
             RGBColor[
              0.207561162916413, 0.3354903207359379, 0.9351316732176418], 
             UndirectedEdge[5, 83] -> RGBColor[0.817319, 0.134127, 0.164218], 
             UndirectedEdge[311, 366] -> 
             RGBColor[
              0.21056004147512417`, 0.3386423322410259, 0.9353024549151172], 
             UndirectedEdge[133, 366] -> 
             RGBColor[
              0.22778137278596647`, 0.35674304334419116`, 0.9362831842565931],
              UndirectedEdge[76, 359] -> 
             RGBColor[
              0.8763277317102309, 0.4195224230366844, 0.31810785708846784`], 
             UndirectedEdge[172, 218] -> 
             RGBColor[
              0.5588854033775118, 0.6492281120932448, 0.9600027877622141], 
             UndirectedEdge[177, 484] -> 
             RGBColor[
              0.2033510637646819, 0.3310652395917648, 0.9348919142992342], 
             UndirectedEdge[45, 328] -> 
             RGBColor[
              0.37591074520931583`, 0.4962310227311757, 0.9454667495001579], 
             UndirectedEdge[115, 144] -> 
             RGBColor[
              0.2435638403098072, 0.37333141737798453`, 0.9371819724340074], 
             UndirectedEdge[63, 72] -> 
             RGBColor[
              0.3088117371325335, 0.4410013587250076, 0.940931053493443], 
             UndirectedEdge[248, 387] -> 
             RGBColor[
              0.2032853235143931, 0.33099614242053865`, 0.9348881704892343], 
             UndirectedEdge[34, 44] -> 
             RGBColor[
              0.5037551933062931, 0.6031416247429248, 0.9557644930809137], 
             UndirectedEdge[279, 285] -> 
             RGBColor[
              0.31918224078287427`, 0.4504503802207983, 0.9415747678474624], 
             UndirectedEdge[13, 77] -> 
             RGBColor[
              0.7393999520548098, 0.7956405917835261, 0.9722782472010072], 
             UndirectedEdge[53, 445] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[91, 298] -> 
             RGBColor[
              0.8219843924164008, 0.8203269587905632, 0.6420658778876114], 
             UndirectedEdge[6, 451] -> 
             RGBColor[
              0.31296091107937973`, 0.44390840499447215`, 0.9412205808236842],
              UndirectedEdge[87, 256] -> 
             RGBColor[
              0.8597722407139262, 0.891023063122262, 0.9864870379186761], 
             UndirectedEdge[153, 172] -> 
             RGBColor[
              0.38789541628795154`, 0.5103972462232906, 0.9459373308167875], 
             UndirectedEdge[72, 438] -> 
             RGBColor[
              0.29983207958869507`, 0.43156316930326144`, 0.9404196752805343],
              UndirectedEdge[207, 440] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[19, 228] -> 
             RGBColor[
              0.42807121290671124`, 0.5396284944077405, 0.9494773208917324], 
             UndirectedEdge[8, 63] -> 
             RGBColor[
              0.27895516343135685`, 0.4105299419182229, 0.939197455929009], 
             UndirectedEdge[72, 128] -> 
             RGBColor[
              0.28177127381369815`, 0.4125801173125145, 0.9393911391102159], 
             UndirectedEdge[229, 485] -> 
             RGBColor[
              0.493481350800354, 0.5991012575949606, 0.9534247903777919], 
             UndirectedEdge[32, 407] -> 
             RGBColor[
              0.5239474714560204, 0.6211561334022514, 0.9568498726559509], 
             UndirectedEdge[475, 478] -> 
             RGBColor[
              0.7294989786631181, 0.787504214333214, 0.9688616962701988], 
             UndirectedEdge[194, 412] -> 
             RGBColor[
              0.21879008438791836`, 0.3472926291572319, 0.9357711436837434], 
             UndirectedEdge[370, 390] -> 
             RGBColor[
              0.48068060887291364`, 0.5879170041207702, 0.9526359105777598], 
             UndirectedEdge[231, 233] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[114, 385] -> 
             RGBColor[
              0.18998822410005822`, 0.3170200478512756, 0.9341309203488837], 
             UndirectedEdge[271, 442] -> 
             RGBColor[
              0.37583021451417103`, 0.49956100808681825`, 0.945182678962928], 
             UndirectedEdge[206, 254] -> 
             RGBColor[
              0.21121110658430017`, 0.33932664295068204`, 0.9353395321099203],
              UndirectedEdge[262, 455] -> 
             RGBColor[
              0.862162982525146, 0.410621698685125, 0.4316079886191312], 
             UndirectedEdge[7, 341] -> 
             RGBColor[
              0.8626928878488475, 0.3737895921602789, 0.20327715629423396`], 
             UndirectedEdge[187, 328] -> 
             RGBColor[
              0.42211567678941486`, 0.5393927026931269, 0.9482958688478269], 
             UndirectedEdge[44, 56] -> 
             RGBColor[
              0.8469959064349548, 0.8780021626885659, 0.8144131900742924], 
             UndirectedEdge[142, 388] -> 
             RGBColor[
              0.6324778710852315, 0.7059774833485709, 0.9677848279671616], 
             UndirectedEdge[282, 419] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[7, 244] -> 
             RGBColor[
              0.9653265435241076, 0.893954535776943, 0.32368523328489207`], 
             UndirectedEdge[107, 470] -> 
             RGBColor[
              0.2829505871294402, 0.41374407449152867`, 0.9394610664624095], 
             UndirectedEdge[10, 383] -> 
             RGBColor[
              0.5131465195328626, 0.6140173050277837, 0.9552627525247963], 
             UndirectedEdge[249, 419] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[191, 271] -> 
             RGBColor[
              0.2668826471852404, 0.3978409619018147, 0.9385099439884801], 
             UndirectedEdge[297, 490] -> 
             RGBColor[
              0.295576036933824, 0.4249379314256113, 0.9402560903469162], 
             UndirectedEdge[32, 176] -> 
             RGBColor[
              0.6217123396719191, 0.698046546413098, 0.9664572955572988], 
             UndirectedEdge[353, 487] -> 
             RGBColor[
              0.212512158872194, 0.340694131396738, 0.9354136251129814], 
             UndirectedEdge[281, 324] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[19, 59] -> 
             RGBColor[
              0.44306018409949816`, 0.5517972164675021, 0.9506573076104392], 
             UndirectedEdge[197, 411] -> 
             RGBColor[
              0.5628841788365053, 0.6538599474387119, 0.9597631075252654], 
             UndirectedEdge[163, 343] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[12, 396] -> 
             RGBColor[
              0.25133562707487567`, 0.38150005802781284`, 0.9376245641929499],
              UndirectedEdge[51, 397] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[448, 482] -> 
             RGBColor[
              0.8802408291329131, 0.907329864708045, 0.9879437260945121], 
             UndirectedEdge[183, 285] -> 
             RGBColor[
              0.2954522956610519, 0.4255087033323427, 0.9402233825780824], 
             UndirectedEdge[155, 365] -> 
             RGBColor[
              0.2717806724248775, 0.40298909698141017`, 0.9387888792798984], 
             UndirectedEdge[122, 217] -> 
             RGBColor[
              0.19845501151425832`, 0.32591917824892747`, 0.9346130913666328],
              UndirectedEdge[249, 269] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[101, 331] -> 
             RGBColor[
              0.6589364835874938, 0.7312180127479719, 0.9682159470470796], 
             UndirectedEdge[246, 458] -> 
             RGBColor[
              0.45506828709517866`, 0.5684604354315133, 0.9502502894486882], 
             UndirectedEdge[35, 437] -> 
             RGBColor[
              0.20415760851311143`, 0.3319129692602549, 0.9349378458294813], 
             UndirectedEdge[354, 473] -> 
             RGBColor[
              0.7341139041926492, 0.7920013522023865, 0.9744208723817095], 
             UndirectedEdge[230, 484] -> 
             RGBColor[
              0.24969102716362834`, 0.37977147924743493`, 0.9375309066609718],
              UndirectedEdge[108, 190] -> 
             RGBColor[
              0.3280007224836446, 0.45851947284484174`, 0.9421208938903753], 
             UndirectedEdge[55, 136] -> 
             RGBColor[
              0.8590242998049419, 0.4221052615756549, 0.20287901902910677`], 
             UndirectedEdge[59, 279] -> 
             RGBColor[
              0.45332288362562734`, 0.5625839643621962, 0.9512417531661489], 
             UndirectedEdge[24, 170] -> 
             RGBColor[
              0.2116033299838412, 0.33973889461199946`, 0.9353618686522815], 
             UndirectedEdge[184, 388] -> 
             RGBColor[
              0.900316789777843, 0.736870657178221, 0.6055744049490553], 
             UndirectedEdge[173, 242] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[4, 345] -> 
             RGBColor[
              0.21015441717533256`, 0.3382159953838789, 0.9352793552113114], 
             UndirectedEdge[59, 256] -> 
             RGBColor[
              0.7339103134596671, 0.7918118736537649, 0.9744326923070242], 
             UndirectedEdge[232, 480] -> 
             RGBColor[
              0.5877523494350976, 0.6753795657900517, 0.9612520559159965], 
             UndirectedEdge[3, 437] -> 
             RGBColor[
              0.19556301830914924`, 0.3228795100273981, 0.9344483966319225], 
             UndirectedEdge[199, 448] -> 
             RGBColor[
              0.9076107391885334, 0.9266123770081562, 0.8910134005812398], 
             UndirectedEdge[151, 226] -> 
             RGBColor[
              0.24965370060264616`, 0.379732246665202, 0.9375287809685435], 
             UndirectedEdge[241, 442] -> 
             RGBColor[
              0.3936637903637048, 0.5153935219207971, 0.9463048865121216], 
             UndirectedEdge[303, 400] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[42, 378] -> 
             RGBColor[
              0.28588285582609785`, 0.41781138586616284`, 0.939591977762287], 
             UndirectedEdge[15, 499] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[341, 374] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[312, 334] -> 
             RGBColor[
              0.230552492853364, 0.3596556662341861, 0.9364409954449265], 
             UndirectedEdge[7, 482] -> 
             RGBColor[
              0.9448470078274355, 0.90254660568778, 0.6370930476807435], 
             UndirectedEdge[219, 403] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[50, 449] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[318, 430] -> 
             RGBColor[
              0.26870184465051744`, 0.3997530537816021, 0.9386135445928661], 
             UndirectedEdge[242, 449] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[356, 365] -> 
             RGBColor[
              0.3958521141784222, 0.5154427777416128, 0.9467614846116235], 
             UndirectedEdge[154, 219] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[69, 275] -> 
             RGBColor[
              0.9574349696021127, 0.8614225983065917, 0.32381674285302947`], 
             UndirectedEdge[173, 310] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[351, 460] -> 
             RGBColor[
              0.6420423630429408, 0.7175237512005181, 0.9668616406644909], 
             UndirectedEdge[97, 207] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[122, 212] -> 
             RGBColor[
              0.1999697851673105, 0.32751130140048207`, 0.9346993554852674], 
             UndirectedEdge[45, 224] -> 
             RGBColor[
              0.2850155679972537, 0.41689981136882326`, 0.9395425870034717], 
             UndirectedEdge[144, 215] -> 
             RGBColor[
              0.23058979905714602`, 0.35969487741971096`, 0.9364431199780423],
              UndirectedEdge[22, 214] -> 
             RGBColor[
              0.2036724125219917, 0.3314029975103854, 0.9349102146355702], 
             UndirectedEdge[142, 150] -> 
             RGBColor[
              0.3397907487213136, 0.46873140098796173`, 0.9428721439367287], 
             UndirectedEdge[149, 419] -> 
             RGBColor[
              0.8427485102135918, 0.3295893587840956, 0.1885693276990594], 
             UndirectedEdge[11, 418] -> 
             RGBColor[
              0.9680252917800689, 0.9114065680096394, 0.5671089180690637], 
             UndirectedEdge[189, 346] -> 
             RGBColor[
              0.758201423428222, 0.7931848261137132, 0.6724145577439462], 
             UndirectedEdge[185, 224] -> 
             RGBColor[
              0.30794222932777976`, 0.4398990236404763, 0.9408884355550042], 
             UndirectedEdge[17, 386] -> 
             RGBColor[
              0.91547859821468, 0.9335639669139454, 0.921203758756203], 
             UndirectedEdge[194, 476] -> 
             RGBColor[
              0.20408939664104067`, 0.33184127425782606`, 0.9349339612642773],
              UndirectedEdge[258, 471] -> 
             RGBColor[
              0.8761965593307338, 0.419241858580502, 0.3038305530822916], 
             UndirectedEdge[203, 397] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[126, 173] -> 
             RGBColor[
              0.8563654629268306, 0.3487034608338446, 0.19818596167822738`], 
             UndirectedEdge[30, 366] -> 
             RGBColor[
              0.1867597729131777, 0.31362674095823617`, 0.9339470648298565], 
             UndirectedEdge[95, 368] -> 
             RGBColor[
              0.19197561743155647`, 0.3191089242506953, 0.9342440994590275], 
             UndirectedEdge[15, 242] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[150, 392] -> 
             RGBColor[
              0.39049019037477983`, 0.5126447091201637, 0.9461026675271316], 
             UndirectedEdge[179, 296] -> 
             RGBColor[
              0.23166652830629497`, 0.3608265881291439, 0.9365044381159032], 
             UndirectedEdge[3, 123] -> 
             RGBColor[
              0.20402053268474474`, 0.331768893873532, 0.9349300395638414], 
             UndirectedEdge[37, 257] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[17, 178] -> 
             RGBColor[
              0.9720885828279697, 0.9273697155199401, 0.5719125519494651], 
             UndirectedEdge[68, 367] -> 
             RGBColor[
              0.2321744218168602, 0.3613604164110565, 0.9365333618999687], 
             UndirectedEdge[1, 363] -> 
             RGBColor[
              0.23069669163243806`, 0.3598072282937236, 0.9364492073520718], 
             UndirectedEdge[227, 329] -> 
             RGBColor[
              0.21529055299948083`, 0.3436143997848786, 0.9355718505482646], 
             UndirectedEdge[121, 420] -> 
             RGBColor[
              0.2550040005711073, 0.3853557511606656, 0.9378334726366879], 
             UndirectedEdge[82, 149] -> 
             RGBColor[
              0.8696222340143458, 0.4946976853386944, 0.21268036640365176`], 
             UndirectedEdge[129, 355] -> 
             RGBColor[
              0.8246751523265887, 0.5626184933768341, 0.4602642940296072], 
             UndirectedEdge[87, 388] -> 
             RGBColor[
              0.8893025910926451, 0.9145697629342451, 0.9893036690998533], 
             UndirectedEdge[91, 228] -> 
             RGBColor[
              0.7683903505092387, 0.7773900081716217, 0.6374549222113163], 
             UndirectedEdge[12, 161] -> 
             RGBColor[
              0.2878546124844855, 0.4177612959984998, 0.9397819826492559], 
             UndirectedEdge[64, 115] -> 
             RGBColor[
              0.21756212088863558`, 0.346001961662103, 0.9357012129790685], 
             UndirectedEdge[56, 342] -> 
             RGBColor[
              0.9717076565997078, 0.9127794890046514, 0.46789915194522813`], 
             UndirectedEdge[378, 416] -> 
             RGBColor[
              0.3046149956866814, 0.43742728847784595`, 0.9406614096646049], 
             UndirectedEdge[119, 363] -> 
             RGBColor[
              0.19847969710316485`, 0.325945124368025, 0.934614497174402], 
             UndirectedEdge[391, 455] -> 
             RGBColor[
              0.8623939674573535, 0.3726044724173211, 0.20303663793067456`], 
             UndirectedEdge[249, 282] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[226, 429] -> 
             RGBColor[
              0.224316855525465, 0.35310161604032264`, 0.9360858851239015], 
             UndirectedEdge[181, 189] -> 
             RGBColor[
              0.4605412675252241, 0.5711446538797107, 0.9511671576944246], 
             UndirectedEdge[160, 167] -> 
             RGBColor[
              0.4561605474821908, 0.5693707081013473, 0.9503297757503926], 
             UndirectedEdge[16, 277] -> 
             RGBColor[
              0.8139749785046464, 0.8358688222621367, 0.6731005033291653], 
             UndirectedEdge[295, 341] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[69, 129] -> 
             RGBColor[
              0.870930679966885, 0.8808856413310856, 0.6795404574101209], 
             UndirectedEdge[352, 368] -> 
             RGBColor[
              0.18920022769262135`, 0.31619181366520155`, 0.9340860451192163],
              UndirectedEdge[194, 297] -> 
             RGBColor[
              0.22957360290378961`, 0.3586267908319759, 0.9363852491104362], 
             UndirectedEdge[188, 228] -> 
             RGBColor[
              0.4764305577406883, 0.5838436086796381, 0.9524734711857346], 
             UndirectedEdge[273, 430] -> 
             RGBColor[
              0.2453937716602786, 0.3752547912516788, 0.937286184317276], 
             UndirectedEdge[200, 468] -> 
             RGBColor[
              0.48541856175705617`, 0.5908180828599114, 0.9532701177626406], 
             UndirectedEdge[93, 172] -> 
             RGBColor[
              0.3758866189646938, 0.4999958295615881, 0.9451721408703121], 
             UndirectedEdge[61, 341] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[121, 442] -> 
             RGBColor[
              0.36944795676254, 0.4928528505313406, 0.9448192188256768], 
             UndirectedEdge[287, 336] -> 
             RGBColor[
              0.8241908545687948, 0.38062143074813315`, 0.4376133802636575], 
             UndirectedEdge[403, 497] -> 
             RGBColor[
              0.8604026869949277, 0.3647097089386806, 0.20143440692924686`], 
             UndirectedEdge[17, 407] -> 
             RGBColor[
              0.8378626122664915, 0.8727397256965316, 0.9135181542326689], 
             UndirectedEdge[135, 470] -> 
             RGBColor[
              0.21501465509276277`, 0.3433244135919803, 0.9355561385706315], 
             UndirectedEdge[322, 471] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[24, 52] -> 
             RGBColor[
              0.19493298804641856`, 0.32221730827504236`, 0.9344125173405062],
              UndirectedEdge[163, 440] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[274, 432] -> 
             RGBColor[
              0.627662215693468, 0.7066269492330988, 0.9651823859384503], 
             UndirectedEdge[89, 261] -> 
             RGBColor[
              0.8925985240592591, 0.917197850416106, 0.989618038128523], 
             UndirectedEdge[255, 312] -> 
             RGBColor[
              0.25276894068346034`, 0.3830065615077669, 0.9377061892825613], 
             UndirectedEdge[370, 422] -> 
             RGBColor[
              0.350546806463606, 0.47704224603396517`, 0.9435943271285148], 
             UndirectedEdge[43, 90] -> 
             RGBColor[
              0.4999309487768256, 0.6034943400182612, 0.9541654474925418], 
             UndirectedEdge[373, 449] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[49, 457] -> 
             RGBColor[
              0.8638009847389825, 0.3780247266271895, 0.20499214689883155`], 
             UndirectedEdge[234, 449] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[245, 299] -> 
             RGBColor[
              0.4708591211784622, 0.5813036723911794, 0.9514869013144127], 
             UndirectedEdge[398, 464] -> 
             RGBColor[
              0.288464885266985, 0.4205252625186573, 0.9397390205191753], 
             UndirectedEdge[245, 262] -> 
             RGBColor[
              0.717395187444922, 0.7773610525896517, 0.9594129365612236], 
             UndirectedEdge[288, 321] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[433, 465] -> 
             RGBColor[
              0.18295181335348598`, 0.3096243340224193, 0.9337302071663033], 
             UndirectedEdge[330, 367] -> 
             RGBColor[
              0.24111934498520485`, 0.3707620978018721, 0.937042762041578], 
             UndirectedEdge[106, 156] -> 
             RGBColor[
              0.2245611665730593, 0.35335840244155936`, 0.9360997982766361], 
             UndirectedEdge[85, 239] -> 
             RGBColor[
              0.23505374481506194`, 0.3643867674417887, 0.9366973350851397], 
             UndirectedEdge[336, 388] -> 
             RGBColor[
              0.8529860941236527, 0.4035819731432213, 0.44035989591821356`], 
             UndirectedEdge[69, 355] -> 
             RGBColor[
              0.8983352152225895, 0.6080214328363002, 0.2621197530231993], 
             UndirectedEdge[102, 383] -> 
             RGBColor[
              0.4499159059433277, 0.5554178997074893, 0.951374070302039], 
             UndirectedEdge[296, 327] -> 
             RGBColor[
              0.19648958029374552`, 0.3238533854206317, 0.9345011629662197], 
             UndirectedEdge[61, 288] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[141, 472] -> 
             RGBColor[
              0.2491195605244581, 0.3791708315765894, 0.9374983624812803], 
             UndirectedEdge[43, 485] -> 
             RGBColor[
              0.4779579810915217, 0.5856556949804177, 0.9524356549867219], 
             UndirectedEdge[9, 358] -> 
             RGBColor[
              0.3137918107660683, 0.4401298504157032, 0.94143822754991], 
             UndirectedEdge[70, 359] -> 
             RGBColor[
              0.8734050425786691, 0.4188525953049994, 0.40570794960622847`], 
             UndirectedEdge[466, 470] -> 
             RGBColor[
              0.2470848114448652, 0.37703218128339433`, 0.9373824865313389], 
             UndirectedEdge[41, 356] -> 
             RGBColor[
              0.5474004384833568, 0.6434433619263427, 0.9575125141927376], 
             UndirectedEdge[79, 436] -> 
             RGBColor[
              0.8681126065678694, 0.4150589185545728, 0.4215368270252724], 
             UndirectedEdge[33, 175] -> 
             RGBColor[
              0.7775942134782825, 0.823051184158842, 0.8471271912321169], 
             UndirectedEdge[176, 448] -> 
             RGBColor[
              0.8540113043416422, 0.8864294488354546, 0.985937554664639], 
             UndirectedEdge[118, 481] -> 
             RGBColor[
              0.2642710788962169, 0.3950960380470579, 0.9383612190378892], 
             UndirectedEdge[326, 346] -> 
             RGBColor[
              0.8725424883879621, 0.4075118710378607, 0.23895123788066785`], 
             UndirectedEdge[63, 435] -> 
             RGBColor[
              0.37424886655935563`, 0.49767971126876503`, 0.9451006495167384],
              UndirectedEdge[194, 350] -> 
             RGBColor[
              0.1999849515613838, 0.32752724224225804`, 0.9347002191889733], 
             UndirectedEdge[275, 486] -> 
             RGBColor[
              0.9637768525866133, 0.8818268394055082, 0.43250180785517167`], 
             UndirectedEdge[407, 478] -> 
             RGBColor[
              0.6025017705556377, 0.6874738908646236, 0.9623310846441953], 
             UndirectedEdge[62, 356] -> 
             RGBColor[
              0.5100962493492036, 0.6131581406526678, 0.9545757917743497], 
             UndirectedEdge[150, 426] -> 
             RGBColor[
              0.27709250902946053`, 0.4057799742189919, 0.9391936166298469], 
             UndirectedEdge[372, 444] -> 
             RGBColor[
              0.8285562969045, 0.22050178822288907`, 0.17497884820646079`], 
             UndirectedEdge[106, 329] -> 
             RGBColor[
              0.18619018249920005`, 0.3130280653190276, 0.9339146274984138], 
             UndirectedEdge[128, 294] -> 
             RGBColor[
              0.23038890902229686`, 0.35948372925592065`, 0.9364316795877479],
              UndirectedEdge[379, 440] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[227, 267] -> 
             RGBColor[
              0.32291920761564974`, 0.44778342947559846`, 0.9420290483103237],
              UndirectedEdge[151, 345] -> 
             RGBColor[
              0.2579701082949577, 0.388473318440524, 0.9380023880835981], 
             UndirectedEdge[275, 418] -> 
             RGBColor[
              0.9409980373735297, 0.8037839099642208, 0.271383839797922], 
             UndirectedEdge[10, 232] -> 
             RGBColor[
              0.5449308949826625, 0.6389979976079412, 0.9583278264694257], 
             UndirectedEdge[5, 431] -> 
             RGBColor[
              0.8760289938084724, 0.418883452871858, 0.28559208007867803`], 
             UndirectedEdge[42, 416] -> 
             RGBColor[
              0.2908008659889437, 0.42290776229911325`, 0.9398747154144922], 
             UndirectedEdge[37, 97] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[441, 450] -> 
             RGBColor[
              0.35399218463513593`, 0.48103197099159145`, 0.9437770468753208],
              UndirectedEdge[5, 259] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[279, 318] -> 
             RGBColor[
              0.28254307525555356`, 0.4143010647322023, 0.9394017821995571], 
             UndirectedEdge[275, 355] -> 
             RGBColor[
              0.8823446787500739, 0.5496431313605049, 0.22311515099154627`], 
             UndirectedEdge[344, 387] -> 
             RGBColor[
              0.22482902569883648`, 0.35363993936600063`, 0.9361150524575872],
              UndirectedEdge[239, 489] -> 
             RGBColor[
              0.24442557524335845`, 0.37423715543029734`, 0.9372310469636506],
              UndirectedEdge[21, 336] -> 
             RGBColor[
              0.8188782126538342, 0.37638527429296664`, 0.43710665573515706`],
              UndirectedEdge[32, 312] -> 
             RGBColor[
              0.3038288820776412, 0.431969188992844, 0.9407862361647759], 
             UndirectedEdge[77, 436] -> 
             RGBColor[
              0.9544907386391261, 0.9655798479084123, 0.9619194881543456], 
             UndirectedEdge[66, 294] -> 
             RGBColor[
              0.23819891010735164`, 0.3676925355789824, 0.9368764475956806], 
             UndirectedEdge[197, 201] -> 
             RGBColor[
              0.49062190566788, 0.5962657278401451, 0.9533417326780644], 
             UndirectedEdge[228, 256] -> 
             RGBColor[
              0.7189213422668801, 0.7796431515940032, 0.9732527055883174], 
             UndirectedEdge[292, 481] -> 
             RGBColor[
              0.24899857925793986`, 0.3790436725948234, 0.9374914727771277], 
             UndirectedEdge[444, 486] -> 
             RGBColor[
              0.898722107235629, 0.5921004206851508, 0.33089828838118596`], 
             UndirectedEdge[154, 244] -> 
             RGBColor[
              0.8706168078338911, 0.40101609835768304`, 0.23147033256236077`],
              UndirectedEdge[288, 386] -> 
             RGBColor[
              0.8260448459967887, 0.38209975318755884`, 0.4377902156211372], 
             UndirectedEdge[273, 285] -> 
             RGBColor[
              0.27433252110274803`, 0.40331048120051716`, 0.9390206426608936],
              UndirectedEdge[190, 487] -> 
             RGBColor[
              0.29152503768335564`, 0.4204245852328503, 0.9400347466411976], 
             UndirectedEdge[83, 343] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[1, 315] -> 
             RGBColor[
              0.23241208756362647`, 0.36161021817978645`, 0.9365468966126522],
              UndirectedEdge[4, 429] -> 
             RGBColor[
              0.2125409132170386, 0.3407243540363004, 0.935415262630382], 
             UndirectedEdge[189, 451] -> 
             RGBColor[
              0.41251169705394175`, 0.5279595148389932, 0.9481647663516817], 
             UndirectedEdge[10, 102] -> 
             RGBColor[
              0.3305278013611218, 0.45687607566175037`, 0.9424222336843717], 
             UndirectedEdge[357, 368] -> 
             RGBColor[
              0.2002969688982753, 0.32785519224637283`, 0.934717988114721], 
             UndirectedEdge[128, 138] -> 
             RGBColor[
              0.22021896748197323`, 0.3487944758855043, 0.9358525164621068], 
             UndirectedEdge[336, 436] -> 
             RGBColor[
              0.8681126065678694, 0.4150589185545728, 0.4215368270252724], 
             UndirectedEdge[196, 454] -> 
             RGBColor[
              0.2775665280001868, 0.40803814535898913`, 0.9391561710226074], 
             UndirectedEdge[25, 164] -> 
             RGBColor[
              0.8191346553029186, 0.8591239335240097, 0.9824771954238392], 
             UndirectedEdge[125, 282] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[9, 286] -> 
             RGBColor[
              0.229182169797179, 0.3582153698186358, 0.9363629575740882], 
             UndirectedEdge[421, 477] -> 
             RGBColor[
              0.23121248497884378`, 0.360349359803983, 0.9364785810201017], 
             UndirectedEdge[105, 484] -> 
             RGBColor[
              0.21851966349026236`, 0.34700839964812025`, 0.9357557436136738],
              UndirectedEdge[299, 475] -> 
             RGBColor[
              0.7005188986757341, 0.7639768798617301, 0.9665802782160611], 
             UndirectedEdge[247, 252] -> 
             RGBColor[
              0.1977339169176573, 0.3251612621078617, 0.9345720260961203], 
             UndirectedEdge[261, 478] -> 
             RGBColor[
              0.7215722356647942, 0.7813528085131327, 0.9739706543969529], 
             UndirectedEdge[104, 303] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[32, 66] -> 
             RGBColor[
              0.3101036799664407, 0.4385643994191369, 0.9411435766218114], 
             UndirectedEdge[213, 454] -> 
             RGBColor[
              0.29958076590078625`, 0.43117650517581874`, 0.9404098493039], 
             UndirectedEdge[129, 331] -> 
             RGBColor[
              0.7939675478085891, 0.839033454471987, 0.98008281403385], 
             UndirectedEdge[245, 475] -> 
             RGBColor[
              0.712599204811678, 0.773784216594479, 0.9675312841667021], 
             UndirectedEdge[90, 148] -> 
             RGBColor[
              0.6360400198232251, 0.7149269386277152, 0.9648173774964799], 
             UndirectedEdge[195, 496] -> 
             RGBColor[
              0.21350786360609533`, 0.34174068020339465`, 0.9354703290245638],
              UndirectedEdge[241, 371] -> 
             RGBColor[
              0.4434440089205643, 0.5559764781177132, 0.9501770359373067], 
             UndirectedEdge[13, 243] -> 
             RGBColor[
              0.39724129654714263`, 0.5111791578470015, 0.9473616067842598], 
             UndirectedEdge[246, 384] -> 
             RGBColor[
              0.5460523779791054, 0.6423489456795577, 0.9574063899317347], 
             UndirectedEdge[22, 268] -> 
             RGBColor[
              0.20099391902560468`, 0.32858773101938626`, 0.934757678393427], 
             UndirectedEdge[69, 306] -> 
             RGBColor[
              0.7222846470752082, 0.7620169546929436, 0.6666017702163287], 
             UndirectedEdge[66, 128] -> 
             RGBColor[
              0.2527669820297753, 0.38300450283855814`, 0.9377060777401315], 
             UndirectedEdge[220, 413] -> 
             RGBColor[
              0.3788148254377005, 0.50253209483257, 0.9453587235974608], 
             UndirectedEdge[319, 492] -> 
             RGBColor[
              0.19102586825047294`, 0.3181106776438004, 0.9341900126481928], 
             UndirectedEdge[61, 186] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[94, 401] -> 
             RGBColor[
              0.1828044456707124, 0.3094694412441735, 0.9337218147947803], 
             UndirectedEdge[429, 488] -> 
             RGBColor[
              0.21473056520455405`, 0.34302581710713376`, 0.9355399600717713],
              UndirectedEdge[11, 431] -> 
             RGBColor[
              0.9904763275659175, 0.9887484103996551, 0.6925501182919337], 
             UndirectedEdge[349, 487] -> 
             RGBColor[
              0.2221770047693607, 0.3508524972212829, 0.9359640237889668], 
             UndirectedEdge[156, 198] -> 
             RGBColor[
              0.23051452206007278`, 0.35961575652294975`, 0.9364388330644213],
              UndirectedEdge[12, 188] -> 
             RGBColor[
              0.3121421207816605, 0.43879791495985154`, 0.9413295612013517], 
             UndirectedEdge[70, 111] -> 
             RGBColor[
              0.985056438314053, 0.9880884674579122, 0.8973170200414953], 
             UndirectedEdge[212, 286] -> 
             RGBColor[
              0.20366843502229037`, 0.33139881690601125`, 0.9349099881228464],
              UndirectedEdge[242, 282] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[70, 175] -> 
             RGBColor[
              0.9901922146655133, 0.990212242962673, 0.8122039149346538], 
             UndirectedEdge[188, 298] -> 
             RGBColor[
              0.5300245996478504, 0.6267805592985796, 0.9570844268620295], 
             UndirectedEdge[286, 367] -> 
             RGBColor[
              0.23641375708701462`, 0.36581622656936946`, 0.9367747857720696],
              UndirectedEdge[9, 492] -> 
             RGBColor[
              0.21887186017874036`, 0.3473785806982704, 0.9357758006940542], 
             UndirectedEdge[37, 343] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[376, 391] -> 
             RGBColor[
              0.9692861559217731, 0.9190249098809967, 0.5809414281870671], 
             UndirectedEdge[230, 490] -> 
             RGBColor[
              0.31848293468104194`, 0.4490145333391401, 0.9415606042859019], 
             UndirectedEdge[346, 355] -> 
             RGBColor[
              0.8988581121735896, 0.6097852870340661, 0.2641511089370308], 
             UndirectedEdge[30, 465] -> 
             RGBColor[
              0.1792054619955512, 0.30568668121283454`, 0.933516857998699], 
             UndirectedEdge[119, 124] -> 
             RGBColor[
              0.20441395972608956`, 0.3321824106387006, 0.9349524446518228], 
             UndirectedEdge[301, 436] -> 
             RGBColor[
              0.8681126065678694, 0.4150589185545728, 0.4215368270252724], 
             UndirectedEdge[39, 108] -> 
             RGBColor[
              0.4086556507016406, 0.5269500959200856, 0.9476548870871122], 
             UndirectedEdge[98, 382] -> 
             RGBColor[
              0.27123479538503203`, 0.4010826361489628, 0.9388065894115436], 
             UndirectedEdge[81, 208] -> 
             RGBColor[
              0.7211325975340719, 0.7754974983423137, 0.7149287914988354], 
             UndirectedEdge[154, 203] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[145, 367] -> 
             RGBColor[
              0.2830394326624652, 0.4148227678377437, 0.9394300490195857], 
             UndirectedEdge[44, 132] -> 
             RGBColor[
              0.6796180336989088, 0.7496420403047319, 0.968701632273641], 
             UndirectedEdge[319, 357] -> 
             RGBColor[
              0.2038097007889821, 0.3315472961835712, 0.9349180329992755], 
             UndirectedEdge[364, 378] -> 
             RGBColor[
              0.29415700671630873`, 0.4265080430632411, 0.9400631784149752], 
             UndirectedEdge[213, 251] -> 
             RGBColor[
              0.3656301307264068, 0.4883851452501694, 0.9446184564254285], 
             UndirectedEdge[73, 136] -> 
             RGBColor[
              0.856961449626315, 0.4062492911560167, 0.20090363136839764`], 
             UndirectedEdge[441, 461] -> 
             RGBColor[
              0.45490348370989475`, 0.5660401492108743, 0.9508690799111832], 
             UndirectedEdge[90, 480] -> 
             RGBColor[
              0.5389584272669072, 0.6365897569125576, 0.9568479281456727], 
             UndirectedEdge[118, 446] -> 
             RGBColor[
              0.21718653605083982`, 0.34560719818412555`, 0.9356798239781839],
              UndirectedEdge[210, 480] -> 
             RGBColor[
              0.364909192113561, 0.48438660176421894`, 0.9448658139891831], 
             UndirectedEdge[95, 492] -> 
             RGBColor[
              0.19924849518226806`, 0.326753179893776, 0.9346582790876721], 
             UndirectedEdge[261, 328] -> 
             RGBColor[
              0.7017283701270802, 0.7652426645136615, 0.9724084726113494], 
             UndirectedEdge[152, 496] -> 
             RGBColor[
              0.2051955967604141, 0.33300396072042604`, 0.9349969577245991], 
             UndirectedEdge[86, 177] -> 
             RGBColor[
              0.204427895244704, 0.3321970577523273, 0.9349532382589922], 
             UndirectedEdge[45, 217] -> 
             RGBColor[
              0.23183546793394733`, 0.36100415438919764`, 0.9365140589777743],
              UndirectedEdge[306, 331] -> 
             RGBColor[
              0.6453215149169124, 0.720164767833845, 0.9671441268400578], 
             UndirectedEdge[103, 129] -> 
             RGBColor[
              0.8774187255071293, 0.9016025093574369, 0.8041344145942433], 
             UndirectedEdge[50, 126] -> 
             RGBColor[
              0.8563654629268306, 0.3487034608338446, 0.19818596167822736`], 
             UndirectedEdge[172, 308] -> 
             RGBColor[
              0.3042365377894142, 0.4307035671871346, 0.9408714806274372], 
             UndirectedEdge[112, 266] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[129, 275] -> 
             RGBColor[
              0.8469448752581116, 0.7933181891173926, 0.6210335543626414], 
             UndirectedEdge[297, 325] -> 
             RGBColor[
              0.3379519408599507, 0.461641809531562, 0.9429562454735485], 
             UndirectedEdge[202, 396] -> 
             RGBColor[
              0.23566677937848166`, 0.36503110563657915`, 0.9367322464966231],
              UndirectedEdge[167, 236] -> 
             RGBColor[
              0.3815834793692655, 0.504536728962441, 0.9455765013084759], 
             UndirectedEdge[184, 301] -> 
             RGBColor[
              0.8369837657282427, 0.26650113164225936`, 0.18231370738115665`],
              UndirectedEdge[78, 258] -> 
             RGBColor[
              0.9750213117175937, 0.926509082881858, 0.43348885156620276`], 
             UndirectedEdge[172, 470] -> 
             RGBColor[0.3122258224217289, 0.4391008118856, 0.94132645856816], 
             UndirectedEdge[72, 159] -> 
             RGBColor[
              0.3689545388465866, 0.49399161017976106`, 0.9447304348549841], 
             UndirectedEdge[304, 337] -> 
             RGBColor[
              0.2261823882456348, 0.3550624092108272, 0.9361921244525068], 
             UndirectedEdge[88, 271] -> 
             RGBColor[
              0.2646478400333292, 0.39549203789019866`, 0.9383826750272796], 
             UndirectedEdge[392, 413] -> 
             RGBColor[
              0.4263466505931637, 0.5437017727632361, 0.9483874094656242], 
             UndirectedEdge[187, 216] -> 
             RGBColor[
              0.3182566714322743, 0.44643568599611877`, 0.9416334355165438], 
             UndirectedEdge[33, 432] -> 
             RGBColor[
              0.6658838925050865, 0.7376570283356887, 0.9681913363476764], 
             UndirectedEdge[36, 75] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[243, 335] -> 
             RGBColor[
              0.2849976301701568, 0.4162998743541054, 0.9395628417739867], 
             UndirectedEdge[323, 499] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[168, 480] -> 
             RGBColor[
              0.6297537319756995, 0.7081913650531002, 0.9654383612024078], 
             UndirectedEdge[301, 388] -> 
             RGBColor[
              0.8529860941236527, 0.4035819731432213, 0.44035989591821356`], 
             UndirectedEdge[111, 371] -> 
             RGBColor[
              0.7655925884892005, 0.8153534034271036, 0.9316997915837725], 
             UndirectedEdge[103, 231] -> 
             RGBColor[
              0.8763449551304583, 0.4195592621909958, 0.3199825200895846], 
             UndirectedEdge[99, 131] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[193, 428] -> 
             RGBColor[
              0.20228207150770255`, 0.3299416609516557, 0.9348310367716316], 
             UndirectedEdge[189, 370] -> 
             RGBColor[
              0.46831823256064525`, 0.5778806701117645, 0.9516626990295814], 
             UndirectedEdge[45, 187] -> 
             RGBColor[
              0.32097517805687237`, 0.4492930088218466, 0.9417882504471444], 
             UndirectedEdge[346, 443] -> 
             RGBColor[
              0.8671794238025463, 0.8799881761931223, 0.6821354249019], 
             UndirectedEdge[19, 318] -> 
             RGBColor[
              0.2722803757294244, 0.4035143168375083, 0.9388173366438475], 
             UndirectedEdge[5, 129] -> 
             RGBColor[
              0.7983595285409613, 0.3603450773806288, 0.4350644229732442], 
             UndirectedEdge[29, 46] -> 
             RGBColor[
              0.24415483873233365`, 0.37395259419152405`, 0.9372156289198665],
              UndirectedEdge[227, 263] -> 
             RGBColor[
              0.3111215525527843, 0.43756489362752915`, 0.9412773121619749], 
             UndirectedEdge[272, 435] -> 
             RGBColor[
              0.5079170557519607, 0.611284214636594, 0.9544331827525074], 
             UndirectedEdge[208, 483] -> 
             RGBColor[
              0.9822132132406076, 0.9513533457595487, 0.41174420115349936`], 
             UndirectedEdge[244, 475] -> 
             RGBColor[
              0.9597357029053115, 0.9456258595690394, 0.6742998293777165], 
             UndirectedEdge[350, 412] -> 
             RGBColor[
              0.20892004662185062`, 0.33691859366855603`, 0.9352090596343783],
              UndirectedEdge[217, 398] -> 
             RGBColor[
              0.24278043899605473`, 0.37250801292671853`, 0.9371373588881275],
              UndirectedEdge[370, 451] -> 
             RGBColor[
              0.34741654792202903`, 0.4737521458369133, 0.9434160635353744], 
             UndirectedEdge[265, 424] -> 
             RGBColor[
              0.2218738016558165, 0.3505338115247602, 0.9359467568201993], 
             UndirectedEdge[28, 419] -> 
             RGBColor[
              0.8613224849238736, 0.3683564012224616, 0.2021744979333091], 
             UndirectedEdge[67, 381] -> 
             RGBColor[
              0.20330273841305002`, 0.33101444658319545`, 0.9348891622419497],
              UndirectedEdge[239, 435] -> 
             RGBColor[
              0.35235214804716863`, 0.47466487178031647`, 0.9438536637907615],
              UndirectedEdge[302, 370] -> 
             RGBColor[
              0.4457020294385857, 0.5595198175689367, 0.9498822686739312], 
             UndirectedEdge[2, 66] -> 
             RGBColor[
              0.23109684665162938`, 0.3602278165901873, 0.9364719955884385], 
             UndirectedEdge[36, 408] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[76, 483] -> 
             RGBColor[
              0.982883335899123, 0.9527866703663195, 0.4846829170152394], 
             UndirectedEdge[9, 367] -> 
             RGBColor[
              0.2501892935368386, 0.3802951887975917, 0.9375592821938071], 
             UndirectedEdge[133, 469] -> 
             RGBColor[
              0.2251876288090195, 0.3540168539715534, 0.9361354743742063], 
             UndirectedEdge[46, 297] -> 
             RGBColor[
              0.26748674663782457`, 0.39847590872859817`, 0.9385443465586196],
              UndirectedEdge[159, 435] -> 
             RGBColor[
              0.4343916682734087, 0.5506699627235185, 0.9489000308782796], 
             UndirectedEdge[126, 340] -> 
             RGBColor[
              0.9580550382851865, 0.8818464109073033, 0.591032485493439], 
             UndirectedEdge[27, 290] -> 
             RGBColor[
              0.19806122117282127`, 0.32550527963232745`, 0.9345906655892486],
              UndirectedEdge[326, 338] -> 
             RGBColor[
              0.8759439761629737, 0.4187016087247386, 0.2763384340342258], 
             UndirectedEdge[179, 438] -> 
             RGBColor[
              0.27563010636510166`, 0.40703509612079425`, 0.9390080988480669],
              UndirectedEdge[138, 339] -> 
             RGBColor[
              0.1899160305473181, 0.31694416785001006`, 0.934126809032856], 
             UndirectedEdge[475, 482] -> 
             RGBColor[
              0.9392561672086392, 0.9542179294798765, 0.9877076437735679], 
             UndirectedEdge[94, 428] -> 
             RGBColor[
              0.19798131880027114`, 0.3254212971726742, 0.9345861152673369], 
             UndirectedEdge[186, 295] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[348, 372] -> 
             RGBColor[
              0.8657911144896757, 0.38473790158096466`, 0.21272342517580606`],
              UndirectedEdge[293, 343] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[385, 446] -> 
             RGBColor[
              0.1942371163982918, 0.32148590305205027`, 0.9343728884795952], 
             UndirectedEdge[7, 288] -> 
             RGBColor[
              0.8626928878488475, 0.3737895921602789, 0.20327715629423396`], 
             UndirectedEdge[242, 323] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[464, 481] -> 
             RGBColor[
              0.28633185579708176`, 0.41828331330390933`, 0.9396175476463986],
              UndirectedEdge[42, 108] -> 
             RGBColor[
              0.29172348972761986`, 0.4237068926091371, 0.9399335041832765], 
             UndirectedEdge[101, 276] -> 
             RGBColor[
              0.41043620356290245`, 0.5289146649262826, 0.9476516475428687], 
             UndirectedEdge[86, 426] -> 
             RGBColor[
              0.2108343428642681, 0.3389306403927288, 0.9353180759734364], 
             UndirectedEdge[37, 324] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[290, 297] -> 
             RGBColor[
              0.21970848593960174`, 0.3482579274180727, 0.9358234452934584], 
             UndirectedEdge[315, 380] -> 
             RGBColor[
              0.2069794182961998, 0.33487887025535457`, 0.9350985437221347], 
             UndirectedEdge[181, 390] -> 
             RGBColor[
              0.4729036438374925, 0.5811809878887164, 0.9521403692426029], 
             UndirectedEdge[283, 421] -> 
             RGBColor[
              0.19788031285751928`, 0.32531513352269537`, 0.934580363128322], 
             UndirectedEdge[97, 355] -> 
             RGBColor[
              0.8304768118928137, 0.23526370799810264`, 0.17681793552818148`],
              UndirectedEdge[192, 219] -> 
             RGBColor[
              0.8349445829202758, 0.3891961618334242, 0.4386390804737884], 
             UndirectedEdge[171, 192] -> 
             RGBColor[
              0.9127961865391916, 0.8801019973264443, 0.6352252611263622], 
             UndirectedEdge[122, 216] -> 
             RGBColor[
              0.23867128343248623`, 0.3681890298938975, 0.9369033485577333], 
             UndirectedEdge[18, 28] -> 
             RGBColor[
              0.8517541692906616, 0.8223523733810587, 0.6271103274009263], 
             UndirectedEdge[178, 288] -> 
             RGBColor[
              0.8637848357389819, 0.37797025225822195`, 0.20492941108331195`],
              UndirectedEdge[165, 185] -> 
             RGBColor[
              0.5826823072651669, 0.6655836746935463, 0.9633520886464765], 
             UndirectedEdge[264, 281] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[80, 192] -> 
             RGBColor[
              0.9140926674874497, 0.9337618841006211, 0.9717390466384628], 
             UndirectedEdge[74, 402] -> 
             RGBColor[
              0.28664069656288654`, 0.4145877472581879, 0.9397823340543834], 
             UndirectedEdge[3, 158] -> 
             RGBColor[
              0.2166432544871289, 0.3450361748146247, 0.9356488848968436], 
             UndirectedEdge[426, 476] -> 
             RGBColor[
              0.20678139218521432`, 0.3346707322571282, 0.9350872664280675], 
             UndirectedEdge[27, 177] -> 
             RGBColor[
              0.20421188606161866`, 0.3319700184051313, 0.9349409368555723], 
             UndirectedEdge[355, 443] -> 
             RGBColor[
              0.8216514179326964, 0.5602563290870928, 0.4599629164436284], 
             UndirectedEdge[21, 256] -> 
             RGBColor[
              0.8436281097875116, 0.8781501713422988, 0.9849471962988788], 
             UndirectedEdge[331, 404] -> 
             RGBColor[
              0.8207108366647649, 0.3778465589340292, 0.4372814530493224], 
             UndirectedEdge[142, 285] -> 
             RGBColor[
              0.3374576097099063, 0.46671055324325716`, 0.9427234783820356], 
             UndirectedEdge[232, 267] -> 
             RGBColor[
              0.5508554530526312, 0.6441295520312013, 0.958705334070763], 
             UndirectedEdge[133, 488] -> 
             RGBColor[
              0.22772081169529612`, 0.3566793897981017, 0.9362797353920715], 
             UndirectedEdge[148, 393] -> 
             RGBColor[
              0.5205392578625186, 0.6188284372317407, 0.9563684594629627], 
             UndirectedEdge[84, 89] -> 
             RGBColor[
              0.7687714356170879, 0.8196030224681695, 0.9775043726151027], 
             UndirectedEdge[27, 350] -> 
             RGBColor[
              0.19805630037094138`, 0.32550010755755476`, 0.9345903853568613],
              UndirectedEdge[8, 435] -> 
             RGBColor[
              0.3541661224083213, 0.47657147384650533`, 0.9439569669470946], 
             UndirectedEdge[20, 220] -> 
             RGBColor[
              0.40815671966871825`, 0.5275114594099448, 0.9473485851862612], 
             UndirectedEdge[35, 422] -> 
             RGBColor[
              0.25718407515887753`, 0.3876471477771245, 0.9379576246593302], 
             UndirectedEdge[65, 177] -> 
             RGBColor[
              0.19983486008505225`, 0.32736948658428433`, 0.9346916717014366],
              UndirectedEdge[93, 160] -> 
             RGBColor[
              0.41434048219955033`, 0.5332607321432926, 0.9476339644047369], 
             UndirectedEdge[277, 373] -> 
             RGBColor[
              0.8718851812720558, 0.40529461979285863`, 0.23639772385740537`],
              UndirectedEdge[15, 126] -> 
             RGBColor[
              0.8563654629268306, 0.3487034608338446, 0.19818596167822736`], 
             UndirectedEdge[95, 367] -> 
             RGBColor[
              0.2305659285403663, 0.35966978799309735`, 0.936441760587425], 
             UndirectedEdge[304, 465] -> 
             RGBColor[
              0.2045659825518425, 0.33234219626737077`, 0.9349611021268518], 
             UndirectedEdge[218, 305] -> 
             RGBColor[
              0.8008096506568456, 0.8446558514839924, 0.9806911855307536], 
             UndirectedEdge[137, 265] -> 
             RGBColor[
              0.26167159806531437`, 0.3912147203864842, 0.9382552565748988], 
             UndirectedEdge[325, 392] -> 
             RGBColor[
              0.4343230041731056, 0.550610489330994, 0.9488956556625256], 
             UndirectedEdge[263, 393] -> 
             RGBColor[
              0.37476311386086897`, 0.49902270590966347`, 0.9451005521185729],
              UndirectedEdge[228, 335] -> 
             RGBColor[
              0.44380700835062176`, 0.5555867299052314, 0.9503947274664715], 
             UndirectedEdge[104, 408] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[145, 375] -> 
             RGBColor[
              0.29508560074384793`, 0.4274840542624467, 0.9401160604711118], 
             UndirectedEdge[181, 451] -> 
             RGBColor[
              0.3396395828866079, 0.4670161296048595, 0.9429205222002176], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.2855288778367985, 0.4174393325559085, 0.93957181923946], 
             UndirectedEdge[387, 439] -> 
             RGBColor[
              0.24411472500393933`, 0.3739104321196243, 0.9372133445023774], 
             UndirectedEdge[163, 231] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[143, 288] -> 
             RGBColor[
              0.8305642118064, 0.2359355020328133, 0.17690162978413582`], 
             UndirectedEdge[128, 312] -> 
             RGBColor[
              0.2464921841409758, 0.3764092924122653, 0.937348737283096], 
             UndirectedEdge[270, 479] -> 
             RGBColor[
              0.18878700248308236`, 0.3157574877699845, 0.9340625125548451], 
             UndirectedEdge[119, 120] -> 
             RGBColor[
              0.1926435788239345, 0.319810994025283, 0.9342821388721632], 
             UndirectedEdge[105, 462] -> 
             RGBColor[
              0.229837954460574, 0.3589046410790131, 0.936400303540522], 
             UndirectedEdge[14, 159] -> 
             RGBColor[
              0.41659878498905367`, 0.5352586615189268, 0.9477662840890294], 
             UndirectedEdge[58, 417] -> 
             RGBColor[
              0.2488046847191422, 0.3788398771409232, 0.9374804307699846], 
             UndirectedEdge[66, 299] -> 
             RGBColor[
              0.35967789907867415`, 0.4813548224100252, 0.9443433705559179], 
             UndirectedEdge[11, 348] -> 
             RGBColor[
              0.9751195085877224, 0.9375300834633149, 0.5832471359376257], 
             UndirectedEdge[4, 31] -> 
             RGBColor[
              0.21260957010359166`, 0.3407965167771657, 0.9354191725385025], 
             UndirectedEdge[259, 400] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[247, 451] -> 
             RGBColor[
              0.24679602556146502`, 0.37672864900985814`, 0.9373660406024997],
              UndirectedEdge[17, 261] -> 
             RGBColor[
              0.9569330773756479, 0.9666186433450407, 0.9251577239854265], 
             UndirectedEdge[361, 386] -> 
             RGBColor[
              0.6265759062045188, 0.7036449006082633, 0.9661292482994008], 
             UndirectedEdge[212, 492] -> 
             RGBColor[
              0.19335812540385172`, 0.3205620277856458, 0.9343228312428125], 
             UndirectedEdge[287, 388] -> 
             RGBColor[
              0.8811274230386713, 0.9080511058370317, 0.9885239142728066], 
             UndirectedEdge[383, 480] -> 
             RGBColor[
              0.5559679739852978, 0.6503988732098943, 0.9581869819713671], 
             UndirectedEdge[403, 440] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[13, 354] -> 
             RGBColor[
              0.7007171274519702, 0.7648883443366565, 0.9717917557802591], 
             UndirectedEdge[1, 42] -> 
             RGBColor[
              0.26932784147908145`, 0.4004110161389142, 0.9386491941861734], 
             UndirectedEdge[161, 188] -> 
             RGBColor[
              0.35599050426396195`, 0.4827628150156156, 0.9439043780350249], 
             UndirectedEdge[194, 426] -> 
             RGBColor[
              0.2125469848716252, 0.34073073573023605`, 0.9354156084021286], 
             UndirectedEdge[257, 324] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[198, 479] -> 
             RGBColor[
              0.19373559329222378`, 0.3209587704691713, 0.9343443274806416], 
             UndirectedEdge[372, 431] -> 
             RGBColor[
              0.8760289938084724, 0.418883452871858, 0.28559208007867803`], 
             UndirectedEdge[107, 466] -> 
             RGBColor[
              0.2835372091003608, 0.41436065137694744`, 0.939494473715824], 
             UndirectedEdge[122, 330] -> 
             RGBColor[
              0.21641357139056538`, 0.344794763317387, 0.9356358047842801], 
             UndirectedEdge[4, 472] -> 
             RGBColor[
              0.19355933557756982`, 0.3207735124356854, 0.9343342898645419], 
             UndirectedEdge[145, 458] -> 
             RGBColor[
              0.3805547611175523, 0.5040310020322399, 0.9454698887190787], 
             UndirectedEdge[3, 451] -> 
             RGBColor[
              0.24545922641333842`, 0.37532358834721574`, 0.9372899118686311],
              UndirectedEdge[146, 239] -> 
             RGBColor[
              0.21955415616402918`, 0.348095717038873, 0.93581465644105], 
             UndirectedEdge[15, 282] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[82, 126] -> 
             RGBColor[
              0.916199280091377, 0.7036541810826651, 0.25133650057422957`], 
             UndirectedEdge[413, 474] -> 
             RGBColor[
              0.40874864664870547`, 0.5284592662479426, 0.9472660802155872], 
             UndirectedEdge[160, 235] -> 
             RGBColor[
              0.4011187714023029, 0.521808750793224, 0.9467914886842361], 
             UndirectedEdge[161, 183] -> 
             RGBColor[
              0.29416391383429163`, 0.4243927717499564, 0.9401412880273525], 
             UndirectedEdge[366, 429] -> 
             RGBColor[
              0.2147911262952244, 0.34308947065322315`, 0.9355434089362928], 
             UndirectedEdge[7, 313] -> 
             RGBColor[
              0.9656877072512522, 0.9180895651945491, 0.6018151796811678], 
             UndirectedEdge[129, 444] -> 
             RGBColor[
              0.8208341223499612, 0.533094653826407, 0.4565861193861659], 
             UndirectedEdge[18, 493] -> 
             RGBColor[
              0.6718112756182114, 0.7427327461515889, 0.9684777360932533], 
             UndirectedEdge[149, 411] -> 
             RGBColor[
              0.8077452715809664, 0.5432739233115719, 0.4578166578979691], 
             UndirectedEdge[221, 301] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[45, 496] -> 
             RGBColor[
              0.24168419906114047`, 0.37135579524949736`, 0.9370749296455758],
              UndirectedEdge[478, 482] -> 
             RGBColor[
              0.7264961635628073, 0.7852647197480608, 0.973944678975416], 
             UndirectedEdge[69, 331] -> 
             RGBColor[
              0.9044576421525903, 0.9071378636611861, 0.6828660025242381], 
             UndirectedEdge[16, 143] -> 
             RGBColor[
              0.7737686828707752, 0.43259576374804576`, 0.44397690814617397`],
              UndirectedEdge[210, 280] -> 
             RGBColor[
              0.396625050619534, 0.5101349644825113, 0.9473626025497911], 
             UndirectedEdge[101, 390] -> 
             RGBColor[
              0.5242582957488938, 0.6246555279128561, 0.9556906799442186], 
             UndirectedEdge[400, 418] -> 
             RGBColor[
              0.8610616366179067, 0.36732222461184755`, 0.20196461326343138`],
              UndirectedEdge[84, 299] -> 
             RGBColor[
              0.5687650672352391, 0.6602306460937123, 0.9595755708293949], 
             UndirectedEdge[333, 386] -> 
             RGBColor[
              0.6306233379177042, 0.7071505825283917, 0.9663871470691616], 
             UndirectedEdge[244, 341] -> 
             RGBColor[
              0.8706168078338911, 0.40101609835768304`, 0.23147033256236077`],
              UndirectedEdge[143, 373] -> 
             RGBColor[
              0.8305642118064, 0.2359355020328133, 0.17690162978413582`], 
             UndirectedEdge[160, 284] -> 
             RGBColor[
              0.3769905478109568, 0.5000200987965604, 0.9452866467788439], 
             UndirectedEdge[281, 343] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[207, 445] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[260, 334] -> 
             RGBColor[
              0.26255693501735466`, 0.39299015605094145`, 0.9382747396284472],
              UndirectedEdge[66, 114] -> 
             RGBColor[
              0.22515212124439515`, 0.35397953326982357`, 0.9361334522709297],
              UndirectedEdge[364, 381] -> 
             RGBColor[
              0.2539571451040042, 0.38425543969027, 0.9377738557665203], 
             UndirectedEdge[204, 306] -> 
             RGBColor[
              0.6716952973173317, 0.7411945060226874, 0.9696596817495633], 
             UndirectedEdge[358, 361] -> 
             RGBColor[
              0.39714059485190245`, 0.5184049552191992, 0.9465264254196921], 
             UndirectedEdge[294, 415] -> 
             RGBColor[
              0.20054448474921935`, 0.3281153470991263, 0.9347320837762653], 
             UndirectedEdge[2, 255] -> 
             RGBColor[
              0.22956360210905913`, 0.3586162793626272, 0.9363846795799712], 
             UndirectedEdge[326, 443] -> 
             RGBColor[
              0.7953357941470689, 0.3579829130908875, 0.4347630453872655], 
             UndirectedEdge[58, 145] -> 
             RGBColor[
              0.27446298131762203`, 0.4058083736958911, 0.9389416328032197], 
             UndirectedEdge[103, 346] -> 
             RGBColor[
              0.9886931652776305, 0.9723526998432848, 0.5099646369553787], 
             UndirectedEdge[62, 108] -> 
             RGBColor[
              0.4199530900612806, 0.5361218661360846, 0.948544262897387], 
             UndirectedEdge[91, 336] -> 
             RGBColor[
              0.8662785326994125, 0.38638207765364485`, 0.21461695287942806`],
              UndirectedEdge[338, 395] -> 
             RGBColor[
              0.9545810948287645, 0.8462000070822004, 0.3759117982208804], 
             UndirectedEdge[19, 335] -> 
             RGBColor[
              0.29929511833709316`, 0.431327440930663, 0.9403770625738554], 
             UndirectedEdge[2, 195] -> 
             RGBColor[
              0.2100171428775559, 0.33807171139322245`, 0.9352715376431322], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.3108236109603984, 0.4367287160722685, 0.9412794952284302], 
             UndirectedEdge[150, 325] -> 
             RGBColor[
              0.38277885144144796`, 0.5059655349192759, 0.945611307829169], 
             UndirectedEdge[208, 238] -> 
             RGBColor[
              0.9647733116194365, 0.8867812659004515, 0.37390414215136103`], 
             UndirectedEdge[318, 335] -> 
             RGBColor[
              0.2880161711733349, 0.41947255233499914`, 0.9397347432185865], 
             UndirectedEdge[12, 421] -> 
             RGBColor[
              0.22311781120305674`, 0.35184134443367066`, 0.9360176013235675],
              UndirectedEdge[102, 278] -> 
             RGBColor[
              0.23503759534630753`, 0.36436979332619235`, 0.9366964153967852],
              UndirectedEdge[5, 209] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[76, 463] -> 
             RGBColor[
              0.9056870458264669, 0.638998257982552, 0.34597987810968656`], 
             UndirectedEdge[293, 445] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[48, 250] -> 
             RGBColor[
              0.2928014111284232, 0.4203922887415252, 0.9401577374493421], 
             UndirectedEdge[459, 477] -> 
             RGBColor[
              0.2530584936401587, 0.3833109000239747, 0.9377226788950901], 
             UndirectedEdge[400, 404] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[144, 246] -> 
             RGBColor[
              0.35696945876019426`, 0.4786389058672158, 0.9441772202942458], 
             UndirectedEdge[90, 393] -> 
             RGBColor[
              0.483014768717581, 0.588842395082875, 0.9530875634575574], 
             UndirectedEdge[157, 360] -> 
             RGBColor[
              0.821018879012048, 0.40265646105823816`, 0.44038049549212843`], 
             UndirectedEdge[156, 250] -> 
             RGBColor[
              0.3132873521623067, 0.4419243116518183, 0.9413243814849879], 
             UndirectedEdge[25, 220] -> 
             RGBColor[
              0.5522883600909476, 0.6427585806873211, 0.9599021951346662], 
             UndirectedEdge[261, 407] -> 
             RGBColor[
              0.8073350312031458, 0.850275694776358, 0.981203007569101], 
             UndirectedEdge[42, 364] -> 
             RGBColor[
              0.2803428770185711, 0.4119885168845083, 0.9392764841648626], 
             UndirectedEdge[83, 257] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[137, 263] -> 
             RGBColor[
              0.3515933537073658, 0.478954224210705, 0.9436241954898061], 
             UndirectedEdge[27, 65] -> 
             RGBColor[
              0.20162066097000025`, 0.3292464765406804, 0.9347933704199787], 
             UndirectedEdge[318, 421] -> 
             RGBColor[
              0.23161541098479776`, 0.360772860583225, 0.9365015270600652], 
             UndirectedEdge[203, 341] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[80, 483] -> 
             RGBColor[
              0.9647055314408126, 0.9417246771617777, 0.6497375573103179], 
             UndirectedEdge[95, 319] -> 
             RGBColor[
              0.19548834932226328`, 0.3228010281878937, 0.9344441443435821], 
             UndirectedEdge[84, 376] -> 
             RGBColor[
              0.832389864449723, 0.8687276795195121, 0.9249120944385643], 
             UndirectedEdge[260, 446] -> 
             RGBColor[
              0.25513065781781996`, 0.38518466786106076`, 0.9378518241281263],
              UndirectedEdge[174, 393] -> 
             RGBColor[
              0.29163543014520826`, 0.4184242024491195, 0.9401185255489448], 
             UndirectedEdge[185, 216] -> 
             RGBColor[
              0.29497840118270136`, 0.42627321830582066`, 0.9401501647204071],
              UndirectedEdge[143, 321] -> 
             RGBColor[
              0.8305642118064, 0.2359355020328133, 0.17690162978413582`], 
             UndirectedEdge[296, 415] -> 
             RGBColor[
              0.1892097843878332, 0.3162018583577987, 0.9340865893588708], 
             UndirectedEdge[42, 113] -> 
             RGBColor[
              0.26381259130705503`, 0.39461413852105653`, 0.938335108847958], 
             UndirectedEdge[54, 264] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[9, 95] -> 
             RGBColor[
              0.2233343412505307, 0.35206893124236366`, 0.9360299323894435], 
             UndirectedEdge[47, 55] -> 
             RGBColor[
              0.8007526423490732, 0.4840965388666049, 0.45044599340948344`], 
             UndirectedEdge[212, 330] -> 
             RGBColor[
              0.20837402292048057`, 0.33634468813851387`, 0.9351779643923548],
              UndirectedEdge[89, 244] -> 
             RGBColor[
              0.9180019876539445, 0.912517691740197, 0.6761842483111349], 
             UndirectedEdge[3, 247] -> 
             RGBColor[
              0.2006452395594779, 0.32822124679293196`, 0.9347378216136562], 
             UndirectedEdge[26, 318] -> 
             RGBColor[
              0.23281828005836602`, 0.3620371522458494, 0.9365700286743196], 
             UndirectedEdge[46, 426] -> 
             RGBColor[
              0.2504601286056602, 0.3805798536268583, 0.937574705850312], 
             UndirectedEdge[102, 247] -> 
             RGBColor[
              0.23463961323959567`, 0.36395148889851525`, 0.9366737509045697],
              UndirectedEdge[285, 287] -> 
             RGBColor[
              0.586107161663346, 0.6687841757317179, 0.9634625646876807], 
             UndirectedEdge[346, 390] -> 
             RGBColor[
              0.7705637997404904, 0.8032211601227189, 0.6733877692921244], 
             UndirectedEdge[388, 473] -> 
             RGBColor[
              0.7653160411936457, 0.8168810892875349, 0.9773969600633411], 
             UndirectedEdge[377, 412] -> 
             RGBColor[
              0.20734204026481207`, 0.3352600089359268, 0.935119194506796], 
             UndirectedEdge[7, 321] -> 
             RGBColor[
              0.8626928878488475, 0.3737895921602789, 0.20327715629423396`], 
             UndirectedEdge[209, 275] -> 
             RGBColor[
              0.8560290549644465, 0.34736971536429956`, 0.19791527993518332`],
              UndirectedEdge[204, 346] -> 
             RGBColor[
              0.9316157699795097, 0.9308133831466772, 0.688428591304491], 
             UndirectedEdge[220, 297] -> 
             RGBColor[
              0.2981314546378194, 0.42715130580178384`, 0.9404189193033476], 
             UndirectedEdge[16, 185] -> 
             RGBColor[
              0.4837779911654755, 0.5881187692744494, 0.9535473316443274], 
             UndirectedEdge[323, 449] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[224, 481] -> 
             RGBColor[
              0.2938275095894578, 0.4261617206915963, 0.9400444140410484], 
             UndirectedEdge[86, 476] -> 
             RGBColor[
              0.2023767546336836, 0.3300411789203187, 0.9348364288355852], 
             UndirectedEdge[66, 385] -> 
             RGBColor[
              0.22541308597049314`, 0.3542538237430719, 0.9361483138260183], 
             UndirectedEdge[184, 316] -> 
             RGBColor[
              0.9311223602384289, 0.7477274618057713, 0.3091758937857617], 
             UndirectedEdge[308, 362] -> 
             RGBColor[
              0.20539074651933456`, 0.3332090754902608, 0.9350080712146716], 
             UndirectedEdge[216, 361] -> 
             RGBColor[
              0.3394942538231242, 0.464830612431145, 0.9429866754868319], 
             UndirectedEdge[123, 410] -> 
             RGBColor[
              0.20098281054011963`, 0.3285760552968229, 0.9347570457816121], 
             UndirectedEdge[174, 225] -> 
             RGBColor[
              0.20819278575014724`, 0.33615419638139327`, 0.9351676432036207],
              UndirectedEdge[3, 139] -> 
             RGBColor[
              0.19702713929235682`, 0.3244183940113813, 0.9345317761559433], 
             UndirectedEdge[226, 472] -> 
             RGBColor[
              0.2053352778859962, 0.33315077443970764`, 0.9350049123580614], 
             UndirectedEdge[9, 441] -> 
             RGBColor[
              0.3055997605504103, 0.43303430826331607`, 0.9409162373541138], 
             UndirectedEdge[253, 354] -> 
             RGBColor[
              0.9250268564024191, 0.9410475477217897, 0.9164719893666022], 
             UndirectedEdge[47, 73] -> 
             RGBColor[
              0.7986897921704463, 0.4682405684469667, 0.4484706057487744], 
             UndirectedEdge[305, 432] -> 
             RGBColor[
              0.8165943047884041, 0.8569869432593805, 0.9822644523386079], 
             UndirectedEdge[4, 226] -> 
             RGBColor[
              0.201838009483021, 0.3294749236085569, 0.9348057480962568], 
             UndirectedEdge[112, 359] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[101, 204] -> 
             RGBColor[
              0.6853102659879131, 0.7522477509368144, 0.9707315019565851], 
             UndirectedEdge[256, 409] -> 
             RGBColor[
              0.7032931179635095, 0.7669554550610453, 0.9720223945230841], 
             UndirectedEdge[64, 268] -> 
             RGBColor[
              0.20747158720625564`, 0.3353961709851344, 0.9351265720134637], 
             UndirectedEdge[97, 395] -> 
             RGBColor[
              0.8502020870562027, 0.32426772933006165`, 0.19322676477969444`],
              UndirectedEdge[117, 156] -> 
             RGBColor[
              0.23299646235272825`, 0.36222443313463404`, 0.9365801758923864],
              UndirectedEdge[48, 117] -> 
             RGBColor[
              0.21251052131884468`, 0.34069241022434094`, 0.9354135318567407],
              UndirectedEdge[5, 103] -> 
             RGBColor[
              0.8763449551304583, 0.41955926219099576`, 0.3199825200895846], 
             UndirectedEdge[344, 438] -> 
             RGBColor[
              0.25444533400405744`, 0.38476855717718994`, 0.9378016574021677],
              UndirectedEdge[42, 381] -> 
             RGBColor[
              0.2456829942137933, 0.3755587824931918, 0.9373026551138322], 
             UndirectedEdge[224, 398] -> 
             RGBColor[
              0.29596053905936104`, 0.4284036699063442, 0.9401658869138251], 
             UndirectedEdge[226, 405] -> 
             RGBColor[
              0.202154999658272, 0.32980810038108366`, 0.9348238002177924], 
             UndirectedEdge[231, 346] -> 
             RGBColor[
              0.8725424883879621, 0.4075118710378607, 0.23895123788066785`], 
             UndirectedEdge[168, 181] -> 
             RGBColor[
              0.5838876467268811, 0.6691726907027558, 0.9623201305737528], 
             UndirectedEdge[178, 391] -> 
             RGBColor[
              0.9546302047945031, 0.8576080870133145, 0.28351307352097976`], 
             UndirectedEdge[30, 133] -> 
             RGBColor[
              0.21997865236817787`, 0.3485418894640472, 0.9358388308718903], 
             UndirectedEdge[120, 363] -> 
             RGBColor[
              0.1889703081558431, 0.31595015365430695`, 0.9340729515417323], 
             UndirectedEdge[452, 468] -> 
             RGBColor[
              0.38113300438540465`, 0.5045399849220095, 0.9455064359101233], 
             UndirectedEdge[159, 344] -> 
             RGBColor[
              0.32356779326194895`, 0.4471969980536896, 0.9421124169766175], 
             UndirectedEdge[68, 330] -> 
             RGBColor[
              0.2158728859753908, 0.3442264686646032, 0.9356050135497582], 
             UndirectedEdge[359, 440] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[180, 413] -> 
             RGBColor[
              0.5070777034000054, 0.6095492560638003, 0.9546582005878961], 
             UndirectedEdge[81, 442] -> 
             RGBColor[
              0.44817461811353243`, 0.562608061123832, 0.9497782682543083], 
             UndirectedEdge[165, 277] -> 
             RGBColor[
              0.9128792946043378, 0.9133337276812334, 0.6829052603313144], 
             UndirectedEdge[28, 310] -> 
             RGBColor[
              0.8613224849238736, 0.3683564012224616, 0.2021744979333091], 
             UndirectedEdge[71, 470] -> 
             RGBColor[
              0.2532282244104237, 0.3834892978250757, 0.9377323448113625], 
             UndirectedEdge[129, 276] -> 
             RGBColor[
              0.5454672677839978, 0.6367301066502977, 0.9595185145296392], 
             UndirectedEdge[192, 251] -> 
             RGBColor[
              0.6611025885462706, 0.7326320332459636, 0.9687519301958931], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.9735420588312775, 0.9270450247585778, 0.5414260096688857], 
             UndirectedEdge[15, 323] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[20, 473] -> 
             RGBColor[
              0.5378272732791293, 0.6356714351473729, 0.9567588795602012], 
             UndirectedEdge[336, 354] -> 
             RGBColor[
              0.8321846694563217, 0.3869954817531224, 0.4383758374637925], 
             UndirectedEdge[36, 440] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[31, 311] -> 
             RGBColor[
              0.2308573313259354, 0.3599760707967341, 0.9364583555449715], 
             UndirectedEdge[366, 405] -> 
             RGBColor[
              0.19262927042803146`, 0.31979595499398417`, 0.9342813240301839],
              UndirectedEdge[257, 374] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[194, 254] -> 
             RGBColor[
              0.22347198353028988`, 0.3522136020054152, 0.9360377709136524], 
             UndirectedEdge[284, 456] -> 
             RGBColor[
              0.2749576588362952, 0.40632831113238277`, 0.9389698039560983], 
             UndirectedEdge[30, 429] -> 
             RGBColor[
              0.20698840587743583`, 0.3348883167730792, 0.9350990555515901], 
             UndirectedEdge[182, 463] -> 
             RGBColor[
              0.8924035413977808, 0.6307547645274091, 0.4579882921332097], 
             UndirectedEdge[130, 238] -> 
             RGBColor[
              0.8848677063670416, 0.8279729997302321, 0.6258750507442762], 
             UndirectedEdge[19, 67] -> 
             RGBColor[
              0.23543376871002816`, 0.36478619665030476`, 0.9367189768837632],
              UndirectedEdge[114, 446] -> 
             RGBColor[
              0.1939761516721938, 0.321211612578802, 0.9343580269245066], 
             UndirectedEdge[164, 418] -> 
             RGBColor[
              0.9146050965365867, 0.8706968435897349, 0.6329687419964006], 
             UndirectedEdge[96, 457] -> 
             RGBColor[
              0.956033925940152, 0.8631590470414205, 0.284717153430919], 
             UndirectedEdge[285, 354] -> 
             RGBColor[
              0.5980978839946363, 0.6783452522392017, 0.9646062504878833], 
             UndirectedEdge[432, 460] -> 
             RGBColor[
              0.797979397774264, 0.8421439216944954, 0.9804889458898756], 
             UndirectedEdge[82, 249] -> 
             RGBColor[
              0.844192723800754, 0.2992353265545988, 0.18832903870459236`], 
             UndirectedEdge[176, 262] -> 
             RGBColor[
              0.9178226250506125, 0.9368943496024587, 0.9775831247382163], 
             UndirectedEdge[216, 358] -> 
             RGBColor[
              0.32697957425635543`, 0.45399102599649405`, 0.9421892511711341],
              UndirectedEdge[54, 374] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[214, 491] -> 
             RGBColor[
              0.20330311497053621`, 0.3310148423689886, 0.9348891836863416], 
             UndirectedEdge[68, 357] -> 
             RGBColor[
              0.2136408209972711, 0.34188042685150594`, 0.9354779007512986], 
             UndirectedEdge[260, 328] -> 
             RGBColor[
              0.3945437578035354, 0.5155112922725004, 0.9465390105509373], 
             UndirectedEdge[224, 286] -> 
             RGBColor[
              0.2553337614325445, 0.3857023507340823, 0.9378522520299093], 
             UndirectedEdge[219, 293] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[209, 404] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[197, 289] -> 
             RGBColor[
              0.3635203797565897, 0.48928481470478324`, 0.9443841750430078], 
             UndirectedEdge[227, 424] -> 
             RGBColor[
              0.24090488888578881`, 0.3705366908440838, 0.9370305490839757], 
             UndirectedEdge[458, 461] -> 
             RGBColor[
              0.4970083451514102, 0.6025092639396462, 0.9535519644503695], 
             UndirectedEdge[292, 464] -> 
             RGBColor[
              0.24293630539384, 0.37267183839329127`, 0.9371462352488977], 
             UndirectedEdge[386, 441] -> 
             RGBColor[
              0.605869176422092, 0.6857097720212253, 0.9648098337879067], 
             UndirectedEdge[257, 343] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[132, 457] -> 
             RGBColor[
              0.80832544399098, 0.8000236768742133, 0.6266376808278413], 
             UndirectedEdge[69, 259] -> 
             RGBColor[
              0.8720195914369621, 0.405748016840095, 0.23691988196683633`], 
             UndirectedEdge[68, 95] -> 
             RGBColor[
              0.20531946953055227`, 0.3331341588558284, 0.9350040120956051], 
             UndirectedEdge[247, 278] -> 
             RGBColor[
              0.20238002081431636`, 0.33004461188325157`, 0.9348366148397402],
              UndirectedEdge[293, 440] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[307, 442] -> 
             RGBColor[
              0.34067507112051615`, 0.4626107234152569, 0.9431806455540332], 
             UndirectedEdge[406, 493] -> 
             RGBColor[
              0.7916429672985688, 0.8334067531326425, 0.7659846388427745], 
             UndirectedEdge[155, 479] -> 
             RGBColor[
              0.2185280104329565, 0.3470171728141185, 0.935756218959712], 
             UndirectedEdge[311, 488] -> 
             RGBColor[
              0.21049948038445382`, 0.3385786786949364, 0.9352990060505957], 
             UndirectedEdge[226, 345] -> 
             RGBColor[
              0.22193035948375894`, 0.35059325738790115`, 0.9359499777048308],
              UndirectedEdge[183, 273] -> 
             RGBColor[
              0.23550505714349235`, 0.3648611253138234, 0.9367230366545871], 
             UndirectedEdge[384, 499] -> 
             RGBColor[
              0.756352573168234, 0.3274478448111356, 0.4309329969189558], 
             UndirectedEdge[20, 325] -> 
             RGBColor[
              0.44797720589084944`, 0.562001963139723, 0.949885911356462], 
             UndirectedEdge[252, 424] -> 
             RGBColor[
              0.21753234437929125`, 0.3459706646628423, 0.9356995172509117], 
             UndirectedEdge[285, 473] -> 
             RGBColor[
              0.4702957798183204, 0.5776141591822213, 0.9523356104782151], 
             UndirectedEdge[71, 236] -> 
             RGBColor[
              0.2828326524801393, 0.4146054287554984, 0.9394182731941062], 
             UndirectedEdge[2, 446] -> 
             RGBColor[
              0.19992087707942807`, 0.32745989589916574`, 0.9346965702420156],
              UndirectedEdge[33, 351] -> 
             RGBColor[
              0.5099468577737633, 0.6130368578417116, 0.9545640311222917], 
             UndirectedEdge[172, 466] -> 
             RGBColor[
              0.31281244439264955`, 0.4397173887710188, 0.9413598658215745], 
             UndirectedEdge[12, 279] -> 
             RGBColor[
              0.2740454754738125, 0.40536954858264795`, 0.9389178564630594], 
             UndirectedEdge[171, 219] -> 
             RGBColor[
              0.8633448747725185, 0.37637450305087206`, 0.2038017602771198], 
             UndirectedEdge[153, 223] -> 
             RGBColor[
              0.3513959068247321, 0.4784326496880068, 0.9436244499198642], 
             UndirectedEdge[121, 489] -> 
             RGBColor[
              0.2627068012405983, 0.39345188305007095`, 0.9382721357395432], 
             UndirectedEdge[362, 470] -> 
             RGBColor[
              0.21338003115164933`, 0.3416063201887262, 0.9354630491553944], 
             UndirectedEdge[168, 232] -> 
             RGBColor[
              0.7381047575552699, 0.7953323134968859, 0.9745310423181337], 
             UndirectedEdge[285, 409] -> 
             RGBColor[
              0.437803206966903, 0.5512352247677147, 0.9497776761191354], 
             UndirectedEdge[159, 439] -> 
             RGBColor[
              0.3428534925670518, 0.4674674908073133, 0.9432107090214077], 
             UndirectedEdge[156, 263] -> 
             RGBColor[
              0.3245522054854192, 0.45168136141230764`, 0.9420421679776179], 
             UndirectedEdge[149, 314] -> 
             RGBColor[
              0.7707695331053225, 0.5139697191710294, 0.454417376319948], 
             UndirectedEdge[110, 457] -> 
             RGBColor[
              0.9752798562916284, 0.9274780602051496, 0.4262581835303463], 
             UndirectedEdge[43, 263] -> 
             RGBColor[
              0.3916792939201136, 0.5136746508450498, 0.9461784361535572], 
             UndirectedEdge[141, 160] -> 
             RGBColor[
              0.37802184945379874`, 0.5011040622114881, 0.9453453778817297], 
             UndirectedEdge[345, 389] -> 
             RGBColor[
              0.23903484731409955`, 0.3685711585847546, 0.9369240529829466], 
             UndirectedEdge[225, 247] -> 
             RGBColor[
              0.2013053783371785, 0.3289150945035113, 0.9347754155404584], 
             UndirectedEdge[171, 293] -> 
             RGBColor[
              0.8633448747725185, 0.37637450305087206`, 0.2038017602771198], 
             UndirectedEdge[179, 415] -> 
             RGBColor[
              0.22772487631702723`, 0.35668366197325296`, 0.936279966866266], 
             UndirectedEdge[143, 414] -> 
             RGBColor[
              0.8892351625821182, 0.5206084458054662, 0.2940261166931848], 
             UndirectedEdge[77, 388] -> 
             RGBColor[
              0.9318009699728012, 0.9483644297913851, 0.9901540914937574], 
             UndirectedEdge[305, 406] -> 
             RGBColor[
              0.9278221085492989, 0.9409395276057798, 0.778913799948221], 
             UndirectedEdge[55, 256] -> 
             RGBColor[
              0.8509498633138987, 0.5235549531780195, 0.45538444278936224`], 
             UndirectedEdge[367, 450] -> 
             RGBColor[
              0.29858171762156427`, 0.42829285152586705`, 0.9404200917150141],
              UndirectedEdge[171, 258] -> 
             RGBColor[
              0.9746741511548784, 0.925170542447061, 0.43301247003911714`], 
             UndirectedEdge[366, 423] -> 
             RGBColor[
              0.18733252995215482`, 0.31422874492109487`, 0.9339796824959081],
              UndirectedEdge[309, 393] -> 
             RGBColor[
              0.2931834633072552, 0.42005128345340215`, 0.9402066837474136], 
             UndirectedEdge[324, 360] -> 
             RGBColor[
              0.8191009627097754, 0.1478239462483719, 0.1659244095033199], 
             UndirectedEdge[125, 310] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[33, 463] -> 
             RGBColor[
              0.7610323559034178, 0.5268877243816464, 0.4568621548257559], 
             UndirectedEdge[137, 280] -> 
             RGBColor[
              0.43200376365867066`, 0.5461711365359171, 0.9494194420439965], 
             UndirectedEdge[72, 179] -> 
             RGBColor[
              0.2943835934590824, 0.4258364649270654, 0.9401093920557657], 
             UndirectedEdge[17, 165] -> 
             RGBColor[
              0.916100851915751, 0.9340601351245527, 0.9212631098697036], 
             UndirectedEdge[402, 417] -> 
             RGBColor[
              0.30478452951240814`, 0.43365806607358726`, 0.9408155984994631],
              UndirectedEdge[102, 225] -> 
             RGBColor[
              0.23396295286916968`, 0.3632402759464521, 0.9366352160975032], 
             UndirectedEdge[83, 231] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[194, 377] -> 
             RGBColor[
              0.19840694520434524`, 0.3258686575096288, 0.934610354061391], 
             UndirectedEdge[131, 495] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[213, 447] -> 
             RGBColor[
              0.3531568288188625, 0.47758139806423716`, 0.9438236686575876], 
             UndirectedEdge[146, 166] -> 
             RGBColor[
              0.217481006477988, 0.34591670527356166`, 0.9356965936333801], 
             UndirectedEdge[422, 428] -> 
             RGBColor[
              0.25745308354951085`, 0.3879298926517971, 0.9379729442892144], 
             UndirectedEdge[232, 338] -> 
             RGBColor[
              0.8446486517517946, 0.8751856702040267, 0.7354620195671999], 
             UndirectedEdge[366, 469] -> 
             RGBColor[
              0.19196874935401928`, 0.31910170546574246`, 0.9342437083321722],
              UndirectedEdge[245, 482] -> 
             RGBColor[
              0.7095963897113673, 0.7715447220093258, 0.9726142668719193], 
             UndirectedEdge[40, 243] -> 
             RGBColor[
              0.23004423631559218`, 0.35912145638766224`, 0.9364120509869986],
              UndirectedEdge[174, 320] -> 
             RGBColor[
              0.20210480252735952`, 0.3297553400138127, 0.934820941565447], 
             UndirectedEdge[30, 31] -> 
             RGBColor[
              0.20705706276398889`, 0.3349604795139445, 0.9351029654597106], 
             UndirectedEdge[77, 354] -> 
             RGBColor[
              0.9005988329718047, 0.9234846927062367, 0.9871780038121258], 
             UndirectedEdge[24, 223] -> 
             RGBColor[
              0.255646740576453, 0.38603131165835397`, 0.9378700757291438], 
             UndirectedEdge[261, 391] -> 
             RGBColor[
              0.9394746993421814, 0.8968570148384152, 0.6367582455569412], 
             UndirectedEdge[125, 323] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[1, 364] -> 
             RGBColor[
              0.27760199236929234`, 0.4091076733359924, 0.9391203948388616], 
             UndirectedEdge[88, 133] -> 
             RGBColor[
              0.24286224712593307`, 0.37259399845815566`, 0.9371420177400999],
              UndirectedEdge[178, 407] -> 
             RGBColor[
              0.8224905366554676, 0.8110267669512574, 0.6279578355331397], 
             UndirectedEdge[103, 486] -> 
             RGBColor[
              0.9942507028356309, 0.9901111596455525, 0.6156026680867737], 
             UndirectedEdge[204, 486] -> 
             RGBColor[
              0.9371733075375102, 0.9485718429489449, 0.7940666224358858], 
             UndirectedEdge[89, 407] -> 
             RGBColor[
              0.7735280589501026, 0.8233189327675969, 0.9779784683757653], 
             UndirectedEdge[38, 301] -> 
             RGBColor[
              0.8446459694565934, 0.30129340921955317`, 0.18870723798989242`],
              UndirectedEdge[92, 132] -> 
             RGBColor[
              0.6587795986186888, 0.7333628964420915, 0.9666246518110923], 
             UndirectedEdge[8, 146] -> 
             RGBColor[
              0.22136813052518187`, 0.35000231910506174`, 0.935917959597383], 
             UndirectedEdge[44, 110] -> 
             RGBColor[
              0.8465724459995572, 0.877096423635668, 0.7683221349761459], 
             UndirectedEdge[102, 252] -> 
             RGBColor[
              0.2303914914496485, 0.3594864435508025, 0.9364318266531653], 
             UndirectedEdge[273, 283] -> 
             RGBColor[
              0.2039582574481488, 0.3317034386513916, 0.9349264930812451], 
             UndirectedEdge[158, 428] -> 
             RGBColor[
              0.2255068530817244, 0.3543523789221541, 0.9361536537242868], 
             UndirectedEdge[176, 328] -> 
             RGBColor[
              0.6804227732338226, 0.7482541598759991, 0.9703763257599396], 
             UndirectedEdge[45, 398] -> 
             RGBColor[
              0.28571521753888074`, 0.4176351873974164, 0.9395824310098286], 
             UndirectedEdge[233, 275] -> 
             RGBColor[
              0.8560290549644465, 0.34736971536429956`, 0.19791527993518332`],
              UndirectedEdge[250, 485] -> 
             RGBColor[
              0.45702605481315906`, 0.567525512507305, 0.9511018911536404], 
             UndirectedEdge[29, 65] -> 
             RGBColor[
              0.19993601783128978`, 0.32747580978935154`, 0.9346974324854354],
              UndirectedEdge[166, 453] -> 
             RGBColor[
              0.35449001734482477`, 0.47600931341249325`, 0.9440381627421772],
              UndirectedEdge[222, 294] -> 
             RGBColor[
              0.23651889122655595`, 0.36592672921591685`, 0.9367807730057844],
              UndirectedEdge[150, 220] -> 
             RGBColor[
              0.34295836521931666`, 0.47147503118949763`, 0.9430739816589682],
              UndirectedEdge[311, 423] -> 
             RGBColor[
              0.20333007809631276`, 0.3310431823237406, 0.9348907191964662], 
             UndirectedEdge[210, 424] -> 
             RGBColor[
              0.24599797700123366`, 0.37588984937385383`, 0.9373205929176016],
              UndirectedEdge[179, 312] -> 
             RGBColor[
              0.25910450378636, 0.3896656400268162, 0.9380669902286457], 
             UndirectedEdge[310, 323] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[108, 349] -> 
             RGBColor[
              0.25865268956964965`, 0.3889473848332744, 0.9380501710381446], 
             UndirectedEdge[355, 395] -> 
             RGBColor[
              0.8765177108418302, 0.526541145326267, 0.2184266358360574], 
             UndirectedEdge[47, 200] -> 
             RGBColor[
              0.6585502468348285, 0.7325721031757053, 0.967019961408724], 
             UndirectedEdge[152, 217] -> 
             RGBColor[
              0.19534686563322098`, 0.3226523198601263, 0.9344360870567976], 
             UndirectedEdge[174, 210] -> 
             RGBColor[
              0.23308695695256842`, 0.3623195486967552, 0.9365853294259726], 
             UndirectedEdge[135, 211] -> 
             RGBColor[
              0.19965674481685908`, 0.3271822761442531, 0.9346815283004108], 
             UndirectedEdge[52, 491] -> 
             RGBColor[
              0.18704172107166453`, 0.3139230863493516, 0.9339631213603773], 
             UndirectedEdge[41, 250] -> 
             RGBColor[
              0.4813094096913133, 0.5872398339500613, 0.9530135658025085], 
             UndirectedEdge[220, 392] -> 
             RGBColor[
              0.39450251795097435`, 0.5161199856012157, 0.9463583294923248], 
             UndirectedEdge[182, 359] -> 
             RGBColor[
              0.8630442272815448, 0.41127892958154133`, 0.4301162711119909], 
             UndirectedEdge[89, 391] -> 
             RGBColor[
              0.9056677270891382, 0.8699002528296541, 0.6335337063636055], 
             UndirectedEdge[62, 190] -> 
             RGBColor[
              0.4365755592180457, 0.5505194134500824, 0.9496034319333838], 
             UndirectedEdge[21, 87] -> 
             RGBColor[
              0.8381407688879172, 0.873774714658863, 0.9844238088252685], 
             UndirectedEdge[185, 286] -> 
             RGBColor[
              0.26801510124259026`, 0.39793308049680753`, 0.9386146446774454],
              UndirectedEdge[114, 294] -> 
             RGBColor[
              0.2027740482369167, 0.3304587596871861, 0.934859054118546], 
             UndirectedEdge[48, 156] -> 
             RGBColor[
              0.2466062489720914, 0.37652918178189576`, 0.9373552331064843], 
             UndirectedEdge[68, 450] -> 
             RGBColor[
              0.27333525861175023`, 0.40175722238859823`, 0.9389823432231943],
              UndirectedEdge[149, 406] -> 
             RGBColor[
              0.9015895992703974, 0.6146262111363756, 0.3242123165327152], 
             UndirectedEdge[123, 158] -> 
             RGBColor[
              0.22135534676052232`, 0.3499888825578671, 0.9359172315808977], 
             UndirectedEdge[55, 91] -> 
             RGBColor[
              0.8839292021421377, 0.5220528575630985, 0.23151925387136146`], 
             UndirectedEdge[135, 169] -> 
             RGBColor[
              0.19175100981754287`, 0.3188728474074218, 0.9342313083876868], 
             UndirectedEdge[141, 456] -> 
             RGBColor[
              0.2759889604791371, 0.40741227454731044`, 0.9390285350589842], 
             UndirectedEdge[287, 354] -> 
             RGBColor[
              0.8499252860376748, 0.8831713687518833, 0.985547826591175], 
             UndirectedEdge[223, 411] -> 
             RGBColor[
              0.5086318602725991, 0.6065187599425428, 0.9563190333306388], 
             UndirectedEdge[127, 301] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[167, 201] -> 
             RGBColor[
              0.5126223254450143, 0.6152089230256782, 0.9547746537379336], 
             UndirectedEdge[28, 218] -> 
             RGBColor[
              0.8445734030785657, 0.8167427042403248, 0.62639461573298], 
             UndirectedEdge[112, 317] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[275, 372] -> 
             RGBColor[
              0.8560290549644465, 0.3473697153642996, 0.19791527993518332`], 
             UndirectedEdge[85, 146] -> 
             RGBColor[
              0.199363430421074, 0.32687398411707613`, 0.9346648244794907], 
             UndirectedEdge[7, 262] -> 
             RGBColor[
              0.9526458055609902, 0.9083629362681058, 0.6238917173700477], 
             UndirectedEdge[448, 455] -> 
             RGBColor[
              0.8196221020524992, 0.3769784315071223, 0.4371776085700797], 
             UndirectedEdge[9, 368] -> 
             RGBColor[
              0.21159898242802877`, 0.3397343250551897, 0.9353616210654097], 
             UndirectedEdge[216, 399] -> 
             RGBColor[
              0.28648541136230066`, 0.41844470993893956`, 0.9396262924086728],
              UndirectedEdge[205, 474] -> 
             RGBColor[
              0.4259491436308685, 0.5433574722117767, 0.9483620806734884], 
             UndirectedEdge[125, 242] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[280, 338] -> 
             RGBColor[
              0.768013484678197, 0.8137930844785333, 0.728866127012082], 
             UndirectedEdge[232, 393] -> 
             RGBColor[
              0.5318086908857713, 0.627632203960369, 0.9574916912278812], 
             UndirectedEdge[403, 483] -> 
             RGBColor[
              0.8686864922225178, 0.39450469054086185`, 0.22397142092169176`],
              UndirectedEdge[427, 433] -> 
             RGBColor[
              0.19902919731618948`, 0.32652268393223965`, 0.9346457903986212],
              UndirectedEdge[269, 310] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[212, 357] -> 
             RGBColor[
              0.2061419579423609, 0.3339986463254166, 0.9350508515938951], 
             UndirectedEdge[88, 307] -> 
             RGBColor[
              0.2294926966396743, 0.3585417532186373, 0.9363806416183849], 
             UndirectedEdge[212, 217] -> 
             RGBColor[
              0.1904154630441735, 0.3174691030700544, 0.9341552509747078], 
             UndirectedEdge[67, 124] -> 
             RGBColor[
              0.19699158310389825`, 0.32438102220291876`, 0.9345297512836113],
              UndirectedEdge[364, 380] -> 
             RGBColor[
              0.2521693231018657, 0.3823763254115605, 0.9376720419483442], 
             UndirectedEdge[82, 384] -> 
             RGBColor[
              0.7661799454534821, 0.6717707570486016, 0.6004570534353222], 
             UndirectedEdge[222, 439] -> 
             RGBColor[
              0.26180020973842244`, 0.3924989979000629, 0.938220506694676], 
             UndirectedEdge[337, 420] -> 
             RGBColor[
              0.2204438807365078, 0.34903087397634414`, 0.935865324939223], 
             UndirectedEdge[61, 99] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[63, 439] -> 
             RGBColor[
              0.2827106908529987, 0.41447723935255987`, 0.9394113276598666], 
             UndirectedEdge[37, 53] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[39, 62] -> 
             RGBColor[
              0.5172304874360417, 0.6189500365253262, 0.9551374251301208], 
             UndirectedEdge[130, 182] -> 
             RGBColor[
              0.8938442105767532, 0.9177064381503486, 0.9729323850318632], 
             UndirectedEdge[152, 398] -> 
             RGBColor[
              0.24922661523815437`, 0.3792833528683451, 0.9375044590888519], 
             UndirectedEdge[23, 110] -> 
             RGBColor[
              0.993178965010662, 0.9878188208072598, 0.4989506198380761], 
             UndirectedEdge[322, 440] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[141, 432] -> 
             RGBColor[
              0.5362845883584992, 0.627612344125192, 0.9591557710589778], 
             UndirectedEdge[161, 459] -> 
             RGBColor[
              0.2888122033466731, 0.4187677847094263, 0.9398365160322288], 
             UndirectedEdge[185, 333] -> 
             RGBColor[
              0.3691868534914339, 0.4941928294486542, 0.944745237738726], 
             UndirectedEdge[297, 474] -> 
             RGBColor[
              0.3280652758488244, 0.45307847721715644`, 0.9423262759214741], 
             UndirectedEdge[265, 329] -> 
             RGBColor[
              0.19625946576950848`, 0.3236115204655551, 0.9344880582844883], 
             UndirectedEdge[90, 280] -> 
             RGBColor[
              0.5706742857728803, 0.6623381196308499, 0.9593447167062806], 
             UndirectedEdge[183, 430] -> 
             RGBColor[
              0.26651354621858253`, 0.39745301338350436`, 0.9384889242344647],
              UndirectedEdge[86, 194] -> 
             RGBColor[
              0.20814234732009446`, 0.3361011823934266, 0.9351647708096462], 
             UndirectedEdge[143, 186] -> 
             RGBColor[
              0.8305642118064, 0.2359355020328133, 0.17690162978413582`], 
             UndirectedEdge[1, 416] -> 
             RGBColor[
              0.288059981339665, 0.42002691875059733`, 0.9397186260884912], 
             UndirectedEdge[27, 86] -> 
             RGBColor[
              0.20621369612965204`, 0.3340740477087234, 0.9350549369775343], 
             UndirectedEdge[66, 415] -> 
             RGBColor[
              0.22292255775669778`, 0.3516361206817638, 0.9360064819286489], 
             UndirectedEdge[413, 490] -> 
             RGBColor[
              0.37625940773370514`, 0.5003187204563975, 0.9451958946410293], 
             UndirectedEdge[226, 284] -> 
             RGBColor[
              0.25636693278706735`, 0.38678827933453314`, 0.9379110896101094],
              UndirectedEdge[245, 438] -> 
             RGBColor[
              0.3820090099045602, 0.5019364048104593, 0.9458781446689446], 
             UndirectedEdge[53, 163] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[367, 368] -> 
             RGBColor[
              0.2188305697178644, 0.3473351818059234, 0.9357734492633911], 
             UndirectedEdge[112, 175] -> 
             RGBColor[
              0.8764817671983398, 0.42012490000344926`, 0.35471866035020744`],
              UndirectedEdge[277, 288] -> 
             RGBColor[
              0.8718851812720558, 0.40529461979285863`, 0.23639772385740537`],
              UndirectedEdge[249, 323] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[416, 452] -> 
             RGBColor[
              0.3516972330284187, 0.47904419925747455`, 0.9436308145882868], 
             UndirectedEdge[13, 87] -> 
             RGBColor[
              0.6969015731746537, 0.761845924926386, 0.9714278248071031], 
             UndirectedEdge[471, 497] -> 
             RGBColor[
              0.8604026869949277, 0.3647097089386806, 0.20143440692924686`], 
             UndirectedEdge[17, 321] -> 
             RGBColor[
              0.8740328861463312, 0.4191122247550715, 0.39530295688299816`], 
             UndirectedEdge[106, 227] -> 
             RGBColor[
              0.21113051364042446`, 0.3392419346567809, 0.9353349424609931], 
             UndirectedEdge[37, 100] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[9, 375] -> 
             RGBColor[
              0.26223546161822137`, 0.3929564752222947, 0.9382452936453332], 
             UndirectedEdge[10, 302] -> 
             RGBColor[
              0.44096969519954776`, 0.5554209075051166, 0.9495807285208586], 
             UndirectedEdge[14, 272] -> 
             RGBColor[
              0.49012417246760553`, 0.5958729134320023, 0.9532994359632572], 
             UndirectedEdge[63, 387] -> 
             RGBColor[
              0.26044194173333185`, 0.39107137210754717`, 0.9381431553411637],
              UndirectedEdge[471, 483] -> 
             RGBColor[
              0.8686864922225178, 0.39450469054086185`, 0.22397142092169176`],
              UndirectedEdge[46, 392] -> 
             RGBColor[
              0.3638578099509795, 0.48744458852803013`, 0.9444837567475968], 
             UndirectedEdge[122, 357] -> 
             RGBColor[
              0.21418150641244568`, 0.34244872150428973`, 0.9355086919858204],
              UndirectedEdge[75, 125] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[244, 261] -> 
             RGBColor[
              0.9518089599069877, 0.9394744537489581, 0.6794087875044705], 
             UndirectedEdge[7, 178] -> 
             RGBColor[
              0.9550785853817441, 0.8593857666277512, 0.2838738510663188], 
             UndirectedEdge[108, 487] -> 
             RGBColor[
              0.27490256852659056`, 0.40602703791885253`, 0.9389755776052008],
              UndirectedEdge[338, 480] -> 
             RGBColor[
              0.736297626172224, 0.7880447217602409, 0.726369338451474], 
             UndirectedEdge[237, 284] -> 
             RGBColor[
              0.3610780260831915, 0.4862793732675318, 0.9442611375927252], 
             UndirectedEdge[162, 456] -> 
             RGBColor[
              0.22433567464264714`, 0.35312139612568205`, 0.9360869568447846],
              UndirectedEdge[104, 310] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[168, 390] -> 
             RGBColor[
              0.6691221372064833, 0.7401524099458952, 0.9685375862733951], 
             UndirectedEdge[164, 431] -> 
             RGBColor[
              0.9370561323224353, 0.9480386859797506, 0.7584099422192706], 
             UndirectedEdge[57, 60] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[158, 247] -> 
             RGBColor[
              0.2179800536352555, 0.34644123547726713`, 0.9357250136307124], 
             UndirectedEdge[32, 475] -> 
             RGBColor[
              0.6509446795635007, 0.7211864568708418, 0.9633804842819546], 
             UndirectedEdge[53, 293] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[72, 294] -> 
             RGBColor[
              0.2672032018912745, 0.39726815005293875`, 0.938561508965765], 
             UndirectedEdge[87, 287] -> 
             RGBColor[
              0.8461097317603583, 0.8801289493416129, 0.985183895618019], 
             UndirectedEdge[154, 374] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[119, 364] -> 
             RGBColor[
              0.24538499784001913`, 0.3752455694102938, 0.9372856846611919], 
             UndirectedEdge[90, 342] -> 
             RGBColor[
              0.7736445823202994, 0.759776227926813, 0.6195883744105202], 
             UndirectedEdge[401, 428] -> 
             RGBColor[
              0.20185876447098355`, 0.3294967384168478, 0.9348069300621171], 
             UndirectedEdge[183, 477] -> 
             RGBColor[
              0.2584102041277772, 0.38893588706450477`, 0.9380274508902138], 
             UndirectedEdge[82, 269] -> 
             RGBColor[
              0.844192723800754, 0.2992353265545988, 0.18832903870459236`], 
             UndirectedEdge[202, 273] -> 
             RGBColor[
              0.21352690809729225`, 0.3417606971711331, 0.9354714135801638], 
             UndirectedEdge[147, 242] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[117, 198] -> 
             RGBColor[
              0.19641879440682608`, 0.3237789849653949, 0.9344971318146779], 
             UndirectedEdge[240, 434] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[249, 310] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[448, 478] -> 
             RGBColor[
              0.6704836405873918, 0.7406161495613826, 0.969097778591143], 
             UndirectedEdge[121, 196] -> 
             RGBColor[
              0.263514639936199, 0.3943009727390789, 0.9383181409581673], 
             UndirectedEdge[200, 256] -> 
             RGBColor[
              0.7338460782820668, 0.7917597246428272, 0.9744276354785424], 
             UndirectedEdge[79, 184] -> 
             RGBColor[
              0.8369837657282427, 0.2665011316422593, 0.18231370738115665`], 
             UndirectedEdge[51, 240] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[339, 387] -> 
             RGBColor[
              0.20309854147984135`, 0.33079982265955976`, 0.9348775335286859],
              UndirectedEdge[46, 142] -> 
             RGBColor[
              0.31315836829751326`, 0.4435312803958282, 0.9412532331571938], 
             UndirectedEdge[233, 259] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[266, 471] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[167, 456] -> 
             RGBColor[
              0.3541276585075292, 0.4756789204371697, 0.9440129329276471], 
             UndirectedEdge[10, 181] -> 
             RGBColor[
              0.3907137841542735, 0.512838374813811, 0.9461169147250448], 
             UndirectedEdge[31, 429] -> 
             RGBColor[
              0.23508841614603562`, 0.36442320920893145`, 0.9366993095661471],
              UndirectedEdge[317, 322] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[52, 466] -> 
             RGBColor[
              0.21559918239939563`, 0.34393878885242324`, 0.9355894265360134],
              UndirectedEdge[207, 281] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[358, 398] -> 
             RGBColor[
              0.3406430519430609, 0.4683522073597428, 0.9429673660120881], 
             UndirectedEdge[155, 250] -> 
             RGBColor[
              0.3015021013571373, 0.4295372658275264, 0.9406532288863496], 
             UndirectedEdge[243, 285] -> 
             RGBColor[
              0.2946220530898087, 0.4246360657495467, 0.9401761014918839], 
             UndirectedEdge[378, 452] -> 
             RGBColor[
              0.34677922286557283`, 0.4739478228245242, 0.9433480769360816], 
             UndirectedEdge[100, 264] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[81, 130] -> 
             RGBColor[
              0.6412269922816769, 0.7166892321720943, 0.9668997000917505], 
             UndirectedEdge[1, 120] -> 
             RGBColor[
              0.22486057335320775`, 0.3536730979509817, 0.9361168490498329], 
             UndirectedEdge[390, 422] -> 
             RGBColor[
              0.42800433190778703`, 0.5412859490450508, 0.9493162414930003], 
             UndirectedEdge[118, 255] -> 
             RGBColor[
              0.24682926108047093`, 0.37676358164758694`, 0.9373679333161395],
              UndirectedEdge[137, 229] -> 
             RGBColor[
              0.3767837963714482, 0.5007729195378712, 0.9452293082213277], 
             UndirectedEdge[367, 375] -> 
             RGBColor[
              0.269467048908057, 0.40055733197302834`, 0.9386571218433146], 
             UndirectedEdge[230, 382] -> 
             RGBColor[
              0.3091332042875092, 0.4409162668033755, 0.940964847732868], 
             UndirectedEdge[114, 334] -> 
             RGBColor[
              0.20140242887172854`, 0.3290171007686827, 0.9347809424248276], 
             UndirectedEdge[52, 170] -> 
             RGBColor[
              0.2001972733204281, 0.32775040587299065`, 0.9347123105990489], 
             UndirectedEdge[4, 389] -> 
             RGBColor[
              0.2189424973133616, 0.34745282480541034`, 0.9357798233743726], 
             UndirectedEdge[190, 378] -> 
             RGBColor[
              0.3221600885821226, 0.4526239661018675, 0.9417793674693858], 
             UndirectedEdge[89, 328] -> 
             RGBColor[
              0.6679213978740371, 0.7382859025049004, 0.9691839334180138], 
             UndirectedEdge[93, 300] -> 
             RGBColor[
              0.3959649652472733, 0.5173866839445316, 0.9464515153408535], 
             UndirectedEdge[104, 125] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[59, 228] -> 
             RGBColor[
              0.5875720741130268, 0.6760565054420705, 0.9606749725030552], 
             UndirectedEdge[96, 136] -> 
             RGBColor[
              0.9223928943750033, 0.7257736795999382, 0.2561940101384317], 
             UndirectedEdge[332, 420] -> 
             RGBColor[
              0.21514942465501302`, 0.3434660649467891, 0.9355638134978279], 
             UndirectedEdge[40, 283] -> 
             RGBColor[
              0.1993276791914918, 0.3268364073080263, 0.9346627884998552], 
             UndirectedEdge[17, 288] -> 
             RGBColor[
              0.8740328861463312, 0.4191122247550715, 0.39530295688299816`], 
             UndirectedEdge[325, 413] -> 
             RGBColor[
              0.4186353116598318, 0.5370225985623481, 0.9478960497676616], 
             UndirectedEdge[421, 459] -> 
             RGBColor[
              0.22407540206524434`, 0.35284783314459717`, 0.9360721347065403],
              UndirectedEdge[148, 342] -> 
             RGBColor[
              0.8111690714652371, 0.789762270075679, 0.6228692704159253], 
             UndirectedEdge[262, 478] -> 
             RGBColor[
              0.7342949612963621, 0.7910810503283867, 0.9607433486647203], 
             UndirectedEdge[133, 405] -> 
             RGBColor[
              0.22584814988303165`, 0.3547111034997951, 0.9361730900722178], 
             UndirectedEdge[374, 397] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[151, 389] -> 
             RGBColor[
              0.26675818843298676`, 0.3977101478620555, 0.9385028562466593], 
             UndirectedEdge[235, 305] -> 
             RGBColor[
              0.6045891554467802, 0.6839715876022671, 0.9650180629183508], 
             UndirectedEdge[204, 348] -> 
             RGBColor[
              0.9214887091320801, 0.896652428961333, 0.6490868722471982], 
             UndirectedEdge[191, 429] -> 
             RGBColor[
              0.23210680778710222`, 0.3612893497788038, 0.9365295113810002], 
             UndirectedEdge[15, 414] -> 
             RGBColor[
              0.8759899507757182, 0.41879994377265284`, 0.28134248690904895`],
              UndirectedEdge[277, 414] -> 
             RGBColor[
              0.987174698071661, 0.9678878453482673, 0.4481743161496815], 
             UndirectedEdge[317, 440] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[76, 182] -> 
             RGBColor[
              0.9744199384876636, 0.9779480289273386, 0.7939001923006881], 
             UndirectedEdge[199, 376] -> 
             RGBColor[
              0.9885107908455275, 0.9895169310024878, 0.8400694590171756], 
             UndirectedEdge[375, 402] -> 
             RGBColor[
              0.3168704423564799, 0.4463611267638398, 0.9415038733564272], 
             UndirectedEdge[45, 195] -> 
             RGBColor[
              0.2465939110217282, 0.3765162138137928, 0.9373545304784634], 
             UndirectedEdge[149, 269] -> 
             RGBColor[
              0.8427485102135918, 0.3295893587840956, 0.1885693276990594], 
             UndirectedEdge[45, 152] -> 
             RGBColor[
              0.23828164417604697`, 0.36777949433082413`, 0.9368811591784987],
              UndirectedEdge[356, 494] -> 
             RGBColor[
              0.7305244527406208, 0.7874409705960981, 0.9449166497009711], 
             UndirectedEdge[44, 360] -> 
             RGBColor[
              0.7815599699638192, 0.37183086141094573`, 0.43644760020267126`],
              UndirectedEdge[284, 432] -> 
             RGBColor[
              0.5352532867156573, 0.6265283807102642, 0.9590970399560919], 
             UndirectedEdge[151, 237] -> 
             RGBColor[
              0.3543647938987703, 0.4792233405982007, 0.9438788289511594], 
             UndirectedEdge[207, 343] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[33, 371] -> 
             RGBColor[
              0.5535152767239239, 0.6484076630803585, 0.9579938966584256], 
             UndirectedEdge[280, 480] -> 
             RGBColor[
              0.5111171823615002, 0.6139869800645582, 0.9546561633608786], 
             UndirectedEdge[420, 454] -> 
             RGBColor[
              0.2690558886350951, 0.39909292378057587`, 0.9386715027011281], 
             UndirectedEdge[267, 393] -> 
             RGBColor[
              0.3865607689237344, 0.5092412417577328, 0.9458522882669219], 
             UndirectedEdge[337, 427] -> 
             RGBColor[
              0.21714766115220907`, 0.3455663382008537, 0.9356776101102171], 
             UndirectedEdge[267, 480] -> 
             RGBColor[
              0.44250442747306074`, 0.5569886035874154, 0.9496126529550372], 
             UndirectedEdge[234, 336] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[122, 492] -> 
             RGBColor[
              0.2013976738739365, 0.329012102964519, 0.9347806716347378], 
             UndirectedEdge[80, 272] -> 
             RGBColor[
              0.7621819360908365, 0.8135182343885552, 0.9575015284128756], 
             UndirectedEdge[331, 444] -> 
             RGBColor[
              0.8431854304737648, 0.5505961353798073, 0.458803149462244], 
             UndirectedEdge[77, 184] -> 
             RGBColor[
              0.9077974773796862, 0.7427431675399421, 0.6030848086881719], 
             UndirectedEdge[266, 359] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[32, 478] -> 
             RGBColor[
              0.43818467591766874`, 0.5522332471390261, 0.9496175194838028], 
             UndirectedEdge[14, 447] -> 
             RGBColor[
              0.4204684417421174, 0.5386103637038271, 0.9480128551955316], 
             UndirectedEdge[16, 358] -> 
             RGBColor[
              0.5157791642391296, 0.6158365769651228, 0.9555864180950544], 
             UndirectedEdge[50, 323] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[92, 365] -> 
             RGBColor[
              0.4788564599632421, 0.5825948499682702, 0.9534562846389698], 
             UndirectedEdge[296, 438] -> 
             RGBColor[
              0.23711501443590766`, 0.3665532925053399, 0.9368147213406718], 
             UndirectedEdge[181, 422] -> 
             RGBColor[
              0.34276984142818484`, 0.4703062298019115, 0.9430987857933579], 
             UndirectedEdge[35, 428] -> 
             RGBColor[
              0.216766629209909, 0.3451658494706758, 0.9356559109047894], 
             UndirectedEdge[19, 298] -> 
             RGBColor[
              0.4816652548138733, 0.582565445026682, 0.9540882765680275], 
             UndirectedEdge[209, 348] -> 
             RGBColor[
              0.8657911144896757, 0.38473790158096455`, 0.21272342517580606`],
              UndirectedEdge[27, 194] -> 
             RGBColor[
              0.20792633813700911`, 0.33587414304623064`, 0.9351524694062264],
              UndirectedEdge[253, 287] -> 
             RGBColor[
              0.9130361340711288, 0.9314864712143058, 0.9153283035663997], 
             UndirectedEdge[412, 476] -> 
             RGBColor[
              0.2130244917015075, 0.341232625684124, 0.9354428017096823], 
             UndirectedEdge[221, 336] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[146, 248] -> 
             RGBColor[
              0.18429425645727748`, 0.31103532684031304`, 0.9338066573150976],
              UndirectedEdge[17, 455] -> 
             RGBColor[
              0.8740328861463312, 0.4191122247550715, 0.39530295688299816`], 
             UndirectedEdge[102, 393] -> 
             RGBColor[
              0.3174055972642307, 0.4455102820141783, 0.9415860984428273], 
             UndirectedEdge[80, 497] -> 
             RGBColor[
              0.9522798235994274, 0.8970322047585058, 0.6159320363216505], 
             UndirectedEdge[108, 416] -> 
             RGBColor[
              0.3104556295882034, 0.4433227952208202, 0.9410029360855943], 
             UndirectedEdge[8, 453] -> 
             RGBColor[
              0.3583771413920187, 0.4800949272439934, 0.9442595287061802], 
             UndirectedEdge[58, 402] -> 
             RGBColor[
              0.296247822930254, 0.42468544619728427`, 0.9403294456885352], 
             UndirectedEdge[95, 357] -> 
             RGBColor[
              0.21203232772077724`, 0.3401897984335468, 0.9353862994387547], 
             UndirectedEdge[183, 283] -> 
             RGBColor[
              0.2250780320064527, 0.3539016607832171, 0.936129232998434], 
             UndirectedEdge[179, 294] -> 
             RGBColor[
              0.2430012286676811, 0.3727400768704716, 0.9371499325332977], 
             UndirectedEdge[136, 240] -> 
             RGBColor[
              0.8413736303622167, 0.28643448166620133`, 0.18597671803717333`],
              UndirectedEdge[153, 289] -> 
             RGBColor[
              0.3557095315743413, 0.48251945059396417`, 0.9438864747036967], 
             UndirectedEdge[73, 200] -> 
             RGBColor[
              0.7612780109143027, 0.4386064526498009, 0.44502052851949037`], 
             UndirectedEdge[196, 447] -> 
             RGBColor[
              0.33114259091826304`, 0.45444303824740756`, 0.942569990376295], 
             UndirectedEdge[68, 492] -> 
             RGBColor[
              0.20085698845876193`, 0.32844380831173514`, 0.9347498804002159],
              UndirectedEdge[25, 413] -> 
             RGBColor[
              0.5841324927331369, 0.6703403678493413, 0.9619312751079657], 
             UndirectedEdge[220, 426] -> 
             RGBColor[0.281104836605655, 0.409255250700044, 0.93944927859504],
              UndirectedEdge[21, 354] -> 
             RGBColor[
              0.8419563231652338, 0.8768171340691335, 0.9847877397984244], 
             UndirectedEdge[125, 269] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[241, 304] -> 
             RGBColor[
              0.2849583416813991, 0.4139279577846052, 0.9396459398364165], 
             UndirectedEdge[93, 456] -> 
             RGBColor[
              0.31230759322488866`, 0.43956894447911504`, 0.9413171215819914],
              UndirectedEdge[295, 455] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[185, 386] -> 
             RGBColor[
              0.5820600535640958, 0.665087506482939, 0.9632927375329758], 
             UndirectedEdge[233, 400] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[83, 317] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[88, 465] -> 
             RGBColor[
              0.20208905675330635`, 0.3297387902069431, 0.9348200448669085], 
             UndirectedEdge[418, 431] -> 
             RGBColor[
              0.9709979456395686, 0.9110545162255583, 0.4028990400131641], 
             UndirectedEdge[121, 307] -> 
             RGBColor[
              0.263034036910473, 0.393795828487049, 0.9382907713268407], 
             UndirectedEdge[64, 74] -> 
             RGBColor[
              0.2126520838133948, 0.3408412013816937, 0.9354215936313823], 
             UndirectedEdge[185, 358] -> 
             RGBColor[
              0.3526247422114796, 0.4798475610938749, 0.9436899146532672], 
             UndirectedEdge[113, 315] -> 
             RGBColor[
              0.22689683739160005`, 0.3558133405619288, 0.9362328112744367], 
             UndirectedEdge[47, 91] -> 
             RGBColor[
              0.8394327584086407, 0.8339577549161943, 0.643804967945467], 
             UndirectedEdge[158, 401] -> 
             RGBColor[
              0.21032997995216565`, 0.3384005229936534, 0.9352893532517302], 
             UndirectedEdge[90, 232] -> 
             RGBColor[
              0.6473094528464778, 0.7237307053563433, 0.9659406092613985], 
             UndirectedEdge[58, 115] -> 
             RGBColor[
              0.23557088884486138`, 0.36493031860593317`, 0.9367267856725908],
              UndirectedEdge[132, 494] -> 
             RGBColor[
              0.8146351336717644, 0.855457320247522, 0.9517217188764132], 
             UndirectedEdge[167, 300] -> 
             RGBColor[
              0.4377850305299138, 0.5534966599025861, 0.9491473266865091], 
             UndirectedEdge[284, 389] -> 
             RGBColor[
              0.2734714206174079, 0.4047661805313866, 0.9388851648882252], 
             UndirectedEdge[103, 233] -> 
             RGBColor[
              0.8763449551304583, 0.4195592621909958, 0.3199825200895846], 
             UndirectedEdge[172, 300] -> 
             RGBColor[
              0.3980318016520928, 0.519176873756168, 0.946583212328937], 
             UndirectedEdge[70, 76] -> 
             RGBColor[
              0.98996116143335, 0.9893085275125257, 0.7572877100420445], 
             UndirectedEdge[57, 73] -> 
             RGBColor[
              0.8251129096320492, 0.19403440474490768`, 0.17168145666561216`],
              UndirectedEdge[287, 473] -> 
             RGBColor[
              0.7221231818613589, 0.7824402756949027, 0.9732771865815069], 
             UndirectedEdge[395, 443] -> 
             RGBColor[
              0.8336688218049073, 0.7551219636314238, 0.61354871525044], 
             UndirectedEdge[100, 397] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[57, 234] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[343, 403] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[105, 425] -> 
             RGBColor[
              0.22254037357983977`, 0.35123442088000967`, 0.9359847171051676],
              UndirectedEdge[133, 423] -> 
             RGBColor[
              0.22055140940715506`, 0.3491438934269059, 0.935871448537942], 
             UndirectedEdge[92, 494] -> 
             RGBColor[
              0.8135287985254407, 0.8545930428227555, 0.9516114497283175], 
             UndirectedEdge[51, 100] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[6, 347] -> 
             RGBColor[
              0.3086318125417763, 0.4393582479507504, 0.9409740450662951], 
             UndirectedEdge[333, 461] -> 
             RGBColor[
              0.479657645205507, 0.5874809597180408, 0.9524463931924381], 
             UndirectedEdge[291, 394] -> 
             RGBColor[
              0.1976212181124982, 0.32504280851812256`, 0.9345656080658895], 
             UndirectedEdge[143, 386] -> 
             RGBColor[
              0.8392900578031888, 0.4839082552203721, 0.450473845405273], 
             UndirectedEdge[123, 437] -> 
             RGBColor[
              0.20027511058254266`, 0.32783221777064053`, 0.9347167433159764],
              UndirectedEdge[72, 453] -> 
             RGBColor[
              0.3882337150931953, 0.510566344050778, 0.9459931262706142], 
             UndirectedEdge[391, 478] -> 
             RGBColor[
              0.7346414386946734, 0.7340552109266808, 0.6178863226320354], 
             UndirectedEdge[328, 464] -> 
             RGBColor[
              0.37866041293742014`, 0.4991210978524166, 0.9456233390095045], 
             UndirectedEdge[149, 173] -> 
             RGBColor[
              0.8427485102135918, 0.3295893587840956, 0.1885693276990594], 
             UndirectedEdge[54, 186] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[355, 444] -> 
             RGBColor[
              0.8548719206901274, 0.42277520421909437`, 0.2001787192628237], 
             UndirectedEdge[7, 448] -> 
             RGBColor[
              0.88883448485202, 0.8578980355011018, 0.6322461472964704], 
             UndirectedEdge[47, 416] -> 
             RGBColor[
              0.5121004622842857, 0.6097734708911251, 0.95656961228473], 
             UndirectedEdge[48, 155] -> 
             RGBColor[
              0.23482099816692198`, 0.3641421359576038, 0.936684080507846], 
             UndirectedEdge[346, 486] -> 
             RGBColor[
              0.9885470027218867, 0.9720400729158498, 0.4940557447733985], 
             UndirectedEdge[24, 491] -> 
             RGBColor[
              0.19844777773507763`, 0.3259115750883605, 0.93461267941361], 
             UndirectedEdge[321, 373] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[209, 231] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[210, 393] -> 
             RGBColor[
              0.30896553356423473`, 0.43663923993453624`, 0.9411054493010679],
              UndirectedEdge[188, 409] -> 
             RGBColor[
              0.4608023334373177, 0.5711559121466802, 0.9512431601205011], 
             UndirectedEdge[307, 427] -> 
             RGBColor[
              0.22293489534478472`, 0.35164908826909147`, 0.9360071845360386],
              UndirectedEdge[178, 186] -> 
             RGBColor[
              0.8637848357389819, 0.37797025225822195`, 0.20492941108331195`],
              UndirectedEdge[328, 475] -> 
             RGBColor[
              0.7096551131254042, 0.7713940703337429, 0.9672995144845954], 
             UndirectedEdge[213, 337] -> 
             RGBColor[
              0.250968758002199, 0.38111445537158695`, 0.9376036715419951], 
             UndirectedEdge[384, 458] -> 
             RGBColor[
              0.5434356286207753, 0.6402010241853623, 0.9572068902738209], 
             UndirectedEdge[87, 473] -> 
             RGBColor[
              0.7302983499153326, 0.788958932792116, 0.9740569414085536], 
             UndirectedEdge[112, 440] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[237, 429] -> 
             RGBColor[
              0.32902794882158914`, 0.4525927099733213, 0.9424359331065173], 
             UndirectedEdge[109, 230] -> 
             RGBColor[
              0.31288969270847855`, 0.4441699482670213, 0.9412042078533198], 
             UndirectedEdge[89, 262] -> 
             RGBColor[
              0.905321249690827, 0.92692609223136, 0.9763907323962904], 
             UndirectedEdge[280, 383] -> 
             RGBColor[
              0.5876838324912708, 0.6761472359281866, 0.9606837705319751], 
             UndirectedEdge[196, 489] -> 
             RGBColor[
              0.23441451862430046`, 0.36371490018601704`, 0.9366609320992263],
              UndirectedEdge[279, 459] -> 
             RGBColor[
              0.27500306633600013`, 0.4063760372935745, 0.9389723898460322], 
             UndirectedEdge[191, 423] -> 
             RGBColor[
              0.20464821144403264`, 0.3324286240466755, 0.9349657849406153], 
             UndirectedEdge[116, 165] -> 
             RGBColor[
              0.7645854413092009, 0.8162193268874823, 0.9771172884853815], 
             UndirectedEdge[176, 313] -> 
             RGBColor[
              0.9308645267408745, 0.9466209785289019, 0.9555065870493364], 
             UndirectedEdge[180, 490] -> 
             RGBColor[
              0.4726781530538206, 0.5797540945256074, 0.9524662916581652], 
             UndirectedEdge[17, 498] -> 
             RGBColor[
              0.8740328861463312, 0.4191122247550715, 0.39530295688299816`], 
             UndirectedEdge[108, 364] -> 
             RGBColor[
              0.29999764061783074`, 0.4324035498062153, 0.9404047048359647], 
             UndirectedEdge[29, 254] -> 
             RGBColor[
              0.219858689201137, 0.34841580056938304`, 0.935831999146997], 
             UndirectedEdge[7, 261] -> 
             RGBColor[
              0.9399230799294223, 0.8986346944528518, 0.6371190231022803], 
             UndirectedEdge[122, 224] -> 
             RGBColor[
              0.25163511157756463`, 0.38181483522855314`, 0.9376416193923304],
              UndirectedEdge[116, 386] -> 
             RGBColor[
              0.7639631876081299, 0.8157231586768751, 0.9770579373718808], 
             UndirectedEdge[8, 439] -> 
             RGBColor[
              0.2626279467019643, 0.3933690019303001, 0.9382676450902228], 
             UndirectedEdge[226, 488] -> 
             RGBColor[
              0.20402766147053647`, 0.33177638667939024`, 0.9349304455376461],
              UndirectedEdge[64, 170] -> 
             RGBColor[
              0.2105590287411936, 0.3386412677934538, 0.9353023972414181], 
             UndirectedEdge[178, 313] -> 
             RGBColor[
              0.9673256290864539, 0.9243605553414638, 0.6042935618647849], 
             UndirectedEdge[81, 251] -> 
             RGBColor[
              0.4506348367930976, 0.5647389788898851, 0.9499350312130843], 
             UndirectedEdge[186, 288] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[45, 118] -> 
             RGBColor[
              0.2554591373040128, 0.3858341287242849, 0.9378593920003125], 
             UndirectedEdge[224, 330] -> 
             RGBColor[
              0.2600393493307347, 0.39064822196658494`, 0.9381202282994179], 
             UndirectedEdge[35, 410] -> 
             RGBColor[
              0.2048653084706884, 0.3326568067864372, 0.934978148295117], 
             UndirectedEdge[163, 379] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[181, 443] -> 
             RGBColor[
              0.5695192678995484, 0.6579480039591199, 0.9608880248523786], 
             UndirectedEdge[167, 235] -> 
             RGBColor[
              0.40241813704526735`, 0.5228636343579377, 0.9468937795073835], 
             UndirectedEdge[202, 279] -> 
             RGBColor[
              0.25837662777741854`, 0.38890059619141426`, 0.9380255387667326],
              UndirectedEdge[242, 310] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[299, 482] -> 
             RGBColor[
              0.6975160835754234, 0.7617373852765769, 0.9716632609212784], 
             UndirectedEdge[56, 110] -> 
             RGBColor[
              0.9942182188017068, 0.9900416795816283, 0.6120669814623443], 
             UndirectedEdge[125, 419] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[262, 448] -> 
             RGBColor[
              0.8880396268664679, 0.9131461952883709, 0.9747423957838162], 
             UndirectedEdge[95, 212] -> 
             RGBColor[
              0.19782060647564204`, 0.3252523783297391, 0.9345769629382018], 
             UndirectedEdge[32, 260] -> 
             RGBColor[
              0.3358333242416319, 0.46530367880959933`, 0.9426199803482964], 
             UndirectedEdge[421, 430] -> 
             RGBColor[
              0.2393158270696491, 0.3688664861229826, 0.9369400543643528], 
             UndirectedEdge[129, 346] -> 
             RGBColor[
              0.871715025393385, 0.8835314226277342, 0.6825874912808683], 
             UndirectedEdge[16, 17] -> 
             RGBColor[
              0.8171965358160596, 0.8565952297054558, 0.9114583528675545], 
             UndirectedEdge[153, 466] -> 
             RGBColor[
              0.32275440531108784`, 0.44832861562108495`, 0.9419933587799665],
              UndirectedEdge[244, 391] -> 
             RGBColor[
              0.9648781629368668, 0.8921768561625062, 0.323324455739553], 
             UndirectedEdge[218, 406] -> 
             RGBColor[
              0.8668298092779636, 0.8929538809350525, 0.7729243520835001], 
             UndirectedEdge[99, 288] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[399, 481] -> 
             RGBColor[
              0.29801585957910287`, 0.4305639420874404, 0.9402829343768502], 
             UndirectedEdge[278, 451] -> 
             RGBColor[
              0.24719400766817687`, 0.37714695343753535`, 0.9373887050947152],
              UndirectedEdge[179, 327] -> 
             RGBColor[
              0.23500467222293953`, 0.364335189036086, 0.9366945404736147], 
             UndirectedEdge[38, 473] -> 
             RGBColor[
              0.7528058541930568, 0.6634482434020327, 0.5999179731708593], 
             UndirectedEdge[17, 176] -> 
             RGBColor[
              0.9356274804823903, 0.9496301387073782, 0.9231255771340168], 
             UndirectedEdge[186, 373] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[399, 496] -> 
             RGBColor[
              0.2561178705712659, 0.3865264991542693, 0.937896905885374], 
             UndirectedEdge[116, 358] -> 
             RGBColor[
              0.5345278762555137, 0.6304832132878109, 0.9574551144921722], 
             UndirectedEdge[71, 135] -> 
             RGBColor[
              0.2217446900292419, 0.3503981070190804, 0.9359394041040694], 
             UndirectedEdge[53, 374] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[228, 409] -> 
             RGBColor[
              0.5569548786168692, 0.6512000868493509, 0.9582646747191151], 
             UndirectedEdge[440, 471] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[403, 471] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[63, 166] -> 
             RGBColor[
              0.275068039384163, 0.4064443280867228, 0.938976089965006], 
             UndirectedEdge[159, 272] -> 
             RGBColor[
              0.4928488984890493, 0.5982329341630651, 0.953473053095963], 
             UndirectedEdge[130, 351] -> 
             RGBColor[
              0.6463531647474265, 0.72096106746608, 0.9672728087793628], 
             UndirectedEdge[113, 378] -> 
             RGBColor[
              0.2776267210047927, 0.4091336646997893, 0.9391218030980706], 
             UndirectedEdge[145, 417] -> 
             RGBColor[
              0.28299968789977625`, 0.4147809935721941, 0.9394277856141477], 
             UndirectedEdge[38, 354] -> 
             RGBColor[
              0.8806079583693727, 0.7641793364590133, 0.6121886131805274], 
             UndirectedEdge[334, 446] -> 
             RGBColor[
              0.20565132116996215`, 0.33348295596945743`, 0.9350229105555391],
              UndirectedEdge[305, 310] -> 
             RGBColor[
              0.8321466499760604, 0.3869651660515733, 0.4383722111318249], 
             UndirectedEdge[338, 383] -> 
             RGBColor[
              0.8128642763019948, 0.8502049776238694, 0.7323969456225705], 
             UndirectedEdge[243, 477] -> 
             RGBColor[
              0.257579961556534, 0.3880632494817088, 0.9379801698040153], 
             UndirectedEdge[38, 221] -> 
             RGBColor[
              0.8446459694565934, 0.30129340921955317`, 0.18870723798989242`],
              UndirectedEdge[330, 357] -> 
             RGBColor[
              0.22258574416561577`, 0.35128210824232153`, 0.9359873008929078],
              UndirectedEdge[48, 365] -> 
             RGBColor[
              0.2630799821961634, 0.393844119895409, 0.9382933878428907], 
             UndirectedEdge[384, 411] -> 
             RGBColor[
              0.673364501803413, 0.7446351140079177, 0.9681614906767982], 
             UndirectedEdge[38, 436] -> 
             RGBColor[
              0.9344998640366943, 0.8062744916611889, 0.5869300975227473], 
             UndirectedEdge[117, 155] -> 
             RGBColor[
              0.22121121154755882`, 0.34983738731034214`, 0.9359090232937483],
              UndirectedEdge[68, 286] -> 
             RGBColor[
              0.21116729807720058`, 0.3392805974321006, 0.9353370372802498], 
             UndirectedEdge[378, 380] -> 
             RGBColor[
              0.25770930190939245`, 0.38819919439321504`, 0.9379875355457686],
              UndirectedEdge[12, 285] -> 
             RGBColor[
              0.28914299431124585`, 0.4188772275808861, 0.9398640771999859], 
             UndirectedEdge[93, 432] -> 
             RGBColor[
              0.5726032211042509, 0.6597690140569965, 0.961444357581985], 
             UndirectedEdge[340, 499] -> 
             RGBColor[
              0.872096562596627, 0.418030146437691, 0.414793028650732], 
             UndirectedEdge[389, 456] -> 
             RGBColor[
              0.24930916567101583`, 0.3793701186072822, 0.937509160213881], 
             UndirectedEdge[390, 451] -> 
             RGBColor[
              0.4248740733662101, 0.5379958488479989, 0.94913797789986], 
             UndirectedEdge[92, 485] -> 
             RGBColor[
              0.6061214293900224, 0.6908811127102437, 0.9622956395712158], 
             UndirectedEdge[293, 471] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[111, 359] -> 
             RGBColor[
              0.8730579162973663, 0.4187090496669422, 0.41146073042143505`], 
             UndirectedEdge[357, 441] -> 
             RGBColor[
              0.29429774702065686`, 0.4211551754544992, 0.9402726044034251], 
             UndirectedEdge[52, 268] -> 
             RGBColor[
              0.19710983178549013`, 0.32450530906467123`, 0.9345364853710946],
              UndirectedEdge[30, 311] -> 
             RGBColor[
              0.20275732105733557`, 0.3304411783608819, 0.9348581015304145], 
             UndirectedEdge[164, 486] -> 
             RGBColor[
              0.9373839117496703, 0.9487397730310224, 0.7940867100536502], 
             UndirectedEdge[194, 290] -> 
             RGBColor[
              0.19998987236326368`, 0.3275324143170307, 0.9347004994213606], 
             UndirectedEdge[238, 445] -> 
             RGBColor[
              0.857059891141737, 0.3514566373014637, 0.19874471492026624`], 
             UndirectedEdge[269, 406] -> 
             RGBColor[
              0.8761600890568056, 0.41916385235227993`, 0.29986098883365586`],
              UndirectedEdge[99, 341] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[41, 457] -> 
             RGBColor[
              0.7799506296404679, 0.7772562145851217, 0.6242203432368331], 
             UndirectedEdge[217, 292] -> 
             RGBColor[
              0.1972518591229097, 0.32465458880135256`, 0.93454457361785], 
             UndirectedEdge[176, 299] -> 
             RGBColor[
              0.6712865587841526, 0.7408369694039865, 0.9696570894914054], 
             UndirectedEdge[218, 314] -> 
             RGBColor[
              0.6705997100303512, 0.7419691429870332, 0.9682319417643492], 
             UndirectedEdge[355, 486] -> 
             RGBColor[
              0.9025631372122566, 0.6216242602355779, 0.3345764630246274], 
             UndirectedEdge[213, 420] -> 
             RGBColor[
              0.24872595585540894`, 0.3787571281134413, 0.9374759472776638], 
             UndirectedEdge[299, 407] -> 
             RGBColor[
              0.5735216905682538, 0.6639465563931397, 0.9600496665900575], 
             UndirectedEdge[201, 314] -> 
             RGBColor[
              0.5845834032200327, 0.6736301677730485, 0.9604396933824965], 
             UndirectedEdge[160, 300] -> 
             RGBColor[
              0.43648566488694934`, 0.5524417763378724, 0.9490450358633619], 
             UndirectedEdge[21, 200] -> 
             RGBColor[
              0.7122146064560578, 0.7745113761794283, 0.9723644063851347], 
             UndirectedEdge[25, 180] -> 
             RGBColor[
              0.6805512380532523, 0.7497757419185513, 0.9692016721251016], 
             UndirectedEdge[45, 185] -> 
             RGBColor[
              0.2976969078072994, 0.42913054113154847`, 0.9403049796510078], 
             UndirectedEdge[191, 226] -> 
             RGBColor[
              0.22140390405308463`, 0.35003991935106027`, 0.935919996846875], 
             UndirectedEdge[50, 82] -> 
             RGBColor[
              0.844192723800754, 0.2992353265545987, 0.18832903870459236`], 
             UndirectedEdge[22, 491] -> 
             RGBColor[
              0.19092580831177908`, 0.31800550830406665`, 0.9341843143827098],
              UndirectedEdge[99, 277] -> 
             RGBColor[
              0.8718851812720558, 0.40529461979285863`, 0.23639772385740537`],
              UndirectedEdge[17, 391] -> 
             RGBColor[
              0.970002280405527, 0.9193210457585888, 0.5690733922205091], 
             UndirectedEdge[211, 362] -> 
             RGBColor[
              0.19802212087574567`, 0.325464182740999, 0.934588438885174], 
             UndirectedEdge[4, 162] -> 
             RGBColor[
              0.19396900628499292`, 0.32120410232381014`, 0.9343576200052762],
              UndirectedEdge[259, 444] -> 
             RGBColor[
              0.8285562969045, 0.22050178822288907`, 0.17497884820646079`], 
             UndirectedEdge[347, 382] -> 
             RGBColor[
              0.30305610597028676`, 0.43452885116168694`, 0.9406187659739635],
              UndirectedEdge[66, 179] -> 
             RGBColor[
              0.26537930167515955`, 0.3962608504531091, 0.9384243306856812], 
             UndirectedEdge[343, 471] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[97, 322] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[363, 381] -> 
             RGBColor[
              0.2070518443671499, 0.33495499464800116`, 0.9351026682797305], 
             UndirectedEdge[238, 471] -> 
             RGBColor[
              0.857059891141737, 0.3514566373014637, 0.19874471492026624`], 
             UndirectedEdge[40, 285] -> 
             RGBColor[
              0.269701942846091, 0.39844344985715197`, 0.9387569380795036], 
             UndirectedEdge[70, 208] -> 
             RGBColor[
              0.9892910387748346, 0.9878752029057549, 0.6843489941803045], 
             UndirectedEdge[84, 448] -> 
             RGBColor[
              0.7514898127927288, 0.8058231255251804, 0.9758560360026285], 
             UndirectedEdge[152, 195] -> 
             RGBColor[
              0.21010530872100186`, 0.3381643792847215, 0.9352765585574867], 
             UndirectedEdge[93, 308] -> 
             RGBColor[
              0.30216970138459465`, 0.4289133773754982, 0.9407397836393536], 
             UndirectedEdge[255, 478] -> 
             RGBColor[
              0.38712473452348783`, 0.5032706196539489, 0.9465374726015883], 
             UndirectedEdge[112, 293] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[87, 184] -> 
             RGBColor[
              0.86529909849953, 0.7089485006828021, 0.6022343862942678], 
             UndirectedEdge[149, 323] -> 
             RGBColor[
              0.8427485102135918, 0.3295893587840956, 0.1885693276990594], 
             UndirectedEdge[272, 497] -> 
             RGBColor[
              0.7564721734761921, 0.7423611564460912, 0.6174367128789657], 
             UndirectedEdge[80, 471] -> 
             RGBColor[
              0.8642091954046907, 0.41214776090032323`, 0.42814428395185355`],
              UndirectedEdge[339, 344] -> 
             RGBColor[
              0.20608159129440537`, 0.33393519715094877`, 0.9350474138025986],
              UndirectedEdge[137, 393] -> 
             RGBColor[
              0.3443442466033714, 0.47267541198794205`, 0.9431622887952733], 
             UndirectedEdge[11, 316] -> 
             RGBColor[
              0.9867175484992736, 0.9766529954342503, 0.6283033308879433], 
             UndirectedEdge[88, 423] -> 
             RGBColor[
              0.20241340429212143`, 0.33007970003505943`, 0.9348385159794148],
              UndirectedEdge[70, 351] -> 
             RGBColor[
              0.7225448589609941, 0.7801979166455426, 0.9196407548248287], 
             UndirectedEdge[55, 298] -> 
             RGBColor[
              0.7891203983542464, 0.4750093414495175, 0.4492866000375796], 
             UndirectedEdge[428, 437] -> 
             RGBColor[
              0.20442661690374475`, 0.33219571413492754`, 0.9349531654593657],
              UndirectedEdge[90, 137] -> 
             RGBColor[
              0.45984500856407784`, 0.5687739133839165, 0.9516112068287906], 
             UndirectedEdge[344, 439] -> 
             RGBColor[
              0.24709777481850334`, 0.37704580661101333`, 0.9373832247762901],
              UndirectedEdge[93, 274] -> 
             RGBColor[
              0.4288787771490915, 0.545063574926054, 0.948778472238694], 
             UndirectedEdge[60, 434] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[54, 244] -> 
             RGBColor[
              0.8706168078338911, 0.40101609835768304`, 0.23147033256236077`],
              UndirectedEdge[243, 318] -> 
             RGBColor[
              0.257982887562488, 0.3884867502609507, 0.9380031158439788], 
             UndirectedEdge[384, 402] -> 
             RGBColor[
              0.493323693614111, 0.5967965847816775, 0.9540138020874405], 
             UndirectedEdge[83, 233] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[153, 201] -> 
             RGBColor[
              0.4828110574856316, 0.5895003637293261, 0.9528440323387535], 
             UndirectedEdge[275, 331] -> 
             RGBColor[
              0.880471837443817, 0.8195704114474931, 0.6243590994767585], 
             UndirectedEdge[312, 327] -> 
             RGBColor[
              0.22392755577381057`, 0.35269243731830396`, 0.9360637150789621],
              UndirectedEdge[181, 370] -> 
             RGBColor[
              0.39544611839331145`, 0.5169372848776308, 0.9464184548781174], 
             UndirectedEdge[32, 245] -> 
             RGBColor[
              0.4212849020662287, 0.5385132494002911, 0.9482871073803061], 
             UndirectedEdge[176, 391] -> 
             RGBColor[
              0.9181691024489237, 0.8798685102007529, 0.6347260987055314], 
             UndirectedEdge[148, 232] -> 
             RGBColor[
              0.6848339419914155, 0.7537167475052093, 0.9692215052668037], 
             UndirectedEdge[430, 477] -> 
             RGBColor[
              0.26829891864456346`, 0.39932955300236017`, 0.9385905985529026],
              UndirectedEdge[7, 475] -> 
             RGBColor[
              0.9478498229277461, 0.9047861002729332, 0.6320100649755263], 
             UndirectedEdge[15, 50] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[168, 395] -> 
             RGBColor[
              0.84803720063224, 0.7663466503750598, 0.6149808209718142], 
             UndirectedEdge[97, 440] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[71, 308] -> 
             RGBColor[
              0.24523893977810896`, 0.3750920531266102, 0.9372773668706396], 
             UndirectedEdge[253, 436] -> 
             RGBColor[
              0.9789187620697407, 0.9831427029239654, 0.8912134737088222], 
             UndirectedEdge[13, 430] -> 
             RGBColor[
              0.4079602536351721, 0.5224454613676528, 0.9479720355331471], 
             UndirectedEdge[209, 233] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[254, 350] -> 
             RGBColor[
              0.21360194576422215`, 0.3418395665167393, 0.9354756868642873], 
             UndirectedEdge[115, 268] -> 
             RGBColor[
              0.22078326587035477`, 0.3493875892702776, 0.9358846524205204], 
             UndirectedEdge[42, 468] -> 
             RGBColor[
              0.3202366373459297, 0.4484035479636482, 0.9417503367363287], 
             UndirectedEdge[51, 60] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[331, 348] -> 
             RGBColor[
              0.8951149267316608, 0.8756226907724907, 0.6465713173376927], 
             UndirectedEdge[310, 406] -> 
             RGBColor[
              0.8761600890568056, 0.41916385235227993`, 0.29986098883365586`],
              UndirectedEdge[70, 130] -> 
             RGBColor[
              0.9093854335224396, 0.9290669367355356, 0.9363199027732196], 
             UndirectedEdge[83, 440] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[100, 374] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[207, 374] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[51, 324] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[164, 180] -> 
             RGBColor[
              0.7420798659697871, 0.7983328217384686, 0.9752041209037695], 
             UndirectedEdge[56, 132] -> 
             RGBColor[
              0.8272638065010585, 0.8625872962506922, 0.8124464787598393], 
             UndirectedEdge[30, 423] -> 
             RGBColor[
              0.17952980953436626`, 0.3060275910409509, 0.9335353291112054], 
             UndirectedEdge[104, 379] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[324, 457] -> 
             RGBColor[
              0.8638009847389825, 0.3780247266271895, 0.20499214689883155`], 
             UndirectedEdge[283, 459] -> 
             RGBColor[
              0.2197263215188342, 0.34827667374268706`, 0.9358244610033103], 
             UndirectedEdge[128, 245] -> 
             RGBColor[
              0.3639482041295633, 0.48295335281971236`, 0.9448496084986262], 
             UndirectedEdge[34, 62] -> 
             RGBColor[
              0.4183440898877315, 0.5346740747422846, 0.9484437217570646], 
             UndirectedEdge[320, 424] -> 
             RGBColor[
              0.2150158225760247, 0.3433256406909113, 0.935556205057076], 
             UndirectedEdge[111, 351] -> 
             RGBColor[
              0.7220241695390399, 0.7799825981884567, 0.9282699260476386], 
             UndirectedEdge[79, 316] -> 
             RGBColor[
              0.8735231410973765, 0.4108198428949215, 0.24276088847601782`], 
             UndirectedEdge[43, 250] -> 
             RGBColor[
              0.3804144405970011, 0.5039176010845604, 0.9454606496609272], 
             UndirectedEdge[116, 313] -> 
             RGBColor[
              0.8311822940909279, 0.8682327058496676, 0.945708059179992], 
             UndirectedEdge[87, 436] -> 
             RGBColor[
              0.9119923597589701, 0.9317851810512723, 0.9610690657604415], 
             UndirectedEdge[280, 393] -> 
             RGBColor[
              0.4551735238121738, 0.5662396182348755, 0.9508957986727633], 
             UndirectedEdge[295, 321] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[131, 186] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[165, 313] -> 
             RGBColor[
              0.9113378981742353, 0.9310509749460764, 0.9536441197850233], 
             UndirectedEdge[140, 270] -> 
             RGBColor[
              0.18167152053006663`, 0.3082786650897521, 0.933657296384033], 
             UndirectedEdge[322, 445] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[112, 463] -> 
             RGBColor[
              0.831998657058118, 0.24386491747293382`, 0.17815401051060936`], 
             UndirectedEdge[115, 223] -> 
             RGBColor[
              0.26791411799790454`, 0.39892510312495144`, 0.9385686847253369],
              UndirectedEdge[102, 451] -> 
             RGBColor[
              0.2794536000934562, 0.411053830452799, 0.9392258411595447], 
             UndirectedEdge[148, 267] -> 
             RGBColor[
              0.5395860200293785, 0.6353257853025731, 0.9575821023058444], 
             UndirectedEdge[447, 500] -> 
             RGBColor[
              0.3505102887658151, 0.47479971666815324`, 0.9436729521167717], 
             UndirectedEdge[238, 293] -> 
             RGBColor[
              0.857059891141737, 0.3514566373014637, 0.19874471492026624`], 
             UndirectedEdge[56, 457] -> 
             RGBColor[
              0.9757033167270259, 0.9283837992580474, 0.47234923862849276`], 
             UndirectedEdge[204, 331] -> 
             RGBColor[
              0.8538682923947138, 0.8863154149909298, 0.9859239140574727], 
             UndirectedEdge[66, 260] -> 
             RGBColor[
              0.2863066273900213, 0.4179525885520823, 0.9396272494745492], 
             UndirectedEdge[225, 424] -> 
             RGBColor[
              0.22110380579881245`, 0.3497244970584919, 0.9359029066952498], 
             UndirectedEdge[178, 244] -> 
             RGBColor[
              0.9669644653593094, 0.9002255259238574, 0.326163615468509], 
             UndirectedEdge[139, 247] -> 
             RGBColor[
              0.19836393844048342`, 0.3258234546740237, 0.9346079048898119], 
             UndirectedEdge[244, 448] -> 
             RGBColor[
              0.9007203648295853, 0.898737794797208, 0.6745359116986607], 
             UndirectedEdge[259, 275] -> 
             RGBColor[
              0.8560290549644465, 0.34736971536429956`, 0.19791527993518332`],
              UndirectedEdge[282, 406] -> 
             RGBColor[
              0.8761600890568056, 0.41916385235227993`, 0.29986098883365586`],
              UndirectedEdge[286, 357] -> 
             RGBColor[
              0.21788015626742555`, 0.3463362370098189, 0.9357193246233994], 
             UndirectedEdge[206, 396] -> 
             RGBColor[
              0.2219991302915197, 0.35066553986717874`, 0.9359538941005956], 
             UndirectedEdge[154, 295] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[410, 428] -> 
             RGBColor[
              0.20513431686132172`, 0.3329395516611099, 0.9349934679250014], 
             UndirectedEdge[104, 147] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[32, 255] -> 
             RGBColor[
              0.3085704354238704, 0.43695286219157675`, 0.941056260613344], 
             UndirectedEdge[165, 498] -> 
             RGBColor[
              0.8264596817975027, 0.3824305319946304, 0.43782978303013764`], 
             UndirectedEdge[248, 439] -> 
             RGBColor[
              0.22555407263405997`, 0.35440200966555135`, 0.9361563428079372],
              UndirectedEdge[141, 389] -> 
             RGBColor[
              0.27450272226024985`, 0.40585014394631425`, 0.9389438959911109],
              UndirectedEdge[328, 478] -> 
             RGBColor[
              0.4968951094795723, 0.6024408606019271, 0.9535365496864436], 
             UndirectedEdge[178, 261] -> 
             RGBColor[
              0.9415610017646239, 0.9049056845997665, 0.6395974052858973], 
             UndirectedEdge[120, 315] -> 
             RGBColor[
              0.19068570408703148`, 0.3177531435403698, 0.9341706408023127], 
             UndirectedEdge[47, 136] -> 
             RGBColor[
              0.8020754049028471, 0.684036360935029, 0.600844615682085], 
             UndirectedEdge[74, 144] -> 
             RGBColor[
              0.23865380323456642`, 0.36817065709757524`, 0.9369023530863214],
              UndirectedEdge[165, 361] -> 
             RGBColor[
              0.6271981599055898, 0.7041410688188706, 0.9661885994129014], 
             UndirectedEdge[32, 482] -> 
             RGBColor[
              0.64794186446319, 0.7189469622856886, 0.9684634669871719], 
             UndirectedEdge[67, 119] -> 
             RGBColor[
              0.194730591149065, 0.3220045763032192, 0.9344009911366213], 
             UndirectedEdge[97, 326] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[409, 430] -> 
             RGBColor[
              0.4088644575244336, 0.5231795348188764, 0.9480432177755177], 
             UndirectedEdge[113, 190] -> 
             RGBColor[
              0.30008982406307977`, 0.4294267187567612, 0.9405224985550569], 
             UndirectedEdge[292, 496] -> 
             RGBColor[
              0.20710059025010286`, 0.3350062296616523, 0.9351054442856517], 
             UndirectedEdge[15, 82] -> 
             RGBColor[
              0.844192723800754, 0.2992353265545987, 0.18832903870459236`], 
             UndirectedEdge[340, 414] -> 
             RGBColor[
              0.9874917700585177, 0.9869911353155156, 0.7157672733396714], 
             UndirectedEdge[149, 282] -> 
             RGBColor[
              0.8427485102135918, 0.3295893587840956, 0.1885693276990594], 
             UndirectedEdge[330, 368] -> 
             RGBColor[
              0.202529033876395, 0.3302012340594701, 0.9348451009131806], 
             UndirectedEdge[331, 431] -> 
             RGBColor[
              0.9104717457098559, 0.9268410177088308, 0.7558742996920007], 
             UndirectedEdge[4, 488] -> 
             RGBColor[
              0.1922517191621101, 0.319399124675368, 0.9342598230441267], 
             UndirectedEdge[87, 409] -> 
             RGBColor[
              0.6978057770639152, 0.7625799983776096, 0.9714990070494738], 
             UndirectedEdge[440, 445] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[55, 200] -> 
             RGBColor[
              0.7633408610929295, 0.4544624230694392, 0.44699591618019946`], 
             UndirectedEdge[64, 215] -> 
             RGBColor[
              0.20458807963597442`, 0.33236542170382943`, 0.9349623605231034],
              UndirectedEdge[167, 493] -> 
             RGBColor[
              0.5234517902759379, 0.624000770437253, 0.9556271888790606], 
             UndirectedEdge[153, 470] -> 
             RGBColor[
              0.32216778334016727`, 0.44771203873566623`, 0.941959951526552], 
             UndirectedEdge[185, 187] -> 
             RGBColor[
              0.3439018393873985, 0.4722922210934996, 0.943134098998677], 
             UndirectedEdge[18, 310] -> 
             RGBColor[
              0.7962722946032341, 0.358714514364911, 0.4348563870006418], 
             UndirectedEdge[226, 366] -> 
             RGBColor[
              0.20408822256120682`, 0.33184004022547964`, 0.9349338944021677],
              UndirectedEdge[333, 361] -> 
             RGBColor[
              0.4137027061318567, 0.5327502235739785, 0.9475817485051508], 
             UndirectedEdge[236, 300] -> 
             RGBColor[
              0.361908596774024, 0.4876077971989662, 0.9442917614214452], 
             UndirectedEdge[161, 335] -> 
             RGBColor[
              0.32336695487389533`, 0.45450593624120883`, 0.9418256343157618],
              UndirectedEdge[61, 397] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[393, 480] -> 
             RGBColor[
              0.4234576653062009, 0.5404912555165833, 0.9483990101121553], 
             UndirectedEdge[349, 378] -> 
             RGBColor[
              0.25281205566812764`, 0.38305187809030017`, 0.9377086446171552],
              UndirectedEdge[97, 163] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[229, 267] -> 
             RGBColor[
              0.4190003186918113, 0.5373387493076619, 0.9479193076929763], 
             UndirectedEdge[77, 287] -> 
             RGBColor[
              0.8886081106405144, 0.9139236161987528, 0.9860343180119231], 
             UndirectedEdge[41, 485] -> 
             RGBColor[
              0.5788529501858339, 0.6689779278459186, 0.9599885711283033], 
             UndirectedEdge[7, 89] -> 
             RGBColor[
              0.9061161076763791, 0.8716779324440909, 0.6338944839089447], 
             UndirectedEdge[41, 44] -> 
             RGBColor[
              0.6512432193483967, 0.7268745780156403, 0.9662842946826327], 
             UndirectedEdge[147, 234] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[259, 331] -> 
             RGBColor[
              0.8207108366647649, 0.37784655893402913`, 0.4372814530493224], 
             UndirectedEdge[77, 409] -> 
             RGBColor[
              0.7403041559440713, 0.7963746652347496, 0.9723494294433779], 
             UndirectedEdge[2, 334] -> 
             RGBColor[
              0.20734715427896283`, 0.33526538408904644`, 0.9351194857423364],
              UndirectedEdge[315, 487] -> 
             RGBColor[
              0.21833205101187592`, 0.3468112070380179, 0.9357450593605774], 
             UndirectedEdge[251, 258] -> 
             RGBColor[
              0.7229805531619574, 0.7777005783665802, 0.766539139108648], 
             UndirectedEdge[39, 96] -> 
             RGBColor[
              0.7306179728698792, 0.7351380902552997, 0.6185709577425946], 
             UndirectedEdge[219, 497] -> 
             RGBColor[
              0.8604026869949277, 0.3647097089386806, 0.20143440692924686`], 
             UndirectedEdge[447, 454] -> 
             RGBColor[
              0.37348676159854866`, 0.49791719373137167`, 0.9450192240810519],
              UndirectedEdge[417, 458] -> 
             RGBColor[
              0.3548964645190724, 0.477062505477272, 0.9440086866858435], 
             UndirectedEdge[189, 422] -> 
             RGBColor[
              0.41564195559551864`, 0.5312496150360451, 0.9483430299448219], 
             UndirectedEdge[431, 444] -> 
             RGBColor[
              0.8985035876174724, 0.5916330293176362, 0.30711377649159965`], 
             UndirectedEdge[161, 273] -> 
             RGBColor[
              0.2730441392759877, 0.4021945496181309, 0.9389385481101638], 
             UndirectedEdge[109, 413] -> 
             RGBColor[
              0.37066616576114175`, 0.49547413538427865`, 0.9448394982084473],
              UndirectedEdge[236, 470] -> 
             RGBColor[
              0.27610261754366017`, 0.40753173532839826`, 0.9390350076606682],
              UndirectedEdge[287, 436] -> 
             RGBColor[
              0.9038171917049964, 0.925266523954059, 0.9602893109333949], 
             UndirectedEdge[253, 473] -> 
             RGBColor[
              0.7972247522261032, 0.8403164546648092, 0.9042013493569341], 
             UndirectedEdge[166, 435] -> 
             RGBColor[
              0.3502789983611274, 0.4724858600150052, 0.9437356009830916], 
             UndirectedEdge[114, 312] -> 
             RGBColor[
              0.21887732335559562`, 0.3473843228435307, 0.9357761118138941], 
             UndirectedEdge[222, 296] -> 
             RGBColor[
              0.22518419086516983`, 0.35401324047458915`, 0.9361352785883901],
              UndirectedEdge[5, 346] -> 
             RGBColor[
              0.8725424883879621, 0.4075118710378607, 0.23895123788066785`], 
             UndirectedEdge[86, 220] -> 
             RGBColor[
              0.2767001990541243, 0.4046256973632345, 0.9391984410025577], 
             UndirectedEdge[195, 255] -> 
             RGBColor[
              0.2379640347981863, 0.3674456667370949, 0.9368630717942905], 
             UndirectedEdge[313, 407] -> 
             RGBColor[
              0.8330996585249757, 0.8697305655180553, 0.9458991641479886], 
             UndirectedEdge[224, 441] -> 
             RGBColor[
              0.33175135218577584`, 0.46052128917876256`, 0.942405531809935], 
             UndirectedEdge[172, 211] -> 
             RGBColor[
              0.29686791214582525`, 0.42295867443787283`, 0.9404518482979395],
              UndirectedEdge[204, 355] -> 
             RGBColor[
              0.8646089820506718, 0.5941398003894627, 0.4641583607120223], 
             UndirectedEdge[109, 180] -> 
             RGBColor[
              0.4670849110812572, 0.5749095094534886, 0.9521098952255831], 
             UndirectedEdge[96, 157] -> 
             RGBColor[
              0.886514879220424, 0.8590158099428777, 0.6326804478109045], 
             UndirectedEdge[316, 372] -> 
             RGBColor[
              0.8735231410973765, 0.41081984289492157`, 0.24276088847601784`],
              UndirectedEdge[53, 112] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[28, 305] -> 
             RGBColor[
              0.905565702349901, 0.8647283509110522, 0.6323840635977009], 
             UndirectedEdge[186, 341] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[65, 86] -> 
             RGBColor[
              0.2018366701530856, 0.3294735158878764, 0.9348056718233985], 
             UndirectedEdge[10, 390] -> 
             RGBColor[
              0.4759482746338757, 0.5838180940569503, 0.9523343704246872], 
             UndirectedEdge[48, 140] -> 
             RGBColor[
              0.20271183825122668`, 0.33039337304788496`, 0.9348555113518924],
              UndirectedEdge[231, 404] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[87, 354] -> 
             RGBColor[
              0.8581004540916486, 0.8896900258490967, 0.9863275814182217], 
             UndirectedEdge[136, 434] -> 
             RGBColor[
              0.8413736303622167, 0.28643448166620133`, 0.18597671803717333`],
              UndirectedEdge[205, 413] -> 
             RGBColor[
              0.4278594550620529, 0.5450120879584244, 0.9484838040286614], 
             UndirectedEdge[20, 490] -> 
             RGBColor[
              0.40560130196472277`, 0.5252980850337723, 0.9471857562298298], 
             UndirectedEdge[390, 443] -> 
             RGBColor[
              0.6547537583791506, 0.7289277232022592, 0.967105480552021], 
             UndirectedEdge[296, 385] -> 
             RGBColor[
              0.19170031260162856`, 0.3188195614191067, 0.9342284212562402], 
             UndirectedEdge[86, 290] -> 
             RGBColor[
              0.1982772303559066, 0.32573231897952337`, 0.9346029669926684], 
             UndirectedEdge[24, 74] -> 
             RGBColor[
              0.2136963850560424, 0.34193882820023935`, 0.9354810650422459], 
             UndirectedEdge[38, 336] -> 
             RGBColor[
              0.8446459694565934, 0.30129340921955317`, 0.18870723798989242`],
              UndirectedEdge[383, 443] -> 
             RGBColor[
              0.6919520032781376, 0.7591269341730926, 0.9700338626521301], 
             UndirectedEdge[14, 435] -> 
             RGBColor[
              0.431666942251965, 0.5483099419924558, 0.9487264137455738], 
             UndirectedEdge[282, 323] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[307, 337] -> 
             RGBColor[
              0.2284739170758735, 0.35747095130272755`, 0.9363226236293758], 
             UndirectedEdge[157, 356] -> 
             RGBColor[
              0.6546957163401086, 0.7278640901242467, 0.9677959060323847], 
             UndirectedEdge[166, 439] -> 
             RGBColor[
              0.2587408226547705, 0.38928338809880003`, 0.9380462791262197], 
             UndirectedEdge[266, 293] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[2, 260] -> 
             RGBColor[
              0.2568264909268206, 0.3869670959806497, 0.9379483993149236], 
             UndirectedEdge[135, 466] -> 
             RGBColor[
              0.21560127706368337`, 0.34394099047739907`, 0.935589545824046], 
             UndirectedEdge[60, 495] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[217, 464] -> 
             RGBColor[
              0.23458513566205164`, 0.3638942295104385, 0.936670648487121], 
             UndirectedEdge[435, 453] -> 
             RGBColor[
              0.4536708445200175, 0.5672446965945355, 0.9501627222939097], 
             UndirectedEdge[82, 411] -> 
             RGBColor[
              0.805124727752193, 0.7023163366231125, 0.604255553355253], 
             UndirectedEdge[94, 193] -> 
             RGBColor[
              0.18322775270743138`, 0.3099143637789815, 0.9337459215042947], 
             UndirectedEdge[88, 469] -> 
             RGBColor[
              0.20704962369398588`, 0.33495266057970696`, 0.9351025418156791],
              UndirectedEdge[36, 76] -> 
             RGBColor[
              0.8763277317102309, 0.4195224230366844, 0.31810785708846784`], 
             UndirectedEdge[163, 326] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[151, 472] -> 
             RGBColor[
              0.24137502669719502`, 0.37103083549233057`, 0.9370573227368286],
              UndirectedEdge[114, 138] -> 
             RGBColor[
              0.19260410669659306`, 0.3197695063167697, 0.9342798909929049], 
             UndirectedEdge[448, 475] -> 
             RGBColor[
              0.8832436442332238, 0.9095693592931984, 0.9828607433892947], 
             UndirectedEdge[169, 362] -> 
             RGBColor[
              0.19011638587642943`, 0.3171547540041677, 0.9341382189724496], 
             UndirectedEdge[20, 25] -> 
             RGBColor[
              0.6134743869641546, 0.6953197324267161, 0.9639211366967662], 
             UndirectedEdge[113, 349] -> 
             RGBColor[
              0.23074179114908483`, 0.35985463074519386`, 0.9364517757028261],
              UndirectedEdge[457, 494] -> 
             RGBColor[
              0.9630746438977319, 0.9212538232548773, 0.6116244787450666], 
             UndirectedEdge[364, 452] -> 
             RGBColor[
              0.34123924405804607`, 0.4681249538428697, 0.9430325833386572], 
             UndirectedEdge[351, 442] -> 
             RGBColor[
              0.4533007905792821, 0.5668798964178177, 0.9501513769419208], 
             UndirectedEdge[71, 466] -> 
             RGBColor[
              0.25381484638134433`, 0.3841058747104944, 0.937765752064777], 
             UndirectedEdge[87, 285] -> 
             RGBColor[
              0.5942823297173198, 0.6753028328289313, 0.9642423195147274], 
             UndirectedEdge[211, 369] -> 
             RGBColor[
              0.20403104555369495`, 0.33177994356535306`, 0.9349306382561757],
              UndirectedEdge[164, 316] -> 
             RGBColor[
              0.9332973532557916, 0.9359432710143458, 0.6941631548152802], 
             UndirectedEdge[27, 297] -> 
             RGBColor[
              0.2276449517133472, 0.3565996561472727, 0.9362754152783243], 
             UndirectedEdge[238, 483] -> 
             RGBColor[
              0.9539815750463821, 0.8506879917634884, 0.30563820376293704`], 
             UndirectedEdge[109, 164] -> 
             RGBColor[
              0.6056683283309234, 0.6842577010589471, 0.9653854185243207], 
             UndirectedEdge[83, 355] -> 
             RGBColor[
              0.8304768118928137, 0.23526370799810264`, 0.17681793552818148`],
              UndirectedEdge[85, 166] -> 
             RGBColor[
              0.23298059512902075`, 0.36220775567647745`, 0.9365792722774698],
              UndirectedEdge[34, 190] -> 
             RGBColor[
              0.32639172231009544`, 0.4570716814510417, 0.9420203527500528], 
             UndirectedEdge[232, 383] -> 
             RGBColor[
              0.6643189995648684, 0.7375398216536801, 0.9672796630870929], 
             UndirectedEdge[185, 441] -> 
             RGBColor[
              0.3444326919958216, 0.4727520189414878, 0.9431679244574711], 
             UndirectedEdge[83, 207] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[138, 385] -> 
             RGBColor[
              0.19286507142269105`, 0.32004379679001804`, 0.9342947525479934],
              UndirectedEdge[131, 234] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[80, 81] -> 
             RGBColor[
              0.7036249157342768, 0.7658688297445426, 0.9529221476556539], 
             UndirectedEdge[5, 486] -> 
             RGBColor[
              0.8762475134266291, 0.4193508442393725, 0.30937659196826445`], 
             UndirectedEdge[94, 139] -> 
             RGBColor[
              0.18683641908668117`, 0.31370730094623644`, 0.9339514297160496],
              UndirectedEdge[126, 249] -> 
             RGBColor[
              0.8563654629268306, 0.3487034608338446, 0.19818596167822738`], 
             UndirectedEdge[359, 483] -> 
             RGBColor[
              0.8686864922225178, 0.39450469054086185`, 0.22397142092169176`],
              UndirectedEdge[275, 404] -> 
             RGBColor[
              0.8560290549644465, 0.3473697153642996, 0.19791527993518332`], 
             UndirectedEdge[313, 391] -> 
             RGBColor[
              0.9652393266640114, 0.9163118855801125, 0.6014544021358288], 
             UndirectedEdge[1, 487] -> 
             RGBColor[
              0.25250692027805216`, 0.38273116144862973`, 0.9376912676080977],
              UndirectedEdge[71, 172] -> 
             RGBColor[
              0.3189558573582081, 0.44617450531270014`, 0.941709724101598], 
             UndirectedEdge[44, 494] -> 
             RGBColor[
              0.8343672336056607, 0.8708721866853958, 0.9536884301908661], 
             UndirectedEdge[85, 387] -> 
             RGBColor[
              0.2183544974781896, 0.34683479969730174`, 0.9357463376536275], 
             UndirectedEdge[414, 499] -> 
             RGBColor[
              0.8759899507757182, 0.41879994377265295`, 0.28134248690904895`],
              UndirectedEdge[89, 376] -> 
             RGBColor[
              0.9224099806388508, 0.9393657454586876, 0.9338012207586489], 
             UndirectedEdge[171, 403] -> 
             RGBColor[
              0.8633448747725185, 0.37637450305087206`, 0.2038017602771198], 
             UndirectedEdge[161, 279] -> 
             RGBColor[
              0.317893858956114, 0.449334448638412, 0.9414926732967325], 
             UndirectedEdge[149, 310] -> 
             RGBColor[
              0.8427485102135918, 0.3295893587840956, 0.1885693276990594], 
             UndirectedEdge[333, 367] -> 
             RGBColor[
              0.33758550933585824`, 0.46207597552121615`, 0.9429053788333501],
              UndirectedEdge[43, 227] -> 
             RGBColor[
              0.3207886255080345, 0.4459380263401525, 0.9418932895024263], 
             UndirectedEdge[71, 369] -> 
             RGBColor[
              0.22611899076607778`, 0.3549957744401804, 0.9361885140598343], 
             UndirectedEdge[134, 174] -> 
             RGBColor[
              0.2085506805802597, 0.33653036653968427`, 0.9351880247847377], 
             UndirectedEdge[158, 370] -> 
             RGBColor[
              0.31860057599581953`, 0.44346473230432215`, 0.9417750365635871],
              UndirectedEdge[7, 391] -> 
             RGBColor[
              0.9529922829593014, 0.8513370968664, 0.28103469133736275`], 
             UndirectedEdge[200, 228] -> 
             RGBColor[
              0.5875078389354265, 0.6760043564311329, 0.9606699156745733], 
             UndirectedEdge[201, 300] -> 
             RGBColor[
              0.49294744284977277`, 0.5982799912622034, 0.9534899138509028], 
             UndirectedEdge[210, 320] -> 
             RGBColor[
              0.21943490594638596`, 0.34797037749922943`, 0.9358078653175701],
              UndirectedEdge[69, 103] -> 
             RGBColor[
              0.9879088198511304, 0.969706918546636, 0.5069176030846314], 
             UndirectedEdge[97, 281] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[192, 272] -> 
             RGBColor[
              0.7182850173642144, 0.7790908357882066, 0.973243723195778], 
             UndirectedEdge[70, 463] -> 
             RGBColor[
              0.9027643566949051, 0.6383284302508672, 0.43357997062744724`], 
             UndirectedEdge[285, 477] -> 
             RGBColor[
              0.2972376680870329, 0.4273852429511985, 0.9403250568965202], 
             UndirectedEdge[10, 168] -> 
             RGBColor[
              0.5869322775232643, 0.6718097968709896, 0.962514131755837], 
             UndirectedEdge[298, 468] -> 
             RGBColor[
              0.5240878676490316, 0.621638460430029, 0.9567061435487108], 
             UndirectedEdge[37, 264] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[191, 405] -> 
             RGBColor[
              0.20994495191990925`, 0.33799583411956474`, 0.9352674264748911],
              UndirectedEdge[349, 380] -> 
             RGBColor[
              0.2108243720536846, 0.3389201604386196, 0.9353175081505242], 
             UndirectedEdge[94, 410] -> 
             RGBColor[
              0.18607999806105058`, 0.3129122544884356, 0.9339083526576646], 
             UndirectedEdge[335, 409] -> 
             RGBColor[
              0.42817878404725107`, 0.5428990333722734, 0.9491644164012382], 
             UndirectedEdge[168, 189] -> 
             RGBColor[
              0.6567597608942148, 0.7301160759368894, 0.967564374725217], 
             UndirectedEdge[187, 399] -> 
             RGBColor[
              0.3354088495669978, 0.4644637127266185, 0.9426102266869426], 
             UndirectedEdge[153, 314] -> 
             RGBColor[
              0.499609722940791, 0.6031382771170792, 0.9541664848189226], 
             UndirectedEdge[233, 355] -> 
             RGBColor[
              0.8304768118928137, 0.23526370799810264`, 0.17681793552818148`],
              UndirectedEdge[233, 486] -> 
             RGBColor[
              0.8762475134266291, 0.4193508442393725, 0.30937659196826445`], 
             UndirectedEdge[49, 264] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[205, 331] -> 
             RGBColor[
              0.6362772310192553, 0.7125979853621729, 0.9664940818172649], 
             UndirectedEdge[308, 456] -> 
             RGBColor[
              0.24065751204960906`, 0.3702766821046615, 0.9370164613391165], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.5070562614150484, 0.6082812369647475, 0.955030602440464], 
             UndirectedEdge[175, 371] -> 
             RGBColor[
              0.7707283648406607, 0.8174771789318643, 0.846586686476931], 
             UndirectedEdge[21, 188] -> 
             RGBColor[
              0.6011373252613197, 0.6823506284279337, 0.9641679618962959], 
             UndirectedEdge[79, 221] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[158, 193] -> 
             RGBColor[
              0.21075328698888462`, 0.3388454455284614, 0.9353134599612447], 
             UndirectedEdge[266, 483] -> 
             RGBColor[
              0.8686864922225178, 0.39450469054086185`, 0.22397142092169176`],
              UndirectedEdge[290, 484] -> 
             RGBColor[
              0.19720039887588448`, 0.3246005008189609, 0.9345416430329105], 
             UndirectedEdge[153, 411] -> 
             RGBColor[
              0.5550733306542569, 0.6470945833278928, 0.9592654071859543], 
             UndirectedEdge[176, 475] -> 
             RGBColor[
              0.9130266424173684, 0.933317513607286, 0.9857014723436948], 
             UndirectedEdge[20, 474] -> 
             RGBColor[
              0.4380905408797232, 0.5534386308253174, 0.9492559418043877], 
             UndirectedEdge[70, 483] -> 
             RGBColor[
              0.9784993022017803, 0.9517819287687919, 0.6160830557918804], 
             UndirectedEdge[163, 266] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[69, 486] -> 
             RGBColor[
              0.9877626572953866, 0.9693942916192012, 0.4910087109026512], 
             UndirectedEdge[262, 475] -> 
             RGBColor[
              0.947054964942194, 0.9600342600602023, 0.974506313462872], 
             UndirectedEdge[18, 167] -> 
             RGBColor[
              0.6058193984674288, 0.6891575673803969, 0.9632826137877326], 
             UndirectedEdge[281, 374] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[138, 294] -> 
             RGBColor[
              0.20565089555954957`, 0.33348250862592854`, 0.9350228863176557],
              UndirectedEdge[291, 349] -> 
             RGBColor[
              0.20137038883349692`, 0.32898342465704544`, 0.9347791177920493],
              UndirectedEdge[288, 455] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[12, 459] -> 
             RGBColor[
              0.24496381986437168`, 0.3748028846536623, 0.9372616991985556], 
             UndirectedEdge[93, 305] -> 
             RGBColor[
              0.6178108662440276, 0.6954235689523357, 0.9658605386388516], 
             UndirectedEdge[127, 184] -> 
             RGBColor[
              0.8369837657282427, 0.2665011316422593, 0.18231370738115665`], 
             UndirectedEdge[204, 431] -> 
             RGBColor[
              0.9368455281102752, 0.9478707558976731, 0.7583898546015062], 
             UndirectedEdge[397, 495] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[28, 493] -> 
             RGBColor[
              0.7693865610991708, 0.7571955764379148, 0.6194549024922544], 
             UndirectedEdge[267, 485] -> 
             RGBColor[
              0.48008856319913695`, 0.5875010981158637, 0.9525714137946194], 
             UndirectedEdge[110, 494] -> 
             RGBColor[
              0.9815895459724128, 0.9829117035784583, 0.7513422215789181], 
             UndirectedEdge[337, 500] -> 
             RGBColor[
              0.24832221794915155`, 0.378332773975503, 0.9374529550011792], 
             UndirectedEdge[43, 393] -> 
             RGBColor[
              0.3844301868161192, 0.5073958386222868, 0.9457165294590244], 
             UndirectedEdge[167, 432] -> 
             RGBColor[
              0.6144232863868914, 0.6958789900150512, 0.9641401689276407], 
             UndirectedEdge[230, 474] -> 
             RGBColor[
              0.3509721735960423, 0.4771550791306852, 0.9436307898604598], 
             UndirectedEdge[40, 421] -> 
             RGBColor[
              0.20367675973790192`, 0.33140756670993643`, 0.9349104622030852],
              UndirectedEdge[254, 476] -> 
             RGBColor[
              0.217706390843879, 0.3461535985323073, 0.9357094289395913], 
             UndirectedEdge[107, 197] -> 
             RGBColor[
              0.36643102917791126`, 0.4918058729400383, 0.9445696390503481], 
             UndirectedEdge[231, 395] -> 
             RGBColor[
              0.8502020870562027, 0.32426772933006165`, 0.19322676477969444`],
              UndirectedEdge[420, 427] -> 
             RGBColor[
              0.21490485900541903`, 0.34320901094270806`, 0.9355498858458859],
              UndirectedEdge[317, 374] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[188, 200] -> 
             RGBColor[
              0.49135529375587494`, 0.5959601817284621, 0.9536484010759594], 
             UndirectedEdge[84, 260] -> 
             RGBColor[
              0.49539379554658625`, 0.5968284122357694, 0.9548594497480263], 
             UndirectedEdge[33, 160] -> 
             RGBColor[
              0.507621153600386, 0.6111487464219849, 0.9543809431704284], 
             UndirectedEdge[135, 362] -> 
             RGBColor[
              0.18189649677046751`, 0.30851512938273096`, 0.9336701084481014],
              UndirectedEdge[123, 193] -> 
             RGBColor[
              0.19813056518650046`, 0.32557816458736866`, 0.9345946146282424],
              UndirectedEdge[439, 453] -> 
             RGBColor[
              0.3621326688136605, 0.48404222467833025`, 0.9444734004370379], 
             UndirectedEdge[269, 282] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[202, 459] -> 
             RGBColor[
              0.22929497216797767`, 0.3583339322624286, 0.9363693815022289], 
             UndirectedEdge[25, 474] -> 
             RGBColor[
              0.5822221813019526, 0.6686857521026937, 0.9618095517527927], 
             UndirectedEdge[103, 259] -> 
             RGBColor[
              0.8763449551304583, 0.4195592621909958, 0.3199825200895846], 
             UndirectedEdge[352, 375] -> 
             RGBColor[
              0.23983670688281394`, 0.3694139638323065, 0.93696971769914], 
             UndirectedEdge[300, 308] -> 
             RGBColor[
              0.3243148840719937, 0.448094421570078, 0.9421508550979786], 
             UndirectedEdge[32, 328] -> 
             RGBColor[
              0.41834081037995485`, 0.5361231031395549, 0.9480553376981994], 
             UndirectedEdge[209, 486] -> 
             RGBColor[
              0.8762475134266291, 0.4193508442393725, 0.30937659196826445`], 
             UndirectedEdge[118, 496] -> 
             RGBColor[
              0.22237308988837995`, 0.35105859511388676`, 0.9359751905464131],
              UndirectedEdge[31, 405] -> 
             RGBColor[
              0.21292656027884266`, 0.3411296935496924, 0.9354372246600381], 
             UndirectedEdge[21, 228] -> 
             RGBColor[
              0.6972898704408712, 0.7623948031306045, 0.9711894764949098], 
             UndirectedEdge[92, 250] -> 
             RGBColor[
              0.5085778888955018, 0.6091430188143863, 0.955320634245421], 
             UndirectedEdge[177, 290] -> 
             RGBColor[
              0.19627542028787323`, 0.3236282896759313, 0.9344889668707066], 
             UndirectedEdge[9, 333] -> 
             RGBColor[
              0.3303539220460226, 0.4544751187704825, 0.9424935506353687], 
             UndirectedEdge[11, 444] -> 
             RGBColor[
              0.8965218183778059, 0.5918677305070236, 0.41658702852886603`], 
             UndirectedEdge[11, 25] -> 
             RGBColor[
              0.8725548505464009, 0.8998336579439141, 0.9166173714965022], 
             UndirectedEdge[168, 338] -> 
             RGBColor[
              0.8866500342923964, 0.9079974694670752, 0.7396483248536112], 
             UndirectedEdge[283, 430] -> 
             RGBColor[
              0.23496674652323896`, 0.3642953267210725, 0.9366923806611228], 
             UndirectedEdge[139, 410] -> 
             RGBColor[
              0.1939894171477317, 0.3212255554346721, 0.9343587823737141], 
             UndirectedEdge[195, 260] -> 
             RGBColor[
              0.2652269236159478, 0.3957964833551174, 0.9384267915292429], 
             UndirectedEdge[391, 407] -> 
             RGBColor[
              0.8204042342330249, 0.8029780971899061, 0.6251186758041836], 
             UndirectedEdge[33, 111] -> 
             RGBColor[
              0.7724584371268222, 0.8209274086540813, 0.9322402963389583], 
             UndirectedEdge[2, 114] -> 
             RGBColor[
              0.19567198478119446`, 0.322994040698391, 0.934454602111304], 
             UndirectedEdge[101, 306] -> 
             RGBColor[
              0.4767634885101116, 0.5860971037797296, 0.9519517147391703], 
             UndirectedEdge[264, 374] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[172, 235] -> 
             RGBColor[
              0.36266490816744634`, 0.48854384821151947`, 0.9443296651498113],
              UndirectedEdge[84, 475] -> 
             RGBColor[
              0.810505150868455, 0.8527111902970119, 0.9756199536816843], 
             UndirectedEdge[37, 397] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[228, 287] -> 
             RGBColor[
              0.7052588333133122, 0.7687490378133541, 0.9719495632876605], 
             UndirectedEdge[68, 375] -> 
             RGBColor[
              0.24422058989824297`, 0.3740217028357595, 0.9372193733514949], 
             UndirectedEdge[197, 236] -> 
             RGBColor[
              0.3595830595921312, 0.48559353377690795`, 0.9441435802486068], 
             UndirectedEdge[107, 214] -> 
             RGBColor[
              0.26772635198284234`, 0.39774243808019455`, 0.9385940687930483],
              UndirectedEdge[207, 317] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[98, 462] -> 
             RGBColor[
              0.22311090923146282`, 0.35183409002391514`, 0.9360172082664957],
              UndirectedEdge[21, 59] -> 
             RGBColor[
              0.7122788416336581, 0.774563525190366, 0.9723694632136166], 
             UndirectedEdge[46, 350] -> 
             RGBColor[
              0.23789809529541878`, 0.3673763601388803, 0.9368593166371566], 
             UndirectedEdge[271, 429] -> 
             RGBColor[
              0.26979559865762076`, 0.4009026585910771, 0.9386758322655065], 
             UndirectedEdge[304, 423] -> 
             RGBColor[
              0.20489033009065757`, 0.3326831060954871, 0.9349795732393582], 
             UndirectedEdge[299, 328] -> 
             RGBColor[
              0.4679150294921883, 0.5789135261304432, 0.9512551316323059], 
             UndirectedEdge[55, 73] -> 
             RGBColor[
              0.8427635790747743, 0.32970518465436127`, 0.1885837576575456], 
             UndirectedEdge[53, 440] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[206, 377] -> 
             RGBColor[
              0.18614606825835553`, 0.31298169845489565`, 0.9339121152576589],
              UndirectedEdge[39, 113] -> 
             RGBColor[
              0.3807447522810758, 0.4978573418320051, 0.9460564917517937], 
             UndirectedEdge[9, 450] -> 
             RGBColor[
              0.29135013033172863`, 0.4206919947751334, 0.9400082635170326], 
             UndirectedEdge[61, 321] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[76, 460] -> 
             RGBColor[
              0.9094586655152967, 0.9266343620675013, 0.8045085958817066], 
             UndirectedEdge[141, 167] -> 
             RGBColor[
              0.3793212150967632, 0.5021589457762018, 0.945447668704877], 
             UndirectedEdge[29, 476] -> 
             RGBColor[
              0.20047610231188778`, 0.3280434728217939, 0.934728189497622], 
             UndirectedEdge[39, 190] -> 
             RGBColor[
              0.4252781198584057, 0.5413476432340834, 0.948714056123109], 
             UndirectedEdge[115, 215] -> 
             RGBColor[
              0.21789975830007355`, 0.3463568399889726, 0.93572044093016], 
             UndirectedEdge[208, 471] -> 
             RGBColor[
              0.8758809832712207, 0.41856687329883735`, 0.26948204651397445`],
              UndirectedEdge[139, 401] -> 
             RGBColor[
              0.19071386475739358`, 0.31778274219041003`, 0.9341722445108298],
              UndirectedEdge[34, 356] -> 
             RGBColor[
              0.3999124124412533, 0.519710408653627, 0.9469927125910187], 
             UndirectedEdge[288, 313] -> 
             RGBColor[
              0.8708575836519874, 0.41710611796942054`, 0.41689029682654455`],
              UndirectedEdge[66, 334] -> 
             RGBColor[
              0.2368272907421635, 0.366250876660479, 0.936798335901962], 
             UndirectedEdge[17, 328] -> 
             RGBColor[
              0.732255951190426, 0.7877066954338351, 0.9047236192749173], 
             UndirectedEdge[318, 459] -> 
             RGBColor[
              0.2534614196461127, 0.38373440080321664`, 0.9377456249350535], 
             UndirectedEdge[163, 233] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[141, 300] -> 
             RGBColor[
              0.3596463325015217, 0.4852300140127269, 0.9441629288178462], 
             UndirectedEdge[354, 436] -> 
             RGBColor[
              0.9158079140362867, 0.9348276004615428, 0.9614329967335975], 
             UndirectedEdge[29, 290] -> 
             RGBColor[
              0.1963765780341108, 0.3237346128809986, 0.9344947276547053], 
             UndirectedEdge[110, 360] -> 
             RGBColor[
              0.8797081782083205, 0.4465238726729873, 0.3015501277947058], 
             UndirectedEdge[289, 308] -> 
             RGBColor[
              0.2720506530758039, 0.4028257715578081, 0.9388206245143462], 
             UndirectedEdge[264, 324] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[109, 382] -> 
             RGBColor[
              0.3269168850214242, 0.4575807073103212, 0.9420518327256824], 
             UndirectedEdge[293, 497] -> 
             RGBColor[
              0.8604026869949277, 0.3647097089386806, 0.20143440692924686`], 
             UndirectedEdge[160, 237] -> 
             RGBColor[
              0.43894866011146105`, 0.554575099007605, 0.9492019757411265], 
             UndirectedEdge[35, 123] -> 
             RGBColor[
              0.21261512288870693`, 0.34080235310638873`, 0.9354194887614002],
              UndirectedEdge[218, 432] -> 
             RGBColor[
              0.7556020055170689, 0.8090012965886532, 0.976275004473887], 
             UndirectedEdge[46, 476] -> 
             RGBColor[
              0.24200254037507565`, 0.3716903921544483, 0.9370930587124607], 
             UndirectedEdge[288, 391] -> 
             RGBColor[
              0.8623939674573535, 0.3726044724173211, 0.20303663793067456`], 
             UndirectedEdge[259, 486] -> 
             RGBColor[
              0.8762475134266291, 0.4193508442393725, 0.30937659196826445`], 
             UndirectedEdge[138, 296] -> 
             RGBColor[
              0.19431619519816343`, 0.32156901988460085`, 0.9343773919002614],
              UndirectedEdge[56, 494] -> 
             RGBColor[
              0.9820130064078103, 0.9838174426313561, 0.7974332766770647], 
             UndirectedEdge[91, 200] -> 
             RGBColor[
              0.7833150865244253, 0.7895065812204456, 0.6386298521015412], 
             UndirectedEdge[172, 493] -> 
             RGBColor[
              0.48369856139811684`, 0.5896809842908348, 0.9530630745214885], 
             UndirectedEdge[340, 461] -> 
             RGBColor[
              0.7616084201779264, 0.8122712266275236, 0.9364981125310801], 
             UndirectedEdge[33, 274] -> 
             RGBColor[
              0.5221594485499271, 0.6229515892047461, 0.9555254510043854], 
             UndirectedEdge[235, 345] -> 
             RGBColor[
              0.28881156407072495`, 0.4173180031065188, 0.9398895386305561], 
             UndirectedEdge[205, 490] -> 
             RGBColor[
              0.3934599047158681, 0.5152169264202315, 0.9462918950989305], 
             UndirectedEdge[141, 284] -> 
             RGBColor[
              0.3001512154255292, 0.4328083364714148, 0.9404045397333283], 
             UndirectedEdge[489, 500] -> 
             RGBColor[
              0.2537822164718525, 0.3840715786067627, 0.937763893839703], 
             UndirectedEdge[155, 198] -> 
             RGBColor[
              0.21872927125490338`, 0.3472287106986578, 0.9357676804657832], 
             UndirectedEdge[23, 157] -> 
             RGBColor[
              0.9051450162162533, 0.9220177033851362, 0.7071961713842101], 
             UndirectedEdge[248, 344] -> 
             RGBColor[
              0.20626837332895714`, 0.33413151691192766`, 0.935058050763147], 
             UndirectedEdge[50, 131] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[442, 500] -> 
             RGBColor[
              0.3605233719937942, 0.48347254608803236`, 0.9443109769258367], 
             UndirectedEdge[18, 305] -> 
             RGBColor[
              0.8079904168689416, 0.8502655206247263, 0.9814068971986999], 
             UndirectedEdge[134, 278] -> 
             RGBColor[
              0.20206125527400282`, 0.32970956908947946`, 0.9348184616137908],
              UndirectedEdge[158, 422] -> 
             RGBColor[
              0.2659242990306929, 0.3968336772286028, 0.9384553674788276], 
             UndirectedEdge[229, 393] -> 
             RGBColor[
              0.39995355652495146`, 0.5208414012368296, 0.9467056648500944], 
             UndirectedEdge[17, 143] -> 
             RGBColor[
              0.8872780979527313, 0.5209207267878847, 0.40798658666713394`], 
             UndirectedEdge[53, 83] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[166, 239] -> 
             RGBColor[
              0.2531713208719759, 0.3834294885982743, 0.9377291042390291], 
             UndirectedEdge[46, 194] -> 
             RGBColor[
              0.24776813306148654`, 0.3777503956275562, 0.9374214006865218], 
             UndirectedEdge[319, 368] -> 
             RGBColor[
              0.18375299049976135`, 0.3104664220007197, 0.9337758330195483], 
             UndirectedEdge[51, 360] -> 
             RGBColor[
              0.8191009627097754, 0.1478239462483719, 0.1659244095033199], 
             UndirectedEdge[132, 250] -> 
             RGBColor[
              0.5096842240418256, 0.610007296239153, 0.9554309033935169], 
             UndirectedEdge[80, 447] -> 
             RGBColor[
              0.6925262053653484, 0.7562556846603798, 0.95221494764515], 
             UndirectedEdge[128, 179] -> 
             RGBColor[
              0.25756930059010474`, 0.38805204413004735`, 0.9379795626777485],
              UndirectedEdge[218, 300] -> 
             RGBColor[
              0.5789637496600913, 0.6666189664761881, 0.9612821622327556], 
             UndirectedEdge[130, 241] -> 
             RGBColor[
              0.5867161645318493, 0.6694746929690595, 0.9634263183495637], 
             UndirectedEdge[134, 252] -> 
             RGBColor[
              0.19741515137734375`, 0.3248262193140896, 0.9345538728701708], 
             UndirectedEdge[266, 317] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[156, 485] -> 
             RGBColor[
              0.4108308926568273, 0.5236624055476755, 0.9482993868107825], 
             UndirectedEdge[96, 110] -> 
             RGBColor[
              0.9745488280148329, 0.9248169273650014, 0.4244348962647706], 
             UndirectedEdge[50, 373] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[37, 322] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[65, 290] -> 
             RGBColor[
              0.1936841951962548, 0.32090474781148043`, 0.9343414004351128], 
             UndirectedEdge[333, 450] -> 
             RGBColor[
              0.3787463461307482, 0.5024727814987578, 0.9453543601565757], 
             UndirectedEdge[238, 266] -> 
             RGBColor[
              0.857059891141737, 0.3514566373014637, 0.19874471492026624`], 
             UndirectedEdge[312, 446] -> 
             RGBColor[
              0.22312621565382923`, 0.3518501780443054, 0.9360180799446056], 
             UndirectedEdge[407, 448] -> 
             RGBColor[
              0.7562464361257435, 0.809539035824608, 0.9763301317632911], 
             UndirectedEdge[14, 454] -> 
             RGBColor[
              0.36689237882404113`, 0.4922054708154086, 0.9445990358418439], 
             UndirectedEdge[77, 473] -> 
             RGBColor[
              0.7727967287954887, 0.8227535996492561, 0.9749073638024577], 
             UndirectedEdge[57, 136] -> 
             RGBColor[
              0.8413736303622167, 0.28643448166620133`, 0.18597671803717333`],
              UndirectedEdge[364, 487] -> 
             RGBColor[
              0.2635219558175418, 0.39430866219422384`, 0.938318557586787], 
             UndirectedEdge[80, 403] -> 
             RGBColor[
              0.8642091954046907, 0.41214776090032323`, 0.42814428395185355`],
              UndirectedEdge[330, 352] -> 
             RGBColor[
              0.21148900295996179`, 0.33961872966115025`, 0.9353553578974033],
              UndirectedEdge[239, 272] -> 
             RGBColor[
              0.41080937826280917`, 0.5222278432198632, 0.9484266860084449], 
             UndirectedEdge[53, 97] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[304, 311] -> 
             RGBColor[
              0.22811784161362691`, 0.3570966934154181, 0.9363023456585673], 
             UndirectedEdge[237, 241] -> 
             RGBColor[
              0.3816373640692611, 0.5049768359303111, 0.9455385732631909], 
             UndirectedEdge[361, 441] -> 
             RGBColor[
              0.38894854463624445`, 0.5113094130668121, 0.9460044352238959], 
             UndirectedEdge[276, 347] -> 
             RGBColor[
              0.3067228826426153, 0.4377048288177037, 0.9408524097411209], 
             UndirectedEdge[11, 180] -> 
             RGBColor[
              0.7955000612132693, 0.8390425461583731, 0.9093442969764326], 
             UndirectedEdge[56, 360] -> 
             RGBColor[
              0.8799904851652522, 0.44712769870825264`, 0.3322774978601368], 
             UndirectedEdge[15, 269] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[8, 387] -> 
             RGBColor[
              0.24035919758229748`, 0.3699631346852874, 0.9369994727715198], 
             UndirectedEdge[139, 278] -> 
             RGBColor[
              0.19876192054719527`, 0.32624175910170083`, 0.9346305693820274],
              UndirectedEdge[15, 449] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[348, 355] -> 
             RGBColor[
              0.8921067382753032, 0.5870113175771698, 0.237923296232169], 
             UndirectedEdge[173, 499] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[130, 483] -> 
             RGBColor[
              0.9023076079882126, 0.8925450795893294, 0.6637151097464145], 
             UndirectedEdge[173, 282] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[84, 244] -> 
             RGBColor[
              0.8279818714648165, 0.8418796258010216, 0.6672951219910502], 
             UndirectedEdge[183, 279] -> 
             RGBColor[
              0.28035477682361865`, 0.41200102433410457`, 0.9392771618411558],
              UndirectedEdge[124, 381] -> 
             RGBColor[
              0.21298610699007461`, 0.34119228091867676`, 0.9354406157571513],
              UndirectedEdge[81, 213] -> 
             RGBColor[
              0.3642555391877909, 0.48719454314839994`, 0.9445308686680915], 
             UndirectedEdge[134, 210] -> 
             RGBColor[
              0.22588078399928613`, 0.3547454040251011, 0.9361749485368607], 
             UndirectedEdge[103, 275] -> 
             RGBColor[
              0.963923015142357, 0.882139466332943, 0.4484107000371519], 
             UndirectedEdge[256, 298] -> 
             RGBColor[
              0.7725153841740422, 0.8225801022129446, 0.9778636612646125], 
             UndirectedEdge[18, 235] -> 
             RGBColor[
              0.5507776223875409, 0.6415956100722736, 0.9597443267215762], 
             UndirectedEdge[255, 334] -> 
             RGBColor[
              0.23529404619959324`, 0.3646393394329189, 0.9367110198934947], 
             UndirectedEdge[209, 372] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[112, 238] -> 
             RGBColor[
              0.857059891141737, 0.3514566373014637, 0.19874471492026624`], 
             UndirectedEdge[360, 457] -> 
             RGBColor[
              0.8673649101585332, 0.4054186191239333, 0.2084049659054714], 
             UndirectedEdge[233, 404] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[259, 348] -> 
             RGBColor[
              0.8657911144896757, 0.38473790158096455`, 0.21272342517580606`],
              UndirectedEdge[244, 376] -> 
             RGBColor[
              0.9816204164865794, 0.9616423487915396, 0.6235919701345964], 
             UndirectedEdge[182, 371] -> 
             RGBColor[
              0.7505720549654683, 0.8042082232990024, 0.9596831026196062], 
             UndirectedEdge[21, 77] -> 
             RGBColor[
              0.8806391477680734, 0.9075693815160031, 0.9852742312191726], 
             UndirectedEdge[153, 493] -> 
             RGBColor[
              0.4936405223165552, 0.5982922111409009, 0.9536965674798805], 
             UndirectedEdge[276, 382] -> 
             RGBColor[
              0.3268271732727834, 0.45750300350269213`, 0.9420461163723881], 
             UndirectedEdge[80, 219] -> 
             RGBColor[
              0.8642091954046907, 0.41214776090032323`, 0.42814428395185355`],
              UndirectedEdge[60, 136] -> 
             RGBColor[
              0.8413736303622167, 0.28643448166620133`, 0.18597671803717333`],
              UndirectedEdge[23, 96] -> 
             RGBColor[
              0.9739330346591857, 0.9234998076435308, 0.35740958973864884`], 
             UndirectedEdge[53, 281] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[141, 162] -> 
             RGBColor[
              0.24952923123188117`, 0.3796014214647141, 0.9375216926220145], 
             UndirectedEdge[28, 149] -> 
             RGBColor[
              0.8867519951374654, 0.5638187600065572, 0.2265258256323685], 
             UndirectedEdge[37, 317] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[372, 486] -> 
             RGBColor[
              0.8762475134266291, 0.4193508442393725, 0.30937659196826445`], 
             UndirectedEdge[63, 453] -> 
             RGBColor[
              0.37845988554305304`, 0.5012031646662531, 0.9454032112758242], 
             UndirectedEdge[82, 242] -> 
             RGBColor[
              0.844192723800754, 0.2992353265545988, 0.18832903870459236`], 
             UndirectedEdge[4, 191] -> 
             RGBColor[
              0.20962796174465825`, 0.33766265734703804`, 0.9352493743533555],
              UndirectedEdge[70, 403] -> 
             RGBColor[
              0.8734050425786691, 0.4188525953049994, 0.40570794960622847`], 
             UndirectedEdge[144, 458] -> 
             RGBColor[
              0.35435270940186414`, 0.4764909843730204, 0.9439777206363321], 
             UndirectedEdge[16, 224] -> 
             RGBColor[
              0.4710966513554297, 0.5758880395117242, 0.9527849389967913], 
             UndirectedEdge[40, 206] -> 
             RGBColor[
              0.19522868075367328`, 0.3225281000583675, 0.9344293566027462], 
             UndirectedEdge[148, 485] -> 
             RGBColor[
              0.6140670521379212, 0.6970882935898717, 0.9630875849906602], 
             UndirectedEdge[34, 291] -> 
             RGBColor[
              0.25248695241717767`, 0.3827101739608151, 0.9376901304679608], 
             UndirectedEdge[222, 339] -> 
             RGBColor[
              0.22078402621432447`, 0.3493883884399983, 0.9358846957209846], 
             UndirectedEdge[197, 314] -> 
             RGBColor[
              0.5074205711230394, 0.6099036412278982, 0.9546641851582337], 
             UndirectedEdge[330, 358] -> 
             RGBColor[
              0.30472186221443454`, 0.43059675941998354`, 0.9409217073976809],
              UndirectedEdge[312, 415] -> 
             RGBColor[
              0.21664775986789828`, 0.3450409102554709, 0.9356491414716133], 
             UndirectedEdge[370, 443] -> 
             RGBColor[
              0.5772962329349696, 0.6646840201911736, 0.9613835661875354], 
             UndirectedEdge[160, 305] -> 
             RGBColor[
              0.6583315658837037, 0.7304786613456766, 0.96845405916136], 
             UndirectedEdge[266, 343] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[47, 468] -> 
             RGBColor[
              0.5415362336412717, 0.63526925655566, 0.9584452336065665], 
             UndirectedEdge[388, 436] -> 
             RGBColor[
              0.9470100510372832, 0.9597073375466911, 0.9644090844152291], 
             UndirectedEdge[69, 209] -> 
             RGBColor[
              0.8720195914369621, 0.405748016840095, 0.23691988196683633`], 
             UndirectedEdge[197, 470] -> 
             RGBColor[
              0.32997863152241563`, 0.4544774028464852, 0.942457651865863], 
             UndirectedEdge[13, 298] -> 
             RGBColor[
              0.6096447166347696, 0.6934029640170689, 0.9628044481530396], 
             UndirectedEdge[168, 383] -> 
             RGBColor[
              0.7063203821054702, 0.7703516209167286, 0.9714659683735043], 
             UndirectedEdge[123, 428] -> 
             RGBColor[
              0.21288413127934025`, 0.34108509798106146`, 0.9354348083912845],
              UndirectedEdge[137, 485] -> 
             RGBColor[
              0.43787204087877396`, 0.550935268346073, 0.9498814143229708], 
             UndirectedEdge[394, 467] -> 
             RGBColor[
              0.2149961156174362, 0.3433049274279415, 0.9355550827749383], 
             UndirectedEdge[232, 395] -> 
             RGBColor[
              0.806035818091638, 0.7335348511120112, 0.6107945156854029], 
             UndirectedEdge[414, 461] -> 
             RGBColor[
              0.7674485024465632, 0.8134259226299666, 0.7363222999185557], 
             UndirectedEdge[224, 333] -> 
             RGBColor[
              0.3565055136813881, 0.481962099685929, 0.9439828450911899], 
             UndirectedEdge[33, 182] -> 
             RGBColor[
              0.75743790360309, 0.8097822285259801, 0.9602236073747921], 
             UndirectedEdge[158, 451] -> 
             RGBColor[
              0.26279404048911603`, 0.39354357703155085`, 0.9382771038856873],
              UndirectedEdge[235, 274] -> 
             RGBColor[
              0.415657066351844, 0.5336115935759853, 0.9479359965181933], 
             UndirectedEdge[284, 345] -> 
             RGBColor[
              0.2646833404793789, 0.39552935110985515`, 0.9383846967251639], 
             UndirectedEdge[70, 238] -> 
             RGBColor[
              0.9610594005806091, 0.8872098489096947, 0.5782429967897421], 
             UndirectedEdge[21, 55] -> 
             RGBColor[
              0.8365288820965593, 0.5120560542024203, 0.4540089567270905], 
             UndirectedEdge[55, 60] -> 
             RGBColor[
              0.8349696694427251, 0.26979777990945364`, 0.18112030099193344`],
              UndirectedEdge[219, 258] -> 
             RGBColor[
              0.8761965593307338, 0.4192418585805019, 0.3038305530822916], 
             UndirectedEdge[175, 463] -> 
             RGBColor[
              0.9058410813145757, 0.6396007349493169, 0.38259068137142616`], 
             UndirectedEdge[101, 431] -> 
             RGBColor[
              0.7419137193030552, 0.7927733536547152, 0.740681887591113], 
             UndirectedEdge[14, 213] -> 
             RGBColor[
              0.34656244604435504`, 0.47186967514827405`, 0.9434034804183797],
              UndirectedEdge[378, 487] -> 
             RGBColor[
              0.26906193462506856`, 0.40013153117587835`, 0.9386340511842113],
              UndirectedEdge[8, 159] -> 
             RGBColor[
              0.3390979651454099, 0.46352019337297634`, 0.9429968372905502], 
             UndirectedEdge[311, 469] -> 
             RGBColor[
              0.2079662974981772, 0.3359161428683881, 0.9351547450327304], 
             UndirectedEdge[343, 440] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[371, 460] -> 
             RGBColor[
              0.6856107819931014, 0.7528945564391651, 0.9702915062006248], 
             UndirectedEdge[224, 358] -> 
             RGBColor[
              0.33994340240143384`, 0.4676168313311497, 0.9429275220057312], 
             UndirectedEdge[455, 475] -> 
             RGBColor[
              0.85896566076965, 0.4082371413550099, 0.4370202203561169], 
             UndirectedEdge[310, 408] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[154, 376] -> 
             RGBColor[
              0.8735554698238286, 0.4189148008366767, 0.4032149808607035], 
             UndirectedEdge[282, 499] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[14, 192] -> 
             RGBColor[
              0.6420349038642188, 0.7161165631440682, 0.9675369541888443], 
             UndirectedEdge[75, 147] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[175, 351] -> 
             RGBColor[
              0.7271599458905001, 0.7821063736932174, 0.8431568209407971], 
             UndirectedEdge[109, 205] -> 
             RGBColor[
              0.3878666627433047, 0.5103723413481127, 0.9459354986663484], 
             UndirectedEdge[43, 148] -> 
             RGBColor[
              0.5374554379217633, 0.6334803821671271, 0.957446343497947], 
             UndirectedEdge[56, 92] -> 
             RGBColor[
              0.8261574713547348, 0.8617230188259255, 0.8123362096117437], 
             UndirectedEdge[46, 412] -> 
             RGBColor[
              0.25670322812195334`, 0.3871417470538542, 0.9379302411319268], 
             UndirectedEdge[170, 214] -> 
             RGBColor[
              0.2164586672192998, 0.34484216189262756`, 0.9356383729250132], 
             UndirectedEdge[94, 437] -> 
             RGBColor[
              0.18537229810347358`, 0.3121684169622533, 0.9338680501920288], 
             UndirectedEdge[173, 249] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[181, 302] -> 
             RGBColor[
              0.4379250644031646, 0.5527838013368829, 0.9493867273387744], 
             UndirectedEdge[188, 279] -> 
             RGBColor[
              0.34218136725328896`, 0.47037106759976377`, 0.9430402518488281],
              UndirectedEdge[317, 471] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[8, 344] -> 
             RGBColor[
              0.2433422473968615, 0.3730985091766764, 0.9371693530454325], 
             UndirectedEdge[236, 493] -> 
             RGBColor[
              0.4475753565200481, 0.558111907733633, 0.9507716236139967], 
             UndirectedEdge[31, 366] -> 
             RGBColor[
              0.21485978318177745`, 0.34316163339408845`, 0.9355473188444132],
              UndirectedEdge[176, 261] -> 
             RGBColor[
              0.9050998994190445, 0.9271661077872047, 0.9908104304704488], 
             UndirectedEdge[144, 145] -> 
             RGBColor[
              0.28245593278256786`, 0.4142094724679425, 0.9393968195646363], 
             UndirectedEdge[144, 375] -> 
             RGBColor[
              0.2688835490281597, 0.3999440366032271, 0.9386238923883652], 
             UndirectedEdge[258, 293] -> 
             RGBColor[
              0.8761965593307338, 0.419241858580502, 0.3038305530822916], 
             UndirectedEdge[242, 269] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[45, 216] -> 
             RGBColor[
              0.27205173985217523`, 0.40327400603416763`, 0.9388043161688746],
              UndirectedEdge[82, 323] -> 
             RGBColor[
              0.844192723800754, 0.2992353265545988, 0.18832903870459236`], 
             UndirectedEdge[258, 272] -> 
             RGBColor[
              0.7801629819799012, 0.8241593809088232, 0.7710309321085329], 
             UndirectedEdge[92, 356] -> 
             RGBColor[
              0.5746689176875454, 0.6653465467906676, 0.9598195826356501], 
             UndirectedEdge[114, 327] -> 
             RGBColor[
              0.19477749179217513`, 0.32205387185280054`, 0.9344036620588632],
              UndirectedEdge[188, 459] -> 
             RGBColor[
              0.3130997116438481, 0.4398044036707781, 0.9413840945843246], 
             UndirectedEdge[465, 469] -> 
             RGBColor[
              0.1844144384363928, 0.3111616457203408, 0.9338135015010149], 
             UndirectedEdge[44, 62] -> 
             RGBColor[
              0.6139390302142435, 0.6965893567419654, 0.9633475722642448], 
             UndirectedEdge[88, 337] -> 
             RGBColor[
              0.22370546244709866`, 0.3524590031503995, 0.9360510671925635], 
             UndirectedEdge[253, 388] -> 
             RGBColor[
              0.9562289934034156, 0.9659272848069381, 0.9194480770482338], 
             UndirectedEdge[80, 238] -> 
             RGBColor[
              0.9472656298196414, 0.8771525973026804, 0.6118974983081796], 
             UndirectedEdge[171, 272] -> 
             RGBColor[
              0.7608854551425784, 0.7598583476143784, 0.6209877429007751], 
             UndirectedEdge[297, 392] -> 
             RGBColor[
              0.3456632797932826, 0.4683209837324499, 0.943447605171511], 
             UndirectedEdge[82, 499] -> 
             RGBColor[
              0.844192723800754, 0.2992353265545988, 0.18832903870459236`], 
             UndirectedEdge[297, 484] -> 
             RGBColor[
              0.2267841294164104, 0.35569487733390615`, 0.9362263927219862], 
             UndirectedEdge[73, 240] -> 
             RGBColor[
              0.8329068192640983, 0.2539418094898154, 0.17914491333122431`], 
             UndirectedEdge[229, 263] -> 
             RGBColor[
              0.40720266362894586`, 0.5271202134595926, 0.9471675715446273], 
             UndirectedEdge[87, 91] -> 
             RGBColor[
              0.9092412489562847, 0.8887699196998804, 0.6506892545416749], 
             UndirectedEdge[296, 339] -> 
             RGBColor[
              0.1887512717262556, 0.3157199324790988, 0.9340604777411028], 
             UndirectedEdge[62, 157] -> 
             RGBColor[
              0.6731273937865867, 0.7428277562129042, 0.9692469151984306], 
             UndirectedEdge[227, 265] -> 
             RGBColor[
              0.22119979691073288`, 0.34982538980330835`, 0.9359083732470674],
              UndirectedEdge[38, 127] -> 
             RGBColor[
              0.8446459694565934, 0.30129340921955317`, 0.18870723798989242`],
              UndirectedEdge[302, 451] -> 
             RGBColor[
              0.38989549393188216`, 0.5095986622961652, 0.9463843359960313], 
             UndirectedEdge[141, 151] -> 
             RGBColor[
              0.29343798324110804`, 0.42575230380208373`, 0.9400222310917625],
              UndirectedEdge[72, 439] -> 
             RGBColor[
              0.292484520403141, 0.4238404187370848, 0.9400012426546567], 
             UndirectedEdge[277, 340] -> 
             RGBColor[
              0.9813346158030243, 0.9667331493458243, 0.648350128762206], 
             UndirectedEdge[53, 322] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[450, 461] -> 
             RGBColor[
              0.440653853491213, 0.5536978357226917, 0.949961106074102], 
             UndirectedEdge[352, 367] -> 
             RGBColor[
              0.22779053880143119`, 0.3567526774076035, 0.9362837062476139], 
             UndirectedEdge[239, 251] -> 
             RGBColor[
              0.35362694944486533`, 0.47576904067762016`, 0.9439348930085601],
              UndirectedEdge[83, 163] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[179, 245] -> 
             RGBColor[
              0.37656052377494753`, 0.49620970043426327`, 0.945567861444176], 
             UndirectedEdge[133, 237] -> 
             RGBColor[
              0.3420181953123312, 0.46624628266428925`, 0.9431757084268175], 
             UndirectedEdge[199, 244] -> 
             RGBColor[
              0.9841027978606212, 0.9626688772839973, 0.5824524865696615], 
             UndirectedEdge[173, 269] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[209, 379] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[139, 451] -> 
             RGBColor[
              0.24317792529434393`, 0.37292579622830746`, 0.9371599951447869],
              UndirectedEdge[18, 218] -> 
             RGBColor[
              0.7469981175976064, 0.8022798739539989, 0.975417449333979], 
             UndirectedEdge[59, 287] -> 
             RGBColor[
              0.7202478045060992, 0.7809177598731158, 0.9731295500063672], 
             UndirectedEdge[167, 274] -> 
             RGBColor[
              0.470698842431732, 0.5811735508841086, 0.9514742835843497], 
             UndirectedEdge[402, 461] -> 
             RGBColor[
              0.4468964101447459, 0.5591048245359614, 0.9503588762639891], 
             UndirectedEdge[472, 488] -> 
             RGBColor[
              0.1957489875650853, 0.32307497550651876`, 0.9344589873059312], 
             UndirectedEdge[227, 270] -> 
             RGBColor[
              0.21213527831829654`, 0.34029800603898447`, 0.9353921623229817],
              UndirectedEdge[124, 363] -> 
             RGBColor[
              0.20074068905799813`, 0.32832157026772446`, 0.934743257321392], 
             UndirectedEdge[118, 195] -> 
             RGBColor[
              0.22728280184896765`, 0.3562190136781822, 0.9362547913793006], 
             UndirectedEdge[54, 154] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[313, 498] -> 
             RGBColor[
              0.8708575836519874, 0.41710611796942054`, 0.41689029682654466`],
              UndirectedEdge[243, 283] -> 
             RGBColor[
              0.2242477894352095, 0.3530290232004211, 0.9360819519122355], 
             UndirectedEdge[302, 346] -> 
             RGBColor[
              0.7355852203061626, 0.7748239735708853, 0.6706341273882959], 
             UndirectedEdge[13, 477] -> 
             RGBColor[
              0.39985691154436676`, 0.5139283350486532, 0.9475105621888961], 
             UndirectedEdge[140, 479] -> 
             RGBColor[
              0.1864188505172612, 0.31326840990439964`, 0.9339276498037584], 
             UndirectedEdge[174, 309] -> 
             RGBColor[
              0.2173048866955889, 0.3457315922156211, 0.9356865638723183], 
             UndirectedEdge[299, 312] -> 
             RGBColor[
              0.3534031011898746, 0.4747596119837323, 0.9439860300988824], 
             UndirectedEdge[215, 402] -> 
             RGBColor[
              0.2785766923854661, 0.4061119675803237, 0.9393231009461043], 
             UndirectedEdge[372, 400] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[29, 426] -> 
             RGBColor[
              0.20893369054247232`, 0.33693293429420396`, 0.9352098366354733],
              UndirectedEdge[361, 481] -> 
             RGBColor[
              0.3510247020399264, 0.47694984457964584`, 0.9436433174550093], 
             UndirectedEdge[188, 335] -> 
             RGBColor[
              0.3476544631710703, 0.4755425552025606, 0.9433732128678576], 
             UndirectedEdge[168, 443] -> 
             RGBColor[
              0.7657377612685392, 0.8169194260162985, 0.9772852418831708], 
             UndirectedEdge[81, 500] -> 
             RGBColor[
              0.3616089991347435, 0.484412861752316, 0.9443801521272757], 
             UndirectedEdge[75, 310] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[348, 444] -> 
             RGBColor[
              0.8882657082986757, 0.5574874780267427, 0.23424512158872762`], 
             UndirectedEdge[262, 482] -> 
             RGBColor[
              0.9440521498418833, 0.9577947654750492, 0.9795892961680893], 
             UndirectedEdge[83, 395] -> 
             RGBColor[
              0.8502020870562027, 0.32426772933006165`, 0.19322676477969444`],
              UndirectedEdge[26, 459] -> 
             RGBColor[
              0.2252782711388126, 0.3541121248072216, 0.9361406363207947], 
             UndirectedEdge[186, 498] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[167, 284] -> 
             RGBColor[
              0.37828991345392127`, 0.5010749823612741, 0.9453889376019913], 
             UndirectedEdge[175, 359] -> 
             RGBColor[
              0.8764817671983398, 0.4201249000034494, 0.35471866035020744`], 
             UndirectedEdge[65, 484] -> 
             RGBColor[
              0.20075983867306346`, 0.3283416977273139, 0.9347443478636406], 
             UndirectedEdge[266, 322] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[210, 252] -> 
             RGBColor[
              0.22195142774965249`, 0.3506154014711605, 0.9359511775114058], 
             UndirectedEdge[133, 271] -> 
             RGBColor[
              0.2827858451483628, 0.4145562312820451, 0.9394156075858068], 
             UndirectedEdge[190, 467] -> 
             RGBColor[
              0.28809331925242987`, 0.41681763157843177`, 0.9398393153533288],
              UndirectedEdge[216, 481] -> 
             RGBColor[
              0.2808636814443794, 0.4125359153569407, 0.9393061432064513], 
             UndirectedEdge[18, 406] -> 
             RGBColor[
              0.8740105754900596, 0.8985635500757864, 0.7736400637514464], 
             UndirectedEdge[315, 364] -> 
             RGBColor[
              0.2434271231031161, 0.3731877189253806, 0.9371741865913413], 
             UndirectedEdge[152, 464] -> 
             RGBColor[
              0.24103131190415128`, 0.37066956945206503`, 0.9370377486878454],
              UndirectedEdge[229, 280] -> 
             RGBColor[
              0.4876130735802507, 0.5943371257848047, 0.9529628180988177], 
             UndirectedEdge[164, 259] -> 
             RGBColor[
              0.8384337610731512, 0.3919783377813091, 0.43897188140083576`], 
             UndirectedEdge[238, 497] -> 
             RGBColor[
              0.9415558672049971, 0.8059955193602164, 0.27183268277426964`], 
             UndirectedEdge[7, 478] -> 
             RGBColor[
              0.7350898192819142, 0.7358328905411176, 0.6182471001773744], 
             UndirectedEdge[137, 227] -> 
             RGBColor[
              0.2807026852952867, 0.41121759970580773`, 0.9393390488386753], 
             UndirectedEdge[44, 157] -> 
             RGBColor[
              0.7585384972051484, 0.8112953062135444, 0.9765676865222799], 
             UndirectedEdge[105, 205] -> 
             RGBColor[
              0.33891161833602373`, 0.4609448212418522, 0.9430733506262359], 
             UndirectedEdge[305, 460] -> 
             RGBColor[
              0.8431870429140408, 0.8777984765898346, 0.9849051269467421], 
             UndirectedEdge[330, 492] -> 
             RGBColor[
              0.2098019116271066, 0.3378454897025508, 0.9352592805418252], 
             UndirectedEdge[94, 123] -> 
             RGBColor[
              0.19382981247906908`, 0.3210578008083872, 0.9343496931239477], 
             UndirectedEdge[418, 444] -> 
             RGBColor[
              0.8835362304269067, 0.5400718010576258, 0.22348630967635297`], 
             UndirectedEdge[203, 295] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[342, 485] -> 
             RGBColor[
              0.7516716146349955, 0.7419375828889696, 0.6178585819047002], 
             UndirectedEdge[279, 430] -> 
             RGBColor[
              0.2902434913404049, 0.42239469027195997`, 0.9398403095038447], 
             UndirectedEdge[391, 448] -> 
             RGBColor[
              0.888386104264779, 0.856120355886665, 0.6318853697511313], 
             UndirectedEdge[174, 252] -> 
             RGBColor[
              0.20462132433062605`, 0.3324003639857437, 0.9349642537592827], 
             UndirectedEdge[14, 489] -> 
             RGBColor[
              0.3237403694481549, 0.4478822256424365, 0.9421037969184629], 
             UndirectedEdge[6, 158] -> 
             RGBColor[
              0.2841449391531702, 0.41362099146188114`, 0.9395795538518968], 
             UndirectedEdge[201, 493] -> 
             RGBColor[
              0.5786142025957969, 0.6687841017968702, 0.9599697760434542], 
             UndirectedEdge[66, 446] -> 
             RGBColor[
              0.22940101354262873`, 0.3584453884705983, 0.9363754204016412], 
             UndirectedEdge[449, 499] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[202, 477] -> 
             RGBColor[
              0.2364320550815771, 0.36583545892181446`, 0.9367758278157905], 
             UndirectedEdge[89, 299] -> 
             RGBColor[
              0.6587851834243671, 0.7308687120328877, 0.9684646971494795], 
             UndirectedEdge[57, 91] -> 
             RGBColor[
              0.8662785326994125, 0.38638207765364485`, 0.21461695287942803`],
              UndirectedEdge[222, 438] -> 
             RGBColor[
              0.2691477689239765, 0.4002217484662395, 0.9386389393205536], 
             UndirectedEdge[83, 346] -> 
             RGBColor[
              0.8725424883879621, 0.4075118710378607, 0.23895123788066785`], 
             UndirectedEdge[38, 388] -> 
             RGBColor[
              0.9118100953703692, 0.7890590735441616, 0.615164700862159], 
             UndirectedEdge[345, 472] -> 
             RGBColor[
              0.21365168557830777`, 0.34189184621502966`, 0.9354785194731159],
              UndirectedEdge[231, 486] -> 
             RGBColor[
              0.8762475134266291, 0.4193508442393725, 0.30937659196826445`], 
             UndirectedEdge[14, 251] -> 
             RGBColor[
              0.43294174364966176`, 0.5494141108897593, 0.9488076429633725], 
             UndirectedEdge[404, 418] -> 
             RGBColor[
              0.8610616366179067, 0.36732222461184755`, 0.20196461326343138`],
              UndirectedEdge[10, 370] -> 
             RGBColor[
              0.3984907491896946, 0.5195743910458647, 0.9466124560602016], 
             UndirectedEdge[216, 224] -> 
             RGBColor[
              0.2822970613726556, 0.41404248854309544`, 0.939387772072871], 
             UndirectedEdge[116, 143] -> 
             RGBColor[
              0.7862678242150312, 0.44236018796317117`, 0.4452227057442526], 
             UndirectedEdge[142, 477] -> 
             RGBColor[
              0.3004155181766316, 0.43013773697541924`, 0.9405275466941669], 
             UndirectedEdge[1, 378] -> 
             RGBColor[
              0.2831419711768191, 0.4149305423176469, 0.9394358884362861], 
             UndirectedEdge[47, 298] -> 
             RGBColor[
              0.697219552726804, 0.7633924807458228, 0.9704559871947942], 
             UndirectedEdge[50, 340] -> 
             RGBColor[
              0.872096562596627, 0.4180301464376909, 0.41479302865073187`], 
             UndirectedEdge[144, 417] -> 
             RGBColor[
              0.256797636184088, 0.38724097591297457`, 0.9379356175314011], 
             UndirectedEdge[326, 395] -> 
             RGBColor[
              0.8502020870562027, 0.32426772933006165`, 0.19322676477969444`],
              UndirectedEdge[14, 166] -> 
             RGBColor[
              0.33248611507677234`, 0.4570745588104135, 0.9426018541938415], 
             UndirectedEdge[41, 132] -> 
             RGBColor[
              0.6315111194145004, 0.7114597115777666, 0.9643175833681797], 
             UndirectedEdge[6, 35] -> 
             RGBColor[
              0.2754047152813548, 0.4044344620104028, 0.9390818110323994], 
             UndirectedEdge[95, 286] -> 
             RGBColor[
              0.2095588048007067, 0.3375899690141414, 0.935245435967706], 
             UndirectedEdge[435, 439] -> 
             RGBColor[
              0.3579216498299631, 0.4805187712808422, 0.9441708386779522], 
             UndirectedEdge[354, 388] -> 
             RGBColor[
              0.8931181453699616, 0.9176121823445156, 0.9896676000730092], 
             UndirectedEdge[47, 59] -> 
             RGBColor[
              0.6586144820124289, 0.7326242521866431, 0.967025018237206], 
             UndirectedEdge[305, 493] -> 
             RGBColor[
              0.7256228086774508, 0.7851087236815824, 0.973751472290028], 
             UndirectedEdge[26, 335] -> 
             RGBColor[
              0.2598330226660348, 0.3898502763390041, 0.9381297546043277], 
             UndirectedEdge[24, 115] -> 
             RGBColor[
              0.2186064221312832, 0.3470995884806487, 0.935760684389932], 
             UndirectedEdge[271, 351] -> 
             RGBColor[
              0.3820420141208699, 0.5047731590450875, 0.9456249628519793], 
             UndirectedEdge[12, 40] -> 
             RGBColor[
              0.22456517753702926`, 0.3533626182190016, 0.9361000266951005], 
             UndirectedEdge[228, 468] -> 
             RGBColor[
              0.47049382574186954`, 0.5787015098110876, 0.9520951878724158], 
             UndirectedEdge[1, 108] -> 
             RGBColor[
              0.2889826050783411, 0.42082604906062115`, 0.9397774148572755], 
             UndirectedEdge[97, 343] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[314, 411] -> 
             RGBColor[
              0.656845676388658, 0.7312243873716151, 0.9668610682296974], 
             UndirectedEdge[211, 466] -> 
             RGBColor[
              0.2317269011689615, 0.36089004383566703`, 0.9365078762611184], 
             UndirectedEdge[12, 202] -> 
             RGBColor[
              0.2283373813057901, 0.35732744355150203`, 0.936314848119256], 
             UndirectedEdge[96, 360] -> 
             RGBColor[
              0.8668775579740029, 0.4036445305638346, 0.2071894410617543], 
             UndirectedEdge[199, 482] -> 
             RGBColor[
              0.9636232621639489, 0.9712609471948344, 0.895860300965513], 
             UndirectedEdge[9, 357] -> 
             RGBColor[
              0.23165569271724953`, 0.3608151992380412, 0.9365038210451369], 
             UndirectedEdge[330, 441] -> 
             RGBColor[
              0.2965298119987766, 0.4235012172675965, 0.9403997172018848], 
             UndirectedEdge[375, 461] -> 
             RGBColor[
              0.4115391847777058, 0.525962316169853, 0.9481981362024026], 
             UndirectedEdge[170, 268] -> 
             RGBColor[
              0.21378017372291278`, 0.34202689540162845`, 0.93548583668287], 
             UndirectedEdge[66, 245] -> 
             RGBColor[
              0.3717582052146181, 0.4911621591427741, 0.9452943765065589], 
             UndirectedEdge[235, 308] -> 
             RGBColor[
              0.2889479905873472, 0.41746139602542953`, 0.9398973079188528], 
             UndirectedEdge[42, 315] -> 
             RGBColor[
              0.2351529722129052, 0.36449106172830237`, 0.9367029859386531], 
             UndirectedEdge[238, 403] -> 
             RGBColor[
              0.857059891141737, 0.3514566373014637, 0.19874471492026624`], 
             UndirectedEdge[382, 425] -> 
             RGBColor[
              0.2677389295661514, 0.3974082595226244, 0.9386075050248284], 
             UndirectedEdge[74, 215] -> 
             RGBColor[
              0.21298972122483276`, 0.3411960797085633, 0.935440821582474], 
             UndirectedEdge[350, 426] -> 
             RGBColor[
              0.20267694710555745`, 0.33035670024156016`, 0.9348535243527634],
              UndirectedEdge[78, 497] -> 
             RGBColor[
              0.9513305032138845, 0.844710858419126, 0.2798946323366356], 
             UndirectedEdge[109, 490] -> 
             RGBColor[
              0.33626661541495695`, 0.4656789738460858, 0.9426475892787163], 
             UndirectedEdge[281, 317] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[219, 471] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[183, 243] -> 
             RGBColor[
              0.2557945891305531, 0.386186709862853, 0.9378784954855774], 
             UndirectedEdge[93, 151] -> 
             RGBColor[
              0.3297566159868596, 0.4579089737338883, 0.9423108176147698], 
             UndirectedEdge[176, 478] -> 
             RGBColor[
              0.7002666387715365, 0.7643643038754704, 0.9719385075455431], 
             UndirectedEdge[28, 282] -> 
             RGBColor[
              0.8613224849238736, 0.3683564012224616, 0.2021744979333091], 
             UndirectedEdge[125, 305] -> 
             RGBColor[
              0.8321466499760604, 0.3869651660515732, 0.4383722111318248], 
             UndirectedEdge[22, 466] -> 
             RGBColor[
              0.21948326963951018`, 0.34802121080713827`, 0.9358106195583459],
              UndirectedEdge[78, 154] -> 
             RGBColor[
              0.863576315147662, 0.3772668633407367, 0.20411934796184356`], 
             UndirectedEdge[273, 421] -> 
             RGBColor[
              0.20830733799455892`, 0.33627459805330173`, 0.9351741667844751],
              UndirectedEdge[221, 234] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[384, 461] -> 
             RGBColor[
              0.587992436035337, 0.6763977741876906, 0.9607080649334159], 
             UndirectedEdge[3, 428] -> 
             RGBColor[
              0.20817203900594683`, 0.33613239023781905`, 0.9351664617072306],
              UndirectedEdge[209, 431] -> 
             RGBColor[
              0.8760289938084724, 0.418883452871858, 0.28559208007867803`], 
             UndirectedEdge[33, 237] -> 
             RGBColor[
              0.49170863187262065`, 0.5974080208929563, 0.9533554339843097], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.6304047842681767, 0.7105954341529999, 0.964207314220084], 
             UndirectedEdge[202, 243] -> 
             RGBColor[
              0.23381644008435298`, 0.36308628172016266`, 0.9366268724111542],
              UndirectedEdge[169, 456] -> 
             RGBColor[
              0.22538315140670392`, 0.35422236061856843`, 0.9361466090968946],
              UndirectedEdge[86, 297] -> 
             RGBColor[
              0.22786096089643254`, 0.35682669549446866`, 0.936287716681744], 
             UndirectedEdge[40, 202] -> 
             RGBColor[
              0.20889632984063528`, 0.3368936658277679, 0.9352077089987738], 
             UndirectedEdge[396, 477] -> 
             RGBColor[
              0.25943030085066265`, 0.39000807339812527`, 0.9380855438894842],
              UndirectedEdge[209, 355] -> 
             RGBColor[
              0.8304768118928137, 0.23526370799810264`, 0.17681793552818148`],
              UndirectedEdge[131, 434] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[87, 228] -> 
             RGBColor[
              0.713434001367286, 0.7752676949105676, 0.9727293181147071], 
             UndirectedEdge[17, 116] -> 
             RGBColor[
              0.8359452478324436, 0.8712418660281439, 0.9133270492646723], 
             UndirectedEdge[104, 323] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[101, 347] -> 
             RGBColor[
              0.38666513626040583`, 0.5059405125852774, 0.9462242971444441], 
             UndirectedEdge[92, 342] -> 
             RGBColor[
              0.8032234487173383, 0.7835550891960509, 0.622077324996481], 
             UndirectedEdge[399, 464] -> 
             RGBColor[
              0.291953585715003, 0.4241921078859083, 0.9399376968486202], 
             UndirectedEdge[423, 469] -> 
             RGBColor[
              0.18473878597520788`, 0.3115025555484572, 0.9338319726135212], 
             UndirectedEdge[114, 415] -> 
             RGBColor[
              0.18749769588626286`, 0.3144023447899675, 0.9339890884515143], 
             UndirectedEdge[244, 478] -> 
             RGBColor[
              0.7469756992594796, 0.7766726498372237, 0.6605368645795646], 
             UndirectedEdge[129, 486] -> 
             RGBColor[
              0.8772725629513854, 0.9012898824300021, 0.7882255224122631], 
             UndirectedEdge[202, 421] -> 
             RGBColor[
              0.20744896350666275`, 0.3353723920424369, 0.9351252836272407], 
             UndirectedEdge[62, 378] -> 
             RGBColor[
              0.4141124561597586, 0.5302263593931105, 0.9482027364763976], 
             UndirectedEdge[263, 485] -> 
             RGBColor[
              0.4682909081362715, 0.5772825622677944, 0.9518196776462704], 
             UndirectedEdge[275, 346] -> 
             RGBColor[
              0.9582193150286128, 0.8640683796032405, 0.32686377672377676`], 
             UndirectedEdge[127, 303] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[260, 312] -> 
             RGBColor[
              0.28003182950122174`, 0.41135737812578943`, 0.9392699090175137],
              UndirectedEdge[32, 299] -> 
             RGBColor[
              0.4092045959302848, 0.5287059126675422, 0.9473361014296651], 
             UndirectedEdge[283, 396] -> 
             RGBColor[
              0.2260981287293382, 0.35497384711683755`, 0.9361873259977045], 
             UndirectedEdge[87, 253] -> 
             RGBColor[
              0.9212113021251026, 0.9380051283115193, 0.9161080583934463], 
             UndirectedEdge[298, 409] -> 
             RGBColor[
              0.6105489205240312, 0.6941370374682924, 0.9628756303954102], 
             UndirectedEdge[208, 258] -> 
             RGBColor[
              0.9934783139029316, 0.9884590978190089, 0.5315328993943991], 
             UndirectedEdge[142, 161] -> 
             RGBColor[
              0.33616922788314596`, 0.46559462166087084`, 0.9426413838313057],
              UndirectedEdge[71, 211] -> 
             RGBColor[
              0.23787031413452003`, 0.3673471603773484, 0.936857734541142], 
             UndirectedEdge[14, 453] -> 
             RGBColor[
              0.43587796123566236`, 0.5518333953899437, 0.9490289755046595], 
             UndirectedEdge[89, 478] -> 
             RGBColor[
              0.687765263411751, 0.7543960465043716, 0.9707461152036172], 
             UndirectedEdge[159, 251] -> 
             RGBColor[
              0.43566646967110545`, 0.5517741316208221, 0.9489812600960783], 
             UndirectedEdge[300, 305] -> 
             RGBColor[
              0.6399560489314267, 0.7146046131469155, 0.9672716100974765], 
             UndirectedEdge[327, 385] -> 
             RGBColor[
              0.19503845651827315`, 0.32232816232604883`, 0.9344185236139517],
              UndirectedEdge[156, 270] -> 
             RGBColor[
              0.22556593125093138`, 0.35441447382376295`, 0.9361570181386248],
              UndirectedEdge[418, 486] -> 
             RGBColor[
              0.9713257250668036, 0.9117556032768301, 0.43857580784754374`], 
             UndirectedEdge[366, 465] -> 
             RGBColor[
              0.18700818241333977`, 0.3138878350929786, 0.9339612113834017], 
             UndirectedEdge[337, 433] -> 
             RGBColor[
              0.20456821904727826`, 0.3323445469658758, 0.9349612294919583], 
             UndirectedEdge[118, 152] -> 
             RGBColor[
              0.21897053500328645`, 0.3474822941952136, 0.9357814200793358], 
             UndirectedEdge[151, 162] -> 
             RGBColor[
              0.24178469740461808`, 0.3714614253804553, 0.9370806528775629], 
             UndirectedEdge[80, 251] -> 
             RGBColor[
              0.7049995072728927, 0.7670594318463122, 0.9530097354129909], 
             UndirectedEdge[348, 486] -> 
             RGBColor[
              0.9784199418744571, 0.9378791187305058, 0.45471402571610575`], 
             UndirectedEdge[376, 455] -> 
             RGBColor[
              0.8735554698238286, 0.41891480083667676`, 0.4032149808607035], 
             UndirectedEdge[153, 197] -> 
             RGBColor[
              0.4056482253886383, 0.5257738371841758, 0.9470685241144907], 
             UndirectedEdge[9, 319] -> 
             RGBColor[
              0.21511171431873558`, 0.34342642899238807`, 0.9355616659499643],
              UndirectedEdge[184, 336] -> 
             RGBColor[
              0.8369837657282427, 0.26650113164225936`, 0.18231370738115665`],
              UndirectedEdge[41, 56] -> 
             RGBColor[
              0.7988889921505462, 0.8398198339616005, 0.8100291411688312], 
             UndirectedEdge[99, 313] -> 
             RGBColor[
              0.8708575836519874, 0.41710611796942054`, 0.41689029682654455`],
              UndirectedEdge[111, 130] -> 
             RGBColor[
              0.9088647441004855, 0.9288516182784499, 0.9449490739960295], 
             UndirectedEdge[255, 327] -> 
             RGBColor[
              0.22866910912003982`, 0.35767611051703674`, 0.9363337395275303],
              UndirectedEdge[32, 84] -> 
             RGBColor[
              0.5191908481230056, 0.617440223102824, 0.9563757768952883], 
             UndirectedEdge[196, 420] -> 
             RGBColor[
              0.22671171795480946`, 0.35561876829661176`, 0.9362222689963712],
              UndirectedEdge[55, 57] -> 
             RGBColor[
              0.8349696694427251, 0.26979777990945364`, 0.18112030099193344`],
              UndirectedEdge[10, 480] -> 
             RGBColor[
              0.4365798694030919, 0.5518570491641553, 0.9492351453536998], 
             UndirectedEdge[152, 216] -> 
             RGBColor[
              0.23556313755144892`, 0.3649221715050963, 0.9367263442478979], 
             UndirectedEdge[244, 482] -> 
             RGBColor[
              0.9567328878050008, 0.9433863649838862, 0.6793828120829337], 
             UndirectedEdge[111, 463] -> 
             RGBColor[
              0.9024172304136022, 0.6381848846128098, 0.4393327514426538], 
             UndirectedEdge[58, 74] -> 
             RGBColor[
              0.2306608517696206, 0.3597695583255239, 0.9364471663249048], 
             UndirectedEdge[66, 327] -> 
             RGBColor[
              0.23020235366261008`, 0.35928764774459687`, 0.9364210555359976],
              UndirectedEdge[168, 346] -> 
             RGBColor[
              0.8815478026298791, 0.8912128629367583, 0.6835675306232744], 
             UndirectedEdge[53, 471] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[28, 125] -> 
             RGBColor[
              0.8613224849238736, 0.3683564012224616, 0.2021744979333091], 
             UndirectedEdge[405, 423] -> 
             RGBColor[
              0.18539930704922003`, 0.3121968050766989, 0.9338695883115329], 
             UndirectedEdge[314, 493] -> 
             RGBColor[
              0.5954128680509563, 0.6824220151846232, 0.9612922285236236], 
             UndirectedEdge[43, 229] -> 
             RGBColor[
              0.416869736584196, 0.535493346172216, 0.9477835488850788], 
             UndirectedEdge[281, 397] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[203, 324] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[403, 445] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[147, 303] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[356, 457] -> 
             RGBColor[
              0.7242147630598365, 0.7320073272227894, 0.6198326116523992], 
             UndirectedEdge[8, 85] -> 
             RGBColor[
              0.23686771917621463`, 0.36629336950797753`, 0.9368006382414729],
              UndirectedEdge[301, 336] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[24, 64] -> 
             RGBColor[
              0.20529474346718407`, 0.33310817019550554`, 0.9350026039828754],
              UndirectedEdge[30, 488] -> 
             RGBColor[
              0.18669921182250732`, 0.3135630874121468, 0.9339436159653348], 
             UndirectedEdge[191, 366] -> 
             RGBColor[
              0.21187817482284405`, 0.3400277739639608, 0.9353775206592663], 
             UndirectedEdge[185, 481] -> 
             RGBColor[
              0.30650884939950357`, 0.4383924504543215, 0.9408068066885844], 
             UndirectedEdge[308, 389] -> 
             RGBColor[
              0.23917127383072181`, 0.36871455150366533`, 0.9369318222712433],
              UndirectedEdge[96, 240] -> 
             RGBColor[
              0.8633136325544521, 0.3762506380670908, 0.20377662205511446`], 
             UndirectedEdge[108, 113] -> 
             RGBColor[
              0.2834673549063147, 0.4150291714427635, 0.9394633295190601], 
             UndirectedEdge[85, 332] -> 
             RGBColor[
              0.21348039489620751`, 0.3417118088476858, 0.9354687647221722], 
             UndirectedEdge[232, 280] -> 
             RGBColor[
              0.6194682079410706, 0.701127928508344, 0.9637488444766045], 
             UndirectedEdge[310, 419] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[39, 378] -> 
             RGBColor[
              0.4028150168001186, 0.5210545891771114, 0.9473133606661228], 
             UndirectedEdge[53, 257] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[248, 339] -> 
             RGBColor[
              0.184537889109962, 0.31129140020548685`, 0.9338205318342458], 
             UndirectedEdge[327, 334] -> 
             RGBColor[
              0.2064526612899435, 0.33432521524345593`, 0.9350685456898955], 
             UndirectedEdge[165, 358] -> 
             RGBColor[
              0.614683480338821, 0.6933014823842196, 0.9653911750972035], 
             UndirectedEdge[69, 204] -> 
             RGBColor[
              0.9308314245530096, 0.9281676018500284, 0.6853815574337436], 
             UndirectedEdge[208, 293] -> 
             RGBColor[
              0.8758809832712207, 0.41856687329883735`, 0.26948204651397445`],
              UndirectedEdge[265, 320] -> 
             RGBColor[
              0.1953107306009688, 0.32261433965013586`, 0.9344340292201678], 
             UndirectedEdge[239, 453] -> 
             RGBColor[
              0.356563167030866, 0.4781883251778045, 0.9441562255498472], 
             UndirectedEdge[108, 452] -> 
             RGBColor[
              0.35261985676709484`, 0.4798433295674984, 0.9436896033570711], 
             UndirectedEdge[331, 418] -> 
             RGBColor[
              0.8880207099240073, 0.849499175318815, 0.6304330994691307], 
             UndirectedEdge[28, 201] -> 
             RGBColor[
              0.7585570962682471, 0.7484037290263401, 0.6186023673511272], 
             UndirectedEdge[431, 486] -> 
             RGBColor[
              0.9937767608526522, 0.9890974456668459, 0.5640170080704137], 
             UndirectedEdge[269, 419] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[315, 378] -> 
             RGBColor[
              0.24896710191064286`, 0.3790105879070351, 0.9374896801887658], 
             UndirectedEdge[57, 240] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[7, 176] -> 
             RGBColor[
              0.9186174830361646, 0.8816461898151895, 0.6350868762508705], 
             UndirectedEdge[6, 302] -> 
             RGBColor[
              0.4112463925959364, 0.5296760767264955, 0.9476867859622409], 
             UndirectedEdge[176, 455] -> 
             RGBColor[
              0.8394774341752623, 0.3928105343831808, 0.439071427873013], 
             UndirectedEdge[161, 396] -> 
             RGBColor[
              0.29518401055717713`, 0.42546495808357687`, 0.940199381026623], 
             UndirectedEdge[36, 463] -> 
             RGBColor[
              0.831998657058118, 0.24386491747293382`, 0.17815401051060936`], 
             UndirectedEdge[131, 373] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[54, 341] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[272, 453] -> 
             RGBColor[
              0.512128074735658, 0.6148076680340822, 0.9547357445115932], 
             UndirectedEdge[169, 236] -> 
             RGBColor[
              0.2528389722684402, 0.38308016914383974`, 0.9377101774777234], 
             UndirectedEdge[69, 101] -> 
             RGBColor[
              0.7358996157457895, 0.7730701996070706, 0.6676735904233504], 
             UndirectedEdge[286, 330] -> 
             RGBColor[
              0.22011222124554525`, 0.3486822788229162, 0.935846437421859], 
             UndirectedEdge[86, 254] -> 
             RGBColor[
              0.2217593415229328, 0.3504135066679079, 0.9359402384849602], 
             UndirectedEdge[68, 319] -> 
             RGBColor[
              0.19709684259875715`, 0.3244916566058529, 0.9345357456561258], 
             UndirectedEdge[37, 207] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[257, 317] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[94, 158] -> 
             RGBColor[
              0.20645253428145324`, 0.3343250817494799, 0.9350685384569499], 
             UndirectedEdge[253, 336] -> 
             RGBColor[
              0.8742585681452911, 0.41920555006140414`, 0.39156282211394233`],
              UndirectedEdge[67, 363] -> 
             RGBColor[
              0.19105732048097354`, 0.31814373593224315`, 0.9341918038061905],
              UndirectedEdge[61, 295] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[16, 116] -> 
             RGBColor[
              0.6656811252095095, 0.7387544214683854, 0.9673125314832324], 
             UndirectedEdge[294, 439] -> 
             RGBColor[
              0.2411021556117397, 0.370744030680491, 0.9370417831321887], 
             UndirectedEdge[69, 346] -> 
             RGBColor[
              0.9822051197373862, 0.9516358318169333, 0.3853706797712563], 
             UndirectedEdge[327, 415] -> 
             RGBColor[
              0.19254792830447778`, 0.31971045926474073`, 0.9342766917165823],
              UndirectedEdge[54, 61] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[244, 262] -> 
             RGBColor[
              0.9645316855385555, 0.9492026955642121, 0.6661814817722379], 
             UndirectedEdge[295, 397] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[61, 264] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[162, 226] -> 
             RGBColor[
              0.2057449485934193, 0.33358136432783236`, 0.9350282424987957], 
             UndirectedEdge[237, 351] -> 
             RGBColor[
              0.44127436428483835`, 0.5564632104273317, 0.9493850636929899], 
             UndirectedEdge[243, 273] -> 
             RGBColor[
              0.23467481457224915`, 0.36398848773102743`, 0.9366757555683887],
              UndirectedEdge[53, 343] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[37, 445] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[144, 402] -> 
             RGBColor[
              0.3042407743951998, 0.43308654496933563`, 0.9407846324499517], 
             UndirectedEdge[235, 456] -> 
             RGBColor[
              0.2990858824276412, 0.4281169631290464, 0.9404746458614907], 
             UndirectedEdge[369, 456] -> 
             RGBColor[
              0.22153756303757788`, 0.35018040341823176`, 0.935927608528311], 
             UndirectedEdge[7, 61] -> 
             RGBColor[
              0.8626928878488475, 0.3737895921602789, 0.20327715629423396`], 
             UndirectedEdge[76, 175] -> 
             RGBColor[
              0.994576248362856, 0.9912169845602006, 0.6808037761580129], 
             UndirectedEdge[259, 372] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[187, 224] -> 
             RGBColor[
              0.3312204995773527, 0.4600614913307744, 0.9423717063511409], 
             UndirectedEdge[142, 183] -> 
             RGBColor[
              0.2986301457506506, 0.42826119735656343`, 0.940425872375729], 
             UndirectedEdge[255, 299] -> 
             RGBColor[
              0.3581446545361039, 0.47974328518246506`, 0.9442560545474505], 
             UndirectedEdge[233, 444] -> 
             RGBColor[
              0.8285562969045, 0.22050178822288907`, 0.17497884820646079`], 
             UndirectedEdge[148, 280] -> 
             RGBColor[
              0.6081987749178179, 0.6923241617797158, 0.9626256127116859], 
             UndirectedEdge[7, 376] -> 
             RGBColor[
              0.9697345365090141, 0.9208025894954335, 0.5813022057324062], 
             UndirectedEdge[73, 256] -> 
             RGBColor[
              0.8488870131352718, 0.5076989827583813, 0.45340905512865315`], 
             UndirectedEdge[207, 403] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[233, 346] -> 
             RGBColor[
              0.8725424883879621, 0.4075118710378607, 0.23895123788066785`], 
             UndirectedEdge[293, 403] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[321, 391] -> 
             RGBColor[
              0.8623939674573535, 0.3726044724173211, 0.20303663793067456`], 
             UndirectedEdge[228, 298] -> 
             RGBColor[
              0.6261771448274018, 0.7068247340012503, 0.9641059414606434], 
             UndirectedEdge[54, 455] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[323, 419] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[65, 194] -> 
             RGBColor[
              0.2035493121604427, 0.3312736112253837, 0.9349032042520906], 
             UndirectedEdge[40, 273] -> 
             RGBColor[
              0.20975470432853144`, 0.3377958718386327, 0.9352565921560083], 
             UndirectedEdge[209, 400] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[31, 488] -> 
             RGBColor[
              0.2147992220911071, 0.343097979847999, 0.9355438699798917], 
             UndirectedEdge[399, 407] -> 
             RGBColor[
              0.49595107779550673`, 0.5964347568986441, 0.9550832606977075], 
             UndirectedEdge[292, 399] -> 
             RGBColor[
              0.2546203091758611, 0.3849524671768223, 0.9378116219793493], 
             UndirectedEdge[93, 218] -> 
             RGBColor[
              0.5568185669726924, 0.6474379222816083, 0.9598710907741307], 
             UndirectedEdge[198, 270] -> 
             RGBColor[
              0.1889882633050292, 0.3159690256545238, 0.9340739740609163], 
             UndirectedEdge[78, 192] -> 
             RGBColor[
              0.9131433471019068, 0.8814405377612413, 0.6357016426534479], 
             UndirectedEdge[286, 492] -> 
             RGBColor[
              0.20509632372891637`, 0.3328996184700481, 0.9349913042723167], 
             UndirectedEdge[317, 343] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[51, 203] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[212, 216] -> 
             RGBColor[
              0.23063173496240144`, 0.3597389547150244, 0.9364455081658081], 
             UndirectedEdge[100, 257] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[189, 302] -> 
             RGBColor[
              0.5107971785704983, 0.6137271865710165, 0.9546309714902383], 
             UndirectedEdge[306, 382] -> 
             RGBColor[
              0.3931544582199925, 0.514685442356139, 0.9463461835686895], 
             UndirectedEdge[20, 150] -> 
             RGBColor[
              0.40414439209252373`, 0.5240361829288928, 0.9470929232210681], 
             UndirectedEdge[255, 446] -> 
             RGBColor[
              0.22786776900005848`, 0.3568338512430382, 0.9362881043931739], 
             UndirectedEdge[182, 237] -> 
             RGBColor[
              0.6887654101141651, 0.7532085811116003, 0.9550446399454904], 
             UndirectedEdge[4, 366] -> 
             RGBColor[
              0.19231228025278044`, 0.3194627782214574, 0.9342632719086483], 
             UndirectedEdge[231, 275] -> 
             RGBColor[
              0.8560290549644465, 0.34736971536429956`, 0.19791527993518332`],
              UndirectedEdge[97, 231] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[114, 128] -> 
             RGBColor[
              0.21734212015934035`, 0.3457707269467618, 0.935688684262997], 
             UndirectedEdge[207, 471] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[54, 391] -> 
             RGBColor[
              0.8623939674573535, 0.3726044724173211, 0.20303663793067456`], 
             UndirectedEdge[299, 478] -> 
             RGBColor[
              0.4877588950299022, 0.5950236701299144, 0.9528173134179094], 
             UndirectedEdge[44, 365] -> 
             RGBColor[
              0.4996948950434621, 0.5988739938309104, 0.9555332651015185], 
             UndirectedEdge[6, 101] -> 
             RGBColor[
              0.4123451334620635, 0.5305680840593294, 0.9477732828680429], 
             UndirectedEdge[236, 308] -> 
             RGBColor[
              0.26811333291134537`, 0.39913449062993284`, 0.9385800297199454],
              UndirectedEdge[47, 256] -> 
             RGBColor[
              0.7899637501662823, 0.8362108983385758, 0.9796027513224682], 
             UndirectedEdge[304, 427] -> 
             RGBColor[
              0.22064336651454602`, 0.34924054617719114`, 0.9358766853591696],
              UndirectedEdge[54, 397] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[220, 254] -> 
             RGBColor[
              0.2920298352643197, 0.42073811697522306`, 0.9400714411065638], 
             UndirectedEdge[377, 426] -> 
             RGBColor[
              0.2010989407485189, 0.3286981155089309, 0.9347636592251812], 
             UndirectedEdge[216, 292] -> 
             RGBColor[
              0.23746813104113765`, 0.36692444044632255`, 0.9368348308089505],
              UndirectedEdge[42, 119] -> 
             RGBColor[
              0.23711084694980825`, 0.3665489122132156, 0.9368144840085036], 
             UndirectedEdge[170, 491] -> 
             RGBColor[
              0.20371206300908717`, 0.33144467268630884`, 0.9349124726721527],
              UndirectedEdge[257, 326] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[98, 347] -> 
             RGBColor[
              0.251130504754864, 0.38128446146397427`, 0.9376128827802765], 
             UndirectedEdge[271, 311] -> 
             RGBColor[
              0.2655645138375205, 0.3964555201788798, 0.9384348782443309], 
             UndirectedEdge[156, 227] -> 
             RGBColor[
              0.2536615370733401, 0.3839447369074104, 0.937757021326487], 
             UndirectedEdge[151, 160] -> 
             RGBColor[
              0.37027731562653565`, 0.4929640661272292, 0.9449043381372781], 
             UndirectedEdge[93, 167] -> 
             RGBColor[
              0.41563984784251484`, 0.5343156157080063, 0.9477362552278843], 
             UndirectedEdge[275, 348] -> 
             RGBColor[
              0.9480922541811833, 0.8299074254178962, 0.2875220576664841], 
             UndirectedEdge[34, 394] -> 
             RGBColor[
              0.2532945186751018, 0.38355897730055144`, 0.9377361201716623], 
             UndirectedEdge[405, 488] -> 
             RGBColor[
              0.1925687093373611, 0.3197323014478947, 0.9342778751656623], 
             UndirectedEdge[338, 443] -> 
             RGBColor[
              0.8722816554650638, 0.8967727827234393, 0.738216219132237], 
             UndirectedEdge[301, 316] -> 
             RGBColor[
              0.8735231410973765, 0.4108198428949215, 0.24276088847601782`], 
             UndirectedEdge[103, 209] -> 
             RGBColor[
              0.8763449551304583, 0.4195592621909958, 0.3199825200895846], 
             UndirectedEdge[126, 414] -> 
             RGBColor[
              0.9638951205538232, 0.8830011069097463, 0.3908566728809145], 
             UndirectedEdge[154, 341] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[306, 347] -> 
             RGBColor[
              0.37305016758982446`, 0.49488726767115054`, 0.9451524769374224],
              UndirectedEdge[20, 388] -> 
             RGBColor[
              0.6968315144564416, 0.7612822652895019, 0.972005607251501], 
             UndirectedEdge[286, 319] -> 
             RGBColor[
              0.2013361778689116, 0.32894746676416586`, 0.9347771695282268], 
             UndirectedEdge[62, 96] -> 
             RGBColor[
              0.7419154122295191, 0.7443098604712988, 0.6194603335528694], 
             UndirectedEdge[149, 242] -> 
             RGBColor[
              0.8427485102135918, 0.3295893587840956, 0.1885693276990594], 
             UndirectedEdge[212, 319] -> 
             RGBColor[
              0.18959797954384694`, 0.31660987607976354`, 0.9341086964987225],
              UndirectedEdge[289, 470] -> 
             RGBColor[
              0.28003993770811864`, 0.41122301625627355`, 0.939275602455069], 
             UndirectedEdge[291, 353] -> 
             RGBColor[
              0.19170554293633024`, 0.31882505883250056`, 0.9342287191160639],
              UndirectedEdge[21, 91] -> 
             RGBColor[
              0.89309711802987, 0.8758970279199172, 0.6491494129218777], 
             UndirectedEdge[95, 224] -> 
             RGBColor[
              0.24948593288589618`, 0.37955591215781015`, 0.9375192268452648],
              UndirectedEdge[218, 235] -> 
             RGBColor[
              0.543596856175445, 0.6359859409315397, 0.9590286150536299], 
             UndirectedEdge[108, 315] -> 
             RGBColor[
              0.25480773581216487`, 0.38490609465000936`, 0.9378312066097552],
              UndirectedEdge[61, 154] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[297, 413] -> 
             RGBColor[
              0.32997558728000875`, 0.45473309296380404`, 0.9424479992766471],
              UndirectedEdge[294, 438] -> 
             RGBColor[
              0.24844971479729377`, 0.37846678124666755`, 0.9374602157580663],
              UndirectedEdge[277, 386] -> 
             RGBColor[
              0.9122570409032669, 0.9128375594706262, 0.6828459092178139], 
             UndirectedEdge[125, 249] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[211, 308] -> 
             RGBColor[
              0.22315099456572612`, 0.35187622225178283`, 0.936019491066981], 
             UndirectedEdge[273, 477] -> 
             RGBColor[
              0.23729042956947327`, 0.36673766493267923`, 0.9368247109730249],
              UndirectedEdge[154, 397] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[105, 230] -> 
             RGBColor[
              0.26393464830119756`, 0.39474242816076077`, 0.9383420598132073],
              UndirectedEdge[355, 404] -> 
             RGBColor[
              0.8436346237856275, 0.3364004159962053, 0.18941787105636293`], 
             UndirectedEdge[250, 263] -> 
             RGBColor[
              0.37074736764175087`, 0.49554446837193705`, 0.9448446723204758],
              UndirectedEdge[11, 259] -> 
             RGBColor[
              0.8740472245688059, 0.4191181540612454, 0.3950653321159444], 
             UndirectedEdge[339, 439] -> 
             RGBColor[
              0.22536729059950822`, 0.35420568990457246`, 0.9361457058473888],
              UndirectedEdge[303, 379] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[416, 468] -> 
             RGBColor[
              0.33896877720651325`, 0.4680194505753313, 0.9428197686386466], 
             UndirectedEdge[77, 336] -> 
             RGBColor[
              0.8579732191915481, 0.4074969800510354, 0.43870016507762466`], 
             UndirectedEdge[297, 412] -> 
             RGBColor[
              0.23850869796425644`, 0.3680181422582739, 0.9368940895558412], 
             UndirectedEdge[69, 418] -> 
             RGBColor[
              0.9649838420823031, 0.8913513621779137, 0.32989074284540154`], 
             UndirectedEdge[281, 322] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[51, 495] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[227, 229] -> 
             RGBColor[
              0.3363119952168668, 0.45938358895469533`, 0.9428824248934964], 
             UndirectedEdge[192, 497] -> 
             RGBColor[
              0.9083829048728054, 0.8626048061581572, 0.6316742311045528], 
             UndirectedEdge[143, 277] -> 
             RGBColor[
              0.8851303930784559, 0.5071031218256719, 0.24908135364154116`], 
             UndirectedEdge[87, 161] -> 
             RGBColor[
              0.5929939478905595, 0.674186901246545, 0.9641602249639974], 
             UndirectedEdge[114, 255] -> 
             RGBColor[
              0.2236188767018249, 0.35236799604226343`, 0.9360461362624624], 
             UndirectedEdge[341, 391] -> 
             RGBColor[
              0.8623939674573535, 0.3726044724173211, 0.20303663793067456`], 
             UndirectedEdge[35, 347] -> 
             RGBColor[
              0.2497247180796972, 0.37980689053635075`, 0.9375328253088007], 
             UndirectedEdge[99, 498] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[89, 448] -> 
             RGBColor[
              0.8415099289818567, 0.8764611914643559, 0.9847451623227131], 
             UndirectedEdge[130, 371] -> 
             RGBColor[
              0.6899215836975872, 0.756331872704727, 0.9707026743154967], 
             UndirectedEdge[187, 481] -> 
             RGBColor[
              0.32978711964907653`, 0.45855491814461957`, 0.9422900774847212],
              UndirectedEdge[427, 500] -> 
             RGBColor[
              0.24278319621806277`, 0.37251091094186695`, 0.937137515907842], 
             UndirectedEdge[134, 247] -> 
             RGBColor[
              0.20166327316729094`, 0.3292912646618023, 0.9347957971215752], 
             UndirectedEdge[79, 301] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[173, 323] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[84, 262] -> 
             RGBColor[
              0.8153011335016991, 0.8562880262921846, 0.9675016060762058], 
             UndirectedEdge[262, 391] -> 
             RGBColor[
              0.9521974249737493, 0.9065852566536692, 0.6235309398247086], 
             UndirectedEdge[205, 382] -> 
             RGBColor[
              0.38411017432233535`, 0.5071186598844669, 0.9456961385458966], 
             UndirectedEdge[50, 499] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[108, 380] -> 
             RGBColor[
              0.26354993581091446`, 0.3940947011361892, 0.9383290619667581], 
             UndirectedEdge[300, 493] -> 
             RGBColor[
              0.5037769076806964, 0.6070718386737781, 0.9543424489920299], 
             UndirectedEdge[331, 382] -> 
             RGBColor[
              0.5753274532973747, 0.6598063513243815, 0.9626104158765989], 
             UndirectedEdge[186, 495] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[93, 235] -> 
             RGBColor[
              0.3605980717626268, 0.48675365839988305`, 0.9441979681617279], 
             UndirectedEdge[18, 300] -> 
             RGBColor[
              0.5861445158721873, 0.672228635616922, 0.9619978739007018], 
             UndirectedEdge[223, 246] -> 
             RGBColor[
              0.38131973644829154`, 0.5042325916141828, 0.9455639325855753], 
             UndirectedEdge[233, 431] -> 
             RGBColor[
              0.8760289938084724, 0.418883452871858, 0.28559208007867803`], 
             UndirectedEdge[182, 351] -> 
             RGBColor[
              0.7070036360153077, 0.7688374180603554, 0.9562532370834724], 
             UndirectedEdge[163, 209] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[70, 182] -> 
             RGBColor[
              0.9700359047903209, 0.9769432873298111, 0.9253003310773291], 
             UndirectedEdge[59, 335] -> 
             RGBColor[
              0.45879597954340867`, 0.567755451964993, 0.9515747141851782], 
             UndirectedEdge[258, 453] -> 
             RGBColor[
              0.7259167707479581, 0.7801198628667647, 0.7667604716499351], 
             UndirectedEdge[161, 354] -> 
             RGBColor[
              0.5968095021678761, 0.6772293206568155, 0.9645241559371533], 
             UndirectedEdge[213, 489] -> 
             RGBColor[
              0.25642875652489994`, 0.38685326000284664`, 0.9379146103805189],
              UndirectedEdge[260, 407] -> 
             RGBColor[
              0.5001504188796009, 0.6005443225351969, 0.9553335455086889], 
             UndirectedEdge[95, 185] -> 
             RGBColor[
              0.262167272695942, 0.39178664192053536`, 0.9382816194928008], 
             UndirectedEdge[117, 479] -> 
             RGBColor[
              0.1962175335848792, 0.3235674470808556, 0.9344856703086066], 
             UndirectedEdge[164, 444] -> 
             RGBColor[
              0.8609083548821511, 0.5647279142270871, 0.4604935778137573], 
             UndirectedEdge[32, 334] -> 
             RGBColor[
              0.2863539875937741, 0.413601966917996, 0.9397910667757092], 
             UndirectedEdge[46, 325] -> 
             RGBColor[
              0.3561464710176476, 0.48076541432714226`, 0.9439923970496341], 
             UndirectedEdge[18, 201] -> 
             RGBColor[
              0.6609818107872878, 0.7339408987400141, 0.9676252009521262], 
             UndirectedEdge[328, 398] -> 
             RGBColor[
              0.38685571627142323`, 0.5077348812686966, 0.9460900494105111], 
             UndirectedEdge[376, 448] -> 
             RGBColor[
              0.9051283578144917, 0.9255858485156985, 0.9321528841461747], 
             UndirectedEdge[326, 355] -> 
             RGBColor[
              0.8304768118928137, 0.23526370799810264`, 0.17681793552818148`],
              UndirectedEdge[257, 281] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[32, 89] -> 
             RGBColor[
              0.6092109643121336, 0.6880782890419994, 0.965264903215373], 
             UndirectedEdge[341, 397] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[160, 274] -> 
             RGBColor[
              0.4693994767887675, 0.5801186673193949, 0.9513719927612023], 
             UndirectedEdge[151, 235] -> 
             RGBColor[
              0.31653490518961214`, 0.44645699238381964`, 0.941468341894269], 
             UndirectedEdge[11, 372] -> 
             RGBColor[
              0.8740472245688059, 0.4191181540612454, 0.3950653321159444], 
             UndirectedEdge[99, 295] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[154, 199] -> 
             RGBColor[
              0.8752103907398564, 0.4195991531649818, 0.3757886584840803], 
             UndirectedEdge[169, 308] -> 
             RGBColor[
              0.2152452595664099, 0.34356679351495156`, 0.9355692711542569], 
             UndirectedEdge[158, 410] -> 
             RGBColor[
              0.2136055323425038, 0.3418433362379155, 0.9354758911146145], 
             UndirectedEdge[311, 465] -> 
             RGBColor[
              0.20300573055749768`, 0.3307022724956242, 0.9348722480839599], 
             UndirectedEdge[139, 428] -> 
             RGBColor[
              0.20589073788695234`, 0.3337345981189107, 0.9350365449833864], 
             UndirectedEdge[113, 364] -> 
             RGBColor[
              0.2720867421972659, 0.4033107957181348, 0.9388063095006463], 
             UndirectedEdge[89, 475] -> 
             RGBColor[
              0.900525267057583, 0.9233492562361874, 0.984509080001769], 
             UndirectedEdge[375, 441] -> 
             RGBColor[
              0.3248775159216287, 0.45329645143875275`, 0.9420140770036214], 
             UndirectedEdge[244, 295] -> 
             RGBColor[
              0.8706168078338911, 0.40101609835768304`, 0.23147033256236077`],
              UndirectedEdge[187, 260] -> 
             RGBColor[
              0.33960819065109193`, 0.4685732783631712, 0.942860511497924], 
             UndirectedEdge[207, 322] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[100, 457] -> 
             RGBColor[
              0.8638009847389825, 0.3780247266271895, 0.20499214689883155`], 
             UndirectedEdge[364, 416] -> 
             RGBColor[
              0.2990750168791546, 0.43160441949619144`, 0.9403459160671803], 
             UndirectedEdge[313, 386] -> 
             RGBColor[
              0.9107156444731642, 0.9305548067354691, 0.9535847686715226], 
             UndirectedEdge[31, 472] -> 
             RGBColor[
              0.21610683850656687`, 0.34447236760831645`, 0.935618336800307], 
             UndirectedEdge[37, 49] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[201, 406] -> 
             RGBColor[
              0.780813502467645, 0.8246149057210677, 0.7651321037016474], 
             UndirectedEdge[245, 376] -> 
             RGBColor[
              0.7344839183929459, 0.7898007058169793, 0.916823424923582], 
             UndirectedEdge[58, 215] -> 
             RGBColor[
              0.22259684759220016`, 0.35129377864765965`, 0.9359879332166258],
              UndirectedEdge[84, 407] -> 
             RGBColor[
              0.6835079427609747, 0.7526808668284215, 0.9690893420556808], 
             UndirectedEdge[100, 324] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[89, 176] -> 
             RGBColor[
              0.8712929271660014, 0.9002093457784437, 0.9875858912771132], 
             UndirectedEdge[75, 379] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[123, 422] -> 
             RGBColor[
              0.25330157722830876`, 0.3835663962875101, 0.9377365221458253], 
             UndirectedEdge[407, 455] -> 
             RGBColor[
              0.7743008553646631, 0.3415502590426163, 0.43266647927211443`], 
             UndirectedEdge[333, 358] -> 
             RGBColor[
              0.40118802656508795`, 0.5219106371393276, 0.9467843241894529], 
             UndirectedEdge[120, 124] -> 
             RGBColor[
              0.1949045707787678, 0.32218743992498255`, 0.9344108990191531], 
             UndirectedEdge[88, 433] -> 
             RGBColor[
              0.20558699861107904`, 0.3334153488817855, 0.9350192474809674], 
             UndirectedEdge[345, 456] -> 
             RGBColor[
              0.2405210855329868, 0.3701332891857508, 0.9370086920508198], 
             UndirectedEdge[392, 474] -> 
             RGBColor[
              0.4244363391619793, 0.5420471570165883, 0.9482656861104513], 
             UndirectedEdge[165, 333] -> 
             RGBColor[
              0.6312455916187752, 0.707646750738999, 0.9664464981826622], 
             UndirectedEdge[31, 133] -> 
             RGBColor[
              0.2480786626367777, 0.3780767818998994, 0.9374390848864473], 
             UndirectedEdge[171, 208] -> 
             RGBColor[
              0.9742007870656089, 0.924158064524564, 0.38148971018664135`], 
             UndirectedEdge[284, 472] -> 
             RGBColor[
              0.24808825888161617`, 0.3780868681616617, 0.9374396313783945], 
             UndirectedEdge[196, 427] -> 
             RGBColor[
              0.22341549837051072`, 0.3521542325211213, 0.9360345541673653], 
             UndirectedEdge[179, 334] -> 
             RGBColor[
              0.24162960930249294`, 0.37129841795196816`, 0.9370718208395792],
              UndirectedEdge[97, 233] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[21, 409] -> 
             RGBColor[
              0.6816616461375005, 0.7497071065976464, 0.9699591654296765], 
             UndirectedEdge[63, 344] -> 
             RGBColor[
              0.2634249915478959, 0.3942067465989362, 0.9383130356150764], 
             UndirectedEdge[292, 398] -> 
             RGBColor[
              0.2511316087278431, 0.3812856218095713, 0.9376129456499045], 
             UndirectedEdge[71, 197] -> 
             RGBColor[
              0.33670866645889475`, 0.4615510962735853, 0.9428409173993011], 
             UndirectedEdge[81, 121] -> 
             RGBColor[
              0.3705335839034893, 0.4937931661956242, 0.9448883940271157], 
             UndirectedEdge[163, 317] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[167, 172] -> 
             RGBColor[
              0.41770668424733426`, 0.5361058055196428, 0.9478679522159678], 
             UndirectedEdge[191, 488] -> 
             RGBColor[
              0.2118176137321737, 0.33996412041787133`, 0.9353740717947447], 
             UndirectedEdge[392, 490] -> 
             RGBColor[
              0.39194710024697893`, 0.5139066112250432, 0.9461955005358933], 
             UndirectedEdge[251, 272] -> 
             RGBColor[
              0.5091918571496574, 0.6123883835338977, 0.9545144119703061], 
             UndirectedEdge[66, 255] -> 
             RGBColor[
              0.2590437385722598, 0.38960177193405976`, 0.9380635297395968], 
             UndirectedEdge[177, 194] -> 
             RGBColor[
              0.2061405372520611, 0.3339971530898346, 0.9350507706876843], 
             UndirectedEdge[36, 359] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[46, 377] -> 
             RGBColor[
              0.23632008893838022`, 0.36571777540625106`, 0.9367694515095745],
              UndirectedEdge[6, 306] -> 
             RGBColor[
              0.39873016479148204`, 0.5195148391452025, 0.9467014626610211], 
             UndirectedEdge[7, 455] -> 
             RGBColor[
              0.8626928878488475, 0.3737895921602789, 0.20327715629423396`], 
             UndirectedEdge[84, 482] -> 
             RGBColor[
              0.8075023357681443, 0.8504716957118587, 0.9807029363869016], 
             UndirectedEdge[83, 97] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[125, 408] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[184, 473] -> 
             RGBColor[
              0.7413125486005306, 0.611259827036092, 0.5903276772577556], 
             UndirectedEdge[410, 422] -> 
             RGBColor[
              0.24555176281029023`, 0.37542084996755853`, 0.9372951816795421],
              UndirectedEdge[202, 283] -> 
             RGBColor[
              0.2030998829602526, 0.3308012326405268, 0.9348776099240107], 
             UndirectedEdge[320, 329] -> 
             RGBColor[
              0.18940148668971674`, 0.3164033496317062, 0.934097506521365], 
             UndirectedEdge[146, 387] -> 
             RGBColor[
              0.20285490882715684`, 0.330543749294386, 0.9348636590095377], 
             UndirectedEdge[107, 170] -> 
             RGBColor[
              0.2681353000213933, 0.3981722683975148, 0.9386173577788594], 
             UndirectedEdge[273, 459] -> 
             RGBColor[
              0.23015334665587384`, 0.35923613827329337`, 0.9364182646594634],
              UndirectedEdge[5, 395] -> 
             RGBColor[
              0.8502020870562027, 0.32426772933006165`, 0.19322676477969444`],
              UndirectedEdge[104, 242] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[422, 437] -> 
             RGBColor[
              0.24484406285271326`, 0.3746770124413762, 0.9372548792139064], 
             UndirectedEdge[29, 177] -> 
             RGBColor[
              0.20252724292290822`, 0.33019935165380243`, 0.934844998921029], 
             UndirectedEdge[202, 285] -> 
             RGBColor[
              0.2734741466148518, 0.4024082751896524, 0.9389717595036591], 
             UndirectedEdge[182, 460] -> 
             RGBColor[
              0.8895334088722675, 0.9142691218847867, 0.9725212169169912], 
             UndirectedEdge[116, 333] -> 
             RGBColor[
              0.5510899875354679, 0.6448284816425902, 0.958510437577631], 
             UndirectedEdge[405, 472] -> 
             RGBColor[
              0.19387632575282085`, 0.32110668920821217`, 0.9343523419860775],
              UndirectedEdge[51, 96] -> 
             RGBColor[
              0.8633136325544521, 0.3762506380670908, 0.20377662205511443`], 
             UndirectedEdge[115, 402] -> 
             RGBColor[
              0.29155073363812734`, 0.41974850753859727`, 0.9400619534020693],
              UndirectedEdge[67, 120] -> 
             RGBColor[
              0.1852212022017432, 0.3120096055895012, 0.9338594455039515], 
             UndirectedEdge[72, 222] -> 
             RGBColor[
              0.28790125601795724`, 0.4190231172725106, 0.9397402325282525], 
             UndirectedEdge[84, 328] -> 
             RGBColor[
              0.5779012816849092, 0.667647836565725, 0.9602948070979291], 
             UndirectedEdge[123, 401] -> 
             RGBColor[
              0.1977072581497815, 0.3251332420525608, 0.9345705079187279], 
             UndirectedEdge[143, 178] -> 
             RGBColor[
              0.8770300475453819, 0.4797787542910352, 0.21761304086744773`], 
             UndirectedEdge[2, 385] -> 
             RGBColor[
              0.19593294950729245`, 0.32326833117163933`, 0.9344694636663926],
              UndirectedEdge[113, 487] -> 
             RGBColor[
              0.24699167010602574`, 0.37693428383077204`, 0.9373771822698823],
              UndirectedEdge[12, 430] -> 
             RGBColor[
              0.26020424486877647`, 0.39082153763204774`, 0.9381296188563681],
              UndirectedEdge[72, 344] -> 
             RGBColor[
              0.27319882109803817`, 0.4035699259834611, 0.9389029506098664], 
             UndirectedEdge[127, 221] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[466, 491] -> 
             RGBColor[
              0.2191139720880547, 0.34763305566574143`, 0.9357895886091172], 
             UndirectedEdge[236, 289] -> 
             RGBColor[
              0.3096443657778342, 0.4423391471866963, 0.9409615308378128], 
             UndirectedEdge[200, 298] -> 
             RGBColor[
              0.6411018808425886, 0.7189413070500743, 0.9652808713508684], 
             UndirectedEdge[231, 431] -> 
             RGBColor[
              0.8760289938084724, 0.418883452871858, 0.28559208007867803`], 
             UndirectedEdge[171, 238] -> 
             RGBColor[
              0.9459691488713833, 0.8234927105285037, 0.27538371279607904`], 
             UndirectedEdge[276, 306] -> 
             RGBColor[
              0.3968212348923211, 0.5178614200121557, 0.946579827335847], 
             UndirectedEdge[294, 296] -> 
             RGBColor[
              0.2044861367384871, 0.3322582732550172, 0.9349565550259025], 
             UndirectedEdge[1, 119] -> 
             RGBColor[
              0.2343699623005295, 0.3636680686646997, 0.9366583946825027], 
             UndirectedEdge[103, 444] -> 
             RGBColor[
              0.8988195489394581, 0.5923088386367739, 0.34150421650250623`], 
             UndirectedEdge[331, 486] -> 
             RGBColor[
              0.9107995251370908, 0.9275421047601026, 0.7915510675263803], 
             UndirectedEdge[100, 281] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[161, 477] -> 
             RGBColor[
              0.29594928626027256`, 0.4262693113688122, 0.9402429623457904], 
             UndirectedEdge[391, 475] -> 
             RGBColor[
              0.9474014423405053, 0.9030084206584965, 0.6316492874301871], 
             UndirectedEdge[2, 312] -> 
             RGBColor[
              0.2248220487628299, 0.35363260616389447`, 0.936114655131403], 
             UndirectedEdge[264, 341] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[73, 434] -> 
             RGBColor[
              0.8329068192640983, 0.2539418094898154, 0.17914491333122431`], 
             UndirectedEdge[241, 271] -> 
             RGBColor[
              0.3224050139052927, 0.4532867845480669, 0.9417784724221802], 
             UndirectedEdge[49, 51] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[5, 275] -> 
             RGBColor[
              0.8560290549644465, 0.34736971536429956`, 0.19791527993518332`],
              UndirectedEdge[18, 274] -> 
             RGBColor[
              0.6190583277740055, 0.6999055265984445, 0.9643248307985424], 
             UndirectedEdge[219, 445] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[177, 297] -> 
             RGBColor[
              0.22585915082839916`, 0.35472266619087656`, 0.9361737165597821],
              UndirectedEdge[250, 365] -> 
             RGBColor[
              0.3297610853863787, 0.45923924976533154`, 0.9422625362213943], 
             UndirectedEdge[325, 474] -> 
             RGBColor[
              0.4167250002286474, 0.5353679828157005, 0.9477743264124886], 
             UndirectedEdge[266, 403] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[214, 470] -> 
             RGBColor[
              0.2312739543273467, 0.36041396798664144`, 0.9364820816085633], 
             UndirectedEdge[152, 481] -> 
             RGBColor[
              0.24709358576825113`, 0.3770414036535972, 0.9373829862160753], 
             UndirectedEdge[289, 466] -> 
             RGBColor[
              0.28062655967903927`, 0.4118395931416923, 0.9393090097084835], 
             UndirectedEdge[126, 269] -> 
             RGBColor[
              0.8563654629268306, 0.3487034608338446, 0.19818596167822738`], 
             UndirectedEdge[183, 396] -> 
             RGBColor[
              0.2576449284246818, 0.38813153377926946`, 0.9379838695710464], 
             UndirectedEdge[54, 99] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[129, 306] -> 
             RGBColor[
              0.611794552731207, 0.6939125455037445, 0.9638185817259406], 
             UndirectedEdge[172, 236] -> 
             RGBColor[
              0.34183025049144444`, 0.4702169428160228, 0.9430123869509037], 
             UndirectedEdge[162, 284] -> 
             RGBColor[
              0.24849792958903924`, 0.3785174580497864, 0.9374629615191288], 
             UndirectedEdge[10, 189] -> 
             RGBColor[
              0.46358589832160735`, 0.5737817600479446, 0.9513611588765089], 
             UndirectedEdge[213, 332] -> 
             RGBColor[
              0.24567430192070422`, 0.375549646342032, 0.9373021601005997], 
             UndirectedEdge[199, 245] -> 
             RGBColor[
              0.7369662997669877, 0.7908272343094369, 0.8756839413586472], 
             UndirectedEdge[123, 139] -> 
             RGBColor[
              0.20173923156575024`, 0.3293711017546237, 0.9348001228399971], 
             UndirectedEdge[391, 482] -> 
             RGBColor[
              0.9443986272401945, 0.9007689260733432, 0.6367322701354043], 
             UndirectedEdge[184, 354] -> 
             RGBColor[
              0.8691146527768465, 0.7119909200930725, 0.6025983172674237], 
             UndirectedEdge[25, 316] -> 
             RGBColor[
              0.8717687253392568, 0.8873861911944285, 0.6881607060366124], 
             UndirectedEdge[106, 479] -> 
             RGBColor[
              0.18778223780521028`, 0.31470141638778093`, 0.9340052926928564],
              UndirectedEdge[118, 260] -> 
             RGBColor[
              0.2740921498982324, 0.4051143982656095, 0.938931653051092], 
             UndirectedEdge[304, 469] -> 
             RGBColor[
              0.20952654949252203`, 0.3375560666401347, 0.9352435990756223], 
             UndirectedEdge[93, 236] -> 
             RGBColor[
              0.339763414086625, 0.46842675300438635`, 0.9428806899628203], 
             UndirectedEdge[343, 445] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[204, 444] -> 
             RGBColor[
              0.8607679520740443, 0.5646159608390356, 0.460480186068581], 
             UndirectedEdge[150, 412] -> 
             RGBColor[
              0.2833356085457537, 0.41234186764598774`, 0.9395491519114617], 
             UndirectedEdge[14, 239] -> 
             RGBColor[
              0.3345592647628135, 0.4592535705757248, 0.9427199170015113], 
             UndirectedEdge[70, 442] -> 
             RGBColor[
              0.7163330593542951, 0.7749857656872733, 0.9191984709357774], 
             UndirectedEdge[93, 493] -> 
             RGBColor[
              0.4816317249932974, 0.5878907944791983, 0.952931377533405], 
             UndirectedEdge[228, 279] -> 
             RGBColor[
              0.4383339124328404, 0.5504152423024345, 0.9500617664474421], 
             UndirectedEdge[300, 456] -> 
             RGBColor[
              0.3344527759122877, 0.4587499886736949, 0.9427281930406164], 
             UndirectedEdge[168, 326] -> 
             RGBColor[
              0.8049147133652906, 0.36546603758664487`, 0.4357177825348484], 
             UndirectedEdge[193, 437] -> 
             RGBColor[
              0.18967305081090496`, 0.3166887807412348, 0.9341129716963235], 
             UndirectedEdge[224, 361] -> 
             RGBColor[
              0.3524580819682026, 0.4784564177658006, 0.943724946321429], 
             UndirectedEdge[12, 477] -> 
             RGBColor[
              0.25210090277797115`, 0.38230441131304815`, 0.9376681455121172],
              UndirectedEdge[212, 224] -> 
             RGBColor[
              0.24359556310747985`, 0.37336476004968, 0.9371837790004052], 
             UndirectedEdge[220, 490] -> 
             RGBColor[
              0.34441527509151576`, 0.47273693329437716`, 0.9431668146677299],
              UndirectedEdge[175, 208] -> 
             RGBColor[
              0.9939061257043407, 0.9897836599534299, 0.6078650602962729], 
             UndirectedEdge[242, 419] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[164, 205] -> 
             RGBColor[
              0.6628616176318347, 0.7337956536330927, 0.9690297243445348], 
             UndirectedEdge[257, 322] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[7, 54] -> 
             RGBColor[
              0.8626928878488475, 0.3737895921602789, 0.20327715629423396`], 
             UndirectedEdge[26, 67] -> 
             RGBColor[
              0.1959716730389698, 0.32330903205864586`, 0.9344716689142352], 
             UndirectedEdge[366, 488] -> 
             RGBColor[
              0.19450193224029588`, 0.32176424129229075`, 0.9343879693500374],
              UndirectedEdge[12, 243] -> 
             RGBColor[
              0.249485287780747, 0.37955523411139636`, 0.9375191901074809], 
             UndirectedEdge[271, 307] -> 
             RGBColor[
              0.26941629466210404`, 0.4005039860425267, 0.9386542314640918], 
             UndirectedEdge[9, 352] -> 
             RGBColor[
              0.22055895151159555`, 0.3491518206568699, 0.9358718780496325], 
             UndirectedEdge[404, 431] -> 
             RGBColor[
              0.8760289938084724, 0.418883452871858, 0.28559208007867803`], 
             UndirectedEdge[256, 287] -> 
             RGBColor[
              0.8515970726599524, 0.8845044060250485, 0.9857072830916294], 
             UndirectedEdge[254, 412] -> 
             RGBColor[
              0.2324070785907567, 0.36160495343171317`, 0.9365466113590574], 
             UndirectedEdge[42, 380] -> 
             RGBColor[
              0.2438951722116548, 0.3736796682144823, 0.9372008412956561], 
             UndirectedEdge[379, 404] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[134, 424] -> 
             RGBColor[
              0.2214617006289249, 0.3501006672167829, 0.9359232882763666], 
             UndirectedEdge[38, 253] -> 
             RGBColor[
              0.9437188064028268, 0.8124944389214359, 0.5419690901557521], 
             UndirectedEdge[103, 348] -> 
             RGBColor[
              0.978566104430201, 0.9381917456579405, 0.470622917898086], 
             UndirectedEdge[42, 452] -> 
             RGBColor[
              0.3329650931678352, 0.45942829664579143`, 0.942561382685969], 
             UndirectedEdge[164, 331] -> 
             RGBColor[
              0.854078896606874, 0.8864833450730073, 0.9859440016752372], 
             UndirectedEdge[6, 181] -> 
             RGBColor[
              0.36099048155066216`, 0.4870935440351898, 0.9442229721664271], 
             UndirectedEdge[172, 197] -> 
             RGBColor[
              0.39570626447019996`, 0.5171626103341097, 0.9464350311560986], 
             UndirectedEdge[80, 258] -> 
             RGBColor[
              0.9759706321031365, 0.9788304292212378, 0.7695262555512177], 
             UndirectedEdge[223, 268] -> 
             RGBColor[
              0.25782358431552455`, 0.3883193124479829, 0.9379940437597322], 
             UndirectedEdge[5, 69] -> 
             RGBColor[
              0.8720195914369621, 0.40574801684009487`, 0.23691988196683633`],
              UndirectedEdge[306, 486] -> 
             RGBColor[
              0.7286265300597087, 0.7824211957918601, 0.775286835218471], 
             UndirectedEdge[5, 348] -> 
             RGBColor[
              0.8657911144896757, 0.38473790158096455`, 0.21272342517580606`],
              UndirectedEdge[279, 409] -> 
             RGBColor[
              0.42270568812946974`, 0.5377275457694766, 0.9488314553822088], 
             UndirectedEdge[463, 483] -> 
             RGBColor[
              0.8980458063387537, 0.6139805254867295, 0.2518434419429105], 
             UndirectedEdge[351, 371] -> 
             RGBColor[
              0.5030810091361415, 0.6074628526147339, 0.9540235263671059], 
             UndirectedEdge[335, 421] -> 
             RGBColor[
              0.25863015359246655`, 0.38858598467637967`, 0.9380612529900733],
              UndirectedEdge[259, 418] -> 
             RGBColor[
              0.8610616366179067, 0.36732222461184755`, 0.20196461326343138`],
              UndirectedEdge[168, 302] -> 
             RGBColor[
              0.6341435577721554, 0.7117552233940616, 0.9657839443695666], 
             UndirectedEdge[87, 336] -> 
             RGBColor[
              0.8296409666047774, 0.38496720214627544`, 0.43813321681502193`],
              UndirectedEdge[36, 266] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[161, 430] -> 
             RGBColor[
              0.3040526283510779, 0.4347864376878118, 0.9407044356900414], 
             UndirectedEdge[220, 412] -> 
             RGBColor[
              0.2873479361219482, 0.41581714412703974`, 0.9398048138766548], 
             UndirectedEdge[372, 404] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[38, 287] -> 
             RGBColor[
              0.8686172360380824, 0.7546182599515294, 0.6110449273803248], 
             UndirectedEdge[171, 497] -> 
             RGBColor[
              0.9509833426511693, 0.843372317984329, 0.27941825080954996`], 
             UndirectedEdge[246, 411] -> 
             RGBColor[
              0.5849971602778163, 0.6728945252540688, 0.9612048898516654], 
             UndirectedEdge[75, 303] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[23, 39] -> 
             RGBColor[
              0.7492481098657082, 0.7981399836975582, 0.6930866813159002], 
             UndirectedEdge[61, 391] -> 
             RGBColor[
              0.8623939674573535, 0.3726044724173211, 0.20303663793067456`], 
             UndirectedEdge[19, 200] -> 
             RGBColor[
              0.44299594892189786`, 0.5517450674565645, 0.9506522507819574], 
             UndirectedEdge[208, 403] -> 
             RGBColor[
              0.8758809832712207, 0.41856687329883735`, 0.26948204651397445`],
              UndirectedEdge[108, 378] -> 
             RGBColor[
              0.3055376194253575, 0.43822641878786983`, 0.940720198433389], 
             UndirectedEdge[10, 451] -> 
             RGBColor[
              0.3426842136829911, 0.46965323577309337`, 0.9431145233823018], 
             UndirectedEdge[199, 262] -> 
             RGBColor[
              0.9714220598975036, 0.9770772777751602, 0.8826589706548171], 
             UndirectedEdge[3, 401] -> 
             RGBColor[
              0.19299516587638807`, 0.32018053430931837`, 0.934302161234674], 
             UndirectedEdge[241, 311] -> 
             RGBColor[
              0.28339808968705427`, 0.4122880340128587, 0.9395570857935246], 
             UndirectedEdge[179, 255] -> 
             RGBColor[
              0.26384605713258924`, 0.39464931322554897`, 0.9383370146772139],
              UndirectedEdge[276, 462] -> 
             RGBColor[
              0.2787032871192142, 0.40825445737764454`, 0.9392567352273402], 
             UndirectedEdge[167, 289] -> 
             RGBColor[
              0.38552079953372403`, 0.5082280098903162, 0.9458170961028769], 
             UndirectedEdge[164, 348] -> 
             RGBColor[
              0.9216993133442403, 0.8968203590434105, 0.6491069598649626], 
             UndirectedEdge[18, 172] -> 
             RGBColor[
              0.5660661695896078, 0.6548377812339787, 0.9607184994301604], 
             UndirectedEdge[289, 300] -> 
             RGBColor[
              0.36584591693848256`, 0.4912990781268415, 0.9445323562158461], 
             UndirectedEdge[59, 188] -> 
             RGBColor[
              0.4914195289334753, 0.5960123307393997, 0.9536534579044413], 
             UndirectedEdge[352, 357] -> 
             RGBColor[
              0.20925693798184208`, 0.337272687848053, 0.9352282450989436], 
             UndirectedEdge[161, 409] -> 
             RGBColor[
              0.4365148251401427, 0.5501192931853284, 0.9496955815684055], 
             UndirectedEdge[39, 157] -> 
             RGBColor[
              0.6618299544269467, 0.7336559859969052, 0.9683575393881558], 
             UndirectedEdge[216, 398] -> 
             RGBColor[
              0.2829967109142827, 0.4147778645716886, 0.939427616079228], 
             UndirectedEdge[279, 396] -> 
             RGBColor[
              0.28137487354650415`, 0.413073210667725, 0.9393352548404263], 
             UndirectedEdge[103, 390] -> 
             RGBColor[
              0.7762674998542347, 0.8212922468524215, 0.7949346926054996], 
             UndirectedEdge[128, 296] -> 
             RGBColor[
              0.21905420866091074`, 0.34757024051459295`, 0.9357861851703535],
              UndirectedEdge[362, 369] -> 
             RGBColor[
              0.18627079750730335`, 0.313112796803831, 0.9339192184038662], 
             UndirectedEdge[86, 412] -> 
             RGBColor[
              0.2170774423805613, 0.34549253381972456`, 0.9356736112550512], 
             UndirectedEdge[261, 299] -> 
             RGBColor[
              0.6925921556774102, 0.7578254740416488, 0.9716892363428151], 
             UndirectedEdge[208, 266] -> 
             RGBColor[
              0.8758809832712207, 0.41856687329883735`, 0.26948204651397445`],
              UndirectedEdge[211, 236] -> 
             RGBColor[
              0.26074470726775645`, 0.39138959788067107`, 0.9381603973904477],
              UndirectedEdge[19, 124] -> 
             RGBColor[
              0.24511713728705276`, 0.3749640309857861, 0.9372704303989646], 
             UndirectedEdge[319, 330] -> 
             RGBColor[
              0.20604176576710181`, 0.3338933379966685, 0.9350451457977351], 
             UndirectedEdge[137, 267] -> 
             RGBColor[
              0.3633910087702312, 0.4891727600587743, 0.9443759316381551], 
             UndirectedEdge[23, 240] -> 
             RGBColor[
              0.8757337238850049, 0.41825190036192983`, 0.2534537711039848], 
             UndirectedEdge[135, 369] -> 
             RGBColor[
              0.18790542144841682`, 0.3148308902070851, 0.9340123078191032], 
             UndirectedEdge[13, 335] -> 
             RGBColor[
              0.4272745801579895, 0.5421649599210498, 0.9490932341588676], 
             UndirectedEdge[176, 178] -> 
             RGBColor[
              0.9202554048713663, 0.8879171799621041, 0.6375652584344874], 
             UndirectedEdge[335, 459] -> 
             RGBColor[
              0.28047616225378147`, 0.41154752489637136`, 0.9393053508650615],
              UndirectedEdge[83, 326] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[33, 76] -> 
             RGBColor[
              0.7773631602461192, 0.8221474687086947, 0.7922109863395075], 
             UndirectedEdge[13, 285] -> 
             RGBColor[
              0.4368990030776415, 0.5505011513164912, 0.9497064938767648], 
             UndirectedEdge[225, 309] -> 
             RGBColor[
              0.20974081891219415`, 0.337781277385676, 0.9352558014020895], 
             UndirectedEdge[242, 499] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[13, 287] -> 
             RGBColor[
              0.68872640512068, 0.7553272678291727, 0.9706480699800565], 
             UndirectedEdge[265, 270] -> 
             RGBColor[
              0.1931041910883242, 0.32029512671966087`, 0.9343083700592054], 
             UndirectedEdge[191, 311] -> 
             RGBColor[
              0.22787572296700198`, 0.35684221136660643`, 0.9362885573598245],
              UndirectedEdge[47, 452] -> 
             RGBColor[
              0.5542646894631771, 0.6462940052378033, 0.9592562795562067], 
             UndirectedEdge[14, 80] -> 
             RGBColor[
              0.6859318225908408, 0.7505439617444168, 0.951794759405942], 
             UndirectedEdge[152, 292] -> 
             RGBColor[
              0.20369803536500936`, 0.33142992874297905`, 0.9349116738185744],
              UndirectedEdge[133, 311] -> 
             RGBColor[
              0.24377892093012438`, 0.3735574807468368, 0.9371942209571512], 
             UndirectedEdge[187, 398] -> 
             RGBColor[
              0.3319201491189798, 0.46079686735936753`, 0.9424115503574978], 
             UndirectedEdge[130, 442] -> 
             RGBColor[
              0.6401413651407276, 0.7157489165078108, 0.9668305248903115], 
             UndirectedEdge[304, 433] -> 
             RGBColor[
              0.2080639244096152, 0.3360187549422132, 0.9351603047409107], 
             UndirectedEdge[354, 409] -> 
             RGBColor[
              0.7016213313412318, 0.7656224177878801, 0.9718629380226298], 
             UndirectedEdge[29, 412] -> 
             RGBColor[
              0.2151767900587655, 0.34349482772119977`, 0.935565371917088], 
             UndirectedEdge[295, 391] -> 
             RGBColor[
              0.8623939674573535, 0.3726044724173211, 0.20303663793067456`], 
             UndirectedEdge[21, 298] -> 
             RGBColor[
              0.7508839123480333, 0.8053317537495459, 0.9758004321712048], 
             UndirectedEdge[383, 395] -> 
             RGBColor[
              0.7742514426418383, 0.7085541585318539, 0.6077294417407735], 
             UndirectedEdge[133, 241] -> 
             RGBColor[
              0.30061942099789657`, 0.430388745116024, 0.9405378151350005], 
             UndirectedEdge[142, 473] -> 
             RGBColor[
              0.4734736299079191, 0.580366653206442, 0.9525381002758618], 
             UndirectedEdge[95, 330] -> 
             RGBColor[
              0.2142643926988969, 0.3425358402466441, 0.9355134122372144], 
             UndirectedEdge[275, 431] -> 
             RGBColor[
              0.9634490731593783, 0.8811257523542364, 0.396825040020792], 
             UndirectedEdge[180, 474] -> 
             RGBColor[
              0.505167391968821, 0.6078946403171526, 0.9545364772327231], 
             UndirectedEdge[82, 173] -> 
             RGBColor[
              0.844192723800754, 0.2992353265545988, 0.18832903870459236`], 
             UndirectedEdge[205, 230] -> 
             RGBColor[
              0.3700829820093897, 0.493707900841167, 0.944848513673534], 
             UndirectedEdge[460, 463] -> 
             RGBColor[
              0.8490960260828695, 0.5965456532875175, 0.46506056118722205`], 
             UndirectedEdge[121, 500] -> 
             RGBColor[
              0.28288233778375105`, 0.41465765115982456`, 0.9394211026986441],
              UndirectedEdge[88, 241] -> 
             RGBColor[
              0.28248141588286296`, 0.41132455172417753`, 0.9395048825764732],
              UndirectedEdge[60, 73] -> 
             RGBColor[
              0.8251129096320492, 0.19403440474490768`, 0.17168145666561216`],
              UndirectedEdge[75, 400] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[141, 274] -> 
             RGBColor[
              0.39256014440333986`, 0.5129069049942494, 0.9464898857156867], 
             UndirectedEdge[299, 448] -> 
             RGBColor[
              0.6415035606000079, 0.7170888150898986, 0.9668163605370053], 
             UndirectedEdge[160, 389] -> 
             RGBColor[
              0.35134205464567747`, 0.4730619062714598, 0.9438260030366266], 
             UndirectedEdge[24, 268] -> 
             RGBColor[
              0.20851588844890323`, 0.3364937978036801, 0.9351860434243273], 
             UndirectedEdge[386, 498] -> 
             RGBColor[
              0.8260448459967887, 0.38209975318755884`, 0.4377902156211372], 
             UndirectedEdge[350, 476] -> 
             RGBColor[
              0.19421935887497294`, 0.3214672387691502, 0.9343718772149121], 
             UndirectedEdge[180, 331] -> 
             RGBColor[
              0.7154954793572077, 0.7771351534675488, 0.9726684783764996], 
             UndirectedEdge[225, 252] -> 
             RGBColor[
              0.1970572565472313, 0.32445004915579856`, 0.9345334912890539], 
             UndirectedEdge[100, 203] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[445, 471] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[373, 498] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[102, 309] -> 
             RGBColor[
              0.24307505381461134`, 0.3728176717806799, 0.9371541367662009], 
             UndirectedEdge[46, 86] -> 
             RGBColor[
              0.24605549105412944`, 0.3759503002900489, 0.9373238682578297], 
             UndirectedEdge[294, 385] -> 
             RGBColor[
              0.2030350129630147, 0.3307330501604344, 0.9348739156736345], 
             UndirectedEdge[27, 29] -> 
             RGBColor[
              0.20431304380785625`, 0.33207634161019856`, 0.9349466976395711],
              UndirectedEdge[274, 284] -> 
             RGBColor[
              0.39152884276049793`, 0.5118229415793216, 0.9464311546128009], 
             UndirectedEdge[284, 300] -> 
             RGBColor[
              0.3586150308586798, 0.48414605059779925`, 0.9441041977149605], 
             UndirectedEdge[159, 453] -> 
             RGBColor[
              0.4386026872571061, 0.5541934161210065, 0.9492025926373653], 
             UndirectedEdge[229, 232] -> 
             RGBColor[
              0.5642482406538483, 0.6557297115102981, 0.9595587106539356], 
             UndirectedEdge[259, 431] -> 
             RGBColor[
              0.8760289938084724, 0.418883452871858, 0.28559208007867803`], 
             UndirectedEdge[112, 483] -> 
             RGBColor[
              0.8686864922225178, 0.39450469054086185`, 0.22397142092169176`],
              UndirectedEdge[78, 376] -> 
             RGBColor[
              0.9710596774572359, 0.9260184962661202, 0.5825654932338206], 
             UndirectedEdge[76, 351] -> 
             RGBColor[
              0.7269288926583368, 0.7812026582430701, 0.7882406160481877], 
             UndirectedEdge[178, 498] -> 
             RGBColor[
              0.8637848357389819, 0.37797025225822195`, 0.20492941108331195`],
              UndirectedEdge[400, 431] -> 
             RGBColor[
              0.8760289938084724, 0.418883452871858, 0.28559208007867803`], 
             UndirectedEdge[18, 432] -> 
             RGBColor[
              0.7627827717291649, 0.8146109657293871, 0.9769907161418333], 
             UndirectedEdge[220, 325] -> 
             RGBColor[
              0.38679117901764243`, 0.5094408114003279, 0.9458669697943621], 
             UndirectedEdge[353, 380] -> 
             RGBColor[
              0.2011595261565179, 0.3287617946140746, 0.9347671094745387], 
             UndirectedEdge[5, 355] -> 
             RGBColor[
              0.8304768118928137, 0.23526370799810264`, 0.17681793552818148`],
              UndirectedEdge[367, 441] -> 
             RGBColor[
              0.31283134784024597`, 0.44063516501404976`, 0.9413280655520953],
              UndirectedEdge[21, 287] -> 
             RGBColor[
              0.8299656008339436, 0.8672560575616497, 0.9836440539982219], 
             UndirectedEdge[175, 182] -> 
             RGBColor[
              0.9746509917198269, 0.978851744377486, 0.8488163971932976], 
             UndirectedEdge[70, 371] -> 
             RGBColor[
              0.7661132779111547, 0.8155687218841894, 0.9230706203609627], 
             UndirectedEdge[217, 496] -> 
             RGBColor[
              0.19874942051831446`, 0.3262286207787995, 0.9346298575238747], 
             UndirectedEdge[195, 292] -> 
             RGBColor[
              0.2120103022106906, 0.3401666482259477, 0.9353850451185391], 
             UndirectedEdge[161, 285] -> 
             RGBColor[
              0.33299137779354726`, 0.4628421276366501, 0.942438894033659], 
             UndirectedEdge[168, 370] -> 
             RGBColor[
              0.5916646117623022, 0.6759087069348095, 0.9628156719089096], 
             UndirectedEdge[50, 173] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[19, 188] -> 
             RGBColor[
              0.3319186677271597, 0.45958431970506974`, 0.9424558062931185], 
             UndirectedEdge[147, 323] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[255, 260] -> 
             RGBColor[
              0.284773382847451, 0.41634105132452215`, 0.9395399334660819], 
             UndirectedEdge[29, 350] -> 
             RGBColor[
              0.19637165723223093`, 0.3237294408062259, 0.9344944474223179], 
             UndirectedEdge[348, 400] -> 
             RGBColor[
              0.8657911144896757, 0.38473790158096466`, 0.21272342517580606`],
              UndirectedEdge[26, 124] -> 
             RGBColor[
              0.2056550416159944, 0.33348686639412717`, 0.9350231224294367], 
             UndirectedEdge[18, 93] -> 
             RGBColor[
              0.5639993331847883, 0.6530475914223423, 0.960586802442077], 
             UndirectedEdge[64, 223] -> 
             RGBColor[
              0.2546024393338054, 0.3849336848398083, 0.9378106043182802], 
             UndirectedEdge[12, 335] -> 
             RGBColor[
              0.27951857139159386`, 0.4105410361854448, 0.9392508174820886], 
             UndirectedEdge[143, 498] -> 
             RGBColor[
              0.8305642118064, 0.2359355020328133, 0.17690162978413582`], 
             UndirectedEdge[44, 92] -> 
             RGBColor[
              0.6785116985525852, 0.7487777628799652, 0.9685913631255452], 
             UndirectedEdge[274, 389] -> 
             RGBColor[
              0.36588034959521865`, 0.4848647490542211, 0.9449705108705836], 
             UndirectedEdge[247, 401] -> 
             RGBColor[
              0.19433196502451466`, 0.32158559497196076`, 0.9343782899685427],
              UndirectedEdge[111, 182] -> 
             RGBColor[
              0.9695152153683666, 0.9767279688727253, 0.933929502300139], 
             UndirectedEdge[157, 190] -> 
             RGBColor[
              0.5811750262089507, 0.6652253629216612, 0.9628235461914189], 
             UndirectedEdge[100, 360] -> 
             RGBColor[
              0.8191009627097754, 0.1478239462483719, 0.1659244095033199], 
             UndirectedEdge[59, 468] -> 
             RGBColor[
              0.48548279693465646`, 0.5908702318708492, 0.9532751745911225], 
             UndirectedEdge[101, 129] -> 
             RGBColor[
              0.6254095214017883, 0.7049657904178714, 0.9648904019329624], 
             UndirectedEdge[180, 382] -> 
             RGBColor[
              0.46332842266028784`, 0.5716558279898428, 0.9518705351051313], 
             UndirectedEdge[145, 402] -> 
             RGBColor[
              0.33044282611088804`, 0.46062656262855517`, 0.9422768005326982],
              UndirectedEdge[90, 263] -> 
             RGBColor[
              0.4902638758215754, 0.5951212073056378, 0.9535494701520902], 
             UndirectedEdge[98, 276] -> 
             RGBColor[
              0.2749015720573606, 0.4042586138049795, 0.9390402331787011], 
             UndirectedEdge[224, 464] -> 
             RGBColor[
              0.28776523572535795`, 0.41978988649006416`, 0.9396991765128184],
              UndirectedEdge[261, 313] -> 
             RGBColor[
              0.9521701236341322, 0.9636094831665644, 0.9575387339007462], 
             UndirectedEdge[78, 219] -> 
             RGBColor[
              0.863576315147662, 0.3772668633407367, 0.20411934796184356`], 
             UndirectedEdge[393, 424] -> 
             RGBColor[
              0.3045464501938735, 0.4319945031262181, 0.9408537890405738], 
             UndirectedEdge[169, 211] -> 
             RGBColor[
              0.20787663392282102`, 0.33582190076568974`, 0.9351496388247592],
              UndirectedEdge[176, 482] -> 
             RGBColor[
              0.9100238273170578, 0.9310780190221328, 0.9907844550489121], 
             UndirectedEdge[35, 94] -> 
             RGBColor[
              0.19771231040963783`, 0.3251385522980016, 0.9345707956374525], 
             UndirectedEdge[114, 296] -> 
             RGBColor[
              0.19143934787553057`, 0.3185452709458584, 0.9342135597011516], 
             UndirectedEdge[130, 175] -> 
             RGBColor[
              0.9140005204519457, 0.9309753937832106, 0.859835968889188], 
             UndirectedEdge[189, 383] -> 
             RGBColor[
              0.5829740029038133, 0.6723235840936835, 0.960312995494176], 
             UndirectedEdge[139, 437] -> 
             RGBColor[
              0.19328171719015474`, 0.3204817179084898, 0.9343184799080784], 
             UndirectedEdge[56, 324] -> 
             RGBColor[
              0.8764265597457015, 0.4197338062115088, 0.3288646788534969], 
             UndirectedEdge[398, 399] -> 
             RGBColor[
              0.30014888904900616`, 0.43280589130218833`, 0.9404044072496268],
              UndirectedEdge[405, 429] -> 
             RGBColor[
              0.2128579033922896, 0.34105753080882717`, 0.9354333147519176], 
             UndirectedEdge[12, 318] -> 
             RGBColor[
              0.2525038287839251, 0.3827279120922901, 0.9376910915520806], 
             UndirectedEdge[11, 205] -> 
             RGBColor[
              0.7162818128753168, 0.7745053780529972, 0.9031699004171979], 
             UndirectedEdge[226, 389] -> 
             RGBColor[
              0.23071843962178798`, 0.35983008680943257`, 0.9364504458678921],
              UndirectedEdge[294, 327] -> 
             RGBColor[
              0.20782428065513164`, 0.3357668741619594, 0.935146657383614], 
             UndirectedEdge[167, 218] -> 
             RGBColor[
              0.5986386322553329, 0.683547898239663, 0.9625669021197863], 
             UndirectedEdge[217, 481] -> 
             RGBColor[
              0.2406474095261515, 0.3702660637119706, 0.9370158860153509], 
             UndirectedEdge[247, 309] -> 
             RGBColor[
              0.21041747928262017`, 0.3384924903377391, 0.9352943362091559], 
             UndirectedEdge[79, 234] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[331, 372] -> 
             RGBColor[
              0.8207108366647649, 0.3778465589340292, 0.4372814530493224], 
             UndirectedEdge[27, 484] -> 
             RGBColor[
              0.20513686464962994`, 0.3329422295481609, 0.9349936130177764], 
             UndirectedEdge[103, 326] -> 
             RGBColor[
              0.8763449551304583, 0.4195592621909958, 0.3199825200895846], 
             UndirectedEdge[155, 394] -> 
             RGBColor[
              0.22097523638302924`, 0.34958936245073197`, 0.9358955848572224],
              UndirectedEdge[433, 469] -> 
             RGBColor[
              0.1879123802941655, 0.31483820439518323`, 0.9340127041150739], 
             UndirectedEdge[65, 412] -> 
             RGBColor[
              0.2124844072209095, 0.34066496265168167`, 0.9354120446974956], 
             UndirectedEdge[13, 161] -> 
             RGBColor[
              0.4356106212508812, 0.5493852197341049, 0.9496243993260349], 
             UndirectedEdge[229, 480] -> 
             RGBColor[
              0.4558972150742777, 0.5685887630665123, 0.9504660295382097], 
             UndirectedEdge[32, 448] -> 
             RGBColor[
              0.5919293414877744, 0.6742983920990104, 0.9636165666028987], 
             UndirectedEdge[251, 453] -> 
             RGBColor[
              0.4549456459177142, 0.5683488654918392, 0.9502439515117083], 
             UndirectedEdge[282, 310] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[392, 473] -> 
             RGBColor[
              0.5241730715613854, 0.6242799613386438, 0.9557686238662648], 
             UndirectedEdge[222, 344] -> 
             RGBColor[
              0.2425145104333196, 0.3722285051464392, 0.9371222146498859], 
             UndirectedEdge[266, 440] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[16, 361] -> 
             RGBColor[
              0.5282938438058984, 0.6266761633997737, 0.9563838424107522], 
             UndirectedEdge[412, 426] -> 
             RGBColor[
              0.221482079932092, 0.35012208715653403`, 0.9359244488475336], 
             UndirectedEdge[274, 460] -> 
             RGBColor[
              0.6542549538191047, 0.7274384825635528, 0.9678230605465845], 
             UndirectedEdge[180, 230] -> 
             RGBColor[
              0.4493012303473422, 0.5582450689465429, 0.9510229102327686], 
             UndirectedEdge[375, 450] -> 
             RGBColor[
              0.31062788570294697`, 0.44095413795057004`, 0.9411061031665402],
              UndirectedEdge[6, 123] -> 
             RGBColor[
              0.2715222173507861, 0.4003537105207884, 0.9388607085188945], 
             UndirectedEdge[170, 466] -> 
             RGBColor[
              0.23226952433681827`, 0.36146037518938046`, 0.9365387778477888],
              UndirectedEdge[267, 280] -> 
             RGBColor[
              0.47422028597903365`, 0.5827369663057078, 0.9521094415156451], 
             UndirectedEdge[52, 214] -> 
             RGBColor[
              0.19978832528187718`, 0.3273205755556704, 0.9346890216132377], 
             UndirectedEdge[358, 386] -> 
             RGBColor[
              0.61406122663775, 0.6928053141736124, 0.965331823983703], 
             UndirectedEdge[230, 413] -> 
             RGBColor[
              0.35288248502722674`, 0.4788096948773328, 0.9437525132156328], 
             UndirectedEdge[53, 207] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[188, 256] -> 
             RGBColor[
              0.6227687970873287, 0.6995989768913324, 0.9662311909897034], 
             UndirectedEdge[38, 87] -> 
             RGBColor[
              0.8767924040920562, 0.7611369170487428, 0.6118246822073715], 
             UndirectedEdge[22, 52] -> 
             RGBColor[
              0.18741101862312, 0.3143112414907485, 0.933984152309606], 
             UndirectedEdge[160, 460] -> 
             RGBColor[
              0.6397166588695635, 0.7156356397807915, 0.9666785527126276], 
             UndirectedEdge[63, 159] -> 
             RGBColor[
              0.3591807092964443, 0.4846284307952361, 0.944140519860194], 
             UndirectedEdge[285, 430] -> 
             RGBColor[
              0.3053410101778382, 0.4359023692701981, 0.9407865302407712], 
             UndirectedEdge[132, 356] -> 
             RGBColor[
              0.575775252833869, 0.6662108242154342, 0.9599298517837459], 
             UndirectedEdge[99, 373] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[243, 396] -> 
             RGBColor[
              0.2568146858534386, 0.38725889619647347`, 0.937936588484848], 
             UndirectedEdge[118, 292] -> 
             RGBColor[
              0.2208755284929752, 0.34948456313643983`, 0.9358899066403883], 
             UndirectedEdge[84, 176] -> 
             RGBColor[
              0.7812728109768734, 0.8295712798392683, 0.9786967649570286], 
             UndirectedEdge[334, 385] -> 
             RGBColor[
              0.20166339359782656`, 0.32929139124193096`, 0.9347958039799161],
              UndirectedEdge[25, 325] -> 
             RGBColor[
              0.5921088463130788, 0.6772490844170992, 0.9624395213048671], 
             UndirectedEdge[321, 397] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[201, 235] -> 
             RGBColor[
              0.4575805493651263, 0.5676469657175549, 0.9512363666717771], 
             UndirectedEdge[321, 498] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[368, 492] -> 
             RGBColor[
              0.18751313635976613`, 0.31441857370660203`, 0.9339899677636383],
              UndirectedEdge[239, 387] -> 
             RGBColor[
              0.2385452232211448, 0.3680565326190986, 0.9368961696151867], 
             UndirectedEdge[196, 500] -> 
             RGBColor[
              0.2545900551674532, 0.38492066829577065`, 0.9378098990583272], 
             UndirectedEdge[122, 185] -> 
             RGBColor[
              0.2643164513876104, 0.39404556499127835`, 0.9384040120398665], 
             UndirectedEdge[350, 377] -> 
             RGBColor[
              0.1885369074382775, 0.3154946220209529, 0.9340482700120258], 
             UndirectedEdge[315, 353] -> 
             RGBColor[
              0.1924173261577683, 0.31957318812789476`, 0.9342692541175359], 
             UndirectedEdge[102, 480] -> 
             RGBColor[
              0.373349255813557, 0.49325764384386095`, 0.9453464631309425], 
             UndirectedEdge[127, 253] -> 
             RGBColor[
              0.8742585681452911, 0.4192055500614041, 0.39156282211394233`], 
             UndirectedEdge[159, 192] -> 
             RGBColor[
              0.6447596298856625, 0.718476583875131, 0.9677105713215501], 
             UndirectedEdge[201, 289] -> 
             RGBColor[
              0.440683211853583, 0.5530113412499335, 0.9501596832672705], 
             UndirectedEdge[29, 194] -> 
             RGBColor[
              0.20624169499829867`, 0.3341034762949018, 0.935056531471683], 
             UndirectedEdge[79, 388] -> 
             RGBColor[
              0.8529860941236527, 0.4035819731432213, 0.44035989591821356`], 
             UndirectedEdge[246, 402] -> 
             RGBColor[
              0.4049563520885143, 0.5250559960278285, 0.9470572012623077], 
             UndirectedEdge[185, 398] -> 
             RGBColor[
              0.30864187886940686`, 0.4406343996690694, 0.9409282795613612], 
             UndirectedEdge[133, 304] -> 
             RGBColor[
              0.24533917292446922`, 0.3751974045185834, 0.9372830750000432], 
             UndirectedEdge[107, 314] -> 
             RGBColor[
              0.4603925267300639, 0.5691703128729416, 0.9516675997547801], 
             UndirectedEdge[13, 279] -> 
             RGBColor[
              0.4218014842402082, 0.536993472318253, 0.9487602731398381], 
             UndirectedEdge[180, 418] -> 
             RGBColor[
              0.7760216792869205, 0.7613486519842765, 0.619693218697663], 
             UndirectedEdge[112, 207] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[308, 369] -> 
             RGBColor[
              0.21139967119728387`, 0.33952483631461483`, 0.9353502705856733],
              UndirectedEdge[45, 292] -> 
             RGBColor[
              0.24018663766573572`, 0.36978176327205037`, 0.9369896457395511],
              UndirectedEdge[348, 418] -> 
             RGBColor[
              0.9556411266613736, 0.8598361892892182, 0.29359605765885616`], 
             UndirectedEdge[51, 264] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[201, 218] -> 
             RGBColor[
              0.6538010445751918, 0.7283312295992802, 0.96690948928418], 
             UndirectedEdge[262, 376] -> 
             RGBColor[
              0.968939678523462, 0.9760507492827026, 0.9237984542197519], 
             UndirectedEdge[304, 307] -> 
             RGBColor[
              0.23196962243821045`, 0.361145159279065, 0.9365216988783283], 
             UndirectedEdge[8, 166] -> 
             RGBColor[
              0.25498529523312863`, 0.38533609066446306`, 0.9378324073953621],
              UndirectedEdge[66, 312] -> 
             RGBColor[
              0.25430218522603054`, 0.38461809873532704`, 0.9377935052910287],
              UndirectedEdge[202, 430] -> 
             RGBColor[
              0.24453539717238243`, 0.37435258524081405`, 0.9372373011600414],
              UndirectedEdge[348, 404] -> 
             RGBColor[
              0.8657911144896757, 0.38473790158096466`, 0.21272342517580606`],
              UndirectedEdge[1, 113] -> 
             RGBColor[
              0.2610717066577763, 0.3917332949725406, 0.938179019521957], 
             UndirectedEdge[29, 377] -> 
             RGBColor[
              0.19479365087519235`, 0.32207085607359665`, 0.9344045822947358],
              UndirectedEdge[259, 404] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[131, 449] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[423, 465] -> 
             RGBColor[
              0.17977821903452834`, 0.30628868517569324`, 0.9335494756647507],
              UndirectedEdge[177, 412] -> 
             RGBColor[
              0.2150756323125279, 0.34338850451613256`, 0.9355596111330893], 
             UndirectedEdge[139, 158] -> 
             RGBColor[
              0.2143619533681344, 0.34263838269571634`, 0.9355189681729995], 
             UndirectedEdge[454, 500] -> 
             RGBColor[
              0.2969342258477388, 0.4283948237797348, 0.9402591327630841], 
             UndirectedEdge[430, 459] -> 
             RGBColor[
              0.261161835730964, 0.3918280263429743, 0.938184152239341], 
             UndirectedEdge[474, 490] -> 
             RGBColor[
              0.3743490963025207, 0.49866410470974976`, 0.9450741712858564], 
             UndirectedEdge[443, 451] -> 
             RGBColor[
              0.521489697428266, 0.6147628649184023, 0.9578856335096356], 
             UndirectedEdge[182, 483] -> 
             RGBColor[
              0.9629580792560939, 0.9404214301836048, 0.652695538050524], 
             UndirectedEdge[92, 457] -> 
             RGBColor[
              0.8072191088446563, 0.7991593994494468, 0.6265274116797456], 
             UndirectedEdge[38, 184] -> 
             RGBColor[
              0.8878066027772542, 0.5834378112927188, 0.2280954180565736], 
             UndirectedEdge[51, 457] -> 
             RGBColor[
              0.8638009847389825, 0.3780247266271895, 0.20499214689883155`], 
             UndirectedEdge[321, 455] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[251, 435] -> 
             RGBColor[
              0.4507346269340168, 0.564825412094351, 0.9499413897526227], 
             UndirectedEdge[16, 441] -> 
             RGBColor[
              0.5075871140234716, 0.6087410348127357, 0.9550644278992582], 
             UndirectedEdge[302, 390] -> 
             RGBColor[
              0.5231595548827668, 0.6237635205800223, 0.9556041830384168], 
             UndirectedEdge[186, 455] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[349, 353] -> 
             RGBColor[
              0.19626227991525308`, 0.3236144783111598, 0.9344882185459253], 
             UndirectedEdge[125, 406] -> 
             RGBColor[
              0.8761600890568056, 0.41916385235227993`, 0.29986098883365586`],
              UndirectedEdge[307, 433] -> 
             RGBColor[
              0.2103554532398539, 0.33842729703411356`, 0.9352908039177796], 
             UndirectedEdge[406, 419] -> 
             RGBColor[
              0.8761600890568056, 0.41916385235228004`, 0.29986098883365586`],
              UndirectedEdge[237, 274] -> 
             RGBColor[
              0.4534869550610022, 0.5663779417903663, 0.9503464835750837], 
             UndirectedEdge[203, 264] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[69, 231] -> 
             RGBColor[
              0.8720195914369621, 0.405748016840095, 0.23691988196683633`], 
             UndirectedEdge[328, 399] -> 
             RGBColor[
              0.3903444167194412, 0.5114017266359476, 0.9462887257399559], 
             UndirectedEdge[78, 262] -> 
             RGBColor[
              0.953970946509212, 0.9135788430387926, 0.625155004871462], 
             UndirectedEdge[27, 412] -> 
             RGBColor[
              0.21686143319747594`, 0.34526549447252863`, 0.9356613098516314],
              UndirectedEdge[147, 221] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[93, 289] -> 
             RGBColor[
              0.3437007342510835, 0.4721180339322616, 0.9431212847572212], 
             UndirectedEdge[141, 235] -> 
             RGBColor[
              0.3242794390168753, 0.4545969884680785, 0.9419093816387205], 
             UndirectedEdge[185, 464] -> 
             RGBColor[
              0.3004465755354037, 0.43202061625278937`, 0.9404615691603544], 
             UndirectedEdge[6, 189] -> 
             RGBColor[
              0.4338625957179959, 0.5480369292693235, 0.9494672163178912], 
             UndirectedEdge[38, 316] -> 
             RGBColor[
              0.942615665830955, 0.799915878171712, 0.3187661896988654], 
             UndirectedEdge[322, 343] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[93, 141] -> 
             RGBColor[
              0.3375011498141227, 0.46604896981814714`, 0.9427518573592213], 
             UndirectedEdge[191, 237] -> 
             RGBColor[
              0.3261149973492088, 0.44953101328405887`, 0.9422700448294907], 
             UndirectedEdge[145, 461] -> 
             RGBColor[
              0.42511156853211396`, 0.5402277520345683, 0.9489710633786737], 
             UndirectedEdge[420, 500] -> 
             RGBColor[
              0.2460794158023615, 0.3759754467173574, 0.9373252307368479], 
             UndirectedEdge[402, 458] -> 
             RGBColor[
              0.4023396027301842, 0.5229080745336331, 0.9468577016043941], 
             UndirectedEdge[148, 263] -> 
             RGBColor[
              0.527788364966513, 0.6251072494545038, 0.9568303661574955], 
             UndirectedEdge[126, 499] -> 
             RGBColor[
              0.8563654629268306, 0.3487034608338446, 0.19818596167822738`], 
             UndirectedEdge[133, 371] -> 
             RGBColor[
              0.4038248401636344, 0.5172459248516914, 0.9478141711009334], 
             UndirectedEdge[72, 245] -> 
             RGBColor[
              0.40076249699854094`, 0.5207377736167305, 0.9469794378766433], 
             UndirectedEdge[57, 131] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[15, 173] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[138, 415] -> 
             RGBColor[
              0.19037454320889569`, 0.31742609372870995`, 0.934152920650624], 
             UndirectedEdge[105, 109] -> 
             RGBColor[
              0.28171832903511257`, 0.41140686866770654`, 0.9394290448060217],
              UndirectedEdge[235, 284] -> 
             RGBColor[
              0.32324813737403335`, 0.4535130250531508, 0.9418506505358348], 
             UndirectedEdge[150, 473] -> 
             RGBColor[
              0.4726289188297277, 0.5796350069269258, 0.9524842760329082], 
             UndirectedEdge[74, 417] -> 
             RGBColor[
              0.23919755835177475`, 0.36874217820182686`, 0.9369333191358328],
              UndirectedEdge[20, 413] -> 
             RGBColor[
              0.4400008523109076, 0.555093246571965, 0.9493776651595607], 
             UndirectedEdge[34, 467] -> 
             RGBColor[
              0.26986184992211565`, 0.40097229287063396`, 0.9386796051770095],
              UndirectedEdge[62, 110] -> 
             RGBColor[
              0.7611613425809955, 0.8086288736350278, 0.7610013636522968], 
             UndirectedEdge[93, 389] -> 
             RGBColor[
              0.31082135500600144`, 0.43800681387811885`, 0.9412324825141183],
              UndirectedEdge[28, 408] -> 
             RGBColor[
              0.8613224849238736, 0.3683564012224616, 0.2021744979333091], 
             UndirectedEdge[93, 284] -> 
             RGBColor[
              0.3364698481712808, 0.4649650064032194, 0.9426931262563356], 
             UndirectedEdge[143, 313] -> 
             RGBColor[
              0.8841027954583874, 0.5189146200022339, 0.4295739266106804], 
             UndirectedEdge[361, 398] -> 
             RGBColor[
              0.35315773150982965`, 0.47919179379439375`, 0.9437647903277859],
              UndirectedEdge[105, 382] -> 
             RGBColor[
              0.2779618406141432, 0.4081531872040607, 0.9391896846855698], 
             UndirectedEdge[240, 495] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[13, 21] -> 
             RGBColor[
              0.680757442248239, 0.7489730331464229, 0.969887983187306], 
             UndirectedEdge[32, 179] -> 
             RGBColor[
              0.31490599852677015`, 0.44361194071062604`, 0.9414170615594284],
              UndirectedEdge[38, 79] -> 
             RGBColor[
              0.8446459694565934, 0.30129340921955317`, 0.18870723798989242`],
              UndirectedEdge[328, 407] -> 
             RGBColor[
              0.5826579050179238, 0.6713637468651524, 0.9607689028585917], 
             UndirectedEdge[357, 367] -> 
             RGBColor[
              0.23888728000708515`, 0.3684160559887748, 0.9369156492431183], 
             UndirectedEdge[196, 213] -> 
             RGBColor[
              0.25723659522050063`, 0.3877023496918546, 0.9379606155991431], 
             UndirectedEdge[233, 326] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[164, 372] -> 
             RGBColor[
              0.8384337610731512, 0.3919783377813091, 0.43897188140083576`], 
             UndirectedEdge[3, 278] -> 
             RGBColor[
              0.20104322166618976`, 0.32863955122060917`, 0.9347604861058716],
              UndirectedEdge[195, 399] -> 
             RGBColor[
              0.2610275825318536, 0.39168691771856473`, 0.9381765067182615], 
             UndirectedEdge[118, 187] -> 
             RGBColor[
              0.30166406888411185`, 0.428995808686236, 0.9406885113479817], 
             UndirectedEdge[61, 178] -> 
             RGBColor[
              0.8637848357389819, 0.3779702522582219, 0.20492941108331192`], 
             UndirectedEdge[2, 496] -> 
             RGBColor[
              0.20510743091696815`, 0.33291129282892695`, 0.9349919368102446],
              UndirectedEdge[103, 404] -> 
             RGBColor[
              0.8763449551304583, 0.4195592621909958, 0.3199825200895846], 
             UndirectedEdge[37, 374] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[236, 466] -> 
             RGBColor[
              0.27668923951458074`, 0.40814831221381703`, 0.9390684149140827],
              UndirectedEdge[150, 254] -> 
             RGBColor[
              0.2880175076881252, 0.41726284049417106`, 0.9398157791413707], 
             UndirectedEdge[148, 229] -> 
             RGBColor[
              0.5529788076305955, 0.64692594478167, 0.958435478889017], 
             UndirectedEdge[160, 432] -> 
             RGBColor[
              0.6131239207439269, 0.6948241064503374, 0.9640378781044934], 
             UndirectedEdge[48, 198] -> 
             RGBColor[
              0.21002858102618926`, 0.33808373361265665`, 0.9352721890287756],
              UndirectedEdge[89, 178] -> 
             RGBColor[
              0.9077540295115808, 0.8779489225910053, 0.6363728660925616], 
             UndirectedEdge[63, 239] -> 
             RGBColor[
              0.2771411890702042, 0.40862333985203414`, 0.9390941527726759], 
             UndirectedEdge[425, 462] -> 
             RGBColor[
              0.2196150434125822, 0.3481597133975768, 0.9358181238797805], 
             UndirectedEdge[44, 457] -> 
             RGBColor[
              0.8280575439248763, 0.8154385433120871, 0.6286043921422944], 
             UndirectedEdge[46, 254] -> 
             RGBColor[
              0.26138512726432483`, 0.39206271990203745`, 0.9381968683618358],
              UndirectedEdge[1, 452] -> 
             RGBColor[
              0.3302242085185564, 0.4565474530972755, 0.942405293359968], 
             UndirectedEdge[260, 299] -> 
             RGBColor[
              0.38540754335386535`, 0.5080941018004876, 0.945819774282403], 
             UndirectedEdge[321, 341] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[249, 406] -> 
             RGBColor[
              0.8761600890568056, 0.41916385235227993`, 0.29986098883365586`],
              UndirectedEdge[398, 496] -> 
             RGBColor[
              0.25262917012324787`, 0.38285965378701825`, 0.9376982295559292],
              UndirectedEdge[382, 462] -> 
             RGBColor[
              0.2750365104468856, 0.4050784797216278, 0.9390230914601827], 
             UndirectedEdge[63, 272] -> 
             RGBColor[
              0.4327060967749962, 0.5452426827083117, 0.9496736717344219], 
             UndirectedEdge[117, 270] -> 
             RGBColor[
              0.19147020359768469`, 0.3185777022662082, 0.9342153168888814], 
             UndirectedEdge[164, 404] -> 
             RGBColor[
              0.8384337610731512, 0.3919783377813091, 0.43897188140083576`], 
             UndirectedEdge[133, 191] -> 
             RGBColor[
              0.24509705427784428`, 0.37494292246977173`, 0.9372692867013004],
              UndirectedEdge[307, 469] -> 
             RGBColor[
              0.21181807832276073`, 0.33996460873203505`, 0.9353740982524913],
              UndirectedEdge[31, 237] -> 
             RGBColor[
              0.3290966057081422, 0.45266487271418654`, 0.9424398430146377], 
             UndirectedEdge[1, 468] -> 
             RGBColor[
              0.317495752696651, 0.44552270441513225`, 0.9415942474103278], 
             UndirectedEdge[346, 395] -> 
             RGBColor[
              0.9494788631662472, 0.8294154005518836, 0.3198310039905435], 
             UndirectedEdge[214, 223] -> 
             RGBColor[
              0.2605020778119116, 0.39113457893898207`, 0.9381465800018753], 
             UndirectedEdge[264, 397] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[103, 204] -> 
             RGBColor[
              0.9373194700932539, 0.9488844698763799, 0.809975514617866], 
             UndirectedEdge[110, 356] -> 
             RGBColor[
              0.7427296651345173, 0.7936652075463704, 0.7595503544862507], 
             UndirectedEdge[184, 253] -> 
             RGBColor[
              0.9322255008103006, 0.7603060225554952, 0.5323787942426484], 
             UndirectedEdge[115, 417] -> 
             RGBColor[
              0.24410759542701554`, 0.3739029384822362, 0.9372129384835188], 
             UndirectedEdge[243, 459] -> 
             RGBColor[
              0.2504428786429346, 0.3805617228223229, 0.9375737234904538], 
             UndirectedEdge[190, 349] -> 
             RGBColor[
              0.2752751587264147, 0.4033449321472721, 0.9391093400741414], 
             UndirectedEdge[128, 222] -> 
             RGBColor[
              0.2510869631489796, 0.3812386964754926, 0.9376104031502354], 
             UndirectedEdge[204, 275] -> 
             RGBColor[
              0.9068456198442363, 0.8406001496363356, 0.6268746543862641], 
             UndirectedEdge[178, 455] -> 
             RGBColor[
              0.8637848357389819, 0.37797025225822195`, 0.20492941108331195`],
              UndirectedEdge[84, 391] -> 
             RGBColor[
              0.8156476109000103, 0.7992621868904787, 0.624644580043521], 
             UndirectedEdge[54, 203] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[236, 314] -> 
             RGBColor[
              0.4535445571442839, 0.5629579737098113, 0.9512415409530388], 
             UndirectedEdge[277, 313] -> 
             RGBColor[
              0.9794761473860648, 0.9653471066434187, 0.651496031025925], 
             UndirectedEdge[186, 397] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[29, 297] -> 
             RGBColor[
              0.22596030857463673`, 0.3548289893959438, 0.9361794773437808], 
             UndirectedEdge[130, 208] -> 
             RGBColor[
              0.913099344561267, 0.9286383537262926, 0.7319810481348386], 
             UndirectedEdge[145, 450] -> 
             RGBColor[
              0.32420026945735514`, 0.45521957381528544`, 0.9418790303428113],
              UndirectedEdge[86, 350] -> 
             RGBColor[
              0.19827230955402672`, 0.32572714690475074`, 0.934602686760281], 
             UndirectedEdge[37, 281] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[281, 445] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[116, 224] -> 
             RGBColor[
              0.4898453633718138, 0.5905346758344123, 0.9546536353939092], 
             UndirectedEdge[112, 163] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[148, 480] -> 
             RGBColor[
              0.576482916411845, 0.6665757990614235, 0.9601288241510779], 
             UndirectedEdge[42, 487] -> 
             RGBColor[
              0.2552478049273309, 0.38561200499714565`, 0.9378473569340987], 
             UndirectedEdge[122, 319] -> 
             RGBColor[
              0.19763752801393172`, 0.3250599512586367, 0.9345665368906477], 
             UndirectedEdge[129, 348] -> 
             RGBColor[
              0.8615879645459554, 0.8493704684423902, 0.6432457722235755], 
             UndirectedEdge[93, 201] -> 
             RGBColor[
              0.4708022601623738, 0.5790989470676235, 0.9520788423922779], 
             UndirectedEdge[121, 427] -> 
             RGBColor[
              0.25170778098680857`, 0.3818912153851751, 0.937645757807682], 
             UndirectedEdge[269, 411] -> 
             RGBColor[
              0.7823157613673747, 0.34781156452747625`, 0.43346533019890965`],
              UndirectedEdge[76, 371] -> 
             RGBColor[
              0.7704973116084974, 0.816573463481717, 0.7916704815843216], 
             UndirectedEdge[61, 244] -> 
             RGBColor[
              0.8706168078338911, 0.40101609835768304`, 0.23147033256236077`],
              UndirectedEdge[184, 436] -> 
             RGBColor[
              0.9230065584441681, 0.7540860752952483, 0.5773398016096436], 
             UndirectedEdge[80, 293] -> 
             RGBColor[
              0.8642091954046907, 0.41214776090032323`, 0.42814428395185355`],
              UndirectedEdge[111, 460] -> 
             RGBColor[
              0.9045539423959997, 0.925414302012888, 0.9445379058811575], 
             UndirectedEdge[286, 358] -> 
             RGBColor[
              0.30001627431624434`, 0.4256508881874809, 0.9406537311281724], 
             UndirectedEdge[176, 244] -> 
             RGBColor[
              0.9305033630137299, 0.9224859491112958, 0.6773766406530607], 
             UndirectedEdge[99, 321] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[187, 478] -> 
             RGBColor[
              0.4419595423271288, 0.555502846692598, 0.9498580506334303], 
             UndirectedEdge[116, 185] -> 
             RGBColor[
              0.5025267031818595, 0.6027654055971375, 0.9554160280414452], 
             UndirectedEdge[97, 257] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[16, 313] -> 
             RGBColor[
              0.8124335820745439, 0.8535860695269795, 0.9438393627828742], 
             UndirectedEdge[166, 344] -> 
             RGBColor[
              0.23945512334966762`, 0.36901289534517634`, 0.9369479870814295],
              UndirectedEdge[103, 443] -> 
             RGBColor[
              0.8728831239162906, 0.898059262922825, 0.8036823482152753], 
             UndirectedEdge[74, 115] -> 
             RGBColor[
              0.22596376247749395`, 0.3548326196668369, 0.936179674038439], 
             UndirectedEdge[196, 332] -> 
             RGBColor[
              0.22366006402010474`, 0.35241128652520237`, 0.9360484818193071],
              UndirectedEdge[49, 203] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[95, 122] -> 
             RGBColor[
              0.20586015494572685`, 0.3337024535086123, 0.935034803330127], 
             UndirectedEdge[97, 209] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[484, 490] -> 
             RGBColor[
              0.27306794987010674`, 0.4012805048264995, 0.9389742880863683], 
             UndirectedEdge[128, 415] -> 
             RGBColor[
              0.215112556671643, 0.34342731435870205`, 0.9355617139207162], 
             UndirectedEdge[371, 442] -> 
             RGBColor[
              0.49686920952944263`, 0.6022507016564647, 0.9535812424780545], 
             UndirectedEdge[88, 311] -> 
             RGBColor[
              0.22564091581509077`, 0.3544932873549904, 0.936161288398624], 
             UndirectedEdge[15, 149] -> 
             RGBColor[
              0.8300337551067959, 0.23185817939204778`, 0.1763936638495297], 
             UndirectedEdge[117, 140] -> 
             RGBColor[
              0.1891020516318635, 0.31608862440062324`, 0.9340804541377947], 
             UndirectedEdge[199, 475] -> 
             RGBColor[
              0.9666260772642596, 0.9735004417799876, 0.8907773182602956], 
             UndirectedEdge[71, 169] -> 
             RGBColor[
              0.22996457913520382`, 0.3590377316405171, 0.9364075146284178], 
             UndirectedEdge[23, 51] -> 
             RGBColor[
              0.8757337238850049, 0.41825190036192983`, 0.2534537711039848], 
             UndirectedEdge[381, 416] -> 
             RGBColor[
              0.26441513407437683`, 0.3951746851048749, 0.9383720870161499], 
             UndirectedEdge[121, 447] -> 
             RGBColor[
              0.3594348735345609, 0.4841800211114614, 0.9441811940166118], 
             UndirectedEdge[244, 407] -> 
             RGBColor[
              0.8327384947978311, 0.845595536100449, 0.6677692177517128], 
             UndirectedEdge[255, 385] -> 
             RGBColor[
              0.2238798414279229, 0.35264228651551177`, 0.9360609978175509], 
             UndirectedEdge[30, 469] -> 
             RGBColor[
              0.18416602893623069`, 0.3109005515855985, 0.9337993549474696], 
             UndirectedEdge[80, 171] -> 
             RGBColor[
              0.9566931052658137, 0.9145293959267929, 0.61948306634346], 
             UndirectedEdge[214, 466] -> 
             RGBColor[
              0.23186057629826734`, 0.3610305448720602, 0.9365154888619778], 
             UndirectedEdge[199, 455] -> 
             RGBColor[
              0.8752103907398564, 0.41959915316498186`, 0.3757886584840803], 
             UndirectedEdge[175, 483] -> 
             RGBColor[
              0.9831143891312863, 0.9536903858164667, 0.5395991219078489], 
             UndirectedEdge[124, 416] -> 
             RGBColor[
              0.25810397876522506`, 0.3885412607245982, 0.9380126760578114], 
             UndirectedEdge[142, 396] -> 
             RGBColor[
              0.2996502424735361, 0.4293333836901839, 0.9404839653749997], 
             UndirectedEdge[185, 361] -> 
             RGBColor[
              0.3651394217782484, 0.4906871475285258, 0.9444873389689651], 
             UndirectedEdge[19, 26] -> 
             RGBColor[
              0.2440972272221243, 0.3738920408415133, 0.9372123480295886], 
             UndirectedEdge[341, 455] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[159, 239] -> 
             RGBColor[
              0.33728399078425725`, 0.4616135913067876, 0.9428935341342171], 
             UndirectedEdge[261, 482] -> 
             RGBColor[
              0.9313294242103154, 0.9480665236597952, 0.992816601900322], 
             UndirectedEdge[5, 97] -> RGBColor[0.817319, 0.134127, 0.164218], 
             UndirectedEdge[285, 396] -> 
             RGBColor[
              0.2964723923839374, 0.4265808896659632, 0.940281475577353], 
             UndirectedEdge[174, 424] -> 
             RGBColor[
              0.2286678735822072, 0.357674811888437, 0.9363336691654786], 
             UndirectedEdge[99, 186] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[79, 127] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[29, 86] -> 
             RGBColor[
              0.2045290529909416, 0.33230338095739453`, 0.934958999042991], 
             UndirectedEdge[127, 316] -> 
             RGBColor[
              0.8735231410973765, 0.4108198428949215, 0.24276088847601782`], 
             UndirectedEdge[197, 466] -> 
             RGBColor[
              0.3305652534933362, 0.45509397973190396`, 0.9424910591192776], 
             UndirectedEdge[183, 206] -> 
             RGBColor[
              0.22097903356863421`, 0.34959335353355825`, 0.935895801101325], 
             UndirectedEdge[25, 392] -> 
             RGBColor[
              0.5998201852464107, 0.6839282586179871, 0.9629308810028296], 
             UndirectedEdge[73, 91] -> 
             RGBColor[
              0.8818663519635108, 0.5061968871434602, 0.22954386621065234`], 
             UndirectedEdge[187, 464] -> 
             RGBColor[
              0.3237248457849767, 0.4521830839430875, 0.9419448399564911], 
             UndirectedEdge[17, 99] -> 
             RGBColor[
              0.8740328861463312, 0.4191122247550715, 0.39530295688299816`], 
             UndirectedEdge[110, 157] -> 
             RGBColor[
              0.9057608095719005, 0.9233348231066068, 0.7742214779103318], 
             UndirectedEdge[241, 429] -> 
             RGBColor[
              0.28762917450715453`, 0.416735172425056, 0.9397980398147002], 
             UndirectedEdge[27, 490] -> 
             RGBColor[
              0.27392877216704353`, 0.40218528363986605`, 0.9390233106427064],
              UndirectedEdge[372, 418] -> 
             RGBColor[
              0.8610616366179067, 0.36732222461184755`, 0.20196461326343138`],
              UndirectedEdge[65, 350] -> 
             RGBColor[
              0.19367927439437493`, 0.3208995757367078, 0.9343411202027254], 
             UndirectedEdge[189, 390] -> 
             RGBColor[
              0.5457757580048264, 0.6421243731228501, 0.957384613394067], 
             UndirectedEdge[263, 267] -> 
             RGBColor[
              0.3938098760277288, 0.5155200539804957, 0.9463141949614547], 
             UndirectedEdge[25, 490] -> 
             RGBColor[
              0.5497329423869521, 0.6405452063111485, 0.9597393661782347], 
             UndirectedEdge[360, 494] -> 
             RGBColor[
              0.8715713699457228, 0.44237438137280577`, 0.4251276579378526], 
             UndirectedEdge[61, 203] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[36, 104] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[33, 241] -> 
             RGBColor[
              0.45030985755818603`, 0.5615504833446909, 0.9507175406924926], 
             UndirectedEdge[82, 419] -> 
             RGBColor[
              0.844192723800754, 0.2992353265545988, 0.18832903870459236`], 
             UndirectedEdge[5, 404] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[40, 396] -> 
             RGBColor[
              0.23189457560972082`, 0.36106628030407867`, 0.9365174250724676],
              UndirectedEdge[169, 369] -> 
             RGBColor[
              0.1961253105543787, 0.32347051482852174`, 0.9344804183434514], 
             UndirectedEdge[268, 491] -> 
             RGBColor[
              0.2006246214741492, 0.3281995758779894, 0.9347366474441984], 
             UndirectedEdge[4, 151] -> 
             RGBColor[
              0.23787775829421978`, 0.3673549846611798, 0.9368581584750242], 
             UndirectedEdge[6, 390] -> 
             RGBColor[
              0.44622497203026434`, 0.5580732632783292, 0.9504404278660695], 
             UndirectedEdge[376, 482] -> 
             RGBColor[
              0.9611408807899072, 0.9702344187023767, 0.9369997845304479], 
             UndirectedEdge[158, 278] -> 
             RGBColor[
              0.21837803574196735`, 0.3468595399049442, 0.9357476781229279], 
             UndirectedEdge[317, 445] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[133, 351] -> 
             RGBColor[
              0.3602564212134738, 0.4818751196130445, 0.9443843055647996], 
             UndirectedEdge[239, 454] -> 
             RGBColor[
              0.28757758461924476`, 0.4185604006032694, 0.9397262858870317], 
             UndirectedEdge[140, 198] -> 
             RGBColor[
              0.18662011133920806`, 0.3134799477889389, 0.9339391113098297], 
             UndirectedEdge[252, 309] -> 
             RGBColor[
              0.20616935749267296`, 0.33402744499002646`, 0.9350524119577515],
              UndirectedEdge[161, 243] -> 
             RGBColor[
              0.29333367126304843`, 0.4235201341671604, 0.9400940069411541], 
             UndirectedEdge[244, 455] -> 
             RGBColor[
              0.8706168078338911, 0.40101609835768304`, 0.23147033256236077`],
              UndirectedEdge[401, 451] -> 
             RGBColor[
              0.23914595187837517`, 0.36868793652624454`, 0.9369303802235176],
              UndirectedEdge[210, 225] -> 
             RGBColor[
              0.22552288916917368`, 0.3543692338668101, 0.9361545669557438], 
             UndirectedEdge[107, 223] -> 
             RGBColor[
              0.31217871061400504`, 0.4444646854438693, 0.9411255648557215], 
             UndirectedEdge[5, 204] -> 
             RGBColor[
              0.8382933582650444, 0.3918663843932574, 0.4389584896556594], 
             UndirectedEdge[59, 200] -> 
             RGBColor[
              0.6024968101282133, 0.6881730784908944, 0.96184990239328], 
             UndirectedEdge[328, 481] -> 
             RGBColor[
              0.38472268680152, 0.5054929320539487, 0.9459685765377344], 
             UndirectedEdge[55, 434] -> 
             RGBColor[
              0.8349696694427251, 0.26979777990945364`, 0.18112030099193344`],
              UndirectedEdge[269, 499] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[377, 476] -> 
             RGBColor[
              0.19264135251793435`, 0.3198086540365209, 0.93428201208733], 
             UndirectedEdge[260, 478] -> 
             RGBColor[
              0.41438762334124934`, 0.5316214362719716, 0.9481011923365408], 
             UndirectedEdge[163, 207] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[238, 258] -> 
             RGBColor[
              0.9652466757087061, 0.8877937438229484, 0.4254269020038368], 
             UndirectedEdge[10, 443] -> 
             RGBColor[
              0.5725638986959316, 0.6605851101273537, 0.9610820260344628], 
             UndirectedEdge[231, 326] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[91, 287] -> 
             RGBColor[
              0.901066080902311, 0.8822512626026671, 0.6499094997146282], 
             UndirectedEdge[242, 249] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[83, 209] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[306, 431] -> 
             RGBColor[
              0.7282987506324737, 0.7817201087405883, 0.7396100673840913], 
             UndirectedEdge[176, 376] -> 
             RGBColor[
              0.9349113559986364, 0.9493340028297863, 0.9349936131005747], 
             UndirectedEdge[30, 191] -> 
             RGBColor[
              0.20407545440505548`, 0.3318266200838168, 0.9349331672745637], 
             UndirectedEdge[209, 444] -> 
             RGBColor[
              0.8285562969045, 0.22050178822288907`, 0.17497884820646079`], 
             UndirectedEdge[169, 289] -> 
             RGBColor[
              0.2567762924328988, 0.386771450071715, 0.9379507722721243], 
             UndirectedEdge[20, 46] -> 
             RGBColor[
              0.3775120116687234, 0.49883606233675915`, 0.9454740124415332], 
             UndirectedEdge[49, 100] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[404, 486] -> 
             RGBColor[
              0.8762475134266291, 0.4193508442393725, 0.30937659196826445`], 
             UndirectedEdge[103, 431] -> 
             RGBColor[
              0.9939229234083959, 0.9894100725942807, 0.579925900252394], 
             UndirectedEdge[219, 238] -> 
             RGBColor[
              0.857059891141737, 0.3514566373014637, 0.19874471492026624`], 
             UndirectedEdge[249, 499] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[254, 377] -> 
             RGBColor[
              0.21202393940718356`, 0.34018098178411005`, 0.935385821736705], 
             UndirectedEdge[57, 434] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[75, 104] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[132, 365] -> 
             RGBColor[
              0.47996279510956574`, 0.5834591273930367, 0.9535665537870656], 
             UndirectedEdge[38, 77] -> 
             RGBColor[
              0.9192907829722123, 0.7949315839058828, 0.6126751046012756], 
             UndirectedEdge[172, 314] -> 
             RGBColor[
              0.4896677620223526, 0.594527050267013, 0.9535329918605306], 
             UndirectedEdge[398, 481] -> 
             RGBColor[
              0.29452715913108485`, 0.4268970967201894, 0.9400842580474054], 
             UndirectedEdge[143, 165] -> 
             RGBColor[
              0.8397048936039028, 0.4842390340274436, 0.4505134128142734], 
             UndirectedEdge[261, 475] -> 
             RGBColor[
              0.9343322393106261, 0.9503060182449484, 0.9877336191951046], 
             UndirectedEdge[288, 373] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[78, 171] -> 
             RGBColor[
              0.9557437848802708, 0.8622080495874132, 0.28344566235844504`], 
             UndirectedEdge[6, 370] -> 
             RGBColor[
              0.3687674465860833, 0.4938295602672435, 0.944718513501584], 
             UndirectedEdge[264, 295] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[45, 464] -> 
             RGBColor[
              0.27751991420487765`, 0.40902140398113634`, 0.9391157206088221],
              UndirectedEdge[228, 318] -> 
             RGBColor[
              0.41679226574295297`, 0.5277736058120767, 0.9488350015364635], 
             UndirectedEdge[7, 295] -> 
             RGBColor[
              0.8626928878488475, 0.3737895921602789, 0.20327715629423396`], 
             UndirectedEdge[225, 320] -> 
             RGBColor[
              0.19454073474396477`, 0.32180502518386755`, 0.9343901790952183],
              UndirectedEdge[137, 148] -> 
             RGBColor[
              0.4973694977090155, 0.5987599555327824, 0.9548921028341959], 
             UndirectedEdge[61, 455] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[11, 331] -> 
             RGBColor[
              0.9074990918503562, 0.9271930694929118, 0.9200841777479003], 
             UndirectedEdge[20, 392] -> 
             RGBColor[
              0.4556885448241814, 0.5686811373406109, 0.9503772710544247], 
             UndirectedEdge[348, 431] -> 
             RGBColor[
              0.9780921624472222, 0.937178031679234, 0.41903725788172613`], 
             UndirectedEdge[241, 351] -> 
             RGBColor[
              0.39987558997040373`, 0.5206056728790665, 0.946747170401173], 
             UndirectedEdge[343, 374] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[162, 389] -> 
             RGBColor[
              0.2228494364237599, 0.35155926552468586`, 0.9360023177769115], 
             UndirectedEdge[207, 266] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[98, 425] -> 
             RGBColor[
              0.21581332835072858`, 0.34416386982491176`, 0.9356016218311414],
              UndirectedEdge[151, 284] -> 
             RGBColor[
              0.2924066815982661, 0.42466834038715606`, 0.9399634999888766], 
             UndirectedEdge[41, 365] -> 
             RGBColor[
              0.4515879807590536, 0.5606916651039451, 0.9511492161960573], 
             UndirectedEdge[436, 473] -> 
             RGBColor[
              0.7880058098599707, 0.8340965074045622, 0.9491623567239293], 
             UndirectedEdge[311, 405] -> 
             RGBColor[
              0.20862681857218934`, 0.3366103923966298, 0.935192360730742], 
             UndirectedEdge[235, 432] -> 
             RGBColor[
              0.5593815103070034, 0.6483170327069279, 0.9606018818614842], 
             UndirectedEdge[109, 474] -> 
             RGBColor[
              0.36875585432995733`, 0.49381951963763093`, 0.9447177748532742],
              UndirectedEdge[364, 468] -> 
             RGBColor[
              0.3285107882361406, 0.45710020516072636`, 0.9422215373890169], 
             UndirectedEdge[203, 374] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[36, 112] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[324, 342] -> 
             RGBColor[
              0.8611372113207705, 0.36762185312492557`, 0.20202542244332183`],
              UndirectedEdge[374, 445] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[2, 327] -> 
             RGBColor[
              0.20072221719940941`, 0.3283021551731643, 0.934742205376372], 
             UndirectedEdge[128, 438] -> 
             RGBColor[
              0.26301778671971743`, 0.3937787485062433, 0.9382898459025171], 
             UndirectedEdge[33, 460] -> 
             RGBColor[
              0.6924766306307231, 0.7584685616661428, 0.9708320109558106], 
             UndirectedEdge[298, 335] -> 
             RGBColor[
              0.4974010502577838, 0.5985236805241728, 0.9550056831427665], 
             UndirectedEdge[112, 343] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[106, 265] -> 
             RGBColor[
              0.1920994264104521, 0.3192390553374573, 0.9342511501972167], 
             UndirectedEdge[19, 468] -> 
             RGBColor[
              0.32598193572834094`, 0.4544422208365192, 0.9420775229797997], 
             UndirectedEdge[161, 202] -> 
             RGBColor[
              0.27218576478809153`, 0.40129234360726607`, 0.9388896649529292],
              UndirectedEdge[204, 390] -> 
             RGBColor[
              0.719190104556114, 0.779752930155814, 0.9733986469546118], 
             UndirectedEdge[211, 289] -> 
             RGBColor[
              0.264682027432215, 0.3950808788085463, 0.9384009921848486], 
             UndirectedEdge[48, 479] -> 
             RGBColor[
              0.20982732020424238`, 0.33787219572811733`, 0.9352607275227045],
              UndirectedEdge[57, 495] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[10, 280] -> 
             RGBColor[
              0.46829572790906493`, 0.5776054118824476, 0.9517319339143078], 
             UndirectedEdge[206, 476] -> 
             RGBColor[
              0.19182851969505096`, 0.31895431520309286`, 0.9342357224605452],
              UndirectedEdge[13, 256] -> 
             RGBColor[
              0.7023889140742479, 0.7662213816098218, 0.9719512122807135], 
             UndirectedEdge[184, 221] -> 
             RGBColor[
              0.8369837657282427, 0.26650113164225936`, 0.18231370738115665`],
              UndirectedEdge[126, 282] -> 
             RGBColor[
              0.8563654629268306, 0.3487034608338446, 0.19818596167822738`], 
             UndirectedEdge[53, 266] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[194, 220] -> 
             RGBColor[
              0.27841284106148134`, 0.4064257927007418, 0.9392959734312498], 
             UndirectedEdge[375, 417] -> 
             RGBColor[
              0.2694273041453681, 0.40051555770747876`, 0.9386548584378767], 
             UndirectedEdge[245, 448] -> 
             RGBColor[
              0.6535838667359518, 0.7268961518226476, 0.9677673664876463], 
             UndirectedEdge[79, 147] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[77, 253] -> 
             RGBColor[
              0.9637096810052588, 0.9717997951686592, 0.9169584807873504], 
             UndirectedEdge[180, 205] -> 
             RGBColor[
              0.5242782003821684, 0.6244474620276343, 0.9557542010457972], 
             UndirectedEdge[28, 432] -> 
             RGBColor[
              0.8603580572101241, 0.8290737960157131, 0.6279678825408344], 
             UndirectedEdge[84, 245] -> 
             RGBColor[
              0.580845373371183, 0.6700379828264612, 0.960526576780036], 
             UndirectedEdge[19, 459] -> 
             RGBColor[
              0.26474036680987095`, 0.3955892893988805, 0.9383879442903225], 
             UndirectedEdge[153, 236] -> 
             RGBColor[
              0.3517722114098828, 0.47882816966608893`, 0.9436458799092957], 
             UndirectedEdge[315, 349] -> 
             RGBColor[
              0.202082172054935, 0.3297315539524397, 0.9348196527935213], 
             UndirectedEdge[18, 460] -> 
             RGBColor[
              0.7893755098548014, 0.8354224990598411, 0.9796313907499675], 
             UndirectedEdge[126, 449] -> 
             RGBColor[
              0.8563654629268306, 0.3487034608338446, 0.19818596167822738`], 
             UndirectedEdge[49, 324] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[334, 415] -> 
             RGBColor[
              0.1991728653840312, 0.3266736881806229, 0.9346539720825469], 
             UndirectedEdge[5, 444] -> 
             RGBColor[
              0.8285562969045, 0.22050178822288907`, 0.17497884820646079`], 
             UndirectedEdge[147, 449] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[254, 426] -> 
             RGBColor[
              0.22616397907446353`, 0.3550430600047173, 0.9361910760774426], 
             UndirectedEdge[186, 321] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[260, 399] -> 
             RGBColor[
              0.3078369305811183, 0.44058230230599205`, 0.9408533683900531], 
             UndirectedEdge[184, 287] -> 
             RGBColor[
              0.8571239304455562, 0.7024298435855887, 0.6014546314672211], 
             UndirectedEdge[129, 431] -> 
             RGBColor[
              0.8769447835241505, 0.9005887953787303, 0.7525487545778835], 
             UndirectedEdge[300, 432] -> 
             RGBColor[
              0.5947484037916498, 0.6789500582515764, 0.96285542904061], 
             UndirectedEdge[207, 293] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[118, 399] -> 
             RGBColor[
              0.2698928088141382, 0.40100483262905684`, 0.9386813682401107], 
             UndirectedEdge[138, 179] -> 
             RGBColor[
              0.23283128712735746`, 0.36205082350005524`, 0.9365707694076565],
              UndirectedEdge[40, 161] -> 
             RGBColor[
              0.2684135610193307, 0.39732751827476565`, 0.9386748435287737], 
             UndirectedEdge[243, 279] -> 
             RGBColor[
              0.27952453425237545`, 0.4111283867513086, 0.9392298807549574], 
             UndirectedEdge[69, 233] -> 
             RGBColor[
              0.8720195914369621, 0.405748016840095, 0.23691988196683633`], 
             UndirectedEdge[237, 460] -> 
             RGBColor[
              0.6238041371417982, 0.701894914251763, 0.9656530435265088], 
             UndirectedEdge[54, 295] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[102, 210] -> 
             RGBColor[
              0.2588571240715909, 0.389405628261814, 0.9380529023198552], 
             UndirectedEdge[137, 156] -> 
             RGBColor[
              0.29413333822792154`, 0.4253340674905862, 0.9401039046543183], 
             UndirectedEdge[231, 444] -> 
             RGBColor[
              0.8285562969045, 0.22050178822288907`, 0.17497884820646079`], 
             UndirectedEdge[383, 393] -> 
             RGBColor[
              0.5000243154359716, 0.6026515113802116, 0.9544266172832518], 
             UndirectedEdge[43, 137] -> 
             RGBColor[
              0.36126042666261593`, 0.4873273569233284, 0.9442401728302576], 
             UndirectedEdge[233, 348] -> 
             RGBColor[
              0.8657911144896757, 0.38473790158096455`, 0.21272342517580606`],
              UndirectedEdge[193, 410] -> 
             RGBColor[
              0.19038075076848193`, 0.31743261826741714`, 0.9341532741619593],
              UndirectedEdge[126, 384] -> 
             RGBColor[
              0.784439054142597, 0.7459729584674704, 0.6152424378957748], 
             UndirectedEdge[162, 345] -> 
             RGBColor[
              0.21406135628573086`, 0.3423224361031544, 0.9355018496138501], 
             UndirectedEdge[165, 178] -> 
             RGBColor[
              0.9007287763047269, 0.8723471763792785, 0.6357027911701743], 
             UndirectedEdge[154, 455] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[211, 470] -> 
             RGBColor[
              0.23114027919804092`, 0.3602734669502483, 0.9364744690077039], 
             UndirectedEdge[201, 305] -> 
             RGBColor[
              0.714793343846527, 0.7763168762700076, 0.9728989371489009], 
             UndirectedEdge[220, 474] -> 
             RGBColor[
              0.37690451400651614`, 0.5008774790859223, 0.9452370002422877], 
             UndirectedEdge[125, 173] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[189, 443] -> 
             RGBColor[
              0.6423913820668823, 0.7188913891932535, 0.9661322690038426], 
             UndirectedEdge[307, 500] -> 
             RGBColor[
              0.2541094521417272, 0.3844155240437408, 0.9377825294270006], 
             UndirectedEdge[102, 134] -> 
             RGBColor[
              0.23432084769928213`, 0.3636164461047431, 0.9366555976786202], 
             UndirectedEdge[102, 174] -> 
             RGBColor[
              0.24152702065256443`, 0.3711905907763972, 0.937065978567732], 
             UndirectedEdge[203, 281] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[279, 421] -> 
             RGBColor[
              0.2531570576746852, 0.38341449707358277`, 0.9377282919710439], 
             UndirectedEdge[335, 430] -> 
             RGBColor[
              0.2957165872581862, 0.4275661778747568, 0.940173270522874], 
             UndirectedEdge[69, 431] -> 
             RGBColor[
              0.9874348778681517, 0.9686932045679294, 0.4553319430682715], 
             UndirectedEdge[149, 249] -> 
             RGBColor[
              0.8427485102135918, 0.3295893587840956, 0.1885693276990594], 
             UndirectedEdge[141, 345] -> 
             RGBColor[
              0.26571464212222085`, 0.3966133145247829, 0.9384434278280497], 
             UndirectedEdge[12, 283] -> 
             RGBColor[
              0.21876873065664665`, 0.34727018503176055`, 0.9357699276203375],
              UndirectedEdge[119, 381] -> 
             RGBColor[
              0.21072511503524133`, 0.3388158350189773, 0.9353118556101614], 
             UndirectedEdge[396, 430] -> 
             RGBColor[
              0.267533642941468, 0.39852519971712486`, 0.9385470172337352], 
             UndirectedEdge[49, 360] -> 
             RGBColor[
              0.8191009627097754, 0.1478239462483719, 0.1659244095033199], 
             UndirectedEdge[208, 497] -> 
             RGBColor[
              0.9697875053992224, 0.9066608733562769, 0.377938680164832], 
             UndirectedEdge[275, 444] -> 
             RGBColor[
              0.8785036487734464, 0.5201192918100778, 0.21943697634810488`], 
             UndirectedEdge[269, 323] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[273, 279] -> 
             RGBColor[
              0.2592350022653147, 0.38980280220227903`, 0.938074421923967], 
             UndirectedEdge[107, 289] -> 
             RGBColor[
              0.31649233536361426`, 0.44855148634982667`, 0.941387589639554], 
             UndirectedEdge[289, 314] -> 
             RGBColor[
              0.4574818773087424, 0.5666492546376866, 0.9514821357474397], 
             UndirectedEdge[6, 428] -> 
             RGBColor[
              0.2756737236719881, 0.40471720688507545`, 0.9390971306622837], 
             UndirectedEdge[7, 17] -> 
             RGBColor[
              0.970450660992768, 0.9210987253730254, 0.5694341697658482], 
             UndirectedEdge[309, 424] -> 
             RGBColor[
              0.23021590674425413`, 0.35930189289271974`, 0.9364218273639473],
              UndirectedEdge[128, 385] -> 
             RGBColor[
              0.21760308488543836`, 0.34604501742001015`, 0.9357035458180856],
              UndirectedEdge[71, 362] -> 
             RGBColor[
              0.22011006608812847`, 0.34868001361582635`, 0.9358463146888325],
              UndirectedEdge[43, 156] -> 
             RGBColor[
              0.33421927844066934`, 0.460054494124931, 0.9426581453180694], 
             UndirectedEdge[59, 298] -> 
             RGBColor[
              0.6411661160201888, 0.718993456061012, 0.9652859281793502], 
             UndirectedEdge[261, 455] -> 
             RGBColor[
              0.8536811654374341, 0.40413620414162243`, 0.44042619244061953`],
              UndirectedEdge[17, 89] -> 
             RGBColor[
              0.9231261051226047, 0.9396618813362796, 0.9219331847920909], 
             UndirectedEdge[9, 68] -> 
             RGBColor[
              0.22494283452702457`, 0.3537595596603228, 0.9361215337019873], 
             UndirectedEdge[73, 298] -> 
             RGBColor[
              0.7870575481756196, 0.4591533710298793, 0.44731121237687044`], 
             UndirectedEdge[16, 333] -> 
             RGBColor[
              0.5323412755190838, 0.6301818453199022, 0.956641741180513], 
             UndirectedEdge[257, 445] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[428, 451] -> 
             RGBColor[
              0.2543228250079339, 0.3846397924547452, 0.9377946806960742], 
             UndirectedEdge[15, 419] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[17, 313] -> 
             RGBColor[
              0.9826977046974779, 0.9860735140867379, 0.8898538805643141], 
             UndirectedEdge[5, 326] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[216, 217] -> 
             RGBColor[
              0.22911696130934928`, 0.3581468315634698, 0.9363592440471735], 
             UndirectedEdge[138, 222] -> 
             RGBColor[
              0.22634894968623231`, 0.35523747584550047`, 0.9362016098801433],
              UndirectedEdge[251, 447] -> 
             RGBColor[
              0.4395361264241692, 0.5551258338057223, 0.9492278312025804], 
             UndirectedEdge[58, 144] -> 
             RGBColor[
              0.24826092960193386`, 0.3782683560366715, 0.9374494647204732], 
             UndirectedEdge[11, 404] -> 
             RGBColor[
              0.8740472245688059, 0.4191181540612454, 0.3950653321159444], 
             UndirectedEdge[270, 329] -> 
             RGBColor[
              0.18719494717707214`, 0.31408413670123125`, 0.9339718473604026],
              UndirectedEdge[314, 406] -> 
             RGBColor[
              0.7976121679228045, 0.8382528191088208, 0.7664545561818166], 
             UndirectedEdge[13, 409] -> 
             RGBColor[
              0.540422450424237, 0.6377783168651694, 0.9569631814115112], 
             UndirectedEdge[279, 335] -> 
             RGBColor[
              0.30955781786322234`, 0.442114188825357, 0.9409615081295651], 
             UndirectedEdge[195, 446] -> 
             RGBColor[
              0.20832130976855523`, 0.33628928327363344`, 0.9351749624563348],
              UndirectedEdge[22, 170] -> 
             RGBColor[
              0.20408136056054266`, 0.3318328278277056, 0.9349335036213813], 
             UndirectedEdge[159, 166] -> 
             RGBColor[
              0.3352108410982161, 0.45943457954147626`, 0.9427754713265473], 
             UndirectedEdge[59, 87] -> 
             RGBColor[
              0.7284229725600728, 0.7874364169703292, 0.9739093048334139], 
             UndirectedEdge[176, 407] -> 
             RGBColor[
              0.7860294343098881, 0.8332871901386956, 0.9791708607176912], 
             UndirectedEdge[169, 470] -> 
             RGBColor[
              0.22323454419872468`, 0.35196403821341704`, 0.9360242490949797],
              UndirectedEdge[13, 188] -> 
             RGBColor[
              0.4598981295480561, 0.5704218386954567, 0.9511719778781306], 
             UndirectedEdge[273, 396] -> 
             RGBColor[
              0.23652515386637785`, 0.3659333116474439, 0.9367811296538575], 
             UndirectedEdge[30, 405] -> 
             RGBColor[
              0.18482655001024287`, 0.3115948011138402, 0.9338369706454812], 
             UndirectedEdge[258, 497] -> 
             RGBColor[
              0.9702608694884922, 0.9076733512787738, 0.4294614400173077], 
             UndirectedEdge[90, 485] -> 
             RGBColor[
              0.5765425629929836, 0.6671022514410058, 0.9598066889852549], 
             UndirectedEdge[89, 455] -> 
             RGBColor[
              0.8311431839354053, 0.386165029469115, 0.43827649964506243`], 
             UndirectedEdge[422, 451] -> 
             RGBColor[
              0.2947402709569025, 0.42712109076119387`, 0.9400963944506149], 
             UndirectedEdge[99, 178] -> 
             RGBColor[
              0.8637848357389819, 0.3779702522582219, 0.20492941108331192`], 
             UndirectedEdge[119, 416] -> 
             RGBColor[
              0.25584298681039175`, 0.38616481482489873`, 0.9378839159108214],
              UndirectedEdge[129, 204] -> 
             RGBColor[
              0.8203413302090085, 0.8600631926608293, 0.9825983689433555], 
             UndirectedEdge[1, 381] -> 
             RGBColor[
              0.24294210956451456`, 0.3726779389446759, 0.9371465657878312], 
             UndirectedEdge[287, 409] -> 
             RGBColor[
              0.6896306090099416, 0.7560613412803963, 0.970719252222427], 
             UndirectedEdge[340, 384] -> 
             RGBColor[
              0.8080357036472916, 0.8499629868732397, 0.9401530383545316], 
             UndirectedEdge[233, 379] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[1, 124] -> 
             RGBColor[
              0.2366309542553628, 0.3660445145643992, 0.9367871548294926], 
             UndirectedEdge[134, 309] -> 
             RGBColor[
              0.2100987137423066, 0.33815744754396704`, 0.9352761829832064], 
             UndirectedEdge[1, 380] -> 
             RGBColor[
              0.24115428756237606`, 0.37079882466596636`, 0.937044751969655], 
             UndirectedEdge[112, 403] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[214, 268] -> 
             RGBColor[
              0.21337122568436184`, 0.3415970650843082, 0.9354625476970588], 
             UndirectedEdge[404, 444] -> 
             RGBColor[
              0.8285562969045, 0.22050178822288907`, 0.17497884820646079`], 
             UndirectedEdge[252, 320] -> 
             RGBColor[
              0.19096927332444358`, 0.31805119278821803`, 0.9341867896508802],
              UndirectedEdge[173, 419] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[407, 475] -> 
             RGBColor[
              0.8152617742014696, 0.8564271005964393, 0.9760940494423469], 
             UndirectedEdge[167, 305] -> 
             RGBColor[
              0.6596309315266682, 0.7315335449103904, 0.9685563499845072], 
             UndirectedEdge[407, 482] -> 
             RGBColor[
              0.812258959101159, 0.8541876060112861, 0.9811770321475642], 
             UndirectedEdge[197, 493] -> 
             RGBColor[
              0.5014513704988036, 0.60505757525172, 0.9541942678191915], 
             UndirectedEdge[235, 300] -> 
             RGBColor[
              0.3827432544500259, 0.5059347025944629, 0.9456090396203527], 
             UndirectedEdge[312, 385] -> 
             RGBColor[
              0.21913828808169364`, 0.347658613316779, 0.9357909733689826], 
             UndirectedEdge[188, 318] -> 
             RGBColor[
              0.3206397205634015, 0.4477294311094059, 0.9418134869378495], 
             UndirectedEdge[71, 153] -> 
             RGBColor[
              0.3288978182766464, 0.4547857321627663, 0.9423432170599901], 
             UndirectedEdge[45, 481] -> 
             RGBColor[
              0.2835821880689775, 0.4153932381826685, 0.939460958137052], 
             UndirectedEdge[53, 317] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[253, 301] -> 
             RGBColor[
              0.8742585681452911, 0.41920555006140414`, 0.39156282211394233`],
              UndirectedEdge[442, 447] -> 
             RGBColor[
              0.43707590774460403`, 0.5529949160396692, 0.9490710682438044], 
             UndirectedEdge[118, 464] -> 
             RGBColor[
              0.2582088050321171, 0.38872420384552575`, 0.9380159815096591], 
             UndirectedEdge[2, 118] -> 
             RGBColor[
              0.2188823691598405, 0.3473896263037145, 0.9357763991649812], 
             UndirectedEdge[332, 454] -> 
             RGBColor[
              0.26600423470039036`, 0.39588544200916653`, 0.9384977155240641],
              UndirectedEdge[84, 455] -> 
             RGBColor[
              0.7711297731426533, 0.3390729855096647, 0.43235041543167274`], 
             UndirectedEdge[423, 488] -> 
             RGBColor[
              0.18727196886148448`, 0.3141650913750055, 0.9339762336313865], 
             UndirectedEdge[5, 231] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[121, 337] -> 
             RGBColor[
              0.25724680271789735`, 0.38771307841881125`, 0.9379611969010192],
              UndirectedEdge[23, 360] -> 
             RGBColor[
              0.8792976493045557, 0.4456457928586737, 0.2568665901106246], 
             UndirectedEdge[79, 336] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[237, 371] -> 
             RGBColor[
              0.4848427832349989, 0.5918340156659786, 0.9528149292291238], 
             UndirectedEdge[9, 330] -> 
             RGBColor[
              0.23388775769536924`, 0.36316124105113845`, 0.9366309338435965],
              UndirectedEdge[76, 111] -> 
             RGBColor[
              0.9894404720113958, 0.9890932090554398, 0.7659168812648544], 
             UndirectedEdge[91, 256] -> 
             RGBColor[
              0.914728589855879, 0.8931453763833161, 0.6512126420152853], 
             UndirectedEdge[35, 193] -> 
             RGBColor[
              0.20201306311706924`, 0.32965891607698306`, 0.9348157171417473],
              UndirectedEdge[43, 267] -> 
             RGBColor[
              0.40347694898297903`, 0.5238931866931191, 0.9469301723019063], 
             UndirectedEdge[261, 448] -> 
             RGBColor[
              0.8753169012348998, 0.903417953473117, 0.9879697015160488], 
             UndirectedEdge[322, 374] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[76, 130] -> 
             RGBColor[
              0.9137694672197825, 0.9300716783330631, 0.8049197639965786], 
             UndirectedEdge[107, 153] -> 
             RGBColor[
              0.35862018099566284`, 0.48504050882921934`, 0.944071938711037], 
             UndirectedEdge[410, 437] -> 
             RGBColor[
              0.19252529616452413`, 0.31968667145068896`, 0.9342754028496933],
              UndirectedEdge[11, 164] -> 
             RGBColor[
              0.9340834784629356, 0.9483907377638316, 0.9226198202751702], 
             UndirectedEdge[213, 500] -> 
             RGBColor[
              0.2766042930680527, 0.40805902811260025`, 0.9390635773396199], 
             UndirectedEdge[251, 454] -> 
             RGBColor[
              0.38596006350609297`, 0.5087209409173039, 0.9458140118488928], 
             UndirectedEdge[111, 483] -> 
             RGBColor[
              0.977978612779826, 0.951566610311706, 0.6247122270146903], 
             UndirectedEdge[5, 233] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[69, 372] -> 
             RGBColor[
              0.8720195914369621, 0.405748016840095, 0.23691988196683633`], 
             UndirectedEdge[454, 489] -> 
             RGBColor[
              0.2767586893045861, 0.4071890556699812, 0.9391101658039832], 
             UndirectedEdge[289, 493] -> 
             RGBColor[
              0.4515126766845066, 0.5618031886615082, 0.9510122184083976], 
             UndirectedEdge[74, 268] -> 
             RGBColor[
              0.21587322879511397`, 0.3442268289898683, 0.9356050330728343], 
             UndirectedEdge[192, 258] -> 
             RGBColor[
              0.9320737133765145, 0.9444030306208892, 0.78526845033412], 
             UndirectedEdge[68, 368] -> 
             RGBColor[
              0.19358411070805037`, 0.32079955266865445`, 0.9343357007715714],
              UndirectedEdge[50, 414] -> 
             RGBColor[
              0.8759899507757182, 0.41879994377265284`, 0.28134248690904895`],
              UndirectedEdge[358, 441] -> 
             RGBColor[
              0.3764338650694757, 0.5004698266321612, 0.945207010908198], 
             UndirectedEdge[71, 289] -> 
             RGBColor[
              0.2867699726445978, 0.4182967096833736, 0.9396588679885072], 
             UndirectedEdge[54, 321] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[75, 408] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[8, 239] -> 
             RGBColor[
              0.25705844491916985`, 0.3875151024297744, 0.9379504702030321], 
             UndirectedEdge[389, 472] -> 
             RGBColor[
              0.22243976571633683`, 0.35112867563656114`, 0.9359789876361772],
              UndirectedEdge[178, 475] -> 
             RGBColor[
              0.9494877447629478, 0.9110570904198478, 0.6344884471591432], 
             UndirectedEdge[332, 489] -> 
             RGBColor[
              0.22285222532450405`, 0.35156219683619444`, 0.9360024766006829],
              UndirectedEdge[28, 406] -> 
             RGBColor[
              0.971585860971019, 0.9130263803621124, 0.4246172301504474], 
             UndirectedEdge[77, 87] -> 
             RGBColor[
              0.896783278694488, 0.9204422732959663, 0.9868140728389698], 
             UndirectedEdge[274, 300] -> 
             RGBColor[
              0.45102395983649046`, 0.5642446191206338, 0.9501895436973189], 
             UndirectedEdge[330, 333] -> 
             RGBColor[
              0.32128397349438886`, 0.4449420277747629, 0.9419770304831396], 
             UndirectedEdge[325, 490] -> 
             RGBColor[
              0.384235761313647, 0.5072274370241554, 0.9457041408379308], 
             UndirectedEdge[420, 489] -> 
             RGBColor[
              0.2259038792592088, 0.3547696786076038, 0.936176263777747], 
             UndirectedEdge[271, 304] -> 
             RGBColor[
              0.26712476583186534`, 0.39809544395062635`, 0.9385237322872229],
              UndirectedEdge[166, 387] -> 
             RGBColor[
              0.2364720735351036, 0.36587752085378733`, 0.9367781068075168], 
             UndirectedEdge[16, 165] -> 
             RGBColor[
              0.7458367292928169, 0.8015726905647942, 0.9752485920882636], 
             UndirectedEdge[44, 356] -> 
             RGBColor[
              0.5955073527677653, 0.681625690653308, 0.9618965630981988], 
             UndirectedEdge[86, 377] -> 
             RGBColor[
              0.19669430319698816`, 0.3240685621721215, 0.9345128216326989], 
             UndirectedEdge[113, 353] -> 
             RGBColor[
              0.22107694525191812`, 0.3496962649206489, 0.9359013770268407], 
             UndirectedEdge[63, 222] -> 
             RGBColor[
              0.27812742646781496`, 0.4096599378879857, 0.9391503175334623], 
             UndirectedEdge[71, 493] -> 
             RGBColor[
              0.4247009633868117, 0.5340694702303104, 0.9494689607646909], 
             UndirectedEdge[106, 270] -> 
             RGBColor[
              0.18303490781801574`, 0.3097116715731334, 0.933734939273131], 
             UndirectedEdge[414, 498] -> 
             RGBColor[
              0.8759899507757182, 0.41879994377265295`, 0.28134248690904895`],
              UndirectedEdge[46, 220] -> 
             RGBColor[
              0.3163259847955163, 0.44627491059736407`, 0.9414550708794333], 
             UndirectedEdge[302, 443] -> 
             RGBColor[
              0.6197751789448227, 0.7005305366504255, 0.9643518386481924], 
             UndirectedEdge[90, 267] -> 
             RGBColor[
              0.5020615308844408, 0.6053397431537071, 0.9543012063004392], 
             UndirectedEdge[116, 187] -> 
             RGBColor[
              0.5258049734314325, 0.6229278732874357, 0.956899298837582], 
             UndirectedEdge[162, 472] -> 
             RGBColor[
              0.19746627468796812`, 0.32487995315496093`, 0.9345567842670808],
              UndirectedEdge[271, 371] -> 
             RGBColor[
              0.4256104330710305, 0.5401439642837345, 0.9490548283881131], 
             UndirectedEdge[84, 478] -> 
             RGBColor[
              0.5977451472226231, 0.6837579805651962, 0.9618569888835327], 
             UndirectedEdge[5, 163] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[188, 430] -> 
             RGBColor[
              0.3283401366482528, 0.45582305664916356`, 0.9422520142421371], 
             UndirectedEdge[380, 487] -> 
             RGBColor[
              0.2270742510106255, 0.35599981352419774`, 0.9362429147175804], 
             UndirectedEdge[88, 304] -> 
             RGBColor[
              0.22720116780943558`, 0.35613321112673696`, 0.9362501424415159],
              UndirectedEdge[41, 494] -> 
             RGBColor[
              0.7862603193212523, 0.8326898579584304, 0.949304381285405], 
             UndirectedEdge[23, 136] -> 
             RGBColor[
              0.9410230313708325, 0.7887755730421966, 0.3307097337117372], 
             UndirectedEdge[7, 84] -> 
             RGBColor[
              0.8160959914872512, 0.8010398665049154, 0.62500535758886], 
             UndirectedEdge[218, 493] -> 
             RGBColor[
              0.6646305094061155, 0.737123077010855, 0.9677620244253071], 
             UndirectedEdge[40, 183] -> 
             RGBColor[
              0.23087447888683538`, 0.35999409397045823`, 0.9364593320731971],
              UndirectedEdge[192, 453] -> 
             RGBColor[
              0.6640388061322713, 0.735051317746148, 0.9689732627371802], 
             UndirectedEdge[49, 397] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[291, 467] -> 
             RGBColor[
              0.21418854935951206`, 0.34245612408820514`, 0.9355090930712366],
              UndirectedEdge[347, 462] -> 
             RGBColor[
              0.25493221981671754`, 0.3852803050366393, 0.9378293848289156], 
             UndirectedEdge[31, 226] -> 
             RGBColor[
              0.22438551241201804`, 0.35317377878118794`, 0.9360897950320219],
              UndirectedEdge[120, 381] -> 
             RGBColor[
              0.20121572608791957`, 0.32882086430525925`, 0.9347703099774917],
              UndirectedEdge[151, 274] -> 
             RGBColor[
              0.3848156105760768, 0.5047669089099905, 0.9460488459712351], 
             UndirectedEdge[316, 418] -> 
             RGBColor[
              0.9672391665729247, 0.8989591012601537, 0.3386522526091738], 
             UndirectedEdge[235, 389] -> 
             RGBColor[
              0.29759964420875396`, 0.4265548325280502, 0.9403900067936175], 
             UndirectedEdge[218, 310] -> 
             RGBColor[
              0.7914851171285034, 0.354974734937755, 0.4343792458886776], 
             UndirectedEdge[408, 463] -> 
             RGBColor[
              0.831998657058118, 0.24386491747293382`, 0.17815401051060936`], 
             UndirectedEdge[12, 273] -> 
             RGBColor[
              0.22919575579368628`, 0.35822964956236686`, 0.9363637312764905],
              UndirectedEdge[121, 454] -> 
             RGBColor[
              0.3058588106164846, 0.437775128223043, 0.9407673746629241], 
             UndirectedEdge[47, 228] -> 
             RGBColor[
              0.643625510819642, 0.7204555301268813, 0.9658450315184992], 
             UndirectedEdge[438, 439] -> 
             RGBColor[
              0.27373103330916027`, 0.40503904993081363`, 0.9388999494469579],
              UndirectedEdge[172, 201] -> 
             RGBColor[
              0.4728690965671932, 0.5808891368792599, 0.9522105393803614], 
             UndirectedEdge[58, 375] -> 
             RGBColor[
              0.26089059756321387`, 0.3915429378311758, 0.9381687056269487], 
             UndirectedEdge[168, 280] -> 
             RGBColor[
              0.6614695904816725, 0.7339397277713925, 0.9679351497630158], 
             UndirectedEdge[77, 301] -> 
             RGBColor[
              0.8579732191915481, 0.4074969800510354, 0.43870016507762466`], 
             UndirectedEdge[283, 477] -> 
             RGBColor[
              0.22686340443243364`, 0.3557782004020729, 0.9362309073168718], 
             UndirectedEdge[125, 149] -> 
             RGBColor[
              0.8300337551067959, 0.23185817939204778`, 0.1763936638495297], 
             UndirectedEdge[7, 407] -> 
             RGBColor[
              0.8208526148202658, 0.8047557768043427, 0.6254794533495226], 
             UndirectedEdge[401, 437] -> 
             RGBColor[
              0.189249743774186, 0.31624385820642686`, 0.9340888649868091], 
             UndirectedEdge[138, 438] -> 
             RGBColor[
              0.23827977325697014`, 0.3677775278762512, 0.936881052632425], 
             UndirectedEdge[45, 399] -> 
             RGBColor[
              0.2892039179868987, 0.4213020327646674, 0.9397811073392734], 
             UndirectedEdge[97, 317] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[71, 201] -> 
             RGBColor[
              0.41387149855588806`, 0.5252776228187356, 0.9486164256235639], 
             UndirectedEdge[107, 236] -> 
             RGBColor[
              0.31255501519915574`, 0.44486020542195137`, 0.9411469948451532],
              UndirectedEdge[134, 225] -> 
             RGBColor[
              0.20098661279686494`, 0.32858005170973914`, 0.9347572623145088],
              UndirectedEdge[59, 91] -> 
             RGBColor[
              0.7833793217020255, 0.7895587302313833, 0.6386349089300231], 
             UndirectedEdge[161, 287] -> 
             RGBColor[
              0.5848187798365858, 0.6676682441493317, 0.9633804701369508], 
             UndirectedEdge[101, 486] -> 
             RGBColor[
              0.7422414987302901, 0.793474440705987, 0.7763586554254926], 
             UndirectedEdge[185, 330] -> 
             RGBColor[
              0.2727206891407805, 0.40287895172931015`, 0.9388826209469538], 
             UndirectedEdge[237, 432] -> 
             RGBColor[
              0.5972113990161616, 0.6810833809213088, 0.9630123689183746], 
             UndirectedEdge[99, 143] -> 
             RGBColor[
              0.8239416059032, 0.18503125101640663`, 0.1705598148920679], 
             UndirectedEdge[107, 411] -> 
             RGBColor[
              0.5158561344435298, 0.6131266190837553, 0.9567665221218118], 
             UndirectedEdge[187, 407] -> 
             RGBColor[
              0.5277223378654804, 0.6244257329558234, 0.9570904038055785], 
             UndirectedEdge[185, 357] -> 
             RGBColor[
              0.2704886241626608, 0.4005329099162129, 0.9387555081484942], 
             UndirectedEdge[80, 208] -> 
             RGBColor[
              0.9754972680138669, 0.9778179512987408, 0.718003495698742], 
             UndirectedEdge[60, 240] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[262, 299] -> 
             RGBColor[
              0.7053148813089781, 0.7675537158569028, 0.9584619306105826], 
             UndirectedEdge[82, 282] -> 
             RGBColor[
              0.844192723800754, 0.2992353265545988, 0.18832903870459236`], 
             UndirectedEdge[286, 368] -> 
             RGBColor[
              0.19782344597820478`, 0.32525536282696743`, 0.934577124643672], 
             UndirectedEdge[81, 454] -> 
             RGBColor[
              0.38458547196747705`, 0.5075303388155344, 0.9457264240915557], 
             UndirectedEdge[68, 352] -> 
             RGBColor[
              0.20254407979161715`, 0.33021704827033466`, 0.934845957755794], 
             UndirectedEdge[196, 337] -> 
             RGBColor[
              0.2289545201015995, 0.3579760955547574, 0.9363499932607025], 
             UndirectedEdge[261, 262] -> 
             RGBColor[
              0.9391282219438701, 0.953882854240121, 0.979615271589626], 
             UndirectedEdge[122, 286] -> 
             RGBColor[
              0.21170798349237516`, 0.3398488920848844, 0.9353678285147715]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {3}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.3086579844982561, 0.441749490127162, 0.9408889876473829], 316 -> 
             RGBColor[
              0.9859314232921296, 0.9642055286847646, 0.39984666542805347`], 
             308 -> 
             RGBColor[
              0.23051962020931505`, 0.35962111500104466`, 0.9364391233964787],
              160 -> RGBColor[
              0.45486118183922636`, 0.5683158245366335, 0.9502274849272453], 
             245 -> RGBColor[
              0.4829394273144061, 0.5911110091239283, 0.9524379072650536], 
             155 -> RGBColor[
              0.24352168839563612`, 0.373287113043605, 0.9371795719448536], 
             425 -> RGBColor[
              0.21231746253184797`, 0.34048949319857336`, 0.9354025374444261],
              213 -> RGBColor[
              0.2792508331211001, 0.4108407095086842, 0.9392142938804358], 
             352 -> RGBColor[
              0.19816019677618812`, 0.3256093092668817, 0.9345963021034391], 
             27 -> RGBColor[
              0.2059976869465667, 0.3338470083615274, 0.9350426355741145], 
             485 -> RGBColor[
              0.5545695953076797, 0.6492636064031623, 0.9580768964794351], 
             454 -> RGBColor[
              0.3199106986804724, 0.45151230084295324`, 0.9416054047273643], 
             367 -> RGBColor[
              0.25742088082667425`, 0.38789604554832535`, 0.9379711103917886],
              19 -> RGBColor[
              0.28355932289318264`, 0.4153692054331722, 0.9394596559991165], 
             164 -> RGBColor[
              0.8806632832194534, 0.9076810133439271, 0.9884796442025071], 
             190 -> RGBColor[
              0.34462319164040967`, 0.47291702015883946`, 0.943180062926372], 
             103 -> RGBColor[
              0.9943968653913747, 0.9904237865729874, 0.6315115602687539], 
             138 -> RGBColor[
              0.1954809540192259, 0.32279325525551217`, 0.9344437231920146], 
             416 -> RGBColor[
              0.30953300584952725`, 0.44252366491079637`, 0.94094414731681], 
             476 -> RGBColor[
              0.19832380395462978`, 0.32578127078471814`, 0.9346056192902162],
              291 -> RGBColor[
              0.19681365185457406`, 0.3241940051783862, 0.9345196183621879], 
             28 -> RGBColor[
              0.949329454771621, 0.8368152036673847, 0.2780874937999273], 337 -> 
             RGBColor[
              0.22268668288329785`, 0.35138820123448977`, 0.9359930492035543],
              195 -> RGBColor[
              0.21841757556668306`, 0.34690109876769015`, 0.9357499298574514],
              114 -> RGBColor[
              0.1897272593739602, 0.31674575737802724`, 0.9341160587937951], 
             479 -> RGBColor[
              0.1935343324702769, 0.320747232584632, 0.9343328659745704], 93 -> 
             RGBColor[
              0.3738197825598743, 0.4982056397499517, 0.9450404438822286], 34 -> 
             RGBColor[
              0.3081602529797812, 0.4412263427432439, 0.9408606425737336], 
             161 -> RGBColor[
              0.331702995966787, 0.46172619605426385`, 0.9423567994829292], 
             22 -> RGBColor[
              0.19129510586323456`, 0.3183936634454635, 0.9342053453319383], 
             124 -> RGBColor[
              0.20667495168092284`, 0.33455885653840006`, 0.9350812047988127],
              84 -> RGBColor[
              0.67875131942796, 0.7489649565289941, 0.9686152462950182], 46 -> 
             RGBColor[
              0.2856812767955215, 0.41759951352417846`, 0.9395804981347052], 
             241 -> RGBColor[
              0.34023858975482646`, 0.4691192983820458, 0.9429006799713738], 
             185 -> RGBColor[
              0.3206235691378255, 0.4521297534032015, 0.9416508282025402], 
             426 -> RGBColor[
              0.21523898041579886`, 0.3435601937295382, 0.9355689135659188], 
             390 -> RGBColor[
              0.5581381343170947, 0.6521607071318558, 0.9583578249422453], 
             121 -> RGBColor[
              0.29180692255249685`, 0.42403795560313273`, 0.9399293445984841],
              322 -> RGBColor[0.817319, 0.134127, 0.164218], 488 -> 
             RGBColor[
              0.19444137114962554`, 0.3217005877462013, 0.9343845204855159], 
             126 -> RGBColor[
              0.9344583887804918, 0.7778563825015339, 0.2661218850346821], 
             433 -> RGBColor[
              0.18644975521125867`, 0.31330089269726175`, 0.9339294097803622],
              236 -> RGBColor[
              0.3057070456133757, 0.438647866258821, 0.9407209360434119], 78 -> 
             RGBColor[
              0.9560909454429859, 0.8635465900222101, 0.28392204388553066`], 
             376 -> RGBColor[
              0.9860284094714858, 0.9884904025100302, 0.8812089425821105], 
             458 -> RGBColor[
              0.45245153773684854`, 0.5663125139373179, 0.9500507897907745], 
             254 -> RGBColor[
              0.2370889777331282, 0.36652592627989644`, 0.9368132385889664], 
             290 -> RGBColor[
              0.1901247553990758, 0.3171635509031274, 0.9341386956043828], 
             251 -> RGBColor[
              0.45200942833171354`, 0.5659295809916547, 0.9500226189704213], 
             165 -> RGBColor[
              0.8447410453925083, 0.8790375959838911, 0.9850533490904128], 
             460 -> RGBColor[
              0.8245721358999006, 0.8629554550249494, 0.9831296204980098], 
             100 -> RGBColor[0.817319, 0.134127, 0.164218], 235 -> 
             RGBColor[
              0.3473763609653794, 0.4753016770498144, 0.9433554924412271], 70 -> 
             RGBColor[
              0.9855771277360073, 0.9883037859149981, 0.8886878488186855], 
             234 -> RGBColor[0.817319, 0.134127, 0.164218], 435 -> 
             RGBColor[
              0.4494598255363201, 0.5637212431970474, 0.949860160534824], 257 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 135 -> 
             RGBColor[
              0.18353112071158095`, 0.3102332227859851, 0.9337631978633384], 
             265 -> RGBColor[
              0.20216870968076056`, 0.32982251048398475`, 0.9348245809832911],
              111 -> RGBColor[
              0.9845357488920988, 0.9878731490008265, 0.9059461912643052], 
             497 -> RGBColor[
              0.946570060984783, 0.8258751268160418, 0.27586722078774056`], 
             481 -> RGBColor[
              0.2923941296611816, 0.4246551475054415, 0.9399627851746286], 
             381 -> RGBColor[
              0.2192972622992264, 0.34782570529895346`, 0.9358000267154899], 
             182 -> RGBColor[
              0.9544946818446345, 0.965582788744624, 0.9619128133359728], 188 -> 
             RGBColor[
              0.38027801256113686`, 0.5037994339769674, 0.9454519565871206], 
             154 -> RGBColor[0.817319, 0.134127, 0.164218], 336 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 463 -> 
             RGBColor[
              0.861357971174354, 0.4633407524188015, 0.20602603153182808`], 
             315 -> RGBColor[
              0.1982372182974502, 0.32569026376917465`, 0.9346006883651319], 
             368 -> RGBColor[
              0.18024025860905457`, 0.30677431806352135`, 0.9335757881349936],
              269 -> RGBColor[0.817319, 0.134127, 0.164218], 208 -> 
             RGBColor[
              0.9930049498136619, 0.9874466198965118, 0.4800101395419234], 86 -> 
             RGBColor[
              0.20642970531273738`, 0.3343010870559193, 0.9350672383809541], 
             119 -> RGBColor[
              0.2021529677712563, 0.32980596473900103`, 0.9348236845048329], 
             436 -> RGBColor[
              0.9696998197036082, 0.9769227556637184, 0.9361744810758174], 
             377 -> RGBColor[
              0.18695890108123892`, 0.31383603728832365`, 0.9339584048844437],
              140 -> RGBColor[
              0.17930336856424547`, 0.3057895872241672, 0.9335224336329464], 
             85 -> 
             RGBColor[
              0.21486301907210675`, 0.34316503451999186`, 0.9355475031235805],
              351 -> RGBColor[
              0.45951259018598095`, 0.572092047376087, 0.950593660830972], 
             443 -> RGBColor[
              0.7513693824412065, 0.8056947392726626, 0.9758531361617966], 
             242 -> RGBColor[0.817319, 0.134127, 0.164218], 117 -> 
             RGBColor[
              0.19890073469948152`, 0.32638766157707927`, 0.9346384746426429],
              47 -> RGBColor[
              0.7146679187190441, 0.7770232768714539, 0.97219507725265], 451 -> 
             RGBColor[
              0.2916100124153255, 0.4238309905641419, 0.9399181308574747], 81 -> 
             RGBColor[
              0.4492602452544817, 0.5635483767881156, 0.9498474434557472], 
             275 -> RGBColor[
              0.9334491648933394, 0.7738551460928987, 0.26530983980554995`], 
             23 -> RGBColor[
              0.9925631716550148, 0.9865017010857893, 0.43192531331195433`], 
             328 -> RGBColor[
              0.4770512439418583, 0.586330716602456, 0.9519743679008402], 418 -> 
             RGBColor[
              0.94854690985372, 0.8337126738355427, 0.27745783979029415`], 
             110 -> RGBColor[
              0.9937947583663093, 0.9891359405287304, 0.5659759263641978], 6 -> 
             RGBColor[
              0.33431180974343394`, 0.46398581942480244`, 0.9425230307898937],
              218 -> RGBColor[
              0.7398173513855104, 0.796670204813265, 0.9747017376660327], 108 -> 
             RGBColor[
              0.3113782533268795, 0.444121925530844, 0.9410617248543786], 297 -> 
             RGBColor[
              0.24929221648012767`, 0.37935230393301794`, 0.937508194982534], 
             487 -> RGBColor[
              0.2384268837263016, 0.3679321503068611, 0.936889430356023], 464 -> 
             RGBColor[
              0.2802695819329819, 0.41191147910237724`, 0.9392723101181687], 
             157 -> RGBColor[
              0.8177268607774917, 0.8575337056844831, 0.9824670294564657], 
             441 -> RGBColor[
              0.3682418148538177, 0.4933742844797741, 0.9446850207124019], 
             354 -> RGBColor[
              0.8619160083689651, 0.8927324452593671, 0.9866915123913776], 
             385 -> RGBColor[
              0.1902491888261562, 0.31729433832452386`, 0.9341457819039722], 
             270 -> RGBColor[
              0.18403967249588782`, 0.31076774295533705`, 0.9337921591351197],
              392 -> RGBColor[
              0.4420343431064375, 0.5572896635318818, 0.9493870153604882], 33 -> 
             RGBColor[
              0.5603811253615456, 0.6539816683073362, 0.9585344014136115], 
             252 -> RGBColor[
              0.1934857951277101, 0.32069621676014903`, 0.9343301018447159], 
             394 -> RGBColor[
              0.19842878437042233`, 0.3258916118578589, 0.934611597769591], 
             260 -> RGBColor[
              0.3120362716652125, 0.4446918679425447, 0.9411036532010344], 
             159 -> RGBColor[
              0.41932351101049736`, 0.5376186822499895, 0.9479399012217352], 
             183 -> RGBColor[
              0.2566248317017963, 0.38705934744564896`, 0.9379257765717759], 
             99 -> RGBColor[0.817319, 0.134127, 0.164218], 329 -> 
             RGBColor[
              0.19035022185825642`, 0.3174005304471254, 0.9341515355856854], 
             309 -> RGBColor[
              0.21885291985763583`, 0.3473586732199038, 0.935774722070787], 
             17 -> RGBColor[
              0.9874606584389937, 0.9890826742652142, 0.8574728706489945], 
             349 -> RGBColor[
              0.2059271258124198, 0.33377284413570474`, 0.9350386172219107], 
             495 -> RGBColor[0.817319, 0.134127, 0.164218], 347 -> 
             RGBColor[
              0.2829518153401187, 0.4147306764766984, 0.9394250593426964], 
             340 -> RGBColor[
              0.981651687789881, 0.9858364393130727, 0.9159430859521958], 404 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 277 -> 
             RGBColor[
              0.9810175438161675, 0.9476298593785759, 0.3807571715722161], 
             104 -> RGBColor[0.817319, 0.134127, 0.164218], 79 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 327 -> 
             RGBColor[
              0.19982772421039008`, 0.3273619863275738, 0.9346912653239311], 
             191 -> RGBColor[
              0.22919385631472186`, 0.35822765308954135`, 0.9363636231039736],
              50 -> RGBColor[0.817319, 0.134127, 0.164218], 225 -> 
             RGBColor[
              0.2006287179667525, 0.32820388155144814`, 0.9347368807333919], 
             405 -> RGBColor[
              0.19069604752509664`, 0.31776401514958813`, 0.9341712298458087],
              61 -> RGBColor[0.817319, 0.134127, 0.164218], 196 -> 
             RGBColor[
              0.23522235731990115`, 0.36456398987502503`, 0.9367069373178505],
              1 -> RGBColor[
              0.2665869568298027, 0.3975301725903983, 0.9384931048601725], 
             263 -> 
             RGBColor[
              0.38201222096486337`, 0.5053015181324264, 0.9455624588131057], 
             201 -> RGBColor[
              0.5677847377648733, 0.6599922543852954, 0.9591172409023272], 
             371 -> RGBColor[
              0.5466494280863021, 0.6428336578533808, 0.9574533919032397], 
             293 -> RGBColor[0.817319, 0.134127, 0.164218], 362 -> 
             RGBColor[
              0.18026187282935408`, 0.3067970359794769, 0.9335770190328644], 
             184 -> RGBColor[
              0.8763132971847281, 0.531249394926778, 0.21850512214346993`], 
             106 -> RGBColor[
              0.18203014314014365`, 0.3086556001909298, 0.9336777194111423], 
             206 -> RGBColor[
              0.18533323543547214`, 0.3121273596214676, 0.9338658256308742], 
             358 -> RGBColor[
              0.3846259152851337, 0.5075653687845483, 0.9457290011039943], 
             247 -> RGBColor[
              0.2019820387076045, 0.3296263074555744, 0.9348139503475248], 
             220 -> RGBColor[
              0.3469706927955112, 0.4749503076705497, 0.9433296436241613], 
             407 -> RGBColor[
              0.6882645660939893, 0.7563967771278489, 0.9695634378163434], 
             107 -> RGBColor[
              0.3194029847849358, 0.4510725445850818, 0.9415730536468945], 
             375 -> RGBColor[
              0.28151321698943976`, 0.41321861839773133`, 0.9393431332948408],
              131 -> RGBColor[0.817319, 0.134127, 0.164218], 411 -> 
             RGBColor[
              0.7123092841021239, 0.7751806935824288, 0.9719599905967291], 
             462 -> RGBColor[
              0.22691262429331643`, 0.35582993359658016`, 0.9362337103151348],
              127 -> RGBColor[0.817319, 0.134127, 0.164218], 210 -> 
             RGBColor[
              0.2504170603715949, 0.38053458618217195`, 0.9375722531780957], 
             357 -> RGBColor[
              0.22035367918749607`, 0.34893606642922426`, 0.9358601880944482],
              181 -> RGBColor[
              0.3876691533578903, 0.5102012686455771, 0.9459229135429605], 
             194 -> RGBColor[
              0.20985498932745156`, 0.3379012777309339, 0.9352623032383384], 
             440 -> RGBColor[0.817319, 0.134127, 0.164218], 490 -> 
             RGBColor[
              0.34185985738752034`, 0.47052355891820463`, 0.9430039857112984],
              118 -> RGBColor[
              0.23614802813125227`, 0.3655369285886743, 0.9367596529011497], 
             348 -> RGBColor[
              0.9627353434690271, 0.8859597047428938, 0.30973427552741817`], 
             276 -> RGBColor[
              0.33049394994511194`, 0.46067898115870887`, 0.9422797601395455],
              305 -> RGBColor[
              0.8618019499281809, 0.8926414981547197, 0.9866806333954745], 
             343 -> RGBColor[0.817319, 0.134127, 0.164218], 280 -> 
             RGBColor[
              0.5428330408674731, 0.6397353427828505, 0.9571529519214865], 
             474 -> RGBColor[
              0.4068383352175211, 0.5268046505012949, 0.9471443568604142], 
             189 -> RGBColor[
              0.5334133816925579, 0.6320880391138444, 0.9564114018458887], 
             168 -> RGBColor[
              0.7801061400958719, 0.8281441127599345, 0.9787173476045451], 
             363 -> RGBColor[
              0.1948064264350734, 0.3220842839970489, 0.9344053098439712], 41 -> 
             RGBColor[
              0.6031363050639882, 0.6886922492886749, 0.9619002457771715], 14 -> 
             RGBColor[
              0.4138740589676099, 0.532898640787864, 0.9475926669563236], 77 -> 
             RGBColor[
              0.9392816575746442, 0.9542369401531062, 0.9876644952328739], 51 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 438 -> 
             RGBColor[
              0.28107859249471434`, 0.41276180049699024`, 0.9393183820728355],
              179 -> RGBColor[
              0.270181620235489, 0.40130839174459826`, 0.9386978156232983], 
             467 -> RGBColor[
              0.23156344686445007`, 0.3607182429980241, 0.9364985677802855], 
             223 -> RGBColor[
              0.3049544364430743, 0.43785682630265677`, 0.9406780760645487], 
             456 -> RGBColor[
              0.25079540388990307`, 0.3809322492082784, 0.9375937992817542], 
             323 -> RGBColor[0.817319, 0.134127, 0.164218], 500 -> 
             RGBColor[
              0.27395775301500525`, 0.40527734671651633`, 0.938912860798804], 
             478 -> RGBColor[
              0.5167389750172862, 0.6185510046013983, 0.955098731472047], 292 -> 
             RGBColor[
              0.2056030288546981, 0.3334321976842053, 0.9350201603796269], 
             491 -> RGBColor[
              0.1905565107603236, 0.3176173531626698, 0.9341632834334811], 
             396 -> RGBColor[
              0.25866502514756723`, 0.3892037201128899, 0.9380419625703169], 
             321 -> RGBColor[0.817319, 0.134127, 0.164218], 143 -> 
             RGBColor[
              0.8371868177096, 0.28683975304921994`, 0.1832434446762037], 112 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 197 -> 
             RGBColor[
              0.4134590735708867, 0.5325392012949949, 0.9475662244538017], 
             421 -> RGBColor[
              0.2022293934039294, 0.3298862929246055, 0.934828036831552], 54 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 71 -> 
             RGBColor[
              0.25995825934690286`, 0.39056299125217575`, 0.9381156103448005],
              177 -> RGBColor[
              0.20242608517667066`, 0.3300930284487352, 0.9348392381370303], 
             158 -> RGBColor[
              0.23397806856290648`, 0.3632561634989598, 0.9366360769138999], 
             226 -> RGBColor[
              0.21361395179144738`, 0.34185218561257913`, 0.9354763705897763],
              432 -> RGBColor[
              0.7713866596486274, 0.8213323883640413, 0.9778482712817413], 
             350 -> RGBColor[
              0.19011491379531606`, 0.31715320675358216`, 0.9341381351396081],
              203 -> RGBColor[0.817319, 0.134127, 0.164218], 475 -> 
             RGBColor[
              0.94225898230895, 0.9564574240650298, 0.9826246610683506], 115 -> 
             RGBColor[
              0.23087379955273474`, 0.3599933799472462, 0.9364592933861251], 
             173 -> RGBColor[0.817319, 0.134127, 0.164218], 212 -> 
             RGBColor[
              0.1919302366972257, 0.31906122622160893`, 0.9342415150933422], 
             129 -> RGBColor[
              0.7604405856228837, 0.8127812321418865, 0.9767572689197328], 
             279 -> RGBColor[
              0.304084721945441, 0.4369427012225601, 0.9406285471105358], 26 -> 
             RGBColor[
              0.20463513155106594`, 0.33241487624985433`, 0.9349650400600608],
              40 -> RGBColor[
              0.20512412607187444`, 0.33292884049526744`, 0.9349928875746183],
              146 -> RGBColor[
              0.18386384177004123`, 0.31058293371416035`, 0.933782145835401], 
             386 -> RGBColor[
              0.8434965379903663, 0.8780452595626765, 0.9849346468634116], 
             192 -> RGBColor[
              0.8701957487608276, 0.8993344855002725, 0.9874812414213651], 
             300 -> RGBColor[
              0.4181101479346723, 0.5365677281391114, 0.9478625867994784], 
             221 -> RGBColor[0.817319, 0.134127, 0.164218], 62 -> 
             RGBColor[
              0.5285279267956817, 0.6281218067413252, 0.9560268009403956], 
             286 -> RGBColor[
              0.21540663334735502`, 0.3437364075904136, 0.9355784611523505], 
             472 -> 
             RGBColor[
              0.19705660398054506`, 0.3244493632668362, 0.9345334541263465], 
             152 -> RGBColor[
              0.20179304187532063`, 0.3294276598017528, 0.934803187257522], 
             64 -> RGBColor[
              0.20425044222453645`, 0.33201054337695984`, 0.9349431325720118],
              307 -> RGBColor[
              0.23426115126844915`, 0.3635537013709653, 0.9366521980551972], 
             37 -> RGBColor[0.817319, 0.134127, 0.164218], 148 -> 
             RGBColor[
              0.6735645089681628, 0.7449129807765811, 0.9680982735018852], 
             261 -> RGBColor[
              0.9264054963123022, 0.9441546124248671, 0.9928425773218587], 
             387 -> RGBColor[
              0.22184597588427246`, 0.3505045648746116, 0.9359451721836745], 
             15 -> RGBColor[0.817319, 0.134127, 0.164218], 136 -> 
             RGBColor[
              0.8894828910866501, 0.591049444998604, 0.22949415411151997`], 
             198 -> RGBColor[
              0.19393685411417064`, 0.3211703083537106, 0.9343557889867128], 
             63 -> RGBColor[
              0.29903790758239124`, 0.43163817934048265`, 0.9403411384986529],
              444 -> RGBColor[
              0.8510308907134999, 0.3932513646686672, 0.19650054461938235`], 
             310 -> RGBColor[0.817319, 0.134127, 0.164218], 171 -> 
             RGBColor[
              0.9553966243175557, 0.8608695091526162, 0.28296928083135936`], 
             395 -> RGBColor[
              0.9159682611686081, 0.7045491879901851, 0.25124429433908335`], 
             311 -> RGBColor[
              0.22655758961928207`, 0.35545676964367157`, 0.9362134916156754],
              353 -> RGBColor[
              0.1865974340180864, 0.31345611248661487`, 0.9339378198699398], 
             59 -> RGBColor[
              0.6025610453058137, 0.6882252275018321, 0.961854959221762], 397 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 229 -> 
             RGBColor[
              0.4323931062930283, 0.5489389087867588, 0.9487726842761488], 
             102 -> RGBColor[
              0.26729718777158684`, 0.39827667034145603`, 0.9385335514616145],
              453 -> RGBColor[
              0.45788186350371485`, 0.5707681499920235, 0.9504652840529954], 
             299 -> RGBColor[
              0.4587788150425182, 0.5714963356584305, 0.9505358953637717], 
             128 -> RGBColor[
              0.24495698094472051`, 0.3747956965154964, 0.9372613097321988], 
             12 -> RGBColor[
              0.2440062290021841, 0.3737963959427358, 0.9372071658155828], 
             222 -> RGBColor[
              0.2572169453532387, 0.3876816964354887, 0.9379594965682719], 
             483 -> RGBColor[
              0.9714214766675533, 0.9152600716225856, 0.3434782627650753], 92 -> 
             RGBColor[
              0.6576732634723652, 0.7324986190173249, 0.9665143826629965], 
             271 -> RGBColor[
              0.3045714380557589, 0.43745427071408804`, 0.9406562648729865], 
             361 -> RGBColor[
              0.4096552744186712, 0.5292445416538502, 0.94732384973539], 344 -> 
             RGBColor[
              0.2278120755134005, 0.35677531385738964`, 0.9362849327314998], 
             132 -> RGBColor[
              0.6598859337650126, 0.7342271738668581, 0.966734920959188], 80 -> 
             RGBColor[
              0.9579895862140718, 0.9681892827009697, 0.9559968518555605], 
             324 -> RGBColor[0.817319, 0.134127, 0.164218], 244 -> 
             RGBColor[
              0.977212423501673, 0.9347942950730491, 0.3659749976870823], 150 -> 
             RGBColor[
              0.3389460376431222, 0.4679997547084456, 0.942818319693775], 125 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 258 -> 
             RGBColor[
              0.9939516779922013, 0.9894715757415058, 0.5830556592468749], 
             133 -> RGBColor[
              0.2610002522409667, 0.3916581918500021, 0.9381749502986271], 
             469 -> RGBColor[
              0.1893750053770723, 0.3163755160931047, 0.9340959984497854], 
             255 -> RGBColor[
              0.25751049402968956`, 0.3879902347064996, 0.9379762137311295], 
             408 -> RGBColor[0.817319, 0.134127, 0.164218], 326 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 176 -> 
             RGBColor[
              0.8837943025257868, 0.9101776031495423, 0.9887782836190391], 
             230 -> RGBColor[
              0.29510601197456354`, 0.4275055077600755, 0.9401172228605054], 
             274 -> RGBColor[
              0.48393777173830865`, 0.5919215101021562, 0.9525165005951594], 
             87 -> RGBColor[
              0.854284899814332, 0.8866476064388262, 0.9859636504450657], 439 -> 
             RGBColor[
              0.2663834741236062, 0.397316299364637, 0.9384815168210803], 130 -> 
             RGBColor[
              0.8331937393088721, 0.8698300875560732, 0.9839519567277537], 35 -> 
             RGBColor[
              0.21649762081927568`, 0.34488310459600313`, 0.9356405912749051],
              379 -> RGBColor[0.817319, 0.134127, 0.164218], 31 -> 
             RGBColor[
              0.23515707303258868`, 0.3644953719497967, 0.9367032194742675], 
             18 -> RGBColor[
              0.7541788838097023, 0.8078895430947328, 0.9761331610019253], 24 -> 
             RGBColor[
              0.20633904470983166`, 0.3342057970140512, 0.9350620753937389], 
             151 -> RGBColor[
              0.28569344941384495`, 0.4176123077178249, 0.9395811913473109], 
             137 -> RGBColor[
              0.3211744864498682, 0.45260693028898363`, 0.9416859321665065], 
             330 -> RGBColor[
              0.22481780914373545`, 0.3536281500554188, 0.9361144136913675], 
             296 -> RGBColor[
              0.19315143637710094`, 0.3203447845136896, 0.9343110606085081], 
             266 -> RGBColor[0.817319, 0.134127, 0.164218], 302 -> 
             RGBColor[
              0.48818097544843886`, 0.5953663340281886, 0.9528505411345881], 
             442 -> RGBColor[
              0.44708899097258314`, 0.5616677454595485, 0.9497090930528694], 
             283 -> RGBColor[
              0.19353123231110916`, 0.32074397412078526`, 0.9343326894250921],
              388 -> RGBColor[
              0.9243202823709581, 0.9424919194296639, 0.9926436877546408], 
             284 -> RGBColor[
              0.29911991378268726`, 0.43172437305648714`, 0.9403458086304425],
              417 -> RGBColor[
              0.25734139130129635`, 0.3878124970172262, 0.9379665835809126], 
             318 -> RGBColor[
              0.2610014285656661, 0.39165942824184447`, 0.9381750172885784], 
             413 -> RGBColor[
              0.4106589580798899, 0.5301138819945902, 0.9473878035707602], 
             238 -> RGBColor[
              0.936541673425211, 0.7861159119043911, 0.2677981447607987], 72 -> 
             RGBColor[
              0.3185855666826758, 0.4503645381095326, 0.941520968488233], 437 -> 
             RGBColor[
              0.19181759620694716`, 0.3189428339245066, 0.9342351003840575], 
             288 -> RGBColor[0.817319, 0.134127, 0.164218], 382 -> 
             RGBColor[
              0.3231603966004548, 0.4543270258466754, 0.9418124726052306], 
             461 -> RGBColor[
              0.5415651525659718, 0.6387060139419746, 0.9570531391099645], 
             389 -> RGBColor[
              0.24782292745212858`, 0.377807988006286, 0.9374245211460078], 
             172 -> RGBColor[
              0.37795345536951325`, 0.5017860193732245, 0.9453038378583956], 
             447 -> 
             RGBColor[
              0.4270628245166249, 0.5443220866197901, 0.9484330434347394], 
             243 -> RGBColor[
              0.2549643465593099, 0.385314072280057, 0.937831214399379], 410 -> 
             RGBColor[
              0.19323299612210112`, 0.3204305089768713, 0.934315705315329], 
             88 -> RGBColor[
              0.22472424201089944`, 0.35352980506630927`, 0.9361090851815727],
              273 -> RGBColor[
              0.21438528258518844`, 0.34266290318199794`, 0.9355202967373982],
              477 -> RGBColor[
              0.26019557655375813`, 0.3908124266833606, 0.9381291252086515], 
             202 -> RGBColor[
              0.21266853360939608`, 0.34085849116026834`, 0.9354225304229293],
              393 -> RGBColor[
              0.36751400675687457`, 0.4927438936869005, 0.9446386454240401], 
             98 -> RGBColor[
              0.21930919416960923`, 0.3478382464512501, 0.9358007062178566], 
             30 -> RGBColor[
              0.1789570524953891, 0.3054255870780922, 0.9335027114451537], 
             116 -> RGBColor[
              0.6844298372258936, 0.7534010577910736, 0.9691812278803502], 
             373 -> RGBColor[0.817319, 0.134127, 0.164218], 434 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 401 -> 
             RGBColor[
              0.18668189134142482`, 0.3135448824883471, 0.9339426295895605], 
             240 -> RGBColor[0.817319, 0.134127, 0.164218], 480 -> 
             RGBColor[
              0.47940132385552714`, 0.5882386173462659, 0.9521593748002706], 
             403 -> RGBColor[0.817319, 0.134127, 0.164218], 317 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 429 -> 
             RGBColor[
              0.23501975925948257`, 0.36435104646806615`, 0.9366953996580266],
              391 -> RGBColor[
              0.9525439023720605, 0.8495594172519633, 0.28067391379202367`], 
             73 -> RGBColor[
              0.8407007288961474, 0.31384921423472306`, 0.18660836999683647`],
              303 -> RGBColor[0.817319, 0.134127, 0.164218], 449 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 29 -> 
             RGBColor[
              0.20262840066914578`, 0.3303056748588697, 0.9348507597050277], 
             360 -> RGBColor[
              0.8226648881293261, 0.1752178387451157, 0.16933722850995975`], 
             320 -> RGBColor[
              0.18845275152117702`, 0.31540616881628697`, 0.9340434774570445],
              482 -> RGBColor[
              0.9362533521083286, 0.9519784348947232, 0.9927906264787851], 75 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 200 -> 
             RGBColor[
              0.6024325749506131, 0.6881209294799567, 0.9618448455647982], 
             301 -> RGBColor[0.817319, 0.134127, 0.164218], 156 -> 
             RGBColor[
              0.26709219000597495`, 0.39806120469218886`, 0.93852187714213], 
             25 -> RGBColor[
              0.7576060273863839, 0.8105668537040923, 0.9764747466451712], 38 -> 
             RGBColor[
              0.8992999083697804, 0.6356262276586594, 0.23768571396967728`], 
             365 -> RGBColor[
              0.30003965645411895`, 0.4326910809192154, 0.9403981866149431], 
             380 -> RGBColor[
              0.2157216182949494, 0.34406747674153443`, 0.9355963990791376], 
             370 -> RGBColor[
              0.4032230834287326, 0.5236733011096846, 0.9469139962132742], 3 -> 
             RGBColor[
              0.19930844041135132`, 0.32681618613028957`, 0.9346616928797874],
              57 -> RGBColor[0.817319, 0.134127, 0.164218], 227 -> 
             RGBColor[
              0.24023088414070523`, 0.3698282691226319, 0.9369921655108439], 
             494 -> RGBColor[
              0.9693843335785163, 0.976687466628186, 0.9367085167936384], 39 -> 
             RGBColor[
              0.5059330480764017, 0.6097782663093272, 0.954248049319846], 424 -> 
             RGBColor[
              0.2415788936308724, 0.37124511256553566`, 0.9370689326571076], 
             109 -> RGBColor[
              0.33067337344239356`, 0.46083438877396704`, 0.9422911928461343],
              465 -> RGBColor[
              0.1794538714957133, 0.3059477753475769, 0.9335310045522444], 
             256 -> RGBColor[
              0.8652595816135205, 0.8953985198056976, 0.9870104253922865], 
             457 -> RGBColor[
              0.9567649542169475, 0.8658201798815686, 0.2865404406964947], 
             339 -> RGBColor[
              0.18435110707541025`, 0.31109508044450795`, 0.9338098948736974],
              420 -> RGBColor[
              0.21820107858971777`, 0.3466735467181985, 0.9357376006748919], 
             287 -> RGBColor[
              0.8379345637063845, 0.8736102922443995, 0.9844041407909724], 
             239 -> RGBColor[
              0.25524447055801713`, 0.38560850036358557`, 0.937847167046699], 
             427 -> RGBColor[
              0.2116086394211203, 0.33974447516721756`, 0.93536217101688], 
             285 -> RGBColor[
              0.3342797596203076, 0.46395805921903643`, 0.9425209885843889], 
             345 -> 
             RGBColor[
              0.2302467671760705, 0.35933432916322317`, 0.9364235848198853], 
             366 -> RGBColor[
              0.19456249333096626`, 0.3218278948383802, 0.9343914182145591], 
             216 -> RGBColor[
              0.2693332332275772, 0.4004166832084398, 0.938649501238274], 21 -> 
             RGBColor[
              0.8219966379615026, 0.8609018228788999, 0.9828839672054712], 
             355 -> RGBColor[
              0.8567924356784412, 0.43753712399430794`, 0.2020178065845444], 
             175 -> RGBColor[
              0.9948073015950193, 0.9921207000103479, 0.7357199810506223], 7 -> 
             RGBColor[
              0.9534406635465423, 0.8531147764808367, 0.28139546888270184`], 
             13 -> RGBColor[
              0.5395182465349754, 0.6370442434139459, 0.9568919991691406], 
             294 -> RGBColor[
              0.2158208370998732, 0.3441717619963449, 0.935602049443297], 412 -> 
             RGBColor[
              0.2277251794483852, 0.35668398058352985`, 0.9362799841291484], 
             193 -> RGBColor[
              0.18752850541486277`, 0.314434727557963, 0.9339908430085895], 
             60 -> RGBColor[0.817319, 0.134127, 0.164218], 65 -> 
             RGBColor[
              0.1972436349934338, 0.32464594471983343`, 0.9345441052658429], 
             448 -> RGBColor[
              0.8242283061574975, 0.8626812945213669, 0.9830968257102389], 69 -> 
             RGBColor[
              0.9814207743108861, 0.9489900505202847, 0.382323645900509], 217 -> 
             RGBColor[
              0.18890068939112134`, 0.3158769799184998, 0.9340689868560732], 
             214 -> RGBColor[
              0.21604971918074886`, 0.3444123315753073, 0.9356150839392021], 
             170 -> RGBColor[
              0.21686761525785075`, 0.3452719922099478, 0.9356616619108242], 
             359 -> RGBColor[0.817319, 0.134127, 0.164218], 74 -> 
             RGBColor[
              0.22105372540225315`, 0.34967185938642753`, 0.935900054690753], 
             246 -> RGBColor[
              0.4576850364535088, 0.5706083569257087, 0.9504497891066018], 
             264 -> RGBColor[0.817319, 0.134127, 0.164218], 278 -> 
             RGBColor[
              0.2027780029210282, 0.3304629163109287, 0.9348592793319558], 45 -> 
             RGBColor[
              0.27477024647677334`, 0.40613132885989545`, 0.9389591310994754],
              492 -> RGBColor[
              0.19478601411047772`, 0.3220628293496827, 0.9344041473922828], 
             306 -> 
             RGBColor[
              0.4631485198395302, 0.5750438588656026, 0.9508798945321485], 
             237 -> RGBColor[
              0.4230361383836957, 0.5408343734785764, 0.9481764665550079], 
             228 -> RGBColor[
              0.5725831029202398, 0.6638877833823089, 0.9594949857843484], 
             180 -> RGBColor[
              0.6034964487201209, 0.6889846301330103, 0.9619285976050319], 
             383 -> RGBColor[
              0.6325346241150686, 0.7125591290735227, 0.9642145891424635], 53 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 304 -> 
             RGBColor[
              0.22967809360797173`, 0.35873661718716465`, 0.9363911997014592],
              48 -> RGBColor[
              0.22612030793820787`, 0.35499715887160266`, 0.9361885890708385],
              5 -> RGBColor[0.817319, 0.134127, 0.164218], 101 -> 
             RGBColor[
              0.49037845718069295`, 0.5971503486938564, 0.953023534946192], 
             333 -> RGBColor[
              0.4177501378450422, 0.536255905494107, 0.9478396472749117], 267 -> 
             RGBColor[
              0.4056075310905943, 0.525738589828565, 0.9470659311098037], 120 -> 
             RGBColor[
              0.18313418987661276`, 0.309816023311565, 0.9337405932394934], 
             147 -> RGBColor[0.817319, 0.134127, 0.164218], 89 -> 
             RGBColor[
              0.8587915518062159, 0.890241088407345, 0.9863934989351874], 43 -> 
             RGBColor[
              0.40134636687536374`, 0.5220477835576731, 0.9467944134940088], 
             199 -> RGBColor[
              0.9909931722195693, 0.9905434594949455, 0.7989299754522408], 
             268 -> RGBColor[
              0.2106927321879748, 0.33878179859330904`, 0.9353100114549157], 
             169 -> RGBColor[
              0.19997089892350478`, 0.32751247202885847`, 0.934699418912035], 
             20 -> RGBColor[
              0.46934274654192526`, 0.5800726111493398, 0.9513675267483611], 
             4 -> RGBColor[
              0.19006206717459462`, 0.3170976616045347, 0.9341351256027375], 
             167 -> RGBColor[
              0.4574599131251553, 0.570425591666061, 0.95043206657354], 431 -> 
             RGBColor[
              0.9934489814254173, 0.9883963586155741, 0.5283402402360341], 
             142 -> RGBColor[
              0.340635459799505, 0.4694630472674779, 0.9429259681796823], 16 -> 
             RGBColor[
              0.6469324131931254, 0.7241077851456973, 0.9654438350861145], 
             414 -> RGBColor[
              0.9933318523271546, 0.9881458313179586, 0.5155914607271469], 
             281 -> RGBColor[0.817319, 0.134127, 0.164218], 289 -> 
             RGBColor[
              0.31358168594229274`, 0.44603042811457155`, 0.9412021256322137],
              398 -> RGBColor[
              0.29666018860098814`, 0.42913904593493735`, 0.940205730920182], 
             178 -> RGBColor[
              0.9567165072169457, 0.8656567567746658, 0.2863522332499358], 58 -> 
             RGBColor[
              0.240267978136988, 0.3698672572646202, 0.9369942779590565], 186 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 122 -> 
             RGBColor[
              0.2080093336373953, 0.3359613765793552, 0.9351571958771926], 
             249 -> RGBColor[0.817319, 0.134127, 0.164218], 113 -> 
             RGBColor[
              0.25555645648574987`, 0.385936417354683, 0.9378649341837416], 
             52 -> RGBColor[
              0.18352693138300546`, 0.3102288195360335, 0.9337629592872735], 
             409 -> RGBColor[
              0.5413266543134985, 0.638512390316393, 0.9570343636538818], 187 -> 
             RGBColor[
              0.36718010963697145`, 0.4924546887837977, 0.9446173697948136], 
             259 -> RGBColor[0.817319, 0.134127, 0.164218], 42 -> 
             RGBColor[
              0.2720687261283602, 0.40329185968743014`, 0.9388052835121744], 
             134 -> RGBColor[
              0.2013445076269774, 0.3289562218680302, 0.9347776438956258], 
             470 -> RGBColor[
              0.24649818947394458`, 0.37641560439797556`, 0.9373490792779244],
              313 -> RGBColor[
              0.9779347509559622, 0.9830643539082616, 0.9222348904796338], 
             248 -> RGBColor[
              0.18472467114451377`, 0.31148771996646574`, 0.9338311687947942],
              174 -> RGBColor[
              0.215756853533542, 0.3441045112113384, 0.9355984056738496], 215 -> 
             RGBColor[
              0.20492571704741236`, 0.3327203000306991, 0.934981588474195], 
             399 -> RGBColor[
              0.30363758949702413`, 0.4364727366694393, 0.9406030835790716], 
             422 -> RGBColor[
              0.29787052949847936`, 0.4304111909582458, 0.9402746580437552], 
             83 -> RGBColor[0.817319, 0.134127, 0.164218], 95 -> 
             RGBColor[
              0.20371097625405837`, 0.3314435304378693, 0.9349124107830614], 
             166 -> RGBColor[
              0.25109817118593475`, 0.381250476832963, 0.9376110414313592], 
             384 -> 
             RGBColor[
              0.6344197195047021, 0.7140895344334067, 0.9643629907568674], 
             233 -> RGBColor[0.817319, 0.134127, 0.164218], 295 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 499 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 141 -> 
             RGBColor[
              0.3011825170683711, 0.43389229988634254`, 0.9404632708362141], 
             319 -> RGBColor[
              0.18726572239046815`, 0.31415852593791815`, 0.9339758779041029],
              205 -> RGBColor[
              0.4450599520442159, 0.5599102939222584, 0.9495798044865625], 
             468 -> RGBColor[
              0.36840454856349925`, 0.4935152362398662, 0.9446953899604831], 
             486 -> RGBColor[
              0.9941045402798871, 0.9897985327181177, 0.5996937759047933], 
             224 -> RGBColor[
              0.295260889517734, 0.42766829387775107`, 0.9401260429074682], 
             231 -> RGBColor[0.817319, 0.134127, 0.164218], 332 -> 
             RGBColor[
              0.2120977707203083, 0.34025858317537977`, 0.9353900263207638], 
             68 -> RGBColor[
              0.20692796280704617`, 0.3348247872737876, 0.935095613408149], 
             484 -> RGBColor[
              0.20427604235269314`, 0.3320374507347944, 0.9349445904614383], 
             10 -> RGBColor[
              0.3937584149506567, 0.5154754809820448, 0.946310915907129], 250 -> 
             RGBColor[
              0.3594825143186384, 0.4857874186114477, 0.9441268858278457], 
             282 -> RGBColor[0.817319, 0.134127, 0.164218], 374 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 232 -> 
             RGBColor[
              0.6961033750146681, 0.7625205142338375, 0.9703447370317223], 
             489 -> RGBColor[
              0.2336066799286998, 0.3628658104970091, 0.9366149268806021], 
             253 -> RGBColor[
              0.9881377044358732, 0.9893626501842123, 0.8462524663418269], 
             459 -> RGBColor[
              0.24592141072655926`, 0.37580937336458886`, 0.9373162325815285],
              415 -> RGBColor[
              0.1852681323985655, 0.3120589322019077, 0.9338621181092336], 55 -> 
             RGBColor[
              0.8437950041640877, 0.3376331698641804, 0.18957145148790017`], 
             446 -> RGBColor[
              0.1982250439704274, 0.32567746777957673`, 0.9345999950552182], 
             325 -> RGBColor[
              0.4266116652397737, 0.5439313151301061, 0.948404295964563], 91 -> 
             RGBColor[
              0.9641975980982375, 0.8908922329609346, 0.3154148586382841], 
             450 -> RGBColor[
              0.33974255441645423`, 0.4686896575034088, 0.9428690730382396], 
             423 -> RGBColor[
              0.18010256657334342`, 0.3066295950038096, 0.9335679467772571], 
             105 -> RGBColor[
              0.23276328462783158`, 0.36197934856144603`, 0.9365668967659092],
              36 -> RGBColor[0.817319, 0.134127, 0.164218], 123 -> 
             RGBColor[
              0.20873262495813816`, 0.3367216016167744, 0.9351983862478953], 
             94 -> RGBColor[0.178927, 0.305394, 0.933501], 473 -> 
             RGBColor[
              0.6063118000163332, 0.691270259145406, 0.9621502323720413], 312 -> 
             RGBColor[
              0.24802738733723106`, 0.37802288830903413`, 0.9374361648339931],
              96 -> RGBColor[
              0.9553028976633565, 0.8604979142012724, 0.28289386616534334`], 
             496 -> RGBColor[
              0.2085981516455076, 0.3365802616390992, 0.9351907281916764], 2 -> 
             RGBColor[
              0.20161671018842872`, 0.32924232401875475`, 0.9347931454288129],
              262 -> RGBColor[
              0.9518509475754381, 0.963611096055375, 0.9663879658573935], 272 -> 
             RGBColor[
              0.5663742859676012, 0.6588471860761407, 0.9590062049701908], 97 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 372 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 356 -> 
             RGBColor[
              0.49166457190272544`, 0.5981944745640103, 0.9531247826083038], 
             402 -> RGBColor[
              0.35222766772351993`, 0.4795036351299483, 0.9436646134180137], 
             455 -> RGBColor[0.817319, 0.134127, 0.164218], 428 -> 
             RGBColor[
              0.2170356376005423, 0.34544859434534847`, 0.9356712305346737], 
             346 -> RGBColor[
              0.9829894651638862, 0.9542816131135821, 0.3884177136420036], 
             341 -> RGBColor[0.817319, 0.134127, 0.164218], 209 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 498 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 378 -> 
             RGBColor[
              0.2996969855238355, 0.4323309120448956, 0.9403786720123997], 
             419 -> RGBColor[0.817319, 0.134127, 0.164218], 66 -> 
             RGBColor[
              0.2605769831148301, 0.3912133091616199, 0.9381508457480642], 
             139 -> RGBColor[
              0.19474583817336233`, 0.32202060189247295`, 0.9344018594320991],
              56 -> 
             RGBColor[
              0.9946416792371043, 0.9909474186345262, 0.6581580365604908], 
             335 -> RGBColor[
              0.3150309137810037, 0.44728567642815387`, 0.9412944691485945], 
             314 -> RGBColor[
              0.6013820686751921, 0.6872680811608015, 0.9617621458626657], 
             144 -> RGBColor[
              0.2562538810668797, 0.3866694548087229, 0.9379046514818897], 
             298 -> RGBColor[
              0.6797711867345639, 0.7497616846201918, 0.9687168971369385], 
             204 -> RGBColor[
              0.8802420747951332, 0.9073451531797723, 0.9884394689669782], 
             452 -> RGBColor[
              0.3938614602073101, 0.5155647336041528, 0.9463174818597636], 
             466 -> RGBColor[
              0.2476714334157858, 0.37764875816881305`, 0.9374158937847534], 
             207 -> RGBColor[0.817319, 0.134127, 0.164218], 334 -> 
             RGBColor[
              0.2130775983694969, 0.3412884441593381, 0.93544582605586], 149 -> 
             RGBColor[
              0.8554632653203876, 0.4273205381761434, 0.2007449915485891], 
             219 -> RGBColor[0.817319, 0.134127, 0.164218], 400 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 9 -> 
             RGBColor[
              0.242957706247003, 0.37269433204685803`, 0.9371474539958257], 
             11 -> RGBColor[
              0.9875036737064178, 0.989100462183736, 0.8567599963478333], 44 -> 
             RGBColor[
              0.6993501336328052, 0.7650569067426056, 0.970668343588094], 153 -> 
             RGBColor[
              0.3978373772063899, 0.5190084730733568, 0.9465708237751796], 
             471 -> RGBColor[0.817319, 0.134127, 0.164218], 406 -> 
             RGBColor[
              0.9938422671704169, 0.9892375570568399, 0.5711469665009675], 32 -> 
             RGBColor[
              0.3596303768180513, 0.4859154896766539, 0.9441363074955585], 
             162 -> RGBColor[
              0.19787594539539122`, 0.32531054304308565`, 0.934580114407815], 
             493 -> RGBColor[
              0.5894436674267205, 0.677575949208445, 0.9608223111845814], 90 -> 
             RGBColor[
              0.5985155306782874, 0.6849408964788493, 0.9615364814910747], 
             331 -> RGBColor[
              0.8274945099942945, 0.8652856768020875, 0.9834083591479672], 8 -> 
             RGBColor[
              0.2588724192803225, 0.3894217044959632, 0.9380537733593651], 
             364 -> RGBColor[
              0.28861702790878196`, 0.42068517408158657`, 0.9397476848175508],
              342 -> 
             RGBColor[
              0.9487736339623114, 0.8346115593747768, 0.2776402673299655], 
             163 -> RGBColor[0.817319, 0.134127, 0.164218], 49 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 338 -> 
             RGBColor[
              0.993193928488921, 0.9878508261742159, 0.5005793021026774], 76 -> 
             RGBColor[
              0.9943451951306927, 0.9903132691100532, 0.6258875712654035], 
             369 -> RGBColor[
              0.19227972218525266`, 0.31942855762818506`, 0.9342614177748679],
              445 -> RGBColor[0.817319, 0.134127, 0.164218], 82 -> 
             RGBColor[
              0.8979401714022621, 0.6294519796637963, 0.23655111611377708`], 
             67 -> RGBColor[
              0.18730821452687368`, 0.3142031878674374, 0.9339782977684097], 
             430 -> RGBColor[
              0.2764022607353688, 0.40784667932135976`, 0.9390520718971536], 
             211 -> RGBColor[
              0.21578236892213723`, 0.34413132950252107`, 
               0.9355998587374834]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw1l3k4VA/cxYfs69jHPjOGGTNjV1rUPZUi6hcVbZKtXVmyRook2RJlqUih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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 42}], {
             RGBColor[
             0.26932784147908145`, 0.4004110161389142, 0.9386491941861734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 108}], {
             RGBColor[
             0.2889826050783411, 0.42082604906062115`, 0.9397774148572755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[
             0.2610717066577763, 0.3917332949725406, 0.938179019521957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 119}], {
             RGBColor[
             0.2343699623005295, 0.3636680686646997, 0.9366583946825027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 120}], {
             RGBColor[
             0.22486057335320775`, 0.3536730979509817, 0.9361168490498329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 124}], {
             RGBColor[
             0.2366309542553628, 0.3660445145643992, 0.9367871548294926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 315}], {
             RGBColor[
             0.23241208756362647`, 0.36161021817978645`, 0.9365468966126522]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 363}], {
             RGBColor[
             0.23069669163243806`, 0.3598072282937236, 0.9364492073520718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 364}], {
             RGBColor[
             0.27760199236929234`, 0.4091076733359924, 0.9391203948388616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 378}], {
             RGBColor[
             0.2831419711768191, 0.4149305423176469, 0.9394358884362861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 380}], {
             RGBColor[
             0.24115428756237606`, 0.37079882466596636`, 0.937044751969655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 381}], {
             RGBColor[
             0.24294210956451456`, 0.3726779389446759, 0.9371465657878312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 416}], {
             RGBColor[
             0.288059981339665, 0.42002691875059733`, 0.9397186260884912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 452}], {
             RGBColor[
             0.3302242085185564, 0.4565474530972755, 0.942405293359968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 468}], {
             RGBColor[
             0.317495752696651, 0.44552270441513225`, 0.9415942474103278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 487}], {
             RGBColor[
             0.25250692027805216`, 0.38273116144862973`, 0.9376912676080977]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[
             0.23109684665162938`, 0.3602278165901873, 0.9364719955884385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 114}], {
             RGBColor[
             0.19567198478119446`, 0.322994040698391, 0.934454602111304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 118}], {
             RGBColor[
             0.2188823691598405, 0.3473896263037145, 0.9357763991649812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 195}], {
             RGBColor[
             0.2100171428775559, 0.33807171139322245`, 0.9352715376431322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 255}], {
             RGBColor[
             0.22956360210905913`, 0.3586162793626272, 0.9363846795799712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 260}], {
             RGBColor[
             0.2568264909268206, 0.3869670959806497, 0.9379483993149236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 312}], {
             RGBColor[
             0.2248220487628299, 0.35363260616389447`, 0.936114655131403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 327}], {
             RGBColor[
             0.20072221719940941`, 0.3283021551731643, 0.934742205376372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 334}], {
             RGBColor[
             0.20734715427896283`, 0.33526538408904644`, 0.9351194857423364]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 385}], {
             RGBColor[
             0.19593294950729245`, 0.32326833117163933`, 0.9344694636663926]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 446}], {
             RGBColor[
             0.19992087707942807`, 0.32745989589916574`, 0.9346965702420156]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 496}], {
             RGBColor[
             0.20510743091696815`, 0.33291129282892695`, 0.9349919368102446]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[
             0.20402053268474474`, 0.331768893873532, 0.9349300395638414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 139}], {
             RGBColor[
             0.19702713929235682`, 0.3244183940113813, 0.9345317761559433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 158}], {
             RGBColor[
             0.2166432544871289, 0.3450361748146247, 0.9356488848968436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 247}], {
             RGBColor[
             0.2006452395594779, 0.32822124679293196`, 0.9347378216136562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 278}], {
             RGBColor[
             0.20104322166618976`, 0.32863955122060917`, 0.9347604861058716]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 401}], {
             RGBColor[
             0.19299516587638807`, 0.32018053430931837`, 0.934302161234674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 428}], {
             RGBColor[
             0.20817203900594683`, 0.33613239023781905`, 0.9351664617072306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 437}], {
             RGBColor[
             0.19556301830914924`, 0.3228795100273981, 0.9344483966319225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 451}], {
             RGBColor[
             0.24545922641333842`, 0.37532358834721574`, 0.9372899118686311]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 31}], {
             RGBColor[
             0.21260957010359166`, 0.3407965167771657, 0.9354191725385025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 151}], {
             RGBColor[
             0.23787775829421978`, 0.3673549846611798, 0.9368581584750242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 162}], {
             RGBColor[
             0.19396900628499292`, 0.32120410232381014`, 0.9343576200052762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 191}], {
             RGBColor[
             0.20962796174465825`, 0.33766265734703804`, 0.9352493743533555]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.201838009483021, 0.3294749236085569, 0.9348057480962568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 345}], {
             RGBColor[
             0.21015441717533256`, 0.3382159953838789, 0.9352793552113114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 366}], {
             RGBColor[
             0.19231228025278044`, 0.3194627782214574, 0.9342632719086483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 389}], {
             RGBColor[
             0.2189424973133616, 0.34745282480541034`, 0.9357798233743726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 405}], {
             RGBColor[
             0.19037905734984562`, 0.31743083837706143`, 0.9341531777242731]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 429}], {
             RGBColor[
             0.2125409132170386, 0.3407243540363004, 0.935415262630382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 472}], {
             RGBColor[
             0.19355933557756982`, 0.3207735124356854, 0.9343342898645419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 488}], {
             RGBColor[
             0.1922517191621101, 0.319399124675368, 0.9342598230441267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 69}], {
             RGBColor[
             0.8720195914369621, 0.40574801684009487`, 0.23691988196683633`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 97}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 103}], {
             RGBColor[
             0.8763449551304583, 0.41955926219099576`, 0.3199825200895846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 129}], {
             RGBColor[
             0.7983595285409613, 0.3603450773806288, 0.4350644229732442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 163}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 204}], {
             RGBColor[
             0.8382933582650444, 0.3918663843932574, 0.4389584896556594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 209}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 231}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 233}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 259}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 275}], {
             RGBColor[
             0.8560290549644465, 0.34736971536429956`, 0.19791527993518332`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 326}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 346}], {
             RGBColor[
             0.8725424883879621, 0.4075118710378607, 0.23895123788066785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 348}], {
             RGBColor[
             0.8657911144896757, 0.38473790158096455`, 0.21272342517580606`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 355}], {
             RGBColor[
             0.8304768118928137, 0.23526370799810264`, 0.17681793552818148`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 395}], {
             RGBColor[
             0.8502020870562027, 0.32426772933006165`, 0.19322676477969444`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 404}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 431}], {
             RGBColor[
             0.8760289938084724, 0.418883452871858, 0.28559208007867803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 444}], {
             RGBColor[
             0.8285562969045, 0.22050178822288907`, 0.17497884820646079`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 486}], {
             RGBColor[
             0.8762475134266291, 0.4193508442393725, 0.30937659196826445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 35}], {
             RGBColor[
             0.2754047152813548, 0.4044344620104028, 0.9390818110323994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 101}], {
             RGBColor[
             0.4123451334620635, 0.5305680840593294, 0.9477732828680429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 123}], {
             RGBColor[
             0.2715222173507861, 0.4003537105207884, 0.9388607085188945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 158}], {
             RGBColor[
             0.2841449391531702, 0.41362099146188114`, 0.9395795538518968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 181}], {
             RGBColor[
             0.36099048155066216`, 0.4870935440351898, 0.9442229721664271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 189}], {
             RGBColor[
             0.4338625957179959, 0.5480369292693235, 0.9494672163178912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 302}], {
             RGBColor[
             0.4112463925959364, 0.5296760767264955, 0.9476867859622409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 306}], {
             RGBColor[
             0.39873016479148204`, 0.5195148391452025, 0.9467014626610211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 347}], {
             RGBColor[
             0.3086318125417763, 0.4393582479507504, 0.9409740450662951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 370}], {
             RGBColor[
             0.3687674465860833, 0.4938295602672435, 0.944718513501584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 390}], {
             RGBColor[
             0.44622497203026434`, 0.5580732632783292, 0.9504404278660695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 422}], {
             RGBColor[
             0.3160911696209566, 0.44719850519152415`, 0.9413988444168244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 428}], {
             RGBColor[
             0.2756737236719881, 0.40471720688507545`, 0.9390971306622837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 451}], {
             RGBColor[
             0.31296091107937973`, 0.44390840499447215`, 0.9412205808236842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 17}], {
             RGBColor[
             0.970450660992768, 0.9210987253730254, 0.5694341697658482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.8626928878488475, 0.3737895921602789, 0.20327715629423396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.8626928878488475, 0.3737895921602789, 0.20327715629423396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.8160959914872512, 0.8010398665049154, 0.62500535758886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 89}], {
             RGBColor[
             0.9061161076763791, 0.8716779324440909, 0.6338944839089447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 176}], {
             RGBColor[
             0.9186174830361646, 0.8816461898151895, 0.6350868762508705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 178}], {
             RGBColor[
             0.9550785853817441, 0.8593857666277512, 0.2838738510663188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 244}], {
             RGBColor[
             0.9653265435241076, 0.893954535776943, 0.32368523328489207`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 261}], {
             RGBColor[
             0.9399230799294223, 0.8986346944528518, 0.6371190231022803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 262}], {
             RGBColor[
             0.9526458055609902, 0.9083629362681058, 0.6238917173700477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 288}], {
             RGBColor[
             0.8626928878488475, 0.3737895921602789, 0.20327715629423396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 295}], {
             RGBColor[
             0.8626928878488475, 0.3737895921602789, 0.20327715629423396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 313}], {
             RGBColor[
             0.9656877072512522, 0.9180895651945491, 0.6018151796811678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 321}], {
             RGBColor[
             0.8626928878488475, 0.3737895921602789, 0.20327715629423396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 341}], {
             RGBColor[
             0.8626928878488475, 0.3737895921602789, 0.20327715629423396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 376}], {
             RGBColor[
             0.9697345365090141, 0.9208025894954335, 0.5813022057324062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 391}], {
             RGBColor[
             0.9529922829593014, 0.8513370968664, 0.28103469133736275`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 407}], {
             RGBColor[
             0.8208526148202658, 0.8047557768043427, 0.6254794533495226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 448}], {
             RGBColor[
             0.88883448485202, 0.8578980355011018, 0.6322461472964704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 455}], {
             RGBColor[
             0.8626928878488475, 0.3737895921602789, 0.20327715629423396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 475}], {
             RGBColor[
             0.9478498229277461, 0.9047861002729332, 0.6320100649755263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 478}], {
             RGBColor[
             0.7350898192819142, 0.7358328905411176, 0.6182471001773744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 482}], {
             RGBColor[
             0.9448470078274355, 0.90254660568778, 0.6370930476807435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 63}], {
             RGBColor[
             0.27895516343135685`, 0.4105299419182229, 0.939197455929009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 85}], {
             RGBColor[
             0.23686771917621463`, 0.36629336950797753`, 0.9368006382414729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 146}], {
             RGBColor[
             0.22136813052518187`, 0.35000231910506174`, 0.935917959597383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 159}], {
             RGBColor[
             0.3390979651454099, 0.46352019337297634`, 0.9429968372905502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 166}], {
             RGBColor[
             0.25498529523312863`, 0.38533609066446306`, 0.9378324073953621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 239}], {
             RGBColor[
             0.25705844491916985`, 0.3875151024297744, 0.9379504702030321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 344}], {
             RGBColor[
             0.2433422473968615, 0.3730985091766764, 0.9371693530454325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 387}], {
             RGBColor[
             0.24035919758229748`, 0.3699631346852874, 0.9369994727715198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 435}], {
             RGBColor[
             0.3541661224083213, 0.47657147384650533`, 0.9439569669470946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 439}], {
             RGBColor[
             0.2626279467019643, 0.3933690019303001, 0.9382676450902228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 453}], {
             RGBColor[
             0.3583771413920187, 0.4800949272439934, 0.9442595287061802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 68}], {
             RGBColor[
             0.22494283452702457`, 0.3537595596603228, 0.9361215337019873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 95}], {
             RGBColor[
             0.2233343412505307, 0.35206893124236366`, 0.9360299323894435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 286}], {
             RGBColor[
             0.229182169797179, 0.3582153698186358, 0.9363629575740882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 319}], {
             RGBColor[
             0.21511171431873558`, 0.34342642899238807`, 0.9355616659499643]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 330}], {
             RGBColor[
             0.23388775769536924`, 0.36316124105113845`, 0.9366309338435965]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 333}], {
             RGBColor[
             0.3303539220460226, 0.4544751187704825, 0.9424935506353687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 352}], {
             RGBColor[
             0.22055895151159555`, 0.3491518206568699, 0.9358718780496325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 357}], {
             RGBColor[
             0.23165569271724953`, 0.3608151992380412, 0.9365038210451369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 358}], {
             RGBColor[
             0.3137918107660683, 0.4401298504157032, 0.94143822754991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 367}], {
             RGBColor[
             0.2501892935368386, 0.3802951887975917, 0.9375592821938071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 368}], {
             RGBColor[
             0.21159898242802877`, 0.3397343250551897, 0.9353616210654097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 375}], {
             RGBColor[
             0.26223546161822137`, 0.3929564752222947, 0.9382452936453332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 441}], {
             RGBColor[
             0.3055997605504103, 0.43303430826331607`, 0.9409162373541138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 450}], {
             RGBColor[
             0.29135013033172863`, 0.4206919947751334, 0.9400082635170326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 492}], {
             RGBColor[
             0.21887186017874036`, 0.3473785806982704, 0.9357758006940542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 102}], {
             RGBColor[
             0.3305278013611218, 0.45687607566175037`, 0.9424222336843717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 168}], {
             RGBColor[
             0.5869322775232643, 0.6718097968709896, 0.962514131755837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 181}], {
             RGBColor[
             0.3907137841542735, 0.512838374813811, 0.9461169147250448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.46358589832160735`, 0.5737817600479446, 0.9513611588765089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 232}], {
             RGBColor[
             0.5449308949826625, 0.6389979976079412, 0.9583278264694257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 280}], {
             RGBColor[
             0.46829572790906493`, 0.5776054118824476, 0.9517319339143078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 302}], {
             RGBColor[
             0.44096969519954776`, 0.5554209075051166, 0.9495807285208586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 370}], {
             RGBColor[
             0.3984907491896946, 0.5195743910458647, 0.9466124560602016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 383}], {
             RGBColor[
             0.5131465195328626, 0.6140173050277837, 0.9552627525247963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 390}], {
             RGBColor[
             0.4759482746338757, 0.5838180940569503, 0.9523343704246872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 443}], {
             RGBColor[
             0.5725638986959316, 0.6605851101273537, 0.9610820260344628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 451}], {
             RGBColor[
             0.3426842136829911, 0.46965323577309337`, 0.9431145233823018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 480}], {
             RGBColor[
             0.4365798694030919, 0.5518570491641553, 0.9492351453536998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 25}], {
             RGBColor[
             0.8725548505464009, 0.8998336579439141, 0.9166173714965022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 164}], {
             RGBColor[
             0.9340834784629356, 0.9483907377638316, 0.9226198202751702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 180}], {
             RGBColor[
             0.7955000612132693, 0.8390425461583731, 0.9093442969764326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 205}], {
             RGBColor[
             0.7162818128753168, 0.7745053780529972, 0.9031699004171979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 259}], {
             RGBColor[
             0.8740472245688059, 0.4191181540612454, 0.3950653321159444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 316}], {
             RGBColor[
             0.9867175484992736, 0.9766529954342503, 0.6283033308879433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 331}], {
             RGBColor[
             0.9074990918503562, 0.9271930694929118, 0.9200841777479003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 348}], {
             RGBColor[
             0.9751195085877224, 0.9375300834633149, 0.5832471359376257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 372}], {
             RGBColor[
             0.8740472245688059, 0.4191181540612454, 0.3950653321159444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 404}], {
             RGBColor[
             0.8740472245688059, 0.4191181540612454, 0.3950653321159444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 418}], {
             RGBColor[
             0.9680252917800689, 0.9114065680096394, 0.5671089180690637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 431}], {
             RGBColor[
             0.9904763275659175, 0.9887484103996551, 0.6925501182919337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 444}], {
             RGBColor[
             0.8965218183778059, 0.5918677305070236, 0.41658702852886603`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 40}], {
             RGBColor[
             0.22456517753702926`, 0.3533626182190016, 0.9361000266951005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 161}], {
             RGBColor[
             0.2878546124844855, 0.4177612959984998, 0.9397819826492559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 188}], {
             RGBColor[
             0.3121421207816605, 0.43879791495985154`, 0.9413295612013517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 202}], {
             RGBColor[
             0.2283373813057901, 0.35732744355150203`, 0.936314848119256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 243}], {
             RGBColor[
             0.249485287780747, 0.37955523411139636`, 0.9375191901074809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 273}], {
             RGBColor[
             0.22919575579368628`, 0.35822964956236686`, 0.9363637312764905]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 279}], {
             RGBColor[
             0.2740454754738125, 0.40536954858264795`, 0.9389178564630594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 283}], {
             RGBColor[
             0.21876873065664665`, 0.34727018503176055`, 0.9357699276203375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 285}], {
             RGBColor[
             0.28914299431124585`, 0.4188772275808861, 0.9398640771999859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 318}], {
             RGBColor[
             0.2525038287839251, 0.3827279120922901, 0.9376910915520806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 335}], {
             RGBColor[
             0.27951857139159386`, 0.4105410361854448, 0.9392508174820886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 396}], {
             RGBColor[
             0.25133562707487567`, 0.38150005802781284`, 0.9376245641929499]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 421}], {
             RGBColor[
             0.22311781120305674`, 0.35184134443367066`, 0.9360176013235675]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 430}], {
             RGBColor[
             0.26020424486877647`, 0.39082153763204774`, 0.9381296188563681]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 459}], {
             RGBColor[
             0.24496381986437168`, 0.3748028846536623, 0.9372616991985556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 477}], {
             RGBColor[
             0.25210090277797115`, 0.38230441131304815`, 0.9376681455121172]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 21}], {
             RGBColor[
             0.680757442248239, 0.7489730331464229, 0.969887983187306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 59}], {
             RGBColor[
             0.5710396459203946, 0.662634735457889, 0.9593734791954514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 77}], {
             RGBColor[
             0.7393999520548098, 0.7956405917835261, 0.9722782472010072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 87}], {
             RGBColor[
             0.6969015731746537, 0.761845924926386, 0.9714278248071031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 161}], {
             RGBColor[
             0.4356106212508812, 0.5493852197341049, 0.9496243993260349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 188}], {
             RGBColor[
             0.4598981295480561, 0.5704218386954567, 0.9511719778781306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 228}], {
             RGBColor[
             0.5560506747276076, 0.6504660133981275, 0.9581934924767446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 243}], {
             RGBColor[
             0.39724129654714263`, 0.5111791578470015, 0.9473616067842598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 256}], {
             RGBColor[
             0.7023889140742479, 0.7662213816098218, 0.9719512122807135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 279}], {
             RGBColor[
             0.4218014842402082, 0.536993472318253, 0.9487602731398381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 285}], {
             RGBColor[
             0.4368990030776415, 0.5505011513164912, 0.9497064938767648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 287}], {
             RGBColor[
             0.68872640512068, 0.7553272678291727, 0.9706480699800565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 298}], {
             RGBColor[
             0.6096447166347696, 0.6934029640170689, 0.9628044481530396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 335}], {
             RGBColor[
             0.4272745801579895, 0.5421649599210498, 0.9490932341588676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 354}], {
             RGBColor[
             0.7007171274519702, 0.7648883443366565, 0.9717917557802591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 409}], {
             RGBColor[
             0.540422450424237, 0.6377783168651694, 0.9569631814115112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 430}], {
             RGBColor[
             0.4079602536351721, 0.5224454613676528, 0.9479720355331471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 477}], {
             RGBColor[
             0.39985691154436676`, 0.5139283350486532, 0.9475105621888961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 80}], {
             RGBColor[
             0.6859318225908408, 0.7505439617444168, 0.951794759405942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 159}], {
             RGBColor[
             0.41659878498905367`, 0.5352586615189268, 0.9477662840890294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 166}], {
             RGBColor[
             0.33248611507677234`, 0.4570745588104135, 0.9426018541938415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 192}], {
             RGBColor[
             0.6420349038642188, 0.7161165631440682, 0.9675369541888443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.34656244604435504`, 0.47186967514827405`, 0.9434034804183797]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 239}], {
             RGBColor[
             0.3345592647628135, 0.4592535705757248, 0.9427199170015113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 251}], {
             RGBColor[
             0.43294174364966176`, 0.5494141108897593, 0.9488076429633725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 272}], {
             RGBColor[
             0.49012417246760553`, 0.5958729134320023, 0.9532994359632572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 435}], {
             RGBColor[
             0.431666942251965, 0.5483099419924558, 0.9487264137455738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 447}], {
             RGBColor[
             0.4204684417421174, 0.5386103637038271, 0.9480128551955316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 453}], {
             RGBColor[
             0.43587796123566236`, 0.5518333953899437, 0.9490289755046595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 454}], {
             RGBColor[
             0.36689237882404113`, 0.4922054708154086, 0.9445990358418439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 489}], {
             RGBColor[
             0.3237403694481549, 0.4478822256424365, 0.9421037969184629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 50}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 82}], {
             RGBColor[
             0.844192723800754, 0.2992353265545987, 0.18832903870459236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 126}], {
             RGBColor[
             0.8563654629268306, 0.3487034608338446, 0.19818596167822736`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 149}], {
             RGBColor[
             0.8300337551067959, 0.23185817939204778`, 0.1763936638495297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 173}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 242}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 249}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 269}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 282}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 323}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 414}], {
             RGBColor[
             0.8759899507757182, 0.41879994377265284`, 0.28134248690904895`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 419}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 449}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 499}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 17}], {
             RGBColor[
             0.8171965358160596, 0.8565952297054558, 0.9114583528675545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 116}], {
             RGBColor[
             0.6656811252095095, 0.7387544214683854, 0.9673125314832324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 143}], {
             RGBColor[
             0.7737686828707752, 0.43259576374804576`, 0.44397690814617397`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 165}], {
             RGBColor[
             0.7458367292928169, 0.8015726905647942, 0.9752485920882636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 185}], {
             RGBColor[
             0.4837779911654755, 0.5881187692744494, 0.9535473316443274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.5070562614150484, 0.6082812369647475, 0.955030602440464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 224}], {
             RGBColor[
             0.4710966513554297, 0.5758880395117242, 0.9527849389967913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 277}], {
             RGBColor[
             0.8139749785046464, 0.8358688222621367, 0.6731005033291653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 313}], {
             RGBColor[
             0.8124335820745439, 0.8535860695269795, 0.9438393627828742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 333}], {
             RGBColor[
             0.5323412755190838, 0.6301818453199022, 0.956641741180513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 358}], {
             RGBColor[
             0.5157791642391296, 0.6158365769651228, 0.9555864180950544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 361}], {
             RGBColor[
             0.5282938438058984, 0.6266761633997737, 0.9563838424107522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 386}], {
             RGBColor[
             0.7452144755917458, 0.8010765223541869, 0.9751892409747631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 441}], {
             RGBColor[
             0.5075871140234716, 0.6087410348127357, 0.9550644278992582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 89}], {
             RGBColor[
             0.9231261051226047, 0.9396618813362796, 0.9219331847920909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.8740328861463312, 0.4191122247550715, 0.39530295688299816`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 116}], {
             RGBColor[
             0.8359452478324436, 0.8712418660281439, 0.9133270492646723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 143}], {
             RGBColor[
             0.8872780979527313, 0.5209207267878847, 0.40798658666713394`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 165}], {
             RGBColor[
             0.916100851915751, 0.9340601351245527, 0.9212631098697036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 176}], {
             RGBColor[
             0.9356274804823903, 0.9496301387073782, 0.9231255771340168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 178}], {
             RGBColor[
             0.9720885828279697, 0.9273697155199401, 0.5719125519494651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 261}], {
             RGBColor[
             0.9569330773756479, 0.9666186433450407, 0.9251577239854265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 277}], {
             RGBColor[
             0.9842391011275806, 0.968356266821895, 0.6191150211106053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 288}], {
             RGBColor[
             0.8740328861463312, 0.4191122247550715, 0.39530295688299816`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 313}], {
             RGBColor[
             0.9826977046974779, 0.9860735140867379, 0.8898538805643141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 321}], {
             RGBColor[
             0.8740328861463312, 0.4191122247550715, 0.39530295688299816`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 328}], {
             RGBColor[
             0.732255951190426, 0.7877066954338351, 0.9047236192749173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 386}], {
             RGBColor[
             0.91547859821468, 0.9335639669139454, 0.921203758756203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 391}], {
             RGBColor[
             0.970002280405527, 0.9193210457585888, 0.5690733922205091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 407}], {
             RGBColor[
             0.8378626122664915, 0.8727397256965316, 0.9135181542326689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 455}], {
             RGBColor[
             0.8740328861463312, 0.4191122247550715, 0.39530295688299816`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 498}], {
             RGBColor[
             0.8740328861463312, 0.4191122247550715, 0.39530295688299816`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 28}], {
             RGBColor[
             0.8517541692906616, 0.8223523733810587, 0.6271103274009263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 93}], {
             RGBColor[
             0.5639993331847883, 0.6530475914223423, 0.960586802442077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 160}], {
             RGBColor[
             0.6045200328244643, 0.6881026838156832, 0.9631803229645852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 167}], {
             RGBColor[
             0.6058193984674288, 0.6891575673803969, 0.9632826137877326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 172}], {
             RGBColor[
             0.5660661695896078, 0.6548377812339787, 0.9607184994301604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 201}], {
             RGBColor[
             0.6609818107872878, 0.7339408987400141, 0.9676252009521262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 218}], {
             RGBColor[
             0.7469981175976064, 0.8022798739539989, 0.975417449333979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 235}], {
             RGBColor[
             0.5507776223875409, 0.6415956100722736, 0.9597443267215762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 274}], {
             RGBColor[
             0.6190583277740055, 0.6999055265984445, 0.9643248307985424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 300}], {
             RGBColor[
             0.5861445158721873, 0.672228635616922, 0.9619978739007018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 305}], {
             RGBColor[
             0.8079904168689416, 0.8502655206247263, 0.9814068971986999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 310}], {
             RGBColor[
             0.7962722946032341, 0.358714514364911, 0.4348563870006418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 406}], {
             RGBColor[
             0.8740105754900596, 0.8985635500757864, 0.7736400637514464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 432}], {
             RGBColor[
             0.7627827717291649, 0.8146109657293871, 0.9769907161418333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 460}], {
             RGBColor[
             0.7893755098548014, 0.8354224990598411, 0.9796313907499675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 493}], {
             RGBColor[
             0.6718112756182114, 0.7427327461515889, 0.9684777360932533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 26}], {
             RGBColor[
             0.2440972272221243, 0.3738920408415133, 0.9372123480295886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 59}], {
             RGBColor[
             0.44306018409949816`, 0.5517972164675021, 0.9506573076104392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 67}], {
             RGBColor[
             0.23543376871002816`, 0.36478619665030476`, 0.9367189768837632]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 124}], {
             RGBColor[
             0.24511713728705276`, 0.3749640309857861, 0.9372704303989646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 188}], {
             RGBColor[
             0.3319186677271597, 0.45958431970506974`, 0.9424558062931185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 200}], {
             RGBColor[
             0.44299594892189786`, 0.5517450674565645, 0.9506522507819574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 228}], {
             RGBColor[
             0.42807121290671124`, 0.5396284944077405, 0.9494773208917324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 298}], {
             RGBColor[
             0.4816652548138733, 0.582565445026682, 0.9540882765680275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 318}], {
             RGBColor[
             0.2722803757294244, 0.4035143168375083, 0.9388173366438475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 335}], {
             RGBColor[
             0.29929511833709316`, 0.431327440930663, 0.9403770625738554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 459}], {
             RGBColor[
             0.26474036680987095`, 0.3955892893988805, 0.9383879442903225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 468}], {
             RGBColor[
             0.32598193572834094`, 0.4544422208365192, 0.9420775229797997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 25}], {
             RGBColor[
             0.6134743869641546, 0.6953197324267161, 0.9639211366967662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 46}], {
             RGBColor[
             0.3775120116687234, 0.49883606233675915`, 0.9454740124415332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 150}], {
             RGBColor[
             0.40414439209252373`, 0.5240361829288928, 0.9470929232210681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 220}], {
             RGBColor[
             0.40815671966871825`, 0.5275114594099448, 0.9473485851862612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 325}], {
             RGBColor[
             0.44797720589084944`, 0.562001963139723, 0.949885911356462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 388}], {
             RGBColor[
             0.6968315144564416, 0.7612822652895019, 0.972005607251501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 392}], {
             RGBColor[
             0.4556885448241814, 0.5686811373406109, 0.9503772710544247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 413}], {
             RGBColor[
             0.4400008523109076, 0.555093246571965, 0.9493776651595607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 473}], {
             RGBColor[
             0.5378272732791293, 0.6356714351473729, 0.9567588795602012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 474}], {
             RGBColor[
             0.4380905408797232, 0.5534386308253174, 0.9492559418043877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 490}], {
             RGBColor[
             0.40560130196472277`, 0.5252980850337723, 0.9471857562298298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 55}], {
             RGBColor[
             0.8365288820965593, 0.5120560542024203, 0.4540089567270905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 59}], {
             RGBColor[
             0.7122788416336581, 0.774563525190366, 0.9723694632136166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 77}], {
             RGBColor[
             0.8806391477680734, 0.9075693815160031, 0.9852742312191726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[
             0.8381407688879172, 0.873774714658863, 0.9844238088252685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 91}], {
             RGBColor[
             0.89309711802987, 0.8758970279199172, 0.6491494129218777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 188}], {
             RGBColor[
             0.6011373252613197, 0.6823506284279337, 0.9641679618962959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 200}], {
             RGBColor[
             0.7122146064560578, 0.7745113761794283, 0.9723644063851347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 228}], {
             RGBColor[
             0.6972898704408712, 0.7623948031306045, 0.9711894764949098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 256}], {
             RGBColor[
             0.8436281097875116, 0.8781501713422988, 0.9849471962988788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 287}], {
             RGBColor[
             0.8299656008339436, 0.8672560575616497, 0.9836440539982219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 298}], {
             RGBColor[
             0.7508839123480333, 0.8053317537495459, 0.9758004321712048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 335}], {
             RGBColor[
             0.5685137758712531, 0.6540937496535268, 0.9620892181770329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 336}], {
             RGBColor[
             0.8188782126538342, 0.37638527429296664`, 0.43710665573515706`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 354}], {
             RGBColor[
             0.8419563231652338, 0.8768171340691335, 0.9847877397984244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 409}], {
             RGBColor[
             0.6816616461375005, 0.7497071065976464, 0.9699591654296765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 24}], {
             RGBColor[
             0.1988170752865331, 0.32629973022975733`, 0.9346337103628386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 52}], {
             RGBColor[
             0.18741101862312, 0.3143112414907485, 0.933984152309606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 170}], {
             RGBColor[
             0.20408136056054266`, 0.3318328278277056, 0.9349335036213813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 214}], {
             RGBColor[
             0.2036724125219917, 0.3314029975103854, 0.9349102146355702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 268}], {
             RGBColor[
             0.20099391902560468`, 0.32858773101938626`, 0.934757678393427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 466}], {
             RGBColor[
             0.21948326963951018`, 0.34802121080713827`, 0.9358106195583459]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 491}], {
             RGBColor[
             0.19092580831177908`, 0.31800550830406665`, 0.9341843143827098]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 39}], {
             RGBColor[
             0.7492481098657082, 0.7981399836975582, 0.6930866813159002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 51}], {
             RGBColor[
             0.8757337238850049, 0.41825190036192983`, 0.2534537711039848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 62}], {
             RGBColor[
             0.7605455492253483, 0.8073117539135573, 0.693976057126175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 96}], {
             RGBColor[
             0.9739330346591857, 0.9234998076435308, 0.35740958973864884`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 110}], {
             RGBColor[
             0.993178965010662, 0.9878188208072598, 0.4989506198380761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 136}], {
             RGBColor[
             0.9410230313708325, 0.7887755730421966, 0.3307097337117372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 157}], {
             RGBColor[
             0.9051450162162533, 0.9220177033851362, 0.7071961713842101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 240}], {
             RGBColor[
             0.8757337238850049, 0.41825190036192983`, 0.2534537711039848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 360}], {
             RGBColor[
             0.8792976493045557, 0.4456457928586737, 0.2568665901106246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 52}], {
             RGBColor[
             0.19493298804641856`, 0.32221730827504236`, 0.9344125173405062]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 64}], {
             RGBColor[
             0.20529474346718407`, 0.33310817019550554`, 0.9350026039828754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.2136963850560424, 0.34193882820023935`, 0.9354810650422459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 115}], {
             RGBColor[
             0.2186064221312832, 0.3470995884806487, 0.935760684389932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 170}], {
             RGBColor[
             0.2116033299838412, 0.33973889461199946`, 0.9353618686522815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 223}], {
             RGBColor[
             0.255646740576453, 0.38603131165835397`, 0.9378700757291438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 268}], {
             RGBColor[
             0.20851588844890323`, 0.3364937978036801, 0.9351860434243273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 491}], {
             RGBColor[
             0.19844777773507763`, 0.3259115750883605, 0.93461267941361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 164}], {
             RGBColor[
             0.8191346553029186, 0.8591239335240097, 0.9824771954238392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.6805512380532523, 0.7497757419185513, 0.9692016721251016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 220}], {
             RGBColor[
             0.5522883600909476, 0.6427585806873211, 0.9599021951346662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 316}], {
             RGBColor[
             0.8717687253392568, 0.8873861911944285, 0.6881607060366124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 325}], {
             RGBColor[
             0.5921088463130788, 0.6772490844170992, 0.9624395213048671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 392}], {
             RGBColor[
             0.5998201852464107, 0.6839282586179871, 0.9629308810028296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 413}], {
             RGBColor[
             0.5841324927331369, 0.6703403678493413, 0.9619312751079657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 474}], {
             RGBColor[
             0.5822221813019526, 0.6686857521026937, 0.9618095517527927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 490}], {
             RGBColor[
             0.5497329423869521, 0.6405452063111485, 0.9597393661782347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 67}], {
             RGBColor[
             0.1959716730389698, 0.32330903205864586`, 0.9344716689142352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 124}], {
             RGBColor[
             0.2056550416159944, 0.33348686639412717`, 0.9350231224294367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 318}], {
             RGBColor[
             0.23281828005836602`, 0.3620371522458494, 0.9365700286743196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 335}], {
             RGBColor[
             0.2598330226660348, 0.3898502763390041, 0.9381297546043277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 459}], {
             RGBColor[
             0.2252782711388126, 0.3541121248072216, 0.9361406363207947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 29}], {
             RGBColor[
             0.20431304380785625`, 0.33207634161019856`, 0.9349466976395711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 65}], {
             RGBColor[
             0.20162066097000025`, 0.3292464765406804, 0.9347933704199787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 86}], {
             RGBColor[
             0.20621369612965204`, 0.3340740477087234, 0.9350549369775343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 177}], {
             RGBColor[
             0.20421188606161866`, 0.3319700184051313, 0.9349409368555723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[
             0.20792633813700911`, 0.33587414304623064`, 0.9351524694062264]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 290}], {
             RGBColor[
             0.19806122117282127`, 0.32550527963232745`, 0.9345906655892486]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 297}], {
             RGBColor[
             0.2276449517133472, 0.3565996561472727, 0.9362754152783243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 350}], {
             RGBColor[
             0.19805630037094138`, 0.32550010755755476`, 0.9345903853568613]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 412}], {
             RGBColor[
             0.21686143319747594`, 0.34526549447252863`, 0.9356613098516314]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 484}], {
             RGBColor[
             0.20513686464962994`, 0.3329422295481609, 0.9349936130177764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 490}], {
             RGBColor[
             0.27392877216704353`, 0.40218528363986605`, 0.9390233106427064]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 125}], {
             RGBColor[
             0.8613224849238736, 0.3683564012224616, 0.2021744979333091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 149}], {
             RGBColor[
             0.8867519951374654, 0.5638187600065572, 0.2265258256323685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 201}], {
             RGBColor[
             0.7585570962682471, 0.7484037290263401, 0.6186023673511272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 218}], {
             RGBColor[
             0.8445734030785657, 0.8167427042403248, 0.62639461573298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 282}], {
             RGBColor[
             0.8613224849238736, 0.3683564012224616, 0.2021744979333091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 305}], {
             RGBColor[
             0.905565702349901, 0.8647283509110522, 0.6323840635977009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 310}], {
             RGBColor[
             0.8613224849238736, 0.3683564012224616, 0.2021744979333091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 406}], {
             RGBColor[
             0.971585860971019, 0.9130263803621124, 0.4246172301504474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 408}], {
             RGBColor[
             0.8613224849238736, 0.3683564012224616, 0.2021744979333091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 419}], {
             RGBColor[
             0.8613224849238736, 0.3683564012224616, 0.2021744979333091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 432}], {
             RGBColor[
             0.8603580572101241, 0.8290737960157131, 0.6279678825408344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 493}], {
             RGBColor[
             0.7693865610991708, 0.7571955764379148, 0.6194549024922544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 46}], {
             RGBColor[
             0.24415483873233365`, 0.37395259419152405`, 0.9372156289198665]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 65}], {
             RGBColor[
             0.19993601783128978`, 0.32747580978935154`, 0.9346974324854354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 86}], {
             RGBColor[
             0.2045290529909416, 0.33230338095739453`, 0.934958999042991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 177}], {
             RGBColor[
             0.20252724292290822`, 0.33019935165380243`, 0.934844998921029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 194}], {
             RGBColor[
             0.20624169499829867`, 0.3341034762949018, 0.935056531471683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 254}], {
             RGBColor[
             0.219858689201137, 0.34841580056938304`, 0.935831999146997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 290}], {
             RGBColor[
             0.1963765780341108, 0.3237346128809986, 0.9344947276547053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 297}], {
             RGBColor[
             0.22596030857463673`, 0.3548289893959438, 0.9361794773437808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 350}], {
             RGBColor[
             0.19637165723223093`, 0.3237294408062259, 0.9344944474223179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 377}], {
             RGBColor[
             0.19479365087519235`, 0.32207085607359665`, 0.9344045822947358]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 412}], {
             RGBColor[
             0.2151767900587655, 0.34349482772119977`, 0.935565371917088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 426}], {
             RGBColor[
             0.20893369054247232`, 0.33693293429420396`, 0.9352098366354733]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 476}], {
             RGBColor[
             0.20047610231188778`, 0.3280434728217939, 0.934728189497622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 31}], {
             RGBColor[
             0.20705706276398889`, 0.3349604795139445, 0.9351029654597106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 133}], {
             RGBColor[
             0.21997865236817787`, 0.3485418894640472, 0.9358388308718903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 191}], {
             RGBColor[
             0.20407545440505548`, 0.3318266200838168, 0.9349331672745637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 311}], {
             RGBColor[
             0.20275732105733557`, 0.3304411783608819, 0.9348581015304145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 366}], {
             RGBColor[
             0.1867597729131777, 0.31362674095823617`, 0.9339470648298565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 405}], {
             RGBColor[
             0.18482655001024287`, 0.3115948011138402, 0.9338369706454812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 423}], {
             RGBColor[
             0.17952980953436626`, 0.3060275910409509, 0.9335353291112054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 429}], {
             RGBColor[
             0.20698840587743583`, 0.3348883167730792, 0.9350990555515901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 465}], {
             RGBColor[
             0.1792054619955512, 0.30568668121283454`, 0.933516857998699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 469}], {
             RGBColor[
             0.18416602893623069`, 0.3109005515855985, 0.9337993549474696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 488}], {
             RGBColor[
             0.18669921182250732`, 0.3135630874121468, 0.9339436159653348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 133}], {
             RGBColor[
             0.2480786626367777, 0.3780767818998994, 0.9374390848864473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 191}], {
             RGBColor[
             0.23217546467365527`, 0.361361512519669, 0.9365334212891205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 226}], {
             RGBColor[
             0.22438551241201804`, 0.35317377878118794`, 0.9360897950320219]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 237}], {
             RGBColor[
             0.3290966057081422, 0.45266487271418654`, 0.9424398430146377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 311}], {
             RGBColor[
             0.2308573313259354, 0.3599760707967341, 0.9364583555449715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 366}], {
             RGBColor[
             0.21485978318177745`, 0.34316163339408845`, 0.9355473188444132]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 405}], {
             RGBColor[
             0.21292656027884266`, 0.3411296935496924, 0.9354372246600381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 429}], {
             RGBColor[
             0.23508841614603562`, 0.36442320920893145`, 0.9366993095661471]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 472}], {
             RGBColor[
             0.21610683850656687`, 0.34447236760831645`, 0.935618336800307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 488}], {
             RGBColor[
             0.2147992220911071, 0.343097979847999, 0.9355438699798917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 66}], {
             RGBColor[
             0.3101036799664407, 0.4385643994191369, 0.9411435766218114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 84}], {
             RGBColor[
             0.5191908481230056, 0.617440223102824, 0.9563757768952883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 89}], {
             RGBColor[
             0.6092109643121336, 0.6880782890419994, 0.965264903215373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 176}], {
             RGBColor[
             0.6217123396719191, 0.698046546413098, 0.9664572955572988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 179}], {
             RGBColor[
             0.31490599852677015`, 0.44361194071062604`, 0.9414170615594284]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 245}], {
             RGBColor[
             0.4212849020662287, 0.5385132494002911, 0.9482871073803061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 255}], {
             RGBColor[
             0.3085704354238704, 0.43695286219157675`, 0.941056260613344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 260}], {
             RGBColor[
             0.3358333242416319, 0.46530367880959933`, 0.9426199803482964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 299}], {
             RGBColor[
             0.4092045959302848, 0.5287059126675422, 0.9473361014296651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 312}], {
             RGBColor[
             0.3038288820776412, 0.431969188992844, 0.9407862361647759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 328}], {
             RGBColor[
             0.41834081037995485`, 0.5361231031395549, 0.9480553376981994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 334}], {
             RGBColor[
             0.2863539875937741, 0.413601966917996, 0.9397910667757092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 407}], {
             RGBColor[
             0.5239474714560204, 0.6211561334022514, 0.9568498726559509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 448}], {
             RGBColor[
             0.5919293414877744, 0.6742983920990104, 0.9636165666028987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 475}], {
             RGBColor[
             0.6509446795635007, 0.7211864568708418, 0.9633804842819546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 478}], {
             RGBColor[
             0.43818467591766874`, 0.5522332471390261, 0.9496175194838028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 482}], {
             RGBColor[
             0.64794186446319, 0.7189469622856886, 0.9684634669871719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 76}], {
             RGBColor[
             0.7773631602461192, 0.8221474687086947, 0.7922109863395075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 111}], {
             RGBColor[
             0.7724584371268222, 0.8209274086540813, 0.9322402963389583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 160}], {
             RGBColor[
             0.507621153600386, 0.6111487464219849, 0.9543809431704284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 175}], {
             RGBColor[
             0.7775942134782825, 0.823051184158842, 0.8471271912321169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 182}], {
             RGBColor[
             0.75743790360309, 0.8097822285259801, 0.9602236073747921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 237}], {
             RGBColor[
             0.49170863187262065`, 0.5974080208929563, 0.9533554339843097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 241}], {
             RGBColor[
             0.45030985755818603`, 0.5615504833446909, 0.9507175406924926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 274}], {
             RGBColor[
             0.5221594485499271, 0.6229515892047461, 0.9555254510043854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 351}], {
             RGBColor[
             0.5099468577737633, 0.6130368578417116, 0.9545640311222917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 371}], {
             RGBColor[
             0.5535152767239239, 0.6484076630803585, 0.9579938966584256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 432}], {
             RGBColor[
             0.6658838925050865, 0.7376570283356887, 0.9681913363476764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 460}], {
             RGBColor[
             0.6924766306307231, 0.7584685616661428, 0.9708320109558106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 463}], {
             RGBColor[
             0.7610323559034178, 0.5268877243816464, 0.4568621548257559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 44}], {
             RGBColor[
             0.5037551933062931, 0.6031416247429248, 0.9557644930809137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 62}], {
             RGBColor[
             0.4183440898877315, 0.5346740747422846, 0.9484437217570646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 190}], {
             RGBColor[
             0.32639172231009544`, 0.4570716814510417, 0.9420203527500528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 291}], {
             RGBColor[
             0.25248695241717767`, 0.3827101739608151, 0.9376901304679608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 356}], {
             RGBColor[
             0.3999124124412533, 0.519710408653627, 0.9469927125910187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 394}], {
             RGBColor[
             0.2532945186751018, 0.38355897730055144`, 0.9377361201716623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 467}], {
             RGBColor[
             0.26986184992211565`, 0.40097229287063396`, 0.9386796051770095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.19771231040963783`, 0.3251385522980016, 0.9345707956374525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 123}], {
             RGBColor[
             0.21261512288870693`, 0.34080235310638873`, 0.9354194887614002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 193}], {
             RGBColor[
             0.20201306311706924`, 0.32965891607698306`, 0.9348157171417473]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 347}], {
             RGBColor[
             0.2497247180796972, 0.37980689053635075`, 0.9375328253088007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 410}], {
             RGBColor[
             0.2048653084706884, 0.3326568067864372, 0.934978148295117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 422}], {
             RGBColor[
             0.25718407515887753`, 0.3876471477771245, 0.9379576246593302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 428}], {
             RGBColor[
             0.216766629209909, 0.3451658494706758, 0.9356559109047894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 437}], {
             RGBColor[
             0.20415760851311143`, 0.3319129692602549, 0.9349378458294813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 75}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 76}], {
             RGBColor[
             0.8763277317102309, 0.4195224230366844, 0.31810785708846784`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 104}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 112}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 266}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 359}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 379}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 408}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 440}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 463}], {
             RGBColor[
             0.831998657058118, 0.24386491747293382`, 0.17815401051060936`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 49}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 53}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 97}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 100}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 203}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 207}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 257}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 264}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 281}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 317}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 322}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 324}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 343}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 374}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 397}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 445}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 77}], {
             RGBColor[
             0.9192907829722123, 0.7949315839058828, 0.6126751046012756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 79}], {
             RGBColor[
             0.8446459694565934, 0.30129340921955317`, 0.18870723798989242`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 87}], {
             RGBColor[
             0.8767924040920562, 0.7611369170487428, 0.6118246822073715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 127}], {
             RGBColor[
             0.8446459694565934, 0.30129340921955317`, 0.18870723798989242`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 184}], {
             RGBColor[
             0.8878066027772542, 0.5834378112927188, 0.2280954180565736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 221}], {
             RGBColor[
             0.8446459694565934, 0.30129340921955317`, 0.18870723798989242`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 253}], {
             RGBColor[
             0.9437188064028268, 0.8124944389214359, 0.5419690901557521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 287}], {
             RGBColor[
             0.8686172360380824, 0.7546182599515294, 0.6110449273803248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 301}], {
             RGBColor[
             0.8446459694565934, 0.30129340921955317`, 0.18870723798989242`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 316}], {
             RGBColor[
             0.942615665830955, 0.799915878171712, 0.3187661896988654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 336}], {
             RGBColor[
             0.8446459694565934, 0.30129340921955317`, 0.18870723798989242`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 354}], {
             RGBColor[
             0.8806079583693727, 0.7641793364590133, 0.6121886131805274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 388}], {
             RGBColor[
             0.9118100953703692, 0.7890590735441616, 0.615164700862159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 436}], {
             RGBColor[
             0.9344998640366943, 0.8062744916611889, 0.5869300975227473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 473}], {
             RGBColor[
             0.7528058541930568, 0.6634482434020327, 0.5999179731708593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 62}], {
             RGBColor[
             0.5172304874360417, 0.6189500365253262, 0.9551374251301208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 96}], {
             RGBColor[
             0.7306179728698792, 0.7351380902552997, 0.6185709577425946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 108}], {
             RGBColor[
             0.4086556507016406, 0.5269500959200856, 0.9476548870871122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 113}], {
             RGBColor[
             0.3807447522810758, 0.4978573418320051, 0.9460564917517937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 157}], {
             RGBColor[
             0.6618299544269467, 0.7336559859969052, 0.9683575393881558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 190}], {
             RGBColor[
             0.4252781198584057, 0.5413476432340834, 0.948714056123109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 378}], {
             RGBColor[
             0.4028150168001186, 0.5210545891771114, 0.9473133606661228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 161}], {
             RGBColor[
             0.2684135610193307, 0.39732751827476565`, 0.9386748435287737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 183}], {
             RGBColor[
             0.23087447888683538`, 0.35999409397045823`, 0.9364593320731971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 202}], {
             RGBColor[
             0.20889632984063528`, 0.3368936658277679, 0.9352077089987738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 206}], {
             RGBColor[
             0.19522868075367328`, 0.3225281000583675, 0.9344293566027462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 243}], {
             RGBColor[
             0.23004423631559218`, 0.35912145638766224`, 0.9364120509869986]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 273}], {
             RGBColor[
             0.20975470432853144`, 0.3377958718386327, 0.9352565921560083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 283}], {
             RGBColor[
             0.1993276791914918, 0.3268364073080263, 0.9346627884998552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 285}], {
             RGBColor[
             0.269701942846091, 0.39844344985715197`, 0.9387569380795036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 396}], {
             RGBColor[
             0.23189457560972082`, 0.36106628030407867`, 0.9365174250724676]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 421}], {
             RGBColor[
             0.20367675973790192`, 0.33140756670993643`, 0.9349104622030852]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 430}], {
             RGBColor[
             0.24076319340362162`, 0.37038775990831363`, 0.9370224797358859]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 477}], {
             RGBColor[
             0.2326598513128163, 0.36187063358931404`, 0.936561006391635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 44}], {
             RGBColor[
             0.6512432193483967, 0.7268745780156403, 0.9662842946826327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 56}], {
             RGBColor[
             0.7988889921505462, 0.8398198339616005, 0.8100291411688312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.6304047842681767, 0.7105954341529999, 0.964207314220084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 132}], {
             RGBColor[
             0.6315111194145004, 0.7114597115777666, 0.9643175833681797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.4813094096913133, 0.5872398339500613, 0.9530135658025085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 356}], {
             RGBColor[
             0.5474004384833568, 0.6434433619263427, 0.9575125141927376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 365}], {
             RGBColor[
             0.4515879807590536, 0.5606916651039451, 0.9511492161960573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 457}], {
             RGBColor[
             0.7799506296404679, 0.7772562145851217, 0.6242203432368331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 485}], {
             RGBColor[
             0.5788529501858339, 0.6689779278459186, 0.9599885711283033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 494}], {
             RGBColor[
             0.7862603193212523, 0.8326898579584304, 0.949304381285405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 108}], {
             RGBColor[
             0.29172348972761986`, 0.4237068926091371, 0.9399335041832765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 113}], {
             RGBColor[
             0.26381259130705503`, 0.39461413852105653`, 0.938335108847958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 119}], {
             RGBColor[
             0.23711084694980825`, 0.3665489122132156, 0.9368144840085036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 315}], {
             RGBColor[
             0.2351529722129052, 0.36449106172830237`, 0.9367029859386531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 364}], {
             RGBColor[
             0.2803428770185711, 0.4119885168845083, 0.9392764841648626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 378}], {
             RGBColor[
             0.28588285582609785`, 0.41781138586616284`, 0.939591977762287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 380}], {
             RGBColor[
             0.2438951722116548, 0.3736796682144823, 0.9372008412956561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 381}], {
             RGBColor[
             0.2456829942137933, 0.3755587824931918, 0.9373026551138322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 416}], {
             RGBColor[
             0.2908008659889437, 0.42290776229911325`, 0.9398747154144922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 452}], {
             RGBColor[
             0.3329650931678352, 0.45942829664579143`, 0.942561382685969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 468}], {
             RGBColor[
             0.3202366373459297, 0.4484035479636482, 0.9417503367363287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 487}], {
             RGBColor[
             0.2552478049273309, 0.38561200499714565`, 0.9378473569340987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[
             0.4999309487768256, 0.6034943400182612, 0.9541654474925418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 137}], {
             RGBColor[
             0.36126042666261593`, 0.4873273569233284, 0.9442401728302576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 148}], {
             RGBColor[
             0.5374554379217633, 0.6334803821671271, 0.957446343497947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 156}], {
             RGBColor[
             0.33421927844066934`, 0.460054494124931, 0.9426581453180694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 227}], {
             RGBColor[
             0.3207886255080345, 0.4459380263401525, 0.9418932895024263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 229}], {
             RGBColor[
             0.416869736584196, 0.535493346172216, 0.9477835488850788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 250}], {
             RGBColor[
             0.3804144405970011, 0.5039176010845604, 0.9454606496609272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 263}], {
             RGBColor[
             0.3916792939201136, 0.5136746508450498, 0.9461784361535572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 267}], {
             RGBColor[
             0.40347694898297903`, 0.5238931866931191, 0.9469301723019063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 393}], {
             RGBColor[
             0.3844301868161192, 0.5073958386222868, 0.9457165294590244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 485}], {
             RGBColor[
             0.4779579810915217, 0.5856556949804177, 0.9524356549867219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 56}], {
             RGBColor[
             0.8469959064349548, 0.8780021626885659, 0.8144131900742924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 62}], {
             RGBColor[
             0.6139390302142435, 0.6965893567419654, 0.9633475722642448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 92}], {
             RGBColor[
             0.6785116985525852, 0.7487777628799652, 0.9685913631255452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 110}], {
             RGBColor[
             0.8465724459995572, 0.877096423635668, 0.7683221349761459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 132}], {
             RGBColor[
             0.6796180336989088, 0.7496420403047319, 0.968701632273641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 157}], {
             RGBColor[
             0.7585384972051484, 0.8112953062135444, 0.9765676865222799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 356}], {
             RGBColor[
             0.5955073527677653, 0.681625690653308, 0.9618965630981988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 360}], {
             RGBColor[
             0.7815599699638192, 0.37183086141094573`, 0.43644760020267126`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 365}], {
             RGBColor[
             0.4996948950434621, 0.5988739938309104, 0.9555332651015185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 457}], {
             RGBColor[
             0.8280575439248763, 0.8154385433120871, 0.6286043921422944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 494}], {
             RGBColor[
             0.8343672336056607, 0.8708721866853958, 0.9536884301908661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 118}], {
             RGBColor[
             0.2554591373040128, 0.3858341287242849, 0.9378593920003125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 152}], {
             RGBColor[
             0.23828164417604697`, 0.36777949433082413`, 0.9368811591784987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 185}], {
             RGBColor[
             0.2976969078072994, 0.42913054113154847`, 0.9403049796510078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 187}], {
             RGBColor[
             0.32097517805687237`, 0.4492930088218466, 0.9417882504471444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 195}], {
             RGBColor[
             0.2465939110217282, 0.3765162138137928, 0.9373545304784634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 216}], {
             RGBColor[
             0.27205173985217523`, 0.40327400603416763`, 0.9388043161688746]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 217}], {
             RGBColor[
             0.23183546793394733`, 0.36100415438919764`, 0.9365140589777743]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 224}], {
             RGBColor[
             0.2850155679972537, 0.41689981136882326`, 0.9395425870034717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 292}], {
             RGBColor[
             0.24018663766573572`, 0.36978176327205037`, 0.9369896457395511]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 328}], {
             RGBColor[
             0.37591074520931583`, 0.4962310227311757, 0.9454667495001579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 398}], {
             RGBColor[
             0.28571521753888074`, 0.4176351873974164, 0.9395824310098286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 399}], {
             RGBColor[
             0.2892039179868987, 0.4213020327646674, 0.9397811073392734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 464}], {
             RGBColor[
             0.27751991420487765`, 0.40902140398113634`, 0.9391157206088221]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 481}], {
             RGBColor[
             0.2835821880689775, 0.4153932381826685, 0.939460958137052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 496}], {
             RGBColor[
             0.24168419906114047`, 0.37135579524949736`, 0.9370749296455758]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 86}], {
             RGBColor[
             0.24605549105412944`, 0.3759503002900489, 0.9373238682578297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 142}], {
             RGBColor[
             0.31315836829751326`, 0.4435312803958282, 0.9412532331571938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 150}], {
             RGBColor[
             0.31231365721932186`, 0.44279963411631207`, 0.9411994089142401]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 194}], {
             RGBColor[
             0.24776813306148654`, 0.3777503956275562, 0.9374214006865218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 220}], {
             RGBColor[
             0.3163259847955163, 0.44627491059736407`, 0.9414550708794333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 254}], {
             RGBColor[
             0.26138512726432483`, 0.39206271990203745`, 0.9381968683618358]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 297}], {
             RGBColor[
             0.26748674663782457`, 0.39847590872859817`, 0.9385443465586196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 325}], {
             RGBColor[
             0.3561464710176476, 0.48076541432714226`, 0.9439923970496341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 350}], {
             RGBColor[
             0.23789809529541878`, 0.3673763601388803, 0.9368593166371566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 377}], {
             RGBColor[
             0.23632008893838022`, 0.36571777540625106`, 0.9367694515095745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 392}], {
             RGBColor[
             0.3638578099509795, 0.48744458852803013`, 0.9444837567475968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 412}], {
             RGBColor[
             0.25670322812195334`, 0.3871417470538542, 0.9379302411319268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 426}], {
             RGBColor[
             0.2504601286056602, 0.3805798536268583, 0.937574705850312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 476}], {
             RGBColor[
             0.24200254037507565`, 0.3716903921544483, 0.9370930587124607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 55}], {
             RGBColor[
             0.8007526423490732, 0.4840965388666049, 0.45044599340948344`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 59}], {
             RGBColor[
             0.6586144820124289, 0.7326242521866431, 0.967025018237206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 73}], {
             RGBColor[
             0.7986897921704463, 0.4682405684469667, 0.4484706057487744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 91}], {
             RGBColor[
             0.8394327584086407, 0.8339577549161943, 0.643804967945467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 136}], {
             RGBColor[
             0.8020754049028471, 0.684036360935029, 0.600844615682085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 200}], {
             RGBColor[
             0.6585502468348285, 0.7325721031757053, 0.967019961408724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 228}], {
             RGBColor[
             0.643625510819642, 0.7204555301268813, 0.9658450315184992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 256}], {
             RGBColor[
             0.7899637501662823, 0.8362108983385758, 0.9796027513224682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 298}], {
             RGBColor[
             0.697219552726804, 0.7633924807458228, 0.9704559871947942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 416}], {
             RGBColor[
             0.5121004622842857, 0.6097734708911251, 0.95656961228473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 452}], {
             RGBColor[
             0.5542646894631771, 0.6462940052378033, 0.9592562795562067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 468}], {
             RGBColor[
             0.5415362336412717, 0.63526925655566, 0.9584452336065665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 117}], {
             RGBColor[
             0.21251052131884468`, 0.34069241022434094`, 0.9354135318567407]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 140}], {
             RGBColor[
             0.20271183825122668`, 0.33039337304788496`, 0.9348555113518924]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 155}], {
             RGBColor[
             0.23482099816692198`, 0.3641421359576038, 0.936684080507846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 156}], {
             RGBColor[
             0.2466062489720914, 0.37652918178189576`, 0.9373552331064843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 198}], {
             RGBColor[
             0.21002858102618926`, 0.33808373361265665`, 0.9352721890287756]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 250}], {
             RGBColor[
             0.2928014111284232, 0.4203922887415252, 0.9401577374493421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 365}], {
             RGBColor[
             0.2630799821961634, 0.393844119895409, 0.9382933878428907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 479}], {
             RGBColor[
             0.20982732020424238`, 0.33787219572811733`, 0.9352607275227045]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 51}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 100}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 203}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 264}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 324}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 360}], {
             RGBColor[
             0.8191009627097754, 0.1478239462483719, 0.1659244095033199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 397}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 457}], {
             RGBColor[
             0.8638009847389825, 0.3780247266271895, 0.20499214689883155`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 82}], {
             RGBColor[
             0.844192723800754, 0.2992353265545987, 0.18832903870459236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 126}], {
             RGBColor[
             0.8563654629268306, 0.3487034608338446, 0.19818596167822736`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 131}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 173}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 242}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 323}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 340}], {
             RGBColor[
             0.872096562596627, 0.4180301464376909, 0.41479302865073187`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 373}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 414}], {
             RGBColor[
             0.8759899507757182, 0.41879994377265284`, 0.28134248690904895`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 449}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 499}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 60}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 96}], {
             RGBColor[
             0.8633136325544521, 0.3762506380670908, 0.20377662205511443`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 100}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 110}], {
             RGBColor[
             0.8761442527887697, 0.4191299801762435, 0.29813730878806594`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 203}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 240}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 264}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 324}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 360}], {
             RGBColor[
             0.8191009627097754, 0.1478239462483719, 0.1659244095033199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 397}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 457}], {
             RGBColor[
             0.8638009847389825, 0.3780247266271895, 0.20499214689883155`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 495}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 170}], {
             RGBColor[
             0.2001972733204281, 0.32775040587299065`, 0.9347123105990489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 214}], {
             RGBColor[
             0.19978832528187718`, 0.3273205755556704, 0.9346890216132377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 268}], {
             RGBColor[
             0.19710983178549013`, 0.32450530906467123`, 0.9345364853710946]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 466}], {
             RGBColor[
             0.21559918239939563`, 0.34393878885242324`, 0.9355894265360134]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 491}], {
             RGBColor[
             0.18704172107166453`, 0.3139230863493516, 0.9339631213603773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 83}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 97}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 112}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 163}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 207}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 257}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 266}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 281}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 317}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 322}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 343}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 374}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 440}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 445}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 471}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 61}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 99}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 154}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 186}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 203}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 244}], {
             RGBColor[
             0.8706168078338911, 0.40101609835768304`, 0.23147033256236077`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 264}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 295}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 321}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 341}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 374}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 391}], {
             RGBColor[
             0.8623939674573535, 0.3726044724173211, 0.20303663793067456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 397}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 455}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 57}], {
             RGBColor[
             0.8349696694427251, 0.26979777990945364`, 0.18112030099193344`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 60}], {
             RGBColor[
             0.8349696694427251, 0.26979777990945364`, 0.18112030099193344`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 73}], {
             RGBColor[
             0.8427635790747743, 0.32970518465436127`, 0.1885837576575456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 91}], {
             RGBColor[
             0.8839292021421377, 0.5220528575630985, 0.23151925387136146`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 136}], {
             RGBColor[
             0.8590242998049419, 0.4221052615756549, 0.20287901902910677`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 200}], {
             RGBColor[
             0.7633408610929295, 0.4544624230694392, 0.44699591618019946`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 256}], {
             RGBColor[
             0.8509498633138987, 0.5235549531780195, 0.45538444278936224`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 298}], {
             RGBColor[
             0.7891203983542464, 0.4750093414495175, 0.4492866000375796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 434}], {
             RGBColor[
             0.8349696694427251, 0.26979777990945364`, 0.18112030099193344`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 92}], {
             RGBColor[
             0.8261574713547348, 0.8617230188259255, 0.8123362096117437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 110}], {
             RGBColor[
             0.9942182188017068, 0.9900416795816283, 0.6120669814623443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 132}], {
             RGBColor[
             0.8272638065010585, 0.8625872962506922, 0.8124464787598393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 324}], {
             RGBColor[
             0.8764265597457015, 0.4197338062115088, 0.3288646788534969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 342}], {
             RGBColor[
             0.9717076565997078, 0.9127794890046514, 0.46789915194522813`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 360}], {
             RGBColor[
             0.8799904851652522, 0.44712769870825264`, 0.3322774978601368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 457}], {
             RGBColor[
             0.9757033167270259, 0.9283837992580474, 0.47234923862849276`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 494}], {
             RGBColor[
             0.9820130064078103, 0.9838174426313561, 0.7974332766770647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 60}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 73}], {
             RGBColor[
             0.8251129096320492, 0.19403440474490768`, 0.17168145666561216`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 91}], {
             RGBColor[
             0.8662785326994125, 0.38638207765364485`, 0.21461695287942803`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 131}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 136}], {
             RGBColor[
             0.8413736303622167, 0.28643448166620133`, 0.18597671803717333`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 234}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 240}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 434}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 495}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 74}], {
             RGBColor[
             0.2306608517696206, 0.3597695583255239, 0.9364471663249048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 115}], {
             RGBColor[
             0.23557088884486138`, 0.36493031860593317`, 0.9367267856725908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 144}], {
             RGBColor[
             0.24826092960193386`, 0.3782683560366715, 0.9374494647204732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 145}], {
             RGBColor[
             0.27446298131762203`, 0.4058083736958911, 0.9389416328032197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 215}], {
             RGBColor[
             0.22259684759220016`, 0.35129377864765965`, 0.9359879332166258]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 375}], {
             RGBColor[
             0.26089059756321387`, 0.3915429378311758, 0.9381687056269487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 402}], {
             RGBColor[
             0.296247822930254, 0.42468544619728427`, 0.9403294456885352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 417}], {
             RGBColor[
             0.2488046847191422, 0.3788398771409232, 0.9374804307699846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 87}], {
             RGBColor[
             0.7284229725600728, 0.7874364169703292, 0.9739093048334139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 91}], {
             RGBColor[
             0.7833793217020255, 0.7895587302313833, 0.6386349089300231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 188}], {
             RGBColor[
             0.4914195289334753, 0.5960123307393997, 0.9536534579044413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 200}], {
             RGBColor[
             0.6024968101282133, 0.6881730784908944, 0.96184990239328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 228}], {
             RGBColor[
             0.5875720741130268, 0.6760565054420705, 0.9606749725030552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 256}], {
             RGBColor[
             0.7339103134596671, 0.7918118736537649, 0.9744326923070242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 279}], {
             RGBColor[
             0.45332288362562734`, 0.5625839643621962, 0.9512417531661489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 287}], {
             RGBColor[
             0.7202478045060992, 0.7809177598731158, 0.9731295500063672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 298}], {
             RGBColor[
             0.6411661160201888, 0.718993456061012, 0.9652859281793502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 335}], {
             RGBColor[
             0.45879597954340867`, 0.567755451964993, 0.9515747141851782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 409}], {
             RGBColor[
             0.5719438498096561, 0.6633688089091125, 0.9594446614378219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 468}], {
             RGBColor[
             0.48548279693465646`, 0.5908702318708492, 0.9532751745911225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 73}], {
             RGBColor[
             0.8251129096320492, 0.19403440474490768`, 0.17168145666561216`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 131}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.8413736303622167, 0.28643448166620133`, 0.18597671803717333`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 240}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 434}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 495}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 99}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 154}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 178}], {
             RGBColor[
             0.8637848357389819, 0.3779702522582219, 0.20492941108331192`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 186}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 203}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 244}], {
             RGBColor[
             0.8706168078338911, 0.40101609835768304`, 0.23147033256236077`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 264}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 288}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 295}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 321}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 341}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 391}], {
             RGBColor[
             0.8623939674573535, 0.3726044724173211, 0.20303663793067456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 397}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 455}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 96}], {
             RGBColor[
             0.7419154122295191, 0.7443098604712988, 0.6194603335528694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 108}], {
             RGBColor[
             0.4199530900612806, 0.5361218661360846, 0.948544262897387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 110}], {
             RGBColor[
             0.7611613425809955, 0.8086288736350278, 0.7610013636522968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 157}], {
             RGBColor[
             0.6731273937865867, 0.7428277562129042, 0.9692469151984306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 190}], {
             RGBColor[
             0.4365755592180457, 0.5505194134500824, 0.9496034319333838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 356}], {
             RGBColor[
             0.5100962493492036, 0.6131581406526678, 0.9545757917743497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 378}], {
             RGBColor[
             0.4141124561597586, 0.5302263593931105, 0.9482027364763976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 72}], {
             RGBColor[
             0.3088117371325335, 0.4410013587250076, 0.940931053493443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 159}], {
             RGBColor[
             0.3591807092964443, 0.4846284307952361, 0.944140519860194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 166}], {
             RGBColor[
             0.275068039384163, 0.4064443280867228, 0.938976089965006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 222}], {
             RGBColor[
             0.27812742646781496`, 0.4096599378879857, 0.9391503175334623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 239}], {
             RGBColor[
             0.2771411890702042, 0.40862333985203414`, 0.9390941527726759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 272}], {
             RGBColor[
             0.4327060967749962, 0.5452426827083117, 0.9496736717344219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 344}], {
             RGBColor[
             0.2634249915478959, 0.3942067465989362, 0.9383130356150764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 387}], {
             RGBColor[
             0.26044194173333185`, 0.39107137210754717`, 0.9381431553411637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 435}], {
             RGBColor[
             0.37424886655935563`, 0.49767971126876503`, 0.9451006495167384]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 439}], {
             RGBColor[
             0.2827106908529987, 0.41447723935255987`, 0.9394113276598666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 453}], {
             RGBColor[
             0.37845988554305304`, 0.5012031646662531, 0.9454032112758242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 74}], {
             RGBColor[
             0.2126520838133948, 0.3408412013816937, 0.9354215936313823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 115}], {
             RGBColor[
             0.21756212088863558`, 0.346001961662103, 0.9357012129790685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 170}], {
             RGBColor[
             0.2105590287411936, 0.3386412677934538, 0.9353023972414181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 215}], {
             RGBColor[
             0.20458807963597442`, 0.33236542170382943`, 0.9349623605231034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 223}], {
             RGBColor[
             0.2546024393338054, 0.3849336848398083, 0.9378106043182802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 268}], {
             RGBColor[
             0.20747158720625564`, 0.3353961709851344, 0.9351265720134637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 86}], {
             RGBColor[
             0.2018366701530856, 0.3294735158878764, 0.9348056718233985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 177}], {
             RGBColor[
             0.19983486008505225`, 0.32736948658428433`, 0.9346916717014366]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 194}], {
             RGBColor[
             0.2035493121604427, 0.3312736112253837, 0.9349032042520906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 290}], {
             RGBColor[
             0.1936841951962548, 0.32090474781148043`, 0.9343414004351128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 297}], {
             RGBColor[
             0.22326792573678073`, 0.35199912432642566`, 0.9360261501241884]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 350}], {
             RGBColor[
             0.19367927439437493`, 0.3208995757367078, 0.9343411202027254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 412}], {
             RGBColor[
             0.2124844072209095, 0.34066496265168167`, 0.9354120446974956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 484}], {
             RGBColor[
             0.20075983867306346`, 0.3283416977273139, 0.9347443478636406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 114}], {
             RGBColor[
             0.22515212124439515`, 0.35397953326982357`, 0.9361334522709297]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 128}], {
             RGBColor[
             0.2527669820297753, 0.38300450283855814`, 0.9377060777401315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 179}], {
             RGBColor[
             0.26537930167515955`, 0.3962608504531091, 0.9384243306856812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 245}], {
             RGBColor[
             0.3717582052146181, 0.4911621591427741, 0.9452943765065589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 255}], {
             RGBColor[
             0.2590437385722598, 0.38960177193405976`, 0.9380635297395968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 260}], {
             RGBColor[
             0.2863066273900213, 0.4179525885520823, 0.9396272494745492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 294}], {
             RGBColor[
             0.23819891010735164`, 0.3676925355789824, 0.9368764475956806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 299}], {
             RGBColor[
             0.35967789907867415`, 0.4813548224100252, 0.9443433705559179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 312}], {
             RGBColor[
             0.25430218522603054`, 0.38461809873532704`, 0.9377935052910287]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 327}], {
             RGBColor[
             0.23020235366261008`, 0.35928764774459687`, 0.9364210555359976]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 334}], {
             RGBColor[
             0.2368272907421635, 0.366250876660479, 0.936798335901962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 385}], {
             RGBColor[
             0.22541308597049314`, 0.3542538237430719, 0.9361483138260183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 415}], {
             RGBColor[
             0.22292255775669778`, 0.3516361206817638, 0.9360064819286489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 446}], {
             RGBColor[
             0.22940101354262873`, 0.3584453884705983, 0.9363754204016412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 119}], {
             RGBColor[
             0.194730591149065, 0.3220045763032192, 0.9344009911366213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 120}], {
             RGBColor[
             0.1852212022017432, 0.3120096055895012, 0.9338594455039515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 124}], {
             RGBColor[
             0.19699158310389825`, 0.32438102220291876`, 0.9345297512836113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 363}], {
             RGBColor[
             0.19105732048097354`, 0.31814373593224315`, 0.9341918038061905]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 381}], {
             RGBColor[
             0.20330273841305002`, 0.33101444658319545`, 0.9348891622419497]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 95}], {
             RGBColor[
             0.20531946953055227`, 0.3331341588558284, 0.9350040120956051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 286}], {
             RGBColor[
             0.21116729807720058`, 0.3392805974321006, 0.9353370372802498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 319}], {
             RGBColor[
             0.19709684259875715`, 0.3244916566058529, 0.9345357456561258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 330}], {
             RGBColor[
             0.2158728859753908, 0.3442264686646032, 0.9356050135497582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 352}], {
             RGBColor[
             0.20254407979161715`, 0.33021704827033466`, 0.934845957755794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 357}], {
             RGBColor[
             0.2136408209972711, 0.34188042685150594`, 0.9354779007512986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 367}], {
             RGBColor[
             0.2321744218168602, 0.3613604164110565, 0.9365333618999687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 368}], {
             RGBColor[
             0.19358411070805037`, 0.32079955266865445`, 0.9343357007715714]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 375}], {
             RGBColor[
             0.24422058989824297`, 0.3740217028357595, 0.9372193733514949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 450}], {
             RGBColor[
             0.27333525861175023`, 0.40175722238859823`, 0.9389823432231943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 492}], {
             RGBColor[
             0.20085698845876193`, 0.32844380831173514`, 0.9347498804002159]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 101}], {
             RGBColor[
             0.7358996157457895, 0.7730701996070706, 0.6676735904233504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 103}], {
             RGBColor[
             0.9879088198511304, 0.969706918546636, 0.5069176030846314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 129}], {
             RGBColor[
             0.870930679966885, 0.8808856413310856, 0.6795404574101209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 204}], {
             RGBColor[
             0.9308314245530096, 0.9281676018500284, 0.6853815574337436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 209}], {
             RGBColor[
             0.8720195914369621, 0.405748016840095, 0.23691988196683633`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 231}], {
             RGBColor[
             0.8720195914369621, 0.405748016840095, 0.23691988196683633`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 233}], {
             RGBColor[
             0.8720195914369621, 0.405748016840095, 0.23691988196683633`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 259}], {
             RGBColor[
             0.8720195914369621, 0.405748016840095, 0.23691988196683633`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 275}], {
             RGBColor[
             0.9574349696021127, 0.8614225983065917, 0.32381674285302947`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 306}], {
             RGBColor[
             0.7222846470752082, 0.7620169546929436, 0.6666017702163287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 331}], {
             RGBColor[
             0.9044576421525903, 0.9071378636611861, 0.6828660025242381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 346}], {
             RGBColor[
             0.9822051197373862, 0.9516358318169333, 0.3853706797712563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 348}], {
             RGBColor[
             0.9720780588899567, 0.9174748776315893, 0.3460289607139636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 355}], {
             RGBColor[
             0.8983352152225895, 0.6080214328363002, 0.2621197530231993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 372}], {
             RGBColor[
             0.8720195914369621, 0.405748016840095, 0.23691988196683633`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 404}], {
             RGBColor[
             0.8720195914369621, 0.405748016840095, 0.23691988196683633`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 418}], {
             RGBColor[
             0.9649838420823031, 0.8913513621779137, 0.32989074284540154`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 431}], {
             RGBColor[
             0.9874348778681517, 0.9686932045679294, 0.4553319430682715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 444}], {
             RGBColor[
             0.894494185245962, 0.578497593285873, 0.2584415783797579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 486}], {
             RGBColor[
             0.9877626572953866, 0.9693942916192012, 0.4910087109026512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 76}], {
             RGBColor[
             0.98996116143335, 0.9893085275125257, 0.7572877100420445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 111}], {
             RGBColor[
             0.985056438314053, 0.9880884674579122, 0.8973170200414953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 130}], {
             RGBColor[
             0.9093854335224396, 0.9290669367355356, 0.9363199027732196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 175}], {
             RGBColor[
             0.9901922146655133, 0.990212242962673, 0.8122039149346538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 182}], {
             RGBColor[
             0.9700359047903209, 0.9769432873298111, 0.9253003310773291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 208}], {
             RGBColor[
             0.9892910387748346, 0.9878752029057549, 0.6843489941803045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[
             0.9610594005806091, 0.8872098489096947, 0.5782429967897421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 351}], {
             RGBColor[
             0.7225448589609941, 0.7801979166455426, 0.9196407548248287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 359}], {
             RGBColor[
             0.8734050425786691, 0.4188525953049994, 0.40570794960622847`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 371}], {
             RGBColor[
             0.7661132779111547, 0.8155687218841894, 0.9230706203609627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 403}], {
             RGBColor[
             0.8734050425786691, 0.4188525953049994, 0.40570794960622847`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 442}], {
             RGBColor[
             0.7163330593542951, 0.7749857656872733, 0.9191984709357774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 463}], {
             RGBColor[
             0.9027643566949051, 0.6383284302508672, 0.43357997062744724`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 483}], {
             RGBColor[
             0.9784993022017803, 0.9517819287687919, 0.6160830557918804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 135}], {
             RGBColor[
             0.2217446900292419, 0.3503981070190804, 0.9359394041040694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 153}], {
             RGBColor[
             0.3288978182766464, 0.4547857321627663, 0.9423432170599901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 169}], {
             RGBColor[
             0.22996457913520382`, 0.3590377316405171, 0.9364075146284178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 172}], {
             RGBColor[
             0.3189558573582081, 0.44617450531270014`, 0.941709724101598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 197}], {
             RGBColor[
             0.33670866645889475`, 0.4615510962735853, 0.9428409173993011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 201}], {
             RGBColor[
             0.41387149855588806`, 0.5252776228187356, 0.9486164256235639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 211}], {
             RGBColor[
             0.23787031413452003`, 0.3673471603773484, 0.936857734541142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 236}], {
             RGBColor[
             0.2828326524801393, 0.4146054287554984, 0.9394182731941062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 289}], {
             RGBColor[
             0.2867699726445978, 0.4182967096833736, 0.9396588679885072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 308}], {
             RGBColor[
             0.24523893977810896`, 0.3750920531266102, 0.9372773668706396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 362}], {
             RGBColor[
             0.22011006608812847`, 0.34868001361582635`, 0.9358463146888325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 369}], {
             RGBColor[
             0.22611899076607778`, 0.3549957744401804, 0.9361885140598343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 466}], {
             RGBColor[
             0.25381484638134433`, 0.3841058747104944, 0.937765752064777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 470}], {
             RGBColor[
             0.2532282244104237, 0.3834892978250757, 0.9377323448113625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 493}], {
             RGBColor[
             0.4247009633868117, 0.5340694702303104, 0.9494689607646909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 128}], {
             RGBColor[
             0.28177127381369815`, 0.4125801173125145, 0.9393911391102159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 159}], {
             RGBColor[
             0.3689545388465866, 0.49399161017976106`, 0.9447304348549841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 179}], {
             RGBColor[
             0.2943835934590824, 0.4258364649270654, 0.9401093920557657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 222}], {
             RGBColor[
             0.28790125601795724`, 0.4190231172725106, 0.9397402325282525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 245}], {
             RGBColor[
             0.40076249699854094`, 0.5207377736167305, 0.9469794378766433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 294}], {
             RGBColor[
             0.2672032018912745, 0.39726815005293875`, 0.938561508965765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 344}], {
             RGBColor[
             0.27319882109803817`, 0.4035699259834611, 0.9389029506098664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 438}], {
             RGBColor[
             0.29983207958869507`, 0.43156316930326144`, 0.9404196752805343]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 439}], {
             RGBColor[
             0.292484520403141, 0.4238404187370848, 0.9400012426546567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 453}], {
             RGBColor[
             0.3882337150931953, 0.510566344050778, 0.9459931262706142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 91}], {
             RGBColor[
             0.8818663519635108, 0.5061968871434602, 0.22954386621065234`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 136}], {
             RGBColor[
             0.856961449626315, 0.4062492911560167, 0.20090363136839764`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 200}], {
             RGBColor[
             0.7612780109143027, 0.4386064526498009, 0.44502052851949037`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 240}], {
             RGBColor[
             0.8329068192640983, 0.2539418094898154, 0.17914491333122431`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 256}], {
             RGBColor[
             0.8488870131352718, 0.5076989827583813, 0.45340905512865315`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 298}], {
             RGBColor[
             0.7870575481756196, 0.4591533710298793, 0.44731121237687044`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 434}], {
             RGBColor[
             0.8329068192640983, 0.2539418094898154, 0.17914491333122431`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 115}], {
             RGBColor[
             0.22596376247749395`, 0.3548326196668369, 0.936179674038439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 144}], {
             RGBColor[
             0.23865380323456642`, 0.36817065709757524`, 0.9369023530863214]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 215}], {
             RGBColor[
             0.21298972122483276`, 0.3411960797085633, 0.935440821582474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 268}], {
             RGBColor[
             0.21587322879511397`, 0.3442268289898683, 0.9356050330728343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 402}], {
             RGBColor[
             0.28664069656288654`, 0.4145877472581879, 0.9397823340543834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 417}], {
             RGBColor[
             0.23919755835177475`, 0.36874217820182686`, 0.9369333191358328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 104}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 125}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 147}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 303}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 310}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 323}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 379}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 400}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 408}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 111}], {
             RGBColor[
             0.9894404720113958, 0.9890932090554398, 0.7659168812648544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 130}], {
             RGBColor[
             0.9137694672197825, 0.9300716783330631, 0.8049197639965786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 175}], {
             RGBColor[
             0.994576248362856, 0.9912169845602006, 0.6808037761580129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.9744199384876636, 0.9779480289273386, 0.7939001923006881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 351}], {
             RGBColor[
             0.7269288926583368, 0.7812026582430701, 0.7882406160481877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 359}], {
             RGBColor[
             0.8763277317102309, 0.4195224230366844, 0.31810785708846784`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 371}], {
             RGBColor[
             0.7704973116084974, 0.816573463481717, 0.7916704815843216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 460}], {
             RGBColor[
             0.9094586655152967, 0.9266343620675013, 0.8045085958817066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 463}], {
             RGBColor[
             0.9056870458264669, 0.638998257982552, 0.34597987810968656`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 483}], {
             RGBColor[
             0.982883335899123, 0.9527866703663195, 0.4846829170152394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 87}], {
             RGBColor[
             0.896783278694488, 0.9204422732959663, 0.9868140728389698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 184}], {
             RGBColor[
             0.9077974773796862, 0.7427431675399421, 0.6030848086881719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 253}], {
             RGBColor[
             0.9637096810052588, 0.9717997951686592, 0.9169584807873504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 287}], {
             RGBColor[
             0.8886081106405144, 0.9139236161987528, 0.9860343180119231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 301}], {
             RGBColor[
             0.8579732191915481, 0.4074969800510354, 0.43870016507762466`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 336}], {
             RGBColor[
             0.8579732191915481, 0.4074969800510354, 0.43870016507762466`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 354}], {
             RGBColor[
             0.9005988329718047, 0.9234846927062367, 0.9871780038121258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 388}], {
             RGBColor[
             0.9318009699728012, 0.9483644297913851, 0.9901540914937574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 409}], {
             RGBColor[
             0.7403041559440713, 0.7963746652347496, 0.9723494294433779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 436}], {
             RGBColor[
             0.9544907386391261, 0.9655798479084123, 0.9619194881543456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 473}], {
             RGBColor[
             0.7727967287954887, 0.8227535996492561, 0.9749073638024577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 154}], {
             RGBColor[
             0.863576315147662, 0.3772668633407367, 0.20411934796184356`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 171}], {
             RGBColor[
             0.9557437848802708, 0.8622080495874132, 0.28344566235844504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 192}], {
             RGBColor[
             0.9131433471019068, 0.8814405377612413, 0.6357016426534479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.9735420588312775, 0.9270450247585778, 0.5414260096688857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 219}], {
             RGBColor[
             0.863576315147662, 0.3772668633407367, 0.20411934796184356`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 258}], {
             RGBColor[
             0.9750213117175937, 0.926509082881858, 0.43348885156620276`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 262}], {
             RGBColor[
             0.953970946509212, 0.9135788430387926, 0.625155004871462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 376}], {
             RGBColor[
             0.9710596774572359, 0.9260184962661202, 0.5825654932338206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 497}], {
             RGBColor[
             0.9513305032138845, 0.844710858419126, 0.2798946323366356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 127}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 147}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 184}], {
             RGBColor[
             0.8369837657282427, 0.2665011316422593, 0.18231370738115665`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 221}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 234}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 253}], {
             RGBColor[
             0.8742585681452911, 0.4192055500614041, 0.39156282211394233`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 301}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 316}], {
             RGBColor[
             0.8735231410973765, 0.4108198428949215, 0.24276088847601782`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 336}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 388}], {
             RGBColor[
             0.8529860941236527, 0.4035819731432213, 0.44035989591821356`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 436}], {
             RGBColor[
             0.8681126065678694, 0.4150589185545728, 0.4215368270252724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 81}], {
             RGBColor[
             0.7036249157342768, 0.7658688297445426, 0.9529221476556539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 171}], {
             RGBColor[
             0.9566931052658137, 0.9145293959267929, 0.61948306634346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 192}], {
             RGBColor[
             0.9140926674874497, 0.9337618841006211, 0.9717390466384628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 208}], {
             RGBColor[
             0.9754972680138669, 0.9778179512987408, 0.718003495698742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 219}], {
             RGBColor[
             0.8642091954046907, 0.41214776090032323`, 0.42814428395185355`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 238}], {
             RGBColor[
             0.9472656298196414, 0.8771525973026804, 0.6118974983081796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 251}], {
             RGBColor[
             0.7049995072728927, 0.7670594318463122, 0.9530097354129909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 258}], {
             RGBColor[
             0.9759706321031365, 0.9788304292212378, 0.7695262555512177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 272}], {
             RGBColor[
             0.7621819360908365, 0.8135182343885552, 0.9575015284128756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 293}], {
             RGBColor[
             0.8642091954046907, 0.41214776090032323`, 0.42814428395185355`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 403}], {
             RGBColor[
             0.8642091954046907, 0.41214776090032323`, 0.42814428395185355`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 447}], {
             RGBColor[
             0.6925262053653484, 0.7562556846603798, 0.95221494764515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 471}], {
             RGBColor[
             0.8642091954046907, 0.41214776090032323`, 0.42814428395185355`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 483}], {
             RGBColor[
             0.9647055314408126, 0.9417246771617777, 0.6497375573103179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 497}], {
             RGBColor[
             0.9522798235994274, 0.8970322047585058, 0.6159320363216505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 121}], {
             RGBColor[
             0.3705335839034893, 0.4937931661956242, 0.9448883940271157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.6412269922816769, 0.7166892321720943, 0.9668997000917505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 208}], {
             RGBColor[
             0.7211325975340719, 0.7754974983423137, 0.7149287914988354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 213}], {
             RGBColor[
             0.3642555391877909, 0.48719454314839994`, 0.9445308686680915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 251}], {
             RGBColor[
             0.4506348367930976, 0.5647389788898851, 0.9499350312130843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 442}], {
             RGBColor[
             0.44817461811353243`, 0.562608061123832, 0.9497782682543083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 447}], {
             RGBColor[
             0.4381615348855533, 0.5539352317039529, 0.9491402434452434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 454}], {
             RGBColor[
             0.38458547196747705`, 0.5075303388155344, 0.9457264240915557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 500}], {
             RGBColor[
             0.3616089991347435, 0.484412861752316, 0.9443801521272757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 126}], {
             RGBColor[
             0.916199280091377, 0.7036541810826651, 0.25133650057422957`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 149}], {
             RGBColor[
             0.8696222340143458, 0.4946976853386944, 0.21268036640365176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 173}], {
             RGBColor[
             0.844192723800754, 0.2992353265545988, 0.18832903870459236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 242}], {
             RGBColor[
             0.844192723800754, 0.2992353265545988, 0.18832903870459236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 249}], {
             RGBColor[
             0.844192723800754, 0.2992353265545988, 0.18832903870459236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 269}], {
             RGBColor[
             0.844192723800754, 0.2992353265545988, 0.18832903870459236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 282}], {
             RGBColor[
             0.844192723800754, 0.2992353265545988, 0.18832903870459236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 323}], {
             RGBColor[
             0.844192723800754, 0.2992353265545988, 0.18832903870459236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 384}], {
             RGBColor[
             0.7661799454534821, 0.6717707570486016, 0.6004570534353222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 411}], {
             RGBColor[
             0.805124727752193, 0.7023163366231125, 0.604255553355253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 419}], {
             RGBColor[
             0.844192723800754, 0.2992353265545988, 0.18832903870459236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 499}], {
             RGBColor[
             0.844192723800754, 0.2992353265545988, 0.18832903870459236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 97}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 163}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 207}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 209}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 231}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 233}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 257}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 317}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 326}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 343}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 346}], {
             RGBColor[
             0.8725424883879621, 0.4075118710378607, 0.23895123788066785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 355}], {
             RGBColor[
             0.8304768118928137, 0.23526370799810264`, 0.17681793552818148`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 395}], {
             RGBColor[
             0.8502020870562027, 0.32426772933006165`, 0.19322676477969444`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 440}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 89}], {
             RGBColor[
             0.7687714356170879, 0.8196030224681695, 0.9775043726151027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 176}], {
             RGBColor[
             0.7812728109768734, 0.8295712798392683, 0.9786967649570286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 244}], {
             RGBColor[
             0.8279818714648165, 0.8418796258010216, 0.6672951219910502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 245}], {
             RGBColor[
             0.580845373371183, 0.6700379828264612, 0.960526576780036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 260}], {
             RGBColor[
             0.49539379554658625`, 0.5968284122357694, 0.9548594497480263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 261}], {
             RGBColor[
             0.802578407870131, 0.8465597844769306, 0.9807289118084384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 262}], {
             RGBColor[
             0.8153011335016991, 0.8562880262921846, 0.9675016060762058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 299}], {
             RGBColor[
             0.5687650672352391, 0.6602306460937123, 0.9595755708293949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 328}], {
             RGBColor[
             0.5779012816849092, 0.667647836565725, 0.9602948070979291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 376}], {
             RGBColor[
             0.832389864449723, 0.8687276795195121, 0.9249120944385643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 391}], {
             RGBColor[
             0.8156476109000103, 0.7992621868904787, 0.624644580043521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 407}], {
             RGBColor[
             0.6835079427609747, 0.7526808668284215, 0.9690893420556808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 448}], {
             RGBColor[
             0.7514898127927288, 0.8058231255251804, 0.9758560360026285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 455}], {
             RGBColor[
             0.7711297731426533, 0.3390729855096647, 0.43235041543167274`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 475}], {
             RGBColor[
             0.810505150868455, 0.8527111902970119, 0.9756199536816843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 478}], {
             RGBColor[
             0.5977451472226231, 0.6837579805651962, 0.9618569888835327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 482}], {
             RGBColor[
             0.8075023357681443, 0.8504716957118587, 0.9807029363869016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 146}], {
             RGBColor[
             0.199363430421074, 0.32687398411707613`, 0.9346648244794907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 166}], {
             RGBColor[
             0.23298059512902075`, 0.36220775567647745`, 0.9365792722774698]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 239}], {
             RGBColor[
             0.23505374481506194`, 0.3643867674417887, 0.9366973350851397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 332}], {
             RGBColor[
             0.21348039489620751`, 0.3417118088476858, 0.9354687647221722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 387}], {
             RGBColor[
             0.2183544974781896, 0.34683479969730174`, 0.9357463376536275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 489}], {
             RGBColor[
             0.2242348495004033, 0.3530154225085005, 0.9360812150020913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 177}], {
             RGBColor[
             0.204427895244704, 0.3321970577523273, 0.9349532382589922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 194}], {
             RGBColor[
             0.20814234732009446`, 0.3361011823934266, 0.9351647708096462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 220}], {
             RGBColor[
             0.2767001990541243, 0.4046256973632345, 0.9391984410025577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 254}], {
             RGBColor[
             0.2217593415229328, 0.3504135066679079, 0.9359402384849602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 290}], {
             RGBColor[
             0.1982772303559066, 0.32573231897952337`, 0.9346029669926684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 297}], {
             RGBColor[
             0.22786096089643254`, 0.35682669549446866`, 0.936287716681744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 350}], {
             RGBColor[
             0.19827230955402672`, 0.32572714690475074`, 0.934602686760281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 377}], {
             RGBColor[
             0.19669430319698816`, 0.3240685621721215, 0.9345128216326989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 412}], {
             RGBColor[
             0.2170774423805613, 0.34549253381972456`, 0.9356736112550512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 426}], {
             RGBColor[
             0.2108343428642681, 0.3389306403927288, 0.9353180759734364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 476}], {
             RGBColor[
             0.2023767546336836, 0.3300411789203187, 0.9348364288355852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 91}], {
             RGBColor[
             0.9092412489562847, 0.8887699196998804, 0.6506892545416749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 161}], {
             RGBColor[
             0.5929939478905595, 0.674186901246545, 0.9641602249639974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 184}], {
             RGBColor[
             0.86529909849953, 0.7089485006828021, 0.6022343862942678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 228}], {
             RGBColor[
             0.713434001367286, 0.7752676949105676, 0.9727293181147071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 253}], {
             RGBColor[
             0.9212113021251026, 0.9380051283115193, 0.9161080583934463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 256}], {
             RGBColor[
             0.8597722407139262, 0.891023063122262, 0.9864870379186761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 285}], {
             RGBColor[
             0.5942823297173198, 0.6753028328289313, 0.9642423195147274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 287}], {
             RGBColor[
             0.8461097317603583, 0.8801289493416129, 0.985183895618019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 336}], {
             RGBColor[
             0.8296409666047774, 0.38496720214627544`, 0.43813321681502193`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 354}], {
             RGBColor[
             0.8581004540916486, 0.8896900258490967, 0.9863275814182217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 388}], {
             RGBColor[
             0.8893025910926451, 0.9145697629342451, 0.9893036690998533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 409}], {
             RGBColor[
             0.6978057770639152, 0.7625799983776096, 0.9714990070494738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 436}], {
             RGBColor[
             0.9119923597589701, 0.9317851810512723, 0.9610690657604415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 473}], {
             RGBColor[
             0.7302983499153326, 0.788958932792116, 0.9740569414085536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 133}], {
             RGBColor[
             0.24286224712593307`, 0.37259399845815566`, 0.9371420177400999]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 241}], {
             RGBColor[
             0.28248141588286296`, 0.41132455172417753`, 0.9395048825764732]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 271}], {
             RGBColor[
             0.2646478400333292, 0.39549203789019866`, 0.9383826750272796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 304}], {
             RGBColor[
             0.22720116780943558`, 0.35613321112673696`, 0.9362501424415159]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 307}], {
             RGBColor[
             0.2294926966396743, 0.3585417532186373, 0.9363806416183849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 311}], {
             RGBColor[
             0.22564091581509077`, 0.3544932873549904, 0.936161288398624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 337}], {
             RGBColor[
             0.22370546244709866`, 0.3524590031503995, 0.9360510671925635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 423}], {
             RGBColor[
             0.20241340429212143`, 0.33007970003505943`, 0.9348385159794148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 427}], {
             RGBColor[
             0.21816644071600988`, 0.3466371401167634, 0.9357356280992264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 433}], {
             RGBColor[
             0.20558699861107904`, 0.3334153488817855, 0.9350192474809674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 465}], {
             RGBColor[
             0.20208905675330635`, 0.3297387902069431, 0.9348200448669085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 469}], {
             RGBColor[
             0.20704962369398588`, 0.33495266057970696`, 0.9351025418156791]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 176}], {
             RGBColor[
             0.8712929271660014, 0.9002093457784437, 0.9875858912771132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 178}], {
             RGBColor[
             0.9077540295115808, 0.8779489225910053, 0.6363728660925616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 244}], {
             RGBColor[
             0.9180019876539445, 0.912517691740197, 0.6761842483111349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 261}], {
             RGBColor[
             0.8925985240592591, 0.917197850416106, 0.989618038128523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 262}], {
             RGBColor[
             0.905321249690827, 0.92692609223136, 0.9763907323962904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 299}], {
             RGBColor[
             0.6587851834243671, 0.7308687120328877, 0.9684646971494795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 328}], {
             RGBColor[
             0.6679213978740371, 0.7382859025049004, 0.9691839334180138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 376}], {
             RGBColor[
             0.9224099806388508, 0.9393657454586876, 0.9338012207586489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 391}], {
             RGBColor[
             0.9056677270891382, 0.8699002528296541, 0.6335337063636055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 407}], {
             RGBColor[
             0.7735280589501026, 0.8233189327675969, 0.9779784683757653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 448}], {
             RGBColor[
             0.8415099289818567, 0.8764611914643559, 0.9847451623227131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 455}], {
             RGBColor[
             0.8311431839354053, 0.386165029469115, 0.43827649964506243`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 475}], {
             RGBColor[
             0.900525267057583, 0.9233492562361874, 0.984509080001769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 478}], {
             RGBColor[
             0.687765263411751, 0.7543960465043716, 0.9707461152036172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 482}], {
             RGBColor[
             0.8975224519572722, 0.9211097616510341, 0.9895920627069863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 137}], {
             RGBColor[
             0.45984500856407784`, 0.5687739133839165, 0.9516112068287906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 148}], {
             RGBColor[
             0.6360400198232251, 0.7149269386277152, 0.9648173774964799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 229}], {
             RGBColor[
             0.5154543184856579, 0.616939902632804, 0.9551545828836118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 232}], {
             RGBColor[
             0.6473094528464778, 0.7237307053563433, 0.9659406092613985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 263}], {
             RGBColor[
             0.4902638758215754, 0.5951212073056378, 0.9535494701520902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 267}], {
             RGBColor[
             0.5020615308844408, 0.6053397431537071, 0.9543012063004392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 280}], {
             RGBColor[
             0.5706742857728803, 0.6623381196308499, 0.9593447167062806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 342}], {
             RGBColor[
             0.7736445823202994, 0.759776227926813, 0.6195883744105202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 393}], {
             RGBColor[
             0.483014768717581, 0.588842395082875, 0.9530875634575574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 480}], {
             RGBColor[
             0.5389584272669072, 0.6365897569125576, 0.9568479281456727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 485}], {
             RGBColor[
             0.5765425629929836, 0.6671022514410058, 0.9598066889852549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 200}], {
             RGBColor[
             0.7833150865244253, 0.7895065812204456, 0.6386298521015412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 228}], {
             RGBColor[
             0.7683903505092387, 0.7773900081716217, 0.6374549222113163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 256}], {
             RGBColor[
             0.914728589855879, 0.8931453763833161, 0.6512126420152853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 287}], {
             RGBColor[
             0.901066080902311, 0.8822512626026671, 0.6499094997146282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 298}], {
             RGBColor[
             0.8219843924164008, 0.8203269587905632, 0.6420658778876114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 336}], {
             RGBColor[
             0.8662785326994125, 0.38638207765364485`, 0.21461695287942806`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 132}], {
             RGBColor[
             0.6587795986186888, 0.7333628964420915, 0.9666246518110923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 250}], {
             RGBColor[
             0.5085778888955018, 0.6091430188143863, 0.955320634245421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 342}], {
             RGBColor[
             0.8032234487173383, 0.7835550891960509, 0.622077324996481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 356}], {
             RGBColor[
             0.5746689176875454, 0.6653465467906676, 0.9598195826356501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 365}], {
             RGBColor[
             0.4788564599632421, 0.5825948499682702, 0.9534562846389698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 457}], {
             RGBColor[
             0.8072191088446563, 0.7991593994494468, 0.6265274116797456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 485}], {
             RGBColor[
             0.6061214293900224, 0.6908811127102437, 0.9622956395712158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 494}], {
             RGBColor[
             0.8135287985254407, 0.8545930428227555, 0.9516114497283175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 141}], {
             RGBColor[
             0.3375011498141227, 0.46604896981814714`, 0.9427518573592213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 151}], {
             RGBColor[
             0.3297566159868596, 0.4579089737338883, 0.9423108176147698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 160}], {
             RGBColor[
             0.41434048219955033`, 0.5332607321432926, 0.9476339644047369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 167}], {
             RGBColor[
             0.41563984784251484`, 0.5343156157080063, 0.9477362552278843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 172}], {
             RGBColor[
             0.3758866189646938, 0.4999958295615881, 0.9451721408703121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 201}], {
             RGBColor[
             0.4708022601623738, 0.5790989470676235, 0.9520788423922779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 218}], {
             RGBColor[
             0.5568185669726924, 0.6474379222816083, 0.9598710907741307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 235}], {
             RGBColor[
             0.3605980717626268, 0.48675365839988305`, 0.9441979681617279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 236}], {
             RGBColor[
             0.339763414086625, 0.46842675300438635`, 0.9428806899628203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 274}], {
             RGBColor[
             0.4288787771490915, 0.545063574926054, 0.948778472238694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 284}], {
             RGBColor[
             0.3364698481712808, 0.4649650064032194, 0.9426931262563356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 289}], {
             RGBColor[
             0.3437007342510835, 0.4721180339322616, 0.9431212847572212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 300}], {
             RGBColor[
             0.3959649652472733, 0.5173866839445316, 0.9464515153408535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 305}], {
             RGBColor[
             0.6178108662440276, 0.6954235689523357, 0.9658605386388516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 308}], {
             RGBColor[
             0.30216970138459465`, 0.4289133773754982, 0.9407397836393536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 389}], {
             RGBColor[
             0.31082135500600144`, 0.43800681387811885`, 0.9412324825141183]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 432}], {
             RGBColor[
             0.5726032211042509, 0.6597690140569965, 0.961444357581985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 456}], {
             RGBColor[
             0.31230759322488866`, 0.43956894447911504`, 0.9413171215819914]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 493}], {
             RGBColor[
             0.4816317249932974, 0.5878907944791983, 0.952931377533405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 123}], {
             RGBColor[
             0.19382981247906908`, 0.3210578008083872, 0.9343496931239477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 139}], {
             RGBColor[
             0.18683641908668117`, 0.31370730094623644`, 0.9339514297160496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 158}], {
             RGBColor[
             0.20645253428145324`, 0.3343250817494799, 0.9350685384569499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 193}], {
             RGBColor[
             0.18322775270743138`, 0.3099143637789815, 0.9337459215042947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 401}], {
             RGBColor[
             0.1828044456707124, 0.3094694412441735, 0.9337218147947803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 410}], {
             RGBColor[
             0.18607999806105058`, 0.3129122544884356, 0.9339083526576646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 428}], {
             RGBColor[
             0.19798131880027114`, 0.3254212971726742, 0.9345861152673369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 437}], {
             RGBColor[
             0.18537229810347358`, 0.3121684169622533, 0.9338680501920288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 122}], {
             RGBColor[
             0.20586015494572685`, 0.3337024535086123, 0.935034803330127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 185}], {
             RGBColor[
             0.262167272695942, 0.39178664192053536`, 0.9382816194928008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 212}], {
             RGBColor[
             0.19782060647564204`, 0.3252523783297391, 0.9345769629382018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 224}], {
             RGBColor[
             0.24948593288589618`, 0.37955591215781015`, 0.9375192268452648]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 286}], {
             RGBColor[
             0.2095588048007067, 0.3375899690141414, 0.935245435967706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 319}], {
             RGBColor[
             0.19548834932226328`, 0.3228010281878937, 0.9344441443435821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 330}], {
             RGBColor[
             0.2142643926988969, 0.3425358402466441, 0.9355134122372144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 357}], {
             RGBColor[
             0.21203232772077724`, 0.3401897984335468, 0.9353862994387547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 367}], {
             RGBColor[
             0.2305659285403663, 0.35966978799309735`, 0.936441760587425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 368}], {
             RGBColor[
             0.19197561743155647`, 0.3191089242506953, 0.9342440994590275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 492}], {
             RGBColor[
             0.19924849518226806`, 0.326753179893776, 0.9346582790876721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 110}], {
             RGBColor[
             0.9745488280148329, 0.9248169273650014, 0.4244348962647706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 136}], {
             RGBColor[
             0.9223928943750033, 0.7257736795999382, 0.2561940101384317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.886514879220424, 0.8590158099428777, 0.6326804478109045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 240}], {
             RGBColor[
             0.8633136325544521, 0.3762506380670908, 0.20377662205511446`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 360}], {
             RGBColor[
             0.8668775579740029, 0.4036445305638346, 0.2071894410617543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 457}], {
             RGBColor[
             0.956033925940152, 0.8631590470414205, 0.284717153430919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 163}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 207}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 209}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 231}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 233}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 257}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 281}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 317}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 322}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 326}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 343}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 355}], {
             RGBColor[
             0.8304768118928137, 0.23526370799810264`, 0.17681793552818148`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 395}], {
             RGBColor[
             0.8502020870562027, 0.32426772933006165`, 0.19322676477969444`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 440}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 105}], {
             RGBColor[
             0.22603623939872042`, 0.3549087975063481, 0.9361838014918828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 276}], {
             RGBColor[
             0.2749015720573606, 0.4042586138049795, 0.9390402331787011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 347}], {
             RGBColor[
             0.251130504754864, 0.38128446146397427`, 0.9376128827802765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 382}], {
             RGBColor[
             0.27123479538503203`, 0.4010826361489628, 0.9388065894115436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 425}], {
             RGBColor[
             0.21581332835072858`, 0.34416386982491176`, 0.9356016218311414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 462}], {
             RGBColor[
             0.22311090923146282`, 0.35183409002391514`, 0.9360172082664957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 131}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 143}], {
             RGBColor[
             0.8239416059032, 0.18503125101640663`, 0.1705598148920679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 178}], {
             RGBColor[
             0.8637848357389819, 0.3779702522582219, 0.20492941108331192`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 186}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 277}], {
             RGBColor[
             0.8718851812720558, 0.40529461979285863`, 0.23639772385740537`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 288}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 295}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 313}], {
             RGBColor[
             0.8708575836519874, 0.41710611796942054`, 0.41689029682654455`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 321}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 341}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 373}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 498}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 203}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 257}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 264}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 281}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 324}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 360}], {
             RGBColor[
             0.8191009627097754, 0.1478239462483719, 0.1659244095033199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 374}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 397}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 457}], {
             RGBColor[
             0.8638009847389825, 0.3780247266271895, 0.20499214689883155`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 103}], {
             RGBColor[
             0.7423876612860338, 0.7937870676334219, 0.792267547607473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 129}], {
             RGBColor[
             0.6254095214017883, 0.7049657904178714, 0.9648904019329624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[
             0.6853102659879131, 0.7522477509368144, 0.9707315019565851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 276}], {
             RGBColor[
             0.41043620356290245`, 0.5289146649262826, 0.9476516475428687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 306}], {
             RGBColor[
             0.4767634885101116, 0.5860971037797296, 0.9519517147391703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 331}], {
             RGBColor[
             0.6589364835874938, 0.7312180127479719, 0.9682159470470796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 347}], {
             RGBColor[
             0.38666513626040583`, 0.5059405125852774, 0.9462242971444441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 390}], {
             RGBColor[
             0.5242582957488938, 0.6246555279128561, 0.9556906799442186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 431}], {
             RGBColor[
             0.7419137193030552, 0.7927733536547152, 0.740681887591113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 486}], {
             RGBColor[
             0.7422414987302901, 0.793474440705987, 0.7763586554254926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 134}], {
             RGBColor[
             0.23432084769928213`, 0.3636164461047431, 0.9366555976786202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 174}], {
             RGBColor[
             0.24152702065256443`, 0.3711905907763972, 0.937065978567732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 210}], {
             RGBColor[
             0.2588571240715909, 0.389405628261814, 0.9380529023198552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 225}], {
             RGBColor[
             0.23396295286916968`, 0.3632402759464521, 0.9366352160975032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 247}], {
             RGBColor[
             0.23463961323959567`, 0.36395148889851525`, 0.9366737509045697]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 252}], {
             RGBColor[
             0.2303914914496485, 0.3594864435508025, 0.9364318266531653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 278}], {
             RGBColor[
             0.23503759534630753`, 0.36436979332619235`, 0.9366964153967852]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 309}], {
             RGBColor[
             0.24307505381461134`, 0.3728176717806799, 0.9371541367662009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 383}], {
             RGBColor[
             0.4499159059433277, 0.5554178997074893, 0.951374070302039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 393}], {
             RGBColor[
             0.3174055972642307, 0.4455102820141783, 0.9415860984428273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 451}], {
             RGBColor[
             0.2794536000934562, 0.411053830452799, 0.9392258411595447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 480}], {
             RGBColor[
             0.373349255813557, 0.49325764384386095`, 0.9453464631309425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 129}], {
             RGBColor[
             0.8774187255071293, 0.9016025093574369, 0.8041344145942433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 204}], {
             RGBColor[
             0.9373194700932539, 0.9488844698763799, 0.809975514617866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 209}], {
             RGBColor[
             0.8763449551304583, 0.4195592621909958, 0.3199825200895846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 231}], {
             RGBColor[
             0.8763449551304583, 0.4195592621909958, 0.3199825200895846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 233}], {
             RGBColor[
             0.8763449551304583, 0.4195592621909958, 0.3199825200895846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 259}], {
             RGBColor[
             0.8763449551304583, 0.4195592621909958, 0.3199825200895846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 275}], {
             RGBColor[
             0.963923015142357, 0.882139466332943, 0.4484107000371519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 326}], {
             RGBColor[
             0.8763449551304583, 0.4195592621909958, 0.3199825200895846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 346}], {
             RGBColor[
             0.9886931652776305, 0.9723526998432848, 0.5099646369553787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 348}], {
             RGBColor[
             0.978566104430201, 0.9381917456579405, 0.470622917898086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 355}], {
             RGBColor[
             0.9026605789160858, 0.621832678187201, 0.34518239114594756`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 390}], {
             RGBColor[
             0.7762674998542347, 0.8212922468524215, 0.7949346926054996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 404}], {
             RGBColor[
             0.8763449551304583, 0.4195592621909958, 0.3199825200895846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 431}], {
             RGBColor[
             0.9939229234083959, 0.9894100725942807, 0.579925900252394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 443}], {
             RGBColor[
             0.8728831239162906, 0.898059262922825, 0.8036823482152753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 444}], {
             RGBColor[
             0.8988195489394581, 0.5923088386367739, 0.34150421650250623`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 486}], {
             RGBColor[
             0.9942507028356309, 0.9901111596455525, 0.6156026680867737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 125}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 147}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 242}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 303}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 310}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 323}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 379}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 408}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 109}], {
             RGBColor[
             0.28171832903511257`, 0.41140686866770654`, 0.9394290448060217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 205}], {
             RGBColor[
             0.33891161833602373`, 0.4609448212418522, 0.9430733506262359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 230}], {
             RGBColor[
             0.26393464830119756`, 0.39474242816076077`, 0.9383420598132073]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 382}], {
             RGBColor[
             0.2779618406141432, 0.4081531872040607, 0.9391896846855698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 425}], {
             RGBColor[
             0.22254037357983977`, 0.35123442088000967`, 0.9359847171051676]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 462}], {
             RGBColor[
             0.229837954460574, 0.3589046410790131, 0.936400303540522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 484}], {
             RGBColor[
             0.21851966349026236`, 0.34700839964812025`, 0.9357557436136738]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 156}], {
             RGBColor[
             0.2245611665730593, 0.35335840244155936`, 0.9360997982766361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 227}], {
             RGBColor[
             0.21113051364042446`, 0.3392419346567809, 0.9353349424609931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 265}], {
             RGBColor[
             0.1920994264104521, 0.3192390553374573, 0.9342511501972167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 270}], {
             RGBColor[
             0.18303490781801574`, 0.3097116715731334, 0.933734939273131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 329}], {
             RGBColor[
             0.18619018249920005`, 0.3130280653190276, 0.9339146274984138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 479}], {
             RGBColor[
             0.18778223780521028`, 0.31470141638778093`, 0.9340052926928564]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 153}], {
             RGBColor[
             0.35862018099566284`, 0.48504050882921934`, 0.944071938711037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 170}], {
             RGBColor[
             0.2681353000213933, 0.3981722683975148, 0.9386173577788594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 197}], {
             RGBColor[
             0.36643102917791126`, 0.4918058729400383, 0.9445696390503481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 214}], {
             RGBColor[
             0.26772635198284234`, 0.39774243808019455`, 0.9385940687930483]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 223}], {
             RGBColor[
             0.31217871061400504`, 0.4444646854438693, 0.9411255648557215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 236}], {
             RGBColor[
             0.31255501519915574`, 0.44486020542195137`, 0.9411469948451532]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 289}], {
             RGBColor[
             0.31649233536361426`, 0.44855148634982667`, 0.941387589639554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 314}], {
             RGBColor[
             0.4603925267300639, 0.5691703128729416, 0.9516675997547801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 411}], {
             RGBColor[
             0.5158561344435298, 0.6131266190837553, 0.9567665221218118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 466}], {
             RGBColor[
             0.2835372091003608, 0.41436065137694744`, 0.939494473715824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 470}], {
             RGBColor[
             0.2829505871294402, 0.41374407449152867`, 0.9394610664624095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 113}], {
             RGBColor[
             0.2834673549063147, 0.4150291714427635, 0.9394633295190601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 190}], {
             RGBColor[
             0.3280007224836446, 0.45851947284484174`, 0.9421208938903753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 315}], {
             RGBColor[
             0.25480773581216487`, 0.38490609465000936`, 0.9378312066097552]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 349}], {
             RGBColor[
             0.25865268956964965`, 0.3889473848332744, 0.9380501710381446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 364}], {
             RGBColor[
             0.29999764061783074`, 0.4324035498062153, 0.9404047048359647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 378}], {
             RGBColor[
             0.3055376194253575, 0.43822641878786983`, 0.940720198433389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 380}], {
             RGBColor[
             0.26354993581091446`, 0.3940947011361892, 0.9383290619667581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 416}], {
             RGBColor[
             0.3104556295882034, 0.4433227952208202, 0.9410029360855943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 452}], {
             RGBColor[
             0.35261985676709484`, 0.4798433295674984, 0.9436896033570711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 487}], {
             RGBColor[
             0.27490256852659056`, 0.40602703791885253`, 0.9389755776052008]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 164}], {
             RGBColor[
             0.6056683283309234, 0.6842577010589471, 0.9653854185243207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 180}], {
             RGBColor[
             0.4670849110812572, 0.5749095094534886, 0.9521098952255831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 205}], {
             RGBColor[
             0.3878666627433047, 0.5103723413481127, 0.9459354986663484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 230}], {
             RGBColor[
             0.31288969270847855`, 0.4441699482670213, 0.9412042078533198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 382}], {
             RGBColor[
             0.3269168850214242, 0.4575807073103212, 0.9420518327256824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 413}], {
             RGBColor[
             0.37066616576114175`, 0.49547413538427865`, 0.9448394982084473]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 474}], {
             RGBColor[
             0.36875585432995733`, 0.49381951963763093`, 0.9447177748532742]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 490}], {
             RGBColor[
             0.33626661541495695`, 0.4656789738460858, 0.9426475892787163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 157}], {
             RGBColor[
             0.9057608095719005, 0.9233348231066068, 0.7742214779103318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 356}], {
             RGBColor[
             0.7427296651345173, 0.7936652075463704, 0.7595503544862507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 360}], {
             RGBColor[
             0.8797081782083205, 0.4465238726729873, 0.3015501277947058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 457}], {
             RGBColor[
             0.9752798562916284, 0.9274780602051496, 0.4262581835303463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 494}], {
             RGBColor[
             0.9815895459724128, 0.9829117035784583, 0.7513422215789181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 130}], {
             RGBColor[
             0.9088647441004855, 0.9288516182784499, 0.9449490739960295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 175}], {
             RGBColor[
             0.9896715252435591, 0.9899969245055872, 0.8208330861574638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 182}], {
             RGBColor[
             0.9695152153683666, 0.9767279688727253, 0.933929502300139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 351}], {
             RGBColor[
             0.7220241695390399, 0.7799825981884567, 0.9282699260476386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 359}], {
             RGBColor[
             0.8730579162973663, 0.4187090496669422, 0.41146073042143505`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 371}], {
             RGBColor[
             0.7655925884892005, 0.8153534034271036, 0.9316997915837725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 460}], {
             RGBColor[
             0.9045539423959997, 0.925414302012888, 0.9445379058811575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 463}], {
             RGBColor[
             0.9024172304136022, 0.6381848846128098, 0.4393327514426538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 483}], {
             RGBColor[
             0.977978612779826, 0.951566610311706, 0.6247122270146903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 163}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 175}], {
             RGBColor[
             0.8764817671983398, 0.42012490000344926`, 0.35471866035020744`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 207}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 238}], {
             RGBColor[
             0.857059891141737, 0.3514566373014637, 0.19874471492026624`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 266}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 293}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 317}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 343}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 359}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 403}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 440}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 445}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 463}], {
             RGBColor[
             0.831998657058118, 0.24386491747293382`, 0.17815401051060936`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 471}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 483}], {
             RGBColor[
             0.8686864922225178, 0.39450469054086185`, 0.22397142092169176`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 190}], {
             RGBColor[
             0.30008982406307977`, 0.4294267187567612, 0.9405224985550569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 315}], {
             RGBColor[
             0.22689683739160005`, 0.3558133405619288, 0.9362328112744367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 349}], {
             RGBColor[
             0.23074179114908483`, 0.35985463074519386`, 0.9364517757028261]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 353}], {
             RGBColor[
             0.22107694525191812`, 0.3496962649206489, 0.9359013770268407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 364}], {
             RGBColor[
             0.2720867421972659, 0.4033107957181348, 0.9388063095006463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 378}], {
             RGBColor[
             0.2776267210047927, 0.4091336646997893, 0.9391218030980706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 380}], {
             RGBColor[
             0.23563903739034964`, 0.36500194704810873`, 0.9367306666314397]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 487}], {
             RGBColor[
             0.24699167010602574`, 0.37693428383077204`, 0.9373771822698823]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 128}], {
             RGBColor[
             0.21734212015934035`, 0.3457707269467618, 0.935688684262997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 138}], {
             RGBColor[
             0.19260410669659306`, 0.3197695063167697, 0.9342798909929049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 179}], {
             RGBColor[
             0.22995443980472458`, 0.3590270745613128, 0.9364069372085467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 255}], {
             RGBColor[
             0.2236188767018249, 0.35236799604226343`, 0.9360461362624624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 294}], {
             RGBColor[
             0.2027740482369167, 0.3304587596871861, 0.934859054118546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 296}], {
             RGBColor[
             0.19143934787553057`, 0.3185452709458584, 0.9342135597011516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 312}], {
             RGBColor[
             0.21887732335559562`, 0.3473843228435307, 0.9357761118138941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 327}], {
             RGBColor[
             0.19477749179217513`, 0.32205387185280054`, 0.9344036620588632]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 334}], {
             RGBColor[
             0.20140242887172854`, 0.3290171007686827, 0.9347809424248276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 385}], {
             RGBColor[
             0.18998822410005822`, 0.3170200478512756, 0.9341309203488837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 415}], {
             RGBColor[
             0.18749769588626286`, 0.3144023447899675, 0.9339890884515143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 446}], {
             RGBColor[
             0.1939761516721938, 0.321211612578802, 0.9343580269245066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 144}], {
             RGBColor[
             0.2435638403098072, 0.37333141737798453`, 0.9371819724340074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 215}], {
             RGBColor[
             0.21789975830007355`, 0.3463568399889726, 0.93572044093016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 223}], {
             RGBColor[
             0.26791411799790454`, 0.39892510312495144`, 0.9385686847253369]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 268}], {
             RGBColor[
             0.22078326587035477`, 0.3493875892702776, 0.9358846524205204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 402}], {
             RGBColor[
             0.29155073363812734`, 0.41974850753859727`, 0.9400619534020693]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 417}], {
             RGBColor[
             0.24410759542701554`, 0.3739029384822362, 0.9372129384835188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 143}], {
             RGBColor[
             0.7862678242150312, 0.44236018796317117`, 0.4452227057442526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 165}], {
             RGBColor[
             0.7645854413092009, 0.8162193268874823, 0.9771172884853815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 185}], {
             RGBColor[
             0.5025267031818595, 0.6027654055971375, 0.9554160280414452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 187}], {
             RGBColor[
             0.5258049734314325, 0.6229278732874357, 0.956899298837582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 224}], {
             RGBColor[
             0.4898453633718138, 0.5905346758344123, 0.9546536353939092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 277}], {
             RGBColor[
             0.8327236905210305, 0.8505154585848247, 0.6749691997262832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 313}], {
             RGBColor[
             0.8311822940909279, 0.8682327058496676, 0.945708059179992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 333}], {
             RGBColor[
             0.5510899875354679, 0.6448284816425902, 0.958510437577631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 358}], {
             RGBColor[
             0.5345278762555137, 0.6304832132878109, 0.9574551144921722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 361}], {
             RGBColor[
             0.5470425558222825, 0.6413227997224619, 0.9582525388078701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 386}], {
             RGBColor[
             0.7639631876081299, 0.8157231586768751, 0.9770579373718808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 441}], {
             RGBColor[
             0.5263358260398556, 0.6233876711354238, 0.9569331242963761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 140}], {
             RGBColor[
             0.1891020516318635, 0.31608862440062324`, 0.9340804541377947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 155}], {
             RGBColor[
             0.22121121154755882`, 0.34983738731034214`, 0.9359090232937483]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 156}], {
             RGBColor[
             0.23299646235272825`, 0.36222443313463404`, 0.9365801758923864]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 198}], {
             RGBColor[
             0.19641879440682608`, 0.3237789849653949, 0.9344971318146779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 270}], {
             RGBColor[
             0.19147020359768469`, 0.3185777022662082, 0.9342153168888814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 479}], {
             RGBColor[
             0.1962175335848792, 0.3235674470808556, 0.9344856703086066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 152}], {
             RGBColor[
             0.21897053500328645`, 0.3474822941952136, 0.9357814200793358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 187}], {
             RGBColor[
             0.30166406888411185`, 0.428995808686236, 0.9406885113479817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.22728280184896765`, 0.3562190136781822, 0.9362547913793006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 255}], {
             RGBColor[
             0.24682926108047093`, 0.37676358164758694`, 0.9373679333161395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 260}], {
             RGBColor[
             0.2740921498982324, 0.4051143982656095, 0.938931653051092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 292}], {
             RGBColor[
             0.2208755284929752, 0.34948456313643983`, 0.9358899066403883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 399}], {
             RGBColor[
             0.2698928088141382, 0.40100483262905684`, 0.9386813682401107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 446}], {
             RGBColor[
             0.21718653605083982`, 0.34560719818412555`, 0.9356798239781839]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 464}], {
             RGBColor[
             0.2582088050321171, 0.38872420384552575`, 0.9380159815096591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 481}], {
             RGBColor[
             0.2642710788962169, 0.3950960380470579, 0.9383612190378892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 496}], {
             RGBColor[
             0.22237308988837995`, 0.35105859511388676`, 0.9359751905464131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 120}], {
             RGBColor[
             0.1926435788239345, 0.319810994025283, 0.9342821388721632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 124}], {
             RGBColor[
             0.20441395972608956`, 0.3321824106387006, 0.9349524446518228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 363}], {
             RGBColor[
             0.19847969710316485`, 0.325945124368025, 0.934614497174402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 364}], {
             RGBColor[
             0.24538499784001913`, 0.3752455694102938, 0.9372856846611919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 381}], {
             RGBColor[
             0.21072511503524133`, 0.3388158350189773, 0.9353118556101614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 416}], {
             RGBColor[
             0.25584298681039175`, 0.38616481482489873`, 0.9378839159108214]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 124}], {
             RGBColor[
             0.1949045707787678, 0.32218743992498255`, 0.9344108990191531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 315}], {
             RGBColor[
             0.19068570408703148`, 0.3177531435403698, 0.9341706408023127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 363}], {
             RGBColor[
             0.1889703081558431, 0.31595015365430695`, 0.9340729515417323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 381}], {
             RGBColor[
             0.20121572608791957`, 0.32882086430525925`, 0.9347703099774917]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 196}], {
             RGBColor[
             0.263514639936199, 0.3943009727390789, 0.9383181409581673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.2855288778367985, 0.4174393325559085, 0.93957181923946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 307}], {
             RGBColor[
             0.263034036910473, 0.393795828487049, 0.9382907713268407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 337}], {
             RGBColor[
             0.25724680271789735`, 0.38771307841881125`, 0.9379611969010192]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 420}], {
             RGBColor[
             0.2550040005711073, 0.3853557511606656, 0.9378334726366879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 427}], {
             RGBColor[
             0.25170778098680857`, 0.3818912153851751, 0.937645757807682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 442}], {
             RGBColor[
             0.36944795676254, 0.4928528505313406, 0.9448192188256768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 447}], {
             RGBColor[
             0.3594348735345609, 0.4841800211114614, 0.9441811940166118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 454}], {
             RGBColor[
             0.3058588106164846, 0.437775128223043, 0.9407673746629241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 489}], {
             RGBColor[
             0.2627068012405983, 0.39345188305007095`, 0.9382721357395432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 500}], {
             RGBColor[
             0.28288233778375105`, 0.41465765115982456`, 0.9394211026986441]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 185}], {
             RGBColor[
             0.2643164513876104, 0.39404556499127835`, 0.9384040120398665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 212}], {
             RGBColor[
             0.1999697851673105, 0.32751130140048207`, 0.9346993554852674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 216}], {
             RGBColor[
             0.23867128343248623`, 0.3681890298938975, 0.9369033485577333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 217}], {
             RGBColor[
             0.19845501151425832`, 0.32591917824892747`, 0.9346130913666328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 224}], {
             RGBColor[
             0.25163511157756463`, 0.38181483522855314`, 0.9376416193923304]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 286}], {
             RGBColor[
             0.21170798349237516`, 0.3398488920848844, 0.9353678285147715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 319}], {
             RGBColor[
             0.19763752801393172`, 0.3250599512586367, 0.9345665368906477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 330}], {
             RGBColor[
             0.21641357139056538`, 0.344794763317387, 0.9356358047842801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 357}], {
             RGBColor[
             0.21418150641244568`, 0.34244872150428973`, 0.9355086919858204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 492}], {
             RGBColor[
             0.2013976738739365, 0.329012102964519, 0.9347806716347378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 139}], {
             RGBColor[
             0.20173923156575024`, 0.3293711017546237, 0.9348001228399971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 158}], {
             RGBColor[
             0.22135534676052232`, 0.3499888825578671, 0.9359172315808977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 193}], {
             RGBColor[
             0.19813056518650046`, 0.32557816458736866`, 0.9345946146282424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 401}], {
             RGBColor[
             0.1977072581497815, 0.3251332420525608, 0.9345705079187279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 410}], {
             RGBColor[
             0.20098281054011963`, 0.3285760552968229, 0.9347570457816121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 422}], {
             RGBColor[
             0.25330157722830876`, 0.3835663962875101, 0.9377365221458253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 428}], {
             RGBColor[
             0.21288413127934025`, 0.34108509798106146`, 0.9354348083912845]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 437}], {
             RGBColor[
             0.20027511058254266`, 0.32783221777064053`, 0.9347167433159764]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 363}], {
             RGBColor[
             0.20074068905799813`, 0.32832157026772446`, 0.934743257321392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 381}], {
             RGBColor[
             0.21298610699007461`, 0.34119228091867676`, 0.9354406157571513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 416}], {
             RGBColor[
             0.25810397876522506`, 0.3885412607245982, 0.9380126760578114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.8300337551067959, 0.23185817939204778`, 0.1763936638495297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 173}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 242}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 249}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 269}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 282}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 305}], {
             RGBColor[
             0.8321466499760604, 0.3869651660515732, 0.4383722111318248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 310}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 323}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 406}], {
             RGBColor[
             0.8761600890568056, 0.41916385235227993`, 0.29986098883365586`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 408}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 419}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 173}], {
             RGBColor[
             0.8563654629268306, 0.3487034608338446, 0.19818596167822738`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 249}], {
             RGBColor[
             0.8563654629268306, 0.3487034608338446, 0.19818596167822738`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 269}], {
             RGBColor[
             0.8563654629268306, 0.3487034608338446, 0.19818596167822738`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 282}], {
             RGBColor[
             0.8563654629268306, 0.3487034608338446, 0.19818596167822738`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 340}], {
             RGBColor[
             0.9580550382851865, 0.8818464109073033, 0.591032485493439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 384}], {
             RGBColor[
             0.784439054142597, 0.7459729584674704, 0.6152424378957748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 414}], {
             RGBColor[
             0.9638951205538232, 0.8830011069097463, 0.3908566728809145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 449}], {
             RGBColor[
             0.8563654629268306, 0.3487034608338446, 0.19818596167822738`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 499}], {
             RGBColor[
             0.8563654629268306, 0.3487034608338446, 0.19818596167822738`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 184}], {
             RGBColor[
             0.8369837657282427, 0.2665011316422593, 0.18231370738115665`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 221}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 253}], {
             RGBColor[
             0.8742585681452911, 0.4192055500614041, 0.39156282211394233`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 301}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 303}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 316}], {
             RGBColor[
             0.8735231410973765, 0.4108198428949215, 0.24276088847601782`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 138}], {
             RGBColor[
             0.22021896748197323`, 0.3487944758855043, 0.9358525164621068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 179}], {
             RGBColor[
             0.25756930059010474`, 0.38805204413004735`, 0.9379795626777485]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 222}], {
             RGBColor[
             0.2510869631489796, 0.3812386964754926, 0.9376104031502354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 245}], {
             RGBColor[
             0.3639482041295633, 0.48295335281971236`, 0.9448496084986262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 294}], {
             RGBColor[
             0.23038890902229686`, 0.35948372925592065`, 0.9364316795877479]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 296}], {
             RGBColor[
             0.21905420866091074`, 0.34757024051459295`, 0.9357861851703535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 312}], {
             RGBColor[
             0.2464921841409758, 0.3764092924122653, 0.937348737283096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 385}], {
             RGBColor[
             0.21760308488543836`, 0.34604501742001015`, 0.9357035458180856]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 415}], {
             RGBColor[
             0.215112556671643, 0.34342731435870205`, 0.9355617139207162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 438}], {
             RGBColor[
             0.26301778671971743`, 0.3937787485062433, 0.9382898459025171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 439}], {
             RGBColor[
             0.25567022753416335`, 0.38605599794006673`, 0.9378714132766395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 204}], {
             RGBColor[
             0.8203413302090085, 0.8600631926608293, 0.9825983689433555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 275}], {
             RGBColor[
             0.8469448752581116, 0.7933181891173926, 0.6210335543626414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 276}], {
             RGBColor[
             0.5454672677839978, 0.6367301066502977, 0.9595185145296392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 306}], {
             RGBColor[
             0.611794552731207, 0.6939125455037445, 0.9638185817259406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 331}], {
             RGBColor[
             0.7939675478085891, 0.839033454471987, 0.98008281403385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 346}], {
             RGBColor[
             0.871715025393385, 0.8835314226277342, 0.6825874912808683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 348}], {
             RGBColor[
             0.8615879645459554, 0.8493704684423902, 0.6432457722235755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 355}], {
             RGBColor[
             0.8246751523265887, 0.5626184933768341, 0.4602642940296072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 431}], {
             RGBColor[
             0.8769447835241505, 0.9005887953787303, 0.7525487545778835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 444}], {
             RGBColor[
             0.8208341223499612, 0.533094653826407, 0.4565861193861659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 486}], {
             RGBColor[
             0.8772725629513854, 0.9012898824300021, 0.7882255224122631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 175}], {
             RGBColor[
             0.9140005204519457, 0.9309753937832106, 0.859835968889188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 182}], {
             RGBColor[
             0.8938442105767532, 0.9177064381503486, 0.9729323850318632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 208}], {
             RGBColor[
             0.913099344561267, 0.9286383537262926, 0.7319810481348386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 238}], {
             RGBColor[
             0.8848677063670416, 0.8279729997302321, 0.6258750507442762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 241}], {
             RGBColor[
             0.5867161645318493, 0.6694746929690595, 0.9634263183495637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 351}], {
             RGBColor[
             0.6463531647474265, 0.72096106746608, 0.9672728087793628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 371}], {
             RGBColor[
             0.6899215836975872, 0.756331872704727, 0.9707026743154967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 442}], {
             RGBColor[
             0.6401413651407276, 0.7157489165078108, 0.9668305248903115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 483}], {
             RGBColor[
             0.9023076079882126, 0.8925450795893294, 0.6637151097464145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 186}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 234}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 373}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 434}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 449}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 495}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 250}], {
             RGBColor[
             0.5096842240418256, 0.610007296239153, 0.9554309033935169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 356}], {
             RGBColor[
             0.575775252833869, 0.6662108242154342, 0.9599298517837459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 365}], {
             RGBColor[
             0.47996279510956574`, 0.5834591273930367, 0.9535665537870656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 457}], {
             RGBColor[
             0.80832544399098, 0.8000236768742133, 0.6266376808278413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 494}], {
             RGBColor[
             0.8146351336717644, 0.855457320247522, 0.9517217188764132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 191}], {
             RGBColor[
             0.24509705427784428`, 0.37494292246977173`, 0.9372692867013004]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 237}], {
             RGBColor[
             0.3420181953123312, 0.46624628266428925`, 0.9431757084268175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 241}], {
             RGBColor[
             0.30061942099789657`, 0.430388745116024, 0.9405378151350005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 271}], {
             RGBColor[
             0.2827858451483628, 0.4145562312820451, 0.9394156075858068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 304}], {
             RGBColor[
             0.24533917292446922`, 0.3751974045185834, 0.9372830750000432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 311}], {
             RGBColor[
             0.24377892093012438`, 0.3735574807468368, 0.9371942209571512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 351}], {
             RGBColor[
             0.3602564212134738, 0.4818751196130445, 0.9443843055647996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 366}], {
             RGBColor[
             0.22778137278596647`, 0.35674304334419116`, 0.9362831842565931]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 371}], {
             RGBColor[
             0.4038248401636344, 0.5172459248516914, 0.9478141711009334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 405}], {
             RGBColor[
             0.22584814988303165`, 0.3547111034997951, 0.9361730900722178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 423}], {
             RGBColor[
             0.22055140940715506`, 0.3491438934269059, 0.935871448537942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 429}], {
             RGBColor[
             0.24801000575022464`, 0.37800461915903416`, 0.9374351749783268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 469}], {
             RGBColor[
             0.2251876288090195, 0.3540168539715534, 0.9361354743742063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 488}], {
             RGBColor[
             0.22772081169529612`, 0.3566793897981017, 0.9362797353920715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 174}], {
             RGBColor[
             0.2085506805802597, 0.33653036653968427`, 0.9351880247847377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 210}], {
             RGBColor[
             0.22588078399928613`, 0.3547454040251011, 0.9361749485368607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 225}], {
             RGBColor[
             0.20098661279686494`, 0.32858005170973914`, 0.9347572623145088]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 247}], {
             RGBColor[
             0.20166327316729094`, 0.3292912646618023, 0.9347957971215752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 252}], {
             RGBColor[
             0.19741515137734375`, 0.3248262193140896, 0.9345538728701708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 278}], {
             RGBColor[
             0.20206125527400282`, 0.32970956908947946`, 0.9348184616137908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 309}], {
             RGBColor[
             0.2100987137423066, 0.33815744754396704`, 0.9352761829832064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 424}], {
             RGBColor[
             0.2214617006289249, 0.3501006672167829, 0.9359232882763666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 169}], {
             RGBColor[
             0.19175100981754287`, 0.3188728474074218, 0.9342313083876868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 211}], {
             RGBColor[
             0.19965674481685908`, 0.3271822761442531, 0.9346815283004108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 362}], {
             RGBColor[
             0.18189649677046751`, 0.30851512938273096`, 0.9336701084481014]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 369}], {
             RGBColor[
             0.18790542144841682`, 0.3148308902070851, 0.9340123078191032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 466}], {
             RGBColor[
             0.21560127706368337`, 0.34394099047739907`, 0.935589545824046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 470}], {
             RGBColor[
             0.21501465509276277`, 0.3433244135919803, 0.9355561385706315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 240}], {
             RGBColor[
             0.8413736303622167, 0.28643448166620133`, 0.18597671803717333`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 434}], {
             RGBColor[
             0.8413736303622167, 0.28643448166620133`, 0.18597671803717333`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 148}], {
             RGBColor[
             0.4973694977090155, 0.5987599555327824, 0.9548921028341959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 156}], {
             RGBColor[
             0.29413333822792154`, 0.4253340674905862, 0.9401039046543183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 227}], {
             RGBColor[
             0.2807026852952867, 0.41121759970580773`, 0.9393390488386753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 229}], {
             RGBColor[
             0.3767837963714482, 0.5007729195378712, 0.9452293082213277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 263}], {
             RGBColor[
             0.3515933537073658, 0.478954224210705, 0.9436241954898061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 265}], {
             RGBColor[
             0.26167159806531437`, 0.3912147203864842, 0.9382552565748988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 267}], {
             RGBColor[
             0.3633910087702312, 0.4891727600587743, 0.9443759316381551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 280}], {
             RGBColor[
             0.43200376365867066`, 0.5461711365359171, 0.9494194420439965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 393}], {
             RGBColor[
             0.3443442466033714, 0.47267541198794205`, 0.9431622887952733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 424}], {
             RGBColor[
             0.2813766900403703, 0.41192602142725965`, 0.939377432411807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 485}], {
             RGBColor[
             0.43787204087877396`, 0.550935268346073, 0.9498814143229708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 179}], {
             RGBColor[
             0.23283128712735746`, 0.36205082350005524`, 0.9365707694076565]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 222}], {
             RGBColor[
             0.22634894968623231`, 0.35523747584550047`, 0.9362016098801433]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 294}], {
             RGBColor[
             0.20565089555954957`, 0.33348250862592854`, 0.9350228863176557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 296}], {
             RGBColor[
             0.19431619519816343`, 0.32156901988460085`, 0.9343773919002614]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 339}], {
             RGBColor[
             0.1899160305473181, 0.31694416785001006`, 0.934126809032856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 385}], {
             RGBColor[
             0.19286507142269105`, 0.32004379679001804`, 0.9342947525479934]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 415}], {
             RGBColor[
             0.19037454320889569`, 0.31742609372870995`, 0.934152920650624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 438}], {
             RGBColor[
             0.23827977325697014`, 0.3677775278762512, 0.936881052632425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 158}], {
             RGBColor[
             0.2143619533681344, 0.34263838269571634`, 0.9355189681729995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 247}], {
             RGBColor[
             0.19836393844048342`, 0.3258234546740237, 0.9346079048898119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 278}], {
             RGBColor[
             0.19876192054719527`, 0.32624175910170083`, 0.9346305693820274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 401}], {
             RGBColor[
             0.19071386475739358`, 0.31778274219041003`, 0.9341722445108298]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 410}], {
             RGBColor[
             0.1939894171477317, 0.3212255554346721, 0.9343587823737141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 428}], {
             RGBColor[
             0.20589073788695234`, 0.3337345981189107, 0.9350365449833864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 437}], {
             RGBColor[
             0.19328171719015474`, 0.3204817179084898, 0.9343184799080784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 451}], {
             RGBColor[
             0.24317792529434393`, 0.37292579622830746`, 0.9371599951447869]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 198}], {
             RGBColor[
             0.18662011133920806`, 0.3134799477889389, 0.9339391113098297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 270}], {
             RGBColor[
             0.18167152053006663`, 0.3082786650897521, 0.933657296384033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 479}], {
             RGBColor[
             0.1864188505172612, 0.31326840990439964`, 0.9339276498037584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 151}], {
             RGBColor[
             0.29343798324110804`, 0.42575230380208373`, 0.9400222310917625]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 160}], {
             RGBColor[
             0.37802184945379874`, 0.5011040622114881, 0.9453453778817297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 162}], {
             RGBColor[
             0.24952923123188117`, 0.3796014214647141, 0.9375216926220145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 167}], {
             RGBColor[
             0.3793212150967632, 0.5021589457762018, 0.945447668704877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 235}], {
             RGBColor[
             0.3242794390168753, 0.4545969884680785, 0.9419093816387205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 274}], {
             RGBColor[
             0.39256014440333986`, 0.5129069049942494, 0.9464898857156867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 284}], {
             RGBColor[
             0.3001512154255292, 0.4328083364714148, 0.9404045397333283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 300}], {
             RGBColor[
             0.3596463325015217, 0.4852300140127269, 0.9441629288178462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 345}], {
             RGBColor[
             0.26571464212222085`, 0.3966133145247829, 0.9384434278280497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 389}], {
             RGBColor[
             0.27450272226024985`, 0.40585014394631425`, 0.9389438959911109]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 432}], {
             RGBColor[
             0.5362845883584992, 0.627612344125192, 0.9591557710589778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 456}], {
             RGBColor[
             0.2759889604791371, 0.40741227454731044`, 0.9390285350589842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 472}], {
             RGBColor[
             0.2491195605244581, 0.3791708315765894, 0.9374983624812803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[
             0.3397907487213136, 0.46873140098796173`, 0.9428721439367287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 161}], {
             RGBColor[
             0.33616922788314596`, 0.46559462166087084`, 0.9426413838313057]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 183}], {
             RGBColor[
             0.2986301457506506, 0.42826119735656343`, 0.940425872375729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 254}], {
             RGBColor[
             0.28886221876631657`, 0.41799448677368717`, 0.9398696033843243]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 285}], {
             RGBColor[
             0.3374576097099063, 0.46671055324325716`, 0.9427234783820356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 388}], {
             RGBColor[
             0.6324778710852315, 0.7059774833485709, 0.9677848279671616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 396}], {
             RGBColor[
             0.2996502424735361, 0.4293333836901839, 0.9404839653749997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 473}], {
             RGBColor[
             0.4734736299079191, 0.580366653206442, 0.9525381002758618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 477}], {
             RGBColor[
             0.3004155181766316, 0.43013773697541924`, 0.9405275466941669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 165}], {
             RGBColor[
             0.8397048936039028, 0.4842390340274436, 0.4505134128142734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 178}], {
             RGBColor[
             0.8770300475453819, 0.4797787542910352, 0.21761304086744773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 186}], {
             RGBColor[
             0.8305642118064, 0.2359355020328133, 0.17690162978413582`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 277}], {
             RGBColor[
             0.8851303930784559, 0.5071031218256719, 0.24908135364154116`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 288}], {
             RGBColor[
             0.8305642118064, 0.2359355020328133, 0.17690162978413582`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 313}], {
             RGBColor[
             0.8841027954583874, 0.5189146200022339, 0.4295739266106804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 321}], {
             RGBColor[
             0.8305642118064, 0.2359355020328133, 0.17690162978413582`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 373}], {
             RGBColor[
             0.8305642118064, 0.2359355020328133, 0.17690162978413582`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 386}], {
             RGBColor[
             0.8392900578031888, 0.4839082552203721, 0.450473845405273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 414}], {
             RGBColor[
             0.8892351625821182, 0.5206084458054662, 0.2940261166931848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 498}], {
             RGBColor[
             0.8305642118064, 0.2359355020328133, 0.17690162978413582`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 145}], {
             RGBColor[
             0.28245593278256786`, 0.4142094724679425, 0.9393968195646363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 215}], {
             RGBColor[
             0.23058979905714602`, 0.35969487741971096`, 0.9364431199780423]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 246}], {
             RGBColor[
             0.35696945876019426`, 0.4786389058672158, 0.9441772202942458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 375}], {
             RGBColor[
             0.2688835490281597, 0.3999440366032271, 0.9386238923883652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 402}], {
             RGBColor[
             0.3042407743951998, 0.43308654496933563`, 0.9407846324499517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 417}], {
             RGBColor[
             0.256797636184088, 0.38724097591297457`, 0.9379356175314011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 458}], {
             RGBColor[
             0.35435270940186414`, 0.4764909843730204, 0.9439777206363321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 367}], {
             RGBColor[
             0.2830394326624652, 0.4148227678377437, 0.9394300490195857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 375}], {
             RGBColor[
             0.29508560074384793`, 0.4274840542624467, 0.9401160604711118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 402}], {
             RGBColor[
             0.33044282611088804`, 0.46062656262855517`, 0.9422768005326982]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 417}], {
             RGBColor[
             0.28299968789977625`, 0.4147809935721941, 0.9394277856141477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 450}], {
             RGBColor[
             0.32420026945735514`, 0.45521957381528544`, 0.9418790303428113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 458}], {
             RGBColor[
             0.3805547611175523, 0.5040310020322399, 0.9454698887190787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 461}], {
             RGBColor[
             0.42511156853211396`, 0.5402277520345683, 0.9489710633786737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 166}], {
             RGBColor[
             0.217481006477988, 0.34591670527356166`, 0.9356965936333801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 239}], {
             RGBColor[
             0.21955415616402918`, 0.348095717038873, 0.93581465644105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 248}], {
             RGBColor[
             0.18429425645727748`, 0.31103532684031304`, 0.9338066573150976]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 387}], {
             RGBColor[
             0.20285490882715684`, 0.330543749294386, 0.9348636590095377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 221}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 234}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 242}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 303}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 323}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 449}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 229}], {
             RGBColor[
             0.5529788076305955, 0.64692594478167, 0.958435478889017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 232}], {
             RGBColor[
             0.6848339419914155, 0.7537167475052093, 0.9692215052668037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 263}], {
             RGBColor[
             0.527788364966513, 0.6251072494545038, 0.9568303661574955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 267}], {
             RGBColor[
             0.5395860200293785, 0.6353257853025731, 0.9575821023058444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 280}], {
             RGBColor[
             0.6081987749178179, 0.6923241617797158, 0.9626256127116859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 342}], {
             RGBColor[
             0.8111690714652371, 0.789762270075679, 0.6228692704159253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 393}], {
             RGBColor[
             0.5205392578625186, 0.6188284372317407, 0.9563684594629627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 480}], {
             RGBColor[
             0.576482916411845, 0.6665757990614235, 0.9601288241510779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 485}], {
             RGBColor[
             0.6140670521379212, 0.6970882935898717, 0.9630875849906602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 173}], {
             RGBColor[
             0.8427485102135918, 0.3295893587840956, 0.1885693276990594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 242}], {
             RGBColor[
             0.8427485102135918, 0.3295893587840956, 0.1885693276990594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 249}], {
             RGBColor[
             0.8427485102135918, 0.3295893587840956, 0.1885693276990594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 269}], {
             RGBColor[
             0.8427485102135918, 0.3295893587840956, 0.1885693276990594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 282}], {
             RGBColor[
             0.8427485102135918, 0.3295893587840956, 0.1885693276990594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 310}], {
             RGBColor[
             0.8427485102135918, 0.3295893587840956, 0.1885693276990594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 314}], {
             RGBColor[
             0.7707695331053225, 0.5139697191710294, 0.454417376319948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 323}], {
             RGBColor[
             0.8427485102135918, 0.3295893587840956, 0.1885693276990594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 406}], {
             RGBColor[
             0.9015895992703974, 0.6146262111363756, 0.3242123165327152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 411}], {
             RGBColor[
             0.8077452715809664, 0.5432739233115719, 0.4578166578979691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 419}], {
             RGBColor[
             0.8427485102135918, 0.3295893587840956, 0.1885693276990594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 220}], {
             RGBColor[
             0.34295836521931666`, 0.47147503118949763`, 0.9430739816589682]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 254}], {
             RGBColor[
             0.2880175076881252, 0.41726284049417106`, 0.9398157791413707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 325}], {
             RGBColor[
             0.38277885144144796`, 0.5059655349192759, 0.945611307829169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 392}], {
             RGBColor[
             0.39049019037477983`, 0.5126447091201637, 0.9461026675271316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 412}], {
             RGBColor[
             0.2833356085457537, 0.41234186764598774`, 0.9395491519114617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 426}], {
             RGBColor[
             0.27709250902946053`, 0.4057799742189919, 0.9391936166298469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 473}], {
             RGBColor[
             0.4726289188297277, 0.5796350069269258, 0.9524842760329082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 160}], {
             RGBColor[
             0.37027731562653565`, 0.4929640661272292, 0.9449043381372781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 162}], {
             RGBColor[
             0.24178469740461808`, 0.3714614253804553, 0.9370806528775629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 226}], {
             RGBColor[
             0.24965370060264616`, 0.379732246665202, 0.9375287809685435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 235}], {
             RGBColor[
             0.31653490518961214`, 0.44645699238381964`, 0.941468341894269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 237}], {
             RGBColor[
             0.3543647938987703, 0.4792233405982007, 0.9438788289511594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 274}], {
             RGBColor[
             0.3848156105760768, 0.5047669089099905, 0.9460488459712351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 284}], {
             RGBColor[
             0.2924066815982661, 0.42466834038715606`, 0.9399634999888766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 345}], {
             RGBColor[
             0.2579701082949577, 0.388473318440524, 0.9380023880835981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 389}], {
             RGBColor[
             0.26675818843298676`, 0.3977101478620555, 0.9385028562466593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 456}], {
             RGBColor[
             0.268244426651874, 0.3992722784630517, 0.9385874953145326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 472}], {
             RGBColor[
             0.24137502669719502`, 0.37103083549233057`, 0.9370573227368286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 195}], {
             RGBColor[
             0.21010530872100186`, 0.3381643792847215, 0.9352765585574867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 216}], {
             RGBColor[
             0.23556313755144892`, 0.3649221715050963, 0.9367263442478979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 217}], {
             RGBColor[
             0.19534686563322098`, 0.3226523198601263, 0.9344360870567976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 292}], {
             RGBColor[
             0.20369803536500936`, 0.33142992874297905`, 0.9349116738185744]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 398}], {
             RGBColor[
             0.24922661523815437`, 0.3792833528683451, 0.9375044590888519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 399}], {
             RGBColor[
             0.2527153156861724, 0.38295019823559606`, 0.9377031354182968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 464}], {
             RGBColor[
             0.24103131190415128`, 0.37066956945206503`, 0.9370377486878454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 481}], {
             RGBColor[
             0.24709358576825113`, 0.3770414036535972, 0.9373829862160753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 496}], {
             RGBColor[
             0.2051955967604141, 0.33300396072042604`, 0.9349969577245991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 172}], {
             RGBColor[
             0.38789541628795154`, 0.5103972462232906, 0.9459373308167875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 197}], {
             RGBColor[
             0.4056482253886383, 0.5257738371841758, 0.9470685241144907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 201}], {
             RGBColor[
             0.4828110574856316, 0.5895003637293261, 0.9528440323387535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 223}], {
             RGBColor[
             0.3513959068247321, 0.4784326496880068, 0.9436244499198642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 236}], {
             RGBColor[
             0.3517722114098828, 0.47882816966608893`, 0.9436458799092957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 289}], {
             RGBColor[
             0.3557095315743413, 0.48251945059396417`, 0.9438864747036967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 314}], {
             RGBColor[
             0.499609722940791, 0.6031382771170792, 0.9541664848189226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 411}], {
             RGBColor[
             0.5550733306542569, 0.6470945833278928, 0.9592654071859543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 466}], {
             RGBColor[
             0.32275440531108784`, 0.44832861562108495`, 0.9419933587799665]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 470}], {
             RGBColor[
             0.32216778334016727`, 0.44771203873566623`, 0.941959951526552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 493}], {
             RGBColor[
             0.4936405223165552, 0.5982922111409009, 0.9536965674798805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 199}], {
             RGBColor[
             0.8752103907398564, 0.4195991531649818, 0.3757886584840803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 219}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 244}], {
             RGBColor[
             0.8706168078338911, 0.40101609835768304`, 0.23147033256236077`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 295}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 341}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 374}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 376}], {
             RGBColor[
             0.8735554698238286, 0.4189148008366767, 0.4032149808607035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 397}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 455}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 198}], {
             RGBColor[
             0.21872927125490338`, 0.3472287106986578, 0.9357676804657832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 250}], {
             RGBColor[
             0.3015021013571373, 0.4295372658275264, 0.9406532288863496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 365}], {
             RGBColor[
             0.2717806724248775, 0.40298909698141017`, 0.9387888792798984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 394}], {
             RGBColor[
             0.22097523638302924`, 0.34958936245073197`, 0.9358955848572224]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 467}], {
             RGBColor[
             0.2375425676300431, 0.36700267802081454`, 0.9368390698625695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 479}], {
             RGBColor[
             0.2185280104329565, 0.3470171728141185, 0.935756218959712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 198}], {
             RGBColor[
             0.23051452206007278`, 0.35961575652294975`, 0.9364388330644213]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 227}], {
             RGBColor[
             0.2536615370733401, 0.3839447369074104, 0.937757021326487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 250}], {
             RGBColor[
             0.3132873521623067, 0.4419243116518183, 0.9413243814849879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 263}], {
             RGBColor[
             0.3245522054854192, 0.45168136141230764`, 0.9420421679776179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 270}], {
             RGBColor[
             0.22556593125093138`, 0.35441447382376295`, 0.9361570181386248]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 479}], {
             RGBColor[
             0.23031326123812593`, 0.35940421863841043`, 0.9364273715583502]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 485}], {
             RGBColor[
             0.4108308926568273, 0.5236624055476755, 0.9482993868107825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 190}], {
             RGBColor[
             0.5811750262089507, 0.6652253629216612, 0.9628235461914189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 356}], {
             RGBColor[
             0.6546957163401086, 0.7278640901242467, 0.9677959060323847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 360}], {
             RGBColor[
             0.821018879012048, 0.40265646105823816`, 0.44038049549212843`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.3108236109603984, 0.4367287160722685, 0.9412794952284302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 193}], {
             RGBColor[
             0.21075328698888462`, 0.3388454455284614, 0.9353134599612447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 247}], {
             RGBColor[
             0.2179800536352555, 0.34644123547726713`, 0.9357250136307124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 278}], {
             RGBColor[
             0.21837803574196735`, 0.3468595399049442, 0.9357476781229279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 370}], {
             RGBColor[
             0.31860057599581953`, 0.44346473230432215`, 0.9417750365635871]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 401}], {
             RGBColor[
             0.21032997995216565`, 0.3384005229936534, 0.9352893532517302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 410}], {
             RGBColor[
             0.2136055323425038, 0.3418433362379155, 0.9354758911146145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 422}], {
             RGBColor[
             0.2659242990306929, 0.3968336772286028, 0.9384553674788276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 428}], {
             RGBColor[
             0.2255068530817244, 0.3543523789221541, 0.9361536537242868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 437}], {
             RGBColor[
             0.21289783238492682`, 0.3410994987117332, 0.9354355886489787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 451}], {
             RGBColor[
             0.26279404048911603`, 0.39354357703155085`, 0.9382771038856873]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 166}], {
             RGBColor[
             0.3352108410982161, 0.45943457954147626`, 0.9427754713265473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 192}], {
             RGBColor[
             0.6447596298856625, 0.718476583875131, 0.9677105713215501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 239}], {
             RGBColor[
             0.33728399078425725`, 0.4616135913067876, 0.9428935341342171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 251}], {
             RGBColor[
             0.43566646967110545`, 0.5517741316208221, 0.9489812600960783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 272}], {
             RGBColor[
             0.4928488984890493, 0.5982329341630651, 0.953473053095963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 344}], {
             RGBColor[
             0.32356779326194895`, 0.4471969980536896, 0.9421124169766175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 435}], {
             RGBColor[
             0.4343916682734087, 0.5506699627235185, 0.9489000308782796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 439}], {
             RGBColor[
             0.3428534925670518, 0.4674674908073133, 0.9432107090214077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 453}], {
             RGBColor[
             0.4386026872571061, 0.5541934161210065, 0.9492025926373653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 167}], {
             RGBColor[
             0.4561605474821908, 0.5693707081013473, 0.9503297757503926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 235}], {
             RGBColor[
             0.4011187714023029, 0.521808750793224, 0.9467914886842361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 237}], {
             RGBColor[
             0.43894866011146105`, 0.554575099007605, 0.9492019757411265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 274}], {
             RGBColor[
             0.4693994767887675, 0.5801186673193949, 0.9513719927612023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 284}], {
             RGBColor[
             0.3769905478109568, 0.5000200987965604, 0.9452866467788439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 300}], {
             RGBColor[
             0.43648566488694934`, 0.5524417763378724, 0.9490450358633619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 305}], {
             RGBColor[
             0.6583315658837037, 0.7304786613456766, 0.96845405916136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 389}], {
             RGBColor[
             0.35134205464567747`, 0.4730619062714598, 0.9438260030366266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 432}], {
             RGBColor[
             0.6131239207439269, 0.6948241064503374, 0.9640378781044934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 460}], {
             RGBColor[
             0.6397166588695635, 0.7156356397807915, 0.9666785527126276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 183}], {
             RGBColor[
             0.29416391383429163`, 0.4243927717499564, 0.9401412880273525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 188}], {
             RGBColor[
             0.35599050426396195`, 0.4827628150156156, 0.9439043780350249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 202}], {
             RGBColor[
             0.27218576478809153`, 0.40129234360726607`, 0.9388896649529292]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 243}], {
             RGBColor[
             0.29333367126304843`, 0.4235201341671604, 0.9400940069411541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 273}], {
             RGBColor[
             0.2730441392759877, 0.4021945496181309, 0.9389385481101638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 279}], {
             RGBColor[
             0.317893858956114, 0.449334448638412, 0.9414926732967325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 285}], {
             RGBColor[
             0.33299137779354726`, 0.4628421276366501, 0.942438894033659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 287}], {
             RGBColor[
             0.5848187798365858, 0.6676682441493317, 0.9633804701369508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 335}], {
             RGBColor[
             0.32336695487389533`, 0.45450593624120883`, 0.9418256343157618]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 354}], {
             RGBColor[
             0.5968095021678761, 0.6772293206568155, 0.9645241559371533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 396}], {
             RGBColor[
             0.29518401055717713`, 0.42546495808357687`, 0.940199381026623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 409}], {
             RGBColor[
             0.4365148251401427, 0.5501192931853284, 0.9496955815684055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 430}], {
             RGBColor[
             0.3040526283510779, 0.4347864376878118, 0.9407044356900414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 459}], {
             RGBColor[
             0.2888122033466731, 0.4187677847094263, 0.9398365160322288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 477}], {
             RGBColor[
             0.29594928626027256`, 0.4262693113688122, 0.9402429623457904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 226}], {
             RGBColor[
             0.2057449485934193, 0.33358136432783236`, 0.9350282424987957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 284}], {
             RGBColor[
             0.24849792958903924`, 0.3785174580497864, 0.9374629615191288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 345}], {
             RGBColor[
             0.21406135628573086`, 0.3423224361031544, 0.9355018496138501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 389}], {
             RGBColor[
             0.2228494364237599, 0.35155926552468586`, 0.9360023177769115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 456}], {
             RGBColor[
             0.22433567464264714`, 0.35312139612568205`, 0.9360869568447846]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 472}], {
             RGBColor[
             0.19746627468796812`, 0.32487995315496093`, 0.9345567842670808]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 207}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 209}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 231}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 233}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 266}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 317}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 326}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 343}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 355}], {
             RGBColor[
             0.8304768118928137, 0.23526370799810264`, 0.17681793552818148`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 379}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 440}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 180}], {
             RGBColor[
             0.7420798659697871, 0.7983328217384686, 0.9752041209037695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 205}], {
             RGBColor[
             0.6628616176318347, 0.7337956536330927, 0.9690297243445348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 259}], {
             RGBColor[
             0.8384337610731512, 0.3919783377813091, 0.43897188140083576`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 316}], {
             RGBColor[
             0.9332973532557916, 0.9359432710143458, 0.6941631548152802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 331}], {
             RGBColor[
             0.854078896606874, 0.8864833450730073, 0.9859440016752372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 348}], {
             RGBColor[
             0.9216993133442403, 0.8968203590434105, 0.6491069598649626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 372}], {
             RGBColor[
             0.8384337610731512, 0.3919783377813091, 0.43897188140083576`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 404}], {
             RGBColor[
             0.8384337610731512, 0.3919783377813091, 0.43897188140083576`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 418}], {
             RGBColor[
             0.9146050965365867, 0.8706968435897349, 0.6329687419964006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 431}], {
             RGBColor[
             0.9370561323224353, 0.9480386859797506, 0.7584099422192706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 444}], {
             RGBColor[
             0.8609083548821511, 0.5647279142270871, 0.4604935778137573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 486}], {
             RGBColor[
             0.9373839117496703, 0.9487397730310224, 0.7940867100536502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 178}], {
             RGBColor[
             0.9007287763047269, 0.8723471763792785, 0.6357027911701743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 185}], {
             RGBColor[
             0.5826823072651669, 0.6655836746935463, 0.9633520886464765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 277}], {
             RGBColor[
             0.9128792946043378, 0.9133337276812334, 0.6829052603313144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 288}], {
             RGBColor[
             0.8264596817975027, 0.3824305319946304, 0.43782978303013764`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 313}], {
             RGBColor[
             0.9113378981742353, 0.9310509749460764, 0.9536441197850233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 333}], {
             RGBColor[
             0.6312455916187752, 0.707646750738999, 0.9664464981826622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 358}], {
             RGBColor[
             0.614683480338821, 0.6933014823842196, 0.9653911750972035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 361}], {
             RGBColor[
             0.6271981599055898, 0.7041410688188706, 0.9661885994129014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 386}], {
             RGBColor[
             0.8441187916914372, 0.8785414277732838, 0.9849939979769122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 498}], {
             RGBColor[
             0.8264596817975027, 0.3824305319946304, 0.43782978303013764`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.2531713208719759, 0.3834294885982743, 0.9377291042390291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 344}], {
             RGBColor[
             0.23945512334966762`, 0.36901289534517634`, 0.9369479870814295]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 387}], {
             RGBColor[
             0.2364720735351036, 0.36587752085378733`, 0.9367781068075168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 435}], {
             RGBColor[
             0.3502789983611274, 0.4724858600150052, 0.9437356009830916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 439}], {
             RGBColor[
             0.2587408226547705, 0.38928338809880003`, 0.9380462791262197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 453}], {
             RGBColor[
             0.35449001734482477`, 0.47600931341249325`, 0.9440381627421772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 172}], {
             RGBColor[
             0.41770668424733426`, 0.5361058055196428, 0.9478679522159678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[
             0.5126223254450143, 0.6152089230256782, 0.9547746537379336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 218}], {
             RGBColor[
             0.5986386322553329, 0.683547898239663, 0.9625669021197863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 235}], {
             RGBColor[
             0.40241813704526735`, 0.5228636343579377, 0.9468937795073835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 236}], {
             RGBColor[
             0.3815834793692655, 0.504536728962441, 0.9455765013084759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 274}], {
             RGBColor[
             0.470698842431732, 0.5811735508841086, 0.9514742835843497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 284}], {
             RGBColor[
             0.37828991345392127`, 0.5010749823612741, 0.9453889376019913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 289}], {
             RGBColor[
             0.38552079953372403`, 0.5082280098903162, 0.9458170961028769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 300}], {
             RGBColor[
             0.4377850305299138, 0.5534966599025861, 0.9491473266865091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 305}], {
             RGBColor[
             0.6596309315266682, 0.7315335449103904, 0.9685563499845072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 432}], {
             RGBColor[
             0.6144232863868914, 0.6958789900150512, 0.9641401689276407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 456}], {
             RGBColor[
             0.3541276585075292, 0.4756789204371697, 0.9440129329276471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 493}], {
             RGBColor[
             0.5234517902759379, 0.624000770437253, 0.9556271888790606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 181}], {
             RGBColor[
             0.5838876467268811, 0.6691726907027558, 0.9623201305737528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 189}], {
             RGBColor[
             0.6567597608942148, 0.7301160759368894, 0.967564374725217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 232}], {
             RGBColor[
             0.7381047575552699, 0.7953323134968859, 0.9745310423181337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 280}], {
             RGBColor[
             0.6614695904816725, 0.7339397277713925, 0.9679351497630158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 302}], {
             RGBColor[
             0.6341435577721554, 0.7117552233940616, 0.9657839443695666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 326}], {
             RGBColor[
             0.8049147133652906, 0.36546603758664487`, 0.4357177825348484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 338}], {
             RGBColor[
             0.8866500342923964, 0.9079974694670752, 0.7396483248536112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 346}], {
             RGBColor[
             0.8815478026298791, 0.8912128629367583, 0.6835675306232744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 370}], {
             RGBColor[
             0.5916646117623022, 0.6759087069348095, 0.9628156719089096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 383}], {
             RGBColor[
             0.7063203821054702, 0.7703516209167286, 0.9714659683735043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 390}], {
             RGBColor[
             0.6691221372064833, 0.7401524099458952, 0.9685375862733951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 395}], {
             RGBColor[
             0.84803720063224, 0.7663466503750598, 0.6149808209718142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 443}], {
             RGBColor[
             0.7657377612685392, 0.8169194260162985, 0.9772852418831708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 480}], {
             RGBColor[
             0.6297537319756995, 0.7081913650531002, 0.9654383612024078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 211}], {
             RGBColor[
             0.20787663392282102`, 0.33582190076568974`, 0.9351496388247592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 236}], {
             RGBColor[
             0.2528389722684402, 0.38308016914383974`, 0.9377101774777234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 289}], {
             RGBColor[
             0.2567762924328988, 0.386771450071715, 0.9379507722721243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 308}], {
             RGBColor[
             0.2152452595664099, 0.34356679351495156`, 0.9355692711542569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 362}], {
             RGBColor[
             0.19011638587642943`, 0.3171547540041677, 0.9341382189724496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 369}], {
             RGBColor[
             0.1961253105543787, 0.32347051482852174`, 0.9344804183434514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 456}], {
             RGBColor[
             0.22538315140670392`, 0.35422236061856843`, 0.9361466090968946]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 470}], {
             RGBColor[
             0.22323454419872468`, 0.35196403821341704`, 0.9360242490949797]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 214}], {
             RGBColor[
             0.2164586672192998, 0.34484216189262756`, 0.9356383729250132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 223}], {
             RGBColor[
             0.26091102585046255`, 0.3915644092563023, 0.9381698689876865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 268}], {
             RGBColor[
             0.21378017372291278`, 0.34202689540162845`, 0.93548583668287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 466}], {
             RGBColor[
             0.23226952433681827`, 0.36146037518938046`, 0.9365387778477888]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 491}], {
             RGBColor[
             0.20371206300908717`, 0.33144467268630884`, 0.9349124726721527]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 192}], {
             RGBColor[
             0.9127961865391916, 0.8801019973264443, 0.6352252611263622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 208}], {
             RGBColor[
             0.9742007870656089, 0.924158064524564, 0.38148971018664135`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 219}], {
             RGBColor[
             0.8633448747725185, 0.37637450305087206`, 0.2038017602771198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 238}], {
             RGBColor[
             0.9459691488713833, 0.8234927105285037, 0.27538371279607904`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 258}], {
             RGBColor[
             0.9746741511548784, 0.925170542447061, 0.43301247003911714`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 272}], {
             RGBColor[
             0.7608854551425784, 0.7598583476143784, 0.6209877429007751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 293}], {
             RGBColor[
             0.8633448747725185, 0.37637450305087206`, 0.2038017602771198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 403}], {
             RGBColor[
             0.8633448747725185, 0.37637450305087206`, 0.2038017602771198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 471}], {
             RGBColor[
             0.8633448747725185, 0.37637450305087206`, 0.2038017602771198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 497}], {
             RGBColor[
             0.9509833426511693, 0.843372317984329, 0.27941825080954996`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 197}], {
             RGBColor[
             0.39570626447019996`, 0.5171626103341097, 0.9464350311560986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 201}], {
             RGBColor[
             0.4728690965671932, 0.5808891368792599, 0.9522105393803614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 211}], {
             RGBColor[
             0.29686791214582525`, 0.42295867443787283`, 0.9404518482979395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 218}], {
             RGBColor[
             0.5588854033775118, 0.6492281120932448, 0.9600027877622141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 235}], {
             RGBColor[
             0.36266490816744634`, 0.48854384821151947`, 0.9443296651498113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 236}], {
             RGBColor[
             0.34183025049144444`, 0.4702169428160228, 0.9430123869509037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 289}], {
             RGBColor[
             0.345767570655903, 0.47390822374389807`, 0.9432529817453046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 300}], {
             RGBColor[
             0.3980318016520928, 0.519176873756168, 0.946583212328937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 308}], {
             RGBColor[
             0.3042365377894142, 0.4307035671871346, 0.9408714806274372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 314}], {
             RGBColor[
             0.4896677620223526, 0.594527050267013, 0.9535329918605306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 466}], {
             RGBColor[
             0.31281244439264955`, 0.4397173887710188, 0.9413598658215745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 470}], {
             RGBColor[0.3122258224217289, 0.4391008118856, 0.94132645856816]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 493}], {
             RGBColor[
             0.48369856139811684`, 0.5896809842908348, 0.9530630745214885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 242}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 249}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 269}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 282}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 310}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 323}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 406}], {
             RGBColor[
             0.8761600890568056, 0.41916385235227993`, 0.29986098883365586`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 419}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 499}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 210}], {
             RGBColor[
             0.23308695695256842`, 0.3623195486967552, 0.9365853294259726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 225}], {
             RGBColor[
             0.20819278575014724`, 0.33615419638139327`, 0.9351676432036207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 252}], {
             RGBColor[
             0.20462132433062605`, 0.3324003639857437, 0.9349642537592827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 309}], {
             RGBColor[
             0.2173048866955889, 0.3457315922156211, 0.9356865638723183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 320}], {
             RGBColor[
             0.20210480252735952`, 0.3297553400138127, 0.934820941565447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 393}], {
             RGBColor[
             0.29163543014520826`, 0.4184242024491195, 0.9401185255489448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 424}], {
             RGBColor[
             0.2286678735822072, 0.357674811888437, 0.9363336691654786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 182}], {
             RGBColor[
             0.9746509917198269, 0.978851744377486, 0.8488163971932976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 208}], {
             RGBColor[
             0.9939061257043407, 0.9897836599534299, 0.6078650602962729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 351}], {
             RGBColor[
             0.7271599458905001, 0.7821063736932174, 0.8431568209407971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 359}], {
             RGBColor[
             0.8764817671983398, 0.4201249000034494, 0.35471866035020744`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 371}], {
             RGBColor[
             0.7707283648406607, 0.8174771789318643, 0.846586686476931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 463}], {
             RGBColor[
             0.9058410813145757, 0.6396007349493169, 0.38259068137142616`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 483}], {
             RGBColor[
             0.9831143891312863, 0.9536903858164667, 0.5395991219078489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 178}], {
             RGBColor[
             0.9202554048713663, 0.8879171799621041, 0.6375652584344874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 244}], {
             RGBColor[
             0.9305033630137299, 0.9224859491112958, 0.6773766406530607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 261}], {
             RGBColor[
             0.9050998994190445, 0.9271661077872047, 0.9908104304704488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 262}], {
             RGBColor[
             0.9178226250506125, 0.9368943496024587, 0.9775831247382163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 299}], {
             RGBColor[
             0.6712865587841526, 0.7408369694039865, 0.9696570894914054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 313}], {
             RGBColor[
             0.9308645267408745, 0.9466209785289019, 0.9555065870493364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 328}], {
             RGBColor[
             0.6804227732338226, 0.7482541598759991, 0.9703763257599396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 376}], {
             RGBColor[
             0.9349113559986364, 0.9493340028297863, 0.9349936131005747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 391}], {
             RGBColor[
             0.9181691024489237, 0.8798685102007529, 0.6347260987055314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 407}], {
             RGBColor[
             0.7860294343098881, 0.8332871901386956, 0.9791708607176912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 448}], {
             RGBColor[
             0.8540113043416422, 0.8864294488354546, 0.985937554664639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 455}], {
             RGBColor[
             0.8394774341752623, 0.3928105343831808, 0.439071427873013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 475}], {
             RGBColor[
             0.9130266424173684, 0.933317513607286, 0.9857014723436948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 478}], {
             RGBColor[
             0.7002666387715365, 0.7643643038754704, 0.9719385075455431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 482}], {
             RGBColor[
             0.9100238273170578, 0.9310780190221328, 0.9907844550489121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 194}], {
             RGBColor[
             0.2061405372520611, 0.3339971530898346, 0.9350507706876843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 290}], {
             RGBColor[
             0.19627542028787323`, 0.3236282896759313, 0.9344889668707066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 297}], {
             RGBColor[
             0.22585915082839916`, 0.35472266619087656`, 0.9361737165597821]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 412}], {
             RGBColor[
             0.2150756323125279, 0.34338850451613256`, 0.9355596111330893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 484}], {
             RGBColor[
             0.2033510637646819, 0.3310652395917648, 0.9348919142992342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 186}], {
             RGBColor[
             0.8637848357389819, 0.37797025225822195`, 0.20492941108331195`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 244}], {
             RGBColor[
             0.9669644653593094, 0.9002255259238574, 0.326163615468509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 261}], {
             RGBColor[
             0.9415610017646239, 0.9049056845997665, 0.6395974052858973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 288}], {
             RGBColor[
             0.8637848357389819, 0.37797025225822195`, 0.20492941108331195`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 313}], {
             RGBColor[
             0.9673256290864539, 0.9243605553414638, 0.6042935618647849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 321}], {
             RGBColor[
             0.8637848357389819, 0.37797025225822195`, 0.20492941108331195`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 391}], {
             RGBColor[
             0.9546302047945031, 0.8576080870133145, 0.28351307352097976`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 407}], {
             RGBColor[
             0.8224905366554676, 0.8110267669512574, 0.6279578355331397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 455}], {
             RGBColor[
             0.8637848357389819, 0.37797025225822195`, 0.20492941108331195`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 475}], {
             RGBColor[
             0.9494877447629478, 0.9110570904198478, 0.6344884471591432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 498}], {
             RGBColor[
             0.8637848357389819, 0.37797025225822195`, 0.20492941108331195`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 222}], {
             RGBColor[
             0.26369928279436383`, 0.3944950440900435, 0.9383286560957851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 245}], {
             RGBColor[
             0.37656052377494753`, 0.49620970043426327`, 0.945567861444176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 255}], {
             RGBColor[
             0.26384605713258924`, 0.39464931322554897`, 0.9383370146772139]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 294}], {
             RGBColor[
             0.2430012286676811, 0.3727400768704716, 0.9371499325332977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 296}], {
             RGBColor[
             0.23166652830629497`, 0.3608265881291439, 0.9365044381159032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 312}], {
             RGBColor[
             0.25910450378636, 0.3896656400268162, 0.9380669902286457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 327}], {
             RGBColor[
             0.23500467222293953`, 0.364335189036086, 0.9366945404736147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 334}], {
             RGBColor[
             0.24162960930249294`, 0.37129841795196816`, 0.9370718208395792]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 385}], {
             RGBColor[
             0.2302154045308226, 0.35930136503456106`, 0.9364217987636353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 415}], {
             RGBColor[
             0.22772487631702723`, 0.35668366197325296`, 0.936279966866266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 438}], {
             RGBColor[
             0.27563010636510166`, 0.40703509612079425`, 0.9390080988480669]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 205}], {
             RGBColor[
             0.5242782003821684, 0.6244474620276343, 0.9557542010457972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 230}], {
             RGBColor[
             0.4493012303473422, 0.5582450689465429, 0.9510229102327686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 331}], {
             RGBColor[
             0.7154954793572077, 0.7771351534675488, 0.9726684783764996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 382}], {
             RGBColor[
             0.46332842266028784`, 0.5716558279898428, 0.9518705351051313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 413}], {
             RGBColor[
             0.5070777034000054, 0.6095492560638003, 0.9546582005878961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 418}], {
             RGBColor[
             0.7760216792869205, 0.7613486519842765, 0.619693218697663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 474}], {
             RGBColor[
             0.505167391968821, 0.6078946403171526, 0.9545364772327231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 490}], {
             RGBColor[
             0.4726781530538206, 0.5797540945256074, 0.9524662916581652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 189}], {
             RGBColor[
             0.4605412675252241, 0.5711446538797107, 0.9511671576944246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 302}], {
             RGBColor[
             0.4379250644031646, 0.5527838013368829, 0.9493867273387744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 370}], {
             RGBColor[
             0.39544611839331145`, 0.5169372848776308, 0.9464184548781174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 390}], {
             RGBColor[
             0.4729036438374925, 0.5811809878887164, 0.9521403692426029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 422}], {
             RGBColor[
             0.34276984142818484`, 0.4703062298019115, 0.9430987857933579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 443}], {
             RGBColor[
             0.5695192678995484, 0.6579480039591199, 0.9608880248523786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 451}], {
             RGBColor[
             0.3396395828866079, 0.4670161296048595, 0.9429205222002176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 237}], {
             RGBColor[
             0.6887654101141651, 0.7532085811116003, 0.9550446399454904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 351}], {
             RGBColor[
             0.7070036360153077, 0.7688374180603554, 0.9562532370834724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 359}], {
             RGBColor[
             0.8630442272815448, 0.41127892958154133`, 0.4301162711119909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 371}], {
             RGBColor[
             0.7505720549654683, 0.8042082232990024, 0.9596831026196062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 460}], {
             RGBColor[
             0.8895334088722675, 0.9142691218847867, 0.9725212169169912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 463}], {
             RGBColor[
             0.8924035413977808, 0.6307547645274091, 0.4579882921332097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 483}], {
             RGBColor[
             0.9629580792560939, 0.9404214301836048, 0.652695538050524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 202}], {
             RGBColor[
             0.23464668265559618`, 0.36395891930295865`, 0.9366741534973526]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 206}], {
             RGBColor[
             0.22097903356863421`, 0.34959335353355825`, 0.935895801101325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 243}], {
             RGBColor[
             0.2557945891305531, 0.386186709862853, 0.9378784954855774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 273}], {
             RGBColor[
             0.23550505714349235`, 0.3648611253138234, 0.9367230366545871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 279}], {
             RGBColor[
             0.28035477682361865`, 0.41200102433410457`, 0.9392771618411558]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 283}], {
             RGBColor[
             0.2250780320064527, 0.3539016607832171, 0.936129232998434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 285}], {
             RGBColor[
             0.2954522956610519, 0.4255087033323427, 0.9402233825780824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 396}], {
             RGBColor[
             0.2576449284246818, 0.38813153377926946`, 0.9379838695710464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 430}], {
             RGBColor[
             0.26651354621858253`, 0.39745301338350436`, 0.9384889242344647]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 477}], {
             RGBColor[
             0.2584102041277772, 0.38893588706450477`, 0.9380274508902138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 221}], {
             RGBColor[
             0.8369837657282427, 0.26650113164225936`, 0.18231370738115665`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 253}], {
             RGBColor[
             0.9322255008103006, 0.7603060225554952, 0.5323787942426484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 287}], {
             RGBColor[
             0.8571239304455562, 0.7024298435855887, 0.6014546314672211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 301}], {
             RGBColor[
             0.8369837657282427, 0.26650113164225936`, 0.18231370738115665`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 316}], {
             RGBColor[
             0.9311223602384289, 0.7477274618057713, 0.3091758937857617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 336}], {
             RGBColor[
             0.8369837657282427, 0.26650113164225936`, 0.18231370738115665`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 354}], {
             RGBColor[
             0.8691146527768465, 0.7119909200930725, 0.6025983172674237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 388}], {
             RGBColor[
             0.900316789777843, 0.736870657178221, 0.6055744049490553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 436}], {
             RGBColor[
             0.9230065584441681, 0.7540860752952483, 0.5773398016096436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 473}], {
             RGBColor[
             0.7413125486005306, 0.611259827036092, 0.5903276772577556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 187}], {
             RGBColor[
             0.3439018393873985, 0.4722922210934996, 0.943134098998677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 216}], {
             RGBColor[
             0.29497840118270136`, 0.42627321830582066`, 0.9401501647204071]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 224}], {
             RGBColor[
             0.30794222932777976`, 0.4398990236404763, 0.9408884355550042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 286}], {
             RGBColor[
             0.26801510124259026`, 0.39793308049680753`, 0.9386146446774454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 330}], {
             RGBColor[
             0.2727206891407805, 0.40287895172931015`, 0.9388826209469538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 333}], {
             RGBColor[
             0.3691868534914339, 0.4941928294486542, 0.944745237738726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 357}], {
             RGBColor[
             0.2704886241626608, 0.4005329099162129, 0.9387555081484942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 358}], {
             RGBColor[
             0.3526247422114796, 0.4798475610938749, 0.9436899146532672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 361}], {
             RGBColor[
             0.3651394217782484, 0.4906871475285258, 0.9444873389689651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 386}], {
             RGBColor[
             0.5820600535640958, 0.665087506482939, 0.9632927375329758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 398}], {
             RGBColor[
             0.30864187886940686`, 0.4406343996690694, 0.9409282795613612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 441}], {
             RGBColor[
             0.3444326919958216, 0.4727520189414878, 0.9431679244574711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 464}], {
             RGBColor[
             0.3004465755354037, 0.43202061625278937`, 0.9404615691603544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 481}], {
             RGBColor[
             0.30650884939950357`, 0.4383924504543215, 0.9408068066885844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 288}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 295}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 321}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 341}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 373}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 397}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 455}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 495}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 498}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 216}], {
             RGBColor[
             0.3182566714322743, 0.44643568599611877`, 0.9416334355165438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 224}], {
             RGBColor[
             0.3312204995773527, 0.4600614913307744, 0.9423717063511409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 260}], {
             RGBColor[
             0.33960819065109193`, 0.4685732783631712, 0.942860511497924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 328}], {
             RGBColor[
             0.42211567678941486`, 0.5393927026931269, 0.9482958688478269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 398}], {
             RGBColor[
             0.3319201491189798, 0.46079686735936753`, 0.9424115503574978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 399}], {
             RGBColor[
             0.3354088495669978, 0.4644637127266185, 0.9426102266869426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 407}], {
             RGBColor[
             0.5277223378654804, 0.6244257329558234, 0.9570904038055785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 464}], {
             RGBColor[
             0.3237248457849767, 0.4521830839430875, 0.9419448399564911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 478}], {
             RGBColor[
             0.4419595423271288, 0.555502846692598, 0.9498580506334303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 481}], {
             RGBColor[
             0.32978711964907653`, 0.45855491814461957`, 0.9422900774847212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 200}], {
             RGBColor[
             0.49135529375587494`, 0.5959601817284621, 0.9536484010759594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 228}], {
             RGBColor[
             0.4764305577406883, 0.5838436086796381, 0.9524734711857346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 256}], {
             RGBColor[
             0.6227687970873287, 0.6995989768913324, 0.9662311909897034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 279}], {
             RGBColor[
             0.34218136725328896`, 0.47037106759976377`, 0.9430402518488281]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 298}], {
             RGBColor[
             0.5300245996478504, 0.6267805592985796, 0.9570844268620295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 318}], {
             RGBColor[
             0.3206397205634015, 0.4477294311094059, 0.9418134869378495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 335}], {
             RGBColor[
             0.3476544631710703, 0.4755425552025606, 0.9433732128678576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 409}], {
             RGBColor[
             0.4608023334373177, 0.5711559121466802, 0.9512431601205011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 430}], {
             RGBColor[
             0.3283401366482528, 0.45582305664916356`, 0.9422520142421371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 459}], {
             RGBColor[
             0.3130997116438481, 0.4398044036707781, 0.9413840945843246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 302}], {
             RGBColor[
             0.5107971785704983, 0.6137271865710165, 0.9546309714902383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 346}], {
             RGBColor[
             0.758201423428222, 0.7931848261137132, 0.6724145577439462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 370}], {
             RGBColor[
             0.46831823256064525`, 0.5778806701117645, 0.9516626990295814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 383}], {
             RGBColor[
             0.5829740029038133, 0.6723235840936835, 0.960312995494176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 390}], {
             RGBColor[
             0.5457757580048264, 0.6421243731228501, 0.957384613394067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 422}], {
             RGBColor[
             0.41564195559551864`, 0.5312496150360451, 0.9483430299448219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 443}], {
             RGBColor[
             0.6423913820668823, 0.7188913891932535, 0.9661322690038426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 451}], {
             RGBColor[
             0.41251169705394175`, 0.5279595148389932, 0.9481647663516817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 349}], {
             RGBColor[
             0.2752751587264147, 0.4033449321472721, 0.9391093400741414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 378}], {
             RGBColor[
             0.3221600885821226, 0.4526239661018675, 0.9417793674693858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 467}], {
             RGBColor[
             0.28809331925242987`, 0.41681763157843177`, 0.9398393153533288]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 487}], {
             RGBColor[
             0.29152503768335564`, 0.4204245852328503, 0.9400347466411976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 226}], {
             RGBColor[
             0.22140390405308463`, 0.35003991935106027`, 0.935919996846875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 237}], {
             RGBColor[
             0.3261149973492088, 0.44953101328405887`, 0.9422700448294907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 271}], {
             RGBColor[
             0.2668826471852404, 0.3978409619018147, 0.9385099439884801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 311}], {
             RGBColor[
             0.22787572296700198`, 0.35684221136660643`, 0.9362885573598245]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 366}], {
             RGBColor[
             0.21187817482284405`, 0.3400277739639608, 0.9353775206592663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 405}], {
             RGBColor[
             0.20994495191990925`, 0.33799583411956474`, 0.9352674264748911]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 423}], {
             RGBColor[
             0.20464821144403264`, 0.3324286240466755, 0.9349657849406153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 429}], {
             RGBColor[
             0.23210680778710222`, 0.3612893497788038, 0.9365295113810002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 488}], {
             RGBColor[
             0.2118176137321737, 0.33996412041787133`, 0.9353740717947447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 219}], {
             RGBColor[
             0.8349445829202758, 0.3891961618334242, 0.4386390804737884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 251}], {
             RGBColor[
             0.6611025885462706, 0.7326320332459636, 0.9687519301958931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 258}], {
             RGBColor[
             0.9320737133765145, 0.9444030306208892, 0.78526845033412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 272}], {
             RGBColor[
             0.7182850173642144, 0.7790908357882066, 0.973243723195778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 435}], {
             RGBColor[
             0.6598277871485738, 0.73152786434866, 0.9686707009780946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 453}], {
             RGBColor[
             0.6640388061322713, 0.735051317746148, 0.9689732627371802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 497}], {
             RGBColor[
             0.9083829048728054, 0.8626048061581572, 0.6316742311045528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 410}], {
             RGBColor[
             0.19038075076848193`, 0.31743261826741714`, 0.9341532741619593]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 428}], {
             RGBColor[
             0.20228207150770255`, 0.3299416609516557, 0.9348310367716316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 437}], {
             RGBColor[
             0.18967305081090496`, 0.3166887807412348, 0.9341129716963235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 220}], {
             RGBColor[
             0.27841284106148134`, 0.4064257927007418, 0.9392959734312498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 254}], {
             RGBColor[
             0.22347198353028988`, 0.3522136020054152, 0.9360377709136524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 290}], {
             RGBColor[
             0.19998987236326368`, 0.3275324143170307, 0.9347004994213606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 297}], {
             RGBColor[
             0.22957360290378961`, 0.3586267908319759, 0.9363852491104362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 350}], {
             RGBColor[
             0.1999849515613838, 0.32752724224225804`, 0.9347002191889733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 377}], {
             RGBColor[
             0.19840694520434524`, 0.3258686575096288, 0.934610354061391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 412}], {
             RGBColor[
             0.21879008438791836`, 0.3472926291572319, 0.9357711436837434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 426}], {
             RGBColor[
             0.2125469848716252, 0.34073073573023605`, 0.9354156084021286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 476}], {
             RGBColor[
             0.20408939664104067`, 0.33184127425782606`, 0.9349339612642773]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.2379640347981863, 0.3674456667370949, 0.9368630717942905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 260}], {
             RGBColor[
             0.2652269236159478, 0.3957964833551174, 0.9384267915292429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 292}], {
             RGBColor[
             0.2120103022106906, 0.3401666482259477, 0.9353850451185391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 399}], {
             RGBColor[
             0.2610275825318536, 0.39168691771856473`, 0.9381765067182615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 446}], {
             RGBColor[
             0.20832130976855523`, 0.33628928327363344`, 0.9351749624563348]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 496}], {
             RGBColor[
             0.21350786360609533`, 0.34174068020339465`, 0.9354703290245638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 213}], {
             RGBColor[
             0.25723659522050063`, 0.3877023496918546, 0.9379606155991431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 332}], {
             RGBColor[
             0.22366006402010474`, 0.35241128652520237`, 0.9360484818193071]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 337}], {
             RGBColor[
             0.2289545201015995, 0.3579760955547574, 0.9363499932607025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 420}], {
             RGBColor[
             0.22671171795480946`, 0.35561876829661176`, 0.9362222689963712]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 427}], {
             RGBColor[
             0.22341549837051072`, 0.3521542325211213, 0.9360345541673653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 447}], {
             RGBColor[
             0.33114259091826304`, 0.45444303824740756`, 0.942569990376295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 454}], {
             RGBColor[
             0.2775665280001868, 0.40803814535898913`, 0.9391561710226074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 489}], {
             RGBColor[
             0.23441451862430046`, 0.36371490018601704`, 0.9366609320992263]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 500}], {
             RGBColor[
             0.2545900551674532, 0.38492066829577065`, 0.9378098990583272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 201}], {
             RGBColor[
             0.49062190566788, 0.5962657278401451, 0.9533417326780644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 236}], {
             RGBColor[
             0.3595830595921312, 0.48559353377690795`, 0.9441435802486068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 289}], {
             RGBColor[
             0.3635203797565897, 0.48928481470478324`, 0.9443841750430078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 314}], {
             RGBColor[
             0.5074205711230394, 0.6099036412278982, 0.9546641851582337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 411}], {
             RGBColor[
             0.5628841788365053, 0.6538599474387119, 0.9597631075252654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 466}], {
             RGBColor[
             0.3305652534933362, 0.45509397973190396`, 0.9424910591192776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 470}], {
             RGBColor[
             0.32997863152241563`, 0.4544774028464852, 0.942457651865863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 493}], {
             RGBColor[
             0.5014513704988036, 0.60505757525172, 0.9541942678191915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 270}], {
             RGBColor[
             0.1889882633050292, 0.3159690256545238, 0.9340739740609163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 479}], {
             RGBColor[
             0.19373559329222378`, 0.3209587704691713, 0.9343443274806416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 244}], {
             RGBColor[
             0.9841027978606212, 0.9626688772839973, 0.5824524865696615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 245}], {
             RGBColor[
             0.7369662997669877, 0.7908272343094369, 0.8756839413586472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 262}], {
             RGBColor[
             0.9714220598975036, 0.9770772777751602, 0.8826589706548171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 376}], {
             RGBColor[
             0.9885107908455275, 0.9895169310024878, 0.8400694590171756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 448}], {
             RGBColor[
             0.9076107391885334, 0.9266123770081562, 0.8910134005812398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 455}], {
             RGBColor[
             0.8752103907398564, 0.41959915316498186`, 0.3757886584840803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 475}], {
             RGBColor[
             0.9666260772642596, 0.9735004417799876, 0.8907773182602956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 482}], {
             RGBColor[
             0.9636232621639489, 0.9712609471948344, 0.895860300965513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 228}], {
             RGBColor[
             0.5875078389354265, 0.6760043564311329, 0.9606699156745733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 256}], {
             RGBColor[
             0.7338460782820668, 0.7917597246428272, 0.9744276354785424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 298}], {
             RGBColor[
             0.6411018808425886, 0.7189413070500743, 0.9652808713508684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 452}], {
             RGBColor[
             0.4981470175789616, 0.6018428315420548, 0.9540811637122809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 468}], {
             RGBColor[
             0.48541856175705617`, 0.5908180828599114, 0.9532701177626406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 218}], {
             RGBColor[
             0.6538010445751918, 0.7283312295992802, 0.96690948928418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 235}], {
             RGBColor[
             0.4575805493651263, 0.5676469657175549, 0.9512363666717771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 236}], {
             RGBColor[
             0.4367458916891245, 0.5493200603220583, 0.9499190884728695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 289}], {
             RGBColor[
             0.440683211853583, 0.5530113412499335, 0.9501596832672705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 300}], {
             RGBColor[
             0.49294744284977277`, 0.5982799912622034, 0.9534899138509028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 305}], {
             RGBColor[
             0.714793343846527, 0.7763168762700076, 0.9728989371489009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 314}], {
             RGBColor[
             0.5845834032200327, 0.6736301677730485, 0.9604396933824965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 406}], {
             RGBColor[
             0.780813502467645, 0.8246149057210677, 0.7651321037016474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 493}], {
             RGBColor[
             0.5786142025957969, 0.6687841017968702, 0.9599697760434542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 243}], {
             RGBColor[
             0.23381644008435298`, 0.36308628172016266`, 0.9366268724111542]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 273}], {
             RGBColor[
             0.21352690809729225`, 0.3417606971711331, 0.9354714135801638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 279}], {
             RGBColor[
             0.25837662777741854`, 0.38890059619141426`, 0.9380255387667326]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 283}], {
             RGBColor[
             0.2030998829602526, 0.3308012326405268, 0.9348776099240107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 285}], {
             RGBColor[
             0.2734741466148518, 0.4024082751896524, 0.9389717595036591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 396}], {
             RGBColor[
             0.23566677937848166`, 0.36503110563657915`, 0.9367322464966231]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 421}], {
             RGBColor[
             0.20744896350666275`, 0.3353723920424369, 0.9351252836272407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 430}], {
             RGBColor[
             0.24453539717238243`, 0.37435258524081405`, 0.9372373011600414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 459}], {
             RGBColor[
             0.22929497216797767`, 0.3583339322624286, 0.9363693815022289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 477}], {
             RGBColor[
             0.2364320550815771, 0.36583545892181446`, 0.9367758278157905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 264}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 281}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 295}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 324}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 341}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 374}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 397}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 275}], {
             RGBColor[
             0.9068456198442363, 0.8406001496363356, 0.6268746543862641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 306}], {
             RGBColor[
             0.6716952973173317, 0.7411945060226874, 0.9696596817495633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 331}], {
             RGBColor[
             0.8538682923947138, 0.8863154149909298, 0.9859239140574727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 346}], {
             RGBColor[
             0.9316157699795097, 0.9308133831466772, 0.688428591304491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 348}], {
             RGBColor[
             0.9214887091320801, 0.896652428961333, 0.6490868722471982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 355}], {
             RGBColor[
             0.8646089820506718, 0.5941398003894627, 0.4641583607120223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 390}], {
             RGBColor[
             0.719190104556114, 0.779752930155814, 0.9733986469546118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 431}], {
             RGBColor[
             0.9368455281102752, 0.9478707558976731, 0.7583898546015062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 444}], {
             RGBColor[
             0.8607679520740443, 0.5646159608390356, 0.460480186068581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 486}], {
             RGBColor[
             0.9371733075375102, 0.9485718429489449, 0.7940666224358858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 230}], {
             RGBColor[
             0.3700829820093897, 0.493707900841167, 0.944848513673534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 331}], {
             RGBColor[
             0.6362772310192553, 0.7125979853621729, 0.9664940818172649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 382}], {
             RGBColor[
             0.38411017432233535`, 0.5071186598844669, 0.9456961385458966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 413}], {
             RGBColor[
             0.4278594550620529, 0.5450120879584244, 0.9484838040286614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 474}], {
             RGBColor[
             0.4259491436308685, 0.5433574722117767, 0.9483620806734884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 490}], {
             RGBColor[
             0.3934599047158681, 0.5152169264202315, 0.9462918950989305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 254}], {
             RGBColor[
             0.21121110658430017`, 0.33932664295068204`, 0.9353395321099203]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 377}], {
             RGBColor[
             0.18614606825835553`, 0.31298169845489565`, 0.9339121152576589]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 396}], {
             RGBColor[
             0.2219991302915197, 0.35066553986717874`, 0.9359538941005956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 476}], {
             RGBColor[
             0.19182851969505096`, 0.31895431520309286`, 0.9342357224605452]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 257}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 266}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 281}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 293}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 317}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 322}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 343}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 374}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 403}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 440}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 445}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 471}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 238}], {
             RGBColor[
             0.9647733116194365, 0.8867812659004515, 0.37390414215136103`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[
             0.9934783139029316, 0.9884590978190089, 0.5315328993943991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 266}], {
             RGBColor[
             0.8758809832712207, 0.41856687329883735`, 0.26948204651397445`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 293}], {
             RGBColor[
             0.8758809832712207, 0.41856687329883735`, 0.26948204651397445`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 403}], {
             RGBColor[
             0.8758809832712207, 0.41856687329883735`, 0.26948204651397445`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 471}], {
             RGBColor[
             0.8758809832712207, 0.41856687329883735`, 0.26948204651397445`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 483}], {
             RGBColor[
             0.9822132132406076, 0.9513533457595487, 0.41174420115349936`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 497}], {
             RGBColor[
             0.9697875053992224, 0.9066608733562769, 0.377938680164832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 231}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 233}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 259}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 275}], {
             RGBColor[
             0.8560290549644465, 0.34736971536429956`, 0.19791527993518332`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 348}], {
             RGBColor[
             0.8657911144896757, 0.38473790158096455`, 0.21272342517580606`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 355}], {
             RGBColor[
             0.8304768118928137, 0.23526370799810264`, 0.17681793552818148`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 372}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 379}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 400}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 404}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 431}], {
             RGBColor[
             0.8760289938084724, 0.418883452871858, 0.28559208007867803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 444}], {
             RGBColor[
             0.8285562969045, 0.22050178822288907`, 0.17497884820646079`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 486}], {
             RGBColor[
             0.8762475134266291, 0.4193508442393725, 0.30937659196826445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 225}], {
             RGBColor[
             0.22552288916917368`, 0.3543692338668101, 0.9361545669557438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 252}], {
             RGBColor[
             0.22195142774965249`, 0.3506154014711605, 0.9359511775114058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 280}], {
             RGBColor[
             0.396625050619534, 0.5101349644825113, 0.9473626025497911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 309}], {
             RGBColor[
             0.23463499011461536`, 0.36394662970103786`, 0.9366734876244414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 320}], {
             RGBColor[
             0.21943490594638596`, 0.34797037749922943`, 0.9358078653175701]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 393}], {
             RGBColor[
             0.30896553356423473`, 0.43663923993453624`, 0.9411054493010679]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 424}], {
             RGBColor[
             0.24599797700123366`, 0.37588984937385383`, 0.9373205929176016]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 480}], {
             RGBColor[
             0.364909192113561, 0.48438660176421894`, 0.9448658139891831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 236}], {
             RGBColor[
             0.26074470726775645`, 0.39138959788067107`, 0.9381603973904477]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 289}], {
             RGBColor[
             0.264682027432215, 0.3950808788085463, 0.9384009921848486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 308}], {
             RGBColor[
             0.22315099456572612`, 0.35187622225178283`, 0.936019491066981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 362}], {
             RGBColor[
             0.19802212087574567`, 0.325464182740999, 0.934588438885174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 369}], {
             RGBColor[
             0.20403104555369495`, 0.33177994356535306`, 0.9349306382561757]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 466}], {
             RGBColor[
             0.2317269011689615, 0.36089004383566703`, 0.9365078762611184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 470}], {
             RGBColor[
             0.23114027919804092`, 0.3602734669502483, 0.9364744690077039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 216}], {
             RGBColor[
             0.23063173496240144`, 0.3597389547150244, 0.9364455081658081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 217}], {
             RGBColor[
             0.1904154630441735, 0.3174691030700544, 0.9341552509747078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 224}], {
             RGBColor[
             0.24359556310747985`, 0.37336476004968, 0.9371837790004052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 286}], {
             RGBColor[
             0.20366843502229037`, 0.33139881690601125`, 0.9349099881228464]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 319}], {
             RGBColor[
             0.18959797954384694`, 0.31660987607976354`, 0.9341086964987225]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 330}], {
             RGBColor[
             0.20837402292048057`, 0.33634468813851387`, 0.9351779643923548]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 357}], {
             RGBColor[
             0.2061419579423609, 0.3339986463254166, 0.9350508515938951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 492}], {
             RGBColor[
             0.19335812540385172`, 0.3205620277856458, 0.9343228312428125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 251}], {
             RGBColor[
             0.3656301307264068, 0.4883851452501694, 0.9446184564254285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 332}], {
             RGBColor[
             0.24567430192070422`, 0.375549646342032, 0.9373021601005997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 337}], {
             RGBColor[
             0.250968758002199, 0.38111445537158695`, 0.9376036715419951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 420}], {
             RGBColor[
             0.24872595585540894`, 0.3787571281134413, 0.9374759472776638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 447}], {
             RGBColor[
             0.3531568288188625, 0.47758139806423716`, 0.9438236686575876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 454}], {
             RGBColor[
             0.29958076590078625`, 0.43117650517581874`, 0.9404098493039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 489}], {
             RGBColor[
             0.25642875652489994`, 0.38685326000284664`, 0.9379146103805189]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 500}], {
             RGBColor[
             0.2766042930680527, 0.40805902811260025`, 0.9390635773396199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 223}], {
             RGBColor[
             0.2605020778119116, 0.39113457893898207`, 0.9381465800018753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 268}], {
             RGBColor[
             0.21337122568436184`, 0.3415970650843082, 0.9354625476970588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 466}], {
             RGBColor[
             0.23186057629826734`, 0.3610305448720602, 0.9365154888619778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 470}], {
             RGBColor[
             0.2312739543273467, 0.36041396798664144`, 0.9364820816085633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 491}], {
             RGBColor[
             0.20330311497053621`, 0.3310148423689886, 0.9348891836863416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 402}], {
             RGBColor[
             0.2785766923854661, 0.4061119675803237, 0.9393231009461043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 417}], {
             RGBColor[
             0.23113355417435436`, 0.36026639852396264`, 0.9364740860275538]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 217}], {
             RGBColor[
             0.22911696130934928`, 0.3581468315634698, 0.9363592440471735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 224}], {
             RGBColor[
             0.2822970613726556, 0.41404248854309544`, 0.939387772072871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 292}], {
             RGBColor[
             0.23746813104113765`, 0.36692444044632255`, 0.9368348308089505]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 358}], {
             RGBColor[
             0.32697957425635543`, 0.45399102599649405`, 0.9421892511711341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 361}], {
             RGBColor[
             0.3394942538231242, 0.464830612431145, 0.9429866754868319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 398}], {
             RGBColor[
             0.2829967109142827, 0.4147778645716886, 0.939427616079228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 399}], {
             RGBColor[
             0.28648541136230066`, 0.41844470993893956`, 0.9396262924086728]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 464}], {
             RGBColor[
             0.27480140758027954`, 0.40616408115540853`, 0.9389609056782213]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 481}], {
             RGBColor[
             0.2808636814443794, 0.4125359153569407, 0.9393061432064513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 292}], {
             RGBColor[
             0.1972518591229097, 0.32465458880135256`, 0.93454457361785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 398}], {
             RGBColor[
             0.24278043899605473`, 0.37250801292671853`, 0.9371373588881275]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 464}], {
             RGBColor[
             0.23458513566205164`, 0.3638942295104385, 0.936670648487121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 481}], {
             RGBColor[
             0.2406474095261515, 0.3702660637119706, 0.9370158860153509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 496}], {
             RGBColor[
             0.19874942051831446`, 0.3262286207787995, 0.9346298575238747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 235}], {
             RGBColor[
             0.543596856175445, 0.6359859409315397, 0.9590286150536299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 274}], {
             RGBColor[
             0.6118775615619095, 0.6942958574577106, 0.963609119130596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.5789637496600913, 0.6666189664761881, 0.9612821622327556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 305}], {
             RGBColor[
             0.8008096506568456, 0.8446558514839924, 0.9806911855307536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 310}], {
             RGBColor[
             0.7914851171285034, 0.354974734937755, 0.4343792458886776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 314}], {
             RGBColor[
             0.6705997100303512, 0.7419691429870332, 0.9682319417643492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 406}], {
             RGBColor[
             0.8668298092779636, 0.8929538809350525, 0.7729243520835001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 432}], {
             RGBColor[
             0.7556020055170689, 0.8090012965886532, 0.976275004473887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 493}], {
             RGBColor[
             0.6646305094061155, 0.737123077010855, 0.9677620244253071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 238}], {
             RGBColor[
             0.857059891141737, 0.3514566373014637, 0.19874471492026624`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 258}], {
             RGBColor[
             0.8761965593307338, 0.4192418585805019, 0.3038305530822916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 293}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 403}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 445}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 471}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 497}], {
             RGBColor[
             0.8604026869949277, 0.3647097089386806, 0.20143440692924686`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 254}], {
             RGBColor[
             0.2920298352643197, 0.42073811697522306`, 0.9400714411065638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 297}], {
             RGBColor[
             0.2981314546378194, 0.42715130580178384`, 0.9404189193033476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 325}], {
             RGBColor[
             0.38679117901764243`, 0.5094408114003279, 0.9458669697943621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 392}], {
             RGBColor[
             0.39450251795097435`, 0.5161199856012157, 0.9463583294923248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 412}], {
             RGBColor[
             0.2873479361219482, 0.41581714412703974`, 0.9398048138766548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 413}], {
             RGBColor[
             0.3788148254377005, 0.50253209483257, 0.9453587235974608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 426}], {
             RGBColor[
             0.281104836605655, 0.409255250700044, 0.93944927859504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 474}], {
             RGBColor[
             0.37690451400651614`, 0.5008774790859223, 0.9452370002422877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 490}], {
             RGBColor[
             0.34441527509151576`, 0.47273693329437716`, 0.9431668146677299]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 234}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 301}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 336}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 294}], {
             RGBColor[
             0.23651889122655595`, 0.36592672921591685`, 0.9367807730057844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 296}], {
             RGBColor[
             0.22518419086516983`, 0.35401324047458915`, 0.9361352785883901]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 339}], {
             RGBColor[
             0.22078402621432447`, 0.3493883884399983, 0.9358846957209846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 344}], {
             RGBColor[
             0.2425145104333196, 0.3722285051464392, 0.9371222146498859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 438}], {
             RGBColor[
             0.2691477689239765, 0.4002217484662395, 0.9386389393205536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 439}], {
             RGBColor[
             0.26180020973842244`, 0.3924989979000629, 0.938220506694676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 246}], {
             RGBColor[
             0.38131973644829154`, 0.5042325916141828, 0.9455639325855753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 268}], {
             RGBColor[
             0.25782358431552455`, 0.3883193124479829, 0.9379940437597322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 411}], {
             RGBColor[
             0.5086318602725991, 0.6065187599425428, 0.9563190333306388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 286}], {
             RGBColor[
             0.2553337614325445, 0.3857023507340823, 0.9378522520299093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 330}], {
             RGBColor[
             0.2600393493307347, 0.39064822196658494`, 0.9381202282994179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 333}], {
             RGBColor[
             0.3565055136813881, 0.481962099685929, 0.9439828450911899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 358}], {
             RGBColor[
             0.33994340240143384`, 0.4676168313311497, 0.9429275220057312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 361}], {
             RGBColor[
             0.3524580819682026, 0.4784564177658006, 0.943724946321429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 398}], {
             RGBColor[
             0.29596053905936104`, 0.4284036699063442, 0.9401658869138251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 441}], {
             RGBColor[
             0.33175135218577584`, 0.46052128917876256`, 0.942405531809935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 464}], {
             RGBColor[
             0.28776523572535795`, 0.41978988649006416`, 0.9396991765128184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 481}], {
             RGBColor[
             0.2938275095894578, 0.4261617206915963, 0.9400444140410484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 247}], {
             RGBColor[
             0.2013053783371785, 0.3289150945035113, 0.9347754155404584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 252}], {
             RGBColor[
             0.1970572565472313, 0.32445004915579856`, 0.9345334912890539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 309}], {
             RGBColor[
             0.20974081891219415`, 0.337781277385676, 0.9352558014020895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 320}], {
             RGBColor[
             0.19454073474396477`, 0.32180502518386755`, 0.9343901790952183]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 424}], {
             RGBColor[
             0.22110380579881245`, 0.3497244970584919, 0.9359029066952498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 284}], {
             RGBColor[
             0.25636693278706735`, 0.38678827933453314`, 0.9379110896101094]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 345}], {
             RGBColor[
             0.22193035948375894`, 0.35059325738790115`, 0.9359499777048308]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 366}], {
             RGBColor[
             0.20408822256120682`, 0.33184004022547964`, 0.9349338944021677]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 389}], {
             RGBColor[
             0.23071843962178798`, 0.35983008680943257`, 0.9364504458678921]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 405}], {
             RGBColor[
             0.202154999658272, 0.32980810038108366`, 0.9348238002177924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 429}], {
             RGBColor[
             0.224316855525465, 0.35310161604032264`, 0.9360858851239015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 472}], {
             RGBColor[
             0.2053352778859962, 0.33315077443970764`, 0.9350049123580614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 488}], {
             RGBColor[
             0.20402766147053647`, 0.33177638667939024`, 0.9349304455376461]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 229}], {
             RGBColor[
             0.3363119952168668, 0.45938358895469533`, 0.9428824248934964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 263}], {
             RGBColor[
             0.3111215525527843, 0.43756489362752915`, 0.9412773121619749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 265}], {
             RGBColor[
             0.22119979691073288`, 0.34982538980330835`, 0.9359083732470674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 267}], {
             RGBColor[
             0.32291920761564974`, 0.44778342947559846`, 0.9420290483103237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 270}], {
             RGBColor[
             0.21213527831829654`, 0.34029800603898447`, 0.9353921623229817]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 329}], {
             RGBColor[
             0.21529055299948083`, 0.3436143997848786, 0.9355718505482646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 424}], {
             RGBColor[
             0.24090488888578881`, 0.3705366908440838, 0.9370305490839757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 256}], {
             RGBColor[
             0.7189213422668801, 0.7796431515940032, 0.9732527055883174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 279}], {
             RGBColor[
             0.4383339124328404, 0.5504152423024345, 0.9500617664474421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 287}], {
             RGBColor[
             0.7052588333133122, 0.7687490378133541, 0.9719495632876605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 298}], {
             RGBColor[
             0.6261771448274018, 0.7068247340012503, 0.9641059414606434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 318}], {
             RGBColor[
             0.41679226574295297`, 0.5277736058120767, 0.9488350015364635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 335}], {
             RGBColor[
             0.44380700835062176`, 0.5555867299052314, 0.9503947274664715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 409}], {
             RGBColor[
             0.5569548786168692, 0.6512000868493509, 0.9582646747191151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 468}], {
             RGBColor[
             0.47049382574186954`, 0.5787015098110876, 0.9520951878724158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 232}], {
             RGBColor[
             0.5642482406538483, 0.6557297115102981, 0.9595587106539356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 263}], {
             RGBColor[
             0.40720266362894586`, 0.5271202134595926, 0.9471675715446273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 267}], {
             RGBColor[
             0.4190003186918113, 0.5373387493076619, 0.9479193076929763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 280}], {
             RGBColor[
             0.4876130735802507, 0.5943371257848047, 0.9529628180988177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 393}], {
             RGBColor[
             0.39995355652495146`, 0.5208414012368296, 0.9467056648500944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 480}], {
             RGBColor[
             0.4558972150742777, 0.5685887630665123, 0.9504660295382097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 485}], {
             RGBColor[
             0.493481350800354, 0.5991012575949606, 0.9534247903777919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 382}], {
             RGBColor[
             0.3091332042875092, 0.4409162668033755, 0.940964847732868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 413}], {
             RGBColor[
             0.35288248502722674`, 0.4788096948773328, 0.9437525132156328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 474}], {
             RGBColor[
             0.3509721735960423, 0.4771550791306852, 0.9436307898604598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 484}], {
             RGBColor[
             0.24969102716362834`, 0.37977147924743493`, 0.9375309066609718]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 490}], {
             RGBColor[
             0.31848293468104194`, 0.4490145333391401, 0.9415606042859019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 233}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 275}], {
             RGBColor[
             0.8560290549644465, 0.34736971536429956`, 0.19791527993518332`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 326}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 346}], {
             RGBColor[
             0.8725424883879621, 0.4075118710378607, 0.23895123788066785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 355}], {
             RGBColor[
             0.8304768118928137, 0.23526370799810264`, 0.17681793552818148`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 395}], {
             RGBColor[
             0.8502020870562027, 0.32426772933006165`, 0.19322676477969444`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 404}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 431}], {
             RGBColor[
             0.8760289938084724, 0.418883452871858, 0.28559208007867803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 444}], {
             RGBColor[
             0.8285562969045, 0.22050178822288907`, 0.17497884820646079`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 486}], {
             RGBColor[
             0.8762475134266291, 0.4193508442393725, 0.30937659196826445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 267}], {
             RGBColor[
             0.5508554530526312, 0.6441295520312013, 0.958705334070763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 280}], {
             RGBColor[
             0.6194682079410706, 0.701127928508344, 0.9637488444766045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 338}], {
             RGBColor[
             0.8446486517517946, 0.8751856702040267, 0.7354620195671999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 383}], {
             RGBColor[
             0.6643189995648684, 0.7375398216536801, 0.9672796630870929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 393}], {
             RGBColor[
             0.5318086908857713, 0.627632203960369, 0.9574916912278812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 395}], {
             RGBColor[
             0.806035818091638, 0.7335348511120112, 0.6107945156854029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 480}], {
             RGBColor[
             0.5877523494350976, 0.6753795657900517, 0.9612520559159965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 259}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 275}], {
             RGBColor[
             0.8560290549644465, 0.34736971536429956`, 0.19791527993518332`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 326}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 346}], {
             RGBColor[
             0.8725424883879621, 0.4075118710378607, 0.23895123788066785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 348}], {
             RGBColor[
             0.8657911144896757, 0.38473790158096455`, 0.21272342517580606`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 355}], {
             RGBColor[
             0.8304768118928137, 0.23526370799810264`, 0.17681793552818148`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 379}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 400}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 404}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 431}], {
             RGBColor[
             0.8760289938084724, 0.418883452871858, 0.28559208007867803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 444}], {
             RGBColor[
             0.8285562969045, 0.22050178822288907`, 0.17497884820646079`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 486}], {
             RGBColor[
             0.8762475134266291, 0.4193508442393725, 0.30937659196826445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 336}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 449}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 274}], {
             RGBColor[
             0.415657066351844, 0.5336115935759853, 0.9479359965181933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 284}], {
             RGBColor[
             0.32324813737403335`, 0.4535130250531508, 0.9418506505358348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 300}], {
             RGBColor[
             0.3827432544500259, 0.5059347025944629, 0.9456090396203527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 305}], {
             RGBColor[
             0.6045891554467802, 0.6839715876022671, 0.9650180629183508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 308}], {
             RGBColor[
             0.2889479905873472, 0.41746139602542953`, 0.9398973079188528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 345}], {
             RGBColor[
             0.28881156407072495`, 0.4173180031065188, 0.9398895386305561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 389}], {
             RGBColor[
             0.29759964420875396`, 0.4265548325280502, 0.9403900067936175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 432}], {
             RGBColor[
             0.5593815103070034, 0.6483170327069279, 0.9606018818614842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 456}], {
             RGBColor[
             0.2990858824276412, 0.4281169631290464, 0.9404746458614907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 289}], {
             RGBColor[
             0.3096443657778342, 0.4423391471866963, 0.9409615308378128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 300}], {
             RGBColor[
             0.361908596774024, 0.4876077971989662, 0.9442917614214452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 308}], {
             RGBColor[
             0.26811333291134537`, 0.39913449062993284`, 0.9385800297199454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 314}], {
             RGBColor[
             0.4535445571442839, 0.5629579737098113, 0.9512415409530388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 466}], {
             RGBColor[
             0.27668923951458074`, 0.40814831221381703`, 0.9390684149140827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 470}], {
             RGBColor[
             0.27610261754366017`, 0.40753173532839826`, 0.9390350076606682]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 493}], {
             RGBColor[
             0.4475753565200481, 0.558111907733633, 0.9507716236139967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 241}], {
             RGBColor[
             0.3816373640692611, 0.5049768359303111, 0.9455385732631909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 274}], {
             RGBColor[
             0.4534869550610022, 0.5663779417903663, 0.9503464835750837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 284}], {
             RGBColor[
             0.3610780260831915, 0.4862793732675318, 0.9442611375927252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 351}], {
             RGBColor[
             0.44127436428483835`, 0.5564632104273317, 0.9493850636929899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 371}], {
             RGBColor[
             0.4848427832349989, 0.5918340156659786, 0.9528149292291238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 429}], {
             RGBColor[
             0.32902794882158914`, 0.4525927099733213, 0.9424359331065173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 432}], {
             RGBColor[
             0.5972113990161616, 0.6810833809213088, 0.9630123689183746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 460}], {
             RGBColor[
             0.6238041371417982, 0.701894914251763, 0.9656530435265088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 258}], {
             RGBColor[
             0.9652466757087061, 0.8877937438229484, 0.4254269020038368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 266}], {
             RGBColor[
             0.857059891141737, 0.3514566373014637, 0.19874471492026624`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 293}], {
             RGBColor[
             0.857059891141737, 0.3514566373014637, 0.19874471492026624`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 403}], {
             RGBColor[
             0.857059891141737, 0.3514566373014637, 0.19874471492026624`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 445}], {
             RGBColor[
             0.857059891141737, 0.3514566373014637, 0.19874471492026624`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 471}], {
             RGBColor[
             0.857059891141737, 0.3514566373014637, 0.19874471492026624`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 483}], {
             RGBColor[
             0.9539815750463821, 0.8506879917634884, 0.30563820376293704`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 497}], {
             RGBColor[
             0.9415558672049971, 0.8059955193602164, 0.27183268277426964`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 251}], {
             RGBColor[
             0.35362694944486533`, 0.47576904067762016`, 0.9439348930085601]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 272}], {
             RGBColor[
             0.41080937826280917`, 0.5222278432198632, 0.9484266860084449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 332}], {
             RGBColor[
             0.23367112063916273`, 0.36293354176948267`, 0.9366185966837315]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 387}], {
             RGBColor[
             0.2385452232211448, 0.3680565326190986, 0.9368961696151867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 435}], {
             RGBColor[
             0.35235214804716863`, 0.47466487178031647`, 0.9438536637907615]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 453}], {
             RGBColor[
             0.356563167030866, 0.4781883251778045, 0.9441562255498472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 454}], {
             RGBColor[
             0.28757758461924476`, 0.4185604006032694, 0.9397262858870317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 489}], {
             RGBColor[
             0.24442557524335845`, 0.37423715543029734`, 0.9372310469636506]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 434}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 495}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 271}], {
             RGBColor[
             0.3224050139052927, 0.4532867845480669, 0.9417784724221802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 304}], {
             RGBColor[
             0.2849583416813991, 0.4139279577846052, 0.9396459398364165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 311}], {
             RGBColor[
             0.28339808968705427`, 0.4122880340128587, 0.9395570857935246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 351}], {
             RGBColor[
             0.39987558997040373`, 0.5206056728790665, 0.946747170401173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 371}], {
             RGBColor[
             0.4434440089205643, 0.5559764781177132, 0.9501770359373067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 429}], {
             RGBColor[
             0.28762917450715453`, 0.416735172425056, 0.9397980398147002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 442}], {
             RGBColor[
             0.3936637903637048, 0.5153935219207971, 0.9463048865121216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 249}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 269}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 282}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 310}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 323}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 419}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 449}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 499}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 273}], {
             RGBColor[
             0.23467481457224915`, 0.36398848773102743`, 0.9366757555683887]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 279}], {
             RGBColor[
             0.27952453425237545`, 0.4111283867513086, 0.9392298807549574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 283}], {
             RGBColor[
             0.2242477894352095, 0.3530290232004211, 0.9360819519122355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 285}], {
             RGBColor[
             0.2946220530898087, 0.4246360657495467, 0.9401761014918839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 318}], {
             RGBColor[
             0.257982887562488, 0.3884867502609507, 0.9380031158439788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 335}], {
             RGBColor[
             0.2849976301701568, 0.4162998743541054, 0.9395628417739867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 396}], {
             RGBColor[
             0.2568146858534386, 0.38725889619647347`, 0.937936588484848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 421}], {
             RGBColor[
             0.22859686998161965`, 0.35760018260233123`, 0.9363296256154655]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 430}], {
             RGBColor[
             0.26568330364733933`, 0.3965803758007084, 0.9384416431482663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 459}], {
             RGBColor[
             0.2504428786429346, 0.3805617228223229, 0.9375737234904538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 477}], {
             RGBColor[
             0.257579961556534, 0.3880632494817088, 0.9379801698040153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 261}], {
             RGBColor[
             0.9518089599069877, 0.9394744537489581, 0.6794087875044705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 262}], {
             RGBColor[
             0.9645316855385555, 0.9492026955642121, 0.6661814817722379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 295}], {
             RGBColor[
             0.8706168078338911, 0.40101609835768304`, 0.23147033256236077`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 341}], {
             RGBColor[
             0.8706168078338911, 0.40101609835768304`, 0.23147033256236077`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 376}], {
             RGBColor[
             0.9816204164865794, 0.9616423487915396, 0.6235919701345964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 391}], {
             RGBColor[
             0.9648781629368668, 0.8921768561625062, 0.323324455739553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 407}], {
             RGBColor[
             0.8327384947978311, 0.845595536100449, 0.6677692177517128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 448}], {
             RGBColor[
             0.9007203648295853, 0.898737794797208, 0.6745359116986607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 455}], {
             RGBColor[
             0.8706168078338911, 0.40101609835768304`, 0.23147033256236077`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 475}], {
             RGBColor[
             0.9597357029053115, 0.9456258595690394, 0.6742998293777165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 478}], {
             RGBColor[
             0.7469756992594796, 0.7766726498372237, 0.6605368645795646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 482}], {
             RGBColor[
             0.9567328878050008, 0.9433863649838862, 0.6793828120829337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 262}], {
             RGBColor[
             0.717395187444922, 0.7773610525896517, 0.9594129365612236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 299}], {
             RGBColor[
             0.4708591211784622, 0.5813036723911794, 0.9514869013144127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 376}], {
             RGBColor[
             0.7344839183929459, 0.7898007058169793, 0.916823424923582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 438}], {
             RGBColor[
             0.3820090099045602, 0.5019364048104593, 0.9458781446689446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 448}], {
             RGBColor[
             0.6535838667359518, 0.7268961518226476, 0.9677673664876463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 475}], {
             RGBColor[
             0.712599204811678, 0.773784216594479, 0.9675312841667021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 482}], {
             RGBColor[
             0.7095963897113673, 0.7715447220093258, 0.9726142668719193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 384}], {
             RGBColor[
             0.5460523779791054, 0.6423489456795577, 0.9574063899317347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 402}], {
             RGBColor[
             0.4049563520885143, 0.5250559960278285, 0.9470572012623077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 411}], {
             RGBColor[
             0.5849971602778163, 0.6728945252540688, 0.9612048898516654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 458}], {
             RGBColor[
             0.45506828709517866`, 0.5684604354315133, 0.9502502894486882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 252}], {
             RGBColor[
             0.1977339169176573, 0.3251612621078617, 0.9345720260961203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 278}], {
             RGBColor[
             0.20238002081431636`, 0.33004461188325157`, 0.9348366148397402]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 309}], {
             RGBColor[
             0.21041747928262017`, 0.3384924903377391, 0.9352943362091559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 401}], {
             RGBColor[
             0.19433196502451466`, 0.32158559497196076`, 0.9343782899685427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 451}], {
             RGBColor[
             0.24679602556146502`, 0.37672864900985814`, 0.9373660406024997]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 339}], {
             RGBColor[
             0.184537889109962, 0.31129140020548685`, 0.9338205318342458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 344}], {
             RGBColor[
             0.20626837332895714`, 0.33413151691192766`, 0.935058050763147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 387}], {
             RGBColor[
             0.2032853235143931, 0.33099614242053865`, 0.9348881704892343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 439}], {
             RGBColor[
             0.22555407263405997`, 0.35440200966555135`, 0.9361563428079372]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 269}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 282}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 310}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 323}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 406}], {
             RGBColor[
             0.8761600890568056, 0.41916385235227993`, 0.29986098883365586`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 419}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 499}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 263}], {
             RGBColor[
             0.37074736764175087`, 0.49554446837193705`, 0.9448446723204758]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 365}], {
             RGBColor[
             0.3297610853863787, 0.45923924976533154`, 0.9422625362213943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 485}], {
             RGBColor[
             0.45702605481315906`, 0.567525512507305, 0.9511018911536404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 258}], {
             RGBColor[
             0.7229805531619574, 0.7777005783665802, 0.766539139108648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 272}], {
             RGBColor[
             0.5091918571496574, 0.6123883835338977, 0.9545144119703061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 435}], {
             RGBColor[
             0.4507346269340168, 0.564825412094351, 0.9499413897526227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 447}], {
             RGBColor[
             0.4395361264241692, 0.5551258338057223, 0.9492278312025804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 453}], {
             RGBColor[
             0.4549456459177142, 0.5683488654918392, 0.9502439515117083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 454}], {
             RGBColor[
             0.38596006350609297`, 0.5087209409173039, 0.9458140118488928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 309}], {
             RGBColor[
             0.20616935749267296`, 0.33402744499002646`, 0.9350524119577515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 320}], {
             RGBColor[
             0.19096927332444358`, 0.31805119278821803`, 0.9341867896508802]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 424}], {
             RGBColor[
             0.21753234437929125`, 0.3459706646628423, 0.9356995172509117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 287}], {
             RGBColor[
             0.9130361340711288, 0.9314864712143058, 0.9153283035663997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 301}], {
             RGBColor[
             0.8742585681452911, 0.41920555006140414`, 0.39156282211394233`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 336}], {
             RGBColor[
             0.8742585681452911, 0.41920555006140414`, 0.39156282211394233`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 354}], {
             RGBColor[
             0.9250268564024191, 0.9410475477217897, 0.9164719893666022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 388}], {
             RGBColor[
             0.9562289934034156, 0.9659272848069381, 0.9194480770482338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 436}], {
             RGBColor[
             0.9789187620697407, 0.9831427029239654, 0.8912134737088222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 473}], {
             RGBColor[
             0.7972247522261032, 0.8403164546648092, 0.9042013493569341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 350}], {
             RGBColor[
             0.21360194576422215`, 0.3418395665167393, 0.9354756868642873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 377}], {
             RGBColor[
             0.21202393940718356`, 0.34018098178411005`, 0.935385821736705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 412}], {
             RGBColor[
             0.2324070785907567, 0.36160495343171317`, 0.9365466113590574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 426}], {
             RGBColor[
             0.22616397907446353`, 0.3550430600047173, 0.9361910760774426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 476}], {
             RGBColor[
             0.217706390843879, 0.3461535985323073, 0.9357094289395913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 260}], {
             RGBColor[
             0.284773382847451, 0.41634105132452215`, 0.9395399334660819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 299}], {
             RGBColor[
             0.3581446545361039, 0.47974328518246506`, 0.9442560545474505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 312}], {
             RGBColor[
             0.25276894068346034`, 0.3830065615077669, 0.9377061892825613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 327}], {
             RGBColor[
             0.22866910912003982`, 0.35767611051703674`, 0.9363337395275303]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 334}], {
             RGBColor[
             0.23529404619959324`, 0.3646393394329189, 0.9367110198934947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 385}], {
             RGBColor[
             0.2238798414279229, 0.35264228651551177`, 0.9360609978175509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 446}], {
             RGBColor[
             0.22786776900005848`, 0.3568338512430382, 0.9362881043931739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 478}], {
             RGBColor[
             0.38712473452348783`, 0.5032706196539489, 0.9465374726015883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 287}], {
             RGBColor[
             0.8515970726599524, 0.8845044060250485, 0.9857072830916294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 298}], {
             RGBColor[
             0.7725153841740422, 0.8225801022129446, 0.9778636612646125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 409}], {
             RGBColor[
             0.7032931179635095, 0.7669554550610453, 0.9720223945230841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 281}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 317}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 322}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 324}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 326}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 343}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 374}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 445}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 272}], {
             RGBColor[
             0.7801629819799012, 0.8241593809088232, 0.7710309321085329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 293}], {
             RGBColor[
             0.8761965593307338, 0.419241858580502, 0.3038305530822916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 403}], {
             RGBColor[
             0.8761965593307338, 0.419241858580502, 0.3038305530822916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 435}], {
             RGBColor[
             0.7217057517642607, 0.7765964094692765, 0.7664579098908495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 453}], {
             RGBColor[
             0.7259167707479581, 0.7801198628667647, 0.7667604716499351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 471}], {
             RGBColor[
             0.8761965593307338, 0.419241858580502, 0.3038305530822916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 497}], {
             RGBColor[
             0.9702608694884922, 0.9076733512787738, 0.4294614400173077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 275}], {
             RGBColor[
             0.8560290549644465, 0.34736971536429956`, 0.19791527993518332`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 331}], {
             RGBColor[
             0.8207108366647649, 0.37784655893402913`, 0.4372814530493224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 348}], {
             RGBColor[
             0.8657911144896757, 0.38473790158096455`, 0.21272342517580606`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 372}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 400}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 404}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 418}], {
             RGBColor[
             0.8610616366179067, 0.36732222461184755`, 0.20196461326343138`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 431}], {
             RGBColor[
             0.8760289938084724, 0.418883452871858, 0.28559208007867803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 444}], {
             RGBColor[
             0.8285562969045, 0.22050178822288907`, 0.17497884820646079`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 486}], {
             RGBColor[
             0.8762475134266291, 0.4193508442393725, 0.30937659196826445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 299}], {
             RGBColor[
             0.38540754335386535`, 0.5080941018004876, 0.945819774282403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 312}], {
             RGBColor[
             0.28003182950122174`, 0.41135737812578943`, 0.9392699090175137]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 328}], {
             RGBColor[
             0.3945437578035354, 0.5155112922725004, 0.9465390105509373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 334}], {
             RGBColor[
             0.26255693501735466`, 0.39299015605094145`, 0.9382747396284472]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 399}], {
             RGBColor[
             0.3078369305811183, 0.44058230230599205`, 0.9408533683900531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 407}], {
             RGBColor[
             0.5001504188796009, 0.6005443225351969, 0.9553335455086889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 446}], {
             RGBColor[
             0.25513065781781996`, 0.38518466786106076`, 0.9378518241281263]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 478}], {
             RGBColor[
             0.41438762334124934`, 0.5316214362719716, 0.9481011923365408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 262}], {
             RGBColor[
             0.9391282219438701, 0.953882854240121, 0.979615271589626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 299}], {
             RGBColor[
             0.6925921556774102, 0.7578254740416488, 0.9716892363428151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 313}], {
             RGBColor[
             0.9521701236341322, 0.9636094831665644, 0.9575387339007462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 328}], {
             RGBColor[
             0.7017283701270802, 0.7652426645136615, 0.9724084726113494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 391}], {
             RGBColor[
             0.9394746993421814, 0.8968570148384152, 0.6367582455569412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 407}], {
             RGBColor[
             0.8073350312031458, 0.850275694776358, 0.981203007569101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 448}], {
             RGBColor[
             0.8753169012348998, 0.903417953473117, 0.9879697015160488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 455}], {
             RGBColor[
             0.8536811654374341, 0.40413620414162243`, 0.44042619244061953`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 475}], {
             RGBColor[
             0.9343322393106261, 0.9503060182449484, 0.9877336191951046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 478}], {
             RGBColor[
             0.7215722356647942, 0.7813528085131327, 0.9739706543969529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 482}], {
             RGBColor[
             0.9313294242103154, 0.9480665236597952, 0.992816601900322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 299}], {
             RGBColor[
             0.7053148813089781, 0.7675537158569028, 0.9584619306105826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 376}], {
             RGBColor[
             0.968939678523462, 0.9760507492827026, 0.9237984542197519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 391}], {
             RGBColor[
             0.9521974249737493, 0.9065852566536692, 0.6235309398247086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 448}], {
             RGBColor[
             0.8880396268664679, 0.9131461952883709, 0.9747423957838162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 455}], {
             RGBColor[
             0.862162982525146, 0.410621698685125, 0.4316079886191312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 475}], {
             RGBColor[
             0.947054964942194, 0.9600342600602023, 0.974506313462872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 478}], {
             RGBColor[
             0.7342949612963621, 0.7910810503283867, 0.9607433486647203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 482}], {
             RGBColor[
             0.9440521498418833, 0.9577947654750492, 0.9795892961680893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 267}], {
             RGBColor[
             0.3938098760277288, 0.5155200539804957, 0.9463141949614547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 393}], {
             RGBColor[
             0.37476311386086897`, 0.49902270590966347`, 0.9451005521185729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 485}], {
             RGBColor[
             0.4682909081362715, 0.5772825622677944, 0.9518196776462704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 281}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 295}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 324}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 341}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 374}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 397}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 270}], {
             RGBColor[
             0.1931041910883242, 0.32029512671966087`, 0.9343083700592054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 320}], {
             RGBColor[
             0.1953107306009688, 0.32261433965013586`, 0.9344340292201678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 329}], {
             RGBColor[
             0.19625946576950848`, 0.3236115204655551, 0.9344880582844883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 424}], {
             RGBColor[
             0.2218738016558165, 0.3505338115247602, 0.9359467568201993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 293}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 317}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 322}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 343}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 359}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 403}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 440}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 445}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 471}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 483}], {
             RGBColor[
             0.8686864922225178, 0.39450469054086185`, 0.22397142092169176`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 280}], {
             RGBColor[
             0.47422028597903365`, 0.5827369663057078, 0.9521094415156451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 393}], {
             RGBColor[
             0.3865607689237344, 0.5092412417577328, 0.9458522882669219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 424}], {
             RGBColor[
             0.32359321236073335`, 0.4484918511970504, 0.9420674318834557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 480}], {
             RGBColor[
             0.44250442747306074`, 0.5569886035874154, 0.9496126529550372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 485}], {
             RGBColor[
             0.48008856319913695`, 0.5875010981158637, 0.9525714137946194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 491}], {
             RGBColor[
             0.2006246214741492, 0.3281995758779894, 0.9347366474441984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 282}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 310}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 323}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 406}], {
             RGBColor[
             0.8761600890568056, 0.41916385235227993`, 0.29986098883365586`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 411}], {
             RGBColor[
             0.7823157613673747, 0.34781156452747625`, 0.43346533019890965`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 419}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 499}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 329}], {
             RGBColor[
             0.18719494717707214`, 0.31408413670123125`, 0.9339718473604026]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 479}], {
             RGBColor[
             0.18878700248308236`, 0.3157574877699845, 0.9340625125548451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 304}], {
             RGBColor[
             0.26712476583186534`, 0.39809544395062635`, 0.9385237322872229]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 307}], {
             RGBColor[
             0.26941629466210404`, 0.4005039860425267, 0.9386542314640918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 311}], {
             RGBColor[
             0.2655645138375205, 0.3964555201788798, 0.9384348782443309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 351}], {
             RGBColor[
             0.3820420141208699, 0.5047731590450875, 0.9456249628519793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 371}], {
             RGBColor[
             0.4256104330710305, 0.5401439642837345, 0.9490548283881131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 429}], {
             RGBColor[
             0.26979559865762076`, 0.4009026585910771, 0.9386758322655065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 442}], {
             RGBColor[
             0.37583021451417103`, 0.49956100808681825`, 0.945182678962928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 435}], {
             RGBColor[
             0.5079170557519607, 0.611284214636594, 0.9544331827525074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 453}], {
             RGBColor[
             0.512128074735658, 0.6148076680340822, 0.9547357445115932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 497}], {
             RGBColor[
             0.7564721734761921, 0.7423611564460912, 0.6174367128789657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 279}], {
             RGBColor[
             0.2592350022653147, 0.38980280220227903`, 0.938074421923967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 283}], {
             RGBColor[
             0.2039582574481488, 0.3317034386513916, 0.9349264930812451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 285}], {
             RGBColor[
             0.27433252110274803`, 0.40331048120051716`, 0.9390206426608936]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 396}], {
             RGBColor[
             0.23652515386637785`, 0.3659333116474439, 0.9367811296538575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 421}], {
             RGBColor[
             0.20830733799455892`, 0.33627459805330173`, 0.9351741667844751]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 430}], {
             RGBColor[
             0.2453937716602786, 0.3752547912516788, 0.937286184317276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 459}], {
             RGBColor[
             0.23015334665587384`, 0.35923613827329337`, 0.9364182646594634]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 477}], {
             RGBColor[
             0.23729042956947327`, 0.36673766493267923`, 0.9368247109730249]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 284}], {
             RGBColor[
             0.39152884276049793`, 0.5118229415793216, 0.9464311546128009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 300}], {
             RGBColor[
             0.45102395983649046`, 0.5642446191206338, 0.9501895436973189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 305}], {
             RGBColor[
             0.6728698608332448, 0.742281504128438, 0.9695985669953169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 389}], {
             RGBColor[
             0.36588034959521865`, 0.4848647490542211, 0.9449705108705836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 432}], {
             RGBColor[
             0.627662215693468, 0.7066269492330988, 0.9651823859384503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 460}], {
             RGBColor[
             0.6542549538191047, 0.7274384825635528, 0.9678230605465845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 331}], {
             RGBColor[
             0.880471837443817, 0.8195704114474931, 0.6243590994767585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 346}], {
             RGBColor[
             0.9582193150286128, 0.8640683796032405, 0.32686377672377676`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 348}], {
             RGBColor[
             0.9480922541811833, 0.8299074254178962, 0.2875220576664841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 355}], {
             RGBColor[
             0.8823446787500739, 0.5496431313605049, 0.22311515099154627`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 372}], {
             RGBColor[
             0.8560290549644465, 0.3473697153642996, 0.19791527993518332`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 404}], {
             RGBColor[
             0.8560290549644465, 0.3473697153642996, 0.19791527993518332`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 418}], {
             RGBColor[
             0.9409980373735297, 0.8037839099642208, 0.271383839797922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 431}], {
             RGBColor[
             0.9634490731593783, 0.8811257523542364, 0.396825040020792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 444}], {
             RGBColor[
             0.8785036487734464, 0.5201192918100778, 0.21943697634810488`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 486}], {
             RGBColor[
             0.9637768525866133, 0.8818268394055082, 0.43250180785517167`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 306}], {
             RGBColor[
             0.3968212348923211, 0.5178614200121557, 0.946579827335847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 347}], {
             RGBColor[
             0.3067228826426153, 0.4377048288177037, 0.9408524097411209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 382}], {
             RGBColor[
             0.3268271732727834, 0.45750300350269213`, 0.9420461163723881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 462}], {
             RGBColor[
             0.2787032871192142, 0.40825445737764454`, 0.9392567352273402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 288}], {
             RGBColor[
             0.8718851812720558, 0.40529461979285863`, 0.23639772385740537`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 313}], {
             RGBColor[
             0.9794761473860648, 0.9653471066434187, 0.651496031025925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 340}], {
             RGBColor[
             0.9813346158030243, 0.9667331493458243, 0.648350128762206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 373}], {
             RGBColor[
             0.8718851812720558, 0.40529461979285863`, 0.23639772385740537`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 386}], {
             RGBColor[
             0.9122570409032669, 0.9128375594706262, 0.6828459092178139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 414}], {
             RGBColor[
             0.987174698071661, 0.9678878453482673, 0.4481743161496815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 498}], {
             RGBColor[
             0.8718851812720558, 0.40529461979285863`, 0.23639772385740537`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 401}], {
             RGBColor[
             0.19472994713122652`, 0.3220038993996379, 0.9344009544607581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 451}], {
             RGBColor[
             0.24719400766817687`, 0.37714695343753535`, 0.9373887050947152]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.31918224078287427`, 0.4504503802207983, 0.9415747678474624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 318}], {
             RGBColor[
             0.28254307525555356`, 0.4143010647322023, 0.9394017821995571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 335}], {
             RGBColor[
             0.30955781786322234`, 0.442114188825357, 0.9409615081295651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 396}], {
             RGBColor[
             0.28137487354650415`, 0.413073210667725, 0.9393352548404263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 409}], {
             RGBColor[
             0.42270568812946974`, 0.5377275457694766, 0.9488314553822088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 421}], {
             RGBColor[
             0.2531570576746852, 0.38341449707358277`, 0.9377282919710439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 430}], {
             RGBColor[
             0.2902434913404049, 0.42239469027195997`, 0.9398403095038447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 459}], {
             RGBColor[
             0.27500306633600013`, 0.4063760372935745, 0.9389723898460322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 477}], {
             RGBColor[
             0.28214014924959957`, 0.4138775639529604, 0.9393788361595936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 338}], {
             RGBColor[
             0.768013484678197, 0.8137930844785333, 0.728866127012082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 383}], {
             RGBColor[
             0.5876838324912708, 0.6761472359281866, 0.9606837705319751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 393}], {
             RGBColor[
             0.4551735238121738, 0.5662396182348755, 0.9508957986727633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 480}], {
             RGBColor[
             0.5111171823615002, 0.6139869800645582, 0.9546561633608786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 317}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 322}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 324}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 343}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 374}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 397}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 445}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 310}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 323}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 406}], {
             RGBColor[
             0.8761600890568056, 0.41916385235227993`, 0.29986098883365586`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 419}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 499}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 396}], {
             RGBColor[
             0.2260981287293382, 0.35497384711683755`, 0.9361873259977045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 421}], {
             RGBColor[
             0.19788031285751928`, 0.32531513352269537`, 0.934580363128322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 430}], {
             RGBColor[
             0.23496674652323896`, 0.3642953267210725, 0.9366923806611228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 459}], {
             RGBColor[
             0.2197263215188342, 0.34827667374268706`, 0.9358244610033103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 477}], {
             RGBColor[
             0.22686340443243364`, 0.3557782004020729, 0.9362309073168718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 300}], {
             RGBColor[
             0.3586150308586798, 0.48414605059779925`, 0.9441041977149605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 345}], {
             RGBColor[
             0.2646833404793789, 0.39552935110985515`, 0.9383846967251639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 389}], {
             RGBColor[
             0.2734714206174079, 0.4047661805313866, 0.9388851648882252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 432}], {
             RGBColor[
             0.5352532867156573, 0.6265283807102642, 0.9590970399560919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 456}], {
             RGBColor[
             0.2749576588362952, 0.40632831113238277`, 0.9389698039560983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 472}], {
             RGBColor[
             0.24808825888161617`, 0.3780868681616617, 0.9374396313783945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 287}], {
             RGBColor[
             0.586107161663346, 0.6687841757317179, 0.9634625646876807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 354}], {
             RGBColor[
             0.5980978839946363, 0.6783452522392017, 0.9646062504878833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 396}], {
             RGBColor[
             0.2964723923839374, 0.4265808896659632, 0.940281475577353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 409}], {
             RGBColor[
             0.437803206966903, 0.5512352247677147, 0.9497776761191354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 430}], {
             RGBColor[
             0.3053410101778382, 0.4359023692701981, 0.9407865302407712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 473}], {
             RGBColor[
             0.4702957798183204, 0.5776141591822213, 0.9523356104782151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 477}], {
             RGBColor[
             0.2972376680870329, 0.4273852429511985, 0.9403250568965202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 319}], {
             RGBColor[
             0.2013361778689116, 0.32894746676416586`, 0.9347771695282268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 330}], {
             RGBColor[
             0.22011222124554525`, 0.3486822788229162, 0.935846437421859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 357}], {
             RGBColor[
             0.21788015626742555`, 0.3463362370098189, 0.9357193246233994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 358}], {
             RGBColor[
             0.30001627431624434`, 0.4256508881874809, 0.9406537311281724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 367}], {
             RGBColor[
             0.23641375708701462`, 0.36581622656936946`, 0.9367747857720696]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 368}], {
             RGBColor[
             0.19782344597820478`, 0.32525536282696743`, 0.934577124643672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 492}], {
             RGBColor[
             0.20509632372891637`, 0.3328996184700481, 0.9349913042723167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 336}], {
             RGBColor[
             0.8241908545687948, 0.38062143074813315`, 0.4376133802636575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 354}], {
             RGBColor[
             0.8499252860376748, 0.8831713687518833, 0.985547826591175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 388}], {
             RGBColor[
             0.8811274230386713, 0.9080511058370317, 0.9885239142728066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 409}], {
             RGBColor[
             0.6896306090099416, 0.7560613412803963, 0.970719252222427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 436}], {
             RGBColor[
             0.9038171917049964, 0.925266523954059, 0.9602893109333949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 473}], {
             RGBColor[
             0.7221231818613589, 0.7824402756949027, 0.9732771865815069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 313}], {
             RGBColor[
             0.8708575836519874, 0.41710611796942054`, 0.41689029682654455`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 321}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 373}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 386}], {
             RGBColor[
             0.8260448459967887, 0.38209975318755884`, 0.4377902156211372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 391}], {
             RGBColor[
             0.8623939674573535, 0.3726044724173211, 0.20303663793067456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 455}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 498}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 300}], {
             RGBColor[
             0.36584591693848256`, 0.4912990781268415, 0.9445323562158461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 308}], {
             RGBColor[
             0.2720506530758039, 0.4028257715578081, 0.9388206245143462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 314}], {
             RGBColor[
             0.4574818773087424, 0.5666492546376866, 0.9514821357474397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 466}], {
             RGBColor[
             0.28062655967903927`, 0.4118395931416923, 0.9393090097084835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 470}], {
             RGBColor[
             0.28003993770811864`, 0.41122301625627355`, 0.939275602455069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 493}], {
             RGBColor[
             0.4515126766845066, 0.5618031886615082, 0.9510122184083976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 297}], {
             RGBColor[
             0.21970848593960174`, 0.3482579274180727, 0.9358234452934584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 484}], {
             RGBColor[
             0.19720039887588448`, 0.3246005008189609, 0.9345416430329105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 349}], {
             RGBColor[
             0.20137038883349692`, 0.32898342465704544`, 0.9347791177920493]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 353}], {
             RGBColor[
             0.19170554293633024`, 0.31882505883250056`, 0.9342287191160639]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 394}], {
             RGBColor[
             0.1976212181124982, 0.32504280851812256`, 0.9345656080658895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 467}], {
             RGBColor[
             0.21418854935951206`, 0.34245612408820514`, 0.9355090930712366]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 398}], {
             RGBColor[
             0.2511316087278431, 0.3812856218095713, 0.9376129456499045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 399}], {
             RGBColor[
             0.2546203091758611, 0.3849524671768223, 0.9378116219793493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 464}], {
             RGBColor[
             0.24293630539384, 0.37267183839329127`, 0.9371462352488977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 481}], {
             RGBColor[
             0.24899857925793986`, 0.3790436725948234, 0.9374914727771277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 496}], {
             RGBColor[
             0.20710059025010286`, 0.3350062296616523, 0.9351054442856517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 343}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 403}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 440}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 445}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 471}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 483}], {
             RGBColor[
             0.8686864922225178, 0.39450469054086185`, 0.22397142092169176`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 497}], {
             RGBColor[
             0.8604026869949277, 0.3647097089386806, 0.20143440692924686`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 296}], {
             RGBColor[
             0.2044861367384871, 0.3322582732550172, 0.9349565550259025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 327}], {
             RGBColor[
             0.20782428065513164`, 0.3357668741619594, 0.935146657383614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 385}], {
             RGBColor[
             0.2030350129630147, 0.3307330501604344, 0.9348739156736345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 415}], {
             RGBColor[
             0.20054448474921935`, 0.3281153470991263, 0.9347320837762653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 438}], {
             RGBColor[
             0.24844971479729377`, 0.37846678124666755`, 0.9374602157580663]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 439}], {
             RGBColor[
             0.2411021556117397, 0.370744030680491, 0.9370417831321887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 321}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 341}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 391}], {
             RGBColor[
             0.8623939674573535, 0.3726044724173211, 0.20303663793067456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 397}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 455}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 327}], {
             RGBColor[
             0.19648958029374552`, 0.3238533854206317, 0.9345011629662197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 339}], {
             RGBColor[
             0.1887512717262556, 0.3157199324790988, 0.9340604777411028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 385}], {
             RGBColor[
             0.19170031260162856`, 0.3188195614191067, 0.9342284212562402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 415}], {
             RGBColor[
             0.1892097843878332, 0.3162018583577987, 0.9340865893588708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 438}], {
             RGBColor[
             0.23711501443590766`, 0.3665532925053399, 0.9368147213406718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 325}], {
             RGBColor[
             0.3379519408599507, 0.461641809531562, 0.9429562454735485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 392}], {
             RGBColor[
             0.3456632797932826, 0.4683209837324499, 0.943447605171511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 412}], {
             RGBColor[
             0.23850869796425644`, 0.3680181422582739, 0.9368940895558412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 413}], {
             RGBColor[
             0.32997558728000875`, 0.45473309296380404`, 0.9424479992766471]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 474}], {
             RGBColor[
             0.3280652758488244, 0.45307847721715644`, 0.9423262759214741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 484}], {
             RGBColor[
             0.2267841294164104, 0.35569487733390615`, 0.9362263927219862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 490}], {
             RGBColor[
             0.295576036933824, 0.4249379314256113, 0.9402560903469162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 335}], {
             RGBColor[
             0.4974010502577838, 0.5985236805241728, 0.9550056831427665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 409}], {
             RGBColor[
             0.6105489205240312, 0.6941370374682924, 0.9628756303954102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 468}], {
             RGBColor[
             0.5240878676490316, 0.621638460430029, 0.9567061435487108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 312}], {
             RGBColor[
             0.3534031011898746, 0.4747596119837323, 0.9439860300988824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 328}], {
             RGBColor[
             0.4679150294921883, 0.5789135261304432, 0.9512551316323059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 399}], {
             RGBColor[
             0.38120820226977115`, 0.5039845361639349, 0.9455694894714217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 407}], {
             RGBColor[
             0.5735216905682538, 0.6639465563931397, 0.9600496665900575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 448}], {
             RGBColor[
             0.6415035606000079, 0.7170888150898986, 0.9668163605370053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 475}], {
             RGBColor[
             0.7005188986757341, 0.7639768798617301, 0.9665802782160611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 478}], {
             RGBColor[
             0.4877588950299022, 0.5950236701299144, 0.9528173134179094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 482}], {
             RGBColor[
             0.6975160835754234, 0.7617373852765769, 0.9716632609212784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 305}], {
             RGBColor[
             0.6399560489314267, 0.7146046131469155, 0.9672716100974765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 308}], {
             RGBColor[
             0.3243148840719937, 0.448094421570078, 0.9421508550979786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 432}], {
             RGBColor[
             0.5947484037916498, 0.6789500582515764, 0.96285542904061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 456}], {
             RGBColor[
             0.3344527759122877, 0.4587499886736949, 0.9427281930406164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 493}], {
             RGBColor[
             0.5037769076806964, 0.6070718386737781, 0.9543424489920299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 316}], {
             RGBColor[
             0.8735231410973765, 0.4108198428949215, 0.24276088847601782`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 336}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 388}], {
             RGBColor[
             0.8529860941236527, 0.4035819731432213, 0.44035989591821356`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 436}], {
             RGBColor[
             0.8681126065678694, 0.4150589185545728, 0.4215368270252724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 346}], {
             RGBColor[
             0.7355852203061626, 0.7748239735708853, 0.6706341273882959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 370}], {
             RGBColor[
             0.4457020294385857, 0.5595198175689367, 0.9498822686739312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 390}], {
             RGBColor[
             0.5231595548827668, 0.6237635205800223, 0.9556041830384168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 422}], {
             RGBColor[
             0.3930257524734591, 0.5128887624932172, 0.9465625995891717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 443}], {
             RGBColor[
             0.6197751789448227, 0.7005305366504255, 0.9643518386481924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 451}], {
             RGBColor[
             0.38989549393188216`, 0.5095986622961652, 0.9463843359960313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 379}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 400}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 307}], {
             RGBColor[
             0.23196962243821045`, 0.361145159279065, 0.9365216988783283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 311}], {
             RGBColor[
             0.22811784161362691`, 0.3570966934154181, 0.9363023456585673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 337}], {
             RGBColor[
             0.2261823882456348, 0.3550624092108272, 0.9361921244525068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 423}], {
             RGBColor[
             0.20489033009065757`, 0.3326831060954871, 0.9349795732393582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 427}], {
             RGBColor[
             0.22064336651454602`, 0.34924054617719114`, 0.9358766853591696]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 433}], {
             RGBColor[
             0.2080639244096152, 0.3360187549422132, 0.9351603047409107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 465}], {
             RGBColor[
             0.2045659825518425, 0.33234219626737077`, 0.9349611021268518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 469}], {
             RGBColor[
             0.20952654949252203`, 0.3375560666401347, 0.9352435990756223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 310}], {
             RGBColor[
             0.8321466499760604, 0.3869651660515733, 0.4383722111318249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 406}], {
             RGBColor[
             0.9278221085492989, 0.9409395276057798, 0.778913799948221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 432}], {
             RGBColor[
             0.8165943047884041, 0.8569869432593805, 0.9822644523386079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 460}], {
             RGBColor[
             0.8431870429140408, 0.8777984765898346, 0.9849051269467421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 493}], {
             RGBColor[
             0.7256228086774508, 0.7851087236815824, 0.973751472290028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 331}], {
             RGBColor[
             0.6453215149169124, 0.720164767833845, 0.9671441268400578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 347}], {
             RGBColor[
             0.37305016758982446`, 0.49488726767115054`, 0.9451524769374224]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 382}], {
             RGBColor[
             0.3931544582199925, 0.514685442356139, 0.9463461835686895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 431}], {
             RGBColor[
             0.7282987506324737, 0.7817201087405883, 0.7396100673840913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 486}], {
             RGBColor[
             0.7286265300597087, 0.7824211957918601, 0.775286835218471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 337}], {
             RGBColor[
             0.2284739170758735, 0.35747095130272755`, 0.9363226236293758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 427}], {
             RGBColor[
             0.22293489534478472`, 0.35164908826909147`, 0.9360071845360386]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 433}], {
             RGBColor[
             0.2103554532398539, 0.33842729703411356`, 0.9352908039177796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 442}], {
             RGBColor[
             0.34067507112051615`, 0.4626107234152569, 0.9431806455540332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 469}], {
             RGBColor[
             0.21181807832276073`, 0.33996460873203505`, 0.9353740982524913]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 500}], {
             RGBColor[
             0.2541094521417272, 0.3844155240437408, 0.9377825294270006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 362}], {
             RGBColor[
             0.20539074651933456`, 0.3332090754902608, 0.9350080712146716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 369}], {
             RGBColor[
             0.21139967119728387`, 0.33952483631461483`, 0.9353502705856733]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 389}], {
             RGBColor[
             0.23917127383072181`, 0.36871455150366533`, 0.9369318222712433]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 456}], {
             RGBColor[
             0.24065751204960906`, 0.3702766821046615, 0.9370164613391165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 393}], {
             RGBColor[
             0.2931834633072552, 0.42005128345340215`, 0.9402066837474136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 424}], {
             RGBColor[
             0.23021590674425413`, 0.35930189289271974`, 0.9364218273639473]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 323}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 406}], {
             RGBColor[
             0.8761600890568056, 0.41916385235227993`, 0.29986098883365586`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 408}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 419}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 366}], {
             RGBColor[
             0.21056004147512417`, 0.3386423322410259, 0.9353024549151172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 405}], {
             RGBColor[
             0.20862681857218934`, 0.3366103923966298, 0.935192360730742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 423}], {
             RGBColor[
             0.20333007809631276`, 0.3310431823237406, 0.9348907191964662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 429}], {
             RGBColor[
             0.23078867443938234`, 0.35990390805586886`, 0.936454445636851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 465}], {
             RGBColor[
             0.20300573055749768`, 0.3307022724956242, 0.9348722480839599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 469}], {
             RGBColor[
             0.2079662974981772, 0.3359161428683881, 0.9351547450327304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 488}], {
             RGBColor[
             0.21049948038445382`, 0.3385786786949364, 0.9352990060505957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 327}], {
             RGBColor[
             0.22392755577381057`, 0.35269243731830396`, 0.9360637150789621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 334}], {
             RGBColor[
             0.230552492853364, 0.3596556662341861, 0.9364409954449265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 385}], {
             RGBColor[
             0.21913828808169364`, 0.347658613316779, 0.9357909733689826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 415}], {
             RGBColor[
             0.21664775986789828`, 0.3450409102554709, 0.9356491414716133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 446}], {
             RGBColor[
             0.22312621565382923`, 0.3518501780443054, 0.9360180799446056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 386}], {
             RGBColor[
             0.9107156444731642, 0.9305548067354691, 0.9535847686715226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 391}], {
             RGBColor[
             0.9652393266640114, 0.9163118855801125, 0.6014544021358288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 407}], {
             RGBColor[
             0.8330996585249757, 0.8697305655180553, 0.9458991641479886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 498}], {
             RGBColor[
             0.8708575836519874, 0.41710611796942054`, 0.41689029682654466`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 406}], {
             RGBColor[
             0.7976121679228045, 0.8382528191088208, 0.7664545561818166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 411}], {
             RGBColor[
             0.656845676388658, 0.7312243873716151, 0.9668610682296974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 493}], {
             RGBColor[
             0.5954128680509563, 0.6824220151846232, 0.9612922285236236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 349}], {
             RGBColor[
             0.202082172054935, 0.3297315539524397, 0.9348196527935213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 353}], {
             RGBColor[
             0.1924173261577683, 0.31957318812789476`, 0.9342692541175359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 364}], {
             RGBColor[
             0.2434271231031161, 0.3731877189253806, 0.9371741865913413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 378}], {
             RGBColor[
             0.24896710191064286`, 0.3790105879070351, 0.9374896801887658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 380}], {
             RGBColor[
             0.2069794182961998, 0.33487887025535457`, 0.9350985437221347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 487}], {
             RGBColor[
             0.21833205101187592`, 0.3468112070380179, 0.9357450593605774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 372}], {
             RGBColor[
             0.8735231410973765, 0.41081984289492157`, 0.24276088847601784`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 418}], {
             RGBColor[
             0.9672391665729247, 0.8989591012601537, 0.3386522526091738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 322}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 343}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 374}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 440}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 445}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 471}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 335}], {
             RGBColor[
             0.2880161711733349, 0.41947255233499914`, 0.9397347432185865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 421}], {
             RGBColor[
             0.23161541098479776`, 0.360772860583225, 0.9365015270600652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 430}], {
             RGBColor[
             0.26870184465051744`, 0.3997530537816021, 0.9386135445928661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 459}], {
             RGBColor[
             0.2534614196461127, 0.38373440080321664`, 0.9377456249350535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 330}], {
             RGBColor[
             0.20604176576710181`, 0.3338933379966685, 0.9350451457977351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 357}], {
             RGBColor[
             0.2038097007889821, 0.3315472961835712, 0.9349180329992755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 368}], {
             RGBColor[
             0.18375299049976135`, 0.3104664220007197, 0.9337758330195483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 492}], {
             RGBColor[
             0.19102586825047294`, 0.3181106776438004, 0.9341900126481928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 329}], {
             RGBColor[
             0.18940148668971674`, 0.3164033496317062, 0.934097506521365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 424}], {
             RGBColor[
             0.2150158225760247, 0.3433256406909113, 0.935556205057076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 341}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 373}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 391}], {
             RGBColor[
             0.8623939674573535, 0.3726044724173211, 0.20303663793067456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 397}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 455}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 498}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 343}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 374}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 440}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 445}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 471}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 419}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 449}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 499}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 342}], {
             RGBColor[
             0.8611372113207705, 0.36762185312492557`, 0.20202542244332183`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 360}], {
             RGBColor[
             0.8191009627097754, 0.1478239462483719, 0.1659244095033199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 457}], {
             RGBColor[
             0.8638009847389825, 0.3780247266271895, 0.20499214689883155`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 392}], {
             RGBColor[
             0.4343230041731056, 0.550610489330994, 0.9488956556625256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 413}], {
             RGBColor[
             0.4186353116598318, 0.5370225985623481, 0.9478960497676616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 474}], {
             RGBColor[
             0.4167250002286474, 0.5353679828157005, 0.9477743264124886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 490}], {
             RGBColor[
             0.384235761313647, 0.5072274370241554, 0.9457041408379308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 338}], {
             RGBColor[
             0.8759439761629737, 0.4187016087247386, 0.2763384340342258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 346}], {
             RGBColor[
             0.8725424883879621, 0.4075118710378607, 0.23895123788066785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 355}], {
             RGBColor[
             0.8304768118928137, 0.23526370799810264`, 0.17681793552818148`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 395}], {
             RGBColor[
             0.8502020870562027, 0.32426772933006165`, 0.19322676477969444`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 443}], {
             RGBColor[
             0.7953357941470689, 0.3579829130908875, 0.4347630453872655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 334}], {
             RGBColor[
             0.2064526612899435, 0.33432521524345593`, 0.9350685456898955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 385}], {
             RGBColor[
             0.19503845651827315`, 0.32232816232604883`, 0.9344185236139517]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 415}], {
             RGBColor[
             0.19254792830447778`, 0.31971045926474073`, 0.9342766917165823]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 446}], {
             RGBColor[
             0.19902638409040874`, 0.32651972705357524`, 0.9346456301895747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 398}], {
             RGBColor[
             0.38685571627142323`, 0.5077348812686966, 0.9460900494105111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 399}], {
             RGBColor[
             0.3903444167194412, 0.5114017266359476, 0.9462887257399559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 407}], {
             RGBColor[
             0.5826579050179238, 0.6713637468651524, 0.9607689028585917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 464}], {
             RGBColor[
             0.37866041293742014`, 0.4991210978524166, 0.9456233390095045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 475}], {
             RGBColor[
             0.7096551131254042, 0.7713940703337429, 0.9672995144845954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 478}], {
             RGBColor[
             0.4968951094795723, 0.6024408606019271, 0.9535365496864436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 481}], {
             RGBColor[
             0.38472268680152, 0.5054929320539487, 0.9459685765377344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 333}], {
             RGBColor[
             0.32128397349438886`, 0.4449420277747629, 0.9419770304831396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 352}], {
             RGBColor[
             0.21148900295996179`, 0.33961872966115025`, 0.9353553578974033]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 357}], {
             RGBColor[
             0.22258574416561577`, 0.35128210824232153`, 0.9359873008929078]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 358}], {
             RGBColor[
             0.30472186221443454`, 0.43059675941998354`, 0.9409217073976809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 367}], {
             RGBColor[
             0.24111934498520485`, 0.3707620978018721, 0.937042762041578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 368}], {
             RGBColor[
             0.202529033876395, 0.3302012340594701, 0.9348451009131806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 441}], {
             RGBColor[
             0.2965298119987766, 0.4235012172675965, 0.9403997172018848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 492}], {
             RGBColor[
             0.2098019116271066, 0.3378454897025508, 0.9352592805418252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 348}], {
             RGBColor[
             0.8951149267316608, 0.8756226907724907, 0.6465713173376927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 372}], {
             RGBColor[
             0.8207108366647649, 0.3778465589340292, 0.4372814530493224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 382}], {
             RGBColor[
             0.5753274532973747, 0.6598063513243815, 0.9626104158765989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 404}], {
             RGBColor[
             0.8207108366647649, 0.3778465589340292, 0.4372814530493224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 418}], {
             RGBColor[
             0.8880207099240073, 0.849499175318815, 0.6304330994691307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 431}], {
             RGBColor[
             0.9104717457098559, 0.9268410177088308, 0.7558742996920007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 444}], {
             RGBColor[
             0.8431854304737648, 0.5505961353798073, 0.458803149462244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 486}], {
             RGBColor[
             0.9107995251370908, 0.9275421047601026, 0.7915510675263803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 420}], {
             RGBColor[
             0.21514942465501302`, 0.3434660649467891, 0.9355638134978279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 454}], {
             RGBColor[
             0.26600423470039036`, 0.39588544200916653`, 0.9384977155240641]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 489}], {
             RGBColor[
             0.22285222532450405`, 0.35156219683619444`, 0.9360024766006829]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 358}], {
             RGBColor[
             0.40118802656508795`, 0.5219106371393276, 0.9467843241894529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 361}], {
             RGBColor[
             0.4137027061318567, 0.5327502235739785, 0.9475817485051508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 367}], {
             RGBColor[
             0.33758550933585824`, 0.46207597552121615`, 0.9429053788333501]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 386}], {
             RGBColor[
             0.6306233379177042, 0.7071505825283917, 0.9663871470691616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 441}], {
             RGBColor[
             0.39299597634942995`, 0.5148150949869406, 0.9462623339936568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 450}], {
             RGBColor[
             0.3787463461307482, 0.5024727814987578, 0.9453543601565757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 461}], {
             RGBColor[
             0.479657645205507, 0.5874809597180408, 0.9524463931924381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 385}], {
             RGBColor[
             0.20166339359782656`, 0.32929139124193096`, 0.9347958039799161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 415}], {
             RGBColor[
             0.1991728653840312, 0.3266736881806229, 0.9346539720825469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 446}], {
             RGBColor[
             0.20565132116996215`, 0.33348295596945743`, 0.9350229105555391]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 409}], {
             RGBColor[
             0.42817878404725107`, 0.5428990333722734, 0.9491644164012382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 421}], {
             RGBColor[
             0.25863015359246655`, 0.38858598467637967`, 0.9380612529900733]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 430}], {
             RGBColor[
             0.2957165872581862, 0.4275661778747568, 0.940173270522874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 459}], {
             RGBColor[
             0.28047616225378147`, 0.41154752489637136`, 0.9393053508650615]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 354}], {
             RGBColor[
             0.8321846694563217, 0.3869954817531224, 0.4383758374637925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 388}], {
             RGBColor[
             0.8529860941236527, 0.4035819731432213, 0.44035989591821356`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 436}], {
             RGBColor[
             0.8681126065678694, 0.4150589185545728, 0.4215368270252724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 420}], {
             RGBColor[
             0.2204438807365078, 0.34903087397634414`, 0.935865324939223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 427}], {
             RGBColor[
             0.21714766115220907`, 0.3455663382008537, 0.9356776101102171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 433}], {
             RGBColor[
             0.20456821904727826`, 0.3323445469658758, 0.9349612294919583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 500}], {
             RGBColor[
             0.24832221794915155`, 0.378332773975503, 0.9374529550011792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 383}], {
             RGBColor[
             0.8128642763019948, 0.8502049776238694, 0.7323969456225705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 395}], {
             RGBColor[
             0.9545810948287645, 0.8462000070822004, 0.3759117982208804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 443}], {
             RGBColor[
             0.8722816554650638, 0.8967727827234393, 0.738216219132237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 480}], {
             RGBColor[
             0.736297626172224, 0.7880447217602409, 0.726369338451474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 344}], {
             RGBColor[
             0.20608159129440537`, 0.33393519715094877`, 0.9350474138025986]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 387}], {
             RGBColor[
             0.20309854147984135`, 0.33079982265955976`, 0.9348775335286859]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 439}], {
             RGBColor[
             0.22536729059950822`, 0.35420568990457246`, 0.9361457058473888]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 384}], {
             RGBColor[
             0.8080357036472916, 0.8499629868732397, 0.9401530383545316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 414}], {
             RGBColor[
             0.9874917700585177, 0.9869911353155156, 0.7157672733396714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 461}], {
             RGBColor[
             0.7616084201779264, 0.8122712266275236, 0.9364981125310801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 499}], {
             RGBColor[
             0.872096562596627, 0.418030146437691, 0.414793028650732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 374}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 391}], {
             RGBColor[
             0.8623939674573535, 0.3726044724173211, 0.20303663793067456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 397}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 455}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 485}], {
             RGBColor[
             0.7516716146349955, 0.7419375828889696, 0.6178585819047002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 374}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 403}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 440}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 445}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 471}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 387}], {
             RGBColor[
             0.22482902569883648`, 0.35363993936600063`, 0.9361150524575872]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 438}], {
             RGBColor[
             0.25444533400405744`, 0.38476855717718994`, 0.9378016574021677]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 439}], {
             RGBColor[
             0.24709777481850334`, 0.37704580661101333`, 0.9373832247762901]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 389}], {
             RGBColor[
             0.23903484731409955`, 0.3685711585847546, 0.9369240529829466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 456}], {
             RGBColor[
             0.2405210855329868, 0.3701332891857508, 0.9370086920508198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 472}], {
             RGBColor[
             0.21365168557830777`, 0.34189184621502966`, 0.9354785194731159]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 355}], {
             RGBColor[
             0.8988581121735896, 0.6097852870340661, 0.2641511089370308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 390}], {
             RGBColor[
             0.7705637997404904, 0.8032211601227189, 0.6733877692921244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 395}], {
             RGBColor[
             0.9494788631662472, 0.8294154005518836, 0.3198310039905435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 431}], {
             RGBColor[
             0.9882192232946517, 0.971338985864578, 0.45837897693901886`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 443}], {
             RGBColor[
             0.8671794238025463, 0.8799881761931223, 0.6821354249019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 486}], {
             RGBColor[
             0.9885470027218867, 0.9720400729158498, 0.4940557447733985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 382}], {
             RGBColor[
             0.30305610597028676`, 0.43452885116168694`, 0.9406187659739635]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 462}], {
             RGBColor[
             0.25493221981671754`, 0.3852803050366393, 0.9378293848289156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 355}], {
             RGBColor[
             0.8921067382753032, 0.5870113175771698, 0.237923296232169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 372}], {
             RGBColor[
             0.8657911144896757, 0.38473790158096466`, 0.21272342517580606`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 400}], {
             RGBColor[
             0.8657911144896757, 0.38473790158096466`, 0.21272342517580606`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 404}], {
             RGBColor[
             0.8657911144896757, 0.38473790158096466`, 0.21272342517580606`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 418}], {
             RGBColor[
             0.9556411266613736, 0.8598361892892182, 0.29359605765885616`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 431}], {
             RGBColor[
             0.9780921624472222, 0.937178031679234, 0.41903725788172613`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 444}], {
             RGBColor[
             0.8882657082986757, 0.5574874780267427, 0.23424512158872762`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 486}], {
             RGBColor[
             0.9784199418744571, 0.9378791187305058, 0.45471402571610575`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 353}], {
             RGBColor[
             0.19626227991525308`, 0.3236144783111598, 0.9344882185459253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 378}], {
             RGBColor[
             0.25281205566812764`, 0.38305187809030017`, 0.9377086446171552]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 380}], {
             RGBColor[
             0.2108243720536846, 0.3389201604386196, 0.9353175081505242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 487}], {
             RGBColor[
             0.2221770047693607, 0.3508524972212829, 0.9359640237889668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 377}], {
             RGBColor[
             0.1885369074382775, 0.3154946220209529, 0.9340482700120258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 412}], {
             RGBColor[
             0.20892004662185062`, 0.33691859366855603`, 0.9352090596343783]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 426}], {
             RGBColor[
             0.20267694710555745`, 0.33035670024156016`, 0.9348535243527634]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 476}], {
             RGBColor[
             0.19421935887497294`, 0.3214672387691502, 0.9343718772149121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 371}], {
             RGBColor[
             0.5030810091361415, 0.6074628526147339, 0.9540235263671059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 442}], {
             RGBColor[
             0.4533007905792821, 0.5668798964178177, 0.9501513769419208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 460}], {
             RGBColor[
             0.6420423630429408, 0.7175237512005181, 0.9668616406644909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 357}], {
             RGBColor[
             0.20925693798184208`, 0.337272687848053, 0.9352282450989436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 367}], {
             RGBColor[
             0.22779053880143119`, 0.3567526774076035, 0.9362837062476139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 368}], {
             RGBColor[
             0.18920022769262135`, 0.31619181366520155`, 0.9340860451192163]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 375}], {
             RGBColor[
             0.23983670688281394`, 0.3694139638323065, 0.93696971769914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 380}], {
             RGBColor[
             0.2011595261565179, 0.3287617946140746, 0.9347671094745387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 487}], {
             RGBColor[
             0.212512158872194, 0.340694131396738, 0.9354136251129814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 388}], {
             RGBColor[
             0.8931181453699616, 0.9176121823445156, 0.9896676000730092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 409}], {
             RGBColor[
             0.7016213313412318, 0.7656224177878801, 0.9718629380226298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 436}], {
             RGBColor[
             0.9158079140362867, 0.9348276004615428, 0.9614329967335975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 473}], {
             RGBColor[
             0.7341139041926492, 0.7920013522023865, 0.9744208723817095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 395}], {
             RGBColor[
             0.8765177108418302, 0.526541145326267, 0.2184266358360574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 404}], {
             RGBColor[
             0.8436346237856275, 0.3364004159962053, 0.18941787105636293`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 431}], {
             RGBColor[
             0.9023446175940999, 0.6211568688680633, 0.310791951135041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 443}], {
             RGBColor[
             0.8216514179326964, 0.5602563290870928, 0.4599629164436284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 444}], {
             RGBColor[
             0.8548719206901274, 0.42277520421909437`, 0.2001787192628237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 486}], {
             RGBColor[
             0.9025631372122566, 0.6216242602355779, 0.3345764630246274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 365}], {
             RGBColor[
             0.3958521141784222, 0.5154427777416128, 0.9467614846116235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 457}], {
             RGBColor[
             0.7242147630598365, 0.7320073272227894, 0.6198326116523992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 494}], {
             RGBColor[
             0.7305244527406208, 0.7874409705960981, 0.9449166497009711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 367}], {
             RGBColor[
             0.23888728000708515`, 0.3684160559887748, 0.9369156492431183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 368}], {
             RGBColor[
             0.2002969688982753, 0.32785519224637283`, 0.934717988114721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 441}], {
             RGBColor[
             0.29429774702065686`, 0.4211551754544992, 0.9402726044034251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 492}], {
             RGBColor[
             0.2075698466489869, 0.3354994478894535, 0.9351321677433655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 361}], {
             RGBColor[
             0.39714059485190245`, 0.5184049552191992, 0.9465264254196921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 386}], {
             RGBColor[
             0.61406122663775, 0.6928053141736124, 0.965331823983703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 398}], {
             RGBColor[
             0.3406430519430609, 0.4683522073597428, 0.9429673660120881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 441}], {
             RGBColor[
             0.3764338650694757, 0.5004698266321612, 0.945207010908198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 408}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 440}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 463}], {
             RGBColor[
             0.831998657058118, 0.24386491747293382`, 0.17815401051060936`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 483}], {
             RGBColor[
             0.8686864922225178, 0.39450469054086185`, 0.22397142092169176`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 457}], {
             RGBColor[
             0.8673649101585332, 0.4054186191239333, 0.2084049659054714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 494}], {
             RGBColor[
             0.8715713699457228, 0.44237438137280577`, 0.4251276579378526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 386}], {
             RGBColor[
             0.6265759062045188, 0.7036449006082633, 0.9661292482994008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 398}], {
             RGBColor[
             0.35315773150982965`, 0.47919179379439375`, 0.9437647903277859]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 441}], {
             RGBColor[
             0.38894854463624445`, 0.5113094130668121, 0.9460044352238959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 481}], {
             RGBColor[
             0.3510247020399264, 0.47694984457964584`, 0.9436433174550093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 369}], {
             RGBColor[
             0.18627079750730335`, 0.313112796803831, 0.9339192184038662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 470}], {
             RGBColor[
             0.21338003115164933`, 0.3416063201887262, 0.9354630491553944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 381}], {
             RGBColor[
             0.2070518443671499, 0.33495499464800116`, 0.9351026682797305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 378}], {
             RGBColor[
             0.29415700671630873`, 0.4265080430632411, 0.9400631784149752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 380}], {
             RGBColor[
             0.2521693231018657, 0.3823763254115605, 0.9376720419483442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 381}], {
             RGBColor[
             0.2539571451040042, 0.38425543969027, 0.9377738557665203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 416}], {
             RGBColor[
             0.2990750168791546, 0.43160441949619144`, 0.9403459160671803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 452}], {
             RGBColor[
             0.34123924405804607`, 0.4681249538428697, 0.9430325833386572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 468}], {
             RGBColor[
             0.3285107882361406, 0.45710020516072636`, 0.9422215373890169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 487}], {
             RGBColor[
             0.2635219558175418, 0.39430866219422384`, 0.938318557586787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 405}], {
             RGBColor[
             0.19262927042803146`, 0.31979595499398417`, 0.9342813240301839]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 423}], {
             RGBColor[
             0.18733252995215482`, 0.31422874492109487`, 0.9339796824959081]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 429}], {
             RGBColor[
             0.2147911262952244, 0.34308947065322315`, 0.9355434089362928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 465}], {
             RGBColor[
             0.18700818241333977`, 0.3138878350929786, 0.9339612113834017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 469}], {
             RGBColor[
             0.19196874935401928`, 0.31910170546574246`, 0.9342437083321722]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 488}], {
             RGBColor[
             0.19450193224029588`, 0.32176424129229075`, 0.9343879693500374]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 368}], {
             RGBColor[
             0.2188305697178644, 0.3473351818059234, 0.9357734492633911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 375}], {
             RGBColor[
             0.269467048908057, 0.40055733197302834`, 0.9386571218433146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 441}], {
             RGBColor[
             0.31283134784024597`, 0.44063516501404976`, 0.9413280655520953]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 450}], {
             RGBColor[
             0.29858171762156427`, 0.42829285152586705`, 0.9404200917150141]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 492}], {
             RGBColor[
             0.18751313635976613`, 0.31441857370660203`, 0.9339899677636383]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 456}], {
             RGBColor[
             0.22153756303757788`, 0.35018040341823176`, 0.935927608528311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 390}], {
             RGBColor[
             0.48068060887291364`, 0.5879170041207702, 0.9526359105777598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 422}], {
             RGBColor[
             0.350546806463606, 0.47704224603396517`, 0.9435943271285148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 443}], {
             RGBColor[
             0.5772962329349696, 0.6646840201911736, 0.9613835661875354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 451}], {
             RGBColor[
             0.34741654792202903`, 0.4737521458369133, 0.9434160635353744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 442}], {
             RGBColor[
             0.49686920952944263`, 0.6022507016564647, 0.9535812424780545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 460}], {
             RGBColor[
             0.6856107819931014, 0.7528945564391651, 0.9702915062006248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 400}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 404}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 418}], {
             RGBColor[
             0.8610616366179067, 0.36732222461184755`, 0.20196461326343138`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 431}], {
             RGBColor[
             0.8760289938084724, 0.418883452871858, 0.28559208007867803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 444}], {
             RGBColor[
             0.8285562969045, 0.22050178822288907`, 0.17497884820646079`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 486}], {
             RGBColor[
             0.8762475134266291, 0.4193508442393725, 0.30937659196826445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 449}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 498}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 397}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 445}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 402}], {
             RGBColor[
             0.3168704423564799, 0.4463611267638398, 0.9415038733564272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 417}], {
             RGBColor[
             0.2694273041453681, 0.40051555770747876`, 0.9386548584378767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 441}], {
             RGBColor[
             0.3248775159216287, 0.45329645143875275`, 0.9420140770036214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 450}], {
             RGBColor[
             0.31062788570294697`, 0.44095413795057004`, 0.9411061031665402]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 461}], {
             RGBColor[
             0.4115391847777058, 0.525962316169853, 0.9481981362024026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 391}], {
             RGBColor[
             0.9692861559217731, 0.9190249098809967, 0.5809414281870671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 448}], {
             RGBColor[
             0.9051283578144917, 0.9255858485156985, 0.9321528841461747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 455}], {
             RGBColor[
             0.8735554698238286, 0.41891480083667676`, 0.4032149808607035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 475}], {
             RGBColor[
             0.9641436958902179, 0.97247391328753, 0.9319168018252305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 482}], {
             RGBColor[
             0.9611408807899072, 0.9702344187023767, 0.9369997845304479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 412}], {
             RGBColor[
             0.20734204026481207`, 0.3352600089359268, 0.935119194506796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 426}], {
             RGBColor[
             0.2010989407485189, 0.3286981155089309, 0.9347636592251812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 476}], {
             RGBColor[
             0.19264135251793435`, 0.3198086540365209, 0.93428201208733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 380}], {
             RGBColor[
             0.25770930190939245`, 0.38819919439321504`, 0.9379875355457686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 416}], {
             RGBColor[
             0.3046149956866814, 0.43742728847784595`, 0.9406614096646049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 452}], {
             RGBColor[
             0.34677922286557283`, 0.4739478228245242, 0.9433480769360816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 487}], {
             RGBColor[
             0.26906193462506856`, 0.40013153117587835`, 0.9386340511842113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 400}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 404}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 440}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 487}], {
             RGBColor[
             0.2270742510106255, 0.35599981352419774`, 0.9362429147175804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 416}], {
             RGBColor[
             0.26441513407437683`, 0.3951746851048749, 0.9383720870161499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 468}], {
             RGBColor[
             0.29385090543136283`, 0.42067047076940983`, 0.9402477083379865]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 425}], {
             RGBColor[
             0.2677389295661514, 0.3974082595226244, 0.9386075050248284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 462}], {
             RGBColor[
             0.2750365104468856, 0.4050784797216278, 0.9390230914601827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 393}], {
             RGBColor[
             0.5000243154359716, 0.6026515113802116, 0.9544266172832518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 395}], {
             RGBColor[
             0.7742514426418383, 0.7085541585318539, 0.6077294417407735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 443}], {
             RGBColor[
             0.6919520032781376, 0.7591269341730926, 0.9700338626521301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 480}], {
             RGBColor[
             0.5559679739852978, 0.6503988732098943, 0.9581869819713671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 402}], {
             RGBColor[
             0.493323693614111, 0.5967965847816775, 0.9540138020874405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 411}], {
             RGBColor[
             0.673364501803413, 0.7446351140079177, 0.9681614906767982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 458}], {
             RGBColor[
             0.5434356286207753, 0.6402010241853623, 0.9572068902738209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 461}], {
             RGBColor[
             0.587992436035337, 0.6763977741876906, 0.9607080649334159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 499}], {
             RGBColor[
             0.756352573168234, 0.3274478448111356, 0.4309329969189558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 415}], {
             RGBColor[
             0.18775866061236085`, 0.31467663526321576`, 0.9340039500066029]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 446}], {
             RGBColor[
             0.1942371163982918, 0.32148590305205027`, 0.9343728884795952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 441}], {
             RGBColor[
             0.605869176422092, 0.6857097720212253, 0.9648098337879067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 498}], {
             RGBColor[
             0.8260448459967887, 0.38209975318755884`, 0.4377902156211372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 439}], {
             RGBColor[
             0.24411472500393933`, 0.3739104321196243, 0.9372133445023774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 436}], {
             RGBColor[
             0.9470100510372832, 0.9597073375466911, 0.9644090844152291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 473}], {
             RGBColor[
             0.7653160411936457, 0.8168810892875349, 0.9773969600633411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 456}], {
             RGBColor[
             0.24930916567101583`, 0.3793701186072822, 0.937509160213881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 472}], {
             RGBColor[
             0.22243976571633683`, 0.35112867563656114`, 0.9359789876361772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 422}], {
             RGBColor[
             0.42800433190778703`, 0.5412859490450508, 0.9493162414930003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 443}], {
             RGBColor[
             0.6547537583791506, 0.7289277232022592, 0.967105480552021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 451}], {
             RGBColor[
             0.4248740733662101, 0.5379958488479989, 0.94913797789986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 407}], {
             RGBColor[
             0.8204042342330249, 0.8029780971899061, 0.6251186758041836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 448}], {
             RGBColor[
             0.888386104264779, 0.856120355886665, 0.6318853697511313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 455}], {
             RGBColor[
             0.8623939674573535, 0.3726044724173211, 0.20303663793067456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 475}], {
             RGBColor[
             0.9474014423405053, 0.9030084206584965, 0.6316492874301871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 478}], {
             RGBColor[
             0.7346414386946734, 0.7340552109266808, 0.6178863226320354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 482}], {
             RGBColor[
             0.9443986272401945, 0.9007689260733432, 0.6367322701354043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 413}], {
             RGBColor[
             0.4263466505931637, 0.5437017727632361, 0.9483874094656242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 473}], {
             RGBColor[
             0.5241730715613854, 0.6242799613386438, 0.9557686238662648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 474}], {
             RGBColor[
             0.4244363391619793, 0.5420471570165883, 0.9482656861104513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 490}], {
             RGBColor[
             0.39194710024697893`, 0.5139066112250432, 0.9461955005358933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 424}], {
             RGBColor[
             0.3045464501938735, 0.4319945031262181, 0.9408537890405738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 480}], {
             RGBColor[
             0.4234576653062009, 0.5404912555165833, 0.9483990101121553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 467}], {
             RGBColor[
             0.2149961156174362, 0.3433049274279415, 0.9355550827749383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 443}], {
             RGBColor[
             0.8336688218049073, 0.7551219636314238, 0.61354871525044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 430}], {
             RGBColor[
             0.267533642941468, 0.39852519971712486`, 0.9385470172337352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 477}], {
             RGBColor[
             0.25943030085066265`, 0.39000807339812527`, 0.9380855438894842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 495}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 399}], {
             RGBColor[
             0.30014888904900616`, 0.43280589130218833`, 0.9404044072496268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 464}], {
             RGBColor[
             0.288464885266985, 0.4205252625186573, 0.9397390205191753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 481}], {
             RGBColor[
             0.29452715913108485`, 0.4268970967201894, 0.9400842580474054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 496}], {
             RGBColor[
             0.25262917012324787`, 0.38285965378701825`, 0.9376982295559292]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 407}], {
             RGBColor[
             0.49595107779550673`, 0.5964347568986441, 0.9550832606977075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 464}], {
             RGBColor[
             0.291953585715003, 0.4241921078859083, 0.9399376968486202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 478}], {
             RGBColor[
             0.41018828225715515`, 0.5275118706354188, 0.9478509075255593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 481}], {
             RGBColor[
             0.29801585957910287`, 0.4305639420874404, 0.9402829343768502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 496}], {
             RGBColor[
             0.2561178705712659, 0.3865264991542693, 0.937896905885374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 404}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 418}], {
             RGBColor[
             0.8610616366179067, 0.36732222461184755`, 0.20196461326343138`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 431}], {
             RGBColor[
             0.8760289938084724, 0.418883452871858, 0.28559208007867803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 444}], {
             RGBColor[
             0.8285562969045, 0.22050178822288907`, 0.17497884820646079`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 428}], {
             RGBColor[
             0.20185876447098355`, 0.3294967384168478, 0.9348069300621171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 437}], {
             RGBColor[
             0.189249743774186, 0.31624385820642686`, 0.9340888649868091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 451}], {
             RGBColor[
             0.23914595187837517`, 0.36868793652624454`, 0.9369303802235176]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 417}], {
             RGBColor[
             0.30478452951240814`, 0.43365806607358726`, 0.9408155984994631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 458}], {
             RGBColor[
             0.4023396027301842, 0.5229080745336331, 0.9468577016043941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 461}], {
             RGBColor[
             0.4468964101447459, 0.5591048245359614, 0.9503588762639891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 440}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 445}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 471}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 483}], {
             RGBColor[
             0.8686864922225178, 0.39450469054086185`, 0.22397142092169176`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 497}], {
             RGBColor[
             0.8604026869949277, 0.3647097089386806, 0.20143440692924686`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 418}], {
             RGBColor[
             0.8610616366179067, 0.36732222461184755`, 0.20196461326343138`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 431}], {
             RGBColor[
             0.8760289938084724, 0.418883452871858, 0.28559208007867803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 444}], {
             RGBColor[
             0.8285562969045, 0.22050178822288907`, 0.17497884820646079`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 486}], {
             RGBColor[
             0.8762475134266291, 0.4193508442393725, 0.30937659196826445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 423}], {
             RGBColor[
             0.18539930704922003`, 0.3121968050766989, 0.9338695883115329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 429}], {
             RGBColor[
             0.2128579033922896, 0.34105753080882717`, 0.9354333147519176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 472}], {
             RGBColor[
             0.19387632575282085`, 0.32110668920821217`, 0.9343523419860775]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 488}], {
             RGBColor[
             0.1925687093373611, 0.3197323014478947, 0.9342778751656623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 419}], {
             RGBColor[
             0.8761600890568056, 0.41916385235228004`, 0.29986098883365586`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 493}], {
             RGBColor[
             0.7916429672985688, 0.8334067531326425, 0.7659846388427745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 448}], {
             RGBColor[
             0.7562464361257435, 0.809539035824608, 0.9763301317632911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 455}], {
             RGBColor[
             0.7743008553646631, 0.3415502590426163, 0.43266647927211443`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 475}], {
             RGBColor[
             0.8152617742014696, 0.8564271005964393, 0.9760940494423469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 478}], {
             RGBColor[
             0.6025017705556377, 0.6874738908646236, 0.9623310846441953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 482}], {
             RGBColor[
             0.812258959101159, 0.8541876060112861, 0.9811770321475642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{408, 463}], {
             RGBColor[
             0.831998657058118, 0.24386491747293382`, 0.17815401051060936`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 430}], {
             RGBColor[
             0.4088644575244336, 0.5231795348188764, 0.9480432177755177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 422}], {
             RGBColor[
             0.24555176281029023`, 0.37542084996755853`, 0.9372951816795421]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 428}], {
             RGBColor[
             0.20513431686132172`, 0.3329395516611099, 0.9349934679250014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 437}], {
             RGBColor[
             0.19252529616452413`, 0.31968667145068896`, 0.9342754028496933]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{412, 426}], {
             RGBColor[
             0.221482079932092, 0.35012208715653403`, 0.9359244488475336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{412, 476}], {
             RGBColor[
             0.2130244917015075, 0.341232625684124, 0.9354428017096823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 474}], {
             RGBColor[
             0.40874864664870547`, 0.5284592662479426, 0.9472660802155872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 490}], {
             RGBColor[
             0.37625940773370514`, 0.5003187204563975, 0.9451958946410293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 461}], {
             RGBColor[
             0.7674485024465632, 0.8134259226299666, 0.7363222999185557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 498}], {
             RGBColor[
             0.8759899507757182, 0.41879994377265295`, 0.28134248690904895`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 499}], {
             RGBColor[
             0.8759899507757182, 0.41879994377265295`, 0.28134248690904895`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 452}], {
             RGBColor[
             0.3516972330284187, 0.47904419925747455`, 0.9436308145882868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 468}], {
             RGBColor[
             0.33896877720651325`, 0.4680194505753313, 0.9428197686386466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{417, 458}], {
             RGBColor[
             0.3548964645190724, 0.477062505477272, 0.9440086866858435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 431}], {
             RGBColor[
             0.9709979456395686, 0.9110545162255583, 0.4028990400131641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 444}], {
             RGBColor[
             0.8835362304269067, 0.5400718010576258, 0.22348630967635297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 486}], {
             RGBColor[
             0.9713257250668036, 0.9117556032768301, 0.43857580784754374`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 427}], {
             RGBColor[
             0.21490485900541903`, 0.34320901094270806`, 0.9355498858458859]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 454}], {
             RGBColor[
             0.2690558886350951, 0.39909292378057587`, 0.9386715027011281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 489}], {
             RGBColor[
             0.2259038792592088, 0.3547696786076038, 0.936176263777747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 500}], {
             RGBColor[
             0.2460794158023615, 0.3759754467173574, 0.9373252307368479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 430}], {
             RGBColor[
             0.2393158270696491, 0.3688664861229826, 0.9369400543643528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 459}], {
             RGBColor[
             0.22407540206524434`, 0.35284783314459717`, 0.9360721347065403]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 477}], {
             RGBColor[
             0.23121248497884378`, 0.360349359803983, 0.9364785810201017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 428}], {
             RGBColor[
             0.25745308354951085`, 0.3879298926517971, 0.9379729442892144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 437}], {
             RGBColor[
             0.24484406285271326`, 0.3746770124413762, 0.9372548792139064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 451}], {
             RGBColor[
             0.2947402709569025, 0.42712109076119387`, 0.9400963944506149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 429}], {
             RGBColor[
             0.207561162916413, 0.3354903207359379, 0.9351316732176418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 465}], {
             RGBColor[
             0.17977821903452834`, 0.30628868517569324`, 0.9335494756647507]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 469}], {
             RGBColor[
             0.18473878597520788`, 0.3115025555484572, 0.9338319726135212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 488}], {
             RGBColor[
             0.18727196886148448`, 0.3141650913750055, 0.9339762336313865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{425, 462}], {
             RGBColor[
             0.2196150434125822, 0.3481597133975768, 0.9358181238797805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 476}], {
             RGBColor[
             0.20678139218521432`, 0.3346707322571282, 0.9350872664280675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 433}], {
             RGBColor[
             0.19902919731618948`, 0.32652268393223965`, 0.9346457903986212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 500}], {
             RGBColor[
             0.24278319621806277`, 0.37251091094186695`, 0.937137515907842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 437}], {
             RGBColor[
             0.20442661690374475`, 0.33219571413492754`, 0.9349531654593657]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 451}], {
             RGBColor[
             0.2543228250079339, 0.3846397924547452, 0.9377946806960742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{429, 488}], {
             RGBColor[
             0.21473056520455405`, 0.34302581710713376`, 0.9355399600717713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{430, 459}], {
             RGBColor[
             0.261161835730964, 0.3918280263429743, 0.938184152239341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{430, 477}], {
             RGBColor[
             0.26829891864456346`, 0.39932955300236017`, 0.9385905985529026]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 444}], {
             RGBColor[
             0.8985035876174724, 0.5916330293176362, 0.30711377649159965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 486}], {
             RGBColor[
             0.9937767608526522, 0.9890974456668459, 0.5640170080704137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{432, 460}], {
             RGBColor[
             0.797979397774264, 0.8421439216944954, 0.9804889458898756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 465}], {
             RGBColor[
             0.18295181335348598`, 0.3096243340224193, 0.9337302071663033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 469}], {
             RGBColor[
             0.1879123802941655, 0.31483820439518323`, 0.9340127041150739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 495}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{435, 439}], {
             RGBColor[
             0.3579216498299631, 0.4805187712808422, 0.9441708386779522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{435, 453}], {
             RGBColor[
             0.4536708445200175, 0.5672446965945355, 0.9501627222939097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 473}], {
             RGBColor[
             0.7880058098599707, 0.8340965074045622, 0.9491623567239293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 439}], {
             RGBColor[
             0.27373103330916027`, 0.40503904993081363`, 0.9388999494469579]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{439, 453}], {
             RGBColor[
             0.3621326688136605, 0.48404222467833025`, 0.9444734004370379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 445}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 471}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 450}], {
             RGBColor[
             0.35399218463513593`, 0.48103197099159145`, 0.9437770468753208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 461}], {
             RGBColor[
             0.45490348370989475`, 0.5660401492108743, 0.9508690799111832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 447}], {
             RGBColor[
             0.43707590774460403`, 0.5529949160396692, 0.9490710682438044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 500}], {
             RGBColor[
             0.3605233719937942, 0.48347254608803236`, 0.9443109769258367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{443, 451}], {
             RGBColor[
             0.521489697428266, 0.6147628649184023, 0.9578856335096356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{444, 486}], {
             RGBColor[
             0.898722107235629, 0.5921004206851508, 0.33089828838118596`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{445, 471}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 454}], {
             RGBColor[
             0.37348676159854866`, 0.49791719373137167`, 0.9450192240810519]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 500}], {
             RGBColor[
             0.3505102887658151, 0.47479971666815324`, 0.9436729521167717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 455}], {
             RGBColor[
             0.8196221020524992, 0.3769784315071223, 0.4371776085700797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 475}], {
             RGBColor[
             0.8832436442332238, 0.9095693592931984, 0.9828607433892947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 478}], {
             RGBColor[
             0.6704836405873918, 0.7406161495613826, 0.969097778591143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 482}], {
             RGBColor[
             0.8802408291329131, 0.907329864708045, 0.9879437260945121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{449, 499}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 461}], {
             RGBColor[
             0.440653853491213, 0.5536978357226917, 0.949961106074102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{452, 468}], {
             RGBColor[
             0.38113300438540465`, 0.5045399849220095, 0.9455064359101233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 489}], {
             RGBColor[
             0.2767586893045861, 0.4071890556699812, 0.9391101658039832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 500}], {
             RGBColor[
             0.2969342258477388, 0.4283948237797348, 0.9402591327630841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{455, 475}], {
             RGBColor[
             0.85896566076965, 0.4082371413550099, 0.4370202203561169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{455, 482}], {
             RGBColor[
             0.8569637840361095, 0.40674414496490774`, 0.4404088754929284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{457, 494}], {
             RGBColor[
             0.9630746438977319, 0.9212538232548773, 0.6116244787450666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{458, 461}], {
             RGBColor[
             0.4970083451514102, 0.6025092639396462, 0.9535519644503695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{459, 477}], {
             RGBColor[
             0.2530584936401587, 0.3833109000239747, 0.9377226788950901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{460, 463}], {
             RGBColor[
             0.8490960260828695, 0.5965456532875175, 0.46506056118722205`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{463, 483}], {
             RGBColor[
             0.8980458063387537, 0.6139805254867295, 0.2518434419429105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 481}], {
             RGBColor[
             0.28633185579708176`, 0.41828331330390933`, 0.9396175476463986]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 496}], {
             RGBColor[
             0.24443386678924475`, 0.3742458703707382, 0.9372315191549225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{465, 469}], {
             RGBColor[
             0.1844144384363928, 0.3111616457203408, 0.9338135015010149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 470}], {
             RGBColor[
             0.2470848114448652, 0.37703218128339433`, 0.9373824865313389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 491}], {
             RGBColor[
             0.2191139720880547, 0.34763305566574143`, 0.9357895886091172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 483}], {
             RGBColor[
             0.8686864922225178, 0.39450469054086185`, 0.22397142092169176`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 497}], {
             RGBColor[
             0.8604026869949277, 0.3647097089386806, 0.20143440692924686`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{472, 488}], {
             RGBColor[
             0.1957489875650853, 0.32307497550651876`, 0.9344589873059312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{474, 490}], {
             RGBColor[
             0.3743490963025207, 0.49866410470974976`, 0.9450741712858564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{475, 478}], {
             RGBColor[
             0.7294989786631181, 0.787504214333214, 0.9688616962701988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{475, 482}], {
             RGBColor[
             0.9392561672086392, 0.9542179294798765, 0.9877076437735679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{478, 482}], {
             RGBColor[
             0.7264961635628073, 0.7852647197480608, 0.973944678975416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{481, 496}], {
             RGBColor[
             0.2504961406533446, 0.38061770457227034`, 0.9375767566831525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{484, 490}], {
             RGBColor[
             0.27306794987010674`, 0.4012805048264995, 0.9389742880863683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{489, 500}], {
             RGBColor[
             0.2537822164718525, 0.3840715786067627, 0.937763893839703]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.0860569014282922], {
             RGBColor[
             0.2665869568298027, 0.3975301725903983, 0.9384931048601725]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.0860569014282922], {
             RGBColor[
             0.20161671018842872`, 0.32924232401875475`, 0.9347931454288129]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.0860569014282922], {
             RGBColor[
             0.19930844041135132`, 0.32681618613028957`, 0.9346616928797874]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.0860569014282922], {
             RGBColor[
             0.19006206717459462`, 0.3170976616045347, 0.9341351256027375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.0860569014282922], {
             RGBColor[
             0.33431180974343394`, 0.46398581942480244`, 0.9425230307898937]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.0860569014282922], {
             RGBColor[
             0.9534406635465423, 0.8531147764808367, 0.28139546888270184`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.0860569014282922], {
             RGBColor[
             0.2588724192803225, 0.3894217044959632, 0.9380537733593651]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.0860569014282922], {
             RGBColor[
             0.242957706247003, 0.37269433204685803`, 0.9371474539958257]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.0860569014282922], {
             RGBColor[
             0.3937584149506567, 0.5154754809820448, 0.946310915907129]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.0860569014282922], {
             RGBColor[
             0.9875036737064178, 0.989100462183736, 0.8567599963478333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.0860569014282922], {
             RGBColor[
             0.2440062290021841, 0.3737963959427358, 0.9372071658155828]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.0860569014282922], {
             RGBColor[
             0.5395182465349754, 0.6370442434139459, 0.9568919991691406]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.0860569014282922], {
             RGBColor[
             0.4138740589676099, 0.532898640787864, 0.9475926669563236]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.0860569014282922], {
             RGBColor[
             0.6469324131931254, 0.7241077851456973, 0.9654438350861145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.0860569014282922], {
             RGBColor[
             0.9874606584389937, 0.9890826742652142, 0.8574728706489945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.0860569014282922], {
             RGBColor[
             0.7541788838097023, 0.8078895430947328, 0.9761331610019253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.0860569014282922], {
             RGBColor[
             0.28355932289318264`, 0.4153692054331722, 0.9394596559991165]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.0860569014282922], {
             RGBColor[
             0.46934274654192526`, 0.5800726111493398, 0.9513675267483611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.0860569014282922], {
             RGBColor[
             0.8219966379615026, 0.8609018228788999, 0.9828839672054712]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.0860569014282922], {
             RGBColor[
             0.19129510586323456`, 0.3183936634454635, 0.9342053453319383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.0860569014282922], {
             RGBColor[
             0.9925631716550148, 0.9865017010857893, 0.43192531331195433`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.0860569014282922], {
             RGBColor[
             0.20633904470983166`, 0.3342057970140512, 0.9350620753937389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.0860569014282922], {
             RGBColor[
             0.7576060273863839, 0.8105668537040923, 0.9764747466451712]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.0860569014282922], {
             RGBColor[
             0.20463513155106594`, 0.33241487624985433`, 0.9349650400600608]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.0860569014282922], {
             RGBColor[
             0.2059976869465667, 0.3338470083615274, 0.9350426355741145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.0860569014282922], {
             RGBColor[
             0.949329454771621, 0.8368152036673847, 0.2780874937999273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.0860569014282922], {
             RGBColor[
             0.20262840066914578`, 0.3303056748588697, 0.9348507597050277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.0860569014282922], {
             RGBColor[
             0.1789570524953891, 0.3054255870780922, 0.9335027114451537]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.0860569014282922], {
             RGBColor[
             0.23515707303258868`, 0.3644953719497967, 0.9367032194742675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.0860569014282922], {
             RGBColor[
             0.3596303768180513, 0.4859154896766539, 0.9441363074955585]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.0860569014282922], {
             RGBColor[
             0.5603811253615456, 0.6539816683073362, 0.9585344014136115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.0860569014282922], {
             RGBColor[
             0.3081602529797812, 0.4412263427432439, 0.9408606425737336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.0860569014282922], {
             RGBColor[
             0.21649762081927568`, 0.34488310459600313`, 0.9356405912749051]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.0860569014282922], {
             RGBColor[
             0.8992999083697804, 0.6356262276586594, 0.23768571396967728`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.0860569014282922], {
             RGBColor[
             0.5059330480764017, 0.6097782663093272, 0.954248049319846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.0860569014282922], {
             RGBColor[
             0.20512412607187444`, 0.33292884049526744`, 0.9349928875746183]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.0860569014282922], {
             RGBColor[
             0.6031363050639882, 0.6886922492886749, 0.9619002457771715]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.0860569014282922], {
             RGBColor[
             0.2720687261283602, 0.40329185968743014`, 0.9388052835121744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.0860569014282922], {
             RGBColor[
             0.40134636687536374`, 0.5220477835576731, 0.9467944134940088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.0860569014282922], {
             RGBColor[
             0.6993501336328052, 0.7650569067426056, 0.970668343588094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.0860569014282922], {
             RGBColor[
             0.27477024647677334`, 0.40613132885989545`, 0.9389591310994754]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.0860569014282922], {
             RGBColor[
             0.2856812767955215, 0.41759951352417846`, 0.9395804981347052]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.0860569014282922], {
             RGBColor[
             0.7146679187190441, 0.7770232768714539, 0.97219507725265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.0860569014282922], {
             RGBColor[
             0.22612030793820787`, 0.35499715887160266`, 0.9361885890708385]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.0860569014282922], {
             RGBColor[
             0.18352693138300546`, 0.3102288195360335, 0.9337629592872735]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.0860569014282922], {
             RGBColor[
             0.8437950041640877, 0.3376331698641804, 0.18957145148790017`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.0860569014282922], {
             RGBColor[
             0.9946416792371043, 0.9909474186345262, 0.6581580365604908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.0860569014282922], {
             RGBColor[
             0.240267978136988, 0.3698672572646202, 0.9369942779590565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.0860569014282922], {
             RGBColor[
             0.6025610453058137, 0.6882252275018321, 0.961854959221762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.0860569014282922], {
             RGBColor[
             0.5285279267956817, 0.6281218067413252, 0.9560268009403956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.0860569014282922], {
             RGBColor[
             0.29903790758239124`, 0.43163817934048265`, 0.9403411384986529]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.0860569014282922], {
             RGBColor[
             0.20425044222453645`, 0.33201054337695984`, 0.9349431325720118]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.0860569014282922], {
             RGBColor[
             0.1972436349934338, 0.32464594471983343`, 0.9345441052658429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.0860569014282922], {
             RGBColor[
             0.2605769831148301, 0.3912133091616199, 0.9381508457480642]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.0860569014282922], {
             RGBColor[
             0.18730821452687368`, 0.3142031878674374, 0.9339782977684097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.0860569014282922], {
             RGBColor[
             0.20692796280704617`, 0.3348247872737876, 0.935095613408149]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.0860569014282922], {
             RGBColor[
             0.9814207743108861, 0.9489900505202847, 0.382323645900509]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.0860569014282922], {
             RGBColor[
             0.9855771277360073, 0.9883037859149981, 0.8886878488186855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.0860569014282922], {
             RGBColor[
             0.25995825934690286`, 0.39056299125217575`, 0.9381156103448005]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.0860569014282922], {
             RGBColor[
             0.3185855666826758, 0.4503645381095326, 0.941520968488233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.0860569014282922], {
             RGBColor[
             0.8407007288961474, 0.31384921423472306`, 0.18660836999683647`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.0860569014282922], {
             RGBColor[
             0.22105372540225315`, 0.34967185938642753`, 0.935900054690753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.0860569014282922], {
             RGBColor[
             0.9943451951306927, 0.9903132691100532, 0.6258875712654035]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.0860569014282922], {
             RGBColor[
             0.9392816575746442, 0.9542369401531062, 0.9876644952328739]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.0860569014282922], {
             RGBColor[
             0.9560909454429859, 0.8635465900222101, 0.28392204388553066`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.0860569014282922], {
             RGBColor[
             0.9579895862140718, 0.9681892827009697, 0.9559968518555605]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.0860569014282922], {
             RGBColor[
             0.4492602452544817, 0.5635483767881156, 0.9498474434557472]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.0860569014282922], {
             RGBColor[
             0.8979401714022621, 0.6294519796637963, 0.23655111611377708`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.0860569014282922], {
             RGBColor[
             0.67875131942796, 0.7489649565289941, 0.9686152462950182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.0860569014282922], {
             RGBColor[
             0.21486301907210675`, 0.34316503451999186`, 0.9355475031235805]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.0860569014282922], {
             RGBColor[
             0.20642970531273738`, 0.3343010870559193, 0.9350672383809541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.0860569014282922], {
             RGBColor[
             0.854284899814332, 0.8866476064388262, 0.9859636504450657]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.0860569014282922], {
             RGBColor[
             0.22472424201089944`, 0.35352980506630927`, 0.9361090851815727]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.0860569014282922], {
             RGBColor[
             0.8587915518062159, 0.890241088407345, 0.9863934989351874]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.0860569014282922], {
             RGBColor[
             0.5985155306782874, 0.6849408964788493, 0.9615364814910747]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.0860569014282922], {
             RGBColor[
             0.9641975980982375, 0.8908922329609346, 0.3154148586382841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.0860569014282922], {
             RGBColor[
             0.6576732634723652, 0.7324986190173249, 0.9665143826629965]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.0860569014282922], {
             RGBColor[
             0.3738197825598743, 0.4982056397499517, 0.9450404438822286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.0860569014282922], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.0860569014282922], {
             RGBColor[
             0.20371097625405837`, 0.3314435304378693, 0.9349124107830614]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.0860569014282922], {
             RGBColor[
             0.9553028976633565, 0.8604979142012724, 0.28289386616534334`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.0860569014282922], {
             RGBColor[
             0.21930919416960923`, 0.3478382464512501, 0.9358007062178566]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.0860569014282922], {
             RGBColor[
             0.49037845718069295`, 0.5971503486938564, 0.953023534946192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.0860569014282922], {
             RGBColor[
             0.26729718777158684`, 0.39827667034145603`, 0.9385335514616145]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.0860569014282922], {
             RGBColor[
             0.9943968653913747, 0.9904237865729874, 0.6315115602687539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.0860569014282922], {
             RGBColor[
             0.23276328462783158`, 0.36197934856144603`, 0.9365668967659092]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.0860569014282922], {
             RGBColor[
             0.18203014314014365`, 0.3086556001909298, 0.9336777194111423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.0860569014282922], {
             RGBColor[
             0.3194029847849358, 0.4510725445850818, 0.9415730536468945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.0860569014282922], {
             RGBColor[
             0.3113782533268795, 0.444121925530844, 0.9410617248543786]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.0860569014282922], {
             RGBColor[
             0.33067337344239356`, 0.46083438877396704`, 0.9422911928461343]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.0860569014282922], {
             RGBColor[
             0.9937947583663093, 0.9891359405287304, 0.5659759263641978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.0860569014282922], {
             RGBColor[
             0.9845357488920988, 0.9878731490008265, 0.9059461912643052]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.0860569014282922], {
             RGBColor[
             0.25555645648574987`, 0.385936417354683, 0.9378649341837416]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.0860569014282922], {
             RGBColor[
             0.1897272593739602, 0.31674575737802724`, 0.9341160587937951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.0860569014282922], {
             RGBColor[
             0.23087379955273474`, 0.3599933799472462, 0.9364592933861251]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.0860569014282922], {
             RGBColor[
             0.6844298372258936, 0.7534010577910736, 0.9691812278803502]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.0860569014282922], {
             RGBColor[
             0.19890073469948152`, 0.32638766157707927`, 0.9346384746426429]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.0860569014282922], {
             RGBColor[
             0.23614802813125227`, 0.3655369285886743, 0.9367596529011497]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.0860569014282922], {
             RGBColor[
             0.2021529677712563, 0.32980596473900103`, 0.9348236845048329]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.0860569014282922], {
             RGBColor[
             0.18313418987661276`, 0.309816023311565, 0.9337405932394934]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.0860569014282922], {
             RGBColor[
             0.29180692255249685`, 0.42403795560313273`, 0.9399293445984841]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.0860569014282922], {
             RGBColor[
             0.2080093336373953, 0.3359613765793552, 0.9351571958771926]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.0860569014282922], {
             RGBColor[
             0.20873262495813816`, 0.3367216016167744, 0.9351983862478953]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.0860569014282922], {
             RGBColor[
             0.20667495168092284`, 0.33455885653840006`, 0.9350812047988127]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.0860569014282922], {
             RGBColor[
             0.9344583887804918, 0.7778563825015339, 0.2661218850346821]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.0860569014282922], {
             RGBColor[
             0.24495698094472051`, 0.3747956965154964, 0.9372613097321988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.0860569014282922], {
             RGBColor[
             0.7604405856228837, 0.8127812321418865, 0.9767572689197328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.0860569014282922], {
             RGBColor[
             0.8331937393088721, 0.8698300875560732, 0.9839519567277537]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.0860569014282922], {
             RGBColor[
             0.6598859337650126, 0.7342271738668581, 0.966734920959188]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.0860569014282922], {
             RGBColor[
             0.2610002522409667, 0.3916581918500021, 0.9381749502986271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.0860569014282922], {
             RGBColor[
             0.2013445076269774, 0.3289562218680302, 0.9347776438956258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.0860569014282922], {
             RGBColor[
             0.18353112071158095`, 0.3102332227859851, 0.9337631978633384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.0860569014282922], {
             RGBColor[
             0.8894828910866501, 0.591049444998604, 0.22949415411151997`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.0860569014282922], {
             RGBColor[
             0.3211744864498682, 0.45260693028898363`, 0.9416859321665065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.0860569014282922], {
             RGBColor[
             0.1954809540192259, 0.32279325525551217`, 0.9344437231920146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.0860569014282922], {
             RGBColor[
             0.19474583817336233`, 0.32202060189247295`, 0.9344018594320991]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.0860569014282922], {
             RGBColor[
             0.17930336856424547`, 0.3057895872241672, 0.9335224336329464]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.0860569014282922], {
             RGBColor[
             0.3011825170683711, 0.43389229988634254`, 0.9404632708362141]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.0860569014282922], {
             RGBColor[
             0.340635459799505, 0.4694630472674779, 0.9429259681796823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.0860569014282922], {
             RGBColor[
             0.8371868177096, 0.28683975304921994`, 0.1832434446762037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.0860569014282922], {
             RGBColor[
             0.2562538810668797, 0.3866694548087229, 0.9379046514818897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.0860569014282922], {
             RGBColor[
             0.3086579844982561, 0.441749490127162, 0.9408889876473829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.0860569014282922], {
             RGBColor[
             0.18386384177004123`, 0.31058293371416035`, 0.933782145835401]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.0860569014282922], {
             RGBColor[
             0.6735645089681628, 0.7449129807765811, 0.9680982735018852]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.0860569014282922], {
             RGBColor[
             0.8554632653203876, 0.4273205381761434, 0.2007449915485891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.0860569014282922], {
             RGBColor[
             0.3389460376431222, 0.4679997547084456, 0.942818319693775]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.0860569014282922], {
             RGBColor[
             0.28569344941384495`, 0.4176123077178249, 0.9395811913473109]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.0860569014282922], {
             RGBColor[
             0.20179304187532063`, 0.3294276598017528, 0.934803187257522]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.0860569014282922], {
             RGBColor[
             0.3978373772063899, 0.5190084730733568, 0.9465708237751796]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.0860569014282922], {
             RGBColor[
             0.24352168839563612`, 0.373287113043605, 0.9371795719448536]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.0860569014282922], {
             RGBColor[
             0.26709219000597495`, 0.39806120469218886`, 0.93852187714213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.0860569014282922], {
             RGBColor[
             0.8177268607774917, 0.8575337056844831, 0.9824670294564657]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.0860569014282922], {
             RGBColor[
             0.23397806856290648`, 0.3632561634989598, 0.9366360769138999]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.0860569014282922], {
             RGBColor[
             0.41932351101049736`, 0.5376186822499895, 0.9479399012217352]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.0860569014282922], {
             RGBColor[
             0.45486118183922636`, 0.5683158245366335, 0.9502274849272453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.0860569014282922], {
             RGBColor[
             0.331702995966787, 0.46172619605426385`, 0.9423567994829292]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.0860569014282922], {
             RGBColor[
             0.19787594539539122`, 0.32531054304308565`, 0.934580114407815]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.0860569014282922], {
             RGBColor[
             0.8806632832194534, 0.9076810133439271, 0.9884796442025071]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.0860569014282922], {
             RGBColor[
             0.8447410453925083, 0.8790375959838911, 0.9850533490904128]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.0860569014282922], {
             RGBColor[
             0.25109817118593475`, 0.381250476832963, 0.9376110414313592]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.0860569014282922], {
             RGBColor[
             0.4574599131251553, 0.570425591666061, 0.95043206657354]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.0860569014282922], {
             RGBColor[
             0.7801061400958719, 0.8281441127599345, 0.9787173476045451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.0860569014282922], {
             RGBColor[
             0.19997089892350478`, 0.32751247202885847`, 0.934699418912035]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.0860569014282922], {
             RGBColor[
             0.21686761525785075`, 0.3452719922099478, 0.9356616619108242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.0860569014282922], {
             RGBColor[
             0.9553966243175557, 0.8608695091526162, 0.28296928083135936`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.0860569014282922], {
             RGBColor[
             0.37795345536951325`, 0.5017860193732245, 0.9453038378583956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.0860569014282922], {
             RGBColor[
             0.215756853533542, 0.3441045112113384, 0.9355984056738496]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.0860569014282922], {
             RGBColor[
             0.9948073015950193, 0.9921207000103479, 0.7357199810506223]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.0860569014282922], {
             RGBColor[
             0.8837943025257868, 0.9101776031495423, 0.9887782836190391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.0860569014282922], {
             RGBColor[
             0.20242608517667066`, 0.3300930284487352, 0.9348392381370303]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.0860569014282922], {
             RGBColor[
             0.9567165072169457, 0.8656567567746658, 0.2863522332499358]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.0860569014282922], {
             RGBColor[
             0.270181620235489, 0.40130839174459826`, 0.9386978156232983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.0860569014282922], {
             RGBColor[
             0.6034964487201209, 0.6889846301330103, 0.9619285976050319]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.0860569014282922], {
             RGBColor[
             0.3876691533578903, 0.5102012686455771, 0.9459229135429605]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.0860569014282922], {
             RGBColor[
             0.9544946818446345, 0.965582788744624, 0.9619128133359728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.0860569014282922], {
             RGBColor[
             0.2566248317017963, 0.38705934744564896`, 0.9379257765717759]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.0860569014282922], {
             RGBColor[
             0.8763132971847281, 0.531249394926778, 0.21850512214346993`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.0860569014282922], {
             RGBColor[
             0.3206235691378255, 0.4521297534032015, 0.9416508282025402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.0860569014282922], {
             RGBColor[
             0.36718010963697145`, 0.4924546887837977, 0.9446173697948136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.0860569014282922], {
             RGBColor[
             0.38027801256113686`, 0.5037994339769674, 0.9454519565871206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.0860569014282922], {
             RGBColor[
             0.5334133816925579, 0.6320880391138444, 0.9564114018458887]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.0860569014282922], {
             RGBColor[
             0.34462319164040967`, 0.47291702015883946`, 0.943180062926372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.0860569014282922], {
             RGBColor[
             0.22919385631472186`, 0.35822765308954135`, 0.9363636231039736]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.0860569014282922], {
             RGBColor[
             0.8701957487608276, 0.8993344855002725, 0.9874812414213651]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.0860569014282922], {
             RGBColor[
             0.18752850541486277`, 0.314434727557963, 0.9339908430085895]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.0860569014282922], {
             RGBColor[
             0.20985498932745156`, 0.3379012777309339, 0.9352623032383384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.0860569014282922], {
             RGBColor[
             0.21841757556668306`, 0.34690109876769015`, 0.9357499298574514]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.0860569014282922], {
             RGBColor[
             0.23522235731990115`, 0.36456398987502503`, 0.9367069373178505]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.0860569014282922], {
             RGBColor[
             0.4134590735708867, 0.5325392012949949, 0.9475662244538017]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.0860569014282922], {
             RGBColor[
             0.19393685411417064`, 0.3211703083537106, 0.9343557889867128]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.0860569014282922], {
             RGBColor[
             0.9909931722195693, 0.9905434594949455, 0.7989299754522408]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.0860569014282922], {
             RGBColor[
             0.6024325749506131, 0.6881209294799567, 0.9618448455647982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.0860569014282922], {
             RGBColor[
             0.5677847377648733, 0.6599922543852954, 0.9591172409023272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.0860569014282922], {
             RGBColor[
             0.21266853360939608`, 0.34085849116026834`, 0.9354225304229293]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.0860569014282922], {
             RGBColor[
             0.8802420747951332, 0.9073451531797723, 0.9884394689669782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.0860569014282922], {
             RGBColor[
             0.4450599520442159, 0.5599102939222584, 0.9495798044865625]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.0860569014282922], {
             RGBColor[
             0.18533323543547214`, 0.3121273596214676, 0.9338658256308742]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.0860569014282922], {
             RGBColor[
             0.9930049498136619, 0.9874466198965118, 0.4800101395419234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.0860569014282922], {
             RGBColor[
             0.2504170603715949, 0.38053458618217195`, 0.9375722531780957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.0860569014282922], {
             RGBColor[
             0.21578236892213723`, 0.34413132950252107`, 0.9355998587374834]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.0860569014282922], {
             RGBColor[
             0.1919302366972257, 0.31906122622160893`, 0.9342415150933422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.0860569014282922], {
             RGBColor[
             0.2792508331211001, 0.4108407095086842, 0.9392142938804358]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.0860569014282922], {
             RGBColor[
             0.21604971918074886`, 0.3444123315753073, 0.9356150839392021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.0860569014282922], {
             RGBColor[
             0.20492571704741236`, 0.3327203000306991, 0.934981588474195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.0860569014282922], {
             RGBColor[
             0.2693332332275772, 0.4004166832084398, 0.938649501238274]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.0860569014282922], {
             RGBColor[
             0.18890068939112134`, 0.3158769799184998, 0.9340689868560732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.0860569014282922], {
             RGBColor[
             0.7398173513855104, 0.796670204813265, 0.9747017376660327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.0860569014282922], {
             RGBColor[
             0.3469706927955112, 0.4749503076705497, 0.9433296436241613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.0860569014282922], {
             RGBColor[
             0.2572169453532387, 0.3876816964354887, 0.9379594965682719]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.0860569014282922], {
             RGBColor[
             0.3049544364430743, 0.43785682630265677`, 0.9406780760645487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.0860569014282922], {
             RGBColor[
             0.295260889517734, 0.42766829387775107`, 0.9401260429074682]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.0860569014282922], {
             RGBColor[
             0.2006287179667525, 0.32820388155144814`, 0.9347368807333919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.0860569014282922], {
             RGBColor[
             0.21361395179144738`, 0.34185218561257913`, 0.9354763705897763]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.0860569014282922], {
             RGBColor[
             0.24023088414070523`, 0.3698282691226319, 0.9369921655108439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.0860569014282922], {
             RGBColor[
             0.5725831029202398, 0.6638877833823089, 0.9594949857843484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.0860569014282922], {
             RGBColor[
             0.4323931062930283, 0.5489389087867588, 0.9487726842761488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.0860569014282922], {
             RGBColor[
             0.29510601197456354`, 0.4275055077600755, 0.9401172228605054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.0860569014282922], {
             RGBColor[
             0.6961033750146681, 0.7625205142338375, 0.9703447370317223]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.0860569014282922], {
             RGBColor[
             0.3473763609653794, 0.4753016770498144, 0.9433554924412271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.0860569014282922], {
             RGBColor[
             0.3057070456133757, 0.438647866258821, 0.9407209360434119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.0860569014282922], {
             RGBColor[
             0.4230361383836957, 0.5408343734785764, 0.9481764665550079]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.0860569014282922], {
             RGBColor[
             0.936541673425211, 0.7861159119043911, 0.2677981447607987]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.0860569014282922], {
             RGBColor[
             0.25524447055801713`, 0.38560850036358557`, 0.937847167046699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.0860569014282922], {
             RGBColor[
             0.34023858975482646`, 0.4691192983820458, 0.9429006799713738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.0860569014282922], {
             RGBColor[
             0.2549643465593099, 0.385314072280057, 0.937831214399379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.0860569014282922], {
             RGBColor[
             0.977212423501673, 0.9347942950730491, 0.3659749976870823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.0860569014282922], {
             RGBColor[
             0.4829394273144061, 0.5911110091239283, 0.9524379072650536]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.0860569014282922], {
             RGBColor[
             0.4576850364535088, 0.5706083569257087, 0.9504497891066018]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.0860569014282922], {
             RGBColor[
             0.2019820387076045, 0.3296263074555744, 0.9348139503475248]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.0860569014282922], {
             RGBColor[
             0.18472467114451377`, 0.31148771996646574`, 0.9338311687947942]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.0860569014282922], {
             RGBColor[
             0.3594825143186384, 0.4857874186114477, 0.9441268858278457]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.0860569014282922], {
             RGBColor[
             0.45200942833171354`, 0.5659295809916547, 0.9500226189704213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.0860569014282922], {
             RGBColor[
             0.1934857951277101, 0.32069621676014903`, 0.9343301018447159]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.0860569014282922], {
             RGBColor[
             0.9881377044358732, 0.9893626501842123, 0.8462524663418269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.0860569014282922], {
             RGBColor[
             0.2370889777331282, 0.36652592627989644`, 0.9368132385889664]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.0860569014282922], {
             RGBColor[
             0.25751049402968956`, 0.3879902347064996, 0.9379762137311295]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.0860569014282922], {
             RGBColor[
             0.8652595816135205, 0.8953985198056976, 0.9870104253922865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.0860569014282922], {
             RGBColor[
             0.9939516779922013, 0.9894715757415058, 0.5830556592468749]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.0860569014282922], {
             RGBColor[
             0.3120362716652125, 0.4446918679425447, 0.9411036532010344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.0860569014282922], {
             RGBColor[
             0.9264054963123022, 0.9441546124248671, 0.9928425773218587]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.0860569014282922], {
             RGBColor[
             0.9518509475754381, 0.963611096055375, 0.9663879658573935]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.0860569014282922], {
             RGBColor[
             0.38201222096486337`, 0.5053015181324264, 0.9455624588131057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.0860569014282922], {
             RGBColor[
             0.20216870968076056`, 0.32982251048398475`, 0.9348245809832911]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.0860569014282922], {
             RGBColor[
             0.4056075310905943, 0.525738589828565, 0.9470659311098037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.0860569014282922], {
             RGBColor[
             0.2106927321879748, 0.33878179859330904`, 0.9353100114549157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.0860569014282922], {
             RGBColor[
             0.18403967249588782`, 0.31076774295533705`, 0.9337921591351197]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.0860569014282922], {
             RGBColor[
             0.3045714380557589, 0.43745427071408804`, 0.9406562648729865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.0860569014282922], {
             RGBColor[
             0.5663742859676012, 0.6588471860761407, 0.9590062049701908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.0860569014282922], {
             RGBColor[
             0.21438528258518844`, 0.34266290318199794`, 0.9355202967373982]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.0860569014282922], {
             RGBColor[
             0.48393777173830865`, 0.5919215101021562, 0.9525165005951594]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.0860569014282922], {
             RGBColor[
             0.9334491648933394, 0.7738551460928987, 0.26530983980554995`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.0860569014282922], {
             RGBColor[
             0.33049394994511194`, 0.46067898115870887`, 0.9422797601395455]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.0860569014282922], {
             RGBColor[
             0.9810175438161675, 0.9476298593785759, 0.3807571715722161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.0860569014282922], {
             RGBColor[
             0.2027780029210282, 0.3304629163109287, 0.9348592793319558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.0860569014282922], {
             RGBColor[
             0.304084721945441, 0.4369427012225601, 0.9406285471105358]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.0860569014282922], {
             RGBColor[
             0.5428330408674731, 0.6397353427828505, 0.9571529519214865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.0860569014282922], {
             RGBColor[
             0.19353123231110916`, 0.32074397412078526`, 0.9343326894250921]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.0860569014282922], {
             RGBColor[
             0.29911991378268726`, 0.43172437305648714`, 0.9403458086304425]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.0860569014282922], {
             RGBColor[
             0.3342797596203076, 0.46395805921903643`, 0.9425209885843889]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.0860569014282922], {
             RGBColor[
             0.21540663334735502`, 0.3437364075904136, 0.9355784611523505]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.0860569014282922], {
             RGBColor[
             0.8379345637063845, 0.8736102922443995, 0.9844041407909724]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.0860569014282922], {
             RGBColor[
             0.31358168594229274`, 0.44603042811457155`, 0.9412021256322137]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.0860569014282922], {
             RGBColor[
             0.1901247553990758, 0.3171635509031274, 0.9341386956043828]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.0860569014282922], {
             RGBColor[
             0.19681365185457406`, 0.3241940051783862, 0.9345196183621879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.0860569014282922], {
             RGBColor[
             0.2056030288546981, 0.3334321976842053, 0.9350201603796269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.0860569014282922], {
             RGBColor[
             0.2158208370998732, 0.3441717619963449, 0.935602049443297]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.0860569014282922], {
             RGBColor[
             0.19315143637710094`, 0.3203447845136896, 0.9343110606085081]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.0860569014282922], {
             RGBColor[
             0.24929221648012767`, 0.37935230393301794`, 0.937508194982534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.0860569014282922], {
             RGBColor[
             0.6797711867345639, 0.7497616846201918, 0.9687168971369385]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.0860569014282922], {
             RGBColor[
             0.4587788150425182, 0.5714963356584305, 0.9505358953637717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.0860569014282922], {
             RGBColor[
             0.4181101479346723, 0.5365677281391114, 0.9478625867994784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.0860569014282922], {
             RGBColor[
             0.48818097544843886`, 0.5953663340281886, 0.9528505411345881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.0860569014282922], {
             RGBColor[
             0.22967809360797173`, 0.35873661718716465`, 0.9363911997014592]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.0860569014282922], {
             RGBColor[
             0.8618019499281809, 0.8926414981547197, 0.9866806333954745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.0860569014282922], {
             RGBColor[
             0.4631485198395302, 0.5750438588656026, 0.9508798945321485]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.0860569014282922], {
             RGBColor[
             0.23426115126844915`, 0.3635537013709653, 0.9366521980551972]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.0860569014282922], {
             RGBColor[
             0.23051962020931505`, 0.35962111500104466`, 0.9364391233964787]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.0860569014282922], {
             RGBColor[
             0.21885291985763583`, 0.3473586732199038, 0.935774722070787]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.0860569014282922], {
             RGBColor[
             0.22655758961928207`, 0.35545676964367157`, 0.9362134916156754]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.0860569014282922], {
             RGBColor[
             0.24802738733723106`, 0.37802288830903413`, 0.9374361648339931]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.0860569014282922], {
             RGBColor[
             0.9779347509559622, 0.9830643539082616, 0.9222348904796338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.0860569014282922], {
             RGBColor[
             0.6013820686751921, 0.6872680811608015, 0.9617621458626657]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.0860569014282922], {
             RGBColor[
             0.1982372182974502, 0.32569026376917465`, 0.9346006883651319]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.0860569014282922], {
             RGBColor[
             0.9859314232921296, 0.9642055286847646, 0.39984666542805347`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.0860569014282922], {
             RGBColor[
             0.2610014285656661, 0.39165942824184447`, 0.9381750172885784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.0860569014282922], {
             RGBColor[
             0.18726572239046815`, 0.31415852593791815`, 0.9339758779041029]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.0860569014282922], {
             RGBColor[
             0.18845275152117702`, 0.31540616881628697`, 0.9340434774570445]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.0860569014282922], {
             RGBColor[
             0.4266116652397737, 0.5439313151301061, 0.948404295964563]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.0860569014282922], {
             RGBColor[
             0.19982772421039008`, 0.3273619863275738, 0.9346912653239311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.0860569014282922], {
             RGBColor[
             0.4770512439418583, 0.586330716602456, 0.9519743679008402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.0860569014282922], {
             RGBColor[
             0.19035022185825642`, 0.3174005304471254, 0.9341515355856854]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.0860569014282922], {
             RGBColor[
             0.22481780914373545`, 0.3536281500554188, 0.9361144136913675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.0860569014282922], {
             RGBColor[
             0.8274945099942945, 0.8652856768020875, 0.9834083591479672]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.0860569014282922], {
             RGBColor[
             0.2120977707203083, 0.34025858317537977`, 0.9353900263207638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.0860569014282922], {
             RGBColor[
             0.4177501378450422, 0.536255905494107, 0.9478396472749117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.0860569014282922], {
             RGBColor[
             0.2130775983694969, 0.3412884441593381, 0.93544582605586]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.0860569014282922], {
             RGBColor[
             0.3150309137810037, 0.44728567642815387`, 0.9412944691485945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.0860569014282922], {
             RGBColor[
             0.22268668288329785`, 0.35138820123448977`, 0.9359930492035543]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.0860569014282922], {
             RGBColor[
             0.993193928488921, 0.9878508261742159, 0.5005793021026774]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.0860569014282922], {
             RGBColor[
             0.18435110707541025`, 0.31109508044450795`, 0.9338098948736974]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.0860569014282922], {
             RGBColor[
             0.981651687789881, 0.9858364393130727, 0.9159430859521958]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.0860569014282922], {
             RGBColor[
             0.9487736339623114, 0.8346115593747768, 0.2776402673299655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.0860569014282922], {
             RGBColor[
             0.2278120755134005, 0.35677531385738964`, 0.9362849327314998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.0860569014282922], {
             RGBColor[
             0.2302467671760705, 0.35933432916322317`, 0.9364235848198853]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.0860569014282922], {
             RGBColor[
             0.9829894651638862, 0.9542816131135821, 0.3884177136420036]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.0860569014282922], {
             RGBColor[
             0.2829518153401187, 0.4147306764766984, 0.9394250593426964]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.0860569014282922], {
             RGBColor[
             0.9627353434690271, 0.8859597047428938, 0.30973427552741817`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.0860569014282922], {
             RGBColor[
             0.2059271258124198, 0.33377284413570474`, 0.9350386172219107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.0860569014282922], {
             RGBColor[
             0.19011491379531606`, 0.31715320675358216`, 0.9341381351396081]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.0860569014282922], {
             RGBColor[
             0.45951259018598095`, 0.572092047376087, 0.950593660830972]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.0860569014282922], {
             RGBColor[
             0.19816019677618812`, 0.3256093092668817, 0.9345963021034391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.0860569014282922], {
             RGBColor[
             0.1865974340180864, 0.31345611248661487`, 0.9339378198699398]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.0860569014282922], {
             RGBColor[
             0.8619160083689651, 0.8927324452593671, 0.9866915123913776]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.0860569014282922], {
             RGBColor[
             0.8567924356784412, 0.43753712399430794`, 0.2020178065845444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.0860569014282922], {
             RGBColor[
             0.49166457190272544`, 0.5981944745640103, 0.9531247826083038]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.0860569014282922], {
             RGBColor[
             0.22035367918749607`, 0.34893606642922426`, 0.9358601880944482]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.0860569014282922], {
             RGBColor[
             0.3846259152851337, 0.5075653687845483, 0.9457290011039943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.0860569014282922], {
             RGBColor[
             0.8226648881293261, 0.1752178387451157, 0.16933722850995975`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.0860569014282922], {
             RGBColor[
             0.4096552744186712, 0.5292445416538502, 0.94732384973539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.0860569014282922], {
             RGBColor[
             0.18026187282935408`, 0.3067970359794769, 0.9335770190328644]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.0860569014282922], {
             RGBColor[
             0.1948064264350734, 0.3220842839970489, 0.9344053098439712]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.0860569014282922], {
             RGBColor[
             0.28861702790878196`, 0.42068517408158657`, 0.9397476848175508]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.0860569014282922], {
             RGBColor[
             0.30003965645411895`, 0.4326910809192154, 0.9403981866149431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.0860569014282922], {
             RGBColor[
             0.19456249333096626`, 0.3218278948383802, 0.9343914182145591]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.0860569014282922], {
             RGBColor[
             0.25742088082667425`, 0.38789604554832535`, 0.9379711103917886]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.0860569014282922], {
             RGBColor[
             0.18024025860905457`, 0.30677431806352135`, 0.9335757881349936]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.0860569014282922], {
             RGBColor[
             0.19227972218525266`, 0.31942855762818506`, 0.9342614177748679]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.0860569014282922], {
             RGBColor[
             0.4032230834287326, 0.5236733011096846, 0.9469139962132742]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.0860569014282922], {
             RGBColor[
             0.5466494280863021, 0.6428336578533808, 0.9574533919032397]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.0860569014282922], {
             RGBColor[
             0.28151321698943976`, 0.41321861839773133`, 0.9393431332948408]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.0860569014282922], {
             RGBColor[
             0.9860284094714858, 0.9884904025100302, 0.8812089425821105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.0860569014282922], {
             RGBColor[
             0.18695890108123892`, 0.31383603728832365`, 0.9339584048844437]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.0860569014282922], {
             RGBColor[
             0.2996969855238355, 0.4323309120448956, 0.9403786720123997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.0860569014282922], {
             RGBColor[
             0.2157216182949494, 0.34406747674153443`, 0.9355963990791376]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.0860569014282922], {
             RGBColor[
             0.2192972622992264, 0.34782570529895346`, 0.9358000267154899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.0860569014282922], {
             RGBColor[
             0.3231603966004548, 0.4543270258466754, 0.9418124726052306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.0860569014282922], {
             RGBColor[
             0.6325346241150686, 0.7125591290735227, 0.9642145891424635]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.0860569014282922], {
             RGBColor[
             0.6344197195047021, 0.7140895344334067, 0.9643629907568674]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.0860569014282922], {
             RGBColor[
             0.1902491888261562, 0.31729433832452386`, 0.9341457819039722]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.0860569014282922], {
             RGBColor[
             0.8434965379903663, 0.8780452595626765, 0.9849346468634116]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.0860569014282922], {
             RGBColor[
             0.22184597588427246`, 0.3505045648746116, 0.9359451721836745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.0860569014282922], {
             RGBColor[
             0.9243202823709581, 0.9424919194296639, 0.9926436877546408]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.0860569014282922], {
             RGBColor[
             0.24782292745212858`, 0.377807988006286, 0.9374245211460078]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.0860569014282922], {
             RGBColor[
             0.5581381343170947, 0.6521607071318558, 0.9583578249422453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.0860569014282922], {
             RGBColor[
             0.9525439023720605, 0.8495594172519633, 0.28067391379202367`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.0860569014282922], {
             RGBColor[
             0.4420343431064375, 0.5572896635318818, 0.9493870153604882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.0860569014282922], {
             RGBColor[
             0.36751400675687457`, 0.4927438936869005, 0.9446386454240401]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.0860569014282922], {
             RGBColor[
             0.19842878437042233`, 0.3258916118578589, 0.934611597769591]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.0860569014282922], {
             RGBColor[
             0.9159682611686081, 0.7045491879901851, 0.25124429433908335`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.0860569014282922], {
             RGBColor[
             0.25866502514756723`, 0.3892037201128899, 0.9380419625703169]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.0860569014282922], {
             RGBColor[
             0.29666018860098814`, 0.42913904593493735`, 0.940205730920182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.0860569014282922], {
             RGBColor[
             0.30363758949702413`, 0.4364727366694393, 0.9406030835790716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[401, 0.0860569014282922], {
             RGBColor[
             0.18668189134142482`, 0.3135448824883471, 0.9339426295895605]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[402, 0.0860569014282922], {
             RGBColor[
             0.35222766772351993`, 0.4795036351299483, 0.9436646134180137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[403, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[404, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[405, 0.0860569014282922], {
             RGBColor[
             0.19069604752509664`, 0.31776401514958813`, 0.9341712298458087]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[406, 0.0860569014282922], {
             RGBColor[
             0.9938422671704169, 0.9892375570568399, 0.5711469665009675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[407, 0.0860569014282922], {
             RGBColor[
             0.6882645660939893, 0.7563967771278489, 0.9695634378163434]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[408, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[409, 0.0860569014282922], {
             RGBColor[
             0.5413266543134985, 0.638512390316393, 0.9570343636538818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[410, 0.0860569014282922], {
             RGBColor[
             0.19323299612210112`, 0.3204305089768713, 0.934315705315329]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[411, 0.0860569014282922], {
             RGBColor[
             0.7123092841021239, 0.7751806935824288, 0.9719599905967291]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[412, 0.0860569014282922], {
             RGBColor[
             0.2277251794483852, 0.35668398058352985`, 0.9362799841291484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[413, 0.0860569014282922], {
             RGBColor[
             0.4106589580798899, 0.5301138819945902, 0.9473878035707602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[414, 0.0860569014282922], {
             RGBColor[
             0.9933318523271546, 0.9881458313179586, 0.5155914607271469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[415, 0.0860569014282922], {
             RGBColor[
             0.1852681323985655, 0.3120589322019077, 0.9338621181092336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[416, 0.0860569014282922], {
             RGBColor[
             0.30953300584952725`, 0.44252366491079637`, 0.94094414731681]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[417, 0.0860569014282922], {
             RGBColor[
             0.25734139130129635`, 0.3878124970172262, 0.9379665835809126]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[418, 0.0860569014282922], {
             RGBColor[
             0.94854690985372, 0.8337126738355427, 0.27745783979029415`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[419, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[420, 0.0860569014282922], {
             RGBColor[
             0.21820107858971777`, 0.3466735467181985, 0.9357376006748919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[421, 0.0860569014282922], {
             RGBColor[
             0.2022293934039294, 0.3298862929246055, 0.934828036831552]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[422, 0.0860569014282922], {
             RGBColor[
             0.29787052949847936`, 0.4304111909582458, 0.9402746580437552]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[423, 0.0860569014282922], {
             RGBColor[
             0.18010256657334342`, 0.3066295950038096, 0.9335679467772571]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[424, 0.0860569014282922], {
             RGBColor[
             0.2415788936308724, 0.37124511256553566`, 0.9370689326571076]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[425, 0.0860569014282922], {
             RGBColor[
             0.21231746253184797`, 0.34048949319857336`, 0.9354025374444261]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[426, 0.0860569014282922], {
             RGBColor[
             0.21523898041579886`, 0.3435601937295382, 0.9355689135659188]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[427, 0.0860569014282922], {
             RGBColor[
             0.2116086394211203, 0.33974447516721756`, 0.93536217101688]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[428, 0.0860569014282922], {
             RGBColor[
             0.2170356376005423, 0.34544859434534847`, 0.9356712305346737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[429, 0.0860569014282922], {
             RGBColor[
             0.23501975925948257`, 0.36435104646806615`, 0.9366953996580266]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[430, 0.0860569014282922], {
             RGBColor[
             0.2764022607353688, 0.40784667932135976`, 0.9390520718971536]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[431, 0.0860569014282922], {
             RGBColor[
             0.9934489814254173, 0.9883963586155741, 0.5283402402360341]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[432, 0.0860569014282922], {
             RGBColor[
             0.7713866596486274, 0.8213323883640413, 0.9778482712817413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[433, 0.0860569014282922], {
             RGBColor[
             0.18644975521125867`, 0.31330089269726175`, 0.9339294097803622]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[434, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[435, 0.0860569014282922], {
             RGBColor[
             0.4494598255363201, 0.5637212431970474, 0.949860160534824]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[436, 0.0860569014282922], {
             RGBColor[
             0.9696998197036082, 0.9769227556637184, 0.9361744810758174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[437, 0.0860569014282922], {
             RGBColor[
             0.19181759620694716`, 0.3189428339245066, 0.9342351003840575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[438, 0.0860569014282922], {
             RGBColor[
             0.28107859249471434`, 0.41276180049699024`, 0.9393183820728355]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[439, 0.0860569014282922], {
             RGBColor[
             0.2663834741236062, 0.397316299364637, 0.9384815168210803]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[440, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[441, 0.0860569014282922], {
             RGBColor[
             0.3682418148538177, 0.4933742844797741, 0.9446850207124019]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[442, 0.0860569014282922], {
             RGBColor[
             0.44708899097258314`, 0.5616677454595485, 0.9497090930528694]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[443, 0.0860569014282922], {
             RGBColor[
             0.7513693824412065, 0.8056947392726626, 0.9758531361617966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[444, 0.0860569014282922], {
             RGBColor[
             0.8510308907134999, 0.3932513646686672, 0.19650054461938235`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[445, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[446, 0.0860569014282922], {
             RGBColor[
             0.1982250439704274, 0.32567746777957673`, 0.9345999950552182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[447, 0.0860569014282922], {
             RGBColor[
             0.4270628245166249, 0.5443220866197901, 0.9484330434347394]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[448, 0.0860569014282922], {
             RGBColor[
             0.8242283061574975, 0.8626812945213669, 0.9830968257102389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[449, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[450, 0.0860569014282922], {
             RGBColor[
             0.33974255441645423`, 0.4686896575034088, 0.9428690730382396]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[451, 0.0860569014282922], {
             RGBColor[
             0.2916100124153255, 0.4238309905641419, 0.9399181308574747]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[452, 0.0860569014282922], {
             RGBColor[
             0.3938614602073101, 0.5155647336041528, 0.9463174818597636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[453, 0.0860569014282922], {
             RGBColor[
             0.45788186350371485`, 0.5707681499920235, 0.9504652840529954]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[454, 0.0860569014282922], {
             RGBColor[
             0.3199106986804724, 0.45151230084295324`, 0.9416054047273643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[455, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[456, 0.0860569014282922], {
             RGBColor[
             0.25079540388990307`, 0.3809322492082784, 0.9375937992817542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[457, 0.0860569014282922], {
             RGBColor[
             0.9567649542169475, 0.8658201798815686, 0.2865404406964947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[458, 0.0860569014282922], {
             RGBColor[
             0.45245153773684854`, 0.5663125139373179, 0.9500507897907745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[459, 0.0860569014282922], {
             RGBColor[
             0.24592141072655926`, 0.37580937336458886`, 0.9373162325815285]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[460, 0.0860569014282922], {
             RGBColor[
             0.8245721358999006, 0.8629554550249494, 0.9831296204980098]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[461, 0.0860569014282922], {
             RGBColor[
             0.5415651525659718, 0.6387060139419746, 0.9570531391099645]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[462, 0.0860569014282922], {
             RGBColor[
             0.22691262429331643`, 0.35582993359658016`, 0.9362337103151348]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[463, 0.0860569014282922], {
             RGBColor[
             0.861357971174354, 0.4633407524188015, 0.20602603153182808`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[464, 0.0860569014282922], {
             RGBColor[
             0.2802695819329819, 0.41191147910237724`, 0.9392723101181687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[465, 0.0860569014282922], {
             RGBColor[
             0.1794538714957133, 0.3059477753475769, 0.9335310045522444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[466, 0.0860569014282922], {
             RGBColor[
             0.2476714334157858, 0.37764875816881305`, 0.9374158937847534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[467, 0.0860569014282922], {
             RGBColor[
             0.23156344686445007`, 0.3607182429980241, 0.9364985677802855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[468, 0.0860569014282922], {
             RGBColor[
             0.36840454856349925`, 0.4935152362398662, 0.9446953899604831]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[469, 0.0860569014282922], {
             RGBColor[
             0.1893750053770723, 0.3163755160931047, 0.9340959984497854]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[470, 0.0860569014282922], {
             RGBColor[
             0.24649818947394458`, 0.37641560439797556`, 0.9373490792779244]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[471, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[472, 0.0860569014282922], {
             RGBColor[
             0.19705660398054506`, 0.3244493632668362, 0.9345334541263465]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[473, 0.0860569014282922], {
             RGBColor[
             0.6063118000163332, 0.691270259145406, 0.9621502323720413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[474, 0.0860569014282922], {
             RGBColor[
             0.4068383352175211, 0.5268046505012949, 0.9471443568604142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[475, 0.0860569014282922], {
             RGBColor[
             0.94225898230895, 0.9564574240650298, 0.9826246610683506]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[476, 0.0860569014282922], {
             RGBColor[
             0.19832380395462978`, 0.32578127078471814`, 0.9346056192902162]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[477, 0.0860569014282922], {
             RGBColor[
             0.26019557655375813`, 0.3908124266833606, 0.9381291252086515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[478, 0.0860569014282922], {
             RGBColor[
             0.5167389750172862, 0.6185510046013983, 0.955098731472047]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[479, 0.0860569014282922], {
             RGBColor[
             0.1935343324702769, 0.320747232584632, 0.9343328659745704]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[480, 0.0860569014282922], {
             RGBColor[
             0.47940132385552714`, 0.5882386173462659, 0.9521593748002706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[481, 0.0860569014282922], {
             RGBColor[
             0.2923941296611816, 0.4246551475054415, 0.9399627851746286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[482, 0.0860569014282922], {
             RGBColor[
             0.9362533521083286, 0.9519784348947232, 0.9927906264787851]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[483, 0.0860569014282922], {
             RGBColor[
             0.9714214766675533, 0.9152600716225856, 0.3434782627650753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[484, 0.0860569014282922], {
             RGBColor[
             0.20427604235269314`, 0.3320374507347944, 0.9349445904614383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[485, 0.0860569014282922], {
             RGBColor[
             0.5545695953076797, 0.6492636064031623, 0.9580768964794351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[486, 0.0860569014282922], {
             RGBColor[
             0.9941045402798871, 0.9897985327181177, 0.5996937759047933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[487, 0.0860569014282922], {
             RGBColor[
             0.2384268837263016, 0.3679321503068611, 0.936889430356023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[488, 0.0860569014282922], {
             RGBColor[
             0.19444137114962554`, 0.3217005877462013, 0.9343845204855159]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[489, 0.0860569014282922], {
             RGBColor[
             0.2336066799286998, 0.3628658104970091, 0.9366149268806021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[490, 0.0860569014282922], {
             RGBColor[
             0.34185985738752034`, 0.47052355891820463`, 0.9430039857112984]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[491, 0.0860569014282922], {
             RGBColor[
             0.1905565107603236, 0.3176173531626698, 0.9341632834334811]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[492, 0.0860569014282922], {
             RGBColor[
             0.19478601411047772`, 0.3220628293496827, 0.9344041473922828]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[493, 0.0860569014282922], {
             RGBColor[
             0.5894436674267205, 0.677575949208445, 0.9608223111845814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[494, 0.0860569014282922], {
             RGBColor[
             0.9693843335785163, 0.976687466628186, 0.9367085167936384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[495, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[496, 0.0860569014282922], {
             RGBColor[
             0.2085981516455076, 0.3365802616390992, 0.9351907281916764]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[497, 0.0860569014282922], {
             RGBColor[
             0.946570060984783, 0.8258751268160418, 0.27586722078774056`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[498, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[499, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[500, 0.0860569014282922], {
             RGBColor[
             0.27395775301500525`, 0.40527734671651633`, 0.938912860798804]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{{3.834946926643799*^9, 3.8349469478612347`*^9}, 
   3.834947050298876*^9, {3.8349471234738255`*^9, 3.8349471300172663`*^9}, {
   3.8349471617829676`*^9, 3.834947218900016*^9}, {3.8349472753220577`*^9, 
   3.834947307624898*^9}, 3.83494993428115*^9, 3.8349573375769677`*^9, {
   3.8349587473655295`*^9, 3.83495875945916*^9}, 3.835018920680505*^9, 
   3.835019004300144*^9, 3.8350204747493663`*^9, 3.8350205388580465`*^9, 
   3.8350518972036915`*^9, 3.835055869064715*^9, 3.835056016720526*^9, 
   3.8350560834369273`*^9},
 Background->RGBColor[1, 1, 0.85],
 CellLabel->
  "Out[510]=",ExpressionUUID->"b35fbc28-e18c-4a20-9e8f-6eb3638d5f0a"]
}, Open  ]],

Cell["Estimated with cubic Mean Deviation v Calculated: (r=6)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 
  3.834950339812094*^9}},ExpressionUUID->"b413ebbd-15f2-4e2a-9441-\
8a6989493c37"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraphc", "[", 
     RowBox[{"graphin5", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsi5", ",", "#"}], "}"}], "]"}], ",", "500", ",", "3"}], 
     "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"CMDi6500", ",", "kri5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.834950273560528*^9, 3.834950273964845*^9}, {
   3.834957360267254*^9, 3.8349573712318316`*^9}, {3.8349587856645794`*^9, 
   3.83495878977224*^9}, {3.8350188291975336`*^9, 3.8350188308736053`*^9}, 
   3.8350559299682813`*^9},
 CellLabel->
  "In[504]:=",ExpressionUUID->"f33e23ee-2d15-4d5b-ad65-2b29bf8b4eff"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1dOWGAgQBNBMbNu2bds2J+bEtm3btm3btu01sjdnH271F1R1ssCg6p0C
ggUL9l38vMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEIS
kZgkJCUZyUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpR
mCIUpRjFKUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGY
JjSlGYE0pwUtaUVr2tCWdrSnAx3pRBCd6UJXutGdHvSkF73pQ1/60Z8BDGQQ
gxnCUIYxnBGMZBSjGcNYxjGeCUxkEpOZwlSmMZ0ZzGQWs5nDXOYxnwUsZBGL
WcJSlrGcFaxkFatZw1rWsZ4NbGQTm9nCVraxnR3sZBe72cNe9rGfAxzkEIc5
wlGOcZwTnOQUpznDWc5xngtc5BKXucJVrnGdG9zkFre5w13ucZ8HPOQRj3nC
U57xnBe85BWvecNb3vGeD3zkE5/5wle+8Z1f+JXf+J0/+JO/+Jt/+Jcf/Cx/
AMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEISkZgkJCUZ
yUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpRmCIUpRjF
KUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGYJjSlGYE0
pwUtaUVr2tCWdrSnAx35Od5BdKYLXelGd3rQk170pg996Ud/BjCQQQxmCEMZ
xnBGMJJRjGYMYxnHeCYwkUlMZgpTmcZ0ZjCTWcxmDnOZx3wWsJBFLGYJS1nG
clawklWsZg1rWcd6NrCRTWxmC1vZxnZ2sJNd7GYPe9nHfg5wkEMc5ghHOcZx
TnCSU5zmDGc5x3kucJFLXOYKV7nGdW5wk1vc5g53ucd9HvCQRzzmCU95xnNe
8JJXvOYNb3nHez7wkU985gtf+Rbw/z//Dz189+A=
          "], {Null, CompressedData["
1:eJxF3Al0ldW5gOF/21YsVqt2QFCqdkClVEWUGRVRJmWoghGKIgREKWUqk4DM
MSCTTAmozEMQUCJjEAMUZAhDSUCGmoo0QGkEEUnpbcV673nZL+uu5beeJjnn
P+ffw7e/vc+hd3Tu9VTPq5IkefYHSYJXhSRZnYoeqf+9KRWp/3n5f5dPRd/U
DydSXp8yN+XOEH9/POWwlG1CfPw8n4/fS9ktFdel4lOunXKurkt5PuWXXvfa
EIPrhVTkp+Jer8Pj7woxnta5us7XSQ/xtfD7KXv7vCY+rokx1+tXNPJ9fPMQ
o7f3tdTgvpd6n3k+viT1c0bKOf69Gm2SitdSPz+Y8uok/u1q//6blIUplySx
fT9P2TrEGJOKBrYnj78/5bKUP7B9VoUYtNPw1M/1U96dirG+/lrff1fff1fj
yv1fNGingiS+V6ybstg+x3yv92aIwXUXp37+SYjRxuedMbjOGdsBc329lrZz
S2Ou/TPSsTDS4D5H2l+0z+QQg3aqnMR75HX7pyI7iW2e7Wtn+7p3pHwyifL6
sx23VZLYVlVsryq2N47xfr8K8d6/sv0nOh4mGl86Th7z9zgiifc4wjYd4bgc
4bgeYTszDwb592M+55jB4/FpXee4P+U4eyrEOO74r2Ws8vpVbOcqPh+rOMar
2PZVbPcqzo/Oqce9nMR+WGjQ7siYHpOyi+3Xxf6YadAnMx2/zPuSEO8dGbP4
nH2CBXpGq/n3DM21f18Jse+6hRi8j6ucr1c5ju5MYi7B2brJeZWfxHma7zzN
N/ra/n18fB+v0cfYpJ1CzFvXpXwp5QXjOsfrePtjvP2B6cq9LjBKNMPnFTnO
i2znIiPdeX3YYH6TF08msZ9Pel9rvS+co0t1rfe41vukP7KdN9nGTi2x/V4w
Zut5+6pdiO8bS/SMEtxPBduwgs+t4HUqeB3auV6I7Yt9dJAStPNNjoWbHB83
OT5ucnzc5LigHXY53ncZtAt59afmJ/yj7YdTndd5SZzzeQbzHlsr85482SLE
vIbkS6yViiLH51nf41mD94d1HVcDjUHK+nQo5WYtdVxVCnE8IWMKH0nie8Zl
+gPnwQnnwQnH4xDnJxbpEOcJ1y/z+mVev8zXwDZKu9b0ejV9fE0fX9PH49Qk
rk208zcG6xh9XmB+QHIgdtFf2L/4eojjd4gxR1lLcK3jqYbxgp5Xro0TtUDJ
w5kpDxpnfZ9LQ6wb8Bslj+KDSs7bl4pZ9uksnz/L/kyVPZfrkruTeI/YxZ8L
9JSPq+B8xZNKfOq4qGr00D46UJkLVR0vvP8DxjfKez7gfSD5/3nb8Hnb83nb
83nbk/XrBmO1sp5NcrxP8v7o338bT/v8KfbLFOcVMremGFyfPL0sxFy9zP69
J8T8hEt1reYr0dd5+ZsQ5+VvnIdI1NfWyvtlDG73vrZ7P9u9t+22P419r9bS
XXpSWT+2JXEdw5lKkCsXOS6wvv132v7BHtpHNyl9eNoxf9rXqR3iuoyrlWii
LXWujz8f4vvCmbpNeW9YqDx+gPcxwJip25TnYKGed97nJDGf5RgFekbPKvkN
c329vsYIXa3UEniX1tYm2lK5T/JrnRDXJ6SOq2OwNj2S+v2RJObCIwZ5nDps
VRKfj7m6yutgtrLOkbdzjCLnaWXHSWXHf2XnaWXjUx93Y4hRQSsrf2+bxDmD
S7TU+XCPMUmpU/EVHavLfB9pSZwHaUaenlQGX5rvE1sr82FGEnM2XufPlbSm
ksd+7Hv5sc/7se/j50kcu/gLf+6i5GvqldIk1iu4UIuUoG7BIT7+wxAfjyN1
kRZpqfJcJI+eCzHHIu8BC7RcEvu+nH1ezj4vZ7+Xs9/L2e9YYj9OsJ8n2H8T
7NMJ9ukEg35l/f9ZiNFcuyr7JebLrhDrI1ygOXpGmTPYTjOU8fHzEONu39/8
JI6D+fb3fMfOfIP3jBW0sk5Q3jf5enwS8/V4Y46Ss3GKvqlrbadM51Wm8zHT
+ZPpfMw0snWnlvj8QT4PL+ogHzPIxw/y8azHzUI8I8DlSdxr4VX+fIOyTo1I
uT7EOYbH9N9KzsGndbWuU4J14WdJzAWYo0XOg4rGIiXfV3R+XOvvrvXvuE/r
+/cPnS8HQ5xLyFzC15X+XG9/rjfo1/X263r7db39uj75/zxU5vgo8/llPr/M
4DplXqfM65R5nTKvQ76fl8R9MD6n2Urk6BllDGOGkv9fSWINi5v9mbx3fxJr
Trygbfx9fy1zvNzpeMM7HSc4URkvNyQxx+NP/LmOUo/fx3UNxlKTJNaAOEsL
9KCyntFP1ZKYb6oZY3S2knuwQMk/5L20EPf7WFGJPOV85DtJnIM4XufoT/37
FGX+Ub/uSWJ77DG49h7bBx/TibbjaONzpX1xlX7p+y0fYqRpN83TfD1hv7S1
X9r6em3tj7ZGpk5U+mlKEtdl6vaxSay7sJa+oMR5XWX/TbD/Jhj0Y9Mkznlc
rcf0olbxcet0vTLPya/vG+RYJM9yvjEsxHof9ylnTEjeH+j9IDHV33c0WAOw
uXbV3j5uq89HxuhWr4PU8+8ZB/Qbpa5H6vrUf8nHIdaZeK/u0pPKHuFjx0Oj
EPdvOEMvKDUBVtKaSjAfqRt/GWJdiDN1mxKTtVDPe7+9vP9e3jfSRthcW2hX
JXrrQKV9yCPLQ8xP65K4311nMG7xyjjdEuJ6gxeV9WWLYxSzdYvjFEt83xtC
zCMbfJ8bfJ8bfJ8bfF8bfI8bjK2297tJzHU4Q4kLSptjJa2pjZR2vy/E9Qhz
dLmyLrFOlgsxrlX2mdP9PV6rx/WU4/+vIdZ6SM2Jy5R1IMtxkuX7wQLlvWc5
XrIcL1hXeX71ENcPnKc5WqBnlDWkulFTs5T1hHWtnnmjnpGmu/SkMjmwgjL+
U/8lvw9xD42DlHy/PYlrwXajQM9qXR/3gPeDB/WMnlXu4wEjQ6nnWP/XJLFG
wEVK7FPyC/vh4SHuhzFfOTccboxX+vOaJO4pcKou0dX+fb1utx0+CjFv4L3a
Q3cpeeMj42Pv/50krp3vGAf1rHKvuMvHdw/x8d39fXfbrbvt0t3x+EyIa9cz
BuOTfNM0xPmLxGTNVvIM+fCREHMlfqNEMyVffjeJNQwu0BJt59+vnLvuTeK+
BEcqwRqA6Uo9R921OMT6CamxsIIS1FXkrRrO2xoG85h97utJXMteN1brMWUd
w7v0aZ2rrG/UCdtCPFfZ5jjC8TpH12q+UmvgPdpXpyjXXeF18XkdouN1jvI8
fFOJtbrN+XNriH2B83SB5miJntFbnVvYTjM0V6/smxoa7yvrO7K+k89HhVgz
IjUj1tEWSpDL2V8UGuw7sLye0K9s75sdz7hUDyg5+GbjKR2ux22XiUa2ztMF
mqNnlHvGatpOMzRXaRfOY74b4vqN25SorU21pU7WbMf57iTuK3C9EmXK2McK
Wlkn6GL91Hn2oxDnGY7UvVqkpUqkK/OuehJrYtyjj/n7iUpdTr2xO8Qabbfj
49skrns4SQnWQFymrIOp/5KhSVw3cJASrB9IriTfHQgx3+EsXabb9aAe1rP6
K+/hV94PBn9fUR/TNJ2o1OfXJzHv4yG9wd+v1s26XdmPtUziGMdivcrfD9Kv
fPwlr33J4HGXfJ1Lvs4lX+eSr0MddizEPH7M8XTMsYaZOlmzdYsS1GPsvz8J
cf3ENbpPmds4Vu9I/b5XEuvDXsY6pU5E5u8Pk1ir4TCdoe/qBb3Ox1fSRnql
Pj6axLr4qEENjJO10PYotj1wlV5U2gUHaaZm6xbdqcW2UbHtRJ7+hfG8DlFy
Mq5Q8vJPkzhG8bD+wN8fsB07htiOHW03XKfUeSuSOP7xOZ2lOUps1wI9qGf0
rJLP8AGtq7wf9i+vGjP0Xb2g9NOr9hNW15raSLO83r0hfq6ABOeT5LtbQsxz
uFvLlFx3izFBFyv5jXq1c4jntZim8zVPyZHYWgnOXdmH/jjEvIjE/TrM67Yy
hmuefq58FoL1tbWOcZwscRzgEJ2jazVfqQ+wr76pxApdq9scPw8Yy/SwMr4e
sD+pS+cmMb9gUyWW6CUlz+BqXa/kGeq3f4R4Xoclyt4JczT1XzI4xM+isar2
0D66SfmcZrAxTz9SPrehrvvIOKTUdbhZS31fGQY1INbSjpqjvE/W65Eh1oc4
Ql/X1UptiHdpbW2iLZW48rnRo0ZfHaGr9aKSq7GK1tYm2lJHKtfnvGZHEs9r
cIISnNuQL/8UYs7FYTpaP9cLylzF/kqQb9mfPxziuQJynvCw0Vy7KucI1Bun
k1hv4EItUqJUqTEwXccrdQf5bm+IeRGf1F46T9cpuQc7aq6ynv3FeYxpOknz
lPyAnXWMjtXL+/kkngOcMi6fASR+FyiJNSYe11OO2w9C3Id84Pv7wNjsvHw2
xPn4rPMMl+gx/beyJ3nWWKfMT9a7hiGeF+Iq5bywodFW+2umTlTWOj7fmx9i
PYdHlHMXnKoEdR75t2qI+1uspfV0l55UEkNV42NfZ1+I+wFsowN1qm7Qrbpb
b3cOYa6u1ov6XR9XW5tqS83WLVqsx5T1nnr27RDrWWyo7+u3Sn2EryixTKlz
yTs/DDHu0xpaSzsqY6RuEvsEp+gRHejfpyp9ckfKlUmcL9hLiXVaqLwOdlPq
NNataUlcr6cZn+sFZe3GRkqu4Ly5ZxLP57GGvqDEbOU8HwuU83zW/z8b3ypt
iBOU9qNO3mlc1Mufadl/l/+mxVpiu+wPsV2wl67UdUpb4F4laBfqrj4h7jvw
HT2o1FDYXQn2g+TD9iHmQxypSzVf9+ppLVVyJN6jRLqSL6mf3gtxHuJ8Xa+7
tUypp7CC3qKVdYIuVoI6i/1PgxDzObJnwvJaUYk0zVP2TeSnds7HdkaurlLm
ZTv7EzM1W7foTi3WY0o/cz6w0fbeaDvjWs1X2hOf0vaarn11uI5XgrqLvdy0
EOcSFit7tWm2yzTbYpqRp/l6Qtn3jUviGoMn9JSW8+/X6s26VE/puOA1Qjyv
wwN6Si9fK3it4LVC/MxjnPc7zliqxx1nrRxnWE/n60ktU8YXVtVWjqlWjqnG
5qjG5qjG5qTG5qnG5qnG5qnG5qnGtjN+oPuV9qS+3RHiuosf6SG9pKy9O4xS
x82Lxmv6nh7Qb5SzPHxQh+s43aa0G+vxm0nMW28aO3WPFitrNbbVQTpRGffU
RTeFmM/wOZ2o2TpPc/SMErdqNa2uGZqr5EDqxhEhrssjjKm6W/cp9SLnfRdC
nNPIuR/W0YbaX0cp/bbFdsK5uly32E54SZlreIOu1u3KvKLu+zSJ6xoO12ma
p8Tnyn4O2ceRt9okMW+1Mdpprl5U6gxsqoM0U7N1i+7UYj2mJb7vNSG+b0zT
POU9YmvtrGOUoG5l/ekQ4uci2E1H6iLdq0Vaqqw/HYx0pT4n33w/xFyFxPX6
iDbTpb7+Al8P1yjXx/raQRf4Orz/6T5/uu9/uteZ7vvF01qqXHe615vue8ch
Ot3XmB7+//OFh0LMY1im5LGHjFa6WMlj7Ov/lMQzIByic5RgD48rlP07+eqc
4xsLtVjPOb6xvE7TfD2hjHPW5wEh5gnco6zTWFEbaFtNU2KiXlmvv+d4xHaa
q6uUqKNNNVOzdYvu1GI9pox31pWfGLW0nqbpLj2p7CWwqrbS1sqcYB/8nySe
Q+EwnaHv6gUlONfCSlpTG2mWXvn+zO0h5nlcrKuU/He7UUcban8dpZm6Uy/Y
Li28X6yiLWwXzFNyQgvvv4X3j2N0jZIX2Bc/HuI5L96j7F8eN8bqJz5+to/H
NbpPed5sHz/b5842PrGdahoN9E3do6x/2FDb6gDN1Il65XtJk43Fukpp+8n2
A9bRhtpfRyntzfnypBDPl/GocsY8yTE+yZishcr3MDgfuy2J51C3GRlaouzz
kPMn9s3NHPPNjLG6S88r472Z4x353k5D5kOI36PB95XP4k7aL8j+7KUQ92dY
XWvoC9pTZyufhbxkFCj7td5J3AvgSj2n5f17A03TbjpN8zRf9yt5jXz2aIj5
C8trRW2gRJoO0DzN9zrXeL/XeL/XOH6wge7Ra3wNvFMf07Y6QK98LtQlidfH
GtrFcY3cQxevjxX1MX1JB+hEpb2pI/+WxJoU39MDSnyj1KP4iLLucv78Woj1
LXbTpbpW83Wvsj/C9tpXiSW6Ual3OccaHeJ3JHCqLtF/K+dX+KwSnF+x/u4J
cT+Bu7VM2bdiBb1FH9JWuljfU4L967POQ/yhP9+nNbSW5uhy5fs/5K9/JnHc
YANto+30Tc3VVbpTCdY8vFPb6iDN1Gzdoju1WI9pie3+ZIj7HTykxA5ln0Od
3dpYrlu0UIv1nF5S6hG8QafpZj2h1CPUa0+EWGfiIl2je3WfUq/h/Up00GE6
XRcodRvn0oONo8oZNT6szZVzar5n+nUSz89xjBLsjZH9NPXZqCTuUbGXEit1
nRbqOWW/ih8o7cI6tTGJ6wsO0I2+b2T/gE11kk7WbC1U+p/8sz8xfyYxJ+83
yDtYXitqA31U03SATtM8JY/+K4l7PJyq7P+or55K4ucMTxnDdIa+qxf0P0qd
hZW0kY5Q6ivOXbcmsT7Bhvq+Et8qax7era/o27pMOUeknvpdEtdfrKX1tJmm
KbFLTyrrMVZV6i72Kysd/9hNR+oi3atFelpLlfmw0vmw0vGO7bWDput0XaAr
nR+041sh9gXO0u36L6UvsK6O0NR/SY/gv5ML8fM77KMD9fK/KTUG6zz9SD9W
Ps+j/vkiiecYmKHZOk/XKcGZBN6qHTVXOa8g/xwJcT7gct2vhVqs55TchuW1
gT6qaTpN8zRfiRNK/uP8aVGI+RgPKXl4kbFcdyj5mXX0YaOpztUlekzJw/is
jtbVul6v/HuLQyGuZ5ihrIFYQ2tpjhYp9eXfk5i/cZ8S5GecrZ8odSf1cE9f
v6f93tPXxxLldXsaOVqkh5R6mfz5lyTmc5ypR5WgVsdJWqjnHc9DHc9DHc9D
Hc9DHcfYSXvoYB3q+GWeNw5xfuNCXaqntVTJxY2Np7S9put4pa76ZRLXHnxJ
e2t5/95Nh2ieUkezznVIYr3fwRijXyvfAcUuWqCnlDqf/eesEPMl1tMWmqbz
9aTS0FhBK2tVbaWdlaBm43OWO0I818RZmqPv6ArdrgV6UM8qUU0f0LrK9yL4
fPsxo6NSP+DD2ly7ai/trQOVzyapD9OTWB+mG6N1sq5S9qd4u96pdbShttX+
yj6V+uWzED//xwm6QzmL+8z7ezHE+gMX61HlXrG5tlBilE5SPoP9URLHAA7V
XXpSq/q4h7SV7lHWAerpG5P4vm402mm6TtbFmqurlDr6RtvxRtvxRtvvRtsP
m+oozdRs3akXnNd/d17jSF2ke7VIT2upsm7j/fqEttcOmq7TdYGu1A+VfP3b
ENcT/EgPKfkbayixSJfb7xuSmDc3OMZxsC5WYqMeVcbGBsc/ttCu+qKO0km6
Qcm73ZN4Rozf9+frtZkyTh/BJH7WjbN0mR5W4l/K95vwLcf5WechdtTByr3g
w9pcu2pv5Xztv0nMb9hK03S45inBuRu21s46Rtco527k5dpJzMu1jQ7aU8co
5wP4jL6kBXrO+VTJGKrMu0rOu0rOO+r0hSHWg/iqztB39YL+R6kLsZLW1Eaa
peSjt5KYj94ydujXyr+9xINKv/86iZ8l4HQ9oaf0ay3n46+98jxlvWKdui3E
deo2+xHraQtN09/pfM3Tk/pfZR3Dykq01s46RmfpGr38vSL6L4n7F2yoxPu6
Vb9V9jF4t76ib+syZR9DfTUjxPoKb9MMLVHqK+ypRI5e+R7cphC/S4N9dYBu
U/aoWFubaEsdqeTRp42Ful+L9LSWKjUSNtDGmqbtNV3HK3UPdf+vQqyRcLnu
10It1nNK3Y/llUjTaZqn+XpETyj1PnX7l0k8X8GHta1O1bm6RIlLSj2PT+po
Xa3bdYeyX+DfjfxPEs8J8TUdr3P0b0p8o3yOjQ/qFL3yvdIzIX5/FJfpYSX3
4gEl/74QYv5F8usLRlftpb2Vuolzvw+TOH/xR/oTrafzldilJ5U5ihW0qj6k
rXSWvqfkRb439UYS1503jCl6RP+lvF+cqvN1t+11s/GAPqJ/1GX6mdKGN9ue
1L2HQ/x+Ec7Sd3SFbteDeljPKnUtdtcDyuc3f03i5zd4jz6jW5X4Vsk/+LiO
1bd1ti5T9n2cf9dP4nlKfaOZjtaxel75HAP5d9J8v+FW41WdoQXKWoTVtaZm
6ULN9b6zvF+cpFneY5b3m+V9ZnmfWd5nlveH5PM76M8QzwfxSe2lozRDV+o6
/UI5g8aOSnygnGNQt70cYn2GG/SoUovhi0qM0klKHXZLEtcgbKjP6Pu6VX/u
4+/Wt5V9/O+TOCZ/7zjG7XpYP9OzeofPq6tv6QFlXDJO6hj1tZn+TkfrWP1c
zyvjp47jh36fGeI+GF/SV5Wxgt2U2G+/fpXEehtHaYZ+oQR9h/dpLe2of1T6
k89d/pHE2gaX6iklqGfwZn1Kh+s4Ha98r4jP8x5K4v9/At6p1ZR4QXtoT52t
m5T9P3LGwb+H+HOI5z3Iv4PAYUq98W6I9Qbephlaol/oV0qbYS3tqTM0R4l/
OP77JXFf1s+YrIt1g25U9oFYR1voi/qyjlLmB/Xj20msX7G79tdxSuzQE/q1
Upfi9fqZnnIcPmG8pK/qNOX7tFhTG+kQZYxSv88J8Zwdh+lk5d6xjRL79IKW
2b/v2L/v2K/vGFf696j9ihM1WxdoiXIWi+00Q2foUfuTefV+iHMGa+hvdbkS
RXrI/PN8iDkM79GG+oxu1W+VeEXf1mVK3cznJg8aT2tvXaj7lboUy2tF/ZU2
0Ec1TQdonubrEfv1jRBrYSxVxgJ20CFKTNcFulI5K+Dzhn4hnlP087rIeQTW
1ye0g/bzGv28fj+v38/r9/P6yHkE5zZXh/g9PWyj7TRXd+o/9aJyZnO1MUgz
dYvu1GI9pnzOyb6iUxL7r5P908k+7GQs1P1apKe1VOnXTvZnJ/uxk/2IjTVN
03W80q+cM3ycxHOGj42j+hfl7AEf1ubaVTl3IEc/F+I5NG5S/n+LsJ4SnXSw
DlXOpZnXfzAW6Rrdp39X5j7OVuo36vG7jPm6Xnfrn7VM+Wweb9HKOkEX63vK
5/HUvc2TWH/jI0r8Ud/QI0q9jFOV+pt96/8m8fuZ+Kj21QG6WrcpwV4Wa2sT
bakjdZNeHof0m9FNR+peZc3E+/UJfU1XKvOJ8+IPknhejOk6WifrKiU458Q7
taG21f46UXfql8p6wD6rURLPhxoZA3WQDtXfO+8eN7pqNx2pe7VIT2upkose
t10et12wvXbQdO2n03WBrtQPlXakzv88xP0N3qJ/0DW6T/+qf1dqXnxcx+ps
/URPKuPgdyF+/xM7a1dlDOD9SgxT1ln2OZ8ksV7F5zRHV2iBEmeUz0GxmlbX
mlpXs5R9EPXU8SSeA2NH7aeDdYNu1I/1qBLkM2yuLfRFfVkn6QYt9L6/CPG+
sYk+p7M0R1fodi3QT/SsstfAalpd62qWcv76hxDrZLxPO+gYfUu/Vmpk5Bz+
nyGew+MhpZ7B3+oiXa4f6GbdoaWa+i95NcTPJbGRDtRBOlSZk9hDiXnK5yvU
cZuTWKfjbZqhRIl+odToWEt76gzN0XeVuu72lL8OMe9iG22nuXpR/1fJvfg9
vVqJ2tpUJ2u2btFiPaZX6oPvhFgP4ePaTRdpkZYq8SN9QjtoP31Dp+sCXakf
KvmIfUV7Y5xO11P6D2X/gNfqzfqMjtPjeuX/t+dvIa5vOFM36EY9qn/R48pn
5H+zjfFlnaSTtVAJPj/nnPW3xis6Sgv1kF5Sxj5u1h3KuP8/ONwSDw==
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[13, 59] -> 
             RGBColor[
              0.8758087454125018, 0.41984658819913434`, 0.3658723730660921], 
             UndirectedEdge[210, 309] -> 
             RGBColor[
              0.844571750401957, 0.8790213032131868, 0.9636789221856116], 
             UndirectedEdge[88, 427] -> 
             RGBColor[
              0.8764931836219652, 0.4198763079461296, 0.3361162766299012], 
             UndirectedEdge[293, 483] -> 
             RGBColor[
              0.7018829699032988, 0.7666601147044692, 0.971177499128846], 
             UndirectedEdge[46, 150] -> 
             RGBColor[
              0.9402136350291203, 0.7988386273393338, 0.280311426887564], 
             UndirectedEdge[400, 444] -> 
             RGBColor[
              0.8596819590739189, 0.4087713554575028, 0.43580771416750785`], 
             UndirectedEdge[98, 105] -> 
             RGBColor[
              0.9451973451227361, 0.804748572578855, 0.4822182899072236], 
             UndirectedEdge[128, 439] -> 
             RGBColor[
              0.780325934612901, 0.648439160466273, 0.5950404777839722], 
             UndirectedEdge[23, 62] -> 
             RGBColor[
              0.9492580970096642, 0.9584329111647943, 0.813457303749337], 
             UndirectedEdge[201, 236] -> 
             RGBColor[
              0.9396041662103289, 0.8394716851056695, 0.6000647212692425], 
             UndirectedEdge[40, 477] -> 
             RGBColor[
              0.7723446387104487, 0.8220807688880465, 0.9779437536818003], 
             UndirectedEdge[455, 482] -> 
             RGBColor[
              0.8879268709244894, 0.9129237636694066, 0.9696762183391631], 
             UndirectedEdge[60, 131] -> 
             RGBColor[
              0.8262665241751039, 0.8650356655959746, 0.983097738414475], 
             UndirectedEdge[179, 222] -> 
             RGBColor[
              0.6927248389991689, 0.7055923117354708, 0.6172622063796034], 
             UndirectedEdge[111, 175] -> 
             RGBColor[
              0.7477340057958953, 0.803032804740476, 0.9755229756057087], 
             UndirectedEdge[51, 110] -> 
             RGBColor[
              0.8380410869753787, 0.8738619233090773, 0.9601135189729231], 
             UndirectedEdge[84, 261] -> 
             RGBColor[
              0.9040253370689244, 0.9252356551688924, 0.953484658385698], 
             UndirectedEdge[156, 479] -> 
             RGBColor[
              0.9667654529300269, 0.9723649047272973, 0.816821364193289], 
             UndirectedEdge[158, 437] -> 
             RGBColor[
              0.7496754062731755, 0.8037284463656653, 0.9662685840078806], 
             UndirectedEdge[103, 355] -> 
             RGBColor[
              0.8471950988265416, 0.8405670720753342, 0.6453749737884169], 
             UndirectedEdge[13, 228] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[59, 409] -> 
             RGBColor[
              0.7441197567657654, 0.7962772285936024, 0.8613020025630711], 
             UndirectedEdge[243, 430] -> 
             RGBColor[
              0.9625059105858152, 0.9715575500226135, 0.9483518927402463], 
             UndirectedEdge[333, 441] -> 
             RGBColor[
              0.95507243076227, 0.9638934225226368, 0.871066054743561], 
             UndirectedEdge[179, 385] -> 
             RGBColor[
              0.6826582149540767, 0.7490024521050213, 0.9704702466835993], 
             UndirectedEdge[81, 447] -> 
             RGBColor[
              0.7222528166843867, 0.7769153186908921, 0.7532510372325918], 
             UndirectedEdge[69, 404] -> 
             RGBColor[
              0.8382141073541229, 0.2720878256117942, 0.18334033459222407`], 
             UndirectedEdge[113, 380] -> 
             RGBColor[
              0.7888193925336342, 0.8336937103543864, 0.9119466410704486], 
             UndirectedEdge[85, 489] -> 
             RGBColor[
              0.8544658224045869, 0.8868653135302432, 0.9859614171365358], 
             UndirectedEdge[277, 498] -> 
             RGBColor[
              0.8762771155155706, 0.420040271273316, 0.3581102683552697], 
             UndirectedEdge[18, 160] -> 
             RGBColor[
              0.9572976282145504, 0.8554205937571029, 0.46979245623624666`], 
             UndirectedEdge[355, 431] -> 
             RGBColor[
              0.8253877388227351, 0.7566676858584281, 0.6144981878096838], 
             UndirectedEdge[357, 492] -> 
             RGBColor[
              0.9194603860349595, 0.9381928345311149, 0.9774820373334476], 
             UndirectedEdge[165, 386] -> 
             RGBColor[
              0.8506890843178316, 0.8801688225860056, 0.7572348036758294], 
             UndirectedEdge[218, 274] -> 
             RGBColor[
              0.9901843573322096, 0.9773696367719296, 0.5658936446211218], 
             UndirectedEdge[116, 441] -> 
             RGBColor[
              0.8614163915312146, 0.8899508134775151, 0.8619377000602448], 
             UndirectedEdge[258, 435] -> 
             RGBColor[
              0.8153619725708763, 0.8562119118077343, 0.9612489104958257], 
             UndirectedEdge[112, 445] -> 
             RGBColor[
              0.6128794243159468, 0.6935149813817817, 0.9644929085821297], 
             UndirectedEdge[114, 179] -> 
             RGBColor[
              0.7118075378207449, 0.7689819574025344, 0.8423111145527004], 
             UndirectedEdge[155, 467] -> 
             RGBColor[
              0.9245684973216617, 0.8659085731192606, 0.6310678389892661], 
             UndirectedEdge[243, 421] -> 
             RGBColor[
              0.7367826808561673, 0.7921030658136684, 0.9341814565188311], 
             UndirectedEdge[172, 289] -> 
             RGBColor[
              0.9314481362712657, 0.7573438443678588, 0.53412426868643], 
             UndirectedEdge[381, 468] -> 
             RGBColor[
              0.9188240182121785, 0.907956781523356, 0.6685886834507142], 
             UndirectedEdge[17, 277] -> 
             RGBColor[
              0.9929605558070855, 0.987812382179335, 0.5841295818718607], 
             UndirectedEdge[279, 477] -> 
             RGBColor[
              0.5742971458714498, 0.6628711455110071, 0.9608603093147285], 
             UndirectedEdge[4, 405] -> 
             RGBColor[
              0.8707617960182173, 0.5060413247156917, 0.21387281349038761`], 
             UndirectedEdge[36, 379] -> 
             RGBColor[
              0.9557486799940477, 0.9640815087805339, 0.8524341229459538], 
             UndirectedEdge[278, 401] -> 
             RGBColor[
              0.7068304303277406, 0.7709005713730497, 0.9714139096552981], 
             UndirectedEdge[152, 399] -> 
             RGBColor[
              0.8379541812815049, 0.270907562023312, 0.18312344590586047`], 
             UndirectedEdge[173, 406] -> 
             RGBColor[
              0.5339461301791677, 0.6324521085174788, 0.9564722518838626], 
             UndirectedEdge[239, 332] -> 
             RGBColor[
              0.8319911223878447, 0.386841152574414, 0.4383573767716197], 
             UndirectedEdge[116, 361] -> 
             RGBColor[
              0.8242200337600153, 0.8634108727484238, 0.9829006786278573], 
             UndirectedEdge[288, 498] -> 
             RGBColor[
              0.7375360445975423, 0.312171739242496, 0.42945169086265567`], 
             UndirectedEdge[16, 386] -> 
             RGBColor[
              0.9492465564161273, 0.9578490926137048, 0.7668759356623438], 
             UndirectedEdge[216, 464] -> 
             RGBColor[
              0.7679355626915176, 0.8166499013755117, 0.9065663593584858], 
             UndirectedEdge[379, 400] -> 
             RGBColor[
              0.8503299877329296, 0.401464066005346, 0.44010655411953226`], 
             UndirectedEdge[22, 24] -> 
             RGBColor[
              0.7626954774262356, 0.8109469312354902, 0.8455869429728797], 
             UndirectedEdge[231, 355] -> 
             RGBColor[
              0.7881366113474993, 0.35235885677204803`, 0.4340454981259927], 
             UndirectedEdge[434, 495] -> 
             RGBColor[
              0.6810240220227881, 0.7494761933307712, 0.9697061192549723], 
             UndirectedEdge[75, 323] -> 
             RGBColor[
              0.7754705595555856, 0.721426287867666, 0.6105611956884682], 
             UndirectedEdge[165, 288] -> 
             RGBColor[
              0.6428825031299363, 0.7199576093149754, 0.9657145544112533], 
             UndirectedEdge[90, 229] -> 
             RGBColor[
              0.9196086862326818, 0.9378574058638252, 0.9617668390012681], 
             UndirectedEdge[267, 424] -> 
             RGBColor[
              0.8436568912133597, 0.2968022359221214, 0.18788192685921193`], 
             UndirectedEdge[258, 403] -> 
             RGBColor[
              0.6099446296500836, 0.6937671862623219, 0.9627455082522394], 
             UndirectedEdge[274, 305] -> 
             RGBColor[
              0.8902287164396463, 0.5399227818929886, 0.258285432632826], 
             UndirectedEdge[399, 478] -> 
             RGBColor[
              0.878533950538692, 0.5413328631603604, 0.2203580897352121], 
             UndirectedEdge[359, 463] -> 
             RGBColor[
              0.916058999747078, 0.9350811278975386, 0.963305531578136], 
             UndirectedEdge[302, 422] -> 
             RGBColor[
              0.8791636765993616, 0.5003292248323418, 0.43224418866331393`], 
             UndirectedEdge[21, 335] -> 
             RGBColor[
              0.6790968419445585, 0.7492348813450294, 0.9686496847503812], 
             UndirectedEdge[266, 445] -> 
             RGBColor[
              0.47618678026918443`, 0.5849291878474456, 0.9520996483778861], 
             UndirectedEdge[200, 452] -> 
             RGBColor[
              0.9334899291846137, 0.9466940262204959, 0.8694375890333614], 
             UndirectedEdge[112, 471] -> 
             RGBColor[
              0.6899545501120022, 0.7567877588997567, 0.9703672105962902], 
             UndirectedEdge[481, 496] -> 
             RGBColor[
              0.6075762632937749, 0.6922098482091986, 0.9623092300250615], 
             UndirectedEdge[6, 422] -> 
             RGBColor[
              0.8391422544904172, 0.8745993856630255, 0.9540082668500629], 
             UndirectedEdge[137, 424] -> 
             RGBColor[
              0.9399623080827267, 0.7892333092443288, 0.3129840025003589], 
             UndirectedEdge[89, 482] -> 
             RGBColor[
              0.7596785295344615, 0.8115019747867122, 0.9577367745383838], 
             UndirectedEdge[142, 254] -> 
             RGBColor[
              0.972360479830194, 0.9562420395263489, 0.6554781108468252], 
             UndirectedEdge[178, 321] -> 
             RGBColor[
              0.877544595635901, 0.486277417662654, 0.217430570537542], 
             UndirectedEdge[151, 456] -> 
             RGBColor[
              0.9494033524188124, 0.9617856835951326, 0.9705311060225056], 
             UndirectedEdge[346, 431] -> 
             RGBColor[
              0.7314451373552785, 0.6817399030526057, 0.6061871641598822], 
             UndirectedEdge[65, 297] -> 
             RGBColor[
              0.9118911325915111, 0.6816680197977678, 0.2476162924308571], 
             UndirectedEdge[79, 253] -> 
             RGBColor[
              0.8654327326346526, 0.5269670589705626, 0.45574753030754533`], 
             UndirectedEdge[376, 475] -> 
             RGBColor[
              0.7937345924778777, 0.8395708058803004, 0.9798687050669903], 
             UndirectedEdge[209, 259] -> 
             RGBColor[
              0.9038572071336889, 0.9254378465266986, 0.9651267455514543], 
             UndirectedEdge[464, 496] -> 
             RGBColor[
              0.5577056480309611, 0.6518095952814875, 0.9583237780375514], 
             UndirectedEdge[101, 103] -> 
             RGBColor[
              0.889341836984537, 0.8734924242514339, 0.6495757667643446], 
             UndirectedEdge[69, 348] -> 
             RGBColor[
              0.8382141073541229, 0.2720878256117942, 0.18334033459222407`], 
             UndirectedEdge[116, 277] -> 
             RGBColor[
              0.8615481363533235, 0.8900052933471447, 0.8597543474132296], 
             UndirectedEdge[171, 471] -> 
             RGBColor[
              0.7878605197111979, 0.8304558279020833, 0.7755086184374896], 
             UndirectedEdge[133, 429] -> 
             RGBColor[
              0.8789946098360092, 0.5293625713071981, 0.4436651446263631], 
             UndirectedEdge[37, 203] -> 
             RGBColor[
              0.9791389701463035, 0.9412929892800512, 0.373459267603665], 
             UndirectedEdge[299, 399] -> 
             RGBColor[
              0.8379541812815049, 0.270907562023312, 0.18312344590586047`], 
             UndirectedEdge[311, 429] -> 
             RGBColor[
              0.9628098535022189, 0.9717842301520064, 0.9478373966637836], 
             UndirectedEdge[327, 446] -> 
             RGBColor[
              0.9798795809233098, 0.9838454800385648, 0.8889690652254204], 
             UndirectedEdge[15, 249] -> 
             RGBColor[
              0.9415038821063118, 0.9556535008351734, 0.9755551762192747], 
             UndirectedEdge[50, 242] -> 
             RGBColor[
              0.6446067701441865, 0.7208455138583401, 0.9662003064805722], 
             UndirectedEdge[163, 355] -> 
             RGBColor[
              0.8438753382940531, 0.8785019202033825, 0.964857766230925], 
             UndirectedEdge[192, 435] -> 
             RGBColor[
              0.9578195396293916, 0.91738653521597, 0.6206303010216494], 
             UndirectedEdge[31, 191] -> 
             RGBColor[
              0.6225979767352874, 0.5740531936850004, 0.5948057679781144], 
             UndirectedEdge[385, 415] -> 
             RGBColor[
              0.9237757045113593, 0.818629650516251, 0.6198466613700029], 
             UndirectedEdge[207, 257] -> 
             RGBColor[
              0.8365851746298115, 0.3905043251299323, 0.4387955615756174], 
             UndirectedEdge[359, 408] -> 
             RGBColor[
              0.8818706463032143, 0.7651030168375335, 0.6122926329680827], 
             UndirectedEdge[183, 202] -> 
             RGBColor[
              0.6458561901163835, 0.7094349073267345, 0.7167848250808098], 
             UndirectedEdge[170, 223] -> 
             RGBColor[
              0.9686139422395793, 0.9625780252812208, 0.6812015966418321], 
             UndirectedEdge[40, 430] -> 
             RGBColor[
              0.8773745434061685, 0.9049378140770857, 0.98166457956009], 
             UndirectedEdge[69, 444] -> 
             RGBColor[
              0.9122060996420627, 0.7530347716039455, 0.6002860731395978], 
             UndirectedEdge[215, 417] -> 
             RGBColor[
              0.7648365052738608, 0.813580421399317, 0.8831828504243788], 
             UndirectedEdge[423, 429] -> 
             RGBColor[
              0.9617540823477998, 0.9337945834253155, 0.6425722036547701], 
             UndirectedEdge[5, 83] -> 
             RGBColor[
              0.6491492127718788, 0.7255622485785258, 0.9658543882668829], 
             UndirectedEdge[311, 366] -> 
             RGBColor[
              0.9236057962692368, 0.9410590263474752, 0.962648503321238], 
             UndirectedEdge[133, 366] -> 
             RGBColor[
              0.8528585716806878, 0.5088791021041773, 0.4535392157313327], 
             UndirectedEdge[76, 359] -> 
             RGBColor[
              0.8010194575623921, 0.8448414468799622, 0.9807063405608777], 
             UndirectedEdge[172, 218] -> 
             RGBColor[
              0.9349777122694447, 0.7588034147490715, 0.47563006014672626`], 
             UndirectedEdge[177, 484] -> 
             RGBColor[
              0.8458733854594958, 0.7856931366517205, 0.6194236080820775], 
             UndirectedEdge[45, 328] -> 
             RGBColor[
              0.8718198170360235, 0.43650026452467194`, 0.21481605305525872`],
              UndirectedEdge[115, 144] -> 
             RGBColor[
              0.4891103845787862, 0.5934464098769114, 0.9536626689898766], 
             UndirectedEdge[63, 72] -> 
             RGBColor[
              0.7853538733038754, 0.8321769861100008, 0.9552147751142779], 
             UndirectedEdge[248, 387] -> 
             RGBColor[
              0.7012419919229518, 0.764987984160038, 0.9722088346340408], 
             UndirectedEdge[34, 44] -> 
             RGBColor[
              0.8516627007795723, 0.8543188559567291, 0.6608053762174072], 
             UndirectedEdge[279, 285] -> 
             RGBColor[
              0.7044683631346595, 0.7612093706607499, 0.7263107291987382], 
             UndirectedEdge[13, 77] -> 
             RGBColor[
              0.875963077373552, 0.41991040843117905`, 0.3633146930731791], 
             UndirectedEdge[53, 445] -> 
             RGBColor[
              0.694946544221047, 0.7580899601238571, 0.9485439666767717], 
             UndirectedEdge[91, 298] -> 
             RGBColor[
              0.7259577755586328, 0.7849815940607858, 0.9742371653102562], 
             UndirectedEdge[6, 451] -> 
             RGBColor[
              0.7866059075672251, 0.8335814720767005, 0.9792697325996422], 
             UndirectedEdge[87, 256] -> 
             RGBColor[
              0.7329841817010304, 0.7878886191377532, 0.8876711613220039], 
             UndirectedEdge[153, 172] -> 
             RGBColor[
              0.9157578492069162, 0.7462518786947314, 0.5879930293126645], 
             UndirectedEdge[72, 438] -> 
             RGBColor[
              0.9674168758800878, 0.9752201398981144, 0.9400389094819274], 
             UndirectedEdge[207, 440] -> 
             RGBColor[
              0.7638235236112407, 0.8158696327582067, 0.9769761937218729], 
             UndirectedEdge[19, 228] -> 
             RGBColor[
              0.7416719876315849, 0.31552948411964216`, 0.4297772874487541], 
             UndirectedEdge[8, 63] -> 
             RGBColor[
              0.4710766197114795, 0.5782425575525428, 0.9523986069744207], 
             UndirectedEdge[72, 128] -> 
             RGBColor[
              0.9211078040718788, 0.7588774895990095, 0.5846876276591257], 
             UndirectedEdge[229, 485] -> 
             RGBColor[
              0.7094371136607784, 0.7719128485725846, 0.9725412682149656], 
             UndirectedEdge[32, 407] -> 
             RGBColor[
              0.8864900694061272, 0.9090123223376557, 0.8309260510290362], 
             UndirectedEdge[475, 478] -> 
             RGBColor[
              0.897167944828654, 0.737223662175853, 0.6058394558648349], 
             UndirectedEdge[194, 412] -> 
             RGBColor[
              0.8178892826681037, 0.8569078468134246, 0.9011634279508235], 
             UndirectedEdge[370, 390] -> 
             RGBColor[
              0.8273881750707837, 0.8487701256167546, 0.6779754411106333], 
             UndirectedEdge[231, 233] -> 
             RGBColor[
              0.8762578943105568, 0.4200323228110802, 0.3584288134652338], 
             UndirectedEdge[114, 385] -> 
             RGBColor[
              0.9656364584487427, 0.9721322955241708, 0.8642357599073298], 
             UndirectedEdge[271, 442] -> 
             RGBColor[
              0.8670612744636644, 0.38902244942097297`, 0.2176577568251678], 
             UndirectedEdge[206, 254] -> 
             RGBColor[
              0.8806474441908974, 0.8842068327640755, 0.6742740043453579], 
             UndirectedEdge[262, 455] -> 
             RGBColor[
              0.8176634177766232, 0.37542542236652, 0.4369884542471537], 
             UndirectedEdge[7, 341] -> 
             RGBColor[
              0.9235961382602629, 0.798058212491259, 0.6053311247536293], 
             UndirectedEdge[187, 328] -> 
             RGBColor[
              0.8417601152242626, 0.32199212177866543`, 0.1876228395410453], 
             UndirectedEdge[44, 56] -> 
             RGBColor[
              0.8911337452790298, 0.8851539359107543, 0.6647394810552307], 
             UndirectedEdge[142, 388] -> 
             RGBColor[
              0.6187792894179369, 0.6883687926028448, 0.9400865805418164], 
             UndirectedEdge[282, 419] -> 
             RGBColor[
              0.9861752694261235, 0.9879054996494969, 0.8498623181103786], 
             UndirectedEdge[7, 244] -> 
             RGBColor[
              0.8902389744353574, 0.5944826428973309, 0.23012504859098004`], 
             UndirectedEdge[107, 470] -> 
             RGBColor[
              0.9551514024451537, 0.9654635176247524, 0.936518167886174], 
             UndirectedEdge[10, 383] -> 
             RGBColor[
              0.9233967365071527, 0.7511083462347841, 0.5745026077996789], 
             UndirectedEdge[249, 419] -> 
             RGBColor[
              0.9592034448034932, 0.9675491862731569, 0.8871709092875224], 
             UndirectedEdge[191, 271] -> 
             RGBColor[
              0.9386711257121461, 0.791428970641415, 0.2858100932376953], 
             UndirectedEdge[297, 490] -> 
             RGBColor[
              0.8806127000722116, 0.83462018057713, 0.6277109798050532], 
             UndirectedEdge[32, 176] -> 
             RGBColor[
              0.9923300230380088, 0.9907434279501994, 0.7511261576610562], 
             UndirectedEdge[353, 487] -> 
             RGBColor[
              0.7118989201526178, 0.7729338151484568, 0.9599157784340052], 
             UndirectedEdge[281, 324] -> 
             RGBColor[
              0.934974458181429, 0.8568893136150657, 0.6240939767379856], 
             UndirectedEdge[19, 59] -> 
             RGBColor[
              0.79158309956613, 0.8348101084781647, 0.8650384907722692], 
             UndirectedEdge[197, 411] -> 
             RGBColor[
              0.7938255478337752, 0.4474870064928065, 0.44587941042908075`], 
             UndirectedEdge[163, 343] -> 
             RGBColor[
              0.8188052532126823, 0.8589169791981119, 0.9623590144432792], 
             UndirectedEdge[12, 396] -> 
             RGBColor[
              0.9024499125457236, 0.9246798766280242, 0.977618470707948], 
             UndirectedEdge[51, 397] -> 
             RGBColor[
              0.850862789546753, 0.8740813900980686, 0.6904974388247966], 
             UndirectedEdge[448, 482] -> 
             RGBColor[
              0.9753404784920092, 0.9778225789421205, 0.7279142458314034], 
             UndirectedEdge[183, 285] -> 
             RGBColor[
              0.6459097438751682, 0.7095494534016598, 0.7226138212290487], 
             UndirectedEdge[155, 365] -> 
             RGBColor[
              0.8644335111197348, 0.5276016752393733, 0.4558313705796173], 
             UndirectedEdge[122, 217] -> 
             RGBColor[
              0.7536258684982454, 0.8074575233303507, 0.9760780416039011], 
             UndirectedEdge[249, 269] -> 
             RGBColor[
              0.9174629203611019, 0.9370240451011378, 0.9919896264445014], 
             UndirectedEdge[101, 331] -> 
             RGBColor[
              0.8868615800748212, 0.8651259353029462, 0.639940437027315], 
             UndirectedEdge[246, 458] -> 
             RGBColor[
              0.7934776361453193, 0.7240290377672842, 0.609610314462266], 
             UndirectedEdge[35, 437] -> 
             RGBColor[
              0.5239110895764139, 0.624373650300577, 0.9556633466024629], 
             UndirectedEdge[354, 473] -> 
             RGBColor[
              0.9593154934476746, 0.9691781421448169, 0.9537524367610619], 
             UndirectedEdge[230, 484] -> 
             RGBColor[
              0.9172601770844262, 0.7096712040909459, 0.25228380021011476`], 
             UndirectedEdge[108, 190] -> 
             RGBColor[
              0.9056201085888542, 0.6543443500725712, 0.24244316661791004`], 
             UndirectedEdge[55, 136] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[59, 279] -> 
             RGBColor[
              0.704245612566082, 0.7628842662816928, 0.8584451619761462], 
             UndirectedEdge[24, 170] -> 
             RGBColor[
              0.9899638141214828, 0.9767298068261734, 0.5657565086037563], 
             UndirectedEdge[184, 388] -> 
             RGBColor[
              0.6184680584569546, 0.6881366770617381, 0.9406134133767244], 
             UndirectedEdge[173, 242] -> 
             RGBColor[
              0.4993986506543562, 0.6044049082930203, 0.9537525477440822], 
             UndirectedEdge[4, 345] -> 
             RGBColor[
              0.861442968484558, 0.6185862006964551, 0.46864591996772276`], 
             UndirectedEdge[59, 256] -> 
             RGBColor[
              0.734620436712404, 0.7885652526347919, 0.8605541812913144], 
             UndirectedEdge[232, 480] -> 
             RGBColor[
              0.8995070156142874, 0.6174337948758607, 0.26137558125106086`], 
             UndirectedEdge[3, 437] -> 
             RGBColor[
              0.7405903641473407, 0.7014701615441583, 0.6097403632302338], 
             UndirectedEdge[199, 448] -> 
             RGBColor[
              0.9941991331797039, 0.9900553809750714, 0.613952920087955], 
             UndirectedEdge[151, 226] -> 
             RGBColor[
              0.9412983509191345, 0.9555406129381732, 0.9773036736873019], 
             UndirectedEdge[241, 442] -> 
             RGBColor[
              0.6876798398098808, 0.2712451989562277, 0.4256514479636119], 
             UndirectedEdge[303, 400] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[42, 378] -> 
             RGBColor[
              0.842954368302361, 0.8777931360914797, 0.9653068275420849], 
             UndirectedEdge[15, 499] -> 
             RGBColor[
              0.8143807251684675, 0.8554841091918248, 0.9631128965053739], 
             UndirectedEdge[341, 374] -> 
             RGBColor[
              0.9712848266939924, 0.9758102399315973, 0.8151057995481195], 
             UndirectedEdge[312, 334] -> 
             RGBColor[
              0.9470296800020028, 0.9582378226796392, 0.9031909489998853], 
             UndirectedEdge[7, 482] -> 
             RGBColor[
              0.9283784852565414, 0.801624879050709, 0.5972358587247895], 
             UndirectedEdge[219, 403] -> 
             RGBColor[
              0.6834116802482115, 0.7511602045598444, 0.9700680172672388], 
             UndirectedEdge[50, 449] -> 
             RGBColor[
              0.8653534658967583, 0.8938421106396321, 0.8993139998751281], 
             UndirectedEdge[318, 430] -> 
             RGBColor[
              0.803901912173657, 0.8475404361455685, 0.9743415143196092], 
             UndirectedEdge[242, 449] -> 
             RGBColor[
              0.7687465830009516, 0.8169266182199395, 0.8906733983899293], 
             UndirectedEdge[356, 365] -> 
             RGBColor[
              0.8888013427280504, 0.54624051615301, 0.4307170337407532], 
             UndirectedEdge[154, 219] -> 
             RGBColor[
              0.6747116644564157, 0.7440971398088195, 0.9693831201549007], 
             UndirectedEdge[69, 275] -> 
             RGBColor[
              0.9337072028354412, 0.7685356185542396, 0.5399480151250937], 
             UndirectedEdge[173, 310] -> 
             RGBColor[
              0.6693295856410726, 0.5742840249456016, 0.5890434153849315], 
             UndirectedEdge[351, 460] -> 
             RGBColor[
              0.8624995087444514, 0.596497818812963, 0.4644628016674477], 
             UndirectedEdge[97, 207] -> 
             RGBColor[
              0.6445305158206289, 0.7181088846119745, 0.9677738884491474], 
             UndirectedEdge[122, 212] -> 
             RGBColor[
              0.740694441364853, 0.7973553941712581, 0.9747891577983018], 
             UndirectedEdge[45, 224] -> 
             RGBColor[
              0.705033895592488, 0.7191908159782441, 0.6225228890398691], 
             UndirectedEdge[144, 215] -> 
             RGBColor[
              0.44706834393772077`, 0.5593147873121472, 0.9503529655455427], 
             UndirectedEdge[22, 214] -> 
             RGBColor[
              0.3547332643917914, 0.46757445792837016`, 0.9448430808088121], 
             UndirectedEdge[142, 150] -> 
             RGBColor[
              0.9424261433396257, 0.8441164271400734, 0.5972586019875008], 
             UndirectedEdge[149, 419] -> 
             RGBColor[
              0.9626686089386223, 0.9703122140951341, 0.8875014197361196], 
             UndirectedEdge[11, 418] -> 
             RGBColor[
              0.7106022107491934, 0.7738471149048816, 0.9717898454784164], 
             UndirectedEdge[189, 346] -> 
             RGBColor[
              0.6317828233364904, 0.7107337018593164, 0.964986162471122], 
             UndirectedEdge[185, 224] -> 
             RGBColor[
              0.6988230540821893, 0.7623985844588059, 0.9626700664030546], 
             UndirectedEdge[17, 386] -> 
             RGBColor[
              0.9926555306179385, 0.9862207974041353, 0.4826619648975158], 
             UndirectedEdge[194, 476] -> 
             RGBColor[
              0.9857635120317221, 0.9881534376134187, 0.8754145122014783], 
             UndirectedEdge[258, 471] -> 
             RGBColor[
              0.6267937697730122, 0.7074460772592279, 0.9640719342831503], 
             UndirectedEdge[203, 397] -> 
             RGBColor[
              0.9827011368900584, 0.9533090141432629, 0.38729761274440844`], 
             UndirectedEdge[126, 173] -> 
             RGBColor[
              0.719836708797027, 0.7772738754909935, 0.891981165063228], 
             UndirectedEdge[30, 366] -> 
             RGBColor[
              0.7064111053053508, 0.7693943015861278, 0.97237429216034], 
             UndirectedEdge[95, 368] -> 
             RGBColor[
              0.8492642082512519, 0.8730458897425898, 0.6906496237524941], 
             UndirectedEdge[15, 242] -> 
             RGBColor[
              0.7523227329362048, 0.8055584727397871, 0.9579158055637778], 
             UndirectedEdge[150, 392] -> 
             RGBColor[
              0.8789322280695973, 0.7942848153013837, 0.618825025158205], 
             UndirectedEdge[179, 296] -> 
             RGBColor[
              0.6964879928670558, 0.759316677828338, 0.9470600400606889], 
             UndirectedEdge[3, 123] -> 
             RGBColor[
              0.8514217095878984, 0.7894309538446789, 0.6198445060093464], 
             UndirectedEdge[37, 257] -> 
             RGBColor[
              0.8719269237254501, 0.40543542688975187`, 0.2365598854064414], 
             UndirectedEdge[17, 178] -> 
             RGBColor[
              0.8898585449959275, 0.5280473151440207, 0.2640593929707274], 
             UndirectedEdge[68, 367] -> 
             RGBColor[
              0.6566847068866923, 0.2944034312897926, 0.4302301860903166], 
             UndirectedEdge[1, 363] -> 
             RGBColor[
              0.7846572425876195, 0.8294600868808824, 0.8758932379808474], 
             UndirectedEdge[227, 329] -> 
             RGBColor[
              0.8389264723489128, 0.2753225086760635, 0.18393474940554064`], 
             UndirectedEdge[121, 420] -> 
             RGBColor[
              0.7060450110859033, 0.7688624765796106, 0.9726155074033995], 
             UndirectedEdge[82, 149] -> 
             RGBColor[
              0.689224206989437, 0.754819766298203, 0.9715426927083355], 
             UndirectedEdge[129, 355] -> 
             RGBColor[
              0.5813699618712211, 0.6691297504152336, 0.9612549080441889], 
             UndirectedEdge[87, 388] -> 
             RGBColor[
              0.6302398477337234, 0.6960315938843967, 0.8810787242510506], 
             UndirectedEdge[91, 228] -> 
             RGBColor[
              0.7232005299524522, 0.3005335226460366, 0.4283231466370737], 
             UndirectedEdge[12, 161] -> 
             RGBColor[
              0.8920705114960007, 0.8224263952588458, 0.6240339416772016], 
             UndirectedEdge[64, 115] -> 
             RGBColor[
              0.7849190936379464, 0.832358785004219, 0.969523883392633], 
             UndirectedEdge[56, 342] -> 
             RGBColor[
              0.7697515485680511, 0.8200550271605905, 0.9776852986902113], 
             UndirectedEdge[378, 416] -> 
             RGBColor[
              0.7625669598873799, 0.8138510982593129, 0.9580758891940435], 
             UndirectedEdge[119, 363] -> 
             RGBColor[
              0.5222992836731025, 0.6230651136572405, 0.9555364593375146], 
             UndirectedEdge[391, 455] -> 
             RGBColor[
              0.9067196507448801, 0.9249611424131103, 0.8445815290244212], 
             UndirectedEdge[249, 282] -> 
             RGBColor[
              0.9533340102112242, 0.9644763910057603, 0.9555298551292236], 
             UndirectedEdge[226, 429] -> 
             RGBColor[
              0.942188127436886, 0.9562042068082369, 0.9757975141336312], 
             UndirectedEdge[181, 189] -> 
             RGBColor[
              0.7854390051884653, 0.3502514663380445, 0.4337766259546231], 
             UndirectedEdge[160, 167] -> 
             RGBColor[
              0.9555531850487585, 0.9637552316079133, 0.8386027209245817], 
             UndirectedEdge[16, 277] -> 
             RGBColor[
              0.9495515816052744, 0.9594406773889045, 0.8683435526366887], 
             UndirectedEdge[295, 341] -> 
             RGBColor[
              0.8204115130101775, 0.860349592192247, 0.9715188441130111], 
             UndirectedEdge[69, 129] -> 
             RGBColor[
              0.6564862058811565, 0.5487232036748527, 0.585197162743536], 
             UndirectedEdge[352, 368] -> 
             RGBColor[
              0.8526570242239189, 0.8828154532531471, 0.8462771113715173], 
             UndirectedEdge[194, 297] -> 
             RGBColor[0.96578853234805, 0.90040744402486, 0.5548807205511214],
              UndirectedEdge[188, 228] -> 
             RGBColor[
              0.8691456157549405, 0.39605342202305593`, 0.2257550291469503], 
             UndirectedEdge[273, 430] -> 
             RGBColor[
              0.8591963707465602, 0.40840920447803664`, 0.43662968854400686`],
              UndirectedEdge[200, 468] -> 
             RGBColor[
              0.9291820302200362, 0.943259024520944, 0.8690266977844132], 
             UndirectedEdge[93, 172] -> 
             RGBColor[
              0.9347738806621748, 0.7580566828813078, 0.43085551817799184`], 
             UndirectedEdge[61, 341] -> 
             RGBColor[
              0.7510673819244169, 0.8048269154035048, 0.965530623357549], 
             UndirectedEdge[121, 442] -> 
             RGBColor[
              0.7120886643452055, 0.29151240956223273`, 0.4274483798723664], 
             UndirectedEdge[287, 336] -> 
             RGBColor[
              0.8444384077770778, 0.3967662800712274, 0.43954460996386757`], 
             UndirectedEdge[403, 497] -> 
             RGBColor[
              0.7703754815667255, 0.8176002096376707, 0.8636783337006957], 
             UndirectedEdge[17, 407] -> 
             RGBColor[
              0.8849174605740479, 0.9051702208965566, 0.7004412331186933], 
             UndirectedEdge[135, 470] -> 
             RGBColor[
              0.9902519662585634, 0.9894991923717792, 0.757586355470847], 
             UndirectedEdge[322, 471] -> 
             RGBColor[
              0.42169684846329547`, 0.5318383878468648, 0.9492135511816506], 
             UndirectedEdge[24, 52] -> 
             RGBColor[
              0.9698139950029055, 0.9054517276414893, 0.5047064276461906], 
             UndirectedEdge[163, 440] -> 
             RGBColor[
              0.8052541829393276, 0.8483307801086186, 0.9610083704003828], 
             UndirectedEdge[274, 432] -> 
             RGBColor[
              0.9897291622239159, 0.9760852637922245, 0.49375973680166485`], 
             UndirectedEdge[89, 261] -> 
             RGBColor[
              0.7695942764769039, 0.8188971226208402, 0.9409520014058218], 
             UndirectedEdge[255, 312] -> 
             RGBColor[
              0.8462380790097387, 0.398201289061377, 0.4397162642126242], 
             UndirectedEdge[370, 422] -> 
             RGBColor[
              0.8207239382553133, 0.8602108570357743, 0.9521725012166988], 
             UndirectedEdge[43, 90] -> 
             RGBColor[
              0.9676139046975074, 0.9753670836675408, 0.9397053910873816], 
             UndirectedEdge[373, 449] -> 
             RGBColor[
              0.9307244037090092, 0.7506925004301641, 0.5193279925279959], 
             UndirectedEdge[49, 457] -> 
             RGBColor[
              0.8502096771946863, 0.8507359527677469, 0.6570860414933016], 
             UndirectedEdge[234, 449] -> 
             RGBColor[
              0.8747104262511745, 0.41939240500041053`, 0.38407436392816174`],
              UndirectedEdge[245, 299] -> 
             RGBColor[
              0.8406086232084051, 0.28296076285270305`, 0.18533837731599165`],
              UndirectedEdge[398, 464] -> 
             RGBColor[
              0.7634432364808067, 0.8138618528379264, 0.9393525788855812], 
             UndirectedEdge[245, 262] -> 
             RGBColor[
              0.8406086232084051, 0.28296076285270305`, 0.18533837731599165`],
              UndirectedEdge[288, 321] -> 
             RGBColor[
              0.7663780253900034, 0.763354737911055, 0.6211984819831616], 
             UndirectedEdge[433, 465] -> 
             RGBColor[
              0.90340817427837, 0.744040994673687, 0.6067982231685003], 
             UndirectedEdge[330, 367] -> 
             RGBColor[
              0.8386565139108803, 0.4426648684565456, 0.44531471208044326`], 
             UndirectedEdge[106, 156] -> 
             RGBColor[
              0.757462525883905, 0.8061108621534677, 0.8004487745575368], 
             UndirectedEdge[85, 239] -> 
             RGBColor[
              0.815178436811991, 0.37348413635039446`, 0.4367407745680666], 
             UndirectedEdge[336, 388] -> 
             RGBColor[
              0.584820596291961, 0.662087765189575, 0.9644700995670246], 
             UndirectedEdge[69, 355] -> 
             RGBColor[
              0.8048880780524335, 0.6684160235757634, 0.5976427490773253], 
             UndirectedEdge[102, 383] -> 
             RGBColor[
              0.7759731937095296, 0.6356509594041961, 0.5927719200554715], 
             UndirectedEdge[296, 327] -> 
             RGBColor[
              0.9761837301173413, 0.9810891205588737, 0.8952251766076558], 
             UndirectedEdge[61, 288] -> 
             RGBColor[
              0.5660840515574544, 0.6586115607070723, 0.9589833566542604], 
             UndirectedEdge[141, 472] -> 
             RGBColor[
              0.841069230331758, 0.2850522722223213, 0.18572271919023098`], 
             UndirectedEdge[43, 485] -> 
             RGBColor[
              0.7574423321256041, 0.8094225263763003, 0.9504798203010789], 
             UndirectedEdge[9, 358] -> 
             RGBColor[
              0.6712581463355166, 0.5973981500803227, 0.5936638529549505], 
             UndirectedEdge[70, 359] -> 
             RGBColor[
              0.9001166902883846, 0.923191379606381, 0.9902917030714713], 
             UndirectedEdge[466, 470] -> 
             RGBColor[
              0.8853035491141017, 0.5090975953829923, 0.4141803156355076], 
             UndirectedEdge[41, 356] -> 
             RGBColor[
              0.80139047992947, 0.8445653844169587, 0.939557203253489], 
             UndirectedEdge[79, 436] -> 
             RGBColor[
              0.8928114620822053, 0.5461454695970671, 0.3354121023633997], 
             UndirectedEdge[33, 175] -> 
             RGBColor[
              0.8118657457091876, 0.8497745682877814, 0.7634829709671342], 
             UndirectedEdge[176, 448] -> 
             RGBColor[
              0.9914832659046545, 0.9889323000622332, 0.658961869274728], 
             UndirectedEdge[118, 481] -> 
             RGBColor[
              0.7995190424084627, 0.8439739595504041, 0.9666890448150159], 
             UndirectedEdge[326, 346] -> 
             RGBColor[
              0.6875233062000194, 0.7543850872673088, 0.9705135919681933], 
             UndirectedEdge[63, 435] -> 
             RGBColor[
              0.783455723582922, 0.8307613491560486, 0.9584278474751171], 
             UndirectedEdge[194, 350] -> 
             RGBColor[
              0.9885833833508264, 0.9895469498689712, 0.8388664133409915], 
             UndirectedEdge[275, 486] -> 
             RGBColor[
              0.854330174419395, 0.8856136081334058, 0.9155810852554396], 
             UndirectedEdge[407, 478] -> 
             RGBColor[
              0.8279752566567529, 0.682389765752588, 0.5991499746561585], 
             UndirectedEdge[62, 356] -> 
             RGBColor[
              0.9429050012317259, 0.9561237599349868, 0.9532584712737271], 
             UndirectedEdge[150, 426] -> 
             RGBColor[
              0.8725892055014137, 0.7892270612822752, 0.6182200220031686], 
             UndirectedEdge[372, 444] -> 
             RGBColor[
              0.8596819590739189, 0.4087713554575028, 0.43580771416750785`], 
             UndirectedEdge[106, 329] -> 
             RGBColor[
              0.7183458567185175, 0.2965922802141915, 0.4279409689768444], 
             UndirectedEdge[128, 294] -> 
             RGBColor[
              0.9369884180279724, 0.769026618212443, 0.4819179145927727], 
             UndirectedEdge[379, 440] -> 
             RGBColor[
              0.7844407432659177, 0.8323092440713272, 0.9789426825377453], 
             UndirectedEdge[227, 267] -> 
             RGBColor[
              0.8389264723489128, 0.2753225086760635, 0.18393474940554064`], 
             UndirectedEdge[151, 345] -> 
             RGBColor[
              0.9032536849639743, 0.9252048290004753, 0.9736749394856244], 
             UndirectedEdge[275, 418] -> 
             RGBColor[
              0.8206223729033837, 0.8592808174003179, 0.9122214066176383], 
             UndirectedEdge[10, 232] -> 
             RGBColor[
              0.8970422834335074, 0.6294175800790874, 0.4469418362266471], 
             UndirectedEdge[5, 431] -> 
             RGBColor[
              0.7726297442847794, 0.7151754223033733, 0.6094293672815586], 
             UndirectedEdge[42, 416] -> 
             RGBColor[
              0.6481459804354983, 0.7239130496874404, 0.9663461193871247], 
             UndirectedEdge[37, 97] -> 
             RGBColor[
              0.6975431394640869, 0.7405055372517039, 0.6644203741953834], 
             UndirectedEdge[441, 450] -> 
             RGBColor[
              0.9028639157375752, 0.9223299344003751, 0.8660688019239994], 
             UndirectedEdge[5, 259] -> 
             RGBColor[
              0.7942746481119751, 0.8393643690673298, 0.9544444529851586], 
             UndirectedEdge[279, 318] -> 
             RGBColor[
              0.5402778505011461, 0.6362950134115049, 0.957469583880607], 
             UndirectedEdge[275, 355] -> 
             RGBColor[
              0.8585909588255058, 0.8889421652946206, 0.9160057604257467], 
             UndirectedEdge[344, 387] -> 
             RGBColor[
              0.6218158893087481, 0.7022361268484474, 0.9644790921108175], 
             UndirectedEdge[239, 489] -> 
             RGBColor[
              0.8442241114577337, 0.396595406003101, 0.439524170189624], 
             UndirectedEdge[21, 336] -> 
             RGBColor[
              0.803157067476149, 0.8467877204512808, 0.9808460610326116], 
             UndirectedEdge[32, 312] -> 
             RGBColor[
              0.949474609880417, 0.9588960103025256, 0.8370233935682356], 
             UndirectedEdge[77, 436] -> 
             RGBColor[
              0.9938193387473282, 0.9909404317009354, 0.6959971643653513], 
             UndirectedEdge[66, 294] -> 
             RGBColor[
              0.8623362123658999, 0.8905844052123197, 0.858176057280837], 
             UndirectedEdge[197, 201] -> 
             RGBColor[
              0.812060066676056, 0.7393729974507494, 0.6116456198757722], 
             UndirectedEdge[228, 256] -> 
             RGBColor[
              0.7036968790624343, 0.2846995802240602, 0.42678774779478423`], 
             UndirectedEdge[292, 481] -> 
             RGBColor[
              0.6963902211344216, 0.7627446006027001, 0.9703733271722099], 
             UndirectedEdge[444, 486] -> 
             RGBColor[
              0.8328290712260165, 0.8701127611831116, 0.9759191432699439], 
             UndirectedEdge[154, 244] -> 
             RGBColor[
              0.7059111612707645, 0.5916723399345474, 0.5893956822199717], 
             UndirectedEdge[288, 386] -> 
             RGBColor[
              0.7857767149805224, 0.8284724309985182, 0.7514393218525431], 
             UndirectedEdge[273, 285] -> 
             RGBColor[
              0.8759572457915535, 0.4187299911185057, 0.2777827512144868], 
             UndirectedEdge[190, 487] -> 
             RGBColor[
              0.7059391955900425, 0.6892060680921073, 0.6106657507779458], 
             UndirectedEdge[83, 343] -> 
             RGBColor[
              0.6768371222284636, 0.74746957112831, 0.9684244570073621], 
             UndirectedEdge[1, 315] -> 
             RGBColor[
              0.9933196833935783, 0.9915055316540082, 0.7603736644809946], 
             UndirectedEdge[4, 429] -> 
             RGBColor[
              0.896312342555947, 0.6460333948988599, 0.45960484223876874`], 
             UndirectedEdge[189, 451] -> 
             RGBColor[
              0.7930824130889255, 0.8386409674135179, 0.9799152501436602], 
             UndirectedEdge[10, 102] -> 
             RGBColor[
              0.8247792948045194, 0.8633321154835418, 0.9502068369210129], 
             UndirectedEdge[357, 368] -> 
             RGBColor[
              0.8311177231452921, 0.8686389711799511, 0.9688201401399326], 
             UndirectedEdge[128, 138] -> 
             RGBColor[
              0.9077422668036018, 0.7489094937883873, 0.6073119959639073], 
             UndirectedEdge[336, 436] -> 
             RGBColor[
              0.9465323343526169, 0.9562242391610078, 0.8103420397013841], 
             UndirectedEdge[196, 454] -> 
             RGBColor[
              0.9491580935860555, 0.9576598795651452, 0.75724730253833], 
             UndirectedEdge[25, 164] -> 
             RGBColor[
              0.6480428248629817, 0.7194255304707482, 0.9687920503808185], 
             UndirectedEdge[125, 282] -> 
             RGBColor[
              0.9489364689144824, 0.8478603837159555, 0.585376011977204], 
             UndirectedEdge[9, 286] -> 
             RGBColor[
              0.6678069797765647, 0.7376675375105597, 0.9695342930303161], 
             UndirectedEdge[421, 477] -> 
             RGBColor[
              0.6121979778143127, 0.6946620840361256, 0.9635618035323157], 
             UndirectedEdge[105, 484] -> 
             RGBColor[
              0.9621646100988177, 0.874603920606893, 0.4960043101485674], 
             UndirectedEdge[299, 475] -> 
             RGBColor[
              0.8503768441414795, 0.40150142803364036`, 0.4401110233256089], 
             UndirectedEdge[247, 252] -> 
             RGBColor[
              0.711327337592605, 0.7677990015309759, 0.7821939985875219], 
             UndirectedEdge[261, 478] -> 
             RGBColor[
              0.9275881698184317, 0.7604062980791471, 0.571517684712292], 
             UndirectedEdge[104, 303] -> 
             RGBColor[
              0.8744581482887588, 0.4139738417015826, 0.2463932148532456], 
             UndirectedEdge[32, 66] -> 
             RGBColor[
              0.862576653509679, 0.8903309800906583, 0.8285425852160554], 
             UndirectedEdge[213, 454] -> 
             RGBColor[
              0.9449500419615817, 0.9575378224920628, 0.9446029729355422], 
             UndirectedEdge[129, 331] -> 
             RGBColor[
              0.696312969745549, 0.7125077632259358, 0.623294057717598], 
             UndirectedEdge[245, 475] -> 
             RGBColor[
              0.901840201024827, 0.7584392863295151, 0.6097381009624009], 
             UndirectedEdge[90, 148] -> 
             RGBColor[
              0.9238856524210415, 0.9412677426072689, 0.9621747798544067], 
             UndirectedEdge[195, 496] -> 
             RGBColor[
              0.7713862183326455, 0.8204072955150472, 0.9425788065891763], 
             UndirectedEdge[241, 371] -> 
             RGBColor[
              0.5093897411621986, 0.6119080246138047, 0.9547071031185488], 
             UndirectedEdge[13, 243] -> 
             RGBColor[
              0.8722329029773166, 0.41813182887037237`, 0.4145622399494907], 
             UndirectedEdge[246, 384] -> 
             RGBColor[
              0.9327863028542196, 0.8335505089457168, 0.6109566444118868], 
             UndirectedEdge[22, 268] -> 
             RGBColor[
              0.7625088079778557, 0.810869738621399, 0.8486805388175827], 
             UndirectedEdge[69, 306] -> 
             RGBColor[
              0.9345935008349446, 0.768902125553854, 0.5252597636076248], 
             UndirectedEdge[66, 128] -> 
             RGBColor[
              0.8049325299498129, 0.6676620197605196, 0.5974930332454481], 
             UndirectedEdge[220, 413] -> 
             RGBColor[
              0.5575041553394479, 0.6516460144373747, 0.9583079157947835], 
             UndirectedEdge[319, 492] -> 
             RGBColor[
              0.7961973344189379, 0.8412545797353701, 0.9801778936397034], 
             UndirectedEdge[61, 186] -> 
             RGBColor[
              0.6662069911104349, 0.7378147173572871, 0.9682882990551582], 
             UndirectedEdge[94, 401] -> 
             RGBColor[
              0.80501200604209, 0.8482449904670908, 0.9810287738076008], 
             UndirectedEdge[429, 488] -> 
             RGBColor[
              0.7008017113544157, 0.7635163067485888, 0.9540965407758161], 
             UndirectedEdge[11, 431] -> 
             RGBColor[
              0.8441867014515525, 0.771353578341468, 0.6163718927182305], 
             UndirectedEdge[349, 487] -> 
             RGBColor[
              0.7114801583495032, 0.7111741390169866, 0.6151241394773201], 
             UndirectedEdge[156, 198] -> 
             RGBColor[
              0.9948904201472166, 0.9914794502896925, 0.6852319495752558], 
             UndirectedEdge[12, 188] -> 
             RGBColor[
              0.9137636320753655, 0.9034537604909598, 0.667417520470068], 
             UndirectedEdge[70, 111] -> 
             RGBColor[
              0.9006255408559153, 0.9235971232365492, 0.9903402376928587], 
             UndirectedEdge[212, 286] -> 
             RGBColor[
              0.8216546634117187, 0.8611893110544666, 0.982702697632788], 
             UndirectedEdge[242, 282] -> 
             RGBColor[
              0.7641528610411172, 0.8143813629103738, 0.9378904844737266], 
             UndirectedEdge[70, 175] -> 
             RGBColor[
              0.7828560349042943, 0.8310369049037863, 0.9788295216323413], 
             UndirectedEdge[188, 298] -> 
             RGBColor[
              0.9448754042623653, 0.9282614431263148, 0.670384989075071], 
             UndirectedEdge[286, 367] -> 
             RGBColor[
              0.8497546458459947, 0.4515142176108397, 0.4463732618118338], 
             UndirectedEdge[9, 492] -> 
             RGBColor[
              0.664882656851965, 0.7353357617891152, 0.9692553684991938], 
             UndirectedEdge[37, 343] -> 
             RGBColor[
              0.8303872175280533, 0.8488524844874292, 0.6749733235110054], 
             UndirectedEdge[376, 391] -> 
             RGBColor[
              0.8330318503456038, 0.8673956726931701, 0.8372370177322676], 
             UndirectedEdge[230, 490] -> 
             RGBColor[
              0.8618439919334763, 0.760208507108272, 0.6126092366784243], 
             UndirectedEdge[346, 355] -> 
             RGBColor[
              0.6358292325750414, 0.7138947875103218, 0.9653894707281766], 
             UndirectedEdge[30, 465] -> 
             RGBColor[
              0.7313859521296366, 0.7893085665196558, 0.9747564153457493], 
             UndirectedEdge[119, 124] -> 
             RGBColor[
              0.40089486438930094`, 0.5212932790428118, 0.9468660625367008], 
             UndirectedEdge[301, 436] -> 
             RGBColor[
              0.9935208115075, 0.9885499958980137, 0.5361585013868582], 
             UndirectedEdge[39, 108] -> 
             RGBColor[
              0.9277573836330724, 0.7501372877898222, 0.5643088210894661], 
             UndirectedEdge[98, 382] -> 
             RGBColor[
              0.8992632868750827, 0.771474563851477, 0.6124714802136795], 
             UndirectedEdge[81, 208] -> 
             RGBColor[
              0.9937395908130285, 0.9890179427105583, 0.5599712786442698], 
             UndirectedEdge[154, 203] -> 
             RGBColor[
              0.7538675123905223, 0.7821687949137224, 0.6609323948793515], 
             UndirectedEdge[145, 367] -> 
             RGBColor[
              0.8534563881153086, 0.4544658864152735, 0.4467263372940653], 
             UndirectedEdge[44, 132] -> 
             RGBColor[
              0.8732869088591466, 0.8712118516585611, 0.6629606751890653], 
             UndirectedEdge[319, 357] -> 
             RGBColor[0.82887568257572, 0.866887472046862, 0.968596674489018],
              UndirectedEdge[364, 378] -> 
             RGBColor[
              0.9524267066683302, 0.9640404962441348, 0.9654133558951488], 
             UndirectedEdge[213, 251] -> 
             RGBColor[
              0.9396592697892974, 0.8005561467673246, 0.5659754523233476], 
             UndirectedEdge[73, 136] -> 
             RGBColor[
              0.8764541544909698, 0.419792828581381, 0.331868196580927], 
             UndirectedEdge[441, 461] -> 
             RGBColor[
              0.7735639875157123, 0.8199540167628998, 0.8541152195659385], 
             UndirectedEdge[90, 480] -> 
             RGBColor[
              0.97466446543186, 0.9598924126769516, 0.6556794713969216], 
             UndirectedEdge[118, 446] -> 
             RGBColor[
              0.9612704090146145, 0.9706361149737601, 0.9504432746298714], 
             UndirectedEdge[210, 480] -> 
             RGBColor[
              0.8546844340934902, 0.8658303585102969, 0.6744696270582199], 
             UndirectedEdge[95, 492] -> 
             RGBColor[
              0.9376068711409193, 0.9425997530937535, 0.699311520946009], 
             UndirectedEdge[261, 328] -> 
             RGBColor[
              0.8779430251410391, 0.4729601457099747, 0.4242069540773461], 
             UndirectedEdge[152, 496] -> 
             RGBColor[
              0.7339182889266278, 0.30923468221081185`, 0.4291668878839656], 
             UndirectedEdge[86, 177] -> 
             RGBColor[
              0.8788897418181085, 0.9033086516137661, 0.8488917435026224], 
             UndirectedEdge[45, 217] -> 
             RGBColor[
              0.8677524277258966, 0.8492976495581036, 0.636721440967938], 
             UndirectedEdge[306, 331] -> 
             RGBColor[
              0.9744202646993371, 0.932686685104937, 0.563356658581687], 
             UndirectedEdge[103, 129] -> 
             RGBColor[
              0.6987932266552647, 0.7208742521744236, 0.6329293874546276], 
             UndirectedEdge[50, 126] -> 
             RGBColor[
              0.8650448282868574, 0.8937144810563133, 0.9044289237997178], 
             UndirectedEdge[172, 308] -> 
             RGBColor[
              0.8447178809531356, 0.6901875903571248, 0.5997864992314811], 
             UndirectedEdge[112, 266] -> 
             RGBColor[
              0.6615182886830051, 0.7337019208327181, 0.9681286039311416], 
             UndirectedEdge[129, 275] -> 
             RGBColor[
              0.7101890866542289, 0.7692493453937099, 0.9035601740919573], 
             UndirectedEdge[297, 325] -> 
             RGBColor[
              0.9254420828087091, 0.8703527247091661, 0.631990346252355], 
             UndirectedEdge[202, 396] -> 
             RGBColor[
              0.9716490190313143, 0.9750326897744817, 0.7312426246317967], 
             UndirectedEdge[167, 236] -> 
             RGBColor[
              0.9393719632309356, 0.9538018513713807, 0.9700917699083931], 
             UndirectedEdge[184, 301] -> 
             RGBColor[
              0.97931316265111, 0.9804195088228512, 0.6921576053867768], 
             UndirectedEdge[78, 258] -> 
             RGBColor[
              0.7769389486350462, 0.6503118155150325, 0.5955859915181805], 
             UndirectedEdge[172, 470] -> 
             RGBColor[
              0.9305553824666277, 0.7569746677269147, 0.5489195096020675], 
             UndirectedEdge[72, 159] -> 
             RGBColor[
              0.9764111708411531, 0.9809313405552027, 0.8801783174048544], 
             UndirectedEdge[304, 337] -> 
             RGBColor[
              0.9870939056130841, 0.9668383453877665, 0.5139282054066712], 
             UndirectedEdge[88, 271] -> 
             RGBColor[
              0.8670612744636644, 0.3890224494209729, 0.21765775682516778`], 
             UndirectedEdge[392, 413] -> 
             RGBColor[
              0.727530474186995, 0.7868180588884135, 0.9737167956783392], 
             UndirectedEdge[187, 216] -> 
             RGBColor[
              0.8948696650880742, 0.5789915278484243, 0.4145782258789176], 
             UndirectedEdge[33, 432] -> 
             RGBColor[
              0.993889190849224, 0.9893379220610965, 0.5762543193597371], 
             UndirectedEdge[36, 75] -> 
             RGBColor[
              0.9593256419214261, 0.8632290912020328, 0.48514691429511725`], 
             UndirectedEdge[243, 335] -> 
             RGBColor[
              0.8163087406000011, 0.8565403243061482, 0.9405278985878069], 
             UndirectedEdge[323, 499] -> 
             RGBColor[
              0.6497755518852655, 0.7261002536095096, 0.9658835165992894], 
             UndirectedEdge[168, 480] -> 
             RGBColor[
              0.9819743278693742, 0.9508573166536212, 0.3844740969454167], 
             UndirectedEdge[301, 388] -> 
             RGBColor[
              0.6318090734468441, 0.6944135219265809, 0.6902865612524987], 
             UndirectedEdge[111, 371] -> 
             RGBColor[
              0.7279407373211355, 0.7869637377160826, 0.9739647770062441], 
             UndirectedEdge[103, 231] -> 
             RGBColor[
              0.8664187878701951, 0.3868551912781747, 0.21516181773295184`], 
             UndirectedEdge[99, 131] -> 
             RGBColor[
              0.9410664405345628, 0.9552343984930172, 0.9730761662221084], 
             UndirectedEdge[193, 428] -> 
             RGBColor[
              0.9130443890979516, 0.9290148302679706, 0.7660464058693617], 
             UndirectedEdge[189, 370] -> 
             RGBColor[
              0.6967841938085917, 0.763052375050065, 0.9704125946864872], 
             UndirectedEdge[45, 187] -> 
             RGBColor[
              0.8853318857507246, 0.54035994569213, 0.22775522531615539`], 
             UndirectedEdge[346, 443] -> 
             RGBColor[
              0.7639333404479328, 0.8137187046213685, 0.9195444173810206], 
             UndirectedEdge[19, 318] -> 
             RGBColor[
              0.6276153375011941, 0.7082208556079768, 0.96406291267673], 
             UndirectedEdge[5, 129] -> 
             RGBColor[
              0.5286119673332653, 0.6276374868601787, 0.9561860875160637], 
             UndirectedEdge[29, 46] -> 
             RGBColor[
              0.9403807979276293, 0.9109878201513772, 0.6498168804928294], 
             UndirectedEdge[227, 263] -> 
             RGBColor[
              0.9258499607527889, 0.7672654445068714, 0.579890969570457], 
             UndirectedEdge[272, 435] -> 
             RGBColor[
              0.9514350365139996, 0.8923229546937772, 0.6141971814791392], 
             UndirectedEdge[208, 483] -> 
             RGBColor[
              0.8058099471185773, 0.8448608328765114, 0.7632221754867576], 
             UndirectedEdge[244, 475] -> 
             RGBColor[
              0.8988574996505898, 0.7448955360167091, 0.6072492618230365], 
             UndirectedEdge[350, 412] -> 
             RGBColor[
              0.8177687481373839, 0.8568580026873758, 0.9031609970582176], 
             UndirectedEdge[217, 398] -> 
             RGBColor[0.87756677052121, 0.90445697425496, 0.9497421613391768],
              UndirectedEdge[370, 451] -> 
             RGBColor[
              0.7681875913321212, 0.8191929434494494, 0.9774339669662784], 
             UndirectedEdge[265, 424] -> 
             RGBColor[
              0.7273622665922737, 0.6372597002339966, 0.596793789849603], 
             UndirectedEdge[28, 419] -> 
             RGBColor[
              0.9889664823251935, 0.9897053711400665, 0.8325174719073658], 
             UndirectedEdge[67, 381] -> 
             RGBColor[
              0.7971047101183031, 0.8121825716909422, 0.6567755005376869], 
             UndirectedEdge[239, 435] -> 
             RGBColor[
              0.8644908576966551, 0.41235782417649064`, 0.42766750316084867`],
              UndirectedEdge[302, 370] -> 
             RGBColor[
              0.7799406324636776, 0.4225915541991565, 0.44275006219158486`], 
             UndirectedEdge[2, 66] -> 
             RGBColor[
              0.8298715850332825, 0.8679061333301641, 0.9834426829884081], 
             UndirectedEdge[36, 408] -> 
             RGBColor[
              0.9472004393916401, 0.8137246587035973, 0.47531661352301247`], 
             UndirectedEdge[76, 483] -> 
             RGBColor[
              0.6777010182159338, 0.7477689902566597, 0.9687672681778362], 
             UndirectedEdge[9, 367] -> 
             RGBColor[
              0.6998721765454534, 0.3318102468428714, 0.43298205346779284`], 
             UndirectedEdge[133, 469] -> 
             RGBColor[
              0.8815609994424168, 0.5312765804735797, 0.4393209164443248], 
             UndirectedEdge[46, 297] -> 
             RGBColor[
              0.9525213698883638, 0.8476346947467213, 0.29021451925497915`], 
             UndirectedEdge[159, 435] -> 
             RGBColor[
              0.9745130211201998, 0.9795157036012505, 0.8833913897656936], 
             UndirectedEdge[126, 340] -> 
             RGBColor[
              0.6972804167738131, 0.757736749052687, 0.8905438980812547], 
             UndirectedEdge[27, 290] -> 
             RGBColor[
              0.6791124413418269, 0.6771278367986768, 0.6113488793440298], 
             UndirectedEdge[326, 338] -> 
             RGBColor[
              0.9090335951408717, 0.9289149635636111, 0.9418694365019766], 
             UndirectedEdge[179, 438] -> 
             RGBColor[
              0.7005160867771913, 0.7623208236711188, 0.9402415277659785], 
             UndirectedEdge[138, 339] -> 
             RGBColor[
              0.9609884593653093, 0.9701126503427858, 0.9368953861252122], 
             UndirectedEdge[475, 482] -> 
             RGBColor[
              0.9369970104717739, 0.9520377721700872, 0.9743600719568459], 
             UndirectedEdge[94, 428] -> 
             RGBColor[
              0.9466602781788143, 0.9558192277420494, 0.7692527193791527], 
             UndirectedEdge[186, 295] -> 
             RGBColor[
              0.7355511221961953, 0.7933373941460293, 0.9742765198106204], 
             UndirectedEdge[348, 372] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[293, 343] -> 
             RGBColor[
              0.7327743358834078, 0.791168147574122, 0.9739997557015051], 
             UndirectedEdge[385, 446] -> 
             RGBColor[
              0.9540127643010221, 0.9652233754296655, 0.9627285740330829], 
             UndirectedEdge[7, 288] -> 
             RGBColor[
              0.7386128078933003, 0.6518428577948263, 0.5987838580503406], 
             UndirectedEdge[242, 323] -> 
             RGBColor[
              0.5877175596530027, 0.6761746171574718, 0.9606864256576932], 
             UndirectedEdge[464, 481] -> 
             RGBColor[
              0.5981650445448526, 0.6845693968582505, 0.9615683444107161], 
             UndirectedEdge[42, 108] -> 
             RGBColor[
              0.8004491643178575, 0.6505879568287943, 0.5943937868407017], 
             UndirectedEdge[101, 276] -> 
             RGBColor[
              0.5935964876413409, 0.6761397184545562, 0.9635492115441662], 
             UndirectedEdge[86, 426] -> 
             RGBColor[
              0.9110690351278782, 0.9285034271568122, 0.852084196259227], 
             UndirectedEdge[37, 324] -> 
             RGBColor[
              0.9553948778923256, 0.8534165244667236, 0.32174708625944504`], 
             UndirectedEdge[290, 297] -> 
             RGBColor[
              0.6776828785536173, 0.6714600967169849, 0.6101986195684848], 
             UndirectedEdge[315, 380] -> 
             RGBColor[
              0.7928656196034691, 0.8353669292310557, 0.8448901872232948], 
             UndirectedEdge[181, 390] -> 
             RGBColor[
              0.8725083260299267, 0.4073966333825042, 0.2388185235707204], 
             UndirectedEdge[283, 421] -> 
             RGBColor[
              0.5856840765400708, 0.6739492228475747, 0.9609191456397939], 
             UndirectedEdge[97, 355] -> 
             RGBColor[
              0.5718576708971608, 0.6608906820751483, 0.9606487932747104], 
             UndirectedEdge[192, 219] -> 
             RGBColor[
              0.8878139897084307, 0.8621719927917547, 0.6346352110499283], 
             UndirectedEdge[171, 192] -> 
             RGBColor[
              0.9754136890484884, 0.9277887251370877, 0.43874938618926834`], 
             UndirectedEdge[122, 216] -> 
             RGBColor[
              0.8591434678673209, 0.8893431593582897, 0.9146719260855852], 
             UndirectedEdge[18, 28] -> 
             RGBColor[
              0.952796075792812, 0.8538960813131017, 0.5688908206483334], 
             UndirectedEdge[178, 288] -> 
             RGBColor[
              0.7519393345709835, 0.422881737540276, 0.44324429760741224`], 
             UndirectedEdge[165, 185] -> 
             RGBColor[
              0.8271682737677979, 0.8656527251075937, 0.9734426077831948], 
             UndirectedEdge[264, 281] -> 
             RGBColor[
              0.7973105846007333, 0.8424381436803184, 0.9760587609351699], 
             UndirectedEdge[80, 192] -> 
             RGBColor[
              0.71763938438081, 0.7267197925760098, 0.6193902428512421], 
             UndirectedEdge[74, 402] -> 
             RGBColor[
              0.9491397793906167, 0.9615891112622655, 0.9709772664083856], 
             UndirectedEdge[3, 158] -> 
             RGBColor[
              0.9378948685617141, 0.857719999898471, 0.6181051399610547], 
             UndirectedEdge[426, 476] -> 
             RGBColor[
              0.9048719200443294, 0.9257691222782214, 0.9486569060209408], 
             UndirectedEdge[27, 177] -> 
             RGBColor[
              0.8541472098390972, 0.8184960932283085, 0.626080921389524], 
             UndirectedEdge[355, 443] -> 
             RGBColor[
              0.8578759419153894, 0.888646487427191, 0.9278554410308222], 
             UndirectedEdge[21, 256] -> 
             RGBColor[
              0.5920447744041837, 0.67868767068053, 0.9617107677789866], 
             UndirectedEdge[331, 404] -> 
             RGBColor[
              0.8647652832637179, 0.3812775319791829, 0.20873826457493216`], 
             UndirectedEdge[142, 285] -> 
             RGBColor[
              0.9799141734789227, 0.9812714341978694, 0.7231715227423234], 
             UndirectedEdge[232, 267] -> 
             RGBColor[
              0.8454143375661266, 0.34786341264104426`, 0.19103532800490702`],
              UndirectedEdge[133, 488] -> 
             RGBColor[
              0.7085640690130801, 0.3936806330234931, 0.4406580629178919], 
             UndirectedEdge[148, 393] -> 
             RGBColor[
              0.9265013752169766, 0.9163982113364901, 0.6727335593092565], 
             UndirectedEdge[84, 89] -> 
             RGBColor[
              0.6962866311418343, 0.7615172218822233, 0.9711831321197787], 
             UndirectedEdge[27, 350] -> 
             RGBColor[
              0.9670975606055396, 0.9060253399805032, 0.5580285494340604], 
             UndirectedEdge[8, 435] -> 
             RGBColor[
              0.6464554692185227, 0.7163006809259662, 0.9485372689818498], 
             UndirectedEdge[20, 220] -> 
             RGBColor[
              0.5919654247578218, 0.6789795677138557, 0.9614609054439117], 
             UndirectedEdge[35, 422] -> 
             RGBColor[
              0.7325048908764324, 0.789043027787677, 0.9449182884260792], 
             UndirectedEdge[65, 177] -> 
             RGBColor[
              0.8217356328278451, 0.6832782788896845, 0.5996543571761909], 
             UndirectedEdge[93, 160] -> 
             RGBColor[
              0.994702741300933, 0.9910780242147339, 0.6648042653768614], 
             UndirectedEdge[277, 373] -> 
             RGBColor[
              0.9330744376056035, 0.7516642998395222, 0.48038184916865784`], 
             UndirectedEdge[15, 126] -> 
             RGBColor[
              0.9727607910788756, 0.9784274399377603, 0.8961444228829234], 
             UndirectedEdge[95, 367] -> 
             RGBColor[
              0.8816883194047562, 0.46998624104596376`, 0.25301948843233635`],
              UndirectedEdge[304, 465] -> 
             RGBColor[
              0.9537930679579494, 0.9441277415682947, 0.6841161913813559], 
             UndirectedEdge[218, 305] -> 
             RGBColor[
              0.8933869984454629, 0.5497883839875378, 0.3702381841982855], 
             UndirectedEdge[137, 265] -> 
             RGBColor[
              0.7709919010349213, 0.8043403017119611, 0.6745680117723262], 
             UndirectedEdge[325, 392] -> 
             RGBColor[
              0.8738088989229964, 0.9022155133632375, 0.9878258669093298], 
             UndirectedEdge[263, 393] -> 
             RGBColor[
              0.9722609233849736, 0.9520124895467243, 0.6468257164446869], 
             UndirectedEdge[228, 335] -> 
             RGBColor[
              0.7617315907560175, 0.33173105400039304`, 0.4314136924423806], 
             UndirectedEdge[104, 408] -> 
             RGBColor[
              0.9439959634301249, 0.8045460114834562, 0.32419614403622543`], 
             UndirectedEdge[145, 375] -> 
             RGBColor[
              0.8461246368451061, 0.39811083335860453`, 0.4397054439976906], 
             UndirectedEdge[181, 451] -> 
             RGBColor[
              0.8330412702041516, 0.3876785119376341, 0.43845754080781707`], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.7433091301474714, 0.7971721663564812, 0.9261613926403076], 
             UndirectedEdge[387, 439] -> 
             RGBColor[
              0.588259205453971, 0.6760213903808525, 0.961134475469213], 
             UndirectedEdge[163, 231] -> 
             RGBColor[
              0.8642056141818695, 0.41214509003020694`, 0.4281503460279573], 
             UndirectedEdge[143, 288] -> 
             RGBColor[
              0.7864459570667808, 0.8302146288206207, 0.846870922278639], 
             UndirectedEdge[128, 312] -> 
             RGBColor[
              0.8918304863205508, 0.7362270499723869, 0.6059738415976283], 
             UndirectedEdge[270, 479] -> 
             RGBColor[
              0.7390945093017893, 0.7954017417446009, 0.9724988701628803], 
             UndirectedEdge[119, 120] -> 
             RGBColor[
              0.730039579471075, 0.7830850326726744, 0.7357835883746736], 
             UndirectedEdge[105, 462] -> 
             RGBColor[
              0.6916801849675023, 0.7514674517871391, 0.8380439370895065], 
             UndirectedEdge[14, 159] -> 
             RGBColor[
              0.9924836753423649, 0.9911598208404044, 0.7742284814090845], 
             UndirectedEdge[58, 417] -> 
             RGBColor[
              0.6516440235702441, 0.7178738576907495, 0.8753251374789286], 
             UndirectedEdge[66, 299] -> 
             RGBColor[
              0.7883061080959134, 0.35249126892013216`, 0.43406239197783747`],
              UndirectedEdge[11, 348] -> 
             RGBColor[
              0.8006692531000443, 0.36214945176074137`, 0.4352946347316905], 
             UndirectedEdge[4, 31] -> 
             RGBColor[
              0.6889630101721027, 0.4783742549575077, 0.4542453277780416], 
             UndirectedEdge[259, 400] -> 
             RGBColor[
              0.8663104837524546, 0.4137148983095418, 0.42458735088286315`], 
             UndirectedEdge[247, 451] -> 
             RGBColor[
              0.6464436650210487, 0.7201315663407927, 0.9677274831571434], 
             UndirectedEdge[17, 261] -> 
             RGBColor[
              0.9845303737357267, 0.9831867532231158, 0.6728089431748268], 
             UndirectedEdge[361, 386] -> 
             RGBColor[
              0.9565602187642566, 0.9636808084460271, 0.7675735193060917], 
             UndirectedEdge[212, 492] -> 
             RGBColor[
              0.8187303404871191, 0.8588575353330221, 0.9824237731016658], 
             UndirectedEdge[287, 388] -> 
             RGBColor[
              0.635200656417563, 0.22346156338848924`, 0.42239278974748207`], 
             UndirectedEdge[383, 480] -> 
             RGBColor[
              0.9270938347783225, 0.733132668429944, 0.2961532253362995], 
             UndirectedEdge[403, 440] -> 
             RGBColor[
              0.6002647052907133, 0.6862051557826319, 0.9617807038561337], 
             UndirectedEdge[13, 354] -> 
             RGBColor[
              0.861350298764537, 0.41001560046711016`, 0.4329836502439711], 
             UndirectedEdge[1, 42] -> 
             RGBColor[
              0.8599761832290406, 0.8892873142426017, 0.882725167979345], 
             UndirectedEdge[161, 188] -> 
             RGBColor[
              0.9511057266854568, 0.8388789008370536, 0.3054455086479846], 
             UndirectedEdge[194, 426] -> 
             RGBColor[
              0.9078123258941537, 0.9272124786598227, 0.9101112380530598], 
             UndirectedEdge[257, 324] -> 
             RGBColor[
              0.8547616615361002, 0.34234492275473055`, 0.19689550543318865`],
              UndirectedEdge[198, 479] -> 
             RGBColor[
              0.9671303914649858, 0.9731454713526289, 0.8565426715840043], 
             UndirectedEdge[372, 431] -> 
             RGBColor[
              0.8518805478676574, 0.33092226713357065`, 0.19457729374712981`],
              UndirectedEdge[107, 466] -> 
             RGBColor[
              0.8646864035873373, 0.49373290988653395`, 0.451591313639628], 
             UndirectedEdge[122, 330] -> 
             RGBColor[
              0.7950232637778394, 0.8401155530478626, 0.9801197411148053], 
             UndirectedEdge[4, 472] -> 
             RGBColor[
              0.8736863986914352, 0.5193212623964658, 0.2163131736494921], 
             UndirectedEdge[145, 458] -> 
             RGBColor[
              0.7872657367055642, 0.8344141795601394, 0.9792513114128718], 
             UndirectedEdge[3, 451] -> 
             RGBColor[
              0.8966478185241671, 0.8251216254449332, 0.6242567708034295], 
             UndirectedEdge[146, 239] -> 
             RGBColor[
              0.8532839865205557, 0.40381950445443804`, 0.44038830916096194`],
              UndirectedEdge[15, 282] -> 
             RGBColor[
              0.9684757067289421, 0.9760098142115134, 0.9382465850421309], 
             UndirectedEdge[82, 126] -> 
             RGBColor[
              0.7170159518268717, 0.7748306775788125, 0.8918014289233871], 
             UndirectedEdge[413, 474] -> 
             RGBColor[
              0.6273701224477973, 0.7083663539618832, 0.963808020653023], 
             UndirectedEdge[160, 235] -> 
             RGBColor[
              0.8533894392966156, 0.8831663375675537, 0.8286263975642811], 
             UndirectedEdge[161, 183] -> 
             RGBColor[
              0.613999178240884, 0.5945072345263709, 0.6011886593348776], 
             UndirectedEdge[366, 429] -> 
             RGBColor[
              0.9172434653558272, 0.9363140103696151, 0.9734182699959772], 
             UndirectedEdge[7, 313] -> 
             RGBColor[
              0.7726054970838558, 0.6793845602533969, 0.6014975551174375], 
             UndirectedEdge[129, 444] -> 
             RGBColor[
              0.6886879834608504, 0.7537484984434157, 0.9638982321064615], 
             UndirectedEdge[18, 493] -> 
             RGBColor[
              0.9573345158403275, 0.8557728429053384, 0.493677123954659], 
             UndirectedEdge[149, 411] -> 
             RGBColor[
              0.8691094781962995, 0.5069099387611526, 0.45322098686274714`], 
             UndirectedEdge[221, 301] -> 
             RGBColor[
              0.9780021502576246, 0.9373649268607361, 0.3769766653439548], 
             UndirectedEdge[45, 496] -> 
             RGBColor[
              0.7630401124344155, 0.7663429794920184, 0.6270727441286879], 
             UndirectedEdge[478, 482] -> 
             RGBColor[
              0.9176724228759894, 0.753011150245019, 0.5883024578448539], 
             UndirectedEdge[69, 331] -> 
             RGBColor[
              0.9198310859267613, 0.7117940363864655, 0.25968189875073433`], 
             UndirectedEdge[16, 143] -> 
             RGBColor[
              0.9499157985023857, 0.9595912904358073, 0.8623075360884397], 
             UndirectedEdge[210, 280] -> 
             RGBColor[
              0.7876738391444515, 0.8342629061230606, 0.9794167336641547], 
             UndirectedEdge[101, 390] -> 
             RGBColor[
              0.8984761442241344, 0.9043045874079283, 0.6850608255209973], 
             UndirectedEdge[400, 418] -> 
             RGBColor[
              0.7628242207327514, 0.332584624842513, 0.4315225955872538], 
             UndirectedEdge[84, 299] -> 
             RGBColor[
              0.8217852305779516, 0.3787032514767585, 0.43738392969988493`], 
             UndirectedEdge[333, 386] -> 
             RGBColor[
              0.9548991503952318, 0.9623563176170666, 0.767415085122201], 
             UndirectedEdge[244, 341] -> 
             RGBColor[
              0.9145796307016465, 0.757116357526425, 0.5978075298318952], 
             UndirectedEdge[143, 373] -> 
             RGBColor[
              0.9334386545027149, 0.7518149128864251, 0.47434583262040886`], 
             UndirectedEdge[160, 284] -> 
             RGBColor[
              0.646611450525783, 0.7111886049132674, 0.8128178771898793], 
             UndirectedEdge[281, 343] -> 
             RGBColor[
              0.8099667978171567, 0.8523252736357714, 0.9773202139895458], 
             UndirectedEdge[207, 445] -> 
             RGBColor[
              0.6513327198957803, 0.724000611893153, 0.968207318877863], 
             UndirectedEdge[260, 334] -> 
             RGBColor[
              0.9872558314813205, 0.9747995260309588, 0.6050329170325565], 
             UndirectedEdge[66, 114] -> 
             RGBColor[
              0.8625330528015756, 0.8906658037910402, 0.8549139018549716], 
             UndirectedEdge[364, 381] -> 
             RGBColor[
              0.9603201456971598, 0.9407409175293635, 0.6620154294596354], 
             UndirectedEdge[204, 306] -> 
             RGBColor[
              0.9842706834399105, 0.9869605487769153, 0.8743795305783604], 
             UndirectedEdge[358, 361] -> 
             RGBColor[
              0.9095350791026879, 0.787681345712272, 0.6150338464453553], 
             UndirectedEdge[294, 415] -> 
             RGBColor[
              0.9527281869423518, 0.8385277572350438, 0.4949496846649693], 
             UndirectedEdge[2, 255] -> 
             RGBColor[
              0.854700281926275, 0.404948819966644, 0.4405233966811013], 
             UndirectedEdge[326, 443] -> 
             RGBColor[
              0.9095700155403674, 0.929136787184178, 0.9329795622708388], 
             UndirectedEdge[58, 145] -> 
             RGBColor[
              0.6083339781062591, 0.6857731212223155, 0.9659205315610241], 
             UndirectedEdge[103, 346] -> 
             RGBColor[
              0.7532524973590851, 0.7656392892695116, 0.6370639501386153], 
             UndirectedEdge[62, 108] -> 
             RGBColor[
              0.8882205884072258, 0.7198353466610563, 0.602961654292055], 
             UndirectedEdge[91, 336] -> 
             RGBColor[
              0.7168204065942949, 0.777695704075896, 0.973365634901412], 
             UndirectedEdge[338, 395] -> 
             RGBColor[
              0.5918984469238254, 0.6572014023952828, 0.9172139907582397], 
             UndirectedEdge[19, 335] -> 
             RGBColor[
              0.6204673675814035, 0.7026368071800528, 0.963350469836702], 
             UndirectedEdge[2, 195] -> 
             RGBColor[
              0.9525592078321163, 0.9639785021487952, 0.9596135697848798], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.8605393035625163, 0.4094107615733261, 0.4343564535795672], 
             UndirectedEdge[150, 325] -> 
             RGBColor[
              0.9131343479494656, 0.8215566573017786, 0.6220872538849398], 
             UndirectedEdge[208, 238] -> 
             RGBColor[
              0.987553570390173, 0.987343088080104, 0.7399315171305991], 
             UndirectedEdge[318, 335] -> 
             RGBColor[
              0.6577047421878429, 0.7325232104291032, 0.96651752016717], 
             UndirectedEdge[12, 421] -> 
             RGBColor[
              0.6731165348331469, 0.7425329499644858, 0.9695590733442376], 
             UndirectedEdge[102, 278] -> 
             RGBColor[
              0.6903408062210481, 0.7580187516951166, 0.9697703780286414], 
             UndirectedEdge[5, 209] -> 
             RGBColor[
              0.7338384039883004, 0.7919115206654033, 0.9742451458880235], 
             UndirectedEdge[76, 463] -> 
             RGBColor[
              0.8525926466970152, 0.8851410389645985, 0.9570752497155623], 
             UndirectedEdge[293, 445] -> 
             RGBColor[
              0.6067324618945926, 0.6887129276195751, 0.9638802368145989], 
             UndirectedEdge[48, 250] -> 
             RGBColor[
              0.7298476865491625, 0.7885959307023507, 0.9740181639803782], 
             UndirectedEdge[459, 477] -> 
             RGBColor[
              0.8256405898876062, 0.7527048052862567, 0.6136020985481656], 
             UndirectedEdge[400, 404] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[144, 246] -> 
             RGBColor[
              0.6354896941029182, 0.5935284606642226, 0.5976140560815344], 
             UndirectedEdge[90, 393] -> 
             RGBColor[
              0.9723476195151729, 0.9520771473786751, 0.6466789625102316], 
             UndirectedEdge[157, 360] -> 
             RGBColor[
              0.683495205532421, 0.7467016603025645, 0.9229278496055344], 
             UndirectedEdge[156, 250] -> 
             RGBColor[
              0.9242071051229961, 0.9385152969787796, 0.8157182527343674], 
             UndirectedEdge[25, 220] -> 
             RGBColor[
              0.7124247815400827, 0.7739345257737879, 0.9732412879164551], 
             UndirectedEdge[261, 407] -> 
             RGBColor[
              0.8777200692423153, 0.9045990235809503, 0.9508858176156076], 
             UndirectedEdge[42, 364] -> 
             RGBColor[
              0.8380057272164486, 0.8741024476722623, 0.9736835860882299], 
             UndirectedEdge[83, 257] -> 
             RGBColor[
              0.7695601935257237, 0.33784681798367233`, 0.43219397440401264`],
              UndirectedEdge[137, 263] -> 
             RGBColor[
              0.9765752234921068, 0.9665656368539228, 0.6635859576736872], 
             UndirectedEdge[27, 65] -> 
             RGBColor[
              0.9133206953797207, 0.6873357598794598, 0.24876655220640198`], 
             UndirectedEdge[318, 421] -> 
             RGBColor[
              0.578178682444009, 0.6680859519366233, 0.960171078098194], 
             UndirectedEdge[203, 341] -> 
             RGBColor[0.9625359818214043, 0.9476128125056, 0.669344242491275],
              UndirectedEdge[80, 483] -> 
             RGBColor[
              0.5481615972561701, 0.6440613049079245, 0.95757243539955], 
             UndirectedEdge[95, 319] -> 
             RGBColor[
              0.8470221676816798, 0.8712943906095006, 0.6904261581015795], 
             UndirectedEdge[84, 376] -> 
             RGBColor[
              0.7508471721325859, 0.8053735410449776, 0.9757780646284042], 
             UndirectedEdge[260, 446] -> 
             RGBColor[
              0.9780334665039105, 0.9688836172597217, 0.6637294923655761], 
             UndirectedEdge[174, 393] -> 
             RGBColor[
              0.983835976501616, 0.9592302267480005, 0.5638692312573159], 
             UndirectedEdge[185, 216] -> 
             RGBColor[
              0.9670591855846733, 0.9743910540666044, 0.9154625028128078], 
             UndirectedEdge[143, 321] -> 
             RGBColor[
              0.9748538486641571, 0.9253081490041877, 0.5081503316738337], 
             UndirectedEdge[296, 415] -> 
             RGBColor[
              0.9376054824243383, 0.8289438762395678, 0.5964364547470924], 
             UndirectedEdge[42, 113] -> 
             RGBColor[
              0.8578306619451824, 0.8884000860543444, 0.9182820080839695], 
             UndirectedEdge[54, 264] -> 
             RGBColor[
              0.8073416800753852, 0.8039197243537861, 0.6333513076580746], 
             UndirectedEdge[9, 95] -> 
             RGBColor[
              0.7157074901147069, 0.7653755726632457, 0.67950363296107], 
             UndirectedEdge[47, 55] -> 
             RGBColor[
              0.833537641919247, 0.38807430526959985`, 0.4385048851851192], 
             UndirectedEdge[212, 330] -> 
             RGBColor[
              0.8050074655090471, 0.8479152873230256, 0.9811148730357022], 
             UndirectedEdge[89, 244] -> 
             RGBColor[
              0.7215390187132774, 0.6043597386333341, 0.5906259644045744], 
             UndirectedEdge[3, 247] -> 
             RGBColor[
              0.6786056729327609, 0.6504716559728235, 0.6050476315371216], 
             UndirectedEdge[26, 318] -> 
             RGBColor[
              0.8288464547126407, 0.864707255348204, 0.867774976318274], 
             UndirectedEdge[46, 426] -> 
             RGBColor[
              0.8945451634344677, 0.874439729381684, 0.6454450367569177], 
             UndirectedEdge[102, 247] -> 
             RGBColor[
              0.5528786357182693, 0.6466781627608185, 0.9584972465338205], 
             UndirectedEdge[285, 287] -> 
             RGBColor[
              0.8759572457915535, 0.41872999111850573`, 0.2777827512144868], 
             UndirectedEdge[346, 390] -> 
             RGBColor[
              0.7623868045986825, 0.796451452426006, 0.6725490088952681], 
             UndirectedEdge[388, 473] -> 
             RGBColor[
              0.6200910299272135, 0.6893470865268854, 0.9378661460163285], 
             UndirectedEdge[377, 412] -> 
             RGBColor[
              0.760570882484887, 0.3308242998772764, 0.4312980038893498], 
             UndirectedEdge[7, 321] -> 
             RGBColor[
              0.9270206994906767, 0.7469363779783933, 0.26006326744553515`], 
             UndirectedEdge[209, 275] -> 
             RGBColor[
              0.9154155233092638, 0.9335233791989344, 0.9216192324639171], 
             UndirectedEdge[204, 346] -> 
             RGBColor[
              0.7606226591899428, 0.8115466639930022, 0.9384514923982591], 
             UndirectedEdge[220, 297] -> 
             RGBColor[
              0.7212136440812937, 0.7079088382577324, 0.6133192376420644], 
             UndirectedEdge[16, 185] -> 
             RGBColor[
              0.9257257458660936, 0.9433329951352929, 0.9830837397697092], 
             UndirectedEdge[323, 449] -> 
             RGBColor[
              0.8084642554055745, 0.8491712139387639, 0.8938001190522491], 
             UndirectedEdge[224, 481] -> 
             RGBColor[
              0.5495700464518474, 0.6450576846954243, 0.9577593749362427], 
             UndirectedEdge[86, 476] -> 
             RGBColor[
              0.9890202212654464, 0.9894443861104081, 0.8173874704076455], 
             UndirectedEdge[66, 385] -> 
             RGBColor[
              0.8333837299349074, 0.8706862984935271, 0.9830730339858706], 
             UndirectedEdge[184, 316] -> 
             RGBColor[
              0.9152289791368378, 0.9344620998854554, 0.9647105399672269], 
             UndirectedEdge[308, 362] -> 
             RGBColor[
              0.8270044483757222, 0.8649400312463513, 0.9833496441607079], 
             UndirectedEdge[216, 361] -> 
             RGBColor[
              0.9535569187305459, 0.963904315721495, 0.923868646894415], 
             UndirectedEdge[123, 410] -> 
             RGBColor[
              0.8548680584915376, 0.8874839104935852, 0.9859175636054444], 
             UndirectedEdge[174, 225] -> 
             RGBColor[
              0.9825702737942618, 0.9549607143149663, 0.5589522152471451], 
             UndirectedEdge[3, 139] -> 
             RGBColor[
              0.9271092490543826, 0.7487194924431486, 0.26020859470457397`], 
             UndirectedEdge[226, 472] -> 
             RGBColor[
              0.9082492116401182, 0.7661360080546458, 0.6108600112497163], 
             UndirectedEdge[9, 441] -> 
             RGBColor[
              0.7184565663641234, 0.774934717719648, 0.849854495437047], 
             UndirectedEdge[253, 354] -> 
             RGBColor[
              0.9308320766624767, 0.9473306038150753, 0.9810037420377578], 
             UndirectedEdge[47, 73] -> 
             RGBColor[
              0.9303496946153251, 0.9435467007764711, 0.8271236226490692], 
             UndirectedEdge[305, 432] -> 
             RGBColor[
              0.8930835350399339, 0.5489321353344011, 0.3221489123186475], 
             UndirectedEdge[4, 226] -> 
             RGBColor[
              0.8868060791213315, 0.6388100566549203, 0.4710650761021744], 
             UndirectedEdge[112, 359] -> 
             RGBColor[
              0.8313483716711112, 0.8685346250899783, 0.9837292432794182], 
             UndirectedEdge[101, 204] -> 
             RGBColor[
              0.8967119988153947, 0.9193997989749245, 0.9509633090239884], 
             UndirectedEdge[256, 409] -> 
             RGBColor[
              0.4859519572406641, 0.5935567166309912, 0.9526750646561093], 
             UndirectedEdge[64, 268] -> 
             RGBColor[
              0.9704575920407286, 0.9757790082395075, 0.8583640594471312], 
             UndirectedEdge[97, 395] -> 
             RGBColor[
              0.3064165963050924, 0.42966742066380703`, 0.9411174687709902], 
             UndirectedEdge[117, 156] -> 
             RGBColor[
              0.8122449907282661, 0.8505857350360371, 0.8047614508648658], 
             UndirectedEdge[48, 117] -> 
             RGBColor[
              0.6178855721544325, 0.700666368759608, 0.9630613621108768], 
             UndirectedEdge[5, 103] -> 
             RGBColor[
              0.7944371042885858, 0.7990748085202792, 0.6403061532602916], 
             UndirectedEdge[344, 438] -> 
             RGBColor[
              0.8601916902758873, 0.8909965472329728, 0.953736376248378], 
             UndirectedEdge[42, 381] -> 
             RGBColor[
              0.8508478073311907, 0.8544935573767084, 0.6619089011065716], 
             UndirectedEdge[224, 398] -> 
             RGBColor[
              0.7148482383878014, 0.7743501406751004, 0.9355436094111078], 
             UndirectedEdge[226, 405] -> 
             RGBColor[
              0.9038623076302913, 0.7462161015334846, 0.6071994710110596], 
             UndirectedEdge[231, 346] -> 
             RGBColor[
              0.725508210369195, 0.3024070015681664, 0.42850481569279164`], 
             UndirectedEdge[168, 181] -> 
             RGBColor[
              0.8729965405314221, 0.40904349553426433`, 0.24071514471745728`],
              UndirectedEdge[178, 391] -> 
             RGBColor[
              0.890978306026738, 0.5307613375400002, 0.3588158385138837], 
             UndirectedEdge[30, 133] -> 
             RGBColor[
              0.7384397031356915, 0.4180827654515399, 0.44296915940260495`], 
             UndirectedEdge[120, 363] -> 
             RGBColor[
              0.7856358033656099, 0.8282205518116024, 0.7401603267753298], 
             UndirectedEdge[452, 468] -> 
             RGBColor[
              0.8687937095770325, 0.8982165375124541, 0.9873475136723995], 
             UndirectedEdge[159, 344] -> 
             RGBColor[
              0.8691859852369526, 0.8967077478900611, 0.8938757841713051], 
             UndirectedEdge[68, 330] -> 
             RGBColor[
              0.5863785773857515, 0.6682832904495004, 0.9638186673670157], 
             UndirectedEdge[359, 440] -> 
             RGBColor[
              0.7585076669727508, 0.8116309129697594, 0.9764691625701725], 
             UndirectedEdge[180, 413] -> 
             RGBColor[
              0.69385125705525, 0.7603489948757104, 0.9704020545883891], 
             UndirectedEdge[81, 442] -> 
             RGBColor[
              0.8761154064361469, 0.4190682807447971, 0.29499756132413085`], 
             UndirectedEdge[165, 277] -> 
             RGBColor[
              0.8509941095069788, 0.8817604073612053, 0.8587024206501743], 
             UndirectedEdge[28, 310] -> 
             RGBColor[
              0.9368750089269035, 0.7860603510535248, 0.5558365059115632], 
             UndirectedEdge[71, 470] -> 
             RGBColor[
              0.9725948344220984, 0.9311248555949052, 0.588031035270401], 
             UndirectedEdge[129, 276] -> 
             RGBColor[
              0.4030478773120687, 0.5235215463775458, 0.946902832234449], 
             UndirectedEdge[192, 251] -> 
             RGBColor[
              0.9255663892440432, 0.7395023937054264, 0.2601156757719657], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.9386036615564017, 0.7746550721246118, 0.47607054698861184`], 
             UndirectedEdge[15, 323] -> 
             RGBColor[
              0.7920404053408276, 0.8378030684586115, 0.9610425262260975], 
             UndirectedEdge[20, 473] -> 
             RGBColor[
              0.826797399384674, 0.8649615179276247, 0.9530829276312751], 
             UndirectedEdge[336, 354] -> 
             RGBColor[
              0.924045059812422, 0.9419188208075064, 0.980356390311758], 
             UndirectedEdge[36, 440] -> 
             RGBColor[
              0.8238374600611766, 0.8602525548358231, 0.8394931431251023], 
             UndirectedEdge[31, 311] -> 
             RGBColor[
              0.6517858549264521, 0.720295520239978, 0.9397981249726929], 
             UndirectedEdge[366, 405] -> 
             RGBColor[
              0.8789176455492327, 0.7263259050948628, 0.6048202268734055], 
             UndirectedEdge[257, 374] -> 
             RGBColor[
              0.8764236196204777, 0.4197275175809472, 0.3285446643672315], 
             UndirectedEdge[194, 254] -> 
             RGBColor[
              0.9834151339793746, 0.9637369890037479, 0.6031971370430306], 
             UndirectedEdge[284, 456] -> 
             RGBColor[
              0.6212351354302066, 0.6943775391657697, 0.9598718206285126], 
             UndirectedEdge[30, 429] -> 
             RGBColor[
              0.7456151625383329, 0.8001195053906589, 0.9575631855028855], 
             UndirectedEdge[182, 463] -> 
             RGBColor[
              0.9005393945585218, 0.9227062159886442, 0.9618252577807365], 
             UndirectedEdge[130, 238] -> 
             RGBColor[
              0.9871513062410279, 0.9864826857402271, 0.6961475469827261], 
             UndirectedEdge[19, 67] -> 
             RGBColor[
              0.6057125786597295, 0.6907837842535006, 0.9621030594718294], 
             UndirectedEdge[114, 446] -> 
             RGBColor[
              0.9831620871676904, 0.9852028807271787, 0.834569441902184], 
             UndirectedEdge[164, 418] -> 
             RGBColor[
              0.5123124450960429, 0.6125407331911124, 0.9554895950529859], 
             UndirectedEdge[96, 457] -> 
             RGBColor[
              0.9824382519891302, 0.9513570198415852, 0.4768551276743572], 
             UndirectedEdge[285, 354] -> 
             RGBColor[
              0.9713233168341355, 0.9748643873784238, 0.7377136021876869], 
             UndirectedEdge[432, 460] -> 
             RGBColor[
              0.9031185317612687, 0.6260655174981828, 0.33175843651190545`], 
             UndirectedEdge[82, 249] -> 
             RGBColor[
              0.6857590428543079, 0.7520567384762258, 0.9712121822597384], 
             UndirectedEdge[176, 262] -> 
             RGBColor[
              0.8748083544481332, 0.41943290082649287`, 0.38245144027450473`],
              UndirectedEdge[216, 358] -> 
             RGBColor[
              0.9435548564731384, 0.8129076888112612, 0.5467150258447059], 
             UndirectedEdge[54, 374] -> 
             RGBColor[
              0.9774984907826467, 0.9344447865278582, 0.47886026186195463`], 
             UndirectedEdge[214, 491] -> 
             RGBColor[
              0.538366099779513, 0.46711655202356794`, 0.5849697461496591], 
             UndirectedEdge[68, 357] -> 
             RGBColor[
              0.6327798005206056, 0.7048584307709889, 0.9535463482822939], 
             UndirectedEdge[260, 328] -> 
             RGBColor[
              0.8803415443356581, 0.46524605170306166`, 0.2479213544211708], 
             UndirectedEdge[224, 286] -> 
             RGBColor[
              0.6718675584117024, 0.7411846066336997, 0.9697930295103183], 
             UndirectedEdge[219, 293] -> 
             RGBColor[
              0.8023702405675512, 0.8455369972618412, 0.9809364250697139], 
             UndirectedEdge[209, 404] -> 
             RGBColor[
              0.8260196543366713, 0.38207966604159066`, 0.4377878128181064], 
             UndirectedEdge[197, 289] -> 
             RGBColor[
              0.847651675557928, 0.8803131178098322, 0.9111429634756407], 
             UndirectedEdge[227, 424] -> 
             RGBColor[
              0.8892370453434089, 0.5899331168972773, 0.22928901439712882`], 
             UndirectedEdge[458, 461] -> 
             RGBColor[
              0.6119968405023704, 0.6954500192447882, 0.9628956098023547], 
             UndirectedEdge[292, 464] -> 
             RGBColor[
              0.6465196058716078, 0.722344347674989, 0.9663878751846999], 
             UndirectedEdge[386, 441] -> 
             RGBColor[
              0.9937565765354559, 0.9902207491751185, 0.6466105407384792], 
             UndirectedEdge[257, 343] -> 
             RGBColor[
              0.7714232212932521, 0.339302229435201, 0.4323796636008955], 
             UndirectedEdge[132, 457] -> 
             RGBColor[0.8723425553003561, 0.86802632536, 0.6592920399393694], 
             UndirectedEdge[69, 259] -> 
             RGBColor[
              0.9221488866598662, 0.7604500858820038, 0.5834555282126308], 
             UndirectedEdge[68, 95] -> 
             RGBColor[
              0.6509262856265654, 0.7092653493336275, 0.6753758318948555], 
             UndirectedEdge[247, 278] -> 
             RGBColor[
              0.5658636899324211, 0.656822185802981, 0.9597914753856563], 
             UndirectedEdge[293, 440] -> 
             RGBColor[
              0.719223265610053, 0.7805819484846287, 0.9726491116586087], 
             UndirectedEdge[307, 442] -> 
             RGBColor[
              0.8611425802212584, 0.4098606843176411, 0.4333352635560689], 
             UndirectedEdge[406, 493] -> 
             RGBColor[
              0.8060299935125139, 0.8461051962176389, 0.8480516457168199], 
             UndirectedEdge[155, 479] -> 
             RGBColor[
              0.9238178474285423, 0.9420060278675829, 0.9896396233141057], 
             UndirectedEdge[311, 488] -> 
             RGBColor[
              0.7071640422678251, 0.7682613227264489, 0.9433267741010769], 
             UndirectedEdge[226, 345] -> 
             RGBColor[
              0.8898840663298024, 0.9150334155046296, 0.9893591307270624], 
             UndirectedEdge[183, 273] -> 
             RGBColor[
              0.644407916791892, 0.2331389778159341, 0.42291712960487904`], 
             UndirectedEdge[384, 499] -> 
             RGBColor[
              0.810764384003258, 0.8527870478720267, 0.9692344188052395], 
             UndirectedEdge[20, 325] -> 
             RGBColor[
              0.796193863485237, 0.8414234541652894, 0.9801320140542022], 
             UndirectedEdge[252, 424] -> 
             RGBColor[
              0.9452929146978233, 0.8061345569798164, 0.425539716930922], 
             UndirectedEdge[285, 473] -> 
             RGBColor[
              0.9812259139881996, 0.98224972812191, 0.7209510882168355], 
             UndirectedEdge[71, 236] -> 
             RGBColor[
              0.9608207349743608, 0.9226569385492737, 0.621986670175156], 
             UndirectedEdge[2, 446] -> 
             RGBColor[
              0.9505006193993973, 0.9624432102663025, 0.9630982230356204], 
             UndirectedEdge[33, 351] -> 
             RGBColor[
              0.932960656323998, 0.9449863740332667, 0.7753108670930504], 
             UndirectedEdge[172, 466] -> 
             RGBColor[
              0.8482890569349865, 0.35474034328797555`, 0.19319220811689025`],
              UndirectedEdge[12, 279] -> 
             RGBColor[
              0.6352157028902841, 0.7107420114393673, 0.9668575791266505], 
             UndirectedEdge[171, 219] -> 
             RGBColor[
              0.906423172588101, 0.9240071200263744, 0.7866905046784441], 
             UndirectedEdge[153, 223] -> 
             RGBColor[
              0.9543168682604793, 0.9654501756647041, 0.9622138053527373], 
             UndirectedEdge[121, 489] -> 
             RGBColor[
              0.6998311637044086, 0.7639077233480006, 0.9720228250929855], 
             UndirectedEdge[362, 470] -> 
             RGBColor[
              0.9128419498892143, 0.9317271086161413, 0.9324826545312943], 
             UndirectedEdge[168, 232] -> 
             RGBColor[
              0.9010918780975486, 0.6227799081753085, 0.2675324727223643], 
             UndirectedEdge[285, 409] -> 
             RGBColor[
              0.744342507334343, 0.7946023329726594, 0.7291675697856631], 
             UndirectedEdge[159, 439] -> 
             RGBColor[
              0.8356293013821756, 0.8704930114224663, 0.8905311675297007], 
             UndirectedEdge[156, 263] -> 
             RGBColor[
              0.9820419930355484, 0.9837581233249566, 0.7909621665544164], 
             UndirectedEdge[149, 314] -> 
             RGBColor[
              0.9641071470998932, 0.9709070865935641, 0.8636611195864364], 
             UndirectedEdge[110, 457] -> 
             RGBColor[
              0.966635609933993, 0.9421473660185228, 0.6443120477028446], 
             UndirectedEdge[43, 263] -> 
             RGBColor[
              0.9675272085673081, 0.97530242583559, 0.9398521450218369], 
             UndirectedEdge[141, 160] -> 
             RGBColor[
              0.8765097884918237, 0.4199118240837473, 0.3379236142406269], 
             UndirectedEdge[345, 389] -> 
             RGBColor[
              0.9129568659761338, 0.9044532028605723, 0.6697572498332384], 
             UndirectedEdge[225, 247] -> 
             RGBColor[
              0.7004167281630209, 0.7320750940552555, 0.6479610269177876], 
             UndirectedEdge[171, 293] -> 
             RGBColor[
              0.8899699399076089, 0.9111537296071741, 0.7850506002090539], 
             UndirectedEdge[179, 415] -> 
             RGBColor[
              0.6699467838833615, 0.6154793123946146, 0.5979220160153735], 
             UndirectedEdge[143, 414] -> 
             RGBColor[
              0.9904050204864645, 0.9903002436384964, 0.8086771717576826], 
             UndirectedEdge[77, 388] -> 
             RGBColor[
              0.6321076006866722, 0.6968039577295024, 0.8501252242309918], 
             UndirectedEdge[305, 406] -> 
             RGBColor[
              0.767444687097819, 0.4524071779788082, 0.4466302979668265], 
             UndirectedEdge[55, 256] -> 
             RGBColor[
              0.7036968790624343, 0.2846995802240602, 0.42678774779478423`], 
             UndirectedEdge[367, 450] -> 
             RGBColor[
              0.822810409461088, 0.43007372463002286`, 0.4437915911257611], 
             UndirectedEdge[171, 258] -> 
             RGBColor[
              0.832956121989973, 0.8666141017288519, 0.7793679956634447], 
             UndirectedEdge[366, 423] -> 
             RGBColor[
              0.9225500251148178, 0.9030693796207843, 0.6573833103122245], 
             UndirectedEdge[309, 393] -> 
             RGBColor[
              0.9671675045362618, 0.9482138261090629, 0.6554475459791631], 
             UndirectedEdge[324, 360] -> 
             RGBColor[
              0.6558800780797485, 0.6320848623602878, 0.6039097037973828], 
             UndirectedEdge[125, 310] -> 
             RGBColor[
              0.9027144301084613, 0.6472881588968105, 0.2403361001397001], 
             UndirectedEdge[33, 463] -> 
             RGBColor[
              0.980699590227901, 0.9822286350750123, 0.7513140615609489], 
             UndirectedEdge[137, 280] -> 
             RGBColor[
              0.9145838933858897, 0.9180085763261352, 0.6879455986867067], 
             UndirectedEdge[72, 179] -> 
             RGBColor[
              0.6957300834289755, 0.7587514302103805, 0.9483429830449188], 
             UndirectedEdge[17, 165] -> 
             RGBColor[
              0.8497613187673525, 0.8777059757205925, 0.696937197456226], 
             UndirectedEdge[402, 417] -> 
             RGBColor[
              0.9745185251574527, 0.9794924737082833, 0.8821579649007079], 
             UndirectedEdge[102, 225] -> 
             RGBColor[
              0.8248938444516478, 0.833271659947391, 0.6579399295607726], 
             UndirectedEdge[83, 231] -> 
             RGBColor[
              0.7695601935257237, 0.33784681798367233`, 0.43219397440401264`],
              UndirectedEdge[194, 377] -> 
             RGBColor[
              0.8744473059605155, 0.41928359799834003`, 0.3884349480778658], 
             UndirectedEdge[131, 495] -> 
             RGBColor[
              0.7412963671467233, 0.7973921173898098, 0.9754930584580643], 
             UndirectedEdge[213, 447] -> 
             RGBColor[
              0.7178938406598294, 0.7764704495868286, 0.9241795180781536], 
             UndirectedEdge[146, 166] -> 
             RGBColor[
              0.8337388373621797, 0.8708929180761834, 0.9838372479138293], 
             UndirectedEdge[422, 428] -> 
             RGBColor[
              0.9815950244762847, 0.9828021027721449, 0.7423123972487576], 
             UndirectedEdge[232, 338] -> 
             RGBColor[
              0.9012770738958897, 0.6324966650734122, 0.4362260400535542], 
             UndirectedEdge[366, 469] -> 
             RGBColor[
              0.9210930497654388, 0.9391850241191875, 0.9669019277229197], 
             UndirectedEdge[245, 482] -> 
             RGBColor[
              0.9223446790721623, 0.7742267743986812, 0.59220110294242], 
             UndirectedEdge[40, 243] -> 
             RGBColor[
              0.8969293417523031, 0.9195217506655893, 0.9485634066683157], 
             UndirectedEdge[174, 320] -> 
             RGBColor[
              0.8361701372859403, 0.8704527628468539, 0.8696018556761185], 
             UndirectedEdge[30, 31] -> 
             RGBColor[
              0.43459116396256625`, 0.5486307954786305, 0.9495239138117948], 
             UndirectedEdge[77, 354] -> 
             RGBColor[
              0.9713320642071333, 0.976635013347434, 0.8660115149757253], 
             UndirectedEdge[24, 223] -> 
             RGBColor[
              0.9735015541869848, 0.9779871650692875, 0.8504338123662112], 
             UndirectedEdge[261, 391] -> 
             RGBColor[
              0.9862100152819423, 0.9872577868170849, 0.8149436114895612], 
             UndirectedEdge[125, 323] -> 
             RGBColor[
              0.7725011675263679, 0.7096536379630536, 0.6081719531611705], 
             UndirectedEdge[1, 364] -> 
             RGBColor[
              0.9694485215950097, 0.9755346743952569, 0.8828316963324088], 
             UndirectedEdge[88, 133] -> 
             RGBColor[
              0.8249687178198697, 0.19292608329124133`, 0.17154337842342776`],
              UndirectedEdge[178, 407] -> 
             RGBColor[
              0.8186516753336532, 0.4756554953825771, 0.44944397593124796`], 
             UndirectedEdge[103, 486] -> 
             RGBColor[
              0.8429343144204308, 0.8372385149141195, 0.6449502986181099], 
             UndirectedEdge[204, 486] -> 
             RGBColor[
              0.8503044762512886, 0.8831458896376101, 0.9463378408777536], 
             UndirectedEdge[89, 407] -> 
             RGBColor[
              0.6699813633152252, 0.7408805902942812, 0.9685842913496883], 
             UndirectedEdge[38, 301] -> 
             RGBColor[
              0.6318090734468441, 0.6944135219265809, 0.6902865612524987], 
             UndirectedEdge[92, 132] -> 
             RGBColor[
              0.8751134199360577, 0.9025829386846316, 0.9516510301073935], 
             UndirectedEdge[8, 146] -> 
             RGBColor[
              0.6296451624543737, 0.7034932013428872, 0.9676184779820195], 
             UndirectedEdge[44, 110] -> 
             RGBColor[
              0.9675799634927837, 0.9453328923170838, 0.6479806829525405], 
             UndirectedEdge[102, 252] -> 
             RGBColor[
              0.8358044538812319, 0.8689955674231113, 0.792172901230507], 
             UndirectedEdge[273, 283] -> 
             RGBColor[
              0.7715005000999191, 0.33936260022630993`, 0.4323873660301325], 
             UndirectedEdge[158, 428] -> 
             RGBColor[
              0.9703057275906395, 0.9743825636393578, 0.7614222321559622], 
             UndirectedEdge[176, 328] -> 
             RGBColor[
              0.8820943854545076, 0.4754365279006312, 0.3894285517946038], 
             UndirectedEdge[45, 398] -> 
             RGBColor[
              0.9687777008842611, 0.9283952370484574, 0.6081015449767175], 
             UndirectedEdge[233, 275] -> 
             RGBColor[
              0.9907728832700919, 0.9904523643531687, 0.8025807334346082], 
             UndirectedEdge[250, 485] -> 
             RGBColor[
              0.7016387401045829, 0.7656946371800855, 0.9717974523834854], 
             UndirectedEdge[29, 65] -> 
             RGBColor[
              0.8997505606307765, 0.7450211452024238, 0.6072186536687073], 
             UndirectedEdge[166, 453] -> 
             RGBColor[
              0.8660698266613729, 0.8943313886443913, 0.8961955017361254], 
             UndirectedEdge[222, 294] -> 
             RGBColor[
              0.9755062420581593, 0.9286407565758998, 0.5142898750291993], 
             UndirectedEdge[150, 220] -> 
             RGBColor[
              0.7089059092220502, 0.6591127708503449, 0.6034161452746494], 
             UndirectedEdge[311, 423] -> 
             RGBColor[
              0.9681164132612092, 0.9385395994031756, 0.6318024369800309], 
             UndirectedEdge[210, 424] -> 
             RGBColor[
              0.8130522538412885, 0.7054876390412542, 0.604455137477807], 
             UndirectedEdge[179, 312] -> 
             RGBColor[
              0.6664527656776476, 0.7361009905837579, 0.9696291969834214], 
             UndirectedEdge[310, 323] -> 
             RGBColor[
              0.7576484946397191, 0.6460537338100532, 0.5959772932985425], 
             UndirectedEdge[108, 349] -> 
             RGBColor[
              0.9111610713483149, 0.6763124209974507, 0.24690155531728444`], 
             UndirectedEdge[355, 395] -> 
             RGBColor[
              0.4643307594504298, 0.5575993089048029, 0.954169169874258], 
             UndirectedEdge[47, 200] -> 
             RGBColor[
              0.929926587792679, 0.9438527145188926, 0.8690977143503663], 
             UndirectedEdge[152, 217] -> 
             RGBColor[
              0.8037264991209485, 0.36453779558820204`, 0.4355993524434657], 
             UndirectedEdge[174, 210] -> 
             RGBColor[
              0.8612402223673111, 0.8900377038521244, 0.8721006074637643], 
             UndirectedEdge[135, 211] -> 
             RGBColor[
              0.9649129277732799, 0.8860368024667394, 0.4508248990883569], 
             UndirectedEdge[52, 491] -> 
             RGBColor[
              0.9212908817479744, 0.7238018063579372, 0.255431311631782], 
             UndirectedEdge[41, 250] -> 
             RGBColor[
              0.7374679615292195, 0.7947824132206365, 0.9746180599407954], 
             UndirectedEdge[220, 392] -> 
             RGBColor[
              0.669580460195581, 0.7397716269118038, 0.9691547582990394], 
             UndirectedEdge[182, 359] -> 
             RGBColor[
              0.8489662054238987, 0.8824066239040079, 0.9854563486260517], 
             UndirectedEdge[89, 391] -> 
             RGBColor[
              0.7784713093548522, 0.8235393535304159, 0.832642085223642], 
             UndirectedEdge[62, 190] -> 
             RGBColor[
              0.9214757572108445, 0.860858870595646, 0.6301943049637279], 
             UndirectedEdge[21, 87] -> 
             RGBColor[
              0.8485763189179115, 0.8807315491461025, 0.8974546857166377], 
             UndirectedEdge[185, 286] -> 
             RGBColor[
              0.9195861793978635, 0.9384374714876184, 0.9824981424391137], 
             UndirectedEdge[114, 294] -> 
             RGBColor[
              0.9945889408797353, 0.9920304022429636, 0.7393387832022962], 
             UndirectedEdge[48, 156] -> 
             RGBColor[
              0.8001660630384241, 0.840779517387932, 0.8038105534305514], 
             UndirectedEdge[68, 450] -> 
             RGBColor[
              0.562609420711063, 0.6493965747097161, 0.9615339859349925], 
             UndirectedEdge[149, 406] -> 
             RGBColor[
              0.7751936800784274, 0.8248352775804697, 0.9782492902392481], 
             UndirectedEdge[123, 158] -> 
             RGBColor[
              0.8605067517137333, 0.8916892386661859, 0.9763727267869933], 
             UndirectedEdge[55, 91] -> 
             RGBColor[
              0.7232005299524522, 0.3005335226460366, 0.4283231466370737], 
             UndirectedEdge[135, 169] -> 
             RGBColor[
              0.9774600495995076, 0.9344422810471835, 0.4678976756022432], 
             UndirectedEdge[141, 456] -> 
             RGBColor[
              0.8595922450947727, 0.40870444691874874`, 0.43595957653304906`],
              UndirectedEdge[287, 354] -> 
             RGBColor[
              0.861350298764537, 0.41001560046711016`, 0.4329836502439711], 
             UndirectedEdge[223, 411] -> 
             RGBColor[
              0.8753958676783758, 0.511639688844806, 0.44401413126298883`], 
             UndirectedEdge[127, 301] -> 
             RGBColor[
              0.7032988426964115, 0.7598275737609232, 0.6947139227169968], 
             UndirectedEdge[167, 201] -> 
             RGBColor[
              0.9164472076014393, 0.8216988246988736, 0.6218435504881321], 
             UndirectedEdge[28, 218] -> 
             RGBColor[
              0.9904050204864645, 0.9903002436384964, 0.8086771717576826], 
             UndirectedEdge[112, 317] -> 
             RGBColor[
              0.7639913833861328, 0.8155551423415992, 0.9771111792566818], 
             UndirectedEdge[275, 372] -> 
             RGBColor[
              0.8740160278695045, 0.41910525342436566`, 0.3955823421578384], 
             UndirectedEdge[85, 146] -> 
             RGBColor[
              0.86805563499882, 0.8977014612072487, 0.9872576255935426], 
             UndirectedEdge[7, 262] -> 
             RGBColor[
              0.8446311606646579, 0.30122616595405494`, 0.1886948811709047], 
             UndirectedEdge[448, 455] -> 
             RGBColor[
              0.9057658608973895, 0.922921082372274, 0.7407673902337015], 
             UndirectedEdge[9, 368] -> 
             RGBColor[
              0.5765399939622976, 0.6657818984379513, 0.9605934713056788], 
             UndirectedEdge[216, 399] -> 
             RGBColor[
              0.9334006199727555, 0.7667996724452102, 0.5382420820056735], 
             UndirectedEdge[205, 474] -> 
             RGBColor[
              0.8172524367296157, 0.8551655629074684, 0.8468232552909654], 
             UndirectedEdge[125, 242] -> 
             RGBColor[
              0.7327834951217449, 0.6774090422442292, 0.6050452324988507], 
             UndirectedEdge[280, 338] -> 
             RGBColor[
              0.9152415266178473, 0.9338649996135405, 0.9424615545481363], 
             UndirectedEdge[232, 393] -> 
             RGBColor[
              0.8979624516698292, 0.612223618010343, 0.25537524199326744`], 
             UndirectedEdge[403, 483] -> 
             RGBColor[
              0.5829244095839591, 0.6722833220024723, 0.9603090913263709], 
             UndirectedEdge[427, 433] -> 
             RGBColor[
              0.9368343988256094, 0.7670197883768115, 0.4502578266012268], 
             UndirectedEdge[269, 310] -> 
             RGBColor[
              0.8982127061777112, 0.7568081336583325, 0.6096411234298538], 
             UndirectedEdge[212, 357] -> 
             RGBColor[
              0.8514086886439012, 0.884490427644514, 0.9708425539509804], 
             UndirectedEdge[88, 307] -> 
             RGBColor[
              0.8611425802212584, 0.409860684317641, 0.4333352635560688], 
             UndirectedEdge[212, 217] -> 
             RGBColor[
              0.7636100702294532, 0.8152572576055137, 0.9770731735247979], 
             UndirectedEdge[67, 124] -> 
             RGBColor[
              0.47806693171236925`, 0.583945039857693, 0.9529413303669698], 
             UndirectedEdge[364, 380] -> 
             RGBColor[
              0.7689944578049004, 0.8193960719723044, 0.9673482190747089], 
             UndirectedEdge[82, 384] -> 
             RGBColor[
              0.6972843982068164, 0.7608931003621809, 0.9600504344725114], 
             UndirectedEdge[222, 439] -> 
             RGBColor[
              0.8188437586430879, 0.80805329882973, 0.6274124382203987], 
             UndirectedEdge[337, 420] -> 
             RGBColor[
              0.9525264031089382, 0.9611401342718033, 0.8219697631322904], 
             UndirectedEdge[61, 99] -> 
             RGBColor[
              0.7567848180418488, 0.809090969898443, 0.9558524953568993], 
             UndirectedEdge[63, 439] -> 
             RGBColor[
              0.6445720038448978, 0.7217386569772644, 0.9655676252391242], 
             UndirectedEdge[37, 53] -> 
             RGBColor[
              0.9717439718581591, 0.9597449762602301, 0.6649338182719968], 
             UndirectedEdge[39, 62] -> 
             RGBColor[
              0.9436130322550627, 0.956651808312897, 0.952059959435284], 
             UndirectedEdge[130, 182] -> 
             RGBColor[
              0.9132065171273342, 0.9286979752510427, 0.7298970039245265], 
             UndirectedEdge[152, 398] -> 
             RGBColor[
              0.8710766812265248, 0.4172695205817712, 0.4165194217826521], 
             UndirectedEdge[23, 110] -> 
             RGBColor[
              0.9785318282556119, 0.9810806759815768, 0.7921771608289325], 
             UndirectedEdge[322, 440] -> 
             RGBColor[
              0.4571125263827004, 0.5604346311939433, 0.9521081240114999], 
             UndirectedEdge[141, 432] -> 
             RGBColor[
              0.8762164633747824, 0.41928443131811444`, 0.3059969854434657], 
             UndirectedEdge[161, 459] -> 
             RGBColor[
              0.9239012415165317, 0.7360008115607107, 0.25762735653800417`], 
             UndirectedEdge[185, 333] -> 
             RGBColor[
              0.931378339845198, 0.9478402201386547, 0.9836228892295664], 
             UndirectedEdge[297, 474] -> 
             RGBColor[
              0.7910796111896432, 0.7646291777822409, 0.6188193425003039], 
             UndirectedEdge[265, 329] -> 
             RGBColor[
              0.7310099531814894, 0.30687356423387635`, 0.4289379330405234], 
             UndirectedEdge[90, 280] -> 
             RGBColor[
              0.9076538704828214, 0.9283249602897155, 0.9606265780028564], 
             UndirectedEdge[183, 430] -> 
             RGBColor[
              0.6207684313076783, 0.694068273440956, 0.9608842272233288], 
             UndirectedEdge[86, 194] -> 
             RGBColor[
              0.9919606271152708, 0.9908877424920095, 0.7788418024397645], 
             UndirectedEdge[143, 186] -> 
             RGBColor[
              0.8865688966197612, 0.9094177854708356, 0.856175864679537], 
             UndirectedEdge[1, 416] -> 
             RGBColor[
              0.7795887748140593, 0.825345276410435, 0.8754942296313035], 
             UndirectedEdge[27, 86] -> 
             RGBColor[
              0.970474804369984, 0.9073661326035414, 0.4980039385328334], 
             UndirectedEdge[66, 415] -> 
             RGBColor[
              0.8206722988641921, 0.7371631587831204, 0.6105248033176447], 
             UndirectedEdge[413, 490] -> 
             RGBColor[
              0.7169032113303657, 0.7783573567567723, 0.9726996579577722], 
             UndirectedEdge[226, 284] -> 
             RGBColor[
              0.6131301339305286, 0.6881324685088103, 0.9666443882933089], 
             UndirectedEdge[245, 438] -> 
             RGBColor[
              0.9296953744267595, 0.7797089109584808, 0.579758293075481], 
             UndirectedEdge[53, 163] -> 
             RGBColor[
              0.9601620075427881, 0.9698094709709129, 0.9523195092042706], 
             UndirectedEdge[367, 368] -> 
             RGBColor[
              0.7889099886364833, 0.4035904582291008, 0.44041271399540893`], 
             UndirectedEdge[112, 175] -> 
             RGBColor[
              0.714087716287021, 0.7763801503873836, 0.9722670618402882], 
             UndirectedEdge[277, 288] -> 
             RGBColor[
              0.7860817401696695, 0.8300640157737179, 0.8529069388268881], 
             UndirectedEdge[249, 323] -> 
             RGBColor[
              0.7768987088231096, 0.8262696452528583, 0.9783257963131902], 
             UndirectedEdge[416, 452] -> 
             RGBColor[
              0.7204300902810635, 0.7808112755336398, 0.9734367929802155], 
             UndirectedEdge[13, 87] -> 
             RGBColor[
              0.8747179087382527, 0.4193954992011085, 0.38395035975321834`], 
             UndirectedEdge[471, 497] -> 
             RGBColor[
              0.7872246216896541, 0.8312791006345767, 0.8650047597316065], 
             UndirectedEdge[17, 321] -> 
             RGBColor[
              0.9732568410274195, 0.921103104316672, 0.35242112502813433`], 
             UndirectedEdge[106, 227] -> 
             RGBColor[
              0.7012704936011454, 0.5896181833353824, 0.5893775775735776], 
             UndirectedEdge[37, 100] -> 
             RGBColor[
              0.9728133610137928, 0.9199552243524374, 0.34888547061491204`], 
             UndirectedEdge[9, 375] -> 
             RGBColor[
              0.692540425275251, 0.2754551937862024, 0.4259611601714183], 
             UndirectedEdge[10, 302] -> 
             RGBColor[
              0.8800451209804626, 0.5009866046085343, 0.43075213324362327`], 
             UndirectedEdge[14, 272] -> 
             RGBColor[
              0.9694056907361647, 0.9039670719329311, 0.50503427312253], 
             UndirectedEdge[63, 387] -> 
             RGBColor[
              0.5517640756849522, 0.6469859591862135, 0.957856035697777], 
             UndirectedEdge[471, 483] -> 
             RGBColor[
              0.5997735497068877, 0.6859622129993783, 0.9616355173572817], 
             UndirectedEdge[46, 392] -> 
             RGBColor[
              0.9008881860026512, 0.8794974834007927, 0.6460500399119541], 
             UndirectedEdge[122, 357] -> 
             RGBColor[
              0.8414244869126934, 0.876690693369351, 0.9698474220300836], 
             UndirectedEdge[75, 125] -> 
             RGBColor[
              0.9205364950243279, 0.7226607129544234, 0.2549200025296258], 
             UndirectedEdge[244, 261] -> 
             RGBColor[
              0.9292777246403675, 0.7680781719200032, 0.5729274906704935], 
             UndirectedEdge[7, 178] -> 
             RGBColor[
              0.859034450638099, 0.41193616425183494`, 0.2024874879156613], 
             UndirectedEdge[108, 487] -> 
             RGBColor[
              0.6726840267864236, 0.5481825441575174, 0.5834331001062729], 
             UndirectedEdge[338, 480] -> 
             RGBColor[
              0.9822521215668858, 0.9654324520007767, 0.6375144479422015], 
             UndirectedEdge[237, 284] -> 
             RGBColor[
              0.6443231785253649, 0.23304991252509769`, 0.42291230388595935`],
              UndirectedEdge[162, 456] -> 
             RGBColor[
              0.6251258235378176, 0.6984668990507428, 0.9600933895604838], 
             UndirectedEdge[104, 310] -> 
             RGBColor[
              0.9382991010440445, 0.7786778899242789, 0.31944254241840453`], 
             UndirectedEdge[168, 390] -> 
             RGBColor[
              0.9836192998420231, 0.9564061933751528, 0.3908645024322665], 
             UndirectedEdge[164, 431] -> 
             RGBColor[
              0.645896935798402, 0.6100471966276989, 0.6000716422927999], 
             UndirectedEdge[57, 60] -> 
             RGBColor[
              0.6103909555191838, 0.6932428482150546, 0.9633868763748603], 
             UndirectedEdge[158, 247] -> 
             RGBColor[
              0.6876907150585957, 0.7527299407943306, 0.9615758523147684], 
             UndirectedEdge[32, 475] -> 
             RGBColor[
              0.9556827575780282, 0.9638462187609207, 0.8376155322377126], 
             UndirectedEdge[53, 293] -> 
             RGBColor[
              0.8741310902135135, 0.902060639346923, 0.9639602504624964], 
             UndirectedEdge[72, 294] -> 
             RGBColor[
              0.9785114864879657, 0.9817998750508097, 0.8453706516945146], 
             UndirectedEdge[87, 287] -> 
             RGBColor[
              0.8747179087382527, 0.41939549920110863`, 0.38395035975321834`],
              UndirectedEdge[154, 374] -> 
             RGBColor[
              0.7626163572631104, 0.8103662223397196, 0.806693951936196], 
             UndirectedEdge[119, 364] -> 
             RGBColor[
              0.7070905626804926, 0.769139701171615, 0.9624749176890761], 
             UndirectedEdge[90, 342] -> 
             RGBColor[0.849751865380868, 0.882884624482799, 0.95491033871668],
              UndirectedEdge[401, 428] -> 
             RGBColor[
              0.8519832723570057, 0.8812126052837788, 0.7599871580016708], 
             UndirectedEdge[183, 477] -> 
             RGBColor[
              0.5157385266119585, 0.6112112282519169, 0.9571634013450392], 
             UndirectedEdge[82, 269] -> 
             RGBColor[
              0.676859777626816, 0.7449607059479433, 0.9703633623978724], 
             UndirectedEdge[202, 273] -> 
             RGBColor[
              0.8759215432856969, 0.4186536270685557, 0.2738967537823275], 
             UndirectedEdge[147, 242] -> 
             RGBColor[
              0.7207646263256509, 0.7809350497375875, 0.9736332638011135], 
             UndirectedEdge[117, 198] -> 
             RGBColor[
              0.812609929263225, 0.8513663016613686, 0.8444827582555812], 
             UndirectedEdge[240, 434] -> 
             RGBColor[
              0.7570520185887997, 0.8101340578207967, 0.9764195282257346], 
             UndirectedEdge[249, 310] -> 
             RGBColor[
              0.9071119714052032, 0.7639041661866152, 0.6104899432917198], 
             UndirectedEdge[448, 478] -> 
             RGBColor[
              0.9355114128488894, 0.7630084689478863, 0.3593936297393924], 
             UndirectedEdge[121, 196] -> 
             RGBColor[
              0.7475171817719453, 0.7972942234295637, 0.7388057222430955], 
             UndirectedEdge[200, 256] -> 
             RGBColor[
              0.7351654435074599, 0.7887906269505833, 0.851522008264864], 
             UndirectedEdge[79, 184] -> 
             RGBColor[
              0.8833396961779453, 0.5407251448802921, 0.43941150503001214`], 
             UndirectedEdge[51, 240] -> 
             RGBColor[
              0.7126729937737029, 0.7754648263421622, 0.9719962417777319], 
             UndirectedEdge[339, 387] -> 
             RGBColor[
              0.740764199014663, 0.7948896192296208, 0.9169122784039296], 
             UndirectedEdge[46, 142] -> 
             RGBColor[
              0.9643821012726796, 0.9293290952394822, 0.6244836167412497], 
             UndirectedEdge[233, 259] -> 
             RGBColor[
              0.9792145670945169, 0.9823668316809329, 0.8460882465221454], 
             UndirectedEdge[266, 471] -> 
             RGBColor[
              0.5532619060652398, 0.6482019653654207, 0.9579739503920466], 
             UndirectedEdge[167, 456] -> 
             RGBColor[
              0.930176869953182, 0.9469441658604156, 0.985656664363215], 
             UndirectedEdge[10, 181] -> 
             RGBColor[
              0.8689469458673809, 0.4156811674380433, 0.4201245082217401], 
             UndirectedEdge[31, 429] -> 
             RGBColor[
              0.6454235240130427, 0.715550504262118, 0.950567891647432], 
             UndirectedEdge[317, 322] -> 
             RGBColor[
              0.49573368173742605`, 0.5906057712887072, 0.9559575198420422], 
             UndirectedEdge[52, 466] -> 
             RGBColor[
              0.8715366968479757, 0.4525155829827585, 0.2121878023302584], 
             UndirectedEdge[207, 281] -> 
             RGBColor[
              0.9077097278219959, 0.9291284171778682, 0.9869440609516287], 
             UndirectedEdge[358, 398] -> 
             RGBColor[
              0.9390625302624276, 0.8101196402736759, 0.5795012453718013], 
             UndirectedEdge[155, 250] -> 
             RGBColor[
              0.8812594996215116, 0.9081564201190653, 0.9885365118551841], 
             UndirectedEdge[243, 285] -> 
             RGBColor[
              0.9876472231533051, 0.9870387299833171, 0.7100814867459662], 
             UndirectedEdge[378, 452] -> 
             RGBColor[
              0.9152384781479264, 0.9346913619376791, 0.9723975011351758], 
             UndirectedEdge[100, 264] -> 
             RGBColor[
              0.8094015941490724, 0.8108682982151583, 0.6413536848522172], 
             UndirectedEdge[81, 130] -> 
             RGBColor[
              0.9933373266638834, 0.9881575403706815, 0.5161873084963967], 
             UndirectedEdge[1, 120] -> 
             RGBColor[
              0.9923975383855921, 0.9894800058963162, 0.6561403670180064], 
             UndirectedEdge[390, 422] -> 
             RGBColor[
              0.9762227412743096, 0.9653766315665324, 0.6622166308182268], 
             UndirectedEdge[118, 255] -> 
             RGBColor[
              0.861880141669753, 0.4104107564382823, 0.4320867644106019], 
             UndirectedEdge[137, 229] -> 
             RGBColor[
              0.92653870913575, 0.9275410219002449, 0.6890858596851184], 
             UndirectedEdge[367, 375] -> 
             RGBColor[
              0.8246507512702025, 0.19048205305666902`, 0.17123889329637462`],
              UndirectedEdge[230, 382] -> 
             RGBColor[
              0.9043061053038208, 0.794053454905553, 0.6166628108602961], 
             UndirectedEdge[114, 334] -> 
             RGBColor[
              0.9923844521451002, 0.9911187894984157, 0.7758728665691643], 
             UndirectedEdge[52, 170] -> 
             RGBColor[
              0.9649263830555, 0.8900425878534226, 0.33547421192181154`], 
             UndirectedEdge[4, 389] -> 
             RGBColor[
              0.902187945552219, 0.6317565815588821, 0.2579971555062917], 
             UndirectedEdge[190, 378] -> 
             RGBColor[
              0.9481253125733577, 0.8815495293352567, 0.6133562073192933], 
             UndirectedEdge[89, 328] -> 
             RGBColor[
              0.7394505545229789, 0.36381452351886195`, 0.43600593656673325`],
              UndirectedEdge[93, 300] -> 
             RGBColor[
              0.8128783552069344, 0.8510923882102911, 0.8041932818873463], 
             UndirectedEdge[104, 125] -> 
             RGBColor[
              0.9531517739306932, 0.8422777940772792, 0.33163720228103244`], 
             UndirectedEdge[59, 228] -> 
             RGBColor[
              0.8758087454125018, 0.41984658819913434`, 0.3658723730660921], 
             UndirectedEdge[96, 136] -> 
             RGBColor[
              0.8762889945437953, 0.4194395681546069, 0.3138915555800298], 
             UndirectedEdge[332, 420] -> 
             RGBColor[
              0.8858986981498622, 0.9118555910978826, 0.9889790027522796], 
             UndirectedEdge[40, 283] -> 
             RGBColor[
              0.7458307374362068, 0.8013679076994957, 0.9753010957892785], 
             UndirectedEdge[17, 288] -> 
             RGBColor[
              0.7848489494300432, 0.826009584133105, 0.6911417156329398], 
             UndirectedEdge[325, 413] -> 
             RGBColor[
              0.7617325940668632, 0.8140899008888084, 0.976979024405074], 
             UndirectedEdge[421, 459] -> 
             RGBColor[
              0.7049472648536781, 0.6561073662663508, 0.6031524882050401], 
             UndirectedEdge[148, 342] -> 
             RGBColor[
              0.8039056210826716, 0.8472056884406141, 0.9809649355157049], 
             UndirectedEdge[262, 478] -> 
             RGBColor[
              0.8374937857442898, 0.2688170134169282, 0.18273928058428096`], 
             UndirectedEdge[133, 405] -> 
             RGBColor[
              0.8534440632982794, 0.38937050112402993`, 0.19793311587798199`],
              UndirectedEdge[374, 397] -> 
             RGBColor[
              0.9914499817626465, 0.98150644156926, 0.5330591698012528], 
             UndirectedEdge[151, 389] -> 
             RGBColor[
              0.964371150565466, 0.9449604002941161, 0.6577017927934778], 
             UndirectedEdge[235, 305] -> 
             RGBColor[
              0.7990422427044047, 0.47734943831090854`, 0.4496032443440757], 
             UndirectedEdge[204, 348] -> 
             RGBColor[
              0.8713322290907669, 0.4174601077605018, 0.4160868459060477], 
             UndirectedEdge[191, 429] -> 
             RGBColor[
              0.9336219753110542, 0.8255419035970288, 0.6028450396692051], 
             UndirectedEdge[15, 414] -> 
             RGBColor[
              0.971266919628012, 0.977809685702083, 0.9209017388391181], 
             UndirectedEdge[277, 414] -> 
             RGBColor[
              0.9900408035893531, 0.9901496305915937, 0.8147131883059316], 
             UndirectedEdge[317, 440] -> 
             RGBColor[
              0.6911506786877725, 0.7586514302213803, 0.969851098547436], 
             UndirectedEdge[76, 182] -> 
             RGBColor[
              0.7854998523738358, 0.8324665349710678, 0.9792260667634781], 
             UndirectedEdge[199, 376] -> 
             RGBColor[
              0.8330977252129077, 0.8675910959824173, 0.848370381303561], 
             UndirectedEdge[375, 402] -> 
             RGBColor[
              0.8644396829505392, 0.41231965813462834`, 0.4277541286575116], 
             UndirectedEdge[45, 195] -> 
             RGBColor[
              0.9673094639871777, 0.9273002283746299, 0.6105868870659672], 
             UndirectedEdge[149, 269] -> 
             RGBColor[
              0.920928084496231, 0.939787072923115, 0.9923201368930985], 
             UndirectedEdge[45, 152] -> 
             RGBColor[
              0.8645337860296493, 0.3804966374505337, 0.20783894153515964`], 
             UndirectedEdge[356, 494] -> 
             RGBColor[
              0.9109253227002763, 0.9306240323392576, 0.9502082209868015], 
             UndirectedEdge[44, 360] -> 
             RGBColor[
              0.6773246995078259, 0.7122046721364279, 0.6466888752016084], 
             UndirectedEdge[284, 432] -> 
             RGBColor[
              0.6461714628502211, 0.7102475157648183, 0.7649279339941375], 
             UndirectedEdge[151, 237] -> 
             RGBColor[
              0.8631019898511022, 0.41132200881133973`, 0.43001849414862137`],
              UndirectedEdge[207, 343] -> 
             RGBColor[
              0.7773745938845954, 0.8264558318477, 0.9783268377647694], 
             UndirectedEdge[33, 371] -> 
             RGBColor[
              0.7920724772344276, 0.833705501263388, 0.7619247723676696], 
             UndirectedEdge[280, 480] -> 
             RGBColor[
              0.9125864391954437, 0.9112706943172133, 0.6801858663443964], 
             UndirectedEdge[420, 454] -> 
             RGBColor[
              0.9076859229000137, 0.9292281327151921, 0.9910570876986341], 
             UndirectedEdge[267, 393] -> 
             RGBColor[
              0.8698671141037027, 0.39848720536929877`, 0.22855791398836042`],
              UndirectedEdge[337, 427] -> 
             RGBColor[
              0.9947161639737907, 0.9911067339547361, 0.6662652404822922], 
             UndirectedEdge[267, 480] -> 
             RGBColor[
              0.8714116780481608, 0.40369738223481644`, 0.23455825324615384`],
              UndirectedEdge[234, 336] -> 
             RGBColor[
              0.8444384077770778, 0.3967662800712274, 0.43954460996386757`], 
             UndirectedEdge[122, 492] -> 
             RGBColor[
              0.8087461387559114, 0.8510578010578591, 0.9814286411807689], 
             UndirectedEdge[80, 272] -> 
             RGBColor[
              0.7112548812654179, 0.701656212053817, 0.6129571233087319], 
             UndirectedEdge[331, 444] -> 
             RGBColor[
              0.9520328635064552, 0.9168193311550286, 0.63838296811366], 
             UndirectedEdge[77, 184] -> 
             RGBColor[
              0.9796116898909382, 0.9828099446257728, 0.85199626836527], 
             UndirectedEdge[266, 359] -> 
             RGBColor[
              0.6946557276243488, 0.7599488315556422, 0.9713359830751747], 
             UndirectedEdge[32, 478] -> 
             RGBColor[
              0.9363581699822436, 0.7648195968358524, 0.4515579181257206], 
             UndirectedEdge[14, 447] -> 
             RGBColor[
              0.7227866477973139, 0.7784937510775864, 0.8430930416310596], 
             UndirectedEdge[16, 358] -> 
             RGBColor[
              0.9022214167545588, 0.7818496298799497, 0.6143362628016072], 
             UndirectedEdge[50, 323] -> 
             RGBColor[
              0.6843244425488095, 0.7530901095771645, 0.969327027142892], 
             UndirectedEdge[92, 365] -> 
             RGBColor[
              0.8869531707893978, 0.5448621525472668, 0.4338455067524504], 
             UndirectedEdge[296, 438] -> 
             RGBColor[
              0.9681747853181681, 0.9757853875160718, 0.9387559664976974], 
             UndirectedEdge[181, 422] -> 
             RGBColor[
              0.8680655014862798, 0.4150237876618507, 0.42161656364143074`], 
             UndirectedEdge[35, 428] -> 
             RGBColor[
              0.7445414108938777, 0.7950277675742696, 0.7508169947505443], 
             UndirectedEdge[19, 298] -> 
             RGBColor[
              0.7536649620773319, 0.8074755362711942, 0.9764183765277765], 
             UndirectedEdge[209, 348] -> 
             RGBColor[
              0.8260196543366713, 0.38207966604159066`, 0.4377878128181064], 
             UndirectedEdge[27, 194] -> 
             RGBColor[
              0.9672180951362596, 0.906075184106552, 0.5560309803266663], 
             UndirectedEdge[253, 287] -> 
             RGBColor[
              0.8489630856771142, 0.40037413540960676`, 0.4399761777812008], 
             UndirectedEdge[412, 476] -> 
             RGBColor[
              0.8149488768182793, 0.8554644904318234, 0.9397090959187044], 
             UndirectedEdge[221, 336] -> 
             RGBColor[
              0.9310136731027414, 0.9050391701237303, 0.6511602036584807], 
             UndirectedEdge[146, 248] -> 
             RGBColor[
              0.9161233330567725, 0.9359558945467942, 0.9918618554115508], 
             UndirectedEdge[17, 455] -> 
             RGBColor[
              0.9050400091986646, 0.920890108819141, 0.7024468607096868], 
             UndirectedEdge[102, 393] -> 
             RGBColor[
              0.8261595471590022, 0.8375411723804251, 0.6628569455709434], 
             UndirectedEdge[80, 497] -> 
             RGBColor[
              0.7356126692389366, 0.7893781925431228, 0.8609416777738748], 
             UndirectedEdge[108, 416] -> 
             RGBColor[
              0.7200617559028762, 0.5866459189966275, 0.5871628484926601], 
             UndirectedEdge[8, 453] -> 
             RGBColor[
              0.6619761517535669, 0.7269316719110952, 0.8799767318043157], 
             UndirectedEdge[58, 402] -> 
             RGBColor[
              0.6358065472644088, 0.7070863583863511, 0.9479935585507555], 
             UndirectedEdge[95, 357] -> 
             RGBColor[
              0.9702852192977015, 0.9682326454052455, 0.6877303017953237], 
             UndirectedEdge[183, 283] -> 
             RGBColor[
              0.4892246253377166, 0.590498367063366, 0.9545207434525174], 
             UndirectedEdge[179, 294] -> 
             RGBColor[
              0.7116106973850691, 0.768900558823814, 0.8455732699785657], 
             UndirectedEdge[136, 240] -> 
             RGBColor[
              0.7821751710392534, 0.3477017342946218, 0.43345131746889387`], 
             UndirectedEdge[153, 289] -> 
             RGBColor[
              0.972172341280227, 0.9781569334782008, 0.9046799496749531], 
             UndirectedEdge[73, 200] -> 
             RGBColor[
              0.9943013566502633, 0.9914304994865644, 0.709142681444078], 
             UndirectedEdge[196, 447] -> 
             RGBColor[
              0.7221018922843033, 0.7765925066599112, 0.7368238476809414], 
             UndirectedEdge[68, 492] -> 
             RGBColor[
              0.6001014523638235, 0.679225538459497, 0.9651275674329793], 
             UndirectedEdge[25, 413] -> 
             RGBColor[
              0.7703747955314966, 0.8209809577503976, 0.977803325295755], 
             UndirectedEdge[220, 426] -> 
             RGBColor[
              0.6632374376273975, 0.7347138728926952, 0.968549755144003], 
             UndirectedEdge[21, 354] -> 
             RGBColor[
              0.8285249039573377, 0.866661701045105, 0.9710046214527668], 
             UndirectedEdge[125, 269] -> 
             RGBColor[
              0.9130653790643601, 0.820408037811333, 0.6218357832924817], 
             UndirectedEdge[241, 304] -> 
             RGBColor[
              0.7039992767870622, 0.7441598717865663, 0.6618785518146485], 
             UndirectedEdge[93, 456] -> 
             RGBColor[
              0.9693264262053565, 0.9742669584672362, 0.8118582088154948], 
             UndirectedEdge[295, 455] -> 
             RGBColor[
              0.7556192424118362, 0.8090147621818505, 0.9762767224864695], 
             UndirectedEdge[185, 386] -> 
             RGBColor[
              0.9700624856183839, 0.9741675467911365, 0.7591673752244846], 
             UndirectedEdge[233, 400] -> 
             RGBColor[
              0.8762578943105568, 0.42003232281108027`, 0.3584288134652338], 
             UndirectedEdge[83, 317] -> 
             RGBColor[
              0.7019072073098345, 0.7670545121335806, 0.970923208795008], 
             UndirectedEdge[88, 465] -> 
             RGBColor[
              0.8542090339238055, 0.40455711214404666`, 0.4404765410080834], 
             UndirectedEdge[418, 431] -> 
             RGBColor[
              0.787419152900613, 0.7270063379641256, 0.6107138340015754], 
             UndirectedEdge[121, 307] -> 
             RGBColor[
              0.7252088668496959, 0.7838056408198106, 0.9627394651426529], 
             UndirectedEdge[64, 74] -> 
             RGBColor[
              0.9430178034194723, 0.9570233516068016, 0.9813401748604789], 
             UndirectedEdge[185, 358] -> 
             RGBColor[
              0.9230373459568153, 0.7981680840573814, 0.6066277023637481], 
             UndirectedEdge[113, 315] -> 
             RGBColor[
              0.9911741621097202, 0.9906183034657509, 0.7959305045856191], 
             UndirectedEdge[47, 91] -> 
             RGBColor[
              0.7004692578075487, 0.7646577418734546, 0.9718060477332893], 
             UndirectedEdge[158, 401] -> 
             RGBColor[
              0.8286574554539151, 0.8668083263643991, 0.9731982865844102], 
             UndirectedEdge[90, 232] -> 
             RGBColor[
              0.8962186364725392, 0.6288033055241955, 0.4483360556900343], 
             UndirectedEdge[58, 115] -> 
             RGBColor[
              0.46816656802188217`, 0.575305928642149, 0.9523281475187606], 
             UndirectedEdge[132, 494] -> 
             RGBColor[
              0.8070772351100772, 0.8493768637466615, 0.9813623916670675], 
             UndirectedEdge[167, 300] -> 
             RGBColor[
              0.77372879895476, 0.8237695956034705, 0.9779917374350666], 
             UndirectedEdge[284, 389] -> 
             RGBColor[
              0.63620293357686, 0.6775522558647531, 0.6470425073994849], 
             UndirectedEdge[103, 233] -> 
             RGBColor[
              0.9793770232711276, 0.9420772711338824, 0.5319499467972785], 
             UndirectedEdge[172, 300] -> 
             RGBColor[
              0.7531381187427145, 0.6184744949133729, 0.590775112033496], 
             UndirectedEdge[70, 76] -> 
             RGBColor[
              0.8366503372383217, 0.8732512906734409, 0.9840614212088977], 
             UndirectedEdge[57, 73] -> 
             RGBColor[
              0.7428672702343893, 0.7943938059290538, 0.8101209240572615], 
             UndirectedEdge[287, 473] -> 
             RGBColor[
              0.8679520302005795, 0.4149391609627677, 0.4218086409300702], 
             UndirectedEdge[395, 443] -> 
             RGBColor[
              0.5924348673233211, 0.6574232260158497, 0.908324116527102], 
             UndirectedEdge[100, 397] -> 
             RGBColor[
              0.9763755277575477, 0.931971249215649, 0.3627238157556555], 
             UndirectedEdge[57, 234] -> 
             RGBColor[
              0.7085493589986231, 0.28863904203798835`, 0.4271697527905808], 
             UndirectedEdge[343, 403] -> 
             RGBColor[
              0.6138157755640681, 0.6967913548721252, 0.96313134789903], 
             UndirectedEdge[105, 425] -> 
             RGBColor[
              0.7713593898144857, 0.8179222978760827, 0.8438281612473979], 
             UndirectedEdge[133, 423] -> 
             RGBColor[
              0.8825323163420028, 0.5071994841413109, 0.23297517150386132`], 
             UndirectedEdge[92, 494] -> 
             RGBColor[
              0.9081530647922974, 0.9285564869306427, 0.9549009305043473], 
             UndirectedEdge[51, 100] -> 
             RGBColor[
              0.8389712126404403, 0.833968308918039, 0.644300908079641], 
             UndirectedEdge[6, 347] -> 
             RGBColor[
              0.7615640611151557, 0.8136588997351795, 0.976869246457327], 
             UndirectedEdge[333, 461] -> 
             RGBColor[
              0.7347065613754882, 0.792089585204848, 0.9749197639496601], 
             UndirectedEdge[291, 394] -> 
             RGBColor[
              0.9910828585363773, 0.9905805470917788, 0.7974436410819838], 
             UndirectedEdge[143, 386] -> 
             RGBColor[
              0.9942525382546761, 0.990425842091651, 0.6383911715432151], 
             UndirectedEdge[123, 437] -> 
             RGBColor[
              0.6632022472993598, 0.7354394003118732, 0.9680079500561725], 
             UndirectedEdge[72, 453] -> 
             RGBColor[
              0.9762534053459628, 0.980866100468553, 0.8827928999441728], 
             UndirectedEdge[391, 478] -> 
             RGBColor[
              0.93646520269638, 0.7650485289887226, 0.46320776853011214`], 
             UndirectedEdge[328, 464] -> 
             RGBColor[
              0.7349301741003873, 0.36014467505098463`, 0.43565007566116776`],
              UndirectedEdge[149, 173] -> 
             RGBColor[
              0.6920449639595923, 0.7572629642103839, 0.9717224288481764], 
             UndirectedEdge[54, 186] -> 
             RGBColor[
              0.8692900678012243, 0.8523142756703963, 0.6395257440059887], 
             UndirectedEdge[355, 444] -> 
             RGBColor[
              0.8370898556321273, 0.8734413183443264, 0.9763438184402509], 
             UndirectedEdge[7, 448] -> 
             RGBColor[
              0.9462174752294414, 0.8116221977535762, 0.3683270306193279], 
             UndirectedEdge[47, 416] -> 
             RGBColor[
              0.7168667488891289, 0.7779699638320365, 0.9730969182972203], 
             UndirectedEdge[48, 155] -> 
             RGBColor[
              0.7572184575369396, 0.8104206405282177, 0.9766288125513681], 
             UndirectedEdge[346, 486] -> 
             RGBColor[
              0.6315684481689305, 0.7105662303491072, 0.9649647955578695], 
             UndirectedEdge[24, 491] -> 
             RGBColor[
              0.9463283128139571, 0.810489025330688, 0.4857136083137267], 
             UndirectedEdge[321, 373] -> 
             RGBColor[
              0.9133707228259375, 0.6849550219768594, 0.24867339232493144`], 
             UndirectedEdge[209, 231] -> 
             RGBColor[
              0.8260196543366713, 0.38207966604159066`, 0.4377878128181064], 
             UndirectedEdge[210, 393] -> 
             RGBColor[
              0.852367588176803, 0.8580150932120203, 0.6654691181715298], 
             UndirectedEdge[188, 409] -> 
             RGBColor[
              0.7341250622794235, 0.7605874793294847, 0.6511259866843584], 
             UndirectedEdge[307, 427] -> 
             RGBColor[
              0.9718156457648355, 0.9763514883956561, 0.825741310278955], 
             UndirectedEdge[178, 186] -> 
             RGBColor[
              0.8186879609396371, 0.4756838419737526, 0.44944759254134414`], 
             UndirectedEdge[328, 475] -> 
             RGBColor[
              0.8576628751478539, 0.4575050551077786, 0.4470881348457081], 
             UndirectedEdge[213, 337] -> 
             RGBColor[
              0.9897905221705061, 0.9894498240486739, 0.7755156483691985], 
             UndirectedEdge[384, 458] -> 
             RGBColor[
              0.8101042295847105, 0.852271330222898, 0.9691686207822925], 
             UndirectedEdge[87, 473] -> 
             RGBColor[
              0.9793669084082484, 0.9832479902458144, 0.8802025010249328], 
             UndirectedEdge[112, 440] -> 
             RGBColor[
              0.7253702280314072, 0.7853840022468352, 0.9732617834261394], 
             UndirectedEdge[237, 429] -> 
             RGBColor[
              0.8636951741962698, 0.4117644047247154, 0.4290143877795076], 
             UndirectedEdge[109, 230] -> 
             RGBColor[
              0.8502392990057036, 0.33774437293541676`, 0.19380457885682087`],
              UndirectedEdge[89, 262] -> 
             RGBColor[
              0.7321645235166045, 0.3078108964447237, 0.4290288250466342], 
             UndirectedEdge[280, 383] -> 
             RGBColor[
              0.8600832398292839, 0.7015652160427077, 0.6011003319422343], 
             UndirectedEdge[196, 489] -> 
             RGBColor[
              0.9457203524407375, 0.9549187180908663, 0.7569194077189818], 
             UndirectedEdge[279, 459] -> 
             RGBColor[
              0.6670464329108152, 0.6243164277412323, 0.600450993987453], 
             UndirectedEdge[191, 423] -> 
             RGBColor[
              0.9389285350700445, 0.7922972728481981, 0.2868100799854524], 
             UndirectedEdge[116, 165] -> 
             RGBColor[
              0.7183488993135905, 0.7798988868884023, 0.972561962997595], 
             UndirectedEdge[176, 313] -> 
             RGBColor[
              0.8178712877590688, 0.8566946625620538, 0.8921323937728376], 
             UndirectedEdge[180, 490] -> 
             RGBColor[
              0.7953002990547539, 0.8400139052184983, 0.9802317593720781], 
             UndirectedEdge[17, 498] -> 
             RGBColor[
              0.8754552550224864, 0.41733731684624076`, 0.2502667862259708], 
             UndirectedEdge[108, 364] -> 
             RGBColor[
              0.9099215026838265, 0.7368353169814494, 0.5945003151937653], 
             UndirectedEdge[29, 254] -> 
             RGBColor[
              0.9483591764851438, 0.9379007644382439, 0.6808113745984048], 
             UndirectedEdge[7, 261] -> 
             RGBColor[
              0.9382942321989838, 0.8090200268848371, 0.5804510855922276], 
             UndirectedEdge[122, 224] -> 
             RGBColor[
              0.5909073363648367, 0.6773506897504912, 0.961879489675832], 
             UndirectedEdge[116, 386] -> 
             RGBColor[
              0.8612431111641765, 0.888413708571945, 0.7582867304388847], 
             UndirectedEdge[8, 439] -> 
             RGBColor[
              0.5075717494804984, 0.6072779887471818, 0.9556770467458569], 
             UndirectedEdge[226, 488] -> 
             RGBColor[
              0.6865423162024923, 0.7526812993826794, 0.9712868915709245], 
             UndirectedEdge[64, 170] -> 
             RGBColor[
              0.9657566495417029, 0.960447061065532, 0.6860382478780492], 
             UndirectedEdge[178, 313] -> 
             RGBColor[
              0.7746011273646871, 0.44124287251265637`, 0.4450534289854769], 
             UndirectedEdge[81, 251] -> 
             RGBColor[
              0.9440182458138546, 0.801001015871388, 0.3950469714777858], 
             UndirectedEdge[186, 288] -> 
             RGBColor[
              0.6780930733456075, 0.7474643743777029, 0.9692240149888649], 
             UndirectedEdge[45, 118] -> 
             RGBColor[
              0.9549828915491033, 0.9181070908332238, 0.6314525589186424], 
             UndirectedEdge[224, 330] -> 
             RGBColor[
              0.6552203605090309, 0.7279105829022585, 0.9682052049132325], 
             UndirectedEdge[35, 410] -> 
             RGBColor[
              0.7155769007685916, 0.7764181604822891, 0.9735729601517348], 
             UndirectedEdge[163, 379] -> 
             RGBColor[
              0.9371654028721985, 0.9521597340533294, 0.9739493502212343], 
             UndirectedEdge[181, 443] -> 
             RGBColor[
              0.873539349929427, 0.41890813484607925`, 0.4034821292278887], 
             UndirectedEdge[167, 235] -> 
             RGBColor[
              0.8140512588699029, 0.8554400969242252, 0.9818942757669822], 
             UndirectedEdge[202, 279] -> 
             RGBColor[
              0.7044148093758748, 0.7610948245858248, 0.7204817330504992], 
             UndirectedEdge[242, 310] -> 
             RGBColor[
              0.7179308222350962, 0.6138091380912287, 0.5928505726362228], 
             UndirectedEdge[299, 482] -> 
             RGBColor[
              0.8640464961730364, 0.41202642007975104`, 0.4284196913122883], 
             UndirectedEdge[56, 110] -> 
             RGBColor[
              0.8861774813073579, 0.9114664404113664, 0.9649113048997542], 
             UndirectedEdge[125, 419] -> 
             RGBColor[
              0.9548059035067513, 0.8509331789833521, 0.5170170661355027], 
             UndirectedEdge[262, 448] -> 
             RGBColor[
              0.8759391561549698, 0.4186912992149959, 0.2758138059086473], 
             UndirectedEdge[95, 212] -> 
             RGBColor[
              0.869555173749861, 0.8888973462071528, 0.6926720375635419], 
             UndirectedEdge[32, 260] -> 
             RGBColor[
              0.9897007613597346, 0.9754577136538451, 0.5388653616009067], 
             UndirectedEdge[421, 430] -> 
             RGBColor[
              0.7172278825100327, 0.7775191292251649, 0.9672826294106053], 
             UndirectedEdge[129, 346] -> 
             RGBColor[
              0.4874273604037645, 0.5942019676094111, 0.9529438843943873], 
             UndirectedEdge[16, 17] -> 
             RGBColor[
              0.9483187908656481, 0.9553862457482916, 0.7065783294427403], 
             UndirectedEdge[153, 466] -> 
             RGBColor[
              0.8754385269409607, 0.5019490693615368, 0.4402293287759057], 
             UndirectedEdge[244, 391] -> 
             RGBColor[
              0.9381547575183158, 0.7727204028295788, 0.46461757448831376`], 
             UndirectedEdge[218, 406] -> 
             RGBColor[
              0.8060083133194686, 0.846096230900659, 0.8484109426221227], 
             UndirectedEdge[99, 288] -> 
             RGBColor[
              0.7686709002770213, 0.8187406269188588, 0.956788211290606], 
             UndirectedEdge[399, 481] -> 
             RGBColor[
              0.7636301018260905, 0.6347191679279488, 0.5932440670579038], 
             UndirectedEdge[278, 451] -> 
             RGBColor[
              0.7839058355238274, 0.8314721552750908, 0.9790006146519643], 
             UndirectedEdge[179, 327] -> 
             RGBColor[
              0.7085250315763644, 0.7676245567139204, 0.8967107378759368], 
             UndirectedEdge[38, 473] -> 
             RGBColor[
              0.6200910299272135, 0.6893470865268854, 0.9378661460163285], 
             UndirectedEdge[17, 176] -> 
             RGBColor[
              0.9907574142059294, 0.9869013265091003, 0.6206413397507132], 
             UndirectedEdge[186, 373] -> 
             RGBColor[
              0.8250857707815415, 0.6690646584435072, 0.5966989253306347], 
             UndirectedEdge[399, 496] -> 
             RGBColor[
              0.723170705312199, 0.6019593663511859, 0.5899995006847392], 
             UndirectedEdge[116, 358] -> 
             RGBColor[
              0.8142179715026079, 0.7124142458381899, 0.6057470575781483], 
             UndirectedEdge[71, 135] -> 
             RGBColor[
              0.9767696799453613, 0.9321135020972446, 0.4652157198612545], 
             UndirectedEdge[53, 374] -> 
             RGBColor[
              0.9784890157007003, 0.9811831122970233, 0.802910986713182], 
             UndirectedEdge[228, 409] -> 
             RGBColor[
              0.7100297590980085, 0.28984089752993386`, 0.42728629530928863`],
              UndirectedEdge[440, 471] -> 
             RGBColor[
              0.6171138454136419, 0.6998840467795379, 0.9631071298870444], 
             UndirectedEdge[403, 471] -> 
             RGBColor[
              0.5648490273713084, 0.6576089124355533, 0.9588861310262843], 
             UndirectedEdge[63, 166] -> 
             RGBColor[
              0.6751702946192855, 0.7456422742858391, 0.9686173769062305], 
             UndirectedEdge[159, 272] -> 
             RGBColor[
              0.9671134845442342, 0.9030191857655558, 0.5430220617622866], 
             UndirectedEdge[130, 351] -> 
             RGBColor[
              0.9325603775466107, 0.9441302182028277, 0.7317429924087122], 
             UndirectedEdge[113, 378] -> 
             RGBColor[
              0.972251641397064, 0.9783381346262169, 0.9100117778908883], 
             UndirectedEdge[145, 417] -> 
             RGBColor[
              0.9470459559993032, 0.9581792365442476, 0.9000849379109763], 
             UndirectedEdge[38, 354] -> 
             RGBColor[
              0.6101884327731497, 0.6819617457833992, 0.9546286599871798], 
             UndirectedEdge[334, 446] -> 
             RGBColor[
              0.9807607579973796, 0.9842098694039103, 0.8743656806949175], 
             UndirectedEdge[305, 310] -> 
             RGBColor[
              0.8577003240724222, 0.4136284555975567, 0.20167774030087252`], 
             UndirectedEdge[338, 383] -> 
             RGBColor[
              0.9297489222007261, 0.7557269737262711, 0.5584289135400395], 
             UndirectedEdge[243, 477] -> 
             RGBColor[
              0.8574760058900954, 0.8887005048335743, 0.9446310668619566], 
             UndirectedEdge[38, 221] -> 
             RGBColor[
              0.6171570460634691, 0.645082095099623, 0.6254324733339024], 
             UndirectedEdge[330, 357] -> 
             RGBColor[
              0.9057375110568875, 0.9272505865211184, 0.976173137267484], 
             UndirectedEdge[48, 365] -> 
             RGBColor[
              0.7634923024048355, 0.44789468229489676`, 0.4461524719964135], 
             UndirectedEdge[384, 411] -> 
             RGBColor[
              0.8744829390078857, 0.5109588281371379, 0.4455594813721977], 
             UndirectedEdge[38, 436] -> 
             RGBColor[
              0.6326757073133445, 0.6962671641369006, 0.7846143093768058], 
             UndirectedEdge[117, 155] -> 
             RGBColor[
              0.7692973852267815, 0.8202268581763227, 0.9775797099856826], 
             UndirectedEdge[68, 286] -> 
             RGBColor[
              0.6030257752884232, 0.6815573141809415, 0.9654064919641016], 
             UndirectedEdge[378, 380] -> 
             RGBColor[
              0.7739430988908129, 0.8230867603915217, 0.958971460528564], 
             UndirectedEdge[12, 285] -> 
             RGBColor[
              0.923981077130285, 0.9374686141341345, 0.7454591035713727], 
             UndirectedEdge[93, 432] -> 
             RGBColor[
              0.994262753625371, 0.9901369350662848, 0.6169143221811197], 
             UndirectedEdge[340, 499] -> 
             RGBColor[
              0.5389003508634052, 0.6347934183067514, 0.9575123717037051], 
             UndirectedEdge[389, 456] -> 
             RGBColor[
              0.9591065334309719, 0.9410340574552297, 0.6666134163701196], 
             UndirectedEdge[390, 451] -> 
             RGBColor[
              0.9236863943511175, 0.9243587179802075, 0.6874780965678062], 
             UndirectedEdge[92, 485] -> 
             RGBColor[
              0.7627890005968545, 0.8134100629677927, 0.9414293052137248], 
             UndirectedEdge[293, 471] -> 
             RGBColor[
              0.6838075876906481, 0.7519857051375501, 0.9697545388287594], 
             UndirectedEdge[111, 359] -> 
             RGBColor[
              0.8649946611799857, 0.8951872794430706, 0.9869851570448387], 
             UndirectedEdge[357, 441] -> 
             RGBColor[
              0.9730342955471178, 0.9777917904616478, 0.8580811642713008], 
             UndirectedEdge[52, 268] -> 
             RGBColor[
              0.9696273255545256, 0.9053745350273981, 0.5078000234908935], 
             UndirectedEdge[30, 311] -> 
             RGBColor[
              0.7519774934517425, 0.804864521368519, 0.9467934188281464], 
             UndirectedEdge[164, 486] -> 
             RGBColor[
              0.5460202466120541, 0.6388735239242003, 0.9588492736907872], 
             UndirectedEdge[194, 290] -> 
             RGBColor[
              0.7005982640871137, 0.760649446687145, 0.8921867432509609], 
             UndirectedEdge[238, 445] -> 
             RGBColor[
              0.704442047182428, 0.7651716906849958, 0.9324705569869627], 
             UndirectedEdge[269, 406] -> 
             RGBColor[
              0.7628292507158064, 0.81497621723021, 0.9770699599287849], 
             UndirectedEdge[99, 341] -> 
             RGBColor[
              0.9536542306439839, 0.9649559816152913, 0.9633354779938946], 
             UndirectedEdge[41, 457] -> 
             RGBColor[
              0.7958473573857894, 0.8079412256837122, 0.6518909226030107], 
             UndirectedEdge[217, 292] -> 
             RGBColor[
              0.7606431399120113, 0.8129394690920224, 0.9767774576382955], 
             UndirectedEdge[176, 299] -> 
             RGBColor[
              0.8748083544481332, 0.41943290082649287`, 0.38245144027450473`],
              UndirectedEdge[218, 314] -> 
             RGBColor[
              0.9949217803409345, 0.9921680399137535, 0.7338227719693111], 
             UndirectedEdge[355, 486] -> 
             RGBColor[
              0.7255110496363872, 0.7854940131549295, 0.9732758192076711], 
             UndirectedEdge[213, 420] -> 
             RGBColor[
              0.9477261481977584, 0.9597514142493937, 0.944867760426608], 
             UndirectedEdge[299, 407] -> 
             RGBColor[
              0.8042483853602121, 0.36494549708479707`, 0.4356513691864914], 
             UndirectedEdge[201, 314] -> 
             RGBColor[
              0.9558005954608836, 0.8497683491734579, 0.4928196369091463], 
             UndirectedEdge[160, 300] -> 
             RGBColor[
              0.8130669793814727, 0.851495836246799, 0.8247238592323656], 
             UndirectedEdge[21, 200] -> 
             RGBColor[
              0.850757580724341, 0.8816335569589326, 0.8613055326594978], 
             UndirectedEdge[25, 180] -> 
             RGBColor[
              0.8487718832558847, 0.8826375062121236, 0.9853354267100609], 
             UndirectedEdge[45, 185] -> 
             RGBColor[
              0.9527525165786489, 0.9164436808321628, 0.6352280019686645], 
             UndirectedEdge[191, 226] -> 
             RGBColor[
              0.9193625801591307, 0.8147068962311195, 0.6200353904643134], 
             UndirectedEdge[50, 82] -> 
             RGBColor[
              0.5931847765800077, 0.678877202800532, 0.9622134130894401], 
             UndirectedEdge[22, 491] -> 
             RGBColor[
              0.7141723641713045, 0.629297009951938, 0.5963118269584712], 
             UndirectedEdge[99, 277] -> 
             RGBColor[
              0.9767825066540639, 0.9805434249650886, 0.849776077529527], 
             UndirectedEdge[17, 391] -> 
             RGBColor[
              0.9934074066136749, 0.9878289841326913, 0.5644990269926469], 
             UndirectedEdge[211, 362] -> 
             RGBColor[
              0.8875029114039308, 0.8282647187111015, 0.6257211981488042], 
             UndirectedEdge[4, 162] -> 
             RGBColor[
              0.679534138956783, 0.47004514262255764`, 0.45365047096653455`], 
             UndirectedEdge[259, 444] -> 
             RGBColor[
              0.9543506642395602, 0.9654753806505668, 0.9621565975755565], 
             UndirectedEdge[347, 382] -> 
             RGBColor[
              0.8588392988894376, 0.890324276911991, 0.9863860806220127], 
             UndirectedEdge[66, 179] -> 
             RGBColor[
              0.5795548093069096, 0.6675359603718907, 0.9611483886312412], 
             UndirectedEdge[343, 471] -> 
             RGBColor[
              0.6306649156869966, 0.7104702458690312, 0.9644577739299408], 
             UndirectedEdge[97, 322] -> 
             RGBColor[
              0.3378195185920887, 0.4626738830477113, 0.9429058187387744], 
             UndirectedEdge[363, 381] -> 
             RGBColor[
              0.7755288666897697, 0.794666330014989, 0.6550769711080741], 
             UndirectedEdge[238, 471] -> 
             RGBColor[
              0.7815171729784833, 0.8284444682029708, 0.9383448590011232], 
             UndirectedEdge[40, 285] -> 
             RGBColor[
              0.9025158559736584, 0.9204189940377894, 0.7433941735658098], 
             UndirectedEdge[70, 208] -> 
             RGBColor[
              0.9647592661409652, 0.9703431332932926, 0.7785163285178192], 
             UndirectedEdge[84, 448] -> 
             RGBColor[
              0.9119485800993821, 0.9278378260376317, 0.7413606034127984], 
             UndirectedEdge[152, 195] -> 
             RGBColor[
              0.8700978566284693, 0.4165395147992195, 0.4181763165088186], 
             UndirectedEdge[93, 308] -> 
             RGBColor[
              0.9044581174173555, 0.922805483654043, 0.8132046690853315], 
             UndirectedEdge[255, 478] -> 
             RGBColor[
              0.8374937857442898, 0.2688170134169282, 0.18273928058428096`], 
             UndirectedEdge[112, 293] -> 
             RGBColor[
              0.7920639703084134, 0.8374856606048475, 0.9799091923678545], 
             UndirectedEdge[87, 184] -> 
             RGBColor[
              0.9777439369379894, 0.982037580780667, 0.8829497683853288], 
             UndirectedEdge[149, 323] -> 
             RGBColor[
              0.7803638729582387, 0.8290326730748355, 0.9786563067617874], 
             UndirectedEdge[272, 497] -> 
             RGBColor[
              0.9683932879115527, 0.9035484173473882, 0.521812407940875], 
             UndirectedEdge[80, 471] -> 
             RGBColor[
              0.5300862150435194, 0.6293868953410054, 0.9561494750994634], 
             UndirectedEdge[339, 344] -> 
             RGBColor[
              0.8671288110293855, 0.8958570534882666, 0.9279684845868812], 
             UndirectedEdge[137, 393] -> 
             RGBColor[
              0.9792776424182412, 0.9417607634150948, 0.3739979831940817], 
             UndirectedEdge[11, 316] -> 
             RGBColor[
              0.815927784956294, 0.8564879455475631, 0.9821922633092612], 
             UndirectedEdge[88, 423] -> 
             RGBColor[
              0.8672328807022635, 0.3896013175588282, 0.2183244146570058], 
             UndirectedEdge[70, 351] -> 
             RGBColor[
              0.9039509455191048, 0.9262487106492716, 0.9906574177582574], 
             UndirectedEdge[55, 298] -> 
             RGBColor[
              0.8505299870866364, 0.40162354006115397`, 0.44012563023643037`],
              UndirectedEdge[428, 437] -> 
             RGBColor[
              0.7730012231762661, 0.818132725285045, 0.7530574554251415], 
             UndirectedEdge[90, 137] -> 
             RGBColor[
              0.9766619196223061, 0.9666302946858736, 0.6634392037392319], 
             UndirectedEdge[344, 439] -> 
             RGBColor[
              0.7146238174686936, 0.7769888246394983, 0.9721906816521647], 
             UndirectedEdge[93, 274] -> 
             RGBColor[
              0.9899805257249397, 0.9766229049041659, 0.5211191026523874], 
             UndirectedEdge[60, 434] -> 
             RGBColor[
              0.7659941790511687, 0.817119741536936, 0.977310799211383], 
             UndirectedEdge[54, 244] -> 
             RGBColor[
              0.9207932947903008, 0.715750904122686, 0.26156199214573034`], 
             UndirectedEdge[243, 318] -> 
             RGBColor[
              0.8234567105197916, 0.8621243727340722, 0.941240341427835], 
             UndirectedEdge[384, 402] -> 
             RGBColor[
              0.9540469725726141, 0.9652488879026078, 0.962670668352224], 
             UndirectedEdge[83, 233] -> 
             RGBColor[
              0.8340891317544206, 0.8685647111921289, 0.8574981818038696], 
             UndirectedEdge[153, 201] -> 
             RGBColor[
              0.936580732398355, 0.8372168131191178, 0.6051826060750845], 
             UndirectedEdge[275, 331] -> 
             RGBColor[
              0.9735339666998337, 0.9323201781053227, 0.5780449100991558], 
             UndirectedEdge[312, 327] -> 
             RGBColor[
              0.9461485029279331, 0.9578734333142935, 0.9177943335303882], 
             UndirectedEdge[181, 370] -> 
             RGBColor[
              0.7688424573505958, 0.33728611702866546`, 0.4321224371697018], 
             UndirectedEdge[32, 245] -> 
             RGBColor[
              0.9410304261784166, 0.7860352209895146, 0.45545656322328665`], 
             UndirectedEdge[176, 391] -> 
             RGBColor[
              0.9924370557521451, 0.9909723601030695, 0.7627760080654478], 
             UndirectedEdge[148, 232] -> 
             RGBColor[
              0.865654473607075, 0.6050173481627389, 0.46570578688938424`], 
             UndirectedEdge[430, 477] -> 
             RGBColor[
              0.8379212075439608, 0.8741165682450707, 0.9777322397537309], 
             UndirectedEdge[7, 475] -> 
             RGBColor[
              0.9078740072092061, 0.7858373909815429, 0.6147728567447706], 
             UndirectedEdge[15, 50] -> 
             RGBColor[
              0.8489296158320114, 0.8824739651594797, 0.9665564070489764], 
             UndirectedEdge[168, 395] -> 
             RGBColor[
              0.5916206532263137, 0.6426262670481273, 0.6641736397614548], 
             UndirectedEdge[97, 440] -> 
             RGBColor[
              0.533236515542435, 0.6307195419803844, 0.9567993974441682], 
             UndirectedEdge[71, 308] -> 
             RGBColor[
              0.8867573329086063, 0.8643377782251154, 0.6388980248998146], 
             UndirectedEdge[253, 436] -> 
             RGBColor[
              0.9533193512026715, 0.9616360221685767, 0.8109893914273838], 
             UndirectedEdge[13, 430] -> 
             RGBColor[
              0.8591963707465602, 0.40840920447803664`, 0.43662968854400686`],
              UndirectedEdge[209, 233] -> 
             RGBColor[
              0.9187783229708422, 0.9349139832790063, 0.8658889394250102], 
             UndirectedEdge[254, 350] -> 
             RGBColor[
              0.9832945994486548, 0.9636871448776991, 0.6051947061504247], 
             UndirectedEdge[115, 268] -> 
             RGBColor[
              0.8089395887693464, 0.8485643381507693, 0.8523357399630429], 
             UndirectedEdge[42, 468] -> 
             RGBColor[
              0.7965095997314673, 0.8413183116662548, 0.9802568400793087], 
             UndirectedEdge[51, 60] -> 
             RGBColor[
              0.7216151542360718, 0.7824505100583015, 0.9728875127633803], 
             UndirectedEdge[331, 348] -> 
             RGBColor[
              0.8647652832637179, 0.3812775319791829, 0.20873826457493216`], 
             UndirectedEdge[310, 406] -> 
             RGBColor[
              0.7524783017599077, 0.6418563383156873, 0.5955702767760033], 
             UndirectedEdge[70, 130] -> 
             RGBColor[
              0.9643570019918202, 0.9694827309534158, 0.7347323583699461], 
             UndirectedEdge[83, 440] -> 
             RGBColor[
              0.6632860519551089, 0.7368833720388167, 0.9670738129644658], 
             UndirectedEdge[100, 374] -> 
             RGBColor[
              0.9795584048563339, 0.9413933603892304, 0.4868626390560973], 
             UndirectedEdge[207, 374] -> 
             RGBColor[
              0.9348751913754336, 0.9470937640663192, 0.8225743389142733], 
             UndirectedEdge[51, 324] -> 
             RGBColor[
              0.8215527295189732, 0.7674296090323252, 0.617162523724174], 
             UndirectedEdge[164, 180] -> 
             RGBColor[
              0.5715192863867349, 0.658793567596061, 0.9613907796734527], 
             UndirectedEdge[56, 132] -> 
             RGBColor[
              0.7918844266737208, 0.8373453997528436, 0.979891297136279], 
             UndirectedEdge[30, 423] -> 
             RGBColor[
              0.7509217222973233, 0.7668748746418281, 0.6415282258191328], 
             UndirectedEdge[104, 379] -> 
             RGBColor[
              0.9525442040325325, 0.954902861560393, 0.7013136534591669], 
             UndirectedEdge[324, 457] -> 
             RGBColor[
              0.9501472524775876, 0.8357150517417706, 0.3013610524540955], 
             UndirectedEdge[283, 459] -> 
             RGBColor[
              0.7991266886133643, 0.7319919440977058, 0.6109594406556439], 
             UndirectedEdge[128, 245] -> 
             RGBColor[
              0.8833863026185504, 0.5633662606593759, 0.22440701125267937`], 
             UndirectedEdge[34, 62] -> 
             RGBColor[
              0.8174327055619525, 0.8579835956405587, 0.982257342982335], 
             UndirectedEdge[320, 424] -> 
             RGBColor[
              0.7879821687599177, 0.6859026980359837, 0.6019563856901611], 
             UndirectedEdge[111, 351] -> 
             RGBColor[
              0.8688289164107058, 0.8982446104859613, 0.9873508717316248], 
             UndirectedEdge[79, 316] -> 
             RGBColor[
              0.8495109171616901, 0.5142714354985901, 0.45422889333416167`], 
             UndirectedEdge[43, 250] -> 
             RGBColor[
              0.9096923206547558, 0.9300595994894131, 0.9646082312017877], 
             UndirectedEdge[116, 313] -> 
             RGBColor[
              0.6874292191668365, 0.7557441977594854, 0.9694801782414055], 
             UndirectedEdge[87, 436] -> 
             RGBColor[
              0.9919515857943794, 0.9901680678558296, 0.7269506643854101], 
             UndirectedEdge[280, 393] -> 
             RGBColor[
              0.9102695932787566, 0.9034554290189367, 0.6711853574577062], 
             UndirectedEdge[295, 321] -> 
             RGBColor[
              0.8238360742405912, 0.8092277576793815, 0.6262509868049171], 
             UndirectedEdge[131, 186] -> 
             RGBColor[
              0.8504886136031489, 0.8839581459518613, 0.9855119699203672], 
             UndirectedEdge[165, 313] -> 
             RGBColor[
              0.6768751923204919, 0.747499311773546, 0.9684282514783503], 
             UndirectedEdge[140, 270] -> 
             RGBColor[
              0.7332254209282736, 0.6930592306660808, 0.6086006890434783], 
             UndirectedEdge[322, 445] -> 
             RGBColor[
              0.3446217226672401, 0.4685656103288897, 0.9433392491674901], 
             UndirectedEdge[112, 463] -> 
             RGBColor[
              0.8829215608057344, 0.9088342171746145, 0.960098152434103], 
             UndirectedEdge[115, 223] -> 
             RGBColor[
              0.7877763863358228, 0.8344897492199078, 0.9646872321564159], 
             UndirectedEdge[102, 451] -> 
             RGBColor[
              0.7709207813096757, 0.8213281322329282, 0.9777063858001285], 
             UndirectedEdge[148, 267] -> 
             RGBColor[
              0.8375591360409484, 0.39128093552169463`, 0.43888845888447725`],
              UndirectedEdge[447, 500] -> 
             RGBColor[
              0.588018268025624, 0.6750806881794766, 0.961597053247035], 
             UndirectedEdge[238, 293] -> 
             RGBColor[
              0.8836265931748944, 0.9091423699080616, 0.9478868407726875], 
             UndirectedEdge[56, 457] -> 
             RGBColor[
              0.8901893917202393, 0.8819684096121932, 0.6610708458055347], 
             UndirectedEdge[204, 331] -> 
             RGBColor[
              0.9695082685317272, 0.9298524596095269, 0.6088016657214699], 
             UndirectedEdge[66, 260] -> 
             RGBColor[
              0.8574044321377958, 0.8743465403235833, 0.6840739523183638], 
             UndirectedEdge[225, 424] -> 
             RGBColor[
              0.9343823052682392, 0.7704106495040961, 0.2913067452611877], 
             UndirectedEdge[178, 244] -> 
             RGBColor[
              0.8530234455990214, 0.384641594275279, 0.1974717579678386], 
             UndirectedEdge[139, 247] -> 
             RGBColor[
              0.6769050955512641, 0.6437294333390081, 0.6036793070582878], 
             UndirectedEdge[244, 448] -> 
             RGBColor[
              0.9372009676708252, 0.7706803427887425, 0.360803435697594], 
             UndirectedEdge[259, 275] -> 
             RGBColor[
              0.9758517674329386, 0.9809762276008609, 0.9018185395610523], 
             UndirectedEdge[282, 406] -> 
             RGBColor[
              0.7987003405659288, 0.8424285631348325, 0.9406101886135071], 
             UndirectedEdge[286, 357] -> 
             RGBColor[
              0.9223847089595592, 0.9405246102525595, 0.9777609618645697], 
             UndirectedEdge[206, 396] -> 
             RGBColor[
              0.8666699732550648, 0.8964474899294858, 0.9741267833774314], 
             UndirectedEdge[154, 295] -> 
             RGBColor[
              0.6117430435792953, 0.6949055746003693, 0.9631069965010877], 
             UndirectedEdge[410, 428] -> 
             RGBColor[
              0.9646670343684438, 0.970177235466757, 0.7709670689744132], 
             UndirectedEdge[104, 147] -> 
             RGBColor[
              0.9411329051345991, 0.9458038015706378, 0.7002252335832952], 
             UndirectedEdge[32, 255] -> 
             RGBColor[
              0.8765036609105393, 0.4198987178069734, 0.3372566648328661], 
             UndirectedEdge[165, 498] -> 
             RGBColor[
              0.7808109574890819, 0.346636000300821, 0.4333153454115133], 
             UndirectedEdge[248, 439] -> 
             RGBColor[
              0.7940499200828973, 0.8397406819510888, 0.979920424175388], 
             UndirectedEdge[141, 389] -> 
             RGBColor[
              0.8695707771925418, 0.39748759138473766`, 0.2274067010470306], 
             UndirectedEdge[328, 478] -> 
             RGBColor[
              0.8447798167506642, 0.32482064049106646`, 0.18971639210438004`],
              UndirectedEdge[178, 261] -> 
             RGBColor[
              0.8850602841081058, 0.5276665169336164, 0.4310224493020036], 
             UndirectedEdge[120, 315] -> 
             RGBColor[
              0.9942982441715686, 0.9902659965847282, 0.6246407532754771], 
             UndirectedEdge[47, 136] -> 
             RGBColor[
              0.833537641919247, 0.38807430526959985`, 0.4385048851851192], 
             UndirectedEdge[74, 144] -> 
             RGBColor[
              0.6472090943603119, 0.7181109764794942, 0.9654789604577225], 
             UndirectedEdge[165, 361] -> 
             RGBColor[
              0.8136660069136705, 0.8551659867624843, 0.981848751864802], 
             UndirectedEdge[32, 482] -> 
             RGBColor[
              0.9761872356253636, 0.9796337068300867, 0.8200785342177317], 
             UndirectedEdge[67, 119] -> 
             RGBColor[
              0.5438751271016359, 0.6405813553331936, 0.9572349887671274], 
             UndirectedEdge[97, 326] -> 
             RGBColor[
              0.6235517445221387, 0.7013809818321354, 0.9657729145147271], 
             UndirectedEdge[409, 430] -> 
             RGBColor[
              0.7192011947668531, 0.7791211530119557, 0.9674379757799432], 
             UndirectedEdge[113, 190] -> 
             RGBColor[
              0.9630016062161793, 0.8921564792981214, 0.566331387861178], 
             UndirectedEdge[292, 496] -> 
             RGBColor[
              0.6559308246205301, 0.7299847990259372, 0.9671287607990453], 
             UndirectedEdge[15, 82] -> 
             RGBColor[
              0.7009007393720259, 0.7635901616819789, 0.9539289121726456], 
             UndirectedEdge[340, 414] -> 
             RGBColor[
              0.6957865453229497, 0.7571189948170097, 0.9153012140374492], 
             UndirectedEdge[149, 282] -> 
             RGBColor[
              0.9567991743463533, 0.9672394188277376, 0.9558603655778208], 
             UndirectedEdge[330, 368] -> 
             RGBColor[
              0.7847165000104379, 0.8320638308584627, 0.9790924592246544], 
             UndirectedEdge[331, 431] -> 
             RGBColor[
              0.940330746697063, 0.8000456986691303, 0.27653733748309295`], 
             UndirectedEdge[4, 488] -> 
             RGBColor[
              0.725881801733018, 0.5103514566151549, 0.45659776053029755`], 
             UndirectedEdge[87, 409] -> 
             RGBColor[
              0.7424835017543918, 0.7956005950965637, 0.8884189825937604], 
             UndirectedEdge[440, 445] -> 
             RGBColor[
              0.5400387196175864, 0.6366112692615629, 0.9572328278728839], 
             UndirectedEdge[55, 200] -> 
             RGBColor[
              0.8761720832758725, 0.41999683774299523`, 0.3598509243817917], 
             UndirectedEdge[64, 215] -> 
             RGBColor[
              0.7428770529968811, 0.7982271624394548, 0.9662141799482991], 
             UndirectedEdge[167, 493] -> 
             RGBColor[
              0.9555900726745354, 0.9641074807561489, 0.862487388642994], 
             UndirectedEdge[153, 470] -> 
             RGBColor[
              0.9712795874755888, 0.9777877568372566, 0.9194751905905905], 
             UndirectedEdge[185, 187] -> 
             RGBColor[
              0.8811913247438589, 0.5691651246791712, 0.4545200102249458], 
             UndirectedEdge[18, 310] -> 
             RGBColor[
              0.903782824087721, 0.6515239850033869, 0.2411957550138424], 
             UndirectedEdge[226, 366] -> 
             RGBColor[
              0.9029840702039038, 0.9254790030037057, 0.9906086207910857], 
             UndirectedEdge[333, 361] -> 
             RGBColor[
              0.9178760729910707, 0.9373534817935454, 0.9920290333111735], 
             UndirectedEdge[236, 300] -> 
             RGBColor[
              0.7968857575636497, 0.8415424560102664, 0.956212908216177], 
             UndirectedEdge[161, 335] -> 
             RGBColor[
              0.7899846891870721, 0.7423953488030595, 0.6139335035911301], 
             UndirectedEdge[61, 397] -> 
             RGBColor[
              0.771232536993071, 0.8105231170411675, 0.6834839936106823], 
             UndirectedEdge[393, 480] -> 
             RGBColor[
              0.977280188227795, 0.935022881406173, 0.3662382508517714], 
             UndirectedEdge[349, 378] -> 
             RGBColor[
              0.9536662753328186, 0.903517600260136, 0.6178145960186677], 
             UndirectedEdge[97, 163] -> 
             RGBColor[
              0.6859611751487158, 0.7505700319623865, 0.9518060651276572], 
             UndirectedEdge[229, 267] -> 
             RGBColor[
              0.8347078252487086, 0.3890073776927322, 0.43861649831571825`], 
             UndirectedEdge[77, 287] -> 
             RGBColor[
              0.875963077373552, 0.4199104084311791, 0.3633146930731791], 
             UndirectedEdge[41, 485] -> 
             RGBColor[
              0.5852179730000677, 0.6741453401075237, 0.9604896490400865], 
             UndirectedEdge[7, 89] -> 
             RGBColor[
              0.7305555262718937, 0.6453015935981679, 0.5981495593263082], 
             UndirectedEdge[41, 44] -> 
             RGBColor[
              0.7967917109445799, 0.8111267519822734, 0.6555595578527068], 
             UndirectedEdge[147, 234] -> 
             RGBColor[
              0.8427224551343073, 0.395398026012176, 0.4393809408689512], 
             UndirectedEdge[259, 331] -> 
             RGBColor[
              0.9619756505242587, 0.9242346454330869, 0.6215524231866929], 
             UndirectedEdge[77, 409] -> 
             RGBColor[
              0.7443512547073406, 0.7963729589416695, 0.8574654825737016], 
             UndirectedEdge[2, 334] -> 
             RGBColor[
              0.9597229843768071, 0.9683591190375396, 0.9044016477026008], 
             UndirectedEdge[315, 487] -> 
             RGBColor[
              0.7341117514835834, 0.7876678922597368, 0.8402648675023869], 
             UndirectedEdge[251, 258] -> 
             RGBColor[
              0.7831088221855278, 0.6783277702971906, 0.6007342852461421], 
             UndirectedEdge[39, 96] -> 
             RGBColor[
              0.9886894055561475, 0.9885092269527418, 0.7633228964863923], 
             UndirectedEdge[219, 497] -> 
             RGBColor[
              0.9057872745665574, 0.9248303927588677, 0.876186645972561], 
             UndirectedEdge[447, 454] -> 
             RGBColor[
              0.6778536153620848, 0.7459471680526271, 0.9703688453501796], 
             UndirectedEdge[417, 458] -> 
             RGBColor[
              0.8305757821695492, 0.8665149160285736, 0.8886559173307763], 
             UndirectedEdge[189, 422] -> 
             RGBColor[
              0.8456187600121177, 0.8796588809998429, 0.9546537843940808], 
             UndirectedEdge[431, 444] -> 
             RGBColor[
              0.9327057604123644, 0.8412864338866103, 0.6171415118719565], 
             UndirectedEdge[161, 273] -> 
             RGBColor[
              0.8546835353686973, 0.3420351785349799, 0.1968326432850394], 
             UndirectedEdge[109, 413] -> 
             RGBColor[
              0.7536121119369632, 0.34984360603441694`, 0.43386485970971944`],
              UndirectedEdge[236, 470] -> 
             RGBColor[
              0.9743030212875629, 0.9800426288238082, 0.9143573057847485], 
             UndirectedEdge[287, 436] -> 
             RGBColor[
              0.8763418151246668, 0.41955254603611114`, 0.3196407498370551], 
             UndirectedEdge[253, 473] -> 
             RGBColor[
              0.9407346738165405, 0.9547159445585616, 0.9642412280669064], 
             UndirectedEdge[166, 435] -> 
             RGBColor[
              0.8505491441263286, 0.8837003976592623, 0.9647560389136596], 
             UndirectedEdge[114, 312] -> 
             RGBColor[
              0.9494310091723135, 0.9592308340029074, 0.8633947102071517], 
             UndirectedEdge[222, 296] -> 
             RGBColor[
              0.9603835375401458, 0.9190568755804238, 0.6157766451113225], 
             UndirectedEdge[5, 346] -> 
             RGBColor[
              0.5830712380370857, 0.6724025239552669, 0.9603206502000514], 
             UndirectedEdge[86, 220] -> 
             RGBColor[
              0.7473857388485146, 0.7983891367248819, 0.8372803195307077], 
             UndirectedEdge[195, 255] -> 
             RGBColor[
              0.8700978566284693, 0.4165395147992196, 0.4181763165088186], 
             UndirectedEdge[313, 407] -> 
             RGBColor[
              0.7120313341271871, 0.7749635569495101, 0.9719322871408176], 
             UndirectedEdge[224, 441] -> 
             RGBColor[
              0.7225171449992611, 0.778451786842788, 0.8501132319170492], 
             UndirectedEdge[172, 211] -> 
             RGBColor[
              0.9052163439813442, 0.6535122778218749, 0.24215805321957734`], 
             UndirectedEdge[204, 355] -> 
             RGBColor[
              0.8545652606573995, 0.8864744467988247, 0.9467625160480607], 
             UndirectedEdge[109, 180] -> 
             RGBColor[
              0.8058768370865553, 0.3909479716755676, 0.43888626065259007`], 
             UndirectedEdge[96, 157] -> 
             RGBColor[
              0.989553111572516, 0.9890395343062828, 0.7567627373279793], 
             UndirectedEdge[316, 372] -> 
             RGBColor[
              0.8330412702041516, 0.38767851193763414`, 0.43845754080781707`],
              UndirectedEdge[53, 112] -> 
             RGBColor[
              0.8802780526348677, 0.9068626931091296, 0.9645729222300272], 
             UndirectedEdge[28, 305] -> 
             RGBColor[
              0.8903758252091496, 0.5485431864706999, 0.4201411173905332], 
             UndirectedEdge[186, 341] -> 
             RGBColor[
              0.86307640371257, 0.8936797290741354, 0.9757712816921535], 
             UndirectedEdge[65, 86] -> 
             RGBColor[
              0.9380632273587319, 0.7721483182649174, 0.4715773743195003], 
             UndirectedEdge[10, 390] -> 
             RGBColor[
              0.9775449078459613, 0.9663627012308211, 0.6599785476886908], 
             UndirectedEdge[48, 140] -> 
             RGBColor[
              0.7665369459826776, 0.7201030273723481, 0.6112230943198979], 
             UndirectedEdge[231, 404] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[87, 354] -> 
             RGBColor[
              0.9694643112541845, 0.9758626495023281, 0.8969650149957842], 
             UndirectedEdge[136, 434] -> 
             RGBColor[
              0.8122848413532798, 0.37122363758590926`, 0.43645236801492915`],
              UndirectedEdge[205, 413] -> 
             RGBColor[
              0.8053364836126802, 0.8454916553595697, 0.8458851878120257], 
             UndirectedEdge[20, 490] -> 
             RGBColor[
              0.7513644807487396, 0.8056909100332532, 0.9758526476069005], 
             UndirectedEdge[390, 443] -> 
             RGBColor[
              0.9844335139390304, 0.9712031523428752, 0.6350149791979136], 
             UndirectedEdge[296, 385] -> 
             RGBColor[
              0.9503169134950535, 0.9624670159499744, 0.9689846854153183], 
             UndirectedEdge[86, 290] -> 
             RGBColor[
              0.7038549733208381, 0.7619403951841344, 0.834159701457128], 
             UndirectedEdge[24, 74] -> 
             RGBColor[
              0.9672249679992521, 0.973306097367443, 0.8610584355861858], 
             UndirectedEdge[38, 336] -> 
             RGBColor[
              0.584820596291961, 0.662087765189575, 0.9644700995670246], 
             UndirectedEdge[383, 443] -> 
             RGBColor[
              0.9302853426002218, 0.7559487973468381, 0.5495390393089018], 
             UndirectedEdge[14, 435] -> 
             RGBColor[
              0.9768052273121304, 0.9804635897686259, 0.8454036011259372], 
             UndirectedEdge[282, 323] -> 
             RGBColor[
              0.8038705334457401, 0.8466259586291982, 0.9410172051360464], 
             UndirectedEdge[307, 337] -> 
             RGBColor[
              0.9716902588727305, 0.9760832985120033, 0.8120937208715437], 
             UndirectedEdge[157, 356] -> 
             RGBColor[
              0.9833055024739408, 0.9869560084172937, 0.9080454789127252], 
             UndirectedEdge[166, 439] -> 
             RGBColor[
              0.7116654243883045, 0.774677705480478, 0.9718958166776667], 
             UndirectedEdge[266, 293] -> 
             RGBColor[
              0.655371326261651, 0.7288998670705116, 0.9675159321636109], 
             UndirectedEdge[2, 260] -> 
             RGBColor[
              0.9569956928833381, 0.953032866893351, 0.6937654593732594], 
             UndirectedEdge[135, 466] -> 
             RGBColor[
              0.8880867794629436, 0.5097566930512185, 0.33230343869607665`], 
             UndirectedEdge[60, 495] -> 
             RGBColor[
              0.6448016770141175, 0.7211790221099794, 0.9660958144215677], 
             UndirectedEdge[217, 464] -> 
             RGBColor[
              0.6624179633224423, 0.7347642653475728, 0.9679724748768017], 
             UndirectedEdge[435, 453] -> 
             RGBColor[
              0.9743552556250095, 0.9794504635146011, 0.886005972305012], 
             UndirectedEdge[82, 411] -> 
             RGBColor[
              0.7063972736166895, 0.3770256941110381, 0.4385831371992629], 
             UndirectedEdge[94, 193] -> 
             RGBColor[
              0.8660731227830359, 0.8960472154512825, 0.9870880216752915], 
             UndirectedEdge[88, 469] -> 
             RGBColor[
              0.8662615638026775, 0.41367841389109705`, 0.42467015959746923`],
              UndirectedEdge[36, 76] -> 
             RGBColor[
              0.8663492506508179, 0.893463088746026, 0.8437303211158075], 
             UndirectedEdge[163, 326] -> 
             RGBColor[
              0.8955694119190312, 0.9189922199603695, 0.9699818874709417], 
             UndirectedEdge[151, 472] -> 
             RGBColor[
              0.92161883027429, 0.7763074215504915, 0.5951758200082784], 
             UndirectedEdge[114, 138] -> 
             RGBColor[
              0.9653427896553646, 0.9719132778189079, 0.8647328645734309], 
             UndirectedEdge[448, 475] -> 
             RGBColor[
              0.9548360004446739, 0.9620350908729545, 0.7454512438513844], 
             UndirectedEdge[169, 362] -> 
             RGBColor[
              0.9000500332301586, 0.8766701972915456, 0.6427939746626905], 
             UndirectedEdge[20, 25] -> 
             RGBColor[
              0.8048360649498705, 0.8483145110268786, 0.9809563149448832], 
             UndirectedEdge[113, 349] -> 
             RGBColor[
              0.96854256897564, 0.9141245502230007, 0.5707897765605523], 
             UndirectedEdge[457, 494] -> 
             RGBColor[
              0.9053822001565957, 0.8939998736060112, 0.6625419403363233], 
             UndirectedEdge[364, 452] -> 
             RGBColor[
              0.9102898370620138, 0.9310006735184617, 0.9807742596813207], 
             UndirectedEdge[351, 442] -> 
             RGBColor[
              0.8355974403579651, 0.38971673263289464`, 0.43870135059900783`],
              UndirectedEdge[71, 466] -> 
             RGBColor[
              0.8763153582386336, 0.4708404685333026, 0.21926655856244595`], 
             UndirectedEdge[87, 285] -> 
             RGBColor[
              0.9913747317947094, 0.9889342354794214, 0.6641636664515577], 
             UndirectedEdge[211, 369] -> 
             RGBColor[
              0.8522629774079538, 0.8005764108221728, 0.6222508993875557], 
             UndirectedEdge[164, 316] -> 
             RGBColor[
              0.6176380193031434, 0.695181563833794, 0.9658920128838309], 
             UndirectedEdge[27, 297] -> 
             RGBColor[
              0.9443027096027632, 0.8168858341363918, 0.27404285664419026`], 
             UndirectedEdge[238, 483] -> 
             RGBColor[
              0.799592555191134, 0.8431188777698898, 0.9397678193012098], 
             UndirectedEdge[109, 164] -> 
             RGBColor[
              0.6720574648246199, 0.282139987847984, 0.4278573430997618], 
             UndirectedEdge[83, 355] -> 
             RGBColor[
              0.7019072073098345, 0.7670545121335806, 0.970923208795008], 
             UndirectedEdge[85, 166] -> 
             RGBColor[
              0.7765805127993325, 0.825389865920118, 0.9783659460244862], 
             UndirectedEdge[34, 190] -> 
             RGBColor[
              0.834832225743581, 0.7924925990520737, 0.6217388553081901], 
             UndirectedEdge[232, 383] -> 
             RGBColor[
              0.8645048827035142, 0.47763014269285703`, 0.20865189164961953`],
              UndirectedEdge[185, 441] -> 
             RGBColor[
              0.9702357659854222, 0.9757046516967067, 0.8628183448458446], 
             UndirectedEdge[83, 207] -> 
             RGBColor[
              0.7745800522333027, 0.824272714670407, 0.978048303969445], 
             UndirectedEdge[138, 385] -> 
             RGBColor[
              0.9361934667886964, 0.9519337725213948, 0.9928919967043298], 
             UndirectedEdge[131, 234] -> 
             RGBColor[
              0.8524664047692366, 0.40316758695860166`, 0.4403103274836573], 
             UndirectedEdge[80, 81] -> 
             RGBColor[
              0.7360912409506213, 0.7882184147419713, 0.7543215385570621], 
             UndirectedEdge[5, 486] -> 
             RGBColor[
              0.6727530550984314, 0.7440017495998748, 0.968206998679546], 
             UndirectedEdge[94, 139] -> 
             RGBColor[
              0.9125488417683922, 0.8324144413673473, 0.6245673027054115], 
             UndirectedEdge[126, 249] -> 
             RGBColor[
              0.9576190945611576, 0.966894016732007, 0.9134276929700162], 
             UndirectedEdge[359, 483] -> 
             RGBColor[
              0.7411673712659967, 0.7977090791895998, 0.9749975500404098], 
             UndirectedEdge[275, 404] -> 
             RGBColor[
              0.8740160278695045, 0.41910525342436566`, 0.3955823421578384], 
             UndirectedEdge[313, 391] -> 
             RGBColor[
              0.8205212801668142, 0.8576223201856448, 0.8359900810147711], 
             UndirectedEdge[1, 487] -> 
             RGBColor[
              0.7322110456976068, 0.7868819015713249, 0.8717644812449161], 
             UndirectedEdge[71, 172] -> 
             RGBColor[
              0.9170730961534257, 0.6995889774523801, 0.25654887399247495`], 
             UndirectedEdge[44, 494] -> 
             RGBColor[
              0.9063265537153863, 0.8971853999045722, 0.6662105755860193], 
             UndirectedEdge[85, 387] -> 
             RGBColor[
              0.6531742938649991, 0.7267335508204925, 0.9676046048160327], 
             UndirectedEdge[414, 499] -> 
             RGBColor[
              0.8290020661724499, 0.8661068708529813, 0.92574272921231], 
             UndirectedEdge[89, 376] -> 
             RGBColor[
              0.6164161115405653, 0.6990350084969255, 0.9632454076485282], 
             UndirectedEdge[171, 403] -> 
             RGBColor[
              0.7710113795882692, 0.8167769369051774, 0.7741821924065788], 
             UndirectedEdge[161, 279] -> 
             RGBColor[
              0.6725577975003754, 0.6461671517854611, 0.6048855673045671], 
             UndirectedEdge[149, 310] -> 
             RGBColor[
              0.9105771355403323, 0.7666671940085924, 0.610820453740317], 
             UndirectedEdge[333, 367] -> 
             RGBColor[
              0.8576160861442178, 0.4577827167115306, 0.4471230930054688], 
             UndirectedEdge[43, 227] -> 
             RGBColor[
              0.9238186648612579, 0.7657505073569092, 0.5833294236680016], 
             UndirectedEdge[71, 369] -> 
             RGBColor[
              0.8641197295800351, 0.846653110452678, 0.6366417201604535], 
             UndirectedEdge[134, 174] -> 
             RGBColor[
              0.8963536802825286, 0.5779569969995724, 0.38601150952096674`], 
             UndirectedEdge[158, 370] -> 
             RGBColor[
              0.8094346413696681, 0.8517913179029872, 0.9712823361239034], 
             UndirectedEdge[7, 391] -> 
             RGBColor[
              0.9471712650769322, 0.8136622577944126, 0.4721411694100477], 
             UndirectedEdge[200, 228] -> 
             RGBColor[
              0.8761720832758725, 0.41999683774299534`, 0.3598509243817917], 
             UndirectedEdge[201, 300] -> 
             RGBColor[
              0.7739610019341534, 0.7094394293377593, 0.607964688795916], 
             UndirectedEdge[210, 320] -> 
             RGBColor[
              0.7047017489611271, 0.7692376293108736, 0.9712017425903323], 
             UndirectedEdge[69, 103] -> 
             RGBColor[
              0.922311342836477, 0.7201605253349532, 0.26931722848776385`], 
             UndirectedEdge[97, 281] -> 
             RGBColor[
              0.6771227197531902, 0.743978326400046, 0.9667672646739239], 
             UndirectedEdge[192, 272] -> 
             RGBColor[
              0.950420003053426, 0.8408900173802752, 0.28026097301824227`], 
             UndirectedEdge[70, 463] -> 
             RGBColor[
              0.9516898794230078, 0.9634909716910173, 0.9666606122261561], 
             UndirectedEdge[285, 477] -> 
             RGBColor[
              0.8630625201114507, 0.8895977482057743, 0.7394618337594507], 
             UndirectedEdge[10, 168] -> 
             RGBColor[
              0.9782772295982043, 0.9688329944584613, 0.662823479408796], 
             UndirectedEdge[298, 468] -> 
             RGBColor[
              0.8907188859361821, 0.9156990779981822, 0.9894387565663711], 
             UndirectedEdge[37, 264] -> 
             RGBColor[
              0.81773100431163, 0.8389653545319763, 0.6737118704566292], 
             UndirectedEdge[191, 405] -> 
             RGBColor[
              0.8952961555044594, 0.6155537983222765, 0.23424699654663333`], 
             UndirectedEdge[349, 380] -> 
             RGBColor[
              0.7702340264693888, 0.7588731759883055, 0.619749459198228], 
             UndirectedEdge[94, 410] -> 
             RGBColor[
              0.9176957680535281, 0.9372096206500691, 0.9920086847803432], 
             UndirectedEdge[335, 409] -> 
             RGBColor[
              0.5730040247810388, 0.6641039272954905, 0.9596139816275039], 
             UndirectedEdge[168, 189] -> 
             RGBColor[
              0.853015318579831, 0.8706884428084631, 0.6833016560081204], 
             UndirectedEdge[187, 399] -> 
             RGBColor[
              0.8587522810025803, 0.43077087026490835`, 0.2030397296868562], 
             UndirectedEdge[153, 314] -> 
             RGBColor[
              0.9757019172784059, 0.9796165038594133, 0.8461857411352494], 
             UndirectedEdge[233, 355] -> 
             RGBColor[
              0.8619537584870842, 0.8903327693746925, 0.8602754673868398], 
             UndirectedEdge[233, 486] -> 
             RGBColor[
              0.8576929740809733, 0.8870042122134778, 0.8598507922165328], 
             UndirectedEdge[49, 264] -> 
             RGBColor[
              0.692045535744704, 0.7593504993554208, 0.9699402895359563], 
             UndirectedEdge[205, 331] -> 
             RGBColor[
              0.9774383238428261, 0.9339347301213519, 0.5133396080873823], 
             UndirectedEdge[308, 456] -> 
             RGBColor[
              0.8792704264963173, 0.9063978659430532, 0.980789189868984], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.8673140386090211, 0.5582861552275501, 0.45965905051685185`], 
             UndirectedEdge[175, 371] -> 
             RGBColor[
              0.6101712313695146, 0.6944035193833198, 0.9624540609457266], 
             UndirectedEdge[21, 188] -> 
             RGBColor[
              0.8402178794429431, 0.8457184333790235, 0.6601616898072357], 
             UndirectedEdge[79, 221] -> 
             RGBColor[
              0.8824656879156216, 0.5120220902388821, 0.22929087833479744`], 
             UndirectedEdge[158, 193] -> 
             RGBColor[
              0.8897185721948611, 0.9146105513485909, 0.979257534452101], 
             UndirectedEdge[266, 483] -> 
             RGBColor[
              0.5713372882778905, 0.6628763749323396, 0.9593969106921332], 
             UndirectedEdge[290, 484] -> 
             RGBColor[
              0.6708386169622254, 0.6443248802220889, 0.6046915660365831], 
             UndirectedEdge[153, 411] -> 
             RGBColor[
              0.8768393249819746, 0.5127162169383854, 0.4415707345619556], 
             UndirectedEdge[176, 475] -> 
             RGBColor[
              0.9531397978844192, 0.9631474932901999, 0.9054076954001705], 
             UndirectedEdge[20, 474] -> 
             RGBColor[
              0.6618313918661711, 0.7356999072383641, 0.9669610103021512], 
             UndirectedEdge[70, 483] -> 
             RGBColor[
              0.7767982509419263, 0.8261189229830784, 0.9783526306884298], 
             UndirectedEdge[163, 266] -> 
             RGBColor[
              0.7414022435909255, 0.7966486986945014, 0.955875190905385], 
             UndirectedEdge[69, 486] -> 
             RGBColor[
              0.8006272936463226, 0.6650874664145487, 0.5972180739070181], 
             UndirectedEdge[262, 475] -> 
             RGBColor[
              0.8503768441414795, 0.40150142803364036`, 0.4401110233256089], 
             UndirectedEdge[18, 167] -> 
             RGBColor[
              0.9179594477878378, 0.8276943531137744, 0.6230603344389476], 
             UndirectedEdge[281, 374] -> 
             RGBColor[
              0.967467395307995, 0.9729632058543907, 0.8215677151390499], 
             UndirectedEdge[138, 294] -> 
             RGBColor[
              0.9651459492196888, 0.9718318792401874, 0.8679950199992963], 
             UndirectedEdge[291, 349] -> 
             RGBColor[
              0.9723714921134028, 0.9157079083393018, 0.5073346112323813], 
             UndirectedEdge[288, 455] -> 
             RGBColor[
              0.6981611935612484, 0.7631417424135241, 0.9712242176647141], 
             UndirectedEdge[12, 459] -> 
             RGBColor[
              0.8865591469064404, 0.8005756712146169, 0.6195993683600877], 
             UndirectedEdge[93, 305] -> 
             RGBColor[
              0.893251110707283, 0.5492905627423621, 0.3403884895524626], 
             UndirectedEdge[127, 184] -> 
             RGBColor[
              0.6899578277065219, 0.7535507288960803, 0.9450407748412226], 
             UndirectedEdge[204, 431] -> 
             RGBColor[
              0.9501811654376364, 0.8543195623411086, 0.5875602094797663], 
             UndirectedEdge[397, 495] -> 
             RGBColor[
              0.7740493123247987, 0.8128099021497466, 0.683705740482984], 
             UndirectedEdge[28, 493] -> 
             RGBColor[
              0.9904267006795098, 0.9903092089554764, 0.8083178748523798], 
             UndirectedEdge[267, 485] -> 
             RGBColor[
              0.7280089171918104, 0.3044371880223242, 0.42870168049425883`], 
             UndirectedEdge[110, 494] -> 
             RGBColor[
              0.9013702897437144, 0.9234979044051843, 0.9663823994305427], 
             UndirectedEdge[337, 500] -> 
             RGBColor[
              0.8599149495363005, 0.8880600626413219, 0.81293318353808], 
             UndirectedEdge[43, 393] -> 
             RGBColor[
              0.9702296274934425, 0.9504975523967621, 0.6502641705422313], 
             UndirectedEdge[167, 432] -> 
             RGBColor[
              0.9551131973731966, 0.9628141424594641, 0.7907127777288399], 
             UndirectedEdge[230, 474] -> 
             RGBColor[
              0.7723109030509079, 0.6902175043133829, 0.603717599373675], 
             UndirectedEdge[40, 421] -> 
             RGBColor[
              0.6516513136765205, 0.7254833298681407, 0.9674941433386748], 
             UndirectedEdge[254, 476] -> 
             RGBColor[
              0.9804747281295503, 0.9622936326221467, 0.6417428050109115], 
             UndirectedEdge[107, 197] -> 
             RGBColor[
              0.8158332034631433, 0.8568969129242006, 0.9820547013974588], 
             UndirectedEdge[231, 395] -> 
             RGBColor[
              0.6111758949527872, 0.19821001583115389`, 0.42102461512351264`],
              UndirectedEdge[420, 427] -> 
             RGBColor[
              0.9526517900010429, 0.9614083241554561, 0.8356173525397017], 
             UndirectedEdge[317, 374] -> 
             RGBColor[
              0.8622023464519655, 0.8898755615294929, 0.8154492437398364], 
             UndirectedEdge[188, 200] -> 
             RGBColor[
              0.9833385485462194, 0.9558213896490767, 0.549972930293113], 
             UndirectedEdge[84, 260] -> 
             RGBColor[
              0.9076231158608532, 0.9136645141585227, 0.689056258901435], 
             UndirectedEdge[33, 160] -> 
             RGBColor[
              0.9943291785247859, 0.9902790112095459, 0.624144262555479], 
             UndirectedEdge[135, 362] -> 
             RGBColor[
              0.9170167954124773, 0.9327157551184806, 0.8096673391221478], 
             UndirectedEdge[123, 193] -> 
             RGBColor[
              0.8032454132210454, 0.8463215052947987, 0.9809969005003927], 
             UndirectedEdge[439, 453] -> 
             RGBColor[
              0.8354715358869852, 0.8704277713358166, 0.8931457500690192], 
             UndirectedEdge[269, 282] -> 
             RGBColor[
              0.9444347449837323, 0.9573803584774777, 0.9546810352673576], 
             UndirectedEdge[202, 459] -> 
             RGBColor[
              0.9557582533920312, 0.8509284843610744, 0.3732235222839363], 
             UndirectedEdge[25, 474] -> 
             RGBColor[
              0.7822907486484321, 0.8306548652982964, 0.9787413927746946], 
             UndirectedEdge[103, 259] -> 
             RGBColor[
              0.9644559074339745, 0.9326011343815745, 0.6311877529237224], 
             UndirectedEdge[352, 375] -> 
             RGBColor[
              0.876618445449665, 0.4201442303296663, 0.3497502535486439], 
             UndirectedEdge[300, 308] -> 
             RGBColor[
              0.7228223554978952, 0.783223295686108, 0.9731242629408356], 
             UndirectedEdge[32, 328] -> 
             RGBColor[
              0.8837896919169137, 0.4759023448811116, 0.3442337763529652], 
             UndirectedEdge[209, 486] -> 
             RGBColor[
              0.7823356141201452, 0.8300752270592434, 0.9788892912458416], 
             UndirectedEdge[118, 496] -> 
             RGBColor[
              0.7590596458945712, 0.8112141579736412, 0.9634444784418512], 
             UndirectedEdge[31, 405] -> 
             RGBColor[
              0.607097704206448, 0.5055623989873657, 0.5819698485248604], 
             UndirectedEdge[21, 228] -> 
             RGBColor[
              0.7807583038736883, 0.34659486689629315`, 0.43331009739120685`],
              UndirectedEdge[92, 250] -> 
             RGBColor[
              0.9150389891260062, 0.9340471360809055, 0.9555577161144337], 
             UndirectedEdge[177, 290] -> 
             RGBColor[
              0.5875273787899513, 0.6730703558089015, 0.9622366843138186], 
             UndirectedEdge[9, 333] -> 
             RGBColor[
              0.6795991402238992, 0.7470702861615961, 0.9706590398207687], 
             UndirectedEdge[11, 444] -> 
             RGBColor[
              0.8558888182609448, 0.8881272108273663, 0.9782175233487975], 
             UndirectedEdge[11, 25] -> 
             RGBColor[
              0.8463325905161322, 0.8807319121845174, 0.9850923008062491], 
             UndirectedEdge[168, 338] -> 
             RGBColor[
              0.9846294152917778, 0.9734516219499484, 0.6467497851491566], 
             UndirectedEdge[283, 430] -> 
             RGBColor[
              0.8114073062697189, 0.8534037070565199, 0.9750895818612091], 
             UndirectedEdge[139, 410] -> 
             RGBColor[
              0.9305555979580218, 0.846772449092055, 0.626281652300672], 
             UndirectedEdge[195, 260] -> 
             RGBColor[
              0.9800920549366295, 0.9704189091422144, 0.6602448391148354], 
             UndirectedEdge[391, 407] -> 
             RGBColor[
              0.8865971021202634, 0.909241254490526, 0.8425759014334278], 
             UndirectedEdge[33, 111] -> 
             RGBColor[
              0.9296352516608084, 0.9423347866205443, 0.7749936870276516], 
             UndirectedEdge[2, 114] -> 
             RGBColor[
              0.9621243135471179, 0.9693521303608079, 0.8646054089098673], 
             UndirectedEdge[101, 306] -> 
             RGBColor[
              0.9016239949830045, 0.9222340244703346, 0.9055183018842057], 
             UndirectedEdge[264, 374] -> 
             RGBColor[
              0.8244760481541713, 0.8604034905687694, 0.8116890388978144], 
             UndirectedEdge[172, 235] -> 
             RGBColor[
              0.7934605786578575, 0.6501449962341276, 0.5946776503654115], 
             UndirectedEdge[84, 475] -> 
             RGBColor[
              0.8736051120791467, 0.9020530192655982, 0.9878064295382409], 
             UndirectedEdge[37, 397] -> 
             RGBColor[
              0.9847049379201054, 0.960068305532467, 0.3950820013600676], 
             UndirectedEdge[228, 287] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[68, 375] -> 
             RGBColor[
              0.6493529556164899, 0.2380483782331236, 0.4232092927939419], 
             UndirectedEdge[197, 236] -> 
             RGBColor[
              0.8349848223055523, 0.8714760241232565, 0.9598938392960332], 
             UndirectedEdge[107, 214] -> 
             RGBColor[
              0.5515763420775036, 0.6239052446900324, 0.9630678324461773], 
             UndirectedEdge[207, 317] -> 
             RGBColor[
              0.8024446789659663, 0.8460407728529705, 0.9808255895524152], 
             UndirectedEdge[98, 462] -> 
             RGBColor[
              0.6417329335243727, 0.5639558442171159, 0.5901320965044372], 
             UndirectedEdge[21, 59] -> 
             RGBColor[
              0.8502125739292851, 0.8814081826431412, 0.8703377056859483], 
             UndirectedEdge[46, 350] -> 
             RGBColor[
              0.9753162208911403, 0.9367742005908325, 0.5742002120448493], 
             UndirectedEdge[271, 429] -> 
             RGBColor[
              0.9614966729899014, 0.9329262812185326, 0.641572216907013], 
             UndirectedEdge[304, 423] -> 
             RGBColor[
              0.9733288381256362, 0.9216940496904671, 0.3508880018547395], 
             UndirectedEdge[299, 328] -> 
             RGBColor[
              0.8209620155031871, 0.16212881353706912`, 0.16770655576004956`],
              UndirectedEdge[55, 73] -> 
             RGBColor[
              0.8764541544909698, 0.4197928285813809, 0.331868196580927], 
             UndirectedEdge[53, 440] -> 
             RGBColor[
              0.8074373479365073, 0.8499589809889108, 0.9573128415207816], 
             UndirectedEdge[206, 377] -> 
             RGBColor[
              0.8059355127681973, 0.36626349383855833`, 0.43581952627941734`],
              UndirectedEdge[39, 113] -> 
             RGBColor[
              0.9851388812603973, 0.9879494170153723, 0.8881970423327341], 
             UndirectedEdge[9, 450] -> 
             RGBColor[
              0.6273906251992045, 0.7055067980393344, 0.9656617870012071], 
             UndirectedEdge[61, 321] -> 
             RGBColor[
              0.7544919431548307, 0.7537050808906393, 0.620262766049455], 
             UndirectedEdge[76, 460] -> 
             RGBColor[
              0.8176324365572626, 0.5611662054957425, 0.4600654706345412], 
             UndirectedEdge[141, 167] -> 
             RGBColor[
              0.8502843348740153, 0.4014276636548616, 0.44010219970909426`], 
             UndirectedEdge[29, 476] -> 
             RGBColor[
              0.9507075545374911, 0.9623172130479145, 0.9530287497568525], 
             UndirectedEdge[39, 190] -> 
             RGBColor[
              0.961012552436691, 0.8911608117244121, 0.591541471761139], 
             UndirectedEdge[115, 215] -> 
             RGBColor[
              0.5813590497254989, 0.6710124923507164, 0.9601858604642108], 
             UndirectedEdge[208, 471] -> 
             RGBColor[
              0.7877345649059266, 0.8301864233095924, 0.761799215186671], 
             UndirectedEdge[139, 401] -> 
             RGBColor[
              0.8178718359465835, 0.7578078189090767, 0.6153017413279296], 
             UndirectedEdge[34, 356] -> 
             RGBColor[
              0.8562614697644622, 0.8877574883914146, 0.9448030216181893], 
             UndirectedEdge[288, 313] -> 
             RGBColor[
              0.6119628229831825, 0.6958029201860585, 0.9626327696550641], 
             UndirectedEdge[66, 334] -> 
             RGBColor[
              0.8601317236312649, 0.8896727924677719, 0.8947101406477052], 
             UndirectedEdge[17, 328] -> 
             RGBColor[
              0.8827412860288608, 0.47334094392037895`, 0.2572438977460699], 
             UndirectedEdge[318, 459] -> 
             RGBColor[
              0.7916212945173026, 0.7261286731867544, 0.610211373114044], 
             UndirectedEdge[163, 233] -> 
             RGBColor[
              0.9760572627386392, 0.9800121192619307, 0.8514327392397867], 
             UndirectedEdge[141, 300] -> 
             RGBColor[
              0.7552935310958248, 0.326588066747452, 0.43084962524761683`], 
             UndirectedEdge[354, 436] -> 
             RGBColor[
              0.9719001708338055, 0.976098219754832, 0.8005006001215393], 
             UndirectedEdge[29, 290] -> 
             RGBColor[
              0.6655423065928827, 0.7348132221216408, 0.969800980806335], 
             UndirectedEdge[110, 360] -> 
             RGBColor[
              0.6723684355361539, 0.73851717663704, 0.9468606990461319], 
             UndirectedEdge[289, 308] -> 
             RGBColor[
              0.9011323730264464, 0.922092645140594, 0.9164734195937697], 
             UndirectedEdge[264, 324] -> 
             RGBColor[
              0.7919831110276052, 0.7443295983294445, 0.6142153004967501], 
             UndirectedEdge[109, 382] -> 
             RGBColor[
              0.849552882183529, 0.4255168447944628, 0.44312037902009327`], 
             UndirectedEdge[293, 497] -> 
             RGBColor[
              0.8893340418860652, 0.9119770023396675, 0.8745467415031708], 
             UndirectedEdge[160, 237] -> 
             RGBColor[
              0.8765097884918237, 0.4199118240837473, 0.3379236142406269], 
             UndirectedEdge[35, 123] -> 
             RGBColor[
              0.6347424350169715, 0.7123344426010977, 0.9657674893815754], 
             UndirectedEdge[218, 432] -> 
             RGBColor[
              0.9944665852326409, 0.9908836669340484, 0.6616888641498542], 
             UndirectedEdge[46, 476] -> 
             RGBColor[
              0.9724963495720359, 0.93538068833528, 0.6107483109053361], 
             UndirectedEdge[288, 391] -> 
             RGBColor[
              0.7865285909762588, 0.8300806177270743, 0.8332763839476742], 
             UndirectedEdge[259, 486] -> 
             RGBColor[
              0.84277185824382, 0.8775280754611701, 0.9590885983429768], 
             UndirectedEdge[138, 296] -> 
             RGBColor[
              0.9500232447016754, 0.9622479982447114, 0.9694817900814194], 
             UndirectedEdge[56, 494] -> 
             RGBColor[
              0.8249240715299604, 0.8633189479988548, 0.9831411975332329], 
             UndirectedEdge[91, 200] -> 
             RGBColor[
              0.764420919842487, 0.8125415405835479, 0.8538251065282982], 
             UndirectedEdge[172, 493] -> 
             RGBColor[
              0.93499939246249, 0.7588123800660513, 0.4752707632414235], 
             UndirectedEdge[340, 461] -> 
             RGBColor[
              0.4794414740714177, 0.5869778608579455, 0.952519892650441], 
             UndirectedEdge[33, 274] -> 
             RGBColor[
              0.9896069629487927, 0.9758238918989777, 0.4804590998310049], 
             UndirectedEdge[235, 345] -> 
             RGBColor[
              0.7818634567462011, 0.8297744172253986, 0.9788241744660333], 
             UndirectedEdge[205, 490] -> 
             RGBColor[
              0.9067855256121841, 0.9251565657023575, 0.8557148925957146], 
             UndirectedEdge[141, 284] -> 
             RGBColor[
              0.6443231785253649, 0.23304991252509769`, 0.42291230388595935`],
              UndirectedEdge[489, 500] -> 
             RGBColor[
              0.8116367281820581, 0.8534068996104317, 0.9816926132850754], 
             UndirectedEdge[155, 198] -> 
             RGBColor[
              0.951942814645732, 0.9611205734299781, 0.8580502086960725], 
             UndirectedEdge[23, 157] -> 
             RGBColor[
              0.9896585982518791, 0.9892651596471013, 0.7682443113883352], 
             UndirectedEdge[248, 344] -> 
             RGBColor[
              0.8276066039376744, 0.8659554184186837, 0.9832650408169925], 
             UndirectedEdge[50, 131] -> 
             RGBColor[
              0.8319874336738515, 0.8695048835769188, 0.9836679452083712], 
             UndirectedEdge[442, 500] -> 
             RGBColor[
              0.7866257073303051, 0.3511785270705201, 0.43389490533375963`], 
             UndirectedEdge[18, 305] -> 
             RGBColor[
              0.8683143686496947, 0.45885227577060794`, 0.21038061679205267`],
              UndirectedEdge[134, 278] -> 
             RGBColor[
              0.7998927635302205, 0.5035936427826306, 0.45286613829794237`], 
             UndirectedEdge[158, 422] -> 
             RGBColor[
              0.9582692075731941, 0.9683978238527652, 0.9555235258314969], 
             UndirectedEdge[229, 393] -> 
             RGBColor[
              0.9222244090286168, 0.9129878745930464, 0.6723256184561179], 
             UndirectedEdge[17, 143] -> 
             RGBColor[
              0.993324772704197, 0.9879629952262378, 0.5780935653236118], 
             UndirectedEdge[53, 83] -> 
             RGBColor[
              0.8181938765585695, 0.8583620629011111, 0.9583849517683536], 
             UndirectedEdge[166, 239] -> 
             RGBColor[
              0.7923005717208974, 0.3556117742630176, 0.434460522781591], 
             UndirectedEdge[46, 194] -> 
             RGBColor[
              0.9754367554218601, 0.9368240447168813, 0.5722026429374552], 
             UndirectedEdge[319, 368] -> 
             RGBColor[
              0.7078546715292704, 0.7717007163842062, 0.9715159964461884], 
             UndirectedEdge[51, 360] -> 
             RGBColor[
              0.5477858229904209, 0.6407337031284213, 0.958821711221991], 
             UndirectedEdge[132, 250] -> 
             RGBColor[
              0.8139631594437862, 0.8548675128969243, 0.9820191772771539], 
             UndirectedEdge[80, 447] -> 
             RGBColor[
              0.4646358383265672, 0.5761828911984723, 0.9510158918172613], 
             UndirectedEdge[128, 179] -> 
             RGBColor[
              0.6542070149689821, 0.5459781733720138, 0.5848902459431768], 
             UndirectedEdge[218, 300] -> 
             RGBColor[
              0.8130821868142043, 0.8518391200780548, 0.8489678238560807], 
             UndirectedEdge[130, 241] -> 
             RGBColor[
              0.7106839767244842, 0.7664229176878274, 0.7121681384556182], 
             UndirectedEdge[134, 252] -> 
             RGBColor[
              0.8968685286370098, 0.5775781866012938, 0.3344678204325193], 
             UndirectedEdge[266, 317] -> 
             RGBColor[
              0.6272987393393704, 0.7069693488072631, 0.9647179190524382], 
             UndirectedEdge[156, 485] -> 
             RGBColor[
              0.7719571165938444, 0.8178782238656668, 0.8015898418336584], 
             UndirectedEdge[96, 110] -> 
             RGBColor[
              0.9784263415762489, 0.9808550506407583, 0.7806955867685768], 
             UndirectedEdge[50, 373] -> 
             RGBColor[
              0.8065845908522442, 0.6546113960685647, 0.5948549006186388], 
             UndirectedEdge[37, 322] -> 
             RGBColor[
              0.6214191503043522, 0.6702206264652628, 0.6597291007627151], 
             UndirectedEdge[65, 290] -> 
             RGBColor[
              0.6467008643305748, 0.5419100224600528, 0.5849223151306966], 
             UndirectedEdge[333, 450] -> 
             RGBColor[
              0.8640064895973512, 0.8944655028423232, 0.986873346307721], 
             UndirectedEdge[238, 266] -> 
             RGBColor[
              0.7530809115494862, 0.8053586301359322, 0.9361062523359747], 
             UndirectedEdge[312, 446] -> 
             RGBColor[
              0.9378073150245929, 0.9523219139084023, 0.961887524332905], 
             UndirectedEdge[407, 448] -> 
             RGBColor[
              0.8856433122727729, 0.9072011944496896, 0.738761762642708], 
             UndirectedEdge[14, 454] -> 
             RGBColor[
              0.9498428490990662, 0.9595611239828206, 0.8635164964884481], 
             UndirectedEdge[77, 473] -> 
             RGBColor[
              0.9812346613611972, 0.9840203540909201, 0.8492490010048739], 
             UndirectedEdge[57, 136] -> 
             RGBColor[
              0.7085493589986231, 0.28863904203798835`, 0.4271697527905808], 
             UndirectedEdge[364, 487] -> 
             RGBColor[
              0.7102405896850148, 0.7716970350009854, 0.9627228993538011], 
             UndirectedEdge[80, 403] -> 
             RGBColor[
              0.5132370749205908, 0.6157080043440994, 0.9548230490685525], 
             UndirectedEdge[330, 352] -> 
             RGBColor[
              0.9272768121355144, 0.9414270685943145, 0.8536301084990687], 
             UndirectedEdge[239, 272] -> 
             RGBColor[
              0.859557833312678, 0.3613601456193608, 0.200754617825244], 
             UndirectedEdge[53, 97] -> 
             RGBColor[
              0.6881443401458955, 0.7521982328426786, 0.948110536248056], 
             UndirectedEdge[304, 311] -> 
             RGBColor[
              0.9743846092800552, 0.959683696417158, 0.6561531948637529], 
             UndirectedEdge[237, 241] -> 
             RGBColor[
              0.6876798398098808, 0.2712451989562277, 0.42565144796361176`], 
             UndirectedEdge[361, 441] -> 
             RGBColor[
              0.9567334991312947, 0.9652179133515973, 0.8712244889274519], 
             UndirectedEdge[276, 347] -> 
             RGBColor[
              0.5937648913162548, 0.6762712766853143, 0.9635659964486597], 
             UndirectedEdge[11, 180] -> 
             RGBColor[
              0.7698090520398855, 0.8200999493098302, 0.9776910300988833], 
             UndirectedEdge[56, 360] -> 
             RGBColor[
              0.5959222173224001, 0.6783382202307104, 0.963619497148822], 
             UndirectedEdge[15, 269] -> 
             RGBColor[
              0.9326046168788198, 0.9485574683068909, 0.9747063563574087], 
             UndirectedEdge[8, 387] -> 
             RGBColor[
              0.4147638213205529, 0.532525290956131, 0.9479654572045095], 
             UndirectedEdge[139, 278] -> 
             RGBColor[
              0.8143672660540429, 0.7550700222733062, 0.6149524385531087], 
             UndirectedEdge[15, 449] -> 
             RGBColor[
              0.9730694286887764, 0.9785550695210792, 0.8910294989583336], 
             UndirectedEdge[348, 355] -> 
             RGBColor[
              0.7881366113474993, 0.35235885677204803`, 0.4340454981259927], 
             UndirectedEdge[173, 499] -> 
             RGBColor[
              0.561456642886619, 0.654330544745058, 0.9589496386856784], 
             UndirectedEdge[130, 483] -> 
             RGBColor[
              0.8054076829694322, 0.8440004305366344, 0.7194382053388846], 
             UndirectedEdge[173, 282] -> 
             RGBColor[
              0.7155516244470936, 0.7748562497647467, 0.9340833272224354], 
             UndirectedEdge[84, 244] -> 
             RGBColor[
              0.855970079305298, 0.7106982711813863, 0.6031586213844504], 
             UndirectedEdge[183, 279] -> 
             RGBColor[
              0.3571443696351674, 0.48282285070689246`, 0.9440122967843265], 
             UndirectedEdge[124, 381] -> 
             RGBColor[
              0.6541244474059682, 0.6928944954005604, 0.6464065743072602], 
             UndirectedEdge[81, 213] -> 
             RGBColor[
              0.9893492432838836, 0.9885059731303277, 0.7274851648179543], 
             UndirectedEdge[134, 210] -> 
             RGBColor[
              0.8087080880659866, 0.5104802413089189, 0.453744767463776], 
             UndirectedEdge[103, 275] -> 
             RGBColor[
              0.9760142236095494, 0.9406866670538104, 0.5876802398361853], 
             UndirectedEdge[256, 298] -> 
             RGBColor[
              0.6967022992236058, 0.7612306804278213, 0.971934067046822], 
             UndirectedEdge[18, 235] -> 
             RGBColor[
              0.8157957020356948, 0.7471054590734147, 0.6130840110786471], 
             UndirectedEdge[255, 334] -> 
             RGBColor[
              0.8748737076582631, 0.41945992605838245`, 0.38136836845396593`],
              UndirectedEdge[209, 372] -> 
             RGBColor[
              0.8260196543366713, 0.38207966604159066`, 0.4377878128181064], 
             UndirectedEdge[112, 238] -> 
             RGBColor[
              0.8897735555962486, 0.9139444236702683, 0.9484995125402182], 
             UndirectedEdge[360, 457] -> 
             RGBColor[
              0.6763803459490353, 0.7090191458378667, 0.6430202399519124], 
             UndirectedEdge[233, 404] -> 
             RGBColor[
              0.8762578943105568, 0.42003232281108027`, 0.3584288134652338], 
             UndirectedEdge[259, 348] -> 
             RGBColor[
              0.8663104837524546, 0.4137148983095418, 0.42458735088286315`], 
             UndirectedEdge[244, 376] -> 
             RGBColor[
              0.776099559704029, 0.6482160577960884, 0.5952208969131999], 
             UndirectedEdge[182, 371] -> 
             RGBColor[
              0.7119122815650486, 0.7741830821770199, 0.9724359685874571], 
             UndirectedEdge[21, 77] -> 
             RGBColor[
              0.8504440718708604, 0.8815039129912083, 0.8665011856965787], 
             UndirectedEdge[153, 493] -> 
             RGBColor[
              0.9757235974714513, 0.9796254691763933, 0.8458264442299465], 
             UndirectedEdge[276, 382] -> 
             RGBColor[
              0.638202072497376, 0.7116591624674453, 0.9678164269318517], 
             UndirectedEdge[80, 219] -> 
             RGBColor[
              0.6486488679204226, 0.7229381874652965, 0.9673313613404179], 
             UndirectedEdge[60, 136] -> 
             RGBColor[
              0.7881366113474993, 0.3523588567720481, 0.4340454981259928], 
             UndirectedEdge[23, 96] -> 
             RGBColor[
              0.9943344703107491, 0.9902903298046392, 0.6247202408004453], 
             UndirectedEdge[53, 281] -> 
             RGBColor[
              0.9513235521472625, 0.9632177654085723, 0.9672807087505373], 
             UndirectedEdge[141, 162] -> 
             RGBColor[
              0.6469169705971057, 0.2357761524484131, 0.42306001650727343`], 
             UndirectedEdge[28, 149] -> 
             RGBColor[
              0.9595903872454232, 0.9690392903183072, 0.938515519374808], 
             UndirectedEdge[37, 317] -> 
             RGBColor[
              0.8554573026094243, 0.8684374254926999, 0.6774720752986512], 
             UndirectedEdge[372, 486] -> 
             RGBColor[
              0.7852960884100921, 0.3501398186645716, 0.43376238134578804`], 
             UndirectedEdge[63, 453] -> 
             RGBColor[
              0.7989764061179663, 0.8413923401411777, 0.8898673102975829], 
             UndirectedEdge[82, 242] -> 
             RGBColor[
              0.4965778936842009, 0.6019617103808393, 0.9535728116042415], 
             UndirectedEdge[4, 191] -> 
             RGBColor[
              0.8810953110374435, 0.551701854514115, 0.2224300931258902], 
             UndirectedEdge[70, 403] -> 
             RGBColor[
              0.741873728606347, 0.7977656224192535, 0.9756032443574324], 
             UndirectedEdge[144, 458] -> 
             RGBColor[
              0.5128076208334091, 0.6122492819414038, 0.9558260324519402], 
             UndirectedEdge[16, 224] -> 
             RGBColor[
              0.6780071248799326, 0.7460801302813742, 0.9703786268409138], 
             UndirectedEdge[40, 206] -> 
             RGBColor[
              0.797483256438624, 0.8417192481178682, 0.9804493361632056], 
             UndirectedEdge[148, 485] -> 
             RGBColor[
              0.7137140798491381, 0.7753231853160283, 0.972949209068104], 
             UndirectedEdge[34, 291] -> 
             RGBColor[
              0.8627874777050499, 0.8908645624593352, 0.854939260551614], 
             UndirectedEdge[222, 339] -> 
             RGBColor[
              0.9713487522037798, 0.9269215276784982, 0.5831902411551152], 
             UndirectedEdge[197, 314] -> 
             RGBColor[
              0.8511812515561069, 0.8817726881910449, 0.852648754935937], 
             UndirectedEdge[330, 358] -> 
             RGBColor[
              0.8794346523836569, 0.7636800825008341, 0.6121628408739259], 
             UndirectedEdge[312, 415] -> 
             RGBColor[
              0.9075702552349301, 0.8057281889949877, 0.6190056116698249], 
             UndirectedEdge[370, 443] -> 
             RGBColor[
              0.828934710920034, 0.8660373778121171, 0.9249708495963858], 
             UndirectedEdge[160, 305] -> 
             RGBColor[
              0.8933768601569751, 0.549559528100034, 0.3540755411158087], 
             UndirectedEdge[266, 343] -> 
             RGBColor[
              0.6022286542579995, 0.6873844078019926, 0.9622191672647924], 
             UndirectedEdge[47, 468] -> 
             RGBColor[
              0.8652303681850979, 0.8953752258108509, 0.9870076389894044], 
             UndirectedEdge[388, 436] -> 
             RGBColor[
              0.6326757073133445, 0.6962671641369006, 0.7846143093768058], 
             UndirectedEdge[69, 209] -> 
             RGBColor[
              0.8617126425361914, 0.7129972374800773, 0.6032562211154957], 
             UndirectedEdge[197, 470] -> 
             RGBColor[
              0.8467589217532898, 0.8799439411688881, 0.9259382043912782], 
             UndirectedEdge[13, 298] -> 
             RGBColor[
              0.8505299870866364, 0.40162354006115397`, 0.44012563023643037`],
              UndirectedEdge[168, 383] -> 
             RGBColor[
              0.9294711285032144, 0.7411518383791156, 0.30538856254325464`], 
             UndirectedEdge[123, 428] -> 
             RGBColor[
              0.8838325686168238, 0.9060935175855656, 0.7631615982042539], 
             UndirectedEdge[137, 485] -> 
             RGBColor[
              0.7664903470504028, 0.800685737394633, 0.6742136329529294], 
             UndirectedEdge[394, 467] -> 
             RGBColor[
              0.9639433298956893, 0.8954426548277312, 0.5648995859699475], 
             UndirectedEdge[232, 395] -> 
             RGBColor[
              0.6392712325189138, 0.4119464284721981, 0.4478419431284197], 
             UndirectedEdge[414, 461] -> 
             RGBColor[
              0.7695431893804625, 0.8182913134041753, 0.9207502501590459], 
             UndirectedEdge[224, 333] -> 
             RGBColor[
              0.6836597188590371, 0.750587355284736, 0.970917776300771], 
             UndirectedEdge[33, 182] -> 
             RGBColor[
              0.9136067959047216, 0.9295541310814817, 0.7734648786088647], 
             UndirectedEdge[158, 451] -> 
             RGBColor[
              0.9057328606500019, 0.9273799102664402, 0.9807849915810763], 
             UndirectedEdge[235, 274] -> 
             RGBColor[
              0.8486672237206223, 0.8687112182569856, 0.6849412348398071], 
             UndirectedEdge[284, 345] -> 
             RGBColor[
              0.5750854679753685, 0.6577966845711123, 0.9630156540916315], 
             UndirectedEdge[70, 238] -> 
             RGBColor[
              0.958541874213522, 0.968601178186671, 0.9550619723322713], 
             UndirectedEdge[21, 55] -> 
             RGBColor[
              0.7807583038736883, 0.34659486689629315`, 0.43331009739120685`],
              UndirectedEdge[55, 60] -> 
             RGBColor[
              0.7881366113474993, 0.35235885677204803`, 0.4340454981259927], 
             UndirectedEdge[219, 258] -> 
             RGBColor[
              0.7453564226499154, 0.800997369383519, 0.9752538205241048], 
             UndirectedEdge[175, 463] -> 
             RGBColor[
              0.7987983443629878, 0.842926653194944, 0.951843350139006], 
             UndirectedEdge[101, 431] -> 
             RGBColor[
              0.8675344769807304, 0.789593038034528, 0.6186989807856116], 
             UndirectedEdge[14, 213] -> 
             RGBColor[
              0.9898830743968109, 0.9900844055170221, 0.8173271692164221], 
             UndirectedEdge[378, 487] -> 
             RGBColor[
              0.7151892307709272, 0.7753877234202028, 0.9543461408076561], 
             UndirectedEdge[8, 159] -> 
             RGBColor[
              0.6621339172487573, 0.7269969119977447, 0.8773621492649972], 
             UndirectedEdge[311, 469] -> 
             RGBColor[
              0.9666594379118305, 0.9746552439015788, 0.9413210543907261], 
             UndirectedEdge[343, 440] -> 
             RGBColor[
              0.6660805936064016, 0.7390664892161097, 0.9673523467597902], 
             UndirectedEdge[371, 460] -> 
             RGBColor[
              0.7685740560180712, 0.5223105702997106, 0.45553873851719373`], 
             UndirectedEdge[224, 358] -> 
             RGBColor[
              0.6753187249706545, 0.6009152192034627, 0.5939225894349527], 
             UndirectedEdge[455, 475] -> 
             RGBColor[
              0.8674223928771541, 0.8971362756002406, 0.987213216359144], 
             UndirectedEdge[310, 408] -> 
             RGBColor[
              0.8935586196078931, 0.6095563763029874, 0.2328950418948931], 
             UndirectedEdge[154, 376] -> 
             RGBColor[
              0.6007882540980525, 0.6863476097981387, 0.9620151254639255], 
             UndirectedEdge[282, 499] -> 
             RGBColor[
              0.82621085327338, 0.8643069993624116, 0.9430875754153228], 
             UndirectedEdge[14, 192] -> 
             RGBColor[
              0.9757901938515567, 0.929030652455124, 0.5114673926650403], 
             UndirectedEdge[75, 147] -> 
             RGBColor[
              0.9085176262282338, 0.8261867204477817, 0.6235080338318886], 
             UndirectedEdge[175, 351] -> 
             RGBColor[
              0.7510594104590849, 0.8056843921531984, 0.9758401556711074], 
             UndirectedEdge[109, 205] -> 
             RGBColor[
              0.8802003214581754, 0.4477097453314738, 0.35587501613501443`], 
             UndirectedEdge[43, 148] -> 
             RGBColor[
              0.9217676603993111, 0.9396881476253559, 0.9657599878864065], 
             UndirectedEdge[56, 92] -> 
             RGBColor[
              0.8929602563559409, 0.9165250229368248, 0.9534298359735587], 
             UndirectedEdge[46, 412] -> 
             RGBColor[
              0.8046221202084176, 0.8041350975352859, 0.6364972266546813], 
             UndirectedEdge[170, 214] -> 
             RGBColor[
              0.5820016010870387, 0.6333573335190533, 0.6650126464396886], 
             UndirectedEdge[94, 437] -> 
             RGBColor[
              0.7260299568613504, 0.785165110468357, 0.9740990712310713], 
             UndirectedEdge[173, 249] -> 
             RGBColor[
              0.6885797998244632, 0.7544999363884066, 0.9713919183995792], 
             UndirectedEdge[181, 302] -> 
             RGBColor[
              0.822868087556541, 0.1767797185852455, 0.16953181251094157`], 
             UndirectedEdge[188, 279] -> 
             RGBColor[
              0.6942509180797402, 0.7271945170175751, 0.6482691460974335], 
             UndirectedEdge[317, 471] -> 
             RGBColor[
              0.6557350007683675, 0.7300551868743017, 0.9669565257175867], 
             UndirectedEdge[8, 344] -> 
             RGBColor[
              0.5411284333352755, 0.6334927252147768, 0.9590216633874612], 
             UndirectedEdge[236, 493] -> 
             RGBColor[
              0.9787470312834252, 0.9818803411629449, 0.8407085594241045], 
             UndirectedEdge[31, 366] -> 
             RGBColor[
              0.6062194667800607, 0.6848253004575867, 0.9653789983048865], 
             UndirectedEdge[176, 261] -> 
             RGBColor[
              0.9835600228741969, 0.986330129193494, 0.8710859242476277], 
             UndirectedEdge[144, 145] -> 
             RGBColor[
              0.6292777946631631, 0.7039136024570779, 0.9672550530321402], 
             UndirectedEdge[144, 375] -> 
             RGBColor[
              0.6631525595970027, 0.25000090161278077`, 0.42408859135706956`],
              UndirectedEdge[258, 293] -> 
             RGBColor[
              0.7289031899694233, 0.7881439789643188, 0.9736139160547146], 
             UndirectedEdge[242, 269] -> 
             RGBColor[
              0.7282817711909949, 0.7869290170057512, 0.9743502557890045], 
             UndirectedEdge[45, 216] -> 
             RGBColor[
              0.973270027094972, 0.9311832855860427, 0.5753153254496222], 
             UndirectedEdge[82, 323] -> 
             RGBColor[
              0.5362955660888238, 0.6342063060996638, 0.9566995322665612], 
             UndirectedEdge[258, 272] -> 
             RGBColor[
              0.8079624359949107, 0.7797153939720395, 0.6208795824924187], 
             UndirectedEdge[92, 356] -> 
             RGBColor[
              0.9789615075262568, 0.9838301072772278, 0.9204968594271273], 
             UndirectedEdge[114, 327] -> 
             RGBColor[
              0.9915032750710304, 0.9907544001330699, 0.7904762510996672], 
             UndirectedEdge[188, 459] -> 
             RGBColor[
              0.9455943620958966, 0.8170281767928247, 0.30101093533087053`], 
             UndirectedEdge[465, 469] -> 
             RGBColor[
              0.9460678965897247, 0.9590992890527156, 0.9692840509083291], 
             UndirectedEdge[44, 62] -> 
             RGBColor[
              0.9383062322468358, 0.9226851275003014, 0.6692608258729449], 
             UndirectedEdge[88, 337] -> 
             RGBColor[
              0.8764095923605619, 0.4196975146903611, 0.327017883691627], 
             UndirectedEdge[253, 388] -> 
             RGBColor[
              0.5916076131420156, 0.667499548197144, 0.9651174512930243], 
             UndirectedEdge[80, 238] -> 
             RGBColor[
              0.7299052205277659, 0.7865435601115169, 0.9342817770433913], 
             UndirectedEdge[171, 272] -> 
             RGBColor[
              0.9690291859330963, 0.902725144614895, 0.43231626664675815`], 
             UndirectedEdge[297, 392] -> 
             RGBColor[
              0.8912399629288408, 0.8430808827087712, 0.6287281175256203], 
             UndirectedEdge[82, 499] -> 
             RGBColor[
              0.5586358859164637, 0.6518873468328772, 0.9587699025458376], 
             UndirectedEdge[297, 484] -> 
             RGBColor[
              0.9360288852231615, 0.7840828775598039, 0.2673855433367437], 
             UndirectedEdge[73, 240] -> 
             RGBColor[
              0.8533059882953347, 0.8829878443140042, 0.8195432710747312], 
             UndirectedEdge[229, 263] -> 
             RGBColor[
              0.9195219901024825, 0.9377927480318744, 0.9619135929357234], 
             UndirectedEdge[87, 91] -> 
             RGBColor[
              0.7622396580360573, 0.8116395327707178, 0.8899742595854381], 
             UndirectedEdge[296, 339] -> 
             RGBColor[
              0.9751119060716664, 0.9806458937713656, 0.9129880748362007], 
             UndirectedEdge[62, 157] -> 
             RGBColor[
              0.9444767382714311, 0.957182115666438, 0.945499800276871], 
             UndirectedEdge[227, 265] -> 
             RGBColor[
              0.7202666382956033, 0.6050401093649097, 0.590873023669096], 
             UndirectedEdge[38, 127] -> 
             RGBColor[
              0.34245373850225597`, 0.46754474199981005`, 0.9431697307069444],
              UndirectedEdge[302, 451] -> 
             RGBColor[
              0.8441394453172335, 0.47298394910812513`, 0.44908516582970015`],
              UndirectedEdge[141, 151] -> 
             RGBColor[
              0.8631019898511022, 0.4113220088113396, 0.43001849414862126`], 
             UndirectedEdge[72, 439] -> 
             RGBColor[
              0.8218490030728943, 0.8612124173046397, 0.958493214885714], 
             UndirectedEdge[277, 340] -> 
             RGBColor[
              0.6999390882803084, 0.7588361780453639, 0.8464828307973267], 
             UndirectedEdge[53, 322] -> 
             RGBColor[
              0.6120203509861609, 0.6819133220562377, 0.9434192628153877], 
             UndirectedEdge[450, 461] -> 
             RGBColor[
              0.6824980463507935, 0.7505260970825862, 0.9699225111300984], 
             UndirectedEdge[352, 367] -> 
             RGBColor[
              0.8839501967198675, 0.4764992833863353, 0.3567711468450186], 
             UndirectedEdge[239, 251] -> 
             RGBColor[
              0.8429887574397561, 0.2937683965027949, 0.18732441966105964`], 
             UndirectedEdge[83, 163] -> 
             RGBColor[
              0.8160107115613896, 0.8567338620208189, 0.9620804806479548], 
             UndirectedEdge[179, 245] -> 
             RGBColor[
              0.6580085819756472, 0.5632402012707469, 0.5880623666384724], 
             UndirectedEdge[133, 237] -> 
             RGBColor[
              0.8326184356397394, 0.25172516658248273`, 0.1788687568468555], 
             UndirectedEdge[199, 244] -> 
             RGBColor[
              0.9382206323856197, 0.772915826118826, 0.47575093805960716`], 
             UndirectedEdge[173, 269] -> 
             RGBColor[
              0.6796805345969713, 0.7474039038601241, 0.9705430985377133], 
             UndirectedEdge[209, 379] -> 
             RGBColor[
              0.8798864631044014, 0.907061598070405, 0.988405550406458], 
             UndirectedEdge[139, 451] -> 
             RGBColor[
              0.8949472411426704, 0.8183794028111178, 0.6228884463245957], 
             UndirectedEdge[18, 218] -> 
             RGBColor[
              0.9573128356472821, 0.8557638775883587, 0.4940364208599619], 
             UndirectedEdge[59, 287] -> 
             RGBColor[
              0.8758087454125018, 0.41984658819913434`, 0.3658723730660921], 
             UndirectedEdge[167, 274] -> 
             RGBColor[
              0.9508309694727652, 0.9493001122973452, 0.6949175582001077], 
             UndirectedEdge[402, 461] -> 
             RGBColor[
              0.755939583490274, 0.808427576924498, 0.9563976573722861], 
             UndirectedEdge[472, 488] -> 
             RGBColor[
              0.6668627955576478, 0.5734481079949976, 0.5891590378919012], 
             UndirectedEdge[227, 270] -> 
             RGBColor[
              0.7106625057012605, 0.5972430418635793, 0.5901169511701725], 
             UndirectedEdge[124, 363] -> 
             RGBColor[
              0.4564910882838359, 0.5664287981817397, 0.951242800937357], 
             UndirectedEdge[118, 195] -> 
             RGBColor[
              0.9633289974473334, 0.9721714068562527, 0.9469586213791308], 
             UndirectedEdge[54, 154] -> 
             RGBColor[
              0.7454819891843243, 0.7538824561247364, 0.6283562206964559], 
             UndirectedEdge[313, 498] -> 
             RGBColor[
              0.760197837391246, 0.33053287421487637`, 0.4312608222407204], 
             UndirectedEdge[243, 283] -> 
             RGBColor[
              0.8309621046158535, 0.8679876436450235, 0.9419884089694348], 
             UndirectedEdge[302, 346] -> 
             RGBColor[
              0.7366063854822767, 0.38771243873865746`, 0.4391324407146747], 
             UndirectedEdge[13, 477] -> 
             RGBColor[
              0.789176434282747, 0.3531711743520105, 0.4341491379584804], 
             UndirectedEdge[140, 479] -> 
             RGBColor[
              0.9331363358742805, 0.8516884147117134, 0.6242339050826354], 
             UndirectedEdge[174, 309] -> 
             RGBColor[
              0.9760401387267699, 0.9802364367491672, 0.8620790352713976], 
             UndirectedEdge[299, 312] -> 
             RGBColor[
              0.8462380790097387, 0.398201289061377, 0.4397162642126242], 
             UndirectedEdge[215, 402] -> 
             RGBColor[
              0.7489990289680255, 0.8027929220949186, 0.9558512714962057], 
             UndirectedEdge[372, 400] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[29, 426] -> 
             RGBColor[
              0.8727563683999229, 0.9013762540943187, 0.987725475608434], 
             UndirectedEdge[361, 481] -> 
             RGBColor[
              0.7837864005838808, 0.8318238112042338, 0.9788706319466453], 
             UndirectedEdge[188, 335] -> 
             RGBColor[
              0.811677809766437, 0.8234227140351734, 0.6573170823839964], 
             UndirectedEdge[168, 443] -> 
             RGBColor[
              0.9851658356912735, 0.9736734455705154, 0.637859910918019], 
             UndirectedEdge[81, 500] -> 
             RGBColor[
              0.8594736706496782, 0.8871162117229757, 0.7649026999868358], 
             UndirectedEdge[75, 310] -> 
             RGBColor[
              0.9056838221376791, 0.6590608088014229, 0.24272534266699788`], 
             UndirectedEdge[348, 444] -> 
             RGBColor[
              0.8596819590739189, 0.4087713554575028, 0.43580771416750785`], 
             UndirectedEdge[262, 482] -> 
             RGBColor[
              0.8640464961730364, 0.41202642007975104`, 0.4284196913122883], 
             UndirectedEdge[83, 395] -> 
             RGBColor[
              0.4364661327177662, 0.5358312507222394, 0.9513918842912878], 
             UndirectedEdge[26, 459] -> 
             RGBColor[
              0.9556150371223098, 0.8527286696779314, 0.5107563864251201], 
             UndirectedEdge[186, 498] -> 
             RGBColor[
              0.804284670966196, 0.3649738436759726, 0.43565498579658757`], 
             UndirectedEdge[167, 284] -> 
             RGBColor[
              0.6072732700990703, 0.6834623642699389, 0.9660857553925803], 
             UndirectedEdge[175, 359] -> 
             RGBColor[
              0.7472251552283646, 0.8026270611103077, 0.9754744409843212], 
             UndirectedEdge[65, 484] -> 
             RGBColor[
              0.9050468710001192, 0.6545328033028718, 0.24210923889895541`], 
             UndirectedEdge[266, 322] -> 
             RGBColor[
              0.39326058703429834`, 0.5087525497798262, 0.9469749445165021], 
             UndirectedEdge[210, 252] -> 
             RGBColor[
              0.8620124948990329, 0.8894694882547065, 0.7947850738310933], 
             UndirectedEdge[133, 271] -> 
             RGBColor[
              0.8823607101034038, 0.5066206160034556, 0.23230851367202326`], 
             UndirectedEdge[190, 467] -> 
             RGBColor[
              0.939691000713254, 0.798601945150375, 0.2703321674209706], 
             UndirectedEdge[216, 481] -> 
             RGBColor[
              0.8178061779543314, 0.857050154303223, 0.9105518113459958], 
             UndirectedEdge[18, 406] -> 
             RGBColor[
              0.7683993686258163, 0.7096920685752642, 0.6086245915127735], 
             UndirectedEdge[315, 364] -> 
             RGBColor[
              0.9713492273809864, 0.9763206650836688, 0.8513320825898796], 
             UndirectedEdge[152, 464] -> 
             RGBColor[
              0.7276441430940129, 0.3041410479768464, 0.4286729641410687], 
             UndirectedEdge[229, 280] -> 
             RGBColor[
              0.8575306599962653, 0.8892356875040869, 0.9862732339487429], 
             UndirectedEdge[164, 259] -> 
             RGBColor[
              0.6675418396255978, 0.7342361433916554, 0.9450867279963999], 
             UndirectedEdge[238, 497] -> 
             RGBColor[
              0.9870436271739005, 0.9884357654050882, 0.8431370616755345], 
             UndirectedEdge[7, 478] -> 
             RGBColor[
              0.8885494196134216, 0.5868107690564748, 0.22871524263277843`], 
             UndirectedEdge[137, 227] -> 
             RGBColor[
              0.9328666797860565, 0.7570137183752419, 0.307063236319852], 
             UndirectedEdge[44, 157] -> 
             RGBColor[
              0.9787067334890509, 0.9535173759826083, 0.624047833511943], 
             UndirectedEdge[105, 205] -> 
             RGBColor[
              0.9951816972301821, 0.9922755222270166, 0.7295152764711306], 
             UndirectedEdge[305, 460] -> 
             RGBColor[
              0.8476371058583946, 0.36716524710632087`, 0.19325065240940165`],
              UndirectedEdge[330, 492] -> 
             RGBColor[
              0.8730591629001054, 0.9016176942096265, 0.9877543564181693], 
             UndirectedEdge[94, 123] -> 
             RGBColor[
              0.836861302301908, 0.8731259027688776, 0.9842032140101838], 
             UndirectedEdge[418, 444] -> 
             RGBColor[
              0.7991212697100053, 0.8437799704500237, 0.9725594646321425], 
             UndirectedEdge[203, 295] -> 
             RGBColor[
              0.8350107003050296, 0.847270477577494, 0.6678494806097419], 
             UndirectedEdge[342, 485] -> 
             RGBColor[
              0.6395802928089647, 0.7169400671915584, 0.9656847679303774], 
             UndirectedEdge[279, 430] -> 
             RGBColor[
              0.6793270505671696, 0.7457281907000464, 0.9645811351930182], 
             UndirectedEdge[391, 448] -> 
             RGBColor[
              0.9941332583124, 0.9898599576858242, 0.6028195565166616], 
             UndirectedEdge[174, 252] -> 
             RGBColor[
              0.9934808832238459, 0.9906846217906866, 0.6931851869168794], 
             UndirectedEdge[14, 489] -> 
             RGBColor[
              0.9464051079537481, 0.9568199625085414, 0.8631886016690999], 
             UndirectedEdge[6, 158] -> 
             RGBColor[
              0.8278529576047721, 0.8661798465302385, 0.9731181017572674], 
             UndirectedEdge[201, 493] -> 
             RGBColor[
              0.955822275653929, 0.8497773144904377, 0.4924603400038434], 
             UndirectedEdge[66, 446] -> 
             RGBColor[
              0.850909358653855, 0.8837568836965348, 0.9534067159807248], 
             UndirectedEdge[449, 499] -> 
             RGBColor[
              0.8308045752332143, 0.8668522546719772, 0.8958704893315255], 
             UndirectedEdge[202, 477] -> 
             RGBColor[
              0.8630089663526659, 0.8894832021308492, 0.7336328376112118], 
             UndirectedEdge[89, 299] -> 
             RGBColor[
              0.7321645235166045, 0.3078108964447237, 0.4290288250466342], 
             UndirectedEdge[57, 91] -> 
             RGBColor[
              0.5129868334266129, 0.6155048470260374, 0.9548033491414818], 
             UndirectedEdge[222, 438] -> 
             RGBColor[
              0.9644116314502814, 0.9220610214232046, 0.608958132816612], 
             UndirectedEdge[83, 346] -> 
             RGBColor[
              0.6079646058423779, 0.6921267293277582, 0.9626121851452064], 
             UndirectedEdge[38, 388] -> 
             RGBColor[
              0.2709639692526886, 0.40213069016546776`, 0.9387423692424463], 
             UndirectedEdge[345, 472] -> 
             RGBColor[
              0.870204545684958, 0.7358002241169478, 0.6072312770480389], 
             UndirectedEdge[231, 486] -> 
             RGBColor[
              0.7852960884100921, 0.3501398186645716, 0.43376238134578804`], 
             UndirectedEdge[14, 251] -> 
             RGBColor[
              0.9445520769267819, 0.8025794482580824, 0.48488897587625346`], 
             UndirectedEdge[404, 418] -> 
             RGBColor[
              0.7628242207327514, 0.332584624842513, 0.4315225955872538], 
             UndirectedEdge[10, 370] -> 
             RGBColor[
              0.8220461048269649, 0.861196926700063, 0.9499344180871628], 
             UndirectedEdge[216, 224] -> 
             RGBColor[
              0.7193405645985124, 0.7771381892126857, 0.9027573898840124], 
             UndirectedEdge[116, 143] -> 
             RGBColor[
              0.8619123532504349, 0.8901559063940476, 0.8537183308649807], 
             UndirectedEdge[142, 477] -> 
             RGBColor[
              0.849742956215713, 0.8829332090481267, 0.9577211028583139], 
             UndirectedEdge[1, 378] -> 
             RGBColor[
              0.9743971626809221, 0.9792253628144743, 0.8744549377862638], 
             UndirectedEdge[47, 298] -> 
             RGBColor[
              0.8914634435088249, 0.9162927679961307, 0.9895097731323242], 
             UndirectedEdge[50, 340] -> 
             RGBColor[
              0.5734492415269491, 0.6617832742744063, 0.9609558822473077], 
             UndirectedEdge[144, 417] -> 
             RGBColor[
              0.6725878401271481, 0.736014338925512, 0.8766596589500447], 
             UndirectedEdge[326, 395] -> 
             RGBColor[
              0.5160248330754078, 0.5980896086617901, 0.9592932911142749], 
             UndirectedEdge[14, 166] -> 
             RGBColor[
              0.8685197983484938, 0.8953445148984163, 0.8555931305570506], 
             UndirectedEdge[41, 132] -> 
             RGBColor[
              0.697542392339271, 0.7633182158243625, 0.9707113739337552], 
             UndirectedEdge[6, 35] -> 
             RGBColor[
              0.6020886409080104, 0.6868250504651503, 0.9625128643518496], 
             UndirectedEdge[95, 286] -> 
             RGBColor[
              0.940531194065519, 0.9449315288151982, 0.6995904454771313], 
             UndirectedEdge[435, 439] -> 
             RGBColor[
              0.819950853351941, 0.8597967803506876, 0.9617062872465533], 
             UndirectedEdge[354, 388] -> 
             RGBColor[
              0.6101884327731497, 0.6819617457833992, 0.9546286599871798], 
             UndirectedEdge[47, 59] -> 
             RGBColor[
              0.9293815809976231, 0.9436273402031012, 0.8781298873768169], 
             UndirectedEdge[305, 493] -> 
             RGBColor[
              0.8934014519074931, 0.5497943608655244, 0.36999865292808354`], 
             UndirectedEdge[26, 335] -> 
             RGBColor[
              0.8216984847928501, 0.8591232069202801, 0.867062533478246], 
             UndirectedEdge[24, 115] -> 
             RGBColor[
              0.8091262582177263, 0.8486415307648604, 0.84924214411834], 
             UndirectedEdge[271, 351] -> 
             RGBColor[
              0.9193500722324444, 0.8998547730808013, 0.6561026611362635], 
             UndirectedEdge[12, 40] -> 
             RGBColor[
              0.8332631957292829, 0.8699516348164067, 0.9839410234937223], 
             UndirectedEdge[228, 468] -> 
             RGBColor[
              0.8330412702041516, 0.3876785119376341, 0.43845754080781707`], 
             UndirectedEdge[1, 108] -> 
             RGBColor[
              0.9318919586964185, 0.7520201835517888, 0.5035418970848805], 
             UndirectedEdge[97, 343] -> 
             RGBColor[
              0.5467875858157898, 0.6413057410698777, 0.9581500414870645], 
             UndirectedEdge[314, 411] -> 
             RGBColor[
              0.8896525670236602, 0.5210839076412788, 0.36666208845133025`], 
             UndirectedEdge[211, 466] -> 
             RGBColor[
              0.8684108567905794, 0.44012266877963246`, 0.20967267804718087`],
              UndirectedEdge[12, 202] -> 
             RGBColor[
              0.9239275233715001, 0.9373540680592094, 0.7396301074231337], 
             UndirectedEdge[96, 360] -> 
             RGBColor[
              0.688171077591291, 0.7477268304601024, 0.7794037790176446], 
             UndirectedEdge[199, 482] -> 
             RGBColor[
              0.9763601432068039, 0.9800580622722042, 0.8428617481934166], 
             UndirectedEdge[9, 357] -> 
             RGBColor[
              0.6975610050087471, 0.7609686541006071, 0.9576741493485085], 
             UndirectedEdge[330, 441] -> 
             RGBColor[
              0.9266330724122638, 0.9412166501401593, 0.8683534833560225], 
             UndirectedEdge[375, 461] -> 
             RGBColor[
              0.7292787060429768, 0.305468059815037, 0.42880164292401246`], 
             UndirectedEdge[170, 268] -> 
             RGBColor[
              0.9897771446731028, 0.9766526142120822, 0.5688501044484592], 
             UndirectedEdge[66, 245] -> 
             RGBColor[
              0.8087340969564778, 0.6849240476592527, 0.6006651539407437], 
             UndirectedEdge[235, 308] -> 
             RGBColor[
              0.7631448154130381, 0.8148937970068628, 0.9770268012727512], 
             UndirectedEdge[42, 315] -> 
             RGBColor[
              0.8618768890150172, 0.8900733049310137, 0.8512255542368157], 
             UndirectedEdge[238, 403] -> 
             RGBColor[
              0.7646680328555547, 0.8147655772060649, 0.9370184329702123], 
             UndirectedEdge[382, 425] -> 
             RGBColor[
              0.7254253315668324, 0.7846482891487045, 0.9740813515538538], 
             UndirectedEdge[74, 215] -> 
             RGBColor[
              0.7394577595070246, 0.7956770589532991, 0.9720021519320565], 
             UndirectedEdge[350, 426] -> 
             RGBColor[
              0.9076917913634339, 0.9271626345337739, 0.912108807160454], 
             UndirectedEdge[78, 497] -> 
             RGBColor[
              0.9373698005516882, 0.7741448388903813, 0.4965188169666367], 
             UndirectedEdge[109, 490] -> 
             RGBColor[
              0.8212448066032992, 0.4029535462629421, 0.4404179962321787], 
             UndirectedEdge[281, 317] -> 
             RGBColor[
              0.8350368828985276, 0.871910214641042, 0.9798189657771917], 
             UndirectedEdge[219, 471] -> 
             RGBColor[
              0.7002608203711402, 0.7648390955567503, 0.9713944432981496], 
             UndirectedEdge[183, 243] -> 
             RGBColor[
              0.6403232296538129, 0.7086522100294597, 0.9277830543315546], 
             UndirectedEdge[93, 151] -> 
             RGBColor[
              0.9745910433398506, 0.9781933013061226, 0.8029465852388531], 
             UndirectedEdge[176, 478] -> 
             RGBColor[
              0.9338152102886346, 0.7641208713651317, 0.5193500812881785], 
             UndirectedEdge[28, 282] -> 
             RGBColor[
              0.9830970477329245, 0.98663257587267, 0.900876417749067], 
             UndirectedEdge[125, 305] -> 
             RGBColor[
              0.8676021059968548, 0.45602839169955695`, 0.20980751354262447`],
              UndirectedEdge[22, 466] -> 
             RGBColor[
              0.7334576851301958, 0.3895123853787591, 0.4394414792147179], 
             UndirectedEdge[78, 154] -> 
             RGBColor[
              0.7062941904415465, 0.593411585940333, 0.5897152911489764], 
             UndirectedEdge[273, 421] -> 
             RGBColor[
              0.7087142175934615, 0.2887728816720732, 0.42718273106306337`], 
             UndirectedEdge[221, 234] -> 
             RGBColor[
              0.8659960409580832, 0.38542916667792615`, 0.21351952580845288`],
              UndirectedEdge[384, 461] -> 
             RGBColor[
              0.7513055072112707, 0.8049714904232208, 0.9642419397519755], 
             UndirectedEdge[3, 428] -> 
             RGBColor[
              0.9612206854648047, 0.8721242788178507, 0.4048940113783153], 
             UndirectedEdge[209, 431] -> 
             RGBColor[
              0.8822123033064931, 0.801248899762742, 0.6201116598478542], 
             UndirectedEdge[33, 237] -> 
             RGBColor[
              0.8761349971913669, 0.4191101833892833, 0.2971298941296924], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.798618222021491, 0.8424978390083437, 0.9442499127710349], 
             UndirectedEdge[202, 243] -> 
             RGBColor[
              0.9875936693945204, 0.986924183908392, 0.7042524905977272], 
             UndirectedEdge[169, 456] -> 
             RGBColor[
              0.9523160113507536, 0.9181280319882474, 0.6402335203709666], 
             UndirectedEdge[86, 297] -> 
             RGBColor[
              0.9690452415817743, 0.9016983925218494, 0.49685367875728853`], 
             UndirectedEdge[40, 202] -> 
             RGBColor[
              0.9024623022148737, 0.9203044479628641, 0.7375651774175709], 
             UndirectedEdge[396, 477] -> 
             RGBColor[
              0.8415313555268893, 0.876809010699664, 0.9716212008960261], 
             UndirectedEdge[209, 355] -> 
             RGBColor[
              0.7865963985262561, 0.833403784220458, 0.9793139664161487], 
             UndirectedEdge[131, 434] -> 
             RGBColor[
              0.8624888691837745, 0.8933328368167663, 0.9867080432478796], 
             UndirectedEdge[87, 228] -> 
             RGBColor[
              0.8747179087382527, 0.41939549920110863`, 0.38395035975321834`],
              UndirectedEdge[17, 116] -> 
             RGBColor[
              0.8603153456136973, 0.8859508617065319, 0.6979891242192813], 
             UndirectedEdge[104, 323] -> 
             RGBColor[
              0.8080858384619509, 0.841043368990522, 0.6872783954398749], 
             UndirectedEdge[101, 347] -> 
             RGBColor[
              0.8142337140334024, 0.8548048328991019, 0.9821188652343271], 
             UndirectedEdge[92, 342] -> 
             RGBColor[
              0.852980541830388, 0.8852925660923785, 0.9494450316613257], 
             UndirectedEdge[399, 464] -> 
             RGBColor[
              0.7137594865632767, 0.5943189150002377, 0.5892586150703938], 
             UndirectedEdge[423, 469] -> 
             RGBColor[
              0.9656036667574114, 0.9366655971748878, 0.6360558613817127], 
             UndirectedEdge[114, 415] -> 
             RGBColor[
              0.9529250273780275, 0.8386091558137642, 0.4916875292391039], 
             UndirectedEdge[244, 478] -> 
             RGBColor[
              0.8795329120548052, 0.5458689140916408, 0.22119164771104446`], 
             UndirectedEdge[129, 486] -> 
             RGBColor[
              0.5771091774651103, 0.6658011932540189, 0.9608302328738818], 
             UndirectedEdge[202, 421] -> 
             RGBColor[
              0.7423156413187377, 0.7928857631109433, 0.7231832272680863], 
             UndirectedEdge[62, 378] -> 
             RGBColor[
              0.9307257923917294, 0.9470405259237415, 0.9738746949934383], 
             UndirectedEdge[263, 485] -> 
             RGBColor[
              0.7594736280171352, 0.8109374635262625, 0.9470413662035344], 
             UndirectedEdge[275, 346] -> 
             RGBColor[
              0.7646483573580491, 0.814014382488798, 0.907694736775945], 
             UndirectedEdge[127, 303] -> 
             RGBColor[
              0.6828605025839412, 0.2670709312780508, 0.4253443640571476], 
             UndirectedEdge[260, 312] -> 
             RGBColor[
              0.9443023885085338, 0.9429115705354505, 0.692554760670544], 
             UndirectedEdge[32, 299] -> 
             RGBColor[
              0.8765036609105393, 0.4198987178069734, 0.3372566648328661], 
             UndirectedEdge[283, 396] -> 
             RGBColor[
              0.8150174542526475, 0.8560961495111132, 0.9689785430035043], 
             UndirectedEdge[87, 253] -> 
             RGBColor[
              0.9508834916230504, 0.9614004519160728, 0.9074538063016286], 
             UndirectedEdge[298, 409] -> 
             RGBColor[
              0.7062016192769673, 0.7689426563866317, 0.9726818883185784], 
             UndirectedEdge[208, 258] -> 
             RGBColor[
              0.8328301671847018, 0.866344697136361, 0.7656585924126262], 
             UndirectedEdge[142, 161] -> 
             RGBColor[
              0.9480036078446386, 0.8662292153225807, 0.6017463608481524], 
             UndirectedEdge[71, 211] -> 
             RGBColor[
              0.9472557959368149, 0.8276624656898655, 0.2812695788879108], 
             UndirectedEdge[14, 453] -> 
             RGBColor[
              0.9923259098471746, 0.991094580753755, 0.776843063948403], 
             UndirectedEdge[89, 478] -> 
             RGBColor[
              0.7198494638913416, 0.5966878647924779, 0.5892161584463727], 
             UndirectedEdge[159, 251] -> 
             RGBColor[
              0.9422598707348514, 0.801631562090707, 0.5228767645160101], 
             UndirectedEdge[300, 305] -> 
             RGBColor[
              0.7721606027609761, 0.4562357707637387, 0.4470015521227987], 
             UndirectedEdge[327, 385] -> 
             RGBColor[
              0.9623539522043623, 0.9707748948355568, 0.9186353832305663], 
             UndirectedEdge[156, 270] -> 
             RGBColor[
              0.76685453798402, 0.8137357206816647, 0.8011881481541319], 
             UndirectedEdge[418, 486] -> 
             RGBColor[
              0.6875424637142651, 0.755832665260627, 0.9694914653995628], 
             UndirectedEdge[366, 465] -> 
             RGBColor[
              0.903014254947131, 0.9255030714986119, 0.9906114998388409], 
             UndirectedEdge[337, 433] -> 
             RGBColor[
              0.9367090119335046, 0.7667515984931588, 0.43661023719381553`], 
             UndirectedEdge[118, 152] -> 
             RGBColor[
              0.861880141669753, 0.4104107564382823, 0.4320867644106019], 
             UndirectedEdge[151, 162] -> 
             RGBColor[
              0.6303904406723118, 0.7023932418896291, 0.9511817659838422], 
             UndirectedEdge[80, 251] -> 
             RGBColor[
              0.6864012674560351, 0.6002685883789682, 0.5928118260624553], 
             UndirectedEdge[348, 486] -> 
             RGBColor[
              0.7852960884100921, 0.3501398186645716, 0.43376238134578804`], 
             UndirectedEdge[376, 455] -> 
             RGBColor[
              0.7446644529305932, 0.8004567973796199, 0.9751848514493073], 
             UndirectedEdge[153, 197] -> 
             RGBColor[
              0.8319613884935784, 0.8692211521367048, 0.9650117241018752], 
             UndirectedEdge[9, 319] -> 
             RGBColor[
              0.5742979533927255, 0.6640303993048622, 0.9603700056547643], 
             UndirectedEdge[184, 336] -> 
             RGBColor[
              0.9323246854962269, 0.9480937520858453, 0.9663411437013028], 
             UndirectedEdge[41, 56] -> 
             RGBColor[
              0.7153892287591541, 0.7772603000765559, 0.9724901797999204], 
             UndirectedEdge[99, 313] -> 
             RGBColor[
              0.8026635894675769, 0.8462823293774293, 0.959501908357703], 
             UndirectedEdge[111, 130] -> 
             RGBColor[
              0.9292349728834212, 0.9414786307901053, 0.7314258123433135], 
             UndirectedEdge[255, 327] -> 
             RGBColor[
              0.87428625627555, 0.41921699981481864`, 0.3911039581409679], 
             UndirectedEdge[32, 84] -> 
             RGBColor[
              0.9127953372327364, 0.9296489539255978, 0.8335248917991266], 
             UndirectedEdge[196, 420] -> 
             RGBColor[
              0.9519341998222323, 0.9598734713224762, 0.7575120900293959], 
             UndirectedEdge[55, 57] -> 
             RGBColor[
              0.7085493589986231, 0.2886390420379883, 0.4271697527905808], 
             UndirectedEdge[10, 480] -> 
             RGBColor[
              0.9758999358733124, 0.9608138245092895, 0.6535881422018409], 
             UndirectedEdge[152, 216] -> 
             RGBColor[
              0.8740715653669988, 0.41912821960682806`, 0.3946619420979218], 
             UndirectedEdge[244, 482] -> 
             RGBColor[
              0.9193619776979252, 0.7606830240858751, 0.5897122638030555], 
             UndirectedEdge[111, 463] -> 
             RGBColor[
              0.9165678503146087, 0.9354868715277069, 0.9633540661995234], 
             UndirectedEdge[58, 74] -> 
             RGBColor[
              0.6262652778034079, 0.6999704952447316, 0.9641444389866063], 
             UndirectedEdge[66, 327] -> 
             RGBColor[
              0.8592505465571951, 0.8893084031024262, 0.9093135251782081], 
             UndirectedEdge[168, 346] -> 
             RGBColor[
              0.7631191263509255, 0.7989217456536462, 0.6753939406153734], 
             UndirectedEdge[53, 471] -> 
             RGBColor[
              0.7720216700171024, 0.8213627376418322, 0.9544182686909322], 
             UndirectedEdge[28, 125] -> 
             RGBColor[
              0.9517276818135523, 0.8496602552065251, 0.5680311657741911], 
             UndirectedEdge[405, 423] -> 
             RGBColor[
              0.9234282625412051, 0.7238064781505632, 0.2739741605321985], 
             UndirectedEdge[314, 493] -> 
             RGBColor[
              0.9949434605339798, 0.9921770052307333, 0.7334634750640083], 
             UndirectedEdge[43, 229] -> 
             RGBColor[
              0.9174906942109513, 0.9362778108819123, 0.9653520470332679], 
             UndirectedEdge[281, 397] -> 
             RGBColor[
              0.9642845182092088, 0.9635410946808092, 0.6974288918386081], 
             UndirectedEdge[203, 324] -> 
             RGBColor[
              0.9533910768622786, 0.8466572330775194, 0.3139626976437859], 
             UndirectedEdge[403, 445] -> 
             RGBColor[
              0.48777390157525297`, 0.5943361349175783, 0.9530118290121238], 
             UndirectedEdge[147, 303] -> 
             RGBColor[
              0.8427224551343073, 0.395398026012176, 0.4393809408689512], 
             UndirectedEdge[356, 457] -> 
             RGBColor[
              0.976190642890555, 0.9492734939525962, 0.6281378692591033], 
             UndirectedEdge[8, 85] -> 
             RGBColor[
              0.5724868378915265, 0.6579901491868219, 0.9621471760926765], 
             UndirectedEdge[301, 336] -> 
             RGBColor[
              0.9456657004861164, 0.9543705969506882, 0.7160142915770769], 
             UndirectedEdge[24, 64] -> 
             RGBColor[
              0.9706442614891084, 0.9758562008535987, 0.8552704636024282], 
             UndirectedEdge[30, 488] -> 
             RGBColor[
              0.48996935130393926`, 0.5965965979651013, 0.9530525629401788], 
             UndirectedEdge[191, 366] -> 
             RGBColor[
              0.894417918078072, 0.7948166997924977, 0.6176561463266594], 
             UndirectedEdge[185, 481] -> 
             RGBColor[
              0.7972886674380083, 0.842310549549343, 0.9704644878650381], 
             UndirectedEdge[308, 389] -> 
             RGBColor[
              0.8942382246429708, 0.8895725826420365, 0.6679598766399563], 
             UndirectedEdge[96, 240] -> 
             RGBColor[
              0.853058248374573, 0.882457953673843, 0.7925783095733855], 
             UndirectedEdge[108, 113] -> 
             RGBColor[
              0.9297464374125604, 0.7511329553635315, 0.5390987371895051], 
             UndirectedEdge[85, 332] -> 
             RGBColor[
              0.8361163387997534, 0.8722339333872127, 0.9842112270095293], 
             UndirectedEdge[232, 280] -> 
             RGBColor[
              0.8548332856482617, 0.5963888266177033, 0.4646736523216841], 
             UndirectedEdge[310, 419] -> 
             RGBColor[
              0.9399532306201025, 0.7873332748303518, 0.5048224062728748], 
             UndirectedEdge[39, 378] -> 
             RGBColor[
              0.9702625876175759, 0.9773424670525076, 0.9352218617908494], 
             UndirectedEdge[53, 257] -> 
             RGBColor[
              0.8656610575133227, 0.41323055728373503`, 0.4256866601082231], 
             UndirectedEdge[248, 339] -> 
             RGBColor[
              0.9465549136435891, 0.958608910799857, 0.9356982271101046], 
             UndirectedEdge[327, 334] -> 
             RGBColor[
              0.9891019459007196, 0.9897613888098017, 0.8302724898924008], 
             UndirectedEdge[165, 358] -> 
             RGBColor[
              0.8036639446562631, 0.7041693598522505, 0.604695130815093], 
             UndirectedEdge[69, 204] -> 
             RGBColor[
              0.9296815046673348, 0.7660679000584438, 0.5707047707474078], 
             UndirectedEdge[208, 293] -> 
             RGBColor[
              0.8898439851023376, 0.9108843250146832, 0.7713411969582353], 
             UndirectedEdge[265, 320] -> 
             RGBColor[
              0.6190117617121123, 0.7010096905036161, 0.9635403949621284], 
             UndirectedEdge[239, 453] -> 
             RGBColor[
              0.8748379793866846, 0.41944515149991, 0.381960478375826], 
             UndirectedEdge[108, 452] -> 
             RGBColor[
              0.8727332741634227, 0.7074861826749936, 0.6014844604337923], 
             UndirectedEdge[331, 418] -> 
             RGBColor[
              0.8067462559947038, 0.8025392352325438, 0.631955290243279], 
             UndirectedEdge[28, 201] -> 
             RGBColor[
              0.9512838356064135, 0.8479005528982009, 0.5676740366975178], 
             UndirectedEdge[431, 486] -> 
             RGBColor[
              0.8211269544166242, 0.7533391286972135, 0.6140735126393768], 
             UndirectedEdge[269, 419] -> 
             RGBColor[
              0.9503041795760012, 0.9604531537448744, 0.8863220894256565], 
             UndirectedEdge[315, 378] -> 
             RGBColor[
              0.9762978684668988, 0.9800113535028862, 0.8429553240437345], 
             UndirectedEdge[57, 240] -> 
             RGBColor[
              0.6014487950568146, 0.6862571644989153, 0.962495605389212], 
             UndirectedEdge[7, 176] -> 
             RGBColor[
              0.9445212726691867, 0.8127346001708217, 0.5282834821681142], 
             UndirectedEdge[6, 302] -> 
             RGBColor[
              0.7922195099537469, 0.432183906617324, 0.4439739059471609], 
             UndirectedEdge[176, 455] -> 
             RGBColor[
              0.9040696583371347, 0.9240334847895193, 0.9007238417824877], 
             UndirectedEdge[161, 396] -> 
             RGBColor[
              0.9397920071558149, 0.860105016974118, 0.6156464588858646], 
             UndirectedEdge[36, 463] -> 
             RGBColor[
              0.9813887928355038, 0.9837027697636024, 0.8263295121330658], 
             UndirectedEdge[131, 373] -> 
             RGBColor[
              0.8973583714861024, 0.7263552733674508, 0.6036819378612391], 
             UndirectedEdge[54, 341] -> 
             RGBColor[
              0.9541504586152063, 0.919326473716614, 0.6367680683083794], 
             UndirectedEdge[272, 453] -> 
             RGBColor[
              0.9669557190490439, 0.9029539456789063, 0.545636644301605], 
             UndirectedEdge[169, 236] -> 
             RGBColor[
              0.9615111046285072, 0.9249857174992127, 0.6246686259161447], 
             UndirectedEdge[69, 101] -> 
             RGBColor[
              0.8470348162104286, 0.7013413757518632, 0.6018435420532529], 
             UndirectedEdge[286, 330] -> 
             RGBColor[
              0.8759834858247051, 0.9039494699310711, 0.9880332809492915], 
             UndirectedEdge[86, 254] -> 
             RGBColor[
              0.9866718432130991, 0.9650279375007375, 0.5451700952491978], 
             UndirectedEdge[68, 319] -> 
             RGBColor[
              0.509516748904584, 0.607920175975244, 0.9562422045885497], 
             UndirectedEdge[37, 207] -> 
             RGBColor[
              0.9281301475328925, 0.9256556280295261, 0.6845971704730882], 
             UndirectedEdge[257, 317] -> 
             RGBColor[
              0.7881366113474993, 0.35235885677204803`, 0.4340454981259927], 
             UndirectedEdge[94, 158] -> 
             RGBColor[
              0.9233344612757237, 0.9414149488226697, 0.9824638479618921], 
             UndirectedEdge[253, 336] -> 
             RGBColor[
              0.905464240181288, 0.9274566232212511, 0.9908451816176025], 
             UndirectedEdge[67, 363] -> 
             RGBColor[
              0.5994713509961709, 0.6857168744721216, 0.9616117271677838], 
             UndirectedEdge[61, 295] -> 
             RGBColor[
              0.6235421004080423, 0.7044845804753987, 0.9640358614760158], 
             UndirectedEdge[16, 116] -> 
             RGBColor[
              0.816906371411886, 0.8575791569161014, 0.9822030949841092], 
             UndirectedEdge[294, 439] -> 
             RGBColor[
              0.8377296170289881, 0.8713615459180732, 0.855723501819361], 
             UndirectedEdge[69, 346] -> 
             RGBColor[
              0.7109454765849768, 0.5934882407699409, 0.5893317254275237], 
             UndirectedEdge[327, 415] -> 
             RGBColor[
              0.949642521133647, 0.8372517551251502, 0.5460871525623403], 
             UndirectedEdge[54, 61] -> 
             RGBColor[
              0.7572810460130712, 0.7634614619997657, 0.6292850856713841], 
             UndirectedEdge[244, 262] -> 
             RGBColor[
              0.8386201556255803, 0.27393159597749905`, 0.18367915122308204`],
              UndirectedEdge[295, 397] -> 
             RGBColor[
              0.8405766680788316, 0.8660457938299098, 0.6894722143661445], 
             UndirectedEdge[61, 264] -> 
             RGBColor[
              0.6042586033845958, 0.6894201660406769, 0.9621138627072441], 
             UndirectedEdge[162, 226] -> 
             RGBColor[
              0.6170208220381398, 0.6922218283937833, 0.9668659572252801], 
             UndirectedEdge[237, 351] -> 
             RGBColor[
              0.8355974403579651, 0.3897167326328945, 0.43870135059900783`], 
             UndirectedEdge[243, 273] -> 
             RGBColor[
              0.8722329029773166, 0.41813182887037237`, 0.4145622399494907], 
             UndirectedEdge[53, 343] -> 
             RGBColor[
              0.8209884182098621, 0.8605451800784041, 0.958663485563678], 
             UndirectedEdge[37, 445] -> 
             RGBColor[
              0.7043453435392383, 0.7463972645328822, 0.664853804624099], 
             UndirectedEdge[144, 402] -> 
             RGBColor[
              0.6567503638213128, 0.7252268396211137, 0.9493280800218717], 
             UndirectedEdge[235, 456] -> 
             RGBColor[
              0.8280131242010391, 0.866355271820056, 0.9756803410029145], 
             UndirectedEdge[369, 456] -> 
             RGBColor[
              0.856632823167746, 0.8887131981706158, 0.9785328851296229], 
             UndirectedEdge[7, 61] -> 
             RGBColor[
              0.7267267256581278, 0.6421932007744107, 0.597848142116634], 
             UndirectedEdge[76, 175] -> 
             RGBColor[
              0.6837588021783018, 0.7526869721773676, 0.9692441591217477], 
             UndirectedEdge[259, 372] -> 
             RGBColor[
              0.8663104837524546, 0.4137148983095418, 0.42458735088286315`], 
             UndirectedEdge[187, 224] -> 
             RGBColor[
              0.7160455774197516, 0.43766321477655873`, 0.4460499349390822], 
             UndirectedEdge[142, 183] -> 
             RGBColor[
              0.6325901799794306, 0.702884914244012, 0.9408730903279119], 
             UndirectedEdge[255, 299] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[233, 444] -> 
             RGBColor[
              0.9692717800767134, 0.9749515174028747, 0.8629187914491125], 
             UndirectedEdge[148, 280] -> 
             RGBColor[
              0.8618076261846251, 0.8926460242475305, 0.9866811748018813], 
             UndirectedEdge[7, 376] -> 
             RGBColor[
              0.7851160672626453, 0.6891579127609222, 0.6027444918349338], 
             UndirectedEdge[73, 256] -> 
             RGBColor[
              0.735588550330106, 0.7884846132081618, 0.8095479165635668], 
             UndirectedEdge[207, 403] -> 
             RGBColor[
              0.7115587055689072, 0.7735944984142221, 0.9727551948611128], 
             UndirectedEdge[233, 346] -> 
             RGBColor[
              0.7680111570196275, 0.81540498656887, 0.8519644437370382], 
             UndirectedEdge[293, 403] -> 
             RGBColor[
              0.6669584475677195, 0.7383068141406441, 0.9684281127978486], 
             UndirectedEdge[321, 391] -> 
             RGBColor[
              0.9749364825736351, 0.9251741379106413, 0.4945557933428688], 
             UndirectedEdge[228, 298] -> 
             RGBColor[
              0.8505299870866364, 0.40162354006115397`, 0.44012563023643037`],
              UndirectedEdge[54, 455] -> 
             RGBColor[
              0.8893581880168652, 0.8679916437062176, 0.6415259466818379], 
             UndirectedEdge[323, 419] -> 
             RGBColor[
              0.8097399680380091, 0.8496987538965949, 0.8726582592943453], 
             UndirectedEdge[65, 194] -> 
             RGBColor[
              0.9348065181250075, 0.770857369767928, 0.5296044161133331], 
             UndirectedEdge[40, 273] -> 
             RGBColor[
              0.8154786581908855, 0.37371867157335387`, 0.4367706978293865], 
             UndirectedEdge[209, 400] -> 
             RGBColor[
              0.8260196543366713, 0.38207966604159066`, 0.4377878128181064], 
             UndirectedEdge[31, 488] -> 
             RGBColor[
              0.38977771277864903`, 0.5120275968365604, 0.9460572690847253], 
             UndirectedEdge[399, 407] -> 
             RGBColor[
              0.8286658499625754, 0.6855255886621636, 0.5997262226385278], 
             UndirectedEdge[292, 399] -> 
             RGBColor[
              0.8119846631528457, 0.6724941187446873, 0.5980635978318876], 
             UndirectedEdge[93, 218] -> 
             RGBColor[
              0.9947179487336646, 0.9914213080459897, 0.6890482300005767], 
             UndirectedEdge[198, 270] -> 
             RGBColor[
              0.767219476518979, 0.8145162873069962, 0.8409094555448471], 
             UndirectedEdge[78, 192] -> 
             RGBColor[
              0.9193965156935616, 0.7114864389232682, 0.254967382044004], 
             UndirectedEdge[286, 492] -> 
             RGBColor[
              0.8897063608027771, 0.9148917179410676, 0.9893421810152552], 
             UndirectedEdge[317, 343] -> 
             RGBColor[
              0.7047017489611271, 0.7692376293108736, 0.9712017425903323], 
             UndirectedEdge[51, 203] -> 
             RGBColor[
              0.8452968217729511, 0.8553060738456528, 0.668874705068394], 
             UndirectedEdge[212, 216] -> 
             RGBColor[
              0.8691276695985286, 0.8971428936334527, 0.9156670580064821], 
             UndirectedEdge[100, 257] -> 
             RGBColor[
              0.8663739836170784, 0.3867040560118732, 0.21498776167016664`], 
             UndirectedEdge[189, 302] -> 
             RGBColor[
              0.7965371803015471, 0.43555690350853554`, 0.44440425097650627`],
              UndirectedEdge[306, 382] -> 
             RGBColor[
              0.9462295798390397, 0.9577534684832237, 0.9097855172718912], 
             UndirectedEdge[20, 150] -> 
             RGBColor[
              0.801317192631838, 0.7334927561034357, 0.6111311723030775], 
             UndirectedEdge[255, 446] -> 
             RGBColor[
              0.86872546433999, 0.41551598687755775`, 0.42049941867597906`], 
             UndirectedEdge[182, 237] -> 
             RGBColor[
              0.8226948667451142, 0.3794285706650379, 0.43747069160955077`], 
             UndirectedEdge[4, 366] -> 
             RGBColor[
              0.8701763044006257, 0.6255499256958391, 0.46947891334373826`], 
             UndirectedEdge[231, 275] -> 
             RGBColor[
              0.8740160278695045, 0.41910525342436555`, 0.3955823421578384], 
             UndirectedEdge[97, 231] -> 
             RGBColor[
              0.6828605025839412, 0.2670709312780508, 0.4253443640571476], 
             UndirectedEdge[114, 128] -> 
             RGBColor[
              0.9371852584636482, 0.7691080167911634, 0.4786557591669073], 
             UndirectedEdge[207, 471] -> 
             RGBColor[
              0.7284078456918357, 0.7872733894111281, 0.9740816208920235], 
             UndirectedEdge[54, 391] -> 
             RGBColor[
              0.9777255854318756, 0.9349305190197678, 0.503578112964798], 
             UndirectedEdge[299, 478] -> 
             RGBColor[
              0.8374937857442898, 0.2688170134169282, 0.18273928058428096`], 
             UndirectedEdge[44, 365] -> 
             RGBColor[
              0.8857354967381238, 0.5239480945298864, 0.2413852701402317], 
             UndirectedEdge[6, 101] -> 
             RGBColor[
              0.7613956574402418, 0.8135273415044213, 0.9768524615528335], 
             UndirectedEdge[236, 308] -> 
             RGBColor[
              0.8884655197740707, 0.9132555514540184, 0.9652242954141621], 
             UndirectedEdge[47, 256] -> 
             RGBColor[
              0.6712137814725218, 0.74090682824049, 0.969502949469855], 
             UndirectedEdge[304, 427] -> 
             RGBColor[
              0.9872192925051888, 0.9671065352714192, 0.5275757948140825], 
             UndirectedEdge[54, 397] -> 
             RGBColor[
              0.9743156136838604, 0.9250226753542768, 0.35472143856151284`], 
             UndirectedEdge[220, 254] -> 
             RGBColor[
              0.7388402457126184, 0.7712383832366205, 0.6616356541339736], 
             UndirectedEdge[377, 426] -> 
             RGBColor[
              0.8205195779689204, 0.3776940544415418, 0.43726321062417406`], 
             UndirectedEdge[216, 292] -> 
             RGBColor[
              0.8661607392810866, 0.8948251051199615, 0.9153713421199796], 
             UndirectedEdge[42, 119] -> 
             RGBColor[
              0.5976182243145235, 0.6828923410189598, 0.9623683893360122], 
             UndirectedEdge[170, 491] -> 
             RGBColor[
              0.9414407008665516, 0.7950798855426213, 0.3164813925893477], 
             UndirectedEdge[257, 326] -> 
             RGBColor[
              0.8225993270974847, 0.3793523899433728, 0.43746157895267057`], 
             UndirectedEdge[98, 347] -> 
             RGBColor[
              0.8548261056939614, 0.7360866780693459, 0.6082210497304876], 
             UndirectedEdge[271, 311] -> 
             RGBColor[
              0.9678590039033108, 0.9376712971963926, 0.6308024502322738], 
             UndirectedEdge[156, 227] -> 
             RGBColor[
              0.9383334493294981, 0.7742062048462757, 0.4344394452005812], 
             UndirectedEdge[151, 160] -> 
             RGBColor[
              0.9747796675143888, 0.9785967493426304, 0.8234771625838723], 
             UndirectedEdge[93, 167] -> 
             RGBColor[
              0.9553645608742203, 0.9633517835714054, 0.8180721435795625], 
             UndirectedEdge[275, 348] -> 
             RGBColor[
              0.8740160278695045, 0.41910525342436566`, 0.3955823421578384], 
             UndirectedEdge[34, 394] -> 
             RGBColor[
              0.8590845549260162, 0.88933330872943, 0.916306273857167], 
             UndirectedEdge[405, 488] -> 
             RGBColor[
              0.662475891547821, 0.5535282014738365, 0.5854984976532444], 
             UndirectedEdge[338, 443] -> 
             RGBColor[
              0.9854436293887852, 0.9882485809176709, 0.8909002619148038], 
             UndirectedEdge[301, 316] -> 
             RGBColor[
              0.9285699941267274, 0.9407389447502982, 0.7143836878430012], 
             UndirectedEdge[103, 209] -> 
             RGBColor[
              0.9040196633102997, 0.885148285979648, 0.6509884458265873], 
             UndirectedEdge[126, 414] -> 
             RGBColor[
              0.987382132082858, 0.9890502015989167, 0.8587742555898596], 
             UndirectedEdge[154, 341] -> 
             RGBColor[
              0.73926832509567, 0.7952479095284753, 0.9646017583826207], 
             UndirectedEdge[306, 347] -> 
             RGBColor[
              0.9017923986579184, 0.9223655827010927, 0.9055350867886992], 
             UndirectedEdge[20, 388] -> 
             RGBColor[
              0.4776703387101491, 0.577745121566207, 0.953959150857393], 
             UndirectedEdge[286, 319] -> 
             RGBColor[
              0.7991216573435376, 0.8435863554568146, 0.9804568181708255], 
             UndirectedEdge[62, 96] -> 
             RGBColor[
              0.949152610330301, 0.9582072858239759, 0.8019757296889811], 
             UndirectedEdge[149, 242] -> 
             RGBColor[
              0.7406462005536159, 0.7967880773560111, 0.9755295860994676], 
             UndirectedEdge[212, 319] -> 
             RGBColor[
              0.7281456370278796, 0.7875521728487691, 0.9735384102572362], 
             UndirectedEdge[289, 470] -> 
             RGBColor[
              0.9869698745399385, 0.988879722510384, 0.865606429964356], 
             UndirectedEdge[291, 353] -> 
             RGBColor[
              0.9727902539165174, 0.9774675844707721, 0.8521262501890663], 
             UndirectedEdge[21, 91] -> 
             RGBColor[
              0.6213002507392107, 0.7024385843134946, 0.9640138660424208], 
             UndirectedEdge[95, 224] -> 
             RGBColor[
              0.7197680687498449, 0.7688926417863857, 0.6797623694410722], 
             UndirectedEdge[218, 235] -> 
             RGBColor[
              0.8534046467293472, 0.8835096213988095, 0.8528703621879963], 
             UndirectedEdge[108, 315] -> 
             RGBColor[
              0.9337926644823953, 0.7528061742402008, 0.47204228334235127`], 
             UndirectedEdge[61, 154] -> 
             RGBColor[
              0.5423989124935349, 0.639382897811627, 0.9571187757456254], 
             UndirectedEdge[297, 413] -> 
             RGBColor[
              0.7791636580727077, 0.7549552702343422, 0.6178812750213643], 
             UndirectedEdge[294, 438] -> 
             RGBColor[
              0.9832974898361816, 0.9853692685115478, 0.8372691964155743], 
             UndirectedEdge[277, 386] -> 
             RGBColor[
              0.9938883213575648, 0.9902752290447481, 0.6444271880914642], 
             UndirectedEdge[125, 249] -> 
             RGBColor[
              0.9219646442918519, 0.8275040703396155, 0.6226846031543478], 
             UndirectedEdge[211, 308] -> 
             RGBColor[
              0.8749005807365249, 0.8182610785946102, 0.6245072041269171], 
             UndirectedEdge[273, 477] -> 
             RGBColor[
              0.789176434282747, 0.3531711743520105, 0.4341491379584804], 
             UndirectedEdge[154, 397] -> 
             RGBColor[
              0.7594334801643241, 0.8009441111661382, 0.6825551286357542], 
             UndirectedEdge[105, 230] -> 
             RGBColor[
              0.9502401635514743, 0.8273274636329311, 0.4864096205538401], 
             UndirectedEdge[355, 404] -> 
             RGBColor[
              0.7881366113474993, 0.3523588567720481, 0.4340454981259928], 
             UndirectedEdge[250, 263] -> 
             RGBColor[
              0.911723616546287, 0.9315745366393753, 0.9611697771042433], 
             UndirectedEdge[11, 259] -> 
             RGBColor[
              0.8658316052787483, 0.8955425251054245, 0.9613869784218303], 
             UndirectedEdge[339, 439] -> 
             RGBColor[
              0.8335721271746086, 0.8696423170206715, 0.924623867945277], 
             UndirectedEdge[303, 379] -> 
             RGBColor[
              0.8503299877329296, 0.401464066005346, 0.44010655411953226`], 
             UndirectedEdge[416, 468] -> 
             RGBColor[
              0.716122191316486, 0.7773762738340879, 0.9730259017312672], 
             UndirectedEdge[77, 336] -> 
             RGBColor[
              0.9459642277259446, 0.9567610327536098, 0.87585295455557], 
             UndirectedEdge[297, 412] -> 
             RGBColor[
              0.7949738971346072, 0.7677184968432647, 0.6191753042683474], 
             UndirectedEdge[69, 418] -> 
             RGBColor[
              0.7669194921303113, 0.6387546756814608, 0.5938583952692169], 
             UndirectedEdge[281, 322] -> 
             RGBColor[
              0.6009987305934555, 0.673693415613605, 0.9620759912412558], 
             UndirectedEdge[51, 495] -> 
             RGBColor[
              0.6366449972076913, 0.7148069618521367, 0.9652828328069696], 
             UndirectedEdge[227, 229] -> 
             RGBColor[
              0.8758134463964321, 0.7282408295531935, 0.6053908715818883], 
             UndirectedEdge[192, 497] -> 
             RGBColor[
              0.9747777910269446, 0.928611997869581, 0.5282455274833853], 
             UndirectedEdge[143, 277] -> 
             RGBColor[
              0.9945575634438232, 0.9920174268668507, 0.73985878851756], 
             UndirectedEdge[87, 161] -> 
             RGBColor[
              0.9594641661604251, 0.8738920166041326, 0.5427385045573866], 
             UndirectedEdge[114, 255] -> 
             RGBColor[
              0.8764745937718037, 0.42012193360722805`, 0.3548375425921436], 
             UndirectedEdge[341, 391] -> 
             RGBColor[
              0.9715119213432213, 0.9762959724235067, 0.8398236506509629], 
             UndirectedEdge[35, 347] -> 
             RGBColor[
              0.6549266975011709, 0.7281025418598308, 0.9677792680333432], 
             UndirectedEdge[99, 498] -> 
             RGBColor[
              0.8646698889204719, 0.4124913453700766, 0.42736444999774836`], 
             UndirectedEdge[89, 448] -> 
             RGBColor[
              0.7775175195073616, 0.8214992934895795, 0.7288279464329221], 
             UndirectedEdge[130, 371] -> 
             RGBColor[
              0.7916721984570404, 0.8328493454329491, 0.7183568976833314], 
             UndirectedEdge[187, 481] -> 
             RGBColor[
              0.7816893196569642, 0.49093785817025015`, 0.4512462159137378], 
             UndirectedEdge[427, 500] -> 
             RGBColor[
              0.8600403364284055, 0.8883282525249747, 0.8265807729454913], 
             UndirectedEdge[134, 247] -> 
             RGBColor[
              0.708251316528368, 0.4293665834930986, 0.4453507173013951], 
             UndirectedEdge[79, 301] -> 
             RGBColor[
              0.892233706171205, 0.5449097081235207, 0.27252693694719493`], 
             UndirectedEdge[173, 323] -> 
             RGBColor[
              0.539116323058979, 0.6366495040118447, 0.956879268406402], 
             UndirectedEdge[84, 262] -> 
             RGBColor[
              0.8217852305779516, 0.3787032514767585, 0.43738392969988493`], 
             UndirectedEdge[262, 391] -> 
             RGBColor[
              0.8765750160532969, 0.42005133924222016`, 0.34502323176912714`],
              UndirectedEdge[205, 382] -> 
             RGBColor[
              0.9492476389825286, 0.9590015134996386, 0.8597684667775864], 
             UndirectedEdge[50, 499] -> 
             RGBColor[
              0.7066647623764493, 0.7707711503103778, 0.9713973974221684], 
             UndirectedEdge[108, 380] -> 
             RGBColor[
              0.7314378949063093, 0.5958815811288363, 0.5880584198271808], 
             UndirectedEdge[300, 493] -> 
             RGBColor[
              0.8131038670072497, 0.8518480853950345, 0.8486085269507779], 
             UndirectedEdge[331, 382] -> 
             RGBColor[
              0.9314671649308564, 0.9006453793158353, 0.6442076524150006], 
             UndirectedEdge[186, 495] -> 
             RGBColor[
              0.6690237664421624, 0.7401015024658661, 0.9685100459274598], 
             UndirectedEdge[93, 235] -> 
             RGBColor[
              0.8532008151220773, 0.8827628895310458, 0.8080958202192619], 
             UndirectedEdge[18, 300] -> 
             RGBColor[
              0.7754732421205519, 0.71543495775266, 0.6091814727467315], 
             UndirectedEdge[223, 246] -> 
             RGBColor[
              0.9341556958599548, 0.834571800007219, 0.6086386192480736], 
             UndirectedEdge[233, 431] -> 
             RGBColor[
              0.9575696632673212, 0.8581778849169763, 0.5010731608185455], 
             UndirectedEdge[182, 351] -> 
             RGBColor[
              0.8528004606546189, 0.8854639549468986, 0.9858220633128378], 
             UndirectedEdge[163, 209] -> 
             RGBColor[
              0.9006999027778112, 0.9230831341076964, 0.9704712382690954], 
             UndirectedEdge[70, 182] -> 
             RGBColor[
              0.8845970850998284, 0.9108164676974866, 0.9888114292740717], 
             UndirectedEdge[59, 335] -> 
             RGBColor[
              0.8216725042527788, 0.8591124632992911, 0.8674930982627092], 
             UndirectedEdge[258, 453] -> 
             RGBColor[
              0.8308826551059205, 0.8668429027928632, 0.8926883733182917], 
             UndirectedEdge[161, 354] -> 
             RGBColor[
              0.9394127511998513, 0.8598221685031351, 0.6162884402935158], 
             UndirectedEdge[213, 489] -> 
             RGBColor[
              0.9415123008162636, 0.9547966610177837, 0.944275078116194], 
             UndirectedEdge[260, 407] -> 
             RGBColor[
              0.8813178480342438, 0.8930278825705806, 0.6864574181313445], 
             UndirectedEdge[95, 185] -> 
             RGBColor[
              0.9674866897360057, 0.9661455066403044, 0.6924674823698675], 
             UndirectedEdge[117, 479] -> 
             RGBColor[
              0.7844849620460352, 0.8322517560989733, 0.9760721728736144], 
             UndirectedEdge[164, 444] -> 
             RGBColor[
              0.6575990526077943, 0.7268208291135971, 0.9619172729233669], 
             UndirectedEdge[32, 334] -> 
             RGBColor[
              0.9924280528532037, 0.9907839657980337, 0.7495015499302481], 
             UndirectedEdge[46, 325] -> 
             RGBColor[
              0.9350903058825193, 0.9067693254011875, 0.6493122686386887], 
             UndirectedEdge[18, 201] -> 
             RGBColor[
              0.9181916507672312, 0.7133641868480631, 0.25303328579979706`], 
             UndirectedEdge[328, 398] -> 
             RGBColor[
              0.8783627122328992, 0.47327314765590944`, 0.42349653330275117`],
              UndirectedEdge[376, 448] -> 
             RGBColor[
              0.8320780604981131, 0.8653556126523338, 0.7334228789415478], 
             UndirectedEdge[326, 355] -> 
             RGBColor[
              0.7814659076674761, 0.8293128700731314, 0.9788246156179949], 
             UndirectedEdge[257, 281] -> 
             RGBColor[
              0.8583133105848524, 0.40775061965531323`, 0.4381244790588017], 
             UndirectedEdge[32, 89] -> 
             RGBColor[
              0.778364276640716, 0.8233104213775456, 0.8209922348192504], 
             UndirectedEdge[341, 397] -> 
             RGBColor[
              0.9681019495952062, 0.9663881287580158, 0.6909669762476777], 
             UndirectedEdge[160, 274] -> 
             RGBColor[
              0.9901691498994779, 0.9770263529406737, 0.5416496799974067], 
             UndirectedEdge[151, 235] -> 
             RGBColor[
              0.8332777413355332, 0.8702816146589423, 0.9667687174262727], 
             UndirectedEdge[11, 372] -> 
             RGBColor[
              0.8006692531000443, 0.36214945176074137`, 0.4352946347316905], 
             UndirectedEdge[99, 295] -> 
             RGBColor[
              0.8261289491276091, 0.8646136466871852, 0.9618407161123614], 
             UndirectedEdge[154, 199] -> 
             RGBColor[
              0.7629093267796432, 0.8110473781208762, 0.8425451666103327], 
             UndirectedEdge[169, 308] -> 
             RGBColor[
              0.8874477025627526, 0.8666665571750543, 0.6415799806408033], 
             UndirectedEdge[158, 410] -> 
             RGBColor[
              0.9413412174653533, 0.9557729565473774, 0.9841781975571526], 
             UndirectedEdge[311, 465] -> 
             RGBColor[
              0.9485806430935225, 0.9609732912810032, 0.9650306265066473], 
             UndirectedEdge[139, 428] -> 
             RGBColor[
              0.959520108083308, 0.8653820561840353, 0.40352568689948154`], 
             UndirectedEdge[113, 364] -> 
             RGBColor[
              0.9673030003111516, 0.9746474462069995, 0.9183885364370333], 
             UndirectedEdge[89, 475] -> 
             RGBColor[
              0.7391740514871261, 0.7957144867175461, 0.9752737725583647], 
             UndirectedEdge[375, 441] -> 
             RGBColor[
              0.8761892856341646, 0.42000395136022955`, 0.35956583678661314`],
              UndirectedEdge[244, 295] -> 
             RGBColor[
              0.7870543491852718, 0.656774022598319, 0.596312767950362], 
             UndirectedEdge[187, 260] -> 
             RGBColor[
              0.8938536130503593, 0.5691057328705197, 0.26086052668206744`], 
             UndirectedEdge[207, 322] -> 
             RGBColor[
              0.5684065266608943, 0.6478239738255336, 0.9630826150164791], 
             UndirectedEdge[100, 457] -> 
             RGBColor[
              0.9675657355990548, 0.9022537516274844, 0.3284994368095625], 
             UndirectedEdge[364, 416] -> 
             RGBColor[
              0.7576183188014673, 0.8101604098400955, 0.9664526477401885], 
             UndirectedEdge[313, 386] -> 
             RGBColor[
              0.8197694041710778, 0.8560141334570888, 0.7541530189196402], 
             UndirectedEdge[31, 472] -> 
             RGBColor[
              0.6114846082162748, 0.5254823055085267, 0.5856303887635171], 
             UndirectedEdge[37, 49] -> 
             RGBColor[
              0.8554573026094243, 0.8684374254926999, 0.6774720752986512], 
             UndirectedEdge[201, 406] -> 
             RGBColor[
              0.7668871284394178, 0.7036965401603634, 0.607407807561958], 
             UndirectedEdge[245, 376] -> 
             RGBColor[
              0.7790822610782662, 0.6617598081088945, 0.5977097360525643], 
             UndirectedEdge[58, 215] -> 
             RGBColor[
              0.42612452738081674`, 0.5411743060773848, 0.9490184440744266], 
             UndirectedEdge[84, 407] -> 
             RGBColor[
              0.8044124239072457, 0.8472191228423334, 0.9811169483295645], 
             UndirectedEdge[100, 324] -> 
             RGBColor[
              0.9470654677297679, 0.8253194681499055, 0.289388900655033], 
             UndirectedEdge[89, 176] -> 
             RGBColor[
              0.7758213169471068, 0.8226116959068248, 0.8887843979817083], 
             UndirectedEdge[75, 379] -> 
             RGBColor[
              0.9199289251261672, 0.8352857804375369, 0.6245964537077602], 
             UndirectedEdge[123, 422] -> 
             RGBColor[
              0.8717960485993784, 0.9001087777989729, 0.9572628918797887], 
             UndirectedEdge[407, 455] -> 
             RGBColor[
              0.7982297047052531, 0.8423023791769757, 0.9805237351504676], 
             UndirectedEdge[333, 358] -> 
             RGBColor[
              0.9078740107336631, 0.7863568548833115, 0.6148754122614645], 
             UndirectedEdge[120, 124] -> 
             RGBColor[
              0.6642313840818084, 0.7264487171971736, 0.731489929974516], 
             UndirectedEdge[88, 433] -> 
             RGBColor[
              0.8378217489284411, 0.27030621763841134`, 0.18301294110425004`],
              UndirectedEdge[345, 456] -> 
             RGBColor[
              0.8979890678294802, 0.921278486161589, 0.9825865630622661], 
             UndirectedEdge[392, 474] -> 
             RGBColor[
              0.7394464273039305, 0.7964919664363123, 0.9746548631572789], 
             UndirectedEdge[165, 333] -> 
             RGBColor[
              0.8120049385446457, 0.8538414959335239, 0.9816903176809112], 
             UndirectedEdge[31, 133] -> 
             RGBColor[
              0.6716452774521646, 0.36170343136584593`, 0.43830563016563606`],
              UndirectedEdge[171, 208] -> 
             RGBColor[
              0.9938969171228874, 0.9893544477792164, 0.5770952765669656], 
             UndirectedEdge[284, 472] -> 
             RGBColor[
              0.5934506132856843, 0.5088992771211285, 0.5845165346142854], 
             UndirectedEdge[196, 427] -> 
             RGBColor[
              0.9941239606870849, 0.9898400710054092, 0.6018075673793977], 
             UndirectedEdge[179, 334] -> 
             RGBColor[
              0.7094062086504341, 0.7679889460792662, 0.8821073533454339], 
             UndirectedEdge[97, 233] -> 
             RGBColor[
              0.7040395953417468, 0.7624008811336965, 0.847223766283572], 
             UndirectedEdge[21, 409] -> 
             RGBColor[
              0.6015440944575452, 0.6863996466393405, 0.9624585890507431], 
             UndirectedEdge[63, 344] -> 
             RGBColor[
              0.6781286876996748, 0.7479533934448592, 0.9689122418807286], 
             UndirectedEdge[292, 398] -> 
             RGBColor[
              0.8616684130703757, 0.8920370565823762, 0.948157561647075], 
             UndirectedEdge[71, 197] -> 
             RGBColor[
              0.8332766354400878, 0.8225582508943535, 0.6335675687816857], 
             UndirectedEdge[81, 121] -> 
             RGBColor[
              0.7476681061720286, 0.7976170354605446, 0.7552329117947458], 
             UndirectedEdge[163, 317] -> 
             RGBColor[
              0.8438753382940531, 0.8785019202033825, 0.964857766230925], 
             UndirectedEdge[167, 172] -> 
             RGBColor[
              0.8956243244100004, 0.7307338902744872, 0.6046539737257121], 
             UndirectedEdge[191, 488] -> 
             RGBColor[
              0.6779761640766604, 0.6220189961714713, 0.5983344171064984], 
             UndirectedEdge[392, 490] -> 
             RGBColor[
              0.828979516186499, 0.8664829692312014, 0.9835465004620281], 
             UndirectedEdge[251, 272] -> 
             RGBColor[
              0.9191818861286511, 0.7144388131832337, 0.2536825562294555], 
             UndirectedEdge[66, 255] -> 
             RGBColor[
              0.7883061080959134, 0.35249126892013216`, 0.43406239197783747`],
              UndirectedEdge[177, 194] -> 
             RGBColor[
              0.875633032584384, 0.9020177031167766, 0.9069187852964552], 
             UndirectedEdge[36, 359] -> 
             RGBColor[
              0.9298156037008808, 0.9434031776789661, 0.849960602978381], 
             UndirectedEdge[46, 377] -> 
             RGBColor[
              0.8656025309873914, 0.38410176514624755`, 0.21199081388043767`],
              UndirectedEdge[6, 306] -> 
             RGBColor[
              0.8489543420647578, 0.8810880913064121, 0.9002686831072055], 
             UndirectedEdge[7, 455] -> 
             RGBColor[
              0.8588038676619216, 0.7467233824808623, 0.6100890031270876], 
             UndirectedEdge[84, 482] -> 
             RGBColor[
              0.8941095901264821, 0.9178405073347643, 0.97026943151826], 
             UndirectedEdge[83, 97] -> 
             RGBColor[
              0.5439930441644971, 0.6391226238925847, 0.9578715076917402], 
             UndirectedEdge[125, 408] -> 
             RGBColor[
              0.9084112924945419, 0.6731562804559877, 0.24508970175752104`], 
             UndirectedEdge[184, 473] -> 
             RGBColor[
              0.9675951191314796, 0.9753530734231557, 0.9397371901506066], 
             UndirectedEdge[410, 422] -> 
             RGBColor[
              0.9526305143509985, 0.9641924956801644, 0.9650683626499481], 
             UndirectedEdge[202, 283] -> 
             RGBColor[
              0.836495065078424, 0.8687703409422983, 0.7309901797186901], 
             UndirectedEdge[320, 329] -> 
             RGBColor[
              0.7714232212932521, 0.33930222943520105`, 0.4323796636008955], 
             UndirectedEdge[146, 387] -> 
             RGBColor[
              0.7103326184278462, 0.7722366029765579, 0.9730759067053758], 
             UndirectedEdge[107, 170] -> 
             RGBColor[
              0.9546509431645422, 0.9518685782090858, 0.6945794788858659], 
             UndirectedEdge[273, 459] -> 
             RGBColor[
              0.8510092923089906, 0.3274680291721606, 0.19387626107363007`], 
             UndirectedEdge[5, 395] -> 
             RGBColor[
              0.41157276491247397`, 0.516107045349748, 0.9491003493461329], 
             UndirectedEdge[104, 242] -> 
             RGBColor[
              0.768368166057328, 0.8087987732716976, 0.6841516747775551], 
             UndirectedEdge[422, 437] -> 
             RGBColor[
              0.7609647031588207, 0.8121479854984524, 0.9471587491006761], 
             UndirectedEdge[29, 177] -> 
             RGBColor[
              0.8405770750901531, 0.8761814785512725, 0.9845330228518294], 
             UndirectedEdge[202, 285] -> 
             RGBColor[
              0.9931801836158757, 0.987821427280592, 0.4990832574952214], 
             UndirectedEdge[182, 460] -> 
             RGBColor[
              0.8495969351316004, 0.5862096568451063, 0.4632321426779905], 
             UndirectedEdge[116, 333] -> 
             RGBColor[
              0.8225589653909906, 0.8620863819194633, 0.9827422444439664], 
             UndirectedEdge[405, 472] -> 
             RGBColor[
              0.8841827869854468, 0.5669829101458028, 0.22507161733203618`], 
             UndirectedEdge[51, 96] -> 
             RGBColor[
              0.8538437290305158, 0.8830715771321397, 0.7926565989444359], 
             UndirectedEdge[115, 402] -> 
             RGBColor[
              0.7910410696090908, 0.8369245446596829, 0.9591609749405398], 
             UndirectedEdge[67, 120] -> 
             RGBColor[
              0.8072116467941433, 0.8457367934875555, 0.7418588562049426], 
             UndirectedEdge[72, 222] -> 
             RGBColor[
              0.9596256281020655, 0.9184916279624664, 0.6170595880955523], 
             UndirectedEdge[84, 328] -> 
             RGBColor[
              0.829071261584326, 0.4347068785508967, 0.4443610412199841], 
             UndirectedEdge[123, 401] -> 
             RGBColor[
              0.7421842964800994, 0.7985192803106069, 0.9749376526327019], 
             UndirectedEdge[143, 178] -> 
             RGBColor[
              0.8909232167537526, 0.5308506782690312, 0.3678788640678603], 
             UndirectedEdge[2, 385] -> 
             RGBColor[
              0.9329749906804496, 0.9493726250632948, 0.9927645410407662], 
             UndirectedEdge[113, 487] -> 
             RGBColor[
              0.7300655244137486, 0.7859946733830675, 0.9073213213495408], 
             UndirectedEdge[12, 430] -> 
             RGBColor[
              0.898839764562795, 0.9219874341734309, 0.9837295095656529], 
             UndirectedEdge[72, 344] -> 
             RGBColor[
              0.8554056869276714, 0.8874271537722347, 0.9618378315273184], 
             UndirectedEdge[127, 221] -> 
             RGBColor[
              0.6886468153130365, 0.7104961469339652, 0.6298598347984006], 
             UndirectedEdge[466, 491] -> 
             RGBColor[
              0.8558795753886769, 0.3892071147755576, 0.1995259227752825], 
             UndirectedEdge[236, 289] -> 
             RGBColor[
              0.9751957750922009, 0.9804118054647524, 0.8995620648691112], 
             UndirectedEdge[200, 298] -> 
             RGBColor[
              0.9554151055437632, 0.9641765667062239, 0.8715288319273331], 
             UndirectedEdge[231, 431] -> 
             RGBColor[
              0.8518805478676574, 0.33092226713357065`, 0.19457729374712981`],
              UndirectedEdge[171, 238] -> 
             RGBColor[
              0.9876795251954442, 0.9876124926725949, 0.7536409203814176], 
             UndirectedEdge[276, 306] -> 
             RGBColor[
              0.6811551722658569, 0.743700468256547, 0.8869654330985381], 
             UndirectedEdge[294, 296] -> 
             RGBColor[
              0.979269395926046, 0.9823651226687672, 0.8440877087102847], 
             UndirectedEdge[1, 119] -> 
             RGBColor[
              0.7290610186930846, 0.7843245677419544, 0.8715164995801912], 
             UndirectedEdge[103, 444] -> 
             RGBColor[
              0.954513120416171, 0.9251858201035164, 0.6480182978506897], 
             UndirectedEdge[331, 486] -> 
             RGBColor[
              0.8404540575107151, 0.8288720259656317, 0.6353149688810803], 
             UndirectedEdge[100, 281] -> 
             RGBColor[
              0.9523929413028961, 0.9234280135007795, 0.6512323610934525], 
             UndirectedEdge[161, 477] -> 
             RGBColor[
              0.8311519544771664, 0.7745555293304855, 0.6180366718652797], 
             UndirectedEdge[391, 475] -> 
             RGBColor[
              0.9557897902921646, 0.9640751509137908, 0.8492653826421042], 
             UndirectedEdge[2, 312] -> 
             RGBColor[
              0.9167695414040204, 0.9364711635420314, 0.9919234913405883], 
             UndirectedEdge[264, 341] -> 
             RGBColor[
              0.8011280159867309, 0.8452851777575252, 0.9695968453442394], 
             UndirectedEdge[73, 434] -> 
             RGBColor[
              0.8984704937663743, 0.9182706992509353, 0.8240448468937842], 
             UndirectedEdge[241, 271] -> 
             RGBColor[
              0.6974736714103178, 0.7221474725658009, 0.6365278071831694], 
             UndirectedEdge[49, 51] -> 
             RGBColor[
              0.7216151542360718, 0.7824505100583015, 0.9728875127633803], 
             UndirectedEdge[5, 275] -> 
             RGBColor[
              0.80583296428755, 0.8474499017395656, 0.9109369398976215], 
             UndirectedEdge[18, 274] -> 
             RGBColor[
              0.9525754126385572, 0.8409654744465347, 0.3261072935117726], 
             UndirectedEdge[219, 445] -> 
             RGBColor[
              0.6231856945750848, 0.7015663180387753, 0.9655201412839891], 
             UndirectedEdge[177, 297] -> 
             RGBColor[
              0.8527176470508876, 0.8128283531466165, 0.6249306616139791], 
             UndirectedEdge[250, 365] -> 
             RGBColor[
              0.8461863304612168, 0.5130518686887953, 0.4540909381989574], 
             UndirectedEdge[325, 474] -> 
             RGBColor[
              0.7736485471837987, 0.8237638084367072, 0.9779170918840137], 
             UndirectedEdge[266, 403] -> 
             RGBColor[
              0.5364127659423112, 0.6345230743685147, 0.9566475243611359], 
             UndirectedEdge[214, 470] -> 
             RGBColor[
              0.5825020603676503, 0.6469522729347199, 0.9069513354399967], 
             UndirectedEdge[152, 481] -> 
             RGBColor[
              0.7608912199358888, 0.3310745499286538, 0.43132993213274207`], 
             UndirectedEdge[289, 466] -> 
             RGBColor[
              0.8858987183171937, 0.5093437131436217, 0.4043168216917494], 
             UndirectedEdge[126, 269] -> 
             RGBColor[
              0.9487198293336657, 0.9597979842037245, 0.9125788731081501], 
             UndirectedEdge[183, 396] -> 
             RGBColor[
              0.6243785792906069, 0.6967607158955493, 0.9547731883656241], 
             UndirectedEdge[54, 99] -> 
             RGBColor[
              0.9598678947326382, 0.9235905282115523, 0.6270899403077297], 
             UndirectedEdge[129, 306] -> 
             RGBColor[
              0.7110753846537323, 0.7696158523933242, 0.8888719225744885], 
             UndirectedEdge[172, 236] -> 
             RGBColor[
              0.9187812830188902, 0.7485067506812831, 0.5828751445068225], 
             UndirectedEdge[162, 284] -> 
             RGBColor[
              0.3022222236837059, 0.4349850974602662, 0.9405224805898492], 
             UndirectedEdge[10, 189] -> 
             RGBColor[
              0.8469409265837693, 0.8806449506641316, 0.9524157012645447], 
             UndirectedEdge[213, 332] -> 
             RGBColor[
              0.9231628172114301, 0.9401652808747532, 0.9425248879891877], 
             UndirectedEdge[199, 245] -> 
             RGBColor[
              0.9412033337598569, 0.786459576431632, 0.4782397771989716], 
             UndirectedEdge[123, 139] -> 
             RGBColor[
              0.8497211322064018, 0.7826887312108635, 0.6184761815305126], 
             UndirectedEdge[391, 482] -> 
             RGBColor[
              0.9762942683395, 0.9798626389829568, 0.8317283846221233], 
             UndirectedEdge[184, 354] -> 
             RGBColor[
              0.9576925219774156, 0.9679677326796695, 0.956499704121458], 
             UndirectedEdge[25, 316] -> 
             RGBColor[
              0.8948906161722932, 0.9190255024498566, 0.989836659920439], 
             UndirectedEdge[106, 479] -> 
             RGBColor[
              0.7297024972016741, 0.787776883216404, 0.9717594965662854], 
             UndirectedEdge[118, 260] -> 
             RGBColor[
              0.9677654824985552, 0.9612257716008084, 0.6811105109675104], 
             UndirectedEdge[304, 469] -> 
             RGBColor[
              0.9718718627762574, 0.9578096941888703, 0.6604066192654348], 
             UndirectedEdge[93, 236] -> 
             RGBColor[
              0.9785215194831101, 0.9811246439782013, 0.796293314360673], 
             UndirectedEdge[343, 445] -> 
             RGBColor[
              0.5535897898909412, 0.6471974683510562, 0.9585834719157803], 
             UndirectedEdge[204, 444] -> 
             RGBColor[
              0.9618832822470287, 0.9710931948270068, 0.9494058401103334], 
             UndirectedEdge[150, 412] -> 
             RGBColor[
              0.7826661622753637, 0.7189224294358771, 0.6092722119009323], 
             UndirectedEdge[14, 239] -> 
             RGBColor[
              0.8764712938447652, 0.4201205690025933, 0.35489223092310934`], 
             UndirectedEdge[70, 442] -> 
             RGBColor[
              0.8567951899881048, 0.4066184077999533, 0.44069426123983046`], 
             UndirectedEdge[93, 493] -> 
             RGBColor[
              0.9947396289267099, 0.9914302733629696, 0.6886889330952739], 
             UndirectedEdge[228, 279] -> 
             RGBColor[
              0.6834469962982196, 0.26757892265532757`, 0.42538173491800535`],
              UndirectedEdge[300, 456] -> 
             RGBColor[
              0.7876906642858962, 0.8346847704993012, 0.9717778026709989], 
             UndirectedEdge[168, 326] -> 
             RGBColor[
              0.9087558014433601, 0.9143398282164557, 0.6888290855051917], 
             UndirectedEdge[193, 437] -> 
             RGBColor[
              0.6924140677804878, 0.758360712994278, 0.9708927577212803], 
             UndirectedEdge[224, 361] -> 
             RGBColor[
              0.6853207872280618, 0.7519118461136967, 0.9710762104846618], 
             UndirectedEdge[12, 477] -> 
             RGBColor[
              0.7938098598670751, 0.8391303889843917, 0.9800086836873632], 
             UndirectedEdge[212, 224] -> 
             RGBColor[
              0.6008915380960445, 0.6851504240256543, 0.962874621596729], 
             UndirectedEdge[220, 490] -> 
             RGBColor[
              0.6589531973389519, 0.7313109247801626, 0.9681376205784724], 
             UndirectedEdge[175, 208] -> 
             RGBColor[
              0.8118677310809452, 0.8497788147972193, 0.7636990664306691], 
             UndirectedEdge[242, 419] -> 
             RGBColor[
              0.7700222956333862, 0.8174541581777705, 0.8695315386320255], 
             UndirectedEdge[164, 205] -> 
             RGBColor[
              0.6830045129441651, 0.7439362280799203, 0.8368739128970892], 
             UndirectedEdge[257, 322] -> 
             RGBColor[
              0.6321111764774514, 0.22021432408709007`, 0.42221684843536866`],
              UndirectedEdge[7, 54] -> 
             RGBColor[
              0.9298098023489172, 0.7566927590875199, 0.2690855870674643], 
             UndirectedEdge[26, 67] -> 
             RGBColor[
              0.8069436958711761, 0.8472701839937278, 0.8658151231133733], 
             UndirectedEdge[366, 488] -> 
             RGBColor[
              0.6615976541214337, 0.7327911029440576, 0.9689076474332705], 
             UndirectedEdge[12, 243] -> 
             RGBColor[
              0.9183945629089296, 0.9365713707619345, 0.9506283366738786], 
             UndirectedEdge[271, 307] -> 
             RGBColor[
              0.9576677820273843, 0.930070700607921, 0.6480535305718549], 
             UndirectedEdge[9, 352] -> 
             RGBColor[
              0.719100306087374, 0.7751451361738031, 0.8351311205800933], 
             UndirectedEdge[404, 431] -> 
             RGBColor[
              0.8518805478676574, 0.33092226713357065`, 0.19457729374712981`],
              UndirectedEdge[256, 287] -> 
             RGBColor[
              0.7036968790624343, 0.2846995802240603, 0.42678774779478423`], 
             UndirectedEdge[254, 412] -> 
             RGBColor[
              0.812600498765932, 0.8310480418221526, 0.6674917207602566], 
             UndirectedEdge[42, 380] -> 
             RGBColor[
              0.6595221194389314, 0.7331487118196491, 0.9672416907216452], 
             UndirectedEdge[379, 404] -> 
             RGBColor[
              0.8503299877329296, 0.401464066005346, 0.44010655411953226`], 
             UndirectedEdge[134, 424] -> 
             RGBColor[
              0.864228367931847, 0.45492362045899226`, 0.2075811961969952], 
             UndirectedEdge[38, 253] -> 
             RGBColor[
              0.5916076131420156, 0.667499548197144, 0.9651174512930243], 
             UndirectedEdge[103, 348] -> 
             RGBColor[
              0.8664187878701951, 0.3868551912781747, 0.21516181773295184`], 
             UndirectedEdge[42, 452] -> 
             RGBColor[
              0.8008174986960448, 0.8447533133658065, 0.9806677313282569], 
             UndirectedEdge[164, 331] -> 
             RGBColor[
              0.6652240388924928, 0.6855800938961172, 0.6213130985345034], 
             UndirectedEdge[6, 181] -> 
             RGBColor[
              0.781121334840665, 0.346878469446833, 0.4333462809252778], 
             UndirectedEdge[172, 197] -> 
             RGBColor[
              0.7912371834846171, 0.648408063026363, 0.5944560431133522], 
             UndirectedEdge[80, 258] -> 
             RGBColor[
              0.5751818173222946, 0.6655451691677741, 0.9600088523254184], 
             UndirectedEdge[223, 268] -> 
             RGBColor[
              0.9733148847386048, 0.9779099724551963, 0.8535274082109141], 
             UndirectedEdge[5, 69] -> 
             RGBColor[
              0.7521300835144776, 0.6269237600207085, 0.5925739285492], 
             UndirectedEdge[306, 486] -> 
             RGBColor[
              0.8552164724188984, 0.8859801151330202, 0.9008928337379709], 
             UndirectedEdge[5, 348] -> 
             RGBColor[
              0.7529646149888621, 0.32469734773534487`, 0.430666284440576], 
             UndirectedEdge[279, 409] -> 
             RGBColor[
              0.4555771330943421, 0.5678757302778922, 0.9505660453409409], 
             UndirectedEdge[463, 483] -> 
             RGBColor[
              0.7927405604006198, 0.8380086712742361, 0.9513664591950945], 
             UndirectedEdge[351, 371] -> 
             RGBColor[
              0.731266141984325, 0.7896153251288051, 0.9742819570716428], 
             UndirectedEdge[335, 421] -> 
             RGBColor[
              0.5710307125242184, 0.6625019035086994, 0.959458635258166], 
             UndirectedEdge[259, 418] -> 
             RGBColor[
              0.8090640567278088, 0.8511952847280821, 0.9557289197051755], 
             UndirectedEdge[168, 302] -> 
             RGBColor[
              0.8840947156445038, 0.49434893270475533`, 0.2513427697393404], 
             UndirectedEdge[87, 336] -> 
             RGBColor[
              0.9440964747729959, 0.955988668908504, 0.9068064545756289], 
             UndirectedEdge[36, 266] -> 
             RGBColor[
              0.7599855207127746, 0.808570473421706, 0.8343599636301045], 
             UndirectedEdge[161, 430] -> 
             RGBColor[
              0.9361818591728863, 0.8574125745195247, 0.6217574977435694], 
             UndirectedEdge[220, 412] -> 
             RGBColor[
              0.5733143944013475, 0.6644092410462972, 0.9596019450417665], 
             UndirectedEdge[372, 404] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[38, 287] -> 
             RGBColor[
              0.6352006564175628, 0.22346156338848927`, 0.42239278974748207`],
              UndirectedEdge[171, 497] -> 
             RGBColor[
              0.993386973906615, 0.9904471251042006, 0.680300821111901], 
             UndirectedEdge[246, 411] -> 
             RGBColor[
              0.8633985433816249, 0.425463966500062, 0.20585394382551325`], 
             UndirectedEdge[75, 303] -> 
             RGBColor[
              0.8527146290178486, 0.33422912095301194`, 0.19524841501897455`],
              UndirectedEdge[23, 39] -> 
             RGBColor[
              0.9887948922355108, 0.9887348522935604, 0.7748044705467482], 
             UndirectedEdge[61, 391] -> 
             RGBColor[
              0.7746425087410862, 0.8204309607066584, 0.8323406680139676], 
             UndirectedEdge[19, 200] -> 
             RGBColor[
              0.792128106361186, 0.8350354827939561, 0.8560063177458186], 
             UndirectedEdge[208, 403] -> 
             RGBColor[
              0.7708854247829979, 0.8165075323126865, 0.7604727891557602], 
             UndirectedEdge[108, 378] -> 
             RGBColor[
              0.9148701437697391, 0.7405260054006668, 0.5861235566476204], 
             UndirectedEdge[10, 451] -> 
             RGBColor[
              0.9183443241072988, 0.9367855190635159, 0.9594370735443358], 
             UndirectedEdge[199, 262] -> 
             RGBColor[
              0.8766189326314995, 0.42018162143505167`, 0.3524454741499894], 
             UndirectedEdge[3, 401] -> 
             RGBColor[
              0.8195724133280803, 0.7645500415428921, 0.6166700658067633], 
             UndirectedEdge[241, 311] -> 
             RGBColor[
              0.6987868519226355, 0.7610054214992747, 0.9427929869399398], 
             UndirectedEdge[179, 255] -> 
             RGBColor[
              0.6878224314420263, 0.2713687046611283, 0.4256605337763233], 
             UndirectedEdge[276, 462] -> 
             RGBColor[
              0.380671719146666, 0.5041404428330842, 0.9454770432226094], 
             UndirectedEdge[167, 289] -> 
             RGBColor[
              0.9520388164833111, 0.9626389450579564, 0.9213408940880007], 
             UndirectedEdge[164, 348] -> 
             RGBColor[
              0.668476075997944, 0.2546118639515619, 0.42442780111473677`], 
             UndirectedEdge[18, 172] -> 
             RGBColor[
              0.8973687675757923, 0.6223992524236768, 0.23584370903737706`], 
             UndirectedEdge[289, 300] -> 
             RGBColor[
              0.8095526108160254, 0.850379549696842, 0.9074620323957845], 
             UndirectedEdge[59, 188] -> 
             RGBColor[
              0.9827935417511635, 0.9555960153332853, 0.5590051033195635], 
             UndirectedEdge[352, 357] -> 
             RGBColor[
              0.9736780352703684, 0.9780022089158029, 0.8433577894143469], 
             UndirectedEdge[161, 409] -> 
             RGBColor[
              0.7124319417000587, 0.6795601140973706, 0.607742407891492], 
             UndirectedEdge[39, 157] -> 
             RGBColor[
              0.9840135334972776, 0.9874840567952039, 0.9068469670742821], 
             UndirectedEdge[216, 398] -> 
             RGBColor[
              0.9830843698902855, 0.9863426102828989, 0.8883360458208609], 
             UndirectedEdge[279, 396] -> 
             RGBColor[
              0.6829371985500983, 0.7484206331546397, 0.9584700963353134], 
             UndirectedEdge[103, 390] -> 
             RGBColor[
              0.9737526708501827, 0.9231237369910184, 0.35253451195550833`], 
             UndirectedEdge[128, 296] -> 
             RGBColor[
              0.921865713509959, 0.759442737216967, 0.5834046846748959], 
             UndirectedEdge[362, 369] -> 
             RGBColor[
              0.8043668450471511, 0.847255363473914, 0.9810933394213468], 
             UndirectedEdge[86, 412] -> 
             RGBColor[
              0.8211459919018281, 0.8581987953104141, 0.8431363861569907], 
             UndirectedEdge[261, 299] -> 
             RGBColor[
              0.8706569941346647, 0.4169565186358365, 0.41722984255724704`], 
             UndirectedEdge[208, 266] -> 
             RGBColor[
              0.7592983034769294, 0.8071005852425538, 0.7595606085215225], 
             UndirectedEdge[211, 236] -> 
             RGBColor[
              0.9489639828022793, 0.8765802389187685, 0.6075958494022584], 
             UndirectedEdge[19, 124] -> 
             RGBColor[
              0.4627323159473945, 0.5714957079631188, 0.9517341332414027], 
             UndirectedEdge[319, 330] -> 
             RGBColor[
              0.7824744594408659, 0.8303123317253736, 0.9788689935737398], 
             UndirectedEdge[137, 267] -> 
             RGBColor[
              0.8727433141751249, 0.4081893035740978, 0.23973140814102736`], 
             UndirectedEdge[23, 240] -> 
             RGBColor[
              0.8531637350539361, 0.8826835790146617, 0.8040598836337414], 
             UndirectedEdge[135, 369] -> 
             RGBColor[
              0.8817768614165, 0.9050274472295519, 0.8061970403608995], 
             UndirectedEdge[13, 335] -> 
             RGBColor[
              0.7617315907560175, 0.33173105400039304`, 0.4314136924423806], 
             UndirectedEdge[176, 178] -> 
             RGBColor[
              0.8892116444215744, 0.5301428991242729, 0.3962440470192613], 
             UndirectedEdge[335, 459] -> 
             RGBColor[
              0.784473324597512, 0.7205446247588305, 0.609498930274016], 
             UndirectedEdge[83, 326] -> 
             RGBColor[
              0.7536012809348125, 0.8075448118905677, 0.9760473300350248], 
             UndirectedEdge[33, 76] -> 
             RGBColor[
              0.8656600480432148, 0.891988954057436, 0.7687148705436906], 
             UndirectedEdge[13, 285] -> 
             RGBColor[
              0.8759572457915535, 0.4187299911185057, 0.2777827512144868], 
             UndirectedEdge[225, 309] -> 
             RGBColor[
              0.9659018018289076, 0.9439443136760288, 0.6505305299689923], 
             UndirectedEdge[242, 499] -> 
             RGBColor[
              0.6100578794806426, 0.6938556578906852, 0.9627567959369696], 
             UndirectedEdge[13, 287] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[265, 270] -> 
             RGBColor[
              0.5487877269501253, 0.6445696252002986, 0.9576217266226468], 
             UndirectedEdge[191, 311] -> 
             RGBColor[
              0.9399843062244636, 0.830286919574889, 0.5920752729944658], 
             UndirectedEdge[47, 452] -> 
             RGBColor[
              0.8695382671496754, 0.8988102275104026, 0.9874185302383526], 
             UndirectedEdge[14, 80] -> 
             RGBColor[
              0.7366250720635487, 0.7897968471286657, 0.8441635429555299], 
             UndirectedEdge[152, 292] -> 
             RGBColor[
              0.7931275941537256, 0.35625785047314623`, 0.4345429526487312], 
             UndirectedEdge[133, 311] -> 
             RGBColor[
              0.8832361637782822, 0.5325259152924382, 0.43648530017653697`], 
             UndirectedEdge[187, 398] -> 
             RGBColor[
              0.8918747809476003, 0.5771328288233675, 0.43643570556364786`], 
             UndirectedEdge[130, 442] -> 
             RGBColor[
              0.8758681446731087, 0.4185394128356573, 0.2680846443401336], 
             UndirectedEdge[304, 433] -> 
             RGBColor[
              0.9292121404649027, 0.7427513998098418, 0.2979207915256058], 
             UndirectedEdge[354, 409] -> 
             RGBColor[
              0.7224320867938181, 0.7815307469955661, 0.9619689183298896], 
             UndirectedEdge[29, 412] -> 
             RGBColor[
              0.7828333251738728, 0.8310716222479205, 0.9787776655061977], 
             UndirectedEdge[295, 391] -> 
             RGBColor[
              0.8439866398268466, 0.8759536374954007, 0.8383288887694297], 
             UndirectedEdge[21, 298] -> 
             RGBColor[
              0.8122944364404869, 0.8540736104361706, 0.9817175914414558], 
             UndirectedEdge[383, 395] -> 
             RGBColor[
              0.5367401601352622, 0.42490161882445, 0.5758527681523378], 
             UndirectedEdge[133, 241] -> 
             RGBColor[
              0.7029792754496201, 0.38884336553871035`, 0.44030220481046733`],
              UndirectedEdge[142, 473] -> 
             RGBColor[
              0.9679063500924618, 0.9755851889642624, 0.9392103573156986], 
             UndirectedEdge[95, 330] -> 
             RGBColor[
              0.9238839961628473, 0.931657505083757, 0.6980026208800454], 
             UndirectedEdge[275, 431] -> 
             RGBColor[
              0.9542068636057428, 0.8567872808369044, 0.5568034538574522], 
             UndirectedEdge[180, 474] -> 
             RGBColor[
              0.7057672101721855, 0.7700229024236092, 0.9713401220673288], 
             UndirectedEdge[82, 173] -> 
             RGBColor[
              0.4479766570901773, 0.5624365972352121, 0.9497656543529502], 
             UndirectedEdge[205, 230] -> 
             RGBColor[
              0.9502772642157906, 0.8273428057110694, 0.48579476653267784`], 
             UndirectedEdge[460, 463] -> 
             RGBColor[
              0.8943254646803867, 0.6213259928407934, 0.4484649313127133], 
             UndirectedEdge[121, 500] -> 
             RGBColor[
              0.6134335575132659, 0.6957824049491292, 0.9635789278091891], 
             UndirectedEdge[88, 241] -> 
             RGBColor[
              0.6876798398098808, 0.2712451989562277, 0.42565144796361176`], 
             UndirectedEdge[60, 73] -> 
             RGBColor[
              0.8622481487577037, 0.8899735280301435, 0.8204345420603796], 
             UndirectedEdge[75, 400] -> 
             RGBColor[
              0.8527146290178486, 0.33422912095301194`, 0.19524841501897455`],
              UndirectedEdge[141, 274] -> 
             RGBColor[
              0.8733616447744948, 0.41027507787670187`, 0.2421335057576442], 
             UndirectedEdge[299, 448] -> 
             RGBColor[
              0.8759391561549698, 0.4186912992149959, 0.2758138059086473], 
             UndirectedEdge[160, 389] -> 
             RGBColor[
              0.9844828485265482, 0.9578451232027274, 0.5195594729314862], 
             UndirectedEdge[24, 268] -> 
             RGBColor[
              0.9946647566205084, 0.9920617540001488, 0.7380823201728381], 
             UndirectedEdge[386, 498] -> 
             RGBColor[
              0.8760737653894726, 0.4189792147565161, 0.29046519037237306`], 
             UndirectedEdge[350, 476] -> 
             RGBColor[
              0.9856429775010022, 0.9881035934873699, 0.8774120813088724], 
             UndirectedEdge[180, 331] -> 
             RGBColor[
              0.8659530972853959, 0.8487920696374924, 0.6378564748637457], 
             UndirectedEdge[225, 252] -> 
             RGBColor[
              0.9833425463259835, 0.9543924987175483, 0.481636681614474], 
             UndirectedEdge[100, 203] -> 
             RGBColor[
              0.9708095599837459, 0.9131959329632332, 0.3411010819992529], 
             UndirectedEdge[445, 471] -> 
             RGBColor[
              0.5046230416981816, 0.6080150259144843, 0.9543382550430346], 
             UndirectedEdge[373, 498] -> 
             RGBColor[
              0.8355311762214984, 0.25990526195303226`, 0.1811016310905022], 
             UndirectedEdge[102, 309] -> 
             RGBColor[
              0.818363709384156, 0.8585473823815918, 0.9610667495850252], 
             UndirectedEdge[46, 86] -> 
             RGBColor[
              0.9786934646555847, 0.9381149932138708, 0.5141756011436224], 
             UndirectedEdge[294, 385] -> 
             RGBColor[
              0.965439618013067, 0.9720508969454504, 0.8674979153331952], 
             UndirectedEdge[27, 29] -> 
             RGBColor[
              0.9321621376420286, 0.8802389595410478, 0.6336452178820404], 
             UndirectedEdge[274, 284] -> 
             RGBColor[
              0.6418892349497897, 0.6967334856026994, 0.6691327144654053], 
             UndirectedEdge[284, 300] -> 
             RGBColor[
              0.4647870644317844, 0.5712029689088246, 0.9522068937003643], 
             UndirectedEdge[159, 453] -> 
             RGBColor[
              0.990033703655244, 0.9901466945863796, 0.8148308525881596], 
             UndirectedEdge[229, 232] -> 
             RGBColor[
              0.8628031628148352, 0.6027437903337765, 0.46543382632062524`], 
             UndirectedEdge[259, 431] -> 
             RGBColor[
              0.9426485474301679, 0.8487017481646686, 0.6003109669449894], 
             UndirectedEdge[112, 483] -> 
             RGBColor[
              0.7080299323246529, 0.7714621684666757, 0.9717901708963768], 
             UndirectedEdge[78, 376] -> 
             RGBColor[
              0.776482588874811, 0.6499553038018742, 0.5955405058422046], 
             UndirectedEdge[76, 351] -> 
             RGBColor[
              0.8048537127931122, 0.8478987779228528, 0.9810720552476638], 
             UndirectedEdge[178, 498] -> 
             RGBColor[
              0.8317222899734411, 0.24483699829778002`, 0.1780106067447566], 
             UndirectedEdge[400, 431] -> 
             RGBColor[
              0.8518805478676574, 0.33092226713357065`, 0.19457729374712981`],
              UndirectedEdge[18, 432] -> 
             RGBColor[
              0.9568576405389885, 0.8544795046086535, 0.42190251304050486`], 
             UndirectedEdge[220, 325] -> 
             RGBColor[
              0.7037825800754492, 0.7670434689121987, 0.9724169870257742], 
             UndirectedEdge[353, 380] -> 
             RGBColor[
              0.7706527882725034, 0.8206328521197757, 0.9645410981549131], 
             UndirectedEdge[5, 355] -> 
             RGBColor[
              0.6770138395045423, 0.7473303067610894, 0.968631673849853], 
             UndirectedEdge[367, 441] -> 
             RGBColor[
              0.8835210369043671, 0.4763590044168986, 0.36658673008298776`], 
             UndirectedEdge[21, 287] -> 
             RGBColor[
              0.7807583038736883, 0.34659486689629315`, 0.43331009739120685`],
              UndirectedEdge[175, 182] -> 
             RGBColor[
              0.7317055500398084, 0.7902521492014133, 0.9739941671869217], 
             UndirectedEdge[70, 371] -> 
             RGBColor[
              0.7630627664295345, 0.814967837879393, 0.9772713230328767], 
             UndirectedEdge[217, 496] -> 
             RGBColor[
              0.6718291820713644, 0.7424047166985209, 0.9687133604911471], 
             UndirectedEdge[195, 292] -> 
             RGBColor[
              0.8602001761732923, 0.8909420479085487, 0.9506429037363248], 
             UndirectedEdge[161, 285] -> 
             RGBColor[
              0.9613231717403763, 0.8728937544802283, 0.3834870917492893], 
             UndirectedEdge[168, 370] -> 
             RGBColor[
              0.8281204968230267, 0.8512404188443947, 0.6808203728307386], 
             UndirectedEdge[50, 173] -> 
             RGBColor[
              0.596005533550163, 0.6813204007127129, 0.962393149229281], 
             UndirectedEdge[19, 188] -> 
             RGBColor[
              0.7815884050797881, 0.799120359214047, 0.6548624748935565], 
             UndirectedEdge[147, 323] -> 
             RGBColor[
              0.7604822987302738, 0.813179645456412, 0.9767599844634333], 
             UndirectedEdge[255, 260] -> 
             RGBColor[
              0.8730555133292838, 0.40924242462892335`, 0.2409442429010717], 
             UndirectedEdge[29, 350] -> 
             RGBColor[
              0.9535274258565956, 0.9637107253034671, 0.9164806508963657], 
             UndirectedEdge[348, 400] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[26, 124] -> 
             RGBColor[
              0.6639634331588411, 0.7279821077033459, 0.8554461968829465], 
             UndirectedEdge[18, 93] -> 
             RGBColor[
              0.9571090040400122, 0.855017145720595, 0.4492618788912275], 
             UndirectedEdge[64, 223] -> 
             RGBColor[
              0.949294389607205, 0.9617044193086461, 0.9707155516405042], 
             UndirectedEdge[12, 335] -> 
             RGBColor[
              0.7526425945769808, 0.8069702084569657, 0.9759055154132135], 
             UndirectedEdge[143, 498] -> 
             RGBColor[
              0.8765199267803115, 0.42014067997125115`, 0.3540862573231037], 
             UndirectedEdge[44, 92] -> 
             RGBColor[
              0.9743627385413668, 0.9503914748425423, 0.6364992140263452], 
             UndirectedEdge[274, 389] -> 
             RGBColor[
              0.979760632950555, 0.9433900038921594, 0.37587431020701223`], 
             UndirectedEdge[247, 401] -> 
             RGBColor[
              0.5693682598249619, 0.6595599824387516, 0.9601407781604772], 
             UndirectedEdge[111, 182] -> 
             RGBColor[
              0.8494750559914294, 0.8828123675341761, 0.9855048832474391], 
             UndirectedEdge[157, 190] -> 
             RGBColor[
              0.9618762584530596, 0.891691119077953, 0.584981312602726], 
             UndirectedEdge[100, 360] -> 
             RGBColor[
              0.6732985612012157, 0.6986235622460016, 0.6310480881528497], 
             UndirectedEdge[59, 468] -> 
             RGBColor[
              0.9286370234249801, 0.9430336502051526, 0.8780588708108638], 
             UndirectedEdge[101, 129] -> 
             RGBColor[
              0.6235167000292163, 0.7020551025913334, 0.9654557010201166], 
             UndirectedEdge[180, 382] -> 
             RGBColor[
              0.8377624124250984, 0.8738588530157791, 0.9842853335539499], 
             UndirectedEdge[145, 402] -> 
             RGBColor[
              0.9312084796934679, 0.9473917372398493, 0.9727533589828032], 
             UndirectedEdge[90, 263] -> 
             RGBColor[
              0.9696452005890386, 0.976882020817503, 0.9362669369898371], 
             UndirectedEdge[98, 276] -> 
             RGBColor[
              0.6341888793018998, 0.5574215636248002, 0.5896513960403265], 
             UndirectedEdge[224, 464] -> 
             RGBColor[
              0.4996994311890336, 0.6046574317677132, 0.9537739229487326], 
             UndirectedEdge[261, 313] -> 
             RGBColor[
              0.811644247288866, 0.8529800892760693, 0.944299997196951], 
             UndirectedEdge[78, 219] -> 
             RGBColor[
              0.8504059992331743, 0.7077048338125551, 0.6029085005331798], 
             UndirectedEdge[393, 424] -> 
             RGBColor[
              0.9356480079755936, 0.7746801619371303, 0.2962237612713585], 
             UndirectedEdge[169, 211] -> 
             RGBColor[
              0.9479461655909612, 0.8299912446398046, 0.28395153462889955`], 
             UndirectedEdge[176, 482] -> 
             RGBColor[
              0.9736442759317545, 0.978934981359366, 0.8878706973801895], 
             UndirectedEdge[35, 94] -> 
             RGBColor[
              0.697570144578962, 0.7620601527575815, 0.9718586105564743], 
             UndirectedEdge[114, 296] -> 
             RGBColor[
              0.9794662363617217, 0.9824465212474875, 0.8408255532844193], 
             UndirectedEdge[130, 175] -> 
             RGBColor[
              0.8114654669318002, 0.8489184124573423, 0.719915096282796], 
             UndirectedEdge[189, 383] -> 
             RGBColor[
              0.7981348254887795, 0.6529637945847859, 0.5949807843990034], 
             UndirectedEdge[139, 437] -> 
             RGBColor[
              0.7388897867658439, 0.6947279389103429, 0.6083720387514], 
             UndirectedEdge[56, 324] -> 
             RGBColor[
              0.8696891238509523, 0.8050341261346143, 0.6219603096510051], 
             UndirectedEdge[398, 399] -> 
             RGBColor[
              0.9289082937620445, 0.7640116239076249, 0.5710283015327688], 
             UndirectedEdge[405, 429] -> 
             RGBColor[
              0.9181217027822147, 0.7570511088993941, 0.5900091202159511], 
             UndirectedEdge[12, 318] -> 
             RGBColor[
              0.7597905644967715, 0.8125542568848896, 0.9766179582532415], 
             UndirectedEdge[11, 205] -> 
             RGBColor[
              0.8812942785973157, 0.9052426097936895, 0.8531741633225198], 
             UndirectedEdge[226, 389] -> 
             RGBColor[
              0.9510015319312939, 0.9347889867982703, 0.6733859840349158], 
             UndirectedEdge[294, 327] -> 
             RGBColor[
              0.9913064346353546, 0.9906730015543497, 0.7937384065255326], 
             UndirectedEdge[167, 218] -> 
             RGBColor[
              0.9555683924814902, 0.9640985154391691, 0.8628466855482969], 
             UndirectedEdge[217, 481] -> 
             RGBColor[
              0.712288578585256, 0.7751645182752839, 0.9719579268643117], 
             UndirectedEdge[247, 309] -> 
             RGBColor[
              0.6938865930955291, 0.7573508164894562, 0.9510878469420402], 
             UndirectedEdge[79, 234] -> 
             RGBColor[
              0.8337886469575384, 0.260719923560956, 0.1799893525263446], 
             UndirectedEdge[331, 372] -> 
             RGBColor[
              0.8647652832637179, 0.3812775319791829, 0.20873826457493216`], 
             UndirectedEdge[27, 484] -> 
             RGBColor[
              0.9374584480113712, 0.7897506176414958, 0.2685358031122886], 
             UndirectedEdge[103, 326] -> 
             RGBColor[
              0.8988891724515196, 0.8810573718323212, 0.6504990950284335], 
             UndirectedEdge[155, 394] -> 
             RGBColor[
              0.9480051031833161, 0.9595152116534029, 0.9249789074068553], 
             UndirectedEdge[433, 469] -> 
             RGBColor[
              0.9214869690966779, 0.7577229472942626, 0.583088651052579], 
             UndirectedEdge[65, 412] -> 
             RGBColor[
              0.7639918829115648, 0.6381684225863326, 0.5938989998305592], 
             UndirectedEdge[13, 161] -> 
             RGBColor[
              0.8546835353686973, 0.34203517853497983`, 0.1968326432850394], 
             UndirectedEdge[229, 480] -> 
             RGBColor[
              0.9245412549453039, 0.920803139891323, 0.6813261273428081], 
             UndirectedEdge[32, 448] -> 
             RGBColor[
              0.9940262255982637, 0.989631025532954, 0.59116970611227], 
             UndirectedEdge[251, 453] -> 
             RGBColor[
              0.942102105239661, 0.8015663220040574, 0.5254913470553284], 
             UndirectedEdge[282, 310] -> 
             RGBColor[
              0.9340837960278335, 0.7842604795629551, 0.573181352114576], 
             UndirectedEdge[392, 473] -> 
             RGBColor[
              0.9044124348224334, 0.9257535771255729, 0.9607767804864029], 
             UndirectedEdge[222, 344] -> 
             RGBColor[
              0.8524004424978648, 0.8342680352973249, 0.630757054862003], 
             UndirectedEdge[266, 440] -> 
             RGBColor[
              0.5886775839846448, 0.6767982087124993, 0.960868523221896], 
             UndirectedEdge[16, 361] -> 
             RGBColor[
              0.9122234790119661, 0.9328462567901836, 0.9914898838513163], 
             UndirectedEdge[412, 426] -> 
             RGBColor[
              0.7369976906807111, 0.7945235314782273, 0.974405821770286], 
             UndirectedEdge[274, 460] -> 
             RGBColor[
              0.9002637131609811, 0.6170561640567703, 0.26789495682608394`], 
             UndirectedEdge[180, 230] -> 
             RGBColor[
              0.8387920376583604, 0.7422001452272102, 0.6103116333090413], 
             UndirectedEdge[375, 450] -> 
             RGBColor[
              0.8154786581908855, 0.3737186715733538, 0.4367706978293865], 
             UndirectedEdge[6, 123] -> 
             RGBColor[
              0.7413797986309564, 0.7978908004764462, 0.9748574678055592], 
             UndirectedEdge[170, 466] -> 
             RGBColor[
              0.8849699095936939, 0.5000343024392147, 0.25288785630196886`], 
             UndirectedEdge[267, 280] -> 
             RGBColor[
              0.8267379480821351, 0.38265241397665906`, 0.437856324316777], 
             UndirectedEdge[52, 214] -> 
             RGBColor[
              0.5618517819684614, 0.5620792543343692, 0.603962565482123], 
             UndirectedEdge[358, 386] -> 
             RGBColor[
              0.946558156506849, 0.8126841815357932, 0.3904198982563828], 
             UndirectedEdge[230, 413] -> 
             RGBColor[
              0.7603949499339724, 0.6805435967654843, 0.6027795318947353], 
             UndirectedEdge[53, 207] -> 
             RGBColor[
              0.9187313482147013, 0.9373483236205009, 0.9682873325257607], 
             UndirectedEdge[188, 256] -> 
             RGBColor[
              0.7246257422260621, 0.7528755033706742, 0.6503781654126017], 
             UndirectedEdge[38, 87] -> 
             RGBColor[
              0.6302398477337234, 0.6960315938843967, 0.8810787242510506], 
             UndirectedEdge[22, 52] -> 
             RGBColor[
              0.7376580463602529, 0.7242597122627394, 0.615304646290935], 
             UndirectedEdge[160, 460] -> 
             RGBColor[
              0.9034118568783099, 0.6266929102638157, 0.36368506530906664`], 
             UndirectedEdge[63, 159] -> 
             RGBColor[
              0.7991341716131566, 0.8414575802278272, 0.8872527277582646], 
             UndirectedEdge[285, 430] -> 
             RGBColor[
              0.9680924248071705, 0.9724547933948136, 0.7431826596377404], 
             UndirectedEdge[132, 356] -> 
             RGBColor[
              0.8778856778440367, 0.9046504840932466, 0.9469583205898475], 
             UndirectedEdge[99, 373] -> 
             RGBColor[
              0.9156635977129555, 0.7403409109846631, 0.5842631216323757], 
             UndirectedEdge[243, 396] -> 
             RGBColor[
              0.9661160585687438, 0.9742499924772068, 0.9422408538825415], 
             UndirectedEdge[118, 292] -> 
             RGBColor[
              0.8478736037352179, 0.8817489103671428, 0.9715085755889998], 
             UndirectedEdge[84, 176] -> 
             RGBColor[
              0.9102523775391274, 0.928950228454877, 0.9013170549615845], 
             UndirectedEdge[334, 385] -> 
             RGBColor[
              0.963235129278432, 0.9711392842009026, 0.9040319987000633], 
             UndirectedEdge[25, 325] -> 
             RGBColor[
              0.916653220267498, 0.9363784122252216, 0.9919123965267457], 
             UndirectedEdge[321, 397] -> 
             RGBColor[
              0.97152651082562, 0.9152662942451504, 0.34569911893958366`], 
             UndirectedEdge[201, 235] -> 
             RGBColor[
              0.8142834618492963, 0.7411099306585139, 0.6118672271278316], 
             UndirectedEdge[321, 498] -> 
             RGBColor[
              0.86314130566246, 0.37556741936487403`, 0.20363796379278543`], 
             UndirectedEdge[368, 492] -> 
             RGBColor[
              0.7984393749885099, 0.8430060788684592, 0.980401359290618], 
             UndirectedEdge[239, 387] -> 
             RGBColor[
              0.7100297590980085, 0.28984089752993386`, 0.42728629530928863`],
              UndirectedEdge[196, 500] -> 
             RGBColor[
              0.8593227462495947, 0.8867933996919948, 0.7484755104351853], 
             UndirectedEdge[122, 185] -> 
             RGBColor[
              0.8386259573509978, 0.8746035546044099, 0.9745846026046274], 
             UndirectedEdge[350, 377] -> 
             RGBColor[
              0.8743669496067022, 0.4192503685809742, 0.38976666081612854`], 
             UndirectedEdge[315, 353] -> 
             RGBColor[
              0.9730075578485894, 0.9775574452311402, 0.8485249616700836], 
             UndirectedEdge[102, 480] -> 
             RGBColor[
              0.8284763930756893, 0.8453564376787017, 0.6718574544576336], 
             UndirectedEdge[127, 253] -> 
             RGBColor[
              0.6630973823915829, 0.7329136000314862, 0.9695448127575224], 
             UndirectedEdge[159, 192] -> 
             RGBColor[
              0.9734979876596263, 0.9280827662877486, 0.5494551813047968], 
             UndirectedEdge[201, 289] -> 
             RGBColor[
              0.9522710194627046, 0.8483087787922452, 0.55131384544885], 
             UndirectedEdge[29, 194] -> 
             RGBColor[
              0.9536479603873154, 0.9637605694295159, 0.9144830817889715], 
             UndirectedEdge[79, 388] -> 
             RGBColor[
              0.6516703033751013, 0.35005448694944524`, 0.43816414227382666`],
              UndirectedEdge[246, 402] -> 
             RGBColor[
              0.937420379133223, 0.8370065954469941, 0.6031123620321974], 
             UndirectedEdge[185, 398] -> 
             RGBColor[
              0.9625668593739624, 0.9716030055290191, 0.9482487223399032], 
             UndirectedEdge[133, 304] -> 
             RGBColor[
              0.8867111136879001, 0.5212955488172992, 0.24920901009300933`], 
             UndirectedEdge[107, 314] -> 
             RGBColor[
              0.9595737322479708, 0.9672922646469091, 0.8632287184308329], 
             UndirectedEdge[13, 279] -> 
             RGBColor[
              0.6834469962982196, 0.26757892265532757`, 0.42538173491800535`],
              UndirectedEdge[180, 418] -> 
             RGBColor[
              0.7130415034889459, 0.7757527089324877, 0.9720329713822282], 
             UndirectedEdge[112, 207] -> 
             RGBColor[
              0.8366642283096011, 0.8727733448784255, 0.9842362744311186], 
             UndirectedEdge[308, 369] -> 
             RGBColor[
              0.7917645143797452, 0.8372517233574226, 0.9798793453994596], 
             UndirectedEdge[45, 292] -> 
             RGBColor[
              0.8518540702750622, 0.8368777318855198, 0.6351368412758363], 
             UndirectedEdge[348, 418] -> 
             RGBColor[
              0.7628242207327514, 0.332584624842513, 0.4315225955872538], 
             UndirectedEdge[51, 264] -> 
             RGBColor[
              0.6838888559382776, 0.752978439097578, 0.9691273079213583], 
             UndirectedEdge[201, 218] -> 
             RGBColor[
              0.9558005954608836, 0.8497683491734579, 0.4928196369091463], 
             UndirectedEdge[262, 376] -> 
             RGBColor[
              0.7685382175104389, 0.3370484425532265, 0.43209211338571785`], 
             UndirectedEdge[304, 307] -> 
             RGBColor[
              0.9641933874041287, 0.9520830998286862, 0.673404275203334], 
             UndirectedEdge[8, 166] -> 
             RGBColor[
              0.5381700402548862, 0.6311816060557565, 0.9587267984129632], 
             UndirectedEdge[66, 312] -> 
             RGBColor[
              0.8171782806584782, 0.8577848369722637, 0.9822319842856926], 
             UndirectedEdge[202, 430] -> 
             RGBColor[
              0.9680388710483858, 0.9723402473198883, 0.7373536634895015], 
             UndirectedEdge[348, 404] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[1, 113] -> 
             RGBColor[
              0.9892734563237435, 0.989832312777339, 0.8274301183281484], 
             UndirectedEdge[29, 377] -> 
             RGBColor[
              0.8510766676310282, 0.402059448288004, 0.4401777731147819], 
             UndirectedEdge[259, 404] -> 
             RGBColor[
              0.8663104837524546, 0.4137148983095418, 0.42458735088286315`], 
             UndirectedEdge[131, 449] -> 
             RGBColor[
              0.9561272465306165, 0.9655859879385182, 0.9081410371177284], 
             UndirectedEdge[423, 465] -> 
             RGBColor[
              0.9475248719391034, 0.9229836445543123, 0.659765433497634], 
             UndirectedEdge[177, 412] -> 
             RGBColor[
              0.7048183973709414, 0.7693287559351812, 0.9712133690136813], 
             UndirectedEdge[139, 158] -> 
             RGBColor[
              0.9361942911802175, 0.8509777772646556, 0.6167368154822208], 
             UndirectedEdge[454, 500] -> 
             RGBColor[
              0.8150744693273761, 0.8561480610847108, 0.9820205081044235], 
             UndirectedEdge[430, 459] -> 
             RGBColor[
              0.9306704945833262, 0.835561850475296, 0.6173229244264553], 
             UndirectedEdge[474, 490] -> 
             RGBColor[
              0.7288191644473012, 0.788031264304671, 0.9736377254367119], 
             UndirectedEdge[443, 451] -> 
             RGBColor[
              0.9252329302003679, 0.94162597017557, 0.9344735050535586], 
             UndirectedEdge[182, 483] -> 
             RGBColor[
              0.7256477660774404, 0.7853341672807054, 0.9735172762430102], 
             UndirectedEdge[92, 457] -> 
             RGBColor[
              0.9734183849825762, 0.9472059485439812, 0.632830578776649], 
             UndirectedEdge[38, 184] -> 
             RGBColor[
              0.6184680584569546, 0.6881366770617381, 0.9406134133767244], 
             UndirectedEdge[51, 457] -> 
             RGBColor[
              0.84205299738826, 0.8443638925099042, 0.6562730598787037], 
             UndirectedEdge[321, 455] -> 
             RGBColor[
              0.8865690851586248, 0.858235262597091, 0.6325036270599087], 
             UndirectedEdge[251, 435] -> 
             RGBColor[
              0.9265814227046167, 0.7909353310189284, 0.5940518842328626], 
             UndirectedEdge[16, 441] -> 
             RGBColor[
              0.9494198367831654, 0.959386197519275, 0.8705269052837038], 
             UndirectedEdge[302, 390] -> 
             RGBColor[
              0.8836065011430085, 0.4927020705529952, 0.2494461485926035], 
             UndirectedEdge[186, 455] -> 
             RGBColor[
              0.7982841331142289, 0.8423448990637389, 0.9805291600656119], 
             UndirectedEdge[349, 353] -> 
             RGBColor[
              0.9503759647145091, 0.9010636919883901, 0.6233842336450168], 
             UndirectedEdge[125, 406] -> 
             RGBColor[
              0.7673309746465564, 0.7054562424686877, 0.6077649366386313], 
             UndirectedEdge[307, 433] -> 
             RGBColor[
              0.9138084937245493, 0.7519963529340786, 0.5960863069904783], 
             UndirectedEdge[406, 419] -> 
             RGBColor[
              0.8045697751581977, 0.8455013584022291, 0.8722512427718059], 
             UndirectedEdge[237, 274] -> 
             RGBColor[
              0.8733616447744948, 0.41027507787670187`, 0.2421335057576442], 
             UndirectedEdge[203, 264] -> 
             RGBColor[
              0.8157272032815831, 0.8322060631427721, 0.6659274818409702], 
             UndirectedEdge[69, 231] -> 
             RGBColor[
              0.8382141073541229, 0.2720878256117942, 0.18334033459222407`], 
             UndirectedEdge[328, 399] -> 
             RGBColor[
              0.8452402122878792, 0.3269111890974502, 0.19010055742595955`], 
             UndirectedEdge[78, 262] -> 
             RGBColor[
              0.8388755084061017, 0.27509109331468956`, 0.1838922238424185], 
             UndirectedEdge[27, 412] -> 
             RGBColor[
              0.7964034599228169, 0.7733862369249566, 0.6203255640438923], 
             UndirectedEdge[147, 221] -> 
             RGBColor[
              0.9284397441385859, 0.9029867890351531, 0.6509147000161061], 
             UndirectedEdge[93, 289] -> 
             RGBColor[
              0.9911883727354855, 0.9899617376647771, 0.7475424385402805], 
             UndirectedEdge[141, 235] -> 
             RGBColor[
              0.7821751710392534, 0.3477017342946218, 0.43345131746889387`], 
             UndirectedEdge[185, 464] -> 
             RGBColor[
              0.7474180521751945, 0.8019102966216319, 0.966479035877528], 
             UndirectedEdge[6, 189] -> 
             RGBColor[
              0.7152025100436956, 0.7774409036773162, 0.9722483603198513], 
             UndirectedEdge[38, 316] -> 
             RGBColor[
              0.5677248899325718, 0.648456112989185, 0.9628394958329487], 
             UndirectedEdge[322, 343] -> 
             RGBColor[
              0.47066359665605517`, 0.5710208302834366, 0.9534587680543963], 
             UndirectedEdge[93, 141] -> 
             RGBColor[
              0.8763840390421316, 0.41964285872607543`, 0.32423656267728074`],
              UndirectedEdge[191, 237] -> 
             RGBColor[
              0.8484781426777663, 0.3174328643399705, 0.1918396386666291], 
             UndirectedEdge[145, 461] -> 
             RGBColor[
              0.7284670143321244, 0.7871143397604623, 0.9743246303825547], 
             UndirectedEdge[420, 500] -> 
             RGBColor[
              0.8178505755635529, 0.8583616528420417, 0.9822852955954895], 
             UndirectedEdge[402, 458] -> 
             RGBColor[
              0.8147383058637139, 0.8557274167241753, 0.9613243384026033], 
             UndirectedEdge[148, 263] -> 
             RGBColor[
              0.9237989562908422, 0.9412030847753181, 0.962321533788862], 
             UndirectedEdge[126, 499] -> 
             RGBColor[
              0.8304959376233134, 0.8667246250886584, 0.9009854132561155], 
             UndirectedEdge[133, 371] -> 
             RGBColor[
              0.7569714232713243, 0.43312765070212483`, 0.44442804429560956`],
              UndirectedEdge[72, 245] -> 
             RGBColor[
              0.9249093710785437, 0.7761395174977426, 0.5878597483544213], 
             UndirectedEdge[57, 131] -> 
             RGBColor[
              0.7068856456517896, 0.7694559434948849, 0.972784120411357], 
             UndirectedEdge[15, 173] -> 
             RGBColor[
              0.7037214963421812, 0.7660333595941599, 0.9541086483124865], 
             UndirectedEdge[138, 415] -> 
             RGBColor[
              0.9234820357179812, 0.8184106328109881, 0.620343766036104], 
             UndirectedEdge[105, 109] -> 
             RGBColor[
              0.8801755876819646, 0.4476995172793815, 0.35628491881578933`], 
             UndirectedEdge[235, 284] -> 
             RGBColor[
              0.5051095243469274, 0.6028734702295793, 0.9561094320322798], 
             UndirectedEdge[150, 473] -> 
             RGBColor[
              0.9437378838489026, 0.845094721064114, 0.5950381674620128], 
             UndirectedEdge[74, 417] -> 
             RGBColor[
              0.964977255696452, 0.9723766105666638, 0.8983088453365586], 
             UndirectedEdge[20, 413] -> 
             RGBColor[
              0.6499154387492356, 0.7260259996904654, 0.9660229428232116], 
             UndirectedEdge[34, 467] -> 
             RGBColor[
              0.8356479490643618, 0.7957266701952876, 0.6223952054395777], 
             UndirectedEdge[62, 110] -> 
             RGBColor[
              0.9333499682751639, 0.9489976320009135, 0.9694326497174683], 
             UndirectedEdge[93, 389] -> 
             RGBColor[
              0.9842942243520101, 0.9574416751662196, 0.499028895586467], 
             UndirectedEdge[28, 408] -> 
             RGBColor[
              0.942571871312984, 0.8119284726127021, 0.5605901075293841], 
             UndirectedEdge[93, 284] -> 
             RGBColor[
              0.6464228263512447, 0.7107851568767596, 0.7922872998448601], 
             UndirectedEdge[143, 313] -> 
             RGBColor[
              0.8204386462573362, 0.8577563312791913, 0.849584619345736], 
             UndirectedEdge[361, 398] -> 
             RGBColor[
              0.9490645925198349, 0.9611162671839097, 0.9566548664215103], 
             UndirectedEdge[105, 382] -> 
             RGBColor[
              0.9492105383182123, 0.9589861714215002, 0.8603833207987488], 
             UndirectedEdge[240, 495] -> 
             RGBColor[
              0.6358595165517484, 0.7141933383938401, 0.9652045434359193], 
             UndirectedEdge[13, 21] -> 
             RGBColor[
              0.7807583038736883, 0.3465948668962931, 0.43331009739120674`], 
             UndirectedEdge[32, 179] -> 
             RGBColor[
              0.7118511385288484, 0.7686471337021525, 0.8159397979137841], 
             UndirectedEdge[38, 79] -> 
             RGBColor[
              0.6516703033751012, 0.35005448694944524`, 0.4381641422738267], 
             UndirectedEdge[328, 407] -> 
             RGBColor[
              0.8115344163665865, 0.4209491241589354, 0.44262848070659044`], 
             UndirectedEdge[357, 367] -> 
             RGBColor[
              0.8695906626674497, 0.46704829533753794`, 0.4384664993572953], 
             UndirectedEdge[196, 213] -> 
             RGBColor[
              0.9891983188838003, 0.9881831610993468, 0.711057975266304], 
             UndirectedEdge[233, 326] -> 
             RGBColor[
              0.9136478321120621, 0.9308230691316796, 0.8653995886268566], 
             UndirectedEdge[164, 372] -> 
             RGBColor[
              0.668476075997944, 0.2546118639515619, 0.42442780111473677`], 
             UndirectedEdge[3, 278] -> 
             RGBColor[
              0.8160678434355395, 0.7618122449071216, 0.6163207630319425], 
             UndirectedEdge[195, 399] -> 
             RGBColor[
              0.9274400568649611, 0.7629166152337974, 0.5735136436220185], 
             UndirectedEdge[118, 187] -> 
             RGBColor[
              0.8826782413908284, 0.5702740646798786, 0.45200304819159776`], 
             UndirectedEdge[61, 178] -> 
             RGBColor[
              0.744015279747535, 0.4164486328599989, 0.44262048698494116`], 
             UndirectedEdge[2, 496] -> 
             RGBColor[
              0.7482898562793541, 0.8030212532661838, 0.9760994268476002], 
             UndirectedEdge[103, 404] -> 
             RGBColor[
              0.8664187878701951, 0.3868551912781747, 0.21516181773295184`], 
             UndirectedEdge[37, 374] -> 
             RGBColor[
              0.9878878150188917, 0.9694904167060485, 0.5192208246605093], 
             UndirectedEdge[236, 466] -> 
             RGBColor[
              0.8774541494822766, 0.5034523173525712, 0.436817405572011], 
             UndirectedEdge[150, 254] -> 
             RGBColor[
              0.9481920135866346, 0.8257515716262005, 0.31130592099313936`], 
             UndirectedEdge[148, 229] -> 
             RGBColor[
              0.8737624419344854, 0.9021784698216402, 0.987821435800293], 
             UndirectedEdge[160, 432] -> 
             RGBColor[
              0.9944513777999092, 0.9905403831027926, 0.6374448995261388], 
             UndirectedEdge[48, 198] -> 
             RGBColor[
              0.8005310015733831, 0.8415600840132635, 0.8435318608212667], 
             UndirectedEdge[89, 178] -> 
             RGBColor[
              0.7465678134900458, 0.41852089474250376`, 0.4428214317913908], 
             UndirectedEdge[63, 239] -> 
             RGBColor[
              0.7475716246919596, 0.3203190752608751, 0.43024172848922937`], 
             UndirectedEdge[425, 462] -> 
             RGBColor[
              0.46789497821612225`, 0.5771295695143435, 0.9517419678446115], 
             UndirectedEdge[44, 457] -> 
             RGBColor[
              0.971591873905665, 0.9158348615179107, 0.3441402238583211], 
             UndirectedEdge[46, 254] -> 
             RGBColor[
              0.9701479715196886, 0.9109642397256092, 0.33853093574688836`], 
             UndirectedEdge[1, 452] -> 
             RGBColor[
              0.9322602930746058, 0.9461855400888011, 0.8898158415724358], 
             UndirectedEdge[260, 299] -> 
             RGBColor[
              0.8730555133292838, 0.40924242462892335`, 0.24094424290107172`],
              UndirectedEdge[321, 341] -> 
             RGBColor[
              0.9513613557569659, 0.9095700926074876, 0.6277457486864504], 
             UndirectedEdge[249, 406] -> 
             RGBColor[
              0.7717285159432983, 0.8220722497584925, 0.9779187797906509], 
             UndirectedEdge[398, 496] -> 
             RGBColor[
              0.772854455229729, 0.8215023041888747, 0.9400934644999266], 
             UndirectedEdge[382, 462] -> 
             RGBColor[
              0.6457461267198488, 0.718193443059761, 0.9682971273959624], 
             UndirectedEdge[63, 272] -> 
             RGBColor[
              0.7760561870069564, 0.7542648313203539, 0.6180585194717101], 
             UndirectedEdge[117, 270] -> 
             RGBColor[
              0.5845740471000285, 0.6736225720533406, 0.9604389568344571], 
             UndirectedEdge[164, 404] -> 
             RGBColor[
              0.668476075997944, 0.2546118639515619, 0.42442780111473677`], 
             UndirectedEdge[133, 191] -> 
             RGBColor[
              0.8637775783175057, 0.43503103092245315`, 0.20649039551348458`],
              UndirectedEdge[307, 469] -> 
             RGBColor[
              0.9564682160359039, 0.9670546473131072, 0.9585721347303071], 
             UndirectedEdge[31, 237] -> 
             RGBColor[
              0.6563458418124253, 0.2441052647833632, 0.4236548733187805], 
             UndirectedEdge[1, 468] -> 
             RGBColor[
              0.9279523941100283, 0.9427505383892493, 0.8894049503234875], 
             UndirectedEdge[346, 395] -> 
             RGBColor[
              0.37038815798297314`, 0.48267152609898045`, 0.9458581462244564],
              UndirectedEdge[214, 223] -> 
             RGBColor[
              0.5655393411525407, 0.6346146917621676, 0.9496899502021435], 
             UndirectedEdge[264, 397] -> 
             RGBColor[
              0.821293171055385, 0.8509813793951879, 0.6875502155973727], 
             UndirectedEdge[103, 204] -> 
             RGBColor[
              0.9719885254414429, 0.9382189485580146, 0.6184369954584994], 
             UndirectedEdge[110, 356] -> 
             RGBColor[
              0.9721787324776736, 0.9787715247517692, 0.9319783283533227], 
             UndirectedEdge[184, 253] -> 
             RGBColor[
              0.9391117023462816, 0.9535055350934143, 0.9669884954273025], 
             UndirectedEdge[115, 417] -> 
             RGBColor[
              0.8068785459149261, 0.8477120439640812, 0.8864925538687127], 
             UndirectedEdge[243, 459] -> 
             RGBColor[
              0.9502252929294608, 0.8501457870637995, 0.5842217515346811], 
             UndirectedEdge[190, 349] -> 
             RGBColor[
              0.9444162401519338, 0.8173359449320404, 0.2741342059889573], 
             UndirectedEdge[128, 222] -> 
             RGBColor[
              0.9181025596420722, 0.7057183711240997, 0.2536068509938104], 
             UndirectedEdge[204, 275] -> 
             RGBColor[
              0.9833843854404072, 0.9865940417773009, 0.8890677820958292], 
             UndirectedEdge[178, 455] -> 
             RGBColor[
              0.8320667077500644, 0.48613542066430004`, 0.4507810609919103], 
             UndirectedEdge[84, 391] -> 
             RGBColor[
              0.9129023699468728, 0.929877886078468, 0.8451747422035181], 
             UndirectedEdge[54, 203] -> 
             RGBColor[
              0.9687496459100586, 0.906247359101861, 0.3330987048051102], 
             UndirectedEdge[236, 314] -> 
             RGBColor[
              0.97872535109038, 0.9818713758459651, 0.8410678563294074], 
             UndirectedEdge[277, 313] -> 
             RGBColor[
              0.8200744293602249, 0.8576057182322885, 0.8556206358939851], 
             UndirectedEdge[186, 397] -> 
             RGBColor[
              0.8832415587812241, 0.8993759307117981, 0.6937246519452869], 
             UndirectedEdge[29, 297] -> 
             RGBColor[
              0.930732574853819, 0.8745712194593558, 0.6324949581064956], 
             UndirectedEdge[130, 208] -> 
             RGBColor[
              0.9933686981684711, 0.9882246408468487, 0.5196019031682739], 
             UndirectedEdge[145, 450] -> 
             RGBColor[
              0.8577669425539873, 0.8894902573979375, 0.9862782127406156], 
             UndirectedEdge[86, 350] -> 
             RGBColor[
              0.991840092584551, 0.9908378983659607, 0.7808393715471587], 
             UndirectedEdge[37, 281] -> 
             RGBColor[
              0.9607223514654537, 0.9515250698175975, 0.6835905466978647], 
             UndirectedEdge[281, 445] -> 
             RGBColor[
              0.6839249238283416, 0.7498700536812244, 0.9672006951026397], 
             UndirectedEdge[116, 224] -> 
             RGBColor[
              0.5900036796279817, 0.6766447462396145, 0.9617894216174547], 
             UndirectedEdge[112, 163] -> 
             RGBColor[
              0.878094887637688, 0.9052344922288375, 0.9682684511096284], 
             UndirectedEdge[148, 480] -> 
             RGBColor[
              0.9288182211336637, 0.9242134766347667, 0.6817340681959465], 
             UndirectedEdge[42, 487] -> 
             RGBColor[
              0.6007682513190457, 0.6854496748483303, 0.9626163710007374], 
             UndirectedEdge[122, 319] -> 
             RGBColor[
              0.7181614352966719, 0.7797524385736061, 0.9725432783363394], 
             UndirectedEdge[129, 348] -> 
             RGBColor[
              0.6892020298999814, 0.27256364350477436`, 0.42574844057013317`],
              UndirectedEdge[93, 201] -> 
             RGBColor[
              0.9555967638536137, 0.8490216173056941, 0.4480450949404119], 
             UndirectedEdge[121, 427] -> 
             RGBColor[
              0.7482347719507559, 0.7988290762625436, 0.8169109847534013], 
             UndirectedEdge[269, 411] -> 
             RGBColor[
              0.8608665252878854, 0.5003372318609793, 0.45243476665577165`], 
             UndirectedEdge[76, 371] -> 
             RGBColor[
              0.6639655337035419, 0.7366179051529742, 0.9676859605222832], 
             UndirectedEdge[61, 244] -> 
             RGBColor[
              0.7177102180995114, 0.6012513458095767, 0.5903245471948999], 
             UndirectedEdge[184, 436] -> 
             RGBColor[
              0.9801797965176104, 0.9822731510331709, 0.786485353511084], 
             UndirectedEdge[80, 293] -> 
             RGBColor[
              0.6321956352399305, 0.7100847970460963, 0.9656914568710276], 
             UndirectedEdge[111, 460] -> 
             RGBColor[
              0.860282572302325, 0.5947300938711481, 0.46425134829051506`], 
             UndirectedEdge[286, 358] -> 
             RGBColor[
              0.8960818502863286, 0.7769541062322751, 0.6137506654710119], 
             UndirectedEdge[176, 244] -> 
             RGBColor[
              0.9355047651105703, 0.7717927452059878, 0.5207598872463801], 
             UndirectedEdge[99, 321] -> 
             RGBColor[
              0.9570787918743977, 0.9138341471024258, 0.6180676206858006], 
             UndirectedEdge[187, 478] -> 
             RGBColor[
              0.8582918854653653, 0.4286803216585246, 0.2026555643652767], 
             UndirectedEdge[116, 185] -> 
             RGBColor[
              0.8377223006141428, 0.8738976110935331, 0.9744945345462501], 
             UndirectedEdge[97, 257] -> 
             RGBColor[
              0.6828605025839412, 0.2670709312780508, 0.4253443640571476], 
             UndirectedEdge[16, 313] -> 
             RGBColor[
              0.7754326644187874, 0.8251795818012451, 0.9780693834648646], 
             UndirectedEdge[166, 344] -> 
             RGBColor[
              0.7452221082430814, 0.800892441948073, 0.975240433319271], 
             UndirectedEdge[103, 443] -> 
             RGBColor[
              0.975299206699433, 0.9403909891863809, 0.5995299204412607], 
             UndirectedEdge[74, 115] -> 
             RGBColor[
              0.7814998001480901, 0.8298086815180634, 0.9753118553763905], 
             UndirectedEdge[196, 332] -> 
             RGBColor[
              0.927370868835904, 0.9402873379478357, 0.7551692175919754], 
             UndirectedEdge[49, 203] -> 
             RGBColor[
              0.8534535015793774, 0.8616781341034956, 0.6696876866829921], 
             UndirectedEdge[95, 122] -> 
             RGBColor[
              0.8595709720186533, 0.8810976119319897, 0.6916769056426451], 
             UndirectedEdge[97, 209] -> 
             RGBColor[
              0.6286822353809187, 0.7054718959794621, 0.9662622653128808], 
             UndirectedEdge[484, 490] -> 
             RGBColor[
              0.8737684384808198, 0.8074849640822339, 0.6222039262731516], 
             UndirectedEdge[128, 415] -> 
             RGBColor[
              0.8953245045262648, 0.6156053717832436, 0.2342666606295804], 
             UndirectedEdge[371, 442] -> 
             RGBColor[
              0.7416719876315849, 0.31552948411964216`, 0.4297772874487541], 
             UndirectedEdge[88, 311] -> 
             RGBColor[
              0.8679367281385428, 0.41492774870995547`, 0.4218345433296814], 
             UndirectedEdge[15, 149] -> 
             RGBColor[
              0.9449690462414408, 0.9584165286571507, 0.9758856866678718], 
             UndirectedEdge[117, 140] -> 
             RGBColor[
              0.7786158736725196, 0.7299092450204532, 0.6121739917542123], 
             UndirectedEdge[199, 475] -> 
             RGBColor[
              0.9558556651594685, 0.9642705742030381, 0.8603987462133975], 
             UndirectedEdge[71, 169] -> 
             RGBColor[
              0.9598029177630427, 0.8760679442703097, 0.2983423554017972], 
             UndirectedEdge[23, 51] -> 
             RGBColor[
              0.8539492157098789, 0.8832972024729582, 0.8041381730047916], 
             UndirectedEdge[381, 416] -> 
             RGBColor[
              0.7704603989162095, 0.7905515195445416, 0.6546779627585302], 
             UndirectedEdge[121, 447] -> 
             RGBColor[
              0.47621270354797446`, 0.5855815119170455, 0.9519272650549451], 
             UndirectedEdge[244, 407] -> 
             RGBColor[
              0.8296648114786886, 0.6900616395934442, 0.6005597806143601], 
             UndirectedEdge[255, 385] -> 
             RGBColor[
              0.8570417118606916, 0.40680226340888587`, 0.44027696401274286`],
              UndirectedEdge[30, 469] -> 
             RGBColor[
              0.7494647469479445, 0.8029905191402313, 0.951046843229828], 
             UndirectedEdge[80, 171] -> 
             RGBColor[
              0.7362485672604802, 0.7885549198106294, 0.7714455364797579], 
             UndirectedEdge[214, 466] -> 
             RGBColor[
              0.6162535088690015, 0.281392080093179, 0.43188009200884314`], 
             UndirectedEdge[199, 455] -> 
             RGBColor[
              0.9067855256121841, 0.9251565657023575, 0.8557148925957146], 
             UndirectedEdge[175, 483] -> 
             RGBColor[
              0.6239067158819064, 0.7055546044870051, 0.9635353686012798], 
             UndirectedEdge[124, 416] -> 
             RGBColor[
              0.4514226205102757, 0.5623139877112924, 0.9508437925878133], 
             UndirectedEdge[142, 396] -> 
             RGBColor[
              0.9583830088943615, 0.9684826966917592, 0.9553308898788988], 
             UndirectedEdge[185, 361] -> 
             RGBColor[
              0.9330394082142228, 0.9491647109676153, 0.9837813234134571], 
             UndirectedEdge[19, 26] -> 
             RGBColor[
              0.7916090801062013, 0.8348208520991536, 0.8646079259878061], 
             UndirectedEdge[341, 455] -> 
             RGBColor[
              0.883144523928211, 0.9093570971099566, 0.9777714843680028], 
             UndirectedEdge[159, 239] -> 
             RGBColor[
              0.8749431563834782, 0.4194886448910098, 0.3802174233496137], 
             UndirectedEdge[261, 482] -> 
             RGBColor[
              0.9674172354615516, 0.9752204080733813, 0.9400383008043031], 
             UndirectedEdge[5, 97] -> 
             RGBColor[
              0.5190996763592048, 0.6193984185200934, 0.9555799727465852], 
             UndirectedEdge[285, 396] -> 
             RGBColor[
              0.9717025727900992, 0.9751472358494069, 0.7370716207800356], 
             UndirectedEdge[174, 424] -> 
             RGBColor[
              0.9445206421661017, 0.8067027725772344, 0.502855250563593], 
             UndirectedEdge[99, 186] -> 
             RGBColor[
              0.8687938398300019, 0.8979437835690736, 0.9660931536915038], 
             UndirectedEdge[79, 127] -> 
             RGBColor[
              0.6993301495414795, 0.3936638548390068, 0.44111571658349213`], 
             UndirectedEdge[29, 86] -> 
             RGBColor[
              0.9569046696210399, 0.9650515179265053, 0.8564560399951388], 
             UndirectedEdge[127, 316] -> 
             RGBColor[
              0.6392146591821392, 0.7138701648235273, 0.967266857297447], 
             UndirectedEdge[197, 466] -> 
             RGBColor[
              0.7924247497927613, 0.4367198589159578, 0.44453800464303084`], 
             UndirectedEdge[183, 206] -> 
             RGBColor[
              0.5408771443401339, 0.6308497074817386, 0.9596689838264445], 
             UndirectedEdge[25, 392] -> 
             RGBColor[
              0.8824511003876299, 0.9091065702248267, 0.988650167800011], 
             UndirectedEdge[73, 91] -> 
             RGBColor[
              0.7648440266651328, 0.8122355268411263, 0.8118510148270011], 
             UndirectedEdge[187, 464] -> 
             RGBColor[
              0.7484422428150884, 0.4640043562184427, 0.44858924792206445`], 
             UndirectedEdge[17, 99] -> 
             RGBColor[
              0.9755497159144375, 0.9764889933244758, 0.6880108543355787], 
             UndirectedEdge[110, 157] -> 
             RGBColor[
              0.9737504695173789, 0.9798298804832204, 0.9242196573564665], 
             UndirectedEdge[241, 429] -> 
             RGBColor[
              0.6924245210092259, 0.7562604055214147, 0.9535627536146791], 
             UndirectedEdge[27, 490] -> 
             RGBColor[
              0.8820422628604212, 0.840287920658822, 0.6288612395805981], 
             UndirectedEdge[372, 418] -> 
             RGBColor[
              0.7628242207327514, 0.332584624842513, 0.4315225955872538], 
             UndirectedEdge[65, 350] -> 
             RGBColor[
              0.9346859835942876, 0.7708075256418792, 0.5316019852207272], 
             UndirectedEdge[189, 390] -> 
             RGBColor[
              0.852282996827588, 0.868218149580823, 0.6804567242880152], 
             UndirectedEdge[263, 267] -> 
             RGBColor[
              0.8680655014862798, 0.4150237876618508, 0.42161656364143085`], 
             UndirectedEdge[25, 490] -> 
             RGBColor[
              0.8718238375310006, 0.9006458680931855, 0.9876330300794439], 
             UndirectedEdge[360, 494] -> 
             RGBColor[
              0.6111150257587565, 0.6903696842245284, 0.9650905916796106], 
             UndirectedEdge[61, 203] -> 
             RGBColor[
              0.7656665692192692, 0.7917478007887517, 0.6618612598542798], 
             UndirectedEdge[36, 104] -> 
             RGBColor[
              0.9919409208277914, 0.9828461723248888, 0.5618641140465238], 
             UndirectedEdge[33, 241] -> 
             RGBColor[
              0.7110842555018715, 0.7672790735182664, 0.7557360131399563], 
             UndirectedEdge[82, 419] -> 
             RGBColor[
              0.7186003020692073, 0.7754858471199624, 0.8655446452408935], 
             UndirectedEdge[5, 404] -> 
             RGBColor[
              0.7529646149888621, 0.32469734773534487`, 0.430666284440576], 
             UndirectedEdge[40, 396] -> 
             RGBColor[
              0.8809846913890971, 0.9076302565316791, 0.9755535407023852], 
             UndirectedEdge[169, 369] -> 
             RGBColor[
              0.8648100992341814, 0.8489818894026169, 0.6393236759014422], 
             UndirectedEdge[268, 491] -> 
             RGBColor[
              0.9461416433655772, 0.8104118327165968, 0.4888072041584297], 
             UndirectedEdge[4, 151] -> 
             RGBColor[
              0.8957191582107794, 0.6455909989854842, 0.4606089486078824], 
             UndirectedEdge[6, 390] -> 
             RGBColor[
              0.8458064913058876, 0.8631586542440057, 0.6798112067439972], 
             UndirectedEdge[376, 482] -> 
             RGBColor[
              0.814239070525213, 0.8553582939494664, 0.9623317070470094], 
             UndirectedEdge[158, 278] -> 
             RGBColor[
              0.8251528855613743, 0.8640705297286286, 0.9728489838095893], 
             UndirectedEdge[317, 445] -> 
             RGBColor[
              0.5786598749723122, 0.6667824093563267, 0.9610822237034262], 
             UndirectedEdge[133, 351] -> 
             RGBColor[
              0.8508968759977045, 0.5073148992153773, 0.4533521074458633], 
             UndirectedEdge[239, 454] -> 
             RGBColor[
              0.8465159388879456, 0.3984228469859537, 0.4397427667358561], 
             UndirectedEdge[140, 198] -> 
             RGBColor[
              0.9612613030914703, 0.8708029602741088, 0.49264449046460224`], 
             UndirectedEdge[252, 309] -> 
             RGBColor[
              0.9768124112584917, 0.9796682211517491, 0.7847635016387267], 
             UndirectedEdge[161, 243] -> 
             RGBColor[
              0.9557366575190209, 0.8719965111080283, 0.5886563248517951], 
             UndirectedEdge[244, 455] -> 
             RGBColor[
              0.8497873601033054, 0.7057815275160286, 0.6025654082053535], 
             UndirectedEdge[401, 451] -> 
             RGBColor[
              0.7874104054163682, 0.8342099519108612, 0.979349917426785], 
             UndirectedEdge[210, 225] -> 
             RGBColor[
              0.8511018854694488, 0.8537455807789861, 0.660552102161359], 
             UndirectedEdge[107, 223] -> 
             RGBColor[
              0.9381886832300442, 0.9531259364521999, 0.9792567826483208], 
             UndirectedEdge[5, 204] -> 
             RGBColor[
              0.8018072661194435, 0.8449821832437698, 0.9416936955199355], 
             UndirectedEdge[59, 200] -> 
             RGBColor[
              0.9933332430325613, 0.9915111389131944, 0.7601489461718257], 
             UndirectedEdge[328, 481] -> 
             RGBColor[
              0.7681772509422632, 0.38707817700279207`, 0.4383070436528411], 
             UndirectedEdge[55, 434] -> 
             RGBColor[
              0.8122848413532798, 0.37122363758590926`, 0.43645236801492915`],
              UndirectedEdge[269, 499] -> 
             RGBColor[
              0.7903397634232576, 0.8368546534577891, 0.9795473467306006], 
             UndirectedEdge[377, 476] -> 
             RGBColor[
              0.8724870353939659, 0.41832136041060575`, 0.4141320600564531], 
             UndirectedEdge[260, 478] -> 
             RGBColor[
              0.9311859486103604, 0.7488351570687775, 0.307089285228029], 
             UndirectedEdge[163, 207] -> 
             RGBColor[
              0.9165481832175214, 0.9357201227402088, 0.9719828614053619], 
             UndirectedEdge[238, 258] -> 
             RGBColor[
              0.8266127752572585, 0.8646027420297394, 0.9422042362270783], 
             UndirectedEdge[10, 443] -> 
             RGBColor[
              0.9790914436952116, 0.9836299534261836, 0.9069739561744432], 
             UndirectedEdge[231, 326] -> 
             RGBColor[
              0.8225993270974847, 0.3793523899433728, 0.43746157895267057`], 
             UndirectedEdge[91, 287] -> 
             RGBColor[
              0.7232005299524522, 0.3005335226460366, 0.4283231466370737], 
             UndirectedEdge[242, 249] -> 
             RGBColor[
              0.7371810364184868, 0.7940250495340339, 0.9751990756508704], 
             UndirectedEdge[83, 209] -> 
             RGBColor[
              0.7587317717935925, 0.8116357260378945, 0.9765366808331785], 
             UndirectedEdge[306, 431] -> 
             RGBColor[
              0.9550931616052463, 0.8571537878365187, 0.5421152023399836], 
             UndirectedEdge[176, 376] -> 
             RGBColor[
              0.8303818579378583, 0.8664680150695792, 0.8933793304903339], 
             UndirectedEdge[30, 191] -> 
             RGBColor[
              0.7227896152605777, 0.6586221948135415, 0.6018010618335677], 
             UndirectedEdge[209, 444] -> 
             RGBColor[
              0.8939144201158854, 0.9180225322486402, 0.9819572904784213], 
             UndirectedEdge[169, 289] -> 
             RGBColor[
              0.9741779578808827, 0.9338228111857884, 0.5759177500957523], 
             UndirectedEdge[20, 46] -> 
             RGBColor[
              0.8232731505648918, 0.8187054242028444, 0.6383561870568264], 
             UndirectedEdge[49, 100] -> 
             RGBColor[
              0.8471278924468666, 0.8403403691758817, 0.6451138896942391], 
             UndirectedEdge[404, 486] -> 
             RGBColor[
              0.7852960884100921, 0.3501398186645716, 0.43376238134578804`], 
             UndirectedEdge[103, 431] -> 
             RGBColor[
              0.9428110036067787, 0.808412187617618, 0.28617266722012247`], 
             UndirectedEdge[219, 238] -> 
             RGBColor[
              0.9000798258553866, 0.9219957603272619, 0.9495267452420777], 
             UndirectedEdge[249, 499] -> 
             RGBColor[
              0.7992390286507496, 0.8439506859860717, 0.9803961665924666], 
             UndirectedEdge[254, 377] -> 
             RGBColor[
              0.8709214500257343, 0.40204372800415866`, 0.23265380995082124`],
              UndirectedEdge[57, 434] -> 
             RGBColor[
              0.6466133005278543, 0.7215400194358464, 0.9669971812082649], 
             UndirectedEdge[75, 104] -> 
             RGBColor[
              0.9561211659599109, 0.8540504439818918, 0.3340264448083302], 
             UndirectedEdge[132, 365] -> 
             RGBColor[
              0.8195692843345844, 0.4920757370912792, 0.4514864808609306], 
             UndirectedEdge[38, 77] -> 
             RGBColor[
              0.6321076006866722, 0.6968039577295024, 0.8501252242309918], 
             UndirectedEdge[172, 314] -> 
             RGBColor[
              0.9349777122694447, 0.7588034147490715, 0.47563006014672626`], 
             UndirectedEdge[398, 481] -> 
             RGBColor[
              0.8133138517436205, 0.8542621057656377, 0.9433380308730912], 
             UndirectedEdge[143, 165] -> 
             RGBColor[
              0.85135832640409, 0.8819110204081082, 0.8526664041019254], 
             UndirectedEdge[261, 475] -> 
             RGBColor[
              0.9469127574142162, 0.9594329200042153, 0.957575298824284], 
             UndirectedEdge[288, 373] -> 
             RGBColor[
              0.7249628312285612, 0.5898615017932924, 0.5873939829297368], 
             UndirectedEdge[78, 171] -> 
             RGBColor[
              0.9380056985732319, 0.773321566157888, 0.4070226756725198], 
             UndirectedEdge[6, 370] -> 
             RGBColor[
              0.6903076882868913, 0.7579928797132476, 0.9697670771424693], 
             UndirectedEdge[264, 295] -> 
             RGBColor[
              0.6736027344703561, 0.7449428428294191, 0.9681020834627061], 
             UndirectedEdge[45, 464] -> 
             RGBColor[
              0.7536288936854932, 0.7587025281410702, 0.6263318585143425], 
             UndirectedEdge[228, 318] -> 
             RGBColor[
              0.7664969040358779, 0.33545375295234237`, 0.43188865433573265`],
              UndirectedEdge[7, 295] -> 
             RGBColor[
              0.7960708567438881, 0.6977158775631529, 0.603836362872096], 
             UndirectedEdge[225, 320] -> 
             RGBColor[
              0.8260318003880778, 0.8341606397737156, 0.6580533503737132], 
             UndirectedEdge[137, 148] -> 
             RGBColor[
              0.9308156753241098, 0.9309513586436886, 0.6894938005382568], 
             UndirectedEdge[61, 455] -> 
             RGBColor[
              0.6862751113260758, 0.7534920853931083, 0.9702885017310074], 
             UndirectedEdge[11, 331] -> 
             RGBColor[
              0.8635138045456434, 0.8468864756098864, 0.6376133489599338], 
             UndirectedEdge[20, 392] -> 
             RGBColor[
              0.7619917436053689, 0.8141516121648945, 0.9768697853274675], 
             UndirectedEdge[348, 431] -> 
             RGBColor[
              0.8518805478676574, 0.33092226713357065`, 0.19457729374712981`],
              UndirectedEdge[241, 351] -> 
             RGBColor[
              0.6502779202517689, 0.7231888973836833, 0.9680931978439296], 
             UndirectedEdge[343, 374] -> 
             RGBColor[
              0.8371322613705945, 0.8702906205242222, 0.8129504919521906], 
             UndirectedEdge[162, 389] -> 
             RGBColor[
              0.6400936216844713, 0.6816416157497263, 0.6472640763314561], 
             UndirectedEdge[207, 266] -> 
             RGBColor[
              0.6999715842628387, 0.7641875513440894, 0.9718430142268751], 
             UndirectedEdge[98, 425] -> 
             RGBColor[
              0.7214121383713561, 0.6304106903060595, 0.5959163206623286], 
             UndirectedEdge[151, 284] -> 
             RGBColor[
              0.6264997525647006, 0.6983038820046561, 0.950960197051871], 
             UndirectedEdge[41, 365] -> 
             RGBColor[
              0.7685724857248732, 0.45201900397375405`, 0.4465524026366916], 
             UndirectedEdge[436, 473] -> 
             RGBColor[
              0.9818027679878696, 0.9834835604983183, 0.783738086150688], 
             UndirectedEdge[311, 405] -> 
             RGBColor[
              0.9244840336956242, 0.7617961248772541, 0.5792393535412119], 
             UndirectedEdge[235, 432] -> 
             RGBColor[
              0.8529494516210536, 0.8822252484191044, 0.7807364543685393], 
             UndirectedEdge[109, 474] -> 
             RGBColor[
              0.7615560806815869, 0.35629287773301604`, 0.43449023802901254`],
              UndirectedEdge[364, 468] -> 
             RGBColor[
              0.9059819380974363, 0.9275656718189098, 0.9803633684323725], 
             UndirectedEdge[203, 374] -> 
             RGBColor[
              0.9858840139888447, 0.9627311253168442, 0.5114364360448502], 
             UndirectedEdge[36, 112] -> 
             RGBColor[
              0.896678164759537, 0.917156266956042, 0.846753223834348], 
             UndirectedEdge[324, 342] -> 
             RGBColor[
              0.8297094093253994, 0.7738016692901679, 0.6179755053387721], 
             UndirectedEdge[374, 445] -> 
             RGBColor[
              0.7110903873817795, 0.7678354005696754, 0.8028309730652843], 
             UndirectedEdge[2, 327] -> 
             RGBColor[
              0.9588418073027374, 0.9679947296721939, 0.9190050322331037], 
             UndirectedEdge[128, 438] -> 
             RGBColor[
              0.9258938074200946, 0.7624468830597477, 0.5765861723801855], 
             UndirectedEdge[33, 460] -> 
             RGBColor[
              0.9030370655778531, 0.6258912695693517, 0.3228913451981321], 
             UndirectedEdge[298, 335] -> 
             RGBColor[
              0.7837543667639807, 0.8317778910923206, 0.9788729840182164], 
             UndirectedEdge[112, 343] -> 
             RGBColor[
              0.7389212983047619, 0.7959702013363286, 0.9746124274690359], 
             UndirectedEdge[106, 265] -> 
             RGBColor[
              0.5393957148500103, 0.6369447666721018, 0.9568823530260517], 
             UndirectedEdge[19, 468] -> 
             RGBColor[
              0.7274318867536049, 0.7865579940859144, 0.9739162423848566], 
             UndirectedEdge[161, 202] -> 
             RGBColor[
              0.9612696179815914, 0.8727792084053032, 0.37765809560105035`], 
             UndirectedEdge[204, 390] -> 
             RGBColor[
              0.9811228326810404, 0.969031111714509, 0.6539220542151523], 
             UndirectedEdge[211, 289] -> 
             RGBColor[
              0.961630836054655, 0.8854173326053443, 0.5588449735818659], 
             UndirectedEdge[48, 479] -> 
             RGBColor[
              0.7724060343561934, 0.8224455384508682, 0.9751212754392999], 
             UndirectedEdge[57, 495] -> 
             RGBColor[
              0.525420798490803, 0.6255993000088897, 0.9557821964184496], 
             UndirectedEdge[10, 280] -> 
             RGBColor[
              0.9088893409242738, 0.9292463721220534, 0.9585352488077757], 
             UndirectedEdge[206, 476] -> 
             RGBColor[
              0.8829958222432448, 0.9086232813737462, 0.9464913795038056], 
             UndirectedEdge[13, 256] -> 
             RGBColor[
              0.7036968790624343, 0.2846995802240602, 0.42678774779478423`], 
             UndirectedEdge[184, 221] -> 
             RGBColor[
              0.964661135267735, 0.9310880819958933, 0.6273035174681806], 
             UndirectedEdge[126, 282] -> 
             RGBColor[
              0.984590919183788, 0.9872503301083471, 0.8761191017928724], 
             UndirectedEdge[53, 266] -> 
             RGBColor[
              0.7435854085881053, 0.7982768995747935, 0.9521796620257837], 
             UndirectedEdge[194, 220] -> 
             RGBColor[
              0.7441290296147901, 0.7970981882278925, 0.8953073613245406], 
             UndirectedEdge[375, 417] -> 
             RGBColor[
              0.8749980004877627, 0.41951132433756055`, 0.37930851460962695`],
              UndirectedEdge[245, 448] -> 
             RGBColor[
              0.9401836690450623, 0.7842240931015485, 0.36329227483695836`], 
             UndirectedEdge[79, 147] -> 
             RGBColor[
              0.8591921020918458, 0.5219909495731319, 0.4551522933952957], 
             UndirectedEdge[77, 253] -> 
             RGBColor[
              0.9527512445759991, 0.9621728157611786, 0.8765003062815697], 
             UndirectedEdge[180, 205] -> 
             RGBColor[
              0.8837335713370682, 0.9071482038212957, 0.8534172892263316], 
             UndirectedEdge[28, 432] -> 
             RGBColor[
              0.9899498253781709, 0.9890158706587915, 0.7365432639382257], 
             UndirectedEdge[84, 245] -> 
             RGBColor[
              0.8589527806795352, 0.7242420214941923, 0.6056474605238149], 
             UndirectedEdge[19, 459] -> 
             RGBColor[
              0.7543839199108632, 0.6962422699377042, 0.6070443227835761], 
             UndirectedEdge[153, 236] -> 
             RGBColor[
              0.9595054880278513, 0.969319839791625, 0.9534308254953455], 
             UndirectedEdge[315, 349] -> 
             RGBColor[
              0.9725887960454748, 0.9157977690996699, 0.5037333227133985], 
             UndirectedEdge[18, 460] -> 
             RGBColor[
              0.8783493653710295, 0.5359856579343897, 0.2199901409853106], 
             UndirectedEdge[126, 449] -> 
             RGBColor[
              0.9891846411436224, 0.9897955854179128, 0.8289020157090751], 
             UndirectedEdge[49, 324] -> 
             RGBColor[
              0.8297094093253994, 0.7738016692901679, 0.6179755053387721], 
             UndirectedEdge[334, 415] -> 
             RGBColor[
              0.9505236982077168, 0.8376161444904959, 0.5314837680318374], 
             UndirectedEdge[5, 444] -> 
             RGBColor[
              0.7843318610941716, 0.8319490547892715, 0.9712749979121257], 
             UndirectedEdge[147, 449] -> 
             RGBColor[
              0.9415113220782227, 0.9539316465188796, 0.9067469571956693], 
             UndirectedEdge[254, 426] -> 
             RGBColor[
              0.902523541991982, 0.9013526736685507, 0.6764395308624931], 
             UndirectedEdge[186, 321] -> 
             RGBColor[
              0.8665009649429838, 0.8425578945612698, 0.6305034243840595], 
             UndirectedEdge[260, 399] -> 
             RGBColor[
              0.931876541916183, 0.751970979978353, 0.30766553321039825`], 
             UndirectedEdge[184, 287] -> 
             RGBColor[
              0.8668700492204069, 0.41413222131933614`, 0.4236401525036676], 
             UndirectedEdge[129, 431] -> 
             RGBColor[
              0.6769858666514581, 0.6369748659575175, 0.6020526014758945], 
             UndirectedEdge[300, 432] -> 
             RGBColor[
              0.8126269917059107, 0.8505547470983497, 0.7768339160366238], 
             UndirectedEdge[207, 293] -> 
             RGBColor[
              0.8305172658882469, 0.867971291116219, 0.9836236026635878], 
             UndirectedEdge[118, 399] -> 
             RGBColor[
              0.9151134844268868, 0.7537234776923913, 0.5943793154746936], 
             UndirectedEdge[138, 179] -> 
             RGBColor[
              0.6823645461606985, 0.7487834343997584, 0.9709673513497004], 
             UndirectedEdge[40, 161] -> 
             RGBColor[
              0.8706052903393742, 0.8053767751625005, 0.6219690116716388], 
             UndirectedEdge[243, 279] -> 
             RGBColor[
              0.6988818489133043, 0.7603121272885499, 0.931479962301244], 
             UndirectedEdge[69, 233] -> 
             RGBColor[
              0.9370700024970195, 0.7699262226343115, 0.4842177220861868], 
             UndirectedEdge[237, 460] -> 
             RGBColor[
              0.8307700341932431, 0.2375175430900342, 0.17709872553421988`], 
             UndirectedEdge[54, 295] -> 
             RGBColor[
              0.8266251770988317, 0.818984138788508, 0.6352733064268463], 
             UndirectedEdge[102, 210] -> 
             RGBColor[
              0.7035637930246972, 0.7683486494845491, 0.9710883217773919], 
             UndirectedEdge[137, 156] -> 
             RGBColor[
              0.989058712068816, 0.9735063971933271, 0.5181344333038113], 
             UndirectedEdge[231, 444] -> 
             RGBColor[
              0.8596819590739189, 0.4087713554575028, 0.43580771416750785`], 
             UndirectedEdge[383, 393] -> 
             RGBColor[
              0.9247769888616354, 0.7253174031316674, 0.2871527164496094], 
             UndirectedEdge[43, 137] -> 
             RGBColor[
              0.9745439276005757, 0.9650506997039606, 0.6670244117712316], 
             UndirectedEdge[233, 348] -> 
             RGBColor[
              0.8762578943105568, 0.42003232281108027`, 0.3584288134652338], 
             UndirectedEdge[193, 410] -> 
             RGBColor[
              0.8840798789726655, 0.91040522317599, 0.988802371270552], 
             UndirectedEdge[126, 384] -> 
             RGBColor[
              0.9691444499136661, 0.9757303786179623, 0.9022659451827891], 
             UndirectedEdge[162, 345] -> 
             RGBColor[
              0.5789761560829796, 0.6618860444560855, 0.9632372230236027], 
             UndirectedEdge[165, 178] -> 
             RGBColor[
              0.795214247462523, 0.457345998598601, 0.44710795215626986`], 
             UndirectedEdge[154, 455] -> 
             RGBColor[
              0.6744760544973288, 0.7439130795180788, 0.9693596367560792], 
             UndirectedEdge[211, 470] -> 
             RGBColor[
              0.9607380822500169, 0.8850481559644001, 0.5736402144975032], 
             UndirectedEdge[201, 305] -> 
             RGBColor[
              0.867306208525429, 0.4548552568273408, 0.20956942749150895`], 
             UndirectedEdge[220, 474] -> 
             RGBColor[
              0.5694201084563834, 0.6613199219852735, 0.9592459832737231], 
             UndirectedEdge[125, 173] -> 
             RGBColor[
              0.6841822585277213, 0.6378839290986019, 0.6012380752475595], 
             UndirectedEdge[189, 443] -> 
             RGBColor[
              0.8538295326768384, 0.8854854017761856, 0.9274521327737676], 
             UndirectedEdge[307, 500] -> 
             RGBColor[
              0.8370144313273453, 0.8733048170822417, 0.9724092533347427], 
             UndirectedEdge[102, 134] -> 
             RGBColor[
              0.791236060720786, 0.49683096075452227`, 0.4520033190633851], 
             UndirectedEdge[102, 174] -> 
             RGBColor[
              0.8350321813495103, 0.8695637830205294, 0.869488434863178], 
             UndirectedEdge[203, 281] -> 
             RGBColor[
              0.9587185504354068, 0.9447657784283934, 0.6758061580822055], 
             UndirectedEdge[279, 421] -> 
             RGBColor[
              0.4536038208375216, 0.5662737064911012, 0.950410698971603], 
             UndirectedEdge[335, 430] -> 
             RGBColor[
              0.7967539422538665, 0.8419563877176446, 0.9736290714795812], 
             UndirectedEdge[69, 431] -> 
             RGBColor[
              0.9005039828326704, 0.6362611391180473, 0.23844044250903082`], 
             UndirectedEdge[149, 249] -> 
             RGBColor[
              0.9298273497237228, 0.9468831054513975, 0.9931689567549646], 
             UndirectedEdge[141, 345] -> 
             RGBColor[
              0.8288258001248807, 0.3843172105223105, 0.43805546550846164`], 
             UndirectedEdge[12, 283] -> 
             RGBColor[
              0.7672959585928333, 0.8184175277958409, 0.9773660257948413], 
             UndirectedEdge[119, 381] -> 
             RGBColor[
              0.7199326427952348, 0.749530810876061, 0.6507002327074178], 
             UndirectedEdge[396, 430] -> 
             RGBColor[
              0.9465612602226092, 0.9596660558887032, 0.9753420267743158], 
             UndirectedEdge[49, 360] -> 
             RGBColor[
              0.5559425027968472, 0.647105763386264, 0.959634692836589], 
             UndirectedEdge[208, 497] -> 
             RGBColor[
              0.9932610191013438, 0.9901777205117097, 0.6665914178610824], 
             UndirectedEdge[275, 444] -> 
             RGBColor[
              0.9659089804151351, 0.9735609133228027, 0.9186490844880193], 
             UndirectedEdge[269, 323] -> 
             RGBColor[
              0.7679994435956179, 0.8191736127245757, 0.9774769764513243], 
             UndirectedEdge[273, 279] -> 
             RGBColor[
              0.6834469962982196, 0.26757892265532757`, 0.42538173491800535`],
              UndirectedEdge[107, 289] -> 
             RGBColor[
              0.9560441562497919, 0.9658326942656965, 0.9217229269705367], 
             UndirectedEdge[289, 314] -> 
             RGBColor[
              0.9913922043427554, 0.9907084695325408, 0.7923169805090149], 
             UndirectedEdge[6, 428] -> 
             RGBColor[
              0.8511787745078626, 0.8805841254496182, 0.759906973174528], 
             UndirectedEdge[7, 17] -> 
             RGBColor[
              0.9454916235307165, 0.8095912242004434, 0.3300065010953132], 
             UndirectedEdge[309, 424] -> 
             RGBColor[
              0.9278521702007474, 0.7956863719382969, 0.5944335652854403], 
             UndirectedEdge[128, 385] -> 
             RGBColor[
              0.90803593559698, 0.7491285114936502, 0.6068148912978062], 
             UndirectedEdge[71, 362] -> 
             RGBColor[
              0.8993596635760123, 0.8743414183416067, 0.6401120189217018], 
             UndirectedEdge[43, 156] -> 
             RGBColor[
              0.9800106971440173, 0.9822431861749945, 0.7944006206519609], 
             UndirectedEdge[59, 298] -> 
             RGBColor[
              0.9548700987487072, 0.9639511923904325, 0.8805610049537836], 
             UndirectedEdge[261, 455] -> 
             RGBColor[
              0.8978426178669319, 0.9203189115035347, 0.9528914452066011], 
             UndirectedEdge[17, 89] -> 
             RGBColor[
              0.7767916678086366, 0.8194683199364465, 0.6905074169089074], 
             UndirectedEdge[9, 68] -> 
             RGBColor[
              0.37820207133761113`, 0.502001358028989, 0.9453196794480403], 
             UndirectedEdge[73, 298] -> 
             RGBColor[
              0.9558382123664092, 0.9638705529638023, 0.8295547402260359], 
             UndirectedEdge[16, 333] -> 
             RGBColor[
              0.9105624106429414, 0.9315217659612229, 0.9913314496674255], 
             UndirectedEdge[257, 445] -> 
             RGBColor[
              0.6873953053007087, 0.27099874946550306`, 0.4256333176762913], 
             UndirectedEdge[428, 451] -> 
             RGBColor[
              0.9290586775530925, 0.9417841891858199, 0.7675738629983371], 
             UndirectedEdge[15, 419] -> 
             RGBColor[
              0.9743451413212111, 0.97908260947891, 0.8698876392004298], 
             UndirectedEdge[17, 313] -> 
             RGBColor[
              0.8188416386205986, 0.8535512865916756, 0.6938554127000367], 
             UndirectedEdge[5, 326] -> 
             RGBColor[
              0.7287079131295202, 0.7878206065180764, 0.9737557950898696], 
             UndirectedEdge[216, 217] -> 
             RGBColor[
              0.8820590967319211, 0.9072450227925453, 0.9169559418120814], 
             UndirectedEdge[138, 222] -> 
             RGBColor[
              0.9462600908337886, 0.9085236321518442, 0.6396839564003339], 
             UndirectedEdge[251, 447] -> 
             RGBColor[
              0.6725628431898005, 0.5889654923278889, 0.591741324737985], 
             UndirectedEdge[58, 144] -> 
             RGBColor[
              0.33387586223410404`, 0.4636082236035798, 0.9424952526000925], 
             UndirectedEdge[11, 404] -> 
             RGBColor[
              0.8006692531000443, 0.36214945176074137`, 0.4352946347316905], 
             UndirectedEdge[270, 329] -> 
             RGBColor[
              0.7246071981185942, 0.3016755192329894, 0.4284338847079078], 
             UndirectedEdge[314, 406] -> 
             RGBColor[
              0.8060083133194686, 0.846096230900659, 0.8484109426221227], 
             UndirectedEdge[13, 409] -> 
             RGBColor[
              0.7100297590980085, 0.28984089752993386`, 0.42728629530928863`],
              UndirectedEdge[279, 335] -> 
             RGBColor[
              0.5331298805813555, 0.6307109649835809, 0.956757141040579], 
             UndirectedEdge[195, 446] -> 
             RGBColor[
              0.9735969814526888, 0.979829252515166, 0.9295776027771965], 
             UndirectedEdge[22, 170] -> 
             RGBColor[
              0.7578078654788301, 0.7955377914474235, 0.6763547272485007], 
             UndirectedEdge[159, 166] -> 
             RGBColor[
              0.8662275921565633, 0.894396628731041, 0.893580919196807], 
             UndirectedEdge[59, 87] -> 
             RGBColor[
              0.9911519812261318, 0.9906091311003644, 0.7962980992289657], 
             UndirectedEdge[176, 407] -> 
             RGBColor[
              0.883947109712518, 0.9083135968669349, 0.8987182141914941], 
             UndirectedEdge[169, 470] -> 
             RGBColor[
              0.9732852040762447, 0.9334536345448443, 0.5907129910113897], 
             UndirectedEdge[13, 188] -> 
             RGBColor[
              0.8691456157549405, 0.3960534220230558, 0.22575502914695028`], 
             UndirectedEdge[273, 396] -> 
             RGBColor[
              0.8616031360685126, 0.41020416611443217`, 0.43255566263887035`],
              UndirectedEdge[30, 405] -> 
             RGBColor[
              0.7072893427317383, 0.5901314001159066, 0.5889651423803139], 
             UndirectedEdge[258, 497] -> 
             RGBColor[
              0.8323202239684293, 0.8674373744613453, 0.8688641369575616], 
             UndirectedEdge[90, 485] -> 
             RGBColor[
              0.7595603241473345, 0.8110021213582133, 0.9468946122690791], 
             UndirectedEdge[89, 455] -> 
             RGBColor[
              0.6901039119398418, 0.7566004782168656, 0.9705899189406818], 
             UndirectedEdge[422, 451] -> 
             RGBColor[
              0.9170221575356472, 0.9357994493992272, 0.9616751566738718], 
             UndirectedEdge[99, 178] -> 
             RGBColor[
              0.879073178893913, 0.5232013436678565, 0.44115705674250494`], 
             UndirectedEdge[119, 416] -> 
             RGBColor[
              0.5172308158995423, 0.6189503031867931, 0.9551374509879709], 
             UndirectedEdge[129, 204] -> 
             RGBColor[
              0.7061633884861225, 0.7667816268979141, 0.9343169297142714], 
             UndirectedEdge[1, 381] -> 
             RGBColor[
              0.9822906017097518, 0.9559257840997029, 0.5710570113507505], 
             UndirectedEdge[287, 409] -> 
             RGBColor[
              0.7100297590980085, 0.28984089752993386`, 0.42728629530928863`],
              UndirectedEdge[340, 384] -> 
             RGBColor[
              0.6775488631537578, 0.7437991718360553, 0.9587929036303788], 
             UndirectedEdge[233, 379] -> 
             RGBColor[
              0.9552438230652295, 0.9639905832246394, 0.8693670513771492], 
             UndirectedEdge[1, 124] -> 
             RGBColor[
              0.663252823303818, 0.7276882522664536, 0.8672228411800336], 
             UndirectedEdge[134, 309] -> 
             RGBColor[
              0.8852413656389592, 0.5706127299069474, 0.4470637193355316], 
             UndirectedEdge[1, 380] -> 
             RGBColor[
              0.7909649138174923, 0.8345809385426437, 0.876389800965824], 
             UndirectedEdge[112, 403] -> 
             RGBColor[
              0.6731054099890736, 0.7431088679028508, 0.9690407845653793], 
             UndirectedEdge[214, 268] -> 
             RGBColor[
              0.5867025435860642, 0.6486892806930289, 0.8373384580087706], 
             UndirectedEdge[404, 444] -> 
             RGBColor[
              0.8596819590739189, 0.4087713554575028, 0.43580771416750785`], 
             UndirectedEdge[252, 320] -> 
             RGBColor[
              0.8369424098176619, 0.8698845472494359, 0.7922863220434474], 
             UndirectedEdge[173, 419] -> 
             RGBColor[
              0.7214210590393626, 0.7779290450321432, 0.8657243813807343], 
             UndirectedEdge[407, 475] -> 
             RGBColor[
              0.8472998442525375, 0.8814163876776562, 0.9852075887681505], 
             UndirectedEdge[167, 305] -> 
             RGBColor[
              0.8671514065391667, 0.5310753676711483, 0.4562541265842761], 
             UndirectedEdge[407, 482] -> 
             RGBColor[
              0.8678043222998728, 0.8972038757468223, 0.9676705907481695], 
             UndirectedEdge[197, 493] -> 
             RGBColor[
              0.8512029317491523, 0.8817816535080247, 0.8522894580306342], 
             UndirectedEdge[235, 300] -> 
             RGBColor[
              0.6715650532026171, 0.7431807015631109, 0.968015414074766], 
             UndirectedEdge[312, 385] -> 
             RGBColor[
              0.9202816863056453, 0.9392513287053943, 0.9915538423380508], 
             UndirectedEdge[188, 318] -> 
             RGBColor[
              0.8188257796862275, 0.8290067624630973, 0.6580295252240245], 
             UndirectedEdge[71, 153] -> 
             RGBColor[
              0.9577973011623868, 0.9204020665627219, 0.6271045549809979], 
             UndirectedEdge[45, 481] -> 
             RGBColor[
              0.803499508948307, 0.7991027810687813, 0.6303173105018525], 
             UndirectedEdge[53, 317] -> 
             RGBColor[
              0.846058503291233, 0.8801301210836746, 0.9611622373513238], 
             UndirectedEdge[253, 301] -> 
             RGBColor[
              0.9524527173361711, 0.959782379958257, 0.7166616433030766], 
             UndirectedEdge[442, 447] -> 
             RGBColor[
              0.6951451380201109, 0.277711265049131, 0.4261271301642636], 
             UndirectedEdge[118, 464] -> 
             RGBColor[
              0.7496484271456489, 0.803573706622693, 0.9627035928275058], 
             UndirectedEdge[2, 118] -> 
             RGBColor[
              0.940232635394042, 0.9547853646073893, 0.9804792416375547], 
             UndirectedEdge[332, 454] -> 
             RGBColor[
              0.8831225919136855, 0.9096419993405516, 0.9887142152612136], 
             UndirectedEdge[84, 455] -> 
             RGBColor[
              0.8245349725318623, 0.8629390107649177, 0.983122575920558], 
             UndirectedEdge[423, 488] -> 
             RGBColor[
              0.7061082711134061, 0.730271675999758, 0.6380615810920633], 
             UndirectedEdge[5, 231] -> 
             RGBColor[
              0.7529646149888621, 0.32469734773534487`, 0.430666284440576], 
             UndirectedEdge[121, 337] -> 
             RGBColor[
              0.7481093850586511, 0.7985608863788908, 0.80326339534599], 
             UndirectedEdge[23, 360] -> 
             RGBColor[
              0.6882765642706542, 0.7479524558009207, 0.7908853530780005], 
             UndirectedEdge[79, 336] -> 
             RGBColor[
              0.8609080547346162, 0.5233592036321835, 0.4553159624902122], 
             UndirectedEdge[237, 371] -> 
             RGBColor[
              0.7416719876315849, 0.3155294841196421, 0.429777287448754], 
             UndirectedEdge[9, 330] -> 
             RGBColor[
              0.651159781873893, 0.7243935137791186, 0.9679464684332302], 
             UndirectedEdge[76, 111] -> 
             RGBColor[
              0.8015283081299227, 0.8452471905101304, 0.980754875182265], 
             UndirectedEdge[91, 256] -> 
             RGBColor[
              0.5057081135223296, 0.6095956543051453, 0.954230341647787], 
             UndirectedEdge[35, 193] -> 
             RGBColor[
              0.6639542554980994, 0.7352557552835026, 0.9686522970466831], 
             UndirectedEdge[43, 267] -> 
             RGBColor[
              0.866711304225259, 0.41401382956187605`, 0.4239088663731271], 
             UndirectedEdge[261, 448] -> 
             RGBColor[
              0.9852562254344517, 0.9852177267762486, 0.7111294726988415], 
             UndirectedEdge[322, 374] -> 
             RGBColor[
              0.6281641941468934, 0.6916587625020558, 0.7977062692039003], 
             UndirectedEdge[76, 130] -> 
             RGBColor[
              0.8652597692658276, 0.891132798226997, 0.7251469958593525], 
             UndirectedEdge[107, 153] -> 
             RGBColor[
              0.9403538691854423, 0.9547407285925691, 0.9755916875967711], 
             UndirectedEdge[410, 437] -> 
             RGBColor[
              0.74403671305098, 0.7995231181930645, 0.9758134208263318], 
             UndirectedEdge[11, 164] -> 
             RGBColor[
              0.5690799936469824, 0.6568879735684549, 0.9611476537696408], 
             UndirectedEdge[213, 500] -> 
             RGBColor[
              0.8551146946251209, 0.8866713426189123, 0.9358311808323976], 
             UndirectedEdge[251, 454] -> 
             RGBColor[
              0.8996190444915526, 0.770032865233123, 0.6121647795953735], 
             UndirectedEdge[111, 483] -> 
             RGBColor[
              0.7416762218335273, 0.7981148228197681, 0.9750460846617972], 
             UndirectedEdge[5, 233] -> 
             RGBColor[
              0.8091957639491283, 0.8488405058196375, 0.8552066468587146], 
             UndirectedEdge[69, 372] -> 
             RGBColor[
              0.8382141073541229, 0.2720878256117942, 0.18334033459222407`], 
             UndirectedEdge[454, 489] -> 
             RGBColor[
              0.9014720755185189, 0.9242733794835821, 0.9904644053882201], 
             UndirectedEdge[289, 493] -> 
             RGBColor[
              0.9914138845358008, 0.9907174348495206, 0.7919576836037121], 
             UndirectedEdge[74, 268] -> 
             RGBColor[
              0.9670382985508721, 0.9732289047533519, 0.8641520314308888], 
             UndirectedEdge[192, 258] -> 
             RGBColor[
              0.8143469391103026, 0.8047789744942322, 0.627312702034929], 
             UndirectedEdge[68, 368] -> 
             RGBColor[
              0.5117587894741561, 0.6096716751083331, 0.9564656702394643], 
             UndirectedEdge[50, 414] -> 
             RGBColor[
              0.8635509568359938, 0.8930967268206361, 0.9291862397559125], 
             UndirectedEdge[358, 441] -> 
             RGBColor[
              0.9467314368738873, 0.8142212864413634, 0.4940708678777428], 
             UndirectedEdge[71, 289] -> 
             RGBColor[
              0.9734875882267364, 0.9314940322358494, 0.5732357943547636], 
             UndirectedEdge[54, 321] -> 
             RGBColor[
              0.9575750198456201, 0.8682046392037486, 0.29150021100028545`], 
             UndirectedEdge[75, 408] -> 
             RGBColor[
              0.9113806845237596, 0.6849289303606003, 0.2474789442848188], 
             UndirectedEdge[8, 239] -> 
             RGBColor[
              0.6562381217823601, 0.2440119631074868, 0.42364800949371784`], 
             UndirectedEdge[389, 472] -> 
             RGBColor[
              0.9313220112864495, 0.7555557954105885, 0.2912581303558924], 
             UndirectedEdge[178, 475] -> 
             RGBColor[
              0.8647801341149206, 0.5122114263314204, 0.45390363007036555`], 
             UndirectedEdge[332, 489] -> 
             RGBColor[
              0.8796848507683674, 0.9069008378662726, 0.9883863204418655], 
             UndirectedEdge[28, 406] -> 
             RGBColor[
              0.8014915534649987, 0.8442284346254021, 0.9232653424104943], 
             UndirectedEdge[77, 87] -> 
             RGBColor[
              0.991383479167707, 0.9907048614484315, 0.7924615792395961], 
             UndirectedEdge[274, 300] -> 
             RGBColor[
              0.8083447638054794, 0.8370407169362308, 0.6810386965078915], 
             UndirectedEdge[330, 333] -> 
             RGBColor[
              0.8877756462720396, 0.9133522185821074, 0.9891580277397443], 
             UndirectedEdge[325, 490] -> 
             RGBColor[
              0.8631816360663671, 0.8937548112315963, 0.9868087291887628], 
             UndirectedEdge[420, 489] -> 
             RGBColor[
              0.9042481817546957, 0.9264869712409132, 0.990729192879286], 
             UndirectedEdge[271, 304] -> 
             RGBColor[
              0.9730714287677378, 0.9208257474836841, 0.3498880151069824], 
             UndirectedEdge[166, 387] -> 
             RGBColor[
              0.6188574962283588, 0.6999250076894272, 0.9641842271363195], 
             UndirectedEdge[16, 165] -> 
             RGBColor[
              0.8063523445655414, 0.849334270930162, 0.981151168221054], 
             UndirectedEdge[44, 356] -> 
             RGBColor[
              0.9771349964493456, 0.9524590202511571, 0.6318065045087993], 
             UndirectedEdge[86, 377] -> 
             RGBColor[
              0.876618445449665, 0.4201442303296663, 0.3497502535486439], 
             UndirectedEdge[113, 353] -> 
             RGBColor[
              0.9689613307787546, 0.9758842263544709, 0.9155814155172375], 
             UndirectedEdge[63, 222] -> 
             RGBColor[
              0.782348628874069, 0.779017867635091, 0.6241339984489624], 
             UndirectedEdge[71, 493] -> 
             RGBColor[
              0.9770388444179607, 0.9329625679340419, 0.5143822889097569], 
             UndirectedEdge[106, 270] -> 
             RGBColor[
              0.5297915822556674, 0.6291476991707714, 0.9561262805271282], 
             UndirectedEdge[414, 498] -> 
             RGBColor[
              0.8735087535439982, 0.4188954824544132, 0.4039891905153514], 
             UndirectedEdge[46, 220] -> 
             RGBColor[
              0.730861867155104, 0.7443254389497538, 0.6306411600283983], 
             UndirectedEdge[302, 443] -> 
             RGBColor[
              0.8846375250425087, 0.5042135720165702, 0.4141097542497718], 
             UndirectedEdge[90, 267] -> 
             RGBColor[
              0.8681232989064126, 0.41506689288315124`, 0.4215187276851273], 
             UndirectedEdge[116, 187] -> 
             RGBColor[
              0.8086450751077205, 0.5119958991997102, 0.4539329137012126], 
             UndirectedEdge[162, 472] -> 
             RGBColor[
              0.5973413013932953, 0.5129886370061016, 0.5847381035462567], 
             UndirectedEdge[271, 371] -> 
             RGBColor[
              0.7784618931428741, 0.7885739003109227, 0.6427165664108827], 
             UndirectedEdge[84, 478] -> 
             RGBColor[
              0.8542805244833622, 0.7030263973405301, 0.6017488154262489], 
             UndirectedEdge[5, 163] -> 
             RGBColor[
              0.7911173437560974, 0.8370096566483276, 0.9597889457027997], 
             UndirectedEdge[188, 430] -> 
             RGBColor[
              0.9578749797522511, 0.9384399397516388, 0.6651410765364356], 
             UndirectedEdge[380, 487] -> 
             RGBColor[
              0.5317569819074974, 0.6307432991483723, 0.9562810039872164], 
             UndirectedEdge[88, 304] -> 
             RGBColor[
              0.8714116780481608, 0.40369738223481644`, 0.23455825324615384`],
              UndirectedEdge[41, 494] -> 
             RGBColor[
              0.7305820371955105, 0.7892917640703738, 0.973961274330709], 
             UndirectedEdge[23, 136] -> 
             RGBColor[
              0.876359318996704, 0.4195899850484859, 0.32154593828693373`], 
             UndirectedEdge[7, 84] -> 
             RGBColor[
              0.8649865868639143, 0.75164012614622, 0.6106822163061845], 
             UndirectedEdge[218, 493] -> 
             RGBColor[
              0.9949434605339798, 0.9921770052307333, 0.7334634750640083], 
             UndirectedEdge[40, 183] -> 
             RGBColor[
              0.5551918624741662, 0.6420324740839319, 0.9610957411513983], 
             UndirectedEdge[192, 453] -> 
             RGBColor[
              0.9733402221644358, 0.928017526201099, 0.5520697638441152], 
             UndirectedEdge[49, 397] -> 
             RGBColor[
              0.8590194693531792, 0.8804534503559114, 0.6913104204393946], 
             UndirectedEdge[291, 467] -> 
             RGBColor[
              0.9676462526747229, 0.8969739085576364, 0.5035325726643946], 
             UndirectedEdge[347, 462] -> 
             RGBColor[
              0.6013089455387275, 0.6828055572776299, 0.9640466969127705], 
             UndirectedEdge[31, 226] -> 
             RGBColor[
              0.6311641288611193, 0.7047154968962085, 0.9677582424425406], 
             UndirectedEdge[120, 381] -> 
             RGBColor[
              0.9832691624877421, 0.9546862490304229, 0.435324100145233], 
             UndirectedEdge[151, 274] -> 
             RGBColor[
              0.9700574519383955, 0.9641416300320623, 0.6797919998593982], 
             UndirectedEdge[316, 418] -> 
             RGBColor[
              0.7591602364053545, 0.8121407051702207, 0.9765342045926064], 
             UndirectedEdge[235, 389] -> 
             RGBColor[
              0.8429809223476927, 0.8495299885190393, 0.6628510277738867], 
             UndirectedEdge[218, 310] -> 
             RGBColor[
              0.9413917687813735, 0.7879281473287818, 0.48098210612319164`], 
             UndirectedEdge[408, 463] -> 
             RGBColor[
              0.9334438354378374, 0.8054026089221697, 0.5886615421227674], 
             UndirectedEdge[12, 273] -> 
             RGBColor[
              0.8297888056286364, 0.3850850849709173, 0.438147317833095], 
             UndirectedEdge[121, 454] -> 
             RGBColor[
              0.7032689048497267, 0.7666488848222797, 0.9723507199123337], 
             UndirectedEdge[47, 228] -> 
             RGBColor[
              0.833537641919247, 0.38807430526959985`, 0.4385048851851192], 
             UndirectedEdge[438, 439] -> 
             RGBColor[
              0.8266350064211102, 0.864781810765378, 0.9503917596067737], 
             UndirectedEdge[172, 201] -> 
             RGBColor[
              0.8958565273893938, 0.616403724008776, 0.23462692508656147`], 
             UndirectedEdge[58, 375] -> 
             RGBColor[
              0.6491900152257333, 0.23790724745627245`, 0.4231989103763255], 
             UndirectedEdge[168, 280] -> 
             RGBColor[
              0.9149637329203356, 0.919289864266385, 0.6894212035513515], 
             UndirectedEdge[77, 301] -> 
             RGBColor[
              0.9929527048808278, 0.9890867894906157, 0.6016694162410441], 
             UndirectedEdge[283, 477] -> 
             RGBColor[
              0.706377401573999, 0.7705466618674807, 0.9713687559829194], 
             UndirectedEdge[125, 149] -> 
             RGBColor[
              0.925429808426981, 0.8302670981615927, 0.6230151136029449], 
             UndirectedEdge[7, 407] -> 
             RGBColor[
              0.838681319037305, 0.731003494558278, 0.6080833755360942], 
             UndirectedEdge[401, 437] -> 
             RGBColor[
              0.6313529510395417, 0.7105584880100864, 0.9648335098535894], 
             UndirectedEdge[138, 438] -> 
             RGBColor[
              0.954051338611811, 0.9652521440874922, 0.962663277786709], 
             UndirectedEdge[45, 399] -> 
             RGBColor[
              0.9190939509667311, 0.7088522992107685, 0.2580075811615301], 
             UndirectedEdge[97, 317] -> 
             RGBColor[
              0.5718576708971608, 0.6608906820751483, 0.9606487932747104], 
             UndirectedEdge[71, 201] -> 
             RGBColor[
              0.9378959793448645, 0.7905539118767665, 0.273738450754895], 
             UndirectedEdge[107, 236] -> 
             RGBColor[
              0.9433773029974162, 0.9569956005791207, 0.9704738027909291], 
             UndirectedEdge[134, 225] -> 
             RGBColor[
              0.8895947890172871, 0.5537622482841469, 0.24497917265269648`], 
             UndirectedEdge[59, 91] -> 
             RGBColor[
              0.7638759130474309, 0.8123161662677565, 0.8628572795547487], 
             UndirectedEdge[161, 287] -> 
             RGBColor[
              0.8546835353686973, 0.3420351785349799, 0.1968326432850394], 
             UndirectedEdge[101, 486] -> 
             RGBColor[
              0.7676577877943824, 0.8184193653310294, 0.9774766121835989], 
             UndirectedEdge[185, 330] -> 
             RGBColor[
              0.9029389814951918, 0.9251634477561772, 0.9809103178420279], 
             UndirectedEdge[237, 432] -> 
             RGBColor[
              0.8762164633747824, 0.41928443131811444`, 0.3059969854434657], 
             UndirectedEdge[99, 143] -> 
             RGBColor[
              0.977146723551175, 0.9806940380119915, 0.843740060981278], 
             UndirectedEdge[107, 411] -> 
             RGBColor[
              0.8660872016283512, 0.5045000574633827, 0.45293271942567803`], 
             UndirectedEdge[187, 407] -> 
             RGBColor[
              0.8250464850812875, 0.5248088053263934, 0.45556765296748714`], 
             UndirectedEdge[185, 357] -> 
             RGBColor[
              0.9493402046300459, 0.9617385880776657, 0.9706379987573062], 
             UndirectedEdge[80, 208] -> 
             RGBColor[
              0.7361226124552089, 0.7882855152181385, 0.7577361332289393], 
             UndirectedEdge[60, 240] -> 
             RGBColor[
              0.7208296735801291, 0.7818368866000049, 0.9728092233923299], 
             UndirectedEdge[262, 299] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[82, 282] -> 
             RGBColor[
              0.7127308674769384, 0.7724130518525658, 0.9339035910825946], 
             UndirectedEdge[286, 368] -> 
             RGBColor[
              0.8013636979131096, 0.8453378545899037, 0.9806802838217401], 
             UndirectedEdge[81, 454] -> 
             RGBColor[
              0.949309017986139, 0.9579826915961261, 0.7736744920899804], 
             UndirectedEdge[68, 352] -> 
             RGBColor[
              0.6543191015992325, 0.7190349128441849, 0.8310033195138787], 
             UndirectedEdge[196, 337] -> 
             RGBColor[
              0.9939985737949799, 0.9895718811217564, 0.5881599779719864], 
             UndirectedEdge[261, 262] -> 
             RGBColor[
              0.8706569941346647, 0.4169565186358365, 0.41722984255724704`], 
             UndirectedEdge[122, 286] -> 
             RGBColor[
              0.8116704616805109, 0.8533895767793036, 0.9817075657118912]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {3}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.9037359105353183, 0.9260785000758135, 0.9906803319930718], 
             316 -> RGBColor[
              0.864485810612455, 0.8947815358129023, 0.9869366224234513], 308 -> 
             RGBColor[
              0.8144021177083163, 0.85493639112986, 0.9821356501388208], 160 -> 
             RGBColor[
              0.9948913654754712, 0.9914814722512418, 0.6853348427218806], 
             245 -> 
             RGBColor[
              0.8871878696252153, 0.5806282885581091, 0.22757913194797494`], 
             155 -> RGBColor[
              0.9086302706092886, 0.9299811299449323, 0.9911471604261739], 
             425 -> RGBColor[
              0.5475741830631058, 0.643584415603287, 0.9575261920025029], 213 -> 
             RGBColor[
              0.9849902672593264, 0.9880611040262643, 0.8984136456635161], 
             352 -> RGBColor[
              0.9952173363489952, 0.9921786909889989, 0.7208147606459318], 27 -> 
             RGBColor[
              0.9457322723909728, 0.8225535742180838, 0.27519311641973515`], 
             485 -> RGBColor[
              0.5493887515754312, 0.6450575640669727, 0.9576690414827765], 
             454 -> RGBColor[
              0.904909816663837, 0.9270145409578612, 0.9907923002075683], 367 -> 
             RGBColor[
              0.8283166269053037, 0.2186595795850035, 0.17474933994456193`], 
             19 -> RGBColor[
              0.5903779628947547, 0.6783344523589264, 0.9608958623462621], 
             164 -> RGBColor[
              0.3707902279938319, 0.4955815918546857, 0.9448474033442104], 
             190 -> RGBColor[
              0.938875277392473, 0.795367874007161, 0.26967581728958295`], 
             103 -> RGBColor[
              0.9646183636105852, 0.8923115738345241, 0.3170494531988555], 
             138 -> RGBColor[
              0.9358997979953182, 0.9517147548161318, 0.9933891013704309], 
             416 -> RGBColor[
              0.567758572020517, 0.6599710118552736, 0.9591151810390832], 476 -> 
             RGBColor[
              0.9828231061818977, 0.9867100812318174, 0.9139601801693592], 
             291 -> RGBColor[
              0.994785781315411, 0.9921118008216839, 0.7360766277764308], 28 -> 
             RGBColor[
              0.9858882606319944, 0.9884324473632395, 0.8835315715460542], 
             337 -> RGBColor[
              0.9945907770816859, 0.9908385440710834, 0.6526176510748809], 
             195 -> RGBColor[
              0.9756555698854077, 0.9813645443976586, 0.9260929495264557], 
             114 -> RGBColor[
              0.994785781315411, 0.9921118008216839, 0.7360766277764308], 479 -> 
             RGBColor[
              0.9390054242477961, 0.9540309257902335, 0.9881320862020375], 93 -> 
             RGBColor[
              0.9945141171263947, 0.9906745761782261, 0.6442736880318423], 34 -> 
             RGBColor[
              0.7307891740946888, 0.7896173240969864, 0.9738018933267972], 
             161 -> RGBColor[
              0.929412606106092, 0.7578515356049396, 0.2620619298551182], 22 -> 
             RGBColor[
              0.5305395287835829, 0.6297549158567403, 0.9561851616176241], 
             124 -> RGBColor[
              0.3350866690000343, 0.46465696356731107`, 0.9425724041365432], 
             84 -> RGBColor[
              0.8307176917338549, 0.8678557544302754, 0.9837157890996548], 46 -> 
             RGBColor[
              0.9621695929621741, 0.8840512954387426, 0.307536441641313], 241 -> 
             RGBColor[
              0.4284015194296424, 0.545481596868683, 0.9485183438908354], 185 -> 
             RGBColor[
              0.9465416750683502, 0.9596514493127246, 0.97537517933185], 426 -> 
             RGBColor[
              0.8269207339067611, 0.8648281633246254, 0.9833536318725223], 
             390 -> RGBColor[
              0.9828869780897801, 0.9539359001475126, 0.3880195707121612], 
             121 -> RGBColor[
              0.5016279930356163, 0.6062832286866982, 0.9539091396170991], 
             322 -> RGBColor[
              0.261695529432354, 0.39238897226127023`, 0.9382145453061062], 
             488 -> RGBColor[
              0.44515590012002204`, 0.5599933993230313, 0.9495859182131093], 
             126 -> RGBColor[
              0.9888760035337214, 0.9896679558345939, 0.834016939633665], 433 -> 
             RGBColor[
              0.8788272467853233, 0.5426646529152341, 0.2206028233127501], 
             236 -> RGBColor[
              0.9625289218398253, 0.9715747117781767, 0.9483129406895036], 78 -> 
             RGBColor[
              0.8819885252183052, 0.5570192799440686, 0.2232406715272555], 
             376 -> RGBColor[
              0.6709766525313169, 0.7428913276596797, 0.9678403401571537], 
             458 -> RGBColor[
              0.6707955628758102, 0.7427498590444654, 0.9678222908326718], 
             254 -> RGBColor[
              0.9781263500772029, 0.937877184012476, 0.3695254298524637], 290 -> 
             RGBColor[
              0.41249261029268103`, 0.5317020993792699, 0.9475046422683243], 
             251 -> RGBColor[
              0.8943282723192684, 0.6130511895083848, 0.23353725898317895`], 
             165 -> RGBColor[
              0.7077948724672457, 0.7716540009024628, 0.9715100362345397], 
             460 -> RGBColor[
              0.8576721025797294, 0.4442986292701026, 0.2028601766026596], 
             100 -> RGBColor[
              0.9644839508512351, 0.8918581680356193, 0.3165272850104999], 
             235 -> RGBColor[
              0.71188751311776, 0.7748512028838656, 0.9719179524066816], 70 -> 
             RGBColor[
              0.9357475699643143, 0.9516012233998596, 0.9936467837194913], 
             234 -> RGBColor[0.817319, 0.134127, 0.164218], 435 -> 
             RGBColor[
              0.9588345730899652, 0.968819472529472, 0.9545665094825462], 257 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 135 -> 
             RGBColor[
              0.9944268117818262, 0.9904878388741185, 0.6347710400617005], 
             265 -> RGBColor[
              0.5583918595444682, 0.652366692701629, 0.9583777991215703], 111 -> 
             RGBColor[
              0.8655035117475163, 0.8955930230732388, 0.987033691666226], 497 -> 
             RGBColor[
              0.9927510758850713, 0.991270397836694, 0.7697969624060179], 481 -> 
             RGBColor[
              0.6480356598076664, 0.7249696497859616, 0.9655537963982261], 
             381 -> RGBColor[
              0.9731622258119019, 0.9211320272338096, 0.35024074447797715`], 
             182 -> RGBColor[
              0.8334466002353424, 0.8700317119951135, 0.9839760748286521], 
             188 -> RGBColor[
              0.9727988472648216, 0.9199062660691676, 0.3488290874408509], 
             154 -> RGBColor[
              0.530599855664788, 0.6298038919365976, 0.9561899107706973], 336 -> 
             RGBColor[
              0.8986772233312333, 0.9220448402136823, 0.9901978298916029], 
             463 -> RGBColor[
              0.9676321888817012, 0.9753807199821749, 0.9396744407328207], 
             315 -> RGBColor[
              0.995220389179555, 0.9922915223424201, 0.7288740507384653], 368 -> 
             RGBColor[
              0.7100967120988425, 0.7734522155172954, 0.9717394620971029], 
             269 -> RGBColor[
              0.90856365513361, 0.9299280125728552, 0.9911408065826354], 208 -> 
             RGBColor[
              0.9937709623176162, 0.9890850431867255, 0.563385873316147], 86 -> 
             RGBColor[
              0.9952173363489952, 0.9921786909889989, 0.7208147606459318], 
             119 -> RGBColor[
              0.4667030597785676, 0.5779295945183125, 0.9511597209368584], 
             436 -> RGBColor[
              0.9943874453740005, 0.9904036381083334, 0.6304862495111653], 
             377 -> RGBColor[0.817319, 0.134127, 0.164218], 140 -> 
             RGBColor[
              0.9272672475007648, 0.7493459036331933, 0.26033572396323335`], 
             85 -> RGBColor[
              0.8108973104359728, 0.8521984090511834, 0.9817863237041996], 
             351 -> RGBColor[
              0.8721543210738953, 0.9008961978986837, 0.9876680517970235], 
             443 -> 
             RGBColor[
              0.9859800497882808, 0.9884704045382378, 0.882010387683666], 242 -> 
             RGBColor[
              0.5479998872483798, 0.6439300214386474, 0.9575597049953735], 
             117 -> RGBColor[
              0.6299644998442744, 0.710472586407713, 0.9640122595451912], 47 -> 
             RGBColor[
              0.8659749257577408, 0.8959689158087994, 0.9870786555553575], 
             451 -> RGBColor[
              0.864485810612455, 0.8947815358129023, 0.9869366224234513], 81 -> 
             RGBColor[
              0.9937082193084409, 0.9889508422343911, 0.5565566839723926], 
             275 -> RGBColor[
              0.9874100836085136, 0.9890617602730968, 0.8583110264735151], 23 -> 
             RGBColor[
              0.9944399569901122, 0.9905159551454576, 0.6362018148608012], 
             328 -> RGBColor[
              0.8282480465095615, 0.21813244061120735`, 0.17468366728014864`],
              418 -> RGBColor[
              0.6538346621982539, 0.7294998745275391, 0.9661317867617615], 
             110 -> RGBColor[
              0.9626236995211117, 0.9716453968176959, 0.948152506797064], 6 -> 
             RGBColor[
              0.7087260045219952, 0.7723814083404988, 0.9716028427758333], 
             218 -> RGBColor[
              0.9949217803409345, 0.9921680399137535, 0.7338227719693111], 
             108 -> RGBColor[
              0.8723649397852354, 0.5133208261379815, 0.21521051594623714`], 
             297 -> RGBColor[
              0.9428731468145535, 0.8112180940546999, 0.2728925968686453], 
             487 -> RGBColor[
              0.47300311378761184`, 0.5830442621770534, 0.9516556842663085], 
             464 -> RGBColor[
              0.5482944292820389, 0.6441691439305393, 0.957582892423206], 157 -> 
             RGBColor[
              0.984877239513646, 0.9880143641487449, 0.9002868079158691], 441 -> 
             RGBColor[
              0.993929856902494, 0.9917578540806887, 0.7502615103598393], 354 -> 
             RGBColor[
              0.9494128962936107, 0.9617928014013306, 0.9705149507319133], 
             385 -> RGBColor[
              0.9364871355820745, 0.9521527902266577, 0.9923948920382287], 
             270 -> RGBColor[
              0.5391835943557824, 0.6367725576989682, 0.9568656541237232], 
             392 -> RGBColor[
              0.8396067790431282, 0.8749436713628427, 0.9845636381825952], 33 -> 
             RGBColor[
              0.9937669915741006, 0.9890765501678498, 0.5629536823890772], 
             252 -> RGBColor[
              0.9942531557555676, 0.9901164061932687, 0.6158696532842083], 
             394 -> RGBColor[
              0.9873799357573437, 0.9890492933618736, 0.8588106543875368], 
             260 -> RGBColor[
              0.9845285399878514, 0.9594732738867701, 0.3943967287032151], 
             159 -> RGBColor[
              0.9901914691504344, 0.9902119346730291, 0.8122162700488411], 
             183 -> RGBColor[
              0.29858575037567603`, 0.43116293344780227`, 0.940315388814637], 
             99 -> RGBColor[
              0.9593716667614157, 0.9692200361102296, 0.9536573499932449], 
             329 -> RGBColor[0.817319, 0.134127, 0.164218], 309 -> 
             RGBColor[
              0.9593716667614157, 0.9692200361102296, 0.9536573499932449], 17 -> 
             RGBColor[
              0.9917277650674593, 0.9837579505387221, 0.4223643586779124], 
             349 -> RGBColor[
              0.9499572029113945, 0.8393040158569198, 0.27859259468833175`], 
             495 -> RGBColor[
              0.5598315199857369, 0.6535354739038146, 0.958491134465157], 347 -> 
             RGBColor[
              0.8144021177083163, 0.85493639112986, 0.9821356501388208], 340 -> 
             RGBColor[
              0.40568483001390493`, 0.5258055422707799, 0.9470708565288444], 
             404 -> RGBColor[0.817319, 0.134127, 0.164218], 277 -> 
             RGBColor[
              0.9941933465467119, 0.9918668138199478, 0.7458948050658091], 
             104 -> RGBColor[
              0.9887364448662763, 0.9736675251047477, 0.41074364455973683`], 
             79 -> RGBColor[
              0.8420234704363077, 0.324016385341434, 0.1878750287895169], 327 -> 
             RGBColor[
              0.9882207688266499, 0.989396999444456, 0.8448758744229037], 191 -> 
             RGBColor[
              0.9107964280332989, 0.6840445930199114, 0.24708291599988724`], 
             50 -> RGBColor[
              0.7412136530399933, 0.7977610062780327, 0.9748409079657708], 
             225 -> RGBColor[
              0.9724319368963994, 0.918668591241828, 0.3474037099447397], 405 -> 
             RGBColor[
              0.8797958829756201, 0.5470630036246418, 0.22141107709337945`], 
             61 -> RGBColor[
              0.5541979693222818, 0.6489619036866565, 0.9580476407205537], 
             196 -> RGBColor[
              0.9934063705082741, 0.9883052181724293, 0.5237023048690918], 1 -> 
             RGBColor[
              0.9914189776076017, 0.9907195409655962, 0.7918732782235238], 
             263 -> 
             RGBColor[
              0.9695585044588393, 0.9768173629855522, 0.9364136909242924], 
             201 -> RGBColor[
              0.9166794105808327, 0.7073686584331623, 0.25181650184898147`], 
             371 -> RGBColor[
              0.5903779628947547, 0.6783344523589264, 0.9608958623462621], 
             293 -> RGBColor[
              0.7859170078870592, 0.832683606842641, 0.9792965206003237], 362 -> 
             RGBColor[
              0.8396067790431282, 0.8749436713628427, 0.9845636381825952], 
             184 -> RGBColor[
              0.9659721476612205, 0.9741426639580084, 0.9424844575110026], 
             106 -> RGBColor[
              0.5203995701555523, 0.6215228406425745, 0.9553869069305332], 
             206 -> RGBColor[
              0.7831685383045918, 0.8305364815156749, 0.979022578838252], 358 -> 
             RGBColor[
              0.8995330168452805, 0.6366847188020381, 0.23788022539564627`], 
             247 -> RGBColor[
              0.4284015194296424, 0.545481596868683, 0.9485183438908354], 220 -> 
             RGBColor[
              0.49955414134803394`, 0.604599582460765, 0.9537458784154836], 
             407 -> RGBColor[
              0.7781071560806364, 0.8265824912543913, 0.9785181075594741], 
             107 -> RGBColor[
              0.9242256841550072, 0.9424164893800648, 0.9926346648923546], 
             375 -> RGBColor[0.817319, 0.134127, 0.164218], 131 -> 
             RGBColor[
              0.9227612143077097, 0.9412487608758049, 0.9924949824509717], 
             411 -> RGBColor[
              0.8370179603650232, 0.28554184150504147`, 0.18308174669233973`],
              462 -> RGBColor[
              0.3882157733691387, 0.5106747234253999, 0.9459577436867201], 
             127 -> RGBColor[
              0.4139435077518233, 0.5329587938341523, 0.9475970921714426], 
             210 -> RGBColor[
              0.7297718340424981, 0.7888225703161442, 0.9737004943779782], 
             357 -> RGBColor[
              0.9521387341917417, 0.9638257268426068, 0.9659008181827622], 
             181 -> RGBColor[0.817319, 0.134127, 0.164218], 194 -> 
             RGBColor[
              0.9887039178815463, 0.98959679399502, 0.8368688442335974], 440 -> 
             RGBColor[
              0.6525295233330468, 0.7284802901266164, 0.9660017027168938], 
             490 -> RGBColor[
              0.8183522533298697, 0.8580222670995601, 0.9825293627414611], 
             118 -> RGBColor[
              0.951002425009259, 0.9629782693148468, 0.9678242932318057], 348 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 276 -> 
             RGBColor[
              0.3731276649241932, 0.4976061622407686, 0.9449963427584986], 
             305 -> RGBColor[
              0.8426196074977271, 0.32859855602443, 0.18844589031277267`], 
             343 -> RGBColor[
              0.6796316638797563, 0.749652688305603, 0.9687029908026865], 280 -> 
             RGBColor[
              0.8455758442464051, 0.8797032419299772, 0.9851329729503312], 
             474 -> RGBColor[
              0.6392860755647328, 0.7180402615097818, 0.9647460881319626], 
             189 -> RGBColor[
              0.7216790155653959, 0.7825003990141335, 0.9728938778638692], 
             168 -> RGBColor[
              0.9843516215942661, 0.9588764866027929, 0.3937094341523718], 
             363 -> RGBColor[
              0.5778955075676374, 0.6682006327961684, 0.959913197738171], 41 -> 
             RGBColor[
              0.6210471944247042, 0.7032331161480748, 0.9633102565973966], 14 -> 
             RGBColor[
              0.9947758815342954, 0.9921077070077798, 0.736240692769328], 77 -> 
             RGBColor[
              0.9932512321206558, 0.9914772252935372, 0.7615080792195372], 51 -> 
             RGBColor[
              0.7134584744296456, 0.7760784498004587, 0.9720745311487822], 
             438 -> RGBColor[
              0.9722028792283037, 0.9787895333588525, 0.931937454202987], 179 -> 
             RGBColor[
              0.42882929432607886`, 0.5458521139833848, 0.9485456013289699], 
             467 -> RGBColor[
              0.9405067240340349, 0.8018360162935888, 0.27098851755235825`], 
             223 -> RGBColor[
              0.9521516823050813, 0.963835383524335, 0.965878900404287], 456 -> 
             RGBColor[
              0.9441387352843182, 0.9578593407562463, 0.9794427295991472], 
             323 -> RGBColor[
              0.6274352320576256, 0.7084192128762963, 0.963813146320013], 500 -> 
             RGBColor[
              0.7252391219909153, 0.7852815812115603, 0.9732487160012789], 
             478 -> RGBColor[
              0.8778433572328694, 0.5381970402507847, 0.21978184175284285`], 
             292 -> RGBColor[
              0.7447447824611768, 0.8005195514194388, 0.9751928579461938], 
             491 -> RGBColor[
              0.8978051995590259, 0.6288391040471358, 0.23643849229931818`], 
             396 -> RGBColor[
              0.9501714082055378, 0.9623584983432966, 0.969230987916611], 321 -> 
             RGBColor[
              0.9547859169873797, 0.858448258094622, 0.28247789137835627`], 
             143 -> 
             RGBColor[
              0.9949217803409345, 0.9921680399137535, 0.7338227719693111], 
             112 -> RGBColor[
              0.7982109327297675, 0.8422877143670542, 0.9805218641353852], 
             197 -> RGBColor[
              0.7074407227712793, 0.7713773364683364, 0.9714747379025629], 
             421 -> RGBColor[
              0.4915046527803846, 0.5980646450162197, 0.95311219318919], 54 -> 
             RGBColor[
              0.9603641227038606, 0.877961020312875, 0.3005225306222146], 71 -> 
             RGBColor[
              0.9591125481088963, 0.8737391653203707, 0.2956603996608085], 
             177 -> RGBColor[
              0.7625621472872217, 0.8144386122385332, 0.976968726359313], 158 -> 
             RGBColor[
              0.9469799106875489, 0.9599782847199781, 0.9746333607387014], 
             226 -> RGBColor[
              0.9279287322849625, 0.9453691994423274, 0.9929878649287398], 
             432 -> RGBColor[
              0.9940113901243472, 0.9895992939543433, 0.5895549563303971], 
             350 -> RGBColor[
              0.9884628488201066, 0.9894971057429224, 0.8408639824483857], 
             203 -> RGBColor[
              0.9771351691162565, 0.9345336978908471, 0.3656748789880058], 
             475 -> RGBColor[
              0.9164925324244385, 0.9362502841009211, 0.9918970699768269], 
             115 -> RGBColor[
              0.6234010903665643, 0.7051441149154807, 0.9634955639085447], 
             173 -> RGBColor[
              0.4507974140603326, 0.5648797951473931, 0.949945390492791], 212 -> 
             RGBColor[
              0.7506786430960607, 0.8051551284464212, 0.9757842897191986], 
             129 -> RGBColor[
              0.43296808969994416`, 0.549436930514323, 0.9488093217103996], 
             279 -> RGBColor[
              0.4157029888946587, 0.5344827679659827, 0.947709204754016], 26 -> 
             RGBColor[
              0.9928401973176479, 0.9913072518393808, 0.76831998962935], 40 -> 
             RGBColor[
              0.8117979745726563, 0.8529020147200616, 0.9818760934881594], 
             146 -> RGBColor[
              0.9252139595616671, 0.9432045133633141, 0.9927289274828857], 
             386 -> RGBColor[
              0.9935832961684177, 0.9886836442695484, 0.5429595711171192], 
             192 -> RGBColor[
              0.9568045061688181, 0.865953597902468, 0.2866940925607525], 300 -> 
             RGBColor[
              0.6312425932874741, 0.7115102002423561, 0.9641128757428504], 
             221 -> RGBColor[
              0.9633501228742496, 0.8880335000337782, 0.3121225774253586], 62 -> 
             RGBColor[
              0.9040762370292161, 0.926349867184131, 0.9907127926378728], 286 -> 
             RGBColor[
              0.8926306837273766, 0.9172234936625121, 0.9896211055463774], 
             472 -> RGBColor[
              0.8885696909952737, 0.586902816666964, 0.22873215757069293`], 
             152 -> RGBColor[0.817319, 0.134127, 0.164218], 64 -> 
             RGBColor[
              0.9464370969093286, 0.9595734550929573, 0.9755522028767213], 
             307 -> RGBColor[
              0.9487897406637753, 0.9613280529529231, 0.9715697906682065], 37 -> 
             RGBColor[
              0.9811427711763504, 0.9480522806692554, 0.38124365621932416`], 
             148 -> RGBColor[
              0.8780394081228452, 0.9055888065650839, 0.9882293766534316], 
             261 -> RGBColor[
              0.977332982403994, 0.9826155559075094, 0.9232535276717411], 387 -> 
             RGBColor[
              0.4954512772940255, 0.6012686925898016, 0.9534228859278658], 15 -> 
             RGBColor[
              0.9566455786240297, 0.9671869240409267, 0.9582719061321819], 
             136 -> RGBColor[0.817319, 0.134127, 0.164218], 198 -> 
             RGBColor[
              0.9952553586821756, 0.9922600169150241, 0.7249532569659711], 63 -> 
             RGBColor[
              0.6080768740758788, 0.6927032257826253, 0.962289185467688], 444 -> 
             RGBColor[
              0.9444078772217567, 0.9580600663725085, 0.9789871425025236], 
             310 -> RGBColor[
              0.8878617572218125, 0.58368825474381, 0.22814144027707217`], 
             171 -> RGBColor[
              0.9940228719281586, 0.9896238523717074, 0.5908046798177842], 
             395 -> RGBColor[
              0.19888968485836142`, 0.32637604749346166`, 0.934637845370538], 
             311 -> RGBColor[
              0.9691721844156284, 0.9765292461298665, 0.9370676299890444], 
             353 -> RGBColor[
              0.9507947265176238, 0.9628233681198602, 0.9681758726017019], 59 -> 
             RGBColor[
              0.9927882362375053, 0.991285764597403, 0.7691811191982763], 397 -> 
             RGBColor[
              0.9882671046638604, 0.9720843303956787, 0.40892034650081105`], 
             229 -> RGBColor[
              0.8694854757461257, 0.8987681330781966, 0.9874134949471546], 
             102 -> RGBColor[
              0.6773557520068964, 0.747874728652954, 0.9684761491768056], 453 -> 
             RGBColor[
              0.9898759381600537, 0.9900814544997301, 0.8174454351274779], 
             299 -> RGBColor[0.817319, 0.134127, 0.164218], 128 -> 
             RGBColor[
              0.8795847356118854, 0.5461042327606428, 0.22123489055738382`], 
             12 -> RGBColor[
              0.8547284168859094, 0.887001254912752, 0.9860059534992851], 222 -> 
             RGBColor[
              0.9566203836722591, 0.8653325094875566, 0.28597881143023696`], 
             483 -> RGBColor[
              0.6178489319195384, 0.7006366225662972, 0.9630584776573683], 92 -> 
             RGBColor[
              0.9761892496182779, 0.9817625618686128, 0.9251895689446732], 
             271 -> RGBColor[
              0.9665458233909934, 0.8988133482629188, 0.32453727047550335`], 
             361 -> RGBColor[
              0.9195371413600953, 0.938677972622506, 0.9921874674950644], 344 -> 
             RGBColor[
              0.7481805013234707, 0.8032035611070932, 0.9755352982937691], 
             132 -> RGBColor[
              0.7740375902538377, 0.8234033155006504, 0.9781124912701137], 80 -> 
             RGBColor[
              0.47847426259280185`, 0.5874859872495516, 0.9520863931417316], 
             324 -> RGBColor[
              0.9296469846083008, 0.7587807682641917, 0.26225051629956597`], 
             244 -> RGBColor[
              0.881222466876741, 0.5535407879324971, 0.22260145366924608`], 
             150 -> RGBColor[
              0.9182576770960664, 0.7136259592399249, 0.253086412133815], 125 -> 
             RGBColor[
              0.9175671029951101, 0.7108880630498108, 0.25253076000232805`], 
             258 -> RGBColor[
              0.6718893720517873, 0.7436043510859964, 0.9679313115091054], 
             133 -> RGBColor[
              0.840268153459609, 0.31052424987372407`, 0.18619413527028325`], 
             469 -> RGBColor[
              0.9641466914080326, 0.9727812416732912, 0.9455744787924079], 
             255 -> RGBColor[0.817319, 0.134127, 0.164218], 408 -> 
             RGBColor[
              0.8992554819939736, 0.6354244978621647, 0.23764864351271403`], 
             326 -> RGBColor[
              0.833159981292454, 0.8698031698301184, 0.9839487368580117], 176 -> 
             RGBColor[
              0.9897870633443997, 0.9900447024794786, 0.8189183208235141], 
             230 -> RGBColor[
              0.9053357305370828, 0.662394747116984, 0.24268911061538745`], 
             274 -> RGBColor[
              0.9854469343234846, 0.9625712336301057, 0.3979645172729326], 87 -> 
             RGBColor[
              0.9895157262147583, 0.9899324976033257, 0.823415079259655], 439 -> 
             RGBColor[
              0.6810671336139167, 0.7507740881719033, 0.9688460650105604], 
             130 -> RGBColor[
              0.992966434019326, 0.9873642385069717, 0.4758179330204009], 35 -> 
             RGBColor[
              0.4954512772940255, 0.6012686925898016, 0.9534228859278658], 
             379 -> RGBColor[
              0.9163519631987888, 0.936138198016038, 0.9918836623585968], 31 -> 
             RGBColor[
              0.334399525437276, 0.46406179435008954`, 0.9425286199563414], 
             18 -> RGBColor[
              0.9197038909536297, 0.7193597152629638, 0.25425006975061265`], 
             24 -> RGBColor[
              0.9948514260688883, 0.9921389466142401, 0.7349887243281352], 
             151 -> RGBColor[
              0.9546679695533065, 0.965712026434019, 0.9616194824458639], 137 -> 
             RGBColor[
              0.9835919425253744, 0.9563139107222933, 0.39075822442308206`], 
             330 -> RGBColor[
              0.8593362879220334, 0.8906754461996299, 0.9864454563522057], 
             296 -> RGBColor[
              0.9641466914080326, 0.9727812416732912, 0.9455744787924079], 
             266 -> RGBColor[
              0.5248256446362427, 0.6251161272983821, 0.9557353437268982], 
             302 -> RGBColor[
              0.8339662626696227, 0.26208515575573654`, 0.18015943753282468`],
              442 -> RGBColor[0.817319, 0.134127, 0.164218], 283 -> 
             RGBColor[
              0.6798635002997572, 0.7498338006789298, 0.9687260980903977], 
             388 -> RGBColor[
              0.2709639692526886, 0.40213069016546776`, 0.9387423692424463], 
             284 -> RGBColor[
              0.29833153557609476`, 0.4308957375752931, 0.940300911657878], 
             417 -> RGBColor[
              0.9903560014632881, 0.9902799730126817, 0.8094895438288808], 
             318 -> RGBColor[
              0.6648527121076335, 0.7381072588570271, 0.967229963007198], 413 -> 
             RGBColor[
              0.6154541693308618, 0.6986924464139844, 0.9628699531740833], 
             238 -> RGBColor[
              0.9813361784627297, 0.9856011329734824, 0.9164771609450512], 72 -> 
             RGBColor[
              0.962630872531872, 0.9716507464373761, 0.9481403647608677], 437 -> 
             RGBColor[
              0.5523709018588021, 0.6474786080113525, 0.9579038072770599], 
             288 -> RGBColor[
              0.5779701337926271, 0.668261217727488, 0.959919072587967], 382 -> 
             RGBColor[
              0.9032764800705589, 0.925712162694122, 0.9906365111052047], 461 -> 
             RGBColor[
              0.5531981181289305, 0.648150179445111, 0.9579689287720375], 389 -> 
             RGBColor[
              0.9740743315776254, 0.9242087741542131, 0.3537841031410918], 
             172 -> RGBColor[
              0.8750336441979549, 0.5254387895843896, 0.21743734832414144`], 
             447 -> RGBColor[
              0.4507974140603326, 0.5648797951473931, 0.949945390492791], 243 -> 
             RGBColor[
              0.9820607089319499, 0.9861414866111171, 0.9152507198484721], 
             410 -> RGBColor[
              0.9357025242431577, 0.9515676283747766, 0.9937230343756037], 88 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 273 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 477 -> 
             RGBColor[
              0.7328913028482409, 0.7912595230560315, 0.9740114138754412], 
             202 -> RGBColor[
              0.9931266298570909, 0.9877068812056669, 0.49325426134698247`], 
             393 -> RGBColor[
              0.9749633423111079, 0.9272076161078964, 0.3572377419650813], 98 -> 
             RGBColor[
              0.8952500936796065, 0.6172369650088319, 0.23430644932215433`], 
             30 -> RGBColor[
              0.5347828024878565, 0.6331997966071715, 0.9565192076672483], 
             116 -> RGBColor[
              0.7289029261599352, 0.7881437728743417, 0.9736138897606502], 
             373 -> RGBColor[
              0.8719555286644952, 0.5114617858590967, 0.2148688932715066], 
             434 -> RGBColor[
              0.8022165240598393, 0.8454169127577279, 0.9809211040447876], 
             401 -> RGBColor[
              0.7103350002202813, 0.7736383680088201, 0.9717632124301189], 
             240 -> RGBColor[
              0.71188751311776, 0.7748512028838656, 0.9719179524066816], 480 -> 
             RGBColor[
              0.9795970341444822, 0.9428381467044494, 0.37523875973846155`], 
             403 -> RGBColor[
              0.5479998872483798, 0.6439300214386474, 0.9575597049953735], 
             317 -> RGBColor[
              0.7297718340424981, 0.7888225703161442, 0.9737004943779782], 
             429 -> RGBColor[
              0.9564475225888094, 0.9670392141741464, 0.9586071633385228], 
             391 -> RGBColor[
              0.9950870481598906, 0.9919000177266605, 0.7066336953073814], 73 -> 
             RGBColor[
              0.9947244634729093, 0.9911244857441428, 0.6671685897427809], 
             303 -> RGBColor[0.817319, 0.134127, 0.164218], 449 -> 
             RGBColor[
              0.9894932787535233, 0.9899232150012316, 0.8237870917844852], 29 -> 
             RGBColor[
              0.9185920028930845, 0.9379243448640118, 0.9920973193443458], 
             360 -> RGBColor[
              0.3821131715511962, 0.5053889564563839, 0.9455688912951997], 
             320 -> RGBColor[
              0.6796316638797563, 0.749652688305603, 0.9687029908026865], 482 -> 
             RGBColor[
              0.9575014885191092, 0.9678252602392532, 0.956823073936865], 75 -> 
             RGBColor[
              0.9235058870535456, 0.7344333628590358, 0.2573092450569236], 
             200 -> RGBColor[
              0.9938782498276173, 0.9917365132289858, 0.7511167731453752], 
             301 -> RGBColor[
              0.9926541776409996, 0.986696353687694, 0.441830753262551], 156 -> 
             RGBColor[
              0.9945254816122576, 0.990698883664361, 0.6455106421845405], 25 -> 
             RGBColor[
              0.9252954217321314, 0.9432694690868108, 0.9927366974174268], 38 -> 
             RGBColor[
              0.2709639692526886, 0.40213069016546776`, 0.9387423692424463], 
             365 -> RGBColor[
              0.8423351313749579, 0.3264119478865936, 0.188173475656339], 380 -> 
             RGBColor[
              0.5905108500273831, 0.6784423361196912, 0.9609063237081242], 
             370 -> RGBColor[
              0.6718893720517873, 0.7436043510859964, 0.9679313115091054], 3 -> 
             RGBColor[
              0.9288098264358793, 0.755461715076964, 0.26157691918340775`], 
             57 -> RGBColor[
              0.4910100769958693, 0.597663126113965, 0.9530732583717423], 227 -> 
             RGBColor[
              0.8821414170467385, 0.5577135260281905, 0.22336824821662188`], 
             494 -> RGBColor[
              0.8401168799663169, 0.8753504119926727, 0.9846122920640215], 39 -> 
             RGBColor[
              0.9831498274809092, 0.986953749441663, 0.9134071262326952], 424 -> 
             RGBColor[
              0.8963326736400791, 0.6221527077663642, 0.23520978057763575`], 
             109 -> RGBColor[
              0.8226910832400139, 0.17541918584463317`, 0.16936231297753757`],
              465 -> RGBColor[
              0.9279891017714167, 0.94541733643214, 0.9929936230242503], 256 -> 
             RGBColor[
              0.47645263718730263`, 0.5858447406721807, 0.9519272433843528], 
             457 -> RGBColor[
              0.9706475203468744, 0.9126493352193497, 0.34047158860862503`], 
             339 -> 
             RGBColor[
              0.9860771207353004, 0.9885105458694399, 0.8804016708799934], 
             420 -> RGBColor[
              0.9104620291361905, 0.9314417244725232, 0.9913218751896999], 
             287 -> RGBColor[0.817319, 0.134127, 0.164218], 239 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 427 -> 
             RGBColor[
              0.9948415508658955, 0.991374923838389, 0.6799128298897035], 285 -> 
             RGBColor[
              0.9932337373746605, 0.9879359733555171, 0.5049122536434604], 
             345 -> RGBColor[
              0.8518394003746422, 0.8846976315669316, 0.985730396525385], 366 -> 
             RGBColor[
              0.8780394081228452, 0.9055888065650839, 0.9882293766534316], 
             216 -> RGBColor[
              0.9875766961009964, 0.9891306588204842, 0.8555498262937655], 21 -> 
             RGBColor[
              0.7076369116210648, 0.7715306006888794, 0.9714942921736204], 
             355 -> RGBColor[
              0.7297718340424981, 0.7888225703161442, 0.9737004943779782], 
             175 -> RGBColor[
              0.6299644998442744, 0.710472586407713, 0.9640122595451912], 7 -> 
             RGBColor[
              0.8992554819939736, 0.6354244978621647, 0.23764864351271403`], 
             13 -> RGBColor[0.817319, 0.134127, 0.164218], 294 -> 
             RGBColor[
              0.9943921004440595, 0.9919490036642432, 0.7426009386281616], 
             412 -> RGBColor[
              0.647074647454661, 0.7242188996318293, 0.9654580116680496], 193 -> 
             RGBColor[
              0.8324572337021733, 0.8692428179772036, 0.9838817081655005], 60 -> 
             RGBColor[
              0.7297718340424981, 0.7888225703161442, 0.9737004943779782], 65 -> 
             RGBColor[
              0.8809091183684686, 0.5521179455408358, 0.22233998799306884`], 
             448 -> RGBColor[
              0.9931794684649093, 0.9878198976449879, 0.49900541772594187`], 
             69 -> RGBColor[
              0.8800043220623688, 0.5480094768353825, 0.22158500377667217`], 
             217 -> RGBColor[
              0.7765414973628456, 0.8253593867646062, 0.9783620573303973], 
             214 -> RGBColor[0.178927, 0.305394, 0.933501], 170 -> 
             RGBColor[
              0.9850762021740773, 0.9613206670381067, 0.39652429287937724`], 
             359 -> RGBColor[
              0.864485810612455, 0.8947815358129023, 0.9869366224234513], 74 -> 
             RGBColor[
              0.9395985099296158, 0.954473248120646, 0.9871281468442363], 246 -> 
             RGBColor[
              0.9161597094148285, 0.705308216490103, 0.25139833809186024`], 
             264 -> RGBColor[
              0.6543192374469097, 0.7298784283946972, 0.9661800846939343], 
             278 -> RGBColor[
              0.7033258604351998, 0.7681627747372791, 0.9710646068804772], 45 -> 
             RGBColor[
              0.9589633580889476, 0.873235912351601, 0.29508082460547885`], 
             492 -> RGBColor[
              0.8867820378781774, 0.912559942219623, 0.989063256484133], 306 -> 
             RGBColor[
              0.9891826796075204, 0.9897947742723254, 0.8289345234385777], 
             237 -> RGBColor[0.817319, 0.134127, 0.164218], 228 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 180 -> 
             RGBColor[
              0.772248344779638, 0.8220055433374364, 0.9779341560026951], 383 -> 
             RGBColor[
              0.8745906354121629, 0.5234271901554384, 0.2170676909341375], 53 -> 
             RGBColor[
              0.9623451725399679, 0.971437671851205, 0.9486239803246693], 304 -> 
             RGBColor[
              0.9795970341444822, 0.9428381467044494, 0.37523875973846155`], 
             48 -> RGBColor[
              0.6058066444645905, 0.690860151111503, 0.9621104646765624], 5 -> 
             RGBColor[
              0.6242558449665865, 0.7058380432060345, 0.9635628533217278], 
             101 -> RGBColor[
              0.8140653103584886, 0.8546732746683439, 0.9821020803298336], 
             333 -> RGBColor[
              0.9162150046220459, 0.9360289909645848, 0.9918705991272827], 
             267 -> RGBColor[0.817319, 0.134127, 0.164218], 120 -> 
             RGBColor[
              0.9933760991635824, 0.9882404708270363, 0.5204074558124888], 
             147 -> RGBColor[
              0.893529365402922, 0.9179400780365278, 0.9897068226068535], 89 -> 
             RGBColor[
              0.5618555705498138, 0.6551786893341711, 0.9586504751399025], 43 -> 
             RGBColor[
              0.9654959126757771, 0.9737874886856279, 0.9432905991193813], 
             199 -> RGBColor[
              0.9952187978944984, 0.992290864305155, 0.7289004224499682], 268 -> 
             RGBColor[
              0.9944780871721284, 0.9919845613860577, 0.7411759160175412], 
             169 -> RGBColor[
              0.960493287417189, 0.8783967232202486, 0.30102431114278594`], 
             20 -> RGBColor[
              0.6843767081676095, 0.7533595529669463, 0.9691759324723398], 4 -> 
             RGBColor[
              0.8662447525395159, 0.4855304852612168, 0.21010368168889168`], 
             167 -> 
             RGBColor[
              0.9162150046220459, 0.9360289909645848, 0.9918705991272827], 
             431 -> RGBColor[
              0.9210036436029722, 0.7245128014007121, 0.25529588124138947`], 
             142 -> RGBColor[
              0.9665946095831851, 0.9746068950402218, 0.9414307918411866], 16 -> 
             RGBColor[
              0.904909816663837, 0.9270145409578612, 0.9907923002075683], 414 -> 
             RGBColor[
              0.9858882606319944, 0.9884324473632395, 0.8835315715460542], 
             281 -> RGBColor[
              0.9403019317545571, 0.9549978589659397, 0.9859374371764053], 
             289 -> RGBColor[
              0.9878626283445765, 0.9892488991513281, 0.8508111890487187], 
             398 -> RGBColor[
              0.9785920436795745, 0.9835545617453136, 0.9211222653479563], 
             178 -> RGBColor[
              0.8389239349601617, 0.30019199744667, 0.1849069101171349], 58 -> 
             RGBColor[
              0.3129320456772, 0.44546774236881737`, 0.9411607311289764], 186 -> 
             RGBColor[
              0.778216012898588, 0.8266675310279177, 0.9785289573897628], 122 -> 
             RGBColor[
              0.7307102396336452, 0.7895556598960951, 0.9737940258774049], 
             249 -> RGBColor[
              0.9263621855885937, 0.9441200776294203, 0.9928384463063674], 
             113 -> RGBColor[
              0.9871279350398854, 0.9889450845890816, 0.862986958432773], 52 -> 
             RGBColor[
              0.9447765639369228, 0.8187645086687385, 0.27442413096424584`], 
             409 -> RGBColor[
              0.4954512772940255, 0.6012686925898016, 0.9534228859278658], 
             187 -> RGBColor[
              0.8485161495816131, 0.3739219623623945, 0.19409242567149362`], 
             259 -> RGBColor[
              0.9642934512573637, 0.9728906949286251, 0.9453260526485894], 42 -> 
             RGBColor[
              0.7285333888504795, 0.7878550875196072, 0.9735770577351661], 
             134 -> RGBColor[
              0.8481762150777309, 0.37130907680530634`, 0.1937669040066749], 
             470 -> RGBColor[
              0.9860771207353004, 0.9885105458694399, 0.8804016708799934], 
             313 -> RGBColor[
              0.6459555121737379, 0.7233446226446291, 0.965346466722161], 248 -> 
             RGBColor[
              0.907032706551878, 0.9287072757302742, 0.9909947833402158], 174 -> 
             RGBColor[
              0.9927086106921241, 0.9912528373881047, 0.7705007205495504], 
             215 -> RGBColor[
              0.5393170090844335, 0.6368808697859522, 0.9568761570198768], 
             399 -> RGBColor[
              0.8792245438445145, 0.544468686069936, 0.22093433771758136`], 
             422 -> RGBColor[
              0.9695585044588393, 0.9768173629855522, 0.9364136909242924], 83 -> 
             RGBColor[
              0.6740425805771709, 0.745286453951017, 0.9681459232120379], 95 -> 
             RGBColor[
              0.9884317044036613, 0.9726395639678842, 0.4095597854078852], 
             166 -> RGBColor[
              0.7422637151626922, 0.7985813227890527, 0.974945568344773], 384 -> 
             RGBColor[
              0.9494128962936107, 0.9617928014013306, 0.9705149507319133], 
             233 -> RGBColor[
              0.9941356829316702, 0.9918429684332407, 0.7468504403957015], 
             295 -> RGBColor[
              0.6928862314938027, 0.760007257264141, 0.970024082231478], 499 -> 
             RGBColor[
              0.6721158717129053, 0.743781294342723, 0.9679538868785659], 141 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 319 -> 
             RGBColor[
              0.7056126309596984, 0.7699492172511171, 0.9712925307952738], 
             205 -> RGBColor[
              0.9952187978944984, 0.992290864305155, 0.7289004224499682], 468 -> 
             RGBColor[
              0.864485810612455, 0.8947815358129023, 0.9869366224234513], 486 -> 
             RGBColor[
              0.7212502652302764, 0.7821654559937149, 0.9728511440373642], 
             224 -> RGBColor[
              0.4511044330960283, 0.5651457196048872, 0.9499649534742592], 
             231 -> RGBColor[0.817319, 0.134127, 0.164218], 332 -> 
             RGBColor[
              0.861335367163534, 0.8922694577232421, 0.9866361303148591], 68 -> 
             RGBColor[
              0.3134208668494696, 0.4458911346993708, 0.9411918783818257], 
             484 -> RGBColor[
              0.9291846236317697, 0.7569476610649077, 0.261878489804842], 10 -> 
             RGBColor[
              0.9722028376021425, 0.9787895023141296, 0.9319375246652203], 
             250 -> RGBColor[
              0.8538887286337347, 0.8863317102931982, 0.9859258632841942], 
             282 -> RGBColor[
              0.9803058348338546, 0.9848327043821002, 0.9182212639520798], 
             374 -> RGBColor[
              0.9946328588614328, 0.9909285527428415, 0.6571979931016946], 
             232 -> RGBColor[
              0.8594620063491899, 0.45473161896156633`, 0.20444399200736055`],
              489 -> RGBColor[
              0.8980343343732009, 0.9215322180093031, 0.990136510568872], 253 -> 
             RGBColor[
              0.9122512570313426, 0.9328684062288201, 0.9914925333436022], 
             459 -> RGBColor[
              0.9183898769269716, 0.7141500875164819, 0.25319278322089017`], 
             415 -> RGBColor[
              0.9110642734406441, 0.6851065108058444, 0.247298430701777], 55 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 446 -> 
             RGBColor[
              0.9715383930199698, 0.9782939606326734, 0.9330622560279371], 
             325 -> RGBColor[
              0.9080110188028646, 0.9294873553636324, 0.9910880956360646], 91 -> 
             RGBColor[
              0.5349635898573565, 0.6333465679381098, 0.9565334399112212], 
             450 -> RGBColor[
              0.8117979745726563, 0.8529020147200616, 0.9818760934881594], 
             423 -> RGBColor[
              0.9670606421067902, 0.9005499526764846, 0.32653724397101747`], 
             105 -> RGBColor[
              0.9951445965658657, 0.9922601801488783, 0.7301301304922928], 36 -> 
             RGBColor[
              0.9951453967893066, 0.9920248195450299, 0.7129845835333108], 
             123 -> RGBColor[
              0.7740335927399176, 0.8234001926123937, 0.978112092835285], 94 -> 
             RGBColor[
              0.8996890118638986, 0.9228516129253614, 0.9902943351850827], 
             473 -> RGBColor[
              0.9692180906017386, 0.9765634828883031, 0.9369899227902105], 
             312 -> RGBColor[
              0.9040762370292161, 0.926349867184131, 0.9907127926378728], 96 -> 
             RGBColor[
              0.9942289836313859, 0.9900647044638207, 0.6132386667400894], 
             496 -> RGBColor[
              0.5671168667798834, 0.6594500466324357, 0.9590646636518968], 2 -> 
             RGBColor[
              0.9294628457788249, 0.9465924598999318, 0.9931341900433037], 
             262 -> RGBColor[0.817319, 0.134127, 0.164218], 272 -> 
             RGBColor[
              0.9440354999380339, 0.8158264368580825, 0.2738278534757321], 97 -> 
             RGBColor[
              0.4139435077518233, 0.5329587938341523, 0.9475970921714426], 
             372 -> RGBColor[0.817319, 0.134127, 0.164218], 356 -> 
             RGBColor[
              0.9817337654342356, 0.9858976526858426, 0.9158041499095815], 
             402 -> RGBColor[
              0.9586810488516174, 0.968704974403885, 0.9548263859725348], 455 -> 
             RGBColor[
              0.8183522533298697, 0.8580222670995601, 0.9825293627414611], 
             428 -> 
             RGBColor[
              0.99363154449373, 0.9887868425587375, 0.5482111035732229], 346 -> 
             RGBColor[
              0.5418866311075848, 0.6389670047044993, 0.957078447078375], 341 -> 
             RGBColor[
              0.9479367945265521, 0.9606919271203531, 0.9730136059945443], 
             209 -> RGBColor[
              0.8434209630100141, 0.8779849981247719, 0.9849274384543191], 
             498 -> RGBColor[0.817319, 0.134127, 0.164218], 378 -> 
             RGBColor[
              0.9573753477542426, 0.9677311846633522, 0.9570365973490037], 
             419 -> RGBColor[
              0.9920447040183925, 0.9909782949168935, 0.7815033722686775], 66 -> 
             RGBColor[
              0.7302803242877403, 0.7892198067603964, 0.9737511759335125], 
             139 -> RGBColor[
              0.9254086716728859, 0.7419772698093332, 0.2588402702257402], 56 -> 
             RGBColor[
              0.809731263093604, 0.8512874840050368, 0.9816701030024443], 335 -> 
             RGBColor[
              0.6505567722680523, 0.7269391620011793, 0.9658050773271419], 
             314 -> RGBColor[
              0.9949217803409345, 0.9921680399137535, 0.7338227719693111], 
             144 -> RGBColor[
              0.35481967879100806`, 0.48174870483834226`, 0.9438297740712086],
              298 -> RGBColor[
              0.9169519612599091, 0.9366166201834619, 0.991940890709291], 204 -> 
             RGBColor[
              0.9793586872723007, 0.9841263232815052, 0.9198245377181432], 
             452 -> RGBColor[
              0.87310160854161, 0.9016515392120059, 0.9877584049213477], 466 -> 
             RGBColor[
              0.8349167633035023, 0.2693911201397685, 0.18106963801326467`], 
             207 -> RGBColor[
              0.8751175238894345, 0.9032589753897968, 0.9879506847268521], 
             334 -> RGBColor[
              0.9899831229747894, 0.9901257781751474, 0.8156691053618979], 
             149 -> RGBColor[
              0.9332925138588519, 0.9496461332733748, 0.9934994672035617], 
             219 -> RGBColor[
              0.8188234732480434, 0.8583903876810415, 0.9825763295391041], 
             400 -> RGBColor[0.817319, 0.134127, 0.164218], 9 -> 
             RGBColor[
              0.44298327582575264`, 0.5581115813586073, 0.9494474805142548], 
             11 -> RGBColor[
              0.767369759300133, 0.8181943552822241, 0.9774479041950713], 44 -> 
             RGBColor[
              0.9725362274644557, 0.9190203878164718, 0.3478088591080171], 
             153 -> 
             RGBColor[
              0.9564820542158774, 0.9670649678050733, 0.9585487103011875], 
             471 -> RGBColor[
              0.581698167494237, 0.6712878034324593, 0.9602125570571951], 406 -> 
             RGBColor[
              0.6170948462980028, 0.7000244218875646, 0.9629991132749344], 32 -> 
             RGBColor[
              0.994872982731618, 0.9914421534209201, 0.6833339944985983], 162 -> 
             RGBColor[
              0.30611291179131705`, 0.4390744573452393, 0.9407440495218204], 
             493 -> RGBColor[
              0.9949651407270251, 0.9921859705477131, 0.7331041781587054], 90 -> 
             RGBColor[
              0.9697318967192379, 0.9769466786494537, 0.9361201830553818], 
             331 -> RGBColor[
              0.9596578497911538, 0.8755785959375486, 0.29777879372479643`], 
             8 -> RGBColor[
              0.33407636534708024`, 0.46378188932246034`, 0.9425080284811533],
              364 -> RGBColor[
              0.9474780655824178, 0.9603498078249174, 0.9737901144412937], 
             342 -> RGBColor[
              0.7297718340424981, 0.7888225703161442, 0.9737004943779782], 
             163 -> RGBColor[
              0.9579788425456083, 0.9681812700906207, 0.9560150380838718], 49 -> 
             RGBColor[
              0.7297718340424981, 0.7888225703161442, 0.9737004943779782], 
             338 -> RGBColor[
              0.9849072089892894, 0.9880267572971039, 0.8997901361459415], 76 -> 
             RGBColor[
              0.7375531045123291, 0.7949013579470221, 0.9744760586983041], 
             369 -> RGBColor[
              0.7691269110511739, 0.8195670555849852, 0.9776230406600984], 
             445 -> RGBColor[
              0.42754791590212615`, 0.5447422483965092, 0.9484639530288741], 
             82 -> RGBColor[
              0.44515590012002204`, 0.5599933993230313, 0.9495859182131093], 
             67 -> RGBColor[
              0.6210471944247042, 0.7032331161480748, 0.9633102565973966], 
             430 -> RGBColor[
              0.9429511122396806, 0.9569736134341099, 0.9814530656320205], 
             211 -> RGBColor[
              0.9353990437647335, 0.7815857660593604, 
               0.2668787581150132]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw1l3k4VA/cxYfs69jHPjOGGTNjV1rUPZUi6hcVbZKtXVmyRook2RJlqUih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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 42}], {
             RGBColor[
             0.8599761832290406, 0.8892873142426017, 0.882725167979345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 108}], {
             RGBColor[
             0.9318919586964185, 0.7520201835517888, 0.5035418970848805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[
             0.9892734563237435, 0.989832312777339, 0.8274301183281484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 119}], {
             RGBColor[
             0.7290610186930846, 0.7843245677419544, 0.8715164995801912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 120}], {
             RGBColor[
             0.9923975383855921, 0.9894800058963162, 0.6561403670180064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 124}], {
             RGBColor[
             0.663252823303818, 0.7276882522664536, 0.8672228411800336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 315}], {
             RGBColor[
             0.9933196833935783, 0.9915055316540082, 0.7603736644809946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 363}], {
             RGBColor[
             0.7846572425876195, 0.8294600868808824, 0.8758932379808474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 364}], {
             RGBColor[
             0.9694485215950097, 0.9755346743952569, 0.8828316963324088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 378}], {
             RGBColor[
             0.9743971626809221, 0.9792253628144743, 0.8744549377862638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 380}], {
             RGBColor[
             0.7909649138174923, 0.8345809385426437, 0.876389800965824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 381}], {
             RGBColor[
             0.9822906017097518, 0.9559257840997029, 0.5710570113507505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 416}], {
             RGBColor[
             0.7795887748140593, 0.825345276410435, 0.8754942296313035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 452}], {
             RGBColor[
             0.9322602930746058, 0.9461855400888011, 0.8898158415724358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 468}], {
             RGBColor[
             0.9279523941100283, 0.9427505383892493, 0.8894049503234875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 487}], {
             RGBColor[
             0.7322110456976068, 0.7868819015713249, 0.8717644812449161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[
             0.8298715850332825, 0.8679061333301641, 0.9834426829884081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 114}], {
             RGBColor[
             0.9621243135471179, 0.9693521303608079, 0.8646054089098673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 118}], {
             RGBColor[
             0.940232635394042, 0.9547853646073893, 0.9804792416375547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 195}], {
             RGBColor[
             0.9525592078321163, 0.9639785021487952, 0.9596135697848798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 255}], {
             RGBColor[
             0.854700281926275, 0.404948819966644, 0.4405233966811013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 260}], {
             RGBColor[
             0.9569956928833381, 0.953032866893351, 0.6937654593732594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 312}], {
             RGBColor[
             0.9167695414040204, 0.9364711635420314, 0.9919234913405883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 327}], {
             RGBColor[
             0.9588418073027374, 0.9679947296721939, 0.9190050322331037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 334}], {
             RGBColor[
             0.9597229843768071, 0.9683591190375396, 0.9044016477026008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 385}], {
             RGBColor[
             0.9329749906804496, 0.9493726250632948, 0.9927645410407662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 446}], {
             RGBColor[
             0.9505006193993973, 0.9624432102663025, 0.9630982230356204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 496}], {
             RGBColor[
             0.7482898562793541, 0.8030212532661838, 0.9760994268476002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[
             0.8514217095878984, 0.7894309538446789, 0.6198445060093464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 139}], {
             RGBColor[
             0.9271092490543826, 0.7487194924431486, 0.26020859470457397`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 158}], {
             RGBColor[
             0.9378948685617141, 0.857719999898471, 0.6181051399610547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 247}], {
             RGBColor[
             0.6786056729327609, 0.6504716559728235, 0.6050476315371216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 278}], {
             RGBColor[
             0.8160678434355395, 0.7618122449071216, 0.6163207630319425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 401}], {
             RGBColor[
             0.8195724133280803, 0.7645500415428921, 0.6166700658067633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 428}], {
             RGBColor[
             0.9612206854648047, 0.8721242788178507, 0.4048940113783153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 437}], {
             RGBColor[
             0.7405903641473407, 0.7014701615441583, 0.6097403632302338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 451}], {
             RGBColor[
             0.8966478185241671, 0.8251216254449332, 0.6242567708034295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 31}], {
             RGBColor[
             0.6889630101721027, 0.4783742549575077, 0.4542453277780416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 151}], {
             RGBColor[
             0.8957191582107794, 0.6455909989854842, 0.4606089486078824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 162}], {
             RGBColor[
             0.679534138956783, 0.47004514262255764`, 0.45365047096653455`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 191}], {
             RGBColor[
             0.8810953110374435, 0.551701854514115, 0.2224300931258902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.8868060791213315, 0.6388100566549203, 0.4710650761021744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 345}], {
             RGBColor[
             0.861442968484558, 0.6185862006964551, 0.46864591996772276`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 366}], {
             RGBColor[
             0.8701763044006257, 0.6255499256958391, 0.46947891334373826`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 389}], {
             RGBColor[
             0.902187945552219, 0.6317565815588821, 0.2579971555062917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 405}], {
             RGBColor[
             0.8707617960182173, 0.5060413247156917, 0.21387281349038761`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 429}], {
             RGBColor[
             0.896312342555947, 0.6460333948988599, 0.45960484223876874`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 472}], {
             RGBColor[
             0.8736863986914352, 0.5193212623964658, 0.2163131736494921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 488}], {
             RGBColor[
             0.725881801733018, 0.5103514566151549, 0.45659776053029755`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 69}], {
             RGBColor[
             0.7521300835144776, 0.6269237600207085, 0.5925739285492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[
             0.6491492127718788, 0.7255622485785258, 0.9658543882668829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 97}], {
             RGBColor[
             0.5190996763592048, 0.6193984185200934, 0.9555799727465852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 103}], {
             RGBColor[
             0.7944371042885858, 0.7990748085202792, 0.6403061532602916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 129}], {
             RGBColor[
             0.5286119673332653, 0.6276374868601787, 0.9561860875160637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 163}], {
             RGBColor[
             0.7911173437560974, 0.8370096566483276, 0.9597889457027997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 204}], {
             RGBColor[
             0.8018072661194435, 0.8449821832437698, 0.9416936955199355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 209}], {
             RGBColor[
             0.7338384039883004, 0.7919115206654033, 0.9742451458880235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 231}], {
             RGBColor[
             0.7529646149888621, 0.32469734773534487`, 0.430666284440576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 233}], {
             RGBColor[
             0.8091957639491283, 0.8488405058196375, 0.8552066468587146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 259}], {
             RGBColor[
             0.7942746481119751, 0.8393643690673298, 0.9544444529851586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 275}], {
             RGBColor[
             0.80583296428755, 0.8474499017395656, 0.9109369398976215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 326}], {
             RGBColor[
             0.7287079131295202, 0.7878206065180764, 0.9737557950898696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 346}], {
             RGBColor[
             0.5830712380370857, 0.6724025239552669, 0.9603206502000514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 348}], {
             RGBColor[
             0.7529646149888621, 0.32469734773534487`, 0.430666284440576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 355}], {
             RGBColor[
             0.6770138395045423, 0.7473303067610894, 0.968631673849853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 395}], {
             RGBColor[
             0.41157276491247397`, 0.516107045349748, 0.9491003493461329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 404}], {
             RGBColor[
             0.7529646149888621, 0.32469734773534487`, 0.430666284440576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 431}], {
             RGBColor[
             0.7726297442847794, 0.7151754223033733, 0.6094293672815586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 444}], {
             RGBColor[
             0.7843318610941716, 0.8319490547892715, 0.9712749979121257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 486}], {
             RGBColor[
             0.6727530550984314, 0.7440017495998748, 0.968206998679546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 35}], {
             RGBColor[
             0.6020886409080104, 0.6868250504651503, 0.9625128643518496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 101}], {
             RGBColor[
             0.7613956574402418, 0.8135273415044213, 0.9768524615528335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 123}], {
             RGBColor[
             0.7413797986309564, 0.7978908004764462, 0.9748574678055592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 158}], {
             RGBColor[
             0.8278529576047721, 0.8661798465302385, 0.9731181017572674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 181}], {
             RGBColor[
             0.781121334840665, 0.346878469446833, 0.4333462809252778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 189}], {
             RGBColor[
             0.7152025100436956, 0.7774409036773162, 0.9722483603198513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 302}], {
             RGBColor[
             0.7922195099537469, 0.432183906617324, 0.4439739059471609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 306}], {
             RGBColor[
             0.8489543420647578, 0.8810880913064121, 0.9002686831072055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 347}], {
             RGBColor[
             0.7615640611151557, 0.8136588997351795, 0.976869246457327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 370}], {
             RGBColor[
             0.6903076882868913, 0.7579928797132476, 0.9697670771424693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 390}], {
             RGBColor[
             0.8458064913058876, 0.8631586542440057, 0.6798112067439972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 422}], {
             RGBColor[
             0.8391422544904172, 0.8745993856630255, 0.9540082668500629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 428}], {
             RGBColor[
             0.8511787745078626, 0.8805841254496182, 0.759906973174528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 451}], {
             RGBColor[
             0.7866059075672251, 0.8335814720767005, 0.9792697325996422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 17}], {
             RGBColor[
             0.9454916235307165, 0.8095912242004434, 0.3300065010953132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.9298098023489172, 0.7566927590875199, 0.2690855870674643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.7267267256581278, 0.6421932007744107, 0.597848142116634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.8649865868639143, 0.75164012614622, 0.6106822163061845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 89}], {
             RGBColor[
             0.7305555262718937, 0.6453015935981679, 0.5981495593263082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 176}], {
             RGBColor[
             0.9445212726691867, 0.8127346001708217, 0.5282834821681142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 178}], {
             RGBColor[
             0.859034450638099, 0.41193616425183494`, 0.2024874879156613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 244}], {
             RGBColor[
             0.8902389744353574, 0.5944826428973309, 0.23012504859098004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 261}], {
             RGBColor[
             0.9382942321989838, 0.8090200268848371, 0.5804510855922276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 262}], {
             RGBColor[
             0.8446311606646579, 0.30122616595405494`, 0.1886948811709047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 288}], {
             RGBColor[
             0.7386128078933003, 0.6518428577948263, 0.5987838580503406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 295}], {
             RGBColor[
             0.7960708567438881, 0.6977158775631529, 0.603836362872096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 313}], {
             RGBColor[
             0.7726054970838558, 0.6793845602533969, 0.6014975551174375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 321}], {
             RGBColor[
             0.9270206994906767, 0.7469363779783933, 0.26006326744553515`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 341}], {
             RGBColor[
             0.9235961382602629, 0.798058212491259, 0.6053311247536293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 376}], {
             RGBColor[
             0.7851160672626453, 0.6891579127609222, 0.6027444918349338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 391}], {
             RGBColor[
             0.9471712650769322, 0.8136622577944126, 0.4721411694100477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 407}], {
             RGBColor[
             0.838681319037305, 0.731003494558278, 0.6080833755360942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 448}], {
             RGBColor[
             0.9462174752294414, 0.8116221977535762, 0.3683270306193279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 455}], {
             RGBColor[
             0.8588038676619216, 0.7467233824808623, 0.6100890031270876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 475}], {
             RGBColor[
             0.9078740072092061, 0.7858373909815429, 0.6147728567447706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 478}], {
             RGBColor[
             0.8885494196134216, 0.5868107690564748, 0.22871524263277843`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 482}], {
             RGBColor[
             0.9283784852565414, 0.801624879050709, 0.5972358587247895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 63}], {
             RGBColor[
             0.4710766197114795, 0.5782425575525428, 0.9523986069744207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 85}], {
             RGBColor[
             0.5724868378915265, 0.6579901491868219, 0.9621471760926765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 146}], {
             RGBColor[
             0.6296451624543737, 0.7034932013428872, 0.9676184779820195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 159}], {
             RGBColor[
             0.6621339172487573, 0.7269969119977447, 0.8773621492649972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 166}], {
             RGBColor[
             0.5381700402548862, 0.6311816060557565, 0.9587267984129632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 239}], {
             RGBColor[
             0.6562381217823601, 0.2440119631074868, 0.42364800949371784`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 344}], {
             RGBColor[
             0.5411284333352755, 0.6334927252147768, 0.9590216633874612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 387}], {
             RGBColor[
             0.4147638213205529, 0.532525290956131, 0.9479654572045095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 435}], {
             RGBColor[
             0.6464554692185227, 0.7163006809259662, 0.9485372689818498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 439}], {
             RGBColor[
             0.5075717494804984, 0.6072779887471818, 0.9556770467458569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 453}], {
             RGBColor[
             0.6619761517535669, 0.7269316719110952, 0.8799767318043157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 68}], {
             RGBColor[
             0.37820207133761113`, 0.502001358028989, 0.9453196794480403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 95}], {
             RGBColor[
             0.7157074901147069, 0.7653755726632457, 0.67950363296107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 286}], {
             RGBColor[
             0.6678069797765647, 0.7376675375105597, 0.9695342930303161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 319}], {
             RGBColor[
             0.5742979533927255, 0.6640303993048622, 0.9603700056547643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 330}], {
             RGBColor[
             0.651159781873893, 0.7243935137791186, 0.9679464684332302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 333}], {
             RGBColor[
             0.6795991402238992, 0.7470702861615961, 0.9706590398207687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 352}], {
             RGBColor[
             0.719100306087374, 0.7751451361738031, 0.8351311205800933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 357}], {
             RGBColor[
             0.6975610050087471, 0.7609686541006071, 0.9576741493485085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 358}], {
             RGBColor[
             0.6712581463355166, 0.5973981500803227, 0.5936638529549505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 367}], {
             RGBColor[
             0.6998721765454534, 0.3318102468428714, 0.43298205346779284`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 368}], {
             RGBColor[
             0.5765399939622976, 0.6657818984379513, 0.9605934713056788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 375}], {
             RGBColor[
             0.692540425275251, 0.2754551937862024, 0.4259611601714183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 441}], {
             RGBColor[
             0.7184565663641234, 0.774934717719648, 0.849854495437047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 450}], {
             RGBColor[
             0.6273906251992045, 0.7055067980393344, 0.9656617870012071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 492}], {
             RGBColor[
             0.664882656851965, 0.7353357617891152, 0.9692553684991938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 102}], {
             RGBColor[
             0.8247792948045194, 0.8633321154835418, 0.9502068369210129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 168}], {
             RGBColor[
             0.9782772295982043, 0.9688329944584613, 0.662823479408796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 181}], {
             RGBColor[
             0.8689469458673809, 0.4156811674380433, 0.4201245082217401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.8469409265837693, 0.8806449506641316, 0.9524157012645447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 232}], {
             RGBColor[
             0.8970422834335074, 0.6294175800790874, 0.4469418362266471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 280}], {
             RGBColor[
             0.9088893409242738, 0.9292463721220534, 0.9585352488077757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 302}], {
             RGBColor[
             0.8800451209804626, 0.5009866046085343, 0.43075213324362327`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 370}], {
             RGBColor[
             0.8220461048269649, 0.861196926700063, 0.9499344180871628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 383}], {
             RGBColor[
             0.9233967365071527, 0.7511083462347841, 0.5745026077996789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 390}], {
             RGBColor[
             0.9775449078459613, 0.9663627012308211, 0.6599785476886908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 443}], {
             RGBColor[
             0.9790914436952116, 0.9836299534261836, 0.9069739561744432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 451}], {
             RGBColor[
             0.9183443241072988, 0.9367855190635159, 0.9594370735443358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 480}], {
             RGBColor[
             0.9758999358733124, 0.9608138245092895, 0.6535881422018409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 25}], {
             RGBColor[
             0.8463325905161322, 0.8807319121845174, 0.9850923008062491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 164}], {
             RGBColor[
             0.5690799936469824, 0.6568879735684549, 0.9611476537696408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 180}], {
             RGBColor[
             0.7698090520398855, 0.8200999493098302, 0.9776910300988833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 205}], {
             RGBColor[
             0.8812942785973157, 0.9052426097936895, 0.8531741633225198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 259}], {
             RGBColor[
             0.8658316052787483, 0.8955425251054245, 0.9613869784218303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 316}], {
             RGBColor[
             0.815927784956294, 0.8564879455475631, 0.9821922633092612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 331}], {
             RGBColor[
             0.8635138045456434, 0.8468864756098864, 0.6376133489599338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 348}], {
             RGBColor[
             0.8006692531000443, 0.36214945176074137`, 0.4352946347316905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 372}], {
             RGBColor[
             0.8006692531000443, 0.36214945176074137`, 0.4352946347316905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 404}], {
             RGBColor[
             0.8006692531000443, 0.36214945176074137`, 0.4352946347316905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 418}], {
             RGBColor[
             0.7106022107491934, 0.7738471149048816, 0.9717898454784164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 431}], {
             RGBColor[
             0.8441867014515525, 0.771353578341468, 0.6163718927182305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 444}], {
             RGBColor[
             0.8558888182609448, 0.8881272108273663, 0.9782175233487975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 40}], {
             RGBColor[
             0.8332631957292829, 0.8699516348164067, 0.9839410234937223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 161}], {
             RGBColor[
             0.8920705114960007, 0.8224263952588458, 0.6240339416772016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 188}], {
             RGBColor[
             0.9137636320753655, 0.9034537604909598, 0.667417520470068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 202}], {
             RGBColor[
             0.9239275233715001, 0.9373540680592094, 0.7396301074231337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 243}], {
             RGBColor[
             0.9183945629089296, 0.9365713707619345, 0.9506283366738786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 273}], {
             RGBColor[
             0.8297888056286364, 0.3850850849709173, 0.438147317833095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 279}], {
             RGBColor[
             0.6352157028902841, 0.7107420114393673, 0.9668575791266505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 283}], {
             RGBColor[
             0.7672959585928333, 0.8184175277958409, 0.9773660257948413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 285}], {
             RGBColor[
             0.923981077130285, 0.9374686141341345, 0.7454591035713727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 318}], {
             RGBColor[
             0.7597905644967715, 0.8125542568848896, 0.9766179582532415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 335}], {
             RGBColor[
             0.7526425945769808, 0.8069702084569657, 0.9759055154132135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 396}], {
             RGBColor[
             0.9024499125457236, 0.9246798766280242, 0.977618470707948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 421}], {
             RGBColor[
             0.6731165348331469, 0.7425329499644858, 0.9695590733442376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 430}], {
             RGBColor[
             0.898839764562795, 0.9219874341734309, 0.9837295095656529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 459}], {
             RGBColor[
             0.8865591469064404, 0.8005756712146169, 0.6195993683600877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 477}], {
             RGBColor[
             0.7938098598670751, 0.8391303889843917, 0.9800086836873632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 21}], {
             RGBColor[
             0.7807583038736883, 0.3465948668962931, 0.43331009739120674`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 59}], {
             RGBColor[
             0.8758087454125018, 0.41984658819913434`, 0.3658723730660921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 77}], {
             RGBColor[
             0.875963077373552, 0.41991040843117905`, 0.3633146930731791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 87}], {
             RGBColor[
             0.8747179087382527, 0.4193954992011085, 0.38395035975321834`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 161}], {
             RGBColor[
             0.8546835353686973, 0.34203517853497983`, 0.1968326432850394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 188}], {
             RGBColor[
             0.8691456157549405, 0.3960534220230558, 0.22575502914695028`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 228}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 243}], {
             RGBColor[
             0.8722329029773166, 0.41813182887037237`, 0.4145622399494907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 256}], {
             RGBColor[
             0.7036968790624343, 0.2846995802240602, 0.42678774779478423`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 279}], {
             RGBColor[
             0.6834469962982196, 0.26757892265532757`, 0.42538173491800535`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 285}], {
             RGBColor[
             0.8759572457915535, 0.4187299911185057, 0.2777827512144868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 287}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 298}], {
             RGBColor[
             0.8505299870866364, 0.40162354006115397`, 0.44012563023643037`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 335}], {
             RGBColor[
             0.7617315907560175, 0.33173105400039304`, 0.4314136924423806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 354}], {
             RGBColor[
             0.861350298764537, 0.41001560046711016`, 0.4329836502439711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 409}], {
             RGBColor[
             0.7100297590980085, 0.28984089752993386`, 0.42728629530928863`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 430}], {
             RGBColor[
             0.8591963707465602, 0.40840920447803664`, 0.43662968854400686`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 477}], {
             RGBColor[
             0.789176434282747, 0.3531711743520105, 0.4341491379584804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 80}], {
             RGBColor[
             0.7366250720635487, 0.7897968471286657, 0.8441635429555299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 159}], {
             RGBColor[
             0.9924836753423649, 0.9911598208404044, 0.7742284814090845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 166}], {
             RGBColor[
             0.8685197983484938, 0.8953445148984163, 0.8555931305570506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 192}], {
             RGBColor[
             0.9757901938515567, 0.929030652455124, 0.5114673926650403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.9898830743968109, 0.9900844055170221, 0.8173271692164221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 239}], {
             RGBColor[
             0.8764712938447652, 0.4201205690025933, 0.35489223092310934`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 251}], {
             RGBColor[
             0.9445520769267819, 0.8025794482580824, 0.48488897587625346`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 272}], {
             RGBColor[
             0.9694056907361647, 0.9039670719329311, 0.50503427312253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 435}], {
             RGBColor[
             0.9768052273121304, 0.9804635897686259, 0.8454036011259372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 447}], {
             RGBColor[
             0.7227866477973139, 0.7784937510775864, 0.8430930416310596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 453}], {
             RGBColor[
             0.9923259098471746, 0.991094580753755, 0.776843063948403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 454}], {
             RGBColor[
             0.9498428490990662, 0.9595611239828206, 0.8635164964884481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 489}], {
             RGBColor[
             0.9464051079537481, 0.9568199625085414, 0.8631886016690999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 50}], {
             RGBColor[
             0.8489296158320114, 0.8824739651594797, 0.9665564070489764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 82}], {
             RGBColor[
             0.7009007393720259, 0.7635901616819789, 0.9539289121726456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 126}], {
             RGBColor[
             0.9727607910788756, 0.9784274399377603, 0.8961444228829234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 149}], {
             RGBColor[
             0.9449690462414408, 0.9584165286571507, 0.9758856866678718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 173}], {
             RGBColor[
             0.7037214963421812, 0.7660333595941599, 0.9541086483124865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 242}], {
             RGBColor[
             0.7523227329362048, 0.8055584727397871, 0.9579158055637778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 249}], {
             RGBColor[
             0.9415038821063118, 0.9556535008351734, 0.9755551762192747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 269}], {
             RGBColor[
             0.9326046168788198, 0.9485574683068909, 0.9747063563574087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 282}], {
             RGBColor[
             0.9684757067289421, 0.9760098142115134, 0.9382465850421309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 323}], {
             RGBColor[
             0.7920404053408276, 0.8378030684586115, 0.9610425262260975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 414}], {
             RGBColor[
             0.971266919628012, 0.977809685702083, 0.9209017388391181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 419}], {
             RGBColor[
             0.9743451413212111, 0.97908260947891, 0.8698876392004298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 449}], {
             RGBColor[
             0.9730694286887764, 0.9785550695210792, 0.8910294989583336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 499}], {
             RGBColor[
             0.8143807251684675, 0.8554841091918248, 0.9631128965053739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 17}], {
             RGBColor[
             0.9483187908656481, 0.9553862457482916, 0.7065783294427403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 116}], {
             RGBColor[
             0.816906371411886, 0.8575791569161014, 0.9822030949841092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 143}], {
             RGBColor[
             0.9499157985023857, 0.9595912904358073, 0.8623075360884397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 165}], {
             RGBColor[
             0.8063523445655414, 0.849334270930162, 0.981151168221054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 185}], {
             RGBColor[
             0.9257257458660936, 0.9433329951352929, 0.9830837397697092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.8673140386090211, 0.5582861552275501, 0.45965905051685185`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 224}], {
             RGBColor[
             0.6780071248799326, 0.7460801302813742, 0.9703786268409138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 277}], {
             RGBColor[
             0.9495515816052744, 0.9594406773889045, 0.8683435526366887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 313}], {
             RGBColor[
             0.7754326644187874, 0.8251795818012451, 0.9780693834648646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 333}], {
             RGBColor[
             0.9105624106429414, 0.9315217659612229, 0.9913314496674255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 358}], {
             RGBColor[
             0.9022214167545588, 0.7818496298799497, 0.6143362628016072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 361}], {
             RGBColor[
             0.9122234790119661, 0.9328462567901836, 0.9914898838513163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 386}], {
             RGBColor[
             0.9492465564161273, 0.9578490926137048, 0.7668759356623438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 441}], {
             RGBColor[
             0.9494198367831654, 0.959386197519275, 0.8705269052837038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 89}], {
             RGBColor[
             0.7767916678086366, 0.8194683199364465, 0.6905074169089074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.9755497159144375, 0.9764889933244758, 0.6880108543355787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 116}], {
             RGBColor[
             0.8603153456136973, 0.8859508617065319, 0.6979891242192813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 143}], {
             RGBColor[
             0.993324772704197, 0.9879629952262378, 0.5780935653236118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 165}], {
             RGBColor[
             0.8497613187673525, 0.8777059757205925, 0.696937197456226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 176}], {
             RGBColor[
             0.9907574142059294, 0.9869013265091003, 0.6206413397507132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 178}], {
             RGBColor[
             0.8898585449959275, 0.5280473151440207, 0.2640593929707274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 261}], {
             RGBColor[
             0.9845303737357267, 0.9831867532231158, 0.6728089431748268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 277}], {
             RGBColor[
             0.9929605558070855, 0.987812382179335, 0.5841295818718607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 288}], {
             RGBColor[
             0.7848489494300432, 0.826009584133105, 0.6911417156329398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 313}], {
             RGBColor[
             0.8188416386205986, 0.8535512865916756, 0.6938554127000367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 321}], {
             RGBColor[
             0.9732568410274195, 0.921103104316672, 0.35242112502813433`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 328}], {
             RGBColor[
             0.8827412860288608, 0.47334094392037895`, 0.2572438977460699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 386}], {
             RGBColor[
             0.9926555306179385, 0.9862207974041353, 0.4826619648975158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 391}], {
             RGBColor[
             0.9934074066136749, 0.9878289841326913, 0.5644990269926469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 407}], {
             RGBColor[
             0.8849174605740479, 0.9051702208965566, 0.7004412331186933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 455}], {
             RGBColor[
             0.9050400091986646, 0.920890108819141, 0.7024468607096868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 498}], {
             RGBColor[
             0.8754552550224864, 0.41733731684624076`, 0.2502667862259708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 28}], {
             RGBColor[
             0.952796075792812, 0.8538960813131017, 0.5688908206483334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 93}], {
             RGBColor[
             0.9571090040400122, 0.855017145720595, 0.4492618788912275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 160}], {
             RGBColor[
             0.9572976282145504, 0.8554205937571029, 0.46979245623624666`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 167}], {
             RGBColor[
             0.9179594477878378, 0.8276943531137744, 0.6230603344389476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 172}], {
             RGBColor[
             0.8973687675757923, 0.6223992524236768, 0.23584370903737706`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 201}], {
             RGBColor[
             0.9181916507672312, 0.7133641868480631, 0.25303328579979706`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 218}], {
             RGBColor[
             0.9573128356472821, 0.8557638775883587, 0.4940364208599619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 235}], {
             RGBColor[
             0.8157957020356948, 0.7471054590734147, 0.6130840110786471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 274}], {
             RGBColor[
             0.9525754126385572, 0.8409654744465347, 0.3261072935117726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 300}], {
             RGBColor[
             0.7754732421205519, 0.71543495775266, 0.6091814727467315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 305}], {
             RGBColor[
             0.8683143686496947, 0.45885227577060794`, 0.21038061679205267`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 310}], {
             RGBColor[
             0.903782824087721, 0.6515239850033869, 0.2411957550138424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 406}], {
             RGBColor[
             0.7683993686258163, 0.7096920685752642, 0.6086245915127735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 432}], {
             RGBColor[
             0.9568576405389885, 0.8544795046086535, 0.42190251304050486`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 460}], {
             RGBColor[
             0.8783493653710295, 0.5359856579343897, 0.2199901409853106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 493}], {
             RGBColor[
             0.9573345158403275, 0.8557728429053384, 0.493677123954659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 26}], {
             RGBColor[
             0.7916090801062013, 0.8348208520991536, 0.8646079259878061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 59}], {
             RGBColor[
             0.79158309956613, 0.8348101084781647, 0.8650384907722692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 67}], {
             RGBColor[
             0.6057125786597295, 0.6907837842535006, 0.9621030594718294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 124}], {
             RGBColor[
             0.4627323159473945, 0.5714957079631188, 0.9517341332414027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 188}], {
             RGBColor[
             0.7815884050797881, 0.799120359214047, 0.6548624748935565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 200}], {
             RGBColor[
             0.792128106361186, 0.8350354827939561, 0.8560063177458186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 228}], {
             RGBColor[
             0.7416719876315849, 0.31552948411964216`, 0.4297772874487541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 298}], {
             RGBColor[
             0.7536649620773319, 0.8074755362711942, 0.9764183765277765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 318}], {
             RGBColor[
             0.6276153375011941, 0.7082208556079768, 0.96406291267673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 335}], {
             RGBColor[
             0.6204673675814035, 0.7026368071800528, 0.963350469836702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 459}], {
             RGBColor[
             0.7543839199108632, 0.6962422699377042, 0.6070443227835761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 468}], {
             RGBColor[
             0.7274318867536049, 0.7865579940859144, 0.9739162423848566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 25}], {
             RGBColor[
             0.8048360649498705, 0.8483145110268786, 0.9809563149448832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 46}], {
             RGBColor[
             0.8232731505648918, 0.8187054242028444, 0.6383561870568264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 150}], {
             RGBColor[
             0.801317192631838, 0.7334927561034357, 0.6111311723030775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 220}], {
             RGBColor[
             0.5919654247578218, 0.6789795677138557, 0.9614609054439117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 325}], {
             RGBColor[
             0.796193863485237, 0.8414234541652894, 0.9801320140542022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 388}], {
             RGBColor[
             0.4776703387101491, 0.577745121566207, 0.953959150857393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 392}], {
             RGBColor[
             0.7619917436053689, 0.8141516121648945, 0.9768697853274675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 413}], {
             RGBColor[
             0.6499154387492356, 0.7260259996904654, 0.9660229428232116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 473}], {
             RGBColor[
             0.826797399384674, 0.8649615179276247, 0.9530829276312751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 474}], {
             RGBColor[
             0.6618313918661711, 0.7356999072383641, 0.9669610103021512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 490}], {
             RGBColor[
             0.7513644807487396, 0.8056909100332532, 0.9758526476069005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 55}], {
             RGBColor[
             0.7807583038736883, 0.34659486689629315`, 0.43331009739120685`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 59}], {
             RGBColor[
             0.8502125739292851, 0.8814081826431412, 0.8703377056859483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 77}], {
             RGBColor[
             0.8504440718708604, 0.8815039129912083, 0.8665011856965787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[
             0.8485763189179115, 0.8807315491461025, 0.8974546857166377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 91}], {
             RGBColor[
             0.6213002507392107, 0.7024385843134946, 0.9640138660424208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 188}], {
             RGBColor[
             0.8402178794429431, 0.8457184333790235, 0.6601616898072357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 200}], {
             RGBColor[
             0.850757580724341, 0.8816335569589326, 0.8613055326594978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 228}], {
             RGBColor[
             0.7807583038736883, 0.34659486689629315`, 0.43331009739120685`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 256}], {
             RGBColor[
             0.5920447744041837, 0.67868767068053, 0.9617107677789866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 287}], {
             RGBColor[
             0.7807583038736883, 0.34659486689629315`, 0.43331009739120685`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 298}], {
             RGBColor[
             0.8122944364404869, 0.8540736104361706, 0.9817175914414558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 335}], {
             RGBColor[
             0.6790968419445585, 0.7492348813450294, 0.9686496847503812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 336}], {
             RGBColor[
             0.803157067476149, 0.8467877204512808, 0.9808460610326116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 354}], {
             RGBColor[
             0.8285249039573377, 0.866661701045105, 0.9710046214527668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 409}], {
             RGBColor[
             0.6015440944575452, 0.6863996466393405, 0.9624585890507431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 24}], {
             RGBColor[
             0.7626954774262356, 0.8109469312354902, 0.8455869429728797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 52}], {
             RGBColor[
             0.7376580463602529, 0.7242597122627394, 0.615304646290935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 170}], {
             RGBColor[
             0.7578078654788301, 0.7955377914474235, 0.6763547272485007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 214}], {
             RGBColor[
             0.3547332643917914, 0.46757445792837016`, 0.9448430808088121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 268}], {
             RGBColor[
             0.7625088079778557, 0.810869738621399, 0.8486805388175827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 466}], {
             RGBColor[
             0.7334576851301958, 0.3895123853787591, 0.4394414792147179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 491}], {
             RGBColor[
             0.7141723641713045, 0.629297009951938, 0.5963118269584712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 39}], {
             RGBColor[
             0.9887948922355108, 0.9887348522935604, 0.7748044705467482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 51}], {
             RGBColor[
             0.8539492157098789, 0.8832972024729582, 0.8041381730047916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 62}], {
             RGBColor[
             0.9492580970096642, 0.9584329111647943, 0.813457303749337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 96}], {
             RGBColor[
             0.9943344703107491, 0.9902903298046392, 0.6247202408004453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 110}], {
             RGBColor[
             0.9785318282556119, 0.9810806759815768, 0.7921771608289325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 136}], {
             RGBColor[
             0.876359318996704, 0.4195899850484859, 0.32154593828693373`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 157}], {
             RGBColor[
             0.9896585982518791, 0.9892651596471013, 0.7682443113883352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 240}], {
             RGBColor[
             0.8531637350539361, 0.8826835790146617, 0.8040598836337414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 360}], {
             RGBColor[
             0.6882765642706542, 0.7479524558009207, 0.7908853530780005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 52}], {
             RGBColor[
             0.9698139950029055, 0.9054517276414893, 0.5047064276461906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 64}], {
             RGBColor[
             0.9706442614891084, 0.9758562008535987, 0.8552704636024282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.9672249679992521, 0.973306097367443, 0.8610584355861858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 115}], {
             RGBColor[
             0.8091262582177263, 0.8486415307648604, 0.84924214411834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 170}], {
             RGBColor[
             0.9899638141214828, 0.9767298068261734, 0.5657565086037563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 223}], {
             RGBColor[
             0.9735015541869848, 0.9779871650692875, 0.8504338123662112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 268}], {
             RGBColor[
             0.9946647566205084, 0.9920617540001488, 0.7380823201728381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 491}], {
             RGBColor[
             0.9463283128139571, 0.810489025330688, 0.4857136083137267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 164}], {
             RGBColor[
             0.6480428248629817, 0.7194255304707482, 0.9687920503808185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.8487718832558847, 0.8826375062121236, 0.9853354267100609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 220}], {
             RGBColor[
             0.7124247815400827, 0.7739345257737879, 0.9732412879164551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 316}], {
             RGBColor[
             0.8948906161722932, 0.9190255024498566, 0.989836659920439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 325}], {
             RGBColor[
             0.916653220267498, 0.9363784122252216, 0.9919123965267457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 392}], {
             RGBColor[
             0.8824511003876299, 0.9091065702248267, 0.988650167800011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 413}], {
             RGBColor[
             0.7703747955314966, 0.8209809577503976, 0.977803325295755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 474}], {
             RGBColor[
             0.7822907486484321, 0.8306548652982964, 0.9787413927746946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 490}], {
             RGBColor[
             0.8718238375310006, 0.9006458680931855, 0.9876330300794439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 67}], {
             RGBColor[
             0.8069436958711761, 0.8472701839937278, 0.8658151231133733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 124}], {
             RGBColor[
             0.6639634331588411, 0.7279821077033459, 0.8554461968829465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 318}], {
             RGBColor[
             0.8288464547126407, 0.864707255348204, 0.867774976318274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 335}], {
             RGBColor[
             0.8216984847928501, 0.8591232069202801, 0.867062533478246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 459}], {
             RGBColor[
             0.9556150371223098, 0.8527286696779314, 0.5107563864251201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 29}], {
             RGBColor[
             0.9321621376420286, 0.8802389595410478, 0.6336452178820404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 65}], {
             RGBColor[
             0.9133206953797207, 0.6873357598794598, 0.24876655220640198`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 86}], {
             RGBColor[
             0.970474804369984, 0.9073661326035414, 0.4980039385328334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 177}], {
             RGBColor[
             0.8541472098390972, 0.8184960932283085, 0.626080921389524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[
             0.9672180951362596, 0.906075184106552, 0.5560309803266663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 290}], {
             RGBColor[
             0.6791124413418269, 0.6771278367986768, 0.6113488793440298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 297}], {
             RGBColor[
             0.9443027096027632, 0.8168858341363918, 0.27404285664419026`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 350}], {
             RGBColor[
             0.9670975606055396, 0.9060253399805032, 0.5580285494340604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 412}], {
             RGBColor[
             0.7964034599228169, 0.7733862369249566, 0.6203255640438923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 484}], {
             RGBColor[
             0.9374584480113712, 0.7897506176414958, 0.2685358031122886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 490}], {
             RGBColor[
             0.8820422628604212, 0.840287920658822, 0.6288612395805981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 125}], {
             RGBColor[
             0.9517276818135523, 0.8496602552065251, 0.5680311657741911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 149}], {
             RGBColor[
             0.9595903872454232, 0.9690392903183072, 0.938515519374808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 201}], {
             RGBColor[
             0.9512838356064135, 0.8479005528982009, 0.5676740366975178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 218}], {
             RGBColor[
             0.9904050204864645, 0.9903002436384964, 0.8086771717576826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 282}], {
             RGBColor[
             0.9830970477329245, 0.98663257587267, 0.900876417749067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 305}], {
             RGBColor[
             0.8903758252091496, 0.5485431864706999, 0.4201411173905332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 310}], {
             RGBColor[
             0.9368750089269035, 0.7860603510535248, 0.5558365059115632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 406}], {
             RGBColor[
             0.8014915534649987, 0.8442284346254021, 0.9232653424104943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 408}], {
             RGBColor[
             0.942571871312984, 0.8119284726127021, 0.5605901075293841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 419}], {
             RGBColor[
             0.9889664823251935, 0.9897053711400665, 0.8325174719073658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 432}], {
             RGBColor[
             0.9899498253781709, 0.9890158706587915, 0.7365432639382257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 493}], {
             RGBColor[
             0.9904267006795098, 0.9903092089554764, 0.8083178748523798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 46}], {
             RGBColor[
             0.9403807979276293, 0.9109878201513772, 0.6498168804928294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 65}], {
             RGBColor[
             0.8997505606307765, 0.7450211452024238, 0.6072186536687073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 86}], {
             RGBColor[
             0.9569046696210399, 0.9650515179265053, 0.8564560399951388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 177}], {
             RGBColor[
             0.8405770750901531, 0.8761814785512725, 0.9845330228518294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 194}], {
             RGBColor[
             0.9536479603873154, 0.9637605694295159, 0.9144830817889715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 254}], {
             RGBColor[
             0.9483591764851438, 0.9379007644382439, 0.6808113745984048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 290}], {
             RGBColor[
             0.6655423065928827, 0.7348132221216408, 0.969800980806335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 297}], {
             RGBColor[
             0.930732574853819, 0.8745712194593558, 0.6324949581064956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 350}], {
             RGBColor[
             0.9535274258565956, 0.9637107253034671, 0.9164806508963657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 377}], {
             RGBColor[
             0.8510766676310282, 0.402059448288004, 0.4401777731147819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 412}], {
             RGBColor[
             0.7828333251738728, 0.8310716222479205, 0.9787776655061977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 426}], {
             RGBColor[
             0.8727563683999229, 0.9013762540943187, 0.987725475608434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 476}], {
             RGBColor[
             0.9507075545374911, 0.9623172130479145, 0.9530287497568525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 31}], {
             RGBColor[
             0.43459116396256625`, 0.5486307954786305, 0.9495239138117948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 133}], {
             RGBColor[
             0.7384397031356915, 0.4180827654515399, 0.44296915940260495`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 191}], {
             RGBColor[
             0.7227896152605777, 0.6586221948135415, 0.6018010618335677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 311}], {
             RGBColor[
             0.7519774934517425, 0.804864521368519, 0.9467934188281464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 366}], {
             RGBColor[
             0.7064111053053508, 0.7693943015861278, 0.97237429216034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 405}], {
             RGBColor[
             0.7072893427317383, 0.5901314001159066, 0.5889651423803139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 423}], {
             RGBColor[
             0.7509217222973233, 0.7668748746418281, 0.6415282258191328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 429}], {
             RGBColor[
             0.7456151625383329, 0.8001195053906589, 0.9575631855028855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 465}], {
             RGBColor[
             0.7313859521296366, 0.7893085665196558, 0.9747564153457493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 469}], {
             RGBColor[
             0.7494647469479445, 0.8029905191402313, 0.951046843229828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 488}], {
             RGBColor[
             0.48996935130393926`, 0.5965965979651013, 0.9530525629401788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 133}], {
             RGBColor[
             0.6716452774521646, 0.36170343136584593`, 0.43830563016563606`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 191}], {
             RGBColor[
             0.6225979767352874, 0.5740531936850004, 0.5948057679781144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 226}], {
             RGBColor[
             0.6311641288611193, 0.7047154968962085, 0.9677582424425406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 237}], {
             RGBColor[
             0.6563458418124253, 0.2441052647833632, 0.4236548733187805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 311}], {
             RGBColor[
             0.6517858549264521, 0.720295520239978, 0.9397981249726929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 366}], {
             RGBColor[
             0.6062194667800607, 0.6848253004575867, 0.9653789983048865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 405}], {
             RGBColor[
             0.607097704206448, 0.5055623989873657, 0.5819698485248604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 429}], {
             RGBColor[
             0.6454235240130427, 0.715550504262118, 0.950567891647432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 472}], {
             RGBColor[
             0.6114846082162748, 0.5254823055085267, 0.5856303887635171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 488}], {
             RGBColor[
             0.38977771277864903`, 0.5120275968365604, 0.9460572690847253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 66}], {
             RGBColor[
             0.862576653509679, 0.8903309800906583, 0.8285425852160554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 84}], {
             RGBColor[
             0.9127953372327364, 0.9296489539255978, 0.8335248917991266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 89}], {
             RGBColor[
             0.778364276640716, 0.8233104213775456, 0.8209922348192504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 176}], {
             RGBColor[
             0.9923300230380088, 0.9907434279501994, 0.7511261576610562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 179}], {
             RGBColor[
             0.7118511385288484, 0.7686471337021525, 0.8159397979137841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 245}], {
             RGBColor[
             0.9410304261784166, 0.7860352209895146, 0.45545656322328665`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 255}], {
             RGBColor[
             0.8765036609105393, 0.4198987178069734, 0.3372566648328661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 260}], {
             RGBColor[
             0.9897007613597346, 0.9754577136538451, 0.5388653616009067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 299}], {
             RGBColor[
             0.8765036609105393, 0.4198987178069734, 0.3372566648328661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 312}], {
             RGBColor[
             0.949474609880417, 0.9588960103025256, 0.8370233935682356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 328}], {
             RGBColor[
             0.8837896919169137, 0.4759023448811116, 0.3442337763529652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 334}], {
             RGBColor[
             0.9924280528532037, 0.9907839657980337, 0.7495015499302481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 407}], {
             RGBColor[
             0.8864900694061272, 0.9090123223376557, 0.8309260510290362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 448}], {
             RGBColor[
             0.9940262255982637, 0.989631025532954, 0.59116970611227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 475}], {
             RGBColor[
             0.9556827575780282, 0.9638462187609207, 0.8376155322377126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 478}], {
             RGBColor[
             0.9363581699822436, 0.7648195968358524, 0.4515579181257206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 482}], {
             RGBColor[
             0.9761872356253636, 0.9796337068300867, 0.8200785342177317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 76}], {
             RGBColor[
             0.8656600480432148, 0.891988954057436, 0.7687148705436906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 111}], {
             RGBColor[
             0.9296352516608084, 0.9423347866205443, 0.7749936870276516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 160}], {
             RGBColor[
             0.9943291785247859, 0.9902790112095459, 0.624144262555479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 175}], {
             RGBColor[
             0.8118657457091876, 0.8497745682877814, 0.7634829709671342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 182}], {
             RGBColor[
             0.9136067959047216, 0.9295541310814817, 0.7734648786088647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 237}], {
             RGBColor[
             0.8761349971913669, 0.4191101833892833, 0.2971298941296924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 241}], {
             RGBColor[
             0.7110842555018715, 0.7672790735182664, 0.7557360131399563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 274}], {
             RGBColor[
             0.9896069629487927, 0.9758238918989777, 0.4804590998310049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 351}], {
             RGBColor[
             0.932960656323998, 0.9449863740332667, 0.7753108670930504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 371}], {
             RGBColor[
             0.7920724772344276, 0.833705501263388, 0.7619247723676696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 432}], {
             RGBColor[
             0.993889190849224, 0.9893379220610965, 0.5762543193597371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 460}], {
             RGBColor[
             0.9030370655778531, 0.6258912695693517, 0.3228913451981321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 463}], {
             RGBColor[
             0.980699590227901, 0.9822286350750123, 0.7513140615609489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 44}], {
             RGBColor[
             0.8516627007795723, 0.8543188559567291, 0.6608053762174072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 62}], {
             RGBColor[
             0.8174327055619525, 0.8579835956405587, 0.982257342982335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 190}], {
             RGBColor[
             0.834832225743581, 0.7924925990520737, 0.6217388553081901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 291}], {
             RGBColor[
             0.8627874777050499, 0.8908645624593352, 0.854939260551614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 356}], {
             RGBColor[
             0.8562614697644622, 0.8877574883914146, 0.9448030216181893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 394}], {
             RGBColor[
             0.8590845549260162, 0.88933330872943, 0.916306273857167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 467}], {
             RGBColor[
             0.8356479490643618, 0.7957266701952876, 0.6223952054395777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.697570144578962, 0.7620601527575815, 0.9718586105564743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 123}], {
             RGBColor[
             0.6347424350169715, 0.7123344426010977, 0.9657674893815754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 193}], {
             RGBColor[
             0.6639542554980994, 0.7352557552835026, 0.9686522970466831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 347}], {
             RGBColor[
             0.6549266975011709, 0.7281025418598308, 0.9677792680333432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 410}], {
             RGBColor[
             0.7155769007685916, 0.7764181604822891, 0.9735729601517348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 422}], {
             RGBColor[
             0.7325048908764324, 0.789043027787677, 0.9449182884260792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 428}], {
             RGBColor[
             0.7445414108938777, 0.7950277675742696, 0.7508169947505443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 437}], {
             RGBColor[
             0.5239110895764139, 0.624373650300577, 0.9556633466024629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 75}], {
             RGBColor[
             0.9593256419214261, 0.8632290912020328, 0.48514691429511725`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 76}], {
             RGBColor[
             0.8663492506508179, 0.893463088746026, 0.8437303211158075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 104}], {
             RGBColor[
             0.9919409208277914, 0.9828461723248888, 0.5618641140465238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 112}], {
             RGBColor[
             0.896678164759537, 0.917156266956042, 0.846753223834348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 266}], {
             RGBColor[
             0.7599855207127746, 0.808570473421706, 0.8343599636301045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 359}], {
             RGBColor[
             0.9298156037008808, 0.9434031776789661, 0.849960602978381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 379}], {
             RGBColor[
             0.9557486799940477, 0.9640815087805339, 0.8524341229459538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 408}], {
             RGBColor[
             0.9472004393916401, 0.8137246587035973, 0.47531661352301247`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 440}], {
             RGBColor[
             0.8238374600611766, 0.8602525548358231, 0.8394931431251023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 463}], {
             RGBColor[
             0.9813887928355038, 0.9837027697636024, 0.8263295121330658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 49}], {
             RGBColor[
             0.8554573026094243, 0.8684374254926999, 0.6774720752986512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 53}], {
             RGBColor[
             0.9717439718581591, 0.9597449762602301, 0.6649338182719968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 97}], {
             RGBColor[
             0.6975431394640869, 0.7405055372517039, 0.6644203741953834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 100}], {
             RGBColor[
             0.9728133610137928, 0.9199552243524374, 0.34888547061491204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 203}], {
             RGBColor[
             0.9791389701463035, 0.9412929892800512, 0.373459267603665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 207}], {
             RGBColor[
             0.9281301475328925, 0.9256556280295261, 0.6845971704730882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 257}], {
             RGBColor[
             0.8719269237254501, 0.40543542688975187`, 0.2365598854064414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 264}], {
             RGBColor[
             0.81773100431163, 0.8389653545319763, 0.6737118704566292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 281}], {
             RGBColor[
             0.9607223514654537, 0.9515250698175975, 0.6835905466978647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 317}], {
             RGBColor[
             0.8554573026094243, 0.8684374254926999, 0.6774720752986512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 322}], {
             RGBColor[
             0.6214191503043522, 0.6702206264652628, 0.6597291007627151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 324}], {
             RGBColor[
             0.9553948778923256, 0.8534165244667236, 0.32174708625944504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 343}], {
             RGBColor[
             0.8303872175280533, 0.8488524844874292, 0.6749733235110054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 374}], {
             RGBColor[
             0.9878878150188917, 0.9694904167060485, 0.5192208246605093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 397}], {
             RGBColor[
             0.9847049379201054, 0.960068305532467, 0.3950820013600676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 445}], {
             RGBColor[
             0.7043453435392383, 0.7463972645328822, 0.664853804624099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 77}], {
             RGBColor[
             0.6321076006866722, 0.6968039577295024, 0.8501252242309918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 79}], {
             RGBColor[
             0.6516703033751012, 0.35005448694944524`, 0.4381641422738267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 87}], {
             RGBColor[
             0.6302398477337234, 0.6960315938843967, 0.8810787242510506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 127}], {
             RGBColor[
             0.34245373850225597`, 0.46754474199981005`, 0.9431697307069444]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 184}], {
             RGBColor[
             0.6184680584569546, 0.6881366770617381, 0.9406134133767244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 221}], {
             RGBColor[
             0.6171570460634691, 0.645082095099623, 0.6254324733339024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 253}], {
             RGBColor[
             0.5916076131420156, 0.667499548197144, 0.9651174512930243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 287}], {
             RGBColor[
             0.6352006564175628, 0.22346156338848927`, 0.42239278974748207`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 301}], {
             RGBColor[
             0.6318090734468441, 0.6944135219265809, 0.6902865612524987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 316}], {
             RGBColor[
             0.5677248899325718, 0.648456112989185, 0.9628394958329487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 336}], {
             RGBColor[
             0.584820596291961, 0.662087765189575, 0.9644700995670246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 354}], {
             RGBColor[
             0.6101884327731497, 0.6819617457833992, 0.9546286599871798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 388}], {
             RGBColor[
             0.2709639692526886, 0.40213069016546776`, 0.9387423692424463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 436}], {
             RGBColor[
             0.6326757073133445, 0.6962671641369006, 0.7846143093768058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 473}], {
             RGBColor[
             0.6200910299272135, 0.6893470865268854, 0.9378661460163285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 62}], {
             RGBColor[
             0.9436130322550627, 0.956651808312897, 0.952059959435284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 96}], {
             RGBColor[
             0.9886894055561475, 0.9885092269527418, 0.7633228964863923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 108}], {
             RGBColor[
             0.9277573836330724, 0.7501372877898222, 0.5643088210894661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 113}], {
             RGBColor[
             0.9851388812603973, 0.9879494170153723, 0.8881970423327341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 157}], {
             RGBColor[
             0.9840135334972776, 0.9874840567952039, 0.9068469670742821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 190}], {
             RGBColor[
             0.961012552436691, 0.8911608117244121, 0.591541471761139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 378}], {
             RGBColor[
             0.9702625876175759, 0.9773424670525076, 0.9352218617908494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 161}], {
             RGBColor[
             0.8706052903393742, 0.8053767751625005, 0.6219690116716388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 183}], {
             RGBColor[
             0.5551918624741662, 0.6420324740839319, 0.9610957411513983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 202}], {
             RGBColor[
             0.9024623022148737, 0.9203044479628641, 0.7375651774175709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 206}], {
             RGBColor[
             0.797483256438624, 0.8417192481178682, 0.9804493361632056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 243}], {
             RGBColor[
             0.8969293417523031, 0.9195217506655893, 0.9485634066683157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 273}], {
             RGBColor[
             0.8154786581908855, 0.37371867157335387`, 0.4367706978293865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 283}], {
             RGBColor[
             0.7458307374362068, 0.8013679076994957, 0.9753010957892785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 285}], {
             RGBColor[
             0.9025158559736584, 0.9204189940377894, 0.7433941735658098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 396}], {
             RGBColor[
             0.8809846913890971, 0.9076302565316791, 0.9755535407023852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 421}], {
             RGBColor[
             0.6516513136765205, 0.7254833298681407, 0.9674941433386748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 430}], {
             RGBColor[
             0.8773745434061685, 0.9049378140770857, 0.98166457956009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 477}], {
             RGBColor[
             0.7723446387104487, 0.8220807688880465, 0.9779437536818003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 44}], {
             RGBColor[
             0.7967917109445799, 0.8111267519822734, 0.6555595578527068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 56}], {
             RGBColor[
             0.7153892287591541, 0.7772603000765559, 0.9724901797999204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.798618222021491, 0.8424978390083437, 0.9442499127710349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 132}], {
             RGBColor[
             0.697542392339271, 0.7633182158243625, 0.9707113739337552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.7374679615292195, 0.7947824132206365, 0.9746180599407954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 356}], {
             RGBColor[
             0.80139047992947, 0.8445653844169587, 0.939557203253489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 365}], {
             RGBColor[
             0.7685724857248732, 0.45201900397375405`, 0.4465524026366916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 457}], {
             RGBColor[
             0.7958473573857894, 0.8079412256837122, 0.6518909226030107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 485}], {
             RGBColor[
             0.5852179730000677, 0.6741453401075237, 0.9604896490400865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 494}], {
             RGBColor[
             0.7305820371955105, 0.7892917640703738, 0.973961274330709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 108}], {
             RGBColor[
             0.8004491643178575, 0.6505879568287943, 0.5943937868407017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 113}], {
             RGBColor[
             0.8578306619451824, 0.8884000860543444, 0.9182820080839695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 119}], {
             RGBColor[
             0.5976182243145235, 0.6828923410189598, 0.9623683893360122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 315}], {
             RGBColor[
             0.8618768890150172, 0.8900733049310137, 0.8512255542368157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 364}], {
             RGBColor[
             0.8380057272164486, 0.8741024476722623, 0.9736835860882299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 378}], {
             RGBColor[
             0.842954368302361, 0.8777931360914797, 0.9653068275420849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 380}], {
             RGBColor[
             0.6595221194389314, 0.7331487118196491, 0.9672416907216452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 381}], {
             RGBColor[
             0.8508478073311907, 0.8544935573767084, 0.6619089011065716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 416}], {
             RGBColor[
             0.6481459804354983, 0.7239130496874404, 0.9663461193871247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 452}], {
             RGBColor[
             0.8008174986960448, 0.8447533133658065, 0.9806677313282569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 468}], {
             RGBColor[
             0.7965095997314673, 0.8413183116662548, 0.9802568400793087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 487}], {
             RGBColor[
             0.6007682513190457, 0.6854496748483303, 0.9626163710007374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[
             0.9676139046975074, 0.9753670836675408, 0.9397053910873816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 137}], {
             RGBColor[
             0.9745439276005757, 0.9650506997039606, 0.6670244117712316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 148}], {
             RGBColor[
             0.9217676603993111, 0.9396881476253559, 0.9657599878864065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 156}], {
             RGBColor[
             0.9800106971440173, 0.9822431861749945, 0.7944006206519609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 227}], {
             RGBColor[
             0.9238186648612579, 0.7657505073569092, 0.5833294236680016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 229}], {
             RGBColor[
             0.9174906942109513, 0.9362778108819123, 0.9653520470332679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 250}], {
             RGBColor[
             0.9096923206547558, 0.9300595994894131, 0.9646082312017877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 263}], {
             RGBColor[
             0.9675272085673081, 0.97530242583559, 0.9398521450218369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 267}], {
             RGBColor[
             0.866711304225259, 0.41401382956187605`, 0.4239088663731271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 393}], {
             RGBColor[
             0.9702296274934425, 0.9504975523967621, 0.6502641705422313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 485}], {
             RGBColor[
             0.7574423321256041, 0.8094225263763003, 0.9504798203010789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 56}], {
             RGBColor[
             0.8911337452790298, 0.8851539359107543, 0.6647394810552307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 62}], {
             RGBColor[
             0.9383062322468358, 0.9226851275003014, 0.6692608258729449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 92}], {
             RGBColor[
             0.9743627385413668, 0.9503914748425423, 0.6364992140263452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 110}], {
             RGBColor[
             0.9675799634927837, 0.9453328923170838, 0.6479806829525405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 132}], {
             RGBColor[
             0.8732869088591466, 0.8712118516585611, 0.6629606751890653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 157}], {
             RGBColor[
             0.9787067334890509, 0.9535173759826083, 0.624047833511943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 356}], {
             RGBColor[
             0.9771349964493456, 0.9524590202511571, 0.6318065045087993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 360}], {
             RGBColor[
             0.6773246995078259, 0.7122046721364279, 0.6466888752016084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 365}], {
             RGBColor[
             0.8857354967381238, 0.5239480945298864, 0.2413852701402317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 457}], {
             RGBColor[
             0.971591873905665, 0.9158348615179107, 0.3441402238583211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 494}], {
             RGBColor[
             0.9063265537153863, 0.8971853999045722, 0.6662105755860193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 118}], {
             RGBColor[
             0.9549828915491033, 0.9181070908332238, 0.6314525589186424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 152}], {
             RGBColor[
             0.8645337860296493, 0.3804966374505337, 0.20783894153515964`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 185}], {
             RGBColor[
             0.9527525165786489, 0.9164436808321628, 0.6352280019686645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 187}], {
             RGBColor[
             0.8853318857507246, 0.54035994569213, 0.22775522531615539`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 195}], {
             RGBColor[
             0.9673094639871777, 0.9273002283746299, 0.6105868870659672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 216}], {
             RGBColor[
             0.973270027094972, 0.9311832855860427, 0.5753153254496222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 217}], {
             RGBColor[
             0.8677524277258966, 0.8492976495581036, 0.636721440967938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 224}], {
             RGBColor[
             0.705033895592488, 0.7191908159782441, 0.6225228890398691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 292}], {
             RGBColor[
             0.8518540702750622, 0.8368777318855198, 0.6351368412758363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 328}], {
             RGBColor[
             0.8718198170360235, 0.43650026452467194`, 0.21481605305525872`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 398}], {
             RGBColor[
             0.9687777008842611, 0.9283952370484574, 0.6081015449767175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 399}], {
             RGBColor[
             0.9190939509667311, 0.7088522992107685, 0.2580075811615301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 464}], {
             RGBColor[
             0.7536288936854932, 0.7587025281410702, 0.6263318585143425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 481}], {
             RGBColor[
             0.803499508948307, 0.7991027810687813, 0.6303173105018525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 496}], {
             RGBColor[
             0.7630401124344155, 0.7663429794920184, 0.6270727441286879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 86}], {
             RGBColor[
             0.9786934646555847, 0.9381149932138708, 0.5141756011436224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 142}], {
             RGBColor[
             0.9643821012726796, 0.9293290952394822, 0.6244836167412497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 150}], {
             RGBColor[
             0.9402136350291203, 0.7988386273393338, 0.280311426887564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 194}], {
             RGBColor[
             0.9754367554218601, 0.9368240447168813, 0.5722026429374552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 220}], {
             RGBColor[
             0.730861867155104, 0.7443254389497538, 0.6306411600283983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 254}], {
             RGBColor[
             0.9701479715196886, 0.9109642397256092, 0.33853093574688836`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 297}], {
             RGBColor[
             0.9525213698883638, 0.8476346947467213, 0.29021451925497915`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 325}], {
             RGBColor[
             0.9350903058825193, 0.9067693254011875, 0.6493122686386887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 350}], {
             RGBColor[
             0.9753162208911403, 0.9367742005908325, 0.5742002120448493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 377}], {
             RGBColor[
             0.8656025309873914, 0.38410176514624755`, 0.21199081388043767`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 392}], {
             RGBColor[
             0.9008881860026512, 0.8794974834007927, 0.6460500399119541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 412}], {
             RGBColor[
             0.8046221202084176, 0.8041350975352859, 0.6364972266546813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 426}], {
             RGBColor[
             0.8945451634344677, 0.874439729381684, 0.6454450367569177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 476}], {
             RGBColor[
             0.9724963495720359, 0.93538068833528, 0.6107483109053361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 55}], {
             RGBColor[
             0.833537641919247, 0.38807430526959985`, 0.4385048851851192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 59}], {
             RGBColor[
             0.9293815809976231, 0.9436273402031012, 0.8781298873768169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 73}], {
             RGBColor[
             0.9303496946153251, 0.9435467007764711, 0.8271236226490692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 91}], {
             RGBColor[
             0.7004692578075487, 0.7646577418734546, 0.9718060477332893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 136}], {
             RGBColor[
             0.833537641919247, 0.38807430526959985`, 0.4385048851851192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 200}], {
             RGBColor[
             0.929926587792679, 0.9438527145188926, 0.8690977143503663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 228}], {
             RGBColor[
             0.833537641919247, 0.38807430526959985`, 0.4385048851851192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 256}], {
             RGBColor[
             0.6712137814725218, 0.74090682824049, 0.969502949469855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 298}], {
             RGBColor[
             0.8914634435088249, 0.9162927679961307, 0.9895097731323242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 416}], {
             RGBColor[
             0.7168667488891289, 0.7779699638320365, 0.9730969182972203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 452}], {
             RGBColor[
             0.8695382671496754, 0.8988102275104026, 0.9874185302383526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 468}], {
             RGBColor[
             0.8652303681850979, 0.8953752258108509, 0.9870076389894044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 117}], {
             RGBColor[
             0.6178855721544325, 0.700666368759608, 0.9630613621108768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 140}], {
             RGBColor[
             0.7665369459826776, 0.7201030273723481, 0.6112230943198979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 155}], {
             RGBColor[
             0.7572184575369396, 0.8104206405282177, 0.9766288125513681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 156}], {
             RGBColor[
             0.8001660630384241, 0.840779517387932, 0.8038105534305514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 198}], {
             RGBColor[
             0.8005310015733831, 0.8415600840132635, 0.8435318608212667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 250}], {
             RGBColor[
             0.7298476865491625, 0.7885959307023507, 0.9740181639803782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 365}], {
             RGBColor[
             0.7634923024048355, 0.44789468229489676`, 0.4461524719964135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 479}], {
             RGBColor[
             0.7724060343561934, 0.8224455384508682, 0.9751212754392999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 51}], {
             RGBColor[
             0.7216151542360718, 0.7824505100583015, 0.9728875127633803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 100}], {
             RGBColor[
             0.8471278924468666, 0.8403403691758817, 0.6451138896942391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 203}], {
             RGBColor[
             0.8534535015793774, 0.8616781341034956, 0.6696876866829921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 264}], {
             RGBColor[
             0.692045535744704, 0.7593504993554208, 0.9699402895359563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 324}], {
             RGBColor[
             0.8297094093253994, 0.7738016692901679, 0.6179755053387721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 360}], {
             RGBColor[
             0.5559425027968472, 0.647105763386264, 0.959634692836589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 397}], {
             RGBColor[
             0.8590194693531792, 0.8804534503559114, 0.6913104204393946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 457}], {
             RGBColor[
             0.8502096771946863, 0.8507359527677469, 0.6570860414933016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 82}], {
             RGBColor[
             0.5931847765800077, 0.678877202800532, 0.9622134130894401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 126}], {
             RGBColor[
             0.8650448282868574, 0.8937144810563133, 0.9044289237997178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 131}], {
             RGBColor[
             0.8319874336738515, 0.8695048835769188, 0.9836679452083712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 173}], {
             RGBColor[
             0.596005533550163, 0.6813204007127129, 0.962393149229281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 242}], {
             RGBColor[
             0.6446067701441865, 0.7208455138583401, 0.9662003064805722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 323}], {
             RGBColor[
             0.6843244425488095, 0.7530901095771645, 0.969327027142892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 340}], {
             RGBColor[
             0.5734492415269491, 0.6617832742744063, 0.9609558822473077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 373}], {
             RGBColor[
             0.8065845908522442, 0.6546113960685647, 0.5948549006186388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 414}], {
             RGBColor[
             0.8635509568359938, 0.8930967268206361, 0.9291862397559125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 449}], {
             RGBColor[
             0.8653534658967583, 0.8938421106396321, 0.8993139998751281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 499}], {
             RGBColor[
             0.7066647623764493, 0.7707711503103778, 0.9713973974221684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 60}], {
             RGBColor[
             0.7216151542360718, 0.7824505100583015, 0.9728875127633803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 96}], {
             RGBColor[
             0.8538437290305158, 0.8830715771321397, 0.7926565989444359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 100}], {
             RGBColor[
             0.8389712126404403, 0.833968308918039, 0.644300908079641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 110}], {
             RGBColor[
             0.8380410869753787, 0.8738619233090773, 0.9601135189729231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 203}], {
             RGBColor[
             0.8452968217729511, 0.8553060738456528, 0.668874705068394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 240}], {
             RGBColor[
             0.7126729937737029, 0.7754648263421622, 0.9719962417777319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 264}], {
             RGBColor[
             0.6838888559382776, 0.752978439097578, 0.9691273079213583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 324}], {
             RGBColor[
             0.8215527295189732, 0.7674296090323252, 0.617162523724174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 360}], {
             RGBColor[
             0.5477858229904209, 0.6407337031284213, 0.958821711221991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 397}], {
             RGBColor[
             0.850862789546753, 0.8740813900980686, 0.6904974388247966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 457}], {
             RGBColor[
             0.84205299738826, 0.8443638925099042, 0.6562730598787037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 495}], {
             RGBColor[
             0.6366449972076913, 0.7148069618521367, 0.9652828328069696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 170}], {
             RGBColor[
             0.9649263830555, 0.8900425878534226, 0.33547421192181154`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 214}], {
             RGBColor[
             0.5618517819684614, 0.5620792543343692, 0.603962565482123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 268}], {
             RGBColor[
             0.9696273255545256, 0.9053745350273981, 0.5078000234908935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 466}], {
             RGBColor[
             0.8715366968479757, 0.4525155829827585, 0.2121878023302584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 491}], {
             RGBColor[
             0.9212908817479744, 0.7238018063579372, 0.255431311631782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 83}], {
             RGBColor[
             0.8181938765585695, 0.8583620629011111, 0.9583849517683536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 97}], {
             RGBColor[
             0.6881443401458955, 0.7521982328426786, 0.948110536248056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 112}], {
             RGBColor[
             0.8802780526348677, 0.9068626931091296, 0.9645729222300272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 163}], {
             RGBColor[
             0.9601620075427881, 0.9698094709709129, 0.9523195092042706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 207}], {
             RGBColor[
             0.9187313482147013, 0.9373483236205009, 0.9682873325257607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 257}], {
             RGBColor[
             0.8656610575133227, 0.41323055728373503`, 0.4256866601082231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 266}], {
             RGBColor[
             0.7435854085881053, 0.7982768995747935, 0.9521796620257837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 281}], {
             RGBColor[
             0.9513235521472625, 0.9632177654085723, 0.9672807087505373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[
             0.8741310902135135, 0.902060639346923, 0.9639602504624964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 317}], {
             RGBColor[
             0.846058503291233, 0.8801301210836746, 0.9611622373513238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 322}], {
             RGBColor[
             0.6120203509861609, 0.6819133220562377, 0.9434192628153877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 343}], {
             RGBColor[
             0.8209884182098621, 0.8605451800784041, 0.958663485563678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 374}], {
             RGBColor[
             0.9784890157007003, 0.9811831122970233, 0.802910986713182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 440}], {
             RGBColor[
             0.8074373479365073, 0.8499589809889108, 0.9573128415207816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 445}], {
             RGBColor[
             0.694946544221047, 0.7580899601238571, 0.9485439666767717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 471}], {
             RGBColor[
             0.7720216700171024, 0.8213627376418322, 0.9544182686909322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 61}], {
             RGBColor[
             0.7572810460130712, 0.7634614619997657, 0.6292850856713841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 99}], {
             RGBColor[
             0.9598678947326382, 0.9235905282115523, 0.6270899403077297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 154}], {
             RGBColor[
             0.7454819891843243, 0.7538824561247364, 0.6283562206964559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 186}], {
             RGBColor[
             0.8692900678012243, 0.8523142756703963, 0.6395257440059887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 203}], {
             RGBColor[
             0.9687496459100586, 0.906247359101861, 0.3330987048051102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 244}], {
             RGBColor[
             0.9207932947903008, 0.715750904122686, 0.26156199214573034`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 264}], {
             RGBColor[
             0.8073416800753852, 0.8039197243537861, 0.6333513076580746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 295}], {
             RGBColor[
             0.8266251770988317, 0.818984138788508, 0.6352733064268463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 321}], {
             RGBColor[
             0.9575750198456201, 0.8682046392037486, 0.29150021100028545`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 341}], {
             RGBColor[
             0.9541504586152063, 0.919326473716614, 0.6367680683083794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 374}], {
             RGBColor[
             0.9774984907826467, 0.9344447865278582, 0.47886026186195463`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 391}], {
             RGBColor[
             0.9777255854318756, 0.9349305190197678, 0.503578112964798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 397}], {
             RGBColor[
             0.9743156136838604, 0.9250226753542768, 0.35472143856151284`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 455}], {
             RGBColor[
             0.8893581880168652, 0.8679916437062176, 0.6415259466818379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 57}], {
             RGBColor[
             0.7085493589986231, 0.2886390420379883, 0.4271697527905808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 60}], {
             RGBColor[
             0.7881366113474993, 0.35235885677204803`, 0.4340454981259927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 73}], {
             RGBColor[
             0.8764541544909698, 0.4197928285813809, 0.331868196580927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 91}], {
             RGBColor[
             0.7232005299524522, 0.3005335226460366, 0.4283231466370737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 136}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 200}], {
             RGBColor[
             0.8761720832758725, 0.41999683774299523`, 0.3598509243817917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 256}], {
             RGBColor[
             0.7036968790624343, 0.2846995802240602, 0.42678774779478423`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 298}], {
             RGBColor[
             0.8505299870866364, 0.40162354006115397`, 0.44012563023643037`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 434}], {
             RGBColor[
             0.8122848413532798, 0.37122363758590926`, 0.43645236801492915`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 92}], {
             RGBColor[
             0.8929602563559409, 0.9165250229368248, 0.9534298359735587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 110}], {
             RGBColor[
             0.8861774813073579, 0.9114664404113664, 0.9649113048997542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 132}], {
             RGBColor[
             0.7918844266737208, 0.8373453997528436, 0.979891297136279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 324}], {
             RGBColor[
             0.8696891238509523, 0.8050341261346143, 0.6219603096510051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 342}], {
             RGBColor[
             0.7697515485680511, 0.8200550271605905, 0.9776852986902113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 360}], {
             RGBColor[
             0.5959222173224001, 0.6783382202307104, 0.963619497148822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 457}], {
             RGBColor[
             0.8901893917202393, 0.8819684096121932, 0.6610708458055347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 494}], {
             RGBColor[
             0.8249240715299604, 0.8633189479988548, 0.9831411975332329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 60}], {
             RGBColor[
             0.6103909555191838, 0.6932428482150546, 0.9633868763748603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 73}], {
             RGBColor[
             0.7428672702343893, 0.7943938059290538, 0.8101209240572615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 91}], {
             RGBColor[
             0.5129868334266129, 0.6155048470260374, 0.9548033491414818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 131}], {
             RGBColor[
             0.7068856456517896, 0.7694559434948849, 0.972784120411357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 136}], {
             RGBColor[
             0.7085493589986231, 0.28863904203798835`, 0.4271697527905808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 234}], {
             RGBColor[
             0.7085493589986231, 0.28863904203798835`, 0.4271697527905808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 240}], {
             RGBColor[
             0.6014487950568146, 0.6862571644989153, 0.962495605389212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 434}], {
             RGBColor[
             0.6466133005278543, 0.7215400194358464, 0.9669971812082649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 495}], {
             RGBColor[
             0.525420798490803, 0.6255993000088897, 0.9557821964184496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 74}], {
             RGBColor[
             0.6262652778034079, 0.6999704952447316, 0.9641444389866063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 115}], {
             RGBColor[
             0.46816656802188217`, 0.575305928642149, 0.9523281475187606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 144}], {
             RGBColor[
             0.33387586223410404`, 0.4636082236035798, 0.9424952526000925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 145}], {
             RGBColor[
             0.6083339781062591, 0.6857731212223155, 0.9659205315610241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 215}], {
             RGBColor[
             0.42612452738081674`, 0.5411743060773848, 0.9490184440744266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 375}], {
             RGBColor[
             0.6491900152257333, 0.23790724745627245`, 0.4231989103763255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 402}], {
             RGBColor[
             0.6358065472644088, 0.7070863583863511, 0.9479935585507555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 417}], {
             RGBColor[
             0.6516440235702441, 0.7178738576907495, 0.8753251374789286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 87}], {
             RGBColor[
             0.9911519812261318, 0.9906091311003644, 0.7962980992289657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 91}], {
             RGBColor[
             0.7638759130474309, 0.8123161662677565, 0.8628572795547487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 188}], {
             RGBColor[
             0.9827935417511635, 0.9555960153332853, 0.5590051033195635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 200}], {
             RGBColor[
             0.9933332430325613, 0.9915111389131944, 0.7601489461718257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 228}], {
             RGBColor[
             0.8758087454125018, 0.41984658819913434`, 0.3658723730660921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 256}], {
             RGBColor[
             0.734620436712404, 0.7885652526347919, 0.8605541812913144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 279}], {
             RGBColor[
             0.704245612566082, 0.7628842662816928, 0.8584451619761462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 287}], {
             RGBColor[
             0.8758087454125018, 0.41984658819913434`, 0.3658723730660921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 298}], {
             RGBColor[
             0.9548700987487072, 0.9639511923904325, 0.8805610049537836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 335}], {
             RGBColor[
             0.8216725042527788, 0.8591124632992911, 0.8674930982627092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 409}], {
             RGBColor[
             0.7441197567657654, 0.7962772285936024, 0.8613020025630711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 468}], {
             RGBColor[
             0.9286370234249801, 0.9430336502051526, 0.8780588708108638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 73}], {
             RGBColor[
             0.8622481487577037, 0.8899735280301435, 0.8204345420603796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 131}], {
             RGBColor[
             0.8262665241751039, 0.8650356655959746, 0.983097738414475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.7881366113474993, 0.3523588567720481, 0.4340454981259928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 240}], {
             RGBColor[
             0.7208296735801291, 0.7818368866000049, 0.9728092233923299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 434}], {
             RGBColor[
             0.7659941790511687, 0.817119741536936, 0.977310799211383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 495}], {
             RGBColor[
             0.6448016770141175, 0.7211790221099794, 0.9660958144215677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 99}], {
             RGBColor[
             0.7567848180418488, 0.809090969898443, 0.9558524953568993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 154}], {
             RGBColor[
             0.5423989124935349, 0.639382897811627, 0.9571187757456254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 178}], {
             RGBColor[
             0.744015279747535, 0.4164486328599989, 0.44262048698494116`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 186}], {
             RGBColor[
             0.6662069911104349, 0.7378147173572871, 0.9682882990551582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 203}], {
             RGBColor[
             0.7656665692192692, 0.7917478007887517, 0.6618612598542798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 244}], {
             RGBColor[
             0.7177102180995114, 0.6012513458095767, 0.5903245471948999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 264}], {
             RGBColor[
             0.6042586033845958, 0.6894201660406769, 0.9621138627072441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 288}], {
             RGBColor[
             0.5660840515574544, 0.6586115607070723, 0.9589833566542604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 295}], {
             RGBColor[
             0.6235421004080423, 0.7044845804753987, 0.9640358614760158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 321}], {
             RGBColor[
             0.7544919431548307, 0.7537050808906393, 0.620262766049455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 341}], {
             RGBColor[
             0.7510673819244169, 0.8048269154035048, 0.965530623357549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 391}], {
             RGBColor[
             0.7746425087410862, 0.8204309607066584, 0.8323406680139676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 397}], {
             RGBColor[
             0.771232536993071, 0.8105231170411675, 0.6834839936106823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 455}], {
             RGBColor[
             0.6862751113260758, 0.7534920853931083, 0.9702885017310074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 96}], {
             RGBColor[
             0.949152610330301, 0.9582072858239759, 0.8019757296889811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 108}], {
             RGBColor[
             0.8882205884072258, 0.7198353466610563, 0.602961654292055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 110}], {
             RGBColor[
             0.9333499682751639, 0.9489976320009135, 0.9694326497174683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 157}], {
             RGBColor[
             0.9444767382714311, 0.957182115666438, 0.945499800276871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 190}], {
             RGBColor[
             0.9214757572108445, 0.860858870595646, 0.6301943049637279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 356}], {
             RGBColor[
             0.9429050012317259, 0.9561237599349868, 0.9532584712737271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 378}], {
             RGBColor[
             0.9307257923917294, 0.9470405259237415, 0.9738746949934383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 72}], {
             RGBColor[
             0.7853538733038754, 0.8321769861100008, 0.9552147751142779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 159}], {
             RGBColor[
             0.7991341716131566, 0.8414575802278272, 0.8872527277582646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 166}], {
             RGBColor[
             0.6751702946192855, 0.7456422742858391, 0.9686173769062305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 222}], {
             RGBColor[
             0.782348628874069, 0.779017867635091, 0.6241339984489624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 239}], {
             RGBColor[
             0.7475716246919596, 0.3203190752608751, 0.43024172848922937`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 272}], {
             RGBColor[
             0.7760561870069564, 0.7542648313203539, 0.6180585194717101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 344}], {
             RGBColor[
             0.6781286876996748, 0.7479533934448592, 0.9689122418807286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 387}], {
             RGBColor[
             0.5517640756849522, 0.6469859591862135, 0.957856035697777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 435}], {
             RGBColor[
             0.783455723582922, 0.8307613491560486, 0.9584278474751171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 439}], {
             RGBColor[
             0.6445720038448978, 0.7217386569772644, 0.9655676252391242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 453}], {
             RGBColor[
             0.7989764061179663, 0.8413923401411777, 0.8898673102975829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 74}], {
             RGBColor[
             0.9430178034194723, 0.9570233516068016, 0.9813401748604789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 115}], {
             RGBColor[
             0.7849190936379464, 0.832358785004219, 0.969523883392633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 170}], {
             RGBColor[
             0.9657566495417029, 0.960447061065532, 0.6860382478780492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 215}], {
             RGBColor[
             0.7428770529968811, 0.7982271624394548, 0.9662141799482991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 223}], {
             RGBColor[
             0.949294389607205, 0.9617044193086461, 0.9707155516405042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 268}], {
             RGBColor[
             0.9704575920407286, 0.9757790082395075, 0.8583640594471312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 86}], {
             RGBColor[
             0.9380632273587319, 0.7721483182649174, 0.4715773743195003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 177}], {
             RGBColor[
             0.8217356328278451, 0.6832782788896845, 0.5996543571761909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 194}], {
             RGBColor[
             0.9348065181250075, 0.770857369767928, 0.5296044161133331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 290}], {
             RGBColor[
             0.6467008643305748, 0.5419100224600528, 0.5849223151306966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 297}], {
             RGBColor[
             0.9118911325915111, 0.6816680197977678, 0.2476162924308571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 350}], {
             RGBColor[
             0.9346859835942876, 0.7708075256418792, 0.5316019852207272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 412}], {
             RGBColor[
             0.7639918829115648, 0.6381684225863326, 0.5938989998305592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 484}], {
             RGBColor[
             0.9050468710001192, 0.6545328033028718, 0.24210923889895541`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 114}], {
             RGBColor[
             0.8625330528015756, 0.8906658037910402, 0.8549139018549716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 128}], {
             RGBColor[
             0.8049325299498129, 0.6676620197605196, 0.5974930332454481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 179}], {
             RGBColor[
             0.5795548093069096, 0.6675359603718907, 0.9611483886312412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 245}], {
             RGBColor[
             0.8087340969564778, 0.6849240476592527, 0.6006651539407437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 255}], {
             RGBColor[
             0.7883061080959134, 0.35249126892013216`, 0.43406239197783747`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 260}], {
             RGBColor[
             0.8574044321377958, 0.8743465403235833, 0.6840739523183638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 294}], {
             RGBColor[
             0.8623362123658999, 0.8905844052123197, 0.858176057280837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 299}], {
             RGBColor[
             0.7883061080959134, 0.35249126892013216`, 0.43406239197783747`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 312}], {
             RGBColor[
             0.8171782806584782, 0.8577848369722637, 0.9822319842856926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 327}], {
             RGBColor[
             0.8592505465571951, 0.8893084031024262, 0.9093135251782081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 334}], {
             RGBColor[
             0.8601317236312649, 0.8896727924677719, 0.8947101406477052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 385}], {
             RGBColor[
             0.8333837299349074, 0.8706862984935271, 0.9830730339858706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 415}], {
             RGBColor[
             0.8206722988641921, 0.7371631587831204, 0.6105248033176447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 446}], {
             RGBColor[
             0.850909358653855, 0.8837568836965348, 0.9534067159807248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 119}], {
             RGBColor[
             0.5438751271016359, 0.6405813553331936, 0.9572349887671274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 120}], {
             RGBColor[
             0.8072116467941433, 0.8457367934875555, 0.7418588562049426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 124}], {
             RGBColor[
             0.47806693171236925`, 0.583945039857693, 0.9529413303669698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 363}], {
             RGBColor[
             0.5994713509961709, 0.6857168744721216, 0.9616117271677838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 381}], {
             RGBColor[
             0.7971047101183031, 0.8121825716909422, 0.6567755005376869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 95}], {
             RGBColor[
             0.6509262856265654, 0.7092653493336275, 0.6753758318948555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 286}], {
             RGBColor[
             0.6030257752884232, 0.6815573141809415, 0.9654064919641016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 319}], {
             RGBColor[
             0.509516748904584, 0.607920175975244, 0.9562422045885497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 330}], {
             RGBColor[
             0.5863785773857515, 0.6682832904495004, 0.9638186673670157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 352}], {
             RGBColor[
             0.6543191015992325, 0.7190349128441849, 0.8310033195138787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 357}], {
             RGBColor[
             0.6327798005206056, 0.7048584307709889, 0.9535463482822939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 367}], {
             RGBColor[
             0.6566847068866923, 0.2944034312897926, 0.4302301860903166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 368}], {
             RGBColor[
             0.5117587894741561, 0.6096716751083331, 0.9564656702394643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 375}], {
             RGBColor[
             0.6493529556164899, 0.2380483782331236, 0.4232092927939419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 450}], {
             RGBColor[
             0.562609420711063, 0.6493965747097161, 0.9615339859349925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 492}], {
             RGBColor[
             0.6001014523638235, 0.679225538459497, 0.9651275674329793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 101}], {
             RGBColor[
             0.8470348162104286, 0.7013413757518632, 0.6018435420532529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 103}], {
             RGBColor[
             0.922311342836477, 0.7201605253349532, 0.26931722848776385`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 129}], {
             RGBColor[
             0.6564862058811565, 0.5487232036748527, 0.585197162743536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 204}], {
             RGBColor[
             0.9296815046673348, 0.7660679000584438, 0.5707047707474078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 209}], {
             RGBColor[
             0.8617126425361914, 0.7129972374800773, 0.6032562211154957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 231}], {
             RGBColor[
             0.8382141073541229, 0.2720878256117942, 0.18334033459222407`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 233}], {
             RGBColor[
             0.9370700024970195, 0.7699262226343115, 0.4842177220861868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 259}], {
             RGBColor[
             0.9221488866598662, 0.7604500858820038, 0.5834555282126308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 275}], {
             RGBColor[
             0.9337072028354412, 0.7685356185542396, 0.5399480151250937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 306}], {
             RGBColor[
             0.9345935008349446, 0.768902125553854, 0.5252597636076248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 331}], {
             RGBColor[
             0.9198310859267613, 0.7117940363864655, 0.25968189875073433`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 346}], {
             RGBColor[
             0.7109454765849768, 0.5934882407699409, 0.5893317254275237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 348}], {
             RGBColor[
             0.8382141073541229, 0.2720878256117942, 0.18334033459222407`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 355}], {
             RGBColor[
             0.8048880780524335, 0.6684160235757634, 0.5976427490773253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 372}], {
             RGBColor[
             0.8382141073541229, 0.2720878256117942, 0.18334033459222407`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 404}], {
             RGBColor[
             0.8382141073541229, 0.2720878256117942, 0.18334033459222407`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 418}], {
             RGBColor[
             0.7669194921303113, 0.6387546756814608, 0.5938583952692169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 431}], {
             RGBColor[
             0.9005039828326704, 0.6362611391180473, 0.23844044250903082`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 444}], {
             RGBColor[
             0.9122060996420627, 0.7530347716039455, 0.6002860731395978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 486}], {
             RGBColor[
             0.8006272936463226, 0.6650874664145487, 0.5972180739070181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 76}], {
             RGBColor[
             0.8366503372383217, 0.8732512906734409, 0.9840614212088977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 111}], {
             RGBColor[
             0.9006255408559153, 0.9235971232365492, 0.9903402376928587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 130}], {
             RGBColor[
             0.9643570019918202, 0.9694827309534158, 0.7347323583699461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 175}], {
             RGBColor[
             0.7828560349042943, 0.8310369049037863, 0.9788295216323413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 182}], {
             RGBColor[
             0.8845970850998284, 0.9108164676974866, 0.9888114292740717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 208}], {
             RGBColor[
             0.9647592661409652, 0.9703431332932926, 0.7785163285178192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[
             0.958541874213522, 0.968601178186671, 0.9550619723322713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 351}], {
             RGBColor[
             0.9039509455191048, 0.9262487106492716, 0.9906574177582574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 359}], {
             RGBColor[
             0.9001166902883846, 0.923191379606381, 0.9902917030714713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 371}], {
             RGBColor[
             0.7630627664295345, 0.814967837879393, 0.9772713230328767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 403}], {
             RGBColor[
             0.741873728606347, 0.7977656224192535, 0.9756032443574324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 442}], {
             RGBColor[
             0.8567951899881048, 0.4066184077999533, 0.44069426123983046`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 463}], {
             RGBColor[
             0.9516898794230078, 0.9634909716910173, 0.9666606122261561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 483}], {
             RGBColor[
             0.7767982509419263, 0.8261189229830784, 0.9783526306884298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 135}], {
             RGBColor[
             0.9767696799453613, 0.9321135020972446, 0.4652157198612545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 153}], {
             RGBColor[
             0.9577973011623868, 0.9204020665627219, 0.6271045549809979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 169}], {
             RGBColor[
             0.9598029177630427, 0.8760679442703097, 0.2983423554017972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 172}], {
             RGBColor[
             0.9170730961534257, 0.6995889774523801, 0.25654887399247495`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 197}], {
             RGBColor[
             0.8332766354400878, 0.8225582508943535, 0.6335675687816857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 201}], {
             RGBColor[
             0.9378959793448645, 0.7905539118767665, 0.273738450754895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 211}], {
             RGBColor[
             0.9472557959368149, 0.8276624656898655, 0.2812695788879108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 236}], {
             RGBColor[
             0.9608207349743608, 0.9226569385492737, 0.621986670175156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 289}], {
             RGBColor[
             0.9734875882267364, 0.9314940322358494, 0.5732357943547636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 308}], {
             RGBColor[
             0.8867573329086063, 0.8643377782251154, 0.6388980248998146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 362}], {
             RGBColor[
             0.8993596635760123, 0.8743414183416067, 0.6401120189217018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 369}], {
             RGBColor[
             0.8641197295800351, 0.846653110452678, 0.6366417201604535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 466}], {
             RGBColor[
             0.8763153582386336, 0.4708404685333026, 0.21926655856244595`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 470}], {
             RGBColor[
             0.9725948344220984, 0.9311248555949052, 0.588031035270401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 493}], {
             RGBColor[
             0.9770388444179607, 0.9329625679340419, 0.5143822889097569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 128}], {
             RGBColor[
             0.9211078040718788, 0.7588774895990095, 0.5846876276591257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 159}], {
             RGBColor[
             0.9764111708411531, 0.9809313405552027, 0.8801783174048544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 179}], {
             RGBColor[
             0.6957300834289755, 0.7587514302103805, 0.9483429830449188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 222}], {
             RGBColor[
             0.9596256281020655, 0.9184916279624664, 0.6170595880955523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 245}], {
             RGBColor[
             0.9249093710785437, 0.7761395174977426, 0.5878597483544213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 294}], {
             RGBColor[
             0.9785114864879657, 0.9817998750508097, 0.8453706516945146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 344}], {
             RGBColor[
             0.8554056869276714, 0.8874271537722347, 0.9618378315273184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 438}], {
             RGBColor[
             0.9674168758800878, 0.9752201398981144, 0.9400389094819274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 439}], {
             RGBColor[
             0.8218490030728943, 0.8612124173046397, 0.958493214885714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 453}], {
             RGBColor[
             0.9762534053459628, 0.980866100468553, 0.8827928999441728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 91}], {
             RGBColor[
             0.7648440266651328, 0.8122355268411263, 0.8118510148270011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 136}], {
             RGBColor[
             0.8764541544909698, 0.419792828581381, 0.331868196580927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 200}], {
             RGBColor[
             0.9943013566502633, 0.9914304994865644, 0.709142681444078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 240}], {
             RGBColor[
             0.8533059882953347, 0.8829878443140042, 0.8195432710747312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 256}], {
             RGBColor[
             0.735588550330106, 0.7884846132081618, 0.8095479165635668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 298}], {
             RGBColor[
             0.9558382123664092, 0.9638705529638023, 0.8295547402260359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 434}], {
             RGBColor[
             0.8984704937663743, 0.9182706992509353, 0.8240448468937842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 115}], {
             RGBColor[
             0.7814998001480901, 0.8298086815180634, 0.9753118553763905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 144}], {
             RGBColor[
             0.6472090943603119, 0.7181109764794942, 0.9654789604577225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 215}], {
             RGBColor[
             0.7394577595070246, 0.7956770589532991, 0.9720021519320565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 268}], {
             RGBColor[
             0.9670382985508721, 0.9732289047533519, 0.8641520314308888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 402}], {
             RGBColor[
             0.9491397793906167, 0.9615891112622655, 0.9709772664083856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 417}], {
             RGBColor[
             0.964977255696452, 0.9723766105666638, 0.8983088453365586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 104}], {
             RGBColor[
             0.9561211659599109, 0.8540504439818918, 0.3340264448083302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 125}], {
             RGBColor[
             0.9205364950243279, 0.7226607129544234, 0.2549200025296258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 147}], {
             RGBColor[
             0.9085176262282338, 0.8261867204477817, 0.6235080338318886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 303}], {
             RGBColor[
             0.8527146290178486, 0.33422912095301194`, 0.19524841501897455`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 310}], {
             RGBColor[
             0.9056838221376791, 0.6590608088014229, 0.24272534266699788`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 323}], {
             RGBColor[
             0.7754705595555856, 0.721426287867666, 0.6105611956884682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 379}], {
             RGBColor[
             0.9199289251261672, 0.8352857804375369, 0.6245964537077602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 400}], {
             RGBColor[
             0.8527146290178486, 0.33422912095301194`, 0.19524841501897455`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 408}], {
             RGBColor[
             0.9113806845237596, 0.6849289303606003, 0.2474789442848188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 111}], {
             RGBColor[
             0.8015283081299227, 0.8452471905101304, 0.980754875182265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 130}], {
             RGBColor[
             0.8652597692658276, 0.891132798226997, 0.7251469958593525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 175}], {
             RGBColor[
             0.6837588021783018, 0.7526869721773676, 0.9692441591217477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.7854998523738358, 0.8324665349710678, 0.9792260667634781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 351}], {
             RGBColor[
             0.8048537127931122, 0.8478987779228528, 0.9810720552476638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 359}], {
             RGBColor[
             0.8010194575623921, 0.8448414468799622, 0.9807063405608777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 371}], {
             RGBColor[
             0.6639655337035419, 0.7366179051529742, 0.9676859605222832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 460}], {
             RGBColor[
             0.8176324365572626, 0.5611662054957425, 0.4600654706345412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 463}], {
             RGBColor[
             0.8525926466970152, 0.8851410389645985, 0.9570752497155623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 483}], {
             RGBColor[
             0.6777010182159338, 0.7477689902566597, 0.9687672681778362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 87}], {
             RGBColor[
             0.991383479167707, 0.9907048614484315, 0.7924615792395961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 184}], {
             RGBColor[
             0.9796116898909382, 0.9828099446257728, 0.85199626836527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 253}], {
             RGBColor[
             0.9527512445759991, 0.9621728157611786, 0.8765003062815697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 287}], {
             RGBColor[
             0.875963077373552, 0.4199104084311791, 0.3633146930731791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 301}], {
             RGBColor[
             0.9929527048808278, 0.9890867894906157, 0.6016694162410441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 336}], {
             RGBColor[
             0.9459642277259446, 0.9567610327536098, 0.87585295455557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 354}], {
             RGBColor[
             0.9713320642071333, 0.976635013347434, 0.8660115149757253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 388}], {
             RGBColor[
             0.6321076006866722, 0.6968039577295024, 0.8501252242309918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 409}], {
             RGBColor[
             0.7443512547073406, 0.7963729589416695, 0.8574654825737016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 436}], {
             RGBColor[
             0.9938193387473282, 0.9909404317009354, 0.6959971643653513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 473}], {
             RGBColor[
             0.9812346613611972, 0.9840203540909201, 0.8492490010048739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 154}], {
             RGBColor[
             0.7062941904415465, 0.593411585940333, 0.5897152911489764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 171}], {
             RGBColor[
             0.9380056985732319, 0.773321566157888, 0.4070226756725198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 192}], {
             RGBColor[
             0.9193965156935616, 0.7114864389232682, 0.254967382044004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.9386036615564017, 0.7746550721246118, 0.47607054698861184`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 219}], {
             RGBColor[
             0.8504059992331743, 0.7077048338125551, 0.6029085005331798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 258}], {
             RGBColor[
             0.7769389486350462, 0.6503118155150325, 0.5955859915181805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 262}], {
             RGBColor[
             0.8388755084061017, 0.27509109331468956`, 0.1838922238424185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 376}], {
             RGBColor[
             0.776482588874811, 0.6499553038018742, 0.5955405058422046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 497}], {
             RGBColor[
             0.9373698005516882, 0.7741448388903813, 0.4965188169666367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 127}], {
             RGBColor[
             0.6993301495414795, 0.3936638548390068, 0.44111571658349213`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 147}], {
             RGBColor[
             0.8591921020918458, 0.5219909495731319, 0.4551522933952957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 184}], {
             RGBColor[
             0.8833396961779453, 0.5407251448802921, 0.43941150503001214`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 221}], {
             RGBColor[
             0.8824656879156216, 0.5120220902388821, 0.22929087833479744`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 234}], {
             RGBColor[
             0.8337886469575384, 0.260719923560956, 0.1799893525263446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 253}], {
             RGBColor[
             0.8654327326346526, 0.5269670589705626, 0.45574753030754533`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 301}], {
             RGBColor[
             0.892233706171205, 0.5449097081235207, 0.27252693694719493`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 316}], {
             RGBColor[
             0.8495109171616901, 0.5142714354985901, 0.45422889333416167`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 336}], {
             RGBColor[
             0.8609080547346162, 0.5233592036321835, 0.4553159624902122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 388}], {
             RGBColor[
             0.6516703033751013, 0.35005448694944524`, 0.43816414227382666`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 436}], {
             RGBColor[
             0.8928114620822053, 0.5461454695970671, 0.3354121023633997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 81}], {
             RGBColor[
             0.7360912409506213, 0.7882184147419713, 0.7543215385570621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 171}], {
             RGBColor[
             0.7362485672604802, 0.7885549198106294, 0.7714455364797579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 192}], {
             RGBColor[
             0.71763938438081, 0.7267197925760098, 0.6193902428512421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 208}], {
             RGBColor[
             0.7361226124552089, 0.7882855152181385, 0.7577361332289393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 219}], {
             RGBColor[
             0.6486488679204226, 0.7229381874652965, 0.9673313613404179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 238}], {
             RGBColor[
             0.7299052205277659, 0.7865435601115169, 0.9342817770433913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 251}], {
             RGBColor[
             0.6864012674560351, 0.6002685883789682, 0.5928118260624553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 258}], {
             RGBColor[
             0.5751818173222946, 0.6655451691677741, 0.9600088523254184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 272}], {
             RGBColor[
             0.7112548812654179, 0.701656212053817, 0.6129571233087319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 293}], {
             RGBColor[
             0.6321956352399305, 0.7100847970460963, 0.9656914568710276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 403}], {
             RGBColor[
             0.5132370749205908, 0.6157080043440994, 0.9548230490685525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 447}], {
             RGBColor[
             0.4646358383265672, 0.5761828911984723, 0.9510158918172613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 471}], {
             RGBColor[
             0.5300862150435194, 0.6293868953410054, 0.9561494750994634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 483}], {
             RGBColor[
             0.5481615972561701, 0.6440613049079245, 0.95757243539955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 497}], {
             RGBColor[
             0.7356126692389366, 0.7893781925431228, 0.8609416777738748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 121}], {
             RGBColor[
             0.7476681061720286, 0.7976170354605446, 0.7552329117947458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.9933373266638834, 0.9881575403706815, 0.5161873084963967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 208}], {
             RGBColor[
             0.9937395908130285, 0.9890179427105583, 0.5599712786442698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 213}], {
             RGBColor[
             0.9893492432838836, 0.9885059731303277, 0.7274851648179543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 251}], {
             RGBColor[
             0.9440182458138546, 0.801001015871388, 0.3950469714777858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 442}], {
             RGBColor[
             0.8761154064361469, 0.4190682807447971, 0.29499756132413085`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 447}], {
             RGBColor[
             0.7222528166843867, 0.7769153186908921, 0.7532510372325918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 454}], {
             RGBColor[
             0.949309017986139, 0.9579826915961261, 0.7736744920899804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 500}], {
             RGBColor[
             0.8594736706496782, 0.8871162117229757, 0.7649026999868358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 126}], {
             RGBColor[
             0.7170159518268717, 0.7748306775788125, 0.8918014289233871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 149}], {
             RGBColor[
             0.689224206989437, 0.754819766298203, 0.9715426927083355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 173}], {
             RGBColor[
             0.4479766570901773, 0.5624365972352121, 0.9497656543529502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 242}], {
             RGBColor[
             0.4965778936842009, 0.6019617103808393, 0.9535728116042415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 249}], {
             RGBColor[
             0.6857590428543079, 0.7520567384762258, 0.9712121822597384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 269}], {
             RGBColor[
             0.676859777626816, 0.7449607059479433, 0.9703633623978724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 282}], {
             RGBColor[
             0.7127308674769384, 0.7724130518525658, 0.9339035910825946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 323}], {
             RGBColor[
             0.5362955660888238, 0.6342063060996638, 0.9566995322665612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 384}], {
             RGBColor[
             0.6972843982068164, 0.7608931003621809, 0.9600504344725114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 411}], {
             RGBColor[
             0.7063972736166895, 0.3770256941110381, 0.4385831371992629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 419}], {
             RGBColor[
             0.7186003020692073, 0.7754858471199624, 0.8655446452408935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 499}], {
             RGBColor[
             0.5586358859164637, 0.6518873468328772, 0.9587699025458376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 97}], {
             RGBColor[
             0.5439930441644971, 0.6391226238925847, 0.9578715076917402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 163}], {
             RGBColor[
             0.8160107115613896, 0.8567338620208189, 0.9620804806479548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 207}], {
             RGBColor[
             0.7745800522333027, 0.824272714670407, 0.978048303969445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 209}], {
             RGBColor[
             0.7587317717935925, 0.8116357260378945, 0.9765366808331785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 231}], {
             RGBColor[
             0.7695601935257237, 0.33784681798367233`, 0.43219397440401264`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 233}], {
             RGBColor[
             0.8340891317544206, 0.8685647111921289, 0.8574981818038696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 257}], {
             RGBColor[
             0.7695601935257237, 0.33784681798367233`, 0.43219397440401264`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 317}], {
             RGBColor[
             0.7019072073098345, 0.7670545121335806, 0.970923208795008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 326}], {
             RGBColor[
             0.7536012809348125, 0.8075448118905677, 0.9760473300350248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 343}], {
             RGBColor[
             0.6768371222284636, 0.74746957112831, 0.9684244570073621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 346}], {
             RGBColor[
             0.6079646058423779, 0.6921267293277582, 0.9626121851452064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 355}], {
             RGBColor[
             0.7019072073098345, 0.7670545121335806, 0.970923208795008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 395}], {
             RGBColor[
             0.4364661327177662, 0.5358312507222394, 0.9513918842912878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 440}], {
             RGBColor[
             0.6632860519551089, 0.7368833720388167, 0.9670738129644658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 89}], {
             RGBColor[
             0.6962866311418343, 0.7615172218822233, 0.9711831321197787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 176}], {
             RGBColor[
             0.9102523775391274, 0.928950228454877, 0.9013170549615845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 244}], {
             RGBColor[
             0.855970079305298, 0.7106982711813863, 0.6031586213844504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 245}], {
             RGBColor[
             0.8589527806795352, 0.7242420214941923, 0.6056474605238149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 260}], {
             RGBColor[
             0.9076231158608532, 0.9136645141585227, 0.689056258901435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 261}], {
             RGBColor[
             0.9040253370689244, 0.9252356551688924, 0.953484658385698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 262}], {
             RGBColor[
             0.8217852305779516, 0.3787032514767585, 0.43738392969988493`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 299}], {
             RGBColor[
             0.8217852305779516, 0.3787032514767585, 0.43738392969988493`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 328}], {
             RGBColor[
             0.829071261584326, 0.4347068785508967, 0.4443610412199841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 376}], {
             RGBColor[
             0.7508471721325859, 0.8053735410449776, 0.9757780646284042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 391}], {
             RGBColor[
             0.9129023699468728, 0.929877886078468, 0.8451747422035181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 407}], {
             RGBColor[
             0.8044124239072457, 0.8472191228423334, 0.9811169483295645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 448}], {
             RGBColor[
             0.9119485800993821, 0.9278378260376317, 0.7413606034127984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 455}], {
             RGBColor[
             0.8245349725318623, 0.8629390107649177, 0.983122575920558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 475}], {
             RGBColor[
             0.8736051120791467, 0.9020530192655982, 0.9878064295382409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 478}], {
             RGBColor[
             0.8542805244833622, 0.7030263973405301, 0.6017488154262489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 482}], {
             RGBColor[
             0.8941095901264821, 0.9178405073347643, 0.97026943151826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 146}], {
             RGBColor[
             0.86805563499882, 0.8977014612072487, 0.9872576255935426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 166}], {
             RGBColor[
             0.7765805127993325, 0.825389865920118, 0.9783659460244862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 239}], {
             RGBColor[
             0.815178436811991, 0.37348413635039446`, 0.4367407745680666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 332}], {
             RGBColor[
             0.8361163387997534, 0.8722339333872127, 0.9842112270095293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 387}], {
             RGBColor[
             0.6531742938649991, 0.7267335508204925, 0.9676046048160327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 489}], {
             RGBColor[
             0.8544658224045869, 0.8868653135302432, 0.9859614171365358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 177}], {
             RGBColor[
             0.8788897418181085, 0.9033086516137661, 0.8488917435026224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 194}], {
             RGBColor[
             0.9919606271152708, 0.9908877424920095, 0.7788418024397645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 220}], {
             RGBColor[
             0.7473857388485146, 0.7983891367248819, 0.8372803195307077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 254}], {
             RGBColor[
             0.9866718432130991, 0.9650279375007375, 0.5451700952491978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 290}], {
             RGBColor[
             0.7038549733208381, 0.7619403951841344, 0.834159701457128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 297}], {
             RGBColor[
             0.9690452415817743, 0.9016983925218494, 0.49685367875728853`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 350}], {
             RGBColor[
             0.991840092584551, 0.9908378983659607, 0.7808393715471587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 377}], {
             RGBColor[
             0.876618445449665, 0.4201442303296663, 0.3497502535486439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 412}], {
             RGBColor[
             0.8211459919018281, 0.8581987953104141, 0.8431363861569907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 426}], {
             RGBColor[
             0.9110690351278782, 0.9285034271568122, 0.852084196259227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 476}], {
             RGBColor[
             0.9890202212654464, 0.9894443861104081, 0.8173874704076455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 91}], {
             RGBColor[
             0.7622396580360573, 0.8116395327707178, 0.8899742595854381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 161}], {
             RGBColor[
             0.9594641661604251, 0.8738920166041326, 0.5427385045573866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 184}], {
             RGBColor[
             0.9777439369379894, 0.982037580780667, 0.8829497683853288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 228}], {
             RGBColor[
             0.8747179087382527, 0.41939549920110863`, 0.38395035975321834`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 253}], {
             RGBColor[
             0.9508834916230504, 0.9614004519160728, 0.9074538063016286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 256}], {
             RGBColor[
             0.7329841817010304, 0.7878886191377532, 0.8876711613220039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 285}], {
             RGBColor[
             0.9913747317947094, 0.9889342354794214, 0.6641636664515577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 287}], {
             RGBColor[
             0.8747179087382527, 0.41939549920110863`, 0.38395035975321834`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 336}], {
             RGBColor[
             0.9440964747729959, 0.955988668908504, 0.9068064545756289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 354}], {
             RGBColor[
             0.9694643112541845, 0.9758626495023281, 0.8969650149957842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 388}], {
             RGBColor[
             0.6302398477337234, 0.6960315938843967, 0.8810787242510506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 409}], {
             RGBColor[
             0.7424835017543918, 0.7956005950965637, 0.8884189825937604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 436}], {
             RGBColor[
             0.9919515857943794, 0.9901680678558296, 0.7269506643854101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 473}], {
             RGBColor[
             0.9793669084082484, 0.9832479902458144, 0.8802025010249328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 133}], {
             RGBColor[
             0.8249687178198697, 0.19292608329124133`, 0.17154337842342776`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 241}], {
             RGBColor[
             0.6876798398098808, 0.2712451989562277, 0.42565144796361176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 271}], {
             RGBColor[
             0.8670612744636644, 0.3890224494209729, 0.21765775682516778`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 304}], {
             RGBColor[
             0.8714116780481608, 0.40369738223481644`, 0.23455825324615384`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 307}], {
             RGBColor[
             0.8611425802212584, 0.409860684317641, 0.4333352635560688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 311}], {
             RGBColor[
             0.8679367281385428, 0.41492774870995547`, 0.4218345433296814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 337}], {
             RGBColor[
             0.8764095923605619, 0.4196975146903611, 0.327017883691627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 423}], {
             RGBColor[
             0.8672328807022635, 0.3896013175588282, 0.2183244146570058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 427}], {
             RGBColor[
             0.8764931836219652, 0.4198763079461296, 0.3361162766299012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 433}], {
             RGBColor[
             0.8378217489284411, 0.27030621763841134`, 0.18301294110425004`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 465}], {
             RGBColor[
             0.8542090339238055, 0.40455711214404666`, 0.4404765410080834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 469}], {
             RGBColor[
             0.8662615638026775, 0.41367841389109705`, 0.42467015959746923`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 176}], {
             RGBColor[
             0.7758213169471068, 0.8226116959068248, 0.8887843979817083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 178}], {
             RGBColor[
             0.7465678134900458, 0.41852089474250376`, 0.4428214317913908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 244}], {
             RGBColor[
             0.7215390187132774, 0.6043597386333341, 0.5906259644045744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 261}], {
             RGBColor[
             0.7695942764769039, 0.8188971226208402, 0.9409520014058218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 262}], {
             RGBColor[
             0.7321645235166045, 0.3078108964447237, 0.4290288250466342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 299}], {
             RGBColor[
             0.7321645235166045, 0.3078108964447237, 0.4290288250466342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 328}], {
             RGBColor[
             0.7394505545229789, 0.36381452351886195`, 0.43600593656673325`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 376}], {
             RGBColor[
             0.6164161115405653, 0.6990350084969255, 0.9632454076485282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 391}], {
             RGBColor[
             0.7784713093548522, 0.8235393535304159, 0.832642085223642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 407}], {
             RGBColor[
             0.6699813633152252, 0.7408805902942812, 0.9685842913496883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 448}], {
             RGBColor[
             0.7775175195073616, 0.8214992934895795, 0.7288279464329221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 455}], {
             RGBColor[
             0.6901039119398418, 0.7566004782168656, 0.9705899189406818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 475}], {
             RGBColor[
             0.7391740514871261, 0.7957144867175461, 0.9752737725583647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 478}], {
             RGBColor[
             0.7198494638913416, 0.5966878647924779, 0.5892161584463727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 482}], {
             RGBColor[
             0.7596785295344615, 0.8115019747867122, 0.9577367745383838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 137}], {
             RGBColor[
             0.9766619196223061, 0.9666302946858736, 0.6634392037392319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 148}], {
             RGBColor[
             0.9238856524210415, 0.9412677426072689, 0.9621747798544067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 229}], {
             RGBColor[
             0.9196086862326818, 0.9378574058638252, 0.9617668390012681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 232}], {
             RGBColor[
             0.8962186364725392, 0.6288033055241955, 0.4483360556900343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 263}], {
             RGBColor[
             0.9696452005890386, 0.976882020817503, 0.9362669369898371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 267}], {
             RGBColor[
             0.8681232989064126, 0.41506689288315124`, 0.4215187276851273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 280}], {
             RGBColor[
             0.9076538704828214, 0.9283249602897155, 0.9606265780028564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 342}], {
             RGBColor[
             0.849751865380868, 0.882884624482799, 0.95491033871668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 393}], {
             RGBColor[
             0.9723476195151729, 0.9520771473786751, 0.6466789625102316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 480}], {
             RGBColor[
             0.97466446543186, 0.9598924126769516, 0.6556794713969216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 485}], {
             RGBColor[
             0.7595603241473345, 0.8110021213582133, 0.9468946122690791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 200}], {
             RGBColor[
             0.764420919842487, 0.8125415405835479, 0.8538251065282982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 228}], {
             RGBColor[
             0.7232005299524522, 0.3005335226460366, 0.4283231466370737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 256}], {
             RGBColor[
             0.5057081135223296, 0.6095956543051453, 0.954230341647787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 287}], {
             RGBColor[
             0.7232005299524522, 0.3005335226460366, 0.4283231466370737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 298}], {
             RGBColor[
             0.7259577755586328, 0.7849815940607858, 0.9742371653102562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 336}], {
             RGBColor[
             0.7168204065942949, 0.777695704075896, 0.973365634901412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 132}], {
             RGBColor[
             0.8751134199360577, 0.9025829386846316, 0.9516510301073935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 250}], {
             RGBColor[
             0.9150389891260062, 0.9340471360809055, 0.9555577161144337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 342}], {
             RGBColor[
             0.852980541830388, 0.8852925660923785, 0.9494450316613257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 356}], {
             RGBColor[
             0.9789615075262568, 0.9838301072772278, 0.9204968594271273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 365}], {
             RGBColor[
             0.8869531707893978, 0.5448621525472668, 0.4338455067524504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 457}], {
             RGBColor[
             0.9734183849825762, 0.9472059485439812, 0.632830578776649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 485}], {
             RGBColor[
             0.7627890005968545, 0.8134100629677927, 0.9414293052137248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 494}], {
             RGBColor[
             0.9081530647922974, 0.9285564869306427, 0.9549009305043473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 141}], {
             RGBColor[
             0.8763840390421316, 0.41964285872607543`, 0.32423656267728074`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 151}], {
             RGBColor[
             0.9745910433398506, 0.9781933013061226, 0.8029465852388531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 160}], {
             RGBColor[
             0.994702741300933, 0.9910780242147339, 0.6648042653768614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 167}], {
             RGBColor[
             0.9553645608742203, 0.9633517835714054, 0.8180721435795625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 172}], {
             RGBColor[
             0.9347738806621748, 0.7580566828813078, 0.43085551817799184`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 201}], {
             RGBColor[
             0.9555967638536137, 0.8490216173056941, 0.4480450949404119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 218}], {
             RGBColor[
             0.9947179487336646, 0.9914213080459897, 0.6890482300005767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 235}], {
             RGBColor[
             0.8532008151220773, 0.8827628895310458, 0.8080958202192619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 236}], {
             RGBColor[
             0.9785215194831101, 0.9811246439782013, 0.796293314360673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 274}], {
             RGBColor[
             0.9899805257249397, 0.9766229049041659, 0.5211191026523874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 284}], {
             RGBColor[
             0.6464228263512447, 0.7107851568767596, 0.7922872998448601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 289}], {
             RGBColor[
             0.9911883727354855, 0.9899617376647771, 0.7475424385402805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 300}], {
             RGBColor[
             0.8128783552069344, 0.8510923882102911, 0.8041932818873463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 305}], {
             RGBColor[
             0.893251110707283, 0.5492905627423621, 0.3403884895524626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 308}], {
             RGBColor[
             0.9044581174173555, 0.922805483654043, 0.8132046690853315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 389}], {
             RGBColor[
             0.9842942243520101, 0.9574416751662196, 0.499028895586467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 432}], {
             RGBColor[
             0.994262753625371, 0.9901369350662848, 0.6169143221811197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 456}], {
             RGBColor[
             0.9693264262053565, 0.9742669584672362, 0.8118582088154948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 493}], {
             RGBColor[
             0.9947396289267099, 0.9914302733629696, 0.6886889330952739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 123}], {
             RGBColor[
             0.836861302301908, 0.8731259027688776, 0.9842032140101838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 139}], {
             RGBColor[
             0.9125488417683922, 0.8324144413673473, 0.6245673027054115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 158}], {
             RGBColor[
             0.9233344612757237, 0.9414149488226697, 0.9824638479618921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 193}], {
             RGBColor[
             0.8660731227830359, 0.8960472154512825, 0.9870880216752915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 401}], {
             RGBColor[
             0.80501200604209, 0.8482449904670908, 0.9810287738076008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 410}], {
             RGBColor[
             0.9176957680535281, 0.9372096206500691, 0.9920086847803432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 428}], {
             RGBColor[
             0.9466602781788143, 0.9558192277420494, 0.7692527193791527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 437}], {
             RGBColor[
             0.7260299568613504, 0.785165110468357, 0.9740990712310713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 122}], {
             RGBColor[
             0.8595709720186533, 0.8810976119319897, 0.6916769056426451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 185}], {
             RGBColor[
             0.9674866897360057, 0.9661455066403044, 0.6924674823698675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 212}], {
             RGBColor[
             0.869555173749861, 0.8888973462071528, 0.6926720375635419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 224}], {
             RGBColor[
             0.7197680687498449, 0.7688926417863857, 0.6797623694410722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 286}], {
             RGBColor[
             0.940531194065519, 0.9449315288151982, 0.6995904454771313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 319}], {
             RGBColor[
             0.8470221676816798, 0.8712943906095006, 0.6904261581015795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 330}], {
             RGBColor[
             0.9238839961628473, 0.931657505083757, 0.6980026208800454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 357}], {
             RGBColor[
             0.9702852192977015, 0.9682326454052455, 0.6877303017953237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 367}], {
             RGBColor[
             0.8816883194047562, 0.46998624104596376`, 0.25301948843233635`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 368}], {
             RGBColor[
             0.8492642082512519, 0.8730458897425898, 0.6906496237524941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 492}], {
             RGBColor[
             0.9376068711409193, 0.9425997530937535, 0.699311520946009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 110}], {
             RGBColor[
             0.9784263415762489, 0.9808550506407583, 0.7806955867685768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 136}], {
             RGBColor[
             0.8762889945437953, 0.4194395681546069, 0.3138915555800298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.989553111572516, 0.9890395343062828, 0.7567627373279793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 240}], {
             RGBColor[
             0.853058248374573, 0.882457953673843, 0.7925783095733855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 360}], {
             RGBColor[
             0.688171077591291, 0.7477268304601024, 0.7794037790176446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 457}], {
             RGBColor[
             0.9824382519891302, 0.9513570198415852, 0.4768551276743572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 163}], {
             RGBColor[
             0.6859611751487158, 0.7505700319623865, 0.9518060651276572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 207}], {
             RGBColor[
             0.6445305158206289, 0.7181088846119745, 0.9677738884491474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 209}], {
             RGBColor[
             0.6286822353809187, 0.7054718959794621, 0.9662622653128808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 231}], {
             RGBColor[
             0.6828605025839412, 0.2670709312780508, 0.4253443640571476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 233}], {
             RGBColor[
             0.7040395953417468, 0.7624008811336965, 0.847223766283572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 257}], {
             RGBColor[
             0.6828605025839412, 0.2670709312780508, 0.4253443640571476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 281}], {
             RGBColor[
             0.6771227197531902, 0.743978326400046, 0.9667672646739239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 317}], {
             RGBColor[
             0.5718576708971608, 0.6608906820751483, 0.9606487932747104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 322}], {
             RGBColor[
             0.3378195185920887, 0.4626738830477113, 0.9429058187387744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 326}], {
             RGBColor[
             0.6235517445221387, 0.7013809818321354, 0.9657729145147271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 343}], {
             RGBColor[
             0.5467875858157898, 0.6413057410698777, 0.9581500414870645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 355}], {
             RGBColor[
             0.5718576708971608, 0.6608906820751483, 0.9606487932747104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 395}], {
             RGBColor[
             0.3064165963050924, 0.42966742066380703`, 0.9411174687709902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 440}], {
             RGBColor[
             0.533236515542435, 0.6307195419803844, 0.9567993974441682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 105}], {
             RGBColor[
             0.9451973451227361, 0.804748572578855, 0.4822182899072236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 276}], {
             RGBColor[
             0.6341888793018998, 0.5574215636248002, 0.5896513960403265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 347}], {
             RGBColor[
             0.8548261056939614, 0.7360866780693459, 0.6082210497304876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 382}], {
             RGBColor[
             0.8992632868750827, 0.771474563851477, 0.6124714802136795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 425}], {
             RGBColor[
             0.7214121383713561, 0.6304106903060595, 0.5959163206623286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 462}], {
             RGBColor[
             0.6417329335243727, 0.5639558442171159, 0.5901320965044372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 131}], {
             RGBColor[
             0.9410664405345628, 0.9552343984930172, 0.9730761662221084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 143}], {
             RGBColor[
             0.977146723551175, 0.9806940380119915, 0.843740060981278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 178}], {
             RGBColor[
             0.879073178893913, 0.5232013436678565, 0.44115705674250494`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 186}], {
             RGBColor[
             0.8687938398300019, 0.8979437835690736, 0.9660931536915038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 277}], {
             RGBColor[
             0.9767825066540639, 0.9805434249650886, 0.849776077529527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 288}], {
             RGBColor[
             0.7686709002770213, 0.8187406269188588, 0.956788211290606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 295}], {
             RGBColor[
             0.8261289491276091, 0.8646136466871852, 0.9618407161123614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 313}], {
             RGBColor[
             0.8026635894675769, 0.8462823293774293, 0.959501908357703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 321}], {
             RGBColor[
             0.9570787918743977, 0.9138341471024258, 0.6180676206858006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 341}], {
             RGBColor[
             0.9536542306439839, 0.9649559816152913, 0.9633354779938946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 373}], {
             RGBColor[
             0.9156635977129555, 0.7403409109846631, 0.5842631216323757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 498}], {
             RGBColor[
             0.8646698889204719, 0.4124913453700766, 0.42736444999774836`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 203}], {
             RGBColor[
             0.9708095599837459, 0.9131959329632332, 0.3411010819992529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 257}], {
             RGBColor[
             0.8663739836170784, 0.3867040560118732, 0.21498776167016664`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 264}], {
             RGBColor[
             0.8094015941490724, 0.8108682982151583, 0.6413536848522172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 281}], {
             RGBColor[
             0.9523929413028961, 0.9234280135007795, 0.6512323610934525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 324}], {
             RGBColor[
             0.9470654677297679, 0.8253194681499055, 0.289388900655033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 360}], {
             RGBColor[
             0.6732985612012157, 0.6986235622460016, 0.6310480881528497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 374}], {
             RGBColor[
             0.9795584048563339, 0.9413933603892304, 0.4868626390560973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 397}], {
             RGBColor[
             0.9763755277575477, 0.931971249215649, 0.3627238157556555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 457}], {
             RGBColor[
             0.9675657355990548, 0.9022537516274844, 0.3284994368095625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 103}], {
             RGBColor[
             0.889341836984537, 0.8734924242514339, 0.6495757667643446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 129}], {
             RGBColor[
             0.6235167000292163, 0.7020551025913334, 0.9654557010201166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[
             0.8967119988153947, 0.9193997989749245, 0.9509633090239884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 276}], {
             RGBColor[
             0.5935964876413409, 0.6761397184545562, 0.9635492115441662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 306}], {
             RGBColor[
             0.9016239949830045, 0.9222340244703346, 0.9055183018842057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 331}], {
             RGBColor[
             0.8868615800748212, 0.8651259353029462, 0.639940437027315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 347}], {
             RGBColor[
             0.8142337140334024, 0.8548048328991019, 0.9821188652343271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 390}], {
             RGBColor[
             0.8984761442241344, 0.9043045874079283, 0.6850608255209973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 431}], {
             RGBColor[
             0.8675344769807304, 0.789593038034528, 0.6186989807856116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 486}], {
             RGBColor[
             0.7676577877943824, 0.8184193653310294, 0.9774766121835989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 134}], {
             RGBColor[
             0.791236060720786, 0.49683096075452227`, 0.4520033190633851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 174}], {
             RGBColor[
             0.8350321813495103, 0.8695637830205294, 0.869488434863178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 210}], {
             RGBColor[
             0.7035637930246972, 0.7683486494845491, 0.9710883217773919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 225}], {
             RGBColor[
             0.8248938444516478, 0.833271659947391, 0.6579399295607726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 247}], {
             RGBColor[
             0.5528786357182693, 0.6466781627608185, 0.9584972465338205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 252}], {
             RGBColor[
             0.8358044538812319, 0.8689955674231113, 0.792172901230507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 278}], {
             RGBColor[
             0.6903408062210481, 0.7580187516951166, 0.9697703780286414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 309}], {
             RGBColor[
             0.818363709384156, 0.8585473823815918, 0.9610667495850252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 383}], {
             RGBColor[
             0.7759731937095296, 0.6356509594041961, 0.5927719200554715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 393}], {
             RGBColor[
             0.8261595471590022, 0.8375411723804251, 0.6628569455709434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 451}], {
             RGBColor[
             0.7709207813096757, 0.8213281322329282, 0.9777063858001285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 480}], {
             RGBColor[
             0.8284763930756893, 0.8453564376787017, 0.6718574544576336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 129}], {
             RGBColor[
             0.6987932266552647, 0.7208742521744236, 0.6329293874546276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 204}], {
             RGBColor[
             0.9719885254414429, 0.9382189485580146, 0.6184369954584994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 209}], {
             RGBColor[
             0.9040196633102997, 0.885148285979648, 0.6509884458265873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 231}], {
             RGBColor[
             0.8664187878701951, 0.3868551912781747, 0.21516181773295184`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 233}], {
             RGBColor[
             0.9793770232711276, 0.9420772711338824, 0.5319499467972785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 259}], {
             RGBColor[
             0.9644559074339745, 0.9326011343815745, 0.6311877529237224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 275}], {
             RGBColor[
             0.9760142236095494, 0.9406866670538104, 0.5876802398361853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 326}], {
             RGBColor[
             0.8988891724515196, 0.8810573718323212, 0.6504990950284335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 346}], {
             RGBColor[
             0.7532524973590851, 0.7656392892695116, 0.6370639501386153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 348}], {
             RGBColor[
             0.8664187878701951, 0.3868551912781747, 0.21516181773295184`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 355}], {
             RGBColor[
             0.8471950988265416, 0.8405670720753342, 0.6453749737884169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 390}], {
             RGBColor[
             0.9737526708501827, 0.9231237369910184, 0.35253451195550833`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 404}], {
             RGBColor[
             0.8664187878701951, 0.3868551912781747, 0.21516181773295184`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 431}], {
             RGBColor[
             0.9428110036067787, 0.808412187617618, 0.28617266722012247`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 443}], {
             RGBColor[
             0.975299206699433, 0.9403909891863809, 0.5995299204412607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 444}], {
             RGBColor[
             0.954513120416171, 0.9251858201035164, 0.6480182978506897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 486}], {
             RGBColor[
             0.8429343144204308, 0.8372385149141195, 0.6449502986181099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 125}], {
             RGBColor[
             0.9531517739306932, 0.8422777940772792, 0.33163720228103244`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 147}], {
             RGBColor[
             0.9411329051345991, 0.9458038015706378, 0.7002252335832952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 242}], {
             RGBColor[
             0.768368166057328, 0.8087987732716976, 0.6841516747775551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 303}], {
             RGBColor[
             0.8744581482887588, 0.4139738417015826, 0.2463932148532456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 310}], {
             RGBColor[
             0.9382991010440445, 0.7786778899242789, 0.31944254241840453`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 323}], {
             RGBColor[
             0.8080858384619509, 0.841043368990522, 0.6872783954398749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 379}], {
             RGBColor[
             0.9525442040325325, 0.954902861560393, 0.7013136534591669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 408}], {
             RGBColor[
             0.9439959634301249, 0.8045460114834562, 0.32419614403622543`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 109}], {
             RGBColor[
             0.8801755876819646, 0.4476995172793815, 0.35628491881578933`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 205}], {
             RGBColor[
             0.9951816972301821, 0.9922755222270166, 0.7295152764711306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 230}], {
             RGBColor[
             0.9502401635514743, 0.8273274636329311, 0.4864096205538401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 382}], {
             RGBColor[
             0.9492105383182123, 0.9589861714215002, 0.8603833207987488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 425}], {
             RGBColor[
             0.7713593898144857, 0.8179222978760827, 0.8438281612473979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 462}], {
             RGBColor[
             0.6916801849675023, 0.7514674517871391, 0.8380439370895065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 484}], {
             RGBColor[
             0.9621646100988177, 0.874603920606893, 0.4960043101485674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 156}], {
             RGBColor[
             0.757462525883905, 0.8061108621534677, 0.8004487745575368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 227}], {
             RGBColor[
             0.7012704936011454, 0.5896181833353824, 0.5893775775735776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 265}], {
             RGBColor[
             0.5393957148500103, 0.6369447666721018, 0.9568823530260517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 270}], {
             RGBColor[
             0.5297915822556674, 0.6291476991707714, 0.9561262805271282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 329}], {
             RGBColor[
             0.7183458567185175, 0.2965922802141915, 0.4279409689768444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 479}], {
             RGBColor[
             0.7297024972016741, 0.787776883216404, 0.9717594965662854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 153}], {
             RGBColor[
             0.9403538691854423, 0.9547407285925691, 0.9755916875967711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 170}], {
             RGBColor[
             0.9546509431645422, 0.9518685782090858, 0.6945794788858659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 197}], {
             RGBColor[
             0.8158332034631433, 0.8568969129242006, 0.9820547013974588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 214}], {
             RGBColor[
             0.5515763420775036, 0.6239052446900324, 0.9630678324461773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 223}], {
             RGBColor[
             0.9381886832300442, 0.9531259364521999, 0.9792567826483208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 236}], {
             RGBColor[
             0.9433773029974162, 0.9569956005791207, 0.9704738027909291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 289}], {
             RGBColor[
             0.9560441562497919, 0.9658326942656965, 0.9217229269705367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 314}], {
             RGBColor[
             0.9595737322479708, 0.9672922646469091, 0.8632287184308329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 411}], {
             RGBColor[
             0.8660872016283512, 0.5045000574633827, 0.45293271942567803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 466}], {
             RGBColor[
             0.8646864035873373, 0.49373290988653395`, 0.451591313639628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 470}], {
             RGBColor[
             0.9551514024451537, 0.9654635176247524, 0.936518167886174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 113}], {
             RGBColor[
             0.9297464374125604, 0.7511329553635315, 0.5390987371895051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 190}], {
             RGBColor[
             0.9056201085888542, 0.6543443500725712, 0.24244316661791004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 315}], {
             RGBColor[
             0.9337926644823953, 0.7528061742402008, 0.47204228334235127`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 349}], {
             RGBColor[
             0.9111610713483149, 0.6763124209974507, 0.24690155531728444`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 364}], {
             RGBColor[
             0.9099215026838265, 0.7368353169814494, 0.5945003151937653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 378}], {
             RGBColor[
             0.9148701437697391, 0.7405260054006668, 0.5861235566476204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 380}], {
             RGBColor[
             0.7314378949063093, 0.5958815811288363, 0.5880584198271808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 416}], {
             RGBColor[
             0.7200617559028762, 0.5866459189966275, 0.5871628484926601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 452}], {
             RGBColor[
             0.8727332741634227, 0.7074861826749936, 0.6014844604337923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 487}], {
             RGBColor[
             0.6726840267864236, 0.5481825441575174, 0.5834331001062729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 164}], {
             RGBColor[
             0.6720574648246199, 0.282139987847984, 0.4278573430997618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 180}], {
             RGBColor[
             0.8058768370865553, 0.3909479716755676, 0.43888626065259007`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 205}], {
             RGBColor[
             0.8802003214581754, 0.4477097453314738, 0.35587501613501443`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 230}], {
             RGBColor[
             0.8502392990057036, 0.33774437293541676`, 0.19380457885682087`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 382}], {
             RGBColor[
             0.849552882183529, 0.4255168447944628, 0.44312037902009327`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 413}], {
             RGBColor[
             0.7536121119369632, 0.34984360603441694`, 0.43386485970971944`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 474}], {
             RGBColor[
             0.7615560806815869, 0.35629287773301604`, 0.43449023802901254`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 490}], {
             RGBColor[
             0.8212448066032992, 0.4029535462629421, 0.4404179962321787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 157}], {
             RGBColor[
             0.9737504695173789, 0.9798298804832204, 0.9242196573564665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 356}], {
             RGBColor[
             0.9721787324776736, 0.9787715247517692, 0.9319783283533227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 360}], {
             RGBColor[
             0.6723684355361539, 0.73851717663704, 0.9468606990461319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 457}], {
             RGBColor[
             0.966635609933993, 0.9421473660185228, 0.6443120477028446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 494}], {
             RGBColor[
             0.9013702897437144, 0.9234979044051843, 0.9663823994305427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 130}], {
             RGBColor[
             0.9292349728834212, 0.9414786307901053, 0.7314258123433135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 175}], {
             RGBColor[
             0.7477340057958953, 0.803032804740476, 0.9755229756057087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 182}], {
             RGBColor[
             0.8494750559914294, 0.8828123675341761, 0.9855048832474391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 351}], {
             RGBColor[
             0.8688289164107058, 0.8982446104859613, 0.9873508717316248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 359}], {
             RGBColor[
             0.8649946611799857, 0.8951872794430706, 0.9869851570448387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 371}], {
             RGBColor[
             0.7279407373211355, 0.7869637377160826, 0.9739647770062441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 460}], {
             RGBColor[
             0.860282572302325, 0.5947300938711481, 0.46425134829051506`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 463}], {
             RGBColor[
             0.9165678503146087, 0.9354868715277069, 0.9633540661995234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 483}], {
             RGBColor[
             0.7416762218335273, 0.7981148228197681, 0.9750460846617972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 163}], {
             RGBColor[
             0.878094887637688, 0.9052344922288375, 0.9682684511096284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 175}], {
             RGBColor[
             0.714087716287021, 0.7763801503873836, 0.9722670618402882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 207}], {
             RGBColor[
             0.8366642283096011, 0.8727733448784255, 0.9842362744311186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 238}], {
             RGBColor[
             0.8897735555962486, 0.9139444236702683, 0.9484995125402182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 266}], {
             RGBColor[
             0.6615182886830051, 0.7337019208327181, 0.9681286039311416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 293}], {
             RGBColor[
             0.7920639703084134, 0.8374856606048475, 0.9799091923678545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 317}], {
             RGBColor[
             0.7639913833861328, 0.8155551423415992, 0.9771111792566818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 343}], {
             RGBColor[
             0.7389212983047619, 0.7959702013363286, 0.9746124274690359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 359}], {
             RGBColor[
             0.8313483716711112, 0.8685346250899783, 0.9837292432794182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 403}], {
             RGBColor[
             0.6731054099890736, 0.7431088679028508, 0.9690407845653793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 440}], {
             RGBColor[
             0.7253702280314072, 0.7853840022468352, 0.9732617834261394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 445}], {
             RGBColor[
             0.6128794243159468, 0.6935149813817817, 0.9644929085821297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 463}], {
             RGBColor[
             0.8829215608057344, 0.9088342171746145, 0.960098152434103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 471}], {
             RGBColor[
             0.6899545501120022, 0.7567877588997567, 0.9703672105962902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 483}], {
             RGBColor[
             0.7080299323246529, 0.7714621684666757, 0.9717901708963768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 190}], {
             RGBColor[
             0.9630016062161793, 0.8921564792981214, 0.566331387861178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 315}], {
             RGBColor[
             0.9911741621097202, 0.9906183034657509, 0.7959305045856191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 349}], {
             RGBColor[
             0.96854256897564, 0.9141245502230007, 0.5707897765605523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 353}], {
             RGBColor[
             0.9689613307787546, 0.9758842263544709, 0.9155814155172375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 364}], {
             RGBColor[
             0.9673030003111516, 0.9746474462069995, 0.9183885364370333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 378}], {
             RGBColor[
             0.972251641397064, 0.9783381346262169, 0.9100117778908883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 380}], {
             RGBColor[
             0.7888193925336342, 0.8336937103543864, 0.9119466410704486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 487}], {
             RGBColor[
             0.7300655244137486, 0.7859946733830675, 0.9073213213495408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 128}], {
             RGBColor[
             0.9371852584636482, 0.7691080167911634, 0.4786557591669073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 138}], {
             RGBColor[
             0.9653427896553646, 0.9719132778189079, 0.8647328645734309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 179}], {
             RGBColor[
             0.7118075378207449, 0.7689819574025344, 0.8423111145527004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 255}], {
             RGBColor[
             0.8764745937718037, 0.42012193360722805`, 0.3548375425921436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 294}], {
             RGBColor[
             0.9945889408797353, 0.9920304022429636, 0.7393387832022962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 296}], {
             RGBColor[
             0.9794662363617217, 0.9824465212474875, 0.8408255532844193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 312}], {
             RGBColor[
             0.9494310091723135, 0.9592308340029074, 0.8633947102071517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 327}], {
             RGBColor[
             0.9915032750710304, 0.9907544001330699, 0.7904762510996672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 334}], {
             RGBColor[
             0.9923844521451002, 0.9911187894984157, 0.7758728665691643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 385}], {
             RGBColor[
             0.9656364584487427, 0.9721322955241708, 0.8642357599073298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 415}], {
             RGBColor[
             0.9529250273780275, 0.8386091558137642, 0.4916875292391039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 446}], {
             RGBColor[
             0.9831620871676904, 0.9852028807271787, 0.834569441902184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 144}], {
             RGBColor[
             0.4891103845787862, 0.5934464098769114, 0.9536626689898766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 215}], {
             RGBColor[
             0.5813590497254989, 0.6710124923507164, 0.9601858604642108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 223}], {
             RGBColor[
             0.7877763863358228, 0.8344897492199078, 0.9646872321564159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 268}], {
             RGBColor[
             0.8089395887693464, 0.8485643381507693, 0.8523357399630429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 402}], {
             RGBColor[
             0.7910410696090908, 0.8369245446596829, 0.9591609749405398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 417}], {
             RGBColor[
             0.8068785459149261, 0.8477120439640812, 0.8864925538687127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 143}], {
             RGBColor[
             0.8619123532504349, 0.8901559063940476, 0.8537183308649807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 165}], {
             RGBColor[
             0.7183488993135905, 0.7798988868884023, 0.972561962997595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 185}], {
             RGBColor[
             0.8377223006141428, 0.8738976110935331, 0.9744945345462501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 187}], {
             RGBColor[
             0.8086450751077205, 0.5119958991997102, 0.4539329137012126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 224}], {
             RGBColor[
             0.5900036796279817, 0.6766447462396145, 0.9617894216174547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 277}], {
             RGBColor[
             0.8615481363533235, 0.8900052933471447, 0.8597543474132296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 313}], {
             RGBColor[
             0.6874292191668365, 0.7557441977594854, 0.9694801782414055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 333}], {
             RGBColor[
             0.8225589653909906, 0.8620863819194633, 0.9827422444439664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 358}], {
             RGBColor[
             0.8142179715026079, 0.7124142458381899, 0.6057470575781483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 361}], {
             RGBColor[
             0.8242200337600153, 0.8634108727484238, 0.9829006786278573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 386}], {
             RGBColor[
             0.8612431111641765, 0.888413708571945, 0.7582867304388847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 441}], {
             RGBColor[
             0.8614163915312146, 0.8899508134775151, 0.8619377000602448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 140}], {
             RGBColor[
             0.7786158736725196, 0.7299092450204532, 0.6121739917542123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 155}], {
             RGBColor[
             0.7692973852267815, 0.8202268581763227, 0.9775797099856826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 156}], {
             RGBColor[
             0.8122449907282661, 0.8505857350360371, 0.8047614508648658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 198}], {
             RGBColor[
             0.812609929263225, 0.8513663016613686, 0.8444827582555812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 270}], {
             RGBColor[
             0.5845740471000285, 0.6736225720533406, 0.9604389568344571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 479}], {
             RGBColor[
             0.7844849620460352, 0.8322517560989733, 0.9760721728736144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 152}], {
             RGBColor[
             0.861880141669753, 0.4104107564382823, 0.4320867644106019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 187}], {
             RGBColor[
             0.8826782413908284, 0.5702740646798786, 0.45200304819159776`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.9633289974473334, 0.9721714068562527, 0.9469586213791308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 255}], {
             RGBColor[
             0.861880141669753, 0.4104107564382823, 0.4320867644106019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 260}], {
             RGBColor[
             0.9677654824985552, 0.9612257716008084, 0.6811105109675104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 292}], {
             RGBColor[
             0.8478736037352179, 0.8817489103671428, 0.9715085755889998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 399}], {
             RGBColor[
             0.9151134844268868, 0.7537234776923913, 0.5943793154746936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 446}], {
             RGBColor[
             0.9612704090146145, 0.9706361149737601, 0.9504432746298714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 464}], {
             RGBColor[
             0.7496484271456489, 0.803573706622693, 0.9627035928275058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 481}], {
             RGBColor[
             0.7995190424084627, 0.8439739595504041, 0.9666890448150159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 496}], {
             RGBColor[
             0.7590596458945712, 0.8112141579736412, 0.9634444784418512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 120}], {
             RGBColor[
             0.730039579471075, 0.7830850326726744, 0.7357835883746736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 124}], {
             RGBColor[
             0.40089486438930094`, 0.5212932790428118, 0.9468660625367008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 363}], {
             RGBColor[
             0.5222992836731025, 0.6230651136572405, 0.9555364593375146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 364}], {
             RGBColor[
             0.7070905626804926, 0.769139701171615, 0.9624749176890761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 381}], {
             RGBColor[
             0.7199326427952348, 0.749530810876061, 0.6507002327074178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 416}], {
             RGBColor[
             0.5172308158995423, 0.6189503031867931, 0.9551374509879709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 124}], {
             RGBColor[
             0.6642313840818084, 0.7264487171971736, 0.731489929974516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 315}], {
             RGBColor[
             0.9942982441715686, 0.9902659965847282, 0.6246407532754771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 363}], {
             RGBColor[
             0.7856358033656099, 0.8282205518116024, 0.7401603267753298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 381}], {
             RGBColor[
             0.9832691624877421, 0.9546862490304229, 0.435324100145233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 196}], {
             RGBColor[
             0.7475171817719453, 0.7972942234295637, 0.7388057222430955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.7433091301474714, 0.7971721663564812, 0.9261613926403076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 307}], {
             RGBColor[
             0.7252088668496959, 0.7838056408198106, 0.9627394651426529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 337}], {
             RGBColor[
             0.7481093850586511, 0.7985608863788908, 0.80326339534599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 420}], {
             RGBColor[
             0.7060450110859033, 0.7688624765796106, 0.9726155074033995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 427}], {
             RGBColor[
             0.7482347719507559, 0.7988290762625436, 0.8169109847534013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 442}], {
             RGBColor[
             0.7120886643452055, 0.29151240956223273`, 0.4274483798723664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 447}], {
             RGBColor[
             0.47621270354797446`, 0.5855815119170455, 0.9519272650549451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 454}], {
             RGBColor[
             0.7032689048497267, 0.7666488848222797, 0.9723507199123337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 489}], {
             RGBColor[
             0.6998311637044086, 0.7639077233480006, 0.9720228250929855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 500}], {
             RGBColor[
             0.6134335575132659, 0.6957824049491292, 0.9635789278091891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 185}], {
             RGBColor[
             0.8386259573509978, 0.8746035546044099, 0.9745846026046274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 212}], {
             RGBColor[
             0.740694441364853, 0.7973553941712581, 0.9747891577983018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 216}], {
             RGBColor[
             0.8591434678673209, 0.8893431593582897, 0.9146719260855852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 217}], {
             RGBColor[
             0.7536258684982454, 0.8074575233303507, 0.9760780416039011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 224}], {
             RGBColor[
             0.5909073363648367, 0.6773506897504912, 0.961879489675832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 286}], {
             RGBColor[
             0.8116704616805109, 0.8533895767793036, 0.9817075657118912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 319}], {
             RGBColor[
             0.7181614352966719, 0.7797524385736061, 0.9725432783363394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 330}], {
             RGBColor[
             0.7950232637778394, 0.8401155530478626, 0.9801197411148053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 357}], {
             RGBColor[
             0.8414244869126934, 0.876690693369351, 0.9698474220300836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 492}], {
             RGBColor[
             0.8087461387559114, 0.8510578010578591, 0.9814286411807689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 139}], {
             RGBColor[
             0.8497211322064018, 0.7826887312108635, 0.6184761815305126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 158}], {
             RGBColor[
             0.8605067517137333, 0.8916892386661859, 0.9763727267869933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 193}], {
             RGBColor[
             0.8032454132210454, 0.8463215052947987, 0.9809969005003927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 401}], {
             RGBColor[
             0.7421842964800994, 0.7985192803106069, 0.9749376526327019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 410}], {
             RGBColor[
             0.8548680584915376, 0.8874839104935852, 0.9859175636054444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 422}], {
             RGBColor[
             0.8717960485993784, 0.9001087777989729, 0.9572628918797887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 428}], {
             RGBColor[
             0.8838325686168238, 0.9060935175855656, 0.7631615982042539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 437}], {
             RGBColor[
             0.6632022472993598, 0.7354394003118732, 0.9680079500561725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 363}], {
             RGBColor[
             0.4564910882838359, 0.5664287981817397, 0.951242800937357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 381}], {
             RGBColor[
             0.6541244474059682, 0.6928944954005604, 0.6464065743072602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 416}], {
             RGBColor[
             0.4514226205102757, 0.5623139877112924, 0.9508437925878133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.925429808426981, 0.8302670981615927, 0.6230151136029449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 173}], {
             RGBColor[
             0.6841822585277213, 0.6378839290986019, 0.6012380752475595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 242}], {
             RGBColor[
             0.7327834951217449, 0.6774090422442292, 0.6050452324988507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 249}], {
             RGBColor[
             0.9219646442918519, 0.8275040703396155, 0.6226846031543478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 269}], {
             RGBColor[
             0.9130653790643601, 0.820408037811333, 0.6218357832924817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 282}], {
             RGBColor[
             0.9489364689144824, 0.8478603837159555, 0.585376011977204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 305}], {
             RGBColor[
             0.8676021059968548, 0.45602839169955695`, 0.20980751354262447`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 310}], {
             RGBColor[
             0.9027144301084613, 0.6472881588968105, 0.2403361001397001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 323}], {
             RGBColor[
             0.7725011675263679, 0.7096536379630536, 0.6081719531611705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 406}], {
             RGBColor[
             0.7673309746465564, 0.7054562424686877, 0.6077649366386313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 408}], {
             RGBColor[
             0.9084112924945419, 0.6731562804559877, 0.24508970175752104`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 419}], {
             RGBColor[
             0.9548059035067513, 0.8509331789833521, 0.5170170661355027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 173}], {
             RGBColor[
             0.719836708797027, 0.7772738754909935, 0.891981165063228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 249}], {
             RGBColor[
             0.9576190945611576, 0.966894016732007, 0.9134276929700162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 269}], {
             RGBColor[
             0.9487198293336657, 0.9597979842037245, 0.9125788731081501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 282}], {
             RGBColor[
             0.984590919183788, 0.9872503301083471, 0.8761191017928724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 340}], {
             RGBColor[
             0.6972804167738131, 0.757736749052687, 0.8905438980812547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 384}], {
             RGBColor[
             0.9691444499136661, 0.9757303786179623, 0.9022659451827891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 414}], {
             RGBColor[
             0.987382132082858, 0.9890502015989167, 0.8587742555898596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 449}], {
             RGBColor[
             0.9891846411436224, 0.9897955854179128, 0.8289020157090751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 499}], {
             RGBColor[
             0.8304959376233134, 0.8667246250886584, 0.9009854132561155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 184}], {
             RGBColor[
             0.6899578277065219, 0.7535507288960803, 0.9450407748412226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 221}], {
             RGBColor[
             0.6886468153130365, 0.7104961469339652, 0.6298598347984006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 253}], {
             RGBColor[
             0.6630973823915829, 0.7329136000314862, 0.9695448127575224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 301}], {
             RGBColor[
             0.7032988426964115, 0.7598275737609232, 0.6947139227169968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 303}], {
             RGBColor[
             0.6828605025839412, 0.2670709312780508, 0.4253443640571476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 316}], {
             RGBColor[
             0.6392146591821392, 0.7138701648235273, 0.967266857297447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 138}], {
             RGBColor[
             0.9077422668036018, 0.7489094937883873, 0.6073119959639073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 179}], {
             RGBColor[
             0.6542070149689821, 0.5459781733720138, 0.5848902459431768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 222}], {
             RGBColor[
             0.9181025596420722, 0.7057183711240997, 0.2536068509938104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 245}], {
             RGBColor[
             0.8833863026185504, 0.5633662606593759, 0.22440701125267937`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 294}], {
             RGBColor[
             0.9369884180279724, 0.769026618212443, 0.4819179145927727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 296}], {
             RGBColor[
             0.921865713509959, 0.759442737216967, 0.5834046846748959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 312}], {
             RGBColor[
             0.8918304863205508, 0.7362270499723869, 0.6059738415976283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 385}], {
             RGBColor[
             0.90803593559698, 0.7491285114936502, 0.6068148912978062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 415}], {
             RGBColor[
             0.8953245045262648, 0.6156053717832436, 0.2342666606295804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 438}], {
             RGBColor[
             0.9258938074200946, 0.7624468830597477, 0.5765861723801855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 439}], {
             RGBColor[
             0.780325934612901, 0.648439160466273, 0.5950404777839722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 204}], {
             RGBColor[
             0.7061633884861225, 0.7667816268979141, 0.9343169297142714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 275}], {
             RGBColor[
             0.7101890866542289, 0.7692493453937099, 0.9035601740919573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 276}], {
             RGBColor[
             0.4030478773120687, 0.5235215463775458, 0.946902832234449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 306}], {
             RGBColor[
             0.7110753846537323, 0.7696158523933242, 0.8888719225744885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 331}], {
             RGBColor[
             0.696312969745549, 0.7125077632259358, 0.623294057717598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 346}], {
             RGBColor[
             0.4874273604037645, 0.5942019676094111, 0.9529438843943873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 348}], {
             RGBColor[
             0.6892020298999814, 0.27256364350477436`, 0.42574844057013317`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 355}], {
             RGBColor[
             0.5813699618712211, 0.6691297504152336, 0.9612549080441889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 431}], {
             RGBColor[
             0.6769858666514581, 0.6369748659575175, 0.6020526014758945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 444}], {
             RGBColor[
             0.6886879834608504, 0.7537484984434157, 0.9638982321064615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 486}], {
             RGBColor[
             0.5771091774651103, 0.6658011932540189, 0.9608302328738818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 175}], {
             RGBColor[
             0.8114654669318002, 0.8489184124573423, 0.719915096282796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 182}], {
             RGBColor[
             0.9132065171273342, 0.9286979752510427, 0.7298970039245265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 208}], {
             RGBColor[
             0.9933686981684711, 0.9882246408468487, 0.5196019031682739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 238}], {
             RGBColor[
             0.9871513062410279, 0.9864826857402271, 0.6961475469827261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 241}], {
             RGBColor[
             0.7106839767244842, 0.7664229176878274, 0.7121681384556182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 351}], {
             RGBColor[
             0.9325603775466107, 0.9441302182028277, 0.7317429924087122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 371}], {
             RGBColor[
             0.7916721984570404, 0.8328493454329491, 0.7183568976833314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 442}], {
             RGBColor[
             0.8758681446731087, 0.4185394128356573, 0.2680846443401336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 483}], {
             RGBColor[
             0.8054076829694322, 0.8440004305366344, 0.7194382053388846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 186}], {
             RGBColor[
             0.8504886136031489, 0.8839581459518613, 0.9855119699203672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 234}], {
             RGBColor[
             0.8524664047692366, 0.40316758695860166`, 0.4403103274836573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 373}], {
             RGBColor[
             0.8973583714861024, 0.7263552733674508, 0.6036819378612391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 434}], {
             RGBColor[
             0.8624888691837745, 0.8933328368167663, 0.9867080432478796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 449}], {
             RGBColor[
             0.9561272465306165, 0.9655859879385182, 0.9081410371177284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 495}], {
             RGBColor[
             0.7412963671467233, 0.7973921173898098, 0.9754930584580643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 250}], {
             RGBColor[
             0.8139631594437862, 0.8548675128969243, 0.9820191772771539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 356}], {
             RGBColor[
             0.8778856778440367, 0.9046504840932466, 0.9469583205898475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 365}], {
             RGBColor[
             0.8195692843345844, 0.4920757370912792, 0.4514864808609306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 457}], {
             RGBColor[0.8723425553003561, 0.86802632536, 0.6592920399393694]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 494}], {
             RGBColor[
             0.8070772351100772, 0.8493768637466615, 0.9813623916670675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 191}], {
             RGBColor[
             0.8637775783175057, 0.43503103092245315`, 0.20649039551348458`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 237}], {
             RGBColor[
             0.8326184356397394, 0.25172516658248273`, 0.1788687568468555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 241}], {
             RGBColor[
             0.7029792754496201, 0.38884336553871035`, 0.44030220481046733`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 271}], {
             RGBColor[
             0.8823607101034038, 0.5066206160034556, 0.23230851367202326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 304}], {
             RGBColor[
             0.8867111136879001, 0.5212955488172992, 0.24920901009300933`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 311}], {
             RGBColor[
             0.8832361637782822, 0.5325259152924382, 0.43648530017653697`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 351}], {
             RGBColor[
             0.8508968759977045, 0.5073148992153773, 0.4533521074458633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 366}], {
             RGBColor[
             0.8528585716806878, 0.5088791021041773, 0.4535392157313327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 371}], {
             RGBColor[
             0.7569714232713243, 0.43312765070212483`, 0.44442804429560956`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 405}], {
             RGBColor[
             0.8534440632982794, 0.38937050112402993`, 0.19793311587798199`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 423}], {
             RGBColor[
             0.8825323163420028, 0.5071994841413109, 0.23297517150386132`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 429}], {
             RGBColor[
             0.8789946098360092, 0.5293625713071981, 0.4436651446263631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 469}], {
             RGBColor[
             0.8815609994424168, 0.5312765804735797, 0.4393209164443248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 488}], {
             RGBColor[
             0.7085640690130801, 0.3936806330234931, 0.4406580629178919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 174}], {
             RGBColor[
             0.8963536802825286, 0.5779569969995724, 0.38601150952096674`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 210}], {
             RGBColor[
             0.8087080880659866, 0.5104802413089189, 0.453744767463776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 225}], {
             RGBColor[
             0.8895947890172871, 0.5537622482841469, 0.24497917265269648`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 247}], {
             RGBColor[
             0.708251316528368, 0.4293665834930986, 0.4453507173013951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 252}], {
             RGBColor[
             0.8968685286370098, 0.5775781866012938, 0.3344678204325193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 278}], {
             RGBColor[
             0.7998927635302205, 0.5035936427826306, 0.45286613829794237`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 309}], {
             RGBColor[
             0.8852413656389592, 0.5706127299069474, 0.4470637193355316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 424}], {
             RGBColor[
             0.864228367931847, 0.45492362045899226`, 0.2075811961969952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 169}], {
             RGBColor[
             0.9774600495995076, 0.9344422810471835, 0.4678976756022432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 211}], {
             RGBColor[
             0.9649129277732799, 0.8860368024667394, 0.4508248990883569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 362}], {
             RGBColor[
             0.9170167954124773, 0.9327157551184806, 0.8096673391221478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 369}], {
             RGBColor[
             0.8817768614165, 0.9050274472295519, 0.8061970403608995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 466}], {
             RGBColor[
             0.8880867794629436, 0.5097566930512185, 0.33230343869607665`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 470}], {
             RGBColor[
             0.9902519662585634, 0.9894991923717792, 0.757586355470847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 240}], {
             RGBColor[
             0.7821751710392534, 0.3477017342946218, 0.43345131746889387`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 434}], {
             RGBColor[
             0.8122848413532798, 0.37122363758590926`, 0.43645236801492915`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 148}], {
             RGBColor[
             0.9308156753241098, 0.9309513586436886, 0.6894938005382568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 156}], {
             RGBColor[
             0.989058712068816, 0.9735063971933271, 0.5181344333038113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 227}], {
             RGBColor[
             0.9328666797860565, 0.7570137183752419, 0.307063236319852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 229}], {
             RGBColor[
             0.92653870913575, 0.9275410219002449, 0.6890858596851184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 263}], {
             RGBColor[
             0.9765752234921068, 0.9665656368539228, 0.6635859576736872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 265}], {
             RGBColor[
             0.7709919010349213, 0.8043403017119611, 0.6745680117723262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 267}], {
             RGBColor[
             0.8727433141751249, 0.4081893035740978, 0.23973140814102736`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 280}], {
             RGBColor[
             0.9145838933858897, 0.9180085763261352, 0.6879455986867067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 393}], {
             RGBColor[
             0.9792776424182412, 0.9417607634150948, 0.3739979831940817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 424}], {
             RGBColor[
             0.9399623080827267, 0.7892333092443288, 0.3129840025003589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 485}], {
             RGBColor[
             0.7664903470504028, 0.800685737394633, 0.6742136329529294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 179}], {
             RGBColor[
             0.6823645461606985, 0.7487834343997584, 0.9709673513497004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 222}], {
             RGBColor[
             0.9462600908337886, 0.9085236321518442, 0.6396839564003339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 294}], {
             RGBColor[
             0.9651459492196888, 0.9718318792401874, 0.8679950199992963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 296}], {
             RGBColor[
             0.9500232447016754, 0.9622479982447114, 0.9694817900814194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 339}], {
             RGBColor[
             0.9609884593653093, 0.9701126503427858, 0.9368953861252122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 385}], {
             RGBColor[
             0.9361934667886964, 0.9519337725213948, 0.9928919967043298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 415}], {
             RGBColor[
             0.9234820357179812, 0.8184106328109881, 0.620343766036104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 438}], {
             RGBColor[
             0.954051338611811, 0.9652521440874922, 0.962663277786709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 158}], {
             RGBColor[
             0.9361942911802175, 0.8509777772646556, 0.6167368154822208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 247}], {
             RGBColor[
             0.6769050955512641, 0.6437294333390081, 0.6036793070582878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 278}], {
             RGBColor[
             0.8143672660540429, 0.7550700222733062, 0.6149524385531087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 401}], {
             RGBColor[
             0.8178718359465835, 0.7578078189090767, 0.6153017413279296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 410}], {
             RGBColor[
             0.9305555979580218, 0.846772449092055, 0.626281652300672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 428}], {
             RGBColor[
             0.959520108083308, 0.8653820561840353, 0.40352568689948154`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 437}], {
             RGBColor[
             0.7388897867658439, 0.6947279389103429, 0.6083720387514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 451}], {
             RGBColor[
             0.8949472411426704, 0.8183794028111178, 0.6228884463245957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 198}], {
             RGBColor[
             0.9612613030914703, 0.8708029602741088, 0.49264449046460224`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 270}], {
             RGBColor[
             0.7332254209282736, 0.6930592306660808, 0.6086006890434783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 479}], {
             RGBColor[
             0.9331363358742805, 0.8516884147117134, 0.6242339050826354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 151}], {
             RGBColor[
             0.8631019898511022, 0.4113220088113396, 0.43001849414862126`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 160}], {
             RGBColor[
             0.8765097884918237, 0.4199118240837473, 0.3379236142406269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 162}], {
             RGBColor[
             0.6469169705971057, 0.2357761524484131, 0.42306001650727343`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 167}], {
             RGBColor[
             0.8502843348740153, 0.4014276636548616, 0.44010219970909426`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 235}], {
             RGBColor[
             0.7821751710392534, 0.3477017342946218, 0.43345131746889387`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 274}], {
             RGBColor[
             0.8733616447744948, 0.41027507787670187`, 0.2421335057576442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 284}], {
             RGBColor[
             0.6443231785253649, 0.23304991252509769`, 0.42291230388595935`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 300}], {
             RGBColor[
             0.7552935310958248, 0.326588066747452, 0.43084962524761683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 345}], {
             RGBColor[
             0.8288258001248807, 0.3843172105223105, 0.43805546550846164`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 389}], {
             RGBColor[
             0.8695707771925418, 0.39748759138473766`, 0.2274067010470306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 432}], {
             RGBColor[
             0.8762164633747824, 0.41928443131811444`, 0.3059969854434657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 456}], {
             RGBColor[
             0.8595922450947727, 0.40870444691874874`, 0.43595957653304906`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 472}], {
             RGBColor[
             0.841069230331758, 0.2850522722223213, 0.18572271919023098`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[
             0.9424261433396257, 0.8441164271400734, 0.5972586019875008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 161}], {
             RGBColor[
             0.9480036078446386, 0.8662292153225807, 0.6017463608481524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 183}], {
             RGBColor[
             0.6325901799794306, 0.702884914244012, 0.9408730903279119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 254}], {
             RGBColor[
             0.972360479830194, 0.9562420395263489, 0.6554781108468252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 285}], {
             RGBColor[
             0.9799141734789227, 0.9812714341978694, 0.7231715227423234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 388}], {
             RGBColor[
             0.6187792894179369, 0.6883687926028448, 0.9400865805418164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 396}], {
             RGBColor[
             0.9583830088943615, 0.9684826966917592, 0.9553308898788988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 473}], {
             RGBColor[
             0.9679063500924618, 0.9755851889642624, 0.9392103573156986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 477}], {
             RGBColor[
             0.849742956215713, 0.8829332090481267, 0.9577211028583139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 165}], {
             RGBColor[
             0.85135832640409, 0.8819110204081082, 0.8526664041019254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 178}], {
             RGBColor[
             0.8909232167537526, 0.5308506782690312, 0.3678788640678603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 186}], {
             RGBColor[
             0.8865688966197612, 0.9094177854708356, 0.856175864679537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 277}], {
             RGBColor[
             0.9945575634438232, 0.9920174268668507, 0.73985878851756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 288}], {
             RGBColor[
             0.7864459570667808, 0.8302146288206207, 0.846870922278639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 313}], {
             RGBColor[
             0.8204386462573362, 0.8577563312791913, 0.849584619345736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 321}], {
             RGBColor[
             0.9748538486641571, 0.9253081490041877, 0.5081503316738337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 373}], {
             RGBColor[
             0.9334386545027149, 0.7518149128864251, 0.47434583262040886`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 386}], {
             RGBColor[
             0.9942525382546761, 0.990425842091651, 0.6383911715432151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 414}], {
             RGBColor[
             0.9904050204864645, 0.9903002436384964, 0.8086771717576826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 498}], {
             RGBColor[
             0.8765199267803115, 0.42014067997125115`, 0.3540862573231037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 145}], {
             RGBColor[
             0.6292777946631631, 0.7039136024570779, 0.9672550530321402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 215}], {
             RGBColor[
             0.44706834393772077`, 0.5593147873121472, 0.9503529655455427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 246}], {
             RGBColor[
             0.6354896941029182, 0.5935284606642226, 0.5976140560815344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 375}], {
             RGBColor[
             0.6631525595970027, 0.25000090161278077`, 0.42408859135706956`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 402}], {
             RGBColor[
             0.6567503638213128, 0.7252268396211137, 0.9493280800218717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 417}], {
             RGBColor[
             0.6725878401271481, 0.736014338925512, 0.8766596589500447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 458}], {
             RGBColor[
             0.5128076208334091, 0.6122492819414038, 0.9558260324519402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 367}], {
             RGBColor[
             0.8534563881153086, 0.4544658864152735, 0.4467263372940653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 375}], {
             RGBColor[
             0.8461246368451061, 0.39811083335860453`, 0.4397054439976906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 402}], {
             RGBColor[
             0.9312084796934679, 0.9473917372398493, 0.9727533589828032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 417}], {
             RGBColor[
             0.9470459559993032, 0.9581792365442476, 0.9000849379109763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 450}], {
             RGBColor[
             0.8577669425539873, 0.8894902573979375, 0.9862782127406156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 458}], {
             RGBColor[
             0.7872657367055642, 0.8344141795601394, 0.9792513114128718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 461}], {
             RGBColor[
             0.7284670143321244, 0.7871143397604623, 0.9743246303825547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 166}], {
             RGBColor[
             0.8337388373621797, 0.8708929180761834, 0.9838372479138293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 239}], {
             RGBColor[
             0.8532839865205557, 0.40381950445443804`, 0.44038830916096194`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 248}], {
             RGBColor[
             0.9161233330567725, 0.9359558945467942, 0.9918618554115508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 387}], {
             RGBColor[
             0.7103326184278462, 0.7722366029765579, 0.9730759067053758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 221}], {
             RGBColor[
             0.9284397441385859, 0.9029867890351531, 0.6509147000161061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 234}], {
             RGBColor[
             0.8427224551343073, 0.395398026012176, 0.4393809408689512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 242}], {
             RGBColor[
             0.7207646263256509, 0.7809350497375875, 0.9736332638011135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 303}], {
             RGBColor[
             0.8427224551343073, 0.395398026012176, 0.4393809408689512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 323}], {
             RGBColor[
             0.7604822987302738, 0.813179645456412, 0.9767599844634333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 449}], {
             RGBColor[
             0.9415113220782227, 0.9539316465188796, 0.9067469571956693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 229}], {
             RGBColor[
             0.8737624419344854, 0.9021784698216402, 0.987821435800293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 232}], {
             RGBColor[
             0.865654473607075, 0.6050173481627389, 0.46570578688938424`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 263}], {
             RGBColor[
             0.9237989562908422, 0.9412030847753181, 0.962321533788862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 267}], {
             RGBColor[
             0.8375591360409484, 0.39128093552169463`, 0.43888845888447725`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 280}], {
             RGBColor[
             0.8618076261846251, 0.8926460242475305, 0.9866811748018813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 342}], {
             RGBColor[
             0.8039056210826716, 0.8472056884406141, 0.9809649355157049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 393}], {
             RGBColor[
             0.9265013752169766, 0.9163982113364901, 0.6727335593092565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 480}], {
             RGBColor[
             0.9288182211336637, 0.9242134766347667, 0.6817340681959465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 485}], {
             RGBColor[
             0.7137140798491381, 0.7753231853160283, 0.972949209068104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 173}], {
             RGBColor[
             0.6920449639595923, 0.7572629642103839, 0.9717224288481764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 242}], {
             RGBColor[
             0.7406462005536159, 0.7967880773560111, 0.9755295860994676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 249}], {
             RGBColor[
             0.9298273497237228, 0.9468831054513975, 0.9931689567549646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 269}], {
             RGBColor[
             0.920928084496231, 0.939787072923115, 0.9923201368930985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 282}], {
             RGBColor[
             0.9567991743463533, 0.9672394188277376, 0.9558603655778208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 310}], {
             RGBColor[
             0.9105771355403323, 0.7666671940085924, 0.610820453740317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 314}], {
             RGBColor[
             0.9641071470998932, 0.9709070865935641, 0.8636611195864364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 323}], {
             RGBColor[
             0.7803638729582387, 0.8290326730748355, 0.9786563067617874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 406}], {
             RGBColor[
             0.7751936800784274, 0.8248352775804697, 0.9782492902392481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 411}], {
             RGBColor[
             0.8691094781962995, 0.5069099387611526, 0.45322098686274714`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 419}], {
             RGBColor[
             0.9626686089386223, 0.9703122140951341, 0.8875014197361196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 220}], {
             RGBColor[
             0.7089059092220502, 0.6591127708503449, 0.6034161452746494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 254}], {
             RGBColor[
             0.9481920135866346, 0.8257515716262005, 0.31130592099313936`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 325}], {
             RGBColor[
             0.9131343479494656, 0.8215566573017786, 0.6220872538849398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 392}], {
             RGBColor[
             0.8789322280695973, 0.7942848153013837, 0.618825025158205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 412}], {
             RGBColor[
             0.7826661622753637, 0.7189224294358771, 0.6092722119009323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 426}], {
             RGBColor[
             0.8725892055014137, 0.7892270612822752, 0.6182200220031686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 473}], {
             RGBColor[
             0.9437378838489026, 0.845094721064114, 0.5950381674620128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 160}], {
             RGBColor[
             0.9747796675143888, 0.9785967493426304, 0.8234771625838723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 162}], {
             RGBColor[
             0.6303904406723118, 0.7023932418896291, 0.9511817659838422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 226}], {
             RGBColor[
             0.9412983509191345, 0.9555406129381732, 0.9773036736873019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 235}], {
             RGBColor[
             0.8332777413355332, 0.8702816146589423, 0.9667687174262727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 237}], {
             RGBColor[
             0.8631019898511022, 0.41132200881133973`, 0.43001849414862137`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 274}], {
             RGBColor[
             0.9700574519383955, 0.9641416300320623, 0.6797919998593982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 284}], {
             RGBColor[
             0.6264997525647006, 0.6983038820046561, 0.950960197051871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 345}], {
             RGBColor[
             0.9032536849639743, 0.9252048290004753, 0.9736749394856244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 389}], {
             RGBColor[
             0.964371150565466, 0.9449604002941161, 0.6577017927934778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 456}], {
             RGBColor[
             0.9494033524188124, 0.9617856835951326, 0.9705311060225056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 472}], {
             RGBColor[
             0.92161883027429, 0.7763074215504915, 0.5951758200082784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 195}], {
             RGBColor[
             0.8700978566284693, 0.4165395147992195, 0.4181763165088186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 216}], {
             RGBColor[
             0.8740715653669988, 0.41912821960682806`, 0.3946619420979218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 217}], {
             RGBColor[
             0.8037264991209485, 0.36453779558820204`, 0.4355993524434657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 292}], {
             RGBColor[
             0.7931275941537256, 0.35625785047314623`, 0.4345429526487312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 398}], {
             RGBColor[
             0.8710766812265248, 0.4172695205817712, 0.4165194217826521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 399}], {
             RGBColor[
             0.8379541812815049, 0.270907562023312, 0.18312344590586047`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 464}], {
             RGBColor[
             0.7276441430940129, 0.3041410479768464, 0.4286729641410687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 481}], {
             RGBColor[
             0.7608912199358888, 0.3310745499286538, 0.43132993213274207`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 496}], {
             RGBColor[
             0.7339182889266278, 0.30923468221081185`, 0.4291668878839656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 172}], {
             RGBColor[
             0.9157578492069162, 0.7462518786947314, 0.5879930293126645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 197}], {
             RGBColor[
             0.8319613884935784, 0.8692211521367048, 0.9650117241018752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 201}], {
             RGBColor[
             0.936580732398355, 0.8372168131191178, 0.6051826060750845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 223}], {
             RGBColor[
             0.9543168682604793, 0.9654501756647041, 0.9622138053527373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 236}], {
             RGBColor[
             0.9595054880278513, 0.969319839791625, 0.9534308254953455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 289}], {
             RGBColor[
             0.972172341280227, 0.9781569334782008, 0.9046799496749531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 314}], {
             RGBColor[
             0.9757019172784059, 0.9796165038594133, 0.8461857411352494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 411}], {
             RGBColor[
             0.8768393249819746, 0.5127162169383854, 0.4415707345619556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 466}], {
             RGBColor[
             0.8754385269409607, 0.5019490693615368, 0.4402293287759057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 470}], {
             RGBColor[
             0.9712795874755888, 0.9777877568372566, 0.9194751905905905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 493}], {
             RGBColor[
             0.9757235974714513, 0.9796254691763933, 0.8458264442299465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 199}], {
             RGBColor[
             0.7629093267796432, 0.8110473781208762, 0.8425451666103327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[
             0.7538675123905223, 0.7821687949137224, 0.6609323948793515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 219}], {
             RGBColor[
             0.6747116644564157, 0.7440971398088195, 0.9693831201549007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 244}], {
             RGBColor[
             0.7059111612707645, 0.5916723399345474, 0.5893956822199717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 295}], {
             RGBColor[
             0.6117430435792953, 0.6949055746003693, 0.9631069965010877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 341}], {
             RGBColor[
             0.73926832509567, 0.7952479095284753, 0.9646017583826207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 374}], {
             RGBColor[
             0.7626163572631104, 0.8103662223397196, 0.806693951936196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 376}], {
             RGBColor[
             0.6007882540980525, 0.6863476097981387, 0.9620151254639255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 397}], {
             RGBColor[
             0.7594334801643241, 0.8009441111661382, 0.6825551286357542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 455}], {
             RGBColor[
             0.6744760544973288, 0.7439130795180788, 0.9693596367560792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 198}], {
             RGBColor[
             0.951942814645732, 0.9611205734299781, 0.8580502086960725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 250}], {
             RGBColor[
             0.8812594996215116, 0.9081564201190653, 0.9885365118551841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 365}], {
             RGBColor[
             0.8644335111197348, 0.5276016752393733, 0.4558313705796173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 394}], {
             RGBColor[
             0.9480051031833161, 0.9595152116534029, 0.9249789074068553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 467}], {
             RGBColor[
             0.9245684973216617, 0.8659085731192606, 0.6310678389892661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 479}], {
             RGBColor[
             0.9238178474285423, 0.9420060278675829, 0.9896396233141057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 198}], {
             RGBColor[
             0.9948904201472166, 0.9914794502896925, 0.6852319495752558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 227}], {
             RGBColor[
             0.9383334493294981, 0.7742062048462757, 0.4344394452005812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 250}], {
             RGBColor[
             0.9242071051229961, 0.9385152969787796, 0.8157182527343674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 263}], {
             RGBColor[
             0.9820419930355484, 0.9837581233249566, 0.7909621665544164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 270}], {
             RGBColor[
             0.76685453798402, 0.8137357206816647, 0.8011881481541319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 479}], {
             RGBColor[
             0.9667654529300269, 0.9723649047272973, 0.816821364193289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 485}], {
             RGBColor[
             0.7719571165938444, 0.8178782238656668, 0.8015898418336584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 190}], {
             RGBColor[
             0.9618762584530596, 0.891691119077953, 0.584981312602726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 356}], {
             RGBColor[
             0.9833055024739408, 0.9869560084172937, 0.9080454789127252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 360}], {
             RGBColor[
             0.683495205532421, 0.7467016603025645, 0.9229278496055344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.8605393035625163, 0.4094107615733261, 0.4343564535795672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 193}], {
             RGBColor[
             0.8897185721948611, 0.9146105513485909, 0.979257534452101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 247}], {
             RGBColor[
             0.6876907150585957, 0.7527299407943306, 0.9615758523147684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 278}], {
             RGBColor[
             0.8251528855613743, 0.8640705297286286, 0.9728489838095893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 370}], {
             RGBColor[
             0.8094346413696681, 0.8517913179029872, 0.9712823361239034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 401}], {
             RGBColor[
             0.8286574554539151, 0.8668083263643991, 0.9731982865844102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 410}], {
             RGBColor[
             0.9413412174653533, 0.9557729565473774, 0.9841781975571526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 422}], {
             RGBColor[
             0.9582692075731941, 0.9683978238527652, 0.9555235258314969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 428}], {
             RGBColor[
             0.9703057275906395, 0.9743825636393578, 0.7614222321559622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 437}], {
             RGBColor[
             0.7496754062731755, 0.8037284463656653, 0.9662685840078806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 451}], {
             RGBColor[
             0.9057328606500019, 0.9273799102664402, 0.9807849915810763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 166}], {
             RGBColor[
             0.8662275921565633, 0.894396628731041, 0.893580919196807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 192}], {
             RGBColor[
             0.9734979876596263, 0.9280827662877486, 0.5494551813047968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 239}], {
             RGBColor[
             0.8749431563834782, 0.4194886448910098, 0.3802174233496137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 251}], {
             RGBColor[
             0.9422598707348514, 0.801631562090707, 0.5228767645160101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 272}], {
             RGBColor[
             0.9671134845442342, 0.9030191857655558, 0.5430220617622866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 344}], {
             RGBColor[
             0.8691859852369526, 0.8967077478900611, 0.8938757841713051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 435}], {
             RGBColor[
             0.9745130211201998, 0.9795157036012505, 0.8833913897656936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 439}], {
             RGBColor[
             0.8356293013821756, 0.8704930114224663, 0.8905311675297007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 453}], {
             RGBColor[
             0.990033703655244, 0.9901466945863796, 0.8148308525881596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 167}], {
             RGBColor[
             0.9555531850487585, 0.9637552316079133, 0.8386027209245817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 235}], {
             RGBColor[
             0.8533894392966156, 0.8831663375675537, 0.8286263975642811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 237}], {
             RGBColor[
             0.8765097884918237, 0.4199118240837473, 0.3379236142406269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 274}], {
             RGBColor[
             0.9901691498994779, 0.9770263529406737, 0.5416496799974067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 284}], {
             RGBColor[
             0.646611450525783, 0.7111886049132674, 0.8128178771898793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 300}], {
             RGBColor[
             0.8130669793814727, 0.851495836246799, 0.8247238592323656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 305}], {
             RGBColor[
             0.8933768601569751, 0.549559528100034, 0.3540755411158087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 389}], {
             RGBColor[
             0.9844828485265482, 0.9578451232027274, 0.5195594729314862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 432}], {
             RGBColor[
             0.9944513777999092, 0.9905403831027926, 0.6374448995261388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 460}], {
             RGBColor[
             0.9034118568783099, 0.6266929102638157, 0.36368506530906664`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 183}], {
             RGBColor[
             0.613999178240884, 0.5945072345263709, 0.6011886593348776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 188}], {
             RGBColor[
             0.9511057266854568, 0.8388789008370536, 0.3054455086479846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 202}], {
             RGBColor[
             0.9612696179815914, 0.8727792084053032, 0.37765809560105035`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 243}], {
             RGBColor[
             0.9557366575190209, 0.8719965111080283, 0.5886563248517951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 273}], {
             RGBColor[
             0.8546835353686973, 0.3420351785349799, 0.1968326432850394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 279}], {
             RGBColor[
             0.6725577975003754, 0.6461671517854611, 0.6048855673045671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 285}], {
             RGBColor[
             0.9613231717403763, 0.8728937544802283, 0.3834870917492893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 287}], {
             RGBColor[
             0.8546835353686973, 0.3420351785349799, 0.1968326432850394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 335}], {
             RGBColor[
             0.7899846891870721, 0.7423953488030595, 0.6139335035911301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 354}], {
             RGBColor[
             0.9394127511998513, 0.8598221685031351, 0.6162884402935158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 396}], {
             RGBColor[
             0.9397920071558149, 0.860105016974118, 0.6156464588858646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 409}], {
             RGBColor[
             0.7124319417000587, 0.6795601140973706, 0.607742407891492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 430}], {
             RGBColor[
             0.9361818591728863, 0.8574125745195247, 0.6217574977435694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 459}], {
             RGBColor[
             0.9239012415165317, 0.7360008115607107, 0.25762735653800417`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 477}], {
             RGBColor[
             0.8311519544771664, 0.7745555293304855, 0.6180366718652797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 226}], {
             RGBColor[
             0.6170208220381398, 0.6922218283937833, 0.9668659572252801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 284}], {
             RGBColor[
             0.3022222236837059, 0.4349850974602662, 0.9405224805898492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 345}], {
             RGBColor[
             0.5789761560829796, 0.6618860444560855, 0.9632372230236027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 389}], {
             RGBColor[
             0.6400936216844713, 0.6816416157497263, 0.6472640763314561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 456}], {
             RGBColor[
             0.6251258235378176, 0.6984668990507428, 0.9600933895604838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 472}], {
             RGBColor[
             0.5973413013932953, 0.5129886370061016, 0.5847381035462567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 207}], {
             RGBColor[
             0.9165481832175214, 0.9357201227402088, 0.9719828614053619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 209}], {
             RGBColor[
             0.9006999027778112, 0.9230831341076964, 0.9704712382690954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 231}], {
             RGBColor[
             0.8642056141818695, 0.41214509003020694`, 0.4281503460279573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 233}], {
             RGBColor[
             0.9760572627386392, 0.9800121192619307, 0.8514327392397867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 266}], {
             RGBColor[
             0.7414022435909255, 0.7966486986945014, 0.955875190905385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 317}], {
             RGBColor[
             0.8438753382940531, 0.8785019202033825, 0.964857766230925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 326}], {
             RGBColor[
             0.8955694119190312, 0.9189922199603695, 0.9699818874709417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 343}], {
             RGBColor[
             0.8188052532126823, 0.8589169791981119, 0.9623590144432792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 355}], {
             RGBColor[
             0.8438753382940531, 0.8785019202033825, 0.964857766230925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 379}], {
             RGBColor[
             0.9371654028721985, 0.9521597340533294, 0.9739493502212343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 440}], {
             RGBColor[
             0.8052541829393276, 0.8483307801086186, 0.9610083704003828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 180}], {
             RGBColor[
             0.5715192863867349, 0.658793567596061, 0.9613907796734527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 205}], {
             RGBColor[
             0.6830045129441651, 0.7439362280799203, 0.8368739128970892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 259}], {
             RGBColor[
             0.6675418396255978, 0.7342361433916554, 0.9450867279963999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 316}], {
             RGBColor[
             0.6176380193031434, 0.695181563833794, 0.9658920128838309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 331}], {
             RGBColor[
             0.6652240388924928, 0.6855800938961172, 0.6213130985345034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 348}], {
             RGBColor[
             0.668476075997944, 0.2546118639515619, 0.42442780111473677`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 372}], {
             RGBColor[
             0.668476075997944, 0.2546118639515619, 0.42442780111473677`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 404}], {
             RGBColor[
             0.668476075997944, 0.2546118639515619, 0.42442780111473677`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 418}], {
             RGBColor[
             0.5123124450960429, 0.6125407331911124, 0.9554895950529859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 431}], {
             RGBColor[
             0.645896935798402, 0.6100471966276989, 0.6000716422927999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 444}], {
             RGBColor[
             0.6575990526077943, 0.7268208291135971, 0.9619172729233669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 486}], {
             RGBColor[
             0.5460202466120541, 0.6388735239242003, 0.9588492736907872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 178}], {
             RGBColor[
             0.795214247462523, 0.457345998598601, 0.44710795215626986`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 185}], {
             RGBColor[
             0.8271682737677979, 0.8656527251075937, 0.9734426077831948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 277}], {
             RGBColor[
             0.8509941095069788, 0.8817604073612053, 0.8587024206501743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 288}], {
             RGBColor[
             0.6428825031299363, 0.7199576093149754, 0.9657145544112533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 313}], {
             RGBColor[
             0.6768751923204919, 0.747499311773546, 0.9684282514783503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 333}], {
             RGBColor[
             0.8120049385446457, 0.8538414959335239, 0.9816903176809112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 358}], {
             RGBColor[
             0.8036639446562631, 0.7041693598522505, 0.604695130815093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 361}], {
             RGBColor[
             0.8136660069136705, 0.8551659867624843, 0.981848751864802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 386}], {
             RGBColor[
             0.8506890843178316, 0.8801688225860056, 0.7572348036758294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 498}], {
             RGBColor[
             0.7808109574890819, 0.346636000300821, 0.4333153454115133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.7923005717208974, 0.3556117742630176, 0.434460522781591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 344}], {
             RGBColor[
             0.7452221082430814, 0.800892441948073, 0.975240433319271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 387}], {
             RGBColor[
             0.6188574962283588, 0.6999250076894272, 0.9641842271363195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 435}], {
             RGBColor[
             0.8505491441263286, 0.8837003976592623, 0.9647560389136596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 439}], {
             RGBColor[
             0.7116654243883045, 0.774677705480478, 0.9718958166776667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 453}], {
             RGBColor[
             0.8660698266613729, 0.8943313886443913, 0.8961955017361254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 172}], {
             RGBColor[
             0.8956243244100004, 0.7307338902744872, 0.6046539737257121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[
             0.9164472076014393, 0.8216988246988736, 0.6218435504881321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 218}], {
             RGBColor[
             0.9555683924814902, 0.9640985154391691, 0.8628466855482969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 235}], {
             RGBColor[
             0.8140512588699029, 0.8554400969242252, 0.9818942757669822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 236}], {
             RGBColor[
             0.9393719632309356, 0.9538018513713807, 0.9700917699083931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 274}], {
             RGBColor[
             0.9508309694727652, 0.9493001122973452, 0.6949175582001077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 284}], {
             RGBColor[
             0.6072732700990703, 0.6834623642699389, 0.9660857553925803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 289}], {
             RGBColor[
             0.9520388164833111, 0.9626389450579564, 0.9213408940880007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 300}], {
             RGBColor[
             0.77372879895476, 0.8237695956034705, 0.9779917374350666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 305}], {
             RGBColor[
             0.8671514065391667, 0.5310753676711483, 0.4562541265842761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 432}], {
             RGBColor[
             0.9551131973731966, 0.9628141424594641, 0.7907127777288399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 456}], {
             RGBColor[
             0.930176869953182, 0.9469441658604156, 0.985656664363215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 493}], {
             RGBColor[
             0.9555900726745354, 0.9641074807561489, 0.862487388642994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 181}], {
             RGBColor[
             0.8729965405314221, 0.40904349553426433`, 0.24071514471745728`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 189}], {
             RGBColor[
             0.853015318579831, 0.8706884428084631, 0.6833016560081204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 232}], {
             RGBColor[
             0.9010918780975486, 0.6227799081753085, 0.2675324727223643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 280}], {
             RGBColor[
             0.9149637329203356, 0.919289864266385, 0.6894212035513515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 302}], {
             RGBColor[
             0.8840947156445038, 0.49434893270475533`, 0.2513427697393404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 326}], {
             RGBColor[
             0.9087558014433601, 0.9143398282164557, 0.6888290855051917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 338}], {
             RGBColor[
             0.9846294152917778, 0.9734516219499484, 0.6467497851491566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 346}], {
             RGBColor[
             0.7631191263509255, 0.7989217456536462, 0.6753939406153734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 370}], {
             RGBColor[
             0.8281204968230267, 0.8512404188443947, 0.6808203728307386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 383}], {
             RGBColor[
             0.9294711285032144, 0.7411518383791156, 0.30538856254325464`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 390}], {
             RGBColor[
             0.9836192998420231, 0.9564061933751528, 0.3908645024322665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 395}], {
             RGBColor[
             0.5916206532263137, 0.6426262670481273, 0.6641736397614548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 443}], {
             RGBColor[
             0.9851658356912735, 0.9736734455705154, 0.637859910918019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 480}], {
             RGBColor[
             0.9819743278693742, 0.9508573166536212, 0.3844740969454167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 211}], {
             RGBColor[
             0.9479461655909612, 0.8299912446398046, 0.28395153462889955`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 236}], {
             RGBColor[
             0.9615111046285072, 0.9249857174992127, 0.6246686259161447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 289}], {
             RGBColor[
             0.9741779578808827, 0.9338228111857884, 0.5759177500957523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 308}], {
             RGBColor[
             0.8874477025627526, 0.8666665571750543, 0.6415799806408033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 362}], {
             RGBColor[
             0.9000500332301586, 0.8766701972915456, 0.6427939746626905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 369}], {
             RGBColor[
             0.8648100992341814, 0.8489818894026169, 0.6393236759014422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 456}], {
             RGBColor[
             0.9523160113507536, 0.9181280319882474, 0.6402335203709666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 470}], {
             RGBColor[
             0.9732852040762447, 0.9334536345448443, 0.5907129910113897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 214}], {
             RGBColor[
             0.5820016010870387, 0.6333573335190533, 0.6650126464396886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 223}], {
             RGBColor[
             0.9686139422395793, 0.9625780252812208, 0.6812015966418321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 268}], {
             RGBColor[
             0.9897771446731028, 0.9766526142120822, 0.5688501044484592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 466}], {
             RGBColor[
             0.8849699095936939, 0.5000343024392147, 0.25288785630196886`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 491}], {
             RGBColor[
             0.9414407008665516, 0.7950798855426213, 0.3164813925893477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 192}], {
             RGBColor[
             0.9754136890484884, 0.9277887251370877, 0.43874938618926834`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 208}], {
             RGBColor[
             0.9938969171228874, 0.9893544477792164, 0.5770952765669656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 219}], {
             RGBColor[
             0.906423172588101, 0.9240071200263744, 0.7866905046784441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 238}], {
             RGBColor[
             0.9876795251954442, 0.9876124926725949, 0.7536409203814176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 258}], {
             RGBColor[
             0.832956121989973, 0.8666141017288519, 0.7793679956634447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 272}], {
             RGBColor[
             0.9690291859330963, 0.902725144614895, 0.43231626664675815`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 293}], {
             RGBColor[
             0.8899699399076089, 0.9111537296071741, 0.7850506002090539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 403}], {
             RGBColor[
             0.7710113795882692, 0.8167769369051774, 0.7741821924065788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 471}], {
             RGBColor[
             0.7878605197111979, 0.8304558279020833, 0.7755086184374896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 497}], {
             RGBColor[
             0.993386973906615, 0.9904471251042006, 0.680300821111901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 197}], {
             RGBColor[
             0.7912371834846171, 0.648408063026363, 0.5944560431133522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 201}], {
             RGBColor[
             0.8958565273893938, 0.616403724008776, 0.23462692508656147`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 211}], {
             RGBColor[
             0.9052163439813442, 0.6535122778218749, 0.24215805321957734`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 218}], {
             RGBColor[
             0.9349777122694447, 0.7588034147490715, 0.47563006014672626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 235}], {
             RGBColor[
             0.7934605786578575, 0.6501449962341276, 0.5946776503654115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 236}], {
             RGBColor[
             0.9187812830188902, 0.7485067506812831, 0.5828751445068225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 289}], {
             RGBColor[
             0.9314481362712657, 0.7573438443678588, 0.53412426868643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 300}], {
             RGBColor[
             0.7531381187427145, 0.6184744949133729, 0.590775112033496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 308}], {
             RGBColor[
             0.8447178809531356, 0.6901875903571248, 0.5997864992314811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 314}], {
             RGBColor[
             0.9349777122694447, 0.7588034147490715, 0.47563006014672626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 466}], {
             RGBColor[
             0.8482890569349865, 0.35474034328797555`, 0.19319220811689025`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 470}], {
             RGBColor[
             0.9305553824666277, 0.7569746677269147, 0.5489195096020675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 493}], {
             RGBColor[
             0.93499939246249, 0.7588123800660513, 0.4752707632414235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 242}], {
             RGBColor[
             0.4993986506543562, 0.6044049082930203, 0.9537525477440822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 249}], {
             RGBColor[
             0.6885797998244632, 0.7544999363884066, 0.9713919183995792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 269}], {
             RGBColor[
             0.6796805345969713, 0.7474039038601241, 0.9705430985377133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 282}], {
             RGBColor[
             0.7155516244470936, 0.7748562497647467, 0.9340833272224354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 310}], {
             RGBColor[
             0.6693295856410726, 0.5742840249456016, 0.5890434153849315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 323}], {
             RGBColor[
             0.539116323058979, 0.6366495040118447, 0.956879268406402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 406}], {
             RGBColor[
             0.5339461301791677, 0.6324521085174788, 0.9564722518838626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 419}], {
             RGBColor[
             0.7214210590393626, 0.7779290450321432, 0.8657243813807343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 499}], {
             RGBColor[
             0.561456642886619, 0.654330544745058, 0.9589496386856784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 210}], {
             RGBColor[
             0.8612402223673111, 0.8900377038521244, 0.8721006074637643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 225}], {
             RGBColor[
             0.9825702737942618, 0.9549607143149663, 0.5589522152471451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 252}], {
             RGBColor[
             0.9934808832238459, 0.9906846217906866, 0.6931851869168794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 309}], {
             RGBColor[
             0.9760401387267699, 0.9802364367491672, 0.8620790352713976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 320}], {
             RGBColor[
             0.8361701372859403, 0.8704527628468539, 0.8696018556761185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 393}], {
             RGBColor[
             0.983835976501616, 0.9592302267480005, 0.5638692312573159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 424}], {
             RGBColor[
             0.9445206421661017, 0.8067027725772344, 0.502855250563593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 182}], {
             RGBColor[
             0.7317055500398084, 0.7902521492014133, 0.9739941671869217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 208}], {
             RGBColor[
             0.8118677310809452, 0.8497788147972193, 0.7636990664306691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 351}], {
             RGBColor[
             0.7510594104590849, 0.8056843921531984, 0.9758401556711074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 359}], {
             RGBColor[
             0.7472251552283646, 0.8026270611103077, 0.9754744409843212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 371}], {
             RGBColor[
             0.6101712313695146, 0.6944035193833198, 0.9624540609457266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 463}], {
             RGBColor[
             0.7987983443629878, 0.842926653194944, 0.951843350139006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 483}], {
             RGBColor[
             0.6239067158819064, 0.7055546044870051, 0.9635353686012798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 178}], {
             RGBColor[
             0.8892116444215744, 0.5301428991242729, 0.3962440470192613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 244}], {
             RGBColor[
             0.9355047651105703, 0.7717927452059878, 0.5207598872463801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 261}], {
             RGBColor[
             0.9835600228741969, 0.986330129193494, 0.8710859242476277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 262}], {
             RGBColor[
             0.8748083544481332, 0.41943290082649287`, 0.38245144027450473`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 299}], {
             RGBColor[
             0.8748083544481332, 0.41943290082649287`, 0.38245144027450473`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 313}], {
             RGBColor[
             0.8178712877590688, 0.8566946625620538, 0.8921323937728376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 328}], {
             RGBColor[
             0.8820943854545076, 0.4754365279006312, 0.3894285517946038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 376}], {
             RGBColor[
             0.8303818579378583, 0.8664680150695792, 0.8933793304903339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 391}], {
             RGBColor[
             0.9924370557521451, 0.9909723601030695, 0.7627760080654478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 407}], {
             RGBColor[
             0.883947109712518, 0.9083135968669349, 0.8987182141914941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 448}], {
             RGBColor[
             0.9914832659046545, 0.9889323000622332, 0.658961869274728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 455}], {
             RGBColor[
             0.9040696583371347, 0.9240334847895193, 0.9007238417824877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 475}], {
             RGBColor[
             0.9531397978844192, 0.9631474932901999, 0.9054076954001705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 478}], {
             RGBColor[
             0.9338152102886346, 0.7641208713651317, 0.5193500812881785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 482}], {
             RGBColor[
             0.9736442759317545, 0.978934981359366, 0.8878706973801895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 194}], {
             RGBColor[
             0.875633032584384, 0.9020177031167766, 0.9069187852964552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 290}], {
             RGBColor[
             0.5875273787899513, 0.6730703558089015, 0.9622366843138186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 297}], {
             RGBColor[
             0.8527176470508876, 0.8128283531466165, 0.6249306616139791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 412}], {
             RGBColor[
             0.7048183973709414, 0.7693287559351812, 0.9712133690136813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 484}], {
             RGBColor[
             0.8458733854594958, 0.7856931366517205, 0.6194236080820775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 186}], {
             RGBColor[
             0.8186879609396371, 0.4756838419737526, 0.44944759254134414`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 244}], {
             RGBColor[
             0.8530234455990214, 0.384641594275279, 0.1974717579678386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 261}], {
             RGBColor[
             0.8850602841081058, 0.5276665169336164, 0.4310224493020036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 288}], {
             RGBColor[
             0.7519393345709835, 0.422881737540276, 0.44324429760741224`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 313}], {
             RGBColor[
             0.7746011273646871, 0.44124287251265637`, 0.4450534289854769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 321}], {
             RGBColor[
             0.877544595635901, 0.486277417662654, 0.217430570537542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 391}], {
             RGBColor[
             0.890978306026738, 0.5307613375400002, 0.3588158385138837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 407}], {
             RGBColor[
             0.8186516753336532, 0.4756554953825771, 0.44944397593124796`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 455}], {
             RGBColor[
             0.8320667077500644, 0.48613542066430004`, 0.4507810609919103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 475}], {
             RGBColor[
             0.8647801341149206, 0.5122114263314204, 0.45390363007036555`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 498}], {
             RGBColor[
             0.8317222899734411, 0.24483699829778002`, 0.1780106067447566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 222}], {
             RGBColor[
             0.6927248389991689, 0.7055923117354708, 0.6172622063796034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 245}], {
             RGBColor[
             0.6580085819756472, 0.5632402012707469, 0.5880623666384724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 255}], {
             RGBColor[
             0.6878224314420263, 0.2713687046611283, 0.4256605337763233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 294}], {
             RGBColor[
             0.7116106973850691, 0.768900558823814, 0.8455732699785657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 296}], {
             RGBColor[
             0.6964879928670558, 0.759316677828338, 0.9470600400606889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 312}], {
             RGBColor[
             0.6664527656776476, 0.7361009905837579, 0.9696291969834214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 327}], {
             RGBColor[
             0.7085250315763644, 0.7676245567139204, 0.8967107378759368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 334}], {
             RGBColor[
             0.7094062086504341, 0.7679889460792662, 0.8821073533454339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 385}], {
             RGBColor[
             0.6826582149540767, 0.7490024521050213, 0.9704702466835993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 415}], {
             RGBColor[
             0.6699467838833615, 0.6154793123946146, 0.5979220160153735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 438}], {
             RGBColor[
             0.7005160867771913, 0.7623208236711188, 0.9402415277659785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 205}], {
             RGBColor[
             0.8837335713370682, 0.9071482038212957, 0.8534172892263316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 230}], {
             RGBColor[
             0.8387920376583604, 0.7422001452272102, 0.6103116333090413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 331}], {
             RGBColor[
             0.8659530972853959, 0.8487920696374924, 0.6378564748637457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 382}], {
             RGBColor[
             0.8377624124250984, 0.8738588530157791, 0.9842853335539499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 413}], {
             RGBColor[
             0.69385125705525, 0.7603489948757104, 0.9704020545883891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 418}], {
             RGBColor[
             0.7130415034889459, 0.7757527089324877, 0.9720329713822282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 474}], {
             RGBColor[
             0.7057672101721855, 0.7700229024236092, 0.9713401220673288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 490}], {
             RGBColor[
             0.7953002990547539, 0.8400139052184983, 0.9802317593720781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 189}], {
             RGBColor[
             0.7854390051884653, 0.3502514663380445, 0.4337766259546231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 302}], {
             RGBColor[
             0.822868087556541, 0.1767797185852455, 0.16953181251094157`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 370}], {
             RGBColor[
             0.7688424573505958, 0.33728611702866546`, 0.4321224371697018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 390}], {
             RGBColor[
             0.8725083260299267, 0.4073966333825042, 0.2388185235707204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 422}], {
             RGBColor[
             0.8680655014862798, 0.4150237876618507, 0.42161656364143074`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 443}], {
             RGBColor[
             0.873539349929427, 0.41890813484607925`, 0.4034821292278887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 451}], {
             RGBColor[
             0.8330412702041516, 0.3876785119376341, 0.43845754080781707`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 237}], {
             RGBColor[
             0.8226948667451142, 0.3794285706650379, 0.43747069160955077`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 351}], {
             RGBColor[
             0.8528004606546189, 0.8854639549468986, 0.9858220633128378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 359}], {
             RGBColor[
             0.8489662054238987, 0.8824066239040079, 0.9854563486260517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 371}], {
             RGBColor[
             0.7119122815650486, 0.7741830821770199, 0.9724359685874571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 460}], {
             RGBColor[
             0.8495969351316004, 0.5862096568451063, 0.4632321426779905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 463}], {
             RGBColor[
             0.9005393945585218, 0.9227062159886442, 0.9618252577807365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 483}], {
             RGBColor[
             0.7256477660774404, 0.7853341672807054, 0.9735172762430102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 202}], {
             RGBColor[
             0.6458561901163835, 0.7094349073267345, 0.7167848250808098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 206}], {
             RGBColor[
             0.5408771443401339, 0.6308497074817386, 0.9596689838264445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 243}], {
             RGBColor[
             0.6403232296538129, 0.7086522100294597, 0.9277830543315546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 273}], {
             RGBColor[
             0.644407916791892, 0.2331389778159341, 0.42291712960487904`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 279}], {
             RGBColor[
             0.3571443696351674, 0.48282285070689246`, 0.9440122967843265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 283}], {
             RGBColor[
             0.4892246253377166, 0.590498367063366, 0.9545207434525174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 285}], {
             RGBColor[
             0.6459097438751682, 0.7095494534016598, 0.7226138212290487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 396}], {
             RGBColor[
             0.6243785792906069, 0.6967607158955493, 0.9547731883656241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 430}], {
             RGBColor[
             0.6207684313076783, 0.694068273440956, 0.9608842272233288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 477}], {
             RGBColor[
             0.5157385266119585, 0.6112112282519169, 0.9571634013450392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 221}], {
             RGBColor[
             0.964661135267735, 0.9310880819958933, 0.6273035174681806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 253}], {
             RGBColor[
             0.9391117023462816, 0.9535055350934143, 0.9669884954273025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 287}], {
             RGBColor[
             0.8668700492204069, 0.41413222131933614`, 0.4236401525036676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 301}], {
             RGBColor[
             0.97931316265111, 0.9804195088228512, 0.6921576053867768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 316}], {
             RGBColor[
             0.9152289791368378, 0.9344620998854554, 0.9647105399672269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 336}], {
             RGBColor[
             0.9323246854962269, 0.9480937520858453, 0.9663411437013028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 354}], {
             RGBColor[
             0.9576925219774156, 0.9679677326796695, 0.956499704121458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 388}], {
             RGBColor[
             0.6184680584569546, 0.6881366770617381, 0.9406134133767244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 436}], {
             RGBColor[
             0.9801797965176104, 0.9822731510331709, 0.786485353511084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 473}], {
             RGBColor[
             0.9675951191314796, 0.9753530734231557, 0.9397371901506066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 187}], {
             RGBColor[
             0.8811913247438589, 0.5691651246791712, 0.4545200102249458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 216}], {
             RGBColor[
             0.9670591855846733, 0.9743910540666044, 0.9154625028128078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 224}], {
             RGBColor[
             0.6988230540821893, 0.7623985844588059, 0.9626700664030546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 286}], {
             RGBColor[
             0.9195861793978635, 0.9384374714876184, 0.9824981424391137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 330}], {
             RGBColor[
             0.9029389814951918, 0.9251634477561772, 0.9809103178420279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 333}], {
             RGBColor[
             0.931378339845198, 0.9478402201386547, 0.9836228892295664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 357}], {
             RGBColor[
             0.9493402046300459, 0.9617385880776657, 0.9706379987573062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 358}], {
             RGBColor[
             0.9230373459568153, 0.7981680840573814, 0.6066277023637481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 361}], {
             RGBColor[
             0.9330394082142228, 0.9491647109676153, 0.9837813234134571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 386}], {
             RGBColor[
             0.9700624856183839, 0.9741675467911365, 0.7591673752244846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 398}], {
             RGBColor[
             0.9625668593739624, 0.9716030055290191, 0.9482487223399032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 441}], {
             RGBColor[
             0.9702357659854222, 0.9757046516967067, 0.8628183448458446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 464}], {
             RGBColor[
             0.7474180521751945, 0.8019102966216319, 0.966479035877528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 481}], {
             RGBColor[
             0.7972886674380083, 0.842310549549343, 0.9704644878650381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 288}], {
             RGBColor[
             0.6780930733456075, 0.7474643743777029, 0.9692240149888649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 295}], {
             RGBColor[
             0.7355511221961953, 0.7933373941460293, 0.9742765198106204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 321}], {
             RGBColor[
             0.8665009649429838, 0.8425578945612698, 0.6305034243840595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 341}], {
             RGBColor[
             0.86307640371257, 0.8936797290741354, 0.9757712816921535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 373}], {
             RGBColor[
             0.8250857707815415, 0.6690646584435072, 0.5966989253306347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 397}], {
             RGBColor[
             0.8832415587812241, 0.8993759307117981, 0.6937246519452869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 455}], {
             RGBColor[
             0.7982841331142289, 0.8423448990637389, 0.9805291600656119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 495}], {
             RGBColor[
             0.6690237664421624, 0.7401015024658661, 0.9685100459274598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 498}], {
             RGBColor[
             0.804284670966196, 0.3649738436759726, 0.43565498579658757`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 216}], {
             RGBColor[
             0.8948696650880742, 0.5789915278484243, 0.4145782258789176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 224}], {
             RGBColor[
             0.7160455774197516, 0.43766321477655873`, 0.4460499349390822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 260}], {
             RGBColor[
             0.8938536130503593, 0.5691057328705197, 0.26086052668206744`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 328}], {
             RGBColor[
             0.8417601152242626, 0.32199212177866543`, 0.1876228395410453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 398}], {
             RGBColor[
             0.8918747809476003, 0.5771328288233675, 0.43643570556364786`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 399}], {
             RGBColor[
             0.8587522810025803, 0.43077087026490835`, 0.2030397296868562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 407}], {
             RGBColor[
             0.8250464850812875, 0.5248088053263934, 0.45556765296748714`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 464}], {
             RGBColor[
             0.7484422428150884, 0.4640043562184427, 0.44858924792206445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 478}], {
             RGBColor[
             0.8582918854653653, 0.4286803216585246, 0.2026555643652767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 481}], {
             RGBColor[
             0.7816893196569642, 0.49093785817025015`, 0.4512462159137378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 200}], {
             RGBColor[
             0.9833385485462194, 0.9558213896490767, 0.549972930293113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 228}], {
             RGBColor[
             0.8691456157549405, 0.39605342202305593`, 0.2257550291469503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 256}], {
             RGBColor[
             0.7246257422260621, 0.7528755033706742, 0.6503781654126017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 279}], {
             RGBColor[
             0.6942509180797402, 0.7271945170175751, 0.6482691460974335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 298}], {
             RGBColor[
             0.9448754042623653, 0.9282614431263148, 0.670384989075071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 318}], {
             RGBColor[
             0.8188257796862275, 0.8290067624630973, 0.6580295252240245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 335}], {
             RGBColor[
             0.811677809766437, 0.8234227140351734, 0.6573170823839964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 409}], {
             RGBColor[
             0.7341250622794235, 0.7605874793294847, 0.6511259866843584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 430}], {
             RGBColor[
             0.9578749797522511, 0.9384399397516388, 0.6651410765364356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 459}], {
             RGBColor[
             0.9455943620958966, 0.8170281767928247, 0.30101093533087053`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 302}], {
             RGBColor[
             0.7965371803015471, 0.43555690350853554`, 0.44440425097650627`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 346}], {
             RGBColor[
             0.6317828233364904, 0.7107337018593164, 0.964986162471122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 370}], {
             RGBColor[
             0.6967841938085917, 0.763052375050065, 0.9704125946864872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 383}], {
             RGBColor[
             0.7981348254887795, 0.6529637945847859, 0.5949807843990034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 390}], {
             RGBColor[
             0.852282996827588, 0.868218149580823, 0.6804567242880152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 422}], {
             RGBColor[
             0.8456187600121177, 0.8796588809998429, 0.9546537843940808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 443}], {
             RGBColor[
             0.8538295326768384, 0.8854854017761856, 0.9274521327737676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 451}], {
             RGBColor[
             0.7930824130889255, 0.8386409674135179, 0.9799152501436602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 349}], {
             RGBColor[
             0.9444162401519338, 0.8173359449320404, 0.2741342059889573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 378}], {
             RGBColor[
             0.9481253125733577, 0.8815495293352567, 0.6133562073192933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 467}], {
             RGBColor[
             0.939691000713254, 0.798601945150375, 0.2703321674209706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 487}], {
             RGBColor[
             0.7059391955900425, 0.6892060680921073, 0.6106657507779458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 226}], {
             RGBColor[
             0.9193625801591307, 0.8147068962311195, 0.6200353904643134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 237}], {
             RGBColor[
             0.8484781426777663, 0.3174328643399705, 0.1918396386666291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 271}], {
             RGBColor[
             0.9386711257121461, 0.791428970641415, 0.2858100932376953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 311}], {
             RGBColor[
             0.9399843062244636, 0.830286919574889, 0.5920752729944658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 366}], {
             RGBColor[
             0.894417918078072, 0.7948166997924977, 0.6176561463266594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 405}], {
             RGBColor[
             0.8952961555044594, 0.6155537983222765, 0.23424699654663333`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 423}], {
             RGBColor[
             0.9389285350700445, 0.7922972728481981, 0.2868100799854524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 429}], {
             RGBColor[
             0.9336219753110542, 0.8255419035970288, 0.6028450396692051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 488}], {
             RGBColor[
             0.6779761640766604, 0.6220189961714713, 0.5983344171064984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 219}], {
             RGBColor[
             0.8878139897084307, 0.8621719927917547, 0.6346352110499283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 251}], {
             RGBColor[
             0.9255663892440432, 0.7395023937054264, 0.2601156757719657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 258}], {
             RGBColor[
             0.8143469391103026, 0.8047789744942322, 0.627312702034929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 272}], {
             RGBColor[
             0.950420003053426, 0.8408900173802752, 0.28026097301824227`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 435}], {
             RGBColor[
             0.9578195396293916, 0.91738653521597, 0.6206303010216494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 453}], {
             RGBColor[
             0.9733402221644358, 0.928017526201099, 0.5520697638441152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 497}], {
             RGBColor[
             0.9747777910269446, 0.928611997869581, 0.5282455274833853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 410}], {
             RGBColor[
             0.8840798789726655, 0.91040522317599, 0.988802371270552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 428}], {
             RGBColor[
             0.9130443890979516, 0.9290148302679706, 0.7660464058693617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 437}], {
             RGBColor[
             0.6924140677804878, 0.758360712994278, 0.9708927577212803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 220}], {
             RGBColor[
             0.7441290296147901, 0.7970981882278925, 0.8953073613245406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 254}], {
             RGBColor[
             0.9834151339793746, 0.9637369890037479, 0.6031971370430306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 290}], {
             RGBColor[
             0.7005982640871137, 0.760649446687145, 0.8921867432509609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 297}], {
             RGBColor[
             0.96578853234805, 0.90040744402486, 0.5548807205511214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 350}], {
             RGBColor[
             0.9885833833508264, 0.9895469498689712, 0.8388664133409915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 377}], {
             RGBColor[
             0.8744473059605155, 0.41928359799834003`, 0.3884349480778658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 412}], {
             RGBColor[
             0.8178892826681037, 0.8569078468134246, 0.9011634279508235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 426}], {
             RGBColor[
             0.9078123258941537, 0.9272124786598227, 0.9101112380530598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 476}], {
             RGBColor[
             0.9857635120317221, 0.9881534376134187, 0.8754145122014783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.8700978566284693, 0.4165395147992196, 0.4181763165088186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 260}], {
             RGBColor[
             0.9800920549366295, 0.9704189091422144, 0.6602448391148354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 292}], {
             RGBColor[
             0.8602001761732923, 0.8909420479085487, 0.9506429037363248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 399}], {
             RGBColor[
             0.9274400568649611, 0.7629166152337974, 0.5735136436220185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 446}], {
             RGBColor[
             0.9735969814526888, 0.979829252515166, 0.9295776027771965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 496}], {
             RGBColor[
             0.7713862183326455, 0.8204072955150472, 0.9425788065891763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 213}], {
             RGBColor[
             0.9891983188838003, 0.9881831610993468, 0.711057975266304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 332}], {
             RGBColor[
             0.927370868835904, 0.9402873379478357, 0.7551692175919754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 337}], {
             RGBColor[
             0.9939985737949799, 0.9895718811217564, 0.5881599779719864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 420}], {
             RGBColor[
             0.9519341998222323, 0.9598734713224762, 0.7575120900293959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 427}], {
             RGBColor[
             0.9941239606870849, 0.9898400710054092, 0.6018075673793977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 447}], {
             RGBColor[
             0.7221018922843033, 0.7765925066599112, 0.7368238476809414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 454}], {
             RGBColor[
             0.9491580935860555, 0.9576598795651452, 0.75724730253833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 489}], {
             RGBColor[
             0.9457203524407375, 0.9549187180908663, 0.7569194077189818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 500}], {
             RGBColor[
             0.8593227462495947, 0.8867933996919948, 0.7484755104351853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 201}], {
             RGBColor[
             0.812060066676056, 0.7393729974507494, 0.6116456198757722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 236}], {
             RGBColor[
             0.8349848223055523, 0.8714760241232565, 0.9598938392960332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 289}], {
             RGBColor[
             0.847651675557928, 0.8803131178098322, 0.9111429634756407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 314}], {
             RGBColor[
             0.8511812515561069, 0.8817726881910449, 0.852648754935937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 411}], {
             RGBColor[
             0.7938255478337752, 0.4474870064928065, 0.44587941042908075`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 466}], {
             RGBColor[
             0.7924247497927613, 0.4367198589159578, 0.44453800464303084`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 470}], {
             RGBColor[
             0.8467589217532898, 0.8799439411688881, 0.9259382043912782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 493}], {
             RGBColor[
             0.8512029317491523, 0.8817816535080247, 0.8522894580306342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 270}], {
             RGBColor[
             0.767219476518979, 0.8145162873069962, 0.8409094555448471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 479}], {
             RGBColor[
             0.9671303914649858, 0.9731454713526289, 0.8565426715840043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 244}], {
             RGBColor[
             0.9382206323856197, 0.772915826118826, 0.47575093805960716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 245}], {
             RGBColor[
             0.9412033337598569, 0.786459576431632, 0.4782397771989716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 262}], {
             RGBColor[
             0.8766189326314995, 0.42018162143505167`, 0.3524454741499894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 376}], {
             RGBColor[
             0.8330977252129077, 0.8675910959824173, 0.848370381303561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 448}], {
             RGBColor[
             0.9941991331797039, 0.9900553809750714, 0.613952920087955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 455}], {
             RGBColor[
             0.9067855256121841, 0.9251565657023575, 0.8557148925957146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 475}], {
             RGBColor[
             0.9558556651594685, 0.9642705742030381, 0.8603987462133975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 482}], {
             RGBColor[
             0.9763601432068039, 0.9800580622722042, 0.8428617481934166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 228}], {
             RGBColor[
             0.8761720832758725, 0.41999683774299534`, 0.3598509243817917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 256}], {
             RGBColor[
             0.7351654435074599, 0.7887906269505833, 0.851522008264864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 298}], {
             RGBColor[
             0.9554151055437632, 0.9641765667062239, 0.8715288319273331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 452}], {
             RGBColor[
             0.9334899291846137, 0.9466940262204959, 0.8694375890333614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 468}], {
             RGBColor[
             0.9291820302200362, 0.943259024520944, 0.8690266977844132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 218}], {
             RGBColor[
             0.9558005954608836, 0.8497683491734579, 0.4928196369091463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 235}], {
             RGBColor[
             0.8142834618492963, 0.7411099306585139, 0.6118672271278316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 236}], {
             RGBColor[
             0.9396041662103289, 0.8394716851056695, 0.6000647212692425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 289}], {
             RGBColor[
             0.9522710194627046, 0.8483087787922452, 0.55131384544885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 300}], {
             RGBColor[
             0.7739610019341534, 0.7094394293377593, 0.607964688795916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 305}], {
             RGBColor[
             0.867306208525429, 0.4548552568273408, 0.20956942749150895`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 314}], {
             RGBColor[
             0.9558005954608836, 0.8497683491734579, 0.4928196369091463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 406}], {
             RGBColor[
             0.7668871284394178, 0.7036965401603634, 0.607407807561958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 493}], {
             RGBColor[
             0.955822275653929, 0.8497773144904377, 0.4924603400038434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 243}], {
             RGBColor[
             0.9875936693945204, 0.986924183908392, 0.7042524905977272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 273}], {
             RGBColor[
             0.8759215432856969, 0.4186536270685557, 0.2738967537823275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 279}], {
             RGBColor[
             0.7044148093758748, 0.7610948245858248, 0.7204817330504992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 283}], {
             RGBColor[
             0.836495065078424, 0.8687703409422983, 0.7309901797186901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 285}], {
             RGBColor[
             0.9931801836158757, 0.987821427280592, 0.4990832574952214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 396}], {
             RGBColor[
             0.9716490190313143, 0.9750326897744817, 0.7312426246317967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 421}], {
             RGBColor[
             0.7423156413187377, 0.7928857631109433, 0.7231832272680863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 430}], {
             RGBColor[
             0.9680388710483858, 0.9723402473198883, 0.7373536634895015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 459}], {
             RGBColor[
             0.9557582533920312, 0.8509284843610744, 0.3732235222839363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 477}], {
             RGBColor[
             0.8630089663526659, 0.8894832021308492, 0.7336328376112118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 264}], {
             RGBColor[
             0.8157272032815831, 0.8322060631427721, 0.6659274818409702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 281}], {
             RGBColor[
             0.9587185504354068, 0.9447657784283934, 0.6758061580822055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 295}], {
             RGBColor[
             0.8350107003050296, 0.847270477577494, 0.6678494806097419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 324}], {
             RGBColor[
             0.9533910768622786, 0.8466572330775194, 0.3139626976437859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 341}], {
             RGBColor[
             0.9625359818214043, 0.9476128125056, 0.669344242491275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 374}], {
             RGBColor[
             0.9858840139888447, 0.9627311253168442, 0.5114364360448502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 397}], {
             RGBColor[
             0.9827011368900584, 0.9533090141432629, 0.38729761274440844`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 275}], {
             RGBColor[
             0.9833843854404072, 0.9865940417773009, 0.8890677820958292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 306}], {
             RGBColor[
             0.9842706834399105, 0.9869605487769153, 0.8743795305783604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 331}], {
             RGBColor[
             0.9695082685317272, 0.9298524596095269, 0.6088016657214699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 346}], {
             RGBColor[
             0.7606226591899428, 0.8115466639930022, 0.9384514923982591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 348}], {
             RGBColor[
             0.8713322290907669, 0.4174601077605018, 0.4160868459060477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 355}], {
             RGBColor[
             0.8545652606573995, 0.8864744467988247, 0.9467625160480607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 390}], {
             RGBColor[
             0.9811228326810404, 0.969031111714509, 0.6539220542151523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 431}], {
             RGBColor[
             0.9501811654376364, 0.8543195623411086, 0.5875602094797663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 444}], {
             RGBColor[
             0.9618832822470287, 0.9710931948270068, 0.9494058401103334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 486}], {
             RGBColor[
             0.8503044762512886, 0.8831458896376101, 0.9463378408777536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 230}], {
             RGBColor[
             0.9502772642157906, 0.8273428057110694, 0.48579476653267784`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 331}], {
             RGBColor[
             0.9774383238428261, 0.9339347301213519, 0.5133396080873823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 382}], {
             RGBColor[
             0.9492476389825286, 0.9590015134996386, 0.8597684667775864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 413}], {
             RGBColor[
             0.8053364836126802, 0.8454916553595697, 0.8458851878120257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 474}], {
             RGBColor[
             0.8172524367296157, 0.8551655629074684, 0.8468232552909654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 490}], {
             RGBColor[
             0.9067855256121841, 0.9251565657023575, 0.8557148925957146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 254}], {
             RGBColor[
             0.8806474441908974, 0.8842068327640755, 0.6742740043453579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 377}], {
             RGBColor[
             0.8059355127681973, 0.36626349383855833`, 0.43581952627941734`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 396}], {
             RGBColor[
             0.8666699732550648, 0.8964474899294858, 0.9741267833774314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 476}], {
             RGBColor[
             0.8829958222432448, 0.9086232813737462, 0.9464913795038056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 257}], {
             RGBColor[
             0.8365851746298115, 0.3905043251299323, 0.4387955615756174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 266}], {
             RGBColor[
             0.6999715842628387, 0.7641875513440894, 0.9718430142268751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 281}], {
             RGBColor[
             0.9077097278219959, 0.9291284171778682, 0.9869440609516287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 293}], {
             RGBColor[
             0.8305172658882469, 0.867971291116219, 0.9836236026635878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 317}], {
             RGBColor[
             0.8024446789659663, 0.8460407728529705, 0.9808255895524152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 322}], {
             RGBColor[
             0.5684065266608943, 0.6478239738255336, 0.9630826150164791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 343}], {
             RGBColor[
             0.7773745938845954, 0.8264558318477, 0.9783268377647694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 374}], {
             RGBColor[
             0.9348751913754336, 0.9470937640663192, 0.8225743389142733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 403}], {
             RGBColor[
             0.7115587055689072, 0.7735944984142221, 0.9727551948611128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 440}], {
             RGBColor[
             0.7638235236112407, 0.8158696327582067, 0.9769761937218729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 445}], {
             RGBColor[
             0.6513327198957803, 0.724000611893153, 0.968207318877863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 471}], {
             RGBColor[
             0.7284078456918357, 0.7872733894111281, 0.9740816208920235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 238}], {
             RGBColor[
             0.987553570390173, 0.987343088080104, 0.7399315171305991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[
             0.8328301671847018, 0.866344697136361, 0.7656585924126262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 266}], {
             RGBColor[
             0.7592983034769294, 0.8071005852425538, 0.7595606085215225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 293}], {
             RGBColor[
             0.8898439851023376, 0.9108843250146832, 0.7713411969582353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 403}], {
             RGBColor[
             0.7708854247829979, 0.8165075323126865, 0.7604727891557602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 471}], {
             RGBColor[
             0.7877345649059266, 0.8301864233095924, 0.761799215186671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 483}], {
             RGBColor[
             0.8058099471185773, 0.8448608328765114, 0.7632221754867576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 497}], {
             RGBColor[
             0.9932610191013438, 0.9901777205117097, 0.6665914178610824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 231}], {
             RGBColor[
             0.8260196543366713, 0.38207966604159066`, 0.4377878128181064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 233}], {
             RGBColor[
             0.9187783229708422, 0.9349139832790063, 0.8658889394250102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 259}], {
             RGBColor[
             0.9038572071336889, 0.9254378465266986, 0.9651267455514543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 275}], {
             RGBColor[
             0.9154155233092638, 0.9335233791989344, 0.9216192324639171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 348}], {
             RGBColor[
             0.8260196543366713, 0.38207966604159066`, 0.4377878128181064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 355}], {
             RGBColor[
             0.7865963985262561, 0.833403784220458, 0.9793139664161487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 372}], {
             RGBColor[
             0.8260196543366713, 0.38207966604159066`, 0.4377878128181064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 379}], {
             RGBColor[
             0.8798864631044014, 0.907061598070405, 0.988405550406458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 400}], {
             RGBColor[
             0.8260196543366713, 0.38207966604159066`, 0.4377878128181064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 404}], {
             RGBColor[
             0.8260196543366713, 0.38207966604159066`, 0.4377878128181064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 431}], {
             RGBColor[
             0.8822123033064931, 0.801248899762742, 0.6201116598478542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 444}], {
             RGBColor[
             0.8939144201158854, 0.9180225322486402, 0.9819572904784213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 486}], {
             RGBColor[
             0.7823356141201452, 0.8300752270592434, 0.9788892912458416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 225}], {
             RGBColor[
             0.8511018854694488, 0.8537455807789861, 0.660552102161359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 252}], {
             RGBColor[
             0.8620124948990329, 0.8894694882547065, 0.7947850738310933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 280}], {
             RGBColor[
             0.7876738391444515, 0.8342629061230606, 0.9794167336641547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 309}], {
             RGBColor[
             0.844571750401957, 0.8790213032131868, 0.9636789221856116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 320}], {
             RGBColor[
             0.7047017489611271, 0.7692376293108736, 0.9712017425903323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 393}], {
             RGBColor[
             0.852367588176803, 0.8580150932120203, 0.6654691181715298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 424}], {
             RGBColor[
             0.8130522538412885, 0.7054876390412542, 0.604455137477807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 480}], {
             RGBColor[
             0.8546844340934902, 0.8658303585102969, 0.6744696270582199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 236}], {
             RGBColor[
             0.9489639828022793, 0.8765802389187685, 0.6075958494022584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 289}], {
             RGBColor[
             0.961630836054655, 0.8854173326053443, 0.5588449735818659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 308}], {
             RGBColor[
             0.8749005807365249, 0.8182610785946102, 0.6245072041269171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 362}], {
             RGBColor[
             0.8875029114039308, 0.8282647187111015, 0.6257211981488042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 369}], {
             RGBColor[
             0.8522629774079538, 0.8005764108221728, 0.6222508993875557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 466}], {
             RGBColor[
             0.8684108567905794, 0.44012266877963246`, 0.20967267804718087`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 470}], {
             RGBColor[
             0.9607380822500169, 0.8850481559644001, 0.5736402144975032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 216}], {
             RGBColor[
             0.8691276695985286, 0.8971428936334527, 0.9156670580064821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 217}], {
             RGBColor[
             0.7636100702294532, 0.8152572576055137, 0.9770731735247979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 224}], {
             RGBColor[
             0.6008915380960445, 0.6851504240256543, 0.962874621596729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 286}], {
             RGBColor[
             0.8216546634117187, 0.8611893110544666, 0.982702697632788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 319}], {
             RGBColor[
             0.7281456370278796, 0.7875521728487691, 0.9735384102572362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 330}], {
             RGBColor[
             0.8050074655090471, 0.8479152873230256, 0.9811148730357022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 357}], {
             RGBColor[
             0.8514086886439012, 0.884490427644514, 0.9708425539509804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 492}], {
             RGBColor[
             0.8187303404871191, 0.8588575353330221, 0.9824237731016658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 251}], {
             RGBColor[
             0.9396592697892974, 0.8005561467673246, 0.5659754523233476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 332}], {
             RGBColor[
             0.9231628172114301, 0.9401652808747532, 0.9425248879891877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 337}], {
             RGBColor[
             0.9897905221705061, 0.9894498240486739, 0.7755156483691985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 420}], {
             RGBColor[
             0.9477261481977584, 0.9597514142493937, 0.944867760426608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 447}], {
             RGBColor[
             0.7178938406598294, 0.7764704495868286, 0.9241795180781536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 454}], {
             RGBColor[
             0.9449500419615817, 0.9575378224920628, 0.9446029729355422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 489}], {
             RGBColor[
             0.9415123008162636, 0.9547966610177837, 0.944275078116194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 500}], {
             RGBColor[
             0.8551146946251209, 0.8866713426189123, 0.9358311808323976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 223}], {
             RGBColor[
             0.5655393411525407, 0.6346146917621676, 0.9496899502021435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 268}], {
             RGBColor[
             0.5867025435860642, 0.6486892806930289, 0.8373384580087706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 466}], {
             RGBColor[
             0.6162535088690015, 0.281392080093179, 0.43188009200884314`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 470}], {
             RGBColor[
             0.5825020603676503, 0.6469522729347199, 0.9069513354399967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 491}], {
             RGBColor[
             0.538366099779513, 0.46711655202356794`, 0.5849697461496591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 402}], {
             RGBColor[
             0.7489990289680255, 0.8027929220949186, 0.9558512714962057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 417}], {
             RGBColor[
             0.7648365052738608, 0.813580421399317, 0.8831828504243788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 217}], {
             RGBColor[
             0.8820590967319211, 0.9072450227925453, 0.9169559418120814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 224}], {
             RGBColor[
             0.7193405645985124, 0.7771381892126857, 0.9027573898840124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 292}], {
             RGBColor[
             0.8661607392810866, 0.8948251051199615, 0.9153713421199796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 358}], {
             RGBColor[
             0.9435548564731384, 0.8129076888112612, 0.5467150258447059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 361}], {
             RGBColor[
             0.9535569187305459, 0.963904315721495, 0.923868646894415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 398}], {
             RGBColor[
             0.9830843698902855, 0.9863426102828989, 0.8883360458208609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 399}], {
             RGBColor[
             0.9334006199727555, 0.7667996724452102, 0.5382420820056735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 464}], {
             RGBColor[
             0.7679355626915176, 0.8166499013755117, 0.9065663593584858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 481}], {
             RGBColor[
             0.8178061779543314, 0.857050154303223, 0.9105518113459958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 292}], {
             RGBColor[
             0.7606431399120113, 0.8129394690920224, 0.9767774576382955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 398}], {
             RGBColor[
             0.87756677052121, 0.90445697425496, 0.9497421613391768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 464}], {
             RGBColor[
             0.6624179633224423, 0.7347642653475728, 0.9679724748768017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 481}], {
             RGBColor[
             0.712288578585256, 0.7751645182752839, 0.9719579268643117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 496}], {
             RGBColor[
             0.6718291820713644, 0.7424047166985209, 0.9687133604911471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 235}], {
             RGBColor[
             0.8534046467293472, 0.8835096213988095, 0.8528703621879963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 274}], {
             RGBColor[
             0.9901843573322096, 0.9773696367719296, 0.5658936446211218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.8130821868142043, 0.8518391200780548, 0.8489678238560807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 305}], {
             RGBColor[
             0.8933869984454629, 0.5497883839875378, 0.3702381841982855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 310}], {
             RGBColor[
             0.9413917687813735, 0.7879281473287818, 0.48098210612319164`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 314}], {
             RGBColor[
             0.9949217803409345, 0.9921680399137535, 0.7338227719693111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 406}], {
             RGBColor[
             0.8060083133194686, 0.846096230900659, 0.8484109426221227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 432}], {
             RGBColor[
             0.9944665852326409, 0.9908836669340484, 0.6616888641498542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 493}], {
             RGBColor[
             0.9949434605339798, 0.9921770052307333, 0.7334634750640083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 238}], {
             RGBColor[
             0.9000798258553866, 0.9219957603272619, 0.9495267452420777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 258}], {
             RGBColor[
             0.7453564226499154, 0.800997369383519, 0.9752538205241048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 293}], {
             RGBColor[
             0.8023702405675512, 0.8455369972618412, 0.9809364250697139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 403}], {
             RGBColor[
             0.6834116802482115, 0.7511602045598444, 0.9700680172672388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 445}], {
             RGBColor[
             0.6231856945750848, 0.7015663180387753, 0.9655201412839891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 471}], {
             RGBColor[
             0.7002608203711402, 0.7648390955567503, 0.9713944432981496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 497}], {
             RGBColor[
             0.9057872745665574, 0.9248303927588677, 0.876186645972561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 254}], {
             RGBColor[
             0.7388402457126184, 0.7712383832366205, 0.6616356541339736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 297}], {
             RGBColor[
             0.7212136440812937, 0.7079088382577324, 0.6133192376420644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 325}], {
             RGBColor[
             0.7037825800754492, 0.7670434689121987, 0.9724169870257742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 392}], {
             RGBColor[
             0.669580460195581, 0.7397716269118038, 0.9691547582990394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 412}], {
             RGBColor[
             0.5733143944013475, 0.6644092410462972, 0.9596019450417665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 413}], {
             RGBColor[
             0.5575041553394479, 0.6516460144373747, 0.9583079157947835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 426}], {
             RGBColor[
             0.6632374376273975, 0.7347138728926952, 0.968549755144003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 474}], {
             RGBColor[
             0.5694201084563834, 0.6613199219852735, 0.9592459832737231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 490}], {
             RGBColor[
             0.6589531973389519, 0.7313109247801626, 0.9681376205784724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 234}], {
             RGBColor[
             0.8659960409580832, 0.38542916667792615`, 0.21351952580845288`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 301}], {
             RGBColor[
             0.9780021502576246, 0.9373649268607361, 0.3769766653439548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 336}], {
             RGBColor[
             0.9310136731027414, 0.9050391701237303, 0.6511602036584807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 294}], {
             RGBColor[
             0.9755062420581593, 0.9286407565758998, 0.5142898750291993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 296}], {
             RGBColor[
             0.9603835375401458, 0.9190568755804238, 0.6157766451113225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 339}], {
             RGBColor[
             0.9713487522037798, 0.9269215276784982, 0.5831902411551152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 344}], {
             RGBColor[
             0.8524004424978648, 0.8342680352973249, 0.630757054862003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 438}], {
             RGBColor[
             0.9644116314502814, 0.9220610214232046, 0.608958132816612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 439}], {
             RGBColor[
             0.8188437586430879, 0.80805329882973, 0.6274124382203987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 246}], {
             RGBColor[
             0.9341556958599548, 0.834571800007219, 0.6086386192480736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 268}], {
             RGBColor[
             0.9733148847386048, 0.9779099724551963, 0.8535274082109141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 411}], {
             RGBColor[
             0.8753958676783758, 0.511639688844806, 0.44401413126298883`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 286}], {
             RGBColor[
             0.6718675584117024, 0.7411846066336997, 0.9697930295103183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 330}], {
             RGBColor[
             0.6552203605090309, 0.7279105829022585, 0.9682052049132325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 333}], {
             RGBColor[
             0.6836597188590371, 0.750587355284736, 0.970917776300771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 358}], {
             RGBColor[
             0.6753187249706545, 0.6009152192034627, 0.5939225894349527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 361}], {
             RGBColor[
             0.6853207872280618, 0.7519118461136967, 0.9710762104846618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 398}], {
             RGBColor[
             0.7148482383878014, 0.7743501406751004, 0.9355436094111078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 441}], {
             RGBColor[
             0.7225171449992611, 0.778451786842788, 0.8501132319170492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 464}], {
             RGBColor[
             0.4996994311890336, 0.6046574317677132, 0.9537739229487326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 481}], {
             RGBColor[
             0.5495700464518474, 0.6450576846954243, 0.9577593749362427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 247}], {
             RGBColor[
             0.7004167281630209, 0.7320750940552555, 0.6479610269177876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 252}], {
             RGBColor[
             0.9833425463259835, 0.9543924987175483, 0.481636681614474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 309}], {
             RGBColor[
             0.9659018018289076, 0.9439443136760288, 0.6505305299689923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 320}], {
             RGBColor[
             0.8260318003880778, 0.8341606397737156, 0.6580533503737132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 424}], {
             RGBColor[
             0.9343823052682392, 0.7704106495040961, 0.2913067452611877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 284}], {
             RGBColor[
             0.6131301339305286, 0.6881324685088103, 0.9666443882933089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 345}], {
             RGBColor[
             0.8898840663298024, 0.9150334155046296, 0.9893591307270624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 366}], {
             RGBColor[
             0.9029840702039038, 0.9254790030037057, 0.9906086207910857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 389}], {
             RGBColor[
             0.9510015319312939, 0.9347889867982703, 0.6733859840349158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 405}], {
             RGBColor[
             0.9038623076302913, 0.7462161015334846, 0.6071994710110596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 429}], {
             RGBColor[
             0.942188127436886, 0.9562042068082369, 0.9757975141336312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 472}], {
             RGBColor[
             0.9082492116401182, 0.7661360080546458, 0.6108600112497163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 488}], {
             RGBColor[
             0.6865423162024923, 0.7526812993826794, 0.9712868915709245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 229}], {
             RGBColor[
             0.8758134463964321, 0.7282408295531935, 0.6053908715818883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 263}], {
             RGBColor[
             0.9258499607527889, 0.7672654445068714, 0.579890969570457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 265}], {
             RGBColor[
             0.7202666382956033, 0.6050401093649097, 0.590873023669096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 267}], {
             RGBColor[
             0.8389264723489128, 0.2753225086760635, 0.18393474940554064`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 270}], {
             RGBColor[
             0.7106625057012605, 0.5972430418635793, 0.5901169511701725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 329}], {
             RGBColor[
             0.8389264723489128, 0.2753225086760635, 0.18393474940554064`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 424}], {
             RGBColor[
             0.8892370453434089, 0.5899331168972773, 0.22928901439712882`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 256}], {
             RGBColor[
             0.7036968790624343, 0.2846995802240602, 0.42678774779478423`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 279}], {
             RGBColor[
             0.6834469962982196, 0.26757892265532757`, 0.42538173491800535`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 287}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 298}], {
             RGBColor[
             0.8505299870866364, 0.40162354006115397`, 0.44012563023643037`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 318}], {
             RGBColor[
             0.7664969040358779, 0.33545375295234237`, 0.43188865433573265`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 335}], {
             RGBColor[
             0.7617315907560175, 0.33173105400039304`, 0.4314136924423806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 409}], {
             RGBColor[
             0.7100297590980085, 0.28984089752993386`, 0.42728629530928863`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 468}], {
             RGBColor[
             0.8330412702041516, 0.3876785119376341, 0.43845754080781707`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 232}], {
             RGBColor[
             0.8628031628148352, 0.6027437903337765, 0.46543382632062524`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 263}], {
             RGBColor[
             0.9195219901024825, 0.9377927480318744, 0.9619135929357234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 267}], {
             RGBColor[
             0.8347078252487086, 0.3890073776927322, 0.43861649831571825`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 280}], {
             RGBColor[
             0.8575306599962653, 0.8892356875040869, 0.9862732339487429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 393}], {
             RGBColor[
             0.9222244090286168, 0.9129878745930464, 0.6723256184561179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 480}], {
             RGBColor[
             0.9245412549453039, 0.920803139891323, 0.6813261273428081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 485}], {
             RGBColor[
             0.7094371136607784, 0.7719128485725846, 0.9725412682149656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 382}], {
             RGBColor[
             0.9043061053038208, 0.794053454905553, 0.6166628108602961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 413}], {
             RGBColor[
             0.7603949499339724, 0.6805435967654843, 0.6027795318947353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 474}], {
             RGBColor[
             0.7723109030509079, 0.6902175043133829, 0.603717599373675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 484}], {
             RGBColor[
             0.9172601770844262, 0.7096712040909459, 0.25228380021011476`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 490}], {
             RGBColor[
             0.8618439919334763, 0.760208507108272, 0.6126092366784243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 233}], {
             RGBColor[
             0.8762578943105568, 0.4200323228110802, 0.3584288134652338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 275}], {
             RGBColor[
             0.8740160278695045, 0.41910525342436555`, 0.3955823421578384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 326}], {
             RGBColor[
             0.8225993270974847, 0.3793523899433728, 0.43746157895267057`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 346}], {
             RGBColor[
             0.725508210369195, 0.3024070015681664, 0.42850481569279164`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 355}], {
             RGBColor[
             0.7881366113474993, 0.35235885677204803`, 0.4340454981259927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 395}], {
             RGBColor[
             0.6111758949527872, 0.19821001583115389`, 0.42102461512351264`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 404}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 431}], {
             RGBColor[
             0.8518805478676574, 0.33092226713357065`, 0.19457729374712981`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 444}], {
             RGBColor[
             0.8596819590739189, 0.4087713554575028, 0.43580771416750785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 486}], {
             RGBColor[
             0.7852960884100921, 0.3501398186645716, 0.43376238134578804`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 267}], {
             RGBColor[
             0.8454143375661266, 0.34786341264104426`, 0.19103532800490702`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 280}], {
             RGBColor[
             0.8548332856482617, 0.5963888266177033, 0.4646736523216841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 338}], {
             RGBColor[
             0.9012770738958897, 0.6324966650734122, 0.4362260400535542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 383}], {
             RGBColor[
             0.8645048827035142, 0.47763014269285703`, 0.20865189164961953`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 393}], {
             RGBColor[
             0.8979624516698292, 0.612223618010343, 0.25537524199326744`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 395}], {
             RGBColor[
             0.6392712325189138, 0.4119464284721981, 0.4478419431284197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 480}], {
             RGBColor[
             0.8995070156142874, 0.6174337948758607, 0.26137558125106086`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 259}], {
             RGBColor[
             0.9792145670945169, 0.9823668316809329, 0.8460882465221454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 275}], {
             RGBColor[
             0.9907728832700919, 0.9904523643531687, 0.8025807334346082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 326}], {
             RGBColor[
             0.9136478321120621, 0.9308230691316796, 0.8653995886268566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 346}], {
             RGBColor[
             0.7680111570196275, 0.81540498656887, 0.8519644437370382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 348}], {
             RGBColor[
             0.8762578943105568, 0.42003232281108027`, 0.3584288134652338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 355}], {
             RGBColor[
             0.8619537584870842, 0.8903327693746925, 0.8602754673868398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 379}], {
             RGBColor[
             0.9552438230652295, 0.9639905832246394, 0.8693670513771492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 400}], {
             RGBColor[
             0.8762578943105568, 0.42003232281108027`, 0.3584288134652338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 404}], {
             RGBColor[
             0.8762578943105568, 0.42003232281108027`, 0.3584288134652338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 431}], {
             RGBColor[
             0.9575696632673212, 0.8581778849169763, 0.5010731608185455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 444}], {
             RGBColor[
             0.9692717800767134, 0.9749515174028747, 0.8629187914491125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 486}], {
             RGBColor[
             0.8576929740809733, 0.8870042122134778, 0.8598507922165328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 336}], {
             RGBColor[
             0.8444384077770778, 0.3967662800712274, 0.43954460996386757`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 449}], {
             RGBColor[
             0.8747104262511745, 0.41939240500041053`, 0.38407436392816174`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 274}], {
             RGBColor[
             0.8486672237206223, 0.8687112182569856, 0.6849412348398071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 284}], {
             RGBColor[
             0.5051095243469274, 0.6028734702295793, 0.9561094320322798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 300}], {
             RGBColor[
             0.6715650532026171, 0.7431807015631109, 0.968015414074766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 305}], {
             RGBColor[
             0.7990422427044047, 0.47734943831090854`, 0.4496032443440757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 308}], {
             RGBColor[
             0.7631448154130381, 0.8148937970068628, 0.9770268012727512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 345}], {
             RGBColor[
             0.7818634567462011, 0.8297744172253986, 0.9788241744660333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 389}], {
             RGBColor[
             0.8429809223476927, 0.8495299885190393, 0.6628510277738867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 432}], {
             RGBColor[
             0.8529494516210536, 0.8822252484191044, 0.7807364543685393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 456}], {
             RGBColor[
             0.8280131242010391, 0.866355271820056, 0.9756803410029145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 289}], {
             RGBColor[
             0.9751957750922009, 0.9804118054647524, 0.8995620648691112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 300}], {
             RGBColor[
             0.7968857575636497, 0.8415424560102664, 0.956212908216177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 308}], {
             RGBColor[
             0.8884655197740707, 0.9132555514540184, 0.9652242954141621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 314}], {
             RGBColor[
             0.97872535109038, 0.9818713758459651, 0.8410678563294074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 466}], {
             RGBColor[
             0.8774541494822766, 0.5034523173525712, 0.436817405572011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 470}], {
             RGBColor[
             0.9743030212875629, 0.9800426288238082, 0.9143573057847485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 493}], {
             RGBColor[
             0.9787470312834252, 0.9818803411629449, 0.8407085594241045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 241}], {
             RGBColor[
             0.6876798398098808, 0.2712451989562277, 0.42565144796361176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 274}], {
             RGBColor[
             0.8733616447744948, 0.41027507787670187`, 0.2421335057576442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 284}], {
             RGBColor[
             0.6443231785253649, 0.23304991252509769`, 0.42291230388595935`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 351}], {
             RGBColor[
             0.8355974403579651, 0.3897167326328945, 0.43870135059900783`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 371}], {
             RGBColor[
             0.7416719876315849, 0.3155294841196421, 0.429777287448754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 429}], {
             RGBColor[
             0.8636951741962698, 0.4117644047247154, 0.4290143877795076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 432}], {
             RGBColor[
             0.8762164633747824, 0.41928443131811444`, 0.3059969854434657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 460}], {
             RGBColor[
             0.8307700341932431, 0.2375175430900342, 0.17709872553421988`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 258}], {
             RGBColor[
             0.8266127752572585, 0.8646027420297394, 0.9422042362270783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 266}], {
             RGBColor[
             0.7530809115494862, 0.8053586301359322, 0.9361062523359747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 293}], {
             RGBColor[
             0.8836265931748944, 0.9091423699080616, 0.9478868407726875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 403}], {
             RGBColor[
             0.7646680328555547, 0.8147655772060649, 0.9370184329702123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 445}], {
             RGBColor[
             0.704442047182428, 0.7651716906849958, 0.9324705569869627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 471}], {
             RGBColor[
             0.7815171729784833, 0.8284444682029708, 0.9383448590011232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 483}], {
             RGBColor[
             0.799592555191134, 0.8431188777698898, 0.9397678193012098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 497}], {
             RGBColor[
             0.9870436271739005, 0.9884357654050882, 0.8431370616755345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 251}], {
             RGBColor[
             0.8429887574397561, 0.2937683965027949, 0.18732441966105964`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 272}], {
             RGBColor[
             0.859557833312678, 0.3613601456193608, 0.200754617825244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 332}], {
             RGBColor[
             0.8319911223878447, 0.386841152574414, 0.4383573767716197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 387}], {
             RGBColor[
             0.7100297590980085, 0.28984089752993386`, 0.42728629530928863`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 435}], {
             RGBColor[
             0.8644908576966551, 0.41235782417649064`, 0.42766750316084867`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 453}], {
             RGBColor[
             0.8748379793866846, 0.41944515149991, 0.381960478375826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 454}], {
             RGBColor[
             0.8465159388879456, 0.3984228469859537, 0.4397427667358561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 489}], {
             RGBColor[
             0.8442241114577337, 0.396595406003101, 0.439524170189624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 434}], {
             RGBColor[
             0.7570520185887997, 0.8101340578207967, 0.9764195282257346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 495}], {
             RGBColor[
             0.6358595165517484, 0.7141933383938401, 0.9652045434359193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 271}], {
             RGBColor[
             0.6974736714103178, 0.7221474725658009, 0.6365278071831694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 304}], {
             RGBColor[
             0.7039992767870622, 0.7441598717865663, 0.6618785518146485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 311}], {
             RGBColor[
             0.6987868519226355, 0.7610054214992747, 0.9427929869399398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 351}], {
             RGBColor[
             0.6502779202517689, 0.7231888973836833, 0.9680931978439296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 371}], {
             RGBColor[
             0.5093897411621986, 0.6119080246138047, 0.9547071031185488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 429}], {
             RGBColor[
             0.6924245210092259, 0.7562604055214147, 0.9535627536146791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 442}], {
             RGBColor[
             0.6876798398098808, 0.2712451989562277, 0.4256514479636119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 249}], {
             RGBColor[
             0.7371810364184868, 0.7940250495340339, 0.9751990756508704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 269}], {
             RGBColor[
             0.7282817711909949, 0.7869290170057512, 0.9743502557890045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 282}], {
             RGBColor[
             0.7641528610411172, 0.8143813629103738, 0.9378904844737266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 310}], {
             RGBColor[
             0.7179308222350962, 0.6138091380912287, 0.5928505726362228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 323}], {
             RGBColor[
             0.5877175596530027, 0.6761746171574718, 0.9606864256576932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 419}], {
             RGBColor[
             0.7700222956333862, 0.8174541581777705, 0.8695315386320255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 449}], {
             RGBColor[
             0.7687465830009516, 0.8169266182199395, 0.8906733983899293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 499}], {
             RGBColor[
             0.6100578794806426, 0.6938556578906852, 0.9627567959369696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 273}], {
             RGBColor[
             0.8722329029773166, 0.41813182887037237`, 0.4145622399494907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 279}], {
             RGBColor[
             0.6988818489133043, 0.7603121272885499, 0.931479962301244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 283}], {
             RGBColor[
             0.8309621046158535, 0.8679876436450235, 0.9419884089694348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 285}], {
             RGBColor[
             0.9876472231533051, 0.9870387299833171, 0.7100814867459662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 318}], {
             RGBColor[
             0.8234567105197916, 0.8621243727340722, 0.941240341427835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 335}], {
             RGBColor[
             0.8163087406000011, 0.8565403243061482, 0.9405278985878069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 396}], {
             RGBColor[
             0.9661160585687438, 0.9742499924772068, 0.9422408538825415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 421}], {
             RGBColor[
             0.7367826808561673, 0.7921030658136684, 0.9341814565188311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 430}], {
             RGBColor[
             0.9625059105858152, 0.9715575500226135, 0.9483518927402463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 459}], {
             RGBColor[
             0.9502252929294608, 0.8501457870637995, 0.5842217515346811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 477}], {
             RGBColor[
             0.8574760058900954, 0.8887005048335743, 0.9446310668619566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 261}], {
             RGBColor[
             0.9292777246403675, 0.7680781719200032, 0.5729274906704935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 262}], {
             RGBColor[
             0.8386201556255803, 0.27393159597749905`, 0.18367915122308204`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 295}], {
             RGBColor[
             0.7870543491852718, 0.656774022598319, 0.596312767950362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 341}], {
             RGBColor[
             0.9145796307016465, 0.757116357526425, 0.5978075298318952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 376}], {
             RGBColor[
             0.776099559704029, 0.6482160577960884, 0.5952208969131999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 391}], {
             RGBColor[
             0.9381547575183158, 0.7727204028295788, 0.46461757448831376`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 407}], {
             RGBColor[
             0.8296648114786886, 0.6900616395934442, 0.6005597806143601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 448}], {
             RGBColor[
             0.9372009676708252, 0.7706803427887425, 0.360803435697594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 455}], {
             RGBColor[
             0.8497873601033054, 0.7057815275160286, 0.6025654082053535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 475}], {
             RGBColor[
             0.8988574996505898, 0.7448955360167091, 0.6072492618230365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 478}], {
             RGBColor[
             0.8795329120548052, 0.5458689140916408, 0.22119164771104446`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 482}], {
             RGBColor[
             0.9193619776979252, 0.7606830240858751, 0.5897122638030555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 262}], {
             RGBColor[
             0.8406086232084051, 0.28296076285270305`, 0.18533837731599165`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 299}], {
             RGBColor[
             0.8406086232084051, 0.28296076285270305`, 0.18533837731599165`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 376}], {
             RGBColor[
             0.7790822610782662, 0.6617598081088945, 0.5977097360525643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 438}], {
             RGBColor[
             0.9296953744267595, 0.7797089109584808, 0.579758293075481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 448}], {
             RGBColor[
             0.9401836690450623, 0.7842240931015485, 0.36329227483695836`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 475}], {
             RGBColor[
             0.901840201024827, 0.7584392863295151, 0.6097381009624009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 482}], {
             RGBColor[
             0.9223446790721623, 0.7742267743986812, 0.59220110294242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 384}], {
             RGBColor[
             0.9327863028542196, 0.8335505089457168, 0.6109566444118868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 402}], {
             RGBColor[
             0.937420379133223, 0.8370065954469941, 0.6031123620321974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 411}], {
             RGBColor[
             0.8633985433816249, 0.425463966500062, 0.20585394382551325`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 458}], {
             RGBColor[
             0.7934776361453193, 0.7240290377672842, 0.609610314462266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 252}], {
             RGBColor[
             0.711327337592605, 0.7677990015309759, 0.7821939985875219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 278}], {
             RGBColor[
             0.5658636899324211, 0.656822185802981, 0.9597914753856563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 309}], {
             RGBColor[
             0.6938865930955291, 0.7573508164894562, 0.9510878469420402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 401}], {
             RGBColor[
             0.5693682598249619, 0.6595599824387516, 0.9601407781604772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 451}], {
             RGBColor[
             0.6464436650210487, 0.7201315663407927, 0.9677274831571434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 339}], {
             RGBColor[
             0.9465549136435891, 0.958608910799857, 0.9356982271101046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 344}], {
             RGBColor[
             0.8276066039376744, 0.8659554184186837, 0.9832650408169925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 387}], {
             RGBColor[
             0.7012419919229518, 0.764987984160038, 0.9722088346340408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 439}], {
             RGBColor[
             0.7940499200828973, 0.8397406819510888, 0.979920424175388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 269}], {
             RGBColor[
             0.9174629203611019, 0.9370240451011378, 0.9919896264445014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 282}], {
             RGBColor[
             0.9533340102112242, 0.9644763910057603, 0.9555298551292236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 310}], {
             RGBColor[
             0.9071119714052032, 0.7639041661866152, 0.6104899432917198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 323}], {
             RGBColor[
             0.7768987088231096, 0.8262696452528583, 0.9783257963131902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 406}], {
             RGBColor[
             0.7717285159432983, 0.8220722497584925, 0.9779187797906509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 419}], {
             RGBColor[
             0.9592034448034932, 0.9675491862731569, 0.8871709092875224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 499}], {
             RGBColor[
             0.7992390286507496, 0.8439506859860717, 0.9803961665924666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 263}], {
             RGBColor[
             0.911723616546287, 0.9315745366393753, 0.9611697771042433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 365}], {
             RGBColor[
             0.8461863304612168, 0.5130518686887953, 0.4540909381989574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 485}], {
             RGBColor[
             0.7016387401045829, 0.7656946371800855, 0.9717974523834854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 258}], {
             RGBColor[
             0.7831088221855278, 0.6783277702971906, 0.6007342852461421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 272}], {
             RGBColor[
             0.9191818861286511, 0.7144388131832337, 0.2536825562294555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 435}], {
             RGBColor[
             0.9265814227046167, 0.7909353310189284, 0.5940518842328626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 447}], {
             RGBColor[
             0.6725628431898005, 0.5889654923278889, 0.591741324737985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 453}], {
             RGBColor[
             0.942102105239661, 0.8015663220040574, 0.5254913470553284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 454}], {
             RGBColor[
             0.8996190444915526, 0.770032865233123, 0.6121647795953735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 309}], {
             RGBColor[
             0.9768124112584917, 0.9796682211517491, 0.7847635016387267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 320}], {
             RGBColor[
             0.8369424098176619, 0.8698845472494359, 0.7922863220434474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 424}], {
             RGBColor[
             0.9452929146978233, 0.8061345569798164, 0.425539716930922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 287}], {
             RGBColor[
             0.8489630856771142, 0.40037413540960676`, 0.4399761777812008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 301}], {
             RGBColor[
             0.9524527173361711, 0.959782379958257, 0.7166616433030766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 336}], {
             RGBColor[
             0.905464240181288, 0.9274566232212511, 0.9908451816176025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 354}], {
             RGBColor[
             0.9308320766624767, 0.9473306038150753, 0.9810037420377578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 388}], {
             RGBColor[
             0.5916076131420156, 0.667499548197144, 0.9651174512930243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 436}], {
             RGBColor[
             0.9533193512026715, 0.9616360221685767, 0.8109893914273838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 473}], {
             RGBColor[
             0.9407346738165405, 0.9547159445585616, 0.9642412280669064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 350}], {
             RGBColor[
             0.9832945994486548, 0.9636871448776991, 0.6051947061504247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 377}], {
             RGBColor[
             0.8709214500257343, 0.40204372800415866`, 0.23265380995082124`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 412}], {
             RGBColor[
             0.812600498765932, 0.8310480418221526, 0.6674917207602566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 426}], {
             RGBColor[
             0.902523541991982, 0.9013526736685507, 0.6764395308624931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 476}], {
             RGBColor[
             0.9804747281295503, 0.9622936326221467, 0.6417428050109115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 260}], {
             RGBColor[
             0.8730555133292838, 0.40924242462892335`, 0.2409442429010717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 299}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 312}], {
             RGBColor[
             0.8462380790097387, 0.398201289061377, 0.4397162642126242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 327}], {
             RGBColor[
             0.87428625627555, 0.41921699981481864`, 0.3911039581409679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 334}], {
             RGBColor[
             0.8748737076582631, 0.41945992605838245`, 0.38136836845396593`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 385}], {
             RGBColor[
             0.8570417118606916, 0.40680226340888587`, 0.44027696401274286`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 446}], {
             RGBColor[
             0.86872546433999, 0.41551598687755775`, 0.42049941867597906`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 478}], {
             RGBColor[
             0.8374937857442898, 0.2688170134169282, 0.18273928058428096`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 287}], {
             RGBColor[
             0.7036968790624343, 0.2846995802240603, 0.42678774779478423`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 298}], {
             RGBColor[
             0.6967022992236058, 0.7612306804278213, 0.971934067046822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 409}], {
             RGBColor[
             0.4859519572406641, 0.5935567166309912, 0.9526750646561093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 281}], {
             RGBColor[
             0.8583133105848524, 0.40775061965531323`, 0.4381244790588017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 317}], {
             RGBColor[
             0.7881366113474993, 0.35235885677204803`, 0.4340454981259927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 322}], {
             RGBColor[
             0.6321111764774514, 0.22021432408709007`, 0.42221684843536866`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 324}], {
             RGBColor[
             0.8547616615361002, 0.34234492275473055`, 0.19689550543318865`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 326}], {
             RGBColor[
             0.8225993270974847, 0.3793523899433728, 0.43746157895267057`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 343}], {
             RGBColor[
             0.7714232212932521, 0.339302229435201, 0.4323796636008955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 374}], {
             RGBColor[
             0.8764236196204777, 0.4197275175809472, 0.3285446643672315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 445}], {
             RGBColor[
             0.6873953053007087, 0.27099874946550306`, 0.4256333176762913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 272}], {
             RGBColor[
             0.8079624359949107, 0.7797153939720395, 0.6208795824924187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 293}], {
             RGBColor[
             0.7289031899694233, 0.7881439789643188, 0.9736139160547146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 403}], {
             RGBColor[
             0.6099446296500836, 0.6937671862623219, 0.9627455082522394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 435}], {
             RGBColor[
             0.8153619725708763, 0.8562119118077343, 0.9612489104958257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 453}], {
             RGBColor[
             0.8308826551059205, 0.8668429027928632, 0.8926883733182917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 471}], {
             RGBColor[
             0.6267937697730122, 0.7074460772592279, 0.9640719342831503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 497}], {
             RGBColor[
             0.8323202239684293, 0.8674373744613453, 0.8688641369575616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 275}], {
             RGBColor[
             0.9758517674329386, 0.9809762276008609, 0.9018185395610523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 331}], {
             RGBColor[
             0.9619756505242587, 0.9242346454330869, 0.6215524231866929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 348}], {
             RGBColor[
             0.8663104837524546, 0.4137148983095418, 0.42458735088286315`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 372}], {
             RGBColor[
             0.8663104837524546, 0.4137148983095418, 0.42458735088286315`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 400}], {
             RGBColor[
             0.8663104837524546, 0.4137148983095418, 0.42458735088286315`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 404}], {
             RGBColor[
             0.8663104837524546, 0.4137148983095418, 0.42458735088286315`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 418}], {
             RGBColor[
             0.8090640567278088, 0.8511952847280821, 0.9557289197051755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 431}], {
             RGBColor[
             0.9426485474301679, 0.8487017481646686, 0.6003109669449894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 444}], {
             RGBColor[
             0.9543506642395602, 0.9654753806505668, 0.9621565975755565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 486}], {
             RGBColor[
             0.84277185824382, 0.8775280754611701, 0.9590885983429768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 299}], {
             RGBColor[
             0.8730555133292838, 0.40924242462892335`, 0.24094424290107172`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 312}], {
             RGBColor[
             0.9443023885085338, 0.9429115705354505, 0.692554760670544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 328}], {
             RGBColor[
             0.8803415443356581, 0.46524605170306166`, 0.2479213544211708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 334}], {
             RGBColor[
             0.9872558314813205, 0.9747995260309588, 0.6050329170325565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 399}], {
             RGBColor[
             0.931876541916183, 0.751970979978353, 0.30766553321039825`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 407}], {
             RGBColor[
             0.8813178480342438, 0.8930278825705806, 0.6864574181313445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 446}], {
             RGBColor[
             0.9780334665039105, 0.9688836172597217, 0.6637294923655761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 478}], {
             RGBColor[
             0.9311859486103604, 0.7488351570687775, 0.307089285228029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 262}], {
             RGBColor[
             0.8706569941346647, 0.4169565186358365, 0.41722984255724704`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 299}], {
             RGBColor[
             0.8706569941346647, 0.4169565186358365, 0.41722984255724704`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 313}], {
             RGBColor[
             0.811644247288866, 0.8529800892760693, 0.944299997196951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 328}], {
             RGBColor[
             0.8779430251410391, 0.4729601457099747, 0.4242069540773461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 391}], {
             RGBColor[
             0.9862100152819423, 0.9872577868170849, 0.8149436114895612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 407}], {
             RGBColor[
             0.8777200692423153, 0.9045990235809503, 0.9508858176156076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 448}], {
             RGBColor[
             0.9852562254344517, 0.9852177267762486, 0.7111294726988415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 455}], {
             RGBColor[
             0.8978426178669319, 0.9203189115035347, 0.9528914452066011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 475}], {
             RGBColor[
             0.9469127574142162, 0.9594329200042153, 0.957575298824284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 478}], {
             RGBColor[
             0.9275881698184317, 0.7604062980791471, 0.571517684712292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 482}], {
             RGBColor[
             0.9674172354615516, 0.9752204080733813, 0.9400383008043031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 299}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 376}], {
             RGBColor[
             0.7685382175104389, 0.3370484425532265, 0.43209211338571785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 391}], {
             RGBColor[
             0.8765750160532969, 0.42005133924222016`, 0.34502323176912714`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 448}], {
             RGBColor[
             0.8759391561549698, 0.4186912992149959, 0.2758138059086473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 455}], {
             RGBColor[
             0.8176634177766232, 0.37542542236652, 0.4369884542471537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 475}], {
             RGBColor[
             0.8503768441414795, 0.40150142803364036`, 0.4401110233256089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 478}], {
             RGBColor[
             0.8374937857442898, 0.2688170134169282, 0.18273928058428096`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 482}], {
             RGBColor[
             0.8640464961730364, 0.41202642007975104`, 0.4284196913122883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 267}], {
             RGBColor[
             0.8680655014862798, 0.4150237876618508, 0.42161656364143085`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 393}], {
             RGBColor[
             0.9722609233849736, 0.9520124895467243, 0.6468257164446869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 485}], {
             RGBColor[
             0.7594736280171352, 0.8109374635262625, 0.9470413662035344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 281}], {
             RGBColor[
             0.7973105846007333, 0.8424381436803184, 0.9760587609351699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 295}], {
             RGBColor[
             0.6736027344703561, 0.7449428428294191, 0.9681020834627061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 324}], {
             RGBColor[
             0.7919831110276052, 0.7443295983294445, 0.6142153004967501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 341}], {
             RGBColor[
             0.8011280159867309, 0.8452851777575252, 0.9695968453442394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 374}], {
             RGBColor[
             0.8244760481541713, 0.8604034905687694, 0.8116890388978144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 397}], {
             RGBColor[
             0.821293171055385, 0.8509813793951879, 0.6875502155973727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 270}], {
             RGBColor[
             0.5487877269501253, 0.6445696252002986, 0.9576217266226468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 320}], {
             RGBColor[
             0.6190117617121123, 0.7010096905036161, 0.9635403949621284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 329}], {
             RGBColor[
             0.7310099531814894, 0.30687356423387635`, 0.4289379330405234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 424}], {
             RGBColor[
             0.7273622665922737, 0.6372597002339966, 0.596793789849603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 293}], {
             RGBColor[
             0.655371326261651, 0.7288998670705116, 0.9675159321636109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 317}], {
             RGBColor[
             0.6272987393393704, 0.7069693488072631, 0.9647179190524382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 322}], {
             RGBColor[
             0.39326058703429834`, 0.5087525497798262, 0.9469749445165021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 343}], {
             RGBColor[
             0.6022286542579995, 0.6873844078019926, 0.9622191672647924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 359}], {
             RGBColor[
             0.6946557276243488, 0.7599488315556422, 0.9713359830751747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 403}], {
             RGBColor[
             0.5364127659423112, 0.6345230743685147, 0.9566475243611359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 440}], {
             RGBColor[
             0.5886775839846448, 0.6767982087124993, 0.960868523221896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 445}], {
             RGBColor[
             0.47618678026918443`, 0.5849291878474456, 0.9520996483778861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 471}], {
             RGBColor[
             0.5532619060652398, 0.6482019653654207, 0.9579739503920466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 483}], {
             RGBColor[
             0.5713372882778905, 0.6628763749323396, 0.9593969106921332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 280}], {
             RGBColor[
             0.8267379480821351, 0.38265241397665906`, 0.437856324316777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 393}], {
             RGBColor[
             0.8698671141037027, 0.39848720536929877`, 0.22855791398836042`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 424}], {
             RGBColor[
             0.8436568912133597, 0.2968022359221214, 0.18788192685921193`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 480}], {
             RGBColor[
             0.8714116780481608, 0.40369738223481644`, 0.23455825324615384`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 485}], {
             RGBColor[
             0.7280089171918104, 0.3044371880223242, 0.42870168049425883`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 491}], {
             RGBColor[
             0.9461416433655772, 0.8104118327165968, 0.4888072041584297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 282}], {
             RGBColor[
             0.9444347449837323, 0.9573803584774777, 0.9546810352673576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 310}], {
             RGBColor[
             0.8982127061777112, 0.7568081336583325, 0.6096411234298538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 323}], {
             RGBColor[
             0.7679994435956179, 0.8191736127245757, 0.9774769764513243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 406}], {
             RGBColor[
             0.7628292507158064, 0.81497621723021, 0.9770699599287849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 411}], {
             RGBColor[
             0.8608665252878854, 0.5003372318609793, 0.45243476665577165`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 419}], {
             RGBColor[
             0.9503041795760012, 0.9604531537448744, 0.8863220894256565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 499}], {
             RGBColor[
             0.7903397634232576, 0.8368546534577891, 0.9795473467306006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 329}], {
             RGBColor[
             0.7246071981185942, 0.3016755192329894, 0.4284338847079078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 479}], {
             RGBColor[
             0.7390945093017893, 0.7954017417446009, 0.9724988701628803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 304}], {
             RGBColor[
             0.9730714287677378, 0.9208257474836841, 0.3498880151069824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 307}], {
             RGBColor[
             0.9576677820273843, 0.930070700607921, 0.6480535305718549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 311}], {
             RGBColor[
             0.9678590039033108, 0.9376712971963926, 0.6308024502322738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 351}], {
             RGBColor[
             0.9193500722324444, 0.8998547730808013, 0.6561026611362635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 371}], {
             RGBColor[
             0.7784618931428741, 0.7885739003109227, 0.6427165664108827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 429}], {
             RGBColor[
             0.9614966729899014, 0.9329262812185326, 0.641572216907013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 442}], {
             RGBColor[
             0.8670612744636644, 0.38902244942097297`, 0.2176577568251678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 435}], {
             RGBColor[
             0.9514350365139996, 0.8923229546937772, 0.6141971814791392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 453}], {
             RGBColor[
             0.9669557190490439, 0.9029539456789063, 0.545636644301605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 497}], {
             RGBColor[
             0.9683932879115527, 0.9035484173473882, 0.521812407940875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 279}], {
             RGBColor[
             0.6834469962982196, 0.26757892265532757`, 0.42538173491800535`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 283}], {
             RGBColor[
             0.7715005000999191, 0.33936260022630993`, 0.4323873660301325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 285}], {
             RGBColor[
             0.8759572457915535, 0.4187299911185057, 0.2777827512144868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 396}], {
             RGBColor[
             0.8616031360685126, 0.41020416611443217`, 0.43255566263887035`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 421}], {
             RGBColor[
             0.7087142175934615, 0.2887728816720732, 0.42718273106306337`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 430}], {
             RGBColor[
             0.8591963707465602, 0.40840920447803664`, 0.43662968854400686`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 459}], {
             RGBColor[
             0.8510092923089906, 0.3274680291721606, 0.19387626107363007`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 477}], {
             RGBColor[
             0.789176434282747, 0.3531711743520105, 0.4341491379584804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 284}], {
             RGBColor[
             0.6418892349497897, 0.6967334856026994, 0.6691327144654053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 300}], {
             RGBColor[
             0.8083447638054794, 0.8370407169362308, 0.6810386965078915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 305}], {
             RGBColor[
             0.8902287164396463, 0.5399227818929886, 0.258285432632826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 389}], {
             RGBColor[
             0.979760632950555, 0.9433900038921594, 0.37587431020701223`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 432}], {
             RGBColor[
             0.9897291622239159, 0.9760852637922245, 0.49375973680166485`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 460}], {
             RGBColor[
             0.9002637131609811, 0.6170561640567703, 0.26789495682608394`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 331}], {
             RGBColor[
             0.9735339666998337, 0.9323201781053227, 0.5780449100991558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 346}], {
             RGBColor[
             0.7646483573580491, 0.814014382488798, 0.907694736775945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 348}], {
             RGBColor[
             0.8740160278695045, 0.41910525342436566`, 0.3955823421578384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 355}], {
             RGBColor[
             0.8585909588255058, 0.8889421652946206, 0.9160057604257467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 372}], {
             RGBColor[
             0.8740160278695045, 0.41910525342436566`, 0.3955823421578384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 404}], {
             RGBColor[
             0.8740160278695045, 0.41910525342436566`, 0.3955823421578384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 418}], {
             RGBColor[
             0.8206223729033837, 0.8592808174003179, 0.9122214066176383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 431}], {
             RGBColor[
             0.9542068636057428, 0.8567872808369044, 0.5568034538574522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 444}], {
             RGBColor[
             0.9659089804151351, 0.9735609133228027, 0.9186490844880193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 486}], {
             RGBColor[
             0.854330174419395, 0.8856136081334058, 0.9155810852554396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 306}], {
             RGBColor[
             0.6811551722658569, 0.743700468256547, 0.8869654330985381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 347}], {
             RGBColor[
             0.5937648913162548, 0.6762712766853143, 0.9635659964486597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 382}], {
             RGBColor[
             0.638202072497376, 0.7116591624674453, 0.9678164269318517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 462}], {
             RGBColor[
             0.380671719146666, 0.5041404428330842, 0.9454770432226094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 288}], {
             RGBColor[
             0.7860817401696695, 0.8300640157737179, 0.8529069388268881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 313}], {
             RGBColor[
             0.8200744293602249, 0.8576057182322885, 0.8556206358939851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 340}], {
             RGBColor[
             0.6999390882803084, 0.7588361780453639, 0.8464828307973267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 373}], {
             RGBColor[
             0.9330744376056035, 0.7516642998395222, 0.48038184916865784`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 386}], {
             RGBColor[
             0.9938883213575648, 0.9902752290447481, 0.6444271880914642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 414}], {
             RGBColor[
             0.9900408035893531, 0.9901496305915937, 0.8147131883059316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 498}], {
             RGBColor[
             0.8762771155155706, 0.420040271273316, 0.3581102683552697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 401}], {
             RGBColor[
             0.7068304303277406, 0.7709005713730497, 0.9714139096552981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 451}], {
             RGBColor[
             0.7839058355238274, 0.8314721552750908, 0.9790006146519643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.7044683631346595, 0.7612093706607499, 0.7263107291987382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 318}], {
             RGBColor[
             0.5402778505011461, 0.6362950134115049, 0.957469583880607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 335}], {
             RGBColor[
             0.5331298805813555, 0.6307109649835809, 0.956757141040579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 396}], {
             RGBColor[
             0.6829371985500983, 0.7484206331546397, 0.9584700963353134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 409}], {
             RGBColor[
             0.4555771330943421, 0.5678757302778922, 0.9505660453409409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 421}], {
             RGBColor[
             0.4536038208375216, 0.5662737064911012, 0.950410698971603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 430}], {
             RGBColor[
             0.6793270505671696, 0.7457281907000464, 0.9645811351930182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 459}], {
             RGBColor[
             0.6670464329108152, 0.6243164277412323, 0.600450993987453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 477}], {
             RGBColor[
             0.5742971458714498, 0.6628711455110071, 0.9608603093147285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 338}], {
             RGBColor[
             0.9152415266178473, 0.9338649996135405, 0.9424615545481363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 383}], {
             RGBColor[
             0.8600832398292839, 0.7015652160427077, 0.6011003319422343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 393}], {
             RGBColor[
             0.9102695932787566, 0.9034554290189367, 0.6711853574577062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 480}], {
             RGBColor[
             0.9125864391954437, 0.9112706943172133, 0.6801858663443964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 317}], {
             RGBColor[
             0.8350368828985276, 0.871910214641042, 0.9798189657771917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 322}], {
             RGBColor[
             0.6009987305934555, 0.673693415613605, 0.9620759912412558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 324}], {
             RGBColor[
             0.934974458181429, 0.8568893136150657, 0.6240939767379856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 343}], {
             RGBColor[
             0.8099667978171567, 0.8523252736357714, 0.9773202139895458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 374}], {
             RGBColor[
             0.967467395307995, 0.9729632058543907, 0.8215677151390499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 397}], {
             RGBColor[
             0.9642845182092088, 0.9635410946808092, 0.6974288918386081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 445}], {
             RGBColor[
             0.6839249238283416, 0.7498700536812244, 0.9672006951026397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 310}], {
             RGBColor[
             0.9340837960278335, 0.7842604795629551, 0.573181352114576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 323}], {
             RGBColor[
             0.8038705334457401, 0.8466259586291982, 0.9410172051360464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 406}], {
             RGBColor[
             0.7987003405659288, 0.8424285631348325, 0.9406101886135071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 419}], {
             RGBColor[
             0.9861752694261235, 0.9879054996494969, 0.8498623181103786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 499}], {
             RGBColor[
             0.82621085327338, 0.8643069993624116, 0.9430875754153228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 396}], {
             RGBColor[
             0.8150174542526475, 0.8560961495111132, 0.9689785430035043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 421}], {
             RGBColor[
             0.5856840765400708, 0.6739492228475747, 0.9609191456397939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 430}], {
             RGBColor[
             0.8114073062697189, 0.8534037070565199, 0.9750895818612091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 459}], {
             RGBColor[
             0.7991266886133643, 0.7319919440977058, 0.6109594406556439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 477}], {
             RGBColor[
             0.706377401573999, 0.7705466618674807, 0.9713687559829194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 300}], {
             RGBColor[
             0.4647870644317844, 0.5712029689088246, 0.9522068937003643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 345}], {
             RGBColor[
             0.5750854679753685, 0.6577966845711123, 0.9630156540916315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 389}], {
             RGBColor[
             0.63620293357686, 0.6775522558647531, 0.6470425073994849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 432}], {
             RGBColor[
             0.6461714628502211, 0.7102475157648183, 0.7649279339941375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 456}], {
             RGBColor[
             0.6212351354302066, 0.6943775391657697, 0.9598718206285126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 472}], {
             RGBColor[
             0.5934506132856843, 0.5088992771211285, 0.5845165346142854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 287}], {
             RGBColor[
             0.8759572457915535, 0.41872999111850573`, 0.2777827512144868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 354}], {
             RGBColor[
             0.9713233168341355, 0.9748643873784238, 0.7377136021876869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 396}], {
             RGBColor[
             0.9717025727900992, 0.9751472358494069, 0.7370716207800356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 409}], {
             RGBColor[
             0.744342507334343, 0.7946023329726594, 0.7291675697856631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 430}], {
             RGBColor[
             0.9680924248071705, 0.9724547933948136, 0.7431826596377404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 473}], {
             RGBColor[
             0.9812259139881996, 0.98224972812191, 0.7209510882168355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 477}], {
             RGBColor[
             0.8630625201114507, 0.8895977482057743, 0.7394618337594507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 319}], {
             RGBColor[
             0.7991216573435376, 0.8435863554568146, 0.9804568181708255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 330}], {
             RGBColor[
             0.8759834858247051, 0.9039494699310711, 0.9880332809492915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 357}], {
             RGBColor[
             0.9223847089595592, 0.9405246102525595, 0.9777609618645697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 358}], {
             RGBColor[
             0.8960818502863286, 0.7769541062322751, 0.6137506654710119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 367}], {
             RGBColor[
             0.8497546458459947, 0.4515142176108397, 0.4463732618118338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 368}], {
             RGBColor[
             0.8013636979131096, 0.8453378545899037, 0.9806802838217401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 492}], {
             RGBColor[
             0.8897063608027771, 0.9148917179410676, 0.9893421810152552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 336}], {
             RGBColor[
             0.8444384077770778, 0.3967662800712274, 0.43954460996386757`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 354}], {
             RGBColor[
             0.861350298764537, 0.41001560046711016`, 0.4329836502439711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 388}], {
             RGBColor[
             0.635200656417563, 0.22346156338848924`, 0.42239278974748207`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 409}], {
             RGBColor[
             0.7100297590980085, 0.28984089752993386`, 0.42728629530928863`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 436}], {
             RGBColor[
             0.8763418151246668, 0.41955254603611114`, 0.3196407498370551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 473}], {
             RGBColor[
             0.8679520302005795, 0.4149391609627677, 0.4218086409300702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 313}], {
             RGBColor[
             0.6119628229831825, 0.6958029201860585, 0.9626327696550641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 321}], {
             RGBColor[
             0.7663780253900034, 0.763354737911055, 0.6211984819831616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 373}], {
             RGBColor[
             0.7249628312285612, 0.5898615017932924, 0.5873939829297368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 386}], {
             RGBColor[
             0.7857767149805224, 0.8284724309985182, 0.7514393218525431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 391}], {
             RGBColor[
             0.7865285909762588, 0.8300806177270743, 0.8332763839476742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 455}], {
             RGBColor[
             0.6981611935612484, 0.7631417424135241, 0.9712242176647141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 498}], {
             RGBColor[
             0.7375360445975423, 0.312171739242496, 0.42945169086265567`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 300}], {
             RGBColor[
             0.8095526108160254, 0.850379549696842, 0.9074620323957845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 308}], {
             RGBColor[
             0.9011323730264464, 0.922092645140594, 0.9164734195937697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 314}], {
             RGBColor[
             0.9913922043427554, 0.9907084695325408, 0.7923169805090149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 466}], {
             RGBColor[
             0.8858987183171937, 0.5093437131436217, 0.4043168216917494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 470}], {
             RGBColor[
             0.9869698745399385, 0.988879722510384, 0.865606429964356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 493}], {
             RGBColor[
             0.9914138845358008, 0.9907174348495206, 0.7919576836037121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 297}], {
             RGBColor[
             0.6776828785536173, 0.6714600967169849, 0.6101986195684848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 484}], {
             RGBColor[
             0.6708386169622254, 0.6443248802220889, 0.6046915660365831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 349}], {
             RGBColor[
             0.9723714921134028, 0.9157079083393018, 0.5073346112323813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 353}], {
             RGBColor[
             0.9727902539165174, 0.9774675844707721, 0.8521262501890663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 394}], {
             RGBColor[
             0.9910828585363773, 0.9905805470917788, 0.7974436410819838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 467}], {
             RGBColor[
             0.9676462526747229, 0.8969739085576364, 0.5035325726643946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 398}], {
             RGBColor[
             0.8616684130703757, 0.8920370565823762, 0.948157561647075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 399}], {
             RGBColor[
             0.8119846631528457, 0.6724941187446873, 0.5980635978318876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 464}], {
             RGBColor[
             0.6465196058716078, 0.722344347674989, 0.9663878751846999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 481}], {
             RGBColor[
             0.6963902211344216, 0.7627446006027001, 0.9703733271722099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 496}], {
             RGBColor[
             0.6559308246205301, 0.7299847990259372, 0.9671287607990453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 343}], {
             RGBColor[
             0.7327743358834078, 0.791168147574122, 0.9739997557015051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 403}], {
             RGBColor[
             0.6669584475677195, 0.7383068141406441, 0.9684281127978486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 440}], {
             RGBColor[
             0.719223265610053, 0.7805819484846287, 0.9726491116586087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 445}], {
             RGBColor[
             0.6067324618945926, 0.6887129276195751, 0.9638802368145989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 471}], {
             RGBColor[
             0.6838075876906481, 0.7519857051375501, 0.9697545388287594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 483}], {
             RGBColor[
             0.7018829699032988, 0.7666601147044692, 0.971177499128846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 497}], {
             RGBColor[
             0.8893340418860652, 0.9119770023396675, 0.8745467415031708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 296}], {
             RGBColor[
             0.979269395926046, 0.9823651226687672, 0.8440877087102847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 327}], {
             RGBColor[
             0.9913064346353546, 0.9906730015543497, 0.7937384065255326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 385}], {
             RGBColor[
             0.965439618013067, 0.9720508969454504, 0.8674979153331952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 415}], {
             RGBColor[
             0.9527281869423518, 0.8385277572350438, 0.4949496846649693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 438}], {
             RGBColor[
             0.9832974898361816, 0.9853692685115478, 0.8372691964155743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 439}], {
             RGBColor[
             0.8377296170289881, 0.8713615459180732, 0.855723501819361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 321}], {
             RGBColor[
             0.8238360742405912, 0.8092277576793815, 0.6262509868049171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 341}], {
             RGBColor[
             0.8204115130101775, 0.860349592192247, 0.9715188441130111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 391}], {
             RGBColor[
             0.8439866398268466, 0.8759536374954007, 0.8383288887694297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 397}], {
             RGBColor[
             0.8405766680788316, 0.8660457938299098, 0.6894722143661445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 455}], {
             RGBColor[
             0.7556192424118362, 0.8090147621818505, 0.9762767224864695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 327}], {
             RGBColor[
             0.9761837301173413, 0.9810891205588737, 0.8952251766076558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 339}], {
             RGBColor[
             0.9751119060716664, 0.9806458937713656, 0.9129880748362007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 385}], {
             RGBColor[
             0.9503169134950535, 0.9624670159499744, 0.9689846854153183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 415}], {
             RGBColor[
             0.9376054824243383, 0.8289438762395678, 0.5964364547470924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 438}], {
             RGBColor[
             0.9681747853181681, 0.9757853875160718, 0.9387559664976974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 325}], {
             RGBColor[
             0.9254420828087091, 0.8703527247091661, 0.631990346252355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 392}], {
             RGBColor[
             0.8912399629288408, 0.8430808827087712, 0.6287281175256203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 412}], {
             RGBColor[
             0.7949738971346072, 0.7677184968432647, 0.6191753042683474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 413}], {
             RGBColor[
             0.7791636580727077, 0.7549552702343422, 0.6178812750213643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 474}], {
             RGBColor[
             0.7910796111896432, 0.7646291777822409, 0.6188193425003039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 484}], {
             RGBColor[
             0.9360288852231615, 0.7840828775598039, 0.2673855433367437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 490}], {
             RGBColor[
             0.8806127000722116, 0.83462018057713, 0.6277109798050532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 335}], {
             RGBColor[
             0.7837543667639807, 0.8317778910923206, 0.9788729840182164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 409}], {
             RGBColor[
             0.7062016192769673, 0.7689426563866317, 0.9726818883185784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 468}], {
             RGBColor[
             0.8907188859361821, 0.9156990779981822, 0.9894387565663711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 312}], {
             RGBColor[
             0.8462380790097387, 0.398201289061377, 0.4397162642126242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 328}], {
             RGBColor[
             0.8209620155031871, 0.16212881353706912`, 0.16770655576004956`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 399}], {
             RGBColor[
             0.8379541812815049, 0.270907562023312, 0.18312344590586047`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 407}], {
             RGBColor[
             0.8042483853602121, 0.36494549708479707`, 0.4356513691864914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 448}], {
             RGBColor[
             0.8759391561549698, 0.4186912992149959, 0.2758138059086473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 475}], {
             RGBColor[
             0.8503768441414795, 0.40150142803364036`, 0.4401110233256089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 478}], {
             RGBColor[
             0.8374937857442898, 0.2688170134169282, 0.18273928058428096`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 482}], {
             RGBColor[
             0.8640464961730364, 0.41202642007975104`, 0.4284196913122883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 305}], {
             RGBColor[
             0.7721606027609761, 0.4562357707637387, 0.4470015521227987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 308}], {
             RGBColor[
             0.7228223554978952, 0.783223295686108, 0.9731242629408356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 432}], {
             RGBColor[
             0.8126269917059107, 0.8505547470983497, 0.7768339160366238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 456}], {
             RGBColor[
             0.7876906642858962, 0.8346847704993012, 0.9717778026709989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 493}], {
             RGBColor[
             0.8131038670072497, 0.8518480853950345, 0.8486085269507779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 316}], {
             RGBColor[
             0.9285699941267274, 0.9407389447502982, 0.7143836878430012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 336}], {
             RGBColor[
             0.9456657004861164, 0.9543705969506882, 0.7160142915770769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 388}], {
             RGBColor[
             0.6318090734468441, 0.6944135219265809, 0.6902865612524987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 436}], {
             RGBColor[
             0.9935208115075, 0.9885499958980137, 0.5361585013868582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 346}], {
             RGBColor[
             0.7366063854822767, 0.38771243873865746`, 0.4391324407146747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 370}], {
             RGBColor[
             0.7799406324636776, 0.4225915541991565, 0.44275006219158486`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 390}], {
             RGBColor[
             0.8836065011430085, 0.4927020705529952, 0.2494461485926035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 422}], {
             RGBColor[
             0.8791636765993616, 0.5003292248323418, 0.43224418866331393`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 443}], {
             RGBColor[
             0.8846375250425087, 0.5042135720165702, 0.4141097542497718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 451}], {
             RGBColor[
             0.8441394453172335, 0.47298394910812513`, 0.44908516582970015`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 379}], {
             RGBColor[
             0.8503299877329296, 0.401464066005346, 0.44010655411953226`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 400}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 307}], {
             RGBColor[
             0.9641933874041287, 0.9520830998286862, 0.673404275203334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 311}], {
             RGBColor[
             0.9743846092800552, 0.959683696417158, 0.6561531948637529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 337}], {
             RGBColor[
             0.9870939056130841, 0.9668383453877665, 0.5139282054066712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 423}], {
             RGBColor[
             0.9733288381256362, 0.9216940496904671, 0.3508880018547395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 427}], {
             RGBColor[
             0.9872192925051888, 0.9671065352714192, 0.5275757948140825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 433}], {
             RGBColor[
             0.9292121404649027, 0.7427513998098418, 0.2979207915256058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 465}], {
             RGBColor[
             0.9537930679579494, 0.9441277415682947, 0.6841161913813559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 469}], {
             RGBColor[
             0.9718718627762574, 0.9578096941888703, 0.6604066192654348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 310}], {
             RGBColor[
             0.8577003240724222, 0.4136284555975567, 0.20167774030087252`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 406}], {
             RGBColor[
             0.767444687097819, 0.4524071779788082, 0.4466302979668265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 432}], {
             RGBColor[
             0.8930835350399339, 0.5489321353344011, 0.3221489123186475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 460}], {
             RGBColor[
             0.8476371058583946, 0.36716524710632087`, 0.19325065240940165`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 493}], {
             RGBColor[
             0.8934014519074931, 0.5497943608655244, 0.36999865292808354`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 331}], {
             RGBColor[
             0.9744202646993371, 0.932686685104937, 0.563356658581687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 347}], {
             RGBColor[
             0.9017923986579184, 0.9223655827010927, 0.9055350867886992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 382}], {
             RGBColor[
             0.9462295798390397, 0.9577534684832237, 0.9097855172718912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 431}], {
             RGBColor[
             0.9550931616052463, 0.8571537878365187, 0.5421152023399836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 486}], {
             RGBColor[
             0.8552164724188984, 0.8859801151330202, 0.9008928337379709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 337}], {
             RGBColor[
             0.9716902588727305, 0.9760832985120033, 0.8120937208715437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 427}], {
             RGBColor[
             0.9718156457648355, 0.9763514883956561, 0.825741310278955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 433}], {
             RGBColor[
             0.9138084937245493, 0.7519963529340786, 0.5960863069904783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 442}], {
             RGBColor[
             0.8611425802212584, 0.4098606843176411, 0.4333352635560689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 469}], {
             RGBColor[
             0.9564682160359039, 0.9670546473131072, 0.9585721347303071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 500}], {
             RGBColor[
             0.8370144313273453, 0.8733048170822417, 0.9724092533347427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 362}], {
             RGBColor[
             0.8270044483757222, 0.8649400312463513, 0.9833496441607079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 369}], {
             RGBColor[
             0.7917645143797452, 0.8372517233574226, 0.9798793453994596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 389}], {
             RGBColor[
             0.8942382246429708, 0.8895725826420365, 0.6679598766399563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 456}], {
             RGBColor[
             0.8792704264963173, 0.9063978659430532, 0.980789189868984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 393}], {
             RGBColor[
             0.9671675045362618, 0.9482138261090629, 0.6554475459791631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 424}], {
             RGBColor[
             0.9278521702007474, 0.7956863719382969, 0.5944335652854403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 323}], {
             RGBColor[
             0.7576484946397191, 0.6460537338100532, 0.5959772932985425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 406}], {
             RGBColor[
             0.7524783017599077, 0.6418563383156873, 0.5955702767760033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 408}], {
             RGBColor[
             0.8935586196078931, 0.6095563763029874, 0.2328950418948931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 419}], {
             RGBColor[
             0.9399532306201025, 0.7873332748303518, 0.5048224062728748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 366}], {
             RGBColor[
             0.9236057962692368, 0.9410590263474752, 0.962648503321238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 405}], {
             RGBColor[
             0.9244840336956242, 0.7617961248772541, 0.5792393535412119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 423}], {
             RGBColor[
             0.9681164132612092, 0.9385395994031756, 0.6318024369800309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 429}], {
             RGBColor[
             0.9628098535022189, 0.9717842301520064, 0.9478373966637836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 465}], {
             RGBColor[
             0.9485806430935225, 0.9609732912810032, 0.9650306265066473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 469}], {
             RGBColor[
             0.9666594379118305, 0.9746552439015788, 0.9413210543907261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 488}], {
             RGBColor[
             0.7071640422678251, 0.7682613227264489, 0.9433267741010769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 327}], {
             RGBColor[
             0.9461485029279331, 0.9578734333142935, 0.9177943335303882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 334}], {
             RGBColor[
             0.9470296800020028, 0.9582378226796392, 0.9031909489998853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 385}], {
             RGBColor[
             0.9202816863056453, 0.9392513287053943, 0.9915538423380508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 415}], {
             RGBColor[
             0.9075702552349301, 0.8057281889949877, 0.6190056116698249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 446}], {
             RGBColor[
             0.9378073150245929, 0.9523219139084023, 0.961887524332905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 386}], {
             RGBColor[
             0.8197694041710778, 0.8560141334570888, 0.7541530189196402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 391}], {
             RGBColor[
             0.8205212801668142, 0.8576223201856448, 0.8359900810147711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 407}], {
             RGBColor[
             0.7120313341271871, 0.7749635569495101, 0.9719322871408176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 498}], {
             RGBColor[
             0.760197837391246, 0.33053287421487637`, 0.4312608222407204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 406}], {
             RGBColor[
             0.8060083133194686, 0.846096230900659, 0.8484109426221227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 411}], {
             RGBColor[
             0.8896525670236602, 0.5210839076412788, 0.36666208845133025`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 493}], {
             RGBColor[
             0.9949434605339798, 0.9921770052307333, 0.7334634750640083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 349}], {
             RGBColor[
             0.9725887960454748, 0.9157977690996699, 0.5037333227133985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 353}], {
             RGBColor[
             0.9730075578485894, 0.9775574452311402, 0.8485249616700836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 364}], {
             RGBColor[
             0.9713492273809864, 0.9763206650836688, 0.8513320825898796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 378}], {
             RGBColor[
             0.9762978684668988, 0.9800113535028862, 0.8429553240437345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 380}], {
             RGBColor[
             0.7928656196034691, 0.8353669292310557, 0.8448901872232948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 487}], {
             RGBColor[
             0.7341117514835834, 0.7876678922597368, 0.8402648675023869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 372}], {
             RGBColor[
             0.8330412702041516, 0.38767851193763414`, 0.43845754080781707`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 418}], {
             RGBColor[
             0.7591602364053545, 0.8121407051702207, 0.9765342045926064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 322}], {
             RGBColor[
             0.49573368173742605`, 0.5906057712887072, 0.9559575198420422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 343}], {
             RGBColor[
             0.7047017489611271, 0.7692376293108736, 0.9712017425903323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 374}], {
             RGBColor[
             0.8622023464519655, 0.8898755615294929, 0.8154492437398364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 440}], {
             RGBColor[
             0.6911506786877725, 0.7586514302213803, 0.969851098547436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 445}], {
             RGBColor[
             0.5786598749723122, 0.6667824093563267, 0.9610822237034262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 471}], {
             RGBColor[
             0.6557350007683675, 0.7300551868743017, 0.9669565257175867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 335}], {
             RGBColor[
             0.6577047421878429, 0.7325232104291032, 0.96651752016717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 421}], {
             RGBColor[
             0.578178682444009, 0.6680859519366233, 0.960171078098194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 430}], {
             RGBColor[
             0.803901912173657, 0.8475404361455685, 0.9743415143196092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 459}], {
             RGBColor[
             0.7916212945173026, 0.7261286731867544, 0.610211373114044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 330}], {
             RGBColor[
             0.7824744594408659, 0.8303123317253736, 0.9788689935737398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 357}], {
             RGBColor[
             0.82887568257572, 0.866887472046862, 0.968596674489018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 368}], {
             RGBColor[
             0.7078546715292704, 0.7717007163842062, 0.9715159964461884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 492}], {
             RGBColor[
             0.7961973344189379, 0.8412545797353701, 0.9801778936397034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 329}], {
             RGBColor[
             0.7714232212932521, 0.33930222943520105`, 0.4323796636008955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 424}], {
             RGBColor[
             0.7879821687599177, 0.6859026980359837, 0.6019563856901611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 341}], {
             RGBColor[
             0.9513613557569659, 0.9095700926074876, 0.6277457486864504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 373}], {
             RGBColor[
             0.9133707228259375, 0.6849550219768594, 0.24867339232493144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 391}], {
             RGBColor[
             0.9749364825736351, 0.9251741379106413, 0.4945557933428688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 397}], {
             RGBColor[
             0.97152651082562, 0.9152662942451504, 0.34569911893958366`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 455}], {
             RGBColor[
             0.8865690851586248, 0.858235262597091, 0.6325036270599087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 498}], {
             RGBColor[
             0.86314130566246, 0.37556741936487403`, 0.20363796379278543`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 343}], {
             RGBColor[
             0.47066359665605517`, 0.5710208302834366, 0.9534587680543963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 374}], {
             RGBColor[
             0.6281641941468934, 0.6916587625020558, 0.7977062692039003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 440}], {
             RGBColor[
             0.4571125263827004, 0.5604346311939433, 0.9521081240114999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 445}], {
             RGBColor[
             0.3446217226672401, 0.4685656103288897, 0.9433392491674901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 471}], {
             RGBColor[
             0.42169684846329547`, 0.5318383878468648, 0.9492135511816506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 419}], {
             RGBColor[
             0.8097399680380091, 0.8496987538965949, 0.8726582592943453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 449}], {
             RGBColor[
             0.8084642554055745, 0.8491712139387639, 0.8938001190522491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 499}], {
             RGBColor[
             0.6497755518852655, 0.7261002536095096, 0.9658835165992894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 342}], {
             RGBColor[
             0.8297094093253994, 0.7738016692901679, 0.6179755053387721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 360}], {
             RGBColor[
             0.6558800780797485, 0.6320848623602878, 0.6039097037973828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 457}], {
             RGBColor[
             0.9501472524775876, 0.8357150517417706, 0.3013610524540955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 392}], {
             RGBColor[
             0.8738088989229964, 0.9022155133632375, 0.9878258669093298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 413}], {
             RGBColor[
             0.7617325940668632, 0.8140899008888084, 0.976979024405074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 474}], {
             RGBColor[
             0.7736485471837987, 0.8237638084367072, 0.9779170918840137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 490}], {
             RGBColor[
             0.8631816360663671, 0.8937548112315963, 0.9868087291887628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 338}], {
             RGBColor[
             0.9090335951408717, 0.9289149635636111, 0.9418694365019766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 346}], {
             RGBColor[
             0.6875233062000194, 0.7543850872673088, 0.9705135919681933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 355}], {
             RGBColor[
             0.7814659076674761, 0.8293128700731314, 0.9788246156179949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 395}], {
             RGBColor[
             0.5160248330754078, 0.5980896086617901, 0.9592932911142749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 443}], {
             RGBColor[
             0.9095700155403674, 0.929136787184178, 0.9329795622708388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 334}], {
             RGBColor[
             0.9891019459007196, 0.9897613888098017, 0.8302724898924008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 385}], {
             RGBColor[
             0.9623539522043623, 0.9707748948355568, 0.9186353832305663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 415}], {
             RGBColor[
             0.949642521133647, 0.8372517551251502, 0.5460871525623403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 446}], {
             RGBColor[
             0.9798795809233098, 0.9838454800385648, 0.8889690652254204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 398}], {
             RGBColor[
             0.8783627122328992, 0.47327314765590944`, 0.42349653330275117`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 399}], {
             RGBColor[
             0.8452402122878792, 0.3269111890974502, 0.19010055742595955`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 407}], {
             RGBColor[
             0.8115344163665865, 0.4209491241589354, 0.44262848070659044`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 464}], {
             RGBColor[
             0.7349301741003873, 0.36014467505098463`, 0.43565007566116776`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 475}], {
             RGBColor[
             0.8576628751478539, 0.4575050551077786, 0.4470881348457081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 478}], {
             RGBColor[
             0.8447798167506642, 0.32482064049106646`, 0.18971639210438004`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 481}], {
             RGBColor[
             0.7681772509422632, 0.38707817700279207`, 0.4383070436528411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 333}], {
             RGBColor[
             0.8877756462720396, 0.9133522185821074, 0.9891580277397443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 352}], {
             RGBColor[
             0.9272768121355144, 0.9414270685943145, 0.8536301084990687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 357}], {
             RGBColor[
             0.9057375110568875, 0.9272505865211184, 0.976173137267484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 358}], {
             RGBColor[
             0.8794346523836569, 0.7636800825008341, 0.6121628408739259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 367}], {
             RGBColor[
             0.8386565139108803, 0.4426648684565456, 0.44531471208044326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 368}], {
             RGBColor[
             0.7847165000104379, 0.8320638308584627, 0.9790924592246544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 441}], {
             RGBColor[
             0.9266330724122638, 0.9412166501401593, 0.8683534833560225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 492}], {
             RGBColor[
             0.8730591629001054, 0.9016176942096265, 0.9877543564181693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 348}], {
             RGBColor[
             0.8647652832637179, 0.3812775319791829, 0.20873826457493216`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 372}], {
             RGBColor[
             0.8647652832637179, 0.3812775319791829, 0.20873826457493216`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 382}], {
             RGBColor[
             0.9314671649308564, 0.9006453793158353, 0.6442076524150006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 404}], {
             RGBColor[
             0.8647652832637179, 0.3812775319791829, 0.20873826457493216`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 418}], {
             RGBColor[
             0.8067462559947038, 0.8025392352325438, 0.631955290243279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 431}], {
             RGBColor[
             0.940330746697063, 0.8000456986691303, 0.27653733748309295`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 444}], {
             RGBColor[
             0.9520328635064552, 0.9168193311550286, 0.63838296811366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 486}], {
             RGBColor[
             0.8404540575107151, 0.8288720259656317, 0.6353149688810803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 420}], {
             RGBColor[
             0.8858986981498622, 0.9118555910978826, 0.9889790027522796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 454}], {
             RGBColor[
             0.8831225919136855, 0.9096419993405516, 0.9887142152612136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 489}], {
             RGBColor[
             0.8796848507683674, 0.9069008378662726, 0.9883863204418655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 358}], {
             RGBColor[
             0.9078740107336631, 0.7863568548833115, 0.6148754122614645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 361}], {
             RGBColor[
             0.9178760729910707, 0.9373534817935454, 0.9920290333111735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 367}], {
             RGBColor[
             0.8576160861442178, 0.4577827167115306, 0.4471230930054688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 386}], {
             RGBColor[
             0.9548991503952318, 0.9623563176170666, 0.767415085122201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 441}], {
             RGBColor[
             0.95507243076227, 0.9638934225226368, 0.871066054743561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 450}], {
             RGBColor[
             0.8640064895973512, 0.8944655028423232, 0.986873346307721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 461}], {
             RGBColor[
             0.7347065613754882, 0.792089585204848, 0.9749197639496601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 385}], {
             RGBColor[
             0.963235129278432, 0.9711392842009026, 0.9040319987000633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 415}], {
             RGBColor[
             0.9505236982077168, 0.8376161444904959, 0.5314837680318374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 446}], {
             RGBColor[
             0.9807607579973796, 0.9842098694039103, 0.8743656806949175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 409}], {
             RGBColor[
             0.5730040247810388, 0.6641039272954905, 0.9596139816275039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 421}], {
             RGBColor[
             0.5710307125242184, 0.6625019035086994, 0.959458635258166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 430}], {
             RGBColor[
             0.7967539422538665, 0.8419563877176446, 0.9736290714795812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 459}], {
             RGBColor[
             0.784473324597512, 0.7205446247588305, 0.609498930274016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 354}], {
             RGBColor[
             0.924045059812422, 0.9419188208075064, 0.980356390311758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 388}], {
             RGBColor[
             0.584820596291961, 0.662087765189575, 0.9644700995670246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 436}], {
             RGBColor[
             0.9465323343526169, 0.9562242391610078, 0.8103420397013841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 420}], {
             RGBColor[
             0.9525264031089382, 0.9611401342718033, 0.8219697631322904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 427}], {
             RGBColor[
             0.9947161639737907, 0.9911067339547361, 0.6662652404822922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 433}], {
             RGBColor[
             0.9367090119335046, 0.7667515984931588, 0.43661023719381553`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 500}], {
             RGBColor[
             0.8599149495363005, 0.8880600626413219, 0.81293318353808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 383}], {
             RGBColor[
             0.9297489222007261, 0.7557269737262711, 0.5584289135400395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 395}], {
             RGBColor[
             0.5918984469238254, 0.6572014023952828, 0.9172139907582397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 443}], {
             RGBColor[
             0.9854436293887852, 0.9882485809176709, 0.8909002619148038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 480}], {
             RGBColor[
             0.9822521215668858, 0.9654324520007767, 0.6375144479422015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 344}], {
             RGBColor[
             0.8671288110293855, 0.8958570534882666, 0.9279684845868812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 387}], {
             RGBColor[
             0.740764199014663, 0.7948896192296208, 0.9169122784039296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 439}], {
             RGBColor[
             0.8335721271746086, 0.8696423170206715, 0.924623867945277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 384}], {
             RGBColor[
             0.6775488631537578, 0.7437991718360553, 0.9587929036303788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 414}], {
             RGBColor[
             0.6957865453229497, 0.7571189948170097, 0.9153012140374492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 461}], {
             RGBColor[
             0.4794414740714177, 0.5869778608579455, 0.952519892650441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 499}], {
             RGBColor[
             0.5389003508634052, 0.6347934183067514, 0.9575123717037051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 374}], {
             RGBColor[
             0.9712848266939924, 0.9758102399315973, 0.8151057995481195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 391}], {
             RGBColor[
             0.9715119213432213, 0.9762959724235067, 0.8398236506509629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 397}], {
             RGBColor[
             0.9681019495952062, 0.9663881287580158, 0.6909669762476777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 455}], {
             RGBColor[
             0.883144523928211, 0.9093570971099566, 0.9777714843680028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 485}], {
             RGBColor[
             0.6395802928089647, 0.7169400671915584, 0.9656847679303774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 374}], {
             RGBColor[
             0.8371322613705945, 0.8702906205242222, 0.8129504919521906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 403}], {
             RGBColor[
             0.6138157755640681, 0.6967913548721252, 0.96313134789903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 440}], {
             RGBColor[
             0.6660805936064016, 0.7390664892161097, 0.9673523467597902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 445}], {
             RGBColor[
             0.5535897898909412, 0.6471974683510562, 0.9585834719157803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 471}], {
             RGBColor[
             0.6306649156869966, 0.7104702458690312, 0.9644577739299408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 387}], {
             RGBColor[
             0.6218158893087481, 0.7022361268484474, 0.9644790921108175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 438}], {
             RGBColor[
             0.8601916902758873, 0.8909965472329728, 0.953736376248378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 439}], {
             RGBColor[
             0.7146238174686936, 0.7769888246394983, 0.9721906816521647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 389}], {
             RGBColor[
             0.9129568659761338, 0.9044532028605723, 0.6697572498332384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 456}], {
             RGBColor[
             0.8979890678294802, 0.921278486161589, 0.9825865630622661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 472}], {
             RGBColor[
             0.870204545684958, 0.7358002241169478, 0.6072312770480389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 355}], {
             RGBColor[
             0.6358292325750414, 0.7138947875103218, 0.9653894707281766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 390}], {
             RGBColor[
             0.7623868045986825, 0.796451452426006, 0.6725490088952681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 395}], {
             RGBColor[
             0.37038815798297314`, 0.48267152609898045`, 0.9458581462244564]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 431}], {
             RGBColor[
             0.7314451373552785, 0.6817399030526057, 0.6061871641598822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 443}], {
             RGBColor[
             0.7639333404479328, 0.8137187046213685, 0.9195444173810206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 486}], {
             RGBColor[
             0.6315684481689305, 0.7105662303491072, 0.9649647955578695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 382}], {
             RGBColor[
             0.8588392988894376, 0.890324276911991, 0.9863860806220127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 462}], {
             RGBColor[
             0.6013089455387275, 0.6828055572776299, 0.9640466969127705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 355}], {
             RGBColor[
             0.7881366113474993, 0.35235885677204803`, 0.4340454981259927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 372}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 400}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 404}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 418}], {
             RGBColor[
             0.7628242207327514, 0.332584624842513, 0.4315225955872538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 431}], {
             RGBColor[
             0.8518805478676574, 0.33092226713357065`, 0.19457729374712981`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 444}], {
             RGBColor[
             0.8596819590739189, 0.4087713554575028, 0.43580771416750785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 486}], {
             RGBColor[
             0.7852960884100921, 0.3501398186645716, 0.43376238134578804`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 353}], {
             RGBColor[
             0.9503759647145091, 0.9010636919883901, 0.6233842336450168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 378}], {
             RGBColor[
             0.9536662753328186, 0.903517600260136, 0.6178145960186677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 380}], {
             RGBColor[
             0.7702340264693888, 0.7588731759883055, 0.619749459198228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 487}], {
             RGBColor[
             0.7114801583495032, 0.7111741390169866, 0.6151241394773201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 377}], {
             RGBColor[
             0.8743669496067022, 0.4192503685809742, 0.38976666081612854`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 412}], {
             RGBColor[
             0.8177687481373839, 0.8568580026873758, 0.9031609970582176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 426}], {
             RGBColor[
             0.9076917913634339, 0.9271626345337739, 0.912108807160454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 476}], {
             RGBColor[
             0.9856429775010022, 0.9881035934873699, 0.8774120813088724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 371}], {
             RGBColor[
             0.731266141984325, 0.7896153251288051, 0.9742819570716428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 442}], {
             RGBColor[
             0.8355974403579651, 0.38971673263289464`, 0.43870135059900783`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 460}], {
             RGBColor[
             0.8624995087444514, 0.596497818812963, 0.4644628016674477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 357}], {
             RGBColor[
             0.9736780352703684, 0.9780022089158029, 0.8433577894143469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 367}], {
             RGBColor[
             0.8839501967198675, 0.4764992833863353, 0.3567711468450186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 368}], {
             RGBColor[
             0.8526570242239189, 0.8828154532531471, 0.8462771113715173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 375}], {
             RGBColor[
             0.876618445449665, 0.4201442303296663, 0.3497502535486439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 380}], {
             RGBColor[
             0.7706527882725034, 0.8206328521197757, 0.9645410981549131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 487}], {
             RGBColor[
             0.7118989201526178, 0.7729338151484568, 0.9599157784340052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 388}], {
             RGBColor[
             0.6101884327731497, 0.6819617457833992, 0.9546286599871798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 409}], {
             RGBColor[
             0.7224320867938181, 0.7815307469955661, 0.9619689183298896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 436}], {
             RGBColor[
             0.9719001708338055, 0.976098219754832, 0.8005006001215393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 473}], {
             RGBColor[
             0.9593154934476746, 0.9691781421448169, 0.9537524367610619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 395}], {
             RGBColor[
             0.4643307594504298, 0.5575993089048029, 0.954169169874258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 404}], {
             RGBColor[
             0.7881366113474993, 0.3523588567720481, 0.4340454981259928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 431}], {
             RGBColor[
             0.8253877388227351, 0.7566676858584281, 0.6144981878096838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 443}], {
             RGBColor[
             0.8578759419153894, 0.888646487427191, 0.9278554410308222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 444}], {
             RGBColor[
             0.8370898556321273, 0.8734413183443264, 0.9763438184402509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 486}], {
             RGBColor[
             0.7255110496363872, 0.7854940131549295, 0.9732758192076711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 365}], {
             RGBColor[
             0.8888013427280504, 0.54624051615301, 0.4307170337407532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 457}], {
             RGBColor[
             0.976190642890555, 0.9492734939525962, 0.6281378692591033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 494}], {
             RGBColor[
             0.9109253227002763, 0.9306240323392576, 0.9502082209868015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 367}], {
             RGBColor[
             0.8695906626674497, 0.46704829533753794`, 0.4384664993572953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 368}], {
             RGBColor[
             0.8311177231452921, 0.8686389711799511, 0.9688201401399326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 441}], {
             RGBColor[
             0.9730342955471178, 0.9777917904616478, 0.8580811642713008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 492}], {
             RGBColor[
             0.9194603860349595, 0.9381928345311149, 0.9774820373334476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 361}], {
             RGBColor[
             0.9095350791026879, 0.787681345712272, 0.6150338464453553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 386}], {
             RGBColor[
             0.946558156506849, 0.8126841815357932, 0.3904198982563828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 398}], {
             RGBColor[
             0.9390625302624276, 0.8101196402736759, 0.5795012453718013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 441}], {
             RGBColor[
             0.9467314368738873, 0.8142212864413634, 0.4940708678777428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 408}], {
             RGBColor[
             0.8818706463032143, 0.7651030168375335, 0.6122926329680827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 440}], {
             RGBColor[
             0.7585076669727508, 0.8116309129697594, 0.9764691625701725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 463}], {
             RGBColor[
             0.916058999747078, 0.9350811278975386, 0.963305531578136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 483}], {
             RGBColor[
             0.7411673712659967, 0.7977090791895998, 0.9749975500404098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 457}], {
             RGBColor[
             0.6763803459490353, 0.7090191458378667, 0.6430202399519124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 494}], {
             RGBColor[
             0.6111150257587565, 0.6903696842245284, 0.9650905916796106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 386}], {
             RGBColor[
             0.9565602187642566, 0.9636808084460271, 0.7675735193060917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 398}], {
             RGBColor[
             0.9490645925198349, 0.9611162671839097, 0.9566548664215103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 441}], {
             RGBColor[
             0.9567334991312947, 0.9652179133515973, 0.8712244889274519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 481}], {
             RGBColor[
             0.7837864005838808, 0.8318238112042338, 0.9788706319466453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 369}], {
             RGBColor[
             0.8043668450471511, 0.847255363473914, 0.9810933394213468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 470}], {
             RGBColor[
             0.9128419498892143, 0.9317271086161413, 0.9324826545312943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 381}], {
             RGBColor[
             0.7755288666897697, 0.794666330014989, 0.6550769711080741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 378}], {
             RGBColor[
             0.9524267066683302, 0.9640404962441348, 0.9654133558951488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 380}], {
             RGBColor[
             0.7689944578049004, 0.8193960719723044, 0.9673482190747089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 381}], {
             RGBColor[
             0.9603201456971598, 0.9407409175293635, 0.6620154294596354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 416}], {
             RGBColor[
             0.7576183188014673, 0.8101604098400955, 0.9664526477401885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 452}], {
             RGBColor[
             0.9102898370620138, 0.9310006735184617, 0.9807742596813207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 468}], {
             RGBColor[
             0.9059819380974363, 0.9275656718189098, 0.9803633684323725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 487}], {
             RGBColor[
             0.7102405896850148, 0.7716970350009854, 0.9627228993538011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 405}], {
             RGBColor[
             0.8789176455492327, 0.7263259050948628, 0.6048202268734055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 423}], {
             RGBColor[
             0.9225500251148178, 0.9030693796207843, 0.6573833103122245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 429}], {
             RGBColor[
             0.9172434653558272, 0.9363140103696151, 0.9734182699959772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 465}], {
             RGBColor[
             0.903014254947131, 0.9255030714986119, 0.9906114998388409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 469}], {
             RGBColor[
             0.9210930497654388, 0.9391850241191875, 0.9669019277229197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 488}], {
             RGBColor[
             0.6615976541214337, 0.7327911029440576, 0.9689076474332705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 368}], {
             RGBColor[
             0.7889099886364833, 0.4035904582291008, 0.44041271399540893`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 375}], {
             RGBColor[
             0.8246507512702025, 0.19048205305666902`, 0.17123889329637462`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 441}], {
             RGBColor[
             0.8835210369043671, 0.4763590044168986, 0.36658673008298776`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 450}], {
             RGBColor[
             0.822810409461088, 0.43007372463002286`, 0.4437915911257611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 492}], {
             RGBColor[
             0.7984393749885099, 0.8430060788684592, 0.980401359290618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 456}], {
             RGBColor[
             0.856632823167746, 0.8887131981706158, 0.9785328851296229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 390}], {
             RGBColor[
             0.8273881750707837, 0.8487701256167546, 0.6779754411106333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 422}], {
             RGBColor[
             0.8207239382553133, 0.8602108570357743, 0.9521725012166988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 443}], {
             RGBColor[
             0.828934710920034, 0.8660373778121171, 0.9249708495963858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 451}], {
             RGBColor[
             0.7681875913321212, 0.8191929434494494, 0.9774339669662784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 442}], {
             RGBColor[
             0.7416719876315849, 0.31552948411964216`, 0.4297772874487541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 460}], {
             RGBColor[
             0.7685740560180712, 0.5223105702997106, 0.45553873851719373`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 400}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 404}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 418}], {
             RGBColor[
             0.7628242207327514, 0.332584624842513, 0.4315225955872538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 431}], {
             RGBColor[
             0.8518805478676574, 0.33092226713357065`, 0.19457729374712981`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 444}], {
             RGBColor[
             0.8596819590739189, 0.4087713554575028, 0.43580771416750785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 486}], {
             RGBColor[
             0.7852960884100921, 0.3501398186645716, 0.43376238134578804`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 449}], {
             RGBColor[
             0.9307244037090092, 0.7506925004301641, 0.5193279925279959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 498}], {
             RGBColor[
             0.8355311762214984, 0.25990526195303226`, 0.1811016310905022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 397}], {
             RGBColor[
             0.9914499817626465, 0.98150644156926, 0.5330591698012528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 445}], {
             RGBColor[
             0.7110903873817795, 0.7678354005696754, 0.8028309730652843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 402}], {
             RGBColor[
             0.8644396829505392, 0.41231965813462834`, 0.4277541286575116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 417}], {
             RGBColor[
             0.8749980004877627, 0.41951132433756055`, 0.37930851460962695`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 441}], {
             RGBColor[
             0.8761892856341646, 0.42000395136022955`, 0.35956583678661314`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 450}], {
             RGBColor[
             0.8154786581908855, 0.3737186715733538, 0.4367706978293865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 461}], {
             RGBColor[
             0.7292787060429768, 0.305468059815037, 0.42880164292401246`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 391}], {
             RGBColor[
             0.8330318503456038, 0.8673956726931701, 0.8372370177322676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 448}], {
             RGBColor[
             0.8320780604981131, 0.8653556126523338, 0.7334228789415478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 455}], {
             RGBColor[
             0.7446644529305932, 0.8004567973796199, 0.9751848514493073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 475}], {
             RGBColor[
             0.7937345924778777, 0.8395708058803004, 0.9798687050669903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 482}], {
             RGBColor[
             0.814239070525213, 0.8553582939494664, 0.9623317070470094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 412}], {
             RGBColor[
             0.760570882484887, 0.3308242998772764, 0.4312980038893498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 426}], {
             RGBColor[
             0.8205195779689204, 0.3776940544415418, 0.43726321062417406`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 476}], {
             RGBColor[
             0.8724870353939659, 0.41832136041060575`, 0.4141320600564531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 380}], {
             RGBColor[
             0.7739430988908129, 0.8230867603915217, 0.958971460528564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 416}], {
             RGBColor[
             0.7625669598873799, 0.8138510982593129, 0.9580758891940435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 452}], {
             RGBColor[
             0.9152384781479264, 0.9346913619376791, 0.9723975011351758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 487}], {
             RGBColor[
             0.7151892307709272, 0.7753877234202028, 0.9543461408076561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 400}], {
             RGBColor[
             0.8503299877329296, 0.401464066005346, 0.44010655411953226`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 404}], {
             RGBColor[
             0.8503299877329296, 0.401464066005346, 0.44010655411953226`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 440}], {
             RGBColor[
             0.7844407432659177, 0.8323092440713272, 0.9789426825377453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 487}], {
             RGBColor[
             0.5317569819074974, 0.6307432991483723, 0.9562810039872164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 416}], {
             RGBColor[
             0.7704603989162095, 0.7905515195445416, 0.6546779627585302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 468}], {
             RGBColor[
             0.9188240182121785, 0.907956781523356, 0.6685886834507142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 425}], {
             RGBColor[
             0.7254253315668324, 0.7846482891487045, 0.9740813515538538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 462}], {
             RGBColor[
             0.6457461267198488, 0.718193443059761, 0.9682971273959624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 393}], {
             RGBColor[
             0.9247769888616354, 0.7253174031316674, 0.2871527164496094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 395}], {
             RGBColor[
             0.5367401601352622, 0.42490161882445, 0.5758527681523378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 443}], {
             RGBColor[
             0.9302853426002218, 0.7559487973468381, 0.5495390393089018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 480}], {
             RGBColor[
             0.9270938347783225, 0.733132668429944, 0.2961532253362995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 402}], {
             RGBColor[
             0.9540469725726141, 0.9652488879026078, 0.962670668352224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 411}], {
             RGBColor[
             0.8744829390078857, 0.5109588281371379, 0.4455594813721977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 458}], {
             RGBColor[
             0.8101042295847105, 0.852271330222898, 0.9691686207822925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 461}], {
             RGBColor[
             0.7513055072112707, 0.8049714904232208, 0.9642419397519755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 499}], {
             RGBColor[
             0.810764384003258, 0.8527870478720267, 0.9692344188052395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 415}], {
             RGBColor[
             0.9237757045113593, 0.818629650516251, 0.6198466613700029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 446}], {
             RGBColor[
             0.9540127643010221, 0.9652233754296655, 0.9627285740330829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 441}], {
             RGBColor[
             0.9937565765354559, 0.9902207491751185, 0.6466105407384792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 498}], {
             RGBColor[
             0.8760737653894726, 0.4189792147565161, 0.29046519037237306`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 439}], {
             RGBColor[
             0.588259205453971, 0.6760213903808525, 0.961134475469213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 436}], {
             RGBColor[
             0.6326757073133445, 0.6962671641369006, 0.7846143093768058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 473}], {
             RGBColor[
             0.6200910299272135, 0.6893470865268854, 0.9378661460163285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 456}], {
             RGBColor[
             0.9591065334309719, 0.9410340574552297, 0.6666134163701196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 472}], {
             RGBColor[
             0.9313220112864495, 0.7555557954105885, 0.2912581303558924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 422}], {
             RGBColor[
             0.9762227412743096, 0.9653766315665324, 0.6622166308182268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 443}], {
             RGBColor[
             0.9844335139390304, 0.9712031523428752, 0.6350149791979136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 451}], {
             RGBColor[
             0.9236863943511175, 0.9243587179802075, 0.6874780965678062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 407}], {
             RGBColor[
             0.8865971021202634, 0.909241254490526, 0.8425759014334278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 448}], {
             RGBColor[
             0.9941332583124, 0.9898599576858242, 0.6028195565166616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 455}], {
             RGBColor[
             0.9067196507448801, 0.9249611424131103, 0.8445815290244212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 475}], {
             RGBColor[
             0.9557897902921646, 0.9640751509137908, 0.8492653826421042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 478}], {
             RGBColor[
             0.93646520269638, 0.7650485289887226, 0.46320776853011214`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 482}], {
             RGBColor[
             0.9762942683395, 0.9798626389829568, 0.8317283846221233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 413}], {
             RGBColor[
             0.727530474186995, 0.7868180588884135, 0.9737167956783392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 473}], {
             RGBColor[
             0.9044124348224334, 0.9257535771255729, 0.9607767804864029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 474}], {
             RGBColor[
             0.7394464273039305, 0.7964919664363123, 0.9746548631572789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 490}], {
             RGBColor[
             0.828979516186499, 0.8664829692312014, 0.9835465004620281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 424}], {
             RGBColor[
             0.9356480079755936, 0.7746801619371303, 0.2962237612713585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 480}], {
             RGBColor[
             0.977280188227795, 0.935022881406173, 0.3662382508517714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 467}], {
             RGBColor[
             0.9639433298956893, 0.8954426548277312, 0.5648995859699475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 443}], {
             RGBColor[
             0.5924348673233211, 0.6574232260158497, 0.908324116527102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 430}], {
             RGBColor[
             0.9465612602226092, 0.9596660558887032, 0.9753420267743158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 477}], {
             RGBColor[
             0.8415313555268893, 0.876809010699664, 0.9716212008960261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 495}], {
             RGBColor[
             0.7740493123247987, 0.8128099021497466, 0.683705740482984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 399}], {
             RGBColor[
             0.9289082937620445, 0.7640116239076249, 0.5710283015327688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 464}], {
             RGBColor[
             0.7634432364808067, 0.8138618528379264, 0.9393525788855812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 481}], {
             RGBColor[
             0.8133138517436205, 0.8542621057656377, 0.9433380308730912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 496}], {
             RGBColor[
             0.772854455229729, 0.8215023041888747, 0.9400934644999266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 407}], {
             RGBColor[
             0.8286658499625754, 0.6855255886621636, 0.5997262226385278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 464}], {
             RGBColor[
             0.7137594865632767, 0.5943189150002377, 0.5892586150703938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 478}], {
             RGBColor[
             0.878533950538692, 0.5413328631603604, 0.2203580897352121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 481}], {
             RGBColor[
             0.7636301018260905, 0.6347191679279488, 0.5932440670579038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 496}], {
             RGBColor[
             0.723170705312199, 0.6019593663511859, 0.5899995006847392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 404}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 418}], {
             RGBColor[
             0.7628242207327514, 0.332584624842513, 0.4315225955872538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 431}], {
             RGBColor[
             0.8518805478676574, 0.33092226713357065`, 0.19457729374712981`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 444}], {
             RGBColor[
             0.8596819590739189, 0.4087713554575028, 0.43580771416750785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 428}], {
             RGBColor[
             0.8519832723570057, 0.8812126052837788, 0.7599871580016708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 437}], {
             RGBColor[
             0.6313529510395417, 0.7105584880100864, 0.9648335098535894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 451}], {
             RGBColor[
             0.7874104054163682, 0.8342099519108612, 0.979349917426785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 417}], {
             RGBColor[
             0.9745185251574527, 0.9794924737082833, 0.8821579649007079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 458}], {
             RGBColor[
             0.8147383058637139, 0.8557274167241753, 0.9613243384026033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 461}], {
             RGBColor[
             0.755939583490274, 0.808427576924498, 0.9563976573722861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 440}], {
             RGBColor[
             0.6002647052907133, 0.6862051557826319, 0.9617807038561337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 445}], {
             RGBColor[
             0.48777390157525297`, 0.5943361349175783, 0.9530118290121238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 471}], {
             RGBColor[
             0.5648490273713084, 0.6576089124355533, 0.9588861310262843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 483}], {
             RGBColor[
             0.5829244095839591, 0.6722833220024723, 0.9603090913263709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 497}], {
             RGBColor[
             0.7703754815667255, 0.8176002096376707, 0.8636783337006957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 418}], {
             RGBColor[
             0.7628242207327514, 0.332584624842513, 0.4315225955872538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 431}], {
             RGBColor[
             0.8518805478676574, 0.33092226713357065`, 0.19457729374712981`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 444}], {
             RGBColor[
             0.8596819590739189, 0.4087713554575028, 0.43580771416750785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 486}], {
             RGBColor[
             0.7852960884100921, 0.3501398186645716, 0.43376238134578804`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 423}], {
             RGBColor[
             0.9234282625412051, 0.7238064781505632, 0.2739741605321985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 429}], {
             RGBColor[
             0.9181217027822147, 0.7570511088993941, 0.5900091202159511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 472}], {
             RGBColor[
             0.8841827869854468, 0.5669829101458028, 0.22507161733203618`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 488}], {
             RGBColor[
             0.662475891547821, 0.5535282014738365, 0.5854984976532444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 419}], {
             RGBColor[
             0.8045697751581977, 0.8455013584022291, 0.8722512427718059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 493}], {
             RGBColor[
             0.8060299935125139, 0.8461051962176389, 0.8480516457168199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 448}], {
             RGBColor[
             0.8856433122727729, 0.9072011944496896, 0.738761762642708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 455}], {
             RGBColor[
             0.7982297047052531, 0.8423023791769757, 0.9805237351504676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 475}], {
             RGBColor[
             0.8472998442525375, 0.8814163876776562, 0.9852075887681505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 478}], {
             RGBColor[
             0.8279752566567529, 0.682389765752588, 0.5991499746561585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 482}], {
             RGBColor[
             0.8678043222998728, 0.8972038757468223, 0.9676705907481695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{408, 463}], {
             RGBColor[
             0.9334438354378374, 0.8054026089221697, 0.5886615421227674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 430}], {
             RGBColor[
             0.7192011947668531, 0.7791211530119557, 0.9674379757799432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 422}], {
             RGBColor[
             0.9526305143509985, 0.9641924956801644, 0.9650683626499481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 428}], {
             RGBColor[
             0.9646670343684438, 0.970177235466757, 0.7709670689744132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 437}], {
             RGBColor[
             0.74403671305098, 0.7995231181930645, 0.9758134208263318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{412, 426}], {
             RGBColor[
             0.7369976906807111, 0.7945235314782273, 0.974405821770286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{412, 476}], {
             RGBColor[
             0.8149488768182793, 0.8554644904318234, 0.9397090959187044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 474}], {
             RGBColor[
             0.6273701224477973, 0.7083663539618832, 0.963808020653023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 490}], {
             RGBColor[
             0.7169032113303657, 0.7783573567567723, 0.9726996579577722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 461}], {
             RGBColor[
             0.7695431893804625, 0.8182913134041753, 0.9207502501590459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 498}], {
             RGBColor[
             0.8735087535439982, 0.4188954824544132, 0.4039891905153514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 499}], {
             RGBColor[
             0.8290020661724499, 0.8661068708529813, 0.92574272921231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 452}], {
             RGBColor[
             0.7204300902810635, 0.7808112755336398, 0.9734367929802155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 468}], {
             RGBColor[
             0.716122191316486, 0.7773762738340879, 0.9730259017312672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{417, 458}], {
             RGBColor[
             0.8305757821695492, 0.8665149160285736, 0.8886559173307763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 431}], {
             RGBColor[
             0.787419152900613, 0.7270063379641256, 0.6107138340015754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 444}], {
             RGBColor[
             0.7991212697100053, 0.8437799704500237, 0.9725594646321425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 486}], {
             RGBColor[
             0.6875424637142651, 0.755832665260627, 0.9694914653995628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 427}], {
             RGBColor[
             0.9526517900010429, 0.9614083241554561, 0.8356173525397017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 454}], {
             RGBColor[
             0.9076859229000137, 0.9292281327151921, 0.9910570876986341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 489}], {
             RGBColor[
             0.9042481817546957, 0.9264869712409132, 0.990729192879286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 500}], {
             RGBColor[
             0.8178505755635529, 0.8583616528420417, 0.9822852955954895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 430}], {
             RGBColor[
             0.7172278825100327, 0.7775191292251649, 0.9672826294106053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 459}], {
             RGBColor[
             0.7049472648536781, 0.6561073662663508, 0.6031524882050401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 477}], {
             RGBColor[
             0.6121979778143127, 0.6946620840361256, 0.9635618035323157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 428}], {
             RGBColor[
             0.9815950244762847, 0.9828021027721449, 0.7423123972487576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 437}], {
             RGBColor[
             0.7609647031588207, 0.8121479854984524, 0.9471587491006761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 451}], {
             RGBColor[
             0.9170221575356472, 0.9357994493992272, 0.9616751566738718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 429}], {
             RGBColor[
             0.9617540823477998, 0.9337945834253155, 0.6425722036547701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 465}], {
             RGBColor[
             0.9475248719391034, 0.9229836445543123, 0.659765433497634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 469}], {
             RGBColor[
             0.9656036667574114, 0.9366655971748878, 0.6360558613817127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 488}], {
             RGBColor[
             0.7061082711134061, 0.730271675999758, 0.6380615810920633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{425, 462}], {
             RGBColor[
             0.46789497821612225`, 0.5771295695143435, 0.9517419678446115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 476}], {
             RGBColor[
             0.9048719200443294, 0.9257691222782214, 0.9486569060209408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 433}], {
             RGBColor[
             0.9368343988256094, 0.7670197883768115, 0.4502578266012268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 500}], {
             RGBColor[
             0.8600403364284055, 0.8883282525249747, 0.8265807729454913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 437}], {
             RGBColor[
             0.7730012231762661, 0.818132725285045, 0.7530574554251415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 451}], {
             RGBColor[
             0.9290586775530925, 0.9417841891858199, 0.7675738629983371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{429, 488}], {
             RGBColor[
             0.7008017113544157, 0.7635163067485888, 0.9540965407758161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{430, 459}], {
             RGBColor[
             0.9306704945833262, 0.835561850475296, 0.6173229244264553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{430, 477}], {
             RGBColor[
             0.8379212075439608, 0.8741165682450707, 0.9777322397537309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 444}], {
             RGBColor[
             0.9327057604123644, 0.8412864338866103, 0.6171415118719565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 486}], {
             RGBColor[
             0.8211269544166242, 0.7533391286972135, 0.6140735126393768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{432, 460}], {
             RGBColor[
             0.9031185317612687, 0.6260655174981828, 0.33175843651190545`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 465}], {
             RGBColor[
             0.90340817427837, 0.744040994673687, 0.6067982231685003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 469}], {
             RGBColor[
             0.9214869690966779, 0.7577229472942626, 0.583088651052579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 495}], {
             RGBColor[
             0.6810240220227881, 0.7494761933307712, 0.9697061192549723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{435, 439}], {
             RGBColor[
             0.819950853351941, 0.8597967803506876, 0.9617062872465533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{435, 453}], {
             RGBColor[
             0.9743552556250095, 0.9794504635146011, 0.886005972305012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 473}], {
             RGBColor[
             0.9818027679878696, 0.9834835604983183, 0.783738086150688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 439}], {
             RGBColor[
             0.8266350064211102, 0.864781810765378, 0.9503917596067737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{439, 453}], {
             RGBColor[
             0.8354715358869852, 0.8704277713358166, 0.8931457500690192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 445}], {
             RGBColor[
             0.5400387196175864, 0.6366112692615629, 0.9572328278728839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 471}], {
             RGBColor[
             0.6171138454136419, 0.6998840467795379, 0.9631071298870444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 450}], {
             RGBColor[
             0.9028639157375752, 0.9223299344003751, 0.8660688019239994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 461}], {
             RGBColor[
             0.7735639875157123, 0.8199540167628998, 0.8541152195659385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 447}], {
             RGBColor[
             0.6951451380201109, 0.277711265049131, 0.4261271301642636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 500}], {
             RGBColor[
             0.7866257073303051, 0.3511785270705201, 0.43389490533375963`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{443, 451}], {
             RGBColor[
             0.9252329302003679, 0.94162597017557, 0.9344735050535586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{444, 486}], {
             RGBColor[
             0.8328290712260165, 0.8701127611831116, 0.9759191432699439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{445, 471}], {
             RGBColor[
             0.5046230416981816, 0.6080150259144843, 0.9543382550430346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 454}], {
             RGBColor[
             0.6778536153620848, 0.7459471680526271, 0.9703688453501796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 500}], {
             RGBColor[
             0.588018268025624, 0.6750806881794766, 0.961597053247035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 455}], {
             RGBColor[
             0.9057658608973895, 0.922921082372274, 0.7407673902337015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 475}], {
             RGBColor[
             0.9548360004446739, 0.9620350908729545, 0.7454512438513844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 478}], {
             RGBColor[
             0.9355114128488894, 0.7630084689478863, 0.3593936297393924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 482}], {
             RGBColor[
             0.9753404784920092, 0.9778225789421205, 0.7279142458314034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{449, 499}], {
             RGBColor[
             0.8308045752332143, 0.8668522546719772, 0.8958704893315255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 461}], {
             RGBColor[
             0.6824980463507935, 0.7505260970825862, 0.9699225111300984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{452, 468}], {
             RGBColor[
             0.8687937095770325, 0.8982165375124541, 0.9873475136723995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 489}], {
             RGBColor[
             0.9014720755185189, 0.9242733794835821, 0.9904644053882201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 500}], {
             RGBColor[
             0.8150744693273761, 0.8561480610847108, 0.9820205081044235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{455, 475}], {
             RGBColor[
             0.8674223928771541, 0.8971362756002406, 0.987213216359144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{455, 482}], {
             RGBColor[
             0.8879268709244894, 0.9129237636694066, 0.9696762183391631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{457, 494}], {
             RGBColor[
             0.9053822001565957, 0.8939998736060112, 0.6625419403363233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{458, 461}], {
             RGBColor[
             0.6119968405023704, 0.6954500192447882, 0.9628956098023547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{459, 477}], {
             RGBColor[
             0.8256405898876062, 0.7527048052862567, 0.6136020985481656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{460, 463}], {
             RGBColor[
             0.8943254646803867, 0.6213259928407934, 0.4484649313127133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{463, 483}], {
             RGBColor[
             0.7927405604006198, 0.8380086712742361, 0.9513664591950945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 481}], {
             RGBColor[
             0.5981650445448526, 0.6845693968582505, 0.9615683444107161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 496}], {
             RGBColor[
             0.5577056480309611, 0.6518095952814875, 0.9583237780375514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{465, 469}], {
             RGBColor[
             0.9460678965897247, 0.9590992890527156, 0.9692840509083291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 470}], {
             RGBColor[
             0.8853035491141017, 0.5090975953829923, 0.4141803156355076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 491}], {
             RGBColor[
             0.8558795753886769, 0.3892071147755576, 0.1995259227752825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 483}], {
             RGBColor[
             0.5997735497068877, 0.6859622129993783, 0.9616355173572817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 497}], {
             RGBColor[
             0.7872246216896541, 0.8312791006345767, 0.8650047597316065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{472, 488}], {
             RGBColor[
             0.6668627955576478, 0.5734481079949976, 0.5891590378919012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{474, 490}], {
             RGBColor[
             0.7288191644473012, 0.788031264304671, 0.9736377254367119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{475, 478}], {
             RGBColor[
             0.897167944828654, 0.737223662175853, 0.6058394558648349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{475, 482}], {
             RGBColor[
             0.9369970104717739, 0.9520377721700872, 0.9743600719568459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{478, 482}], {
             RGBColor[
             0.9176724228759894, 0.753011150245019, 0.5883024578448539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{481, 496}], {
             RGBColor[
             0.6075762632937749, 0.6922098482091986, 0.9623092300250615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{484, 490}], {
             RGBColor[
             0.8737684384808198, 0.8074849640822339, 0.6222039262731516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{489, 500}], {
             RGBColor[
             0.8116367281820581, 0.8534068996104317, 0.9816926132850754]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.0860569014282922], {
             RGBColor[
             0.9914189776076017, 0.9907195409655962, 0.7918732782235238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.0860569014282922], {
             RGBColor[
             0.9294628457788249, 0.9465924598999318, 0.9931341900433037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.0860569014282922], {
             RGBColor[
             0.9288098264358793, 0.755461715076964, 0.26157691918340775`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.0860569014282922], {
             RGBColor[
             0.8662447525395159, 0.4855304852612168, 0.21010368168889168`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.0860569014282922], {
             RGBColor[
             0.6242558449665865, 0.7058380432060345, 0.9635628533217278]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.0860569014282922], {
             RGBColor[
             0.7087260045219952, 0.7723814083404988, 0.9716028427758333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.0860569014282922], {
             RGBColor[
             0.8992554819939736, 0.6354244978621647, 0.23764864351271403`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.0860569014282922], {
             RGBColor[
             0.33407636534708024`, 0.46378188932246034`, 0.9425080284811533]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.0860569014282922], {
             RGBColor[
             0.44298327582575264`, 0.5581115813586073, 0.9494474805142548]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.0860569014282922], {
             RGBColor[
             0.9722028376021425, 0.9787895023141296, 0.9319375246652203]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.0860569014282922], {
             RGBColor[
             0.767369759300133, 0.8181943552822241, 0.9774479041950713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.0860569014282922], {
             RGBColor[
             0.8547284168859094, 0.887001254912752, 0.9860059534992851]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.0860569014282922], {
             RGBColor[
             0.9947758815342954, 0.9921077070077798, 0.736240692769328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.0860569014282922], {
             RGBColor[
             0.9566455786240297, 0.9671869240409267, 0.9582719061321819]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.0860569014282922], {
             RGBColor[
             0.904909816663837, 0.9270145409578612, 0.9907923002075683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.0860569014282922], {
             RGBColor[
             0.9917277650674593, 0.9837579505387221, 0.4223643586779124]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.0860569014282922], {
             RGBColor[
             0.9197038909536297, 0.7193597152629638, 0.25425006975061265`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.0860569014282922], {
             RGBColor[
             0.5903779628947547, 0.6783344523589264, 0.9608958623462621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.0860569014282922], {
             RGBColor[
             0.6843767081676095, 0.7533595529669463, 0.9691759324723398]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.0860569014282922], {
             RGBColor[
             0.7076369116210648, 0.7715306006888794, 0.9714942921736204]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.0860569014282922], {
             RGBColor[
             0.5305395287835829, 0.6297549158567403, 0.9561851616176241]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.0860569014282922], {
             RGBColor[
             0.9944399569901122, 0.9905159551454576, 0.6362018148608012]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.0860569014282922], {
             RGBColor[
             0.9948514260688883, 0.9921389466142401, 0.7349887243281352]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.0860569014282922], {
             RGBColor[
             0.9252954217321314, 0.9432694690868108, 0.9927366974174268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.0860569014282922], {
             RGBColor[
             0.9928401973176479, 0.9913072518393808, 0.76831998962935]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.0860569014282922], {
             RGBColor[
             0.9457322723909728, 0.8225535742180838, 0.27519311641973515`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.0860569014282922], {
             RGBColor[
             0.9858882606319944, 0.9884324473632395, 0.8835315715460542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.0860569014282922], {
             RGBColor[
             0.9185920028930845, 0.9379243448640118, 0.9920973193443458]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.0860569014282922], {
             RGBColor[
             0.5347828024878565, 0.6331997966071715, 0.9565192076672483]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.0860569014282922], {
             RGBColor[
             0.334399525437276, 0.46406179435008954`, 0.9425286199563414]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.0860569014282922], {
             RGBColor[
             0.994872982731618, 0.9914421534209201, 0.6833339944985983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.0860569014282922], {
             RGBColor[
             0.9937669915741006, 0.9890765501678498, 0.5629536823890772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.0860569014282922], {
             RGBColor[
             0.7307891740946888, 0.7896173240969864, 0.9738018933267972]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.0860569014282922], {
             RGBColor[
             0.4954512772940255, 0.6012686925898016, 0.9534228859278658]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.0860569014282922], {
             RGBColor[
             0.9951453967893066, 0.9920248195450299, 0.7129845835333108]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.0860569014282922], {
             RGBColor[
             0.9811427711763504, 0.9480522806692554, 0.38124365621932416`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.0860569014282922], {
             RGBColor[
             0.2709639692526886, 0.40213069016546776`, 0.9387423692424463]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.0860569014282922], {
             RGBColor[
             0.9831498274809092, 0.986953749441663, 0.9134071262326952]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.0860569014282922], {
             RGBColor[
             0.8117979745726563, 0.8529020147200616, 0.9818760934881594]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.0860569014282922], {
             RGBColor[
             0.6210471944247042, 0.7032331161480748, 0.9633102565973966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.0860569014282922], {
             RGBColor[
             0.7285333888504795, 0.7878550875196072, 0.9735770577351661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.0860569014282922], {
             RGBColor[
             0.9654959126757771, 0.9737874886856279, 0.9432905991193813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.0860569014282922], {
             RGBColor[
             0.9725362274644557, 0.9190203878164718, 0.3478088591080171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.0860569014282922], {
             RGBColor[
             0.9589633580889476, 0.873235912351601, 0.29508082460547885`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.0860569014282922], {
             RGBColor[
             0.9621695929621741, 0.8840512954387426, 0.307536441641313]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.0860569014282922], {
             RGBColor[
             0.8659749257577408, 0.8959689158087994, 0.9870786555553575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.0860569014282922], {
             RGBColor[
             0.6058066444645905, 0.690860151111503, 0.9621104646765624]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.0860569014282922], {
             RGBColor[
             0.7297718340424981, 0.7888225703161442, 0.9737004943779782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.0860569014282922], {
             RGBColor[
             0.7412136530399933, 0.7977610062780327, 0.9748409079657708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.0860569014282922], {
             RGBColor[
             0.7134584744296456, 0.7760784498004587, 0.9720745311487822]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.0860569014282922], {
             RGBColor[
             0.9447765639369228, 0.8187645086687385, 0.27442413096424584`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.0860569014282922], {
             RGBColor[
             0.9623451725399679, 0.971437671851205, 0.9486239803246693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.0860569014282922], {
             RGBColor[
             0.9603641227038606, 0.877961020312875, 0.3005225306222146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.0860569014282922], {
             RGBColor[
             0.809731263093604, 0.8512874840050368, 0.9816701030024443]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.0860569014282922], {
             RGBColor[
             0.4910100769958693, 0.597663126113965, 0.9530732583717423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.0860569014282922], {
             RGBColor[
             0.3129320456772, 0.44546774236881737`, 0.9411607311289764]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.0860569014282922], {
             RGBColor[
             0.9927882362375053, 0.991285764597403, 0.7691811191982763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.0860569014282922], {
             RGBColor[
             0.7297718340424981, 0.7888225703161442, 0.9737004943779782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.0860569014282922], {
             RGBColor[
             0.5541979693222818, 0.6489619036866565, 0.9580476407205537]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.0860569014282922], {
             RGBColor[
             0.9040762370292161, 0.926349867184131, 0.9907127926378728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.0860569014282922], {
             RGBColor[
             0.6080768740758788, 0.6927032257826253, 0.962289185467688]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.0860569014282922], {
             RGBColor[
             0.9464370969093286, 0.9595734550929573, 0.9755522028767213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.0860569014282922], {
             RGBColor[
             0.8809091183684686, 0.5521179455408358, 0.22233998799306884`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.0860569014282922], {
             RGBColor[
             0.7302803242877403, 0.7892198067603964, 0.9737511759335125]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.0860569014282922], {
             RGBColor[
             0.6210471944247042, 0.7032331161480748, 0.9633102565973966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.0860569014282922], {
             RGBColor[
             0.3134208668494696, 0.4458911346993708, 0.9411918783818257]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.0860569014282922], {
             RGBColor[
             0.8800043220623688, 0.5480094768353825, 0.22158500377667217`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.0860569014282922], {
             RGBColor[
             0.9357475699643143, 0.9516012233998596, 0.9936467837194913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.0860569014282922], {
             RGBColor[
             0.9591125481088963, 0.8737391653203707, 0.2956603996608085]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.0860569014282922], {
             RGBColor[
             0.962630872531872, 0.9716507464373761, 0.9481403647608677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.0860569014282922], {
             RGBColor[
             0.9947244634729093, 0.9911244857441428, 0.6671685897427809]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.0860569014282922], {
             RGBColor[
             0.9395985099296158, 0.954473248120646, 0.9871281468442363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.0860569014282922], {
             RGBColor[
             0.9235058870535456, 0.7344333628590358, 0.2573092450569236]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.0860569014282922], {
             RGBColor[
             0.7375531045123291, 0.7949013579470221, 0.9744760586983041]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.0860569014282922], {
             RGBColor[
             0.9932512321206558, 0.9914772252935372, 0.7615080792195372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.0860569014282922], {
             RGBColor[
             0.8819885252183052, 0.5570192799440686, 0.2232406715272555]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.0860569014282922], {
             RGBColor[
             0.8420234704363077, 0.324016385341434, 0.1878750287895169]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.0860569014282922], {
             RGBColor[
             0.47847426259280185`, 0.5874859872495516, 0.9520863931417316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.0860569014282922], {
             RGBColor[
             0.9937082193084409, 0.9889508422343911, 0.5565566839723926]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.0860569014282922], {
             RGBColor[
             0.44515590012002204`, 0.5599933993230313, 0.9495859182131093]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.0860569014282922], {
             RGBColor[
             0.6740425805771709, 0.745286453951017, 0.9681459232120379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.0860569014282922], {
             RGBColor[
             0.8307176917338549, 0.8678557544302754, 0.9837157890996548]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.0860569014282922], {
             RGBColor[
             0.8108973104359728, 0.8521984090511834, 0.9817863237041996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.0860569014282922], {
             RGBColor[
             0.9952173363489952, 0.9921786909889989, 0.7208147606459318]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.0860569014282922], {
             RGBColor[
             0.9895157262147583, 0.9899324976033257, 0.823415079259655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.0860569014282922], {
             RGBColor[
             0.5618555705498138, 0.6551786893341711, 0.9586504751399025]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.0860569014282922], {
             RGBColor[
             0.9697318967192379, 0.9769466786494537, 0.9361201830553818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.0860569014282922], {
             RGBColor[
             0.5349635898573565, 0.6333465679381098, 0.9565334399112212]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.0860569014282922], {
             RGBColor[
             0.9761892496182779, 0.9817625618686128, 0.9251895689446732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.0860569014282922], {
             RGBColor[
             0.9945141171263947, 0.9906745761782261, 0.6442736880318423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.0860569014282922], {
             RGBColor[
             0.8996890118638986, 0.9228516129253614, 0.9902943351850827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.0860569014282922], {
             RGBColor[
             0.9884317044036613, 0.9726395639678842, 0.4095597854078852]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.0860569014282922], {
             RGBColor[
             0.9942289836313859, 0.9900647044638207, 0.6132386667400894]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.0860569014282922], {
             RGBColor[
             0.4139435077518233, 0.5329587938341523, 0.9475970921714426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.0860569014282922], {
             RGBColor[
             0.8952500936796065, 0.6172369650088319, 0.23430644932215433`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.0860569014282922], {
             RGBColor[
             0.9593716667614157, 0.9692200361102296, 0.9536573499932449]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.0860569014282922], {
             RGBColor[
             0.9644839508512351, 0.8918581680356193, 0.3165272850104999]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.0860569014282922], {
             RGBColor[
             0.8140653103584886, 0.8546732746683439, 0.9821020803298336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.0860569014282922], {
             RGBColor[
             0.6773557520068964, 0.747874728652954, 0.9684761491768056]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.0860569014282922], {
             RGBColor[
             0.9646183636105852, 0.8923115738345241, 0.3170494531988555]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.0860569014282922], {
             RGBColor[
             0.9887364448662763, 0.9736675251047477, 0.41074364455973683`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.0860569014282922], {
             RGBColor[
             0.9951445965658657, 0.9922601801488783, 0.7301301304922928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.0860569014282922], {
             RGBColor[
             0.5203995701555523, 0.6215228406425745, 0.9553869069305332]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.0860569014282922], {
             RGBColor[
             0.9242256841550072, 0.9424164893800648, 0.9926346648923546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.0860569014282922], {
             RGBColor[
             0.8723649397852354, 0.5133208261379815, 0.21521051594623714`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.0860569014282922], {
             RGBColor[
             0.8226910832400139, 0.17541918584463317`, 0.16936231297753757`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.0860569014282922], {
             RGBColor[
             0.9626236995211117, 0.9716453968176959, 0.948152506797064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.0860569014282922], {
             RGBColor[
             0.8655035117475163, 0.8955930230732388, 0.987033691666226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.0860569014282922], {
             RGBColor[
             0.7982109327297675, 0.8422877143670542, 0.9805218641353852]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.0860569014282922], {
             RGBColor[
             0.9871279350398854, 0.9889450845890816, 0.862986958432773]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.0860569014282922], {
             RGBColor[
             0.994785781315411, 0.9921118008216839, 0.7360766277764308]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.0860569014282922], {
             RGBColor[
             0.6234010903665643, 0.7051441149154807, 0.9634955639085447]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.0860569014282922], {
             RGBColor[
             0.7289029261599352, 0.7881437728743417, 0.9736138897606502]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.0860569014282922], {
             RGBColor[
             0.6299644998442744, 0.710472586407713, 0.9640122595451912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.0860569014282922], {
             RGBColor[
             0.951002425009259, 0.9629782693148468, 0.9678242932318057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.0860569014282922], {
             RGBColor[
             0.4667030597785676, 0.5779295945183125, 0.9511597209368584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.0860569014282922], {
             RGBColor[
             0.9933760991635824, 0.9882404708270363, 0.5204074558124888]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.0860569014282922], {
             RGBColor[
             0.5016279930356163, 0.6062832286866982, 0.9539091396170991]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.0860569014282922], {
             RGBColor[
             0.7307102396336452, 0.7895556598960951, 0.9737940258774049]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.0860569014282922], {
             RGBColor[
             0.7740335927399176, 0.8234001926123937, 0.978112092835285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.0860569014282922], {
             RGBColor[
             0.3350866690000343, 0.46465696356731107`, 0.9425724041365432]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.0860569014282922], {
             RGBColor[
             0.9175671029951101, 0.7108880630498108, 0.25253076000232805`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.0860569014282922], {
             RGBColor[
             0.9888760035337214, 0.9896679558345939, 0.834016939633665]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.0860569014282922], {
             RGBColor[
             0.4139435077518233, 0.5329587938341523, 0.9475970921714426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.0860569014282922], {
             RGBColor[
             0.8795847356118854, 0.5461042327606428, 0.22123489055738382`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.0860569014282922], {
             RGBColor[
             0.43296808969994416`, 0.549436930514323, 0.9488093217103996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.0860569014282922], {
             RGBColor[
             0.992966434019326, 0.9873642385069717, 0.4758179330204009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.0860569014282922], {
             RGBColor[
             0.9227612143077097, 0.9412487608758049, 0.9924949824509717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.0860569014282922], {
             RGBColor[
             0.7740375902538377, 0.8234033155006504, 0.9781124912701137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.0860569014282922], {
             RGBColor[
             0.840268153459609, 0.31052424987372407`, 0.18619413527028325`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.0860569014282922], {
             RGBColor[
             0.8481762150777309, 0.37130907680530634`, 0.1937669040066749]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.0860569014282922], {
             RGBColor[
             0.9944268117818262, 0.9904878388741185, 0.6347710400617005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.0860569014282922], {
             RGBColor[
             0.9835919425253744, 0.9563139107222933, 0.39075822442308206`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.0860569014282922], {
             RGBColor[
             0.9358997979953182, 0.9517147548161318, 0.9933891013704309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.0860569014282922], {
             RGBColor[
             0.9254086716728859, 0.7419772698093332, 0.2588402702257402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.0860569014282922], {
             RGBColor[
             0.9272672475007648, 0.7493459036331933, 0.26033572396323335`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.0860569014282922], {
             RGBColor[
             0.9665946095831851, 0.9746068950402218, 0.9414307918411866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.0860569014282922], {
             RGBColor[
             0.9949217803409345, 0.9921680399137535, 0.7338227719693111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.0860569014282922], {
             RGBColor[
             0.35481967879100806`, 0.48174870483834226`, 0.9438297740712086]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.0860569014282922], {
             RGBColor[
             0.9037359105353183, 0.9260785000758135, 0.9906803319930718]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.0860569014282922], {
             RGBColor[
             0.9252139595616671, 0.9432045133633141, 0.9927289274828857]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.0860569014282922], {
             RGBColor[
             0.893529365402922, 0.9179400780365278, 0.9897068226068535]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.0860569014282922], {
             RGBColor[
             0.8780394081228452, 0.9055888065650839, 0.9882293766534316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.0860569014282922], {
             RGBColor[
             0.9332925138588519, 0.9496461332733748, 0.9934994672035617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.0860569014282922], {
             RGBColor[
             0.9182576770960664, 0.7136259592399249, 0.253086412133815]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.0860569014282922], {
             RGBColor[
             0.9546679695533065, 0.965712026434019, 0.9616194824458639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.0860569014282922], {
             RGBColor[
             0.9564820542158774, 0.9670649678050733, 0.9585487103011875]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.0860569014282922], {
             RGBColor[
             0.530599855664788, 0.6298038919365976, 0.9561899107706973]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.0860569014282922], {
             RGBColor[
             0.9086302706092886, 0.9299811299449323, 0.9911471604261739]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.0860569014282922], {
             RGBColor[
             0.9945254816122576, 0.990698883664361, 0.6455106421845405]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.0860569014282922], {
             RGBColor[
             0.984877239513646, 0.9880143641487449, 0.9002868079158691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.0860569014282922], {
             RGBColor[
             0.9469799106875489, 0.9599782847199781, 0.9746333607387014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.0860569014282922], {
             RGBColor[
             0.9901914691504344, 0.9902119346730291, 0.8122162700488411]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.0860569014282922], {
             RGBColor[
             0.9948913654754712, 0.9914814722512418, 0.6853348427218806]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.0860569014282922], {
             RGBColor[
             0.929412606106092, 0.7578515356049396, 0.2620619298551182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.0860569014282922], {
             RGBColor[
             0.30611291179131705`, 0.4390744573452393, 0.9407440495218204]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.0860569014282922], {
             RGBColor[
             0.9579788425456083, 0.9681812700906207, 0.9560150380838718]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.0860569014282922], {
             RGBColor[
             0.3707902279938319, 0.4955815918546857, 0.9448474033442104]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.0860569014282922], {
             RGBColor[
             0.7077948724672457, 0.7716540009024628, 0.9715100362345397]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.0860569014282922], {
             RGBColor[
             0.7422637151626922, 0.7985813227890527, 0.974945568344773]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.0860569014282922], {
             RGBColor[
             0.9162150046220459, 0.9360289909645848, 0.9918705991272827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.0860569014282922], {
             RGBColor[
             0.9843516215942661, 0.9588764866027929, 0.3937094341523718]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.0860569014282922], {
             RGBColor[
             0.960493287417189, 0.8783967232202486, 0.30102431114278594`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.0860569014282922], {
             RGBColor[
             0.9850762021740773, 0.9613206670381067, 0.39652429287937724`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.0860569014282922], {
             RGBColor[
             0.9940228719281586, 0.9896238523717074, 0.5908046798177842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.0860569014282922], {
             RGBColor[
             0.8750336441979549, 0.5254387895843896, 0.21743734832414144`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.0860569014282922], {
             RGBColor[
             0.4507974140603326, 0.5648797951473931, 0.949945390492791]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.0860569014282922], {
             RGBColor[
             0.9927086106921241, 0.9912528373881047, 0.7705007205495504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.0860569014282922], {
             RGBColor[
             0.6299644998442744, 0.710472586407713, 0.9640122595451912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.0860569014282922], {
             RGBColor[
             0.9897870633443997, 0.9900447024794786, 0.8189183208235141]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.0860569014282922], {
             RGBColor[
             0.7625621472872217, 0.8144386122385332, 0.976968726359313]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.0860569014282922], {
             RGBColor[
             0.8389239349601617, 0.30019199744667, 0.1849069101171349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.0860569014282922], {
             RGBColor[
             0.42882929432607886`, 0.5458521139833848, 0.9485456013289699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.0860569014282922], {
             RGBColor[
             0.772248344779638, 0.8220055433374364, 0.9779341560026951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.0860569014282922], {
             RGBColor[
             0.8334466002353424, 0.8700317119951135, 0.9839760748286521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.0860569014282922], {
             RGBColor[
             0.29858575037567603`, 0.43116293344780227`, 0.940315388814637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.0860569014282922], {
             RGBColor[
             0.9659721476612205, 0.9741426639580084, 0.9424844575110026]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.0860569014282922], {
             RGBColor[
             0.9465416750683502, 0.9596514493127246, 0.97537517933185]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.0860569014282922], {
             RGBColor[
             0.778216012898588, 0.8266675310279177, 0.9785289573897628]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.0860569014282922], {
             RGBColor[
             0.8485161495816131, 0.3739219623623945, 0.19409242567149362`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.0860569014282922], {
             RGBColor[
             0.9727988472648216, 0.9199062660691676, 0.3488290874408509]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.0860569014282922], {
             RGBColor[
             0.7216790155653959, 0.7825003990141335, 0.9728938778638692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.0860569014282922], {
             RGBColor[
             0.938875277392473, 0.795367874007161, 0.26967581728958295`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.0860569014282922], {
             RGBColor[
             0.9107964280332989, 0.6840445930199114, 0.24708291599988724`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.0860569014282922], {
             RGBColor[
             0.9568045061688181, 0.865953597902468, 0.2866940925607525]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.0860569014282922], {
             RGBColor[
             0.8324572337021733, 0.8692428179772036, 0.9838817081655005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.0860569014282922], {
             RGBColor[
             0.9887039178815463, 0.98959679399502, 0.8368688442335974]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.0860569014282922], {
             RGBColor[
             0.9756555698854077, 0.9813645443976586, 0.9260929495264557]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.0860569014282922], {
             RGBColor[
             0.9934063705082741, 0.9883052181724293, 0.5237023048690918]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.0860569014282922], {
             RGBColor[
             0.7074407227712793, 0.7713773364683364, 0.9714747379025629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.0860569014282922], {
             RGBColor[
             0.9952553586821756, 0.9922600169150241, 0.7249532569659711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.0860569014282922], {
             RGBColor[
             0.9952187978944984, 0.992290864305155, 0.7289004224499682]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.0860569014282922], {
             RGBColor[
             0.9938782498276173, 0.9917365132289858, 0.7511167731453752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.0860569014282922], {
             RGBColor[
             0.9166794105808327, 0.7073686584331623, 0.25181650184898147`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.0860569014282922], {
             RGBColor[
             0.9931266298570909, 0.9877068812056669, 0.49325426134698247`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.0860569014282922], {
             RGBColor[
             0.9771351691162565, 0.9345336978908471, 0.3656748789880058]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.0860569014282922], {
             RGBColor[
             0.9793586872723007, 0.9841263232815052, 0.9198245377181432]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.0860569014282922], {
             RGBColor[
             0.9952187978944984, 0.992290864305155, 0.7289004224499682]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.0860569014282922], {
             RGBColor[
             0.7831685383045918, 0.8305364815156749, 0.979022578838252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.0860569014282922], {
             RGBColor[
             0.8751175238894345, 0.9032589753897968, 0.9879506847268521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.0860569014282922], {
             RGBColor[
             0.9937709623176162, 0.9890850431867255, 0.563385873316147]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.0860569014282922], {
             RGBColor[
             0.8434209630100141, 0.8779849981247719, 0.9849274384543191]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.0860569014282922], {
             RGBColor[
             0.7297718340424981, 0.7888225703161442, 0.9737004943779782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.0860569014282922], {
             RGBColor[
             0.9353990437647335, 0.7815857660593604, 0.2668787581150132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.0860569014282922], {
             RGBColor[
             0.7506786430960607, 0.8051551284464212, 0.9757842897191986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.0860569014282922], {
             RGBColor[
             0.9849902672593264, 0.9880611040262643, 0.8984136456635161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.0860569014282922], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.0860569014282922], {
             RGBColor[
             0.5393170090844335, 0.6368808697859522, 0.9568761570198768]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.0860569014282922], {
             RGBColor[
             0.9875766961009964, 0.9891306588204842, 0.8555498262937655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.0860569014282922], {
             RGBColor[
             0.7765414973628456, 0.8253593867646062, 0.9783620573303973]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.0860569014282922], {
             RGBColor[
             0.9949217803409345, 0.9921680399137535, 0.7338227719693111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.0860569014282922], {
             RGBColor[
             0.8188234732480434, 0.8583903876810415, 0.9825763295391041]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.0860569014282922], {
             RGBColor[
             0.49955414134803394`, 0.604599582460765, 0.9537458784154836]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.0860569014282922], {
             RGBColor[
             0.9633501228742496, 0.8880335000337782, 0.3121225774253586]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.0860569014282922], {
             RGBColor[
             0.9566203836722591, 0.8653325094875566, 0.28597881143023696`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.0860569014282922], {
             RGBColor[
             0.9521516823050813, 0.963835383524335, 0.965878900404287]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.0860569014282922], {
             RGBColor[
             0.4511044330960283, 0.5651457196048872, 0.9499649534742592]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.0860569014282922], {
             RGBColor[
             0.9724319368963994, 0.918668591241828, 0.3474037099447397]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.0860569014282922], {
             RGBColor[
             0.9279287322849625, 0.9453691994423274, 0.9929878649287398]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.0860569014282922], {
             RGBColor[
             0.8821414170467385, 0.5577135260281905, 0.22336824821662188`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.0860569014282922], {
             RGBColor[
             0.8694854757461257, 0.8987681330781966, 0.9874134949471546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.0860569014282922], {
             RGBColor[
             0.9053357305370828, 0.662394747116984, 0.24268911061538745`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.0860569014282922], {
             RGBColor[
             0.8594620063491899, 0.45473161896156633`, 0.20444399200736055`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.0860569014282922], {
             RGBColor[
             0.9941356829316702, 0.9918429684332407, 0.7468504403957015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.0860569014282922], {
             RGBColor[
             0.71188751311776, 0.7748512028838656, 0.9719179524066816]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.0860569014282922], {
             RGBColor[
             0.9625289218398253, 0.9715747117781767, 0.9483129406895036]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.0860569014282922], {
             RGBColor[
             0.9813361784627297, 0.9856011329734824, 0.9164771609450512]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.0860569014282922], {
             RGBColor[
             0.71188751311776, 0.7748512028838656, 0.9719179524066816]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.0860569014282922], {
             RGBColor[
             0.4284015194296424, 0.545481596868683, 0.9485183438908354]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.0860569014282922], {
             RGBColor[
             0.5479998872483798, 0.6439300214386474, 0.9575597049953735]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.0860569014282922], {
             RGBColor[
             0.9820607089319499, 0.9861414866111171, 0.9152507198484721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.0860569014282922], {
             RGBColor[
             0.881222466876741, 0.5535407879324971, 0.22260145366924608`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.0860569014282922], {
             RGBColor[
             0.8871878696252153, 0.5806282885581091, 0.22757913194797494`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.0860569014282922], {
             RGBColor[
             0.9161597094148285, 0.705308216490103, 0.25139833809186024`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.0860569014282922], {
             RGBColor[
             0.4284015194296424, 0.545481596868683, 0.9485183438908354]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.0860569014282922], {
             RGBColor[
             0.907032706551878, 0.9287072757302742, 0.9909947833402158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.0860569014282922], {
             RGBColor[
             0.9263621855885937, 0.9441200776294203, 0.9928384463063674]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.0860569014282922], {
             RGBColor[
             0.8538887286337347, 0.8863317102931982, 0.9859258632841942]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.0860569014282922], {
             RGBColor[
             0.8943282723192684, 0.6130511895083848, 0.23353725898317895`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.0860569014282922], {
             RGBColor[
             0.9942531557555676, 0.9901164061932687, 0.6158696532842083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.0860569014282922], {
             RGBColor[
             0.9122512570313426, 0.9328684062288201, 0.9914925333436022]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.0860569014282922], {
             RGBColor[
             0.9781263500772029, 0.937877184012476, 0.3695254298524637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.0860569014282922], {
             RGBColor[
             0.47645263718730263`, 0.5858447406721807, 0.9519272433843528]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.0860569014282922], {
             RGBColor[
             0.6718893720517873, 0.7436043510859964, 0.9679313115091054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.0860569014282922], {
             RGBColor[
             0.9642934512573637, 0.9728906949286251, 0.9453260526485894]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.0860569014282922], {
             RGBColor[
             0.9845285399878514, 0.9594732738867701, 0.3943967287032151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.0860569014282922], {
             RGBColor[
             0.977332982403994, 0.9826155559075094, 0.9232535276717411]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.0860569014282922], {
             RGBColor[
             0.9695585044588393, 0.9768173629855522, 0.9364136909242924]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.0860569014282922], {
             RGBColor[
             0.6543192374469097, 0.7298784283946972, 0.9661800846939343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.0860569014282922], {
             RGBColor[
             0.5583918595444682, 0.652366692701629, 0.9583777991215703]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.0860569014282922], {
             RGBColor[
             0.5248256446362427, 0.6251161272983821, 0.9557353437268982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.0860569014282922], {
             RGBColor[
             0.9944780871721284, 0.9919845613860577, 0.7411759160175412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.0860569014282922], {
             RGBColor[
             0.90856365513361, 0.9299280125728552, 0.9911408065826354]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.0860569014282922], {
             RGBColor[
             0.5391835943557824, 0.6367725576989682, 0.9568656541237232]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.0860569014282922], {
             RGBColor[
             0.9665458233909934, 0.8988133482629188, 0.32453727047550335`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.0860569014282922], {
             RGBColor[
             0.9440354999380339, 0.8158264368580825, 0.2738278534757321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.0860569014282922], {
             RGBColor[
             0.9854469343234846, 0.9625712336301057, 0.3979645172729326]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.0860569014282922], {
             RGBColor[
             0.9874100836085136, 0.9890617602730968, 0.8583110264735151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.0860569014282922], {
             RGBColor[
             0.3731276649241932, 0.4976061622407686, 0.9449963427584986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.0860569014282922], {
             RGBColor[
             0.9941933465467119, 0.9918668138199478, 0.7458948050658091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.0860569014282922], {
             RGBColor[
             0.7033258604351998, 0.7681627747372791, 0.9710646068804772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.0860569014282922], {
             RGBColor[
             0.4157029888946587, 0.5344827679659827, 0.947709204754016]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.0860569014282922], {
             RGBColor[
             0.8455758442464051, 0.8797032419299772, 0.9851329729503312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.0860569014282922], {
             RGBColor[
             0.9403019317545571, 0.9549978589659397, 0.9859374371764053]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.0860569014282922], {
             RGBColor[
             0.9803058348338546, 0.9848327043821002, 0.9182212639520798]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.0860569014282922], {
             RGBColor[
             0.6798635002997572, 0.7498338006789298, 0.9687260980903977]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.0860569014282922], {
             RGBColor[
             0.29833153557609476`, 0.4308957375752931, 0.940300911657878]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.0860569014282922], {
             RGBColor[
             0.9932337373746605, 0.9879359733555171, 0.5049122536434604]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.0860569014282922], {
             RGBColor[
             0.8926306837273766, 0.9172234936625121, 0.9896211055463774]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.0860569014282922], {
             RGBColor[
             0.5779701337926271, 0.668261217727488, 0.959919072587967]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.0860569014282922], {
             RGBColor[
             0.9878626283445765, 0.9892488991513281, 0.8508111890487187]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.0860569014282922], {
             RGBColor[
             0.41249261029268103`, 0.5317020993792699, 0.9475046422683243]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.0860569014282922], {
             RGBColor[
             0.994785781315411, 0.9921118008216839, 0.7360766277764308]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.0860569014282922], {
             RGBColor[
             0.7447447824611768, 0.8005195514194388, 0.9751928579461938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.0860569014282922], {
             RGBColor[
             0.7859170078870592, 0.832683606842641, 0.9792965206003237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.0860569014282922], {
             RGBColor[
             0.9943921004440595, 0.9919490036642432, 0.7426009386281616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.0860569014282922], {
             RGBColor[
             0.6928862314938027, 0.760007257264141, 0.970024082231478]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.0860569014282922], {
             RGBColor[
             0.9641466914080326, 0.9727812416732912, 0.9455744787924079]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.0860569014282922], {
             RGBColor[
             0.9428731468145535, 0.8112180940546999, 0.2728925968686453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.0860569014282922], {
             RGBColor[
             0.9169519612599091, 0.9366166201834619, 0.991940890709291]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.0860569014282922], {
             RGBColor[
             0.6312425932874741, 0.7115102002423561, 0.9641128757428504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.0860569014282922], {
             RGBColor[
             0.9926541776409996, 0.986696353687694, 0.441830753262551]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.0860569014282922], {
             RGBColor[
             0.8339662626696227, 0.26208515575573654`, 0.18015943753282468`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.0860569014282922], {
             RGBColor[
             0.9795970341444822, 0.9428381467044494, 0.37523875973846155`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.0860569014282922], {
             RGBColor[
             0.8426196074977271, 0.32859855602443, 0.18844589031277267`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.0860569014282922], {
             RGBColor[
             0.9891826796075204, 0.9897947742723254, 0.8289345234385777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.0860569014282922], {
             RGBColor[
             0.9487897406637753, 0.9613280529529231, 0.9715697906682065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.0860569014282922], {
             RGBColor[
             0.8144021177083163, 0.85493639112986, 0.9821356501388208]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.0860569014282922], {
             RGBColor[
             0.9593716667614157, 0.9692200361102296, 0.9536573499932449]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.0860569014282922], {
             RGBColor[
             0.8878617572218125, 0.58368825474381, 0.22814144027707217`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.0860569014282922], {
             RGBColor[
             0.9691721844156284, 0.9765292461298665, 0.9370676299890444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.0860569014282922], {
             RGBColor[
             0.9040762370292161, 0.926349867184131, 0.9907127926378728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.0860569014282922], {
             RGBColor[
             0.6459555121737379, 0.7233446226446291, 0.965346466722161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.0860569014282922], {
             RGBColor[
             0.9949217803409345, 0.9921680399137535, 0.7338227719693111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.0860569014282922], {
             RGBColor[
             0.995220389179555, 0.9922915223424201, 0.7288740507384653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.0860569014282922], {
             RGBColor[
             0.864485810612455, 0.8947815358129023, 0.9869366224234513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.0860569014282922], {
             RGBColor[
             0.7297718340424981, 0.7888225703161442, 0.9737004943779782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.0860569014282922], {
             RGBColor[
             0.6648527121076335, 0.7381072588570271, 0.967229963007198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.0860569014282922], {
             RGBColor[
             0.7056126309596984, 0.7699492172511171, 0.9712925307952738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.0860569014282922], {
             RGBColor[
             0.6796316638797563, 0.749652688305603, 0.9687029908026865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.0860569014282922], {
             RGBColor[
             0.9547859169873797, 0.858448258094622, 0.28247789137835627`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.0860569014282922], {
             RGBColor[
             0.261695529432354, 0.39238897226127023`, 0.9382145453061062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.0860569014282922], {
             RGBColor[
             0.6274352320576256, 0.7084192128762963, 0.963813146320013]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.0860569014282922], {
             RGBColor[
             0.9296469846083008, 0.7587807682641917, 0.26225051629956597`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.0860569014282922], {
             RGBColor[
             0.9080110188028646, 0.9294873553636324, 0.9910880956360646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.0860569014282922], {
             RGBColor[
             0.833159981292454, 0.8698031698301184, 0.9839487368580117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.0860569014282922], {
             RGBColor[
             0.9882207688266499, 0.989396999444456, 0.8448758744229037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.0860569014282922], {
             RGBColor[
             0.8282480465095615, 0.21813244061120735`, 0.17468366728014864`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.0860569014282922], {
             RGBColor[
             0.8593362879220334, 0.8906754461996299, 0.9864454563522057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.0860569014282922], {
             RGBColor[
             0.9596578497911538, 0.8755785959375486, 0.29777879372479643`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.0860569014282922], {
             RGBColor[
             0.861335367163534, 0.8922694577232421, 0.9866361303148591]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.0860569014282922], {
             RGBColor[
             0.9162150046220459, 0.9360289909645848, 0.9918705991272827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.0860569014282922], {
             RGBColor[
             0.9899831229747894, 0.9901257781751474, 0.8156691053618979]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.0860569014282922], {
             RGBColor[
             0.6505567722680523, 0.7269391620011793, 0.9658050773271419]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.0860569014282922], {
             RGBColor[
             0.8986772233312333, 0.9220448402136823, 0.9901978298916029]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.0860569014282922], {
             RGBColor[
             0.9945907770816859, 0.9908385440710834, 0.6526176510748809]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.0860569014282922], {
             RGBColor[
             0.9849072089892894, 0.9880267572971039, 0.8997901361459415]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.0860569014282922], {
             RGBColor[
             0.9860771207353004, 0.9885105458694399, 0.8804016708799934]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.0860569014282922], {
             RGBColor[
             0.40568483001390493`, 0.5258055422707799, 0.9470708565288444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.0860569014282922], {
             RGBColor[
             0.9479367945265521, 0.9606919271203531, 0.9730136059945443]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.0860569014282922], {
             RGBColor[
             0.7297718340424981, 0.7888225703161442, 0.9737004943779782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.0860569014282922], {
             RGBColor[
             0.6796316638797563, 0.749652688305603, 0.9687029908026865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.0860569014282922], {
             RGBColor[
             0.7481805013234707, 0.8032035611070932, 0.9755352982937691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.0860569014282922], {
             RGBColor[
             0.8518394003746422, 0.8846976315669316, 0.985730396525385]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.0860569014282922], {
             RGBColor[
             0.5418866311075848, 0.6389670047044993, 0.957078447078375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.0860569014282922], {
             RGBColor[
             0.8144021177083163, 0.85493639112986, 0.9821356501388208]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.0860569014282922], {
             RGBColor[
             0.9499572029113945, 0.8393040158569198, 0.27859259468833175`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.0860569014282922], {
             RGBColor[
             0.9884628488201066, 0.9894971057429224, 0.8408639824483857]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.0860569014282922], {
             RGBColor[
             0.8721543210738953, 0.9008961978986837, 0.9876680517970235]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.0860569014282922], {
             RGBColor[
             0.9952173363489952, 0.9921786909889989, 0.7208147606459318]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.0860569014282922], {
             RGBColor[
             0.9507947265176238, 0.9628233681198602, 0.9681758726017019]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.0860569014282922], {
             RGBColor[
             0.9494128962936107, 0.9617928014013306, 0.9705149507319133]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.0860569014282922], {
             RGBColor[
             0.7297718340424981, 0.7888225703161442, 0.9737004943779782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.0860569014282922], {
             RGBColor[
             0.9817337654342356, 0.9858976526858426, 0.9158041499095815]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.0860569014282922], {
             RGBColor[
             0.9521387341917417, 0.9638257268426068, 0.9659008181827622]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.0860569014282922], {
             RGBColor[
             0.8995330168452805, 0.6366847188020381, 0.23788022539564627`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.0860569014282922], {
             RGBColor[
             0.864485810612455, 0.8947815358129023, 0.9869366224234513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.0860569014282922], {
             RGBColor[
             0.3821131715511962, 0.5053889564563839, 0.9455688912951997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.0860569014282922], {
             RGBColor[
             0.9195371413600953, 0.938677972622506, 0.9921874674950644]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.0860569014282922], {
             RGBColor[
             0.8396067790431282, 0.8749436713628427, 0.9845636381825952]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.0860569014282922], {
             RGBColor[
             0.5778955075676374, 0.6682006327961684, 0.959913197738171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.0860569014282922], {
             RGBColor[
             0.9474780655824178, 0.9603498078249174, 0.9737901144412937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.0860569014282922], {
             RGBColor[
             0.8423351313749579, 0.3264119478865936, 0.188173475656339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.0860569014282922], {
             RGBColor[
             0.8780394081228452, 0.9055888065650839, 0.9882293766534316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.0860569014282922], {
             RGBColor[
             0.8283166269053037, 0.2186595795850035, 0.17474933994456193`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.0860569014282922], {
             RGBColor[
             0.7100967120988425, 0.7734522155172954, 0.9717394620971029]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.0860569014282922], {
             RGBColor[
             0.7691269110511739, 0.8195670555849852, 0.9776230406600984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.0860569014282922], {
             RGBColor[
             0.6718893720517873, 0.7436043510859964, 0.9679313115091054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.0860569014282922], {
             RGBColor[
             0.5903779628947547, 0.6783344523589264, 0.9608958623462621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.0860569014282922], {
             RGBColor[
             0.8719555286644952, 0.5114617858590967, 0.2148688932715066]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.0860569014282922], {
             RGBColor[
             0.9946328588614328, 0.9909285527428415, 0.6571979931016946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.0860569014282922], {
             RGBColor[
             0.6709766525313169, 0.7428913276596797, 0.9678403401571537]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.0860569014282922], {
             RGBColor[
             0.9573753477542426, 0.9677311846633522, 0.9570365973490037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.0860569014282922], {
             RGBColor[
             0.9163519631987888, 0.936138198016038, 0.9918836623585968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.0860569014282922], {
             RGBColor[
             0.5905108500273831, 0.6784423361196912, 0.9609063237081242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.0860569014282922], {
             RGBColor[
             0.9731622258119019, 0.9211320272338096, 0.35024074447797715`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.0860569014282922], {
             RGBColor[
             0.9032764800705589, 0.925712162694122, 0.9906365111052047]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.0860569014282922], {
             RGBColor[
             0.8745906354121629, 0.5234271901554384, 0.2170676909341375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.0860569014282922], {
             RGBColor[
             0.9494128962936107, 0.9617928014013306, 0.9705149507319133]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.0860569014282922], {
             RGBColor[
             0.9364871355820745, 0.9521527902266577, 0.9923948920382287]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.0860569014282922], {
             RGBColor[
             0.9935832961684177, 0.9886836442695484, 0.5429595711171192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.0860569014282922], {
             RGBColor[
             0.4954512772940255, 0.6012686925898016, 0.9534228859278658]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.0860569014282922], {
             RGBColor[
             0.2709639692526886, 0.40213069016546776`, 0.9387423692424463]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.0860569014282922], {
             RGBColor[
             0.9740743315776254, 0.9242087741542131, 0.3537841031410918]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.0860569014282922], {
             RGBColor[
             0.9828869780897801, 0.9539359001475126, 0.3880195707121612]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.0860569014282922], {
             RGBColor[
             0.9950870481598906, 0.9919000177266605, 0.7066336953073814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.0860569014282922], {
             RGBColor[
             0.8396067790431282, 0.8749436713628427, 0.9845636381825952]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.0860569014282922], {
             RGBColor[
             0.9749633423111079, 0.9272076161078964, 0.3572377419650813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.0860569014282922], {
             RGBColor[
             0.9873799357573437, 0.9890492933618736, 0.8588106543875368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.0860569014282922], {
             RGBColor[
             0.19888968485836142`, 0.32637604749346166`, 0.934637845370538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.0860569014282922], {
             RGBColor[
             0.9501714082055378, 0.9623584983432966, 0.969230987916611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.0860569014282922], {
             RGBColor[
             0.9882671046638604, 0.9720843303956787, 0.40892034650081105`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.0860569014282922], {
             RGBColor[
             0.9785920436795745, 0.9835545617453136, 0.9211222653479563]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.0860569014282922], {
             RGBColor[
             0.8792245438445145, 0.544468686069936, 0.22093433771758136`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[401, 0.0860569014282922], {
             RGBColor[
             0.7103350002202813, 0.7736383680088201, 0.9717632124301189]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[402, 0.0860569014282922], {
             RGBColor[
             0.9586810488516174, 0.968704974403885, 0.9548263859725348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[403, 0.0860569014282922], {
             RGBColor[
             0.5479998872483798, 0.6439300214386474, 0.9575597049953735]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[404, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[405, 0.0860569014282922], {
             RGBColor[
             0.8797958829756201, 0.5470630036246418, 0.22141107709337945`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[406, 0.0860569014282922], {
             RGBColor[
             0.6170948462980028, 0.7000244218875646, 0.9629991132749344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[407, 0.0860569014282922], {
             RGBColor[
             0.7781071560806364, 0.8265824912543913, 0.9785181075594741]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[408, 0.0860569014282922], {
             RGBColor[
             0.8992554819939736, 0.6354244978621647, 0.23764864351271403`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[409, 0.0860569014282922], {
             RGBColor[
             0.4954512772940255, 0.6012686925898016, 0.9534228859278658]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[410, 0.0860569014282922], {
             RGBColor[
             0.9357025242431577, 0.9515676283747766, 0.9937230343756037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[411, 0.0860569014282922], {
             RGBColor[
             0.8370179603650232, 0.28554184150504147`, 0.18308174669233973`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[412, 0.0860569014282922], {
             RGBColor[
             0.647074647454661, 0.7242188996318293, 0.9654580116680496]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[413, 0.0860569014282922], {
             RGBColor[
             0.6154541693308618, 0.6986924464139844, 0.9628699531740833]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[414, 0.0860569014282922], {
             RGBColor[
             0.9858882606319944, 0.9884324473632395, 0.8835315715460542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[415, 0.0860569014282922], {
             RGBColor[
             0.9110642734406441, 0.6851065108058444, 0.247298430701777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[416, 0.0860569014282922], {
             RGBColor[
             0.567758572020517, 0.6599710118552736, 0.9591151810390832]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[417, 0.0860569014282922], {
             RGBColor[
             0.9903560014632881, 0.9902799730126817, 0.8094895438288808]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[418, 0.0860569014282922], {
             RGBColor[
             0.6538346621982539, 0.7294998745275391, 0.9661317867617615]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[419, 0.0860569014282922], {
             RGBColor[
             0.9920447040183925, 0.9909782949168935, 0.7815033722686775]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[420, 0.0860569014282922], {
             RGBColor[
             0.9104620291361905, 0.9314417244725232, 0.9913218751896999]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[421, 0.0860569014282922], {
             RGBColor[
             0.4915046527803846, 0.5980646450162197, 0.95311219318919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[422, 0.0860569014282922], {
             RGBColor[
             0.9695585044588393, 0.9768173629855522, 0.9364136909242924]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[423, 0.0860569014282922], {
             RGBColor[
             0.9670606421067902, 0.9005499526764846, 0.32653724397101747`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[424, 0.0860569014282922], {
             RGBColor[
             0.8963326736400791, 0.6221527077663642, 0.23520978057763575`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[425, 0.0860569014282922], {
             RGBColor[
             0.5475741830631058, 0.643584415603287, 0.9575261920025029]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[426, 0.0860569014282922], {
             RGBColor[
             0.8269207339067611, 0.8648281633246254, 0.9833536318725223]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[427, 0.0860569014282922], {
             RGBColor[
             0.9948415508658955, 0.991374923838389, 0.6799128298897035]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[428, 0.0860569014282922], {
             RGBColor[
             0.99363154449373, 0.9887868425587375, 0.5482111035732229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[429, 0.0860569014282922], {
             RGBColor[
             0.9564475225888094, 0.9670392141741464, 0.9586071633385228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[430, 0.0860569014282922], {
             RGBColor[
             0.9429511122396806, 0.9569736134341099, 0.9814530656320205]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[431, 0.0860569014282922], {
             RGBColor[
             0.9210036436029722, 0.7245128014007121, 0.25529588124138947`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[432, 0.0860569014282922], {
             RGBColor[
             0.9940113901243472, 0.9895992939543433, 0.5895549563303971]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[433, 0.0860569014282922], {
             RGBColor[
             0.8788272467853233, 0.5426646529152341, 0.2206028233127501]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[434, 0.0860569014282922], {
             RGBColor[
             0.8022165240598393, 0.8454169127577279, 0.9809211040447876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[435, 0.0860569014282922], {
             RGBColor[
             0.9588345730899652, 0.968819472529472, 0.9545665094825462]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[436, 0.0860569014282922], {
             RGBColor[
             0.9943874453740005, 0.9904036381083334, 0.6304862495111653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[437, 0.0860569014282922], {
             RGBColor[
             0.5523709018588021, 0.6474786080113525, 0.9579038072770599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[438, 0.0860569014282922], {
             RGBColor[
             0.9722028792283037, 0.9787895333588525, 0.931937454202987]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[439, 0.0860569014282922], {
             RGBColor[
             0.6810671336139167, 0.7507740881719033, 0.9688460650105604]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[440, 0.0860569014282922], {
             RGBColor[
             0.6525295233330468, 0.7284802901266164, 0.9660017027168938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[441, 0.0860569014282922], {
             RGBColor[
             0.993929856902494, 0.9917578540806887, 0.7502615103598393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[442, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[443, 0.0860569014282922], {
             RGBColor[
             0.9859800497882808, 0.9884704045382378, 0.882010387683666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[444, 0.0860569014282922], {
             RGBColor[
             0.9444078772217567, 0.9580600663725085, 0.9789871425025236]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[445, 0.0860569014282922], {
             RGBColor[
             0.42754791590212615`, 0.5447422483965092, 0.9484639530288741]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[446, 0.0860569014282922], {
             RGBColor[
             0.9715383930199698, 0.9782939606326734, 0.9330622560279371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[447, 0.0860569014282922], {
             RGBColor[
             0.4507974140603326, 0.5648797951473931, 0.949945390492791]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[448, 0.0860569014282922], {
             RGBColor[
             0.9931794684649093, 0.9878198976449879, 0.49900541772594187`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[449, 0.0860569014282922], {
             RGBColor[
             0.9894932787535233, 0.9899232150012316, 0.8237870917844852]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[450, 0.0860569014282922], {
             RGBColor[
             0.8117979745726563, 0.8529020147200616, 0.9818760934881594]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[451, 0.0860569014282922], {
             RGBColor[
             0.864485810612455, 0.8947815358129023, 0.9869366224234513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[452, 0.0860569014282922], {
             RGBColor[
             0.87310160854161, 0.9016515392120059, 0.9877584049213477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[453, 0.0860569014282922], {
             RGBColor[
             0.9898759381600537, 0.9900814544997301, 0.8174454351274779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[454, 0.0860569014282922], {
             RGBColor[
             0.904909816663837, 0.9270145409578612, 0.9907923002075683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[455, 0.0860569014282922], {
             RGBColor[
             0.8183522533298697, 0.8580222670995601, 0.9825293627414611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[456, 0.0860569014282922], {
             RGBColor[
             0.9441387352843182, 0.9578593407562463, 0.9794427295991472]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[457, 0.0860569014282922], {
             RGBColor[
             0.9706475203468744, 0.9126493352193497, 0.34047158860862503`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[458, 0.0860569014282922], {
             RGBColor[
             0.6707955628758102, 0.7427498590444654, 0.9678222908326718]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[459, 0.0860569014282922], {
             RGBColor[
             0.9183898769269716, 0.7141500875164819, 0.25319278322089017`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[460, 0.0860569014282922], {
             RGBColor[
             0.8576721025797294, 0.4442986292701026, 0.2028601766026596]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[461, 0.0860569014282922], {
             RGBColor[
             0.5531981181289305, 0.648150179445111, 0.9579689287720375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[462, 0.0860569014282922], {
             RGBColor[
             0.3882157733691387, 0.5106747234253999, 0.9459577436867201]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[463, 0.0860569014282922], {
             RGBColor[
             0.9676321888817012, 0.9753807199821749, 0.9396744407328207]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[464, 0.0860569014282922], {
             RGBColor[
             0.5482944292820389, 0.6441691439305393, 0.957582892423206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[465, 0.0860569014282922], {
             RGBColor[
             0.9279891017714167, 0.94541733643214, 0.9929936230242503]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[466, 0.0860569014282922], {
             RGBColor[
             0.8349167633035023, 0.2693911201397685, 0.18106963801326467`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[467, 0.0860569014282922], {
             RGBColor[
             0.9405067240340349, 0.8018360162935888, 0.27098851755235825`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[468, 0.0860569014282922], {
             RGBColor[
             0.864485810612455, 0.8947815358129023, 0.9869366224234513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[469, 0.0860569014282922], {
             RGBColor[
             0.9641466914080326, 0.9727812416732912, 0.9455744787924079]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[470, 0.0860569014282922], {
             RGBColor[
             0.9860771207353004, 0.9885105458694399, 0.8804016708799934]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[471, 0.0860569014282922], {
             RGBColor[
             0.581698167494237, 0.6712878034324593, 0.9602125570571951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[472, 0.0860569014282922], {
             RGBColor[
             0.8885696909952737, 0.586902816666964, 0.22873215757069293`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[473, 0.0860569014282922], {
             RGBColor[
             0.9692180906017386, 0.9765634828883031, 0.9369899227902105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[474, 0.0860569014282922], {
             RGBColor[
             0.6392860755647328, 0.7180402615097818, 0.9647460881319626]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[475, 0.0860569014282922], {
             RGBColor[
             0.9164925324244385, 0.9362502841009211, 0.9918970699768269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[476, 0.0860569014282922], {
             RGBColor[
             0.9828231061818977, 0.9867100812318174, 0.9139601801693592]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[477, 0.0860569014282922], {
             RGBColor[
             0.7328913028482409, 0.7912595230560315, 0.9740114138754412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[478, 0.0860569014282922], {
             RGBColor[
             0.8778433572328694, 0.5381970402507847, 0.21978184175284285`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[479, 0.0860569014282922], {
             RGBColor[
             0.9390054242477961, 0.9540309257902335, 0.9881320862020375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[480, 0.0860569014282922], {
             RGBColor[
             0.9795970341444822, 0.9428381467044494, 0.37523875973846155`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[481, 0.0860569014282922], {
             RGBColor[
             0.6480356598076664, 0.7249696497859616, 0.9655537963982261]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[482, 0.0860569014282922], {
             RGBColor[
             0.9575014885191092, 0.9678252602392532, 0.956823073936865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[483, 0.0860569014282922], {
             RGBColor[
             0.6178489319195384, 0.7006366225662972, 0.9630584776573683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[484, 0.0860569014282922], {
             RGBColor[
             0.9291846236317697, 0.7569476610649077, 0.261878489804842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[485, 0.0860569014282922], {
             RGBColor[
             0.5493887515754312, 0.6450575640669727, 0.9576690414827765]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[486, 0.0860569014282922], {
             RGBColor[
             0.7212502652302764, 0.7821654559937149, 0.9728511440373642]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[487, 0.0860569014282922], {
             RGBColor[
             0.47300311378761184`, 0.5830442621770534, 0.9516556842663085]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[488, 0.0860569014282922], {
             RGBColor[
             0.44515590012002204`, 0.5599933993230313, 0.9495859182131093]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[489, 0.0860569014282922], {
             RGBColor[
             0.8980343343732009, 0.9215322180093031, 0.990136510568872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[490, 0.0860569014282922], {
             RGBColor[
             0.8183522533298697, 0.8580222670995601, 0.9825293627414611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[491, 0.0860569014282922], {
             RGBColor[
             0.8978051995590259, 0.6288391040471358, 0.23643849229931818`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[492, 0.0860569014282922], {
             RGBColor[
             0.8867820378781774, 0.912559942219623, 0.989063256484133]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[493, 0.0860569014282922], {
             RGBColor[
             0.9949651407270251, 0.9921859705477131, 0.7331041781587054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[494, 0.0860569014282922], {
             RGBColor[
             0.8401168799663169, 0.8753504119926727, 0.9846122920640215]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[495, 0.0860569014282922], {
             RGBColor[
             0.5598315199857369, 0.6535354739038146, 0.958491134465157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[496, 0.0860569014282922], {
             RGBColor[
             0.5671168667798834, 0.6594500466324357, 0.9590646636518968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[497, 0.0860569014282922], {
             RGBColor[
             0.9927510758850713, 0.991270397836694, 0.7697969624060179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[498, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[499, 0.0860569014282922], {
             RGBColor[
             0.6721158717129053, 0.743781294342723, 0.9679538868785659]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[500, 0.0860569014282922], {
             RGBColor[
             0.7252391219909153, 0.7852815812115603, 0.9732487160012789]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1dOWGAgQBNBMbNu2bds2J+bEtm3btm3btu01sjdnH271F1R1ssCg6p0C
ggUL9l38vMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEIS
kZgkJCUZyUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpR
mCIUpRjFKUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGY
JjSlGYE0pwUtaUVr2tCWdrSnAx3pRBCd6UJXutGdHvSkF73pQ1/60Z8BDGQQ
gxnCUIYxnBGMZBSjGcNYxjGeCUxkEpOZwlSmMZ0ZzGQWs5nDXOYxnwUsZBGL
WcJSlrGcFaxkFatZw1rWsZ4NbGQTm9nCVraxnR3sZBe72cNe9rGfAxzkEIc5
wlGOcZwTnOQUpznDWc5xngtc5BKXucJVrnGdG9zkFre5w13ucZ8HPOQRj3nC
U57xnBe85BWvecNb3vGeD3zkE5/5wle+8Z1f+JXf+J0/+JO/+Jt/+Jcf/Cx/
AMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEISkZgkJCUZ
yUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpRmCIUpRjF
KUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGYJjSlGYE0
pwUtaUVr2tCWdrSnAx35Od5BdKYLXelGd3rQk170pg996Ud/BjCQQQxmCEMZ
xnBGMJJRjGYMYxnHeCYwkUlMZgpTmcZ0ZjCTWcxmDnOZx3wWsJBFLGYJS1nG
clawklWsZg1rWcd6NrCRTWxmC1vZxnZ2sJNd7GYPe9nHfg5wkEMc5ghHOcZx
TnCSU5zmDGc5x3kucJFLXOYKV7nGdW5wk1vc5g53ucd9HvCQRzzmCU95xnNe
8JJXvOYNb3nHez7wkU985gtf+Rbw/z//Dz189+A=
          "], {Null, CompressedData["
1:eJxF3Al0ldW5gOF/21YsVqt2QFCqdkClVEWUGRVRJmWoghGKIgREKWUqk4DM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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[13, 59] -> 
             RGBColor[
              0.5710396459203946, 0.662634735457889, 0.9593734791954514], 
             UndirectedEdge[210, 309] -> 
             RGBColor[
              0.23463499011461536`, 0.36394662970103786`, 0.9366734876244414],
              UndirectedEdge[88, 427] -> 
             RGBColor[
              0.21816644071600988`, 0.3466371401167634, 0.9357356280992264], 
             UndirectedEdge[293, 483] -> 
             RGBColor[
              0.8686864922225178, 0.39450469054086185`, 0.22397142092169176`],
              UndirectedEdge[46, 150] -> 
             RGBColor[
              0.31231365721932186`, 0.44279963411631207`, 0.9411994089142401],
              UndirectedEdge[400, 444] -> 
             RGBColor[
              0.8285562969045, 0.22050178822288907`, 0.17497884820646079`], 
             UndirectedEdge[98, 105] -> 
             RGBColor[
              0.22603623939872042`, 0.3549087975063481, 0.9361838014918828], 
             UndirectedEdge[128, 439] -> 
             RGBColor[
              0.25567022753416335`, 0.38605599794006673`, 0.9378714132766395],
              UndirectedEdge[23, 62] -> 
             RGBColor[
              0.7605455492253483, 0.8073117539135573, 0.693976057126175], 
             UndirectedEdge[201, 236] -> 
             RGBColor[
              0.4367458916891245, 0.5493200603220583, 0.9499190884728695], 
             UndirectedEdge[40, 477] -> 
             RGBColor[
              0.2326598513128163, 0.36187063358931404`, 0.936561006391635], 
             UndirectedEdge[455, 482] -> 
             RGBColor[
              0.8569637840361095, 0.40674414496490774`, 0.4404088754929284], 
             UndirectedEdge[60, 131] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[179, 222] -> 
             RGBColor[
              0.26369928279436383`, 0.3944950440900435, 0.9383286560957851], 
             UndirectedEdge[111, 175] -> 
             RGBColor[
              0.9896715252435591, 0.9899969245055872, 0.8208330861574638], 
             UndirectedEdge[51, 110] -> 
             RGBColor[
              0.8761442527887697, 0.4191299801762435, 0.29813730878806594`], 
             UndirectedEdge[84, 261] -> 
             RGBColor[
              0.802578407870131, 0.8465597844769306, 0.9807289118084384], 
             UndirectedEdge[156, 479] -> 
             RGBColor[
              0.23031326123812593`, 0.35940421863841043`, 0.9364273715583502],
              UndirectedEdge[158, 437] -> 
             RGBColor[
              0.21289783238492682`, 0.3410994987117332, 0.9354355886489787], 
             UndirectedEdge[103, 355] -> 
             RGBColor[
              0.9026605789160858, 0.621832678187201, 0.34518239114594756`], 
             UndirectedEdge[13, 228] -> 
             RGBColor[
              0.5560506747276076, 0.6504660133981275, 0.9581934924767446], 
             UndirectedEdge[59, 409] -> 
             RGBColor[
              0.5719438498096561, 0.6633688089091125, 0.9594446614378219], 
             UndirectedEdge[243, 430] -> 
             RGBColor[
              0.26568330364733933`, 0.3965803758007084, 0.9384416431482663], 
             UndirectedEdge[333, 441] -> 
             RGBColor[
              0.39299597634942995`, 0.5148150949869406, 0.9462623339936568], 
             UndirectedEdge[179, 385] -> 
             RGBColor[
              0.2302154045308226, 0.35930136503456106`, 0.9364217987636353], 
             UndirectedEdge[81, 447] -> 
             RGBColor[
              0.4381615348855533, 0.5539352317039529, 0.9491402434452434], 
             UndirectedEdge[69, 404] -> 
             RGBColor[
              0.8720195914369621, 0.405748016840095, 0.23691988196683633`], 
             UndirectedEdge[113, 380] -> 
             RGBColor[
              0.23563903739034964`, 0.36500194704810873`, 0.9367306666314397],
              UndirectedEdge[85, 489] -> 
             RGBColor[
              0.2242348495004033, 0.3530154225085005, 0.9360812150020913], 
             UndirectedEdge[277, 498] -> 
             RGBColor[
              0.8718851812720558, 0.40529461979285863`, 0.23639772385740537`],
              UndirectedEdge[18, 160] -> 
             RGBColor[
              0.6045200328244643, 0.6881026838156832, 0.9631803229645852], 
             UndirectedEdge[355, 431] -> 
             RGBColor[
              0.9023446175940999, 0.6211568688680633, 0.310791951135041], 
             UndirectedEdge[357, 492] -> 
             RGBColor[
              0.2075698466489869, 0.3354994478894535, 0.9351321677433655], 
             UndirectedEdge[165, 386] -> 
             RGBColor[
              0.8441187916914372, 0.8785414277732838, 0.9849939979769122], 
             UndirectedEdge[218, 274] -> 
             RGBColor[
              0.6118775615619095, 0.6942958574577106, 0.963609119130596], 
             UndirectedEdge[116, 441] -> 
             RGBColor[
              0.5263358260398556, 0.6233876711354238, 0.9569331242963761], 
             UndirectedEdge[258, 435] -> 
             RGBColor[
              0.7217057517642607, 0.7765964094692765, 0.7664579098908495], 
             UndirectedEdge[112, 445] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[114, 179] -> 
             RGBColor[
              0.22995443980472458`, 0.3590270745613128, 0.9364069372085467], 
             UndirectedEdge[155, 467] -> 
             RGBColor[
              0.2375425676300431, 0.36700267802081454`, 0.9368390698625695], 
             UndirectedEdge[243, 421] -> 
             RGBColor[
              0.22859686998161965`, 0.35760018260233123`, 0.9363296256154655],
              UndirectedEdge[172, 289] -> 
             RGBColor[
              0.345767570655903, 0.47390822374389807`, 0.9432529817453046], 
             UndirectedEdge[381, 468] -> 
             RGBColor[
              0.29385090543136283`, 0.42067047076940983`, 0.9402477083379865],
              UndirectedEdge[17, 277] -> 
             RGBColor[
              0.9842391011275806, 0.968356266821895, 0.6191150211106053], 
             UndirectedEdge[279, 477] -> 
             RGBColor[
              0.28214014924959957`, 0.4138775639529604, 0.9393788361595936], 
             UndirectedEdge[4, 405] -> 
             RGBColor[
              0.19037905734984562`, 0.31743083837706143`, 0.9341531777242731],
              UndirectedEdge[36, 379] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[278, 401] -> 
             RGBColor[
              0.19472994713122652`, 0.3220038993996379, 0.9344009544607581], 
             UndirectedEdge[152, 399] -> 
             RGBColor[
              0.2527153156861724, 0.38295019823559606`, 0.9377031354182968], 
             UndirectedEdge[173, 406] -> 
             RGBColor[
              0.8761600890568056, 0.41916385235227993`, 0.29986098883365586`],
              UndirectedEdge[239, 332] -> 
             RGBColor[
              0.23367112063916273`, 0.36293354176948267`, 0.9366185966837315],
              UndirectedEdge[116, 361] -> 
             RGBColor[
              0.5470425558222825, 0.6413227997224619, 0.9582525388078701], 
             UndirectedEdge[288, 498] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[16, 386] -> 
             RGBColor[
              0.7452144755917458, 0.8010765223541869, 0.9751892409747631], 
             UndirectedEdge[216, 464] -> 
             RGBColor[
              0.27480140758027954`, 0.40616408115540853`, 0.9389609056782213],
              UndirectedEdge[379, 400] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[22, 24] -> 
             RGBColor[
              0.1988170752865331, 0.32629973022975733`, 0.9346337103628386], 
             UndirectedEdge[231, 355] -> 
             RGBColor[
              0.8304768118928137, 0.23526370799810264`, 0.17681793552818148`],
              UndirectedEdge[434, 495] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[75, 323] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[165, 288] -> 
             RGBColor[
              0.8264596817975027, 0.3824305319946304, 0.43782978303013764`], 
             UndirectedEdge[90, 229] -> 
             RGBColor[
              0.5154543184856579, 0.616939902632804, 0.9551545828836118], 
             UndirectedEdge[267, 424] -> 
             RGBColor[
              0.32359321236073335`, 0.4484918511970504, 0.9420674318834557], 
             UndirectedEdge[258, 403] -> 
             RGBColor[
              0.8761965593307338, 0.419241858580502, 0.3038305530822916], 
             UndirectedEdge[274, 305] -> 
             RGBColor[
              0.6728698608332448, 0.742281504128438, 0.9695985669953169], 
             UndirectedEdge[399, 478] -> 
             RGBColor[
              0.41018828225715515`, 0.5275118706354188, 0.9478509075255593], 
             UndirectedEdge[359, 463] -> 
             RGBColor[
              0.831998657058118, 0.24386491747293382`, 0.17815401051060936`], 
             UndirectedEdge[302, 422] -> 
             RGBColor[
              0.3930257524734591, 0.5128887624932172, 0.9465625995891717], 
             UndirectedEdge[21, 335] -> 
             RGBColor[
              0.5685137758712531, 0.6540937496535268, 0.9620892181770329], 
             UndirectedEdge[266, 445] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[200, 452] -> 
             RGBColor[
              0.4981470175789616, 0.6018428315420548, 0.9540811637122809], 
             UndirectedEdge[112, 471] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[481, 496] -> 
             RGBColor[
              0.2504961406533446, 0.38061770457227034`, 0.9375767566831525], 
             UndirectedEdge[6, 422] -> 
             RGBColor[
              0.3160911696209566, 0.44719850519152415`, 0.9413988444168244], 
             UndirectedEdge[137, 424] -> 
             RGBColor[
              0.2813766900403703, 0.41192602142725965`, 0.939377432411807], 
             UndirectedEdge[89, 482] -> 
             RGBColor[
              0.8975224519572722, 0.9211097616510341, 0.9895920627069863], 
             UndirectedEdge[142, 254] -> 
             RGBColor[
              0.28886221876631657`, 0.41799448677368717`, 0.9398696033843243],
              UndirectedEdge[178, 321] -> 
             RGBColor[
              0.8637848357389819, 0.37797025225822195`, 0.20492941108331195`],
              UndirectedEdge[151, 456] -> 
             RGBColor[
              0.268244426651874, 0.3992722784630517, 0.9385874953145326], 
             UndirectedEdge[346, 431] -> 
             RGBColor[
              0.9882192232946517, 0.971338985864578, 0.45837897693901886`], 
             UndirectedEdge[65, 297] -> 
             RGBColor[
              0.22326792573678073`, 0.35199912432642566`, 0.9360261501241884],
              UndirectedEdge[79, 253] -> 
             RGBColor[
              0.8742585681452911, 0.4192055500614041, 0.39156282211394233`], 
             UndirectedEdge[376, 475] -> 
             RGBColor[
              0.9641436958902179, 0.97247391328753, 0.9319168018252305], 
             UndirectedEdge[209, 259] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[464, 496] -> 
             RGBColor[
              0.24443386678924475`, 0.3742458703707382, 0.9372315191549225], 
             UndirectedEdge[101, 103] -> 
             RGBColor[
              0.7423876612860338, 0.7937870676334219, 0.792267547607473], 
             UndirectedEdge[69, 348] -> 
             RGBColor[
              0.9720780588899567, 0.9174748776315893, 0.3460289607139636], 
             UndirectedEdge[116, 277] -> 
             RGBColor[
              0.8327236905210305, 0.8505154585848247, 0.6749691997262832], 
             UndirectedEdge[171, 471] -> 
             RGBColor[
              0.8633448747725185, 0.37637450305087206`, 0.2038017602771198], 
             UndirectedEdge[133, 429] -> 
             RGBColor[
              0.24801000575022464`, 0.37800461915903416`, 0.9374351749783268],
              UndirectedEdge[37, 203] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[299, 399] -> 
             RGBColor[
              0.38120820226977115`, 0.5039845361639349, 0.9455694894714217], 
             UndirectedEdge[311, 429] -> 
             RGBColor[
              0.23078867443938234`, 0.35990390805586886`, 0.936454445636851], 
             UndirectedEdge[327, 446] -> 
             RGBColor[
              0.19902638409040874`, 0.32651972705357524`, 0.9346456301895747],
              UndirectedEdge[15, 249] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[50, 242] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[163, 355] -> 
             RGBColor[
              0.8304768118928137, 0.23526370799810264`, 0.17681793552818148`],
              UndirectedEdge[192, 435] -> 
             RGBColor[
              0.6598277871485738, 0.73152786434866, 0.9686707009780946], 
             UndirectedEdge[31, 191] -> 
             RGBColor[
              0.23217546467365527`, 0.361361512519669, 0.9365334212891205], 
             UndirectedEdge[385, 415] -> 
             RGBColor[
              0.18775866061236085`, 0.31467663526321576`, 0.9340039500066029],
              UndirectedEdge[207, 257] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[359, 408] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[183, 202] -> 
             RGBColor[
              0.23464668265559618`, 0.36395891930295865`, 0.9366741534973526],
              UndirectedEdge[170, 223] -> 
             RGBColor[
              0.26091102585046255`, 0.3915644092563023, 0.9381698689876865], 
             UndirectedEdge[40, 430] -> 
             RGBColor[
              0.24076319340362162`, 0.37038775990831363`, 0.9370224797358859],
              UndirectedEdge[69, 444] -> 
             RGBColor[
              0.894494185245962, 0.578497593285873, 0.2584415783797579], 
             UndirectedEdge[215, 417] -> 
             RGBColor[
              0.23113355417435436`, 0.36026639852396264`, 0.9364740860275538],
              UndirectedEdge[423, 429] -> 
             RGBColor[
              0.207561162916413, 0.3354903207359379, 0.9351316732176418], 
             UndirectedEdge[5, 83] -> RGBColor[0.817319, 0.134127, 0.164218], 
             UndirectedEdge[311, 366] -> 
             RGBColor[
              0.21056004147512417`, 0.3386423322410259, 0.9353024549151172], 
             UndirectedEdge[133, 366] -> 
             RGBColor[
              0.22778137278596647`, 0.35674304334419116`, 0.9362831842565931],
              UndirectedEdge[76, 359] -> 
             RGBColor[
              0.8763277317102309, 0.4195224230366844, 0.31810785708846784`], 
             UndirectedEdge[172, 218] -> 
             RGBColor[
              0.5588854033775118, 0.6492281120932448, 0.9600027877622141], 
             UndirectedEdge[177, 484] -> 
             RGBColor[
              0.2033510637646819, 0.3310652395917648, 0.9348919142992342], 
             UndirectedEdge[45, 328] -> 
             RGBColor[
              0.37591074520931583`, 0.4962310227311757, 0.9454667495001579], 
             UndirectedEdge[115, 144] -> 
             RGBColor[
              0.2435638403098072, 0.37333141737798453`, 0.9371819724340074], 
             UndirectedEdge[63, 72] -> 
             RGBColor[
              0.3088117371325335, 0.4410013587250076, 0.940931053493443], 
             UndirectedEdge[248, 387] -> 
             RGBColor[
              0.2032853235143931, 0.33099614242053865`, 0.9348881704892343], 
             UndirectedEdge[34, 44] -> 
             RGBColor[
              0.5037551933062931, 0.6031416247429248, 0.9557644930809137], 
             UndirectedEdge[279, 285] -> 
             RGBColor[
              0.31918224078287427`, 0.4504503802207983, 0.9415747678474624], 
             UndirectedEdge[13, 77] -> 
             RGBColor[
              0.7393999520548098, 0.7956405917835261, 0.9722782472010072], 
             UndirectedEdge[53, 445] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[91, 298] -> 
             RGBColor[
              0.8219843924164008, 0.8203269587905632, 0.6420658778876114], 
             UndirectedEdge[6, 451] -> 
             RGBColor[
              0.31296091107937973`, 0.44390840499447215`, 0.9412205808236842],
              UndirectedEdge[87, 256] -> 
             RGBColor[
              0.8597722407139262, 0.891023063122262, 0.9864870379186761], 
             UndirectedEdge[153, 172] -> 
             RGBColor[
              0.38789541628795154`, 0.5103972462232906, 0.9459373308167875], 
             UndirectedEdge[72, 438] -> 
             RGBColor[
              0.29983207958869507`, 0.43156316930326144`, 0.9404196752805343],
              UndirectedEdge[207, 440] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[19, 228] -> 
             RGBColor[
              0.42807121290671124`, 0.5396284944077405, 0.9494773208917324], 
             UndirectedEdge[8, 63] -> 
             RGBColor[
              0.27895516343135685`, 0.4105299419182229, 0.939197455929009], 
             UndirectedEdge[72, 128] -> 
             RGBColor[
              0.28177127381369815`, 0.4125801173125145, 0.9393911391102159], 
             UndirectedEdge[229, 485] -> 
             RGBColor[
              0.493481350800354, 0.5991012575949606, 0.9534247903777919], 
             UndirectedEdge[32, 407] -> 
             RGBColor[
              0.5239474714560204, 0.6211561334022514, 0.9568498726559509], 
             UndirectedEdge[475, 478] -> 
             RGBColor[
              0.7294989786631181, 0.787504214333214, 0.9688616962701988], 
             UndirectedEdge[194, 412] -> 
             RGBColor[
              0.21879008438791836`, 0.3472926291572319, 0.9357711436837434], 
             UndirectedEdge[370, 390] -> 
             RGBColor[
              0.48068060887291364`, 0.5879170041207702, 0.9526359105777598], 
             UndirectedEdge[231, 233] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[114, 385] -> 
             RGBColor[
              0.18998822410005822`, 0.3170200478512756, 0.9341309203488837], 
             UndirectedEdge[271, 442] -> 
             RGBColor[
              0.37583021451417103`, 0.49956100808681825`, 0.945182678962928], 
             UndirectedEdge[206, 254] -> 
             RGBColor[
              0.21121110658430017`, 0.33932664295068204`, 0.9353395321099203],
              UndirectedEdge[262, 455] -> 
             RGBColor[
              0.862162982525146, 0.410621698685125, 0.4316079886191312], 
             UndirectedEdge[7, 341] -> 
             RGBColor[
              0.8626928878488475, 0.3737895921602789, 0.20327715629423396`], 
             UndirectedEdge[187, 328] -> 
             RGBColor[
              0.42211567678941486`, 0.5393927026931269, 0.9482958688478269], 
             UndirectedEdge[44, 56] -> 
             RGBColor[
              0.8469959064349548, 0.8780021626885659, 0.8144131900742924], 
             UndirectedEdge[142, 388] -> 
             RGBColor[
              0.6324778710852315, 0.7059774833485709, 0.9677848279671616], 
             UndirectedEdge[282, 419] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[7, 244] -> 
             RGBColor[
              0.9653265435241076, 0.893954535776943, 0.32368523328489207`], 
             UndirectedEdge[107, 470] -> 
             RGBColor[
              0.2829505871294402, 0.41374407449152867`, 0.9394610664624095], 
             UndirectedEdge[10, 383] -> 
             RGBColor[
              0.5131465195328626, 0.6140173050277837, 0.9552627525247963], 
             UndirectedEdge[249, 419] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[191, 271] -> 
             RGBColor[
              0.2668826471852404, 0.3978409619018147, 0.9385099439884801], 
             UndirectedEdge[297, 490] -> 
             RGBColor[
              0.295576036933824, 0.4249379314256113, 0.9402560903469162], 
             UndirectedEdge[32, 176] -> 
             RGBColor[
              0.6217123396719191, 0.698046546413098, 0.9664572955572988], 
             UndirectedEdge[353, 487] -> 
             RGBColor[
              0.212512158872194, 0.340694131396738, 0.9354136251129814], 
             UndirectedEdge[281, 324] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[19, 59] -> 
             RGBColor[
              0.44306018409949816`, 0.5517972164675021, 0.9506573076104392], 
             UndirectedEdge[197, 411] -> 
             RGBColor[
              0.5628841788365053, 0.6538599474387119, 0.9597631075252654], 
             UndirectedEdge[163, 343] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[12, 396] -> 
             RGBColor[
              0.25133562707487567`, 0.38150005802781284`, 0.9376245641929499],
              UndirectedEdge[51, 397] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[448, 482] -> 
             RGBColor[
              0.8802408291329131, 0.907329864708045, 0.9879437260945121], 
             UndirectedEdge[183, 285] -> 
             RGBColor[
              0.2954522956610519, 0.4255087033323427, 0.9402233825780824], 
             UndirectedEdge[155, 365] -> 
             RGBColor[
              0.2717806724248775, 0.40298909698141017`, 0.9387888792798984], 
             UndirectedEdge[122, 217] -> 
             RGBColor[
              0.19845501151425832`, 0.32591917824892747`, 0.9346130913666328],
              UndirectedEdge[249, 269] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[101, 331] -> 
             RGBColor[
              0.6589364835874938, 0.7312180127479719, 0.9682159470470796], 
             UndirectedEdge[246, 458] -> 
             RGBColor[
              0.45506828709517866`, 0.5684604354315133, 0.9502502894486882], 
             UndirectedEdge[35, 437] -> 
             RGBColor[
              0.20415760851311143`, 0.3319129692602549, 0.9349378458294813], 
             UndirectedEdge[354, 473] -> 
             RGBColor[
              0.7341139041926492, 0.7920013522023865, 0.9744208723817095], 
             UndirectedEdge[230, 484] -> 
             RGBColor[
              0.24969102716362834`, 0.37977147924743493`, 0.9375309066609718],
              UndirectedEdge[108, 190] -> 
             RGBColor[
              0.3280007224836446, 0.45851947284484174`, 0.9421208938903753], 
             UndirectedEdge[55, 136] -> 
             RGBColor[
              0.8590242998049419, 0.4221052615756549, 0.20287901902910677`], 
             UndirectedEdge[59, 279] -> 
             RGBColor[
              0.45332288362562734`, 0.5625839643621962, 0.9512417531661489], 
             UndirectedEdge[24, 170] -> 
             RGBColor[
              0.2116033299838412, 0.33973889461199946`, 0.9353618686522815], 
             UndirectedEdge[184, 388] -> 
             RGBColor[
              0.900316789777843, 0.736870657178221, 0.6055744049490553], 
             UndirectedEdge[173, 242] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[4, 345] -> 
             RGBColor[
              0.21015441717533256`, 0.3382159953838789, 0.9352793552113114], 
             UndirectedEdge[59, 256] -> 
             RGBColor[
              0.7339103134596671, 0.7918118736537649, 0.9744326923070242], 
             UndirectedEdge[232, 480] -> 
             RGBColor[
              0.5877523494350976, 0.6753795657900517, 0.9612520559159965], 
             UndirectedEdge[3, 437] -> 
             RGBColor[
              0.19556301830914924`, 0.3228795100273981, 0.9344483966319225], 
             UndirectedEdge[199, 448] -> 
             RGBColor[
              0.9076107391885334, 0.9266123770081562, 0.8910134005812398], 
             UndirectedEdge[151, 226] -> 
             RGBColor[
              0.24965370060264616`, 0.379732246665202, 0.9375287809685435], 
             UndirectedEdge[241, 442] -> 
             RGBColor[
              0.3936637903637048, 0.5153935219207971, 0.9463048865121216], 
             UndirectedEdge[303, 400] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[42, 378] -> 
             RGBColor[
              0.28588285582609785`, 0.41781138586616284`, 0.939591977762287], 
             UndirectedEdge[15, 499] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[341, 374] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[312, 334] -> 
             RGBColor[
              0.230552492853364, 0.3596556662341861, 0.9364409954449265], 
             UndirectedEdge[7, 482] -> 
             RGBColor[
              0.9448470078274355, 0.90254660568778, 0.6370930476807435], 
             UndirectedEdge[219, 403] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[50, 449] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[318, 430] -> 
             RGBColor[
              0.26870184465051744`, 0.3997530537816021, 0.9386135445928661], 
             UndirectedEdge[242, 449] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[356, 365] -> 
             RGBColor[
              0.3958521141784222, 0.5154427777416128, 0.9467614846116235], 
             UndirectedEdge[154, 219] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[69, 275] -> 
             RGBColor[
              0.9574349696021127, 0.8614225983065917, 0.32381674285302947`], 
             UndirectedEdge[173, 310] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[351, 460] -> 
             RGBColor[
              0.6420423630429408, 0.7175237512005181, 0.9668616406644909], 
             UndirectedEdge[97, 207] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[122, 212] -> 
             RGBColor[
              0.1999697851673105, 0.32751130140048207`, 0.9346993554852674], 
             UndirectedEdge[45, 224] -> 
             RGBColor[
              0.2850155679972537, 0.41689981136882326`, 0.9395425870034717], 
             UndirectedEdge[144, 215] -> 
             RGBColor[
              0.23058979905714602`, 0.35969487741971096`, 0.9364431199780423],
              UndirectedEdge[22, 214] -> 
             RGBColor[
              0.2036724125219917, 0.3314029975103854, 0.9349102146355702], 
             UndirectedEdge[142, 150] -> 
             RGBColor[
              0.3397907487213136, 0.46873140098796173`, 0.9428721439367287], 
             UndirectedEdge[149, 419] -> 
             RGBColor[
              0.8427485102135918, 0.3295893587840956, 0.1885693276990594], 
             UndirectedEdge[11, 418] -> 
             RGBColor[
              0.9680252917800689, 0.9114065680096394, 0.5671089180690637], 
             UndirectedEdge[189, 346] -> 
             RGBColor[
              0.758201423428222, 0.7931848261137132, 0.6724145577439462], 
             UndirectedEdge[185, 224] -> 
             RGBColor[
              0.30794222932777976`, 0.4398990236404763, 0.9408884355550042], 
             UndirectedEdge[17, 386] -> 
             RGBColor[
              0.91547859821468, 0.9335639669139454, 0.921203758756203], 
             UndirectedEdge[194, 476] -> 
             RGBColor[
              0.20408939664104067`, 0.33184127425782606`, 0.9349339612642773],
              UndirectedEdge[258, 471] -> 
             RGBColor[
              0.8761965593307338, 0.419241858580502, 0.3038305530822916], 
             UndirectedEdge[203, 397] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[126, 173] -> 
             RGBColor[
              0.8563654629268306, 0.3487034608338446, 0.19818596167822738`], 
             UndirectedEdge[30, 366] -> 
             RGBColor[
              0.1867597729131777, 0.31362674095823617`, 0.9339470648298565], 
             UndirectedEdge[95, 368] -> 
             RGBColor[
              0.19197561743155647`, 0.3191089242506953, 0.9342440994590275], 
             UndirectedEdge[15, 242] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[150, 392] -> 
             RGBColor[
              0.39049019037477983`, 0.5126447091201637, 0.9461026675271316], 
             UndirectedEdge[179, 296] -> 
             RGBColor[
              0.23166652830629497`, 0.3608265881291439, 0.9365044381159032], 
             UndirectedEdge[3, 123] -> 
             RGBColor[
              0.20402053268474474`, 0.331768893873532, 0.9349300395638414], 
             UndirectedEdge[37, 257] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[17, 178] -> 
             RGBColor[
              0.9720885828279697, 0.9273697155199401, 0.5719125519494651], 
             UndirectedEdge[68, 367] -> 
             RGBColor[
              0.2321744218168602, 0.3613604164110565, 0.9365333618999687], 
             UndirectedEdge[1, 363] -> 
             RGBColor[
              0.23069669163243806`, 0.3598072282937236, 0.9364492073520718], 
             UndirectedEdge[227, 329] -> 
             RGBColor[
              0.21529055299948083`, 0.3436143997848786, 0.9355718505482646], 
             UndirectedEdge[121, 420] -> 
             RGBColor[
              0.2550040005711073, 0.3853557511606656, 0.9378334726366879], 
             UndirectedEdge[82, 149] -> 
             RGBColor[
              0.8696222340143458, 0.4946976853386944, 0.21268036640365176`], 
             UndirectedEdge[129, 355] -> 
             RGBColor[
              0.8246751523265887, 0.5626184933768341, 0.4602642940296072], 
             UndirectedEdge[87, 388] -> 
             RGBColor[
              0.8893025910926451, 0.9145697629342451, 0.9893036690998533], 
             UndirectedEdge[91, 228] -> 
             RGBColor[
              0.7683903505092387, 0.7773900081716217, 0.6374549222113163], 
             UndirectedEdge[12, 161] -> 
             RGBColor[
              0.2878546124844855, 0.4177612959984998, 0.9397819826492559], 
             UndirectedEdge[64, 115] -> 
             RGBColor[
              0.21756212088863558`, 0.346001961662103, 0.9357012129790685], 
             UndirectedEdge[56, 342] -> 
             RGBColor[
              0.9717076565997078, 0.9127794890046514, 0.46789915194522813`], 
             UndirectedEdge[378, 416] -> 
             RGBColor[
              0.3046149956866814, 0.43742728847784595`, 0.9406614096646049], 
             UndirectedEdge[119, 363] -> 
             RGBColor[
              0.19847969710316485`, 0.325945124368025, 0.934614497174402], 
             UndirectedEdge[391, 455] -> 
             RGBColor[
              0.8623939674573535, 0.3726044724173211, 0.20303663793067456`], 
             UndirectedEdge[249, 282] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[226, 429] -> 
             RGBColor[
              0.224316855525465, 0.35310161604032264`, 0.9360858851239015], 
             UndirectedEdge[181, 189] -> 
             RGBColor[
              0.4605412675252241, 0.5711446538797107, 0.9511671576944246], 
             UndirectedEdge[160, 167] -> 
             RGBColor[
              0.4561605474821908, 0.5693707081013473, 0.9503297757503926], 
             UndirectedEdge[16, 277] -> 
             RGBColor[
              0.8139749785046464, 0.8358688222621367, 0.6731005033291653], 
             UndirectedEdge[295, 341] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[69, 129] -> 
             RGBColor[
              0.870930679966885, 0.8808856413310856, 0.6795404574101209], 
             UndirectedEdge[352, 368] -> 
             RGBColor[
              0.18920022769262135`, 0.31619181366520155`, 0.9340860451192163],
              UndirectedEdge[194, 297] -> 
             RGBColor[
              0.22957360290378961`, 0.3586267908319759, 0.9363852491104362], 
             UndirectedEdge[188, 228] -> 
             RGBColor[
              0.4764305577406883, 0.5838436086796381, 0.9524734711857346], 
             UndirectedEdge[273, 430] -> 
             RGBColor[
              0.2453937716602786, 0.3752547912516788, 0.937286184317276], 
             UndirectedEdge[200, 468] -> 
             RGBColor[
              0.48541856175705617`, 0.5908180828599114, 0.9532701177626406], 
             UndirectedEdge[93, 172] -> 
             RGBColor[
              0.3758866189646938, 0.4999958295615881, 0.9451721408703121], 
             UndirectedEdge[61, 341] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[121, 442] -> 
             RGBColor[
              0.36944795676254, 0.4928528505313406, 0.9448192188256768], 
             UndirectedEdge[287, 336] -> 
             RGBColor[
              0.8241908545687948, 0.38062143074813315`, 0.4376133802636575], 
             UndirectedEdge[403, 497] -> 
             RGBColor[
              0.8604026869949277, 0.3647097089386806, 0.20143440692924686`], 
             UndirectedEdge[17, 407] -> 
             RGBColor[
              0.8378626122664915, 0.8727397256965316, 0.9135181542326689], 
             UndirectedEdge[135, 470] -> 
             RGBColor[
              0.21501465509276277`, 0.3433244135919803, 0.9355561385706315], 
             UndirectedEdge[322, 471] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[24, 52] -> 
             RGBColor[
              0.19493298804641856`, 0.32221730827504236`, 0.9344125173405062],
              UndirectedEdge[163, 440] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[274, 432] -> 
             RGBColor[
              0.627662215693468, 0.7066269492330988, 0.9651823859384503], 
             UndirectedEdge[89, 261] -> 
             RGBColor[
              0.8925985240592591, 0.917197850416106, 0.989618038128523], 
             UndirectedEdge[255, 312] -> 
             RGBColor[
              0.25276894068346034`, 0.3830065615077669, 0.9377061892825613], 
             UndirectedEdge[370, 422] -> 
             RGBColor[
              0.350546806463606, 0.47704224603396517`, 0.9435943271285148], 
             UndirectedEdge[43, 90] -> 
             RGBColor[
              0.4999309487768256, 0.6034943400182612, 0.9541654474925418], 
             UndirectedEdge[373, 449] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[49, 457] -> 
             RGBColor[
              0.8638009847389825, 0.3780247266271895, 0.20499214689883155`], 
             UndirectedEdge[234, 449] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[245, 299] -> 
             RGBColor[
              0.4708591211784622, 0.5813036723911794, 0.9514869013144127], 
             UndirectedEdge[398, 464] -> 
             RGBColor[
              0.288464885266985, 0.4205252625186573, 0.9397390205191753], 
             UndirectedEdge[245, 262] -> 
             RGBColor[
              0.717395187444922, 0.7773610525896517, 0.9594129365612236], 
             UndirectedEdge[288, 321] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[433, 465] -> 
             RGBColor[
              0.18295181335348598`, 0.3096243340224193, 0.9337302071663033], 
             UndirectedEdge[330, 367] -> 
             RGBColor[
              0.24111934498520485`, 0.3707620978018721, 0.937042762041578], 
             UndirectedEdge[106, 156] -> 
             RGBColor[
              0.2245611665730593, 0.35335840244155936`, 0.9360997982766361], 
             UndirectedEdge[85, 239] -> 
             RGBColor[
              0.23505374481506194`, 0.3643867674417887, 0.9366973350851397], 
             UndirectedEdge[336, 388] -> 
             RGBColor[
              0.8529860941236527, 0.4035819731432213, 0.44035989591821356`], 
             UndirectedEdge[69, 355] -> 
             RGBColor[
              0.8983352152225895, 0.6080214328363002, 0.2621197530231993], 
             UndirectedEdge[102, 383] -> 
             RGBColor[
              0.4499159059433277, 0.5554178997074893, 0.951374070302039], 
             UndirectedEdge[296, 327] -> 
             RGBColor[
              0.19648958029374552`, 0.3238533854206317, 0.9345011629662197], 
             UndirectedEdge[61, 288] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[141, 472] -> 
             RGBColor[
              0.2491195605244581, 0.3791708315765894, 0.9374983624812803], 
             UndirectedEdge[43, 485] -> 
             RGBColor[
              0.4779579810915217, 0.5856556949804177, 0.9524356549867219], 
             UndirectedEdge[9, 358] -> 
             RGBColor[
              0.3137918107660683, 0.4401298504157032, 0.94143822754991], 
             UndirectedEdge[70, 359] -> 
             RGBColor[
              0.8734050425786691, 0.4188525953049994, 0.40570794960622847`], 
             UndirectedEdge[466, 470] -> 
             RGBColor[
              0.2470848114448652, 0.37703218128339433`, 0.9373824865313389], 
             UndirectedEdge[41, 356] -> 
             RGBColor[
              0.5474004384833568, 0.6434433619263427, 0.9575125141927376], 
             UndirectedEdge[79, 436] -> 
             RGBColor[
              0.8681126065678694, 0.4150589185545728, 0.4215368270252724], 
             UndirectedEdge[33, 175] -> 
             RGBColor[
              0.7775942134782825, 0.823051184158842, 0.8471271912321169], 
             UndirectedEdge[176, 448] -> 
             RGBColor[
              0.8540113043416422, 0.8864294488354546, 0.985937554664639], 
             UndirectedEdge[118, 481] -> 
             RGBColor[
              0.2642710788962169, 0.3950960380470579, 0.9383612190378892], 
             UndirectedEdge[326, 346] -> 
             RGBColor[
              0.8725424883879621, 0.4075118710378607, 0.23895123788066785`], 
             UndirectedEdge[63, 435] -> 
             RGBColor[
              0.37424886655935563`, 0.49767971126876503`, 0.9451006495167384],
              UndirectedEdge[194, 350] -> 
             RGBColor[
              0.1999849515613838, 0.32752724224225804`, 0.9347002191889733], 
             UndirectedEdge[275, 486] -> 
             RGBColor[
              0.9637768525866133, 0.8818268394055082, 0.43250180785517167`], 
             UndirectedEdge[407, 478] -> 
             RGBColor[
              0.6025017705556377, 0.6874738908646236, 0.9623310846441953], 
             UndirectedEdge[62, 356] -> 
             RGBColor[
              0.5100962493492036, 0.6131581406526678, 0.9545757917743497], 
             UndirectedEdge[150, 426] -> 
             RGBColor[
              0.27709250902946053`, 0.4057799742189919, 0.9391936166298469], 
             UndirectedEdge[372, 444] -> 
             RGBColor[
              0.8285562969045, 0.22050178822288907`, 0.17497884820646079`], 
             UndirectedEdge[106, 329] -> 
             RGBColor[
              0.18619018249920005`, 0.3130280653190276, 0.9339146274984138], 
             UndirectedEdge[128, 294] -> 
             RGBColor[
              0.23038890902229686`, 0.35948372925592065`, 0.9364316795877479],
              UndirectedEdge[379, 440] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[227, 267] -> 
             RGBColor[
              0.32291920761564974`, 0.44778342947559846`, 0.9420290483103237],
              UndirectedEdge[151, 345] -> 
             RGBColor[
              0.2579701082949577, 0.388473318440524, 0.9380023880835981], 
             UndirectedEdge[275, 418] -> 
             RGBColor[
              0.9409980373735297, 0.8037839099642208, 0.271383839797922], 
             UndirectedEdge[10, 232] -> 
             RGBColor[
              0.5449308949826625, 0.6389979976079412, 0.9583278264694257], 
             UndirectedEdge[5, 431] -> 
             RGBColor[
              0.8760289938084724, 0.418883452871858, 0.28559208007867803`], 
             UndirectedEdge[42, 416] -> 
             RGBColor[
              0.2908008659889437, 0.42290776229911325`, 0.9398747154144922], 
             UndirectedEdge[37, 97] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[441, 450] -> 
             RGBColor[
              0.35399218463513593`, 0.48103197099159145`, 0.9437770468753208],
              UndirectedEdge[5, 259] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[279, 318] -> 
             RGBColor[
              0.28254307525555356`, 0.4143010647322023, 0.9394017821995571], 
             UndirectedEdge[275, 355] -> 
             RGBColor[
              0.8823446787500739, 0.5496431313605049, 0.22311515099154627`], 
             UndirectedEdge[344, 387] -> 
             RGBColor[
              0.22482902569883648`, 0.35363993936600063`, 0.9361150524575872],
              UndirectedEdge[239, 489] -> 
             RGBColor[
              0.24442557524335845`, 0.37423715543029734`, 0.9372310469636506],
              UndirectedEdge[21, 336] -> 
             RGBColor[
              0.8188782126538342, 0.37638527429296664`, 0.43710665573515706`],
              UndirectedEdge[32, 312] -> 
             RGBColor[
              0.3038288820776412, 0.431969188992844, 0.9407862361647759], 
             UndirectedEdge[77, 436] -> 
             RGBColor[
              0.9544907386391261, 0.9655798479084123, 0.9619194881543456], 
             UndirectedEdge[66, 294] -> 
             RGBColor[
              0.23819891010735164`, 0.3676925355789824, 0.9368764475956806], 
             UndirectedEdge[197, 201] -> 
             RGBColor[
              0.49062190566788, 0.5962657278401451, 0.9533417326780644], 
             UndirectedEdge[228, 256] -> 
             RGBColor[
              0.7189213422668801, 0.7796431515940032, 0.9732527055883174], 
             UndirectedEdge[292, 481] -> 
             RGBColor[
              0.24899857925793986`, 0.3790436725948234, 0.9374914727771277], 
             UndirectedEdge[444, 486] -> 
             RGBColor[
              0.898722107235629, 0.5921004206851508, 0.33089828838118596`], 
             UndirectedEdge[154, 244] -> 
             RGBColor[
              0.8706168078338911, 0.40101609835768304`, 0.23147033256236077`],
              UndirectedEdge[288, 386] -> 
             RGBColor[
              0.8260448459967887, 0.38209975318755884`, 0.4377902156211372], 
             UndirectedEdge[273, 285] -> 
             RGBColor[
              0.27433252110274803`, 0.40331048120051716`, 0.9390206426608936],
              UndirectedEdge[190, 487] -> 
             RGBColor[
              0.29152503768335564`, 0.4204245852328503, 0.9400347466411976], 
             UndirectedEdge[83, 343] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[1, 315] -> 
             RGBColor[
              0.23241208756362647`, 0.36161021817978645`, 0.9365468966126522],
              UndirectedEdge[4, 429] -> 
             RGBColor[
              0.2125409132170386, 0.3407243540363004, 0.935415262630382], 
             UndirectedEdge[189, 451] -> 
             RGBColor[
              0.41251169705394175`, 0.5279595148389932, 0.9481647663516817], 
             UndirectedEdge[10, 102] -> 
             RGBColor[
              0.3305278013611218, 0.45687607566175037`, 0.9424222336843717], 
             UndirectedEdge[357, 368] -> 
             RGBColor[
              0.2002969688982753, 0.32785519224637283`, 0.934717988114721], 
             UndirectedEdge[128, 138] -> 
             RGBColor[
              0.22021896748197323`, 0.3487944758855043, 0.9358525164621068], 
             UndirectedEdge[336, 436] -> 
             RGBColor[
              0.8681126065678694, 0.4150589185545728, 0.4215368270252724], 
             UndirectedEdge[196, 454] -> 
             RGBColor[
              0.2775665280001868, 0.40803814535898913`, 0.9391561710226074], 
             UndirectedEdge[25, 164] -> 
             RGBColor[
              0.8191346553029186, 0.8591239335240097, 0.9824771954238392], 
             UndirectedEdge[125, 282] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[9, 286] -> 
             RGBColor[
              0.229182169797179, 0.3582153698186358, 0.9363629575740882], 
             UndirectedEdge[421, 477] -> 
             RGBColor[
              0.23121248497884378`, 0.360349359803983, 0.9364785810201017], 
             UndirectedEdge[105, 484] -> 
             RGBColor[
              0.21851966349026236`, 0.34700839964812025`, 0.9357557436136738],
              UndirectedEdge[299, 475] -> 
             RGBColor[
              0.7005188986757341, 0.7639768798617301, 0.9665802782160611], 
             UndirectedEdge[247, 252] -> 
             RGBColor[
              0.1977339169176573, 0.3251612621078617, 0.9345720260961203], 
             UndirectedEdge[261, 478] -> 
             RGBColor[
              0.7215722356647942, 0.7813528085131327, 0.9739706543969529], 
             UndirectedEdge[104, 303] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[32, 66] -> 
             RGBColor[
              0.3101036799664407, 0.4385643994191369, 0.9411435766218114], 
             UndirectedEdge[213, 454] -> 
             RGBColor[
              0.29958076590078625`, 0.43117650517581874`, 0.9404098493039], 
             UndirectedEdge[129, 331] -> 
             RGBColor[
              0.7939675478085891, 0.839033454471987, 0.98008281403385], 
             UndirectedEdge[245, 475] -> 
             RGBColor[
              0.712599204811678, 0.773784216594479, 0.9675312841667021], 
             UndirectedEdge[90, 148] -> 
             RGBColor[
              0.6360400198232251, 0.7149269386277152, 0.9648173774964799], 
             UndirectedEdge[195, 496] -> 
             RGBColor[
              0.21350786360609533`, 0.34174068020339465`, 0.9354703290245638],
              UndirectedEdge[241, 371] -> 
             RGBColor[
              0.4434440089205643, 0.5559764781177132, 0.9501770359373067], 
             UndirectedEdge[13, 243] -> 
             RGBColor[
              0.39724129654714263`, 0.5111791578470015, 0.9473616067842598], 
             UndirectedEdge[246, 384] -> 
             RGBColor[
              0.5460523779791054, 0.6423489456795577, 0.9574063899317347], 
             UndirectedEdge[22, 268] -> 
             RGBColor[
              0.20099391902560468`, 0.32858773101938626`, 0.934757678393427], 
             UndirectedEdge[69, 306] -> 
             RGBColor[
              0.7222846470752082, 0.7620169546929436, 0.6666017702163287], 
             UndirectedEdge[66, 128] -> 
             RGBColor[
              0.2527669820297753, 0.38300450283855814`, 0.9377060777401315], 
             UndirectedEdge[220, 413] -> 
             RGBColor[
              0.3788148254377005, 0.50253209483257, 0.9453587235974608], 
             UndirectedEdge[319, 492] -> 
             RGBColor[
              0.19102586825047294`, 0.3181106776438004, 0.9341900126481928], 
             UndirectedEdge[61, 186] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[94, 401] -> 
             RGBColor[
              0.1828044456707124, 0.3094694412441735, 0.9337218147947803], 
             UndirectedEdge[429, 488] -> 
             RGBColor[
              0.21473056520455405`, 0.34302581710713376`, 0.9355399600717713],
              UndirectedEdge[11, 431] -> 
             RGBColor[
              0.9904763275659175, 0.9887484103996551, 0.6925501182919337], 
             UndirectedEdge[349, 487] -> 
             RGBColor[
              0.2221770047693607, 0.3508524972212829, 0.9359640237889668], 
             UndirectedEdge[156, 198] -> 
             RGBColor[
              0.23051452206007278`, 0.35961575652294975`, 0.9364388330644213],
              UndirectedEdge[12, 188] -> 
             RGBColor[
              0.3121421207816605, 0.43879791495985154`, 0.9413295612013517], 
             UndirectedEdge[70, 111] -> 
             RGBColor[
              0.985056438314053, 0.9880884674579122, 0.8973170200414953], 
             UndirectedEdge[212, 286] -> 
             RGBColor[
              0.20366843502229037`, 0.33139881690601125`, 0.9349099881228464],
              UndirectedEdge[242, 282] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[70, 175] -> 
             RGBColor[
              0.9901922146655133, 0.990212242962673, 0.8122039149346538], 
             UndirectedEdge[188, 298] -> 
             RGBColor[
              0.5300245996478504, 0.6267805592985796, 0.9570844268620295], 
             UndirectedEdge[286, 367] -> 
             RGBColor[
              0.23641375708701462`, 0.36581622656936946`, 0.9367747857720696],
              UndirectedEdge[9, 492] -> 
             RGBColor[
              0.21887186017874036`, 0.3473785806982704, 0.9357758006940542], 
             UndirectedEdge[37, 343] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[376, 391] -> 
             RGBColor[
              0.9692861559217731, 0.9190249098809967, 0.5809414281870671], 
             UndirectedEdge[230, 490] -> 
             RGBColor[
              0.31848293468104194`, 0.4490145333391401, 0.9415606042859019], 
             UndirectedEdge[346, 355] -> 
             RGBColor[
              0.8988581121735896, 0.6097852870340661, 0.2641511089370308], 
             UndirectedEdge[30, 465] -> 
             RGBColor[
              0.1792054619955512, 0.30568668121283454`, 0.933516857998699], 
             UndirectedEdge[119, 124] -> 
             RGBColor[
              0.20441395972608956`, 0.3321824106387006, 0.9349524446518228], 
             UndirectedEdge[301, 436] -> 
             RGBColor[
              0.8681126065678694, 0.4150589185545728, 0.4215368270252724], 
             UndirectedEdge[39, 108] -> 
             RGBColor[
              0.4086556507016406, 0.5269500959200856, 0.9476548870871122], 
             UndirectedEdge[98, 382] -> 
             RGBColor[
              0.27123479538503203`, 0.4010826361489628, 0.9388065894115436], 
             UndirectedEdge[81, 208] -> 
             RGBColor[
              0.7211325975340719, 0.7754974983423137, 0.7149287914988354], 
             UndirectedEdge[154, 203] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[145, 367] -> 
             RGBColor[
              0.2830394326624652, 0.4148227678377437, 0.9394300490195857], 
             UndirectedEdge[44, 132] -> 
             RGBColor[
              0.6796180336989088, 0.7496420403047319, 0.968701632273641], 
             UndirectedEdge[319, 357] -> 
             RGBColor[
              0.2038097007889821, 0.3315472961835712, 0.9349180329992755], 
             UndirectedEdge[364, 378] -> 
             RGBColor[
              0.29415700671630873`, 0.4265080430632411, 0.9400631784149752], 
             UndirectedEdge[213, 251] -> 
             RGBColor[
              0.3656301307264068, 0.4883851452501694, 0.9446184564254285], 
             UndirectedEdge[73, 136] -> 
             RGBColor[
              0.856961449626315, 0.4062492911560167, 0.20090363136839764`], 
             UndirectedEdge[441, 461] -> 
             RGBColor[
              0.45490348370989475`, 0.5660401492108743, 0.9508690799111832], 
             UndirectedEdge[90, 480] -> 
             RGBColor[
              0.5389584272669072, 0.6365897569125576, 0.9568479281456727], 
             UndirectedEdge[118, 446] -> 
             RGBColor[
              0.21718653605083982`, 0.34560719818412555`, 0.9356798239781839],
              UndirectedEdge[210, 480] -> 
             RGBColor[
              0.364909192113561, 0.48438660176421894`, 0.9448658139891831], 
             UndirectedEdge[95, 492] -> 
             RGBColor[
              0.19924849518226806`, 0.326753179893776, 0.9346582790876721], 
             UndirectedEdge[261, 328] -> 
             RGBColor[
              0.7017283701270802, 0.7652426645136615, 0.9724084726113494], 
             UndirectedEdge[152, 496] -> 
             RGBColor[
              0.2051955967604141, 0.33300396072042604`, 0.9349969577245991], 
             UndirectedEdge[86, 177] -> 
             RGBColor[
              0.204427895244704, 0.3321970577523273, 0.9349532382589922], 
             UndirectedEdge[45, 217] -> 
             RGBColor[
              0.23183546793394733`, 0.36100415438919764`, 0.9365140589777743],
              UndirectedEdge[306, 331] -> 
             RGBColor[
              0.6453215149169124, 0.720164767833845, 0.9671441268400578], 
             UndirectedEdge[103, 129] -> 
             RGBColor[
              0.8774187255071293, 0.9016025093574369, 0.8041344145942433], 
             UndirectedEdge[50, 126] -> 
             RGBColor[
              0.8563654629268306, 0.3487034608338446, 0.19818596167822736`], 
             UndirectedEdge[172, 308] -> 
             RGBColor[
              0.3042365377894142, 0.4307035671871346, 0.9408714806274372], 
             UndirectedEdge[112, 266] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[129, 275] -> 
             RGBColor[
              0.8469448752581116, 0.7933181891173926, 0.6210335543626414], 
             UndirectedEdge[297, 325] -> 
             RGBColor[
              0.3379519408599507, 0.461641809531562, 0.9429562454735485], 
             UndirectedEdge[202, 396] -> 
             RGBColor[
              0.23566677937848166`, 0.36503110563657915`, 0.9367322464966231],
              UndirectedEdge[167, 236] -> 
             RGBColor[
              0.3815834793692655, 0.504536728962441, 0.9455765013084759], 
             UndirectedEdge[184, 301] -> 
             RGBColor[
              0.8369837657282427, 0.26650113164225936`, 0.18231370738115665`],
              UndirectedEdge[78, 258] -> 
             RGBColor[
              0.9750213117175937, 0.926509082881858, 0.43348885156620276`], 
             UndirectedEdge[172, 470] -> 
             RGBColor[0.3122258224217289, 0.4391008118856, 0.94132645856816], 
             UndirectedEdge[72, 159] -> 
             RGBColor[
              0.3689545388465866, 0.49399161017976106`, 0.9447304348549841], 
             UndirectedEdge[304, 337] -> 
             RGBColor[
              0.2261823882456348, 0.3550624092108272, 0.9361921244525068], 
             UndirectedEdge[88, 271] -> 
             RGBColor[
              0.2646478400333292, 0.39549203789019866`, 0.9383826750272796], 
             UndirectedEdge[392, 413] -> 
             RGBColor[
              0.4263466505931637, 0.5437017727632361, 0.9483874094656242], 
             UndirectedEdge[187, 216] -> 
             RGBColor[
              0.3182566714322743, 0.44643568599611877`, 0.9416334355165438], 
             UndirectedEdge[33, 432] -> 
             RGBColor[
              0.6658838925050865, 0.7376570283356887, 0.9681913363476764], 
             UndirectedEdge[36, 75] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[243, 335] -> 
             RGBColor[
              0.2849976301701568, 0.4162998743541054, 0.9395628417739867], 
             UndirectedEdge[323, 499] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[168, 480] -> 
             RGBColor[
              0.6297537319756995, 0.7081913650531002, 0.9654383612024078], 
             UndirectedEdge[301, 388] -> 
             RGBColor[
              0.8529860941236527, 0.4035819731432213, 0.44035989591821356`], 
             UndirectedEdge[111, 371] -> 
             RGBColor[
              0.7655925884892005, 0.8153534034271036, 0.9316997915837725], 
             UndirectedEdge[103, 231] -> 
             RGBColor[
              0.8763449551304583, 0.4195592621909958, 0.3199825200895846], 
             UndirectedEdge[99, 131] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[193, 428] -> 
             RGBColor[
              0.20228207150770255`, 0.3299416609516557, 0.9348310367716316], 
             UndirectedEdge[189, 370] -> 
             RGBColor[
              0.46831823256064525`, 0.5778806701117645, 0.9516626990295814], 
             UndirectedEdge[45, 187] -> 
             RGBColor[
              0.32097517805687237`, 0.4492930088218466, 0.9417882504471444], 
             UndirectedEdge[346, 443] -> 
             RGBColor[
              0.8671794238025463, 0.8799881761931223, 0.6821354249019], 
             UndirectedEdge[19, 318] -> 
             RGBColor[
              0.2722803757294244, 0.4035143168375083, 0.9388173366438475], 
             UndirectedEdge[5, 129] -> 
             RGBColor[
              0.7983595285409613, 0.3603450773806288, 0.4350644229732442], 
             UndirectedEdge[29, 46] -> 
             RGBColor[
              0.24415483873233365`, 0.37395259419152405`, 0.9372156289198665],
              UndirectedEdge[227, 263] -> 
             RGBColor[
              0.3111215525527843, 0.43756489362752915`, 0.9412773121619749], 
             UndirectedEdge[272, 435] -> 
             RGBColor[
              0.5079170557519607, 0.611284214636594, 0.9544331827525074], 
             UndirectedEdge[208, 483] -> 
             RGBColor[
              0.9822132132406076, 0.9513533457595487, 0.41174420115349936`], 
             UndirectedEdge[244, 475] -> 
             RGBColor[
              0.9597357029053115, 0.9456258595690394, 0.6742998293777165], 
             UndirectedEdge[350, 412] -> 
             RGBColor[
              0.20892004662185062`, 0.33691859366855603`, 0.9352090596343783],
              UndirectedEdge[217, 398] -> 
             RGBColor[
              0.24278043899605473`, 0.37250801292671853`, 0.9371373588881275],
              UndirectedEdge[370, 451] -> 
             RGBColor[
              0.34741654792202903`, 0.4737521458369133, 0.9434160635353744], 
             UndirectedEdge[265, 424] -> 
             RGBColor[
              0.2218738016558165, 0.3505338115247602, 0.9359467568201993], 
             UndirectedEdge[28, 419] -> 
             RGBColor[
              0.8613224849238736, 0.3683564012224616, 0.2021744979333091], 
             UndirectedEdge[67, 381] -> 
             RGBColor[
              0.20330273841305002`, 0.33101444658319545`, 0.9348891622419497],
              UndirectedEdge[239, 435] -> 
             RGBColor[
              0.35235214804716863`, 0.47466487178031647`, 0.9438536637907615],
              UndirectedEdge[302, 370] -> 
             RGBColor[
              0.4457020294385857, 0.5595198175689367, 0.9498822686739312], 
             UndirectedEdge[2, 66] -> 
             RGBColor[
              0.23109684665162938`, 0.3602278165901873, 0.9364719955884385], 
             UndirectedEdge[36, 408] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[76, 483] -> 
             RGBColor[
              0.982883335899123, 0.9527866703663195, 0.4846829170152394], 
             UndirectedEdge[9, 367] -> 
             RGBColor[
              0.2501892935368386, 0.3802951887975917, 0.9375592821938071], 
             UndirectedEdge[133, 469] -> 
             RGBColor[
              0.2251876288090195, 0.3540168539715534, 0.9361354743742063], 
             UndirectedEdge[46, 297] -> 
             RGBColor[
              0.26748674663782457`, 0.39847590872859817`, 0.9385443465586196],
              UndirectedEdge[159, 435] -> 
             RGBColor[
              0.4343916682734087, 0.5506699627235185, 0.9489000308782796], 
             UndirectedEdge[126, 340] -> 
             RGBColor[
              0.9580550382851865, 0.8818464109073033, 0.591032485493439], 
             UndirectedEdge[27, 290] -> 
             RGBColor[
              0.19806122117282127`, 0.32550527963232745`, 0.9345906655892486],
              UndirectedEdge[326, 338] -> 
             RGBColor[
              0.8759439761629737, 0.4187016087247386, 0.2763384340342258], 
             UndirectedEdge[179, 438] -> 
             RGBColor[
              0.27563010636510166`, 0.40703509612079425`, 0.9390080988480669],
              UndirectedEdge[138, 339] -> 
             RGBColor[
              0.1899160305473181, 0.31694416785001006`, 0.934126809032856], 
             UndirectedEdge[475, 482] -> 
             RGBColor[
              0.9392561672086392, 0.9542179294798765, 0.9877076437735679], 
             UndirectedEdge[94, 428] -> 
             RGBColor[
              0.19798131880027114`, 0.3254212971726742, 0.9345861152673369], 
             UndirectedEdge[186, 295] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[348, 372] -> 
             RGBColor[
              0.8657911144896757, 0.38473790158096466`, 0.21272342517580606`],
              UndirectedEdge[293, 343] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[385, 446] -> 
             RGBColor[
              0.1942371163982918, 0.32148590305205027`, 0.9343728884795952], 
             UndirectedEdge[7, 288] -> 
             RGBColor[
              0.8626928878488475, 0.3737895921602789, 0.20327715629423396`], 
             UndirectedEdge[242, 323] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[464, 481] -> 
             RGBColor[
              0.28633185579708176`, 0.41828331330390933`, 0.9396175476463986],
              UndirectedEdge[42, 108] -> 
             RGBColor[
              0.29172348972761986`, 0.4237068926091371, 0.9399335041832765], 
             UndirectedEdge[101, 276] -> 
             RGBColor[
              0.41043620356290245`, 0.5289146649262826, 0.9476516475428687], 
             UndirectedEdge[86, 426] -> 
             RGBColor[
              0.2108343428642681, 0.3389306403927288, 0.9353180759734364], 
             UndirectedEdge[37, 324] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[290, 297] -> 
             RGBColor[
              0.21970848593960174`, 0.3482579274180727, 0.9358234452934584], 
             UndirectedEdge[315, 380] -> 
             RGBColor[
              0.2069794182961998, 0.33487887025535457`, 0.9350985437221347], 
             UndirectedEdge[181, 390] -> 
             RGBColor[
              0.4729036438374925, 0.5811809878887164, 0.9521403692426029], 
             UndirectedEdge[283, 421] -> 
             RGBColor[
              0.19788031285751928`, 0.32531513352269537`, 0.934580363128322], 
             UndirectedEdge[97, 355] -> 
             RGBColor[
              0.8304768118928137, 0.23526370799810264`, 0.17681793552818148`],
              UndirectedEdge[192, 219] -> 
             RGBColor[
              0.8349445829202758, 0.3891961618334242, 0.4386390804737884], 
             UndirectedEdge[171, 192] -> 
             RGBColor[
              0.9127961865391916, 0.8801019973264443, 0.6352252611263622], 
             UndirectedEdge[122, 216] -> 
             RGBColor[
              0.23867128343248623`, 0.3681890298938975, 0.9369033485577333], 
             UndirectedEdge[18, 28] -> 
             RGBColor[
              0.8517541692906616, 0.8223523733810587, 0.6271103274009263], 
             UndirectedEdge[178, 288] -> 
             RGBColor[
              0.8637848357389819, 0.37797025225822195`, 0.20492941108331195`],
              UndirectedEdge[165, 185] -> 
             RGBColor[
              0.5826823072651669, 0.6655836746935463, 0.9633520886464765], 
             UndirectedEdge[264, 281] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[80, 192] -> 
             RGBColor[
              0.9140926674874497, 0.9337618841006211, 0.9717390466384628], 
             UndirectedEdge[74, 402] -> 
             RGBColor[
              0.28664069656288654`, 0.4145877472581879, 0.9397823340543834], 
             UndirectedEdge[3, 158] -> 
             RGBColor[
              0.2166432544871289, 0.3450361748146247, 0.9356488848968436], 
             UndirectedEdge[426, 476] -> 
             RGBColor[
              0.20678139218521432`, 0.3346707322571282, 0.9350872664280675], 
             UndirectedEdge[27, 177] -> 
             RGBColor[
              0.20421188606161866`, 0.3319700184051313, 0.9349409368555723], 
             UndirectedEdge[355, 443] -> 
             RGBColor[
              0.8216514179326964, 0.5602563290870928, 0.4599629164436284], 
             UndirectedEdge[21, 256] -> 
             RGBColor[
              0.8436281097875116, 0.8781501713422988, 0.9849471962988788], 
             UndirectedEdge[331, 404] -> 
             RGBColor[
              0.8207108366647649, 0.3778465589340292, 0.4372814530493224], 
             UndirectedEdge[142, 285] -> 
             RGBColor[
              0.3374576097099063, 0.46671055324325716`, 0.9427234783820356], 
             UndirectedEdge[232, 267] -> 
             RGBColor[
              0.5508554530526312, 0.6441295520312013, 0.958705334070763], 
             UndirectedEdge[133, 488] -> 
             RGBColor[
              0.22772081169529612`, 0.3566793897981017, 0.9362797353920715], 
             UndirectedEdge[148, 393] -> 
             RGBColor[
              0.5205392578625186, 0.6188284372317407, 0.9563684594629627], 
             UndirectedEdge[84, 89] -> 
             RGBColor[
              0.7687714356170879, 0.8196030224681695, 0.9775043726151027], 
             UndirectedEdge[27, 350] -> 
             RGBColor[
              0.19805630037094138`, 0.32550010755755476`, 0.9345903853568613],
              UndirectedEdge[8, 435] -> 
             RGBColor[
              0.3541661224083213, 0.47657147384650533`, 0.9439569669470946], 
             UndirectedEdge[20, 220] -> 
             RGBColor[
              0.40815671966871825`, 0.5275114594099448, 0.9473485851862612], 
             UndirectedEdge[35, 422] -> 
             RGBColor[
              0.25718407515887753`, 0.3876471477771245, 0.9379576246593302], 
             UndirectedEdge[65, 177] -> 
             RGBColor[
              0.19983486008505225`, 0.32736948658428433`, 0.9346916717014366],
              UndirectedEdge[93, 160] -> 
             RGBColor[
              0.41434048219955033`, 0.5332607321432926, 0.9476339644047369], 
             UndirectedEdge[277, 373] -> 
             RGBColor[
              0.8718851812720558, 0.40529461979285863`, 0.23639772385740537`],
              UndirectedEdge[15, 126] -> 
             RGBColor[
              0.8563654629268306, 0.3487034608338446, 0.19818596167822736`], 
             UndirectedEdge[95, 367] -> 
             RGBColor[
              0.2305659285403663, 0.35966978799309735`, 0.936441760587425], 
             UndirectedEdge[304, 465] -> 
             RGBColor[
              0.2045659825518425, 0.33234219626737077`, 0.9349611021268518], 
             UndirectedEdge[218, 305] -> 
             RGBColor[
              0.8008096506568456, 0.8446558514839924, 0.9806911855307536], 
             UndirectedEdge[137, 265] -> 
             RGBColor[
              0.26167159806531437`, 0.3912147203864842, 0.9382552565748988], 
             UndirectedEdge[325, 392] -> 
             RGBColor[
              0.4343230041731056, 0.550610489330994, 0.9488956556625256], 
             UndirectedEdge[263, 393] -> 
             RGBColor[
              0.37476311386086897`, 0.49902270590966347`, 0.9451005521185729],
              UndirectedEdge[228, 335] -> 
             RGBColor[
              0.44380700835062176`, 0.5555867299052314, 0.9503947274664715], 
             UndirectedEdge[104, 408] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[145, 375] -> 
             RGBColor[
              0.29508560074384793`, 0.4274840542624467, 0.9401160604711118], 
             UndirectedEdge[181, 451] -> 
             RGBColor[
              0.3396395828866079, 0.4670161296048595, 0.9429205222002176], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.2855288778367985, 0.4174393325559085, 0.93957181923946], 
             UndirectedEdge[387, 439] -> 
             RGBColor[
              0.24411472500393933`, 0.3739104321196243, 0.9372133445023774], 
             UndirectedEdge[163, 231] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[143, 288] -> 
             RGBColor[
              0.8305642118064, 0.2359355020328133, 0.17690162978413582`], 
             UndirectedEdge[128, 312] -> 
             RGBColor[
              0.2464921841409758, 0.3764092924122653, 0.937348737283096], 
             UndirectedEdge[270, 479] -> 
             RGBColor[
              0.18878700248308236`, 0.3157574877699845, 0.9340625125548451], 
             UndirectedEdge[119, 120] -> 
             RGBColor[
              0.1926435788239345, 0.319810994025283, 0.9342821388721632], 
             UndirectedEdge[105, 462] -> 
             RGBColor[
              0.229837954460574, 0.3589046410790131, 0.936400303540522], 
             UndirectedEdge[14, 159] -> 
             RGBColor[
              0.41659878498905367`, 0.5352586615189268, 0.9477662840890294], 
             UndirectedEdge[58, 417] -> 
             RGBColor[
              0.2488046847191422, 0.3788398771409232, 0.9374804307699846], 
             UndirectedEdge[66, 299] -> 
             RGBColor[
              0.35967789907867415`, 0.4813548224100252, 0.9443433705559179], 
             UndirectedEdge[11, 348] -> 
             RGBColor[
              0.9751195085877224, 0.9375300834633149, 0.5832471359376257], 
             UndirectedEdge[4, 31] -> 
             RGBColor[
              0.21260957010359166`, 0.3407965167771657, 0.9354191725385025], 
             UndirectedEdge[259, 400] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[247, 451] -> 
             RGBColor[
              0.24679602556146502`, 0.37672864900985814`, 0.9373660406024997],
              UndirectedEdge[17, 261] -> 
             RGBColor[
              0.9569330773756479, 0.9666186433450407, 0.9251577239854265], 
             UndirectedEdge[361, 386] -> 
             RGBColor[
              0.6265759062045188, 0.7036449006082633, 0.9661292482994008], 
             UndirectedEdge[212, 492] -> 
             RGBColor[
              0.19335812540385172`, 0.3205620277856458, 0.9343228312428125], 
             UndirectedEdge[287, 388] -> 
             RGBColor[
              0.8811274230386713, 0.9080511058370317, 0.9885239142728066], 
             UndirectedEdge[383, 480] -> 
             RGBColor[
              0.5559679739852978, 0.6503988732098943, 0.9581869819713671], 
             UndirectedEdge[403, 440] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[13, 354] -> 
             RGBColor[
              0.7007171274519702, 0.7648883443366565, 0.9717917557802591], 
             UndirectedEdge[1, 42] -> 
             RGBColor[
              0.26932784147908145`, 0.4004110161389142, 0.9386491941861734], 
             UndirectedEdge[161, 188] -> 
             RGBColor[
              0.35599050426396195`, 0.4827628150156156, 0.9439043780350249], 
             UndirectedEdge[194, 426] -> 
             RGBColor[
              0.2125469848716252, 0.34073073573023605`, 0.9354156084021286], 
             UndirectedEdge[257, 324] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[198, 479] -> 
             RGBColor[
              0.19373559329222378`, 0.3209587704691713, 0.9343443274806416], 
             UndirectedEdge[372, 431] -> 
             RGBColor[
              0.8760289938084724, 0.418883452871858, 0.28559208007867803`], 
             UndirectedEdge[107, 466] -> 
             RGBColor[
              0.2835372091003608, 0.41436065137694744`, 0.939494473715824], 
             UndirectedEdge[122, 330] -> 
             RGBColor[
              0.21641357139056538`, 0.344794763317387, 0.9356358047842801], 
             UndirectedEdge[4, 472] -> 
             RGBColor[
              0.19355933557756982`, 0.3207735124356854, 0.9343342898645419], 
             UndirectedEdge[145, 458] -> 
             RGBColor[
              0.3805547611175523, 0.5040310020322399, 0.9454698887190787], 
             UndirectedEdge[3, 451] -> 
             RGBColor[
              0.24545922641333842`, 0.37532358834721574`, 0.9372899118686311],
              UndirectedEdge[146, 239] -> 
             RGBColor[
              0.21955415616402918`, 0.348095717038873, 0.93581465644105], 
             UndirectedEdge[15, 282] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[82, 126] -> 
             RGBColor[
              0.916199280091377, 0.7036541810826651, 0.25133650057422957`], 
             UndirectedEdge[413, 474] -> 
             RGBColor[
              0.40874864664870547`, 0.5284592662479426, 0.9472660802155872], 
             UndirectedEdge[160, 235] -> 
             RGBColor[
              0.4011187714023029, 0.521808750793224, 0.9467914886842361], 
             UndirectedEdge[161, 183] -> 
             RGBColor[
              0.29416391383429163`, 0.4243927717499564, 0.9401412880273525], 
             UndirectedEdge[366, 429] -> 
             RGBColor[
              0.2147911262952244, 0.34308947065322315`, 0.9355434089362928], 
             UndirectedEdge[7, 313] -> 
             RGBColor[
              0.9656877072512522, 0.9180895651945491, 0.6018151796811678], 
             UndirectedEdge[129, 444] -> 
             RGBColor[
              0.8208341223499612, 0.533094653826407, 0.4565861193861659], 
             UndirectedEdge[18, 493] -> 
             RGBColor[
              0.6718112756182114, 0.7427327461515889, 0.9684777360932533], 
             UndirectedEdge[149, 411] -> 
             RGBColor[
              0.8077452715809664, 0.5432739233115719, 0.4578166578979691], 
             UndirectedEdge[221, 301] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[45, 496] -> 
             RGBColor[
              0.24168419906114047`, 0.37135579524949736`, 0.9370749296455758],
              UndirectedEdge[478, 482] -> 
             RGBColor[
              0.7264961635628073, 0.7852647197480608, 0.973944678975416], 
             UndirectedEdge[69, 331] -> 
             RGBColor[
              0.9044576421525903, 0.9071378636611861, 0.6828660025242381], 
             UndirectedEdge[16, 143] -> 
             RGBColor[
              0.7737686828707752, 0.43259576374804576`, 0.44397690814617397`],
              UndirectedEdge[210, 280] -> 
             RGBColor[
              0.396625050619534, 0.5101349644825113, 0.9473626025497911], 
             UndirectedEdge[101, 390] -> 
             RGBColor[
              0.5242582957488938, 0.6246555279128561, 0.9556906799442186], 
             UndirectedEdge[400, 418] -> 
             RGBColor[
              0.8610616366179067, 0.36732222461184755`, 0.20196461326343138`],
              UndirectedEdge[84, 299] -> 
             RGBColor[
              0.5687650672352391, 0.6602306460937123, 0.9595755708293949], 
             UndirectedEdge[333, 386] -> 
             RGBColor[
              0.6306233379177042, 0.7071505825283917, 0.9663871470691616], 
             UndirectedEdge[244, 341] -> 
             RGBColor[
              0.8706168078338911, 0.40101609835768304`, 0.23147033256236077`],
              UndirectedEdge[143, 373] -> 
             RGBColor[
              0.8305642118064, 0.2359355020328133, 0.17690162978413582`], 
             UndirectedEdge[160, 284] -> 
             RGBColor[
              0.3769905478109568, 0.5000200987965604, 0.9452866467788439], 
             UndirectedEdge[281, 343] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[207, 445] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[260, 334] -> 
             RGBColor[
              0.26255693501735466`, 0.39299015605094145`, 0.9382747396284472],
              UndirectedEdge[66, 114] -> 
             RGBColor[
              0.22515212124439515`, 0.35397953326982357`, 0.9361334522709297],
              UndirectedEdge[364, 381] -> 
             RGBColor[
              0.2539571451040042, 0.38425543969027, 0.9377738557665203], 
             UndirectedEdge[204, 306] -> 
             RGBColor[
              0.6716952973173317, 0.7411945060226874, 0.9696596817495633], 
             UndirectedEdge[358, 361] -> 
             RGBColor[
              0.39714059485190245`, 0.5184049552191992, 0.9465264254196921], 
             UndirectedEdge[294, 415] -> 
             RGBColor[
              0.20054448474921935`, 0.3281153470991263, 0.9347320837762653], 
             UndirectedEdge[2, 255] -> 
             RGBColor[
              0.22956360210905913`, 0.3586162793626272, 0.9363846795799712], 
             UndirectedEdge[326, 443] -> 
             RGBColor[
              0.7953357941470689, 0.3579829130908875, 0.4347630453872655], 
             UndirectedEdge[58, 145] -> 
             RGBColor[
              0.27446298131762203`, 0.4058083736958911, 0.9389416328032197], 
             UndirectedEdge[103, 346] -> 
             RGBColor[
              0.9886931652776305, 0.9723526998432848, 0.5099646369553787], 
             UndirectedEdge[62, 108] -> 
             RGBColor[
              0.4199530900612806, 0.5361218661360846, 0.948544262897387], 
             UndirectedEdge[91, 336] -> 
             RGBColor[
              0.8662785326994125, 0.38638207765364485`, 0.21461695287942806`],
              UndirectedEdge[338, 395] -> 
             RGBColor[
              0.9545810948287645, 0.8462000070822004, 0.3759117982208804], 
             UndirectedEdge[19, 335] -> 
             RGBColor[
              0.29929511833709316`, 0.431327440930663, 0.9403770625738554], 
             UndirectedEdge[2, 195] -> 
             RGBColor[
              0.2100171428775559, 0.33807171139322245`, 0.9352715376431322], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.3108236109603984, 0.4367287160722685, 0.9412794952284302], 
             UndirectedEdge[150, 325] -> 
             RGBColor[
              0.38277885144144796`, 0.5059655349192759, 0.945611307829169], 
             UndirectedEdge[208, 238] -> 
             RGBColor[
              0.9647733116194365, 0.8867812659004515, 0.37390414215136103`], 
             UndirectedEdge[318, 335] -> 
             RGBColor[
              0.2880161711733349, 0.41947255233499914`, 0.9397347432185865], 
             UndirectedEdge[12, 421] -> 
             RGBColor[
              0.22311781120305674`, 0.35184134443367066`, 0.9360176013235675],
              UndirectedEdge[102, 278] -> 
             RGBColor[
              0.23503759534630753`, 0.36436979332619235`, 0.9366964153967852],
              UndirectedEdge[5, 209] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[76, 463] -> 
             RGBColor[
              0.9056870458264669, 0.638998257982552, 0.34597987810968656`], 
             UndirectedEdge[293, 445] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[48, 250] -> 
             RGBColor[
              0.2928014111284232, 0.4203922887415252, 0.9401577374493421], 
             UndirectedEdge[459, 477] -> 
             RGBColor[
              0.2530584936401587, 0.3833109000239747, 0.9377226788950901], 
             UndirectedEdge[400, 404] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[144, 246] -> 
             RGBColor[
              0.35696945876019426`, 0.4786389058672158, 0.9441772202942458], 
             UndirectedEdge[90, 393] -> 
             RGBColor[
              0.483014768717581, 0.588842395082875, 0.9530875634575574], 
             UndirectedEdge[157, 360] -> 
             RGBColor[
              0.821018879012048, 0.40265646105823816`, 0.44038049549212843`], 
             UndirectedEdge[156, 250] -> 
             RGBColor[
              0.3132873521623067, 0.4419243116518183, 0.9413243814849879], 
             UndirectedEdge[25, 220] -> 
             RGBColor[
              0.5522883600909476, 0.6427585806873211, 0.9599021951346662], 
             UndirectedEdge[261, 407] -> 
             RGBColor[
              0.8073350312031458, 0.850275694776358, 0.981203007569101], 
             UndirectedEdge[42, 364] -> 
             RGBColor[
              0.2803428770185711, 0.4119885168845083, 0.9392764841648626], 
             UndirectedEdge[83, 257] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[137, 263] -> 
             RGBColor[
              0.3515933537073658, 0.478954224210705, 0.9436241954898061], 
             UndirectedEdge[27, 65] -> 
             RGBColor[
              0.20162066097000025`, 0.3292464765406804, 0.9347933704199787], 
             UndirectedEdge[318, 421] -> 
             RGBColor[
              0.23161541098479776`, 0.360772860583225, 0.9365015270600652], 
             UndirectedEdge[203, 341] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[80, 483] -> 
             RGBColor[
              0.9647055314408126, 0.9417246771617777, 0.6497375573103179], 
             UndirectedEdge[95, 319] -> 
             RGBColor[
              0.19548834932226328`, 0.3228010281878937, 0.9344441443435821], 
             UndirectedEdge[84, 376] -> 
             RGBColor[
              0.832389864449723, 0.8687276795195121, 0.9249120944385643], 
             UndirectedEdge[260, 446] -> 
             RGBColor[
              0.25513065781781996`, 0.38518466786106076`, 0.9378518241281263],
              UndirectedEdge[174, 393] -> 
             RGBColor[
              0.29163543014520826`, 0.4184242024491195, 0.9401185255489448], 
             UndirectedEdge[185, 216] -> 
             RGBColor[
              0.29497840118270136`, 0.42627321830582066`, 0.9401501647204071],
              UndirectedEdge[143, 321] -> 
             RGBColor[
              0.8305642118064, 0.2359355020328133, 0.17690162978413582`], 
             UndirectedEdge[296, 415] -> 
             RGBColor[
              0.1892097843878332, 0.3162018583577987, 0.9340865893588708], 
             UndirectedEdge[42, 113] -> 
             RGBColor[
              0.26381259130705503`, 0.39461413852105653`, 0.938335108847958], 
             UndirectedEdge[54, 264] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[9, 95] -> 
             RGBColor[
              0.2233343412505307, 0.35206893124236366`, 0.9360299323894435], 
             UndirectedEdge[47, 55] -> 
             RGBColor[
              0.8007526423490732, 0.4840965388666049, 0.45044599340948344`], 
             UndirectedEdge[212, 330] -> 
             RGBColor[
              0.20837402292048057`, 0.33634468813851387`, 0.9351779643923548],
              UndirectedEdge[89, 244] -> 
             RGBColor[
              0.9180019876539445, 0.912517691740197, 0.6761842483111349], 
             UndirectedEdge[3, 247] -> 
             RGBColor[
              0.2006452395594779, 0.32822124679293196`, 0.9347378216136562], 
             UndirectedEdge[26, 318] -> 
             RGBColor[
              0.23281828005836602`, 0.3620371522458494, 0.9365700286743196], 
             UndirectedEdge[46, 426] -> 
             RGBColor[
              0.2504601286056602, 0.3805798536268583, 0.937574705850312], 
             UndirectedEdge[102, 247] -> 
             RGBColor[
              0.23463961323959567`, 0.36395148889851525`, 0.9366737509045697],
              UndirectedEdge[285, 287] -> 
             RGBColor[
              0.586107161663346, 0.6687841757317179, 0.9634625646876807], 
             UndirectedEdge[346, 390] -> 
             RGBColor[
              0.7705637997404904, 0.8032211601227189, 0.6733877692921244], 
             UndirectedEdge[388, 473] -> 
             RGBColor[
              0.7653160411936457, 0.8168810892875349, 0.9773969600633411], 
             UndirectedEdge[377, 412] -> 
             RGBColor[
              0.20734204026481207`, 0.3352600089359268, 0.935119194506796], 
             UndirectedEdge[7, 321] -> 
             RGBColor[
              0.8626928878488475, 0.3737895921602789, 0.20327715629423396`], 
             UndirectedEdge[209, 275] -> 
             RGBColor[
              0.8560290549644465, 0.34736971536429956`, 0.19791527993518332`],
              UndirectedEdge[204, 346] -> 
             RGBColor[
              0.9316157699795097, 0.9308133831466772, 0.688428591304491], 
             UndirectedEdge[220, 297] -> 
             RGBColor[
              0.2981314546378194, 0.42715130580178384`, 0.9404189193033476], 
             UndirectedEdge[16, 185] -> 
             RGBColor[
              0.4837779911654755, 0.5881187692744494, 0.9535473316443274], 
             UndirectedEdge[323, 449] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[224, 481] -> 
             RGBColor[
              0.2938275095894578, 0.4261617206915963, 0.9400444140410484], 
             UndirectedEdge[86, 476] -> 
             RGBColor[
              0.2023767546336836, 0.3300411789203187, 0.9348364288355852], 
             UndirectedEdge[66, 385] -> 
             RGBColor[
              0.22541308597049314`, 0.3542538237430719, 0.9361483138260183], 
             UndirectedEdge[184, 316] -> 
             RGBColor[
              0.9311223602384289, 0.7477274618057713, 0.3091758937857617], 
             UndirectedEdge[308, 362] -> 
             RGBColor[
              0.20539074651933456`, 0.3332090754902608, 0.9350080712146716], 
             UndirectedEdge[216, 361] -> 
             RGBColor[
              0.3394942538231242, 0.464830612431145, 0.9429866754868319], 
             UndirectedEdge[123, 410] -> 
             RGBColor[
              0.20098281054011963`, 0.3285760552968229, 0.9347570457816121], 
             UndirectedEdge[174, 225] -> 
             RGBColor[
              0.20819278575014724`, 0.33615419638139327`, 0.9351676432036207],
              UndirectedEdge[3, 139] -> 
             RGBColor[
              0.19702713929235682`, 0.3244183940113813, 0.9345317761559433], 
             UndirectedEdge[226, 472] -> 
             RGBColor[
              0.2053352778859962, 0.33315077443970764`, 0.9350049123580614], 
             UndirectedEdge[9, 441] -> 
             RGBColor[
              0.3055997605504103, 0.43303430826331607`, 0.9409162373541138], 
             UndirectedEdge[253, 354] -> 
             RGBColor[
              0.9250268564024191, 0.9410475477217897, 0.9164719893666022], 
             UndirectedEdge[47, 73] -> 
             RGBColor[
              0.7986897921704463, 0.4682405684469667, 0.4484706057487744], 
             UndirectedEdge[305, 432] -> 
             RGBColor[
              0.8165943047884041, 0.8569869432593805, 0.9822644523386079], 
             UndirectedEdge[4, 226] -> 
             RGBColor[
              0.201838009483021, 0.3294749236085569, 0.9348057480962568], 
             UndirectedEdge[112, 359] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[101, 204] -> 
             RGBColor[
              0.6853102659879131, 0.7522477509368144, 0.9707315019565851], 
             UndirectedEdge[256, 409] -> 
             RGBColor[
              0.7032931179635095, 0.7669554550610453, 0.9720223945230841], 
             UndirectedEdge[64, 268] -> 
             RGBColor[
              0.20747158720625564`, 0.3353961709851344, 0.9351265720134637], 
             UndirectedEdge[97, 395] -> 
             RGBColor[
              0.8502020870562027, 0.32426772933006165`, 0.19322676477969444`],
              UndirectedEdge[117, 156] -> 
             RGBColor[
              0.23299646235272825`, 0.36222443313463404`, 0.9365801758923864],
              UndirectedEdge[48, 117] -> 
             RGBColor[
              0.21251052131884468`, 0.34069241022434094`, 0.9354135318567407],
              UndirectedEdge[5, 103] -> 
             RGBColor[
              0.8763449551304583, 0.41955926219099576`, 0.3199825200895846], 
             UndirectedEdge[344, 438] -> 
             RGBColor[
              0.25444533400405744`, 0.38476855717718994`, 0.9378016574021677],
              UndirectedEdge[42, 381] -> 
             RGBColor[
              0.2456829942137933, 0.3755587824931918, 0.9373026551138322], 
             UndirectedEdge[224, 398] -> 
             RGBColor[
              0.29596053905936104`, 0.4284036699063442, 0.9401658869138251], 
             UndirectedEdge[226, 405] -> 
             RGBColor[
              0.202154999658272, 0.32980810038108366`, 0.9348238002177924], 
             UndirectedEdge[231, 346] -> 
             RGBColor[
              0.8725424883879621, 0.4075118710378607, 0.23895123788066785`], 
             UndirectedEdge[168, 181] -> 
             RGBColor[
              0.5838876467268811, 0.6691726907027558, 0.9623201305737528], 
             UndirectedEdge[178, 391] -> 
             RGBColor[
              0.9546302047945031, 0.8576080870133145, 0.28351307352097976`], 
             UndirectedEdge[30, 133] -> 
             RGBColor[
              0.21997865236817787`, 0.3485418894640472, 0.9358388308718903], 
             UndirectedEdge[120, 363] -> 
             RGBColor[
              0.1889703081558431, 0.31595015365430695`, 0.9340729515417323], 
             UndirectedEdge[452, 468] -> 
             RGBColor[
              0.38113300438540465`, 0.5045399849220095, 0.9455064359101233], 
             UndirectedEdge[159, 344] -> 
             RGBColor[
              0.32356779326194895`, 0.4471969980536896, 0.9421124169766175], 
             UndirectedEdge[68, 330] -> 
             RGBColor[
              0.2158728859753908, 0.3442264686646032, 0.9356050135497582], 
             UndirectedEdge[359, 440] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[180, 413] -> 
             RGBColor[
              0.5070777034000054, 0.6095492560638003, 0.9546582005878961], 
             UndirectedEdge[81, 442] -> 
             RGBColor[
              0.44817461811353243`, 0.562608061123832, 0.9497782682543083], 
             UndirectedEdge[165, 277] -> 
             RGBColor[
              0.9128792946043378, 0.9133337276812334, 0.6829052603313144], 
             UndirectedEdge[28, 310] -> 
             RGBColor[
              0.8613224849238736, 0.3683564012224616, 0.2021744979333091], 
             UndirectedEdge[71, 470] -> 
             RGBColor[
              0.2532282244104237, 0.3834892978250757, 0.9377323448113625], 
             UndirectedEdge[129, 276] -> 
             RGBColor[
              0.5454672677839978, 0.6367301066502977, 0.9595185145296392], 
             UndirectedEdge[192, 251] -> 
             RGBColor[
              0.6611025885462706, 0.7326320332459636, 0.9687519301958931], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.9735420588312775, 0.9270450247585778, 0.5414260096688857], 
             UndirectedEdge[15, 323] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[20, 473] -> 
             RGBColor[
              0.5378272732791293, 0.6356714351473729, 0.9567588795602012], 
             UndirectedEdge[336, 354] -> 
             RGBColor[
              0.8321846694563217, 0.3869954817531224, 0.4383758374637925], 
             UndirectedEdge[36, 440] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[31, 311] -> 
             RGBColor[
              0.2308573313259354, 0.3599760707967341, 0.9364583555449715], 
             UndirectedEdge[366, 405] -> 
             RGBColor[
              0.19262927042803146`, 0.31979595499398417`, 0.9342813240301839],
              UndirectedEdge[257, 374] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[194, 254] -> 
             RGBColor[
              0.22347198353028988`, 0.3522136020054152, 0.9360377709136524], 
             UndirectedEdge[284, 456] -> 
             RGBColor[
              0.2749576588362952, 0.40632831113238277`, 0.9389698039560983], 
             UndirectedEdge[30, 429] -> 
             RGBColor[
              0.20698840587743583`, 0.3348883167730792, 0.9350990555515901], 
             UndirectedEdge[182, 463] -> 
             RGBColor[
              0.8924035413977808, 0.6307547645274091, 0.4579882921332097], 
             UndirectedEdge[130, 238] -> 
             RGBColor[
              0.8848677063670416, 0.8279729997302321, 0.6258750507442762], 
             UndirectedEdge[19, 67] -> 
             RGBColor[
              0.23543376871002816`, 0.36478619665030476`, 0.9367189768837632],
              UndirectedEdge[114, 446] -> 
             RGBColor[
              0.1939761516721938, 0.321211612578802, 0.9343580269245066], 
             UndirectedEdge[164, 418] -> 
             RGBColor[
              0.9146050965365867, 0.8706968435897349, 0.6329687419964006], 
             UndirectedEdge[96, 457] -> 
             RGBColor[
              0.956033925940152, 0.8631590470414205, 0.284717153430919], 
             UndirectedEdge[285, 354] -> 
             RGBColor[
              0.5980978839946363, 0.6783452522392017, 0.9646062504878833], 
             UndirectedEdge[432, 460] -> 
             RGBColor[
              0.797979397774264, 0.8421439216944954, 0.9804889458898756], 
             UndirectedEdge[82, 249] -> 
             RGBColor[
              0.844192723800754, 0.2992353265545988, 0.18832903870459236`], 
             UndirectedEdge[176, 262] -> 
             RGBColor[
              0.9178226250506125, 0.9368943496024587, 0.9775831247382163], 
             UndirectedEdge[216, 358] -> 
             RGBColor[
              0.32697957425635543`, 0.45399102599649405`, 0.9421892511711341],
              UndirectedEdge[54, 374] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[214, 491] -> 
             RGBColor[
              0.20330311497053621`, 0.3310148423689886, 0.9348891836863416], 
             UndirectedEdge[68, 357] -> 
             RGBColor[
              0.2136408209972711, 0.34188042685150594`, 0.9354779007512986], 
             UndirectedEdge[260, 328] -> 
             RGBColor[
              0.3945437578035354, 0.5155112922725004, 0.9465390105509373], 
             UndirectedEdge[224, 286] -> 
             RGBColor[
              0.2553337614325445, 0.3857023507340823, 0.9378522520299093], 
             UndirectedEdge[219, 293] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[209, 404] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[197, 289] -> 
             RGBColor[
              0.3635203797565897, 0.48928481470478324`, 0.9443841750430078], 
             UndirectedEdge[227, 424] -> 
             RGBColor[
              0.24090488888578881`, 0.3705366908440838, 0.9370305490839757], 
             UndirectedEdge[458, 461] -> 
             RGBColor[
              0.4970083451514102, 0.6025092639396462, 0.9535519644503695], 
             UndirectedEdge[292, 464] -> 
             RGBColor[
              0.24293630539384, 0.37267183839329127`, 0.9371462352488977], 
             UndirectedEdge[386, 441] -> 
             RGBColor[
              0.605869176422092, 0.6857097720212253, 0.9648098337879067], 
             UndirectedEdge[257, 343] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[132, 457] -> 
             RGBColor[
              0.80832544399098, 0.8000236768742133, 0.6266376808278413], 
             UndirectedEdge[69, 259] -> 
             RGBColor[
              0.8720195914369621, 0.405748016840095, 0.23691988196683633`], 
             UndirectedEdge[68, 95] -> 
             RGBColor[
              0.20531946953055227`, 0.3331341588558284, 0.9350040120956051], 
             UndirectedEdge[247, 278] -> 
             RGBColor[
              0.20238002081431636`, 0.33004461188325157`, 0.9348366148397402],
              UndirectedEdge[293, 440] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[307, 442] -> 
             RGBColor[
              0.34067507112051615`, 0.4626107234152569, 0.9431806455540332], 
             UndirectedEdge[406, 493] -> 
             RGBColor[
              0.7916429672985688, 0.8334067531326425, 0.7659846388427745], 
             UndirectedEdge[155, 479] -> 
             RGBColor[
              0.2185280104329565, 0.3470171728141185, 0.935756218959712], 
             UndirectedEdge[311, 488] -> 
             RGBColor[
              0.21049948038445382`, 0.3385786786949364, 0.9352990060505957], 
             UndirectedEdge[226, 345] -> 
             RGBColor[
              0.22193035948375894`, 0.35059325738790115`, 0.9359499777048308],
              UndirectedEdge[183, 273] -> 
             RGBColor[
              0.23550505714349235`, 0.3648611253138234, 0.9367230366545871], 
             UndirectedEdge[384, 499] -> 
             RGBColor[
              0.756352573168234, 0.3274478448111356, 0.4309329969189558], 
             UndirectedEdge[20, 325] -> 
             RGBColor[
              0.44797720589084944`, 0.562001963139723, 0.949885911356462], 
             UndirectedEdge[252, 424] -> 
             RGBColor[
              0.21753234437929125`, 0.3459706646628423, 0.9356995172509117], 
             UndirectedEdge[285, 473] -> 
             RGBColor[
              0.4702957798183204, 0.5776141591822213, 0.9523356104782151], 
             UndirectedEdge[71, 236] -> 
             RGBColor[
              0.2828326524801393, 0.4146054287554984, 0.9394182731941062], 
             UndirectedEdge[2, 446] -> 
             RGBColor[
              0.19992087707942807`, 0.32745989589916574`, 0.9346965702420156],
              UndirectedEdge[33, 351] -> 
             RGBColor[
              0.5099468577737633, 0.6130368578417116, 0.9545640311222917], 
             UndirectedEdge[172, 466] -> 
             RGBColor[
              0.31281244439264955`, 0.4397173887710188, 0.9413598658215745], 
             UndirectedEdge[12, 279] -> 
             RGBColor[
              0.2740454754738125, 0.40536954858264795`, 0.9389178564630594], 
             UndirectedEdge[171, 219] -> 
             RGBColor[
              0.8633448747725185, 0.37637450305087206`, 0.2038017602771198], 
             UndirectedEdge[153, 223] -> 
             RGBColor[
              0.3513959068247321, 0.4784326496880068, 0.9436244499198642], 
             UndirectedEdge[121, 489] -> 
             RGBColor[
              0.2627068012405983, 0.39345188305007095`, 0.9382721357395432], 
             UndirectedEdge[362, 470] -> 
             RGBColor[
              0.21338003115164933`, 0.3416063201887262, 0.9354630491553944], 
             UndirectedEdge[168, 232] -> 
             RGBColor[
              0.7381047575552699, 0.7953323134968859, 0.9745310423181337], 
             UndirectedEdge[285, 409] -> 
             RGBColor[
              0.437803206966903, 0.5512352247677147, 0.9497776761191354], 
             UndirectedEdge[159, 439] -> 
             RGBColor[
              0.3428534925670518, 0.4674674908073133, 0.9432107090214077], 
             UndirectedEdge[156, 263] -> 
             RGBColor[
              0.3245522054854192, 0.45168136141230764`, 0.9420421679776179], 
             UndirectedEdge[149, 314] -> 
             RGBColor[
              0.7707695331053225, 0.5139697191710294, 0.454417376319948], 
             UndirectedEdge[110, 457] -> 
             RGBColor[
              0.9752798562916284, 0.9274780602051496, 0.4262581835303463], 
             UndirectedEdge[43, 263] -> 
             RGBColor[
              0.3916792939201136, 0.5136746508450498, 0.9461784361535572], 
             UndirectedEdge[141, 160] -> 
             RGBColor[
              0.37802184945379874`, 0.5011040622114881, 0.9453453778817297], 
             UndirectedEdge[345, 389] -> 
             RGBColor[
              0.23903484731409955`, 0.3685711585847546, 0.9369240529829466], 
             UndirectedEdge[225, 247] -> 
             RGBColor[
              0.2013053783371785, 0.3289150945035113, 0.9347754155404584], 
             UndirectedEdge[171, 293] -> 
             RGBColor[
              0.8633448747725185, 0.37637450305087206`, 0.2038017602771198], 
             UndirectedEdge[179, 415] -> 
             RGBColor[
              0.22772487631702723`, 0.35668366197325296`, 0.936279966866266], 
             UndirectedEdge[143, 414] -> 
             RGBColor[
              0.8892351625821182, 0.5206084458054662, 0.2940261166931848], 
             UndirectedEdge[77, 388] -> 
             RGBColor[
              0.9318009699728012, 0.9483644297913851, 0.9901540914937574], 
             UndirectedEdge[305, 406] -> 
             RGBColor[
              0.9278221085492989, 0.9409395276057798, 0.778913799948221], 
             UndirectedEdge[55, 256] -> 
             RGBColor[
              0.8509498633138987, 0.5235549531780195, 0.45538444278936224`], 
             UndirectedEdge[367, 450] -> 
             RGBColor[
              0.29858171762156427`, 0.42829285152586705`, 0.9404200917150141],
              UndirectedEdge[171, 258] -> 
             RGBColor[
              0.9746741511548784, 0.925170542447061, 0.43301247003911714`], 
             UndirectedEdge[366, 423] -> 
             RGBColor[
              0.18733252995215482`, 0.31422874492109487`, 0.9339796824959081],
              UndirectedEdge[309, 393] -> 
             RGBColor[
              0.2931834633072552, 0.42005128345340215`, 0.9402066837474136], 
             UndirectedEdge[324, 360] -> 
             RGBColor[
              0.8191009627097754, 0.1478239462483719, 0.1659244095033199], 
             UndirectedEdge[125, 310] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[33, 463] -> 
             RGBColor[
              0.7610323559034178, 0.5268877243816464, 0.4568621548257559], 
             UndirectedEdge[137, 280] -> 
             RGBColor[
              0.43200376365867066`, 0.5461711365359171, 0.9494194420439965], 
             UndirectedEdge[72, 179] -> 
             RGBColor[
              0.2943835934590824, 0.4258364649270654, 0.9401093920557657], 
             UndirectedEdge[17, 165] -> 
             RGBColor[
              0.916100851915751, 0.9340601351245527, 0.9212631098697036], 
             UndirectedEdge[402, 417] -> 
             RGBColor[
              0.30478452951240814`, 0.43365806607358726`, 0.9408155984994631],
              UndirectedEdge[102, 225] -> 
             RGBColor[
              0.23396295286916968`, 0.3632402759464521, 0.9366352160975032], 
             UndirectedEdge[83, 231] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[194, 377] -> 
             RGBColor[
              0.19840694520434524`, 0.3258686575096288, 0.934610354061391], 
             UndirectedEdge[131, 495] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[213, 447] -> 
             RGBColor[
              0.3531568288188625, 0.47758139806423716`, 0.9438236686575876], 
             UndirectedEdge[146, 166] -> 
             RGBColor[
              0.217481006477988, 0.34591670527356166`, 0.9356965936333801], 
             UndirectedEdge[422, 428] -> 
             RGBColor[
              0.25745308354951085`, 0.3879298926517971, 0.9379729442892144], 
             UndirectedEdge[232, 338] -> 
             RGBColor[
              0.8446486517517946, 0.8751856702040267, 0.7354620195671999], 
             UndirectedEdge[366, 469] -> 
             RGBColor[
              0.19196874935401928`, 0.31910170546574246`, 0.9342437083321722],
              UndirectedEdge[245, 482] -> 
             RGBColor[
              0.7095963897113673, 0.7715447220093258, 0.9726142668719193], 
             UndirectedEdge[40, 243] -> 
             RGBColor[
              0.23004423631559218`, 0.35912145638766224`, 0.9364120509869986],
              UndirectedEdge[174, 320] -> 
             RGBColor[
              0.20210480252735952`, 0.3297553400138127, 0.934820941565447], 
             UndirectedEdge[30, 31] -> 
             RGBColor[
              0.20705706276398889`, 0.3349604795139445, 0.9351029654597106], 
             UndirectedEdge[77, 354] -> 
             RGBColor[
              0.9005988329718047, 0.9234846927062367, 0.9871780038121258], 
             UndirectedEdge[24, 223] -> 
             RGBColor[
              0.255646740576453, 0.38603131165835397`, 0.9378700757291438], 
             UndirectedEdge[261, 391] -> 
             RGBColor[
              0.9394746993421814, 0.8968570148384152, 0.6367582455569412], 
             UndirectedEdge[125, 323] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[1, 364] -> 
             RGBColor[
              0.27760199236929234`, 0.4091076733359924, 0.9391203948388616], 
             UndirectedEdge[88, 133] -> 
             RGBColor[
              0.24286224712593307`, 0.37259399845815566`, 0.9371420177400999],
              UndirectedEdge[178, 407] -> 
             RGBColor[
              0.8224905366554676, 0.8110267669512574, 0.6279578355331397], 
             UndirectedEdge[103, 486] -> 
             RGBColor[
              0.9942507028356309, 0.9901111596455525, 0.6156026680867737], 
             UndirectedEdge[204, 486] -> 
             RGBColor[
              0.9371733075375102, 0.9485718429489449, 0.7940666224358858], 
             UndirectedEdge[89, 407] -> 
             RGBColor[
              0.7735280589501026, 0.8233189327675969, 0.9779784683757653], 
             UndirectedEdge[38, 301] -> 
             RGBColor[
              0.8446459694565934, 0.30129340921955317`, 0.18870723798989242`],
              UndirectedEdge[92, 132] -> 
             RGBColor[
              0.6587795986186888, 0.7333628964420915, 0.9666246518110923], 
             UndirectedEdge[8, 146] -> 
             RGBColor[
              0.22136813052518187`, 0.35000231910506174`, 0.935917959597383], 
             UndirectedEdge[44, 110] -> 
             RGBColor[
              0.8465724459995572, 0.877096423635668, 0.7683221349761459], 
             UndirectedEdge[102, 252] -> 
             RGBColor[
              0.2303914914496485, 0.3594864435508025, 0.9364318266531653], 
             UndirectedEdge[273, 283] -> 
             RGBColor[
              0.2039582574481488, 0.3317034386513916, 0.9349264930812451], 
             UndirectedEdge[158, 428] -> 
             RGBColor[
              0.2255068530817244, 0.3543523789221541, 0.9361536537242868], 
             UndirectedEdge[176, 328] -> 
             RGBColor[
              0.6804227732338226, 0.7482541598759991, 0.9703763257599396], 
             UndirectedEdge[45, 398] -> 
             RGBColor[
              0.28571521753888074`, 0.4176351873974164, 0.9395824310098286], 
             UndirectedEdge[233, 275] -> 
             RGBColor[
              0.8560290549644465, 0.34736971536429956`, 0.19791527993518332`],
              UndirectedEdge[250, 485] -> 
             RGBColor[
              0.45702605481315906`, 0.567525512507305, 0.9511018911536404], 
             UndirectedEdge[29, 65] -> 
             RGBColor[
              0.19993601783128978`, 0.32747580978935154`, 0.9346974324854354],
              UndirectedEdge[166, 453] -> 
             RGBColor[
              0.35449001734482477`, 0.47600931341249325`, 0.9440381627421772],
              UndirectedEdge[222, 294] -> 
             RGBColor[
              0.23651889122655595`, 0.36592672921591685`, 0.9367807730057844],
              UndirectedEdge[150, 220] -> 
             RGBColor[
              0.34295836521931666`, 0.47147503118949763`, 0.9430739816589682],
              UndirectedEdge[311, 423] -> 
             RGBColor[
              0.20333007809631276`, 0.3310431823237406, 0.9348907191964662], 
             UndirectedEdge[210, 424] -> 
             RGBColor[
              0.24599797700123366`, 0.37588984937385383`, 0.9373205929176016],
              UndirectedEdge[179, 312] -> 
             RGBColor[
              0.25910450378636, 0.3896656400268162, 0.9380669902286457], 
             UndirectedEdge[310, 323] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[108, 349] -> 
             RGBColor[
              0.25865268956964965`, 0.3889473848332744, 0.9380501710381446], 
             UndirectedEdge[355, 395] -> 
             RGBColor[
              0.8765177108418302, 0.526541145326267, 0.2184266358360574], 
             UndirectedEdge[47, 200] -> 
             RGBColor[
              0.6585502468348285, 0.7325721031757053, 0.967019961408724], 
             UndirectedEdge[152, 217] -> 
             RGBColor[
              0.19534686563322098`, 0.3226523198601263, 0.9344360870567976], 
             UndirectedEdge[174, 210] -> 
             RGBColor[
              0.23308695695256842`, 0.3623195486967552, 0.9365853294259726], 
             UndirectedEdge[135, 211] -> 
             RGBColor[
              0.19965674481685908`, 0.3271822761442531, 0.9346815283004108], 
             UndirectedEdge[52, 491] -> 
             RGBColor[
              0.18704172107166453`, 0.3139230863493516, 0.9339631213603773], 
             UndirectedEdge[41, 250] -> 
             RGBColor[
              0.4813094096913133, 0.5872398339500613, 0.9530135658025085], 
             UndirectedEdge[220, 392] -> 
             RGBColor[
              0.39450251795097435`, 0.5161199856012157, 0.9463583294923248], 
             UndirectedEdge[182, 359] -> 
             RGBColor[
              0.8630442272815448, 0.41127892958154133`, 0.4301162711119909], 
             UndirectedEdge[89, 391] -> 
             RGBColor[
              0.9056677270891382, 0.8699002528296541, 0.6335337063636055], 
             UndirectedEdge[62, 190] -> 
             RGBColor[
              0.4365755592180457, 0.5505194134500824, 0.9496034319333838], 
             UndirectedEdge[21, 87] -> 
             RGBColor[
              0.8381407688879172, 0.873774714658863, 0.9844238088252685], 
             UndirectedEdge[185, 286] -> 
             RGBColor[
              0.26801510124259026`, 0.39793308049680753`, 0.9386146446774454],
              UndirectedEdge[114, 294] -> 
             RGBColor[
              0.2027740482369167, 0.3304587596871861, 0.934859054118546], 
             UndirectedEdge[48, 156] -> 
             RGBColor[
              0.2466062489720914, 0.37652918178189576`, 0.9373552331064843], 
             UndirectedEdge[68, 450] -> 
             RGBColor[
              0.27333525861175023`, 0.40175722238859823`, 0.9389823432231943],
              UndirectedEdge[149, 406] -> 
             RGBColor[
              0.9015895992703974, 0.6146262111363756, 0.3242123165327152], 
             UndirectedEdge[123, 158] -> 
             RGBColor[
              0.22135534676052232`, 0.3499888825578671, 0.9359172315808977], 
             UndirectedEdge[55, 91] -> 
             RGBColor[
              0.8839292021421377, 0.5220528575630985, 0.23151925387136146`], 
             UndirectedEdge[135, 169] -> 
             RGBColor[
              0.19175100981754287`, 0.3188728474074218, 0.9342313083876868], 
             UndirectedEdge[141, 456] -> 
             RGBColor[
              0.2759889604791371, 0.40741227454731044`, 0.9390285350589842], 
             UndirectedEdge[287, 354] -> 
             RGBColor[
              0.8499252860376748, 0.8831713687518833, 0.985547826591175], 
             UndirectedEdge[223, 411] -> 
             RGBColor[
              0.5086318602725991, 0.6065187599425428, 0.9563190333306388], 
             UndirectedEdge[127, 301] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[167, 201] -> 
             RGBColor[
              0.5126223254450143, 0.6152089230256782, 0.9547746537379336], 
             UndirectedEdge[28, 218] -> 
             RGBColor[
              0.8445734030785657, 0.8167427042403248, 0.62639461573298], 
             UndirectedEdge[112, 317] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[275, 372] -> 
             RGBColor[
              0.8560290549644465, 0.3473697153642996, 0.19791527993518332`], 
             UndirectedEdge[85, 146] -> 
             RGBColor[
              0.199363430421074, 0.32687398411707613`, 0.9346648244794907], 
             UndirectedEdge[7, 262] -> 
             RGBColor[
              0.9526458055609902, 0.9083629362681058, 0.6238917173700477], 
             UndirectedEdge[448, 455] -> 
             RGBColor[
              0.8196221020524992, 0.3769784315071223, 0.4371776085700797], 
             UndirectedEdge[9, 368] -> 
             RGBColor[
              0.21159898242802877`, 0.3397343250551897, 0.9353616210654097], 
             UndirectedEdge[216, 399] -> 
             RGBColor[
              0.28648541136230066`, 0.41844470993893956`, 0.9396262924086728],
              UndirectedEdge[205, 474] -> 
             RGBColor[
              0.4259491436308685, 0.5433574722117767, 0.9483620806734884], 
             UndirectedEdge[125, 242] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[280, 338] -> 
             RGBColor[
              0.768013484678197, 0.8137930844785333, 0.728866127012082], 
             UndirectedEdge[232, 393] -> 
             RGBColor[
              0.5318086908857713, 0.627632203960369, 0.9574916912278812], 
             UndirectedEdge[403, 483] -> 
             RGBColor[
              0.8686864922225178, 0.39450469054086185`, 0.22397142092169176`],
              UndirectedEdge[427, 433] -> 
             RGBColor[
              0.19902919731618948`, 0.32652268393223965`, 0.9346457903986212],
              UndirectedEdge[269, 310] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[212, 357] -> 
             RGBColor[
              0.2061419579423609, 0.3339986463254166, 0.9350508515938951], 
             UndirectedEdge[88, 307] -> 
             RGBColor[
              0.2294926966396743, 0.3585417532186373, 0.9363806416183849], 
             UndirectedEdge[212, 217] -> 
             RGBColor[
              0.1904154630441735, 0.3174691030700544, 0.9341552509747078], 
             UndirectedEdge[67, 124] -> 
             RGBColor[
              0.19699158310389825`, 0.32438102220291876`, 0.9345297512836113],
              UndirectedEdge[364, 380] -> 
             RGBColor[
              0.2521693231018657, 0.3823763254115605, 0.9376720419483442], 
             UndirectedEdge[82, 384] -> 
             RGBColor[
              0.7661799454534821, 0.6717707570486016, 0.6004570534353222], 
             UndirectedEdge[222, 439] -> 
             RGBColor[
              0.26180020973842244`, 0.3924989979000629, 0.938220506694676], 
             UndirectedEdge[337, 420] -> 
             RGBColor[
              0.2204438807365078, 0.34903087397634414`, 0.935865324939223], 
             UndirectedEdge[61, 99] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[63, 439] -> 
             RGBColor[
              0.2827106908529987, 0.41447723935255987`, 0.9394113276598666], 
             UndirectedEdge[37, 53] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[39, 62] -> 
             RGBColor[
              0.5172304874360417, 0.6189500365253262, 0.9551374251301208], 
             UndirectedEdge[130, 182] -> 
             RGBColor[
              0.8938442105767532, 0.9177064381503486, 0.9729323850318632], 
             UndirectedEdge[152, 398] -> 
             RGBColor[
              0.24922661523815437`, 0.3792833528683451, 0.9375044590888519], 
             UndirectedEdge[23, 110] -> 
             RGBColor[
              0.993178965010662, 0.9878188208072598, 0.4989506198380761], 
             UndirectedEdge[322, 440] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[141, 432] -> 
             RGBColor[
              0.5362845883584992, 0.627612344125192, 0.9591557710589778], 
             UndirectedEdge[161, 459] -> 
             RGBColor[
              0.2888122033466731, 0.4187677847094263, 0.9398365160322288], 
             UndirectedEdge[185, 333] -> 
             RGBColor[
              0.3691868534914339, 0.4941928294486542, 0.944745237738726], 
             UndirectedEdge[297, 474] -> 
             RGBColor[
              0.3280652758488244, 0.45307847721715644`, 0.9423262759214741], 
             UndirectedEdge[265, 329] -> 
             RGBColor[
              0.19625946576950848`, 0.3236115204655551, 0.9344880582844883], 
             UndirectedEdge[90, 280] -> 
             RGBColor[
              0.5706742857728803, 0.6623381196308499, 0.9593447167062806], 
             UndirectedEdge[183, 430] -> 
             RGBColor[
              0.26651354621858253`, 0.39745301338350436`, 0.9384889242344647],
              UndirectedEdge[86, 194] -> 
             RGBColor[
              0.20814234732009446`, 0.3361011823934266, 0.9351647708096462], 
             UndirectedEdge[143, 186] -> 
             RGBColor[
              0.8305642118064, 0.2359355020328133, 0.17690162978413582`], 
             UndirectedEdge[1, 416] -> 
             RGBColor[
              0.288059981339665, 0.42002691875059733`, 0.9397186260884912], 
             UndirectedEdge[27, 86] -> 
             RGBColor[
              0.20621369612965204`, 0.3340740477087234, 0.9350549369775343], 
             UndirectedEdge[66, 415] -> 
             RGBColor[
              0.22292255775669778`, 0.3516361206817638, 0.9360064819286489], 
             UndirectedEdge[413, 490] -> 
             RGBColor[
              0.37625940773370514`, 0.5003187204563975, 0.9451958946410293], 
             UndirectedEdge[226, 284] -> 
             RGBColor[
              0.25636693278706735`, 0.38678827933453314`, 0.9379110896101094],
              UndirectedEdge[245, 438] -> 
             RGBColor[
              0.3820090099045602, 0.5019364048104593, 0.9458781446689446], 
             UndirectedEdge[53, 163] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[367, 368] -> 
             RGBColor[
              0.2188305697178644, 0.3473351818059234, 0.9357734492633911], 
             UndirectedEdge[112, 175] -> 
             RGBColor[
              0.8764817671983398, 0.42012490000344926`, 0.35471866035020744`],
              UndirectedEdge[277, 288] -> 
             RGBColor[
              0.8718851812720558, 0.40529461979285863`, 0.23639772385740537`],
              UndirectedEdge[249, 323] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[416, 452] -> 
             RGBColor[
              0.3516972330284187, 0.47904419925747455`, 0.9436308145882868], 
             UndirectedEdge[13, 87] -> 
             RGBColor[
              0.6969015731746537, 0.761845924926386, 0.9714278248071031], 
             UndirectedEdge[471, 497] -> 
             RGBColor[
              0.8604026869949277, 0.3647097089386806, 0.20143440692924686`], 
             UndirectedEdge[17, 321] -> 
             RGBColor[
              0.8740328861463312, 0.4191122247550715, 0.39530295688299816`], 
             UndirectedEdge[106, 227] -> 
             RGBColor[
              0.21113051364042446`, 0.3392419346567809, 0.9353349424609931], 
             UndirectedEdge[37, 100] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[9, 375] -> 
             RGBColor[
              0.26223546161822137`, 0.3929564752222947, 0.9382452936453332], 
             UndirectedEdge[10, 302] -> 
             RGBColor[
              0.44096969519954776`, 0.5554209075051166, 0.9495807285208586], 
             UndirectedEdge[14, 272] -> 
             RGBColor[
              0.49012417246760553`, 0.5958729134320023, 0.9532994359632572], 
             UndirectedEdge[63, 387] -> 
             RGBColor[
              0.26044194173333185`, 0.39107137210754717`, 0.9381431553411637],
              UndirectedEdge[471, 483] -> 
             RGBColor[
              0.8686864922225178, 0.39450469054086185`, 0.22397142092169176`],
              UndirectedEdge[46, 392] -> 
             RGBColor[
              0.3638578099509795, 0.48744458852803013`, 0.9444837567475968], 
             UndirectedEdge[122, 357] -> 
             RGBColor[
              0.21418150641244568`, 0.34244872150428973`, 0.9355086919858204],
              UndirectedEdge[75, 125] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[244, 261] -> 
             RGBColor[
              0.9518089599069877, 0.9394744537489581, 0.6794087875044705], 
             UndirectedEdge[7, 178] -> 
             RGBColor[
              0.9550785853817441, 0.8593857666277512, 0.2838738510663188], 
             UndirectedEdge[108, 487] -> 
             RGBColor[
              0.27490256852659056`, 0.40602703791885253`, 0.9389755776052008],
              UndirectedEdge[338, 480] -> 
             RGBColor[
              0.736297626172224, 0.7880447217602409, 0.726369338451474], 
             UndirectedEdge[237, 284] -> 
             RGBColor[
              0.3610780260831915, 0.4862793732675318, 0.9442611375927252], 
             UndirectedEdge[162, 456] -> 
             RGBColor[
              0.22433567464264714`, 0.35312139612568205`, 0.9360869568447846],
              UndirectedEdge[104, 310] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[168, 390] -> 
             RGBColor[
              0.6691221372064833, 0.7401524099458952, 0.9685375862733951], 
             UndirectedEdge[164, 431] -> 
             RGBColor[
              0.9370561323224353, 0.9480386859797506, 0.7584099422192706], 
             UndirectedEdge[57, 60] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[158, 247] -> 
             RGBColor[
              0.2179800536352555, 0.34644123547726713`, 0.9357250136307124], 
             UndirectedEdge[32, 475] -> 
             RGBColor[
              0.6509446795635007, 0.7211864568708418, 0.9633804842819546], 
             UndirectedEdge[53, 293] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[72, 294] -> 
             RGBColor[
              0.2672032018912745, 0.39726815005293875`, 0.938561508965765], 
             UndirectedEdge[87, 287] -> 
             RGBColor[
              0.8461097317603583, 0.8801289493416129, 0.985183895618019], 
             UndirectedEdge[154, 374] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[119, 364] -> 
             RGBColor[
              0.24538499784001913`, 0.3752455694102938, 0.9372856846611919], 
             UndirectedEdge[90, 342] -> 
             RGBColor[
              0.7736445823202994, 0.759776227926813, 0.6195883744105202], 
             UndirectedEdge[401, 428] -> 
             RGBColor[
              0.20185876447098355`, 0.3294967384168478, 0.9348069300621171], 
             UndirectedEdge[183, 477] -> 
             RGBColor[
              0.2584102041277772, 0.38893588706450477`, 0.9380274508902138], 
             UndirectedEdge[82, 269] -> 
             RGBColor[
              0.844192723800754, 0.2992353265545988, 0.18832903870459236`], 
             UndirectedEdge[202, 273] -> 
             RGBColor[
              0.21352690809729225`, 0.3417606971711331, 0.9354714135801638], 
             UndirectedEdge[147, 242] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[117, 198] -> 
             RGBColor[
              0.19641879440682608`, 0.3237789849653949, 0.9344971318146779], 
             UndirectedEdge[240, 434] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[249, 310] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[448, 478] -> 
             RGBColor[
              0.6704836405873918, 0.7406161495613826, 0.969097778591143], 
             UndirectedEdge[121, 196] -> 
             RGBColor[
              0.263514639936199, 0.3943009727390789, 0.9383181409581673], 
             UndirectedEdge[200, 256] -> 
             RGBColor[
              0.7338460782820668, 0.7917597246428272, 0.9744276354785424], 
             UndirectedEdge[79, 184] -> 
             RGBColor[
              0.8369837657282427, 0.2665011316422593, 0.18231370738115665`], 
             UndirectedEdge[51, 240] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[339, 387] -> 
             RGBColor[
              0.20309854147984135`, 0.33079982265955976`, 0.9348775335286859],
              UndirectedEdge[46, 142] -> 
             RGBColor[
              0.31315836829751326`, 0.4435312803958282, 0.9412532331571938], 
             UndirectedEdge[233, 259] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[266, 471] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[167, 456] -> 
             RGBColor[
              0.3541276585075292, 0.4756789204371697, 0.9440129329276471], 
             UndirectedEdge[10, 181] -> 
             RGBColor[
              0.3907137841542735, 0.512838374813811, 0.9461169147250448], 
             UndirectedEdge[31, 429] -> 
             RGBColor[
              0.23508841614603562`, 0.36442320920893145`, 0.9366993095661471],
              UndirectedEdge[317, 322] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[52, 466] -> 
             RGBColor[
              0.21559918239939563`, 0.34393878885242324`, 0.9355894265360134],
              UndirectedEdge[207, 281] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[358, 398] -> 
             RGBColor[
              0.3406430519430609, 0.4683522073597428, 0.9429673660120881], 
             UndirectedEdge[155, 250] -> 
             RGBColor[
              0.3015021013571373, 0.4295372658275264, 0.9406532288863496], 
             UndirectedEdge[243, 285] -> 
             RGBColor[
              0.2946220530898087, 0.4246360657495467, 0.9401761014918839], 
             UndirectedEdge[378, 452] -> 
             RGBColor[
              0.34677922286557283`, 0.4739478228245242, 0.9433480769360816], 
             UndirectedEdge[100, 264] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[81, 130] -> 
             RGBColor[
              0.6412269922816769, 0.7166892321720943, 0.9668997000917505], 
             UndirectedEdge[1, 120] -> 
             RGBColor[
              0.22486057335320775`, 0.3536730979509817, 0.9361168490498329], 
             UndirectedEdge[390, 422] -> 
             RGBColor[
              0.42800433190778703`, 0.5412859490450508, 0.9493162414930003], 
             UndirectedEdge[118, 255] -> 
             RGBColor[
              0.24682926108047093`, 0.37676358164758694`, 0.9373679333161395],
              UndirectedEdge[137, 229] -> 
             RGBColor[
              0.3767837963714482, 0.5007729195378712, 0.9452293082213277], 
             UndirectedEdge[367, 375] -> 
             RGBColor[
              0.269467048908057, 0.40055733197302834`, 0.9386571218433146], 
             UndirectedEdge[230, 382] -> 
             RGBColor[
              0.3091332042875092, 0.4409162668033755, 0.940964847732868], 
             UndirectedEdge[114, 334] -> 
             RGBColor[
              0.20140242887172854`, 0.3290171007686827, 0.9347809424248276], 
             UndirectedEdge[52, 170] -> 
             RGBColor[
              0.2001972733204281, 0.32775040587299065`, 0.9347123105990489], 
             UndirectedEdge[4, 389] -> 
             RGBColor[
              0.2189424973133616, 0.34745282480541034`, 0.9357798233743726], 
             UndirectedEdge[190, 378] -> 
             RGBColor[
              0.3221600885821226, 0.4526239661018675, 0.9417793674693858], 
             UndirectedEdge[89, 328] -> 
             RGBColor[
              0.6679213978740371, 0.7382859025049004, 0.9691839334180138], 
             UndirectedEdge[93, 300] -> 
             RGBColor[
              0.3959649652472733, 0.5173866839445316, 0.9464515153408535], 
             UndirectedEdge[104, 125] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[59, 228] -> 
             RGBColor[
              0.5875720741130268, 0.6760565054420705, 0.9606749725030552], 
             UndirectedEdge[96, 136] -> 
             RGBColor[
              0.9223928943750033, 0.7257736795999382, 0.2561940101384317], 
             UndirectedEdge[332, 420] -> 
             RGBColor[
              0.21514942465501302`, 0.3434660649467891, 0.9355638134978279], 
             UndirectedEdge[40, 283] -> 
             RGBColor[
              0.1993276791914918, 0.3268364073080263, 0.9346627884998552], 
             UndirectedEdge[17, 288] -> 
             RGBColor[
              0.8740328861463312, 0.4191122247550715, 0.39530295688299816`], 
             UndirectedEdge[325, 413] -> 
             RGBColor[
              0.4186353116598318, 0.5370225985623481, 0.9478960497676616], 
             UndirectedEdge[421, 459] -> 
             RGBColor[
              0.22407540206524434`, 0.35284783314459717`, 0.9360721347065403],
              UndirectedEdge[148, 342] -> 
             RGBColor[
              0.8111690714652371, 0.789762270075679, 0.6228692704159253], 
             UndirectedEdge[262, 478] -> 
             RGBColor[
              0.7342949612963621, 0.7910810503283867, 0.9607433486647203], 
             UndirectedEdge[133, 405] -> 
             RGBColor[
              0.22584814988303165`, 0.3547111034997951, 0.9361730900722178], 
             UndirectedEdge[374, 397] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[151, 389] -> 
             RGBColor[
              0.26675818843298676`, 0.3977101478620555, 0.9385028562466593], 
             UndirectedEdge[235, 305] -> 
             RGBColor[
              0.6045891554467802, 0.6839715876022671, 0.9650180629183508], 
             UndirectedEdge[204, 348] -> 
             RGBColor[
              0.9214887091320801, 0.896652428961333, 0.6490868722471982], 
             UndirectedEdge[191, 429] -> 
             RGBColor[
              0.23210680778710222`, 0.3612893497788038, 0.9365295113810002], 
             UndirectedEdge[15, 414] -> 
             RGBColor[
              0.8759899507757182, 0.41879994377265284`, 0.28134248690904895`],
              UndirectedEdge[277, 414] -> 
             RGBColor[
              0.987174698071661, 0.9678878453482673, 0.4481743161496815], 
             UndirectedEdge[317, 440] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[76, 182] -> 
             RGBColor[
              0.9744199384876636, 0.9779480289273386, 0.7939001923006881], 
             UndirectedEdge[199, 376] -> 
             RGBColor[
              0.9885107908455275, 0.9895169310024878, 0.8400694590171756], 
             UndirectedEdge[375, 402] -> 
             RGBColor[
              0.3168704423564799, 0.4463611267638398, 0.9415038733564272], 
             UndirectedEdge[45, 195] -> 
             RGBColor[
              0.2465939110217282, 0.3765162138137928, 0.9373545304784634], 
             UndirectedEdge[149, 269] -> 
             RGBColor[
              0.8427485102135918, 0.3295893587840956, 0.1885693276990594], 
             UndirectedEdge[45, 152] -> 
             RGBColor[
              0.23828164417604697`, 0.36777949433082413`, 0.9368811591784987],
              UndirectedEdge[356, 494] -> 
             RGBColor[
              0.7305244527406208, 0.7874409705960981, 0.9449166497009711], 
             UndirectedEdge[44, 360] -> 
             RGBColor[
              0.7815599699638192, 0.37183086141094573`, 0.43644760020267126`],
              UndirectedEdge[284, 432] -> 
             RGBColor[
              0.5352532867156573, 0.6265283807102642, 0.9590970399560919], 
             UndirectedEdge[151, 237] -> 
             RGBColor[
              0.3543647938987703, 0.4792233405982007, 0.9438788289511594], 
             UndirectedEdge[207, 343] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[33, 371] -> 
             RGBColor[
              0.5535152767239239, 0.6484076630803585, 0.9579938966584256], 
             UndirectedEdge[280, 480] -> 
             RGBColor[
              0.5111171823615002, 0.6139869800645582, 0.9546561633608786], 
             UndirectedEdge[420, 454] -> 
             RGBColor[
              0.2690558886350951, 0.39909292378057587`, 0.9386715027011281], 
             UndirectedEdge[267, 393] -> 
             RGBColor[
              0.3865607689237344, 0.5092412417577328, 0.9458522882669219], 
             UndirectedEdge[337, 427] -> 
             RGBColor[
              0.21714766115220907`, 0.3455663382008537, 0.9356776101102171], 
             UndirectedEdge[267, 480] -> 
             RGBColor[
              0.44250442747306074`, 0.5569886035874154, 0.9496126529550372], 
             UndirectedEdge[234, 336] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[122, 492] -> 
             RGBColor[
              0.2013976738739365, 0.329012102964519, 0.9347806716347378], 
             UndirectedEdge[80, 272] -> 
             RGBColor[
              0.7621819360908365, 0.8135182343885552, 0.9575015284128756], 
             UndirectedEdge[331, 444] -> 
             RGBColor[
              0.8431854304737648, 0.5505961353798073, 0.458803149462244], 
             UndirectedEdge[77, 184] -> 
             RGBColor[
              0.9077974773796862, 0.7427431675399421, 0.6030848086881719], 
             UndirectedEdge[266, 359] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[32, 478] -> 
             RGBColor[
              0.43818467591766874`, 0.5522332471390261, 0.9496175194838028], 
             UndirectedEdge[14, 447] -> 
             RGBColor[
              0.4204684417421174, 0.5386103637038271, 0.9480128551955316], 
             UndirectedEdge[16, 358] -> 
             RGBColor[
              0.5157791642391296, 0.6158365769651228, 0.9555864180950544], 
             UndirectedEdge[50, 323] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[92, 365] -> 
             RGBColor[
              0.4788564599632421, 0.5825948499682702, 0.9534562846389698], 
             UndirectedEdge[296, 438] -> 
             RGBColor[
              0.23711501443590766`, 0.3665532925053399, 0.9368147213406718], 
             UndirectedEdge[181, 422] -> 
             RGBColor[
              0.34276984142818484`, 0.4703062298019115, 0.9430987857933579], 
             UndirectedEdge[35, 428] -> 
             RGBColor[
              0.216766629209909, 0.3451658494706758, 0.9356559109047894], 
             UndirectedEdge[19, 298] -> 
             RGBColor[
              0.4816652548138733, 0.582565445026682, 0.9540882765680275], 
             UndirectedEdge[209, 348] -> 
             RGBColor[
              0.8657911144896757, 0.38473790158096455`, 0.21272342517580606`],
              UndirectedEdge[27, 194] -> 
             RGBColor[
              0.20792633813700911`, 0.33587414304623064`, 0.9351524694062264],
              UndirectedEdge[253, 287] -> 
             RGBColor[
              0.9130361340711288, 0.9314864712143058, 0.9153283035663997], 
             UndirectedEdge[412, 476] -> 
             RGBColor[
              0.2130244917015075, 0.341232625684124, 0.9354428017096823], 
             UndirectedEdge[221, 336] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[146, 248] -> 
             RGBColor[
              0.18429425645727748`, 0.31103532684031304`, 0.9338066573150976],
              UndirectedEdge[17, 455] -> 
             RGBColor[
              0.8740328861463312, 0.4191122247550715, 0.39530295688299816`], 
             UndirectedEdge[102, 393] -> 
             RGBColor[
              0.3174055972642307, 0.4455102820141783, 0.9415860984428273], 
             UndirectedEdge[80, 497] -> 
             RGBColor[
              0.9522798235994274, 0.8970322047585058, 0.6159320363216505], 
             UndirectedEdge[108, 416] -> 
             RGBColor[
              0.3104556295882034, 0.4433227952208202, 0.9410029360855943], 
             UndirectedEdge[8, 453] -> 
             RGBColor[
              0.3583771413920187, 0.4800949272439934, 0.9442595287061802], 
             UndirectedEdge[58, 402] -> 
             RGBColor[
              0.296247822930254, 0.42468544619728427`, 0.9403294456885352], 
             UndirectedEdge[95, 357] -> 
             RGBColor[
              0.21203232772077724`, 0.3401897984335468, 0.9353862994387547], 
             UndirectedEdge[183, 283] -> 
             RGBColor[
              0.2250780320064527, 0.3539016607832171, 0.936129232998434], 
             UndirectedEdge[179, 294] -> 
             RGBColor[
              0.2430012286676811, 0.3727400768704716, 0.9371499325332977], 
             UndirectedEdge[136, 240] -> 
             RGBColor[
              0.8413736303622167, 0.28643448166620133`, 0.18597671803717333`],
              UndirectedEdge[153, 289] -> 
             RGBColor[
              0.3557095315743413, 0.48251945059396417`, 0.9438864747036967], 
             UndirectedEdge[73, 200] -> 
             RGBColor[
              0.7612780109143027, 0.4386064526498009, 0.44502052851949037`], 
             UndirectedEdge[196, 447] -> 
             RGBColor[
              0.33114259091826304`, 0.45444303824740756`, 0.942569990376295], 
             UndirectedEdge[68, 492] -> 
             RGBColor[
              0.20085698845876193`, 0.32844380831173514`, 0.9347498804002159],
              UndirectedEdge[25, 413] -> 
             RGBColor[
              0.5841324927331369, 0.6703403678493413, 0.9619312751079657], 
             UndirectedEdge[220, 426] -> 
             RGBColor[0.281104836605655, 0.409255250700044, 0.93944927859504],
              UndirectedEdge[21, 354] -> 
             RGBColor[
              0.8419563231652338, 0.8768171340691335, 0.9847877397984244], 
             UndirectedEdge[125, 269] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[241, 304] -> 
             RGBColor[
              0.2849583416813991, 0.4139279577846052, 0.9396459398364165], 
             UndirectedEdge[93, 456] -> 
             RGBColor[
              0.31230759322488866`, 0.43956894447911504`, 0.9413171215819914],
              UndirectedEdge[295, 455] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[185, 386] -> 
             RGBColor[
              0.5820600535640958, 0.665087506482939, 0.9632927375329758], 
             UndirectedEdge[233, 400] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[83, 317] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[88, 465] -> 
             RGBColor[
              0.20208905675330635`, 0.3297387902069431, 0.9348200448669085], 
             UndirectedEdge[418, 431] -> 
             RGBColor[
              0.9709979456395686, 0.9110545162255583, 0.4028990400131641], 
             UndirectedEdge[121, 307] -> 
             RGBColor[
              0.263034036910473, 0.393795828487049, 0.9382907713268407], 
             UndirectedEdge[64, 74] -> 
             RGBColor[
              0.2126520838133948, 0.3408412013816937, 0.9354215936313823], 
             UndirectedEdge[185, 358] -> 
             RGBColor[
              0.3526247422114796, 0.4798475610938749, 0.9436899146532672], 
             UndirectedEdge[113, 315] -> 
             RGBColor[
              0.22689683739160005`, 0.3558133405619288, 0.9362328112744367], 
             UndirectedEdge[47, 91] -> 
             RGBColor[
              0.8394327584086407, 0.8339577549161943, 0.643804967945467], 
             UndirectedEdge[158, 401] -> 
             RGBColor[
              0.21032997995216565`, 0.3384005229936534, 0.9352893532517302], 
             UndirectedEdge[90, 232] -> 
             RGBColor[
              0.6473094528464778, 0.7237307053563433, 0.9659406092613985], 
             UndirectedEdge[58, 115] -> 
             RGBColor[
              0.23557088884486138`, 0.36493031860593317`, 0.9367267856725908],
              UndirectedEdge[132, 494] -> 
             RGBColor[
              0.8146351336717644, 0.855457320247522, 0.9517217188764132], 
             UndirectedEdge[167, 300] -> 
             RGBColor[
              0.4377850305299138, 0.5534966599025861, 0.9491473266865091], 
             UndirectedEdge[284, 389] -> 
             RGBColor[
              0.2734714206174079, 0.4047661805313866, 0.9388851648882252], 
             UndirectedEdge[103, 233] -> 
             RGBColor[
              0.8763449551304583, 0.4195592621909958, 0.3199825200895846], 
             UndirectedEdge[172, 300] -> 
             RGBColor[
              0.3980318016520928, 0.519176873756168, 0.946583212328937], 
             UndirectedEdge[70, 76] -> 
             RGBColor[
              0.98996116143335, 0.9893085275125257, 0.7572877100420445], 
             UndirectedEdge[57, 73] -> 
             RGBColor[
              0.8251129096320492, 0.19403440474490768`, 0.17168145666561216`],
              UndirectedEdge[287, 473] -> 
             RGBColor[
              0.7221231818613589, 0.7824402756949027, 0.9732771865815069], 
             UndirectedEdge[395, 443] -> 
             RGBColor[
              0.8336688218049073, 0.7551219636314238, 0.61354871525044], 
             UndirectedEdge[100, 397] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[57, 234] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[343, 403] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[105, 425] -> 
             RGBColor[
              0.22254037357983977`, 0.35123442088000967`, 0.9359847171051676],
              UndirectedEdge[133, 423] -> 
             RGBColor[
              0.22055140940715506`, 0.3491438934269059, 0.935871448537942], 
             UndirectedEdge[92, 494] -> 
             RGBColor[
              0.8135287985254407, 0.8545930428227555, 0.9516114497283175], 
             UndirectedEdge[51, 100] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[6, 347] -> 
             RGBColor[
              0.3086318125417763, 0.4393582479507504, 0.9409740450662951], 
             UndirectedEdge[333, 461] -> 
             RGBColor[
              0.479657645205507, 0.5874809597180408, 0.9524463931924381], 
             UndirectedEdge[291, 394] -> 
             RGBColor[
              0.1976212181124982, 0.32504280851812256`, 0.9345656080658895], 
             UndirectedEdge[143, 386] -> 
             RGBColor[
              0.8392900578031888, 0.4839082552203721, 0.450473845405273], 
             UndirectedEdge[123, 437] -> 
             RGBColor[
              0.20027511058254266`, 0.32783221777064053`, 0.9347167433159764],
              UndirectedEdge[72, 453] -> 
             RGBColor[
              0.3882337150931953, 0.510566344050778, 0.9459931262706142], 
             UndirectedEdge[391, 478] -> 
             RGBColor[
              0.7346414386946734, 0.7340552109266808, 0.6178863226320354], 
             UndirectedEdge[328, 464] -> 
             RGBColor[
              0.37866041293742014`, 0.4991210978524166, 0.9456233390095045], 
             UndirectedEdge[149, 173] -> 
             RGBColor[
              0.8427485102135918, 0.3295893587840956, 0.1885693276990594], 
             UndirectedEdge[54, 186] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[355, 444] -> 
             RGBColor[
              0.8548719206901274, 0.42277520421909437`, 0.2001787192628237], 
             UndirectedEdge[7, 448] -> 
             RGBColor[
              0.88883448485202, 0.8578980355011018, 0.6322461472964704], 
             UndirectedEdge[47, 416] -> 
             RGBColor[
              0.5121004622842857, 0.6097734708911251, 0.95656961228473], 
             UndirectedEdge[48, 155] -> 
             RGBColor[
              0.23482099816692198`, 0.3641421359576038, 0.936684080507846], 
             UndirectedEdge[346, 486] -> 
             RGBColor[
              0.9885470027218867, 0.9720400729158498, 0.4940557447733985], 
             UndirectedEdge[24, 491] -> 
             RGBColor[
              0.19844777773507763`, 0.3259115750883605, 0.93461267941361], 
             UndirectedEdge[321, 373] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[209, 231] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[210, 393] -> 
             RGBColor[
              0.30896553356423473`, 0.43663923993453624`, 0.9411054493010679],
              UndirectedEdge[188, 409] -> 
             RGBColor[
              0.4608023334373177, 0.5711559121466802, 0.9512431601205011], 
             UndirectedEdge[307, 427] -> 
             RGBColor[
              0.22293489534478472`, 0.35164908826909147`, 0.9360071845360386],
              UndirectedEdge[178, 186] -> 
             RGBColor[
              0.8637848357389819, 0.37797025225822195`, 0.20492941108331195`],
              UndirectedEdge[328, 475] -> 
             RGBColor[
              0.7096551131254042, 0.7713940703337429, 0.9672995144845954], 
             UndirectedEdge[213, 337] -> 
             RGBColor[
              0.250968758002199, 0.38111445537158695`, 0.9376036715419951], 
             UndirectedEdge[384, 458] -> 
             RGBColor[
              0.5434356286207753, 0.6402010241853623, 0.9572068902738209], 
             UndirectedEdge[87, 473] -> 
             RGBColor[
              0.7302983499153326, 0.788958932792116, 0.9740569414085536], 
             UndirectedEdge[112, 440] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[237, 429] -> 
             RGBColor[
              0.32902794882158914`, 0.4525927099733213, 0.9424359331065173], 
             UndirectedEdge[109, 230] -> 
             RGBColor[
              0.31288969270847855`, 0.4441699482670213, 0.9412042078533198], 
             UndirectedEdge[89, 262] -> 
             RGBColor[
              0.905321249690827, 0.92692609223136, 0.9763907323962904], 
             UndirectedEdge[280, 383] -> 
             RGBColor[
              0.5876838324912708, 0.6761472359281866, 0.9606837705319751], 
             UndirectedEdge[196, 489] -> 
             RGBColor[
              0.23441451862430046`, 0.36371490018601704`, 0.9366609320992263],
              UndirectedEdge[279, 459] -> 
             RGBColor[
              0.27500306633600013`, 0.4063760372935745, 0.9389723898460322], 
             UndirectedEdge[191, 423] -> 
             RGBColor[
              0.20464821144403264`, 0.3324286240466755, 0.9349657849406153], 
             UndirectedEdge[116, 165] -> 
             RGBColor[
              0.7645854413092009, 0.8162193268874823, 0.9771172884853815], 
             UndirectedEdge[176, 313] -> 
             RGBColor[
              0.9308645267408745, 0.9466209785289019, 0.9555065870493364], 
             UndirectedEdge[180, 490] -> 
             RGBColor[
              0.4726781530538206, 0.5797540945256074, 0.9524662916581652], 
             UndirectedEdge[17, 498] -> 
             RGBColor[
              0.8740328861463312, 0.4191122247550715, 0.39530295688299816`], 
             UndirectedEdge[108, 364] -> 
             RGBColor[
              0.29999764061783074`, 0.4324035498062153, 0.9404047048359647], 
             UndirectedEdge[29, 254] -> 
             RGBColor[
              0.219858689201137, 0.34841580056938304`, 0.935831999146997], 
             UndirectedEdge[7, 261] -> 
             RGBColor[
              0.9399230799294223, 0.8986346944528518, 0.6371190231022803], 
             UndirectedEdge[122, 224] -> 
             RGBColor[
              0.25163511157756463`, 0.38181483522855314`, 0.9376416193923304],
              UndirectedEdge[116, 386] -> 
             RGBColor[
              0.7639631876081299, 0.8157231586768751, 0.9770579373718808], 
             UndirectedEdge[8, 439] -> 
             RGBColor[
              0.2626279467019643, 0.3933690019303001, 0.9382676450902228], 
             UndirectedEdge[226, 488] -> 
             RGBColor[
              0.20402766147053647`, 0.33177638667939024`, 0.9349304455376461],
              UndirectedEdge[64, 170] -> 
             RGBColor[
              0.2105590287411936, 0.3386412677934538, 0.9353023972414181], 
             UndirectedEdge[178, 313] -> 
             RGBColor[
              0.9673256290864539, 0.9243605553414638, 0.6042935618647849], 
             UndirectedEdge[81, 251] -> 
             RGBColor[
              0.4506348367930976, 0.5647389788898851, 0.9499350312130843], 
             UndirectedEdge[186, 288] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[45, 118] -> 
             RGBColor[
              0.2554591373040128, 0.3858341287242849, 0.9378593920003125], 
             UndirectedEdge[224, 330] -> 
             RGBColor[
              0.2600393493307347, 0.39064822196658494`, 0.9381202282994179], 
             UndirectedEdge[35, 410] -> 
             RGBColor[
              0.2048653084706884, 0.3326568067864372, 0.934978148295117], 
             UndirectedEdge[163, 379] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[181, 443] -> 
             RGBColor[
              0.5695192678995484, 0.6579480039591199, 0.9608880248523786], 
             UndirectedEdge[167, 235] -> 
             RGBColor[
              0.40241813704526735`, 0.5228636343579377, 0.9468937795073835], 
             UndirectedEdge[202, 279] -> 
             RGBColor[
              0.25837662777741854`, 0.38890059619141426`, 0.9380255387667326],
              UndirectedEdge[242, 310] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[299, 482] -> 
             RGBColor[
              0.6975160835754234, 0.7617373852765769, 0.9716632609212784], 
             UndirectedEdge[56, 110] -> 
             RGBColor[
              0.9942182188017068, 0.9900416795816283, 0.6120669814623443], 
             UndirectedEdge[125, 419] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[262, 448] -> 
             RGBColor[
              0.8880396268664679, 0.9131461952883709, 0.9747423957838162], 
             UndirectedEdge[95, 212] -> 
             RGBColor[
              0.19782060647564204`, 0.3252523783297391, 0.9345769629382018], 
             UndirectedEdge[32, 260] -> 
             RGBColor[
              0.3358333242416319, 0.46530367880959933`, 0.9426199803482964], 
             UndirectedEdge[421, 430] -> 
             RGBColor[
              0.2393158270696491, 0.3688664861229826, 0.9369400543643528], 
             UndirectedEdge[129, 346] -> 
             RGBColor[
              0.871715025393385, 0.8835314226277342, 0.6825874912808683], 
             UndirectedEdge[16, 17] -> 
             RGBColor[
              0.8171965358160596, 0.8565952297054558, 0.9114583528675545], 
             UndirectedEdge[153, 466] -> 
             RGBColor[
              0.32275440531108784`, 0.44832861562108495`, 0.9419933587799665],
              UndirectedEdge[244, 391] -> 
             RGBColor[
              0.9648781629368668, 0.8921768561625062, 0.323324455739553], 
             UndirectedEdge[218, 406] -> 
             RGBColor[
              0.8668298092779636, 0.8929538809350525, 0.7729243520835001], 
             UndirectedEdge[99, 288] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[399, 481] -> 
             RGBColor[
              0.29801585957910287`, 0.4305639420874404, 0.9402829343768502], 
             UndirectedEdge[278, 451] -> 
             RGBColor[
              0.24719400766817687`, 0.37714695343753535`, 0.9373887050947152],
              UndirectedEdge[179, 327] -> 
             RGBColor[
              0.23500467222293953`, 0.364335189036086, 0.9366945404736147], 
             UndirectedEdge[38, 473] -> 
             RGBColor[
              0.7528058541930568, 0.6634482434020327, 0.5999179731708593], 
             UndirectedEdge[17, 176] -> 
             RGBColor[
              0.9356274804823903, 0.9496301387073782, 0.9231255771340168], 
             UndirectedEdge[186, 373] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[399, 496] -> 
             RGBColor[
              0.2561178705712659, 0.3865264991542693, 0.937896905885374], 
             UndirectedEdge[116, 358] -> 
             RGBColor[
              0.5345278762555137, 0.6304832132878109, 0.9574551144921722], 
             UndirectedEdge[71, 135] -> 
             RGBColor[
              0.2217446900292419, 0.3503981070190804, 0.9359394041040694], 
             UndirectedEdge[53, 374] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[228, 409] -> 
             RGBColor[
              0.5569548786168692, 0.6512000868493509, 0.9582646747191151], 
             UndirectedEdge[440, 471] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[403, 471] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[63, 166] -> 
             RGBColor[
              0.275068039384163, 0.4064443280867228, 0.938976089965006], 
             UndirectedEdge[159, 272] -> 
             RGBColor[
              0.4928488984890493, 0.5982329341630651, 0.953473053095963], 
             UndirectedEdge[130, 351] -> 
             RGBColor[
              0.6463531647474265, 0.72096106746608, 0.9672728087793628], 
             UndirectedEdge[113, 378] -> 
             RGBColor[
              0.2776267210047927, 0.4091336646997893, 0.9391218030980706], 
             UndirectedEdge[145, 417] -> 
             RGBColor[
              0.28299968789977625`, 0.4147809935721941, 0.9394277856141477], 
             UndirectedEdge[38, 354] -> 
             RGBColor[
              0.8806079583693727, 0.7641793364590133, 0.6121886131805274], 
             UndirectedEdge[334, 446] -> 
             RGBColor[
              0.20565132116996215`, 0.33348295596945743`, 0.9350229105555391],
              UndirectedEdge[305, 310] -> 
             RGBColor[
              0.8321466499760604, 0.3869651660515733, 0.4383722111318249], 
             UndirectedEdge[338, 383] -> 
             RGBColor[
              0.8128642763019948, 0.8502049776238694, 0.7323969456225705], 
             UndirectedEdge[243, 477] -> 
             RGBColor[
              0.257579961556534, 0.3880632494817088, 0.9379801698040153], 
             UndirectedEdge[38, 221] -> 
             RGBColor[
              0.8446459694565934, 0.30129340921955317`, 0.18870723798989242`],
              UndirectedEdge[330, 357] -> 
             RGBColor[
              0.22258574416561577`, 0.35128210824232153`, 0.9359873008929078],
              UndirectedEdge[48, 365] -> 
             RGBColor[
              0.2630799821961634, 0.393844119895409, 0.9382933878428907], 
             UndirectedEdge[384, 411] -> 
             RGBColor[
              0.673364501803413, 0.7446351140079177, 0.9681614906767982], 
             UndirectedEdge[38, 436] -> 
             RGBColor[
              0.9344998640366943, 0.8062744916611889, 0.5869300975227473], 
             UndirectedEdge[117, 155] -> 
             RGBColor[
              0.22121121154755882`, 0.34983738731034214`, 0.9359090232937483],
              UndirectedEdge[68, 286] -> 
             RGBColor[
              0.21116729807720058`, 0.3392805974321006, 0.9353370372802498], 
             UndirectedEdge[378, 380] -> 
             RGBColor[
              0.25770930190939245`, 0.38819919439321504`, 0.9379875355457686],
              UndirectedEdge[12, 285] -> 
             RGBColor[
              0.28914299431124585`, 0.4188772275808861, 0.9398640771999859], 
             UndirectedEdge[93, 432] -> 
             RGBColor[
              0.5726032211042509, 0.6597690140569965, 0.961444357581985], 
             UndirectedEdge[340, 499] -> 
             RGBColor[
              0.872096562596627, 0.418030146437691, 0.414793028650732], 
             UndirectedEdge[389, 456] -> 
             RGBColor[
              0.24930916567101583`, 0.3793701186072822, 0.937509160213881], 
             UndirectedEdge[390, 451] -> 
             RGBColor[
              0.4248740733662101, 0.5379958488479989, 0.94913797789986], 
             UndirectedEdge[92, 485] -> 
             RGBColor[
              0.6061214293900224, 0.6908811127102437, 0.9622956395712158], 
             UndirectedEdge[293, 471] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[111, 359] -> 
             RGBColor[
              0.8730579162973663, 0.4187090496669422, 0.41146073042143505`], 
             UndirectedEdge[357, 441] -> 
             RGBColor[
              0.29429774702065686`, 0.4211551754544992, 0.9402726044034251], 
             UndirectedEdge[52, 268] -> 
             RGBColor[
              0.19710983178549013`, 0.32450530906467123`, 0.9345364853710946],
              UndirectedEdge[30, 311] -> 
             RGBColor[
              0.20275732105733557`, 0.3304411783608819, 0.9348581015304145], 
             UndirectedEdge[164, 486] -> 
             RGBColor[
              0.9373839117496703, 0.9487397730310224, 0.7940867100536502], 
             UndirectedEdge[194, 290] -> 
             RGBColor[
              0.19998987236326368`, 0.3275324143170307, 0.9347004994213606], 
             UndirectedEdge[238, 445] -> 
             RGBColor[
              0.857059891141737, 0.3514566373014637, 0.19874471492026624`], 
             UndirectedEdge[269, 406] -> 
             RGBColor[
              0.8761600890568056, 0.41916385235227993`, 0.29986098883365586`],
              UndirectedEdge[99, 341] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[41, 457] -> 
             RGBColor[
              0.7799506296404679, 0.7772562145851217, 0.6242203432368331], 
             UndirectedEdge[217, 292] -> 
             RGBColor[
              0.1972518591229097, 0.32465458880135256`, 0.93454457361785], 
             UndirectedEdge[176, 299] -> 
             RGBColor[
              0.6712865587841526, 0.7408369694039865, 0.9696570894914054], 
             UndirectedEdge[218, 314] -> 
             RGBColor[
              0.6705997100303512, 0.7419691429870332, 0.9682319417643492], 
             UndirectedEdge[355, 486] -> 
             RGBColor[
              0.9025631372122566, 0.6216242602355779, 0.3345764630246274], 
             UndirectedEdge[213, 420] -> 
             RGBColor[
              0.24872595585540894`, 0.3787571281134413, 0.9374759472776638], 
             UndirectedEdge[299, 407] -> 
             RGBColor[
              0.5735216905682538, 0.6639465563931397, 0.9600496665900575], 
             UndirectedEdge[201, 314] -> 
             RGBColor[
              0.5845834032200327, 0.6736301677730485, 0.9604396933824965], 
             UndirectedEdge[160, 300] -> 
             RGBColor[
              0.43648566488694934`, 0.5524417763378724, 0.9490450358633619], 
             UndirectedEdge[21, 200] -> 
             RGBColor[
              0.7122146064560578, 0.7745113761794283, 0.9723644063851347], 
             UndirectedEdge[25, 180] -> 
             RGBColor[
              0.6805512380532523, 0.7497757419185513, 0.9692016721251016], 
             UndirectedEdge[45, 185] -> 
             RGBColor[
              0.2976969078072994, 0.42913054113154847`, 0.9403049796510078], 
             UndirectedEdge[191, 226] -> 
             RGBColor[
              0.22140390405308463`, 0.35003991935106027`, 0.935919996846875], 
             UndirectedEdge[50, 82] -> 
             RGBColor[
              0.844192723800754, 0.2992353265545987, 0.18832903870459236`], 
             UndirectedEdge[22, 491] -> 
             RGBColor[
              0.19092580831177908`, 0.31800550830406665`, 0.9341843143827098],
              UndirectedEdge[99, 277] -> 
             RGBColor[
              0.8718851812720558, 0.40529461979285863`, 0.23639772385740537`],
              UndirectedEdge[17, 391] -> 
             RGBColor[
              0.970002280405527, 0.9193210457585888, 0.5690733922205091], 
             UndirectedEdge[211, 362] -> 
             RGBColor[
              0.19802212087574567`, 0.325464182740999, 0.934588438885174], 
             UndirectedEdge[4, 162] -> 
             RGBColor[
              0.19396900628499292`, 0.32120410232381014`, 0.9343576200052762],
              UndirectedEdge[259, 444] -> 
             RGBColor[
              0.8285562969045, 0.22050178822288907`, 0.17497884820646079`], 
             UndirectedEdge[347, 382] -> 
             RGBColor[
              0.30305610597028676`, 0.43452885116168694`, 0.9406187659739635],
              UndirectedEdge[66, 179] -> 
             RGBColor[
              0.26537930167515955`, 0.3962608504531091, 0.9384243306856812], 
             UndirectedEdge[343, 471] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[97, 322] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[363, 381] -> 
             RGBColor[
              0.2070518443671499, 0.33495499464800116`, 0.9351026682797305], 
             UndirectedEdge[238, 471] -> 
             RGBColor[
              0.857059891141737, 0.3514566373014637, 0.19874471492026624`], 
             UndirectedEdge[40, 285] -> 
             RGBColor[
              0.269701942846091, 0.39844344985715197`, 0.9387569380795036], 
             UndirectedEdge[70, 208] -> 
             RGBColor[
              0.9892910387748346, 0.9878752029057549, 0.6843489941803045], 
             UndirectedEdge[84, 448] -> 
             RGBColor[
              0.7514898127927288, 0.8058231255251804, 0.9758560360026285], 
             UndirectedEdge[152, 195] -> 
             RGBColor[
              0.21010530872100186`, 0.3381643792847215, 0.9352765585574867], 
             UndirectedEdge[93, 308] -> 
             RGBColor[
              0.30216970138459465`, 0.4289133773754982, 0.9407397836393536], 
             UndirectedEdge[255, 478] -> 
             RGBColor[
              0.38712473452348783`, 0.5032706196539489, 0.9465374726015883], 
             UndirectedEdge[112, 293] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[87, 184] -> 
             RGBColor[
              0.86529909849953, 0.7089485006828021, 0.6022343862942678], 
             UndirectedEdge[149, 323] -> 
             RGBColor[
              0.8427485102135918, 0.3295893587840956, 0.1885693276990594], 
             UndirectedEdge[272, 497] -> 
             RGBColor[
              0.7564721734761921, 0.7423611564460912, 0.6174367128789657], 
             UndirectedEdge[80, 471] -> 
             RGBColor[
              0.8642091954046907, 0.41214776090032323`, 0.42814428395185355`],
              UndirectedEdge[339, 344] -> 
             RGBColor[
              0.20608159129440537`, 0.33393519715094877`, 0.9350474138025986],
              UndirectedEdge[137, 393] -> 
             RGBColor[
              0.3443442466033714, 0.47267541198794205`, 0.9431622887952733], 
             UndirectedEdge[11, 316] -> 
             RGBColor[
              0.9867175484992736, 0.9766529954342503, 0.6283033308879433], 
             UndirectedEdge[88, 423] -> 
             RGBColor[
              0.20241340429212143`, 0.33007970003505943`, 0.9348385159794148],
              UndirectedEdge[70, 351] -> 
             RGBColor[
              0.7225448589609941, 0.7801979166455426, 0.9196407548248287], 
             UndirectedEdge[55, 298] -> 
             RGBColor[
              0.7891203983542464, 0.4750093414495175, 0.4492866000375796], 
             UndirectedEdge[428, 437] -> 
             RGBColor[
              0.20442661690374475`, 0.33219571413492754`, 0.9349531654593657],
              UndirectedEdge[90, 137] -> 
             RGBColor[
              0.45984500856407784`, 0.5687739133839165, 0.9516112068287906], 
             UndirectedEdge[344, 439] -> 
             RGBColor[
              0.24709777481850334`, 0.37704580661101333`, 0.9373832247762901],
              UndirectedEdge[93, 274] -> 
             RGBColor[
              0.4288787771490915, 0.545063574926054, 0.948778472238694], 
             UndirectedEdge[60, 434] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[54, 244] -> 
             RGBColor[
              0.8706168078338911, 0.40101609835768304`, 0.23147033256236077`],
              UndirectedEdge[243, 318] -> 
             RGBColor[
              0.257982887562488, 0.3884867502609507, 0.9380031158439788], 
             UndirectedEdge[384, 402] -> 
             RGBColor[
              0.493323693614111, 0.5967965847816775, 0.9540138020874405], 
             UndirectedEdge[83, 233] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[153, 201] -> 
             RGBColor[
              0.4828110574856316, 0.5895003637293261, 0.9528440323387535], 
             UndirectedEdge[275, 331] -> 
             RGBColor[
              0.880471837443817, 0.8195704114474931, 0.6243590994767585], 
             UndirectedEdge[312, 327] -> 
             RGBColor[
              0.22392755577381057`, 0.35269243731830396`, 0.9360637150789621],
              UndirectedEdge[181, 370] -> 
             RGBColor[
              0.39544611839331145`, 0.5169372848776308, 0.9464184548781174], 
             UndirectedEdge[32, 245] -> 
             RGBColor[
              0.4212849020662287, 0.5385132494002911, 0.9482871073803061], 
             UndirectedEdge[176, 391] -> 
             RGBColor[
              0.9181691024489237, 0.8798685102007529, 0.6347260987055314], 
             UndirectedEdge[148, 232] -> 
             RGBColor[
              0.6848339419914155, 0.7537167475052093, 0.9692215052668037], 
             UndirectedEdge[430, 477] -> 
             RGBColor[
              0.26829891864456346`, 0.39932955300236017`, 0.9385905985529026],
              UndirectedEdge[7, 475] -> 
             RGBColor[
              0.9478498229277461, 0.9047861002729332, 0.6320100649755263], 
             UndirectedEdge[15, 50] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[168, 395] -> 
             RGBColor[
              0.84803720063224, 0.7663466503750598, 0.6149808209718142], 
             UndirectedEdge[97, 440] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[71, 308] -> 
             RGBColor[
              0.24523893977810896`, 0.3750920531266102, 0.9372773668706396], 
             UndirectedEdge[253, 436] -> 
             RGBColor[
              0.9789187620697407, 0.9831427029239654, 0.8912134737088222], 
             UndirectedEdge[13, 430] -> 
             RGBColor[
              0.4079602536351721, 0.5224454613676528, 0.9479720355331471], 
             UndirectedEdge[209, 233] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[254, 350] -> 
             RGBColor[
              0.21360194576422215`, 0.3418395665167393, 0.9354756868642873], 
             UndirectedEdge[115, 268] -> 
             RGBColor[
              0.22078326587035477`, 0.3493875892702776, 0.9358846524205204], 
             UndirectedEdge[42, 468] -> 
             RGBColor[
              0.3202366373459297, 0.4484035479636482, 0.9417503367363287], 
             UndirectedEdge[51, 60] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[331, 348] -> 
             RGBColor[
              0.8951149267316608, 0.8756226907724907, 0.6465713173376927], 
             UndirectedEdge[310, 406] -> 
             RGBColor[
              0.8761600890568056, 0.41916385235227993`, 0.29986098883365586`],
              UndirectedEdge[70, 130] -> 
             RGBColor[
              0.9093854335224396, 0.9290669367355356, 0.9363199027732196], 
             UndirectedEdge[83, 440] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[100, 374] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[207, 374] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[51, 324] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[164, 180] -> 
             RGBColor[
              0.7420798659697871, 0.7983328217384686, 0.9752041209037695], 
             UndirectedEdge[56, 132] -> 
             RGBColor[
              0.8272638065010585, 0.8625872962506922, 0.8124464787598393], 
             UndirectedEdge[30, 423] -> 
             RGBColor[
              0.17952980953436626`, 0.3060275910409509, 0.9335353291112054], 
             UndirectedEdge[104, 379] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[324, 457] -> 
             RGBColor[
              0.8638009847389825, 0.3780247266271895, 0.20499214689883155`], 
             UndirectedEdge[283, 459] -> 
             RGBColor[
              0.2197263215188342, 0.34827667374268706`, 0.9358244610033103], 
             UndirectedEdge[128, 245] -> 
             RGBColor[
              0.3639482041295633, 0.48295335281971236`, 0.9448496084986262], 
             UndirectedEdge[34, 62] -> 
             RGBColor[
              0.4183440898877315, 0.5346740747422846, 0.9484437217570646], 
             UndirectedEdge[320, 424] -> 
             RGBColor[
              0.2150158225760247, 0.3433256406909113, 0.935556205057076], 
             UndirectedEdge[111, 351] -> 
             RGBColor[
              0.7220241695390399, 0.7799825981884567, 0.9282699260476386], 
             UndirectedEdge[79, 316] -> 
             RGBColor[
              0.8735231410973765, 0.4108198428949215, 0.24276088847601782`], 
             UndirectedEdge[43, 250] -> 
             RGBColor[
              0.3804144405970011, 0.5039176010845604, 0.9454606496609272], 
             UndirectedEdge[116, 313] -> 
             RGBColor[
              0.8311822940909279, 0.8682327058496676, 0.945708059179992], 
             UndirectedEdge[87, 436] -> 
             RGBColor[
              0.9119923597589701, 0.9317851810512723, 0.9610690657604415], 
             UndirectedEdge[280, 393] -> 
             RGBColor[
              0.4551735238121738, 0.5662396182348755, 0.9508957986727633], 
             UndirectedEdge[295, 321] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[131, 186] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[165, 313] -> 
             RGBColor[
              0.9113378981742353, 0.9310509749460764, 0.9536441197850233], 
             UndirectedEdge[140, 270] -> 
             RGBColor[
              0.18167152053006663`, 0.3082786650897521, 0.933657296384033], 
             UndirectedEdge[322, 445] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[112, 463] -> 
             RGBColor[
              0.831998657058118, 0.24386491747293382`, 0.17815401051060936`], 
             UndirectedEdge[115, 223] -> 
             RGBColor[
              0.26791411799790454`, 0.39892510312495144`, 0.9385686847253369],
              UndirectedEdge[102, 451] -> 
             RGBColor[
              0.2794536000934562, 0.411053830452799, 0.9392258411595447], 
             UndirectedEdge[148, 267] -> 
             RGBColor[
              0.5395860200293785, 0.6353257853025731, 0.9575821023058444], 
             UndirectedEdge[447, 500] -> 
             RGBColor[
              0.3505102887658151, 0.47479971666815324`, 0.9436729521167717], 
             UndirectedEdge[238, 293] -> 
             RGBColor[
              0.857059891141737, 0.3514566373014637, 0.19874471492026624`], 
             UndirectedEdge[56, 457] -> 
             RGBColor[
              0.9757033167270259, 0.9283837992580474, 0.47234923862849276`], 
             UndirectedEdge[204, 331] -> 
             RGBColor[
              0.8538682923947138, 0.8863154149909298, 0.9859239140574727], 
             UndirectedEdge[66, 260] -> 
             RGBColor[
              0.2863066273900213, 0.4179525885520823, 0.9396272494745492], 
             UndirectedEdge[225, 424] -> 
             RGBColor[
              0.22110380579881245`, 0.3497244970584919, 0.9359029066952498], 
             UndirectedEdge[178, 244] -> 
             RGBColor[
              0.9669644653593094, 0.9002255259238574, 0.326163615468509], 
             UndirectedEdge[139, 247] -> 
             RGBColor[
              0.19836393844048342`, 0.3258234546740237, 0.9346079048898119], 
             UndirectedEdge[244, 448] -> 
             RGBColor[
              0.9007203648295853, 0.898737794797208, 0.6745359116986607], 
             UndirectedEdge[259, 275] -> 
             RGBColor[
              0.8560290549644465, 0.34736971536429956`, 0.19791527993518332`],
              UndirectedEdge[282, 406] -> 
             RGBColor[
              0.8761600890568056, 0.41916385235227993`, 0.29986098883365586`],
              UndirectedEdge[286, 357] -> 
             RGBColor[
              0.21788015626742555`, 0.3463362370098189, 0.9357193246233994], 
             UndirectedEdge[206, 396] -> 
             RGBColor[
              0.2219991302915197, 0.35066553986717874`, 0.9359538941005956], 
             UndirectedEdge[154, 295] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[410, 428] -> 
             RGBColor[
              0.20513431686132172`, 0.3329395516611099, 0.9349934679250014], 
             UndirectedEdge[104, 147] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[32, 255] -> 
             RGBColor[
              0.3085704354238704, 0.43695286219157675`, 0.941056260613344], 
             UndirectedEdge[165, 498] -> 
             RGBColor[
              0.8264596817975027, 0.3824305319946304, 0.43782978303013764`], 
             UndirectedEdge[248, 439] -> 
             RGBColor[
              0.22555407263405997`, 0.35440200966555135`, 0.9361563428079372],
              UndirectedEdge[141, 389] -> 
             RGBColor[
              0.27450272226024985`, 0.40585014394631425`, 0.9389438959911109],
              UndirectedEdge[328, 478] -> 
             RGBColor[
              0.4968951094795723, 0.6024408606019271, 0.9535365496864436], 
             UndirectedEdge[178, 261] -> 
             RGBColor[
              0.9415610017646239, 0.9049056845997665, 0.6395974052858973], 
             UndirectedEdge[120, 315] -> 
             RGBColor[
              0.19068570408703148`, 0.3177531435403698, 0.9341706408023127], 
             UndirectedEdge[47, 136] -> 
             RGBColor[
              0.8020754049028471, 0.684036360935029, 0.600844615682085], 
             UndirectedEdge[74, 144] -> 
             RGBColor[
              0.23865380323456642`, 0.36817065709757524`, 0.9369023530863214],
              UndirectedEdge[165, 361] -> 
             RGBColor[
              0.6271981599055898, 0.7041410688188706, 0.9661885994129014], 
             UndirectedEdge[32, 482] -> 
             RGBColor[
              0.64794186446319, 0.7189469622856886, 0.9684634669871719], 
             UndirectedEdge[67, 119] -> 
             RGBColor[
              0.194730591149065, 0.3220045763032192, 0.9344009911366213], 
             UndirectedEdge[97, 326] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[409, 430] -> 
             RGBColor[
              0.4088644575244336, 0.5231795348188764, 0.9480432177755177], 
             UndirectedEdge[113, 190] -> 
             RGBColor[
              0.30008982406307977`, 0.4294267187567612, 0.9405224985550569], 
             UndirectedEdge[292, 496] -> 
             RGBColor[
              0.20710059025010286`, 0.3350062296616523, 0.9351054442856517], 
             UndirectedEdge[15, 82] -> 
             RGBColor[
              0.844192723800754, 0.2992353265545987, 0.18832903870459236`], 
             UndirectedEdge[340, 414] -> 
             RGBColor[
              0.9874917700585177, 0.9869911353155156, 0.7157672733396714], 
             UndirectedEdge[149, 282] -> 
             RGBColor[
              0.8427485102135918, 0.3295893587840956, 0.1885693276990594], 
             UndirectedEdge[330, 368] -> 
             RGBColor[
              0.202529033876395, 0.3302012340594701, 0.9348451009131806], 
             UndirectedEdge[331, 431] -> 
             RGBColor[
              0.9104717457098559, 0.9268410177088308, 0.7558742996920007], 
             UndirectedEdge[4, 488] -> 
             RGBColor[
              0.1922517191621101, 0.319399124675368, 0.9342598230441267], 
             UndirectedEdge[87, 409] -> 
             RGBColor[
              0.6978057770639152, 0.7625799983776096, 0.9714990070494738], 
             UndirectedEdge[440, 445] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[55, 200] -> 
             RGBColor[
              0.7633408610929295, 0.4544624230694392, 0.44699591618019946`], 
             UndirectedEdge[64, 215] -> 
             RGBColor[
              0.20458807963597442`, 0.33236542170382943`, 0.9349623605231034],
              UndirectedEdge[167, 493] -> 
             RGBColor[
              0.5234517902759379, 0.624000770437253, 0.9556271888790606], 
             UndirectedEdge[153, 470] -> 
             RGBColor[
              0.32216778334016727`, 0.44771203873566623`, 0.941959951526552], 
             UndirectedEdge[185, 187] -> 
             RGBColor[
              0.3439018393873985, 0.4722922210934996, 0.943134098998677], 
             UndirectedEdge[18, 310] -> 
             RGBColor[
              0.7962722946032341, 0.358714514364911, 0.4348563870006418], 
             UndirectedEdge[226, 366] -> 
             RGBColor[
              0.20408822256120682`, 0.33184004022547964`, 0.9349338944021677],
              UndirectedEdge[333, 361] -> 
             RGBColor[
              0.4137027061318567, 0.5327502235739785, 0.9475817485051508], 
             UndirectedEdge[236, 300] -> 
             RGBColor[
              0.361908596774024, 0.4876077971989662, 0.9442917614214452], 
             UndirectedEdge[161, 335] -> 
             RGBColor[
              0.32336695487389533`, 0.45450593624120883`, 0.9418256343157618],
              UndirectedEdge[61, 397] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[393, 480] -> 
             RGBColor[
              0.4234576653062009, 0.5404912555165833, 0.9483990101121553], 
             UndirectedEdge[349, 378] -> 
             RGBColor[
              0.25281205566812764`, 0.38305187809030017`, 0.9377086446171552],
              UndirectedEdge[97, 163] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[229, 267] -> 
             RGBColor[
              0.4190003186918113, 0.5373387493076619, 0.9479193076929763], 
             UndirectedEdge[77, 287] -> 
             RGBColor[
              0.8886081106405144, 0.9139236161987528, 0.9860343180119231], 
             UndirectedEdge[41, 485] -> 
             RGBColor[
              0.5788529501858339, 0.6689779278459186, 0.9599885711283033], 
             UndirectedEdge[7, 89] -> 
             RGBColor[
              0.9061161076763791, 0.8716779324440909, 0.6338944839089447], 
             UndirectedEdge[41, 44] -> 
             RGBColor[
              0.6512432193483967, 0.7268745780156403, 0.9662842946826327], 
             UndirectedEdge[147, 234] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[259, 331] -> 
             RGBColor[
              0.8207108366647649, 0.37784655893402913`, 0.4372814530493224], 
             UndirectedEdge[77, 409] -> 
             RGBColor[
              0.7403041559440713, 0.7963746652347496, 0.9723494294433779], 
             UndirectedEdge[2, 334] -> 
             RGBColor[
              0.20734715427896283`, 0.33526538408904644`, 0.9351194857423364],
              UndirectedEdge[315, 487] -> 
             RGBColor[
              0.21833205101187592`, 0.3468112070380179, 0.9357450593605774], 
             UndirectedEdge[251, 258] -> 
             RGBColor[
              0.7229805531619574, 0.7777005783665802, 0.766539139108648], 
             UndirectedEdge[39, 96] -> 
             RGBColor[
              0.7306179728698792, 0.7351380902552997, 0.6185709577425946], 
             UndirectedEdge[219, 497] -> 
             RGBColor[
              0.8604026869949277, 0.3647097089386806, 0.20143440692924686`], 
             UndirectedEdge[447, 454] -> 
             RGBColor[
              0.37348676159854866`, 0.49791719373137167`, 0.9450192240810519],
              UndirectedEdge[417, 458] -> 
             RGBColor[
              0.3548964645190724, 0.477062505477272, 0.9440086866858435], 
             UndirectedEdge[189, 422] -> 
             RGBColor[
              0.41564195559551864`, 0.5312496150360451, 0.9483430299448219], 
             UndirectedEdge[431, 444] -> 
             RGBColor[
              0.8985035876174724, 0.5916330293176362, 0.30711377649159965`], 
             UndirectedEdge[161, 273] -> 
             RGBColor[
              0.2730441392759877, 0.4021945496181309, 0.9389385481101638], 
             UndirectedEdge[109, 413] -> 
             RGBColor[
              0.37066616576114175`, 0.49547413538427865`, 0.9448394982084473],
              UndirectedEdge[236, 470] -> 
             RGBColor[
              0.27610261754366017`, 0.40753173532839826`, 0.9390350076606682],
              UndirectedEdge[287, 436] -> 
             RGBColor[
              0.9038171917049964, 0.925266523954059, 0.9602893109333949], 
             UndirectedEdge[253, 473] -> 
             RGBColor[
              0.7972247522261032, 0.8403164546648092, 0.9042013493569341], 
             UndirectedEdge[166, 435] -> 
             RGBColor[
              0.3502789983611274, 0.4724858600150052, 0.9437356009830916], 
             UndirectedEdge[114, 312] -> 
             RGBColor[
              0.21887732335559562`, 0.3473843228435307, 0.9357761118138941], 
             UndirectedEdge[222, 296] -> 
             RGBColor[
              0.22518419086516983`, 0.35401324047458915`, 0.9361352785883901],
              UndirectedEdge[5, 346] -> 
             RGBColor[
              0.8725424883879621, 0.4075118710378607, 0.23895123788066785`], 
             UndirectedEdge[86, 220] -> 
             RGBColor[
              0.2767001990541243, 0.4046256973632345, 0.9391984410025577], 
             UndirectedEdge[195, 255] -> 
             RGBColor[
              0.2379640347981863, 0.3674456667370949, 0.9368630717942905], 
             UndirectedEdge[313, 407] -> 
             RGBColor[
              0.8330996585249757, 0.8697305655180553, 0.9458991641479886], 
             UndirectedEdge[224, 441] -> 
             RGBColor[
              0.33175135218577584`, 0.46052128917876256`, 0.942405531809935], 
             UndirectedEdge[172, 211] -> 
             RGBColor[
              0.29686791214582525`, 0.42295867443787283`, 0.9404518482979395],
              UndirectedEdge[204, 355] -> 
             RGBColor[
              0.8646089820506718, 0.5941398003894627, 0.4641583607120223], 
             UndirectedEdge[109, 180] -> 
             RGBColor[
              0.4670849110812572, 0.5749095094534886, 0.9521098952255831], 
             UndirectedEdge[96, 157] -> 
             RGBColor[
              0.886514879220424, 0.8590158099428777, 0.6326804478109045], 
             UndirectedEdge[316, 372] -> 
             RGBColor[
              0.8735231410973765, 0.41081984289492157`, 0.24276088847601784`],
              UndirectedEdge[53, 112] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[28, 305] -> 
             RGBColor[
              0.905565702349901, 0.8647283509110522, 0.6323840635977009], 
             UndirectedEdge[186, 341] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[65, 86] -> 
             RGBColor[
              0.2018366701530856, 0.3294735158878764, 0.9348056718233985], 
             UndirectedEdge[10, 390] -> 
             RGBColor[
              0.4759482746338757, 0.5838180940569503, 0.9523343704246872], 
             UndirectedEdge[48, 140] -> 
             RGBColor[
              0.20271183825122668`, 0.33039337304788496`, 0.9348555113518924],
              UndirectedEdge[231, 404] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[87, 354] -> 
             RGBColor[
              0.8581004540916486, 0.8896900258490967, 0.9863275814182217], 
             UndirectedEdge[136, 434] -> 
             RGBColor[
              0.8413736303622167, 0.28643448166620133`, 0.18597671803717333`],
              UndirectedEdge[205, 413] -> 
             RGBColor[
              0.4278594550620529, 0.5450120879584244, 0.9484838040286614], 
             UndirectedEdge[20, 490] -> 
             RGBColor[
              0.40560130196472277`, 0.5252980850337723, 0.9471857562298298], 
             UndirectedEdge[390, 443] -> 
             RGBColor[
              0.6547537583791506, 0.7289277232022592, 0.967105480552021], 
             UndirectedEdge[296, 385] -> 
             RGBColor[
              0.19170031260162856`, 0.3188195614191067, 0.9342284212562402], 
             UndirectedEdge[86, 290] -> 
             RGBColor[
              0.1982772303559066, 0.32573231897952337`, 0.9346029669926684], 
             UndirectedEdge[24, 74] -> 
             RGBColor[
              0.2136963850560424, 0.34193882820023935`, 0.9354810650422459], 
             UndirectedEdge[38, 336] -> 
             RGBColor[
              0.8446459694565934, 0.30129340921955317`, 0.18870723798989242`],
              UndirectedEdge[383, 443] -> 
             RGBColor[
              0.6919520032781376, 0.7591269341730926, 0.9700338626521301], 
             UndirectedEdge[14, 435] -> 
             RGBColor[
              0.431666942251965, 0.5483099419924558, 0.9487264137455738], 
             UndirectedEdge[282, 323] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[307, 337] -> 
             RGBColor[
              0.2284739170758735, 0.35747095130272755`, 0.9363226236293758], 
             UndirectedEdge[157, 356] -> 
             RGBColor[
              0.6546957163401086, 0.7278640901242467, 0.9677959060323847], 
             UndirectedEdge[166, 439] -> 
             RGBColor[
              0.2587408226547705, 0.38928338809880003`, 0.9380462791262197], 
             UndirectedEdge[266, 293] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[2, 260] -> 
             RGBColor[
              0.2568264909268206, 0.3869670959806497, 0.9379483993149236], 
             UndirectedEdge[135, 466] -> 
             RGBColor[
              0.21560127706368337`, 0.34394099047739907`, 0.935589545824046], 
             UndirectedEdge[60, 495] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[217, 464] -> 
             RGBColor[
              0.23458513566205164`, 0.3638942295104385, 0.936670648487121], 
             UndirectedEdge[435, 453] -> 
             RGBColor[
              0.4536708445200175, 0.5672446965945355, 0.9501627222939097], 
             UndirectedEdge[82, 411] -> 
             RGBColor[
              0.805124727752193, 0.7023163366231125, 0.604255553355253], 
             UndirectedEdge[94, 193] -> 
             RGBColor[
              0.18322775270743138`, 0.3099143637789815, 0.9337459215042947], 
             UndirectedEdge[88, 469] -> 
             RGBColor[
              0.20704962369398588`, 0.33495266057970696`, 0.9351025418156791],
              UndirectedEdge[36, 76] -> 
             RGBColor[
              0.8763277317102309, 0.4195224230366844, 0.31810785708846784`], 
             UndirectedEdge[163, 326] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[151, 472] -> 
             RGBColor[
              0.24137502669719502`, 0.37103083549233057`, 0.9370573227368286],
              UndirectedEdge[114, 138] -> 
             RGBColor[
              0.19260410669659306`, 0.3197695063167697, 0.9342798909929049], 
             UndirectedEdge[448, 475] -> 
             RGBColor[
              0.8832436442332238, 0.9095693592931984, 0.9828607433892947], 
             UndirectedEdge[169, 362] -> 
             RGBColor[
              0.19011638587642943`, 0.3171547540041677, 0.9341382189724496], 
             UndirectedEdge[20, 25] -> 
             RGBColor[
              0.6134743869641546, 0.6953197324267161, 0.9639211366967662], 
             UndirectedEdge[113, 349] -> 
             RGBColor[
              0.23074179114908483`, 0.35985463074519386`, 0.9364517757028261],
              UndirectedEdge[457, 494] -> 
             RGBColor[
              0.9630746438977319, 0.9212538232548773, 0.6116244787450666], 
             UndirectedEdge[364, 452] -> 
             RGBColor[
              0.34123924405804607`, 0.4681249538428697, 0.9430325833386572], 
             UndirectedEdge[351, 442] -> 
             RGBColor[
              0.4533007905792821, 0.5668798964178177, 0.9501513769419208], 
             UndirectedEdge[71, 466] -> 
             RGBColor[
              0.25381484638134433`, 0.3841058747104944, 0.937765752064777], 
             UndirectedEdge[87, 285] -> 
             RGBColor[
              0.5942823297173198, 0.6753028328289313, 0.9642423195147274], 
             UndirectedEdge[211, 369] -> 
             RGBColor[
              0.20403104555369495`, 0.33177994356535306`, 0.9349306382561757],
              UndirectedEdge[164, 316] -> 
             RGBColor[
              0.9332973532557916, 0.9359432710143458, 0.6941631548152802], 
             UndirectedEdge[27, 297] -> 
             RGBColor[
              0.2276449517133472, 0.3565996561472727, 0.9362754152783243], 
             UndirectedEdge[238, 483] -> 
             RGBColor[
              0.9539815750463821, 0.8506879917634884, 0.30563820376293704`], 
             UndirectedEdge[109, 164] -> 
             RGBColor[
              0.6056683283309234, 0.6842577010589471, 0.9653854185243207], 
             UndirectedEdge[83, 355] -> 
             RGBColor[
              0.8304768118928137, 0.23526370799810264`, 0.17681793552818148`],
              UndirectedEdge[85, 166] -> 
             RGBColor[
              0.23298059512902075`, 0.36220775567647745`, 0.9365792722774698],
              UndirectedEdge[34, 190] -> 
             RGBColor[
              0.32639172231009544`, 0.4570716814510417, 0.9420203527500528], 
             UndirectedEdge[232, 383] -> 
             RGBColor[
              0.6643189995648684, 0.7375398216536801, 0.9672796630870929], 
             UndirectedEdge[185, 441] -> 
             RGBColor[
              0.3444326919958216, 0.4727520189414878, 0.9431679244574711], 
             UndirectedEdge[83, 207] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[138, 385] -> 
             RGBColor[
              0.19286507142269105`, 0.32004379679001804`, 0.9342947525479934],
              UndirectedEdge[131, 234] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[80, 81] -> 
             RGBColor[
              0.7036249157342768, 0.7658688297445426, 0.9529221476556539], 
             UndirectedEdge[5, 486] -> 
             RGBColor[
              0.8762475134266291, 0.4193508442393725, 0.30937659196826445`], 
             UndirectedEdge[94, 139] -> 
             RGBColor[
              0.18683641908668117`, 0.31370730094623644`, 0.9339514297160496],
              UndirectedEdge[126, 249] -> 
             RGBColor[
              0.8563654629268306, 0.3487034608338446, 0.19818596167822738`], 
             UndirectedEdge[359, 483] -> 
             RGBColor[
              0.8686864922225178, 0.39450469054086185`, 0.22397142092169176`],
              UndirectedEdge[275, 404] -> 
             RGBColor[
              0.8560290549644465, 0.3473697153642996, 0.19791527993518332`], 
             UndirectedEdge[313, 391] -> 
             RGBColor[
              0.9652393266640114, 0.9163118855801125, 0.6014544021358288], 
             UndirectedEdge[1, 487] -> 
             RGBColor[
              0.25250692027805216`, 0.38273116144862973`, 0.9376912676080977],
              UndirectedEdge[71, 172] -> 
             RGBColor[
              0.3189558573582081, 0.44617450531270014`, 0.941709724101598], 
             UndirectedEdge[44, 494] -> 
             RGBColor[
              0.8343672336056607, 0.8708721866853958, 0.9536884301908661], 
             UndirectedEdge[85, 387] -> 
             RGBColor[
              0.2183544974781896, 0.34683479969730174`, 0.9357463376536275], 
             UndirectedEdge[414, 499] -> 
             RGBColor[
              0.8759899507757182, 0.41879994377265295`, 0.28134248690904895`],
              UndirectedEdge[89, 376] -> 
             RGBColor[
              0.9224099806388508, 0.9393657454586876, 0.9338012207586489], 
             UndirectedEdge[171, 403] -> 
             RGBColor[
              0.8633448747725185, 0.37637450305087206`, 0.2038017602771198], 
             UndirectedEdge[161, 279] -> 
             RGBColor[
              0.317893858956114, 0.449334448638412, 0.9414926732967325], 
             UndirectedEdge[149, 310] -> 
             RGBColor[
              0.8427485102135918, 0.3295893587840956, 0.1885693276990594], 
             UndirectedEdge[333, 367] -> 
             RGBColor[
              0.33758550933585824`, 0.46207597552121615`, 0.9429053788333501],
              UndirectedEdge[43, 227] -> 
             RGBColor[
              0.3207886255080345, 0.4459380263401525, 0.9418932895024263], 
             UndirectedEdge[71, 369] -> 
             RGBColor[
              0.22611899076607778`, 0.3549957744401804, 0.9361885140598343], 
             UndirectedEdge[134, 174] -> 
             RGBColor[
              0.2085506805802597, 0.33653036653968427`, 0.9351880247847377], 
             UndirectedEdge[158, 370] -> 
             RGBColor[
              0.31860057599581953`, 0.44346473230432215`, 0.9417750365635871],
              UndirectedEdge[7, 391] -> 
             RGBColor[
              0.9529922829593014, 0.8513370968664, 0.28103469133736275`], 
             UndirectedEdge[200, 228] -> 
             RGBColor[
              0.5875078389354265, 0.6760043564311329, 0.9606699156745733], 
             UndirectedEdge[201, 300] -> 
             RGBColor[
              0.49294744284977277`, 0.5982799912622034, 0.9534899138509028], 
             UndirectedEdge[210, 320] -> 
             RGBColor[
              0.21943490594638596`, 0.34797037749922943`, 0.9358078653175701],
              UndirectedEdge[69, 103] -> 
             RGBColor[
              0.9879088198511304, 0.969706918546636, 0.5069176030846314], 
             UndirectedEdge[97, 281] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[192, 272] -> 
             RGBColor[
              0.7182850173642144, 0.7790908357882066, 0.973243723195778], 
             UndirectedEdge[70, 463] -> 
             RGBColor[
              0.9027643566949051, 0.6383284302508672, 0.43357997062744724`], 
             UndirectedEdge[285, 477] -> 
             RGBColor[
              0.2972376680870329, 0.4273852429511985, 0.9403250568965202], 
             UndirectedEdge[10, 168] -> 
             RGBColor[
              0.5869322775232643, 0.6718097968709896, 0.962514131755837], 
             UndirectedEdge[298, 468] -> 
             RGBColor[
              0.5240878676490316, 0.621638460430029, 0.9567061435487108], 
             UndirectedEdge[37, 264] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[191, 405] -> 
             RGBColor[
              0.20994495191990925`, 0.33799583411956474`, 0.9352674264748911],
              UndirectedEdge[349, 380] -> 
             RGBColor[
              0.2108243720536846, 0.3389201604386196, 0.9353175081505242], 
             UndirectedEdge[94, 410] -> 
             RGBColor[
              0.18607999806105058`, 0.3129122544884356, 0.9339083526576646], 
             UndirectedEdge[335, 409] -> 
             RGBColor[
              0.42817878404725107`, 0.5428990333722734, 0.9491644164012382], 
             UndirectedEdge[168, 189] -> 
             RGBColor[
              0.6567597608942148, 0.7301160759368894, 0.967564374725217], 
             UndirectedEdge[187, 399] -> 
             RGBColor[
              0.3354088495669978, 0.4644637127266185, 0.9426102266869426], 
             UndirectedEdge[153, 314] -> 
             RGBColor[
              0.499609722940791, 0.6031382771170792, 0.9541664848189226], 
             UndirectedEdge[233, 355] -> 
             RGBColor[
              0.8304768118928137, 0.23526370799810264`, 0.17681793552818148`],
              UndirectedEdge[233, 486] -> 
             RGBColor[
              0.8762475134266291, 0.4193508442393725, 0.30937659196826445`], 
             UndirectedEdge[49, 264] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[205, 331] -> 
             RGBColor[
              0.6362772310192553, 0.7125979853621729, 0.9664940818172649], 
             UndirectedEdge[308, 456] -> 
             RGBColor[
              0.24065751204960906`, 0.3702766821046615, 0.9370164613391165], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.5070562614150484, 0.6082812369647475, 0.955030602440464], 
             UndirectedEdge[175, 371] -> 
             RGBColor[
              0.7707283648406607, 0.8174771789318643, 0.846586686476931], 
             UndirectedEdge[21, 188] -> 
             RGBColor[
              0.6011373252613197, 0.6823506284279337, 0.9641679618962959], 
             UndirectedEdge[79, 221] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[158, 193] -> 
             RGBColor[
              0.21075328698888462`, 0.3388454455284614, 0.9353134599612447], 
             UndirectedEdge[266, 483] -> 
             RGBColor[
              0.8686864922225178, 0.39450469054086185`, 0.22397142092169176`],
              UndirectedEdge[290, 484] -> 
             RGBColor[
              0.19720039887588448`, 0.3246005008189609, 0.9345416430329105], 
             UndirectedEdge[153, 411] -> 
             RGBColor[
              0.5550733306542569, 0.6470945833278928, 0.9592654071859543], 
             UndirectedEdge[176, 475] -> 
             RGBColor[
              0.9130266424173684, 0.933317513607286, 0.9857014723436948], 
             UndirectedEdge[20, 474] -> 
             RGBColor[
              0.4380905408797232, 0.5534386308253174, 0.9492559418043877], 
             UndirectedEdge[70, 483] -> 
             RGBColor[
              0.9784993022017803, 0.9517819287687919, 0.6160830557918804], 
             UndirectedEdge[163, 266] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[69, 486] -> 
             RGBColor[
              0.9877626572953866, 0.9693942916192012, 0.4910087109026512], 
             UndirectedEdge[262, 475] -> 
             RGBColor[
              0.947054964942194, 0.9600342600602023, 0.974506313462872], 
             UndirectedEdge[18, 167] -> 
             RGBColor[
              0.6058193984674288, 0.6891575673803969, 0.9632826137877326], 
             UndirectedEdge[281, 374] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[138, 294] -> 
             RGBColor[
              0.20565089555954957`, 0.33348250862592854`, 0.9350228863176557],
              UndirectedEdge[291, 349] -> 
             RGBColor[
              0.20137038883349692`, 0.32898342465704544`, 0.9347791177920493],
              UndirectedEdge[288, 455] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[12, 459] -> 
             RGBColor[
              0.24496381986437168`, 0.3748028846536623, 0.9372616991985556], 
             UndirectedEdge[93, 305] -> 
             RGBColor[
              0.6178108662440276, 0.6954235689523357, 0.9658605386388516], 
             UndirectedEdge[127, 184] -> 
             RGBColor[
              0.8369837657282427, 0.2665011316422593, 0.18231370738115665`], 
             UndirectedEdge[204, 431] -> 
             RGBColor[
              0.9368455281102752, 0.9478707558976731, 0.7583898546015062], 
             UndirectedEdge[397, 495] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[28, 493] -> 
             RGBColor[
              0.7693865610991708, 0.7571955764379148, 0.6194549024922544], 
             UndirectedEdge[267, 485] -> 
             RGBColor[
              0.48008856319913695`, 0.5875010981158637, 0.9525714137946194], 
             UndirectedEdge[110, 494] -> 
             RGBColor[
              0.9815895459724128, 0.9829117035784583, 0.7513422215789181], 
             UndirectedEdge[337, 500] -> 
             RGBColor[
              0.24832221794915155`, 0.378332773975503, 0.9374529550011792], 
             UndirectedEdge[43, 393] -> 
             RGBColor[
              0.3844301868161192, 0.5073958386222868, 0.9457165294590244], 
             UndirectedEdge[167, 432] -> 
             RGBColor[
              0.6144232863868914, 0.6958789900150512, 0.9641401689276407], 
             UndirectedEdge[230, 474] -> 
             RGBColor[
              0.3509721735960423, 0.4771550791306852, 0.9436307898604598], 
             UndirectedEdge[40, 421] -> 
             RGBColor[
              0.20367675973790192`, 0.33140756670993643`, 0.9349104622030852],
              UndirectedEdge[254, 476] -> 
             RGBColor[
              0.217706390843879, 0.3461535985323073, 0.9357094289395913], 
             UndirectedEdge[107, 197] -> 
             RGBColor[
              0.36643102917791126`, 0.4918058729400383, 0.9445696390503481], 
             UndirectedEdge[231, 395] -> 
             RGBColor[
              0.8502020870562027, 0.32426772933006165`, 0.19322676477969444`],
              UndirectedEdge[420, 427] -> 
             RGBColor[
              0.21490485900541903`, 0.34320901094270806`, 0.9355498858458859],
              UndirectedEdge[317, 374] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[188, 200] -> 
             RGBColor[
              0.49135529375587494`, 0.5959601817284621, 0.9536484010759594], 
             UndirectedEdge[84, 260] -> 
             RGBColor[
              0.49539379554658625`, 0.5968284122357694, 0.9548594497480263], 
             UndirectedEdge[33, 160] -> 
             RGBColor[
              0.507621153600386, 0.6111487464219849, 0.9543809431704284], 
             UndirectedEdge[135, 362] -> 
             RGBColor[
              0.18189649677046751`, 0.30851512938273096`, 0.9336701084481014],
              UndirectedEdge[123, 193] -> 
             RGBColor[
              0.19813056518650046`, 0.32557816458736866`, 0.9345946146282424],
              UndirectedEdge[439, 453] -> 
             RGBColor[
              0.3621326688136605, 0.48404222467833025`, 0.9444734004370379], 
             UndirectedEdge[269, 282] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[202, 459] -> 
             RGBColor[
              0.22929497216797767`, 0.3583339322624286, 0.9363693815022289], 
             UndirectedEdge[25, 474] -> 
             RGBColor[
              0.5822221813019526, 0.6686857521026937, 0.9618095517527927], 
             UndirectedEdge[103, 259] -> 
             RGBColor[
              0.8763449551304583, 0.4195592621909958, 0.3199825200895846], 
             UndirectedEdge[352, 375] -> 
             RGBColor[
              0.23983670688281394`, 0.3694139638323065, 0.93696971769914], 
             UndirectedEdge[300, 308] -> 
             RGBColor[
              0.3243148840719937, 0.448094421570078, 0.9421508550979786], 
             UndirectedEdge[32, 328] -> 
             RGBColor[
              0.41834081037995485`, 0.5361231031395549, 0.9480553376981994], 
             UndirectedEdge[209, 486] -> 
             RGBColor[
              0.8762475134266291, 0.4193508442393725, 0.30937659196826445`], 
             UndirectedEdge[118, 496] -> 
             RGBColor[
              0.22237308988837995`, 0.35105859511388676`, 0.9359751905464131],
              UndirectedEdge[31, 405] -> 
             RGBColor[
              0.21292656027884266`, 0.3411296935496924, 0.9354372246600381], 
             UndirectedEdge[21, 228] -> 
             RGBColor[
              0.6972898704408712, 0.7623948031306045, 0.9711894764949098], 
             UndirectedEdge[92, 250] -> 
             RGBColor[
              0.5085778888955018, 0.6091430188143863, 0.955320634245421], 
             UndirectedEdge[177, 290] -> 
             RGBColor[
              0.19627542028787323`, 0.3236282896759313, 0.9344889668707066], 
             UndirectedEdge[9, 333] -> 
             RGBColor[
              0.3303539220460226, 0.4544751187704825, 0.9424935506353687], 
             UndirectedEdge[11, 444] -> 
             RGBColor[
              0.8965218183778059, 0.5918677305070236, 0.41658702852886603`], 
             UndirectedEdge[11, 25] -> 
             RGBColor[
              0.8725548505464009, 0.8998336579439141, 0.9166173714965022], 
             UndirectedEdge[168, 338] -> 
             RGBColor[
              0.8866500342923964, 0.9079974694670752, 0.7396483248536112], 
             UndirectedEdge[283, 430] -> 
             RGBColor[
              0.23496674652323896`, 0.3642953267210725, 0.9366923806611228], 
             UndirectedEdge[139, 410] -> 
             RGBColor[
              0.1939894171477317, 0.3212255554346721, 0.9343587823737141], 
             UndirectedEdge[195, 260] -> 
             RGBColor[
              0.2652269236159478, 0.3957964833551174, 0.9384267915292429], 
             UndirectedEdge[391, 407] -> 
             RGBColor[
              0.8204042342330249, 0.8029780971899061, 0.6251186758041836], 
             UndirectedEdge[33, 111] -> 
             RGBColor[
              0.7724584371268222, 0.8209274086540813, 0.9322402963389583], 
             UndirectedEdge[2, 114] -> 
             RGBColor[
              0.19567198478119446`, 0.322994040698391, 0.934454602111304], 
             UndirectedEdge[101, 306] -> 
             RGBColor[
              0.4767634885101116, 0.5860971037797296, 0.9519517147391703], 
             UndirectedEdge[264, 374] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[172, 235] -> 
             RGBColor[
              0.36266490816744634`, 0.48854384821151947`, 0.9443296651498113],
              UndirectedEdge[84, 475] -> 
             RGBColor[
              0.810505150868455, 0.8527111902970119, 0.9756199536816843], 
             UndirectedEdge[37, 397] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[228, 287] -> 
             RGBColor[
              0.7052588333133122, 0.7687490378133541, 0.9719495632876605], 
             UndirectedEdge[68, 375] -> 
             RGBColor[
              0.24422058989824297`, 0.3740217028357595, 0.9372193733514949], 
             UndirectedEdge[197, 236] -> 
             RGBColor[
              0.3595830595921312, 0.48559353377690795`, 0.9441435802486068], 
             UndirectedEdge[107, 214] -> 
             RGBColor[
              0.26772635198284234`, 0.39774243808019455`, 0.9385940687930483],
              UndirectedEdge[207, 317] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[98, 462] -> 
             RGBColor[
              0.22311090923146282`, 0.35183409002391514`, 0.9360172082664957],
              UndirectedEdge[21, 59] -> 
             RGBColor[
              0.7122788416336581, 0.774563525190366, 0.9723694632136166], 
             UndirectedEdge[46, 350] -> 
             RGBColor[
              0.23789809529541878`, 0.3673763601388803, 0.9368593166371566], 
             UndirectedEdge[271, 429] -> 
             RGBColor[
              0.26979559865762076`, 0.4009026585910771, 0.9386758322655065], 
             UndirectedEdge[304, 423] -> 
             RGBColor[
              0.20489033009065757`, 0.3326831060954871, 0.9349795732393582], 
             UndirectedEdge[299, 328] -> 
             RGBColor[
              0.4679150294921883, 0.5789135261304432, 0.9512551316323059], 
             UndirectedEdge[55, 73] -> 
             RGBColor[
              0.8427635790747743, 0.32970518465436127`, 0.1885837576575456], 
             UndirectedEdge[53, 440] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[206, 377] -> 
             RGBColor[
              0.18614606825835553`, 0.31298169845489565`, 0.9339121152576589],
              UndirectedEdge[39, 113] -> 
             RGBColor[
              0.3807447522810758, 0.4978573418320051, 0.9460564917517937], 
             UndirectedEdge[9, 450] -> 
             RGBColor[
              0.29135013033172863`, 0.4206919947751334, 0.9400082635170326], 
             UndirectedEdge[61, 321] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[76, 460] -> 
             RGBColor[
              0.9094586655152967, 0.9266343620675013, 0.8045085958817066], 
             UndirectedEdge[141, 167] -> 
             RGBColor[
              0.3793212150967632, 0.5021589457762018, 0.945447668704877], 
             UndirectedEdge[29, 476] -> 
             RGBColor[
              0.20047610231188778`, 0.3280434728217939, 0.934728189497622], 
             UndirectedEdge[39, 190] -> 
             RGBColor[
              0.4252781198584057, 0.5413476432340834, 0.948714056123109], 
             UndirectedEdge[115, 215] -> 
             RGBColor[
              0.21789975830007355`, 0.3463568399889726, 0.93572044093016], 
             UndirectedEdge[208, 471] -> 
             RGBColor[
              0.8758809832712207, 0.41856687329883735`, 0.26948204651397445`],
              UndirectedEdge[139, 401] -> 
             RGBColor[
              0.19071386475739358`, 0.31778274219041003`, 0.9341722445108298],
              UndirectedEdge[34, 356] -> 
             RGBColor[
              0.3999124124412533, 0.519710408653627, 0.9469927125910187], 
             UndirectedEdge[288, 313] -> 
             RGBColor[
              0.8708575836519874, 0.41710611796942054`, 0.41689029682654455`],
              UndirectedEdge[66, 334] -> 
             RGBColor[
              0.2368272907421635, 0.366250876660479, 0.936798335901962], 
             UndirectedEdge[17, 328] -> 
             RGBColor[
              0.732255951190426, 0.7877066954338351, 0.9047236192749173], 
             UndirectedEdge[318, 459] -> 
             RGBColor[
              0.2534614196461127, 0.38373440080321664`, 0.9377456249350535], 
             UndirectedEdge[163, 233] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[141, 300] -> 
             RGBColor[
              0.3596463325015217, 0.4852300140127269, 0.9441629288178462], 
             UndirectedEdge[354, 436] -> 
             RGBColor[
              0.9158079140362867, 0.9348276004615428, 0.9614329967335975], 
             UndirectedEdge[29, 290] -> 
             RGBColor[
              0.1963765780341108, 0.3237346128809986, 0.9344947276547053], 
             UndirectedEdge[110, 360] -> 
             RGBColor[
              0.8797081782083205, 0.4465238726729873, 0.3015501277947058], 
             UndirectedEdge[289, 308] -> 
             RGBColor[
              0.2720506530758039, 0.4028257715578081, 0.9388206245143462], 
             UndirectedEdge[264, 324] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[109, 382] -> 
             RGBColor[
              0.3269168850214242, 0.4575807073103212, 0.9420518327256824], 
             UndirectedEdge[293, 497] -> 
             RGBColor[
              0.8604026869949277, 0.3647097089386806, 0.20143440692924686`], 
             UndirectedEdge[160, 237] -> 
             RGBColor[
              0.43894866011146105`, 0.554575099007605, 0.9492019757411265], 
             UndirectedEdge[35, 123] -> 
             RGBColor[
              0.21261512288870693`, 0.34080235310638873`, 0.9354194887614002],
              UndirectedEdge[218, 432] -> 
             RGBColor[
              0.7556020055170689, 0.8090012965886532, 0.976275004473887], 
             UndirectedEdge[46, 476] -> 
             RGBColor[
              0.24200254037507565`, 0.3716903921544483, 0.9370930587124607], 
             UndirectedEdge[288, 391] -> 
             RGBColor[
              0.8623939674573535, 0.3726044724173211, 0.20303663793067456`], 
             UndirectedEdge[259, 486] -> 
             RGBColor[
              0.8762475134266291, 0.4193508442393725, 0.30937659196826445`], 
             UndirectedEdge[138, 296] -> 
             RGBColor[
              0.19431619519816343`, 0.32156901988460085`, 0.9343773919002614],
              UndirectedEdge[56, 494] -> 
             RGBColor[
              0.9820130064078103, 0.9838174426313561, 0.7974332766770647], 
             UndirectedEdge[91, 200] -> 
             RGBColor[
              0.7833150865244253, 0.7895065812204456, 0.6386298521015412], 
             UndirectedEdge[172, 493] -> 
             RGBColor[
              0.48369856139811684`, 0.5896809842908348, 0.9530630745214885], 
             UndirectedEdge[340, 461] -> 
             RGBColor[
              0.7616084201779264, 0.8122712266275236, 0.9364981125310801], 
             UndirectedEdge[33, 274] -> 
             RGBColor[
              0.5221594485499271, 0.6229515892047461, 0.9555254510043854], 
             UndirectedEdge[235, 345] -> 
             RGBColor[
              0.28881156407072495`, 0.4173180031065188, 0.9398895386305561], 
             UndirectedEdge[205, 490] -> 
             RGBColor[
              0.3934599047158681, 0.5152169264202315, 0.9462918950989305], 
             UndirectedEdge[141, 284] -> 
             RGBColor[
              0.3001512154255292, 0.4328083364714148, 0.9404045397333283], 
             UndirectedEdge[489, 500] -> 
             RGBColor[
              0.2537822164718525, 0.3840715786067627, 0.937763893839703], 
             UndirectedEdge[155, 198] -> 
             RGBColor[
              0.21872927125490338`, 0.3472287106986578, 0.9357676804657832], 
             UndirectedEdge[23, 157] -> 
             RGBColor[
              0.9051450162162533, 0.9220177033851362, 0.7071961713842101], 
             UndirectedEdge[248, 344] -> 
             RGBColor[
              0.20626837332895714`, 0.33413151691192766`, 0.935058050763147], 
             UndirectedEdge[50, 131] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[442, 500] -> 
             RGBColor[
              0.3605233719937942, 0.48347254608803236`, 0.9443109769258367], 
             UndirectedEdge[18, 305] -> 
             RGBColor[
              0.8079904168689416, 0.8502655206247263, 0.9814068971986999], 
             UndirectedEdge[134, 278] -> 
             RGBColor[
              0.20206125527400282`, 0.32970956908947946`, 0.9348184616137908],
              UndirectedEdge[158, 422] -> 
             RGBColor[
              0.2659242990306929, 0.3968336772286028, 0.9384553674788276], 
             UndirectedEdge[229, 393] -> 
             RGBColor[
              0.39995355652495146`, 0.5208414012368296, 0.9467056648500944], 
             UndirectedEdge[17, 143] -> 
             RGBColor[
              0.8872780979527313, 0.5209207267878847, 0.40798658666713394`], 
             UndirectedEdge[53, 83] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[166, 239] -> 
             RGBColor[
              0.2531713208719759, 0.3834294885982743, 0.9377291042390291], 
             UndirectedEdge[46, 194] -> 
             RGBColor[
              0.24776813306148654`, 0.3777503956275562, 0.9374214006865218], 
             UndirectedEdge[319, 368] -> 
             RGBColor[
              0.18375299049976135`, 0.3104664220007197, 0.9337758330195483], 
             UndirectedEdge[51, 360] -> 
             RGBColor[
              0.8191009627097754, 0.1478239462483719, 0.1659244095033199], 
             UndirectedEdge[132, 250] -> 
             RGBColor[
              0.5096842240418256, 0.610007296239153, 0.9554309033935169], 
             UndirectedEdge[80, 447] -> 
             RGBColor[
              0.6925262053653484, 0.7562556846603798, 0.95221494764515], 
             UndirectedEdge[128, 179] -> 
             RGBColor[
              0.25756930059010474`, 0.38805204413004735`, 0.9379795626777485],
              UndirectedEdge[218, 300] -> 
             RGBColor[
              0.5789637496600913, 0.6666189664761881, 0.9612821622327556], 
             UndirectedEdge[130, 241] -> 
             RGBColor[
              0.5867161645318493, 0.6694746929690595, 0.9634263183495637], 
             UndirectedEdge[134, 252] -> 
             RGBColor[
              0.19741515137734375`, 0.3248262193140896, 0.9345538728701708], 
             UndirectedEdge[266, 317] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[156, 485] -> 
             RGBColor[
              0.4108308926568273, 0.5236624055476755, 0.9482993868107825], 
             UndirectedEdge[96, 110] -> 
             RGBColor[
              0.9745488280148329, 0.9248169273650014, 0.4244348962647706], 
             UndirectedEdge[50, 373] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[37, 322] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[65, 290] -> 
             RGBColor[
              0.1936841951962548, 0.32090474781148043`, 0.9343414004351128], 
             UndirectedEdge[333, 450] -> 
             RGBColor[
              0.3787463461307482, 0.5024727814987578, 0.9453543601565757], 
             UndirectedEdge[238, 266] -> 
             RGBColor[
              0.857059891141737, 0.3514566373014637, 0.19874471492026624`], 
             UndirectedEdge[312, 446] -> 
             RGBColor[
              0.22312621565382923`, 0.3518501780443054, 0.9360180799446056], 
             UndirectedEdge[407, 448] -> 
             RGBColor[
              0.7562464361257435, 0.809539035824608, 0.9763301317632911], 
             UndirectedEdge[14, 454] -> 
             RGBColor[
              0.36689237882404113`, 0.4922054708154086, 0.9445990358418439], 
             UndirectedEdge[77, 473] -> 
             RGBColor[
              0.7727967287954887, 0.8227535996492561, 0.9749073638024577], 
             UndirectedEdge[57, 136] -> 
             RGBColor[
              0.8413736303622167, 0.28643448166620133`, 0.18597671803717333`],
              UndirectedEdge[364, 487] -> 
             RGBColor[
              0.2635219558175418, 0.39430866219422384`, 0.938318557586787], 
             UndirectedEdge[80, 403] -> 
             RGBColor[
              0.8642091954046907, 0.41214776090032323`, 0.42814428395185355`],
              UndirectedEdge[330, 352] -> 
             RGBColor[
              0.21148900295996179`, 0.33961872966115025`, 0.9353553578974033],
              UndirectedEdge[239, 272] -> 
             RGBColor[
              0.41080937826280917`, 0.5222278432198632, 0.9484266860084449], 
             UndirectedEdge[53, 97] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[304, 311] -> 
             RGBColor[
              0.22811784161362691`, 0.3570966934154181, 0.9363023456585673], 
             UndirectedEdge[237, 241] -> 
             RGBColor[
              0.3816373640692611, 0.5049768359303111, 0.9455385732631909], 
             UndirectedEdge[361, 441] -> 
             RGBColor[
              0.38894854463624445`, 0.5113094130668121, 0.9460044352238959], 
             UndirectedEdge[276, 347] -> 
             RGBColor[
              0.3067228826426153, 0.4377048288177037, 0.9408524097411209], 
             UndirectedEdge[11, 180] -> 
             RGBColor[
              0.7955000612132693, 0.8390425461583731, 0.9093442969764326], 
             UndirectedEdge[56, 360] -> 
             RGBColor[
              0.8799904851652522, 0.44712769870825264`, 0.3322774978601368], 
             UndirectedEdge[15, 269] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[8, 387] -> 
             RGBColor[
              0.24035919758229748`, 0.3699631346852874, 0.9369994727715198], 
             UndirectedEdge[139, 278] -> 
             RGBColor[
              0.19876192054719527`, 0.32624175910170083`, 0.9346305693820274],
              UndirectedEdge[15, 449] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[348, 355] -> 
             RGBColor[
              0.8921067382753032, 0.5870113175771698, 0.237923296232169], 
             UndirectedEdge[173, 499] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[130, 483] -> 
             RGBColor[
              0.9023076079882126, 0.8925450795893294, 0.6637151097464145], 
             UndirectedEdge[173, 282] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[84, 244] -> 
             RGBColor[
              0.8279818714648165, 0.8418796258010216, 0.6672951219910502], 
             UndirectedEdge[183, 279] -> 
             RGBColor[
              0.28035477682361865`, 0.41200102433410457`, 0.9392771618411558],
              UndirectedEdge[124, 381] -> 
             RGBColor[
              0.21298610699007461`, 0.34119228091867676`, 0.9354406157571513],
              UndirectedEdge[81, 213] -> 
             RGBColor[
              0.3642555391877909, 0.48719454314839994`, 0.9445308686680915], 
             UndirectedEdge[134, 210] -> 
             RGBColor[
              0.22588078399928613`, 0.3547454040251011, 0.9361749485368607], 
             UndirectedEdge[103, 275] -> 
             RGBColor[
              0.963923015142357, 0.882139466332943, 0.4484107000371519], 
             UndirectedEdge[256, 298] -> 
             RGBColor[
              0.7725153841740422, 0.8225801022129446, 0.9778636612646125], 
             UndirectedEdge[18, 235] -> 
             RGBColor[
              0.5507776223875409, 0.6415956100722736, 0.9597443267215762], 
             UndirectedEdge[255, 334] -> 
             RGBColor[
              0.23529404619959324`, 0.3646393394329189, 0.9367110198934947], 
             UndirectedEdge[209, 372] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[112, 238] -> 
             RGBColor[
              0.857059891141737, 0.3514566373014637, 0.19874471492026624`], 
             UndirectedEdge[360, 457] -> 
             RGBColor[
              0.8673649101585332, 0.4054186191239333, 0.2084049659054714], 
             UndirectedEdge[233, 404] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[259, 348] -> 
             RGBColor[
              0.8657911144896757, 0.38473790158096455`, 0.21272342517580606`],
              UndirectedEdge[244, 376] -> 
             RGBColor[
              0.9816204164865794, 0.9616423487915396, 0.6235919701345964], 
             UndirectedEdge[182, 371] -> 
             RGBColor[
              0.7505720549654683, 0.8042082232990024, 0.9596831026196062], 
             UndirectedEdge[21, 77] -> 
             RGBColor[
              0.8806391477680734, 0.9075693815160031, 0.9852742312191726], 
             UndirectedEdge[153, 493] -> 
             RGBColor[
              0.4936405223165552, 0.5982922111409009, 0.9536965674798805], 
             UndirectedEdge[276, 382] -> 
             RGBColor[
              0.3268271732727834, 0.45750300350269213`, 0.9420461163723881], 
             UndirectedEdge[80, 219] -> 
             RGBColor[
              0.8642091954046907, 0.41214776090032323`, 0.42814428395185355`],
              UndirectedEdge[60, 136] -> 
             RGBColor[
              0.8413736303622167, 0.28643448166620133`, 0.18597671803717333`],
              UndirectedEdge[23, 96] -> 
             RGBColor[
              0.9739330346591857, 0.9234998076435308, 0.35740958973864884`], 
             UndirectedEdge[53, 281] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[141, 162] -> 
             RGBColor[
              0.24952923123188117`, 0.3796014214647141, 0.9375216926220145], 
             UndirectedEdge[28, 149] -> 
             RGBColor[
              0.8867519951374654, 0.5638187600065572, 0.2265258256323685], 
             UndirectedEdge[37, 317] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[372, 486] -> 
             RGBColor[
              0.8762475134266291, 0.4193508442393725, 0.30937659196826445`], 
             UndirectedEdge[63, 453] -> 
             RGBColor[
              0.37845988554305304`, 0.5012031646662531, 0.9454032112758242], 
             UndirectedEdge[82, 242] -> 
             RGBColor[
              0.844192723800754, 0.2992353265545988, 0.18832903870459236`], 
             UndirectedEdge[4, 191] -> 
             RGBColor[
              0.20962796174465825`, 0.33766265734703804`, 0.9352493743533555],
              UndirectedEdge[70, 403] -> 
             RGBColor[
              0.8734050425786691, 0.4188525953049994, 0.40570794960622847`], 
             UndirectedEdge[144, 458] -> 
             RGBColor[
              0.35435270940186414`, 0.4764909843730204, 0.9439777206363321], 
             UndirectedEdge[16, 224] -> 
             RGBColor[
              0.4710966513554297, 0.5758880395117242, 0.9527849389967913], 
             UndirectedEdge[40, 206] -> 
             RGBColor[
              0.19522868075367328`, 0.3225281000583675, 0.9344293566027462], 
             UndirectedEdge[148, 485] -> 
             RGBColor[
              0.6140670521379212, 0.6970882935898717, 0.9630875849906602], 
             UndirectedEdge[34, 291] -> 
             RGBColor[
              0.25248695241717767`, 0.3827101739608151, 0.9376901304679608], 
             UndirectedEdge[222, 339] -> 
             RGBColor[
              0.22078402621432447`, 0.3493883884399983, 0.9358846957209846], 
             UndirectedEdge[197, 314] -> 
             RGBColor[
              0.5074205711230394, 0.6099036412278982, 0.9546641851582337], 
             UndirectedEdge[330, 358] -> 
             RGBColor[
              0.30472186221443454`, 0.43059675941998354`, 0.9409217073976809],
              UndirectedEdge[312, 415] -> 
             RGBColor[
              0.21664775986789828`, 0.3450409102554709, 0.9356491414716133], 
             UndirectedEdge[370, 443] -> 
             RGBColor[
              0.5772962329349696, 0.6646840201911736, 0.9613835661875354], 
             UndirectedEdge[160, 305] -> 
             RGBColor[
              0.6583315658837037, 0.7304786613456766, 0.96845405916136], 
             UndirectedEdge[266, 343] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[47, 468] -> 
             RGBColor[
              0.5415362336412717, 0.63526925655566, 0.9584452336065665], 
             UndirectedEdge[388, 436] -> 
             RGBColor[
              0.9470100510372832, 0.9597073375466911, 0.9644090844152291], 
             UndirectedEdge[69, 209] -> 
             RGBColor[
              0.8720195914369621, 0.405748016840095, 0.23691988196683633`], 
             UndirectedEdge[197, 470] -> 
             RGBColor[
              0.32997863152241563`, 0.4544774028464852, 0.942457651865863], 
             UndirectedEdge[13, 298] -> 
             RGBColor[
              0.6096447166347696, 0.6934029640170689, 0.9628044481530396], 
             UndirectedEdge[168, 383] -> 
             RGBColor[
              0.7063203821054702, 0.7703516209167286, 0.9714659683735043], 
             UndirectedEdge[123, 428] -> 
             RGBColor[
              0.21288413127934025`, 0.34108509798106146`, 0.9354348083912845],
              UndirectedEdge[137, 485] -> 
             RGBColor[
              0.43787204087877396`, 0.550935268346073, 0.9498814143229708], 
             UndirectedEdge[394, 467] -> 
             RGBColor[
              0.2149961156174362, 0.3433049274279415, 0.9355550827749383], 
             UndirectedEdge[232, 395] -> 
             RGBColor[
              0.806035818091638, 0.7335348511120112, 0.6107945156854029], 
             UndirectedEdge[414, 461] -> 
             RGBColor[
              0.7674485024465632, 0.8134259226299666, 0.7363222999185557], 
             UndirectedEdge[224, 333] -> 
             RGBColor[
              0.3565055136813881, 0.481962099685929, 0.9439828450911899], 
             UndirectedEdge[33, 182] -> 
             RGBColor[
              0.75743790360309, 0.8097822285259801, 0.9602236073747921], 
             UndirectedEdge[158, 451] -> 
             RGBColor[
              0.26279404048911603`, 0.39354357703155085`, 0.9382771038856873],
              UndirectedEdge[235, 274] -> 
             RGBColor[
              0.415657066351844, 0.5336115935759853, 0.9479359965181933], 
             UndirectedEdge[284, 345] -> 
             RGBColor[
              0.2646833404793789, 0.39552935110985515`, 0.9383846967251639], 
             UndirectedEdge[70, 238] -> 
             RGBColor[
              0.9610594005806091, 0.8872098489096947, 0.5782429967897421], 
             UndirectedEdge[21, 55] -> 
             RGBColor[
              0.8365288820965593, 0.5120560542024203, 0.4540089567270905], 
             UndirectedEdge[55, 60] -> 
             RGBColor[
              0.8349696694427251, 0.26979777990945364`, 0.18112030099193344`],
              UndirectedEdge[219, 258] -> 
             RGBColor[
              0.8761965593307338, 0.4192418585805019, 0.3038305530822916], 
             UndirectedEdge[175, 463] -> 
             RGBColor[
              0.9058410813145757, 0.6396007349493169, 0.38259068137142616`], 
             UndirectedEdge[101, 431] -> 
             RGBColor[
              0.7419137193030552, 0.7927733536547152, 0.740681887591113], 
             UndirectedEdge[14, 213] -> 
             RGBColor[
              0.34656244604435504`, 0.47186967514827405`, 0.9434034804183797],
              UndirectedEdge[378, 487] -> 
             RGBColor[
              0.26906193462506856`, 0.40013153117587835`, 0.9386340511842113],
              UndirectedEdge[8, 159] -> 
             RGBColor[
              0.3390979651454099, 0.46352019337297634`, 0.9429968372905502], 
             UndirectedEdge[311, 469] -> 
             RGBColor[
              0.2079662974981772, 0.3359161428683881, 0.9351547450327304], 
             UndirectedEdge[343, 440] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[371, 460] -> 
             RGBColor[
              0.6856107819931014, 0.7528945564391651, 0.9702915062006248], 
             UndirectedEdge[224, 358] -> 
             RGBColor[
              0.33994340240143384`, 0.4676168313311497, 0.9429275220057312], 
             UndirectedEdge[455, 475] -> 
             RGBColor[
              0.85896566076965, 0.4082371413550099, 0.4370202203561169], 
             UndirectedEdge[310, 408] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[154, 376] -> 
             RGBColor[
              0.8735554698238286, 0.4189148008366767, 0.4032149808607035], 
             UndirectedEdge[282, 499] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[14, 192] -> 
             RGBColor[
              0.6420349038642188, 0.7161165631440682, 0.9675369541888443], 
             UndirectedEdge[75, 147] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[175, 351] -> 
             RGBColor[
              0.7271599458905001, 0.7821063736932174, 0.8431568209407971], 
             UndirectedEdge[109, 205] -> 
             RGBColor[
              0.3878666627433047, 0.5103723413481127, 0.9459354986663484], 
             UndirectedEdge[43, 148] -> 
             RGBColor[
              0.5374554379217633, 0.6334803821671271, 0.957446343497947], 
             UndirectedEdge[56, 92] -> 
             RGBColor[
              0.8261574713547348, 0.8617230188259255, 0.8123362096117437], 
             UndirectedEdge[46, 412] -> 
             RGBColor[
              0.25670322812195334`, 0.3871417470538542, 0.9379302411319268], 
             UndirectedEdge[170, 214] -> 
             RGBColor[
              0.2164586672192998, 0.34484216189262756`, 0.9356383729250132], 
             UndirectedEdge[94, 437] -> 
             RGBColor[
              0.18537229810347358`, 0.3121684169622533, 0.9338680501920288], 
             UndirectedEdge[173, 249] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[181, 302] -> 
             RGBColor[
              0.4379250644031646, 0.5527838013368829, 0.9493867273387744], 
             UndirectedEdge[188, 279] -> 
             RGBColor[
              0.34218136725328896`, 0.47037106759976377`, 0.9430402518488281],
              UndirectedEdge[317, 471] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[8, 344] -> 
             RGBColor[
              0.2433422473968615, 0.3730985091766764, 0.9371693530454325], 
             UndirectedEdge[236, 493] -> 
             RGBColor[
              0.4475753565200481, 0.558111907733633, 0.9507716236139967], 
             UndirectedEdge[31, 366] -> 
             RGBColor[
              0.21485978318177745`, 0.34316163339408845`, 0.9355473188444132],
              UndirectedEdge[176, 261] -> 
             RGBColor[
              0.9050998994190445, 0.9271661077872047, 0.9908104304704488], 
             UndirectedEdge[144, 145] -> 
             RGBColor[
              0.28245593278256786`, 0.4142094724679425, 0.9393968195646363], 
             UndirectedEdge[144, 375] -> 
             RGBColor[
              0.2688835490281597, 0.3999440366032271, 0.9386238923883652], 
             UndirectedEdge[258, 293] -> 
             RGBColor[
              0.8761965593307338, 0.419241858580502, 0.3038305530822916], 
             UndirectedEdge[242, 269] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[45, 216] -> 
             RGBColor[
              0.27205173985217523`, 0.40327400603416763`, 0.9388043161688746],
              UndirectedEdge[82, 323] -> 
             RGBColor[
              0.844192723800754, 0.2992353265545988, 0.18832903870459236`], 
             UndirectedEdge[258, 272] -> 
             RGBColor[
              0.7801629819799012, 0.8241593809088232, 0.7710309321085329], 
             UndirectedEdge[92, 356] -> 
             RGBColor[
              0.5746689176875454, 0.6653465467906676, 0.9598195826356501], 
             UndirectedEdge[114, 327] -> 
             RGBColor[
              0.19477749179217513`, 0.32205387185280054`, 0.9344036620588632],
              UndirectedEdge[188, 459] -> 
             RGBColor[
              0.3130997116438481, 0.4398044036707781, 0.9413840945843246], 
             UndirectedEdge[465, 469] -> 
             RGBColor[
              0.1844144384363928, 0.3111616457203408, 0.9338135015010149], 
             UndirectedEdge[44, 62] -> 
             RGBColor[
              0.6139390302142435, 0.6965893567419654, 0.9633475722642448], 
             UndirectedEdge[88, 337] -> 
             RGBColor[
              0.22370546244709866`, 0.3524590031503995, 0.9360510671925635], 
             UndirectedEdge[253, 388] -> 
             RGBColor[
              0.9562289934034156, 0.9659272848069381, 0.9194480770482338], 
             UndirectedEdge[80, 238] -> 
             RGBColor[
              0.9472656298196414, 0.8771525973026804, 0.6118974983081796], 
             UndirectedEdge[171, 272] -> 
             RGBColor[
              0.7608854551425784, 0.7598583476143784, 0.6209877429007751], 
             UndirectedEdge[297, 392] -> 
             RGBColor[
              0.3456632797932826, 0.4683209837324499, 0.943447605171511], 
             UndirectedEdge[82, 499] -> 
             RGBColor[
              0.844192723800754, 0.2992353265545988, 0.18832903870459236`], 
             UndirectedEdge[297, 484] -> 
             RGBColor[
              0.2267841294164104, 0.35569487733390615`, 0.9362263927219862], 
             UndirectedEdge[73, 240] -> 
             RGBColor[
              0.8329068192640983, 0.2539418094898154, 0.17914491333122431`], 
             UndirectedEdge[229, 263] -> 
             RGBColor[
              0.40720266362894586`, 0.5271202134595926, 0.9471675715446273], 
             UndirectedEdge[87, 91] -> 
             RGBColor[
              0.9092412489562847, 0.8887699196998804, 0.6506892545416749], 
             UndirectedEdge[296, 339] -> 
             RGBColor[
              0.1887512717262556, 0.3157199324790988, 0.9340604777411028], 
             UndirectedEdge[62, 157] -> 
             RGBColor[
              0.6731273937865867, 0.7428277562129042, 0.9692469151984306], 
             UndirectedEdge[227, 265] -> 
             RGBColor[
              0.22119979691073288`, 0.34982538980330835`, 0.9359083732470674],
              UndirectedEdge[38, 127] -> 
             RGBColor[
              0.8446459694565934, 0.30129340921955317`, 0.18870723798989242`],
              UndirectedEdge[302, 451] -> 
             RGBColor[
              0.38989549393188216`, 0.5095986622961652, 0.9463843359960313], 
             UndirectedEdge[141, 151] -> 
             RGBColor[
              0.29343798324110804`, 0.42575230380208373`, 0.9400222310917625],
              UndirectedEdge[72, 439] -> 
             RGBColor[
              0.292484520403141, 0.4238404187370848, 0.9400012426546567], 
             UndirectedEdge[277, 340] -> 
             RGBColor[
              0.9813346158030243, 0.9667331493458243, 0.648350128762206], 
             UndirectedEdge[53, 322] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[450, 461] -> 
             RGBColor[
              0.440653853491213, 0.5536978357226917, 0.949961106074102], 
             UndirectedEdge[352, 367] -> 
             RGBColor[
              0.22779053880143119`, 0.3567526774076035, 0.9362837062476139], 
             UndirectedEdge[239, 251] -> 
             RGBColor[
              0.35362694944486533`, 0.47576904067762016`, 0.9439348930085601],
              UndirectedEdge[83, 163] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[179, 245] -> 
             RGBColor[
              0.37656052377494753`, 0.49620970043426327`, 0.945567861444176], 
             UndirectedEdge[133, 237] -> 
             RGBColor[
              0.3420181953123312, 0.46624628266428925`, 0.9431757084268175], 
             UndirectedEdge[199, 244] -> 
             RGBColor[
              0.9841027978606212, 0.9626688772839973, 0.5824524865696615], 
             UndirectedEdge[173, 269] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[209, 379] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[139, 451] -> 
             RGBColor[
              0.24317792529434393`, 0.37292579622830746`, 0.9371599951447869],
              UndirectedEdge[18, 218] -> 
             RGBColor[
              0.7469981175976064, 0.8022798739539989, 0.975417449333979], 
             UndirectedEdge[59, 287] -> 
             RGBColor[
              0.7202478045060992, 0.7809177598731158, 0.9731295500063672], 
             UndirectedEdge[167, 274] -> 
             RGBColor[
              0.470698842431732, 0.5811735508841086, 0.9514742835843497], 
             UndirectedEdge[402, 461] -> 
             RGBColor[
              0.4468964101447459, 0.5591048245359614, 0.9503588762639891], 
             UndirectedEdge[472, 488] -> 
             RGBColor[
              0.1957489875650853, 0.32307497550651876`, 0.9344589873059312], 
             UndirectedEdge[227, 270] -> 
             RGBColor[
              0.21213527831829654`, 0.34029800603898447`, 0.9353921623229817],
              UndirectedEdge[124, 363] -> 
             RGBColor[
              0.20074068905799813`, 0.32832157026772446`, 0.934743257321392], 
             UndirectedEdge[118, 195] -> 
             RGBColor[
              0.22728280184896765`, 0.3562190136781822, 0.9362547913793006], 
             UndirectedEdge[54, 154] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[313, 498] -> 
             RGBColor[
              0.8708575836519874, 0.41710611796942054`, 0.41689029682654466`],
              UndirectedEdge[243, 283] -> 
             RGBColor[
              0.2242477894352095, 0.3530290232004211, 0.9360819519122355], 
             UndirectedEdge[302, 346] -> 
             RGBColor[
              0.7355852203061626, 0.7748239735708853, 0.6706341273882959], 
             UndirectedEdge[13, 477] -> 
             RGBColor[
              0.39985691154436676`, 0.5139283350486532, 0.9475105621888961], 
             UndirectedEdge[140, 479] -> 
             RGBColor[
              0.1864188505172612, 0.31326840990439964`, 0.9339276498037584], 
             UndirectedEdge[174, 309] -> 
             RGBColor[
              0.2173048866955889, 0.3457315922156211, 0.9356865638723183], 
             UndirectedEdge[299, 312] -> 
             RGBColor[
              0.3534031011898746, 0.4747596119837323, 0.9439860300988824], 
             UndirectedEdge[215, 402] -> 
             RGBColor[
              0.2785766923854661, 0.4061119675803237, 0.9393231009461043], 
             UndirectedEdge[372, 400] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[29, 426] -> 
             RGBColor[
              0.20893369054247232`, 0.33693293429420396`, 0.9352098366354733],
              UndirectedEdge[361, 481] -> 
             RGBColor[
              0.3510247020399264, 0.47694984457964584`, 0.9436433174550093], 
             UndirectedEdge[188, 335] -> 
             RGBColor[
              0.3476544631710703, 0.4755425552025606, 0.9433732128678576], 
             UndirectedEdge[168, 443] -> 
             RGBColor[
              0.7657377612685392, 0.8169194260162985, 0.9772852418831708], 
             UndirectedEdge[81, 500] -> 
             RGBColor[
              0.3616089991347435, 0.484412861752316, 0.9443801521272757], 
             UndirectedEdge[75, 310] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[348, 444] -> 
             RGBColor[
              0.8882657082986757, 0.5574874780267427, 0.23424512158872762`], 
             UndirectedEdge[262, 482] -> 
             RGBColor[
              0.9440521498418833, 0.9577947654750492, 0.9795892961680893], 
             UndirectedEdge[83, 395] -> 
             RGBColor[
              0.8502020870562027, 0.32426772933006165`, 0.19322676477969444`],
              UndirectedEdge[26, 459] -> 
             RGBColor[
              0.2252782711388126, 0.3541121248072216, 0.9361406363207947], 
             UndirectedEdge[186, 498] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[167, 284] -> 
             RGBColor[
              0.37828991345392127`, 0.5010749823612741, 0.9453889376019913], 
             UndirectedEdge[175, 359] -> 
             RGBColor[
              0.8764817671983398, 0.4201249000034494, 0.35471866035020744`], 
             UndirectedEdge[65, 484] -> 
             RGBColor[
              0.20075983867306346`, 0.3283416977273139, 0.9347443478636406], 
             UndirectedEdge[266, 322] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[210, 252] -> 
             RGBColor[
              0.22195142774965249`, 0.3506154014711605, 0.9359511775114058], 
             UndirectedEdge[133, 271] -> 
             RGBColor[
              0.2827858451483628, 0.4145562312820451, 0.9394156075858068], 
             UndirectedEdge[190, 467] -> 
             RGBColor[
              0.28809331925242987`, 0.41681763157843177`, 0.9398393153533288],
              UndirectedEdge[216, 481] -> 
             RGBColor[
              0.2808636814443794, 0.4125359153569407, 0.9393061432064513], 
             UndirectedEdge[18, 406] -> 
             RGBColor[
              0.8740105754900596, 0.8985635500757864, 0.7736400637514464], 
             UndirectedEdge[315, 364] -> 
             RGBColor[
              0.2434271231031161, 0.3731877189253806, 0.9371741865913413], 
             UndirectedEdge[152, 464] -> 
             RGBColor[
              0.24103131190415128`, 0.37066956945206503`, 0.9370377486878454],
              UndirectedEdge[229, 280] -> 
             RGBColor[
              0.4876130735802507, 0.5943371257848047, 0.9529628180988177], 
             UndirectedEdge[164, 259] -> 
             RGBColor[
              0.8384337610731512, 0.3919783377813091, 0.43897188140083576`], 
             UndirectedEdge[238, 497] -> 
             RGBColor[
              0.9415558672049971, 0.8059955193602164, 0.27183268277426964`], 
             UndirectedEdge[7, 478] -> 
             RGBColor[
              0.7350898192819142, 0.7358328905411176, 0.6182471001773744], 
             UndirectedEdge[137, 227] -> 
             RGBColor[
              0.2807026852952867, 0.41121759970580773`, 0.9393390488386753], 
             UndirectedEdge[44, 157] -> 
             RGBColor[
              0.7585384972051484, 0.8112953062135444, 0.9765676865222799], 
             UndirectedEdge[105, 205] -> 
             RGBColor[
              0.33891161833602373`, 0.4609448212418522, 0.9430733506262359], 
             UndirectedEdge[305, 460] -> 
             RGBColor[
              0.8431870429140408, 0.8777984765898346, 0.9849051269467421], 
             UndirectedEdge[330, 492] -> 
             RGBColor[
              0.2098019116271066, 0.3378454897025508, 0.9352592805418252], 
             UndirectedEdge[94, 123] -> 
             RGBColor[
              0.19382981247906908`, 0.3210578008083872, 0.9343496931239477], 
             UndirectedEdge[418, 444] -> 
             RGBColor[
              0.8835362304269067, 0.5400718010576258, 0.22348630967635297`], 
             UndirectedEdge[203, 295] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[342, 485] -> 
             RGBColor[
              0.7516716146349955, 0.7419375828889696, 0.6178585819047002], 
             UndirectedEdge[279, 430] -> 
             RGBColor[
              0.2902434913404049, 0.42239469027195997`, 0.9398403095038447], 
             UndirectedEdge[391, 448] -> 
             RGBColor[
              0.888386104264779, 0.856120355886665, 0.6318853697511313], 
             UndirectedEdge[174, 252] -> 
             RGBColor[
              0.20462132433062605`, 0.3324003639857437, 0.9349642537592827], 
             UndirectedEdge[14, 489] -> 
             RGBColor[
              0.3237403694481549, 0.4478822256424365, 0.9421037969184629], 
             UndirectedEdge[6, 158] -> 
             RGBColor[
              0.2841449391531702, 0.41362099146188114`, 0.9395795538518968], 
             UndirectedEdge[201, 493] -> 
             RGBColor[
              0.5786142025957969, 0.6687841017968702, 0.9599697760434542], 
             UndirectedEdge[66, 446] -> 
             RGBColor[
              0.22940101354262873`, 0.3584453884705983, 0.9363754204016412], 
             UndirectedEdge[449, 499] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[202, 477] -> 
             RGBColor[
              0.2364320550815771, 0.36583545892181446`, 0.9367758278157905], 
             UndirectedEdge[89, 299] -> 
             RGBColor[
              0.6587851834243671, 0.7308687120328877, 0.9684646971494795], 
             UndirectedEdge[57, 91] -> 
             RGBColor[
              0.8662785326994125, 0.38638207765364485`, 0.21461695287942803`],
              UndirectedEdge[222, 438] -> 
             RGBColor[
              0.2691477689239765, 0.4002217484662395, 0.9386389393205536], 
             UndirectedEdge[83, 346] -> 
             RGBColor[
              0.8725424883879621, 0.4075118710378607, 0.23895123788066785`], 
             UndirectedEdge[38, 388] -> 
             RGBColor[
              0.9118100953703692, 0.7890590735441616, 0.615164700862159], 
             UndirectedEdge[345, 472] -> 
             RGBColor[
              0.21365168557830777`, 0.34189184621502966`, 0.9354785194731159],
              UndirectedEdge[231, 486] -> 
             RGBColor[
              0.8762475134266291, 0.4193508442393725, 0.30937659196826445`], 
             UndirectedEdge[14, 251] -> 
             RGBColor[
              0.43294174364966176`, 0.5494141108897593, 0.9488076429633725], 
             UndirectedEdge[404, 418] -> 
             RGBColor[
              0.8610616366179067, 0.36732222461184755`, 0.20196461326343138`],
              UndirectedEdge[10, 370] -> 
             RGBColor[
              0.3984907491896946, 0.5195743910458647, 0.9466124560602016], 
             UndirectedEdge[216, 224] -> 
             RGBColor[
              0.2822970613726556, 0.41404248854309544`, 0.939387772072871], 
             UndirectedEdge[116, 143] -> 
             RGBColor[
              0.7862678242150312, 0.44236018796317117`, 0.4452227057442526], 
             UndirectedEdge[142, 477] -> 
             RGBColor[
              0.3004155181766316, 0.43013773697541924`, 0.9405275466941669], 
             UndirectedEdge[1, 378] -> 
             RGBColor[
              0.2831419711768191, 0.4149305423176469, 0.9394358884362861], 
             UndirectedEdge[47, 298] -> 
             RGBColor[
              0.697219552726804, 0.7633924807458228, 0.9704559871947942], 
             UndirectedEdge[50, 340] -> 
             RGBColor[
              0.872096562596627, 0.4180301464376909, 0.41479302865073187`], 
             UndirectedEdge[144, 417] -> 
             RGBColor[
              0.256797636184088, 0.38724097591297457`, 0.9379356175314011], 
             UndirectedEdge[326, 395] -> 
             RGBColor[
              0.8502020870562027, 0.32426772933006165`, 0.19322676477969444`],
              UndirectedEdge[14, 166] -> 
             RGBColor[
              0.33248611507677234`, 0.4570745588104135, 0.9426018541938415], 
             UndirectedEdge[41, 132] -> 
             RGBColor[
              0.6315111194145004, 0.7114597115777666, 0.9643175833681797], 
             UndirectedEdge[6, 35] -> 
             RGBColor[
              0.2754047152813548, 0.4044344620104028, 0.9390818110323994], 
             UndirectedEdge[95, 286] -> 
             RGBColor[
              0.2095588048007067, 0.3375899690141414, 0.935245435967706], 
             UndirectedEdge[435, 439] -> 
             RGBColor[
              0.3579216498299631, 0.4805187712808422, 0.9441708386779522], 
             UndirectedEdge[354, 388] -> 
             RGBColor[
              0.8931181453699616, 0.9176121823445156, 0.9896676000730092], 
             UndirectedEdge[47, 59] -> 
             RGBColor[
              0.6586144820124289, 0.7326242521866431, 0.967025018237206], 
             UndirectedEdge[305, 493] -> 
             RGBColor[
              0.7256228086774508, 0.7851087236815824, 0.973751472290028], 
             UndirectedEdge[26, 335] -> 
             RGBColor[
              0.2598330226660348, 0.3898502763390041, 0.9381297546043277], 
             UndirectedEdge[24, 115] -> 
             RGBColor[
              0.2186064221312832, 0.3470995884806487, 0.935760684389932], 
             UndirectedEdge[271, 351] -> 
             RGBColor[
              0.3820420141208699, 0.5047731590450875, 0.9456249628519793], 
             UndirectedEdge[12, 40] -> 
             RGBColor[
              0.22456517753702926`, 0.3533626182190016, 0.9361000266951005], 
             UndirectedEdge[228, 468] -> 
             RGBColor[
              0.47049382574186954`, 0.5787015098110876, 0.9520951878724158], 
             UndirectedEdge[1, 108] -> 
             RGBColor[
              0.2889826050783411, 0.42082604906062115`, 0.9397774148572755], 
             UndirectedEdge[97, 343] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[314, 411] -> 
             RGBColor[
              0.656845676388658, 0.7312243873716151, 0.9668610682296974], 
             UndirectedEdge[211, 466] -> 
             RGBColor[
              0.2317269011689615, 0.36089004383566703`, 0.9365078762611184], 
             UndirectedEdge[12, 202] -> 
             RGBColor[
              0.2283373813057901, 0.35732744355150203`, 0.936314848119256], 
             UndirectedEdge[96, 360] -> 
             RGBColor[
              0.8668775579740029, 0.4036445305638346, 0.2071894410617543], 
             UndirectedEdge[199, 482] -> 
             RGBColor[
              0.9636232621639489, 0.9712609471948344, 0.895860300965513], 
             UndirectedEdge[9, 357] -> 
             RGBColor[
              0.23165569271724953`, 0.3608151992380412, 0.9365038210451369], 
             UndirectedEdge[330, 441] -> 
             RGBColor[
              0.2965298119987766, 0.4235012172675965, 0.9403997172018848], 
             UndirectedEdge[375, 461] -> 
             RGBColor[
              0.4115391847777058, 0.525962316169853, 0.9481981362024026], 
             UndirectedEdge[170, 268] -> 
             RGBColor[
              0.21378017372291278`, 0.34202689540162845`, 0.93548583668287], 
             UndirectedEdge[66, 245] -> 
             RGBColor[
              0.3717582052146181, 0.4911621591427741, 0.9452943765065589], 
             UndirectedEdge[235, 308] -> 
             RGBColor[
              0.2889479905873472, 0.41746139602542953`, 0.9398973079188528], 
             UndirectedEdge[42, 315] -> 
             RGBColor[
              0.2351529722129052, 0.36449106172830237`, 0.9367029859386531], 
             UndirectedEdge[238, 403] -> 
             RGBColor[
              0.857059891141737, 0.3514566373014637, 0.19874471492026624`], 
             UndirectedEdge[382, 425] -> 
             RGBColor[
              0.2677389295661514, 0.3974082595226244, 0.9386075050248284], 
             UndirectedEdge[74, 215] -> 
             RGBColor[
              0.21298972122483276`, 0.3411960797085633, 0.935440821582474], 
             UndirectedEdge[350, 426] -> 
             RGBColor[
              0.20267694710555745`, 0.33035670024156016`, 0.9348535243527634],
              UndirectedEdge[78, 497] -> 
             RGBColor[
              0.9513305032138845, 0.844710858419126, 0.2798946323366356], 
             UndirectedEdge[109, 490] -> 
             RGBColor[
              0.33626661541495695`, 0.4656789738460858, 0.9426475892787163], 
             UndirectedEdge[281, 317] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[219, 471] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[183, 243] -> 
             RGBColor[
              0.2557945891305531, 0.386186709862853, 0.9378784954855774], 
             UndirectedEdge[93, 151] -> 
             RGBColor[
              0.3297566159868596, 0.4579089737338883, 0.9423108176147698], 
             UndirectedEdge[176, 478] -> 
             RGBColor[
              0.7002666387715365, 0.7643643038754704, 0.9719385075455431], 
             UndirectedEdge[28, 282] -> 
             RGBColor[
              0.8613224849238736, 0.3683564012224616, 0.2021744979333091], 
             UndirectedEdge[125, 305] -> 
             RGBColor[
              0.8321466499760604, 0.3869651660515732, 0.4383722111318248], 
             UndirectedEdge[22, 466] -> 
             RGBColor[
              0.21948326963951018`, 0.34802121080713827`, 0.9358106195583459],
              UndirectedEdge[78, 154] -> 
             RGBColor[
              0.863576315147662, 0.3772668633407367, 0.20411934796184356`], 
             UndirectedEdge[273, 421] -> 
             RGBColor[
              0.20830733799455892`, 0.33627459805330173`, 0.9351741667844751],
              UndirectedEdge[221, 234] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[384, 461] -> 
             RGBColor[
              0.587992436035337, 0.6763977741876906, 0.9607080649334159], 
             UndirectedEdge[3, 428] -> 
             RGBColor[
              0.20817203900594683`, 0.33613239023781905`, 0.9351664617072306],
              UndirectedEdge[209, 431] -> 
             RGBColor[
              0.8760289938084724, 0.418883452871858, 0.28559208007867803`], 
             UndirectedEdge[33, 237] -> 
             RGBColor[
              0.49170863187262065`, 0.5974080208929563, 0.9533554339843097], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.6304047842681767, 0.7105954341529999, 0.964207314220084], 
             UndirectedEdge[202, 243] -> 
             RGBColor[
              0.23381644008435298`, 0.36308628172016266`, 0.9366268724111542],
              UndirectedEdge[169, 456] -> 
             RGBColor[
              0.22538315140670392`, 0.35422236061856843`, 0.9361466090968946],
              UndirectedEdge[86, 297] -> 
             RGBColor[
              0.22786096089643254`, 0.35682669549446866`, 0.936287716681744], 
             UndirectedEdge[40, 202] -> 
             RGBColor[
              0.20889632984063528`, 0.3368936658277679, 0.9352077089987738], 
             UndirectedEdge[396, 477] -> 
             RGBColor[
              0.25943030085066265`, 0.39000807339812527`, 0.9380855438894842],
              UndirectedEdge[209, 355] -> 
             RGBColor[
              0.8304768118928137, 0.23526370799810264`, 0.17681793552818148`],
              UndirectedEdge[131, 434] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[87, 228] -> 
             RGBColor[
              0.713434001367286, 0.7752676949105676, 0.9727293181147071], 
             UndirectedEdge[17, 116] -> 
             RGBColor[
              0.8359452478324436, 0.8712418660281439, 0.9133270492646723], 
             UndirectedEdge[104, 323] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[101, 347] -> 
             RGBColor[
              0.38666513626040583`, 0.5059405125852774, 0.9462242971444441], 
             UndirectedEdge[92, 342] -> 
             RGBColor[
              0.8032234487173383, 0.7835550891960509, 0.622077324996481], 
             UndirectedEdge[399, 464] -> 
             RGBColor[
              0.291953585715003, 0.4241921078859083, 0.9399376968486202], 
             UndirectedEdge[423, 469] -> 
             RGBColor[
              0.18473878597520788`, 0.3115025555484572, 0.9338319726135212], 
             UndirectedEdge[114, 415] -> 
             RGBColor[
              0.18749769588626286`, 0.3144023447899675, 0.9339890884515143], 
             UndirectedEdge[244, 478] -> 
             RGBColor[
              0.7469756992594796, 0.7766726498372237, 0.6605368645795646], 
             UndirectedEdge[129, 486] -> 
             RGBColor[
              0.8772725629513854, 0.9012898824300021, 0.7882255224122631], 
             UndirectedEdge[202, 421] -> 
             RGBColor[
              0.20744896350666275`, 0.3353723920424369, 0.9351252836272407], 
             UndirectedEdge[62, 378] -> 
             RGBColor[
              0.4141124561597586, 0.5302263593931105, 0.9482027364763976], 
             UndirectedEdge[263, 485] -> 
             RGBColor[
              0.4682909081362715, 0.5772825622677944, 0.9518196776462704], 
             UndirectedEdge[275, 346] -> 
             RGBColor[
              0.9582193150286128, 0.8640683796032405, 0.32686377672377676`], 
             UndirectedEdge[127, 303] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[260, 312] -> 
             RGBColor[
              0.28003182950122174`, 0.41135737812578943`, 0.9392699090175137],
              UndirectedEdge[32, 299] -> 
             RGBColor[
              0.4092045959302848, 0.5287059126675422, 0.9473361014296651], 
             UndirectedEdge[283, 396] -> 
             RGBColor[
              0.2260981287293382, 0.35497384711683755`, 0.9361873259977045], 
             UndirectedEdge[87, 253] -> 
             RGBColor[
              0.9212113021251026, 0.9380051283115193, 0.9161080583934463], 
             UndirectedEdge[298, 409] -> 
             RGBColor[
              0.6105489205240312, 0.6941370374682924, 0.9628756303954102], 
             UndirectedEdge[208, 258] -> 
             RGBColor[
              0.9934783139029316, 0.9884590978190089, 0.5315328993943991], 
             UndirectedEdge[142, 161] -> 
             RGBColor[
              0.33616922788314596`, 0.46559462166087084`, 0.9426413838313057],
              UndirectedEdge[71, 211] -> 
             RGBColor[
              0.23787031413452003`, 0.3673471603773484, 0.936857734541142], 
             UndirectedEdge[14, 453] -> 
             RGBColor[
              0.43587796123566236`, 0.5518333953899437, 0.9490289755046595], 
             UndirectedEdge[89, 478] -> 
             RGBColor[
              0.687765263411751, 0.7543960465043716, 0.9707461152036172], 
             UndirectedEdge[159, 251] -> 
             RGBColor[
              0.43566646967110545`, 0.5517741316208221, 0.9489812600960783], 
             UndirectedEdge[300, 305] -> 
             RGBColor[
              0.6399560489314267, 0.7146046131469155, 0.9672716100974765], 
             UndirectedEdge[327, 385] -> 
             RGBColor[
              0.19503845651827315`, 0.32232816232604883`, 0.9344185236139517],
              UndirectedEdge[156, 270] -> 
             RGBColor[
              0.22556593125093138`, 0.35441447382376295`, 0.9361570181386248],
              UndirectedEdge[418, 486] -> 
             RGBColor[
              0.9713257250668036, 0.9117556032768301, 0.43857580784754374`], 
             UndirectedEdge[366, 465] -> 
             RGBColor[
              0.18700818241333977`, 0.3138878350929786, 0.9339612113834017], 
             UndirectedEdge[337, 433] -> 
             RGBColor[
              0.20456821904727826`, 0.3323445469658758, 0.9349612294919583], 
             UndirectedEdge[118, 152] -> 
             RGBColor[
              0.21897053500328645`, 0.3474822941952136, 0.9357814200793358], 
             UndirectedEdge[151, 162] -> 
             RGBColor[
              0.24178469740461808`, 0.3714614253804553, 0.9370806528775629], 
             UndirectedEdge[80, 251] -> 
             RGBColor[
              0.7049995072728927, 0.7670594318463122, 0.9530097354129909], 
             UndirectedEdge[348, 486] -> 
             RGBColor[
              0.9784199418744571, 0.9378791187305058, 0.45471402571610575`], 
             UndirectedEdge[376, 455] -> 
             RGBColor[
              0.8735554698238286, 0.41891480083667676`, 0.4032149808607035], 
             UndirectedEdge[153, 197] -> 
             RGBColor[
              0.4056482253886383, 0.5257738371841758, 0.9470685241144907], 
             UndirectedEdge[9, 319] -> 
             RGBColor[
              0.21511171431873558`, 0.34342642899238807`, 0.9355616659499643],
              UndirectedEdge[184, 336] -> 
             RGBColor[
              0.8369837657282427, 0.26650113164225936`, 0.18231370738115665`],
              UndirectedEdge[41, 56] -> 
             RGBColor[
              0.7988889921505462, 0.8398198339616005, 0.8100291411688312], 
             UndirectedEdge[99, 313] -> 
             RGBColor[
              0.8708575836519874, 0.41710611796942054`, 0.41689029682654455`],
              UndirectedEdge[111, 130] -> 
             RGBColor[
              0.9088647441004855, 0.9288516182784499, 0.9449490739960295], 
             UndirectedEdge[255, 327] -> 
             RGBColor[
              0.22866910912003982`, 0.35767611051703674`, 0.9363337395275303],
              UndirectedEdge[32, 84] -> 
             RGBColor[
              0.5191908481230056, 0.617440223102824, 0.9563757768952883], 
             UndirectedEdge[196, 420] -> 
             RGBColor[
              0.22671171795480946`, 0.35561876829661176`, 0.9362222689963712],
              UndirectedEdge[55, 57] -> 
             RGBColor[
              0.8349696694427251, 0.26979777990945364`, 0.18112030099193344`],
              UndirectedEdge[10, 480] -> 
             RGBColor[
              0.4365798694030919, 0.5518570491641553, 0.9492351453536998], 
             UndirectedEdge[152, 216] -> 
             RGBColor[
              0.23556313755144892`, 0.3649221715050963, 0.9367263442478979], 
             UndirectedEdge[244, 482] -> 
             RGBColor[
              0.9567328878050008, 0.9433863649838862, 0.6793828120829337], 
             UndirectedEdge[111, 463] -> 
             RGBColor[
              0.9024172304136022, 0.6381848846128098, 0.4393327514426538], 
             UndirectedEdge[58, 74] -> 
             RGBColor[
              0.2306608517696206, 0.3597695583255239, 0.9364471663249048], 
             UndirectedEdge[66, 327] -> 
             RGBColor[
              0.23020235366261008`, 0.35928764774459687`, 0.9364210555359976],
              UndirectedEdge[168, 346] -> 
             RGBColor[
              0.8815478026298791, 0.8912128629367583, 0.6835675306232744], 
             UndirectedEdge[53, 471] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[28, 125] -> 
             RGBColor[
              0.8613224849238736, 0.3683564012224616, 0.2021744979333091], 
             UndirectedEdge[405, 423] -> 
             RGBColor[
              0.18539930704922003`, 0.3121968050766989, 0.9338695883115329], 
             UndirectedEdge[314, 493] -> 
             RGBColor[
              0.5954128680509563, 0.6824220151846232, 0.9612922285236236], 
             UndirectedEdge[43, 229] -> 
             RGBColor[
              0.416869736584196, 0.535493346172216, 0.9477835488850788], 
             UndirectedEdge[281, 397] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[203, 324] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[403, 445] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[147, 303] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[356, 457] -> 
             RGBColor[
              0.7242147630598365, 0.7320073272227894, 0.6198326116523992], 
             UndirectedEdge[8, 85] -> 
             RGBColor[
              0.23686771917621463`, 0.36629336950797753`, 0.9368006382414729],
              UndirectedEdge[301, 336] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[24, 64] -> 
             RGBColor[
              0.20529474346718407`, 0.33310817019550554`, 0.9350026039828754],
              UndirectedEdge[30, 488] -> 
             RGBColor[
              0.18669921182250732`, 0.3135630874121468, 0.9339436159653348], 
             UndirectedEdge[191, 366] -> 
             RGBColor[
              0.21187817482284405`, 0.3400277739639608, 0.9353775206592663], 
             UndirectedEdge[185, 481] -> 
             RGBColor[
              0.30650884939950357`, 0.4383924504543215, 0.9408068066885844], 
             UndirectedEdge[308, 389] -> 
             RGBColor[
              0.23917127383072181`, 0.36871455150366533`, 0.9369318222712433],
              UndirectedEdge[96, 240] -> 
             RGBColor[
              0.8633136325544521, 0.3762506380670908, 0.20377662205511446`], 
             UndirectedEdge[108, 113] -> 
             RGBColor[
              0.2834673549063147, 0.4150291714427635, 0.9394633295190601], 
             UndirectedEdge[85, 332] -> 
             RGBColor[
              0.21348039489620751`, 0.3417118088476858, 0.9354687647221722], 
             UndirectedEdge[232, 280] -> 
             RGBColor[
              0.6194682079410706, 0.701127928508344, 0.9637488444766045], 
             UndirectedEdge[310, 419] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[39, 378] -> 
             RGBColor[
              0.4028150168001186, 0.5210545891771114, 0.9473133606661228], 
             UndirectedEdge[53, 257] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[248, 339] -> 
             RGBColor[
              0.184537889109962, 0.31129140020548685`, 0.9338205318342458], 
             UndirectedEdge[327, 334] -> 
             RGBColor[
              0.2064526612899435, 0.33432521524345593`, 0.9350685456898955], 
             UndirectedEdge[165, 358] -> 
             RGBColor[
              0.614683480338821, 0.6933014823842196, 0.9653911750972035], 
             UndirectedEdge[69, 204] -> 
             RGBColor[
              0.9308314245530096, 0.9281676018500284, 0.6853815574337436], 
             UndirectedEdge[208, 293] -> 
             RGBColor[
              0.8758809832712207, 0.41856687329883735`, 0.26948204651397445`],
              UndirectedEdge[265, 320] -> 
             RGBColor[
              0.1953107306009688, 0.32261433965013586`, 0.9344340292201678], 
             UndirectedEdge[239, 453] -> 
             RGBColor[
              0.356563167030866, 0.4781883251778045, 0.9441562255498472], 
             UndirectedEdge[108, 452] -> 
             RGBColor[
              0.35261985676709484`, 0.4798433295674984, 0.9436896033570711], 
             UndirectedEdge[331, 418] -> 
             RGBColor[
              0.8880207099240073, 0.849499175318815, 0.6304330994691307], 
             UndirectedEdge[28, 201] -> 
             RGBColor[
              0.7585570962682471, 0.7484037290263401, 0.6186023673511272], 
             UndirectedEdge[431, 486] -> 
             RGBColor[
              0.9937767608526522, 0.9890974456668459, 0.5640170080704137], 
             UndirectedEdge[269, 419] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[315, 378] -> 
             RGBColor[
              0.24896710191064286`, 0.3790105879070351, 0.9374896801887658], 
             UndirectedEdge[57, 240] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[7, 176] -> 
             RGBColor[
              0.9186174830361646, 0.8816461898151895, 0.6350868762508705], 
             UndirectedEdge[6, 302] -> 
             RGBColor[
              0.4112463925959364, 0.5296760767264955, 0.9476867859622409], 
             UndirectedEdge[176, 455] -> 
             RGBColor[
              0.8394774341752623, 0.3928105343831808, 0.439071427873013], 
             UndirectedEdge[161, 396] -> 
             RGBColor[
              0.29518401055717713`, 0.42546495808357687`, 0.940199381026623], 
             UndirectedEdge[36, 463] -> 
             RGBColor[
              0.831998657058118, 0.24386491747293382`, 0.17815401051060936`], 
             UndirectedEdge[131, 373] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[54, 341] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[272, 453] -> 
             RGBColor[
              0.512128074735658, 0.6148076680340822, 0.9547357445115932], 
             UndirectedEdge[169, 236] -> 
             RGBColor[
              0.2528389722684402, 0.38308016914383974`, 0.9377101774777234], 
             UndirectedEdge[69, 101] -> 
             RGBColor[
              0.7358996157457895, 0.7730701996070706, 0.6676735904233504], 
             UndirectedEdge[286, 330] -> 
             RGBColor[
              0.22011222124554525`, 0.3486822788229162, 0.935846437421859], 
             UndirectedEdge[86, 254] -> 
             RGBColor[
              0.2217593415229328, 0.3504135066679079, 0.9359402384849602], 
             UndirectedEdge[68, 319] -> 
             RGBColor[
              0.19709684259875715`, 0.3244916566058529, 0.9345357456561258], 
             UndirectedEdge[37, 207] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[257, 317] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[94, 158] -> 
             RGBColor[
              0.20645253428145324`, 0.3343250817494799, 0.9350685384569499], 
             UndirectedEdge[253, 336] -> 
             RGBColor[
              0.8742585681452911, 0.41920555006140414`, 0.39156282211394233`],
              UndirectedEdge[67, 363] -> 
             RGBColor[
              0.19105732048097354`, 0.31814373593224315`, 0.9341918038061905],
              UndirectedEdge[61, 295] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[16, 116] -> 
             RGBColor[
              0.6656811252095095, 0.7387544214683854, 0.9673125314832324], 
             UndirectedEdge[294, 439] -> 
             RGBColor[
              0.2411021556117397, 0.370744030680491, 0.9370417831321887], 
             UndirectedEdge[69, 346] -> 
             RGBColor[
              0.9822051197373862, 0.9516358318169333, 0.3853706797712563], 
             UndirectedEdge[327, 415] -> 
             RGBColor[
              0.19254792830447778`, 0.31971045926474073`, 0.9342766917165823],
              UndirectedEdge[54, 61] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[244, 262] -> 
             RGBColor[
              0.9645316855385555, 0.9492026955642121, 0.6661814817722379], 
             UndirectedEdge[295, 397] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[61, 264] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[162, 226] -> 
             RGBColor[
              0.2057449485934193, 0.33358136432783236`, 0.9350282424987957], 
             UndirectedEdge[237, 351] -> 
             RGBColor[
              0.44127436428483835`, 0.5564632104273317, 0.9493850636929899], 
             UndirectedEdge[243, 273] -> 
             RGBColor[
              0.23467481457224915`, 0.36398848773102743`, 0.9366757555683887],
              UndirectedEdge[53, 343] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[37, 445] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[144, 402] -> 
             RGBColor[
              0.3042407743951998, 0.43308654496933563`, 0.9407846324499517], 
             UndirectedEdge[235, 456] -> 
             RGBColor[
              0.2990858824276412, 0.4281169631290464, 0.9404746458614907], 
             UndirectedEdge[369, 456] -> 
             RGBColor[
              0.22153756303757788`, 0.35018040341823176`, 0.935927608528311], 
             UndirectedEdge[7, 61] -> 
             RGBColor[
              0.8626928878488475, 0.3737895921602789, 0.20327715629423396`], 
             UndirectedEdge[76, 175] -> 
             RGBColor[
              0.994576248362856, 0.9912169845602006, 0.6808037761580129], 
             UndirectedEdge[259, 372] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[187, 224] -> 
             RGBColor[
              0.3312204995773527, 0.4600614913307744, 0.9423717063511409], 
             UndirectedEdge[142, 183] -> 
             RGBColor[
              0.2986301457506506, 0.42826119735656343`, 0.940425872375729], 
             UndirectedEdge[255, 299] -> 
             RGBColor[
              0.3581446545361039, 0.47974328518246506`, 0.9442560545474505], 
             UndirectedEdge[233, 444] -> 
             RGBColor[
              0.8285562969045, 0.22050178822288907`, 0.17497884820646079`], 
             UndirectedEdge[148, 280] -> 
             RGBColor[
              0.6081987749178179, 0.6923241617797158, 0.9626256127116859], 
             UndirectedEdge[7, 376] -> 
             RGBColor[
              0.9697345365090141, 0.9208025894954335, 0.5813022057324062], 
             UndirectedEdge[73, 256] -> 
             RGBColor[
              0.8488870131352718, 0.5076989827583813, 0.45340905512865315`], 
             UndirectedEdge[207, 403] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[233, 346] -> 
             RGBColor[
              0.8725424883879621, 0.4075118710378607, 0.23895123788066785`], 
             UndirectedEdge[293, 403] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[321, 391] -> 
             RGBColor[
              0.8623939674573535, 0.3726044724173211, 0.20303663793067456`], 
             UndirectedEdge[228, 298] -> 
             RGBColor[
              0.6261771448274018, 0.7068247340012503, 0.9641059414606434], 
             UndirectedEdge[54, 455] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[323, 419] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[65, 194] -> 
             RGBColor[
              0.2035493121604427, 0.3312736112253837, 0.9349032042520906], 
             UndirectedEdge[40, 273] -> 
             RGBColor[
              0.20975470432853144`, 0.3377958718386327, 0.9352565921560083], 
             UndirectedEdge[209, 400] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[31, 488] -> 
             RGBColor[
              0.2147992220911071, 0.343097979847999, 0.9355438699798917], 
             UndirectedEdge[399, 407] -> 
             RGBColor[
              0.49595107779550673`, 0.5964347568986441, 0.9550832606977075], 
             UndirectedEdge[292, 399] -> 
             RGBColor[
              0.2546203091758611, 0.3849524671768223, 0.9378116219793493], 
             UndirectedEdge[93, 218] -> 
             RGBColor[
              0.5568185669726924, 0.6474379222816083, 0.9598710907741307], 
             UndirectedEdge[198, 270] -> 
             RGBColor[
              0.1889882633050292, 0.3159690256545238, 0.9340739740609163], 
             UndirectedEdge[78, 192] -> 
             RGBColor[
              0.9131433471019068, 0.8814405377612413, 0.6357016426534479], 
             UndirectedEdge[286, 492] -> 
             RGBColor[
              0.20509632372891637`, 0.3328996184700481, 0.9349913042723167], 
             UndirectedEdge[317, 343] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[51, 203] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[212, 216] -> 
             RGBColor[
              0.23063173496240144`, 0.3597389547150244, 0.9364455081658081], 
             UndirectedEdge[100, 257] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[189, 302] -> 
             RGBColor[
              0.5107971785704983, 0.6137271865710165, 0.9546309714902383], 
             UndirectedEdge[306, 382] -> 
             RGBColor[
              0.3931544582199925, 0.514685442356139, 0.9463461835686895], 
             UndirectedEdge[20, 150] -> 
             RGBColor[
              0.40414439209252373`, 0.5240361829288928, 0.9470929232210681], 
             UndirectedEdge[255, 446] -> 
             RGBColor[
              0.22786776900005848`, 0.3568338512430382, 0.9362881043931739], 
             UndirectedEdge[182, 237] -> 
             RGBColor[
              0.6887654101141651, 0.7532085811116003, 0.9550446399454904], 
             UndirectedEdge[4, 366] -> 
             RGBColor[
              0.19231228025278044`, 0.3194627782214574, 0.9342632719086483], 
             UndirectedEdge[231, 275] -> 
             RGBColor[
              0.8560290549644465, 0.34736971536429956`, 0.19791527993518332`],
              UndirectedEdge[97, 231] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[114, 128] -> 
             RGBColor[
              0.21734212015934035`, 0.3457707269467618, 0.935688684262997], 
             UndirectedEdge[207, 471] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[54, 391] -> 
             RGBColor[
              0.8623939674573535, 0.3726044724173211, 0.20303663793067456`], 
             UndirectedEdge[299, 478] -> 
             RGBColor[
              0.4877588950299022, 0.5950236701299144, 0.9528173134179094], 
             UndirectedEdge[44, 365] -> 
             RGBColor[
              0.4996948950434621, 0.5988739938309104, 0.9555332651015185], 
             UndirectedEdge[6, 101] -> 
             RGBColor[
              0.4123451334620635, 0.5305680840593294, 0.9477732828680429], 
             UndirectedEdge[236, 308] -> 
             RGBColor[
              0.26811333291134537`, 0.39913449062993284`, 0.9385800297199454],
              UndirectedEdge[47, 256] -> 
             RGBColor[
              0.7899637501662823, 0.8362108983385758, 0.9796027513224682], 
             UndirectedEdge[304, 427] -> 
             RGBColor[
              0.22064336651454602`, 0.34924054617719114`, 0.9358766853591696],
              UndirectedEdge[54, 397] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[220, 254] -> 
             RGBColor[
              0.2920298352643197, 0.42073811697522306`, 0.9400714411065638], 
             UndirectedEdge[377, 426] -> 
             RGBColor[
              0.2010989407485189, 0.3286981155089309, 0.9347636592251812], 
             UndirectedEdge[216, 292] -> 
             RGBColor[
              0.23746813104113765`, 0.36692444044632255`, 0.9368348308089505],
              UndirectedEdge[42, 119] -> 
             RGBColor[
              0.23711084694980825`, 0.3665489122132156, 0.9368144840085036], 
             UndirectedEdge[170, 491] -> 
             RGBColor[
              0.20371206300908717`, 0.33144467268630884`, 0.9349124726721527],
              UndirectedEdge[257, 326] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[98, 347] -> 
             RGBColor[
              0.251130504754864, 0.38128446146397427`, 0.9376128827802765], 
             UndirectedEdge[271, 311] -> 
             RGBColor[
              0.2655645138375205, 0.3964555201788798, 0.9384348782443309], 
             UndirectedEdge[156, 227] -> 
             RGBColor[
              0.2536615370733401, 0.3839447369074104, 0.937757021326487], 
             UndirectedEdge[151, 160] -> 
             RGBColor[
              0.37027731562653565`, 0.4929640661272292, 0.9449043381372781], 
             UndirectedEdge[93, 167] -> 
             RGBColor[
              0.41563984784251484`, 0.5343156157080063, 0.9477362552278843], 
             UndirectedEdge[275, 348] -> 
             RGBColor[
              0.9480922541811833, 0.8299074254178962, 0.2875220576664841], 
             UndirectedEdge[34, 394] -> 
             RGBColor[
              0.2532945186751018, 0.38355897730055144`, 0.9377361201716623], 
             UndirectedEdge[405, 488] -> 
             RGBColor[
              0.1925687093373611, 0.3197323014478947, 0.9342778751656623], 
             UndirectedEdge[338, 443] -> 
             RGBColor[
              0.8722816554650638, 0.8967727827234393, 0.738216219132237], 
             UndirectedEdge[301, 316] -> 
             RGBColor[
              0.8735231410973765, 0.4108198428949215, 0.24276088847601782`], 
             UndirectedEdge[103, 209] -> 
             RGBColor[
              0.8763449551304583, 0.4195592621909958, 0.3199825200895846], 
             UndirectedEdge[126, 414] -> 
             RGBColor[
              0.9638951205538232, 0.8830011069097463, 0.3908566728809145], 
             UndirectedEdge[154, 341] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[306, 347] -> 
             RGBColor[
              0.37305016758982446`, 0.49488726767115054`, 0.9451524769374224],
              UndirectedEdge[20, 388] -> 
             RGBColor[
              0.6968315144564416, 0.7612822652895019, 0.972005607251501], 
             UndirectedEdge[286, 319] -> 
             RGBColor[
              0.2013361778689116, 0.32894746676416586`, 0.9347771695282268], 
             UndirectedEdge[62, 96] -> 
             RGBColor[
              0.7419154122295191, 0.7443098604712988, 0.6194603335528694], 
             UndirectedEdge[149, 242] -> 
             RGBColor[
              0.8427485102135918, 0.3295893587840956, 0.1885693276990594], 
             UndirectedEdge[212, 319] -> 
             RGBColor[
              0.18959797954384694`, 0.31660987607976354`, 0.9341086964987225],
              UndirectedEdge[289, 470] -> 
             RGBColor[
              0.28003993770811864`, 0.41122301625627355`, 0.939275602455069], 
             UndirectedEdge[291, 353] -> 
             RGBColor[
              0.19170554293633024`, 0.31882505883250056`, 0.9342287191160639],
              UndirectedEdge[21, 91] -> 
             RGBColor[
              0.89309711802987, 0.8758970279199172, 0.6491494129218777], 
             UndirectedEdge[95, 224] -> 
             RGBColor[
              0.24948593288589618`, 0.37955591215781015`, 0.9375192268452648],
              UndirectedEdge[218, 235] -> 
             RGBColor[
              0.543596856175445, 0.6359859409315397, 0.9590286150536299], 
             UndirectedEdge[108, 315] -> 
             RGBColor[
              0.25480773581216487`, 0.38490609465000936`, 0.9378312066097552],
              UndirectedEdge[61, 154] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[297, 413] -> 
             RGBColor[
              0.32997558728000875`, 0.45473309296380404`, 0.9424479992766471],
              UndirectedEdge[294, 438] -> 
             RGBColor[
              0.24844971479729377`, 0.37846678124666755`, 0.9374602157580663],
              UndirectedEdge[277, 386] -> 
             RGBColor[
              0.9122570409032669, 0.9128375594706262, 0.6828459092178139], 
             UndirectedEdge[125, 249] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[211, 308] -> 
             RGBColor[
              0.22315099456572612`, 0.35187622225178283`, 0.936019491066981], 
             UndirectedEdge[273, 477] -> 
             RGBColor[
              0.23729042956947327`, 0.36673766493267923`, 0.9368247109730249],
              UndirectedEdge[154, 397] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[105, 230] -> 
             RGBColor[
              0.26393464830119756`, 0.39474242816076077`, 0.9383420598132073],
              UndirectedEdge[355, 404] -> 
             RGBColor[
              0.8436346237856275, 0.3364004159962053, 0.18941787105636293`], 
             UndirectedEdge[250, 263] -> 
             RGBColor[
              0.37074736764175087`, 0.49554446837193705`, 0.9448446723204758],
              UndirectedEdge[11, 259] -> 
             RGBColor[
              0.8740472245688059, 0.4191181540612454, 0.3950653321159444], 
             UndirectedEdge[339, 439] -> 
             RGBColor[
              0.22536729059950822`, 0.35420568990457246`, 0.9361457058473888],
              UndirectedEdge[303, 379] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[416, 468] -> 
             RGBColor[
              0.33896877720651325`, 0.4680194505753313, 0.9428197686386466], 
             UndirectedEdge[77, 336] -> 
             RGBColor[
              0.8579732191915481, 0.4074969800510354, 0.43870016507762466`], 
             UndirectedEdge[297, 412] -> 
             RGBColor[
              0.23850869796425644`, 0.3680181422582739, 0.9368940895558412], 
             UndirectedEdge[69, 418] -> 
             RGBColor[
              0.9649838420823031, 0.8913513621779137, 0.32989074284540154`], 
             UndirectedEdge[281, 322] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[51, 495] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[227, 229] -> 
             RGBColor[
              0.3363119952168668, 0.45938358895469533`, 0.9428824248934964], 
             UndirectedEdge[192, 497] -> 
             RGBColor[
              0.9083829048728054, 0.8626048061581572, 0.6316742311045528], 
             UndirectedEdge[143, 277] -> 
             RGBColor[
              0.8851303930784559, 0.5071031218256719, 0.24908135364154116`], 
             UndirectedEdge[87, 161] -> 
             RGBColor[
              0.5929939478905595, 0.674186901246545, 0.9641602249639974], 
             UndirectedEdge[114, 255] -> 
             RGBColor[
              0.2236188767018249, 0.35236799604226343`, 0.9360461362624624], 
             UndirectedEdge[341, 391] -> 
             RGBColor[
              0.8623939674573535, 0.3726044724173211, 0.20303663793067456`], 
             UndirectedEdge[35, 347] -> 
             RGBColor[
              0.2497247180796972, 0.37980689053635075`, 0.9375328253088007], 
             UndirectedEdge[99, 498] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[89, 448] -> 
             RGBColor[
              0.8415099289818567, 0.8764611914643559, 0.9847451623227131], 
             UndirectedEdge[130, 371] -> 
             RGBColor[
              0.6899215836975872, 0.756331872704727, 0.9707026743154967], 
             UndirectedEdge[187, 481] -> 
             RGBColor[
              0.32978711964907653`, 0.45855491814461957`, 0.9422900774847212],
              UndirectedEdge[427, 500] -> 
             RGBColor[
              0.24278319621806277`, 0.37251091094186695`, 0.937137515907842], 
             UndirectedEdge[134, 247] -> 
             RGBColor[
              0.20166327316729094`, 0.3292912646618023, 0.9347957971215752], 
             UndirectedEdge[79, 301] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[173, 323] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[84, 262] -> 
             RGBColor[
              0.8153011335016991, 0.8562880262921846, 0.9675016060762058], 
             UndirectedEdge[262, 391] -> 
             RGBColor[
              0.9521974249737493, 0.9065852566536692, 0.6235309398247086], 
             UndirectedEdge[205, 382] -> 
             RGBColor[
              0.38411017432233535`, 0.5071186598844669, 0.9456961385458966], 
             UndirectedEdge[50, 499] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[108, 380] -> 
             RGBColor[
              0.26354993581091446`, 0.3940947011361892, 0.9383290619667581], 
             UndirectedEdge[300, 493] -> 
             RGBColor[
              0.5037769076806964, 0.6070718386737781, 0.9543424489920299], 
             UndirectedEdge[331, 382] -> 
             RGBColor[
              0.5753274532973747, 0.6598063513243815, 0.9626104158765989], 
             UndirectedEdge[186, 495] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[93, 235] -> 
             RGBColor[
              0.3605980717626268, 0.48675365839988305`, 0.9441979681617279], 
             UndirectedEdge[18, 300] -> 
             RGBColor[
              0.5861445158721873, 0.672228635616922, 0.9619978739007018], 
             UndirectedEdge[223, 246] -> 
             RGBColor[
              0.38131973644829154`, 0.5042325916141828, 0.9455639325855753], 
             UndirectedEdge[233, 431] -> 
             RGBColor[
              0.8760289938084724, 0.418883452871858, 0.28559208007867803`], 
             UndirectedEdge[182, 351] -> 
             RGBColor[
              0.7070036360153077, 0.7688374180603554, 0.9562532370834724], 
             UndirectedEdge[163, 209] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[70, 182] -> 
             RGBColor[
              0.9700359047903209, 0.9769432873298111, 0.9253003310773291], 
             UndirectedEdge[59, 335] -> 
             RGBColor[
              0.45879597954340867`, 0.567755451964993, 0.9515747141851782], 
             UndirectedEdge[258, 453] -> 
             RGBColor[
              0.7259167707479581, 0.7801198628667647, 0.7667604716499351], 
             UndirectedEdge[161, 354] -> 
             RGBColor[
              0.5968095021678761, 0.6772293206568155, 0.9645241559371533], 
             UndirectedEdge[213, 489] -> 
             RGBColor[
              0.25642875652489994`, 0.38685326000284664`, 0.9379146103805189],
              UndirectedEdge[260, 407] -> 
             RGBColor[
              0.5001504188796009, 0.6005443225351969, 0.9553335455086889], 
             UndirectedEdge[95, 185] -> 
             RGBColor[
              0.262167272695942, 0.39178664192053536`, 0.9382816194928008], 
             UndirectedEdge[117, 479] -> 
             RGBColor[
              0.1962175335848792, 0.3235674470808556, 0.9344856703086066], 
             UndirectedEdge[164, 444] -> 
             RGBColor[
              0.8609083548821511, 0.5647279142270871, 0.4604935778137573], 
             UndirectedEdge[32, 334] -> 
             RGBColor[
              0.2863539875937741, 0.413601966917996, 0.9397910667757092], 
             UndirectedEdge[46, 325] -> 
             RGBColor[
              0.3561464710176476, 0.48076541432714226`, 0.9439923970496341], 
             UndirectedEdge[18, 201] -> 
             RGBColor[
              0.6609818107872878, 0.7339408987400141, 0.9676252009521262], 
             UndirectedEdge[328, 398] -> 
             RGBColor[
              0.38685571627142323`, 0.5077348812686966, 0.9460900494105111], 
             UndirectedEdge[376, 448] -> 
             RGBColor[
              0.9051283578144917, 0.9255858485156985, 0.9321528841461747], 
             UndirectedEdge[326, 355] -> 
             RGBColor[
              0.8304768118928137, 0.23526370799810264`, 0.17681793552818148`],
              UndirectedEdge[257, 281] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[32, 89] -> 
             RGBColor[
              0.6092109643121336, 0.6880782890419994, 0.965264903215373], 
             UndirectedEdge[341, 397] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[160, 274] -> 
             RGBColor[
              0.4693994767887675, 0.5801186673193949, 0.9513719927612023], 
             UndirectedEdge[151, 235] -> 
             RGBColor[
              0.31653490518961214`, 0.44645699238381964`, 0.941468341894269], 
             UndirectedEdge[11, 372] -> 
             RGBColor[
              0.8740472245688059, 0.4191181540612454, 0.3950653321159444], 
             UndirectedEdge[99, 295] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[154, 199] -> 
             RGBColor[
              0.8752103907398564, 0.4195991531649818, 0.3757886584840803], 
             UndirectedEdge[169, 308] -> 
             RGBColor[
              0.2152452595664099, 0.34356679351495156`, 0.9355692711542569], 
             UndirectedEdge[158, 410] -> 
             RGBColor[
              0.2136055323425038, 0.3418433362379155, 0.9354758911146145], 
             UndirectedEdge[311, 465] -> 
             RGBColor[
              0.20300573055749768`, 0.3307022724956242, 0.9348722480839599], 
             UndirectedEdge[139, 428] -> 
             RGBColor[
              0.20589073788695234`, 0.3337345981189107, 0.9350365449833864], 
             UndirectedEdge[113, 364] -> 
             RGBColor[
              0.2720867421972659, 0.4033107957181348, 0.9388063095006463], 
             UndirectedEdge[89, 475] -> 
             RGBColor[
              0.900525267057583, 0.9233492562361874, 0.984509080001769], 
             UndirectedEdge[375, 441] -> 
             RGBColor[
              0.3248775159216287, 0.45329645143875275`, 0.9420140770036214], 
             UndirectedEdge[244, 295] -> 
             RGBColor[
              0.8706168078338911, 0.40101609835768304`, 0.23147033256236077`],
              UndirectedEdge[187, 260] -> 
             RGBColor[
              0.33960819065109193`, 0.4685732783631712, 0.942860511497924], 
             UndirectedEdge[207, 322] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[100, 457] -> 
             RGBColor[
              0.8638009847389825, 0.3780247266271895, 0.20499214689883155`], 
             UndirectedEdge[364, 416] -> 
             RGBColor[
              0.2990750168791546, 0.43160441949619144`, 0.9403459160671803], 
             UndirectedEdge[313, 386] -> 
             RGBColor[
              0.9107156444731642, 0.9305548067354691, 0.9535847686715226], 
             UndirectedEdge[31, 472] -> 
             RGBColor[
              0.21610683850656687`, 0.34447236760831645`, 0.935618336800307], 
             UndirectedEdge[37, 49] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[201, 406] -> 
             RGBColor[
              0.780813502467645, 0.8246149057210677, 0.7651321037016474], 
             UndirectedEdge[245, 376] -> 
             RGBColor[
              0.7344839183929459, 0.7898007058169793, 0.916823424923582], 
             UndirectedEdge[58, 215] -> 
             RGBColor[
              0.22259684759220016`, 0.35129377864765965`, 0.9359879332166258],
              UndirectedEdge[84, 407] -> 
             RGBColor[
              0.6835079427609747, 0.7526808668284215, 0.9690893420556808], 
             UndirectedEdge[100, 324] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[89, 176] -> 
             RGBColor[
              0.8712929271660014, 0.9002093457784437, 0.9875858912771132], 
             UndirectedEdge[75, 379] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[123, 422] -> 
             RGBColor[
              0.25330157722830876`, 0.3835663962875101, 0.9377365221458253], 
             UndirectedEdge[407, 455] -> 
             RGBColor[
              0.7743008553646631, 0.3415502590426163, 0.43266647927211443`], 
             UndirectedEdge[333, 358] -> 
             RGBColor[
              0.40118802656508795`, 0.5219106371393276, 0.9467843241894529], 
             UndirectedEdge[120, 124] -> 
             RGBColor[
              0.1949045707787678, 0.32218743992498255`, 0.9344108990191531], 
             UndirectedEdge[88, 433] -> 
             RGBColor[
              0.20558699861107904`, 0.3334153488817855, 0.9350192474809674], 
             UndirectedEdge[345, 456] -> 
             RGBColor[
              0.2405210855329868, 0.3701332891857508, 0.9370086920508198], 
             UndirectedEdge[392, 474] -> 
             RGBColor[
              0.4244363391619793, 0.5420471570165883, 0.9482656861104513], 
             UndirectedEdge[165, 333] -> 
             RGBColor[
              0.6312455916187752, 0.707646750738999, 0.9664464981826622], 
             UndirectedEdge[31, 133] -> 
             RGBColor[
              0.2480786626367777, 0.3780767818998994, 0.9374390848864473], 
             UndirectedEdge[171, 208] -> 
             RGBColor[
              0.9742007870656089, 0.924158064524564, 0.38148971018664135`], 
             UndirectedEdge[284, 472] -> 
             RGBColor[
              0.24808825888161617`, 0.3780868681616617, 0.9374396313783945], 
             UndirectedEdge[196, 427] -> 
             RGBColor[
              0.22341549837051072`, 0.3521542325211213, 0.9360345541673653], 
             UndirectedEdge[179, 334] -> 
             RGBColor[
              0.24162960930249294`, 0.37129841795196816`, 0.9370718208395792],
              UndirectedEdge[97, 233] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[21, 409] -> 
             RGBColor[
              0.6816616461375005, 0.7497071065976464, 0.9699591654296765], 
             UndirectedEdge[63, 344] -> 
             RGBColor[
              0.2634249915478959, 0.3942067465989362, 0.9383130356150764], 
             UndirectedEdge[292, 398] -> 
             RGBColor[
              0.2511316087278431, 0.3812856218095713, 0.9376129456499045], 
             UndirectedEdge[71, 197] -> 
             RGBColor[
              0.33670866645889475`, 0.4615510962735853, 0.9428409173993011], 
             UndirectedEdge[81, 121] -> 
             RGBColor[
              0.3705335839034893, 0.4937931661956242, 0.9448883940271157], 
             UndirectedEdge[163, 317] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[167, 172] -> 
             RGBColor[
              0.41770668424733426`, 0.5361058055196428, 0.9478679522159678], 
             UndirectedEdge[191, 488] -> 
             RGBColor[
              0.2118176137321737, 0.33996412041787133`, 0.9353740717947447], 
             UndirectedEdge[392, 490] -> 
             RGBColor[
              0.39194710024697893`, 0.5139066112250432, 0.9461955005358933], 
             UndirectedEdge[251, 272] -> 
             RGBColor[
              0.5091918571496574, 0.6123883835338977, 0.9545144119703061], 
             UndirectedEdge[66, 255] -> 
             RGBColor[
              0.2590437385722598, 0.38960177193405976`, 0.9380635297395968], 
             UndirectedEdge[177, 194] -> 
             RGBColor[
              0.2061405372520611, 0.3339971530898346, 0.9350507706876843], 
             UndirectedEdge[36, 359] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[46, 377] -> 
             RGBColor[
              0.23632008893838022`, 0.36571777540625106`, 0.9367694515095745],
              UndirectedEdge[6, 306] -> 
             RGBColor[
              0.39873016479148204`, 0.5195148391452025, 0.9467014626610211], 
             UndirectedEdge[7, 455] -> 
             RGBColor[
              0.8626928878488475, 0.3737895921602789, 0.20327715629423396`], 
             UndirectedEdge[84, 482] -> 
             RGBColor[
              0.8075023357681443, 0.8504716957118587, 0.9807029363869016], 
             UndirectedEdge[83, 97] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[125, 408] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[184, 473] -> 
             RGBColor[
              0.7413125486005306, 0.611259827036092, 0.5903276772577556], 
             UndirectedEdge[410, 422] -> 
             RGBColor[
              0.24555176281029023`, 0.37542084996755853`, 0.9372951816795421],
              UndirectedEdge[202, 283] -> 
             RGBColor[
              0.2030998829602526, 0.3308012326405268, 0.9348776099240107], 
             UndirectedEdge[320, 329] -> 
             RGBColor[
              0.18940148668971674`, 0.3164033496317062, 0.934097506521365], 
             UndirectedEdge[146, 387] -> 
             RGBColor[
              0.20285490882715684`, 0.330543749294386, 0.9348636590095377], 
             UndirectedEdge[107, 170] -> 
             RGBColor[
              0.2681353000213933, 0.3981722683975148, 0.9386173577788594], 
             UndirectedEdge[273, 459] -> 
             RGBColor[
              0.23015334665587384`, 0.35923613827329337`, 0.9364182646594634],
              UndirectedEdge[5, 395] -> 
             RGBColor[
              0.8502020870562027, 0.32426772933006165`, 0.19322676477969444`],
              UndirectedEdge[104, 242] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[422, 437] -> 
             RGBColor[
              0.24484406285271326`, 0.3746770124413762, 0.9372548792139064], 
             UndirectedEdge[29, 177] -> 
             RGBColor[
              0.20252724292290822`, 0.33019935165380243`, 0.934844998921029], 
             UndirectedEdge[202, 285] -> 
             RGBColor[
              0.2734741466148518, 0.4024082751896524, 0.9389717595036591], 
             UndirectedEdge[182, 460] -> 
             RGBColor[
              0.8895334088722675, 0.9142691218847867, 0.9725212169169912], 
             UndirectedEdge[116, 333] -> 
             RGBColor[
              0.5510899875354679, 0.6448284816425902, 0.958510437577631], 
             UndirectedEdge[405, 472] -> 
             RGBColor[
              0.19387632575282085`, 0.32110668920821217`, 0.9343523419860775],
              UndirectedEdge[51, 96] -> 
             RGBColor[
              0.8633136325544521, 0.3762506380670908, 0.20377662205511443`], 
             UndirectedEdge[115, 402] -> 
             RGBColor[
              0.29155073363812734`, 0.41974850753859727`, 0.9400619534020693],
              UndirectedEdge[67, 120] -> 
             RGBColor[
              0.1852212022017432, 0.3120096055895012, 0.9338594455039515], 
             UndirectedEdge[72, 222] -> 
             RGBColor[
              0.28790125601795724`, 0.4190231172725106, 0.9397402325282525], 
             UndirectedEdge[84, 328] -> 
             RGBColor[
              0.5779012816849092, 0.667647836565725, 0.9602948070979291], 
             UndirectedEdge[123, 401] -> 
             RGBColor[
              0.1977072581497815, 0.3251332420525608, 0.9345705079187279], 
             UndirectedEdge[143, 178] -> 
             RGBColor[
              0.8770300475453819, 0.4797787542910352, 0.21761304086744773`], 
             UndirectedEdge[2, 385] -> 
             RGBColor[
              0.19593294950729245`, 0.32326833117163933`, 0.9344694636663926],
              UndirectedEdge[113, 487] -> 
             RGBColor[
              0.24699167010602574`, 0.37693428383077204`, 0.9373771822698823],
              UndirectedEdge[12, 430] -> 
             RGBColor[
              0.26020424486877647`, 0.39082153763204774`, 0.9381296188563681],
              UndirectedEdge[72, 344] -> 
             RGBColor[
              0.27319882109803817`, 0.4035699259834611, 0.9389029506098664], 
             UndirectedEdge[127, 221] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[466, 491] -> 
             RGBColor[
              0.2191139720880547, 0.34763305566574143`, 0.9357895886091172], 
             UndirectedEdge[236, 289] -> 
             RGBColor[
              0.3096443657778342, 0.4423391471866963, 0.9409615308378128], 
             UndirectedEdge[200, 298] -> 
             RGBColor[
              0.6411018808425886, 0.7189413070500743, 0.9652808713508684], 
             UndirectedEdge[231, 431] -> 
             RGBColor[
              0.8760289938084724, 0.418883452871858, 0.28559208007867803`], 
             UndirectedEdge[171, 238] -> 
             RGBColor[
              0.9459691488713833, 0.8234927105285037, 0.27538371279607904`], 
             UndirectedEdge[276, 306] -> 
             RGBColor[
              0.3968212348923211, 0.5178614200121557, 0.946579827335847], 
             UndirectedEdge[294, 296] -> 
             RGBColor[
              0.2044861367384871, 0.3322582732550172, 0.9349565550259025], 
             UndirectedEdge[1, 119] -> 
             RGBColor[
              0.2343699623005295, 0.3636680686646997, 0.9366583946825027], 
             UndirectedEdge[103, 444] -> 
             RGBColor[
              0.8988195489394581, 0.5923088386367739, 0.34150421650250623`], 
             UndirectedEdge[331, 486] -> 
             RGBColor[
              0.9107995251370908, 0.9275421047601026, 0.7915510675263803], 
             UndirectedEdge[100, 281] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[161, 477] -> 
             RGBColor[
              0.29594928626027256`, 0.4262693113688122, 0.9402429623457904], 
             UndirectedEdge[391, 475] -> 
             RGBColor[
              0.9474014423405053, 0.9030084206584965, 0.6316492874301871], 
             UndirectedEdge[2, 312] -> 
             RGBColor[
              0.2248220487628299, 0.35363260616389447`, 0.936114655131403], 
             UndirectedEdge[264, 341] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[73, 434] -> 
             RGBColor[
              0.8329068192640983, 0.2539418094898154, 0.17914491333122431`], 
             UndirectedEdge[241, 271] -> 
             RGBColor[
              0.3224050139052927, 0.4532867845480669, 0.9417784724221802], 
             UndirectedEdge[49, 51] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[5, 275] -> 
             RGBColor[
              0.8560290549644465, 0.34736971536429956`, 0.19791527993518332`],
              UndirectedEdge[18, 274] -> 
             RGBColor[
              0.6190583277740055, 0.6999055265984445, 0.9643248307985424], 
             UndirectedEdge[219, 445] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[177, 297] -> 
             RGBColor[
              0.22585915082839916`, 0.35472266619087656`, 0.9361737165597821],
              UndirectedEdge[250, 365] -> 
             RGBColor[
              0.3297610853863787, 0.45923924976533154`, 0.9422625362213943], 
             UndirectedEdge[325, 474] -> 
             RGBColor[
              0.4167250002286474, 0.5353679828157005, 0.9477743264124886], 
             UndirectedEdge[266, 403] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[214, 470] -> 
             RGBColor[
              0.2312739543273467, 0.36041396798664144`, 0.9364820816085633], 
             UndirectedEdge[152, 481] -> 
             RGBColor[
              0.24709358576825113`, 0.3770414036535972, 0.9373829862160753], 
             UndirectedEdge[289, 466] -> 
             RGBColor[
              0.28062655967903927`, 0.4118395931416923, 0.9393090097084835], 
             UndirectedEdge[126, 269] -> 
             RGBColor[
              0.8563654629268306, 0.3487034608338446, 0.19818596167822738`], 
             UndirectedEdge[183, 396] -> 
             RGBColor[
              0.2576449284246818, 0.38813153377926946`, 0.9379838695710464], 
             UndirectedEdge[54, 99] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[129, 306] -> 
             RGBColor[
              0.611794552731207, 0.6939125455037445, 0.9638185817259406], 
             UndirectedEdge[172, 236] -> 
             RGBColor[
              0.34183025049144444`, 0.4702169428160228, 0.9430123869509037], 
             UndirectedEdge[162, 284] -> 
             RGBColor[
              0.24849792958903924`, 0.3785174580497864, 0.9374629615191288], 
             UndirectedEdge[10, 189] -> 
             RGBColor[
              0.46358589832160735`, 0.5737817600479446, 0.9513611588765089], 
             UndirectedEdge[213, 332] -> 
             RGBColor[
              0.24567430192070422`, 0.375549646342032, 0.9373021601005997], 
             UndirectedEdge[199, 245] -> 
             RGBColor[
              0.7369662997669877, 0.7908272343094369, 0.8756839413586472], 
             UndirectedEdge[123, 139] -> 
             RGBColor[
              0.20173923156575024`, 0.3293711017546237, 0.9348001228399971], 
             UndirectedEdge[391, 482] -> 
             RGBColor[
              0.9443986272401945, 0.9007689260733432, 0.6367322701354043], 
             UndirectedEdge[184, 354] -> 
             RGBColor[
              0.8691146527768465, 0.7119909200930725, 0.6025983172674237], 
             UndirectedEdge[25, 316] -> 
             RGBColor[
              0.8717687253392568, 0.8873861911944285, 0.6881607060366124], 
             UndirectedEdge[106, 479] -> 
             RGBColor[
              0.18778223780521028`, 0.31470141638778093`, 0.9340052926928564],
              UndirectedEdge[118, 260] -> 
             RGBColor[
              0.2740921498982324, 0.4051143982656095, 0.938931653051092], 
             UndirectedEdge[304, 469] -> 
             RGBColor[
              0.20952654949252203`, 0.3375560666401347, 0.9352435990756223], 
             UndirectedEdge[93, 236] -> 
             RGBColor[
              0.339763414086625, 0.46842675300438635`, 0.9428806899628203], 
             UndirectedEdge[343, 445] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[204, 444] -> 
             RGBColor[
              0.8607679520740443, 0.5646159608390356, 0.460480186068581], 
             UndirectedEdge[150, 412] -> 
             RGBColor[
              0.2833356085457537, 0.41234186764598774`, 0.9395491519114617], 
             UndirectedEdge[14, 239] -> 
             RGBColor[
              0.3345592647628135, 0.4592535705757248, 0.9427199170015113], 
             UndirectedEdge[70, 442] -> 
             RGBColor[
              0.7163330593542951, 0.7749857656872733, 0.9191984709357774], 
             UndirectedEdge[93, 493] -> 
             RGBColor[
              0.4816317249932974, 0.5878907944791983, 0.952931377533405], 
             UndirectedEdge[228, 279] -> 
             RGBColor[
              0.4383339124328404, 0.5504152423024345, 0.9500617664474421], 
             UndirectedEdge[300, 456] -> 
             RGBColor[
              0.3344527759122877, 0.4587499886736949, 0.9427281930406164], 
             UndirectedEdge[168, 326] -> 
             RGBColor[
              0.8049147133652906, 0.36546603758664487`, 0.4357177825348484], 
             UndirectedEdge[193, 437] -> 
             RGBColor[
              0.18967305081090496`, 0.3166887807412348, 0.9341129716963235], 
             UndirectedEdge[224, 361] -> 
             RGBColor[
              0.3524580819682026, 0.4784564177658006, 0.943724946321429], 
             UndirectedEdge[12, 477] -> 
             RGBColor[
              0.25210090277797115`, 0.38230441131304815`, 0.9376681455121172],
              UndirectedEdge[212, 224] -> 
             RGBColor[
              0.24359556310747985`, 0.37336476004968, 0.9371837790004052], 
             UndirectedEdge[220, 490] -> 
             RGBColor[
              0.34441527509151576`, 0.47273693329437716`, 0.9431668146677299],
              UndirectedEdge[175, 208] -> 
             RGBColor[
              0.9939061257043407, 0.9897836599534299, 0.6078650602962729], 
             UndirectedEdge[242, 419] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[164, 205] -> 
             RGBColor[
              0.6628616176318347, 0.7337956536330927, 0.9690297243445348], 
             UndirectedEdge[257, 322] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[7, 54] -> 
             RGBColor[
              0.8626928878488475, 0.3737895921602789, 0.20327715629423396`], 
             UndirectedEdge[26, 67] -> 
             RGBColor[
              0.1959716730389698, 0.32330903205864586`, 0.9344716689142352], 
             UndirectedEdge[366, 488] -> 
             RGBColor[
              0.19450193224029588`, 0.32176424129229075`, 0.9343879693500374],
              UndirectedEdge[12, 243] -> 
             RGBColor[
              0.249485287780747, 0.37955523411139636`, 0.9375191901074809], 
             UndirectedEdge[271, 307] -> 
             RGBColor[
              0.26941629466210404`, 0.4005039860425267, 0.9386542314640918], 
             UndirectedEdge[9, 352] -> 
             RGBColor[
              0.22055895151159555`, 0.3491518206568699, 0.9358718780496325], 
             UndirectedEdge[404, 431] -> 
             RGBColor[
              0.8760289938084724, 0.418883452871858, 0.28559208007867803`], 
             UndirectedEdge[256, 287] -> 
             RGBColor[
              0.8515970726599524, 0.8845044060250485, 0.9857072830916294], 
             UndirectedEdge[254, 412] -> 
             RGBColor[
              0.2324070785907567, 0.36160495343171317`, 0.9365466113590574], 
             UndirectedEdge[42, 380] -> 
             RGBColor[
              0.2438951722116548, 0.3736796682144823, 0.9372008412956561], 
             UndirectedEdge[379, 404] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[134, 424] -> 
             RGBColor[
              0.2214617006289249, 0.3501006672167829, 0.9359232882763666], 
             UndirectedEdge[38, 253] -> 
             RGBColor[
              0.9437188064028268, 0.8124944389214359, 0.5419690901557521], 
             UndirectedEdge[103, 348] -> 
             RGBColor[
              0.978566104430201, 0.9381917456579405, 0.470622917898086], 
             UndirectedEdge[42, 452] -> 
             RGBColor[
              0.3329650931678352, 0.45942829664579143`, 0.942561382685969], 
             UndirectedEdge[164, 331] -> 
             RGBColor[
              0.854078896606874, 0.8864833450730073, 0.9859440016752372], 
             UndirectedEdge[6, 181] -> 
             RGBColor[
              0.36099048155066216`, 0.4870935440351898, 0.9442229721664271], 
             UndirectedEdge[172, 197] -> 
             RGBColor[
              0.39570626447019996`, 0.5171626103341097, 0.9464350311560986], 
             UndirectedEdge[80, 258] -> 
             RGBColor[
              0.9759706321031365, 0.9788304292212378, 0.7695262555512177], 
             UndirectedEdge[223, 268] -> 
             RGBColor[
              0.25782358431552455`, 0.3883193124479829, 0.9379940437597322], 
             UndirectedEdge[5, 69] -> 
             RGBColor[
              0.8720195914369621, 0.40574801684009487`, 0.23691988196683633`],
              UndirectedEdge[306, 486] -> 
             RGBColor[
              0.7286265300597087, 0.7824211957918601, 0.775286835218471], 
             UndirectedEdge[5, 348] -> 
             RGBColor[
              0.8657911144896757, 0.38473790158096455`, 0.21272342517580606`],
              UndirectedEdge[279, 409] -> 
             RGBColor[
              0.42270568812946974`, 0.5377275457694766, 0.9488314553822088], 
             UndirectedEdge[463, 483] -> 
             RGBColor[
              0.8980458063387537, 0.6139805254867295, 0.2518434419429105], 
             UndirectedEdge[351, 371] -> 
             RGBColor[
              0.5030810091361415, 0.6074628526147339, 0.9540235263671059], 
             UndirectedEdge[335, 421] -> 
             RGBColor[
              0.25863015359246655`, 0.38858598467637967`, 0.9380612529900733],
              UndirectedEdge[259, 418] -> 
             RGBColor[
              0.8610616366179067, 0.36732222461184755`, 0.20196461326343138`],
              UndirectedEdge[168, 302] -> 
             RGBColor[
              0.6341435577721554, 0.7117552233940616, 0.9657839443695666], 
             UndirectedEdge[87, 336] -> 
             RGBColor[
              0.8296409666047774, 0.38496720214627544`, 0.43813321681502193`],
              UndirectedEdge[36, 266] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[161, 430] -> 
             RGBColor[
              0.3040526283510779, 0.4347864376878118, 0.9407044356900414], 
             UndirectedEdge[220, 412] -> 
             RGBColor[
              0.2873479361219482, 0.41581714412703974`, 0.9398048138766548], 
             UndirectedEdge[372, 404] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[38, 287] -> 
             RGBColor[
              0.8686172360380824, 0.7546182599515294, 0.6110449273803248], 
             UndirectedEdge[171, 497] -> 
             RGBColor[
              0.9509833426511693, 0.843372317984329, 0.27941825080954996`], 
             UndirectedEdge[246, 411] -> 
             RGBColor[
              0.5849971602778163, 0.6728945252540688, 0.9612048898516654], 
             UndirectedEdge[75, 303] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[23, 39] -> 
             RGBColor[
              0.7492481098657082, 0.7981399836975582, 0.6930866813159002], 
             UndirectedEdge[61, 391] -> 
             RGBColor[
              0.8623939674573535, 0.3726044724173211, 0.20303663793067456`], 
             UndirectedEdge[19, 200] -> 
             RGBColor[
              0.44299594892189786`, 0.5517450674565645, 0.9506522507819574], 
             UndirectedEdge[208, 403] -> 
             RGBColor[
              0.8758809832712207, 0.41856687329883735`, 0.26948204651397445`],
              UndirectedEdge[108, 378] -> 
             RGBColor[
              0.3055376194253575, 0.43822641878786983`, 0.940720198433389], 
             UndirectedEdge[10, 451] -> 
             RGBColor[
              0.3426842136829911, 0.46965323577309337`, 0.9431145233823018], 
             UndirectedEdge[199, 262] -> 
             RGBColor[
              0.9714220598975036, 0.9770772777751602, 0.8826589706548171], 
             UndirectedEdge[3, 401] -> 
             RGBColor[
              0.19299516587638807`, 0.32018053430931837`, 0.934302161234674], 
             UndirectedEdge[241, 311] -> 
             RGBColor[
              0.28339808968705427`, 0.4122880340128587, 0.9395570857935246], 
             UndirectedEdge[179, 255] -> 
             RGBColor[
              0.26384605713258924`, 0.39464931322554897`, 0.9383370146772139],
              UndirectedEdge[276, 462] -> 
             RGBColor[
              0.2787032871192142, 0.40825445737764454`, 0.9392567352273402], 
             UndirectedEdge[167, 289] -> 
             RGBColor[
              0.38552079953372403`, 0.5082280098903162, 0.9458170961028769], 
             UndirectedEdge[164, 348] -> 
             RGBColor[
              0.9216993133442403, 0.8968203590434105, 0.6491069598649626], 
             UndirectedEdge[18, 172] -> 
             RGBColor[
              0.5660661695896078, 0.6548377812339787, 0.9607184994301604], 
             UndirectedEdge[289, 300] -> 
             RGBColor[
              0.36584591693848256`, 0.4912990781268415, 0.9445323562158461], 
             UndirectedEdge[59, 188] -> 
             RGBColor[
              0.4914195289334753, 0.5960123307393997, 0.9536534579044413], 
             UndirectedEdge[352, 357] -> 
             RGBColor[
              0.20925693798184208`, 0.337272687848053, 0.9352282450989436], 
             UndirectedEdge[161, 409] -> 
             RGBColor[
              0.4365148251401427, 0.5501192931853284, 0.9496955815684055], 
             UndirectedEdge[39, 157] -> 
             RGBColor[
              0.6618299544269467, 0.7336559859969052, 0.9683575393881558], 
             UndirectedEdge[216, 398] -> 
             RGBColor[
              0.2829967109142827, 0.4147778645716886, 0.939427616079228], 
             UndirectedEdge[279, 396] -> 
             RGBColor[
              0.28137487354650415`, 0.413073210667725, 0.9393352548404263], 
             UndirectedEdge[103, 390] -> 
             RGBColor[
              0.7762674998542347, 0.8212922468524215, 0.7949346926054996], 
             UndirectedEdge[128, 296] -> 
             RGBColor[
              0.21905420866091074`, 0.34757024051459295`, 0.9357861851703535],
              UndirectedEdge[362, 369] -> 
             RGBColor[
              0.18627079750730335`, 0.313112796803831, 0.9339192184038662], 
             UndirectedEdge[86, 412] -> 
             RGBColor[
              0.2170774423805613, 0.34549253381972456`, 0.9356736112550512], 
             UndirectedEdge[261, 299] -> 
             RGBColor[
              0.6925921556774102, 0.7578254740416488, 0.9716892363428151], 
             UndirectedEdge[208, 266] -> 
             RGBColor[
              0.8758809832712207, 0.41856687329883735`, 0.26948204651397445`],
              UndirectedEdge[211, 236] -> 
             RGBColor[
              0.26074470726775645`, 0.39138959788067107`, 0.9381603973904477],
              UndirectedEdge[19, 124] -> 
             RGBColor[
              0.24511713728705276`, 0.3749640309857861, 0.9372704303989646], 
             UndirectedEdge[319, 330] -> 
             RGBColor[
              0.20604176576710181`, 0.3338933379966685, 0.9350451457977351], 
             UndirectedEdge[137, 267] -> 
             RGBColor[
              0.3633910087702312, 0.4891727600587743, 0.9443759316381551], 
             UndirectedEdge[23, 240] -> 
             RGBColor[
              0.8757337238850049, 0.41825190036192983`, 0.2534537711039848], 
             UndirectedEdge[135, 369] -> 
             RGBColor[
              0.18790542144841682`, 0.3148308902070851, 0.9340123078191032], 
             UndirectedEdge[13, 335] -> 
             RGBColor[
              0.4272745801579895, 0.5421649599210498, 0.9490932341588676], 
             UndirectedEdge[176, 178] -> 
             RGBColor[
              0.9202554048713663, 0.8879171799621041, 0.6375652584344874], 
             UndirectedEdge[335, 459] -> 
             RGBColor[
              0.28047616225378147`, 0.41154752489637136`, 0.9393053508650615],
              UndirectedEdge[83, 326] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[33, 76] -> 
             RGBColor[
              0.7773631602461192, 0.8221474687086947, 0.7922109863395075], 
             UndirectedEdge[13, 285] -> 
             RGBColor[
              0.4368990030776415, 0.5505011513164912, 0.9497064938767648], 
             UndirectedEdge[225, 309] -> 
             RGBColor[
              0.20974081891219415`, 0.337781277385676, 0.9352558014020895], 
             UndirectedEdge[242, 499] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[13, 287] -> 
             RGBColor[
              0.68872640512068, 0.7553272678291727, 0.9706480699800565], 
             UndirectedEdge[265, 270] -> 
             RGBColor[
              0.1931041910883242, 0.32029512671966087`, 0.9343083700592054], 
             UndirectedEdge[191, 311] -> 
             RGBColor[
              0.22787572296700198`, 0.35684221136660643`, 0.9362885573598245],
              UndirectedEdge[47, 452] -> 
             RGBColor[
              0.5542646894631771, 0.6462940052378033, 0.9592562795562067], 
             UndirectedEdge[14, 80] -> 
             RGBColor[
              0.6859318225908408, 0.7505439617444168, 0.951794759405942], 
             UndirectedEdge[152, 292] -> 
             RGBColor[
              0.20369803536500936`, 0.33142992874297905`, 0.9349116738185744],
              UndirectedEdge[133, 311] -> 
             RGBColor[
              0.24377892093012438`, 0.3735574807468368, 0.9371942209571512], 
             UndirectedEdge[187, 398] -> 
             RGBColor[
              0.3319201491189798, 0.46079686735936753`, 0.9424115503574978], 
             UndirectedEdge[130, 442] -> 
             RGBColor[
              0.6401413651407276, 0.7157489165078108, 0.9668305248903115], 
             UndirectedEdge[304, 433] -> 
             RGBColor[
              0.2080639244096152, 0.3360187549422132, 0.9351603047409107], 
             UndirectedEdge[354, 409] -> 
             RGBColor[
              0.7016213313412318, 0.7656224177878801, 0.9718629380226298], 
             UndirectedEdge[29, 412] -> 
             RGBColor[
              0.2151767900587655, 0.34349482772119977`, 0.935565371917088], 
             UndirectedEdge[295, 391] -> 
             RGBColor[
              0.8623939674573535, 0.3726044724173211, 0.20303663793067456`], 
             UndirectedEdge[21, 298] -> 
             RGBColor[
              0.7508839123480333, 0.8053317537495459, 0.9758004321712048], 
             UndirectedEdge[383, 395] -> 
             RGBColor[
              0.7742514426418383, 0.7085541585318539, 0.6077294417407735], 
             UndirectedEdge[133, 241] -> 
             RGBColor[
              0.30061942099789657`, 0.430388745116024, 0.9405378151350005], 
             UndirectedEdge[142, 473] -> 
             RGBColor[
              0.4734736299079191, 0.580366653206442, 0.9525381002758618], 
             UndirectedEdge[95, 330] -> 
             RGBColor[
              0.2142643926988969, 0.3425358402466441, 0.9355134122372144], 
             UndirectedEdge[275, 431] -> 
             RGBColor[
              0.9634490731593783, 0.8811257523542364, 0.396825040020792], 
             UndirectedEdge[180, 474] -> 
             RGBColor[
              0.505167391968821, 0.6078946403171526, 0.9545364772327231], 
             UndirectedEdge[82, 173] -> 
             RGBColor[
              0.844192723800754, 0.2992353265545988, 0.18832903870459236`], 
             UndirectedEdge[205, 230] -> 
             RGBColor[
              0.3700829820093897, 0.493707900841167, 0.944848513673534], 
             UndirectedEdge[460, 463] -> 
             RGBColor[
              0.8490960260828695, 0.5965456532875175, 0.46506056118722205`], 
             UndirectedEdge[121, 500] -> 
             RGBColor[
              0.28288233778375105`, 0.41465765115982456`, 0.9394211026986441],
              UndirectedEdge[88, 241] -> 
             RGBColor[
              0.28248141588286296`, 0.41132455172417753`, 0.9395048825764732],
              UndirectedEdge[60, 73] -> 
             RGBColor[
              0.8251129096320492, 0.19403440474490768`, 0.17168145666561216`],
              UndirectedEdge[75, 400] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[141, 274] -> 
             RGBColor[
              0.39256014440333986`, 0.5129069049942494, 0.9464898857156867], 
             UndirectedEdge[299, 448] -> 
             RGBColor[
              0.6415035606000079, 0.7170888150898986, 0.9668163605370053], 
             UndirectedEdge[160, 389] -> 
             RGBColor[
              0.35134205464567747`, 0.4730619062714598, 0.9438260030366266], 
             UndirectedEdge[24, 268] -> 
             RGBColor[
              0.20851588844890323`, 0.3364937978036801, 0.9351860434243273], 
             UndirectedEdge[386, 498] -> 
             RGBColor[
              0.8260448459967887, 0.38209975318755884`, 0.4377902156211372], 
             UndirectedEdge[350, 476] -> 
             RGBColor[
              0.19421935887497294`, 0.3214672387691502, 0.9343718772149121], 
             UndirectedEdge[180, 331] -> 
             RGBColor[
              0.7154954793572077, 0.7771351534675488, 0.9726684783764996], 
             UndirectedEdge[225, 252] -> 
             RGBColor[
              0.1970572565472313, 0.32445004915579856`, 0.9345334912890539], 
             UndirectedEdge[100, 203] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[445, 471] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[373, 498] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[102, 309] -> 
             RGBColor[
              0.24307505381461134`, 0.3728176717806799, 0.9371541367662009], 
             UndirectedEdge[46, 86] -> 
             RGBColor[
              0.24605549105412944`, 0.3759503002900489, 0.9373238682578297], 
             UndirectedEdge[294, 385] -> 
             RGBColor[
              0.2030350129630147, 0.3307330501604344, 0.9348739156736345], 
             UndirectedEdge[27, 29] -> 
             RGBColor[
              0.20431304380785625`, 0.33207634161019856`, 0.9349466976395711],
              UndirectedEdge[274, 284] -> 
             RGBColor[
              0.39152884276049793`, 0.5118229415793216, 0.9464311546128009], 
             UndirectedEdge[284, 300] -> 
             RGBColor[
              0.3586150308586798, 0.48414605059779925`, 0.9441041977149605], 
             UndirectedEdge[159, 453] -> 
             RGBColor[
              0.4386026872571061, 0.5541934161210065, 0.9492025926373653], 
             UndirectedEdge[229, 232] -> 
             RGBColor[
              0.5642482406538483, 0.6557297115102981, 0.9595587106539356], 
             UndirectedEdge[259, 431] -> 
             RGBColor[
              0.8760289938084724, 0.418883452871858, 0.28559208007867803`], 
             UndirectedEdge[112, 483] -> 
             RGBColor[
              0.8686864922225178, 0.39450469054086185`, 0.22397142092169176`],
              UndirectedEdge[78, 376] -> 
             RGBColor[
              0.9710596774572359, 0.9260184962661202, 0.5825654932338206], 
             UndirectedEdge[76, 351] -> 
             RGBColor[
              0.7269288926583368, 0.7812026582430701, 0.7882406160481877], 
             UndirectedEdge[178, 498] -> 
             RGBColor[
              0.8637848357389819, 0.37797025225822195`, 0.20492941108331195`],
              UndirectedEdge[400, 431] -> 
             RGBColor[
              0.8760289938084724, 0.418883452871858, 0.28559208007867803`], 
             UndirectedEdge[18, 432] -> 
             RGBColor[
              0.7627827717291649, 0.8146109657293871, 0.9769907161418333], 
             UndirectedEdge[220, 325] -> 
             RGBColor[
              0.38679117901764243`, 0.5094408114003279, 0.9458669697943621], 
             UndirectedEdge[353, 380] -> 
             RGBColor[
              0.2011595261565179, 0.3287617946140746, 0.9347671094745387], 
             UndirectedEdge[5, 355] -> 
             RGBColor[
              0.8304768118928137, 0.23526370799810264`, 0.17681793552818148`],
              UndirectedEdge[367, 441] -> 
             RGBColor[
              0.31283134784024597`, 0.44063516501404976`, 0.9413280655520953],
              UndirectedEdge[21, 287] -> 
             RGBColor[
              0.8299656008339436, 0.8672560575616497, 0.9836440539982219], 
             UndirectedEdge[175, 182] -> 
             RGBColor[
              0.9746509917198269, 0.978851744377486, 0.8488163971932976], 
             UndirectedEdge[70, 371] -> 
             RGBColor[
              0.7661132779111547, 0.8155687218841894, 0.9230706203609627], 
             UndirectedEdge[217, 496] -> 
             RGBColor[
              0.19874942051831446`, 0.3262286207787995, 0.9346298575238747], 
             UndirectedEdge[195, 292] -> 
             RGBColor[
              0.2120103022106906, 0.3401666482259477, 0.9353850451185391], 
             UndirectedEdge[161, 285] -> 
             RGBColor[
              0.33299137779354726`, 0.4628421276366501, 0.942438894033659], 
             UndirectedEdge[168, 370] -> 
             RGBColor[
              0.5916646117623022, 0.6759087069348095, 0.9628156719089096], 
             UndirectedEdge[50, 173] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[19, 188] -> 
             RGBColor[
              0.3319186677271597, 0.45958431970506974`, 0.9424558062931185], 
             UndirectedEdge[147, 323] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[255, 260] -> 
             RGBColor[
              0.284773382847451, 0.41634105132452215`, 0.9395399334660819], 
             UndirectedEdge[29, 350] -> 
             RGBColor[
              0.19637165723223093`, 0.3237294408062259, 0.9344944474223179], 
             UndirectedEdge[348, 400] -> 
             RGBColor[
              0.8657911144896757, 0.38473790158096466`, 0.21272342517580606`],
              UndirectedEdge[26, 124] -> 
             RGBColor[
              0.2056550416159944, 0.33348686639412717`, 0.9350231224294367], 
             UndirectedEdge[18, 93] -> 
             RGBColor[
              0.5639993331847883, 0.6530475914223423, 0.960586802442077], 
             UndirectedEdge[64, 223] -> 
             RGBColor[
              0.2546024393338054, 0.3849336848398083, 0.9378106043182802], 
             UndirectedEdge[12, 335] -> 
             RGBColor[
              0.27951857139159386`, 0.4105410361854448, 0.9392508174820886], 
             UndirectedEdge[143, 498] -> 
             RGBColor[
              0.8305642118064, 0.2359355020328133, 0.17690162978413582`], 
             UndirectedEdge[44, 92] -> 
             RGBColor[
              0.6785116985525852, 0.7487777628799652, 0.9685913631255452], 
             UndirectedEdge[274, 389] -> 
             RGBColor[
              0.36588034959521865`, 0.4848647490542211, 0.9449705108705836], 
             UndirectedEdge[247, 401] -> 
             RGBColor[
              0.19433196502451466`, 0.32158559497196076`, 0.9343782899685427],
              UndirectedEdge[111, 182] -> 
             RGBColor[
              0.9695152153683666, 0.9767279688727253, 0.933929502300139], 
             UndirectedEdge[157, 190] -> 
             RGBColor[
              0.5811750262089507, 0.6652253629216612, 0.9628235461914189], 
             UndirectedEdge[100, 360] -> 
             RGBColor[
              0.8191009627097754, 0.1478239462483719, 0.1659244095033199], 
             UndirectedEdge[59, 468] -> 
             RGBColor[
              0.48548279693465646`, 0.5908702318708492, 0.9532751745911225], 
             UndirectedEdge[101, 129] -> 
             RGBColor[
              0.6254095214017883, 0.7049657904178714, 0.9648904019329624], 
             UndirectedEdge[180, 382] -> 
             RGBColor[
              0.46332842266028784`, 0.5716558279898428, 0.9518705351051313], 
             UndirectedEdge[145, 402] -> 
             RGBColor[
              0.33044282611088804`, 0.46062656262855517`, 0.9422768005326982],
              UndirectedEdge[90, 263] -> 
             RGBColor[
              0.4902638758215754, 0.5951212073056378, 0.9535494701520902], 
             UndirectedEdge[98, 276] -> 
             RGBColor[
              0.2749015720573606, 0.4042586138049795, 0.9390402331787011], 
             UndirectedEdge[224, 464] -> 
             RGBColor[
              0.28776523572535795`, 0.41978988649006416`, 0.9396991765128184],
              UndirectedEdge[261, 313] -> 
             RGBColor[
              0.9521701236341322, 0.9636094831665644, 0.9575387339007462], 
             UndirectedEdge[78, 219] -> 
             RGBColor[
              0.863576315147662, 0.3772668633407367, 0.20411934796184356`], 
             UndirectedEdge[393, 424] -> 
             RGBColor[
              0.3045464501938735, 0.4319945031262181, 0.9408537890405738], 
             UndirectedEdge[169, 211] -> 
             RGBColor[
              0.20787663392282102`, 0.33582190076568974`, 0.9351496388247592],
              UndirectedEdge[176, 482] -> 
             RGBColor[
              0.9100238273170578, 0.9310780190221328, 0.9907844550489121], 
             UndirectedEdge[35, 94] -> 
             RGBColor[
              0.19771231040963783`, 0.3251385522980016, 0.9345707956374525], 
             UndirectedEdge[114, 296] -> 
             RGBColor[
              0.19143934787553057`, 0.3185452709458584, 0.9342135597011516], 
             UndirectedEdge[130, 175] -> 
             RGBColor[
              0.9140005204519457, 0.9309753937832106, 0.859835968889188], 
             UndirectedEdge[189, 383] -> 
             RGBColor[
              0.5829740029038133, 0.6723235840936835, 0.960312995494176], 
             UndirectedEdge[139, 437] -> 
             RGBColor[
              0.19328171719015474`, 0.3204817179084898, 0.9343184799080784], 
             UndirectedEdge[56, 324] -> 
             RGBColor[
              0.8764265597457015, 0.4197338062115088, 0.3288646788534969], 
             UndirectedEdge[398, 399] -> 
             RGBColor[
              0.30014888904900616`, 0.43280589130218833`, 0.9404044072496268],
              UndirectedEdge[405, 429] -> 
             RGBColor[
              0.2128579033922896, 0.34105753080882717`, 0.9354333147519176], 
             UndirectedEdge[12, 318] -> 
             RGBColor[
              0.2525038287839251, 0.3827279120922901, 0.9376910915520806], 
             UndirectedEdge[11, 205] -> 
             RGBColor[
              0.7162818128753168, 0.7745053780529972, 0.9031699004171979], 
             UndirectedEdge[226, 389] -> 
             RGBColor[
              0.23071843962178798`, 0.35983008680943257`, 0.9364504458678921],
              UndirectedEdge[294, 327] -> 
             RGBColor[
              0.20782428065513164`, 0.3357668741619594, 0.935146657383614], 
             UndirectedEdge[167, 218] -> 
             RGBColor[
              0.5986386322553329, 0.683547898239663, 0.9625669021197863], 
             UndirectedEdge[217, 481] -> 
             RGBColor[
              0.2406474095261515, 0.3702660637119706, 0.9370158860153509], 
             UndirectedEdge[247, 309] -> 
             RGBColor[
              0.21041747928262017`, 0.3384924903377391, 0.9352943362091559], 
             UndirectedEdge[79, 234] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[331, 372] -> 
             RGBColor[
              0.8207108366647649, 0.3778465589340292, 0.4372814530493224], 
             UndirectedEdge[27, 484] -> 
             RGBColor[
              0.20513686464962994`, 0.3329422295481609, 0.9349936130177764], 
             UndirectedEdge[103, 326] -> 
             RGBColor[
              0.8763449551304583, 0.4195592621909958, 0.3199825200895846], 
             UndirectedEdge[155, 394] -> 
             RGBColor[
              0.22097523638302924`, 0.34958936245073197`, 0.9358955848572224],
              UndirectedEdge[433, 469] -> 
             RGBColor[
              0.1879123802941655, 0.31483820439518323`, 0.9340127041150739], 
             UndirectedEdge[65, 412] -> 
             RGBColor[
              0.2124844072209095, 0.34066496265168167`, 0.9354120446974956], 
             UndirectedEdge[13, 161] -> 
             RGBColor[
              0.4356106212508812, 0.5493852197341049, 0.9496243993260349], 
             UndirectedEdge[229, 480] -> 
             RGBColor[
              0.4558972150742777, 0.5685887630665123, 0.9504660295382097], 
             UndirectedEdge[32, 448] -> 
             RGBColor[
              0.5919293414877744, 0.6742983920990104, 0.9636165666028987], 
             UndirectedEdge[251, 453] -> 
             RGBColor[
              0.4549456459177142, 0.5683488654918392, 0.9502439515117083], 
             UndirectedEdge[282, 310] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[392, 473] -> 
             RGBColor[
              0.5241730715613854, 0.6242799613386438, 0.9557686238662648], 
             UndirectedEdge[222, 344] -> 
             RGBColor[
              0.2425145104333196, 0.3722285051464392, 0.9371222146498859], 
             UndirectedEdge[266, 440] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[16, 361] -> 
             RGBColor[
              0.5282938438058984, 0.6266761633997737, 0.9563838424107522], 
             UndirectedEdge[412, 426] -> 
             RGBColor[
              0.221482079932092, 0.35012208715653403`, 0.9359244488475336], 
             UndirectedEdge[274, 460] -> 
             RGBColor[
              0.6542549538191047, 0.7274384825635528, 0.9678230605465845], 
             UndirectedEdge[180, 230] -> 
             RGBColor[
              0.4493012303473422, 0.5582450689465429, 0.9510229102327686], 
             UndirectedEdge[375, 450] -> 
             RGBColor[
              0.31062788570294697`, 0.44095413795057004`, 0.9411061031665402],
              UndirectedEdge[6, 123] -> 
             RGBColor[
              0.2715222173507861, 0.4003537105207884, 0.9388607085188945], 
             UndirectedEdge[170, 466] -> 
             RGBColor[
              0.23226952433681827`, 0.36146037518938046`, 0.9365387778477888],
              UndirectedEdge[267, 280] -> 
             RGBColor[
              0.47422028597903365`, 0.5827369663057078, 0.9521094415156451], 
             UndirectedEdge[52, 214] -> 
             RGBColor[
              0.19978832528187718`, 0.3273205755556704, 0.9346890216132377], 
             UndirectedEdge[358, 386] -> 
             RGBColor[
              0.61406122663775, 0.6928053141736124, 0.965331823983703], 
             UndirectedEdge[230, 413] -> 
             RGBColor[
              0.35288248502722674`, 0.4788096948773328, 0.9437525132156328], 
             UndirectedEdge[53, 207] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[188, 256] -> 
             RGBColor[
              0.6227687970873287, 0.6995989768913324, 0.9662311909897034], 
             UndirectedEdge[38, 87] -> 
             RGBColor[
              0.8767924040920562, 0.7611369170487428, 0.6118246822073715], 
             UndirectedEdge[22, 52] -> 
             RGBColor[
              0.18741101862312, 0.3143112414907485, 0.933984152309606], 
             UndirectedEdge[160, 460] -> 
             RGBColor[
              0.6397166588695635, 0.7156356397807915, 0.9666785527126276], 
             UndirectedEdge[63, 159] -> 
             RGBColor[
              0.3591807092964443, 0.4846284307952361, 0.944140519860194], 
             UndirectedEdge[285, 430] -> 
             RGBColor[
              0.3053410101778382, 0.4359023692701981, 0.9407865302407712], 
             UndirectedEdge[132, 356] -> 
             RGBColor[
              0.575775252833869, 0.6662108242154342, 0.9599298517837459], 
             UndirectedEdge[99, 373] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[243, 396] -> 
             RGBColor[
              0.2568146858534386, 0.38725889619647347`, 0.937936588484848], 
             UndirectedEdge[118, 292] -> 
             RGBColor[
              0.2208755284929752, 0.34948456313643983`, 0.9358899066403883], 
             UndirectedEdge[84, 176] -> 
             RGBColor[
              0.7812728109768734, 0.8295712798392683, 0.9786967649570286], 
             UndirectedEdge[334, 385] -> 
             RGBColor[
              0.20166339359782656`, 0.32929139124193096`, 0.9347958039799161],
              UndirectedEdge[25, 325] -> 
             RGBColor[
              0.5921088463130788, 0.6772490844170992, 0.9624395213048671], 
             UndirectedEdge[321, 397] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[201, 235] -> 
             RGBColor[
              0.4575805493651263, 0.5676469657175549, 0.9512363666717771], 
             UndirectedEdge[321, 498] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[368, 492] -> 
             RGBColor[
              0.18751313635976613`, 0.31441857370660203`, 0.9339899677636383],
              UndirectedEdge[239, 387] -> 
             RGBColor[
              0.2385452232211448, 0.3680565326190986, 0.9368961696151867], 
             UndirectedEdge[196, 500] -> 
             RGBColor[
              0.2545900551674532, 0.38492066829577065`, 0.9378098990583272], 
             UndirectedEdge[122, 185] -> 
             RGBColor[
              0.2643164513876104, 0.39404556499127835`, 0.9384040120398665], 
             UndirectedEdge[350, 377] -> 
             RGBColor[
              0.1885369074382775, 0.3154946220209529, 0.9340482700120258], 
             UndirectedEdge[315, 353] -> 
             RGBColor[
              0.1924173261577683, 0.31957318812789476`, 0.9342692541175359], 
             UndirectedEdge[102, 480] -> 
             RGBColor[
              0.373349255813557, 0.49325764384386095`, 0.9453464631309425], 
             UndirectedEdge[127, 253] -> 
             RGBColor[
              0.8742585681452911, 0.4192055500614041, 0.39156282211394233`], 
             UndirectedEdge[159, 192] -> 
             RGBColor[
              0.6447596298856625, 0.718476583875131, 0.9677105713215501], 
             UndirectedEdge[201, 289] -> 
             RGBColor[
              0.440683211853583, 0.5530113412499335, 0.9501596832672705], 
             UndirectedEdge[29, 194] -> 
             RGBColor[
              0.20624169499829867`, 0.3341034762949018, 0.935056531471683], 
             UndirectedEdge[79, 388] -> 
             RGBColor[
              0.8529860941236527, 0.4035819731432213, 0.44035989591821356`], 
             UndirectedEdge[246, 402] -> 
             RGBColor[
              0.4049563520885143, 0.5250559960278285, 0.9470572012623077], 
             UndirectedEdge[185, 398] -> 
             RGBColor[
              0.30864187886940686`, 0.4406343996690694, 0.9409282795613612], 
             UndirectedEdge[133, 304] -> 
             RGBColor[
              0.24533917292446922`, 0.3751974045185834, 0.9372830750000432], 
             UndirectedEdge[107, 314] -> 
             RGBColor[
              0.4603925267300639, 0.5691703128729416, 0.9516675997547801], 
             UndirectedEdge[13, 279] -> 
             RGBColor[
              0.4218014842402082, 0.536993472318253, 0.9487602731398381], 
             UndirectedEdge[180, 418] -> 
             RGBColor[
              0.7760216792869205, 0.7613486519842765, 0.619693218697663], 
             UndirectedEdge[112, 207] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[308, 369] -> 
             RGBColor[
              0.21139967119728387`, 0.33952483631461483`, 0.9353502705856733],
              UndirectedEdge[45, 292] -> 
             RGBColor[
              0.24018663766573572`, 0.36978176327205037`, 0.9369896457395511],
              UndirectedEdge[348, 418] -> 
             RGBColor[
              0.9556411266613736, 0.8598361892892182, 0.29359605765885616`], 
             UndirectedEdge[51, 264] -> 
             RGBColor[0.817319, 0.134127, 0.164218], 
             UndirectedEdge[201, 218] -> 
             RGBColor[
              0.6538010445751918, 0.7283312295992802, 0.96690948928418], 
             UndirectedEdge[262, 376] -> 
             RGBColor[
              0.968939678523462, 0.9760507492827026, 0.9237984542197519], 
             UndirectedEdge[304, 307] -> 
             RGBColor[
              0.23196962243821045`, 0.361145159279065, 0.9365216988783283], 
             UndirectedEdge[8, 166] -> 
             RGBColor[
              0.25498529523312863`, 0.38533609066446306`, 0.9378324073953621],
              UndirectedEdge[66, 312] -> 
             RGBColor[
              0.25430218522603054`, 0.38461809873532704`, 0.9377935052910287],
              UndirectedEdge[202, 430] -> 
             RGBColor[
              0.24453539717238243`, 0.37435258524081405`, 0.9372373011600414],
              UndirectedEdge[348, 404] -> 
             RGBColor[
              0.8657911144896757, 0.38473790158096466`, 0.21272342517580606`],
              UndirectedEdge[1, 113] -> 
             RGBColor[
              0.2610717066577763, 0.3917332949725406, 0.938179019521957], 
             UndirectedEdge[29, 377] -> 
             RGBColor[
              0.19479365087519235`, 0.32207085607359665`, 0.9344045822947358],
              UndirectedEdge[259, 404] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[131, 449] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[423, 465] -> 
             RGBColor[
              0.17977821903452834`, 0.30628868517569324`, 0.9335494756647507],
              UndirectedEdge[177, 412] -> 
             RGBColor[
              0.2150756323125279, 0.34338850451613256`, 0.9355596111330893], 
             UndirectedEdge[139, 158] -> 
             RGBColor[
              0.2143619533681344, 0.34263838269571634`, 0.9355189681729995], 
             UndirectedEdge[454, 500] -> 
             RGBColor[
              0.2969342258477388, 0.4283948237797348, 0.9402591327630841], 
             UndirectedEdge[430, 459] -> 
             RGBColor[
              0.261161835730964, 0.3918280263429743, 0.938184152239341], 
             UndirectedEdge[474, 490] -> 
             RGBColor[
              0.3743490963025207, 0.49866410470974976`, 0.9450741712858564], 
             UndirectedEdge[443, 451] -> 
             RGBColor[
              0.521489697428266, 0.6147628649184023, 0.9578856335096356], 
             UndirectedEdge[182, 483] -> 
             RGBColor[
              0.9629580792560939, 0.9404214301836048, 0.652695538050524], 
             UndirectedEdge[92, 457] -> 
             RGBColor[
              0.8072191088446563, 0.7991593994494468, 0.6265274116797456], 
             UndirectedEdge[38, 184] -> 
             RGBColor[
              0.8878066027772542, 0.5834378112927188, 0.2280954180565736], 
             UndirectedEdge[51, 457] -> 
             RGBColor[
              0.8638009847389825, 0.3780247266271895, 0.20499214689883155`], 
             UndirectedEdge[321, 455] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[251, 435] -> 
             RGBColor[
              0.4507346269340168, 0.564825412094351, 0.9499413897526227], 
             UndirectedEdge[16, 441] -> 
             RGBColor[
              0.5075871140234716, 0.6087410348127357, 0.9550644278992582], 
             UndirectedEdge[302, 390] -> 
             RGBColor[
              0.5231595548827668, 0.6237635205800223, 0.9556041830384168], 
             UndirectedEdge[186, 455] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[349, 353] -> 
             RGBColor[
              0.19626227991525308`, 0.3236144783111598, 0.9344882185459253], 
             UndirectedEdge[125, 406] -> 
             RGBColor[
              0.8761600890568056, 0.41916385235227993`, 0.29986098883365586`],
              UndirectedEdge[307, 433] -> 
             RGBColor[
              0.2103554532398539, 0.33842729703411356`, 0.9352908039177796], 
             UndirectedEdge[406, 419] -> 
             RGBColor[
              0.8761600890568056, 0.41916385235228004`, 0.29986098883365586`],
              UndirectedEdge[237, 274] -> 
             RGBColor[
              0.4534869550610022, 0.5663779417903663, 0.9503464835750837], 
             UndirectedEdge[203, 264] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[69, 231] -> 
             RGBColor[
              0.8720195914369621, 0.405748016840095, 0.23691988196683633`], 
             UndirectedEdge[328, 399] -> 
             RGBColor[
              0.3903444167194412, 0.5114017266359476, 0.9462887257399559], 
             UndirectedEdge[78, 262] -> 
             RGBColor[
              0.953970946509212, 0.9135788430387926, 0.625155004871462], 
             UndirectedEdge[27, 412] -> 
             RGBColor[
              0.21686143319747594`, 0.34526549447252863`, 0.9356613098516314],
              UndirectedEdge[147, 221] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[93, 289] -> 
             RGBColor[
              0.3437007342510835, 0.4721180339322616, 0.9431212847572212], 
             UndirectedEdge[141, 235] -> 
             RGBColor[
              0.3242794390168753, 0.4545969884680785, 0.9419093816387205], 
             UndirectedEdge[185, 464] -> 
             RGBColor[
              0.3004465755354037, 0.43202061625278937`, 0.9404615691603544], 
             UndirectedEdge[6, 189] -> 
             RGBColor[
              0.4338625957179959, 0.5480369292693235, 0.9494672163178912], 
             UndirectedEdge[38, 316] -> 
             RGBColor[
              0.942615665830955, 0.799915878171712, 0.3187661896988654], 
             UndirectedEdge[322, 343] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[93, 141] -> 
             RGBColor[
              0.3375011498141227, 0.46604896981814714`, 0.9427518573592213], 
             UndirectedEdge[191, 237] -> 
             RGBColor[
              0.3261149973492088, 0.44953101328405887`, 0.9422700448294907], 
             UndirectedEdge[145, 461] -> 
             RGBColor[
              0.42511156853211396`, 0.5402277520345683, 0.9489710633786737], 
             UndirectedEdge[420, 500] -> 
             RGBColor[
              0.2460794158023615, 0.3759754467173574, 0.9373252307368479], 
             UndirectedEdge[402, 458] -> 
             RGBColor[
              0.4023396027301842, 0.5229080745336331, 0.9468577016043941], 
             UndirectedEdge[148, 263] -> 
             RGBColor[
              0.527788364966513, 0.6251072494545038, 0.9568303661574955], 
             UndirectedEdge[126, 499] -> 
             RGBColor[
              0.8563654629268306, 0.3487034608338446, 0.19818596167822738`], 
             UndirectedEdge[133, 371] -> 
             RGBColor[
              0.4038248401636344, 0.5172459248516914, 0.9478141711009334], 
             UndirectedEdge[72, 245] -> 
             RGBColor[
              0.40076249699854094`, 0.5207377736167305, 0.9469794378766433], 
             UndirectedEdge[57, 131] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[15, 173] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[138, 415] -> 
             RGBColor[
              0.19037454320889569`, 0.31742609372870995`, 0.934152920650624], 
             UndirectedEdge[105, 109] -> 
             RGBColor[
              0.28171832903511257`, 0.41140686866770654`, 0.9394290448060217],
              UndirectedEdge[235, 284] -> 
             RGBColor[
              0.32324813737403335`, 0.4535130250531508, 0.9418506505358348], 
             UndirectedEdge[150, 473] -> 
             RGBColor[
              0.4726289188297277, 0.5796350069269258, 0.9524842760329082], 
             UndirectedEdge[74, 417] -> 
             RGBColor[
              0.23919755835177475`, 0.36874217820182686`, 0.9369333191358328],
              UndirectedEdge[20, 413] -> 
             RGBColor[
              0.4400008523109076, 0.555093246571965, 0.9493776651595607], 
             UndirectedEdge[34, 467] -> 
             RGBColor[
              0.26986184992211565`, 0.40097229287063396`, 0.9386796051770095],
              UndirectedEdge[62, 110] -> 
             RGBColor[
              0.7611613425809955, 0.8086288736350278, 0.7610013636522968], 
             UndirectedEdge[93, 389] -> 
             RGBColor[
              0.31082135500600144`, 0.43800681387811885`, 0.9412324825141183],
              UndirectedEdge[28, 408] -> 
             RGBColor[
              0.8613224849238736, 0.3683564012224616, 0.2021744979333091], 
             UndirectedEdge[93, 284] -> 
             RGBColor[
              0.3364698481712808, 0.4649650064032194, 0.9426931262563356], 
             UndirectedEdge[143, 313] -> 
             RGBColor[
              0.8841027954583874, 0.5189146200022339, 0.4295739266106804], 
             UndirectedEdge[361, 398] -> 
             RGBColor[
              0.35315773150982965`, 0.47919179379439375`, 0.9437647903277859],
              UndirectedEdge[105, 382] -> 
             RGBColor[
              0.2779618406141432, 0.4081531872040607, 0.9391896846855698], 
             UndirectedEdge[240, 495] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[13, 21] -> 
             RGBColor[
              0.680757442248239, 0.7489730331464229, 0.969887983187306], 
             UndirectedEdge[32, 179] -> 
             RGBColor[
              0.31490599852677015`, 0.44361194071062604`, 0.9414170615594284],
              UndirectedEdge[38, 79] -> 
             RGBColor[
              0.8446459694565934, 0.30129340921955317`, 0.18870723798989242`],
              UndirectedEdge[328, 407] -> 
             RGBColor[
              0.5826579050179238, 0.6713637468651524, 0.9607689028585917], 
             UndirectedEdge[357, 367] -> 
             RGBColor[
              0.23888728000708515`, 0.3684160559887748, 0.9369156492431183], 
             UndirectedEdge[196, 213] -> 
             RGBColor[
              0.25723659522050063`, 0.3877023496918546, 0.9379606155991431], 
             UndirectedEdge[233, 326] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[164, 372] -> 
             RGBColor[
              0.8384337610731512, 0.3919783377813091, 0.43897188140083576`], 
             UndirectedEdge[3, 278] -> 
             RGBColor[
              0.20104322166618976`, 0.32863955122060917`, 0.9347604861058716],
              UndirectedEdge[195, 399] -> 
             RGBColor[
              0.2610275825318536, 0.39168691771856473`, 0.9381765067182615], 
             UndirectedEdge[118, 187] -> 
             RGBColor[
              0.30166406888411185`, 0.428995808686236, 0.9406885113479817], 
             UndirectedEdge[61, 178] -> 
             RGBColor[
              0.8637848357389819, 0.3779702522582219, 0.20492941108331192`], 
             UndirectedEdge[2, 496] -> 
             RGBColor[
              0.20510743091696815`, 0.33291129282892695`, 0.9349919368102446],
              UndirectedEdge[103, 404] -> 
             RGBColor[
              0.8763449551304583, 0.4195592621909958, 0.3199825200895846], 
             UndirectedEdge[37, 374] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[236, 466] -> 
             RGBColor[
              0.27668923951458074`, 0.40814831221381703`, 0.9390684149140827],
              UndirectedEdge[150, 254] -> 
             RGBColor[
              0.2880175076881252, 0.41726284049417106`, 0.9398157791413707], 
             UndirectedEdge[148, 229] -> 
             RGBColor[
              0.5529788076305955, 0.64692594478167, 0.958435478889017], 
             UndirectedEdge[160, 432] -> 
             RGBColor[
              0.6131239207439269, 0.6948241064503374, 0.9640378781044934], 
             UndirectedEdge[48, 198] -> 
             RGBColor[
              0.21002858102618926`, 0.33808373361265665`, 0.9352721890287756],
              UndirectedEdge[89, 178] -> 
             RGBColor[
              0.9077540295115808, 0.8779489225910053, 0.6363728660925616], 
             UndirectedEdge[63, 239] -> 
             RGBColor[
              0.2771411890702042, 0.40862333985203414`, 0.9390941527726759], 
             UndirectedEdge[425, 462] -> 
             RGBColor[
              0.2196150434125822, 0.3481597133975768, 0.9358181238797805], 
             UndirectedEdge[44, 457] -> 
             RGBColor[
              0.8280575439248763, 0.8154385433120871, 0.6286043921422944], 
             UndirectedEdge[46, 254] -> 
             RGBColor[
              0.26138512726432483`, 0.39206271990203745`, 0.9381968683618358],
              UndirectedEdge[1, 452] -> 
             RGBColor[
              0.3302242085185564, 0.4565474530972755, 0.942405293359968], 
             UndirectedEdge[260, 299] -> 
             RGBColor[
              0.38540754335386535`, 0.5080941018004876, 0.945819774282403], 
             UndirectedEdge[321, 341] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[249, 406] -> 
             RGBColor[
              0.8761600890568056, 0.41916385235227993`, 0.29986098883365586`],
              UndirectedEdge[398, 496] -> 
             RGBColor[
              0.25262917012324787`, 0.38285965378701825`, 0.9376982295559292],
              UndirectedEdge[382, 462] -> 
             RGBColor[
              0.2750365104468856, 0.4050784797216278, 0.9390230914601827], 
             UndirectedEdge[63, 272] -> 
             RGBColor[
              0.4327060967749962, 0.5452426827083117, 0.9496736717344219], 
             UndirectedEdge[117, 270] -> 
             RGBColor[
              0.19147020359768469`, 0.3185777022662082, 0.9342153168888814], 
             UndirectedEdge[164, 404] -> 
             RGBColor[
              0.8384337610731512, 0.3919783377813091, 0.43897188140083576`], 
             UndirectedEdge[133, 191] -> 
             RGBColor[
              0.24509705427784428`, 0.37494292246977173`, 0.9372692867013004],
              UndirectedEdge[307, 469] -> 
             RGBColor[
              0.21181807832276073`, 0.33996460873203505`, 0.9353740982524913],
              UndirectedEdge[31, 237] -> 
             RGBColor[
              0.3290966057081422, 0.45266487271418654`, 0.9424398430146377], 
             UndirectedEdge[1, 468] -> 
             RGBColor[
              0.317495752696651, 0.44552270441513225`, 0.9415942474103278], 
             UndirectedEdge[346, 395] -> 
             RGBColor[
              0.9494788631662472, 0.8294154005518836, 0.3198310039905435], 
             UndirectedEdge[214, 223] -> 
             RGBColor[
              0.2605020778119116, 0.39113457893898207`, 0.9381465800018753], 
             UndirectedEdge[264, 397] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[103, 204] -> 
             RGBColor[
              0.9373194700932539, 0.9488844698763799, 0.809975514617866], 
             UndirectedEdge[110, 356] -> 
             RGBColor[
              0.7427296651345173, 0.7936652075463704, 0.7595503544862507], 
             UndirectedEdge[184, 253] -> 
             RGBColor[
              0.9322255008103006, 0.7603060225554952, 0.5323787942426484], 
             UndirectedEdge[115, 417] -> 
             RGBColor[
              0.24410759542701554`, 0.3739029384822362, 0.9372129384835188], 
             UndirectedEdge[243, 459] -> 
             RGBColor[
              0.2504428786429346, 0.3805617228223229, 0.9375737234904538], 
             UndirectedEdge[190, 349] -> 
             RGBColor[
              0.2752751587264147, 0.4033449321472721, 0.9391093400741414], 
             UndirectedEdge[128, 222] -> 
             RGBColor[
              0.2510869631489796, 0.3812386964754926, 0.9376104031502354], 
             UndirectedEdge[204, 275] -> 
             RGBColor[
              0.9068456198442363, 0.8406001496363356, 0.6268746543862641], 
             UndirectedEdge[178, 455] -> 
             RGBColor[
              0.8637848357389819, 0.37797025225822195`, 0.20492941108331195`],
              UndirectedEdge[84, 391] -> 
             RGBColor[
              0.8156476109000103, 0.7992621868904787, 0.624644580043521], 
             UndirectedEdge[54, 203] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[236, 314] -> 
             RGBColor[
              0.4535445571442839, 0.5629579737098113, 0.9512415409530388], 
             UndirectedEdge[277, 313] -> 
             RGBColor[
              0.9794761473860648, 0.9653471066434187, 0.651496031025925], 
             UndirectedEdge[186, 397] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[29, 297] -> 
             RGBColor[
              0.22596030857463673`, 0.3548289893959438, 0.9361794773437808], 
             UndirectedEdge[130, 208] -> 
             RGBColor[
              0.913099344561267, 0.9286383537262926, 0.7319810481348386], 
             UndirectedEdge[145, 450] -> 
             RGBColor[
              0.32420026945735514`, 0.45521957381528544`, 0.9418790303428113],
              UndirectedEdge[86, 350] -> 
             RGBColor[
              0.19827230955402672`, 0.32572714690475074`, 0.934602686760281], 
             UndirectedEdge[37, 281] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[281, 445] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[116, 224] -> 
             RGBColor[
              0.4898453633718138, 0.5905346758344123, 0.9546536353939092], 
             UndirectedEdge[112, 163] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[148, 480] -> 
             RGBColor[
              0.576482916411845, 0.6665757990614235, 0.9601288241510779], 
             UndirectedEdge[42, 487] -> 
             RGBColor[
              0.2552478049273309, 0.38561200499714565`, 0.9378473569340987], 
             UndirectedEdge[122, 319] -> 
             RGBColor[
              0.19763752801393172`, 0.3250599512586367, 0.9345665368906477], 
             UndirectedEdge[129, 348] -> 
             RGBColor[
              0.8615879645459554, 0.8493704684423902, 0.6432457722235755], 
             UndirectedEdge[93, 201] -> 
             RGBColor[
              0.4708022601623738, 0.5790989470676235, 0.9520788423922779], 
             UndirectedEdge[121, 427] -> 
             RGBColor[
              0.25170778098680857`, 0.3818912153851751, 0.937645757807682], 
             UndirectedEdge[269, 411] -> 
             RGBColor[
              0.7823157613673747, 0.34781156452747625`, 0.43346533019890965`],
              UndirectedEdge[76, 371] -> 
             RGBColor[
              0.7704973116084974, 0.816573463481717, 0.7916704815843216], 
             UndirectedEdge[61, 244] -> 
             RGBColor[
              0.8706168078338911, 0.40101609835768304`, 0.23147033256236077`],
              UndirectedEdge[184, 436] -> 
             RGBColor[
              0.9230065584441681, 0.7540860752952483, 0.5773398016096436], 
             UndirectedEdge[80, 293] -> 
             RGBColor[
              0.8642091954046907, 0.41214776090032323`, 0.42814428395185355`],
              UndirectedEdge[111, 460] -> 
             RGBColor[
              0.9045539423959997, 0.925414302012888, 0.9445379058811575], 
             UndirectedEdge[286, 358] -> 
             RGBColor[
              0.30001627431624434`, 0.4256508881874809, 0.9406537311281724], 
             UndirectedEdge[176, 244] -> 
             RGBColor[
              0.9305033630137299, 0.9224859491112958, 0.6773766406530607], 
             UndirectedEdge[99, 321] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[187, 478] -> 
             RGBColor[
              0.4419595423271288, 0.555502846692598, 0.9498580506334303], 
             UndirectedEdge[116, 185] -> 
             RGBColor[
              0.5025267031818595, 0.6027654055971375, 0.9554160280414452], 
             UndirectedEdge[97, 257] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[16, 313] -> 
             RGBColor[
              0.8124335820745439, 0.8535860695269795, 0.9438393627828742], 
             UndirectedEdge[166, 344] -> 
             RGBColor[
              0.23945512334966762`, 0.36901289534517634`, 0.9369479870814295],
              UndirectedEdge[103, 443] -> 
             RGBColor[
              0.8728831239162906, 0.898059262922825, 0.8036823482152753], 
             UndirectedEdge[74, 115] -> 
             RGBColor[
              0.22596376247749395`, 0.3548326196668369, 0.936179674038439], 
             UndirectedEdge[196, 332] -> 
             RGBColor[
              0.22366006402010474`, 0.35241128652520237`, 0.9360484818193071],
              UndirectedEdge[49, 203] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[95, 122] -> 
             RGBColor[
              0.20586015494572685`, 0.3337024535086123, 0.935034803330127], 
             UndirectedEdge[97, 209] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[484, 490] -> 
             RGBColor[
              0.27306794987010674`, 0.4012805048264995, 0.9389742880863683], 
             UndirectedEdge[128, 415] -> 
             RGBColor[
              0.215112556671643, 0.34342731435870205`, 0.9355617139207162], 
             UndirectedEdge[371, 442] -> 
             RGBColor[
              0.49686920952944263`, 0.6022507016564647, 0.9535812424780545], 
             UndirectedEdge[88, 311] -> 
             RGBColor[
              0.22564091581509077`, 0.3544932873549904, 0.936161288398624], 
             UndirectedEdge[15, 149] -> 
             RGBColor[
              0.8300337551067959, 0.23185817939204778`, 0.1763936638495297], 
             UndirectedEdge[117, 140] -> 
             RGBColor[
              0.1891020516318635, 0.31608862440062324`, 0.9340804541377947], 
             UndirectedEdge[199, 475] -> 
             RGBColor[
              0.9666260772642596, 0.9735004417799876, 0.8907773182602956], 
             UndirectedEdge[71, 169] -> 
             RGBColor[
              0.22996457913520382`, 0.3590377316405171, 0.9364075146284178], 
             UndirectedEdge[23, 51] -> 
             RGBColor[
              0.8757337238850049, 0.41825190036192983`, 0.2534537711039848], 
             UndirectedEdge[381, 416] -> 
             RGBColor[
              0.26441513407437683`, 0.3951746851048749, 0.9383720870161499], 
             UndirectedEdge[121, 447] -> 
             RGBColor[
              0.3594348735345609, 0.4841800211114614, 0.9441811940166118], 
             UndirectedEdge[244, 407] -> 
             RGBColor[
              0.8327384947978311, 0.845595536100449, 0.6677692177517128], 
             UndirectedEdge[255, 385] -> 
             RGBColor[
              0.2238798414279229, 0.35264228651551177`, 0.9360609978175509], 
             UndirectedEdge[30, 469] -> 
             RGBColor[
              0.18416602893623069`, 0.3109005515855985, 0.9337993549474696], 
             UndirectedEdge[80, 171] -> 
             RGBColor[
              0.9566931052658137, 0.9145293959267929, 0.61948306634346], 
             UndirectedEdge[214, 466] -> 
             RGBColor[
              0.23186057629826734`, 0.3610305448720602, 0.9365154888619778], 
             UndirectedEdge[199, 455] -> 
             RGBColor[
              0.8752103907398564, 0.41959915316498186`, 0.3757886584840803], 
             UndirectedEdge[175, 483] -> 
             RGBColor[
              0.9831143891312863, 0.9536903858164667, 0.5395991219078489], 
             UndirectedEdge[124, 416] -> 
             RGBColor[
              0.25810397876522506`, 0.3885412607245982, 0.9380126760578114], 
             UndirectedEdge[142, 396] -> 
             RGBColor[
              0.2996502424735361, 0.4293333836901839, 0.9404839653749997], 
             UndirectedEdge[185, 361] -> 
             RGBColor[
              0.3651394217782484, 0.4906871475285258, 0.9444873389689651], 
             UndirectedEdge[19, 26] -> 
             RGBColor[
              0.2440972272221243, 0.3738920408415133, 0.9372123480295886], 
             UndirectedEdge[341, 455] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[159, 239] -> 
             RGBColor[
              0.33728399078425725`, 0.4616135913067876, 0.9428935341342171], 
             UndirectedEdge[261, 482] -> 
             RGBColor[
              0.9313294242103154, 0.9480665236597952, 0.992816601900322], 
             UndirectedEdge[5, 97] -> RGBColor[0.817319, 0.134127, 0.164218], 
             UndirectedEdge[285, 396] -> 
             RGBColor[
              0.2964723923839374, 0.4265808896659632, 0.940281475577353], 
             UndirectedEdge[174, 424] -> 
             RGBColor[
              0.2286678735822072, 0.357674811888437, 0.9363336691654786], 
             UndirectedEdge[99, 186] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[79, 127] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[29, 86] -> 
             RGBColor[
              0.2045290529909416, 0.33230338095739453`, 0.934958999042991], 
             UndirectedEdge[127, 316] -> 
             RGBColor[
              0.8735231410973765, 0.4108198428949215, 0.24276088847601782`], 
             UndirectedEdge[197, 466] -> 
             RGBColor[
              0.3305652534933362, 0.45509397973190396`, 0.9424910591192776], 
             UndirectedEdge[183, 206] -> 
             RGBColor[
              0.22097903356863421`, 0.34959335353355825`, 0.935895801101325], 
             UndirectedEdge[25, 392] -> 
             RGBColor[
              0.5998201852464107, 0.6839282586179871, 0.9629308810028296], 
             UndirectedEdge[73, 91] -> 
             RGBColor[
              0.8818663519635108, 0.5061968871434602, 0.22954386621065234`], 
             UndirectedEdge[187, 464] -> 
             RGBColor[
              0.3237248457849767, 0.4521830839430875, 0.9419448399564911], 
             UndirectedEdge[17, 99] -> 
             RGBColor[
              0.8740328861463312, 0.4191122247550715, 0.39530295688299816`], 
             UndirectedEdge[110, 157] -> 
             RGBColor[
              0.9057608095719005, 0.9233348231066068, 0.7742214779103318], 
             UndirectedEdge[241, 429] -> 
             RGBColor[
              0.28762917450715453`, 0.416735172425056, 0.9397980398147002], 
             UndirectedEdge[27, 490] -> 
             RGBColor[
              0.27392877216704353`, 0.40218528363986605`, 0.9390233106427064],
              UndirectedEdge[372, 418] -> 
             RGBColor[
              0.8610616366179067, 0.36732222461184755`, 0.20196461326343138`],
              UndirectedEdge[65, 350] -> 
             RGBColor[
              0.19367927439437493`, 0.3208995757367078, 0.9343411202027254], 
             UndirectedEdge[189, 390] -> 
             RGBColor[
              0.5457757580048264, 0.6421243731228501, 0.957384613394067], 
             UndirectedEdge[263, 267] -> 
             RGBColor[
              0.3938098760277288, 0.5155200539804957, 0.9463141949614547], 
             UndirectedEdge[25, 490] -> 
             RGBColor[
              0.5497329423869521, 0.6405452063111485, 0.9597393661782347], 
             UndirectedEdge[360, 494] -> 
             RGBColor[
              0.8715713699457228, 0.44237438137280577`, 0.4251276579378526], 
             UndirectedEdge[61, 203] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[36, 104] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[33, 241] -> 
             RGBColor[
              0.45030985755818603`, 0.5615504833446909, 0.9507175406924926], 
             UndirectedEdge[82, 419] -> 
             RGBColor[
              0.844192723800754, 0.2992353265545988, 0.18832903870459236`], 
             UndirectedEdge[5, 404] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[40, 396] -> 
             RGBColor[
              0.23189457560972082`, 0.36106628030407867`, 0.9365174250724676],
              UndirectedEdge[169, 369] -> 
             RGBColor[
              0.1961253105543787, 0.32347051482852174`, 0.9344804183434514], 
             UndirectedEdge[268, 491] -> 
             RGBColor[
              0.2006246214741492, 0.3281995758779894, 0.9347366474441984], 
             UndirectedEdge[4, 151] -> 
             RGBColor[
              0.23787775829421978`, 0.3673549846611798, 0.9368581584750242], 
             UndirectedEdge[6, 390] -> 
             RGBColor[
              0.44622497203026434`, 0.5580732632783292, 0.9504404278660695], 
             UndirectedEdge[376, 482] -> 
             RGBColor[
              0.9611408807899072, 0.9702344187023767, 0.9369997845304479], 
             UndirectedEdge[158, 278] -> 
             RGBColor[
              0.21837803574196735`, 0.3468595399049442, 0.9357476781229279], 
             UndirectedEdge[317, 445] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[133, 351] -> 
             RGBColor[
              0.3602564212134738, 0.4818751196130445, 0.9443843055647996], 
             UndirectedEdge[239, 454] -> 
             RGBColor[
              0.28757758461924476`, 0.4185604006032694, 0.9397262858870317], 
             UndirectedEdge[140, 198] -> 
             RGBColor[
              0.18662011133920806`, 0.3134799477889389, 0.9339391113098297], 
             UndirectedEdge[252, 309] -> 
             RGBColor[
              0.20616935749267296`, 0.33402744499002646`, 0.9350524119577515],
              UndirectedEdge[161, 243] -> 
             RGBColor[
              0.29333367126304843`, 0.4235201341671604, 0.9400940069411541], 
             UndirectedEdge[244, 455] -> 
             RGBColor[
              0.8706168078338911, 0.40101609835768304`, 0.23147033256236077`],
              UndirectedEdge[401, 451] -> 
             RGBColor[
              0.23914595187837517`, 0.36868793652624454`, 0.9369303802235176],
              UndirectedEdge[210, 225] -> 
             RGBColor[
              0.22552288916917368`, 0.3543692338668101, 0.9361545669557438], 
             UndirectedEdge[107, 223] -> 
             RGBColor[
              0.31217871061400504`, 0.4444646854438693, 0.9411255648557215], 
             UndirectedEdge[5, 204] -> 
             RGBColor[
              0.8382933582650444, 0.3918663843932574, 0.4389584896556594], 
             UndirectedEdge[59, 200] -> 
             RGBColor[
              0.6024968101282133, 0.6881730784908944, 0.96184990239328], 
             UndirectedEdge[328, 481] -> 
             RGBColor[
              0.38472268680152, 0.5054929320539487, 0.9459685765377344], 
             UndirectedEdge[55, 434] -> 
             RGBColor[
              0.8349696694427251, 0.26979777990945364`, 0.18112030099193344`],
              UndirectedEdge[269, 499] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[377, 476] -> 
             RGBColor[
              0.19264135251793435`, 0.3198086540365209, 0.93428201208733], 
             UndirectedEdge[260, 478] -> 
             RGBColor[
              0.41438762334124934`, 0.5316214362719716, 0.9481011923365408], 
             UndirectedEdge[163, 207] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[238, 258] -> 
             RGBColor[
              0.9652466757087061, 0.8877937438229484, 0.4254269020038368], 
             UndirectedEdge[10, 443] -> 
             RGBColor[
              0.5725638986959316, 0.6605851101273537, 0.9610820260344628], 
             UndirectedEdge[231, 326] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[91, 287] -> 
             RGBColor[
              0.901066080902311, 0.8822512626026671, 0.6499094997146282], 
             UndirectedEdge[242, 249] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[83, 209] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[306, 431] -> 
             RGBColor[
              0.7282987506324737, 0.7817201087405883, 0.7396100673840913], 
             UndirectedEdge[176, 376] -> 
             RGBColor[
              0.9349113559986364, 0.9493340028297863, 0.9349936131005747], 
             UndirectedEdge[30, 191] -> 
             RGBColor[
              0.20407545440505548`, 0.3318266200838168, 0.9349331672745637], 
             UndirectedEdge[209, 444] -> 
             RGBColor[
              0.8285562969045, 0.22050178822288907`, 0.17497884820646079`], 
             UndirectedEdge[169, 289] -> 
             RGBColor[
              0.2567762924328988, 0.386771450071715, 0.9379507722721243], 
             UndirectedEdge[20, 46] -> 
             RGBColor[
              0.3775120116687234, 0.49883606233675915`, 0.9454740124415332], 
             UndirectedEdge[49, 100] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[404, 486] -> 
             RGBColor[
              0.8762475134266291, 0.4193508442393725, 0.30937659196826445`], 
             UndirectedEdge[103, 431] -> 
             RGBColor[
              0.9939229234083959, 0.9894100725942807, 0.579925900252394], 
             UndirectedEdge[219, 238] -> 
             RGBColor[
              0.857059891141737, 0.3514566373014637, 0.19874471492026624`], 
             UndirectedEdge[249, 499] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[254, 377] -> 
             RGBColor[
              0.21202393940718356`, 0.34018098178411005`, 0.935385821736705], 
             UndirectedEdge[57, 434] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[75, 104] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[132, 365] -> 
             RGBColor[
              0.47996279510956574`, 0.5834591273930367, 0.9535665537870656], 
             UndirectedEdge[38, 77] -> 
             RGBColor[
              0.9192907829722123, 0.7949315839058828, 0.6126751046012756], 
             UndirectedEdge[172, 314] -> 
             RGBColor[
              0.4896677620223526, 0.594527050267013, 0.9535329918605306], 
             UndirectedEdge[398, 481] -> 
             RGBColor[
              0.29452715913108485`, 0.4268970967201894, 0.9400842580474054], 
             UndirectedEdge[143, 165] -> 
             RGBColor[
              0.8397048936039028, 0.4842390340274436, 0.4505134128142734], 
             UndirectedEdge[261, 475] -> 
             RGBColor[
              0.9343322393106261, 0.9503060182449484, 0.9877336191951046], 
             UndirectedEdge[288, 373] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[78, 171] -> 
             RGBColor[
              0.9557437848802708, 0.8622080495874132, 0.28344566235844504`], 
             UndirectedEdge[6, 370] -> 
             RGBColor[
              0.3687674465860833, 0.4938295602672435, 0.944718513501584], 
             UndirectedEdge[264, 295] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[45, 464] -> 
             RGBColor[
              0.27751991420487765`, 0.40902140398113634`, 0.9391157206088221],
              UndirectedEdge[228, 318] -> 
             RGBColor[
              0.41679226574295297`, 0.5277736058120767, 0.9488350015364635], 
             UndirectedEdge[7, 295] -> 
             RGBColor[
              0.8626928878488475, 0.3737895921602789, 0.20327715629423396`], 
             UndirectedEdge[225, 320] -> 
             RGBColor[
              0.19454073474396477`, 0.32180502518386755`, 0.9343901790952183],
              UndirectedEdge[137, 148] -> 
             RGBColor[
              0.4973694977090155, 0.5987599555327824, 0.9548921028341959], 
             UndirectedEdge[61, 455] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[11, 331] -> 
             RGBColor[
              0.9074990918503562, 0.9271930694929118, 0.9200841777479003], 
             UndirectedEdge[20, 392] -> 
             RGBColor[
              0.4556885448241814, 0.5686811373406109, 0.9503772710544247], 
             UndirectedEdge[348, 431] -> 
             RGBColor[
              0.9780921624472222, 0.937178031679234, 0.41903725788172613`], 
             UndirectedEdge[241, 351] -> 
             RGBColor[
              0.39987558997040373`, 0.5206056728790665, 0.946747170401173], 
             UndirectedEdge[343, 374] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[162, 389] -> 
             RGBColor[
              0.2228494364237599, 0.35155926552468586`, 0.9360023177769115], 
             UndirectedEdge[207, 266] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[98, 425] -> 
             RGBColor[
              0.21581332835072858`, 0.34416386982491176`, 0.9356016218311414],
              UndirectedEdge[151, 284] -> 
             RGBColor[
              0.2924066815982661, 0.42466834038715606`, 0.9399634999888766], 
             UndirectedEdge[41, 365] -> 
             RGBColor[
              0.4515879807590536, 0.5606916651039451, 0.9511492161960573], 
             UndirectedEdge[436, 473] -> 
             RGBColor[
              0.7880058098599707, 0.8340965074045622, 0.9491623567239293], 
             UndirectedEdge[311, 405] -> 
             RGBColor[
              0.20862681857218934`, 0.3366103923966298, 0.935192360730742], 
             UndirectedEdge[235, 432] -> 
             RGBColor[
              0.5593815103070034, 0.6483170327069279, 0.9606018818614842], 
             UndirectedEdge[109, 474] -> 
             RGBColor[
              0.36875585432995733`, 0.49381951963763093`, 0.9447177748532742],
              UndirectedEdge[364, 468] -> 
             RGBColor[
              0.3285107882361406, 0.45710020516072636`, 0.9422215373890169], 
             UndirectedEdge[203, 374] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[36, 112] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[324, 342] -> 
             RGBColor[
              0.8611372113207705, 0.36762185312492557`, 0.20202542244332183`],
              UndirectedEdge[374, 445] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[2, 327] -> 
             RGBColor[
              0.20072221719940941`, 0.3283021551731643, 0.934742205376372], 
             UndirectedEdge[128, 438] -> 
             RGBColor[
              0.26301778671971743`, 0.3937787485062433, 0.9382898459025171], 
             UndirectedEdge[33, 460] -> 
             RGBColor[
              0.6924766306307231, 0.7584685616661428, 0.9708320109558106], 
             UndirectedEdge[298, 335] -> 
             RGBColor[
              0.4974010502577838, 0.5985236805241728, 0.9550056831427665], 
             UndirectedEdge[112, 343] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[106, 265] -> 
             RGBColor[
              0.1920994264104521, 0.3192390553374573, 0.9342511501972167], 
             UndirectedEdge[19, 468] -> 
             RGBColor[
              0.32598193572834094`, 0.4544422208365192, 0.9420775229797997], 
             UndirectedEdge[161, 202] -> 
             RGBColor[
              0.27218576478809153`, 0.40129234360726607`, 0.9388896649529292],
              UndirectedEdge[204, 390] -> 
             RGBColor[
              0.719190104556114, 0.779752930155814, 0.9733986469546118], 
             UndirectedEdge[211, 289] -> 
             RGBColor[
              0.264682027432215, 0.3950808788085463, 0.9384009921848486], 
             UndirectedEdge[48, 479] -> 
             RGBColor[
              0.20982732020424238`, 0.33787219572811733`, 0.9352607275227045],
              UndirectedEdge[57, 495] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[10, 280] -> 
             RGBColor[
              0.46829572790906493`, 0.5776054118824476, 0.9517319339143078], 
             UndirectedEdge[206, 476] -> 
             RGBColor[
              0.19182851969505096`, 0.31895431520309286`, 0.9342357224605452],
              UndirectedEdge[13, 256] -> 
             RGBColor[
              0.7023889140742479, 0.7662213816098218, 0.9719512122807135], 
             UndirectedEdge[184, 221] -> 
             RGBColor[
              0.8369837657282427, 0.26650113164225936`, 0.18231370738115665`],
              UndirectedEdge[126, 282] -> 
             RGBColor[
              0.8563654629268306, 0.3487034608338446, 0.19818596167822738`], 
             UndirectedEdge[53, 266] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[194, 220] -> 
             RGBColor[
              0.27841284106148134`, 0.4064257927007418, 0.9392959734312498], 
             UndirectedEdge[375, 417] -> 
             RGBColor[
              0.2694273041453681, 0.40051555770747876`, 0.9386548584378767], 
             UndirectedEdge[245, 448] -> 
             RGBColor[
              0.6535838667359518, 0.7268961518226476, 0.9677673664876463], 
             UndirectedEdge[79, 147] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[77, 253] -> 
             RGBColor[
              0.9637096810052588, 0.9717997951686592, 0.9169584807873504], 
             UndirectedEdge[180, 205] -> 
             RGBColor[
              0.5242782003821684, 0.6244474620276343, 0.9557542010457972], 
             UndirectedEdge[28, 432] -> 
             RGBColor[
              0.8603580572101241, 0.8290737960157131, 0.6279678825408344], 
             UndirectedEdge[84, 245] -> 
             RGBColor[
              0.580845373371183, 0.6700379828264612, 0.960526576780036], 
             UndirectedEdge[19, 459] -> 
             RGBColor[
              0.26474036680987095`, 0.3955892893988805, 0.9383879442903225], 
             UndirectedEdge[153, 236] -> 
             RGBColor[
              0.3517722114098828, 0.47882816966608893`, 0.9436458799092957], 
             UndirectedEdge[315, 349] -> 
             RGBColor[
              0.202082172054935, 0.3297315539524397, 0.9348196527935213], 
             UndirectedEdge[18, 460] -> 
             RGBColor[
              0.7893755098548014, 0.8354224990598411, 0.9796313907499675], 
             UndirectedEdge[126, 449] -> 
             RGBColor[
              0.8563654629268306, 0.3487034608338446, 0.19818596167822738`], 
             UndirectedEdge[49, 324] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[334, 415] -> 
             RGBColor[
              0.1991728653840312, 0.3266736881806229, 0.9346539720825469], 
             UndirectedEdge[5, 444] -> 
             RGBColor[
              0.8285562969045, 0.22050178822288907`, 0.17497884820646079`], 
             UndirectedEdge[147, 449] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[254, 426] -> 
             RGBColor[
              0.22616397907446353`, 0.3550430600047173, 0.9361910760774426], 
             UndirectedEdge[186, 321] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[260, 399] -> 
             RGBColor[
              0.3078369305811183, 0.44058230230599205`, 0.9408533683900531], 
             UndirectedEdge[184, 287] -> 
             RGBColor[
              0.8571239304455562, 0.7024298435855887, 0.6014546314672211], 
             UndirectedEdge[129, 431] -> 
             RGBColor[
              0.8769447835241505, 0.9005887953787303, 0.7525487545778835], 
             UndirectedEdge[300, 432] -> 
             RGBColor[
              0.5947484037916498, 0.6789500582515764, 0.96285542904061], 
             UndirectedEdge[207, 293] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[118, 399] -> 
             RGBColor[
              0.2698928088141382, 0.40100483262905684`, 0.9386813682401107], 
             UndirectedEdge[138, 179] -> 
             RGBColor[
              0.23283128712735746`, 0.36205082350005524`, 0.9365707694076565],
              UndirectedEdge[40, 161] -> 
             RGBColor[
              0.2684135610193307, 0.39732751827476565`, 0.9386748435287737], 
             UndirectedEdge[243, 279] -> 
             RGBColor[
              0.27952453425237545`, 0.4111283867513086, 0.9392298807549574], 
             UndirectedEdge[69, 233] -> 
             RGBColor[
              0.8720195914369621, 0.405748016840095, 0.23691988196683633`], 
             UndirectedEdge[237, 460] -> 
             RGBColor[
              0.6238041371417982, 0.701894914251763, 0.9656530435265088], 
             UndirectedEdge[54, 295] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[102, 210] -> 
             RGBColor[
              0.2588571240715909, 0.389405628261814, 0.9380529023198552], 
             UndirectedEdge[137, 156] -> 
             RGBColor[
              0.29413333822792154`, 0.4253340674905862, 0.9401039046543183], 
             UndirectedEdge[231, 444] -> 
             RGBColor[
              0.8285562969045, 0.22050178822288907`, 0.17497884820646079`], 
             UndirectedEdge[383, 393] -> 
             RGBColor[
              0.5000243154359716, 0.6026515113802116, 0.9544266172832518], 
             UndirectedEdge[43, 137] -> 
             RGBColor[
              0.36126042666261593`, 0.4873273569233284, 0.9442401728302576], 
             UndirectedEdge[233, 348] -> 
             RGBColor[
              0.8657911144896757, 0.38473790158096455`, 0.21272342517580606`],
              UndirectedEdge[193, 410] -> 
             RGBColor[
              0.19038075076848193`, 0.31743261826741714`, 0.9341532741619593],
              UndirectedEdge[126, 384] -> 
             RGBColor[
              0.784439054142597, 0.7459729584674704, 0.6152424378957748], 
             UndirectedEdge[162, 345] -> 
             RGBColor[
              0.21406135628573086`, 0.3423224361031544, 0.9355018496138501], 
             UndirectedEdge[165, 178] -> 
             RGBColor[
              0.9007287763047269, 0.8723471763792785, 0.6357027911701743], 
             UndirectedEdge[154, 455] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[211, 470] -> 
             RGBColor[
              0.23114027919804092`, 0.3602734669502483, 0.9364744690077039], 
             UndirectedEdge[201, 305] -> 
             RGBColor[
              0.714793343846527, 0.7763168762700076, 0.9728989371489009], 
             UndirectedEdge[220, 474] -> 
             RGBColor[
              0.37690451400651614`, 0.5008774790859223, 0.9452370002422877], 
             UndirectedEdge[125, 173] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[189, 443] -> 
             RGBColor[
              0.6423913820668823, 0.7188913891932535, 0.9661322690038426], 
             UndirectedEdge[307, 500] -> 
             RGBColor[
              0.2541094521417272, 0.3844155240437408, 0.9377825294270006], 
             UndirectedEdge[102, 134] -> 
             RGBColor[
              0.23432084769928213`, 0.3636164461047431, 0.9366555976786202], 
             UndirectedEdge[102, 174] -> 
             RGBColor[
              0.24152702065256443`, 0.3711905907763972, 0.937065978567732], 
             UndirectedEdge[203, 281] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[279, 421] -> 
             RGBColor[
              0.2531570576746852, 0.38341449707358277`, 0.9377282919710439], 
             UndirectedEdge[335, 430] -> 
             RGBColor[
              0.2957165872581862, 0.4275661778747568, 0.940173270522874], 
             UndirectedEdge[69, 431] -> 
             RGBColor[
              0.9874348778681517, 0.9686932045679294, 0.4553319430682715], 
             UndirectedEdge[149, 249] -> 
             RGBColor[
              0.8427485102135918, 0.3295893587840956, 0.1885693276990594], 
             UndirectedEdge[141, 345] -> 
             RGBColor[
              0.26571464212222085`, 0.3966133145247829, 0.9384434278280497], 
             UndirectedEdge[12, 283] -> 
             RGBColor[
              0.21876873065664665`, 0.34727018503176055`, 0.9357699276203375],
              UndirectedEdge[119, 381] -> 
             RGBColor[
              0.21072511503524133`, 0.3388158350189773, 0.9353118556101614], 
             UndirectedEdge[396, 430] -> 
             RGBColor[
              0.267533642941468, 0.39852519971712486`, 0.9385470172337352], 
             UndirectedEdge[49, 360] -> 
             RGBColor[
              0.8191009627097754, 0.1478239462483719, 0.1659244095033199], 
             UndirectedEdge[208, 497] -> 
             RGBColor[
              0.9697875053992224, 0.9066608733562769, 0.377938680164832], 
             UndirectedEdge[275, 444] -> 
             RGBColor[
              0.8785036487734464, 0.5201192918100778, 0.21943697634810488`], 
             UndirectedEdge[269, 323] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[273, 279] -> 
             RGBColor[
              0.2592350022653147, 0.38980280220227903`, 0.938074421923967], 
             UndirectedEdge[107, 289] -> 
             RGBColor[
              0.31649233536361426`, 0.44855148634982667`, 0.941387589639554], 
             UndirectedEdge[289, 314] -> 
             RGBColor[
              0.4574818773087424, 0.5666492546376866, 0.9514821357474397], 
             UndirectedEdge[6, 428] -> 
             RGBColor[
              0.2756737236719881, 0.40471720688507545`, 0.9390971306622837], 
             UndirectedEdge[7, 17] -> 
             RGBColor[
              0.970450660992768, 0.9210987253730254, 0.5694341697658482], 
             UndirectedEdge[309, 424] -> 
             RGBColor[
              0.23021590674425413`, 0.35930189289271974`, 0.9364218273639473],
              UndirectedEdge[128, 385] -> 
             RGBColor[
              0.21760308488543836`, 0.34604501742001015`, 0.9357035458180856],
              UndirectedEdge[71, 362] -> 
             RGBColor[
              0.22011006608812847`, 0.34868001361582635`, 0.9358463146888325],
              UndirectedEdge[43, 156] -> 
             RGBColor[
              0.33421927844066934`, 0.460054494124931, 0.9426581453180694], 
             UndirectedEdge[59, 298] -> 
             RGBColor[
              0.6411661160201888, 0.718993456061012, 0.9652859281793502], 
             UndirectedEdge[261, 455] -> 
             RGBColor[
              0.8536811654374341, 0.40413620414162243`, 0.44042619244061953`],
              UndirectedEdge[17, 89] -> 
             RGBColor[
              0.9231261051226047, 0.9396618813362796, 0.9219331847920909], 
             UndirectedEdge[9, 68] -> 
             RGBColor[
              0.22494283452702457`, 0.3537595596603228, 0.9361215337019873], 
             UndirectedEdge[73, 298] -> 
             RGBColor[
              0.7870575481756196, 0.4591533710298793, 0.44731121237687044`], 
             UndirectedEdge[16, 333] -> 
             RGBColor[
              0.5323412755190838, 0.6301818453199022, 0.956641741180513], 
             UndirectedEdge[257, 445] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[428, 451] -> 
             RGBColor[
              0.2543228250079339, 0.3846397924547452, 0.9377946806960742], 
             UndirectedEdge[15, 419] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[17, 313] -> 
             RGBColor[
              0.9826977046974779, 0.9860735140867379, 0.8898538805643141], 
             UndirectedEdge[5, 326] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[216, 217] -> 
             RGBColor[
              0.22911696130934928`, 0.3581468315634698, 0.9363592440471735], 
             UndirectedEdge[138, 222] -> 
             RGBColor[
              0.22634894968623231`, 0.35523747584550047`, 0.9362016098801433],
              UndirectedEdge[251, 447] -> 
             RGBColor[
              0.4395361264241692, 0.5551258338057223, 0.9492278312025804], 
             UndirectedEdge[58, 144] -> 
             RGBColor[
              0.24826092960193386`, 0.3782683560366715, 0.9374494647204732], 
             UndirectedEdge[11, 404] -> 
             RGBColor[
              0.8740472245688059, 0.4191181540612454, 0.3950653321159444], 
             UndirectedEdge[270, 329] -> 
             RGBColor[
              0.18719494717707214`, 0.31408413670123125`, 0.9339718473604026],
              UndirectedEdge[314, 406] -> 
             RGBColor[
              0.7976121679228045, 0.8382528191088208, 0.7664545561818166], 
             UndirectedEdge[13, 409] -> 
             RGBColor[
              0.540422450424237, 0.6377783168651694, 0.9569631814115112], 
             UndirectedEdge[279, 335] -> 
             RGBColor[
              0.30955781786322234`, 0.442114188825357, 0.9409615081295651], 
             UndirectedEdge[195, 446] -> 
             RGBColor[
              0.20832130976855523`, 0.33628928327363344`, 0.9351749624563348],
              UndirectedEdge[22, 170] -> 
             RGBColor[
              0.20408136056054266`, 0.3318328278277056, 0.9349335036213813], 
             UndirectedEdge[159, 166] -> 
             RGBColor[
              0.3352108410982161, 0.45943457954147626`, 0.9427754713265473], 
             UndirectedEdge[59, 87] -> 
             RGBColor[
              0.7284229725600728, 0.7874364169703292, 0.9739093048334139], 
             UndirectedEdge[176, 407] -> 
             RGBColor[
              0.7860294343098881, 0.8332871901386956, 0.9791708607176912], 
             UndirectedEdge[169, 470] -> 
             RGBColor[
              0.22323454419872468`, 0.35196403821341704`, 0.9360242490949797],
              UndirectedEdge[13, 188] -> 
             RGBColor[
              0.4598981295480561, 0.5704218386954567, 0.9511719778781306], 
             UndirectedEdge[273, 396] -> 
             RGBColor[
              0.23652515386637785`, 0.3659333116474439, 0.9367811296538575], 
             UndirectedEdge[30, 405] -> 
             RGBColor[
              0.18482655001024287`, 0.3115948011138402, 0.9338369706454812], 
             UndirectedEdge[258, 497] -> 
             RGBColor[
              0.9702608694884922, 0.9076733512787738, 0.4294614400173077], 
             UndirectedEdge[90, 485] -> 
             RGBColor[
              0.5765425629929836, 0.6671022514410058, 0.9598066889852549], 
             UndirectedEdge[89, 455] -> 
             RGBColor[
              0.8311431839354053, 0.386165029469115, 0.43827649964506243`], 
             UndirectedEdge[422, 451] -> 
             RGBColor[
              0.2947402709569025, 0.42712109076119387`, 0.9400963944506149], 
             UndirectedEdge[99, 178] -> 
             RGBColor[
              0.8637848357389819, 0.3779702522582219, 0.20492941108331192`], 
             UndirectedEdge[119, 416] -> 
             RGBColor[
              0.25584298681039175`, 0.38616481482489873`, 0.9378839159108214],
              UndirectedEdge[129, 204] -> 
             RGBColor[
              0.8203413302090085, 0.8600631926608293, 0.9825983689433555], 
             UndirectedEdge[1, 381] -> 
             RGBColor[
              0.24294210956451456`, 0.3726779389446759, 0.9371465657878312], 
             UndirectedEdge[287, 409] -> 
             RGBColor[
              0.6896306090099416, 0.7560613412803963, 0.970719252222427], 
             UndirectedEdge[340, 384] -> 
             RGBColor[
              0.8080357036472916, 0.8499629868732397, 0.9401530383545316], 
             UndirectedEdge[233, 379] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[1, 124] -> 
             RGBColor[
              0.2366309542553628, 0.3660445145643992, 0.9367871548294926], 
             UndirectedEdge[134, 309] -> 
             RGBColor[
              0.2100987137423066, 0.33815744754396704`, 0.9352761829832064], 
             UndirectedEdge[1, 380] -> 
             RGBColor[
              0.24115428756237606`, 0.37079882466596636`, 0.937044751969655], 
             UndirectedEdge[112, 403] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[214, 268] -> 
             RGBColor[
              0.21337122568436184`, 0.3415970650843082, 0.9354625476970588], 
             UndirectedEdge[404, 444] -> 
             RGBColor[
              0.8285562969045, 0.22050178822288907`, 0.17497884820646079`], 
             UndirectedEdge[252, 320] -> 
             RGBColor[
              0.19096927332444358`, 0.31805119278821803`, 0.9341867896508802],
              UndirectedEdge[173, 419] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[407, 475] -> 
             RGBColor[
              0.8152617742014696, 0.8564271005964393, 0.9760940494423469], 
             UndirectedEdge[167, 305] -> 
             RGBColor[
              0.6596309315266682, 0.7315335449103904, 0.9685563499845072], 
             UndirectedEdge[407, 482] -> 
             RGBColor[
              0.812258959101159, 0.8541876060112861, 0.9811770321475642], 
             UndirectedEdge[197, 493] -> 
             RGBColor[
              0.5014513704988036, 0.60505757525172, 0.9541942678191915], 
             UndirectedEdge[235, 300] -> 
             RGBColor[
              0.3827432544500259, 0.5059347025944629, 0.9456090396203527], 
             UndirectedEdge[312, 385] -> 
             RGBColor[
              0.21913828808169364`, 0.347658613316779, 0.9357909733689826], 
             UndirectedEdge[188, 318] -> 
             RGBColor[
              0.3206397205634015, 0.4477294311094059, 0.9418134869378495], 
             UndirectedEdge[71, 153] -> 
             RGBColor[
              0.3288978182766464, 0.4547857321627663, 0.9423432170599901], 
             UndirectedEdge[45, 481] -> 
             RGBColor[
              0.2835821880689775, 0.4153932381826685, 0.939460958137052], 
             UndirectedEdge[53, 317] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[253, 301] -> 
             RGBColor[
              0.8742585681452911, 0.41920555006140414`, 0.39156282211394233`],
              UndirectedEdge[442, 447] -> 
             RGBColor[
              0.43707590774460403`, 0.5529949160396692, 0.9490710682438044], 
             UndirectedEdge[118, 464] -> 
             RGBColor[
              0.2582088050321171, 0.38872420384552575`, 0.9380159815096591], 
             UndirectedEdge[2, 118] -> 
             RGBColor[
              0.2188823691598405, 0.3473896263037145, 0.9357763991649812], 
             UndirectedEdge[332, 454] -> 
             RGBColor[
              0.26600423470039036`, 0.39588544200916653`, 0.9384977155240641],
              UndirectedEdge[84, 455] -> 
             RGBColor[
              0.7711297731426533, 0.3390729855096647, 0.43235041543167274`], 
             UndirectedEdge[423, 488] -> 
             RGBColor[
              0.18727196886148448`, 0.3141650913750055, 0.9339762336313865], 
             UndirectedEdge[5, 231] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[121, 337] -> 
             RGBColor[
              0.25724680271789735`, 0.38771307841881125`, 0.9379611969010192],
              UndirectedEdge[23, 360] -> 
             RGBColor[
              0.8792976493045557, 0.4456457928586737, 0.2568665901106246], 
             UndirectedEdge[79, 336] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[237, 371] -> 
             RGBColor[
              0.4848427832349989, 0.5918340156659786, 0.9528149292291238], 
             UndirectedEdge[9, 330] -> 
             RGBColor[
              0.23388775769536924`, 0.36316124105113845`, 0.9366309338435965],
              UndirectedEdge[76, 111] -> 
             RGBColor[
              0.9894404720113958, 0.9890932090554398, 0.7659168812648544], 
             UndirectedEdge[91, 256] -> 
             RGBColor[
              0.914728589855879, 0.8931453763833161, 0.6512126420152853], 
             UndirectedEdge[35, 193] -> 
             RGBColor[
              0.20201306311706924`, 0.32965891607698306`, 0.9348157171417473],
              UndirectedEdge[43, 267] -> 
             RGBColor[
              0.40347694898297903`, 0.5238931866931191, 0.9469301723019063], 
             UndirectedEdge[261, 448] -> 
             RGBColor[
              0.8753169012348998, 0.903417953473117, 0.9879697015160488], 
             UndirectedEdge[322, 374] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[76, 130] -> 
             RGBColor[
              0.9137694672197825, 0.9300716783330631, 0.8049197639965786], 
             UndirectedEdge[107, 153] -> 
             RGBColor[
              0.35862018099566284`, 0.48504050882921934`, 0.944071938711037], 
             UndirectedEdge[410, 437] -> 
             RGBColor[
              0.19252529616452413`, 0.31968667145068896`, 0.9342754028496933],
              UndirectedEdge[11, 164] -> 
             RGBColor[
              0.9340834784629356, 0.9483907377638316, 0.9226198202751702], 
             UndirectedEdge[213, 500] -> 
             RGBColor[
              0.2766042930680527, 0.40805902811260025`, 0.9390635773396199], 
             UndirectedEdge[251, 454] -> 
             RGBColor[
              0.38596006350609297`, 0.5087209409173039, 0.9458140118488928], 
             UndirectedEdge[111, 483] -> 
             RGBColor[
              0.977978612779826, 0.951566610311706, 0.6247122270146903], 
             UndirectedEdge[5, 233] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[69, 372] -> 
             RGBColor[
              0.8720195914369621, 0.405748016840095, 0.23691988196683633`], 
             UndirectedEdge[454, 489] -> 
             RGBColor[
              0.2767586893045861, 0.4071890556699812, 0.9391101658039832], 
             UndirectedEdge[289, 493] -> 
             RGBColor[
              0.4515126766845066, 0.5618031886615082, 0.9510122184083976], 
             UndirectedEdge[74, 268] -> 
             RGBColor[
              0.21587322879511397`, 0.3442268289898683, 0.9356050330728343], 
             UndirectedEdge[192, 258] -> 
             RGBColor[
              0.9320737133765145, 0.9444030306208892, 0.78526845033412], 
             UndirectedEdge[68, 368] -> 
             RGBColor[
              0.19358411070805037`, 0.32079955266865445`, 0.9343357007715714],
              UndirectedEdge[50, 414] -> 
             RGBColor[
              0.8759899507757182, 0.41879994377265284`, 0.28134248690904895`],
              UndirectedEdge[358, 441] -> 
             RGBColor[
              0.3764338650694757, 0.5004698266321612, 0.945207010908198], 
             UndirectedEdge[71, 289] -> 
             RGBColor[
              0.2867699726445978, 0.4182967096833736, 0.9396588679885072], 
             UndirectedEdge[54, 321] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[75, 408] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[8, 239] -> 
             RGBColor[
              0.25705844491916985`, 0.3875151024297744, 0.9379504702030321], 
             UndirectedEdge[389, 472] -> 
             RGBColor[
              0.22243976571633683`, 0.35112867563656114`, 0.9359789876361772],
              UndirectedEdge[178, 475] -> 
             RGBColor[
              0.9494877447629478, 0.9110570904198478, 0.6344884471591432], 
             UndirectedEdge[332, 489] -> 
             RGBColor[
              0.22285222532450405`, 0.35156219683619444`, 0.9360024766006829],
              UndirectedEdge[28, 406] -> 
             RGBColor[
              0.971585860971019, 0.9130263803621124, 0.4246172301504474], 
             UndirectedEdge[77, 87] -> 
             RGBColor[
              0.896783278694488, 0.9204422732959663, 0.9868140728389698], 
             UndirectedEdge[274, 300] -> 
             RGBColor[
              0.45102395983649046`, 0.5642446191206338, 0.9501895436973189], 
             UndirectedEdge[330, 333] -> 
             RGBColor[
              0.32128397349438886`, 0.4449420277747629, 0.9419770304831396], 
             UndirectedEdge[325, 490] -> 
             RGBColor[
              0.384235761313647, 0.5072274370241554, 0.9457041408379308], 
             UndirectedEdge[420, 489] -> 
             RGBColor[
              0.2259038792592088, 0.3547696786076038, 0.936176263777747], 
             UndirectedEdge[271, 304] -> 
             RGBColor[
              0.26712476583186534`, 0.39809544395062635`, 0.9385237322872229],
              UndirectedEdge[166, 387] -> 
             RGBColor[
              0.2364720735351036, 0.36587752085378733`, 0.9367781068075168], 
             UndirectedEdge[16, 165] -> 
             RGBColor[
              0.7458367292928169, 0.8015726905647942, 0.9752485920882636], 
             UndirectedEdge[44, 356] -> 
             RGBColor[
              0.5955073527677653, 0.681625690653308, 0.9618965630981988], 
             UndirectedEdge[86, 377] -> 
             RGBColor[
              0.19669430319698816`, 0.3240685621721215, 0.9345128216326989], 
             UndirectedEdge[113, 353] -> 
             RGBColor[
              0.22107694525191812`, 0.3496962649206489, 0.9359013770268407], 
             UndirectedEdge[63, 222] -> 
             RGBColor[
              0.27812742646781496`, 0.4096599378879857, 0.9391503175334623], 
             UndirectedEdge[71, 493] -> 
             RGBColor[
              0.4247009633868117, 0.5340694702303104, 0.9494689607646909], 
             UndirectedEdge[106, 270] -> 
             RGBColor[
              0.18303490781801574`, 0.3097116715731334, 0.933734939273131], 
             UndirectedEdge[414, 498] -> 
             RGBColor[
              0.8759899507757182, 0.41879994377265295`, 0.28134248690904895`],
              UndirectedEdge[46, 220] -> 
             RGBColor[
              0.3163259847955163, 0.44627491059736407`, 0.9414550708794333], 
             UndirectedEdge[302, 443] -> 
             RGBColor[
              0.6197751789448227, 0.7005305366504255, 0.9643518386481924], 
             UndirectedEdge[90, 267] -> 
             RGBColor[
              0.5020615308844408, 0.6053397431537071, 0.9543012063004392], 
             UndirectedEdge[116, 187] -> 
             RGBColor[
              0.5258049734314325, 0.6229278732874357, 0.956899298837582], 
             UndirectedEdge[162, 472] -> 
             RGBColor[
              0.19746627468796812`, 0.32487995315496093`, 0.9345567842670808],
              UndirectedEdge[271, 371] -> 
             RGBColor[
              0.4256104330710305, 0.5401439642837345, 0.9490548283881131], 
             UndirectedEdge[84, 478] -> 
             RGBColor[
              0.5977451472226231, 0.6837579805651962, 0.9618569888835327], 
             UndirectedEdge[5, 163] -> RGBColor[0.817319, 0.134127, 0.164218],
              UndirectedEdge[188, 430] -> 
             RGBColor[
              0.3283401366482528, 0.45582305664916356`, 0.9422520142421371], 
             UndirectedEdge[380, 487] -> 
             RGBColor[
              0.2270742510106255, 0.35599981352419774`, 0.9362429147175804], 
             UndirectedEdge[88, 304] -> 
             RGBColor[
              0.22720116780943558`, 0.35613321112673696`, 0.9362501424415159],
              UndirectedEdge[41, 494] -> 
             RGBColor[
              0.7862603193212523, 0.8326898579584304, 0.949304381285405], 
             UndirectedEdge[23, 136] -> 
             RGBColor[
              0.9410230313708325, 0.7887755730421966, 0.3307097337117372], 
             UndirectedEdge[7, 84] -> 
             RGBColor[
              0.8160959914872512, 0.8010398665049154, 0.62500535758886], 
             UndirectedEdge[218, 493] -> 
             RGBColor[
              0.6646305094061155, 0.737123077010855, 0.9677620244253071], 
             UndirectedEdge[40, 183] -> 
             RGBColor[
              0.23087447888683538`, 0.35999409397045823`, 0.9364593320731971],
              UndirectedEdge[192, 453] -> 
             RGBColor[
              0.6640388061322713, 0.735051317746148, 0.9689732627371802], 
             UndirectedEdge[49, 397] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[291, 467] -> 
             RGBColor[
              0.21418854935951206`, 0.34245612408820514`, 0.9355090930712366],
              UndirectedEdge[347, 462] -> 
             RGBColor[
              0.25493221981671754`, 0.3852803050366393, 0.9378293848289156], 
             UndirectedEdge[31, 226] -> 
             RGBColor[
              0.22438551241201804`, 0.35317377878118794`, 0.9360897950320219],
              UndirectedEdge[120, 381] -> 
             RGBColor[
              0.20121572608791957`, 0.32882086430525925`, 0.9347703099774917],
              UndirectedEdge[151, 274] -> 
             RGBColor[
              0.3848156105760768, 0.5047669089099905, 0.9460488459712351], 
             UndirectedEdge[316, 418] -> 
             RGBColor[
              0.9672391665729247, 0.8989591012601537, 0.3386522526091738], 
             UndirectedEdge[235, 389] -> 
             RGBColor[
              0.29759964420875396`, 0.4265548325280502, 0.9403900067936175], 
             UndirectedEdge[218, 310] -> 
             RGBColor[
              0.7914851171285034, 0.354974734937755, 0.4343792458886776], 
             UndirectedEdge[408, 463] -> 
             RGBColor[
              0.831998657058118, 0.24386491747293382`, 0.17815401051060936`], 
             UndirectedEdge[12, 273] -> 
             RGBColor[
              0.22919575579368628`, 0.35822964956236686`, 0.9363637312764905],
              UndirectedEdge[121, 454] -> 
             RGBColor[
              0.3058588106164846, 0.437775128223043, 0.9407673746629241], 
             UndirectedEdge[47, 228] -> 
             RGBColor[
              0.643625510819642, 0.7204555301268813, 0.9658450315184992], 
             UndirectedEdge[438, 439] -> 
             RGBColor[
              0.27373103330916027`, 0.40503904993081363`, 0.9388999494469579],
              UndirectedEdge[172, 201] -> 
             RGBColor[
              0.4728690965671932, 0.5808891368792599, 0.9522105393803614], 
             UndirectedEdge[58, 375] -> 
             RGBColor[
              0.26089059756321387`, 0.3915429378311758, 0.9381687056269487], 
             UndirectedEdge[168, 280] -> 
             RGBColor[
              0.6614695904816725, 0.7339397277713925, 0.9679351497630158], 
             UndirectedEdge[77, 301] -> 
             RGBColor[
              0.8579732191915481, 0.4074969800510354, 0.43870016507762466`], 
             UndirectedEdge[283, 477] -> 
             RGBColor[
              0.22686340443243364`, 0.3557782004020729, 0.9362309073168718], 
             UndirectedEdge[125, 149] -> 
             RGBColor[
              0.8300337551067959, 0.23185817939204778`, 0.1763936638495297], 
             UndirectedEdge[7, 407] -> 
             RGBColor[
              0.8208526148202658, 0.8047557768043427, 0.6254794533495226], 
             UndirectedEdge[401, 437] -> 
             RGBColor[
              0.189249743774186, 0.31624385820642686`, 0.9340888649868091], 
             UndirectedEdge[138, 438] -> 
             RGBColor[
              0.23827977325697014`, 0.3677775278762512, 0.936881052632425], 
             UndirectedEdge[45, 399] -> 
             RGBColor[
              0.2892039179868987, 0.4213020327646674, 0.9397811073392734], 
             UndirectedEdge[97, 317] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[71, 201] -> 
             RGBColor[
              0.41387149855588806`, 0.5252776228187356, 0.9486164256235639], 
             UndirectedEdge[107, 236] -> 
             RGBColor[
              0.31255501519915574`, 0.44486020542195137`, 0.9411469948451532],
              UndirectedEdge[134, 225] -> 
             RGBColor[
              0.20098661279686494`, 0.32858005170973914`, 0.9347572623145088],
              UndirectedEdge[59, 91] -> 
             RGBColor[
              0.7833793217020255, 0.7895587302313833, 0.6386349089300231], 
             UndirectedEdge[161, 287] -> 
             RGBColor[
              0.5848187798365858, 0.6676682441493317, 0.9633804701369508], 
             UndirectedEdge[101, 486] -> 
             RGBColor[
              0.7422414987302901, 0.793474440705987, 0.7763586554254926], 
             UndirectedEdge[185, 330] -> 
             RGBColor[
              0.2727206891407805, 0.40287895172931015`, 0.9388826209469538], 
             UndirectedEdge[237, 432] -> 
             RGBColor[
              0.5972113990161616, 0.6810833809213088, 0.9630123689183746], 
             UndirectedEdge[99, 143] -> 
             RGBColor[
              0.8239416059032, 0.18503125101640663`, 0.1705598148920679], 
             UndirectedEdge[107, 411] -> 
             RGBColor[
              0.5158561344435298, 0.6131266190837553, 0.9567665221218118], 
             UndirectedEdge[187, 407] -> 
             RGBColor[
              0.5277223378654804, 0.6244257329558234, 0.9570904038055785], 
             UndirectedEdge[185, 357] -> 
             RGBColor[
              0.2704886241626608, 0.4005329099162129, 0.9387555081484942], 
             UndirectedEdge[80, 208] -> 
             RGBColor[
              0.9754972680138669, 0.9778179512987408, 0.718003495698742], 
             UndirectedEdge[60, 240] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[262, 299] -> 
             RGBColor[
              0.7053148813089781, 0.7675537158569028, 0.9584619306105826], 
             UndirectedEdge[82, 282] -> 
             RGBColor[
              0.844192723800754, 0.2992353265545988, 0.18832903870459236`], 
             UndirectedEdge[286, 368] -> 
             RGBColor[
              0.19782344597820478`, 0.32525536282696743`, 0.934577124643672], 
             UndirectedEdge[81, 454] -> 
             RGBColor[
              0.38458547196747705`, 0.5075303388155344, 0.9457264240915557], 
             UndirectedEdge[68, 352] -> 
             RGBColor[
              0.20254407979161715`, 0.33021704827033466`, 0.934845957755794], 
             UndirectedEdge[196, 337] -> 
             RGBColor[
              0.2289545201015995, 0.3579760955547574, 0.9363499932607025], 
             UndirectedEdge[261, 262] -> 
             RGBColor[
              0.9391282219438701, 0.953882854240121, 0.979615271589626], 
             UndirectedEdge[122, 286] -> 
             RGBColor[
              0.21170798349237516`, 0.3398488920848844, 0.9353678285147715]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {3}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.3086579844982561, 0.441749490127162, 0.9408889876473829], 316 -> 
             RGBColor[
              0.9859314232921296, 0.9642055286847646, 0.39984666542805347`], 
             308 -> RGBColor[
              0.23051962020931505`, 0.35962111500104466`, 0.9364391233964787],
              160 -> RGBColor[
              0.45486118183922636`, 0.5683158245366335, 0.9502274849272453], 
             245 -> RGBColor[
              0.4829394273144061, 0.5911110091239283, 0.9524379072650536], 
             155 -> RGBColor[
              0.24352168839563612`, 0.373287113043605, 0.9371795719448536], 
             425 -> RGBColor[
              0.21231746253184797`, 0.34048949319857336`, 0.9354025374444261],
              213 -> RGBColor[
              0.2792508331211001, 0.4108407095086842, 0.9392142938804358], 
             352 -> RGBColor[
              0.19816019677618812`, 0.3256093092668817, 0.9345963021034391], 
             27 -> RGBColor[
              0.2059976869465667, 0.3338470083615274, 0.9350426355741145], 
             485 -> RGBColor[
              0.5545695953076797, 0.6492636064031623, 0.9580768964794351], 
             454 -> RGBColor[
              0.3199106986804724, 0.45151230084295324`, 0.9416054047273643], 
             367 -> RGBColor[
              0.25742088082667425`, 0.38789604554832535`, 0.9379711103917886],
              19 -> RGBColor[
              0.28355932289318264`, 0.4153692054331722, 0.9394596559991165], 
             164 -> RGBColor[
              0.8806632832194534, 0.9076810133439271, 0.9884796442025071], 
             190 -> RGBColor[
              0.34462319164040967`, 0.47291702015883946`, 0.943180062926372], 
             103 -> 
             RGBColor[
              0.9943968653913747, 0.9904237865729874, 0.6315115602687539], 
             138 -> RGBColor[
              0.1954809540192259, 0.32279325525551217`, 0.9344437231920146], 
             416 -> RGBColor[
              0.30953300584952725`, 0.44252366491079637`, 0.94094414731681], 
             476 -> RGBColor[
              0.19832380395462978`, 0.32578127078471814`, 0.9346056192902162],
              291 -> RGBColor[
              0.19681365185457406`, 0.3241940051783862, 0.9345196183621879], 
             28 -> RGBColor[
              0.949329454771621, 0.8368152036673847, 0.2780874937999273], 337 -> 
             RGBColor[
              0.22268668288329785`, 0.35138820123448977`, 0.9359930492035543],
              195 -> RGBColor[
              0.21841757556668306`, 0.34690109876769015`, 0.9357499298574514],
              114 -> RGBColor[
              0.1897272593739602, 0.31674575737802724`, 0.9341160587937951], 
             479 -> RGBColor[
              0.1935343324702769, 0.320747232584632, 0.9343328659745704], 93 -> 
             RGBColor[
              0.3738197825598743, 0.4982056397499517, 0.9450404438822286], 34 -> 
             RGBColor[
              0.3081602529797812, 0.4412263427432439, 0.9408606425737336], 
             161 -> RGBColor[
              0.331702995966787, 0.46172619605426385`, 0.9423567994829292], 
             22 -> RGBColor[
              0.19129510586323456`, 0.3183936634454635, 0.9342053453319383], 
             124 -> RGBColor[
              0.20667495168092284`, 0.33455885653840006`, 0.9350812047988127],
              84 -> RGBColor[
              0.67875131942796, 0.7489649565289941, 0.9686152462950182], 46 -> 
             RGBColor[
              0.2856812767955215, 0.41759951352417846`, 0.9395804981347052], 
             241 -> RGBColor[
              0.34023858975482646`, 0.4691192983820458, 0.9429006799713738], 
             185 -> RGBColor[
              0.3206235691378255, 0.4521297534032015, 0.9416508282025402], 
             426 -> RGBColor[
              0.21523898041579886`, 0.3435601937295382, 0.9355689135659188], 
             390 -> RGBColor[
              0.5581381343170947, 0.6521607071318558, 0.9583578249422453], 
             121 -> RGBColor[
              0.29180692255249685`, 0.42403795560313273`, 0.9399293445984841],
              322 -> RGBColor[0.817319, 0.134127, 0.164218], 488 -> 
             RGBColor[
              0.19444137114962554`, 0.3217005877462013, 0.9343845204855159], 
             126 -> RGBColor[
              0.9344583887804918, 0.7778563825015339, 0.2661218850346821], 
             433 -> RGBColor[
              0.18644975521125867`, 0.31330089269726175`, 0.9339294097803622],
              236 -> RGBColor[
              0.3057070456133757, 0.438647866258821, 0.9407209360434119], 78 -> 
             RGBColor[
              0.9560909454429859, 0.8635465900222101, 0.28392204388553066`], 
             376 -> RGBColor[
              0.9860284094714858, 0.9884904025100302, 0.8812089425821105], 
             458 -> RGBColor[
              0.45245153773684854`, 0.5663125139373179, 0.9500507897907745], 
             254 -> RGBColor[
              0.2370889777331282, 0.36652592627989644`, 0.9368132385889664], 
             290 -> RGBColor[
              0.1901247553990758, 0.3171635509031274, 0.9341386956043828], 
             251 -> RGBColor[
              0.45200942833171354`, 0.5659295809916547, 0.9500226189704213], 
             165 -> RGBColor[
              0.8447410453925083, 0.8790375959838911, 0.9850533490904128], 
             460 -> RGBColor[
              0.8245721358999006, 0.8629554550249494, 0.9831296204980098], 
             100 -> RGBColor[0.817319, 0.134127, 0.164218], 235 -> 
             RGBColor[
              0.3473763609653794, 0.4753016770498144, 0.9433554924412271], 70 -> 
             RGBColor[
              0.9855771277360073, 0.9883037859149981, 0.8886878488186855], 
             234 -> RGBColor[0.817319, 0.134127, 0.164218], 435 -> 
             RGBColor[
              0.4494598255363201, 0.5637212431970474, 0.949860160534824], 257 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 135 -> 
             RGBColor[
              0.18353112071158095`, 0.3102332227859851, 0.9337631978633384], 
             265 -> RGBColor[
              0.20216870968076056`, 0.32982251048398475`, 0.9348245809832911],
              111 -> RGBColor[
              0.9845357488920988, 0.9878731490008265, 0.9059461912643052], 
             497 -> RGBColor[
              0.946570060984783, 0.8258751268160418, 0.27586722078774056`], 
             481 -> RGBColor[
              0.2923941296611816, 0.4246551475054415, 0.9399627851746286], 
             381 -> RGBColor[
              0.2192972622992264, 0.34782570529895346`, 0.9358000267154899], 
             182 -> RGBColor[
              0.9544946818446345, 0.965582788744624, 0.9619128133359728], 188 -> 
             RGBColor[
              0.38027801256113686`, 0.5037994339769674, 0.9454519565871206], 
             154 -> RGBColor[0.817319, 0.134127, 0.164218], 336 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 463 -> 
             RGBColor[
              0.861357971174354, 0.4633407524188015, 0.20602603153182808`], 
             315 -> RGBColor[
              0.1982372182974502, 0.32569026376917465`, 0.9346006883651319], 
             368 -> RGBColor[
              0.18024025860905457`, 0.30677431806352135`, 0.9335757881349936],
              269 -> RGBColor[0.817319, 0.134127, 0.164218], 208 -> 
             RGBColor[
              0.9930049498136619, 0.9874466198965118, 0.4800101395419234], 86 -> 
             RGBColor[
              0.20642970531273738`, 0.3343010870559193, 0.9350672383809541], 
             119 -> RGBColor[
              0.2021529677712563, 0.32980596473900103`, 0.9348236845048329], 
             436 -> RGBColor[
              0.9696998197036082, 0.9769227556637184, 0.9361744810758174], 
             377 -> RGBColor[
              0.18695890108123892`, 0.31383603728832365`, 0.9339584048844437],
              140 -> RGBColor[
              0.17930336856424547`, 0.3057895872241672, 0.9335224336329464], 
             85 -> RGBColor[
              0.21486301907210675`, 0.34316503451999186`, 0.9355475031235805],
              351 -> RGBColor[
              0.45951259018598095`, 0.572092047376087, 0.950593660830972], 
             443 -> RGBColor[
              0.7513693824412065, 0.8056947392726626, 0.9758531361617966], 
             242 -> RGBColor[0.817319, 0.134127, 0.164218], 117 -> 
             RGBColor[
              0.19890073469948152`, 0.32638766157707927`, 0.9346384746426429],
              47 -> RGBColor[
              0.7146679187190441, 0.7770232768714539, 0.97219507725265], 451 -> 
             RGBColor[
              0.2916100124153255, 0.4238309905641419, 0.9399181308574747], 81 -> 
             RGBColor[
              0.4492602452544817, 0.5635483767881156, 0.9498474434557472], 
             275 -> RGBColor[
              0.9334491648933394, 0.7738551460928987, 0.26530983980554995`], 
             23 -> RGBColor[
              0.9925631716550148, 0.9865017010857893, 0.43192531331195433`], 
             328 -> RGBColor[
              0.4770512439418583, 0.586330716602456, 0.9519743679008402], 418 -> 
             RGBColor[
              0.94854690985372, 0.8337126738355427, 0.27745783979029415`], 
             110 -> RGBColor[
              0.9937947583663093, 0.9891359405287304, 0.5659759263641978], 6 -> 
             RGBColor[
              0.33431180974343394`, 0.46398581942480244`, 0.9425230307898937],
              218 -> 
             RGBColor[
              0.7398173513855104, 0.796670204813265, 0.9747017376660327], 108 -> 
             RGBColor[
              0.3113782533268795, 0.444121925530844, 0.9410617248543786], 297 -> 
             RGBColor[
              0.24929221648012767`, 0.37935230393301794`, 0.937508194982534], 
             487 -> RGBColor[
              0.2384268837263016, 0.3679321503068611, 0.936889430356023], 464 -> 
             RGBColor[
              0.2802695819329819, 0.41191147910237724`, 0.9392723101181687], 
             157 -> RGBColor[
              0.8177268607774917, 0.8575337056844831, 0.9824670294564657], 
             441 -> RGBColor[
              0.3682418148538177, 0.4933742844797741, 0.9446850207124019], 
             354 -> RGBColor[
              0.8619160083689651, 0.8927324452593671, 0.9866915123913776], 
             385 -> RGBColor[
              0.1902491888261562, 0.31729433832452386`, 0.9341457819039722], 
             270 -> RGBColor[
              0.18403967249588782`, 0.31076774295533705`, 0.9337921591351197],
              392 -> RGBColor[
              0.4420343431064375, 0.5572896635318818, 0.9493870153604882], 33 -> 
             RGBColor[
              0.5603811253615456, 0.6539816683073362, 0.9585344014136115], 
             252 -> RGBColor[
              0.1934857951277101, 0.32069621676014903`, 0.9343301018447159], 
             394 -> RGBColor[
              0.19842878437042233`, 0.3258916118578589, 0.934611597769591], 
             260 -> RGBColor[
              0.3120362716652125, 0.4446918679425447, 0.9411036532010344], 
             159 -> RGBColor[
              0.41932351101049736`, 0.5376186822499895, 0.9479399012217352], 
             183 -> RGBColor[
              0.2566248317017963, 0.38705934744564896`, 0.9379257765717759], 
             99 -> RGBColor[0.817319, 0.134127, 0.164218], 329 -> 
             RGBColor[
              0.19035022185825642`, 0.3174005304471254, 0.9341515355856854], 
             309 -> RGBColor[
              0.21885291985763583`, 0.3473586732199038, 0.935774722070787], 
             17 -> RGBColor[
              0.9874606584389937, 0.9890826742652142, 0.8574728706489945], 
             349 -> RGBColor[
              0.2059271258124198, 0.33377284413570474`, 0.9350386172219107], 
             495 -> RGBColor[0.817319, 0.134127, 0.164218], 347 -> 
             RGBColor[
              0.2829518153401187, 0.4147306764766984, 0.9394250593426964], 
             340 -> RGBColor[
              0.981651687789881, 0.9858364393130727, 0.9159430859521958], 404 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 277 -> 
             RGBColor[
              0.9810175438161675, 0.9476298593785759, 0.3807571715722161], 
             104 -> RGBColor[0.817319, 0.134127, 0.164218], 79 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 327 -> 
             RGBColor[
              0.19982772421039008`, 0.3273619863275738, 0.9346912653239311], 
             191 -> RGBColor[
              0.22919385631472186`, 0.35822765308954135`, 0.9363636231039736],
              50 -> RGBColor[0.817319, 0.134127, 0.164218], 225 -> 
             RGBColor[
              0.2006287179667525, 0.32820388155144814`, 0.9347368807333919], 
             405 -> RGBColor[
              0.19069604752509664`, 0.31776401514958813`, 0.9341712298458087],
              61 -> RGBColor[0.817319, 0.134127, 0.164218], 196 -> 
             RGBColor[
              0.23522235731990115`, 0.36456398987502503`, 0.9367069373178505],
              1 -> RGBColor[
              0.2665869568298027, 0.3975301725903983, 0.9384931048601725], 
             263 -> RGBColor[
              0.38201222096486337`, 0.5053015181324264, 0.9455624588131057], 
             201 -> RGBColor[
              0.5677847377648733, 0.6599922543852954, 0.9591172409023272], 
             371 -> RGBColor[
              0.5466494280863021, 0.6428336578533808, 0.9574533919032397], 
             293 -> RGBColor[0.817319, 0.134127, 0.164218], 362 -> 
             RGBColor[
              0.18026187282935408`, 0.3067970359794769, 0.9335770190328644], 
             184 -> RGBColor[
              0.8763132971847281, 0.531249394926778, 0.21850512214346993`], 
             106 -> RGBColor[
              0.18203014314014365`, 0.3086556001909298, 0.9336777194111423], 
             206 -> RGBColor[
              0.18533323543547214`, 0.3121273596214676, 0.9338658256308742], 
             358 -> RGBColor[
              0.3846259152851337, 0.5075653687845483, 0.9457290011039943], 
             247 -> RGBColor[
              0.2019820387076045, 0.3296263074555744, 0.9348139503475248], 
             220 -> RGBColor[
              0.3469706927955112, 0.4749503076705497, 0.9433296436241613], 
             407 -> RGBColor[
              0.6882645660939893, 0.7563967771278489, 0.9695634378163434], 
             107 -> RGBColor[
              0.3194029847849358, 0.4510725445850818, 0.9415730536468945], 
             375 -> RGBColor[
              0.28151321698943976`, 0.41321861839773133`, 0.9393431332948408],
              131 -> RGBColor[0.817319, 0.134127, 0.164218], 411 -> 
             RGBColor[
              0.7123092841021239, 0.7751806935824288, 0.9719599905967291], 
             462 -> RGBColor[
              0.22691262429331643`, 0.35582993359658016`, 0.9362337103151348],
              127 -> RGBColor[0.817319, 0.134127, 0.164218], 210 -> 
             RGBColor[
              0.2504170603715949, 0.38053458618217195`, 0.9375722531780957], 
             357 -> RGBColor[
              0.22035367918749607`, 0.34893606642922426`, 0.9358601880944482],
              181 -> RGBColor[
              0.3876691533578903, 0.5102012686455771, 0.9459229135429605], 
             194 -> RGBColor[
              0.20985498932745156`, 0.3379012777309339, 0.9352623032383384], 
             440 -> RGBColor[0.817319, 0.134127, 0.164218], 490 -> 
             RGBColor[
              0.34185985738752034`, 0.47052355891820463`, 0.9430039857112984],
              118 -> RGBColor[
              0.23614802813125227`, 0.3655369285886743, 0.9367596529011497], 
             348 -> RGBColor[
              0.9627353434690271, 0.8859597047428938, 0.30973427552741817`], 
             276 -> RGBColor[
              0.33049394994511194`, 0.46067898115870887`, 0.9422797601395455],
              305 -> RGBColor[
              0.8618019499281809, 0.8926414981547197, 0.9866806333954745], 
             343 -> RGBColor[0.817319, 0.134127, 0.164218], 280 -> 
             RGBColor[
              0.5428330408674731, 0.6397353427828505, 0.9571529519214865], 
             474 -> RGBColor[
              0.4068383352175211, 0.5268046505012949, 0.9471443568604142], 
             189 -> RGBColor[
              0.5334133816925579, 0.6320880391138444, 0.9564114018458887], 
             168 -> RGBColor[
              0.7801061400958719, 0.8281441127599345, 0.9787173476045451], 
             363 -> RGBColor[
              0.1948064264350734, 0.3220842839970489, 0.9344053098439712], 41 -> 
             RGBColor[
              0.6031363050639882, 0.6886922492886749, 0.9619002457771715], 14 -> 
             RGBColor[
              0.4138740589676099, 0.532898640787864, 0.9475926669563236], 77 -> 
             RGBColor[
              0.9392816575746442, 0.9542369401531062, 0.9876644952328739], 51 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 438 -> 
             RGBColor[
              0.28107859249471434`, 0.41276180049699024`, 0.9393183820728355],
              179 -> RGBColor[
              0.270181620235489, 0.40130839174459826`, 0.9386978156232983], 
             467 -> RGBColor[
              0.23156344686445007`, 0.3607182429980241, 0.9364985677802855], 
             223 -> 
             RGBColor[
              0.3049544364430743, 0.43785682630265677`, 0.9406780760645487], 
             456 -> RGBColor[
              0.25079540388990307`, 0.3809322492082784, 0.9375937992817542], 
             323 -> RGBColor[0.817319, 0.134127, 0.164218], 500 -> 
             RGBColor[
              0.27395775301500525`, 0.40527734671651633`, 0.938912860798804], 
             478 -> RGBColor[
              0.5167389750172862, 0.6185510046013983, 0.955098731472047], 292 -> 
             RGBColor[
              0.2056030288546981, 0.3334321976842053, 0.9350201603796269], 
             491 -> RGBColor[
              0.1905565107603236, 0.3176173531626698, 0.9341632834334811], 
             396 -> RGBColor[
              0.25866502514756723`, 0.3892037201128899, 0.9380419625703169], 
             321 -> RGBColor[0.817319, 0.134127, 0.164218], 143 -> 
             RGBColor[
              0.8371868177096, 0.28683975304921994`, 0.1832434446762037], 112 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 197 -> 
             RGBColor[
              0.4134590735708867, 0.5325392012949949, 0.9475662244538017], 
             421 -> RGBColor[
              0.2022293934039294, 0.3298862929246055, 0.934828036831552], 54 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 71 -> 
             RGBColor[
              0.25995825934690286`, 0.39056299125217575`, 0.9381156103448005],
              177 -> RGBColor[
              0.20242608517667066`, 0.3300930284487352, 0.9348392381370303], 
             158 -> RGBColor[
              0.23397806856290648`, 0.3632561634989598, 0.9366360769138999], 
             226 -> RGBColor[
              0.21361395179144738`, 0.34185218561257913`, 0.9354763705897763],
              432 -> RGBColor[
              0.7713866596486274, 0.8213323883640413, 0.9778482712817413], 
             350 -> RGBColor[
              0.19011491379531606`, 0.31715320675358216`, 0.9341381351396081],
              203 -> RGBColor[0.817319, 0.134127, 0.164218], 475 -> 
             RGBColor[
              0.94225898230895, 0.9564574240650298, 0.9826246610683506], 115 -> 
             RGBColor[
              0.23087379955273474`, 0.3599933799472462, 0.9364592933861251], 
             173 -> RGBColor[0.817319, 0.134127, 0.164218], 212 -> 
             RGBColor[
              0.1919302366972257, 0.31906122622160893`, 0.9342415150933422], 
             129 -> RGBColor[
              0.7604405856228837, 0.8127812321418865, 0.9767572689197328], 
             279 -> RGBColor[
              0.304084721945441, 0.4369427012225601, 0.9406285471105358], 26 -> 
             RGBColor[
              0.20463513155106594`, 0.33241487624985433`, 0.9349650400600608],
              40 -> RGBColor[
              0.20512412607187444`, 0.33292884049526744`, 0.9349928875746183],
              146 -> RGBColor[
              0.18386384177004123`, 0.31058293371416035`, 0.933782145835401], 
             386 -> RGBColor[
              0.8434965379903663, 0.8780452595626765, 0.9849346468634116], 
             192 -> RGBColor[
              0.8701957487608276, 0.8993344855002725, 0.9874812414213651], 
             300 -> RGBColor[
              0.4181101479346723, 0.5365677281391114, 0.9478625867994784], 
             221 -> RGBColor[0.817319, 0.134127, 0.164218], 62 -> 
             RGBColor[
              0.5285279267956817, 0.6281218067413252, 0.9560268009403956], 
             286 -> RGBColor[
              0.21540663334735502`, 0.3437364075904136, 0.9355784611523505], 
             472 -> RGBColor[
              0.19705660398054506`, 0.3244493632668362, 0.9345334541263465], 
             152 -> RGBColor[
              0.20179304187532063`, 0.3294276598017528, 0.934803187257522], 
             64 -> RGBColor[
              0.20425044222453645`, 0.33201054337695984`, 0.9349431325720118],
              307 -> RGBColor[
              0.23426115126844915`, 0.3635537013709653, 0.9366521980551972], 
             37 -> RGBColor[0.817319, 0.134127, 0.164218], 148 -> 
             RGBColor[
              0.6735645089681628, 0.7449129807765811, 0.9680982735018852], 
             261 -> RGBColor[
              0.9264054963123022, 0.9441546124248671, 0.9928425773218587], 
             387 -> RGBColor[
              0.22184597588427246`, 0.3505045648746116, 0.9359451721836745], 
             15 -> RGBColor[0.817319, 0.134127, 0.164218], 136 -> 
             RGBColor[
              0.8894828910866501, 0.591049444998604, 0.22949415411151997`], 
             198 -> RGBColor[
              0.19393685411417064`, 0.3211703083537106, 0.9343557889867128], 
             63 -> RGBColor[
              0.29903790758239124`, 0.43163817934048265`, 0.9403411384986529],
              444 -> RGBColor[
              0.8510308907134999, 0.3932513646686672, 0.19650054461938235`], 
             310 -> RGBColor[0.817319, 0.134127, 0.164218], 171 -> 
             RGBColor[
              0.9553966243175557, 0.8608695091526162, 0.28296928083135936`], 
             395 -> RGBColor[
              0.9159682611686081, 0.7045491879901851, 0.25124429433908335`], 
             311 -> 
             RGBColor[
              0.22655758961928207`, 0.35545676964367157`, 0.9362134916156754],
              353 -> RGBColor[
              0.1865974340180864, 0.31345611248661487`, 0.9339378198699398], 
             59 -> RGBColor[
              0.6025610453058137, 0.6882252275018321, 0.961854959221762], 397 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 229 -> 
             RGBColor[
              0.4323931062930283, 0.5489389087867588, 0.9487726842761488], 
             102 -> RGBColor[
              0.26729718777158684`, 0.39827667034145603`, 0.9385335514616145],
              453 -> RGBColor[
              0.45788186350371485`, 0.5707681499920235, 0.9504652840529954], 
             299 -> RGBColor[
              0.4587788150425182, 0.5714963356584305, 0.9505358953637717], 
             128 -> RGBColor[
              0.24495698094472051`, 0.3747956965154964, 0.9372613097321988], 
             12 -> RGBColor[
              0.2440062290021841, 0.3737963959427358, 0.9372071658155828], 
             222 -> RGBColor[
              0.2572169453532387, 0.3876816964354887, 0.9379594965682719], 
             483 -> RGBColor[
              0.9714214766675533, 0.9152600716225856, 0.3434782627650753], 92 -> 
             RGBColor[
              0.6576732634723652, 0.7324986190173249, 0.9665143826629965], 
             271 -> RGBColor[
              0.3045714380557589, 0.43745427071408804`, 0.9406562648729865], 
             361 -> RGBColor[
              0.4096552744186712, 0.5292445416538502, 0.94732384973539], 344 -> 
             RGBColor[
              0.2278120755134005, 0.35677531385738964`, 0.9362849327314998], 
             132 -> RGBColor[
              0.6598859337650126, 0.7342271738668581, 0.966734920959188], 80 -> 
             RGBColor[
              0.9579895862140718, 0.9681892827009697, 0.9559968518555605], 
             324 -> RGBColor[0.817319, 0.134127, 0.164218], 244 -> 
             RGBColor[
              0.977212423501673, 0.9347942950730491, 0.3659749976870823], 150 -> 
             RGBColor[
              0.3389460376431222, 0.4679997547084456, 0.942818319693775], 125 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 258 -> 
             RGBColor[
              0.9939516779922013, 0.9894715757415058, 0.5830556592468749], 
             133 -> RGBColor[
              0.2610002522409667, 0.3916581918500021, 0.9381749502986271], 
             469 -> RGBColor[
              0.1893750053770723, 0.3163755160931047, 0.9340959984497854], 
             255 -> RGBColor[
              0.25751049402968956`, 0.3879902347064996, 0.9379762137311295], 
             408 -> RGBColor[0.817319, 0.134127, 0.164218], 326 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 176 -> 
             RGBColor[
              0.8837943025257868, 0.9101776031495423, 0.9887782836190391], 
             230 -> RGBColor[
              0.29510601197456354`, 0.4275055077600755, 0.9401172228605054], 
             274 -> RGBColor[
              0.48393777173830865`, 0.5919215101021562, 0.9525165005951594], 
             87 -> RGBColor[
              0.854284899814332, 0.8866476064388262, 0.9859636504450657], 439 -> 
             RGBColor[
              0.2663834741236062, 0.397316299364637, 0.9384815168210803], 130 -> 
             RGBColor[
              0.8331937393088721, 0.8698300875560732, 0.9839519567277537], 35 -> 
             RGBColor[
              0.21649762081927568`, 0.34488310459600313`, 0.9356405912749051],
              379 -> RGBColor[0.817319, 0.134127, 0.164218], 31 -> 
             RGBColor[
              0.23515707303258868`, 0.3644953719497967, 0.9367032194742675], 
             18 -> RGBColor[
              0.7541788838097023, 0.8078895430947328, 0.9761331610019253], 24 -> 
             RGBColor[
              0.20633904470983166`, 0.3342057970140512, 0.9350620753937389], 
             151 -> RGBColor[
              0.28569344941384495`, 0.4176123077178249, 0.9395811913473109], 
             137 -> RGBColor[
              0.3211744864498682, 0.45260693028898363`, 0.9416859321665065], 
             330 -> RGBColor[
              0.22481780914373545`, 0.3536281500554188, 0.9361144136913675], 
             296 -> RGBColor[
              0.19315143637710094`, 0.3203447845136896, 0.9343110606085081], 
             266 -> RGBColor[0.817319, 0.134127, 0.164218], 302 -> 
             RGBColor[
              0.48818097544843886`, 0.5953663340281886, 0.9528505411345881], 
             442 -> RGBColor[
              0.44708899097258314`, 0.5616677454595485, 0.9497090930528694], 
             283 -> RGBColor[
              0.19353123231110916`, 0.32074397412078526`, 0.9343326894250921],
              388 -> RGBColor[
              0.9243202823709581, 0.9424919194296639, 0.9926436877546408], 
             284 -> RGBColor[
              0.29911991378268726`, 0.43172437305648714`, 0.9403458086304425],
              417 -> RGBColor[
              0.25734139130129635`, 0.3878124970172262, 0.9379665835809126], 
             318 -> RGBColor[
              0.2610014285656661, 0.39165942824184447`, 0.9381750172885784], 
             413 -> 
             RGBColor[
              0.4106589580798899, 0.5301138819945902, 0.9473878035707602], 
             238 -> RGBColor[
              0.936541673425211, 0.7861159119043911, 0.2677981447607987], 72 -> 
             RGBColor[
              0.3185855666826758, 0.4503645381095326, 0.941520968488233], 437 -> 
             RGBColor[
              0.19181759620694716`, 0.3189428339245066, 0.9342351003840575], 
             288 -> RGBColor[0.817319, 0.134127, 0.164218], 382 -> 
             RGBColor[
              0.3231603966004548, 0.4543270258466754, 0.9418124726052306], 
             461 -> RGBColor[
              0.5415651525659718, 0.6387060139419746, 0.9570531391099645], 
             389 -> RGBColor[
              0.24782292745212858`, 0.377807988006286, 0.9374245211460078], 
             172 -> RGBColor[
              0.37795345536951325`, 0.5017860193732245, 0.9453038378583956], 
             447 -> RGBColor[
              0.4270628245166249, 0.5443220866197901, 0.9484330434347394], 
             243 -> RGBColor[
              0.2549643465593099, 0.385314072280057, 0.937831214399379], 410 -> 
             RGBColor[
              0.19323299612210112`, 0.3204305089768713, 0.934315705315329], 
             88 -> RGBColor[
              0.22472424201089944`, 0.35352980506630927`, 0.9361090851815727],
              273 -> RGBColor[
              0.21438528258518844`, 0.34266290318199794`, 0.9355202967373982],
              477 -> RGBColor[
              0.26019557655375813`, 0.3908124266833606, 0.9381291252086515], 
             202 -> RGBColor[
              0.21266853360939608`, 0.34085849116026834`, 0.9354225304229293],
              393 -> RGBColor[
              0.36751400675687457`, 0.4927438936869005, 0.9446386454240401], 
             98 -> RGBColor[
              0.21930919416960923`, 0.3478382464512501, 0.9358007062178566], 
             30 -> RGBColor[
              0.1789570524953891, 0.3054255870780922, 0.9335027114451537], 
             116 -> RGBColor[
              0.6844298372258936, 0.7534010577910736, 0.9691812278803502], 
             373 -> RGBColor[0.817319, 0.134127, 0.164218], 434 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 401 -> 
             RGBColor[
              0.18668189134142482`, 0.3135448824883471, 0.9339426295895605], 
             240 -> RGBColor[0.817319, 0.134127, 0.164218], 480 -> 
             RGBColor[
              0.47940132385552714`, 0.5882386173462659, 0.9521593748002706], 
             403 -> RGBColor[0.817319, 0.134127, 0.164218], 317 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 429 -> 
             RGBColor[
              0.23501975925948257`, 0.36435104646806615`, 0.9366953996580266],
              391 -> RGBColor[
              0.9525439023720605, 0.8495594172519633, 0.28067391379202367`], 
             73 -> RGBColor[
              0.8407007288961474, 0.31384921423472306`, 0.18660836999683647`],
              303 -> RGBColor[0.817319, 0.134127, 0.164218], 449 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 29 -> 
             RGBColor[
              0.20262840066914578`, 0.3303056748588697, 0.9348507597050277], 
             360 -> RGBColor[
              0.8226648881293261, 0.1752178387451157, 0.16933722850995975`], 
             320 -> RGBColor[
              0.18845275152117702`, 0.31540616881628697`, 0.9340434774570445],
              482 -> RGBColor[
              0.9362533521083286, 0.9519784348947232, 0.9927906264787851], 75 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 200 -> 
             RGBColor[
              0.6024325749506131, 0.6881209294799567, 0.9618448455647982], 
             301 -> RGBColor[0.817319, 0.134127, 0.164218], 156 -> 
             RGBColor[
              0.26709219000597495`, 0.39806120469218886`, 0.93852187714213], 
             25 -> RGBColor[
              0.7576060273863839, 0.8105668537040923, 0.9764747466451712], 38 -> 
             RGBColor[
              0.8992999083697804, 0.6356262276586594, 0.23768571396967728`], 
             365 -> RGBColor[
              0.30003965645411895`, 0.4326910809192154, 0.9403981866149431], 
             380 -> RGBColor[
              0.2157216182949494, 0.34406747674153443`, 0.9355963990791376], 
             370 -> RGBColor[
              0.4032230834287326, 0.5236733011096846, 0.9469139962132742], 3 -> 
             RGBColor[
              0.19930844041135132`, 0.32681618613028957`, 0.9346616928797874],
              57 -> RGBColor[0.817319, 0.134127, 0.164218], 227 -> 
             RGBColor[
              0.24023088414070523`, 0.3698282691226319, 0.9369921655108439], 
             494 -> RGBColor[
              0.9693843335785163, 0.976687466628186, 0.9367085167936384], 39 -> 
             RGBColor[
              0.5059330480764017, 0.6097782663093272, 0.954248049319846], 424 -> 
             RGBColor[
              0.2415788936308724, 0.37124511256553566`, 0.9370689326571076], 
             109 -> RGBColor[
              0.33067337344239356`, 0.46083438877396704`, 0.9422911928461343],
              465 -> RGBColor[
              0.1794538714957133, 0.3059477753475769, 0.9335310045522444], 
             256 -> RGBColor[
              0.8652595816135205, 0.8953985198056976, 0.9870104253922865], 
             457 -> RGBColor[
              0.9567649542169475, 0.8658201798815686, 0.2865404406964947], 
             339 -> RGBColor[
              0.18435110707541025`, 0.31109508044450795`, 0.9338098948736974],
              420 -> RGBColor[
              0.21820107858971777`, 0.3466735467181985, 0.9357376006748919], 
             287 -> RGBColor[
              0.8379345637063845, 0.8736102922443995, 0.9844041407909724], 
             239 -> RGBColor[
              0.25524447055801713`, 0.38560850036358557`, 0.937847167046699], 
             427 -> RGBColor[
              0.2116086394211203, 0.33974447516721756`, 0.93536217101688], 
             285 -> RGBColor[
              0.3342797596203076, 0.46395805921903643`, 0.9425209885843889], 
             345 -> RGBColor[
              0.2302467671760705, 0.35933432916322317`, 0.9364235848198853], 
             366 -> RGBColor[
              0.19456249333096626`, 0.3218278948383802, 0.9343914182145591], 
             216 -> RGBColor[
              0.2693332332275772, 0.4004166832084398, 0.938649501238274], 21 -> 
             RGBColor[
              0.8219966379615026, 0.8609018228788999, 0.9828839672054712], 
             355 -> RGBColor[
              0.8567924356784412, 0.43753712399430794`, 0.2020178065845444], 
             175 -> RGBColor[
              0.9948073015950193, 0.9921207000103479, 0.7357199810506223], 7 -> 
             RGBColor[
              0.9534406635465423, 0.8531147764808367, 0.28139546888270184`], 
             13 -> RGBColor[
              0.5395182465349754, 0.6370442434139459, 0.9568919991691406], 
             294 -> RGBColor[
              0.2158208370998732, 0.3441717619963449, 0.935602049443297], 412 -> 
             RGBColor[
              0.2277251794483852, 0.35668398058352985`, 0.9362799841291484], 
             193 -> RGBColor[
              0.18752850541486277`, 0.314434727557963, 0.9339908430085895], 
             60 -> RGBColor[0.817319, 0.134127, 0.164218], 65 -> 
             RGBColor[
              0.1972436349934338, 0.32464594471983343`, 0.9345441052658429], 
             448 -> RGBColor[
              0.8242283061574975, 0.8626812945213669, 0.9830968257102389], 69 -> 
             RGBColor[
              0.9814207743108861, 0.9489900505202847, 0.382323645900509], 217 -> 
             RGBColor[
              0.18890068939112134`, 0.3158769799184998, 0.9340689868560732], 
             214 -> 
             RGBColor[
              0.21604971918074886`, 0.3444123315753073, 0.9356150839392021], 
             170 -> RGBColor[
              0.21686761525785075`, 0.3452719922099478, 0.9356616619108242], 
             359 -> RGBColor[0.817319, 0.134127, 0.164218], 74 -> 
             RGBColor[
              0.22105372540225315`, 0.34967185938642753`, 0.935900054690753], 
             246 -> RGBColor[
              0.4576850364535088, 0.5706083569257087, 0.9504497891066018], 
             264 -> RGBColor[0.817319, 0.134127, 0.164218], 278 -> 
             RGBColor[
              0.2027780029210282, 0.3304629163109287, 0.9348592793319558], 45 -> 
             RGBColor[
              0.27477024647677334`, 0.40613132885989545`, 0.9389591310994754],
              492 -> RGBColor[
              0.19478601411047772`, 0.3220628293496827, 0.9344041473922828], 
             306 -> RGBColor[
              0.4631485198395302, 0.5750438588656026, 0.9508798945321485], 
             237 -> RGBColor[
              0.4230361383836957, 0.5408343734785764, 0.9481764665550079], 
             228 -> RGBColor[
              0.5725831029202398, 0.6638877833823089, 0.9594949857843484], 
             180 -> RGBColor[
              0.6034964487201209, 0.6889846301330103, 0.9619285976050319], 
             383 -> RGBColor[
              0.6325346241150686, 0.7125591290735227, 0.9642145891424635], 53 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 304 -> 
             RGBColor[
              0.22967809360797173`, 0.35873661718716465`, 0.9363911997014592],
              48 -> RGBColor[
              0.22612030793820787`, 0.35499715887160266`, 0.9361885890708385],
              5 -> RGBColor[0.817319, 0.134127, 0.164218], 101 -> 
             RGBColor[
              0.49037845718069295`, 0.5971503486938564, 0.953023534946192], 
             333 -> RGBColor[
              0.4177501378450422, 0.536255905494107, 0.9478396472749117], 267 -> 
             RGBColor[
              0.4056075310905943, 0.525738589828565, 0.9470659311098037], 120 -> 
             RGBColor[
              0.18313418987661276`, 0.309816023311565, 0.9337405932394934], 
             147 -> RGBColor[0.817319, 0.134127, 0.164218], 89 -> 
             RGBColor[
              0.8587915518062159, 0.890241088407345, 0.9863934989351874], 43 -> 
             RGBColor[
              0.40134636687536374`, 0.5220477835576731, 0.9467944134940088], 
             199 -> RGBColor[
              0.9909931722195693, 0.9905434594949455, 0.7989299754522408], 
             268 -> 
             RGBColor[
              0.2106927321879748, 0.33878179859330904`, 0.9353100114549157], 
             169 -> RGBColor[
              0.19997089892350478`, 0.32751247202885847`, 0.934699418912035], 
             20 -> RGBColor[
              0.46934274654192526`, 0.5800726111493398, 0.9513675267483611], 
             4 -> RGBColor[
              0.19006206717459462`, 0.3170976616045347, 0.9341351256027375], 
             167 -> RGBColor[
              0.4574599131251553, 0.570425591666061, 0.95043206657354], 431 -> 
             RGBColor[
              0.9934489814254173, 0.9883963586155741, 0.5283402402360341], 
             142 -> RGBColor[
              0.340635459799505, 0.4694630472674779, 0.9429259681796823], 16 -> 
             RGBColor[
              0.6469324131931254, 0.7241077851456973, 0.9654438350861145], 
             414 -> RGBColor[
              0.9933318523271546, 0.9881458313179586, 0.5155914607271469], 
             281 -> RGBColor[0.817319, 0.134127, 0.164218], 289 -> 
             RGBColor[
              0.31358168594229274`, 0.44603042811457155`, 0.9412021256322137],
              398 -> RGBColor[
              0.29666018860098814`, 0.42913904593493735`, 0.940205730920182], 
             178 -> RGBColor[
              0.9567165072169457, 0.8656567567746658, 0.2863522332499358], 58 -> 
             RGBColor[
              0.240267978136988, 0.3698672572646202, 0.9369942779590565], 186 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 122 -> 
             RGBColor[
              0.2080093336373953, 0.3359613765793552, 0.9351571958771926], 
             249 -> RGBColor[0.817319, 0.134127, 0.164218], 113 -> 
             RGBColor[
              0.25555645648574987`, 0.385936417354683, 0.9378649341837416], 
             52 -> RGBColor[
              0.18352693138300546`, 0.3102288195360335, 0.9337629592872735], 
             409 -> RGBColor[
              0.5413266543134985, 0.638512390316393, 0.9570343636538818], 187 -> 
             RGBColor[
              0.36718010963697145`, 0.4924546887837977, 0.9446173697948136], 
             259 -> RGBColor[0.817319, 0.134127, 0.164218], 42 -> 
             RGBColor[
              0.2720687261283602, 0.40329185968743014`, 0.9388052835121744], 
             134 -> RGBColor[
              0.2013445076269774, 0.3289562218680302, 0.9347776438956258], 
             470 -> RGBColor[
              0.24649818947394458`, 0.37641560439797556`, 0.9373490792779244],
              313 -> RGBColor[
              0.9779347509559622, 0.9830643539082616, 0.9222348904796338], 
             248 -> 
             RGBColor[
              0.18472467114451377`, 0.31148771996646574`, 0.9338311687947942],
              174 -> RGBColor[
              0.215756853533542, 0.3441045112113384, 0.9355984056738496], 215 -> 
             RGBColor[
              0.20492571704741236`, 0.3327203000306991, 0.934981588474195], 
             399 -> RGBColor[
              0.30363758949702413`, 0.4364727366694393, 0.9406030835790716], 
             422 -> RGBColor[
              0.29787052949847936`, 0.4304111909582458, 0.9402746580437552], 
             83 -> RGBColor[0.817319, 0.134127, 0.164218], 95 -> 
             RGBColor[
              0.20371097625405837`, 0.3314435304378693, 0.9349124107830614], 
             166 -> RGBColor[
              0.25109817118593475`, 0.381250476832963, 0.9376110414313592], 
             384 -> RGBColor[
              0.6344197195047021, 0.7140895344334067, 0.9643629907568674], 
             233 -> RGBColor[0.817319, 0.134127, 0.164218], 295 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 499 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 141 -> 
             RGBColor[
              0.3011825170683711, 0.43389229988634254`, 0.9404632708362141], 
             319 -> RGBColor[
              0.18726572239046815`, 0.31415852593791815`, 0.9339758779041029],
              205 -> RGBColor[
              0.4450599520442159, 0.5599102939222584, 0.9495798044865625], 
             468 -> RGBColor[
              0.36840454856349925`, 0.4935152362398662, 0.9446953899604831], 
             486 -> RGBColor[
              0.9941045402798871, 0.9897985327181177, 0.5996937759047933], 
             224 -> RGBColor[
              0.295260889517734, 0.42766829387775107`, 0.9401260429074682], 
             231 -> RGBColor[0.817319, 0.134127, 0.164218], 332 -> 
             RGBColor[
              0.2120977707203083, 0.34025858317537977`, 0.9353900263207638], 
             68 -> RGBColor[
              0.20692796280704617`, 0.3348247872737876, 0.935095613408149], 
             484 -> RGBColor[
              0.20427604235269314`, 0.3320374507347944, 0.9349445904614383], 
             10 -> RGBColor[
              0.3937584149506567, 0.5154754809820448, 0.946310915907129], 250 -> 
             RGBColor[
              0.3594825143186384, 0.4857874186114477, 0.9441268858278457], 
             282 -> RGBColor[0.817319, 0.134127, 0.164218], 374 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 232 -> 
             RGBColor[
              0.6961033750146681, 0.7625205142338375, 0.9703447370317223], 
             489 -> 
             RGBColor[
              0.2336066799286998, 0.3628658104970091, 0.9366149268806021], 
             253 -> RGBColor[
              0.9881377044358732, 0.9893626501842123, 0.8462524663418269], 
             459 -> RGBColor[
              0.24592141072655926`, 0.37580937336458886`, 0.9373162325815285],
              415 -> RGBColor[
              0.1852681323985655, 0.3120589322019077, 0.9338621181092336], 55 -> 
             RGBColor[
              0.8437950041640877, 0.3376331698641804, 0.18957145148790017`], 
             446 -> RGBColor[
              0.1982250439704274, 0.32567746777957673`, 0.9345999950552182], 
             325 -> RGBColor[
              0.4266116652397737, 0.5439313151301061, 0.948404295964563], 91 -> 
             RGBColor[
              0.9641975980982375, 0.8908922329609346, 0.3154148586382841], 
             450 -> RGBColor[
              0.33974255441645423`, 0.4686896575034088, 0.9428690730382396], 
             423 -> RGBColor[
              0.18010256657334342`, 0.3066295950038096, 0.9335679467772571], 
             105 -> RGBColor[
              0.23276328462783158`, 0.36197934856144603`, 0.9365668967659092],
              36 -> RGBColor[0.817319, 0.134127, 0.164218], 123 -> 
             RGBColor[
              0.20873262495813816`, 0.3367216016167744, 0.9351983862478953], 
             94 -> RGBColor[0.178927, 0.305394, 0.933501], 473 -> 
             RGBColor[
              0.6063118000163332, 0.691270259145406, 0.9621502323720413], 312 -> 
             RGBColor[
              0.24802738733723106`, 0.37802288830903413`, 0.9374361648339931],
              96 -> RGBColor[
              0.9553028976633565, 0.8604979142012724, 0.28289386616534334`], 
             496 -> RGBColor[
              0.2085981516455076, 0.3365802616390992, 0.9351907281916764], 2 -> 
             RGBColor[
              0.20161671018842872`, 0.32924232401875475`, 0.9347931454288129],
              262 -> RGBColor[
              0.9518509475754381, 0.963611096055375, 0.9663879658573935], 272 -> 
             RGBColor[
              0.5663742859676012, 0.6588471860761407, 0.9590062049701908], 97 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 372 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 356 -> 
             RGBColor[
              0.49166457190272544`, 0.5981944745640103, 0.9531247826083038], 
             402 -> RGBColor[
              0.35222766772351993`, 0.4795036351299483, 0.9436646134180137], 
             455 -> RGBColor[0.817319, 0.134127, 0.164218], 428 -> 
             RGBColor[
              0.2170356376005423, 0.34544859434534847`, 0.9356712305346737], 
             346 -> RGBColor[
              0.9829894651638862, 0.9542816131135821, 0.3884177136420036], 
             341 -> RGBColor[0.817319, 0.134127, 0.164218], 209 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 498 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 378 -> 
             RGBColor[
              0.2996969855238355, 0.4323309120448956, 0.9403786720123997], 
             419 -> RGBColor[0.817319, 0.134127, 0.164218], 66 -> 
             RGBColor[
              0.2605769831148301, 0.3912133091616199, 0.9381508457480642], 
             139 -> RGBColor[
              0.19474583817336233`, 0.32202060189247295`, 0.9344018594320991],
              56 -> RGBColor[
              0.9946416792371043, 0.9909474186345262, 0.6581580365604908], 
             335 -> RGBColor[
              0.3150309137810037, 0.44728567642815387`, 0.9412944691485945], 
             314 -> RGBColor[
              0.6013820686751921, 0.6872680811608015, 0.9617621458626657], 
             144 -> RGBColor[
              0.2562538810668797, 0.3866694548087229, 0.9379046514818897], 
             298 -> RGBColor[
              0.6797711867345639, 0.7497616846201918, 0.9687168971369385], 
             204 -> RGBColor[
              0.8802420747951332, 0.9073451531797723, 0.9884394689669782], 
             452 -> RGBColor[
              0.3938614602073101, 0.5155647336041528, 0.9463174818597636], 
             466 -> RGBColor[
              0.2476714334157858, 0.37764875816881305`, 0.9374158937847534], 
             207 -> RGBColor[0.817319, 0.134127, 0.164218], 334 -> 
             RGBColor[
              0.2130775983694969, 0.3412884441593381, 0.93544582605586], 149 -> 
             RGBColor[
              0.8554632653203876, 0.4273205381761434, 0.2007449915485891], 
             219 -> RGBColor[0.817319, 0.134127, 0.164218], 400 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 9 -> 
             RGBColor[
              0.242957706247003, 0.37269433204685803`, 0.9371474539958257], 
             11 -> RGBColor[
              0.9875036737064178, 0.989100462183736, 0.8567599963478333], 44 -> 
             RGBColor[
              0.6993501336328052, 0.7650569067426056, 0.970668343588094], 153 -> 
             RGBColor[
              0.3978373772063899, 0.5190084730733568, 0.9465708237751796], 
             471 -> RGBColor[0.817319, 0.134127, 0.164218], 406 -> 
             RGBColor[
              0.9938422671704169, 0.9892375570568399, 0.5711469665009675], 32 -> 
             RGBColor[
              0.3596303768180513, 0.4859154896766539, 0.9441363074955585], 
             162 -> RGBColor[
              0.19787594539539122`, 0.32531054304308565`, 0.934580114407815], 
             493 -> RGBColor[
              0.5894436674267205, 0.677575949208445, 0.9608223111845814], 90 -> 
             RGBColor[
              0.5985155306782874, 0.6849408964788493, 0.9615364814910747], 
             331 -> RGBColor[
              0.8274945099942945, 0.8652856768020875, 0.9834083591479672], 8 -> 
             RGBColor[
              0.2588724192803225, 0.3894217044959632, 0.9380537733593651], 
             364 -> RGBColor[
              0.28861702790878196`, 0.42068517408158657`, 0.9397476848175508],
              342 -> RGBColor[
              0.9487736339623114, 0.8346115593747768, 0.2776402673299655], 
             163 -> RGBColor[0.817319, 0.134127, 0.164218], 49 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 338 -> 
             RGBColor[
              0.993193928488921, 0.9878508261742159, 0.5005793021026774], 76 -> 
             RGBColor[
              0.9943451951306927, 0.9903132691100532, 0.6258875712654035], 
             369 -> RGBColor[
              0.19227972218525266`, 0.31942855762818506`, 0.9342614177748679],
              445 -> RGBColor[0.817319, 0.134127, 0.164218], 82 -> 
             RGBColor[
              0.8979401714022621, 0.6294519796637963, 0.23655111611377708`], 
             67 -> RGBColor[
              0.18730821452687368`, 0.3142031878674374, 0.9339782977684097], 
             430 -> RGBColor[
              0.2764022607353688, 0.40784667932135976`, 0.9390520718971536], 
             211 -> RGBColor[
              0.21578236892213723`, 0.34413132950252107`, 
               0.9355998587374834]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw1l3k4VA/cxYfs69jHPjOGGTNjV1rUPZUi6hcVbZKtXVmyRook2RJlqUih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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 42}], {
             RGBColor[
             0.26932784147908145`, 0.4004110161389142, 0.9386491941861734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 108}], {
             RGBColor[
             0.2889826050783411, 0.42082604906062115`, 0.9397774148572755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[
             0.2610717066577763, 0.3917332949725406, 0.938179019521957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 119}], {
             RGBColor[
             0.2343699623005295, 0.3636680686646997, 0.9366583946825027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 120}], {
             RGBColor[
             0.22486057335320775`, 0.3536730979509817, 0.9361168490498329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 124}], {
             RGBColor[
             0.2366309542553628, 0.3660445145643992, 0.9367871548294926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 315}], {
             RGBColor[
             0.23241208756362647`, 0.36161021817978645`, 0.9365468966126522]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 363}], {
             RGBColor[
             0.23069669163243806`, 0.3598072282937236, 0.9364492073520718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 364}], {
             RGBColor[
             0.27760199236929234`, 0.4091076733359924, 0.9391203948388616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 378}], {
             RGBColor[
             0.2831419711768191, 0.4149305423176469, 0.9394358884362861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 380}], {
             RGBColor[
             0.24115428756237606`, 0.37079882466596636`, 0.937044751969655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 381}], {
             RGBColor[
             0.24294210956451456`, 0.3726779389446759, 0.9371465657878312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 416}], {
             RGBColor[
             0.288059981339665, 0.42002691875059733`, 0.9397186260884912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 452}], {
             RGBColor[
             0.3302242085185564, 0.4565474530972755, 0.942405293359968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 468}], {
             RGBColor[
             0.317495752696651, 0.44552270441513225`, 0.9415942474103278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 487}], {
             RGBColor[
             0.25250692027805216`, 0.38273116144862973`, 0.9376912676080977]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[
             0.23109684665162938`, 0.3602278165901873, 0.9364719955884385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 114}], {
             RGBColor[
             0.19567198478119446`, 0.322994040698391, 0.934454602111304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 118}], {
             RGBColor[
             0.2188823691598405, 0.3473896263037145, 0.9357763991649812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 195}], {
             RGBColor[
             0.2100171428775559, 0.33807171139322245`, 0.9352715376431322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 255}], {
             RGBColor[
             0.22956360210905913`, 0.3586162793626272, 0.9363846795799712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 260}], {
             RGBColor[
             0.2568264909268206, 0.3869670959806497, 0.9379483993149236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 312}], {
             RGBColor[
             0.2248220487628299, 0.35363260616389447`, 0.936114655131403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 327}], {
             RGBColor[
             0.20072221719940941`, 0.3283021551731643, 0.934742205376372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 334}], {
             RGBColor[
             0.20734715427896283`, 0.33526538408904644`, 0.9351194857423364]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 385}], {
             RGBColor[
             0.19593294950729245`, 0.32326833117163933`, 0.9344694636663926]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 446}], {
             RGBColor[
             0.19992087707942807`, 0.32745989589916574`, 0.9346965702420156]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 496}], {
             RGBColor[
             0.20510743091696815`, 0.33291129282892695`, 0.9349919368102446]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[
             0.20402053268474474`, 0.331768893873532, 0.9349300395638414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 139}], {
             RGBColor[
             0.19702713929235682`, 0.3244183940113813, 0.9345317761559433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 158}], {
             RGBColor[
             0.2166432544871289, 0.3450361748146247, 0.9356488848968436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 247}], {
             RGBColor[
             0.2006452395594779, 0.32822124679293196`, 0.9347378216136562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 278}], {
             RGBColor[
             0.20104322166618976`, 0.32863955122060917`, 0.9347604861058716]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 401}], {
             RGBColor[
             0.19299516587638807`, 0.32018053430931837`, 0.934302161234674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 428}], {
             RGBColor[
             0.20817203900594683`, 0.33613239023781905`, 0.9351664617072306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 437}], {
             RGBColor[
             0.19556301830914924`, 0.3228795100273981, 0.9344483966319225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 451}], {
             RGBColor[
             0.24545922641333842`, 0.37532358834721574`, 0.9372899118686311]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 31}], {
             RGBColor[
             0.21260957010359166`, 0.3407965167771657, 0.9354191725385025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 151}], {
             RGBColor[
             0.23787775829421978`, 0.3673549846611798, 0.9368581584750242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 162}], {
             RGBColor[
             0.19396900628499292`, 0.32120410232381014`, 0.9343576200052762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 191}], {
             RGBColor[
             0.20962796174465825`, 0.33766265734703804`, 0.9352493743533555]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.201838009483021, 0.3294749236085569, 0.9348057480962568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 345}], {
             RGBColor[
             0.21015441717533256`, 0.3382159953838789, 0.9352793552113114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 366}], {
             RGBColor[
             0.19231228025278044`, 0.3194627782214574, 0.9342632719086483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 389}], {
             RGBColor[
             0.2189424973133616, 0.34745282480541034`, 0.9357798233743726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 405}], {
             RGBColor[
             0.19037905734984562`, 0.31743083837706143`, 0.9341531777242731]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 429}], {
             RGBColor[
             0.2125409132170386, 0.3407243540363004, 0.935415262630382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 472}], {
             RGBColor[
             0.19355933557756982`, 0.3207735124356854, 0.9343342898645419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 488}], {
             RGBColor[
             0.1922517191621101, 0.319399124675368, 0.9342598230441267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 69}], {
             RGBColor[
             0.8720195914369621, 0.40574801684009487`, 0.23691988196683633`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 97}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 103}], {
             RGBColor[
             0.8763449551304583, 0.41955926219099576`, 0.3199825200895846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 129}], {
             RGBColor[
             0.7983595285409613, 0.3603450773806288, 0.4350644229732442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 163}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 204}], {
             RGBColor[
             0.8382933582650444, 0.3918663843932574, 0.4389584896556594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 209}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 231}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 233}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 259}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 275}], {
             RGBColor[
             0.8560290549644465, 0.34736971536429956`, 0.19791527993518332`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 326}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 346}], {
             RGBColor[
             0.8725424883879621, 0.4075118710378607, 0.23895123788066785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 348}], {
             RGBColor[
             0.8657911144896757, 0.38473790158096455`, 0.21272342517580606`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 355}], {
             RGBColor[
             0.8304768118928137, 0.23526370799810264`, 0.17681793552818148`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 395}], {
             RGBColor[
             0.8502020870562027, 0.32426772933006165`, 0.19322676477969444`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 404}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 431}], {
             RGBColor[
             0.8760289938084724, 0.418883452871858, 0.28559208007867803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 444}], {
             RGBColor[
             0.8285562969045, 0.22050178822288907`, 0.17497884820646079`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 486}], {
             RGBColor[
             0.8762475134266291, 0.4193508442393725, 0.30937659196826445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 35}], {
             RGBColor[
             0.2754047152813548, 0.4044344620104028, 0.9390818110323994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 101}], {
             RGBColor[
             0.4123451334620635, 0.5305680840593294, 0.9477732828680429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 123}], {
             RGBColor[
             0.2715222173507861, 0.4003537105207884, 0.9388607085188945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 158}], {
             RGBColor[
             0.2841449391531702, 0.41362099146188114`, 0.9395795538518968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 181}], {
             RGBColor[
             0.36099048155066216`, 0.4870935440351898, 0.9442229721664271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 189}], {
             RGBColor[
             0.4338625957179959, 0.5480369292693235, 0.9494672163178912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 302}], {
             RGBColor[
             0.4112463925959364, 0.5296760767264955, 0.9476867859622409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 306}], {
             RGBColor[
             0.39873016479148204`, 0.5195148391452025, 0.9467014626610211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 347}], {
             RGBColor[
             0.3086318125417763, 0.4393582479507504, 0.9409740450662951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 370}], {
             RGBColor[
             0.3687674465860833, 0.4938295602672435, 0.944718513501584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 390}], {
             RGBColor[
             0.44622497203026434`, 0.5580732632783292, 0.9504404278660695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 422}], {
             RGBColor[
             0.3160911696209566, 0.44719850519152415`, 0.9413988444168244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 428}], {
             RGBColor[
             0.2756737236719881, 0.40471720688507545`, 0.9390971306622837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 451}], {
             RGBColor[
             0.31296091107937973`, 0.44390840499447215`, 0.9412205808236842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 17}], {
             RGBColor[
             0.970450660992768, 0.9210987253730254, 0.5694341697658482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.8626928878488475, 0.3737895921602789, 0.20327715629423396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.8626928878488475, 0.3737895921602789, 0.20327715629423396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.8160959914872512, 0.8010398665049154, 0.62500535758886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 89}], {
             RGBColor[
             0.9061161076763791, 0.8716779324440909, 0.6338944839089447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 176}], {
             RGBColor[
             0.9186174830361646, 0.8816461898151895, 0.6350868762508705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 178}], {
             RGBColor[
             0.9550785853817441, 0.8593857666277512, 0.2838738510663188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 244}], {
             RGBColor[
             0.9653265435241076, 0.893954535776943, 0.32368523328489207`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 261}], {
             RGBColor[
             0.9399230799294223, 0.8986346944528518, 0.6371190231022803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 262}], {
             RGBColor[
             0.9526458055609902, 0.9083629362681058, 0.6238917173700477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 288}], {
             RGBColor[
             0.8626928878488475, 0.3737895921602789, 0.20327715629423396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 295}], {
             RGBColor[
             0.8626928878488475, 0.3737895921602789, 0.20327715629423396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 313}], {
             RGBColor[
             0.9656877072512522, 0.9180895651945491, 0.6018151796811678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 321}], {
             RGBColor[
             0.8626928878488475, 0.3737895921602789, 0.20327715629423396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 341}], {
             RGBColor[
             0.8626928878488475, 0.3737895921602789, 0.20327715629423396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 376}], {
             RGBColor[
             0.9697345365090141, 0.9208025894954335, 0.5813022057324062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 391}], {
             RGBColor[
             0.9529922829593014, 0.8513370968664, 0.28103469133736275`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 407}], {
             RGBColor[
             0.8208526148202658, 0.8047557768043427, 0.6254794533495226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 448}], {
             RGBColor[
             0.88883448485202, 0.8578980355011018, 0.6322461472964704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 455}], {
             RGBColor[
             0.8626928878488475, 0.3737895921602789, 0.20327715629423396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 475}], {
             RGBColor[
             0.9478498229277461, 0.9047861002729332, 0.6320100649755263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 478}], {
             RGBColor[
             0.7350898192819142, 0.7358328905411176, 0.6182471001773744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 482}], {
             RGBColor[
             0.9448470078274355, 0.90254660568778, 0.6370930476807435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 63}], {
             RGBColor[
             0.27895516343135685`, 0.4105299419182229, 0.939197455929009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 85}], {
             RGBColor[
             0.23686771917621463`, 0.36629336950797753`, 0.9368006382414729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 146}], {
             RGBColor[
             0.22136813052518187`, 0.35000231910506174`, 0.935917959597383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 159}], {
             RGBColor[
             0.3390979651454099, 0.46352019337297634`, 0.9429968372905502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 166}], {
             RGBColor[
             0.25498529523312863`, 0.38533609066446306`, 0.9378324073953621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 239}], {
             RGBColor[
             0.25705844491916985`, 0.3875151024297744, 0.9379504702030321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 344}], {
             RGBColor[
             0.2433422473968615, 0.3730985091766764, 0.9371693530454325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 387}], {
             RGBColor[
             0.24035919758229748`, 0.3699631346852874, 0.9369994727715198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 435}], {
             RGBColor[
             0.3541661224083213, 0.47657147384650533`, 0.9439569669470946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 439}], {
             RGBColor[
             0.2626279467019643, 0.3933690019303001, 0.9382676450902228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 453}], {
             RGBColor[
             0.3583771413920187, 0.4800949272439934, 0.9442595287061802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 68}], {
             RGBColor[
             0.22494283452702457`, 0.3537595596603228, 0.9361215337019873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 95}], {
             RGBColor[
             0.2233343412505307, 0.35206893124236366`, 0.9360299323894435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 286}], {
             RGBColor[
             0.229182169797179, 0.3582153698186358, 0.9363629575740882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 319}], {
             RGBColor[
             0.21511171431873558`, 0.34342642899238807`, 0.9355616659499643]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 330}], {
             RGBColor[
             0.23388775769536924`, 0.36316124105113845`, 0.9366309338435965]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 333}], {
             RGBColor[
             0.3303539220460226, 0.4544751187704825, 0.9424935506353687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 352}], {
             RGBColor[
             0.22055895151159555`, 0.3491518206568699, 0.9358718780496325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 357}], {
             RGBColor[
             0.23165569271724953`, 0.3608151992380412, 0.9365038210451369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 358}], {
             RGBColor[
             0.3137918107660683, 0.4401298504157032, 0.94143822754991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 367}], {
             RGBColor[
             0.2501892935368386, 0.3802951887975917, 0.9375592821938071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 368}], {
             RGBColor[
             0.21159898242802877`, 0.3397343250551897, 0.9353616210654097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 375}], {
             RGBColor[
             0.26223546161822137`, 0.3929564752222947, 0.9382452936453332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 441}], {
             RGBColor[
             0.3055997605504103, 0.43303430826331607`, 0.9409162373541138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 450}], {
             RGBColor[
             0.29135013033172863`, 0.4206919947751334, 0.9400082635170326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 492}], {
             RGBColor[
             0.21887186017874036`, 0.3473785806982704, 0.9357758006940542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 102}], {
             RGBColor[
             0.3305278013611218, 0.45687607566175037`, 0.9424222336843717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 168}], {
             RGBColor[
             0.5869322775232643, 0.6718097968709896, 0.962514131755837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 181}], {
             RGBColor[
             0.3907137841542735, 0.512838374813811, 0.9461169147250448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.46358589832160735`, 0.5737817600479446, 0.9513611588765089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 232}], {
             RGBColor[
             0.5449308949826625, 0.6389979976079412, 0.9583278264694257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 280}], {
             RGBColor[
             0.46829572790906493`, 0.5776054118824476, 0.9517319339143078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 302}], {
             RGBColor[
             0.44096969519954776`, 0.5554209075051166, 0.9495807285208586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 370}], {
             RGBColor[
             0.3984907491896946, 0.5195743910458647, 0.9466124560602016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 383}], {
             RGBColor[
             0.5131465195328626, 0.6140173050277837, 0.9552627525247963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 390}], {
             RGBColor[
             0.4759482746338757, 0.5838180940569503, 0.9523343704246872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 443}], {
             RGBColor[
             0.5725638986959316, 0.6605851101273537, 0.9610820260344628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 451}], {
             RGBColor[
             0.3426842136829911, 0.46965323577309337`, 0.9431145233823018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 480}], {
             RGBColor[
             0.4365798694030919, 0.5518570491641553, 0.9492351453536998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 25}], {
             RGBColor[
             0.8725548505464009, 0.8998336579439141, 0.9166173714965022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 164}], {
             RGBColor[
             0.9340834784629356, 0.9483907377638316, 0.9226198202751702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 180}], {
             RGBColor[
             0.7955000612132693, 0.8390425461583731, 0.9093442969764326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 205}], {
             RGBColor[
             0.7162818128753168, 0.7745053780529972, 0.9031699004171979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 259}], {
             RGBColor[
             0.8740472245688059, 0.4191181540612454, 0.3950653321159444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 316}], {
             RGBColor[
             0.9867175484992736, 0.9766529954342503, 0.6283033308879433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 331}], {
             RGBColor[
             0.9074990918503562, 0.9271930694929118, 0.9200841777479003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 348}], {
             RGBColor[
             0.9751195085877224, 0.9375300834633149, 0.5832471359376257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 372}], {
             RGBColor[
             0.8740472245688059, 0.4191181540612454, 0.3950653321159444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 404}], {
             RGBColor[
             0.8740472245688059, 0.4191181540612454, 0.3950653321159444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 418}], {
             RGBColor[
             0.9680252917800689, 0.9114065680096394, 0.5671089180690637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 431}], {
             RGBColor[
             0.9904763275659175, 0.9887484103996551, 0.6925501182919337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 444}], {
             RGBColor[
             0.8965218183778059, 0.5918677305070236, 0.41658702852886603`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 40}], {
             RGBColor[
             0.22456517753702926`, 0.3533626182190016, 0.9361000266951005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 161}], {
             RGBColor[
             0.2878546124844855, 0.4177612959984998, 0.9397819826492559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 188}], {
             RGBColor[
             0.3121421207816605, 0.43879791495985154`, 0.9413295612013517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 202}], {
             RGBColor[
             0.2283373813057901, 0.35732744355150203`, 0.936314848119256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 243}], {
             RGBColor[
             0.249485287780747, 0.37955523411139636`, 0.9375191901074809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 273}], {
             RGBColor[
             0.22919575579368628`, 0.35822964956236686`, 0.9363637312764905]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 279}], {
             RGBColor[
             0.2740454754738125, 0.40536954858264795`, 0.9389178564630594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 283}], {
             RGBColor[
             0.21876873065664665`, 0.34727018503176055`, 0.9357699276203375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 285}], {
             RGBColor[
             0.28914299431124585`, 0.4188772275808861, 0.9398640771999859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 318}], {
             RGBColor[
             0.2525038287839251, 0.3827279120922901, 0.9376910915520806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 335}], {
             RGBColor[
             0.27951857139159386`, 0.4105410361854448, 0.9392508174820886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 396}], {
             RGBColor[
             0.25133562707487567`, 0.38150005802781284`, 0.9376245641929499]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 421}], {
             RGBColor[
             0.22311781120305674`, 0.35184134443367066`, 0.9360176013235675]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 430}], {
             RGBColor[
             0.26020424486877647`, 0.39082153763204774`, 0.9381296188563681]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 459}], {
             RGBColor[
             0.24496381986437168`, 0.3748028846536623, 0.9372616991985556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 477}], {
             RGBColor[
             0.25210090277797115`, 0.38230441131304815`, 0.9376681455121172]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 21}], {
             RGBColor[
             0.680757442248239, 0.7489730331464229, 0.969887983187306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 59}], {
             RGBColor[
             0.5710396459203946, 0.662634735457889, 0.9593734791954514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 77}], {
             RGBColor[
             0.7393999520548098, 0.7956405917835261, 0.9722782472010072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 87}], {
             RGBColor[
             0.6969015731746537, 0.761845924926386, 0.9714278248071031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 161}], {
             RGBColor[
             0.4356106212508812, 0.5493852197341049, 0.9496243993260349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 188}], {
             RGBColor[
             0.4598981295480561, 0.5704218386954567, 0.9511719778781306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 228}], {
             RGBColor[
             0.5560506747276076, 0.6504660133981275, 0.9581934924767446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 243}], {
             RGBColor[
             0.39724129654714263`, 0.5111791578470015, 0.9473616067842598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 256}], {
             RGBColor[
             0.7023889140742479, 0.7662213816098218, 0.9719512122807135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 279}], {
             RGBColor[
             0.4218014842402082, 0.536993472318253, 0.9487602731398381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 285}], {
             RGBColor[
             0.4368990030776415, 0.5505011513164912, 0.9497064938767648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 287}], {
             RGBColor[
             0.68872640512068, 0.7553272678291727, 0.9706480699800565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 298}], {
             RGBColor[
             0.6096447166347696, 0.6934029640170689, 0.9628044481530396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 335}], {
             RGBColor[
             0.4272745801579895, 0.5421649599210498, 0.9490932341588676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 354}], {
             RGBColor[
             0.7007171274519702, 0.7648883443366565, 0.9717917557802591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 409}], {
             RGBColor[
             0.540422450424237, 0.6377783168651694, 0.9569631814115112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 430}], {
             RGBColor[
             0.4079602536351721, 0.5224454613676528, 0.9479720355331471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 477}], {
             RGBColor[
             0.39985691154436676`, 0.5139283350486532, 0.9475105621888961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 80}], {
             RGBColor[
             0.6859318225908408, 0.7505439617444168, 0.951794759405942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 159}], {
             RGBColor[
             0.41659878498905367`, 0.5352586615189268, 0.9477662840890294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 166}], {
             RGBColor[
             0.33248611507677234`, 0.4570745588104135, 0.9426018541938415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 192}], {
             RGBColor[
             0.6420349038642188, 0.7161165631440682, 0.9675369541888443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.34656244604435504`, 0.47186967514827405`, 0.9434034804183797]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 239}], {
             RGBColor[
             0.3345592647628135, 0.4592535705757248, 0.9427199170015113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 251}], {
             RGBColor[
             0.43294174364966176`, 0.5494141108897593, 0.9488076429633725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 272}], {
             RGBColor[
             0.49012417246760553`, 0.5958729134320023, 0.9532994359632572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 435}], {
             RGBColor[
             0.431666942251965, 0.5483099419924558, 0.9487264137455738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 447}], {
             RGBColor[
             0.4204684417421174, 0.5386103637038271, 0.9480128551955316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 453}], {
             RGBColor[
             0.43587796123566236`, 0.5518333953899437, 0.9490289755046595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 454}], {
             RGBColor[
             0.36689237882404113`, 0.4922054708154086, 0.9445990358418439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 489}], {
             RGBColor[
             0.3237403694481549, 0.4478822256424365, 0.9421037969184629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 50}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 82}], {
             RGBColor[
             0.844192723800754, 0.2992353265545987, 0.18832903870459236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 126}], {
             RGBColor[
             0.8563654629268306, 0.3487034608338446, 0.19818596167822736`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 149}], {
             RGBColor[
             0.8300337551067959, 0.23185817939204778`, 0.1763936638495297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 173}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 242}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 249}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 269}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 282}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 323}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 414}], {
             RGBColor[
             0.8759899507757182, 0.41879994377265284`, 0.28134248690904895`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 419}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 449}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 499}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 17}], {
             RGBColor[
             0.8171965358160596, 0.8565952297054558, 0.9114583528675545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 116}], {
             RGBColor[
             0.6656811252095095, 0.7387544214683854, 0.9673125314832324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 143}], {
             RGBColor[
             0.7737686828707752, 0.43259576374804576`, 0.44397690814617397`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 165}], {
             RGBColor[
             0.7458367292928169, 0.8015726905647942, 0.9752485920882636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 185}], {
             RGBColor[
             0.4837779911654755, 0.5881187692744494, 0.9535473316443274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.5070562614150484, 0.6082812369647475, 0.955030602440464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 224}], {
             RGBColor[
             0.4710966513554297, 0.5758880395117242, 0.9527849389967913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 277}], {
             RGBColor[
             0.8139749785046464, 0.8358688222621367, 0.6731005033291653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 313}], {
             RGBColor[
             0.8124335820745439, 0.8535860695269795, 0.9438393627828742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 333}], {
             RGBColor[
             0.5323412755190838, 0.6301818453199022, 0.956641741180513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 358}], {
             RGBColor[
             0.5157791642391296, 0.6158365769651228, 0.9555864180950544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 361}], {
             RGBColor[
             0.5282938438058984, 0.6266761633997737, 0.9563838424107522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 386}], {
             RGBColor[
             0.7452144755917458, 0.8010765223541869, 0.9751892409747631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 441}], {
             RGBColor[
             0.5075871140234716, 0.6087410348127357, 0.9550644278992582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 89}], {
             RGBColor[
             0.9231261051226047, 0.9396618813362796, 0.9219331847920909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.8740328861463312, 0.4191122247550715, 0.39530295688299816`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 116}], {
             RGBColor[
             0.8359452478324436, 0.8712418660281439, 0.9133270492646723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 143}], {
             RGBColor[
             0.8872780979527313, 0.5209207267878847, 0.40798658666713394`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 165}], {
             RGBColor[
             0.916100851915751, 0.9340601351245527, 0.9212631098697036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 176}], {
             RGBColor[
             0.9356274804823903, 0.9496301387073782, 0.9231255771340168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 178}], {
             RGBColor[
             0.9720885828279697, 0.9273697155199401, 0.5719125519494651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 261}], {
             RGBColor[
             0.9569330773756479, 0.9666186433450407, 0.9251577239854265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 277}], {
             RGBColor[
             0.9842391011275806, 0.968356266821895, 0.6191150211106053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 288}], {
             RGBColor[
             0.8740328861463312, 0.4191122247550715, 0.39530295688299816`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 313}], {
             RGBColor[
             0.9826977046974779, 0.9860735140867379, 0.8898538805643141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 321}], {
             RGBColor[
             0.8740328861463312, 0.4191122247550715, 0.39530295688299816`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 328}], {
             RGBColor[
             0.732255951190426, 0.7877066954338351, 0.9047236192749173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 386}], {
             RGBColor[
             0.91547859821468, 0.9335639669139454, 0.921203758756203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 391}], {
             RGBColor[
             0.970002280405527, 0.9193210457585888, 0.5690733922205091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 407}], {
             RGBColor[
             0.8378626122664915, 0.8727397256965316, 0.9135181542326689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 455}], {
             RGBColor[
             0.8740328861463312, 0.4191122247550715, 0.39530295688299816`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 498}], {
             RGBColor[
             0.8740328861463312, 0.4191122247550715, 0.39530295688299816`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 28}], {
             RGBColor[
             0.8517541692906616, 0.8223523733810587, 0.6271103274009263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 93}], {
             RGBColor[
             0.5639993331847883, 0.6530475914223423, 0.960586802442077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 160}], {
             RGBColor[
             0.6045200328244643, 0.6881026838156832, 0.9631803229645852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 167}], {
             RGBColor[
             0.6058193984674288, 0.6891575673803969, 0.9632826137877326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 172}], {
             RGBColor[
             0.5660661695896078, 0.6548377812339787, 0.9607184994301604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 201}], {
             RGBColor[
             0.6609818107872878, 0.7339408987400141, 0.9676252009521262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 218}], {
             RGBColor[
             0.7469981175976064, 0.8022798739539989, 0.975417449333979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 235}], {
             RGBColor[
             0.5507776223875409, 0.6415956100722736, 0.9597443267215762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 274}], {
             RGBColor[
             0.6190583277740055, 0.6999055265984445, 0.9643248307985424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 300}], {
             RGBColor[
             0.5861445158721873, 0.672228635616922, 0.9619978739007018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 305}], {
             RGBColor[
             0.8079904168689416, 0.8502655206247263, 0.9814068971986999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 310}], {
             RGBColor[
             0.7962722946032341, 0.358714514364911, 0.4348563870006418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 406}], {
             RGBColor[
             0.8740105754900596, 0.8985635500757864, 0.7736400637514464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 432}], {
             RGBColor[
             0.7627827717291649, 0.8146109657293871, 0.9769907161418333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 460}], {
             RGBColor[
             0.7893755098548014, 0.8354224990598411, 0.9796313907499675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 493}], {
             RGBColor[
             0.6718112756182114, 0.7427327461515889, 0.9684777360932533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 26}], {
             RGBColor[
             0.2440972272221243, 0.3738920408415133, 0.9372123480295886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 59}], {
             RGBColor[
             0.44306018409949816`, 0.5517972164675021, 0.9506573076104392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 67}], {
             RGBColor[
             0.23543376871002816`, 0.36478619665030476`, 0.9367189768837632]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 124}], {
             RGBColor[
             0.24511713728705276`, 0.3749640309857861, 0.9372704303989646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 188}], {
             RGBColor[
             0.3319186677271597, 0.45958431970506974`, 0.9424558062931185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 200}], {
             RGBColor[
             0.44299594892189786`, 0.5517450674565645, 0.9506522507819574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 228}], {
             RGBColor[
             0.42807121290671124`, 0.5396284944077405, 0.9494773208917324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 298}], {
             RGBColor[
             0.4816652548138733, 0.582565445026682, 0.9540882765680275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 318}], {
             RGBColor[
             0.2722803757294244, 0.4035143168375083, 0.9388173366438475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 335}], {
             RGBColor[
             0.29929511833709316`, 0.431327440930663, 0.9403770625738554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 459}], {
             RGBColor[
             0.26474036680987095`, 0.3955892893988805, 0.9383879442903225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 468}], {
             RGBColor[
             0.32598193572834094`, 0.4544422208365192, 0.9420775229797997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 25}], {
             RGBColor[
             0.6134743869641546, 0.6953197324267161, 0.9639211366967662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 46}], {
             RGBColor[
             0.3775120116687234, 0.49883606233675915`, 0.9454740124415332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 150}], {
             RGBColor[
             0.40414439209252373`, 0.5240361829288928, 0.9470929232210681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 220}], {
             RGBColor[
             0.40815671966871825`, 0.5275114594099448, 0.9473485851862612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 325}], {
             RGBColor[
             0.44797720589084944`, 0.562001963139723, 0.949885911356462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 388}], {
             RGBColor[
             0.6968315144564416, 0.7612822652895019, 0.972005607251501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 392}], {
             RGBColor[
             0.4556885448241814, 0.5686811373406109, 0.9503772710544247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 413}], {
             RGBColor[
             0.4400008523109076, 0.555093246571965, 0.9493776651595607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 473}], {
             RGBColor[
             0.5378272732791293, 0.6356714351473729, 0.9567588795602012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 474}], {
             RGBColor[
             0.4380905408797232, 0.5534386308253174, 0.9492559418043877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 490}], {
             RGBColor[
             0.40560130196472277`, 0.5252980850337723, 0.9471857562298298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 55}], {
             RGBColor[
             0.8365288820965593, 0.5120560542024203, 0.4540089567270905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 59}], {
             RGBColor[
             0.7122788416336581, 0.774563525190366, 0.9723694632136166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 77}], {
             RGBColor[
             0.8806391477680734, 0.9075693815160031, 0.9852742312191726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[
             0.8381407688879172, 0.873774714658863, 0.9844238088252685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 91}], {
             RGBColor[
             0.89309711802987, 0.8758970279199172, 0.6491494129218777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 188}], {
             RGBColor[
             0.6011373252613197, 0.6823506284279337, 0.9641679618962959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 200}], {
             RGBColor[
             0.7122146064560578, 0.7745113761794283, 0.9723644063851347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 228}], {
             RGBColor[
             0.6972898704408712, 0.7623948031306045, 0.9711894764949098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 256}], {
             RGBColor[
             0.8436281097875116, 0.8781501713422988, 0.9849471962988788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 287}], {
             RGBColor[
             0.8299656008339436, 0.8672560575616497, 0.9836440539982219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 298}], {
             RGBColor[
             0.7508839123480333, 0.8053317537495459, 0.9758004321712048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 335}], {
             RGBColor[
             0.5685137758712531, 0.6540937496535268, 0.9620892181770329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 336}], {
             RGBColor[
             0.8188782126538342, 0.37638527429296664`, 0.43710665573515706`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 354}], {
             RGBColor[
             0.8419563231652338, 0.8768171340691335, 0.9847877397984244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 409}], {
             RGBColor[
             0.6816616461375005, 0.7497071065976464, 0.9699591654296765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 24}], {
             RGBColor[
             0.1988170752865331, 0.32629973022975733`, 0.9346337103628386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 52}], {
             RGBColor[
             0.18741101862312, 0.3143112414907485, 0.933984152309606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 170}], {
             RGBColor[
             0.20408136056054266`, 0.3318328278277056, 0.9349335036213813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 214}], {
             RGBColor[
             0.2036724125219917, 0.3314029975103854, 0.9349102146355702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 268}], {
             RGBColor[
             0.20099391902560468`, 0.32858773101938626`, 0.934757678393427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 466}], {
             RGBColor[
             0.21948326963951018`, 0.34802121080713827`, 0.9358106195583459]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 491}], {
             RGBColor[
             0.19092580831177908`, 0.31800550830406665`, 0.9341843143827098]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 39}], {
             RGBColor[
             0.7492481098657082, 0.7981399836975582, 0.6930866813159002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 51}], {
             RGBColor[
             0.8757337238850049, 0.41825190036192983`, 0.2534537711039848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 62}], {
             RGBColor[
             0.7605455492253483, 0.8073117539135573, 0.693976057126175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 96}], {
             RGBColor[
             0.9739330346591857, 0.9234998076435308, 0.35740958973864884`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 110}], {
             RGBColor[
             0.993178965010662, 0.9878188208072598, 0.4989506198380761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 136}], {
             RGBColor[
             0.9410230313708325, 0.7887755730421966, 0.3307097337117372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 157}], {
             RGBColor[
             0.9051450162162533, 0.9220177033851362, 0.7071961713842101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 240}], {
             RGBColor[
             0.8757337238850049, 0.41825190036192983`, 0.2534537711039848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 360}], {
             RGBColor[
             0.8792976493045557, 0.4456457928586737, 0.2568665901106246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 52}], {
             RGBColor[
             0.19493298804641856`, 0.32221730827504236`, 0.9344125173405062]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 64}], {
             RGBColor[
             0.20529474346718407`, 0.33310817019550554`, 0.9350026039828754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.2136963850560424, 0.34193882820023935`, 0.9354810650422459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 115}], {
             RGBColor[
             0.2186064221312832, 0.3470995884806487, 0.935760684389932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 170}], {
             RGBColor[
             0.2116033299838412, 0.33973889461199946`, 0.9353618686522815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 223}], {
             RGBColor[
             0.255646740576453, 0.38603131165835397`, 0.9378700757291438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 268}], {
             RGBColor[
             0.20851588844890323`, 0.3364937978036801, 0.9351860434243273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 491}], {
             RGBColor[
             0.19844777773507763`, 0.3259115750883605, 0.93461267941361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 164}], {
             RGBColor[
             0.8191346553029186, 0.8591239335240097, 0.9824771954238392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.6805512380532523, 0.7497757419185513, 0.9692016721251016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 220}], {
             RGBColor[
             0.5522883600909476, 0.6427585806873211, 0.9599021951346662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 316}], {
             RGBColor[
             0.8717687253392568, 0.8873861911944285, 0.6881607060366124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 325}], {
             RGBColor[
             0.5921088463130788, 0.6772490844170992, 0.9624395213048671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 392}], {
             RGBColor[
             0.5998201852464107, 0.6839282586179871, 0.9629308810028296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 413}], {
             RGBColor[
             0.5841324927331369, 0.6703403678493413, 0.9619312751079657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 474}], {
             RGBColor[
             0.5822221813019526, 0.6686857521026937, 0.9618095517527927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 490}], {
             RGBColor[
             0.5497329423869521, 0.6405452063111485, 0.9597393661782347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 67}], {
             RGBColor[
             0.1959716730389698, 0.32330903205864586`, 0.9344716689142352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 124}], {
             RGBColor[
             0.2056550416159944, 0.33348686639412717`, 0.9350231224294367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 318}], {
             RGBColor[
             0.23281828005836602`, 0.3620371522458494, 0.9365700286743196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 335}], {
             RGBColor[
             0.2598330226660348, 0.3898502763390041, 0.9381297546043277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 459}], {
             RGBColor[
             0.2252782711388126, 0.3541121248072216, 0.9361406363207947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 29}], {
             RGBColor[
             0.20431304380785625`, 0.33207634161019856`, 0.9349466976395711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 65}], {
             RGBColor[
             0.20162066097000025`, 0.3292464765406804, 0.9347933704199787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 86}], {
             RGBColor[
             0.20621369612965204`, 0.3340740477087234, 0.9350549369775343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 177}], {
             RGBColor[
             0.20421188606161866`, 0.3319700184051313, 0.9349409368555723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[
             0.20792633813700911`, 0.33587414304623064`, 0.9351524694062264]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 290}], {
             RGBColor[
             0.19806122117282127`, 0.32550527963232745`, 0.9345906655892486]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 297}], {
             RGBColor[
             0.2276449517133472, 0.3565996561472727, 0.9362754152783243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 350}], {
             RGBColor[
             0.19805630037094138`, 0.32550010755755476`, 0.9345903853568613]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 412}], {
             RGBColor[
             0.21686143319747594`, 0.34526549447252863`, 0.9356613098516314]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 484}], {
             RGBColor[
             0.20513686464962994`, 0.3329422295481609, 0.9349936130177764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 490}], {
             RGBColor[
             0.27392877216704353`, 0.40218528363986605`, 0.9390233106427064]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 125}], {
             RGBColor[
             0.8613224849238736, 0.3683564012224616, 0.2021744979333091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 149}], {
             RGBColor[
             0.8867519951374654, 0.5638187600065572, 0.2265258256323685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 201}], {
             RGBColor[
             0.7585570962682471, 0.7484037290263401, 0.6186023673511272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 218}], {
             RGBColor[
             0.8445734030785657, 0.8167427042403248, 0.62639461573298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 282}], {
             RGBColor[
             0.8613224849238736, 0.3683564012224616, 0.2021744979333091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 305}], {
             RGBColor[
             0.905565702349901, 0.8647283509110522, 0.6323840635977009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 310}], {
             RGBColor[
             0.8613224849238736, 0.3683564012224616, 0.2021744979333091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 406}], {
             RGBColor[
             0.971585860971019, 0.9130263803621124, 0.4246172301504474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 408}], {
             RGBColor[
             0.8613224849238736, 0.3683564012224616, 0.2021744979333091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 419}], {
             RGBColor[
             0.8613224849238736, 0.3683564012224616, 0.2021744979333091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 432}], {
             RGBColor[
             0.8603580572101241, 0.8290737960157131, 0.6279678825408344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 493}], {
             RGBColor[
             0.7693865610991708, 0.7571955764379148, 0.6194549024922544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 46}], {
             RGBColor[
             0.24415483873233365`, 0.37395259419152405`, 0.9372156289198665]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 65}], {
             RGBColor[
             0.19993601783128978`, 0.32747580978935154`, 0.9346974324854354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 86}], {
             RGBColor[
             0.2045290529909416, 0.33230338095739453`, 0.934958999042991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 177}], {
             RGBColor[
             0.20252724292290822`, 0.33019935165380243`, 0.934844998921029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 194}], {
             RGBColor[
             0.20624169499829867`, 0.3341034762949018, 0.935056531471683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 254}], {
             RGBColor[
             0.219858689201137, 0.34841580056938304`, 0.935831999146997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 290}], {
             RGBColor[
             0.1963765780341108, 0.3237346128809986, 0.9344947276547053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 297}], {
             RGBColor[
             0.22596030857463673`, 0.3548289893959438, 0.9361794773437808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 350}], {
             RGBColor[
             0.19637165723223093`, 0.3237294408062259, 0.9344944474223179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 377}], {
             RGBColor[
             0.19479365087519235`, 0.32207085607359665`, 0.9344045822947358]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 412}], {
             RGBColor[
             0.2151767900587655, 0.34349482772119977`, 0.935565371917088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 426}], {
             RGBColor[
             0.20893369054247232`, 0.33693293429420396`, 0.9352098366354733]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 476}], {
             RGBColor[
             0.20047610231188778`, 0.3280434728217939, 0.934728189497622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 31}], {
             RGBColor[
             0.20705706276398889`, 0.3349604795139445, 0.9351029654597106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 133}], {
             RGBColor[
             0.21997865236817787`, 0.3485418894640472, 0.9358388308718903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 191}], {
             RGBColor[
             0.20407545440505548`, 0.3318266200838168, 0.9349331672745637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 311}], {
             RGBColor[
             0.20275732105733557`, 0.3304411783608819, 0.9348581015304145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 366}], {
             RGBColor[
             0.1867597729131777, 0.31362674095823617`, 0.9339470648298565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 405}], {
             RGBColor[
             0.18482655001024287`, 0.3115948011138402, 0.9338369706454812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 423}], {
             RGBColor[
             0.17952980953436626`, 0.3060275910409509, 0.9335353291112054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 429}], {
             RGBColor[
             0.20698840587743583`, 0.3348883167730792, 0.9350990555515901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 465}], {
             RGBColor[
             0.1792054619955512, 0.30568668121283454`, 0.933516857998699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 469}], {
             RGBColor[
             0.18416602893623069`, 0.3109005515855985, 0.9337993549474696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 488}], {
             RGBColor[
             0.18669921182250732`, 0.3135630874121468, 0.9339436159653348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 133}], {
             RGBColor[
             0.2480786626367777, 0.3780767818998994, 0.9374390848864473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 191}], {
             RGBColor[
             0.23217546467365527`, 0.361361512519669, 0.9365334212891205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 226}], {
             RGBColor[
             0.22438551241201804`, 0.35317377878118794`, 0.9360897950320219]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 237}], {
             RGBColor[
             0.3290966057081422, 0.45266487271418654`, 0.9424398430146377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 311}], {
             RGBColor[
             0.2308573313259354, 0.3599760707967341, 0.9364583555449715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 366}], {
             RGBColor[
             0.21485978318177745`, 0.34316163339408845`, 0.9355473188444132]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 405}], {
             RGBColor[
             0.21292656027884266`, 0.3411296935496924, 0.9354372246600381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 429}], {
             RGBColor[
             0.23508841614603562`, 0.36442320920893145`, 0.9366993095661471]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 472}], {
             RGBColor[
             0.21610683850656687`, 0.34447236760831645`, 0.935618336800307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 488}], {
             RGBColor[
             0.2147992220911071, 0.343097979847999, 0.9355438699798917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 66}], {
             RGBColor[
             0.3101036799664407, 0.4385643994191369, 0.9411435766218114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 84}], {
             RGBColor[
             0.5191908481230056, 0.617440223102824, 0.9563757768952883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 89}], {
             RGBColor[
             0.6092109643121336, 0.6880782890419994, 0.965264903215373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 176}], {
             RGBColor[
             0.6217123396719191, 0.698046546413098, 0.9664572955572988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 179}], {
             RGBColor[
             0.31490599852677015`, 0.44361194071062604`, 0.9414170615594284]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 245}], {
             RGBColor[
             0.4212849020662287, 0.5385132494002911, 0.9482871073803061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 255}], {
             RGBColor[
             0.3085704354238704, 0.43695286219157675`, 0.941056260613344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 260}], {
             RGBColor[
             0.3358333242416319, 0.46530367880959933`, 0.9426199803482964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 299}], {
             RGBColor[
             0.4092045959302848, 0.5287059126675422, 0.9473361014296651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 312}], {
             RGBColor[
             0.3038288820776412, 0.431969188992844, 0.9407862361647759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 328}], {
             RGBColor[
             0.41834081037995485`, 0.5361231031395549, 0.9480553376981994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 334}], {
             RGBColor[
             0.2863539875937741, 0.413601966917996, 0.9397910667757092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 407}], {
             RGBColor[
             0.5239474714560204, 0.6211561334022514, 0.9568498726559509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 448}], {
             RGBColor[
             0.5919293414877744, 0.6742983920990104, 0.9636165666028987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 475}], {
             RGBColor[
             0.6509446795635007, 0.7211864568708418, 0.9633804842819546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 478}], {
             RGBColor[
             0.43818467591766874`, 0.5522332471390261, 0.9496175194838028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 482}], {
             RGBColor[
             0.64794186446319, 0.7189469622856886, 0.9684634669871719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 76}], {
             RGBColor[
             0.7773631602461192, 0.8221474687086947, 0.7922109863395075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 111}], {
             RGBColor[
             0.7724584371268222, 0.8209274086540813, 0.9322402963389583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 160}], {
             RGBColor[
             0.507621153600386, 0.6111487464219849, 0.9543809431704284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 175}], {
             RGBColor[
             0.7775942134782825, 0.823051184158842, 0.8471271912321169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 182}], {
             RGBColor[
             0.75743790360309, 0.8097822285259801, 0.9602236073747921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 237}], {
             RGBColor[
             0.49170863187262065`, 0.5974080208929563, 0.9533554339843097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 241}], {
             RGBColor[
             0.45030985755818603`, 0.5615504833446909, 0.9507175406924926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 274}], {
             RGBColor[
             0.5221594485499271, 0.6229515892047461, 0.9555254510043854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 351}], {
             RGBColor[
             0.5099468577737633, 0.6130368578417116, 0.9545640311222917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 371}], {
             RGBColor[
             0.5535152767239239, 0.6484076630803585, 0.9579938966584256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 432}], {
             RGBColor[
             0.6658838925050865, 0.7376570283356887, 0.9681913363476764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 460}], {
             RGBColor[
             0.6924766306307231, 0.7584685616661428, 0.9708320109558106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 463}], {
             RGBColor[
             0.7610323559034178, 0.5268877243816464, 0.4568621548257559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 44}], {
             RGBColor[
             0.5037551933062931, 0.6031416247429248, 0.9557644930809137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 62}], {
             RGBColor[
             0.4183440898877315, 0.5346740747422846, 0.9484437217570646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 190}], {
             RGBColor[
             0.32639172231009544`, 0.4570716814510417, 0.9420203527500528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 291}], {
             RGBColor[
             0.25248695241717767`, 0.3827101739608151, 0.9376901304679608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 356}], {
             RGBColor[
             0.3999124124412533, 0.519710408653627, 0.9469927125910187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 394}], {
             RGBColor[
             0.2532945186751018, 0.38355897730055144`, 0.9377361201716623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 467}], {
             RGBColor[
             0.26986184992211565`, 0.40097229287063396`, 0.9386796051770095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.19771231040963783`, 0.3251385522980016, 0.9345707956374525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 123}], {
             RGBColor[
             0.21261512288870693`, 0.34080235310638873`, 0.9354194887614002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 193}], {
             RGBColor[
             0.20201306311706924`, 0.32965891607698306`, 0.9348157171417473]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 347}], {
             RGBColor[
             0.2497247180796972, 0.37980689053635075`, 0.9375328253088007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 410}], {
             RGBColor[
             0.2048653084706884, 0.3326568067864372, 0.934978148295117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 422}], {
             RGBColor[
             0.25718407515887753`, 0.3876471477771245, 0.9379576246593302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 428}], {
             RGBColor[
             0.216766629209909, 0.3451658494706758, 0.9356559109047894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 437}], {
             RGBColor[
             0.20415760851311143`, 0.3319129692602549, 0.9349378458294813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 75}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 76}], {
             RGBColor[
             0.8763277317102309, 0.4195224230366844, 0.31810785708846784`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 104}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 112}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 266}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 359}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 379}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 408}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 440}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 463}], {
             RGBColor[
             0.831998657058118, 0.24386491747293382`, 0.17815401051060936`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 49}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 53}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 97}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 100}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 203}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 207}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 257}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 264}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 281}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 317}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 322}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 324}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 343}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 374}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 397}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 445}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 77}], {
             RGBColor[
             0.9192907829722123, 0.7949315839058828, 0.6126751046012756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 79}], {
             RGBColor[
             0.8446459694565934, 0.30129340921955317`, 0.18870723798989242`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 87}], {
             RGBColor[
             0.8767924040920562, 0.7611369170487428, 0.6118246822073715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 127}], {
             RGBColor[
             0.8446459694565934, 0.30129340921955317`, 0.18870723798989242`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 184}], {
             RGBColor[
             0.8878066027772542, 0.5834378112927188, 0.2280954180565736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 221}], {
             RGBColor[
             0.8446459694565934, 0.30129340921955317`, 0.18870723798989242`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 253}], {
             RGBColor[
             0.9437188064028268, 0.8124944389214359, 0.5419690901557521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 287}], {
             RGBColor[
             0.8686172360380824, 0.7546182599515294, 0.6110449273803248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 301}], {
             RGBColor[
             0.8446459694565934, 0.30129340921955317`, 0.18870723798989242`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 316}], {
             RGBColor[
             0.942615665830955, 0.799915878171712, 0.3187661896988654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 336}], {
             RGBColor[
             0.8446459694565934, 0.30129340921955317`, 0.18870723798989242`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 354}], {
             RGBColor[
             0.8806079583693727, 0.7641793364590133, 0.6121886131805274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 388}], {
             RGBColor[
             0.9118100953703692, 0.7890590735441616, 0.615164700862159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 436}], {
             RGBColor[
             0.9344998640366943, 0.8062744916611889, 0.5869300975227473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 473}], {
             RGBColor[
             0.7528058541930568, 0.6634482434020327, 0.5999179731708593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 62}], {
             RGBColor[
             0.5172304874360417, 0.6189500365253262, 0.9551374251301208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 96}], {
             RGBColor[
             0.7306179728698792, 0.7351380902552997, 0.6185709577425946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 108}], {
             RGBColor[
             0.4086556507016406, 0.5269500959200856, 0.9476548870871122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 113}], {
             RGBColor[
             0.3807447522810758, 0.4978573418320051, 0.9460564917517937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 157}], {
             RGBColor[
             0.6618299544269467, 0.7336559859969052, 0.9683575393881558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 190}], {
             RGBColor[
             0.4252781198584057, 0.5413476432340834, 0.948714056123109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 378}], {
             RGBColor[
             0.4028150168001186, 0.5210545891771114, 0.9473133606661228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 161}], {
             RGBColor[
             0.2684135610193307, 0.39732751827476565`, 0.9386748435287737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 183}], {
             RGBColor[
             0.23087447888683538`, 0.35999409397045823`, 0.9364593320731971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 202}], {
             RGBColor[
             0.20889632984063528`, 0.3368936658277679, 0.9352077089987738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 206}], {
             RGBColor[
             0.19522868075367328`, 0.3225281000583675, 0.9344293566027462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 243}], {
             RGBColor[
             0.23004423631559218`, 0.35912145638766224`, 0.9364120509869986]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 273}], {
             RGBColor[
             0.20975470432853144`, 0.3377958718386327, 0.9352565921560083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 283}], {
             RGBColor[
             0.1993276791914918, 0.3268364073080263, 0.9346627884998552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 285}], {
             RGBColor[
             0.269701942846091, 0.39844344985715197`, 0.9387569380795036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 396}], {
             RGBColor[
             0.23189457560972082`, 0.36106628030407867`, 0.9365174250724676]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 421}], {
             RGBColor[
             0.20367675973790192`, 0.33140756670993643`, 0.9349104622030852]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 430}], {
             RGBColor[
             0.24076319340362162`, 0.37038775990831363`, 0.9370224797358859]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 477}], {
             RGBColor[
             0.2326598513128163, 0.36187063358931404`, 0.936561006391635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 44}], {
             RGBColor[
             0.6512432193483967, 0.7268745780156403, 0.9662842946826327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 56}], {
             RGBColor[
             0.7988889921505462, 0.8398198339616005, 0.8100291411688312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.6304047842681767, 0.7105954341529999, 0.964207314220084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 132}], {
             RGBColor[
             0.6315111194145004, 0.7114597115777666, 0.9643175833681797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.4813094096913133, 0.5872398339500613, 0.9530135658025085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 356}], {
             RGBColor[
             0.5474004384833568, 0.6434433619263427, 0.9575125141927376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 365}], {
             RGBColor[
             0.4515879807590536, 0.5606916651039451, 0.9511492161960573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 457}], {
             RGBColor[
             0.7799506296404679, 0.7772562145851217, 0.6242203432368331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 485}], {
             RGBColor[
             0.5788529501858339, 0.6689779278459186, 0.9599885711283033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 494}], {
             RGBColor[
             0.7862603193212523, 0.8326898579584304, 0.949304381285405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 108}], {
             RGBColor[
             0.29172348972761986`, 0.4237068926091371, 0.9399335041832765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 113}], {
             RGBColor[
             0.26381259130705503`, 0.39461413852105653`, 0.938335108847958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 119}], {
             RGBColor[
             0.23711084694980825`, 0.3665489122132156, 0.9368144840085036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 315}], {
             RGBColor[
             0.2351529722129052, 0.36449106172830237`, 0.9367029859386531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 364}], {
             RGBColor[
             0.2803428770185711, 0.4119885168845083, 0.9392764841648626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 378}], {
             RGBColor[
             0.28588285582609785`, 0.41781138586616284`, 0.939591977762287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 380}], {
             RGBColor[
             0.2438951722116548, 0.3736796682144823, 0.9372008412956561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 381}], {
             RGBColor[
             0.2456829942137933, 0.3755587824931918, 0.9373026551138322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 416}], {
             RGBColor[
             0.2908008659889437, 0.42290776229911325`, 0.9398747154144922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 452}], {
             RGBColor[
             0.3329650931678352, 0.45942829664579143`, 0.942561382685969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 468}], {
             RGBColor[
             0.3202366373459297, 0.4484035479636482, 0.9417503367363287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 487}], {
             RGBColor[
             0.2552478049273309, 0.38561200499714565`, 0.9378473569340987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[
             0.4999309487768256, 0.6034943400182612, 0.9541654474925418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 137}], {
             RGBColor[
             0.36126042666261593`, 0.4873273569233284, 0.9442401728302576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 148}], {
             RGBColor[
             0.5374554379217633, 0.6334803821671271, 0.957446343497947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 156}], {
             RGBColor[
             0.33421927844066934`, 0.460054494124931, 0.9426581453180694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 227}], {
             RGBColor[
             0.3207886255080345, 0.4459380263401525, 0.9418932895024263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 229}], {
             RGBColor[
             0.416869736584196, 0.535493346172216, 0.9477835488850788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 250}], {
             RGBColor[
             0.3804144405970011, 0.5039176010845604, 0.9454606496609272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 263}], {
             RGBColor[
             0.3916792939201136, 0.5136746508450498, 0.9461784361535572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 267}], {
             RGBColor[
             0.40347694898297903`, 0.5238931866931191, 0.9469301723019063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 393}], {
             RGBColor[
             0.3844301868161192, 0.5073958386222868, 0.9457165294590244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 485}], {
             RGBColor[
             0.4779579810915217, 0.5856556949804177, 0.9524356549867219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 56}], {
             RGBColor[
             0.8469959064349548, 0.8780021626885659, 0.8144131900742924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 62}], {
             RGBColor[
             0.6139390302142435, 0.6965893567419654, 0.9633475722642448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 92}], {
             RGBColor[
             0.6785116985525852, 0.7487777628799652, 0.9685913631255452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 110}], {
             RGBColor[
             0.8465724459995572, 0.877096423635668, 0.7683221349761459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 132}], {
             RGBColor[
             0.6796180336989088, 0.7496420403047319, 0.968701632273641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 157}], {
             RGBColor[
             0.7585384972051484, 0.8112953062135444, 0.9765676865222799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 356}], {
             RGBColor[
             0.5955073527677653, 0.681625690653308, 0.9618965630981988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 360}], {
             RGBColor[
             0.7815599699638192, 0.37183086141094573`, 0.43644760020267126`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 365}], {
             RGBColor[
             0.4996948950434621, 0.5988739938309104, 0.9555332651015185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 457}], {
             RGBColor[
             0.8280575439248763, 0.8154385433120871, 0.6286043921422944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 494}], {
             RGBColor[
             0.8343672336056607, 0.8708721866853958, 0.9536884301908661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 118}], {
             RGBColor[
             0.2554591373040128, 0.3858341287242849, 0.9378593920003125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 152}], {
             RGBColor[
             0.23828164417604697`, 0.36777949433082413`, 0.9368811591784987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 185}], {
             RGBColor[
             0.2976969078072994, 0.42913054113154847`, 0.9403049796510078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 187}], {
             RGBColor[
             0.32097517805687237`, 0.4492930088218466, 0.9417882504471444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 195}], {
             RGBColor[
             0.2465939110217282, 0.3765162138137928, 0.9373545304784634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 216}], {
             RGBColor[
             0.27205173985217523`, 0.40327400603416763`, 0.9388043161688746]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 217}], {
             RGBColor[
             0.23183546793394733`, 0.36100415438919764`, 0.9365140589777743]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 224}], {
             RGBColor[
             0.2850155679972537, 0.41689981136882326`, 0.9395425870034717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 292}], {
             RGBColor[
             0.24018663766573572`, 0.36978176327205037`, 0.9369896457395511]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 328}], {
             RGBColor[
             0.37591074520931583`, 0.4962310227311757, 0.9454667495001579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 398}], {
             RGBColor[
             0.28571521753888074`, 0.4176351873974164, 0.9395824310098286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 399}], {
             RGBColor[
             0.2892039179868987, 0.4213020327646674, 0.9397811073392734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 464}], {
             RGBColor[
             0.27751991420487765`, 0.40902140398113634`, 0.9391157206088221]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 481}], {
             RGBColor[
             0.2835821880689775, 0.4153932381826685, 0.939460958137052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 496}], {
             RGBColor[
             0.24168419906114047`, 0.37135579524949736`, 0.9370749296455758]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 86}], {
             RGBColor[
             0.24605549105412944`, 0.3759503002900489, 0.9373238682578297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 142}], {
             RGBColor[
             0.31315836829751326`, 0.4435312803958282, 0.9412532331571938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 150}], {
             RGBColor[
             0.31231365721932186`, 0.44279963411631207`, 0.9411994089142401]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 194}], {
             RGBColor[
             0.24776813306148654`, 0.3777503956275562, 0.9374214006865218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 220}], {
             RGBColor[
             0.3163259847955163, 0.44627491059736407`, 0.9414550708794333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 254}], {
             RGBColor[
             0.26138512726432483`, 0.39206271990203745`, 0.9381968683618358]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 297}], {
             RGBColor[
             0.26748674663782457`, 0.39847590872859817`, 0.9385443465586196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 325}], {
             RGBColor[
             0.3561464710176476, 0.48076541432714226`, 0.9439923970496341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 350}], {
             RGBColor[
             0.23789809529541878`, 0.3673763601388803, 0.9368593166371566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 377}], {
             RGBColor[
             0.23632008893838022`, 0.36571777540625106`, 0.9367694515095745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 392}], {
             RGBColor[
             0.3638578099509795, 0.48744458852803013`, 0.9444837567475968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 412}], {
             RGBColor[
             0.25670322812195334`, 0.3871417470538542, 0.9379302411319268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 426}], {
             RGBColor[
             0.2504601286056602, 0.3805798536268583, 0.937574705850312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 476}], {
             RGBColor[
             0.24200254037507565`, 0.3716903921544483, 0.9370930587124607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 55}], {
             RGBColor[
             0.8007526423490732, 0.4840965388666049, 0.45044599340948344`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 59}], {
             RGBColor[
             0.6586144820124289, 0.7326242521866431, 0.967025018237206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 73}], {
             RGBColor[
             0.7986897921704463, 0.4682405684469667, 0.4484706057487744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 91}], {
             RGBColor[
             0.8394327584086407, 0.8339577549161943, 0.643804967945467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 136}], {
             RGBColor[
             0.8020754049028471, 0.684036360935029, 0.600844615682085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 200}], {
             RGBColor[
             0.6585502468348285, 0.7325721031757053, 0.967019961408724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 228}], {
             RGBColor[
             0.643625510819642, 0.7204555301268813, 0.9658450315184992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 256}], {
             RGBColor[
             0.7899637501662823, 0.8362108983385758, 0.9796027513224682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 298}], {
             RGBColor[
             0.697219552726804, 0.7633924807458228, 0.9704559871947942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 416}], {
             RGBColor[
             0.5121004622842857, 0.6097734708911251, 0.95656961228473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 452}], {
             RGBColor[
             0.5542646894631771, 0.6462940052378033, 0.9592562795562067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 468}], {
             RGBColor[
             0.5415362336412717, 0.63526925655566, 0.9584452336065665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 117}], {
             RGBColor[
             0.21251052131884468`, 0.34069241022434094`, 0.9354135318567407]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 140}], {
             RGBColor[
             0.20271183825122668`, 0.33039337304788496`, 0.9348555113518924]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 155}], {
             RGBColor[
             0.23482099816692198`, 0.3641421359576038, 0.936684080507846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 156}], {
             RGBColor[
             0.2466062489720914, 0.37652918178189576`, 0.9373552331064843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 198}], {
             RGBColor[
             0.21002858102618926`, 0.33808373361265665`, 0.9352721890287756]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 250}], {
             RGBColor[
             0.2928014111284232, 0.4203922887415252, 0.9401577374493421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 365}], {
             RGBColor[
             0.2630799821961634, 0.393844119895409, 0.9382933878428907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 479}], {
             RGBColor[
             0.20982732020424238`, 0.33787219572811733`, 0.9352607275227045]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 51}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 100}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 203}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 264}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 324}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 360}], {
             RGBColor[
             0.8191009627097754, 0.1478239462483719, 0.1659244095033199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 397}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 457}], {
             RGBColor[
             0.8638009847389825, 0.3780247266271895, 0.20499214689883155`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 82}], {
             RGBColor[
             0.844192723800754, 0.2992353265545987, 0.18832903870459236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 126}], {
             RGBColor[
             0.8563654629268306, 0.3487034608338446, 0.19818596167822736`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 131}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 173}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 242}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 323}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 340}], {
             RGBColor[
             0.872096562596627, 0.4180301464376909, 0.41479302865073187`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 373}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 414}], {
             RGBColor[
             0.8759899507757182, 0.41879994377265284`, 0.28134248690904895`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 449}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 499}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 60}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 96}], {
             RGBColor[
             0.8633136325544521, 0.3762506380670908, 0.20377662205511443`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 100}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 110}], {
             RGBColor[
             0.8761442527887697, 0.4191299801762435, 0.29813730878806594`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 203}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 240}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 264}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 324}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 360}], {
             RGBColor[
             0.8191009627097754, 0.1478239462483719, 0.1659244095033199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 397}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 457}], {
             RGBColor[
             0.8638009847389825, 0.3780247266271895, 0.20499214689883155`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 495}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 170}], {
             RGBColor[
             0.2001972733204281, 0.32775040587299065`, 0.9347123105990489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 214}], {
             RGBColor[
             0.19978832528187718`, 0.3273205755556704, 0.9346890216132377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 268}], {
             RGBColor[
             0.19710983178549013`, 0.32450530906467123`, 0.9345364853710946]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 466}], {
             RGBColor[
             0.21559918239939563`, 0.34393878885242324`, 0.9355894265360134]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 491}], {
             RGBColor[
             0.18704172107166453`, 0.3139230863493516, 0.9339631213603773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 83}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 97}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 112}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 163}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 207}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 257}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 266}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 281}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 317}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 322}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 343}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 374}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 440}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 445}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 471}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 61}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 99}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 154}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 186}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 203}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 244}], {
             RGBColor[
             0.8706168078338911, 0.40101609835768304`, 0.23147033256236077`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 264}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 295}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 321}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 341}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 374}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 391}], {
             RGBColor[
             0.8623939674573535, 0.3726044724173211, 0.20303663793067456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 397}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 455}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 57}], {
             RGBColor[
             0.8349696694427251, 0.26979777990945364`, 0.18112030099193344`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 60}], {
             RGBColor[
             0.8349696694427251, 0.26979777990945364`, 0.18112030099193344`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 73}], {
             RGBColor[
             0.8427635790747743, 0.32970518465436127`, 0.1885837576575456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 91}], {
             RGBColor[
             0.8839292021421377, 0.5220528575630985, 0.23151925387136146`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 136}], {
             RGBColor[
             0.8590242998049419, 0.4221052615756549, 0.20287901902910677`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 200}], {
             RGBColor[
             0.7633408610929295, 0.4544624230694392, 0.44699591618019946`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 256}], {
             RGBColor[
             0.8509498633138987, 0.5235549531780195, 0.45538444278936224`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 298}], {
             RGBColor[
             0.7891203983542464, 0.4750093414495175, 0.4492866000375796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 434}], {
             RGBColor[
             0.8349696694427251, 0.26979777990945364`, 0.18112030099193344`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 92}], {
             RGBColor[
             0.8261574713547348, 0.8617230188259255, 0.8123362096117437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 110}], {
             RGBColor[
             0.9942182188017068, 0.9900416795816283, 0.6120669814623443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 132}], {
             RGBColor[
             0.8272638065010585, 0.8625872962506922, 0.8124464787598393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 324}], {
             RGBColor[
             0.8764265597457015, 0.4197338062115088, 0.3288646788534969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 342}], {
             RGBColor[
             0.9717076565997078, 0.9127794890046514, 0.46789915194522813`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 360}], {
             RGBColor[
             0.8799904851652522, 0.44712769870825264`, 0.3322774978601368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 457}], {
             RGBColor[
             0.9757033167270259, 0.9283837992580474, 0.47234923862849276`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 494}], {
             RGBColor[
             0.9820130064078103, 0.9838174426313561, 0.7974332766770647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 60}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 73}], {
             RGBColor[
             0.8251129096320492, 0.19403440474490768`, 0.17168145666561216`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 91}], {
             RGBColor[
             0.8662785326994125, 0.38638207765364485`, 0.21461695287942803`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 131}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 136}], {
             RGBColor[
             0.8413736303622167, 0.28643448166620133`, 0.18597671803717333`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 234}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 240}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 434}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 495}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 74}], {
             RGBColor[
             0.2306608517696206, 0.3597695583255239, 0.9364471663249048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 115}], {
             RGBColor[
             0.23557088884486138`, 0.36493031860593317`, 0.9367267856725908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 144}], {
             RGBColor[
             0.24826092960193386`, 0.3782683560366715, 0.9374494647204732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 145}], {
             RGBColor[
             0.27446298131762203`, 0.4058083736958911, 0.9389416328032197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 215}], {
             RGBColor[
             0.22259684759220016`, 0.35129377864765965`, 0.9359879332166258]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 375}], {
             RGBColor[
             0.26089059756321387`, 0.3915429378311758, 0.9381687056269487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 402}], {
             RGBColor[
             0.296247822930254, 0.42468544619728427`, 0.9403294456885352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 417}], {
             RGBColor[
             0.2488046847191422, 0.3788398771409232, 0.9374804307699846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 87}], {
             RGBColor[
             0.7284229725600728, 0.7874364169703292, 0.9739093048334139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 91}], {
             RGBColor[
             0.7833793217020255, 0.7895587302313833, 0.6386349089300231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 188}], {
             RGBColor[
             0.4914195289334753, 0.5960123307393997, 0.9536534579044413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 200}], {
             RGBColor[
             0.6024968101282133, 0.6881730784908944, 0.96184990239328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 228}], {
             RGBColor[
             0.5875720741130268, 0.6760565054420705, 0.9606749725030552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 256}], {
             RGBColor[
             0.7339103134596671, 0.7918118736537649, 0.9744326923070242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 279}], {
             RGBColor[
             0.45332288362562734`, 0.5625839643621962, 0.9512417531661489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 287}], {
             RGBColor[
             0.7202478045060992, 0.7809177598731158, 0.9731295500063672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 298}], {
             RGBColor[
             0.6411661160201888, 0.718993456061012, 0.9652859281793502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 335}], {
             RGBColor[
             0.45879597954340867`, 0.567755451964993, 0.9515747141851782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 409}], {
             RGBColor[
             0.5719438498096561, 0.6633688089091125, 0.9594446614378219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 468}], {
             RGBColor[
             0.48548279693465646`, 0.5908702318708492, 0.9532751745911225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 73}], {
             RGBColor[
             0.8251129096320492, 0.19403440474490768`, 0.17168145666561216`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 131}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.8413736303622167, 0.28643448166620133`, 0.18597671803717333`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 240}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 434}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 495}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 99}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 154}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 178}], {
             RGBColor[
             0.8637848357389819, 0.3779702522582219, 0.20492941108331192`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 186}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 203}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 244}], {
             RGBColor[
             0.8706168078338911, 0.40101609835768304`, 0.23147033256236077`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 264}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 288}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 295}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 321}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 341}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 391}], {
             RGBColor[
             0.8623939674573535, 0.3726044724173211, 0.20303663793067456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 397}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 455}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 96}], {
             RGBColor[
             0.7419154122295191, 0.7443098604712988, 0.6194603335528694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 108}], {
             RGBColor[
             0.4199530900612806, 0.5361218661360846, 0.948544262897387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 110}], {
             RGBColor[
             0.7611613425809955, 0.8086288736350278, 0.7610013636522968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 157}], {
             RGBColor[
             0.6731273937865867, 0.7428277562129042, 0.9692469151984306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 190}], {
             RGBColor[
             0.4365755592180457, 0.5505194134500824, 0.9496034319333838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 356}], {
             RGBColor[
             0.5100962493492036, 0.6131581406526678, 0.9545757917743497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 378}], {
             RGBColor[
             0.4141124561597586, 0.5302263593931105, 0.9482027364763976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 72}], {
             RGBColor[
             0.3088117371325335, 0.4410013587250076, 0.940931053493443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 159}], {
             RGBColor[
             0.3591807092964443, 0.4846284307952361, 0.944140519860194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 166}], {
             RGBColor[
             0.275068039384163, 0.4064443280867228, 0.938976089965006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 222}], {
             RGBColor[
             0.27812742646781496`, 0.4096599378879857, 0.9391503175334623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 239}], {
             RGBColor[
             0.2771411890702042, 0.40862333985203414`, 0.9390941527726759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 272}], {
             RGBColor[
             0.4327060967749962, 0.5452426827083117, 0.9496736717344219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 344}], {
             RGBColor[
             0.2634249915478959, 0.3942067465989362, 0.9383130356150764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 387}], {
             RGBColor[
             0.26044194173333185`, 0.39107137210754717`, 0.9381431553411637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 435}], {
             RGBColor[
             0.37424886655935563`, 0.49767971126876503`, 0.9451006495167384]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 439}], {
             RGBColor[
             0.2827106908529987, 0.41447723935255987`, 0.9394113276598666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 453}], {
             RGBColor[
             0.37845988554305304`, 0.5012031646662531, 0.9454032112758242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 74}], {
             RGBColor[
             0.2126520838133948, 0.3408412013816937, 0.9354215936313823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 115}], {
             RGBColor[
             0.21756212088863558`, 0.346001961662103, 0.9357012129790685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 170}], {
             RGBColor[
             0.2105590287411936, 0.3386412677934538, 0.9353023972414181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 215}], {
             RGBColor[
             0.20458807963597442`, 0.33236542170382943`, 0.9349623605231034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 223}], {
             RGBColor[
             0.2546024393338054, 0.3849336848398083, 0.9378106043182802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 268}], {
             RGBColor[
             0.20747158720625564`, 0.3353961709851344, 0.9351265720134637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 86}], {
             RGBColor[
             0.2018366701530856, 0.3294735158878764, 0.9348056718233985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 177}], {
             RGBColor[
             0.19983486008505225`, 0.32736948658428433`, 0.9346916717014366]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 194}], {
             RGBColor[
             0.2035493121604427, 0.3312736112253837, 0.9349032042520906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 290}], {
             RGBColor[
             0.1936841951962548, 0.32090474781148043`, 0.9343414004351128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 297}], {
             RGBColor[
             0.22326792573678073`, 0.35199912432642566`, 0.9360261501241884]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 350}], {
             RGBColor[
             0.19367927439437493`, 0.3208995757367078, 0.9343411202027254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 412}], {
             RGBColor[
             0.2124844072209095, 0.34066496265168167`, 0.9354120446974956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 484}], {
             RGBColor[
             0.20075983867306346`, 0.3283416977273139, 0.9347443478636406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 114}], {
             RGBColor[
             0.22515212124439515`, 0.35397953326982357`, 0.9361334522709297]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 128}], {
             RGBColor[
             0.2527669820297753, 0.38300450283855814`, 0.9377060777401315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 179}], {
             RGBColor[
             0.26537930167515955`, 0.3962608504531091, 0.9384243306856812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 245}], {
             RGBColor[
             0.3717582052146181, 0.4911621591427741, 0.9452943765065589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 255}], {
             RGBColor[
             0.2590437385722598, 0.38960177193405976`, 0.9380635297395968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 260}], {
             RGBColor[
             0.2863066273900213, 0.4179525885520823, 0.9396272494745492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 294}], {
             RGBColor[
             0.23819891010735164`, 0.3676925355789824, 0.9368764475956806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 299}], {
             RGBColor[
             0.35967789907867415`, 0.4813548224100252, 0.9443433705559179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 312}], {
             RGBColor[
             0.25430218522603054`, 0.38461809873532704`, 0.9377935052910287]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 327}], {
             RGBColor[
             0.23020235366261008`, 0.35928764774459687`, 0.9364210555359976]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 334}], {
             RGBColor[
             0.2368272907421635, 0.366250876660479, 0.936798335901962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 385}], {
             RGBColor[
             0.22541308597049314`, 0.3542538237430719, 0.9361483138260183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 415}], {
             RGBColor[
             0.22292255775669778`, 0.3516361206817638, 0.9360064819286489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 446}], {
             RGBColor[
             0.22940101354262873`, 0.3584453884705983, 0.9363754204016412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 119}], {
             RGBColor[
             0.194730591149065, 0.3220045763032192, 0.9344009911366213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 120}], {
             RGBColor[
             0.1852212022017432, 0.3120096055895012, 0.9338594455039515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 124}], {
             RGBColor[
             0.19699158310389825`, 0.32438102220291876`, 0.9345297512836113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 363}], {
             RGBColor[
             0.19105732048097354`, 0.31814373593224315`, 0.9341918038061905]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 381}], {
             RGBColor[
             0.20330273841305002`, 0.33101444658319545`, 0.9348891622419497]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 95}], {
             RGBColor[
             0.20531946953055227`, 0.3331341588558284, 0.9350040120956051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 286}], {
             RGBColor[
             0.21116729807720058`, 0.3392805974321006, 0.9353370372802498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 319}], {
             RGBColor[
             0.19709684259875715`, 0.3244916566058529, 0.9345357456561258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 330}], {
             RGBColor[
             0.2158728859753908, 0.3442264686646032, 0.9356050135497582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 352}], {
             RGBColor[
             0.20254407979161715`, 0.33021704827033466`, 0.934845957755794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 357}], {
             RGBColor[
             0.2136408209972711, 0.34188042685150594`, 0.9354779007512986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 367}], {
             RGBColor[
             0.2321744218168602, 0.3613604164110565, 0.9365333618999687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 368}], {
             RGBColor[
             0.19358411070805037`, 0.32079955266865445`, 0.9343357007715714]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 375}], {
             RGBColor[
             0.24422058989824297`, 0.3740217028357595, 0.9372193733514949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 450}], {
             RGBColor[
             0.27333525861175023`, 0.40175722238859823`, 0.9389823432231943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 492}], {
             RGBColor[
             0.20085698845876193`, 0.32844380831173514`, 0.9347498804002159]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 101}], {
             RGBColor[
             0.7358996157457895, 0.7730701996070706, 0.6676735904233504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 103}], {
             RGBColor[
             0.9879088198511304, 0.969706918546636, 0.5069176030846314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 129}], {
             RGBColor[
             0.870930679966885, 0.8808856413310856, 0.6795404574101209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 204}], {
             RGBColor[
             0.9308314245530096, 0.9281676018500284, 0.6853815574337436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 209}], {
             RGBColor[
             0.8720195914369621, 0.405748016840095, 0.23691988196683633`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 231}], {
             RGBColor[
             0.8720195914369621, 0.405748016840095, 0.23691988196683633`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 233}], {
             RGBColor[
             0.8720195914369621, 0.405748016840095, 0.23691988196683633`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 259}], {
             RGBColor[
             0.8720195914369621, 0.405748016840095, 0.23691988196683633`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 275}], {
             RGBColor[
             0.9574349696021127, 0.8614225983065917, 0.32381674285302947`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 306}], {
             RGBColor[
             0.7222846470752082, 0.7620169546929436, 0.6666017702163287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 331}], {
             RGBColor[
             0.9044576421525903, 0.9071378636611861, 0.6828660025242381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 346}], {
             RGBColor[
             0.9822051197373862, 0.9516358318169333, 0.3853706797712563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 348}], {
             RGBColor[
             0.9720780588899567, 0.9174748776315893, 0.3460289607139636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 355}], {
             RGBColor[
             0.8983352152225895, 0.6080214328363002, 0.2621197530231993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 372}], {
             RGBColor[
             0.8720195914369621, 0.405748016840095, 0.23691988196683633`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 404}], {
             RGBColor[
             0.8720195914369621, 0.405748016840095, 0.23691988196683633`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 418}], {
             RGBColor[
             0.9649838420823031, 0.8913513621779137, 0.32989074284540154`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 431}], {
             RGBColor[
             0.9874348778681517, 0.9686932045679294, 0.4553319430682715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 444}], {
             RGBColor[
             0.894494185245962, 0.578497593285873, 0.2584415783797579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 486}], {
             RGBColor[
             0.9877626572953866, 0.9693942916192012, 0.4910087109026512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 76}], {
             RGBColor[
             0.98996116143335, 0.9893085275125257, 0.7572877100420445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 111}], {
             RGBColor[
             0.985056438314053, 0.9880884674579122, 0.8973170200414953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 130}], {
             RGBColor[
             0.9093854335224396, 0.9290669367355356, 0.9363199027732196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 175}], {
             RGBColor[
             0.9901922146655133, 0.990212242962673, 0.8122039149346538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 182}], {
             RGBColor[
             0.9700359047903209, 0.9769432873298111, 0.9253003310773291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 208}], {
             RGBColor[
             0.9892910387748346, 0.9878752029057549, 0.6843489941803045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[
             0.9610594005806091, 0.8872098489096947, 0.5782429967897421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 351}], {
             RGBColor[
             0.7225448589609941, 0.7801979166455426, 0.9196407548248287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 359}], {
             RGBColor[
             0.8734050425786691, 0.4188525953049994, 0.40570794960622847`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 371}], {
             RGBColor[
             0.7661132779111547, 0.8155687218841894, 0.9230706203609627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 403}], {
             RGBColor[
             0.8734050425786691, 0.4188525953049994, 0.40570794960622847`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 442}], {
             RGBColor[
             0.7163330593542951, 0.7749857656872733, 0.9191984709357774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 463}], {
             RGBColor[
             0.9027643566949051, 0.6383284302508672, 0.43357997062744724`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 483}], {
             RGBColor[
             0.9784993022017803, 0.9517819287687919, 0.6160830557918804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 135}], {
             RGBColor[
             0.2217446900292419, 0.3503981070190804, 0.9359394041040694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 153}], {
             RGBColor[
             0.3288978182766464, 0.4547857321627663, 0.9423432170599901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 169}], {
             RGBColor[
             0.22996457913520382`, 0.3590377316405171, 0.9364075146284178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 172}], {
             RGBColor[
             0.3189558573582081, 0.44617450531270014`, 0.941709724101598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 197}], {
             RGBColor[
             0.33670866645889475`, 0.4615510962735853, 0.9428409173993011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 201}], {
             RGBColor[
             0.41387149855588806`, 0.5252776228187356, 0.9486164256235639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 211}], {
             RGBColor[
             0.23787031413452003`, 0.3673471603773484, 0.936857734541142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 236}], {
             RGBColor[
             0.2828326524801393, 0.4146054287554984, 0.9394182731941062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 289}], {
             RGBColor[
             0.2867699726445978, 0.4182967096833736, 0.9396588679885072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 308}], {
             RGBColor[
             0.24523893977810896`, 0.3750920531266102, 0.9372773668706396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 362}], {
             RGBColor[
             0.22011006608812847`, 0.34868001361582635`, 0.9358463146888325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 369}], {
             RGBColor[
             0.22611899076607778`, 0.3549957744401804, 0.9361885140598343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 466}], {
             RGBColor[
             0.25381484638134433`, 0.3841058747104944, 0.937765752064777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 470}], {
             RGBColor[
             0.2532282244104237, 0.3834892978250757, 0.9377323448113625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 493}], {
             RGBColor[
             0.4247009633868117, 0.5340694702303104, 0.9494689607646909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 128}], {
             RGBColor[
             0.28177127381369815`, 0.4125801173125145, 0.9393911391102159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 159}], {
             RGBColor[
             0.3689545388465866, 0.49399161017976106`, 0.9447304348549841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 179}], {
             RGBColor[
             0.2943835934590824, 0.4258364649270654, 0.9401093920557657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 222}], {
             RGBColor[
             0.28790125601795724`, 0.4190231172725106, 0.9397402325282525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 245}], {
             RGBColor[
             0.40076249699854094`, 0.5207377736167305, 0.9469794378766433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 294}], {
             RGBColor[
             0.2672032018912745, 0.39726815005293875`, 0.938561508965765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 344}], {
             RGBColor[
             0.27319882109803817`, 0.4035699259834611, 0.9389029506098664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 438}], {
             RGBColor[
             0.29983207958869507`, 0.43156316930326144`, 0.9404196752805343]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 439}], {
             RGBColor[
             0.292484520403141, 0.4238404187370848, 0.9400012426546567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 453}], {
             RGBColor[
             0.3882337150931953, 0.510566344050778, 0.9459931262706142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 91}], {
             RGBColor[
             0.8818663519635108, 0.5061968871434602, 0.22954386621065234`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 136}], {
             RGBColor[
             0.856961449626315, 0.4062492911560167, 0.20090363136839764`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 200}], {
             RGBColor[
             0.7612780109143027, 0.4386064526498009, 0.44502052851949037`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 240}], {
             RGBColor[
             0.8329068192640983, 0.2539418094898154, 0.17914491333122431`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 256}], {
             RGBColor[
             0.8488870131352718, 0.5076989827583813, 0.45340905512865315`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 298}], {
             RGBColor[
             0.7870575481756196, 0.4591533710298793, 0.44731121237687044`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 434}], {
             RGBColor[
             0.8329068192640983, 0.2539418094898154, 0.17914491333122431`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 115}], {
             RGBColor[
             0.22596376247749395`, 0.3548326196668369, 0.936179674038439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 144}], {
             RGBColor[
             0.23865380323456642`, 0.36817065709757524`, 0.9369023530863214]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 215}], {
             RGBColor[
             0.21298972122483276`, 0.3411960797085633, 0.935440821582474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 268}], {
             RGBColor[
             0.21587322879511397`, 0.3442268289898683, 0.9356050330728343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 402}], {
             RGBColor[
             0.28664069656288654`, 0.4145877472581879, 0.9397823340543834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 417}], {
             RGBColor[
             0.23919755835177475`, 0.36874217820182686`, 0.9369333191358328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 104}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 125}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 147}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 303}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 310}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 323}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 379}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 400}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 408}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 111}], {
             RGBColor[
             0.9894404720113958, 0.9890932090554398, 0.7659168812648544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 130}], {
             RGBColor[
             0.9137694672197825, 0.9300716783330631, 0.8049197639965786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 175}], {
             RGBColor[
             0.994576248362856, 0.9912169845602006, 0.6808037761580129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.9744199384876636, 0.9779480289273386, 0.7939001923006881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 351}], {
             RGBColor[
             0.7269288926583368, 0.7812026582430701, 0.7882406160481877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 359}], {
             RGBColor[
             0.8763277317102309, 0.4195224230366844, 0.31810785708846784`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 371}], {
             RGBColor[
             0.7704973116084974, 0.816573463481717, 0.7916704815843216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 460}], {
             RGBColor[
             0.9094586655152967, 0.9266343620675013, 0.8045085958817066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 463}], {
             RGBColor[
             0.9056870458264669, 0.638998257982552, 0.34597987810968656`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 483}], {
             RGBColor[
             0.982883335899123, 0.9527866703663195, 0.4846829170152394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 87}], {
             RGBColor[
             0.896783278694488, 0.9204422732959663, 0.9868140728389698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 184}], {
             RGBColor[
             0.9077974773796862, 0.7427431675399421, 0.6030848086881719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 253}], {
             RGBColor[
             0.9637096810052588, 0.9717997951686592, 0.9169584807873504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 287}], {
             RGBColor[
             0.8886081106405144, 0.9139236161987528, 0.9860343180119231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 301}], {
             RGBColor[
             0.8579732191915481, 0.4074969800510354, 0.43870016507762466`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 336}], {
             RGBColor[
             0.8579732191915481, 0.4074969800510354, 0.43870016507762466`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 354}], {
             RGBColor[
             0.9005988329718047, 0.9234846927062367, 0.9871780038121258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 388}], {
             RGBColor[
             0.9318009699728012, 0.9483644297913851, 0.9901540914937574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 409}], {
             RGBColor[
             0.7403041559440713, 0.7963746652347496, 0.9723494294433779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 436}], {
             RGBColor[
             0.9544907386391261, 0.9655798479084123, 0.9619194881543456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 473}], {
             RGBColor[
             0.7727967287954887, 0.8227535996492561, 0.9749073638024577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 154}], {
             RGBColor[
             0.863576315147662, 0.3772668633407367, 0.20411934796184356`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 171}], {
             RGBColor[
             0.9557437848802708, 0.8622080495874132, 0.28344566235844504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 192}], {
             RGBColor[
             0.9131433471019068, 0.8814405377612413, 0.6357016426534479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.9735420588312775, 0.9270450247585778, 0.5414260096688857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 219}], {
             RGBColor[
             0.863576315147662, 0.3772668633407367, 0.20411934796184356`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 258}], {
             RGBColor[
             0.9750213117175937, 0.926509082881858, 0.43348885156620276`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 262}], {
             RGBColor[
             0.953970946509212, 0.9135788430387926, 0.625155004871462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 376}], {
             RGBColor[
             0.9710596774572359, 0.9260184962661202, 0.5825654932338206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 497}], {
             RGBColor[
             0.9513305032138845, 0.844710858419126, 0.2798946323366356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 127}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 147}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 184}], {
             RGBColor[
             0.8369837657282427, 0.2665011316422593, 0.18231370738115665`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 221}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 234}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 253}], {
             RGBColor[
             0.8742585681452911, 0.4192055500614041, 0.39156282211394233`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 301}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 316}], {
             RGBColor[
             0.8735231410973765, 0.4108198428949215, 0.24276088847601782`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 336}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 388}], {
             RGBColor[
             0.8529860941236527, 0.4035819731432213, 0.44035989591821356`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 436}], {
             RGBColor[
             0.8681126065678694, 0.4150589185545728, 0.4215368270252724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 81}], {
             RGBColor[
             0.7036249157342768, 0.7658688297445426, 0.9529221476556539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 171}], {
             RGBColor[
             0.9566931052658137, 0.9145293959267929, 0.61948306634346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 192}], {
             RGBColor[
             0.9140926674874497, 0.9337618841006211, 0.9717390466384628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 208}], {
             RGBColor[
             0.9754972680138669, 0.9778179512987408, 0.718003495698742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 219}], {
             RGBColor[
             0.8642091954046907, 0.41214776090032323`, 0.42814428395185355`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 238}], {
             RGBColor[
             0.9472656298196414, 0.8771525973026804, 0.6118974983081796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 251}], {
             RGBColor[
             0.7049995072728927, 0.7670594318463122, 0.9530097354129909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 258}], {
             RGBColor[
             0.9759706321031365, 0.9788304292212378, 0.7695262555512177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 272}], {
             RGBColor[
             0.7621819360908365, 0.8135182343885552, 0.9575015284128756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 293}], {
             RGBColor[
             0.8642091954046907, 0.41214776090032323`, 0.42814428395185355`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 403}], {
             RGBColor[
             0.8642091954046907, 0.41214776090032323`, 0.42814428395185355`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 447}], {
             RGBColor[
             0.6925262053653484, 0.7562556846603798, 0.95221494764515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 471}], {
             RGBColor[
             0.8642091954046907, 0.41214776090032323`, 0.42814428395185355`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 483}], {
             RGBColor[
             0.9647055314408126, 0.9417246771617777, 0.6497375573103179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 497}], {
             RGBColor[
             0.9522798235994274, 0.8970322047585058, 0.6159320363216505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 121}], {
             RGBColor[
             0.3705335839034893, 0.4937931661956242, 0.9448883940271157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.6412269922816769, 0.7166892321720943, 0.9668997000917505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 208}], {
             RGBColor[
             0.7211325975340719, 0.7754974983423137, 0.7149287914988354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 213}], {
             RGBColor[
             0.3642555391877909, 0.48719454314839994`, 0.9445308686680915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 251}], {
             RGBColor[
             0.4506348367930976, 0.5647389788898851, 0.9499350312130843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 442}], {
             RGBColor[
             0.44817461811353243`, 0.562608061123832, 0.9497782682543083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 447}], {
             RGBColor[
             0.4381615348855533, 0.5539352317039529, 0.9491402434452434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 454}], {
             RGBColor[
             0.38458547196747705`, 0.5075303388155344, 0.9457264240915557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 500}], {
             RGBColor[
             0.3616089991347435, 0.484412861752316, 0.9443801521272757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 126}], {
             RGBColor[
             0.916199280091377, 0.7036541810826651, 0.25133650057422957`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 149}], {
             RGBColor[
             0.8696222340143458, 0.4946976853386944, 0.21268036640365176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 173}], {
             RGBColor[
             0.844192723800754, 0.2992353265545988, 0.18832903870459236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 242}], {
             RGBColor[
             0.844192723800754, 0.2992353265545988, 0.18832903870459236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 249}], {
             RGBColor[
             0.844192723800754, 0.2992353265545988, 0.18832903870459236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 269}], {
             RGBColor[
             0.844192723800754, 0.2992353265545988, 0.18832903870459236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 282}], {
             RGBColor[
             0.844192723800754, 0.2992353265545988, 0.18832903870459236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 323}], {
             RGBColor[
             0.844192723800754, 0.2992353265545988, 0.18832903870459236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 384}], {
             RGBColor[
             0.7661799454534821, 0.6717707570486016, 0.6004570534353222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 411}], {
             RGBColor[
             0.805124727752193, 0.7023163366231125, 0.604255553355253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 419}], {
             RGBColor[
             0.844192723800754, 0.2992353265545988, 0.18832903870459236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 499}], {
             RGBColor[
             0.844192723800754, 0.2992353265545988, 0.18832903870459236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 97}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 163}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 207}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 209}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 231}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 233}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 257}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 317}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 326}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 343}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 346}], {
             RGBColor[
             0.8725424883879621, 0.4075118710378607, 0.23895123788066785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 355}], {
             RGBColor[
             0.8304768118928137, 0.23526370799810264`, 0.17681793552818148`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 395}], {
             RGBColor[
             0.8502020870562027, 0.32426772933006165`, 0.19322676477969444`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 440}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 89}], {
             RGBColor[
             0.7687714356170879, 0.8196030224681695, 0.9775043726151027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 176}], {
             RGBColor[
             0.7812728109768734, 0.8295712798392683, 0.9786967649570286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 244}], {
             RGBColor[
             0.8279818714648165, 0.8418796258010216, 0.6672951219910502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 245}], {
             RGBColor[
             0.580845373371183, 0.6700379828264612, 0.960526576780036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 260}], {
             RGBColor[
             0.49539379554658625`, 0.5968284122357694, 0.9548594497480263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 261}], {
             RGBColor[
             0.802578407870131, 0.8465597844769306, 0.9807289118084384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 262}], {
             RGBColor[
             0.8153011335016991, 0.8562880262921846, 0.9675016060762058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 299}], {
             RGBColor[
             0.5687650672352391, 0.6602306460937123, 0.9595755708293949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 328}], {
             RGBColor[
             0.5779012816849092, 0.667647836565725, 0.9602948070979291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 376}], {
             RGBColor[
             0.832389864449723, 0.8687276795195121, 0.9249120944385643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 391}], {
             RGBColor[
             0.8156476109000103, 0.7992621868904787, 0.624644580043521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 407}], {
             RGBColor[
             0.6835079427609747, 0.7526808668284215, 0.9690893420556808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 448}], {
             RGBColor[
             0.7514898127927288, 0.8058231255251804, 0.9758560360026285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 455}], {
             RGBColor[
             0.7711297731426533, 0.3390729855096647, 0.43235041543167274`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 475}], {
             RGBColor[
             0.810505150868455, 0.8527111902970119, 0.9756199536816843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 478}], {
             RGBColor[
             0.5977451472226231, 0.6837579805651962, 0.9618569888835327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 482}], {
             RGBColor[
             0.8075023357681443, 0.8504716957118587, 0.9807029363869016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 146}], {
             RGBColor[
             0.199363430421074, 0.32687398411707613`, 0.9346648244794907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 166}], {
             RGBColor[
             0.23298059512902075`, 0.36220775567647745`, 0.9365792722774698]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 239}], {
             RGBColor[
             0.23505374481506194`, 0.3643867674417887, 0.9366973350851397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 332}], {
             RGBColor[
             0.21348039489620751`, 0.3417118088476858, 0.9354687647221722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 387}], {
             RGBColor[
             0.2183544974781896, 0.34683479969730174`, 0.9357463376536275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 489}], {
             RGBColor[
             0.2242348495004033, 0.3530154225085005, 0.9360812150020913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 177}], {
             RGBColor[
             0.204427895244704, 0.3321970577523273, 0.9349532382589922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 194}], {
             RGBColor[
             0.20814234732009446`, 0.3361011823934266, 0.9351647708096462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 220}], {
             RGBColor[
             0.2767001990541243, 0.4046256973632345, 0.9391984410025577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 254}], {
             RGBColor[
             0.2217593415229328, 0.3504135066679079, 0.9359402384849602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 290}], {
             RGBColor[
             0.1982772303559066, 0.32573231897952337`, 0.9346029669926684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 297}], {
             RGBColor[
             0.22786096089643254`, 0.35682669549446866`, 0.936287716681744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 350}], {
             RGBColor[
             0.19827230955402672`, 0.32572714690475074`, 0.934602686760281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 377}], {
             RGBColor[
             0.19669430319698816`, 0.3240685621721215, 0.9345128216326989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 412}], {
             RGBColor[
             0.2170774423805613, 0.34549253381972456`, 0.9356736112550512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 426}], {
             RGBColor[
             0.2108343428642681, 0.3389306403927288, 0.9353180759734364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 476}], {
             RGBColor[
             0.2023767546336836, 0.3300411789203187, 0.9348364288355852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 91}], {
             RGBColor[
             0.9092412489562847, 0.8887699196998804, 0.6506892545416749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 161}], {
             RGBColor[
             0.5929939478905595, 0.674186901246545, 0.9641602249639974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 184}], {
             RGBColor[
             0.86529909849953, 0.7089485006828021, 0.6022343862942678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 228}], {
             RGBColor[
             0.713434001367286, 0.7752676949105676, 0.9727293181147071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 253}], {
             RGBColor[
             0.9212113021251026, 0.9380051283115193, 0.9161080583934463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 256}], {
             RGBColor[
             0.8597722407139262, 0.891023063122262, 0.9864870379186761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 285}], {
             RGBColor[
             0.5942823297173198, 0.6753028328289313, 0.9642423195147274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 287}], {
             RGBColor[
             0.8461097317603583, 0.8801289493416129, 0.985183895618019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 336}], {
             RGBColor[
             0.8296409666047774, 0.38496720214627544`, 0.43813321681502193`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 354}], {
             RGBColor[
             0.8581004540916486, 0.8896900258490967, 0.9863275814182217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 388}], {
             RGBColor[
             0.8893025910926451, 0.9145697629342451, 0.9893036690998533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 409}], {
             RGBColor[
             0.6978057770639152, 0.7625799983776096, 0.9714990070494738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 436}], {
             RGBColor[
             0.9119923597589701, 0.9317851810512723, 0.9610690657604415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 473}], {
             RGBColor[
             0.7302983499153326, 0.788958932792116, 0.9740569414085536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 133}], {
             RGBColor[
             0.24286224712593307`, 0.37259399845815566`, 0.9371420177400999]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 241}], {
             RGBColor[
             0.28248141588286296`, 0.41132455172417753`, 0.9395048825764732]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 271}], {
             RGBColor[
             0.2646478400333292, 0.39549203789019866`, 0.9383826750272796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 304}], {
             RGBColor[
             0.22720116780943558`, 0.35613321112673696`, 0.9362501424415159]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 307}], {
             RGBColor[
             0.2294926966396743, 0.3585417532186373, 0.9363806416183849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 311}], {
             RGBColor[
             0.22564091581509077`, 0.3544932873549904, 0.936161288398624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 337}], {
             RGBColor[
             0.22370546244709866`, 0.3524590031503995, 0.9360510671925635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 423}], {
             RGBColor[
             0.20241340429212143`, 0.33007970003505943`, 0.9348385159794148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 427}], {
             RGBColor[
             0.21816644071600988`, 0.3466371401167634, 0.9357356280992264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 433}], {
             RGBColor[
             0.20558699861107904`, 0.3334153488817855, 0.9350192474809674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 465}], {
             RGBColor[
             0.20208905675330635`, 0.3297387902069431, 0.9348200448669085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 469}], {
             RGBColor[
             0.20704962369398588`, 0.33495266057970696`, 0.9351025418156791]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 176}], {
             RGBColor[
             0.8712929271660014, 0.9002093457784437, 0.9875858912771132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 178}], {
             RGBColor[
             0.9077540295115808, 0.8779489225910053, 0.6363728660925616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 244}], {
             RGBColor[
             0.9180019876539445, 0.912517691740197, 0.6761842483111349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 261}], {
             RGBColor[
             0.8925985240592591, 0.917197850416106, 0.989618038128523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 262}], {
             RGBColor[
             0.905321249690827, 0.92692609223136, 0.9763907323962904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 299}], {
             RGBColor[
             0.6587851834243671, 0.7308687120328877, 0.9684646971494795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 328}], {
             RGBColor[
             0.6679213978740371, 0.7382859025049004, 0.9691839334180138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 376}], {
             RGBColor[
             0.9224099806388508, 0.9393657454586876, 0.9338012207586489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 391}], {
             RGBColor[
             0.9056677270891382, 0.8699002528296541, 0.6335337063636055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 407}], {
             RGBColor[
             0.7735280589501026, 0.8233189327675969, 0.9779784683757653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 448}], {
             RGBColor[
             0.8415099289818567, 0.8764611914643559, 0.9847451623227131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 455}], {
             RGBColor[
             0.8311431839354053, 0.386165029469115, 0.43827649964506243`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 475}], {
             RGBColor[
             0.900525267057583, 0.9233492562361874, 0.984509080001769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 478}], {
             RGBColor[
             0.687765263411751, 0.7543960465043716, 0.9707461152036172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 482}], {
             RGBColor[
             0.8975224519572722, 0.9211097616510341, 0.9895920627069863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 137}], {
             RGBColor[
             0.45984500856407784`, 0.5687739133839165, 0.9516112068287906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 148}], {
             RGBColor[
             0.6360400198232251, 0.7149269386277152, 0.9648173774964799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 229}], {
             RGBColor[
             0.5154543184856579, 0.616939902632804, 0.9551545828836118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 232}], {
             RGBColor[
             0.6473094528464778, 0.7237307053563433, 0.9659406092613985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 263}], {
             RGBColor[
             0.4902638758215754, 0.5951212073056378, 0.9535494701520902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 267}], {
             RGBColor[
             0.5020615308844408, 0.6053397431537071, 0.9543012063004392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 280}], {
             RGBColor[
             0.5706742857728803, 0.6623381196308499, 0.9593447167062806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 342}], {
             RGBColor[
             0.7736445823202994, 0.759776227926813, 0.6195883744105202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 393}], {
             RGBColor[
             0.483014768717581, 0.588842395082875, 0.9530875634575574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 480}], {
             RGBColor[
             0.5389584272669072, 0.6365897569125576, 0.9568479281456727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 485}], {
             RGBColor[
             0.5765425629929836, 0.6671022514410058, 0.9598066889852549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 200}], {
             RGBColor[
             0.7833150865244253, 0.7895065812204456, 0.6386298521015412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 228}], {
             RGBColor[
             0.7683903505092387, 0.7773900081716217, 0.6374549222113163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 256}], {
             RGBColor[
             0.914728589855879, 0.8931453763833161, 0.6512126420152853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 287}], {
             RGBColor[
             0.901066080902311, 0.8822512626026671, 0.6499094997146282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 298}], {
             RGBColor[
             0.8219843924164008, 0.8203269587905632, 0.6420658778876114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 336}], {
             RGBColor[
             0.8662785326994125, 0.38638207765364485`, 0.21461695287942806`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 132}], {
             RGBColor[
             0.6587795986186888, 0.7333628964420915, 0.9666246518110923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 250}], {
             RGBColor[
             0.5085778888955018, 0.6091430188143863, 0.955320634245421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 342}], {
             RGBColor[
             0.8032234487173383, 0.7835550891960509, 0.622077324996481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 356}], {
             RGBColor[
             0.5746689176875454, 0.6653465467906676, 0.9598195826356501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 365}], {
             RGBColor[
             0.4788564599632421, 0.5825948499682702, 0.9534562846389698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 457}], {
             RGBColor[
             0.8072191088446563, 0.7991593994494468, 0.6265274116797456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 485}], {
             RGBColor[
             0.6061214293900224, 0.6908811127102437, 0.9622956395712158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 494}], {
             RGBColor[
             0.8135287985254407, 0.8545930428227555, 0.9516114497283175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 141}], {
             RGBColor[
             0.3375011498141227, 0.46604896981814714`, 0.9427518573592213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 151}], {
             RGBColor[
             0.3297566159868596, 0.4579089737338883, 0.9423108176147698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 160}], {
             RGBColor[
             0.41434048219955033`, 0.5332607321432926, 0.9476339644047369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 167}], {
             RGBColor[
             0.41563984784251484`, 0.5343156157080063, 0.9477362552278843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 172}], {
             RGBColor[
             0.3758866189646938, 0.4999958295615881, 0.9451721408703121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 201}], {
             RGBColor[
             0.4708022601623738, 0.5790989470676235, 0.9520788423922779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 218}], {
             RGBColor[
             0.5568185669726924, 0.6474379222816083, 0.9598710907741307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 235}], {
             RGBColor[
             0.3605980717626268, 0.48675365839988305`, 0.9441979681617279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 236}], {
             RGBColor[
             0.339763414086625, 0.46842675300438635`, 0.9428806899628203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 274}], {
             RGBColor[
             0.4288787771490915, 0.545063574926054, 0.948778472238694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 284}], {
             RGBColor[
             0.3364698481712808, 0.4649650064032194, 0.9426931262563356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 289}], {
             RGBColor[
             0.3437007342510835, 0.4721180339322616, 0.9431212847572212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 300}], {
             RGBColor[
             0.3959649652472733, 0.5173866839445316, 0.9464515153408535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 305}], {
             RGBColor[
             0.6178108662440276, 0.6954235689523357, 0.9658605386388516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 308}], {
             RGBColor[
             0.30216970138459465`, 0.4289133773754982, 0.9407397836393536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 389}], {
             RGBColor[
             0.31082135500600144`, 0.43800681387811885`, 0.9412324825141183]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 432}], {
             RGBColor[
             0.5726032211042509, 0.6597690140569965, 0.961444357581985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 456}], {
             RGBColor[
             0.31230759322488866`, 0.43956894447911504`, 0.9413171215819914]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 493}], {
             RGBColor[
             0.4816317249932974, 0.5878907944791983, 0.952931377533405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 123}], {
             RGBColor[
             0.19382981247906908`, 0.3210578008083872, 0.9343496931239477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 139}], {
             RGBColor[
             0.18683641908668117`, 0.31370730094623644`, 0.9339514297160496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 158}], {
             RGBColor[
             0.20645253428145324`, 0.3343250817494799, 0.9350685384569499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 193}], {
             RGBColor[
             0.18322775270743138`, 0.3099143637789815, 0.9337459215042947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 401}], {
             RGBColor[
             0.1828044456707124, 0.3094694412441735, 0.9337218147947803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 410}], {
             RGBColor[
             0.18607999806105058`, 0.3129122544884356, 0.9339083526576646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 428}], {
             RGBColor[
             0.19798131880027114`, 0.3254212971726742, 0.9345861152673369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 437}], {
             RGBColor[
             0.18537229810347358`, 0.3121684169622533, 0.9338680501920288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 122}], {
             RGBColor[
             0.20586015494572685`, 0.3337024535086123, 0.935034803330127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 185}], {
             RGBColor[
             0.262167272695942, 0.39178664192053536`, 0.9382816194928008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 212}], {
             RGBColor[
             0.19782060647564204`, 0.3252523783297391, 0.9345769629382018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 224}], {
             RGBColor[
             0.24948593288589618`, 0.37955591215781015`, 0.9375192268452648]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 286}], {
             RGBColor[
             0.2095588048007067, 0.3375899690141414, 0.935245435967706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 319}], {
             RGBColor[
             0.19548834932226328`, 0.3228010281878937, 0.9344441443435821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 330}], {
             RGBColor[
             0.2142643926988969, 0.3425358402466441, 0.9355134122372144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 357}], {
             RGBColor[
             0.21203232772077724`, 0.3401897984335468, 0.9353862994387547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 367}], {
             RGBColor[
             0.2305659285403663, 0.35966978799309735`, 0.936441760587425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 368}], {
             RGBColor[
             0.19197561743155647`, 0.3191089242506953, 0.9342440994590275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 492}], {
             RGBColor[
             0.19924849518226806`, 0.326753179893776, 0.9346582790876721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 110}], {
             RGBColor[
             0.9745488280148329, 0.9248169273650014, 0.4244348962647706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 136}], {
             RGBColor[
             0.9223928943750033, 0.7257736795999382, 0.2561940101384317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.886514879220424, 0.8590158099428777, 0.6326804478109045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 240}], {
             RGBColor[
             0.8633136325544521, 0.3762506380670908, 0.20377662205511446`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 360}], {
             RGBColor[
             0.8668775579740029, 0.4036445305638346, 0.2071894410617543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 457}], {
             RGBColor[
             0.956033925940152, 0.8631590470414205, 0.284717153430919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 163}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 207}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 209}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 231}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 233}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 257}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 281}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 317}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 322}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 326}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 343}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 355}], {
             RGBColor[
             0.8304768118928137, 0.23526370799810264`, 0.17681793552818148`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 395}], {
             RGBColor[
             0.8502020870562027, 0.32426772933006165`, 0.19322676477969444`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 440}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 105}], {
             RGBColor[
             0.22603623939872042`, 0.3549087975063481, 0.9361838014918828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 276}], {
             RGBColor[
             0.2749015720573606, 0.4042586138049795, 0.9390402331787011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 347}], {
             RGBColor[
             0.251130504754864, 0.38128446146397427`, 0.9376128827802765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 382}], {
             RGBColor[
             0.27123479538503203`, 0.4010826361489628, 0.9388065894115436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 425}], {
             RGBColor[
             0.21581332835072858`, 0.34416386982491176`, 0.9356016218311414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 462}], {
             RGBColor[
             0.22311090923146282`, 0.35183409002391514`, 0.9360172082664957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 131}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 143}], {
             RGBColor[
             0.8239416059032, 0.18503125101640663`, 0.1705598148920679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 178}], {
             RGBColor[
             0.8637848357389819, 0.3779702522582219, 0.20492941108331192`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 186}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 277}], {
             RGBColor[
             0.8718851812720558, 0.40529461979285863`, 0.23639772385740537`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 288}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 295}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 313}], {
             RGBColor[
             0.8708575836519874, 0.41710611796942054`, 0.41689029682654455`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 321}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 341}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 373}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 498}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 203}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 257}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 264}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 281}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 324}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 360}], {
             RGBColor[
             0.8191009627097754, 0.1478239462483719, 0.1659244095033199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 374}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 397}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 457}], {
             RGBColor[
             0.8638009847389825, 0.3780247266271895, 0.20499214689883155`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 103}], {
             RGBColor[
             0.7423876612860338, 0.7937870676334219, 0.792267547607473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 129}], {
             RGBColor[
             0.6254095214017883, 0.7049657904178714, 0.9648904019329624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[
             0.6853102659879131, 0.7522477509368144, 0.9707315019565851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 276}], {
             RGBColor[
             0.41043620356290245`, 0.5289146649262826, 0.9476516475428687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 306}], {
             RGBColor[
             0.4767634885101116, 0.5860971037797296, 0.9519517147391703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 331}], {
             RGBColor[
             0.6589364835874938, 0.7312180127479719, 0.9682159470470796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 347}], {
             RGBColor[
             0.38666513626040583`, 0.5059405125852774, 0.9462242971444441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 390}], {
             RGBColor[
             0.5242582957488938, 0.6246555279128561, 0.9556906799442186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 431}], {
             RGBColor[
             0.7419137193030552, 0.7927733536547152, 0.740681887591113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 486}], {
             RGBColor[
             0.7422414987302901, 0.793474440705987, 0.7763586554254926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 134}], {
             RGBColor[
             0.23432084769928213`, 0.3636164461047431, 0.9366555976786202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 174}], {
             RGBColor[
             0.24152702065256443`, 0.3711905907763972, 0.937065978567732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 210}], {
             RGBColor[
             0.2588571240715909, 0.389405628261814, 0.9380529023198552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 225}], {
             RGBColor[
             0.23396295286916968`, 0.3632402759464521, 0.9366352160975032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 247}], {
             RGBColor[
             0.23463961323959567`, 0.36395148889851525`, 0.9366737509045697]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 252}], {
             RGBColor[
             0.2303914914496485, 0.3594864435508025, 0.9364318266531653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 278}], {
             RGBColor[
             0.23503759534630753`, 0.36436979332619235`, 0.9366964153967852]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 309}], {
             RGBColor[
             0.24307505381461134`, 0.3728176717806799, 0.9371541367662009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 383}], {
             RGBColor[
             0.4499159059433277, 0.5554178997074893, 0.951374070302039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 393}], {
             RGBColor[
             0.3174055972642307, 0.4455102820141783, 0.9415860984428273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 451}], {
             RGBColor[
             0.2794536000934562, 0.411053830452799, 0.9392258411595447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 480}], {
             RGBColor[
             0.373349255813557, 0.49325764384386095`, 0.9453464631309425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 129}], {
             RGBColor[
             0.8774187255071293, 0.9016025093574369, 0.8041344145942433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 204}], {
             RGBColor[
             0.9373194700932539, 0.9488844698763799, 0.809975514617866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 209}], {
             RGBColor[
             0.8763449551304583, 0.4195592621909958, 0.3199825200895846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 231}], {
             RGBColor[
             0.8763449551304583, 0.4195592621909958, 0.3199825200895846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 233}], {
             RGBColor[
             0.8763449551304583, 0.4195592621909958, 0.3199825200895846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 259}], {
             RGBColor[
             0.8763449551304583, 0.4195592621909958, 0.3199825200895846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 275}], {
             RGBColor[
             0.963923015142357, 0.882139466332943, 0.4484107000371519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 326}], {
             RGBColor[
             0.8763449551304583, 0.4195592621909958, 0.3199825200895846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 346}], {
             RGBColor[
             0.9886931652776305, 0.9723526998432848, 0.5099646369553787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 348}], {
             RGBColor[
             0.978566104430201, 0.9381917456579405, 0.470622917898086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 355}], {
             RGBColor[
             0.9026605789160858, 0.621832678187201, 0.34518239114594756`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 390}], {
             RGBColor[
             0.7762674998542347, 0.8212922468524215, 0.7949346926054996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 404}], {
             RGBColor[
             0.8763449551304583, 0.4195592621909958, 0.3199825200895846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 431}], {
             RGBColor[
             0.9939229234083959, 0.9894100725942807, 0.579925900252394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 443}], {
             RGBColor[
             0.8728831239162906, 0.898059262922825, 0.8036823482152753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 444}], {
             RGBColor[
             0.8988195489394581, 0.5923088386367739, 0.34150421650250623`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 486}], {
             RGBColor[
             0.9942507028356309, 0.9901111596455525, 0.6156026680867737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 125}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 147}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 242}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 303}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 310}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 323}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 379}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 408}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 109}], {
             RGBColor[
             0.28171832903511257`, 0.41140686866770654`, 0.9394290448060217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 205}], {
             RGBColor[
             0.33891161833602373`, 0.4609448212418522, 0.9430733506262359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 230}], {
             RGBColor[
             0.26393464830119756`, 0.39474242816076077`, 0.9383420598132073]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 382}], {
             RGBColor[
             0.2779618406141432, 0.4081531872040607, 0.9391896846855698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 425}], {
             RGBColor[
             0.22254037357983977`, 0.35123442088000967`, 0.9359847171051676]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 462}], {
             RGBColor[
             0.229837954460574, 0.3589046410790131, 0.936400303540522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 484}], {
             RGBColor[
             0.21851966349026236`, 0.34700839964812025`, 0.9357557436136738]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 156}], {
             RGBColor[
             0.2245611665730593, 0.35335840244155936`, 0.9360997982766361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 227}], {
             RGBColor[
             0.21113051364042446`, 0.3392419346567809, 0.9353349424609931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 265}], {
             RGBColor[
             0.1920994264104521, 0.3192390553374573, 0.9342511501972167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 270}], {
             RGBColor[
             0.18303490781801574`, 0.3097116715731334, 0.933734939273131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 329}], {
             RGBColor[
             0.18619018249920005`, 0.3130280653190276, 0.9339146274984138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 479}], {
             RGBColor[
             0.18778223780521028`, 0.31470141638778093`, 0.9340052926928564]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 153}], {
             RGBColor[
             0.35862018099566284`, 0.48504050882921934`, 0.944071938711037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 170}], {
             RGBColor[
             0.2681353000213933, 0.3981722683975148, 0.9386173577788594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 197}], {
             RGBColor[
             0.36643102917791126`, 0.4918058729400383, 0.9445696390503481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 214}], {
             RGBColor[
             0.26772635198284234`, 0.39774243808019455`, 0.9385940687930483]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 223}], {
             RGBColor[
             0.31217871061400504`, 0.4444646854438693, 0.9411255648557215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 236}], {
             RGBColor[
             0.31255501519915574`, 0.44486020542195137`, 0.9411469948451532]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 289}], {
             RGBColor[
             0.31649233536361426`, 0.44855148634982667`, 0.941387589639554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 314}], {
             RGBColor[
             0.4603925267300639, 0.5691703128729416, 0.9516675997547801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 411}], {
             RGBColor[
             0.5158561344435298, 0.6131266190837553, 0.9567665221218118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 466}], {
             RGBColor[
             0.2835372091003608, 0.41436065137694744`, 0.939494473715824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 470}], {
             RGBColor[
             0.2829505871294402, 0.41374407449152867`, 0.9394610664624095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 113}], {
             RGBColor[
             0.2834673549063147, 0.4150291714427635, 0.9394633295190601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 190}], {
             RGBColor[
             0.3280007224836446, 0.45851947284484174`, 0.9421208938903753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 315}], {
             RGBColor[
             0.25480773581216487`, 0.38490609465000936`, 0.9378312066097552]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 349}], {
             RGBColor[
             0.25865268956964965`, 0.3889473848332744, 0.9380501710381446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 364}], {
             RGBColor[
             0.29999764061783074`, 0.4324035498062153, 0.9404047048359647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 378}], {
             RGBColor[
             0.3055376194253575, 0.43822641878786983`, 0.940720198433389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 380}], {
             RGBColor[
             0.26354993581091446`, 0.3940947011361892, 0.9383290619667581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 416}], {
             RGBColor[
             0.3104556295882034, 0.4433227952208202, 0.9410029360855943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 452}], {
             RGBColor[
             0.35261985676709484`, 0.4798433295674984, 0.9436896033570711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 487}], {
             RGBColor[
             0.27490256852659056`, 0.40602703791885253`, 0.9389755776052008]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 164}], {
             RGBColor[
             0.6056683283309234, 0.6842577010589471, 0.9653854185243207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 180}], {
             RGBColor[
             0.4670849110812572, 0.5749095094534886, 0.9521098952255831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 205}], {
             RGBColor[
             0.3878666627433047, 0.5103723413481127, 0.9459354986663484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 230}], {
             RGBColor[
             0.31288969270847855`, 0.4441699482670213, 0.9412042078533198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 382}], {
             RGBColor[
             0.3269168850214242, 0.4575807073103212, 0.9420518327256824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 413}], {
             RGBColor[
             0.37066616576114175`, 0.49547413538427865`, 0.9448394982084473]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 474}], {
             RGBColor[
             0.36875585432995733`, 0.49381951963763093`, 0.9447177748532742]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 490}], {
             RGBColor[
             0.33626661541495695`, 0.4656789738460858, 0.9426475892787163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 157}], {
             RGBColor[
             0.9057608095719005, 0.9233348231066068, 0.7742214779103318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 356}], {
             RGBColor[
             0.7427296651345173, 0.7936652075463704, 0.7595503544862507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 360}], {
             RGBColor[
             0.8797081782083205, 0.4465238726729873, 0.3015501277947058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 457}], {
             RGBColor[
             0.9752798562916284, 0.9274780602051496, 0.4262581835303463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 494}], {
             RGBColor[
             0.9815895459724128, 0.9829117035784583, 0.7513422215789181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 130}], {
             RGBColor[
             0.9088647441004855, 0.9288516182784499, 0.9449490739960295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 175}], {
             RGBColor[
             0.9896715252435591, 0.9899969245055872, 0.8208330861574638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 182}], {
             RGBColor[
             0.9695152153683666, 0.9767279688727253, 0.933929502300139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 351}], {
             RGBColor[
             0.7220241695390399, 0.7799825981884567, 0.9282699260476386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 359}], {
             RGBColor[
             0.8730579162973663, 0.4187090496669422, 0.41146073042143505`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 371}], {
             RGBColor[
             0.7655925884892005, 0.8153534034271036, 0.9316997915837725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 460}], {
             RGBColor[
             0.9045539423959997, 0.925414302012888, 0.9445379058811575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 463}], {
             RGBColor[
             0.9024172304136022, 0.6381848846128098, 0.4393327514426538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 483}], {
             RGBColor[
             0.977978612779826, 0.951566610311706, 0.6247122270146903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 163}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 175}], {
             RGBColor[
             0.8764817671983398, 0.42012490000344926`, 0.35471866035020744`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 207}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 238}], {
             RGBColor[
             0.857059891141737, 0.3514566373014637, 0.19874471492026624`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 266}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 293}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 317}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 343}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 359}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 403}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 440}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 445}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 463}], {
             RGBColor[
             0.831998657058118, 0.24386491747293382`, 0.17815401051060936`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 471}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 483}], {
             RGBColor[
             0.8686864922225178, 0.39450469054086185`, 0.22397142092169176`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 190}], {
             RGBColor[
             0.30008982406307977`, 0.4294267187567612, 0.9405224985550569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 315}], {
             RGBColor[
             0.22689683739160005`, 0.3558133405619288, 0.9362328112744367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 349}], {
             RGBColor[
             0.23074179114908483`, 0.35985463074519386`, 0.9364517757028261]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 353}], {
             RGBColor[
             0.22107694525191812`, 0.3496962649206489, 0.9359013770268407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 364}], {
             RGBColor[
             0.2720867421972659, 0.4033107957181348, 0.9388063095006463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 378}], {
             RGBColor[
             0.2776267210047927, 0.4091336646997893, 0.9391218030980706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 380}], {
             RGBColor[
             0.23563903739034964`, 0.36500194704810873`, 0.9367306666314397]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 487}], {
             RGBColor[
             0.24699167010602574`, 0.37693428383077204`, 0.9373771822698823]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 128}], {
             RGBColor[
             0.21734212015934035`, 0.3457707269467618, 0.935688684262997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 138}], {
             RGBColor[
             0.19260410669659306`, 0.3197695063167697, 0.9342798909929049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 179}], {
             RGBColor[
             0.22995443980472458`, 0.3590270745613128, 0.9364069372085467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 255}], {
             RGBColor[
             0.2236188767018249, 0.35236799604226343`, 0.9360461362624624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 294}], {
             RGBColor[
             0.2027740482369167, 0.3304587596871861, 0.934859054118546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 296}], {
             RGBColor[
             0.19143934787553057`, 0.3185452709458584, 0.9342135597011516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 312}], {
             RGBColor[
             0.21887732335559562`, 0.3473843228435307, 0.9357761118138941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 327}], {
             RGBColor[
             0.19477749179217513`, 0.32205387185280054`, 0.9344036620588632]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 334}], {
             RGBColor[
             0.20140242887172854`, 0.3290171007686827, 0.9347809424248276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 385}], {
             RGBColor[
             0.18998822410005822`, 0.3170200478512756, 0.9341309203488837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 415}], {
             RGBColor[
             0.18749769588626286`, 0.3144023447899675, 0.9339890884515143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 446}], {
             RGBColor[
             0.1939761516721938, 0.321211612578802, 0.9343580269245066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 144}], {
             RGBColor[
             0.2435638403098072, 0.37333141737798453`, 0.9371819724340074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 215}], {
             RGBColor[
             0.21789975830007355`, 0.3463568399889726, 0.93572044093016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 223}], {
             RGBColor[
             0.26791411799790454`, 0.39892510312495144`, 0.9385686847253369]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 268}], {
             RGBColor[
             0.22078326587035477`, 0.3493875892702776, 0.9358846524205204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 402}], {
             RGBColor[
             0.29155073363812734`, 0.41974850753859727`, 0.9400619534020693]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 417}], {
             RGBColor[
             0.24410759542701554`, 0.3739029384822362, 0.9372129384835188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 143}], {
             RGBColor[
             0.7862678242150312, 0.44236018796317117`, 0.4452227057442526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 165}], {
             RGBColor[
             0.7645854413092009, 0.8162193268874823, 0.9771172884853815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 185}], {
             RGBColor[
             0.5025267031818595, 0.6027654055971375, 0.9554160280414452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 187}], {
             RGBColor[
             0.5258049734314325, 0.6229278732874357, 0.956899298837582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 224}], {
             RGBColor[
             0.4898453633718138, 0.5905346758344123, 0.9546536353939092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 277}], {
             RGBColor[
             0.8327236905210305, 0.8505154585848247, 0.6749691997262832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 313}], {
             RGBColor[
             0.8311822940909279, 0.8682327058496676, 0.945708059179992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 333}], {
             RGBColor[
             0.5510899875354679, 0.6448284816425902, 0.958510437577631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 358}], {
             RGBColor[
             0.5345278762555137, 0.6304832132878109, 0.9574551144921722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 361}], {
             RGBColor[
             0.5470425558222825, 0.6413227997224619, 0.9582525388078701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 386}], {
             RGBColor[
             0.7639631876081299, 0.8157231586768751, 0.9770579373718808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 441}], {
             RGBColor[
             0.5263358260398556, 0.6233876711354238, 0.9569331242963761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 140}], {
             RGBColor[
             0.1891020516318635, 0.31608862440062324`, 0.9340804541377947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 155}], {
             RGBColor[
             0.22121121154755882`, 0.34983738731034214`, 0.9359090232937483]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 156}], {
             RGBColor[
             0.23299646235272825`, 0.36222443313463404`, 0.9365801758923864]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 198}], {
             RGBColor[
             0.19641879440682608`, 0.3237789849653949, 0.9344971318146779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 270}], {
             RGBColor[
             0.19147020359768469`, 0.3185777022662082, 0.9342153168888814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 479}], {
             RGBColor[
             0.1962175335848792, 0.3235674470808556, 0.9344856703086066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 152}], {
             RGBColor[
             0.21897053500328645`, 0.3474822941952136, 0.9357814200793358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 187}], {
             RGBColor[
             0.30166406888411185`, 0.428995808686236, 0.9406885113479817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.22728280184896765`, 0.3562190136781822, 0.9362547913793006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 255}], {
             RGBColor[
             0.24682926108047093`, 0.37676358164758694`, 0.9373679333161395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 260}], {
             RGBColor[
             0.2740921498982324, 0.4051143982656095, 0.938931653051092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 292}], {
             RGBColor[
             0.2208755284929752, 0.34948456313643983`, 0.9358899066403883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 399}], {
             RGBColor[
             0.2698928088141382, 0.40100483262905684`, 0.9386813682401107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 446}], {
             RGBColor[
             0.21718653605083982`, 0.34560719818412555`, 0.9356798239781839]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 464}], {
             RGBColor[
             0.2582088050321171, 0.38872420384552575`, 0.9380159815096591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 481}], {
             RGBColor[
             0.2642710788962169, 0.3950960380470579, 0.9383612190378892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 496}], {
             RGBColor[
             0.22237308988837995`, 0.35105859511388676`, 0.9359751905464131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 120}], {
             RGBColor[
             0.1926435788239345, 0.319810994025283, 0.9342821388721632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 124}], {
             RGBColor[
             0.20441395972608956`, 0.3321824106387006, 0.9349524446518228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 363}], {
             RGBColor[
             0.19847969710316485`, 0.325945124368025, 0.934614497174402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 364}], {
             RGBColor[
             0.24538499784001913`, 0.3752455694102938, 0.9372856846611919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 381}], {
             RGBColor[
             0.21072511503524133`, 0.3388158350189773, 0.9353118556101614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 416}], {
             RGBColor[
             0.25584298681039175`, 0.38616481482489873`, 0.9378839159108214]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 124}], {
             RGBColor[
             0.1949045707787678, 0.32218743992498255`, 0.9344108990191531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 315}], {
             RGBColor[
             0.19068570408703148`, 0.3177531435403698, 0.9341706408023127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 363}], {
             RGBColor[
             0.1889703081558431, 0.31595015365430695`, 0.9340729515417323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 381}], {
             RGBColor[
             0.20121572608791957`, 0.32882086430525925`, 0.9347703099774917]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 196}], {
             RGBColor[
             0.263514639936199, 0.3943009727390789, 0.9383181409581673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.2855288778367985, 0.4174393325559085, 0.93957181923946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 307}], {
             RGBColor[
             0.263034036910473, 0.393795828487049, 0.9382907713268407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 337}], {
             RGBColor[
             0.25724680271789735`, 0.38771307841881125`, 0.9379611969010192]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 420}], {
             RGBColor[
             0.2550040005711073, 0.3853557511606656, 0.9378334726366879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 427}], {
             RGBColor[
             0.25170778098680857`, 0.3818912153851751, 0.937645757807682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 442}], {
             RGBColor[
             0.36944795676254, 0.4928528505313406, 0.9448192188256768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 447}], {
             RGBColor[
             0.3594348735345609, 0.4841800211114614, 0.9441811940166118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 454}], {
             RGBColor[
             0.3058588106164846, 0.437775128223043, 0.9407673746629241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 489}], {
             RGBColor[
             0.2627068012405983, 0.39345188305007095`, 0.9382721357395432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 500}], {
             RGBColor[
             0.28288233778375105`, 0.41465765115982456`, 0.9394211026986441]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 185}], {
             RGBColor[
             0.2643164513876104, 0.39404556499127835`, 0.9384040120398665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 212}], {
             RGBColor[
             0.1999697851673105, 0.32751130140048207`, 0.9346993554852674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 216}], {
             RGBColor[
             0.23867128343248623`, 0.3681890298938975, 0.9369033485577333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 217}], {
             RGBColor[
             0.19845501151425832`, 0.32591917824892747`, 0.9346130913666328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 224}], {
             RGBColor[
             0.25163511157756463`, 0.38181483522855314`, 0.9376416193923304]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 286}], {
             RGBColor[
             0.21170798349237516`, 0.3398488920848844, 0.9353678285147715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 319}], {
             RGBColor[
             0.19763752801393172`, 0.3250599512586367, 0.9345665368906477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 330}], {
             RGBColor[
             0.21641357139056538`, 0.344794763317387, 0.9356358047842801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 357}], {
             RGBColor[
             0.21418150641244568`, 0.34244872150428973`, 0.9355086919858204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 492}], {
             RGBColor[
             0.2013976738739365, 0.329012102964519, 0.9347806716347378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 139}], {
             RGBColor[
             0.20173923156575024`, 0.3293711017546237, 0.9348001228399971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 158}], {
             RGBColor[
             0.22135534676052232`, 0.3499888825578671, 0.9359172315808977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 193}], {
             RGBColor[
             0.19813056518650046`, 0.32557816458736866`, 0.9345946146282424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 401}], {
             RGBColor[
             0.1977072581497815, 0.3251332420525608, 0.9345705079187279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 410}], {
             RGBColor[
             0.20098281054011963`, 0.3285760552968229, 0.9347570457816121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 422}], {
             RGBColor[
             0.25330157722830876`, 0.3835663962875101, 0.9377365221458253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 428}], {
             RGBColor[
             0.21288413127934025`, 0.34108509798106146`, 0.9354348083912845]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 437}], {
             RGBColor[
             0.20027511058254266`, 0.32783221777064053`, 0.9347167433159764]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 363}], {
             RGBColor[
             0.20074068905799813`, 0.32832157026772446`, 0.934743257321392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 381}], {
             RGBColor[
             0.21298610699007461`, 0.34119228091867676`, 0.9354406157571513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 416}], {
             RGBColor[
             0.25810397876522506`, 0.3885412607245982, 0.9380126760578114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.8300337551067959, 0.23185817939204778`, 0.1763936638495297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 173}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 242}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 249}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 269}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 282}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 305}], {
             RGBColor[
             0.8321466499760604, 0.3869651660515732, 0.4383722111318248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 310}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 323}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 406}], {
             RGBColor[
             0.8761600890568056, 0.41916385235227993`, 0.29986098883365586`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 408}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 419}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 173}], {
             RGBColor[
             0.8563654629268306, 0.3487034608338446, 0.19818596167822738`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 249}], {
             RGBColor[
             0.8563654629268306, 0.3487034608338446, 0.19818596167822738`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 269}], {
             RGBColor[
             0.8563654629268306, 0.3487034608338446, 0.19818596167822738`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 282}], {
             RGBColor[
             0.8563654629268306, 0.3487034608338446, 0.19818596167822738`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 340}], {
             RGBColor[
             0.9580550382851865, 0.8818464109073033, 0.591032485493439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 384}], {
             RGBColor[
             0.784439054142597, 0.7459729584674704, 0.6152424378957748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 414}], {
             RGBColor[
             0.9638951205538232, 0.8830011069097463, 0.3908566728809145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 449}], {
             RGBColor[
             0.8563654629268306, 0.3487034608338446, 0.19818596167822738`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 499}], {
             RGBColor[
             0.8563654629268306, 0.3487034608338446, 0.19818596167822738`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 184}], {
             RGBColor[
             0.8369837657282427, 0.2665011316422593, 0.18231370738115665`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 221}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 253}], {
             RGBColor[
             0.8742585681452911, 0.4192055500614041, 0.39156282211394233`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 301}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 303}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 316}], {
             RGBColor[
             0.8735231410973765, 0.4108198428949215, 0.24276088847601782`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 138}], {
             RGBColor[
             0.22021896748197323`, 0.3487944758855043, 0.9358525164621068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 179}], {
             RGBColor[
             0.25756930059010474`, 0.38805204413004735`, 0.9379795626777485]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 222}], {
             RGBColor[
             0.2510869631489796, 0.3812386964754926, 0.9376104031502354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 245}], {
             RGBColor[
             0.3639482041295633, 0.48295335281971236`, 0.9448496084986262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 294}], {
             RGBColor[
             0.23038890902229686`, 0.35948372925592065`, 0.9364316795877479]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 296}], {
             RGBColor[
             0.21905420866091074`, 0.34757024051459295`, 0.9357861851703535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 312}], {
             RGBColor[
             0.2464921841409758, 0.3764092924122653, 0.937348737283096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 385}], {
             RGBColor[
             0.21760308488543836`, 0.34604501742001015`, 0.9357035458180856]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 415}], {
             RGBColor[
             0.215112556671643, 0.34342731435870205`, 0.9355617139207162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 438}], {
             RGBColor[
             0.26301778671971743`, 0.3937787485062433, 0.9382898459025171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 439}], {
             RGBColor[
             0.25567022753416335`, 0.38605599794006673`, 0.9378714132766395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 204}], {
             RGBColor[
             0.8203413302090085, 0.8600631926608293, 0.9825983689433555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 275}], {
             RGBColor[
             0.8469448752581116, 0.7933181891173926, 0.6210335543626414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 276}], {
             RGBColor[
             0.5454672677839978, 0.6367301066502977, 0.9595185145296392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 306}], {
             RGBColor[
             0.611794552731207, 0.6939125455037445, 0.9638185817259406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 331}], {
             RGBColor[
             0.7939675478085891, 0.839033454471987, 0.98008281403385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 346}], {
             RGBColor[
             0.871715025393385, 0.8835314226277342, 0.6825874912808683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 348}], {
             RGBColor[
             0.8615879645459554, 0.8493704684423902, 0.6432457722235755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 355}], {
             RGBColor[
             0.8246751523265887, 0.5626184933768341, 0.4602642940296072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 431}], {
             RGBColor[
             0.8769447835241505, 0.9005887953787303, 0.7525487545778835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 444}], {
             RGBColor[
             0.8208341223499612, 0.533094653826407, 0.4565861193861659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 486}], {
             RGBColor[
             0.8772725629513854, 0.9012898824300021, 0.7882255224122631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 175}], {
             RGBColor[
             0.9140005204519457, 0.9309753937832106, 0.859835968889188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 182}], {
             RGBColor[
             0.8938442105767532, 0.9177064381503486, 0.9729323850318632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 208}], {
             RGBColor[
             0.913099344561267, 0.9286383537262926, 0.7319810481348386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 238}], {
             RGBColor[
             0.8848677063670416, 0.8279729997302321, 0.6258750507442762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 241}], {
             RGBColor[
             0.5867161645318493, 0.6694746929690595, 0.9634263183495637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 351}], {
             RGBColor[
             0.6463531647474265, 0.72096106746608, 0.9672728087793628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 371}], {
             RGBColor[
             0.6899215836975872, 0.756331872704727, 0.9707026743154967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 442}], {
             RGBColor[
             0.6401413651407276, 0.7157489165078108, 0.9668305248903115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 483}], {
             RGBColor[
             0.9023076079882126, 0.8925450795893294, 0.6637151097464145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 186}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 234}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 373}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 434}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 449}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 495}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 250}], {
             RGBColor[
             0.5096842240418256, 0.610007296239153, 0.9554309033935169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 356}], {
             RGBColor[
             0.575775252833869, 0.6662108242154342, 0.9599298517837459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 365}], {
             RGBColor[
             0.47996279510956574`, 0.5834591273930367, 0.9535665537870656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 457}], {
             RGBColor[
             0.80832544399098, 0.8000236768742133, 0.6266376808278413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 494}], {
             RGBColor[
             0.8146351336717644, 0.855457320247522, 0.9517217188764132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 191}], {
             RGBColor[
             0.24509705427784428`, 0.37494292246977173`, 0.9372692867013004]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 237}], {
             RGBColor[
             0.3420181953123312, 0.46624628266428925`, 0.9431757084268175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 241}], {
             RGBColor[
             0.30061942099789657`, 0.430388745116024, 0.9405378151350005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 271}], {
             RGBColor[
             0.2827858451483628, 0.4145562312820451, 0.9394156075858068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 304}], {
             RGBColor[
             0.24533917292446922`, 0.3751974045185834, 0.9372830750000432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 311}], {
             RGBColor[
             0.24377892093012438`, 0.3735574807468368, 0.9371942209571512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 351}], {
             RGBColor[
             0.3602564212134738, 0.4818751196130445, 0.9443843055647996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 366}], {
             RGBColor[
             0.22778137278596647`, 0.35674304334419116`, 0.9362831842565931]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 371}], {
             RGBColor[
             0.4038248401636344, 0.5172459248516914, 0.9478141711009334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 405}], {
             RGBColor[
             0.22584814988303165`, 0.3547111034997951, 0.9361730900722178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 423}], {
             RGBColor[
             0.22055140940715506`, 0.3491438934269059, 0.935871448537942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 429}], {
             RGBColor[
             0.24801000575022464`, 0.37800461915903416`, 0.9374351749783268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 469}], {
             RGBColor[
             0.2251876288090195, 0.3540168539715534, 0.9361354743742063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 488}], {
             RGBColor[
             0.22772081169529612`, 0.3566793897981017, 0.9362797353920715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 174}], {
             RGBColor[
             0.2085506805802597, 0.33653036653968427`, 0.9351880247847377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 210}], {
             RGBColor[
             0.22588078399928613`, 0.3547454040251011, 0.9361749485368607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 225}], {
             RGBColor[
             0.20098661279686494`, 0.32858005170973914`, 0.9347572623145088]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 247}], {
             RGBColor[
             0.20166327316729094`, 0.3292912646618023, 0.9347957971215752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 252}], {
             RGBColor[
             0.19741515137734375`, 0.3248262193140896, 0.9345538728701708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 278}], {
             RGBColor[
             0.20206125527400282`, 0.32970956908947946`, 0.9348184616137908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 309}], {
             RGBColor[
             0.2100987137423066, 0.33815744754396704`, 0.9352761829832064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 424}], {
             RGBColor[
             0.2214617006289249, 0.3501006672167829, 0.9359232882763666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 169}], {
             RGBColor[
             0.19175100981754287`, 0.3188728474074218, 0.9342313083876868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 211}], {
             RGBColor[
             0.19965674481685908`, 0.3271822761442531, 0.9346815283004108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 362}], {
             RGBColor[
             0.18189649677046751`, 0.30851512938273096`, 0.9336701084481014]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 369}], {
             RGBColor[
             0.18790542144841682`, 0.3148308902070851, 0.9340123078191032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 466}], {
             RGBColor[
             0.21560127706368337`, 0.34394099047739907`, 0.935589545824046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 470}], {
             RGBColor[
             0.21501465509276277`, 0.3433244135919803, 0.9355561385706315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 240}], {
             RGBColor[
             0.8413736303622167, 0.28643448166620133`, 0.18597671803717333`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 434}], {
             RGBColor[
             0.8413736303622167, 0.28643448166620133`, 0.18597671803717333`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 148}], {
             RGBColor[
             0.4973694977090155, 0.5987599555327824, 0.9548921028341959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 156}], {
             RGBColor[
             0.29413333822792154`, 0.4253340674905862, 0.9401039046543183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 227}], {
             RGBColor[
             0.2807026852952867, 0.41121759970580773`, 0.9393390488386753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 229}], {
             RGBColor[
             0.3767837963714482, 0.5007729195378712, 0.9452293082213277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 263}], {
             RGBColor[
             0.3515933537073658, 0.478954224210705, 0.9436241954898061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 265}], {
             RGBColor[
             0.26167159806531437`, 0.3912147203864842, 0.9382552565748988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 267}], {
             RGBColor[
             0.3633910087702312, 0.4891727600587743, 0.9443759316381551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 280}], {
             RGBColor[
             0.43200376365867066`, 0.5461711365359171, 0.9494194420439965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 393}], {
             RGBColor[
             0.3443442466033714, 0.47267541198794205`, 0.9431622887952733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 424}], {
             RGBColor[
             0.2813766900403703, 0.41192602142725965`, 0.939377432411807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 485}], {
             RGBColor[
             0.43787204087877396`, 0.550935268346073, 0.9498814143229708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 179}], {
             RGBColor[
             0.23283128712735746`, 0.36205082350005524`, 0.9365707694076565]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 222}], {
             RGBColor[
             0.22634894968623231`, 0.35523747584550047`, 0.9362016098801433]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 294}], {
             RGBColor[
             0.20565089555954957`, 0.33348250862592854`, 0.9350228863176557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 296}], {
             RGBColor[
             0.19431619519816343`, 0.32156901988460085`, 0.9343773919002614]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 339}], {
             RGBColor[
             0.1899160305473181, 0.31694416785001006`, 0.934126809032856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 385}], {
             RGBColor[
             0.19286507142269105`, 0.32004379679001804`, 0.9342947525479934]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 415}], {
             RGBColor[
             0.19037454320889569`, 0.31742609372870995`, 0.934152920650624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 438}], {
             RGBColor[
             0.23827977325697014`, 0.3677775278762512, 0.936881052632425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 158}], {
             RGBColor[
             0.2143619533681344, 0.34263838269571634`, 0.9355189681729995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 247}], {
             RGBColor[
             0.19836393844048342`, 0.3258234546740237, 0.9346079048898119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 278}], {
             RGBColor[
             0.19876192054719527`, 0.32624175910170083`, 0.9346305693820274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 401}], {
             RGBColor[
             0.19071386475739358`, 0.31778274219041003`, 0.9341722445108298]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 410}], {
             RGBColor[
             0.1939894171477317, 0.3212255554346721, 0.9343587823737141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 428}], {
             RGBColor[
             0.20589073788695234`, 0.3337345981189107, 0.9350365449833864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 437}], {
             RGBColor[
             0.19328171719015474`, 0.3204817179084898, 0.9343184799080784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 451}], {
             RGBColor[
             0.24317792529434393`, 0.37292579622830746`, 0.9371599951447869]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 198}], {
             RGBColor[
             0.18662011133920806`, 0.3134799477889389, 0.9339391113098297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 270}], {
             RGBColor[
             0.18167152053006663`, 0.3082786650897521, 0.933657296384033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 479}], {
             RGBColor[
             0.1864188505172612, 0.31326840990439964`, 0.9339276498037584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 151}], {
             RGBColor[
             0.29343798324110804`, 0.42575230380208373`, 0.9400222310917625]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 160}], {
             RGBColor[
             0.37802184945379874`, 0.5011040622114881, 0.9453453778817297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 162}], {
             RGBColor[
             0.24952923123188117`, 0.3796014214647141, 0.9375216926220145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 167}], {
             RGBColor[
             0.3793212150967632, 0.5021589457762018, 0.945447668704877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 235}], {
             RGBColor[
             0.3242794390168753, 0.4545969884680785, 0.9419093816387205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 274}], {
             RGBColor[
             0.39256014440333986`, 0.5129069049942494, 0.9464898857156867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 284}], {
             RGBColor[
             0.3001512154255292, 0.4328083364714148, 0.9404045397333283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 300}], {
             RGBColor[
             0.3596463325015217, 0.4852300140127269, 0.9441629288178462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 345}], {
             RGBColor[
             0.26571464212222085`, 0.3966133145247829, 0.9384434278280497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 389}], {
             RGBColor[
             0.27450272226024985`, 0.40585014394631425`, 0.9389438959911109]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 432}], {
             RGBColor[
             0.5362845883584992, 0.627612344125192, 0.9591557710589778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 456}], {
             RGBColor[
             0.2759889604791371, 0.40741227454731044`, 0.9390285350589842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 472}], {
             RGBColor[
             0.2491195605244581, 0.3791708315765894, 0.9374983624812803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[
             0.3397907487213136, 0.46873140098796173`, 0.9428721439367287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 161}], {
             RGBColor[
             0.33616922788314596`, 0.46559462166087084`, 0.9426413838313057]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 183}], {
             RGBColor[
             0.2986301457506506, 0.42826119735656343`, 0.940425872375729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 254}], {
             RGBColor[
             0.28886221876631657`, 0.41799448677368717`, 0.9398696033843243]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 285}], {
             RGBColor[
             0.3374576097099063, 0.46671055324325716`, 0.9427234783820356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 388}], {
             RGBColor[
             0.6324778710852315, 0.7059774833485709, 0.9677848279671616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 396}], {
             RGBColor[
             0.2996502424735361, 0.4293333836901839, 0.9404839653749997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 473}], {
             RGBColor[
             0.4734736299079191, 0.580366653206442, 0.9525381002758618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 477}], {
             RGBColor[
             0.3004155181766316, 0.43013773697541924`, 0.9405275466941669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 165}], {
             RGBColor[
             0.8397048936039028, 0.4842390340274436, 0.4505134128142734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 178}], {
             RGBColor[
             0.8770300475453819, 0.4797787542910352, 0.21761304086744773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 186}], {
             RGBColor[
             0.8305642118064, 0.2359355020328133, 0.17690162978413582`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 277}], {
             RGBColor[
             0.8851303930784559, 0.5071031218256719, 0.24908135364154116`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 288}], {
             RGBColor[
             0.8305642118064, 0.2359355020328133, 0.17690162978413582`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 313}], {
             RGBColor[
             0.8841027954583874, 0.5189146200022339, 0.4295739266106804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 321}], {
             RGBColor[
             0.8305642118064, 0.2359355020328133, 0.17690162978413582`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 373}], {
             RGBColor[
             0.8305642118064, 0.2359355020328133, 0.17690162978413582`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 386}], {
             RGBColor[
             0.8392900578031888, 0.4839082552203721, 0.450473845405273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 414}], {
             RGBColor[
             0.8892351625821182, 0.5206084458054662, 0.2940261166931848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 498}], {
             RGBColor[
             0.8305642118064, 0.2359355020328133, 0.17690162978413582`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 145}], {
             RGBColor[
             0.28245593278256786`, 0.4142094724679425, 0.9393968195646363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 215}], {
             RGBColor[
             0.23058979905714602`, 0.35969487741971096`, 0.9364431199780423]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 246}], {
             RGBColor[
             0.35696945876019426`, 0.4786389058672158, 0.9441772202942458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 375}], {
             RGBColor[
             0.2688835490281597, 0.3999440366032271, 0.9386238923883652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 402}], {
             RGBColor[
             0.3042407743951998, 0.43308654496933563`, 0.9407846324499517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 417}], {
             RGBColor[
             0.256797636184088, 0.38724097591297457`, 0.9379356175314011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 458}], {
             RGBColor[
             0.35435270940186414`, 0.4764909843730204, 0.9439777206363321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 367}], {
             RGBColor[
             0.2830394326624652, 0.4148227678377437, 0.9394300490195857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 375}], {
             RGBColor[
             0.29508560074384793`, 0.4274840542624467, 0.9401160604711118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 402}], {
             RGBColor[
             0.33044282611088804`, 0.46062656262855517`, 0.9422768005326982]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 417}], {
             RGBColor[
             0.28299968789977625`, 0.4147809935721941, 0.9394277856141477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 450}], {
             RGBColor[
             0.32420026945735514`, 0.45521957381528544`, 0.9418790303428113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 458}], {
             RGBColor[
             0.3805547611175523, 0.5040310020322399, 0.9454698887190787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 461}], {
             RGBColor[
             0.42511156853211396`, 0.5402277520345683, 0.9489710633786737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 166}], {
             RGBColor[
             0.217481006477988, 0.34591670527356166`, 0.9356965936333801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 239}], {
             RGBColor[
             0.21955415616402918`, 0.348095717038873, 0.93581465644105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 248}], {
             RGBColor[
             0.18429425645727748`, 0.31103532684031304`, 0.9338066573150976]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 387}], {
             RGBColor[
             0.20285490882715684`, 0.330543749294386, 0.9348636590095377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 221}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 234}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 242}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 303}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 323}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 449}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 229}], {
             RGBColor[
             0.5529788076305955, 0.64692594478167, 0.958435478889017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 232}], {
             RGBColor[
             0.6848339419914155, 0.7537167475052093, 0.9692215052668037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 263}], {
             RGBColor[
             0.527788364966513, 0.6251072494545038, 0.9568303661574955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 267}], {
             RGBColor[
             0.5395860200293785, 0.6353257853025731, 0.9575821023058444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 280}], {
             RGBColor[
             0.6081987749178179, 0.6923241617797158, 0.9626256127116859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 342}], {
             RGBColor[
             0.8111690714652371, 0.789762270075679, 0.6228692704159253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 393}], {
             RGBColor[
             0.5205392578625186, 0.6188284372317407, 0.9563684594629627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 480}], {
             RGBColor[
             0.576482916411845, 0.6665757990614235, 0.9601288241510779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 485}], {
             RGBColor[
             0.6140670521379212, 0.6970882935898717, 0.9630875849906602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 173}], {
             RGBColor[
             0.8427485102135918, 0.3295893587840956, 0.1885693276990594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 242}], {
             RGBColor[
             0.8427485102135918, 0.3295893587840956, 0.1885693276990594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 249}], {
             RGBColor[
             0.8427485102135918, 0.3295893587840956, 0.1885693276990594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 269}], {
             RGBColor[
             0.8427485102135918, 0.3295893587840956, 0.1885693276990594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 282}], {
             RGBColor[
             0.8427485102135918, 0.3295893587840956, 0.1885693276990594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 310}], {
             RGBColor[
             0.8427485102135918, 0.3295893587840956, 0.1885693276990594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 314}], {
             RGBColor[
             0.7707695331053225, 0.5139697191710294, 0.454417376319948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 323}], {
             RGBColor[
             0.8427485102135918, 0.3295893587840956, 0.1885693276990594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 406}], {
             RGBColor[
             0.9015895992703974, 0.6146262111363756, 0.3242123165327152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 411}], {
             RGBColor[
             0.8077452715809664, 0.5432739233115719, 0.4578166578979691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 419}], {
             RGBColor[
             0.8427485102135918, 0.3295893587840956, 0.1885693276990594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 220}], {
             RGBColor[
             0.34295836521931666`, 0.47147503118949763`, 0.9430739816589682]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 254}], {
             RGBColor[
             0.2880175076881252, 0.41726284049417106`, 0.9398157791413707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 325}], {
             RGBColor[
             0.38277885144144796`, 0.5059655349192759, 0.945611307829169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 392}], {
             RGBColor[
             0.39049019037477983`, 0.5126447091201637, 0.9461026675271316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 412}], {
             RGBColor[
             0.2833356085457537, 0.41234186764598774`, 0.9395491519114617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 426}], {
             RGBColor[
             0.27709250902946053`, 0.4057799742189919, 0.9391936166298469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 473}], {
             RGBColor[
             0.4726289188297277, 0.5796350069269258, 0.9524842760329082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 160}], {
             RGBColor[
             0.37027731562653565`, 0.4929640661272292, 0.9449043381372781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 162}], {
             RGBColor[
             0.24178469740461808`, 0.3714614253804553, 0.9370806528775629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 226}], {
             RGBColor[
             0.24965370060264616`, 0.379732246665202, 0.9375287809685435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 235}], {
             RGBColor[
             0.31653490518961214`, 0.44645699238381964`, 0.941468341894269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 237}], {
             RGBColor[
             0.3543647938987703, 0.4792233405982007, 0.9438788289511594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 274}], {
             RGBColor[
             0.3848156105760768, 0.5047669089099905, 0.9460488459712351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 284}], {
             RGBColor[
             0.2924066815982661, 0.42466834038715606`, 0.9399634999888766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 345}], {
             RGBColor[
             0.2579701082949577, 0.388473318440524, 0.9380023880835981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 389}], {
             RGBColor[
             0.26675818843298676`, 0.3977101478620555, 0.9385028562466593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 456}], {
             RGBColor[
             0.268244426651874, 0.3992722784630517, 0.9385874953145326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 472}], {
             RGBColor[
             0.24137502669719502`, 0.37103083549233057`, 0.9370573227368286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 195}], {
             RGBColor[
             0.21010530872100186`, 0.3381643792847215, 0.9352765585574867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 216}], {
             RGBColor[
             0.23556313755144892`, 0.3649221715050963, 0.9367263442478979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 217}], {
             RGBColor[
             0.19534686563322098`, 0.3226523198601263, 0.9344360870567976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 292}], {
             RGBColor[
             0.20369803536500936`, 0.33142992874297905`, 0.9349116738185744]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 398}], {
             RGBColor[
             0.24922661523815437`, 0.3792833528683451, 0.9375044590888519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 399}], {
             RGBColor[
             0.2527153156861724, 0.38295019823559606`, 0.9377031354182968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 464}], {
             RGBColor[
             0.24103131190415128`, 0.37066956945206503`, 0.9370377486878454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 481}], {
             RGBColor[
             0.24709358576825113`, 0.3770414036535972, 0.9373829862160753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 496}], {
             RGBColor[
             0.2051955967604141, 0.33300396072042604`, 0.9349969577245991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 172}], {
             RGBColor[
             0.38789541628795154`, 0.5103972462232906, 0.9459373308167875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 197}], {
             RGBColor[
             0.4056482253886383, 0.5257738371841758, 0.9470685241144907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 201}], {
             RGBColor[
             0.4828110574856316, 0.5895003637293261, 0.9528440323387535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 223}], {
             RGBColor[
             0.3513959068247321, 0.4784326496880068, 0.9436244499198642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 236}], {
             RGBColor[
             0.3517722114098828, 0.47882816966608893`, 0.9436458799092957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 289}], {
             RGBColor[
             0.3557095315743413, 0.48251945059396417`, 0.9438864747036967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 314}], {
             RGBColor[
             0.499609722940791, 0.6031382771170792, 0.9541664848189226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 411}], {
             RGBColor[
             0.5550733306542569, 0.6470945833278928, 0.9592654071859543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 466}], {
             RGBColor[
             0.32275440531108784`, 0.44832861562108495`, 0.9419933587799665]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 470}], {
             RGBColor[
             0.32216778334016727`, 0.44771203873566623`, 0.941959951526552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 493}], {
             RGBColor[
             0.4936405223165552, 0.5982922111409009, 0.9536965674798805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 199}], {
             RGBColor[
             0.8752103907398564, 0.4195991531649818, 0.3757886584840803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 219}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 244}], {
             RGBColor[
             0.8706168078338911, 0.40101609835768304`, 0.23147033256236077`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 295}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 341}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 374}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 376}], {
             RGBColor[
             0.8735554698238286, 0.4189148008366767, 0.4032149808607035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 397}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 455}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 198}], {
             RGBColor[
             0.21872927125490338`, 0.3472287106986578, 0.9357676804657832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 250}], {
             RGBColor[
             0.3015021013571373, 0.4295372658275264, 0.9406532288863496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 365}], {
             RGBColor[
             0.2717806724248775, 0.40298909698141017`, 0.9387888792798984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 394}], {
             RGBColor[
             0.22097523638302924`, 0.34958936245073197`, 0.9358955848572224]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 467}], {
             RGBColor[
             0.2375425676300431, 0.36700267802081454`, 0.9368390698625695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 479}], {
             RGBColor[
             0.2185280104329565, 0.3470171728141185, 0.935756218959712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 198}], {
             RGBColor[
             0.23051452206007278`, 0.35961575652294975`, 0.9364388330644213]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 227}], {
             RGBColor[
             0.2536615370733401, 0.3839447369074104, 0.937757021326487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 250}], {
             RGBColor[
             0.3132873521623067, 0.4419243116518183, 0.9413243814849879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 263}], {
             RGBColor[
             0.3245522054854192, 0.45168136141230764`, 0.9420421679776179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 270}], {
             RGBColor[
             0.22556593125093138`, 0.35441447382376295`, 0.9361570181386248]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 479}], {
             RGBColor[
             0.23031326123812593`, 0.35940421863841043`, 0.9364273715583502]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 485}], {
             RGBColor[
             0.4108308926568273, 0.5236624055476755, 0.9482993868107825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 190}], {
             RGBColor[
             0.5811750262089507, 0.6652253629216612, 0.9628235461914189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 356}], {
             RGBColor[
             0.6546957163401086, 0.7278640901242467, 0.9677959060323847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 360}], {
             RGBColor[
             0.821018879012048, 0.40265646105823816`, 0.44038049549212843`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.3108236109603984, 0.4367287160722685, 0.9412794952284302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 193}], {
             RGBColor[
             0.21075328698888462`, 0.3388454455284614, 0.9353134599612447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 247}], {
             RGBColor[
             0.2179800536352555, 0.34644123547726713`, 0.9357250136307124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 278}], {
             RGBColor[
             0.21837803574196735`, 0.3468595399049442, 0.9357476781229279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 370}], {
             RGBColor[
             0.31860057599581953`, 0.44346473230432215`, 0.9417750365635871]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 401}], {
             RGBColor[
             0.21032997995216565`, 0.3384005229936534, 0.9352893532517302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 410}], {
             RGBColor[
             0.2136055323425038, 0.3418433362379155, 0.9354758911146145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 422}], {
             RGBColor[
             0.2659242990306929, 0.3968336772286028, 0.9384553674788276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 428}], {
             RGBColor[
             0.2255068530817244, 0.3543523789221541, 0.9361536537242868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 437}], {
             RGBColor[
             0.21289783238492682`, 0.3410994987117332, 0.9354355886489787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 451}], {
             RGBColor[
             0.26279404048911603`, 0.39354357703155085`, 0.9382771038856873]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 166}], {
             RGBColor[
             0.3352108410982161, 0.45943457954147626`, 0.9427754713265473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 192}], {
             RGBColor[
             0.6447596298856625, 0.718476583875131, 0.9677105713215501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 239}], {
             RGBColor[
             0.33728399078425725`, 0.4616135913067876, 0.9428935341342171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 251}], {
             RGBColor[
             0.43566646967110545`, 0.5517741316208221, 0.9489812600960783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 272}], {
             RGBColor[
             0.4928488984890493, 0.5982329341630651, 0.953473053095963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 344}], {
             RGBColor[
             0.32356779326194895`, 0.4471969980536896, 0.9421124169766175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 435}], {
             RGBColor[
             0.4343916682734087, 0.5506699627235185, 0.9489000308782796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 439}], {
             RGBColor[
             0.3428534925670518, 0.4674674908073133, 0.9432107090214077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 453}], {
             RGBColor[
             0.4386026872571061, 0.5541934161210065, 0.9492025926373653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 167}], {
             RGBColor[
             0.4561605474821908, 0.5693707081013473, 0.9503297757503926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 235}], {
             RGBColor[
             0.4011187714023029, 0.521808750793224, 0.9467914886842361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 237}], {
             RGBColor[
             0.43894866011146105`, 0.554575099007605, 0.9492019757411265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 274}], {
             RGBColor[
             0.4693994767887675, 0.5801186673193949, 0.9513719927612023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 284}], {
             RGBColor[
             0.3769905478109568, 0.5000200987965604, 0.9452866467788439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 300}], {
             RGBColor[
             0.43648566488694934`, 0.5524417763378724, 0.9490450358633619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 305}], {
             RGBColor[
             0.6583315658837037, 0.7304786613456766, 0.96845405916136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 389}], {
             RGBColor[
             0.35134205464567747`, 0.4730619062714598, 0.9438260030366266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 432}], {
             RGBColor[
             0.6131239207439269, 0.6948241064503374, 0.9640378781044934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 460}], {
             RGBColor[
             0.6397166588695635, 0.7156356397807915, 0.9666785527126276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 183}], {
             RGBColor[
             0.29416391383429163`, 0.4243927717499564, 0.9401412880273525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 188}], {
             RGBColor[
             0.35599050426396195`, 0.4827628150156156, 0.9439043780350249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 202}], {
             RGBColor[
             0.27218576478809153`, 0.40129234360726607`, 0.9388896649529292]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 243}], {
             RGBColor[
             0.29333367126304843`, 0.4235201341671604, 0.9400940069411541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 273}], {
             RGBColor[
             0.2730441392759877, 0.4021945496181309, 0.9389385481101638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 279}], {
             RGBColor[
             0.317893858956114, 0.449334448638412, 0.9414926732967325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 285}], {
             RGBColor[
             0.33299137779354726`, 0.4628421276366501, 0.942438894033659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 287}], {
             RGBColor[
             0.5848187798365858, 0.6676682441493317, 0.9633804701369508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 335}], {
             RGBColor[
             0.32336695487389533`, 0.45450593624120883`, 0.9418256343157618]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 354}], {
             RGBColor[
             0.5968095021678761, 0.6772293206568155, 0.9645241559371533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 396}], {
             RGBColor[
             0.29518401055717713`, 0.42546495808357687`, 0.940199381026623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 409}], {
             RGBColor[
             0.4365148251401427, 0.5501192931853284, 0.9496955815684055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 430}], {
             RGBColor[
             0.3040526283510779, 0.4347864376878118, 0.9407044356900414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 459}], {
             RGBColor[
             0.2888122033466731, 0.4187677847094263, 0.9398365160322288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 477}], {
             RGBColor[
             0.29594928626027256`, 0.4262693113688122, 0.9402429623457904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 226}], {
             RGBColor[
             0.2057449485934193, 0.33358136432783236`, 0.9350282424987957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 284}], {
             RGBColor[
             0.24849792958903924`, 0.3785174580497864, 0.9374629615191288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 345}], {
             RGBColor[
             0.21406135628573086`, 0.3423224361031544, 0.9355018496138501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 389}], {
             RGBColor[
             0.2228494364237599, 0.35155926552468586`, 0.9360023177769115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 456}], {
             RGBColor[
             0.22433567464264714`, 0.35312139612568205`, 0.9360869568447846]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 472}], {
             RGBColor[
             0.19746627468796812`, 0.32487995315496093`, 0.9345567842670808]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 207}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 209}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 231}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 233}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 266}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 317}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 326}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 343}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 355}], {
             RGBColor[
             0.8304768118928137, 0.23526370799810264`, 0.17681793552818148`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 379}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 440}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 180}], {
             RGBColor[
             0.7420798659697871, 0.7983328217384686, 0.9752041209037695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 205}], {
             RGBColor[
             0.6628616176318347, 0.7337956536330927, 0.9690297243445348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 259}], {
             RGBColor[
             0.8384337610731512, 0.3919783377813091, 0.43897188140083576`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 316}], {
             RGBColor[
             0.9332973532557916, 0.9359432710143458, 0.6941631548152802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 331}], {
             RGBColor[
             0.854078896606874, 0.8864833450730073, 0.9859440016752372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 348}], {
             RGBColor[
             0.9216993133442403, 0.8968203590434105, 0.6491069598649626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 372}], {
             RGBColor[
             0.8384337610731512, 0.3919783377813091, 0.43897188140083576`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 404}], {
             RGBColor[
             0.8384337610731512, 0.3919783377813091, 0.43897188140083576`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 418}], {
             RGBColor[
             0.9146050965365867, 0.8706968435897349, 0.6329687419964006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 431}], {
             RGBColor[
             0.9370561323224353, 0.9480386859797506, 0.7584099422192706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 444}], {
             RGBColor[
             0.8609083548821511, 0.5647279142270871, 0.4604935778137573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 486}], {
             RGBColor[
             0.9373839117496703, 0.9487397730310224, 0.7940867100536502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 178}], {
             RGBColor[
             0.9007287763047269, 0.8723471763792785, 0.6357027911701743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 185}], {
             RGBColor[
             0.5826823072651669, 0.6655836746935463, 0.9633520886464765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 277}], {
             RGBColor[
             0.9128792946043378, 0.9133337276812334, 0.6829052603313144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 288}], {
             RGBColor[
             0.8264596817975027, 0.3824305319946304, 0.43782978303013764`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 313}], {
             RGBColor[
             0.9113378981742353, 0.9310509749460764, 0.9536441197850233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 333}], {
             RGBColor[
             0.6312455916187752, 0.707646750738999, 0.9664464981826622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 358}], {
             RGBColor[
             0.614683480338821, 0.6933014823842196, 0.9653911750972035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 361}], {
             RGBColor[
             0.6271981599055898, 0.7041410688188706, 0.9661885994129014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 386}], {
             RGBColor[
             0.8441187916914372, 0.8785414277732838, 0.9849939979769122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 498}], {
             RGBColor[
             0.8264596817975027, 0.3824305319946304, 0.43782978303013764`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.2531713208719759, 0.3834294885982743, 0.9377291042390291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 344}], {
             RGBColor[
             0.23945512334966762`, 0.36901289534517634`, 0.9369479870814295]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 387}], {
             RGBColor[
             0.2364720735351036, 0.36587752085378733`, 0.9367781068075168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 435}], {
             RGBColor[
             0.3502789983611274, 0.4724858600150052, 0.9437356009830916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 439}], {
             RGBColor[
             0.2587408226547705, 0.38928338809880003`, 0.9380462791262197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 453}], {
             RGBColor[
             0.35449001734482477`, 0.47600931341249325`, 0.9440381627421772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 172}], {
             RGBColor[
             0.41770668424733426`, 0.5361058055196428, 0.9478679522159678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[
             0.5126223254450143, 0.6152089230256782, 0.9547746537379336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 218}], {
             RGBColor[
             0.5986386322553329, 0.683547898239663, 0.9625669021197863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 235}], {
             RGBColor[
             0.40241813704526735`, 0.5228636343579377, 0.9468937795073835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 236}], {
             RGBColor[
             0.3815834793692655, 0.504536728962441, 0.9455765013084759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 274}], {
             RGBColor[
             0.470698842431732, 0.5811735508841086, 0.9514742835843497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 284}], {
             RGBColor[
             0.37828991345392127`, 0.5010749823612741, 0.9453889376019913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 289}], {
             RGBColor[
             0.38552079953372403`, 0.5082280098903162, 0.9458170961028769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 300}], {
             RGBColor[
             0.4377850305299138, 0.5534966599025861, 0.9491473266865091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 305}], {
             RGBColor[
             0.6596309315266682, 0.7315335449103904, 0.9685563499845072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 432}], {
             RGBColor[
             0.6144232863868914, 0.6958789900150512, 0.9641401689276407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 456}], {
             RGBColor[
             0.3541276585075292, 0.4756789204371697, 0.9440129329276471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 493}], {
             RGBColor[
             0.5234517902759379, 0.624000770437253, 0.9556271888790606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 181}], {
             RGBColor[
             0.5838876467268811, 0.6691726907027558, 0.9623201305737528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 189}], {
             RGBColor[
             0.6567597608942148, 0.7301160759368894, 0.967564374725217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 232}], {
             RGBColor[
             0.7381047575552699, 0.7953323134968859, 0.9745310423181337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 280}], {
             RGBColor[
             0.6614695904816725, 0.7339397277713925, 0.9679351497630158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 302}], {
             RGBColor[
             0.6341435577721554, 0.7117552233940616, 0.9657839443695666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 326}], {
             RGBColor[
             0.8049147133652906, 0.36546603758664487`, 0.4357177825348484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 338}], {
             RGBColor[
             0.8866500342923964, 0.9079974694670752, 0.7396483248536112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 346}], {
             RGBColor[
             0.8815478026298791, 0.8912128629367583, 0.6835675306232744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 370}], {
             RGBColor[
             0.5916646117623022, 0.6759087069348095, 0.9628156719089096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 383}], {
             RGBColor[
             0.7063203821054702, 0.7703516209167286, 0.9714659683735043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 390}], {
             RGBColor[
             0.6691221372064833, 0.7401524099458952, 0.9685375862733951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 395}], {
             RGBColor[
             0.84803720063224, 0.7663466503750598, 0.6149808209718142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 443}], {
             RGBColor[
             0.7657377612685392, 0.8169194260162985, 0.9772852418831708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 480}], {
             RGBColor[
             0.6297537319756995, 0.7081913650531002, 0.9654383612024078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 211}], {
             RGBColor[
             0.20787663392282102`, 0.33582190076568974`, 0.9351496388247592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 236}], {
             RGBColor[
             0.2528389722684402, 0.38308016914383974`, 0.9377101774777234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 289}], {
             RGBColor[
             0.2567762924328988, 0.386771450071715, 0.9379507722721243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 308}], {
             RGBColor[
             0.2152452595664099, 0.34356679351495156`, 0.9355692711542569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 362}], {
             RGBColor[
             0.19011638587642943`, 0.3171547540041677, 0.9341382189724496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 369}], {
             RGBColor[
             0.1961253105543787, 0.32347051482852174`, 0.9344804183434514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 456}], {
             RGBColor[
             0.22538315140670392`, 0.35422236061856843`, 0.9361466090968946]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 470}], {
             RGBColor[
             0.22323454419872468`, 0.35196403821341704`, 0.9360242490949797]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 214}], {
             RGBColor[
             0.2164586672192998, 0.34484216189262756`, 0.9356383729250132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 223}], {
             RGBColor[
             0.26091102585046255`, 0.3915644092563023, 0.9381698689876865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 268}], {
             RGBColor[
             0.21378017372291278`, 0.34202689540162845`, 0.93548583668287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 466}], {
             RGBColor[
             0.23226952433681827`, 0.36146037518938046`, 0.9365387778477888]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 491}], {
             RGBColor[
             0.20371206300908717`, 0.33144467268630884`, 0.9349124726721527]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 192}], {
             RGBColor[
             0.9127961865391916, 0.8801019973264443, 0.6352252611263622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 208}], {
             RGBColor[
             0.9742007870656089, 0.924158064524564, 0.38148971018664135`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 219}], {
             RGBColor[
             0.8633448747725185, 0.37637450305087206`, 0.2038017602771198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 238}], {
             RGBColor[
             0.9459691488713833, 0.8234927105285037, 0.27538371279607904`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 258}], {
             RGBColor[
             0.9746741511548784, 0.925170542447061, 0.43301247003911714`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 272}], {
             RGBColor[
             0.7608854551425784, 0.7598583476143784, 0.6209877429007751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 293}], {
             RGBColor[
             0.8633448747725185, 0.37637450305087206`, 0.2038017602771198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 403}], {
             RGBColor[
             0.8633448747725185, 0.37637450305087206`, 0.2038017602771198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 471}], {
             RGBColor[
             0.8633448747725185, 0.37637450305087206`, 0.2038017602771198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 497}], {
             RGBColor[
             0.9509833426511693, 0.843372317984329, 0.27941825080954996`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 197}], {
             RGBColor[
             0.39570626447019996`, 0.5171626103341097, 0.9464350311560986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 201}], {
             RGBColor[
             0.4728690965671932, 0.5808891368792599, 0.9522105393803614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 211}], {
             RGBColor[
             0.29686791214582525`, 0.42295867443787283`, 0.9404518482979395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 218}], {
             RGBColor[
             0.5588854033775118, 0.6492281120932448, 0.9600027877622141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 235}], {
             RGBColor[
             0.36266490816744634`, 0.48854384821151947`, 0.9443296651498113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 236}], {
             RGBColor[
             0.34183025049144444`, 0.4702169428160228, 0.9430123869509037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 289}], {
             RGBColor[
             0.345767570655903, 0.47390822374389807`, 0.9432529817453046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 300}], {
             RGBColor[
             0.3980318016520928, 0.519176873756168, 0.946583212328937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 308}], {
             RGBColor[
             0.3042365377894142, 0.4307035671871346, 0.9408714806274372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 314}], {
             RGBColor[
             0.4896677620223526, 0.594527050267013, 0.9535329918605306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 466}], {
             RGBColor[
             0.31281244439264955`, 0.4397173887710188, 0.9413598658215745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 470}], {
             RGBColor[0.3122258224217289, 0.4391008118856, 0.94132645856816]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 493}], {
             RGBColor[
             0.48369856139811684`, 0.5896809842908348, 0.9530630745214885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 242}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 249}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 269}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 282}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 310}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 323}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 406}], {
             RGBColor[
             0.8761600890568056, 0.41916385235227993`, 0.29986098883365586`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 419}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 499}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 210}], {
             RGBColor[
             0.23308695695256842`, 0.3623195486967552, 0.9365853294259726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 225}], {
             RGBColor[
             0.20819278575014724`, 0.33615419638139327`, 0.9351676432036207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 252}], {
             RGBColor[
             0.20462132433062605`, 0.3324003639857437, 0.9349642537592827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 309}], {
             RGBColor[
             0.2173048866955889, 0.3457315922156211, 0.9356865638723183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 320}], {
             RGBColor[
             0.20210480252735952`, 0.3297553400138127, 0.934820941565447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 393}], {
             RGBColor[
             0.29163543014520826`, 0.4184242024491195, 0.9401185255489448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 424}], {
             RGBColor[
             0.2286678735822072, 0.357674811888437, 0.9363336691654786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 182}], {
             RGBColor[
             0.9746509917198269, 0.978851744377486, 0.8488163971932976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 208}], {
             RGBColor[
             0.9939061257043407, 0.9897836599534299, 0.6078650602962729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 351}], {
             RGBColor[
             0.7271599458905001, 0.7821063736932174, 0.8431568209407971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 359}], {
             RGBColor[
             0.8764817671983398, 0.4201249000034494, 0.35471866035020744`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 371}], {
             RGBColor[
             0.7707283648406607, 0.8174771789318643, 0.846586686476931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 463}], {
             RGBColor[
             0.9058410813145757, 0.6396007349493169, 0.38259068137142616`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 483}], {
             RGBColor[
             0.9831143891312863, 0.9536903858164667, 0.5395991219078489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 178}], {
             RGBColor[
             0.9202554048713663, 0.8879171799621041, 0.6375652584344874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 244}], {
             RGBColor[
             0.9305033630137299, 0.9224859491112958, 0.6773766406530607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 261}], {
             RGBColor[
             0.9050998994190445, 0.9271661077872047, 0.9908104304704488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 262}], {
             RGBColor[
             0.9178226250506125, 0.9368943496024587, 0.9775831247382163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 299}], {
             RGBColor[
             0.6712865587841526, 0.7408369694039865, 0.9696570894914054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 313}], {
             RGBColor[
             0.9308645267408745, 0.9466209785289019, 0.9555065870493364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 328}], {
             RGBColor[
             0.6804227732338226, 0.7482541598759991, 0.9703763257599396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 376}], {
             RGBColor[
             0.9349113559986364, 0.9493340028297863, 0.9349936131005747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 391}], {
             RGBColor[
             0.9181691024489237, 0.8798685102007529, 0.6347260987055314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 407}], {
             RGBColor[
             0.7860294343098881, 0.8332871901386956, 0.9791708607176912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 448}], {
             RGBColor[
             0.8540113043416422, 0.8864294488354546, 0.985937554664639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 455}], {
             RGBColor[
             0.8394774341752623, 0.3928105343831808, 0.439071427873013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 475}], {
             RGBColor[
             0.9130266424173684, 0.933317513607286, 0.9857014723436948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 478}], {
             RGBColor[
             0.7002666387715365, 0.7643643038754704, 0.9719385075455431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 482}], {
             RGBColor[
             0.9100238273170578, 0.9310780190221328, 0.9907844550489121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 194}], {
             RGBColor[
             0.2061405372520611, 0.3339971530898346, 0.9350507706876843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 290}], {
             RGBColor[
             0.19627542028787323`, 0.3236282896759313, 0.9344889668707066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 297}], {
             RGBColor[
             0.22585915082839916`, 0.35472266619087656`, 0.9361737165597821]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 412}], {
             RGBColor[
             0.2150756323125279, 0.34338850451613256`, 0.9355596111330893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 484}], {
             RGBColor[
             0.2033510637646819, 0.3310652395917648, 0.9348919142992342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 186}], {
             RGBColor[
             0.8637848357389819, 0.37797025225822195`, 0.20492941108331195`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 244}], {
             RGBColor[
             0.9669644653593094, 0.9002255259238574, 0.326163615468509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 261}], {
             RGBColor[
             0.9415610017646239, 0.9049056845997665, 0.6395974052858973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 288}], {
             RGBColor[
             0.8637848357389819, 0.37797025225822195`, 0.20492941108331195`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 313}], {
             RGBColor[
             0.9673256290864539, 0.9243605553414638, 0.6042935618647849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 321}], {
             RGBColor[
             0.8637848357389819, 0.37797025225822195`, 0.20492941108331195`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 391}], {
             RGBColor[
             0.9546302047945031, 0.8576080870133145, 0.28351307352097976`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 407}], {
             RGBColor[
             0.8224905366554676, 0.8110267669512574, 0.6279578355331397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 455}], {
             RGBColor[
             0.8637848357389819, 0.37797025225822195`, 0.20492941108331195`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 475}], {
             RGBColor[
             0.9494877447629478, 0.9110570904198478, 0.6344884471591432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 498}], {
             RGBColor[
             0.8637848357389819, 0.37797025225822195`, 0.20492941108331195`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 222}], {
             RGBColor[
             0.26369928279436383`, 0.3944950440900435, 0.9383286560957851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 245}], {
             RGBColor[
             0.37656052377494753`, 0.49620970043426327`, 0.945567861444176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 255}], {
             RGBColor[
             0.26384605713258924`, 0.39464931322554897`, 0.9383370146772139]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 294}], {
             RGBColor[
             0.2430012286676811, 0.3727400768704716, 0.9371499325332977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 296}], {
             RGBColor[
             0.23166652830629497`, 0.3608265881291439, 0.9365044381159032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 312}], {
             RGBColor[
             0.25910450378636, 0.3896656400268162, 0.9380669902286457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 327}], {
             RGBColor[
             0.23500467222293953`, 0.364335189036086, 0.9366945404736147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 334}], {
             RGBColor[
             0.24162960930249294`, 0.37129841795196816`, 0.9370718208395792]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 385}], {
             RGBColor[
             0.2302154045308226, 0.35930136503456106`, 0.9364217987636353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 415}], {
             RGBColor[
             0.22772487631702723`, 0.35668366197325296`, 0.936279966866266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 438}], {
             RGBColor[
             0.27563010636510166`, 0.40703509612079425`, 0.9390080988480669]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 205}], {
             RGBColor[
             0.5242782003821684, 0.6244474620276343, 0.9557542010457972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 230}], {
             RGBColor[
             0.4493012303473422, 0.5582450689465429, 0.9510229102327686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 331}], {
             RGBColor[
             0.7154954793572077, 0.7771351534675488, 0.9726684783764996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 382}], {
             RGBColor[
             0.46332842266028784`, 0.5716558279898428, 0.9518705351051313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 413}], {
             RGBColor[
             0.5070777034000054, 0.6095492560638003, 0.9546582005878961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 418}], {
             RGBColor[
             0.7760216792869205, 0.7613486519842765, 0.619693218697663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 474}], {
             RGBColor[
             0.505167391968821, 0.6078946403171526, 0.9545364772327231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 490}], {
             RGBColor[
             0.4726781530538206, 0.5797540945256074, 0.9524662916581652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 189}], {
             RGBColor[
             0.4605412675252241, 0.5711446538797107, 0.9511671576944246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 302}], {
             RGBColor[
             0.4379250644031646, 0.5527838013368829, 0.9493867273387744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 370}], {
             RGBColor[
             0.39544611839331145`, 0.5169372848776308, 0.9464184548781174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 390}], {
             RGBColor[
             0.4729036438374925, 0.5811809878887164, 0.9521403692426029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 422}], {
             RGBColor[
             0.34276984142818484`, 0.4703062298019115, 0.9430987857933579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 443}], {
             RGBColor[
             0.5695192678995484, 0.6579480039591199, 0.9608880248523786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 451}], {
             RGBColor[
             0.3396395828866079, 0.4670161296048595, 0.9429205222002176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 237}], {
             RGBColor[
             0.6887654101141651, 0.7532085811116003, 0.9550446399454904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 351}], {
             RGBColor[
             0.7070036360153077, 0.7688374180603554, 0.9562532370834724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 359}], {
             RGBColor[
             0.8630442272815448, 0.41127892958154133`, 0.4301162711119909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 371}], {
             RGBColor[
             0.7505720549654683, 0.8042082232990024, 0.9596831026196062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 460}], {
             RGBColor[
             0.8895334088722675, 0.9142691218847867, 0.9725212169169912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 463}], {
             RGBColor[
             0.8924035413977808, 0.6307547645274091, 0.4579882921332097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 483}], {
             RGBColor[
             0.9629580792560939, 0.9404214301836048, 0.652695538050524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 202}], {
             RGBColor[
             0.23464668265559618`, 0.36395891930295865`, 0.9366741534973526]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 206}], {
             RGBColor[
             0.22097903356863421`, 0.34959335353355825`, 0.935895801101325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 243}], {
             RGBColor[
             0.2557945891305531, 0.386186709862853, 0.9378784954855774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 273}], {
             RGBColor[
             0.23550505714349235`, 0.3648611253138234, 0.9367230366545871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 279}], {
             RGBColor[
             0.28035477682361865`, 0.41200102433410457`, 0.9392771618411558]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 283}], {
             RGBColor[
             0.2250780320064527, 0.3539016607832171, 0.936129232998434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 285}], {
             RGBColor[
             0.2954522956610519, 0.4255087033323427, 0.9402233825780824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 396}], {
             RGBColor[
             0.2576449284246818, 0.38813153377926946`, 0.9379838695710464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 430}], {
             RGBColor[
             0.26651354621858253`, 0.39745301338350436`, 0.9384889242344647]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 477}], {
             RGBColor[
             0.2584102041277772, 0.38893588706450477`, 0.9380274508902138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 221}], {
             RGBColor[
             0.8369837657282427, 0.26650113164225936`, 0.18231370738115665`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 253}], {
             RGBColor[
             0.9322255008103006, 0.7603060225554952, 0.5323787942426484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 287}], {
             RGBColor[
             0.8571239304455562, 0.7024298435855887, 0.6014546314672211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 301}], {
             RGBColor[
             0.8369837657282427, 0.26650113164225936`, 0.18231370738115665`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 316}], {
             RGBColor[
             0.9311223602384289, 0.7477274618057713, 0.3091758937857617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 336}], {
             RGBColor[
             0.8369837657282427, 0.26650113164225936`, 0.18231370738115665`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 354}], {
             RGBColor[
             0.8691146527768465, 0.7119909200930725, 0.6025983172674237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 388}], {
             RGBColor[
             0.900316789777843, 0.736870657178221, 0.6055744049490553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 436}], {
             RGBColor[
             0.9230065584441681, 0.7540860752952483, 0.5773398016096436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 473}], {
             RGBColor[
             0.7413125486005306, 0.611259827036092, 0.5903276772577556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 187}], {
             RGBColor[
             0.3439018393873985, 0.4722922210934996, 0.943134098998677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 216}], {
             RGBColor[
             0.29497840118270136`, 0.42627321830582066`, 0.9401501647204071]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 224}], {
             RGBColor[
             0.30794222932777976`, 0.4398990236404763, 0.9408884355550042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 286}], {
             RGBColor[
             0.26801510124259026`, 0.39793308049680753`, 0.9386146446774454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 330}], {
             RGBColor[
             0.2727206891407805, 0.40287895172931015`, 0.9388826209469538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 333}], {
             RGBColor[
             0.3691868534914339, 0.4941928294486542, 0.944745237738726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 357}], {
             RGBColor[
             0.2704886241626608, 0.4005329099162129, 0.9387555081484942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 358}], {
             RGBColor[
             0.3526247422114796, 0.4798475610938749, 0.9436899146532672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 361}], {
             RGBColor[
             0.3651394217782484, 0.4906871475285258, 0.9444873389689651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 386}], {
             RGBColor[
             0.5820600535640958, 0.665087506482939, 0.9632927375329758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 398}], {
             RGBColor[
             0.30864187886940686`, 0.4406343996690694, 0.9409282795613612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 441}], {
             RGBColor[
             0.3444326919958216, 0.4727520189414878, 0.9431679244574711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 464}], {
             RGBColor[
             0.3004465755354037, 0.43202061625278937`, 0.9404615691603544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 481}], {
             RGBColor[
             0.30650884939950357`, 0.4383924504543215, 0.9408068066885844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 288}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 295}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 321}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 341}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 373}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 397}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 455}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 495}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 498}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 216}], {
             RGBColor[
             0.3182566714322743, 0.44643568599611877`, 0.9416334355165438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 224}], {
             RGBColor[
             0.3312204995773527, 0.4600614913307744, 0.9423717063511409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 260}], {
             RGBColor[
             0.33960819065109193`, 0.4685732783631712, 0.942860511497924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 328}], {
             RGBColor[
             0.42211567678941486`, 0.5393927026931269, 0.9482958688478269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 398}], {
             RGBColor[
             0.3319201491189798, 0.46079686735936753`, 0.9424115503574978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 399}], {
             RGBColor[
             0.3354088495669978, 0.4644637127266185, 0.9426102266869426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 407}], {
             RGBColor[
             0.5277223378654804, 0.6244257329558234, 0.9570904038055785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 464}], {
             RGBColor[
             0.3237248457849767, 0.4521830839430875, 0.9419448399564911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 478}], {
             RGBColor[
             0.4419595423271288, 0.555502846692598, 0.9498580506334303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 481}], {
             RGBColor[
             0.32978711964907653`, 0.45855491814461957`, 0.9422900774847212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 200}], {
             RGBColor[
             0.49135529375587494`, 0.5959601817284621, 0.9536484010759594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 228}], {
             RGBColor[
             0.4764305577406883, 0.5838436086796381, 0.9524734711857346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 256}], {
             RGBColor[
             0.6227687970873287, 0.6995989768913324, 0.9662311909897034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 279}], {
             RGBColor[
             0.34218136725328896`, 0.47037106759976377`, 0.9430402518488281]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 298}], {
             RGBColor[
             0.5300245996478504, 0.6267805592985796, 0.9570844268620295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 318}], {
             RGBColor[
             0.3206397205634015, 0.4477294311094059, 0.9418134869378495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 335}], {
             RGBColor[
             0.3476544631710703, 0.4755425552025606, 0.9433732128678576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 409}], {
             RGBColor[
             0.4608023334373177, 0.5711559121466802, 0.9512431601205011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 430}], {
             RGBColor[
             0.3283401366482528, 0.45582305664916356`, 0.9422520142421371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 459}], {
             RGBColor[
             0.3130997116438481, 0.4398044036707781, 0.9413840945843246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 302}], {
             RGBColor[
             0.5107971785704983, 0.6137271865710165, 0.9546309714902383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 346}], {
             RGBColor[
             0.758201423428222, 0.7931848261137132, 0.6724145577439462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 370}], {
             RGBColor[
             0.46831823256064525`, 0.5778806701117645, 0.9516626990295814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 383}], {
             RGBColor[
             0.5829740029038133, 0.6723235840936835, 0.960312995494176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 390}], {
             RGBColor[
             0.5457757580048264, 0.6421243731228501, 0.957384613394067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 422}], {
             RGBColor[
             0.41564195559551864`, 0.5312496150360451, 0.9483430299448219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 443}], {
             RGBColor[
             0.6423913820668823, 0.7188913891932535, 0.9661322690038426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 451}], {
             RGBColor[
             0.41251169705394175`, 0.5279595148389932, 0.9481647663516817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 349}], {
             RGBColor[
             0.2752751587264147, 0.4033449321472721, 0.9391093400741414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 378}], {
             RGBColor[
             0.3221600885821226, 0.4526239661018675, 0.9417793674693858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 467}], {
             RGBColor[
             0.28809331925242987`, 0.41681763157843177`, 0.9398393153533288]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 487}], {
             RGBColor[
             0.29152503768335564`, 0.4204245852328503, 0.9400347466411976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 226}], {
             RGBColor[
             0.22140390405308463`, 0.35003991935106027`, 0.935919996846875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 237}], {
             RGBColor[
             0.3261149973492088, 0.44953101328405887`, 0.9422700448294907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 271}], {
             RGBColor[
             0.2668826471852404, 0.3978409619018147, 0.9385099439884801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 311}], {
             RGBColor[
             0.22787572296700198`, 0.35684221136660643`, 0.9362885573598245]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 366}], {
             RGBColor[
             0.21187817482284405`, 0.3400277739639608, 0.9353775206592663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 405}], {
             RGBColor[
             0.20994495191990925`, 0.33799583411956474`, 0.9352674264748911]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 423}], {
             RGBColor[
             0.20464821144403264`, 0.3324286240466755, 0.9349657849406153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 429}], {
             RGBColor[
             0.23210680778710222`, 0.3612893497788038, 0.9365295113810002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 488}], {
             RGBColor[
             0.2118176137321737, 0.33996412041787133`, 0.9353740717947447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 219}], {
             RGBColor[
             0.8349445829202758, 0.3891961618334242, 0.4386390804737884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 251}], {
             RGBColor[
             0.6611025885462706, 0.7326320332459636, 0.9687519301958931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 258}], {
             RGBColor[
             0.9320737133765145, 0.9444030306208892, 0.78526845033412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 272}], {
             RGBColor[
             0.7182850173642144, 0.7790908357882066, 0.973243723195778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 435}], {
             RGBColor[
             0.6598277871485738, 0.73152786434866, 0.9686707009780946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 453}], {
             RGBColor[
             0.6640388061322713, 0.735051317746148, 0.9689732627371802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 497}], {
             RGBColor[
             0.9083829048728054, 0.8626048061581572, 0.6316742311045528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 410}], {
             RGBColor[
             0.19038075076848193`, 0.31743261826741714`, 0.9341532741619593]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 428}], {
             RGBColor[
             0.20228207150770255`, 0.3299416609516557, 0.9348310367716316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 437}], {
             RGBColor[
             0.18967305081090496`, 0.3166887807412348, 0.9341129716963235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 220}], {
             RGBColor[
             0.27841284106148134`, 0.4064257927007418, 0.9392959734312498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 254}], {
             RGBColor[
             0.22347198353028988`, 0.3522136020054152, 0.9360377709136524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 290}], {
             RGBColor[
             0.19998987236326368`, 0.3275324143170307, 0.9347004994213606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 297}], {
             RGBColor[
             0.22957360290378961`, 0.3586267908319759, 0.9363852491104362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 350}], {
             RGBColor[
             0.1999849515613838, 0.32752724224225804`, 0.9347002191889733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 377}], {
             RGBColor[
             0.19840694520434524`, 0.3258686575096288, 0.934610354061391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 412}], {
             RGBColor[
             0.21879008438791836`, 0.3472926291572319, 0.9357711436837434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 426}], {
             RGBColor[
             0.2125469848716252, 0.34073073573023605`, 0.9354156084021286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 476}], {
             RGBColor[
             0.20408939664104067`, 0.33184127425782606`, 0.9349339612642773]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.2379640347981863, 0.3674456667370949, 0.9368630717942905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 260}], {
             RGBColor[
             0.2652269236159478, 0.3957964833551174, 0.9384267915292429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 292}], {
             RGBColor[
             0.2120103022106906, 0.3401666482259477, 0.9353850451185391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 399}], {
             RGBColor[
             0.2610275825318536, 0.39168691771856473`, 0.9381765067182615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 446}], {
             RGBColor[
             0.20832130976855523`, 0.33628928327363344`, 0.9351749624563348]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 496}], {
             RGBColor[
             0.21350786360609533`, 0.34174068020339465`, 0.9354703290245638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 213}], {
             RGBColor[
             0.25723659522050063`, 0.3877023496918546, 0.9379606155991431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 332}], {
             RGBColor[
             0.22366006402010474`, 0.35241128652520237`, 0.9360484818193071]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 337}], {
             RGBColor[
             0.2289545201015995, 0.3579760955547574, 0.9363499932607025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 420}], {
             RGBColor[
             0.22671171795480946`, 0.35561876829661176`, 0.9362222689963712]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 427}], {
             RGBColor[
             0.22341549837051072`, 0.3521542325211213, 0.9360345541673653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 447}], {
             RGBColor[
             0.33114259091826304`, 0.45444303824740756`, 0.942569990376295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 454}], {
             RGBColor[
             0.2775665280001868, 0.40803814535898913`, 0.9391561710226074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 489}], {
             RGBColor[
             0.23441451862430046`, 0.36371490018601704`, 0.9366609320992263]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 500}], {
             RGBColor[
             0.2545900551674532, 0.38492066829577065`, 0.9378098990583272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 201}], {
             RGBColor[
             0.49062190566788, 0.5962657278401451, 0.9533417326780644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 236}], {
             RGBColor[
             0.3595830595921312, 0.48559353377690795`, 0.9441435802486068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 289}], {
             RGBColor[
             0.3635203797565897, 0.48928481470478324`, 0.9443841750430078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 314}], {
             RGBColor[
             0.5074205711230394, 0.6099036412278982, 0.9546641851582337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 411}], {
             RGBColor[
             0.5628841788365053, 0.6538599474387119, 0.9597631075252654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 466}], {
             RGBColor[
             0.3305652534933362, 0.45509397973190396`, 0.9424910591192776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 470}], {
             RGBColor[
             0.32997863152241563`, 0.4544774028464852, 0.942457651865863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 493}], {
             RGBColor[
             0.5014513704988036, 0.60505757525172, 0.9541942678191915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 270}], {
             RGBColor[
             0.1889882633050292, 0.3159690256545238, 0.9340739740609163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 479}], {
             RGBColor[
             0.19373559329222378`, 0.3209587704691713, 0.9343443274806416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 244}], {
             RGBColor[
             0.9841027978606212, 0.9626688772839973, 0.5824524865696615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 245}], {
             RGBColor[
             0.7369662997669877, 0.7908272343094369, 0.8756839413586472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 262}], {
             RGBColor[
             0.9714220598975036, 0.9770772777751602, 0.8826589706548171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 376}], {
             RGBColor[
             0.9885107908455275, 0.9895169310024878, 0.8400694590171756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 448}], {
             RGBColor[
             0.9076107391885334, 0.9266123770081562, 0.8910134005812398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 455}], {
             RGBColor[
             0.8752103907398564, 0.41959915316498186`, 0.3757886584840803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 475}], {
             RGBColor[
             0.9666260772642596, 0.9735004417799876, 0.8907773182602956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 482}], {
             RGBColor[
             0.9636232621639489, 0.9712609471948344, 0.895860300965513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 228}], {
             RGBColor[
             0.5875078389354265, 0.6760043564311329, 0.9606699156745733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 256}], {
             RGBColor[
             0.7338460782820668, 0.7917597246428272, 0.9744276354785424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 298}], {
             RGBColor[
             0.6411018808425886, 0.7189413070500743, 0.9652808713508684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 452}], {
             RGBColor[
             0.4981470175789616, 0.6018428315420548, 0.9540811637122809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 468}], {
             RGBColor[
             0.48541856175705617`, 0.5908180828599114, 0.9532701177626406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 218}], {
             RGBColor[
             0.6538010445751918, 0.7283312295992802, 0.96690948928418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 235}], {
             RGBColor[
             0.4575805493651263, 0.5676469657175549, 0.9512363666717771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 236}], {
             RGBColor[
             0.4367458916891245, 0.5493200603220583, 0.9499190884728695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 289}], {
             RGBColor[
             0.440683211853583, 0.5530113412499335, 0.9501596832672705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 300}], {
             RGBColor[
             0.49294744284977277`, 0.5982799912622034, 0.9534899138509028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 305}], {
             RGBColor[
             0.714793343846527, 0.7763168762700076, 0.9728989371489009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 314}], {
             RGBColor[
             0.5845834032200327, 0.6736301677730485, 0.9604396933824965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 406}], {
             RGBColor[
             0.780813502467645, 0.8246149057210677, 0.7651321037016474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 493}], {
             RGBColor[
             0.5786142025957969, 0.6687841017968702, 0.9599697760434542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 243}], {
             RGBColor[
             0.23381644008435298`, 0.36308628172016266`, 0.9366268724111542]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 273}], {
             RGBColor[
             0.21352690809729225`, 0.3417606971711331, 0.9354714135801638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 279}], {
             RGBColor[
             0.25837662777741854`, 0.38890059619141426`, 0.9380255387667326]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 283}], {
             RGBColor[
             0.2030998829602526, 0.3308012326405268, 0.9348776099240107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 285}], {
             RGBColor[
             0.2734741466148518, 0.4024082751896524, 0.9389717595036591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 396}], {
             RGBColor[
             0.23566677937848166`, 0.36503110563657915`, 0.9367322464966231]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 421}], {
             RGBColor[
             0.20744896350666275`, 0.3353723920424369, 0.9351252836272407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 430}], {
             RGBColor[
             0.24453539717238243`, 0.37435258524081405`, 0.9372373011600414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 459}], {
             RGBColor[
             0.22929497216797767`, 0.3583339322624286, 0.9363693815022289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 477}], {
             RGBColor[
             0.2364320550815771, 0.36583545892181446`, 0.9367758278157905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 264}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 281}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 295}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 324}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 341}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 374}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 397}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 275}], {
             RGBColor[
             0.9068456198442363, 0.8406001496363356, 0.6268746543862641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 306}], {
             RGBColor[
             0.6716952973173317, 0.7411945060226874, 0.9696596817495633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 331}], {
             RGBColor[
             0.8538682923947138, 0.8863154149909298, 0.9859239140574727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 346}], {
             RGBColor[
             0.9316157699795097, 0.9308133831466772, 0.688428591304491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 348}], {
             RGBColor[
             0.9214887091320801, 0.896652428961333, 0.6490868722471982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 355}], {
             RGBColor[
             0.8646089820506718, 0.5941398003894627, 0.4641583607120223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 390}], {
             RGBColor[
             0.719190104556114, 0.779752930155814, 0.9733986469546118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 431}], {
             RGBColor[
             0.9368455281102752, 0.9478707558976731, 0.7583898546015062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 444}], {
             RGBColor[
             0.8607679520740443, 0.5646159608390356, 0.460480186068581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 486}], {
             RGBColor[
             0.9371733075375102, 0.9485718429489449, 0.7940666224358858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 230}], {
             RGBColor[
             0.3700829820093897, 0.493707900841167, 0.944848513673534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 331}], {
             RGBColor[
             0.6362772310192553, 0.7125979853621729, 0.9664940818172649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 382}], {
             RGBColor[
             0.38411017432233535`, 0.5071186598844669, 0.9456961385458966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 413}], {
             RGBColor[
             0.4278594550620529, 0.5450120879584244, 0.9484838040286614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 474}], {
             RGBColor[
             0.4259491436308685, 0.5433574722117767, 0.9483620806734884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 490}], {
             RGBColor[
             0.3934599047158681, 0.5152169264202315, 0.9462918950989305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 254}], {
             RGBColor[
             0.21121110658430017`, 0.33932664295068204`, 0.9353395321099203]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 377}], {
             RGBColor[
             0.18614606825835553`, 0.31298169845489565`, 0.9339121152576589]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 396}], {
             RGBColor[
             0.2219991302915197, 0.35066553986717874`, 0.9359538941005956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 476}], {
             RGBColor[
             0.19182851969505096`, 0.31895431520309286`, 0.9342357224605452]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 257}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 266}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 281}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 293}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 317}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 322}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 343}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 374}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 403}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 440}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 445}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 471}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 238}], {
             RGBColor[
             0.9647733116194365, 0.8867812659004515, 0.37390414215136103`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[
             0.9934783139029316, 0.9884590978190089, 0.5315328993943991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 266}], {
             RGBColor[
             0.8758809832712207, 0.41856687329883735`, 0.26948204651397445`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 293}], {
             RGBColor[
             0.8758809832712207, 0.41856687329883735`, 0.26948204651397445`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 403}], {
             RGBColor[
             0.8758809832712207, 0.41856687329883735`, 0.26948204651397445`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 471}], {
             RGBColor[
             0.8758809832712207, 0.41856687329883735`, 0.26948204651397445`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 483}], {
             RGBColor[
             0.9822132132406076, 0.9513533457595487, 0.41174420115349936`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 497}], {
             RGBColor[
             0.9697875053992224, 0.9066608733562769, 0.377938680164832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 231}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 233}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 259}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 275}], {
             RGBColor[
             0.8560290549644465, 0.34736971536429956`, 0.19791527993518332`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 348}], {
             RGBColor[
             0.8657911144896757, 0.38473790158096455`, 0.21272342517580606`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 355}], {
             RGBColor[
             0.8304768118928137, 0.23526370799810264`, 0.17681793552818148`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 372}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 379}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 400}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 404}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 431}], {
             RGBColor[
             0.8760289938084724, 0.418883452871858, 0.28559208007867803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 444}], {
             RGBColor[
             0.8285562969045, 0.22050178822288907`, 0.17497884820646079`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 486}], {
             RGBColor[
             0.8762475134266291, 0.4193508442393725, 0.30937659196826445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 225}], {
             RGBColor[
             0.22552288916917368`, 0.3543692338668101, 0.9361545669557438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 252}], {
             RGBColor[
             0.22195142774965249`, 0.3506154014711605, 0.9359511775114058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 280}], {
             RGBColor[
             0.396625050619534, 0.5101349644825113, 0.9473626025497911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 309}], {
             RGBColor[
             0.23463499011461536`, 0.36394662970103786`, 0.9366734876244414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 320}], {
             RGBColor[
             0.21943490594638596`, 0.34797037749922943`, 0.9358078653175701]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 393}], {
             RGBColor[
             0.30896553356423473`, 0.43663923993453624`, 0.9411054493010679]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 424}], {
             RGBColor[
             0.24599797700123366`, 0.37588984937385383`, 0.9373205929176016]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 480}], {
             RGBColor[
             0.364909192113561, 0.48438660176421894`, 0.9448658139891831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 236}], {
             RGBColor[
             0.26074470726775645`, 0.39138959788067107`, 0.9381603973904477]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 289}], {
             RGBColor[
             0.264682027432215, 0.3950808788085463, 0.9384009921848486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 308}], {
             RGBColor[
             0.22315099456572612`, 0.35187622225178283`, 0.936019491066981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 362}], {
             RGBColor[
             0.19802212087574567`, 0.325464182740999, 0.934588438885174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 369}], {
             RGBColor[
             0.20403104555369495`, 0.33177994356535306`, 0.9349306382561757]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 466}], {
             RGBColor[
             0.2317269011689615, 0.36089004383566703`, 0.9365078762611184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 470}], {
             RGBColor[
             0.23114027919804092`, 0.3602734669502483, 0.9364744690077039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 216}], {
             RGBColor[
             0.23063173496240144`, 0.3597389547150244, 0.9364455081658081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 217}], {
             RGBColor[
             0.1904154630441735, 0.3174691030700544, 0.9341552509747078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 224}], {
             RGBColor[
             0.24359556310747985`, 0.37336476004968, 0.9371837790004052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 286}], {
             RGBColor[
             0.20366843502229037`, 0.33139881690601125`, 0.9349099881228464]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 319}], {
             RGBColor[
             0.18959797954384694`, 0.31660987607976354`, 0.9341086964987225]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 330}], {
             RGBColor[
             0.20837402292048057`, 0.33634468813851387`, 0.9351779643923548]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 357}], {
             RGBColor[
             0.2061419579423609, 0.3339986463254166, 0.9350508515938951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 492}], {
             RGBColor[
             0.19335812540385172`, 0.3205620277856458, 0.9343228312428125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 251}], {
             RGBColor[
             0.3656301307264068, 0.4883851452501694, 0.9446184564254285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 332}], {
             RGBColor[
             0.24567430192070422`, 0.375549646342032, 0.9373021601005997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 337}], {
             RGBColor[
             0.250968758002199, 0.38111445537158695`, 0.9376036715419951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 420}], {
             RGBColor[
             0.24872595585540894`, 0.3787571281134413, 0.9374759472776638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 447}], {
             RGBColor[
             0.3531568288188625, 0.47758139806423716`, 0.9438236686575876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 454}], {
             RGBColor[
             0.29958076590078625`, 0.43117650517581874`, 0.9404098493039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 489}], {
             RGBColor[
             0.25642875652489994`, 0.38685326000284664`, 0.9379146103805189]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 500}], {
             RGBColor[
             0.2766042930680527, 0.40805902811260025`, 0.9390635773396199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 223}], {
             RGBColor[
             0.2605020778119116, 0.39113457893898207`, 0.9381465800018753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 268}], {
             RGBColor[
             0.21337122568436184`, 0.3415970650843082, 0.9354625476970588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 466}], {
             RGBColor[
             0.23186057629826734`, 0.3610305448720602, 0.9365154888619778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 470}], {
             RGBColor[
             0.2312739543273467, 0.36041396798664144`, 0.9364820816085633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 491}], {
             RGBColor[
             0.20330311497053621`, 0.3310148423689886, 0.9348891836863416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 402}], {
             RGBColor[
             0.2785766923854661, 0.4061119675803237, 0.9393231009461043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 417}], {
             RGBColor[
             0.23113355417435436`, 0.36026639852396264`, 0.9364740860275538]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 217}], {
             RGBColor[
             0.22911696130934928`, 0.3581468315634698, 0.9363592440471735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 224}], {
             RGBColor[
             0.2822970613726556, 0.41404248854309544`, 0.939387772072871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 292}], {
             RGBColor[
             0.23746813104113765`, 0.36692444044632255`, 0.9368348308089505]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 358}], {
             RGBColor[
             0.32697957425635543`, 0.45399102599649405`, 0.9421892511711341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 361}], {
             RGBColor[
             0.3394942538231242, 0.464830612431145, 0.9429866754868319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 398}], {
             RGBColor[
             0.2829967109142827, 0.4147778645716886, 0.939427616079228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 399}], {
             RGBColor[
             0.28648541136230066`, 0.41844470993893956`, 0.9396262924086728]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 464}], {
             RGBColor[
             0.27480140758027954`, 0.40616408115540853`, 0.9389609056782213]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 481}], {
             RGBColor[
             0.2808636814443794, 0.4125359153569407, 0.9393061432064513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 292}], {
             RGBColor[
             0.1972518591229097, 0.32465458880135256`, 0.93454457361785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 398}], {
             RGBColor[
             0.24278043899605473`, 0.37250801292671853`, 0.9371373588881275]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 464}], {
             RGBColor[
             0.23458513566205164`, 0.3638942295104385, 0.936670648487121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 481}], {
             RGBColor[
             0.2406474095261515, 0.3702660637119706, 0.9370158860153509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 496}], {
             RGBColor[
             0.19874942051831446`, 0.3262286207787995, 0.9346298575238747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 235}], {
             RGBColor[
             0.543596856175445, 0.6359859409315397, 0.9590286150536299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 274}], {
             RGBColor[
             0.6118775615619095, 0.6942958574577106, 0.963609119130596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.5789637496600913, 0.6666189664761881, 0.9612821622327556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 305}], {
             RGBColor[
             0.8008096506568456, 0.8446558514839924, 0.9806911855307536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 310}], {
             RGBColor[
             0.7914851171285034, 0.354974734937755, 0.4343792458886776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 314}], {
             RGBColor[
             0.6705997100303512, 0.7419691429870332, 0.9682319417643492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 406}], {
             RGBColor[
             0.8668298092779636, 0.8929538809350525, 0.7729243520835001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 432}], {
             RGBColor[
             0.7556020055170689, 0.8090012965886532, 0.976275004473887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 493}], {
             RGBColor[
             0.6646305094061155, 0.737123077010855, 0.9677620244253071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 238}], {
             RGBColor[
             0.857059891141737, 0.3514566373014637, 0.19874471492026624`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 258}], {
             RGBColor[
             0.8761965593307338, 0.4192418585805019, 0.3038305530822916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 293}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 403}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 445}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 471}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 497}], {
             RGBColor[
             0.8604026869949277, 0.3647097089386806, 0.20143440692924686`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 254}], {
             RGBColor[
             0.2920298352643197, 0.42073811697522306`, 0.9400714411065638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 297}], {
             RGBColor[
             0.2981314546378194, 0.42715130580178384`, 0.9404189193033476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 325}], {
             RGBColor[
             0.38679117901764243`, 0.5094408114003279, 0.9458669697943621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 392}], {
             RGBColor[
             0.39450251795097435`, 0.5161199856012157, 0.9463583294923248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 412}], {
             RGBColor[
             0.2873479361219482, 0.41581714412703974`, 0.9398048138766548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 413}], {
             RGBColor[
             0.3788148254377005, 0.50253209483257, 0.9453587235974608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 426}], {
             RGBColor[
             0.281104836605655, 0.409255250700044, 0.93944927859504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 474}], {
             RGBColor[
             0.37690451400651614`, 0.5008774790859223, 0.9452370002422877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 490}], {
             RGBColor[
             0.34441527509151576`, 0.47273693329437716`, 0.9431668146677299]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 234}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 301}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 336}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 294}], {
             RGBColor[
             0.23651889122655595`, 0.36592672921591685`, 0.9367807730057844]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 296}], {
             RGBColor[
             0.22518419086516983`, 0.35401324047458915`, 0.9361352785883901]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 339}], {
             RGBColor[
             0.22078402621432447`, 0.3493883884399983, 0.9358846957209846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 344}], {
             RGBColor[
             0.2425145104333196, 0.3722285051464392, 0.9371222146498859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 438}], {
             RGBColor[
             0.2691477689239765, 0.4002217484662395, 0.9386389393205536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 439}], {
             RGBColor[
             0.26180020973842244`, 0.3924989979000629, 0.938220506694676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 246}], {
             RGBColor[
             0.38131973644829154`, 0.5042325916141828, 0.9455639325855753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 268}], {
             RGBColor[
             0.25782358431552455`, 0.3883193124479829, 0.9379940437597322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 411}], {
             RGBColor[
             0.5086318602725991, 0.6065187599425428, 0.9563190333306388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 286}], {
             RGBColor[
             0.2553337614325445, 0.3857023507340823, 0.9378522520299093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 330}], {
             RGBColor[
             0.2600393493307347, 0.39064822196658494`, 0.9381202282994179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 333}], {
             RGBColor[
             0.3565055136813881, 0.481962099685929, 0.9439828450911899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 358}], {
             RGBColor[
             0.33994340240143384`, 0.4676168313311497, 0.9429275220057312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 361}], {
             RGBColor[
             0.3524580819682026, 0.4784564177658006, 0.943724946321429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 398}], {
             RGBColor[
             0.29596053905936104`, 0.4284036699063442, 0.9401658869138251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 441}], {
             RGBColor[
             0.33175135218577584`, 0.46052128917876256`, 0.942405531809935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 464}], {
             RGBColor[
             0.28776523572535795`, 0.41978988649006416`, 0.9396991765128184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 481}], {
             RGBColor[
             0.2938275095894578, 0.4261617206915963, 0.9400444140410484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 247}], {
             RGBColor[
             0.2013053783371785, 0.3289150945035113, 0.9347754155404584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 252}], {
             RGBColor[
             0.1970572565472313, 0.32445004915579856`, 0.9345334912890539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 309}], {
             RGBColor[
             0.20974081891219415`, 0.337781277385676, 0.9352558014020895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 320}], {
             RGBColor[
             0.19454073474396477`, 0.32180502518386755`, 0.9343901790952183]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 424}], {
             RGBColor[
             0.22110380579881245`, 0.3497244970584919, 0.9359029066952498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 284}], {
             RGBColor[
             0.25636693278706735`, 0.38678827933453314`, 0.9379110896101094]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 345}], {
             RGBColor[
             0.22193035948375894`, 0.35059325738790115`, 0.9359499777048308]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 366}], {
             RGBColor[
             0.20408822256120682`, 0.33184004022547964`, 0.9349338944021677]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 389}], {
             RGBColor[
             0.23071843962178798`, 0.35983008680943257`, 0.9364504458678921]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 405}], {
             RGBColor[
             0.202154999658272, 0.32980810038108366`, 0.9348238002177924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 429}], {
             RGBColor[
             0.224316855525465, 0.35310161604032264`, 0.9360858851239015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 472}], {
             RGBColor[
             0.2053352778859962, 0.33315077443970764`, 0.9350049123580614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 488}], {
             RGBColor[
             0.20402766147053647`, 0.33177638667939024`, 0.9349304455376461]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 229}], {
             RGBColor[
             0.3363119952168668, 0.45938358895469533`, 0.9428824248934964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 263}], {
             RGBColor[
             0.3111215525527843, 0.43756489362752915`, 0.9412773121619749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 265}], {
             RGBColor[
             0.22119979691073288`, 0.34982538980330835`, 0.9359083732470674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 267}], {
             RGBColor[
             0.32291920761564974`, 0.44778342947559846`, 0.9420290483103237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 270}], {
             RGBColor[
             0.21213527831829654`, 0.34029800603898447`, 0.9353921623229817]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 329}], {
             RGBColor[
             0.21529055299948083`, 0.3436143997848786, 0.9355718505482646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 424}], {
             RGBColor[
             0.24090488888578881`, 0.3705366908440838, 0.9370305490839757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 256}], {
             RGBColor[
             0.7189213422668801, 0.7796431515940032, 0.9732527055883174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 279}], {
             RGBColor[
             0.4383339124328404, 0.5504152423024345, 0.9500617664474421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 287}], {
             RGBColor[
             0.7052588333133122, 0.7687490378133541, 0.9719495632876605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 298}], {
             RGBColor[
             0.6261771448274018, 0.7068247340012503, 0.9641059414606434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 318}], {
             RGBColor[
             0.41679226574295297`, 0.5277736058120767, 0.9488350015364635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 335}], {
             RGBColor[
             0.44380700835062176`, 0.5555867299052314, 0.9503947274664715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 409}], {
             RGBColor[
             0.5569548786168692, 0.6512000868493509, 0.9582646747191151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 468}], {
             RGBColor[
             0.47049382574186954`, 0.5787015098110876, 0.9520951878724158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 232}], {
             RGBColor[
             0.5642482406538483, 0.6557297115102981, 0.9595587106539356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 263}], {
             RGBColor[
             0.40720266362894586`, 0.5271202134595926, 0.9471675715446273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 267}], {
             RGBColor[
             0.4190003186918113, 0.5373387493076619, 0.9479193076929763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 280}], {
             RGBColor[
             0.4876130735802507, 0.5943371257848047, 0.9529628180988177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 393}], {
             RGBColor[
             0.39995355652495146`, 0.5208414012368296, 0.9467056648500944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 480}], {
             RGBColor[
             0.4558972150742777, 0.5685887630665123, 0.9504660295382097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 485}], {
             RGBColor[
             0.493481350800354, 0.5991012575949606, 0.9534247903777919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 382}], {
             RGBColor[
             0.3091332042875092, 0.4409162668033755, 0.940964847732868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 413}], {
             RGBColor[
             0.35288248502722674`, 0.4788096948773328, 0.9437525132156328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 474}], {
             RGBColor[
             0.3509721735960423, 0.4771550791306852, 0.9436307898604598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 484}], {
             RGBColor[
             0.24969102716362834`, 0.37977147924743493`, 0.9375309066609718]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 490}], {
             RGBColor[
             0.31848293468104194`, 0.4490145333391401, 0.9415606042859019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 233}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 275}], {
             RGBColor[
             0.8560290549644465, 0.34736971536429956`, 0.19791527993518332`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 326}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 346}], {
             RGBColor[
             0.8725424883879621, 0.4075118710378607, 0.23895123788066785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 355}], {
             RGBColor[
             0.8304768118928137, 0.23526370799810264`, 0.17681793552818148`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 395}], {
             RGBColor[
             0.8502020870562027, 0.32426772933006165`, 0.19322676477969444`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 404}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 431}], {
             RGBColor[
             0.8760289938084724, 0.418883452871858, 0.28559208007867803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 444}], {
             RGBColor[
             0.8285562969045, 0.22050178822288907`, 0.17497884820646079`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 486}], {
             RGBColor[
             0.8762475134266291, 0.4193508442393725, 0.30937659196826445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 267}], {
             RGBColor[
             0.5508554530526312, 0.6441295520312013, 0.958705334070763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 280}], {
             RGBColor[
             0.6194682079410706, 0.701127928508344, 0.9637488444766045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 338}], {
             RGBColor[
             0.8446486517517946, 0.8751856702040267, 0.7354620195671999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 383}], {
             RGBColor[
             0.6643189995648684, 0.7375398216536801, 0.9672796630870929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 393}], {
             RGBColor[
             0.5318086908857713, 0.627632203960369, 0.9574916912278812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 395}], {
             RGBColor[
             0.806035818091638, 0.7335348511120112, 0.6107945156854029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 480}], {
             RGBColor[
             0.5877523494350976, 0.6753795657900517, 0.9612520559159965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 259}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 275}], {
             RGBColor[
             0.8560290549644465, 0.34736971536429956`, 0.19791527993518332`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 326}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 346}], {
             RGBColor[
             0.8725424883879621, 0.4075118710378607, 0.23895123788066785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 348}], {
             RGBColor[
             0.8657911144896757, 0.38473790158096455`, 0.21272342517580606`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 355}], {
             RGBColor[
             0.8304768118928137, 0.23526370799810264`, 0.17681793552818148`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 379}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 400}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 404}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 431}], {
             RGBColor[
             0.8760289938084724, 0.418883452871858, 0.28559208007867803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 444}], {
             RGBColor[
             0.8285562969045, 0.22050178822288907`, 0.17497884820646079`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 486}], {
             RGBColor[
             0.8762475134266291, 0.4193508442393725, 0.30937659196826445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 336}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 449}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 274}], {
             RGBColor[
             0.415657066351844, 0.5336115935759853, 0.9479359965181933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 284}], {
             RGBColor[
             0.32324813737403335`, 0.4535130250531508, 0.9418506505358348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 300}], {
             RGBColor[
             0.3827432544500259, 0.5059347025944629, 0.9456090396203527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 305}], {
             RGBColor[
             0.6045891554467802, 0.6839715876022671, 0.9650180629183508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 308}], {
             RGBColor[
             0.2889479905873472, 0.41746139602542953`, 0.9398973079188528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 345}], {
             RGBColor[
             0.28881156407072495`, 0.4173180031065188, 0.9398895386305561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 389}], {
             RGBColor[
             0.29759964420875396`, 0.4265548325280502, 0.9403900067936175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 432}], {
             RGBColor[
             0.5593815103070034, 0.6483170327069279, 0.9606018818614842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 456}], {
             RGBColor[
             0.2990858824276412, 0.4281169631290464, 0.9404746458614907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 289}], {
             RGBColor[
             0.3096443657778342, 0.4423391471866963, 0.9409615308378128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 300}], {
             RGBColor[
             0.361908596774024, 0.4876077971989662, 0.9442917614214452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 308}], {
             RGBColor[
             0.26811333291134537`, 0.39913449062993284`, 0.9385800297199454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 314}], {
             RGBColor[
             0.4535445571442839, 0.5629579737098113, 0.9512415409530388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 466}], {
             RGBColor[
             0.27668923951458074`, 0.40814831221381703`, 0.9390684149140827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 470}], {
             RGBColor[
             0.27610261754366017`, 0.40753173532839826`, 0.9390350076606682]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 493}], {
             RGBColor[
             0.4475753565200481, 0.558111907733633, 0.9507716236139967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 241}], {
             RGBColor[
             0.3816373640692611, 0.5049768359303111, 0.9455385732631909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 274}], {
             RGBColor[
             0.4534869550610022, 0.5663779417903663, 0.9503464835750837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 284}], {
             RGBColor[
             0.3610780260831915, 0.4862793732675318, 0.9442611375927252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 351}], {
             RGBColor[
             0.44127436428483835`, 0.5564632104273317, 0.9493850636929899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 371}], {
             RGBColor[
             0.4848427832349989, 0.5918340156659786, 0.9528149292291238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 429}], {
             RGBColor[
             0.32902794882158914`, 0.4525927099733213, 0.9424359331065173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 432}], {
             RGBColor[
             0.5972113990161616, 0.6810833809213088, 0.9630123689183746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 460}], {
             RGBColor[
             0.6238041371417982, 0.701894914251763, 0.9656530435265088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 258}], {
             RGBColor[
             0.9652466757087061, 0.8877937438229484, 0.4254269020038368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 266}], {
             RGBColor[
             0.857059891141737, 0.3514566373014637, 0.19874471492026624`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 293}], {
             RGBColor[
             0.857059891141737, 0.3514566373014637, 0.19874471492026624`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 403}], {
             RGBColor[
             0.857059891141737, 0.3514566373014637, 0.19874471492026624`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 445}], {
             RGBColor[
             0.857059891141737, 0.3514566373014637, 0.19874471492026624`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 471}], {
             RGBColor[
             0.857059891141737, 0.3514566373014637, 0.19874471492026624`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 483}], {
             RGBColor[
             0.9539815750463821, 0.8506879917634884, 0.30563820376293704`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 497}], {
             RGBColor[
             0.9415558672049971, 0.8059955193602164, 0.27183268277426964`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 251}], {
             RGBColor[
             0.35362694944486533`, 0.47576904067762016`, 0.9439348930085601]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 272}], {
             RGBColor[
             0.41080937826280917`, 0.5222278432198632, 0.9484266860084449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 332}], {
             RGBColor[
             0.23367112063916273`, 0.36293354176948267`, 0.9366185966837315]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 387}], {
             RGBColor[
             0.2385452232211448, 0.3680565326190986, 0.9368961696151867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 435}], {
             RGBColor[
             0.35235214804716863`, 0.47466487178031647`, 0.9438536637907615]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 453}], {
             RGBColor[
             0.356563167030866, 0.4781883251778045, 0.9441562255498472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 454}], {
             RGBColor[
             0.28757758461924476`, 0.4185604006032694, 0.9397262858870317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 489}], {
             RGBColor[
             0.24442557524335845`, 0.37423715543029734`, 0.9372310469636506]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 434}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 495}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 271}], {
             RGBColor[
             0.3224050139052927, 0.4532867845480669, 0.9417784724221802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 304}], {
             RGBColor[
             0.2849583416813991, 0.4139279577846052, 0.9396459398364165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 311}], {
             RGBColor[
             0.28339808968705427`, 0.4122880340128587, 0.9395570857935246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 351}], {
             RGBColor[
             0.39987558997040373`, 0.5206056728790665, 0.946747170401173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 371}], {
             RGBColor[
             0.4434440089205643, 0.5559764781177132, 0.9501770359373067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 429}], {
             RGBColor[
             0.28762917450715453`, 0.416735172425056, 0.9397980398147002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 442}], {
             RGBColor[
             0.3936637903637048, 0.5153935219207971, 0.9463048865121216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 249}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 269}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 282}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 310}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 323}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 419}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 449}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 499}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 273}], {
             RGBColor[
             0.23467481457224915`, 0.36398848773102743`, 0.9366757555683887]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 279}], {
             RGBColor[
             0.27952453425237545`, 0.4111283867513086, 0.9392298807549574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 283}], {
             RGBColor[
             0.2242477894352095, 0.3530290232004211, 0.9360819519122355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 285}], {
             RGBColor[
             0.2946220530898087, 0.4246360657495467, 0.9401761014918839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 318}], {
             RGBColor[
             0.257982887562488, 0.3884867502609507, 0.9380031158439788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 335}], {
             RGBColor[
             0.2849976301701568, 0.4162998743541054, 0.9395628417739867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 396}], {
             RGBColor[
             0.2568146858534386, 0.38725889619647347`, 0.937936588484848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 421}], {
             RGBColor[
             0.22859686998161965`, 0.35760018260233123`, 0.9363296256154655]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 430}], {
             RGBColor[
             0.26568330364733933`, 0.3965803758007084, 0.9384416431482663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 459}], {
             RGBColor[
             0.2504428786429346, 0.3805617228223229, 0.9375737234904538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 477}], {
             RGBColor[
             0.257579961556534, 0.3880632494817088, 0.9379801698040153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 261}], {
             RGBColor[
             0.9518089599069877, 0.9394744537489581, 0.6794087875044705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 262}], {
             RGBColor[
             0.9645316855385555, 0.9492026955642121, 0.6661814817722379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 295}], {
             RGBColor[
             0.8706168078338911, 0.40101609835768304`, 0.23147033256236077`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 341}], {
             RGBColor[
             0.8706168078338911, 0.40101609835768304`, 0.23147033256236077`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 376}], {
             RGBColor[
             0.9816204164865794, 0.9616423487915396, 0.6235919701345964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 391}], {
             RGBColor[
             0.9648781629368668, 0.8921768561625062, 0.323324455739553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 407}], {
             RGBColor[
             0.8327384947978311, 0.845595536100449, 0.6677692177517128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 448}], {
             RGBColor[
             0.9007203648295853, 0.898737794797208, 0.6745359116986607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 455}], {
             RGBColor[
             0.8706168078338911, 0.40101609835768304`, 0.23147033256236077`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 475}], {
             RGBColor[
             0.9597357029053115, 0.9456258595690394, 0.6742998293777165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 478}], {
             RGBColor[
             0.7469756992594796, 0.7766726498372237, 0.6605368645795646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 482}], {
             RGBColor[
             0.9567328878050008, 0.9433863649838862, 0.6793828120829337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 262}], {
             RGBColor[
             0.717395187444922, 0.7773610525896517, 0.9594129365612236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 299}], {
             RGBColor[
             0.4708591211784622, 0.5813036723911794, 0.9514869013144127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 376}], {
             RGBColor[
             0.7344839183929459, 0.7898007058169793, 0.916823424923582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 438}], {
             RGBColor[
             0.3820090099045602, 0.5019364048104593, 0.9458781446689446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 448}], {
             RGBColor[
             0.6535838667359518, 0.7268961518226476, 0.9677673664876463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 475}], {
             RGBColor[
             0.712599204811678, 0.773784216594479, 0.9675312841667021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 482}], {
             RGBColor[
             0.7095963897113673, 0.7715447220093258, 0.9726142668719193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 384}], {
             RGBColor[
             0.5460523779791054, 0.6423489456795577, 0.9574063899317347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 402}], {
             RGBColor[
             0.4049563520885143, 0.5250559960278285, 0.9470572012623077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 411}], {
             RGBColor[
             0.5849971602778163, 0.6728945252540688, 0.9612048898516654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 458}], {
             RGBColor[
             0.45506828709517866`, 0.5684604354315133, 0.9502502894486882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 252}], {
             RGBColor[
             0.1977339169176573, 0.3251612621078617, 0.9345720260961203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 278}], {
             RGBColor[
             0.20238002081431636`, 0.33004461188325157`, 0.9348366148397402]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 309}], {
             RGBColor[
             0.21041747928262017`, 0.3384924903377391, 0.9352943362091559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 401}], {
             RGBColor[
             0.19433196502451466`, 0.32158559497196076`, 0.9343782899685427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 451}], {
             RGBColor[
             0.24679602556146502`, 0.37672864900985814`, 0.9373660406024997]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 339}], {
             RGBColor[
             0.184537889109962, 0.31129140020548685`, 0.9338205318342458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 344}], {
             RGBColor[
             0.20626837332895714`, 0.33413151691192766`, 0.935058050763147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 387}], {
             RGBColor[
             0.2032853235143931, 0.33099614242053865`, 0.9348881704892343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 439}], {
             RGBColor[
             0.22555407263405997`, 0.35440200966555135`, 0.9361563428079372]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 269}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 282}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 310}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 323}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 406}], {
             RGBColor[
             0.8761600890568056, 0.41916385235227993`, 0.29986098883365586`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 419}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 499}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 263}], {
             RGBColor[
             0.37074736764175087`, 0.49554446837193705`, 0.9448446723204758]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 365}], {
             RGBColor[
             0.3297610853863787, 0.45923924976533154`, 0.9422625362213943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 485}], {
             RGBColor[
             0.45702605481315906`, 0.567525512507305, 0.9511018911536404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 258}], {
             RGBColor[
             0.7229805531619574, 0.7777005783665802, 0.766539139108648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 272}], {
             RGBColor[
             0.5091918571496574, 0.6123883835338977, 0.9545144119703061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 435}], {
             RGBColor[
             0.4507346269340168, 0.564825412094351, 0.9499413897526227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 447}], {
             RGBColor[
             0.4395361264241692, 0.5551258338057223, 0.9492278312025804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 453}], {
             RGBColor[
             0.4549456459177142, 0.5683488654918392, 0.9502439515117083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 454}], {
             RGBColor[
             0.38596006350609297`, 0.5087209409173039, 0.9458140118488928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 309}], {
             RGBColor[
             0.20616935749267296`, 0.33402744499002646`, 0.9350524119577515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 320}], {
             RGBColor[
             0.19096927332444358`, 0.31805119278821803`, 0.9341867896508802]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 424}], {
             RGBColor[
             0.21753234437929125`, 0.3459706646628423, 0.9356995172509117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 287}], {
             RGBColor[
             0.9130361340711288, 0.9314864712143058, 0.9153283035663997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 301}], {
             RGBColor[
             0.8742585681452911, 0.41920555006140414`, 0.39156282211394233`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 336}], {
             RGBColor[
             0.8742585681452911, 0.41920555006140414`, 0.39156282211394233`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 354}], {
             RGBColor[
             0.9250268564024191, 0.9410475477217897, 0.9164719893666022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 388}], {
             RGBColor[
             0.9562289934034156, 0.9659272848069381, 0.9194480770482338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 436}], {
             RGBColor[
             0.9789187620697407, 0.9831427029239654, 0.8912134737088222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 473}], {
             RGBColor[
             0.7972247522261032, 0.8403164546648092, 0.9042013493569341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 350}], {
             RGBColor[
             0.21360194576422215`, 0.3418395665167393, 0.9354756868642873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 377}], {
             RGBColor[
             0.21202393940718356`, 0.34018098178411005`, 0.935385821736705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 412}], {
             RGBColor[
             0.2324070785907567, 0.36160495343171317`, 0.9365466113590574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 426}], {
             RGBColor[
             0.22616397907446353`, 0.3550430600047173, 0.9361910760774426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 476}], {
             RGBColor[
             0.217706390843879, 0.3461535985323073, 0.9357094289395913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 260}], {
             RGBColor[
             0.284773382847451, 0.41634105132452215`, 0.9395399334660819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 299}], {
             RGBColor[
             0.3581446545361039, 0.47974328518246506`, 0.9442560545474505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 312}], {
             RGBColor[
             0.25276894068346034`, 0.3830065615077669, 0.9377061892825613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 327}], {
             RGBColor[
             0.22866910912003982`, 0.35767611051703674`, 0.9363337395275303]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 334}], {
             RGBColor[
             0.23529404619959324`, 0.3646393394329189, 0.9367110198934947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 385}], {
             RGBColor[
             0.2238798414279229, 0.35264228651551177`, 0.9360609978175509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 446}], {
             RGBColor[
             0.22786776900005848`, 0.3568338512430382, 0.9362881043931739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 478}], {
             RGBColor[
             0.38712473452348783`, 0.5032706196539489, 0.9465374726015883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 287}], {
             RGBColor[
             0.8515970726599524, 0.8845044060250485, 0.9857072830916294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 298}], {
             RGBColor[
             0.7725153841740422, 0.8225801022129446, 0.9778636612646125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 409}], {
             RGBColor[
             0.7032931179635095, 0.7669554550610453, 0.9720223945230841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 281}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 317}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 322}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 324}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 326}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 343}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 374}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 445}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 272}], {
             RGBColor[
             0.7801629819799012, 0.8241593809088232, 0.7710309321085329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 293}], {
             RGBColor[
             0.8761965593307338, 0.419241858580502, 0.3038305530822916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 403}], {
             RGBColor[
             0.8761965593307338, 0.419241858580502, 0.3038305530822916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 435}], {
             RGBColor[
             0.7217057517642607, 0.7765964094692765, 0.7664579098908495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 453}], {
             RGBColor[
             0.7259167707479581, 0.7801198628667647, 0.7667604716499351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 471}], {
             RGBColor[
             0.8761965593307338, 0.419241858580502, 0.3038305530822916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 497}], {
             RGBColor[
             0.9702608694884922, 0.9076733512787738, 0.4294614400173077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 275}], {
             RGBColor[
             0.8560290549644465, 0.34736971536429956`, 0.19791527993518332`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 331}], {
             RGBColor[
             0.8207108366647649, 0.37784655893402913`, 0.4372814530493224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 348}], {
             RGBColor[
             0.8657911144896757, 0.38473790158096455`, 0.21272342517580606`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 372}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 400}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 404}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 418}], {
             RGBColor[
             0.8610616366179067, 0.36732222461184755`, 0.20196461326343138`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 431}], {
             RGBColor[
             0.8760289938084724, 0.418883452871858, 0.28559208007867803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 444}], {
             RGBColor[
             0.8285562969045, 0.22050178822288907`, 0.17497884820646079`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 486}], {
             RGBColor[
             0.8762475134266291, 0.4193508442393725, 0.30937659196826445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 299}], {
             RGBColor[
             0.38540754335386535`, 0.5080941018004876, 0.945819774282403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 312}], {
             RGBColor[
             0.28003182950122174`, 0.41135737812578943`, 0.9392699090175137]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 328}], {
             RGBColor[
             0.3945437578035354, 0.5155112922725004, 0.9465390105509373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 334}], {
             RGBColor[
             0.26255693501735466`, 0.39299015605094145`, 0.9382747396284472]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 399}], {
             RGBColor[
             0.3078369305811183, 0.44058230230599205`, 0.9408533683900531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 407}], {
             RGBColor[
             0.5001504188796009, 0.6005443225351969, 0.9553335455086889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 446}], {
             RGBColor[
             0.25513065781781996`, 0.38518466786106076`, 0.9378518241281263]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 478}], {
             RGBColor[
             0.41438762334124934`, 0.5316214362719716, 0.9481011923365408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 262}], {
             RGBColor[
             0.9391282219438701, 0.953882854240121, 0.979615271589626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 299}], {
             RGBColor[
             0.6925921556774102, 0.7578254740416488, 0.9716892363428151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 313}], {
             RGBColor[
             0.9521701236341322, 0.9636094831665644, 0.9575387339007462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 328}], {
             RGBColor[
             0.7017283701270802, 0.7652426645136615, 0.9724084726113494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 391}], {
             RGBColor[
             0.9394746993421814, 0.8968570148384152, 0.6367582455569412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 407}], {
             RGBColor[
             0.8073350312031458, 0.850275694776358, 0.981203007569101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 448}], {
             RGBColor[
             0.8753169012348998, 0.903417953473117, 0.9879697015160488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 455}], {
             RGBColor[
             0.8536811654374341, 0.40413620414162243`, 0.44042619244061953`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 475}], {
             RGBColor[
             0.9343322393106261, 0.9503060182449484, 0.9877336191951046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 478}], {
             RGBColor[
             0.7215722356647942, 0.7813528085131327, 0.9739706543969529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 482}], {
             RGBColor[
             0.9313294242103154, 0.9480665236597952, 0.992816601900322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 299}], {
             RGBColor[
             0.7053148813089781, 0.7675537158569028, 0.9584619306105826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 376}], {
             RGBColor[
             0.968939678523462, 0.9760507492827026, 0.9237984542197519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 391}], {
             RGBColor[
             0.9521974249737493, 0.9065852566536692, 0.6235309398247086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 448}], {
             RGBColor[
             0.8880396268664679, 0.9131461952883709, 0.9747423957838162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 455}], {
             RGBColor[
             0.862162982525146, 0.410621698685125, 0.4316079886191312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 475}], {
             RGBColor[
             0.947054964942194, 0.9600342600602023, 0.974506313462872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 478}], {
             RGBColor[
             0.7342949612963621, 0.7910810503283867, 0.9607433486647203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 482}], {
             RGBColor[
             0.9440521498418833, 0.9577947654750492, 0.9795892961680893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 267}], {
             RGBColor[
             0.3938098760277288, 0.5155200539804957, 0.9463141949614547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 393}], {
             RGBColor[
             0.37476311386086897`, 0.49902270590966347`, 0.9451005521185729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 485}], {
             RGBColor[
             0.4682909081362715, 0.5772825622677944, 0.9518196776462704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 281}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 295}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 324}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 341}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 374}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 397}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 270}], {
             RGBColor[
             0.1931041910883242, 0.32029512671966087`, 0.9343083700592054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 320}], {
             RGBColor[
             0.1953107306009688, 0.32261433965013586`, 0.9344340292201678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 329}], {
             RGBColor[
             0.19625946576950848`, 0.3236115204655551, 0.9344880582844883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 424}], {
             RGBColor[
             0.2218738016558165, 0.3505338115247602, 0.9359467568201993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 293}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 317}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 322}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 343}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 359}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 403}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 440}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 445}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 471}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 483}], {
             RGBColor[
             0.8686864922225178, 0.39450469054086185`, 0.22397142092169176`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 280}], {
             RGBColor[
             0.47422028597903365`, 0.5827369663057078, 0.9521094415156451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 393}], {
             RGBColor[
             0.3865607689237344, 0.5092412417577328, 0.9458522882669219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 424}], {
             RGBColor[
             0.32359321236073335`, 0.4484918511970504, 0.9420674318834557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 480}], {
             RGBColor[
             0.44250442747306074`, 0.5569886035874154, 0.9496126529550372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 485}], {
             RGBColor[
             0.48008856319913695`, 0.5875010981158637, 0.9525714137946194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 491}], {
             RGBColor[
             0.2006246214741492, 0.3281995758779894, 0.9347366474441984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 282}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 310}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 323}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 406}], {
             RGBColor[
             0.8761600890568056, 0.41916385235227993`, 0.29986098883365586`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 411}], {
             RGBColor[
             0.7823157613673747, 0.34781156452747625`, 0.43346533019890965`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 419}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 499}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 329}], {
             RGBColor[
             0.18719494717707214`, 0.31408413670123125`, 0.9339718473604026]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 479}], {
             RGBColor[
             0.18878700248308236`, 0.3157574877699845, 0.9340625125548451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 304}], {
             RGBColor[
             0.26712476583186534`, 0.39809544395062635`, 0.9385237322872229]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 307}], {
             RGBColor[
             0.26941629466210404`, 0.4005039860425267, 0.9386542314640918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 311}], {
             RGBColor[
             0.2655645138375205, 0.3964555201788798, 0.9384348782443309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 351}], {
             RGBColor[
             0.3820420141208699, 0.5047731590450875, 0.9456249628519793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 371}], {
             RGBColor[
             0.4256104330710305, 0.5401439642837345, 0.9490548283881131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 429}], {
             RGBColor[
             0.26979559865762076`, 0.4009026585910771, 0.9386758322655065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 442}], {
             RGBColor[
             0.37583021451417103`, 0.49956100808681825`, 0.945182678962928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 435}], {
             RGBColor[
             0.5079170557519607, 0.611284214636594, 0.9544331827525074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 453}], {
             RGBColor[
             0.512128074735658, 0.6148076680340822, 0.9547357445115932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 497}], {
             RGBColor[
             0.7564721734761921, 0.7423611564460912, 0.6174367128789657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 279}], {
             RGBColor[
             0.2592350022653147, 0.38980280220227903`, 0.938074421923967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 283}], {
             RGBColor[
             0.2039582574481488, 0.3317034386513916, 0.9349264930812451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 285}], {
             RGBColor[
             0.27433252110274803`, 0.40331048120051716`, 0.9390206426608936]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 396}], {
             RGBColor[
             0.23652515386637785`, 0.3659333116474439, 0.9367811296538575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 421}], {
             RGBColor[
             0.20830733799455892`, 0.33627459805330173`, 0.9351741667844751]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 430}], {
             RGBColor[
             0.2453937716602786, 0.3752547912516788, 0.937286184317276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 459}], {
             RGBColor[
             0.23015334665587384`, 0.35923613827329337`, 0.9364182646594634]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 477}], {
             RGBColor[
             0.23729042956947327`, 0.36673766493267923`, 0.9368247109730249]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 284}], {
             RGBColor[
             0.39152884276049793`, 0.5118229415793216, 0.9464311546128009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 300}], {
             RGBColor[
             0.45102395983649046`, 0.5642446191206338, 0.9501895436973189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 305}], {
             RGBColor[
             0.6728698608332448, 0.742281504128438, 0.9695985669953169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 389}], {
             RGBColor[
             0.36588034959521865`, 0.4848647490542211, 0.9449705108705836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 432}], {
             RGBColor[
             0.627662215693468, 0.7066269492330988, 0.9651823859384503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 460}], {
             RGBColor[
             0.6542549538191047, 0.7274384825635528, 0.9678230605465845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 331}], {
             RGBColor[
             0.880471837443817, 0.8195704114474931, 0.6243590994767585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 346}], {
             RGBColor[
             0.9582193150286128, 0.8640683796032405, 0.32686377672377676`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 348}], {
             RGBColor[
             0.9480922541811833, 0.8299074254178962, 0.2875220576664841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 355}], {
             RGBColor[
             0.8823446787500739, 0.5496431313605049, 0.22311515099154627`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 372}], {
             RGBColor[
             0.8560290549644465, 0.3473697153642996, 0.19791527993518332`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 404}], {
             RGBColor[
             0.8560290549644465, 0.3473697153642996, 0.19791527993518332`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 418}], {
             RGBColor[
             0.9409980373735297, 0.8037839099642208, 0.271383839797922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 431}], {
             RGBColor[
             0.9634490731593783, 0.8811257523542364, 0.396825040020792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 444}], {
             RGBColor[
             0.8785036487734464, 0.5201192918100778, 0.21943697634810488`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 486}], {
             RGBColor[
             0.9637768525866133, 0.8818268394055082, 0.43250180785517167`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 306}], {
             RGBColor[
             0.3968212348923211, 0.5178614200121557, 0.946579827335847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 347}], {
             RGBColor[
             0.3067228826426153, 0.4377048288177037, 0.9408524097411209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 382}], {
             RGBColor[
             0.3268271732727834, 0.45750300350269213`, 0.9420461163723881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 462}], {
             RGBColor[
             0.2787032871192142, 0.40825445737764454`, 0.9392567352273402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 288}], {
             RGBColor[
             0.8718851812720558, 0.40529461979285863`, 0.23639772385740537`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 313}], {
             RGBColor[
             0.9794761473860648, 0.9653471066434187, 0.651496031025925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 340}], {
             RGBColor[
             0.9813346158030243, 0.9667331493458243, 0.648350128762206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 373}], {
             RGBColor[
             0.8718851812720558, 0.40529461979285863`, 0.23639772385740537`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 386}], {
             RGBColor[
             0.9122570409032669, 0.9128375594706262, 0.6828459092178139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 414}], {
             RGBColor[
             0.987174698071661, 0.9678878453482673, 0.4481743161496815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 498}], {
             RGBColor[
             0.8718851812720558, 0.40529461979285863`, 0.23639772385740537`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 401}], {
             RGBColor[
             0.19472994713122652`, 0.3220038993996379, 0.9344009544607581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 451}], {
             RGBColor[
             0.24719400766817687`, 0.37714695343753535`, 0.9373887050947152]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.31918224078287427`, 0.4504503802207983, 0.9415747678474624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 318}], {
             RGBColor[
             0.28254307525555356`, 0.4143010647322023, 0.9394017821995571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 335}], {
             RGBColor[
             0.30955781786322234`, 0.442114188825357, 0.9409615081295651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 396}], {
             RGBColor[
             0.28137487354650415`, 0.413073210667725, 0.9393352548404263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 409}], {
             RGBColor[
             0.42270568812946974`, 0.5377275457694766, 0.9488314553822088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 421}], {
             RGBColor[
             0.2531570576746852, 0.38341449707358277`, 0.9377282919710439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 430}], {
             RGBColor[
             0.2902434913404049, 0.42239469027195997`, 0.9398403095038447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 459}], {
             RGBColor[
             0.27500306633600013`, 0.4063760372935745, 0.9389723898460322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 477}], {
             RGBColor[
             0.28214014924959957`, 0.4138775639529604, 0.9393788361595936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 338}], {
             RGBColor[
             0.768013484678197, 0.8137930844785333, 0.728866127012082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 383}], {
             RGBColor[
             0.5876838324912708, 0.6761472359281866, 0.9606837705319751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 393}], {
             RGBColor[
             0.4551735238121738, 0.5662396182348755, 0.9508957986727633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 480}], {
             RGBColor[
             0.5111171823615002, 0.6139869800645582, 0.9546561633608786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 317}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 322}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 324}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 343}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 374}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 397}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 445}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 310}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 323}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 406}], {
             RGBColor[
             0.8761600890568056, 0.41916385235227993`, 0.29986098883365586`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 419}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 499}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 396}], {
             RGBColor[
             0.2260981287293382, 0.35497384711683755`, 0.9361873259977045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 421}], {
             RGBColor[
             0.19788031285751928`, 0.32531513352269537`, 0.934580363128322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 430}], {
             RGBColor[
             0.23496674652323896`, 0.3642953267210725, 0.9366923806611228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 459}], {
             RGBColor[
             0.2197263215188342, 0.34827667374268706`, 0.9358244610033103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 477}], {
             RGBColor[
             0.22686340443243364`, 0.3557782004020729, 0.9362309073168718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 300}], {
             RGBColor[
             0.3586150308586798, 0.48414605059779925`, 0.9441041977149605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 345}], {
             RGBColor[
             0.2646833404793789, 0.39552935110985515`, 0.9383846967251639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 389}], {
             RGBColor[
             0.2734714206174079, 0.4047661805313866, 0.9388851648882252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 432}], {
             RGBColor[
             0.5352532867156573, 0.6265283807102642, 0.9590970399560919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 456}], {
             RGBColor[
             0.2749576588362952, 0.40632831113238277`, 0.9389698039560983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 472}], {
             RGBColor[
             0.24808825888161617`, 0.3780868681616617, 0.9374396313783945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 287}], {
             RGBColor[
             0.586107161663346, 0.6687841757317179, 0.9634625646876807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 354}], {
             RGBColor[
             0.5980978839946363, 0.6783452522392017, 0.9646062504878833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 396}], {
             RGBColor[
             0.2964723923839374, 0.4265808896659632, 0.940281475577353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 409}], {
             RGBColor[
             0.437803206966903, 0.5512352247677147, 0.9497776761191354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 430}], {
             RGBColor[
             0.3053410101778382, 0.4359023692701981, 0.9407865302407712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 473}], {
             RGBColor[
             0.4702957798183204, 0.5776141591822213, 0.9523356104782151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 477}], {
             RGBColor[
             0.2972376680870329, 0.4273852429511985, 0.9403250568965202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 319}], {
             RGBColor[
             0.2013361778689116, 0.32894746676416586`, 0.9347771695282268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 330}], {
             RGBColor[
             0.22011222124554525`, 0.3486822788229162, 0.935846437421859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 357}], {
             RGBColor[
             0.21788015626742555`, 0.3463362370098189, 0.9357193246233994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 358}], {
             RGBColor[
             0.30001627431624434`, 0.4256508881874809, 0.9406537311281724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 367}], {
             RGBColor[
             0.23641375708701462`, 0.36581622656936946`, 0.9367747857720696]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 368}], {
             RGBColor[
             0.19782344597820478`, 0.32525536282696743`, 0.934577124643672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 492}], {
             RGBColor[
             0.20509632372891637`, 0.3328996184700481, 0.9349913042723167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 336}], {
             RGBColor[
             0.8241908545687948, 0.38062143074813315`, 0.4376133802636575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 354}], {
             RGBColor[
             0.8499252860376748, 0.8831713687518833, 0.985547826591175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 388}], {
             RGBColor[
             0.8811274230386713, 0.9080511058370317, 0.9885239142728066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 409}], {
             RGBColor[
             0.6896306090099416, 0.7560613412803963, 0.970719252222427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 436}], {
             RGBColor[
             0.9038171917049964, 0.925266523954059, 0.9602893109333949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 473}], {
             RGBColor[
             0.7221231818613589, 0.7824402756949027, 0.9732771865815069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 313}], {
             RGBColor[
             0.8708575836519874, 0.41710611796942054`, 0.41689029682654455`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 321}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 373}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 386}], {
             RGBColor[
             0.8260448459967887, 0.38209975318755884`, 0.4377902156211372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 391}], {
             RGBColor[
             0.8623939674573535, 0.3726044724173211, 0.20303663793067456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 455}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 498}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 300}], {
             RGBColor[
             0.36584591693848256`, 0.4912990781268415, 0.9445323562158461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 308}], {
             RGBColor[
             0.2720506530758039, 0.4028257715578081, 0.9388206245143462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 314}], {
             RGBColor[
             0.4574818773087424, 0.5666492546376866, 0.9514821357474397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 466}], {
             RGBColor[
             0.28062655967903927`, 0.4118395931416923, 0.9393090097084835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 470}], {
             RGBColor[
             0.28003993770811864`, 0.41122301625627355`, 0.939275602455069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 493}], {
             RGBColor[
             0.4515126766845066, 0.5618031886615082, 0.9510122184083976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 297}], {
             RGBColor[
             0.21970848593960174`, 0.3482579274180727, 0.9358234452934584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 484}], {
             RGBColor[
             0.19720039887588448`, 0.3246005008189609, 0.9345416430329105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 349}], {
             RGBColor[
             0.20137038883349692`, 0.32898342465704544`, 0.9347791177920493]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 353}], {
             RGBColor[
             0.19170554293633024`, 0.31882505883250056`, 0.9342287191160639]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 394}], {
             RGBColor[
             0.1976212181124982, 0.32504280851812256`, 0.9345656080658895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 467}], {
             RGBColor[
             0.21418854935951206`, 0.34245612408820514`, 0.9355090930712366]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 398}], {
             RGBColor[
             0.2511316087278431, 0.3812856218095713, 0.9376129456499045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 399}], {
             RGBColor[
             0.2546203091758611, 0.3849524671768223, 0.9378116219793493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 464}], {
             RGBColor[
             0.24293630539384, 0.37267183839329127`, 0.9371462352488977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 481}], {
             RGBColor[
             0.24899857925793986`, 0.3790436725948234, 0.9374914727771277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 496}], {
             RGBColor[
             0.20710059025010286`, 0.3350062296616523, 0.9351054442856517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 343}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 403}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 440}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 445}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 471}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 483}], {
             RGBColor[
             0.8686864922225178, 0.39450469054086185`, 0.22397142092169176`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 497}], {
             RGBColor[
             0.8604026869949277, 0.3647097089386806, 0.20143440692924686`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 296}], {
             RGBColor[
             0.2044861367384871, 0.3322582732550172, 0.9349565550259025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 327}], {
             RGBColor[
             0.20782428065513164`, 0.3357668741619594, 0.935146657383614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 385}], {
             RGBColor[
             0.2030350129630147, 0.3307330501604344, 0.9348739156736345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 415}], {
             RGBColor[
             0.20054448474921935`, 0.3281153470991263, 0.9347320837762653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 438}], {
             RGBColor[
             0.24844971479729377`, 0.37846678124666755`, 0.9374602157580663]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 439}], {
             RGBColor[
             0.2411021556117397, 0.370744030680491, 0.9370417831321887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 321}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 341}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 391}], {
             RGBColor[
             0.8623939674573535, 0.3726044724173211, 0.20303663793067456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 397}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 455}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 327}], {
             RGBColor[
             0.19648958029374552`, 0.3238533854206317, 0.9345011629662197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 339}], {
             RGBColor[
             0.1887512717262556, 0.3157199324790988, 0.9340604777411028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 385}], {
             RGBColor[
             0.19170031260162856`, 0.3188195614191067, 0.9342284212562402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 415}], {
             RGBColor[
             0.1892097843878332, 0.3162018583577987, 0.9340865893588708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 438}], {
             RGBColor[
             0.23711501443590766`, 0.3665532925053399, 0.9368147213406718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 325}], {
             RGBColor[
             0.3379519408599507, 0.461641809531562, 0.9429562454735485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 392}], {
             RGBColor[
             0.3456632797932826, 0.4683209837324499, 0.943447605171511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 412}], {
             RGBColor[
             0.23850869796425644`, 0.3680181422582739, 0.9368940895558412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 413}], {
             RGBColor[
             0.32997558728000875`, 0.45473309296380404`, 0.9424479992766471]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 474}], {
             RGBColor[
             0.3280652758488244, 0.45307847721715644`, 0.9423262759214741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 484}], {
             RGBColor[
             0.2267841294164104, 0.35569487733390615`, 0.9362263927219862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 490}], {
             RGBColor[
             0.295576036933824, 0.4249379314256113, 0.9402560903469162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 335}], {
             RGBColor[
             0.4974010502577838, 0.5985236805241728, 0.9550056831427665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 409}], {
             RGBColor[
             0.6105489205240312, 0.6941370374682924, 0.9628756303954102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 468}], {
             RGBColor[
             0.5240878676490316, 0.621638460430029, 0.9567061435487108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 312}], {
             RGBColor[
             0.3534031011898746, 0.4747596119837323, 0.9439860300988824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 328}], {
             RGBColor[
             0.4679150294921883, 0.5789135261304432, 0.9512551316323059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 399}], {
             RGBColor[
             0.38120820226977115`, 0.5039845361639349, 0.9455694894714217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 407}], {
             RGBColor[
             0.5735216905682538, 0.6639465563931397, 0.9600496665900575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 448}], {
             RGBColor[
             0.6415035606000079, 0.7170888150898986, 0.9668163605370053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 475}], {
             RGBColor[
             0.7005188986757341, 0.7639768798617301, 0.9665802782160611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 478}], {
             RGBColor[
             0.4877588950299022, 0.5950236701299144, 0.9528173134179094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 482}], {
             RGBColor[
             0.6975160835754234, 0.7617373852765769, 0.9716632609212784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 305}], {
             RGBColor[
             0.6399560489314267, 0.7146046131469155, 0.9672716100974765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 308}], {
             RGBColor[
             0.3243148840719937, 0.448094421570078, 0.9421508550979786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 432}], {
             RGBColor[
             0.5947484037916498, 0.6789500582515764, 0.96285542904061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 456}], {
             RGBColor[
             0.3344527759122877, 0.4587499886736949, 0.9427281930406164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 493}], {
             RGBColor[
             0.5037769076806964, 0.6070718386737781, 0.9543424489920299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 316}], {
             RGBColor[
             0.8735231410973765, 0.4108198428949215, 0.24276088847601782`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 336}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 388}], {
             RGBColor[
             0.8529860941236527, 0.4035819731432213, 0.44035989591821356`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 436}], {
             RGBColor[
             0.8681126065678694, 0.4150589185545728, 0.4215368270252724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 346}], {
             RGBColor[
             0.7355852203061626, 0.7748239735708853, 0.6706341273882959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 370}], {
             RGBColor[
             0.4457020294385857, 0.5595198175689367, 0.9498822686739312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 390}], {
             RGBColor[
             0.5231595548827668, 0.6237635205800223, 0.9556041830384168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 422}], {
             RGBColor[
             0.3930257524734591, 0.5128887624932172, 0.9465625995891717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 443}], {
             RGBColor[
             0.6197751789448227, 0.7005305366504255, 0.9643518386481924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 451}], {
             RGBColor[
             0.38989549393188216`, 0.5095986622961652, 0.9463843359960313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 379}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 400}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 307}], {
             RGBColor[
             0.23196962243821045`, 0.361145159279065, 0.9365216988783283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 311}], {
             RGBColor[
             0.22811784161362691`, 0.3570966934154181, 0.9363023456585673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 337}], {
             RGBColor[
             0.2261823882456348, 0.3550624092108272, 0.9361921244525068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 423}], {
             RGBColor[
             0.20489033009065757`, 0.3326831060954871, 0.9349795732393582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 427}], {
             RGBColor[
             0.22064336651454602`, 0.34924054617719114`, 0.9358766853591696]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 433}], {
             RGBColor[
             0.2080639244096152, 0.3360187549422132, 0.9351603047409107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 465}], {
             RGBColor[
             0.2045659825518425, 0.33234219626737077`, 0.9349611021268518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 469}], {
             RGBColor[
             0.20952654949252203`, 0.3375560666401347, 0.9352435990756223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 310}], {
             RGBColor[
             0.8321466499760604, 0.3869651660515733, 0.4383722111318249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 406}], {
             RGBColor[
             0.9278221085492989, 0.9409395276057798, 0.778913799948221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 432}], {
             RGBColor[
             0.8165943047884041, 0.8569869432593805, 0.9822644523386079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 460}], {
             RGBColor[
             0.8431870429140408, 0.8777984765898346, 0.9849051269467421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 493}], {
             RGBColor[
             0.7256228086774508, 0.7851087236815824, 0.973751472290028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 331}], {
             RGBColor[
             0.6453215149169124, 0.720164767833845, 0.9671441268400578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 347}], {
             RGBColor[
             0.37305016758982446`, 0.49488726767115054`, 0.9451524769374224]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 382}], {
             RGBColor[
             0.3931544582199925, 0.514685442356139, 0.9463461835686895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 431}], {
             RGBColor[
             0.7282987506324737, 0.7817201087405883, 0.7396100673840913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 486}], {
             RGBColor[
             0.7286265300597087, 0.7824211957918601, 0.775286835218471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 337}], {
             RGBColor[
             0.2284739170758735, 0.35747095130272755`, 0.9363226236293758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 427}], {
             RGBColor[
             0.22293489534478472`, 0.35164908826909147`, 0.9360071845360386]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 433}], {
             RGBColor[
             0.2103554532398539, 0.33842729703411356`, 0.9352908039177796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 442}], {
             RGBColor[
             0.34067507112051615`, 0.4626107234152569, 0.9431806455540332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 469}], {
             RGBColor[
             0.21181807832276073`, 0.33996460873203505`, 0.9353740982524913]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 500}], {
             RGBColor[
             0.2541094521417272, 0.3844155240437408, 0.9377825294270006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 362}], {
             RGBColor[
             0.20539074651933456`, 0.3332090754902608, 0.9350080712146716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 369}], {
             RGBColor[
             0.21139967119728387`, 0.33952483631461483`, 0.9353502705856733]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 389}], {
             RGBColor[
             0.23917127383072181`, 0.36871455150366533`, 0.9369318222712433]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 456}], {
             RGBColor[
             0.24065751204960906`, 0.3702766821046615, 0.9370164613391165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 393}], {
             RGBColor[
             0.2931834633072552, 0.42005128345340215`, 0.9402066837474136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 424}], {
             RGBColor[
             0.23021590674425413`, 0.35930189289271974`, 0.9364218273639473]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 323}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 406}], {
             RGBColor[
             0.8761600890568056, 0.41916385235227993`, 0.29986098883365586`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 408}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 419}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 366}], {
             RGBColor[
             0.21056004147512417`, 0.3386423322410259, 0.9353024549151172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 405}], {
             RGBColor[
             0.20862681857218934`, 0.3366103923966298, 0.935192360730742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 423}], {
             RGBColor[
             0.20333007809631276`, 0.3310431823237406, 0.9348907191964662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 429}], {
             RGBColor[
             0.23078867443938234`, 0.35990390805586886`, 0.936454445636851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 465}], {
             RGBColor[
             0.20300573055749768`, 0.3307022724956242, 0.9348722480839599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 469}], {
             RGBColor[
             0.2079662974981772, 0.3359161428683881, 0.9351547450327304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 488}], {
             RGBColor[
             0.21049948038445382`, 0.3385786786949364, 0.9352990060505957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 327}], {
             RGBColor[
             0.22392755577381057`, 0.35269243731830396`, 0.9360637150789621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 334}], {
             RGBColor[
             0.230552492853364, 0.3596556662341861, 0.9364409954449265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 385}], {
             RGBColor[
             0.21913828808169364`, 0.347658613316779, 0.9357909733689826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 415}], {
             RGBColor[
             0.21664775986789828`, 0.3450409102554709, 0.9356491414716133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 446}], {
             RGBColor[
             0.22312621565382923`, 0.3518501780443054, 0.9360180799446056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 386}], {
             RGBColor[
             0.9107156444731642, 0.9305548067354691, 0.9535847686715226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 391}], {
             RGBColor[
             0.9652393266640114, 0.9163118855801125, 0.6014544021358288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 407}], {
             RGBColor[
             0.8330996585249757, 0.8697305655180553, 0.9458991641479886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 498}], {
             RGBColor[
             0.8708575836519874, 0.41710611796942054`, 0.41689029682654466`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 406}], {
             RGBColor[
             0.7976121679228045, 0.8382528191088208, 0.7664545561818166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 411}], {
             RGBColor[
             0.656845676388658, 0.7312243873716151, 0.9668610682296974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 493}], {
             RGBColor[
             0.5954128680509563, 0.6824220151846232, 0.9612922285236236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 349}], {
             RGBColor[
             0.202082172054935, 0.3297315539524397, 0.9348196527935213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 353}], {
             RGBColor[
             0.1924173261577683, 0.31957318812789476`, 0.9342692541175359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 364}], {
             RGBColor[
             0.2434271231031161, 0.3731877189253806, 0.9371741865913413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 378}], {
             RGBColor[
             0.24896710191064286`, 0.3790105879070351, 0.9374896801887658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 380}], {
             RGBColor[
             0.2069794182961998, 0.33487887025535457`, 0.9350985437221347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 487}], {
             RGBColor[
             0.21833205101187592`, 0.3468112070380179, 0.9357450593605774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 372}], {
             RGBColor[
             0.8735231410973765, 0.41081984289492157`, 0.24276088847601784`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 418}], {
             RGBColor[
             0.9672391665729247, 0.8989591012601537, 0.3386522526091738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 322}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 343}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 374}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 440}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 445}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 471}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 335}], {
             RGBColor[
             0.2880161711733349, 0.41947255233499914`, 0.9397347432185865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 421}], {
             RGBColor[
             0.23161541098479776`, 0.360772860583225, 0.9365015270600652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 430}], {
             RGBColor[
             0.26870184465051744`, 0.3997530537816021, 0.9386135445928661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 459}], {
             RGBColor[
             0.2534614196461127, 0.38373440080321664`, 0.9377456249350535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 330}], {
             RGBColor[
             0.20604176576710181`, 0.3338933379966685, 0.9350451457977351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 357}], {
             RGBColor[
             0.2038097007889821, 0.3315472961835712, 0.9349180329992755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 368}], {
             RGBColor[
             0.18375299049976135`, 0.3104664220007197, 0.9337758330195483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 492}], {
             RGBColor[
             0.19102586825047294`, 0.3181106776438004, 0.9341900126481928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 329}], {
             RGBColor[
             0.18940148668971674`, 0.3164033496317062, 0.934097506521365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 424}], {
             RGBColor[
             0.2150158225760247, 0.3433256406909113, 0.935556205057076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 341}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 373}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 391}], {
             RGBColor[
             0.8623939674573535, 0.3726044724173211, 0.20303663793067456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 397}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 455}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 498}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 343}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 374}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 440}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 445}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 471}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 419}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 449}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 499}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 342}], {
             RGBColor[
             0.8611372113207705, 0.36762185312492557`, 0.20202542244332183`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 360}], {
             RGBColor[
             0.8191009627097754, 0.1478239462483719, 0.1659244095033199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 457}], {
             RGBColor[
             0.8638009847389825, 0.3780247266271895, 0.20499214689883155`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 392}], {
             RGBColor[
             0.4343230041731056, 0.550610489330994, 0.9488956556625256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 413}], {
             RGBColor[
             0.4186353116598318, 0.5370225985623481, 0.9478960497676616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 474}], {
             RGBColor[
             0.4167250002286474, 0.5353679828157005, 0.9477743264124886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 490}], {
             RGBColor[
             0.384235761313647, 0.5072274370241554, 0.9457041408379308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 338}], {
             RGBColor[
             0.8759439761629737, 0.4187016087247386, 0.2763384340342258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 346}], {
             RGBColor[
             0.8725424883879621, 0.4075118710378607, 0.23895123788066785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 355}], {
             RGBColor[
             0.8304768118928137, 0.23526370799810264`, 0.17681793552818148`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 395}], {
             RGBColor[
             0.8502020870562027, 0.32426772933006165`, 0.19322676477969444`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 443}], {
             RGBColor[
             0.7953357941470689, 0.3579829130908875, 0.4347630453872655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 334}], {
             RGBColor[
             0.2064526612899435, 0.33432521524345593`, 0.9350685456898955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 385}], {
             RGBColor[
             0.19503845651827315`, 0.32232816232604883`, 0.9344185236139517]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 415}], {
             RGBColor[
             0.19254792830447778`, 0.31971045926474073`, 0.9342766917165823]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 446}], {
             RGBColor[
             0.19902638409040874`, 0.32651972705357524`, 0.9346456301895747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 398}], {
             RGBColor[
             0.38685571627142323`, 0.5077348812686966, 0.9460900494105111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 399}], {
             RGBColor[
             0.3903444167194412, 0.5114017266359476, 0.9462887257399559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 407}], {
             RGBColor[
             0.5826579050179238, 0.6713637468651524, 0.9607689028585917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 464}], {
             RGBColor[
             0.37866041293742014`, 0.4991210978524166, 0.9456233390095045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 475}], {
             RGBColor[
             0.7096551131254042, 0.7713940703337429, 0.9672995144845954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 478}], {
             RGBColor[
             0.4968951094795723, 0.6024408606019271, 0.9535365496864436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 481}], {
             RGBColor[
             0.38472268680152, 0.5054929320539487, 0.9459685765377344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 333}], {
             RGBColor[
             0.32128397349438886`, 0.4449420277747629, 0.9419770304831396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 352}], {
             RGBColor[
             0.21148900295996179`, 0.33961872966115025`, 0.9353553578974033]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 357}], {
             RGBColor[
             0.22258574416561577`, 0.35128210824232153`, 0.9359873008929078]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 358}], {
             RGBColor[
             0.30472186221443454`, 0.43059675941998354`, 0.9409217073976809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 367}], {
             RGBColor[
             0.24111934498520485`, 0.3707620978018721, 0.937042762041578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 368}], {
             RGBColor[
             0.202529033876395, 0.3302012340594701, 0.9348451009131806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 441}], {
             RGBColor[
             0.2965298119987766, 0.4235012172675965, 0.9403997172018848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 492}], {
             RGBColor[
             0.2098019116271066, 0.3378454897025508, 0.9352592805418252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 348}], {
             RGBColor[
             0.8951149267316608, 0.8756226907724907, 0.6465713173376927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 372}], {
             RGBColor[
             0.8207108366647649, 0.3778465589340292, 0.4372814530493224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 382}], {
             RGBColor[
             0.5753274532973747, 0.6598063513243815, 0.9626104158765989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 404}], {
             RGBColor[
             0.8207108366647649, 0.3778465589340292, 0.4372814530493224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 418}], {
             RGBColor[
             0.8880207099240073, 0.849499175318815, 0.6304330994691307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 431}], {
             RGBColor[
             0.9104717457098559, 0.9268410177088308, 0.7558742996920007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 444}], {
             RGBColor[
             0.8431854304737648, 0.5505961353798073, 0.458803149462244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 486}], {
             RGBColor[
             0.9107995251370908, 0.9275421047601026, 0.7915510675263803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 420}], {
             RGBColor[
             0.21514942465501302`, 0.3434660649467891, 0.9355638134978279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 454}], {
             RGBColor[
             0.26600423470039036`, 0.39588544200916653`, 0.9384977155240641]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 489}], {
             RGBColor[
             0.22285222532450405`, 0.35156219683619444`, 0.9360024766006829]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 358}], {
             RGBColor[
             0.40118802656508795`, 0.5219106371393276, 0.9467843241894529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 361}], {
             RGBColor[
             0.4137027061318567, 0.5327502235739785, 0.9475817485051508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 367}], {
             RGBColor[
             0.33758550933585824`, 0.46207597552121615`, 0.9429053788333501]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 386}], {
             RGBColor[
             0.6306233379177042, 0.7071505825283917, 0.9663871470691616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 441}], {
             RGBColor[
             0.39299597634942995`, 0.5148150949869406, 0.9462623339936568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 450}], {
             RGBColor[
             0.3787463461307482, 0.5024727814987578, 0.9453543601565757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 461}], {
             RGBColor[
             0.479657645205507, 0.5874809597180408, 0.9524463931924381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 385}], {
             RGBColor[
             0.20166339359782656`, 0.32929139124193096`, 0.9347958039799161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 415}], {
             RGBColor[
             0.1991728653840312, 0.3266736881806229, 0.9346539720825469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 446}], {
             RGBColor[
             0.20565132116996215`, 0.33348295596945743`, 0.9350229105555391]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 409}], {
             RGBColor[
             0.42817878404725107`, 0.5428990333722734, 0.9491644164012382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 421}], {
             RGBColor[
             0.25863015359246655`, 0.38858598467637967`, 0.9380612529900733]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 430}], {
             RGBColor[
             0.2957165872581862, 0.4275661778747568, 0.940173270522874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 459}], {
             RGBColor[
             0.28047616225378147`, 0.41154752489637136`, 0.9393053508650615]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 354}], {
             RGBColor[
             0.8321846694563217, 0.3869954817531224, 0.4383758374637925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 388}], {
             RGBColor[
             0.8529860941236527, 0.4035819731432213, 0.44035989591821356`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 436}], {
             RGBColor[
             0.8681126065678694, 0.4150589185545728, 0.4215368270252724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 420}], {
             RGBColor[
             0.2204438807365078, 0.34903087397634414`, 0.935865324939223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 427}], {
             RGBColor[
             0.21714766115220907`, 0.3455663382008537, 0.9356776101102171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 433}], {
             RGBColor[
             0.20456821904727826`, 0.3323445469658758, 0.9349612294919583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 500}], {
             RGBColor[
             0.24832221794915155`, 0.378332773975503, 0.9374529550011792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 383}], {
             RGBColor[
             0.8128642763019948, 0.8502049776238694, 0.7323969456225705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 395}], {
             RGBColor[
             0.9545810948287645, 0.8462000070822004, 0.3759117982208804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 443}], {
             RGBColor[
             0.8722816554650638, 0.8967727827234393, 0.738216219132237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 480}], {
             RGBColor[
             0.736297626172224, 0.7880447217602409, 0.726369338451474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 344}], {
             RGBColor[
             0.20608159129440537`, 0.33393519715094877`, 0.9350474138025986]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 387}], {
             RGBColor[
             0.20309854147984135`, 0.33079982265955976`, 0.9348775335286859]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 439}], {
             RGBColor[
             0.22536729059950822`, 0.35420568990457246`, 0.9361457058473888]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 384}], {
             RGBColor[
             0.8080357036472916, 0.8499629868732397, 0.9401530383545316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 414}], {
             RGBColor[
             0.9874917700585177, 0.9869911353155156, 0.7157672733396714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 461}], {
             RGBColor[
             0.7616084201779264, 0.8122712266275236, 0.9364981125310801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 499}], {
             RGBColor[
             0.872096562596627, 0.418030146437691, 0.414793028650732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 374}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 391}], {
             RGBColor[
             0.8623939674573535, 0.3726044724173211, 0.20303663793067456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 397}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 455}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 485}], {
             RGBColor[
             0.7516716146349955, 0.7419375828889696, 0.6178585819047002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 374}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 403}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 440}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 445}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 471}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 387}], {
             RGBColor[
             0.22482902569883648`, 0.35363993936600063`, 0.9361150524575872]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 438}], {
             RGBColor[
             0.25444533400405744`, 0.38476855717718994`, 0.9378016574021677]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 439}], {
             RGBColor[
             0.24709777481850334`, 0.37704580661101333`, 0.9373832247762901]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 389}], {
             RGBColor[
             0.23903484731409955`, 0.3685711585847546, 0.9369240529829466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 456}], {
             RGBColor[
             0.2405210855329868, 0.3701332891857508, 0.9370086920508198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 472}], {
             RGBColor[
             0.21365168557830777`, 0.34189184621502966`, 0.9354785194731159]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 355}], {
             RGBColor[
             0.8988581121735896, 0.6097852870340661, 0.2641511089370308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 390}], {
             RGBColor[
             0.7705637997404904, 0.8032211601227189, 0.6733877692921244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 395}], {
             RGBColor[
             0.9494788631662472, 0.8294154005518836, 0.3198310039905435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 431}], {
             RGBColor[
             0.9882192232946517, 0.971338985864578, 0.45837897693901886`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 443}], {
             RGBColor[
             0.8671794238025463, 0.8799881761931223, 0.6821354249019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 486}], {
             RGBColor[
             0.9885470027218867, 0.9720400729158498, 0.4940557447733985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 382}], {
             RGBColor[
             0.30305610597028676`, 0.43452885116168694`, 0.9406187659739635]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 462}], {
             RGBColor[
             0.25493221981671754`, 0.3852803050366393, 0.9378293848289156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 355}], {
             RGBColor[
             0.8921067382753032, 0.5870113175771698, 0.237923296232169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 372}], {
             RGBColor[
             0.8657911144896757, 0.38473790158096466`, 0.21272342517580606`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 400}], {
             RGBColor[
             0.8657911144896757, 0.38473790158096466`, 0.21272342517580606`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 404}], {
             RGBColor[
             0.8657911144896757, 0.38473790158096466`, 0.21272342517580606`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 418}], {
             RGBColor[
             0.9556411266613736, 0.8598361892892182, 0.29359605765885616`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 431}], {
             RGBColor[
             0.9780921624472222, 0.937178031679234, 0.41903725788172613`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 444}], {
             RGBColor[
             0.8882657082986757, 0.5574874780267427, 0.23424512158872762`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 486}], {
             RGBColor[
             0.9784199418744571, 0.9378791187305058, 0.45471402571610575`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 353}], {
             RGBColor[
             0.19626227991525308`, 0.3236144783111598, 0.9344882185459253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 378}], {
             RGBColor[
             0.25281205566812764`, 0.38305187809030017`, 0.9377086446171552]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 380}], {
             RGBColor[
             0.2108243720536846, 0.3389201604386196, 0.9353175081505242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 487}], {
             RGBColor[
             0.2221770047693607, 0.3508524972212829, 0.9359640237889668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 377}], {
             RGBColor[
             0.1885369074382775, 0.3154946220209529, 0.9340482700120258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 412}], {
             RGBColor[
             0.20892004662185062`, 0.33691859366855603`, 0.9352090596343783]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 426}], {
             RGBColor[
             0.20267694710555745`, 0.33035670024156016`, 0.9348535243527634]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 476}], {
             RGBColor[
             0.19421935887497294`, 0.3214672387691502, 0.9343718772149121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 371}], {
             RGBColor[
             0.5030810091361415, 0.6074628526147339, 0.9540235263671059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 442}], {
             RGBColor[
             0.4533007905792821, 0.5668798964178177, 0.9501513769419208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 460}], {
             RGBColor[
             0.6420423630429408, 0.7175237512005181, 0.9668616406644909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 357}], {
             RGBColor[
             0.20925693798184208`, 0.337272687848053, 0.9352282450989436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 367}], {
             RGBColor[
             0.22779053880143119`, 0.3567526774076035, 0.9362837062476139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 368}], {
             RGBColor[
             0.18920022769262135`, 0.31619181366520155`, 0.9340860451192163]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 375}], {
             RGBColor[
             0.23983670688281394`, 0.3694139638323065, 0.93696971769914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 380}], {
             RGBColor[
             0.2011595261565179, 0.3287617946140746, 0.9347671094745387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 487}], {
             RGBColor[
             0.212512158872194, 0.340694131396738, 0.9354136251129814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 388}], {
             RGBColor[
             0.8931181453699616, 0.9176121823445156, 0.9896676000730092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 409}], {
             RGBColor[
             0.7016213313412318, 0.7656224177878801, 0.9718629380226298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 436}], {
             RGBColor[
             0.9158079140362867, 0.9348276004615428, 0.9614329967335975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 473}], {
             RGBColor[
             0.7341139041926492, 0.7920013522023865, 0.9744208723817095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 395}], {
             RGBColor[
             0.8765177108418302, 0.526541145326267, 0.2184266358360574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 404}], {
             RGBColor[
             0.8436346237856275, 0.3364004159962053, 0.18941787105636293`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 431}], {
             RGBColor[
             0.9023446175940999, 0.6211568688680633, 0.310791951135041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 443}], {
             RGBColor[
             0.8216514179326964, 0.5602563290870928, 0.4599629164436284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 444}], {
             RGBColor[
             0.8548719206901274, 0.42277520421909437`, 0.2001787192628237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 486}], {
             RGBColor[
             0.9025631372122566, 0.6216242602355779, 0.3345764630246274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 365}], {
             RGBColor[
             0.3958521141784222, 0.5154427777416128, 0.9467614846116235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 457}], {
             RGBColor[
             0.7242147630598365, 0.7320073272227894, 0.6198326116523992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 494}], {
             RGBColor[
             0.7305244527406208, 0.7874409705960981, 0.9449166497009711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 367}], {
             RGBColor[
             0.23888728000708515`, 0.3684160559887748, 0.9369156492431183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 368}], {
             RGBColor[
             0.2002969688982753, 0.32785519224637283`, 0.934717988114721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 441}], {
             RGBColor[
             0.29429774702065686`, 0.4211551754544992, 0.9402726044034251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 492}], {
             RGBColor[
             0.2075698466489869, 0.3354994478894535, 0.9351321677433655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 361}], {
             RGBColor[
             0.39714059485190245`, 0.5184049552191992, 0.9465264254196921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 386}], {
             RGBColor[
             0.61406122663775, 0.6928053141736124, 0.965331823983703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 398}], {
             RGBColor[
             0.3406430519430609, 0.4683522073597428, 0.9429673660120881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 441}], {
             RGBColor[
             0.3764338650694757, 0.5004698266321612, 0.945207010908198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 408}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 440}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 463}], {
             RGBColor[
             0.831998657058118, 0.24386491747293382`, 0.17815401051060936`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 483}], {
             RGBColor[
             0.8686864922225178, 0.39450469054086185`, 0.22397142092169176`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 457}], {
             RGBColor[
             0.8673649101585332, 0.4054186191239333, 0.2084049659054714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 494}], {
             RGBColor[
             0.8715713699457228, 0.44237438137280577`, 0.4251276579378526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 386}], {
             RGBColor[
             0.6265759062045188, 0.7036449006082633, 0.9661292482994008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 398}], {
             RGBColor[
             0.35315773150982965`, 0.47919179379439375`, 0.9437647903277859]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 441}], {
             RGBColor[
             0.38894854463624445`, 0.5113094130668121, 0.9460044352238959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 481}], {
             RGBColor[
             0.3510247020399264, 0.47694984457964584`, 0.9436433174550093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 369}], {
             RGBColor[
             0.18627079750730335`, 0.313112796803831, 0.9339192184038662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 470}], {
             RGBColor[
             0.21338003115164933`, 0.3416063201887262, 0.9354630491553944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 381}], {
             RGBColor[
             0.2070518443671499, 0.33495499464800116`, 0.9351026682797305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 378}], {
             RGBColor[
             0.29415700671630873`, 0.4265080430632411, 0.9400631784149752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 380}], {
             RGBColor[
             0.2521693231018657, 0.3823763254115605, 0.9376720419483442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 381}], {
             RGBColor[
             0.2539571451040042, 0.38425543969027, 0.9377738557665203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 416}], {
             RGBColor[
             0.2990750168791546, 0.43160441949619144`, 0.9403459160671803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 452}], {
             RGBColor[
             0.34123924405804607`, 0.4681249538428697, 0.9430325833386572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 468}], {
             RGBColor[
             0.3285107882361406, 0.45710020516072636`, 0.9422215373890169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 487}], {
             RGBColor[
             0.2635219558175418, 0.39430866219422384`, 0.938318557586787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 405}], {
             RGBColor[
             0.19262927042803146`, 0.31979595499398417`, 0.9342813240301839]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 423}], {
             RGBColor[
             0.18733252995215482`, 0.31422874492109487`, 0.9339796824959081]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 429}], {
             RGBColor[
             0.2147911262952244, 0.34308947065322315`, 0.9355434089362928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 465}], {
             RGBColor[
             0.18700818241333977`, 0.3138878350929786, 0.9339612113834017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 469}], {
             RGBColor[
             0.19196874935401928`, 0.31910170546574246`, 0.9342437083321722]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 488}], {
             RGBColor[
             0.19450193224029588`, 0.32176424129229075`, 0.9343879693500374]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 368}], {
             RGBColor[
             0.2188305697178644, 0.3473351818059234, 0.9357734492633911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 375}], {
             RGBColor[
             0.269467048908057, 0.40055733197302834`, 0.9386571218433146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 441}], {
             RGBColor[
             0.31283134784024597`, 0.44063516501404976`, 0.9413280655520953]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 450}], {
             RGBColor[
             0.29858171762156427`, 0.42829285152586705`, 0.9404200917150141]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 492}], {
             RGBColor[
             0.18751313635976613`, 0.31441857370660203`, 0.9339899677636383]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 456}], {
             RGBColor[
             0.22153756303757788`, 0.35018040341823176`, 0.935927608528311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 390}], {
             RGBColor[
             0.48068060887291364`, 0.5879170041207702, 0.9526359105777598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 422}], {
             RGBColor[
             0.350546806463606, 0.47704224603396517`, 0.9435943271285148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 443}], {
             RGBColor[
             0.5772962329349696, 0.6646840201911736, 0.9613835661875354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 451}], {
             RGBColor[
             0.34741654792202903`, 0.4737521458369133, 0.9434160635353744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 442}], {
             RGBColor[
             0.49686920952944263`, 0.6022507016564647, 0.9535812424780545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 460}], {
             RGBColor[
             0.6856107819931014, 0.7528945564391651, 0.9702915062006248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 400}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 404}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 418}], {
             RGBColor[
             0.8610616366179067, 0.36732222461184755`, 0.20196461326343138`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 431}], {
             RGBColor[
             0.8760289938084724, 0.418883452871858, 0.28559208007867803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 444}], {
             RGBColor[
             0.8285562969045, 0.22050178822288907`, 0.17497884820646079`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 486}], {
             RGBColor[
             0.8762475134266291, 0.4193508442393725, 0.30937659196826445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 449}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 498}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 397}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 445}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 402}], {
             RGBColor[
             0.3168704423564799, 0.4463611267638398, 0.9415038733564272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 417}], {
             RGBColor[
             0.2694273041453681, 0.40051555770747876`, 0.9386548584378767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 441}], {
             RGBColor[
             0.3248775159216287, 0.45329645143875275`, 0.9420140770036214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 450}], {
             RGBColor[
             0.31062788570294697`, 0.44095413795057004`, 0.9411061031665402]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 461}], {
             RGBColor[
             0.4115391847777058, 0.525962316169853, 0.9481981362024026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 391}], {
             RGBColor[
             0.9692861559217731, 0.9190249098809967, 0.5809414281870671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 448}], {
             RGBColor[
             0.9051283578144917, 0.9255858485156985, 0.9321528841461747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 455}], {
             RGBColor[
             0.8735554698238286, 0.41891480083667676`, 0.4032149808607035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 475}], {
             RGBColor[
             0.9641436958902179, 0.97247391328753, 0.9319168018252305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 482}], {
             RGBColor[
             0.9611408807899072, 0.9702344187023767, 0.9369997845304479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 412}], {
             RGBColor[
             0.20734204026481207`, 0.3352600089359268, 0.935119194506796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 426}], {
             RGBColor[
             0.2010989407485189, 0.3286981155089309, 0.9347636592251812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 476}], {
             RGBColor[
             0.19264135251793435`, 0.3198086540365209, 0.93428201208733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 380}], {
             RGBColor[
             0.25770930190939245`, 0.38819919439321504`, 0.9379875355457686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 416}], {
             RGBColor[
             0.3046149956866814, 0.43742728847784595`, 0.9406614096646049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 452}], {
             RGBColor[
             0.34677922286557283`, 0.4739478228245242, 0.9433480769360816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 487}], {
             RGBColor[
             0.26906193462506856`, 0.40013153117587835`, 0.9386340511842113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 400}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 404}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 440}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 487}], {
             RGBColor[
             0.2270742510106255, 0.35599981352419774`, 0.9362429147175804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 416}], {
             RGBColor[
             0.26441513407437683`, 0.3951746851048749, 0.9383720870161499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 468}], {
             RGBColor[
             0.29385090543136283`, 0.42067047076940983`, 0.9402477083379865]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 425}], {
             RGBColor[
             0.2677389295661514, 0.3974082595226244, 0.9386075050248284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 462}], {
             RGBColor[
             0.2750365104468856, 0.4050784797216278, 0.9390230914601827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 393}], {
             RGBColor[
             0.5000243154359716, 0.6026515113802116, 0.9544266172832518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 395}], {
             RGBColor[
             0.7742514426418383, 0.7085541585318539, 0.6077294417407735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 443}], {
             RGBColor[
             0.6919520032781376, 0.7591269341730926, 0.9700338626521301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 480}], {
             RGBColor[
             0.5559679739852978, 0.6503988732098943, 0.9581869819713671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 402}], {
             RGBColor[
             0.493323693614111, 0.5967965847816775, 0.9540138020874405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 411}], {
             RGBColor[
             0.673364501803413, 0.7446351140079177, 0.9681614906767982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 458}], {
             RGBColor[
             0.5434356286207753, 0.6402010241853623, 0.9572068902738209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 461}], {
             RGBColor[
             0.587992436035337, 0.6763977741876906, 0.9607080649334159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 499}], {
             RGBColor[
             0.756352573168234, 0.3274478448111356, 0.4309329969189558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 415}], {
             RGBColor[
             0.18775866061236085`, 0.31467663526321576`, 0.9340039500066029]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 446}], {
             RGBColor[
             0.1942371163982918, 0.32148590305205027`, 0.9343728884795952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 441}], {
             RGBColor[
             0.605869176422092, 0.6857097720212253, 0.9648098337879067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 498}], {
             RGBColor[
             0.8260448459967887, 0.38209975318755884`, 0.4377902156211372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 439}], {
             RGBColor[
             0.24411472500393933`, 0.3739104321196243, 0.9372133445023774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 436}], {
             RGBColor[
             0.9470100510372832, 0.9597073375466911, 0.9644090844152291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 473}], {
             RGBColor[
             0.7653160411936457, 0.8168810892875349, 0.9773969600633411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 456}], {
             RGBColor[
             0.24930916567101583`, 0.3793701186072822, 0.937509160213881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 472}], {
             RGBColor[
             0.22243976571633683`, 0.35112867563656114`, 0.9359789876361772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 422}], {
             RGBColor[
             0.42800433190778703`, 0.5412859490450508, 0.9493162414930003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 443}], {
             RGBColor[
             0.6547537583791506, 0.7289277232022592, 0.967105480552021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 451}], {
             RGBColor[
             0.4248740733662101, 0.5379958488479989, 0.94913797789986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 407}], {
             RGBColor[
             0.8204042342330249, 0.8029780971899061, 0.6251186758041836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 448}], {
             RGBColor[
             0.888386104264779, 0.856120355886665, 0.6318853697511313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 455}], {
             RGBColor[
             0.8623939674573535, 0.3726044724173211, 0.20303663793067456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 475}], {
             RGBColor[
             0.9474014423405053, 0.9030084206584965, 0.6316492874301871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 478}], {
             RGBColor[
             0.7346414386946734, 0.7340552109266808, 0.6178863226320354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 482}], {
             RGBColor[
             0.9443986272401945, 0.9007689260733432, 0.6367322701354043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 413}], {
             RGBColor[
             0.4263466505931637, 0.5437017727632361, 0.9483874094656242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 473}], {
             RGBColor[
             0.5241730715613854, 0.6242799613386438, 0.9557686238662648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 474}], {
             RGBColor[
             0.4244363391619793, 0.5420471570165883, 0.9482656861104513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 490}], {
             RGBColor[
             0.39194710024697893`, 0.5139066112250432, 0.9461955005358933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 424}], {
             RGBColor[
             0.3045464501938735, 0.4319945031262181, 0.9408537890405738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 480}], {
             RGBColor[
             0.4234576653062009, 0.5404912555165833, 0.9483990101121553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 467}], {
             RGBColor[
             0.2149961156174362, 0.3433049274279415, 0.9355550827749383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 443}], {
             RGBColor[
             0.8336688218049073, 0.7551219636314238, 0.61354871525044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 430}], {
             RGBColor[
             0.267533642941468, 0.39852519971712486`, 0.9385470172337352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 477}], {
             RGBColor[
             0.25943030085066265`, 0.39000807339812527`, 0.9380855438894842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 495}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 399}], {
             RGBColor[
             0.30014888904900616`, 0.43280589130218833`, 0.9404044072496268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 464}], {
             RGBColor[
             0.288464885266985, 0.4205252625186573, 0.9397390205191753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 481}], {
             RGBColor[
             0.29452715913108485`, 0.4268970967201894, 0.9400842580474054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 496}], {
             RGBColor[
             0.25262917012324787`, 0.38285965378701825`, 0.9376982295559292]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 407}], {
             RGBColor[
             0.49595107779550673`, 0.5964347568986441, 0.9550832606977075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 464}], {
             RGBColor[
             0.291953585715003, 0.4241921078859083, 0.9399376968486202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 478}], {
             RGBColor[
             0.41018828225715515`, 0.5275118706354188, 0.9478509075255593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 481}], {
             RGBColor[
             0.29801585957910287`, 0.4305639420874404, 0.9402829343768502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 496}], {
             RGBColor[
             0.2561178705712659, 0.3865264991542693, 0.937896905885374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 404}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 418}], {
             RGBColor[
             0.8610616366179067, 0.36732222461184755`, 0.20196461326343138`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 431}], {
             RGBColor[
             0.8760289938084724, 0.418883452871858, 0.28559208007867803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 444}], {
             RGBColor[
             0.8285562969045, 0.22050178822288907`, 0.17497884820646079`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 428}], {
             RGBColor[
             0.20185876447098355`, 0.3294967384168478, 0.9348069300621171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 437}], {
             RGBColor[
             0.189249743774186, 0.31624385820642686`, 0.9340888649868091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 451}], {
             RGBColor[
             0.23914595187837517`, 0.36868793652624454`, 0.9369303802235176]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 417}], {
             RGBColor[
             0.30478452951240814`, 0.43365806607358726`, 0.9408155984994631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 458}], {
             RGBColor[
             0.4023396027301842, 0.5229080745336331, 0.9468577016043941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 461}], {
             RGBColor[
             0.4468964101447459, 0.5591048245359614, 0.9503588762639891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 440}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 445}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 471}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 483}], {
             RGBColor[
             0.8686864922225178, 0.39450469054086185`, 0.22397142092169176`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 497}], {
             RGBColor[
             0.8604026869949277, 0.3647097089386806, 0.20143440692924686`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 418}], {
             RGBColor[
             0.8610616366179067, 0.36732222461184755`, 0.20196461326343138`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 431}], {
             RGBColor[
             0.8760289938084724, 0.418883452871858, 0.28559208007867803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 444}], {
             RGBColor[
             0.8285562969045, 0.22050178822288907`, 0.17497884820646079`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 486}], {
             RGBColor[
             0.8762475134266291, 0.4193508442393725, 0.30937659196826445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 423}], {
             RGBColor[
             0.18539930704922003`, 0.3121968050766989, 0.9338695883115329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 429}], {
             RGBColor[
             0.2128579033922896, 0.34105753080882717`, 0.9354333147519176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 472}], {
             RGBColor[
             0.19387632575282085`, 0.32110668920821217`, 0.9343523419860775]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 488}], {
             RGBColor[
             0.1925687093373611, 0.3197323014478947, 0.9342778751656623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 419}], {
             RGBColor[
             0.8761600890568056, 0.41916385235228004`, 0.29986098883365586`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 493}], {
             RGBColor[
             0.7916429672985688, 0.8334067531326425, 0.7659846388427745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 448}], {
             RGBColor[
             0.7562464361257435, 0.809539035824608, 0.9763301317632911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 455}], {
             RGBColor[
             0.7743008553646631, 0.3415502590426163, 0.43266647927211443`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 475}], {
             RGBColor[
             0.8152617742014696, 0.8564271005964393, 0.9760940494423469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 478}], {
             RGBColor[
             0.6025017705556377, 0.6874738908646236, 0.9623310846441953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 482}], {
             RGBColor[
             0.812258959101159, 0.8541876060112861, 0.9811770321475642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{408, 463}], {
             RGBColor[
             0.831998657058118, 0.24386491747293382`, 0.17815401051060936`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 430}], {
             RGBColor[
             0.4088644575244336, 0.5231795348188764, 0.9480432177755177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 422}], {
             RGBColor[
             0.24555176281029023`, 0.37542084996755853`, 0.9372951816795421]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 428}], {
             RGBColor[
             0.20513431686132172`, 0.3329395516611099, 0.9349934679250014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 437}], {
             RGBColor[
             0.19252529616452413`, 0.31968667145068896`, 0.9342754028496933]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{412, 426}], {
             RGBColor[
             0.221482079932092, 0.35012208715653403`, 0.9359244488475336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{412, 476}], {
             RGBColor[
             0.2130244917015075, 0.341232625684124, 0.9354428017096823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 474}], {
             RGBColor[
             0.40874864664870547`, 0.5284592662479426, 0.9472660802155872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 490}], {
             RGBColor[
             0.37625940773370514`, 0.5003187204563975, 0.9451958946410293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 461}], {
             RGBColor[
             0.7674485024465632, 0.8134259226299666, 0.7363222999185557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 498}], {
             RGBColor[
             0.8759899507757182, 0.41879994377265295`, 0.28134248690904895`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 499}], {
             RGBColor[
             0.8759899507757182, 0.41879994377265295`, 0.28134248690904895`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 452}], {
             RGBColor[
             0.3516972330284187, 0.47904419925747455`, 0.9436308145882868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 468}], {
             RGBColor[
             0.33896877720651325`, 0.4680194505753313, 0.9428197686386466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{417, 458}], {
             RGBColor[
             0.3548964645190724, 0.477062505477272, 0.9440086866858435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 431}], {
             RGBColor[
             0.9709979456395686, 0.9110545162255583, 0.4028990400131641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 444}], {
             RGBColor[
             0.8835362304269067, 0.5400718010576258, 0.22348630967635297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 486}], {
             RGBColor[
             0.9713257250668036, 0.9117556032768301, 0.43857580784754374`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 427}], {
             RGBColor[
             0.21490485900541903`, 0.34320901094270806`, 0.9355498858458859]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 454}], {
             RGBColor[
             0.2690558886350951, 0.39909292378057587`, 0.9386715027011281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 489}], {
             RGBColor[
             0.2259038792592088, 0.3547696786076038, 0.936176263777747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 500}], {
             RGBColor[
             0.2460794158023615, 0.3759754467173574, 0.9373252307368479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 430}], {
             RGBColor[
             0.2393158270696491, 0.3688664861229826, 0.9369400543643528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 459}], {
             RGBColor[
             0.22407540206524434`, 0.35284783314459717`, 0.9360721347065403]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 477}], {
             RGBColor[
             0.23121248497884378`, 0.360349359803983, 0.9364785810201017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 428}], {
             RGBColor[
             0.25745308354951085`, 0.3879298926517971, 0.9379729442892144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 437}], {
             RGBColor[
             0.24484406285271326`, 0.3746770124413762, 0.9372548792139064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 451}], {
             RGBColor[
             0.2947402709569025, 0.42712109076119387`, 0.9400963944506149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 429}], {
             RGBColor[
             0.207561162916413, 0.3354903207359379, 0.9351316732176418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 465}], {
             RGBColor[
             0.17977821903452834`, 0.30628868517569324`, 0.9335494756647507]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 469}], {
             RGBColor[
             0.18473878597520788`, 0.3115025555484572, 0.9338319726135212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 488}], {
             RGBColor[
             0.18727196886148448`, 0.3141650913750055, 0.9339762336313865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{425, 462}], {
             RGBColor[
             0.2196150434125822, 0.3481597133975768, 0.9358181238797805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 476}], {
             RGBColor[
             0.20678139218521432`, 0.3346707322571282, 0.9350872664280675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 433}], {
             RGBColor[
             0.19902919731618948`, 0.32652268393223965`, 0.9346457903986212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 500}], {
             RGBColor[
             0.24278319621806277`, 0.37251091094186695`, 0.937137515907842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 437}], {
             RGBColor[
             0.20442661690374475`, 0.33219571413492754`, 0.9349531654593657]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 451}], {
             RGBColor[
             0.2543228250079339, 0.3846397924547452, 0.9377946806960742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{429, 488}], {
             RGBColor[
             0.21473056520455405`, 0.34302581710713376`, 0.9355399600717713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{430, 459}], {
             RGBColor[
             0.261161835730964, 0.3918280263429743, 0.938184152239341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{430, 477}], {
             RGBColor[
             0.26829891864456346`, 0.39932955300236017`, 0.9385905985529026]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 444}], {
             RGBColor[
             0.8985035876174724, 0.5916330293176362, 0.30711377649159965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 486}], {
             RGBColor[
             0.9937767608526522, 0.9890974456668459, 0.5640170080704137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{432, 460}], {
             RGBColor[
             0.797979397774264, 0.8421439216944954, 0.9804889458898756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 465}], {
             RGBColor[
             0.18295181335348598`, 0.3096243340224193, 0.9337302071663033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 469}], {
             RGBColor[
             0.1879123802941655, 0.31483820439518323`, 0.9340127041150739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 495}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{435, 439}], {
             RGBColor[
             0.3579216498299631, 0.4805187712808422, 0.9441708386779522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{435, 453}], {
             RGBColor[
             0.4536708445200175, 0.5672446965945355, 0.9501627222939097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 473}], {
             RGBColor[
             0.7880058098599707, 0.8340965074045622, 0.9491623567239293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 439}], {
             RGBColor[
             0.27373103330916027`, 0.40503904993081363`, 0.9388999494469579]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{439, 453}], {
             RGBColor[
             0.3621326688136605, 0.48404222467833025`, 0.9444734004370379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 445}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 471}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 450}], {
             RGBColor[
             0.35399218463513593`, 0.48103197099159145`, 0.9437770468753208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 461}], {
             RGBColor[
             0.45490348370989475`, 0.5660401492108743, 0.9508690799111832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 447}], {
             RGBColor[
             0.43707590774460403`, 0.5529949160396692, 0.9490710682438044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 500}], {
             RGBColor[
             0.3605233719937942, 0.48347254608803236`, 0.9443109769258367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{443, 451}], {
             RGBColor[
             0.521489697428266, 0.6147628649184023, 0.9578856335096356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{444, 486}], {
             RGBColor[
             0.898722107235629, 0.5921004206851508, 0.33089828838118596`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{445, 471}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 454}], {
             RGBColor[
             0.37348676159854866`, 0.49791719373137167`, 0.9450192240810519]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 500}], {
             RGBColor[
             0.3505102887658151, 0.47479971666815324`, 0.9436729521167717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 455}], {
             RGBColor[
             0.8196221020524992, 0.3769784315071223, 0.4371776085700797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 475}], {
             RGBColor[
             0.8832436442332238, 0.9095693592931984, 0.9828607433892947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 478}], {
             RGBColor[
             0.6704836405873918, 0.7406161495613826, 0.969097778591143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 482}], {
             RGBColor[
             0.8802408291329131, 0.907329864708045, 0.9879437260945121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{449, 499}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 461}], {
             RGBColor[
             0.440653853491213, 0.5536978357226917, 0.949961106074102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{452, 468}], {
             RGBColor[
             0.38113300438540465`, 0.5045399849220095, 0.9455064359101233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 489}], {
             RGBColor[
             0.2767586893045861, 0.4071890556699812, 0.9391101658039832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 500}], {
             RGBColor[
             0.2969342258477388, 0.4283948237797348, 0.9402591327630841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{455, 475}], {
             RGBColor[
             0.85896566076965, 0.4082371413550099, 0.4370202203561169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{455, 482}], {
             RGBColor[
             0.8569637840361095, 0.40674414496490774`, 0.4404088754929284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{457, 494}], {
             RGBColor[
             0.9630746438977319, 0.9212538232548773, 0.6116244787450666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{458, 461}], {
             RGBColor[
             0.4970083451514102, 0.6025092639396462, 0.9535519644503695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{459, 477}], {
             RGBColor[
             0.2530584936401587, 0.3833109000239747, 0.9377226788950901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{460, 463}], {
             RGBColor[
             0.8490960260828695, 0.5965456532875175, 0.46506056118722205`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{463, 483}], {
             RGBColor[
             0.8980458063387537, 0.6139805254867295, 0.2518434419429105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 481}], {
             RGBColor[
             0.28633185579708176`, 0.41828331330390933`, 0.9396175476463986]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 496}], {
             RGBColor[
             0.24443386678924475`, 0.3742458703707382, 0.9372315191549225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{465, 469}], {
             RGBColor[
             0.1844144384363928, 0.3111616457203408, 0.9338135015010149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 470}], {
             RGBColor[
             0.2470848114448652, 0.37703218128339433`, 0.9373824865313389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 491}], {
             RGBColor[
             0.2191139720880547, 0.34763305566574143`, 0.9357895886091172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 483}], {
             RGBColor[
             0.8686864922225178, 0.39450469054086185`, 0.22397142092169176`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 497}], {
             RGBColor[
             0.8604026869949277, 0.3647097089386806, 0.20143440692924686`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{472, 488}], {
             RGBColor[
             0.1957489875650853, 0.32307497550651876`, 0.9344589873059312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{474, 490}], {
             RGBColor[
             0.3743490963025207, 0.49866410470974976`, 0.9450741712858564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{475, 478}], {
             RGBColor[
             0.7294989786631181, 0.787504214333214, 0.9688616962701988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{475, 482}], {
             RGBColor[
             0.9392561672086392, 0.9542179294798765, 0.9877076437735679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{478, 482}], {
             RGBColor[
             0.7264961635628073, 0.7852647197480608, 0.973944678975416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{481, 496}], {
             RGBColor[
             0.2504961406533446, 0.38061770457227034`, 0.9375767566831525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{484, 490}], {
             RGBColor[
             0.27306794987010674`, 0.4012805048264995, 0.9389742880863683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{489, 500}], {
             RGBColor[
             0.2537822164718525, 0.3840715786067627, 0.937763893839703]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.0860569014282922], {
             RGBColor[
             0.2665869568298027, 0.3975301725903983, 0.9384931048601725]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.0860569014282922], {
             RGBColor[
             0.20161671018842872`, 0.32924232401875475`, 0.9347931454288129]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.0860569014282922], {
             RGBColor[
             0.19930844041135132`, 0.32681618613028957`, 0.9346616928797874]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.0860569014282922], {
             RGBColor[
             0.19006206717459462`, 0.3170976616045347, 0.9341351256027375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.0860569014282922], {
             RGBColor[
             0.33431180974343394`, 0.46398581942480244`, 0.9425230307898937]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.0860569014282922], {
             RGBColor[
             0.9534406635465423, 0.8531147764808367, 0.28139546888270184`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.0860569014282922], {
             RGBColor[
             0.2588724192803225, 0.3894217044959632, 0.9380537733593651]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.0860569014282922], {
             RGBColor[
             0.242957706247003, 0.37269433204685803`, 0.9371474539958257]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.0860569014282922], {
             RGBColor[
             0.3937584149506567, 0.5154754809820448, 0.946310915907129]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.0860569014282922], {
             RGBColor[
             0.9875036737064178, 0.989100462183736, 0.8567599963478333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.0860569014282922], {
             RGBColor[
             0.2440062290021841, 0.3737963959427358, 0.9372071658155828]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.0860569014282922], {
             RGBColor[
             0.5395182465349754, 0.6370442434139459, 0.9568919991691406]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.0860569014282922], {
             RGBColor[
             0.4138740589676099, 0.532898640787864, 0.9475926669563236]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.0860569014282922], {
             RGBColor[
             0.6469324131931254, 0.7241077851456973, 0.9654438350861145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.0860569014282922], {
             RGBColor[
             0.9874606584389937, 0.9890826742652142, 0.8574728706489945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.0860569014282922], {
             RGBColor[
             0.7541788838097023, 0.8078895430947328, 0.9761331610019253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.0860569014282922], {
             RGBColor[
             0.28355932289318264`, 0.4153692054331722, 0.9394596559991165]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.0860569014282922], {
             RGBColor[
             0.46934274654192526`, 0.5800726111493398, 0.9513675267483611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.0860569014282922], {
             RGBColor[
             0.8219966379615026, 0.8609018228788999, 0.9828839672054712]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.0860569014282922], {
             RGBColor[
             0.19129510586323456`, 0.3183936634454635, 0.9342053453319383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.0860569014282922], {
             RGBColor[
             0.9925631716550148, 0.9865017010857893, 0.43192531331195433`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.0860569014282922], {
             RGBColor[
             0.20633904470983166`, 0.3342057970140512, 0.9350620753937389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.0860569014282922], {
             RGBColor[
             0.7576060273863839, 0.8105668537040923, 0.9764747466451712]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.0860569014282922], {
             RGBColor[
             0.20463513155106594`, 0.33241487624985433`, 0.9349650400600608]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.0860569014282922], {
             RGBColor[
             0.2059976869465667, 0.3338470083615274, 0.9350426355741145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.0860569014282922], {
             RGBColor[
             0.949329454771621, 0.8368152036673847, 0.2780874937999273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.0860569014282922], {
             RGBColor[
             0.20262840066914578`, 0.3303056748588697, 0.9348507597050277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.0860569014282922], {
             RGBColor[
             0.1789570524953891, 0.3054255870780922, 0.9335027114451537]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.0860569014282922], {
             RGBColor[
             0.23515707303258868`, 0.3644953719497967, 0.9367032194742675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.0860569014282922], {
             RGBColor[
             0.3596303768180513, 0.4859154896766539, 0.9441363074955585]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.0860569014282922], {
             RGBColor[
             0.5603811253615456, 0.6539816683073362, 0.9585344014136115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.0860569014282922], {
             RGBColor[
             0.3081602529797812, 0.4412263427432439, 0.9408606425737336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.0860569014282922], {
             RGBColor[
             0.21649762081927568`, 0.34488310459600313`, 0.9356405912749051]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.0860569014282922], {
             RGBColor[
             0.8992999083697804, 0.6356262276586594, 0.23768571396967728`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.0860569014282922], {
             RGBColor[
             0.5059330480764017, 0.6097782663093272, 0.954248049319846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.0860569014282922], {
             RGBColor[
             0.20512412607187444`, 0.33292884049526744`, 0.9349928875746183]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.0860569014282922], {
             RGBColor[
             0.6031363050639882, 0.6886922492886749, 0.9619002457771715]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.0860569014282922], {
             RGBColor[
             0.2720687261283602, 0.40329185968743014`, 0.9388052835121744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.0860569014282922], {
             RGBColor[
             0.40134636687536374`, 0.5220477835576731, 0.9467944134940088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.0860569014282922], {
             RGBColor[
             0.6993501336328052, 0.7650569067426056, 0.970668343588094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.0860569014282922], {
             RGBColor[
             0.27477024647677334`, 0.40613132885989545`, 0.9389591310994754]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.0860569014282922], {
             RGBColor[
             0.2856812767955215, 0.41759951352417846`, 0.9395804981347052]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.0860569014282922], {
             RGBColor[
             0.7146679187190441, 0.7770232768714539, 0.97219507725265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.0860569014282922], {
             RGBColor[
             0.22612030793820787`, 0.35499715887160266`, 0.9361885890708385]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.0860569014282922], {
             RGBColor[
             0.18352693138300546`, 0.3102288195360335, 0.9337629592872735]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.0860569014282922], {
             RGBColor[
             0.8437950041640877, 0.3376331698641804, 0.18957145148790017`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.0860569014282922], {
             RGBColor[
             0.9946416792371043, 0.9909474186345262, 0.6581580365604908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.0860569014282922], {
             RGBColor[
             0.240267978136988, 0.3698672572646202, 0.9369942779590565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.0860569014282922], {
             RGBColor[
             0.6025610453058137, 0.6882252275018321, 0.961854959221762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.0860569014282922], {
             RGBColor[
             0.5285279267956817, 0.6281218067413252, 0.9560268009403956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.0860569014282922], {
             RGBColor[
             0.29903790758239124`, 0.43163817934048265`, 0.9403411384986529]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.0860569014282922], {
             RGBColor[
             0.20425044222453645`, 0.33201054337695984`, 0.9349431325720118]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.0860569014282922], {
             RGBColor[
             0.1972436349934338, 0.32464594471983343`, 0.9345441052658429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.0860569014282922], {
             RGBColor[
             0.2605769831148301, 0.3912133091616199, 0.9381508457480642]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.0860569014282922], {
             RGBColor[
             0.18730821452687368`, 0.3142031878674374, 0.9339782977684097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.0860569014282922], {
             RGBColor[
             0.20692796280704617`, 0.3348247872737876, 0.935095613408149]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.0860569014282922], {
             RGBColor[
             0.9814207743108861, 0.9489900505202847, 0.382323645900509]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.0860569014282922], {
             RGBColor[
             0.9855771277360073, 0.9883037859149981, 0.8886878488186855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.0860569014282922], {
             RGBColor[
             0.25995825934690286`, 0.39056299125217575`, 0.9381156103448005]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.0860569014282922], {
             RGBColor[
             0.3185855666826758, 0.4503645381095326, 0.941520968488233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.0860569014282922], {
             RGBColor[
             0.8407007288961474, 0.31384921423472306`, 0.18660836999683647`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.0860569014282922], {
             RGBColor[
             0.22105372540225315`, 0.34967185938642753`, 0.935900054690753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.0860569014282922], {
             RGBColor[
             0.9943451951306927, 0.9903132691100532, 0.6258875712654035]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.0860569014282922], {
             RGBColor[
             0.9392816575746442, 0.9542369401531062, 0.9876644952328739]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.0860569014282922], {
             RGBColor[
             0.9560909454429859, 0.8635465900222101, 0.28392204388553066`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.0860569014282922], {
             RGBColor[
             0.9579895862140718, 0.9681892827009697, 0.9559968518555605]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.0860569014282922], {
             RGBColor[
             0.4492602452544817, 0.5635483767881156, 0.9498474434557472]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.0860569014282922], {
             RGBColor[
             0.8979401714022621, 0.6294519796637963, 0.23655111611377708`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.0860569014282922], {
             RGBColor[
             0.67875131942796, 0.7489649565289941, 0.9686152462950182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.0860569014282922], {
             RGBColor[
             0.21486301907210675`, 0.34316503451999186`, 0.9355475031235805]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.0860569014282922], {
             RGBColor[
             0.20642970531273738`, 0.3343010870559193, 0.9350672383809541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.0860569014282922], {
             RGBColor[
             0.854284899814332, 0.8866476064388262, 0.9859636504450657]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.0860569014282922], {
             RGBColor[
             0.22472424201089944`, 0.35352980506630927`, 0.9361090851815727]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.0860569014282922], {
             RGBColor[
             0.8587915518062159, 0.890241088407345, 0.9863934989351874]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.0860569014282922], {
             RGBColor[
             0.5985155306782874, 0.6849408964788493, 0.9615364814910747]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.0860569014282922], {
             RGBColor[
             0.9641975980982375, 0.8908922329609346, 0.3154148586382841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.0860569014282922], {
             RGBColor[
             0.6576732634723652, 0.7324986190173249, 0.9665143826629965]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.0860569014282922], {
             RGBColor[
             0.3738197825598743, 0.4982056397499517, 0.9450404438822286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.0860569014282922], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.0860569014282922], {
             RGBColor[
             0.20371097625405837`, 0.3314435304378693, 0.9349124107830614]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.0860569014282922], {
             RGBColor[
             0.9553028976633565, 0.8604979142012724, 0.28289386616534334`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.0860569014282922], {
             RGBColor[
             0.21930919416960923`, 0.3478382464512501, 0.9358007062178566]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.0860569014282922], {
             RGBColor[
             0.49037845718069295`, 0.5971503486938564, 0.953023534946192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.0860569014282922], {
             RGBColor[
             0.26729718777158684`, 0.39827667034145603`, 0.9385335514616145]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.0860569014282922], {
             RGBColor[
             0.9943968653913747, 0.9904237865729874, 0.6315115602687539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.0860569014282922], {
             RGBColor[
             0.23276328462783158`, 0.36197934856144603`, 0.9365668967659092]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.0860569014282922], {
             RGBColor[
             0.18203014314014365`, 0.3086556001909298, 0.9336777194111423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.0860569014282922], {
             RGBColor[
             0.3194029847849358, 0.4510725445850818, 0.9415730536468945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.0860569014282922], {
             RGBColor[
             0.3113782533268795, 0.444121925530844, 0.9410617248543786]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.0860569014282922], {
             RGBColor[
             0.33067337344239356`, 0.46083438877396704`, 0.9422911928461343]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.0860569014282922], {
             RGBColor[
             0.9937947583663093, 0.9891359405287304, 0.5659759263641978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.0860569014282922], {
             RGBColor[
             0.9845357488920988, 0.9878731490008265, 0.9059461912643052]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.0860569014282922], {
             RGBColor[
             0.25555645648574987`, 0.385936417354683, 0.9378649341837416]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.0860569014282922], {
             RGBColor[
             0.1897272593739602, 0.31674575737802724`, 0.9341160587937951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.0860569014282922], {
             RGBColor[
             0.23087379955273474`, 0.3599933799472462, 0.9364592933861251]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.0860569014282922], {
             RGBColor[
             0.6844298372258936, 0.7534010577910736, 0.9691812278803502]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.0860569014282922], {
             RGBColor[
             0.19890073469948152`, 0.32638766157707927`, 0.9346384746426429]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.0860569014282922], {
             RGBColor[
             0.23614802813125227`, 0.3655369285886743, 0.9367596529011497]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.0860569014282922], {
             RGBColor[
             0.2021529677712563, 0.32980596473900103`, 0.9348236845048329]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.0860569014282922], {
             RGBColor[
             0.18313418987661276`, 0.309816023311565, 0.9337405932394934]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.0860569014282922], {
             RGBColor[
             0.29180692255249685`, 0.42403795560313273`, 0.9399293445984841]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.0860569014282922], {
             RGBColor[
             0.2080093336373953, 0.3359613765793552, 0.9351571958771926]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.0860569014282922], {
             RGBColor[
             0.20873262495813816`, 0.3367216016167744, 0.9351983862478953]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.0860569014282922], {
             RGBColor[
             0.20667495168092284`, 0.33455885653840006`, 0.9350812047988127]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.0860569014282922], {
             RGBColor[
             0.9344583887804918, 0.7778563825015339, 0.2661218850346821]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.0860569014282922], {
             RGBColor[
             0.24495698094472051`, 0.3747956965154964, 0.9372613097321988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.0860569014282922], {
             RGBColor[
             0.7604405856228837, 0.8127812321418865, 0.9767572689197328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.0860569014282922], {
             RGBColor[
             0.8331937393088721, 0.8698300875560732, 0.9839519567277537]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.0860569014282922], {
             RGBColor[
             0.6598859337650126, 0.7342271738668581, 0.966734920959188]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.0860569014282922], {
             RGBColor[
             0.2610002522409667, 0.3916581918500021, 0.9381749502986271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.0860569014282922], {
             RGBColor[
             0.2013445076269774, 0.3289562218680302, 0.9347776438956258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.0860569014282922], {
             RGBColor[
             0.18353112071158095`, 0.3102332227859851, 0.9337631978633384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.0860569014282922], {
             RGBColor[
             0.8894828910866501, 0.591049444998604, 0.22949415411151997`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.0860569014282922], {
             RGBColor[
             0.3211744864498682, 0.45260693028898363`, 0.9416859321665065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.0860569014282922], {
             RGBColor[
             0.1954809540192259, 0.32279325525551217`, 0.9344437231920146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.0860569014282922], {
             RGBColor[
             0.19474583817336233`, 0.32202060189247295`, 0.9344018594320991]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.0860569014282922], {
             RGBColor[
             0.17930336856424547`, 0.3057895872241672, 0.9335224336329464]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.0860569014282922], {
             RGBColor[
             0.3011825170683711, 0.43389229988634254`, 0.9404632708362141]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.0860569014282922], {
             RGBColor[
             0.340635459799505, 0.4694630472674779, 0.9429259681796823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.0860569014282922], {
             RGBColor[
             0.8371868177096, 0.28683975304921994`, 0.1832434446762037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.0860569014282922], {
             RGBColor[
             0.2562538810668797, 0.3866694548087229, 0.9379046514818897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.0860569014282922], {
             RGBColor[
             0.3086579844982561, 0.441749490127162, 0.9408889876473829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.0860569014282922], {
             RGBColor[
             0.18386384177004123`, 0.31058293371416035`, 0.933782145835401]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.0860569014282922], {
             RGBColor[
             0.6735645089681628, 0.7449129807765811, 0.9680982735018852]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.0860569014282922], {
             RGBColor[
             0.8554632653203876, 0.4273205381761434, 0.2007449915485891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.0860569014282922], {
             RGBColor[
             0.3389460376431222, 0.4679997547084456, 0.942818319693775]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.0860569014282922], {
             RGBColor[
             0.28569344941384495`, 0.4176123077178249, 0.9395811913473109]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.0860569014282922], {
             RGBColor[
             0.20179304187532063`, 0.3294276598017528, 0.934803187257522]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.0860569014282922], {
             RGBColor[
             0.3978373772063899, 0.5190084730733568, 0.9465708237751796]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.0860569014282922], {
             RGBColor[
             0.24352168839563612`, 0.373287113043605, 0.9371795719448536]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.0860569014282922], {
             RGBColor[
             0.26709219000597495`, 0.39806120469218886`, 0.93852187714213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.0860569014282922], {
             RGBColor[
             0.8177268607774917, 0.8575337056844831, 0.9824670294564657]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.0860569014282922], {
             RGBColor[
             0.23397806856290648`, 0.3632561634989598, 0.9366360769138999]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.0860569014282922], {
             RGBColor[
             0.41932351101049736`, 0.5376186822499895, 0.9479399012217352]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.0860569014282922], {
             RGBColor[
             0.45486118183922636`, 0.5683158245366335, 0.9502274849272453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.0860569014282922], {
             RGBColor[
             0.331702995966787, 0.46172619605426385`, 0.9423567994829292]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.0860569014282922], {
             RGBColor[
             0.19787594539539122`, 0.32531054304308565`, 0.934580114407815]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.0860569014282922], {
             RGBColor[
             0.8806632832194534, 0.9076810133439271, 0.9884796442025071]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.0860569014282922], {
             RGBColor[
             0.8447410453925083, 0.8790375959838911, 0.9850533490904128]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.0860569014282922], {
             RGBColor[
             0.25109817118593475`, 0.381250476832963, 0.9376110414313592]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.0860569014282922], {
             RGBColor[
             0.4574599131251553, 0.570425591666061, 0.95043206657354]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.0860569014282922], {
             RGBColor[
             0.7801061400958719, 0.8281441127599345, 0.9787173476045451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.0860569014282922], {
             RGBColor[
             0.19997089892350478`, 0.32751247202885847`, 0.934699418912035]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.0860569014282922], {
             RGBColor[
             0.21686761525785075`, 0.3452719922099478, 0.9356616619108242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.0860569014282922], {
             RGBColor[
             0.9553966243175557, 0.8608695091526162, 0.28296928083135936`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.0860569014282922], {
             RGBColor[
             0.37795345536951325`, 0.5017860193732245, 0.9453038378583956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.0860569014282922], {
             RGBColor[
             0.215756853533542, 0.3441045112113384, 0.9355984056738496]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.0860569014282922], {
             RGBColor[
             0.9948073015950193, 0.9921207000103479, 0.7357199810506223]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.0860569014282922], {
             RGBColor[
             0.8837943025257868, 0.9101776031495423, 0.9887782836190391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.0860569014282922], {
             RGBColor[
             0.20242608517667066`, 0.3300930284487352, 0.9348392381370303]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.0860569014282922], {
             RGBColor[
             0.9567165072169457, 0.8656567567746658, 0.2863522332499358]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.0860569014282922], {
             RGBColor[
             0.270181620235489, 0.40130839174459826`, 0.9386978156232983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.0860569014282922], {
             RGBColor[
             0.6034964487201209, 0.6889846301330103, 0.9619285976050319]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.0860569014282922], {
             RGBColor[
             0.3876691533578903, 0.5102012686455771, 0.9459229135429605]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.0860569014282922], {
             RGBColor[
             0.9544946818446345, 0.965582788744624, 0.9619128133359728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.0860569014282922], {
             RGBColor[
             0.2566248317017963, 0.38705934744564896`, 0.9379257765717759]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.0860569014282922], {
             RGBColor[
             0.8763132971847281, 0.531249394926778, 0.21850512214346993`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.0860569014282922], {
             RGBColor[
             0.3206235691378255, 0.4521297534032015, 0.9416508282025402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.0860569014282922], {
             RGBColor[
             0.36718010963697145`, 0.4924546887837977, 0.9446173697948136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.0860569014282922], {
             RGBColor[
             0.38027801256113686`, 0.5037994339769674, 0.9454519565871206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.0860569014282922], {
             RGBColor[
             0.5334133816925579, 0.6320880391138444, 0.9564114018458887]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.0860569014282922], {
             RGBColor[
             0.34462319164040967`, 0.47291702015883946`, 0.943180062926372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.0860569014282922], {
             RGBColor[
             0.22919385631472186`, 0.35822765308954135`, 0.9363636231039736]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.0860569014282922], {
             RGBColor[
             0.8701957487608276, 0.8993344855002725, 0.9874812414213651]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.0860569014282922], {
             RGBColor[
             0.18752850541486277`, 0.314434727557963, 0.9339908430085895]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.0860569014282922], {
             RGBColor[
             0.20985498932745156`, 0.3379012777309339, 0.9352623032383384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.0860569014282922], {
             RGBColor[
             0.21841757556668306`, 0.34690109876769015`, 0.9357499298574514]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.0860569014282922], {
             RGBColor[
             0.23522235731990115`, 0.36456398987502503`, 0.9367069373178505]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.0860569014282922], {
             RGBColor[
             0.4134590735708867, 0.5325392012949949, 0.9475662244538017]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.0860569014282922], {
             RGBColor[
             0.19393685411417064`, 0.3211703083537106, 0.9343557889867128]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.0860569014282922], {
             RGBColor[
             0.9909931722195693, 0.9905434594949455, 0.7989299754522408]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.0860569014282922], {
             RGBColor[
             0.6024325749506131, 0.6881209294799567, 0.9618448455647982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.0860569014282922], {
             RGBColor[
             0.5677847377648733, 0.6599922543852954, 0.9591172409023272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.0860569014282922], {
             RGBColor[
             0.21266853360939608`, 0.34085849116026834`, 0.9354225304229293]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.0860569014282922], {
             RGBColor[
             0.8802420747951332, 0.9073451531797723, 0.9884394689669782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.0860569014282922], {
             RGBColor[
             0.4450599520442159, 0.5599102939222584, 0.9495798044865625]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.0860569014282922], {
             RGBColor[
             0.18533323543547214`, 0.3121273596214676, 0.9338658256308742]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.0860569014282922], {
             RGBColor[
             0.9930049498136619, 0.9874466198965118, 0.4800101395419234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.0860569014282922], {
             RGBColor[
             0.2504170603715949, 0.38053458618217195`, 0.9375722531780957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.0860569014282922], {
             RGBColor[
             0.21578236892213723`, 0.34413132950252107`, 0.9355998587374834]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.0860569014282922], {
             RGBColor[
             0.1919302366972257, 0.31906122622160893`, 0.9342415150933422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.0860569014282922], {
             RGBColor[
             0.2792508331211001, 0.4108407095086842, 0.9392142938804358]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.0860569014282922], {
             RGBColor[
             0.21604971918074886`, 0.3444123315753073, 0.9356150839392021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.0860569014282922], {
             RGBColor[
             0.20492571704741236`, 0.3327203000306991, 0.934981588474195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.0860569014282922], {
             RGBColor[
             0.2693332332275772, 0.4004166832084398, 0.938649501238274]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.0860569014282922], {
             RGBColor[
             0.18890068939112134`, 0.3158769799184998, 0.9340689868560732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.0860569014282922], {
             RGBColor[
             0.7398173513855104, 0.796670204813265, 0.9747017376660327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.0860569014282922], {
             RGBColor[
             0.3469706927955112, 0.4749503076705497, 0.9433296436241613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.0860569014282922], {
             RGBColor[
             0.2572169453532387, 0.3876816964354887, 0.9379594965682719]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.0860569014282922], {
             RGBColor[
             0.3049544364430743, 0.43785682630265677`, 0.9406780760645487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.0860569014282922], {
             RGBColor[
             0.295260889517734, 0.42766829387775107`, 0.9401260429074682]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.0860569014282922], {
             RGBColor[
             0.2006287179667525, 0.32820388155144814`, 0.9347368807333919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.0860569014282922], {
             RGBColor[
             0.21361395179144738`, 0.34185218561257913`, 0.9354763705897763]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.0860569014282922], {
             RGBColor[
             0.24023088414070523`, 0.3698282691226319, 0.9369921655108439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.0860569014282922], {
             RGBColor[
             0.5725831029202398, 0.6638877833823089, 0.9594949857843484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.0860569014282922], {
             RGBColor[
             0.4323931062930283, 0.5489389087867588, 0.9487726842761488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.0860569014282922], {
             RGBColor[
             0.29510601197456354`, 0.4275055077600755, 0.9401172228605054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.0860569014282922], {
             RGBColor[
             0.6961033750146681, 0.7625205142338375, 0.9703447370317223]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.0860569014282922], {
             RGBColor[
             0.3473763609653794, 0.4753016770498144, 0.9433554924412271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.0860569014282922], {
             RGBColor[
             0.3057070456133757, 0.438647866258821, 0.9407209360434119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.0860569014282922], {
             RGBColor[
             0.4230361383836957, 0.5408343734785764, 0.9481764665550079]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.0860569014282922], {
             RGBColor[
             0.936541673425211, 0.7861159119043911, 0.2677981447607987]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.0860569014282922], {
             RGBColor[
             0.25524447055801713`, 0.38560850036358557`, 0.937847167046699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.0860569014282922], {
             RGBColor[
             0.34023858975482646`, 0.4691192983820458, 0.9429006799713738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.0860569014282922], {
             RGBColor[
             0.2549643465593099, 0.385314072280057, 0.937831214399379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.0860569014282922], {
             RGBColor[
             0.977212423501673, 0.9347942950730491, 0.3659749976870823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.0860569014282922], {
             RGBColor[
             0.4829394273144061, 0.5911110091239283, 0.9524379072650536]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.0860569014282922], {
             RGBColor[
             0.4576850364535088, 0.5706083569257087, 0.9504497891066018]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.0860569014282922], {
             RGBColor[
             0.2019820387076045, 0.3296263074555744, 0.9348139503475248]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.0860569014282922], {
             RGBColor[
             0.18472467114451377`, 0.31148771996646574`, 0.9338311687947942]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.0860569014282922], {
             RGBColor[
             0.3594825143186384, 0.4857874186114477, 0.9441268858278457]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.0860569014282922], {
             RGBColor[
             0.45200942833171354`, 0.5659295809916547, 0.9500226189704213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.0860569014282922], {
             RGBColor[
             0.1934857951277101, 0.32069621676014903`, 0.9343301018447159]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.0860569014282922], {
             RGBColor[
             0.9881377044358732, 0.9893626501842123, 0.8462524663418269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.0860569014282922], {
             RGBColor[
             0.2370889777331282, 0.36652592627989644`, 0.9368132385889664]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.0860569014282922], {
             RGBColor[
             0.25751049402968956`, 0.3879902347064996, 0.9379762137311295]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.0860569014282922], {
             RGBColor[
             0.8652595816135205, 0.8953985198056976, 0.9870104253922865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.0860569014282922], {
             RGBColor[
             0.9939516779922013, 0.9894715757415058, 0.5830556592468749]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.0860569014282922], {
             RGBColor[
             0.3120362716652125, 0.4446918679425447, 0.9411036532010344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.0860569014282922], {
             RGBColor[
             0.9264054963123022, 0.9441546124248671, 0.9928425773218587]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.0860569014282922], {
             RGBColor[
             0.9518509475754381, 0.963611096055375, 0.9663879658573935]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.0860569014282922], {
             RGBColor[
             0.38201222096486337`, 0.5053015181324264, 0.9455624588131057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.0860569014282922], {
             RGBColor[
             0.20216870968076056`, 0.32982251048398475`, 0.9348245809832911]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.0860569014282922], {
             RGBColor[
             0.4056075310905943, 0.525738589828565, 0.9470659311098037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.0860569014282922], {
             RGBColor[
             0.2106927321879748, 0.33878179859330904`, 0.9353100114549157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.0860569014282922], {
             RGBColor[
             0.18403967249588782`, 0.31076774295533705`, 0.9337921591351197]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.0860569014282922], {
             RGBColor[
             0.3045714380557589, 0.43745427071408804`, 0.9406562648729865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.0860569014282922], {
             RGBColor[
             0.5663742859676012, 0.6588471860761407, 0.9590062049701908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.0860569014282922], {
             RGBColor[
             0.21438528258518844`, 0.34266290318199794`, 0.9355202967373982]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.0860569014282922], {
             RGBColor[
             0.48393777173830865`, 0.5919215101021562, 0.9525165005951594]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.0860569014282922], {
             RGBColor[
             0.9334491648933394, 0.7738551460928987, 0.26530983980554995`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.0860569014282922], {
             RGBColor[
             0.33049394994511194`, 0.46067898115870887`, 0.9422797601395455]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.0860569014282922], {
             RGBColor[
             0.9810175438161675, 0.9476298593785759, 0.3807571715722161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.0860569014282922], {
             RGBColor[
             0.2027780029210282, 0.3304629163109287, 0.9348592793319558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.0860569014282922], {
             RGBColor[
             0.304084721945441, 0.4369427012225601, 0.9406285471105358]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.0860569014282922], {
             RGBColor[
             0.5428330408674731, 0.6397353427828505, 0.9571529519214865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.0860569014282922], {
             RGBColor[
             0.19353123231110916`, 0.32074397412078526`, 0.9343326894250921]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.0860569014282922], {
             RGBColor[
             0.29911991378268726`, 0.43172437305648714`, 0.9403458086304425]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.0860569014282922], {
             RGBColor[
             0.3342797596203076, 0.46395805921903643`, 0.9425209885843889]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.0860569014282922], {
             RGBColor[
             0.21540663334735502`, 0.3437364075904136, 0.9355784611523505]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.0860569014282922], {
             RGBColor[
             0.8379345637063845, 0.8736102922443995, 0.9844041407909724]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.0860569014282922], {
             RGBColor[
             0.31358168594229274`, 0.44603042811457155`, 0.9412021256322137]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.0860569014282922], {
             RGBColor[
             0.1901247553990758, 0.3171635509031274, 0.9341386956043828]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.0860569014282922], {
             RGBColor[
             0.19681365185457406`, 0.3241940051783862, 0.9345196183621879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.0860569014282922], {
             RGBColor[
             0.2056030288546981, 0.3334321976842053, 0.9350201603796269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.0860569014282922], {
             RGBColor[
             0.2158208370998732, 0.3441717619963449, 0.935602049443297]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.0860569014282922], {
             RGBColor[
             0.19315143637710094`, 0.3203447845136896, 0.9343110606085081]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.0860569014282922], {
             RGBColor[
             0.24929221648012767`, 0.37935230393301794`, 0.937508194982534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.0860569014282922], {
             RGBColor[
             0.6797711867345639, 0.7497616846201918, 0.9687168971369385]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.0860569014282922], {
             RGBColor[
             0.4587788150425182, 0.5714963356584305, 0.9505358953637717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.0860569014282922], {
             RGBColor[
             0.4181101479346723, 0.5365677281391114, 0.9478625867994784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.0860569014282922], {
             RGBColor[
             0.48818097544843886`, 0.5953663340281886, 0.9528505411345881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.0860569014282922], {
             RGBColor[
             0.22967809360797173`, 0.35873661718716465`, 0.9363911997014592]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.0860569014282922], {
             RGBColor[
             0.8618019499281809, 0.8926414981547197, 0.9866806333954745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.0860569014282922], {
             RGBColor[
             0.4631485198395302, 0.5750438588656026, 0.9508798945321485]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.0860569014282922], {
             RGBColor[
             0.23426115126844915`, 0.3635537013709653, 0.9366521980551972]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.0860569014282922], {
             RGBColor[
             0.23051962020931505`, 0.35962111500104466`, 0.9364391233964787]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.0860569014282922], {
             RGBColor[
             0.21885291985763583`, 0.3473586732199038, 0.935774722070787]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.0860569014282922], {
             RGBColor[
             0.22655758961928207`, 0.35545676964367157`, 0.9362134916156754]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.0860569014282922], {
             RGBColor[
             0.24802738733723106`, 0.37802288830903413`, 0.9374361648339931]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.0860569014282922], {
             RGBColor[
             0.9779347509559622, 0.9830643539082616, 0.9222348904796338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.0860569014282922], {
             RGBColor[
             0.6013820686751921, 0.6872680811608015, 0.9617621458626657]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.0860569014282922], {
             RGBColor[
             0.1982372182974502, 0.32569026376917465`, 0.9346006883651319]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.0860569014282922], {
             RGBColor[
             0.9859314232921296, 0.9642055286847646, 0.39984666542805347`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.0860569014282922], {
             RGBColor[
             0.2610014285656661, 0.39165942824184447`, 0.9381750172885784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.0860569014282922], {
             RGBColor[
             0.18726572239046815`, 0.31415852593791815`, 0.9339758779041029]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.0860569014282922], {
             RGBColor[
             0.18845275152117702`, 0.31540616881628697`, 0.9340434774570445]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.0860569014282922], {
             RGBColor[
             0.4266116652397737, 0.5439313151301061, 0.948404295964563]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.0860569014282922], {
             RGBColor[
             0.19982772421039008`, 0.3273619863275738, 0.9346912653239311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.0860569014282922], {
             RGBColor[
             0.4770512439418583, 0.586330716602456, 0.9519743679008402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.0860569014282922], {
             RGBColor[
             0.19035022185825642`, 0.3174005304471254, 0.9341515355856854]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.0860569014282922], {
             RGBColor[
             0.22481780914373545`, 0.3536281500554188, 0.9361144136913675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.0860569014282922], {
             RGBColor[
             0.8274945099942945, 0.8652856768020875, 0.9834083591479672]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.0860569014282922], {
             RGBColor[
             0.2120977707203083, 0.34025858317537977`, 0.9353900263207638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.0860569014282922], {
             RGBColor[
             0.4177501378450422, 0.536255905494107, 0.9478396472749117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.0860569014282922], {
             RGBColor[
             0.2130775983694969, 0.3412884441593381, 0.93544582605586]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.0860569014282922], {
             RGBColor[
             0.3150309137810037, 0.44728567642815387`, 0.9412944691485945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.0860569014282922], {
             RGBColor[
             0.22268668288329785`, 0.35138820123448977`, 0.9359930492035543]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.0860569014282922], {
             RGBColor[
             0.993193928488921, 0.9878508261742159, 0.5005793021026774]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.0860569014282922], {
             RGBColor[
             0.18435110707541025`, 0.31109508044450795`, 0.9338098948736974]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.0860569014282922], {
             RGBColor[
             0.981651687789881, 0.9858364393130727, 0.9159430859521958]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.0860569014282922], {
             RGBColor[
             0.9487736339623114, 0.8346115593747768, 0.2776402673299655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.0860569014282922], {
             RGBColor[
             0.2278120755134005, 0.35677531385738964`, 0.9362849327314998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.0860569014282922], {
             RGBColor[
             0.2302467671760705, 0.35933432916322317`, 0.9364235848198853]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.0860569014282922], {
             RGBColor[
             0.9829894651638862, 0.9542816131135821, 0.3884177136420036]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.0860569014282922], {
             RGBColor[
             0.2829518153401187, 0.4147306764766984, 0.9394250593426964]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.0860569014282922], {
             RGBColor[
             0.9627353434690271, 0.8859597047428938, 0.30973427552741817`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.0860569014282922], {
             RGBColor[
             0.2059271258124198, 0.33377284413570474`, 0.9350386172219107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.0860569014282922], {
             RGBColor[
             0.19011491379531606`, 0.31715320675358216`, 0.9341381351396081]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.0860569014282922], {
             RGBColor[
             0.45951259018598095`, 0.572092047376087, 0.950593660830972]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.0860569014282922], {
             RGBColor[
             0.19816019677618812`, 0.3256093092668817, 0.9345963021034391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.0860569014282922], {
             RGBColor[
             0.1865974340180864, 0.31345611248661487`, 0.9339378198699398]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.0860569014282922], {
             RGBColor[
             0.8619160083689651, 0.8927324452593671, 0.9866915123913776]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.0860569014282922], {
             RGBColor[
             0.8567924356784412, 0.43753712399430794`, 0.2020178065845444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.0860569014282922], {
             RGBColor[
             0.49166457190272544`, 0.5981944745640103, 0.9531247826083038]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.0860569014282922], {
             RGBColor[
             0.22035367918749607`, 0.34893606642922426`, 0.9358601880944482]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.0860569014282922], {
             RGBColor[
             0.3846259152851337, 0.5075653687845483, 0.9457290011039943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.0860569014282922], {
             RGBColor[
             0.8226648881293261, 0.1752178387451157, 0.16933722850995975`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.0860569014282922], {
             RGBColor[
             0.4096552744186712, 0.5292445416538502, 0.94732384973539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.0860569014282922], {
             RGBColor[
             0.18026187282935408`, 0.3067970359794769, 0.9335770190328644]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.0860569014282922], {
             RGBColor[
             0.1948064264350734, 0.3220842839970489, 0.9344053098439712]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.0860569014282922], {
             RGBColor[
             0.28861702790878196`, 0.42068517408158657`, 0.9397476848175508]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.0860569014282922], {
             RGBColor[
             0.30003965645411895`, 0.4326910809192154, 0.9403981866149431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.0860569014282922], {
             RGBColor[
             0.19456249333096626`, 0.3218278948383802, 0.9343914182145591]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.0860569014282922], {
             RGBColor[
             0.25742088082667425`, 0.38789604554832535`, 0.9379711103917886]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.0860569014282922], {
             RGBColor[
             0.18024025860905457`, 0.30677431806352135`, 0.9335757881349936]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.0860569014282922], {
             RGBColor[
             0.19227972218525266`, 0.31942855762818506`, 0.9342614177748679]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.0860569014282922], {
             RGBColor[
             0.4032230834287326, 0.5236733011096846, 0.9469139962132742]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.0860569014282922], {
             RGBColor[
             0.5466494280863021, 0.6428336578533808, 0.9574533919032397]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.0860569014282922], {
             RGBColor[
             0.28151321698943976`, 0.41321861839773133`, 0.9393431332948408]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.0860569014282922], {
             RGBColor[
             0.9860284094714858, 0.9884904025100302, 0.8812089425821105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.0860569014282922], {
             RGBColor[
             0.18695890108123892`, 0.31383603728832365`, 0.9339584048844437]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.0860569014282922], {
             RGBColor[
             0.2996969855238355, 0.4323309120448956, 0.9403786720123997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.0860569014282922], {
             RGBColor[
             0.2157216182949494, 0.34406747674153443`, 0.9355963990791376]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.0860569014282922], {
             RGBColor[
             0.2192972622992264, 0.34782570529895346`, 0.9358000267154899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.0860569014282922], {
             RGBColor[
             0.3231603966004548, 0.4543270258466754, 0.9418124726052306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.0860569014282922], {
             RGBColor[
             0.6325346241150686, 0.7125591290735227, 0.9642145891424635]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.0860569014282922], {
             RGBColor[
             0.6344197195047021, 0.7140895344334067, 0.9643629907568674]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.0860569014282922], {
             RGBColor[
             0.1902491888261562, 0.31729433832452386`, 0.9341457819039722]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.0860569014282922], {
             RGBColor[
             0.8434965379903663, 0.8780452595626765, 0.9849346468634116]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.0860569014282922], {
             RGBColor[
             0.22184597588427246`, 0.3505045648746116, 0.9359451721836745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.0860569014282922], {
             RGBColor[
             0.9243202823709581, 0.9424919194296639, 0.9926436877546408]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.0860569014282922], {
             RGBColor[
             0.24782292745212858`, 0.377807988006286, 0.9374245211460078]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.0860569014282922], {
             RGBColor[
             0.5581381343170947, 0.6521607071318558, 0.9583578249422453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.0860569014282922], {
             RGBColor[
             0.9525439023720605, 0.8495594172519633, 0.28067391379202367`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.0860569014282922], {
             RGBColor[
             0.4420343431064375, 0.5572896635318818, 0.9493870153604882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.0860569014282922], {
             RGBColor[
             0.36751400675687457`, 0.4927438936869005, 0.9446386454240401]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.0860569014282922], {
             RGBColor[
             0.19842878437042233`, 0.3258916118578589, 0.934611597769591]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.0860569014282922], {
             RGBColor[
             0.9159682611686081, 0.7045491879901851, 0.25124429433908335`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.0860569014282922], {
             RGBColor[
             0.25866502514756723`, 0.3892037201128899, 0.9380419625703169]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.0860569014282922], {
             RGBColor[
             0.29666018860098814`, 0.42913904593493735`, 0.940205730920182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.0860569014282922], {
             RGBColor[
             0.30363758949702413`, 0.4364727366694393, 0.9406030835790716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[401, 0.0860569014282922], {
             RGBColor[
             0.18668189134142482`, 0.3135448824883471, 0.9339426295895605]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[402, 0.0860569014282922], {
             RGBColor[
             0.35222766772351993`, 0.4795036351299483, 0.9436646134180137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[403, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[404, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[405, 0.0860569014282922], {
             RGBColor[
             0.19069604752509664`, 0.31776401514958813`, 0.9341712298458087]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[406, 0.0860569014282922], {
             RGBColor[
             0.9938422671704169, 0.9892375570568399, 0.5711469665009675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[407, 0.0860569014282922], {
             RGBColor[
             0.6882645660939893, 0.7563967771278489, 0.9695634378163434]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[408, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[409, 0.0860569014282922], {
             RGBColor[
             0.5413266543134985, 0.638512390316393, 0.9570343636538818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[410, 0.0860569014282922], {
             RGBColor[
             0.19323299612210112`, 0.3204305089768713, 0.934315705315329]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[411, 0.0860569014282922], {
             RGBColor[
             0.7123092841021239, 0.7751806935824288, 0.9719599905967291]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[412, 0.0860569014282922], {
             RGBColor[
             0.2277251794483852, 0.35668398058352985`, 0.9362799841291484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[413, 0.0860569014282922], {
             RGBColor[
             0.4106589580798899, 0.5301138819945902, 0.9473878035707602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[414, 0.0860569014282922], {
             RGBColor[
             0.9933318523271546, 0.9881458313179586, 0.5155914607271469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[415, 0.0860569014282922], {
             RGBColor[
             0.1852681323985655, 0.3120589322019077, 0.9338621181092336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[416, 0.0860569014282922], {
             RGBColor[
             0.30953300584952725`, 0.44252366491079637`, 0.94094414731681]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[417, 0.0860569014282922], {
             RGBColor[
             0.25734139130129635`, 0.3878124970172262, 0.9379665835809126]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[418, 0.0860569014282922], {
             RGBColor[
             0.94854690985372, 0.8337126738355427, 0.27745783979029415`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[419, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[420, 0.0860569014282922], {
             RGBColor[
             0.21820107858971777`, 0.3466735467181985, 0.9357376006748919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[421, 0.0860569014282922], {
             RGBColor[
             0.2022293934039294, 0.3298862929246055, 0.934828036831552]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[422, 0.0860569014282922], {
             RGBColor[
             0.29787052949847936`, 0.4304111909582458, 0.9402746580437552]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[423, 0.0860569014282922], {
             RGBColor[
             0.18010256657334342`, 0.3066295950038096, 0.9335679467772571]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[424, 0.0860569014282922], {
             RGBColor[
             0.2415788936308724, 0.37124511256553566`, 0.9370689326571076]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[425, 0.0860569014282922], {
             RGBColor[
             0.21231746253184797`, 0.34048949319857336`, 0.9354025374444261]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[426, 0.0860569014282922], {
             RGBColor[
             0.21523898041579886`, 0.3435601937295382, 0.9355689135659188]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[427, 0.0860569014282922], {
             RGBColor[
             0.2116086394211203, 0.33974447516721756`, 0.93536217101688]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[428, 0.0860569014282922], {
             RGBColor[
             0.2170356376005423, 0.34544859434534847`, 0.9356712305346737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[429, 0.0860569014282922], {
             RGBColor[
             0.23501975925948257`, 0.36435104646806615`, 0.9366953996580266]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[430, 0.0860569014282922], {
             RGBColor[
             0.2764022607353688, 0.40784667932135976`, 0.9390520718971536]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[431, 0.0860569014282922], {
             RGBColor[
             0.9934489814254173, 0.9883963586155741, 0.5283402402360341]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[432, 0.0860569014282922], {
             RGBColor[
             0.7713866596486274, 0.8213323883640413, 0.9778482712817413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[433, 0.0860569014282922], {
             RGBColor[
             0.18644975521125867`, 0.31330089269726175`, 0.9339294097803622]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[434, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[435, 0.0860569014282922], {
             RGBColor[
             0.4494598255363201, 0.5637212431970474, 0.949860160534824]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[436, 0.0860569014282922], {
             RGBColor[
             0.9696998197036082, 0.9769227556637184, 0.9361744810758174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[437, 0.0860569014282922], {
             RGBColor[
             0.19181759620694716`, 0.3189428339245066, 0.9342351003840575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[438, 0.0860569014282922], {
             RGBColor[
             0.28107859249471434`, 0.41276180049699024`, 0.9393183820728355]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[439, 0.0860569014282922], {
             RGBColor[
             0.2663834741236062, 0.397316299364637, 0.9384815168210803]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[440, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[441, 0.0860569014282922], {
             RGBColor[
             0.3682418148538177, 0.4933742844797741, 0.9446850207124019]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[442, 0.0860569014282922], {
             RGBColor[
             0.44708899097258314`, 0.5616677454595485, 0.9497090930528694]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[443, 0.0860569014282922], {
             RGBColor[
             0.7513693824412065, 0.8056947392726626, 0.9758531361617966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[444, 0.0860569014282922], {
             RGBColor[
             0.8510308907134999, 0.3932513646686672, 0.19650054461938235`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[445, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[446, 0.0860569014282922], {
             RGBColor[
             0.1982250439704274, 0.32567746777957673`, 0.9345999950552182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[447, 0.0860569014282922], {
             RGBColor[
             0.4270628245166249, 0.5443220866197901, 0.9484330434347394]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[448, 0.0860569014282922], {
             RGBColor[
             0.8242283061574975, 0.8626812945213669, 0.9830968257102389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[449, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[450, 0.0860569014282922], {
             RGBColor[
             0.33974255441645423`, 0.4686896575034088, 0.9428690730382396]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[451, 0.0860569014282922], {
             RGBColor[
             0.2916100124153255, 0.4238309905641419, 0.9399181308574747]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[452, 0.0860569014282922], {
             RGBColor[
             0.3938614602073101, 0.5155647336041528, 0.9463174818597636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[453, 0.0860569014282922], {
             RGBColor[
             0.45788186350371485`, 0.5707681499920235, 0.9504652840529954]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[454, 0.0860569014282922], {
             RGBColor[
             0.3199106986804724, 0.45151230084295324`, 0.9416054047273643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[455, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[456, 0.0860569014282922], {
             RGBColor[
             0.25079540388990307`, 0.3809322492082784, 0.9375937992817542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[457, 0.0860569014282922], {
             RGBColor[
             0.9567649542169475, 0.8658201798815686, 0.2865404406964947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[458, 0.0860569014282922], {
             RGBColor[
             0.45245153773684854`, 0.5663125139373179, 0.9500507897907745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[459, 0.0860569014282922], {
             RGBColor[
             0.24592141072655926`, 0.37580937336458886`, 0.9373162325815285]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[460, 0.0860569014282922], {
             RGBColor[
             0.8245721358999006, 0.8629554550249494, 0.9831296204980098]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[461, 0.0860569014282922], {
             RGBColor[
             0.5415651525659718, 0.6387060139419746, 0.9570531391099645]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[462, 0.0860569014282922], {
             RGBColor[
             0.22691262429331643`, 0.35582993359658016`, 0.9362337103151348]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[463, 0.0860569014282922], {
             RGBColor[
             0.861357971174354, 0.4633407524188015, 0.20602603153182808`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[464, 0.0860569014282922], {
             RGBColor[
             0.2802695819329819, 0.41191147910237724`, 0.9392723101181687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[465, 0.0860569014282922], {
             RGBColor[
             0.1794538714957133, 0.3059477753475769, 0.9335310045522444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[466, 0.0860569014282922], {
             RGBColor[
             0.2476714334157858, 0.37764875816881305`, 0.9374158937847534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[467, 0.0860569014282922], {
             RGBColor[
             0.23156344686445007`, 0.3607182429980241, 0.9364985677802855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[468, 0.0860569014282922], {
             RGBColor[
             0.36840454856349925`, 0.4935152362398662, 0.9446953899604831]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[469, 0.0860569014282922], {
             RGBColor[
             0.1893750053770723, 0.3163755160931047, 0.9340959984497854]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[470, 0.0860569014282922], {
             RGBColor[
             0.24649818947394458`, 0.37641560439797556`, 0.9373490792779244]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[471, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[472, 0.0860569014282922], {
             RGBColor[
             0.19705660398054506`, 0.3244493632668362, 0.9345334541263465]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[473, 0.0860569014282922], {
             RGBColor[
             0.6063118000163332, 0.691270259145406, 0.9621502323720413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[474, 0.0860569014282922], {
             RGBColor[
             0.4068383352175211, 0.5268046505012949, 0.9471443568604142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[475, 0.0860569014282922], {
             RGBColor[
             0.94225898230895, 0.9564574240650298, 0.9826246610683506]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[476, 0.0860569014282922], {
             RGBColor[
             0.19832380395462978`, 0.32578127078471814`, 0.9346056192902162]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[477, 0.0860569014282922], {
             RGBColor[
             0.26019557655375813`, 0.3908124266833606, 0.9381291252086515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[478, 0.0860569014282922], {
             RGBColor[
             0.5167389750172862, 0.6185510046013983, 0.955098731472047]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[479, 0.0860569014282922], {
             RGBColor[
             0.1935343324702769, 0.320747232584632, 0.9343328659745704]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[480, 0.0860569014282922], {
             RGBColor[
             0.47940132385552714`, 0.5882386173462659, 0.9521593748002706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[481, 0.0860569014282922], {
             RGBColor[
             0.2923941296611816, 0.4246551475054415, 0.9399627851746286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[482, 0.0860569014282922], {
             RGBColor[
             0.9362533521083286, 0.9519784348947232, 0.9927906264787851]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[483, 0.0860569014282922], {
             RGBColor[
             0.9714214766675533, 0.9152600716225856, 0.3434782627650753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[484, 0.0860569014282922], {
             RGBColor[
             0.20427604235269314`, 0.3320374507347944, 0.9349445904614383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[485, 0.0860569014282922], {
             RGBColor[
             0.5545695953076797, 0.6492636064031623, 0.9580768964794351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[486, 0.0860569014282922], {
             RGBColor[
             0.9941045402798871, 0.9897985327181177, 0.5996937759047933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[487, 0.0860569014282922], {
             RGBColor[
             0.2384268837263016, 0.3679321503068611, 0.936889430356023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[488, 0.0860569014282922], {
             RGBColor[
             0.19444137114962554`, 0.3217005877462013, 0.9343845204855159]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[489, 0.0860569014282922], {
             RGBColor[
             0.2336066799286998, 0.3628658104970091, 0.9366149268806021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[490, 0.0860569014282922], {
             RGBColor[
             0.34185985738752034`, 0.47052355891820463`, 0.9430039857112984]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[491, 0.0860569014282922], {
             RGBColor[
             0.1905565107603236, 0.3176173531626698, 0.9341632834334811]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[492, 0.0860569014282922], {
             RGBColor[
             0.19478601411047772`, 0.3220628293496827, 0.9344041473922828]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[493, 0.0860569014282922], {
             RGBColor[
             0.5894436674267205, 0.677575949208445, 0.9608223111845814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[494, 0.0860569014282922], {
             RGBColor[
             0.9693843335785163, 0.976687466628186, 0.9367085167936384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[495, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[496, 0.0860569014282922], {
             RGBColor[
             0.2085981516455076, 0.3365802616390992, 0.9351907281916764]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[497, 0.0860569014282922], {
             RGBColor[
             0.946570060984783, 0.8258751268160418, 0.27586722078774056`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[498, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[499, 0.0860569014282922], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[500, 0.0860569014282922], {
             RGBColor[
             0.27395775301500525`, 0.40527734671651633`, 0.938912860798804]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{
  3.834950276960332*^9, {3.8349573666066523`*^9, 3.83495737580899*^9}, 
   3.8349587938370156`*^9, 3.8350189212906833`*^9, 3.835019008666805*^9, 
   3.8350204886401753`*^9, 3.83502054312705*^9, 3.83505593496436*^9},
 CellLabel->
  "Out[504]=",ExpressionUUID->"a6c6db70-9088-4f17-b889-6e33ed4333c4"]
}, Open  ]],

Cell["Estimated with absolute Mean Deviation v Calculated: (r=3)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 
  3.8349503756793146`*^9}},ExpressionUUID->"bef87b09-a7be-4ef0-928a-\
b9fd268c267d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphin5", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsi5", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}], 
     "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"AMDi3500", ",", "kri5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502409842243`*^9}, {3.834957391671958*^9, 3.8349574025038147`*^9}, {
   3.8350188314314775`*^9, 3.835018832832349*^9}, 3.8350559521927605`*^9},
 CellLabel->"In[75]:=",ExpressionUUID->"a67fb919-4481-414b-988b-b845f970dccb"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1dOWGAgQBNBMbNu2bds2J+bEtm3btm3btu01sjdnH271F1R1ssCg6p0C
ggUL9l38vMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEIS
kZgkJCUZyUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpR
mCIUpRjFKUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGY
JjSlGYE0pwUtaUVr2tCWdrSnAx3pRBCd6UJXutGdHvSkF73pQ1/60Z8BDGQQ
gxnCUIYxnBGMZBSjGcNYxjGeCUxkEpOZwlSmMZ0ZzGQWs5nDXOYxnwUsZBGL
WcJSlrGcFaxkFatZw1rWsZ4NbGQTm9nCVraxnR3sZBe72cNe9rGfAxzkEIc5
wlGOcZwTnOQUpznDWc5xngtc5BKXucJVrnGdG9zkFre5w13ucZ8HPOQRj3nC
U57xnBe85BWvecNb3vGeD3zkE5/5wle+8Z1f+JXf+J0/+JO/+Jt/+Jcf/Cx/
AMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEISkZgkJCUZ
yUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpRmCIUpRjF
KUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGYJjSlGYE0
pwUtaUVr2tCWdrSnAx35Od5BdKYLXelGd3rQk170pg996Ud/BjCQQQxmCEMZ
xnBGMJJRjGYMYxnHeCYwkUlMZgpTmcZ0ZjCTWcxmDnOZx3wWsJBFLGYJS1nG
clawklWsZg1rWcd6NrCRTWxmC1vZxnZ2sJNd7GYPe9nHfg5wkEMc5ghHOcZx
TnCSU5zmDGc5x3kucJFLXOYKV7nGdW5wk1vc5g53ucd9HvCQRzzmCU95xnNe
8JJXvOYNb3nHez7wkU985gtf+Rbw/z//Dz189+A=
          "], {Null, CompressedData["
1:eJxF3Al0ldW5gOF/21YsVqt2QFCqdkClVEWUGRVRJmWoghGKIgREKWUqk4DM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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[13, 59] -> 
             RGBColor[
              0.9392387365664682, 0.785305730084084, 0.3140576031734424], 
             UndirectedEdge[210, 309] -> 
             RGBColor[
              0.8608633864817239, 0.8889761088634522, 0.8270539408663962], 
             UndirectedEdge[88, 427] -> 
             RGBColor[
              0.9603502555782448, 0.8674214006785717, 0.4782752179830251], 
             UndirectedEdge[293, 483] -> 
             RGBColor[
              0.9935428988788235, 0.9913952549366757, 0.7419488292586851], 
             UndirectedEdge[46, 150] -> 
             RGBColor[
              0.8992832841214033, 0.6270635154136042, 0.2372328069126143], 
             UndirectedEdge[400, 444] -> 
             RGBColor[
              0.9133353455258018, 0.9293968368660809, 0.7782341171454648], 
             UndirectedEdge[98, 105] -> 
             RGBColor[
              0.9502504031368864, 0.8862025617305563, 0.6121394057222457], 
             UndirectedEdge[128, 439] -> 
             RGBColor[
              0.9929722520354481, 0.9873766826551652, 0.4764511881706561], 
             UndirectedEdge[23, 62] -> 
             RGBColor[
              0.9815915230367982, 0.9845204495050018, 0.8591216218067445], 
             UndirectedEdge[201, 236] -> 
             RGBColor[
              0.993709903214347, 0.9889544439388551, 0.5567399667384061], 
             UndirectedEdge[40, 477] -> 
             RGBColor[
              0.8858538295654089, 0.9118198141065648, 0.9889747231466397], 
             UndirectedEdge[455, 482] -> 
             RGBColor[
              0.9601063806368788, 0.9559962654602856, 0.6947727460921964], 
             UndirectedEdge[60, 131] -> 
             RGBColor[
              0.8533352167560632, 0.8855058483461449, 0.9462512167494157], 
             UndirectedEdge[179, 222] -> 
             RGBColor[
              0.8981484333103995, 0.9184453100129377, 0.8564912482043515], 
             UndirectedEdge[111, 175] -> 
             RGBColor[
              0.9364000544463222, 0.9499576772110798, 0.9106719904930326], 
             UndirectedEdge[51, 110] -> 
             RGBColor[
              0.9673484045718895, 0.9714610746320169, 0.7096228329103884], 
             UndirectedEdge[84, 261] -> 
             RGBColor[
              0.9751071125760631, 0.9619908211102829, 0.6586839152206512], 
             UndirectedEdge[156, 479] -> 
             RGBColor[
              0.9683920872411056, 0.9010394027490376, 0.38208851092195817`], 
             UndirectedEdge[158, 437] -> 
             RGBColor[
              0.9498455757444334, 0.958693611363393, 0.7966733091178098], 
             UndirectedEdge[103, 355] -> 
             RGBColor[
              0.8440943485433072, 0.8786140239636046, 0.9618935962291815], 
             UndirectedEdge[13, 228] -> 
             RGBColor[
              0.9312938132278401, 0.7585056381061797, 0.2831930762757523], 
             UndirectedEdge[59, 409] -> 
             RGBColor[
              0.9554618641260045, 0.8526326229996435, 0.32726669235105593`], 
             UndirectedEdge[243, 430] -> 
             RGBColor[
              0.9815397683483524, 0.948267541455931, 0.47835458986248697`], 
             UndirectedEdge[333, 441] -> 
             RGBColor[
              0.9653236997938599, 0.8873664731605424, 0.46884292992821974`], 
             UndirectedEdge[179, 385] -> 
             RGBColor[
              0.8932801040085188, 0.9164321307362537, 0.9371720635688845], 
             UndirectedEdge[81, 447] -> 
             RGBColor[
              0.6260371514803211, 0.6934537742494662, 0.9259213741370935], 
             UndirectedEdge[69, 404] -> 
             RGBColor[
              0.9751982553226612, 0.9306134981087384, 0.5339098387818486], 
             UndirectedEdge[113, 380] -> 
             RGBColor[
              0.9904883702460019, 0.9900424558851384, 0.7860519957199927], 
             UndirectedEdge[85, 489] -> 
             RGBColor[
              0.9597133792012329, 0.8666401062156361, 0.3745794247738353], 
             UndirectedEdge[277, 498] -> 
             RGBColor[
              0.982596866561481, 0.9555034630955119, 0.5621869541976099], 
             UndirectedEdge[18, 160] -> 
             RGBColor[
              0.8394702557622507, 0.8727243033374312, 0.8560310849507212], 
             UndirectedEdge[355, 431] -> 
             RGBColor[
              0.8606179833879211, 0.8884512164598666, 0.8003433285582922], 
             UndirectedEdge[357, 492] -> 
             RGBColor[
              0.9274348943423032, 0.7267764054037946, 0.3327996742035863], 
             UndirectedEdge[165, 386] -> 
             RGBColor[
              0.868347342918248, 0.8965219495687837, 0.9150747642904747], 
             UndirectedEdge[218, 274] -> 
             RGBColor[
              0.9940660171973914, 0.9897161357399407, 0.5955007761120495], 
             UndirectedEdge[116, 441] -> 
             RGBColor[
              0.7750834785791074, 0.8205681323677618, 0.8142763971464249], 
             UndirectedEdge[258, 435] -> 
             RGBColor[
              0.9557179377997864, 0.848906480750917, 0.4833841184526442], 
             UndirectedEdge[112, 445] -> 
             RGBColor[
              0.9944664537475343, 0.9905726290303506, 0.6390858233871715], 
             UndirectedEdge[114, 179] -> 
             RGBColor[
              0.8857278999271943, 0.9109814190429582, 0.9580933087822243], 
             UndirectedEdge[155, 467] -> 
             RGBColor[
              0.9608676145546942, 0.8768827744154477, 0.5312748027739345], 
             UndirectedEdge[243, 421] -> 
             RGBColor[
              0.970938786999407, 0.9136318460310049, 0.34160310455262266`], 
             UndirectedEdge[172, 289] -> 
             RGBColor[
              0.9815292594124929, 0.9632116963813484, 0.6362105027286704], 
             UndirectedEdge[381, 468] -> 
             RGBColor[
              0.5598208460199744, 0.630349847455476, 0.9593698708391805], 
             UndirectedEdge[17, 277] -> 
             RGBColor[
              0.9908927007980083, 0.9905019119801322, 0.800595046919211], 
             UndirectedEdge[279, 477] -> 
             RGBColor[
              0.8594641234477801, 0.8907773787778575, 0.9864576494187716], 
             UndirectedEdge[4, 405] -> 
             RGBColor[
              0.9884852748178055, 0.9848001401022062, 0.6502676448175031], 
             UndirectedEdge[36, 379] -> 
             RGBColor[
              0.9711557856423809, 0.9360256720109683, 0.6165090800092765], 
             UndirectedEdge[278, 401] -> 
             RGBColor[
              0.9832075518635394, 0.9550172707607042, 0.38926493928793837`], 
             UndirectedEdge[152, 399] -> 
             RGBColor[
              0.9806264400071044, 0.9460167489206739, 0.40422260458576553`], 
             UndirectedEdge[173, 406] -> 
             RGBColor[
              0.6305424047206638, 0.6954718570142995, 0.8582008903086606], 
             UndirectedEdge[239, 332] -> 
             RGBColor[
              0.9446239838484053, 0.9572889034745653, 0.9450526086780204], 
             UndirectedEdge[116, 361] -> 
             RGBColor[
              0.7685878425147328, 0.8000462195583207, 0.6708981356987852], 
             UndirectedEdge[288, 498] -> 
             RGBColor[
              0.9738373461641832, 0.950334684333643, 0.6380998060895707], 
             UndirectedEdge[16, 386] -> 
             RGBColor[
              0.682941824451877, 0.7455974616439464, 0.8999246857936022], 
             UndirectedEdge[216, 464] -> 
             RGBColor[
              0.7367575869090933, 0.7943250517453083, 0.9743847853413928], 
             UndirectedEdge[379, 400] -> 
             RGBColor[
              0.9863725791649787, 0.9865209679981968, 0.7465851457242993], 
             UndirectedEdge[22, 24] -> 
             RGBColor[
              0.6428786799326573, 0.6528865132054431, 0.6107479900751512], 
             UndirectedEdge[231, 355] -> 
             RGBColor[
              0.8445244062913274, 0.8789347603279231, 0.961165620638808], 
             UndirectedEdge[434, 495] -> 
             RGBColor[
              0.9590387362238897, 0.8683128715632094, 0.5233487808118442], 
             UndirectedEdge[75, 323] -> 
             RGBColor[
              0.9161029066154934, 0.7002851117436042, 0.2511044428007564], 
             UndirectedEdge[165, 288] -> 
             RGBColor[
              0.8619698482573309, 0.8923381996641775, 0.9515112852456045], 
             UndirectedEdge[90, 229] -> 
             RGBColor[
              0.9767702963422751, 0.9333028963480063, 0.3642574171615298], 
             UndirectedEdge[267, 424] -> 
             RGBColor[
              0.9872896848327313, 0.9671860668791005, 0.5412774831340429], 
             UndirectedEdge[258, 403] -> 
             RGBColor[
              0.9539779913050169, 0.8482866074956906, 0.5194622625124445], 
             UndirectedEdge[274, 305] -> 
             RGBColor[
              0.9884906135007661, 0.9717103818107722, 0.5056968024292154], 
             UndirectedEdge[399, 478] -> 
             RGBColor[
              0.978526502646055, 0.9471350632628164, 0.5834355665098863], 
             UndirectedEdge[359, 463] -> 
             RGBColor[
              0.5747563755550478, 0.6414887409280485, 0.9340879151462755], 
             UndirectedEdge[302, 422] -> 
             RGBColor[
              0.9909141839177678, 0.9846769790323722, 0.6022205622300556], 
             UndirectedEdge[21, 335] -> 
             RGBColor[
              0.9515397579089316, 0.9610018751344538, 0.867485809892006], 
             UndirectedEdge[266, 445] -> 
             RGBColor[
              0.9160002525522213, 0.9317437273964151, 0.7964815820759051], 
             UndirectedEdge[200, 452] -> 
             RGBColor[
              0.9713426116098536, 0.9141210398451372, 0.5187026103830852], 
             UndirectedEdge[112, 471] -> 
             RGBColor[
              0.9943343786637633, 0.9902901337810035, 0.6247102655916166], 
             UndirectedEdge[481, 496] -> 
             RGBColor[
              0.8933327963767697, 0.913213435789713, 0.7399413013406793], 
             UndirectedEdge[6, 422] -> 
             RGBColor[
              0.9840832156419341, 0.9579710903008624, 0.3926667277117729], 
             UndirectedEdge[137, 424] -> 
             RGBColor[
              0.93450098441864, 0.766833991140369, 0.30215839657366095`], 
             UndirectedEdge[89, 482] -> 
             RGBColor[
              0.9898238603287832, 0.9759524701572224, 0.5325822152711157], 
             UndirectedEdge[142, 254] -> 
             RGBColor[
              0.924696788401473, 0.7391548898592186, 0.25826747223551333`], 
             UndirectedEdge[178, 321] -> 
             RGBColor[
              0.9916155199510335, 0.9908008162755131, 0.7886160629575796], 
             UndirectedEdge[151, 456] -> 
             RGBColor[
              0.9936179389821218, 0.9887577417451359, 0.5467302275981534], 
             UndirectedEdge[346, 431] -> 
             RGBColor[
              0.9863734782580253, 0.9868718355971104, 0.7743702623966813], 
             UndirectedEdge[65, 297] -> 
             RGBColor[
              0.9939852997896008, 0.9917551762670722, 0.7474814743249156], 
             UndirectedEdge[79, 253] -> 
             RGBColor[
              0.9653165445931126, 0.8898891911907448, 0.34464311316705154`], 
             UndirectedEdge[376, 475] -> 
             RGBColor[
              0.9623530650400152, 0.8846701898385929, 0.30824919601793066`], 
             UndirectedEdge[209, 259] -> 
             RGBColor[
              0.9817046100759494, 0.9499474952036498, 0.38342629424989283`], 
             UndirectedEdge[464, 496] -> 
             RGBColor[
              0.8095247974438824, 0.8511713496663689, 0.9816375408392558], 
             UndirectedEdge[101, 103] -> 
             RGBColor[
              0.977408835632833, 0.9795933003133612, 0.7425153074717711], 
             UndirectedEdge[69, 348] -> 
             RGBColor[
              0.9896286127342009, 0.9899791790801664, 0.8215442574915428], 
             UndirectedEdge[116, 277] -> 
             RGBColor[
              0.7739075933555172, 0.8205371655355613, 0.8668587751545065], 
             UndirectedEdge[171, 471] -> 
             RGBColor[
              0.9589490564596197, 0.9658127556553187, 0.7862151169772829], 
             UndirectedEdge[133, 429] -> 
             RGBColor[
              0.944843246404796, 0.8139681115194559, 0.527588441543214], 
             UndirectedEdge[37, 203] -> 
             RGBColor[
              0.9613416354418167, 0.8786008485781167, 0.5308670953942907], 
             UndirectedEdge[299, 399] -> 
             RGBColor[
              0.9812991629138326, 0.9474556351954462, 0.4774443414185895], 
             UndirectedEdge[311, 429] -> 
             RGBColor[
              0.9592968725931798, 0.9680357266261229, 0.9050721749084948], 
             UndirectedEdge[327, 446] -> 
             RGBColor[
              0.9167702015754176, 0.9358972354599704, 0.9720068567036368], 
             UndirectedEdge[15, 249] -> 
             RGBColor[
              0.956400187774908, 0.9190844752340988, 0.6288844007270398], 
             UndirectedEdge[50, 242] -> 
             RGBColor[
              0.7161153301032923, 0.773414530705026, 0.8683650015909435], 
             UndirectedEdge[163, 355] -> 
             RGBColor[
              0.8083659173859232, 0.8507855971946705, 0.9813841556905634], 
             UndirectedEdge[192, 435] -> 
             RGBColor[
              0.9947700749427124, 0.9912220440660247, 0.6721331167494811], 
             UndirectedEdge[31, 191] -> 
             RGBColor[
              0.964651298732267, 0.9730886032073534, 0.9416315233295285], 
             UndirectedEdge[385, 415] -> 
             RGBColor[
              0.9856979205833596, 0.9883537368616129, 0.8866859987361893], 
             UndirectedEdge[207, 257] -> 
             RGBColor[
              0.9134496534360996, 0.9290257140363805, 0.7407720083560196], 
             UndirectedEdge[359, 408] -> 
             RGBColor[
              0.4564709853367192, 0.5487656704506338, 0.9538122052914921], 
             UndirectedEdge[183, 202] -> 
             RGBColor[
              0.8866393458610011, 0.9091032885845189, 0.8288865228237321], 
             UndirectedEdge[170, 223] -> 
             RGBColor[
              0.9915612985631092, 0.9907783943381803, 0.7895146516759395], 
             UndirectedEdge[40, 430] -> 
             RGBColor[
              0.9568646805366128, 0.964420459329651, 0.8078813702206633], 
             UndirectedEdge[69, 444] -> 
             RGBColor[
              0.9125862558119022, 0.9303179682566645, 0.8801218528571031], 
             UndirectedEdge[215, 417] -> 
             RGBColor[
              0.7860615536133626, 0.7653377230576248, 0.619525400525716], 
             UndirectedEdge[423, 429] -> 
             RGBColor[
              0.9886980169903079, 0.9895943538248468, 0.8369666372724359], 
             UndirectedEdge[5, 83] -> 
             RGBColor[
              0.9599836505934835, 0.963551525558523, 0.7060197842749871], 
             UndirectedEdge[311, 366] -> 
             RGBColor[
              0.8949824830755052, 0.9190987546248172, 0.9898454222676779], 
             UndirectedEdge[133, 366] -> 
             RGBColor[
              0.8805288568871215, 0.7650311395181502, 0.6123616889023972], 
             UndirectedEdge[76, 359] -> 
             RGBColor[
              0.564272680241169, 0.571677309269128, 0.6059104770581294], 
             UndirectedEdge[172, 218] -> 
             RGBColor[
              0.9892808236783404, 0.9885581508973027, 0.7344684492894908], 
             UndirectedEdge[177, 484] -> 
             RGBColor[
              0.7076274754010992, 0.7216600878634916, 0.6231615670106305], 
             UndirectedEdge[45, 328] -> 
             RGBColor[
              0.9806362513674156, 0.9819974160743944, 0.7368231737134958], 
             UndirectedEdge[115, 144] -> 
             RGBColor[
              0.9754668478163386, 0.9793500705508054, 0.8414222415439367], 
             UndirectedEdge[63, 72] -> 
             RGBColor[
              0.9943958766038382, 0.9904216716564282, 0.6314039368474826], 
             UndirectedEdge[248, 387] -> 
             RGBColor[
              0.7870331035590885, 0.7350269030546515, 0.612518232976407], 
             UndirectedEdge[34, 44] -> 
             RGBColor[
              0.8380789787786328, 0.7549395418643581, 0.6131849585733617], 
             UndirectedEdge[279, 285] -> 
             RGBColor[
              0.9211990806272894, 0.9132121600519787, 0.673760526121062], 
             UndirectedEdge[13, 77] -> 
             RGBColor[
              0.9439451496733521, 0.8001931463416045, 0.41638925456025033`], 
             UndirectedEdge[53, 445] -> 
             RGBColor[
              0.9747801972261496, 0.9781058879378741, 0.7844971667770826], 
             UndirectedEdge[91, 298] -> 
             RGBColor[
              0.8921099911591066, 0.914235982200786, 0.8789219612045986], 
             UndirectedEdge[6, 451] -> 
             RGBColor[
              0.5784562793133832, 0.6213981306953746, 0.6512397408268764], 
             UndirectedEdge[87, 256] -> 
             RGBColor[
              0.9646964089227478, 0.886354309967974, 0.38106526422933074`], 
             UndirectedEdge[153, 172] -> 
             RGBColor[
              0.9231624154869924, 0.9402091257700239, 0.9444426559834296], 
             UndirectedEdge[72, 438] -> 
             RGBColor[
              0.936921918207346, 0.9482205653255321, 0.7818161520463515], 
             UndirectedEdge[207, 440] -> 
             RGBColor[
              0.9129364598908537, 0.9306389311268408, 0.8819668666021595], 
             UndirectedEdge[19, 228] -> 
             RGBColor[
              0.8788849425966627, 0.8707452986222683, 0.6564510988862013], 
             UndirectedEdge[8, 63] -> 
             RGBColor[
              0.9685680955096592, 0.9739785916720265, 0.8351361021992447], 
             UndirectedEdge[72, 128] -> 
             RGBColor[
              0.9932252802716248, 0.987917884467268, 0.5039917501692175], 
             UndirectedEdge[229, 485] -> 
             RGBColor[
              0.9752278121622533, 0.9476011757962794, 0.6277420183885941], 
             UndirectedEdge[32, 407] -> 
             RGBColor[
              0.9492029391948652, 0.9598400994236855, 0.897726215316861], 
             UndirectedEdge[475, 478] -> 
             RGBColor[
              0.9745004221698573, 0.933554148447951, 0.5677950041213602], 
             UndirectedEdge[194, 412] -> 
             RGBColor[
              0.9741399387296641, 0.9729898233156111, 0.6852011071060025], 
             UndirectedEdge[370, 390] -> 
             RGBColor[
              0.9530979498761358, 0.8479226877488152, 0.5340468264632154], 
             UndirectedEdge[231, 233] -> 
             RGBColor[
              0.9743824174435289, 0.9688741699750418, 0.6756700111803403], 
             UndirectedEdge[114, 385] -> 
             RGBColor[
              0.9777335346744709, 0.9827325773900298, 0.9144381635246427], 
             UndirectedEdge[271, 442] -> 
             RGBColor[
              0.9771080066981197, 0.9336649362072146, 0.43165143395658234`], 
             UndirectedEdge[206, 254] -> 
             RGBColor[
              0.9493078206345816, 0.882073941093162, 0.611077162212169], 
             UndirectedEdge[262, 455] -> 
             RGBColor[
              0.9652033058496563, 0.9715881941008453, 0.8507275661771951], 
             UndirectedEdge[7, 341] -> 
             RGBColor[
              0.8466718526002868, 0.8806626791107329, 0.9639267168251731], 
             UndirectedEdge[187, 328] -> 
             RGBColor[
              0.9697831958439121, 0.9739032250352129, 0.7551945657845639], 
             UndirectedEdge[44, 56] -> 
             RGBColor[
              0.9501915111941358, 0.842139495648894, 0.5597958046919513], 
             UndirectedEdge[142, 388] -> 
             RGBColor[
              0.9526513945188759, 0.8373001679860737, 0.44828131640003455`], 
             UndirectedEdge[282, 419] -> 
             RGBColor[
              0.9938388978173485, 0.9892303503513202, 0.5707802332127038], 
             UndirectedEdge[7, 244] -> 
             RGBColor[
              0.8585410932240711, 0.8895147393338534, 0.9438351884428506], 
             UndirectedEdge[107, 470] -> 
             RGBColor[
              0.9658189267129976, 0.9181405806167529, 0.6015567124131457], 
             UndirectedEdge[10, 383] -> 
             RGBColor[
              0.9679534557489211, 0.9736020868772253, 0.8426743491658908], 
             UndirectedEdge[249, 419] -> 
             RGBColor[
              0.9745151482439447, 0.9785675469325228, 0.8372610069579032], 
             UndirectedEdge[191, 271] -> 
             RGBColor[
              0.9692288156998807, 0.9736704110273178, 0.7704661406238424], 
             UndirectedEdge[297, 490] -> 
             RGBColor[
              0.9652807524075472, 0.9717538444571259, 0.8591571460588707], 
             UndirectedEdge[32, 176] -> 
             RGBColor[
              0.9512346845464942, 0.9606802783400581, 0.8640549368519475], 
             UndirectedEdge[353, 487] -> 
             RGBColor[
              0.8888572126340172, 0.7840960460416673, 0.6157179999032489], 
             UndirectedEdge[281, 324] -> 
             RGBColor[
              0.9155386417632967, 0.934323616875737, 0.9513780304038908], 
             UndirectedEdge[19, 59] -> 
             RGBColor[
              0.8868298659352909, 0.8975453906001725, 0.6873156257838915], 
             UndirectedEdge[197, 411] -> 
             RGBColor[
              0.6976308981195423, 0.7616560138941271, 0.9669897437391672], 
             UndirectedEdge[163, 343] -> 
             RGBColor[
              0.9374190094689305, 0.9515339436371125, 0.9439351156991718], 
             UndirectedEdge[12, 396] -> 
             RGBColor[
              0.904634269066876, 0.8978483614916393, 0.6690095846888742], 
             UndirectedEdge[51, 397] -> 
             RGBColor[
              0.967980708978577, 0.9728135098221395, 0.7784452654478606], 
             UndirectedEdge[448, 482] -> 
             RGBColor[
              0.9742546450504257, 0.9665580701445396, 0.6711719427262226], 
             UndirectedEdge[183, 285] -> 
             RGBColor[
              0.8771078860570048, 0.878390794776928, 0.6694659691835577], 
             UndirectedEdge[155, 365] -> 
             RGBColor[
              0.9531987869222773, 0.8722886316303661, 0.5946474040489473], 
             UndirectedEdge[122, 217] -> 
             RGBColor[
              0.9617036817565081, 0.9411867757315475, 0.6584295376147464], 
             UndirectedEdge[249, 269] -> 
             RGBColor[
              0.9701441856656199, 0.9768888728841387, 0.9190638445298187], 
             UndirectedEdge[101, 331] -> 
             RGBColor[
              0.9932079822687523, 0.9878808857882202, 0.5021089693074458], 
             UndirectedEdge[246, 458] -> 
             RGBColor[
              0.9641413122620133, 0.9702233019131649, 0.8086284343394216], 
             UndirectedEdge[35, 437] -> 
             RGBColor[
              0.9384005773342559, 0.9210912314295714, 0.6668143241823539], 
             UndirectedEdge[354, 473] -> 
             RGBColor[
              0.9462607938224218, 0.8778347084246421, 0.6147090669547121], 
             UndirectedEdge[230, 484] -> 
             RGBColor[
              0.976273233563711, 0.9311058752983485, 0.4065699633335189], 
             UndirectedEdge[108, 190] -> 
             RGBColor[
              0.9798061382390042, 0.9431066650085193, 0.41319671710749595`], 
             UndirectedEdge[55, 136] -> 
             RGBColor[
              0.9692153865220603, 0.9759648454285998, 0.9102766034238408], 
             UndirectedEdge[59, 279] -> 
             RGBColor[
              0.9256587989527771, 0.9282558371555079, 0.691085689668443], 
             UndirectedEdge[24, 170] -> 
             RGBColor[
              0.9713173222026474, 0.9159562244810951, 0.528153218075148], 
             UndirectedEdge[184, 388] -> 
             RGBColor[
              0.9940981719095893, 0.9897849114179917, 0.599000618098898], 
             UndirectedEdge[173, 242] -> 
             RGBColor[
              0.6302510746423557, 0.6953513845400776, 0.8630289836442976], 
             UndirectedEdge[4, 345] -> 
             RGBColor[
              0.9925289033263527, 0.9864722844070031, 0.5832542558557466], 
             UndirectedEdge[59, 256] -> 
             RGBColor[0.96047293643393, 0.87249985485971, 0.3312987187549974],
              UndirectedEdge[232, 480] -> 
             RGBColor[
              0.9501373115073011, 0.8298976361988598, 0.500899195874946], 
             UndirectedEdge[3, 437] -> 
             RGBColor[
              0.9476429427604052, 0.9587763645356043, 0.9054007610626362], 
             UndirectedEdge[199, 448] -> 
             RGBColor[
              0.8077964511705654, 0.8502171977580681, 0.9562189301075168], 
             UndirectedEdge[151, 226] -> 
             RGBColor[
              0.9324800434765362, 0.7495390366426834, 0.343584496357633], 
             UndirectedEdge[241, 442] -> 
             RGBColor[
              0.907537130715252, 0.8825893687645501, 0.6434333130704232], 
             UndirectedEdge[303, 400] -> 
             RGBColor[
              0.9357198533976008, 0.763143465038285, 0.39605911062437665`], 
             UndirectedEdge[42, 378] -> 
             RGBColor[
              0.9896781963490179, 0.9768442739897987, 0.41440217123534295`], 
             UndirectedEdge[15, 499] -> 
             RGBColor[
              0.9247358977271057, 0.8943055225109454, 0.6421349034837205], 
             UndirectedEdge[341, 374] -> 
             RGBColor[
              0.9147212511527762, 0.7361433985748995, 0.5835310529549174], 
             UndirectedEdge[312, 334] -> 
             RGBColor[
              0.9863680680846111, 0.9690524554443428, 0.5825593874890587], 
             UndirectedEdge[7, 482] -> 
             RGBColor[
              0.8594592733723669, 0.8764378497800773, 0.6849885418253789], 
             UndirectedEdge[219, 403] -> 
             RGBColor[
              0.9918273957212359, 0.9908884323514506, 0.7851047331284087], 
             UndirectedEdge[50, 449] -> 
             RGBColor[
              0.5988194865142104, 0.6830832109094143, 0.9628579298331226], 
             UndirectedEdge[318, 430] -> 
             RGBColor[
              0.8393941243457503, 0.8718479827123802, 0.7963862498380538], 
             UndirectedEdge[242, 449] -> 
             RGBColor[
              0.8743907645417467, 0.9004988932691297, 0.8819308760902402], 
             UndirectedEdge[356, 365] -> 
             RGBColor[
              0.8819876279053673, 0.9079630689168329, 0.9528396882863186], 
             UndirectedEdge[154, 219] -> 
             RGBColor[
              0.9914259222759942, 0.9907224127644463, 0.7917581870960331], 
             UndirectedEdge[69, 275] -> 
             RGBColor[
              0.9726089369593487, 0.9209617711055174, 0.528628390716589], 
             UndirectedEdge[173, 310] -> 
             RGBColor[
              0.62604959990583, 0.6775732764319031, 0.6640903096262615], 
             UndirectedEdge[351, 460] -> 
             RGBColor[
              0.9625360866525121, 0.9708633612363932, 0.9162057887982322], 
             UndirectedEdge[97, 207] -> 
             RGBColor[
              0.8353657419654966, 0.8715619835170241, 0.9841591242801122], 
             UndirectedEdge[122, 212] -> 
             RGBColor[
              0.9387304280699327, 0.9232551340100519, 0.6696422416496282], 
             UndirectedEdge[45, 224] -> 
             RGBColor[
              0.928514372112596, 0.9450091591709102, 0.9643706440341306], 
             UndirectedEdge[144, 215] -> 
             RGBColor[
              0.8107266583852177, 0.8498252641010753, 0.8433416863512109], 
             UndirectedEdge[22, 214] -> 
             RGBColor[
              0.6649516099759709, 0.727780398365025, 0.7920354407776522], 
             UndirectedEdge[142, 150] -> 
             RGBColor[
              0.8878077809557794, 0.5815669693466466, 0.2279993477008741], 
             UndirectedEdge[149, 419] -> 
             RGBColor[
              0.9890063322785497, 0.9893750482583952, 0.812731212293424], 
             UndirectedEdge[11, 418] -> 
             RGBColor[
              0.962429205292586, 0.9579672330421033, 0.691674509875548], 
             UndirectedEdge[189, 346] -> 
             RGBColor[
              0.9798516888412363, 0.9844940030444014, 0.9189900146573377], 
             UndirectedEdge[185, 224] -> 
             RGBColor[
              0.9393772929848963, 0.9522296062977308, 0.9065250283288391], 
             UndirectedEdge[17, 386] -> 
             RGBColor[
              0.9885106750616273, 0.9895168831228696, 0.840071377856042], 
             UndirectedEdge[194, 476] -> 
             RGBColor[
              0.9913780625119362, 0.9823384958288639, 0.4413988916760967], 
             UndirectedEdge[258, 471] -> 
             RGBColor[
              0.9550956595630806, 0.847575490524584, 0.4156529726433391], 
             UndirectedEdge[203, 397] -> 
             RGBColor[
              0.9627478504775684, 0.8779628106962841, 0.41891450301032546`], 
             UndirectedEdge[126, 173] -> 
             RGBColor[
              0.6220480102344731, 0.690478679239932, 0.9326739497316471], 
             UndirectedEdge[30, 366] -> 
             RGBColor[
              0.9252175029171147, 0.9410022107494556, 0.907920410516089], 
             UndirectedEdge[95, 368] -> 
             RGBColor[
              0.9922636706546848, 0.9905402438598176, 0.7394509330822593], 
             UndirectedEdge[15, 242] -> 
             RGBColor[
              0.9752946749348739, 0.9319308261171501, 0.5411416446900582], 
             UndirectedEdge[150, 392] -> 
             RGBColor[
              0.8563988508626363, 0.6804429118965487, 0.5971588220582656], 
             UndirectedEdge[179, 296] -> 
             RGBColor[
              0.7978435623755142, 0.8420007218541934, 0.9804852480917444], 
             UndirectedEdge[3, 123] -> 
             RGBColor[
              0.9739250320215074, 0.9302136160072546, 0.5558856950323805], 
             UndirectedEdge[37, 257] -> 
             RGBColor[
              0.992110961114899, 0.9891802581191367, 0.6477154076125999], 
             UndirectedEdge[17, 178] -> 
             RGBColor[
              0.9902688417202183, 0.9902439302190191, 0.8109340063337309], 
             UndirectedEdge[68, 367] -> 
             RGBColor[
              0.8051727511389221, 0.8443871913266184, 0.7667506129364747], 
             UndirectedEdge[1, 363] -> 
             RGBColor[
              0.9015581799543335, 0.9195341082011574, 0.7323463793616469], 
             UndirectedEdge[227, 329] -> 
             RGBColor[
              0.9392288470349074, 0.9537818252288615, 0.9733403074100001], 
             UndirectedEdge[121, 420] -> 
             RGBColor[
              0.7375971876029415, 0.7896547130612005, 0.7719551522265649], 
             UndirectedEdge[82, 149] -> 
             RGBColor[
              0.6631627506668747, 0.7293247381647878, 0.9284844460073448], 
             UndirectedEdge[129, 355] -> 
             RGBColor[
              0.7129153726440876, 0.7756541745578542, 0.9720203998383725], 
             UndirectedEdge[87, 388] -> 
             RGBColor[
              0.9938505109493042, 0.989255189666306, 0.5720442509581445], 
             UndirectedEdge[91, 228] -> 
             RGBColor[
              0.8803812175162085, 0.8719141999615281, 0.6566002335866976], 
             UndirectedEdge[12, 161] -> 
             RGBColor[
              0.9663858043398335, 0.946494925403191, 0.6543594386025344], 
             UndirectedEdge[64, 115] -> 
             RGBColor[
              0.9657174907294519, 0.9481506003541635, 0.6600634704044648], 
             UndirectedEdge[56, 342] -> 
             RGBColor[
              0.8567859319572655, 0.887663740324798, 0.9217965892824875], 
             UndirectedEdge[378, 416] -> 
             RGBColor[
              0.9926370002207396, 0.98650839489912, 0.4528195862775355], 
             UndirectedEdge[119, 363] -> 
             RGBColor[
              0.8744395813694296, 0.9027185799159712, 0.9850966822575996], 
             UndirectedEdge[391, 455] -> 
             RGBColor[
              0.8792832492005307, 0.9065806116772637, 0.9883480153258113], 
             UndirectedEdge[249, 282] -> 
             RGBColor[
              0.9732213833843004, 0.9758003147174363, 0.6964426861768249], 
             UndirectedEdge[226, 429] -> 
             RGBColor[
              0.930962153192761, 0.7509373092552929, 0.5160057171103617], 
             UndirectedEdge[181, 189] -> 
             RGBColor[
              0.979988942101067, 0.9845963663008515, 0.9187576806898274], 
             UndirectedEdge[160, 167] -> 
             RGBColor[
              0.9651345874236454, 0.8877435622621184, 0.5050719280695807], 
             UndirectedEdge[16, 277] -> 
             RGBColor[
              0.685323850188258, 0.7465824905012091, 0.8604483548567712], 
             UndirectedEdge[295, 341] -> 
             RGBColor[
              0.9516666740972219, 0.9634736651970415, 0.966699892789793], 
             UndirectedEdge[69, 129] -> 
             RGBColor[
              0.8456548582721708, 0.877926939467178, 0.8734782787243922], 
             UndirectedEdge[352, 368] -> 
             RGBColor[
              0.9916445037616086, 0.9892159084829034, 0.6720584378260548], 
             UndirectedEdge[194, 297] -> 
             RGBColor[
              0.9925584268506809, 0.9848631757962979, 0.5698742655841579], 
             UndirectedEdge[188, 228] -> 
             RGBColor[
              0.9809213504297777, 0.9469734438288868, 0.4086086367486075], 
             UndirectedEdge[273, 430] -> 
             RGBColor[
              0.9939254533301065, 0.989415483841005, 0.5802012666177107], 
             UndirectedEdge[200, 468] -> 
             RGBColor[
              0.5641150516591029, 0.5710523644678476, 0.6057836454009806], 
             UndirectedEdge[93, 172] -> 
             RGBColor[
              0.9552991245781561, 0.8658228783516961, 0.5807065541161782], 
             UndirectedEdge[61, 341] -> 
             RGBColor[
              0.9497173404186532, 0.8847175417449633, 0.6121980327278185], 
             UndirectedEdge[121, 442] -> 
             RGBColor[
              0.7208089501496209, 0.7339666409070762, 0.6265845584050994], 
             UndirectedEdge[287, 336] -> 
             RGBColor[
              0.9836853848639946, 0.955441196832879, 0.492133103648548], 
             UndirectedEdge[403, 497] -> 
             RGBColor[
              0.9849546347512743, 0.9645161388442954, 0.5786687644464311], 
             UndirectedEdge[17, 407] -> 
             RGBColor[
              0.9900233224483883, 0.9901424016905599, 0.8150028960514617], 
             UndirectedEdge[135, 470] -> 
             RGBColor[
              0.970062220172232, 0.9208864113333484, 0.5756187291765259], 
             UndirectedEdge[322, 471] -> 
             RGBColor[
              0.9939738124001369, 0.9895189190019482, 0.5854648529529451], 
             UndirectedEdge[24, 52] -> 
             RGBColor[
              0.9724830359029119, 0.9158702014126971, 0.46754122310692386`], 
             UndirectedEdge[163, 440] -> 
             RGBColor[
              0.9409967148476166, 0.9530134167540336, 0.8846432787696209], 
             UndirectedEdge[274, 432] -> 
             RGBColor[
              0.9501929972484039, 0.827765072116107, 0.43378009200464884`], 
             UndirectedEdge[89, 261] -> 
             RGBColor[
              0.982007660874582, 0.9838848282071243, 0.8031054092819132], 
             UndirectedEdge[255, 312] -> 
             RGBColor[
              0.9920728485357264, 0.990989933398092, 0.7810369447807786], 
             UndirectedEdge[370, 422] -> 
             RGBColor[
              0.9532251235681535, 0.8421414605688078, 0.3339207754733104], 
             UndirectedEdge[43, 90] -> 
             RGBColor[
              0.938494381438708, 0.7825517459375457, 0.3118010653319602], 
             UndirectedEdge[373, 449] -> 
             RGBColor[
              0.8736676821838837, 0.8944542194195549, 0.6965050996240262], 
             UndirectedEdge[49, 457] -> 
             RGBColor[
              0.8305974764076187, 0.7819287153264181, 0.6197100631657795], 
             UndirectedEdge[234, 449] -> 
             RGBColor[
              0.8709053119286034, 0.8990575690415485, 0.9396938459522424], 
             UndirectedEdge[245, 299] -> 
             RGBColor[
              0.9941060600181102, 0.9898017832845076, 0.5998591900316346], 
             UndirectedEdge[398, 464] -> 
             RGBColor[
              0.871274699966634, 0.7861528781186962, 0.6176409600228231], 
             UndirectedEdge[245, 262] -> 
             RGBColor[
              0.9944925069973469, 0.9906283542973121, 0.6419215588472533], 
             UndirectedEdge[288, 321] -> 
             RGBColor[
              0.9834798586315254, 0.9858900192747573, 0.8541899554350205], 
             UndirectedEdge[433, 465] -> 
             RGBColor[
              0.9857789536690571, 0.9639469855251935, 0.5587175706681585], 
             UndirectedEdge[330, 367] -> 
             RGBColor[
              0.9877869823140104, 0.9696416070121069, 0.47705057300618214`], 
             UndirectedEdge[106, 156] -> 
             RGBColor[
              0.9659151793513522, 0.9707396324855551, 0.7396179676748197], 
             UndirectedEdge[85, 239] -> 
             RGBColor[
              0.9556332617855701, 0.8668414504751062, 0.5794771887688146], 
             UndirectedEdge[336, 388] -> 
             RGBColor[
              0.994495074156672, 0.9906338451915289, 0.64220097829712], 
             UndirectedEdge[69, 355] -> 
             RGBColor[
              0.8596175140705391, 0.8888346722969777, 0.8748699457659366], 
             UndirectedEdge[102, 383] -> 
             RGBColor[
              0.9944154563199314, 0.9904635506893389, 0.6335350681122411], 
             UndirectedEdge[296, 327] -> 
             RGBColor[
              0.8761941725077202, 0.9037496949463532, 0.968081831340619], 
             UndirectedEdge[61, 288] -> 
             RGBColor[
              0.9574946872731565, 0.8905178742948152, 0.5990330131600716], 
             UndirectedEdge[141, 472] -> 
             RGBColor[
              0.9435553537995685, 0.8157078582184678, 0.5585158850973894], 
             UndirectedEdge[43, 485] -> 
             RGBColor[
              0.9369518972586861, 0.7968500253858188, 0.5752856665590245], 
             UndirectedEdge[9, 358] -> 
             RGBColor[
              0.9876453733122699, 0.9891590586122696, 0.8544116671720399], 
             UndirectedEdge[70, 359] -> 
             RGBColor[
              0.5330942210117806, 0.6091681030360365, 0.9613049912397444], 
             UndirectedEdge[466, 470] -> 
             RGBColor[
              0.9719330527059014, 0.9216600486642237, 0.5446141925342283], 
             UndirectedEdge[41, 356] -> 
             RGBColor[
              0.8915352883079954, 0.9128517045262127, 0.8232607394904925], 
             UndirectedEdge[79, 436] -> 
             RGBColor[
              0.941513225988074, 0.8781182076066338, 0.6257124920901033], 
             UndirectedEdge[33, 175] -> 
             RGBColor[
              0.937312604053465, 0.9454010348207783, 0.7037496928002254], 
             UndirectedEdge[176, 448] -> 
             RGBColor[
              0.9791664585321558, 0.9822326794137162, 0.8417688169336461], 
             UndirectedEdge[118, 481] -> 
             RGBColor[
              0.9887145880292574, 0.9877939353608679, 0.7053224880454441], 
             UndirectedEdge[326, 346] -> 
             RGBColor[
              0.9859187245278406, 0.9858991633509004, 0.7248731252807812], 
             UndirectedEdge[63, 435] -> 
             RGBColor[
              0.9950392861473956, 0.9917978596114139, 0.7014350950002703], 
             UndirectedEdge[194, 350] -> 
             RGBColor[
              0.9639482372940178, 0.884748579595571, 0.3420616533984366], 
             UndirectedEdge[275, 486] -> 
             RGBColor[
              0.9724344626023801, 0.9208896214751244, 0.5315198823367195], 
             UndirectedEdge[407, 478] -> 
             RGBColor[
              0.9897214621671596, 0.9900175747068165, 0.8200055021007876], 
             UndirectedEdge[62, 356] -> 
             RGBColor[
              0.8900954405732442, 0.9127387432954781, 0.8821919689168785], 
             UndirectedEdge[150, 426] -> 
             RGBColor[
              0.6955977937530174, 0.5528205243684673, 0.5824069295733316], 
             UndirectedEdge[372, 444] -> 
             RGBColor[
              0.8927053954542412, 0.9168473582538277, 0.9745219439994277], 
             UndirectedEdge[106, 329] -> 
             RGBColor[
              0.9291526552173783, 0.9462670178695982, 0.9903966718653585], 
             UndirectedEdge[128, 294] -> 
             RGBColor[
              0.9905601558032989, 0.9880255479178403, 0.6360966069147493], 
             UndirectedEdge[379, 440] -> 
             RGBColor[
              0.9855148012846893, 0.9873971540388198, 0.8502741256289755], 
             UndirectedEdge[227, 267] -> 
             RGBColor[
              0.9769888066990331, 0.9803878535876117, 0.8311263052179285], 
             UndirectedEdge[151, 345] -> 
             RGBColor[
              0.9935242761434537, 0.989564176760924, 0.6097171825700566], 
             UndirectedEdge[275, 418] -> 
             RGBColor[
              0.9689692135509458, 0.906070664148603, 0.33872924845255314`], 
             UndirectedEdge[10, 232] -> 
             RGBColor[
              0.9671723454132466, 0.9734967853473315, 0.871444418067046], 
             UndirectedEdge[5, 431] -> 
             RGBColor[
              0.9926018487576362, 0.9855616315569663, 0.5231062613009816], 
             UndirectedEdge[42, 416] -> 
             RGBColor[
              0.9900572158068606, 0.9778061763089201, 0.4427976109810236], 
             UndirectedEdge[37, 97] -> 
             RGBColor[
              0.9140270496442962, 0.9317165275997802, 0.8911025235366925], 
             UndirectedEdge[441, 450] -> 
             RGBColor[
              0.9570797670329043, 0.964880507596638, 0.8312922079820069], 
             UndirectedEdge[5, 259] -> 
             RGBColor[
              0.9898312144496862, 0.9773604399737117, 0.4149966176613959], 
             UndirectedEdge[279, 318] -> 
             RGBColor[
              0.7755450322793994, 0.8249579296392571, 0.9781626977217528], 
             UndirectedEdge[275, 355] -> 
             RGBColor[
              0.8398694513312653, 0.8186890061961937, 0.6271705118305693], 
             UndirectedEdge[344, 387] -> 
             RGBColor[
              0.9604114080322901, 0.8680400714527897, 0.45606163082337026`], 
             UndirectedEdge[239, 489] -> 
             RGBColor[
              0.9890127009269722, 0.9878359060545845, 0.6944718506539334], 
             UndirectedEdge[21, 336] -> 
             RGBColor[
              0.9943734044431054, 0.9912043542376657, 0.6893446095666633], 
             UndirectedEdge[32, 312] -> 
             RGBColor[
              0.9497926129993202, 0.9600839446957532, 0.8879537943501545], 
             UndirectedEdge[77, 436] -> 
             RGBColor[
              0.9686618678237052, 0.9734860420906457, 0.7903466055373181], 
             UndirectedEdge[66, 294] -> 
             RGBColor[
              0.9862458846954594, 0.9735143908738377, 0.6157742474815322], 
             UndirectedEdge[197, 201] -> 
             RGBColor[
              0.7234086894042315, 0.7775156513637631, 0.7200067225100033], 
             UndirectedEdge[228, 256] -> 
             RGBColor[
              0.9525280130953018, 0.8456997628818059, 0.3004341918573073], 
             UndirectedEdge[292, 481] -> 
             RGBColor[
              0.9919460030514884, 0.9891302085161385, 0.65176957849307], 
             UndirectedEdge[444, 486] -> 
             RGBColor[
              0.9124117814549337, 0.9302458186262716, 0.8830133444772337], 
             UndirectedEdge[154, 244] -> 
             RGBColor[
              0.9869754385075247, 0.9886951558285859, 0.8571459110430137], 
             UndirectedEdge[288, 386] -> 
             RGBColor[
              0.9812609228970586, 0.984972432324508, 0.8909634629767383], 
             UndirectedEdge[273, 285] -> 
             RGBColor[
              0.9846495595384119, 0.9592496198920402, 0.4485974962459775], 
             UndirectedEdge[190, 487] -> 
             RGBColor[
              0.9186446107885713, 0.8991063329248149, 0.6557618545265138], 
             UndirectedEdge[83, 343] -> 
             RGBColor[
              0.9570528773067757, 0.9671894569038653, 0.9458078115409061], 
             UndirectedEdge[1, 315] -> 
             RGBColor[
              0.9937449467635517, 0.989029398547158, 0.5605542408056348], 
             UndirectedEdge[4, 429] -> 
             RGBColor[
              0.9904203066930833, 0.9856003255106844, 0.618199158942182], 
             UndirectedEdge[189, 451] -> 
             RGBColor[
              0.5801206797499041, 0.6454894302133305, 0.92500754737899], 
             UndirectedEdge[10, 102] -> 
             RGBColor[
              0.9673392721603814, 0.972288410284825, 0.775824255855077], 
             UndirectedEdge[357, 368] -> 
             RGBColor[
              0.9913349491300594, 0.9885538024267939, 0.6383653265316664], 
             UndirectedEdge[128, 138] -> 
             RGBColor[
              0.9766757871599407, 0.9783945364684088, 0.6920181941316845], 
             UndirectedEdge[336, 436] -> 
             RGBColor[
              0.9688234904130071, 0.9738317364666118, 0.8079382269638189], 
             UndirectedEdge[196, 454] -> 
             RGBColor[
              0.6734246339964871, 0.7038974629631614, 0.6389277349402431], 
             UndirectedEdge[25, 164] -> 
             RGBColor[
              0.9047313645117165, 0.926872248055715, 0.9907752792819929], 
             UndirectedEdge[125, 282] -> 
             RGBColor[
              0.9322621482681863, 0.9436098251013735, 0.7088066287751946], 
             UndirectedEdge[9, 286] -> 
             RGBColor[
              0.9778228575701141, 0.9482480874567334, 0.6048011787217853], 
             UndirectedEdge[421, 477] -> 
             RGBColor[
              0.9127122341651857, 0.9030317364260544, 0.6679297162252082], 
             UndirectedEdge[105, 484] -> 
             RGBColor[
              0.9594597919027572, 0.9217573672597068, 0.6245354020034041], 
             UndirectedEdge[299, 475] -> 
             RGBColor[
              0.9772730824376349, 0.9338747203805808, 0.4618037790300634], 
             UndirectedEdge[247, 252] -> 
             RGBColor[
              0.8798866174645681, 0.9070617211530119, 0.9884055651294683], 
             UndirectedEdge[261, 478] -> 
             RGBColor[
              0.9790251945828573, 0.9831155024039143, 0.8862605434392481], 
             UndirectedEdge[104, 303] -> 
             RGBColor[
              0.907422711507748, 0.6629945714040477, 0.24397135781061163`], 
             UndirectedEdge[32, 66] -> 
             RGBColor[
              0.9458422511762752, 0.9433844253320922, 0.6915909451351946], 
             UndirectedEdge[213, 454] -> 
             RGBColor[
              0.6860411425542627, 0.746879109328125, 0.848560964058934], 
             UndirectedEdge[129, 331] -> 
             RGBColor[
              0.8459308393808584, 0.8759938766086637, 0.7200955910233118], 
             UndirectedEdge[245, 475] -> 
             RGBColor[
              0.9770546099173684, 0.9334074297506909, 0.4380243934551645], 
             UndirectedEdge[90, 148] -> 
             RGBColor[
              0.9224442243876665, 0.9243116039299714, 0.6887474212736473], 
             UndirectedEdge[195, 496] -> 
             RGBColor[
              0.8753528338422361, 0.9031056875445556, 0.9686688270103224], 
             UndirectedEdge[241, 371] -> 
             RGBColor[
              0.821794231017269, 0.8609911197252574, 0.9827981358600935], 
             UndirectedEdge[13, 243] -> 
             RGBColor[
              0.9312706138956925, 0.7584273813113839, 0.2831029512511854], 
             UndirectedEdge[246, 384] -> 
             RGBColor[
              0.9747077513048901, 0.9781486411977619, 0.7922991404621604], 
             UndirectedEdge[22, 268] -> 
             RGBColor[
              0.6643813668028353, 0.7265607058781167, 0.729967990514772], 
             UndirectedEdge[69, 306] -> 
             RGBColor[
              0.9819231069441257, 0.9532980016981872, 0.5600346174495687], 
             UndirectedEdge[66, 128] -> 
             RGBColor[
              0.9882566074021573, 0.9720070282253106, 0.41244179748233245`], 
             UndirectedEdge[220, 413] -> 
             RGBColor[
              0.7046064881816142, 0.6903699323283892, 0.611077907702541], 
             UndirectedEdge[319, 492] -> 
             RGBColor[
              0.9153758577976584, 0.7213458516827096, 0.57224381242458], 
             UndirectedEdge[61, 186] -> 
             RGBColor[
              0.9665724230255843, 0.8938831507639733, 0.3771857110029996], 
             UndirectedEdge[94, 401] -> 
             RGBColor[
              0.9434295742664079, 0.8045434366244837, 0.31701086477588647`], 
             UndirectedEdge[429, 488] -> 
             RGBColor[
              0.6666716443400258, 0.7309937264282035, 0.8800941639154222], 
             UndirectedEdge[11, 431] -> 
             RGBColor[
              0.9670693980183709, 0.9724748841619066, 0.8070470349319394], 
             UndirectedEdge[349, 487] -> 
             RGBColor[
              0.9296160681661272, 0.9446671948497307, 0.9151872881639402], 
             UndirectedEdge[156, 198] -> 
             RGBColor[
              0.9899610029136222, 0.9774282205306668, 0.44696519612849095`], 
             UndirectedEdge[12, 188] -> 
             RGBColor[
              0.9835697608090508, 0.9559071539145039, 0.41889721096174926`], 
             UndirectedEdge[70, 111] -> 
             RGBColor[
              0.9381126280376877, 0.951323236906263, 0.9108353372910095], 
             UndirectedEdge[212, 286] -> 
             RGBColor[
              0.9369836063355421, 0.9173626941267049, 0.6628561690711263], 
             UndirectedEdge[242, 282] -> 
             RGBColor[
              0.9921158705442664, 0.9886466656004875, 0.6086999301398435], 
             UndirectedEdge[70, 175] -> 
             RGBColor[
              0.8855488684321957, 0.9115766463768901, 0.9889456356815118], 
             UndirectedEdge[188, 298] -> 
             RGBColor[
              0.9926501240726758, 0.9892952260681447, 0.6309303643665086], 
             UndirectedEdge[286, 367] -> 
             RGBColor[
              0.9815296506772213, 0.9485341581098807, 0.4527420211951849], 
             UndirectedEdge[9, 492] -> 
             RGBColor[
              0.9242405741624289, 0.7275864625230376, 0.5406383472431976], 
             UndirectedEdge[37, 343] -> 
             RGBColor[
              0.9880200621909672, 0.989314002092676, 0.8482021027882907], 
             UndirectedEdge[376, 391] -> 
             RGBColor[
              0.8938709054708682, 0.8768835319616324, 0.6497668105586358], 
             UndirectedEdge[230, 490] -> 
             RGBColor[
              0.9643276241879136, 0.9697151995713749, 0.7554150213772914], 
             UndirectedEdge[346, 355] -> 
             RGBColor[
              0.8526335233125599, 0.8849825265248978, 0.947439000718306], 
             UndirectedEdge[30, 465] -> 
             RGBColor[
              0.9833868555967316, 0.9629577914981705, 0.5983608262779622], 
             UndirectedEdge[119, 124] -> 
             RGBColor[
              0.9486017502918052, 0.9126189791441913, 0.6407064953643506], 
             UndirectedEdge[301, 436] -> 
             RGBColor[
              0.9254971729416744, 0.9432364149313058, 0.9860324358953628], 
             UndirectedEdge[39, 108] -> 
             RGBColor[
              0.9932063205705048, 0.9878773315836922, 0.5019281037080133], 
             UndirectedEdge[98, 382] -> 
             RGBColor[
              0.9665797819046555, 0.8970210040679241, 0.5235952717186831], 
             UndirectedEdge[81, 208] -> 
             RGBColor[
              0.965811125322148, 0.910010231555662, 0.5952664918844407], 
             UndirectedEdge[154, 203] -> 
             RGBColor[
              0.9612555101752576, 0.878565233567076, 0.532294413946222], 
             UndirectedEdge[145, 367] -> 
             RGBColor[
              0.9772231284411024, 0.9340072473879445, 0.4360119955263474], 
             UndirectedEdge[44, 132] -> 
             RGBColor[
              0.900613722431578, 0.6388663690638625, 0.2386410011256434], 
             UndirectedEdge[319, 357] -> 
             RGBColor[
              0.9807527841090984, 0.9816029824307139, 0.6984333605607739], 
             UndirectedEdge[364, 378] -> 
             RGBColor[
              0.9899000122197783, 0.9873314108662463, 0.6402741265872405], 
             UndirectedEdge[213, 251] -> 
             RGBColor[
              0.9706697442743972, 0.9760437299672775, 0.8627741811441636], 
             UndirectedEdge[73, 136] -> 
             RGBColor[
              0.9485318986240632, 0.8939893404463385, 0.6220841421947744], 
             UndirectedEdge[441, 461] -> 
             RGBColor[
              0.994944235170474, 0.9915945551829066, 0.691089382748997], 
             UndirectedEdge[90, 480] -> 
             RGBColor[
              0.9452133211808763, 0.8123176547805537, 0.3173690669721172], 
             UndirectedEdge[118, 446] -> 
             RGBColor[
              0.9299034115751079, 0.9456836369613986, 0.9494029467869696], 
             UndirectedEdge[210, 480] -> 
             RGBColor[
              0.8168426161099678, 0.727395277781711, 0.6086425797022219], 
             UndirectedEdge[95, 492] -> 
             RGBColor[
              0.9283636158669285, 0.7287628468368184, 0.4338852807541792], 
             UndirectedEdge[261, 328] -> 
             RGBColor[
              0.9813870185345592, 0.9825573369983815, 0.7355523207309593], 
             UndirectedEdge[152, 496] -> 
             RGBColor[
              0.8932288064724898, 0.9129910118994506, 0.7286226420111181], 
             UndirectedEdge[86, 177] -> 
             RGBColor[
              0.7247427383824914, 0.7788212001376849, 0.7383484379603721], 
             UndirectedEdge[45, 217] -> 
             RGBColor[
              0.9592304140133037, 0.9691146900419678, 0.9538964540511816], 
             UndirectedEdge[306, 331] -> 
             RGBColor[
              0.9821990880528132, 0.951364938839673, 0.40665192974848824`], 
             UndirectedEdge[103, 129] -> 
             RGBColor[
              0.8301316927449391, 0.8677062911338049, 0.9605019291876371], 
             UndirectedEdge[50, 126] -> 
             RGBColor[
              0.7079122656954095, 0.7685418254048804, 0.938009967678293], 
             UndirectedEdge[172, 308] -> 
             RGBColor[
              0.8440142383264699, 0.8780418870468285, 0.9366430909766552], 
             UndirectedEdge[112, 266] -> 
             RGBColor[
              0.9162806114852575, 0.9323433868055433, 0.8269969217621163], 
             UndirectedEdge[129, 275] -> 
             RGBColor[
              0.8259067955328971, 0.807781273366394, 0.6257788447890249], 
             UndirectedEdge[297, 325] -> 
             RGBColor[
              0.9951540493837361, 0.9920433265696033, 0.7139263650393461], 
             UndirectedEdge[202, 396] -> 
             RGBColor[
              0.9150025235047397, 0.9313835600879881, 0.8316809274662159], 
             UndirectedEdge[167, 236] -> 
             RGBColor[
              0.9651086887619267, 0.8869065863041876, 0.445440305996581], 
             UndirectedEdge[184, 301] -> 
             RGBColor[
              0.9507045672268772, 0.9590456693413258, 0.7697710293203313], 
             UndirectedEdge[78, 258] -> 
             RGBColor[
              0.9548236184902736, 0.8469936221774215, 0.38604298071119114`], 
             UndirectedEdge[172, 470] -> 
             RGBColor[
              0.9690858518811296, 0.9204826579534571, 0.5917996785202331], 
             UndirectedEdge[72, 159] -> 
             RGBColor[
              0.8416482654168942, 0.8733072664005492, 0.7724488150053614], 
             UndirectedEdge[304, 337] -> 
             RGBColor[
              0.9491948363005827, 0.8295078984803739, 0.5165184490979178], 
             UndirectedEdge[88, 271] -> 
             RGBColor[
              0.9943825626827818, 0.9903931945255325, 0.6299547987044936], 
             UndirectedEdge[392, 413] -> 
             RGBColor[
              0.6584178138042035, 0.7306491138489921, 0.9683452528836243], 
             UndirectedEdge[187, 216] -> 
             RGBColor[
              0.7970038184660401, 0.8420964887121403, 0.9708646111411015], 
             UndirectedEdge[33, 432] -> 
             RGBColor[
              0.9484221861219768, 0.8229196067546027, 0.33099265886497276`], 
             UndirectedEdge[36, 75] -> 
             RGBColor[
              0.95402844998809, 0.8532395289918973, 0.29335534741790315`], 
             UndirectedEdge[243, 335] -> 
             RGBColor[
              0.9387579820441576, 0.9181759861407703, 0.6621404561767863], 
             UndirectedEdge[323, 499] -> 
             RGBColor[
              0.8890697795256626, 0.7489726769032113, 0.6086614389998632], 
             UndirectedEdge[168, 480] -> 
             RGBColor[
              0.9467435612820985, 0.828494233265336, 0.5571424198505982], 
             UndirectedEdge[301, 388] -> 
             RGBColor[
              0.9511687566853395, 0.9600385236562229, 0.8202951872286639], 
             UndirectedEdge[111, 371] -> 
             RGBColor[
              0.8889659151847373, 0.9123856727788011, 0.9060811543549607], 
             UndirectedEdge[103, 231] -> 
             RGBColor[
              0.9617407263921789, 0.9709868769038736, 0.9496471499880725], 
             UndirectedEdge[99, 131] -> 
             RGBColor[
              0.9873205747953313, 0.9879200498219433, 0.799893090735895], 
             UndirectedEdge[193, 428] -> 
             RGBColor[
              0.909647413470967, 0.9299266216378659, 0.961235000166852], 
             UndirectedEdge[189, 370] -> 
             RGBColor[
              0.9487918669895068, 0.8456639311766505, 0.5840003359674039], 
             UndirectedEdge[45, 187] -> 
             RGBColor[
              0.9569165873051024, 0.9673890418715347, 0.95781315912551], 
             UndirectedEdge[346, 443] -> 
             RGBColor[
              0.9674024658231213, 0.9240229645619651, 0.6033252089185832], 
             UndirectedEdge[19, 318] -> 
             RGBColor[
              0.7367160992619132, 0.7942474830839217, 0.9743926338372014], 
             UndirectedEdge[5, 129] -> 
             RGBColor[
              0.8448992380138027, 0.872764589654954, 0.694783332581062], 
             UndirectedEdge[29, 46] -> 
             RGBColor[
              0.9375540210147754, 0.7901295327521776, 0.2686127033942143], 
             UndirectedEdge[227, 263] -> 
             RGBColor[
              0.9745305297791589, 0.9736967052230963, 0.6854221354839395], 
             UndirectedEdge[272, 435] -> 
             RGBColor[
              0.9380542346946958, 0.7721685344210818, 0.46882452924188894`], 
             UndirectedEdge[208, 483] -> 
             RGBColor[
              0.9702010567699588, 0.9119806257956484, 0.5294571886014905], 
             UndirectedEdge[244, 475] -> 
             RGBColor[
              0.9716444240557984, 0.9321862523066016, 0.6067579743781552], 
             UndirectedEdge[350, 412] -> 
             RGBColor[
              0.9482236419349522, 0.880265567971154, 0.6121367023372455], 
             UndirectedEdge[217, 398] -> 
             RGBColor[
              0.9338347582317821, 0.8356499632559611, 0.6102040807482032], 
             UndirectedEdge[370, 451] -> 
             RGBColor[
              0.5475981872396026, 0.50556850096332, 0.5924937885884138], 
             UndirectedEdge[265, 424] -> 
             RGBColor[
              0.9864556921444174, 0.9654022408483923, 0.4505025258173362], 
             UndirectedEdge[28, 419] -> 
             RGBColor[
              0.9946416934043442, 0.9919233854611996, 0.7290998613898423], 
             UndirectedEdge[67, 381] -> 
             RGBColor[
              0.9677187237249295, 0.9732132636405255, 0.8261107096523121], 
             UndirectedEdge[239, 435] -> 
             RGBColor[
              0.9900495423158384, 0.9900536049446242, 0.8073256371886866], 
             UndirectedEdge[302, 370] -> 
             RGBColor[
              0.9539584348288195, 0.8482785203902045, 0.5197863639335728], 
             UndirectedEdge[2, 66] -> 
             RGBColor[
              0.9732837076776313, 0.9645711484287764, 0.6701348048225415], 
             UndirectedEdge[36, 408] -> 
             RGBColor[
              0.8487182813773322, 0.8402059616759723, 0.6432618161908091], 
             UndirectedEdge[76, 483] -> 
             RGBColor[
              0.9708284925923595, 0.9144681997508737, 0.5299620381920058], 
             UndirectedEdge[9, 367] -> 
             RGBColor[
              0.9901299734011018, 0.9889397210434323, 0.7226074108924023], 
             UndirectedEdge[133, 469] -> 
             RGBColor[
              0.8471006795364846, 0.738583101940451, 0.609118432017115], 
             UndirectedEdge[46, 297] -> 
             RGBColor[
              0.9644718768067901, 0.8835345895128706, 0.4950636241087206], 
             UndirectedEdge[159, 435] -> 
             RGBColor[
              0.8422916749604514, 0.8746834543555349, 0.8424799731581492], 
             UndirectedEdge[126, 340] -> 
             RGBColor[
              0.9790887614191743, 0.9675273278413263, 0.6573932765216962], 
             UndirectedEdge[27, 290] -> 
             RGBColor[
              0.7896283927701178, 0.8355829689208562, 0.9796664367606033], 
             UndirectedEdge[326, 338] -> 
             RGBColor[
              0.9779708317104522, 0.9367690943976005, 0.4185370181612344], 
             UndirectedEdge[179, 438] -> 
             RGBColor[
              0.8406193118213405, 0.8759022596875117, 0.9846200847481419], 
             UndirectedEdge[138, 339] -> 
             RGBColor[
              0.957096125545646, 0.9116351297884182, 0.6163221395185674], 
             UndirectedEdge[475, 482] -> 
             RGBColor[
              0.9725626042040942, 0.9191093627528255, 0.3479113277606835], 
             UndirectedEdge[94, 428] -> 
             RGBColor[
              0.9358939771550208, 0.8134316853637062, 0.5886440007590872], 
             UndirectedEdge[186, 295] -> 
             RGBColor[
              0.9685217567041531, 0.9726392742160515, 0.731687571064974], 
             UndirectedEdge[348, 372] -> 
             RGBColor[
              0.9697477523765399, 0.9765085690773296, 0.9159443486338675], 
             UndirectedEdge[293, 343] -> 
             RGBColor[
              0.9900156928318682, 0.989936664591199, 0.8004037615733754], 
             UndirectedEdge[385, 446] -> 
             RGBColor[
              0.9304252261904883, 0.9458994207148823, 0.9407551281971807], 
             UndirectedEdge[7, 288] -> 
             RGBColor[
              0.85444919945479, 0.8864630116605847, 0.9507616972574261], 
             UndirectedEdge[242, 323] -> 
             RGBColor[
              0.9396285567334308, 0.786597980509416, 0.507668180206201], 
             UndirectedEdge[464, 481] -> 
             RGBColor[
              0.9093790676005927, 0.9257940630220336, 0.7415286600985842], 
             UndirectedEdge[42, 108] -> 
             RGBColor[
              0.9901546119807454, 0.978014496876596, 0.4533985834488723], 
             UndirectedEdge[101, 276] -> 
             RGBColor[
              0.909373767396813, 0.9260044380782251, 0.7589244310481174], 
             UndirectedEdge[86, 426] -> 
             RGBColor[
              0.7598756915905089, 0.807343714273459, 0.7411142327331552], 
             UndirectedEdge[37, 324] -> 
             RGBColor[
              0.9206078457662497, 0.9369638757964738, 0.8917302057455505], 
             UndirectedEdge[290, 297] -> 
             RGBColor[
              0.8871810741574686, 0.9098096516898004, 0.851620258798508], 
             UndirectedEdge[315, 380] -> 
             RGBColor[
              0.994700408121971, 0.9910730337808549, 0.6645503132455619], 
             UndirectedEdge[181, 390] -> 
             RGBColor[
              0.9842950249876962, 0.9868551228730162, 0.8688041711856391], 
             UndirectedEdge[283, 421] -> 
             RGBColor[
              0.9837107771151401, 0.9556060560362196, 0.4854967111425228], 
             UndirectedEdge[97, 355] -> 
             RGBColor[
              0.7819381079787922, 0.8297127793372002, 0.9788634476369271], 
             UndirectedEdge[192, 219] -> 
             RGBColor[
              0.9931709160383502, 0.9906603900975076, 0.7058780460896287], 
             UndirectedEdge[171, 192] -> 
             RGBColor[
              0.9591749085186705, 0.9662958303724822, 0.8107977198076082], 
             UndirectedEdge[122, 216] -> 
             RGBColor[
              0.8103301417327479, 0.8222627654409015, 0.6570263026335983], 
             UndirectedEdge[18, 28] -> 
             RGBColor[
              0.8393576104593539, 0.8726777216098311, 0.8578979091364201], 
             UndirectedEdge[178, 288] -> 
             RGBColor[
              0.9830190895556496, 0.9856994794206575, 0.8618260914544272], 
             UndirectedEdge[165, 185] -> 
             RGBColor[
              0.8692758764258632, 0.8969059220364054, 0.8996865611015998], 
             UndirectedEdge[264, 281] -> 
             RGBColor[
              0.9340997389648238, 0.949123731956673, 0.9531484044246594], 
             UndirectedEdge[80, 192] -> 
             RGBColor[
              0.9412585317987621, 0.7876706623639202, 0.4286805180309817], 
             UndirectedEdge[74, 402] -> 
             RGBColor[
              0.8208282193823524, 0.8601633008021292, 0.982721268136341], 
             UndirectedEdge[3, 158] -> 
             RGBColor[
              0.9919276179051719, 0.9899362782839082, 0.7112196690058487], 
             UndirectedEdge[426, 476] -> 
             RGBColor[
              0.7596060220996594, 0.8067669185002998, 0.7117623728613767], 
             UndirectedEdge[27, 177] -> 
             RGBColor[
              0.6281007518430358, 0.7065424015630154, 0.9655181299587501], 
             UndirectedEdge[355, 443] -> 
             RGBColor[
              0.8416469709530171, 0.8256023454247212, 0.6292982750801941], 
             UndirectedEdge[21, 256] -> 
             RGBColor[
              0.9652865896279283, 0.8884473950806936, 0.5056894205479601], 
             UndirectedEdge[331, 404] -> 
             RGBColor[
              0.9754742364313488, 0.9286804352502241, 0.3805271510807682], 
             UndirectedEdge[142, 285] -> 
             RGBColor[
              0.9432563532858231, 0.8068794597076978, 0.30370908232923416`], 
             UndirectedEdge[232, 267] -> 
             RGBColor[
              0.9942824228669862, 0.991744420080979, 0.7328443062315682], 
             UndirectedEdge[133, 488] -> 
             RGBColor[
              0.6216171015184127, 0.5548713474704446, 0.5905992990494154], 
             UndirectedEdge[148, 393] -> 
             RGBColor[
              0.9094312438335646, 0.8804157649278506, 0.6381944491161399], 
             UndirectedEdge[84, 89] -> 
             RGBColor[
              0.9878435962877522, 0.9692725745587165, 0.5248892634131955], 
             UndirectedEdge[27, 350] -> 
             RGBColor[
              0.869089448668618, 0.8179122376828964, 0.6248560387774963], 
             UndirectedEdge[8, 435] -> 
             RGBColor[
              0.968695310482631, 0.9742506916358067, 0.8489826669274352], 
             UndirectedEdge[20, 220] -> 
             RGBColor[
              0.9352745182849945, 0.8741177530917199, 0.6320156503787664], 
             UndirectedEdge[35, 422] -> 
             RGBColor[
              0.9807105633629735, 0.9465943422275145, 0.3795646104799518], 
             UndirectedEdge[65, 177] -> 
             RGBColor[
              0.7243864134073554, 0.7802707439464642, 0.860330953320448], 
             UndirectedEdge[93, 160] -> 
             RGBColor[
              0.960107057706475, 0.8678110822585012, 0.5010266596478555], 
             UndirectedEdge[277, 373] -> 
             RGBColor[
              0.9913214562229201, 0.9849335526546157, 0.5960803375317898], 
             UndirectedEdge[15, 126] -> 
             RGBColor[
              0.9670916105269911, 0.9270581208170044, 0.6107866107774077], 
             UndirectedEdge[95, 367] -> 
             RGBColor[
              0.9942530151056015, 0.990116105357213, 0.6158543444033839], 
             UndirectedEdge[304, 465] -> 
             RGBColor[
              0.9422074596638867, 0.8021781780739006, 0.30569186258793024`], 
             UndirectedEdge[218, 305] -> 
             RGBColor[
              0.9882260951792036, 0.971144603867855, 0.47690561554499705`], 
             UndirectedEdge[137, 265] -> 
             RGBColor[
              0.9414747333944451, 0.7897863141705668, 0.37786926936068244`], 
             UndirectedEdge[325, 392] -> 
             RGBColor[
              0.921489173319127, 0.9367037959128508, 0.8442935312925958], 
             UndirectedEdge[263, 393] -> 
             RGBColor[
              0.9738871750665854, 0.9235774512960366, 0.3530570354372429], 
             UndirectedEdge[228, 335] -> 
             RGBColor[
              0.9387811813763051, 0.9182542429355661, 0.6622305812013531], 
             UndirectedEdge[104, 408] -> 
             RGBColor[
              0.835637933010077, 0.7905523640289636, 0.6212501290920669], 
             UndirectedEdge[145, 375] -> 
             RGBColor[
              0.9578961740609304, 0.9224423661428891, 0.6311118243618588], 
             UndirectedEdge[181, 451] -> 
             RGBColor[
              0.578795262351163, 0.644500936087521, 0.9272511333108374], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.7375005691741812, 0.7906945917579444, 0.8520488221672103], 
             UndirectedEdge[387, 439] -> 
             RGBColor[
              0.9598028191299937, 0.8667383613285543, 0.38982048458374136`], 
             UndirectedEdge[163, 231] -> 
             RGBColor[
              0.9260122952347949, 0.9431584501349396, 0.9691377094494544], 
             UndirectedEdge[143, 288] -> 
             RGBColor[
              0.9843424635559853, 0.9849695201084625, 0.7470547865798496], 
             UndirectedEdge[128, 312] -> 
             RGBColor[
              0.9922069692252022, 0.9887065475889717, 0.6088046466972924], 
             UndirectedEdge[270, 479] -> 
             RGBColor[
              0.8994244627640979, 0.8508873153037063, 0.629795463891946], 
             UndirectedEdge[119, 120] -> 
             RGBColor[
              0.9512963714522786, 0.9631974940907576, 0.9673267185772845], 
             UndirectedEdge[105, 462] -> 
             RGBColor[
              0.8954033943262008, 0.9188149635311116, 0.9684100865487384], 
             UndirectedEdge[14, 159] -> 
             RGBColor[
              0.8415482118806652, 0.8730932620035198, 0.7615586050456885], 
             UndirectedEdge[58, 417] -> 
             RGBColor[
              0.88161294651367, 0.47868644342620076`, 0.2197758101413146], 
             UndirectedEdge[66, 299] -> 
             RGBColor[
              0.9891334344163472, 0.9738824725478528, 0.5078790068278244], 
             UndirectedEdge[11, 348] -> 
             RGBColor[
              0.9633405417365675, 0.9717300818728827, 0.9267900849791704], 
             UndirectedEdge[4, 31] -> 
             RGBColor[
              0.9877749939535714, 0.9845064207114598, 0.6620388368858149], 
             UndirectedEdge[259, 400] -> 
             RGBColor[
              0.9913359244219537, 0.9816016583953521, 0.49180382809308776`], 
             UndirectedEdge[247, 451] -> 
             RGBColor[
              0.5167737228584388, 0.5961545808166826, 0.9597483275563979], 
             UndirectedEdge[17, 261] -> 
             RGBColor[
              0.979327054864086, 0.9832403293876577, 0.8812579373899222], 
             UndirectedEdge[361, 386] -> 
             RGBColor[
              0.9847006924535722, 0.9696502651091363, 0.6190899716290563], 
             UndirectedEdge[212, 492] -> 
             RGBColor[
              0.883401322927857, 0.6967010691930091, 0.5986933375925385], 
             UndirectedEdge[287, 388] -> 
             RGBColor[
              0.983752672075374, 0.9555851173742389, 0.4994569013586586], 
             UndirectedEdge[383, 480] -> 
             RGBColor[
              0.9509184218429756, 0.8300029377287537, 0.47212912697379095`], 
             UndirectedEdge[403, 440] -> 
             RGBColor[
              0.9919131157483356, 0.9909238797855606, 0.7836841304430466], 
             UndirectedEdge[13, 354] -> 
             RGBColor[
              0.9244381093741103, 0.7883074383868084, 0.5969944428658969], 
             UndirectedEdge[1, 42] -> 
             RGBColor[
              0.9900653580536234, 0.9778235917514384, 0.44368384429303287`], 
             UndirectedEdge[161, 188] -> 
             RGBColor[
              0.975856875514673, 0.9781111397190738, 0.7193779199729885], 
             UndirectedEdge[194, 426] -> 
             RGBColor[
              0.758092493676453, 0.8019012576114641, 0.6854895393524736], 
             UndirectedEdge[257, 324] -> 
             RGBColor[
              0.9216628951076848, 0.9355747300027966, 0.7415553946787028], 
             UndirectedEdge[198, 479] -> 
             RGBColor[
              0.9652505347181812, 0.8908122348252845, 0.3384197978096124], 
             UndirectedEdge[372, 431] -> 
             RGBColor[
              0.9734766086583433, 0.9772533713663535, 0.7962012985866365], 
             UndirectedEdge[107, 466] -> 
             RGBColor[
              0.9843404241374915, 0.9868012573716447, 0.8647988572580583], 
             UndirectedEdge[122, 330] -> 
             RGBColor[
              0.9772266882174132, 0.934842413308755, 0.366030413414067], 
             UndirectedEdge[4, 472] -> 
             RGBColor[
              0.9885818468859728, 0.9848400751341824, 0.6486671957274691], 
             UndirectedEdge[145, 458] -> 
             RGBColor[
              0.9472835367282239, 0.9144825722493798, 0.647519319893358], 
             UndirectedEdge[3, 451] -> 
             RGBColor[
              0.5843259924605718, 0.6477065157280597, 0.8767240604753376], 
             UndirectedEdge[146, 239] -> 
             RGBColor[
              0.9165920835240676, 0.6799628210613167, 0.5466043457885665], 
             UndirectedEdge[15, 282] -> 
             RGBColor[
              0.9757239373483116, 0.9297472786528963, 0.3624036269818403], 
             UndirectedEdge[82, 126] -> 
             RGBColor[
              0.6593629893843529, 0.726490882421821, 0.9349164507221919], 
             UndirectedEdge[413, 474] -> 
             RGBColor[
              0.6908419238964731, 0.6357980217069457, 0.6000026161828671], 
             UndirectedEdge[160, 235] -> 
             RGBColor[
              0.9941076738311097, 0.9905868164066032, 0.6568475561902656], 
             UndirectedEdge[161, 183] -> 
             RGBColor[
              0.8685582061287598, 0.8977720757927401, 0.9666958890576296], 
             UndirectedEdge[366, 429] -> 
             RGBColor[
              0.9255833997087346, 0.9411535184759091, 0.9018565537684039], 
             UndirectedEdge[7, 313] -> 
             RGBColor[
              0.8581222584804777, 0.8719277846037095, 0.6797944914444659], 
             UndirectedEdge[129, 444] -> 
             RGBColor[
              0.7658841143854508, 0.8171374705175412, 0.977272306929539], 
             UndirectedEdge[18, 493] -> 
             RGBColor[
              0.8398127655774765, 0.8726753158598739, 0.8364984520395502], 
             UndirectedEdge[149, 411] -> 
             RGBColor[
              0.9622100041626851, 0.9713368634967454, 0.94885278512985], 
             UndirectedEdge[221, 301] -> 
             RGBColor[
              0.9350888375232078, 0.9503898626713041, 0.969796249665603], 
             UndirectedEdge[45, 496] -> 
             RGBColor[
              0.8806240845243325, 0.9070369776723823, 0.9597459745678963], 
             UndirectedEdge[478, 482] -> 
             RGBColor[
              0.9868413940370585, 0.9751831443540124, 0.6157373494284505], 
             UndirectedEdge[69, 331] -> 
             RGBColor[
              0.99263298080731, 0.9891743743477871, 0.6229451369508758], 
             UndirectedEdge[16, 143] -> 
             RGBColor[
              0.6860233651108038, 0.7455945494279008, 0.7560160093967134], 
             UndirectedEdge[210, 280] -> 
             RGBColor[
              0.8572140897803716, 0.8781138925627088, 0.689773592120747], 
             UndirectedEdge[101, 390] -> 
             RGBColor[
              0.9917167639472868, 0.9893114168290789, 0.6756312825573498], 
             UndirectedEdge[400, 418] -> 
             RGBColor[
              0.989466366004119, 0.9752951988588034, 0.4845409466762822], 
             UndirectedEdge[84, 299] -> 
             RGBColor[
              0.987633790263805, 0.9688238206881363, 0.5020531724792335], 
             UndirectedEdge[333, 386] -> 
             RGBColor[
              0.9617657888338886, 0.8863504774710793, 0.5609016388731325], 
             UndirectedEdge[244, 341] -> 
             RGBColor[
              0.9711979751509194, 0.9780400775433187, 0.9336384946850395], 
             UndirectedEdge[143, 373] -> 
             RGBColor[
              0.9920209711454658, 0.9839456115813076, 0.4916479920717321], 
             UndirectedEdge[160, 284] -> 
             RGBColor[
              0.9935047050390722, 0.9892971271299315, 0.5912181242690308], 
             UndirectedEdge[281, 343] -> 
             RGBColor[
              0.9829508581880142, 0.9866737431719391, 0.907849927446631], 
             UndirectedEdge[207, 445] -> 
             RGBColor[
              0.9139596956151814, 0.930116642684262, 0.7962869519336235], 
             UndirectedEdge[260, 334] -> 
             RGBColor[
              0.9661229171250174, 0.9552247740408026, 0.6737524546615603], 
             UndirectedEdge[66, 114] -> 
             RGBColor[
              0.977061833443732, 0.9673888684390212, 0.663739423393549], 
             UndirectedEdge[364, 381] -> 
             RGBColor[
              0.9641283678583042, 0.9722110120317231, 0.9206814241604935], 
             UndirectedEdge[204, 306] -> 
             RGBColor[
              0.9828381303430885, 0.9527317856814854, 0.47620773933309085`], 
             UndirectedEdge[358, 361] -> 
             RGBColor[
              0.985315266839857, 0.9699044074117062, 0.6089048835807904], 
             UndirectedEdge[294, 415] -> 
             RGBColor[
              0.9873297677537624, 0.9890285476031339, 0.8596420680375123], 
             UndirectedEdge[2, 255] -> 
             RGBColor[
              0.9774638580959951, 0.9813656912818993, 0.8626894623392449], 
             UndirectedEdge[326, 443] -> 
             RGBColor[
              0.9749321721682978, 0.9265189822507237, 0.4067323996426692], 
             UndirectedEdge[58, 145] -> 
             RGBColor[
              0.8889642451869979, 0.5064578515396547, 0.2328468688434464], 
             UndirectedEdge[103, 346] -> 
             RGBColor[
              0.9698498434134115, 0.9770346431008484, 0.9359205300675706], 
             UndirectedEdge[62, 108] -> 
             RGBColor[
              0.9925269359833797, 0.9893909241311116, 0.6436310537189743], 
             UndirectedEdge[91, 336] -> 
             RGBColor[
              0.8931941765510223, 0.9139474025729191, 0.8073880332976965], 
             UndirectedEdge[338, 395] -> 
             RGBColor[
              0.7663778384235603, 0.7735733879624191, 0.6340530076772258], 
             UndirectedEdge[19, 335] -> 
             RGBColor[
              0.8488642550973029, 0.8825760221304475, 0.985380098922543], 
             UndirectedEdge[2, 195] -> 
             RGBColor[
              0.959926110262679, 0.9696335391656538, 0.952718821767631], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.986396887795763, 0.9867306986433695, 0.7617467418413485], 
             UndirectedEdge[150, 325] -> 
             RGBColor[
              0.9299654566983493, 0.7355722524703368, 0.4560955478432398], 
             UndirectedEdge[208, 238] -> 
             RGBColor[
              0.9512717758467308, 0.8445158594900659, 0.279650330929096], 
             UndirectedEdge[318, 335] -> 
             RGBColor[
              0.7966123380415555, 0.8417564273972196, 0.9801721161523531], 
             UndirectedEdge[12, 421] -> 
             RGBColor[
              0.9736103967108278, 0.9226438129114177, 0.3519818037903313], 
             UndirectedEdge[102, 278] -> 
             RGBColor[
              0.9879405623174387, 0.9701815740479194, 0.47578450634641234`], 
             UndirectedEdge[5, 209] -> 
             RGBColor[
              0.9827191548081493, 0.9533697928117915, 0.38736760895379285`], 
             UndirectedEdge[76, 463] -> 
             RGBColor[
              0.9601020557962168, 0.9077720501971765, 0.606497392204405], 
             UndirectedEdge[293, 445] -> 
             RGBColor[
              0.9946166339348821, 0.9908938492655412, 0.6554320099752888], 
             UndirectedEdge[48, 250] -> 
             RGBColor[
              0.9736109475376837, 0.9794701138754239, 0.9130045552512913], 
             UndirectedEdge[459, 477] -> 
             RGBColor[
              0.8942351908268651, 0.8348506378796215, 0.6266360232902171], 
             UndirectedEdge[400, 404] -> 
             RGBColor[
              0.9759473450365606, 0.9296923667181547, 0.4320221030702104], 
             UndirectedEdge[144, 246] -> 
             RGBColor[
              0.9947810720063123, 0.991245565673091, 0.6733300792563195], 
             UndirectedEdge[90, 393] -> 
             RGBColor[
              0.970606458030171, 0.9125108223832186, 0.34031206926220003`], 
             UndirectedEdge[157, 360] -> 
             RGBColor[
              0.9922887375121424, 0.9853080337326091, 0.45364257860899293`], 
             UndirectedEdge[156, 250] -> 
             RGBColor[
              0.9769540226485787, 0.9789723837421797, 0.7209320853640503], 
             UndirectedEdge[25, 220] -> 
             RGBColor[
              0.9362251173273104, 0.874875734964739, 0.6321063193640323], 
             UndirectedEdge[261, 407] -> 
             RGBColor[
              0.9799674447471953, 0.9835051470615928, 0.8706450197509084], 
             UndirectedEdge[42, 364] -> 
             RGBColor[
              0.9873202278058992, 0.9786291922760466, 0.6302521512907286], 
             UndirectedEdge[83, 257] -> 
             RGBColor[
              0.9611437762307076, 0.9670557129303259, 0.7453211163652154], 
             UndirectedEdge[137, 263] -> 
             RGBColor[
              0.9398504491628847, 0.7848789918367595, 0.3229400569434002], 
             UndirectedEdge[27, 65] -> 
             RGBColor[
              0.89643261840225, 0.917528493498128, 0.8755276522870109], 
             UndirectedEdge[318, 421] -> 
             RGBColor[
              0.828793142996805, 0.8372122872874541, 0.6596347645281896], 
             UndirectedEdge[203, 341] -> 
             RGBColor[
              0.9454780468186523, 0.8679101552818089, 0.6087869975882478], 
             UndirectedEdge[80, 483] -> 
             RGBColor[
              0.940091019767424, 0.7879714885672384, 0.5049902922796075], 
             UndirectedEdge[95, 319] -> 
             RGBColor[
              0.9816815056337237, 0.9835894238637376, 0.7995189671113667], 
             UndirectedEdge[84, 376] -> 
             RGBColor[
              0.9727137728661852, 0.9196192901461484, 0.34849858946710077`], 
             UndirectedEdge[260, 446] -> 
             RGBColor[
              0.9134587358232007, 0.9334275497239946, 0.9776123044535485], 
             UndirectedEdge[174, 393] -> 
             RGBColor[
              0.9392981010697621, 0.904230786173752, 0.6410431766217866], 
             UndirectedEdge[185, 216] -> 
             RGBColor[
              0.8187197948618438, 0.8574111268781424, 0.8946476033647418], 
             UndirectedEdge[143, 321] -> 
             RGBColor[
              0.9929388939513691, 0.9900708569633181, 0.673844758083002], 
             UndirectedEdge[296, 415] -> 
             RGBColor[
              0.8902613789503551, 0.9139223279795526, 0.9299991832590492], 
             UndirectedEdge[42, 113] -> 
             RGBColor[
              0.9865659627690982, 0.9783172842996021, 0.6427522749258637], 
             UndirectedEdge[54, 264] -> 
             RGBColor[
              0.9409181768299625, 0.9524873440326833, 0.864511247797779], 
             UndirectedEdge[9, 95] -> 
             RGBColor[
              0.9905462219984942, 0.9898300347040656, 0.7679135019299843], 
             UndirectedEdge[47, 55] -> 
             RGBColor[
              0.9882179209081481, 0.9893958217569673, 0.844923071802657], 
             UndirectedEdge[212, 330] -> 
             RGBColor[
              0.9432409379723312, 0.9384701430289311, 0.6871647208821234], 
             UndirectedEdge[89, 244] -> 
             RGBColor[
              0.9889056801804874, 0.9890293597109986, 0.7914288618885873], 
             UndirectedEdge[3, 247] -> 
             RGBColor[
              0.9221727153190107, 0.9384670965447424, 0.9029713880317355], 
             UndirectedEdge[26, 318] -> 
             RGBColor[
              0.8220044030128106, 0.814312273249491, 0.6332617916363457], 
             UndirectedEdge[46, 426] -> 
             RGBColor[
              0.7300059436325623, 0.7005726713280368, 0.6106788978770363], 
             UndirectedEdge[102, 247] -> 
             RGBColor[
              0.9242108592241347, 0.9380325178651518, 0.7763403149571115], 
             UndirectedEdge[285, 287] -> 
             RGBColor[
              0.9743576308423212, 0.9251644090958628, 0.3548846672878583], 
             UndirectedEdge[346, 390] -> 
             RGBColor[
              0.9841577717278653, 0.986752759616566, 0.8690365051531492], 
             UndirectedEdge[388, 473] -> 
             RGBColor[
              0.9659967439223447, 0.8902100312967643, 0.45901929778567696`], 
             UndirectedEdge[377, 412] -> 
             RGBColor[
              0.9608746648690172, 0.9282429397492289, 0.6336680230941611], 
             UndirectedEdge[7, 321] -> 
             RGBColor[
              0.8630456298501739, 0.8915643485154403, 0.8775516687605784], 
             UndirectedEdge[209, 275] -> 
             RGBColor[
              0.9637267123272437, 0.8883864765232314, 0.3183631211617557], 
             UndirectedEdge[204, 346] -> 
             RGBColor[
              0.9862880323396062, 0.9866890754175197, 0.7650700014878478], 
             UndirectedEdge[220, 297] -> 
             RGBColor[
              0.9677761179254338, 0.8966348044752122, 0.4977222940732887], 
             UndirectedEdge[16, 185] -> 
             RGBColor[
              0.6838703579594925, 0.745981434111568, 0.8845364826047273], 
             UndirectedEdge[323, 449] -> 
             RGBColor[
              0.8223327131443487, 0.6962666607138044, 0.60216110844838], 
             UndirectedEdge[224, 481] -> 
             RGBColor[
              0.9412230839650331, 0.9511856172882409, 0.7445659708069136], 
             UndirectedEdge[86, 476] -> 
             RGBColor[
              0.9931612604259921, 0.9877809524908587, 0.49702358505677846`], 
             UndirectedEdge[66, 385] -> 
             RGBColor[
              0.9846140375250565, 0.9728395801323168, 0.6428181781802091], 
             UndirectedEdge[184, 316] -> 
             RGBColor[
              0.5862804912255636, 0.6470930285515473, 0.7409887300952827], 
             UndirectedEdge[308, 362] -> 
             RGBColor[
              0.7755954478277511, 0.8248461427175688, 0.9782078390548907], 
             UndirectedEdge[216, 361] -> 
             RGBColor[
              0.814853536249825, 0.8375212372905427, 0.6745988361610644], 
             UndirectedEdge[123, 410] -> 
             RGBColor[
              0.9543825040923555, 0.916558060494965, 0.6301310867145471], 
             UndirectedEdge[174, 225] -> 
             RGBColor[
              0.9343551308804574, 0.8851157147638836, 0.6345548584534384], 
             UndirectedEdge[3, 139] -> 
             RGBColor[
              0.9547184301721083, 0.8547052012398799, 0.5371018075964108], 
             UndirectedEdge[226, 472] -> 
             RGBColor[
              0.9291236933856505, 0.7501770588787907, 0.5464737538956488], 
             UndirectedEdge[9, 441] -> 
             RGBColor[
              0.9905887098859563, 0.9899209119991628, 0.772538046275393], 
             UndirectedEdge[253, 354] -> 
             RGBColor[
              0.972958146129502, 0.9733713177199604, 0.6898824149199128], 
             UndirectedEdge[47, 73] -> 
             RGBColor[
              0.9675344330101509, 0.9074203167747059, 0.5567306105735907], 
             UndirectedEdge[305, 432] -> 
             RGBColor[
              0.944353075230216, 0.8091935402440212, 0.3151849314375963], 
             UndirectedEdge[4, 226] -> 
             RGBColor[
              0.9314846706594351, 0.7464471442887625, 0.317121569643323], 
             UndirectedEdge[112, 359] -> 
             RGBColor[
              0.5868369063402853, 0.6482831442197393, 0.8015510815366913], 
             UndirectedEdge[101, 204] -> 
             RGBColor[
              0.9938470245590276, 0.9892477326300325, 0.5716647788920484], 
             UndirectedEdge[256, 409] -> 
             RGBColor[
              0.9312430850070132, 0.7651087744761581, 0.2635347761456615], 
             UndirectedEdge[64, 268] -> 
             RGBColor[
              0.9845431649545142, 0.9590011365014823, 0.4387956594171406], 
             UndirectedEdge[97, 395] -> 
             RGBColor[
              0.7036303159071808, 0.7674337097280214, 0.9718135617153938], 
             UndirectedEdge[117, 156] -> 
             RGBColor[
              0.9384694251386885, 0.9489332375680635, 0.7397080990621858], 
             UndirectedEdge[48, 117] -> 
             RGBColor[
              0.9351263500277934, 0.9494309677013077, 0.931780568949427], 
             UndirectedEdge[5, 103] -> 
             RGBColor[
              0.9760782139130224, 0.9757244390607043, 0.6846565289718709], 
             UndirectedEdge[344, 438] -> 
             RGBColor[
              0.9372774788734658, 0.9489810736376647, 0.8205167362874191], 
             UndirectedEdge[42, 381] -> 
             RGBColor[
              0.9639065519875438, 0.9617238751552754, 0.6948094688085961], 
             UndirectedEdge[224, 398] -> 
             RGBColor[
              0.9031187163310743, 0.8115444323849035, 0.6206782707311524], 
             UndirectedEdge[226, 405] -> 
             RGBColor[
              0.9290271213174831, 0.7501371238468146, 0.5480742029856828], 
             UndirectedEdge[231, 346] -> 
             RGBColor[
              0.9702799011614316, 0.9773553794651669, 0.9351925544771971], 
             UndirectedEdge[168, 181] -> 
             RGBColor[
              0.9826717217445214, 0.986183845264973, 0.8957065068991721], 
             UndirectedEdge[178, 391] -> 
             RGBColor[
              0.9072060320368783, 0.9262586637571282, 0.889628205255995], 
             UndirectedEdge[30, 133] -> 
             RGBColor[
              0.944477349613176, 0.8138168037930025, 0.5336522982908991], 
             UndirectedEdge[120, 363] -> 
             RGBColor[
              0.8869408458194084, 0.9120420024738234, 0.9639353023957442], 
             UndirectedEdge[452, 468] -> 
             RGBColor[
              0.5861545599507506, 0.6484626753772896, 0.8464199649821045], 
             UndirectedEdge[159, 344] -> 
             RGBColor[
              0.8420038260830139, 0.8740677747126818, 0.8111493992464291], 
             UndirectedEdge[68, 330] -> 
             RGBColor[
              0.7991229669447234, 0.8248030066421457, 0.673252932576855], 
             UndirectedEdge[359, 440] -> 
             RGBColor[
              0.5855333116829213, 0.6482057732531901, 0.856715656519016], 
             UndirectedEdge[180, 413] -> 
             RGBColor[
              0.7287757623806213, 0.7846467498774699, 0.8946436370776796], 
             UndirectedEdge[81, 442] -> 
             RGBColor[
              0.9718562887601929, 0.9326492841896267, 0.6070468499308518], 
             UndirectedEdge[165, 277] -> 
             RGBColor[
              0.8707293686546289, 0.8975069784260464, 0.8755984333536437], 
             UndirectedEdge[28, 310] -> 
             RGBColor[
              0.9887171913947362, 0.9735615926021925, 0.5680808842989458], 
             UndirectedEdge[71, 470] -> 
             RGBColor[
              0.9551279351798135, 0.9101672566361961, 0.6196537724216613], 
             UndirectedEdge[129, 276] -> 
             RGBColor[
              0.7620966245089191, 0.8141174288986688, 0.9769110527639833], 
             UndirectedEdge[192, 251] -> 
             RGBColor[
              0.9709380417755523, 0.9753710554469693, 0.8013667187532781], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.8226825254064585, 0.8581504281570734, 0.7432735160379585], 
             UndirectedEdge[15, 323] -> 
             RGBColor[
              0.923236623537476, 0.7276985935618248, 0.26137187704819786`], 
             UndirectedEdge[20, 473] -> 
             RGBColor[
              0.9338401234041958, 0.8684308553731115, 0.6308615025881005], 
             UndirectedEdge[336, 354] -> 
             RGBColor[
              0.9747591240567491, 0.9782585223194067, 0.7978907474661551], 
             UndirectedEdge[36, 440] -> 
             RGBColor[
              0.9777806077235343, 0.9396460644785285, 0.546165267418333], 
             UndirectedEdge[31, 311] -> 
             RGBColor[
              0.9566515598536678, 0.9669418218268983, 0.9489118528521276], 
             UndirectedEdge[366, 405] -> 
             RGBColor[
              0.9236483678334568, 0.9403533330674309, 0.9339250396437249], 
             UndirectedEdge[257, 374] -> 
             RGBColor[
              0.9316398891173758, 0.7454449460775301, 0.3554363396941125], 
             UndirectedEdge[194, 254] -> 
             RGBColor[
              0.9642588416109876, 0.8859800222096035, 0.3423115729226909], 
             UndirectedEdge[284, 456] -> 
             RGBColor[
              0.9934678517554696, 0.988436720343473, 0.5303941592080499], 
             UndirectedEdge[30, 429] -> 
             RGBColor[
              0.9895318924347892, 0.9899391827507613, 0.8231471631569058], 
             UndirectedEdge[182, 463] -> 
             RGBColor[
              0.9828667845033299, 0.9849224970540018, 0.8323757874993186], 
             UndirectedEdge[130, 238] -> 
             RGBColor[
              0.9716052729734291, 0.9228890427268854, 0.5567236102566763], 
             UndirectedEdge[19, 67] -> 
             RGBColor[
              0.8918453858637854, 0.9130939550936245, 0.8232916471168272], 
             UndirectedEdge[114, 446] -> 
             RGBColor[
              0.9228730221091638, 0.9404487090215867, 0.9616763734105205], 
             UndirectedEdge[164, 418] -> 
             RGBColor[
              0.9311949817444323, 0.9331671708861409, 0.6923447875526306], 
             UndirectedEdge[96, 457] -> 
             RGBColor[
              0.9634718810631488, 0.8819666998490178, 0.352431517341921], 
             UndirectedEdge[285, 354] -> 
             RGBColor[
              0.9654313700350757, 0.9479817345823907, 0.6606423111054653], 
             UndirectedEdge[432, 460] -> 
             RGBColor[
              0.947280675050169, 0.8273815676952241, 0.5417094405605571], 
             UndirectedEdge[82, 249] -> 
             RGBColor[
              0.6486715666322697, 0.7185172368389154, 0.9530142406718239], 
             UndirectedEdge[176, 262] -> 
             RGBColor[
              0.9949123147658029, 0.9920048965686231, 0.722405367360196], 
             UndirectedEdge[216, 358] -> 
             RGBColor[
              0.8184058357405132, 0.8572812967130907, 0.8998507185053508], 
             UndirectedEdge[54, 374] -> 
             RGBColor[
              0.9323340736381263, 0.7475574450264808, 0.47662181879241994`], 
             UndirectedEdge[214, 491] -> 
             RGBColor[
              0.9830801294240394, 0.9533621024845698, 0.49296420586895884`], 
             UndirectedEdge[68, 357] -> 
             RGBColor[
              0.8046602782116891, 0.8432910635542281, 0.7109710974234639], 
             UndirectedEdge[260, 328] -> 
             RGBColor[
              0.9724278089637228, 0.9758755731698112, 0.7507179255982941], 
             UndirectedEdge[224, 286] -> 
             RGBColor[
              0.9292408181214099, 0.911188804977143, 0.6621176550191936], 
             UndirectedEdge[219, 293] -> 
             RGBColor[
              0.9935076781834546, 0.9913806902740101, 0.7425325273291866], 
             UndirectedEdge[209, 404] -> 
             RGBColor[
              0.9663160306905563, 0.8980382035264525, 0.32364456922701546`], 
             UndirectedEdge[197, 289] -> 
             RGBColor[
              0.7160100800689776, 0.7529241317551307, 0.6601657419589453], 
             UndirectedEdge[227, 424] -> 
             RGBColor[
              0.9691810650349142, 0.9556517045267058, 0.6646404751142002], 
             UndirectedEdge[458, 461] -> 
             RGBColor[
              0.9645459069727409, 0.9710886890886115, 0.8526660717330168], 
             UndirectedEdge[292, 464] -> 
             RGBColor[
              0.9081380041186011, 0.9270881223927943, 0.8934658179916466], 
             UndirectedEdge[386, 441] -> 
             RGBColor[
              0.9911963285179468, 0.9901721779185775, 0.7624682330766959], 
             UndirectedEdge[257, 343] -> 
             RGBColor[
              0.9890751115324024, 0.9879248562989986, 0.698027291721443], 
             UndirectedEdge[132, 457] -> 
             RGBColor[
              0.9109275911598707, 0.6797574216785305, 0.24693978200204209`], 
             UndirectedEdge[69, 259] -> 
             RGBColor[
              0.9905868347080544, 0.9825227897859357, 0.5936915638047261], 
             UndirectedEdge[68, 95] -> 
             RGBColor[
              0.8055889997363144, 0.8452775049872518, 0.8120567039740567], 
             UndirectedEdge[247, 278] -> 
             RGBColor[
              0.9183501488101815, 0.9190642178161327, 0.6854398465020967], 
             UndirectedEdge[293, 440] -> 
             RGBColor[
              0.9935933982105543, 0.9914161377081201, 0.7411119246438247], 
             UndirectedEdge[307, 442] -> 
             RGBColor[
              0.8934622120068924, 0.8713664106399946, 0.6420908347591916], 
             UndirectedEdge[406, 493] -> 
             RGBColor[
              0.9936651513276926, 0.9914577674346313, 0.7407920078844752], 
             UndirectedEdge[155, 479] -> 
             RGBColor[
              0.9372258791427828, 0.7888285595765239, 0.26834867274152935`], 
             UndirectedEdge[311, 488] -> 
             RGBColor[
              0.6360707277067965, 0.7089389625771115, 0.9680830324146962], 
             UndirectedEdge[226, 345] -> 
             RGBColor[
              0.9330707498260302, 0.7518092681516114, 0.4810608140239263], 
             UndirectedEdge[183, 273] -> 
             RGBColor[
              0.8859851666934708, 0.9077040654928313, 0.7576831575639054], 
             UndirectedEdge[384, 499] -> 
             RGBColor[
              0.922829757441749, 0.9408033629204882, 0.9751643898903433], 
             UndirectedEdge[20, 325] -> 
             RGBColor[
              0.9626524497432969, 0.969526275186111, 0.8482197213448237], 
             UndirectedEdge[252, 424] -> 
             RGBColor[
              0.9423173661904355, 0.9348290992454265, 0.6828035640882277], 
             UndirectedEdge[285, 473] -> 
             RGBColor[
              0.9566017026892919, 0.8597893230183884, 0.3144470637148765], 
             UndirectedEdge[71, 236] -> 
             RGBColor[
              0.9755842662461357, 0.9788017706291956, 0.7907698867112564], 
             UndirectedEdge[2, 446] -> 
             RGBColor[
              0.9190948963430631, 0.937630989011342, 0.9680717548395132], 
             UndirectedEdge[33, 351] -> 
             RGBColor[
              0.9636775977243199, 0.9664014002957719, 0.7054890071026478], 
             UndirectedEdge[172, 466] -> 
             RGBColor[
              0.9876073493056234, 0.9891433347083489, 0.8550418233651458], 
             UndirectedEdge[12, 279] -> 
             RGBColor[
              0.9203622859934222, 0.9103894552632208, 0.6705097369838946], 
             UndirectedEdge[171, 219] -> 
             RGBColor[
              0.9579721757919634, 0.9665820919131347, 0.8876911921267354], 
             UndirectedEdge[153, 223] -> 
             RGBColor[
              0.9261976014927262, 0.9414642531841173, 0.894141769058828], 
             UndirectedEdge[121, 489] -> 
             RGBColor[
              0.7371284514641252, 0.788652133856766, 0.7209361162205513], 
             UndirectedEdge[362, 470] -> 
             RGBColor[
              0.9006670613824108, 0.8672869136241973, 0.6333644265984686], 
             UndirectedEdge[168, 232] -> 
             RGBColor[
              0.9900736690119196, 0.9901632212884277, 0.8141685232010173], 
             UndirectedEdge[285, 409] -> 
             RGBColor[
              0.9510021458005169, 0.8375889458961141, 0.3099415288036749], 
             UndirectedEdge[159, 439] -> 
             RGBColor[
              0.8413952371807174, 0.8727660645884464, 0.7449082530068002], 
             UndirectedEdge[156, 263] -> 
             RGBColor[
              0.9916417140468241, 0.9830976538326976, 0.4534944415053149], 
             UndirectedEdge[149, 314] -> 
             RGBColor[
              0.9883407503779679, 0.9879514358737034, 0.7402867299104485], 
             UndirectedEdge[110, 457] -> 
             RGBColor[
              0.9634603287021868, 0.8819419905170427, 0.3511741141441074], 
             UndirectedEdge[43, 263] -> 
             RGBColor[
              0.9417750984751225, 0.7936183748503638, 0.3245460315070031], 
             UndirectedEdge[141, 160] -> 
             RGBColor[
              0.947632926362219, 0.8173940392619587, 0.49093995531474444`], 
             UndirectedEdge[345, 389] -> 
             RGBColor[
              0.9927099509324728, 0.9870830004944458, 0.5839575916175518], 
             UndirectedEdge[225, 247] -> 
             RGBColor[
              0.9011639914071687, 0.8586500010973632, 0.6313890579403961], 
             UndirectedEdge[171, 293] -> 
             RGBColor[
              0.9595116706637747, 0.9670161305489846, 0.8474522010471661], 
             UndirectedEdge[179, 415] -> 
             RGBColor[
              0.8936922858360828, 0.9166025785145413, 0.9303411439937708], 
             UndirectedEdge[143, 414] -> 
             RGBColor[
              0.9939174420751702, 0.9904755117600494, 0.6576276832702515], 
             UndirectedEdge[77, 388] -> 
             RGBColor[
              0.9943334515673703, 0.9902881508155628, 0.6246093568706191], 
             UndirectedEdge[305, 406] -> 
             RGBColor[
              0.9874599798850113, 0.9721050039759358, 0.5824417015194752], 
             UndirectedEdge[55, 256] -> 
             RGBColor[
              0.9620186544795759, 0.8870960199147473, 0.5598475631012241], 
             UndirectedEdge[367, 450] -> 
             RGBColor[
              0.9566210305480498, 0.9638993166409074, 0.7813615725990162], 
             UndirectedEdge[171, 258] -> 
             RGBColor[
              0.9201227713757444, 0.8239802670573746, 0.6220487215107713], 
             UndirectedEdge[366, 423] -> 
             RGBColor[
              0.9243836274726334, 0.9406573818235411, 0.921739884631619], 
             UndirectedEdge[309, 393] -> 
             RGBColor[
              0.9762211109985306, 0.9300026468601742, 0.48522745597878414`], 
             UndirectedEdge[324, 360] -> 
             RGBColor[
              0.9216086309264866, 0.9354586644061635, 0.7356490734349659], 
             UndirectedEdge[125, 310] -> 
             RGBColor[
              0.9276314111182227, 0.9280152644574529, 0.6886059724653765], 
             UndirectedEdge[33, 463] -> 
             RGBColor[
              0.9806873321880976, 0.9790872324079734, 0.6766959635047335], 
             UndirectedEdge[137, 280] -> 
             RGBColor[
              0.9385350883934775, 0.7804419711001535, 0.3178301287392921], 
             UndirectedEdge[72, 179] -> 
             RGBColor[
              0.8975770756472474, 0.9169992780272025, 0.7780232761246757], 
             UndirectedEdge[17, 165] -> 
             RGBColor[
              0.8692196004218996, 0.8968826504625391, 0.9006192001249083], 
             UndirectedEdge[402, 417] -> 
             RGBColor[
              0.8957377098390178, 0.8514716469650954, 0.6302329476370745], 
             UndirectedEdge[102, 225] -> 
             RGBColor[
              0.9707544049144259, 0.9097673573291498, 0.42173371778471186`], 
             UndirectedEdge[83, 231] -> 
             RGBColor[
              0.9456461630726399, 0.9588139634016923, 0.9710104052911888], 
             UndirectedEdge[194, 377] -> 
             RGBColor[
              0.9765992602280829, 0.9327259513736459, 0.3635929741553523], 
             UndirectedEdge[131, 495] -> 
             RGBColor[
              0.9857501801110398, 0.9876444149556971, 0.8530872695375332], 
             UndirectedEdge[213, 447] -> 
             RGBColor[
              0.631326297458315, 0.6957960168064427, 0.845209758996403], 
             UndirectedEdge[146, 166] -> 
             RGBColor[
              0.868774101009765, 0.6432266961728896, 0.5915710881776031], 
             UndirectedEdge[422, 428] -> 
             RGBColor[
              0.9797224651289603, 0.9775688421059643, 0.676633543210337], 
             UndirectedEdge[232, 338] -> 
             RGBColor[
              0.9779803258925048, 0.9383548159887467, 0.5333595097714834], 
             UndirectedEdge[366, 469] -> 
             RGBColor[
              0.8278408328404233, 0.865768508896904, 0.9833865442423049], 
             UndirectedEdge[245, 482] -> 
             RGBColor[
              0.9893955817845695, 0.9750364256567523, 0.4859667387622547], 
             UndirectedEdge[40, 243] -> 
             RGBColor[
              0.9440803823996303, 0.9224199237115153, 0.6626481114740541], 
             UndirectedEdge[174, 320] -> 
             RGBColor[
              0.9529934686359627, 0.963952594619472, 0.945420621518007], 
             UndirectedEdge[30, 31] -> 
             RGBColor[
              0.9868865796952773, 0.9888452779515366, 0.8669868411005386], 
             UndirectedEdge[77, 354] -> 
             RGBColor[
              0.9745975014674473, 0.9779128279434406, 0.7802991260396542], 
             UndirectedEdge[24, 223] -> 
             RGBColor[
              0.9705865441318577, 0.9156540289686839, 0.5402641019011563], 
             UndirectedEdge[261, 391] -> 
             RGBColor[
              0.8962642451807461, 0.9192550629257669, 0.9599521363121862], 
             UndirectedEdge[125, 323] -> 
             RGBColor[
              0.8797748344573506, 0.7415611400103019, 0.6077748788415522], 
             UndirectedEdge[1, 364] -> 
             RGBColor[
              0.9902871739243837, 0.988310728627886, 0.6695557996449304], 
             UndirectedEdge[88, 133] -> 
             RGBColor[
              0.9473958156330666, 0.8147829125470338, 0.4677856386005401], 
             UndirectedEdge[178, 407] -> 
             RGBColor[
              0.9909092316033277, 0.9905087478929542, 0.8003210886947172], 
             UndirectedEdge[103, 486] -> 
             RGBColor[
              0.976659359814422, 0.9808146392425353, 0.8662429667353317], 
             UndirectedEdge[204, 486] -> 
             RGBColor[
              0.9930975487406167, 0.9904690715592066, 0.695392438155609], 
             UndirectedEdge[89, 407] -> 
             RGBColor[
              0.9927039284588843, 0.9907869005100265, 0.7368503679434528], 
             UndirectedEdge[38, 301] -> 
             RGBColor[
              0.9507162831727404, 0.959070728564863, 0.7710462377250858], 
             UndirectedEdge[92, 132] -> 
             RGBColor[
              0.9411077721316246, 0.7871431277216159, 0.48287308762018816`], 
             UndirectedEdge[8, 146] -> 
             RGBColor[
              0.8952378516908602, 0.6641599077524991, 0.5882613755273152], 
             UndirectedEdge[44, 110] -> 
             RGBColor[
              0.9531464599738941, 0.8410509379023747, 0.3428753332677087], 
             UndirectedEdge[102, 252] -> 
             RGBColor[
              0.9494770309718252, 0.9581790773847985, 0.7787502249737841], 
             UndirectedEdge[273, 283] -> 
             RGBColor[
              0.993913145308857, 0.989389158228084, 0.5788616144610017], 
             UndirectedEdge[158, 428] -> 
             RGBColor[
              0.9816971542450095, 0.983225645056325, 0.7697021648559516], 
             UndirectedEdge[176, 328] -> 
             RGBColor[
              0.9941150314704905, 0.9902995882176562, 0.6356260009275854], 
             UndirectedEdge[45, 398] -> 
             RGBColor[
              0.9423739870470842, 0.8420185061247095, 0.5957493937514636], 
             UndirectedEdge[233, 275] -> 
             RGBColor[
              0.9697274624834669, 0.9086284158433124, 0.3416749023721015], 
             UndirectedEdge[250, 485] -> 
             RGBColor[
              0.9706699800424199, 0.9776462996559125, 0.93453225268055], 
             UndirectedEdge[29, 65] -> 
             RGBColor[
              0.9670674439975859, 0.8983501195063792, 0.5210305536104092], 
             UndirectedEdge[166, 453] -> 
             RGBColor[
              0.8835318731878373, 0.7262079505796589, 0.6045106667750322], 
             UndirectedEdge[222, 294] -> 
             RGBColor[
              0.991785915228079, 0.9908712791015303, 0.7857921722480931], 
             UndirectedEdge[150, 220] -> 
             RGBColor[
              0.902587525240047, 0.6401637303759458, 0.23989147687718243`], 
             UndirectedEdge[311, 423] -> 
             RGBColor[
              0.9580971003570784, 0.9675395899737549, 0.9249555057717099], 
             UndirectedEdge[210, 424] -> 
             RGBColor[
              0.853179985805534, 0.8645059126029242, 0.6741018599551157], 
             UndirectedEdge[179, 312] -> 
             RGBColor[
              0.8965587646008248, 0.917787941148906, 0.8828361726527506], 
             UndirectedEdge[310, 323] -> 
             RGBColor[
              0.9354270819969048, 0.7688198724012416, 0.30872950618816486`], 
             UndirectedEdge[108, 349] -> 
             RGBColor[
              0.9907775956165601, 0.9886675269334351, 0.6726221507449224], 
             UndirectedEdge[355, 395] -> 
             RGBColor[
              0.6485702363708445, 0.7242828377784751, 0.9663621809583836], 
             UndirectedEdge[47, 200] -> 
             RGBColor[
              0.9689778967451443, 0.91314316947818, 0.5578920553772151], 
             UndirectedEdge[152, 217] -> 
             RGBColor[
              0.971835135961461, 0.9750687242690361, 0.7227731214944033], 
             UndirectedEdge[174, 210] -> 
             RGBColor[
              0.8239403765529554, 0.86320424817703, 0.9828696615093986], 
             UndirectedEdge[135, 211] -> 
             RGBColor[
              0.989836084245518, 0.9900649738818708, 0.8181059176299565], 
             UndirectedEdge[52, 491] -> 
             RGBColor[
              0.9831476675122417, 0.9535065596260863, 0.5003153099730169], 
             UndirectedEdge[41, 250] -> 
             RGBColor[
              0.9777641226352605, 0.9807051057000193, 0.8091064695567636], 
             UndirectedEdge[220, 392] -> 
             RGBColor[
              0.8941112418608248, 0.8412952738184598, 0.6280894603265383], 
             UndirectedEdge[182, 359] -> 
             RGBColor[
              0.587037408948282, 0.6488277561259532, 0.8317888723530431], 
             UndirectedEdge[89, 391] -> 
             RGBColor[
              0.9090007288924351, 0.9265368163742005, 0.8261574845047306], 
             UndirectedEdge[62, 190] -> 
             RGBColor[
              0.979122262196032, 0.9446106507860377, 0.5544107998675568], 
             UndirectedEdge[21, 87] -> 
             RGBColor[
              0.9937288412357376, 0.9898256987124427, 0.6191878822276878], 
             UndirectedEdge[185, 286] -> 
             RGBColor[
              0.97935900970972, 0.9488833258437697, 0.5793431623342133], 
             UndirectedEdge[114, 294] -> 
             RGBColor[
              0.9793653818448738, 0.9834073881315508, 0.8873942328259659], 
             UndirectedEdge[48, 156] -> 
             RGBColor[
              0.9897594803256515, 0.9881531185876641, 0.6827063791280779], 
             UndirectedEdge[68, 450] -> 
             RGBColor[
              0.7679570151787629, 0.8190607162709462, 0.9775639321696891], 
             UndirectedEdge[149, 406] -> 
             RGBColor[
              0.9875746350837756, 0.9889118359817841, 0.8458228158849268], 
             UndirectedEdge[123, 158] -> 
             RGBColor[
              0.9761276650055355, 0.9301308628350433, 0.44715824308755403`], 
             UndirectedEdge[55, 91] -> 
             RGBColor[
              0.8898718589004826, 0.9133104569944694, 0.9160136048306144], 
             UndirectedEdge[135, 169] -> 
             RGBColor[
              0.9643825412367975, 0.8983683769951586, 0.5710487261858759], 
             UndirectedEdge[141, 456] -> 
             RGBColor[
              0.9475960730786164, 0.8165336324755003, 0.43011599025376357`], 
             UndirectedEdge[287, 354] -> 
             RGBColor[
              0.9640167219754512, 0.9432097945021166, 0.6551466705276938], 
             UndirectedEdge[223, 411] -> 
             RGBColor[
              0.9661852634687915, 0.9731987059344381, 0.8927336175842908], 
             UndirectedEdge[127, 301] -> 
             RGBColor[
              0.872386669758878, 0.9010814664331517, 0.9876902134220173], 
             UndirectedEdge[167, 201] -> 
             RGBColor[
              0.9644943745622219, 0.8855926303477119, 0.3785759964664813], 
             UndirectedEdge[28, 218] -> 
             RGBColor[
              0.9939761115037623, 0.9904997730765079, 0.6566553790068668], 
             UndirectedEdge[112, 317] -> 
             RGBColor[
              0.8608124205615131, 0.8888670979135663, 0.8215066149766497], 
             UndirectedEdge[275, 372] -> 
             RGBColor[
              0.9527280766016876, 0.9074911611026806, 0.6230284818589136], 
             UndirectedEdge[85, 146] -> 
             RGBColor[
              0.8872927617983284, 0.5587670212223683, 0.2267119199084686], 
             UndirectedEdge[7, 262] -> 
             RGBColor[
              0.8645561985851443, 0.892029778420637, 0.8409433619103777], 
             UndirectedEdge[448, 455] -> 
             RGBColor[
              0.9494574496160091, 0.9618159769459383, 0.9700910157506453], 
             UndirectedEdge[9, 368] -> 
             RGBColor[
              0.9881406289501852, 0.9893638595460369, 0.8462039995712778], 
             UndirectedEdge[216, 399] -> 
             RGBColor[
              0.8081089492198849, 0.8147701615342109, 0.6483973891581352], 
             UndirectedEdge[205, 474] -> 
             RGBColor[
              0.782378987989764, 0.7099644424704568, 0.6073095899682348], 
             UndirectedEdge[125, 242] -> 
             RGBColor[
              0.9318328858547484, 0.9457933725656272, 0.8875446464834126], 
             UndirectedEdge[280, 338] -> 
             RGBColor[
              0.9750216918330874, 0.9274044427466527, 0.35746441883958924`], 
             UndirectedEdge[232, 393] -> 
             RGBColor[
              0.9755304483565956, 0.9300908038015246, 0.5238421981650289], 
             UndirectedEdge[403, 483] -> 
             RGBColor[
              0.9918626164166049, 0.9909029970141163, 0.784521035057907], 
             UndirectedEdge[427, 433] -> 
             RGBColor[
              0.9598238876306797, 0.8674444859515633, 0.5044986220635804], 
             UndirectedEdge[269, 310] -> 
             RGBColor[
              0.98483719808906, 0.9719571156590157, 0.6323824144748011], 
             UndirectedEdge[212, 357] -> 
             RGBColor[
              0.9487782492392969, 0.9569581999410134, 0.7248828857287324], 
             UndirectedEdge[88, 307] -> 
             RGBColor[
              0.9107367679915546, 0.9280946689583126, 0.8403941995071028], 
             UndirectedEdge[212, 217] -> 
             RGBColor[
              0.9277179315114261, 0.9448145054517236, 0.9795638450828029], 
             UndirectedEdge[67, 124] -> 
             RGBColor[
              0.9765655744956103, 0.9312423595627883, 0.47995378495791235`], 
             UndirectedEdge[364, 380] -> 
             RGBColor[
              0.991242635282803, 0.9903543638615829, 0.7735518720848575], 
             UndirectedEdge[82, 384] -> 
             RGBColor[
              0.649267980310924, 0.7189620411839183, 0.9520046678834622], 
             UndirectedEdge[222, 439] -> 
             RGBColor[
              0.9941980114602282, 0.9902224138388552, 0.6261467535039998], 
             UndirectedEdge[337, 420] -> 
             RGBColor[
              0.9928063797219766, 0.9902134344944815, 0.6903879821711447], 
             UndirectedEdge[61, 99] -> 
             RGBColor[
              0.9674773454155816, 0.8958186882544896, 0.47568092862057537`], 
             UndirectedEdge[63, 439] -> 
             RGBColor[
              0.9941428483676615, 0.9898804698443253, 0.6038633748489213], 
             UndirectedEdge[37, 53] -> 
             RGBColor[
              0.9732151057056324, 0.9784041050836698, 0.8791570342663262], 
             UndirectedEdge[39, 62] -> 
             RGBColor[
              0.9925224445275327, 0.9893813173612107, 0.6431421864680742], 
             UndirectedEdge[130, 182] -> 
             RGBColor[
              0.9920891504937486, 0.9909966746766755, 0.7807667791482374], 
             UndirectedEdge[152, 398] -> 
             RGBColor[
              0.9549787089952414, 0.8479725403517779, 0.36462606119468544`], 
             UndirectedEdge[23, 110] -> 
             RGBColor[
              0.9819718595823903, 0.9823672234351385, 0.6848691379855132], 
             UndirectedEdge[322, 440] -> 
             RGBColor[
              0.9930826517595803, 0.9903237026938743, 0.6855203254170359], 
             UndirectedEdge[141, 432] -> 
             RGBColor[
              0.9034726484824014, 0.6540469786310403, 0.24114030561400673`], 
             UndirectedEdge[161, 459] -> 
             RGBColor[
              0.9474204680781293, 0.8766667001695548, 0.6111688198665793], 
             UndirectedEdge[185, 333] -> 
             RGBColor[
              0.962694322341504, 0.8867344499387009, 0.5455134356842576], 
             UndirectedEdge[297, 474] -> 
             RGBColor[
              0.9540115536402927, 0.8420628938537686, 0.4866470025536147], 
             UndirectedEdge[265, 329] -> 
             RGBColor[
              0.9565034741444106, 0.963532361550548, 0.759202358113136], 
             UndirectedEdge[90, 280] -> 
             RGBColor[
              0.9855847948512801, 0.9630362695615514, 0.3985000793906422], 
             UndirectedEdge[183, 430] -> 
             RGBColor[
              0.8863837798486994, 0.9085566587258931, 0.8010697395552908], 
             UndirectedEdge[86, 194] -> 
             RGBColor[
              0.9916477320027856, 0.9829152916020231, 0.47075075154787527`], 
             UndirectedEdge[143, 186] -> 
             RGBColor[
              0.9934201993084132, 0.9883347965776208, 0.5252074844227775], 
             UndirectedEdge[1, 416] -> 
             RGBColor[
              0.993024161925345, 0.9874877126607596, 0.48210125933522535`], 
             UndirectedEdge[27, 86] -> 
             RGBColor[
              0.8967889433773859, 0.9160789496893484, 0.753545136926935], 
             UndirectedEdge[66, 415] -> 
             RGBColor[
              0.9850262193526207, 0.9730100279106042, 0.6359872586050954], 
             UndirectedEdge[413, 490] -> 
             RGBColor[
              0.7021111226637275, 0.7654889723103029, 0.972512759688123], 
             UndirectedEdge[226, 284] -> 
             RGBColor[
              0.9323299562498839, 0.7492180152410206, 0.32724842796752956`], 
             UndirectedEdge[245, 438] -> 
             RGBColor[
              0.9369258709396414, 0.9482290198202296, 0.7822463825632766], 
             UndirectedEdge[53, 163] -> 
             RGBColor[
              0.9226140529835958, 0.9406240466281064, 0.9748900471772073], 
             UndirectedEdge[367, 368] -> 
             RGBColor[
              0.9918474220572924, 0.9896499301991843, 0.6941448420446773], 
             UndirectedEdge[112, 175] -> 
             RGBColor[
              0.9392915537607004, 0.9506916875605929, 0.8291917259784587], 
             UndirectedEdge[277, 288] -> 
             RGBColor[
              0.9836429486334396, 0.9859574611817707, 0.8514871320399073], 
             UndirectedEdge[249, 323] -> 
             RGBColor[
              0.9207340695734648, 0.7737516296263647, 0.5954109362431825], 
             UndirectedEdge[416, 452] -> 
             RGBColor[
              0.9931990697900417, 0.9895008239864104, 0.6202769779937125], 
             UndirectedEdge[13, 87] -> 
             RGBColor[
              0.943462209055286, 0.7991601851923478, 0.3638241486477757], 
             UndirectedEdge[471, 497] -> 
             RGBColor[
              0.9860723030093379, 0.9638050218731888, 0.4748594745773258], 
             UndirectedEdge[17, 321] -> 
             RGBColor[
              0.9907296107960941, 0.9904344700731189, 0.8032978703143242], 
             UndirectedEdge[106, 227] -> 
             RGBColor[
              0.9488039950836868, 0.9613386838759537, 0.9715456616534442], 
             UndirectedEdge[37, 100] -> 
             RGBColor[
              0.9871849845889084, 0.9729729714356863, 0.5937844559407814], 
             UndirectedEdge[9, 375] -> 
             RGBColor[
              0.9708030190209298, 0.9773748397983768, 0.9177072397279137], 
             UndirectedEdge[10, 302] -> 
             RGBColor[
              0.9662623833839025, 0.9731204926632402, 0.8865248437995223], 
             UndirectedEdge[14, 272] -> 
             RGBColor[
              0.9373107716149096, 0.7705783420690667, 0.38790316112942824`], 
             UndirectedEdge[63, 387] -> 
             RGBColor[
              0.9605720419367557, 0.8683836511318626, 0.4735456400069], 
             UndirectedEdge[471, 483] -> 
             RGBColor[
              0.9929802846746685, 0.9901918800430098, 0.6807117451888017], 
             UndirectedEdge[46, 392] -> 
             RGBColor[
              0.8908070007421812, 0.8281950588561182, 0.6254307903619702], 
             UndirectedEdge[122, 357] -> 
             RGBColor[
              0.9827639994843789, 0.9533304702208374, 0.4037485782606759], 
             UndirectedEdge[75, 125] -> 
             RGBColor[
              0.9083072357368112, 0.8594805037998154, 0.6309809090779681], 
             UndirectedEdge[244, 261] -> 
             RGBColor[
              0.9761691964687984, 0.981747606262565, 0.9252235136960429], 
             UndirectedEdge[7, 178] -> 
             RGBColor[
              0.8625848607742981, 0.8913738086613405, 0.8851878047799853], 
             UndirectedEdge[108, 487] -> 
             RGBColor[
              0.932049284575919, 0.9438866062698889, 0.7449821083779313], 
             UndirectedEdge[338, 480] -> 
             RGBColor[
              0.9346502181626837, 0.776685827965655, 0.2763334064210643], 
             UndirectedEdge[237, 284] -> 
             RGBColor[
              0.9420776118064451, 0.7934798425005685, 0.33538211070082613`], 
             UndirectedEdge[162, 456] -> 
             RGBColor[
              0.9858772609414086, 0.9629123509989872, 0.4940630638341176], 
             UndirectedEdge[104, 310] -> 
             RGBColor[
              0.9602722770022463, 0.872120692002526, 0.3289687237065694], 
             UndirectedEdge[168, 390] -> 
             RGBColor[
              0.9883032220298917, 0.9894310959629472, 0.8435094114631364], 
             UndirectedEdge[164, 431] -> 
             RGBColor[
              0.9358351744702171, 0.9476748220059441, 0.8077173126090219], 
             UndirectedEdge[57, 60] -> 
             RGBColor[
              0.7903027589751057, 0.836382524989258, 0.9796612755161677], 
             UndirectedEdge[158, 247] -> 
             RGBColor[
              0.9243753483030388, 0.9383843433725311, 0.794243936086909], 
             UndirectedEdge[32, 475] -> 
             RGBColor[
              0.9339818991975629, 0.9033766731648201, 0.6455157173374336], 
             UndirectedEdge[53, 293] -> 
             RGBColor[
              0.9752107363465334, 0.9790267675821929, 0.8313586930514111], 
             UndirectedEdge[72, 294] -> 
             RGBColor[
              0.9912145575649269, 0.9894252471157952, 0.7073242001684172], 
             UndirectedEdge[87, 287] -> 
             RGBColor[
              0.9830408216566269, 0.954062541307656, 0.42197637630957263`], 
             UndirectedEdge[154, 374] -> 
             RGBColor[
              0.9304987145093814, 0.7467984768601668, 0.5070384693128915], 
             UndirectedEdge[119, 364] -> 
             RGBColor[
              0.9631685753394797, 0.9714952003426998, 0.922306102540883], 
             UndirectedEdge[90, 342] -> 
             RGBColor[
              0.8552487335133643, 0.8714842843864967, 0.6821385541498122], 
             UndirectedEdge[401, 428] -> 
             RGBColor[
              0.9767996547122061, 0.9677095162617307, 0.6652789766676801], 
             UndirectedEdge[183, 477] -> 
             RGBColor[
              0.8153729288774956, 0.8559560135028068, 0.9821630924812673], 
             UndirectedEdge[82, 269] -> 
             RGBColor[
              0.6649181184869928, 0.7302685984244155, 0.9091546252796183], 
             UndirectedEdge[202, 273] -> 
             RGBColor[
              0.9941810193424082, 0.989962113699631, 0.6080180498861519], 
             UndirectedEdge[147, 242] -> 
             RGBColor[
              0.9627618437520877, 0.9704552840487686, 0.8904946780982674], 
             UndirectedEdge[117, 198] -> 
             RGBColor[
              0.9353278726157641, 0.9387060696443104, 0.69603938594984], 
             UndirectedEdge[240, 434] -> 
             RGBColor[
              0.9601044251100501, 0.8675089917608372, 0.41522049056678134`], 
             UndirectedEdge[249, 310] -> 
             RGBColor[
              0.9685906462343368, 0.9602057540735156, 0.6762420298670067], 
             UndirectedEdge[448, 478] -> 
             RGBColor[
              0.9761924630161888, 0.9810028558396652, 0.8910556190868992], 
             UndirectedEdge[121, 196] -> 
             RGBColor[
              0.7248840606164056, 0.7477129453929809, 0.6424155930485196], 
             UndirectedEdge[200, 256] -> 
             RGBColor[
              0.9427786303165722, 0.8108433676359599, 0.27281654667578215`], 
             UndirectedEdge[79, 184] -> 
             RGBColor[
              0.9667206202732768, 0.8939274620166539, 0.40945108551507176`], 
             UndirectedEdge[51, 240] -> 
             RGBColor[
              0.9679662045184586, 0.9727824862485721, 0.776866544475115], 
             UndirectedEdge[339, 387] -> 
             RGBColor[
              0.9398217839902476, 0.7991204572627116, 0.27043739871551786`], 
             UndirectedEdge[46, 142] -> 
             RGBColor[
              0.9222159308353244, 0.7293191163062162, 0.2562713160045787], 
             UndirectedEdge[233, 259] -> 
             RGBColor[
              0.9877053602321726, 0.9701894345237307, 0.4067380754602387], 
             UndirectedEdge[266, 471] -> 
             RGBColor[
              0.9158681774684503, 0.931461232147068, 0.7821060242803504], 
             UndirectedEdge[167, 456] -> 
             RGBColor[
              0.9650977341400429, 0.88688315547566, 0.4442479630085998], 
             UndirectedEdge[10, 181] -> 
             RGBColor[
              0.9597703981458485, 0.9695174093238768, 0.9529824017652008], 
             UndirectedEdge[31, 429] -> 
             RGBColor[
              0.9872524764868973, 0.9889965856779902, 0.8609229843528536], 
             UndirectedEdge[317, 322] -> 
             RGBColor[
              0.860451854297887, 0.8880958831345112, 0.7822612023379782], 
             UndirectedEdge[52, 466] -> 
             RGBColor[
              0.9925390270824115, 0.9906146345664556, 0.7320180576463119], 
             UndirectedEdge[207, 281] -> 
             RGBColor[
              0.9073254000917113, 0.9277746009093208, 0.9505946440812075], 
             UndirectedEdge[358, 398] -> 
             RGBColor[
              0.9529229487980538, 0.8491091230864786, 0.5431068931867811], 
             UndirectedEdge[155, 250] -> 
             RGBColor[
              0.9457878145502558, 0.866761540569666, 0.6071922471836215], 
             UndirectedEdge[243, 285] -> 
             RGBColor[
              0.9722638745566579, 0.9181016775069661, 0.3467508194907538], 
             UndirectedEdge[378, 452] -> 
             RGBColor[
              0.9928200503321991, 0.9885389216672889, 0.5918815382480319], 
             UndirectedEdge[100, 264] -> 
             RGBColor[
              0.9352980157832212, 0.9341675584002821, 0.6893948170276532], 
             UndirectedEdge[81, 130] -> 
             RGBColor[
              0.9861446224488462, 0.9883834147924815, 0.8723397712120209], 
             UndirectedEdge[1, 120] -> 
             RGBColor[
              0.9784149700371826, 0.9800130223759439, 0.7145764156813319], 
             UndirectedEdge[390, 422] -> 
             RGBColor[
              0.9900536989650841, 0.9843211463909829, 0.6164810247596982], 
             UndirectedEdge[118, 255] -> 
             RGBColor[
              0.9882723733280401, 0.989418339231956, 0.8440206542867013], 
             UndirectedEdge[137, 229] -> 
             RGBColor[
              0.9297205898844725, 0.7507085978866084, 0.28358746651017974`], 
             UndirectedEdge[367, 375] -> 
             RGBColor[
              0.9745098121280371, 0.9776609104515243, 0.7656480822013132], 
             UndirectedEdge[230, 382] -> 
             RGBColor[
              0.9928620002801803, 0.9896461611797917, 0.6465595283042865], 
             UndirectedEdge[114, 334] -> 
             RGBColor[
              0.9755372034109805, 0.9622459333383948, 0.6578165236185323], 
             UndirectedEdge[52, 170] -> 
             RGBColor[
              0.9934577903341633, 0.9909945667821936, 0.716791772881707], 
             UndirectedEdge[4, 389] -> 
             RGBColor[
              0.9911238717658777, 0.9817208766315968, 0.4200183472369485], 
             UndirectedEdge[190, 378] -> 
             RGBColor[
              0.9793297226072768, 0.9419364421217219, 0.3742003048939666], 
             UndirectedEdge[89, 328] -> 
             RGBColor[
              0.9941235022462482, 0.9898390904468153, 0.6017576689235036], 
             UndirectedEdge[93, 300] -> 
             RGBColor[
              0.8851033899235885, 0.8112102469864266, 0.6221018156745322], 
             UndirectedEdge[104, 125] -> 
             RGBColor[
              0.904620029462692, 0.8448619596115863, 0.6280140963599568], 
             UndirectedEdge[59, 228] -> 
             RGBColor[
              0.9767467922142932, 0.9332236114052912, 0.3641661080627017], 
             UndirectedEdge[96, 136] -> 
             RGBColor[
              0.9716372295767118, 0.9746757668983917, 0.703639929213518], 
             UndirectedEdge[332, 420] -> 
             RGBColor[
              0.9491728374028843, 0.9580901384195297, 0.7911738806890548], 
             UndirectedEdge[40, 283] -> 
             RGBColor[
              0.9568523725153633, 0.9643941337167301, 0.8065417180639542], 
             UndirectedEdge[17, 288] -> 
             RGBColor[
              0.9821331804007103, 0.9853331332182633, 0.8765078988111719], 
             UndirectedEdge[325, 413] -> 
             RGBColor[
              0.7319844196399166, 0.7857784544227803, 0.8272819786685984], 
             UndirectedEdge[421, 459] -> 
             RGBColor[
              0.9546450604491237, 0.8528155876777815, 0.30879118505437625`], 
             UndirectedEdge[148, 342] -> 
             RGBColor[
              0.7940735193167578, 0.8393892269311287, 0.980020934003752], 
             UndirectedEdge[262, 478] -> 
             RGBColor[
              0.9919383192498359, 0.9907750729945721, 0.7716921695134491], 
             UndirectedEdge[133, 405] -> 
             RGBColor[
              0.9429082145295181, 0.8131679261109777, 0.559656927418535], 
             UndirectedEdge[374, 397] -> 
             RGBColor[
              0.9319910548116922, 0.7461960539893748, 0.39365855837699504`], 
             UndirectedEdge[151, 389] -> 
             RGBColor[
              0.9921192445829787, 0.9848127689855177, 0.4464812739512585], 
             UndirectedEdge[235, 305] -> 
             RGBColor[
              0.9882450122036541, 0.9711850654703501, 0.4789646169140946], 
             UndirectedEdge[204, 348] -> 
             RGBColor[
              0.9905436361331639, 0.9894129630634645, 0.737717379375065], 
             UndirectedEdge[191, 429] -> 
             RGBColor[
              0.9672966114717789, 0.974182508006578, 0.8977918453858957], 
             UndirectedEdge[15, 414] -> 
             RGBColor[
              0.9764680635067153, 0.9324160524463172, 0.5216955594223636], 
             UndirectedEdge[277, 414] -> 
             RGBColor[
              0.9932179271526245, 0.9914634528333577, 0.7620600287303092], 
             UndirectedEdge[317, 440] -> 
             RGBColor[
              0.8595088259041492, 0.8887897269470171, 0.8766711899589745], 
             UndirectedEdge[76, 182] -> 
             RGBColor[
              0.9723830891894509, 0.9151110653950811, 0.5041983494111724], 
             UndirectedEdge[199, 376] -> 
             RGBColor[
              0.8082358430273561, 0.8099583133581827, 0.6412385287063151], 
             UndirectedEdge[375, 402] -> 
             RGBColor[
              0.9003756921992805, 0.922896718142129, 0.9729400930141723], 
             UndirectedEdge[45, 195] -> 
             RGBColor[
              0.9624983921465095, 0.9715519427828896, 0.948364619496868], 
             UndirectedEdge[149, 269] -> 
             RGBColor[
              0.9846353697002249, 0.9876963742100111, 0.8945340498653396], 
             UndirectedEdge[45, 152] -> 
             RGBColor[
              0.9803743647767631, 0.9814372671377847, 0.7083184344976637], 
             UndirectedEdge[356, 494] -> 
             RGBColor[
              0.8913707364723769, 0.9132661109233792, 0.8610570155082586], 
             UndirectedEdge[44, 360] -> 
             RGBColor[
              0.953373334505067, 0.8415361995840196, 0.36756922587856145`], 
             UndirectedEdge[284, 432] -> 
             RGBColor[
              0.9493444271592546, 0.8259500664990131, 0.34141847456829305`], 
             UndirectedEdge[151, 237] -> 
             RGBColor[
              0.9422276990330973, 0.7938008639022314, 0.35171817909092956`], 
             UndirectedEdge[207, 343] -> 
             RGBColor[
              0.9093587545121676, 0.9291594580099198, 0.9412587035317104], 
             UndirectedEdge[33, 371] -> 
             RGBColor[
              0.88987846479188, 0.9078290303884996, 0.6991588566621535], 
             UndirectedEdge[280, 480] -> 
             RGBColor[
              0.9471786774478836, 0.8189472629567658, 0.325004104943052], 
             UndirectedEdge[420, 454] -> 
             RGBColor[
              0.686137760983023, 0.745839230631381, 0.7684672941182884], 
             UndirectedEdge[267, 393] -> 
             RGBColor[
              0.9763454519864596, 0.9302685996605521, 0.4987612051712319], 
             UndirectedEdge[337, 427] -> 
             RGBColor[
              0.9586400261486123, 0.8669549288048761, 0.5241182705567429], 
             UndirectedEdge[267, 480] -> 
             RGBColor[
              0.950952315137165, 0.8300754320578873, 0.47581820288114907`], 
             UndirectedEdge[234, 336] -> 
             RGBColor[
              0.9895717449249173, 0.9892187446298739, 0.7689205340795373], 
             UndirectedEdge[122, 492] -> 
             RGBColor[
              0.9173870731729389, 0.693073339472833, 0.277559030124482], 
             UndirectedEdge[80, 272] -> 
             RGBColor[
              0.8845426915507456, 0.5686171527189775, 0.2253719305233896], 
             UndirectedEdge[331, 444] -> 
             RGBColor[
              0.9128622369205899, 0.9283849053981503, 0.7267391651560225], 
             UndirectedEdge[77, 184] -> 
             RGBColor[
              0.993869262108908, 0.9892952965006656, 0.5740851989622866], 
             UndirectedEdge[266, 359] -> 
             RGBColor[
              0.5083707051449723, 0.5894542425858039, 0.9589468402254251], 
             UndirectedEdge[32, 478] -> 
             RGBColor[
              0.9482606890305272, 0.9594504547660071, 0.9133417390052005], 
             UndirectedEdge[14, 447] -> 
             RGBColor[
              0.6312475580573389, 0.6943810654432889, 0.7460294714720366], 
             UndirectedEdge[16, 358] -> 
             RGBColor[
              0.6835563988381619, 0.7458516039465164, 0.8897395977453364], 
             UndirectedEdge[50, 323] -> 
             RGBColor[
              0.6640572787058945, 0.5691822981497006, 0.5885952339490832], 
             UndirectedEdge[92, 365] -> 
             RGBColor[
              0.9851523604604715, 0.9867052482513463, 0.8320076229529247], 
             UndirectedEdge[296, 438] -> 
             RGBColor[
              0.8371884049356129, 0.8732220091525231, 0.9842781240134202], 
             UndirectedEdge[181, 422] -> 
             RGBColor[
              0.9844221986797138, 0.9810738956930087, 0.668678120195734], 
             UndirectedEdge[35, 428] -> 
             RGBColor[
              0.970252155834832, 0.9456232651225034, 0.6398431799204958], 
             UndirectedEdge[19, 298] -> 
             RGBColor[
              0.8906137162395609, 0.9130670808615262, 0.8787728265041025], 
             UndirectedEdge[209, 348] -> 
             RGBColor[
              0.9807463881020959, 0.9574038844978805, 0.6112789879367097], 
             UndirectedEdge[27, 194] -> 
             RGBColor[
              0.89500574546333, 0.9106364930273536, 0.6979204435462533], 
             UndirectedEdge[253, 287] -> 
             RGBColor[
              0.9818844069367476, 0.9505539922334327, 0.3841247711023058], 
             UndirectedEdge[412, 476] -> 
             RGBColor[
              0.9756534671528705, 0.9778554842044469, 0.7114739406149057], 
             UndirectedEdge[221, 336] -> 
             RGBColor[
              0.9784151549945403, 0.9809851842066102, 0.7917020407340591], 
             UndirectedEdge[146, 248] -> 
             RGBColor[
              0.7480428889779576, 0.5483503276508952, 0.5796863965696573], 
             UndirectedEdge[17, 455] -> 
             RGBColor[
              0.9623460588838706, 0.9705658781391546, 0.9096538164035473], 
             UndirectedEdge[102, 393] -> 
             RGBColor[
              0.9756973751037303, 0.9288824287390182, 0.42822203595305997`], 
             UndirectedEdge[80, 497] -> 
             RGBColor[
              0.9331830381020935, 0.7615846303974175, 0.2991380216681314], 
             UndirectedEdge[108, 416] -> 
             RGBColor[
              0.993113415852467, 0.9876786177859174, 0.4918159984910648], 
             UndirectedEdge[8, 453] -> 
             RGBColor[
              0.9099956238689325, 0.7471411621592683, 0.6012009541247443], 
             UndirectedEdge[58, 402] -> 
             RGBColor[
              0.831443763325348, 0.5069122035388947, 0.5746751374957599], 
             UndirectedEdge[95, 357] -> 
             RGBColor[
              0.9937405421783685, 0.9890199775848226, 0.5600748288903731], 
             UndirectedEdge[183, 283] -> 
             RGBColor[
              0.8863714718274499, 0.9085303331129722, 0.7997300873985819], 
             UndirectedEdge[179, 294] -> 
             RGBColor[
              0.8949119511789215, 0.9171069414777746, 0.9101281328702076], 
             UndirectedEdge[136, 240] -> 
             RGBColor[
              0.9722434771623188, 0.9759724691829719, 0.7696262375804311], 
             UndirectedEdge[153, 289] -> 
             RGBColor[
              0.9199315264186336, 0.9154548781537901, 0.6784258493609493], 
             UndirectedEdge[73, 200] -> 
             RGBColor[
              0.9478596395832124, 0.830987876232221, 0.276904845998337], 
             UndirectedEdge[196, 447] -> 
             RGBColor[
              0.6187097889005394, 0.6528143704414792, 0.6355765298777123], 
             UndirectedEdge[68, 492] -> 
             RGBColor[
              0.7392833519002491, 0.5830339328062237, 0.58478154928727], 
             UndirectedEdge[25, 413] -> 
             RGBColor[
              0.7005316892706891, 0.7642295749952714, 0.9723621119211181], 
             UndirectedEdge[220, 426] -> 
             RGBColor[
              0.733310184751206, 0.7136728862903784, 0.6133375678416044], 
             UndirectedEdge[21, 354] -> 
             RGBColor[
              0.9747047415545619, 0.9789729519069034, 0.852358176445809], 
             UndirectedEdge[125, 269] -> 
             RGBColor[
              0.9291849505495058, 0.944698383268076, 0.9314277871281884], 
             UndirectedEdge[241, 304] -> 
             RGBColor[
              0.8807138247471786, 0.7775719049045666, 0.6149343738186615], 
             UndirectedEdge[93, 456] -> 
             RGBColor[
              0.9600702044228724, 0.8669506754720429, 0.44020269458687467`], 
             UndirectedEdge[295, 455] -> 
             RGBColor[
              0.9396568994348856, 0.9545067426677846, 0.9866807908144215], 
             UndirectedEdge[185, 386] -> 
             RGBColor[
              0.988566951065591, 0.989540154696736, 0.8391387388327337], 
             UndirectedEdge[233, 400] -> 
             RGBColor[
              0.99022461493664, 0.9778529505535127, 0.4874866005958306], 
             UndirectedEdge[83, 317] -> 
             RGBColor[
              0.8279997852237683, 0.8664411104614232, 0.9832568515322977], 
             UndirectedEdge[88, 465] -> 
             RGBColor[
              0.9863053216166222, 0.963923900252202, 0.5324941665876033], 
             UndirectedEdge[418, 431] -> 
             RGBColor[
              0.9897177456076015, 0.975832874412276, 0.511902065180276], 
             UndirectedEdge[121, 307] -> 
             RGBColor[
              0.6538173464428869, 0.7270694756513361, 0.9678044221362405], 
             UndirectedEdge[64, 74] -> 
             RGBColor[
              0.8859131502556428, 0.885225611536244, 0.6702794554679183], 
             UndirectedEdge[185, 358] -> 
             RGBColor[
              0.9891815254518758, 0.9897942969993059, 0.8289536507844679], 
             UndirectedEdge[113, 315] -> 
             RGBColor[
              0.9902455514790267, 0.9895230910953217, 0.7596226714384655], 
             UndirectedEdge[47, 91] -> 
             RGBColor[
              0.8903066281644174, 0.9134902452581669, 0.9088083529804263], 
             UndirectedEdge[158, 401] -> 
             RGBColor[
              0.9892327513563968, 0.9743373963171026, 0.4980690288727508], 
             UndirectedEdge[90, 232] -> 
             RGBColor[
              0.9885434289106976, 0.9739866428036454, 0.5743951703225363], 
             UndirectedEdge[58, 115] -> 
             RGBColor[
              0.8865077965308136, 0.5503030860811541, 0.5620481455771273], 
             UndirectedEdge[132, 494] -> 
             RGBColor[
              0.9409659548428163, 0.7870844826281557, 0.48522336710711894`], 
             UndirectedEdge[167, 300] -> 
             RGBColor[
              0.890130919640759, 0.8311427269900438, 0.6261470840962573], 
             UndirectedEdge[284, 389] -> 
             RGBColor[
              0.9919691573563265, 0.9844917475838549, 0.43014520556115504`], 
             UndirectedEdge[103, 233] -> 
             RGBColor[
              0.9739523596955089, 0.9685534336107233, 0.6763979867707137], 
             UndirectedEdge[172, 300] -> 
             RGBColor[
              0.9145644138262841, 0.9333533126323128, 0.9436225709095045], 
             UndirectedEdge[70, 76] -> 
             RGBColor[
              0.9184399012529495, 0.8754514123051644, 0.6337144682978737], 
             UndirectedEdge[57, 73] -> 
             RGBColor[
              0.9000718326779873, 0.8557340830598046, 0.6308269426735655], 
             UndirectedEdge[287, 473] -> 
             RGBColor[
              0.9551870546296672, 0.8550173829381145, 0.308951423137105], 
             UndirectedEdge[395, 443] -> 
             RGBColor[
              0.7633391788814059, 0.7633232758155424, 0.6222483891586607], 
             UndirectedEdge[100, 397] -> 
             RGBColor[
              0.9885911996246599, 0.9723349335538536, 0.4818318635568163], 
             UndirectedEdge[57, 234] -> 
             RGBColor[
              0.919221596206149, 0.9370753536002205, 0.9444371858622419], 
             UndirectedEdge[343, 403] -> 
             RGBColor[
              0.9883354103696496, 0.9894444066686396, 0.8429759673725975], 
             UndirectedEdge[105, 425] -> 
             RGBColor[
              0.9721677675713278, 0.9786928463110631, 0.9288397178031453], 
             UndirectedEdge[133, 423] -> 
             RGBColor[
              0.9436434741686947, 0.813471974867088, 0.5474717724064292], 
             UndirectedEdge[92, 494] -> 
             RGBColor[
              0.994535469027481, 0.9920082902578926, 0.7402249501748649], 
             UndirectedEdge[51, 100] -> 
             RGBColor[
              0.96270356675827, 0.9558551152268445, 0.6862920950931597], 
             UndirectedEdge[6, 347] -> 
             RGBColor[
              0.8406269433994273, 0.852760045743412, 0.6700186771279562], 
             UndirectedEdge[333, 461] -> 
             RGBColor[
              0.9655136954864157, 0.8877728547354085, 0.4895227885454335], 
             UndirectedEdge[291, 394] -> 
             RGBColor[
              0.982546045252165, 0.9847226741897868, 0.8346824088741096], 
             UndirectedEdge[143, 386] -> 
             RGBColor[
              0.9907199582169024, 0.9891532700130687, 0.7106182656247199], 
             UndirectedEdge[123, 437] -> 
             RGBColor[
              0.9318429898607687, 0.8989709490867395, 0.6413393351443415], 
             UndirectedEdge[72, 453] -> 
             RGBColor[
              0.9358234049631116, 0.7635842421436702, 0.3974687887729821], 
             UndirectedEdge[391, 478] -> 
             RGBColor[
              0.9060182626007103, 0.9257674905709905, 0.9093126186620655], 
             UndirectedEdge[328, 464] -> 
             RGBColor[
              0.9095369642869654, 0.926131788068381, 0.7587147399848553], 
             UndirectedEdge[149, 173] -> 
             RGBColor[
              0.6258477715169948, 0.6933125349828987, 0.9262419450168], 
             UndirectedEdge[54, 186] -> 
             RGBColor[
              0.9937966396194163, 0.9897676727907896, 0.6118084671800456], 
             UndirectedEdge[355, 444] -> 
             RGBColor[
              0.779846770183819, 0.8280452033473409, 0.9786639739710834], 
             UndirectedEdge[7, 448] -> 
             RGBColor[
              0.8488103423514972, 0.88225756126573, 0.9603068114838278], 
             UndirectedEdge[47, 416] -> 
             RGBColor[
              0.9908343549253326, 0.9885229536194531, 0.6594664229878424], 
             UndirectedEdge[48, 155] -> 
             RGBColor[
              0.9585932722273287, 0.8759422754151505, 0.568966540947649], 
             UndirectedEdge[346, 486] -> 
             RGBColor[
              0.9851985345836747, 0.9871831418038286, 0.8517883712244563], 
             UndirectedEdge[24, 491] -> 
             RGBColor[
              0.9610071993807259, 0.8784682173249879, 0.3116767551664579], 
             UndirectedEdge[321, 373] -> 
             RGBColor[
              0.991158366221006, 0.9848661107476023, 0.598783160926903], 
             UndirectedEdge[209, 231] -> 
             RGBColor[
              0.9683816672873058, 0.9486322306549608, 0.6523582299699944], 
             UndirectedEdge[210, 393] -> 
             RGBColor[
              0.8422357529592623, 0.8275884453843758, 0.6315855819923047], 
             UndirectedEdge[188, 409] -> 
             RGBColor[
              0.959636422341489, 0.866382455423239, 0.3717092210369617], 
             UndirectedEdge[307, 427] -> 
             RGBColor[
              0.8760840958868488, 0.8037959771045136, 0.621191716966255], 
             UndirectedEdge[178, 186] -> 
             RGBColor[
              0.9920968253080775, 0.9890647558898158, 0.6399787892973552], 
             UndirectedEdge[328, 475] -> 
             RGBColor[
              0.9768622461215593, 0.9329959830424183, 0.4170867814130715], 
             UndirectedEdge[213, 337] -> 
             RGBColor[
              0.9927097612932163, 0.9912533131912256, 0.7704816521117903], 
             UndirectedEdge[384, 458] -> 
             RGBColor[
              0.9445240221253288, 0.9581017807040473, 0.9772336082225619], 
             UndirectedEdge[87, 473] -> 
             RGBColor[
              0.9652848935035975, 0.8886874552301816, 0.38153877273659087`], 
             UndirectedEdge[112, 440] -> 
             RGBColor[
              0.9934432180232066, 0.9910949174729293, 0.7247657380557073], 
             UndirectedEdge[237, 429] -> 
             RGBColor[
              0.9407098087493221, 0.7951991365148408, 0.5241393998436583], 
             UndirectedEdge[109, 230] -> 
             RGBColor[
              0.9623281923258415, 0.8767757857803609, 0.39036354991334005`], 
             UndirectedEdge[89, 262] -> 
             RGBColor[
              0.9949207855415607, 0.9915443987977821, 0.6885370353561143], 
             UndirectedEdge[280, 383] -> 
             RGBColor[
              0.9912898955133793, 0.9807215525097513, 0.5532601393923159], 
             UndirectedEdge[196, 489] -> 
             RGBColor[
              0.9808484274949154, 0.9466953733313295, 0.4110535634869224], 
             UndirectedEdge[279, 459] -> 
             RGBColor[
              0.901396949731718, 0.8405612300295846, 0.6273191182479395], 
             UndirectedEdge[191, 423] -> 
             RGBColor[
              0.9660968392356776, 0.9736863713542101, 0.9176751762491109], 
             UndirectedEdge[116, 165] -> 
             RGBColor[
              0.6522344929794085, 0.7269179040179681, 0.9668829283602036], 
             UndirectedEdge[176, 313] -> 
             RGBColor[
              0.9884783746611363, 0.9719029027516957, 0.5612564968942844], 
             UndirectedEdge[180, 490] -> 
             RGBColor[
              0.961973824919356, 0.9704119498288513, 0.9158226965061755], 
             UndirectedEdge[17, 498] -> 
             RGBColor[
              0.9810870983287518, 0.9548791351320045, 0.5872077209688744], 
             UndirectedEdge[108, 364] -> 
             RGBColor[
              0.9903764278515057, 0.9885016337530437, 0.6792705388007698], 
             UndirectedEdge[29, 254] -> 
             RGBColor[
              0.9400348785809239, 0.79996530630518, 0.27060885962514886`], 
             UndirectedEdge[7, 261] -> 
             RGBColor[
              0.8516430739181657, 0.8843702078299791, 0.9555117358361764], 
             UndirectedEdge[122, 224] -> 
             RGBColor[
              0.9309876398558004, 0.9170812448604899, 0.6689037275976956], 
             UndirectedEdge[116, 386] -> 
             RGBColor[
              0.7715255676191362, 0.8195521366782986, 0.9063351060913376], 
             UndirectedEdge[8, 439] -> 
             RGBColor[
              0.967798872702897, 0.9723333018687182, 0.7514109467760861], 
             UndirectedEdge[226, 488] -> 
             RGBColor[
              0.6077360083063776, 0.4918405452062815, 0.5790165746165631], 
             UndirectedEdge[64, 170] -> 
             RGBColor[
              0.9840152325155878, 0.9604513091983051, 0.5688262087523029], 
             UndirectedEdge[178, 313] -> 
             RGBColor[
              0.9866921485813374, 0.9711642523637823, 0.590858885641467], 
             UndirectedEdge[81, 251] -> 
             RGBColor[
              0.9653805982964034, 0.973701487410301, 0.943485796284854], 
             UndirectedEdge[186, 288] -> 
             RGBColor[
              0.9839611639885695, 0.98415395888906, 0.705552681774796], 
             UndirectedEdge[45, 118] -> 
             RGBColor[
              0.9760058761768202, 0.9816174772435371, 0.9251271612726613], 
             UndirectedEdge[224, 330] -> 
             RGBColor[
              0.9354981497581989, 0.9322962538793691, 0.686426206830191], 
             UndirectedEdge[35, 410] -> 
             RGBColor[
              0.9609400915658426, 0.9386783428377969, 0.6556060757525595], 
             UndirectedEdge[163, 379] -> 
             RGBColor[
              0.9343718927664634, 0.9493930242864733, 0.9549870913605644], 
             UndirectedEdge[181, 443] -> 
             RGBColor[
              0.9675397190829522, 0.9241253278184152, 0.603092874951073], 
             UndirectedEdge[167, 235] -> 
             RGBColor[
              0.9648662465172659, 0.8863880268575289, 0.41905196384534127`], 
             UndirectedEdge[202, 279] -> 
             RGBColor[
              0.9307305404312858, 0.9439246538595696, 0.8331810797612363], 
             UndirectedEdge[242, 310] -> 
             RGBColor[
              0.9874851333943028, 0.9730521049565669, 0.5884992738300252], 
             UndirectedEdge[299, 482] -> 
             RGBColor[
              0.9896140543048361, 0.9755037162866422, 0.5097461243371537], 
             UndirectedEdge[56, 110] -> 
             RGBColor[
              0.9896487842518336, 0.9876770155154228, 0.6532606402608154], 
             UndirectedEdge[125, 419] -> 
             RGBColor[
              0.9335559131278306, 0.94637705731646, 0.8496249495562729], 
             UndirectedEdge[262, 448] -> 
             RGBColor[
              0.9793515702632031, 0.9821499987850995, 0.8271267628112212], 
             UndirectedEdge[95, 212] -> 
             RGBColor[
              0.9497069707639223, 0.9589446413740371, 0.8259684922793253], 
             UndirectedEdge[32, 260] -> 
             RGBColor[
              0.9295474620397266, 0.946256263292213, 0.9791468615226563], 
             UndirectedEdge[421, 430] -> 
             RGBColor[
              0.9837230851363896, 0.9556323816491405, 0.48683636329923174`], 
             UndirectedEdge[129, 346] -> 
             RGBColor[
              0.8386708675141918, 0.8740747936950981, 0.9460473336767616], 
             UndirectedEdge[16, 17] -> 
             RGBColor[
              0.6838140819555287, 0.7459581625377016, 0.8854691216280357], 
             UndirectedEdge[153, 466] -> 
             RGBColor[
              0.9260096163117641, 0.9413865164807906, 0.8972571699974247], 
             UndirectedEdge[244, 391] -> 
             RGBColor[
              0.9031622644866515, 0.9243995944296411, 0.9482755889188603], 
             UndirectedEdge[218, 406] -> 
             RGBColor[
              0.9930353835816368, 0.990110757905104, 0.6722456752023093], 
             UndirectedEdge[99, 288] -> 
             RGBColor[
              0.9848660863785669, 0.9860894963795762, 0.8040478993923719], 
             UndirectedEdge[399, 481] -> 
             RGBColor[
              0.9807304299113843, 0.9462391728109363, 0.41554126391532653`], 
             UndirectedEdge[278, 451] -> 
             RGBColor[
              0.5805034259517428, 0.62830363699945, 0.6591925189456986], 
             UndirectedEdge[179, 327] -> 
             RGBColor[
              0.879625079393448, 0.9064299454813418, 0.9684237920753405], 
             UndirectedEdge[38, 473] -> 
             RGBColor[
              0.9655442704097457, 0.8892422362054044, 0.4097703482820989], 
             UndirectedEdge[17, 176] -> 
             RGBColor[
              0.9920550678000173, 0.9909825806069323, 0.7813316175865483], 
             UndirectedEdge[186, 373] -> 
             RGBColor[
              0.99163967157805, 0.9831300503619049, 0.4501458872666785], 
             UndirectedEdge[399, 496] -> 
             RGBColor[
              0.8808761597546739, 0.8716164594552716, 0.6556501446559981], 
             UndirectedEdge[116, 358] -> 
             RGBColor[
              0.772140142005421, 0.8198062789808687, 0.8961500180430717], 
             UndirectedEdge[71, 135] -> 
             RGBColor[
              0.9717786000706381, 0.9780542960602128, 0.9139004539088715], 
             UndirectedEdge[53, 374] -> 
             RGBColor[
              0.9127440337081092, 0.7346687930420632, 0.5868779663478388], 
             UndirectedEdge[228, 409] -> 
             RGBColor[
              0.9475169407873765, 0.8258325310217391, 0.29640216545336584`], 
             UndirectedEdge[440, 471] -> 
             RGBColor[
              0.9930307840063992, 0.9902127628144541, 0.6798748405739414], 
             UndirectedEdge[403, 471] -> 
             RGBColor[
              0.9928042763888922, 0.9901190960936348, 0.683628657978956], 
             UndirectedEdge[63, 166] -> 
             RGBColor[
              0.942104344828564, 0.953045380092417, 0.8384458148495326], 
             UndirectedEdge[159, 272] -> 
             RGBColor[
              0.7851794085347799, 0.6547820292014226, 0.5960228426715775], 
             UndirectedEdge[130, 351] -> 
             RGBColor[
              0.9627983826367366, 0.9709718273665693, 0.9118588655393843], 
             UndirectedEdge[113, 378] -> 
             RGBColor[
              0.9891457471829773, 0.9870195028898019, 0.6527742502223756], 
             UndirectedEdge[145, 417] -> 
             RGBColor[
              0.9532581917006677, 0.8510172949658554, 0.28840467898476096`], 
             UndirectedEdge[38, 354] -> 
             RGBColor[
              0.9743739377555294, 0.9774346477694067, 0.7559655956726876], 
             UndirectedEdge[334, 446] -> 
             RGBColor[
              0.9282288949269979, 0.9254127766632474, 0.6841334882910703], 
             UndirectedEdge[305, 310] -> 
             RGBColor[
              0.9829671750701775, 0.9542064233935396, 0.38833112083707605`], 
             UndirectedEdge[338, 383] -> 
             RGBColor[
              0.9787614362281793, 0.9384601175186406, 0.5045894408703282], 
             UndirectedEdge[243, 477] -> 
             RGBColor[
              0.9105289173771486, 0.8956668962328449, 0.6594479427884634], 
             UndirectedEdge[38, 221] -> 
             RGBColor[
              0.9780299686933207, 0.9801613096566101, 0.7497768889405916], 
             UndirectedEdge[330, 357] -> 
             RGBColor[
              0.9872745093867774, 0.9685454792397166, 0.4212710574931713], 
             UndirectedEdge[48, 365] -> 
             RGBColor[
              0.9810219199097052, 0.984997204936124, 0.9004597121166171], 
             UndirectedEdge[384, 411] -> 
             RGBColor[
              0.9483152338067347, 0.9609741665158759, 0.9723730070059674], 
             UndirectedEdge[38, 436] -> 
             RGBColor[
              0.9684383041117873, 0.9730078619166118, 0.7660130751703514], 
             UndirectedEdge[117, 155] -> 
             RGBColor[
              0.9073032170403657, 0.8367223943955497, 0.6259682608817569], 
             UndirectedEdge[68, 286] -> 
             RGBColor[
              0.7928656353079344, 0.8036955577399196, 0.6489443807658577], 
             UndirectedEdge[378, 380] -> 
             RGBColor[
              0.9936006038259215, 0.9885694455753351, 0.557701892029472], 
             UndirectedEdge[12, 285] -> 
             RGBColor[
              0.9749354842680786, 0.927113644387379, 0.35712951872846244`], 
             UndirectedEdge[93, 432] -> 
             RGBColor[
              0.9159467798266573, 0.7044640216275829, 0.25122700994711783`], 
             UndirectedEdge[340, 499] -> 
             RGBColor[
              0.936733048619289, 0.9347747295352673, 0.688741569228009], 
             UndirectedEdge[389, 456] -> 
             RGBColor[
              0.9928036137711409, 0.9862765654786576, 0.5209706366456485], 
             UndirectedEdge[390, 451] -> 
             RGBColor[
              0.5844267626365333, 0.6477481867854952, 0.8750540378748017], 
             UndirectedEdge[92, 485] -> 
             RGBColor[
              0.9876058782702591, 0.9885350778166191, 0.827854457280885], 
             UndirectedEdge[293, 471] -> 
             RGBColor[
              0.994484558851111, 0.990611354016194, 0.641056452179734], 
             UndirectedEdge[111, 359] -> 
             RGBColor[
              0.5839454070259071, 0.6475491338702264, 0.8830313460512651], 
             UndirectedEdge[357, 441] -> 
             RGBColor[
              0.9937830300658306, 0.9891108548799198, 0.5646993732357817], 
             UndirectedEdge[52, 268] -> 
             RGBColor[
              0.9939857227730897, 0.9895443940853706, 0.5867612235465447], 
             UndirectedEdge[30, 311] -> 
             RGBColor[
              0.9589309758015598, 0.9678844188996694, 0.9111360316561798], 
             UndirectedEdge[164, 486] -> 
             RGBColor[
              0.9346602307958665, 0.9479861282126623, 0.885135421436797], 
             UndirectedEdge[194, 290] -> 
             RGBColor[
              0.8844871813955175, 0.9024193108335308, 0.6968720513815436], 
             UndirectedEdge[238, 445] -> 
             RGBColor[
              0.9741830788352117, 0.9230096089867744, 0.445280445311962], 
             UndirectedEdge[269, 406] -> 
             RGBColor[
              0.9893300029038938, 0.9898556962414118, 0.8264929951572002], 
             UndirectedEdge[99, 341] -> 
             RGBColor[
              0.9770887395240636, 0.9802891638297244, 0.8172129189601187], 
             UndirectedEdge[41, 457] -> 
             RGBColor[
              0.9645198398913459, 0.8842081778176407, 0.46649536853895257`], 
             UndirectedEdge[217, 292] -> 
             RGBColor[
              0.9706980623837491, 0.9765852075300592, 0.8860289387170268], 
             UndirectedEdge[176, 299] -> 
             RGBColor[
              0.9945258677865662, 0.9911783255558186, 0.6803429985445772], 
             UndirectedEdge[218, 314] -> 
             RGBColor[
              0.993801498875829, 0.9891503577970233, 0.5667095892278311], 
             UndirectedEdge[355, 486] -> 
             RGBColor[
              0.8594430397135705, 0.8887625226665847, 0.8777614373860672], 
             UndirectedEdge[213, 420] -> 
             RGBColor[
              0.9939336721915073, 0.9906795989007275, 0.6717058286116266], 
             UndirectedEdge[299, 407] -> 
             RGBColor[
              0.9924941224349372, 0.9903381466394463, 0.7140142770094908], 
             UndirectedEdge[201, 314] -> 
             RGBColor[
              0.9934485439452356, 0.9883954228897014, 0.5282926232180687], 
             UndirectedEdge[160, 300] -> 
             RGBColor[
              0.9193723469546028, 0.935341516539118, 0.8639426764411817], 
             UndirectedEdge[21, 200] -> 
             RGBColor[
              0.971811062629562, 0.9143147563804288, 0.5109391646741392], 
             UndirectedEdge[25, 180] -> 
             RGBColor[
              0.9603943915263176, 0.9691525525138196, 0.9156720487391707], 
             UndirectedEdge[45, 185] -> 
             RGBColor[
              0.9786325637009061, 0.9827036800375368, 0.8815961513491504], 
             UndirectedEdge[191, 226] -> 
             RGBColor[
              0.9083609754381307, 0.735029326784656, 0.5967142560870367], 
             UndirectedEdge[50, 82] -> 
             RGBColor[
              0.39199477576469927`, 0.5139479053622513, 0.9461985383777247], 
             UndirectedEdge[22, 491] -> 
             RGBColor[
              0.6535433115419873, 0.6905228714188323, 0.6435220769412443], 
             UndirectedEdge[99, 277] -> 
             RGBColor[
              0.9936256067758649, 0.9912582751414452, 0.728135047500411], 
             UndirectedEdge[17, 391] -> 
             RGBColor[
              0.9063201228819391, 0.925892317554734, 0.9043100126127396], 
             UndirectedEdge[211, 362] -> 
             RGBColor[
              0.9204409254556969, 0.9364654761727196, 0.8758516150518993], 
             UndirectedEdge[4, 162] -> 
             RGBColor[
              0.9841975189361454, 0.9583566621519265, 0.39311077442541753`], 
             UndirectedEdge[259, 444] -> 
             RGBColor[
              0.9108160908213343, 0.9217333208362989, 0.6974855920098728], 
             UndirectedEdge[347, 382] -> 
             RGBColor[
              0.847823132779542, 0.8796169627872963, 0.8735198527863846], 
             UndirectedEdge[66, 179] -> 
             RGBColor[
              0.8926084027777799, 0.9010884217852451, 0.6864733234377907], 
             UndirectedEdge[343, 471] -> 
             RGBColor[
              0.9894530786277131, 0.9887332896975332, 0.7391666775034922], 
             UndirectedEdge[97, 322] -> 
             RGBColor[
              0.9155119338342232, 0.9312467550840574, 0.7877125830949886], 
             UndirectedEdge[363, 381] -> 
             RGBColor[
              0.8753993738882541, 0.9034343916049944, 0.9834720038772102], 
             UndirectedEdge[238, 471] -> 
             RGBColor[
              0.9740510037514406, 0.9227271137374273, 0.4309048875164072], 
             UndirectedEdge[40, 285] -> 
             RGBColor[
              0.9475887867449182, 0.934254595380686, 0.6762775998489301], 
             UndirectedEdge[70, 208] -> 
             RGBColor[
              0.9178124654305488, 0.8729638383499392, 0.6332096187073585], 
             UndirectedEdge[84, 448] -> 
             RGBColor[
              0.9722743810093946, 0.9598781745460337, 0.6634789908683025], 
             UndirectedEdge[152, 195] -> 
             RGBColor[
              0.9751031140946667, 0.9775059770099579, 0.7172412869400898], 
             UndirectedEdge[93, 308] -> 
             RGBColor[
              0.8145532144237744, 0.7558988214009423, 0.6151223357416828], 
             UndirectedEdge[255, 478] -> 
             RGBColor[
              0.9905409245669334, 0.9903564434683461, 0.8064248894358246], 
             UndirectedEdge[112, 293] -> 
             RGBColor[
              0.9948969928679183, 0.9914935086746693, 0.6859473496615], 
             UndirectedEdge[87, 184] -> 
             RGBColor[
              0.993386321490842, 0.9882623353514088, 0.521520093049812], 
             UndirectedEdge[149, 323] -> 
             RGBColor[
              0.9352252536080699, 0.7845591309522371, 0.5708811415787034], 
             UndirectedEdge[272, 497] -> 
             RGBColor[
              0.9295823148203721, 0.7452345869454096, 0.29613348990005905`], 
             UndirectedEdge[80, 471] -> 
             RGBColor[
              0.9410326797397115, 0.7871875876467569, 0.40409791520065635`], 
             UndirectedEdge[339, 344] -> 
             RGBColor[
              0.97400117932345, 0.9219189860994099, 0.46699627979716807`], 
             UndirectedEdge[137, 393] -> 
             RGBColor[
              0.9235567515723684, 0.7299165239218206, 0.25964211861084996`], 
             UndirectedEdge[11, 316] -> 
             RGBColor[
              0.5593539288516777, 0.6300016213958669, 0.9601602398136058], 
             UndirectedEdge[88, 423] -> 
             RGBColor[
              0.9912505862185785, 0.9904091548524248, 0.777163834329762], 
             UndirectedEdge[70, 351] -> 
             RGBColor[
              0.9119138621030507, 0.9325770118518837, 0.9906849499839343], 
             UndirectedEdge[55, 298] -> 
             RGBColor[
              0.9900212839028373, 0.9901415586995863, 0.8150366800268296], 
             UndirectedEdge[428, 437] -> 
             RGBColor[
              0.9374124791002427, 0.9520657313080212, 0.9638832569127391], 
             UndirectedEdge[90, 137] -> 
             RGBColor[
              0.9365697321264702, 0.7738123629239414, 0.31019509076835733`], 
             UndirectedEdge[344, 439] -> 
             RGBColor[
              0.993982214463196, 0.9895368901652526, 0.5863793656653915], 
             UndirectedEdge[93, 274] -> 
             RGBColor[
              0.9600843180972073, 0.8669808631943339, 0.44173888093873703`], 
             UndirectedEdge[60, 434] -> 
             RGBColor[
              0.826623772868913, 0.7661743049536573, 0.6165127280237267], 
             UndirectedEdge[54, 244] -> 
             RGBColor[
              0.9888107976362696, 0.9894541239949001, 0.826729260522542], 
             UndirectedEdge[243, 318] -> 
             RGBColor[
              0.8266098262087679, 0.8298474470942445, 0.6511529910914448], 
             UndirectedEdge[384, 402] -> 
             RGBColor[
              0.9003294939094507, 0.9228622635332169, 0.9730182946684103], 
             UndirectedEdge[83, 233] -> 
             RGBColor[
              0.9578577963759698, 0.956380520108542, 0.6977612420738301], 
             UndirectedEdge[153, 201] -> 
             RGBColor[
              0.9273301357538877, 0.9400463977624225, 0.7382668299120074], 
             UndirectedEdge[275, 331] -> 
             RGBColor[
              0.9728849180680362, 0.9190287082470031, 0.3752457030155084], 
             UndirectedEdge[312, 327] -> 
             RGBColor[
              0.9749093747330309, 0.9795369142410658, 0.8704327559016252], 
             UndirectedEdge[181, 370] -> 
             RGBColor[
              0.9474664495907655, 0.844675437050841, 0.5862439218992512], 
             UndirectedEdge[32, 245] -> 
             RGBColor[
              0.9508148767780382, 0.9593037360687471, 0.7835711283390048], 
             UndirectedEdge[176, 391] -> 
             RGBColor[
              0.9089922581166774, 0.9269973141450414, 0.8600258165088124], 
             UndirectedEdge[148, 232] -> 
             RGBColor[
              0.9273682147140911, 0.9418915853482774, 0.8722775501764761], 
             UndirectedEdge[430, 477] -> 
             RGBColor[
              0.923313215514131, 0.9376674318509806, 0.8046812015350726], 
             UndirectedEdge[7, 475] -> 
             RGBColor[
              0.8471183015051658, 0.8348088538740158, 0.6370461965182888], 
             UndirectedEdge[15, 50] -> 
             RGBColor[
              0.6997233969073375, 0.7145151437574346, 0.6220686984329404], 
             UndirectedEdge[168, 395] -> 
             RGBColor[
              0.7784711815429751, 0.8253817932621001, 0.9148620211067597], 
             UndirectedEdge[97, 440] -> 
             RGBColor[
              0.9145689054404855, 0.9319405988965632, 0.8821225707159848], 
             UndirectedEdge[71, 308] -> 
             RGBColor[
              0.8300563216251539, 0.8677264857295677, 0.9644971848780834], 
             UndirectedEdge[253, 436] -> 
             RGBColor[
              0.96702251248576, 0.9689445318671657, 0.6999298944175767], 
             UndirectedEdge[13, 430] -> 
             RGBColor[
              0.9440549120326751, 0.8004279169295196, 0.42833620999779454`], 
             UndirectedEdge[209, 233] -> 
             RGBColor[
              0.9805933005906355, 0.9461987873618105, 0.37910906675263567`], 
             UndirectedEdge[254, 350] -> 
             RGBColor[
              0.9383425448162757, 0.7932557668651462, 0.2692471681539339], 
             UndirectedEdge[115, 268] -> 
             RGBColor[
              0.9745222672866894, 0.977329708309627, 0.7386104801669304], 
             UndirectedEdge[42, 468] -> 
             RGBColor[
              0.5830127059675694, 0.6367680276997995, 0.6689405979694156], 
             UndirectedEdge[51, 60] -> 
             RGBColor[
              0.8344855522773214, 0.8714477994413923, 0.9781587819320604], 
             UndirectedEdge[331, 348] -> 
             RGBColor[
              0.9899045938428885, 0.9880461162216522, 0.6681615697904624], 
             UndirectedEdge[310, 406] -> 
             RGBColor[
              0.9877764634726107, 0.9731725774307887, 0.5836711804943883], 
             UndirectedEdge[70, 130] -> 
             RGBColor[
              0.938145962557247, 0.9513370215867588, 0.9102828980349388], 
             UndirectedEdge[83, 440] -> 
             RGBColor[
              0.9606305826854618, 0.9686689300207862, 0.8865159746113553], 
             UndirectedEdge[100, 374] -> 
             RGBColor[
              0.926713912591385, 0.7292376593940797, 0.3015053880222941], 
             UndirectedEdge[207, 374] -> 
             RGBColor[
              0.851923532097141, 0.6866795477884512, 0.5986677515043799], 
             UndirectedEdge[51, 324] -> 
             RGBColor[
              0.8961264279356113, 0.9198460195876321, 0.9842378448979286], 
             UndirectedEdge[164, 180] -> 
             RGBColor[
              0.9329754376216488, 0.9472894229379135, 0.9130568044385543], 
             UndirectedEdge[56, 132] -> 
             RGBColor[
              0.9371160467095174, 0.7854924466769105, 0.5490263081187502], 
             UndirectedEdge[30, 423] -> 
             RGBColor[
              0.9883321201986879, 0.9894430460983934, 0.843030494020121], 
             UndirectedEdge[104, 379] -> 
             RGBColor[
              0.9580754372751259, 0.8863720743639596, 0.5944973929105344], 
             UndirectedEdge[324, 457] -> 
             RGBColor[
              0.8922383520659085, 0.8303269354726579, 0.6257891261316477], 
             UndirectedEdge[283, 459] -> 
             RGBColor[
              0.9652337337768195, 0.8874249574897868, 0.4442030182075316], 
             UndirectedEdge[128, 245] -> 
             RGBColor[
              0.9932292330039203, 0.9879263389619655, 0.5044219806861426], 
             UndirectedEdge[34, 62] -> 
             RGBColor[
              0.8771559152907384, 0.9026302878007502, 0.880902277963457], 
             UndirectedEdge[320, 424] -> 
             RGBColor[
              0.9822330778885414, 0.9652542590453663, 0.6366528199637241], 
             UndirectedEdge[111, 351] -> 
             RGBColor[
              0.9627650481171772, 0.9709580426860734, 0.9124113047954551], 
             UndirectedEdge[79, 316] -> 
             RGBColor[
              0.5593671290477132, 0.5522284334651065, 0.6019633554197891], 
             UndirectedEdge[43, 250] -> 
             RGBColor[
              0.9270874070768771, 0.7894931047598459, 0.5919836753657384], 
             UndirectedEdge[116, 313] -> 
             RGBColor[
              0.7688211319839069, 0.8008331597168172, 0.671804421233507], 
             UndirectedEdge[87, 436] -> 
             RGBColor[
              0.9681789272056391, 0.9724530809413889, 0.7377814996248435], 
             UndirectedEdge[280, 393] -> 
             RGBColor[
              0.9725718142971782, 0.9191404305594306, 0.3479471072331348], 
             UndirectedEdge[295, 321] -> 
             RGBColor[
              0.968040451347109, 0.9743753346017489, 0.8803248447251983], 
             UndirectedEdge[131, 186] -> 
             RGBColor[
              0.986415652405334, 0.985984512331427, 0.7013978731183191], 
             UndirectedEdge[165, 313] -> 
             RGBColor[
              0.8656429072830186, 0.8778029726073023, 0.6805440794326443], 
             UndirectedEdge[140, 270] -> 
             RGBColor[
              0.9046835099120145, 0.8717376847716214, 0.634027016672862], 
             UndirectedEdge[322, 445] -> 
             RGBColor[
              0.9941058874839082, 0.9898014142512954, 0.5998404107485], 
             UndirectedEdge[112, 463] -> 
             RGBColor[
              0.9826662818953331, 0.984377885147788, 0.8021379966829669], 
             UndirectedEdge[115, 223] -> 
             RGBColor[
              0.9732635567769733, 0.9784776854940385, 0.8807519133281012], 
             UndirectedEdge[102, 451] -> 
             RGBColor[
              0.5863641363656958, 0.6472719370484693, 0.7500929874007136], 
             UndirectedEdge[148, 267] -> 
             RGBColor[
              0.9281832183439551, 0.9420693812073049, 0.847196557182679], 
             UndirectedEdge[447, 500] -> 
             RGBColor[
              0.5088246122312231, 0.6017931939268142, 0.9571102104051221], 
             UndirectedEdge[238, 293] -> 
             RGBColor[
              0.9746136179555956, 0.9239304886310932, 0.4921419715862906], 
             UndirectedEdge[56, 457] -> 
             RGBColor[
              0.9605053799224283, 0.8830305482635621, 0.5680945855683501], 
             UndirectedEdge[204, 331] -> 
             RGBColor[
              0.9935480042062729, 0.9886081583310853, 0.5391182588343979], 
             UndirectedEdge[66, 260] -> 
             RGBColor[
              0.967647547157769, 0.9603677091414289, 0.679675354436577], 
             UndirectedEdge[225, 424] -> 
             RGBColor[
              0.9635947401330361, 0.8864173791897778, 0.32578705689915555`], 
             UndirectedEdge[178, 244] -> 
             RGBColor[
              0.9871109833249307, 0.9887512070939263, 0.8548995826398518], 
             UndirectedEdge[139, 247] -> 
             RGBColor[
              0.8871661605699753, 0.8031532663285028, 0.620126074677471], 
             UndirectedEdge[244, 448] -> 
             RGBColor[
              0.9733364649021299, 0.9796349596983158, 0.9300185893436942], 
             UndirectedEdge[259, 275] -> 
             RGBColor[
              0.9708387719687807, 0.9123771236851517, 0.3459921298693587], 
             UndirectedEdge[282, 406] -> 
             RGBColor[
              0.9924072006225744, 0.9887671380747094, 0.6038718368042064], 
             UndirectedEdge[286, 357] -> 
             RGBColor[
              0.9810171777499883, 0.9474380303374904, 0.39696250568217406`], 
             UndirectedEdge[206, 396] -> 
             RGBColor[
              0.8975661703177293, 0.9205332280459014, 0.9683988382663016], 
             UndirectedEdge[154, 295] -> 
             RGBColor[
              0.9674441374538272, 0.9741287434823087, 0.8902073091477671], 
             UndirectedEdge[410, 428] -> 
             RGBColor[
              0.9599519933318295, 0.9696528427162467, 0.9526750084829447], 
             UndirectedEdge[104, 147] -> 
             RGBColor[
              0.9355489873600312, 0.8695238710947276, 0.6309641279748117], 
             UndirectedEdge[32, 255] -> 
             RGBColor[
              0.950022401594639, 0.9601789681852151, 0.8841456026518979], 
             UndirectedEdge[165, 498] -> 
             RGBColor[
              0.8609237661853724, 0.8618842015779187, 0.6622111074033071], 
             UndirectedEdge[248, 439] -> 
             RGBColor[
              0.8206039099899944, 0.8565237217671142, 0.7428359678184282], 
             UndirectedEdge[141, 389] -> 
             RGBColor[
              0.9460973786794733, 0.8125886597158822, 0.3298670366068687], 
             UndirectedEdge[328, 478] -> 
             RGBColor[
              0.9911410359545234, 0.9890697646436053, 0.6849128030808385], 
             UndirectedEdge[178, 261] -> 
             RGBColor[
              0.9802129640190254, 0.983606675590052, 0.8665761300331776], 
             UndirectedEdge[120, 315] -> 
             RGBColor[
              0.9791276126286266, 0.981537292819824, 0.7921431638397319], 
             UndirectedEdge[47, 136] -> 
             RGBColor[
              0.9696501557859952, 0.9761446336922974, 0.9030713515736525], 
             UndirectedEdge[74, 144] -> 
             RGBColor[
              0.8956625073425295, 0.9164250817328858, 0.8516382266073905], 
             UndirectedEdge[165, 361] -> 
             RGBColor[
              0.8654096178138445, 0.8770160324488058, 0.6796377938979223], 
             UndirectedEdge[32, 482] -> 
             RGBColor[
              0.9463228710647641, 0.9450056690708816, 0.6934580626445239], 
             UndirectedEdge[67, 119] -> 
             RGBColor[
              0.966758931206105, 0.9724974519515023, 0.8277353880327015], 
             UndirectedEdge[97, 326] -> 
             RGBColor[
              0.9152233091940727, 0.9306294161632027, 0.7562975721994023], 
             UndirectedEdge[409, 430] -> 
             RGBColor[
              0.9602780395922115, 0.8677548098450791, 0.4415452991754081], 
             UndirectedEdge[113, 190] -> 
             RGBColor[
              0.9762174890273572, 0.9434094524315253, 0.6025504085844874], 
             UndirectedEdge[292, 496] -> 
             RGBColor[
              0.892091732894778, 0.9145074951604737, 0.8918784592337416], 
             UndirectedEdge[15, 82] -> 
             RGBColor[
              0.6511741205962809, 0.6724642007743755, 0.6189751814768394], 
             UndirectedEdge[340, 414] -> 
             RGBColor[
              0.9884652143988986, 0.9728852594706392, 0.5683022251666521], 
             UndirectedEdge[149, 282] -> 
             RGBColor[
              0.9877125674189055, 0.9866078160433086, 0.6719128915123458], 
             UndirectedEdge[330, 368] -> 
             RGBColor[
              0.9857976378630937, 0.9700657455147115, 0.6006471616850575], 
             UndirectedEdge[331, 431] -> 
             RGBColor[
              0.993633450124692, 0.988790918510676, 0.5484185197432313], 
             UndirectedEdge[4, 488] -> 
             RGBColor[
              0.6671941618067001, 0.7265035614616732, 0.6812100164483834], 
             UndirectedEdge[87, 409] -> 
             RGBColor[
              0.9596853366148224, 0.8664870781079073, 0.3770332378253893], 
             UndirectedEdge[440, 445] -> 
             RGBColor[
              0.9931628590901704, 0.9904952580638013, 0.6942503983694961], 
             UndirectedEdge[55, 200] -> 
             RGBColor[
              0.9685431274812095, 0.9129633812144824, 0.5650973072274034], 
             UndirectedEdge[64, 215] -> 
             RGBColor[
              0.800977301298331, 0.8186257939044335, 0.6619829152117387], 
             UndirectedEdge[167, 493] -> 
             RGBColor[
              0.9654770972388712, 0.887694574784561, 0.48553929515840955`], 
             UndirectedEdge[153, 470] -> 
             RGBColor[
              0.9074881188872703, 0.8727258397258988, 0.6340150251525121], 
             UndirectedEdge[185, 187] -> 
             RGBColor[
              0.9677795081774027, 0.9746094889983554, 0.8999675434202185], 
             UndirectedEdge[18, 310] -> 
             RGBColor[
              0.8339240777223945, 0.8543901258560312, 0.6793776246494633], 
             UndirectedEdge[226, 366] -> 
             RGBColor[
              0.8666477636750864, 0.7020003372539871, 0.6007789644695448], 
             UndirectedEdge[333, 361] -> 
             RGBColor[
              0.9588280637294853, 0.8668445603511012, 0.3254646684805801], 
             UndirectedEdge[236, 300] -> 
             RGBColor[
              0.9193464482928841, 0.9345045405811871, 0.804311054368182], 
             UndirectedEdge[161, 335] -> 
             RGBColor[
              0.9337167064612004, 0.9493919388257531, 0.972999864425734], 
             UndirectedEdge[61, 397] -> 
             RGBColor[
              0.9669871440775691, 0.8947701971594386, 0.4223255381498962], 
             UndirectedEdge[393, 480] -> 
             RGBColor[
              0.9322003406267745, 0.7684218157784329, 0.2668160948146098], 
             UndirectedEdge[349, 378] -> 
             RGBColor[
              0.9903011799848327, 0.9874973040466377, 0.633625738531393], 
             UndirectedEdge[97, 163] -> 
             RGBColor[
              0.8634259969222595, 0.8939364691442168, 0.9868355364475736], 
             UndirectedEdge[229, 267] -> 
             RGBColor[
              0.9825092902985638, 0.9510606736253399, 0.5227065530705617], 
             UndirectedEdge[77, 287] -> 
             RGBColor[
              0.9835237622746928, 0.9550955024569128, 0.4745414822220472], 
             UndirectedEdge[41, 485] -> 
             RGBColor[
              0.9876286128170696, 0.9880620263259924, 0.7924084607500497], 
             UndirectedEdge[7, 89] -> 
             RGBColor[
              0.8643795576298547, 0.8916519612784128, 0.8217170840287209], 
             UndirectedEdge[41, 44] -> 
             RGBColor[
              0.9542059711630533, 0.8433171252029726, 0.4581965876625539], 
             UndirectedEdge[147, 234] -> 
             RGBColor[
              0.9592763911389444, 0.9690139598211873, 0.9482576479602696], 
             UndirectedEdge[259, 331] -> 
             RGBColor[
              0.990862815816742, 0.9805897269274215, 0.44030887610364555`], 
             UndirectedEdge[77, 409] -> 
             RGBColor[
              0.9601682772328884, 0.867520039257164, 0.4295983437378639], 
             UndirectedEdge[2, 334] -> 
             RGBColor[
              0.9717590776448798, 0.9594282133281501, 0.6642119050475249], 
             UndirectedEdge[315, 487] -> 
             RGBColor[
              0.9326726732402408, 0.9452199715886114, 0.812834117380492], 
             UndirectedEdge[251, 258] -> 
             RGBColor[
              0.9318859046326262, 0.8330554921318618, 0.6126177204564413], 
             UndirectedEdge[39, 96] -> 
             RGBColor[
              0.9929143334340869, 0.9872528006233223, 0.47014710584465663`], 
             UndirectedEdge[219, 497] -> 
             RGBColor[
              0.9850954223416816, 0.9645743581310049, 0.5763355497267784], 
             UndirectedEdge[447, 454] -> 
             RGBColor[
              0.3235303862498307, 0.45095564853709613`, 0.9419712245030648], 
             UndirectedEdge[417, 458] -> 
             RGBColor[
              0.939932238054896, 0.8867111641359259, 0.6344482611912261], 
             UndirectedEdge[189, 422] -> 
             RGBColor[
              0.9857476160784551, 0.9820623898188182, 0.6664345342638867], 
             UndirectedEdge[431, 444] -> 
             RGBColor[
              0.9135867251292843, 0.9299345124195535, 0.8055952356494586], 
             UndirectedEdge[161, 273] -> 
             RGBColor[
              0.9760998796101668, 0.9786309009078522, 0.7458274161200493], 
             UndirectedEdge[109, 413] -> 
             RGBColor[
              0.7001116908016556, 0.6725495585192889, 0.6074612882241717], 
             UndirectedEdge[236, 470] -> 
             RGBColor[
              0.9738678863477297, 0.9216338859023314, 0.4524881619789106], 
             UndirectedEdge[287, 436] -> 
             RGBColor[
              0.958081088331709, 0.9387830086493218, 0.6651941500253575], 
             UndirectedEdge[253, 473] -> 
             RGBColor[
              0.9641284787837183, 0.8851789061559583, 0.3436871675293241], 
             UndirectedEdge[166, 435] -> 
             RGBColor[
              0.9422315598015358, 0.9533174800561972, 0.8522923795777231], 
             UndirectedEdge[114, 312] -> 
             RGBColor[
              0.981012195266777, 0.9840883878026823, 0.8601022726085088], 
             UndirectedEdge[222, 296] -> 
             RGBColor[
              0.8947175264246718, 0.9157650594779491, 0.8561492874696299], 
             UndirectedEdge[5, 346] -> 
             RGBColor[
              0.9846173886822751, 0.9820929416219975, 0.6702019334609954], 
             UndirectedEdge[86, 220] -> 
             RGBColor[
              0.9668654230775384, 0.8946869202809373, 0.3985987800370061], 
             UndirectedEdge[195, 255] -> 
             RGBColor[
              0.9747648892977292, 0.9793528047713085, 0.867258112510908], 
             UndirectedEdge[313, 407] -> 
             RGBColor[
              0.9864466293095073, 0.9710627238353231, 0.5949277753591978], 
             UndirectedEdge[224, 441] -> 
             RGBColor[
              0.9420066704372521, 0.9528616295195724, 0.8298545225728013], 
             UndirectedEdge[172, 211] -> 
             RGBColor[
              0.9888597159544157, 0.9896612205019794, 0.8342868669736638], 
             UndirectedEdge[204, 355] -> 
             RGBColor[
              0.860532537469502, 0.8882684562802758, 0.7910430676494586], 
             UndirectedEdge[109, 180] -> 
             RGBColor[
              0.9599743930572839, 0.8774725360378373, 0.5507712250422242], 
             UndirectedEdge[96, 157] -> 
             RGBColor[
              0.9920734153419317, 0.9848474813829393, 0.43020608919595377`], 
             UndirectedEdge[316, 372] -> 
             RGBColor[
              0.5657611394916502, 0.6347801086003138, 0.9493145034683028], 
             UndirectedEdge[53, 112] -> 
             RGBColor[
              0.9750605561591857, 0.9787055473470021, 0.8150125064632937], 
             UndirectedEdge[28, 305] -> 
             RGBColor[
              0.9884007078071368, 0.9724940191473395, 0.5668514053240328], 
             UndirectedEdge[186, 341] -> 
             RGBColor[
              0.9761838171340662, 0.9783536263392082, 0.7187177013425429], 
             UndirectedEdge[65, 86] -> 
             RGBColor[
              0.9930746049417055, 0.9898072920727974, 0.6483579602886329], 
             UndirectedEdge[10, 390] -> 
             RGBColor[
              0.9654018984312187, 0.9727646600218509, 0.9007853063291651], 
             UndirectedEdge[48, 140] -> 
             RGBColor[
              0.9703080592781272, 0.9223875023501968, 0.5783925335901152], 
             UndirectedEdge[231, 404] -> 
             RGBColor[
              0.9601051475434496, 0.9207135861396838, 0.62020551365472], 
             UndirectedEdge[87, 354] -> 
             RGBColor[
              0.9741145608493813, 0.9768798667941838, 0.7277340201271796], 
             UndirectedEdge[136, 434] -> 
             RGBColor[
              0.9385085693476389, 0.8542501799417953, 0.6140191361811863], 
             UndirectedEdge[205, 413] -> 
             RGBColor[
              0.5604501242182839, 0.6538901931224327, 0.9586406740449946], 
             UndirectedEdge[20, 490] -> 
             RGBColor[
              0.9327791527671079, 0.9492367930736336, 0.9934505023643483], 
             UndirectedEdge[390, 443] -> 
             RGBColor[
              0.9731712193683224, 0.9273725785163893, 0.5508957795150373], 
             UndirectedEdge[296, 385] -> 
             RGBColor[
              0.889849197122791, 0.9137518802012652, 0.9368301028341628], 
             UndirectedEdge[86, 290] -> 
             RGBColor[
              0.8862703793095734, 0.9078617674955256, 0.7524967447622253], 
             UndirectedEdge[24, 74] -> 
             RGBColor[
              0.8732152399427024, 0.8407305268190339, 0.6296064647907634], 
             UndirectedEdge[38, 336] -> 
             RGBColor[
              0.994042600644073, 0.9896660501001691, 0.5929520287935419], 
             UndirectedEdge[383, 443] -> 
             RGBColor[
              0.9757227766860248, 0.9282100053717638, 0.492784822351763], 
             UndirectedEdge[14, 435] -> 
             RGBColor[0.9944230380405812, 0.990479767223179, 0.634360291616], 
             UndirectedEdge[282, 323] -> 
             RGBColor[
              0.9400578191468685, 0.7844144330451622, 0.32893016249798307`], 
             UndirectedEdge[307, 337] -> 
             RGBColor[
              0.9090265385619221, 0.927628197084617, 0.8862372520808206], 
             UndirectedEdge[157, 356] -> 
             RGBColor[
              0.889933907068214, 0.9088198315076755, 0.7005480022572146], 
             UndirectedEdge[166, 439] -> 
             RGBColor[
              0.9413351220218018, 0.9514000902891089, 0.754720659426374], 
             UndirectedEdge[266, 293] -> 
             RGBColor[
              0.9164307916726053, 0.9326646070407338, 0.8433431083502336], 
             UndirectedEdge[2, 260] -> 
             RGBColor[
              0.9569889185410827, 0.9674429863888973, 0.9576907212100032], 
             UndirectedEdge[135, 466] -> 
             RGBColor[
              0.9885837175967258, 0.9895470880882403, 0.8388608740214385], 
             UndirectedEdge[60, 495] -> 
             RGBColor[
              0.8592929917974323, 0.8887004739972061, 0.8802481196680345], 
             UndirectedEdge[217, 464] -> 
             RGBColor[
              0.8881311269328536, 0.9132490620359544, 0.9757880203225411], 
             UndirectedEdge[435, 453] -> 
             RGBColor[
              0.936466814506669, 0.7649604300986557, 0.4674999469257698], 
             UndirectedEdge[82, 411] -> 
             RGBColor[
              0.6424927529494531, 0.7139090877111498, 0.9634733605441288], 
             UndirectedEdge[94, 193] -> 
             RGBColor[
              0.8762773330251689, 0.7667605420006189, 0.6129668882750583], 
             UndirectedEdge[88, 469] -> 
             RGBColor[
              0.8947077915863686, 0.9155202819257877, 0.8388104939404479], 
             UndirectedEdge[36, 76] -> 
             RGBColor[
              0.9565199762817819, 0.8631176004944665, 0.2953600879574464], 
             UndirectedEdge[163, 326] -> 
             RGBColor[
              0.9416511186012038, 0.9517022340206731, 0.7588182802530385], 
             UndirectedEdge[151, 472] -> 
             RGBColor[
              0.989577219703074, 0.9879319674881033, 0.6751301224417791], 
             UndirectedEdge[114, 138] -> 
             RGBColor[
              0.9654810132015155, 0.9737763766821194, 0.9433158200429008], 
             UndirectedEdge[448, 475] -> 
             RGBColor[
              0.9619136731832245, 0.9249290742384781, 0.6232295974191323], 
             UndirectedEdge[169, 362] -> 
             RGBColor[
              0.8949873824469763, 0.8447688792860075, 0.6287944236078187], 
             UndirectedEdge[20, 25] -> 
             RGBColor[
              0.9311997193740694, 0.9479773957586022, 0.9932998545973435], 
             UndirectedEdge[113, 349] -> 
             RGBColor[
              0.9871889464049131, 0.988970314356441, 0.8619758422219137], 
             UndirectedEdge[457, 494] -> 
             RGBColor[
              0.9643552880557272, 0.8846225842148072, 0.5042916445567188], 
             UndirectedEdge[364, 452] -> 
             RGBColor[
              0.9904620817890805, 0.9903238399535368, 0.8077315183034175], 
             UndirectedEdge[351, 442] -> 
             RGBColor[
              0.9485100489480832, 0.9152376967637145, 0.6465659442582151], 
             UndirectedEdge[71, 466] -> 
             RGBColor[
              0.9736494326043074, 0.9788279333910881, 0.882895917266574], 
             UndirectedEdge[87, 285] -> 
             RGBColor[
              0.9844554697162514, 0.95883448138793, 0.42747201688734415`], 
             UndirectedEdge[211, 369] -> 
             RGBColor[
              0.9851988924416841, 0.9870253744248222, 0.8447106680188416], 
             UndirectedEdge[164, 316] -> 
             RGBColor[
              0.5281197053035239, 0.6052015592399045, 0.9608305174906883], 
             UndirectedEdge[27, 297] -> 
             RGBColor[
              0.8976996382252811, 0.9180268338836233, 0.8526686509632175], 
             UndirectedEdge[238, 483] -> 
             RGBColor[
              0.9731093437791531, 0.9235110146579089, 0.5317972645953583], 
             UndirectedEdge[109, 164] -> 
             RGBColor[
              0.9043113660426829, 0.8351922315797327, 0.6258744555850464], 
             UndirectedEdge[83, 355] -> 
             RGBColor[
              0.8279997852237683, 0.8664411104614232, 0.9832568515322977], 
             UndirectedEdge[85, 166] -> 
             RGBColor[
              0.9078152792712675, 0.8301053255866792, 0.6244439311578509], 
             UndirectedEdge[34, 190] -> 
             RGBColor[
              0.8644351175463629, 0.8563460286781577, 0.6504679413519787], 
             UndirectedEdge[232, 383] -> 
             RGBColor[
              0.9942485295727967, 0.9916719257518454, 0.7291552303242099], 
             UndirectedEdge[185, 441] -> 
             RGBColor[
              0.9921248620255623, 0.990556150386199, 0.7470800298878211], 
             UndirectedEdge[83, 207] -> 
             RGBColor[
              0.8814274192104727, 0.9082903146412471, 0.9885525281754828], 
             UndirectedEdge[138, 385] -> 
             RGBColor[0.97303321728284, 0.979227088375415, 0.922394574829561],
              UndirectedEdge[131, 234] -> 
             RGBColor[
              0.9822540539871063, 0.9861986769571074, 0.9110271270954899], 
             UndirectedEdge[80, 81] -> 
             RGBColor[
              0.9357010883196132, 0.786001094327252, 0.5707995955625575], 
             UndirectedEdge[5, 486] -> 
             RGBColor[
              0.9914269050832857, 0.9858729377636843, 0.6005243701287567], 
             UndirectedEdge[94, 139] -> 
             RGBColor[
              0.9111178860661479, 0.6848284883750497, 0.24731619155471998`], 
             UndirectedEdge[126, 249] -> 
             RGBColor[
              0.96458905656298, 0.9731111568815445, 0.9448256699723923], 
             UndirectedEdge[359, 483] -> 
             RGBColor[
              0.5854828123511906, 0.6481848904817458, 0.8575525611338763], 
             UndirectedEdge[275, 404] -> 
             RGBColor[
              0.9554501925833875, 0.8604678320079544, 0.2862104048464813], 
             UndirectedEdge[313, 391] -> 
             RGBColor[
              0.9027434297430581, 0.9068126396994972, 0.6842348919204757], 
             UndirectedEdge[1, 487] -> 
             RGBColor[
              0.931960030648797, 0.9436957011447311, 0.7352673692220919], 
             UndirectedEdge[71, 172] -> 
             RGBColor[
              0.9708022317795356, 0.9776505426803213, 0.9300814032525788], 
             UndirectedEdge[44, 494] -> 
             RGBColor[
              0.9540414193274347, 0.8437315316001391, 0.49599286368032014`], 
             UndirectedEdge[85, 387] -> 
             RGBColor[
              0.9262829763794593, 0.7454435966261246, 0.2595437563152183], 
             UndirectedEdge[414, 499] -> 
             RGBColor[
              0.9423012194949019, 0.9536901357877039, 0.868985121374029], 
             UndirectedEdge[89, 376] -> 
             RGBColor[
              0.9796143211647041, 0.9415132972429898, 0.4929200835283628], 
             UndirectedEdge[171, 403] -> 
             RGBColor[
              0.9578313882015561, 0.9665238726264253, 0.8900244068463881], 
             UndirectedEdge[161, 279] -> 
             RGBColor[
              0.9126494006990444, 0.9325934410677907, 0.9709904459951337], 
             UndirectedEdge[149, 310] -> 
             RGBColor[
              0.9830818302689418, 0.971013255399388, 0.6517122352025275], 
             UndirectedEdge[333, 367] -> 
             RGBColor[
              0.9648649633090054, 0.8863852822048119, 0.41891229454522916`], 
             UndirectedEdge[43, 227] -> 
             RGBColor[
              0.9261247555971797, 0.7887751608624847, 0.5936131932211495], 
             UndirectedEdge[71, 369] -> 
             RGBColor[
              0.9671414082668042, 0.9750146966031641, 0.9405052042977566], 
             UndirectedEdge[134, 174] -> 
             RGBColor[
              0.9580691873674243, 0.9659252806336822, 0.8521254847885696], 
             UndirectedEdge[158, 370] -> 
             RGBColor[
              0.9551998126842027, 0.8477982635191684, 0.4269893971189249], 
             UndirectedEdge[7, 391] -> 
             RGBColor[
              0.7786361419360188, 0.8270221959970554, 0.9785638110589938], 
             UndirectedEdge[200, 228] -> 
             RGBColor[
              0.9590524860969354, 0.871567124181541, 0.30568393598348653`], 
             UndirectedEdge[201, 300] -> 
             RGBColor[
              0.9187321340931793, 0.9331905846247115, 0.7374467448380824], 
             UndirectedEdge[210, 320] -> 
             RGBColor[
              0.8559311205254632, 0.887310253830096, 0.9359630268885253], 
             UndirectedEdge[69, 103] -> 
             RGBColor[
              0.9768338341713906, 0.9808867888729282, 0.8633514751152012], 
             UndirectedEdge[97, 281] -> 
             RGBColor[
              0.9089578456413432, 0.9290762686790434, 0.9507503481950328], 
             UndirectedEdge[192, 272] -> 
             RGBColor[
              0.9376578085170408, 0.7713206189119124, 0.4256759862629093], 
             UndirectedEdge[70, 463] -> 
             RGBColor[
              0.9289235965668283, 0.9452628439640851, 0.96189190638602], 
             UndirectedEdge[285, 477] -> 
             RGBColor[
              0.9140373217224365, 0.9075015679020156, 0.6730774311633394], 
             UndirectedEdge[10, 168] -> 
             RGBColor[
              0.963778595188044, 0.9720933824138077, 0.927687642042698], 
             UndirectedEdge[298, 468] -> 
             RGBColor[
              0.5855932080807307, 0.6482305419529514, 0.855723018200407], 
             UndirectedEdge[37, 264] -> 
             RGBColor[
              0.9391689429677768, 0.9517639908774098, 0.8935005797663191], 
             UndirectedEdge[191, 405] -> 
             RGBColor[
              0.965361579596501, 0.9733823225980998, 0.9298603312612167], 
             UndirectedEdge[349, 380] -> 
             RGBColor[
              0.9916438030478574, 0.9905202570419742, 0.7669034840290101], 
             UndirectedEdge[94, 410] -> 
             RGBColor[
              0.9265819128860313, 0.8064867630789997, 0.604406896591151], 
             UndirectedEdge[335, 409] -> 
             RGBColor[
              0.9174962532880164, 0.8376632545299183, 0.6253311654897074], 
             UndirectedEdge[168, 189] -> 
             RGBColor[
              0.9839971391432627, 0.9871723393907825, 0.8934629209673248], 
             UndirectedEdge[187, 399] -> 
             RGBColor[
              0.9571686625354437, 0.931968523654424, 0.6537173292136118], 
             UndirectedEdge[153, 314] -> 
             RGBColor[
              0.9276830906844811, 0.9408013326697444, 0.7766837959217698], 
             UndirectedEdge[233, 355] -> 
             RGBColor[
              0.8567360395946573, 0.8765013170347727, 0.6879164574214491], 
             UndirectedEdge[233, 486] -> 
             RGBColor[
              0.989301050865772, 0.9787019323137035, 0.5922658279275995], 
             UndirectedEdge[49, 264] -> 
             RGBColor[
              0.8070800013022728, 0.8497602426148299, 0.9812615038665539], 
             UndirectedEdge[205, 331] -> 
             RGBColor[
              0.8224480751137861, 0.8576489626876083, 0.7177550485400788], 
             UndirectedEdge[308, 456] -> 
             RGBColor[
              0.8487853181711861, 0.8791696841671752, 0.7961392314473517], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.6621543815636888, 0.7306667959455659, 0.9607534903810869], 
             UndirectedEdge[175, 371] -> 
             RGBColor[
              0.8364021555792454, 0.8726390822494283, 0.984191452745463], 
             UndirectedEdge[21, 188] -> 
             RGBColor[
              0.9936799269624043, 0.9897210760277745, 0.6138638654392603], 
             UndirectedEdge[79, 221] -> 
             RGBColor[
              0.9511048905696073, 0.8852716553466322, 0.6094763058603434], 
             UndirectedEdge[158, 193] -> 
             RGBColor[
              0.9220805101151577, 0.9365545016932377, 0.7940250523719227], 
             UndirectedEdge[266, 483] -> 
             RGBColor[
              0.9149265174961628, 0.9322451330675496, 0.8829984013593014], 
             UndirectedEdge[290, 484] -> 
             RGBColor[
              0.8691551163281812, 0.8507006552213323, 0.6373098738124838], 
             UndirectedEdge[153, 411] -> 
             RGBColor[
              0.9015523444691984, 0.9241867602927865, 0.9852498511411713], 
             UndirectedEdge[176, 475] -> 
             RGBColor[
              0.9774744176858243, 0.9347839720220019, 0.5185082019681071], 
             UndirectedEdge[20, 474] -> 
             RGBColor[
              0.9215099539998535, 0.8195458424702764, 0.6209403588590924], 
             UndirectedEdge[70, 483] -> 
             RGBColor[
              0.9396500333629711, 0.9519589935177822, 0.8853565523736208], 
             UndirectedEdge[163, 266] -> 
             RGBColor[
              0.8638341083096677, 0.8942618860866474, 0.98687446247603], 
             UndirectedEdge[69, 486] -> 
             RGBColor[
              0.9921825253416539, 0.9910352875759084, 0.7792193162720868], 
             UndirectedEdge[262, 475] -> 
             RGBColor[
              0.9776595294168716, 0.9347012913933852, 0.5038661478456822], 
             UndirectedEdge[18, 167] -> 
             RGBColor[
              0.8102288284484069, 0.7685255137883571, 0.6182354926057969], 
             UndirectedEdge[281, 374] -> 
             RGBColor[
              0.9255156357729876, 0.7441938329504705, 0.5652589754193005], 
             UndirectedEdge[138, 294] -> 
             RGBColor[
              0.9746650644532429, 0.9799018991169359, 0.8953506441308842], 
             UndirectedEdge[291, 349] -> 
             RGBColor[
              0.9792628548999573, 0.9833649906050055, 0.8890933696344568], 
             UndirectedEdge[288, 455] -> 
             RGBColor[
              0.9550963067193019, 0.966021427340793, 0.9605459015242436], 
             UndirectedEdge[12, 459] -> 
             RGBColor[
              0.9551333533725072, 0.8544627143649849, 0.3106881108553401], 
             UndirectedEdge[93, 305] -> 
             RGBColor[
              0.9542443960790195, 0.8484093313222483, 0.3231437203716845], 
             UndirectedEdge[127, 184] -> 
             RGBColor[
              0.9153160849831278, 0.9308278541949205, 0.7663956442922515], 
             UndirectedEdge[204, 431] -> 
             RGBColor[
              0.9942724924149673, 0.9901577653524885, 0.6179743293278339], 
             UndirectedEdge[397, 495] -> 
             RGBColor[
              0.992788148498688, 0.9900661843779535, 0.6805346031838346], 
             UndirectedEdge[28, 493] -> 
             RGBColor[
              0.9946058792498182, 0.9918467826060351, 0.7252017116890327], 
             UndirectedEdge[267, 485] -> 
             RGBColor[
              0.9878159483605395, 0.988462718110946, 0.8127987785558035], 
             UndirectedEdge[110, 494] -> 
             RGBColor[
              0.9934986923851324, 0.9892690514666679, 0.5894576992491842], 
             UndirectedEdge[337, 500] -> 
             RGBColor[
              0.8702080760661244, 0.897250490311597, 0.8823821035205094], 
             UndirectedEdge[43, 393] -> 
             RGBColor[
              0.9254814008846062, 0.738655906935425, 0.26124809317445286`], 
             UndirectedEdge[167, 432] -> 
             RGBColor[
              0.9209743095438278, 0.7243965016312001, 0.255272278368843], 
             UndirectedEdge[230, 474] -> 
             RGBColor[
              0.9530584254206591, 0.8400242489680176, 0.3829048778720355], 
             UndirectedEdge[40, 421] -> 
             RGBColor[
              0.9462636991876674, 0.9297847639047248, 0.671129884910799], 
             UndirectedEdge[254, 476] -> 
             RGBColor[
              0.965772370034194, 0.8908456830984391, 0.36858440643159396`], 
             UndirectedEdge[107, 197] -> 
             RGBColor[
              0.7159740439692044, 0.7753363020346604, 0.9359395824743381], 
             UndirectedEdge[231, 395] -> 
             RGBColor[
              0.7662166142197162, 0.8166556907187442, 0.9541157347172746], 
             UndirectedEdge[420, 427] -> 
             RGBColor[
              0.9598639370469033, 0.8663812145143781, 0.4253424470565792], 
             UndirectedEdge[317, 374] -> 
             RGBColor[
              0.7984958981104365, 0.6448303436086273, 0.5933720748611948], 
             UndirectedEdge[188, 200] -> 
             RGBColor[
              0.9711719676510482, 0.9121170485830408, 0.3809909915670824], 
             UndirectedEdge[84, 260] -> 
             RGBColor[
              0.9661479030052268, 0.9553090572817124, 0.6738495200879862], 
             UndirectedEdge[33, 160] -> 
             RGBColor[
              0.9925824640017944, 0.9862666673855212, 0.5807923085657104], 
             UndirectedEdge[135, 362] -> 
             RGBColor[
              0.9173177262732353, 0.9351739530482139, 0.9276111080856788], 
             UndirectedEdge[123, 193] -> 
             RGBColor[
              0.904077924231493, 0.8768318394165842, 0.6386910783984545], 
             UndirectedEdge[439, 453] -> 
             RGBColor[
              0.935570376726935, 0.7630430403315673, 0.3699282267744208], 
             UndirectedEdge[269, 282] -> 
             RGBColor[
              0.9894679352390237, 0.9875516763029363, 0.6525830707846193], 
             UndirectedEdge[202, 459] -> 
             RGBColor[
              0.9655016078103708, 0.8879979129613337, 0.47335945363268184`], 
             UndirectedEdge[25, 474] -> 
             RGBColor[
              0.9224605530421692, 0.8203038243432954, 0.6210310278443583], 
             UndirectedEdge[103, 259] -> 
             RGBColor[
              0.9750636691808225, 0.9723021414525626, 0.6807152142679709], 
             UndirectedEdge[352, 375] -> 
             RGBColor[
              0.9743068938323534, 0.9772268887352433, 0.7435616779826908], 
             UndirectedEdge[300, 308] -> 
             RGBColor[
              0.7738185036719023, 0.8234292556815591, 0.9780383525350091], 
             UndirectedEdge[32, 328] -> 
             RGBColor[
              0.950622512982229, 0.9588922893604743, 0.7626335162969118], 
             UndirectedEdge[209, 486] -> 
             RGBColor[
              0.9833003007095489, 0.9584599929936226, 0.5689540467172537], 
             UndirectedEdge[118, 496] -> 
             RGBColor[
              0.8888603178725469, 0.9131712220052031, 0.9454313687861156], 
             UndirectedEdge[31, 405] -> 
             RGBColor[
              0.9853174446116194, 0.9881964002695119, 0.8929914702281747], 
             UndirectedEdge[21, 228] -> 
             RGBColor[
              0.9815604454082916, 0.9491711516262746, 0.5385568098556643], 
             UndirectedEdge[92, 250] -> 
             RGBColor[
              0.97774138808845, 0.9811781571906462, 0.8445524660875989], 
             UndirectedEdge[177, 290] -> 
             RGBColor[
              0.6175821877752233, 0.6983252193691925, 0.9644697377940403], 
             UndirectedEdge[9, 333] -> 
             RGBColor[
              0.9611581702018981, 0.8860992115516646, 0.5709714520718295], 
             UndirectedEdge[11, 444] -> 
             RGBColor[
              0.8862981848142688, 0.9120688710493807, 0.9853676803447307], 
             UndirectedEdge[11, 25] -> 
             RGBColor[
              0.9359655880598703, 0.9516723102116775, 0.9901050016049104], 
             UndirectedEdge[168, 338] -> 
             RGBColor[
              0.9745865756673022, 0.936951413055223, 0.5896027337471355], 
             UndirectedEdge[283, 430] -> 
             RGBColor[
              0.9943117584640855, 0.9902417514611458, 0.6222481964523872], 
             UndirectedEdge[139, 410] -> 
             RGBColor[
              0.9351759022429567, 0.8410496457275902, 0.6113471992785775], 
             UndirectedEdge[195, 260] -> 
             RGBColor[
              0.9542899497428167, 0.9654300998783063, 0.9622593713816663], 
             UndirectedEdge[391, 407] -> 
             RGBColor[
              0.9069605127650484, 0.926157135228669, 0.8936970949737257], 
             UndirectedEdge[33, 111] -> 
             RGBColor[
              0.9898763636589569, 0.9851476253501512, 0.625639394409723], 
             UndirectedEdge[2, 114] -> 
             RGBColor[
              0.9664032048270457, 0.9744641456864895, 0.9417547901669752], 
             UndirectedEdge[101, 306] -> 
             RGBColor[
              0.982498108405568, 0.9520045131386203, 0.4391984498061387], 
             UndirectedEdge[264, 374] -> 
             RGBColor[
              0.8786978709702535, 0.7080286788358032, 0.6012215118478318], 
             UndirectedEdge[172, 235] -> 
             RGBColor[
              0.9892997407027909, 0.9885986124997979, 0.7365274506585884], 
             UndirectedEdge[84, 475] -> 
             RGBColor[
              0.9705823401630631, 0.9124294671543196, 0.3402183759027634], 
             UndirectedEdge[37, 397] -> 
             RGBColor[
              0.9924621268092155, 0.9899313660309813, 0.6859376262954824], 
             UndirectedEdge[228, 287] -> 
             RGBColor[
              0.9708724258291808, 0.9134079942214879, 0.34134530393754914`], 
             UndirectedEdge[68, 375] -> 
             RGBColor[
              0.7858457967587501, 0.832822310081563, 0.9618504417719861], 
             UndirectedEdge[197, 236] -> 
             RGBColor[
              0.7240230036039365, 0.7788296073202389, 0.786871032040103], 
             UndirectedEdge[107, 214] -> 
             RGBColor[
              0.9863573630013054, 0.9869507093774681, 0.7816094734211713], 
             UndirectedEdge[207, 317] -> 
             RGBColor[
              0.7803056624291602, 0.8284111115674777, 0.978707743523102], 
             UndirectedEdge[98, 462] -> 
             RGBColor[
              0.8859346176116298, 0.8355383144578858, 0.6274803912932498], 
             UndirectedEdge[21, 59] -> 
             RGBColor[
              0.9895053687469197, 0.975971243604179, 0.5694213367533545], 
             UndirectedEdge[46, 350] -> 
             RGBColor[
              0.9358616872501271, 0.7834199933121437, 0.26725101192299927`], 
             UndirectedEdge[271, 429] -> 
             RGBColor[
              0.9918299934545111, 0.9895783934979546, 0.6897576016471676], 
             UndirectedEdge[304, 423] -> 
             RGBColor[
              0.9471527242658432, 0.8286634326741236, 0.550361530330089], 
             UndirectedEdge[299, 328] -> 
             RGBColor[
              0.993913696222301, 0.9893903365762351, 0.5789215779895416], 
             UndirectedEdge[55, 73] -> 
             RGBColor[
              0.9670996637462159, 0.9072405285110083, 0.5639358624237789], 
             UndirectedEdge[53, 440] -> 
             RGBColor[
              0.9737569615018218, 0.9786281763804529, 0.8701770814456184], 
             UndirectedEdge[206, 377] -> 
             RGBColor[
              0.9616482392516769, 0.9288198702572046, 0.6323585634448304], 
             UndirectedEdge[39, 113] -> 
             RGBColor[
              0.9896176713588577, 0.9881801190066982, 0.6912817951850048], 
             UndirectedEdge[9, 450] -> 
             RGBColor[
              0.9529142374409426, 0.96361324598776, 0.9334207301256167], 
             UndirectedEdge[61, 321] -> 
             RGBColor[
              0.9660911176685403, 0.8956192111496707, 0.5258229846632241], 
             UndirectedEdge[76, 460] -> 
             RGBColor[
              0.9690621258024109, 0.913737761689674, 0.5592353071121716], 
             UndirectedEdge[141, 167] -> 
             RGBColor[
              0.9183914990483752, 0.7131952497128846, 0.25314436296982007`], 
             UndirectedEdge[29, 476] -> 
             RGBColor[
              0.9671540994818725, 0.8963237799244406, 0.36969617837855473`], 
             UndirectedEdge[39, 190] -> 
             RGBColor[
              0.9798016467831572, 0.9430970582386182, 0.4127078498565958], 
             UndirectedEdge[115, 215] -> 
             RGBColor[
              0.7909564036305062, 0.8369543657125782, 0.9617977359615286], 
             UndirectedEdge[208, 471] -> 
             RGBColor[
              0.9711427167422462, 0.9111967248751668, 0.42856481152253945`], 
             UndirectedEdge[139, 401] -> 
             RGBColor[
              0.9520235636233332, 0.8391063192730743, 0.3239511674633129], 
             UndirectedEdge[34, 356] -> 
             RGBColor[
              0.775408295923575, 0.8244741211875981, 0.9782491104013002], 
             UndirectedEdge[288, 313] -> 
             RGBColor[
              0.9785564872618293, 0.9662534553630266, 0.6564327781189079], 
             UndirectedEdge[66, 334] -> 
             RGBColor[
              0.9824177062615661, 0.9523529360806817, 0.3861965382740986], 
             UndirectedEdge[17, 328] -> 
             RGBColor[
              0.9914428962357522, 0.9891945916273487, 0.6799101970315127], 
             UndirectedEdge[318, 459] -> 
             RGBColor[
              0.8103160996584844, 0.7690311887410213, 0.6183410715931984], 
             UndirectedEdge[163, 233] -> 
             RGBColor[
              0.9382239285381248, 0.9407250068417893, 0.6958885462320956], 
             UndirectedEdge[141, 300] -> 
             RGBColor[
              0.8726292585793326, 0.7607932039898841, 0.6120151113414211], 
             UndirectedEdge[354, 436] -> 
             RGBColor[
              0.9491548275244635, 0.9616003341358494, 0.9709517938429646], 
             UndirectedEdge[29, 290] -> 
             RGBColor[
              0.8602632183654538, 0.8164045949291073, 0.6251693380840015], 
             UndirectedEdge[110, 360] -> 
             RGBColor[
              0.9928306075627649, 0.9870737194505483, 0.46103406144742554`], 
             UndirectedEdge[289, 308] -> 
             RGBColor[
              0.8407833492581112, 0.8532876394305947, 0.670626284354175], 
             UndirectedEdge[264, 324] -> 
             RGBColor[
              0.8687208769605625, 0.8981584627610697, 0.9873405668324221], 
             UndirectedEdge[109, 382] -> 
             RGBColor[
              0.961844129432657, 0.878245720079087, 0.5197848545796628], 
             UndirectedEdge[293, 497] -> 
             RGBColor[
              0.986634917213493, 0.9650083967668548, 0.5360965586472091], 
             UndirectedEdge[160, 237] -> 
             RGBColor[
              0.9429489215048621, 0.7961250671818296, 0.4870315068463004], 
             UndirectedEdge[35, 123] -> 
             RGBColor[
              0.9646826665953581, 0.8925284829012217, 0.31729925815209814`], 
             UndirectedEdge[218, 432] -> 
             RGBColor[
              0.9499284789268414, 0.8271992941731896, 0.4049889051204304], 
             UndirectedEdge[46, 476] -> 
             RGBColor[
              0.9632915124680455, 0.8810099095454367, 0.3665882502006594], 
             UndirectedEdge[288, 391] -> 
             RGBColor[
              0.8990703707173704, 0.9213478667563724, 0.9552020977334359], 
             UndirectedEdge[259, 486] -> 
             RGBColor[
              0.9904123603510858, 0.9824506401555428, 0.5965830554248567], 
             UndirectedEdge[138, 296] -> 
             RGBColor[
              0.8775966756498357, 0.9047956794933547, 0.965707759352421], 
             UndirectedEdge[56, 494] -> 
             RGBColor[
              0.9905437436053741, 0.9903576092131872, 0.806378170673427], 
             UndirectedEdge[91, 200] -> 
             RGBColor[
              0.870631834737479, 0.837057804715682, 0.6289825884051725], 
             UndirectedEdge[172, 493] -> 
             RGBColor[
              0.9899105914243962, 0.98990516042683, 0.8030147819716567], 
             UndirectedEdge[340, 461] -> 
             RGBColor[
              0.9890156371931578, 0.9729853949879876, 0.5499139571934214], 
             UndirectedEdge[33, 274] -> 
             RGBColor[
              0.9925597243925268, 0.9854364483213538, 0.5215045298565919], 
             UndirectedEdge[235, 345] -> 
             RGBColor[
              0.993977157708839, 0.9905328446359328, 0.659010546101188], 
             UndirectedEdge[205, 490] -> 
             RGBColor[
              0.7936481867570186, 0.839655393073814, 0.9798197334734907], 
             UndirectedEdge[141, 284] -> 
             RGBColor[
              0.946761616663802, 0.8147488145806976, 0.33929055916927015`], 
             UndirectedEdge[489, 500] -> 
             RGBColor[
              0.8709632508255991, 0.8956741968166645, 0.7325872440143323], 
             UndirectedEdge[155, 198] -> 
             RGBColor[
              0.9587947948152994, 0.8652173773581531, 0.3332253579480621], 
             UndirectedEdge[23, 157] -> 
             RGBColor[
              0.981429989531768, 0.9806015377171993, 0.6774776551470806], 
             UndirectedEdge[248, 344] -> 
             RGBColor[
              0.8212124988922909, 0.8578254318913496, 0.8090771140580572], 
             UndirectedEdge[50, 131] -> 
             RGBColor[
              0.7101682285727133, 0.7702243188249732, 0.9341912109763701], 
             UndirectedEdge[442, 500] -> 
             RGBColor[
              0.8546437495110948, 0.8409887038669747, 0.6382356861988805], 
             UndirectedEdge[18, 305] -> 
             RGBColor[
              0.8336075941347951, 0.8533225524011783, 0.6781481456745502], 
             UndirectedEdge[134, 278] -> 
             RGBColor[
              0.9886077509874396, 0.9716086231499292, 0.5484038756648282], 
             UndirectedEdge[158, 422] -> 
             RGBColor[
              0.992155561773151, 0.9841967221613361, 0.5094235954154077], 
             UndirectedEdge[229, 393] -> 
             RGBColor[
              0.9637573157881733, 0.8894070573458855, 0.3137044450040224], 
             UndirectedEdge[17, 143] -> 
             RGBColor[
              0.991592215720554, 0.9895139709068241, 0.6961627014591534], 
             UndirectedEdge[53, 83] -> 
             RGBColor[
              0.9422479208214409, 0.956279559894859, 0.9767627430189416], 
             UndirectedEdge[166, 239] -> 
             RGBColor[
              0.9371146009970068, 0.9513011254256275, 0.9443363570379489], 
             UndirectedEdge[46, 194] -> 
             RGBColor[
              0.961777984044839, 0.8761442486566009, 0.34031541669175625`], 
             UndirectedEdge[319, 368] -> 
             RGBColor[
              0.9792759125854147, 0.9831232487057089, 0.8778094647526602], 
             UndirectedEdge[51, 360] -> 
             RGBColor[
              0.9675752791030623, 0.9719463363136618, 0.7343167255212412], 
             UndirectedEdge[132, 250] -> 
             RGBColor[
              0.9241718739037853, 0.7762543495609093, 0.589550883019853], 
             UndirectedEdge[80, 447] -> 
             RGBColor[
              0.578479477993175, 0.4924198760931997, 0.5834982408659979], 
             UndirectedEdge[128, 179] -> 
             RGBColor[
              0.8969226738856194, 0.9155995788292477, 0.7067956828710078], 
             UndirectedEdge[218, 300] -> 
             RGBColor[
              0.9190850890237727, 0.9339455195320334, 0.7758637108478448], 
             UndirectedEdge[130, 241] -> 
             RGBColor[
              0.9218254644039052, 0.9383234993674049, 0.9087262343515923], 
             UndirectedEdge[134, 252] -> 
             RGBColor[
              0.9501442196418262, 0.9596061264868085, 0.8513695942921999], 
             UndirectedEdge[266, 317] -> 
             RGBColor[
              0.7823462193662001, 0.8300381962796308, 0.9789023736653835], 
             UndirectedEdge[156, 485] -> 
             RGBColor[
              0.9868185128303878, 0.9863293043681527, 0.7042340765573364], 
             UndirectedEdge[96, 110] -> 
             RGBColor[
              0.9926152853925541, 0.9866131671008784, 0.43759757203438643`], 
             UndirectedEdge[50, 373] -> 
             RGBColor[
              0.7153922477454293, 0.7673698568554512, 0.6829392251247295], 
             UndirectedEdge[37, 322] -> 
             RGBColor[
              0.992540795963391, 0.9900996313970911, 0.6945002782377436], 
             UndirectedEdge[65, 290] -> 
             RGBColor[
              0.8859140543344375, 0.909311311304305, 0.8744792601223013], 
             UndirectedEdge[333, 450] -> 
             RGBColor[
              0.9276492273488461, 0.8610588071491397, 0.6297256137784435], 
             UndirectedEdge[238, 266] -> 
             RGBColor[
              0.895997236572935, 0.8647803667619671, 0.6331915436869069], 
             UndirectedEdge[312, 446] -> 
             RGBColor[
              0.9337038867827944, 0.9472552311275347, 0.8864192372810469], 
             UndirectedEdge[407, 448] -> 
             RGBColor[
              0.9771347131805268, 0.9813925004973436, 0.8754400953985597], 
             UndirectedEdge[14, 454] -> 
             RGBColor[
              0.6859624031532867, 0.7454641579649712, 0.7493806765345675], 
             UndirectedEdge[77, 473] -> 
             RGBColor[
              0.9657678341216636, 0.8897204163794383, 0.4341038786490655], 
             UndirectedEdge[57, 136] -> 
             RGBColor[
              0.9021875554538317, 0.9244583999773961, 0.9771676836736273], 
             UndirectedEdge[364, 487] -> 
             RGBColor[
              0.9292149004010728, 0.9445013016693393, 0.9218356762197877], 
             UndirectedEdge[80, 403] -> 
             RGBColor[
              0.9399150114816478, 0.7878987046178634, 0.5079072050697617], 
             UndirectedEdge[330, 352] -> 
             RGBColor[
              0.9875840640183267, 0.969207585295826, 0.4549641687875597], 
             UndirectedEdge[239, 272] -> 
             RGBColor[
              0.9329372758901668, 0.770152179790512, 0.5608685067021149], 
             UndirectedEdge[53, 97] -> 
             RGBColor[
              0.8961862435764647, 0.919551228770636, 0.9723693391235712], 
             UndirectedEdge[304, 311] -> 
             RGBColor[
              0.917751579868715, 0.8071048054753995, 0.6184670679661479], 
             UndirectedEdge[237, 241] -> 
             RGBColor[
              0.8730711369945563, 0.7436114720929159, 0.6085955741954459], 
             UndirectedEdge[361, 441] -> 
             RGBColor[
              0.9882586034135434, 0.9706662607985994, 0.5270312626841436], 
             UndirectedEdge[276, 347] -> 
             RGBColor[
              0.7642544301721035, 0.8158031230826788, 0.9771261226666491], 
             UndirectedEdge[11, 180] -> 
             RGBColor[
              0.9642096611698026, 0.9720894850938759, 0.9123865267614717], 
             UndirectedEdge[56, 360] -> 
             RGBColor[
              0.9898756587830064, 0.9881622771970676, 0.6779545328716683], 
             UndirectedEdge[15, 269] -> 
             RGBColor[
              0.9726467396296311, 0.9308358368195988, 0.585024785334834], 
             UndirectedEdge[8, 387] -> 
             RGBColor[
              0.9342280662719913, 0.8508364831562554, 0.6210932119340649], 
             UndirectedEdge[139, 278] -> 
             RGBColor[
              0.9508958636632793, 0.8353023225112702, 0.3195702660667719], 
             UndirectedEdge[15, 449] -> 
             RGBColor[
              0.8579988313457919, 0.8415995063215385, 0.6356345729322372], 
             UndirectedEdge[348, 355] -> 
             RGBColor[
              0.8568891271061176, 0.8877064141708427, 0.9200863786055231], 
             UndirectedEdge[173, 499] -> 
             RGBColor[
              0.5796922974345877, 0.657726080933873, 0.9640222424379599], 
             UndirectedEdge[130, 483] -> 
             RGBColor[
              0.990534553896657, 0.990353809032468, 0.8065304679290708], 
             UndirectedEdge[173, 282] -> 
             RGBColor[
              0.6306803370557936, 0.6931678370758239, 0.6842909659360796], 
             UndirectedEdge[84, 244] -> 
             RGBColor[
              0.9820051318819685, 0.9671353526141572, 0.6470073678273254], 
             UndirectedEdge[183, 279] -> 
             RGBColor[
              0.8225346877823485, 0.8616666056527699, 0.9828461874389898], 
             UndirectedEdge[124, 381] -> 
             RGBColor[
              0.9495615428106297, 0.9133347908332146, 0.6390818169839613], 
             UndirectedEdge[81, 213] -> 
             RGBColor[
              0.9885479077847532, 0.989377235040495, 0.8325111136929626], 
             UndirectedEdge[134, 210] -> 
             RGBColor[
              0.8610068392569247, 0.8892829398443063, 0.8426678901590878], 
             UndirectedEdge[103, 275] -> 
             RGBColor[
              0.9570857714321168, 0.9107411227721443, 0.6156520411798337], 
             UndirectedEdge[256, 298] -> 
             RGBColor[
              0.9642567867381999, 0.8880215451210638, 0.5227559194752084], 
             UndirectedEdge[18, 235] -> 
             RGBColor[
              0.8392019148558711, 0.8713687679328418, 0.7700111207264818], 
             UndirectedEdge[255, 334] -> 
             RGBColor[
              0.98659785667993, 0.9691474789338048, 0.578751195790802], 
             UndirectedEdge[209, 372] -> 
             RGBColor[
              0.9635939147088564, 0.9450615326211786, 0.6604626462394477], 
             UndirectedEdge[112, 238] -> 
             RGBColor[
              0.974463437768248, 0.9236092683959025, 0.4757957849981732], 
             UndirectedEdge[360, 457] -> 
             RGBColor[
              0.9636872032333597, 0.8824272521986876, 0.3758680067549601], 
             UndirectedEdge[233, 404] -> 
             RGBColor[
              0.9723167808467794, 0.9182801428465335, 0.3469563504373613], 
             UndirectedEdge[259, 348] -> 
             RGBColor[
              0.987858447743633, 0.9813945316598007, 0.6389079966443126], 
             UndirectedEdge[244, 376] -> 
             RGBColor[
              0.9737758567589205, 0.9393760752984305, 0.6150381879424925], 
             UndirectedEdge[182, 371] -> 
             RGBColor[
              0.8920579171071124, 0.9136642950345281, 0.8548386806567386], 
             UndirectedEdge[21, 77] -> 
             RGBColor[
              0.9942117818538037, 0.9908586598616995, 0.6717529881401625], 
             UndirectedEdge[153, 493] -> 
             RGBColor[
              0.9283128584305369, 0.9421483421992717, 0.8452301286039356], 
             UndirectedEdge[276, 382] -> 
             RGBColor[
              0.9088092347795573, 0.9273022557739004, 0.8795871028508738], 
             UndirectedEdge[80, 219] -> 
             RGBColor[
              0.940055799072055, 0.7879569239045727, 0.505573990350109], 
             UndirectedEdge[60, 136] -> 
             RGBColor[
              0.8387628249211816, 0.874637782375792, 0.9709184750373765], 
             UndirectedEdge[23, 96] -> 
             RGBColor[
              0.9819834119433524, 0.9823919327671136, 0.6861265411833268], 
             UndirectedEdge[53, 281] -> 
             RGBColor[
              0.9681459017026794, 0.975763846162933, 0.9388048589246665], 
             UndirectedEdge[141, 162] -> 
             RGBColor[
              0.939171025849741, 0.7892244452362118, 0.3029594637953378], 
             UndirectedEdge[28, 149] -> 
             RGBColor[
              0.9885153630059011, 0.989300851153188, 0.8302325196894843], 
             UndirectedEdge[37, 317] -> 
             RGBColor[
              0.8589669701079599, 0.8885656556502339, 0.8856511427796823], 
             UndirectedEdge[372, 486] -> 
             RGBColor[
              0.9723016649839927, 0.9775646775730715, 0.8736194074144116], 
             UndirectedEdge[63, 453] -> 
             RGBColor[
              0.9363395995336969, 0.7646883301348755, 0.45365338219757945`], 
             UndirectedEdge[82, 242] -> 
             RGBColor[
              0.6675660537922357, 0.7313635877219666, 0.8652714846348424], 
             UndirectedEdge[4, 191] -> 
             RGBColor[
              0.967819128938453, 0.9696923430400477, 0.6989076979188569], 
             UndirectedEdge[70, 403] -> 
             RGBColor[
              0.9394740250771949, 0.9518862095684072, 0.888273465163775], 
             UndirectedEdge[144, 458] -> 
             RGBColor[
              0.9645973428267511, 0.9711987051793765, 0.858264547016721], 
             UndirectedEdge[16, 224] -> 
             RGBColor[
              0.6337521663711823, 0.7082869132449412, 0.9673109752897076], 
             UndirectedEdge[40, 206] -> 
             RGBColor[
              0.9396838933619043, 0.9541167571461904, 0.9724160642891901], 
             UndirectedEdge[148, 485] -> 
             RGBColor[
              0.9209017402076445, 0.9386098833782444, 0.9522320225007115], 
             UndirectedEdge[34, 291] -> 
             RGBColor[
              0.8663250506171079, 0.8958237656948022, 0.9561594140929307], 
             UndirectedEdge[222, 339] -> 
             RGBColor[
              0.9742169763204823, 0.9226045097730126, 0.5067636676357763], 
             UndirectedEdge[197, 314] -> 
             RGBColor[
              0.723761644334825, 0.778270586271085, 0.7584236885197657], 
             UndirectedEdge[330, 358] -> 
             RGBColor[
              0.9853023822251785, 0.9698609445809443, 0.6088548292858196], 
             UndirectedEdge[312, 415] -> 
             RGBColor[
              0.9889765811756657, 0.9897095472742653, 0.8323501078200554], 
             UndirectedEdge[370, 443] -> 
             RGBColor[
              0.9363426439713918, 0.7851928926942142, 0.2683355302286494], 
             UndirectedEdge[160, 305] -> 
             RGBColor[
              0.9885133531100336, 0.9725406008749395, 0.564984581138334], 
             UndirectedEdge[266, 343] -> 
             RGBColor[
              0.9113993114492075, 0.930786542722073, 0.9414533336739919], 
             UndirectedEdge[47, 468] -> 
             RGBColor[
              0.5837898450860415, 0.6474848050103323, 0.8856094099762344], 
             UndirectedEdge[388, 436] -> 
             RGBColor[
              0.9688907776243865, 0.9739756570079717, 0.8152620246739295], 
             UndirectedEdge[69, 209] -> 
             RGBColor[
              0.9834747750665174, 0.9585321426240154, 0.566062555097123], 
             UndirectedEdge[197, 470] -> 
             RGBColor[
              0.7035666725376143, 0.7101950933272394, 0.615754917750508], 
             UndirectedEdge[13, 298] -> 
             RGBColor[
              0.9430225868707383, 0.8008274203454376, 0.5055148038936533], 
             UndirectedEdge[168, 383] -> 
             RGBColor[
              0.9908547793475941, 0.9902685228183217, 0.7853984542998622], 
             UndirectedEdge[123, 428] -> 
             RGBColor[
              0.9636945683613449, 0.9235029827796715, 0.6143681908824834], 
             UndirectedEdge[137, 485] -> 
             RGBColor[
              0.9350272479464483, 0.7881106423722144, 0.5736796919954217], 
             UndirectedEdge[394, 467] -> 
             RGBColor[
              0.9929379248903356, 0.9913476647021713, 0.7667003908390633], 
             UndirectedEdge[232, 395] -> 
             RGBColor[
              0.7818649317681777, 0.8267851961956239, 0.8586187971311077], 
             UndirectedEdge[414, 461] -> 
             RGBColor[
              0.9945838080687707, 0.9919008012404241, 0.7301575093394412], 
             UndirectedEdge[224, 333] -> 
             RGBColor[
              0.9125761307531939, 0.8490399290720742, 0.6282879283692379], 
             UndirectedEdge[33, 182] -> 
             RGBColor[
              0.9929683655813318, 0.986426247605878, 0.574396920711501], 
             UndirectedEdge[158, 451] -> 
             RGBColor[
              0.5865286254446, 0.6476237625558484, 0.7679966085305111], 
             UndirectedEdge[235, 274] -> 
             RGBColor[
              0.9940849342218421, 0.9897565973424358, 0.5975597774811471], 
             UndirectedEdge[284, 345] -> 
             RGBColor[
              0.9933741889168015, 0.9892431553592611, 0.5933811141799532], 
             UndirectedEdge[70, 238] -> 
             RGBColor[
              0.9207207524397432, 0.8844942272121997, 0.6355496947012262], 
             UndirectedEdge[21, 55] -> 
             RGBColor[
              0.9910510867925657, 0.9905674086592161, 0.7979701810995812], 
             UndirectedEdge[55, 60] -> 
             RGBColor[
              0.8573305900433345, 0.8878889704404619, 0.9127701952663811], 
             UndirectedEdge[219, 258] -> 
             RGBColor[
              0.9541187788954242, 0.8483448267824001, 0.5171290477927918], 
             UndirectedEdge[175, 463] -> 
             RGBColor[
              0.9272110229754629, 0.9438972842689022, 0.961728559588043], 
             UndirectedEdge[101, 431] -> 
             RGBColor[
              0.9939324704774468, 0.9894304928096234, 0.5809650398008818], 
             UndirectedEdge[14, 213] -> 
             RGBColor[
              0.993758314361771, 0.9903045262343178, 0.6526192110279058], 
             UndirectedEdge[378, 487] -> 
             RGBColor[
              0.9315728689441914, 0.9427163833830915, 0.705985696164402], 
             UndirectedEdge[8, 159] -> 
             RGBColor[
              0.815820484322715, 0.8568641864161475, 0.9761809803571236], 
             UndirectedEdge[311, 469] -> 
             RGBColor[
              0.8615543057248685, 0.8926507170471178, 0.9866021653823958], 
             UndirectedEdge[343, 440] -> 
             RGBColor[
              0.9885619179871565, 0.989538073389459, 0.8392221499675829], 
             UndirectedEdge[371, 460] -> 
             RGBColor[
              0.8887369537200722, 0.9122909913291208, 0.9098756383577378], 
             UndirectedEdge[224, 358] -> 
             RGBColor[
              0.9390633338635657, 0.9520997761326793, 0.9117281434694482], 
             UndirectedEdge[455, 475] -> 
             RGBColor[
              0.9477654087696776, 0.9143672695542242, 0.6468304007851062], 
             UndirectedEdge[310, 408] -> 
             RGBColor[
              0.8586493146656077, 0.8737056688748301, 0.6818420051974866], 
             UndirectedEdge[154, 376] -> 
             RGBColor[
              0.9776840794917414, 0.9411790933605771, 0.5586371326827893], 
             UndirectedEdge[282, 499] -> 
             RGBColor[
              0.9415570933364983, 0.9510213619942829, 0.7096931889335056], 
             UndirectedEdge[14, 192] -> 
             RGBColor[
              0.9940266118629261, 0.9896318517140095, 0.5912117486370203], 
             UndirectedEdge[75, 147] -> 
             RGBColor[
              0.9392361936341505, 0.8841424152829567, 0.6339309406928229], 
             UndirectedEdge[175, 351] -> 
             RGBColor[
              0.9102012885116852, 0.9312114521567005, 0.9905216031859574], 
             UndirectedEdge[109, 205] -> 
             RGBColor[
              0.7916487548949465, 0.7467159792828, 0.6147682620095394], 
             UndirectedEdge[43, 148] -> 
             RGBColor[
              0.8773191672421017, 0.7504566884821777, 0.6096834451859001], 
             UndirectedEdge[56, 92] -> 
             RGBColor[
              0.9906855608941822, 0.9904162543066475, 0.8040278911864962], 
             UndirectedEdge[46, 412] -> 
             RGBColor[
              0.9460533886857734, 0.8716612370321839, 0.6103904656305652], 
             UndirectedEdge[170, 214] -> 
             RGBColor[
              0.9933902522459609, 0.990850109640677, 0.7094406687776489], 
             UndirectedEdge[94, 437] -> 
             RGBColor[
              0.9040423986544446, 0.7888996516707742, 0.6156151450209454], 
             UndirectedEdge[173, 249] -> 
             RGBColor[
              0.6113565874823899, 0.6825050336570264, 0.9507717396812791], 
             UndirectedEdge[181, 302] -> 
             RGBColor[
              0.9851555099403799, 0.9872109555144055, 0.8545437086559964], 
             UndirectedEdge[188, 279] -> 
             RGBColor[
              0.9298333571682618, 0.9420056695791035, 0.7355282183543488], 
             UndirectedEdge[317, 471] -> 
             RGBColor[
              0.8603999865447058, 0.887984943255091, 0.7766157174948838], 
             UndirectedEdge[8, 344] -> 
             RGBColor[
              0.9684074616051935, 0.9736350119929537, 0.817652093015715], 
             UndirectedEdge[236, 493] -> 
             RGBColor[
              0.9946926258909963, 0.9910563883757043, 0.6637032654303343], 
             UndirectedEdge[31, 366] -> 
             RGBColor[
              0.9229380869692227, 0.9400596136766844, 0.9456962317120368], 
             UndirectedEdge[176, 261] -> 
             RGBColor[
              0.9819991900988243, 0.9843453259779653, 0.836973741285995], 
             UndirectedEdge[144, 145] -> 
             RGBColor[
              0.9779232964725229, 0.9355048360093059, 0.5122209648102558], 
             UndirectedEdge[144, 375] -> 
             RGBColor[
              0.9752099801594576, 0.9791584990728857, 0.8418570514852217], 
             UndirectedEdge[258, 293] -> 
             RGBColor[
              0.9556582737672357, 0.84877886541825, 0.4768900567132225], 
             UndirectedEdge[242, 269] -> 
             RGBColor[
              0.9890386728255859, 0.98973522376719, 0.8313210884928373], 
             UndirectedEdge[45, 216] -> 
             RGBColor[
              0.8078568739895435, 0.8501906797513217, 0.9524932190700334], 
             UndirectedEdge[82, 323] -> 
             RGBColor[
              0.6155080023948377, 0.5271313551666414, 0.5855017169929821], 
             UndirectedEdge[258, 272] -> 
             RGBColor[
              0.8986056713741147, 0.6290050555968048, 0.2369269879660724], 
             UndirectedEdge[92, 356] -> 
             RGBColor[
              0.891512553761185, 0.9133247560168394, 0.8587067360213279], 
             UndirectedEdge[114, 327] -> 
             RGBColor[
              0.9640785100594003, 0.9727303921351178, 0.9456898920310988], 
             UndirectedEdge[188, 459] -> 
             RGBColor[
              0.9646044245473466, 0.8860789286808677, 0.3757065922257942], 
             UndirectedEdge[465, 469] -> 
             RGBColor[
              0.8860101855200402, 0.887724089645619, 0.6738269600041782], 
             UndirectedEdge[44, 62] -> 
             RGBColor[
              0.952766123428302, 0.8432041639722381, 0.5171278170889398], 
             UndirectedEdge[88, 337] -> 
             RGBColor[
              0.9932926982533181, 0.9912536206586751, 0.7433207530975907], 
             UndirectedEdge[253, 388] -> 
             RGBColor[
              0.9926940962294251, 0.9857466405920827, 0.5341926457508778], 
             UndirectedEdge[80, 238] -> 
             RGBColor[
              0.9211617388441962, 0.7205067222616559, 0.25518343460721293`], 
             UndirectedEdge[171, 272] -> 
             RGBColor[
              0.9024590682706539, 0.7472423207275394, 0.607489132300016], 
             UndirectedEdge[297, 392] -> 
             RGBColor[
              0.9215874435480231, 0.9369139859958151, 0.8549896392543719], 
             UndirectedEdge[82, 499] -> 
             RGBColor[
              0.6170072765844674, 0.6937382841157621, 0.9662647434285048], 
             UndirectedEdge[297, 484] -> 
             RGBColor[
              0.9772263617833445, 0.9331445201840995, 0.5103120880150981], 
             UndirectedEdge[73, 240] -> 
             RGBColor[
              0.9701277543864745, 0.9072481522653804, 0.4232854965803694], 
             UndirectedEdge[229, 263] -> 
             RGBColor[
              0.9800510133786896, 0.9443695252608244, 0.37700238333657266`], 
             UndirectedEdge[87, 91] -> 
             RGBColor[
              0.8925496133436546, 0.9125687470476962, 0.737231305958721], 
             UndirectedEdge[296, 339] -> 
             RGBColor[
              0.873912105385597, 0.8461599216142683, 0.6307576675231692], 
             UndirectedEdge[62, 157] -> 
             RGBColor[
              0.9916815264353773, 0.9869759981208276, 0.6032011698193713], 
             UndirectedEdge[227, 265] -> 
             RGBColor[
              0.9761548140107192, 0.9786040275569036, 0.7403513479012218], 
             UndirectedEdge[38, 127] -> 
             RGBColor[
              0.9153278009289909, 0.9308529134184578, 0.767670852697006], 
             UndirectedEdge[302, 451] -> 
             RGBColor[
              0.5852872475892169, 0.6481040194268844, 0.860793575345159], 
             UndirectedEdge[141, 151] -> 
             RGBColor[
              0.9469117038904542, 0.8150698359823605, 0.3556266275593736], 
             UndirectedEdge[72, 439] -> 
             RGBColor[
              0.9936266537970762, 0.9887763818531201, 0.547678781424324], 
             UndirectedEdge[277, 340] -> 
             RGBColor[
              0.9876497562770116, 0.9725480465809211, 0.5818164765842893], 
             UndirectedEdge[53, 322] -> 
             RGBColor[
              0.9746999898955595, 0.977934332567947, 0.7757670938246223], 
             UndirectedEdge[450, 461] -> 
             RGBColor[
              0.9572697627254603, 0.9652868891715038, 0.8519720665992205], 
             UndirectedEdge[352, 367] -> 
             RGBColor[
              0.9936338482125253, 0.9887917699802988, 0.5484618491471795], 
             UndirectedEdge[239, 251] -> 
             RGBColor[
              0.9662175091486784, 0.974202616325569, 0.9365592391924837], 
             UndirectedEdge[83, 163] -> 
             RGBColor[
              0.9094876741672357, 0.9306648002684398, 0.9912289403429442], 
             UndirectedEdge[179, 245] -> 
             RGBColor[
              0.8975810283795429, 0.9170077325218999, 0.7784535066416008], 
             UndirectedEdge[133, 237] -> 
             RGBColor[
              0.8956552659277088, 0.6190767575570819, 0.23464453497765156`], 
             UndirectedEdge[199, 244] -> 
             RGBColor[
              0.8175272020431393, 0.8574743758261916, 0.9397473070665396], 
             UndirectedEdge[173, 269] -> 
             RGBColor[
              0.6276031393371131, 0.6942563952425262, 0.9069121242890734], 
             UndirectedEdge[209, 379] -> 
             RGBColor[
              0.9767412648189742, 0.9548668048064946, 0.6382076118811044], 
             UndirectedEdge[139, 451] -> 
             RGBColor[
              0.5493194377115366, 0.5123926855118202, 0.5938787471210731], 
             UndirectedEdge[18, 218] -> 
             RGBColor[
              0.8391829978314206, 0.8713283063303466, 0.7679521193573843], 
             UndirectedEdge[59, 287] -> 
             RGBColor[
              0.9788173491678089, 0.9402080861993922, 0.3722098308352393], 
             UndirectedEdge[167, 274] -> 
             RGBColor[
              0.9651118478143778, 0.886913343197951, 0.4457841493604622], 
             UndirectedEdge[402, 461] -> 
             RGBColor[
              0.9203513787568629, 0.9358491719177809, 0.8484507581788653], 
             UndirectedEdge[472, 488] -> 
             RGBColor[
              0.6648331845329154, 0.7302334760517014, 0.9105622007007093], 
             UndirectedEdge[227, 270] -> 
             RGBColor[
              0.9070237466918736, 0.9281023523994871, 0.9702685561894491], 
             UndirectedEdge[124, 363] -> 
             RGBColor[
              0.8842462246589349, 0.8614634875272571, 0.6373150791828104], 
             UndirectedEdge[118, 195] -> 
             RGBColor[
              0.9707346254947238, 0.9776861871157103, 0.9340500137150873], 
             UndirectedEdge[54, 154] -> 
             RGBColor[
              0.9927190203690903, 0.9912571420570467, 0.7703282052628387], 
             UndirectedEdge[313, 498] -> 
             RGBColor[
              0.9775104051898709, 0.9357994572767678, 0.36713260027661054`], 
             UndirectedEdge[243, 283] -> 
             RGBColor[
              0.9815274603271029, 0.94824121584301, 0.47701493770577796`], 
             UndirectedEdge[302, 346] -> 
             RGBColor[
              0.985018256680549, 0.9871085922579553, 0.8547760426235066], 
             UndirectedEdge[13, 477] -> 
             RGBColor[
              0.8730440610614711, 0.7478272717064334, 0.6094295629237709], 
             UndirectedEdge[140, 479] -> 
             RGBColor[
              0.9489406661935812, 0.8352737865115704, 0.27777466538399564`], 
             UndirectedEdge[174, 309] -> 
             RGBColor[
              0.9579257345922236, 0.9656184496528284, 0.836511535495878], 
             UndirectedEdge[299, 312] -> 
             RGBColor[
              0.9930837962393921, 0.9905819919115139, 0.7042418560427843], 
             UndirectedEdge[215, 402] -> 
             RGBColor[
              0.7358923704250406, 0.7935634831703187, 0.9744247278801613], 
             UndirectedEdge[372, 400] -> 
             RGBColor[
              0.9732252290548606, 0.9767156958128809, 0.7688401800826427], 
             UndirectedEdge[29, 426] -> 
             RGBColor[
              0.7338685306463895, 0.7158865417070407, 0.6137868260549315], 
             UndirectedEdge[361, 481] -> 
             RGBColor[
              0.9874750169413244, 0.9689902485672681, 0.4417427109182558], 
             UndirectedEdge[188, 335] -> 
             RGBColor[
              0.9509006629304178, 0.958804167337066, 0.7375376367849491], 
             UndirectedEdge[168, 443] -> 
             RGBColor[
              0.9715479161251477, 0.9267013009083462, 0.5777981152285703], 
             UndirectedEdge[81, 500] -> 
             RGBColor[
              0.8660462225576613, 0.8953744121608666, 0.9444115651016818], 
             UndirectedEdge[75, 310] -> 
             RGBColor[
              0.9639594832763654, 0.8867392361907551, 0.3319355364245806], 
             UndirectedEdge[348, 444] -> 
             RGBColor[
              0.9098578688474808, 0.9291897101305295, 0.9253382856966896], 
             UndirectedEdge[262, 482] -> 
             RGBColor[
              0.9900005012840728, 0.9763302872994466, 0.5518084931527725], 
             UndirectedEdge[83, 395] -> 
             RGBColor[
              0.7496919931521571, 0.8041620408522444, 0.9762069656107644], 
             UndirectedEdge[26, 459] -> 
             RGBColor[
              0.9478563204651292, 0.8299155736398185, 0.28241821216253227`], 
             UndirectedEdge[186, 498] -> 
             RGBColor[
              0.982915081916611, 0.9536999608028012, 0.4162525039324987], 
             UndirectedEdge[167, 284] -> 
             RGBColor[
              0.9642632777252285, 0.8850983375808572, 0.3534225319241064], 
             UndirectedEdge[175, 359] -> 
             RGBColor[
              0.5313816474204152, 0.6078025433408535, 0.9611416444417675], 
             UndirectedEdge[65, 484] -> 
             RGBColor[
              0.9759593419603134, 0.9326461797986041, 0.5331710893388915], 
             UndirectedEdge[266, 322] -> 
             RGBColor[
              0.9159200452216313, 0.931572172026488, 0.7877515091234448], 
             UndirectedEdge[210, 252] -> 
             RGBColor[
              0.8160154088273572, 0.8568850940301562, 0.9821137710130289], 
             UndirectedEdge[133, 271] -> 
             RGBColor[
              0.9467754506328978, 0.8134560145401957, 0.40026273678116076`], 
             UndirectedEdge[190, 467] -> 
             RGBColor[
              0.978683277160572, 0.9444291191924742, 0.5616859179619842], 
             UndirectedEdge[216, 481] -> 
             RGBColor[
              0.8205655858419806, 0.8563671378686526, 0.7326885458428163], 
             UndirectedEdge[18, 406] -> 
             RGBColor[
              0.8384168825372283, 0.8722887064384275, 0.8734882053318624], 
             UndirectedEdge[315, 364] -> 
             RGBColor[
              0.9909998165158277, 0.9898349990717662, 0.7471225478033304], 
             UndirectedEdge[152, 464] -> 
             RGBColor[
              0.9092750776963129, 0.9255716391317712, 0.7302100007690232], 
             UndirectedEdge[229, 280] -> 
             RGBColor[
              0.9787356526092825, 0.9399325045242184, 0.3718924551324646], 
             UndirectedEdge[164, 259] -> 
             RGBColor[
              0.933064540162267, 0.9394736304226895, 0.6996076689694362], 
             UndirectedEdge[238, 497] -> 
             RGBColor[
              0.9662013621138226, 0.897124156488088, 0.3259449939838823], 
             UndirectedEdge[7, 478] -> 
             RGBColor[
              0.86139709133813, 0.8908826354752029, 0.9048722181860557], 
             UndirectedEdge[137, 227] -> 
             RGBColor[
              0.9242001062849419, 0.7800357778488802, 0.5920072186575465], 
             UndirectedEdge[44, 157] -> 
             RGBColor[
              0.9526045899232718, 0.8392852521844355, 0.33548385042927603`], 
             UndirectedEdge[105, 205] -> 
             RGBColor[
              0.8058531840815162, 0.848767912344863, 0.9595083744040482], 
             UndirectedEdge[305, 460] -> 
             RGBColor[
              0.985578291302531, 0.9713268773898893, 0.6136261509851237], 
             UndirectedEdge[330, 492] -> 
             RGBColor[
              0.9218975830753375, 0.7082883484917122, 0.2950815093569774], 
             UndirectedEdge[94, 123] -> 
             RGBColor[
              0.9303244879155468, 0.7603369031424245, 0.26610007899068966`], 
             UndirectedEdge[418, 444] -> 
             RGBColor[
              0.9089465324034994, 0.9154268612997503, 0.6902227105930672], 
             UndirectedEdge[203, 295] -> 
             RGBColor[
              0.9378159863887392, 0.8621958031586522, 0.6217568673106788], 
             UndirectedEdge[342, 485] -> 
             RGBColor[
              0.8537062493333424, 0.8857825638347697, 0.9456231553768765], 
             UndirectedEdge[279, 430] -> 
             RGBColor[
              0.930474974418984, 0.9433780240009435, 0.8053642964927951], 
             UndirectedEdge[391, 448] -> 
             RGBColor[
              0.8934315136140776, 0.9171424163615177, 0.9647472119598375], 
             UndirectedEdge[174, 252] -> 
             RGBColor[
              0.9130777569378568, 0.9335274348195323, 0.9915713656425107], 
             UndirectedEdge[14, 489] -> 
             RGBColor[
              0.993386196651715, 0.9882620683331391, 0.5215065050812467], 
             UndirectedEdge[6, 158] -> 
             RGBColor[
              0.9860579047579833, 0.963627893251223, 0.4857353493573874], 
             UndirectedEdge[201, 493] -> 
             RGBColor[
              0.9940783116912915, 0.9897424324192285, 0.5968389559002346], 
             UndirectedEdge[66, 446] -> 
             RGBColor[
              0.9297535249597494, 0.9305557117638736, 0.6900563880660868], 
             UndirectedEdge[449, 499] -> 
             RGBColor[
              0.8238319873339786, 0.862873589662925, 0.9829241348839026], 
             UndirectedEdge[202, 477] -> 
             RGBColor[
              0.9235687815264328, 0.9382140617096065, 0.8324979848035139], 
             UndirectedEdge[89, 299] -> 
             RGBColor[
              0.994534338562324, 0.9907178277849777, 0.6464746665404956], 
             UndirectedEdge[57, 91] -> 
             RGBColor[
              0.822844027832254, 0.8618040115432656, 0.9829046850804011], 
             UndirectedEdge[222, 438] -> 
             RGBColor[
              0.9374932758704981, 0.9496665973112672, 0.8602841241260273], 
             UndirectedEdge[83, 346] -> 
             RGBColor[
              0.9537552800938724, 0.9648617295986671, 0.9572837853706868], 
             UndirectedEdge[38, 388] -> 
             RGBColor[
              0.9941098878554524, 0.9898099706415289, 0.6002758265036525], 
             UndirectedEdge[345, 472] -> 
             RGBColor[
              0.990167926052568, 0.9902021989970313, 0.8126064401080724], 
             UndirectedEdge[231, 486] -> 
             RGBColor[
              0.9770894175624422, 0.9811353756068538, 0.8655149911449582], 
             UndirectedEdge[14, 251] -> 
             RGBColor[
              0.9705910048734211, 0.9746287786041237, 0.763593893619797], 
             UndirectedEdge[404, 418] -> 
             RGBColor[
              0.9715585319142583, 0.9157223911518241, 0.34401069651781285`], 
             UndirectedEdge[10, 370] -> 
             RGBColor[
              0.9285733230342881, 0.8305849741996757, 0.6182250570427772], 
             UndirectedEdge[216, 224] -> 
             RGBColor[
              0.7686016032735337, 0.8197166060115156, 0.9774220960497222], 
             UndirectedEdge[116, 143] -> 
             RGBColor[
              0.7746071082780629, 0.8195492244622531, 0.7624264296944487], 
             UndirectedEdge[142, 477] -> 
             RGBColor[
              0.8815213961063137, 0.7844446784335766, 0.6164062056269437], 
             UndirectedEdge[1, 378] -> 
             RGBColor[
              0.9926451424675025, 0.9865258103416381, 0.4537058195895447], 
             UndirectedEdge[47, 298] -> 
             RGBColor[
              0.9904560531667721, 0.9903213469632838, 0.8078314281766413], 
             UndirectedEdge[50, 340] -> 
             RGBColor[
              0.7117205477995208, 0.7549843507817566, 0.668675364177229], 
             UndirectedEdge[144, 417] -> 
             RGBColor[
              0.970571997799195, 0.907733427895852, 0.49914990610812404`], 
             UndirectedEdge[326, 395] -> 
             RGBColor[
              0.7818554375861251, 0.8251994746044777, 0.7437963055208587], 
             UndirectedEdge[14, 166] -> 
             RGBColor[
              0.9414880967217496, 0.9517272877041822, 0.7713710114652623], 
             UndirectedEdge[41, 132] -> 
             RGBColor[
              0.941130506678435, 0.7866700762309892, 0.4474270910893527], 
             UndirectedEdge[6, 35] -> 
             RGBColor[
              0.9746129063478057, 0.9260255133174013, 0.3558763644219316], 
             UndirectedEdge[95, 286] -> 
             RGBColor[
              0.9819458992746137, 0.9494244717705141, 0.4980481122327669], 
             UndirectedEdge[435, 439] -> 
             RGBColor[
              0.9942700633406335, 0.9901525698081056, 0.6177099395771117], 
             UndirectedEdge[354, 388] -> 
             RGBColor[
              0.9748264112681285, 0.9784024428607665, 0.8052145451762657], 
             UndirectedEdge[47, 59] -> 
             RGBColor[
              0.9866722028625021, 0.9747996567019301, 0.6163742274564303], 
             UndirectedEdge[305, 493] -> 
             RGBColor[
              0.9888558629252595, 0.9724916133973822, 0.5454519482271629], 
             UndirectedEdge[26, 335] -> 
             RGBColor[
              0.9341525588482003, 0.9026408122960168, 0.6442492567216871], 
             UndirectedEdge[24, 115] -> 
             RGBColor[
              0.9530195804165116, 0.9036555156369535, 0.6193904797273098], 
             UndirectedEdge[271, 351] -> 
             RGBColor[
              0.9651642399325766, 0.9706390570751943, 0.7773464071867471], 
             UndirectedEdge[12, 40] -> 
             RGBColor[
              0.946751992111051, 0.9314318905919281, 0.6730268107117627], 
             UndirectedEdge[228, 468] -> 
             RGBColor[
              0.5738644344378325, 0.6059087597136935, 0.6334012905825058], 
             UndirectedEdge[1, 108] -> 
             RGBColor[
              0.9931215580992299, 0.9876960332284355, 0.49270223180307404`], 
             UndirectedEdge[97, 343] -> 
             RGBColor[
              0.9109912000617995, 0.9304611257796422, 0.9414144076455355], 
             UndirectedEdge[314, 411] -> 
             RGBColor[
              0.9676707526605464, 0.9725357854200654, 0.7752756444472326], 
             UndirectedEdge[211, 466] -> 
             RGBColor[
              0.9917069167791874, 0.9908386112127461, 0.787101380987659], 
             UndirectedEdge[12, 202] -> 
             RGBColor[
              0.9844669440720749, 0.9578261381949699, 0.5165500723686369], 
             UndirectedEdge[96, 360] -> 
             RGBColor[
              0.9928421599237269, 0.9870984287825233, 0.4622914646452392], 
             UndirectedEdge[199, 482] -> 
             RGBColor[
              0.8184453821914351, 0.8443974862724153, 0.680900660449068], 
             UndirectedEdge[9, 357] -> 
             RGBColor[
              0.9896175004738688, 0.9878435932710419, 0.6668278953793915], 
             UndirectedEdge[330, 441] -> 
             RGBColor[
              0.9882457187988649, 0.9706227979678375, 0.5269812083891727], 
             UndirectedEdge[375, 461] -> 
             RGBColor[
              0.9751585443054476, 0.9790484829821207, 0.8362585762015176], 
             UndirectedEdge[170, 268] -> 
             RGBColor[
              0.9928200090728253, 0.9896304171537686, 0.6473732185147687], 
             UndirectedEdge[66, 245] -> 
             RGBColor[
              0.9889149618960806, 0.973415181917963, 0.4840996212529255], 
             UndirectedEdge[235, 308] -> 
             RGBColor[
              0.8485538305484092, 0.8786745555490443, 0.770943232284093], 
             UndirectedEdge[42, 315] -> 
             RGBColor[
              0.9907780006450673, 0.9793478621953184, 0.521250592451433], 
             UndirectedEdge[238, 403] -> 
             RGBColor[
              0.9729333354933769, 0.9234382307085338, 0.5347141773855126], 
             UndirectedEdge[382, 425] -> 
             RGBColor[
              0.988497146339097, 0.989511288648431, 0.8402955837995828], 
             UndirectedEdge[74, 215] -> 
             RGBColor[
              0.7111520631566971, 0.7740293768946587, 0.9720137210249824], 
             UndirectedEdge[350, 426] -> 
             RGBColor[
              0.7321761968817412, 0.7091770022670069, 0.6124251345837166], 
             UndirectedEdge[78, 497] -> 
             RGBColor[
              0.9858002619365309, 0.9632231535260263, 0.44524948264517783`], 
             UndirectedEdge[109, 490] -> 
             RGBColor[
              0.9333097533403902, 0.8583147584706703, 0.6286403476526676], 
             UndirectedEdge[281, 317] -> 
             RGBColor[
              0.8538977661050068, 0.8859253967294971, 0.9452989674380226], 
             UndirectedEdge[219, 471] -> 
             RGBColor[
              0.9929450639792996, 0.9901773153803441, 0.6812954432593032], 
             UndirectedEdge[183, 243] -> 
             RGBColor[
              0.873599481711717, 0.8665561231077573, 0.6558364808086817], 
             UndirectedEdge[93, 151] -> 
             RGBColor[
              0.9593858352347102, 0.865486878978903, 0.36571333189248467`], 
             UndirectedEdge[176, 478] -> 
             RGBColor[
              0.9917532075187886, 0.9908577536231888, 0.7863342236358741], 
             UndirectedEdge[28, 282] -> 
             RGBColor[
              0.9933479285446999, 0.9891561532461131, 0.588281540608764], 
             UndirectedEdge[125, 305] -> 
             RGBColor[
              0.9273149275306232, 0.9269476910025999, 0.6873764934904634], 
             UndirectedEdge[22, 466] -> 
             RGBColor[
              0.6629346711121571, 0.7276309463592017, 0.8752248246145393], 
             UndirectedEdge[78, 154] -> 
             RGBColor[
              0.9921307618708437, 0.9893712081594679, 0.6606721200144325], 
             UndirectedEdge[273, 421] -> 
             RGBColor[
              0.9833244719811611, 0.9547797884160789, 0.4434497813078463], 
             UndirectedEdge[221, 234] -> 
             RGBColor[
              0.973559112974165, 0.979714004186315, 0.9257453942265871], 
             UndirectedEdge[384, 461] -> 
             RGBColor[
              0.9751123460156177, 0.9790140283732085, 0.8363367778557558], 
             UndirectedEdge[3, 428] -> 
             RGBColor[
              0.9794945212609814, 0.9833083982285363, 0.878429616800778], 
             UndirectedEdge[209, 431] -> 
             RGBColor[
              0.9844752443838993, 0.9581486867869045, 0.4915359378894786], 
             UndirectedEdge[33, 237] -> 
             RGBColor[
              0.9411553707691673, 0.7904493827561581, 0.32495629499750583`], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.9947000208630997, 0.9915938838607261, 0.7024286741570986], 
             UndirectedEdge[202, 243] -> 
             RGBColor[
              0.9817953343606542, 0.948814171314557, 0.5061713731309283], 
             UndirectedEdge[169, 456] -> 
             RGBColor[
              0.9681772527904112, 0.8990924207356139, 0.4467258160002795], 
             UndirectedEdge[86, 297] -> 
             RGBColor[
              0.9943416247647368, 0.9903056324582927, 0.6254989589648396], 
             UndirectedEdge[40, 202] -> 
             RGBColor[
              0.9571202465489146, 0.9649670891882769, 0.8356981534891046], 
             UndirectedEdge[396, 477] -> 
             RGBColor[
              0.8437361065212341, 0.8782362850062759, 0.9849574971237511], 
             UndirectedEdge[209, 355] -> 
             RGBColor[
              0.8507352894384341, 0.8562593777146918, 0.6646046762111033], 
             UndirectedEdge[131, 434] -> 
             RGBColor[
              0.9530809611825204, 0.8651182459121483, 0.5893518778932255], 
             UndirectedEdge[87, 228] -> 
             RGBColor[
              0.980970264703111, 0.9470780665135551, 0.41393265353703507`], 
             UndirectedEdge[17, 116] -> 
             RGBColor[
              0.7723978251227879, 0.8199128375720539, 0.891879541925771], 
             UndirectedEdge[104, 323] -> 
             RGBColor[
              0.9124157003413742, 0.685666567555375, 0.24813763008274514`], 
             UndirectedEdge[101, 347] -> 
             RGBColor[
              0.8483876653967977, 0.8783191450916211, 0.752857180983628], 
             UndirectedEdge[92, 342] -> 
             RGBColor[
              0.8607776573793725, 0.8893144213695034, 0.8556433687839256], 
             UndirectedEdge[399, 464] -> 
             RGBColor[
              0.896922430978497, 0.8841970866875921, 0.6572375034139031], 
             UndirectedEdge[423, 469] -> 
             RGBColor[
              0.8909554501219965, 0.9142093442458419, 0.9184966277463369], 
             UndirectedEdge[114, 415] -> 
             RGBColor[
              0.9781457165020351, 0.9829030251683173, 0.9076072439495291], 
             UndirectedEdge[244, 478] -> 
             RGBColor[
              0.9859232138887627, 0.9882600339077886, 0.8745839960459221], 
             UndirectedEdge[129, 486] -> 
             RGBColor[
              0.8454803839152023, 0.877854789836785, 0.8763697703445228], 
             UndirectedEdge[202, 421] -> 
             RGBColor[
              0.9839786511486914, 0.9561790115077665, 0.514653146567673], 
             UndirectedEdge[62, 378] -> 
             RGBColor[
              0.9920505203516523, 0.9882207012443143, 0.604634641505445], 
             UndirectedEdge[263, 485] -> 
             RGBColor[
              0.9853576714406653, 0.9817715697464304, 0.6670946088218146], 
             UndirectedEdge[275, 346] -> 
             RGBColor[
              0.9656249462013695, 0.9171096253334375, 0.6011974456689584], 
             UndirectedEdge[127, 303] -> 
             RGBColor[
              0.8572913575919543, 0.7049427034690912, 0.6019403482070056], 
             UndirectedEdge[260, 312] -> 
             RGBColor[
              0.971597908980814, 0.97706722850509, 0.8760382036515368], 
             UndirectedEdge[32, 299] -> 
             RGBColor[
              0.9510333492983047, 0.9597710266986369, 0.8073505139139038], 
             UndirectedEdge[283, 396] -> 
             RGBColor[
              0.9147346494711884, 0.9308106046164412, 0.8025244920410657], 
             UndirectedEdge[87, 253] -> 
             RGBColor[
              0.9919822458106777, 0.9842240645254998, 0.4567121207017917], 
             UndirectedEdge[298, 409] -> 
             RGBColor[
              0.9592457144302746, 0.8681543132609971, 0.518723893071267], 
             UndirectedEdge[208, 258] -> 
             RGBColor[
              0.9323164316583709, 0.7693642362772226, 0.26439841605602793`], 
             UndirectedEdge[142, 161] -> 
             RGBColor[
              0.9347066733575781, 0.8262607407235099, 0.600939002203306], 
             UndirectedEdge[71, 211] -> 
             RGBColor[
              0.9749017992530996, 0.9793458191847184, 0.8621409608750921], 
             UndirectedEdge[14, 453] -> 
             RGBColor[
              0.9357233514268826, 0.7633702377466407, 0.3865785788133091], 
             UndirectedEdge[89, 478] -> 
             RGBColor[
              0.9917616782945464, 0.990397255852348, 0.7524658916317923], 
             UndirectedEdge[159, 251] -> 
             RGBColor[
              0.8184596417932914, 0.8588324657364796, 0.9717135751619463], 
             UndirectedEdge[300, 305] -> 
             RGBColor[
              0.9135096853271473, 0.9159397656028649, 0.6860597371650107], 
             UndirectedEdge[327, 385] -> 
             RGBColor[
              0.9716307141407248, 0.9781811038284134, 0.9247686468177589], 
             UndirectedEdge[156, 270] -> 
             RGBColor[
              0.9241349309595388, 0.9375033010090885, 0.7383408622108245], 
             UndirectedEdge[418, 486] -> 
             RGBColor[
              0.988542801933251, 0.9761441806189941, 0.5893201740080511], 
             UndirectedEdge[366, 465] -> 
             RGBColor[
              0.9194383628706768, 0.9141721272233183, 0.6770702168894602], 
             UndirectedEdge[337, 433] -> 
             RGBColor[
              0.992766330305753, 0.9912767059316667, 0.769544157178146], 
             UndirectedEdge[118, 152] -> 
             RGBColor[
              0.9886105981249775, 0.9875715114706054, 0.694003828715883], 
             UndirectedEdge[151, 162] -> 
             RGBColor[
              0.9851928917532464, 0.9614485545058474, 0.41957370113972753`], 
             UndirectedEdge[80, 251] -> 
             RGBColor[
              0.9178229248092571, 0.7726675892540344, 0.6010626630137584], 
             UndirectedEdge[348, 486] -> 
             RGBColor[
              0.9894541383772324, 0.9899070294497735, 0.8244357491116735], 
             UndirectedEdge[376, 455] -> 
             RGBColor[
              0.9498968414727997, 0.921557092546053, 0.6551106143494436], 
             UndirectedEdge[153, 197] -> 
             RGBColor[
              0.6576432361434771, 0.7299215611438062, 0.9683978952137045], 
             UndirectedEdge[9, 319] -> 
             RGBColor[
              0.9775584639292241, 0.9824130395499568, 0.9062720336003852], 
             UndirectedEdge[184, 336] -> 
             RGBColor[
              0.9940308846982099, 0.9896409908766318, 0.5916768203887874], 
             UndirectedEdge[41, 56] -> 
             RGBColor[
              0.9907082954409927, 0.9899432028160207, 0.7685818946556606], 
             UndirectedEdge[99, 313] -> 
             RGBColor[
              0.9885391454042546, 0.9715542693227011, 0.5330806935794116], 
             UndirectedEdge[111, 130] -> 
             RGBColor[
              0.9889971485713736, 0.9897180524209486, 0.8320092528464595], 
             UndirectedEdge[255, 327] -> 
             RGBColor[
              0.9751391633283497, 0.9796319377305278, 0.8666245642033685], 
             UndirectedEdge[32, 84] -> 
             RGBColor[
              0.9443426070237331, 0.9383257734723757, 0.6857651107866037], 
             UndirectedEdge[196, 420] -> 
             RGBColor[
              0.9813171636337317, 0.9476979525357639, 0.4620725994929359], 
             UndirectedEdge[55, 57] -> 
             RGBColor[
              0.9207553205759844, 0.937709588042066, 0.9190194039026318], 
             UndirectedEdge[10, 480] -> 
             RGBColor[
              0.9238422376834254, 0.8118277973242398, 0.6144183147166269], 
             UndirectedEdge[152, 216] -> 
             RGBColor[
              0.8204615959377007, 0.8561447139783901, 0.7213698865132552], 
             UndirectedEdge[244, 482] -> 
             RGBColor[
              0.9839853959229996, 0.9738152482126631, 0.6547003196852454], 
             UndirectedEdge[111, 463] -> 
             RGBColor[
              0.9797747825809549, 0.983643874798275, 0.8836182611975407], 
             UndirectedEdge[58, 74] -> 
             RGBColor[
              0.8067034560570044, 0.4873780972632346, 0.572264130640581], 
             UndirectedEdge[66, 327] -> 
             RGBColor[
              0.9709590129099859, 0.9628373948774047, 0.6740699066866651], 
             UndirectedEdge[168, 346] -> 
             RGBColor[
              0.9825344684846906, 0.9860814820085229, 0.8959388408666823], 
             UndirectedEdge[53, 471] -> 
             RGBColor[
              0.9746481221423784, 0.9778233926885269, 0.7701216089815277], 
             UndirectedEdge[28, 125] -> 
             RGBColor[
              0.9330649438551819, 0.9463028602112529, 0.8671262569523333], 
             UndirectedEdge[405, 423] -> 
             RGBColor[
              0.98676298511503, 0.9887941684163686, 0.8690351231477569], 
             UndirectedEdge[314, 493] -> 
             RGBColor[
              0.9944312666218849, 0.9904973673265505, 0.6352559219099969], 
             UndirectedEdge[43, 229] -> 
             RGBColor[
              0.9316452391967103, 0.7594479809002128, 0.28519344107378264`], 
             UndirectedEdge[281, 397] -> 
             RGBColor[
              0.9873929228062625, 0.9872911071102445, 0.7455854509538227], 
             UndirectedEdge[203, 324] -> 
             RGBColor[
              0.8908935694346025, 0.8249953204617766, 0.6247070824603935], 
             UndirectedEdge[403, 445] -> 
             RGBColor[
              0.9929363514726635, 0.9904015913429819, 0.6980042157745108], 
             UndirectedEdge[147, 303] -> 
             RGBColor[
              0.9057108035210635, 0.7435510553421159, 0.6065586381842736], 
             UndirectedEdge[356, 457] -> 
             RGBColor[
              0.8613323727894311, 0.805939049973754, 0.6227734304031818], 
             UndirectedEdge[8, 85] -> 
             RGBColor[
              0.9342790299523627, 0.8510385371662885, 0.621134218507563], 
             UndirectedEdge[301, 336] -> 
             RGBColor[
              0.9511014694739601, 0.959894603114863, 0.8129713895185533], 
             UndirectedEdge[24, 64] -> 
             RGBColor[
              0.9630404780843363, 0.8853269438288087, 0.3195756589775198], 
             UndirectedEdge[30, 488] -> 
             RGBColor[
              0.666305747548406, 0.73084241870175, 0.8861580206631072], 
             UndirectedEdge[191, 366] -> 
             RGBColor[
              0.9029822219541044, 0.9252455360052723, 0.9825650927450789], 
             UndirectedEdge[185, 481] -> 
             RGBColor[
              0.9913412755533432, 0.9888801381548677, 0.6617914781219332], 
             UndirectedEdge[308, 389] -> 
             RGBColor[
              0.847286623772043, 0.8752247114075572, 0.6958902778004568], 
             UndirectedEdge[96, 240] -> 
             RGBColor[
              0.9932330853391231, 0.9879345787174336, 0.5048412835991132], 
             UndirectedEdge[108, 113] -> 
             RGBColor[
              0.9896221628147048, 0.9881897257765992, 0.6917706624359049], 
             UndirectedEdge[85, 332] -> 
             RGBColor[
              0.915324662122666, 0.836093103635617, 0.6251601827979225], 
             UndirectedEdge[232, 280] -> 
             RGBColor[
              0.9905087851777048, 0.9806162509798575, 0.5820302082934711], 
             UndirectedEdge[310, 419] -> 
             RGBColor[
              0.9892081606673848, 0.9736357897073997, 0.5505795769028856], 
             UndirectedEdge[39, 378] -> 
             RGBColor[
              0.9927299049387773, 0.9867071086968948, 0.462931691494484], 
             UndirectedEdge[53, 257] -> 
             RGBColor[
              0.9742701550470676, 0.9770149592899925, 0.7289822231994785], 
             UndirectedEdge[248, 339] -> 
             RGBColor[
              0.8006228748502484, 0.7889058177012716, 0.6234528819502048], 
             UndirectedEdge[327, 334] -> 
             RGBColor[
              0.9694343828772343, 0.9576944597767785, 0.6681470069116485], 
             UndirectedEdge[165, 358] -> 
             RGBColor[
              0.8689619173045326, 0.8967760918713539, 0.904889676242209], 
             UndirectedEdge[69, 204] -> 
             RGBColor[
              0.9932720230975853, 0.9905412211895994, 0.6925009465354783], 
             UndirectedEdge[208, 293] -> 
             RGBColor[
              0.9717053309464012, 0.9124000997688326, 0.4898018955924228], 
             UndirectedEdge[265, 320] -> 
             RGBColor[
              0.9892068268643465, 0.9882065820755641, 0.7123636927507457], 
             UndirectedEdge[239, 453] -> 
             RGBColor[
              0.9313498557021399, 0.762944075468086, 0.5595439243859957], 
             UndirectedEdge[108, 452] -> 
             RGBColor[
              0.9932964659639265, 0.9897091445540862, 0.6308779504615611], 
             UndirectedEdge[331, 418] -> 
             RGBColor[
              0.9889932573989071, 0.9742832673908728, 0.43304599468684], 
             UndirectedEdge[28, 201] -> 
             RGBColor[
              0.9936231565731688, 0.989744838169186, 0.6182384129971045], 
             UndirectedEdge[431, 486] -> 
             RGBColor[
              0.9931829946590358, 0.9906518317387973, 0.7046926990644424], 
             UndirectedEdge[269, 419] -> 
             RGBColor[
              0.9907617000986679, 0.9903189085180228, 0.7934013915656976], 
             UndirectedEdge[315, 378] -> 
             RGBColor[
              0.9933577850589463, 0.9880500807855184, 0.5312725677479448], 
             UndirectedEdge[57, 240] -> 
             RGBColor[
              0.923783411216243, 0.9377172117964379, 0.7783690380592223], 
             UndirectedEdge[7, 176] -> 
             RGBColor[
              0.864371086854097, 0.8921124590492537, 0.8555854160328026], 
             UndirectedEdge[6, 302] -> 
             RGBColor[
              0.9848165269026001, 0.964108150122259, 0.5785323161720354], 
             UndirectedEdge[176, 455] -> 
             RGBColor[
              0.9650181941186089, 0.971670874729462, 0.8653696202996201], 
             UndirectedEdge[161, 396] -> 
             RGBColor[
              0.8969213837724983, 0.9200523472962092, 0.9694902937001133], 
             UndirectedEdge[36, 463] -> 
             RGBColor[
              0.9670036715956607, 0.9329290321533872, 0.6235375260455926], 
             UndirectedEdge[131, 373] -> 
             RGBColor[
              0.9850164242423867, 0.9815953273351139, 0.6678383807672738], 
             UndirectedEdge[54, 341] -> 
             RGBColor[
              0.9769415570124852, 0.9806020637717796, 0.8468207889048645], 
             UndirectedEdge[272, 453] -> 
             RGBColor[
              0.8793545480809973, 0.5450590049445434, 0.22104281643919804`], 
             UndirectedEdge[169, 236] -> 
             RGBColor[
              0.9681882074122952, 0.8991158515641415, 0.44791815898826065`], 
             UndirectedEdge[69, 101] -> 
             RGBColor[
              0.9929320011600647, 0.9898139486467343, 0.6554916570085263], 
             UndirectedEdge[286, 330] -> 
             RGBColor[
              0.9754798664830227, 0.9289499734254081, 0.3592443408355651], 
             UndirectedEdge[86, 254] -> 
             RGBColor[
              0.9660420395250435, 0.8914224788715983, 0.3979362663033726], 
             UndirectedEdge[68, 319] -> 
             RGBColor[
              0.7926012416670443, 0.8378605098331431, 0.9504152356444576], 
             UndirectedEdge[37, 207] -> 
             RGBColor[
              0.9123946040946643, 0.9304148598300577, 0.8909468194228672], 
             UndirectedEdge[257, 317] -> 
             RGBColor[
              0.860022019449395, 0.8871765098565567, 0.7354763317128346], 
             UndirectedEdge[94, 158] -> 
             RGBColor[
              0.9483270737992113, 0.8200595654190781, 0.42143405296415787`], 
             UndirectedEdge[253, 336] -> 
             RGBColor[
              0.9926268090180457, 0.9856027200507228, 0.5268688480407672], 
             UndirectedEdge[67, 363] -> 
             RGBColor[
              0.9024034055732347, 0.921341960334568, 0.8243439718511613], 
             UndirectedEdge[61, 295] -> 
             RGBColor[
              0.9420552799887401, 0.8790031896218067, 0.6251679024502496], 
             UndirectedEdge[16, 116] -> 
             RGBColor[
              0.4668289745130376, 0.5759934160931307, 0.9517328498633311], 
             UndirectedEdge[294, 439] -> 
             RGBColor[
              0.9909615293287503, 0.9888840453036922, 0.6797836381698559], 
             UndirectedEdge[69, 346] -> 
             RGBColor[
              0.9853730089406433, 0.9872552914342215, 0.8488968796043257], 
             UndirectedEdge[327, 415] -> 
             RGBColor[
              0.9720428959682889, 0.978351551606701, 0.9179377272426452], 
             UndirectedEdge[54, 61] -> 
             RGBColor[
              0.9673301629040032, 0.8961315881965447, 0.5052887985653212], 
             UndirectedEdge[244, 262] -> 
             RGBColor[
              0.989082321135777, 0.9894071768532229, 0.8106551397702441], 
             UndirectedEdge[295, 397] -> 
             RGBColor[
              0.968936477756138, 0.9735263206115168, 0.7768273982118705], 
             UndirectedEdge[61, 264] -> 
             RGBColor[
              0.9136939602361305, 0.856602822005867, 0.629888491620733], 
             UndirectedEdge[162, 226] -> 
             RGBColor[
              0.9247393654358229, 0.7236936458965348, 0.2909173325935972], 
             UndirectedEdge[237, 351] -> 
             RGBColor[
              0.9140440552273876, 0.7762598000920804, 0.6117282053832378], 
             UndirectedEdge[243, 273] -> 
             RGBColor[
              0.981141155193124, 0.9474149482228693, 0.4349680078711015], 
             UndirectedEdge[53, 343] -> 
             RGBColor[
              0.9701792561231357, 0.9771487032635318, 0.9294689183751692], 
             UndirectedEdge[37, 445] -> 
             RGBColor[
              0.9926210032939811, 0.9902711867670182, 0.7032303511902038], 
             UndirectedEdge[144, 402] -> 
             RGBColor[
              0.9204028146108729, 0.9359591880085459, 0.8540492334625693], 
             UndirectedEdge[235, 456] -> 
             RGBColor[
              0.9940708205475071, 0.9897264096201446, 0.5960235911292848], 
             UndirectedEdge[369, 456] -> 
             RGBColor[
              0.9858704048128364, 0.9864578950407717, 0.7721472508670248], 
             UndirectedEdge[7, 61] -> 
             RGBColor[
              0.8370604584918049, 0.796192203535498, 0.6223947264856297], 
             UndirectedEdge[76, 175] -> 
             RGBColor[
              0.916727327661584, 0.8740858526099815, 0.6335511214998968], 
             UndirectedEdge[259, 372] -> 
             RGBColor[
              0.9707059743503933, 0.9690521797830989, 0.6880916549470508], 
             UndirectedEdge[187, 224] -> 
             RGBColor[
              0.9176613165890926, 0.9369149681317287, 0.9827420361051988], 
             UndirectedEdge[142, 183] -> 
             RGBColor[
              0.8445919604408821, 0.755333905308489, 0.612794743647162], 
             UndirectedEdge[255, 299] -> 
             RGBColor[
              0.993313584834711, 0.9906770154009759, 0.7004336643445277], 
             UndirectedEdge[233, 444] -> 
             RGBColor[
              0.9097047813360205, 0.9179846129944595, 0.6931683645126157], 
             UndirectedEdge[148, 280] -> 
             RGBColor[
              0.9244095806546737, 0.9309412121061834, 0.696382459244582], 
             UndirectedEdge[7, 376] -> 
             RGBColor[
              0.8492497342082879, 0.8419986768658447, 0.6453264100826261], 
             UndirectedEdge[73, 256] -> 
             RGBColor[
              0.9413351665815787, 0.8051205149324858, 0.2716551018721578], 
             UndirectedEdge[207, 403] -> 
             RGBColor[
              0.9127099522733467, 0.9305452644060215, 0.8857206840071741], 
             UndirectedEdge[233, 346] -> 
             RGBColor[
              0.9824915344647616, 0.9749219361720166, 0.6619433912598383], 
             UndirectedEdge[293, 403] -> 
             RGBColor[
              0.9933668905930473, 0.9913224709873006, 0.7448657420488394], 
             UndirectedEdge[321, 391] -> 
             RGBColor[
              0.9076668011127542, 0.926449203611228, 0.8819920692365882], 
             UndirectedEdge[228, 298] -> 
             RGBColor[
              0.9805306425185631, 0.948745301666645, 0.5556233087829128], 
             UndirectedEdge[54, 455] -> 
             RGBColor[
              0.9649317823501489, 0.9716351412425226, 0.8668016869294931], 
             UndirectedEdge[323, 419] -> 
             RGBColor[
              0.9413515840065128, 0.7871816652602488, 0.4697484832790613], 
             UndirectedEdge[65, 194] -> 
             RGBColor[
              0.9912914070276496, 0.9843648354108026, 0.5927332669079513], 
             UndirectedEdge[40, 273] -> 
             RGBColor[
              0.9564660673813843, 0.9635678660965893, 0.7644947882292779], 
             UndirectedEdge[209, 400] -> 
             RGBColor[
              0.9842238647804168, 0.9576110112334318, 0.46417481938548477`], 
             UndirectedEdge[31, 488] -> 
             RGBColor[
              0.6640263316005139, 0.7298998216289788, 0.923933841859055], 
             UndirectedEdge[399, 407] -> 
             RGBColor[
              0.9794687528103931, 0.9475247079204948, 0.5678200428215467], 
             UndirectedEdge[292, 399] -> 
             RGBColor[
              0.9794893664293927, 0.9475332321816969, 0.5674784218083889], 
             UndirectedEdge[93, 218] -> 
             RGBColor[
              0.9598197997756448, 0.8664150852514166, 0.4129476940545186], 
             UndirectedEdge[198, 270] -> 
             RGBColor[
              0.9209933784366144, 0.9272761330853356, 0.6946721490984786], 
             UndirectedEdge[78, 192] -> 
             RGBColor[
              0.9938757556331996, 0.9893091854925291, 0.574791979008028], 
             UndirectedEdge[286, 492] -> 
             RGBColor[
              0.9156402514385484, 0.6871808995894861, 0.2707729575459802], 
             UndirectedEdge[317, 343] -> 
             RGBColor[
              0.8559311205254632, 0.887310253830096, 0.9359630268885253], 
             UndirectedEdge[51, 203] -> 
             RGBColor[
              0.9368602176111783, 0.8614829923692751, 0.6233747345466688], 
             UndirectedEdge[212, 216] -> 
             RGBColor[
              0.776344391487666, 0.8258904951610775, 0.9781606101016547], 
             UndirectedEdge[100, 257] -> 
             RGBColor[
              0.9882400339303437, 0.971583825642009, 0.4436096448739338], 
             UndirectedEdge[189, 302] -> 
             RGBColor[
              0.9864809273391211, 0.9881994496402149, 0.8523001227241491], 
             UndirectedEdge[306, 382] -> 
             RGBColor[
              0.9819335757883123, 0.9533023308342954, 0.5598611216088952], 
             UndirectedEdge[20, 150] -> 
             RGBColor[
              0.897562127286806, 0.7132653911698088, 0.6010850121104936], 
             UndirectedEdge[255, 446] -> 
             RGBColor[
              0.9339336753781133, 0.9473502546169967, 0.8826110455827902], 
             UndirectedEdge[182, 237] -> 
             RGBColor[
              0.9433348230843995, 0.7962846474021865, 0.48063611899209097`], 
             UndirectedEdge[4, 366] -> 
             RGBColor[
              0.9261059171754088, 0.9366633535093787, 0.7029724063013651], 
             UndirectedEdge[231, 275] -> 
             RGBColor[
              0.957515829180137, 0.9110618591364628, 0.6149240655894603], 
             UndirectedEdge[97, 231] -> 
             RGBColor[
              0.8995844858276638, 0.9220856322774693, 0.9666170013958182], 
             UndirectedEdge[114, 128] -> 
             RGBColor[
              0.9813761045515716, 0.9819000254830237, 0.6840617828267661], 
             UndirectedEdge[207, 471] -> 
             RGBColor[
              0.9138276205314104, 0.9298341474349149, 0.7819113941380689], 
             UndirectedEdge[54, 391] -> 
             RGBColor[
              0.9089058463482171, 0.926961580658102, 0.8614578831386854], 
             UndirectedEdge[299, 478] -> 
             RGBColor[
              0.9915518722705992, 0.9899485019817678, 0.7296298006978303], 
             UndirectedEdge[44, 365] -> 
             RGBColor[
              0.9446583107604252, 0.8384284895935928, 0.58777553645838], 
             UndirectedEdge[6, 101] -> 
             RGBColor[
              0.9857462806241368, 0.9629613607389583, 0.4518169855094244], 
             UndirectedEdge[236, 308] -> 
             RGBColor[
              0.84879627279307, 0.8791931149957029, 0.7973315744353328], 
             UndirectedEdge[47, 256] -> 
             RGBColor[
              0.9624534237435107, 0.8872758081784448, 0.5526423112510359], 
             UndirectedEdge[304, 427] -> 
             RGBColor[
              0.9162523936255094, 0.7056756785002704, 0.25147291398335214`], 
             UndirectedEdge[54, 397] -> 
             RGBColor[
              0.9942113606714011, 0.9906547191862548, 0.6569482943269422], 
             UndirectedEdge[220, 254] -> 
             RGBColor[
              0.9394765326857405, 0.7977516508885177, 0.27015960141182166`], 
             UndirectedEdge[377, 426] -> 
             RGBColor[
              0.7448272198158061, 0.7571543740450818, 0.6339564553406323], 
             UndirectedEdge[216, 292] -> 
             RGBColor[
              0.819324522359989, 0.8576611972394133, 0.8846257037358787], 
             UndirectedEdge[42, 119] -> 
             RGBColor[
              0.9629467594687193, 0.9610080634662521, 0.6964341471889854], 
             UndirectedEdge[170, 491] -> 
             RGBColor[
              0.9819819538119774, 0.9535925826944843, 0.5609273049412411], 
             UndirectedEdge[257, 326] -> 
             RGBColor[
              0.9933072206646756, 0.9880931466825592, 0.5129104562753097], 
             UndirectedEdge[98, 347] -> 
             RGBColor[
              0.8220249772972018, 0.7855218713767027, 0.6211342915344584], 
             UndirectedEdge[271, 311] -> 
             RGBColor[
              0.9612290768212817, 0.9675236296468627, 0.7777464701464416], 
             UndirectedEdge[156, 227] -> 
             RGBColor[
              0.9759913711688812, 0.9782544398448184, 0.7225616032194613], 
             UndirectedEdge[151, 160] -> 
             RGBColor[
              0.9936547922657244, 0.9896181485315942, 0.6075541926591341], 
             UndirectedEdge[93, 167] -> 
             RGBColor[
              0.9308656303926311, 0.7636122927094271, 0.26323106730293117`], 
             UndirectedEdge[275, 348] -> 
             RGBColor[
              0.9698805499949272, 0.9198335129793824, 0.5738448235561755], 
             UndirectedEdge[34, 394] -> 
             RGBColor[
              0.8786897652761265, 0.9032645741878547, 0.8554824142290578], 
             UndirectedEdge[405, 488] -> 
             RGBColor[
              0.664736612464748, 0.7301935410197252, 0.9121626497907431], 
             UndirectedEdge[338, 443] -> 
             RGBColor[
              0.9594545730057329, 0.8748928956086651, 0.29698910179903637`], 
             UndirectedEdge[301, 316] -> 
             RGBColor[
              0.5433510760013137, 0.6173466407897785, 0.9622832992250486], 
             UndirectedEdge[103, 209] -> 
             RGBColor[
              0.9679516095392856, 0.9483114942906423, 0.6530862055603679], 
             UndirectedEdge[126, 414] -> 
             RGBColor[
              0.9846569322947873, 0.9864427340937629, 0.837636828667716], 
             UndirectedEdge[154, 341] -> 
             RGBColor[
              0.9751061978837403, 0.9798430956054653, 0.8772374394253362], 
             UndirectedEdge[306, 347] -> 
             RGBColor[
              0.8373787711808585, 0.841803198143074, 0.6574001414246705], 
             UndirectedEdge[20, 388] -> 
             RGBColor[
              0.9624057408499025, 0.9689985898092359, 0.8213669808096541], 
             UndirectedEdge[286, 319] -> 
             RGBColor[
              0.9689581412053436, 0.9420074766164054, 0.6364066439031677], 
             UndirectedEdge[62, 96] -> 
             RGBColor[
              0.9922349488469618, 0.9887663931707418, 0.6118500558556177], 
             UndirectedEdge[149, 242] -> 
             RGBColor[
              0.9872833050054677, 0.9887913635075624, 0.8506509092205636], 
             UndirectedEdge[212, 319] -> 
             RGBColor[
              0.9367192126946522, 0.9515276462199284, 0.9643270239497261], 
             UndirectedEdge[289, 470] -> 
             RGBColor[
              0.9658549628127708, 0.8957284103372232, 0.3257828718977529], 
             UndirectedEdge[291, 353] -> 
             RGBColor[
              0.9385039993678475, 0.8227938417969421, 0.5896240813737655], 
             UndirectedEdge[21, 91] -> 
             RGBColor[
              0.893139794048835, 0.9146618321604157, 0.8618554622773504], 
             UndirectedEdge[95, 224] -> 
             RGBColor[
              0.94196418254979, 0.9527707522244753, 0.8252299782273926], 
             UndirectedEdge[218, 235] -> 
             RGBColor[
              0.9938204159002796, 0.9891908193995185, 0.5687685905969286], 
             UndirectedEdge[108, 315] -> 
             RGBColor[
              0.9938342006906737, 0.9892203036723157, 0.5702689799614742], 
             UndirectedEdge[61, 154] -> 
             RGBColor[
              0.9654948037752583, 0.8953726200302305, 0.5357054490857928], 
             UndirectedEdge[297, 413] -> 
             RGBColor[
              0.7320826898688124, 0.7859886445057446, 0.8379780866303745], 
             UndirectedEdge[294, 438] -> 
             RGBColor[
              0.93425679373902, 0.9483282287761043, 0.9139210087918834], 
             UndirectedEdge[277, 386] -> 
             RGBColor[
              0.9900204432943567, 0.990141211086377, 0.8150506110847775], 
             UndirectedEdge[125, 249] -> 
             RGBColor[
              0.9129383986947825, 0.9329470216825759, 0.9752874025203941], 
             UndirectedEdge[211, 308] -> 
             RGBColor[
              0.8481138058000339, 0.8797371635512257, 0.8687026485991685], 
             UndirectedEdge[273, 477] -> 
             RGBColor[
              0.9229146023589025, 0.9368148386179189, 0.7612946195436872], 
             UndirectedEdge[154, 397] -> 
             RGBColor[
              0.9923760015426563, 0.9898957510199407, 0.6873649448474137], 
             UndirectedEdge[105, 230] -> 
             RGBColor[
              0.9765326215124112, 0.9788277188424239, 0.7351036623078491], 
             UndirectedEdge[355, 404] -> 
             RGBColor[
              0.8424587696945779, 0.8283407331994147, 0.6324519598958289], 
             UndirectedEdge[250, 263] -> 
             RGBColor[
              0.9754931812588563, 0.9744146491204575, 0.6837926176285285], 
             UndirectedEdge[11, 259] -> 
             RGBColor[
              0.9642987637104209, 0.9642736925786519, 0.6989373912923537], 
             UndirectedEdge[339, 439] -> 
             RGBColor[
              0.9733925904211536, 0.9206172759751745, 0.4007551335575391], 
             UndirectedEdge[303, 379] -> 
             RGBColor[
              0.9282372534361581, 0.7603992586113477, 0.5700919031199962], 
             UndirectedEdge[416, 468] -> 
             RGBColor[
              0.5859715098392911, 0.6464321486091207, 0.7073580130116081], 
             UndirectedEdge[77, 336] -> 
             RGBColor[
              0.9942661643559909, 0.990144230274203, 0.6172855591605085], 
             UndirectedEdge[297, 412] -> 
             RGBColor[
              0.9768338314916153, 0.9803801641718808, 0.8399493145229668], 
             UndirectedEdge[69, 418] -> 
             RGBColor[
              0.9887172762902194, 0.976216330249387, 0.5864286823879205], 
             UndirectedEdge[281, 322] -> 
             RGBColor[
              0.987471591960438, 0.9874593724763543, 0.7541481028960839], 
             UndirectedEdge[51, 495] -> 
             RGBColor[
              0.9669005156322981, 0.9735863660509443, 0.8849948347201779], 
             UndirectedEdge[227, 229] -> 
             RGBColor[
              0.9644006705007467, 0.9395263112729452, 0.646069545050719], 
             UndirectedEdge[192, 497] -> 
             RGBColor[
              0.9862981550683887, 0.9642880965903524, 0.4994420774076511], 
             UndirectedEdge[143, 277] -> 
             RGBColor[
              0.9931019839532833, 0.9901382988703314, 0.6711419346878889], 
             UndirectedEdge[87, 161] -> 
             RGBColor[
              0.9759057897880064, 0.9782157624037421, 0.724701936761416], 
             UndirectedEdge[114, 255] -> 
             RGBColor[
              0.9812419838620958, 0.9841834112921442, 0.8562940809102522], 
             UndirectedEdge[341, 391] -> 
             RGBColor[
              0.8912930238628671, 0.9155475342065207, 0.9683671173011827], 
             UndirectedEdge[35, 347] -> 
             RGBColor[
              0.8372542911204667, 0.8413832976700641, 0.6569165598961352], 
             UndirectedEdge[99, 498] -> 
             RGBColor[
              0.9838200043066083, 0.9556354982933174, 0.5147477215500744], 
             UndirectedEdge[89, 448] -> 
             RGBColor[
              0.9791749293079135, 0.9817721816428752, 0.8079004849295645], 
             UndirectedEdge[130, 371] -> 
             RGBColor[
              0.8889992497042968, 0.9123994574592971, 0.90552871509889], 
             UndirectedEdge[187, 481] -> 
             RGBColor[
              0.9696252991575395, 0.9735654999888657, 0.7380084858982929], 
             UndirectedEdge[427, 500] -> 
             RGBColor[
              0.8372656333910511, 0.7734182703314936, 0.6173365684059438], 
             UndirectedEdge[134, 247] -> 
             RGBColor[
              0.9248780478941356, 0.9394595669671619, 0.8489596842755274], 
             UndirectedEdge[79, 301] -> 
             RGBColor[
              0.923791205049027, 0.864181074254885, 0.6307456546448377], 
             UndirectedEdge[173, 323] -> 
             RGBColor[
              0.5781930232449579, 0.4911191519847523, 0.5832592160024372], 
             UndirectedEdge[84, 262] -> 
             RGBColor[
              0.9880202372430418, 0.9696503917009407, 0.5441155412948523], 
             UndirectedEdge[262, 391] -> 
             RGBColor[
              0.9091773698477246, 0.9269146335164247, 0.8453837623863873], 
             UndirectedEdge[205, 382] -> 
             RGBColor[
              0.8221825628492854, 0.8595863546822308, 0.8709642404004858], 
             UndirectedEdge[50, 499] -> 
             RGBColor[
              0.6655565528955242, 0.7357892270988213, 0.9693582603846058], 
             UndirectedEdge[108, 380] -> 
             RGBColor[
              0.994077019457649, 0.9897396684621325, 0.5966983042430013], 
             UndirectedEdge[300, 493] -> 
             RGBColor[
              0.9197148567698286, 0.9352925290615606, 0.8444100435300106], 
             UndirectedEdge[331, 382] -> 
             RGBColor[
              0.9926434496514966, 0.9891787034838952, 0.6227716411102022], 
             UndirectedEdge[186, 495] -> 
             RGBColor[
              0.9923734274467032, 0.9891791379824881, 0.635394776036938], 
             UndirectedEdge[93, 235] -> 
             RGBColor[
              0.9598387168000955, 0.8664555468539118, 0.4150066954236161], 
             UndirectedEdge[18, 300] -> 
             RGBColor[
              0.7644665879793643, 0.8161234680653566, 0.9771062409773978], 
             UndirectedEdge[223, 246] -> 
             RGBColor[
              0.9925777809669469, 0.9903731806163242, 0.712659751040484], 
             UndirectedEdge[233, 431] -> 
             RGBColor[
              0.9904759945401226, 0.9783906261069855, 0.5148477190998244], 
             UndirectedEdge[182, 351] -> 
             RGBColor[
              0.965857050039552, 0.9722366649418004, 0.861168831097233], 
             UndirectedEdge[163, 209] -> 
             RGBColor[
              0.9322231783819015, 0.9204830675217084, 0.6725767650217498], 
             UndirectedEdge[70, 182] -> 
             RGBColor[
              0.9412046299600626, 0.9526018591619898, 0.8595928635927874], 
             UndirectedEdge[59, 335] -> 
             RGBColor[
              0.9467261047149331, 0.9450543349134704, 0.6930951080990433], 
             UndirectedEdge[258, 453] -> 
             RGBColor[
              0.8970182511860878, 0.6217969512743786, 0.23560240564995327`], 
             UndirectedEdge[161, 354] -> 
             RGBColor[
              0.9568816901068307, 0.9673630155982027, 0.9578722309795371], 
             UndirectedEdge[213, 489] -> 
             RGBColor[
              0.993464936052691, 0.989677019696293, 0.6206867926056132], 
             UndirectedEdge[260, 407] -> 
             RGBColor[
              0.9710082351763589, 0.9768233832330224, 0.8858106246182433], 
             UndirectedEdge[95, 185] -> 
             RGBColor[
              0.9920823741381001, 0.9904652730911019, 0.7424554855424124], 
             UndirectedEdge[117, 479] -> 
             RGBColor[
              0.9137589569432474, 0.8623172518626812, 0.6311627007433073], 
             UndirectedEdge[164, 444] -> 
             RGBColor[
              0.8550639612661151, 0.8872688088934183, 0.9860379580218132], 
             UndirectedEdge[32, 334] -> 
             RGBColor[
              0.9443176211435237, 0.9382414902314659, 0.685668045360178], 
             UndirectedEdge[46, 325] -> 
             RGBColor[
              0.9643736065778943, 0.8833243994299063, 0.4843675161469444], 
             UndirectedEdge[18, 201] -> 
             RGBColor[
              0.8388300429008271, 0.8705733714230247, 0.729535153347622], 
             UndirectedEdge[328, 398] -> 
             RGBColor[
              0.9552405955858939, 0.8485326892883877, 0.3931308004105175], 
             UndirectedEdge[376, 448] -> 
             RGBColor[
              0.9640451058863466, 0.932118897230307, 0.6315098109834697], 
             UndirectedEdge[326, 355] -> 
             RGBColor[
              0.8601632296577364, 0.8874785442136566, 0.7508461914423921], 
             UndirectedEdge[257, 281] -> 
             RGBColor[
              0.9870417571119461, 0.9865399991983999, 0.7073632322709402], 
             UndirectedEdge[32, 89] -> 
             RGBColor[
              0.951243155322252, 0.9602197805692171, 0.8301866048478658], 
             UndirectedEdge[341, 397] -> 
             RGBColor[
              0.9765985381860511, 0.9792406727346734, 0.7638575284894396], 
             UndirectedEdge[160, 274] -> 
             RGBColor[
              0.9943532751282216, 0.9911121327470253, 0.6835797417053865], 
             UndirectedEdge[151, 235] -> 
             RGBColor[
              0.9933864513593449, 0.9882626131270048, 0.5215342284348947], 
             UndirectedEdge[11, 372] -> 
             RGBColor[
              0.9461880683433278, 0.9593877299961808, 0.9759737432819084], 
             UndirectedEdge[99, 295] -> 
             RGBColor[
              0.9694266790941506, 0.9745748117065678, 0.8301827886825497], 
             UndirectedEdge[154, 199] -> 
             RGBColor[
              0.8214354247759601, 0.8592773938883382, 0.8833462518068363], 
             UndirectedEdge[169, 308] -> 
             RGBColor[
              0.8226602627913133, 0.7880405666645135, 0.6216454571550878], 
             UndirectedEdge[158, 410] -> 
             RGBColor[
              0.9723850899760201, 0.9762807227716186, 0.7854650606880154], 
             UndirectedEdge[311, 465] -> 
             RGBColor[
              0.9531518357551221, 0.9410543353735321, 0.6802858380295511], 
             UndirectedEdge[139, 428] -> 
             RGBColor[
              0.944487966511946, 0.8479945680122968, 0.5955843034465136], 
             UndirectedEdge[113, 364] -> 
             RGBColor[
              0.9867877786398587, 0.9888044211760498, 0.8686242302777611], 
             UndirectedEdge[89, 475] -> 
             RGBColor[
              0.977482888461582, 0.934323474251161, 0.4846398699640254], 
             UndirectedEdge[375, 441] -> 
             RGBColor[
              0.9749685486128916, 0.9786421014072548, 0.8155787175843039], 
             UndirectedEdge[244, 295] -> 
             RGBColor[
              0.9635359147210063, 0.972325725420162, 0.9466083644074705], 
             UndirectedEdge[187, 260] -> 
             RGBColor[
              0.9487081449014096, 0.9612671989669516, 0.9717079110103084], 
             UndirectedEdge[207, 322] -> 
             RGBColor[
              0.9138794882845914, 0.9299450873143349, 0.7875568789811633], 
             UndirectedEdge[100, 457] -> 
             RGBColor[
              0.9588154908885672, 0.8663360311118703, 0.32784337632687865`], 
             UndirectedEdge[364, 416] -> 
             RGBColor[
              0.9902790316776209, 0.9882933131853678, 0.6686695663329211], 
             UndirectedEdge[313, 386] -> 
             RGBColor[
              0.9849339819227463, 0.9704372052676329, 0.6199962571637782], 
             UndirectedEdge[31, 472] -> 
             RGBColor[
              0.9854140166797868, 0.988236335301488, 0.8913910211381406], 
             UndirectedEdge[37, 49] -> 
             RGBColor[
              0.8589669701079599, 0.8885656556502339, 0.8856511427796823], 
             UndirectedEdge[201, 406] -> 
             RGBColor[
              0.9926824286510434, 0.9893558229977821, 0.633828709192547], 
             UndirectedEdge[245, 376] -> 
             RGBColor[
              0.9791860426204905, 0.9405972527425197, 0.44630460701950186`], 
             UndirectedEdge[58, 215] -> 
             RGBColor[
              0.7217676070996927, 0.42077827963142406`, 0.5639675903844014], 
             UndirectedEdge[84, 407] -> 
             RGBColor[
              0.9858033801603654, 0.9688928934131851, 0.5924288738821908], 
             UndirectedEdge[100, 324] -> 
             RGBColor[
              0.9167369185816941, 0.9193674433193462, 0.6876244430068843], 
             UndirectedEdge[89, 176] -> 
             RGBColor[
              0.9947356738105133, 0.9916270794263988, 0.7031790894785392], 
             UndirectedEdge[75, 379] -> 
             RGBColor[
              0.961762643549245, 0.9009906185521885, 0.5974642056285455], 
             UndirectedEdge[123, 422] -> 
             RGBColor[
              0.9741529758894863, 0.9244740598846826, 0.3540896214419395], 
             UndirectedEdge[407, 455] -> 
             RGBColor[
              0.9629864487669799, 0.9708306958130897, 0.8990408987645335], 
             UndirectedEdge[333, 358] -> 
             RGBColor[
              0.9623803632201734, 0.8866046197736492, 0.5507165508248666], 
             UndirectedEdge[120, 124] -> 
             RGBColor[
              0.9611030147417838, 0.9219424017020437, 0.6195451155024954], 
             UndirectedEdge[88, 433] -> 
             RGBColor[
              0.9944765597353855, 0.9917431778053623, 0.7237011046044282], 
             UndirectedEdge[345, 456] -> 
             RGBColor[
              0.9942086453316159, 0.9910279732540639, 0.6842065452644466], 
             UndirectedEdge[392, 474] -> 
             RGBColor[
              0.8803466775756836, 0.7867233631970162, 0.6170141688068644], 
             UndirectedEdge[165, 333] -> 
             RGBColor[
              0.8424747141941609, 0.7937162448107488, 0.6214494611419986], 
             UndirectedEdge[31, 133] -> 
             RGBColor[
              0.942197933665284, 0.8128742067202313, 0.5714281194868469], 
             UndirectedEdge[171, 208] -> 
             RGBColor[
              0.93616982855491, 0.8876015014079572, 0.6349605603899716], 
             UndirectedEdge[284, 472] -> 
             RGBColor[
              0.9894271324764217, 0.9876109460864404, 0.6587940540516757], 
             UndirectedEdge[196, 427] -> 
             RGBColor[
              0.9471508100603674, 0.8244394468461584, 0.2958028878785339], 
             UndirectedEdge[179, 334] -> 
             RGBColor[
              0.8910837727450283, 0.8959454866846188, 0.680550423662774], 
             UndirectedEdge[97, 233] -> 
             RGBColor[
              0.9117961191309936, 0.919652188984319, 0.6933678381784595], 
             UndirectedEdge[21, 409] -> 
             RGBColor[
              0.960275517320003, 0.8685801632206269, 0.5016573941440186], 
             UndirectedEdge[63, 344] -> 
             RGBColor[
              0.994751437269958, 0.9911821799685607, 0.6701045210885502], 
             UndirectedEdge[292, 398] -> 
             RGBColor[
              0.9538416354175296, 0.849489023612801, 0.5278818784173089], 
             UndirectedEdge[71, 197] -> 
             RGBColor[
              0.7052830524360203, 0.7673629780541036, 0.9540366424828537], 
             UndirectedEdge[81, 121] -> 
             RGBColor[
              0.7322114231961874, 0.7883523492009681, 0.9327604373079008], 
             UndirectedEdge[163, 317] -> 
             RGBColor[
              0.8083659173859232, 0.8507855971946705, 0.9813841556905634], 
             UndirectedEdge[167, 172] -> 
             RGBColor[
              0.9603266542953266, 0.8857553583553133, 0.5847518225379034], 
             UndirectedEdge[191, 488] -> 
             RGBColor[
              0.6440704665853956, 0.7150857439575667, 0.9608027028920971], 
             UndirectedEdge[392, 490] -> 
             RGBColor[
              0.8916158763429383, 0.9164143138003735, 0.9895243123121203], 
             UndirectedEdge[251, 272] -> 
             RGBColor[
              0.9142222015275359, 0.7563175458020266, 0.5980581312456861], 
             UndirectedEdge[66, 255] -> 
             RGBColor[
              0.9881224867126814, 0.9742904140344311, 0.5846740955658186], 
             UndirectedEdge[177, 194] -> 
             RGBColor[
              0.7229595404684355, 0.77337874347569, 0.6827237445796903], 
             UndirectedEdge[36, 359] -> 
             RGBColor[
              0.571174296040613, 0.5968342912253385, 0.622950610899317], 
             UndirectedEdge[46, 377] -> 
             RGBColor[
              0.9485127101841921, 0.8313973650902187, 0.28878233267991493`], 
             UndirectedEdge[6, 306] -> 
             RGBColor[
              0.9747373864081976, 0.9264454137904112, 0.35635994595046694`], 
             UndirectedEdge[7, 455] -> 
             RGBColor[
              0.8346620779379503, 0.871695756581476, 0.9839076148498016], 
             UndirectedEdge[84, 482] -> 
             RGBColor[
              0.9829233120302643, 0.954058463060381, 0.3881607212098537], 
             UndirectedEdge[83, 97] -> 
             RGBColor[
              0.8830598647601047, 0.9095919824109695, 0.9887082322893079], 
             UndirectedEdge[125, 408] -> 
             RGBColor[
              0.8029970671260533, 0.8464469364838905, 0.980887377850874], 
             UndirectedEdge[184, 473] -> 
             RGBColor[
              0.9655325544638825, 0.8892171769818673, 0.4084951398773443], 
             UndirectedEdge[410, 422] -> 
             RGBColor[
              0.970410400859971, 0.9706239198212578, 0.6923964390424008], 
             UndirectedEdge[202, 283] -> 
             RGBColor[
              0.9945673244763873, 0.9907883813197718, 0.6500649797208284], 
             UndirectedEdge[320, 329] -> 
             RGBColor[
              0.9522808598885346, 0.963384379747522, 0.945352652259524], 
             UndirectedEdge[146, 387] -> 
             RGBColor[
              0.8872417981179568, 0.5585649672123352, 0.22667091333497036`], 
             UndirectedEdge[107, 170] -> 
             RGBColor[
              0.9852591873892433, 0.9871811895873828, 0.8495725724934535], 
             UndirectedEdge[273, 459] -> 
             RGBColor[
              0.9648474286428405, 0.8865986898696461, 0.4021560883728551], 
             UndirectedEdge[5, 395] -> 
             RGBColor[
              0.7805541017405597, 0.8213932528755747, 0.689125113701073], 
             UndirectedEdge[104, 242] -> 
             RGBColor[
              0.9644737517387721, 0.8898988001107004, 0.5279073977246055], 
             UndirectedEdge[422, 437] -> 
             RGBColor[
              0.9478708866283843, 0.9530368084130323, 0.7036046874721953], 
             UndirectedEdge[29, 177] -> 
             RGBColor[
              0.6987355774383719, 0.6873640275712666, 0.6110210312821484], 
             UndirectedEdge[202, 285] -> 
             RGBColor[
              0.9853037387059422, 0.9606488429837278, 0.5198008615058043], 
             UndirectedEdge[182, 460] -> 
             RGBColor[
              0.991826854509524, 0.9908882085464994, 0.7851137024070853], 
             UndirectedEdge[116, 333] -> 
             RGBColor[
              0.7456529388950492, 0.7167464319202637, 0.6127098029428614], 
             UndirectedEdge[405, 472] -> 
             RGBColor[
              0.9861242975440209, 0.9885300546922344, 0.8796198290698288], 
             UndirectedEdge[51, 96] -> 
             RGBColor[
              0.9673599569328516, 0.971485783963992, 0.7108802361082021], 
             UndirectedEdge[115, 402] -> 
             RGBColor[
              0.9006325598561615, 0.9230882896200487, 0.9725052830728873], 
             UndirectedEdge[67, 120] -> 
             RGBColor[
              0.9792601956560838, 0.9818208745093546, 0.8065740081708461], 
             UndirectedEdge[72, 222] -> 
             RGBColor[
              0.994451039696405, 0.990763615650958, 0.6536873155025611], 
             UndirectedEdge[84, 328] -> 
             RGBColor[
              0.9872229539477293, 0.9679450833499739, 0.45733617486224165`], 
             UndirectedEdge[123, 401] -> 
             RGBColor[
              0.9712301654727321, 0.914614734040449, 0.3427350548992826], 
             UndirectedEdge[143, 178] -> 
             RGBColor[
              0.9924781248754933, 0.9898803171092183, 0.6814808941024088], 
             UndirectedEdge[2, 385] -> 
             RGBColor[
              0.9739554089083702, 0.9799148573797851, 0.9208335449536353], 
             UndirectedEdge[113, 487] -> 
             RGBColor[
              0.9284606353642718, 0.9441893936928949, 0.9343357998549229], 
             UndirectedEdge[12, 430] -> 
             RGBColor[
              0.9842113780597732, 0.9572795083363439, 0.48873328910019564`], 
             UndirectedEdge[72, 344] -> 
             RGBColor[
              0.9942352426993726, 0.9900780919773555, 0.6139199276639529], 
             UndirectedEdge[127, 221] -> 
             RGBColor[
              0.8997003552794582, 0.9221720475248989, 0.9664208646375232], 
             UndirectedEdge[466, 491] -> 
             RGBColor[
              0.9810631905602255, 0.9532126504787464, 0.5761535897058458], 
             UndirectedEdge[236, 289] -> 
             RGBColor[
              0.986311293879093, 0.9643629243302227, 0.4968989861873479], 
             UndirectedEdge[200, 298] -> 
             RGBColor[
              0.9707812597398335, 0.9138889064207989, 0.5280056636013876], 
             UndirectedEdge[231, 431] -> 
             RGBColor[
              0.9782643612367927, 0.9808240694001358, 0.7880968823171832], 
             UndirectedEdge[171, 238] -> 
             RGBColor[
              0.9390781155641044, 0.8991318902702178, 0.6373006363838394], 
             UndirectedEdge[276, 306] -> 
             RGBColor[
              0.8983648731808739, 0.889488491129678, 0.6634673914891598], 
             UndirectedEdge[294, 296] -> 
             RGBColor[
              0.8914810442931937, 0.9144266909427861, 0.909786172135486], 
             UndirectedEdge[1, 119] -> 
             RGBColor[
              0.9659137055872038, 0.9706895998180916, 0.7357377955431872], 
             UndirectedEdge[103, 444] -> 
             RGBColor[
              0.8970630902846706, 0.9200973199232914, 0.9671455033203479], 
             UndirectedEdge[331, 486] -> 
             RGBColor[
              0.9924585064503414, 0.9891022247173942, 0.6258366285710064], 
             UndirectedEdge[100, 281] -> 
             RGBColor[
              0.9821157805859553, 0.9703327125149495, 0.6534322805991217], 
             UndirectedEdge[161, 477] -> 
             RGBColor[
              0.9054876417941915, 0.9268828489178277, 0.9703073510374113], 
             UndirectedEdge[391, 475] -> 
             RGBColor[
              0.8917394727677461, 0.8696937089698036, 0.6414865969942984], 
             UndirectedEdge[2, 312] -> 
             RGBColor[
              0.9772340695006763, 0.9812706677924374, 0.8664976540375016], 
             UndirectedEdge[264, 341] -> 
             RGBColor[
              0.9233053543446124, 0.9410732975811019, 0.9714204819602763], 
             UndirectedEdge[73, 434] -> 
             RGBColor[
              0.9363928465717946, 0.7855258630242038, 0.2676783951811246], 
             UndirectedEdge[241, 271] -> 
             RGBColor[
              0.9241913216997453, 0.9379907290760299, 0.7742137759989551], 
             UndirectedEdge[49, 51] -> 
             RGBColor[
              0.8344855522773214, 0.8714477994413923, 0.9781587819320604], 
             UndirectedEdge[5, 275] -> 
             RGBColor[
              0.9718533167009805, 0.9157994212932934, 0.3499334445732587], 
             UndirectedEdge[18, 274] -> 
             RGBColor[
              0.8394475161529831, 0.8718940842732639, 0.7967433062416027], 
             UndirectedEdge[219, 445] -> 
             RGBColor[
              0.9930771390630706, 0.9904598106296914, 0.6956710010548581], 
             UndirectedEdge[177, 297] -> 
             RGBColor[
              0.7256534332303868, 0.7807690843319597, 0.8374719519966547], 
             UndirectedEdge[250, 365] -> 
             RGBColor[
              0.9682164622326324, 0.9758164700906395, 0.9386854183525897], 
             UndirectedEdge[325, 474] -> 
             RGBColor[
              0.9539132834113967, 0.8418527037708043, 0.47595089459183854`], 
             UndirectedEdge[266, 403] -> 
             RGBColor[
              0.9147505092103866, 0.9321723491181746, 0.8859153141494557], 
             UndirectedEdge[214, 470] -> 
             RGBColor[
              0.9739499915697152, 0.9218095006700471, 0.46142480869734115`], 
             UndirectedEdge[152, 481] -> 
             RGBColor[
              0.9930830766292001, 0.9876137252551154, 0.4885137612704466], 
             UndirectedEdge[289, 466] -> 
             RGBColor[
              0.9843764602372647, 0.9643890870921151, 0.5890250167426655], 
             UndirectedEdge[126, 269] -> 
             RGBColor[
              0.9808356084177032, 0.9848625184670444, 0.9009660545801867], 
             UndirectedEdge[183, 396] -> 
             RGBColor[
              0.8068066708558024, 0.8491255118811885, 0.9813460351439693], 
             UndirectedEdge[54, 99] -> 
             RGBColor[
              0.9947015620094137, 0.9917032102813057, 0.7103036847976214], 
             UndirectedEdge[129, 306] -> 
             RGBColor[
              0.8352209655176741, 0.8401175039590638, 0.6571850715220047], 
             UndirectedEdge[172, 236] -> 
             RGBColor[
              0.9895421829474518, 0.9891171719464565, 0.7629157928098281], 
             UndirectedEdge[162, 284] -> 
             RGBColor[
              0.9850428045265942, 0.9611275331041846, 0.4032376327496241], 
             UndirectedEdge[10, 189] -> 
             RGBColor[
              0.9610958155445897, 0.9705059034496861, 0.9507388158333534], 
             UndirectedEdge[213, 332] -> 
             RGBColor[
              0.9490762189741242, 0.9591300171162738, 0.8712675506297003], 
             UndirectedEdge[199, 245] -> 
             RGBColor[
              0.8229373879047093, 0.8586955532702808, 0.771013726143549], 
             UndirectedEdge[123, 139] -> 
             RGBColor[
              0.938918477272472, 0.7948997857910151, 0.2730403816781161], 
             UndirectedEdge[391, 482] -> 
             RGBColor[
              0.9040804446349473, 0.911322704875865, 0.6894289423013886], 
             UndirectedEdge[184, 354] -> 
             RGBColor[
              0.9743622218096664, 0.9774095885458695, 0.7546903872679331], 
             UndirectedEdge[25, 316] -> 
             RGBColor[
              0.5555386592081927, 0.6270646888158106, 0.9634457617913047], 
             UndirectedEdge[106, 479] -> 
             RGBColor[
              0.9412047111559112, 0.8841236467801727, 0.6310725693559411], 
             UndirectedEdge[118, 260] -> 
             RGBColor[
              0.9677974337731274, 0.9754956343389538, 0.9390219131574595], 
             UndirectedEdge[304, 469] -> 
             RGBColor[
              0.8506099296336331, 0.7537745597474865, 0.612008189940775], 
             UndirectedEdge[93, 236] -> 
             RGBColor[
              0.9600811590447562, 0.8669741063005705, 0.4413950375748559], 
             UndirectedEdge[343, 445] -> 
             RGBColor[
              0.9895851537114844, 0.9890157849468802, 0.753542235299047], 
             UndirectedEdge[204, 444] -> 
             RGBColor[
              0.9135012792108652, 0.9297517522399626, 0.7962949747406252], 
             UndirectedEdge[150, 412] -> 
             RGBColor[
              0.9116452388062285, 0.7239090900726144, 0.5821184973268605], 
             UndirectedEdge[14, 239] -> 
             RGBColor[
              0.9893060792360522, 0.9884634125926093, 0.7264042690762259], 
             UndirectedEdge[70, 442] -> 
             RGBColor[
              0.9238576288685938, 0.895602890983904, 0.6449899767537696], 
             UndirectedEdge[93, 493] -> 
             RGBColor[
              0.9604495675217007, 0.8677620947809439, 0.4814940267366844], 
             UndirectedEdge[228, 279] -> 
             RGBColor[
              0.917713875614149, 0.9014557451776037, 0.6602211627707528], 
             UndirectedEdge[300, 456] -> 
             RGBColor[
              0.9193354936710002, 0.9344811097526595, 0.8031187113802009], 
             UndirectedEdge[168, 326] -> 
             RGBColor[
              0.990064174829867, 0.9885774996972816, 0.6993460315907684], 
             UndirectedEdge[193, 437] -> 
             RGBColor[
              0.8777958349703909, 0.9053945879449339, 0.9882061444287102], 
             UndirectedEdge[224, 361] -> 
             RGBColor[
              0.9355110343728774, 0.9323397167101312, 0.6864762611251617], 
             UndirectedEdge[12, 477] -> 
             RGBColor[
              0.9132005270885692, 0.9046788631132577, 0.669826642026172], 
             UndirectedEdge[212, 224] -> 
             RGBColor[
              0.8970018896107184, 0.920708974580666, 0.990038035065752], 
             UndirectedEdge[220, 490] -> 
             RGBColor[
              0.937804550720349, 0.8761351322797706, 0.6322569671310372], 
             UndirectedEdge[175, 208] -> 
             RGBColor[
              0.9160998918391834, 0.8715982786547563, 0.6330462719093816], 
             UndirectedEdge[242, 419] -> 
             RGBColor[
              0.9934096354039107, 0.991413897815574, 0.7495182509209217], 
             UndirectedEdge[164, 205] -> 
             RGBColor[
              0.7646497994593113, 0.8165328661828763, 0.9770538414058694], 
             UndirectedEdge[257, 322] -> 
             RGBColor[
              0.9935958453048261, 0.9887104856034139, 0.5443254671708959], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.8642846750856369, 0.8920767255623143, 0.8570174826626756], 
             UndirectedEdge[26, 67] -> 
             RGBColor[
              0.9771336896146828, 0.9331587452591937, 0.48216080491597135`], 
             UndirectedEdge[366, 488] -> 
             RGBColor[
              0.6023572548223513, 0.6820567544268977, 0.9648674112746053], 
             UndirectedEdge[12, 243] -> 
             RGBColor[
              0.9714270799227906, 0.9152789727182082, 0.34350003035358645`], 
             UndirectedEdge[271, 307] -> 
             RGBColor[
              0.9101164029913857, 0.9267677709514744, 0.7728712976877234], 
             UndirectedEdge[9, 352] -> 
             RGBColor[
              0.989927055105418, 0.9885056993271514, 0.7005210066737799], 
             UndirectedEdge[404, 431] -> 
             RGBColor[
              0.9761987246400432, 0.9302300422716274, 0.4593832215742042], 
             UndirectedEdge[256, 287] -> 
             RGBColor[
              0.9545985700488175, 0.8526842376759068, 0.30847791462984486`], 
             UndirectedEdge[254, 412] -> 
             RGBColor[
              0.948534246251922, 0.8814970105851863, 0.6123866218614997], 
             UndirectedEdge[42, 380] -> 
             RGBColor[
              0.9910208194120425, 0.9798672269851352, 0.5476799167329601], 
             UndirectedEdge[379, 404] -> 
             RGBColor[
              0.968464745075118, 0.9269481602912175, 0.60605489556583], 
             UndirectedEdge[134, 424] -> 
             RGBColor[
              0.9873087966200029, 0.9672269450595765, 0.5433576832342868], 
             UndirectedEdge[38, 253] -> 
             RGBColor[
              0.9922416227168259, 0.9847788455007227, 0.4849436962472997], 
             UndirectedEdge[103, 348] -> 
             RGBColor[
              0.9741054472069691, 0.9797585307467933, 0.9085679079547877], 
             UndirectedEdge[42, 452] -> 
             RGBColor[0.99024026591832, 0.9798367030770891, 0.58185956295152],
              UndirectedEdge[164, 331] -> 
             RGBColor[
              0.9351106862615226, 0.9461252149845409, 0.7288612421155859], 
             UndirectedEdge[6, 181] -> 
             RGBColor[
              0.9783245416645461, 0.9605050667828956, 0.6449898741377138], 
             UndirectedEdge[172, 197] -> 
             RGBColor[
              0.7192409691373364, 0.7776783793713645, 0.9261825485814255], 
             UndirectedEdge[80, 258] -> 
             RGBColor[
              0.9022063946558361, 0.6453550990488127, 0.2399315197341448], 
             UndirectedEdge[223, 268] -> 
             RGBColor[
              0.9920892310020356, 0.9893282216413573, 0.659484102340777], 
             UndirectedEdge[5, 69] -> 
             RGBColor[
              0.9916013794402543, 0.9859450873940774, 0.5976328785086261], 
             UndirectedEdge[306, 486] -> 
             RGBColor[
              0.981748632587157, 0.9532258520677943, 0.5629261090696993], 
             UndirectedEdge[5, 348] -> 
             RGBColor[
              0.9888729924758328, 0.9848168292679425, 0.6428493113482127], 
             UndirectedEdge[279, 409] -> 
             RGBColor[
              0.8964289475258604, 0.8208647567719559, 0.623321747059107], 
             UndirectedEdge[463, 483] -> 
             RGBColor[
              0.9813121879062383, 0.9842796314097944, 0.858139476280152], 
             UndirectedEdge[351, 371] -> 
             RGBColor[
              0.8627671492501003, 0.8936394477244218, 0.9859307670478855], 
             UndirectedEdge[335, 421] -> 
             RGBColor[
              0.9409412988321947, 0.9255408263339798, 0.670622229613531], 
             UndirectedEdge[259, 418] -> 
             RGBColor[
              0.9869471112996515, 0.9676316828290215, 0.4037924215406903], 
             UndirectedEdge[168, 302] -> 
             RGBColor[
              0.9891637069825754, 0.9897869286043365, 0.8292489489334938], 
             UndirectedEdge[87, 336] -> 
             RGBColor[
              0.9937832237379248, 0.9891112691249462, 0.5647204532480339], 
             UndirectedEdge[36, 266] -> 
             RGBColor[
              0.9006180011855852, 0.8808945338111425, 0.6483964511247421], 
             UndirectedEdge[161, 430] -> 
             RGBColor[
              0.9764984927653954, 0.9794834941409138, 0.7892139981114348], 
             UndirectedEdge[220, 412] -> 
             RGBColor[
              0.9493576298044171, 0.8847614519945255, 0.6130491355951333], 
             UndirectedEdge[372, 404] -> 
             RGBColor[
              0.9553173949650001, 0.9171428881059016, 0.6283099299241733], 
             UndirectedEdge[38, 287] -> 
             RGBColor[
              0.983300198562775, 0.9546173222828789, 0.45020795185508056`], 
             UndirectedEdge[171, 497] -> 
             RGBColor[
              0.9510994148220018, 0.9402097984059794, 0.6812552234447579], 
             UndirectedEdge[246, 411] -> 
             RGBColor[
              0.967932523943419, 0.9730956877249934, 0.8037678331228271], 
             UndirectedEdge[75, 303] -> 
             RGBColor[
              0.9111099177818671, 0.6776131155922768, 0.2469381705286229], 
             UndirectedEdge[23, 39] -> 
             RGBColor[
              0.9822709076239232, 0.9830068569575823, 0.7174186717957834], 
             UndirectedEdge[61, 391] -> 
             RGBColor[
              0.8816816297543851, 0.8310770586312858, 0.6268351269616395], 
             UndirectedEdge[19, 200] -> 
             RGBColor[
              0.8691355598179332, 0.8358889033764223, 0.6288334537046762], 
             UndirectedEdge[208, 403] -> 
             RGBColor[
              0.9700250484841826, 0.9119078418462734, 0.5323741013916448], 
             UndirectedEdge[108, 378] -> 
             RGBColor[
              0.9927343963946245, 0.9867167154667958, 0.4634205587453841], 
             UndirectedEdge[10, 451] -> 
             RGBColor[
              0.5599021357946855, 0.6304104732363557, 0.9592322684543634], 
             UndirectedEdge[199, 262] -> 
             RGBColor[
              0.8235423074042125, 0.8599894149129751, 0.8368554805340667], 
             UndirectedEdge[3, 401] -> 
             RGBColor[
              0.9870301183723684, 0.9744201494893139, 0.6067964808175772], 
             UndirectedEdge[241, 311] -> 
             RGBColor[
              0.891658200838414, 0.9164480622041982, 0.9895283492602823], 
             UndirectedEdge[179, 255] -> 
             RGBColor[
              0.8967885531961437, 0.917882964638368, 0.879027980954494], 
             UndirectedEdge[276, 462] -> 
             RGBColor[
              0.8281640704865316, 0.8658195661638619, 0.9834722224254405], 
             UndirectedEdge[167, 289] -> 
             RGBColor[
              0.9570957652269678, 0.8610011107390794, 0.3187350159154232], 
             UndirectedEdge[164, 348] -> 
             RGBColor[
              0.9321063181884136, 0.9469300197169201, 0.927460362656253], 
             UndirectedEdge[18, 172] -> 
             RGBColor[
              0.8346623226339319, 0.8707360994306261, 0.935710979419044], 
             UndirectedEdge[289, 300] -> 
             RGBColor[
              0.9113335247579253, 0.908599065016079, 0.6776057642870242], 
             UndirectedEdge[59, 188] -> 
             RGBColor[
              0.9888662737684057, 0.9737735358067909, 0.4394731636462976], 
             UndirectedEdge[352, 357] -> 
             RGBColor[
              0.9931213752852923, 0.9876956422079084, 0.4926823336341686], 
             UndirectedEdge[161, 409] -> 
             RGBColor[
              0.9424524658722717, 0.8569702269119261, 0.6071714486777469], 
             UndirectedEdge[39, 157] -> 
             RGBColor[
              0.9923609110225025, 0.985462405573408, 0.4614982198084103], 
             UndirectedEdge[216, 398] -> 
             RGBColor[
              0.7824612182080218, 0.7167259529653149, 0.6088008457670551], 
             UndirectedEdge[279, 396] -> 
             RGBColor[
              0.850897865426087, 0.8839468771562389, 0.9856405920814736], 
             UndirectedEdge[103, 390] -> 
             RGBColor[
              0.9756185969586126, 0.9803842570552728, 0.8834911006640247], 
             UndirectedEdge[128, 296] -> 
             RGBColor[
              0.8934917669998916, 0.912919328294259, 0.7064537221362863], 
             UndirectedEdge[362, 369] -> 
             RGBColor[
              0.9126805344694013, 0.9321343535911653, 0.9542158584745639], 
             UndirectedEdge[86, 412] -> 
             RGBColor[
              0.97592313664372, 0.978432279977606, 0.7408258004866842], 
             UndirectedEdge[261, 299] -> 
             RGBColor[
              0.9817978548506349, 0.9834360743365441, 0.7802693183479512], 
             UndirectedEdge[208, 266] -> 
             RGBColor[
              0.8930889495637405, 0.8532499778997066, 0.6308514676930392], 
             UndirectedEdge[211, 236] -> 
             RGBColor[
              0.9936417504210158, 0.9908124484508537, 0.6949753504323414], 
             UndirectedEdge[19, 124] -> 
             RGBColor[
              0.8736882049494854, 0.8532154822863135, 0.6362627544484764], 
             UndirectedEdge[319, 330] -> 
             RGBColor[
              0.9752154728421327, 0.9631149255186315, 0.660715195714165], 
             UndirectedEdge[137, 267] -> 
             RGBColor[
              0.942308726082759, 0.7915701402012749, 0.46864422667738914`], 
             UndirectedEdge[23, 240] -> 
             RGBColor[
              0.9825896595289594, 0.9836886350516936, 0.7521128495502399], 
             UndirectedEdge[135, 369] -> 
             RGBColor[
              0.9820756932592226, 0.9857338513003164, 0.8964701610526211], 
             UndirectedEdge[13, 335] -> 
             RGBColor[
              0.9012731257284801, 0.7703363616143588, 0.6121220763120938], 
             UndirectedEdge[176, 178] -> 
             RGBColor[
              0.9929409769549566, 0.9913489268093265, 0.7666498102298037], 
             UndirectedEdge[335, 459] -> 
             RGBColor[
              0.922464255493874, 0.857359727787547, 0.6293285366785398], 
             UndirectedEdge[83, 326] -> 
             RGBColor[
              0.9612849864390489, 0.9673577472874257, 0.7606909760947729], 
             UndirectedEdge[33, 76] -> 
             RGBColor[
              0.9702036368742187, 0.9092758007490527, 0.34851852541658723`], 
             UndirectedEdge[13, 285] -> 
             RGBColor[
              0.9347790182409805, 0.7702620529805546, 0.2967324396260614], 
             UndirectedEdge[225, 309] -> 
             RGBColor[
              0.971278140809226, 0.9108875754503059, 0.478739137810436], 
             UndirectedEdge[242, 499] -> 
             RGBColor[
              0.9411278309230605, 0.9532049094585366, 0.8884312066417236], 
             UndirectedEdge[13, 287] -> 
             RGBColor[
              0.9333643701813559, 0.7654901129002807, 0.2912367990482898], 
             UndirectedEdge[265, 270] -> 
             RGBColor[
              0.9242983738013768, 0.9378528887211737, 0.756130606892585], 
             UndirectedEdge[191, 311] -> 
             RGBColor[
              0.9366956948385494, 0.9521277441554861, 0.9857807138851697], 
             UndirectedEdge[47, 452] -> 
             RGBColor[
              0.9910174050367921, 0.990553480387622, 0.798528374958339], 
             UndirectedEdge[14, 80] -> 
             RGBColor[
              0.9409114948966308, 0.7869283855210747, 0.39090769289750066`], 
             UndirectedEdge[152, 292] -> 
             RGBColor[
              0.9918420131472085, 0.988907784625876, 0.640450919163509], 
             UndirectedEdge[133, 311] -> 
             RGBColor[
              0.9142423297715665, 0.791913347668364, 0.6155773100424881], 
             UndirectedEdge[187, 398] -> 
             RGBColor[
              0.9315209315235807, 0.833924315085528, 0.6141207858225317], 
             UndirectedEdge[130, 442] -> 
             RGBColor[
              0.9747421494022797, 0.9339977064985896, 0.5661638923092196], 
             UndirectedEdge[304, 433] -> 
             RGBColor[
              0.9503786977826502, 0.8299974556270611, 0.4968988006047553], 
             UndirectedEdge[354, 409] -> 
             RGBColor[
              0.9406612369336467, 0.8556343313023679, 0.6102035320435104], 
             UndirectedEdge[29, 412] -> 
             RGBColor[
              0.9499159756996005, 0.8869751074111878, 0.6134983938084605], 
             UndirectedEdge[295, 391] -> 
             RGBColor[
              0.883630963432954, 0.909833182083364, 0.9813369870236137], 
             UndirectedEdge[21, 298] -> 
             RGBColor[
              0.9932892190511897, 0.9914929338655326, 0.7608785374735655], 
             UndirectedEdge[383, 395] -> 
             RGBColor[
              0.7826460421038522, 0.8268904977255178, 0.8298487282299525], 
             UndirectedEdge[133, 241] -> 
             RGBColor[
              0.8772045746500301, 0.7623804470975312, 0.6120446158950016], 
             UndirectedEdge[142, 473] -> 
             RGBColor[
              0.9240857770731692, 0.7367324335499492, 0.2577758381784809], 
             UndirectedEdge[95, 330] -> 
             RGBColor[
              0.9882032309114028, 0.9705319206727403, 0.5223566640437641], 
             UndirectedEdge[275, 431] -> 
             RGBColor[
              0.9736094062767306, 0.9205783152684064, 0.45410177350894443`], 
             UndirectedEdge[180, 474] -> 
             RGBColor[
              0.9507046261521015, 0.8407209992254938, 0.5433125530009196], 
             UndirectedEdge[82, 173] -> 
             RGBColor[
              0.30613052030376275`, 0.435884759197303, 0.9408625204310788], 
             UndirectedEdge[205, 230] -> 
             RGBColor[
              0.82266662574247, 0.8581164203835047, 0.7415429357341631], 
             UndirectedEdge[460, 463] -> 
             RGBColor[
              0.9795458211162897, 0.9835491933485947, 0.8874127452003178], 
             UndirectedEdge[121, 500] -> 
             RGBColor[
              0.6149988839470893, 0.6966917688783161, 0.9639492735759294], 
             UndirectedEdge[88, 241] -> 
             RGBColor[
              0.9248116866999141, 0.939317627082868, 0.8417366778183344], 
             UndirectedEdge[60, 73] -> 
             RGBColor[
              0.8366471021453372, 0.8059134654582005, 0.6245777340373148], 
             UndirectedEdge[75, 400] -> 
             RGBColor[
              0.9692452435106875, 0.9037348249791258, 0.423431413132926], 
             UndirectedEdge[141, 274] -> 
             RGBColor[
              0.9476101867529514, 0.8165638201977914, 0.43165217660562594`], 
             UndirectedEdge[299, 448] -> 
             RGBColor[
              0.9789651232839663, 0.981323427772295, 0.7850643939956025], 
             UndirectedEdge[160, 389] -> 
             RGBColor[
              0.9928404670547435, 0.9871369722651161, 0.5817946017066293], 
             UndirectedEdge[24, 268] -> 
             RGBColor[
              0.9718452546415739, 0.9145060517842722, 0.3981226687399856], 
             UndirectedEdge[386, 498] -> 
             RGBColor[
              0.9802148408251001, 0.9545184342382492, 0.601663285134441], 
             UndirectedEdge[350, 476] -> 
             RGBColor[
              0.9654617657172242, 0.8896142404844067, 0.3683344869073397], 
             UndirectedEdge[180, 331] -> 
             RGBColor[
              0.9907737132761236, 0.9884055194426455, 0.6537580115727637], 
             UndirectedEdge[225, 252] -> 
             RGBColor[
              0.9264301631548593, 0.8787965606170098, 0.6337989679570686], 
             UndirectedEdge[100, 203] -> 
             RGBColor[
              0.9574707082572612, 0.8610044161009891, 0.3267613326556245], 
             UndirectedEdge[445, 471] -> 
             RGBColor[
              0.994054019730727, 0.9896904743718753, 0.5941949259054055], 
             UndirectedEdge[373, 498] -> 
             RGBColor[
              0.9815158537536637, 0.949310775806488, 0.38269301158145325`], 
             UndirectedEdge[102, 309] -> 
             RGBColor[
              0.9943250086261919, 0.9902700922180946, 0.6236903948271515], 
             UndirectedEdge[46, 86] -> 
             RGBColor[
              0.963561181958895, 0.8815867053185957, 0.395940110072438], 
             UndirectedEdge[294, 385] -> 
             RGBColor[
              0.9869175859261983, 0.9888580998248464, 0.866472987612626], 
             UndirectedEdge[27, 29] -> 
             RGBColor[
              0.8707817824332663, 0.8246217771229303, 0.6262177302487113], 
             UndirectedEdge[274, 284] -> 
             RGBColor[
              0.9934819654298046, 0.9884669080657641, 0.5319303455599123], 
             UndirectedEdge[284, 300] -> 
             RGBColor[
              0.9185010372561858, 0.9326962918578569, 0.7122932802957074], 
             UndirectedEdge[159, 453] -> 
             RGBColor[
              0.7835919883467529, 0.6475739248789965, 0.5946982603554583], 
             UndirectedEdge[229, 232] -> 
             RGBColor[
              0.9816942866686998, 0.9508828777663124, 0.5477875460643586], 
             UndirectedEdge[259, 431] -> 
             RGBColor[
              0.9915873040254364, 0.9821393339488247, 0.5191649465970816], 
             UndirectedEdge[112, 483] -> 
             RGBColor[
              0.9933927186914758, 0.991074034701485, 0.7256026426705677], 
             UndirectedEdge[78, 376] -> 
             RGBColor[
              0.9789311801222396, 0.9400521276293123, 0.4185643969139114], 
             UndirectedEdge[76, 351] -> 
             RGBColor[
              0.9430923213324389, 0.895086218084975, 0.6352904358023193], 
             UndirectedEdge[178, 498] -> 
             RGBColor[
              0.9819730074836911, 0.9552454813343987, 0.5725259136121299], 
             UndirectedEdge[400, 431] -> 
             RGBColor[
              0.9941065587299038, 0.9898028499786067, 0.5999134717326735], 
             UndirectedEdge[18, 432] -> 
             RGBColor[
              0.7953099778824331, 0.7093772427065129, 0.6062314352499836], 
             UndirectedEdge[220, 325] -> 
             RGBColor[
              0.9676778476965378, 0.8964246143922479, 0.48702618611151255`], 
             UndirectedEdge[353, 380] -> 
             RGBColor[
              0.9508849475157473, 0.8299491082339108, 0.46743419576831885`], 
             UndirectedEdge[5, 355] -> 
             RGBColor[
              0.8588618938121709, 0.8836723224847536, 0.6961749996226063], 
             UndirectedEdge[367, 441] -> 
             RGBColor[
              0.9942955029930636, 0.9902069826523101, 0.6204788887487926], 
             UndirectedEdge[21, 287] -> 
             RGBColor[
              0.9836310023618073, 0.9561556264203757, 0.546600532628202], 
             UndirectedEdge[175, 182] -> 
             RGBColor[
              0.9394920563686971, 0.9512362994668068, 0.8594295167948105], 
             UndirectedEdge[70, 371] -> 
             RGBColor[
              0.8381147291706108, 0.8740046419446114, 0.98435479954344], 
             UndirectedEdge[217, 496] -> 
             RGBColor[
              0.8720848557090304, 0.9006684348036338, 0.9742006615646359], 
             UndirectedEdge[195, 292] -> 
             RGBColor[
              0.9739660405169548, 0.9790224602709809, 0.8804971041627132], 
             UndirectedEdge[161, 285] -> 
             RGBColor[
              0.9672225989737008, 0.9493176301919489, 0.6576102277397017], 
             UndirectedEdge[168, 370] -> 
             RGBColor[
              0.9514746466329611, 0.847251410140772, 0.5609491621767485], 
             UndirectedEdge[50, 173] -> 
             RGBColor[
              0.35467979661481946`, 0.4779357021803622, 0.9439560373871798], 
             UndirectedEdge[19, 188] -> 
             RGBColor[
              0.8910044241507755, 0.9112952230237681, 0.7317581544697973], 
             UndirectedEdge[147, 323] -> 
             RGBColor[
              0.9107037923546899, 0.7662230514934432, 0.6107249104564072], 
             UndirectedEdge[255, 260] -> 
             RGBColor[
              0.9718276975761329, 0.977162251994552, 0.8722300119532802], 
             UndirectedEdge[29, 350] -> 
             RGBColor[
              0.9397242742639542, 0.7987338636911476, 0.27035894010089456`], 
             UndirectedEdge[348, 400] -> 
             RGBColor[
              0.9903777024481003, 0.9890580476895827, 0.7196565217799046], 
             UndirectedEdge[26, 124] -> 
             RGBColor[
              0.958976508700383, 0.8732802724518828, 0.29513191224762053`], 
             UndirectedEdge[18, 93] -> 
             RGBColor[
              0.8052012987312365, 0.74859303378474, 0.6141902241840718], 
             UndirectedEdge[64, 223] -> 
             RGBColor[
              0.9832844544447981, 0.9601491136858938, 0.5809370925783113], 
             UndirectedEdge[12, 335] -> 
             RGBColor[
              0.9414295917555782, 0.9271879530211832, 0.6725191554144949], 
             UndirectedEdge[143, 498] -> 
             RGBColor[
              0.9832963814840268, 0.9545155220222037, 0.45775460873755225`], 
             UndirectedEdge[44, 92] -> 
             RGBColor[
              0.9541832366162428, 0.8437901766935993, 0.49364258419338936`], 
             UndirectedEdge[274, 389] -> 
             RGBColor[
              0.9928177274454759, 0.9863067532009487, 0.5225068229975108], 
             UndirectedEdge[247, 401] -> 
             RGBColor[
              0.9194778487702354, 0.9228682145779368, 0.6898207478986376], 
             UndirectedEdge[111, 182] -> 
             RGBColor[
              0.9920558159741891, 0.9909828899961797, 0.7813192184043082], 
             UndirectedEdge[157, 190] -> 
             RGBColor[
              0.9789607286910019, 0.9406917389982352, 0.37276683320789294`], 
             UndirectedEdge[100, 360] -> 
             RGBColor[
              0.9881857697491452, 0.9714677600453758, 0.4377033236301968], 
             UndirectedEdge[59, 468] -> 
             RGBColor[
              0.5818093577764606, 0.6327088516915977, 0.6642658174801959], 
             UndirectedEdge[101, 129] -> 
             RGBColor[
              0.8462298597336133, 0.876633450907611, 0.7526421110809622], 
             UndirectedEdge[180, 382] -> 
             RGBColor[
              0.9905082010116227, 0.9903429114372679, 0.8069672034331707], 
             UndirectedEdge[145, 402] -> 
             RGBColor[
              0.9030890085123457, 0.8792430550785493, 0.6433040063392064], 
             UndirectedEdge[90, 263] -> 
             RGBColor[
              0.9869001556206873, 0.9674732902981574, 0.4036100075947503], 
             UndirectedEdge[98, 276] -> 
             RGBColor[
              0.8830110792972172, 0.8332071643633067, 0.6272015415989478], 
             UndirectedEdge[224, 464] -> 
             RGBColor[
              0.8574150850321458, 0.8891435311648967, 0.9862622103054901], 
             UndirectedEdge[261, 313] -> 
             RGBColor[
              0.975750361725205, 0.964160651532421, 0.6611828166976582], 
             UndirectedEdge[78, 219] -> 
             RGBColor[
              0.9926730229064926, 0.9895954470331816, 0.6516854513271553], 
             UndirectedEdge[393, 424] -> 
             RGBColor[
              0.9685377103223407, 0.9055324505996462, 0.33227537506750365`], 
             UndirectedEdge[169, 211] -> 
             RGBColor[
              0.9675057404192591, 0.8996599001196643, 0.5192892331520964], 
             UndirectedEdge[176, 482] -> 
             RGBColor[
              0.9898153895530255, 0.9764129679280633, 0.5664505472751974], 
             UndirectedEdge[35, 94] -> 
             RGBColor[
              0.9368820753890339, 0.7824571854852564, 0.29157506802870203`], 
             UndirectedEdge[114, 296] -> 
             RGBColor[
              0.8822969930414665, 0.9083011685079696, 0.9577513480475026], 
             UndirectedEdge[130, 175] -> 
             RGBColor[
              0.9364333889658816, 0.9499714618915758, 0.9101195512369619], 
             UndirectedEdge[189, 383] -> 
             RGBColor[
              0.9881719997041398, 0.9886810438542001, 0.8084496280905176], 
             UndirectedEdge[139, 437] -> 
             RGBColor[
              0.9126363880113699, 0.8234625343193648, 0.6225554477083719], 
             UndirectedEdge[56, 324] -> 
             RGBColor[
              0.9184268076155553, 0.9360619604710378, 0.9278756522483558], 
             UndirectedEdge[398, 399] -> 
             RGBColor[
              0.9426260622774255, 0.8065979879075987, 0.2916535638395654], 
             UndirectedEdge[405, 429] -> 
             RGBColor[
              0.9879627573511314, 0.9892903050687366, 0.8491517922845417], 
             UndirectedEdge[12, 318] -> 
             RGBColor[
              0.8292814359201885, 0.8388594139746575, 0.6615316903291535], 
             UndirectedEdge[11, 205] -> 
             RGBColor[
              0.7958840230074651, 0.8413329283388389, 0.9763835637287869], 
             UndirectedEdge[226, 389] -> 
             RGBColor[
              0.9316657182655552, 0.7470578603762053, 0.31782490540512814`], 
             UndirectedEdge[294, 327] -> 
             RGBColor[
              0.9732625613111275, 0.9788559145699344, 0.897724716119082], 
             UndirectedEdge[167, 218] -> 
             RGBColor[
              0.9648473294928153, 0.8863475652550338, 0.41699296247624373`], 
             UndirectedEdge[217, 481] -> 
             RGBColor[
              0.9719391258657408, 0.9752911481592985, 0.7340917808239644], 
             UndirectedEdge[247, 309] -> 
             RGBColor[
              0.9247345951189349, 0.9391527359863079, 0.8333457349828357], 
             UndirectedEdge[79, 234] -> 
             RGBColor[
              0.9622614804999843, 0.8935052157698959, 0.5866947992058218], 
             UndirectedEdge[331, 372] -> 
             RGBColor[
              0.9727521204496489, 0.9757037643449502, 0.7173452280932004], 
             UndirectedEdge[27, 484] -> 
             RGBColor[
              0.8796736803959937, 0.8589178374151553, 0.6383582659771935], 
             UndirectedEdge[103, 326] -> 
             RGBColor[
              0.9773795497585879, 0.979530660789607, 0.7393277207916567], 
             UndirectedEdge[155, 394] -> 
             RGBColor[
              0.9628404495755424, 0.8776985923961159, 0.49857982094510783`], 
             UndirectedEdge[433, 469] -> 
             RGBColor[
              0.8941814236388035, 0.9155433671987794, 0.8650338980210032], 
             UndirectedEdge[65, 412] -> 
             RGBColor[
              0.975566811668584, 0.9798818237863854, 0.8628083158467601], 
             UndirectedEdge[13, 161] -> 
             RGBColor[
              0.9262293383127354, 0.7896433339963667, 0.5939623595001332], 
             UndirectedEdge[229, 480] -> 
             RGBColor[
              0.9383641789388786, 0.7892138897432207, 0.29076144271393956`], 
             UndirectedEdge[32, 448] -> 
             RGBColor[
              0.9356739400438944, 0.9508253805565343, 0.9687763323029727], 
             UndirectedEdge[251, 453] -> 
             RGBColor[
              0.9126347813395088, 0.7491094414796005, 0.5967335489295669], 
             UndirectedEdge[282, 310] -> 
             RGBColor[
              0.9879143958077405, 0.9708685574923132, 0.4097612561218073], 
             UndirectedEdge[392, 473] -> 
             RGBColor[
              0.892676846980026, 0.8356083760998514, 0.6269353125358724], 
             UndirectedEdge[222, 344] -> 
             RGBColor[
              0.9948066003625248, 0.9915241239630906, 0.6923878997436288], 
             UndirectedEdge[266, 440] -> 
             RGBColor[
              0.9149770168278936, 0.9322660158389939, 0.8821614967444411], 
             UndirectedEdge[16, 361] -> 
             RGBColor[
              0.6800040993474736, 0.7260915445239684, 0.6644877154010498], 
             UndirectedEdge[412, 426] -> 
             RGBColor[
              0.7423678983173875, 0.7974182459870469, 0.9555645882912824], 
             UndirectedEdge[274, 460] -> 
             RGBColor[
              0.991418213320719, 0.989898409261975, 0.7322213115521763], 
             UndirectedEdge[180, 230] -> 
             RGBColor[
              0.9909922639048073, 0.9888729771385418, 0.6775458987668479], 
             UndirectedEdge[375, 450] -> 
             RGBColor[
              0.9372940761678779, 0.952334435395852, 0.9764614014345275], 
             UndirectedEdge[6, 123] -> 
             RGBColor[
              0.9680553188743186, 0.9039052309745694, 0.3304013753839192], 
             UndirectedEdge[170, 466] -> 
             RGBColor[
              0.991373313382147, 0.9907006576348536, 0.792630052614536], 
             UndirectedEdge[267, 280] -> 
             RGBColor[
              0.9913237888075688, 0.9807940468388849, 0.556949215299674], 
             UndirectedEdge[52, 214] -> 
             RGBColor[
              0.9945559659462253, 0.9907640865722789, 0.6488286738094249], 
             UndirectedEdge[358, 386] -> 
             RGBColor[
              0.9882529919442604, 0.9894103245316843, 0.8443418539733427], 
             UndirectedEdge[230, 413] -> 
             RGBColor[
              0.7311295616491789, 0.7839499996199936, 0.7342359619487954], 
             UndirectedEdge[53, 207] -> 
             RGBColor[
              0.8945537980268329, 0.9182495610009136, 0.9722136350097459], 
             UndirectedEdge[188, 256] -> 
             RGBColor[
              0.9646474946494145, 0.8862496872833057, 0.3757412474409032], 
             UndirectedEdge[38, 87] -> 
             RGBColor[
              0.9933980374367051, 0.9882873945749461, 0.5227953014545665], 
             UndirectedEdge[22, 52] -> 
             RGBColor[
              0.6650191480641732, 0.7279248555065416, 0.7993865448817103], 
             UndirectedEdge[160, 460] -> 
             RGBColor[
              0.9914409529299866, 0.9907286283261424, 0.7915090902612947], 
             UndirectedEdge[63, 159] -> 
             RGBColor[
              0.8421644599874796, 0.8744113543917547, 0.8286334084299589], 
             UndirectedEdge[285, 430] -> 
             RGBColor[
              0.9850481726936404, 0.9601022131251018, 0.49198407823736295`], 
             UndirectedEdge[132, 356] -> 
             RGBColor[
              0.8379430395765202, 0.7084009483871025, 0.603705152953582], 
             UndirectedEdge[99, 373] -> 
             RGBColor[
              0.9925445939680474, 0.9850655878524213, 0.5486411048842543], 
             UndirectedEdge[243, 396] -> 
             RGBColor[
              0.9019626593554555, 0.8888363946112263, 0.6586308854511655], 
             UndirectedEdge[118, 292] -> 
             RGBColor[
              0.9874735245472657, 0.9890879947316286, 0.8572596459385065], 
             UndirectedEdge[84, 176] -> 
             RGBColor[
              0.9878351255119944, 0.9697330723295574, 0.5587575954172773], 
             UndirectedEdge[334, 385] -> 
             RGBColor[
              0.983089407492305, 0.9676966450316904, 0.6368952784051924], 
             UndirectedEdge[25, 325] -> 
             RGBColor[
              0.9636030487856126, 0.9702842570591301, 0.8483103903300897], 
             UndirectedEdge[321, 397] -> 
             RGBColor[
              0.9929723154359382, 0.9901423421393808, 0.677482480424845], 
             UndirectedEdge[201, 235] -> 
             RGBColor[
              0.9934674609696861, 0.9884358844921965, 0.5303516245871662], 
             UndirectedEdge[321, 498] -> 
             RGBColor[
              0.982433776559567, 0.9554360211884985, 0.5648897775927231], 
             UndirectedEdge[368, 492] -> 
             RGBColor[
              0.9259580228186195, 0.7282966716787896, 0.5121757783954726], 
             UndirectedEdge[239, 387] -> 
             RGBColor[
              0.9555822981051987, 0.8666393964650729, 0.5794361821953162], 
             UndirectedEdge[196, 500] -> 
             RGBColor[
              0.8587188599778796, 0.8547350083528795, 0.6540667208423006], 
             UndirectedEdge[122, 185] -> 
             RGBColor[
              0.9811058314441105, 0.9547757657271166, 0.5861292349127152], 
             UndirectedEdge[350, 377] -> 
             RGBColor[
              0.9506829634333709, 0.8400016960291887, 0.2905285693865953], 
             UndirectedEdge[315, 353] -> 
             RGBColor[
              0.9506421287487721, 0.829429743444094, 0.4410048714867917], 
             UndirectedEdge[102, 480] -> 
             RGBColor[
              0.9503042382544358, 0.8286892611363533, 0.40527903366297713`], 
             UndirectedEdge[127, 253] -> 
             RGBColor[
              0.9139120093029636, 0.9267895833690115, 0.7015876719442312], 
             UndirectedEdge[159, 192] -> 
             RGBColor[
              0.8418952487827964, 0.8738355388463654, 0.7993314301791696], 
             UndirectedEdge[201, 289] -> 
             RGBColor[
              0.9856969796793882, 0.9630489683737471, 0.43003467665724826`], 
             UndirectedEdge[29, 194] -> 
             RGBColor[
              0.965640571058666, 0.8914581190356048, 0.34342334486965154`], 
             UndirectedEdge[79, 388] -> 
             RGBColor[
              0.967184809731739, 0.8949203163315509, 0.45997524342340435`], 
             UndirectedEdge[246, 402] -> 
             RGBColor[
              0.9199467840461351, 0.9349837847423343, 0.80441312078527], 
             UndirectedEdge[185, 398] -> 
             RGBColor[
              0.9532369079193844, 0.8492389532515301, 0.5379037780461721], 
             UndirectedEdge[133, 304] -> 
             RGBColor[
              0.9032979536803313, 0.6530371903687326, 0.24098333460086713`], 
             UndirectedEdge[107, 314] -> 
             RGBColor[
              0.9860138985102084, 0.9862160735605986, 0.7442254831824034], 
             UndirectedEdge[13, 279] -> 
             RGBColor[
              0.8802058199663241, 0.7535378638563964, 0.6101126578814935], 
             UndirectedEdge[180, 418] -> 
             RGBColor[
              0.9868580087590332, 0.9754474753442455, 0.6172415570098084], 
             UndirectedEdge[112, 207] -> 
             RGBColor[
              0.9142400545482177, 0.9307163020933902, 0.8268022916198348], 
             UndirectedEdge[308, 369] -> 
             RGBColor[
              0.8403534148137384, 0.8754060409696713, 0.947066892021833], 
             UndirectedEdge[45, 292] -> 
             RGBColor[
              0.9792372911990512, 0.9829537503988077, 0.8715742517202871], 
             UndirectedEdge[348, 418] -> 
             RGBColor[
              0.985988889325798, 0.9750880721232521, 0.6316451152275071], 
             UndirectedEdge[51, 264] -> 
             RGBColor[
              0.9146875251371384, 0.934646134668568, 0.9860082189186974], 
             UndirectedEdge[201, 218] -> 
             RGBColor[
              0.9934485439452356, 0.9883954228897014, 0.5282926232180687], 
             UndirectedEdge[262, 376] -> 
             RGBColor[
              0.9797909621199937, 0.941891114385214, 0.5121463614100196], 
             UndirectedEdge[304, 307] -> 
             RGBColor[
              0.8666389060388191, 0.7663489467800113, 0.6135918955074298], 
             UndirectedEdge[8, 166] -> 
             RGBColor[
              0.9157603691637994, 0.9354982121168098, 0.9859933867766975], 
             UndirectedEdge[66, 312] -> 
             RGBColor[
              0.9878926981173626, 0.9741953905449692, 0.5884822872640753], 
             UndirectedEdge[202, 430] -> 
             RGBColor[
              0.9945796324976368, 0.9908147069326927, 0.6514046318775374], 
             UndirectedEdge[348, 404] -> 
             RGBColor[
              0.9724698683582398, 0.9294852399826035, 0.5791262716214353], 
             UndirectedEdge[1, 113] -> 
             RGBColor[
              0.9895329088875828, 0.9879988206514416, 0.6820559232800655], 
             UndirectedEdge[29, 377] -> 
             RGBColor[
              0.9523752971980192, 0.8467112354692226, 0.2918902608578103], 
             UndirectedEdge[259, 404] -> 
             RGBColor[
              0.9734280903320932, 0.9220288506883727, 0.35127357793461844`], 
             UndirectedEdge[131, 449] -> 
             RGBColor[
              0.8684436630111676, 0.8973086813890769, 0.9477570854756668], 
             UndirectedEdge[423, 465] -> 
             RGBColor[
              0.9825529801522501, 0.962612962572256, 0.6121803003934922], 
             UndirectedEdge[177, 412] -> 
             RGBColor[
              0.70723494510937, 0.7688957318512728, 0.9527987935184993], 
             UndirectedEdge[139, 158] -> 
             RGBColor[
              0.9569210631561367, 0.8546224480676686, 0.4283743556515843], 
             UndirectedEdge[454, 500] -> 
             RGBColor[
              0.5635394573271708, 0.6528762864484965, 0.9604614154676531], 
             UndirectedEdge[430, 459] -> 
             RGBColor[
              0.965246041798069, 0.8874512831027077, 0.44554267036424056`], 
             UndirectedEdge[474, 490] -> 
             RGBColor[
              0.9240399864352078, 0.821563221658327, 0.6211816756113631], 
             UndirectedEdge[443, 451] -> 
             RGBColor[
              0.5676714567317892, 0.5850183917308942, 0.6093427416402356], 
             UndirectedEdge[182, 483] -> 
             RGBColor[
              0.9935932212994726, 0.9916186466076989, 0.7558404334869194], 
             UndirectedEdge[92, 457] -> 
             RGBColor[
              0.9644971053445355, 0.8846812293082674, 0.501941365069788], 
             UndirectedEdge[38, 184] -> 
             RGBColor[
              0.9936456983969901, 0.9888171163266317, 0.5497516685953199], 
             UndirectedEdge[51, 457] -> 
             RGBColor[
              0.9382050002424843, 0.8668146073801563, 0.6244567782179229], 
             UndirectedEdge[321, 455] -> 
             RGBColor[
              0.9636927371146857, 0.9711227641956486, 0.8873358730273959], 
             UndirectedEdge[251, 435] -> 
             RGBColor[
              0.9713344679532074, 0.9762189709561389, 0.8445152617322578], 
             UndirectedEdge[16, 441] -> 
             RGBColor[
              0.6864997354118483, 0.7466134573334096, 0.8078659768486895], 
             UndirectedEdge[302, 390] -> 
             RGBColor[
              0.9907870102257501, 0.9904582062123797, 0.8023466132199607], 
             UndirectedEdge[186, 455] -> 
             RGBColor[
              0.9641740424717298, 0.9693867038099513, 0.7386985993671715], 
             UndirectedEdge[349, 353] -> 
             RGBColor[
              0.9475855236746584, 0.8288769667052134, 0.5433580422702399], 
             UndirectedEdge[125, 406] -> 
             RGBColor[
              0.9321242159330565, 0.945913845039849, 0.8827165531477756], 
             UndirectedEdge[307, 433] -> 
             RGBColor[
              0.9102104000439895, 0.9281177542313042, 0.866617603587658], 
             UndirectedEdge[406, 419] -> 
             RGBColor[
              0.9937009654822186, 0.9915343702897959, 0.7446901575852847], 
             UndirectedEdge[237, 274] -> 
             RGBColor[
              0.9429261818955945, 0.7952948481176623, 0.42774372813718187`], 
             UndirectedEdge[203, 264] -> 
             RGBColor[
              0.9094546666361296, 0.8397954355427126, 0.6264774564811623], 
             UndirectedEdge[69, 231] -> 
             RGBColor[
              0.9772638919194108, 0.9812075252372467, 0.8626234995248276], 
             UndirectedEdge[328, 399] -> 
             RGBColor[
              0.9808883265977569, 0.9465768978572836, 0.4327273438015976], 
             UndirectedEdge[78, 262] -> 
             RGBColor[
              0.9942376444990961, 0.9900832291841047, 0.614181348741663], 
             UndirectedEdge[27, 412] -> 
             RGBColor[
              0.8792811501042643, 0.9061534814029366, 0.9679954924850622], 
             UndirectedEdge[147, 221] -> 
             RGBColor[
              0.9481198012085674, 0.9607803993979235, 0.9710391546147912], 
             UndirectedEdge[93, 289] -> 
             RGBColor[
              0.9520682355097974, 0.8410686307354622, 0.31468974749369805`], 
             UndirectedEdge[141, 235] -> 
             RGBColor[
              0.9473645854558395, 0.8160385038573692, 0.404919991090505], 
             UndirectedEdge[185, 464] -> 
             RGBColor[
              0.9075332766204559, 0.9268380520315235, 0.9034877176205098], 
             UndirectedEdge[6, 189] -> 
             RGBColor[
              0.9796499590632873, 0.9614935609087051, 0.6427462882058663], 
             UndirectedEdge[38, 316] -> 
             RGBColor[
              0.5862922071714266, 0.6471180877750845, 0.7422639385000372], 
             UndirectedEdge[322, 343] -> 
             RGBColor[
              0.9895049463808943, 0.9888442295769532, 0.7448121623465866], 
             UndirectedEdge[93, 141] -> 
             RGBColor[
              0.9133639693312048, 0.6932627697092675, 0.24909909454809492`], 
             UndirectedEdge[191, 237] -> 
             RGBColor[
              0.9181086309946918, 0.779291154044204, 0.6048479388203332], 
             UndirectedEdge[145, 461] -> 
             RGBColor[
              0.9778718606185128, 0.9353948199185409, 0.5066224895265518], 
             UndirectedEdge[420, 500] -> 
             RGBColor[
              0.8714319869644154, 0.896676776021099, 0.7836062800203458], 
             UndirectedEdge[402, 458] -> 
             RGBColor[
              0.8897630548665739, 0.9149369242486198, 0.9893475885456715], 
             UndirectedEdge[148, 263] -> 
             RGBColor[
              0.9257249414240809, 0.9353782328427894, 0.7014923874486901], 
             UndirectedEdge[126, 499] -> 
             RGBColor[
              0.9329247665151779, 0.948332204158391, 0.9580761727290731], 
             UndirectedEdge[133, 371] -> 
             RGBColor[
              0.8443783599504217, 0.7364564051894233, 0.6088470966422992], 
             UndirectedEdge[72, 245] -> 
             RGBColor[
              0.9938836347655482, 0.9893260381599204, 0.5756495739398104], 
             UndirectedEdge[57, 131] -> 
             RGBColor[
              0.9167599472887131, 0.9353264659477489, 0.9525004253856664], 
             UndirectedEdge[15, 173] -> 
             RGBColor[
              0.613859141446401, 0.6364519975924864, 0.6167326804862945], 
             UndirectedEdge[138, 415] -> 
             RGBColor[
              0.9734453991104042, 0.9793975361537024, 0.9155636552544474], 
             UndirectedEdge[105, 109] -> 
             RGBColor[
              0.9455147506648878, 0.8674272777417192, 0.6083289885832253], 
             UndirectedEdge[235, 284] -> 
             RGBColor[
              0.9932363641326927, 0.987941591725342, 0.5051981600447913], 
             UndirectedEdge[150, 473] -> 
             RGBColor[
              0.9011531303592482, 0.6344768326573373, 0.2387373290865165], 
             UndirectedEdge[74, 417] -> 
             RGBColor[
              0.8709974025706744, 0.8319375406894354, 0.6278219407818957], 
             UndirectedEdge[20, 413] -> 
             RGBColor[
              0.6995810902283732, 0.7634715931222523, 0.9722714429358523], 
             UndirectedEdge[34, 467] -> 
             RGBColor[
              0.8767169302552783, 0.9024487562071866, 0.8881773960578845], 
             UndirectedEdge[62, 110] -> 
             RGBColor[
              0.9922233964859998, 0.9887416838387668, 0.610592652657804], 
             UndirectedEdge[93, 389] -> 
             RGBColor[
              0.9585715100237293, 0.8630057027124247, 0.3399537409399798], 
             UndirectedEdge[28, 408] -> 
             RGBColor[
              0.864082847402567, 0.89199326462863, 0.8603622896844434], 
             UndirectedEdge[93, 284] -> 
             RGBColor[
              0.959235748008058, 0.8651658575772401, 0.34937726350238124`], 
             UndirectedEdge[143, 313] -> 
             RGBColor[
              0.988015522581673, 0.9704342930515873, 0.4760875807668894], 
             UndirectedEdge[361, 398] -> 
             RGBColor[
              0.9493706493073657, 0.8293490636639305, 0.3178550108424946], 
             UndirectedEdge[105, 382] -> 
             RGBColor[
              0.9760485586192266, 0.98029765314115, 0.8645249669741717], 
             UndirectedEdge[240, 495] -> 
             RGBColor[
              0.9927736440385696, 0.9900351608043859, 0.678955882211089], 
             UndirectedEdge[13, 21] -> 
             RGBColor[
              0.9440523897604667, 0.8012532703050674, 0.488448304966405], 
             UndirectedEdge[32, 179] -> 
             RGBColor[
              0.8545083176597374, 0.8869769759360291, 0.98594483052387], 
             UndirectedEdge[38, 79] -> 
             RGBColor[
              0.9667323362191399, 0.8939525212401911, 0.4107262939198263], 
             UndirectedEdge[328, 407] -> 
             RGBColor[
              0.9920832861188615, 0.9894594093012837, 0.6692972793924988], 
             UndirectedEdge[357, 367] -> 
             RGBColor[
              0.9933242935809761, 0.9881296639241892, 0.5147687378527911], 
             UndirectedEdge[196, 213] -> 
             RGBColor[
              0.9812205452049715, 0.9487378312325079, 0.5421662694335814], 
             UndirectedEdge[233, 326] -> 
             RGBColor[
              0.9900212408099378, 0.9774179538607752, 0.4653505819839244], 
             UndirectedEdge[164, 372] -> 
             RGBColor[
              0.9149538447951739, 0.9345876678402183, 0.976644020958991], 
             UndirectedEdge[3, 278] -> 
             RGBColor[
              0.9859024184123146, 0.9706161527275098, 0.6024155794210363], 
             UndirectedEdge[195, 399] -> 
             RGBColor[
              0.9627504673768508, 0.9361314245657788, 0.6442687895849698], 
             UndirectedEdge[118, 187] -> 
             RGBColor[
              0.9651528206533169, 0.9735232862043557, 0.9434985533437292], 
             UndirectedEdge[61, 178] -> 
             RGBColor[
              0.9656303485926644, 0.8954286712955709, 0.5334591206826308], 
             UndirectedEdge[2, 496] -> 
             RGBColor[
              0.8780518026405021, 0.9051185740551465, 0.9641001768386592], 
             UndirectedEdge[103, 404] -> 
             RGBColor[
              0.9596750897954294, 0.9203928497753653, 0.6209334892450935], 
             UndirectedEdge[37, 374] -> 
             RGBColor[
              0.9305848397759406, 0.7468340918712073, 0.5056111507609602], 
             UndirectedEdge[236, 466] -> 
             RGBColor[
              0.9923893837722235, 0.9902945626572233, 0.7157303068238232], 
             UndirectedEdge[150, 254] -> 
             RGBColor[
              0.9017641416875519, 0.6368992889666066, 0.2392289631435489], 
             UndirectedEdge[148, 229] -> 
             RGBColor[
              0.9155950821456688, 0.9012078388926383, 0.6621397970154697], 
             UndirectedEdge[160, 432] -> 
             RGBColor[
              0.9502157368576716, 0.8285952911802743, 0.49306787071376734`], 
             UndirectedEdge[48, 198] -> 
             RGBColor[
              0.9866179278027272, 0.9779259506639111, 0.639037666015732], 
             UndirectedEdge[89, 178] -> 
             RGBColor[
              0.9929494477307144, 0.9908884290384856, 0.732781478225722], 
             UndirectedEdge[63, 239] -> 
             RGBColor[
              0.9899223273428666, 0.989781504980844, 0.7934790724604963], 
             UndirectedEdge[425, 462] -> 
             RGBColor[
              0.9078519820460712, 0.9280285990383925, 0.9441807033741495], 
             UndirectedEdge[44, 457] -> 
             RGBColor[
              0.9240030556444889, 0.736404470650514, 0.2577092785752433], 
             UndirectedEdge[46, 254] -> 
             RGBColor[
              0.9361722915670969, 0.7846514359261761, 0.2675009314472535], 
             UndirectedEdge[1, 452] -> 
             RGBColor[
              0.9932072120368045, 0.9895182394289286, 0.6211632113057217], 
             UndirectedEdge[260, 299] -> 
             RGBColor[
              0.9728386452797986, 0.9767543105079737, 0.7954349232152861], 
             UndirectedEdge[321, 341] -> 
             RGBColor[
              0.9757025117770222, 0.9800896867249056, 0.8673549750027674], 
             UndirectedEdge[249, 406] -> 
             RGBColor[
              0.9730834510491706, 0.9781043346559118, 0.8703526105494059], 
             UndirectedEdge[398, 496] -> 
             RGBColor[
              0.8552284287428109, 0.7735722508863756, 0.616053601264918], 
             UndirectedEdge[382, 462] -> 
             RGBColor[
              0.9117327730939699, 0.9296334058684794, 0.879865952545176], 
             UndirectedEdge[63, 272] -> 
             RGBColor[
              0.937927019721724, 0.7718964344573016, 0.4549779645136986], 
             UndirectedEdge[117, 270] -> 
             RGBColor[
              0.8695018006616807, 0.8987811501227322, 0.9874150520321736], 
             UndirectedEdge[164, 404] -> 
             RGBColor[
              0.9176759607768739, 0.8875643387454921, 0.6398259439465588], 
             UndirectedEdge[133, 191] -> 
             RGBColor[
              0.9222420686501657, 0.7980601290488192, 0.6082969805198889], 
             UndirectedEdge[307, 469] -> 
             RGBColor[
              0.8104416318949725, 0.8518948583517296, 0.9817269929236778], 
             UndirectedEdge[31, 237] -> 
             RGBColor[
              0.9380644960098101, 0.7941052317156161, 0.5679790777872912], 
             UndirectedEdge[1, 468] -> 
             RGBColor[
              0.585979652086054, 0.6464495640516389, 0.7082442463236174], 
             UndirectedEdge[346, 395] -> 
             RGBColor[
              0.7743257312409487, 0.822703456915719, 0.9403891147967727], 
             UndirectedEdge[214, 223] -> 
             RGBColor[
              0.9926594741751712, 0.9905479141282656, 0.7215515526036572], 
             UndirectedEdge[264, 397] -> 
             RGBColor[
              0.9405751580035284, 0.9511259529955771, 0.7815479873823541], 
             UndirectedEdge[103, 204] -> 
             RGBColor[
              0.9777488575703535, 0.9803205728562263, 0.7795245969987232], 
             UndirectedEdge[110, 356] -> 
             RGBColor[
              0.8904757771188363, 0.9105855172256148, 0.7079394850956473], 
             UndirectedEdge[184, 253] -> 
             RGBColor[
              0.9922299067709628, 0.9847537862771856, 0.4836684878425451], 
             UndirectedEdge[115, 417] -> 
             RGBColor[
              0.9508017430444835, 0.8948625295073549, 0.6176059557184419], 
             UndirectedEdge[243, 459] -> 
             RGBColor[
              0.9524617436610865, 0.845450747484572, 0.30030941161763147`], 
             UndirectedEdge[190, 349] -> 
             RGBColor[
              0.9773729218292125, 0.9438872535883611, 0.5834018968935049], 
             UndirectedEdge[128, 222] -> 
             RGBColor[
              0.9937966379347769, 0.9893639164530033, 0.5824597222488933], 
             UndirectedEdge[204, 275] -> 
             RGBColor[
              0.9735239603583116, 0.9203955550888154, 0.444801512600111], 
             UndirectedEdge[178, 455] -> 
             RGBColor[
              0.96323196803881, 0.9709322243415488, 0.8949720090468027], 
             UndirectedEdge[84, 391] -> 
             RGBColor[
              0.9021001805939162, 0.9046428092773591, 0.6817359904434686], 
             UndirectedEdge[54, 203] -> 
             RGBColor[
              0.9630908693040025, 0.8793242017333902, 0.5018777634257504], 
             UndirectedEdge[236, 314] -> 
             RGBColor[
              0.9940628581449404, 0.989709378846177, 0.5951569327481684], 
             UndirectedEdge[277, 313] -> 
             RGBColor[
              0.9873160076591273, 0.9714222341248955, 0.580519926226947], 
             UndirectedEdge[186, 397] -> 
             RGBColor[
              0.9934536207929823, 0.9884062817536834, 0.5288452067646205], 
             UndirectedEdge[29, 297] -> 
             RGBColor[
              0.9683344638206173, 0.8988484598918745, 0.4981715522866159], 
             UndirectedEdge[130, 208] -> 
             RGBColor[
              0.9686969859642347, 0.911358653864625, 0.5543835342628085], 
             UndirectedEdge[145, 450] -> 
             RGBColor[
              0.9400073924809431, 0.9086807723322723, 0.6468253147595617], 
             UndirectedEdge[86, 350] -> 
             RGBColor[
              0.9657314352080737, 0.8901910362575658, 0.3976863467791183], 
             UndirectedEdge[37, 281] -> 
             RGBColor[
              0.9859867077705109, 0.9879291449920771, 0.8575380433377878], 
             UndirectedEdge[281, 445] -> 
             RGBColor[
              0.987551799291028, 0.9876309278462814, 0.7628781758485441], 
             UndirectedEdge[116, 224] -> 
             RGBColor[
              0.7223359095384414, 0.7822415882792935, 0.973721395587443], 
             UndirectedEdge[112, 163] -> 
             RGBColor[
              0.9423003095049807, 0.9530907877205829, 0.8294787037872962], 
             UndirectedEdge[148, 480] -> 
             RGBColor[
              0.88403810698427, 0.7802225973251857, 0.615251446826057], 
             UndirectedEdge[42, 487] -> 
             RGBColor[
              0.9289930845303124, 0.9340141647928917, 0.6959637208678902], 
             UndirectedEdge[122, 319] -> 
             RGBColor[
              0.9707049629397341, 0.9478999164997524, 0.6431927164816696], 
             UndirectedEdge[129, 348] -> 
             RGBColor[
              0.8429264713077493, 0.8767986813410431, 0.9186947115639787], 
             UndirectedEdge[93, 201] -> 
             RGBColor[
              0.9594668448450514, 0.8656601503440947, 0.3745307280447562], 
             UndirectedEdge[121, 427] -> 
             RGBColor[
              0.7034308340295772, 0.666396207371595, 0.6056854406121629], 
             UndirectedEdge[269, 411] -> 
             RGBColor[
              0.9639653719828034, 0.9722807237563731, 0.9295229644021236], 
             UndirectedEdge[76, 371] -> 
             RGBColor[
              0.8692931883999993, 0.8365138481777028, 0.628960285361825], 
             UndirectedEdge[61, 244] -> 
             RGBColor[
              0.9615865810424375, 0.8935696019680839, 0.592106504345496], 
             UndirectedEdge[184, 436] -> 
             RGBColor[
              0.9684265881659242, 0.9729828026930747, 0.7647378667655969], 
             UndirectedEdge[80, 293] -> 
             RGBColor[
              0.9415952939438665, 0.7883909625404227, 0.4653349992705397], 
             UndirectedEdge[111, 460] -> 
             RGBColor[
              0.9887348525871491, 0.9896095862907724, 0.8363561761053073], 
             UndirectedEdge[286, 358] -> 
             RGBColor[
              0.9790450505883894, 0.9487534956787181, 0.5845462774748225], 
             UndirectedEdge[176, 244] -> 
             RGBColor[
              0.9888972094047297, 0.9894898574818396, 0.825297193892669], 
             UndirectedEdge[99, 321] -> 
             RGBColor[
              0.9934625167739507, 0.9911908332344317, 0.7308378708955242], 
             UndirectedEdge[187, 478] -> 
             RGBColor[
              0.9674213718922102, 0.9744613904407456, 0.9059027884928527], 
             UndirectedEdge[116, 185] -> 
             RGBColor[
              0.7724541011267516, 0.8199361091459203, 0.8909469029024626], 
             UndirectedEdge[97, 257] -> 
             RGBColor[
              0.9150820989857313, 0.9303273818061029, 0.7409277124698448], 
             UndirectedEdge[16, 313] -> 
             RGBColor[
              0.6802373888166477, 0.726878484682465, 0.6653940009357717], 
             UndirectedEdge[166, 344] -> 
             RGBColor[
              0.9419437109240983, 0.9527018004133443, 0.8209618056660029], 
             UndirectedEdge[103, 443] -> 
             RGBColor[
              0.9588632910538686, 0.9176544620006717, 0.6177798044294586], 
             UndirectedEdge[74, 115] -> 
             RGBColor[
              0.875892252587818, 0.9035541833443888, 0.9700942762177083], 
             UndirectedEdge[196, 332] -> 
             RGBColor[
              0.9364597104163486, 0.9161483707513103, 0.6616343215110095], 
             UndirectedEdge[49, 203] -> 
             RGBColor[
              0.8292526937763127, 0.7765971003155367, 0.6186280194945253], 
             UndirectedEdge[95, 122] -> 
             RGBColor[
              0.9836927210090042, 0.9553169116538611, 0.5048341848112687], 
             UndirectedEdge[97, 209] -> 
             RGBColor[
              0.9057953689747704, 0.899410249664238, 0.6700560569681137], 
             UndirectedEdge[484, 490] -> 
             RGBColor[
              0.9472547945782597, 0.9126448479886579, 0.6448467610728466], 
             UndirectedEdge[128, 415] -> 
             RGBColor[
              0.9893404904604602, 0.9875211849546068, 0.6563096180383126], 
             UndirectedEdge[371, 442] -> 
             RGBColor[
              0.8747109160156434, 0.8566653268564421, 0.6402357938177208], 
             UndirectedEdge[88, 311] -> 
             RGBColor[
              0.9618494418214505, 0.9688505276537008, 0.8452693719658209], 
             UndirectedEdge[15, 149] -> 
             RGBColor[
              0.9708913718095129, 0.9298919765599711, 0.6043546060625606], 
             UndirectedEdge[117, 140] -> 
             RGBColor[
              0.919018004091164, 0.8831676213305962, 0.6353942535242233], 
             UndirectedEdge[199, 475] -> 
             RGBColor[
              0.806104410324234, 0.8027684903663539, 0.6329583151419778], 
             UndirectedEdge[71, 169] -> 
             RGBColor[
              0.949448256244379, 0.8876492222980064, 0.6150837694310114], 
             UndirectedEdge[23, 51] -> 
             RGBColor[
              0.956716531122688, 0.967239840298252, 0.9581518020593288], 
             UndirectedEdge[381, 416] -> 
             RGBColor[
              0.9668653558592655, 0.9713879960645966, 0.7332268838507885], 
             UndirectedEdge[121, 447] -> 
             RGBColor[
              0.3749898128697492, 0.4947711309669157, 0.9454590826113412], 
             UndirectedEdge[244, 407] -> 
             RGBColor[
              0.9868654640531007, 0.988649678565467, 0.8589684723575826], 
             UndirectedEdge[255, 385] -> 
             RGBColor[
              0.9887941879434203, 0.9896341229854397, 0.8353728356969123], 
             UndirectedEdge[30, 469] -> 
             RGBColor[
              0.8917893255664779, 0.9145541731717564, 0.9046771536308068], 
             UndirectedEdge[80, 171] -> 
             RGBColor[
              0.9060597915523753, 0.7635923641795473, 0.6104936640680885], 
             UndirectedEdge[214, 466] -> 
             RGBColor[
              0.992471488994209, 0.9904701774249389, 0.7246669535422539], 
             UndirectedEdge[199, 455] -> 
             RGBColor[
              0.7936481867570186, 0.839655393073814, 0.9798197334734907], 
             UndirectedEdge[175, 483] -> 
             RGBColor[
              0.9379374597716057, 0.9505934338225992, 0.8851932055756438], 
             UndirectedEdge[124, 416] -> 
             RGBColor[
              0.9757122066299463, 0.9294170919868594, 0.3870699591563888], 
             UndirectedEdge[142, 396] -> 
             RGBColor[
              0.8729551380846207, 0.777614176811958, 0.6155891482896458], 
             UndirectedEdge[185, 361] -> 
             RGBColor[
              0.9856292259611876, 0.9700342375767579, 0.6037017684401813], 
             UndirectedEdge[19, 26] -> 
             RGBColor[
              0.874256320068558, 0.8551318679827189, 0.6384697744065353], 
             UndirectedEdge[341, 455] -> 
             RGBColor[
              0.9473189598647986, 0.9602210947909413, 0.9737109210919905], 
             UndirectedEdge[159, 239] -> 
             RGBColor[
              0.8371747161559224, 0.872667099724965, 0.9345239506183751], 
             UndirectedEdge[261, 482] -> 
             RGBColor[
              0.9770873766170942, 0.9686707167087888, 0.6663768670785712], 
             UndirectedEdge[5, 97] -> 
             RGBColor[
              0.9139219733485073, 0.9268231944343, 0.7016263803796168], 
             UndirectedEdge[285, 396] -> 
             RGBColor[
              0.9054710637007434, 0.9006710662803972, 0.6722603738260415], 
             UndirectedEdge[174, 424] -> 
             RGBColor[
              0.9502423339160337, 0.9411482533923003, 0.6835594545845975], 
             UndirectedEdge[99, 186] -> 
             RGBColor[
              0.9939438221309947, 0.9894547728487344, 0.5822005972352997], 
             UndirectedEdge[79, 127] -> 
             RGBColor[
              0.8884027228052775, 0.8359632591084798, 0.6273702696167578], 
             UndirectedEdge[29, 86] -> 
             RGBColor[
              0.9674237689727219, 0.8969005756975996, 0.3990480382503333], 
             UndirectedEdge[127, 316] -> 
             RGBColor[
              0.5079625937575643, 0.5891288256433732, 0.9589079141969687], 
             UndirectedEdge[197, 466] -> 
             RGBColor[
              0.7220881699621081, 0.7788557700821312, 0.8789970625954207], 
             UndirectedEdge[183, 206] -> 
             RGBColor[
              0.8692029926739908, 0.8982529565424324, 0.9656044336238178], 
             UndirectedEdge[25, 392] -> 
             RGBColor[
              0.8900364429498997, 0.915154916485342, 0.9893736645451154], 
             UndirectedEdge[73, 91] -> 
             RGBColor[
              0.8691883710024855, 0.831334952012208, 0.6278211436015482], 
             UndirectedEdge[187, 464] -> 
             RGBColor[
              0.8858173002246522, 0.9115234138655214, 0.9797047253968695], 
             UndirectedEdge[17, 99] -> 
             RGBColor[
              0.9921158385431356, 0.9906339471779377, 0.7531558142716755], 
             UndirectedEdge[110, 157] -> 
             RGBColor[
              0.9920618629809697, 0.9848227720509642, 0.4289486859981401], 
             UndirectedEdge[241, 429] -> 
             RGBColor[
              0.9222591174716434, 0.9385028260552901, 0.9015394807610083], 
             UndirectedEdge[27, 490] -> 
             RGBColor[
              0.8677280710201962, 0.8975271616881817, 0.987203324020966], 
             UndirectedEdge[372, 418] -> 
             RGBColor[
              0.9688364159325584, 0.9627457202465501, 0.6808287735302452], 
             UndirectedEdge[65, 350] -> 
             RGBColor[
              0.9653751102329378, 0.8916405800663454, 0.5196688621391943], 
             UndirectedEdge[189, 390] -> 
             RGBColor[
              0.9856204423864374, 0.9878436169988256, 0.8665605852537918], 
             UndirectedEdge[263, 267] -> 
             RGBColor[
              0.992639149576976, 0.985231067575491, 0.5620591435037822], 
             UndirectedEdge[25, 490] -> 
             RGBColor[
              0.9337297518094239, 0.9499947749466527, 0.9935411713496143], 
             UndirectedEdge[360, 494] -> 
             RGBColor[
              0.9937255669163052, 0.9897543131483127, 0.614151591860037], 
             UndirectedEdge[61, 203] -> 
             RGBColor[
              0.9358666527101704, 0.783439679706574, 0.26725500724870443`], 
             UndirectedEdge[36, 104] -> 
             RGBColor[
              0.9503412437139708, 0.8386209848036683, 0.2903885346998919], 
             UndirectedEdge[33, 241] -> 
             RGBColor[
              0.9227046794914886, 0.9337530722966074, 0.7023563759148559], 
             UndirectedEdge[82, 419] -> 
             RGBColor[
              0.6692890810653176, 0.7319472724727996, 0.8273517877077028], 
             UndirectedEdge[5, 404] -> 
             RGBColor[
              0.9744426350642931, 0.9254511482965144, 0.35521489263851846`], 
             UndirectedEdge[40, 396] -> 
             RGBColor[
              0.8772875715437158, 0.9049893124849464, 0.9881576658093418], 
             UndirectedEdge[169, 369] -> 
             RGBColor[
              0.9597453494329635, 0.89532877753811, 0.597653476574761], 
             UndirectedEdge[268, 491] -> 
             RGBColor[
              0.9825098862509039, 0.9521424099976614, 0.43089675560607865`], 
             UndirectedEdge[4, 151] -> 
             RGBColor[
              0.9919381969768586, 0.984202052898075, 0.4457779381894533], 
             UndirectedEdge[6, 390] -> 
             RGBColor[
              0.9839560419499165, 0.9637523174808698, 0.592792778701678], 
             UndirectedEdge[376, 482] -> 
             RGBColor[
              0.9746940369072163, 0.9262991857446543, 0.3561915413250209], 
             UndirectedEdge[158, 278] -> 
             RGBColor[
              0.9881050513963427, 0.9705333995552985, 0.4936881274762098], 
             UndirectedEdge[317, 445] -> 
             RGBColor[
              0.860532061628477, 0.8882674385044382, 0.7909912752904386], 
             UndirectedEdge[133, 351] -> 
             RGBColor[
              0.9181774928828614, 0.7950287750966956, 0.6151772470827935], 
             UndirectedEdge[239, 454] -> 
             RGBColor[
              0.6815889074285439, 0.7450379956864165, 0.9223460221072541], 
             UndirectedEdge[140, 198] -> 
             RGBColor[
              0.9705095818660978, 0.9116626042931997, 0.3426513505905284], 
             UndirectedEdge[252, 309] -> 
             RGBColor[
              0.9500007668666254, 0.9592992955059545, 0.8357556449995083], 
             UndirectedEdge[161, 243] -> 
             RGBColor[
              0.9637141946284129, 0.9374829585227782, 0.6439807393648257], 
             UndirectedEdge[244, 455] -> 
             RGBColor[
              0.959188200488583, 0.9690731550140618, 0.9536193927096681], 
             UndirectedEdge[401, 451] -> 
             RGBColor[
              0.5816311259117967, 0.6321076337612541, 0.6635734203422397], 
             UndirectedEdge[210, 225] -> 
             RGBColor[
              0.8372927827699579, 0.8084733739745076, 0.6250972638239567], 
             UndirectedEdge[107, 223] -> 
             RGBColor[
              0.9845284093184536, 0.9868789940749714, 0.8616834563194617], 
             UndirectedEdge[5, 204] -> 
             RGBColor[
              0.9925164028392172, 0.9853788713773755, 0.5138060003921482], 
             UndirectedEdge[59, 200] -> 
             RGBColor[
              0.9669974094355636, 0.8983672161594453, 0.33654846288117657`], 
             UndirectedEdge[328, 481] -> 
             RGBColor[
              0.9933449632198527, 0.9881738741917252, 0.5170185004862786], 
             UndirectedEdge[55, 434] -> 
             RGBColor[
              0.9570763344697917, 0.8675013680064652, 0.555870856410191], 
             UndirectedEdge[269, 499] -> 
             RGBColor[
              0.9384798956178177, 0.9521099201609854, 0.9323143472864994], 
             UndirectedEdge[377, 476] -> 
             RGBColor[
              0.9781127886512893, 0.9375916122624817, 0.3898658076642554], 
             UndirectedEdge[260, 478] -> 
             RGBColor[
              0.970065985012021, 0.9764337385753439, 0.9014261483065829], 
             UndirectedEdge[163, 207] -> 
             RGBColor[
              0.8617935513726278, 0.8926348013744942, 0.9866798323337483], 
             UndirectedEdge[238, 258] -> 
             RGBColor[
              0.9352247186675653, 0.7808946251394832, 0.2667384920498957], 
             UndirectedEdge[10, 443] -> 
             RGBColor[
              0.9486465925264748, 0.9100348649672498, 0.635074010094599], 
             UndirectedEdge[231, 326] -> 
             RGBColor[
              0.9778096075066081, 0.9798513971539256, 0.7385997452012831], 
             UndirectedEdge[91, 287] -> 
             RGBColor[
              0.8824517744697243, 0.878898674755629, 0.6646439563592351], 
             UndirectedEdge[242, 249] -> 
             RGBColor[
              0.9727921209708628, 0.9779838621816901, 0.8751807038850428], 
             UndirectedEdge[83, 209] -> 
             RGBColor[
              0.9518570462197466, 0.936138580788461, 0.6744494608634841], 
             UndirectedEdge[306, 431] -> 
             RGBColor[
              0.9829235762615076, 0.9529145458610762, 0.48550800024192425`], 
             UndirectedEdge[176, 376] -> 
             RGBColor[
              0.9796058503889464, 0.9419737950138307, 0.5267884155324445], 
             UndirectedEdge[30, 191] -> 
             RGBColor[
              0.9669307146801589, 0.9740312002801246, 0.9038557021335807], 
             UndirectedEdge[209, 444] -> 
             RGBColor[
              0.9037040311797973, 0.8977426736743787, 0.6698565833022698], 
             UndirectedEdge[169, 289] -> 
             RGBColor[
              0.9601752838773363, 0.8732103759990334, 0.3212128689071029], 
             UndirectedEdge[20, 46] -> 
             RGBColor[
              0.931970277166351, 0.8610175381293783, 0.6293569804141983], 
             UndirectedEdge[49, 100] -> 
             RGBColor[
              0.8550960429234042, 0.8709692231731063, 0.6815453800410161], 
             UndirectedEdge[404, 486] -> 
             RGBColor[
              0.9750237809656926, 0.9305413484783455, 0.5368013304019793], 
             UndirectedEdge[103, 431] -> 
             RGBColor[
              0.9778343034887726, 0.9805033330358173, 0.7888248579075566], 
             UndirectedEdge[219, 238] -> 
             RGBColor[
              0.9730741230837843, 0.9234964499952432, 0.5323809626658599], 
             UndirectedEdge[249, 499] -> 
             RGBColor[
              0.9222333437630945, 0.9403585585754854, 0.9761739626787052], 
             UndirectedEdge[254, 377] -> 
             RGBColor[
              0.9509935677503407, 0.8412331386432211, 0.29077848891084956`], 
             UndirectedEdge[57, 434] -> 
             RGBColor[
              0.890048503401563, 0.8159949225552614, 0.6227619366599775], 
             UndirectedEdge[75, 104] -> 
             RGBColor[
              0.9409481016208348, 0.8035859313448885, 0.2713436603191609], 
             UndirectedEdge[132, 365] -> 
             RGBColor[
              0.9315828462758068, 0.7817814406216094, 0.5770060398851788], 
             UndirectedEdge[38, 77] -> 
             RGBColor[
              0.9938809780547712, 0.9893203557242028, 0.5753604073670411], 
             UndirectedEdge[172, 314] -> 
             RGBColor[
              0.9892808236783404, 0.9885581508973027, 0.7344684492894908], 
             UndirectedEdge[398, 481] -> 
             RGBColor[
              0.9550826988995212, 0.8481949642420403, 0.3759447205242465], 
             UndirectedEdge[143, 165] -> 
             RGBColor[
              0.8714288835771746, 0.8965190373527383, 0.771166087893586], 
             UndirectedEdge[261, 475] -> 
             RGBColor[
              0.964746404749893, 0.9270417208027273, 0.6184345217714811], 
             UndirectedEdge[288, 373] -> 
             RGBColor[
              0.9825619358256221, 0.9797647738927469, 0.6719931894237505], 
             UndirectedEdge[78, 171] -> 
             RGBColor[
              0.9586770153868127, 0.9652308873081561, 0.7566051250451349], 
             UndirectedEdge[6, 370] -> 
             RGBColor[
              0.9471274665529859, 0.8215726316586947, 0.3102325294152901], 
             UndirectedEdge[264, 295] -> 
             RGBColor[
              0.9156432939146992, 0.9353589454579452, 0.9843903516827074], 
             UndirectedEdge[45, 464] -> 
             RGBColor[
              0.8966703557481557, 0.9196176049047029, 0.9613333333258014], 
             UndirectedEdge[228, 318] -> 
             RGBColor[
              0.8266330255409153, 0.8299257038890404, 0.6512431161160117], 
             UndirectedEdge[7, 295] -> 
             RGBColor[
              0.8390097921703736, 0.8749483269875762, 0.976896586547604], 
             UndirectedEdge[225, 320] -> 
             RGBColor[
              0.9663458748529652, 0.9092217204169496, 0.5876482238325651], 
             UndirectedEdge[137, 148] -> 
             RGBColor[
              0.8753945179298639, 0.7417173054685734, 0.6080774706222971], 
             UndirectedEdge[61, 455] -> 
             RGBColor[
              0.9377075657563168, 0.8757506192157064, 0.6321789307524471], 
             UndirectedEdge[11, 331] -> 
             RGBColor[
              0.9663449098096765, 0.9709252771405034, 0.7281909644385034], 
             UndirectedEdge[20, 392] -> 
             RGBColor[
              0.8890858439075838, 0.9143969346123229, 0.9892829955598497], 
             UndirectedEdge[348, 431] -> 
             RGBColor[
              0.9906290820515828, 0.9895957232430554, 0.7470176402838984], 
             UndirectedEdge[241, 351] -> 
             RGBColor[
              0.8955933639497089, 0.9195634896325298, 0.9891282863005879], 
             UndirectedEdge[343, 374] -> 
             RGBColor[
              0.927548990193444, 0.7455786900510695, 0.5559230348698032], 
             UndirectedEdge[162, 389] -> 
             RGBColor[
              0.9843785665422655, 0.9589673782393693, 0.3938141101872227], 
             UndirectedEdge[207, 266] -> 
             RGBColor[
              0.8357738533529047, 0.8718874004594547, 0.9841980503085686], 
             UndirectedEdge[98, 425] -> 
             RGBColor[
              0.9626989908567568, 0.8954161972378373, 0.5879100225476568], 
             UndirectedEdge[151, 284] -> 
             RGBColor[
              0.9927834825673074, 0.9869729238503331, 0.4559047965136599], 
             UndirectedEdge[41, 365] -> 
             RGBColor[
              0.985175095007282, 0.9862321967607195, 0.7965616264220894], 
             UndirectedEdge[436, 473] -> 
             RGBColor[
              0.9403251601786797, 0.8734079225718473, 0.6247565464523759], 
             UndirectedEdge[311, 405] -> 
             RGBColor[
              0.9573618407179019, 0.9672355412176447, 0.9371406607838157], 
             UndirectedEdge[235, 432] -> 
             RGBColor[
              0.9499473959512921, 0.8272397557756848, 0.40704790648952793`], 
             UndirectedEdge[109, 474] -> 
             RGBColor[
              0.9220405545731357, 0.728623807867313, 0.2561302041474117], 
             UndirectedEdge[364, 468] -> 
             RGBColor[
              0.5832345218383298, 0.6472551645762471, 0.894812553321313], 
             UndirectedEdge[203, 374] -> 
             RGBColor[
              0.9008705634442935, 0.6348655365365101, 0.23858802747580324`], 
             UndirectedEdge[36, 112] -> 
             RGBColor[
              0.9790842023808982, 0.9397234354450779, 0.49100069243600836`], 
             UndirectedEdge[324, 342] -> 
             RGBColor[
              0.7885189041007457, 0.8349601275338938, 0.9794911298457851], 
             UndirectedEdge[374, 445] -> 
             RGBColor[
              0.9321499312964577, 0.7465358747254116, 0.4109512832717165], 
             UndirectedEdge[2, 327] -> 
             RGBColor[
              0.9603003842932996, 0.9699126721248731, 0.9520852734600914], 
             UndirectedEdge[128, 438] -> 
             RGBColor[
              0.9362675164457179, 0.9468208661275772, 0.7105885587926837], 
             UndirectedEdge[33, 460] -> 
             RGBColor[
              0.9896474021942918, 0.9850529439004709, 0.6294338784125002], 
             UndirectedEdge[298, 335] -> 
             RGBColor[
              0.9505099550192032, 0.9605760251748241, 0.8845523088192542], 
             UndirectedEdge[112, 343] -> 
             RGBColor[
              0.9898655126445205, 0.9896154443560083, 0.7840575749852581], 
             UndirectedEdge[106, 265] -> 
             RGBColor[
              0.9660786221931901, 0.9710892201976402, 0.7574077123565801], 
             UndirectedEdge[19, 468] -> 
             RGBColor[
              0.48394750815883025`, 0.5702305389085748, 0.9565508083036955], 
             UndirectedEdge[161, 202] -> 
             RGBColor[
              0.976754058777697, 0.9800301239995398, 0.8170307813798761], 
             UndirectedEdge[204, 390] -> 
             RGBColor[
              0.9920567858848073, 0.990038689371944, 0.7126405720843019], 
             UndirectedEdge[211, 289] -> 
             RGBColor[
              0.9856288268860569, 0.9649069728857456, 0.5682700603511837], 
             UndirectedEdge[48, 479] -> 
             RGBColor[
              0.9650490121302107, 0.9015371328822819, 0.5741609808091992], 
             UndirectedEdge[57, 495] -> 
             RGBColor[
              0.9227177223300824, 0.9385210915988101, 0.8864973283042852], 
             UndirectedEdge[10, 280] -> 
             RGBColor[
              0.9642137113538293, 0.9625464121052374, 0.6955493271351518], 
             UndirectedEdge[206, 476] -> 
             RGBColor[
              0.9764270415355302, 0.9784324147124226, 0.7101644809655748], 
             UndirectedEdge[13, 256] -> 
             RGBColor[
              0.9150199574474769, 0.6977818815605986, 0.25032568696804797`], 
             UndirectedEdge[184, 221] -> 
             RGBColor[
              0.9780182527474576, 0.9801362504330728, 0.7485016805358371], 
             UndirectedEdge[126, 282] -> 
             RGBColor[
              0.9839128061363838, 0.9837739603003419, 0.678344896227193], 
             UndirectedEdge[53, 266] -> 
             RGBColor[
              0.8965943549638727, 0.9198766457130667, 0.9724082651520274], 
             UndirectedEdge[194, 220] -> 
             RGBColor[
              0.9650822251634825, 0.8892444636189425, 0.34297408665632434`], 
             UndirectedEdge[375, 417] -> 
             RGBColor[
              0.9505448753876025, 0.8946709580294352, 0.6180407656597269], 
             UndirectedEdge[245, 448] -> 
             RGBColor[
              0.9787466507636998, 0.9808561371424052, 0.7612850084207035], 
             UndirectedEdge[79, 147] -> 
             RGBColor[
              0.9368221687343867, 0.8745716109815045, 0.6319885595940259], 
             UndirectedEdge[77, 253] -> 
             RGBColor[
              0.9924651864287438, 0.9852570256747566, 0.5092772266142663], 
             UndirectedEdge[180, 205] -> 
             RGBColor[
              0.8203128264739123, 0.858813170640981, 0.9019506108630473], 
             UndirectedEdge[28, 432] -> 
             RGBColor[
              0.9501030915547748, 0.8285487094526742, 0.49493469489946607`], 
             UndirectedEdge[84, 245] -> 
             RGBColor[
              0.9874153177435385, 0.9683565300582464, 0.47827378690433464`], 
             UndirectedEdge[19, 459] -> 
             RGBColor[
              0.8625680167142318, 0.8098507834742492, 0.6235490543633881], 
             UndirectedEdge[153, 236] -> 
             RGBColor[
              0.9279444499535925, 0.9413603537188983, 0.805131139442107], 
             UndirectedEdge[315, 349] -> 
             RGBColor[
              0.9914009842808821, 0.9900008922521575, 0.740474159747483], 
             UndirectedEdge[18, 460] -> 
             RGBColor[
              0.8365351939547481, 0.871510579852381, 0.904672654797511], 
             UndirectedEdge[126, 449] -> 
             RGBColor[
              0.866187700133864, 0.8956261879689841, 0.9515758421775897], 
             UndirectedEdge[49, 324] -> 
             RGBColor[
              0.7885189041007457, 0.8349601275338938, 0.9794911298457851], 
             UndirectedEdge[334, 415] -> 
             RGBColor[
              0.9835015893198691, 0.967867092809978, 0.6300643588300787], 
             UndirectedEdge[5, 444] -> 
             RGBColor[
              0.9118306355535342, 0.9251556184444405, 0.7014269067137728], 
             UndirectedEdge[147, 449] -> 
             RGBColor[
              0.8454660001630058, 0.8801239642531569, 0.9849876063404465], 
             UndirectedEdge[254, 426] -> 
             RGBColor[
              0.7324868011987109, 0.7104084448810393, 0.6126750541079709], 
             UndirectedEdge[186, 321] -> 
             RGBColor[
              0.9925575943839533, 0.9892552957439156, 0.6323426532779484], 
             UndirectedEdge[260, 399] -> 
             RGBColor[
              0.9598132756552544, 0.9339408717890223, 0.649240689027342], 
             UndirectedEdge[184, 287] -> 
             RGBColor[
              0.9832884826169119, 0.9545922630593418, 0.4489327434503261], 
             UndirectedEdge[129, 431] -> 
             RGBColor[
              0.8466553275895529, 0.877543483630067, 0.7989516615167478], 
             UndirectedEdge[300, 432] -> 
             RGBColor[
              0.8752120690747851, 0.7719944559081997, 0.614143026740444], 
             UndirectedEdge[207, 293] -> 
             RGBColor[
              0.9143902347355655, 0.9310375223285807, 0.8431484782079521], 
             UndirectedEdge[118, 399] -> 
             RGBColor[
              0.9762579514071617, 0.9461969590264263, 0.6210313313607629], 
             UndirectedEdge[138, 179] -> 
             RGBColor[
              0.8810275825355633, 0.9074759300283433, 0.9660497200871426], 
             UndirectedEdge[40, 161] -> 
             RGBColor[
              0.9390391068166732, 0.953635876396498, 0.9735075197230021], 
             UndirectedEdge[243, 279] -> 
             RGBColor[
              0.9176906762820015, 0.9013774883828078, 0.660131037746186], 
             UndirectedEdge[69, 233] -> 
             RGBColor[
              0.9894755252227405, 0.9787740819440964, 0.5893743363074689], 
             UndirectedEdge[237, 460] -> 
             RGBColor[
              0.9400138596973595, 0.7949113436967794, 0.5356730766930902], 
             UndirectedEdge[54, 295] -> 
             RGBColor[
              0.9692794965825722, 0.9748877116486229, 0.8597906586272955], 
             UndirectedEdge[102, 210] -> 
             RGBColor[
              0.8603396505869237, 0.8878558907422962, 0.7700485208406721], 
             UndirectedEdge[137, 156] -> 
             RGBColor[
              0.9413112905526071, 0.7894367264584816, 0.360079524678922], 
             UndirectedEdge[231, 444] -> 
             RGBColor[
              0.8974931480326906, 0.9204180562876099, 0.9664175277299745], 
             UndirectedEdge[383, 393] -> 
             RGBColor[
              0.9763115586922702, 0.9301961053314185, 0.4950721292638738], 
             UndirectedEdge[43, 137] -> 
             RGBColor[
              0.8914446749809054, 0.5999574474761478, 0.23113111468061015`], 
             UndirectedEdge[233, 348] -> 
             RGBColor[
              0.9867471382583191, 0.9776458238179615, 0.6345907691470555], 
             UndirectedEdge[193, 410] -> 
             RGBColor[
              0.9003353492019777, 0.9229816993531594, 0.9769978959989158], 
             UndirectedEdge[126, 384] -> 
             RGBColor[
              0.9651854702416345, 0.9735559612265472, 0.9438160971840306], 
             UndirectedEdge[162, 345] -> 
             RGBColor[
              0.9857835981027405, 0.9637187860147755, 0.5570500188060208], 
             UndirectedEdge[165, 178] -> 
             RGBColor[
              0.8701055095768389, 0.8972489966649333, 0.8859373927681636], 
             UndirectedEdge[154, 455] -> 
             RGBColor[
              0.9630964232214039, 0.9708761730762084, 0.8972183374499647], 
             UndirectedEdge[211, 470] -> 
             RGBColor[
              0.9731854193546936, 0.9221779344578542, 0.5238592361427463], 
             UndirectedEdge[201, 305] -> 
             RGBColor[
              0.9878731402486101, 0.970389668960533, 0.4384886495352347], 
             UndirectedEdge[220, 474] -> 
             RGBColor[
              0.9265353519530943, 0.7464441816764132, 0.25974682362578116`], 
             UndirectedEdge[125, 173] -> 
             RGBColor[
              0.5703973523662756, 0.6503145440409636, 0.9631356822796489], 
             UndirectedEdge[189, 443] -> 
             RGBColor[
              0.9688651364816934, 0.9251138219442246, 0.6008492890192256], 
             UndirectedEdge[307, 500] -> 
             RGBColor[
              0.7876521458043608, 0.8340915386112345, 0.9794555499300215], 
             UndirectedEdge[102, 134] -> 
             RGBColor[
              0.9944684614013927, 0.9905769231989485, 0.6393043441198432], 
             UndirectedEdge[102, 174] -> 
             RGBColor[
              0.9574019986974234, 0.9644982315316724, 0.7795061154701539], 
             UndirectedEdge[203, 281] -> 
             RGBColor[
              0.9562724314388638, 0.8759605896573799, 0.590514920052631], 
             UndirectedEdge[279, 421] -> 
             RGBColor[
              0.9198739930700386, 0.9087423285760174, 0.6686128111829307], 
             UndirectedEdge[335, 430] -> 
             RGBColor[
              0.9515422801811401, 0.960176521758906, 0.8073737149233954], 
             UndirectedEdge[69, 431] -> 
             RGBColor[
              0.9933574690160043, 0.9907239813691904, 0.7018012074443118], 
             UndirectedEdge[149, 249] -> 
             RGBColor[
              0.9683888178455018, 0.975945012624511, 0.9383936652575452], 
             UndirectedEdge[141, 345] -> 
             RGBColor[
              0.9475024102399483, 0.8173400674912885, 0.4931029452256669], 
             UndirectedEdge[12, 283] -> 
             RGBColor[
              0.9841990700385237, 0.957253182723423, 0.4873936369434866], 
             UndirectedEdge[119, 381] -> 
             RGBColor[
              0.9397548995211243, 0.9545898832219286, 0.9868634200587505], 
             UndirectedEdge[396, 430] -> 
             RGBColor[
              0.914746957492438, 0.9308369302293621, 0.8038641441977746], 
             UndirectedEdge[49, 360] -> 
             RGBColor[
              0.8599677552681967, 0.8870604442599236, 0.7295700104690976], 
             UndirectedEdge[208, 497] -> 
             RGBColor[
              0.9632930751046282, 0.8855937676258274, 0.32360491799001456`], 
             UndirectedEdge[275, 444] -> 
             RGBColor[
              0.8928381930726286, 0.8601723021558805, 0.6324224189217357], 
             UndirectedEdge[269, 323] -> 
             RGBColor[
              0.9369806214281879, 0.7855029912118647, 0.5515513208509768], 
             UndirectedEdge[273, 279] -> 
             RGBColor[
              0.9300763612637555, 0.9425254307678819, 0.7619777145014096], 
             UndirectedEdge[107, 289] -> 
             RGBColor[
              0.9782623342443609, 0.9608696190446442, 0.6459675366215829], 
             UndirectedEdge[289, 314] -> 
             RGBColor[
              0.9860499346099816, 0.963803903281069, 0.4684516426670106], 
             UndirectedEdge[6, 428] -> 
             RGBColor[
              0.9736248081137926, 0.9570000131958512, 0.6529452971523169], 
             UndirectedEdge[7, 17] -> 
             RGBColor[
              0.8616989516193587, 0.8910074624589462, 0.8998696121367298], 
             UndirectedEdge[309, 424] -> 
             RGBColor[
              0.9871653438448023, 0.9669201140787226, 0.5277437339415951], 
             UndirectedEdge[128, 385] -> 
             RGBColor[
              0.9889283086328962, 0.9873507371763193, 0.6631405376134263], 
             UndirectedEdge[71, 362] -> 
             RGBColor[
              0.9023834412808168, 0.9244547983510616, 0.9716461513308143], 
             UndirectedEdge[43, 156] -> 
             RGBColor[
              0.9432359398648449, 0.7981761094720861, 0.3616854992425249], 
             UndirectedEdge[59, 298] -> 
             RGBColor[
              0.9884755658571913, 0.9755453936445491, 0.5864878356806028], 
             UndirectedEdge[261, 455] -> 
             RGBColor[
              0.9522901811826776, 0.9639286235101875, 0.9652959401029939], 
             UndirectedEdge[17, 89] -> 
             RGBColor[
              0.992063538575775, 0.9905220828360914, 0.7474632855824666], 
             UndirectedEdge[9, 68] -> 
             RGBColor[
              0.8014659580318149, 0.844101120673471, 0.9188097704630752], 
             UndirectedEdge[73, 298] -> 
             RGBColor[
              0.96933779600484, 0.9081660537173248, 0.5268442187977632], 
             UndirectedEdge[16, 333] -> 
             RGBColor[
              0.6570691957277901, 0.6427917568859114, 0.6062993826451261], 
             UndirectedEdge[257, 445] -> 
             RGBColor[
              0.9936760526354163, 0.988882040973341, 0.5530555401233562], 
             UndirectedEdge[428, 451] -> 
             RGBColor[
              0.5740955288004095, 0.6409958825004766, 0.9352065563254405], 
             UndirectedEdge[15, 419] -> 
             RGBColor[
              0.9770177022079559, 0.9325145108679829, 0.5032219477629185], 
             UndirectedEdge[17, 313] -> 
             RGBColor[
              0.985806239426398, 0.9707979061613881, 0.6055406929982116], 
             UndirectedEdge[5, 326] -> 
             RGBColor[
              0.9921470950274516, 0.9845889593107562, 0.4736091241850816], 
             UndirectedEdge[216, 217] -> 
             RGBColor[
              0.7993176451742414, 0.8438221368825732, 0.9669479060667729], 
             UndirectedEdge[138, 222] -> 
             RGBColor[
              0.977901546584721, 0.9812402676520988, 0.8417137594650281], 
             UndirectedEdge[251, 447] -> 
             RGBColor[
              0.6081589879699651, 0.6801202691762487, 0.9561844415882943], 
             UndirectedEdge[58, 144] -> 
             RGBColor[
              0.9062780512855251, 0.5631739844696513, 0.4435920959668095], 
             UndirectedEdge[11, 404] -> 
             RGBColor[
              0.9489101843250277, 0.9123644009014547, 0.6391556662694762], 
             UndirectedEdge[270, 329] -> 
             RGBColor[
              0.887372406825565, 0.9130306863931317, 0.9891195664013633], 
             UndirectedEdge[314, 406] -> 
             RGBColor[
              0.9930353835816368, 0.990110757905104, 0.6722456752023093], 
             UndirectedEdge[13, 409] -> 
             RGBColor[
              0.9100088851395515, 0.677914649700532, 0.2462936605641065], 
             UndirectedEdge[279, 335] -> 
             RGBColor[
              0.8876931881147891, 0.9132864686857829, 0.9891501628070943], 
             UndirectedEdge[195, 446] -> 
             RGBColor[
              0.916395927544797, 0.9356181025007511, 0.9726404050111763], 
             UndirectedEdge[22, 170] -> 
             RGBColor[
              0.6638534343639089, 0.7280108785749395, 0.8599985398499344], 
             UndirectedEdge[159, 166] -> 
             RGBColor[
              0.7893567336416198, 0.835930974836538, 0.9794906930074115], 
             UndirectedEdge[59, 87] -> 
             RGBColor[
              0.9889151880417391, 0.9738781584914593, 0.44479718043472516`], 
             UndirectedEdge[176, 407] -> 
             RGBColor[
              0.9926954576831266, 0.9912473982808674, 0.7707186999475345], 
             UndirectedEdge[169, 470] -> 
             RGBColor[
              0.947731876345973, 0.830481337571142, 0.27680204469866565`], 
             UndirectedEdge[13, 188] -> 
             RGBColor[
              0.9434132947819527, 0.7990555625076795, 0.35850013185934815`], 
             UndirectedEdge[273, 396] -> 
             RGBColor[
              0.9143483443372094, 0.9299843369963003, 0.7604775622063892], 
             UndirectedEdge[30, 405] -> 
             RGBColor[
              0.9875968605595113, 0.989138997342283, 0.8552156490322268], 
             UndirectedEdge[258, 497] -> 
             RGBColor[
              0.9472460179254626, 0.8219725332752448, 0.31069307911081423`], 
             UndirectedEdge[90, 485] -> 
             RGBColor[
              0.9820769544042509, 0.9707049408336124, 0.6543496426467716], 
             UndirectedEdge[89, 455] -> 
             RGBColor[
              0.9650266648943667, 0.9712103769586211, 0.8315012882955384], 
             UndirectedEdge[422, 451] -> 
             RGBColor[
              0.5845539363285509, 0.6419669596054878, 0.6749279868848965], 
             UndirectedEdge[99, 178] -> 
             RGBColor[
              0.9930017476980748, 0.9910002933803319, 0.7384740069149309], 
             UndirectedEdge[119, 416] -> 
             RGBColor[
              0.965905563340441, 0.9706721843755733, 0.734851562231178], 
             UndirectedEdge[129, 204] -> 
             RGBColor[
              0.8465698816711338, 0.8773607234504761, 0.7896514006079143], 
             UndirectedEdge[1, 381] -> 
             RGBColor[
              0.9668734981060283, 0.9714054115071149, 0.7341131171627978], 
             UndirectedEdge[287, 409] -> 
             RGBColor[
              0.9495874977408922, 0.8328170058158402, 0.30444588822590335`], 
             UndirectedEdge[340, 384] -> 
             RGBColor[
              0.9689937523457456, 0.9599984866034235, 0.6744814936829664], 
             UndirectedEdge[233, 379] -> 
             RGBColor[
              0.9827420149751974, 0.9751087441265756, 0.6615193930914502], 
             UndirectedEdge[1, 124] -> 
             RGBColor[
              0.9757203488767091, 0.9294345074293776, 0.3879561924683981], 
             UndirectedEdge[134, 309] -> 
             RGBColor[
              0.9949921972961928, 0.9916971413201046, 0.6963097641455672], 
             UndirectedEdge[1, 380] -> 
             RGBColor[
              0.993987765530527, 0.9895487633369747, 0.5869835650871619], 
             UndirectedEdge[112, 403] -> 
             RGBColor[
              0.9932167104056996, 0.99100125075211, 0.728519555460722], 
             UndirectedEdge[214, 268] -> 
             RGBColor[
              0.9939181846848874, 0.989399936943854, 0.5794101194424865], 
             UndirectedEdge[404, 444] -> 
             RGBColor[
              0.8954275114359411, 0.8698240291591015, 0.6377038669869954], 
             UndirectedEdge[252, 320] -> 
             RGBColor[
              0.9450685009103645, 0.9576334404725982, 0.9446647310216373], 
             UndirectedEdge[173, 419] -> 
             RGBColor[
              0.6319741019154379, 0.6959350692909103, 0.8251092867171579], 
             UndirectedEdge[407, 475] -> 
             RGBColor[
              0.9754426723341953, 0.9339437931056295, 0.5521794804330207], 
             UndirectedEdge[167, 305] -> 
             RGBColor[
              0.9592719257961899, 0.8683418113258654, 0.32718898879340963`], 
             UndirectedEdge[407, 482] -> 
             RGBColor[
              0.9877836442013965, 0.975572789011691, 0.6001218257401109], 
             UndirectedEdge[197, 493] -> 
             RGBColor[
              0.724391412080881, 0.7796175958006123, 0.8269700212019315], 
             UndirectedEdge[235, 300] -> 
             RGBColor[
              0.9191040060482233, 0.9339859811345286, 0.7779227122169423], 
             UndirectedEdge[312, 385] -> 
             RGBColor[
              0.9885643993481015, 0.9895390994959778, 0.839181027395169], 
             UndirectedEdge[188, 318] -> 
             RGBColor[
              0.8387525070950281, 0.8704756282905401, 0.7265501716996076], 
             UndirectedEdge[71, 153] -> 
             RGBColor[
              0.9092044987856763, 0.929893724452763, 0.9722967498848578], 
             UndirectedEdge[45, 481] -> 
             RGBColor[
              0.9804783546810429, 0.9816596910280471, 0.7196370938272247], 
             UndirectedEdge[53, 317] -> 
             RGBColor[
              0.8411261640401284, 0.8764003568210899, 0.9669179583665608], 
             UndirectedEdge[253, 301] -> 
             RGBColor[
              0.949300491546713, 0.9550073985154168, 0.7049630569723111], 
             UndirectedEdge[442, 447] -> 
             RGBColor[
              0.6146346784337546, 0.6390680659555743, 0.6197454952342922], 
             UndirectedEdge[118, 464] -> 
             RGBColor[
              0.9049065890963701, 0.9257518492375236, 0.9470187275440207], 
             UndirectedEdge[2, 118] -> 
             RGBColor[
              0.9734335942929898, 0.9796990736263014, 0.9294813635434241], 
             UndirectedEdge[332, 454] -> 
             RGBColor[
              0.6412803077656398, 0.7142896488469272, 0.968029016136362], 
             UndirectedEdge[84, 455] -> 
             RGBColor[
              0.9581261165958478, 0.9493163698617797, 0.6870797942342763], 
             UndirectedEdge[423, 488] -> 
             RGBColor[
              0.6654718721039246, 0.7304975897758356, 0.8999774947786373], 
             UndirectedEdge[5, 231] -> 
             RGBColor[
              0.9765082716610426, 0.9760451754250228, 0.6839285533814974], 
             UndirectedEdge[121, 337] -> 
             RGBColor[
              0.7363732767046505, 0.7902284273516985, 0.8707309757267284], 
             UndirectedEdge[23, 360] -> 
             RGBColor[
              0.9821987341135632, 0.9828524851167834, 0.709563030596366], 
             UndirectedEdge[79, 336] -> 
             RGBColor[
              0.9671175225203597, 0.8947763957901911, 0.45265144571329374`], 
             UndirectedEdge[237, 371] -> 
             RGBColor[
              0.8402449222949477, 0.7176874301848082, 0.6053980549427435], 
             UndirectedEdge[9, 330] -> 
             RGBColor[
              0.9840801892069031, 0.9693555363589594, 0.6291097305327826], 
             UndirectedEdge[76, 111] -> 
             RGBColor[
              0.969291087267076, 0.9138324431393543, 0.5554408231093946], 
             UndirectedEdge[91, 256] -> 
             RGBColor[
              0.8641073617358452, 0.8111904434159469, 0.6237328442789933], 
             UndirectedEdge[35, 193] -> 
             RGBColor[
              0.9106355117049801, 0.8989521217594161, 0.6641660674364669], 
             UndirectedEdge[43, 267] -> 
             RGBColor[
              0.9442333753949967, 0.8003095232148794, 0.47025020124099204`], 
             UndirectedEdge[261, 448] -> 
             RGBColor[
              0.9664384455962245, 0.9744904281944415, 0.9416951367370201], 
             UndirectedEdge[322, 374] -> 
             RGBColor[
              0.9320697239658677, 0.7463643193554845, 0.4022212103192563], 
             UndirectedEdge[76, 130] -> 
             RGBColor[
              0.9693244217866355, 0.9138462278198503, 0.5548883838533238], 
             UndirectedEdge[107, 153] -> 
             RGBColor[
              0.9198954903188604, 0.9378670484333198, 0.9541996898763421], 
             UndirectedEdge[410, 437] -> 
             RGBColor[
              0.9281004148312534, 0.9451208090233147, 0.9796461527448028], 
             UndirectedEdge[11, 164] -> 
             RGBColor[
              0.9085466341552015, 0.9298091806357713, 0.987489757304294], 
             UndirectedEdge[213, 500] -> 
             RGBColor[
              0.8713353685356552, 0.897716654717843, 0.8636999499609913], 
             UndirectedEdge[251, 454] -> 
             RGBColor[
              0.662873833065913, 0.731203361697931, 0.9595356466508254], 
             UndirectedEdge[111, 483] -> 
             RGBColor[
              0.9905012193770977, 0.990340024351972, 0.8070829071851415], 
             UndirectedEdge[5, 233] -> 
             RGBColor[
              0.9887199049643725, 0.9736117321318725, 0.41067939016413874`], 
             UndirectedEdge[69, 372] -> 
             RGBColor[
              0.9724761393409613, 0.9776368272034646, 0.8707279157942809], 
             UndirectedEdge[454, 489] -> 
             RGBColor[
              0.6856690248442068, 0.7448366514269464, 0.717448258112275], 
             UndirectedEdge[289, 493] -> 
             RGBColor[
              0.9866797023560374, 0.9651509128105962, 0.5369979753491765], 
             UndirectedEdge[74, 268] -> 
             RGBColor[
              0.8947179268128803, 0.9144047194917075, 0.7488264652303842], 
             UndirectedEdge[192, 258] -> 
             RGBColor[
              0.9553215116221312, 0.8480585652417476, 0.44023557547366454`], 
             UndirectedEdge[68, 368] -> 
             RGBColor[
              0.8031834066880055, 0.844811329829223, 0.8903472016153502], 
             UndirectedEdge[50, 414] -> 
             RGBColor[
              0.7172887186751338, 0.7738997570341931, 0.8489189163232489], 
             UndirectedEdge[358, 441] -> 
             RGBColor[
              0.9918109029042317, 0.9904263202211475, 0.7522831450284301], 
             UndirectedEdge[71, 289] -> 
             RGBColor[
              0.9675713427111768, 0.9528962950640876, 0.6640645966300986], 
             UndirectedEdge[54, 321] -> 
             RGBColor[
              0.9933153342623723, 0.9915037331764869, 0.7604457408402701], 
             UndirectedEdge[75, 408] -> 
             RGBColor[
              0.8393251392841963, 0.8051709082171926, 0.6242169418100783], 
             UndirectedEdge[8, 239] -> 
             RGBColor[
              0.963578351678102, 0.9722343370052369, 0.941026644387661], 
             UndirectedEdge[389, 472] -> 
             RGBColor[
              0.988762894492093, 0.985450791221625, 0.6493705314892743], 
             UndirectedEdge[178, 475] -> 
             RGBColor[
              0.9756881916060254, 0.9340453216340887, 0.5481105907152899], 
             UndirectedEdge[332, 489] -> 
             RGBColor[
              0.9487041012640681, 0.9570875592150953, 0.7401548446830413], 
             UndirectedEdge[28, 406] -> 
             RGBColor[
              0.9932099962095701, 0.9914601731845887, 0.762191464981345], 
             UndirectedEdge[77, 87] -> 
             RGBColor[0.993621601148623, 0.98876557474898, 0.547128831821533],
              UndirectedEdge[274, 300] -> 
             RGBColor[
              0.9193496073453351, 0.9345112974749507, 0.8046548977320631], 
             UndirectedEdge[330, 333] -> 
             RGBColor[
              0.9588151791148067, 0.8668010975203392, 0.32541461418560935`], 
             UndirectedEdge[325, 490] -> 
             RGBColor[
              0.9651824821786512, 0.9715436543741616, 0.8484610380970945], 
             UndirectedEdge[420, 489] -> 
             RGBColor[
              0.9935615544814513, 0.9886371409995489, 0.5405931226649676], 
             UndirectedEdge[271, 304] -> 
             RGBColor[
              0.9502847007300463, 0.8286474723472312, 0.4031524947048206], 
             UndirectedEdge[166, 387] -> 
             RGBColor[
              0.9077643155908961, 0.8299032715766459, 0.6244029245843528], 
             UndirectedEdge[16, 165] -> 
             RGBColor[
              0.5636507498121494, 0.6529632289836158, 0.9604725080624683], 
             UndirectedEdge[44, 356] -> 
             RGBColor[
              0.8510185040611385, 0.765047997359086, 0.6144746495267831], 
             UndirectedEdge[86, 377] -> 
             RGBColor[
              0.9783824581421388, 0.9381684080356407, 0.419217667536034], 
             UndirectedEdge[113, 353] -> 
             RGBColor[
              0.946430090872803, 0.8283991655483777, 0.5625065539612224], 
             UndirectedEdge[63, 222] -> 
             RGBColor[
              0.9949672342669904, 0.9918677036421635, 0.7098719089271586], 
             UndirectedEdge[71, 493] -> 
             RGBColor[
              0.9759526747230802, 0.979589759109569, 0.8308688758730849], 
             UndirectedEdge[106, 270] -> 
             RGBColor[
              0.8969475548743444, 0.9205875450402239, 0.9873249206448075], 
             UndirectedEdge[414, 498] -> 
             RGBColor[
              0.983412324683368, 0.9558406759852299, 0.5486727027799727], 
             UndirectedEdge[46, 220] -> 
             RGBColor[
              0.9369956751195919, 0.7879158773355153, 0.2681634451808871], 
             UndirectedEdge[302, 443] -> 
             RGBColor[
              0.9740317043210062, 0.9277284111577786, 0.5366353169853946], 
             UndirectedEdge[90, 267] -> 
             RGBColor[
              0.9893584325405615, 0.9741644386626729, 0.5493141773287392], 
             UndirectedEdge[116, 187] -> 
             RGBColor[
              0.7507381247309479, 0.8046214709799182, 0.9671639106788223], 
             UndirectedEdge[162, 472] -> 
             RGBColor[
              0.9818365416623607, 0.9620865767419547, 0.6224629586777433], 
             UndirectedEdge[271, 371] -> 
             RGBColor[
              0.8913651070001367, 0.9120666871679219, 0.7710162567462527], 
             UndirectedEdge[84, 478] -> 
             RGBColor[
              0.9848611299960275, 0.9685032487555065, 0.6080443975705304], 
             UndirectedEdge[5, 163] -> 
             RGBColor[
              0.9403497827556384, 0.9478960122917701, 0.7041470884332528], 
             UndirectedEdge[188, 430] -> 
             RGBColor[
              0.9936824492346127, 0.9888957226522266, 0.5537517704706497], 
             UndirectedEdge[380, 487] -> 
             RGBColor[
              0.932915492007216, 0.9457393363784281, 0.8392634416620193], 
             UndirectedEdge[88, 304] -> 
             RGBColor[
              0.9509050657302152, 0.8299743703540694, 0.4706753965242], 
             UndirectedEdge[41, 494] -> 
             RGBColor[
              0.9945582035742915, 0.9915352387672658, 0.7047789536440294], 
             UndirectedEdge[23, 136] -> 
             RGBColor[
              0.9609938037665482, 0.9704298232326518, 0.9509114951646449], 
             UndirectedEdge[7, 84] -> 
             RGBColor[
              0.8574790093313358, 0.8697579541815714, 0.6772955899674589], 
             UndirectedEdge[218, 493] -> 
             RGBColor[
              0.9944312666218849, 0.9904973673265505, 0.6352559219099969], 
             UndirectedEdge[40, 183] -> 
             RGBColor[
              0.8489243938999773, 0.8827090409814773, 0.9853632611668581], 
             UndirectedEdge[192, 453] -> 
             RGBColor[
              0.9360703883290138, 0.7641125145894863, 0.42435140394679016`], 
             UndirectedEdge[49, 397] -> 
             RGBColor[
              0.8603731851437114, 0.8879276177684013, 0.773698550395717], 
             UndirectedEdge[291, 467] -> 
             RGBColor[
              0.9805732102313169, 0.9839068562091187, 0.8673773907029363], 
             UndirectedEdge[347, 462] -> 
             RGBColor[
              0.7671779684865162, 0.818134273177258, 0.9774049723609513], 
             UndirectedEdge[31, 226] -> 
             RGBColor[
              0.928316840453249, 0.7498434044560682, 0.5598453950539946], 
             UndirectedEdge[120, 381] -> 
             RGBColor[
              0.9522561639711031, 0.9639133057797808, 0.965702040196895], 
             UndirectedEdge[151, 274] -> 
             RGBColor[
              0.9936320526564568, 0.9887879294674269, 0.5482664139500156], 
             UndirectedEdge[316, 418] -> 
             RGBColor[
              0.5820022764409083, 0.6333596116462363, 0.6650152700619424], 
             UndirectedEdge[235, 389] -> 
             RGBColor[
              0.992572126148364, 0.9857814368605267, 0.4957746374823899], 
             UndirectedEdge[218, 310] -> 
             RGBColor[
              0.988542578766803, 0.9722121773227079, 0.4781350945199101], 
             UndirectedEdge[408, 463] -> 
             RGBColor[
              0.852300360891767, 0.8848604113786824, 0.9543991204377676], 
             UndirectedEdge[12, 273] -> 
             RGBColor[
              0.9838127649045446, 0.9564269151032823, 0.4453467071088102], 
             UndirectedEdge[121, 454] -> 
             RGBColor[
              0.4297046579656969, 0.5458542234885979, 0.9488102876738721], 
             UndirectedEdge[47, 228] -> 
             RGBColor[
              0.978727279523874, 0.9479995647240258, 0.5855097005587402], 
             UndirectedEdge[438, 439] -> 
             RGBColor[
              0.9366688899711693, 0.9476793635134293, 0.7542755900477902], 
             UndirectedEdge[172, 201] -> 
             RGBColor[
              0.988927868747747, 0.9878032159899808, 0.6960514832797284], 
             UndirectedEdge[58, 375] -> 
             RGBColor[
              0.8862509288739326, 0.5501115146032345, 0.5624829555184123], 
             UndirectedEdge[168, 280] -> 
             RGBColor[
              0.9871150349525022, 0.9792128480463338, 0.6382734322691233], 
             UndirectedEdge[77, 301] -> 
             RGBColor[
              0.9509398468846583, 0.9595489087388969, 0.7953797680920525], 
             UndirectedEdge[283, 477] -> 
             RGBColor[
              0.9233009074928815, 0.9376411062380596, 0.8033415493783636], 
             UndirectedEdge[125, 149] -> 
             RGBColor[
              0.9274295827293875, 0.9437545230084483, 0.950757607855915], 
             UndirectedEdge[7, 407] -> 
             RGBColor[
              0.862339341502468, 0.8912722801328813, 0.889256694497716], 
             UndirectedEdge[401, 437] -> 
             RGBColor[
              0.94494807621163, 0.9431774825687987, 0.6922501209295383], 
             UndirectedEdge[138, 438] -> 
             RGBColor[
              0.920372425095662, 0.9386972173266729, 0.9698425960088184], 
             UndirectedEdge[45, 399] -> 
             RGBColor[
              0.9680217180589472, 0.9400627146936055, 0.6353459371425437], 
             UndirectedEdge[97, 317] -> 
             RGBColor[
              0.7819381079787922, 0.8297127793372002, 0.9788634476369271], 
             UndirectedEdge[71, 201] -> 
             RGBColor[
              0.9749699520464308, 0.97748781467272, 0.7239055771811567], 
             UndirectedEdge[107, 236] -> 
             RGBColor[
              0.9862752577793198, 0.9867750946097524, 0.7726728267027407], 
             UndirectedEdge[134, 225] -> 
             RGBColor[
              0.9714215935844268, 0.9111944064311599, 0.49435308710312764`], 
             UndirectedEdge[59, 91] -> 
             RGBColor[
              0.8883261408548366, 0.8987142919394322, 0.6874647604843878], 
             UndirectedEdge[161, 287] -> 
             RGBColor[
              0.9658079509140762, 0.9445456901116749, 0.6521145871619302], 
             UndirectedEdge[101, 486] -> 
             RGBColor[
              0.9927575268030961, 0.9897417990163415, 0.6583831486286569], 
             UndirectedEdge[185, 330] -> 
             RGBColor[
              0.9856163413465091, 0.9699907747459958, 0.6036517141452106], 
             UndirectedEdge[237, 432] -> 
             RGBColor[
              0.8987886436250445, 0.6327780065509112, 0.23723185714556272`], 
             UndirectedEdge[99, 143] -> 
             RGBColor[
              0.9943251216984106, 0.9902703340681369, 0.6237027020403534], 
             UndirectedEdge[107, 411] -> 
             RGBColor[
              0.9598831522949256, 0.9696015011836406, 0.9527915384018049], 
             UndirectedEdge[187, 407] -> 
             RGBColor[
              0.9683636220565484, 0.9748510350984241, 0.890287264804513], 
             UndirectedEdge[185, 357] -> 
             RGBColor[
              0.9911536526134748, 0.9884788316580781, 0.6413698789918195], 
             UndirectedEdge[80, 208] -> 
             RGBColor[
              0.9182534518350017, 0.7089763333993955, 0.25284335861334517`], 
             UndirectedEdge[60, 240] -> 
             RGBColor[
              0.860358680683593, 0.8878965941948338, 0.7721198294229715], 
             UndirectedEdge[262, 299] -> 
             RGBColor[
              0.9947109795176134, 0.9910956449272019, 0.6657009444221523], 
             UndirectedEdge[82, 282] -> 
             RGBColor[
              0.6679953162056733, 0.7291800402577129, 0.6865334669266245], 
             UndirectedEdge[286, 368] -> 
             RGBColor[
              0.9795403062263047, 0.9489582966124854, 0.5763386098740603], 
             UndirectedEdge[81, 454] -> 
             RGBColor[
              0.680751996576269, 0.7445368667711485, 0.9292725791996244], 
             UndirectedEdge[68, 352] -> 
             RGBColor[
              0.8049698328432382, 0.8439531696103375, 0.7446642087178523], 
             UndirectedEdge[196, 337] -> 
             RGBColor[
              0.9800932527354407, 0.948271666826262, 0.5608484229930994], 
             UndirectedEdge[261, 262] -> 
             RGBColor[
              0.9821843018298716, 0.9842626453493486, 0.82233168716357], 
             UndirectedEdge[122, 286] -> 
             RGBColor[
              0.9709693565806241, 0.9137349644065289, 0.3417218616030698]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.9606094903739957, 0.8787887030793093, 0.3014757376868928], 
             316 -> RGBColor[0.178927, 0.305394, 0.933501], 308 -> 
             RGBColor[
              0.7032683281720882, 0.7681178300960748, 0.9710588726021598], 
             160 -> RGBColor[
              0.9943760147374892, 0.9919423518111926, 0.742867520414505], 245 -> 
             RGBColor[
              0.9938875874978437, 0.9893344926546178, 0.5760798044567357], 
             155 -> RGBColor[
              0.9307701392399009, 0.7632337021093925, 0.2631542328799791], 
             425 -> RGBColor[
              0.9846163552911982, 0.9879064818183441, 0.9046103346285563], 
             213 -> 
             RGBColor[
              0.9938370537627471, 0.9917194775974715, 0.7517994985522722], 
             352 -> RGBColor[
              0.9934309299168415, 0.9883577482640179, 0.526375444928557], 27 -> 
             RGBColor[
              0.8001469568379302, 0.8438001511146791, 0.9807148289253129], 
             485 -> RGBColor[
              0.980534470224229, 0.9850032202818855, 0.917834243873836], 454 -> 
             RGBColor[
              0.3782452313457785, 0.5020387410587784, 0.9453224295655958], 
             367 -> RGBColor[
              0.9938367665082091, 0.9892257916965796, 0.570548253365802], 19 -> 
             RGBColor[
              0.7889680163176606, 0.8350670778171496, 0.9796006166073912], 
             164 -> RGBColor[
              0.8773124106070478, 0.9050091184798089, 0.9881600349813765], 
             190 -> RGBColor[
              0.9664014644516566, 0.8983263916634453, 0.32397646325607843`], 
             103 -> RGBColor[
              0.9613106686441588, 0.9706661405395551, 0.950375125578446], 138 -> 
             RGBColor[
              0.9607806958098847, 0.9702708876675045, 0.9512722313478192], 
             416 -> RGBColor[
              0.9930160196785822, 0.9874702972182414, 0.4812150260232161], 
             476 -> RGBColor[
              0.9928915909351426, 0.9872041567176997, 0.46767172518499983`], 
             291 -> RGBColor[
              0.9701813305931464, 0.9772818656967343, 0.9353594087379825], 28 -> 
             RGBColor[
              0.9941507241316956, 0.9918491883559925, 0.7466011687859025], 
             337 -> RGBColor[
              0.9915824688236856, 0.9907871487849795, 0.7891638056713084], 
             195 -> RGBColor[
              0.957227141464413, 0.9676206526550628, 0.9572874719392941], 114 -> 
             RGBColor[
              0.9701813305931464, 0.9772818656967343, 0.9353594087379825], 
             479 -> RGBColor[
              0.9436816190456646, 0.8144234170436553, 0.2735431126030796], 93 -> 
             RGBColor[
              0.9258381006754607, 0.74367981270581, 0.259185798881206], 34 -> 
             RGBColor[
              0.7624687706410692, 0.81436566569287, 0.9769594194478789], 161 -> 
             RGBColor[
              0.9586729190454557, 0.968698911207761, 0.9548401476137736], 22 -> 
             RGBColor[
              0.33541479209391883`, 0.4649411672992876, 0.9425933118499377], 
             124 -> RGBColor[
              0.9584083935813104, 0.8713638867554774, 0.29292489228956153`], 
             84 -> RGBColor[
              0.9809430479892333, 0.9473785674618751, 0.38046776935193355`], 
             46 -> RGBColor[
              0.9336914340009483, 0.7748156623731737, 0.26550477521631893`], 
             241 -> RGBColor[
              0.8546204457168776, 0.8869151616333653, 0.9859956551127959], 
             185 -> RGBColor[
              0.9894954845732064, 0.9899241271643575, 0.8237505356438588], 
             426 -> RGBColor[
              0.5263204532641764, 0.6263296802828999, 0.9558530205377536], 
             390 -> RGBColor[
              0.9899265252730665, 0.9901023735709904, 0.8166070757496033], 
             121 -> RGBColor[
              0.4811640845856154, 0.5896697059184175, 0.9522981457821484], 
             322 -> RGBColor[
              0.994025680153318, 0.9896298588813683, 0.5911103377960397], 488 -> 
             RGBColor[
              0.34344549945364256`, 0.47189696237919215`, 0.9431050214216236],
              126 -> RGBColor[
              0.9752804793150632, 0.9810848024644501, 0.9267278800227603], 
             433 -> RGBColor[
              0.9939501917878205, 0.9917662630783539, 0.7499245086849835], 
             236 -> RGBColor[
              0.9943242174140519, 0.9902683998953309, 0.6236042762685057], 78 -> 
             RGBColor[
              0.993377862501342, 0.9882442424282031, 0.5205993842455547], 376 -> 
             RGBColor[
              0.9644844977431373, 0.8918600128304217, 0.31652940958226805`], 
             458 -> RGBColor[
              0.933957583082452, 0.9501764414194502, 0.993562902099823], 254 -> 
             RGBColor[
              0.9386531491332455, 0.7944872094791786, 0.26949708767818814`], 
             290 -> RGBColor[
              0.7791098287023053, 0.8273657867270332, 0.9786180445958936], 
             251 -> RGBColor[
              0.9475024347860473, 0.9603679823370835, 0.9737488637360548], 
             165 -> RGBColor[
              0.7490562682785202, 0.8038877169084533, 0.9756225865593409], 
             460 -> RGBColor[
              0.988505891122484, 0.9895149048410922, 0.8401506601080845], 100 -> 
             RGBColor[
              0.9833140574043528, 0.9553765389585586, 0.38967869320211534`], 
             235 -> RGBColor[
              0.9938393329247301, 0.9892312810020136, 0.5708275919660262], 70 -> 
             RGBColor[
              0.8872614420235612, 0.9129422060720731, 0.9891089824794888], 
             234 -> RGBColor[
              0.984715702904542, 0.9879475646095789, 0.9029638875720654], 435 -> 
             RGBColor[
              0.9951665011203675, 0.9920699595751941, 0.7152816597284607], 
             257 -> RGBColor[
              0.9931660104563343, 0.9877911123254594, 0.4975405965457522], 
             135 -> RGBColor[
              0.9867128850630565, 0.988773450757365, 0.8698654106637361], 265 -> 
             RGBColor[
              0.9934294411202225, 0.9883545638785901, 0.5262133986043577], 
             111 -> RGBColor[
              0.9889638140518142, 0.9897042677404527, 0.8325616921025303], 
             497 -> RGBColor[
              0.97822266137172, 0.9382020646238496, 0.36989958104480086`], 
             481 -> RGBColor[
              0.99318706653348, 0.9878361491453779, 0.49983242060000765`], 
             381 -> RGBColor[
              0.9407146920399488, 0.9553056949109519, 0.985238741678361], 182 -> 
             RGBColor[
              0.995147817896564, 0.9922615122519065, 0.7300767447060861], 188 -> 
             RGBColor[
              0.9930408319838904, 0.9875233682303866, 0.4839156923322034], 
             154 -> RGBColor[
              0.9908836612403454, 0.9904981738907326, 0.8007448557833103], 
             336 -> RGBColor[
              0.9944277869452927, 0.990489924650169, 0.6348771805870094], 463 -> 
             RGBColor[
              0.9705857511100956, 0.9775834818560972, 0.9346748302925512], 
             315 -> RGBColor[
              0.9944575893549957, 0.9905536689910381, 0.6381209889640348], 
             368 -> RGBColor[
              0.9898580776063758, 0.9900740687017889, 0.8177414307235527], 
             269 -> RGBColor[
              0.9863907375203431, 0.9886402344696388, 0.8752042291376131], 
             208 -> RGBColor[
              0.9483634888375365, 0.8329854706278054, 0.27731025493522826`], 
             86 -> RGBColor[
              0.9934309299168415, 0.9883577482640179, 0.526375444928557], 119 -> 
             RGBColor[
              0.9387951070022998, 0.9538740715329053, 0.9884880984391399], 
             436 -> RGBColor[
              0.9432191938807214, 0.9571735482830547, 0.9809992733406284], 
             377 -> RGBColor[
              0.963333986367436, 0.8879790678072637, 0.312059890143511], 140 -> 
             RGBColor[
              0.9541997133414978, 0.8561241559794854, 0.28200621816491167`], 
             85 -> RGBColor[
              0.9263339400598308, 0.7456456506361578, 0.2595847628887165], 
             351 -> RGBColor[
              0.9365662821825401, 0.9522118176316942, 0.9922609174883799], 
             443 -> RGBColor[
              0.9564159134635785, 0.8646427834617884, 0.2851844832804712], 
             242 -> 
             RGBColor[
              0.9916866081308287, 0.9908302130647413, 0.7874379478480613], 
             117 -> RGBColor[
              0.8838362948408303, 0.910211086681707, 0.9887822888835349], 47 -> 
             RGBColor[
              0.9886526901720829, 0.9895756100206647, 0.8377178199524689], 
             451 -> RGBColor[0.178927, 0.305394, 0.933501], 81 -> 
             RGBColor[
              0.9832587618067594, 0.9870349924835186, 0.9132227288336531], 
             275 -> RGBColor[
              0.9528608742200749, 0.8508161050047334, 0.28092895678122154`], 
             23 -> RGBColor[
              0.9713399861331887, 0.9781459891013735, 0.9333981071344537], 
             328 -> RGBColor[
              0.9935028599062253, 0.9885115992380725, 0.5342045803725497], 
             418 -> RGBColor[
              0.9850775528818166, 0.9613252232924727, 0.3965295401238847], 
             110 -> RGBColor[
              0.992603733031592, 0.9865884577689035, 0.4363401688365728], 6 -> 
             RGBColor[
              0.9779855586267664, 0.9374022613907492, 0.36897848165375263`], 
             218 -> RGBColor[
              0.993801498875829, 0.9891503577970233, 0.5667095892278311], 108 -> 
             RGBColor[
              0.9932108120263519, 0.9878869383535932, 0.5024169709589135], 
             297 -> RGBColor[
              0.995252319612632, 0.9922535166525676, 0.7246224730011223], 487 -> 
             RGBColor[
              0.8708877571254859, 0.8998862741861845, 0.9875472457969493], 
             464 -> RGBColor[
              0.8255710686677055, 0.8637519768986894, 0.9832248995971609], 
             157 -> RGBColor[
              0.9915199929303472, 0.983057086333025, 0.42155720315970746`], 
             441 -> RGBColor[
              0.9947542394779181, 0.9911881736080407, 0.6704095241317832], 
             354 -> RGBColor[
              0.9550904611682056, 0.9660271199886443, 0.9609043143453008], 
             385 -> RGBColor[
              0.9852857387557954, 0.9881832890833254, 0.8935169183113029], 
             270 -> RGBColor[
              0.8551673064825311, 0.8873512135637573, 0.9860478151808123], 
             392 -> RGBColor[
              0.8479225674834141, 0.8815744553390628, 0.9853568055076216], 33 -> 
             RGBColor[
              0.9907889132660996, 0.9805909829598496, 0.4187170967169158], 
             252 -> RGBColor[
              0.9051527892122586, 0.9272082806726585, 0.9908154751461409], 
             394 -> RGBColor[
              0.9949107599111838, 0.9921634826828394, 0.7340054090102366], 
             260 -> 
             RGBColor[
              0.9513527580212203, 0.9632395471015498, 0.9672312708240386], 
             159 -> RGBColor[
              0.6894168488005354, 0.7572969491358756, 0.9696782865878377], 
             183 -> RGBColor[
              0.7784434932120639, 0.8268452403777193, 0.9785516305014856], 99 -> 
             RGBColor[
              0.9948487445209921, 0.9913903103392506, 0.6806958148528756], 
             329 -> RGBColor[
              0.9195775071685988, 0.938710159222506, 0.9921913176219144], 309 -> 
             RGBColor[
              0.9948487445209921, 0.9913903103392506, 0.6806958148528756], 17 -> 
             RGBColor[
              0.989382932565279, 0.9898775840166248, 0.8256158136904755], 349 -> 
             RGBColor[
              0.9883443792067684, 0.9894481155132768, 0.8428273305309312], 
             495 -> RGBColor[
              0.9917079551524091, 0.9908390406067582, 0.787084172456152], 347 -> 
             RGBColor[
              0.7032683281720882, 0.7681178300960748, 0.9710588726021598], 
             340 -> RGBColor[
              0.9828970435232856, 0.9539698532182026, 0.38805867302063213`], 
             404 -> RGBColor[
              0.9580395109467, 0.8701195590111754, 0.291491852911741], 277 -> 
             RGBColor[
              0.9924024690307376, 0.9911262399436396, 0.7755742801479465], 
             104 -> RGBColor[
              0.9372608953467156, 0.7889673871566595, 0.26837684760114966`], 
             79 -> RGBColor[
              0.9398072580954265, 0.7990628669302131, 0.2704257108395781], 
             327 -> RGBColor[
              0.957975689525654, 0.9681789185735015, 0.956020375324215], 191 -> 
             RGBColor[
              0.9446954337171486, 0.9582745255359413, 0.9785003843625706], 50 -> 
             RGBColor[
              0.440544052075756, 0.5559988483453105, 0.9492920553338258], 225 -> 
             RGBColor[
              0.9477075370974599, 0.8303848405613612, 0.2767824607679964], 
             405 -> RGBColor[
              0.9860277254758535, 0.9884901196602583, 0.8812202781598628], 61 -> 
             RGBColor[
              0.9401059463101712, 0.8002470661697285, 0.2706660423882752], 
             196 -> RGBColor[
              0.9686040366471959, 0.9057561848675444, 0.3325330403148906], 1 -> 
             RGBColor[
              0.9930323041721079, 0.9875051281032778, 0.4829874926472346], 
             263 -> RGBColor[
              0.9901808726571018, 0.9785399192109755, 0.4163549737697932], 
             201 -> RGBColor[
              0.9930955890146421, 0.9876404879823795, 0.4898756572083064], 
             371 -> RGBColor[
              0.7889680163176606, 0.8350670778171496, 0.9796006166073912], 
             293 -> RGBColor[
              0.995047173055266, 0.99181472890986, 0.7022935362496173], 362 -> 
             RGBColor[
              0.8479225674834141, 0.8815744553390628, 0.9853568055076216], 
             184 -> RGBColor[
              0.9936339824511271, 0.9887920571030946, 0.5484764601905654], 
             106 -> RGBColor[
              0.9387278032661578, 0.9538238765166903, 0.9886020261088027], 
             206 -> RGBColor[
              0.9599624921359178, 0.9696606727071454, 0.9526572367461499], 
             358 -> RGBColor[
              0.9888675663305452, 0.9896644668342544, 0.8341567659250769], 
             247 -> RGBColor[
              0.8546204457168776, 0.8869151616333653, 0.9859956551127959], 
             220 -> RGBColor[
              0.9402999162382355, 0.8010160922978569, 0.2708221151454552], 
             407 -> RGBColor[
              0.9906637123314976, 0.9904072193644949, 0.804389978412448], 107 -> 
             RGBColor[
              0.9782262981445877, 0.9832817893241739, 0.9217413771369758], 
             375 -> RGBColor[
              0.9551828577478652, 0.9660960292064689, 0.9607479110368246], 
             131 -> RGBColor[
              0.9797924050696706, 0.9844497893046359, 0.9190903666189144], 
             411 -> RGBColor[
              0.9415400064452636, 0.9559212130431074, 0.983841699666634], 462 -> 
             RGBColor[
              0.8310876088009442, 0.8681507162584411, 0.9837510721197427], 
             127 -> RGBColor[
              0.8369981875151284, 0.8728636512867465, 0.9843148283939375], 
             210 -> RGBColor[
              0.7268780284424557, 0.786561907387654, 0.9734120668799169], 357 -> 
             RGBColor[
              0.9928118206537431, 0.9870335361517989, 0.4589892223397802], 
             181 -> RGBColor[
              0.9786635247023259, 0.9836078721750421, 0.9210012666216748], 
             194 -> RGBColor[
              0.9898645340887297, 0.9774728349400282, 0.41512605816719356`], 
             440 -> RGBColor[
              0.9921396233658426, 0.9910175465063801, 0.7799303130380321], 
             490 -> RGBColor[
              0.9353091852024623, 0.9512541722616843, 0.9936918191166191], 
             118 -> RGBColor[
              0.9842421095250347, 0.9877517215763579, 0.9108125554908805], 
             348 -> RGBColor[
              0.9869002257697794, 0.9888509209540315, 0.8667606903311295], 
             276 -> 
             RGBColor[
              0.8252405321721189, 0.8634884160692828, 0.9831933727311384], 
             305 -> RGBColor[
              0.9826506914825781, 0.9531388499386866, 0.387101641862163], 343 -> 
             RGBColor[
              0.9849842126084705, 0.988058600272538, 0.8985139868971337], 280 -> 
             RGBColor[
              0.9875501511182875, 0.9696658777377635, 0.406135117361577], 474 -> 
             RGBColor[
              0.9127707876679533, 0.6918722710549696, 0.24867153210610715`], 
             189 -> RGBColor[
              0.9813143594998083, 0.9855848604266609, 0.9165140947579802], 
             168 -> RGBColor[
              0.986679918786717, 0.988759818354904, 0.8704117471766695], 363 -> 
             RGBColor[
              0.8100840557365593, 0.8515630882990369, 0.9817052660760593], 41 -> 
             RGBColor[
              0.9947227554099102, 0.9911208323700993, 0.6669826776262632], 14 -> 
             RGBColor[
              0.9936795749607948, 0.9888895748711639, 0.5534389235035393], 77 -> 
             RGBColor[
              0.994104541766689, 0.9897985358982367, 0.5996939377340077], 51 -> 
             RGBColor[
              0.9420930761121871, 0.9563336914951305, 0.9829054969842039], 
             438 -> RGBColor[
              0.8799641543814392, 0.9071235469858413, 0.9884129606698177], 
             179 -> RGBColor[
              0.801274469261242, 0.844680972389182, 0.980827208826466], 467 -> 
             RGBColor[
              0.9909650898694874, 0.9905318467215031, 0.79939537266789], 223 -> 
             RGBColor[
              0.9908305204923195, 0.9904761988257689, 0.8016255355019477], 
             456 -> RGBColor[
              0.994302308170284, 0.9902215382382756, 0.6212195902925434], 323 -> 
             RGBColor[
              0.8875705053360329, 0.5823657479540907, 0.22789841256434062`], 
             500 -> RGBColor[
              0.7488336833085633, 0.8037138318382145, 0.9756004013697104], 
             478 -> RGBColor[
              0.9887792120028216, 0.989627930049138, 0.8356210257891272], 292 -> 
             RGBColor[
              0.9907049395694967, 0.9904242678868992, 0.8037067363861324], 
             491 -> RGBColor[
              0.9716718309900558, 0.9161045755383771, 0.34445084203255094`], 
             396 -> RGBColor[
              0.8351698484995409, 0.8714057833846575, 0.9841404397864532], 
             321 -> RGBColor[
              0.9920762890269093, 0.9909913561296129, 0.7809799269381729], 
             143 -> RGBColor[
              0.993801498875829, 0.9891503577970233, 0.5667095892278311], 112 -> 
             RGBColor[
              0.9947468126805705, 0.9911722884394787, 0.6696011630733826], 
             197 -> RGBColor[
              0.45372178979382105`, 0.5673908147451469, 0.9501377878117003], 
             421 -> RGBColor[
              0.9731221037874442, 0.9209966862242144, 0.35008487798936744`], 
             54 -> RGBColor[
              0.9945543794978353, 0.9920161102233609, 0.7399115547423671], 71 -> 
             RGBColor[
              0.9568443150782195, 0.9673351413630604, 0.957935497154007], 177 -> 
             RGBColor[
              0.45605454684814134`, 0.5692846520113517, 0.9503214309921871], 
             158 -> RGBColor[
              0.9941302508892002, 0.9898535251116969, 0.6024922170610222], 
             226 -> RGBColor[
              0.8720265171591127, 0.5117841280333708, 0.2149281278115027], 
             432 -> RGBColor[
              0.9060554589778539, 0.6652482305493559, 0.24326822101302964`], 
             350 -> RGBColor[
              0.9380319404993059, 0.7920243242511138, 0.2689972486296796], 
             203 -> RGBColor[
              0.9316273591101696, 0.7666322932434195, 0.2638439721091337], 
             475 -> RGBColor[
              0.9602216323368931, 0.877480366846764, 0.29996898245359327`], 
             115 -> RGBColor[
              0.9556965930616271, 0.9664791721623082, 0.9598782911542546], 
             173 -> RGBColor[
              0.26881554115388295`, 0.3998725560154139, 0.9386200194405339], 
             212 -> RGBColor[
              0.9047446778248507, 0.9268828637302279, 0.9907765491176846], 
             129 -> RGBColor[
              0.6989527168457194, 0.7647464417280546, 0.9706287327968282], 
             279 -> RGBColor[
              0.866625882352633, 0.8964879709278204, 0.987140744376494], 26 -> 
             RGBColor[
              0.9595446238194555, 0.8751966581482882, 0.29733893220567953`], 
             40 -> RGBColor[
              0.9194052945878907, 0.9385728415852352, 0.9921748918322305], 
             146 -> RGBColor[
              0.8482515835368258, 0.3718883918085789, 0.19383907692822067`], 
             386 -> RGBColor[
              0.9876384175579757, 0.9891561822291143, 0.8545269420216086], 
             192 -> RGBColor[
              0.9943736487650573, 0.9903741285568551, 0.6289845737705014], 
             300 -> RGBColor[
              0.8443686791717164, 0.8787406812670434, 0.9850178324678583], 
             221 -> RGBColor[
              0.962402523043788, 0.9714804437630512, 0.9485269008811088], 62 -> 
             RGBColor[
              0.9918430599404076, 0.9908949099086302, 0.7848451364790352], 
             286 -> RGBColor[
              0.9692225348462337, 0.9078425245231819, 0.3349357890245679], 
             472 -> RGBColor[
              0.9862208696121882, 0.9885699897242106, 0.8780193799797948], 
             152 -> RGBColor[
              0.9929790867249203, 0.987391301364853, 0.47719510194088555`], 
             64 -> RGBColor[
              0.9757383883972767, 0.9298220285460188, 0.3602486496546748], 
             307 -> RGBColor[
              0.8264706083001584, 0.8644692453842545, 0.9833106984903327], 37 -> 
             RGBColor[
              0.9910559117734639, 0.9905694039128139, 0.7978902186794475], 
             148 -> RGBColor[
              0.8612690101910601, 0.8922165464746034, 0.986629801127587], 261 -> 
             RGBColor[
              0.969271177162893, 0.9766030747586907, 0.9369000610893689], 387 -> 
             RGBColor[
              0.9262320126990878, 0.7452415426160914, 0.25950274974172005`], 
             15 -> RGBColor[
              0.9589027417389191, 0.8730314391695588, 0.2948453415320551], 
             136 -> RGBColor[
              0.9506476213999075, 0.96271365736393, 0.9684248831948361], 198 -> 
             RGBColor[
              0.9868194503906978, 0.9672010526069138, 0.4032964830161451], 63 -> 
             RGBColor[
              0.9949120711744236, 0.9915257596476336, 0.68758853027208], 444 -> 
             RGBColor[
              0.8328155119251822, 0.8695284993070277, 0.9839158810622498], 
             310 -> RGBColor[
              0.9832836586577769, 0.9552739968483925, 0.3895605998119891], 
             171 -> RGBColor[
              0.9239761682722836, 0.9422175321881092, 0.9926108658447149], 
             395 -> RGBColor[
              0.5702624442992332, 0.6620037681692963, 0.9593122950368501], 
             311 -> RGBColor[
              0.9286959559599504, 0.945980962775031, 0.9930610434077688], 353 -> 
             RGBColor[
              0.9068266681425484, 0.66830581789715, 0.24388875400954857`], 59 -> 
             RGBColor[
              0.9846917155529212, 0.9600237033831954, 0.3950306349603918], 
             397 -> RGBColor[
              0.9938683418449671, 0.9892933281491487, 0.5739850339115172], 
             229 -> RGBColor[
              0.9699211541002775, 0.9101991313106733, 0.3376497929033522], 
             102 -> RGBColor[
              0.9938012727313917, 0.9891498740969386, 0.5666849748014273], 
             453 -> 
             RGBColor[
              0.8777671278929704, 0.5378509006221174, 0.21971823412307892`], 
             299 -> RGBColor[
              0.9943245325383767, 0.9902690739143976, 0.6236385756065336], 
             128 -> RGBColor[
              0.9925708785099968, 0.9865181852693132, 0.43276415691554965`], 
             12 -> RGBColor[
              0.9740986896342113, 0.9242909395986211, 0.3538787295912951], 
             222 -> RGBColor[
              0.9950223973595571, 0.9922096476366933, 0.732155287582237], 483 -> 
             RGBColor[
              0.9920386247023811, 0.9909757809634914, 0.7816041222677528], 92 -> 
             RGBColor[
              0.9946772863162893, 0.9920669353513528, 0.7378746706879341], 
             271 -> RGBColor[
              0.993762197682613, 0.9890662965186944, 0.5624318968851143], 361 -> 
             RGBColor[
              0.9817629673491688, 0.9501443479891583, 0.3836530012365039], 
             344 -> RGBColor[
              0.9945908033654924, 0.990838600289488, 0.6526205119050205], 132 -> 
             RGBColor[
              0.8875382579469597, 0.582219320091879, 0.2278715045524422], 80 -> 
             RGBColor[
              0.888143414832467, 0.5849671961709855, 0.22837646229146202`], 
             324 -> RGBColor[
              0.8501597797590354, 0.8833583476801338, 0.9855701928116534], 
             244 -> RGBColor[
              0.9830672157747038, 0.9868921377664392, 0.913546966302717], 150 -> 
             RGBColor[
              0.8648751342418585, 0.47931136845403466`, 0.20896083860890968`],
              125 -> RGBColor[
              0.8719791635786683, 0.9007565320665132, 0.9876513451187638], 
             258 -> RGBColor[
              0.9162693744792052, 0.70574300192664, 0.2514865771768276], 133 -> 
             RGBColor[
              0.8997887035831827, 0.6378457325616971, 0.2380935766772073], 
             469 -> RGBColor[
              0.7944126554897866, 0.8393204713192048, 0.9801432873570228], 
             255 -> RGBColor[
              0.9923026371310454, 0.991084956887554, 0.7772287530825219], 408 -> 
             RGBColor[
              0.7340149706734385, 0.7921373409012676, 0.9741234105829841], 
             326 -> RGBColor[
              0.9934484308730169, 0.9883951810396591, 0.5282803160048672], 
             176 -> RGBColor[
              0.9947272030347556, 0.9920875771972398, 0.737047421482621], 230 -> 
             RGBColor[
              0.9933460631733649, 0.9881762268810655, 0.5171382236379638], 
             274 -> RGBColor[
              0.9943305355189539, 0.9902819136828579, 0.624291962996268], 87 -> 
             RGBColor[
              0.993138660530557, 0.9877326135997232, 0.4945637259090585], 439 -> 
             RGBColor[
              0.9933736255608995, 0.9882351800410172, 0.5201382194257627], 
             130 -> RGBColor[
              0.989030483090933, 0.9897318371014445, 0.8314568135903888], 35 -> 
             RGBColor[
              0.9712402540688452, 0.9146487652440536, 0.3427742471901105], 
             379 -> RGBColor[
              0.978889979203536, 0.9837767615712596, 0.920617938219919], 31 -> 
             RGBColor[
              0.9846071637473853, 0.9879026808787655, 0.9047626622964865], 18 -> 
             RGBColor[
              0.6845644967870121, 0.75350625486367, 0.9691946494869375], 24 -> 
             RGBColor[
              0.950342567771396, 0.8408318591115987, 0.2789026683003648], 151 -> 
             RGBColor[
              0.9929335697939597, 0.987293945251996, 0.4722408649037633], 137 -> 
             RGBColor[
              0.8895200256686676, 0.5912180644625434, 0.22952514011700725`], 
             330 -> RGBColor[
              0.9817371981198117, 0.9500574223276341, 0.38355289264656234`], 
             296 -> RGBColor[
              0.7944126554897866, 0.8393204713192048, 0.9801432873570228], 
             266 -> RGBColor[
              0.8378144102899445, 0.8735144851716078, 0.98439268045085], 302 -> 
             RGBColor[
              0.9916474951784339, 0.990814038853769, 0.7880861506903181], 442 -> 
             RGBColor[
              0.9604538157136263, 0.8782635758957348, 0.30087097102805044`], 
             283 -> RGBColor[
              0.994299450442836, 0.9902154258482249, 0.6209085442956781], 388 -> 
             RGBColor[
              0.9945623613680514, 0.9907777657328888, 0.6495247760072306], 
             284 -> RGBColor[
              0.9926333953406552, 0.9866519024486703, 0.43956872812355646`], 
             417 -> RGBColor[
              0.9459068930273399, 0.8232458868524015, 0.2753336202826292], 
             318 -> RGBColor[
              0.6844641822061658, 0.7534278883506937, 0.9691846510670117], 
             413 -> RGBColor[
              0.4689130601249929, 0.5797237723589216, 0.9513337002596269], 
             238 -> RGBColor[
              0.9541800628559253, 0.8560462483523263, 0.2819904069229638], 72 -> 
             RGBColor[
              0.9938796820332528, 0.9893175836652229, 0.5752193434228853], 
             437 -> RGBColor[
              0.9055609005996667, 0.9275336976150892, 0.9908544011745972], 
             288 -> 
             RGBColor[
              0.9748834282361416, 0.9807886824199018, 0.9273999839318681], 
             382 -> RGBColor[
              0.9923779373869958, 0.9911160954785178, 0.7759808329706093], 
             461 -> RGBColor[
              0.9951342308630299, 0.9920009367577726, 0.7117692413662107], 
             389 -> RGBColor[
              0.9913049193719978, 0.9823315927190396, 0.4207216829987536], 
             172 -> RGBColor[
              0.9847601484808517, 0.9879659439975822, 0.9022273093511506], 
             447 -> RGBColor[
              0.26881554115388295`, 0.3998725560154139, 0.9386200194405339], 
             243 -> RGBColor[
              0.96875547021137, 0.9062670058377953, 0.33312133111587783`], 
             410 -> RGBColor[
              0.9506399290628401, 0.9627079204315402, 0.9684379043150084], 88 -> 
             RGBColor[
              0.9950029276829506, 0.9917200925323707, 0.6974777005238729], 
             273 -> RGBColor[
              0.9935268401748779, 0.9885628906079433, 0.5368146846263252], 
             477 -> RGBColor[
              0.8523023645429272, 0.8850667866278944, 0.985774554461049], 202 -> 
             RGBColor[
              0.9948351985099385, 0.9913613367913187, 0.6792214151459787], 
             393 -> RGBColor[
              0.957593477476069, 0.8686149833810978, 0.28975909710469266`], 
             98 -> RGBColor[
              0.9407816264223154, 0.8029259126573305, 0.2712097104667571], 30 -> 
             RGBColor[
              0.9891659956431693, 0.9897878750243079, 0.8292110199045908], 
             116 -> RGBColor[
              0.5554127176802968, 0.649948091127483, 0.9581432701610665], 373 -> 
             RGBColor[
              0.9902404434151026, 0.9787408653655918, 0.4165863949156331], 
             434 -> RGBColor[
              0.9263695172953702, 0.7457867025196606, 0.25961338916753657`], 
             401 -> RGBColor[
              0.9843352518235933, 0.9588212675225083, 0.3936458406844794], 
             240 -> RGBColor[
              0.9938393329247301, 0.9892312810020136, 0.5708275919660262], 
             480 -> RGBColor[
              0.9068072037774798, 0.6682286481757681, 0.243873092524527], 403 -> 
             RGBColor[
              0.9916866081308287, 0.9908302130647413, 0.7874379478480613], 
             317 -> RGBColor[
              0.7268780284424557, 0.786561907387654, 0.9734120668799169], 429 -> 
             RGBColor[
              0.9898977892264091, 0.9900904904772149, 0.8170833064092208], 
             391 -> RGBColor[
              0.8232573131985991, 0.861907051092843, 0.9830042115350036], 73 -> 
             RGBColor[
              0.9464161758482188, 0.825265023528747, 0.27574340119471263`], 
             303 -> RGBColor[
              0.8775845276687803, 0.537021755651436, 0.2195658680200736], 449 -> 
             RGBColor[
              0.7570949209526647, 0.8101675734735181, 0.9764238043324193], 29 -> 
             RGBColor[
              0.9414166080286024, 0.8054434031311815, 0.27172063157210957`], 
             360 -> RGBColor[
              0.9930574820939376, 0.9875589811321932, 0.48572795405827834`], 
             320 -> RGBColor[
              0.9849842126084705, 0.988058600272538, 0.8985139868971337], 482 -> 
             RGBColor[
              0.9849035760712954, 0.9607383586588869, 0.39585367306777375`], 
             75 -> RGBColor[
              0.944635307894954, 0.8182044755331176, 0.2743104730371722], 200 -> 
             RGBColor[
              0.9493031033182059, 0.8367107289356951, 0.2780662908019614], 
             301 -> RGBColor[
              0.9077751520026275, 0.929299281579557, 0.9910655984500972], 156 -> 
             RGBColor[
              0.9931025554365466, 0.9876553884544198, 0.4906339092408367], 25 -> 
             RGBColor[
              0.9321503184163853, 0.9487353776316212, 0.9933905235826094], 38 -> 
             RGBColor[
              0.9936574143428533, 0.988842175550169, 0.5510268770000745], 365 -> 
             RGBColor[
              0.9756274346046538, 0.9813435611513397, 0.9261405752179155], 
             380 -> RGBColor[
              0.9949432268889462, 0.9915923985706716, 0.6909796375270891], 
             370 -> RGBColor[
              0.9162693744792052, 0.70574300192664, 0.2514865771768276], 3 -> 
             RGBColor[
              0.9897249849211437, 0.9900190314561195, 0.8199471209506751], 57 -> 
             RGBColor[
              0.8537274895077558, 0.8862031425908621, 0.9859104841524184], 
             227 -> RGBColor[
              0.958880186901216, 0.968853491235217, 0.9544892971980858], 494 -> 
             RGBColor[
              0.9943936517386729, 0.9919496451644323, 0.7425752296617957], 39 -> 
             RGBColor[
              0.9932018291146577, 0.9878677248137911, 0.5014392364571132], 
             424 -> RGBColor[
              0.9794819431686124, 0.9424499178181945, 0.37479165303031464`], 
             109 -> RGBColor[
              0.9313103214783182, 0.7653753446796563, 0.2635888761887163], 
             465 -> RGBColor[
              0.9776077155502937, 0.9361277079720332, 0.36751063265133355`], 
             256 -> 
             RGBColor[
              0.9362541573149386, 0.7849760063362248, 0.26756680254960297`], 
             457 -> RGBColor[
              0.9343169243727816, 0.777295523265182, 0.26600805945164196`], 
             339 -> RGBColor[
              0.9534115552814075, 0.8529993719093318, 0.2813720476893156], 
             420 -> RGBColor[
              0.9940302906202675, 0.9896397202039835, 0.5916121586709812], 
             287 -> RGBColor[
              0.9729429827826966, 0.9203924690155889, 0.3493890267100867], 
             239 -> RGBColor[
              0.9849325835113094, 0.9880372503140545, 0.8993696146489125], 
             427 -> RGBColor[
              0.925697583473539, 0.7431227088247726, 0.2590727354421773], 285 -> 
             RGBColor[
              0.9757722789019458, 0.9299363491761369, 0.3603803078656298], 
             345 -> RGBColor[
              0.9941149824929478, 0.991834408269852, 0.7471935002363499], 366 -> 
             RGBColor[
              0.8612690101910601, 0.8922165464746034, 0.986629801127587], 216 -> 
             RGBColor[
              0.6479441051504812, 0.7248981265919272, 0.9655446710856248], 21 -> 
             RGBColor[
              0.9943190219409181, 0.9919187838251624, 0.7438120385463172], 
             355 -> RGBColor[
              0.7268780284424557, 0.786561907387654, 0.9734120668799169], 175 -> 
             RGBColor[
              0.8838362948408303, 0.910211086681707, 0.9887822888835349], 7 -> 
             RGBColor[
              0.7340149706734385, 0.7921373409012676, 0.9741234105829841], 13 -> 
             RGBColor[
              0.8937857575800151, 0.6105877567849725, 0.23308457138649294`], 
             294 -> RGBColor[
              0.988549433096601, 0.9895329105663673, 0.8394290569139491], 412 -> 
             RGBColor[
              0.9584153433705985, 0.968506811691194, 0.9552761560448114], 193 -> 
             RGBColor[
              0.8500307693411151, 0.8832554782747786, 0.9855578876828232], 60 -> 
             RGBColor[
              0.7268780284424557, 0.786561907387654, 0.9734120668799169], 65 -> 
             RGBColor[
              0.9927182799665696, 0.9912568358815769, 0.7703404756487089], 
             448 -> RGBColor[
              0.963605714029556, 0.9723777816301924, 0.9464902123846713], 69 -> 
             RGBColor[
              0.9923569996986223, 0.9911074372063013, 0.7763278246519563], 
             217 -> RGBColor[
              0.9506911851980016, 0.9627461471732193, 0.9683511410479212], 
             214 -> RGBColor[
              0.9944884278580229, 0.9906196294307623, 0.6414775697053667], 
             170 -> RGBColor[
              0.9922920766338988, 0.9910805898505916, 0.7774037678499311], 
             359 -> RGBColor[0.178927, 0.305394, 0.933501], 74 -> 
             RGBColor[
              0.7960879121140089, 0.8406291945264692, 0.980310261281162], 246 -> 
             RGBColor[
              0.9943250414415744, 0.9902701624068795, 0.6236939665790201], 
             264 -> RGBColor[
              0.8872819741620896, 0.9129585778420056, 0.9891109408531908], 
             278 -> RGBColor[
              0.9820798519034855, 0.9512132739989001, 0.3848840378913974], 45 -> 
             RGBColor[
              0.9677696428286059, 0.9754832329107163, 0.9394417670544419], 
             492 -> RGBColor[
              0.8620579680308632, 0.46651927465579035`, 0.20661012606739243`],
              306 -> RGBColor[
              0.9714892141896289, 0.9154885661900731, 0.3437414102471812], 
             237 -> RGBColor[
              0.891521828272235, 0.6003077825524666, 0.23119549327809583`], 
             228 -> RGBColor[
              0.968801868875665, 0.906423519427387, 0.33330158116501163`], 
             180 -> RGBColor[
              0.9886384646362497, 0.9895697273960181, 0.8379535738957321], 
             383 -> RGBColor[
              0.9950296399084713, 0.9917772272817392, 0.7003851614230548], 53 -> 
             RGBColor[
              0.955374299637801, 0.9662388062545256, 0.9604238498532048], 304 -> 
             RGBColor[
              0.9068072037774798, 0.6682286481757681, 0.243873092524527], 48 -> 
             RGBColor[
              0.9864164052147566, 0.9886508487209084, 0.8747788490153189], 5 -> 
             RGBColor[
              0.9908457591818861, 0.9807827375818533, 0.4189379323652959], 
             101 -> RGBColor[
              0.9935070026215072, 0.9885204600871674, 0.5346554893650962], 
             333 -> RGBColor[
              0.9358931601098016, 0.7835447727130442, 0.2672763357246563], 
             267 -> RGBColor[
              0.9950974264968502, 0.9919222159400064, 0.7077633132377711], 
             120 -> RGBColor[
              0.9637976359022573, 0.97252091664861, 0.9461653387154291], 147 -> 
             RGBColor[
              0.9338370793733468, 0.9500803550327958, 0.9935514083484737], 89 -> 
             RGBColor[
              0.9947441445862711, 0.9911665816555579, 0.6693107574744576], 43 -> 
             RGBColor[
              0.8933693242931432, 0.6086968304897522, 0.23273708924421305`], 
             199 -> 
             RGBColor[
              0.6519871883115749, 0.7280566138859438, 0.9659476478303624], 
             268 -> RGBColor[
              0.9933479415117518, 0.9881802444569457, 0.5173426691796064], 
             169 -> RGBColor[
              0.9420521974105385, 0.8079633032329522, 0.2722320417080156], 20 -> 
             RGBColor[
              0.9302491203317536, 0.9472194138855831, 0.9932091856120776], 4 -> 
             RGBColor[
              0.9909428241597575, 0.9811101605441541, 0.41931501147514333`], 
             167 -> RGBColor[
              0.9358931601098016, 0.7835447727130442, 0.2672763357246563], 
             431 -> RGBColor[
              0.9943579383333864, 0.9903405255320793, 0.6272745902366673], 
             142 -> RGBColor[
              0.9107404276697004, 0.6838225702392586, 0.2470378567928385], 16 -> 
             RGBColor[
              0.3782452313457785, 0.5020387410587784, 0.9453224295655958], 
             414 -> RGBColor[
              0.9940333852745115, 0.9918006657230757, 0.7485457773126719], 
             281 -> RGBColor[
              0.9809175037675578, 0.9852888860713402, 0.9171858679961281], 
             289 -> RGBColor[
              0.9782983703441341, 0.9384574487651146, 0.37019369610619013`], 
             398 -> RGBColor[
              0.9169783312655625, 0.7085537793387028, 0.2520570204484853], 
             178 -> RGBColor[
              0.9911547508751576, 0.9906102764214133, 0.7962521989769864], 58 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 186 -> 
             RGBColor[
              0.9930388997409973, 0.9875192353582182, 0.4837053796177239], 
             122 -> RGBColor[
              0.9727161783150146, 0.9196274042898758, 0.34850793418157167`], 
             249 -> RGBColor[
              0.9538976338108968, 0.9651375112986388, 0.9629234599220243], 
             113 -> RGBColor[
              0.9860335136030577, 0.9884925131996053, 0.8811243539128963], 52 -> 
             RGBColor[
              0.9946235040344277, 0.9909085437137956, 0.6561797779134829], 
             409 -> RGBColor[
              0.9262320126990878, 0.7452415426160914, 0.25950274974172005`], 
             187 -> RGBColor[
              0.946063531781599, 0.9592948508323533, 0.9761845511965781], 259 -> 
             RGBColor[
              0.9888166697174864, 0.9739381423655701, 0.41105530295749587`], 
             42 -> RGBColor[
              0.9870984119351388, 0.9681420553995989, 0.4043801959388311], 
             134 -> RGBColor[
              0.9951356500713936, 0.9920039723009585, 0.7119237134382589], 
             470 -> 
             RGBColor[
              0.9534115552814075, 0.8529993719093318, 0.2813720476893156], 
             313 -> RGBColor[
              0.982229546287517, 0.9517182283061514, 0.38546557230594763`], 
             248 -> RGBColor[
              0.6478341944190893, 0.7248122634932114, 0.9655337162110939], 
             174 -> RGBColor[
              0.921002724663455, 0.939846588966406, 0.9923272561388804], 215 -> 
             RGBColor[
              0.6262162141993853, 0.7074295592628481, 0.9637171807688028], 
             399 -> RGBColor[
              0.9682737932892885, 0.9046421964764947, 0.33125010723064546`], 
             422 -> RGBColor[
              0.9901808726571018, 0.9785399192109755, 0.4163549737697932], 83 -> 
             RGBColor[
              0.9291215420050808, 0.9463203135351925, 0.9931016361846785], 95 -> 
             RGBColor[
              0.9946692637029938, 0.9910064190178464, 0.6611604354409659], 
             166 -> RGBColor[
              0.8892966184827042, 0.9145650005372005, 0.9893030994269854], 
             384 -> RGBColor[
              0.9550904611682056, 0.9660271199886443, 0.9609043143453008], 
             233 -> RGBColor[
              0.9865940507468588, 0.9664407266818915, 0.40242084796298155`], 
             295 -> RGBColor[
              0.9440046136673089, 0.9577593130738848, 0.9796697625122239], 
             499 -> RGBColor[
              0.8905690537152924, 0.915579605852332, 0.9894244654353859], 141 -> 
             RGBColor[
              0.9008898379869488, 0.6428457267127249, 0.2390123902149838], 
             319 -> RGBColor[
              0.9686937475644536, 0.9761724287096288, 0.9378774987817676], 
             205 -> RGBColor[
              0.6519871883115749, 0.7280566138859438, 0.9659476478303624], 
             468 -> RGBColor[0.178927, 0.305394, 0.933501], 486 -> 
             RGBColor[
              0.9920080509846853, 0.9909631379455155, 0.7821108078922175], 
             224 -> RGBColor[
              0.8892591013965861, 0.9145350854311041, 0.9892995210138195], 
             231 -> RGBColor[
              0.9621707841401991, 0.9713076132681921, 0.948919174397699], 332 -> 
             RGBColor[
              0.9043153841855012, 0.9265405566350761, 0.9907356027071285], 68 -> 
             RGBColor[
              0.616508735769635, 0.6995485909566572, 0.9629529725071476], 484 -> 
             RGBColor[
              0.9592004039540571, 0.8740355237156314, 0.29600170302907397`], 
             10 -> RGBColor[
              0.9408772715893711, 0.9554269464727114, 0.9849635369087267], 
             250 -> 
             RGBColor[
              0.9608054898606109, 0.9702893790299395, 0.9512302614872639], 
             282 -> RGBColor[
              0.9925451329577042, 0.9864631181362338, 0.4299619124316255], 
             374 -> RGBColor[
              0.8701137677784173, 0.5030987798296008, 0.2133320828424728], 
             232 -> RGBColor[
              0.9934674192371222, 0.9915666242219515, 0.7579252992253651], 
             489 -> RGBColor[
              0.9930928183426351, 0.9876345617951144, 0.4895740866589542], 
             253 -> RGBColor[
              0.9908258310907986, 0.9807155154512766, 0.4188605154945249], 
             459 -> RGBColor[
              0.936168017110803, 0.7846344891313487, 0.26749749211938506`], 
             415 -> RGBColor[
              0.9861101024109237, 0.9885241846399004, 0.8798550791610755], 55 -> 
             RGBColor[
              0.9877831516442132, 0.9892160334932698, 0.8521283236528453], 
             446 -> RGBColor[
              0.8755647136251812, 0.9036155523464393, 0.9879933380830586], 
             325 -> RGBColor[
              0.9950557791548401, 0.991833136486639, 0.7032302570775699], 91 -> 
             RGBColor[
              0.791960566156752, 0.8374048804956691, 0.9798988860083836], 450 -> 
             RGBColor[
              0.9194052945878907, 0.9385728415852352, 0.9921748918322305], 
             423 -> RGBColor[
              0.9874982447542066, 0.9890982171724789, 0.8568499681356511], 
             105 -> RGBColor[
              0.9597191798514574, 0.9694792108037822, 0.9530691009777342], 36 -> 
             RGBColor[
              0.9634215920812259, 0.888274582450677, 0.31240022179863414`], 
             123 -> RGBColor[
              0.958125079121871, 0.8704082005583897, 0.2918242691140858], 94 -> 
             RGBColor[
              0.9025238967092226, 0.6502656057264592, 0.24037588886729355`], 
             473 -> RGBColor[
              0.937431126476638, 0.7896422968606399, 0.2685138195641233], 312 -> 
             RGBColor[
              0.9918430599404076, 0.9908949099086302, 0.7848451364790352], 96 -> 
             RGBColor[
              0.9926268377535161, 0.9866378764328535, 0.4388549752322001], 
             496 -> RGBColor[
              0.7934785262200592, 0.8385907224340483, 0.9800501820813508], 2 -> 
             RGBColor[
              0.962625079060945, 0.9716464256762447, 0.9481501715959678], 262 -> 
             RGBColor[
              0.9950974264968502, 0.9919222159400064, 0.7077633132377711], 
             272 -> RGBColor[
              0.8809419682690243, 0.5522671092669695, 0.2223673987553172], 97 -> 
             RGBColor[
              0.8369981875151284, 0.8728636512867465, 0.9843148283939375], 
             372 -> RGBColor[
              0.9525952789833002, 0.9641662172006277, 0.9651280069366056], 
             356 -> RGBColor[
              0.7883478212060807, 0.834582576682326, 0.9795388013547217], 402 -> 
             RGBColor[
              0.8455685266506958, 0.8796974070777893, 0.9851322749915199], 
             455 -> RGBColor[
              0.9353091852024623, 0.9512541722616843, 0.9936918191166191], 
             428 -> RGBColor[
              0.9692640576008189, 0.9765977650009532, 0.9369121126508809], 
             346 -> RGBColor[
              0.9783890181826642, 0.9834031456621417, 0.9214659345566951], 
             341 -> RGBColor[
              0.9593287345271351, 0.9691880173201982, 0.9537300230673619], 
             209 -> RGBColor[
              0.9745925504344124, 0.9259568480417296, 0.35579728554228984`], 
             498 -> RGBColor[
              0.9727912640922246, 0.9198806862473842, 0.3487996282472734], 
             378 -> RGBColor[
              0.992257980762897, 0.9855464925799985, 0.42442414653185484`], 
             419 -> RGBColor[
              0.9951326626769927, 0.9919975825664068, 0.711598553993782], 66 -> 
             RGBColor[
              0.9839423362943176, 0.9574958711813081, 0.39211943804911525`], 
             139 -> RGBColor[
              0.9197118754230731, 0.7193913710236404, 0.2542564942421464], 56 -> 
             RGBColor[
              0.9866938354720752, 0.988765573261942, 0.8701811116850582], 335 -> 
             RGBColor[
              0.9087604938769451, 0.9300849664437453, 0.9911595812376947], 
             314 -> RGBColor[
              0.993801498875829, 0.9891503577970233, 0.5667095892278311], 144 -> 
             RGBColor[
              0.9952371025710501, 0.9922209689393026, 0.7229661919336189], 
             298 -> RGBColor[
              0.9922594161614613, 0.9910670839059028, 0.7779450364008138], 
             204 -> RGBColor[
              0.9941870464965482, 0.9899750051728976, 0.6086740684190005], 
             452 -> RGBColor[
              0.9933821199015013, 0.9915313507545793, 0.7593389299642089], 
             466 -> RGBColor[
              0.9904545501303952, 0.9903207254191156, 0.8078563373791409], 
             207 -> RGBColor[
              0.8337332964158648, 0.8702603157473016, 0.984003420166287], 334 -> 
             RGBColor[
              0.9808930762288146, 0.9472100009800555, 0.380273638499082], 149 -> R\
GBColor[0.9828800018801067, 0.9867525139503834, 0.9138638705930661], 219 -> 
             RGBColor[
              0.9919681833116432, 0.9909466516381601, 0.7827715184087559], 
             400 -> RGBColor[
              0.9938551791264212, 0.9892651744251341, 0.5725523532286797], 9 -> 
             RGBColor[
              0.9864231802939946, 0.9886536503902849, 0.8746665684190028], 11 -> 
             RGBColor[
              0.9397808577033554, 0.9546092427917339, 0.9868194796272114], 44 -> 
             RGBColor[
              0.9136891869161964, 0.695513418035846, 0.24941049769884457`], 
             153 -> RGBColor[
              0.8615646824931331, 0.8924523075424656, 0.9866580026157085], 
             471 -> RGBColor[
              0.9939219446469559, 0.9894079791225282, 0.5798193681098507], 
             406 -> RGBColor[
              0.9922692682874446, 0.9910711580131849, 0.7777817611767874], 32 -> 
             RGBColor[
              0.9077421660582328, 0.9292729794828762, 0.991062452221274], 162 -> 
             RGBColor[
              0.9774522137125331, 0.9356031637596989, 0.36690653737569173`], 
             493 -> RGBColor[
              0.9950610343679408, 0.9918443768560777, 0.7038022545921628], 90 -> 
             RGBColor[
              0.9836194385842728, 0.9564066613853394, 0.3908650414197074], 
             331 -> RGBColor[
              0.9929089619159975, 0.9872413114892729, 0.4695624492497953], 8 -> 
             RGBColor[
              0.9422241198448946, 0.9564314236964193, 0.9826836741264096], 
             364 -> RGBColor[
              0.9875420436766597, 0.9891163291524943, 0.8561241066426261], 
             342 -> RGBColor[
              0.7268780284424557, 0.786561907387654, 0.9734120668799169], 163 -> 
             RGBColor[
              0.8898538063293907, 0.915009287001687, 0.9893562445012097], 49 -> 
             RGBColor[
              0.7268780284424557, 0.786561907387654, 0.9734120668799169], 338 -> 
             RGBColor[
              0.9624932325478874, 0.8851430077555419, 0.30879372031760155`], 
             76 -> RGBColor[
              0.9496183604823378, 0.8379606185382559, 0.2783199541162587], 
             369 -> RGBColor[
              0.9774385014553887, 0.9826942518432679, 0.9230749114415062], 
             445 -> RGBColor[
              0.9941860948144982, 0.9899729696212225, 0.6085704837009602], 82 -> 
             RGBColor[
              0.34344549945364256`, 0.47189696237919215`, 0.9431050214216236],
              67 -> RGBColor[
              0.9947227554099102, 0.9911208323700993, 0.6669826776262632], 
             430 -> 
             RGBColor[
              0.994324066485335, 0.9902680770740667, 0.6235878486090961], 211 -> 
             RGBColor[
              0.9929592834279797, 0.9913564970063765, 
               0.7663464245961771]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw1l3k4VA/cxYfs69jHPjOGGTNjV1rUPZUi6hcVbZKtXVmyRook2RJlqUih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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 42}], {
             RGBColor[
             0.9900653580536234, 0.9778235917514384, 0.44368384429303287`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 108}], {
             RGBColor[
             0.9931215580992299, 0.9876960332284355, 0.49270223180307404`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[
             0.9895329088875828, 0.9879988206514416, 0.6820559232800655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 119}], {
             RGBColor[
             0.9659137055872038, 0.9706895998180916, 0.7357377955431872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 120}], {
             RGBColor[
             0.9784149700371826, 0.9800130223759439, 0.7145764156813319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 124}], {
             RGBColor[
             0.9757203488767091, 0.9294345074293776, 0.3879561924683981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 315}], {
             RGBColor[
             0.9937449467635517, 0.989029398547158, 0.5605542408056348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 363}], {
             RGBColor[
             0.9015581799543335, 0.9195341082011574, 0.7323463793616469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 364}], {
             RGBColor[
             0.9902871739243837, 0.988310728627886, 0.6695557996449304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 378}], {
             RGBColor[
             0.9926451424675025, 0.9865258103416381, 0.4537058195895447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 380}], {
             RGBColor[
             0.993987765530527, 0.9895487633369747, 0.5869835650871619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 381}], {
             RGBColor[
             0.9668734981060283, 0.9714054115071149, 0.7341131171627978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 416}], {
             RGBColor[
             0.993024161925345, 0.9874877126607596, 0.48210125933522535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 452}], {
             RGBColor[
             0.9932072120368045, 0.9895182394289286, 0.6211632113057217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 468}], {
             RGBColor[
             0.585979652086054, 0.6464495640516389, 0.7082442463236174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 487}], {
             RGBColor[
             0.931960030648797, 0.9436957011447311, 0.7352673692220919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[
             0.9732837076776313, 0.9645711484287764, 0.6701348048225415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 114}], {
             RGBColor[
             0.9664032048270457, 0.9744641456864895, 0.9417547901669752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 118}], {
             RGBColor[
             0.9734335942929898, 0.9796990736263014, 0.9294813635434241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 195}], {
             RGBColor[
             0.959926110262679, 0.9696335391656538, 0.952718821767631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 255}], {
             RGBColor[
             0.9774638580959951, 0.9813656912818993, 0.8626894623392449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 260}], {
             RGBColor[
             0.9569889185410827, 0.9674429863888973, 0.9576907212100032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 312}], {
             RGBColor[
             0.9772340695006763, 0.9812706677924374, 0.8664976540375016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 327}], {
             RGBColor[
             0.9603003842932996, 0.9699126721248731, 0.9520852734600914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 334}], {
             RGBColor[
             0.9717590776448798, 0.9594282133281501, 0.6642119050475249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 385}], {
             RGBColor[
             0.9739554089083702, 0.9799148573797851, 0.9208335449536353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 446}], {
             RGBColor[
             0.9190948963430631, 0.937630989011342, 0.9680717548395132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 496}], {
             RGBColor[
             0.8780518026405021, 0.9051185740551465, 0.9641001768386592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[
             0.9739250320215074, 0.9302136160072546, 0.5558856950323805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 139}], {
             RGBColor[
             0.9547184301721083, 0.8547052012398799, 0.5371018075964108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 158}], {
             RGBColor[
             0.9919276179051719, 0.9899362782839082, 0.7112196690058487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 247}], {
             RGBColor[
             0.9221727153190107, 0.9384670965447424, 0.9029713880317355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 278}], {
             RGBColor[
             0.9859024184123146, 0.9706161527275098, 0.6024155794210363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 401}], {
             RGBColor[
             0.9870301183723684, 0.9744201494893139, 0.6067964808175772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 428}], {
             RGBColor[
             0.9794945212609814, 0.9833083982285363, 0.878429616800778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 437}], {
             RGBColor[
             0.9476429427604052, 0.9587763645356043, 0.9054007610626362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 451}], {
             RGBColor[
             0.5843259924605718, 0.6477065157280597, 0.8767240604753376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 31}], {
             RGBColor[
             0.9877749939535714, 0.9845064207114598, 0.6620388368858149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 151}], {
             RGBColor[
             0.9919381969768586, 0.984202052898075, 0.4457779381894533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 162}], {
             RGBColor[
             0.9841975189361454, 0.9583566621519265, 0.39311077442541753`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 191}], {
             RGBColor[
             0.967819128938453, 0.9696923430400477, 0.6989076979188569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.9314846706594351, 0.7464471442887625, 0.317121569643323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 345}], {
             RGBColor[
             0.9925289033263527, 0.9864722844070031, 0.5832542558557466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 366}], {
             RGBColor[
             0.9261059171754088, 0.9366633535093787, 0.7029724063013651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 389}], {
             RGBColor[
             0.9911238717658777, 0.9817208766315968, 0.4200183472369485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 405}], {
             RGBColor[
             0.9884852748178055, 0.9848001401022062, 0.6502676448175031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 429}], {
             RGBColor[
             0.9904203066930833, 0.9856003255106844, 0.618199158942182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 472}], {
             RGBColor[
             0.9885818468859728, 0.9848400751341824, 0.6486671957274691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 488}], {
             RGBColor[
             0.6671941618067001, 0.7265035614616732, 0.6812100164483834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 69}], {
             RGBColor[
             0.9916013794402543, 0.9859450873940774, 0.5976328785086261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[
             0.9599836505934835, 0.963551525558523, 0.7060197842749871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 97}], {
             RGBColor[
             0.9139219733485073, 0.9268231944343, 0.7016263803796168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 103}], {
             RGBColor[
             0.9760782139130224, 0.9757244390607043, 0.6846565289718709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 129}], {
             RGBColor[
             0.8448992380138027, 0.872764589654954, 0.694783332581062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 163}], {
             RGBColor[
             0.9403497827556384, 0.9478960122917701, 0.7041470884332528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 204}], {
             RGBColor[
             0.9925164028392172, 0.9853788713773755, 0.5138060003921482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 209}], {
             RGBColor[
             0.9827191548081493, 0.9533697928117915, 0.38736760895379285`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 231}], {
             RGBColor[
             0.9765082716610426, 0.9760451754250228, 0.6839285533814974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 233}], {
             RGBColor[
             0.9887199049643725, 0.9736117321318725, 0.41067939016413874`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 259}], {
             RGBColor[
             0.9898312144496862, 0.9773604399737117, 0.4149966176613959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 275}], {
             RGBColor[
             0.9718533167009805, 0.9157994212932934, 0.3499334445732587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 326}], {
             RGBColor[
             0.9921470950274516, 0.9845889593107562, 0.4736091241850816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 346}], {
             RGBColor[
             0.9846173886822751, 0.9820929416219975, 0.6702019334609954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 348}], {
             RGBColor[
             0.9888729924758328, 0.9848168292679425, 0.6428493113482127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 355}], {
             RGBColor[
             0.8588618938121709, 0.8836723224847536, 0.6961749996226063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 395}], {
             RGBColor[
             0.7805541017405597, 0.8213932528755747, 0.689125113701073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 404}], {
             RGBColor[
             0.9744426350642931, 0.9254511482965144, 0.35521489263851846`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 431}], {
             RGBColor[
             0.9926018487576362, 0.9855616315569663, 0.5231062613009816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 444}], {
             RGBColor[
             0.9118306355535342, 0.9251556184444405, 0.7014269067137728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 486}], {
             RGBColor[
             0.9914269050832857, 0.9858729377636843, 0.6005243701287567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 35}], {
             RGBColor[
             0.9746129063478057, 0.9260255133174013, 0.3558763644219316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 101}], {
             RGBColor[
             0.9857462806241368, 0.9629613607389583, 0.4518169855094244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 123}], {
             RGBColor[
             0.9680553188743186, 0.9039052309745694, 0.3304013753839192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 158}], {
             RGBColor[
             0.9860579047579833, 0.963627893251223, 0.4857353493573874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 181}], {
             RGBColor[
             0.9783245416645461, 0.9605050667828956, 0.6449898741377138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 189}], {
             RGBColor[
             0.9796499590632873, 0.9614935609087051, 0.6427462882058663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 302}], {
             RGBColor[
             0.9848165269026001, 0.964108150122259, 0.5785323161720354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 306}], {
             RGBColor[
             0.9747373864081976, 0.9264454137904112, 0.35635994595046694`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 347}], {
             RGBColor[
             0.8406269433994273, 0.852760045743412, 0.6700186771279562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 370}], {
             RGBColor[
             0.9471274665529859, 0.8215726316586947, 0.3102325294152901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 390}], {
             RGBColor[
             0.9839560419499165, 0.9637523174808698, 0.592792778701678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 422}], {
             RGBColor[
             0.9840832156419341, 0.9579710903008624, 0.3926667277117729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 428}], {
             RGBColor[
             0.9736248081137926, 0.9570000131958512, 0.6529452971523169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 451}], {
             RGBColor[
             0.5784562793133832, 0.6213981306953746, 0.6512397408268764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 17}], {
             RGBColor[
             0.8616989516193587, 0.8910074624589462, 0.8998696121367298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.8642846750856369, 0.8920767255623143, 0.8570174826626756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.8370604584918049, 0.796192203535498, 0.6223947264856297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.8574790093313358, 0.8697579541815714, 0.6772955899674589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 89}], {
             RGBColor[
             0.8643795576298547, 0.8916519612784128, 0.8217170840287209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 176}], {
             RGBColor[
             0.864371086854097, 0.8921124590492537, 0.8555854160328026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 178}], {
             RGBColor[
             0.8625848607742981, 0.8913738086613405, 0.8851878047799853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 244}], {
             RGBColor[
             0.8585410932240711, 0.8895147393338534, 0.9438351884428506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 261}], {
             RGBColor[
             0.8516430739181657, 0.8843702078299791, 0.9555117358361764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 262}], {
             RGBColor[
             0.8645561985851443, 0.892029778420637, 0.8409433619103777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 288}], {
             RGBColor[
             0.85444919945479, 0.8864630116605847, 0.9507616972574261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 295}], {
             RGBColor[
             0.8390097921703736, 0.8749483269875762, 0.976896586547604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 313}], {
             RGBColor[
             0.8581222584804777, 0.8719277846037095, 0.6797944914444659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 321}], {
             RGBColor[
             0.8630456298501739, 0.8915643485154403, 0.8775516687605784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 341}], {
             RGBColor[
             0.8466718526002868, 0.8806626791107329, 0.9639267168251731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 376}], {
             RGBColor[
             0.8492497342082879, 0.8419986768658447, 0.6453264100826261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 391}], {
             RGBColor[
             0.7786361419360188, 0.8270221959970554, 0.9785638110589938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 407}], {
             RGBColor[
             0.862339341502468, 0.8912722801328813, 0.889256694497716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 448}], {
             RGBColor[
             0.8488103423514972, 0.88225756126573, 0.9603068114838278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 455}], {
             RGBColor[
             0.8346620779379503, 0.871695756581476, 0.9839076148498016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 475}], {
             RGBColor[
             0.8471183015051658, 0.8348088538740158, 0.6370461965182888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 478}], {
             RGBColor[
             0.86139709133813, 0.8908826354752029, 0.9048722181860557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 482}], {
             RGBColor[
             0.8594592733723669, 0.8764378497800773, 0.6849885418253789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 63}], {
             RGBColor[
             0.9685680955096592, 0.9739785916720265, 0.8351361021992447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 85}], {
             RGBColor[
             0.9342790299523627, 0.8510385371662885, 0.621134218507563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 146}], {
             RGBColor[
             0.8952378516908602, 0.6641599077524991, 0.5882613755273152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 159}], {
             RGBColor[
             0.815820484322715, 0.8568641864161475, 0.9761809803571236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 166}], {
             RGBColor[
             0.9157603691637994, 0.9354982121168098, 0.9859933867766975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 239}], {
             RGBColor[
             0.963578351678102, 0.9722343370052369, 0.941026644387661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 344}], {
             RGBColor[
             0.9684074616051935, 0.9736350119929537, 0.817652093015715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 387}], {
             RGBColor[
             0.9342280662719913, 0.8508364831562554, 0.6210932119340649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 435}], {
             RGBColor[
             0.968695310482631, 0.9742506916358067, 0.8489826669274352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 439}], {
             RGBColor[
             0.967798872702897, 0.9723333018687182, 0.7514109467760861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 453}], {
             RGBColor[
             0.9099956238689325, 0.7471411621592683, 0.6012009541247443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 68}], {
             RGBColor[
             0.8014659580318149, 0.844101120673471, 0.9188097704630752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 95}], {
             RGBColor[
             0.9905462219984942, 0.9898300347040656, 0.7679135019299843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 286}], {
             RGBColor[
             0.9778228575701141, 0.9482480874567334, 0.6048011787217853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 319}], {
             RGBColor[
             0.9775584639292241, 0.9824130395499568, 0.9062720336003852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 330}], {
             RGBColor[
             0.9840801892069031, 0.9693555363589594, 0.6291097305327826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 333}], {
             RGBColor[
             0.9611581702018981, 0.8860992115516646, 0.5709714520718295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 352}], {
             RGBColor[
             0.989927055105418, 0.9885056993271514, 0.7005210066737799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 357}], {
             RGBColor[
             0.9896175004738688, 0.9878435932710419, 0.6668278953793915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 358}], {
             RGBColor[
             0.9876453733122699, 0.9891590586122696, 0.8544116671720399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 367}], {
             RGBColor[
             0.9901299734011018, 0.9889397210434323, 0.7226074108924023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 368}], {
             RGBColor[
             0.9881406289501852, 0.9893638595460369, 0.8462039995712778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 375}], {
             RGBColor[
             0.9708030190209298, 0.9773748397983768, 0.9177072397279137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 441}], {
             RGBColor[
             0.9905887098859563, 0.9899209119991628, 0.772538046275393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 450}], {
             RGBColor[
             0.9529142374409426, 0.96361324598776, 0.9334207301256167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 492}], {
             RGBColor[
             0.9242405741624289, 0.7275864625230376, 0.5406383472431976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 102}], {
             RGBColor[
             0.9673392721603814, 0.972288410284825, 0.775824255855077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 168}], {
             RGBColor[
             0.963778595188044, 0.9720933824138077, 0.927687642042698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 181}], {
             RGBColor[
             0.9597703981458485, 0.9695174093238768, 0.9529824017652008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.9610958155445897, 0.9705059034496861, 0.9507388158333534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 232}], {
             RGBColor[
             0.9671723454132466, 0.9734967853473315, 0.871444418067046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 280}], {
             RGBColor[
             0.9642137113538293, 0.9625464121052374, 0.6955493271351518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 302}], {
             RGBColor[
             0.9662623833839025, 0.9731204926632402, 0.8865248437995223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 370}], {
             RGBColor[
             0.9285733230342881, 0.8305849741996757, 0.6182250570427772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 383}], {
             RGBColor[
             0.9679534557489211, 0.9736020868772253, 0.8426743491658908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 390}], {
             RGBColor[
             0.9654018984312187, 0.9727646600218509, 0.9007853063291651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 443}], {
             RGBColor[
             0.9486465925264748, 0.9100348649672498, 0.635074010094599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 451}], {
             RGBColor[
             0.5599021357946855, 0.6304104732363557, 0.9592322684543634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 480}], {
             RGBColor[
             0.9238422376834254, 0.8118277973242398, 0.6144183147166269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 25}], {
             RGBColor[
             0.9359655880598703, 0.9516723102116775, 0.9901050016049104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 164}], {
             RGBColor[
             0.9085466341552015, 0.9298091806357713, 0.987489757304294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 180}], {
             RGBColor[
             0.9642096611698026, 0.9720894850938759, 0.9123865267614717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 205}], {
             RGBColor[
             0.7958840230074651, 0.8413329283388389, 0.9763835637287869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 259}], {
             RGBColor[
             0.9642987637104209, 0.9642736925786519, 0.6989373912923537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 316}], {
             RGBColor[
             0.5593539288516777, 0.6300016213958669, 0.9601602398136058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 331}], {
             RGBColor[
             0.9663449098096765, 0.9709252771405034, 0.7281909644385034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 348}], {
             RGBColor[
             0.9633405417365675, 0.9717300818728827, 0.9267900849791704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 372}], {
             RGBColor[
             0.9461880683433278, 0.9593877299961808, 0.9759737432819084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 404}], {
             RGBColor[
             0.9489101843250277, 0.9123644009014547, 0.6391556662694762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 418}], {
             RGBColor[
             0.962429205292586, 0.9579672330421033, 0.691674509875548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 431}], {
             RGBColor[
             0.9670693980183709, 0.9724748841619066, 0.8070470349319394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 444}], {
             RGBColor[
             0.8862981848142688, 0.9120688710493807, 0.9853676803447307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 40}], {
             RGBColor[
             0.946751992111051, 0.9314318905919281, 0.6730268107117627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 161}], {
             RGBColor[
             0.9663858043398335, 0.946494925403191, 0.6543594386025344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 188}], {
             RGBColor[
             0.9835697608090508, 0.9559071539145039, 0.41889721096174926`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 202}], {
             RGBColor[
             0.9844669440720749, 0.9578261381949699, 0.5165500723686369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 243}], {
             RGBColor[
             0.9714270799227906, 0.9152789727182082, 0.34350003035358645`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 273}], {
             RGBColor[
             0.9838127649045446, 0.9564269151032823, 0.4453467071088102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 279}], {
             RGBColor[
             0.9203622859934222, 0.9103894552632208, 0.6705097369838946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 283}], {
             RGBColor[
             0.9841990700385237, 0.957253182723423, 0.4873936369434866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 285}], {
             RGBColor[
             0.9749354842680786, 0.927113644387379, 0.35712951872846244`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 318}], {
             RGBColor[
             0.8292814359201885, 0.8388594139746575, 0.6615316903291535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 335}], {
             RGBColor[
             0.9414295917555782, 0.9271879530211832, 0.6725191554144949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 396}], {
             RGBColor[
             0.904634269066876, 0.8978483614916393, 0.6690095846888742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 421}], {
             RGBColor[
             0.9736103967108278, 0.9226438129114177, 0.3519818037903313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 430}], {
             RGBColor[
             0.9842113780597732, 0.9572795083363439, 0.48873328910019564`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 459}], {
             RGBColor[
             0.9551333533725072, 0.8544627143649849, 0.3106881108553401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 477}], {
             RGBColor[
             0.9132005270885692, 0.9046788631132577, 0.669826642026172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 21}], {
             RGBColor[
             0.9440523897604667, 0.8012532703050674, 0.488448304966405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 59}], {
             RGBColor[
             0.9392387365664682, 0.785305730084084, 0.3140576031734424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 77}], {
             RGBColor[
             0.9439451496733521, 0.8001931463416045, 0.41638925456025033`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 87}], {
             RGBColor[
             0.943462209055286, 0.7991601851923478, 0.3638241486477757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 161}], {
             RGBColor[
             0.9262293383127354, 0.7896433339963667, 0.5939623595001332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 188}], {
             RGBColor[
             0.9434132947819527, 0.7990555625076795, 0.35850013185934815`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 228}], {
             RGBColor[
             0.9312938132278401, 0.7585056381061797, 0.2831930762757523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 243}], {
             RGBColor[
             0.9312706138956925, 0.7584273813113839, 0.2831029512511854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 256}], {
             RGBColor[
             0.9150199574474769, 0.6977818815605986, 0.25032568696804797`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 279}], {
             RGBColor[
             0.8802058199663241, 0.7535378638563964, 0.6101126578814935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 285}], {
             RGBColor[
             0.9347790182409805, 0.7702620529805546, 0.2967324396260614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 287}], {
             RGBColor[
             0.9333643701813559, 0.7654901129002807, 0.2912367990482898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 298}], {
             RGBColor[
             0.9430225868707383, 0.8008274203454376, 0.5055148038936533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 335}], {
             RGBColor[
             0.9012731257284801, 0.7703363616143588, 0.6121220763120938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 354}], {
             RGBColor[
             0.9244381093741103, 0.7883074383868084, 0.5969944428658969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 409}], {
             RGBColor[
             0.9100088851395515, 0.677914649700532, 0.2462936605641065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 430}], {
             RGBColor[
             0.9440549120326751, 0.8004279169295196, 0.42833620999779454`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 477}], {
             RGBColor[
             0.8730440610614711, 0.7478272717064334, 0.6094295629237709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 80}], {
             RGBColor[
             0.9409114948966308, 0.7869283855210747, 0.39090769289750066`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 159}], {
             RGBColor[
             0.8415482118806652, 0.8730932620035198, 0.7615586050456885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 166}], {
             RGBColor[
             0.9414880967217496, 0.9517272877041822, 0.7713710114652623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 192}], {
             RGBColor[
             0.9940266118629261, 0.9896318517140095, 0.5912117486370203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.993758314361771, 0.9903045262343178, 0.6526192110279058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 239}], {
             RGBColor[
             0.9893060792360522, 0.9884634125926093, 0.7264042690762259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 251}], {
             RGBColor[
             0.9705910048734211, 0.9746287786041237, 0.763593893619797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 272}], {
             RGBColor[
             0.9373107716149096, 0.7705783420690667, 0.38790316112942824`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 435}], {
             RGBColor[0.9944230380405812, 0.990479767223179, 0.634360291616]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 447}], {
             RGBColor[
             0.6312475580573389, 0.6943810654432889, 0.7460294714720366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 453}], {
             RGBColor[
             0.9357233514268826, 0.7633702377466407, 0.3865785788133091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 454}], {
             RGBColor[
             0.6859624031532867, 0.7454641579649712, 0.7493806765345675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 489}], {
             RGBColor[
             0.993386196651715, 0.9882620683331391, 0.5215065050812467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 50}], {
             RGBColor[
             0.6997233969073375, 0.7145151437574346, 0.6220686984329404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 82}], {
             RGBColor[
             0.6511741205962809, 0.6724642007743755, 0.6189751814768394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 126}], {
             RGBColor[
             0.9670916105269911, 0.9270581208170044, 0.6107866107774077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 149}], {
             RGBColor[
             0.9708913718095129, 0.9298919765599711, 0.6043546060625606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 173}], {
             RGBColor[
             0.613859141446401, 0.6364519975924864, 0.6167326804862945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 242}], {
             RGBColor[
             0.9752946749348739, 0.9319308261171501, 0.5411416446900582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 249}], {
             RGBColor[
             0.956400187774908, 0.9190844752340988, 0.6288844007270398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 269}], {
             RGBColor[
             0.9726467396296311, 0.9308358368195988, 0.585024785334834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 282}], {
             RGBColor[
             0.9757239373483116, 0.9297472786528963, 0.3624036269818403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 323}], {
             RGBColor[
             0.923236623537476, 0.7276985935618248, 0.26137187704819786`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 414}], {
             RGBColor[
             0.9764680635067153, 0.9324160524463172, 0.5216955594223636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 419}], {
             RGBColor[
             0.9770177022079559, 0.9325145108679829, 0.5032219477629185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 449}], {
             RGBColor[
             0.8579988313457919, 0.8415995063215385, 0.6356345729322372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 499}], {
             RGBColor[
             0.9247358977271057, 0.8943055225109454, 0.6421349034837205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 17}], {
             RGBColor[
             0.6838140819555287, 0.7459581625377016, 0.8854691216280357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 116}], {
             RGBColor[
             0.4668289745130376, 0.5759934160931307, 0.9517328498633311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 143}], {
             RGBColor[
             0.6860233651108038, 0.7455945494279008, 0.7560160093967134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 165}], {
             RGBColor[
             0.5636507498121494, 0.6529632289836158, 0.9604725080624683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 185}], {
             RGBColor[
             0.6838703579594925, 0.745981434111568, 0.8845364826047273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.6621543815636888, 0.7306667959455659, 0.9607534903810869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 224}], {
             RGBColor[
             0.6337521663711823, 0.7082869132449412, 0.9673109752897076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 277}], {
             RGBColor[
             0.685323850188258, 0.7465824905012091, 0.8604483548567712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 313}], {
             RGBColor[
             0.6802373888166477, 0.726878484682465, 0.6653940009357717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 333}], {
             RGBColor[
             0.6570691957277901, 0.6427917568859114, 0.6062993826451261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 358}], {
             RGBColor[
             0.6835563988381619, 0.7458516039465164, 0.8897395977453364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 361}], {
             RGBColor[
             0.6800040993474736, 0.7260915445239684, 0.6644877154010498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 386}], {
             RGBColor[
             0.682941824451877, 0.7455974616439464, 0.8999246857936022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 441}], {
             RGBColor[
             0.6864997354118483, 0.7466134573334096, 0.8078659768486895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 89}], {
             RGBColor[
             0.992063538575775, 0.9905220828360914, 0.7474632855824666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.9921158385431356, 0.9906339471779377, 0.7531558142716755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 116}], {
             RGBColor[
             0.7723978251227879, 0.8199128375720539, 0.891879541925771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 143}], {
             RGBColor[
             0.991592215720554, 0.9895139709068241, 0.6961627014591534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 165}], {
             RGBColor[
             0.8692196004218996, 0.8968826504625391, 0.9006192001249083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 176}], {
             RGBColor[
             0.9920550678000173, 0.9909825806069323, 0.7813316175865483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 178}], {
             RGBColor[
             0.9902688417202183, 0.9902439302190191, 0.8109340063337309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 261}], {
             RGBColor[
             0.979327054864086, 0.9832403293876577, 0.8812579373899222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 277}], {
             RGBColor[
             0.9908927007980083, 0.9905019119801322, 0.800595046919211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 288}], {
             RGBColor[
             0.9821331804007103, 0.9853331332182633, 0.8765078988111719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 313}], {
             RGBColor[
             0.985806239426398, 0.9707979061613881, 0.6055406929982116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 321}], {
             RGBColor[
             0.9907296107960941, 0.9904344700731189, 0.8032978703143242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 328}], {
             RGBColor[
             0.9914428962357522, 0.9891945916273487, 0.6799101970315127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 386}], {
             RGBColor[
             0.9885106750616273, 0.9895168831228696, 0.840071377856042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 391}], {
             RGBColor[
             0.9063201228819391, 0.925892317554734, 0.9043100126127396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 407}], {
             RGBColor[
             0.9900233224483883, 0.9901424016905599, 0.8150028960514617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 455}], {
             RGBColor[
             0.9623460588838706, 0.9705658781391546, 0.9096538164035473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 498}], {
             RGBColor[
             0.9810870983287518, 0.9548791351320045, 0.5872077209688744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 28}], {
             RGBColor[
             0.8393576104593539, 0.8726777216098311, 0.8578979091364201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 93}], {
             RGBColor[
             0.8052012987312365, 0.74859303378474, 0.6141902241840718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 160}], {
             RGBColor[
             0.8394702557622507, 0.8727243033374312, 0.8560310849507212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 167}], {
             RGBColor[
             0.8102288284484069, 0.7685255137883571, 0.6182354926057969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 172}], {
             RGBColor[
             0.8346623226339319, 0.8707360994306261, 0.935710979419044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 201}], {
             RGBColor[
             0.8388300429008271, 0.8705733714230247, 0.729535153347622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 218}], {
             RGBColor[
             0.8391829978314206, 0.8713283063303466, 0.7679521193573843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 235}], {
             RGBColor[
             0.8392019148558711, 0.8713687679328418, 0.7700111207264818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 274}], {
             RGBColor[
             0.8394475161529831, 0.8718940842732639, 0.7967433062416027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 300}], {
             RGBColor[
             0.7644665879793643, 0.8161234680653566, 0.9771062409773978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 305}], {
             RGBColor[
             0.8336075941347951, 0.8533225524011783, 0.6781481456745502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 310}], {
             RGBColor[
             0.8339240777223945, 0.8543901258560312, 0.6793776246494633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 406}], {
             RGBColor[
             0.8384168825372283, 0.8722887064384275, 0.8734882053318624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 432}], {
             RGBColor[
             0.7953099778824331, 0.7093772427065129, 0.6062314352499836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 460}], {
             RGBColor[
             0.8365351939547481, 0.871510579852381, 0.904672654797511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 493}], {
             RGBColor[
             0.8398127655774765, 0.8726753158598739, 0.8364984520395502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 26}], {
             RGBColor[
             0.874256320068558, 0.8551318679827189, 0.6384697744065353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 59}], {
             RGBColor[
             0.8868298659352909, 0.8975453906001725, 0.6873156257838915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 67}], {
             RGBColor[
             0.8918453858637854, 0.9130939550936245, 0.8232916471168272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 124}], {
             RGBColor[
             0.8736882049494854, 0.8532154822863135, 0.6362627544484764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 188}], {
             RGBColor[
             0.8910044241507755, 0.9112952230237681, 0.7317581544697973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 200}], {
             RGBColor[
             0.8691355598179332, 0.8358889033764223, 0.6288334537046762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 228}], {
             RGBColor[
             0.8788849425966627, 0.8707452986222683, 0.6564510988862013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 298}], {
             RGBColor[
             0.8906137162395609, 0.9130670808615262, 0.8787728265041025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 318}], {
             RGBColor[
             0.7367160992619132, 0.7942474830839217, 0.9743926338372014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 335}], {
             RGBColor[
             0.8488642550973029, 0.8825760221304475, 0.985380098922543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 459}], {
             RGBColor[
             0.8625680167142318, 0.8098507834742492, 0.6235490543633881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 468}], {
             RGBColor[
             0.48394750815883025`, 0.5702305389085748, 0.9565508083036955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 25}], {
             RGBColor[
             0.9311997193740694, 0.9479773957586022, 0.9932998545973435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 46}], {
             RGBColor[
             0.931970277166351, 0.8610175381293783, 0.6293569804141983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 150}], {
             RGBColor[
             0.897562127286806, 0.7132653911698088, 0.6010850121104936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 220}], {
             RGBColor[
             0.9352745182849945, 0.8741177530917199, 0.6320156503787664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 325}], {
             RGBColor[
             0.9626524497432969, 0.969526275186111, 0.8482197213448237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 388}], {
             RGBColor[
             0.9624057408499025, 0.9689985898092359, 0.8213669808096541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 392}], {
             RGBColor[
             0.8890858439075838, 0.9143969346123229, 0.9892829955598497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 413}], {
             RGBColor[
             0.6995810902283732, 0.7634715931222523, 0.9722714429358523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 473}], {
             RGBColor[
             0.9338401234041958, 0.8684308553731115, 0.6308615025881005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 474}], {
             RGBColor[
             0.9215099539998535, 0.8195458424702764, 0.6209403588590924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 490}], {
             RGBColor[
             0.9327791527671079, 0.9492367930736336, 0.9934505023643483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 55}], {
             RGBColor[
             0.9910510867925657, 0.9905674086592161, 0.7979701810995812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 59}], {
             RGBColor[
             0.9895053687469197, 0.975971243604179, 0.5694213367533545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 77}], {
             RGBColor[
             0.9942117818538037, 0.9908586598616995, 0.6717529881401625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[
             0.9937288412357376, 0.9898256987124427, 0.6191878822276878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 91}], {
             RGBColor[
             0.893139794048835, 0.9146618321604157, 0.8618554622773504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 188}], {
             RGBColor[
             0.9936799269624043, 0.9897210760277745, 0.6138638654392603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 200}], {
             RGBColor[
             0.971811062629562, 0.9143147563804288, 0.5109391646741392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 228}], {
             RGBColor[
             0.9815604454082916, 0.9491711516262746, 0.5385568098556643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 256}], {
             RGBColor[
             0.9652865896279283, 0.8884473950806936, 0.5056894205479601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 287}], {
             RGBColor[
             0.9836310023618073, 0.9561556264203757, 0.546600532628202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 298}], {
             RGBColor[
             0.9932892190511897, 0.9914929338655326, 0.7608785374735655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 335}], {
             RGBColor[
             0.9515397579089316, 0.9610018751344538, 0.867485809892006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 336}], {
             RGBColor[
             0.9943734044431054, 0.9912043542376657, 0.6893446095666633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 354}], {
             RGBColor[
             0.9747047415545619, 0.9789729519069034, 0.852358176445809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 409}], {
             RGBColor[
             0.960275517320003, 0.8685801632206269, 0.5016573941440186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 24}], {
             RGBColor[
             0.6428786799326573, 0.6528865132054431, 0.6107479900751512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 52}], {
             RGBColor[
             0.6650191480641732, 0.7279248555065416, 0.7993865448817103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 170}], {
             RGBColor[
             0.6638534343639089, 0.7280108785749395, 0.8599985398499344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 214}], {
             RGBColor[
             0.6649516099759709, 0.727780398365025, 0.7920354407776522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 268}], {
             RGBColor[
             0.6643813668028353, 0.7265607058781167, 0.729967990514772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 466}], {
             RGBColor[
             0.6629346711121571, 0.7276309463592017, 0.8752248246145393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 491}], {
             RGBColor[
             0.6535433115419873, 0.6905228714188323, 0.6435220769412443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 39}], {
             RGBColor[
             0.9822709076239232, 0.9830068569575823, 0.7174186717957834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 51}], {
             RGBColor[
             0.956716531122688, 0.967239840298252, 0.9581518020593288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 62}], {
             RGBColor[
             0.9815915230367982, 0.9845204495050018, 0.8591216218067445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 96}], {
             RGBColor[
             0.9819834119433524, 0.9823919327671136, 0.6861265411833268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 110}], {
             RGBColor[
             0.9819718595823903, 0.9823672234351385, 0.6848691379855132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 136}], {
             RGBColor[
             0.9609938037665482, 0.9704298232326518, 0.9509114951646449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 157}], {
             RGBColor[
             0.981429989531768, 0.9806015377171993, 0.6774776551470806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 240}], {
             RGBColor[
             0.9825896595289594, 0.9836886350516936, 0.7521128495502399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 360}], {
             RGBColor[
             0.9821987341135632, 0.9828524851167834, 0.709563030596366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 52}], {
             RGBColor[
             0.9724830359029119, 0.9158702014126971, 0.46754122310692386`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 64}], {
             RGBColor[
             0.9630404780843363, 0.8853269438288087, 0.3195756589775198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.8732152399427024, 0.8407305268190339, 0.6296064647907634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 115}], {
             RGBColor[
             0.9530195804165116, 0.9036555156369535, 0.6193904797273098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 170}], {
             RGBColor[
             0.9713173222026474, 0.9159562244810951, 0.528153218075148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 223}], {
             RGBColor[
             0.9705865441318577, 0.9156540289686839, 0.5402641019011563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 268}], {
             RGBColor[
             0.9718452546415739, 0.9145060517842722, 0.3981226687399856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 491}], {
             RGBColor[
             0.9610071993807259, 0.8784682173249879, 0.3116767551664579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 164}], {
             RGBColor[
             0.9047313645117165, 0.926872248055715, 0.9907752792819929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.9603943915263176, 0.9691525525138196, 0.9156720487391707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 220}], {
             RGBColor[
             0.9362251173273104, 0.874875734964739, 0.6321063193640323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 316}], {
             RGBColor[
             0.5555386592081927, 0.6270646888158106, 0.9634457617913047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 325}], {
             RGBColor[
             0.9636030487856126, 0.9702842570591301, 0.8483103903300897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 392}], {
             RGBColor[
             0.8900364429498997, 0.915154916485342, 0.9893736645451154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 413}], {
             RGBColor[
             0.7005316892706891, 0.7642295749952714, 0.9723621119211181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 474}], {
             RGBColor[
             0.9224605530421692, 0.8203038243432954, 0.6210310278443583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 490}], {
             RGBColor[
             0.9337297518094239, 0.9499947749466527, 0.9935411713496143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 67}], {
             RGBColor[
             0.9771336896146828, 0.9331587452591937, 0.48216080491597135`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 124}], {
             RGBColor[
             0.958976508700383, 0.8732802724518828, 0.29513191224762053`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 318}], {
             RGBColor[
             0.8220044030128106, 0.814312273249491, 0.6332617916363457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 335}], {
             RGBColor[
             0.9341525588482003, 0.9026408122960168, 0.6442492567216871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 459}], {
             RGBColor[
             0.9478563204651292, 0.8299155736398185, 0.28241821216253227`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 29}], {
             RGBColor[
             0.8707817824332663, 0.8246217771229303, 0.6262177302487113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 65}], {
             RGBColor[
             0.89643261840225, 0.917528493498128, 0.8755276522870109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 86}], {
             RGBColor[
             0.8967889433773859, 0.9160789496893484, 0.753545136926935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 177}], {
             RGBColor[
             0.6281007518430358, 0.7065424015630154, 0.9655181299587501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[
             0.89500574546333, 0.9106364930273536, 0.6979204435462533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 290}], {
             RGBColor[
             0.7896283927701178, 0.8355829689208562, 0.9796664367606033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 297}], {
             RGBColor[
             0.8976996382252811, 0.9180268338836233, 0.8526686509632175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 350}], {
             RGBColor[
             0.869089448668618, 0.8179122376828964, 0.6248560387774963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 412}], {
             RGBColor[
             0.8792811501042643, 0.9061534814029366, 0.9679954924850622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 484}], {
             RGBColor[
             0.8796736803959937, 0.8589178374151553, 0.6383582659771935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 490}], {
             RGBColor[
             0.8677280710201962, 0.8975271616881817, 0.987203324020966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 125}], {
             RGBColor[
             0.9330649438551819, 0.9463028602112529, 0.8671262569523333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 149}], {
             RGBColor[
             0.9885153630059011, 0.989300851153188, 0.8302325196894843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 201}], {
             RGBColor[
             0.9936231565731688, 0.989744838169186, 0.6182384129971045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 218}], {
             RGBColor[
             0.9939761115037623, 0.9904997730765079, 0.6566553790068668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 282}], {
             RGBColor[
             0.9933479285446999, 0.9891561532461131, 0.588281540608764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 305}], {
             RGBColor[
             0.9884007078071368, 0.9724940191473395, 0.5668514053240328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 310}], {
             RGBColor[
             0.9887171913947362, 0.9735615926021925, 0.5680808842989458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 406}], {
             RGBColor[
             0.9932099962095701, 0.9914601731845887, 0.762191464981345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 408}], {
             RGBColor[
             0.864082847402567, 0.89199326462863, 0.8603622896844434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 419}], {
             RGBColor[
             0.9946416934043442, 0.9919233854611996, 0.7290998613898423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 432}], {
             RGBColor[
             0.9501030915547748, 0.8285487094526742, 0.49493469489946607`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 493}], {
             RGBColor[
             0.9946058792498182, 0.9918467826060351, 0.7252017116890327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 46}], {
             RGBColor[
             0.9375540210147754, 0.7901295327521776, 0.2686127033942143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 65}], {
             RGBColor[
             0.9670674439975859, 0.8983501195063792, 0.5210305536104092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 86}], {
             RGBColor[
             0.9674237689727219, 0.8969005756975996, 0.3990480382503333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 177}], {
             RGBColor[
             0.6987355774383719, 0.6873640275712666, 0.6110210312821484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 194}], {
             RGBColor[
             0.965640571058666, 0.8914581190356048, 0.34342334486965154`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 254}], {
             RGBColor[
             0.9400348785809239, 0.79996530630518, 0.27060885962514886`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 290}], {
             RGBColor[
             0.8602632183654538, 0.8164045949291073, 0.6251693380840015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 297}], {
             RGBColor[
             0.9683344638206173, 0.8988484598918745, 0.4981715522866159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 350}], {
             RGBColor[
             0.9397242742639542, 0.7987338636911476, 0.27035894010089456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 377}], {
             RGBColor[
             0.9523752971980192, 0.8467112354692226, 0.2918902608578103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 412}], {
             RGBColor[
             0.9499159756996005, 0.8869751074111878, 0.6134983938084605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 426}], {
             RGBColor[
             0.7338685306463895, 0.7158865417070407, 0.6137868260549315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 476}], {
             RGBColor[
             0.9671540994818725, 0.8963237799244406, 0.36969617837855473`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 31}], {
             RGBColor[
             0.9868865796952773, 0.9888452779515366, 0.8669868411005386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 133}], {
             RGBColor[
             0.944477349613176, 0.8138168037930025, 0.5336522982908991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 191}], {
             RGBColor[
             0.9669307146801589, 0.9740312002801246, 0.9038557021335807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 311}], {
             RGBColor[
             0.9589309758015598, 0.9678844188996694, 0.9111360316561798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 366}], {
             RGBColor[
             0.9252175029171147, 0.9410022107494556, 0.907920410516089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 405}], {
             RGBColor[
             0.9875968605595113, 0.989138997342283, 0.8552156490322268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 423}], {
             RGBColor[
             0.9883321201986879, 0.9894430460983934, 0.843030494020121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 429}], {
             RGBColor[
             0.9895318924347892, 0.9899391827507613, 0.8231471631569058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 465}], {
             RGBColor[
             0.9833868555967316, 0.9629577914981705, 0.5983608262779622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 469}], {
             RGBColor[
             0.8917893255664779, 0.9145541731717564, 0.9046771536308068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 488}], {
             RGBColor[
             0.666305747548406, 0.73084241870175, 0.8861580206631072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 133}], {
             RGBColor[
             0.942197933665284, 0.8128742067202313, 0.5714281194868469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 191}], {
             RGBColor[
             0.964651298732267, 0.9730886032073534, 0.9416315233295285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 226}], {
             RGBColor[
             0.928316840453249, 0.7498434044560682, 0.5598453950539946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 237}], {
             RGBColor[
             0.9380644960098101, 0.7941052317156161, 0.5679790777872912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 311}], {
             RGBColor[
             0.9566515598536678, 0.9669418218268983, 0.9489118528521276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 366}], {
             RGBColor[
             0.9229380869692227, 0.9400596136766844, 0.9456962317120368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 405}], {
             RGBColor[
             0.9853174446116194, 0.9881964002695119, 0.8929914702281747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 429}], {
             RGBColor[
             0.9872524764868973, 0.9889965856779902, 0.8609229843528536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 472}], {
             RGBColor[
             0.9854140166797868, 0.988236335301488, 0.8913910211381406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 488}], {
             RGBColor[
             0.6640263316005139, 0.7298998216289788, 0.923933841859055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 66}], {
             RGBColor[
             0.9458422511762752, 0.9433844253320922, 0.6915909451351946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 84}], {
             RGBColor[
             0.9443426070237331, 0.9383257734723757, 0.6857651107866037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 89}], {
             RGBColor[
             0.951243155322252, 0.9602197805692171, 0.8301866048478658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 176}], {
             RGBColor[
             0.9512346845464942, 0.9606802783400581, 0.8640549368519475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 179}], {
             RGBColor[
             0.8545083176597374, 0.8869769759360291, 0.98594483052387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 245}], {
             RGBColor[
             0.9508148767780382, 0.9593037360687471, 0.7835711283390048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 255}], {
             RGBColor[
             0.950022401594639, 0.9601789681852151, 0.8841456026518979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 260}], {
             RGBColor[
             0.9295474620397266, 0.946256263292213, 0.9791468615226563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 299}], {
             RGBColor[
             0.9510333492983047, 0.9597710266986369, 0.8073505139139038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 312}], {
             RGBColor[
             0.9497926129993202, 0.9600839446957532, 0.8879537943501545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 328}], {
             RGBColor[
             0.950622512982229, 0.9588922893604743, 0.7626335162969118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 334}], {
             RGBColor[
             0.9443176211435237, 0.9382414902314659, 0.685668045360178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 407}], {
             RGBColor[
             0.9492029391948652, 0.9598400994236855, 0.897726215316861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 448}], {
             RGBColor[
             0.9356739400438944, 0.9508253805565343, 0.9687763323029727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 475}], {
             RGBColor[
             0.9339818991975629, 0.9033766731648201, 0.6455157173374336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 478}], {
             RGBColor[
             0.9482606890305272, 0.9594504547660071, 0.9133417390052005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 482}], {
             RGBColor[
             0.9463228710647641, 0.9450056690708816, 0.6934580626445239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 76}], {
             RGBColor[
             0.9702036368742187, 0.9092758007490527, 0.34851852541658723`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 111}], {
             RGBColor[
             0.9898763636589569, 0.9851476253501512, 0.625639394409723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 160}], {
             RGBColor[
             0.9925824640017944, 0.9862666673855212, 0.5807923085657104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 175}], {
             RGBColor[
             0.937312604053465, 0.9454010348207783, 0.7037496928002254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 182}], {
             RGBColor[
             0.9929683655813318, 0.986426247605878, 0.574396920711501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 237}], {
             RGBColor[
             0.9411553707691673, 0.7904493827561581, 0.32495629499750583`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 241}], {
             RGBColor[
             0.9227046794914886, 0.9337530722966074, 0.7023563759148559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 274}], {
             RGBColor[
             0.9925597243925268, 0.9854364483213538, 0.5215045298565919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 351}], {
             RGBColor[
             0.9636775977243199, 0.9664014002957719, 0.7054890071026478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 371}], {
             RGBColor[
             0.88987846479188, 0.9078290303884996, 0.6991588566621535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 432}], {
             RGBColor[
             0.9484221861219768, 0.8229196067546027, 0.33099265886497276`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 460}], {
             RGBColor[
             0.9896474021942918, 0.9850529439004709, 0.6294338784125002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 463}], {
             RGBColor[
             0.9806873321880976, 0.9790872324079734, 0.6766959635047335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 44}], {
             RGBColor[
             0.8380789787786328, 0.7549395418643581, 0.6131849585733617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 62}], {
             RGBColor[
             0.8771559152907384, 0.9026302878007502, 0.880902277963457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 190}], {
             RGBColor[
             0.8644351175463629, 0.8563460286781577, 0.6504679413519787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 291}], {
             RGBColor[
             0.8663250506171079, 0.8958237656948022, 0.9561594140929307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 356}], {
             RGBColor[
             0.775408295923575, 0.8244741211875981, 0.9782491104013002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 394}], {
             RGBColor[
             0.8786897652761265, 0.9032645741878547, 0.8554824142290578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 467}], {
             RGBColor[
             0.8767169302552783, 0.9024487562071866, 0.8881773960578845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.9368820753890339, 0.7824571854852564, 0.29157506802870203`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 123}], {
             RGBColor[
             0.9646826665953581, 0.8925284829012217, 0.31729925815209814`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 193}], {
             RGBColor[
             0.9106355117049801, 0.8989521217594161, 0.6641660674364669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 347}], {
             RGBColor[
             0.8372542911204667, 0.8413832976700641, 0.6569165598961352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 410}], {
             RGBColor[
             0.9609400915658426, 0.9386783428377969, 0.6556060757525595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 422}], {
             RGBColor[
             0.9807105633629735, 0.9465943422275145, 0.3795646104799518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 428}], {
             RGBColor[
             0.970252155834832, 0.9456232651225034, 0.6398431799204958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 437}], {
             RGBColor[
             0.9384005773342559, 0.9210912314295714, 0.6668143241823539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 75}], {
             RGBColor[
             0.95402844998809, 0.8532395289918973, 0.29335534741790315`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 76}], {
             RGBColor[
             0.9565199762817819, 0.8631176004944665, 0.2953600879574464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 104}], {
             RGBColor[
             0.9503412437139708, 0.8386209848036683, 0.2903885346998919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 112}], {
             RGBColor[
             0.9790842023808982, 0.9397234354450779, 0.49100069243600836`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 266}], {
             RGBColor[
             0.9006180011855852, 0.8808945338111425, 0.6483964511247421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 359}], {
             RGBColor[
             0.571174296040613, 0.5968342912253385, 0.622950610899317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 379}], {
             RGBColor[
             0.9711557856423809, 0.9360256720109683, 0.6165090800092765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 408}], {
             RGBColor[
             0.8487182813773322, 0.8402059616759723, 0.6432618161908091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 440}], {
             RGBColor[
             0.9777806077235343, 0.9396460644785285, 0.546165267418333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 463}], {
             RGBColor[
             0.9670036715956607, 0.9329290321533872, 0.6235375260455926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 49}], {
             RGBColor[
             0.8589669701079599, 0.8885656556502339, 0.8856511427796823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 53}], {
             RGBColor[
             0.9732151057056324, 0.9784041050836698, 0.8791570342663262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 97}], {
             RGBColor[
             0.9140270496442962, 0.9317165275997802, 0.8911025235366925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 100}], {
             RGBColor[
             0.9871849845889084, 0.9729729714356863, 0.5937844559407814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 203}], {
             RGBColor[
             0.9613416354418167, 0.8786008485781167, 0.5308670953942907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 207}], {
             RGBColor[
             0.9123946040946643, 0.9304148598300577, 0.8909468194228672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 257}], {
             RGBColor[
             0.992110961114899, 0.9891802581191367, 0.6477154076125999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 264}], {
             RGBColor[
             0.9391689429677768, 0.9517639908774098, 0.8935005797663191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 281}], {
             RGBColor[
             0.9859867077705109, 0.9879291449920771, 0.8575380433377878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 317}], {
             RGBColor[
             0.8589669701079599, 0.8885656556502339, 0.8856511427796823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 322}], {
             RGBColor[
             0.992540795963391, 0.9900996313970911, 0.6945002782377436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 324}], {
             RGBColor[
             0.9206078457662497, 0.9369638757964738, 0.8917302057455505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 343}], {
             RGBColor[
             0.9880200621909672, 0.989314002092676, 0.8482021027882907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 374}], {
             RGBColor[
             0.9305848397759406, 0.7468340918712073, 0.5056111507609602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 397}], {
             RGBColor[
             0.9924621268092155, 0.9899313660309813, 0.6859376262954824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 445}], {
             RGBColor[
             0.9926210032939811, 0.9902711867670182, 0.7032303511902038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 77}], {
             RGBColor[
             0.9938809780547712, 0.9893203557242028, 0.5753604073670411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 79}], {
             RGBColor[
             0.9667323362191399, 0.8939525212401911, 0.4107262939198263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 87}], {
             RGBColor[
             0.9933980374367051, 0.9882873945749461, 0.5227953014545665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 127}], {
             RGBColor[
             0.9153278009289909, 0.9308529134184578, 0.767670852697006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 184}], {
             RGBColor[
             0.9936456983969901, 0.9888171163266317, 0.5497516685953199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 221}], {
             RGBColor[
             0.9780299686933207, 0.9801613096566101, 0.7497768889405916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 253}], {
             RGBColor[
             0.9922416227168259, 0.9847788455007227, 0.4849436962472997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 287}], {
             RGBColor[
             0.983300198562775, 0.9546173222828789, 0.45020795185508056`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 301}], {
             RGBColor[
             0.9507162831727404, 0.959070728564863, 0.7710462377250858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 316}], {
             RGBColor[
             0.5862922071714266, 0.6471180877750845, 0.7422639385000372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 336}], {
             RGBColor[
             0.994042600644073, 0.9896660501001691, 0.5929520287935419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 354}], {
             RGBColor[
             0.9743739377555294, 0.9774346477694067, 0.7559655956726876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 388}], {
             RGBColor[
             0.9941098878554524, 0.9898099706415289, 0.6002758265036525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 436}], {
             RGBColor[
             0.9684383041117873, 0.9730078619166118, 0.7660130751703514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 473}], {
             RGBColor[
             0.9655442704097457, 0.8892422362054044, 0.4097703482820989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 62}], {
             RGBColor[
             0.9925224445275327, 0.9893813173612107, 0.6431421864680742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 96}], {
             RGBColor[
             0.9929143334340869, 0.9872528006233223, 0.47014710584465663`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 108}], {
             RGBColor[
             0.9932063205705048, 0.9878773315836922, 0.5019281037080133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 113}], {
             RGBColor[
             0.9896176713588577, 0.9881801190066982, 0.6912817951850048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 157}], {
             RGBColor[
             0.9923609110225025, 0.985462405573408, 0.4614982198084103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 190}], {
             RGBColor[
             0.9798016467831572, 0.9430970582386182, 0.4127078498565958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 378}], {
             RGBColor[
             0.9927299049387773, 0.9867071086968948, 0.462931691494484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 161}], {
             RGBColor[
             0.9390391068166732, 0.953635876396498, 0.9735075197230021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 183}], {
             RGBColor[
             0.8489243938999773, 0.8827090409814773, 0.9853632611668581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 202}], {
             RGBColor[
             0.9571202465489146, 0.9649670891882769, 0.8356981534891046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 206}], {
             RGBColor[
             0.9396838933619043, 0.9541167571461904, 0.9724160642891901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 243}], {
             RGBColor[
             0.9440803823996303, 0.9224199237115153, 0.6626481114740541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 273}], {
             RGBColor[
             0.9564660673813843, 0.9635678660965893, 0.7644947882292779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 283}], {
             RGBColor[
             0.9568523725153633, 0.9643941337167301, 0.8065417180639542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 285}], {
             RGBColor[
             0.9475887867449182, 0.934254595380686, 0.6762775998489301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 396}], {
             RGBColor[
             0.8772875715437158, 0.9049893124849464, 0.9881576658093418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 421}], {
             RGBColor[
             0.9462636991876674, 0.9297847639047248, 0.671129884910799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 430}], {
             RGBColor[
             0.9568646805366128, 0.964420459329651, 0.8078813702206633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 477}], {
             RGBColor[
             0.8858538295654089, 0.9118198141065648, 0.9889747231466397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 44}], {
             RGBColor[
             0.9542059711630533, 0.8433171252029726, 0.4581965876625539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 56}], {
             RGBColor[
             0.9907082954409927, 0.9899432028160207, 0.7685818946556606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.9947000208630997, 0.9915938838607261, 0.7024286741570986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 132}], {
             RGBColor[
             0.941130506678435, 0.7866700762309892, 0.4474270910893527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.9777641226352605, 0.9807051057000193, 0.8091064695567636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 356}], {
             RGBColor[
             0.8915352883079954, 0.9128517045262127, 0.8232607394904925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 365}], {
             RGBColor[
             0.985175095007282, 0.9862321967607195, 0.7965616264220894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 457}], {
             RGBColor[
             0.9645198398913459, 0.8842081778176407, 0.46649536853895257`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 485}], {
             RGBColor[
             0.9876286128170696, 0.9880620263259924, 0.7924084607500497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 494}], {
             RGBColor[
             0.9945582035742915, 0.9915352387672658, 0.7047789536440294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 108}], {
             RGBColor[
             0.9901546119807454, 0.978014496876596, 0.4533985834488723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 113}], {
             RGBColor[
             0.9865659627690982, 0.9783172842996021, 0.6427522749258637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 119}], {
             RGBColor[
             0.9629467594687193, 0.9610080634662521, 0.6964341471889854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 315}], {
             RGBColor[
             0.9907780006450673, 0.9793478621953184, 0.521250592451433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 364}], {
             RGBColor[
             0.9873202278058992, 0.9786291922760466, 0.6302521512907286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 378}], {
             RGBColor[
             0.9896781963490179, 0.9768442739897987, 0.41440217123534295`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 380}], {
             RGBColor[
             0.9910208194120425, 0.9798672269851352, 0.5476799167329601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 381}], {
             RGBColor[
             0.9639065519875438, 0.9617238751552754, 0.6948094688085961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 416}], {
             RGBColor[
             0.9900572158068606, 0.9778061763089201, 0.4427976109810236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 452}], {
             RGBColor[
             0.99024026591832, 0.9798367030770891, 0.58185956295152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 468}], {
             RGBColor[
             0.5830127059675694, 0.6367680276997995, 0.6689405979694156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 487}], {
             RGBColor[
             0.9289930845303124, 0.9340141647928917, 0.6959637208678902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[
             0.938494381438708, 0.7825517459375457, 0.3118010653319602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 137}], {
             RGBColor[
             0.8914446749809054, 0.5999574474761478, 0.23113111468061015`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 148}], {
             RGBColor[
             0.8773191672421017, 0.7504566884821777, 0.6096834451859001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 156}], {
             RGBColor[
             0.9432359398648449, 0.7981761094720861, 0.3616854992425249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 227}], {
             RGBColor[
             0.9261247555971797, 0.7887751608624847, 0.5936131932211495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 229}], {
             RGBColor[
             0.9316452391967103, 0.7594479809002128, 0.28519344107378264`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 250}], {
             RGBColor[
             0.9270874070768771, 0.7894931047598459, 0.5919836753657384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 263}], {
             RGBColor[
             0.9417750984751225, 0.7936183748503638, 0.3245460315070031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 267}], {
             RGBColor[
             0.9442333753949967, 0.8003095232148794, 0.47025020124099204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 393}], {
             RGBColor[
             0.9254814008846062, 0.738655906935425, 0.26124809317445286`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 485}], {
             RGBColor[
             0.9369518972586861, 0.7968500253858188, 0.5752856665590245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 56}], {
             RGBColor[
             0.9501915111941358, 0.842139495648894, 0.5597958046919513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 62}], {
             RGBColor[
             0.952766123428302, 0.8432041639722381, 0.5171278170889398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 92}], {
             RGBColor[
             0.9541832366162428, 0.8437901766935993, 0.49364258419338936`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 110}], {
             RGBColor[
             0.9531464599738941, 0.8410509379023747, 0.3428753332677087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 132}], {
             RGBColor[
             0.900613722431578, 0.6388663690638625, 0.2386410011256434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 157}], {
             RGBColor[
             0.9526045899232718, 0.8392852521844355, 0.33548385042927603`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 356}], {
             RGBColor[
             0.8510185040611385, 0.765047997359086, 0.6144746495267831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 360}], {
             RGBColor[
             0.953373334505067, 0.8415361995840196, 0.36756922587856145`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 365}], {
             RGBColor[
             0.9446583107604252, 0.8384284895935928, 0.58777553645838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 457}], {
             RGBColor[
             0.9240030556444889, 0.736404470650514, 0.2577092785752433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 494}], {
             RGBColor[
             0.9540414193274347, 0.8437315316001391, 0.49599286368032014`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 118}], {
             RGBColor[
             0.9760058761768202, 0.9816174772435371, 0.9251271612726613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 152}], {
             RGBColor[
             0.9803743647767631, 0.9814372671377847, 0.7083184344976637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 185}], {
             RGBColor[
             0.9786325637009061, 0.9827036800375368, 0.8815961513491504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 187}], {
             RGBColor[
             0.9569165873051024, 0.9673890418715347, 0.95781315912551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 195}], {
             RGBColor[
             0.9624983921465095, 0.9715519427828896, 0.948364619496868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 216}], {
             RGBColor[
             0.8078568739895435, 0.8501906797513217, 0.9524932190700334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 217}], {
             RGBColor[
             0.9592304140133037, 0.9691146900419678, 0.9538964540511816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 224}], {
             RGBColor[
             0.928514372112596, 0.9450091591709102, 0.9643706440341306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 292}], {
             RGBColor[
             0.9792372911990512, 0.9829537503988077, 0.8715742517202871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 328}], {
             RGBColor[
             0.9806362513674156, 0.9819974160743944, 0.7368231737134958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 398}], {
             RGBColor[
             0.9423739870470842, 0.8420185061247095, 0.5957493937514636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 399}], {
             RGBColor[
             0.9680217180589472, 0.9400627146936055, 0.6353459371425437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 464}], {
             RGBColor[
             0.8966703557481557, 0.9196176049047029, 0.9613333333258014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 481}], {
             RGBColor[
             0.9804783546810429, 0.9816596910280471, 0.7196370938272247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 496}], {
             RGBColor[
             0.8806240845243325, 0.9070369776723823, 0.9597459745678963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 86}], {
             RGBColor[
             0.963561181958895, 0.8815867053185957, 0.395940110072438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 142}], {
             RGBColor[
             0.9222159308353244, 0.7293191163062162, 0.2562713160045787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 150}], {
             RGBColor[
             0.8992832841214033, 0.6270635154136042, 0.2372328069126143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 194}], {
             RGBColor[
             0.961777984044839, 0.8761442486566009, 0.34031541669175625`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 220}], {
             RGBColor[
             0.9369956751195919, 0.7879158773355153, 0.2681634451808871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 254}], {
             RGBColor[
             0.9361722915670969, 0.7846514359261761, 0.2675009314472535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 297}], {
             RGBColor[
             0.9644718768067901, 0.8835345895128706, 0.4950636241087206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 325}], {
             RGBColor[
             0.9643736065778943, 0.8833243994299063, 0.4843675161469444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 350}], {
             RGBColor[
             0.9358616872501271, 0.7834199933121437, 0.26725101192299927`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 377}], {
             RGBColor[
             0.9485127101841921, 0.8313973650902187, 0.28878233267991493`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 392}], {
             RGBColor[
             0.8908070007421812, 0.8281950588561182, 0.6254307903619702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 412}], {
             RGBColor[
             0.9460533886857734, 0.8716612370321839, 0.6103904656305652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 426}], {
             RGBColor[
             0.7300059436325623, 0.7005726713280368, 0.6106788978770363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 476}], {
             RGBColor[
             0.9632915124680455, 0.8810099095454367, 0.3665882502006594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 55}], {
             RGBColor[
             0.9882179209081481, 0.9893958217569673, 0.844923071802657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 59}], {
             RGBColor[
             0.9866722028625021, 0.9747996567019301, 0.6163742274564303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 73}], {
             RGBColor[
             0.9675344330101509, 0.9074203167747059, 0.5567306105735907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 91}], {
             RGBColor[
             0.8903066281644174, 0.9134902452581669, 0.9088083529804263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 136}], {
             RGBColor[
             0.9696501557859952, 0.9761446336922974, 0.9030713515736525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 200}], {
             RGBColor[
             0.9689778967451443, 0.91314316947818, 0.5578920553772151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 228}], {
             RGBColor[
             0.978727279523874, 0.9479995647240258, 0.5855097005587402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 256}], {
             RGBColor[
             0.9624534237435107, 0.8872758081784448, 0.5526423112510359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 298}], {
             RGBColor[
             0.9904560531667721, 0.9903213469632838, 0.8078314281766413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 416}], {
             RGBColor[
             0.9908343549253326, 0.9885229536194531, 0.6594664229878424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 452}], {
             RGBColor[
             0.9910174050367921, 0.990553480387622, 0.798528374958339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 468}], {
             RGBColor[
             0.5837898450860415, 0.6474848050103323, 0.8856094099762344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 117}], {
             RGBColor[
             0.9351263500277934, 0.9494309677013077, 0.931780568949427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 140}], {
             RGBColor[
             0.9703080592781272, 0.9223875023501968, 0.5783925335901152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 155}], {
             RGBColor[
             0.9585932722273287, 0.8759422754151505, 0.568966540947649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 156}], {
             RGBColor[
             0.9897594803256515, 0.9881531185876641, 0.6827063791280779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 198}], {
             RGBColor[
             0.9866179278027272, 0.9779259506639111, 0.639037666015732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 250}], {
             RGBColor[
             0.9736109475376837, 0.9794701138754239, 0.9130045552512913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 365}], {
             RGBColor[
             0.9810219199097052, 0.984997204936124, 0.9004597121166171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 479}], {
             RGBColor[
             0.9650490121302107, 0.9015371328822819, 0.5741609808091992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 51}], {
             RGBColor[
             0.8344855522773214, 0.8714477994413923, 0.9781587819320604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 100}], {
             RGBColor[
             0.8550960429234042, 0.8709692231731063, 0.6815453800410161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 203}], {
             RGBColor[
             0.8292526937763127, 0.7765971003155367, 0.6186280194945253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 264}], {
             RGBColor[
             0.8070800013022728, 0.8497602426148299, 0.9812615038665539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 324}], {
             RGBColor[
             0.7885189041007457, 0.8349601275338938, 0.9794911298457851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 360}], {
             RGBColor[
             0.8599677552681967, 0.8870604442599236, 0.7295700104690976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 397}], {
             RGBColor[
             0.8603731851437114, 0.8879276177684013, 0.773698550395717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 457}], {
             RGBColor[
             0.8305974764076187, 0.7819287153264181, 0.6197100631657795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 82}], {
             RGBColor[
             0.39199477576469927`, 0.5139479053622513, 0.9461985383777247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 126}], {
             RGBColor[
             0.7079122656954095, 0.7685418254048804, 0.938009967678293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 131}], {
             RGBColor[
             0.7101682285727133, 0.7702243188249732, 0.9341912109763701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 173}], {
             RGBColor[
             0.35467979661481946`, 0.4779357021803622, 0.9439560373871798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 242}], {
             RGBColor[
             0.7161153301032923, 0.773414530705026, 0.8683650015909435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 323}], {
             RGBColor[
             0.6640572787058945, 0.5691822981497006, 0.5885952339490832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 340}], {
             RGBColor[
             0.7117205477995208, 0.7549843507817566, 0.668675364177229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 373}], {
             RGBColor[
             0.7153922477454293, 0.7673698568554512, 0.6829392251247295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 414}], {
             RGBColor[
             0.7172887186751338, 0.7738997570341931, 0.8489189163232489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 449}], {
             RGBColor[
             0.5988194865142104, 0.6830832109094143, 0.9628579298331226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 499}], {
             RGBColor[
             0.6655565528955242, 0.7357892270988213, 0.9693582603846058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 60}], {
             RGBColor[
             0.8344855522773214, 0.8714477994413923, 0.9781587819320604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 96}], {
             RGBColor[
             0.9673599569328516, 0.971485783963992, 0.7108802361082021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 100}], {
             RGBColor[
             0.96270356675827, 0.9558551152268445, 0.6862920950931597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 110}], {
             RGBColor[
             0.9673484045718895, 0.9714610746320169, 0.7096228329103884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 203}], {
             RGBColor[
             0.9368602176111783, 0.8614829923692751, 0.6233747345466688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 240}], {
             RGBColor[
             0.9679662045184586, 0.9727824862485721, 0.776866544475115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 264}], {
             RGBColor[
             0.9146875251371384, 0.934646134668568, 0.9860082189186974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 324}], {
             RGBColor[
             0.8961264279356113, 0.9198460195876321, 0.9842378448979286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 360}], {
             RGBColor[
             0.9675752791030623, 0.9719463363136618, 0.7343167255212412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 397}], {
             RGBColor[
             0.967980708978577, 0.9728135098221395, 0.7784452654478606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 457}], {
             RGBColor[
             0.9382050002424843, 0.8668146073801563, 0.6244567782179229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 495}], {
             RGBColor[
             0.9669005156322981, 0.9735863660509443, 0.8849948347201779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 170}], {
             RGBColor[
             0.9934577903341633, 0.9909945667821936, 0.716791772881707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 214}], {
             RGBColor[
             0.9945559659462253, 0.9907640865722789, 0.6488286738094249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 268}], {
             RGBColor[
             0.9939857227730897, 0.9895443940853706, 0.5867612235465447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 466}], {
             RGBColor[
             0.9925390270824115, 0.9906146345664556, 0.7320180576463119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 491}], {
             RGBColor[
             0.9831476675122417, 0.9535065596260863, 0.5003153099730169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 83}], {
             RGBColor[
             0.9422479208214409, 0.956279559894859, 0.9767627430189416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 97}], {
             RGBColor[
             0.8961862435764647, 0.919551228770636, 0.9723693391235712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 112}], {
             RGBColor[
             0.9750605561591857, 0.9787055473470021, 0.8150125064632937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 163}], {
             RGBColor[
             0.9226140529835958, 0.9406240466281064, 0.9748900471772073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 207}], {
             RGBColor[
             0.8945537980268329, 0.9182495610009136, 0.9722136350097459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 257}], {
             RGBColor[
             0.9742701550470676, 0.9770149592899925, 0.7289822231994785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 266}], {
             RGBColor[
             0.8965943549638727, 0.9198766457130667, 0.9724082651520274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 281}], {
             RGBColor[
             0.9681459017026794, 0.975763846162933, 0.9388048589246665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[
             0.9752107363465334, 0.9790267675821929, 0.8313586930514111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 317}], {
             RGBColor[
             0.8411261640401284, 0.8764003568210899, 0.9669179583665608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 322}], {
             RGBColor[
             0.9746999898955595, 0.977934332567947, 0.7757670938246223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 343}], {
             RGBColor[
             0.9701792561231357, 0.9771487032635318, 0.9294689183751692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 374}], {
             RGBColor[
             0.9127440337081092, 0.7346687930420632, 0.5868779663478388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 440}], {
             RGBColor[
             0.9737569615018218, 0.9786281763804529, 0.8701770814456184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 445}], {
             RGBColor[
             0.9747801972261496, 0.9781058879378741, 0.7844971667770826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 471}], {
             RGBColor[
             0.9746481221423784, 0.9778233926885269, 0.7701216089815277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 61}], {
             RGBColor[
             0.9673301629040032, 0.8961315881965447, 0.5052887985653212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 99}], {
             RGBColor[
             0.9947015620094137, 0.9917032102813057, 0.7103036847976214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 154}], {
             RGBColor[
             0.9927190203690903, 0.9912571420570467, 0.7703282052628387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 186}], {
             RGBColor[
             0.9937966396194163, 0.9897676727907896, 0.6118084671800456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 203}], {
             RGBColor[
             0.9630908693040025, 0.8793242017333902, 0.5018777634257504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 244}], {
             RGBColor[
             0.9888107976362696, 0.9894541239949001, 0.826729260522542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 264}], {
             RGBColor[
             0.9409181768299625, 0.9524873440326833, 0.864511247797779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 295}], {
             RGBColor[
             0.9692794965825722, 0.9748877116486229, 0.8597906586272955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 321}], {
             RGBColor[
             0.9933153342623723, 0.9915037331764869, 0.7604457408402701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 341}], {
             RGBColor[
             0.9769415570124852, 0.9806020637717796, 0.8468207889048645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 374}], {
             RGBColor[
             0.9323340736381263, 0.7475574450264808, 0.47662181879241994`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 391}], {
             RGBColor[
             0.9089058463482171, 0.926961580658102, 0.8614578831386854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 397}], {
             RGBColor[
             0.9942113606714011, 0.9906547191862548, 0.6569482943269422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 455}], {
             RGBColor[
             0.9649317823501489, 0.9716351412425226, 0.8668016869294931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 57}], {
             RGBColor[
             0.9207553205759844, 0.937709588042066, 0.9190194039026318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 60}], {
             RGBColor[
             0.8573305900433345, 0.8878889704404619, 0.9127701952663811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 73}], {
             RGBColor[
             0.9670996637462159, 0.9072405285110083, 0.5639358624237789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 91}], {
             RGBColor[
             0.8898718589004826, 0.9133104569944694, 0.9160136048306144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 136}], {
             RGBColor[
             0.9692153865220603, 0.9759648454285998, 0.9102766034238408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 200}], {
             RGBColor[
             0.9685431274812095, 0.9129633812144824, 0.5650973072274034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 256}], {
             RGBColor[
             0.9620186544795759, 0.8870960199147473, 0.5598475631012241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 298}], {
             RGBColor[
             0.9900212839028373, 0.9901415586995863, 0.8150366800268296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 434}], {
             RGBColor[
             0.9570763344697917, 0.8675013680064652, 0.555870856410191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 92}], {
             RGBColor[
             0.9906855608941822, 0.9904162543066475, 0.8040278911864962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 110}], {
             RGBColor[
             0.9896487842518336, 0.9876770155154228, 0.6532606402608154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 132}], {
             RGBColor[
             0.9371160467095174, 0.7854924466769105, 0.5490263081187502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 324}], {
             RGBColor[
             0.9184268076155553, 0.9360619604710378, 0.9278756522483558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 342}], {
             RGBColor[
             0.8567859319572655, 0.887663740324798, 0.9217965892824875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 360}], {
             RGBColor[
             0.9898756587830064, 0.9881622771970676, 0.6779545328716683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 457}], {
             RGBColor[
             0.9605053799224283, 0.8830305482635621, 0.5680945855683501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 494}], {
             RGBColor[
             0.9905437436053741, 0.9903576092131872, 0.806378170673427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 60}], {
             RGBColor[
             0.7903027589751057, 0.836382524989258, 0.9796612755161677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 73}], {
             RGBColor[
             0.9000718326779873, 0.8557340830598046, 0.6308269426735655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 91}], {
             RGBColor[
             0.822844027832254, 0.8618040115432656, 0.9829046850804011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 131}], {
             RGBColor[
             0.9167599472887131, 0.9353264659477489, 0.9525004253856664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 136}], {
             RGBColor[
             0.9021875554538317, 0.9244583999773961, 0.9771676836736273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 234}], {
             RGBColor[
             0.919221596206149, 0.9370753536002205, 0.9444371858622419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 240}], {
             RGBColor[
             0.923783411216243, 0.9377172117964379, 0.7783690380592223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 434}], {
             RGBColor[
             0.890048503401563, 0.8159949225552614, 0.6227619366599775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 495}], {
             RGBColor[
             0.9227177223300824, 0.9385210915988101, 0.8864973283042852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 74}], {
             RGBColor[
             0.8067034560570044, 0.4873780972632346, 0.572264130640581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 115}], {
             RGBColor[
             0.8865077965308136, 0.5503030860811541, 0.5620481455771273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 144}], {
             RGBColor[
             0.9062780512855251, 0.5631739844696513, 0.4435920959668095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 145}], {
             RGBColor[
             0.8889642451869979, 0.5064578515396547, 0.2328468688434464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 215}], {
             RGBColor[
             0.7217676070996927, 0.42077827963142406`, 0.5639675903844014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 375}], {
             RGBColor[
             0.8862509288739326, 0.5501115146032345, 0.5624829555184123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 402}], {
             RGBColor[
             0.831443763325348, 0.5069122035388947, 0.5746751374957599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 417}], {
             RGBColor[
             0.88161294651367, 0.47868644342620076`, 0.2197758101413146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 87}], {
             RGBColor[
             0.9889151880417391, 0.9738781584914593, 0.44479718043472516`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 91}], {
             RGBColor[
             0.8883261408548366, 0.8987142919394322, 0.6874647604843878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 188}], {
             RGBColor[
             0.9888662737684057, 0.9737735358067909, 0.4394731636462976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 200}], {
             RGBColor[
             0.9669974094355636, 0.8983672161594453, 0.33654846288117657`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 228}], {
             RGBColor[
             0.9767467922142932, 0.9332236114052912, 0.3641661080627017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 256}], {
             RGBColor[
             0.96047293643393, 0.87249985485971, 0.3312987187549974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 279}], {
             RGBColor[
             0.9256587989527771, 0.9282558371555079, 0.691085689668443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 287}], {
             RGBColor[
             0.9788173491678089, 0.9402080861993922, 0.3722098308352393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 298}], {
             RGBColor[
             0.9884755658571913, 0.9755453936445491, 0.5864878356806028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 335}], {
             RGBColor[
             0.9467261047149331, 0.9450543349134704, 0.6930951080990433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 409}], {
             RGBColor[
             0.9554618641260045, 0.8526326229996435, 0.32726669235105593`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 468}], {
             RGBColor[
             0.5818093577764606, 0.6327088516915977, 0.6642658174801959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 73}], {
             RGBColor[
             0.8366471021453372, 0.8059134654582005, 0.6245777340373148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 131}], {
             RGBColor[
             0.8533352167560632, 0.8855058483461449, 0.9462512167494157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.8387628249211816, 0.874637782375792, 0.9709184750373765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 240}], {
             RGBColor[
             0.860358680683593, 0.8878965941948338, 0.7721198294229715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 434}], {
             RGBColor[
             0.826623772868913, 0.7661743049536573, 0.6165127280237267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 495}], {
             RGBColor[
             0.8592929917974323, 0.8887004739972061, 0.8802481196680345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 99}], {
             RGBColor[
             0.9674773454155816, 0.8958186882544896, 0.47568092862057537`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 154}], {
             RGBColor[
             0.9654948037752583, 0.8953726200302305, 0.5357054490857928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 178}], {
             RGBColor[
             0.9656303485926644, 0.8954286712955709, 0.5334591206826308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 186}], {
             RGBColor[
             0.9665724230255843, 0.8938831507639733, 0.3771857110029996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 203}], {
             RGBColor[
             0.9358666527101704, 0.783439679706574, 0.26725500724870443`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 244}], {
             RGBColor[
             0.9615865810424375, 0.8935696019680839, 0.592106504345496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 264}], {
             RGBColor[
             0.9136939602361305, 0.856602822005867, 0.629888491620733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 288}], {
             RGBColor[
             0.9574946872731565, 0.8905178742948152, 0.5990330131600716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 295}], {
             RGBColor[
             0.9420552799887401, 0.8790031896218067, 0.6251679024502496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 321}], {
             RGBColor[
             0.9660911176685403, 0.8956192111496707, 0.5258229846632241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 341}], {
             RGBColor[
             0.9497173404186532, 0.8847175417449633, 0.6121980327278185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 391}], {
             RGBColor[
             0.8816816297543851, 0.8310770586312858, 0.6268351269616395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 397}], {
             RGBColor[
             0.9669871440775691, 0.8947701971594386, 0.4223255381498962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 455}], {
             RGBColor[
             0.9377075657563168, 0.8757506192157064, 0.6321789307524471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 96}], {
             RGBColor[
             0.9922349488469618, 0.9887663931707418, 0.6118500558556177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 108}], {
             RGBColor[
             0.9925269359833797, 0.9893909241311116, 0.6436310537189743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 110}], {
             RGBColor[
             0.9922233964859998, 0.9887416838387668, 0.610592652657804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 157}], {
             RGBColor[
             0.9916815264353773, 0.9869759981208276, 0.6032011698193713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 190}], {
             RGBColor[
             0.979122262196032, 0.9446106507860377, 0.5544107998675568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 356}], {
             RGBColor[
             0.8900954405732442, 0.9127387432954781, 0.8821919689168785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 378}], {
             RGBColor[
             0.9920505203516523, 0.9882207012443143, 0.604634641505445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 72}], {
             RGBColor[
             0.9943958766038382, 0.9904216716564282, 0.6314039368474826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 159}], {
             RGBColor[
             0.8421644599874796, 0.8744113543917547, 0.8286334084299589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 166}], {
             RGBColor[
             0.942104344828564, 0.953045380092417, 0.8384458148495326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 222}], {
             RGBColor[
             0.9949672342669904, 0.9918677036421635, 0.7098719089271586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 239}], {
             RGBColor[
             0.9899223273428666, 0.989781504980844, 0.7934790724604963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 272}], {
             RGBColor[
             0.937927019721724, 0.7718964344573016, 0.4549779645136986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 344}], {
             RGBColor[
             0.994751437269958, 0.9911821799685607, 0.6701045210885502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 387}], {
             RGBColor[
             0.9605720419367557, 0.8683836511318626, 0.4735456400069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 435}], {
             RGBColor[
             0.9950392861473956, 0.9917978596114139, 0.7014350950002703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 439}], {
             RGBColor[
             0.9941428483676615, 0.9898804698443253, 0.6038633748489213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 453}], {
             RGBColor[
             0.9363395995336969, 0.7646883301348755, 0.45365338219757945`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 74}], {
             RGBColor[
             0.8859131502556428, 0.885225611536244, 0.6702794554679183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 115}], {
             RGBColor[
             0.9657174907294519, 0.9481506003541635, 0.6600634704044648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 170}], {
             RGBColor[
             0.9840152325155878, 0.9604513091983051, 0.5688262087523029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 215}], {
             RGBColor[
             0.800977301298331, 0.8186257939044335, 0.6619829152117387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 223}], {
             RGBColor[
             0.9832844544447981, 0.9601491136858938, 0.5809370925783113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 268}], {
             RGBColor[
             0.9845431649545142, 0.9590011365014823, 0.4387956594171406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 86}], {
             RGBColor[
             0.9930746049417055, 0.9898072920727974, 0.6483579602886329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 177}], {
             RGBColor[
             0.7243864134073554, 0.7802707439464642, 0.860330953320448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 194}], {
             RGBColor[
             0.9912914070276496, 0.9843648354108026, 0.5927332669079513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 290}], {
             RGBColor[
             0.8859140543344375, 0.909311311304305, 0.8744792601223013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 297}], {
             RGBColor[
             0.9939852997896008, 0.9917551762670722, 0.7474814743249156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 350}], {
             RGBColor[
             0.9653751102329378, 0.8916405800663454, 0.5196688621391943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 412}], {
             RGBColor[
             0.975566811668584, 0.9798818237863854, 0.8628083158467601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 484}], {
             RGBColor[
             0.9759593419603134, 0.9326461797986041, 0.5331710893388915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 114}], {
             RGBColor[
             0.977061833443732, 0.9673888684390212, 0.663739423393549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 128}], {
             RGBColor[
             0.9882566074021573, 0.9720070282253106, 0.41244179748233245`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 179}], {
             RGBColor[
             0.8926084027777799, 0.9010884217852451, 0.6864733234377907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 245}], {
             RGBColor[
             0.9889149618960806, 0.973415181917963, 0.4840996212529255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 255}], {
             RGBColor[
             0.9881224867126814, 0.9742904140344311, 0.5846740955658186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 260}], {
             RGBColor[
             0.967647547157769, 0.9603677091414289, 0.679675354436577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 294}], {
             RGBColor[
             0.9862458846954594, 0.9735143908738377, 0.6157742474815322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 299}], {
             RGBColor[
             0.9891334344163472, 0.9738824725478528, 0.5078790068278244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 312}], {
             RGBColor[
             0.9878926981173626, 0.9741953905449692, 0.5884822872640753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 327}], {
             RGBColor[
             0.9709590129099859, 0.9628373948774047, 0.6740699066866651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 334}], {
             RGBColor[
             0.9824177062615661, 0.9523529360806817, 0.3861965382740986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 385}], {
             RGBColor[
             0.9846140375250565, 0.9728395801323168, 0.6428181781802091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 415}], {
             RGBColor[
             0.9850262193526207, 0.9730100279106042, 0.6359872586050954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 446}], {
             RGBColor[
             0.9297535249597494, 0.9305557117638736, 0.6900563880660868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 119}], {
             RGBColor[
             0.966758931206105, 0.9724974519515023, 0.8277353880327015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 120}], {
             RGBColor[
             0.9792601956560838, 0.9818208745093546, 0.8065740081708461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 124}], {
             RGBColor[
             0.9765655744956103, 0.9312423595627883, 0.47995378495791235`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 363}], {
             RGBColor[
             0.9024034055732347, 0.921341960334568, 0.8243439718511613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 381}], {
             RGBColor[
             0.9677187237249295, 0.9732132636405255, 0.8261107096523121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 95}], {
             RGBColor[
             0.8055889997363144, 0.8452775049872518, 0.8120567039740567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 286}], {
             RGBColor[
             0.7928656353079344, 0.8036955577399196, 0.6489443807658577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 319}], {
             RGBColor[
             0.7926012416670443, 0.8378605098331431, 0.9504152356444576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 330}], {
             RGBColor[
             0.7991229669447234, 0.8248030066421457, 0.673252932576855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 352}], {
             RGBColor[
             0.8049698328432382, 0.8439531696103375, 0.7446642087178523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 357}], {
             RGBColor[
             0.8046602782116891, 0.8432910635542281, 0.7109710974234639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 367}], {
             RGBColor[
             0.8051727511389221, 0.8443871913266184, 0.7667506129364747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 368}], {
             RGBColor[
             0.8031834066880055, 0.844811329829223, 0.8903472016153502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 375}], {
             RGBColor[
             0.7858457967587501, 0.832822310081563, 0.9618504417719861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 450}], {
             RGBColor[
             0.7679570151787629, 0.8190607162709462, 0.9775639321696891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 492}], {
             RGBColor[
             0.7392833519002491, 0.5830339328062237, 0.58478154928727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 101}], {
             RGBColor[
             0.9929320011600647, 0.9898139486467343, 0.6554916570085263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 103}], {
             RGBColor[
             0.9768338341713906, 0.9808867888729282, 0.8633514751152012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 129}], {
             RGBColor[
             0.8456548582721708, 0.877926939467178, 0.8734782787243922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 204}], {
             RGBColor[
             0.9932720230975853, 0.9905412211895994, 0.6925009465354783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 209}], {
             RGBColor[
             0.9834747750665174, 0.9585321426240154, 0.566062555097123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 231}], {
             RGBColor[
             0.9772638919194108, 0.9812075252372467, 0.8626234995248276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 233}], {
             RGBColor[
             0.9894755252227405, 0.9787740819440964, 0.5893743363074689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 259}], {
             RGBColor[
             0.9905868347080544, 0.9825227897859357, 0.5936915638047261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 275}], {
             RGBColor[
             0.9726089369593487, 0.9209617711055174, 0.528628390716589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 306}], {
             RGBColor[
             0.9819231069441257, 0.9532980016981872, 0.5600346174495687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 331}], {
             RGBColor[
             0.99263298080731, 0.9891743743477871, 0.6229451369508758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 346}], {
             RGBColor[
             0.9853730089406433, 0.9872552914342215, 0.8488968796043257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 348}], {
             RGBColor[
             0.9896286127342009, 0.9899791790801664, 0.8215442574915428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 355}], {
             RGBColor[
             0.8596175140705391, 0.8888346722969777, 0.8748699457659366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 372}], {
             RGBColor[
             0.9724761393409613, 0.9776368272034646, 0.8707279157942809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 404}], {
             RGBColor[
             0.9751982553226612, 0.9306134981087384, 0.5339098387818486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 418}], {
             RGBColor[
             0.9887172762902194, 0.976216330249387, 0.5864286823879205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 431}], {
             RGBColor[
             0.9933574690160043, 0.9907239813691904, 0.7018012074443118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 444}], {
             RGBColor[
             0.9125862558119022, 0.9303179682566645, 0.8801218528571031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 486}], {
             RGBColor[
             0.9921825253416539, 0.9910352875759084, 0.7792193162720868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 76}], {
             RGBColor[
             0.9184399012529495, 0.8754514123051644, 0.6337144682978737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 111}], {
             RGBColor[
             0.9381126280376877, 0.951323236906263, 0.9108353372910095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 130}], {
             RGBColor[
             0.938145962557247, 0.9513370215867588, 0.9102828980349388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 175}], {
             RGBColor[
             0.8855488684321957, 0.9115766463768901, 0.9889456356815118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 182}], {
             RGBColor[
             0.9412046299600626, 0.9526018591619898, 0.8595928635927874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 208}], {
             RGBColor[
             0.9178124654305488, 0.8729638383499392, 0.6332096187073585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[
             0.9207207524397432, 0.8844942272121997, 0.6355496947012262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 351}], {
             RGBColor[
             0.9119138621030507, 0.9325770118518837, 0.9906849499839343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 359}], {
             RGBColor[
             0.5330942210117806, 0.6091681030360365, 0.9613049912397444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 371}], {
             RGBColor[
             0.8381147291706108, 0.8740046419446114, 0.98435479954344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 403}], {
             RGBColor[
             0.9394740250771949, 0.9518862095684072, 0.888273465163775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 442}], {
             RGBColor[
             0.9238576288685938, 0.895602890983904, 0.6449899767537696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 463}], {
             RGBColor[
             0.9289235965668283, 0.9452628439640851, 0.96189190638602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 483}], {
             RGBColor[
             0.9396500333629711, 0.9519589935177822, 0.8853565523736208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 135}], {
             RGBColor[
             0.9717786000706381, 0.9780542960602128, 0.9139004539088715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 153}], {
             RGBColor[
             0.9092044987856763, 0.929893724452763, 0.9722967498848578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 169}], {
             RGBColor[
             0.949448256244379, 0.8876492222980064, 0.6150837694310114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 172}], {
             RGBColor[
             0.9708022317795356, 0.9776505426803213, 0.9300814032525788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 197}], {
             RGBColor[
             0.7052830524360203, 0.7673629780541036, 0.9540366424828537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 201}], {
             RGBColor[
             0.9749699520464308, 0.97748781467272, 0.7239055771811567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 211}], {
             RGBColor[
             0.9749017992530996, 0.9793458191847184, 0.8621409608750921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 236}], {
             RGBColor[
             0.9755842662461357, 0.9788017706291956, 0.7907698867112564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 289}], {
             RGBColor[
             0.9675713427111768, 0.9528962950640876, 0.6640645966300986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 308}], {
             RGBColor[
             0.8300563216251539, 0.8677264857295677, 0.9644971848780834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 362}], {
             RGBColor[
             0.9023834412808168, 0.9244547983510616, 0.9716461513308143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 369}], {
             RGBColor[
             0.9671414082668042, 0.9750146966031641, 0.9405052042977566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 466}], {
             RGBColor[
             0.9736494326043074, 0.9788279333910881, 0.882895917266574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 470}], {
             RGBColor[
             0.9551279351798135, 0.9101672566361961, 0.6196537724216613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 493}], {
             RGBColor[
             0.9759526747230802, 0.979589759109569, 0.8308688758730849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 128}], {
             RGBColor[
             0.9932252802716248, 0.987917884467268, 0.5039917501692175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 159}], {
             RGBColor[
             0.8416482654168942, 0.8733072664005492, 0.7724488150053614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 179}], {
             RGBColor[
             0.8975770756472474, 0.9169992780272025, 0.7780232761246757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 222}], {
             RGBColor[
             0.994451039696405, 0.990763615650958, 0.6536873155025611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 245}], {
             RGBColor[
             0.9938836347655482, 0.9893260381599204, 0.5756495739398104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 294}], {
             RGBColor[
             0.9912145575649269, 0.9894252471157952, 0.7073242001684172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 344}], {
             RGBColor[
             0.9942352426993726, 0.9900780919773555, 0.6139199276639529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 438}], {
             RGBColor[
             0.936921918207346, 0.9482205653255321, 0.7818161520463515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 439}], {
             RGBColor[
             0.9936266537970762, 0.9887763818531201, 0.547678781424324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 453}], {
             RGBColor[
             0.9358234049631116, 0.7635842421436702, 0.3974687887729821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 91}], {
             RGBColor[
             0.8691883710024855, 0.831334952012208, 0.6278211436015482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 136}], {
             RGBColor[
             0.9485318986240632, 0.8939893404463385, 0.6220841421947744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 200}], {
             RGBColor[
             0.9478596395832124, 0.830987876232221, 0.276904845998337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 240}], {
             RGBColor[
             0.9701277543864745, 0.9072481522653804, 0.4232854965803694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 256}], {
             RGBColor[
             0.9413351665815787, 0.8051205149324858, 0.2716551018721578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 298}], {
             RGBColor[
             0.96933779600484, 0.9081660537173248, 0.5268442187977632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 434}], {
             RGBColor[
             0.9363928465717946, 0.7855258630242038, 0.2676783951811246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 115}], {
             RGBColor[
             0.875892252587818, 0.9035541833443888, 0.9700942762177083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 144}], {
             RGBColor[
             0.8956625073425295, 0.9164250817328858, 0.8516382266073905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 215}], {
             RGBColor[
             0.7111520631566971, 0.7740293768946587, 0.9720137210249824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 268}], {
             RGBColor[
             0.8947179268128803, 0.9144047194917075, 0.7488264652303842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 402}], {
             RGBColor[
             0.8208282193823524, 0.8601633008021292, 0.982721268136341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 417}], {
             RGBColor[
             0.8709974025706744, 0.8319375406894354, 0.6278219407818957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 104}], {
             RGBColor[
             0.9409481016208348, 0.8035859313448885, 0.2713436603191609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 125}], {
             RGBColor[
             0.9083072357368112, 0.8594805037998154, 0.6309809090779681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 147}], {
             RGBColor[
             0.9392361936341505, 0.8841424152829567, 0.6339309406928229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 303}], {
             RGBColor[
             0.9111099177818671, 0.6776131155922768, 0.2469381705286229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 310}], {
             RGBColor[
             0.9639594832763654, 0.8867392361907551, 0.3319355364245806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 323}], {
             RGBColor[
             0.9161029066154934, 0.7002851117436042, 0.2511044428007564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 379}], {
             RGBColor[
             0.961762643549245, 0.9009906185521885, 0.5974642056285455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 400}], {
             RGBColor[
             0.9692452435106875, 0.9037348249791258, 0.423431413132926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 408}], {
             RGBColor[
             0.8393251392841963, 0.8051709082171926, 0.6242169418100783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 111}], {
             RGBColor[
             0.969291087267076, 0.9138324431393543, 0.5554408231093946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 130}], {
             RGBColor[
             0.9693244217866355, 0.9138462278198503, 0.5548883838533238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 175}], {
             RGBColor[
             0.916727327661584, 0.8740858526099815, 0.6335511214998968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.9723830891894509, 0.9151110653950811, 0.5041983494111724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 351}], {
             RGBColor[
             0.9430923213324389, 0.895086218084975, 0.6352904358023193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 359}], {
             RGBColor[
             0.564272680241169, 0.571677309269128, 0.6059104770581294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 371}], {
             RGBColor[
             0.8692931883999993, 0.8365138481777028, 0.628960285361825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 460}], {
             RGBColor[
             0.9690621258024109, 0.913737761689674, 0.5592353071121716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 463}], {
             RGBColor[
             0.9601020557962168, 0.9077720501971765, 0.606497392204405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 483}], {
             RGBColor[
             0.9708284925923595, 0.9144681997508737, 0.5299620381920058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 87}], {
             RGBColor[
             0.993621601148623, 0.98876557474898, 0.547128831821533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 184}], {
             RGBColor[
             0.993869262108908, 0.9892952965006656, 0.5740851989622866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 253}], {
             RGBColor[
             0.9924651864287438, 0.9852570256747566, 0.5092772266142663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 287}], {
             RGBColor[
             0.9835237622746928, 0.9550955024569128, 0.4745414822220472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 301}], {
             RGBColor[
             0.9509398468846583, 0.9595489087388969, 0.7953797680920525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 336}], {
             RGBColor[
             0.9942661643559909, 0.990144230274203, 0.6172855591605085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 354}], {
             RGBColor[
             0.9745975014674473, 0.9779128279434406, 0.7802991260396542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 388}], {
             RGBColor[
             0.9943334515673703, 0.9902881508155628, 0.6246093568706191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 409}], {
             RGBColor[
             0.9601682772328884, 0.867520039257164, 0.4295983437378639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 436}], {
             RGBColor[
             0.9686618678237052, 0.9734860420906457, 0.7903466055373181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 473}], {
             RGBColor[
             0.9657678341216636, 0.8897204163794383, 0.4341038786490655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 154}], {
             RGBColor[
             0.9921307618708437, 0.9893712081594679, 0.6606721200144325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 171}], {
             RGBColor[
             0.9586770153868127, 0.9652308873081561, 0.7566051250451349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 192}], {
             RGBColor[
             0.9938757556331996, 0.9893091854925291, 0.574791979008028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.8226825254064585, 0.8581504281570734, 0.7432735160379585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 219}], {
             RGBColor[
             0.9926730229064926, 0.9895954470331816, 0.6516854513271553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 258}], {
             RGBColor[
             0.9548236184902736, 0.8469936221774215, 0.38604298071119114`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 262}], {
             RGBColor[
             0.9942376444990961, 0.9900832291841047, 0.614181348741663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 376}], {
             RGBColor[
             0.9789311801222396, 0.9400521276293123, 0.4185643969139114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 497}], {
             RGBColor[
             0.9858002619365309, 0.9632231535260263, 0.44524948264517783`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 127}], {
             RGBColor[
             0.8884027228052775, 0.8359632591084798, 0.6273702696167578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 147}], {
             RGBColor[
             0.9368221687343867, 0.8745716109815045, 0.6319885595940259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 184}], {
             RGBColor[
             0.9667206202732768, 0.8939274620166539, 0.40945108551507176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 221}], {
             RGBColor[
             0.9511048905696073, 0.8852716553466322, 0.6094763058603434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 234}], {
             RGBColor[
             0.9622614804999843, 0.8935052157698959, 0.5866947992058218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 253}], {
             RGBColor[
             0.9653165445931126, 0.8898891911907448, 0.34464311316705154`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 301}], {
             RGBColor[
             0.923791205049027, 0.864181074254885, 0.6307456546448377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 316}], {
             RGBColor[
             0.5593671290477132, 0.5522284334651065, 0.6019633554197891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 336}], {
             RGBColor[
             0.9671175225203597, 0.8947763957901911, 0.45265144571329374`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 388}], {
             RGBColor[
             0.967184809731739, 0.8949203163315509, 0.45997524342340435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 436}], {
             RGBColor[
             0.941513225988074, 0.8781182076066338, 0.6257124920901033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 81}], {
             RGBColor[
             0.9357010883196132, 0.786001094327252, 0.5707995955625575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 171}], {
             RGBColor[
             0.9060597915523753, 0.7635923641795473, 0.6104936640680885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 192}], {
             RGBColor[
             0.9412585317987621, 0.7876706623639202, 0.4286805180309817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 208}], {
             RGBColor[
             0.9182534518350017, 0.7089763333993955, 0.25284335861334517`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 219}], {
             RGBColor[
             0.940055799072055, 0.7879569239045727, 0.505573990350109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 238}], {
             RGBColor[
             0.9211617388441962, 0.7205067222616559, 0.25518343460721293`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 251}], {
             RGBColor[
             0.9178229248092571, 0.7726675892540344, 0.6010626630137584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 258}], {
             RGBColor[
             0.9022063946558361, 0.6453550990488127, 0.2399315197341448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 272}], {
             RGBColor[
             0.8845426915507456, 0.5686171527189775, 0.2253719305233896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 293}], {
             RGBColor[
             0.9415952939438665, 0.7883909625404227, 0.4653349992705397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 403}], {
             RGBColor[
             0.9399150114816478, 0.7878987046178634, 0.5079072050697617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 447}], {
             RGBColor[
             0.578479477993175, 0.4924198760931997, 0.5834982408659979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 471}], {
             RGBColor[
             0.9410326797397115, 0.7871875876467569, 0.40409791520065635`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 483}], {
             RGBColor[
             0.940091019767424, 0.7879714885672384, 0.5049902922796075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 497}], {
             RGBColor[
             0.9331830381020935, 0.7615846303974175, 0.2991380216681314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 121}], {
             RGBColor[
             0.7322114231961874, 0.7883523492009681, 0.9327604373079008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.9861446224488462, 0.9883834147924815, 0.8723397712120209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 208}], {
             RGBColor[
             0.965811125322148, 0.910010231555662, 0.5952664918844407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 213}], {
             RGBColor[
             0.9885479077847532, 0.989377235040495, 0.8325111136929626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 251}], {
             RGBColor[
             0.9653805982964034, 0.973701487410301, 0.943485796284854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 442}], {
             RGBColor[
             0.9718562887601929, 0.9326492841896267, 0.6070468499308518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 447}], {
             RGBColor[
             0.6260371514803211, 0.6934537742494662, 0.9259213741370935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 454}], {
             RGBColor[
             0.680751996576269, 0.7445368667711485, 0.9292725791996244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 500}], {
             RGBColor[
             0.8660462225576613, 0.8953744121608666, 0.9444115651016818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 126}], {
             RGBColor[
             0.6593629893843529, 0.726490882421821, 0.9349164507221919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 149}], {
             RGBColor[
             0.6631627506668747, 0.7293247381647878, 0.9284844460073448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 173}], {
             RGBColor[
             0.30613052030376275`, 0.435884759197303, 0.9408625204310788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 242}], {
             RGBColor[
             0.6675660537922357, 0.7313635877219666, 0.8652714846348424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 249}], {
             RGBColor[
             0.6486715666322697, 0.7185172368389154, 0.9530142406718239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 269}], {
             RGBColor[
             0.6649181184869928, 0.7302685984244155, 0.9091546252796183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 282}], {
             RGBColor[
             0.6679953162056733, 0.7291800402577129, 0.6865334669266245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 323}], {
             RGBColor[
             0.6155080023948377, 0.5271313551666414, 0.5855017169929821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 384}], {
             RGBColor[
             0.649267980310924, 0.7189620411839183, 0.9520046678834622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 411}], {
             RGBColor[
             0.6424927529494531, 0.7139090877111498, 0.9634733605441288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 419}], {
             RGBColor[
             0.6692890810653176, 0.7319472724727996, 0.8273517877077028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 499}], {
             RGBColor[
             0.6170072765844674, 0.6937382841157621, 0.9662647434285048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 97}], {
             RGBColor[
             0.8830598647601047, 0.9095919824109695, 0.9887082322893079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 163}], {
             RGBColor[
             0.9094876741672357, 0.9306648002684398, 0.9912289403429442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 207}], {
             RGBColor[
             0.8814274192104727, 0.9082903146412471, 0.9885525281754828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 209}], {
             RGBColor[
             0.9518570462197466, 0.936138580788461, 0.6744494608634841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 231}], {
             RGBColor[
             0.9456461630726399, 0.9588139634016923, 0.9710104052911888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 233}], {
             RGBColor[
             0.9578577963759698, 0.956380520108542, 0.6977612420738301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 257}], {
             RGBColor[
             0.9611437762307076, 0.9670557129303259, 0.7453211163652154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 317}], {
             RGBColor[
             0.8279997852237683, 0.8664411104614232, 0.9832568515322977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 326}], {
             RGBColor[
             0.9612849864390489, 0.9673577472874257, 0.7606909760947729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 343}], {
             RGBColor[
             0.9570528773067757, 0.9671894569038653, 0.9458078115409061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 346}], {
             RGBColor[
             0.9537552800938724, 0.9648617295986671, 0.9572837853706868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 355}], {
             RGBColor[
             0.8279997852237683, 0.8664411104614232, 0.9832568515322977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 395}], {
             RGBColor[
             0.7496919931521571, 0.8041620408522444, 0.9762069656107644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 440}], {
             RGBColor[
             0.9606305826854618, 0.9686689300207862, 0.8865159746113553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 89}], {
             RGBColor[
             0.9878435962877522, 0.9692725745587165, 0.5248892634131955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 176}], {
             RGBColor[
             0.9878351255119944, 0.9697330723295574, 0.5587575954172773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 244}], {
             RGBColor[
             0.9820051318819685, 0.9671353526141572, 0.6470073678273254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 245}], {
             RGBColor[
             0.9874153177435385, 0.9683565300582464, 0.47827378690433464`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 260}], {
             RGBColor[
             0.9661479030052268, 0.9553090572817124, 0.6738495200879862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 261}], {
             RGBColor[
             0.9751071125760631, 0.9619908211102829, 0.6586839152206512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 262}], {
             RGBColor[
             0.9880202372430418, 0.9696503917009407, 0.5441155412948523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 299}], {
             RGBColor[
             0.987633790263805, 0.9688238206881363, 0.5020531724792335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 328}], {
             RGBColor[
             0.9872229539477293, 0.9679450833499739, 0.45733617486224165`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 376}], {
             RGBColor[
             0.9727137728661852, 0.9196192901461484, 0.34849858946710077`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 391}], {
             RGBColor[
             0.9021001805939162, 0.9046428092773591, 0.6817359904434686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 407}], {
             RGBColor[
             0.9858033801603654, 0.9688928934131851, 0.5924288738821908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 448}], {
             RGBColor[
             0.9722743810093946, 0.9598781745460337, 0.6634789908683025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 455}], {
             RGBColor[
             0.9581261165958478, 0.9493163698617797, 0.6870797942342763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 475}], {
             RGBColor[
             0.9705823401630631, 0.9124294671543196, 0.3402183759027634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 478}], {
             RGBColor[
             0.9848611299960275, 0.9685032487555065, 0.6080443975705304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 482}], {
             RGBColor[
             0.9829233120302643, 0.954058463060381, 0.3881607212098537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 146}], {
             RGBColor[
             0.8872927617983284, 0.5587670212223683, 0.2267119199084686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 166}], {
             RGBColor[
             0.9078152792712675, 0.8301053255866792, 0.6244439311578509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 239}], {
             RGBColor[
             0.9556332617855701, 0.8668414504751062, 0.5794771887688146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 332}], {
             RGBColor[
             0.915324662122666, 0.836093103635617, 0.6251601827979225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 387}], {
             RGBColor[
             0.9262829763794593, 0.7454435966261246, 0.2595437563152183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 489}], {
             RGBColor[
             0.9597133792012329, 0.8666401062156361, 0.3745794247738353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 177}], {
             RGBColor[
             0.7247427383824914, 0.7788212001376849, 0.7383484379603721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 194}], {
             RGBColor[
             0.9916477320027856, 0.9829152916020231, 0.47075075154787527`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 220}], {
             RGBColor[
             0.9668654230775384, 0.8946869202809373, 0.3985987800370061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 254}], {
             RGBColor[
             0.9660420395250435, 0.8914224788715983, 0.3979362663033726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 290}], {
             RGBColor[
             0.8862703793095734, 0.9078617674955256, 0.7524967447622253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 297}], {
             RGBColor[
             0.9943416247647368, 0.9903056324582927, 0.6254989589648396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 350}], {
             RGBColor[
             0.9657314352080737, 0.8901910362575658, 0.3976863467791183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 377}], {
             RGBColor[
             0.9783824581421388, 0.9381684080356407, 0.419217667536034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 412}], {
             RGBColor[
             0.97592313664372, 0.978432279977606, 0.7408258004866842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 426}], {
             RGBColor[
             0.7598756915905089, 0.807343714273459, 0.7411142327331552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 476}], {
             RGBColor[
             0.9931612604259921, 0.9877809524908587, 0.49702358505677846`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 91}], {
             RGBColor[
             0.8925496133436546, 0.9125687470476962, 0.737231305958721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 161}], {
             RGBColor[
             0.9759057897880064, 0.9782157624037421, 0.724701936761416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 184}], {
             RGBColor[
             0.993386321490842, 0.9882623353514088, 0.521520093049812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 228}], {
             RGBColor[
             0.980970264703111, 0.9470780665135551, 0.41393265353703507`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 253}], {
             RGBColor[
             0.9919822458106777, 0.9842240645254998, 0.4567121207017917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 256}], {
             RGBColor[
             0.9646964089227478, 0.886354309967974, 0.38106526422933074`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 285}], {
             RGBColor[
             0.9844554697162514, 0.95883448138793, 0.42747201688734415`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 287}], {
             RGBColor[
             0.9830408216566269, 0.954062541307656, 0.42197637630957263`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 336}], {
             RGBColor[
             0.9937832237379248, 0.9891112691249462, 0.5647204532480339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 354}], {
             RGBColor[
             0.9741145608493813, 0.9768798667941838, 0.7277340201271796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 388}], {
             RGBColor[
             0.9938505109493042, 0.989255189666306, 0.5720442509581445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 409}], {
             RGBColor[
             0.9596853366148224, 0.8664870781079073, 0.3770332378253893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 436}], {
             RGBColor[
             0.9681789272056391, 0.9724530809413889, 0.7377814996248435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 473}], {
             RGBColor[
             0.9652848935035975, 0.8886874552301816, 0.38153877273659087`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 133}], {
             RGBColor[
             0.9473958156330666, 0.8147829125470338, 0.4677856386005401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 241}], {
             RGBColor[
             0.9248116866999141, 0.939317627082868, 0.8417366778183344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 271}], {
             RGBColor[
             0.9943825626827818, 0.9903931945255325, 0.6299547987044936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 304}], {
             RGBColor[
             0.9509050657302152, 0.8299743703540694, 0.4706753965242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 307}], {
             RGBColor[
             0.9107367679915546, 0.9280946689583126, 0.8403941995071028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 311}], {
             RGBColor[
             0.9618494418214505, 0.9688505276537008, 0.8452693719658209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 337}], {
             RGBColor[
             0.9932926982533181, 0.9912536206586751, 0.7433207530975907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 423}], {
             RGBColor[
             0.9912505862185785, 0.9904091548524248, 0.777163834329762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 427}], {
             RGBColor[
             0.9603502555782448, 0.8674214006785717, 0.4782752179830251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 433}], {
             RGBColor[
             0.9944765597353855, 0.9917431778053623, 0.7237011046044282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 465}], {
             RGBColor[
             0.9863053216166222, 0.963923900252202, 0.5324941665876033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 469}], {
             RGBColor[
             0.8947077915863686, 0.9155202819257877, 0.8388104939404479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 176}], {
             RGBColor[
             0.9947356738105133, 0.9916270794263988, 0.7031790894785392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 178}], {
             RGBColor[
             0.9929494477307144, 0.9908884290384856, 0.732781478225722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 244}], {
             RGBColor[
             0.9889056801804874, 0.9890293597109986, 0.7914288618885873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 261}], {
             RGBColor[
             0.982007660874582, 0.9838848282071243, 0.8031054092819132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 262}], {
             RGBColor[
             0.9949207855415607, 0.9915443987977821, 0.6885370353561143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 299}], {
             RGBColor[
             0.994534338562324, 0.9907178277849777, 0.6464746665404956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 328}], {
             RGBColor[
             0.9941235022462482, 0.9898390904468153, 0.6017576689235036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 376}], {
             RGBColor[
             0.9796143211647041, 0.9415132972429898, 0.4929200835283628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 391}], {
             RGBColor[
             0.9090007288924351, 0.9265368163742005, 0.8261574845047306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 407}], {
             RGBColor[
             0.9927039284588843, 0.9907869005100265, 0.7368503679434528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 448}], {
             RGBColor[
             0.9791749293079135, 0.9817721816428752, 0.8079004849295645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 455}], {
             RGBColor[
             0.9650266648943667, 0.9712103769586211, 0.8315012882955384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 475}], {
             RGBColor[
             0.977482888461582, 0.934323474251161, 0.4846398699640254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 478}], {
             RGBColor[
             0.9917616782945464, 0.990397255852348, 0.7524658916317923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 482}], {
             RGBColor[
             0.9898238603287832, 0.9759524701572224, 0.5325822152711157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 137}], {
             RGBColor[
             0.9365697321264702, 0.7738123629239414, 0.31019509076835733`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 148}], {
             RGBColor[
             0.9224442243876665, 0.9243116039299714, 0.6887474212736473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 229}], {
             RGBColor[
             0.9767702963422751, 0.9333028963480063, 0.3642574171615298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 232}], {
             RGBColor[
             0.9885434289106976, 0.9739866428036454, 0.5743951703225363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 263}], {
             RGBColor[
             0.9869001556206873, 0.9674732902981574, 0.4036100075947503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 267}], {
             RGBColor[
             0.9893584325405615, 0.9741644386626729, 0.5493141773287392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 280}], {
             RGBColor[
             0.9855847948512801, 0.9630362695615514, 0.3985000793906422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 342}], {
             RGBColor[
             0.8552487335133643, 0.8714842843864967, 0.6821385541498122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 393}], {
             RGBColor[
             0.970606458030171, 0.9125108223832186, 0.34031206926220003`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 480}], {
             RGBColor[
             0.9452133211808763, 0.8123176547805537, 0.3173690669721172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 485}], {
             RGBColor[
             0.9820769544042509, 0.9707049408336124, 0.6543496426467716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 200}], {
             RGBColor[
             0.870631834737479, 0.837057804715682, 0.6289825884051725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 228}], {
             RGBColor[
             0.8803812175162085, 0.8719141999615281, 0.6566002335866976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 256}], {
             RGBColor[
             0.8641073617358452, 0.8111904434159469, 0.6237328442789933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 287}], {
             RGBColor[
             0.8824517744697243, 0.878898674755629, 0.6646439563592351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 298}], {
             RGBColor[
             0.8921099911591066, 0.914235982200786, 0.8789219612045986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 336}], {
             RGBColor[
             0.8931941765510223, 0.9139474025729191, 0.8073880332976965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 132}], {
             RGBColor[
             0.9411077721316246, 0.7871431277216159, 0.48287308762018816`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 250}], {
             RGBColor[
             0.97774138808845, 0.9811781571906462, 0.8445524660875989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 342}], {
             RGBColor[
             0.8607776573793725, 0.8893144213695034, 0.8556433687839256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 356}], {
             RGBColor[
             0.891512553761185, 0.9133247560168394, 0.8587067360213279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 365}], {
             RGBColor[
             0.9851523604604715, 0.9867052482513463, 0.8320076229529247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 457}], {
             RGBColor[
             0.9644971053445355, 0.8846812293082674, 0.501941365069788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 485}], {
             RGBColor[
             0.9876058782702591, 0.9885350778166191, 0.827854457280885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 494}], {
             RGBColor[
             0.994535469027481, 0.9920082902578926, 0.7402249501748649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 141}], {
             RGBColor[
             0.9133639693312048, 0.6932627697092675, 0.24909909454809492`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 151}], {
             RGBColor[
             0.9593858352347102, 0.865486878978903, 0.36571333189248467`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 160}], {
             RGBColor[
             0.960107057706475, 0.8678110822585012, 0.5010266596478555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 167}], {
             RGBColor[
             0.9308656303926311, 0.7636122927094271, 0.26323106730293117`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 172}], {
             RGBColor[
             0.9552991245781561, 0.8658228783516961, 0.5807065541161782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 201}], {
             RGBColor[
             0.9594668448450514, 0.8656601503440947, 0.3745307280447562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 218}], {
             RGBColor[
             0.9598197997756448, 0.8664150852514166, 0.4129476940545186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 235}], {
             RGBColor[
             0.9598387168000955, 0.8664555468539118, 0.4150066954236161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 236}], {
             RGBColor[
             0.9600811590447562, 0.8669741063005705, 0.4413950375748559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 274}], {
             RGBColor[
             0.9600843180972073, 0.8669808631943339, 0.44173888093873703`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 284}], {
             RGBColor[
             0.959235748008058, 0.8651658575772401, 0.34937726350238124`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 289}], {
             RGBColor[
             0.9520682355097974, 0.8410686307354622, 0.31468974749369805`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 300}], {
             RGBColor[
             0.8851033899235885, 0.8112102469864266, 0.6221018156745322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 305}], {
             RGBColor[
             0.9542443960790195, 0.8484093313222483, 0.3231437203716845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 308}], {
             RGBColor[
             0.8145532144237744, 0.7558988214009423, 0.6151223357416828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 389}], {
             RGBColor[
             0.9585715100237293, 0.8630057027124247, 0.3399537409399798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 432}], {
             RGBColor[
             0.9159467798266573, 0.7044640216275829, 0.25122700994711783`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 456}], {
             RGBColor[
             0.9600702044228724, 0.8669506754720429, 0.44020269458687467`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 493}], {
             RGBColor[
             0.9604495675217007, 0.8677620947809439, 0.4814940267366844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 123}], {
             RGBColor[
             0.9303244879155468, 0.7603369031424245, 0.26610007899068966`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 139}], {
             RGBColor[
             0.9111178860661479, 0.6848284883750497, 0.24731619155471998`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 158}], {
             RGBColor[
             0.9483270737992113, 0.8200595654190781, 0.42143405296415787`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 193}], {
             RGBColor[
             0.8762773330251689, 0.7667605420006189, 0.6129668882750583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 401}], {
             RGBColor[
             0.9434295742664079, 0.8045434366244837, 0.31701086477588647`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 410}], {
             RGBColor[
             0.9265819128860313, 0.8064867630789997, 0.604406896591151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 428}], {
             RGBColor[
             0.9358939771550208, 0.8134316853637062, 0.5886440007590872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 437}], {
             RGBColor[
             0.9040423986544446, 0.7888996516707742, 0.6156151450209454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 122}], {
             RGBColor[
             0.9836927210090042, 0.9553169116538611, 0.5048341848112687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 185}], {
             RGBColor[
             0.9920823741381001, 0.9904652730911019, 0.7424554855424124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 212}], {
             RGBColor[
             0.9497069707639223, 0.9589446413740371, 0.8259684922793253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 224}], {
             RGBColor[
             0.94196418254979, 0.9527707522244753, 0.8252299782273926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 286}], {
             RGBColor[
             0.9819458992746137, 0.9494244717705141, 0.4980481122327669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 319}], {
             RGBColor[
             0.9816815056337237, 0.9835894238637376, 0.7995189671113667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 330}], {
             RGBColor[
             0.9882032309114028, 0.9705319206727403, 0.5223566640437641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 357}], {
             RGBColor[
             0.9937405421783685, 0.9890199775848226, 0.5600748288903731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 367}], {
             RGBColor[
             0.9942530151056015, 0.990116105357213, 0.6158543444033839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 368}], {
             RGBColor[
             0.9922636706546848, 0.9905402438598176, 0.7394509330822593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 492}], {
             RGBColor[
             0.9283636158669285, 0.7287628468368184, 0.4338852807541792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 110}], {
             RGBColor[
             0.9926152853925541, 0.9866131671008784, 0.43759757203438643`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 136}], {
             RGBColor[
             0.9716372295767118, 0.9746757668983917, 0.703639929213518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.9920734153419317, 0.9848474813829393, 0.43020608919595377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 240}], {
             RGBColor[
             0.9932330853391231, 0.9879345787174336, 0.5048412835991132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 360}], {
             RGBColor[
             0.9928421599237269, 0.9870984287825233, 0.4622914646452392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 457}], {
             RGBColor[
             0.9634718810631488, 0.8819666998490178, 0.352431517341921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 163}], {
             RGBColor[
             0.8634259969222595, 0.8939364691442168, 0.9868355364475736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 207}], {
             RGBColor[
             0.8353657419654966, 0.8715619835170241, 0.9841591242801122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 209}], {
             RGBColor[
             0.9057953689747704, 0.899410249664238, 0.6700560569681137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 231}], {
             RGBColor[
             0.8995844858276638, 0.9220856322774693, 0.9666170013958182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 233}], {
             RGBColor[
             0.9117961191309936, 0.919652188984319, 0.6933678381784595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 257}], {
             RGBColor[
             0.9150820989857313, 0.9303273818061029, 0.7409277124698448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 281}], {
             RGBColor[
             0.9089578456413432, 0.9290762686790434, 0.9507503481950328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 317}], {
             RGBColor[
             0.7819381079787922, 0.8297127793372002, 0.9788634476369271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 322}], {
             RGBColor[
             0.9155119338342232, 0.9312467550840574, 0.7877125830949886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 326}], {
             RGBColor[
             0.9152233091940727, 0.9306294161632027, 0.7562975721994023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 343}], {
             RGBColor[
             0.9109912000617995, 0.9304611257796422, 0.9414144076455355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 355}], {
             RGBColor[
             0.7819381079787922, 0.8297127793372002, 0.9788634476369271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 395}], {
             RGBColor[
             0.7036303159071808, 0.7674337097280214, 0.9718135617153938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 440}], {
             RGBColor[
             0.9145689054404855, 0.9319405988965632, 0.8821225707159848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 105}], {
             RGBColor[
             0.9502504031368864, 0.8862025617305563, 0.6121394057222457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 276}], {
             RGBColor[
             0.8830110792972172, 0.8332071643633067, 0.6272015415989478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 347}], {
             RGBColor[
             0.8220249772972018, 0.7855218713767027, 0.6211342915344584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 382}], {
             RGBColor[
             0.9665797819046555, 0.8970210040679241, 0.5235952717186831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 425}], {
             RGBColor[
             0.9626989908567568, 0.8954161972378373, 0.5879100225476568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 462}], {
             RGBColor[
             0.8859346176116298, 0.8355383144578858, 0.6274803912932498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 131}], {
             RGBColor[
             0.9873205747953313, 0.9879200498219433, 0.799893090735895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 143}], {
             RGBColor[
             0.9943251216984106, 0.9902703340681369, 0.6237027020403534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 178}], {
             RGBColor[
             0.9930017476980748, 0.9910002933803319, 0.7384740069149309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 186}], {
             RGBColor[
             0.9939438221309947, 0.9894547728487344, 0.5822005972352997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 277}], {
             RGBColor[
             0.9936256067758649, 0.9912582751414452, 0.728135047500411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 288}], {
             RGBColor[
             0.9848660863785669, 0.9860894963795762, 0.8040478993923719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 295}], {
             RGBColor[
             0.9694266790941506, 0.9745748117065678, 0.8301827886825497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 313}], {
             RGBColor[
             0.9885391454042546, 0.9715542693227011, 0.5330806935794116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 321}], {
             RGBColor[
             0.9934625167739507, 0.9911908332344317, 0.7308378708955242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 341}], {
             RGBColor[
             0.9770887395240636, 0.9802891638297244, 0.8172129189601187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 373}], {
             RGBColor[
             0.9925445939680474, 0.9850655878524213, 0.5486411048842543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 498}], {
             RGBColor[
             0.9838200043066083, 0.9556354982933174, 0.5147477215500744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 203}], {
             RGBColor[
             0.9574707082572612, 0.8610044161009891, 0.3267613326556245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 257}], {
             RGBColor[
             0.9882400339303437, 0.971583825642009, 0.4436096448739338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 264}], {
             RGBColor[
             0.9352980157832212, 0.9341675584002821, 0.6893948170276532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 281}], {
             RGBColor[
             0.9821157805859553, 0.9703327125149495, 0.6534322805991217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 324}], {
             RGBColor[
             0.9167369185816941, 0.9193674433193462, 0.6876244430068843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 360}], {
             RGBColor[
             0.9881857697491452, 0.9714677600453758, 0.4377033236301968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 374}], {
             RGBColor[
             0.926713912591385, 0.7292376593940797, 0.3015053880222941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 397}], {
             RGBColor[
             0.9885911996246599, 0.9723349335538536, 0.4818318635568163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 457}], {
             RGBColor[
             0.9588154908885672, 0.8663360311118703, 0.32784337632687865`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 103}], {
             RGBColor[
             0.977408835632833, 0.9795933003133612, 0.7425153074717711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 129}], {
             RGBColor[
             0.8462298597336133, 0.876633450907611, 0.7526421110809622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[
             0.9938470245590276, 0.9892477326300325, 0.5716647788920484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 276}], {
             RGBColor[
             0.909373767396813, 0.9260044380782251, 0.7589244310481174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 306}], {
             RGBColor[
             0.982498108405568, 0.9520045131386203, 0.4391984498061387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 331}], {
             RGBColor[
             0.9932079822687523, 0.9878808857882202, 0.5021089693074458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 347}], {
             RGBColor[
             0.8483876653967977, 0.8783191450916211, 0.752857180983628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 390}], {
             RGBColor[
             0.9917167639472868, 0.9893114168290789, 0.6756312825573498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 431}], {
             RGBColor[
             0.9939324704774468, 0.9894304928096234, 0.5809650398008818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 486}], {
             RGBColor[
             0.9927575268030961, 0.9897417990163415, 0.6583831486286569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 134}], {
             RGBColor[
             0.9944684614013927, 0.9905769231989485, 0.6393043441198432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 174}], {
             RGBColor[
             0.9574019986974234, 0.9644982315316724, 0.7795061154701539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 210}], {
             RGBColor[
             0.8603396505869237, 0.8878558907422962, 0.7700485208406721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 225}], {
             RGBColor[
             0.9707544049144259, 0.9097673573291498, 0.42173371778471186`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 247}], {
             RGBColor[
             0.9242108592241347, 0.9380325178651518, 0.7763403149571115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 252}], {
             RGBColor[
             0.9494770309718252, 0.9581790773847985, 0.7787502249737841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 278}], {
             RGBColor[
             0.9879405623174387, 0.9701815740479194, 0.47578450634641234`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 309}], {
             RGBColor[
             0.9943250086261919, 0.9902700922180946, 0.6236903948271515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 383}], {
             RGBColor[
             0.9944154563199314, 0.9904635506893389, 0.6335350681122411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 393}], {
             RGBColor[
             0.9756973751037303, 0.9288824287390182, 0.42822203595305997`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 451}], {
             RGBColor[
             0.5863641363656958, 0.6472719370484693, 0.7500929874007136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 480}], {
             RGBColor[
             0.9503042382544358, 0.8286892611363533, 0.40527903366297713`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 129}], {
             RGBColor[
             0.8301316927449391, 0.8677062911338049, 0.9605019291876371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 204}], {
             RGBColor[
             0.9777488575703535, 0.9803205728562263, 0.7795245969987232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 209}], {
             RGBColor[
             0.9679516095392856, 0.9483114942906423, 0.6530862055603679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 231}], {
             RGBColor[
             0.9617407263921789, 0.9709868769038736, 0.9496471499880725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 233}], {
             RGBColor[
             0.9739523596955089, 0.9685534336107233, 0.6763979867707137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 259}], {
             RGBColor[
             0.9750636691808225, 0.9723021414525626, 0.6807152142679709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 275}], {
             RGBColor[
             0.9570857714321168, 0.9107411227721443, 0.6156520411798337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 326}], {
             RGBColor[
             0.9773795497585879, 0.979530660789607, 0.7393277207916567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 346}], {
             RGBColor[
             0.9698498434134115, 0.9770346431008484, 0.9359205300675706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 348}], {
             RGBColor[
             0.9741054472069691, 0.9797585307467933, 0.9085679079547877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 355}], {
             RGBColor[
             0.8440943485433072, 0.8786140239636046, 0.9618935962291815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 390}], {
             RGBColor[
             0.9756185969586126, 0.9803842570552728, 0.8834911006640247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 404}], {
             RGBColor[
             0.9596750897954294, 0.9203928497753653, 0.6209334892450935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 431}], {
             RGBColor[
             0.9778343034887726, 0.9805033330358173, 0.7888248579075566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 443}], {
             RGBColor[
             0.9588632910538686, 0.9176544620006717, 0.6177798044294586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 444}], {
             RGBColor[
             0.8970630902846706, 0.9200973199232914, 0.9671455033203479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 486}], {
             RGBColor[
             0.976659359814422, 0.9808146392425353, 0.8662429667353317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 125}], {
             RGBColor[
             0.904620029462692, 0.8448619596115863, 0.6280140963599568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 147}], {
             RGBColor[
             0.9355489873600312, 0.8695238710947276, 0.6309641279748117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 242}], {
             RGBColor[
             0.9644737517387721, 0.8898988001107004, 0.5279073977246055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 303}], {
             RGBColor[
             0.907422711507748, 0.6629945714040477, 0.24397135781061163`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 310}], {
             RGBColor[
             0.9602722770022463, 0.872120692002526, 0.3289687237065694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 323}], {
             RGBColor[
             0.9124157003413742, 0.685666567555375, 0.24813763008274514`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 379}], {
             RGBColor[
             0.9580754372751259, 0.8863720743639596, 0.5944973929105344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 408}], {
             RGBColor[
             0.835637933010077, 0.7905523640289636, 0.6212501290920669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 109}], {
             RGBColor[
             0.9455147506648878, 0.8674272777417192, 0.6083289885832253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 205}], {
             RGBColor[
             0.8058531840815162, 0.848767912344863, 0.9595083744040482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 230}], {
             RGBColor[
             0.9765326215124112, 0.9788277188424239, 0.7351036623078491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 382}], {
             RGBColor[
             0.9760485586192266, 0.98029765314115, 0.8645249669741717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 425}], {
             RGBColor[
             0.9721677675713278, 0.9786928463110631, 0.9288397178031453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 462}], {
             RGBColor[
             0.8954033943262008, 0.9188149635311116, 0.9684100865487384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 484}], {
             RGBColor[
             0.9594597919027572, 0.9217573672597068, 0.6245354020034041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 156}], {
             RGBColor[
             0.9659151793513522, 0.9707396324855551, 0.7396179676748197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 227}], {
             RGBColor[
             0.9488039950836868, 0.9613386838759537, 0.9715456616534442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 265}], {
             RGBColor[
             0.9660786221931901, 0.9710892201976402, 0.7574077123565801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 270}], {
             RGBColor[
             0.8969475548743444, 0.9205875450402239, 0.9873249206448075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 329}], {
             RGBColor[
             0.9291526552173783, 0.9462670178695982, 0.9903966718653585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 479}], {
             RGBColor[
             0.9412047111559112, 0.8841236467801727, 0.6310725693559411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 153}], {
             RGBColor[
             0.9198954903188604, 0.9378670484333198, 0.9541996898763421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 170}], {
             RGBColor[
             0.9852591873892433, 0.9871811895873828, 0.8495725724934535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 197}], {
             RGBColor[
             0.7159740439692044, 0.7753363020346604, 0.9359395824743381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 214}], {
             RGBColor[
             0.9863573630013054, 0.9869507093774681, 0.7816094734211713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 223}], {
             RGBColor[
             0.9845284093184536, 0.9868789940749714, 0.8616834563194617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 236}], {
             RGBColor[
             0.9862752577793198, 0.9867750946097524, 0.7726728267027407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 289}], {
             RGBColor[
             0.9782623342443609, 0.9608696190446442, 0.6459675366215829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 314}], {
             RGBColor[
             0.9860138985102084, 0.9862160735605986, 0.7442254831824034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 411}], {
             RGBColor[
             0.9598831522949256, 0.9696015011836406, 0.9527915384018049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 466}], {
             RGBColor[
             0.9843404241374915, 0.9868012573716447, 0.8647988572580583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 470}], {
             RGBColor[
             0.9658189267129976, 0.9181405806167529, 0.6015567124131457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 113}], {
             RGBColor[
             0.9896221628147048, 0.9881897257765992, 0.6917706624359049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 190}], {
             RGBColor[
             0.9798061382390042, 0.9431066650085193, 0.41319671710749595`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 315}], {
             RGBColor[
             0.9938342006906737, 0.9892203036723157, 0.5702689799614742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 349}], {
             RGBColor[
             0.9907775956165601, 0.9886675269334351, 0.6726221507449224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 364}], {
             RGBColor[
             0.9903764278515057, 0.9885016337530437, 0.6792705388007698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 378}], {
             RGBColor[
             0.9927343963946245, 0.9867167154667958, 0.4634205587453841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 380}], {
             RGBColor[
             0.994077019457649, 0.9897396684621325, 0.5966983042430013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 416}], {
             RGBColor[
             0.993113415852467, 0.9876786177859174, 0.4918159984910648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 452}], {
             RGBColor[
             0.9932964659639265, 0.9897091445540862, 0.6308779504615611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 487}], {
             RGBColor[
             0.932049284575919, 0.9438866062698889, 0.7449821083779313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 164}], {
             RGBColor[
             0.9043113660426829, 0.8351922315797327, 0.6258744555850464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 180}], {
             RGBColor[
             0.9599743930572839, 0.8774725360378373, 0.5507712250422242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 205}], {
             RGBColor[
             0.7916487548949465, 0.7467159792828, 0.6147682620095394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 230}], {
             RGBColor[
             0.9623281923258415, 0.8767757857803609, 0.39036354991334005`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 382}], {
             RGBColor[
             0.961844129432657, 0.878245720079087, 0.5197848545796628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 413}], {
             RGBColor[
             0.7001116908016556, 0.6725495585192889, 0.6074612882241717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 474}], {
             RGBColor[
             0.9220405545731357, 0.728623807867313, 0.2561302041474117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 490}], {
             RGBColor[
             0.9333097533403902, 0.8583147584706703, 0.6286403476526676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 157}], {
             RGBColor[
             0.9920618629809697, 0.9848227720509642, 0.4289486859981401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 356}], {
             RGBColor[
             0.8904757771188363, 0.9105855172256148, 0.7079394850956473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 360}], {
             RGBColor[
             0.9928306075627649, 0.9870737194505483, 0.46103406144742554`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 457}], {
             RGBColor[
             0.9634603287021868, 0.8819419905170427, 0.3511741141441074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 494}], {
             RGBColor[
             0.9934986923851324, 0.9892690514666679, 0.5894576992491842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 130}], {
             RGBColor[
             0.9889971485713736, 0.9897180524209486, 0.8320092528464595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 175}], {
             RGBColor[
             0.9364000544463222, 0.9499576772110798, 0.9106719904930326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 182}], {
             RGBColor[
             0.9920558159741891, 0.9909828899961797, 0.7813192184043082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 351}], {
             RGBColor[
             0.9627650481171772, 0.9709580426860734, 0.9124113047954551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 359}], {
             RGBColor[
             0.5839454070259071, 0.6475491338702264, 0.8830313460512651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 371}], {
             RGBColor[
             0.8889659151847373, 0.9123856727788011, 0.9060811543549607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 460}], {
             RGBColor[
             0.9887348525871491, 0.9896095862907724, 0.8363561761053073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 463}], {
             RGBColor[
             0.9797747825809549, 0.983643874798275, 0.8836182611975407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 483}], {
             RGBColor[
             0.9905012193770977, 0.990340024351972, 0.8070829071851415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 163}], {
             RGBColor[
             0.9423003095049807, 0.9530907877205829, 0.8294787037872962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 175}], {
             RGBColor[
             0.9392915537607004, 0.9506916875605929, 0.8291917259784587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 207}], {
             RGBColor[
             0.9142400545482177, 0.9307163020933902, 0.8268022916198348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 238}], {
             RGBColor[
             0.974463437768248, 0.9236092683959025, 0.4757957849981732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 266}], {
             RGBColor[
             0.9162806114852575, 0.9323433868055433, 0.8269969217621163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 293}], {
             RGBColor[
             0.9948969928679183, 0.9914935086746693, 0.6859473496615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 317}], {
             RGBColor[
             0.8608124205615131, 0.8888670979135663, 0.8215066149766497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 343}], {
             RGBColor[
             0.9898655126445205, 0.9896154443560083, 0.7840575749852581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 359}], {
             RGBColor[
             0.5868369063402853, 0.6482831442197393, 0.8015510815366913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 403}], {
             RGBColor[
             0.9932167104056996, 0.99100125075211, 0.728519555460722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 440}], {
             RGBColor[
             0.9934432180232066, 0.9910949174729293, 0.7247657380557073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 445}], {
             RGBColor[
             0.9944664537475343, 0.9905726290303506, 0.6390858233871715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 463}], {
             RGBColor[
             0.9826662818953331, 0.984377885147788, 0.8021379966829669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 471}], {
             RGBColor[
             0.9943343786637633, 0.9902901337810035, 0.6247102655916166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 483}], {
             RGBColor[
             0.9933927186914758, 0.991074034701485, 0.7256026426705677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 190}], {
             RGBColor[
             0.9762174890273572, 0.9434094524315253, 0.6025504085844874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 315}], {
             RGBColor[
             0.9902455514790267, 0.9895230910953217, 0.7596226714384655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 349}], {
             RGBColor[
             0.9871889464049131, 0.988970314356441, 0.8619758422219137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 353}], {
             RGBColor[
             0.946430090872803, 0.8283991655483777, 0.5625065539612224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 364}], {
             RGBColor[
             0.9867877786398587, 0.9888044211760498, 0.8686242302777611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 378}], {
             RGBColor[
             0.9891457471829773, 0.9870195028898019, 0.6527742502223756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 380}], {
             RGBColor[
             0.9904883702460019, 0.9900424558851384, 0.7860519957199927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 487}], {
             RGBColor[
             0.9284606353642718, 0.9441893936928949, 0.9343357998549229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 128}], {
             RGBColor[
             0.9813761045515716, 0.9819000254830237, 0.6840617828267661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 138}], {
             RGBColor[
             0.9654810132015155, 0.9737763766821194, 0.9433158200429008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 179}], {
             RGBColor[
             0.8857278999271943, 0.9109814190429582, 0.9580933087822243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 255}], {
             RGBColor[
             0.9812419838620958, 0.9841834112921442, 0.8562940809102522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 294}], {
             RGBColor[
             0.9793653818448738, 0.9834073881315508, 0.8873942328259659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 296}], {
             RGBColor[
             0.8822969930414665, 0.9083011685079696, 0.9577513480475026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 312}], {
             RGBColor[
             0.981012195266777, 0.9840883878026823, 0.8601022726085088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 327}], {
             RGBColor[
             0.9640785100594003, 0.9727303921351178, 0.9456898920310988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 334}], {
             RGBColor[
             0.9755372034109805, 0.9622459333383948, 0.6578165236185323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 385}], {
             RGBColor[
             0.9777335346744709, 0.9827325773900298, 0.9144381635246427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 415}], {
             RGBColor[
             0.9781457165020351, 0.9829030251683173, 0.9076072439495291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 446}], {
             RGBColor[
             0.9228730221091638, 0.9404487090215867, 0.9616763734105205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 144}], {
             RGBColor[
             0.9754668478163386, 0.9793500705508054, 0.8414222415439367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 215}], {
             RGBColor[
             0.7909564036305062, 0.8369543657125782, 0.9617977359615286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 223}], {
             RGBColor[
             0.9732635567769733, 0.9784776854940385, 0.8807519133281012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 268}], {
             RGBColor[
             0.9745222672866894, 0.977329708309627, 0.7386104801669304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 402}], {
             RGBColor[
             0.9006325598561615, 0.9230882896200487, 0.9725052830728873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 417}], {
             RGBColor[
             0.9508017430444835, 0.8948625295073549, 0.6176059557184419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 143}], {
             RGBColor[
             0.7746071082780629, 0.8195492244622531, 0.7624264296944487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 165}], {
             RGBColor[
             0.6522344929794085, 0.7269179040179681, 0.9668829283602036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 185}], {
             RGBColor[
             0.7724541011267516, 0.8199361091459203, 0.8909469029024626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 187}], {
             RGBColor[
             0.7507381247309479, 0.8046214709799182, 0.9671639106788223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 224}], {
             RGBColor[
             0.7223359095384414, 0.7822415882792935, 0.973721395587443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 277}], {
             RGBColor[
             0.7739075933555172, 0.8205371655355613, 0.8668587751545065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 313}], {
             RGBColor[
             0.7688211319839069, 0.8008331597168172, 0.671804421233507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 333}], {
             RGBColor[
             0.7456529388950492, 0.7167464319202637, 0.6127098029428614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 358}], {
             RGBColor[
             0.772140142005421, 0.8198062789808687, 0.8961500180430717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 361}], {
             RGBColor[
             0.7685878425147328, 0.8000462195583207, 0.6708981356987852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 386}], {
             RGBColor[
             0.7715255676191362, 0.8195521366782986, 0.9063351060913376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 441}], {
             RGBColor[
             0.7750834785791074, 0.8205681323677618, 0.8142763971464249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 140}], {
             RGBColor[
             0.919018004091164, 0.8831676213305962, 0.6353942535242233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 155}], {
             RGBColor[
             0.9073032170403657, 0.8367223943955497, 0.6259682608817569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 156}], {
             RGBColor[
             0.9384694251386885, 0.9489332375680635, 0.7397080990621858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 198}], {
             RGBColor[
             0.9353278726157641, 0.9387060696443104, 0.69603938594984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 270}], {
             RGBColor[
             0.8695018006616807, 0.8987811501227322, 0.9874150520321736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 479}], {
             RGBColor[
             0.9137589569432474, 0.8623172518626812, 0.6311627007433073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 152}], {
             RGBColor[
             0.9886105981249775, 0.9875715114706054, 0.694003828715883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 187}], {
             RGBColor[
             0.9651528206533169, 0.9735232862043557, 0.9434985533437292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.9707346254947238, 0.9776861871157103, 0.9340500137150873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 255}], {
             RGBColor[
             0.9882723733280401, 0.989418339231956, 0.8440206542867013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 260}], {
             RGBColor[
             0.9677974337731274, 0.9754956343389538, 0.9390219131574595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 292}], {
             RGBColor[
             0.9874735245472657, 0.9890879947316286, 0.8572596459385065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 399}], {
             RGBColor[
             0.9762579514071617, 0.9461969590264263, 0.6210313313607629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 446}], {
             RGBColor[
             0.9299034115751079, 0.9456836369613986, 0.9494029467869696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 464}], {
             RGBColor[
             0.9049065890963701, 0.9257518492375236, 0.9470187275440207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 481}], {
             RGBColor[
             0.9887145880292574, 0.9877939353608679, 0.7053224880454441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 496}], {
             RGBColor[
             0.8888603178725469, 0.9131712220052031, 0.9454313687861156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 120}], {
             RGBColor[
             0.9512963714522786, 0.9631974940907576, 0.9673267185772845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 124}], {
             RGBColor[
             0.9486017502918052, 0.9126189791441913, 0.6407064953643506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 363}], {
             RGBColor[
             0.8744395813694296, 0.9027185799159712, 0.9850966822575996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 364}], {
             RGBColor[
             0.9631685753394797, 0.9714952003426998, 0.922306102540883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 381}], {
             RGBColor[
             0.9397548995211243, 0.9545898832219286, 0.9868634200587505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 416}], {
             RGBColor[
             0.965905563340441, 0.9706721843755733, 0.734851562231178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 124}], {
             RGBColor[
             0.9611030147417838, 0.9219424017020437, 0.6195451155024954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 315}], {
             RGBColor[
             0.9791276126286266, 0.981537292819824, 0.7921431638397319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 363}], {
             RGBColor[
             0.8869408458194084, 0.9120420024738234, 0.9639353023957442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 381}], {
             RGBColor[
             0.9522561639711031, 0.9639133057797808, 0.965702040196895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 196}], {
             RGBColor[
             0.7248840606164056, 0.7477129453929809, 0.6424155930485196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.7375005691741812, 0.7906945917579444, 0.8520488221672103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 307}], {
             RGBColor[
             0.6538173464428869, 0.7270694756513361, 0.9678044221362405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 337}], {
             RGBColor[
             0.7363732767046505, 0.7902284273516985, 0.8707309757267284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 420}], {
             RGBColor[
             0.7375971876029415, 0.7896547130612005, 0.7719551522265649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 427}], {
             RGBColor[
             0.7034308340295772, 0.666396207371595, 0.6056854406121629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 442}], {
             RGBColor[
             0.7208089501496209, 0.7339666409070762, 0.6265845584050994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 447}], {
             RGBColor[
             0.3749898128697492, 0.4947711309669157, 0.9454590826113412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 454}], {
             RGBColor[
             0.4297046579656969, 0.5458542234885979, 0.9488102876738721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 489}], {
             RGBColor[
             0.7371284514641252, 0.788652133856766, 0.7209361162205513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 500}], {
             RGBColor[
             0.6149988839470893, 0.6966917688783161, 0.9639492735759294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 185}], {
             RGBColor[
             0.9811058314441105, 0.9547757657271166, 0.5861292349127152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 212}], {
             RGBColor[
             0.9387304280699327, 0.9232551340100519, 0.6696422416496282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 216}], {
             RGBColor[
             0.8103301417327479, 0.8222627654409015, 0.6570263026335983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 217}], {
             RGBColor[
             0.9617036817565081, 0.9411867757315475, 0.6584295376147464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 224}], {
             RGBColor[
             0.9309876398558004, 0.9170812448604899, 0.6689037275976956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 286}], {
             RGBColor[
             0.9709693565806241, 0.9137349644065289, 0.3417218616030698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 319}], {
             RGBColor[
             0.9707049629397341, 0.9478999164997524, 0.6431927164816696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 330}], {
             RGBColor[
             0.9772266882174132, 0.934842413308755, 0.366030413414067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 357}], {
             RGBColor[
             0.9827639994843789, 0.9533304702208374, 0.4037485782606759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 492}], {
             RGBColor[
             0.9173870731729389, 0.693073339472833, 0.277559030124482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 139}], {
             RGBColor[
             0.938918477272472, 0.7948997857910151, 0.2730403816781161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 158}], {
             RGBColor[
             0.9761276650055355, 0.9301308628350433, 0.44715824308755403`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 193}], {
             RGBColor[
             0.904077924231493, 0.8768318394165842, 0.6386910783984545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 401}], {
             RGBColor[
             0.9712301654727321, 0.914614734040449, 0.3427350548992826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 410}], {
             RGBColor[
             0.9543825040923555, 0.916558060494965, 0.6301310867145471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 422}], {
             RGBColor[
             0.9741529758894863, 0.9244740598846826, 0.3540896214419395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 428}], {
             RGBColor[
             0.9636945683613449, 0.9235029827796715, 0.6143681908824834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 437}], {
             RGBColor[
             0.9318429898607687, 0.8989709490867395, 0.6413393351443415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 363}], {
             RGBColor[
             0.8842462246589349, 0.8614634875272571, 0.6373150791828104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 381}], {
             RGBColor[
             0.9495615428106297, 0.9133347908332146, 0.6390818169839613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 416}], {
             RGBColor[
             0.9757122066299463, 0.9294170919868594, 0.3870699591563888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.9274295827293875, 0.9437545230084483, 0.950757607855915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 173}], {
             RGBColor[
             0.5703973523662756, 0.6503145440409636, 0.9631356822796489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 242}], {
             RGBColor[
             0.9318328858547484, 0.9457933725656272, 0.8875446464834126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 249}], {
             RGBColor[
             0.9129383986947825, 0.9329470216825759, 0.9752874025203941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 269}], {
             RGBColor[
             0.9291849505495058, 0.944698383268076, 0.9314277871281884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 282}], {
             RGBColor[
             0.9322621482681863, 0.9436098251013735, 0.7088066287751946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 305}], {
             RGBColor[
             0.9273149275306232, 0.9269476910025999, 0.6873764934904634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 310}], {
             RGBColor[
             0.9276314111182227, 0.9280152644574529, 0.6886059724653765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 323}], {
             RGBColor[
             0.8797748344573506, 0.7415611400103019, 0.6077748788415522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 406}], {
             RGBColor[
             0.9321242159330565, 0.945913845039849, 0.8827165531477756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 408}], {
             RGBColor[
             0.8029970671260533, 0.8464469364838905, 0.980887377850874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 419}], {
             RGBColor[
             0.9335559131278306, 0.94637705731646, 0.8496249495562729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 173}], {
             RGBColor[
             0.6220480102344731, 0.690478679239932, 0.9326739497316471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 249}], {
             RGBColor[
             0.96458905656298, 0.9731111568815445, 0.9448256699723923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 269}], {
             RGBColor[
             0.9808356084177032, 0.9848625184670444, 0.9009660545801867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 282}], {
             RGBColor[
             0.9839128061363838, 0.9837739603003419, 0.678344896227193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 340}], {
             RGBColor[
             0.9790887614191743, 0.9675273278413263, 0.6573932765216962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 384}], {
             RGBColor[
             0.9651854702416345, 0.9735559612265472, 0.9438160971840306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 414}], {
             RGBColor[
             0.9846569322947873, 0.9864427340937629, 0.837636828667716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 449}], {
             RGBColor[
             0.866187700133864, 0.8956261879689841, 0.9515758421775897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 499}], {
             RGBColor[
             0.9329247665151779, 0.948332204158391, 0.9580761727290731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 184}], {
             RGBColor[
             0.9153160849831278, 0.9308278541949205, 0.7663956442922515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 221}], {
             RGBColor[
             0.8997003552794582, 0.9221720475248989, 0.9664208646375232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 253}], {
             RGBColor[
             0.9139120093029636, 0.9267895833690115, 0.7015876719442312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 301}], {
             RGBColor[
             0.872386669758878, 0.9010814664331517, 0.9876902134220173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 303}], {
             RGBColor[
             0.8572913575919543, 0.7049427034690912, 0.6019403482070056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 316}], {
             RGBColor[
             0.5079625937575643, 0.5891288256433732, 0.9589079141969687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 138}], {
             RGBColor[
             0.9766757871599407, 0.9783945364684088, 0.6920181941316845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 179}], {
             RGBColor[
             0.8969226738856194, 0.9155995788292477, 0.7067956828710078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 222}], {
             RGBColor[
             0.9937966379347769, 0.9893639164530033, 0.5824597222488933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 245}], {
             RGBColor[
             0.9932292330039203, 0.9879263389619655, 0.5044219806861426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 294}], {
             RGBColor[
             0.9905601558032989, 0.9880255479178403, 0.6360966069147493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 296}], {
             RGBColor[
             0.8934917669998916, 0.912919328294259, 0.7064537221362863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 312}], {
             RGBColor[
             0.9922069692252022, 0.9887065475889717, 0.6088046466972924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 385}], {
             RGBColor[
             0.9889283086328962, 0.9873507371763193, 0.6631405376134263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 415}], {
             RGBColor[
             0.9893404904604602, 0.9875211849546068, 0.6563096180383126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 438}], {
             RGBColor[
             0.9362675164457179, 0.9468208661275772, 0.7105885587926837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 439}], {
             RGBColor[
             0.9929722520354481, 0.9873766826551652, 0.4764511881706561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 204}], {
             RGBColor[
             0.8465698816711338, 0.8773607234504761, 0.7896514006079143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 275}], {
             RGBColor[
             0.8259067955328971, 0.807781273366394, 0.6257788447890249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 276}], {
             RGBColor[
             0.7620966245089191, 0.8141174288986688, 0.9769110527639833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 306}], {
             RGBColor[
             0.8352209655176741, 0.8401175039590638, 0.6571850715220047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 331}], {
             RGBColor[
             0.8459308393808584, 0.8759938766086637, 0.7200955910233118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 346}], {
             RGBColor[
             0.8386708675141918, 0.8740747936950981, 0.9460473336767616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 348}], {
             RGBColor[
             0.8429264713077493, 0.8767986813410431, 0.9186947115639787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 355}], {
             RGBColor[
             0.7129153726440876, 0.7756541745578542, 0.9720203998383725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 431}], {
             RGBColor[
             0.8466553275895529, 0.877543483630067, 0.7989516615167478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 444}], {
             RGBColor[
             0.7658841143854508, 0.8171374705175412, 0.977272306929539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 486}], {
             RGBColor[
             0.8454803839152023, 0.877854789836785, 0.8763697703445228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 175}], {
             RGBColor[
             0.9364333889658816, 0.9499714618915758, 0.9101195512369619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 182}], {
             RGBColor[
             0.9920891504937486, 0.9909966746766755, 0.7807667791482374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 208}], {
             RGBColor[
             0.9686969859642347, 0.911358653864625, 0.5543835342628085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 238}], {
             RGBColor[
             0.9716052729734291, 0.9228890427268854, 0.5567236102566763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 241}], {
             RGBColor[
             0.9218254644039052, 0.9383234993674049, 0.9087262343515923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 351}], {
             RGBColor[
             0.9627983826367366, 0.9709718273665693, 0.9118588655393843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 371}], {
             RGBColor[
             0.8889992497042968, 0.9123994574592971, 0.90552871509889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 442}], {
             RGBColor[
             0.9747421494022797, 0.9339977064985896, 0.5661638923092196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 483}], {
             RGBColor[
             0.990534553896657, 0.990353809032468, 0.8065304679290708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 186}], {
             RGBColor[
             0.986415652405334, 0.985984512331427, 0.7013978731183191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 234}], {
             RGBColor[
             0.9822540539871063, 0.9861986769571074, 0.9110271270954899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 373}], {
             RGBColor[
             0.9850164242423867, 0.9815953273351139, 0.6678383807672738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 434}], {
             RGBColor[
             0.9530809611825204, 0.8651182459121483, 0.5893518778932255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 449}], {
             RGBColor[
             0.8684436630111676, 0.8973086813890769, 0.9477570854756668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 495}], {
             RGBColor[
             0.9857501801110398, 0.9876444149556971, 0.8530872695375332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 250}], {
             RGBColor[
             0.9241718739037853, 0.7762543495609093, 0.589550883019853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 356}], {
             RGBColor[
             0.8379430395765202, 0.7084009483871025, 0.603705152953582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 365}], {
             RGBColor[
             0.9315828462758068, 0.7817814406216094, 0.5770060398851788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 457}], {
             RGBColor[
             0.9109275911598707, 0.6797574216785305, 0.24693978200204209`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 494}], {
             RGBColor[
             0.9409659548428163, 0.7870844826281557, 0.48522336710711894`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 191}], {
             RGBColor[
             0.9222420686501657, 0.7980601290488192, 0.6082969805198889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 237}], {
             RGBColor[
             0.8956552659277088, 0.6190767575570819, 0.23464453497765156`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 241}], {
             RGBColor[
             0.8772045746500301, 0.7623804470975312, 0.6120446158950016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 271}], {
             RGBColor[
             0.9467754506328978, 0.8134560145401957, 0.40026273678116076`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 304}], {
             RGBColor[
             0.9032979536803313, 0.6530371903687326, 0.24098333460086713`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 311}], {
             RGBColor[
             0.9142423297715665, 0.791913347668364, 0.6155773100424881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 351}], {
             RGBColor[
             0.9181774928828614, 0.7950287750966956, 0.6151772470827935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 366}], {
             RGBColor[
             0.8805288568871215, 0.7650311395181502, 0.6123616889023972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 371}], {
             RGBColor[
             0.8443783599504217, 0.7364564051894233, 0.6088470966422992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 405}], {
             RGBColor[
             0.9429082145295181, 0.8131679261109777, 0.559656927418535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 423}], {
             RGBColor[
             0.9436434741686947, 0.813471974867088, 0.5474717724064292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 429}], {
             RGBColor[
             0.944843246404796, 0.8139681115194559, 0.527588441543214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 469}], {
             RGBColor[
             0.8471006795364846, 0.738583101940451, 0.609118432017115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 488}], {
             RGBColor[
             0.6216171015184127, 0.5548713474704446, 0.5905992990494154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 174}], {
             RGBColor[
             0.9580691873674243, 0.9659252806336822, 0.8521254847885696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 210}], {
             RGBColor[
             0.8610068392569247, 0.8892829398443063, 0.8426678901590878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 225}], {
             RGBColor[
             0.9714215935844268, 0.9111944064311599, 0.49435308710312764`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 247}], {
             RGBColor[
             0.9248780478941356, 0.9394595669671619, 0.8489596842755274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 252}], {
             RGBColor[
             0.9501442196418262, 0.9596061264868085, 0.8513695942921999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 278}], {
             RGBColor[
             0.9886077509874396, 0.9716086231499292, 0.5484038756648282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 309}], {
             RGBColor[
             0.9949921972961928, 0.9916971413201046, 0.6963097641455672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 424}], {
             RGBColor[
             0.9873087966200029, 0.9672269450595765, 0.5433576832342868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 169}], {
             RGBColor[
             0.9643825412367975, 0.8983683769951586, 0.5710487261858759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 211}], {
             RGBColor[
             0.989836084245518, 0.9900649738818708, 0.8181059176299565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 362}], {
             RGBColor[
             0.9173177262732353, 0.9351739530482139, 0.9276111080856788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 369}], {
             RGBColor[
             0.9820756932592226, 0.9857338513003164, 0.8964701610526211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 466}], {
             RGBColor[
             0.9885837175967258, 0.9895470880882403, 0.8388608740214385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 470}], {
             RGBColor[
             0.970062220172232, 0.9208864113333484, 0.5756187291765259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 240}], {
             RGBColor[
             0.9722434771623188, 0.9759724691829719, 0.7696262375804311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 434}], {
             RGBColor[
             0.9385085693476389, 0.8542501799417953, 0.6140191361811863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 148}], {
             RGBColor[
             0.8753945179298639, 0.7417173054685734, 0.6080774706222971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 156}], {
             RGBColor[
             0.9413112905526071, 0.7894367264584816, 0.360079524678922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 227}], {
             RGBColor[
             0.9242001062849419, 0.7800357778488802, 0.5920072186575465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 229}], {
             RGBColor[
             0.9297205898844725, 0.7507085978866084, 0.28358746651017974`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 263}], {
             RGBColor[
             0.9398504491628847, 0.7848789918367595, 0.3229400569434002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 265}], {
             RGBColor[
             0.9414747333944451, 0.7897863141705668, 0.37786926936068244`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 267}], {
             RGBColor[
             0.942308726082759, 0.7915701402012749, 0.46864422667738914`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 280}], {
             RGBColor[
             0.9385350883934775, 0.7804419711001535, 0.3178301287392921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 393}], {
             RGBColor[
             0.9235567515723684, 0.7299165239218206, 0.25964211861084996`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 424}], {
             RGBColor[
             0.93450098441864, 0.766833991140369, 0.30215839657366095`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 485}], {
             RGBColor[
             0.9350272479464483, 0.7881106423722144, 0.5736796919954217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 179}], {
             RGBColor[
             0.8810275825355633, 0.9074759300283433, 0.9660497200871426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 222}], {
             RGBColor[
             0.977901546584721, 0.9812402676520988, 0.8417137594650281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 294}], {
             RGBColor[
             0.9746650644532429, 0.9799018991169359, 0.8953506441308842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 296}], {
             RGBColor[
             0.8775966756498357, 0.9047956794933547, 0.965707759352421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 339}], {
             RGBColor[
             0.957096125545646, 0.9116351297884182, 0.6163221395185674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 385}], {
             RGBColor[
             0.97303321728284, 0.979227088375415, 0.922394574829561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 415}], {
             RGBColor[
             0.9734453991104042, 0.9793975361537024, 0.9155636552544474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 438}], {
             RGBColor[
             0.920372425095662, 0.9386972173266729, 0.9698425960088184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 158}], {
             RGBColor[
             0.9569210631561367, 0.8546224480676686, 0.4283743556515843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 247}], {
             RGBColor[
             0.8871661605699753, 0.8031532663285028, 0.620126074677471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 278}], {
             RGBColor[
             0.9508958636632793, 0.8353023225112702, 0.3195702660667719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 401}], {
             RGBColor[
             0.9520235636233332, 0.8391063192730743, 0.3239511674633129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 410}], {
             RGBColor[
             0.9351759022429567, 0.8410496457275902, 0.6113471992785775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 428}], {
             RGBColor[
             0.944487966511946, 0.8479945680122968, 0.5955843034465136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 437}], {
             RGBColor[
             0.9126363880113699, 0.8234625343193648, 0.6225554477083719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 451}], {
             RGBColor[
             0.5493194377115366, 0.5123926855118202, 0.5938787471210731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 198}], {
             RGBColor[
             0.9705095818660978, 0.9116626042931997, 0.3426513505905284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 270}], {
             RGBColor[
             0.9046835099120145, 0.8717376847716214, 0.634027016672862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 479}], {
             RGBColor[
             0.9489406661935812, 0.8352737865115704, 0.27777466538399564`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 151}], {
             RGBColor[
             0.9469117038904542, 0.8150698359823605, 0.3556266275593736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 160}], {
             RGBColor[
             0.947632926362219, 0.8173940392619587, 0.49093995531474444`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 162}], {
             RGBColor[
             0.939171025849741, 0.7892244452362118, 0.3029594637953378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 167}], {
             RGBColor[
             0.9183914990483752, 0.7131952497128846, 0.25314436296982007`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 235}], {
             RGBColor[
             0.9473645854558395, 0.8160385038573692, 0.404919991090505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 274}], {
             RGBColor[
             0.9476101867529514, 0.8165638201977914, 0.43165217660562594`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 284}], {
             RGBColor[
             0.946761616663802, 0.8147488145806976, 0.33929055916927015`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 300}], {
             RGBColor[
             0.8726292585793326, 0.7607932039898841, 0.6120151113414211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 345}], {
             RGBColor[
             0.9475024102399483, 0.8173400674912885, 0.4931029452256669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 389}], {
             RGBColor[
             0.9460973786794733, 0.8125886597158822, 0.3298670366068687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 432}], {
             RGBColor[
             0.9034726484824014, 0.6540469786310403, 0.24114030561400673`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 456}], {
             RGBColor[
             0.9475960730786164, 0.8165336324755003, 0.43011599025376357`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 472}], {
             RGBColor[
             0.9435553537995685, 0.8157078582184678, 0.5585158850973894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[
             0.8878077809557794, 0.5815669693466466, 0.2279993477008741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 161}], {
             RGBColor[
             0.9347066733575781, 0.8262607407235099, 0.600939002203306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 183}], {
             RGBColor[
             0.8445919604408821, 0.755333905308489, 0.612794743647162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 254}], {
             RGBColor[
             0.924696788401473, 0.7391548898592186, 0.25826747223551333`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 285}], {
             RGBColor[
             0.9432563532858231, 0.8068794597076978, 0.30370908232923416`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 388}], {
             RGBColor[
             0.9526513945188759, 0.8373001679860737, 0.44828131640003455`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 396}], {
             RGBColor[
             0.8729551380846207, 0.777614176811958, 0.6155891482896458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 473}], {
             RGBColor[
             0.9240857770731692, 0.7367324335499492, 0.2577758381784809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 477}], {
             RGBColor[
             0.8815213961063137, 0.7844446784335766, 0.6164062056269437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 165}], {
             RGBColor[
             0.8714288835771746, 0.8965190373527383, 0.771166087893586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 178}], {
             RGBColor[
             0.9924781248754933, 0.9898803171092183, 0.6814808941024088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 186}], {
             RGBColor[
             0.9934201993084132, 0.9883347965776208, 0.5252074844227775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 277}], {
             RGBColor[
             0.9931019839532833, 0.9901382988703314, 0.6711419346878889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 288}], {
             RGBColor[
             0.9843424635559853, 0.9849695201084625, 0.7470547865798496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 313}], {
             RGBColor[
             0.988015522581673, 0.9704342930515873, 0.4760875807668894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 321}], {
             RGBColor[
             0.9929388939513691, 0.9900708569633181, 0.673844758083002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 373}], {
             RGBColor[
             0.9920209711454658, 0.9839456115813076, 0.4916479920717321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 386}], {
             RGBColor[
             0.9907199582169024, 0.9891532700130687, 0.7106182656247199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 414}], {
             RGBColor[
             0.9939174420751702, 0.9904755117600494, 0.6576276832702515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 498}], {
             RGBColor[
             0.9832963814840268, 0.9545155220222037, 0.45775460873755225`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 145}], {
             RGBColor[
             0.9779232964725229, 0.9355048360093059, 0.5122209648102558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 215}], {
             RGBColor[
             0.8107266583852177, 0.8498252641010753, 0.8433416863512109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 246}], {
             RGBColor[
             0.9947810720063123, 0.991245565673091, 0.6733300792563195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 375}], {
             RGBColor[
             0.9752099801594576, 0.9791584990728857, 0.8418570514852217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 402}], {
             RGBColor[
             0.9204028146108729, 0.9359591880085459, 0.8540492334625693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 417}], {
             RGBColor[
             0.970571997799195, 0.907733427895852, 0.49914990610812404`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 458}], {
             RGBColor[
             0.9645973428267511, 0.9711987051793765, 0.858264547016721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 367}], {
             RGBColor[
             0.9772231284411024, 0.9340072473879445, 0.4360119955263474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 375}], {
             RGBColor[
             0.9578961740609304, 0.9224423661428891, 0.6311118243618588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 402}], {
             RGBColor[
             0.9030890085123457, 0.8792430550785493, 0.6433040063392064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 417}], {
             RGBColor[
             0.9532581917006677, 0.8510172949658554, 0.28840467898476096`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 450}], {
             RGBColor[
             0.9400073924809431, 0.9086807723322723, 0.6468253147595617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 458}], {
             RGBColor[
             0.9472835367282239, 0.9144825722493798, 0.647519319893358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 461}], {
             RGBColor[
             0.9778718606185128, 0.9353948199185409, 0.5066224895265518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 166}], {
             RGBColor[
             0.868774101009765, 0.6432266961728896, 0.5915710881776031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 239}], {
             RGBColor[
             0.9165920835240676, 0.6799628210613167, 0.5466043457885665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 248}], {
             RGBColor[
             0.7480428889779576, 0.5483503276508952, 0.5796863965696573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 387}], {
             RGBColor[
             0.8872417981179568, 0.5585649672123352, 0.22667091333497036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 221}], {
             RGBColor[
             0.9481198012085674, 0.9607803993979235, 0.9710391546147912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 234}], {
             RGBColor[
             0.9592763911389444, 0.9690139598211873, 0.9482576479602696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 242}], {
             RGBColor[
             0.9627618437520877, 0.9704552840487686, 0.8904946780982674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 303}], {
             RGBColor[
             0.9057108035210635, 0.7435510553421159, 0.6065586381842736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 323}], {
             RGBColor[
             0.9107037923546899, 0.7662230514934432, 0.6107249104564072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 449}], {
             RGBColor[
             0.8454660001630058, 0.8801239642531569, 0.9849876063404465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 229}], {
             RGBColor[
             0.9155950821456688, 0.9012078388926383, 0.6621397970154697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 232}], {
             RGBColor[
             0.9273682147140911, 0.9418915853482774, 0.8722775501764761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 263}], {
             RGBColor[
             0.9257249414240809, 0.9353782328427894, 0.7014923874486901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 267}], {
             RGBColor[
             0.9281832183439551, 0.9420693812073049, 0.847196557182679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 280}], {
             RGBColor[
             0.9244095806546737, 0.9309412121061834, 0.696382459244582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 342}], {
             RGBColor[
             0.7940735193167578, 0.8393892269311287, 0.980020934003752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 393}], {
             RGBColor[
             0.9094312438335646, 0.8804157649278506, 0.6381944491161399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 480}], {
             RGBColor[
             0.88403810698427, 0.7802225973251857, 0.615251446826057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 485}], {
             RGBColor[
             0.9209017402076445, 0.9386098833782444, 0.9522320225007115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 173}], {
             RGBColor[
             0.6258477715169948, 0.6933125349828987, 0.9262419450168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 242}], {
             RGBColor[
             0.9872833050054677, 0.9887913635075624, 0.8506509092205636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 249}], {
             RGBColor[
             0.9683888178455018, 0.975945012624511, 0.9383936652575452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 269}], {
             RGBColor[
             0.9846353697002249, 0.9876963742100111, 0.8945340498653396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 282}], {
             RGBColor[
             0.9877125674189055, 0.9866078160433086, 0.6719128915123458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 310}], {
             RGBColor[
             0.9830818302689418, 0.971013255399388, 0.6517122352025275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 314}], {
             RGBColor[
             0.9883407503779679, 0.9879514358737034, 0.7402867299104485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 323}], {
             RGBColor[
             0.9352252536080699, 0.7845591309522371, 0.5708811415787034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 406}], {
             RGBColor[
             0.9875746350837756, 0.9889118359817841, 0.8458228158849268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 411}], {
             RGBColor[
             0.9622100041626851, 0.9713368634967454, 0.94885278512985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 419}], {
             RGBColor[
             0.9890063322785497, 0.9893750482583952, 0.812731212293424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 220}], {
             RGBColor[
             0.902587525240047, 0.6401637303759458, 0.23989147687718243`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 254}], {
             RGBColor[
             0.9017641416875519, 0.6368992889666066, 0.2392289631435489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 325}], {
             RGBColor[
             0.9299654566983493, 0.7355722524703368, 0.4560955478432398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 392}], {
             RGBColor[
             0.8563988508626363, 0.6804429118965487, 0.5971588220582656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 412}], {
             RGBColor[
             0.9116452388062285, 0.7239090900726144, 0.5821184973268605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 426}], {
             RGBColor[
             0.6955977937530174, 0.5528205243684673, 0.5824069295733316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 473}], {
             RGBColor[
             0.9011531303592482, 0.6344768326573373, 0.2387373290865165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 160}], {
             RGBColor[
             0.9936547922657244, 0.9896181485315942, 0.6075541926591341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 162}], {
             RGBColor[
             0.9851928917532464, 0.9614485545058474, 0.41957370113972753`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 226}], {
             RGBColor[
             0.9324800434765362, 0.7495390366426834, 0.343584496357633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 235}], {
             RGBColor[
             0.9933864513593449, 0.9882626131270048, 0.5215342284348947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 237}], {
             RGBColor[
             0.9422276990330973, 0.7938008639022314, 0.35171817909092956`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 274}], {
             RGBColor[
             0.9936320526564568, 0.9887879294674269, 0.5482664139500156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 284}], {
             RGBColor[
             0.9927834825673074, 0.9869729238503331, 0.4559047965136599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 345}], {
             RGBColor[
             0.9935242761434537, 0.989564176760924, 0.6097171825700566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 389}], {
             RGBColor[
             0.9921192445829787, 0.9848127689855177, 0.4464812739512585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 456}], {
             RGBColor[
             0.9936179389821218, 0.9887577417451359, 0.5467302275981534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 472}], {
             RGBColor[
             0.989577219703074, 0.9879319674881033, 0.6751301224417791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 195}], {
             RGBColor[
             0.9751031140946667, 0.9775059770099579, 0.7172412869400898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 216}], {
             RGBColor[
             0.8204615959377007, 0.8561447139783901, 0.7213698865132552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 217}], {
             RGBColor[
             0.971835135961461, 0.9750687242690361, 0.7227731214944033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 292}], {
             RGBColor[
             0.9918420131472085, 0.988907784625876, 0.640450919163509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 398}], {
             RGBColor[
             0.9549787089952414, 0.8479725403517779, 0.36462606119468544`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 399}], {
             RGBColor[
             0.9806264400071044, 0.9460167489206739, 0.40422260458576553`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 464}], {
             RGBColor[
             0.9092750776963129, 0.9255716391317712, 0.7302100007690232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 481}], {
             RGBColor[
             0.9930830766292001, 0.9876137252551154, 0.4885137612704466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 496}], {
             RGBColor[
             0.8932288064724898, 0.9129910118994506, 0.7286226420111181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 172}], {
             RGBColor[
             0.9231624154869924, 0.9402091257700239, 0.9444426559834296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 197}], {
             RGBColor[
             0.6576432361434771, 0.7299215611438062, 0.9683978952137045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 201}], {
             RGBColor[
             0.9273301357538877, 0.9400463977624225, 0.7382668299120074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 223}], {
             RGBColor[
             0.9261976014927262, 0.9414642531841173, 0.894141769058828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 236}], {
             RGBColor[
             0.9279444499535925, 0.9413603537188983, 0.805131139442107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 289}], {
             RGBColor[
             0.9199315264186336, 0.9154548781537901, 0.6784258493609493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 314}], {
             RGBColor[
             0.9276830906844811, 0.9408013326697444, 0.7766837959217698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 411}], {
             RGBColor[
             0.9015523444691984, 0.9241867602927865, 0.9852498511411713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 466}], {
             RGBColor[
             0.9260096163117641, 0.9413865164807906, 0.8972571699974247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 470}], {
             RGBColor[
             0.9074881188872703, 0.8727258397258988, 0.6340150251525121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 493}], {
             RGBColor[
             0.9283128584305369, 0.9421483421992717, 0.8452301286039356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 199}], {
             RGBColor[
             0.8214354247759601, 0.8592773938883382, 0.8833462518068363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[
             0.9612555101752576, 0.878565233567076, 0.532294413946222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 219}], {
             RGBColor[
             0.9914259222759942, 0.9907224127644463, 0.7917581870960331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 244}], {
             RGBColor[
             0.9869754385075247, 0.9886951558285859, 0.8571459110430137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 295}], {
             RGBColor[
             0.9674441374538272, 0.9741287434823087, 0.8902073091477671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 341}], {
             RGBColor[
             0.9751061978837403, 0.9798430956054653, 0.8772374394253362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 374}], {
             RGBColor[
             0.9304987145093814, 0.7467984768601668, 0.5070384693128915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 376}], {
             RGBColor[
             0.9776840794917414, 0.9411790933605771, 0.5586371326827893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 397}], {
             RGBColor[
             0.9923760015426563, 0.9898957510199407, 0.6873649448474137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 455}], {
             RGBColor[
             0.9630964232214039, 0.9708761730762084, 0.8972183374499647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 198}], {
             RGBColor[
             0.9587947948152994, 0.8652173773581531, 0.3332253579480621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 250}], {
             RGBColor[
             0.9457878145502558, 0.866761540569666, 0.6071922471836215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 365}], {
             RGBColor[
             0.9531987869222773, 0.8722886316303661, 0.5946474040489473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 394}], {
             RGBColor[
             0.9628404495755424, 0.8776985923961159, 0.49857982094510783`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 467}], {
             RGBColor[
             0.9608676145546942, 0.8768827744154477, 0.5312748027739345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 479}], {
             RGBColor[
             0.9372258791427828, 0.7888285595765239, 0.26834867274152935`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 198}], {
             RGBColor[
             0.9899610029136222, 0.9774282205306668, 0.44696519612849095`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 227}], {
             RGBColor[
             0.9759913711688812, 0.9782544398448184, 0.7225616032194613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 250}], {
             RGBColor[
             0.9769540226485787, 0.9789723837421797, 0.7209320853640503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 263}], {
             RGBColor[
             0.9916417140468241, 0.9830976538326976, 0.4534944415053149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 270}], {
             RGBColor[
             0.9241349309595388, 0.9375033010090885, 0.7383408622108245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 479}], {
             RGBColor[
             0.9683920872411056, 0.9010394027490376, 0.38208851092195817`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 485}], {
             RGBColor[
             0.9868185128303878, 0.9863293043681527, 0.7042340765573364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 190}], {
             RGBColor[
             0.9789607286910019, 0.9406917389982352, 0.37276683320789294`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 356}], {
             RGBColor[
             0.889933907068214, 0.9088198315076755, 0.7005480022572146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 360}], {
             RGBColor[
             0.9922887375121424, 0.9853080337326091, 0.45364257860899293`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.986396887795763, 0.9867306986433695, 0.7617467418413485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 193}], {
             RGBColor[
             0.9220805101151577, 0.9365545016932377, 0.7940250523719227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 247}], {
             RGBColor[
             0.9243753483030388, 0.9383843433725311, 0.794243936086909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 278}], {
             RGBColor[
             0.9881050513963427, 0.9705333995552985, 0.4936881274762098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 370}], {
             RGBColor[
             0.9551998126842027, 0.8477982635191684, 0.4269893971189249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 401}], {
             RGBColor[
             0.9892327513563968, 0.9743373963171026, 0.4980690288727508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 410}], {
             RGBColor[
             0.9723850899760201, 0.9762807227716186, 0.7854650606880154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 422}], {
             RGBColor[
             0.992155561773151, 0.9841967221613361, 0.5094235954154077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 428}], {
             RGBColor[
             0.9816971542450095, 0.983225645056325, 0.7697021648559516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 437}], {
             RGBColor[
             0.9498455757444334, 0.958693611363393, 0.7966733091178098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 451}], {
             RGBColor[
             0.5865286254446, 0.6476237625558484, 0.7679966085305111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 166}], {
             RGBColor[
             0.7893567336416198, 0.835930974836538, 0.9794906930074115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 192}], {
             RGBColor[
             0.8418952487827964, 0.8738355388463654, 0.7993314301791696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 239}], {
             RGBColor[
             0.8371747161559224, 0.872667099724965, 0.9345239506183751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 251}], {
             RGBColor[
             0.8184596417932914, 0.8588324657364796, 0.9717135751619463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 272}], {
             RGBColor[
             0.7851794085347799, 0.6547820292014226, 0.5960228426715775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 344}], {
             RGBColor[
             0.8420038260830139, 0.8740677747126818, 0.8111493992464291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 435}], {
             RGBColor[
             0.8422916749604514, 0.8746834543555349, 0.8424799731581492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 439}], {
             RGBColor[
             0.8413952371807174, 0.8727660645884464, 0.7449082530068002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 453}], {
             RGBColor[
             0.7835919883467529, 0.6475739248789965, 0.5946982603554583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 167}], {
             RGBColor[
             0.9651345874236454, 0.8877435622621184, 0.5050719280695807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 235}], {
             RGBColor[
             0.9941076738311097, 0.9905868164066032, 0.6568475561902656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 237}], {
             RGBColor[
             0.9429489215048621, 0.7961250671818296, 0.4870315068463004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 274}], {
             RGBColor[
             0.9943532751282216, 0.9911121327470253, 0.6835797417053865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 284}], {
             RGBColor[
             0.9935047050390722, 0.9892971271299315, 0.5912181242690308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 300}], {
             RGBColor[
             0.9193723469546028, 0.935341516539118, 0.8639426764411817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 305}], {
             RGBColor[
             0.9885133531100336, 0.9725406008749395, 0.564984581138334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 389}], {
             RGBColor[
             0.9928404670547435, 0.9871369722651161, 0.5817946017066293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 432}], {
             RGBColor[
             0.9502157368576716, 0.8285952911802743, 0.49306787071376734`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 460}], {
             RGBColor[
             0.9914409529299866, 0.9907286283261424, 0.7915090902612947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 183}], {
             RGBColor[
             0.8685582061287598, 0.8977720757927401, 0.9666958890576296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 188}], {
             RGBColor[
             0.975856875514673, 0.9781111397190738, 0.7193779199729885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 202}], {
             RGBColor[
             0.976754058777697, 0.9800301239995398, 0.8170307813798761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 243}], {
             RGBColor[
             0.9637141946284129, 0.9374829585227782, 0.6439807393648257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 273}], {
             RGBColor[
             0.9760998796101668, 0.9786309009078522, 0.7458274161200493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 279}], {
             RGBColor[
             0.9126494006990444, 0.9325934410677907, 0.9709904459951337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 285}], {
             RGBColor[
             0.9672225989737008, 0.9493176301919489, 0.6576102277397017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 287}], {
             RGBColor[
             0.9658079509140762, 0.9445456901116749, 0.6521145871619302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 335}], {
             RGBColor[
             0.9337167064612004, 0.9493919388257531, 0.972999864425734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 354}], {
             RGBColor[
             0.9568816901068307, 0.9673630155982027, 0.9578722309795371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 396}], {
             RGBColor[
             0.8969213837724983, 0.9200523472962092, 0.9694902937001133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 409}], {
             RGBColor[
             0.9424524658722717, 0.8569702269119261, 0.6071714486777469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 430}], {
             RGBColor[
             0.9764984927653954, 0.9794834941409138, 0.7892139981114348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 459}], {
             RGBColor[
             0.9474204680781293, 0.8766667001695548, 0.6111688198665793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 477}], {
             RGBColor[
             0.9054876417941915, 0.9268828489178277, 0.9703073510374113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 226}], {
             RGBColor[
             0.9247393654358229, 0.7236936458965348, 0.2909173325935972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 284}], {
             RGBColor[
             0.9850428045265942, 0.9611275331041846, 0.4032376327496241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 345}], {
             RGBColor[
             0.9857835981027405, 0.9637187860147755, 0.5570500188060208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 389}], {
             RGBColor[
             0.9843785665422655, 0.9589673782393693, 0.3938141101872227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 456}], {
             RGBColor[
             0.9858772609414086, 0.9629123509989872, 0.4940630638341176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 472}], {
             RGBColor[
             0.9818365416623607, 0.9620865767419547, 0.6224629586777433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 207}], {
             RGBColor[
             0.8617935513726278, 0.8926348013744942, 0.9866798323337483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 209}], {
             RGBColor[
             0.9322231783819015, 0.9204830675217084, 0.6725767650217498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 231}], {
             RGBColor[
             0.9260122952347949, 0.9431584501349396, 0.9691377094494544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 233}], {
             RGBColor[
             0.9382239285381248, 0.9407250068417893, 0.6958885462320956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 266}], {
             RGBColor[
             0.8638341083096677, 0.8942618860866474, 0.98687446247603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 317}], {
             RGBColor[
             0.8083659173859232, 0.8507855971946705, 0.9813841556905634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 326}], {
             RGBColor[
             0.9416511186012038, 0.9517022340206731, 0.7588182802530385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 343}], {
             RGBColor[
             0.9374190094689305, 0.9515339436371125, 0.9439351156991718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 355}], {
             RGBColor[
             0.8083659173859232, 0.8507855971946705, 0.9813841556905634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 379}], {
             RGBColor[
             0.9343718927664634, 0.9493930242864733, 0.9549870913605644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 440}], {
             RGBColor[
             0.9409967148476166, 0.9530134167540336, 0.8846432787696209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 180}], {
             RGBColor[
             0.9329754376216488, 0.9472894229379135, 0.9130568044385543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 205}], {
             RGBColor[
             0.7646497994593113, 0.8165328661828763, 0.9770538414058694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 259}], {
             RGBColor[
             0.933064540162267, 0.9394736304226895, 0.6996076689694362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 316}], {
             RGBColor[
             0.5281197053035239, 0.6052015592399045, 0.9608305174906883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 331}], {
             RGBColor[
             0.9351106862615226, 0.9461252149845409, 0.7288612421155859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 348}], {
             RGBColor[
             0.9321063181884136, 0.9469300197169201, 0.927460362656253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 372}], {
             RGBColor[
             0.9149538447951739, 0.9345876678402183, 0.976644020958991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 404}], {
             RGBColor[
             0.9176759607768739, 0.8875643387454921, 0.6398259439465588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 418}], {
             RGBColor[
             0.9311949817444323, 0.9331671708861409, 0.6923447875526306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 431}], {
             RGBColor[
             0.9358351744702171, 0.9476748220059441, 0.8077173126090219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 444}], {
             RGBColor[
             0.8550639612661151, 0.8872688088934183, 0.9860379580218132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 486}], {
             RGBColor[
             0.9346602307958665, 0.9479861282126623, 0.885135421436797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 178}], {
             RGBColor[
             0.8701055095768389, 0.8972489966649333, 0.8859373927681636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 185}], {
             RGBColor[
             0.8692758764258632, 0.8969059220364054, 0.8996865611015998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 277}], {
             RGBColor[
             0.8707293686546289, 0.8975069784260464, 0.8755984333536437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 288}], {
             RGBColor[
             0.8619698482573309, 0.8923381996641775, 0.9515112852456045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 313}], {
             RGBColor[
             0.8656429072830186, 0.8778029726073023, 0.6805440794326443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 333}], {
             RGBColor[
             0.8424747141941609, 0.7937162448107488, 0.6214494611419986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 358}], {
             RGBColor[
             0.8689619173045326, 0.8967760918713539, 0.904889676242209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 361}], {
             RGBColor[
             0.8654096178138445, 0.8770160324488058, 0.6796377938979223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 386}], {
             RGBColor[
             0.868347342918248, 0.8965219495687837, 0.9150747642904747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 498}], {
             RGBColor[
             0.8609237661853724, 0.8618842015779187, 0.6622111074033071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.9371146009970068, 0.9513011254256275, 0.9443363570379489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 344}], {
             RGBColor[
             0.9419437109240983, 0.9527018004133443, 0.8209618056660029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 387}], {
             RGBColor[
             0.9077643155908961, 0.8299032715766459, 0.6244029245843528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 435}], {
             RGBColor[
             0.9422315598015358, 0.9533174800561972, 0.8522923795777231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 439}], {
             RGBColor[
             0.9413351220218018, 0.9514000902891089, 0.754720659426374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 453}], {
             RGBColor[
             0.8835318731878373, 0.7262079505796589, 0.6045106667750322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 172}], {
             RGBColor[
             0.9603266542953266, 0.8857553583553133, 0.5847518225379034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[
             0.9644943745622219, 0.8855926303477119, 0.3785759964664813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 218}], {
             RGBColor[
             0.9648473294928153, 0.8863475652550338, 0.41699296247624373`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 235}], {
             RGBColor[
             0.9648662465172659, 0.8863880268575289, 0.41905196384534127`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 236}], {
             RGBColor[
             0.9651086887619267, 0.8869065863041876, 0.445440305996581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 274}], {
             RGBColor[
             0.9651118478143778, 0.886913343197951, 0.4457841493604622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 284}], {
             RGBColor[
             0.9642632777252285, 0.8850983375808572, 0.3534225319241064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 289}], {
             RGBColor[
             0.9570957652269678, 0.8610011107390794, 0.3187350159154232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 300}], {
             RGBColor[
             0.890130919640759, 0.8311427269900438, 0.6261470840962573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 305}], {
             RGBColor[
             0.9592719257961899, 0.8683418113258654, 0.32718898879340963`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 432}], {
             RGBColor[
             0.9209743095438278, 0.7243965016312001, 0.255272278368843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 456}], {
             RGBColor[
             0.9650977341400429, 0.88688315547566, 0.4442479630085998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 493}], {
             RGBColor[
             0.9654770972388712, 0.887694574784561, 0.48553929515840955`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 181}], {
             RGBColor[
             0.9826717217445214, 0.986183845264973, 0.8957065068991721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 189}], {
             RGBColor[
             0.9839971391432627, 0.9871723393907825, 0.8934629209673248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 232}], {
             RGBColor[
             0.9900736690119196, 0.9901632212884277, 0.8141685232010173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 280}], {
             RGBColor[
             0.9871150349525022, 0.9792128480463338, 0.6382734322691233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 302}], {
             RGBColor[
             0.9891637069825754, 0.9897869286043365, 0.8292489489334938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 326}], {
             RGBColor[
             0.990064174829867, 0.9885774996972816, 0.6993460315907684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 338}], {
             RGBColor[
             0.9745865756673022, 0.936951413055223, 0.5896027337471355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 346}], {
             RGBColor[
             0.9825344684846906, 0.9860814820085229, 0.8959388408666823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 370}], {
             RGBColor[
             0.9514746466329611, 0.847251410140772, 0.5609491621767485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 383}], {
             RGBColor[
             0.9908547793475941, 0.9902685228183217, 0.7853984542998622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 390}], {
             RGBColor[
             0.9883032220298917, 0.9894310959629472, 0.8435094114631364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 395}], {
             RGBColor[
             0.7784711815429751, 0.8253817932621001, 0.9148620211067597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 443}], {
             RGBColor[
             0.9715479161251477, 0.9267013009083462, 0.5777981152285703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 480}], {
             RGBColor[
             0.9467435612820985, 0.828494233265336, 0.5571424198505982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 211}], {
             RGBColor[
             0.9675057404192591, 0.8996599001196643, 0.5192892331520964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 236}], {
             RGBColor[
             0.9681882074122952, 0.8991158515641415, 0.44791815898826065`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 289}], {
             RGBColor[
             0.9601752838773363, 0.8732103759990334, 0.3212128689071029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 308}], {
             RGBColor[
             0.8226602627913133, 0.7880405666645135, 0.6216454571550878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 362}], {
             RGBColor[
             0.8949873824469763, 0.8447688792860075, 0.6287944236078187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 369}], {
             RGBColor[
             0.9597453494329635, 0.89532877753811, 0.597653476574761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 456}], {
             RGBColor[
             0.9681772527904112, 0.8990924207356139, 0.4467258160002795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 470}], {
             RGBColor[
             0.947731876345973, 0.830481337571142, 0.27680204469866565`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 214}], {
             RGBColor[
             0.9933902522459609, 0.990850109640677, 0.7094406687776489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 223}], {
             RGBColor[
             0.9915612985631092, 0.9907783943381803, 0.7895146516759395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 268}], {
             RGBColor[
             0.9928200090728253, 0.9896304171537686, 0.6473732185147687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 466}], {
             RGBColor[
             0.991373313382147, 0.9907006576348536, 0.792630052614536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 491}], {
             RGBColor[
             0.9819819538119774, 0.9535925826944843, 0.5609273049412411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 192}], {
             RGBColor[
             0.9591749085186705, 0.9662958303724822, 0.8107977198076082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 208}], {
             RGBColor[
             0.93616982855491, 0.8876015014079572, 0.6349605603899716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 219}], {
             RGBColor[
             0.9579721757919634, 0.9665820919131347, 0.8876911921267354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 238}], {
             RGBColor[
             0.9390781155641044, 0.8991318902702178, 0.6373006363838394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 258}], {
             RGBColor[
             0.9201227713757444, 0.8239802670573746, 0.6220487215107713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 272}], {
             RGBColor[
             0.9024590682706539, 0.7472423207275394, 0.607489132300016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 293}], {
             RGBColor[
             0.9595116706637747, 0.9670161305489846, 0.8474522010471661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 403}], {
             RGBColor[
             0.9578313882015561, 0.9665238726264253, 0.8900244068463881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 471}], {
             RGBColor[
             0.9589490564596197, 0.9658127556553187, 0.7862151169772829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 497}], {
             RGBColor[
             0.9510994148220018, 0.9402097984059794, 0.6812552234447579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 197}], {
             RGBColor[
             0.7192409691373364, 0.7776783793713645, 0.9261825485814255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 201}], {
             RGBColor[
             0.988927868747747, 0.9878032159899808, 0.6960514832797284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 211}], {
             RGBColor[
             0.9888597159544157, 0.9896612205019794, 0.8342868669736638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 218}], {
             RGBColor[
             0.9892808236783404, 0.9885581508973027, 0.7344684492894908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 235}], {
             RGBColor[
             0.9892997407027909, 0.9885986124997979, 0.7365274506585884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 236}], {
             RGBColor[
             0.9895421829474518, 0.9891171719464565, 0.7629157928098281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 289}], {
             RGBColor[
             0.9815292594124929, 0.9632116963813484, 0.6362105027286704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 300}], {
             RGBColor[
             0.9145644138262841, 0.9333533126323128, 0.9436225709095045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 308}], {
             RGBColor[
             0.8440142383264699, 0.8780418870468285, 0.9366430909766552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 314}], {
             RGBColor[
             0.9892808236783404, 0.9885581508973027, 0.7344684492894908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 466}], {
             RGBColor[
             0.9876073493056234, 0.9891433347083489, 0.8550418233651458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 470}], {
             RGBColor[
             0.9690858518811296, 0.9204826579534571, 0.5917996785202331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 493}], {
             RGBColor[
             0.9899105914243962, 0.98990516042683, 0.8030147819716567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 242}], {
             RGBColor[
             0.6302510746423557, 0.6953513845400776, 0.8630289836442976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 249}], {
             RGBColor[
             0.6113565874823899, 0.6825050336570264, 0.9507717396812791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 269}], {
             RGBColor[
             0.6276031393371131, 0.6942563952425262, 0.9069121242890734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 282}], {
             RGBColor[
             0.6306803370557936, 0.6931678370758239, 0.6842909659360796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 310}], {
             RGBColor[
             0.62604959990583, 0.6775732764319031, 0.6640903096262615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 323}], {
             RGBColor[
             0.5781930232449579, 0.4911191519847523, 0.5832592160024372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 406}], {
             RGBColor[
             0.6305424047206638, 0.6954718570142995, 0.8582008903086606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 419}], {
             RGBColor[
             0.6319741019154379, 0.6959350692909103, 0.8251092867171579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 499}], {
             RGBColor[
             0.5796922974345877, 0.657726080933873, 0.9640222424379599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 210}], {
             RGBColor[
             0.8239403765529554, 0.86320424817703, 0.9828696615093986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 225}], {
             RGBColor[
             0.9343551308804574, 0.8851157147638836, 0.6345548584534384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 252}], {
             RGBColor[
             0.9130777569378568, 0.9335274348195323, 0.9915713656425107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 309}], {
             RGBColor[
             0.9579257345922236, 0.9656184496528284, 0.836511535495878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 320}], {
             RGBColor[
             0.9529934686359627, 0.963952594619472, 0.945420621518007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 393}], {
             RGBColor[
             0.9392981010697621, 0.904230786173752, 0.6410431766217866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 424}], {
             RGBColor[
             0.9502423339160337, 0.9411482533923003, 0.6835594545845975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 182}], {
             RGBColor[
             0.9394920563686971, 0.9512362994668068, 0.8594295167948105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 208}], {
             RGBColor[
             0.9160998918391834, 0.8715982786547563, 0.6330462719093816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 351}], {
             RGBColor[
             0.9102012885116852, 0.9312114521567005, 0.9905216031859574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 359}], {
             RGBColor[
             0.5313816474204152, 0.6078025433408535, 0.9611416444417675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 371}], {
             RGBColor[
             0.8364021555792454, 0.8726390822494283, 0.984191452745463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 463}], {
             RGBColor[
             0.9272110229754629, 0.9438972842689022, 0.961728559588043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 483}], {
             RGBColor[
             0.9379374597716057, 0.9505934338225992, 0.8851932055756438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 178}], {
             RGBColor[
             0.9929409769549566, 0.9913489268093265, 0.7666498102298037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 244}], {
             RGBColor[
             0.9888972094047297, 0.9894898574818396, 0.825297193892669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 261}], {
             RGBColor[
             0.9819991900988243, 0.9843453259779653, 0.836973741285995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 262}], {
             RGBColor[
             0.9949123147658029, 0.9920048965686231, 0.722405367360196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 299}], {
             RGBColor[
             0.9945258677865662, 0.9911783255558186, 0.6803429985445772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 313}], {
             RGBColor[
             0.9884783746611363, 0.9719029027516957, 0.5612564968942844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 328}], {
             RGBColor[
             0.9941150314704905, 0.9902995882176562, 0.6356260009275854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 376}], {
             RGBColor[
             0.9796058503889464, 0.9419737950138307, 0.5267884155324445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 391}], {
             RGBColor[
             0.9089922581166774, 0.9269973141450414, 0.8600258165088124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 407}], {
             RGBColor[
             0.9926954576831266, 0.9912473982808674, 0.7707186999475345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 448}], {
             RGBColor[
             0.9791664585321558, 0.9822326794137162, 0.8417688169336461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 455}], {
             RGBColor[
             0.9650181941186089, 0.971670874729462, 0.8653696202996201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 475}], {
             RGBColor[
             0.9774744176858243, 0.9347839720220019, 0.5185082019681071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 478}], {
             RGBColor[
             0.9917532075187886, 0.9908577536231888, 0.7863342236358741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 482}], {
             RGBColor[
             0.9898153895530255, 0.9764129679280633, 0.5664505472751974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 194}], {
             RGBColor[
             0.7229595404684355, 0.77337874347569, 0.6827237445796903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 290}], {
             RGBColor[
             0.6175821877752233, 0.6983252193691925, 0.9644697377940403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 297}], {
             RGBColor[
             0.7256534332303868, 0.7807690843319597, 0.8374719519966547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 412}], {
             RGBColor[
             0.70723494510937, 0.7688957318512728, 0.9527987935184993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 484}], {
             RGBColor[
             0.7076274754010992, 0.7216600878634916, 0.6231615670106305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 186}], {
             RGBColor[
             0.9920968253080775, 0.9890647558898158, 0.6399787892973552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 244}], {
             RGBColor[
             0.9871109833249307, 0.9887512070939263, 0.8548995826398518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 261}], {
             RGBColor[
             0.9802129640190254, 0.983606675590052, 0.8665761300331776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 288}], {
             RGBColor[
             0.9830190895556496, 0.9856994794206575, 0.8618260914544272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 313}], {
             RGBColor[
             0.9866921485813374, 0.9711642523637823, 0.590858885641467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 321}], {
             RGBColor[
             0.9916155199510335, 0.9908008162755131, 0.7886160629575796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 391}], {
             RGBColor[
             0.9072060320368783, 0.9262586637571282, 0.889628205255995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 407}], {
             RGBColor[
             0.9909092316033277, 0.9905087478929542, 0.8003210886947172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 455}], {
             RGBColor[
             0.96323196803881, 0.9709322243415488, 0.8949720090468027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 475}], {
             RGBColor[
             0.9756881916060254, 0.9340453216340887, 0.5481105907152899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 498}], {
             RGBColor[
             0.9819730074836911, 0.9552454813343987, 0.5725259136121299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 222}], {
             RGBColor[
             0.8981484333103995, 0.9184453100129377, 0.8564912482043515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 245}], {
             RGBColor[
             0.8975810283795429, 0.9170077325218999, 0.7784535066416008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 255}], {
             RGBColor[
             0.8967885531961437, 0.917882964638368, 0.879027980954494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 294}], {
             RGBColor[
             0.8949119511789215, 0.9171069414777746, 0.9101281328702076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 296}], {
             RGBColor[
             0.7978435623755142, 0.8420007218541934, 0.9804852480917444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 312}], {
             RGBColor[
             0.8965587646008248, 0.917787941148906, 0.8828361726527506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 327}], {
             RGBColor[
             0.879625079393448, 0.9064299454813418, 0.9684237920753405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 334}], {
             RGBColor[
             0.8910837727450283, 0.8959454866846188, 0.680550423662774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 385}], {
             RGBColor[
             0.8932801040085188, 0.9164321307362537, 0.9371720635688845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 415}], {
             RGBColor[
             0.8936922858360828, 0.9166025785145413, 0.9303411439937708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 438}], {
             RGBColor[
             0.8406193118213405, 0.8759022596875117, 0.9846200847481419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 205}], {
             RGBColor[
             0.8203128264739123, 0.858813170640981, 0.9019506108630473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 230}], {
             RGBColor[
             0.9909922639048073, 0.9888729771385418, 0.6775458987668479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 331}], {
             RGBColor[
             0.9907737132761236, 0.9884055194426455, 0.6537580115727637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 382}], {
             RGBColor[
             0.9905082010116227, 0.9903429114372679, 0.8069672034331707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 413}], {
             RGBColor[
             0.7287757623806213, 0.7846467498774699, 0.8946436370776796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 418}], {
             RGBColor[
             0.9868580087590332, 0.9754474753442455, 0.6172415570098084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 474}], {
             RGBColor[
             0.9507046261521015, 0.8407209992254938, 0.5433125530009196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 490}], {
             RGBColor[
             0.961973824919356, 0.9704119498288513, 0.9158226965061755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 189}], {
             RGBColor[
             0.979988942101067, 0.9845963663008515, 0.9187576806898274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 302}], {
             RGBColor[
             0.9851555099403799, 0.9872109555144055, 0.8545437086559964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 370}], {
             RGBColor[
             0.9474664495907655, 0.844675437050841, 0.5862439218992512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 390}], {
             RGBColor[
             0.9842950249876962, 0.9868551228730162, 0.8688041711856391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 422}], {
             RGBColor[
             0.9844221986797138, 0.9810738956930087, 0.668678120195734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 443}], {
             RGBColor[
             0.9675397190829522, 0.9241253278184152, 0.603092874951073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 451}], {
             RGBColor[
             0.578795262351163, 0.644500936087521, 0.9272511333108374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 237}], {
             RGBColor[
             0.9433348230843995, 0.7962846474021865, 0.48063611899209097`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 351}], {
             RGBColor[
             0.965857050039552, 0.9722366649418004, 0.861168831097233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 359}], {
             RGBColor[
             0.587037408948282, 0.6488277561259532, 0.8317888723530431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 371}], {
             RGBColor[
             0.8920579171071124, 0.9136642950345281, 0.8548386806567386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 460}], {
             RGBColor[
             0.991826854509524, 0.9908882085464994, 0.7851137024070853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 463}], {
             RGBColor[
             0.9828667845033299, 0.9849224970540018, 0.8323757874993186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 483}], {
             RGBColor[
             0.9935932212994726, 0.9916186466076989, 0.7558404334869194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 202}], {
             RGBColor[
             0.8866393458610011, 0.9091032885845189, 0.8288865228237321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 206}], {
             RGBColor[
             0.8692029926739908, 0.8982529565424324, 0.9656044336238178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 243}], {
             RGBColor[
             0.873599481711717, 0.8665561231077573, 0.6558364808086817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 273}], {
             RGBColor[
             0.8859851666934708, 0.9077040654928313, 0.7576831575639054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 279}], {
             RGBColor[
             0.8225346877823485, 0.8616666056527699, 0.9828461874389898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 283}], {
             RGBColor[
             0.8863714718274499, 0.9085303331129722, 0.7997300873985819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 285}], {
             RGBColor[
             0.8771078860570048, 0.878390794776928, 0.6694659691835577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 396}], {
             RGBColor[
             0.8068066708558024, 0.8491255118811885, 0.9813460351439693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 430}], {
             RGBColor[
             0.8863837798486994, 0.9085566587258931, 0.8010697395552908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 477}], {
             RGBColor[
             0.8153729288774956, 0.8559560135028068, 0.9821630924812673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 221}], {
             RGBColor[
             0.9780182527474576, 0.9801362504330728, 0.7485016805358371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 253}], {
             RGBColor[
             0.9922299067709628, 0.9847537862771856, 0.4836684878425451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 287}], {
             RGBColor[
             0.9832884826169119, 0.9545922630593418, 0.4489327434503261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 301}], {
             RGBColor[
             0.9507045672268772, 0.9590456693413258, 0.7697710293203313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 316}], {
             RGBColor[
             0.5862804912255636, 0.6470930285515473, 0.7409887300952827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 336}], {
             RGBColor[
             0.9940308846982099, 0.9896409908766318, 0.5916768203887874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 354}], {
             RGBColor[
             0.9743622218096664, 0.9774095885458695, 0.7546903872679331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 388}], {
             RGBColor[
             0.9940981719095893, 0.9897849114179917, 0.599000618098898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 436}], {
             RGBColor[
             0.9684265881659242, 0.9729828026930747, 0.7647378667655969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 473}], {
             RGBColor[
             0.9655325544638825, 0.8892171769818673, 0.4084951398773443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 187}], {
             RGBColor[
             0.9677795081774027, 0.9746094889983554, 0.8999675434202185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 216}], {
             RGBColor[
             0.8187197948618438, 0.8574111268781424, 0.8946476033647418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 224}], {
             RGBColor[
             0.9393772929848963, 0.9522296062977308, 0.9065250283288391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 286}], {
             RGBColor[
             0.97935900970972, 0.9488833258437697, 0.5793431623342133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 330}], {
             RGBColor[
             0.9856163413465091, 0.9699907747459958, 0.6036517141452106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 333}], {
             RGBColor[
             0.962694322341504, 0.8867344499387009, 0.5455134356842576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 357}], {
             RGBColor[
             0.9911536526134748, 0.9884788316580781, 0.6413698789918195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 358}], {
             RGBColor[
             0.9891815254518758, 0.9897942969993059, 0.8289536507844679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 361}], {
             RGBColor[
             0.9856292259611876, 0.9700342375767579, 0.6037017684401813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 386}], {
             RGBColor[
             0.988566951065591, 0.989540154696736, 0.8391387388327337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 398}], {
             RGBColor[
             0.9532369079193844, 0.8492389532515301, 0.5379037780461721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 441}], {
             RGBColor[
             0.9921248620255623, 0.990556150386199, 0.7470800298878211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 464}], {
             RGBColor[
             0.9075332766204559, 0.9268380520315235, 0.9034877176205098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 481}], {
             RGBColor[
             0.9913412755533432, 0.9888801381548677, 0.6617914781219332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 288}], {
             RGBColor[
             0.9839611639885695, 0.98415395888906, 0.705552681774796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 295}], {
             RGBColor[
             0.9685217567041531, 0.9726392742160515, 0.731687571064974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 321}], {
             RGBColor[
             0.9925575943839533, 0.9892552957439156, 0.6323426532779484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 341}], {
             RGBColor[
             0.9761838171340662, 0.9783536263392082, 0.7187177013425429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 373}], {
             RGBColor[
             0.99163967157805, 0.9831300503619049, 0.4501458872666785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 397}], {
             RGBColor[
             0.9934536207929823, 0.9884062817536834, 0.5288452067646205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 455}], {
             RGBColor[
             0.9641740424717298, 0.9693867038099513, 0.7386985993671715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 495}], {
             RGBColor[
             0.9923734274467032, 0.9891791379824881, 0.635394776036938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 498}], {
             RGBColor[
             0.982915081916611, 0.9536999608028012, 0.4162525039324987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 216}], {
             RGBColor[
             0.7970038184660401, 0.8420964887121403, 0.9708646111411015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 224}], {
             RGBColor[
             0.9176613165890926, 0.9369149681317287, 0.9827420361051988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 260}], {
             RGBColor[
             0.9487081449014096, 0.9612671989669516, 0.9717079110103084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 328}], {
             RGBColor[
             0.9697831958439121, 0.9739032250352129, 0.7551945657845639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 398}], {
             RGBColor[
             0.9315209315235807, 0.833924315085528, 0.6141207858225317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 399}], {
             RGBColor[
             0.9571686625354437, 0.931968523654424, 0.6537173292136118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 407}], {
             RGBColor[
             0.9683636220565484, 0.9748510350984241, 0.890287264804513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 464}], {
             RGBColor[
             0.8858173002246522, 0.9115234138655214, 0.9797047253968695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 478}], {
             RGBColor[
             0.9674213718922102, 0.9744613904407456, 0.9059027884928527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 481}], {
             RGBColor[
             0.9696252991575395, 0.9735654999888657, 0.7380084858982929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 200}], {
             RGBColor[
             0.9711719676510482, 0.9121170485830408, 0.3809909915670824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 228}], {
             RGBColor[
             0.9809213504297777, 0.9469734438288868, 0.4086086367486075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 256}], {
             RGBColor[
             0.9646474946494145, 0.8862496872833057, 0.3757412474409032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 279}], {
             RGBColor[
             0.9298333571682618, 0.9420056695791035, 0.7355282183543488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 298}], {
             RGBColor[
             0.9926501240726758, 0.9892952260681447, 0.6309303643665086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 318}], {
             RGBColor[
             0.8387525070950281, 0.8704756282905401, 0.7265501716996076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 335}], {
             RGBColor[
             0.9509006629304178, 0.958804167337066, 0.7375376367849491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 409}], {
             RGBColor[
             0.959636422341489, 0.866382455423239, 0.3717092210369617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 430}], {
             RGBColor[
             0.9936824492346127, 0.9888957226522266, 0.5537517704706497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 459}], {
             RGBColor[
             0.9646044245473466, 0.8860789286808677, 0.3757065922257942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 302}], {
             RGBColor[
             0.9864809273391211, 0.9881994496402149, 0.8523001227241491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 346}], {
             RGBColor[
             0.9798516888412363, 0.9844940030444014, 0.9189900146573377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 370}], {
             RGBColor[
             0.9487918669895068, 0.8456639311766505, 0.5840003359674039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 383}], {
             RGBColor[
             0.9881719997041398, 0.9886810438542001, 0.8084496280905176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 390}], {
             RGBColor[
             0.9856204423864374, 0.9878436169988256, 0.8665605852537918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 422}], {
             RGBColor[
             0.9857476160784551, 0.9820623898188182, 0.6664345342638867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 443}], {
             RGBColor[
             0.9688651364816934, 0.9251138219442246, 0.6008492890192256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 451}], {
             RGBColor[
             0.5801206797499041, 0.6454894302133305, 0.92500754737899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 349}], {
             RGBColor[
             0.9773729218292125, 0.9438872535883611, 0.5834018968935049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 378}], {
             RGBColor[
             0.9793297226072768, 0.9419364421217219, 0.3742003048939666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 467}], {
             RGBColor[
             0.978683277160572, 0.9444291191924742, 0.5616859179619842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 487}], {
             RGBColor[
             0.9186446107885713, 0.8991063329248149, 0.6557618545265138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 226}], {
             RGBColor[
             0.9083609754381307, 0.735029326784656, 0.5967142560870367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 237}], {
             RGBColor[
             0.9181086309946918, 0.779291154044204, 0.6048479388203332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 271}], {
             RGBColor[
             0.9692288156998807, 0.9736704110273178, 0.7704661406238424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 311}], {
             RGBColor[
             0.9366956948385494, 0.9521277441554861, 0.9857807138851697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 366}], {
             RGBColor[
             0.9029822219541044, 0.9252455360052723, 0.9825650927450789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 405}], {
             RGBColor[
             0.965361579596501, 0.9733823225980998, 0.9298603312612167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 423}], {
             RGBColor[
             0.9660968392356776, 0.9736863713542101, 0.9176751762491109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 429}], {
             RGBColor[
             0.9672966114717789, 0.974182508006578, 0.8977918453858957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 488}], {
             RGBColor[
             0.6440704665853956, 0.7150857439575667, 0.9608027028920971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 219}], {
             RGBColor[
             0.9931709160383502, 0.9906603900975076, 0.7058780460896287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 251}], {
             RGBColor[
             0.9709380417755523, 0.9753710554469693, 0.8013667187532781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 258}], {
             RGBColor[
             0.9553215116221312, 0.8480585652417476, 0.44023557547366454`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 272}], {
             RGBColor[
             0.9376578085170408, 0.7713206189119124, 0.4256759862629093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 435}], {
             RGBColor[
             0.9947700749427124, 0.9912220440660247, 0.6721331167494811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 453}], {
             RGBColor[
             0.9360703883290138, 0.7641125145894863, 0.42435140394679016`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 497}], {
             RGBColor[
             0.9862981550683887, 0.9642880965903524, 0.4994420774076511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 410}], {
             RGBColor[
             0.9003353492019777, 0.9229816993531594, 0.9769978959989158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 428}], {
             RGBColor[
             0.909647413470967, 0.9299266216378659, 0.961235000166852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 437}], {
             RGBColor[
             0.8777958349703909, 0.9053945879449339, 0.9882061444287102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 220}], {
             RGBColor[
             0.9650822251634825, 0.8892444636189425, 0.34297408665632434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 254}], {
             RGBColor[
             0.9642588416109876, 0.8859800222096035, 0.3423115729226909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 290}], {
             RGBColor[
             0.8844871813955175, 0.9024193108335308, 0.6968720513815436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 297}], {
             RGBColor[
             0.9925584268506809, 0.9848631757962979, 0.5698742655841579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 350}], {
             RGBColor[
             0.9639482372940178, 0.884748579595571, 0.3420616533984366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 377}], {
             RGBColor[
             0.9765992602280829, 0.9327259513736459, 0.3635929741553523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 412}], {
             RGBColor[
             0.9741399387296641, 0.9729898233156111, 0.6852011071060025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 426}], {
             RGBColor[
             0.758092493676453, 0.8019012576114641, 0.6854895393524736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 476}], {
             RGBColor[
             0.9913780625119362, 0.9823384958288639, 0.4413988916760967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.9747648892977292, 0.9793528047713085, 0.867258112510908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 260}], {
             RGBColor[
             0.9542899497428167, 0.9654300998783063, 0.9622593713816663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 292}], {
             RGBColor[
             0.9739660405169548, 0.9790224602709809, 0.8804971041627132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 399}], {
             RGBColor[
             0.9627504673768508, 0.9361314245657788, 0.6442687895849698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 446}], {
             RGBColor[
             0.916395927544797, 0.9356181025007511, 0.9726404050111763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 496}], {
             RGBColor[
             0.8753528338422361, 0.9031056875445556, 0.9686688270103224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 213}], {
             RGBColor[
             0.9812205452049715, 0.9487378312325079, 0.5421662694335814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 332}], {
             RGBColor[
             0.9364597104163486, 0.9161483707513103, 0.6616343215110095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 337}], {
             RGBColor[
             0.9800932527354407, 0.948271666826262, 0.5608484229930994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 420}], {
             RGBColor[
             0.9813171636337317, 0.9476979525357639, 0.4620725994929359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 427}], {
             RGBColor[
             0.9471508100603674, 0.8244394468461584, 0.2958028878785339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 447}], {
             RGBColor[
             0.6187097889005394, 0.6528143704414792, 0.6355765298777123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 454}], {
             RGBColor[
             0.6734246339964871, 0.7038974629631614, 0.6389277349402431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 489}], {
             RGBColor[
             0.9808484274949154, 0.9466953733313295, 0.4110535634869224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 500}], {
             RGBColor[
             0.8587188599778796, 0.8547350083528795, 0.6540667208423006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 201}], {
             RGBColor[
             0.7234086894042315, 0.7775156513637631, 0.7200067225100033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 236}], {
             RGBColor[
             0.7240230036039365, 0.7788296073202389, 0.786871032040103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 289}], {
             RGBColor[
             0.7160100800689776, 0.7529241317551307, 0.6601657419589453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 314}], {
             RGBColor[
             0.723761644334825, 0.778270586271085, 0.7584236885197657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 411}], {
             RGBColor[
             0.6976308981195423, 0.7616560138941271, 0.9669897437391672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 466}], {
             RGBColor[
             0.7220881699621081, 0.7788557700821312, 0.8789970625954207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 470}], {
             RGBColor[
             0.7035666725376143, 0.7101950933272394, 0.615754917750508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 493}], {
             RGBColor[
             0.724391412080881, 0.7796175958006123, 0.8269700212019315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 270}], {
             RGBColor[
             0.9209933784366144, 0.9272761330853356, 0.6946721490984786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 479}], {
             RGBColor[
             0.9652505347181812, 0.8908122348252845, 0.3384197978096124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 244}], {
             RGBColor[
             0.8175272020431393, 0.8574743758261916, 0.9397473070665396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 245}], {
             RGBColor[
             0.8229373879047093, 0.8586955532702808, 0.771013726143549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 262}], {
             RGBColor[
             0.8235423074042125, 0.8599894149129751, 0.8368554805340667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 376}], {
             RGBColor[
             0.8082358430273561, 0.8099583133581827, 0.6412385287063151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 448}], {
             RGBColor[
             0.8077964511705654, 0.8502171977580681, 0.9562189301075168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 455}], {
             RGBColor[
             0.7936481867570186, 0.839655393073814, 0.9798197334734907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 475}], {
             RGBColor[
             0.806104410324234, 0.8027684903663539, 0.6329583151419778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 482}], {
             RGBColor[
             0.8184453821914351, 0.8443974862724153, 0.680900660449068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 228}], {
             RGBColor[
             0.9590524860969354, 0.871567124181541, 0.30568393598348653`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 256}], {
             RGBColor[
             0.9427786303165722, 0.8108433676359599, 0.27281654667578215`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 298}], {
             RGBColor[
             0.9707812597398335, 0.9138889064207989, 0.5280056636013876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 452}], {
             RGBColor[
             0.9713426116098536, 0.9141210398451372, 0.5187026103830852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 468}], {
             RGBColor[
             0.5641150516591029, 0.5710523644678476, 0.6057836454009806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 218}], {
             RGBColor[
             0.9934485439452356, 0.9883954228897014, 0.5282926232180687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 235}], {
             RGBColor[
             0.9934674609696861, 0.9884358844921965, 0.5303516245871662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 236}], {
             RGBColor[
             0.993709903214347, 0.9889544439388551, 0.5567399667384061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 289}], {
             RGBColor[
             0.9856969796793882, 0.9630489683737471, 0.43003467665724826`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 300}], {
             RGBColor[
             0.9187321340931793, 0.9331905846247115, 0.7374467448380824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 305}], {
             RGBColor[
             0.9878731402486101, 0.970389668960533, 0.4384886495352347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 314}], {
             RGBColor[
             0.9934485439452356, 0.9883954228897014, 0.5282926232180687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 406}], {
             RGBColor[
             0.9926824286510434, 0.9893558229977821, 0.633828709192547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 493}], {
             RGBColor[
             0.9940783116912915, 0.9897424324192285, 0.5968389559002346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 243}], {
             RGBColor[
             0.9817953343606542, 0.948814171314557, 0.5061713731309283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 273}], {
             RGBColor[
             0.9941810193424082, 0.989962113699631, 0.6080180498861519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 279}], {
             RGBColor[
             0.9307305404312858, 0.9439246538595696, 0.8331810797612363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 283}], {
             RGBColor[
             0.9945673244763873, 0.9907883813197718, 0.6500649797208284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 285}], {
             RGBColor[
             0.9853037387059422, 0.9606488429837278, 0.5198008615058043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 396}], {
             RGBColor[
             0.9150025235047397, 0.9313835600879881, 0.8316809274662159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 421}], {
             RGBColor[
             0.9839786511486914, 0.9561790115077665, 0.514653146567673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 430}], {
             RGBColor[
             0.9945796324976368, 0.9908147069326927, 0.6514046318775374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 459}], {
             RGBColor[
             0.9655016078103708, 0.8879979129613337, 0.47335945363268184`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 477}], {
             RGBColor[
             0.9235687815264328, 0.9382140617096065, 0.8324979848035139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 264}], {
             RGBColor[
             0.9094546666361296, 0.8397954355427126, 0.6264774564811623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 281}], {
             RGBColor[
             0.9562724314388638, 0.8759605896573799, 0.590514920052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 295}], {
             RGBColor[
             0.9378159863887392, 0.8621958031586522, 0.6217568673106788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 324}], {
             RGBColor[
             0.8908935694346025, 0.8249953204617766, 0.6247070824603935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 341}], {
             RGBColor[
             0.9454780468186523, 0.8679101552818089, 0.6087869975882478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 374}], {
             RGBColor[
             0.9008705634442935, 0.6348655365365101, 0.23858802747580324`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 397}], {
             RGBColor[
             0.9627478504775684, 0.8779628106962841, 0.41891450301032546`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 275}], {
             RGBColor[
             0.9735239603583116, 0.9203955550888154, 0.444801512600111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 306}], {
             RGBColor[
             0.9828381303430885, 0.9527317856814854, 0.47620773933309085`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 331}], {
             RGBColor[
             0.9935480042062729, 0.9886081583310853, 0.5391182588343979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 346}], {
             RGBColor[
             0.9862880323396062, 0.9866890754175197, 0.7650700014878478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 348}], {
             RGBColor[
             0.9905436361331639, 0.9894129630634645, 0.737717379375065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 355}], {
             RGBColor[
             0.860532537469502, 0.8882684562802758, 0.7910430676494586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 390}], {
             RGBColor[
             0.9920567858848073, 0.990038689371944, 0.7126405720843019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 431}], {
             RGBColor[
             0.9942724924149673, 0.9901577653524885, 0.6179743293278339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 444}], {
             RGBColor[
             0.9135012792108652, 0.9297517522399626, 0.7962949747406252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 486}], {
             RGBColor[
             0.9930975487406167, 0.9904690715592066, 0.695392438155609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 230}], {
             RGBColor[
             0.82266662574247, 0.8581164203835047, 0.7415429357341631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 331}], {
             RGBColor[
             0.8224480751137861, 0.8576489626876083, 0.7177550485400788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 382}], {
             RGBColor[
             0.8221825628492854, 0.8595863546822308, 0.8709642404004858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 413}], {
             RGBColor[
             0.5604501242182839, 0.6538901931224327, 0.9586406740449946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 474}], {
             RGBColor[
             0.782378987989764, 0.7099644424704568, 0.6073095899682348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 490}], {
             RGBColor[
             0.7936481867570186, 0.839655393073814, 0.9798197334734907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 254}], {
             RGBColor[
             0.9493078206345816, 0.882073941093162, 0.611077162212169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 377}], {
             RGBColor[
             0.9616482392516769, 0.9288198702572046, 0.6323585634448304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 396}], {
             RGBColor[
             0.8975661703177293, 0.9205332280459014, 0.9683988382663016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 476}], {
             RGBColor[
             0.9764270415355302, 0.9784324147124226, 0.7101644809655748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 257}], {
             RGBColor[
             0.9134496534360996, 0.9290257140363805, 0.7407720083560196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 266}], {
             RGBColor[
             0.8357738533529047, 0.8718874004594547, 0.9841980503085686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 281}], {
             RGBColor[
             0.9073254000917113, 0.9277746009093208, 0.9505946440812075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 293}], {
             RGBColor[
             0.9143902347355655, 0.9310375223285807, 0.8431484782079521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 317}], {
             RGBColor[
             0.7803056624291602, 0.8284111115674777, 0.978707743523102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 322}], {
             RGBColor[
             0.9138794882845914, 0.9299450873143349, 0.7875568789811633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 343}], {
             RGBColor[
             0.9093587545121676, 0.9291594580099198, 0.9412587035317104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 374}], {
             RGBColor[
             0.851923532097141, 0.6866795477884512, 0.5986677515043799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 403}], {
             RGBColor[
             0.9127099522733467, 0.9305452644060215, 0.8857206840071741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 440}], {
             RGBColor[
             0.9129364598908537, 0.9306389311268408, 0.8819668666021595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 445}], {
             RGBColor[
             0.9139596956151814, 0.930116642684262, 0.7962869519336235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 471}], {
             RGBColor[
             0.9138276205314104, 0.9298341474349149, 0.7819113941380689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 238}], {
             RGBColor[
             0.9512717758467308, 0.8445158594900659, 0.279650330929096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[
             0.9323164316583709, 0.7693642362772226, 0.26439841605602793`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 266}], {
             RGBColor[
             0.8930889495637405, 0.8532499778997066, 0.6308514676930392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 293}], {
             RGBColor[
             0.9717053309464012, 0.9124000997688326, 0.4898018955924228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 403}], {
             RGBColor[
             0.9700250484841826, 0.9119078418462734, 0.5323741013916448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 471}], {
             RGBColor[
             0.9711427167422462, 0.9111967248751668, 0.42856481152253945`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 483}], {
             RGBColor[
             0.9702010567699588, 0.9119806257956484, 0.5294571886014905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 497}], {
             RGBColor[
             0.9632930751046282, 0.8855937676258274, 0.32360491799001456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 231}], {
             RGBColor[
             0.9683816672873058, 0.9486322306549608, 0.6523582299699944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 233}], {
             RGBColor[
             0.9805933005906355, 0.9461987873618105, 0.37910906675263567`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 259}], {
             RGBColor[
             0.9817046100759494, 0.9499474952036498, 0.38342629424989283`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 275}], {
             RGBColor[
             0.9637267123272437, 0.8883864765232314, 0.3183631211617557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 348}], {
             RGBColor[
             0.9807463881020959, 0.9574038844978805, 0.6112789879367097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 355}], {
             RGBColor[
             0.8507352894384341, 0.8562593777146918, 0.6646046762111033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 372}], {
             RGBColor[
             0.9635939147088564, 0.9450615326211786, 0.6604626462394477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 379}], {
             RGBColor[
             0.9767412648189742, 0.9548668048064946, 0.6382076118811044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 400}], {
             RGBColor[
             0.9842238647804168, 0.9576110112334318, 0.46417481938548477`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 404}], {
             RGBColor[
             0.9663160306905563, 0.8980382035264525, 0.32364456922701546`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 431}], {
             RGBColor[
             0.9844752443838993, 0.9581486867869045, 0.4915359378894786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 444}], {
             RGBColor[
             0.9037040311797973, 0.8977426736743787, 0.6698565833022698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 486}], {
             RGBColor[
             0.9833003007095489, 0.9584599929936226, 0.5689540467172537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 225}], {
             RGBColor[
             0.8372927827699579, 0.8084733739745076, 0.6250972638239567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 252}], {
             RGBColor[
             0.8160154088273572, 0.8568850940301562, 0.9821137710130289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 280}], {
             RGBColor[
             0.8572140897803716, 0.8781138925627088, 0.689773592120747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 309}], {
             RGBColor[
             0.8608633864817239, 0.8889761088634522, 0.8270539408663962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 320}], {
             RGBColor[
             0.8559311205254632, 0.887310253830096, 0.9359630268885253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 393}], {
             RGBColor[
             0.8422357529592623, 0.8275884453843758, 0.6315855819923047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 424}], {
             RGBColor[
             0.853179985805534, 0.8645059126029242, 0.6741018599551157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 480}], {
             RGBColor[
             0.8168426161099678, 0.727395277781711, 0.6086425797022219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 236}], {
             RGBColor[
             0.9936417504210158, 0.9908124484508537, 0.6949753504323414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 289}], {
             RGBColor[
             0.9856288268860569, 0.9649069728857456, 0.5682700603511837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 308}], {
             RGBColor[
             0.8481138058000339, 0.8797371635512257, 0.8687026485991685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 362}], {
             RGBColor[
             0.9204409254556969, 0.9364654761727196, 0.8758516150518993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 369}], {
             RGBColor[
             0.9851988924416841, 0.9870253744248222, 0.8447106680188416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 466}], {
             RGBColor[
             0.9917069167791874, 0.9908386112127461, 0.787101380987659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 470}], {
             RGBColor[
             0.9731854193546936, 0.9221779344578542, 0.5238592361427463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 216}], {
             RGBColor[
             0.776344391487666, 0.8258904951610775, 0.9781606101016547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 217}], {
             RGBColor[
             0.9277179315114261, 0.9448145054517236, 0.9795638450828029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 224}], {
             RGBColor[
             0.8970018896107184, 0.920708974580666, 0.990038035065752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 286}], {
             RGBColor[
             0.9369836063355421, 0.9173626941267049, 0.6628561690711263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 319}], {
             RGBColor[
             0.9367192126946522, 0.9515276462199284, 0.9643270239497261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 330}], {
             RGBColor[
             0.9432409379723312, 0.9384701430289311, 0.6871647208821234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 357}], {
             RGBColor[
             0.9487782492392969, 0.9569581999410134, 0.7248828857287324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 492}], {
             RGBColor[
             0.883401322927857, 0.6967010691930091, 0.5986933375925385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 251}], {
             RGBColor[
             0.9706697442743972, 0.9760437299672775, 0.8627741811441636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 332}], {
             RGBColor[
             0.9490762189741242, 0.9591300171162738, 0.8712675506297003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 337}], {
             RGBColor[
             0.9927097612932163, 0.9912533131912256, 0.7704816521117903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 420}], {
             RGBColor[
             0.9939336721915073, 0.9906795989007275, 0.6717058286116266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 447}], {
             RGBColor[
             0.631326297458315, 0.6957960168064427, 0.845209758996403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 454}], {
             RGBColor[
             0.6860411425542627, 0.746879109328125, 0.848560964058934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 489}], {
             RGBColor[
             0.993464936052691, 0.989677019696293, 0.6206867926056132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 500}], {
             RGBColor[
             0.8713353685356552, 0.897716654717843, 0.8636999499609913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 223}], {
             RGBColor[
             0.9926594741751712, 0.9905479141282656, 0.7215515526036572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 268}], {
             RGBColor[
             0.9939181846848874, 0.989399936943854, 0.5794101194424865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 466}], {
             RGBColor[
             0.992471488994209, 0.9904701774249389, 0.7246669535422539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 470}], {
             RGBColor[
             0.9739499915697152, 0.9218095006700471, 0.46142480869734115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 491}], {
             RGBColor[
             0.9830801294240394, 0.9533621024845698, 0.49296420586895884`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 402}], {
             RGBColor[
             0.7358923704250406, 0.7935634831703187, 0.9744247278801613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 417}], {
             RGBColor[
             0.7860615536133626, 0.7653377230576248, 0.619525400525716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 217}], {
             RGBColor[
             0.7993176451742414, 0.8438221368825732, 0.9669479060667729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 224}], {
             RGBColor[
             0.7686016032735337, 0.8197166060115156, 0.9774220960497222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 292}], {
             RGBColor[
             0.819324522359989, 0.8576611972394133, 0.8846257037358787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 358}], {
             RGBColor[
             0.8184058357405132, 0.8572812967130907, 0.8998507185053508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 361}], {
             RGBColor[
             0.814853536249825, 0.8375212372905427, 0.6745988361610644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 398}], {
             RGBColor[
             0.7824612182080218, 0.7167259529653149, 0.6088008457670551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 399}], {
             RGBColor[
             0.8081089492198849, 0.8147701615342109, 0.6483973891581352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 464}], {
             RGBColor[
             0.7367575869090933, 0.7943250517453083, 0.9743847853413928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 481}], {
             RGBColor[
             0.8205655858419806, 0.8563671378686526, 0.7326885458428163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 292}], {
             RGBColor[
             0.9706980623837491, 0.9765852075300592, 0.8860289387170268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 398}], {
             RGBColor[
             0.9338347582317821, 0.8356499632559611, 0.6102040807482032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 464}], {
             RGBColor[
             0.8881311269328536, 0.9132490620359544, 0.9757880203225411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 481}], {
             RGBColor[
             0.9719391258657408, 0.9752911481592985, 0.7340917808239644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 496}], {
             RGBColor[
             0.8720848557090304, 0.9006684348036338, 0.9742006615646359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 235}], {
             RGBColor[
             0.9938204159002796, 0.9891908193995185, 0.5687685905969286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 274}], {
             RGBColor[
             0.9940660171973914, 0.9897161357399407, 0.5955007761120495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.9190850890237727, 0.9339455195320334, 0.7758637108478448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 305}], {
             RGBColor[
             0.9882260951792036, 0.971144603867855, 0.47690561554499705`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 310}], {
             RGBColor[
             0.988542578766803, 0.9722121773227079, 0.4781350945199101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 314}], {
             RGBColor[
             0.993801498875829, 0.9891503577970233, 0.5667095892278311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 406}], {
             RGBColor[
             0.9930353835816368, 0.990110757905104, 0.6722456752023093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 432}], {
             RGBColor[
             0.9499284789268414, 0.8271992941731896, 0.4049889051204304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 493}], {
             RGBColor[
             0.9944312666218849, 0.9904973673265505, 0.6352559219099969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 238}], {
             RGBColor[
             0.9730741230837843, 0.9234964499952432, 0.5323809626658599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 258}], {
             RGBColor[
             0.9541187788954242, 0.8483448267824001, 0.5171290477927918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 293}], {
             RGBColor[
             0.9935076781834546, 0.9913806902740101, 0.7425325273291866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 403}], {
             RGBColor[
             0.9918273957212359, 0.9908884323514506, 0.7851047331284087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 445}], {
             RGBColor[
             0.9930771390630706, 0.9904598106296914, 0.6956710010548581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 471}], {
             RGBColor[
             0.9929450639792996, 0.9901773153803441, 0.6812954432593032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 497}], {
             RGBColor[
             0.9850954223416816, 0.9645743581310049, 0.5763355497267784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 254}], {
             RGBColor[
             0.9394765326857405, 0.7977516508885177, 0.27015960141182166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 297}], {
             RGBColor[
             0.9677761179254338, 0.8966348044752122, 0.4977222940732887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 325}], {
             RGBColor[
             0.9676778476965378, 0.8964246143922479, 0.48702618611151255`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 392}], {
             RGBColor[
             0.8941112418608248, 0.8412952738184598, 0.6280894603265383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 412}], {
             RGBColor[
             0.9493576298044171, 0.8847614519945255, 0.6130491355951333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 413}], {
             RGBColor[
             0.7046064881816142, 0.6903699323283892, 0.611077907702541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 426}], {
             RGBColor[
             0.733310184751206, 0.7136728862903784, 0.6133375678416044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 474}], {
             RGBColor[
             0.9265353519530943, 0.7464441816764132, 0.25974682362578116`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 490}], {
             RGBColor[
             0.937804550720349, 0.8761351322797706, 0.6322569671310372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 234}], {
             RGBColor[
             0.973559112974165, 0.979714004186315, 0.9257453942265871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 301}], {
             RGBColor[
             0.9350888375232078, 0.9503898626713041, 0.969796249665603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 336}], {
             RGBColor[
             0.9784151549945403, 0.9809851842066102, 0.7917020407340591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 294}], {
             RGBColor[
             0.991785915228079, 0.9908712791015303, 0.7857921722480931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 296}], {
             RGBColor[
             0.8947175264246718, 0.9157650594779491, 0.8561492874696299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 339}], {
             RGBColor[
             0.9742169763204823, 0.9226045097730126, 0.5067636676357763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 344}], {
             RGBColor[
             0.9948066003625248, 0.9915241239630906, 0.6923878997436288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 438}], {
             RGBColor[
             0.9374932758704981, 0.9496665973112672, 0.8602841241260273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 439}], {
             RGBColor[
             0.9941980114602282, 0.9902224138388552, 0.6261467535039998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 246}], {
             RGBColor[
             0.9925777809669469, 0.9903731806163242, 0.712659751040484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 268}], {
             RGBColor[
             0.9920892310020356, 0.9893282216413573, 0.659484102340777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 411}], {
             RGBColor[
             0.9661852634687915, 0.9731987059344381, 0.8927336175842908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 286}], {
             RGBColor[
             0.9292408181214099, 0.911188804977143, 0.6621176550191936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 330}], {
             RGBColor[
             0.9354981497581989, 0.9322962538793691, 0.686426206830191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 333}], {
             RGBColor[
             0.9125761307531939, 0.8490399290720742, 0.6282879283692379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 358}], {
             RGBColor[
             0.9390633338635657, 0.9520997761326793, 0.9117281434694482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 361}], {
             RGBColor[
             0.9355110343728774, 0.9323397167101312, 0.6864762611251617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 398}], {
             RGBColor[
             0.9031187163310743, 0.8115444323849035, 0.6206782707311524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 441}], {
             RGBColor[
             0.9420066704372521, 0.9528616295195724, 0.8298545225728013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 464}], {
             RGBColor[
             0.8574150850321458, 0.8891435311648967, 0.9862622103054901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 481}], {
             RGBColor[
             0.9412230839650331, 0.9511856172882409, 0.7445659708069136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 247}], {
             RGBColor[
             0.9011639914071687, 0.8586500010973632, 0.6313890579403961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 252}], {
             RGBColor[
             0.9264301631548593, 0.8787965606170098, 0.6337989679570686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 309}], {
             RGBColor[
             0.971278140809226, 0.9108875754503059, 0.478739137810436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 320}], {
             RGBColor[
             0.9663458748529652, 0.9092217204169496, 0.5876482238325651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 424}], {
             RGBColor[
             0.9635947401330361, 0.8864173791897778, 0.32578705689915555`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 284}], {
             RGBColor[
             0.9323299562498839, 0.7492180152410206, 0.32724842796752956`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 345}], {
             RGBColor[
             0.9330707498260302, 0.7518092681516114, 0.4810608140239263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 366}], {
             RGBColor[
             0.8666477636750864, 0.7020003372539871, 0.6007789644695448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 389}], {
             RGBColor[
             0.9316657182655552, 0.7470578603762053, 0.31782490540512814`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 405}], {
             RGBColor[
             0.9290271213174831, 0.7501371238468146, 0.5480742029856828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 429}], {
             RGBColor[
             0.930962153192761, 0.7509373092552929, 0.5160057171103617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 472}], {
             RGBColor[
             0.9291236933856505, 0.7501770588787907, 0.5464737538956488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 488}], {
             RGBColor[
             0.6077360083063776, 0.4918405452062815, 0.5790165746165631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 229}], {
             RGBColor[
             0.9644006705007467, 0.9395263112729452, 0.646069545050719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 263}], {
             RGBColor[
             0.9745305297791589, 0.9736967052230963, 0.6854221354839395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 265}], {
             RGBColor[
             0.9761548140107192, 0.9786040275569036, 0.7403513479012218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 267}], {
             RGBColor[
             0.9769888066990331, 0.9803878535876117, 0.8311263052179285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 270}], {
             RGBColor[
             0.9070237466918736, 0.9281023523994871, 0.9702685561894491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 329}], {
             RGBColor[
             0.9392288470349074, 0.9537818252288615, 0.9733403074100001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 424}], {
             RGBColor[
             0.9691810650349142, 0.9556517045267058, 0.6646404751142002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 256}], {
             RGBColor[
             0.9525280130953018, 0.8456997628818059, 0.3004341918573073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 279}], {
             RGBColor[
             0.917713875614149, 0.9014557451776037, 0.6602211627707528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 287}], {
             RGBColor[
             0.9708724258291808, 0.9134079942214879, 0.34134530393754914`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 298}], {
             RGBColor[
             0.9805306425185631, 0.948745301666645, 0.5556233087829128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 318}], {
             RGBColor[
             0.8266330255409153, 0.8299257038890404, 0.6512431161160117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 335}], {
             RGBColor[
             0.9387811813763051, 0.9182542429355661, 0.6622305812013531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 409}], {
             RGBColor[
             0.9475169407873765, 0.8258325310217391, 0.29640216545336584`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 468}], {
             RGBColor[
             0.5738644344378325, 0.6059087597136935, 0.6334012905825058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 232}], {
             RGBColor[
             0.9816942866686998, 0.9508828777663124, 0.5477875460643586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 263}], {
             RGBColor[
             0.9800510133786896, 0.9443695252608244, 0.37700238333657266`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 267}], {
             RGBColor[
             0.9825092902985638, 0.9510606736253399, 0.5227065530705617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 280}], {
             RGBColor[
             0.9787356526092825, 0.9399325045242184, 0.3718924551324646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 393}], {
             RGBColor[
             0.9637573157881733, 0.8894070573458855, 0.3137044450040224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 480}], {
             RGBColor[
             0.9383641789388786, 0.7892138897432207, 0.29076144271393956`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 485}], {
             RGBColor[
             0.9752278121622533, 0.9476011757962794, 0.6277420183885941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 382}], {
             RGBColor[
             0.9928620002801803, 0.9896461611797917, 0.6465595283042865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 413}], {
             RGBColor[
             0.7311295616491789, 0.7839499996199936, 0.7342359619487954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 474}], {
             RGBColor[
             0.9530584254206591, 0.8400242489680176, 0.3829048778720355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 484}], {
             RGBColor[
             0.976273233563711, 0.9311058752983485, 0.4065699633335189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 490}], {
             RGBColor[
             0.9643276241879136, 0.9697151995713749, 0.7554150213772914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 233}], {
             RGBColor[
             0.9743824174435289, 0.9688741699750418, 0.6756700111803403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 275}], {
             RGBColor[
             0.957515829180137, 0.9110618591364628, 0.6149240655894603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 326}], {
             RGBColor[
             0.9778096075066081, 0.9798513971539256, 0.7385997452012831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 346}], {
             RGBColor[
             0.9702799011614316, 0.9773553794651669, 0.9351925544771971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 355}], {
             RGBColor[
             0.8445244062913274, 0.8789347603279231, 0.961165620638808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 395}], {
             RGBColor[
             0.7662166142197162, 0.8166556907187442, 0.9541157347172746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 404}], {
             RGBColor[
             0.9601051475434496, 0.9207135861396838, 0.62020551365472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 431}], {
             RGBColor[
             0.9782643612367927, 0.9808240694001358, 0.7880968823171832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 444}], {
             RGBColor[
             0.8974931480326906, 0.9204180562876099, 0.9664175277299745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 486}], {
             RGBColor[
             0.9770894175624422, 0.9811353756068538, 0.8655149911449582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 267}], {
             RGBColor[
             0.9942824228669862, 0.991744420080979, 0.7328443062315682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 280}], {
             RGBColor[
             0.9905087851777048, 0.9806162509798575, 0.5820302082934711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 338}], {
             RGBColor[
             0.9779803258925048, 0.9383548159887467, 0.5333595097714834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 383}], {
             RGBColor[
             0.9942485295727967, 0.9916719257518454, 0.7291552303242099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 393}], {
             RGBColor[
             0.9755304483565956, 0.9300908038015246, 0.5238421981650289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 395}], {
             RGBColor[
             0.7818649317681777, 0.8267851961956239, 0.8586187971311077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 480}], {
             RGBColor[
             0.9501373115073011, 0.8298976361988598, 0.500899195874946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 259}], {
             RGBColor[
             0.9877053602321726, 0.9701894345237307, 0.4067380754602387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 275}], {
             RGBColor[
             0.9697274624834669, 0.9086284158433124, 0.3416749023721015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 326}], {
             RGBColor[
             0.9900212408099378, 0.9774179538607752, 0.4653505819839244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 346}], {
             RGBColor[
             0.9824915344647616, 0.9749219361720166, 0.6619433912598383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 348}], {
             RGBColor[
             0.9867471382583191, 0.9776458238179615, 0.6345907691470555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 355}], {
             RGBColor[
             0.8567360395946573, 0.8765013170347727, 0.6879164574214491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 379}], {
             RGBColor[
             0.9827420149751974, 0.9751087441265756, 0.6615193930914502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 400}], {
             RGBColor[
             0.99022461493664, 0.9778529505535127, 0.4874866005958306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 404}], {
             RGBColor[
             0.9723167808467794, 0.9182801428465335, 0.3469563504373613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 431}], {
             RGBColor[
             0.9904759945401226, 0.9783906261069855, 0.5148477190998244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 444}], {
             RGBColor[
             0.9097047813360205, 0.9179846129944595, 0.6931683645126157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 486}], {
             RGBColor[
             0.989301050865772, 0.9787019323137035, 0.5922658279275995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 336}], {
             RGBColor[
             0.9895717449249173, 0.9892187446298739, 0.7689205340795373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 449}], {
             RGBColor[
             0.8709053119286034, 0.8990575690415485, 0.9396938459522424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 274}], {
             RGBColor[
             0.9940849342218421, 0.9897565973424358, 0.5975597774811471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 284}], {
             RGBColor[
             0.9932363641326927, 0.987941591725342, 0.5051981600447913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 300}], {
             RGBColor[
             0.9191040060482233, 0.9339859811345286, 0.7779227122169423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 305}], {
             RGBColor[
             0.9882450122036541, 0.9711850654703501, 0.4789646169140946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 308}], {
             RGBColor[
             0.8485538305484092, 0.8786745555490443, 0.770943232284093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 345}], {
             RGBColor[
             0.993977157708839, 0.9905328446359328, 0.659010546101188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 389}], {
             RGBColor[
             0.992572126148364, 0.9857814368605267, 0.4957746374823899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 432}], {
             RGBColor[
             0.9499473959512921, 0.8272397557756848, 0.40704790648952793`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 456}], {
             RGBColor[
             0.9940708205475071, 0.9897264096201446, 0.5960235911292848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 289}], {
             RGBColor[
             0.986311293879093, 0.9643629243302227, 0.4968989861873479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 300}], {
             RGBColor[
             0.9193464482928841, 0.9345045405811871, 0.804311054368182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 308}], {
             RGBColor[
             0.84879627279307, 0.8791931149957029, 0.7973315744353328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 314}], {
             RGBColor[
             0.9940628581449404, 0.989709378846177, 0.5951569327481684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 466}], {
             RGBColor[
             0.9923893837722235, 0.9902945626572233, 0.7157303068238232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 470}], {
             RGBColor[
             0.9738678863477297, 0.9216338859023314, 0.4524881619789106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 493}], {
             RGBColor[
             0.9946926258909963, 0.9910563883757043, 0.6637032654303343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 241}], {
             RGBColor[
             0.8730711369945563, 0.7436114720929159, 0.6085955741954459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 274}], {
             RGBColor[
             0.9429261818955945, 0.7952948481176623, 0.42774372813718187`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 284}], {
             RGBColor[
             0.9420776118064451, 0.7934798425005685, 0.33538211070082613`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 351}], {
             RGBColor[
             0.9140440552273876, 0.7762598000920804, 0.6117282053832378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 371}], {
             RGBColor[
             0.8402449222949477, 0.7176874301848082, 0.6053980549427435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 429}], {
             RGBColor[
             0.9407098087493221, 0.7951991365148408, 0.5241393998436583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 432}], {
             RGBColor[
             0.8987886436250445, 0.6327780065509112, 0.23723185714556272`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 460}], {
             RGBColor[
             0.9400138596973595, 0.7949113436967794, 0.5356730766930902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 258}], {
             RGBColor[
             0.9352247186675653, 0.7808946251394832, 0.2667384920498957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 266}], {
             RGBColor[
             0.895997236572935, 0.8647803667619671, 0.6331915436869069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 293}], {
             RGBColor[
             0.9746136179555956, 0.9239304886310932, 0.4921419715862906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 403}], {
             RGBColor[
             0.9729333354933769, 0.9234382307085338, 0.5347141773855126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 445}], {
             RGBColor[
             0.9741830788352117, 0.9230096089867744, 0.445280445311962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 471}], {
             RGBColor[
             0.9740510037514406, 0.9227271137374273, 0.4309048875164072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 483}], {
             RGBColor[
             0.9731093437791531, 0.9235110146579089, 0.5317972645953583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 497}], {
             RGBColor[
             0.9662013621138226, 0.897124156488088, 0.3259449939838823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 251}], {
             RGBColor[
             0.9662175091486784, 0.974202616325569, 0.9365592391924837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 272}], {
             RGBColor[
             0.9329372758901668, 0.770152179790512, 0.5608685067021149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 332}], {
             RGBColor[
             0.9446239838484053, 0.9572889034745653, 0.9450526086780204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 387}], {
             RGBColor[
             0.9555822981051987, 0.8666393964650729, 0.5794361821953162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 435}], {
             RGBColor[
             0.9900495423158384, 0.9900536049446242, 0.8073256371886866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 453}], {
             RGBColor[
             0.9313498557021399, 0.762944075468086, 0.5595439243859957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 454}], {
             RGBColor[
             0.6815889074285439, 0.7450379956864165, 0.9223460221072541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 489}], {
             RGBColor[
             0.9890127009269722, 0.9878359060545845, 0.6944718506539334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 434}], {
             RGBColor[
             0.9601044251100501, 0.8675089917608372, 0.41522049056678134`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 495}], {
             RGBColor[
             0.9927736440385696, 0.9900351608043859, 0.678955882211089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 271}], {
             RGBColor[
             0.9241913216997453, 0.9379907290760299, 0.7742137759989551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 304}], {
             RGBColor[
             0.8807138247471786, 0.7775719049045666, 0.6149343738186615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 311}], {
             RGBColor[
             0.891658200838414, 0.9164480622041982, 0.9895283492602823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 351}], {
             RGBColor[
             0.8955933639497089, 0.9195634896325298, 0.9891282863005879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 371}], {
             RGBColor[
             0.821794231017269, 0.8609911197252574, 0.9827981358600935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 429}], {
             RGBColor[
             0.9222591174716434, 0.9385028260552901, 0.9015394807610083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 442}], {
             RGBColor[
             0.907537130715252, 0.8825893687645501, 0.6434333130704232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 249}], {
             RGBColor[
             0.9727921209708628, 0.9779838621816901, 0.8751807038850428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 269}], {
             RGBColor[
             0.9890386728255859, 0.98973522376719, 0.8313210884928373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 282}], {
             RGBColor[
             0.9921158705442664, 0.9886466656004875, 0.6086999301398435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 310}], {
             RGBColor[
             0.9874851333943028, 0.9730521049565669, 0.5884992738300252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 323}], {
             RGBColor[
             0.9396285567334308, 0.786597980509416, 0.507668180206201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 419}], {
             RGBColor[
             0.9934096354039107, 0.991413897815574, 0.7495182509209217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 449}], {
             RGBColor[
             0.8743907645417467, 0.9004988932691297, 0.8819308760902402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 499}], {
             RGBColor[
             0.9411278309230605, 0.9532049094585366, 0.8884312066417236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 273}], {
             RGBColor[
             0.981141155193124, 0.9474149482228693, 0.4349680078711015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 279}], {
             RGBColor[
             0.9176906762820015, 0.9013774883828078, 0.660131037746186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 283}], {
             RGBColor[
             0.9815274603271029, 0.94824121584301, 0.47701493770577796`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 285}], {
             RGBColor[
             0.9722638745566579, 0.9181016775069661, 0.3467508194907538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 318}], {
             RGBColor[
             0.8266098262087679, 0.8298474470942445, 0.6511529910914448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 335}], {
             RGBColor[
             0.9387579820441576, 0.9181759861407703, 0.6621404561767863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 396}], {
             RGBColor[
             0.9019626593554555, 0.8888363946112263, 0.6586308854511655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 421}], {
             RGBColor[
             0.970938786999407, 0.9136318460310049, 0.34160310455262266`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 430}], {
             RGBColor[
             0.9815397683483524, 0.948267541455931, 0.47835458986248697`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 459}], {
             RGBColor[
             0.9524617436610865, 0.845450747484572, 0.30030941161763147`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 477}], {
             RGBColor[
             0.9105289173771486, 0.8956668962328449, 0.6594479427884634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 261}], {
             RGBColor[
             0.9761691964687984, 0.981747606262565, 0.9252235136960429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 262}], {
             RGBColor[
             0.989082321135777, 0.9894071768532229, 0.8106551397702441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 295}], {
             RGBColor[
             0.9635359147210063, 0.972325725420162, 0.9466083644074705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 341}], {
             RGBColor[
             0.9711979751509194, 0.9780400775433187, 0.9336384946850395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 376}], {
             RGBColor[
             0.9737758567589205, 0.9393760752984305, 0.6150381879424925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 391}], {
             RGBColor[
             0.9031622644866515, 0.9243995944296411, 0.9482755889188603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 407}], {
             RGBColor[
             0.9868654640531007, 0.988649678565467, 0.8589684723575826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 448}], {
             RGBColor[
             0.9733364649021299, 0.9796349596983158, 0.9300185893436942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 455}], {
             RGBColor[
             0.959188200488583, 0.9690731550140618, 0.9536193927096681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 475}], {
             RGBColor[
             0.9716444240557984, 0.9321862523066016, 0.6067579743781552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 478}], {
             RGBColor[
             0.9859232138887627, 0.9882600339077886, 0.8745839960459221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 482}], {
             RGBColor[
             0.9839853959229996, 0.9738152482126631, 0.6547003196852454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 262}], {
             RGBColor[
             0.9944925069973469, 0.9906283542973121, 0.6419215588472533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 299}], {
             RGBColor[
             0.9941060600181102, 0.9898017832845076, 0.5998591900316346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 376}], {
             RGBColor[
             0.9791860426204905, 0.9405972527425197, 0.44630460701950186`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 438}], {
             RGBColor[
             0.9369258709396414, 0.9482290198202296, 0.7822463825632766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 448}], {
             RGBColor[
             0.9787466507636998, 0.9808561371424052, 0.7612850084207035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 475}], {
             RGBColor[
             0.9770546099173684, 0.9334074297506909, 0.4380243934551645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 482}], {
             RGBColor[
             0.9893955817845695, 0.9750364256567523, 0.4859667387622547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 384}], {
             RGBColor[
             0.9747077513048901, 0.9781486411977619, 0.7922991404621604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 402}], {
             RGBColor[
             0.9199467840461351, 0.9349837847423343, 0.80441312078527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 411}], {
             RGBColor[
             0.967932523943419, 0.9730956877249934, 0.8037678331228271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 458}], {
             RGBColor[
             0.9641413122620133, 0.9702233019131649, 0.8086284343394216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 252}], {
             RGBColor[
             0.8798866174645681, 0.9070617211530119, 0.9884055651294683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 278}], {
             RGBColor[
             0.9183501488101815, 0.9190642178161327, 0.6854398465020967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 309}], {
             RGBColor[
             0.9247345951189349, 0.9391527359863079, 0.8333457349828357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 401}], {
             RGBColor[
             0.9194778487702354, 0.9228682145779368, 0.6898207478986376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 451}], {
             RGBColor[
             0.5167737228584388, 0.5961545808166826, 0.9597483275563979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 339}], {
             RGBColor[
             0.8006228748502484, 0.7889058177012716, 0.6234528819502048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 344}], {
             RGBColor[
             0.8212124988922909, 0.8578254318913496, 0.8090771140580572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 387}], {
             RGBColor[
             0.7870331035590885, 0.7350269030546515, 0.612518232976407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 439}], {
             RGBColor[
             0.8206039099899944, 0.8565237217671142, 0.7428359678184282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 269}], {
             RGBColor[
             0.9701441856656199, 0.9768888728841387, 0.9190638445298187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 282}], {
             RGBColor[
             0.9732213833843004, 0.9758003147174363, 0.6964426861768249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 310}], {
             RGBColor[
             0.9685906462343368, 0.9602057540735156, 0.6762420298670067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 323}], {
             RGBColor[
             0.9207340695734648, 0.7737516296263647, 0.5954109362431825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 406}], {
             RGBColor[
             0.9730834510491706, 0.9781043346559118, 0.8703526105494059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 419}], {
             RGBColor[
             0.9745151482439447, 0.9785675469325228, 0.8372610069579032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 499}], {
             RGBColor[
             0.9222333437630945, 0.9403585585754854, 0.9761739626787052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 263}], {
             RGBColor[
             0.9754931812588563, 0.9744146491204575, 0.6837926176285285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 365}], {
             RGBColor[
             0.9682164622326324, 0.9758164700906395, 0.9386854183525897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 485}], {
             RGBColor[
             0.9706699800424199, 0.9776462996559125, 0.93453225268055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 258}], {
             RGBColor[
             0.9318859046326262, 0.8330554921318618, 0.6126177204564413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 272}], {
             RGBColor[
             0.9142222015275359, 0.7563175458020266, 0.5980581312456861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 435}], {
             RGBColor[
             0.9713344679532074, 0.9762189709561389, 0.8445152617322578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 447}], {
             RGBColor[
             0.6081589879699651, 0.6801202691762487, 0.9561844415882943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 453}], {
             RGBColor[
             0.9126347813395088, 0.7491094414796005, 0.5967335489295669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 454}], {
             RGBColor[
             0.662873833065913, 0.731203361697931, 0.9595356466508254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 309}], {
             RGBColor[
             0.9500007668666254, 0.9592992955059545, 0.8357556449995083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 320}], {
             RGBColor[
             0.9450685009103645, 0.9576334404725982, 0.9446647310216373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 424}], {
             RGBColor[
             0.9423173661904355, 0.9348290992454265, 0.6828035640882277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 287}], {
             RGBColor[
             0.9818844069367476, 0.9505539922334327, 0.3841247711023058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 301}], {
             RGBColor[
             0.949300491546713, 0.9550073985154168, 0.7049630569723111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 336}], {
             RGBColor[
             0.9926268090180457, 0.9856027200507228, 0.5268688480407672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 354}], {
             RGBColor[
             0.972958146129502, 0.9733713177199604, 0.6898824149199128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 388}], {
             RGBColor[
             0.9926940962294251, 0.9857466405920827, 0.5341926457508778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 436}], {
             RGBColor[
             0.96702251248576, 0.9689445318671657, 0.6999298944175767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 473}], {
             RGBColor[
             0.9641284787837183, 0.8851789061559583, 0.3436871675293241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 350}], {
             RGBColor[
             0.9383425448162757, 0.7932557668651462, 0.2692471681539339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 377}], {
             RGBColor[
             0.9509935677503407, 0.8412331386432211, 0.29077848891084956`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 412}], {
             RGBColor[
             0.948534246251922, 0.8814970105851863, 0.6123866218614997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 426}], {
             RGBColor[
             0.7324868011987109, 0.7104084448810393, 0.6126750541079709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 476}], {
             RGBColor[
             0.965772370034194, 0.8908456830984391, 0.36858440643159396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 260}], {
             RGBColor[
             0.9718276975761329, 0.977162251994552, 0.8722300119532802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 299}], {
             RGBColor[
             0.993313584834711, 0.9906770154009759, 0.7004336643445277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 312}], {
             RGBColor[
             0.9920728485357264, 0.990989933398092, 0.7810369447807786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 327}], {
             RGBColor[
             0.9751391633283497, 0.9796319377305278, 0.8666245642033685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 334}], {
             RGBColor[
             0.98659785667993, 0.9691474789338048, 0.578751195790802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 385}], {
             RGBColor[
             0.9887941879434203, 0.9896341229854397, 0.8353728356969123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 446}], {
             RGBColor[
             0.9339336753781133, 0.9473502546169967, 0.8826110455827902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 478}], {
             RGBColor[
             0.9905409245669334, 0.9903564434683461, 0.8064248894358246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 287}], {
             RGBColor[
             0.9545985700488175, 0.8526842376759068, 0.30847791462984486`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 298}], {
             RGBColor[
             0.9642567867381999, 0.8880215451210638, 0.5227559194752084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 409}], {
             RGBColor[
             0.9312430850070132, 0.7651087744761581, 0.2635347761456615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 281}], {
             RGBColor[
             0.9870417571119461, 0.9865399991983999, 0.7073632322709402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 317}], {
             RGBColor[
             0.860022019449395, 0.8871765098565567, 0.7354763317128346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 322}], {
             RGBColor[
             0.9935958453048261, 0.9887104856034139, 0.5443254671708959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 324}], {
             RGBColor[
             0.9216628951076848, 0.9355747300027966, 0.7415553946787028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 326}], {
             RGBColor[
             0.9933072206646756, 0.9880931466825592, 0.5129104562753097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 343}], {
             RGBColor[
             0.9890751115324024, 0.9879248562989986, 0.698027291721443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 374}], {
             RGBColor[
             0.9316398891173758, 0.7454449460775301, 0.3554363396941125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 445}], {
             RGBColor[
             0.9936760526354163, 0.988882040973341, 0.5530555401233562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 272}], {
             RGBColor[
             0.8986056713741147, 0.6290050555968048, 0.2369269879660724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 293}], {
             RGBColor[
             0.9556582737672357, 0.84877886541825, 0.4768900567132225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 403}], {
             RGBColor[
             0.9539779913050169, 0.8482866074956906, 0.5194622625124445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 435}], {
             RGBColor[
             0.9557179377997864, 0.848906480750917, 0.4833841184526442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 453}], {
             RGBColor[
             0.8970182511860878, 0.6217969512743786, 0.23560240564995327`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 471}], {
             RGBColor[
             0.9550956595630806, 0.847575490524584, 0.4156529726433391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 497}], {
             RGBColor[
             0.9472460179254626, 0.8219725332752448, 0.31069307911081423`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 275}], {
             RGBColor[
             0.9708387719687807, 0.9123771236851517, 0.3459921298693587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 331}], {
             RGBColor[
             0.990862815816742, 0.9805897269274215, 0.44030887610364555`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 348}], {
             RGBColor[
             0.987858447743633, 0.9813945316598007, 0.6389079966443126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 372}], {
             RGBColor[
             0.9707059743503933, 0.9690521797830989, 0.6880916549470508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 400}], {
             RGBColor[
             0.9913359244219537, 0.9816016583953521, 0.49180382809308776`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 404}], {
             RGBColor[
             0.9734280903320932, 0.9220288506883727, 0.35127357793461844`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 418}], {
             RGBColor[
             0.9869471112996515, 0.9676316828290215, 0.4037924215406903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 431}], {
             RGBColor[
             0.9915873040254364, 0.9821393339488247, 0.5191649465970816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 444}], {
             RGBColor[
             0.9108160908213343, 0.9217333208362989, 0.6974855920098728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 486}], {
             RGBColor[
             0.9904123603510858, 0.9824506401555428, 0.5965830554248567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 299}], {
             RGBColor[
             0.9728386452797986, 0.9767543105079737, 0.7954349232152861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 312}], {
             RGBColor[
             0.971597908980814, 0.97706722850509, 0.8760382036515368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 328}], {
             RGBColor[
             0.9724278089637228, 0.9758755731698112, 0.7507179255982941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 334}], {
             RGBColor[
             0.9661229171250174, 0.9552247740408026, 0.6737524546615603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 399}], {
             RGBColor[
             0.9598132756552544, 0.9339408717890223, 0.649240689027342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 407}], {
             RGBColor[
             0.9710082351763589, 0.9768233832330224, 0.8858106246182433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 446}], {
             RGBColor[
             0.9134587358232007, 0.9334275497239946, 0.9776123044535485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 478}], {
             RGBColor[
             0.970065985012021, 0.9764337385753439, 0.9014261483065829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 262}], {
             RGBColor[
             0.9821843018298716, 0.9842626453493486, 0.82233168716357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 299}], {
             RGBColor[
             0.9817978548506349, 0.9834360743365441, 0.7802693183479512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 313}], {
             RGBColor[
             0.975750361725205, 0.964160651532421, 0.6611828166976582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 328}], {
             RGBColor[
             0.9813870185345592, 0.9825573369983815, 0.7355523207309593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 391}], {
             RGBColor[
             0.8962642451807461, 0.9192550629257669, 0.9599521363121862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 407}], {
             RGBColor[
             0.9799674447471953, 0.9835051470615928, 0.8706450197509084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 448}], {
             RGBColor[
             0.9664384455962245, 0.9744904281944415, 0.9416951367370201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 455}], {
             RGBColor[
             0.9522901811826776, 0.9639286235101875, 0.9652959401029939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 475}], {
             RGBColor[
             0.964746404749893, 0.9270417208027273, 0.6184345217714811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 478}], {
             RGBColor[
             0.9790251945828573, 0.9831155024039143, 0.8862605434392481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 482}], {
             RGBColor[
             0.9770873766170942, 0.9686707167087888, 0.6663768670785712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 299}], {
             RGBColor[
             0.9947109795176134, 0.9910956449272019, 0.6657009444221523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 376}], {
             RGBColor[
             0.9797909621199937, 0.941891114385214, 0.5121463614100196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 391}], {
             RGBColor[
             0.9091773698477246, 0.9269146335164247, 0.8453837623863873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 448}], {
             RGBColor[
             0.9793515702632031, 0.9821499987850995, 0.8271267628112212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 455}], {
             RGBColor[
             0.9652033058496563, 0.9715881941008453, 0.8507275661771951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 475}], {
             RGBColor[
             0.9776595294168716, 0.9347012913933852, 0.5038661478456822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 478}], {
             RGBColor[
             0.9919383192498359, 0.9907750729945721, 0.7716921695134491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 482}], {
             RGBColor[
             0.9900005012840728, 0.9763302872994466, 0.5518084931527725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 267}], {
             RGBColor[
             0.992639149576976, 0.985231067575491, 0.5620591435037822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 393}], {
             RGBColor[
             0.9738871750665854, 0.9235774512960366, 0.3530570354372429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 485}], {
             RGBColor[
             0.9853576714406653, 0.9817715697464304, 0.6670946088218146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 281}], {
             RGBColor[
             0.9340997389648238, 0.949123731956673, 0.9531484044246594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 295}], {
             RGBColor[
             0.9156432939146992, 0.9353589454579452, 0.9843903516827074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 324}], {
             RGBColor[
             0.8687208769605625, 0.8981584627610697, 0.9873405668324221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 341}], {
             RGBColor[
             0.9233053543446124, 0.9410732975811019, 0.9714204819602763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 374}], {
             RGBColor[
             0.8786978709702535, 0.7080286788358032, 0.6012215118478318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 397}], {
             RGBColor[
             0.9405751580035284, 0.9511259529955771, 0.7815479873823541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 270}], {
             RGBColor[
             0.9242983738013768, 0.9378528887211737, 0.756130606892585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 320}], {
             RGBColor[
             0.9892068268643465, 0.9882065820755641, 0.7123636927507457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 329}], {
             RGBColor[
             0.9565034741444106, 0.963532361550548, 0.759202358113136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 424}], {
             RGBColor[
             0.9864556921444174, 0.9654022408483923, 0.4505025258173362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 293}], {
             RGBColor[
             0.9164307916726053, 0.9326646070407338, 0.8433431083502336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 317}], {
             RGBColor[
             0.7823462193662001, 0.8300381962796308, 0.9789023736653835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 322}], {
             RGBColor[
             0.9159200452216313, 0.931572172026488, 0.7877515091234448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 343}], {
             RGBColor[
             0.9113993114492075, 0.930786542722073, 0.9414533336739919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 359}], {
             RGBColor[
             0.5083707051449723, 0.5894542425858039, 0.9589468402254251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 403}], {
             RGBColor[
             0.9147505092103866, 0.9321723491181746, 0.8859153141494557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 440}], {
             RGBColor[
             0.9149770168278936, 0.9322660158389939, 0.8821614967444411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 445}], {
             RGBColor[
             0.9160002525522213, 0.9317437273964151, 0.7964815820759051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 471}], {
             RGBColor[
             0.9158681774684503, 0.931461232147068, 0.7821060242803504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 483}], {
             RGBColor[
             0.9149265174961628, 0.9322451330675496, 0.8829984013593014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 280}], {
             RGBColor[
             0.9913237888075688, 0.9807940468388849, 0.556949215299674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 393}], {
             RGBColor[
             0.9763454519864596, 0.9302685996605521, 0.4987612051712319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 424}], {
             RGBColor[
             0.9872896848327313, 0.9671860668791005, 0.5412774831340429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 480}], {
             RGBColor[
             0.950952315137165, 0.8300754320578873, 0.47581820288114907`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 485}], {
             RGBColor[
             0.9878159483605395, 0.988462718110946, 0.8127987785558035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 491}], {
             RGBColor[
             0.9825098862509039, 0.9521424099976614, 0.43089675560607865`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 282}], {
             RGBColor[
             0.9894679352390237, 0.9875516763029363, 0.6525830707846193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 310}], {
             RGBColor[
             0.98483719808906, 0.9719571156590157, 0.6323824144748011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 323}], {
             RGBColor[
             0.9369806214281879, 0.7855029912118647, 0.5515513208509768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 406}], {
             RGBColor[
             0.9893300029038938, 0.9898556962414118, 0.8264929951572002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 411}], {
             RGBColor[
             0.9639653719828034, 0.9722807237563731, 0.9295229644021236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 419}], {
             RGBColor[
             0.9907617000986679, 0.9903189085180228, 0.7934013915656976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 499}], {
             RGBColor[
             0.9384798956178177, 0.9521099201609854, 0.9323143472864994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 329}], {
             RGBColor[
             0.887372406825565, 0.9130306863931317, 0.9891195664013633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 479}], {
             RGBColor[
             0.8994244627640979, 0.8508873153037063, 0.629795463891946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 304}], {
             RGBColor[
             0.9502847007300463, 0.8286474723472312, 0.4031524947048206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 307}], {
             RGBColor[
             0.9101164029913857, 0.9267677709514744, 0.7728712976877234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 311}], {
             RGBColor[
             0.9612290768212817, 0.9675236296468627, 0.7777464701464416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 351}], {
             RGBColor[
             0.9651642399325766, 0.9706390570751943, 0.7773464071867471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 371}], {
             RGBColor[
             0.8913651070001367, 0.9120666871679219, 0.7710162567462527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 429}], {
             RGBColor[
             0.9918299934545111, 0.9895783934979546, 0.6897576016471676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 442}], {
             RGBColor[
             0.9771080066981197, 0.9336649362072146, 0.43165143395658234`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 435}], {
             RGBColor[
             0.9380542346946958, 0.7721685344210818, 0.46882452924188894`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 453}], {
             RGBColor[
             0.8793545480809973, 0.5450590049445434, 0.22104281643919804`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 497}], {
             RGBColor[
             0.9295823148203721, 0.7452345869454096, 0.29613348990005905`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 279}], {
             RGBColor[
             0.9300763612637555, 0.9425254307678819, 0.7619777145014096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 283}], {
             RGBColor[
             0.993913145308857, 0.989389158228084, 0.5788616144610017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 285}], {
             RGBColor[
             0.9846495595384119, 0.9592496198920402, 0.4485974962459775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 396}], {
             RGBColor[
             0.9143483443372094, 0.9299843369963003, 0.7604775622063892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 421}], {
             RGBColor[
             0.9833244719811611, 0.9547797884160789, 0.4434497813078463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 430}], {
             RGBColor[
             0.9939254533301065, 0.989415483841005, 0.5802012666177107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 459}], {
             RGBColor[
             0.9648474286428405, 0.8865986898696461, 0.4021560883728551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 477}], {
             RGBColor[
             0.9229146023589025, 0.9368148386179189, 0.7612946195436872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 284}], {
             RGBColor[
             0.9934819654298046, 0.9884669080657641, 0.5319303455599123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 300}], {
             RGBColor[
             0.9193496073453351, 0.9345112974749507, 0.8046548977320631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 305}], {
             RGBColor[
             0.9884906135007661, 0.9717103818107722, 0.5056968024292154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 389}], {
             RGBColor[
             0.9928177274454759, 0.9863067532009487, 0.5225068229975108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 432}], {
             RGBColor[
             0.9501929972484039, 0.827765072116107, 0.43378009200464884`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 460}], {
             RGBColor[
             0.991418213320719, 0.989898409261975, 0.7322213115521763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 331}], {
             RGBColor[
             0.9728849180680362, 0.9190287082470031, 0.3752457030155084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 346}], {
             RGBColor[
             0.9656249462013695, 0.9171096253334375, 0.6011974456689584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 348}], {
             RGBColor[
             0.9698805499949272, 0.9198335129793824, 0.5738448235561755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 355}], {
             RGBColor[
             0.8398694513312653, 0.8186890061961937, 0.6271705118305693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 372}], {
             RGBColor[
             0.9527280766016876, 0.9074911611026806, 0.6230284818589136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 404}], {
             RGBColor[
             0.9554501925833875, 0.8604678320079544, 0.2862104048464813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 418}], {
             RGBColor[
             0.9689692135509458, 0.906070664148603, 0.33872924845255314`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 431}], {
             RGBColor[
             0.9736094062767306, 0.9205783152684064, 0.45410177350894443`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 444}], {
             RGBColor[
             0.8928381930726286, 0.8601723021558805, 0.6324224189217357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 486}], {
             RGBColor[
             0.9724344626023801, 0.9208896214751244, 0.5315198823367195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 306}], {
             RGBColor[
             0.8983648731808739, 0.889488491129678, 0.6634673914891598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 347}], {
             RGBColor[
             0.7642544301721035, 0.8158031230826788, 0.9771261226666491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 382}], {
             RGBColor[
             0.9088092347795573, 0.9273022557739004, 0.8795871028508738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 462}], {
             RGBColor[
             0.8281640704865316, 0.8658195661638619, 0.9834722224254405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 288}], {
             RGBColor[
             0.9836429486334396, 0.9859574611817707, 0.8514871320399073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 313}], {
             RGBColor[
             0.9873160076591273, 0.9714222341248955, 0.580519926226947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 340}], {
             RGBColor[
             0.9876497562770116, 0.9725480465809211, 0.5818164765842893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 373}], {
             RGBColor[
             0.9913214562229201, 0.9849335526546157, 0.5960803375317898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 386}], {
             RGBColor[
             0.9900204432943567, 0.990141211086377, 0.8150506110847775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 414}], {
             RGBColor[
             0.9932179271526245, 0.9914634528333577, 0.7620600287303092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 498}], {
             RGBColor[
             0.982596866561481, 0.9555034630955119, 0.5621869541976099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 401}], {
             RGBColor[
             0.9832075518635394, 0.9550172707607042, 0.38926493928793837`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 451}], {
             RGBColor[
             0.5805034259517428, 0.62830363699945, 0.6591925189456986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.9211990806272894, 0.9132121600519787, 0.673760526121062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 318}], {
             RGBColor[
             0.7755450322793994, 0.8249579296392571, 0.9781626977217528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 335}], {
             RGBColor[
             0.8876931881147891, 0.9132864686857829, 0.9891501628070943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 396}], {
             RGBColor[
             0.850897865426087, 0.8839468771562389, 0.9856405920814736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 409}], {
             RGBColor[
             0.8964289475258604, 0.8208647567719559, 0.623321747059107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 421}], {
             RGBColor[
             0.9198739930700386, 0.9087423285760174, 0.6686128111829307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 430}], {
             RGBColor[
             0.930474974418984, 0.9433780240009435, 0.8053642964927951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 459}], {
             RGBColor[
             0.901396949731718, 0.8405612300295846, 0.6273191182479395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 477}], {
             RGBColor[
             0.8594641234477801, 0.8907773787778575, 0.9864576494187716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 338}], {
             RGBColor[
             0.9750216918330874, 0.9274044427466527, 0.35746441883958924`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 383}], {
             RGBColor[
             0.9912898955133793, 0.9807215525097513, 0.5532601393923159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 393}], {
             RGBColor[
             0.9725718142971782, 0.9191404305594306, 0.3479471072331348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 480}], {
             RGBColor[
             0.9471786774478836, 0.8189472629567658, 0.325004104943052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 317}], {
             RGBColor[
             0.8538977661050068, 0.8859253967294971, 0.9452989674380226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 322}], {
             RGBColor[
             0.987471591960438, 0.9874593724763543, 0.7541481028960839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 324}], {
             RGBColor[
             0.9155386417632967, 0.934323616875737, 0.9513780304038908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 343}], {
             RGBColor[
             0.9829508581880142, 0.9866737431719391, 0.907849927446631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 374}], {
             RGBColor[
             0.9255156357729876, 0.7441938329504705, 0.5652589754193005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 397}], {
             RGBColor[
             0.9873929228062625, 0.9872911071102445, 0.7455854509538227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 445}], {
             RGBColor[
             0.987551799291028, 0.9876309278462814, 0.7628781758485441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 310}], {
             RGBColor[
             0.9879143958077405, 0.9708685574923132, 0.4097612561218073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 323}], {
             RGBColor[
             0.9400578191468685, 0.7844144330451622, 0.32893016249798307`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 406}], {
             RGBColor[
             0.9924072006225744, 0.9887671380747094, 0.6038718368042064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 419}], {
             RGBColor[
             0.9938388978173485, 0.9892303503513202, 0.5707802332127038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 499}], {
             RGBColor[
             0.9415570933364983, 0.9510213619942829, 0.7096931889335056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 396}], {
             RGBColor[
             0.9147346494711884, 0.9308106046164412, 0.8025244920410657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 421}], {
             RGBColor[
             0.9837107771151401, 0.9556060560362196, 0.4854967111425228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 430}], {
             RGBColor[
             0.9943117584640855, 0.9902417514611458, 0.6222481964523872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 459}], {
             RGBColor[
             0.9652337337768195, 0.8874249574897868, 0.4442030182075316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 477}], {
             RGBColor[
             0.9233009074928815, 0.9376411062380596, 0.8033415493783636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 300}], {
             RGBColor[
             0.9185010372561858, 0.9326962918578569, 0.7122932802957074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 345}], {
             RGBColor[
             0.9933741889168015, 0.9892431553592611, 0.5933811141799532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 389}], {
             RGBColor[
             0.9919691573563265, 0.9844917475838549, 0.43014520556115504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 432}], {
             RGBColor[
             0.9493444271592546, 0.8259500664990131, 0.34141847456829305`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 456}], {
             RGBColor[
             0.9934678517554696, 0.988436720343473, 0.5303941592080499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 472}], {
             RGBColor[
             0.9894271324764217, 0.9876109460864404, 0.6587940540516757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 287}], {
             RGBColor[
             0.9743576308423212, 0.9251644090958628, 0.3548846672878583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 354}], {
             RGBColor[
             0.9654313700350757, 0.9479817345823907, 0.6606423111054653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 396}], {
             RGBColor[
             0.9054710637007434, 0.9006710662803972, 0.6722603738260415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 409}], {
             RGBColor[
             0.9510021458005169, 0.8375889458961141, 0.3099415288036749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 430}], {
             RGBColor[
             0.9850481726936404, 0.9601022131251018, 0.49198407823736295`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 473}], {
             RGBColor[
             0.9566017026892919, 0.8597893230183884, 0.3144470637148765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 477}], {
             RGBColor[
             0.9140373217224365, 0.9075015679020156, 0.6730774311633394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 319}], {
             RGBColor[
             0.9689581412053436, 0.9420074766164054, 0.6364066439031677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 330}], {
             RGBColor[
             0.9754798664830227, 0.9289499734254081, 0.3592443408355651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 357}], {
             RGBColor[
             0.9810171777499883, 0.9474380303374904, 0.39696250568217406`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 358}], {
             RGBColor[
             0.9790450505883894, 0.9487534956787181, 0.5845462774748225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 367}], {
             RGBColor[
             0.9815296506772213, 0.9485341581098807, 0.4527420211951849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 368}], {
             RGBColor[
             0.9795403062263047, 0.9489582966124854, 0.5763386098740603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 492}], {
             RGBColor[
             0.9156402514385484, 0.6871808995894861, 0.2707729575459802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 336}], {
             RGBColor[
             0.9836853848639946, 0.955441196832879, 0.492133103648548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 354}], {
             RGBColor[
             0.9640167219754512, 0.9432097945021166, 0.6551466705276938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 388}], {
             RGBColor[
             0.983752672075374, 0.9555851173742389, 0.4994569013586586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 409}], {
             RGBColor[
             0.9495874977408922, 0.8328170058158402, 0.30444588822590335`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 436}], {
             RGBColor[
             0.958081088331709, 0.9387830086493218, 0.6651941500253575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 473}], {
             RGBColor[
             0.9551870546296672, 0.8550173829381145, 0.308951423137105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 313}], {
             RGBColor[
             0.9785564872618293, 0.9662534553630266, 0.6564327781189079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 321}], {
             RGBColor[
             0.9834798586315254, 0.9858900192747573, 0.8541899554350205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 373}], {
             RGBColor[
             0.9825619358256221, 0.9797647738927469, 0.6719931894237505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 386}], {
             RGBColor[
             0.9812609228970586, 0.984972432324508, 0.8909634629767383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 391}], {
             RGBColor[
             0.8990703707173704, 0.9213478667563724, 0.9552020977334359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 455}], {
             RGBColor[
             0.9550963067193019, 0.966021427340793, 0.9605459015242436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 498}], {
             RGBColor[
             0.9738373461641832, 0.950334684333643, 0.6380998060895707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 300}], {
             RGBColor[
             0.9113335247579253, 0.908599065016079, 0.6776057642870242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 308}], {
             RGBColor[
             0.8407833492581112, 0.8532876394305947, 0.670626284354175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 314}], {
             RGBColor[
             0.9860499346099816, 0.963803903281069, 0.4684516426670106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 466}], {
             RGBColor[
             0.9843764602372647, 0.9643890870921151, 0.5890250167426655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 470}], {
             RGBColor[
             0.9658549628127708, 0.8957284103372232, 0.3257828718977529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 493}], {
             RGBColor[
             0.9866797023560374, 0.9651509128105962, 0.5369979753491765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 297}], {
             RGBColor[
             0.8871810741574686, 0.9098096516898004, 0.851620258798508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 484}], {
             RGBColor[
             0.8691551163281812, 0.8507006552213323, 0.6373098738124838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 349}], {
             RGBColor[
             0.9792628548999573, 0.9833649906050055, 0.8890933696344568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 353}], {
             RGBColor[
             0.9385039993678475, 0.8227938417969421, 0.5896240813737655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 394}], {
             RGBColor[
             0.982546045252165, 0.9847226741897868, 0.8346824088741096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 467}], {
             RGBColor[
             0.9805732102313169, 0.9839068562091187, 0.8673773907029363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 398}], {
             RGBColor[
             0.9538416354175296, 0.849489023612801, 0.5278818784173089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 399}], {
             RGBColor[
             0.9794893664293927, 0.9475332321816969, 0.5674784218083889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 464}], {
             RGBColor[
             0.9081380041186011, 0.9270881223927943, 0.8934658179916466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 481}], {
             RGBColor[
             0.9919460030514884, 0.9891302085161385, 0.65176957849307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 496}], {
             RGBColor[
             0.892091732894778, 0.9145074951604737, 0.8918784592337416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 343}], {
             RGBColor[
             0.9900156928318682, 0.989936664591199, 0.8004037615733754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 403}], {
             RGBColor[
             0.9933668905930473, 0.9913224709873006, 0.7448657420488394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 440}], {
             RGBColor[
             0.9935933982105543, 0.9914161377081201, 0.7411119246438247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 445}], {
             RGBColor[
             0.9946166339348821, 0.9908938492655412, 0.6554320099752888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 471}], {
             RGBColor[
             0.994484558851111, 0.990611354016194, 0.641056452179734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 483}], {
             RGBColor[
             0.9935428988788235, 0.9913952549366757, 0.7419488292586851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 497}], {
             RGBColor[
             0.986634917213493, 0.9650083967668548, 0.5360965586472091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 296}], {
             RGBColor[
             0.8914810442931937, 0.9144266909427861, 0.909786172135486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 327}], {
             RGBColor[
             0.9732625613111275, 0.9788559145699344, 0.897724716119082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 385}], {
             RGBColor[
             0.9869175859261983, 0.9888580998248464, 0.866472987612626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 415}], {
             RGBColor[
             0.9873297677537624, 0.9890285476031339, 0.8596420680375123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 438}], {
             RGBColor[
             0.93425679373902, 0.9483282287761043, 0.9139210087918834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 439}], {
             RGBColor[
             0.9909615293287503, 0.9888840453036922, 0.6797836381698559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 321}], {
             RGBColor[
             0.968040451347109, 0.9743753346017489, 0.8803248447251983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 341}], {
             RGBColor[
             0.9516666740972219, 0.9634736651970415, 0.966699892789793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 391}], {
             RGBColor[
             0.883630963432954, 0.909833182083364, 0.9813369870236137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 397}], {
             RGBColor[
             0.968936477756138, 0.9735263206115168, 0.7768273982118705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 455}], {
             RGBColor[
             0.9396568994348856, 0.9545067426677846, 0.9866807908144215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 327}], {
             RGBColor[
             0.8761941725077202, 0.9037496949463532, 0.968081831340619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 339}], {
             RGBColor[
             0.873912105385597, 0.8461599216142683, 0.6307576675231692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 385}], {
             RGBColor[
             0.889849197122791, 0.9137518802012652, 0.9368301028341628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 415}], {
             RGBColor[
             0.8902613789503551, 0.9139223279795526, 0.9299991832590492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 438}], {
             RGBColor[
             0.8371884049356129, 0.8732220091525231, 0.9842781240134202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 325}], {
             RGBColor[
             0.9951540493837361, 0.9920433265696033, 0.7139263650393461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 392}], {
             RGBColor[
             0.9215874435480231, 0.9369139859958151, 0.8549896392543719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 412}], {
             RGBColor[
             0.9768338314916153, 0.9803801641718808, 0.8399493145229668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 413}], {
             RGBColor[
             0.7320826898688124, 0.7859886445057446, 0.8379780866303745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 474}], {
             RGBColor[
             0.9540115536402927, 0.8420628938537686, 0.4866470025536147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 484}], {
             RGBColor[
             0.9772263617833445, 0.9331445201840995, 0.5103120880150981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 490}], {
             RGBColor[
             0.9652807524075472, 0.9717538444571259, 0.8591571460588707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 335}], {
             RGBColor[
             0.9505099550192032, 0.9605760251748241, 0.8845523088192542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 409}], {
             RGBColor[
             0.9592457144302746, 0.8681543132609971, 0.518723893071267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 468}], {
             RGBColor[
             0.5855932080807307, 0.6482305419529514, 0.855723018200407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 312}], {
             RGBColor[
             0.9930837962393921, 0.9905819919115139, 0.7042418560427843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 328}], {
             RGBColor[
             0.993913696222301, 0.9893903365762351, 0.5789215779895416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 399}], {
             RGBColor[
             0.9812991629138326, 0.9474556351954462, 0.4774443414185895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 407}], {
             RGBColor[
             0.9924941224349372, 0.9903381466394463, 0.7140142770094908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 448}], {
             RGBColor[
             0.9789651232839663, 0.981323427772295, 0.7850643939956025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 475}], {
             RGBColor[
             0.9772730824376349, 0.9338747203805808, 0.4618037790300634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 478}], {
             RGBColor[
             0.9915518722705992, 0.9899485019817678, 0.7296298006978303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 482}], {
             RGBColor[
             0.9896140543048361, 0.9755037162866422, 0.5097461243371537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 305}], {
             RGBColor[
             0.9135096853271473, 0.9159397656028649, 0.6860597371650107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 308}], {
             RGBColor[
             0.7738185036719023, 0.8234292556815591, 0.9780383525350091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 432}], {
             RGBColor[
             0.8752120690747851, 0.7719944559081997, 0.614143026740444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 456}], {
             RGBColor[
             0.9193354936710002, 0.9344811097526595, 0.8031187113802009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 493}], {
             RGBColor[
             0.9197148567698286, 0.9352925290615606, 0.8444100435300106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 316}], {
             RGBColor[
             0.5433510760013137, 0.6173466407897785, 0.9622832992250486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 336}], {
             RGBColor[
             0.9511014694739601, 0.959894603114863, 0.8129713895185533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 388}], {
             RGBColor[
             0.9511687566853395, 0.9600385236562229, 0.8202951872286639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 436}], {
             RGBColor[
             0.9254971729416744, 0.9432364149313058, 0.9860324358953628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 346}], {
             RGBColor[
             0.985018256680549, 0.9871085922579553, 0.8547760426235066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 370}], {
             RGBColor[
             0.9539584348288195, 0.8482785203902045, 0.5197863639335728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 390}], {
             RGBColor[
             0.9907870102257501, 0.9904582062123797, 0.8023466132199607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 422}], {
             RGBColor[
             0.9909141839177678, 0.9846769790323722, 0.6022205622300556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 443}], {
             RGBColor[
             0.9740317043210062, 0.9277284111577786, 0.5366353169853946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 451}], {
             RGBColor[
             0.5852872475892169, 0.6481040194268844, 0.860793575345159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 379}], {
             RGBColor[
             0.9282372534361581, 0.7603992586113477, 0.5700919031199962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 400}], {
             RGBColor[
             0.9357198533976008, 0.763143465038285, 0.39605911062437665`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 307}], {
             RGBColor[
             0.8666389060388191, 0.7663489467800113, 0.6135918955074298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 311}], {
             RGBColor[
             0.917751579868715, 0.8071048054753995, 0.6184670679661479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 337}], {
             RGBColor[
             0.9491948363005827, 0.8295078984803739, 0.5165184490979178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 423}], {
             RGBColor[
             0.9471527242658432, 0.8286634326741236, 0.550361530330089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 427}], {
             RGBColor[
             0.9162523936255094, 0.7056756785002704, 0.25147291398335214`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 433}], {
             RGBColor[
             0.9503786977826502, 0.8299974556270611, 0.4968988006047553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 465}], {
             RGBColor[
             0.9422074596638867, 0.8021781780739006, 0.30569186258793024`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 469}], {
             RGBColor[
             0.8506099296336331, 0.7537745597474865, 0.612008189940775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 310}], {
             RGBColor[
             0.9829671750701775, 0.9542064233935396, 0.38833112083707605`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 406}], {
             RGBColor[
             0.9874599798850113, 0.9721050039759358, 0.5824417015194752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 432}], {
             RGBColor[
             0.944353075230216, 0.8091935402440212, 0.3151849314375963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 460}], {
             RGBColor[
             0.985578291302531, 0.9713268773898893, 0.6136261509851237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 493}], {
             RGBColor[
             0.9888558629252595, 0.9724916133973822, 0.5454519482271629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 331}], {
             RGBColor[
             0.9821990880528132, 0.951364938839673, 0.40665192974848824`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 347}], {
             RGBColor[
             0.8373787711808585, 0.841803198143074, 0.6574001414246705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 382}], {
             RGBColor[
             0.9819335757883123, 0.9533023308342954, 0.5598611216088952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 431}], {
             RGBColor[
             0.9829235762615076, 0.9529145458610762, 0.48550800024192425`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 486}], {
             RGBColor[
             0.981748632587157, 0.9532258520677943, 0.5629261090696993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 337}], {
             RGBColor[
             0.9090265385619221, 0.927628197084617, 0.8862372520808206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 427}], {
             RGBColor[
             0.8760840958868488, 0.8037959771045136, 0.621191716966255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 433}], {
             RGBColor[
             0.9102104000439895, 0.9281177542313042, 0.866617603587658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 442}], {
             RGBColor[
             0.8934622120068924, 0.8713664106399946, 0.6420908347591916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 469}], {
             RGBColor[
             0.8104416318949725, 0.8518948583517296, 0.9817269929236778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 500}], {
             RGBColor[
             0.7876521458043608, 0.8340915386112345, 0.9794555499300215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 362}], {
             RGBColor[
             0.7755954478277511, 0.8248461427175688, 0.9782078390548907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 369}], {
             RGBColor[
             0.8403534148137384, 0.8754060409696713, 0.947066892021833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 389}], {
             RGBColor[
             0.847286623772043, 0.8752247114075572, 0.6958902778004568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 456}], {
             RGBColor[
             0.8487853181711861, 0.8791696841671752, 0.7961392314473517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 393}], {
             RGBColor[
             0.9762211109985306, 0.9300026468601742, 0.48522745597878414`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 424}], {
             RGBColor[
             0.9871653438448023, 0.9669201140787226, 0.5277437339415951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 323}], {
             RGBColor[
             0.9354270819969048, 0.7688198724012416, 0.30872950618816486`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 406}], {
             RGBColor[
             0.9877764634726107, 0.9731725774307887, 0.5836711804943883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 408}], {
             RGBColor[
             0.8586493146656077, 0.8737056688748301, 0.6818420051974866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 419}], {
             RGBColor[
             0.9892081606673848, 0.9736357897073997, 0.5505795769028856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 366}], {
             RGBColor[
             0.8949824830755052, 0.9190987546248172, 0.9898454222676779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 405}], {
             RGBColor[
             0.9573618407179019, 0.9672355412176447, 0.9371406607838157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 423}], {
             RGBColor[
             0.9580971003570784, 0.9675395899737549, 0.9249555057717099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 429}], {
             RGBColor[
             0.9592968725931798, 0.9680357266261229, 0.9050721749084948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 465}], {
             RGBColor[
             0.9531518357551221, 0.9410543353735321, 0.6802858380295511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 469}], {
             RGBColor[
             0.8615543057248685, 0.8926507170471178, 0.9866021653823958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 488}], {
             RGBColor[
             0.6360707277067965, 0.7089389625771115, 0.9680830324146962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 327}], {
             RGBColor[
             0.9749093747330309, 0.9795369142410658, 0.8704327559016252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 334}], {
             RGBColor[
             0.9863680680846111, 0.9690524554443428, 0.5825593874890587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 385}], {
             RGBColor[
             0.9885643993481015, 0.9895390994959778, 0.839181027395169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 415}], {
             RGBColor[
             0.9889765811756657, 0.9897095472742653, 0.8323501078200554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 446}], {
             RGBColor[
             0.9337038867827944, 0.9472552311275347, 0.8864192372810469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 386}], {
             RGBColor[
             0.9849339819227463, 0.9704372052676329, 0.6199962571637782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 391}], {
             RGBColor[
             0.9027434297430581, 0.9068126396994972, 0.6842348919204757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 407}], {
             RGBColor[
             0.9864466293095073, 0.9710627238353231, 0.5949277753591978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 498}], {
             RGBColor[
             0.9775104051898709, 0.9357994572767678, 0.36713260027661054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 406}], {
             RGBColor[
             0.9930353835816368, 0.990110757905104, 0.6722456752023093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 411}], {
             RGBColor[
             0.9676707526605464, 0.9725357854200654, 0.7752756444472326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 493}], {
             RGBColor[
             0.9944312666218849, 0.9904973673265505, 0.6352559219099969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 349}], {
             RGBColor[
             0.9914009842808821, 0.9900008922521575, 0.740474159747483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 353}], {
             RGBColor[
             0.9506421287487721, 0.829429743444094, 0.4410048714867917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 364}], {
             RGBColor[
             0.9909998165158277, 0.9898349990717662, 0.7471225478033304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 378}], {
             RGBColor[
             0.9933577850589463, 0.9880500807855184, 0.5312725677479448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 380}], {
             RGBColor[
             0.994700408121971, 0.9910730337808549, 0.6645503132455619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 487}], {
             RGBColor[
             0.9326726732402408, 0.9452199715886114, 0.812834117380492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 372}], {
             RGBColor[
             0.5657611394916502, 0.6347801086003138, 0.9493145034683028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 418}], {
             RGBColor[
             0.5820022764409083, 0.6333596116462363, 0.6650152700619424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 322}], {
             RGBColor[
             0.860451854297887, 0.8880958831345112, 0.7822612023379782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 343}], {
             RGBColor[
             0.8559311205254632, 0.887310253830096, 0.9359630268885253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 374}], {
             RGBColor[
             0.7984958981104365, 0.6448303436086273, 0.5933720748611948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 440}], {
             RGBColor[
             0.8595088259041492, 0.8887897269470171, 0.8766711899589745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 445}], {
             RGBColor[
             0.860532061628477, 0.8882674385044382, 0.7909912752904386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 471}], {
             RGBColor[
             0.8603999865447058, 0.887984943255091, 0.7766157174948838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 335}], {
             RGBColor[
             0.7966123380415555, 0.8417564273972196, 0.9801721161523531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 421}], {
             RGBColor[
             0.828793142996805, 0.8372122872874541, 0.6596347645281896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 430}], {
             RGBColor[
             0.8393941243457503, 0.8718479827123802, 0.7963862498380538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 459}], {
             RGBColor[
             0.8103160996584844, 0.7690311887410213, 0.6183410715931984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 330}], {
             RGBColor[
             0.9752154728421327, 0.9631149255186315, 0.660715195714165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 357}], {
             RGBColor[
             0.9807527841090984, 0.9816029824307139, 0.6984333605607739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 368}], {
             RGBColor[
             0.9792759125854147, 0.9831232487057089, 0.8778094647526602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 492}], {
             RGBColor[
             0.9153758577976584, 0.7213458516827096, 0.57224381242458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 329}], {
             RGBColor[
             0.9522808598885346, 0.963384379747522, 0.945352652259524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 424}], {
             RGBColor[
             0.9822330778885414, 0.9652542590453663, 0.6366528199637241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 341}], {
             RGBColor[
             0.9757025117770222, 0.9800896867249056, 0.8673549750027674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 373}], {
             RGBColor[
             0.991158366221006, 0.9848661107476023, 0.598783160926903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 391}], {
             RGBColor[
             0.9076668011127542, 0.926449203611228, 0.8819920692365882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 397}], {
             RGBColor[
             0.9929723154359382, 0.9901423421393808, 0.677482480424845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 455}], {
             RGBColor[
             0.9636927371146857, 0.9711227641956486, 0.8873358730273959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 498}], {
             RGBColor[
             0.982433776559567, 0.9554360211884985, 0.5648897775927231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 343}], {
             RGBColor[
             0.9895049463808943, 0.9888442295769532, 0.7448121623465866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 374}], {
             RGBColor[
             0.9320697239658677, 0.7463643193554845, 0.4022212103192563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 440}], {
             RGBColor[
             0.9930826517595803, 0.9903237026938743, 0.6855203254170359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 445}], {
             RGBColor[
             0.9941058874839082, 0.9898014142512954, 0.5998404107485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 471}], {
             RGBColor[
             0.9939738124001369, 0.9895189190019482, 0.5854648529529451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 419}], {
             RGBColor[
             0.9413515840065128, 0.7871816652602488, 0.4697484832790613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 449}], {
             RGBColor[
             0.8223327131443487, 0.6962666607138044, 0.60216110844838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 499}], {
             RGBColor[
             0.8890697795256626, 0.7489726769032113, 0.6086614389998632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 342}], {
             RGBColor[
             0.7885189041007457, 0.8349601275338938, 0.9794911298457851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 360}], {
             RGBColor[
             0.9216086309264866, 0.9354586644061635, 0.7356490734349659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 457}], {
             RGBColor[
             0.8922383520659085, 0.8303269354726579, 0.6257891261316477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 392}], {
             RGBColor[
             0.921489173319127, 0.9367037959128508, 0.8442935312925958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 413}], {
             RGBColor[
             0.7319844196399166, 0.7857784544227803, 0.8272819786685984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 474}], {
             RGBColor[
             0.9539132834113967, 0.8418527037708043, 0.47595089459183854`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 490}], {
             RGBColor[
             0.9651824821786512, 0.9715436543741616, 0.8484610380970945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 338}], {
             RGBColor[
             0.9779708317104522, 0.9367690943976005, 0.4185370181612344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 346}], {
             RGBColor[
             0.9859187245278406, 0.9858991633509004, 0.7248731252807812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 355}], {
             RGBColor[
             0.8601632296577364, 0.8874785442136566, 0.7508461914423921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 395}], {
             RGBColor[
             0.7818554375861251, 0.8251994746044777, 0.7437963055208587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 443}], {
             RGBColor[
             0.9749321721682978, 0.9265189822507237, 0.4067323996426692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 334}], {
             RGBColor[
             0.9694343828772343, 0.9576944597767785, 0.6681470069116485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 385}], {
             RGBColor[
             0.9716307141407248, 0.9781811038284134, 0.9247686468177589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 415}], {
             RGBColor[
             0.9720428959682889, 0.978351551606701, 0.9179377272426452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 446}], {
             RGBColor[
             0.9167702015754176, 0.9358972354599704, 0.9720068567036368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 398}], {
             RGBColor[
             0.9552405955858939, 0.8485326892883877, 0.3931308004105175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 399}], {
             RGBColor[
             0.9808883265977569, 0.9465768978572836, 0.4327273438015976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 407}], {
             RGBColor[
             0.9920832861188615, 0.9894594093012837, 0.6692972793924988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 464}], {
             RGBColor[
             0.9095369642869654, 0.926131788068381, 0.7587147399848553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 475}], {
             RGBColor[
             0.9768622461215593, 0.9329959830424183, 0.4170867814130715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 478}], {
             RGBColor[
             0.9911410359545234, 0.9890697646436053, 0.6849128030808385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 481}], {
             RGBColor[
             0.9933449632198527, 0.9881738741917252, 0.5170185004862786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 333}], {
             RGBColor[
             0.9588151791148067, 0.8668010975203392, 0.32541461418560935`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 352}], {
             RGBColor[
             0.9875840640183267, 0.969207585295826, 0.4549641687875597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 357}], {
             RGBColor[
             0.9872745093867774, 0.9685454792397166, 0.4212710574931713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 358}], {
             RGBColor[
             0.9853023822251785, 0.9698609445809443, 0.6088548292858196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 367}], {
             RGBColor[
             0.9877869823140104, 0.9696416070121069, 0.47705057300618214`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 368}], {
             RGBColor[
             0.9857976378630937, 0.9700657455147115, 0.6006471616850575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 441}], {
             RGBColor[
             0.9882457187988649, 0.9706227979678375, 0.5269812083891727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 492}], {
             RGBColor[
             0.9218975830753375, 0.7082883484917122, 0.2950815093569774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 348}], {
             RGBColor[
             0.9899045938428885, 0.9880461162216522, 0.6681615697904624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 372}], {
             RGBColor[
             0.9727521204496489, 0.9757037643449502, 0.7173452280932004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 382}], {
             RGBColor[
             0.9926434496514966, 0.9891787034838952, 0.6227716411102022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 404}], {
             RGBColor[
             0.9754742364313488, 0.9286804352502241, 0.3805271510807682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 418}], {
             RGBColor[
             0.9889932573989071, 0.9742832673908728, 0.43304599468684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 431}], {
             RGBColor[
             0.993633450124692, 0.988790918510676, 0.5484185197432313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 444}], {
             RGBColor[
             0.9128622369205899, 0.9283849053981503, 0.7267391651560225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 486}], {
             RGBColor[
             0.9924585064503414, 0.9891022247173942, 0.6258366285710064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 420}], {
             RGBColor[
             0.9491728374028843, 0.9580901384195297, 0.7911738806890548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 454}], {
             RGBColor[
             0.6412803077656398, 0.7142896488469272, 0.968029016136362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 489}], {
             RGBColor[
             0.9487041012640681, 0.9570875592150953, 0.7401548446830413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 358}], {
             RGBColor[
             0.9623803632201734, 0.8866046197736492, 0.5507165508248666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 361}], {
             RGBColor[
             0.9588280637294853, 0.8668445603511012, 0.3254646684805801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 367}], {
             RGBColor[
             0.9648649633090054, 0.8863852822048119, 0.41891229454522916`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 386}], {
             RGBColor[
             0.9617657888338886, 0.8863504774710793, 0.5609016388731325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 441}], {
             RGBColor[
             0.9653236997938599, 0.8873664731605424, 0.46884292992821974`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 450}], {
             RGBColor[
             0.9276492273488461, 0.8610588071491397, 0.6297256137784435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 461}], {
             RGBColor[
             0.9655136954864157, 0.8877728547354085, 0.4895227885454335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 385}], {
             RGBColor[
             0.983089407492305, 0.9676966450316904, 0.6368952784051924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 415}], {
             RGBColor[
             0.9835015893198691, 0.967867092809978, 0.6300643588300787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 446}], {
             RGBColor[
             0.9282288949269979, 0.9254127766632474, 0.6841334882910703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 409}], {
             RGBColor[
             0.9174962532880164, 0.8376632545299183, 0.6253311654897074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 421}], {
             RGBColor[
             0.9409412988321947, 0.9255408263339798, 0.670622229613531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 430}], {
             RGBColor[
             0.9515422801811401, 0.960176521758906, 0.8073737149233954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 459}], {
             RGBColor[
             0.922464255493874, 0.857359727787547, 0.6293285366785398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 354}], {
             RGBColor[
             0.9747591240567491, 0.9782585223194067, 0.7978907474661551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 388}], {
             RGBColor[
             0.994495074156672, 0.9906338451915289, 0.64220097829712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 436}], {
             RGBColor[
             0.9688234904130071, 0.9738317364666118, 0.8079382269638189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 420}], {
             RGBColor[
             0.9928063797219766, 0.9902134344944815, 0.6903879821711447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 427}], {
             RGBColor[
             0.9586400261486123, 0.8669549288048761, 0.5241182705567429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 433}], {
             RGBColor[
             0.992766330305753, 0.9912767059316667, 0.769544157178146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 500}], {
             RGBColor[
             0.8702080760661244, 0.897250490311597, 0.8823821035205094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 383}], {
             RGBColor[
             0.9787614362281793, 0.9384601175186406, 0.5045894408703282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 395}], {
             RGBColor[
             0.7663778384235603, 0.7735733879624191, 0.6340530076772258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 443}], {
             RGBColor[
             0.9594545730057329, 0.8748928956086651, 0.29698910179903637`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 480}], {
             RGBColor[
             0.9346502181626837, 0.776685827965655, 0.2763334064210643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 344}], {
             RGBColor[
             0.97400117932345, 0.9219189860994099, 0.46699627979716807`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 387}], {
             RGBColor[
             0.9398217839902476, 0.7991204572627116, 0.27043739871551786`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 439}], {
             RGBColor[
             0.9733925904211536, 0.9206172759751745, 0.4007551335575391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 384}], {
             RGBColor[
             0.9689937523457456, 0.9599984866034235, 0.6744814936829664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 414}], {
             RGBColor[
             0.9884652143988986, 0.9728852594706392, 0.5683022251666521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 461}], {
             RGBColor[
             0.9890156371931578, 0.9729853949879876, 0.5499139571934214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 499}], {
             RGBColor[
             0.936733048619289, 0.9347747295352673, 0.688741569228009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 374}], {
             RGBColor[
             0.9147212511527762, 0.7361433985748995, 0.5835310529549174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 391}], {
             RGBColor[
             0.8912930238628671, 0.9155475342065207, 0.9683671173011827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 397}], {
             RGBColor[
             0.9765985381860511, 0.9792406727346734, 0.7638575284894396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 455}], {
             RGBColor[
             0.9473189598647986, 0.9602210947909413, 0.9737109210919905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 485}], {
             RGBColor[
             0.8537062493333424, 0.8857825638347697, 0.9456231553768765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 374}], {
             RGBColor[
             0.927548990193444, 0.7455786900510695, 0.5559230348698032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 403}], {
             RGBColor[
             0.9883354103696496, 0.9894444066686396, 0.8429759673725975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 440}], {
             RGBColor[
             0.9885619179871565, 0.989538073389459, 0.8392221499675829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 445}], {
             RGBColor[
             0.9895851537114844, 0.9890157849468802, 0.753542235299047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 471}], {
             RGBColor[
             0.9894530786277131, 0.9887332896975332, 0.7391666775034922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 387}], {
             RGBColor[
             0.9604114080322901, 0.8680400714527897, 0.45606163082337026`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 438}], {
             RGBColor[
             0.9372774788734658, 0.9489810736376647, 0.8205167362874191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 439}], {
             RGBColor[
             0.993982214463196, 0.9895368901652526, 0.5863793656653915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 389}], {
             RGBColor[
             0.9927099509324728, 0.9870830004944458, 0.5839575916175518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 456}], {
             RGBColor[
             0.9942086453316159, 0.9910279732540639, 0.6842065452644466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 472}], {
             RGBColor[
             0.990167926052568, 0.9902021989970313, 0.8126064401080724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 355}], {
             RGBColor[
             0.8526335233125599, 0.8849825265248978, 0.947439000718306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 390}], {
             RGBColor[
             0.9841577717278653, 0.986752759616566, 0.8690365051531492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 395}], {
             RGBColor[
             0.7743257312409487, 0.822703456915719, 0.9403891147967727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 431}], {
             RGBColor[
             0.9863734782580253, 0.9868718355971104, 0.7743702623966813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 443}], {
             RGBColor[
             0.9674024658231213, 0.9240229645619651, 0.6033252089185832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 486}], {
             RGBColor[
             0.9851985345836747, 0.9871831418038286, 0.8517883712244563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 382}], {
             RGBColor[
             0.847823132779542, 0.8796169627872963, 0.8735198527863846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 462}], {
             RGBColor[
             0.7671779684865162, 0.818134273177258, 0.9774049723609513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 355}], {
             RGBColor[
             0.8568891271061176, 0.8877064141708427, 0.9200863786055231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 372}], {
             RGBColor[
             0.9697477523765399, 0.9765085690773296, 0.9159443486338675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 400}], {
             RGBColor[
             0.9903777024481003, 0.9890580476895827, 0.7196565217799046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 404}], {
             RGBColor[
             0.9724698683582398, 0.9294852399826035, 0.5791262716214353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 418}], {
             RGBColor[
             0.985988889325798, 0.9750880721232521, 0.6316451152275071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 431}], {
             RGBColor[
             0.9906290820515828, 0.9895957232430554, 0.7470176402838984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 444}], {
             RGBColor[
             0.9098578688474808, 0.9291897101305295, 0.9253382856966896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 486}], {
             RGBColor[
             0.9894541383772324, 0.9899070294497735, 0.8244357491116735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 353}], {
             RGBColor[
             0.9475855236746584, 0.8288769667052134, 0.5433580422702399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 378}], {
             RGBColor[
             0.9903011799848327, 0.9874973040466377, 0.633625738531393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 380}], {
             RGBColor[
             0.9916438030478574, 0.9905202570419742, 0.7669034840290101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 487}], {
             RGBColor[
             0.9296160681661272, 0.9446671948497307, 0.9151872881639402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 377}], {
             RGBColor[
             0.9506829634333709, 0.8400016960291887, 0.2905285693865953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 412}], {
             RGBColor[
             0.9482236419349522, 0.880265567971154, 0.6121367023372455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 426}], {
             RGBColor[
             0.7321761968817412, 0.7091770022670069, 0.6124251345837166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 476}], {
             RGBColor[
             0.9654617657172242, 0.8896142404844067, 0.3683344869073397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 371}], {
             RGBColor[
             0.8627671492501003, 0.8936394477244218, 0.9859307670478855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 442}], {
             RGBColor[
             0.9485100489480832, 0.9152376967637145, 0.6465659442582151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 460}], {
             RGBColor[
             0.9625360866525121, 0.9708633612363932, 0.9162057887982322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 357}], {
             RGBColor[
             0.9931213752852923, 0.9876956422079084, 0.4926823336341686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 367}], {
             RGBColor[
             0.9936338482125253, 0.9887917699802988, 0.5484618491471795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 368}], {
             RGBColor[
             0.9916445037616086, 0.9892159084829034, 0.6720584378260548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 375}], {
             RGBColor[
             0.9743068938323534, 0.9772268887352433, 0.7435616779826908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 380}], {
             RGBColor[
             0.9508849475157473, 0.8299491082339108, 0.46743419576831885`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 487}], {
             RGBColor[
             0.8888572126340172, 0.7840960460416673, 0.6157179999032489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 388}], {
             RGBColor[
             0.9748264112681285, 0.9784024428607665, 0.8052145451762657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 409}], {
             RGBColor[
             0.9406612369336467, 0.8556343313023679, 0.6102035320435104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 436}], {
             RGBColor[
             0.9491548275244635, 0.9616003341358494, 0.9709517938429646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 473}], {
             RGBColor[
             0.9462607938224218, 0.8778347084246421, 0.6147090669547121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 395}], {
             RGBColor[
             0.6485702363708445, 0.7242828377784751, 0.9663621809583836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 404}], {
             RGBColor[
             0.8424587696945779, 0.8283407331994147, 0.6324519598958289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 431}], {
             RGBColor[
             0.8606179833879211, 0.8884512164598666, 0.8003433285582922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 443}], {
             RGBColor[
             0.8416469709530171, 0.8256023454247212, 0.6292982750801941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 444}], {
             RGBColor[
             0.779846770183819, 0.8280452033473409, 0.9786639739710834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 486}], {
             RGBColor[
             0.8594430397135705, 0.8887625226665847, 0.8777614373860672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 365}], {
             RGBColor[
             0.8819876279053673, 0.9079630689168329, 0.9528396882863186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 457}], {
             RGBColor[
             0.8613323727894311, 0.805939049973754, 0.6227734304031818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 494}], {
             RGBColor[
             0.8913707364723769, 0.9132661109233792, 0.8610570155082586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 367}], {
             RGBColor[
             0.9933242935809761, 0.9881296639241892, 0.5147687378527911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 368}], {
             RGBColor[
             0.9913349491300594, 0.9885538024267939, 0.6383653265316664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 441}], {
             RGBColor[
             0.9937830300658306, 0.9891108548799198, 0.5646993732357817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 492}], {
             RGBColor[
             0.9274348943423032, 0.7267764054037946, 0.3327996742035863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 361}], {
             RGBColor[
             0.985315266839857, 0.9699044074117062, 0.6089048835807904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 386}], {
             RGBColor[
             0.9882529919442604, 0.9894103245316843, 0.8443418539733427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 398}], {
             RGBColor[
             0.9529229487980538, 0.8491091230864786, 0.5431068931867811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 441}], {
             RGBColor[
             0.9918109029042317, 0.9904263202211475, 0.7522831450284301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 408}], {
             RGBColor[
             0.4564709853367192, 0.5487656704506338, 0.9538122052914921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 440}], {
             RGBColor[
             0.5855333116829213, 0.6482057732531901, 0.856715656519016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 463}], {
             RGBColor[
             0.5747563755550478, 0.6414887409280485, 0.9340879151462755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 483}], {
             RGBColor[
             0.5854828123511906, 0.6481848904817458, 0.8575525611338763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 457}], {
             RGBColor[
             0.9636872032333597, 0.8824272521986876, 0.3758680067549601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 494}], {
             RGBColor[
             0.9937255669163052, 0.9897543131483127, 0.614151591860037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 386}], {
             RGBColor[
             0.9847006924535722, 0.9696502651091363, 0.6190899716290563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 398}], {
             RGBColor[
             0.9493706493073657, 0.8293490636639305, 0.3178550108424946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 441}], {
             RGBColor[
             0.9882586034135434, 0.9706662607985994, 0.5270312626841436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 481}], {
             RGBColor[
             0.9874750169413244, 0.9689902485672681, 0.4417427109182558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 369}], {
             RGBColor[
             0.9126805344694013, 0.9321343535911653, 0.9542158584745639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 470}], {
             RGBColor[
             0.9006670613824108, 0.8672869136241973, 0.6333644265984686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 381}], {
             RGBColor[
             0.8753993738882541, 0.9034343916049944, 0.9834720038772102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 378}], {
             RGBColor[
             0.9899000122197783, 0.9873314108662463, 0.6402741265872405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 380}], {
             RGBColor[
             0.991242635282803, 0.9903543638615829, 0.7735518720848575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 381}], {
             RGBColor[
             0.9641283678583042, 0.9722110120317231, 0.9206814241604935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 416}], {
             RGBColor[
             0.9902790316776209, 0.9882933131853678, 0.6686695663329211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 452}], {
             RGBColor[
             0.9904620817890805, 0.9903238399535368, 0.8077315183034175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 468}], {
             RGBColor[
             0.5832345218383298, 0.6472551645762471, 0.894812553321313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 487}], {
             RGBColor[
             0.9292149004010728, 0.9445013016693393, 0.9218356762197877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 405}], {
             RGBColor[
             0.9236483678334568, 0.9403533330674309, 0.9339250396437249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 423}], {
             RGBColor[
             0.9243836274726334, 0.9406573818235411, 0.921739884631619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 429}], {
             RGBColor[
             0.9255833997087346, 0.9411535184759091, 0.9018565537684039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 465}], {
             RGBColor[
             0.9194383628706768, 0.9141721272233183, 0.6770702168894602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 469}], {
             RGBColor[
             0.8278408328404233, 0.865768508896904, 0.9833865442423049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 488}], {
             RGBColor[
             0.6023572548223513, 0.6820567544268977, 0.9648674112746053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 368}], {
             RGBColor[
             0.9918474220572924, 0.9896499301991843, 0.6941448420446773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 375}], {
             RGBColor[
             0.9745098121280371, 0.9776609104515243, 0.7656480822013132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 441}], {
             RGBColor[
             0.9942955029930636, 0.9902069826523101, 0.6204788887487926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 450}], {
             RGBColor[
             0.9566210305480498, 0.9638993166409074, 0.7813615725990162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 492}], {
             RGBColor[
             0.9259580228186195, 0.7282966716787896, 0.5121757783954726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 456}], {
             RGBColor[
             0.9858704048128364, 0.9864578950407717, 0.7721472508670248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 390}], {
             RGBColor[
             0.9530979498761358, 0.8479226877488152, 0.5340468264632154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 422}], {
             RGBColor[
             0.9532251235681535, 0.8421414605688078, 0.3339207754733104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 443}], {
             RGBColor[
             0.9363426439713918, 0.7851928926942142, 0.2683355302286494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 451}], {
             RGBColor[
             0.5475981872396026, 0.50556850096332, 0.5924937885884138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 442}], {
             RGBColor[
             0.8747109160156434, 0.8566653268564421, 0.6402357938177208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 460}], {
             RGBColor[
             0.8887369537200722, 0.9122909913291208, 0.9098756383577378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 400}], {
             RGBColor[
             0.9732252290548606, 0.9767156958128809, 0.7688401800826427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 404}], {
             RGBColor[
             0.9553173949650001, 0.9171428881059016, 0.6283099299241733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 418}], {
             RGBColor[
             0.9688364159325584, 0.9627457202465501, 0.6808287735302452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 431}], {
             RGBColor[
             0.9734766086583433, 0.9772533713663535, 0.7962012985866365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 444}], {
             RGBColor[
             0.8927053954542412, 0.9168473582538277, 0.9745219439994277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 486}], {
             RGBColor[
             0.9723016649839927, 0.9775646775730715, 0.8736194074144116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 449}], {
             RGBColor[
             0.8736676821838837, 0.8944542194195549, 0.6965050996240262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 498}], {
             RGBColor[
             0.9815158537536637, 0.949310775806488, 0.38269301158145325`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 397}], {
             RGBColor[
             0.9319910548116922, 0.7461960539893748, 0.39365855837699504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 445}], {
             RGBColor[
             0.9321499312964577, 0.7465358747254116, 0.4109512832717165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 402}], {
             RGBColor[
             0.9003756921992805, 0.922896718142129, 0.9729400930141723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 417}], {
             RGBColor[
             0.9505448753876025, 0.8946709580294352, 0.6180407656597269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 441}], {
             RGBColor[
             0.9749685486128916, 0.9786421014072548, 0.8155787175843039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 450}], {
             RGBColor[
             0.9372940761678779, 0.952334435395852, 0.9764614014345275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 461}], {
             RGBColor[
             0.9751585443054476, 0.9790484829821207, 0.8362585762015176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 391}], {
             RGBColor[
             0.8938709054708682, 0.8768835319616324, 0.6497668105586358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 448}], {
             RGBColor[
             0.9640451058863466, 0.932118897230307, 0.6315098109834697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 455}], {
             RGBColor[
             0.9498968414727997, 0.921557092546053, 0.6551106143494436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 475}], {
             RGBColor[
             0.9623530650400152, 0.8846701898385929, 0.30824919601793066`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 482}], {
             RGBColor[
             0.9746940369072163, 0.9262991857446543, 0.3561915413250209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 412}], {
             RGBColor[
             0.9608746648690172, 0.9282429397492289, 0.6336680230941611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 426}], {
             RGBColor[
             0.7448272198158061, 0.7571543740450818, 0.6339564553406323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 476}], {
             RGBColor[
             0.9781127886512893, 0.9375916122624817, 0.3898658076642554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 380}], {
             RGBColor[
             0.9936006038259215, 0.9885694455753351, 0.557701892029472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 416}], {
             RGBColor[
             0.9926370002207396, 0.98650839489912, 0.4528195862775355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 452}], {
             RGBColor[
             0.9928200503321991, 0.9885389216672889, 0.5918815382480319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 487}], {
             RGBColor[
             0.9315728689441914, 0.9427163833830915, 0.705985696164402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 400}], {
             RGBColor[
             0.9863725791649787, 0.9865209679981968, 0.7465851457242993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 404}], {
             RGBColor[
             0.968464745075118, 0.9269481602912175, 0.60605489556583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 440}], {
             RGBColor[
             0.9855148012846893, 0.9873971540388198, 0.8502741256289755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 487}], {
             RGBColor[
             0.932915492007216, 0.9457393363784281, 0.8392634416620193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 416}], {
             RGBColor[
             0.9668653558592655, 0.9713879960645966, 0.7332268838507885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 468}], {
             RGBColor[
             0.5598208460199744, 0.630349847455476, 0.9593698708391805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 425}], {
             RGBColor[
             0.988497146339097, 0.989511288648431, 0.8402955837995828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 462}], {
             RGBColor[
             0.9117327730939699, 0.9296334058684794, 0.879865952545176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 393}], {
             RGBColor[
             0.9763115586922702, 0.9301961053314185, 0.4950721292638738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 395}], {
             RGBColor[
             0.7826460421038522, 0.8268904977255178, 0.8298487282299525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 443}], {
             RGBColor[
             0.9757227766860248, 0.9282100053717638, 0.492784822351763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 480}], {
             RGBColor[
             0.9509184218429756, 0.8300029377287537, 0.47212912697379095`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 402}], {
             RGBColor[
             0.9003294939094507, 0.9228622635332169, 0.9730182946684103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 411}], {
             RGBColor[
             0.9483152338067347, 0.9609741665158759, 0.9723730070059674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 458}], {
             RGBColor[
             0.9445240221253288, 0.9581017807040473, 0.9772336082225619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 461}], {
             RGBColor[
             0.9751123460156177, 0.9790140283732085, 0.8363367778557558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 499}], {
             RGBColor[
             0.922829757441749, 0.9408033629204882, 0.9751643898903433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 415}], {
             RGBColor[
             0.9856979205833596, 0.9883537368616129, 0.8866859987361893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 446}], {
             RGBColor[
             0.9304252261904883, 0.9458994207148823, 0.9407551281971807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 441}], {
             RGBColor[
             0.9911963285179468, 0.9901721779185775, 0.7624682330766959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 498}], {
             RGBColor[
             0.9802148408251001, 0.9545184342382492, 0.601663285134441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 439}], {
             RGBColor[
             0.9598028191299937, 0.8667383613285543, 0.38982048458374136`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 436}], {
             RGBColor[
             0.9688907776243865, 0.9739756570079717, 0.8152620246739295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 473}], {
             RGBColor[
             0.9659967439223447, 0.8902100312967643, 0.45901929778567696`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 456}], {
             RGBColor[
             0.9928036137711409, 0.9862765654786576, 0.5209706366456485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 472}], {
             RGBColor[
             0.988762894492093, 0.985450791221625, 0.6493705314892743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 422}], {
             RGBColor[
             0.9900536989650841, 0.9843211463909829, 0.6164810247596982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 443}], {
             RGBColor[
             0.9731712193683224, 0.9273725785163893, 0.5508957795150373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 451}], {
             RGBColor[
             0.5844267626365333, 0.6477481867854952, 0.8750540378748017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 407}], {
             RGBColor[
             0.9069605127650484, 0.926157135228669, 0.8936970949737257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 448}], {
             RGBColor[
             0.8934315136140776, 0.9171424163615177, 0.9647472119598375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 455}], {
             RGBColor[
             0.8792832492005307, 0.9065806116772637, 0.9883480153258113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 475}], {
             RGBColor[
             0.8917394727677461, 0.8696937089698036, 0.6414865969942984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 478}], {
             RGBColor[
             0.9060182626007103, 0.9257674905709905, 0.9093126186620655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 482}], {
             RGBColor[
             0.9040804446349473, 0.911322704875865, 0.6894289423013886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 413}], {
             RGBColor[
             0.6584178138042035, 0.7306491138489921, 0.9683452528836243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 473}], {
             RGBColor[
             0.892676846980026, 0.8356083760998514, 0.6269353125358724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 474}], {
             RGBColor[
             0.8803466775756836, 0.7867233631970162, 0.6170141688068644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 490}], {
             RGBColor[
             0.8916158763429383, 0.9164143138003735, 0.9895243123121203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 424}], {
             RGBColor[
             0.9685377103223407, 0.9055324505996462, 0.33227537506750365`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 480}], {
             RGBColor[
             0.9322003406267745, 0.7684218157784329, 0.2668160948146098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 467}], {
             RGBColor[
             0.9929379248903356, 0.9913476647021713, 0.7667003908390633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 443}], {
             RGBColor[
             0.7633391788814059, 0.7633232758155424, 0.6222483891586607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 430}], {
             RGBColor[
             0.914746957492438, 0.9308369302293621, 0.8038641441977746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 477}], {
             RGBColor[
             0.8437361065212341, 0.8782362850062759, 0.9849574971237511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 495}], {
             RGBColor[
             0.992788148498688, 0.9900661843779535, 0.6805346031838346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 399}], {
             RGBColor[
             0.9426260622774255, 0.8065979879075987, 0.2916535638395654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 464}], {
             RGBColor[
             0.871274699966634, 0.7861528781186962, 0.6176409600228231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 481}], {
             RGBColor[
             0.9550826988995212, 0.8481949642420403, 0.3759447205242465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 496}], {
             RGBColor[
             0.8552284287428109, 0.7735722508863756, 0.616053601264918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 407}], {
             RGBColor[
             0.9794687528103931, 0.9475247079204948, 0.5678200428215467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 464}], {
             RGBColor[
             0.896922430978497, 0.8841970866875921, 0.6572375034139031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 478}], {
             RGBColor[
             0.978526502646055, 0.9471350632628164, 0.5834355665098863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 481}], {
             RGBColor[
             0.9807304299113843, 0.9462391728109363, 0.41554126391532653`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 496}], {
             RGBColor[
             0.8808761597546739, 0.8716164594552716, 0.6556501446559981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 404}], {
             RGBColor[
             0.9759473450365606, 0.9296923667181547, 0.4320221030702104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 418}], {
             RGBColor[
             0.989466366004119, 0.9752951988588034, 0.4845409466762822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 431}], {
             RGBColor[
             0.9941065587299038, 0.9898028499786067, 0.5999134717326735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 444}], {
             RGBColor[
             0.9133353455258018, 0.9293968368660809, 0.7782341171454648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 428}], {
             RGBColor[
             0.9767996547122061, 0.9677095162617307, 0.6652789766676801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 437}], {
             RGBColor[
             0.94494807621163, 0.9431774825687987, 0.6922501209295383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 451}], {
             RGBColor[
             0.5816311259117967, 0.6321076337612541, 0.6635734203422397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 417}], {
             RGBColor[
             0.8957377098390178, 0.8514716469650954, 0.6302329476370745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 458}], {
             RGBColor[
             0.8897630548665739, 0.9149369242486198, 0.9893475885456715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 461}], {
             RGBColor[
             0.9203513787568629, 0.9358491719177809, 0.8484507581788653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 440}], {
             RGBColor[
             0.9919131157483356, 0.9909238797855606, 0.7836841304430466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 445}], {
             RGBColor[
             0.9929363514726635, 0.9904015913429819, 0.6980042157745108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 471}], {
             RGBColor[
             0.9928042763888922, 0.9901190960936348, 0.683628657978956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 483}], {
             RGBColor[
             0.9918626164166049, 0.9909029970141163, 0.784521035057907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 497}], {
             RGBColor[
             0.9849546347512743, 0.9645161388442954, 0.5786687644464311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 418}], {
             RGBColor[
             0.9715585319142583, 0.9157223911518241, 0.34401069651781285`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 431}], {
             RGBColor[
             0.9761987246400432, 0.9302300422716274, 0.4593832215742042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 444}], {
             RGBColor[
             0.8954275114359411, 0.8698240291591015, 0.6377038669869954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 486}], {
             RGBColor[
             0.9750237809656926, 0.9305413484783455, 0.5368013304019793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 423}], {
             RGBColor[
             0.98676298511503, 0.9887941684163686, 0.8690351231477569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 429}], {
             RGBColor[
             0.9879627573511314, 0.9892903050687366, 0.8491517922845417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 472}], {
             RGBColor[
             0.9861242975440209, 0.9885300546922344, 0.8796198290698288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 488}], {
             RGBColor[
             0.664736612464748, 0.7301935410197252, 0.9121626497907431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 419}], {
             RGBColor[
             0.9937009654822186, 0.9915343702897959, 0.7446901575852847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 493}], {
             RGBColor[
             0.9936651513276926, 0.9914577674346313, 0.7407920078844752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 448}], {
             RGBColor[
             0.9771347131805268, 0.9813925004973436, 0.8754400953985597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 455}], {
             RGBColor[
             0.9629864487669799, 0.9708306958130897, 0.8990408987645335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 475}], {
             RGBColor[
             0.9754426723341953, 0.9339437931056295, 0.5521794804330207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 478}], {
             RGBColor[
             0.9897214621671596, 0.9900175747068165, 0.8200055021007876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 482}], {
             RGBColor[
             0.9877836442013965, 0.975572789011691, 0.6001218257401109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{408, 463}], {
             RGBColor[
             0.852300360891767, 0.8848604113786824, 0.9543991204377676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 430}], {
             RGBColor[
             0.9602780395922115, 0.8677548098450791, 0.4415452991754081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 422}], {
             RGBColor[
             0.970410400859971, 0.9706239198212578, 0.6923964390424008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 428}], {
             RGBColor[
             0.9599519933318295, 0.9696528427162467, 0.9526750084829447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 437}], {
             RGBColor[
             0.9281004148312534, 0.9451208090233147, 0.9796461527448028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{412, 426}], {
             RGBColor[
             0.7423678983173875, 0.7974182459870469, 0.9555645882912824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{412, 476}], {
             RGBColor[
             0.9756534671528705, 0.9778554842044469, 0.7114739406149057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 474}], {
             RGBColor[
             0.6908419238964731, 0.6357980217069457, 0.6000026161828671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 490}], {
             RGBColor[
             0.7021111226637275, 0.7654889723103029, 0.972512759688123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 461}], {
             RGBColor[
             0.9945838080687707, 0.9919008012404241, 0.7301575093394412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 498}], {
             RGBColor[
             0.983412324683368, 0.9558406759852299, 0.5486727027799727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 499}], {
             RGBColor[
             0.9423012194949019, 0.9536901357877039, 0.868985121374029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 452}], {
             RGBColor[
             0.9931990697900417, 0.9895008239864104, 0.6202769779937125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 468}], {
             RGBColor[
             0.5859715098392911, 0.6464321486091207, 0.7073580130116081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{417, 458}], {
             RGBColor[
             0.939932238054896, 0.8867111641359259, 0.6344482611912261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 431}], {
             RGBColor[
             0.9897177456076015, 0.975832874412276, 0.511902065180276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 444}], {
             RGBColor[
             0.9089465324034994, 0.9154268612997503, 0.6902227105930672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 486}], {
             RGBColor[
             0.988542801933251, 0.9761441806189941, 0.5893201740080511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 427}], {
             RGBColor[
             0.9598639370469033, 0.8663812145143781, 0.4253424470565792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 454}], {
             RGBColor[
             0.686137760983023, 0.745839230631381, 0.7684672941182884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 489}], {
             RGBColor[
             0.9935615544814513, 0.9886371409995489, 0.5405931226649676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 500}], {
             RGBColor[
             0.8714319869644154, 0.896676776021099, 0.7836062800203458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 430}], {
             RGBColor[
             0.9837230851363896, 0.9556323816491405, 0.48683636329923174`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 459}], {
             RGBColor[
             0.9546450604491237, 0.8528155876777815, 0.30879118505437625`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 477}], {
             RGBColor[
             0.9127122341651857, 0.9030317364260544, 0.6679297162252082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 428}], {
             RGBColor[
             0.9797224651289603, 0.9775688421059643, 0.676633543210337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 437}], {
             RGBColor[
             0.9478708866283843, 0.9530368084130323, 0.7036046874721953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 451}], {
             RGBColor[
             0.5845539363285509, 0.6419669596054878, 0.6749279868848965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 429}], {
             RGBColor[
             0.9886980169903079, 0.9895943538248468, 0.8369666372724359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 465}], {
             RGBColor[
             0.9825529801522501, 0.962612962572256, 0.6121803003934922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 469}], {
             RGBColor[
             0.8909554501219965, 0.9142093442458419, 0.9184966277463369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 488}], {
             RGBColor[
             0.6654718721039246, 0.7304975897758356, 0.8999774947786373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{425, 462}], {
             RGBColor[
             0.9078519820460712, 0.9280285990383925, 0.9441807033741495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 476}], {
             RGBColor[
             0.7596060220996594, 0.8067669185002998, 0.7117623728613767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 433}], {
             RGBColor[
             0.9598238876306797, 0.8674444859515633, 0.5044986220635804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 500}], {
             RGBColor[
             0.8372656333910511, 0.7734182703314936, 0.6173365684059438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 437}], {
             RGBColor[
             0.9374124791002427, 0.9520657313080212, 0.9638832569127391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 451}], {
             RGBColor[
             0.5740955288004095, 0.6409958825004766, 0.9352065563254405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{429, 488}], {
             RGBColor[
             0.6666716443400258, 0.7309937264282035, 0.8800941639154222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{430, 459}], {
             RGBColor[
             0.965246041798069, 0.8874512831027077, 0.44554267036424056`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{430, 477}], {
             RGBColor[
             0.923313215514131, 0.9376674318509806, 0.8046812015350726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 444}], {
             RGBColor[
             0.9135867251292843, 0.9299345124195535, 0.8055952356494586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 486}], {
             RGBColor[
             0.9931829946590358, 0.9906518317387973, 0.7046926990644424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{432, 460}], {
             RGBColor[
             0.947280675050169, 0.8273815676952241, 0.5417094405605571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 465}], {
             RGBColor[
             0.9857789536690571, 0.9639469855251935, 0.5587175706681585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 469}], {
             RGBColor[
             0.8941814236388035, 0.9155433671987794, 0.8650338980210032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 495}], {
             RGBColor[
             0.9590387362238897, 0.8683128715632094, 0.5233487808118442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{435, 439}], {
             RGBColor[
             0.9942700633406335, 0.9901525698081056, 0.6177099395771117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{435, 453}], {
             RGBColor[
             0.936466814506669, 0.7649604300986557, 0.4674999469257698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 473}], {
             RGBColor[
             0.9403251601786797, 0.8734079225718473, 0.6247565464523759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 439}], {
             RGBColor[
             0.9366688899711693, 0.9476793635134293, 0.7542755900477902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{439, 453}], {
             RGBColor[
             0.935570376726935, 0.7630430403315673, 0.3699282267744208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 445}], {
             RGBColor[
             0.9931628590901704, 0.9904952580638013, 0.6942503983694961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 471}], {
             RGBColor[
             0.9930307840063992, 0.9902127628144541, 0.6798748405739414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 450}], {
             RGBColor[
             0.9570797670329043, 0.964880507596638, 0.8312922079820069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 461}], {
             RGBColor[
             0.994944235170474, 0.9915945551829066, 0.691089382748997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 447}], {
             RGBColor[
             0.6146346784337546, 0.6390680659555743, 0.6197454952342922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 500}], {
             RGBColor[
             0.8546437495110948, 0.8409887038669747, 0.6382356861988805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{443, 451}], {
             RGBColor[
             0.5676714567317892, 0.5850183917308942, 0.6093427416402356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{444, 486}], {
             RGBColor[
             0.9124117814549337, 0.9302458186262716, 0.8830133444772337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{445, 471}], {
             RGBColor[
             0.994054019730727, 0.9896904743718753, 0.5941949259054055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 454}], {
             RGBColor[
             0.3235303862498307, 0.45095564853709613`, 0.9419712245030648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 500}], {
             RGBColor[
             0.5088246122312231, 0.6017931939268142, 0.9571102104051221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 455}], {
             RGBColor[
             0.9494574496160091, 0.9618159769459383, 0.9700910157506453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 475}], {
             RGBColor[
             0.9619136731832245, 0.9249290742384781, 0.6232295974191323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 478}], {
             RGBColor[
             0.9761924630161888, 0.9810028558396652, 0.8910556190868992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 482}], {
             RGBColor[
             0.9742546450504257, 0.9665580701445396, 0.6711719427262226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{449, 499}], {
             RGBColor[
             0.8238319873339786, 0.862873589662925, 0.9829241348839026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 461}], {
             RGBColor[
             0.9572697627254603, 0.9652868891715038, 0.8519720665992205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{452, 468}], {
             RGBColor[
             0.5861545599507506, 0.6484626753772896, 0.8464199649821045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 489}], {
             RGBColor[
             0.6856690248442068, 0.7448366514269464, 0.717448258112275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 500}], {
             RGBColor[
             0.5635394573271708, 0.6528762864484965, 0.9604614154676531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{455, 475}], {
             RGBColor[
             0.9477654087696776, 0.9143672695542242, 0.6468304007851062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{455, 482}], {
             RGBColor[
             0.9601063806368788, 0.9559962654602856, 0.6947727460921964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{457, 494}], {
             RGBColor[
             0.9643552880557272, 0.8846225842148072, 0.5042916445567188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{458, 461}], {
             RGBColor[
             0.9645459069727409, 0.9710886890886115, 0.8526660717330168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{459, 477}], {
             RGBColor[
             0.8942351908268651, 0.8348506378796215, 0.6266360232902171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{460, 463}], {
             RGBColor[
             0.9795458211162897, 0.9835491933485947, 0.8874127452003178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{463, 483}], {
             RGBColor[
             0.9813121879062383, 0.9842796314097944, 0.858139476280152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 481}], {
             RGBColor[
             0.9093790676005927, 0.9257940630220336, 0.7415286600985842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 496}], {
             RGBColor[
             0.8095247974438824, 0.8511713496663689, 0.9816375408392558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{465, 469}], {
             RGBColor[
             0.8860101855200402, 0.887724089645619, 0.6738269600041782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 470}], {
             RGBColor[
             0.9719330527059014, 0.9216600486642237, 0.5446141925342283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 491}], {
             RGBColor[
             0.9810631905602255, 0.9532126504787464, 0.5761535897058458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 483}], {
             RGBColor[
             0.9929802846746685, 0.9901918800430098, 0.6807117451888017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 497}], {
             RGBColor[
             0.9860723030093379, 0.9638050218731888, 0.4748594745773258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{472, 488}], {
             RGBColor[
             0.6648331845329154, 0.7302334760517014, 0.9105622007007093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{474, 490}], {
             RGBColor[
             0.9240399864352078, 0.821563221658327, 0.6211816756113631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{475, 478}], {
             RGBColor[
             0.9745004221698573, 0.933554148447951, 0.5677950041213602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{475, 482}], {
             RGBColor[
             0.9725626042040942, 0.9191093627528255, 0.3479113277606835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{478, 482}], {
             RGBColor[
             0.9868413940370585, 0.9751831443540124, 0.6157373494284505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{481, 496}], {
             RGBColor[
             0.8933327963767697, 0.913213435789713, 0.7399413013406793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{484, 490}], {
             RGBColor[
             0.9472547945782597, 0.9126448479886579, 0.6448467610728466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{489, 500}], {
             RGBColor[
             0.8709632508255991, 0.8956741968166645, 0.7325872440143323]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.028685633809430733`], {
             RGBColor[
             0.9930323041721079, 0.9875051281032778, 0.4829874926472346]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.028685633809430733`], {
             RGBColor[
             0.962625079060945, 0.9716464256762447, 0.9481501715959678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.028685633809430733`], {
             RGBColor[
             0.9897249849211437, 0.9900190314561195, 0.8199471209506751]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.028685633809430733`], {
             RGBColor[
             0.9909428241597575, 0.9811101605441541, 0.41931501147514333`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.028685633809430733`], {
             RGBColor[
             0.9908457591818861, 0.9807827375818533, 0.4189379323652959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.028685633809430733`], {
             RGBColor[
             0.9779855586267664, 0.9374022613907492, 0.36897848165375263`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.028685633809430733`], {
             RGBColor[
             0.7340149706734385, 0.7921373409012676, 0.9741234105829841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.028685633809430733`], {
             RGBColor[
             0.9422241198448946, 0.9564314236964193, 0.9826836741264096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.028685633809430733`], {
             RGBColor[
             0.9864231802939946, 0.9886536503902849, 0.8746665684190028]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.028685633809430733`], {
             RGBColor[
             0.9408772715893711, 0.9554269464727114, 0.9849635369087267]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.028685633809430733`], {
             RGBColor[
             0.9397808577033554, 0.9546092427917339, 0.9868194796272114]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.028685633809430733`], {
             RGBColor[
             0.9740986896342113, 0.9242909395986211, 0.3538787295912951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.028685633809430733`], {
             RGBColor[
             0.8937857575800151, 0.6105877567849725, 0.23308457138649294`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.028685633809430733`], {
             RGBColor[
             0.9936795749607948, 0.9888895748711639, 0.5534389235035393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.028685633809430733`], {
             RGBColor[
             0.9589027417389191, 0.8730314391695588, 0.2948453415320551]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.028685633809430733`], {
             RGBColor[
             0.3782452313457785, 0.5020387410587784, 0.9453224295655958]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.028685633809430733`], {
             RGBColor[
             0.989382932565279, 0.9898775840166248, 0.8256158136904755]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.028685633809430733`], {
             RGBColor[
             0.6845644967870121, 0.75350625486367, 0.9691946494869375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.028685633809430733`], {
             RGBColor[
             0.7889680163176606, 0.8350670778171496, 0.9796006166073912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.028685633809430733`], {
             RGBColor[
             0.9302491203317536, 0.9472194138855831, 0.9932091856120776]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.028685633809430733`], {
             RGBColor[
             0.9943190219409181, 0.9919187838251624, 0.7438120385463172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.028685633809430733`], {
             RGBColor[
             0.33541479209391883`, 0.4649411672992876, 0.9425933118499377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.028685633809430733`], {
             RGBColor[
             0.9713399861331887, 0.9781459891013735, 0.9333981071344537]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.028685633809430733`], {
             RGBColor[
             0.950342567771396, 0.8408318591115987, 0.2789026683003648]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.028685633809430733`], {
             RGBColor[
             0.9321503184163853, 0.9487353776316212, 0.9933905235826094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.028685633809430733`], {
             RGBColor[
             0.9595446238194555, 0.8751966581482882, 0.29733893220567953`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.028685633809430733`], {
             RGBColor[
             0.8001469568379302, 0.8438001511146791, 0.9807148289253129]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.028685633809430733`], {
             RGBColor[
             0.9941507241316956, 0.9918491883559925, 0.7466011687859025]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.028685633809430733`], {
             RGBColor[
             0.9414166080286024, 0.8054434031311815, 0.27172063157210957`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.028685633809430733`], {
             RGBColor[
             0.9891659956431693, 0.9897878750243079, 0.8292110199045908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.028685633809430733`], {
             RGBColor[
             0.9846071637473853, 0.9879026808787655, 0.9047626622964865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.028685633809430733`], {
             RGBColor[
             0.9077421660582328, 0.9292729794828762, 0.991062452221274]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.028685633809430733`], {
             RGBColor[
             0.9907889132660996, 0.9805909829598496, 0.4187170967169158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.028685633809430733`], {
             RGBColor[
             0.7624687706410692, 0.81436566569287, 0.9769594194478789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.028685633809430733`], {
             RGBColor[
             0.9712402540688452, 0.9146487652440536, 0.3427742471901105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.028685633809430733`], {
             RGBColor[
             0.9634215920812259, 0.888274582450677, 0.31240022179863414`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.028685633809430733`], {
             RGBColor[
             0.9910559117734639, 0.9905694039128139, 0.7978902186794475]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.028685633809430733`], {
             RGBColor[
             0.9936574143428533, 0.988842175550169, 0.5510268770000745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.028685633809430733`], {
             RGBColor[
             0.9932018291146577, 0.9878677248137911, 0.5014392364571132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.028685633809430733`], {
             RGBColor[
             0.9194052945878907, 0.9385728415852352, 0.9921748918322305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.028685633809430733`], {
             RGBColor[
             0.9947227554099102, 0.9911208323700993, 0.6669826776262632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.028685633809430733`], {
             RGBColor[
             0.9870984119351388, 0.9681420553995989, 0.4043801959388311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.028685633809430733`], {
             RGBColor[
             0.8933693242931432, 0.6086968304897522, 0.23273708924421305`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.028685633809430733`], {
             RGBColor[
             0.9136891869161964, 0.695513418035846, 0.24941049769884457`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.028685633809430733`], {
             RGBColor[
             0.9677696428286059, 0.9754832329107163, 0.9394417670544419]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.028685633809430733`], {
             RGBColor[
             0.9336914340009483, 0.7748156623731737, 0.26550477521631893`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.028685633809430733`], {
             RGBColor[
             0.9886526901720829, 0.9895756100206647, 0.8377178199524689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.028685633809430733`], {
             RGBColor[
             0.9864164052147566, 0.9886508487209084, 0.8747788490153189]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.028685633809430733`], {
             RGBColor[
             0.7268780284424557, 0.786561907387654, 0.9734120668799169]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.028685633809430733`], {
             RGBColor[
             0.440544052075756, 0.5559988483453105, 0.9492920553338258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.028685633809430733`], {
             RGBColor[
             0.9420930761121871, 0.9563336914951305, 0.9829054969842039]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.028685633809430733`], {
             RGBColor[
             0.9946235040344277, 0.9909085437137956, 0.6561797779134829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.028685633809430733`], {
             RGBColor[
             0.955374299637801, 0.9662388062545256, 0.9604238498532048]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.028685633809430733`], {
             RGBColor[
             0.9945543794978353, 0.9920161102233609, 0.7399115547423671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.028685633809430733`], {
             RGBColor[
             0.9877831516442132, 0.9892160334932698, 0.8521283236528453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.028685633809430733`], {
             RGBColor[
             0.9866938354720752, 0.988765573261942, 0.8701811116850582]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.028685633809430733`], {
             RGBColor[
             0.8537274895077558, 0.8862031425908621, 0.9859104841524184]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.028685633809430733`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.028685633809430733`], {
             RGBColor[
             0.9846917155529212, 0.9600237033831954, 0.3950306349603918]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.028685633809430733`], {
             RGBColor[
             0.7268780284424557, 0.786561907387654, 0.9734120668799169]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.028685633809430733`], {
             RGBColor[
             0.9401059463101712, 0.8002470661697285, 0.2706660423882752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.028685633809430733`], {
             RGBColor[
             0.9918430599404076, 0.9908949099086302, 0.7848451364790352]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.028685633809430733`], {
             RGBColor[
             0.9949120711744236, 0.9915257596476336, 0.68758853027208]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.028685633809430733`], {
             RGBColor[
             0.9757383883972767, 0.9298220285460188, 0.3602486496546748]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.028685633809430733`], {
             RGBColor[
             0.9927182799665696, 0.9912568358815769, 0.7703404756487089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.028685633809430733`], {
             RGBColor[
             0.9839423362943176, 0.9574958711813081, 0.39211943804911525`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.028685633809430733`], {
             RGBColor[
             0.9947227554099102, 0.9911208323700993, 0.6669826776262632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.028685633809430733`], {
             RGBColor[
             0.616508735769635, 0.6995485909566572, 0.9629529725071476]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.028685633809430733`], {
             RGBColor[
             0.9923569996986223, 0.9911074372063013, 0.7763278246519563]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.028685633809430733`], {
             RGBColor[
             0.8872614420235612, 0.9129422060720731, 0.9891089824794888]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.028685633809430733`], {
             RGBColor[
             0.9568443150782195, 0.9673351413630604, 0.957935497154007]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.028685633809430733`], {
             RGBColor[
             0.9938796820332528, 0.9893175836652229, 0.5752193434228853]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.028685633809430733`], {
             RGBColor[
             0.9464161758482188, 0.825265023528747, 0.27574340119471263`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.028685633809430733`], {
             RGBColor[
             0.7960879121140089, 0.8406291945264692, 0.980310261281162]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.028685633809430733`], {
             RGBColor[
             0.944635307894954, 0.8182044755331176, 0.2743104730371722]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.028685633809430733`], {
             RGBColor[
             0.9496183604823378, 0.8379606185382559, 0.2783199541162587]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.028685633809430733`], {
             RGBColor[
             0.994104541766689, 0.9897985358982367, 0.5996939377340077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.028685633809430733`], {
             RGBColor[
             0.993377862501342, 0.9882442424282031, 0.5205993842455547]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.028685633809430733`], {
             RGBColor[
             0.9398072580954265, 0.7990628669302131, 0.2704257108395781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.028685633809430733`], {
             RGBColor[
             0.888143414832467, 0.5849671961709855, 0.22837646229146202`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.028685633809430733`], {
             RGBColor[
             0.9832587618067594, 0.9870349924835186, 0.9132227288336531]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.028685633809430733`], {
             RGBColor[
             0.34344549945364256`, 0.47189696237919215`, 0.9431050214216236]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.028685633809430733`], {
             RGBColor[
             0.9291215420050808, 0.9463203135351925, 0.9931016361846785]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.028685633809430733`], {
             RGBColor[
             0.9809430479892333, 0.9473785674618751, 0.38046776935193355`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.028685633809430733`], {
             RGBColor[
             0.9263339400598308, 0.7456456506361578, 0.2595847628887165]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.028685633809430733`], {
             RGBColor[
             0.9934309299168415, 0.9883577482640179, 0.526375444928557]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.028685633809430733`], {
             RGBColor[
             0.993138660530557, 0.9877326135997232, 0.4945637259090585]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.028685633809430733`], {
             RGBColor[
             0.9950029276829506, 0.9917200925323707, 0.6974777005238729]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.028685633809430733`], {
             RGBColor[
             0.9947441445862711, 0.9911665816555579, 0.6693107574744576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.028685633809430733`], {
             RGBColor[
             0.9836194385842728, 0.9564066613853394, 0.3908650414197074]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.028685633809430733`], {
             RGBColor[
             0.791960566156752, 0.8374048804956691, 0.9798988860083836]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.028685633809430733`], {
             RGBColor[
             0.9946772863162893, 0.9920669353513528, 0.7378746706879341]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.028685633809430733`], {
             RGBColor[
             0.9258381006754607, 0.74367981270581, 0.259185798881206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.028685633809430733`], {
             RGBColor[
             0.9025238967092226, 0.6502656057264592, 0.24037588886729355`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.028685633809430733`], {
             RGBColor[
             0.9946692637029938, 0.9910064190178464, 0.6611604354409659]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.028685633809430733`], {
             RGBColor[
             0.9926268377535161, 0.9866378764328535, 0.4388549752322001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.028685633809430733`], {
             RGBColor[
             0.8369981875151284, 0.8728636512867465, 0.9843148283939375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.028685633809430733`], {
             RGBColor[
             0.9407816264223154, 0.8029259126573305, 0.2712097104667571]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.028685633809430733`], {
             RGBColor[
             0.9948487445209921, 0.9913903103392506, 0.6806958148528756]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.028685633809430733`], {
             RGBColor[
             0.9833140574043528, 0.9553765389585586, 0.38967869320211534`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.028685633809430733`], {
             RGBColor[
             0.9935070026215072, 0.9885204600871674, 0.5346554893650962]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.028685633809430733`], {
             RGBColor[
             0.9938012727313917, 0.9891498740969386, 0.5666849748014273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.028685633809430733`], {
             RGBColor[
             0.9613106686441588, 0.9706661405395551, 0.950375125578446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.028685633809430733`], {
             RGBColor[
             0.9372608953467156, 0.7889673871566595, 0.26837684760114966`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.028685633809430733`], {
             RGBColor[
             0.9597191798514574, 0.9694792108037822, 0.9530691009777342]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.028685633809430733`], {
             RGBColor[
             0.9387278032661578, 0.9538238765166903, 0.9886020261088027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.028685633809430733`], {
             RGBColor[
             0.9782262981445877, 0.9832817893241739, 0.9217413771369758]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.028685633809430733`], {
             RGBColor[
             0.9932108120263519, 0.9878869383535932, 0.5024169709589135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.028685633809430733`], {
             RGBColor[
             0.9313103214783182, 0.7653753446796563, 0.2635888761887163]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.028685633809430733`], {
             RGBColor[
             0.992603733031592, 0.9865884577689035, 0.4363401688365728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.028685633809430733`], {
             RGBColor[
             0.9889638140518142, 0.9897042677404527, 0.8325616921025303]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.028685633809430733`], {
             RGBColor[
             0.9947468126805705, 0.9911722884394787, 0.6696011630733826]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.028685633809430733`], {
             RGBColor[
             0.9860335136030577, 0.9884925131996053, 0.8811243539128963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.028685633809430733`], {
             RGBColor[
             0.9701813305931464, 0.9772818656967343, 0.9353594087379825]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.028685633809430733`], {
             RGBColor[
             0.9556965930616271, 0.9664791721623082, 0.9598782911542546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.028685633809430733`], {
             RGBColor[
             0.5554127176802968, 0.649948091127483, 0.9581432701610665]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.028685633809430733`], {
             RGBColor[
             0.8838362948408303, 0.910211086681707, 0.9887822888835349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.028685633809430733`], {
             RGBColor[
             0.9842421095250347, 0.9877517215763579, 0.9108125554908805]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.028685633809430733`], {
             RGBColor[
             0.9387951070022998, 0.9538740715329053, 0.9884880984391399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.028685633809430733`], {
             RGBColor[
             0.9637976359022573, 0.97252091664861, 0.9461653387154291]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.028685633809430733`], {
             RGBColor[
             0.4811640845856154, 0.5896697059184175, 0.9522981457821484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.028685633809430733`], {
             RGBColor[
             0.9727161783150146, 0.9196274042898758, 0.34850793418157167`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.028685633809430733`], {
             RGBColor[
             0.958125079121871, 0.8704082005583897, 0.2918242691140858]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.028685633809430733`], {
             RGBColor[
             0.9584083935813104, 0.8713638867554774, 0.29292489228956153`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.028685633809430733`], {
             RGBColor[
             0.8719791635786683, 0.9007565320665132, 0.9876513451187638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.028685633809430733`], {
             RGBColor[
             0.9752804793150632, 0.9810848024644501, 0.9267278800227603]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.028685633809430733`], {
             RGBColor[
             0.8369981875151284, 0.8728636512867465, 0.9843148283939375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.028685633809430733`], {
             RGBColor[
             0.9925708785099968, 0.9865181852693132, 0.43276415691554965`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.028685633809430733`], {
             RGBColor[
             0.6989527168457194, 0.7647464417280546, 0.9706287327968282]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.028685633809430733`], {
             RGBColor[
             0.989030483090933, 0.9897318371014445, 0.8314568135903888]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.028685633809430733`], {
             RGBColor[
             0.9797924050696706, 0.9844497893046359, 0.9190903666189144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.028685633809430733`], {
             RGBColor[
             0.8875382579469597, 0.582219320091879, 0.2278715045524422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.028685633809430733`], {
             RGBColor[
             0.8997887035831827, 0.6378457325616971, 0.2380935766772073]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.028685633809430733`], {
             RGBColor[
             0.9951356500713936, 0.9920039723009585, 0.7119237134382589]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.028685633809430733`], {
             RGBColor[
             0.9867128850630565, 0.988773450757365, 0.8698654106637361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.028685633809430733`], {
             RGBColor[
             0.9506476213999075, 0.96271365736393, 0.9684248831948361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.028685633809430733`], {
             RGBColor[
             0.8895200256686676, 0.5912180644625434, 0.22952514011700725`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.028685633809430733`], {
             RGBColor[
             0.9607806958098847, 0.9702708876675045, 0.9512722313478192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.028685633809430733`], {
             RGBColor[
             0.9197118754230731, 0.7193913710236404, 0.2542564942421464]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.028685633809430733`], {
             RGBColor[
             0.9541997133414978, 0.8561241559794854, 0.28200621816491167`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.028685633809430733`], {
             RGBColor[
             0.9008898379869488, 0.6428457267127249, 0.2390123902149838]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.028685633809430733`], {
             RGBColor[
             0.9107404276697004, 0.6838225702392586, 0.2470378567928385]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.028685633809430733`], {
             RGBColor[
             0.993801498875829, 0.9891503577970233, 0.5667095892278311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.028685633809430733`], {
             RGBColor[
             0.9952371025710501, 0.9922209689393026, 0.7229661919336189]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.028685633809430733`], {
             RGBColor[
             0.9606094903739957, 0.8787887030793093, 0.3014757376868928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.028685633809430733`], {
             RGBColor[
             0.8482515835368258, 0.3718883918085789, 0.19383907692822067`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.028685633809430733`], {
             RGBColor[
             0.9338370793733468, 0.9500803550327958, 0.9935514083484737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.028685633809430733`], {
             RGBColor[
             0.8612690101910601, 0.8922165464746034, 0.986629801127587]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.028685633809430733`], {
             RGBColor[
             0.9828800018801067, 0.9867525139503834, 0.9138638705930661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.028685633809430733`], {
             RGBColor[
             0.8648751342418585, 0.47931136845403466`, 0.20896083860890968`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.028685633809430733`], {
             RGBColor[
             0.9929335697939597, 0.987293945251996, 0.4722408649037633]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.028685633809430733`], {
             RGBColor[
             0.9929790867249203, 0.987391301364853, 0.47719510194088555`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.028685633809430733`], {
             RGBColor[
             0.8615646824931331, 0.8924523075424656, 0.9866580026157085]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.028685633809430733`], {
             RGBColor[
             0.9908836612403454, 0.9904981738907326, 0.8007448557833103]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.028685633809430733`], {
             RGBColor[
             0.9307701392399009, 0.7632337021093925, 0.2631542328799791]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.028685633809430733`], {
             RGBColor[
             0.9931025554365466, 0.9876553884544198, 0.4906339092408367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.028685633809430733`], {
             RGBColor[
             0.9915199929303472, 0.983057086333025, 0.42155720315970746`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.028685633809430733`], {
             RGBColor[
             0.9941302508892002, 0.9898535251116969, 0.6024922170610222]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.028685633809430733`], {
             RGBColor[
             0.6894168488005354, 0.7572969491358756, 0.9696782865878377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.028685633809430733`], {
             RGBColor[
             0.9943760147374892, 0.9919423518111926, 0.742867520414505]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.028685633809430733`], {
             RGBColor[
             0.9586729190454557, 0.968698911207761, 0.9548401476137736]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.028685633809430733`], {
             RGBColor[
             0.9774522137125331, 0.9356031637596989, 0.36690653737569173`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.028685633809430733`], {
             RGBColor[
             0.8898538063293907, 0.915009287001687, 0.9893562445012097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.028685633809430733`], {
             RGBColor[
             0.8773124106070478, 0.9050091184798089, 0.9881600349813765]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.028685633809430733`], {
             RGBColor[
             0.7490562682785202, 0.8038877169084533, 0.9756225865593409]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.028685633809430733`], {
             RGBColor[
             0.8892966184827042, 0.9145650005372005, 0.9893030994269854]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.028685633809430733`], {
             RGBColor[
             0.9358931601098016, 0.7835447727130442, 0.2672763357246563]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.028685633809430733`], {
             RGBColor[
             0.986679918786717, 0.988759818354904, 0.8704117471766695]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.028685633809430733`], {
             RGBColor[
             0.9420521974105385, 0.8079633032329522, 0.2722320417080156]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.028685633809430733`], {
             RGBColor[
             0.9922920766338988, 0.9910805898505916, 0.7774037678499311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.028685633809430733`], {
             RGBColor[
             0.9239761682722836, 0.9422175321881092, 0.9926108658447149]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.028685633809430733`], {
             RGBColor[
             0.9847601484808517, 0.9879659439975822, 0.9022273093511506]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.028685633809430733`], {
             RGBColor[
             0.26881554115388295`, 0.3998725560154139, 0.9386200194405339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.028685633809430733`], {
             RGBColor[
             0.921002724663455, 0.939846588966406, 0.9923272561388804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.028685633809430733`], {
             RGBColor[
             0.8838362948408303, 0.910211086681707, 0.9887822888835349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.028685633809430733`], {
             RGBColor[
             0.9947272030347556, 0.9920875771972398, 0.737047421482621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.028685633809430733`], {
             RGBColor[
             0.45605454684814134`, 0.5692846520113517, 0.9503214309921871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.028685633809430733`], {
             RGBColor[
             0.9911547508751576, 0.9906102764214133, 0.7962521989769864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.028685633809430733`], {
             RGBColor[
             0.801274469261242, 0.844680972389182, 0.980827208826466]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.028685633809430733`], {
             RGBColor[
             0.9886384646362497, 0.9895697273960181, 0.8379535738957321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.028685633809430733`], {
             RGBColor[
             0.9786635247023259, 0.9836078721750421, 0.9210012666216748]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.028685633809430733`], {
             RGBColor[
             0.995147817896564, 0.9922615122519065, 0.7300767447060861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.028685633809430733`], {
             RGBColor[
             0.7784434932120639, 0.8268452403777193, 0.9785516305014856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.028685633809430733`], {
             RGBColor[
             0.9936339824511271, 0.9887920571030946, 0.5484764601905654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.028685633809430733`], {
             RGBColor[
             0.9894954845732064, 0.9899241271643575, 0.8237505356438588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.028685633809430733`], {
             RGBColor[
             0.9930388997409973, 0.9875192353582182, 0.4837053796177239]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.028685633809430733`], {
             RGBColor[
             0.946063531781599, 0.9592948508323533, 0.9761845511965781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.028685633809430733`], {
             RGBColor[
             0.9930408319838904, 0.9875233682303866, 0.4839156923322034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.028685633809430733`], {
             RGBColor[
             0.9813143594998083, 0.9855848604266609, 0.9165140947579802]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.028685633809430733`], {
             RGBColor[
             0.9664014644516566, 0.8983263916634453, 0.32397646325607843`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.028685633809430733`], {
             RGBColor[
             0.9446954337171486, 0.9582745255359413, 0.9785003843625706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.028685633809430733`], {
             RGBColor[
             0.9943736487650573, 0.9903741285568551, 0.6289845737705014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.028685633809430733`], {
             RGBColor[
             0.8500307693411151, 0.8832554782747786, 0.9855578876828232]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.028685633809430733`], {
             RGBColor[
             0.9898645340887297, 0.9774728349400282, 0.41512605816719356`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.028685633809430733`], {
             RGBColor[
             0.957227141464413, 0.9676206526550628, 0.9572874719392941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.028685633809430733`], {
             RGBColor[
             0.9686040366471959, 0.9057561848675444, 0.3325330403148906]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.028685633809430733`], {
             RGBColor[
             0.45372178979382105`, 0.5673908147451469, 0.9501377878117003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.028685633809430733`], {
             RGBColor[
             0.9868194503906978, 0.9672010526069138, 0.4032964830161451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.028685633809430733`], {
             RGBColor[
             0.6519871883115749, 0.7280566138859438, 0.9659476478303624]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.028685633809430733`], {
             RGBColor[
             0.9493031033182059, 0.8367107289356951, 0.2780662908019614]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.028685633809430733`], {
             RGBColor[
             0.9930955890146421, 0.9876404879823795, 0.4898756572083064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.028685633809430733`], {
             RGBColor[
             0.9948351985099385, 0.9913613367913187, 0.6792214151459787]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.028685633809430733`], {
             RGBColor[
             0.9316273591101696, 0.7666322932434195, 0.2638439721091337]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.028685633809430733`], {
             RGBColor[
             0.9941870464965482, 0.9899750051728976, 0.6086740684190005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.028685633809430733`], {
             RGBColor[
             0.6519871883115749, 0.7280566138859438, 0.9659476478303624]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.028685633809430733`], {
             RGBColor[
             0.9599624921359178, 0.9696606727071454, 0.9526572367461499]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.028685633809430733`], {
             RGBColor[
             0.8337332964158648, 0.8702603157473016, 0.984003420166287]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.028685633809430733`], {
             RGBColor[
             0.9483634888375365, 0.8329854706278054, 0.27731025493522826`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.028685633809430733`], {
             RGBColor[
             0.9745925504344124, 0.9259568480417296, 0.35579728554228984`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.028685633809430733`], {
             RGBColor[
             0.7268780284424557, 0.786561907387654, 0.9734120668799169]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.028685633809430733`], {
             RGBColor[
             0.9929592834279797, 0.9913564970063765, 0.7663464245961771]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.028685633809430733`], {
             RGBColor[
             0.9047446778248507, 0.9268828637302279, 0.9907765491176846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.028685633809430733`], {
             RGBColor[
             0.9938370537627471, 0.9917194775974715, 0.7517994985522722]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.028685633809430733`], {
             RGBColor[
             0.9944884278580229, 0.9906196294307623, 0.6414775697053667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.028685633809430733`], {
             RGBColor[
             0.6262162141993853, 0.7074295592628481, 0.9637171807688028]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.028685633809430733`], {
             RGBColor[
             0.6479441051504812, 0.7248981265919272, 0.9655446710856248]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.028685633809430733`], {
             RGBColor[
             0.9506911851980016, 0.9627461471732193, 0.9683511410479212]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.028685633809430733`], {
             RGBColor[
             0.993801498875829, 0.9891503577970233, 0.5667095892278311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.028685633809430733`], {
             RGBColor[
             0.9919681833116432, 0.9909466516381601, 0.7827715184087559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.028685633809430733`], {
             RGBColor[
             0.9402999162382355, 0.8010160922978569, 0.2708221151454552]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.028685633809430733`], {
             RGBColor[
             0.962402523043788, 0.9714804437630512, 0.9485269008811088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.028685633809430733`], {
             RGBColor[
             0.9950223973595571, 0.9922096476366933, 0.732155287582237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.028685633809430733`], {
             RGBColor[
             0.9908305204923195, 0.9904761988257689, 0.8016255355019477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.028685633809430733`], {
             RGBColor[
             0.8892591013965861, 0.9145350854311041, 0.9892995210138195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.028685633809430733`], {
             RGBColor[
             0.9477075370974599, 0.8303848405613612, 0.2767824607679964]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.028685633809430733`], {
             RGBColor[
             0.8720265171591127, 0.5117841280333708, 0.2149281278115027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.028685633809430733`], {
             RGBColor[
             0.958880186901216, 0.968853491235217, 0.9544892971980858]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.028685633809430733`], {
             RGBColor[
             0.968801868875665, 0.906423519427387, 0.33330158116501163`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.028685633809430733`], {
             RGBColor[
             0.9699211541002775, 0.9101991313106733, 0.3376497929033522]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.028685633809430733`], {
             RGBColor[
             0.9933460631733649, 0.9881762268810655, 0.5171382236379638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.028685633809430733`], {
             RGBColor[
             0.9621707841401991, 0.9713076132681921, 0.948919174397699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.028685633809430733`], {
             RGBColor[
             0.9934674192371222, 0.9915666242219515, 0.7579252992253651]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.028685633809430733`], {
             RGBColor[
             0.9865940507468588, 0.9664407266818915, 0.40242084796298155`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.028685633809430733`], {
             RGBColor[
             0.984715702904542, 0.9879475646095789, 0.9029638875720654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.028685633809430733`], {
             RGBColor[
             0.9938393329247301, 0.9892312810020136, 0.5708275919660262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.028685633809430733`], {
             RGBColor[
             0.9943242174140519, 0.9902683998953309, 0.6236042762685057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.028685633809430733`], {
             RGBColor[
             0.891521828272235, 0.6003077825524666, 0.23119549327809583`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.028685633809430733`], {
             RGBColor[
             0.9541800628559253, 0.8560462483523263, 0.2819904069229638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.028685633809430733`], {
             RGBColor[
             0.9849325835113094, 0.9880372503140545, 0.8993696146489125]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.028685633809430733`], {
             RGBColor[
             0.9938393329247301, 0.9892312810020136, 0.5708275919660262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.028685633809430733`], {
             RGBColor[
             0.8546204457168776, 0.8869151616333653, 0.9859956551127959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.028685633809430733`], {
             RGBColor[
             0.9916866081308287, 0.9908302130647413, 0.7874379478480613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.028685633809430733`], {
             RGBColor[
             0.96875547021137, 0.9062670058377953, 0.33312133111587783`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.028685633809430733`], {
             RGBColor[
             0.9830672157747038, 0.9868921377664392, 0.913546966302717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.028685633809430733`], {
             RGBColor[
             0.9938875874978437, 0.9893344926546178, 0.5760798044567357]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.028685633809430733`], {
             RGBColor[
             0.9943250414415744, 0.9902701624068795, 0.6236939665790201]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.028685633809430733`], {
             RGBColor[
             0.8546204457168776, 0.8869151616333653, 0.9859956551127959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.028685633809430733`], {
             RGBColor[
             0.6478341944190893, 0.7248122634932114, 0.9655337162110939]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.028685633809430733`], {
             RGBColor[
             0.9538976338108968, 0.9651375112986388, 0.9629234599220243]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.028685633809430733`], {
             RGBColor[
             0.9608054898606109, 0.9702893790299395, 0.9512302614872639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.028685633809430733`], {
             RGBColor[
             0.9475024347860473, 0.9603679823370835, 0.9737488637360548]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.028685633809430733`], {
             RGBColor[
             0.9051527892122586, 0.9272082806726585, 0.9908154751461409]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.028685633809430733`], {
             RGBColor[
             0.9908258310907986, 0.9807155154512766, 0.4188605154945249]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.028685633809430733`], {
             RGBColor[
             0.9386531491332455, 0.7944872094791786, 0.26949708767818814`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.028685633809430733`], {
             RGBColor[
             0.9923026371310454, 0.991084956887554, 0.7772287530825219]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.028685633809430733`], {
             RGBColor[
             0.9362541573149386, 0.7849760063362248, 0.26756680254960297`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.028685633809430733`], {
             RGBColor[
             0.9931660104563343, 0.9877911123254594, 0.4975405965457522]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.028685633809430733`], {
             RGBColor[
             0.9162693744792052, 0.70574300192664, 0.2514865771768276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.028685633809430733`], {
             RGBColor[
             0.9888166697174864, 0.9739381423655701, 0.41105530295749587`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.028685633809430733`], {
             RGBColor[
             0.9513527580212203, 0.9632395471015498, 0.9672312708240386]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.028685633809430733`], {
             RGBColor[
             0.969271177162893, 0.9766030747586907, 0.9369000610893689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.028685633809430733`], {
             RGBColor[
             0.9950974264968502, 0.9919222159400064, 0.7077633132377711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.028685633809430733`], {
             RGBColor[
             0.9901808726571018, 0.9785399192109755, 0.4163549737697932]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.028685633809430733`], {
             RGBColor[
             0.8872819741620896, 0.9129585778420056, 0.9891109408531908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.028685633809430733`], {
             RGBColor[
             0.9934294411202225, 0.9883545638785901, 0.5262133986043577]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.028685633809430733`], {
             RGBColor[
             0.8378144102899445, 0.8735144851716078, 0.98439268045085]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.028685633809430733`], {
             RGBColor[
             0.9950974264968502, 0.9919222159400064, 0.7077633132377711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.028685633809430733`], {
             RGBColor[
             0.9933479415117518, 0.9881802444569457, 0.5173426691796064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.028685633809430733`], {
             RGBColor[
             0.9863907375203431, 0.9886402344696388, 0.8752042291376131]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.028685633809430733`], {
             RGBColor[
             0.8551673064825311, 0.8873512135637573, 0.9860478151808123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.028685633809430733`], {
             RGBColor[
             0.993762197682613, 0.9890662965186944, 0.5624318968851143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.028685633809430733`], {
             RGBColor[
             0.8809419682690243, 0.5522671092669695, 0.2223673987553172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.028685633809430733`], {
             RGBColor[
             0.9935268401748779, 0.9885628906079433, 0.5368146846263252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.028685633809430733`], {
             RGBColor[
             0.9943305355189539, 0.9902819136828579, 0.624291962996268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.028685633809430733`], {
             RGBColor[
             0.9528608742200749, 0.8508161050047334, 0.28092895678122154`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.028685633809430733`], {
             RGBColor[
             0.8252405321721189, 0.8634884160692828, 0.9831933727311384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.028685633809430733`], {
             RGBColor[
             0.9924024690307376, 0.9911262399436396, 0.7755742801479465]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.028685633809430733`], {
             RGBColor[
             0.9820798519034855, 0.9512132739989001, 0.3848840378913974]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.028685633809430733`], {
             RGBColor[
             0.866625882352633, 0.8964879709278204, 0.987140744376494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.028685633809430733`], {
             RGBColor[
             0.9875501511182875, 0.9696658777377635, 0.406135117361577]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.028685633809430733`], {
             RGBColor[
             0.9809175037675578, 0.9852888860713402, 0.9171858679961281]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.028685633809430733`], {
             RGBColor[
             0.9925451329577042, 0.9864631181362338, 0.4299619124316255]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.028685633809430733`], {
             RGBColor[
             0.994299450442836, 0.9902154258482249, 0.6209085442956781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.028685633809430733`], {
             RGBColor[
             0.9926333953406552, 0.9866519024486703, 0.43956872812355646`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.028685633809430733`], {
             RGBColor[
             0.9757722789019458, 0.9299363491761369, 0.3603803078656298]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.028685633809430733`], {
             RGBColor[
             0.9692225348462337, 0.9078425245231819, 0.3349357890245679]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.028685633809430733`], {
             RGBColor[
             0.9729429827826966, 0.9203924690155889, 0.3493890267100867]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.028685633809430733`], {
             RGBColor[
             0.9748834282361416, 0.9807886824199018, 0.9273999839318681]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.028685633809430733`], {
             RGBColor[
             0.9782983703441341, 0.9384574487651146, 0.37019369610619013`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.028685633809430733`], {
             RGBColor[
             0.7791098287023053, 0.8273657867270332, 0.9786180445958936]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.028685633809430733`], {
             RGBColor[
             0.9701813305931464, 0.9772818656967343, 0.9353594087379825]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.028685633809430733`], {
             RGBColor[
             0.9907049395694967, 0.9904242678868992, 0.8037067363861324]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.028685633809430733`], {
             RGBColor[
             0.995047173055266, 0.99181472890986, 0.7022935362496173]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.028685633809430733`], {
             RGBColor[
             0.988549433096601, 0.9895329105663673, 0.8394290569139491]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.028685633809430733`], {
             RGBColor[
             0.9440046136673089, 0.9577593130738848, 0.9796697625122239]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.028685633809430733`], {
             RGBColor[
             0.7944126554897866, 0.8393204713192048, 0.9801432873570228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.028685633809430733`], {
             RGBColor[
             0.995252319612632, 0.9922535166525676, 0.7246224730011223]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.028685633809430733`], {
             RGBColor[
             0.9922594161614613, 0.9910670839059028, 0.7779450364008138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.028685633809430733`], {
             RGBColor[
             0.9943245325383767, 0.9902690739143976, 0.6236385756065336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.028685633809430733`], {
             RGBColor[
             0.8443686791717164, 0.8787406812670434, 0.9850178324678583]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.028685633809430733`], {
             RGBColor[
             0.9077751520026275, 0.929299281579557, 0.9910655984500972]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.028685633809430733`], {
             RGBColor[
             0.9916474951784339, 0.990814038853769, 0.7880861506903181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.028685633809430733`], {
             RGBColor[
             0.8775845276687803, 0.537021755651436, 0.2195658680200736]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.028685633809430733`], {
             RGBColor[
             0.9068072037774798, 0.6682286481757681, 0.243873092524527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.028685633809430733`], {
             RGBColor[
             0.9826506914825781, 0.9531388499386866, 0.387101641862163]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.028685633809430733`], {
             RGBColor[
             0.9714892141896289, 0.9154885661900731, 0.3437414102471812]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.028685633809430733`], {
             RGBColor[
             0.8264706083001584, 0.8644692453842545, 0.9833106984903327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.028685633809430733`], {
             RGBColor[
             0.7032683281720882, 0.7681178300960748, 0.9710588726021598]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.028685633809430733`], {
             RGBColor[
             0.9948487445209921, 0.9913903103392506, 0.6806958148528756]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.028685633809430733`], {
             RGBColor[
             0.9832836586577769, 0.9552739968483925, 0.3895605998119891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.028685633809430733`], {
             RGBColor[
             0.9286959559599504, 0.945980962775031, 0.9930610434077688]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.028685633809430733`], {
             RGBColor[
             0.9918430599404076, 0.9908949099086302, 0.7848451364790352]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.028685633809430733`], {
             RGBColor[
             0.982229546287517, 0.9517182283061514, 0.38546557230594763`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.028685633809430733`], {
             RGBColor[
             0.993801498875829, 0.9891503577970233, 0.5667095892278311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.028685633809430733`], {
             RGBColor[
             0.9944575893549957, 0.9905536689910381, 0.6381209889640348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.028685633809430733`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.028685633809430733`], {
             RGBColor[
             0.7268780284424557, 0.786561907387654, 0.9734120668799169]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.028685633809430733`], {
             RGBColor[
             0.6844641822061658, 0.7534278883506937, 0.9691846510670117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.028685633809430733`], {
             RGBColor[
             0.9686937475644536, 0.9761724287096288, 0.9378774987817676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.028685633809430733`], {
             RGBColor[
             0.9849842126084705, 0.988058600272538, 0.8985139868971337]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.028685633809430733`], {
             RGBColor[
             0.9920762890269093, 0.9909913561296129, 0.7809799269381729]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.028685633809430733`], {
             RGBColor[
             0.994025680153318, 0.9896298588813683, 0.5911103377960397]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.028685633809430733`], {
             RGBColor[
             0.8875705053360329, 0.5823657479540907, 0.22789841256434062`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.028685633809430733`], {
             RGBColor[
             0.8501597797590354, 0.8833583476801338, 0.9855701928116534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.028685633809430733`], {
             RGBColor[
             0.9950557791548401, 0.991833136486639, 0.7032302570775699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.028685633809430733`], {
             RGBColor[
             0.9934484308730169, 0.9883951810396591, 0.5282803160048672]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.028685633809430733`], {
             RGBColor[
             0.957975689525654, 0.9681789185735015, 0.956020375324215]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.028685633809430733`], {
             RGBColor[
             0.9935028599062253, 0.9885115992380725, 0.5342045803725497]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.028685633809430733`], {
             RGBColor[
             0.9195775071685988, 0.938710159222506, 0.9921913176219144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.028685633809430733`], {
             RGBColor[
             0.9817371981198117, 0.9500574223276341, 0.38355289264656234`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.028685633809430733`], {
             RGBColor[
             0.9929089619159975, 0.9872413114892729, 0.4695624492497953]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.028685633809430733`], {
             RGBColor[
             0.9043153841855012, 0.9265405566350761, 0.9907356027071285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.028685633809430733`], {
             RGBColor[
             0.9358931601098016, 0.7835447727130442, 0.2672763357246563]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.028685633809430733`], {
             RGBColor[
             0.9808930762288146, 0.9472100009800555, 0.380273638499082]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.028685633809430733`], {
             RGBColor[
             0.9087604938769451, 0.9300849664437453, 0.9911595812376947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.028685633809430733`], {
             RGBColor[
             0.9944277869452927, 0.990489924650169, 0.6348771805870094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.028685633809430733`], {
             RGBColor[
             0.9915824688236856, 0.9907871487849795, 0.7891638056713084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.028685633809430733`], {
             RGBColor[
             0.9624932325478874, 0.8851430077555419, 0.30879372031760155`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.028685633809430733`], {
             RGBColor[
             0.9534115552814075, 0.8529993719093318, 0.2813720476893156]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.028685633809430733`], {
             RGBColor[
             0.9828970435232856, 0.9539698532182026, 0.38805867302063213`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.028685633809430733`], {
             RGBColor[
             0.9593287345271351, 0.9691880173201982, 0.9537300230673619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.028685633809430733`], {
             RGBColor[
             0.7268780284424557, 0.786561907387654, 0.9734120668799169]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.028685633809430733`], {
             RGBColor[
             0.9849842126084705, 0.988058600272538, 0.8985139868971337]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.028685633809430733`], {
             RGBColor[
             0.9945908033654924, 0.990838600289488, 0.6526205119050205]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.028685633809430733`], {
             RGBColor[
             0.9941149824929478, 0.991834408269852, 0.7471935002363499]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.028685633809430733`], {
             RGBColor[
             0.9783890181826642, 0.9834031456621417, 0.9214659345566951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.028685633809430733`], {
             RGBColor[
             0.7032683281720882, 0.7681178300960748, 0.9710588726021598]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.028685633809430733`], {
             RGBColor[
             0.9869002257697794, 0.9888509209540315, 0.8667606903311295]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.028685633809430733`], {
             RGBColor[
             0.9883443792067684, 0.9894481155132768, 0.8428273305309312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.028685633809430733`], {
             RGBColor[
             0.9380319404993059, 0.7920243242511138, 0.2689972486296796]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.028685633809430733`], {
             RGBColor[
             0.9365662821825401, 0.9522118176316942, 0.9922609174883799]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.028685633809430733`], {
             RGBColor[
             0.9934309299168415, 0.9883577482640179, 0.526375444928557]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.028685633809430733`], {
             RGBColor[
             0.9068266681425484, 0.66830581789715, 0.24388875400954857`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.028685633809430733`], {
             RGBColor[
             0.9550904611682056, 0.9660271199886443, 0.9609043143453008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.028685633809430733`], {
             RGBColor[
             0.7268780284424557, 0.786561907387654, 0.9734120668799169]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.028685633809430733`], {
             RGBColor[
             0.7883478212060807, 0.834582576682326, 0.9795388013547217]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.028685633809430733`], {
             RGBColor[
             0.9928118206537431, 0.9870335361517989, 0.4589892223397802]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.028685633809430733`], {
             RGBColor[
             0.9888675663305452, 0.9896644668342544, 0.8341567659250769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.028685633809430733`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.028685633809430733`], {
             RGBColor[
             0.9930574820939376, 0.9875589811321932, 0.48572795405827834`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.028685633809430733`], {
             RGBColor[
             0.9817629673491688, 0.9501443479891583, 0.3836530012365039]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.028685633809430733`], {
             RGBColor[
             0.8479225674834141, 0.8815744553390628, 0.9853568055076216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.028685633809430733`], {
             RGBColor[
             0.8100840557365593, 0.8515630882990369, 0.9817052660760593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.028685633809430733`], {
             RGBColor[
             0.9875420436766597, 0.9891163291524943, 0.8561241066426261]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.028685633809430733`], {
             RGBColor[
             0.9756274346046538, 0.9813435611513397, 0.9261405752179155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.028685633809430733`], {
             RGBColor[
             0.8612690101910601, 0.8922165464746034, 0.986629801127587]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.028685633809430733`], {
             RGBColor[
             0.9938367665082091, 0.9892257916965796, 0.570548253365802]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.028685633809430733`], {
             RGBColor[
             0.9898580776063758, 0.9900740687017889, 0.8177414307235527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.028685633809430733`], {
             RGBColor[
             0.9774385014553887, 0.9826942518432679, 0.9230749114415062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.028685633809430733`], {
             RGBColor[
             0.9162693744792052, 0.70574300192664, 0.2514865771768276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.028685633809430733`], {
             RGBColor[
             0.7889680163176606, 0.8350670778171496, 0.9796006166073912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.028685633809430733`], {
             RGBColor[
             0.9525952789833002, 0.9641662172006277, 0.9651280069366056]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.028685633809430733`], {
             RGBColor[
             0.9902404434151026, 0.9787408653655918, 0.4165863949156331]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.028685633809430733`], {
             RGBColor[
             0.8701137677784173, 0.5030987798296008, 0.2133320828424728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.028685633809430733`], {
             RGBColor[
             0.9551828577478652, 0.9660960292064689, 0.9607479110368246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.028685633809430733`], {
             RGBColor[
             0.9644844977431373, 0.8918600128304217, 0.31652940958226805`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.028685633809430733`], {
             RGBColor[
             0.963333986367436, 0.8879790678072637, 0.312059890143511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.028685633809430733`], {
             RGBColor[
             0.992257980762897, 0.9855464925799985, 0.42442414653185484`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.028685633809430733`], {
             RGBColor[
             0.978889979203536, 0.9837767615712596, 0.920617938219919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.028685633809430733`], {
             RGBColor[
             0.9949432268889462, 0.9915923985706716, 0.6909796375270891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.028685633809430733`], {
             RGBColor[
             0.9407146920399488, 0.9553056949109519, 0.985238741678361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.028685633809430733`], {
             RGBColor[
             0.9923779373869958, 0.9911160954785178, 0.7759808329706093]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.028685633809430733`], {
             RGBColor[
             0.9950296399084713, 0.9917772272817392, 0.7003851614230548]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.028685633809430733`], {
             RGBColor[
             0.9550904611682056, 0.9660271199886443, 0.9609043143453008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.028685633809430733`], {
             RGBColor[
             0.9852857387557954, 0.9881832890833254, 0.8935169183113029]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.028685633809430733`], {
             RGBColor[
             0.9876384175579757, 0.9891561822291143, 0.8545269420216086]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.028685633809430733`], {
             RGBColor[
             0.9262320126990878, 0.7452415426160914, 0.25950274974172005`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.028685633809430733`], {
             RGBColor[
             0.9945623613680514, 0.9907777657328888, 0.6495247760072306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.028685633809430733`], {
             RGBColor[
             0.9913049193719978, 0.9823315927190396, 0.4207216829987536]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.028685633809430733`], {
             RGBColor[
             0.9899265252730665, 0.9901023735709904, 0.8166070757496033]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.028685633809430733`], {
             RGBColor[
             0.8232573131985991, 0.861907051092843, 0.9830042115350036]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.028685633809430733`], {
             RGBColor[
             0.8479225674834141, 0.8815744553390628, 0.9853568055076216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.028685633809430733`], {
             RGBColor[
             0.957593477476069, 0.8686149833810978, 0.28975909710469266`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.028685633809430733`], {
             RGBColor[
             0.9949107599111838, 0.9921634826828394, 0.7340054090102366]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.028685633809430733`], {
             RGBColor[
             0.5702624442992332, 0.6620037681692963, 0.9593122950368501]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.028685633809430733`], {
             RGBColor[
             0.8351698484995409, 0.8714057833846575, 0.9841404397864532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.028685633809430733`], {
             RGBColor[
             0.9938683418449671, 0.9892933281491487, 0.5739850339115172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.028685633809430733`], {
             RGBColor[
             0.9169783312655625, 0.7085537793387028, 0.2520570204484853]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.028685633809430733`], {
             RGBColor[
             0.9682737932892885, 0.9046421964764947, 0.33125010723064546`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.028685633809430733`], {
             RGBColor[
             0.9938551791264212, 0.9892651744251341, 0.5725523532286797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[401, 0.028685633809430733`], {
             RGBColor[
             0.9843352518235933, 0.9588212675225083, 0.3936458406844794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[402, 0.028685633809430733`], {
             RGBColor[
             0.8455685266506958, 0.8796974070777893, 0.9851322749915199]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[403, 0.028685633809430733`], {
             RGBColor[
             0.9916866081308287, 0.9908302130647413, 0.7874379478480613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[404, 0.028685633809430733`], {
             RGBColor[
             0.9580395109467, 0.8701195590111754, 0.291491852911741]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[405, 0.028685633809430733`], {
             RGBColor[
             0.9860277254758535, 0.9884901196602583, 0.8812202781598628]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[406, 0.028685633809430733`], {
             RGBColor[
             0.9922692682874446, 0.9910711580131849, 0.7777817611767874]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[407, 0.028685633809430733`], {
             RGBColor[
             0.9906637123314976, 0.9904072193644949, 0.804389978412448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[408, 0.028685633809430733`], {
             RGBColor[
             0.7340149706734385, 0.7921373409012676, 0.9741234105829841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[409, 0.028685633809430733`], {
             RGBColor[
             0.9262320126990878, 0.7452415426160914, 0.25950274974172005`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[410, 0.028685633809430733`], {
             RGBColor[
             0.9506399290628401, 0.9627079204315402, 0.9684379043150084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[411, 0.028685633809430733`], {
             RGBColor[
             0.9415400064452636, 0.9559212130431074, 0.983841699666634]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[412, 0.028685633809430733`], {
             RGBColor[
             0.9584153433705985, 0.968506811691194, 0.9552761560448114]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[413, 0.028685633809430733`], {
             RGBColor[
             0.4689130601249929, 0.5797237723589216, 0.9513337002596269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[414, 0.028685633809430733`], {
             RGBColor[
             0.9940333852745115, 0.9918006657230757, 0.7485457773126719]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[415, 0.028685633809430733`], {
             RGBColor[
             0.9861101024109237, 0.9885241846399004, 0.8798550791610755]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[416, 0.028685633809430733`], {
             RGBColor[
             0.9930160196785822, 0.9874702972182414, 0.4812150260232161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[417, 0.028685633809430733`], {
             RGBColor[
             0.9459068930273399, 0.8232458868524015, 0.2753336202826292]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[418, 0.028685633809430733`], {
             RGBColor[
             0.9850775528818166, 0.9613252232924727, 0.3965295401238847]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[419, 0.028685633809430733`], {
             RGBColor[
             0.9951326626769927, 0.9919975825664068, 0.711598553993782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[420, 0.028685633809430733`], {
             RGBColor[
             0.9940302906202675, 0.9896397202039835, 0.5916121586709812]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[421, 0.028685633809430733`], {
             RGBColor[
             0.9731221037874442, 0.9209966862242144, 0.35008487798936744`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[422, 0.028685633809430733`], {
             RGBColor[
             0.9901808726571018, 0.9785399192109755, 0.4163549737697932]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[423, 0.028685633809430733`], {
             RGBColor[
             0.9874982447542066, 0.9890982171724789, 0.8568499681356511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[424, 0.028685633809430733`], {
             RGBColor[
             0.9794819431686124, 0.9424499178181945, 0.37479165303031464`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[425, 0.028685633809430733`], {
             RGBColor[
             0.9846163552911982, 0.9879064818183441, 0.9046103346285563]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[426, 0.028685633809430733`], {
             RGBColor[
             0.5263204532641764, 0.6263296802828999, 0.9558530205377536]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[427, 0.028685633809430733`], {
             RGBColor[
             0.925697583473539, 0.7431227088247726, 0.2590727354421773]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[428, 0.028685633809430733`], {
             RGBColor[
             0.9692640576008189, 0.9765977650009532, 0.9369121126508809]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[429, 0.028685633809430733`], {
             RGBColor[
             0.9898977892264091, 0.9900904904772149, 0.8170833064092208]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[430, 0.028685633809430733`], {
             RGBColor[
             0.994324066485335, 0.9902680770740667, 0.6235878486090961]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[431, 0.028685633809430733`], {
             RGBColor[
             0.9943579383333864, 0.9903405255320793, 0.6272745902366673]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[432, 0.028685633809430733`], {
             RGBColor[
             0.9060554589778539, 0.6652482305493559, 0.24326822101302964`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[433, 0.028685633809430733`], {
             RGBColor[
             0.9939501917878205, 0.9917662630783539, 0.7499245086849835]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[434, 0.028685633809430733`], {
             RGBColor[
             0.9263695172953702, 0.7457867025196606, 0.25961338916753657`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[435, 0.028685633809430733`], {
             RGBColor[
             0.9951665011203675, 0.9920699595751941, 0.7152816597284607]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[436, 0.028685633809430733`], {
             RGBColor[
             0.9432191938807214, 0.9571735482830547, 0.9809992733406284]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[437, 0.028685633809430733`], {
             RGBColor[
             0.9055609005996667, 0.9275336976150892, 0.9908544011745972]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[438, 0.028685633809430733`], {
             RGBColor[
             0.8799641543814392, 0.9071235469858413, 0.9884129606698177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[439, 0.028685633809430733`], {
             RGBColor[
             0.9933736255608995, 0.9882351800410172, 0.5201382194257627]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[440, 0.028685633809430733`], {
             RGBColor[
             0.9921396233658426, 0.9910175465063801, 0.7799303130380321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[441, 0.028685633809430733`], {
             RGBColor[
             0.9947542394779181, 0.9911881736080407, 0.6704095241317832]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[442, 0.028685633809430733`], {
             RGBColor[
             0.9604538157136263, 0.8782635758957348, 0.30087097102805044`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[443, 0.028685633809430733`], {
             RGBColor[
             0.9564159134635785, 0.8646427834617884, 0.2851844832804712]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[444, 0.028685633809430733`], {
             RGBColor[
             0.8328155119251822, 0.8695284993070277, 0.9839158810622498]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[445, 0.028685633809430733`], {
             RGBColor[
             0.9941860948144982, 0.9899729696212225, 0.6085704837009602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[446, 0.028685633809430733`], {
             RGBColor[
             0.8755647136251812, 0.9036155523464393, 0.9879933380830586]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[447, 0.028685633809430733`], {
             RGBColor[
             0.26881554115388295`, 0.3998725560154139, 0.9386200194405339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[448, 0.028685633809430733`], {
             RGBColor[
             0.963605714029556, 0.9723777816301924, 0.9464902123846713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[449, 0.028685633809430733`], {
             RGBColor[
             0.7570949209526647, 0.8101675734735181, 0.9764238043324193]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[450, 0.028685633809430733`], {
             RGBColor[
             0.9194052945878907, 0.9385728415852352, 0.9921748918322305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[451, 0.028685633809430733`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[452, 0.028685633809430733`], {
             RGBColor[
             0.9933821199015013, 0.9915313507545793, 0.7593389299642089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[453, 0.028685633809430733`], {
             RGBColor[
             0.8777671278929704, 0.5378509006221174, 0.21971823412307892`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[454, 0.028685633809430733`], {
             RGBColor[
             0.3782452313457785, 0.5020387410587784, 0.9453224295655958]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[455, 0.028685633809430733`], {
             RGBColor[
             0.9353091852024623, 0.9512541722616843, 0.9936918191166191]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[456, 0.028685633809430733`], {
             RGBColor[
             0.994302308170284, 0.9902215382382756, 0.6212195902925434]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[457, 0.028685633809430733`], {
             RGBColor[
             0.9343169243727816, 0.777295523265182, 0.26600805945164196`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[458, 0.028685633809430733`], {
             RGBColor[
             0.933957583082452, 0.9501764414194502, 0.993562902099823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[459, 0.028685633809430733`], {
             RGBColor[
             0.936168017110803, 0.7846344891313487, 0.26749749211938506`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[460, 0.028685633809430733`], {
             RGBColor[
             0.988505891122484, 0.9895149048410922, 0.8401506601080845]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[461, 0.028685633809430733`], {
             RGBColor[
             0.9951342308630299, 0.9920009367577726, 0.7117692413662107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[462, 0.028685633809430733`], {
             RGBColor[
             0.8310876088009442, 0.8681507162584411, 0.9837510721197427]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[463, 0.028685633809430733`], {
             RGBColor[
             0.9705857511100956, 0.9775834818560972, 0.9346748302925512]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[464, 0.028685633809430733`], {
             RGBColor[
             0.8255710686677055, 0.8637519768986894, 0.9832248995971609]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[465, 0.028685633809430733`], {
             RGBColor[
             0.9776077155502937, 0.9361277079720332, 0.36751063265133355`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[466, 0.028685633809430733`], {
             RGBColor[
             0.9904545501303952, 0.9903207254191156, 0.8078563373791409]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[467, 0.028685633809430733`], {
             RGBColor[
             0.9909650898694874, 0.9905318467215031, 0.79939537266789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[468, 0.028685633809430733`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[469, 0.028685633809430733`], {
             RGBColor[
             0.7944126554897866, 0.8393204713192048, 0.9801432873570228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[470, 0.028685633809430733`], {
             RGBColor[
             0.9534115552814075, 0.8529993719093318, 0.2813720476893156]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[471, 0.028685633809430733`], {
             RGBColor[
             0.9939219446469559, 0.9894079791225282, 0.5798193681098507]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[472, 0.028685633809430733`], {
             RGBColor[
             0.9862208696121882, 0.9885699897242106, 0.8780193799797948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[473, 0.028685633809430733`], {
             RGBColor[
             0.937431126476638, 0.7896422968606399, 0.2685138195641233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[474, 0.028685633809430733`], {
             RGBColor[
             0.9127707876679533, 0.6918722710549696, 0.24867153210610715`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[475, 0.028685633809430733`], {
             RGBColor[
             0.9602216323368931, 0.877480366846764, 0.29996898245359327`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[476, 0.028685633809430733`], {
             RGBColor[
             0.9928915909351426, 0.9872041567176997, 0.46767172518499983`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[477, 0.028685633809430733`], {
             RGBColor[
             0.8523023645429272, 0.8850667866278944, 0.985774554461049]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[478, 0.028685633809430733`], {
             RGBColor[
             0.9887792120028216, 0.989627930049138, 0.8356210257891272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[479, 0.028685633809430733`], {
             RGBColor[
             0.9436816190456646, 0.8144234170436553, 0.2735431126030796]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[480, 0.028685633809430733`], {
             RGBColor[
             0.9068072037774798, 0.6682286481757681, 0.243873092524527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[481, 0.028685633809430733`], {
             RGBColor[
             0.99318706653348, 0.9878361491453779, 0.49983242060000765`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[482, 0.028685633809430733`], {
             RGBColor[
             0.9849035760712954, 0.9607383586588869, 0.39585367306777375`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[483, 0.028685633809430733`], {
             RGBColor[
             0.9920386247023811, 0.9909757809634914, 0.7816041222677528]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[484, 0.028685633809430733`], {
             RGBColor[
             0.9592004039540571, 0.8740355237156314, 0.29600170302907397`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[485, 0.028685633809430733`], {
             RGBColor[
             0.980534470224229, 0.9850032202818855, 0.917834243873836]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[486, 0.028685633809430733`], {
             RGBColor[
             0.9920080509846853, 0.9909631379455155, 0.7821108078922175]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[487, 0.028685633809430733`], {
             RGBColor[
             0.8708877571254859, 0.8998862741861845, 0.9875472457969493]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[488, 0.028685633809430733`], {
             RGBColor[
             0.34344549945364256`, 0.47189696237919215`, 0.9431050214216236]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[489, 0.028685633809430733`], {
             RGBColor[
             0.9930928183426351, 0.9876345617951144, 0.4895740866589542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[490, 0.028685633809430733`], {
             RGBColor[
             0.9353091852024623, 0.9512541722616843, 0.9936918191166191]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[491, 0.028685633809430733`], {
             RGBColor[
             0.9716718309900558, 0.9161045755383771, 0.34445084203255094`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[492, 0.028685633809430733`], {
             RGBColor[
             0.8620579680308632, 0.46651927465579035`, 0.20661012606739243`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[493, 0.028685633809430733`], {
             RGBColor[
             0.9950610343679408, 0.9918443768560777, 0.7038022545921628]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[494, 0.028685633809430733`], {
             RGBColor[
             0.9943936517386729, 0.9919496451644323, 0.7425752296617957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[495, 0.028685633809430733`], {
             RGBColor[
             0.9917079551524091, 0.9908390406067582, 0.787084172456152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[496, 0.028685633809430733`], {
             RGBColor[
             0.7934785262200592, 0.8385907224340483, 0.9800501820813508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[497, 0.028685633809430733`], {
             RGBColor[
             0.97822266137172, 0.9382020646238496, 0.36989958104480086`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[498, 0.028685633809430733`], {
             RGBColor[
             0.9727912640922246, 0.9198806862473842, 0.3487996282472734]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[499, 0.028685633809430733`], {
             RGBColor[
             0.8905690537152924, 0.915579605852332, 0.9894244654353859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[500, 0.028685633809430733`], {
             RGBColor[
             0.7488336833085633, 0.8037138318382145, 0.9756004013697104]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1dOWGAgQBNBMbNu2bds2J+bEtm3btm3btu01sjdnH271F1R1ssCg6p0C
ggUL9l38vMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEIS
kZgkJCUZyUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpR
mCIUpRjFKUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGY
JjSlGYE0pwUtaUVr2tCWdrSnAx3pRBCd6UJXutGdHvSkF73pQ1/60Z8BDGQQ
gxnCUIYxnBGMZBSjGcNYxjGeCUxkEpOZwlSmMZ0ZzGQWs5nDXOYxnwUsZBGL
WcJSlrGcFaxkFatZw1rWsZ4NbGQTm9nCVraxnR3sZBe72cNe9rGfAxzkEIc5
wlGOcZwTnOQUpznDWc5xngtc5BKXucJVrnGdG9zkFre5w13ucZ8HPOQRj3nC
U57xnBe85BWvecNb3vGeD3zkE5/5wle+8Z1f+JXf+J0/+JO/+Jt/+Jcf/Cx/
AMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEISkZgkJCUZ
yUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpRmCIUpRjF
KUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGYJjSlGYE0
pwUtaUVr2tCWdrSnAx35Od5BdKYLXelGd3rQk170pg996Ud/BjCQQQxmCEMZ
xnBGMJJRjGYMYxnHeCYwkUlMZgpTmcZ0ZjCTWcxmDnOZx3wWsJBFLGYJS1nG
clawklWsZg1rWcd6NrCRTWxmC1vZxnZ2sJNd7GYPe9nHfg5wkEMc5ghHOcZx
TnCSU5zmDGc5x3kucJFLXOYKV7nGdW5wk1vc5g53ucd9HvCQRzzmCU95xnNe
8JJXvOYNb3nHez7wkU985gtf+Rbw/z//Dz189+A=
          "], {Null, CompressedData["
1:eJxF3Al0ldW5gOF/21YsVqt2QFCqdkClVEWUGRVRJmWoghGKIgREKWUqk4DM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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[13, 59] -> 
             RGBColor[
              0.2579706137078198, 0.3884738496614871, 0.938002416866113], 
             UndirectedEdge[210, 309] -> 
             RGBColor[
              0.1918597924354573, 0.31898718483606625`, 0.9342375033968474], 
             UndirectedEdge[88, 427] -> 
             RGBColor[
              0.18803656473244668`, 0.3149687301135649, 0.9340197762351194], 
             UndirectedEdge[293, 483] -> 
             RGBColor[
              0.630894839609411, 0.7086289993280623, 0.9658482385387919], 
             UndirectedEdge[46, 150] -> 
             RGBColor[
              0.2095354252082916, 0.3375653955801614, 0.935244104534505], 
             UndirectedEdge[400, 444] -> 
             RGBColor[
              0.7778662305017423, 0.8242556583288213, 0.8882685536457314], 
             UndirectedEdge[98, 105] -> 
             RGBColor[
              0.18986356428247403`, 0.31688902247910566`, 0.93412382115669], 
             UndirectedEdge[128, 439] -> 
             RGBColor[
              0.1967431917255388, 0.32411994711534, 0.9345156057620757], 
             UndirectedEdge[23, 62] -> 
             RGBColor[
              0.34157168432943963`, 0.4649528057928196, 0.943180457023785], 
             UndirectedEdge[201, 236] -> 
             RGBColor[
              0.2329055510975478, 0.36212887964133295`, 0.9365749986308951], 
             UndirectedEdge[40, 477] -> 
             RGBColor[
              0.19140125749096676`, 0.31850523553661203`, 0.9342113905101004],
              UndirectedEdge[455, 482] -> 
             RGBColor[
              0.47270830175216416`, 0.5795209528723455, 0.952539845619061], 
             UndirectedEdge[60, 131] -> 
             RGBColor[
              0.9096110781982166, 0.6242662481872688, 0.5350082437658015], 
             UndirectedEdge[179, 222] -> 
             RGBColor[
              0.19860716321184355`, 0.3260790993300644, 0.9346217561807222], 
             UndirectedEdge[111, 175] -> 
             RGBColor[
              0.38213445941917534`, 0.5054073949376681, 0.9455702477393233], 
             UndirectedEdge[51, 110] -> 
             RGBColor[
              0.7061642122935256, 0.763962913869964, 0.8362189440457062], 
             UndirectedEdge[84, 261] -> 
             RGBColor[
              0.30240410894972447`, 0.4332765821863486, 0.9406023955782863], 
             UndirectedEdge[156, 479] -> 
             RGBColor[
              0.19085648891639362`, 0.317932649224413, 0.9341803667456914], 
             UndirectedEdge[158, 437] -> 
             RGBColor[
              0.1868134400454955, 0.31368314851699497`, 0.9339501210936485], 
             UndirectedEdge[103, 355] -> 
             RGBColor[
              0.48475696898891374`, 0.5914050668107322, 0.9529074440237885], 
             UndirectedEdge[13, 228] -> 
             RGBColor[
              0.2555809934244899, 0.38596220723303065`, 0.9378663315261038], 
             UndirectedEdge[59, 409] -> 
             RGBColor[
              0.2581147666270732, 0.38862536351944543`, 0.9380106261616092], 
             UndirectedEdge[243, 430] -> 
             RGBColor[
              0.19906776015361727`, 0.3265632159194014, 0.934647986495164], 
             UndirectedEdge[333, 441] -> 
             RGBColor[
              0.2266279051671714, 0.35553067574276653`, 0.936217495982105], 
             UndirectedEdge[179, 385] -> 
             RGBColor[
              0.19083377116116018`, 0.3179087714232738, 0.9341790730031387], 
             UndirectedEdge[81, 447] -> 
             RGBColor[
              0.23604325092602435`, 0.36542680110272124`, 0.936753685994316], 
             UndirectedEdge[69, 404] -> 
             RGBColor[
              0.6398415718326245, 0.7153643102811339, 0.9668689392230831], 
             UndirectedEdge[113, 380] -> 
             RGBColor[
              0.19209288530033616`, 0.3192321802159951, 0.9342507776906723], 
             UndirectedEdge[85, 489] -> 
             RGBColor[
              0.18944536571522486`, 0.31644946926960615`, 0.9341000053669545],
              UndirectedEdge[277, 498] -> 
             RGBColor[
              0.6089064489917588, 0.6910771522369943, 0.9638150835884631], 
             UndirectedEdge[18, 160] -> 
             RGBColor[
              0.26388110219154026`, 0.3946861478044915, 0.9383390104414766], 
             UndirectedEdge[355, 431] -> 
             RGBColor[
              0.49048091648110803`, 0.596362862434505, 0.9532721688965031], 
             UndirectedEdge[357, 492] -> 
             RGBColor[
              0.1855765306994534, 0.3123830783697226, 0.9338796809362347], 
             UndirectedEdge[165, 386] -> 
             RGBColor[
              0.3057645176630249, 0.43870827302694076`, 0.9407242089916171], 
             UndirectedEdge[218, 274] -> 
             RGBColor[
              0.26498050169023135`, 0.3958416863835701, 0.9384016196165113], 
             UndirectedEdge[116, 441] -> 
             RGBColor[
              0.24897326082313725`, 0.37901706131456436`, 0.9374900309297209],
              UndirectedEdge[258, 435] -> 
             RGBColor[
              0.32678964542360633`, 0.4509663941385996, 0.942281872262574], 
             UndirectedEdge[112, 445] -> 
             RGBColor[
              0.9782801480279448, 0.9394045757914982, 0.5347896078268422], 
             UndirectedEdge[114, 179] -> 
             RGBColor[
              0.19077318734493098`, 0.3178450939911811, 0.9341756228444302], 
             UndirectedEdge[155, 467] -> 
             RGBColor[
              0.19253479608250443`, 0.31969665646681583`, 0.9342759438559683],
              UndirectedEdge[243, 421] -> 
             RGBColor[
              0.1904580230623436, 0.31751383634761216`, 0.9341576747047806], 
             UndirectedEdge[172, 289] -> 
             RGBColor[
              0.2167825321958998, 0.3451825645172597, 0.9356568165563153], 
             UndirectedEdge[381, 468] -> 
             RGBColor[
              0.20490029607601296`, 0.33269358097797563`, 0.9349801407874807],
              UndirectedEdge[17, 277] -> 
             RGBColor[
              0.4093350243660927, 0.5289671571545423, 0.9473034436852257], 
             UndirectedEdge[279, 477] -> 
             RGBColor[
              0.2028882707819582, 0.3305788148241523, 0.9348655589235091], 
             UndirectedEdge[4, 405] -> 
             RGBColor[
              0.18158563263707392`, 0.3081883914686098, 0.9336524051955868], 
             UndirectedEdge[36, 379] -> 
             RGBColor[
              0.9107780137599082, 0.6018218600251894, 0.4604073756146171], 
             UndirectedEdge[278, 401] -> 
             RGBColor[
              0.18259570595575553`, 0.30925004256889155`, 0.9337099273768162],
              UndirectedEdge[152, 399] -> 
             RGBColor[
              0.19605719925809356`, 0.3233989255376204, 0.9344765395058896], 
             UndirectedEdge[173, 406] -> 
             RGBColor[
              0.5685496786155626, 0.658415121806283, 0.9602730898835382], 
             UndirectedEdge[239, 332] -> 
             RGBColor[
              0.1916360269785587, 0.31875199315331637`, 0.9342247602851084], 
             UndirectedEdge[116, 361] -> 
             RGBColor[
              0.25328984688463263`, 0.3835540669525598, 0.9377358541201064], 
             UndirectedEdge[288, 498] -> 
             RGBColor[
              0.7429048622719281, 0.7990821917836863, 0.9750094718967612], 
             UndirectedEdge[16, 386] -> 
             RGBColor[
              0.2878595743491687, 0.4198890423651035, 0.9397045489578829], 
             UndirectedEdge[216, 464] -> 
             RGBColor[
              0.20118455785762748`, 0.32878810451904233`, 0.9347685349928858],
              UndirectedEdge[379, 400] -> 
             RGBColor[
              0.9086464403656656, 0.6009403996477325, 0.49573306309233295`], 
             UndirectedEdge[22, 24] -> 
             RGBColor[
              0.18354454614871424`, 0.31024733377163405`, 0.9337639624221219],
              UndirectedEdge[231, 355] -> 
             RGBColor[
              0.6616838941423232, 0.7343656744943371, 0.9677797504415411], 
             UndirectedEdge[434, 495] -> 
             RGBColor[
              0.9105859845179732, 0.6779864914594717, 0.24664336835265455`], 
             UndirectedEdge[75, 323] -> 
             RGBColor[
              0.9290142282590157, 0.73628865839294, 0.4899032009526938], 
             UndirectedEdge[165, 288] -> 
             RGBColor[
              0.508574991950541, 0.6066055037109249, 0.956292599133973], 
             UndirectedEdge[90, 229] -> 
             RGBColor[
              0.24859585520259658`, 0.3786203840784777, 0.9374685382379528], 
             UndirectedEdge[267, 424] -> 
             RGBColor[
              0.21136439475697272`, 0.3394877585391924, 0.9353482616445844], 
             UndirectedEdge[258, 403] -> 
             RGBColor[
              0.5792948267817268, 0.6667531924094637, 0.9613678188204143], 
             UndirectedEdge[274, 305] -> 
             RGBColor[
              0.2773195143815185, 0.4086435488273039, 0.9391104309604698], 
             UndirectedEdge[399, 478] -> 
             RGBColor[
              0.22859634417905478`, 0.3575996299504977, 0.9363295956717873], 
             UndirectedEdge[359, 463] -> 
             RGBColor[
              0.7323426131107887, 0.7902188270608363, 0.9746779559842911], 
             UndirectedEdge[302, 422] -> 
             RGBColor[
              0.22565049031831835`, 0.3545033507649412, 0.9361618336524187], 
             UndirectedEdge[21, 335] -> 
             RGBColor[
              0.2551889465783416, 0.385550141140523, 0.9378440050381969], 
             UndirectedEdge[266, 445] -> 
             RGBColor[
              0.9783510953842744, 0.9379685313127405, 0.42709594933440853`], 
             UndirectedEdge[200, 452] -> 
             RGBColor[
              0.24489188267224044`, 0.3747272741036509, 0.9372576024818854], 
             UndirectedEdge[112, 471] -> 
             RGBColor[
              0.9751390722082593, 0.9794426669377387, 0.8581518289048162], 
             UndirectedEdge[481, 496] -> 
             RGBColor[
              0.19554201050297132`, 0.3228574294911333, 0.934447200268439], 
             UndirectedEdge[6, 422] -> 
             RGBColor[
              0.21046728026605566`, 0.33854483432889454`, 0.9352971723014887],
              UndirectedEdge[137, 424] -> 
             RGBColor[
              0.20256381379959026`, 0.3302377899639228, 0.9348470815783543], 
             UndirectedEdge[89, 482] -> 
             RGBColor[
              0.3210267437424298, 0.45247896298156487`, 0.9416765181318323], 
             UndirectedEdge[142, 254] -> 
             RGBColor[
              0.20407108545370353`, 0.33182202803893834`, 0.9349329184692474],
              UndirectedEdge[178, 321] -> 
             RGBColor[
              0.7273722693999012, 0.7841453015250835, 0.9212028178095601], 
             UndirectedEdge[151, 456] -> 
             RGBColor[
              0.19966233325078292`, 0.32718814994263423`, 0.9346818465534554],
              UndirectedEdge[346, 431] -> 
             RGBColor[
              0.43133365387154704`, 0.5480212643488988, 0.948705176904689], 
             UndirectedEdge[65, 297] -> 
             RGBColor[
              0.18922089119532, 0.3162135323166796, 0.9340872218751262], 
             UndirectedEdge[79, 253] -> 
             RGBColor[
              0.6318697246341356, 0.7067600197693191, 0.967143342848597], 
             UndirectedEdge[376, 475] -> 
             RGBColor[
              0.3538187512223421, 0.4808817516864462, 0.9437659958516187], 
             UndirectedEdge[209, 259] -> 
             RGBColor[
              0.8388746662508497, 0.8722406233791922, 0.8551373469793608], 
             UndirectedEdge[464, 496] -> 
             RGBColor[
              0.1941346337620407, 0.32137818730357604`, 0.9343670522450702], 
             UndirectedEdge[101, 103] -> 
             RGBColor[
              0.32745764009317235`, 0.4521656087003331, 0.9423017119454735], 
             UndirectedEdge[69, 348] -> 
             RGBColor[
              0.4524683198594424, 0.5660891289103882, 0.9501175973747447], 
             UndirectedEdge[116, 277] -> 
             RGBColor[
              0.35985275808300965`, 0.4831247951827711, 0.9442597110251651], 
             UndirectedEdge[171, 471] -> 
             RGBColor[
              0.7137657491152036, 0.7742498659419835, 0.9547112060503897], 
             UndirectedEdge[133, 429] -> 
             RGBColor[
              0.19496484613925177`, 0.3222507931505298, 0.9344143316117632], 
             UndirectedEdge[37, 203] -> 
             RGBColor[
              0.8534629031399862, 0.4065189709815528, 0.1986169775584265], 
             UndirectedEdge[299, 399] -> 
             RGBColor[
              0.22397618806162217`, 0.3527435529362591, 0.936066484615808], 
             UndirectedEdge[311, 429] -> 
             RGBColor[
              0.19096685764878327`, 0.3180486537599364, 0.934186652081725], 
             UndirectedEdge[327, 446] -> 
             RGBColor[
              0.18359313787334597`, 0.31029840675511533`, 0.9337667296489547],
              UndirectedEdge[15, 249] -> 
             RGBColor[
              0.6896781375343781, 0.7575010698806214, 0.9697043294069452], 
             UndirectedEdge[50, 242] -> 
             RGBColor[
              0.9267381119467066, 0.943455029677774, 0.9594240314227456], 
             UndirectedEdge[163, 355] -> 
             RGBColor[
              0.7295091887885554, 0.6445510453124249, 0.5980872339837272], 
             UndirectedEdge[192, 435] -> 
             RGBColor[
              0.2756938897780267, 0.40670981874574946`, 0.9390260958950403], 
             UndirectedEdge[31, 191] -> 
             RGBColor[
              0.1912888055455656, 0.31838704141213026`, 0.9342049865381675], 
             UndirectedEdge[385, 415] -> 
             RGBColor[
              0.18097729894859016`, 0.30754899419142984`, 0.9336177614919767],
              UndirectedEdge[207, 257] -> 
             RGBColor[
              0.9190198138450048, 0.7061284902521469, 0.2641826298296307], 
             UndirectedEdge[359, 408] -> 
             RGBColor[
              0.923405109023163, 0.9417213092494618, 0.9911392082523272], 
             UndirectedEdge[183, 202] -> 
             RGBColor[
              0.19186250689715728`, 0.31899003790741964`, 0.9342376579814256],
              UndirectedEdge[170, 223] -> 
             RGBColor[
              0.19795986022643686`, 0.3253987428510222, 0.9345848932333021], 
             UndirectedEdge[40, 430] -> 
             RGBColor[
              0.1932824749084014, 0.32048251431840913`, 0.9343185230590114], 
             UndirectedEdge[69, 444] -> 
             RGBColor[
              0.5043601503383525, 0.6082172545934901, 0.9542027123560828], 
             UndirectedEdge[215, 417] -> 
             RGBColor[
              0.1910469226092748, 0.31813280710982467`, 0.9341912116627795], 
             UndirectedEdge[423, 429] -> 
             RGBColor[
              0.18557451474248365`, 0.3123809594711283, 0.9338795661304677], 
             UndirectedEdge[5, 83] -> 
             RGBColor[
              0.8424015657306109, 0.8748578438487853, 0.849230453036272], 
             UndirectedEdge[311, 366] -> 
             RGBColor[
              0.18627071422588198`, 0.31311270926977675`, 0.9339192136611123],
              UndirectedEdge[133, 366] -> 
             RGBColor[
              0.1902687027163505, 0.3173148486603702, 0.9341468931911505], 
             UndirectedEdge[76, 359] -> 
             RGBColor[
              0.6599771175433797, 0.7303046973046542, 0.9693028506052312], 
             UndirectedEdge[172, 218] -> 
             RGBColor[
              0.25468436170219366`, 0.3850197904431626, 0.9378152696759667], 
             UndirectedEdge[177, 484] -> 
             RGBColor[
              0.18459712642978363`, 0.31135366238448237`, 0.9338239053119759],
              UndirectedEdge[45, 328] -> 
             RGBColor[
              0.22208190708084125`, 0.3507525435211073, 0.9359586081162901], 
             UndirectedEdge[115, 144] -> 
             RGBColor[
              0.1939326542641488, 0.3211658940450518, 0.9343555498114672], 
             UndirectedEdge[63, 72] -> 
             RGBColor[
              0.20896361604647165`, 0.3369643878962938, 0.9352115408486552], 
             UndirectedEdge[248, 387] -> 
             RGBColor[
              0.18458186461527748`, 0.3113376212497815, 0.9338230361742175], 
             UndirectedEdge[34, 44] -> 
             RGBColor[
              0.24396970740458573`, 0.37375800942805687`, 0.9372050859646285],
              UndirectedEdge[279, 285] -> 
             RGBColor[
              0.2111852622032374, 0.3392994788675566, 0.935338060310652], 
             UndirectedEdge[13, 77] -> 
             RGBColor[
              0.293706622672794, 0.4236564919439787, 0.9401246061243856], 
             UndirectedEdge[53, 445] -> 
             RGBColor[
              0.897896740106011, 0.5697053012801583, 0.24507330073286251`], 
             UndirectedEdge[91, 298] -> 
             RGBColor[
              0.368006349252357, 0.4899237097604318, 0.9448344889260978], 
             UndirectedEdge[6, 451] -> 
             RGBColor[
              0.20974058048916117`, 0.3377810267879514, 0.9352557878242505], 
             UndirectedEdge[87, 256] -> 
             RGBColor[
              0.30998490234108894`, 0.4428842197606874, 0.9409740715208748], 
             UndirectedEdge[153, 172] -> 
             RGBColor[
              0.22556462734887084`, 0.3544131033400252, 0.9361569438833315], 
             UndirectedEdge[72, 438] -> 
             RGBColor[
              0.20687895912531873`, 0.33477328129727923`, 0.9350928227209692],
              UndirectedEdge[207, 440] -> 
             RGBColor[
              0.8833097581290331, 0.5630186900098979, 0.22434314065434907`], 
             UndirectedEdge[19, 228] -> 
             RGBColor[
              0.2307172081494932, 0.3598287924539709, 0.9364503757373667], 
             UndirectedEdge[8, 63] -> 
             RGBColor[
              0.20214886588846875`, 0.32980165340011697`, 0.9348234509086764],
              UndirectedEdge[72, 128] -> 
             RGBColor[
              0.20268608388741163`, 0.33036630357859437`, 0.9348540446789733],
              UndirectedEdge[229, 485] -> 
             RGBColor[
              0.2450928096239232, 0.3749384610693741, 0.9372690449745389], 
             UndirectedEdge[32, 407] -> 
             RGBColor[
              0.24840100008144717`, 0.3784155789916214, 0.9374574415270658], 
             UndirectedEdge[475, 478] -> 
             RGBColor[
              0.2929211568634166, 0.42264039555989485`, 0.9400868509528724], 
             UndirectedEdge[194, 412] -> 
             RGBColor[
              0.18818134565428368`, 0.3151209040420562, 0.934028021294434], 
             UndirectedEdge[370, 390] -> 
             RGBColor[
              0.24233683264276484`, 0.3720417545231436, 0.9371120961625645], 
             UndirectedEdge[231, 233] -> 
             RGBColor[
              0.8631076739966228, 0.8934453053740385, 0.9626713381948079], 
             UndirectedEdge[114, 385] -> 
             RGBColor[
              0.18149489941754873`, 0.3080930251020705, 0.9336472380729627], 
             UndirectedEdge[271, 442] -> 
             RGBColor[
              0.22300003138538366`, 0.3517175503776244, 0.9360108939371906], 
             UndirectedEdge[206, 254] -> 
             RGBColor[
              0.18642186112422848`, 0.31327157424320573`, 0.9339278212533714],
              UndirectedEdge[262, 455] -> 
             RGBColor[
              0.47810598768171675`, 0.5841961571289409, 0.9528837813935058], 
             UndirectedEdge[7, 341] -> 
             RGBColor[
              0.7333256796265153, 0.7863640981896829, 0.7861411597228827], 
             UndirectedEdge[187, 328] -> 
             RGBColor[
              0.2321163718921772, 0.36129940225963686`, 0.9365300560426353], 
             UndirectedEdge[44, 56] -> 
             RGBColor[
              0.342928946455201, 0.46870029922168843`, 0.9431727706647948], 
             UndirectedEdge[142, 388] -> 
             RGBColor[
              0.27220031221012625`, 0.4015863957278337, 0.9388802865699359], 
             UndirectedEdge[282, 419] -> 
             RGBColor[
              0.6729998707802133, 0.7444718811327458, 0.9680419956441542], 
             UndirectedEdge[7, 244] -> 
             RGBColor[
              0.45953784870192455`, 0.5719334474988196, 0.9506451367617185], 
             UndirectedEdge[107, 470] -> 
             RGBColor[
              0.20295018288856098`, 0.3306438883736461, 0.9348690847263893], 
             UndirectedEdge[10, 383] -> 
             RGBColor[
              0.24728065527257528`, 0.3772380255635335, 0.9373936395476021], 
             UndirectedEdge[249, 419] -> 
             RGBColor[
              0.6881180325530365, 0.7562823040119602, 0.9695488327224149], 
             UndirectedEdge[191, 271] -> 
             RGBColor[
              0.19934619168565726`, 0.3268558651131542, 0.9346638427590112], 
             UndirectedEdge[297, 490] -> 
             RGBColor[
              0.20561521715269282`, 0.3334450083581805, 0.9350208544851668], 
             UndirectedEdge[32, 176] -> 
             RGBColor[
              0.26830294791528575`, 0.39857679935889445`, 0.938618545077043], 
             UndirectedEdge[353, 487] -> 
             RGBColor[
              0.18672390467583372`, 0.3135890411666101, 0.933945022186802], 
             UndirectedEdge[281, 324] -> 
             RGBColor[
              0.8790783466018638, 0.5485966593380001, 0.5760884806324713], 
             UndirectedEdge[19, 59] -> 
             RGBColor[
              0.2331068284328231, 0.3623404348824274, 0.936586461077376], 
             UndirectedEdge[197, 411] -> 
             RGBColor[
              0.25605149674669436`, 0.3864567360563011, 0.937893125994256], 
             UndirectedEdge[163, 343] -> 
             RGBColor[
              0.8727695735845509, 0.4960098594094768, 0.21479835234035222`], 
             UndirectedEdge[12, 396] -> 
             RGBColor[
              0.19573690002635402`, 0.32306227073691796`, 0.9344582989384823],
              UndirectedEdge[51, 397] -> 
             RGBColor[
              0.9086311282442023, 0.5812180792787432, 0.4466755411222336], 
             UndirectedEdge[448, 482] -> 
             RGBColor[
              0.3164780231838319, 0.4477844619968153, 0.9414143083027866], 
             UndirectedEdge[183, 285] -> 
             RGBColor[
              0.20567627769071223`, 0.33350918685510056`, 0.935024331792476], 
             UndirectedEdge[155, 365] -> 
             RGBColor[
              0.200483284293693, 0.3280510215400352, 0.934728598500861], 
             UndirectedEdge[122, 217] -> 
             RGBColor[
              0.1834604918576584, 0.31015898738238445`, 0.9337591756545935], 
             UndirectedEdge[249, 269] -> 
             RGBColor[
              0.6644117978227214, 0.7371426324130581, 0.9676100378285277], 
             UndirectedEdge[101, 331] -> 
             RGBColor[
              0.2732729587475753, 0.4045575845229832, 0.9388738627783362], 
             UndirectedEdge[246, 458] -> 
             RGBColor[
              0.2394606076875042, 0.3690186597319697, 0.9369482994063559], 
             UndirectedEdge[35, 437] -> 
             RGBColor[
              0.18478436843582058`, 0.31155046560465605`, 0.9338345684672199],
              UndirectedEdge[354, 473] -> 
             RGBColor[
              0.28709080979716467`, 0.41891074115277027`, 0.9396670037727628],
              UndirectedEdge[230, 484] -> 
             RGBColor[
              0.19535510076833423`, 0.3226609755092681, 0.9344365560355595], 
             UndirectedEdge[108, 190] -> 
             RGBColor[
              0.21307880253974895`, 0.34128970981862183`, 0.9354458946315745],
              UndirectedEdge[55, 136] -> 
             RGBColor[
              0.5509076978824959, 0.6462907131067992, 0.9577886185001523], 
             UndirectedEdge[59, 279] -> 
             RGBColor[
              0.23548934775412372`, 0.36484461374956423`, 0.9367221420281024],
              UndirectedEdge[24, 170] -> 
             RGBColor[
              0.18651291707157386`, 0.3133672798171463, 0.9339330067548675], 
             UndirectedEdge[184, 388] -> 
             RGBColor[
              0.43476172806913593`, 0.5486141843644792, 0.9495801910661066], 
             UndirectedEdge[173, 242] -> 
             RGBColor[
              0.8468550508642396, 0.8805617516174773, 0.9515915409041512], 
             UndirectedEdge[4, 345] -> 
             RGBColor[
              0.18617654721563465`, 0.31301373377147346`, 0.9339138509891864],
              UndirectedEdge[59, 256] -> 
             RGBColor[
              0.28727672509446966`, 0.4190164856928953, 0.9396808744204175], 
             UndirectedEdge[232, 480] -> 
             RGBColor[
              0.2609103808391443, 0.3915637313085108, 0.9381698322552461], 
             UndirectedEdge[3, 437] -> 
             RGBColor[
              0.18278910615931465`, 0.30945331844511326`, 0.9337209412322989],
              UndirectedEdge[199, 448] -> 
             RGBColor[
              0.3433591771132972, 0.47106756644443715`, 0.943127151661101], 
             UndirectedEdge[151, 226] -> 
             RGBColor[
              0.19534643528489967`, 0.3226518675367549, 0.9344360625490973], 
             UndirectedEdge[241, 442] -> 
             RGBColor[
              0.22676711964941848`, 0.35567699899031613`, 0.9362254240409197],
              UndirectedEdge[303, 400] -> 
             RGBColor[
              0.9153331914929417, 0.6523376989650047, 0.5021363035234178], 
             UndirectedEdge[42, 378] -> 
             RGBColor[
              0.20375715237687997`, 0.3314920644706901, 0.9349150404449447], 
             UndirectedEdge[15, 499] -> 
             RGBColor[
              0.6404896932769727, 0.7188634972449458, 0.9649460740899308], 
             UndirectedEdge[341, 374] -> 
             RGBColor[
              0.9208708140731814, 0.677947066838142, 0.406871876564454], 
             UndirectedEdge[312, 334] -> 
             RGBColor[
              0.19091202731972692`, 0.3179910236076545, 0.9341835295755994], 
             UndirectedEdge[7, 482] -> 
             RGBColor[
              0.4023630118874444, 0.5224114775409715, 0.9470020067176228], 
             UndirectedEdge[219, 403] -> 
             RGBColor[
              0.7064676273124759, 0.7706171469001197, 0.9713777488413233], 
             UndirectedEdge[50, 449] -> 
             RGBColor[
              0.9319849870644814, 0.931902676711367, 0.6896331946772748], 
             UndirectedEdge[318, 430] -> 
             RGBColor[
              0.1997685243379237, 0.32729976350812295`, 0.9346878939787725], 
             UndirectedEdge[242, 449] -> 
             RGBColor[
              0.9783597736506789, 0.9679158712997968, 0.6606061921458748], 
             UndirectedEdge[356, 365] -> 
             RGBColor[
              0.2261799618783253, 0.3550598589449443, 0.9361919862744781], 
             UndirectedEdge[154, 219] -> 
             RGBColor[
              0.8264967277029731, 0.8644743578312362, 0.9402829367923042], 
             UndirectedEdge[69, 275] -> 
             RGBColor[
              0.46608428308489896`, 0.5771431812489669, 0.9511894958767693], 
             UndirectedEdge[173, 310] -> 
             RGBColor[
              0.682704924474264, 0.7520535428396782, 0.9690093046974939], 
             UndirectedEdge[351, 460] -> 
             RGBColor[
              0.2704319943298352, 0.4015715507923906, 0.9387120740575761], 
             UndirectedEdge[97, 207] -> 
             RGBColor[
              0.9317219029437263, 0.7489756193744845, 0.31352784738991035`], 
             UndirectedEdge[122, 212] -> 
             RGBColor[
              0.18381215152445518`, 0.3105286039886985, 0.9337792021523836], 
             UndirectedEdge[45, 224] -> 
             RGBColor[
              0.20355580866569664`, 0.3312804394643078, 0.9349035742184542], 
             UndirectedEdge[144, 215] -> 
             RGBColor[
              0.19092068807717077`, 0.3180001266128517, 0.9341840227929235], 
             UndirectedEdge[22, 214] -> 
             RGBColor[
              0.1846717285967103, 0.31143207399197287`, 0.9338281537950183], 
             UndirectedEdge[142, 150] -> 
             RGBColor[
              0.2155365862389103, 0.34387299631892737`, 0.9355858617772765], 
             UndirectedEdge[149, 419] -> 
             RGBColor[
              0.6052079656077549, 0.6902679989364768, 0.962135887741037], 
             UndirectedEdge[11, 418] -> 
             RGBColor[
              0.4260394736081712, 0.5428061221897597, 0.9485417938214956], 
             UndirectedEdge[189, 346] -> 
             RGBColor[
              0.346693677388048, 0.46946123011413, 0.9435041892031641], 
             UndirectedEdge[185, 224] -> 
             RGBColor[
              0.2087376164930067, 0.33672684803640285`, 0.9351986705084218], 
             UndirectedEdge[17, 386] -> 
             RGBColor[
              0.34052296335874593`, 0.4690749660172503, 0.9429294418511679], 
             UndirectedEdge[194, 476] -> 
             RGBColor[
              0.18476853282621936`, 0.3115338213749295, 0.9338336666526799], 
             UndirectedEdge[258, 471] -> 
             RGBColor[
              0.686008715672987, 0.7506799404061069, 0.9528121866762553], 
             UndirectedEdge[203, 397] -> 
             RGBColor[
              0.8335404053549352, 0.2588118298231834, 0.1797516360873429], 
             UndirectedEdge[126, 173] -> 
             RGBColor[
              0.6045267350947843, 0.6886225535376819, 0.9628291330052186], 
             UndirectedEdge[30, 366] -> 
             RGBColor[
              0.1807454038963133, 0.3073052577884914, 0.9336045554118075], 
             UndirectedEdge[95, 368] -> 
             RGBColor[
              0.1819562792912616, 0.3085779646025163, 0.9336735129742202], 
             UndirectedEdge[15, 242] -> 
             RGBColor[
              0.8127597142986478, 0.8539262155582815, 0.9481932363943286], 
             UndirectedEdge[150, 392] -> 
             RGBColor[
              0.22610554162039614`, 0.3549816385353439, 0.9361877481508839], 
             UndirectedEdge[179, 296] -> 
             RGBColor[
              0.19117065430032437`, 0.31826285696216006`, 0.9341982579995401],
              UndirectedEdge[3, 123] -> 
             RGBColor[
              0.1847525458331286, 0.3115170180315573, 0.933832756217074], 
             UndirectedEdge[37, 257] -> 
             RGBColor[
              0.9124536887252621, 0.6763132496408797, 0.2587036940792628], 
             UndirectedEdge[17, 178] -> 
             RGBColor[
              0.4223764301651894, 0.5398287637649369, 0.9482544022825725], 
             UndirectedEdge[68, 367] -> 
             RGBColor[
              0.19128856344294365`, 0.31838678694692435`, 0.9342049727507814],
              UndirectedEdge[1, 363] -> 
             RGBColor[
              0.19094550353876433`, 0.3180262092363777, 0.93418543599675], 
             UndirectedEdge[227, 329] -> 
             RGBColor[
              0.18736891797604732`, 0.31426699104133987`, 0.9339817547400375],
              UndirectedEdge[121, 420] -> 
             RGBColor[
              0.1965885249531354, 0.3239573825311042, 0.9345067977181964], 
             UndirectedEdge[82, 149] -> 
             RGBColor[
              0.540625880408879, 0.6379434704911183, 0.9569791961650909], 
             UndirectedEdge[129, 355] -> 
             RGBColor[
              0.4245428223807357, 0.5374596923522321, 0.9491362257297418], 
             UndirectedEdge[87, 388] -> 
             RGBColor[
              0.3185501109900676, 0.45030297299252864`, 0.941519839042071], 
             UndirectedEdge[91, 228] -> 
             RGBColor[
              0.35927043823642757`, 0.48074171339394056`, 0.9443369917173629],
              UndirectedEdge[12, 161] -> 
             RGBColor[
              0.20394297282787943`, 0.33168737354638755`, 0.9349256226447324],
              UndirectedEdge[64, 115] -> 
             RGBColor[
              0.18789626990443398`, 0.31482127135411775`, 0.9340117866522119],
              UndirectedEdge[56, 342] -> 
             RGBColor[
              0.4415801835206408, 0.5562719260910596, 0.9495305912404275], 
             UndirectedEdge[378, 416] -> 
             RGBColor[
              0.2080965578112694, 0.3360530547164289, 0.9351621631648581], 
             UndirectedEdge[119, 363] -> 
             RGBColor[
              0.18346622269800678`, 0.3101650108589469, 0.9337595020174734], 
             UndirectedEdge[391, 455] -> 
             RGBColor[
              0.5430796704315681, 0.6399355677735181, 0.9571723675042059], 
             UndirectedEdge[249, 282] -> 
             RGBColor[
              0.7118315832315418, 0.7748075100316689, 0.9719123778383179], 
             UndirectedEdge[226, 429] -> 
             RGBColor[
              0.18946440368264025`, 0.31646947938043657`, 0.9341010895510347],
              UndirectedEdge[181, 189] -> 
             RGBColor[
              0.238744748764803, 0.3682662466161335, 0.9369075322997265], 
             UndirectedEdge[160, 167] -> 
             RGBColor[
              0.2396559862242012, 0.36922401496175294`, 0.9369594259249842], 
             UndirectedEdge[16, 277] -> 
             RGBColor[
              0.35667163535651547`, 0.47978123350239554`, 0.9440785507919407],
              UndirectedEdge[295, 341] -> 
             RGBColor[
              0.9895466198460419, 0.9890958111978665, 0.7611561924651287], 
             UndirectedEdge[69, 129] -> 
             RGBColor[
              0.36611599979539755`, 0.48974210320523914`, 0.944615139539211], 
             UndirectedEdge[352, 368] -> 
             RGBColor[
              0.1813119634696479, 0.3079007478220177, 0.9336368201413592], 
             UndirectedEdge[194, 297] -> 
             RGBColor[
              0.1906847748105455, 0.3177521668118635, 0.9341705878813915], 
             UndirectedEdge[188, 228] -> 
             RGBColor[
              0.24109668028529843`, 0.37073827576524543`, 0.9370414713204478],
              UndirectedEdge[273, 430] -> 
             RGBColor[
              0.19435747882303328`, 0.32161241159187215`, 0.9343797429416241],
              UndirectedEdge[200, 468] -> 
             RGBColor[
              0.2422384711696754, 0.37193837037844896`, 0.9371064946221849], 
             UndirectedEdge[93, 172] -> 
             RGBColor[
              0.22306123798292227`, 0.35178188239235997`, 0.9360143795623734],
              UndirectedEdge[61, 341] -> 
             RGBColor[
              0.992278182050985, 0.9902253823675571, 0.7158871376728388], 
             UndirectedEdge[121, 442] -> 
             RGBColor[
              0.22151836933651753`, 0.35016022962146637`, 0.9359265154754303],
              UndirectedEdge[287, 336] -> 
             RGBColor[
              0.46475221828321023`, 0.5718710801553506, 0.9521407597407114], 
             UndirectedEdge[403, 497] -> 
             RGBColor[
              0.6107955480026974, 0.6933624123353453, 0.9635615550100725], 
             UndirectedEdge[17, 407] -> 
             RGBColor[
              0.3262865305599572, 0.4541115725037497, 0.9421186980641918], 
             UndirectedEdge[135, 470] -> 
             RGBColor[
              0.18730486737300778`, 0.31419966979650255`, 0.9339781071529487],
              UndirectedEdge[322, 471] -> 
             RGBColor[
              0.8888094561578547, 0.5640382311059557, 0.5627414261917315], 
             UndirectedEdge[24, 52] -> 
             RGBColor[
              0.18264284256949226`, 0.3092995861385628, 0.9337126117372361], 
             UndirectedEdge[163, 440] -> 
             RGBColor[
              0.8954705204165625, 0.6182378713393768, 0.2344903787946242], 
             UndirectedEdge[274, 432] -> 
             RGBColor[
              0.26765870816883486`, 0.3986566512006808, 0.9385541395134164], 
             UndirectedEdge[89, 261] -> 
             RGBColor[
              0.31948712585052597`, 0.45114542334704305`, 0.9415784150411908],
              UndirectedEdge[255, 312] -> 
             RGBColor[
              0.19606964847691927`, 0.3234120104559323, 0.9344772484704849], 
             UndirectedEdge[370, 422] -> 
             RGBColor[
              0.21765000410983476`, 0.3460943324997014, 0.9357062177985042], 
             UndirectedEdge[43, 90] -> 
             RGBColor[
              0.24535980769453214`, 0.3752190929702395, 0.9372842501196719], 
             UndirectedEdge[373, 449] -> 
             RGBColor[
              0.9873031183402635, 0.9734548154410307, 0.5948195031122866], 
             UndirectedEdge[49, 457] -> 
             RGBColor[
              0.7315880631738731, 0.7847063242900234, 0.765752210507527], 
             UndirectedEdge[234, 449] -> 
             RGBColor[
              0.9549924747052941, 0.851092521948047, 0.32521790592745947`], 
             UndirectedEdge[245, 299] -> 
             RGBColor[
              0.24199930981785328`, 0.3716869966339784, 0.9370928747370061], 
             UndirectedEdge[398, 464] -> 
             RGBColor[
              0.20435657897174597`, 0.33212209982773555`, 0.9349491769027501],
              UndirectedEdge[245, 262] -> 
             RGBColor[
              0.2935462908702744, 0.4226836514910424, 0.9401449256179049], 
             UndirectedEdge[288, 321] -> 
             RGBColor[
              0.8483292768809738, 0.881288734461381, 0.9314462475205114], 
             UndirectedEdge[433, 465] -> 
             RGBColor[
              0.17986137360753812`, 0.306376085904231, 0.9335542111946675], 
             UndirectedEdge[330, 367] -> 
             RGBColor[
              0.19336515666501655`, 0.3205694180869378, 0.9343232316627341], 
             UndirectedEdge[106, 156] -> 
             RGBColor[
              0.1895211212928381, 0.31652909318485867`, 0.9341043195350291], 
             UndirectedEdge[85, 239] -> 
             RGBColor[
              0.19195700771123925`, 0.31908936425471746`, 0.9342430396629862],
              UndirectedEdge[336, 388] -> 
             RGBColor[
              0.4770192723969674, 0.5829207625304905, 0.9529068597500787], 
             UndirectedEdge[69, 355] -> 
             RGBColor[
              0.5012830197903266, 0.6057191013914514, 0.9539604693674415], 
             UndirectedEdge[102, 383] -> 
             RGBColor[
              0.23360844690792137`, 0.362867667704204, 0.9366150275074547], 
             UndirectedEdge[296, 327] -> 
             RGBColor[
              0.1830042105599709, 0.3096794068086097, 0.9337331911096979], 
             UndirectedEdge[61, 288] -> 
             RGBColor[
              0.8507412174209339, 0.8822861338586991, 0.8914741508713435], 
             UndirectedEdge[141, 472] -> 
             RGBColor[
              0.19522243291560842`, 0.32252153318442556`, 0.9344290007976113],
              UndirectedEdge[43, 485] -> 
             RGBColor[
              0.24185676211585877`, 0.3715371699611359, 0.9370847568562579], 
             UndirectedEdge[9, 358] -> 
             RGBColor[
              0.2093374978833109, 0.33735736141228945`, 0.9352328328661546], 
             UndirectedEdge[70, 359] -> 
             RGBColor[
              0.6396346219366711, 0.7126850500536813, 0.9680066447733342], 
             UndirectedEdge[466, 470] -> 
             RGBColor[
              0.19475005924981162`, 0.3220250385114528, 0.9344020998161584], 
             UndirectedEdge[41, 356] -> 
             RGBColor[
              0.25420192746199044`, 0.3845127214686115, 0.9377877957596846], 
             UndirectedEdge[79, 436] -> 
             RGBColor[
              0.620883921888038, 0.6972446695931502, 0.9664433372119796], 
             UndirectedEdge[33, 175] -> 
             RGBColor[
              0.326974395016177, 0.4527788821025087, 0.9422331394259775], 
             UndirectedEdge[176, 448] -> 
             RGBColor[
              0.3087587670403855, 0.44109843030645696`, 0.9409224441271964], 
             UndirectedEdge[118, 481] -> 
             RGBColor[
              0.1987399075504107, 0.32621862204637564`, 0.9346293157744259], 
             UndirectedEdge[326, 346] -> 
             RGBColor[
              0.5833986733777301, 0.6710733580441507, 0.9613052656352206], 
             UndirectedEdge[63, 435] -> 
             RGBColor[
              0.22260483335872017`, 0.351302172194599, 0.9359883879942152], 
             UndirectedEdge[194, 350] -> 
             RGBColor[
              0.18381567245253283`, 0.31053230470734794`, 0.9337794026640289],
              UndirectedEdge[275, 486] -> 
             RGBColor[
              0.45132348377934284`, 0.564358118789839, 0.9502489507974816], 
             UndirectedEdge[407, 478] -> 
             RGBColor[
              0.2632216514132959, 0.39399302322496244`, 0.9383014556952256], 
             UndirectedEdge[62, 356] -> 
             RGBColor[
              0.24825469827183463`, 0.37826180651364816`, 0.9374491098554425],
              UndirectedEdge[150, 426] -> 
             RGBColor[
              0.20135872025195078`, 0.3289711602380097, 0.9347784532835923], 
             UndirectedEdge[372, 444] -> 
             RGBColor[
              0.5900676498939734, 0.6780825262854508, 0.9608714333701266], 
             UndirectedEdge[106, 329] -> 
             RGBColor[
              0.18061317161541351`, 0.30716627327725476`, 0.9335970249790304],
              UndirectedEdge[128, 294] -> 
             RGBColor[
              0.1908740507973531, 0.317951107874789, 0.9341813668688315], 
             UndirectedEdge[379, 440] -> 
             RGBColor[
              0.8595285144156211, 0.406306411086346, 0.20259145280411195`], 
             UndirectedEdge[227, 267] -> 
             RGBColor[
              0.2112079223469873, 0.3393232961153739, 0.935339350772316], 
             UndirectedEdge[151, 345] -> 
             RGBColor[
              0.19727711657984534`, 0.32468113599000714`, 0.9345460119926574],
              UndirectedEdge[275, 418] -> 
             RGBColor[
              0.48290882987898437`, 0.5910861687474542, 0.9524354985228551], 
             UndirectedEdge[10, 232] -> 
             RGBColor[
              0.2526232272726644, 0.38285340747425656`, 0.9376978911193801], 
             UndirectedEdge[5, 431] -> 
             RGBColor[
              0.5554141285415004, 0.6483552608910543, 0.9588784790444786], 
             UndirectedEdge[42, 416] -> 
             RGBColor[
              0.20488956233917005`, 0.3326822991399955, 0.9349795295170467], 
             UndirectedEdge[37, 97] -> 
             RGBColor[
              0.9251557778239836, 0.7191603787632175, 0.30804891163954246`], 
             UndirectedEdge[441, 450] -> 
             RGBColor[
              0.21849705952285933`, 0.34698464144520536`, 0.9357544563511697],
              UndirectedEdge[5, 259] -> 
             RGBColor[
              0.686424746410886, 0.7549594960082611, 0.969380061784424], 
             UndirectedEdge[279, 318] -> 
             RGBColor[
              0.20298181137445004`, 0.33067713191767734`, 0.9348708859218705],
              UndirectedEdge[275, 355] -> 
             RGBColor[
              0.5245111056702372, 0.6248607703959599, 0.9557105820673001], 
             UndirectedEdge[344, 387] -> 
             RGBColor[
              0.1895833056665427, 0.31659445290433924`, 0.9341078608431181], 
             UndirectedEdge[239, 489] -> 
             RGBColor[
              0.1941327088524955, 0.32137616410159764`, 0.9343669426243193], 
             UndirectedEdge[21, 336] -> 
             RGBColor[
              0.4626767064166898, 0.5696895855885848, 0.9520225624103578], 
             UndirectedEdge[32, 312] -> 
             RGBColor[
              0.20732064752653726`, 0.335237523811622, 0.935117976221999], 
             UndirectedEdge[77, 436] -> 
             RGBColor[
              0.3449944123676427, 0.4732385528946725, 0.9432037167828538], 
             UndirectedEdge[66, 294] -> 
             RGBColor[
              0.19268716813915449`, 0.3198568091593014, 0.9342846212191803], 
             UndirectedEdge[197, 201] -> 
             RGBColor[
              0.2441727010346539, 0.373971368603798, 0.9372166461515588], 
             UndirectedEdge[228, 256] -> 
             RGBColor[
              0.28488710481113977`, 0.4165048432644388, 0.9395447890804083], 
             UndirectedEdge[292, 481] -> 
             RGBColor[
              0.1951943467181843, 0.32249201281016504`, 0.9344274013302178], 
             UndirectedEdge[444, 486] -> 
             RGBColor[
              0.4895993510327964, 0.5954321921343623, 0.953262167276795], 
             UndirectedEdge[154, 244] -> 
             RGBColor[
              0.7150943787471429, 0.7742699758488314, 0.9312778860004862], 
             UndirectedEdge[288, 386] -> 
             RGBColor[
              0.5084129263265404, 0.6064351624645463, 0.9562833697364408], 
             UndirectedEdge[273, 285] -> 
             RGBColor[
              0.20077325282687788`, 0.3283557968534793, 0.934745111779856], 
             UndirectedEdge[190, 487] -> 
             RGBColor[
              0.2046420322637051, 0.3324221293363686, 0.9349654330454369], 
             UndirectedEdge[83, 343] -> 
             RGBColor[
              0.920728738466214, 0.6743242594892878, 0.4603352612449215], 
             UndirectedEdge[1, 315] -> 
             RGBColor[
              0.19134373832478055`, 0.31844477924602455`, 0.934208114878678], 
             UndirectedEdge[4, 429] -> 
             RGBColor[
              0.18673058009120463`, 0.3135960574514107, 0.9339454023418319], 
             UndirectedEdge[189, 451] -> 
             RGBColor[
              0.22852938408198586`, 0.3575292506429629, 0.9363257823933178], 
             UndirectedEdge[10, 102] -> 
             RGBColor[
              0.21311463700569694`, 0.34132737411436953`, 0.9354479353513978],
              UndirectedEdge[357, 368] -> 
             RGBColor[
              0.18388810829963448`, 0.3106084393753497, 0.9337835277783622], 
             UndirectedEdge[128, 138] -> 
             RGBColor[
              0.18851306554638397`, 0.31546956268090953`, 0.9340469122515535],
              UndirectedEdge[336, 436] -> 
             RGBColor[
              0.49043574205618756`, 0.5945414342179349, 0.953761745333046], 
             UndirectedEdge[196, 454] -> 
             RGBColor[
              0.20169424196759916`, 0.3293238148344616, 0.9347975607489386], 
             UndirectedEdge[25, 164] -> 
             RGBColor[
              0.3024600979339018, 0.4345620939070181, 0.9405606698993174], 
             UndirectedEdge[125, 282] -> 
             RGBColor[
              0.7373315894354715, 0.794728308685404, 0.9744539801456191], 
             UndirectedEdge[9, 286] -> 
             RGBColor[
              0.19059390233229334`, 0.3176566540755726, 0.9341654128281889], 
             UndirectedEdge[421, 477] -> 
             RGBColor[
              0.1910652466541582, 0.31815206684280867`, 0.9341922551900277], 
             UndirectedEdge[105, 484] -> 
             RGBColor[
              0.1881185665568436, 0.315054919230222, 0.9340244461177081], 
             UndirectedEdge[299, 475] -> 
             RGBColor[
              0.28830100074598397`, 0.41778431854565623`, 0.939823739896893], 
             UndirectedEdge[247, 252] -> 
             RGBColor[
              0.18329308738435063`, 0.3099830346668814, 0.9337496422174913], 
             UndirectedEdge[261, 478] -> 
             RGBColor[
              0.2893032374986769, 0.41950673564807195`, 0.9398563203301515], 
             UndirectedEdge[104, 303] -> 
             RGBColor[
              0.8824648742106225, 0.5257558359619144, 0.2222571743069387], 
             UndirectedEdge[32, 66] -> 
             RGBColor[
              0.20877736241614875`, 0.33676862352166215`, 0.9352009339799459],
              UndirectedEdge[213, 454] -> 
             RGBColor[
              0.20680491942710666`, 0.3346954608800703, 0.9350886062696878], 
             UndirectedEdge[129, 331] -> 
             RGBColor[
              0.2954052676483876, 0.42782004444717026`, 0.9401342650284206], 
             UndirectedEdge[245, 475] -> 
             RGBColor[
              0.2902269064135576, 0.4198085675117481, 0.9399334173755393], 
             UndirectedEdge[90, 148] -> 
             RGBColor[
              0.26849318417245727`, 0.3995337383893224, 0.9386016616873261], 
             UndirectedEdge[195, 496] -> 
             RGBColor[
              0.18695506079229124`, 0.31383200090115126`, 0.9339581861856694],
              UndirectedEdge[241, 371] -> 
             RGBColor[
              0.2348560709776379, 0.3641789997054109, 0.9366860778525307], 
             UndirectedEdge[13, 243] -> 
             RGBColor[
              0.2247623131438397, 0.3535698202408788, 0.9361112532762724], 
             UndirectedEdge[246, 384] -> 
             RGBColor[
              0.2539870125967417, 0.38428683231884564`, 0.9377755566760467], 
             UndirectedEdge[22, 268] -> 
             RGBColor[
              0.1840499075552901, 0.3107785006517091, 0.9337927420066112], 
             UndirectedEdge[69, 306] -> 
             RGBColor[
              0.3418131212888621, 0.4641982370033755, 0.9432311265611506], 
             UndirectedEdge[66, 128] -> 
             RGBColor[
              0.19606919376904863`, 0.32341153252913013`, 0.9344772225755442],
              UndirectedEdge[220, 413] -> 
             RGBColor[
              0.2236716605546839, 0.35242347521830786`, 0.9360491422247958], 
             UndirectedEdge[319, 492] -> 
             RGBColor[
              0.18173579190696668`, 0.3083462183819148, 0.9336609565438665], 
             UndirectedEdge[61, 186] -> 
             RGBColor[
              0.9917911303595999, 0.9891836280481643, 0.6628745668001933], 
             UndirectedEdge[94, 401] -> 
             RGBColor[
              0.17982716171712376`, 0.30634012703824637`, 0.9335522628781203],
              UndirectedEdge[429, 488] -> 
             RGBColor[
              0.1872389149746237, 0.3141303496441773, 0.9339743512614285], 
             UndirectedEdge[11, 431] -> 
             RGBColor[
              0.3984128235048672, 0.519506895734326, 0.9466074907044714], 
             UndirectedEdge[349, 487] -> 
             RGBColor[
              0.1889676303182698, 0.3159473390772327, 0.9340727990428441], 
             UndirectedEdge[156, 198] -> 
             RGBColor[
              0.19090321227565094`, 0.31798175843742454`, 0.93418302757188], 
             UndirectedEdge[12, 188] -> 
             RGBColor[
              0.20900601855676193`, 0.3370089556230833, 0.9352139556088873], 
             UndirectedEdge[70, 111] -> 
             RGBColor[
              0.36816732392345053`, 0.4933097641799131, 0.9446802742161886], 
             UndirectedEdge[212, 286] -> 
             RGBColor[
              0.18467080520712215`, 0.3114311034509694, 0.9338281012093472], 
             UndirectedEdge[242, 282] -> 
             RGBColor[
              0.8349131599958114, 0.8712326557093291, 0.9504012848257013], 
             UndirectedEdge[70, 175] -> 
             RGBColor[
              0.3837102779939304, 0.5067722897841764, 0.945670657505465], 
             UndirectedEdge[188, 298] -> 
             RGBColor[
              0.24983259130122784`, 0.37992027213173674`, 0.9375389685291828],
              UndirectedEdge[286, 367] -> 
             RGBColor[
              0.1922727390163294, 0.3194212178748882, 0.9342610200937285], 
             UndirectedEdge[9, 492] -> 
             RGBColor[
              0.18820033017206594`, 0.3151408579739333, 0.9340291024346365], 
             UndirectedEdge[37, 343] -> 
             RGBColor[
              0.8540426861772787, 0.4109754374687308, 0.1991721784497092], 
             UndirectedEdge[376, 391] -> 
             RGBColor[
              0.4221118184289103, 0.5394962463103177, 0.9482660902046844], 
             UndirectedEdge[230, 490] -> 
             RGBColor[
              0.21093312852044277`, 0.33903447038074064`, 0.9353237016704152],
              UndirectedEdge[346, 355] -> 
             RGBColor[
              0.5005625797661037, 0.605095092452838, 0.9539145635661582], 
             UndirectedEdge[30, 465] -> 
             RGBColor[
              0.17899164586466354`, 0.3054619469025459, 0.9335046814863577], 
             UndirectedEdge[119, 124] -> 
             RGBColor[
              0.18484388120986256`, 0.311613017303502, 0.9338379576316604], 
             UndirectedEdge[301, 436] -> 
             RGBColor[
              0.5059845229884368, 0.6069488070899312, 0.9551333650755793], 
             UndirectedEdge[39, 108] -> 
             RGBColor[
              0.22860230621824829`, 0.3576058964317052, 0.9363299352010993], 
             UndirectedEdge[98, 382] -> 
             RGBColor[
              0.20018581629901203`, 0.3277383638170652, 0.9347116581386283], 
             UndirectedEdge[81, 208] -> 
             RGBColor[
              0.3324858109628042, 0.4558962797557328, 0.942644967739437], 
             UndirectedEdge[154, 203] -> 
             RGBColor[
              0.9142690676811895, 0.6673158743356673, 0.5518317374650853], 
             UndirectedEdge[145, 367] -> 
             RGBColor[
              0.2030970423728074, 0.33079824700301824`, 0.9348774481567581], 
             UndirectedEdge[44, 132] -> 
             RGBColor[
              0.27566251602704606`, 0.4070691607303891, 0.9390099445303688], 
             UndirectedEdge[319, 357] -> 
             RGBColor[
              0.18470360051772483`, 0.3114655734017556, 0.9338299688537698], 
             UndirectedEdge[364, 378] -> 
             RGBColor[
              0.20567802361676119`, 0.3335110219340761, 0.9350244312203816], 
             UndirectedEdge[213, 251] -> 
             RGBColor[
              0.22057376513923174`, 0.3491673907187537, 0.9358727216638114], 
             UndirectedEdge[73, 136] -> 
             RGBColor[
              0.5525602908951197, 0.647632362562914, 0.9579187166757537], 
             UndirectedEdge[441, 461] -> 
             RGBColor[
              0.2373696075780963, 0.3668208860399178, 0.9368292200434826], 
             UndirectedEdge[90, 480] -> 
             RGBColor[
              0.2528560578238772, 0.3830981271458908, 0.9377111504748298], 
             UndirectedEdge[118, 446] -> 
             RGBColor[
              0.18780907665371493`, 0.3147296257192406, 0.9340068211255742], 
             UndirectedEdge[210, 480] -> 
             RGBColor[
              0.21944240212988145`, 0.3479782564633687, 0.9358082922141305], 
             UndirectedEdge[95, 492] -> 
             RGBColor[
              0.18364470169108055`, 0.3103526035968892, 0.9337696661320929], 
             UndirectedEdge[261, 328] -> 
             RGBColor[
              0.28613962453427205`, 0.41618157783783527`, 0.9396761572519747],
              UndirectedEdge[152, 496] -> 
             RGBColor[
              0.1850253408084585, 0.31180374284682943`, 0.9338482914873549], 
             UndirectedEdge[86, 177] -> 
             RGBColor[
              0.1848471163861694, 0.31161641767892256`, 0.933838141870165], 
             UndirectedEdge[45, 217] -> 
             RGBColor[
              0.19120987418842403`, 0.31830407955123735`, 0.9342004915141469],
              UndirectedEdge[306, 331] -> 
             RGBColor[
              0.2711023891418522, 0.40227617824530654`, 0.9387502520503602], 
             UndirectedEdge[103, 129] -> 
             RGBColor[
              0.3495899489939847, 0.47542806862452014`, 0.9435621141955579], 
             UndirectedEdge[50, 126] -> 
             RGBColor[
              0.6844097961772514, 0.7515158315979785, 0.9706616235238129], 
             UndirectedEdge[172, 308] -> 
             RGBColor[
              0.207198246316672, 0.3351088723793687, 0.9351110056541736], 
             UndirectedEdge[112, 266] -> 
             RGBColor[
              0.9935124253020141, 0.9901198523525236, 0.6506615550659651], 
             UndirectedEdge[129, 275] -> 
             RGBColor[
              0.3893440856753081, 0.5088837722097477, 0.9463652522390695], 
             UndirectedEdge[297, 325] -> 
             RGBColor[
              0.21444902327045198`, 0.3427298986836028, 0.9355239266751281], 
             UndirectedEdge[202, 396] -> 
             RGBColor[
              0.1920993256937792, 0.31923894947784826`, 0.9342511444615511], 
             UndirectedEdge[167, 236] -> 
             RGBColor[
              0.22411127044535895`, 0.3528855330862843, 0.9360741773577252], 
             UndirectedEdge[184, 301] -> 
             RGBColor[
              0.5986418341837841, 0.6848276074011173, 0.9616939873161781], 
             UndirectedEdge[78, 258] -> 
             RGBColor[
              0.44262074177976496`, 0.5573429685234437, 0.9495499886233556], 
             UndirectedEdge[172, 470] -> 
             RGBColor[
              0.2090529849214024, 0.33705832025015997`, 0.9352166302738731], 
             UndirectedEdge[72, 159] -> 
             RGBColor[
              0.22161615608300847`, 0.35026300969206614`, 0.9359320842859804],
              UndirectedEdge[304, 337] -> 
             RGBColor[
              0.1898974932161501, 0.3169246839396178, 0.9341257533592695], 
             UndirectedEdge[88, 271] -> 
             RGBColor[
              0.19882737388287028`, 0.32631055470747644`, 0.9346342968526646],
              UndirectedEdge[392, 413] -> 
             RGBColor[
              0.23358028524334118`, 0.3628380680091775, 0.9366134237423184], 
             UndirectedEdge[187, 216] -> 
             RGBColor[
              0.21058067829644372`, 0.3386640228486828, 0.9353036301515618], 
             UndirectedEdge[33, 432] -> 
             RGBColor[
              0.27375220804932543`, 0.40506130592528333`, 0.9389011553170851],
              UndirectedEdge[36, 75] -> 
             RGBColor[
              0.929724921483118, 0.7365825483050892, 0.4781251750142107], 
             UndirectedEdge[243, 335] -> 
             RGBColor[
              0.2034771985235191, 0.3311978152207083, 0.9348990974871504], 
             UndirectedEdge[323, 499] -> 
             RGBColor[
              0.8106414871808013, 0.8502981241426343, 0.8671892234801464], 
             UndirectedEdge[168, 480] -> 
             RGBColor[
              0.26803681984078476`, 0.3990540705415648, 0.9385756724137677], 
             UndirectedEdge[301, 388] -> 
             RGBColor[
              0.4925680533292166, 0.5953281354024867, 0.9542784794926122], 
             UndirectedEdge[111, 371] -> 
             RGBColor[
              0.3103368514001098, 0.4381658734848475, 0.9411804208813801], 
             UndirectedEdge[103, 231] -> 
             RGBColor[
              0.5867310207555722, 0.6723340507666251, 0.9622056389073572], 
             UndirectedEdge[99, 131] -> 
             RGBColor[
              0.9067135965497277, 0.6223214351513566, 0.549591400192696], 
             UndirectedEdge[193, 428] -> 
             RGBColor[
              0.18434895637471288`, 0.31109281992171267`, 0.9338097723944743],
              UndirectedEdge[189, 370] -> 
             RGBColor[
              0.24036595787050763`, 0.36997024017682334`, 0.9369998577599323],
              UndirectedEdge[45, 187] -> 
             RGBColor[
              0.21121178851668337`, 0.3393273597048538, 0.9353395709449606], 
             UndirectedEdge[346, 443] -> 
             RGBColor[
              0.3646259972920919, 0.4883092353080305, 0.9445254082932095], 
             UndirectedEdge[19, 318] -> 
             RGBColor[
              0.20059929205314941`, 0.3281729530505406, 0.9347352049711439], 
             UndirectedEdge[5, 129] -> 
             RGBColor[
              0.4894760344411281, 0.5894520908087815, 0.9547425358777173], 
             UndirectedEdge[29, 46] -> 
             RGBColor[
              0.19406985648437775`, 0.32131010227763557`, 0.9343633632749366],
              UndirectedEdge[227, 263] -> 
             RGBColor[
              0.2087485483203887, 0.3367383380800992, 0.935199293059819], 
             UndirectedEdge[272, 435] -> 
             RGBColor[
              0.24781268178209245`, 0.377797219157465, 0.9374239376702564], 
             UndirectedEdge[208, 483] -> 
             RGBColor[
              0.4393277460874472, 0.554945345231554, 0.949214553391788], 
             UndirectedEdge[244, 475] -> 
             RGBColor[
              0.39162513268333266`, 0.5136277391039731, 0.9461749850474426], 
             UndirectedEdge[350, 412] -> 
             RGBColor[
              0.18588998404715956`, 0.3127125377122519, 0.9338975316406739], 
             UndirectedEdge[217, 398] -> 
             RGBColor[
              0.1937507850823029, 0.3209747380037596, 0.9343451926306123], 
             UndirectedEdge[370, 451] -> 
             RGBColor[
              0.21692330433294027`, 0.34533052495875827`, 0.935664833321266], 
             UndirectedEdge[265, 424] -> 
             RGBColor[
              0.18889724072199854`, 0.3158733551485935, 0.9340687904594684], 
             UndirectedEdge[28, 419] -> 
             RGBColor[
              0.5625638978028586, 0.6556476235991, 0.9587787905130681], 
             UndirectedEdge[67, 381] -> 
             RGBColor[
              0.18458590754106158`, 0.31134187062111685`, 0.93382326641286], 
             UndirectedEdge[239, 435] -> 
             RGBColor[
              0.21752143841029148`, 0.3459592017979452, 0.9356988961721111], 
             UndirectedEdge[302, 370] -> 
             RGBColor[
              0.23676036432994563`, 0.36618053275785845`, 0.936794524541795], 
             UndirectedEdge[2, 66] -> 
             RGBColor[
              0.19103840083759993`, 0.31812385018748285`, 0.9341907263604894],
              UndirectedEdge[36, 408] -> 
             RGBColor[
              0.9657078104957213, 0.9722942089440085, 0.8689827508705463], 
             UndirectedEdge[76, 483] -> 
             RGBColor[
              0.43123446241891855`, 0.5479353496981393, 0.948698856513039], 
             UndirectedEdge[9, 367] -> 
             RGBColor[
              0.19547077493947268`, 0.3227825563973006, 0.9344431435084812], 
             UndirectedEdge[133, 469] -> 
             RGBColor[
              0.18966655655355485`, 0.31668195486500017`, 0.9341126018579748],
              UndirectedEdge[46, 297] -> 
             RGBColor[
              0.19948643535294036`, 0.32700327009943075`, 0.934671829428391], 
             UndirectedEdge[159, 435] -> 
             RGBColor[
              0.23525737339525699`, 0.3646007939903714, 0.9367089314315404], 
             UndirectedEdge[126, 340] -> 
             RGBColor[
              0.4261246264730337, 0.5425553802981693, 0.948636879181104], 
             UndirectedEdge[27, 290] -> 
             RGBColor[
              0.18336907213961767`, 0.31006289946237875`, 0.9337539694368944],
              UndirectedEdge[326, 338] -> 
             RGBColor[
              0.5748571876552486, 0.6636751524188924, 0.9607610097179233], 
             UndirectedEdge[179, 438] -> 
             RGBColor[
              0.20137694299580192`, 0.3289903134971859, 0.9347794910418965], 
             UndirectedEdge[138, 339] -> 
             RGBColor[
              0.1814781394477339, 0.3080754093111516, 0.9336462836174759], 
             UndirectedEdge[475, 482] -> 
             RGBColor[
              0.3344502958688525, 0.46410576914612495`, 0.942531855003347], 
             UndirectedEdge[94, 428] -> 
             RGBColor[
              0.18335052254202558`, 0.31004340265919705`, 0.9337529130647533],
              UndirectedEdge[186, 295] -> 
             RGBColor[
              0.9890595681546568, 0.9880540568784736, 0.7081436215924831], 
             UndirectedEdge[348, 372] -> 
             RGBColor[
              0.5381758194150634, 0.6359544006023488, 0.9567863183887886], 
             UndirectedEdge[293, 343] -> 
             RGBColor[
              0.8279897500301316, 0.6038277857603807, 0.5867878259844261], 
             UndirectedEdge[385, 446] -> 
             RGBColor[
              0.18248129368631721`, 0.30912978801955504`, 0.9337034117673295],
              UndirectedEdge[7, 288] -> 
             RGBColor[
              0.5917887149964642, 0.6784248496808247, 0.9617281729213873], 
             UndirectedEdge[242, 323] -> 
             RGBColor[
              0.9829115082024764, 0.98536084245597, 0.8504363857845441], 
             UndirectedEdge[464, 481] -> 
             RGBColor[
              0.2038613891913174, 0.3316016239716596, 0.9349209765773223], 
             UndirectedEdge[42, 108] -> 
             RGBColor[
              0.2050818952093152, 0.3328844531811263, 0.9349904825894705], 
             UndirectedEdge[101, 276] -> 
             RGBColor[
              0.22935486634297414`, 0.3583968848378599, 0.9363727923868895], 
             UndirectedEdge[86, 426] -> 
             RGBColor[
              0.1863343941921356, 0.31317964095185236`, 0.9339228401409845], 
             UndirectedEdge[37, 324] -> 
             RGBColor[
              0.9007937640631225, 0.7100849667901136, 0.5966707240103046], 
             UndirectedEdge[290, 297] -> 
             RGBColor[
              0.18839455558370108`, 0.3153450011961642, 0.9340401632844985], 
             UndirectedEdge[315, 380] -> 
             RGBColor[
              0.18543946082278231`, 0.31223900923860914`, 0.9338718750095351],
              UndirectedEdge[181, 390] -> 
             RGBColor[
              0.24071562353706022`, 0.37033776096245374`, 0.9370197707023586],
              UndirectedEdge[283, 421] -> 
             RGBColor[
              0.18332707368146411`, 0.3100187564200033, 0.9337515776868337], 
             UndirectedEdge[97, 355] -> 
             RGBColor[
              0.7740833188183651, 0.8130804459299827, 0.6840694071044306], 
             UndirectedEdge[192, 219] -> 
             RGBColor[
              0.49125780976030897`, 0.5936378228658237, 0.9544300827546521], 
             UndirectedEdge[171, 192] -> 
             RGBColor[
              0.3918420426717766, 0.5133437939110442, 0.9463191721078775], 
             UndirectedEdge[122, 216] -> 
             RGBColor[
              0.19279683115434215`, 0.3199720719413004, 0.9342908663656634], 
             UndirectedEdge[18, 28] -> 
             RGBColor[
              0.38207742266917044`, 0.5028572911387341, 0.9458047612186589], 
             UndirectedEdge[178, 288] -> 
             RGBColor[
              0.5902663931329839, 0.677188960212233, 0.9616083301678455], 
             UndirectedEdge[165, 185] -> 
             RGBColor[
              0.2587337613234965, 0.38927596619191684`, 0.93804587699385], 
             UndirectedEdge[264, 281] -> 
             RGBColor[
              0.8419839123581961, 0.3124840077358858, 0.18739747519941907`], 
             UndirectedEdge[80, 192] -> 
             RGBColor[
              0.3302026401393104, 0.46042666324658016`, 0.9422611981363149], 
             UndirectedEdge[74, 402] -> 
             RGBColor[
              0.20341804022375085`, 0.331135636096799, 0.9348957285094954], 
             UndirectedEdge[3, 158] -> 
             RGBColor[
              0.187682952058607, 0.31459706077302096`, 0.9339996385164674], 
             UndirectedEdge[426, 476] -> 
             RGBColor[
              0.1853934884122734, 0.3121906893203451, 0.9338692569487667], 
             UndirectedEdge[27, 177] -> 
             RGBColor[
              0.18479696914654997`, 0.31156370975056386`, 0.9338352860590549],
              UndirectedEdge[355, 443] -> 
             RGBColor[
              0.4237732599016528, 0.5366508333936366, 0.9490924002850236], 
             UndirectedEdge[21, 256] -> 
             RGBColor[
              0.3057801725853121, 0.43846478219210167`, 0.9407346183816234], 
             UndirectedEdge[331, 404] -> 
             RGBColor[
              0.5691308396856145, 0.6534422515230649, 0.9623880647122928], 
             UndirectedEdge[142, 285] -> 
             RGBColor[
              0.2150502131881199, 0.3433617874047141, 0.9355581635515585], 
             UndirectedEdge[232, 267] -> 
             RGBColor[
              0.25385827815003914`, 0.3841515242531258, 0.9377682254397526], 
             UndirectedEdge[133, 488] -> 
             RGBColor[
              0.19025464326071956`, 0.31730007128108106`, 0.9341460925259515],
              UndirectedEdge[148, 393] -> 
             RGBColor[
              0.24797563185424576`, 0.37796849001492944`, 0.9374332174358024],
              UndirectedEdge[84, 89] -> 
             RGBColor[
              0.2925984761880414, 0.42478343593361145`, 0.9399775893294924], 
             UndirectedEdge[27, 350] -> 
             RGBColor[
              0.18336792975933797`, 0.3100616987482737, 0.9337539043800275], 
             UndirectedEdge[8, 435] -> 
             RGBColor[
              0.21794255850182165`, 0.34640182571469935`, 0.9357228783383325],
              UndirectedEdge[20, 220] -> 
             RGBColor[
              0.2293954500117661, 0.35843954084691343`, 0.9363751035667891], 
             UndirectedEdge[35, 422] -> 
             RGBColor[
              0.19709463641182273`, 0.32448933776350447`, 0.9345356200170438],
              UndirectedEdge[65, 177] -> 
             RGBColor[
              0.18378082822451933`, 0.3104956812144541, 0.9337774183367911], 
             UndirectedEdge[93, 160] -> 
             RGBColor[
              0.23103960685447572`, 0.36016765393416605`, 0.9364687358666692],
              UndirectedEdge[277, 373] -> 
             RGBColor[
              0.7171130809828956, 0.774434213301909, 0.8741433170431847], 
             UndirectedEdge[15, 126] -> 
             RGBColor[
              0.5704313985291926, 0.6619870174784861, 0.9594308284953961], 
             UndirectedEdge[95, 367] -> 
             RGBColor[
              0.19091514645848728`, 0.31799430202025647`, 0.9341837072059376],
              UndirectedEdge[304, 465] -> 
             RGBColor[
              0.18487917380697239`, 0.31165011206074433`, 0.933839967492855], 
             UndirectedEdge[218, 305] -> 
             RGBColor[
              0.29821563929003225`, 0.43060670099699316`, 0.9403004343609631],
              UndirectedEdge[137, 265] -> 
             RGBColor[
              0.19798921213274367`, 0.325429593565569, 0.934586564780944], 
             UndirectedEdge[325, 392] -> 
             RGBColor[
              0.23524305947406288`, 0.3645857491516413, 0.9367081162749039], 
             UndirectedEdge[263, 393] -> 
             RGBColor[
              0.22282702878996197`, 0.35153571368083814`, 0.9360010416953157],
              UndirectedEdge[228, 335] -> 
             RGBColor[
              0.2342958788041693, 0.36359020221286015`, 0.9366541757369817], 
             UndirectedEdge[104, 408] -> 
             RGBColor[
              0.9307079198191593, 0.8448308855634613, 0.624429309131783], 
             UndirectedEdge[145, 375] -> 
             RGBColor[
              0.20589359976284474`, 0.33373760613192704`, 0.9350367079629848],
              UndirectedEdge[181, 451] -> 
             RGBColor[
              0.21530209522723562`, 0.3436265313980684, 0.93557250786106], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.20367497522683542`, 0.331405691075661, 0.93491036057782], 
             UndirectedEdge[387, 439] -> 
             RGBColor[
              0.1940605439508961, 0.3213003142144977, 0.9343628329399316], 
             UndirectedEdge[163, 231] -> 
             RGBColor[
              0.8314832405552138, 0.7254800292683178, 0.607385428867296], 
             UndirectedEdge[143, 288] -> 
             RGBColor[
              0.6459376056374727, 0.7223853584829198, 0.9659909719465696], 
             UndirectedEdge[128, 312] -> 
             RGBColor[
              0.19461247887943717`, 0.32188043281908996`, 0.9343942648175974],
              UndirectedEdge[270, 479] -> 
             RGBColor[
              0.18121603188329788`, 0.30779991764234993`, 0.9336313569794346],
              UndirectedEdge[119, 120] -> 
             RGBColor[
              0.18211134871711507`, 0.30874095240105776`, 0.9336823439486179],
              UndirectedEdge[105, 462] -> 
             RGBColor[
              0.19074614489061564`, 0.31781667065710506`, 0.9341740828166627],
              UndirectedEdge[14, 159] -> 
             RGBColor[
              0.2315482163827265, 0.3607022347960642, 0.9364977004268829], 
             UndirectedEdge[58, 417] -> 
             RGBColor[
              0.19514933346569613`, 0.3224447010277949, 0.9344248378920796], 
             UndirectedEdge[66, 299] -> 
             RGBColor[
              0.21897785763056482`, 0.34748999074076453`, 0.9357818370921265],
              UndirectedEdge[11, 348] -> 
             RGBColor[
              0.41882704946853977`, 0.5369507513572022, 0.9479740053732437], 
             UndirectedEdge[4, 31] -> 
             RGBColor[
              0.18674651901237604`, 0.3136128102681478, 0.9339463100398131], 
             UndirectedEdge[259, 400] -> 
             RGBColor[
              0.8365707919285453, 0.8712879121400499, 0.8933185067355665], 
             UndirectedEdge[247, 451] -> 
             RGBColor[
              0.19468301666075716`, 0.32195457249961096`, 0.9343982818398924],
              UndirectedEdge[17, 261] -> 
             RGBColor[
              0.3523681166453383, 0.4796252849268593, 0.9436735626991177], 
             UndirectedEdge[361, 386] -> 
             RGBColor[
              0.26785160184799417`, 0.39885939468764287`, 0.9385651245230838],
              UndirectedEdge[212, 492] -> 
             RGBColor[
              0.18227723304689475`, 0.30891530734933015`, 0.933691790815795], 
             UndirectedEdge[287, 388] -> 
             RGBColor[
              0.31642089310081123`, 0.44806502999070874`, 0.9413985832331735],
              UndirectedEdge[383, 480] -> 
             RGBColor[
              0.2555678088390552, 0.3859483493977877, 0.937865580683468], 
             UndirectedEdge[403, 440] -> 
             RGBColor[
              0.8175206971599966, 0.7001431418216288, 0.6031737768596591], 
             UndirectedEdge[13, 354] -> 
             RGBColor[
              0.28176652075351294`, 0.4133145757884693, 0.9393637933883066], 
             UndirectedEdge[1, 42] -> 
             RGBColor[
              0.19991385155278849`, 0.32745251162522343`, 0.9346961701486667],
              UndirectedEdge[161, 188] -> 
             RGBColor[
              0.2189136351360459, 0.34742248882708376`, 0.9357781797160722], 
             UndirectedEdge[194, 426] -> 
             RGBColor[
              0.18673198964571103`, 0.31359753898256787`, 0.9339454826138758],
              UndirectedEdge[257, 324] -> 
             RGBColor[
              0.9513926924014826, 0.9208016602260798, 0.6489338534613713], 
             UndirectedEdge[198, 479] -> 
             RGBColor[
              0.18236486345397498`, 0.30900741246326024`, 0.9336967812378407],
              UndirectedEdge[372, 431] -> 
             RGBColor[
              0.5177615934513908, 0.6185105449794727, 0.9554198037200161], 
             UndirectedEdge[107, 466] -> 
             RGBColor[
              0.20308636910120992`, 0.33078702871784477`, 0.9348768403297303],
              UndirectedEdge[122, 330] -> 
             RGBColor[
              0.18762963037517022`, 0.3145410163029389, 0.9339966019254781], 
             UndirectedEdge[4, 472] -> 
             RGBColor[
              0.18232394464799978`, 0.30896440420377813`, 0.9336944509723744],
              UndirectedEdge[145, 458] -> 
             RGBColor[
              0.2240333301287531, 0.35280361287183004`, 0.936069738771997], 
             UndirectedEdge[3, 451] -> 
             RGBColor[
              0.19437267435842231`, 0.32162838306301855`, 0.9343806083048847],
              UndirectedEdge[146, 239] -> 
             RGBColor[
              0.18835872742063176`, 0.3153073435251416, 0.9340381229236147], 
             UndirectedEdge[15, 282] -> 
             RGBColor[
              0.674559975761555, 0.7456906470014069, 0.9681974923286845], 
             UndirectedEdge[82, 126] -> 
             RGBColor[
              0.504289208348975, 0.6084437231644664, 0.9541186402349197], 
             UndirectedEdge[413, 474] -> 
             RGBColor[
              0.2299117533537109, 0.35898220839482003`, 0.9364045062783105], 
             UndirectedEdge[160, 235] -> 
             RGBColor[
              0.22828336996259535`, 0.35727067420528746`, 0.9363117722531638],
              UndirectedEdge[161, 183] -> 
             RGBColor[
              0.2054076978090161, 0.33322689237048986`, 0.9350090365655417], 
             UndirectedEdge[366, 429] -> 
             RGBColor[
              0.18725297443025463`, 0.3141451270234664, 0.9339751519266276], 
             UndirectedEdge[7, 313] -> 
             RGBColor[
              0.4167872287841039, 0.534905009234637, 0.9479211050634437], 
             UndirectedEdge[129, 444] -> 
             RGBColor[
              0.42761995292876165`, 0.539957845554271, 0.9493784687183828], 
             UndirectedEdge[18, 493] -> 
             RGBColor[
              0.274609024515375, 0.4059618743564031, 0.9389499497472802], 
             UndirectedEdge[149, 411] -> 
             RGBColor[
              0.4211694508709569, 0.5337442476409241, 0.9489595750460023], 
             UndirectedEdge[221, 301] -> 
             RGBColor[
              0.8093616863432395, 0.8079745679423065, 0.6371695161143949], 
             UndirectedEdge[45, 496] -> 
             RGBColor[
              0.19349628938952101`, 0.32070724689468694`, 0.9343306994774011],
              UndirectedEdge[478, 482] -> 
             RGBColor[
              0.2908428553905808, 0.4208402752825938, 0.939954423420793], 
             UndirectedEdge[69, 331] -> 
             RGBColor[
              0.37214546505797846`, 0.49607945348638943`, 0.9449585086661204],
              UndirectedEdge[16, 143] -> 
             RGBColor[
              0.42538425366010096`, 0.535839238383477, 0.9494121511680118], 
             UndirectedEdge[210, 280] -> 
             RGBColor[
              0.22449871038575198`, 0.3532927570287484, 0.9360962414891647], 
             UndirectedEdge[101, 390] -> 
             RGBColor[
              0.25051248587412484`, 0.3806348844356572, 0.9375776875192954], 
             UndirectedEdge[400, 418] -> 
             RGBColor[
              0.7331868241624636, 0.7879829034782768, 0.8847512271126452], 
             UndirectedEdge[84, 299] -> 
             RGBColor[
              0.2577944317187598, 0.3882886712204018, 0.9379923835624739], 
             UndirectedEdge[333, 386] -> 
             RGBColor[
              0.268695341419697, 0.3997462184736812, 0.9386131742434916], 
             UndirectedEdge[244, 341] -> 
             RGBColor[
              0.7205094989495678, 0.7757802394753833, 0.7851817105206231], 
             UndirectedEdge[143, 373] -> 
             RGBColor[
              0.7858256992864812, 0.8304922181829903, 0.8794769174192558], 
             UndirectedEdge[160, 284] -> 
             RGBColor[
              0.22313950665110643`, 0.35186414772514174`, 0.9360188368472383],
              UndirectedEdge[281, 343] -> 
             RGBColor[
              0.8323272687160201, 0.24948713001661726`, 0.17858993507187598`],
              UndirectedEdge[207, 445] -> 
             RGBColor[
              0.9190529143682962, 0.7062401460895815, 0.26431121911210875`], 
             UndirectedEdge[260, 334] -> 
             RGBColor[
              0.19830298963418935`, 0.3257593936142311, 0.9346044339454591], 
             UndirectedEdge[66, 114] -> 
             RGBColor[
              0.1896583133560848, 0.31667329074181017`, 0.9341121324200736], 
             UndirectedEdge[364, 381] -> 
             RGBColor[
              0.19634549402636683`, 0.3237019416180197, 0.9344929574664489], 
             UndirectedEdge[204, 306] -> 
             RGBColor[
              0.2783366060930942, 0.40921806996322074`, 0.9391864591429547], 
             UndirectedEdge[358, 361] -> 
             RGBColor[
              0.2274919045840746, 0.3564387939106588, 0.9362666994707252], 
             UndirectedEdge[294, 415] -> 
             RGBColor[
              0.18394556991543065`, 0.3106688351768284, 0.9337868001323749], 
             UndirectedEdge[2, 255] -> 
             RGBColor[
              0.19068245309328063`, 0.3177497265398128, 0.9341704556630279], 
             UndirectedEdge[326, 443] -> 
             RGBColor[
              0.5066093535132791, 0.6026290989849493, 0.956483102354086], 
             UndirectedEdge[58, 145] -> 
             RGBColor[
              0.20110599109187893`, 0.32870552586681995`, 0.9347640607318055],
              UndirectedEdge[103, 346] -> 
             RGBColor[
              0.4256097063793528, 0.5430634687251261, 0.9483404520319744], 
             UndirectedEdge[62, 108] -> 
             RGBColor[
              0.2304034031645468, 0.35949896351840704`, 0.9364325050077069], 
             UndirectedEdge[91, 336] -> 
             RGBColor[
              0.5428373971732765, 0.639738879428151, 0.957153294865837], 
             UndirectedEdge[338, 395] -> 
             RGBColor[
              0.4642366864681818, 0.5751402530845398, 0.9511830173068838], 
             UndirectedEdge[19, 335] -> 
             RGBColor[
              0.20679640724799403`, 0.3346865140401196, 0.9350881215136799], 
             UndirectedEdge[2, 195] -> 
             RGBColor[
              0.18614467853761885`, 0.312980237770288, 0.933912036115119], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.2086123729274203, 0.33659520910807084`, 0.9351915380726428], 
             UndirectedEdge[150, 325] -> 
             RGBColor[
              0.2244980131258032, 0.35329202416433336`, 0.9360962017812421], 
             UndirectedEdge[208, 238] -> 
             RGBColor[
              0.4566518822195865, 0.5690445386024363, 0.9505687908779773], 
             UndirectedEdge[318, 335] -> 
             RGBColor[
              0.2041779627078255, 0.33193436280942984`, 0.9349390049707589], 
             UndirectedEdge[12, 421] -> 
             RGBColor[
              0.18918604161445732`, 0.31617690319760183`, 0.9340852372430514],
              UndirectedEdge[102, 278] -> 
             RGBColor[
              0.19195325855915324`, 0.31908542365816517`, 0.9342428261543212],
              UndirectedEdge[5, 209] -> 
             RGBColor[
              0.8420261863364131, 0.8747026148224741, 0.8554514610488602], 
             UndirectedEdge[76, 463] -> 
             RGBColor[
              0.4827936292790318, 0.5898280832845495, 0.9527482010251842], 
             UndirectedEdge[293, 445] -> 
             RGBColor[
              0.8864338531014064, 0.8692772537699642, 0.6464479308964578], 
             UndirectedEdge[48, 250] -> 
             RGBColor[
              0.20476233546869063`, 0.33254857563247214`, 0.9349722841349881],
              UndirectedEdge[459, 477] -> 
             RGBColor[
              0.19613686914455325`, 0.32348266363965217`, 0.9344810765880625],
              UndirectedEdge[400, 404] -> 
             RGBColor[
              0.9133476519960143, 0.9314027140164651, 0.9009347805127319], 
             UndirectedEdge[144, 246] -> 
             RGBColor[
              0.21838885852257034`, 0.34687091533356196`, 0.9357482944642723],
              UndirectedEdge[90, 393] -> 
             RGBColor[
              0.24183341082623228`, 0.3715126262751811, 0.9370834270348589], 
             UndirectedEdge[157, 360] -> 
             RGBColor[
              0.44762961538947754`, 0.5573651742459853, 0.9508478770838158], 
             UndirectedEdge[156, 250] -> 
             RGBColor[
              0.20951821380303975`, 0.3375473053019756, 0.9352431243704379], 
             UndirectedEdge[25, 220] -> 
             RGBColor[
              0.25296409856661417`, 0.38321168481668605`, 0.9377173032352967],
              UndirectedEdge[261, 407] -> 
             RGBColor[
              0.30321117252682794`, 0.43412485717667065`, 0.9406483566550587],
              UndirectedEdge[42, 364] -> 
             RGBColor[
              0.2024710281446618, 0.33014026635764265`, 0.9348417975725702], 
             UndirectedEdge[83, 257] -> 
             RGBColor[
              0.9791397410141973, 0.9396620716614368, 0.5198667768744751], 
             UndirectedEdge[137, 263] -> 
             RGBColor[
              0.21799699214111928`, 0.34645903892089325`, 0.935725978253563], 
             UndirectedEdge[27, 65] -> 
             RGBColor[
              0.1841954077512366, 0.31093143058289413`, 0.9338010280275222], 
             UndirectedEdge[318, 421] -> 
             RGBColor[
              0.19115878724665003`, 0.3182503839363337, 0.9341975821883891], 
             UndirectedEdge[203, 341] -> 
             RGBColor[
              0.9196841878836145, 0.6688261379622193, 0.4057355619852222], 
             UndirectedEdge[80, 483] -> 
             RGBColor[
              0.3997284089104274, 0.520646389689377, 0.9466913186431871], 
             UndirectedEdge[95, 319] -> 
             RGBColor[
              0.18277177150935192`, 0.30943509862892227`, 0.9337199540496279],
              UndirectedEdge[84, 376] -> 
             RGBColor[
              0.3233121821951179, 0.4513861043611917, 0.9419346395171995], 
             UndirectedEdge[260, 446] -> 
             RGBColor[
              0.19657895504970424`, 0.32394732395583115`, 0.9345062527263533],
              UndirectedEdge[174, 393] -> 
             RGBColor[
              0.20439651484045512`, 0.33216407495782907`, 0.9349514511913933],
              UndirectedEdge[185, 216] -> 
             RGBColor[
              0.20572802131241785`, 0.3335635726822483, 0.9350272785151843], 
             UndirectedEdge[143, 321] -> 
             RGBColor[
              0.78304348190439, 0.8293416997957703, 0.9255854595882844], 
             UndirectedEdge[296, 415] -> 
             RGBColor[
              0.18131418208775438`, 0.30790307973031616`, 0.9336369464883782],
              UndirectedEdge[42, 113] -> 
             RGBColor[
              0.1986334681543265, 0.3261067474924436, 0.9346232542082819], 
             UndirectedEdge[54, 264] -> 
             RGBColor[
              0.9275346951808384, 0.7361423049047013, 0.5163860611032753], 
             UndirectedEdge[9, 95] -> 
             RGBColor[
              0.18923630977445122`, 0.3162297382209408, 0.934088099940398], 
             UndirectedEdge[47, 55] -> 
             RGBColor[
              0.42760134170853215`, 0.539013813149998, 0.94946155992206], 
             UndirectedEdge[212, 330] -> 
             RGBColor[
              0.18576322285580926`, 0.312579303663019, 0.9338903127783529], 
             UndirectedEdge[89, 244] -> 
             RGBColor[
              0.37820158055690994`, 0.5020009329394131, 0.945319648175928], 
             UndirectedEdge[3, 247] -> 
             RGBColor[
              0.18396896047476097`, 0.31069342013773166`, 0.9337881321901256],
              UndirectedEdge[26, 318] -> 
             RGBColor[
              0.1914380372433468, 0.3185438933883344, 0.9342134850625876], 
             UndirectedEdge[46, 426] -> 
             RGBColor[
              0.19553365018810587`, 0.3228486422701351, 0.9344467241608754], 
             UndirectedEdge[102, 247] -> 
             RGBColor[
              0.19186086570906943`, 0.31898831291468205`, 0.934237564518192], 
             UndirectedEdge[285, 287] -> 
             RGBColor[
              0.2592707940788048, 0.38984042166758914`, 0.938076460214796], 
             UndirectedEdge[346, 390] -> 
             RGBColor[
              0.34866455216030523`, 0.47153274446045024`, 0.9436164276057963],
              UndirectedEdge[388, 473] -> 
             RGBColor[
              0.2961409162225916, 0.4267494884669002, 0.9402436685514961], 
             UndirectedEdge[377, 412] -> 
             RGBColor[
              0.18552364470094684`, 0.3123274918321262, 0.9338766691568576], 
             UndirectedEdge[7, 321] -> 
             RGBColor[
              0.7288945912633815, 0.7853811909936754, 0.9213226605631021], 
             UndirectedEdge[209, 275] -> 
             RGBColor[
              0.7418942375705933, 0.7941342962234403, 0.8470741774102124], 
             UndirectedEdge[204, 346] -> 
             RGBColor[
              0.3786592419849977, 0.5023973362656904, 0.9453488099574316], 
             UndirectedEdge[220, 297] -> 
             RGBColor[
              0.20614792707638763`, 0.3340049202637436, 0.9350511915272475], 
             UndirectedEdge[16, 185] -> 
             RGBColor[
              0.2408288180096403, 0.3704567355300795, 0.9370262169601158], 
             UndirectedEdge[323, 449] -> 
             RGBColor[
              0.9881583833202512, 0.9738084894895631, 0.5806455490390734], 
             UndirectedEdge[224, 481] -> 
             RGBColor[
              0.20560152977914695`, 0.33343062206075413`, 0.9350200750094919],
              UndirectedEdge[86, 476] -> 
             RGBColor[
              0.18437093737264393`, 0.311115923344214, 0.9338110241797885], 
             UndirectedEdge[66, 385] -> 
             RGBColor[
              0.189718897172314, 0.31673696817390284`, 0.9341155825787821], 
             UndirectedEdge[184, 316] -> 
             RGBColor[
              0.4897742836055883, 0.5962632949587165, 0.9530855424591965], 
             UndirectedEdge[308, 362] -> 
             RGBColor[
              0.18507064546441102`, 0.3118513609127166, 0.9338508715204893], 
             UndirectedEdge[216, 361] -> 
             RGBColor[
              0.21500792746091607`, 0.34331734242435297`, 0.9355557554419504],
              UndirectedEdge[123, 410] -> 
             RGBColor[
              0.18404732868398718`, 0.3107757900944599, 0.9337925951437056], 
             UndirectedEdge[174, 225] -> 
             RGBColor[
              0.18572114805288265`, 0.3125350803774465, 0.9338879166805704], 
             UndirectedEdge[3, 139] -> 
             RGBColor[
              0.18312900664284068`, 0.3098105754042345, 0.933740298061998], 
             UndirectedEdge[226, 472] -> 
             RGBColor[
              0.18505776823943543`, 0.311837826132804, 0.933850138181577], 
             UndirectedEdge[9, 441] -> 
             RGBColor[
              0.2076297588947049, 0.33556241945835885`, 0.9351355796571268], 
             UndirectedEdge[253, 354] -> 
             RGBColor[
              0.34404011319445926`, 0.47241198691533204`, 0.9431429096833921],
              UndirectedEdge[47, 73] -> 
             RGBColor[
              0.42925393472115597`, 0.5403554626061129, 0.9495916580976614], 
             UndirectedEdge[305, 432] -> 
             RGBColor[
              0.30089384576863576`, 0.43342166581410385`, 0.9404529542578681],
              UndirectedEdge[4, 226] -> 
             RGBColor[
              0.18424586592068898`, 0.3109844653182212, 0.9338039015456263], 
             UndirectedEdge[112, 359] -> 
             RGBColor[
              0.9514837896604106, 0.9611256689561112, 0.8747939095613684], 
             UndirectedEdge[101, 204] -> 
             RGBColor[
              0.2805071756988172, 0.41149947624089733`, 0.9393100698709307], 
             UndirectedEdge[256, 409] -> 
             RGBColor[
              0.2823955714492146, 0.41388608372871627`, 0.93940289994134], 
             UndirectedEdge[64, 268] -> 
             RGBColor[
              0.18555371944787077`, 0.31235910229799235`, 0.9338783818692034],
              UndirectedEdge[97, 395] -> 
             RGBColor[
              0.7462989112429244, 0.7905238121869427, 0.6818821167624534], 
             UndirectedEdge[117, 156] -> 
             RGBColor[
              0.19147940284680726`, 0.31858737126030207`, 0.9342158407725099],
              UndirectedEdge[48, 117] -> 
             RGBColor[
              0.18672352451245816`, 0.31358864159079863`, 0.9339450005370601],
              UndirectedEdge[5, 103] -> 
             RGBColor[
              0.5496901810493061, 0.6433974652672816, 0.958513754171764], 
             UndirectedEdge[344, 438] -> 
             RGBColor[
              0.19645882867909248`, 0.32382106352386636`, 0.934499411707258], 
             UndirectedEdge[42, 381] -> 
             RGBColor[
              0.19442462278648562`, 0.3216829841546337, 0.9343835666910121], 
             UndirectedEdge[224, 398] -> 
             RGBColor[
              0.2060967195595755, 0.33395109791683003`, 0.9350482753349197], 
             UndirectedEdge[226, 405] -> 
             RGBColor[
              0.18431945622850954`, 0.3110618133976357, 0.9338080924047896], 
             UndirectedEdge[231, 346] -> 
             RGBColor[
              0.6025366315327623, 0.6860240764087309, 0.963212758449727], 
             UndirectedEdge[168, 181] -> 
             RGBColor[
              0.25911497354415575`, 0.3896766444060805, 0.9380675864658636], 
             UndirectedEdge[178, 391] -> 
             RGBColor[
              0.47121205870336796`, 0.5815902029735522, 0.9515146858492259], 
             UndirectedEdge[30, 133] -> 
             RGBColor[
              0.18845727560531045`, 0.31541092391555475`, 0.934043735096943], 
             UndirectedEdge[120, 363] -> 
             RGBColor[
              0.18125858689584057`, 0.307844645658676, 0.9336337804244444], 
             UndirectedEdge[452, 468] -> 
             RGBColor[
              0.22415491498640028`, 0.35293140626614244`, 0.9360766628497713],
              UndirectedEdge[159, 344] -> 
             RGBColor[
              0.2111960256367822, 0.3393107919186533, 0.9353386732722694], 
             UndirectedEdge[68, 330] -> 
             RGBColor[
              0.18750410848445143`, 0.3144090848372459, 0.9339894536394946], 
             UndirectedEdge[359, 440] -> 
             RGBColor[
              0.9005793035034079, 0.7657528918366445, 0.6112602253720522], 
             UndirectedEdge[180, 413] -> 
             RGBColor[
              0.24672751485063993`, 0.37665663990895104`, 0.9373621390188708],
              UndirectedEdge[81, 442] -> 
             RGBColor[
              0.2381306078360068, 0.36762074556118485`, 0.9368725578823716], 
             UndirectedEdge[165, 277] -> 
             RGBColor[
              0.37457657867037175`, 0.49860046416423287`, 0.9450982108256749],
              UndirectedEdge[28, 310] -> 
             RGBColor[
              0.5603270606284811, 0.6539001893978842, 0.958555843487958], 
             UndirectedEdge[71, 470] -> 
             RGBColor[
              0.19617627269900267`, 0.32352407927370813`, 0.9344833205621961],
              UndirectedEdge[129, 276] -> 
             RGBColor[
              0.2514871752437865, 0.381659344762047, 0.9376331946369739], 
             UndirectedEdge[192, 251] -> 
             RGBColor[
              0.2759596386433615, 0.40698913765266753`, 0.9390412298997809], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.4280975104696688, 0.5447636755214684, 0.9486245811666656], 
             UndirectedEdge[15, 323] -> 
             RGBColor[
              0.82255832396822, 0.8598188337480478, 0.8682325932875272], 
             UndirectedEdge[20, 473] -> 
             RGBColor[
              0.25267572333140287`, 0.38290858416043305`, 0.9377008806922643],
              UndirectedEdge[336, 354] -> 
             RGBColor[
              0.4679691659715405, 0.5750820152163606, 0.9523301949713454], 
             UndirectedEdge[36, 440] -> 
             RGBColor[
              0.9428820049759663, 0.7963257915311912, 0.48910376799027133`], 
             UndirectedEdge[31, 311] -> 
             RGBColor[
              0.1909827965699547, 0.3180654065766735, 0.9341875597797062], 
             UndirectedEdge[366, 405] -> 
             RGBColor[
              0.18210802697612394`, 0.3087374610406655, 0.9336821547803826], 
             UndirectedEdge[257, 374] -> 
             RGBColor[
              0.9052484576679132, 0.6263565932934416, 0.25201642158872506`], 
             UndirectedEdge[194, 254] -> 
             RGBColor[
              0.18926826388068996`, 0.3162633240126051, 0.9340899196794763], 
             UndirectedEdge[284, 456] -> 
             RGBColor[
              0.2012208320986775, 0.3288262310463056, 0.9347706007572507], 
             UndirectedEdge[30, 429] -> 
             RGBColor[
              0.18544154731921458`, 0.312241202278651, 0.9338719938324201], 
             UndirectedEdge[182, 463] -> 
             RGBColor[
              0.4500781331882001, 0.5614915648993155, 0.9506635985434537], 
             UndirectedEdge[130, 238] -> 
             RGBColor[
              0.39480407867420486`, 0.5149363424561325, 0.9466476293366854], 
             UndirectedEdge[19, 67] -> 
             RGBColor[
              0.1920452315036252, 0.3191820930542266, 0.9342480638774471], 
             UndirectedEdge[114, 446] -> 
             RGBColor[
              0.18242070987008802`, 0.30906611058746236`, 0.933699961608621], 
             UndirectedEdge[164, 418] -> 
             RGBColor[
              0.3962653140595378, 0.5170172416815048, 0.9466446107033122], 
             UndirectedEdge[96, 457] -> 
             RGBColor[
              0.47001276809964954`, 0.5806165648340276, 0.951420273299755], 
             UndirectedEdge[285, 354] -> 
             RGBColor[
              0.2624877417671351, 0.39305135672859914`, 0.93826589544543], 
             UndirectedEdge[432, 460] -> 
             RGBColor[
              0.2959533208946317, 0.4283960831575556, 0.9401654758500221], 
             UndirectedEdge[82, 249] -> 
             RGBColor[
              0.6235359473541606, 0.7039577755666018, 0.9643921411464688], 
             UndirectedEdge[176, 262] -> 
             RGBColor[
              0.33005042418212294`, 0.46029482143506084`, 0.9422514990701223],
              UndirectedEdge[216, 358] -> 
             RGBColor[
              0.21239908038802668`, 0.34057527874028815`, 0.9354071854605928],
              UndirectedEdge[54, 374] -> 
             RGBColor[
              0.9184848946909366, 0.6778098895741775, 0.5081596346636814], 
             UndirectedEdge[214, 491] -> 
             RGBColor[
              0.1845859949601158, 0.3113419625040855, 0.9338232713912458], 
             UndirectedEdge[68, 357] -> 
             RGBColor[
              0.18698592728629504`, 0.313864443543398, 0.93395994398684], 
             UndirectedEdge[260, 328] -> 
             RGBColor[
              0.2263686482084435, 0.35525818024130285`, 0.9362027316818419], 
             UndirectedEdge[224, 286] -> 
             RGBColor[
              0.19666508001759797`, 0.3240378467577258, 0.9345111574158644], 
             UndirectedEdge[219, 293] -> 
             RGBColor[
              0.7396376270146225, 0.7965298027687717, 0.9746838244203624], 
             UndirectedEdge[209, 404] -> 
             RGBColor[
              0.9156515263183187, 0.9323554252556073, 0.8627536207565263], 
             UndirectedEdge[197, 289] -> 
             RGBColor[
              0.22048333522571711`, 0.34907234314606217`, 0.9358675718140159],
              UndirectedEdge[227, 424] -> 
             RGBColor[
              0.19331536997885967`, 0.3205170891231287, 0.9343203963846103], 
             UndirectedEdge[458, 461] -> 
             RGBColor[
              0.24614691137880979`, 0.3760463888476713, 0.937329074510076], 
             UndirectedEdge[292, 464] -> 
             RGBColor[
              0.19378696997725373`, 0.3210127706226078, 0.9343472533068491], 
             UndirectedEdge[386, 441] -> 
             RGBColor[
              0.26353501578649874`, 0.39432238904964745`, 0.9383193013326985],
              UndirectedEdge[257, 343] -> 
             RGBColor[
              0.9046416145156388, 0.621692130904697, 0.25143530790077595`], 
             UndirectedEdge[132, 457] -> 
             RGBColor[
              0.37078286929344473`, 0.4917742570671961, 0.9450898009992874], 
             UndirectedEdge[69, 259] -> 
             RGBColor[
              0.5630647117651555, 0.6552495084047187, 0.9592526654459177], 
             UndirectedEdge[68, 95] -> 
             RGBColor[
              0.18505409827792216`, 0.3118339687705646, 0.933849929182698], 
             UndirectedEdge[247, 278] -> 
             RGBColor[
              0.18437169562717964`, 0.3111167203178072, 0.9338110673612625], 
             UndirectedEdge[293, 440] -> 
             RGBColor[
              0.8506906968621433, 0.7260557976902806, 0.6064798524386981], 
             UndirectedEdge[307, 442] -> 
             RGBColor[
              0.21483864965875055`, 0.34313942072144443`, 0.9355461153215412],
              UndirectedEdge[406, 493] -> 
             RGBColor[
              0.33870341661598447`, 0.4633663515821581, 0.9429648172026237], 
             UndirectedEdge[155, 479] -> 
             RGBColor[
              0.18812050432693928`, 0.3150569559494543, 0.9340245564708484], 
             UndirectedEdge[311, 488] -> 
             RGBColor[
              0.18625665477025105`, 0.3130979318904876, 0.9339184129959133], 
             UndirectedEdge[226, 345] -> 
             RGBColor[
              0.18891037080707027`, 0.3158871557004993, 0.9340695381983891], 
             UndirectedEdge[183, 273] -> 
             RGBColor[
              0.19206178134703447`, 0.31919948798897047`, 0.934249006366546], 
             UndirectedEdge[384, 499] -> 
             RGBColor[
              0.4483239267217146, 0.554218492373762, 0.9512402754132152], 
             UndirectedEdge[20, 325] -> 
             RGBColor[
              0.23769654620583044`, 0.3671645192667726, 0.9368478387146697], 
             UndirectedEdge[252, 424] -> 
             RGBColor[
              0.1878893571902253, 0.31481400565319295`, 0.934011392983364], 
             UndirectedEdge[285, 473] -> 
             RGBColor[
              0.2389908172005852, 0.3685248801437806, 0.9369215455331186], 
             UndirectedEdge[71, 236] -> 
             RGBColor[
              0.20304903767595361`, 0.3307477910229513, 0.9348747143602888], 
             UndirectedEdge[2, 446] -> 
             RGBColor[
              0.18380079735160318`, 0.310516670033135, 0.9337785555490368], 
             UndirectedEdge[33, 351] -> 
             RGBColor[
              0.24823088148452888`, 0.3782367735601183, 0.937447753524639], 
             UndirectedEdge[172, 466] -> 
             RGBColor[
              0.20918917113405136`, 0.3372014605943586, 0.935224385877214], 
             UndirectedEdge[12, 279] -> 
             RGBColor[
              0.2010090657422573, 0.3286036511789455, 0.9347585409765328], 
             UndirectedEdge[171, 219] -> 
             RGBColor[
              0.5701105988481052, 0.6614643237945504, 0.9595848784963202], 
             UndirectedEdge[153, 223] -> 
             RGBColor[
              0.21791092009915627`, 0.34636857174750746`, 0.9357210765781054],
              UndirectedEdge[121, 489] -> 
             RGBColor[
              0.1983767553672155, 0.32583692607665915`, 0.9346086347948284], 
             UndirectedEdge[362, 470] -> 
             RGBColor[
              0.1869253840691414, 0.31380080878350786`, 0.9339564961401887], 
             UndirectedEdge[168, 232] -> 
             RGBColor[
              0.28558604817661837`, 0.417499422207868, 0.9395750750057368], 
             UndirectedEdge[285, 409] -> 
             RGBColor[
              0.23381068107618688`, 0.3630802286374379, 0.9366265444441588], 
             UndirectedEdge[159, 439] -> 
             RGBColor[
              0.21567326392113564`, 0.34401665322881175`, 0.9355936453690827],
              UndirectedEdge[156, 263] -> 
             RGBColor[
              0.21186651840498638`, 0.34001552232973276`, 0.9353768568435135],
              UndirectedEdge[149, 314] -> 
             RGBColor[
              0.41196878637874557`, 0.5240737659037882, 0.9484356108143341], 
             UndirectedEdge[110, 457] -> 
             RGBColor[
              0.44316356556908426`, 0.5578351155851111, 0.9495785036311474], 
             UndirectedEdge[43, 263] -> 
             RGBColor[
              0.2263534256582619, 0.35524218037589655`, 0.9362018647801287], 
             UndirectedEdge[141, 160] -> 
             RGBColor[
              0.2233789267066098, 0.352115793383584, 0.936032471465209], 
             UndirectedEdge[345, 389] -> 
             RGBColor[
              0.1928812337006961, 0.3200607843689489, 0.9342956729658158], 
             UndirectedEdge[225, 247] -> 
             RGBColor[
              0.18412221385498584`, 0.31085449915717356`, 0.9337968597434113],
              UndirectedEdge[171, 293] -> 
             RGBColor[
              0.6402218599260903, 0.7162357738139922, 0.9665729137735878], 
             UndirectedEdge[179, 415] -> 
             RGBColor[
              0.19025558687597238`, 0.31730106308054046`, 0.9341461462634442],
              UndirectedEdge[143, 414] -> 
             RGBColor[
              0.5016592032391687, 0.6054763090493759, 0.9541415518219014], 
             UndirectedEdge[77, 388] -> 
             RGBColor[
              0.33157794270842256`, 0.4616178812072281, 0.9423488311998864], 
             UndirectedEdge[305, 406] -> 
             RGBColor[
              0.3635284030084348, 0.4892917640422711, 0.9443846862775205], 
             UndirectedEdge[55, 256] -> 
             RGBColor[
              0.4425753647760989, 0.554492515651166, 0.9503238262490175], 
             UndirectedEdge[367, 450] -> 
             RGBColor[
              0.20633807556762712`, 0.3342047783841471, 0.9350620202025242], 
             UndirectedEdge[171, 258] -> 
             RGBColor[
              0.44293779831735625`, 0.5576003693038944, 0.9495749484754112], 
             UndirectedEdge[366, 423] -> 
             RGBColor[
              0.18087837131958237`, 0.30744501498096866`, 0.933612127709855], 
             UndirectedEdge[309, 393] -> 
             RGBColor[
              0.20475589581124165`, 0.33254180714419534`, 0.9349719174060231],
              UndirectedEdge[324, 360] -> 
             RGBColor[
              0.7679481729777577, 0.8188024264455834, 0.9741261052850922], 
             UndirectedEdge[125, 310] -> 
             RGBColor[
              0.7113812015825887, 0.7744556684644794, 0.9718674880046061], 
             UndirectedEdge[33, 463] -> 
             RGBColor[
              0.4057152506945697, 0.5182150283519088, 0.9480144771137997], 
             UndirectedEdge[137, 280] -> 
             RGBColor[
              0.2325647771126936, 0.3617707045769326, 0.9365555920565876], 
             UndirectedEdge[72, 179] -> 
             RGBColor[
              0.20561407521805922`, 0.3334438081124777, 0.9350207894536787], 
             UndirectedEdge[17, 165] -> 
             RGBColor[
              0.3406850289827465, 0.4692453072636289, 0.9429386712487001], 
             UndirectedEdge[402, 417] -> 
             RGBColor[
              0.20763019049226705`, 0.33556287309476157`, 0.9351356042359695],
              UndirectedEdge[102, 225] -> 
             RGBColor[
              0.19170377678695943`, 0.3188232024975315, 0.9342286185364699], 
             UndirectedEdge[83, 231] -> 
             RGBColor[
              0.879442405436877, 0.9037944293481288, 0.8529223377718652], 
             UndirectedEdge[194, 377] -> 
             RGBColor[
              0.1834493331063201, 0.31014725882722227`, 0.9337585401802126], 
             UndirectedEdge[131, 495] -> 
             RGBColor[
              0.8599106722287021, 0.41795803680078086`, 0.20329863351297417`],
              UndirectedEdge[213, 447] -> 
             RGBColor[
              0.2179735437754206, 0.34643439320183167`, 0.9357246429038253], 
             UndirectedEdge[146, 166] -> 
             RGBColor[
              0.18787743892822623`, 0.31480147880417053`, 0.9340107142559747],
              UndirectedEdge[422, 428] -> 
             RGBColor[
              0.19715708759112932`, 0.32455497791258914`, 0.9345391765193171],
              UndirectedEdge[232, 338] -> 
             RGBColor[
              0.351395977443279, 0.47598308304576464`, 0.9437141472934822], 
             UndirectedEdge[366, 469] -> 
             RGBColor[
              0.1819546848445577, 0.30857628873793674`, 0.9336734221728392], 
             UndirectedEdge[245, 482] -> 
             RGBColor[
              0.2881486049407218, 0.4180084472344471, 0.93980098984346], 
             UndirectedEdge[40, 243] -> 
             RGBColor[
              0.19079403389915217`, 0.3178670050414155, 0.9341768100248533], 
             UndirectedEdge[174, 320] -> 
             RGBColor[
              0.1843078028000945, 0.31104956490550145`, 0.933807428759281], 
             UndirectedEdge[30, 31] -> 
             RGBColor[
              0.185457486240386, 0.3122579550953881, 0.9338729015304014], 
             UndirectedEdge[77, 354] -> 
             RGBColor[
              0.32252783628299564`, 0.4537791338930982, 0.9417721664211531], 
             UndirectedEdge[24, 223] -> 
             RGBColor[
              0.19673773915135, 0.32411421611415436`, 0.934515295246042], 
             UndirectedEdge[261, 391] -> 
             RGBColor[
              0.40120374518351687`, 0.5213867241354746, 0.9469338462657712], 
             UndirectedEdge[125, 323] -> 
             RGBColor[
              0.8853299376421364, 0.9088564954320449, 0.8744890811044619], 
             UndirectedEdge[1, 364] -> 
             RGBColor[
              0.2018347227926697, 0.32947146908860947`, 0.9348055609241036], 
             UndirectedEdge[88, 133] -> 
             RGBColor[
              0.19376977710770305`, 0.3209946998266191, 0.9343462741983627], 
             UndirectedEdge[178, 407] -> 
             RGBColor[
              0.3732194860466791, 0.4943283360147483, 0.9452291962385135], 
             UndirectedEdge[103, 486] -> 
             RGBColor[
              0.41156934709801946`, 0.5309024152046116, 0.94744581275397], 
             UndirectedEdge[204, 486] -> 
             RGBColor[
              0.3646188827036643, 0.4902362827451757, 0.9444541706794272], 
             UndirectedEdge[89, 407] -> 
             RGBColor[
              0.2934055397651449, 0.4256317109239335, 0.9400235504062648], 
             UndirectedEdge[38, 301] -> 
             RGBColor[
              0.5876340036038425, 0.6758909546392042, 0.9608274105699129], 
             UndirectedEdge[92, 132] -> 
             RGBColor[
              0.27212682678288186`, 0.40335292715912663`, 0.9388085922584972],
              UndirectedEdge[8, 146] -> 
             RGBColor[
              0.18877984751216192`, 0.31574996744189576`, 0.934062105089836], 
             UndirectedEdge[44, 110] -> 
             RGBColor[
              0.34804321230268565`, 0.4731300192483041, 0.9434986471622288], 
             UndirectedEdge[102, 252] -> 
             RGBColor[
              0.19087465031632422`, 0.3179517380072394, 0.93418140101055], 
             UndirectedEdge[273, 283] -> 
             RGBColor[
              0.18473808843290457`, 0.31150182238726964`, 0.933831932889519], 
             UndirectedEdge[158, 428] -> 
             RGBColor[
              0.1897406655144195, 0.31675984808164837`, 0.9341168222536617], 
             UndirectedEdge[176, 328] -> 
             RGBColor[
              0.27995998628272956`, 0.4108290857819987, 0.939282396167026], 
             UndirectedEdge[45, 398] -> 
             RGBColor[
              0.20371823459922628`, 0.33145115941884645`, 0.934912824135081], 
             UndirectedEdge[233, 275] -> 
             RGBColor[
              0.7259348855245369, 0.7839404012756612, 0.9506021698205669], 
             UndirectedEdge[250, 485] -> 
             RGBColor[
              0.23749323092755345`, 0.3669508220183703, 0.9368362602103498], 
             UndirectedEdge[29, 65] -> 
             RGBColor[
              0.1838043123267574, 0.3105203644948844, 0.9337787557216719], 
             UndirectedEdge[166, 453] -> 
             RGBColor[
              0.2178060906512075, 0.3462583893511425, 0.935715106696126], 
             UndirectedEdge[222, 294] -> 
             RGBColor[
              0.19229714625130181`, 0.3194468714263523, 0.9342624100496528], 
             UndirectedEdge[150, 220] -> 
             RGBColor[
              0.21619691693173887`, 0.3445670457444743, 0.9356234666333614], 
             UndirectedEdge[311, 423] -> 
             RGBColor[
              0.184592254538111, 0.31134854171743864`, 0.9338236278649524], 
             UndirectedEdge[210, 424] -> 
             RGBColor[
              0.19449774707264864`, 0.3217598424157385, 0.9343877310109313], 
             UndirectedEdge[179, 312] -> 
             RGBColor[
              0.19754047021008475`, 0.3249579373529733, 0.9345610095923028], 
             UndirectedEdge[310, 323] -> 
             RGBColor[
              0.8187613818125008, 0.8568526336781708, 0.8678541495778869], 
             UndirectedEdge[108, 349] -> 
             RGBColor[
              0.19740440059431363`, 0.32481491955948594`, 0.9345532606289816],
              UndirectedEdge[355, 395] -> 
             RGBColor[
              0.5319254348002241, 0.6308800567954042, 0.9562942652159951], 
             UndirectedEdge[47, 200] -> 
             RGBColor[
              0.2722924613184966, 0.40352701955789383`, 0.9388180249002662], 
             UndirectedEdge[152, 217] -> 
             RGBColor[
              0.18273892560736155`, 0.30940057550337985`, 0.9337180835241007],
              UndirectedEdge[174, 210] -> 
             RGBColor[
              0.19150041146467078`, 0.3186094526497, 0.9342170371822176], 
             UndirectedEdge[135, 211] -> 
             RGBColor[
              0.18373947818140363`, 0.31045221969739534`, 0.9337750635130075],
              UndirectedEdge[52, 491] -> 
             RGBColor[
              0.18081085908512495`, 0.30737405534203105`, 0.9336082829879782],
              UndirectedEdge[41, 250] -> 
             RGBColor[
              0.2413646105317827, 0.37101988744205927`, 0.9370567295516178], 
             UndirectedEdge[220, 392] -> 
             RGBColor[
              0.22694196327999852`, 0.35586077073178224`, 0.9362353811270232],
              UndirectedEdge[182, 359] -> 
             RGBColor[
              0.6272616214525479, 0.7019681789194203, 0.9672182481235007], 
             UndirectedEdge[89, 391] -> 
             RGBColor[
              0.39139811242183375`, 0.5128935778827375, 0.9463090400169774], 
             UndirectedEdge[62, 190] -> 
             RGBColor[
              0.233868572190446, 0.3631410758690329, 0.9366298412574736], 
             UndirectedEdge[21, 87] -> 
             RGBColor[
              0.30420754500978997`, 0.43707179605062296`, 0.94063554170235], 
             UndirectedEdge[185, 286] -> 
             RGBColor[
              0.1994684028845588, 0.32698431683183726`, 0.9346708025059933], 
             UndirectedEdge[114, 294] -> 
             RGBColor[
              0.18446317038438925`, 0.311212866087469, 0.9338162767133609], 
             UndirectedEdge[48, 156] -> 
             RGBColor[
              0.19463895940372045`, 0.3219082655290739, 0.9343957728442809], 
             UndirectedEdge[68, 450] -> 
             RGBColor[
              0.20047702738706202`, 0.3280444451344552, 0.9347282421792846], 
             UndirectedEdge[149, 406] -> 
             RGBColor[
              0.48881588257467606`, 0.5948821437018659, 0.9531767259019711], 
             UndirectedEdge[123, 158] -> 
             RGBColor[
              0.1887768797193095, 0.31574684810343895`, 0.9340619360784235], 
             UndirectedEdge[55, 91] -> 
             RGBColor[
              0.5169586982013866, 0.6187293857806677, 0.955116028885972], 
             UndirectedEdge[135, 169] -> 
             RGBColor[
              0.1819041358977289, 0.3085231585898313, 0.9336705434850978], 
             UndirectedEdge[141, 456] -> 
             RGBColor[
              0.20146025215418084`, 0.3290778767047479, 0.9347842353752214], 
             UndirectedEdge[287, 354] -> 
             RGBColor[
              0.3073707866753843, 0.44022628267657893`, 0.9408219184544402], 
             UndirectedEdge[223, 411] -> 
             RGBColor[
              0.24469698646716248`, 0.3745224258349809, 0.9372465034313293], 
             UndirectedEdge[127, 301] -> 
             RGBColor[
              0.7442995113076243, 0.8002700424356418, 0.9751223810067287], 
             UndirectedEdge[167, 201] -> 
             RGBColor[
              0.2486574185518422, 0.37868509106187664`, 0.9374720441796176], 
             UndirectedEdge[28, 218] -> 
             RGBColor[
              0.38085905105137724`, 0.5015767053192113, 0.9457353767574448], 
             UndirectedEdge[112, 317] -> 
             RGBColor[
              0.9053802389728423, 0.5628414484156407, 0.4612866067791993], 
             UndirectedEdge[275, 372] -> 
             RGBColor[
              0.55179178264052, 0.6470084529409276, 0.9578582168908132], 
             UndirectedEdge[85, 146] -> 
             RGBColor[
              0.1836713842833611, 0.3103806486931501, 0.9337711856662498], 
             UndirectedEdge[7, 262] -> 
             RGBColor[
              0.407760697816997, 0.5270866817975668, 0.9473459424920676], 
             UndirectedEdge[448, 455] -> 
             RGBColor[
              0.45681433053997933`, 0.564999766000337, 0.9515547264505798], 
             UndirectedEdge[9, 368] -> 
             RGBColor[
              0.18651190777224702`, 0.3133662189795604, 0.933932949276764], 
             UndirectedEdge[216, 399] -> 
             RGBColor[
              0.20389703761891642`, 0.33163909272930703`, 0.934923006702537], 
             UndirectedEdge[205, 474] -> 
             RGBColor[
              0.23349741976768085`, 0.3627509711402839, 0.936608704676068], 
             UndirectedEdge[125, 242] -> 
             RGBColor[
              0.8755313279725643, 0.9029638772422787, 0.9544497242112633], 
             UndirectedEdge[280, 338] -> 
             RGBColor[
              0.33890305736331594`, 0.4628522319448411, 0.9430026939765475], 
             UndirectedEdge[232, 393] -> 
             RGBColor[
              0.24988773384149937`, 0.3799782304378011, 0.9375421088152751], 
             UndirectedEdge[403, 483] -> 
             RGBColor[
              0.5977248399072642, 0.6827163434594106, 0.9625421629597528], 
             UndirectedEdge[427, 433] -> 
             RGBColor[
              0.18359379097292866`, 0.3102990932041856, 0.9337667668420098], 
             UndirectedEdge[269, 310] -> 
             RGBColor[
              0.6233432481970155, 0.705059569312919, 0.963516708609254], 
             UndirectedEdge[212, 357] -> 
             RGBColor[
              0.18524504165765288`, 0.3120346623691711, 0.9338608031256983], 
             UndirectedEdge[88, 307] -> 
             RGBColor[
              0.1906659921562372, 0.31773242505129645`, 0.9341695182370151], 
             UndirectedEdge[212, 217] -> 
             RGBColor[
              0.18159408433829743`, 0.30819727474246456`, 0.9336528865074684],
              UndirectedEdge[67, 124] -> 
             RGBColor[
              0.18312075215718818`, 0.30980189941644914`, 0.9337398279812515],
              UndirectedEdge[364, 380] -> 
             RGBColor[
              0.19593044529067147`, 0.3232656990811941, 0.9344693210549606], 
             UndirectedEdge[82, 384] -> 
             RGBColor[
              0.39409857332891574`, 0.5101959076651558, 0.9469714569601196], 
             UndirectedEdge[222, 439] -> 
             RGBColor[
              0.19816628717948753`, 0.32561571066690326`, 0.9345966489428971],
              UndirectedEdge[337, 420] -> 
             RGBColor[
              0.18856527989536503`, 0.3155244432722696, 0.9340498857814837], 
             UndirectedEdge[61, 99] -> 
             RGBColor[
              0.9849784772768306, 0.9873095986531333, 0.8651734232542627], 
             UndirectedEdge[63, 439] -> 
             RGBColor[
              0.20302072388459882`, 0.33071803143303935`, 0.9348731019317575],
              UndirectedEdge[37, 53] -> 
             RGBColor[
              0.8472647112443593, 0.3588769520067575, 0.19268158199931773`], 
             UndirectedEdge[39, 62] -> 
             RGBColor[
              0.2493920758689453, 0.37945726248211625`, 0.9375138818269986], 
             UndirectedEdge[130, 182] -> 
             RGBColor[
              0.323958117743938, 0.4544792345302443, 0.9418830285018508], 
             UndirectedEdge[152, 398] -> 
             RGBColor[
              0.19524728601816377`, 0.32254765537098895`, 0.934430416145035], 
             UndirectedEdge[23, 110] -> 
             RGBColor[
              0.42451306437954106`, 0.5421136125437187, 0.9482705749734688], 
             UndirectedEdge[322, 440] -> 
             RGBColor[
              0.8562073757382771, 0.38077868388003167`, 0.19941112665599764`],
              UndirectedEdge[141, 432] -> 
             RGBColor[
              0.24927102921021138`, 0.3793300347689854, 0.937506988398856], 
             UndirectedEdge[161, 459] -> 
             RGBColor[
              0.20416528068413636`, 0.3319210331984458, 0.9349382827482713], 
             UndirectedEdge[185, 333] -> 
             RGBColor[
              0.22166458508016862`, 0.3503139116386572, 0.9359348422457243], 
             UndirectedEdge[297, 474] -> 
             RGBColor[
              0.21238801987541464`, 0.34056365344025585`, 0.935406555580762], 
             UndirectedEdge[265, 329] -> 
             RGBColor[
              0.18295078871918613`, 0.3096232570668046, 0.9337301488148957], 
             UndirectedEdge[90, 280] -> 
             RGBColor[
              0.25791236607974777`, 0.3884126277112705, 0.937999099749864], 
             UndirectedEdge[183, 430] -> 
             RGBColor[
              0.19926050368686765`, 0.32676580159349333`, 0.9346589629542441],
              UndirectedEdge[86, 194] -> 
             RGBColor[
              0.18570943860608155`, 0.31252277300643677`, 0.9338872498448976],
              UndirectedEdge[143, 186] -> 
             RGBColor[
              0.7869875185761387, 0.829282852672385, 0.7373913878754195], 
             UndirectedEdge[1, 416] -> 
             RGBColor[
              0.20425325698717794`, 0.33201350187096224`, 0.9349432928685801],
              UndirectedEdge[27, 86] -> 
             RGBColor[
              0.18526169591288671`, 0.3120521670473626, 0.9338617515608961], 
             UndirectedEdge[66, 415] -> 
             RGBColor[
              0.1891407128871262, 0.3161292598311696, 0.9340826558390877], 
             UndirectedEdge[413, 490] -> 
             RGBColor[
              0.2231389506309891, 0.3518635633127446, 0.9360188051827152], 
             UndirectedEdge[226, 284] -> 
             RGBColor[
              0.19690493413279425`, 0.3242899486404264, 0.9345248167528926], 
             UndirectedEdge[245, 438] -> 
             RGBColor[
              0.22328352119424416`, 0.3520155161410289, 0.9360270382624196], 
             UndirectedEdge[53, 163] -> 
             RGBColor[
              0.8659915986516313, 0.4439113739475036, 0.20830775588996076`], 
             UndirectedEdge[367, 368] -> 
             RGBColor[
              0.1881907444562831, 0.3151307827788761, 0.9340285565423035], 
             UndirectedEdge[112, 175] -> 
             RGBColor[
              0.6955594457176699, 0.7552129086866064, 0.8524579222934991], 
             UndirectedEdge[277, 288] -> 
             RGBColor[
              0.5772249873338873, 0.6663273536018384, 0.9606573715704986], 
             UndirectedEdge[249, 323] -> 
             RGBColor[
              0.8598299314382067, 0.8889356967783099, 0.8719474787971606], 
             UndirectedEdge[416, 452] -> 
             RGBColor[
              0.2180186471312624, 0.3464817996885393, 0.935727211473216], 
             UndirectedEdge[13, 87] -> 
             RGBColor[
              0.28067879095443904`, 0.41234158372927926`, 0.9392956139665702],
              UndirectedEdge[471, 497] -> 
             RGBColor[
              0.7175094368939575, 0.7772891603319885, 0.9550059228659136], 
             UndirectedEdge[17, 321] -> 
             RGBColor[
              0.6804393139131792, 0.743928538014085, 0.9180923196352385], 
             UndirectedEdge[106, 227] -> 
             RGBColor[
              0.18640315120824044`, 0.31325190893522514`, 0.9339267557513348],
              UndirectedEdge[37, 100] -> 
             RGBColor[
              0.9275408237580072, 0.7267589387889348, 0.3553036056592853], 
             UndirectedEdge[9, 375] -> 
             RGBColor[
              0.19826733232951002`, 0.32572191552620944`, 0.934602403314708], 
             UndirectedEdge[10, 302] -> 
             RGBColor[
              0.23577384795439005`, 0.3651436414983986, 0.9367383438936274], 
             UndirectedEdge[14, 272] -> 
             RGBColor[
              0.24410352476956199`, 0.37389865996315785`, 0.9372127066655989],
              UndirectedEdge[63, 387] -> 
             RGBColor[
              0.1978509608116646, 0.3252842826614749, 0.9345786915727331], 
             UndirectedEdge[471, 483] -> 
             RGBColor[
              0.7044387287985243, 0.7666430914560537, 0.9539865308155939], 
             UndirectedEdge[46, 392] -> 
             RGBColor[
              0.22028047155655125`, 0.34885912056746937`, 0.9358560190281668],
              UndirectedEdge[122, 357] -> 
             RGBColor[
              0.18711144917701383`, 0.313996375009091, 0.9339670922728234], 
             UndirectedEdge[75, 125] -> 
             RGBColor[
              0.8216340480291034, 0.6538916931792487, 0.593916539379413], 
             UndirectedEdge[244, 261] -> 
             RGBColor[
              0.388007213318593, 0.5104940791921502, 0.9459444544247217], 
             UndirectedEdge[7, 178] -> 
             RGBColor[
              0.47083170751539166`, 0.5812814167445273, 0.9514847432104361], 
             UndirectedEdge[108, 487] -> 
             RGBColor[
              0.20117686323780593`, 0.3287800169857428, 0.9347680967956702], 
             UndirectedEdge[338, 480] -> 
             RGBColor[
              0.3338467491074454, 0.4575377313794614, 0.9427147447015134], 
             UndirectedEdge[237, 284] -> 
             RGBColor[
              0.21986017242091369`, 0.34841735952740993`, 0.9358320836141691],
              UndirectedEdge[162, 456] -> 
             RGBColor[
              0.18946877260235598`, 0.3164740713920633, 0.9341013383545491], 
             UndirectedEdge[104, 310] -> 
             RGBColor[
              0.7844721843600413, 0.7296832002097726, 0.6115226819006405], 
             UndirectedEdge[168, 390] -> 
             RGBColor[
              0.27431313717116323`, 0.40565087799729527`, 0.9389330994007534],
              UndirectedEdge[164, 431] -> 
             RGBColor[
              0.36863866395623385`, 0.49371801522607117`, 0.9447103075862879],
              UndirectedEdge[57, 60] -> 
             RGBColor[
              0.9740668501566808, 0.9799635557919238, 0.9191037618424754], 
             UndirectedEdge[158, 247] -> 
             RGBColor[
              0.18799329436094186`, 0.3149232502096133, 0.9340173120514751], 
             UndirectedEdge[32, 475] -> 
             RGBColor[
              0.27810050553156784`, 0.4070629513265539, 0.9392428367847124], 
             UndirectedEdge[53, 293] -> 
             RGBColor[
              0.8212117750972121, 0.5517293002984074, 0.5802972295340347], 
             UndirectedEdge[72, 294] -> 
             RGBColor[
              0.19930405825751749`, 0.32681158020876566`, 0.9346614433226095],
              UndirectedEdge[87, 287] -> 
             RGBColor[
              0.3062830568763104, 0.4392532906173888, 0.9407537390327037], 
             UndirectedEdge[154, 374] -> 
             RGBColor[
              0.9154556938707563, 0.6764368032115899, 0.5529680520443171], 
             UndirectedEdge[119, 364] -> 
             RGBColor[
              0.19435544195191212`, 0.32161027071117865`, 0.934379626944827], 
             UndirectedEdge[90, 342] -> 
             RGBColor[
              0.36933196448262395`, 0.489404611907154, 0.9450840596145658], 
             UndirectedEdge[401, 428] -> 
             RGBColor[
              0.18425068425914937`, 0.3109895296974434, 0.9338041759428735], 
             UndirectedEdge[183, 477] -> 
             RGBColor[
              0.19737928626943302`, 0.32478852281169623`, 0.934551830405333], 
             UndirectedEdge[82, 269] -> 
             RGBColor[
              0.5609980001725171, 0.6544824750687763, 0.958582964058418], 
             UndirectedEdge[202, 273] -> 
             RGBColor[
              0.18695948203332297`, 0.31383664790579846`, 0.9339584379688055],
              UndirectedEdge[147, 242] -> 
             RGBColor[
              0.8960966123696098, 0.5635667746530044, 0.5481508384278233], 
             UndirectedEdge[117, 198] -> 
             RGBColor[
              0.18298777738438862`, 0.30966213449914926`, 0.9337322552646592],
              UndirectedEdge[240, 434] -> 
             RGBColor[
              0.9649429424873008, 0.8858096572696792, 0.4713319778660402], 
             UndirectedEdge[249, 310] -> 
             RGBColor[
              0.685881195378659, 0.7545348698107444, 0.9693258856973048], 
             UndirectedEdge[448, 478] -> 
             RGBColor[
              0.2749488841783959, 0.4063190884105853, 0.938969304252312], 
             UndirectedEdge[121, 196] -> 
             RGBColor[
              0.19856429776732792`, 0.3260340450300523, 0.9346193150570707], 
             UndirectedEdge[200, 256] -> 
             RGBColor[
              0.28726648438606334`, 0.4190057220590618, 0.9396802912272235], 
             UndirectedEdge[79, 184] -> 
             RGBColor[
              0.7135412330833855, 0.7751234699043363, 0.9730039594525782], 
             UndirectedEdge[51, 240] -> 
             RGBColor[
              0.995029239647029, 0.991776371162987, 0.7003415954352006], 
             UndirectedEdge[339, 387] -> 
             RGBColor[
              0.1845385025539545, 0.3112920449740175, 0.9338205667689736], 
             UndirectedEdge[46, 142] -> 
             RGBColor[
              0.2097115161750654, 0.33775047835105276`, 0.9352541326545596], 
             UndirectedEdge[233, 259] -> 
             RGBColor[
              0.8229153142047934, 0.8620467284314131, 0.9586653393897153], 
             UndirectedEdge[266, 471] -> 
             RGBColor[
              0.975210019564589, 0.978006622458981, 0.7504581704123827], 
             UndirectedEdge[167, 456] -> 
             RGBColor[
              0.21773731167177224`, 0.3461860982829168, 0.9357111898349966], 
             UndirectedEdge[10, 181] -> 
             RGBColor[
              0.22615215264020183`, 0.355030629672469, 0.9361904025795069], 
             UndirectedEdge[31, 429] -> 
             RGBColor[
              0.19196505677432735`, 0.31909782433036316`, 0.9342434980452214],
              UndirectedEdge[317, 322] -> 
             RGBColor[
              0.8190506229224375, 0.1474370125838577, 0.16587620406611453`], 
             UndirectedEdge[52, 466] -> 
             RGBColor[
              0.18744056730247904`, 0.3143422990262493, 0.933985835063182], 
             UndirectedEdge[207, 281] -> 
             RGBColor[
              0.8467054680453859, 0.3339234893640672, 0.19133725700073073`], 
             UndirectedEdge[358, 398] -> 
             RGBColor[
              0.21557110150214517`, 0.3439092740489813, 0.935587827370457], 
             UndirectedEdge[155, 250] -> 
             RGBColor[
              0.2067822292135854, 0.3346716120270169, 0.9350873140955949], 
             UndirectedEdge[243, 285] -> 
             RGBColor[
              0.20548353415746184`, 0.3333066011810086, 0.9350133553333959], 
             UndirectedEdge[378, 452] -> 
             RGBColor[
              0.21688623716897232`, 0.34529156501923397`, 0.935662722401114], 
             UndirectedEdge[100, 264] -> 
             RGBColor[
              0.92938539319056, 0.7351346977720205, 0.3568427596083415], 
             UndirectedEdge[81, 130] -> 
             RGBColor[
              0.27063800741742255`, 0.4017880836094291, 0.9387238061981451], 
             UndirectedEdge[1, 120] -> 
             RGBColor[
              0.18959062955787265`, 0.3166021507784885, 0.9341082779278946], 
             UndirectedEdge[390, 422] -> 
             RGBColor[
              0.23122695863113757`, 0.36036457253022636`, 0.9364794052731881],
              UndirectedEdge[118, 255] -> 
             RGBColor[
              0.19469073239539242`, 0.3219626822259184, 0.9343987212395655], 
             UndirectedEdge[137, 229] -> 
             RGBColor[
              0.2232482662355424, 0.35197846094413987`, 0.9360250305446766], 
             UndirectedEdge[367, 375] -> 
             RGBColor[
              0.19994616901354612`, 0.3274864793255251, 0.9346980105802476], 
             UndirectedEdge[230, 382] -> 
             RGBColor[
              0.20898405610198123`, 0.3369858716906088, 0.9352127048795782], 
             UndirectedEdge[114, 334] -> 
             RGBColor[
              0.18414474445457316`, 0.31087818024586233`, 0.9337981428277268],
              UndirectedEdge[52, 170] -> 
             RGBColor[
              0.1838649636445791, 0.31058411287543064`, 0.9337822097244962], 
             UndirectedEdge[4, 389] -> 
             RGBColor[
              0.18821672881431478`, 0.31515809398667083`, 0.934030036313053], 
             UndirectedEdge[190, 378] -> 
             RGBColor[
              0.21175405970731373`, 0.3398973211081856, 0.9353704524870488], 
             UndirectedEdge[89, 328] -> 
             RGBColor[
              0.27633399177258894`, 0.4076884315850981, 0.9390513510031808], 
             UndirectedEdge[93, 300] -> 
             RGBColor[
              0.2272468293636924, 0.3561812043153706, 0.9362527427994807], 
             UndirectedEdge[104, 125] -> 
             RGBColor[
              0.8510407401896769, 0.7816870619636468, 0.6181576134272155], 
             UndirectedEdge[59, 228] -> 
             RGBColor[
              0.26060629998899837`, 0.391244123055168, 0.9381525153006776], 
             UndirectedEdge[96, 136] -> 
             RGBColor[
              0.4994982670529912, 0.6045542211909409, 0.9537414797863035], 
             UndirectedEdge[332, 420] -> 
             RGBColor[
              0.1873361545684642, 0.31423255462265, 0.9339798889124447], 
             UndirectedEdge[40, 283] -> 
             RGBColor[
              0.18366308451827268`, 0.3103719251138067, 0.9337707130069065], 
             UndirectedEdge[17, 288] -> 
             RGBColor[
              0.543333437646262, 0.6369721967012344, 0.9584978319935238], 
             UndirectedEdge[325, 413] -> 
             RGBColor[
              0.23197275674874823`, 0.36114845363816694`, 0.9365218773726766],
              UndirectedEdge[421, 459] -> 
             RGBColor[
              0.18940834947071425`, 0.31641056284966007`, 0.9340978973465902],
              UndirectedEdge[148, 342] -> 
             RGBColor[
              0.3754741855106375, 0.4958604756469023, 0.9454338500155093], 
             UndirectedEdge[262, 478] -> 
             RGBColor[
              0.29624054132013333`, 0.4255154795391891, 0.9402983591952379], 
             UndirectedEdge[133, 405] -> 
             RGBColor[
              0.18981989868512106`, 0.3168431271677289, 0.9341213344655181], 
             UndirectedEdge[374, 397] -> 
             RGBColor[
              0.8347270315445021, 0.26793275869910615`, 0.18088795066657473`],
              UndirectedEdge[151, 389] -> 
             RGBColor[
              0.1993172981785255, 0.3268254962052045, 0.9346621973165241], 
             UndirectedEdge[235, 305] -> 
             RGBColor[
              0.2638362786788805, 0.394471813217312, 0.9383425806338642], 
             UndirectedEdge[204, 348] -> 
             RGBColor[
              0.38899180466367445`, 0.5111089618702334, 0.9460729299565488], 
             UndirectedEdge[191, 429] -> 
             RGBColor[
              0.1912728666243942, 0.31837028859539307`, 0.9342040788401863], 
             UndirectedEdge[15, 414] -> 
             RGBColor[0.53753656294092, 0.634449250565901, 0.957071181763386],
              UndirectedEdge[277, 414] -> 
             RGBColor[
              0.43294658493558325`, 0.5494183041682945, 0.9488079514458304], 
             UndirectedEdge[317, 440] -> 
             RGBColor[
              0.8544757528158395, 0.36746867129617394`, 0.19775292258988314`],
              UndirectedEdge[76, 182] -> 
             RGBColor[
              0.3777126376207911, 0.5015774351431334, 0.9452884931643937], 
             UndirectedEdge[199, 376] -> 
             RGBColor[
              0.3786216036789717, 0.5023647358567669, 0.9453464116778538], 
             UndirectedEdge[375, 402] -> 
             RGBColor[
              0.21043597475918854`, 0.33851193025629345`, 0.9352953894991849],
              UndirectedEdge[45, 195] -> 
             RGBColor[
              0.19463609510811763`, 0.32190525497278855`, 0.9343956097268837],
              UndirectedEdge[149, 269] -> 
             RGBColor[
              0.5815017308774398, 0.6711283273375747, 0.9601970928471498], 
             UndirectedEdge[45, 152] -> 
             RGBColor[
              0.1927063751242849, 0.3198769969184667, 0.9342857150285693], 
             UndirectedEdge[356, 494] -> 
             RGBColor[
              0.30030937836549265`, 0.4286701061729542, 0.9405711545959381], 
             UndirectedEdge[44, 360] -> 
             RGBColor[
              0.4375870349530485, 0.5468097854709225, 0.9502759669846275], 
             UndirectedEdge[284, 432] -> 
             RGBColor[
              0.249031609154708, 0.37907838911054315`, 0.9374933537808854], 
             UndirectedEdge[151, 237] -> 
             RGBColor[
              0.2183016735730191, 0.3467792784237385, 0.9357433294103739], 
             UndirectedEdge[207, 343] -> 
             RGBColor[
              0.8606088112970214, 0.4407906780799979, 0.2046511142000771], 
             UndirectedEdge[33, 371] -> 
             RGBColor[
              0.2551767869971113, 0.385537360649688, 0.9378433125680343], 
             UndirectedEdge[280, 480] -> 
             RGBColor[
              0.24841746075918128`, 0.37843288020758725`, 0.9374583789383113],
              UndirectedEdge[420, 454] -> 
             RGBColor[
              0.19971846915340663`, 0.3272471523355135, 0.9346850434100643], 
             UndirectedEdge[267, 393] -> 
             RGBColor[
              0.22528640281656057`, 0.35412067171611283`, 0.9361410994078128],
              UndirectedEdge[337, 427] -> 
             RGBColor[
              0.18780005171862202`, 0.314720139940244, 0.9340063071688718], 
             UndirectedEdge[267, 480] -> 
             RGBColor[
              0.23630904981420553`, 0.3657061725868226, 0.9367688228477836], 
             UndirectedEdge[234, 336] -> 
             RGBColor[
              0.7758644491107505, 0.7262741691289183, 0.6116347463560659], 
             UndirectedEdge[122, 492] -> 
             RGBColor[
              0.1841436405662557, 0.3108770199892501, 0.9337980799629202], 
             UndirectedEdge[80, 272] -> 
             RGBColor[
              0.30232143214337615`, 0.4315140636582957, 0.9406590399115311], 
             UndirectedEdge[331, 444] -> 
             RGBColor[
              0.43364941819134256`, 0.5462951958354212, 0.9497218378452923], 
             UndirectedEdge[77, 184] -> 
             RGBColor[
              0.4376517235629901, 0.5511173532058586, 0.9497643390234523], 
             UndirectedEdge[266, 359] -> 
             RGBColor[
              0.9515547370167402, 0.9596896244773535, 0.7671002510689349], 
             UndirectedEdge[32, 478] -> 
             RGBColor[
              0.23449306505329615`, 0.3637974574630227, 0.9366654052021586], 
             UndirectedEdge[14, 447] -> 
             RGBColor[
              0.2323548964610662, 0.3615501067048703, 0.936543639663968], 
             UndirectedEdge[16, 358] -> 
             RGBColor[
              0.24749987708524912`, 0.37746844158811943`, 0.9374061239055242],
              UndirectedEdge[50, 323] -> 
             RGBColor[
              0.9365367216162789, 0.9493476478675402, 0.8794633883159441], 
             UndirectedEdge[92, 365] -> 
             RGBColor[
              0.23949140661491064`, 0.36905103135743866`, 0.9369500533597088],
              UndirectedEdge[296, 438] -> 
             RGBColor[
              0.1924355382075839, 0.3195923301469616, 0.9342702912668306], 
             UndirectedEdge[181, 422] -> 
             RGBColor[
              0.2160287950041301, 0.3443903389390116, 0.9356138923382982], 
             UndirectedEdge[35, 428] -> 
             RGBColor[
              0.18771159390474457`, 0.31462716516930944`, 0.9340012696272331],
              UndirectedEdge[19, 298] -> 
             RGBColor[
              0.2394531191654226, 0.3690107888204622, 0.9369478729461016], 
             UndirectedEdge[209, 348] -> 
             RGBColor[
              0.7282782743451366, 0.7830802438848616, 0.8460022789081878], 
             UndirectedEdge[27, 194] -> 
             RGBColor[
              0.1856592913664621, 0.31247006507807806`, 0.9338843940337875], 
             UndirectedEdge[253, 287] -> 
             RGBColor[
              0.340823165506129, 0.46920105185432204`, 0.9429534744527581], 
             UndirectedEdge[412, 476] -> 
             RGBColor[
              0.18684284442084606`, 0.31371405437983346`, 0.9339517956293248],
              UndirectedEdge[221, 336] -> 
             RGBColor[
              0.7938129054109903, 0.7955671950703103, 0.6357978963718616], 
             UndirectedEdge[146, 248] -> 
             RGBColor[
              0.18017302617267333`, 0.306703652510102, 0.9335719593472032], 
             UndirectedEdge[17, 455] -> 
             RGBColor[
              0.49424404189338955`, 0.5981741285649027, 0.9539120839375526], 
             UndirectedEdge[102, 393] -> 
             RGBColor[
              0.2103791435745319, 0.3384521970779141, 0.9352921530472929], 
             UndirectedEdge[80, 497] -> 
             RGBColor[
              0.4127991170058606, 0.5312924585653119, 0.9477107106935068], 
             UndirectedEdge[108, 416] -> 
             RGBColor[
              0.20942130064370462`, 0.3374454434268651, 0.9352376053093838], 
             UndirectedEdge[8, 453] -> 
             RGBColor[
              0.21870849923514318`, 0.34720687798886773`, 0.9357664975299873],
              UndirectedEdge[58, 402] -> 
             RGBColor[
              0.20564836608822273`, 0.3334798499911863, 0.9350227422680057], 
             UndirectedEdge[95, 357] -> 
             RGBColor[
              0.18661251030183867`, 0.3134719586167301, 0.9339386784419961], 
             UndirectedEdge[183, 283] -> 
             RGBColor[
              0.18964111329673894`, 0.31665521238889094`, 0.9341111529021391],
              UndirectedEdge[179, 294] -> 
             RGBColor[
              0.19380204212800067`, 0.3210286124086723, 0.9343481116435368], 
             UndirectedEdge[136, 240] -> 
             RGBColor[
              0.7615140918759296, 0.8095862292350475, 0.8160223615071904], 
             UndirectedEdge[153, 289] -> 
             RGBColor[
              0.21885506273912853`, 0.34736092552421916`, 0.935774844104718], 
             UndirectedEdge[73, 200] -> 
             RGBColor[
              0.4199369122581749, 0.5305626812641765, 0.9490610674516942], 
             UndirectedEdge[196, 447] -> 
             RGBColor[
              0.2128628663159131, 0.341062747156223, 0.9354335973830761], 
             UndirectedEdge[68, 492] -> 
             RGBColor[
              0.1840181186755369, 0.3107450885235571, 0.9337909316769367], 
             UndirectedEdge[25, 413] -> 
             RGBColor[
              0.25960242052995686`, 0.39018898209408137`, 0.9380953458505918],
              UndirectedEdge[220, 426] -> 
             RGBColor[
              0.20219514191155313`, 0.32985029243444797`, 0.9348260862597317],
              UndirectedEdge[21, 354] -> 
             RGBColor[
              0.30529527480886387`, 0.43804478810981307`, 0.9407037211240865],
              UndirectedEdge[125, 269] -> 
             RGBColor[
              0.6899118040266511, 0.7570634310667932, 0.970151640135829], 
             UndirectedEdge[241, 304] -> 
             RGBColor[
              0.20316948858682138`, 0.3308743925673022, 0.9348815738614715], 
             UndirectedEdge[93, 456] -> 
             RGBColor[
              0.20912093230204676`, 0.3371297372553299, 0.9352204997766816], 
             UndirectedEdge[295, 455] -> 
             RGBColor[
              0.7989202594631184, 0.8423584945526768, 0.9321574576076621], 
             UndirectedEdge[185, 386] -> 
             RGBColor[
              0.25857169569949595`, 0.38910562494553824`, 0.9380366475963178],
              UndirectedEdge[233, 400] -> 
             RGBColor[
              0.9762128798080161, 0.9808371360064839, 0.8829178984103572], 
             UndirectedEdge[83, 317] -> 
             RGBColor[
              0.9062729324823862, 0.5632106001230137, 0.44649236510931034`], 
             UndirectedEdge[88, 465] -> 
             RGBColor[
              0.18430414736705614`, 0.3110457228136103, 0.9338072205877772], 
             UndirectedEdge[418, 431] -> 
             RGBColor[
              0.4488786406898552, 0.5625882607859993, 0.9499970853520581], 
             UndirectedEdge[121, 307] -> 
             RGBColor[
              0.1984527242001829, 0.32591677413681014`, 0.93461296110748], 
             UndirectedEdge[64, 74] -> 
             RGBColor[
              0.1867563887094054, 0.3136231839455006, 0.933946872104458], 
             UndirectedEdge[185, 358] -> 
             RGBColor[
              0.21821199843557637`, 0.3466850241685541, 0.935738222543959], 
             UndirectedEdge[113, 315] -> 
             RGBColor[
              0.19006335492631857`, 0.31709901511324473`, 0.9341351989382931],
              UndirectedEdge[47, 91] -> 
             RGBColor[
              0.37096684027433213`, 0.4930353735304999, 0.9450030845101454], 
             UndirectedEdge[158, 401] -> 
             RGBColor[
              0.1862173046895177, 0.3130565724606977, 0.9339161720670288], 
             UndirectedEdge[90, 232] -> 
             RGBColor[
              0.2704052861597108, 0.40154347881219404`, 0.9387105530667987], 
             UndirectedEdge[58, 115] -> 
             RGBColor[
              0.19207706439220854`, 0.3192155514384495, 0.9342498767133594], 
             UndirectedEdge[132, 494] -> 
             RGBColor[
              0.3138085366833637, 0.4428585774611083, 0.9413399116919258], 
             UndirectedEdge[167, 300] -> 
             RGBColor[
              0.23586320873341787`, 0.3652375653429575, 0.9367434328577955], 
             UndirectedEdge[284, 389] -> 
             RGBColor[
              0.20087579702642006`, 0.328463577308876, 0.9347509515203193], 
             UndirectedEdge[103, 233] -> 
             RGBColor[
              0.6861807488432135, 0.7504846976904338, 0.9477990317770553], 
             UndirectedEdge[172, 300] -> 
             RGBColor[
              0.22767768818641226`, 0.35663406425607636`, 0.936277279572036], 
             UndirectedEdge[70, 76] -> 
             RGBColor[
              0.3900856381049142, 0.5122943062773944, 0.9460768898142273], 
             UndirectedEdge[57, 73] -> 
             RGBColor[
              0.769769601175684, 0.81952464354351, 0.9539791162715971], 
             UndirectedEdge[287, 473] -> 
             RGBColor[
              0.28387386210883436`, 0.4156998060917603, 0.9394775685421287], 
             UndirectedEdge[395, 443] -> 
             RGBColor[
              0.39598885232621217`, 0.5140941996505966, 0.9469051099430464], 
             UndirectedEdge[100, 397] -> 
             RGBColor[
              0.9076183259729562, 0.5790517976305654, 0.33643826418820166`], 
             UndirectedEdge[57, 234] -> 
             RGBColor[
              0.9445095586663342, 0.8587398441686642, 0.6038719941743098], 
             UndirectedEdge[343, 403] -> 
             RGBColor[
              0.7948197503279848, 0.5779151298917289, 0.5834817504053871], 
             UndirectedEdge[105, 425] -> 
             RGBColor[
              0.18905198757822078`, 0.3160360039060004, 0.9340776030640029], 
             UndirectedEdge[133, 423] -> 
             RGBColor[
              0.18859024302857952`, 0.3155506811080321, 0.9340513073949906], 
             UndirectedEdge[92, 494] -> 
             RGBColor[
              0.31362082310207806`, 0.44266127858544857`, 0.9413292216811688],
              UndirectedEdge[51, 100] -> 
             RGBColor[
              0.9942396894003585, 0.9900876030211339, 0.6144039236244064], 
             UndirectedEdge[6, 347] -> 
             RGBColor[
              0.20873556607912272`, 0.336724692921407, 0.9351985537403844], 
             UndirectedEdge[333, 461] -> 
             RGBColor[
              0.24252993321129454`, 0.3722447154639515, 0.9371230929542755], 
             UndirectedEdge[291, 394] -> 
             RGBColor[
              0.18326692398746902`, 0.30995553527790365`, 0.9337481522507443],
              UndirectedEdge[143, 386] -> 
             RGBColor[
              0.4431271313499566, 0.5544881277989356, 0.9504225818042138], 
             UndirectedEdge[123, 437] -> 
             RGBColor[
              0.18388303382001714`, 0.3106031057755313, 0.9337832387942551], 
             UndirectedEdge[72, 453] -> 
             RGBColor[
              0.2255232493931461, 0.35436961248504456`, 0.9361545874699662], 
             UndirectedEdge[391, 478] -> 
             RGBColor[
              0.36121422406998477`, 0.4812548901837663, 0.9445869453059381], 
             UndirectedEdge[328, 464] -> 
             RGBColor[
              0.22272025145336094`, 0.35142348392999634`, 0.9359949608839593],
              UndirectedEdge[149, 173] -> 
             RGBColor[
              0.6408634071546884, 0.7181223008643338, 0.9656896889353898], 
             UndirectedEdge[54, 186] -> 
             RGBColor[
              0.9914243588005289, 0.9890319585828893, 0.6689529207083693], 
             UndirectedEdge[355, 444] -> 
             RGBColor[
              0.5627869729236907, 0.655934843740483, 0.9587237985466135], 
             UndirectedEdge[7, 448] -> 
             RGBColor[
              0.38646904067525956`, 0.507890290668963, 0.9460168875491417], 
             UndirectedEdge[47, 416] -> 
             RGBColor[
              0.24541922577751857`, 0.3752815451427822, 0.9372876338915967], 
             UndirectedEdge[48, 155] -> 
             RGBColor[
              0.1919029748142661, 0.3190325722541152, 0.934239962569438], 
             UndirectedEdge[346, 486] -> 
             RGBColor[
              0.4273749578752095, 0.5445924408467173, 0.9484529322963398], 
             UndirectedEdge[24, 491] -> 
             RGBColor[
              0.1834588125121197, 0.3101572222837467, 0.9337590800183494], 
             UndirectedEdge[321, 373] -> 
             RGBColor[
              0.9882173705299822, 0.9893955941614516, 0.8449321929931977], 
             UndirectedEdge[209, 231] -> 
             RGBColor[
              0.8790670260426792, 0.9036392003218177, 0.8591433457844534], 
             UndirectedEdge[210, 393] -> 
             RGBColor[
              0.20841975513223648`, 0.336392755592659, 0.9351805687741597], 
             UndirectedEdge[188, 409] -> 
             RGBColor[
              0.23860514692337326`, 0.3681195162295229, 0.9368995821813795], 
             UndirectedEdge[307, 427] -> 
             RGBColor[
              0.1891435770986254, 0.31613227029905666`, 0.9340828189516954], 
             UndirectedEdge[178, 186] -> 
             RGBColor[
              0.7313163060716499, 0.7840864544016981, 0.7330087460966953], 
             UndirectedEdge[328, 475] -> 
             RGBColor[
              0.28975754389901165`, 0.4193152377496582, 0.9399066878746956], 
             UndirectedEdge[213, 337] -> 
             RGBColor[
              0.19565173016906506`, 0.3229727518168264, 0.9344534486411072], 
             UndirectedEdge[384, 458] -> 
             RGBColor[
              0.25354859204463764`, 0.3838260245211157, 0.9377505892741895], 
             UndirectedEdge[87, 473] -> 
             RGBColor[
              0.28600307999809077`, 0.4179377490935802, 0.9395988243510263], 
             UndirectedEdge[112, 440] -> 
             RGBColor[
              0.9425369917886818, 0.7961831197118145, 0.4948215293690824], 
             UndirectedEdge[237, 429] -> 
             RGBColor[
              0.2124196419707597, 0.3405968902674201, 0.9354083564123112], 
             UndirectedEdge[109, 230] -> 
             RGBColor[
              0.20976714477549485`, 0.3378089475371612, 0.9352573006210588], 
             UndirectedEdge[89, 262] -> 
             RGBColor[
              0.3264244296719824, 0.4571541672381602, 0.9420204539062771], 
             UndirectedEdge[280, 383] -> 
             RGBColor[
              0.2606241170949257, 0.3912628499631674, 0.9381535299585022], 
             UndirectedEdge[196, 489] -> 
             RGBColor[
              0.19180860925659354`, 0.31893338806987936`, 0.9342345885905299],
              UndirectedEdge[279, 459] -> 
             RGBColor[
              0.20123137359851423`, 0.3288373108310037, 0.9347712010800716], 
             UndirectedEdge[191, 423] -> 
             RGBColor[
              0.1848982635137219, 0.3116701765528954, 0.9338410546234137], 
             UndirectedEdge[116, 165] -> 
             RGBColor[
              0.2912027626996634, 0.4234029452918576, 0.9398949385886397], 
             UndirectedEdge[176, 313] -> 
             RGBColor[
              0.3390769551492299, 0.46811314887213096`, 0.9428266616414984], 
             UndirectedEdge[180, 490] -> 
             RGBColor[
              0.23955648296360244`, 0.3691194307259925, 0.9369537593614949], 
             UndirectedEdge[17, 498] -> 
             RGBColor[
              0.5750148993041335, 0.6617219953363903, 0.9616555440114883], 
             UndirectedEdge[108, 364] -> 
             RGBColor[
              0.2070027664491964, 0.33490341064451234`, 0.9350998733649074], 
             UndirectedEdge[29, 254] -> 
             RGBColor[
              0.18842942576301586`, 0.31538165196552115`, 0.9340421490896246],
              UndirectedEdge[7, 261] -> 
             RGBColor[
              0.40082339399554057`, 0.5210779379064496, 0.9469039036269813], 
             UndirectedEdge[122, 224] -> 
             RGBColor[
              0.195806426334931, 0.3231353472954549, 0.9344622583589008], 
             UndirectedEdge[116, 386] -> 
             RGBColor[
              0.2910406970756628, 0.423232604045479, 0.9398857091911075], 
             UndirectedEdge[8, 439] -> 
             RGBColor[
              0.1983584490277003, 0.3258176849531398, 0.9346075922758748], 
             UndirectedEdge[226, 488] -> 
             RGBColor[
              0.18475420080410804`, 0.31151875751098784`, 0.9338328504652229],
              UndirectedEdge[64, 170] -> 
             RGBColor[
              0.18627047911638173`, 0.31311246215478516`, 0.9339192002719742],
              UndirectedEdge[178, 313] -> 
             RGBColor[
              0.4152649069206235, 0.5336691197660451, 0.9478012623099019], 
             UndirectedEdge[81, 251] -> 
             RGBColor[
              0.23864347228983546`, 0.36815979861964326`, 0.9369017647543021],
              UndirectedEdge[186, 288] -> 
             RGBColor[
              0.8522733135527225, 0.8812298873379956, 0.7432521758076465], 
             UndirectedEdge[45, 118] -> 
             RGBColor[
              0.1966941864369604, 0.3240684394499293, 0.9345128149833881], 
             UndirectedEdge[224, 330] -> 
             RGBColor[
              0.1977574976662851, 0.3251860469697754, 0.9345733689848701], 
             UndirectedEdge[35, 410] -> 
             RGBColor[
              0.18494866329979062`, 0.31172314992358463`, 0.9338439248166706],
              UndirectedEdge[163, 379] -> 
             RGBColor[
              0.8633665292005046, 0.42373393983337493`, 0.2057939864189699], 
             UndirectedEdge[181, 443] -> 
             RGBColor[
              0.2566770686688468, 0.387114251810034, 0.9379287513897718], 
             UndirectedEdge[167, 235] -> 
             RGBColor[
              0.22849052163804753`, 0.3574884037503625, 0.9363235692346273], 
             UndirectedEdge[202, 279] -> 
             RGBColor[
              0.19737149140968246`, 0.32478032991987577`, 0.9345513864996016],
              UndirectedEdge[242, 310] -> 
             RGBColor[
              0.8089627721429287, 0.8509600154884045, 0.9478147926846883], 
             UndirectedEdge[299, 482] -> 
             RGBColor[
              0.2862226992731482, 0.4159841982683552, 0.9396913123648138], 
             UndirectedEdge[56, 110] -> 
             RGBColor[
              0.41196166706796206`, 0.5312422230440008, 0.9474708110355399], 
             UndirectedEdge[125, 419] -> 
             RGBColor[
              0.7136180387569662, 0.7762031026656953, 0.9720904350297161], 
             UndirectedEdge[262, 448] -> 
             RGBColor[
              0.3218757091133844, 0.45245966625341066`, 0.9417582440772314], 
             UndirectedEdge[95, 212] -> 
             RGBColor[
              0.18331321264928, 0.31000418759633763`, 0.9337507883215563], 
             UndirectedEdge[32, 260] -> 
             RGBColor[
              0.21471160984099968`, 0.34300589381819857`, 0.9355388805918587],
              UndirectedEdge[421, 430] -> 
             RGBColor[
              0.19294646407159283`, 0.3201293456246058, 0.9342993877389387], 
             UndirectedEdge[129, 346] -> 
             RGBColor[
              0.36539555977117477`, 0.4891180942666259, 0.9445692337379277], 
             UndirectedEdge[16, 17] -> 
             RGBColor[
              0.32278008566889027`, 0.45042607660179157`, 0.9419190112149659],
              UndirectedEdge[153, 466] -> 
             RGBColor[
              0.2112617016772801, 0.3393798216013181, 0.9353424134256167], 
             UndirectedEdge[244, 391] -> 
             RGBColor[
              0.45991819988990085`, 0.5722422337278446, 0.9506750794005083], 
             UndirectedEdge[218, 406] -> 
             RGBColor[
              0.35118939031714774`, 0.4764899015985373, 0.9436758749335621], 
             UndirectedEdge[99, 288] -> 
             RGBColor[
              0.8454606604699532, 0.8793558579429647, 0.9455510322617159], 
             UndirectedEdge[399, 481] -> 
             RGBColor[
              0.20657386895260635`, 0.3344526121819243, 0.9350754482869736], 
             UndirectedEdge[278, 451] -> 
             RGBColor[
              0.194775409510841, 0.3220516832430941, 0.9344035434760216], 
             UndirectedEdge[179, 327] -> 
             RGBColor[
              0.1919456153481889, 0.3190773901588341, 0.9342423908847639], 
             UndirectedEdge[38, 473] -> 
             RGBColor[
              0.39120686649721753`, 0.5073123077036177, 0.9467925996287968], 
             UndirectedEdge[17, 176] -> 
             RGBColor[
              0.3461884783937958, 0.47427279287102275`, 0.943279801614169], 
             UndirectedEdge[186, 373] -> 
             RGBColor[
              0.9921614072017308, 0.9893367470380662, 0.6567381212803327], 
             UndirectedEdge[399, 496] -> 
             RGBColor[
              0.19684711352332962`, 0.3242291755138407, 0.9345215239547214], 
             UndirectedEdge[116, 358] -> 
             RGBColor[
              0.2506809998117433, 0.38081200326849496`, 0.9375872841387487], 
             UndirectedEdge[71, 135] -> 
             RGBColor[
              0.18886726703484777`, 0.31584185090295647`, 0.9340670835023274],
              UndirectedEdge[53, 374] -> 
             RGBColor[
              0.8400594801870103, 0.30892029565931944`, 0.18599430950878], 
             UndirectedEdge[228, 409] -> 
             RGBColor[
              0.2557251463437433, 0.3861137210909889, 0.9378745408216], 
             UndirectedEdge[440, 471] -> 
             RGBColor[
              0.9242345860512566, 0.784069889818272, 0.5946181447155001], 
             UndirectedEdge[403, 471] -> 
             RGBColor[
              0.8501227775795742, 0.8834026890475528, 0.9665040763953929], 
             UndirectedEdge[63, 166] -> 
             RGBColor[
              0.20124645730453306`, 0.3288531647623917, 0.9347720600748151], 
             UndirectedEdge[159, 272] -> 
             RGBColor[
              0.24467152920527638`, 0.37449566863865497`, 0.9372450536779255],
              UndirectedEdge[130, 351] -> 
             RGBColor[
              0.2715547401921379, 0.40275162787986996`, 0.9387760127734806], 
             UndirectedEdge[113, 378] -> 
             RGBColor[
              0.20184046362642588`, 0.32947750306887713`, 0.9348058878560932],
              UndirectedEdge[145, 417] -> 
             RGBColor[
              0.20308781549592325`, 0.3307885489703952, 0.9348769226997694], 
             UndirectedEdge[38, 354] -> 
             RGBColor[
              0.4147037910637674, 0.5318387842884362, 0.9481369495411083], 
             UndirectedEdge[334, 446] -> 
             RGBColor[
              0.18513113872334164`, 0.31191494316334684`, 0.9338543165220936],
              UndirectedEdge[305, 310] -> 
             RGBColor[
              0.4776836488671362, 0.5829301850756662, 0.9531209010914763], 
             UndirectedEdge[338, 383] -> 
             RGBColor[
              0.34605340544318985`, 0.47036770113504156`, 0.9434098957217043],
              UndirectedEdge[243, 477] -> 
             RGBColor[
              0.19718654273618264`, 0.32458593713760425`, 0.9345408539462529],
              UndirectedEdge[38, 221] -> 
             RGBColor[
              0.7405475305032172, 0.7523239641423858, 0.6316046509416242], 
             UndirectedEdge[330, 357] -> 
             RGBColor[
              0.18906252050836794`, 0.3160470746834114, 0.9340782028987926], 
             UndirectedEdge[48, 365] -> 
             RGBColor[
              0.19846339054879825`, 0.32592798514549043`, 0.9346135685402542],
              UndirectedEdge[384, 411] -> 
             RGBColor[
              0.2746421437909936, 0.40599668481496154`, 0.9389518358410311], 
             UndirectedEdge[38, 436] -> 
             RGBColor[
              0.4371703671484145, 0.5512982032900106, 0.9495684999028087], 
             UndirectedEdge[117, 155] -> 
             RGBColor[
              0.1887434182573529, 0.3157116779853434, 0.9340600304976668], 
             UndirectedEdge[68, 286] -> 
             RGBColor[
              0.1864116908357643, 0.3132608846251963, 0.9339272420704889], 
             UndirectedEdge[378, 380] -> 
             RGBColor[
              0.19721656952288963`, 0.32461749719424154`, 0.9345425639273353],
              UndirectedEdge[12, 285] -> 
             RGBColor[
              0.20421155270957553`, 0.33196966803099826`, 0.9349409178716667],
              UndirectedEdge[93, 432] -> 
             RGBColor[
              0.2569317093580773, 0.38738189531956746`, 0.9379432528003164], 
             UndirectedEdge[340, 499] -> 
             RGBColor[
              0.4961829212208138, 0.5994318600646289, 0.9541521247756388], 
             UndirectedEdge[389, 456] -> 
             RGBColor[
              0.1952664503716337, 0.322567798321576, 0.9344315075266139], 
             UndirectedEdge[390, 451] -> 
             RGBColor[
              0.23050025885424308`, 0.3596007649892832, 0.93643802079595], 
             UndirectedEdge[92, 485] -> 
             RGBColor[
              0.26364199259434656`, 0.39443482845741684`, 0.9383253935036474],
              UndirectedEdge[293, 471] -> 
             RGBColor[
              0.883292777281721, 0.9093153449162048, 0.969810151974432], 
             UndirectedEdge[111, 359] -> 
             RGBColor[
              0.6380588033619161, 0.711320155207173, 0.9679062350071925], 
             UndirectedEdge[357, 441] -> 
             RGBColor[
              0.20500595942209238`, 0.33280463985414815`, 0.9349861581587251],
              UndirectedEdge[52, 268] -> 
             RGBColor[
              0.18314820397606815`, 0.30983075301863783`, 0.9337413913217254],
              UndirectedEdge[30, 311] -> 
             RGBColor[
              0.18445928711484194`, 0.31120878452496137`, 0.9338160555669048],
              UndirectedEdge[164, 486] -> 
             RGBColor[
              0.3646799679598963, 0.49028919172388963`, 0.9444580629779388], 
             UndirectedEdge[194, 290] -> 
             RGBColor[
              0.18381681483281254`, 0.31053350542145297`, 0.9337794677208959],
              UndirectedEdge[238, 445] -> 
             RGBColor[
              0.7249039407503491, 0.7407041936806955, 0.6319785472238091], 
             UndirectedEdge[269, 406] -> 
             RGBColor[
              0.5091880023383142, 0.611421148279524, 0.9547804937952983], 
             UndirectedEdge[99, 341] -> 
             RGBColor[
              0.9869976251000042, 0.9872951064518227, 0.7699640190632113], 
             UndirectedEdge[41, 457] -> 
             RGBColor[
              0.36616941470913866`, 0.48692522378917524`, 0.9448270715857057],
              UndirectedEdge[217, 292] -> 
             RGBColor[
              0.18318117608781065`, 0.30986540879863184`, 0.9337432690347114],
              UndirectedEdge[176, 299] -> 
             RGBColor[
              0.2785034431297019, 0.4092981665779968, 0.9391994481892236], 
             UndirectedEdge[218, 314] -> 
             RGBColor[
              0.27434229412121725`, 0.4056815238004595, 0.9389347598459252], 
             UndirectedEdge[355, 486] -> 
             RGBColor[
              0.48652222048477045`, 0.5929340389323234, 0.9530199242881539], 
             UndirectedEdge[213, 420] -> 
             RGBColor[
              0.19513105630202093`, 0.32242549056993314`, 0.9344237970346471],
              UndirectedEdge[299, 407] -> 
             RGBColor[
              0.2586014952958633, 0.3891369462107238, 0.9380383446392464], 
             UndirectedEdge[201, 314] -> 
             RGBColor[
              0.2601298304238602, 0.39074332333229245`, 0.9381253810638166], 
             UndirectedEdge[160, 300] -> 
             RGBColor[
              0.2356560570579657, 0.36501983579788244`, 0.936731635876332], 
             UndirectedEdge[21, 200] -> 
             RGBColor[
              0.28148912705476437`, 0.4131932983489973, 0.9393417614086988], 
             UndirectedEdge[25, 180] -> 
             RGBColor[
              0.2760199528625702, 0.4074448495073293, 0.9390303000293716], 
             UndirectedEdge[45, 185] -> 
             RGBColor[
              0.2063591315326575, 0.33422690953841927`, 0.935063219308583], 
             UndirectedEdge[191, 226] -> 
             RGBColor[
              0.18878815245387853`, 0.31575869646220367`, 0.9340625780439806],
              UndirectedEdge[50, 82] -> 
             RGBColor[
              0.7002427375322327, 0.764369726655832, 0.9719080506652522], 
             UndirectedEdge[22, 491] -> 
             RGBColor[
              0.1817125626643469, 0.3083218029751023, 0.9336596336728639], 
             UndirectedEdge[99, 277] -> 
             RGBColor[
              0.7114622471897839, 0.7713508183962726, 0.9343566439534178], 
             UndirectedEdge[17, 391] -> 
             RGBColor[
              0.4242791032166461, 0.5413734394625537, 0.9484041876749043], 
             UndirectedEdge[211, 362] -> 
             RGBColor[
              0.1833599948775373, 0.31005335868440065`, 0.9337534525002475], 
             UndirectedEdge[4, 162] -> 
             RGBColor[
              0.18241905104503708`, 0.3090643670571582, 0.9336998671409883], 
             UndirectedEdge[259, 444] -> 
             RGBColor[
              0.6245686648985196, 0.7054652507537504, 0.9640159946250897], 
             UndirectedEdge[347, 382] -> 
             RGBColor[
              0.2075732378156851, 0.3355030122206657, 0.9351323608652922], 
             UndirectedEdge[66, 179] -> 
             RGBColor[
              0.19899718509969622`, 0.32648903706301347`, 0.9346439673502496],
              UndirectedEdge[343, 471] -> 
             RGBColor[
              0.901533639219245, 0.661841877888372, 0.5749261182612281], 
             UndirectedEdge[97, 322] -> 
             RGBColor[
              0.9046195205529701, 0.5667356132446183, 0.288595833391559], 
             UndirectedEdge[363, 381] -> 
             RGBColor[
              0.18545627477246146`, 0.3122566817657879, 0.9338728325390953], 
             UndirectedEdge[238, 471] -> 
             RGBColor[
              0.7217628649306637, 0.780742284826936, 0.9553407683017833], 
             UndirectedEdge[40, 285] -> 
             RGBColor[
              0.19969824891224597`, 0.32722589958001636`, 0.9346838918972433],
              UndirectedEdge[70, 208] -> 
             RGBColor[
              0.39817892177344283`, 0.519304301810809, 0.9465925866929762], 
             UndirectedEdge[84, 448] -> 
             RGBColor[
              0.28804975562944346`, 0.4200889349488619, 0.9397153795004467], 
             UndirectedEdge[152, 195] -> 
             RGBColor[
              0.18616514652705513`, 0.313001750924931, 0.9339132017368377], 
             UndirectedEdge[93, 308] -> 
             RGBColor[
              0.20676738749395213`, 0.33465601243866294`, 0.9350864688816183],
              UndirectedEdge[255, 478] -> 
             RGBColor[
              0.22324206600367816`, 0.3519719441073331, 0.9360246774506443], 
             UndirectedEdge[112, 293] -> 
             RGBColor[
              0.901595183019146, 0.9214285748097474, 0.8700135366280143], 
             UndirectedEdge[87, 184] -> 
             RGBColor[
              0.4246238918446351, 0.5398024449911591, 0.9489353468656369], 
             UndirectedEdge[149, 323] -> 
             RGBColor[
              0.7769198644929252, 0.8229213917028264, 0.8645345338157826], 
             UndirectedEdge[272, 497] -> 
             RGBColor[
              0.3677045224545963, 0.48747048871276477`, 0.9450117306986173], 
             UndirectedEdge[80, 471] -> 
             RGBColor[
              0.6521263465827374, 0.7213327352775194, 0.9506532320788272], 
             UndirectedEdge[339, 344] -> 
             RGBColor[
              0.1852310273425353, 0.3120199324354236, 0.9338600050311847], 
             UndirectedEdge[137, 393] -> 
             RGBColor[
              0.21648582185917808`, 0.3448707031408432, 0.9356399193415825], 
             UndirectedEdge[11, 316] -> 
             RGBColor[
              0.4071433573553281, 0.5270688453462049, 0.9471637926013148], 
             UndirectedEdge[88, 423] -> 
             RGBColor[
              0.18437944571093495`, 0.3111248661472177, 0.9338115087170672], 
             UndirectedEdge[70, 351] -> 
             RGBColor[
              0.3049667644622824, 0.4322301812417861, 0.9408852716041266], 
             UndirectedEdge[55, 298] -> 
             RGBColor[
              0.424640850686557, 0.5359021493799299, 0.9492929643380126], 
             UndirectedEdge[428, 437] -> 
             RGBColor[
              0.18484681961512717`, 0.31161610575374077`, 0.9338381249694931],
              UndirectedEdge[90, 137] -> 
             RGBColor[
              0.23700337417738956`, 0.3664359515152362, 0.9368083635931062], 
             UndirectedEdge[344, 439] -> 
             RGBColor[
              0.19475306873947695`, 0.32202820167590374`, 0.9344022712021427],
              UndirectedEdge[93, 274] -> 
             RGBColor[
              0.23335737797095998`, 0.3626037783327675, 0.936600729502918], 
             UndirectedEdge[60, 434] -> 
             RGBColor[
              0.9602863904874878, 0.8842947028459596, 0.5783529786054818], 
             UndirectedEdge[54, 244] -> 
             RGBColor[
              0.7181235795673231, 0.775643062211419, 0.8864694686198505], 
             UndirectedEdge[243, 318] -> 
             RGBColor[
              0.19728008332867447`, 0.3246842542311293, 0.9345461809446143], 
             UndirectedEdge[384, 402] -> 
             RGBColor[
              0.24310211003433443`, 0.3728461095830723, 0.937155677577888], 
             UndirectedEdge[83, 233] -> 
             RGBColor[
              0.9788921335245182, 0.9819450762719373, 0.8385157306415634], 
             UndirectedEdge[153, 201] -> 
             RGBColor[
              0.2425444285480653, 0.37225995098195497`, 0.9371239184422607], 
             UndirectedEdge[275, 331] -> 
             RGBColor[
              0.39537355093788906`, 0.515221122490898, 0.946708621365979], 
             UndirectedEdge[312, 327] -> 
             RGBColor[
              0.18937402646973123`, 0.31637448719942296`, 0.9340959427024605],
              UndirectedEdge[181, 370] -> 
             RGBColor[
              0.2271386690157574, 0.35606752093192884`, 0.9362465832276747], 
             UndirectedEdge[32, 245] -> 
             RGBColor[
              0.23179881460343715`, 0.36096562941487603`, 0.9365119716248255],
              UndirectedEdge[176, 391] -> 
             RGBColor[
              0.3950241069319744, 0.5160342320796381, 0.9465400851808224], 
             UndirectedEdge[148, 232] -> 
             RGBColor[
              0.27654750718772436`, 0.40799934255194237`, 0.9390603434677424],
              UndirectedEdge[430, 477] -> 
             RGBColor[
              0.19967498374543186`, 0.3272014464145979, 0.9346825669804111], 
             UndirectedEdge[7, 475] -> 
             RGBColor[
              0.40444131336028016`, 0.5242115978182725, 0.9471344342497021], 
             UndirectedEdge[15, 50] -> 
             RGBColor[
              0.7663849277124503, 0.8179130209698517, 0.9772202389257285], 
             UndirectedEdge[168, 395] -> 
             RGBColor[
              0.3984267572015211, 0.5166565922466431, 0.9470439450191381], 
             UndirectedEdge[97, 440] -> 
             RGBColor[
              0.9400446504463722, 0.7867672719569345, 0.32047255191532753`], 
             UndirectedEdge[71, 308] -> 
             RGBColor[
              0.19432153409427227`, 0.32157463140291687`, 0.9343776959424965],
              UndirectedEdge[253, 436] -> 
             RGBColor[
              0.36650668927910635`, 0.49187140591690626`, 0.9445744600450926],
              UndirectedEdge[13, 430] -> 
             RGBColor[
              0.22725075415308893`, 0.3561853295178724, 0.9362529663104306], 
             UndirectedEdge[209, 233] -> 
             RGBColor[
              0.9785167541303205, 0.9817898472456261, 0.8447367386541516], 
             UndirectedEdge[254, 350] -> 
             RGBColor[
              0.18697690227356584`, 0.31385495768280075`, 0.9339594300257164],
              UndirectedEdge[115, 268] -> 
             RGBColor[
              0.18864406926620203`, 0.3156072558965539, 0.9340543727195945], 
             UndirectedEdge[42, 468] -> 
             RGBColor[
              0.21102583019430793`, 0.33913190571759855`, 0.9353289808936021],
              UndirectedEdge[51, 60] -> 
             RGBColor[
              0.9903726876472161, 0.9902614167392676, 0.8073625961746422], 
             UndirectedEdge[331, 348] -> 
             RGBColor[
              0.3817575877124325, 0.5041670701523192, 0.9456367228639543], 
             UndirectedEdge[310, 406] -> 
             RGBColor[
              0.5306573998942516, 0.6288133856772102, 0.9564963416640753], 
             UndirectedEdge[70, 130] -> 
             RGBColor[
              0.33633111822806117`, 0.4651961056645053, 0.9426714251516843], 
             UndirectedEdge[83, 440] -> 
             RGBColor[
              0.9434296852982257, 0.7965522714191877, 0.48002728769919345`], 
             UndirectedEdge[100, 374] -> 
             RGBColor[
              0.9203355927006582, 0.6768022824414968, 0.3486163331687475], 
             UndirectedEdge[207, 374] -> 
             RGBColor[
              0.8612156544492956, 0.4454551404687426, 0.20523222788802623`], 
             UndirectedEdge[51, 324] -> 
             RGBColor[
              0.9674926297054737, 0.9734136310223126, 0.8557710419754258], 
             UndirectedEdge[164, 180] -> 
             RGBColor[
              0.28958519225458484`, 0.42102975172188783`, 0.9398274630675963],
              UndirectedEdge[56, 132] -> 
             RGBColor[
              0.3395809707923225, 0.46518136452608577`, 0.94298210840368], 
             UndirectedEdge[30, 423] -> 
             RGBColor[
              0.17906694420854233`, 0.3055410902361533, 0.9335089696156476], 
             UndirectedEdge[104, 379] -> 
             RGBColor[
              0.8757781230833462, 0.4743585366446421, 0.21585393387585383`], 
             UndirectedEdge[324, 457] -> 
             RGBColor[
              0.7044919829810323, 0.7672858327374596, 0.9691306015608669], 
             UndirectedEdge[283, 459] -> 
             RGBColor[
              0.18839869617185917`, 0.3153493532168468, 0.9340403990848687], 
             UndirectedEdge[128, 245] -> 
             RGBColor[
              0.21909064595633707`, 0.347608538422344, 0.9357882602204238], 
             UndirectedEdge[34, 62] -> 
             RGBColor[
              0.23006104796724536`, 0.35913912649947, 0.9364130083856896], 
             UndirectedEdge[320, 424] -> 
             RGBColor[
              0.18730513840807234`, 0.31419995467154005`, 0.9339781225879946],
              UndirectedEdge[111, 351] -> 
             RGBColor[
              0.3033909458875273, 0.43086528639527777`, 0.9407848618379848], 
             UndirectedEdge[79, 316] -> 
             RGBColor[
              0.6624800077652702, 0.7332731084999433, 0.9690938030221024], 
             UndirectedEdge[43, 250] -> 
             RGBColor[
              0.22400512105631526`, 0.3527739633481394, 0.9360681323070532], 
             UndirectedEdge[116, 313] -> 
             RGBColor[
              0.3188496851508186, 0.44760999428327536`, 0.9416470314755198], 
             UndirectedEdge[87, 436] -> 
             RGBColor[
              0.33196658064928775`, 0.46192364467997304`, 0.9423747246250382],
              UndirectedEdge[280, 393] -> 
             RGBColor[
              0.23739481376153632`, 0.3668473793368775, 0.9368306554983403], 
             UndirectedEdge[295, 321] -> 
             RGBColor[
              0.9851155314829081, 0.988112904001859, 0.896337693305348], 
             UndirectedEdge[131, 186] -> 
             RGBColor[
              0.913526249632497, 0.6241954645463874, 0.3472925437386266], 
             UndirectedEdge[165, 313] -> 
             RGBColor[
              0.3335735057381806, 0.4630856632647371, 0.9424855312760294], 
             UndirectedEdge[140, 270] -> 
             RGBColor[
              0.1795641494336302, 0.30606368445235266`, 0.9335372847176671], 
             UndirectedEdge[322, 445] -> 
             RGBColor[
              0.89195053197754, 0.5240001399597152, 0.23937920511375732`], 
             UndirectedEdge[112, 463] -> 
             RGBColor[
              0.7743003013960627, 0.8206490549360065, 0.8582392599813213], 
             UndirectedEdge[115, 223] -> 
             RGBColor[
              0.1995856510144891, 0.3271075520503548, 0.9346774796135398], 
             UndirectedEdge[102, 451] -> 
             RGBColor[
              0.20226457959273075`, 0.32992327583996894`, 0.9348300406329509],
              UndirectedEdge[148, 267] -> 
             RGBColor[
              0.25194617616278553`, 0.3821417838302541, 0.9376593340602799], 
             UndirectedEdge[447, 500] -> 
             RGBColor[
              0.21735914083056895`, 0.34578861675139594`, 0.9356896535650436],
              UndirectedEdge[238, 293] -> 
             RGBColor[
              0.6482189757415503, 0.7227281926989446, 0.9672024760249813], 
             UndirectedEdge[56, 457] -> 
             RGBColor[
              0.4380492997215996, 0.5534053955584954, 0.9492526271337134], 
             UndirectedEdge[204, 331] -> 
             RGBColor[
              0.3086689498622105, 0.44109928644623464`, 0.9409138412479245], 
             UndirectedEdge[66, 260] -> 
             RGBColor[
              0.203816558535701, 0.331554504110179, 0.9349184235378061], 
             UndirectedEdge[225, 424] -> 
             RGBColor[
              0.18871848366086047`, 0.31568547014348514`, 0.9340586105092841],
              UndirectedEdge[178, 244] -> 
             RGBColor[
              0.45801552683844415`, 0.5706975580302278, 0.9505252940081765], 
             UndirectedEdge[139, 247] -> 
             RGBColor[
              0.18343934894517555`, 0.310136764840827, 0.9337579715970057], 
             UndirectedEdge[244, 448] -> 
             RGBColor[
              0.373652859998312, 0.49730643195466345`, 0.9450574383468822], 
             UndirectedEdge[259, 275] -> 
             RGBColor[
              0.586292797645066, 0.6743911774092273, 0.9610027781457763], 
             UndirectedEdge[282, 406] -> 
             RGBColor[
              0.5566077877471345, 0.6490860258981348, 0.9590828338050883], 
             UndirectedEdge[286, 357] -> 
             RGBColor[
              0.1879701028596808, 0.3148988744713619, 0.934015991329787], 
             UndirectedEdge[206, 396] -> 
             RGBColor[
              0.18892633617542332`, 0.3159039363149012, 0.9340704474024981], 
             UndirectedEdge[154, 295] -> 
             RGBColor[
              0.9841314996436169, 0.9875855475713144, 0.9072523679449918], 
             UndirectedEdge[410, 428] -> 
             RGBColor[
              0.18501111447909718`, 0.3117887900726693, 0.9338474813189439], 
             UndirectedEdge[104, 147] -> 
             RGBColor[
              0.8716060245867224, 0.4422899593743725, 0.21185872764377553`], 
             UndirectedEdge[32, 255] -> 
             RGBColor[
              0.20842141467182945`, 0.3363944998739921, 0.9351806632824844], 
             UndirectedEdge[165, 498] -> 
             RGBColor[
              0.5402564536084126, 0.6313553023460808, 0.9594503111519376], 
             UndirectedEdge[248, 439] -> 
             RGBColor[
              0.18975162768821172`, 0.3167713700213459, 0.934117446533242], 
             UndirectedEdge[141, 389] -> 
             RGBColor[
              0.20111521708192343`, 0.32871522296731825`, 0.9347645861382899],
              UndirectedEdge[328, 478] -> 
             RGBColor[
              0.24615010342073995`, 0.376049743886127, 0.9373292562921416], 
             UndirectedEdge[178, 261] -> 
             RGBColor[
              0.3993010721320601, 0.5198420484378579, 0.9467840608734395], 
             UndirectedEdge[120, 315] -> 
             RGBColor[
              0.18165682168185682`, 0.3082632156683228, 0.9336564593063725], 
             UndirectedEdge[47, 136] -> 
             RGBColor[
              0.40491583995544145`, 0.5205967008566313, 0.9476756741243257], 
             UndirectedEdge[74, 144] -> 
             RGBColor[
              0.1927927730691202, 0.31996780663643465`, 0.9342906352637134], 
             UndirectedEdge[165, 361] -> 
             RGBColor[
              0.26801366747199473`, 0.39902973593402147`, 0.9385743539206161],
              UndirectedEdge[32, 482] -> 
             RGBColor[
              0.27602220405873207`, 0.40526283104925287`, 0.9391104092526332],
              UndirectedEdge[67, 119] -> 
             RGBColor[
              0.18259585546660687`, 0.3092501997142758, 0.933709935891238], 
             UndirectedEdge[97, 326] -> 
             RGBColor[
              0.8569194124299913, 0.8790587115212953, 0.6914601091734929], 
             UndirectedEdge[409, 430] -> 
             RGBColor[
              0.22739490707234228`, 0.3563368433758307, 0.9362611756059269], 
             UndirectedEdge[113, 190] -> 
             RGBColor[
              0.20663037548476026`, 0.33451200412993914`, 0.9350786662503858],
              UndirectedEdge[292, 496] -> 
             RGBColor[
              0.1854675912889076, 0.3122685761420814, 0.9338734769979656], 
             UndirectedEdge[15, 82] -> 
             RGBColor[
              0.5862643398841738, 0.6748409125363397, 0.9606772556368353], 
             UndirectedEdge[340, 414] -> 
             RGBColor[
              0.3932297908847611, 0.5150176133855842, 0.946277232449094], 
             UndirectedEdge[149, 282] -> 
             RGBColor[
              0.6289215162862603, 0.7087932049561856, 0.9644994328569398], 
             UndirectedEdge[330, 368] -> 
             RGBColor[
              0.18440628949779087`, 0.3111530806691976, 0.9338130374310167], 
             UndirectedEdge[331, 431] -> 
             RGBColor[
              0.3613433617487599, 0.48672321452944306`, 0.9442702081951819], 
             UndirectedEdge[4, 488] -> 
             RGBColor[
              0.1820203772126724, 0.30864533558196194`, 0.9336771632560201], 
             UndirectedEdge[87, 409] -> 
             RGBColor[
              0.28082294387369244`, 0.4124930975872375, 0.9393038232620665], 
             UndirectedEdge[440, 445] -> 
             RGBColor[
              0.9273756618709421, 0.7440317986720315, 0.27125592363752593`], 
             UndirectedEdge[55, 200] -> 
             RGBColor[
              0.4182843192455511, 0.5292210318080617, 0.9489309692760928], 
             UndirectedEdge[64, 215] -> 
             RGBColor[
              0.18488430371745596`, 0.31165550392191765`, 0.9338402596336681],
              UndirectedEdge[167, 493] -> 
             RGBColor[
              0.25038390854803594`, 0.3804997415136645, 0.9375703652307877], 
             UndirectedEdge[153, 470] -> 
             RGBColor[
              0.2111255154646311, 0.3392366812571194, 0.9353346578222758], 
             UndirectedEdge[185, 187] -> 
             RGBColor[
              0.21639359634399347`, 0.34477376827694883`, 0.9356346672349283],
              UndirectedEdge[18, 310] -> 
             RGBColor[
              0.46656300779364224`, 0.5714089084514553, 0.952481474208732], 
             UndirectedEdge[226, 366] -> 
             RGBColor[
              0.18476826025973897`, 0.3115335348902769, 0.9338336511304219], 
             UndirectedEdge[333, 361] -> 
             RGBColor[
              0.2309444912286668, 0.3600676813807619, 0.9364633191724905], 
             UndirectedEdge[236, 300] -> 
             RGBColor[
              0.22011134127912346`, 0.34868135392241384`, 0.9358463873090731],
              UndirectedEdge[161, 335] -> 
             RGBColor[
              0.21211283365491676`, 0.3402744152746985, 0.9353908841326062], 
             UndirectedEdge[61, 397] -> 
             RGBColor[
              0.9061343995223057, 0.5802110742285213, 0.48990321177495955`], 
             UndirectedEdge[393, 480] -> 
             RGBColor[
              0.23233850550566576`, 0.36153287877149787`, 0.9365427062233063],
              UndirectedEdge[349, 378] -> 
             RGBColor[
              0.1960796577618784, 0.3234225308490497, 0.9344778184844558], 
             UndirectedEdge[97, 163] -> 
             RGBColor[
              0.9438826652312557, 0.8041948007039634, 0.3236750855301855], 
             UndirectedEdge[229, 267] -> 
             RGBColor[
              0.23204884719292487`, 0.3612284295194095, 0.9365262106109067], 
             UndirectedEdge[77, 287] -> 
             RGBColor[
              0.31931088859466533`, 0.4505681988320882, 0.9415827311905192], 
             UndirectedEdge[41, 485] -> 
             RGBColor[
              0.2592162515913262, 0.38978309405505573`, 0.9380733541008225], 
             UndirectedEdge[7, 89] -> 
             RGBColor[
              0.39101776123385745`, 0.5125847916537125, 0.9462790973781875], 
             UndirectedEdge[41, 44] -> 
             RGBColor[
              0.27104906144274005`, 0.40222012745236824`, 0.938747215116787], 
             UndirectedEdge[147, 234] -> 
             RGBColor[
              0.872729313424225, 0.4467434253012546, 0.2127625522094079], 
             UndirectedEdge[259, 331] -> 
             RGBColor[
              0.4923539796181456, 0.5933274496466499, 0.9547717909351274], 
             UndirectedEdge[77, 409] -> 
             RGBColor[
              0.2938507755920474, 0.42380800580193695`, 0.940132815419882], 
             UndirectedEdge[2, 334] -> 
             RGBColor[
              0.18552483193608832`, 0.31232873969153496`, 0.9338767367681426],
              UndirectedEdge[315, 487] -> 
             RGBColor[
              0.1880750117052634, 0.3150091403196742, 0.9340219657333442], 
             UndirectedEdge[251, 258] -> 
             RGBColor[
              0.3270553942889411, 0.45124571304551764`, 0.9422970062673146], 
             UndirectedEdge[39, 96] -> 
             RGBColor[
              0.359182658449612, 0.4793995184819319, 0.94444576944529], 
             UndirectedEdge[219, 497] -> 
             RGBColor[
              0.5738542866268592, 0.6645036181845554, 0.959879595311844], 
             UndirectedEdge[447, 454] -> 
             RGBColor[
              0.2225609566268063, 0.3512560549674121, 0.9359858892792425], 
             UndirectedEdge[417, 458] -> 
             RGBColor[
              0.21807667250257026`, 0.34654278803280497`, 0.9357305159322711],
              UndirectedEdge[189, 422] -> 
             RGBColor[
              0.22925608385888036`, 0.3582930581839061, 0.936367166870556], 
             UndirectedEdge[431, 444] -> 
             RGBColor[
              0.4935580470291339, 0.5988610156365437, 0.9535144118851442], 
             UndirectedEdge[161, 273] -> 
             RGBColor[
              0.20050467294518176`, 0.3280735023688687, 0.9347298165529216], 
             UndirectedEdge[109, 413] -> 
             RGBColor[
              0.22197296688604118`, 0.35063804046916514`, 0.9359524041333588],
              UndirectedEdge[236, 470] -> 
             RGBColor[
              0.2014866380141136, 0.3291056099164974, 0.9347857380109101], 
             UndirectedEdge[287, 436] -> 
             RGBColor[
              0.3298373627600314, 0.45968570167815315`, 0.9422534688161406], 
             UndirectedEdge[253, 473] -> 
             RGBColor[
              0.32054318862790937`, 0.44788551033051344`, 0.9417985597710807],
              UndirectedEdge[166, 435] -> 
             RGBColor[
              0.21704014991788595`, 0.3454533370769741, 0.9356714875044712], 
             UndirectedEdge[114, 312] -> 
             RGBColor[
              0.1882015984664733, 0.31514219103177, 0.9340291746621268], 
             UndirectedEdge[222, 296] -> 
             RGBColor[
              0.18966575842362554`, 0.31668111597984006`, 0.934112556405656], 
             UndirectedEdge[5, 346] -> 
             RGBColor[
              0.5654957918264961, 0.6570874909093873, 0.9595208737141337], 
             UndirectedEdge[86, 220] -> 
             RGBColor[
              0.20117259087192368`, 0.32877552645831687`, 0.9347678534907535],
              UndirectedEdge[195, 255] -> 
             RGBColor[
              0.19263264106654965`, 0.3197994977487777, 0.9342815159830611], 
             UndirectedEdge[313, 407] -> 
             RGBColor[
              0.31917500731539133`, 0.44795192850485793`, 0.9416655580915212],
              UndirectedEdge[224, 441] -> 
             RGBColor[
              0.21370093658000952`, 0.34194361214051205`, 0.9354813242448025],
              UndirectedEdge[172, 211] -> 
             RGBColor[
              0.20548759572979827`, 0.33331087015105276`, 0.9350135866339319],
              UndirectedEdge[204, 355] -> 
             RGBColor[
              0.4378065045945586, 0.5507389343512965, 0.9499158019492457], 
             UndirectedEdge[109, 180] -> 
             RGBColor[
              0.23839049921865452`, 0.36789390788241305`, 0.9368873583121385],
              UndirectedEdge[96, 157] -> 
             RGBColor[
              0.3849349952696799, 0.5064668572722832, 0.9459123269300246], 
             UndirectedEdge[316, 372] -> 
             RGBColor[
              0.5264921273018517, 0.6260724945913516, 0.9559761056168596], 
             UndirectedEdge[53, 112] -> 
             RGBColor[
              0.9130580700237505, 0.6218566223199413, 0.468638906464419], 
             UndirectedEdge[28, 305] -> 
             RGBColor[
              0.3931980637426643, 0.5143785677629451, 0.9464441881014032], 
             UndirectedEdge[186, 341] -> 
             RGBColor[
              0.9938102781827736, 0.9891691358468536, 0.5676651626091419], 
             UndirectedEdge[65, 86] -> 
             RGBColor[
              0.18424555499085607`, 0.31098413851125284`, 0.9338038838386322],
              UndirectedEdge[10, 390] -> 
             RGBColor[
              0.24135031626720926`, 0.37100486326368376`, 0.9370559155143968],
              UndirectedEdge[48, 140] -> 
             RGBColor[
              0.1844487281323768, 0.3111976863649123, 0.9338154542484741], 
             UndirectedEdge[231, 404] -> 
             RGBColor[
              0.8002424461846211, 0.8440108833840196, 0.9806882202971826], 
             UndirectedEdge[87, 354] -> 
             RGBColor[
              0.30950000456464066`, 0.4424642256783988, 0.9409431742633377], 
             UndirectedEdge[136, 434] -> 
             RGBColor[
              0.7316510467407765, 0.7040970288480641, 0.6113123490612679], 
             UndirectedEdge[205, 413] -> 
             RGBColor[
              0.2338956489319965, 0.363169535241167, 0.9366313832378486], 
             UndirectedEdge[20, 490] -> 
             RGBColor[
              0.22886274008807128`, 0.3578796289413503, 0.9363447665247084], 
             UndirectedEdge[390, 443] -> 
             RGBColor[
              0.2718752322958543, 0.4030884854012488, 0.9387942643246616], 
             UndirectedEdge[296, 385] -> 
             RGBColor[
              0.18189236637294215`, 0.30851078807304944`, 0.9336698732280726],
              UndirectedEdge[86, 290] -> 
             RGBColor[
              0.18341921937923714`, 0.31011560739073746`, 0.9337568252480046],
              UndirectedEdge[24, 74] -> 
             RGBColor[
              0.18699882666459755`, 0.3138780016078617, 0.9339606785873513], 
             UndirectedEdge[38, 336] -> 
             RGBColor[
              0.5720852226715933, 0.663483581767208, 0.9594557908273795], 
             UndirectedEdge[383, 443] -> 
             RGBColor[
              0.2778055713012203, 0.40932164770109847`, 0.9391319883578669], 
             UndirectedEdge[14, 435] -> 
             RGBColor[
              0.23468936895954257`, 0.3640037853148743, 0.9366765844192138], 
             UndirectedEdge[282, 323] -> 
             RGBColor[
              0.8447117696653836, 0.8771252738990953, 0.8704406417188999], 
             UndirectedEdge[307, 337] -> 
             RGBColor[
              0.19042947914241254`, 0.31748383487797555`, 0.9341560491707674],
              UndirectedEdge[157, 356] -> 
             RGBColor[
              0.272205938145604, 0.40343607821729777`, 0.9388130975335695], 
             UndirectedEdge[166, 439] -> 
             RGBColor[
              0.19745604044376464`, 0.3248691963154145, 0.9345562014420135], 
             UndirectedEdge[266, 293] -> 
             RGBColor[
              0.9016661303754756, 0.9199925303309897, 0.7623198781355807], 
             UndirectedEdge[2, 260] -> 
             RGBColor[
              0.1969726482624509, 0.32436112048401927`, 0.9345286729724024], 
             UndirectedEdge[135, 466] -> 
             RGBColor[
              0.18744105358565671`, 0.3143428101407012, 0.9339858627562896], 
             UndirectedEdge[60, 495] -> 
             RGBColor[
              0.9357924776533132, 0.7819607374227355, 0.5583743815380187], 
             UndirectedEdge[217, 464] -> 
             RGBColor[
              0.19184821856094375`, 0.31897501996012645`, 0.9342368442818159],
              UndirectedEdge[435, 453] -> 
             RGBColor[
              0.2391644667053946, 0.36870739678334974`, 0.9369314346155262], 
             UndirectedEdge[82, 411] -> 
             RGBColor[
              0.4006657201660342, 0.5170983953721258, 0.9473454462572704], 
             UndirectedEdge[94, 193] -> 
             RGBColor[
              0.17992543383268728`, 0.3064434172625156, 0.9335578593297211], 
             UndirectedEdge[88, 469] -> 
             RGBColor[
              0.1854557592359103, 0.3122561399041857, 0.9338728031800514], 
             UndirectedEdge[36, 76] -> 
             RGBColor[
              0.7022798190159381, 0.7608775969992009, 0.8471463932234504], 
             UndirectedEdge[163, 326] -> 
             RGBColor[
              0.8123452824001817, 0.7105293109037376, 0.6054779360527895], 
             UndirectedEdge[151, 472] -> 
             RGBColor[
              0.1934245140122105, 0.3206318064223118, 0.9343266119758453], 
             UndirectedEdge[114, 138] -> 
             RGBColor[
              0.18210218513342014`, 0.30873132089358957`, 0.9336818220960829],
              UndirectedEdge[448, 475] -> 
             RGBColor[
              0.3185563246566676, 0.44958458227411635`, 0.9415467358348658], 
             UndirectedEdge[169, 362] -> 
             RGBColor[
              0.18152465259386255`, 0.3081242975768366, 0.9336489324723378], 
             UndirectedEdge[20, 25] -> 
             RGBColor[
              0.26532620998703904`, 0.39620504772268694`, 0.9384213071925849],
              UndirectedEdge[113, 349] -> 
             RGBColor[
              0.19095597353932497`, 0.3180372138708033, 0.934186032247793], 
             UndirectedEdge[457, 494] -> 
             RGBColor[
              0.4122768656126409, 0.531082608493518, 0.9476104304219592], 
             UndirectedEdge[364, 452] -> 
             RGBColor[
              0.21560011293675418`, 0.34393976690618655`, 0.9355894795287394],
              UndirectedEdge[351, 442] -> 
             RGBColor[
              0.23904734061072216`, 0.3685842898316257, 0.936924764457707], 
             UndirectedEdge[71, 466] -> 
             RGBColor[
              0.1963124589116516, 0.3236672196179068, 0.934491076165537], 
             UndirectedEdge[87, 285] -> 
             RGBColor[
              0.2614000119680612, 0.39207836466940904`, 0.9381977160236936], 
             UndirectedEdge[211, 369] -> 
             RGBColor[
              0.1847549864301014, 0.3115195832537184, 0.933832895205461], 
             UndirectedEdge[164, 316] -> 
             RGBColor[
              0.37736919780669476`, 0.5012799648379501, 0.9452666094831315], 
             UndirectedEdge[27, 297] -> 
             RGBColor[
              0.19023703211735066`, 0.31728156085278936`, 0.93414508959739], 
             UndirectedEdge[238, 483] -> 
             RGBColor[
              0.46936492725835366`, 0.5800559392387936, 0.9513788548661433], 
             UndirectedEdge[109, 164] -> 
             RGBColor[
              0.2648306442899861, 0.3950111522821019, 0.9384177281820844], 
             UndirectedEdge[83, 355] -> 
             RGBColor[
              0.7774683536702185, 0.8228654453922359, 0.8436241428882965], 
             UndirectedEdge[85, 166] -> 
             RGBColor[
              0.19147571921883372`, 0.31858349953374643`, 0.9342156309953462],
              UndirectedEdge[34, 190] -> 
             RGBColor[
              0.2127364473424475, 0.3409298727996848, 0.9354263980095573], 
             UndirectedEdge[232, 383] -> 
             RGBColor[
              0.2731170371748888, 0.40439370106409095`, 0.938864983275437], 
             UndirectedEdge[185, 441] -> 
             RGBColor[
              0.21650425944697038`, 0.34489008221462353`, 0.9356409693349313],
              UndirectedEdge[83, 207] -> 
             RGBColor[
              0.9351069377955797, 0.7587606188367377, 0.47308258317377627`], 
             UndirectedEdge[138, 385] -> 
             RGBColor[
              0.18216276894964933`, 0.30879499832568225`, 0.9336852722547914],
              UndirectedEdge[131, 234] -> 
             RGBColor[
              0.88005378670787, 0.5030425365640092, 0.21977647609763581`], 
             UndirectedEdge[80, 81] -> 
             RGBColor[
              0.2928864737857844, 0.4215973242135559, 0.9401217329908362], 
             UndirectedEdge[5, 486] -> 
             RGBColor[
              0.5514554325451628, 0.6449264373888728, 0.9586262344361294], 
             UndirectedEdge[94, 139] -> 
             RGBColor[
              0.18076319755662762`, 0.3073239600536649, 0.9336055687344391], 
             UndirectedEdge[126, 249] -> 
             RGBColor[
              0.6077030059991793, 0.6911038805087482, 0.9631457140050295], 
             UndirectedEdge[359, 483] -> 
             RGBColor[
              0.6807834462506754, 0.7483260934744262, 0.970628611472146], 
             UndirectedEdge[275, 404] -> 
             RGBColor[
              0.663069657712535, 0.7345059792856424, 0.9686190519229416], 
             UndirectedEdge[313, 391] -> 
             RGBColor[
              0.4171675799720802, 0.5352137954636619, 0.9479510477022336], 
             UndirectedEdge[1, 487] -> 
             RGBColor[
              0.19600881958127922`, 0.3233480754298399, 0.9344737843548664], 
             UndirectedEdge[71, 172] -> 
             RGBColor[
              0.21061538458324242`, 0.3387005013566139, 0.9353056066232517], 
             UndirectedEdge[44, 494] -> 
             RGBColor[
              0.31715651234624226`, 0.44637751215671095`, 0.9415305739530406],
              UndirectedEdge[85, 387] -> 
             RGBColor[
              0.18808022272596522`, 0.31501461743282955`, 0.9340222624932641],
              UndirectedEdge[414, 499] -> 
             RGBColor[
              0.5256197261535013, 0.6249285409604874, 0.9560278119560052], 
             UndirectedEdge[89, 376] -> 
             RGBColor[
              0.3403951990959194, 0.4692549455218861, 0.9429106589801041], 
             UndirectedEdge[171, 403] -> 
             RGBColor[
              0.6070518602239434, 0.6903231179453404, 0.9632668381945488], 
             UndirectedEdge[161, 279] -> 
             RGBColor[
              0.21091668232154126`, 0.339017184382946, 0.9353227650837177], 
             UndirectedEdge[149, 310] -> 
             RGBColor[
              0.6029711284333774, 0.688520564735261, 0.9619129407159268], 
             UndirectedEdge[333, 367] -> 
             RGBColor[
              0.21446892121193922`, 0.34275081268170826`, 0.9355250598334595],
              UndirectedEdge[43, 227] -> 
             RGBColor[
              0.21076377490674741`, 0.3388564689951076, 0.9353140572326515], 
             UndirectedEdge[71, 369] -> 
             RGBColor[
              0.18988277528354555`, 0.3169092144592796, 0.9341249151947808], 
             UndirectedEdge[134, 174] -> 
             RGBColor[
              0.18580423451035571`, 0.31262240951223635`, 0.9338926483314081],
              UndirectedEdge[158, 370] -> 
             RGBColor[
              0.21023358203312498`, 0.3382992026687606, 0.9352838635328488], 
             UndirectedEdge[7, 391] -> 
             RGBColor[
              0.47273438056684836`, 0.582826092442144, 0.9516345286027679], 
             UndirectedEdge[200, 228] -> 
             RGBColor[
              0.26059605928059204`, 0.3912333594213344, 0.9381519321074836], 
             UndirectedEdge[201, 300] -> 
             RGBColor[
              0.24465748938560672`, 0.37448091189800614`, 0.9372442541309653],
              UndirectedEdge[210, 320] -> 
             RGBColor[
              0.18833104309187587`, 0.31527824554033135`, 0.9340365463420472],
              UndirectedEdge[69, 103] -> 
             RGBColor[
              0.4263301464035756, 0.5436874776637394, 0.9483863578332576], 
             UndirectedEdge[97, 281] -> 
             RGBColor[
              0.903440360362725, 0.5576720713111039, 0.28746666826170925`], 
             UndirectedEdge[192, 272] -> 
             RGBColor[
              0.28510804558804614`, 0.41660469339403305`, 0.9395622181414255],
              UndirectedEdge[70, 463] -> 
             RGBColor[
              0.4624511336723232, 0.5722084360335765, 0.9514519951932873], 
             UndirectedEdge[285, 477] -> 
             RGBColor[
              0.20609075774927643`, 0.3339448316762051, 0.935047935818643], 
             UndirectedEdge[10, 168] -> 
             RGBColor[
              0.25974966627430485`, 0.39034374670731053`, 0.9381037312779018],
              UndirectedEdge[298, 468] -> 
             RGBColor[
              0.24859500261068126`, 0.37861948795031725`, 0.9374684896841046],
              UndirectedEdge[37, 264] -> 
             RGBColor[
              0.8636993298194549, 0.4739723151879993, 0.20797971857725228`], 
             UndirectedEdge[191, 405] -> 
             RGBColor[
              0.18612791917026347`, 0.3129626226125922, 0.9339110816939413], 
             UndirectedEdge[349, 380] -> 
             RGBColor[
              0.18633207943578872`, 0.3131772079961678, 0.9339227083190349], 
             UndirectedEdge[94, 410] -> 
             RGBColor[
              0.18058759193707163`, 0.30713938741347224`, 0.9335955682541907],
              UndirectedEdge[335, 409] -> 
             RGBColor[
              0.23180434544224413`, 0.3609714426771376, 0.9365122865979134], 
             UndirectedEdge[168, 189] -> 
             RGBColor[
              0.272342262398906, 0.403579363650975, 0.9388208609981212], 
             UndirectedEdge[187, 399] -> 
             RGBColor[
              0.214562612650492, 0.3428492883240075, 0.9355303954222809], 
             UndirectedEdge[153, 314] -> 
             RGBColor[
              0.24522255976789442`, 0.3750748366973221, 0.93727643405329], 
             UndirectedEdge[233, 355] -> 
             RGBColor[
              0.7611336222299645, 0.8125163214181457, 0.9533731433112391], 
             UndirectedEdge[233, 486] -> 
             RGBColor[
              0.6879460003390702, 0.7520136698120249, 0.9479115120414208], 
             UndirectedEdge[49, 264] -> 
             RGBColor[
              0.9297344136885161, 0.7358812173257631, 0.3948314869060207], 
             UndirectedEdge[205, 331] -> 
             RGBColor[
              0.26945802412846753`, 0.40054784635747565`, 0.938656607895468], 
             UndirectedEdge[308, 456] -> 
             RGBColor[
              0.1932579406357965, 0.32045672724233865`, 0.9343171258684819], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.2456814749936662, 0.3755571856965141, 0.9373025685964933], 
             UndirectedEdge[175, 371] -> 
             RGBColor[
              0.32587980547058965`, 0.4516283990891108, 0.9421708041706565], 
             UndirectedEdge[21, 188] -> 
             RGBColor[
              0.26198974805947073`, 0.39269821469290833`, 0.9382313006216629],
              UndirectedEdge[79, 221] -> 
             RGBColor[
              0.9242610852428408, 0.8982704304455256, 0.6484794882507952], 
             UndirectedEdge[158, 193] -> 
             RGBColor[
              0.1863155768050812, 0.3131598626849669, 0.9339217685186295], 
             UndirectedEdge[266, 483] -> 
             RGBColor[
              0.722812081892279, 0.7773202768708386, 0.7464962569767426], 
             UndirectedEdge[290, 484] -> 
             RGBColor[
              0.18316922942285135`, 0.3098528520962973, 0.9337425886898154], 
             UndirectedEdge[153, 411] -> 
             RGBColor[
              0.2544232242601058, 0.38474531843445803`, 0.937800398284958], 
             UndirectedEdge[176, 475] -> 
             RGBColor[
              0.3267310397254062, 0.4574197374557666, 0.9420399908277568], 
             UndirectedEdge[20, 474] -> 
             RGBColor[
              0.2356355428107931, 0.36499827402342566`, 0.9367304676203037], 
             UndirectedEdge[70, 483] -> 
             RGBColor[
              0.41089196681220996`, 0.5303157024471664, 0.9474026506811422], 
             UndirectedEdge[163, 266] -> 
             RGBColor[
              0.9464459539298948, 0.8121746039800857, 0.3903304044915068], 
             UndirectedEdge[69, 486] -> 
             RGBColor[
              0.4280953978994323, 0.5452164497853305, 0.9484988380976231], 
             UndirectedEdge[262, 475] -> 
             RGBColor[
              0.33984798179840503`, 0.4687809734027203, 0.9428757907777918], 
             UndirectedEdge[18, 167] -> 
             RGBColor[
              0.2640882538669924, 0.39490387734956656`, 0.9383508074229403], 
             UndirectedEdge[281, 374] -> 
             RGBColor[
              0.8329341118682944, 0.254151592405362, 0.1791710487598251], 
             UndirectedEdge[138, 294] -> 
             RGBColor[
              0.18513103991648983`, 0.3119148393110808, 0.9338543108951896], 
             UndirectedEdge[291, 349] -> 
             RGBColor[
              0.1841373062547167, 0.310870362226204, 0.9337977192332487], 
             UndirectedEdge[288, 455] -> 
             RGBColor[
              0.6621340048611841, 0.7355343250121988, 0.9672660118228255], 
             UndirectedEdge[12, 459] -> 
             RGBColor[
              0.19425766410485237`, 0.3215074999944453, 0.9343740586410862], 
             UndirectedEdge[93, 305] -> 
             RGBColor[
              0.26659251557076086`, 0.3973687929461906, 0.9384995442473698], 
             UndirectedEdge[127, 184] -> 
             RGBColor[
              0.6864931860475436, 0.7535560913976342, 0.970424092580223], 
             UndirectedEdge[204, 431] -> 
             RGBColor[
              0.36857757870000185`, 0.49366510624735727`, 0.9447064152877764],
              UndirectedEdge[397, 495] -> 
             RGBColor[
              0.8540509182502993, 0.3729173999622112, 0.19768732648561016`], 
             UndirectedEdge[28, 493] -> 
             RGBColor[
              0.36837307735021396`, 0.48845315530283206`, 0.9450243190265064],
              UndirectedEdge[267, 485] -> 
             RGBColor[
              0.24230090955609868`, 0.3720039970814022, 0.9371100503959223], 
             UndirectedEdge[110, 494] -> 
             RGBColor[
              0.3861892329590033, 0.5089194359790232, 0.9458286143237857], 
             UndirectedEdge[337, 500] -> 
             RGBColor[
              0.1950373272242134, 0.32232697536639066`, 0.9344184593023257], 
             UndirectedEdge[43, 393] -> 
             RGBColor[
              0.2248422553763207, 0.3536538445958466, 0.9361158058681482], 
             UndirectedEdge[167, 432] -> 
             RGBColor[
              0.2655480887278028, 0.39643825634715435`, 0.9384339428586312], 
             UndirectedEdge[230, 474] -> 
             RGBColor[
              0.21770593124316456`, 0.3461531154628161, 0.9357094027660106], 
             UndirectedEdge[40, 421] -> 
             RGBColor[
              0.18467273781712776`, 0.31143313474661993`, 0.933828211268628], 
             UndirectedEdge[254, 476] -> 
             RGBColor[
              0.18792976264725234`, 0.31485647435038233`, 0.9340136940143672],
              UndirectedEdge[107, 197] -> 
             RGBColor[
              0.221090097802618, 0.3497100890853544, 0.9359021260451457], 
             UndirectedEdge[231, 395] -> 
             RGBColor[
              0.6338994865668826, 0.711809040751297, 0.9655924600995638], 
             UndirectedEdge[420, 427] -> 
             RGBColor[
              0.1872793778515779, 0.31417287869335075`, 0.9339766555624116], 
             UndirectedEdge[317, 374] -> 
             RGBColor[
              0.832381649136102, 0.24990512175501872`, 0.1786420098235603], 
             UndirectedEdge[188, 200] -> 
             RGBColor[
              0.24347605986022197`, 0.37323915455986845`, 0.937176973467263], 
             UndirectedEdge[84, 260] -> 
             RGBColor[
              0.24263313262389596`, 0.37235318458981626`, 0.9371289700081534],
              UndirectedEdge[33, 160] -> 
             RGBColor[
              0.24786010554572385`, 0.3778470645398819, 0.937426638383438], 
             UndirectedEdge[135, 362] -> 
             RGBColor[
              0.1796163784049865, 0.3061185804127562, 0.9335402590803201], 
             UndirectedEdge[123, 193] -> 
             RGBColor[
              0.18338517057960285`, 0.31007981994350325`, 0.9337548862192361],
              UndirectedEdge[439, 453] -> 
             RGBColor[
              0.21958035723127328`, 0.3481232560217902, 0.9358161485530685], 
             UndirectedEdge[269, 282] -> 
             RGBColor[
              0.6492936360498982, 0.7253322095338435, 0.966103200750267], 
             UndirectedEdge[202, 459] -> 
             RGBColor[
              0.19062008977227754`, 0.3176841787353756, 0.9341669041641552], 
             UndirectedEdge[25, 474] -> 
             RGBColor[
              0.2592041913656412, 0.3897704179931982, 0.9380726672888113], 
             UndirectedEdge[103, 259] -> 
             RGBColor[
              0.5465386609637427, 0.6409354738239997, 0.9581996401022647], 
             UndirectedEdge[352, 375] -> 
             RGBColor[
              0.19306738802691092`, 0.32025644436866674`, 0.9343062741793031],
              UndirectedEdge[300, 308] -> 
             RGBColor[
              0.21138383769744212`, 0.33950819430237933`, 0.9353493688912808],
              UndirectedEdge[32, 328] -> 
             RGBColor[
              0.23132945208889125`, 0.36047229965278604`, 0.9364852421239818],
              UndirectedEdge[209, 486] -> 
             RGBColor[
              0.7039053523851265, 0.7622075647598039, 0.8443835196310663], 
             UndirectedEdge[118, 496] -> 
             RGBColor[
              0.18901315212113398`, 0.315995185378292, 0.9340753914421738], 
             UndirectedEdge[31, 405] -> 
             RGBColor[
              0.18682010932019663`, 0.3136901583475623, 0.9339505008989764], 
             UndirectedEdge[21, 228] -> 
             RGBColor[
              0.2791097474798408, 0.4106924195543743, 0.9392062592618835], 
             UndirectedEdge[92, 250] -> 
             RGBColor[
              0.24579035153480303`, 0.3756716218444204, 0.9373087689544427], 
             UndirectedEdge[177, 290] -> 
             RGBColor[
              0.1829544926129004, 0.3096271500939387, 0.9337303597461633], 
             UndirectedEdge[9, 333] -> 
             RGBColor[
              0.21279008452790313`, 0.3409862488823926, 0.9354294525679199], 
             UndirectedEdge[11, 444] -> 
             RGBColor[
              0.4707188799474499, 0.5790788770403041, 0.9520591203545818], 
             UndirectedEdge[11, 25] -> 
             RGBColor[
              0.3322342574825351, 0.46035097441527295`, 0.9424578530175007], 
             UndirectedEdge[168, 338] -> 
             RGBColor[
              0.35852241644491945`, 0.4834734222788186, 0.944119987452004], 
             UndirectedEdge[283, 430] -> 
             RGBColor[
              0.19193681077273775`, 0.31906813599179257`, 0.9342418894772171],
              UndirectedEdge[139, 410] -> 
             RGBColor[
              0.18242378949369925`, 0.3090693474671371, 0.9337001369886297], 
             UndirectedEdge[195, 260] -> 
             RGBColor[
              0.1989228362357199, 0.32641089169298415`, 0.9346397332924354], 
             UndirectedEdge[391, 407] -> 
             RGBColor[
              0.3751221590981358, 0.49587301171236503`, 0.9453789816308452], 
             UndirectedEdge[33, 111] -> 
             RGBColor[
              0.3114314409456971, 0.4393163564982453, 0.9412427561367012], 
             UndirectedEdge[2, 114] -> 
             RGBColor[
              0.1828144030828347, 0.30947990711565043`, 0.93372238185467], 
             UndirectedEdge[101, 306] -> 
             RGBColor[
              0.24294061497845892`, 0.37267636803996923`, 0.9371464806733664],
              UndirectedEdge[264, 374] -> 
             RGBColor[
              0.8564940987621058, 0.42401565884056125`, 0.20129244608671454`],
              UndirectedEdge[172, 235] -> 
             RGBColor[
              0.22030500109104192`, 0.3488849026634814, 0.9358574159488678], 
             UndirectedEdge[84, 475] -> 
             RGBColor[
              0.3060220283144641, 0.4364102420981715, 0.9408329262010071], 
             UndirectedEdge[37, 397] -> 
             RGBColor[
              0.8419322626018511, 0.3178894150465442, 0.18757522315711248`], 
             UndirectedEdge[228, 287] -> 
             RGBColor[
              0.28118525934636124`, 0.41287391412114016`, 0.9393244565922372],
              UndirectedEdge[68, 375] -> 
             RGBColor[
              0.19408512083298096`, 0.3213261460758332, 0.9343642325570081], 
             UndirectedEdge[197, 236] -> 
             RGBColor[
              0.21962655292817068`, 0.3481718106282057, 0.9358187793296664], 
             UndirectedEdge[107, 214] -> 
             RGBColor[
              0.19941582681621922`, 0.32692905605049705`, 0.9346678083766806],
              UndirectedEdge[207, 317] -> 
             RGBColor[
              0.8461530053131936, 0.3296770187137239, 0.19080821806446593`], 
             UndirectedEdge[98, 462] -> 
             RGBColor[
              0.18918443929913709`, 0.3161752190626076, 0.9340851459935643], 
             UndirectedEdge[21, 59] -> 
             RGBColor[
              0.2814993677631707, 0.4132040619828309, 0.9393423446018928], 
             UndirectedEdge[46, 350] -> 
             RGBColor[
              0.1926173329949277, 0.3197834079949152, 0.9342806442110285], 
             UndirectedEdge[271, 429] -> 
             RGBColor[
              0.200022442914419, 0.32756664803138713`, 0.9347023542660651], 
             UndirectedEdge[304, 423] -> 
             RGBColor[
              0.1849544721508512, 0.3117292553943517, 0.9338442556221451], 
             UndirectedEdge[299, 328] -> 
             RGBColor[
              0.24152994730330735`, 0.3711936668718884, 0.9370661452361624], 
             UndirectedEdge[55, 73] -> 
             RGBColor[
              0.5752457926482104, 0.6660494748562806, 0.9597046024734881], 
             UndirectedEdge[53, 440] -> 
             RGBColor[
              0.8621535838667478, 0.42648384520047466`, 0.20510522227510283`],
              UndirectedEdge[206, 377] -> 
             RGBColor[
              0.18060293034985866`, 0.30715550905782296`, 0.9335964417541076],
              UndirectedEdge[39, 113] -> 
             RGBColor[
              0.2221538791632596, 0.3508281907430225, 0.9359627068199107], 
             UndirectedEdge[9, 450] -> 
             RGBColor[
              0.20465923888359105`, 0.3324402145848314, 0.9349664129369846], 
             UndirectedEdge[61, 321] -> 
             RGBColor[
              0.9878470936878512, 0.9892424751715496, 0.8510686385130581], 
             UndirectedEdge[76, 460] -> 
             RGBColor[
              0.35555086797246704`, 0.4816356758279989, 0.9439036922676769], 
             UndirectedEdge[141, 167] -> 
             RGBColor[
              0.22358607838206196`, 0.35233352292865905`, 0.9360442684466725],
              UndirectedEdge[29, 476] -> 
             RGBColor[
              0.18392969470854525`, 0.3106521493278456, 0.933785896062828], 
             UndirectedEdge[39, 190] -> 
             RGBColor[
              0.23206747524414745`, 0.361248008782331, 0.9365272714508661], 
             UndirectedEdge[115, 215] -> 
             RGBColor[
              0.18797465353578718`, 0.3149036575204792, 0.9340162504840592], 
             UndirectedEdge[208, 471] -> 
             RGBColor[
              0.6917256837597572, 0.7556316908196963, 0.953176466827428], 
             UndirectedEdge[139, 401] -> 
             RGBColor[
              0.18166335927375138`, 0.3082700870919113, 0.9336568316125594], 
             UndirectedEdge[34, 356] -> 
             RGBColor[
              0.22712257342383618`, 0.3560506034443001, 0.9362456666075261], 
             UndirectedEdge[288, 313] -> 
             RGBColor[
              0.5362219144016962, 0.6308125527023426, 0.9580446920208532], 
             UndirectedEdge[66, 334] -> 
             RGBColor[
              0.19236874220933842`, 0.3195221233176947, 0.9342664873335462], 
             UndirectedEdge[17, 328] -> 
             RGBColor[
              0.30921498256740126`, 0.43616829316491434`, 0.9411464986611078],
              UndirectedEdge[318, 459] -> 
             RGBColor[
              0.1962304097370451, 0.3235809807331772, 0.934486403586424], 
             UndirectedEdge[163, 233] -> 
             RGBColor[
              0.9309329686428551, 0.8036306761921264, 0.5929788217369941], 
             UndirectedEdge[141, 300] -> 
             RGBColor[
              0.21958614921582648`, 0.3481293437647886, 0.9358164783980203], 
             UndirectedEdge[354, 436] -> 
             RGBColor[
              0.33305431044836165`, 0.46289663673916315`, 0.9424429040467747],
              UndirectedEdge[29, 290] -> 
             RGBColor[
              0.18297797671513846`, 0.309651833374369, 0.9337316971310441], 
             UndirectedEdge[110, 360] -> 
             RGBColor[
              0.5066197555658096, 0.6093517092932348, 0.9545740073553726], 
             UndirectedEdge[289, 308] -> 
             RGBColor[
              0.20048868170692968`, 0.3280566945635627, 0.9347289058755601], 
             UndirectedEdge[264, 324] -> 
             RGBColor[
              0.9026383334956752, 0.7184607257731993, 0.5982098779593608], 
             UndirectedEdge[109, 382] -> 
             RGBColor[
              0.2128528625805422, 0.3410522325960747, 0.9354330276851459], 
             UndirectedEdge[293, 497] -> 
             RGBColor[
              0.6439655477048442, 0.7192750682039972, 0.9668676305891115], 
             UndirectedEdge[160, 237] -> 
             RGBColor[
              0.23616950031855627`, 0.3655594972189461, 0.9367608757104513], 
             UndirectedEdge[35, 123] -> 
             RGBColor[
              0.18674780810963457`, 0.3136141651911, 0.933946383451995], 
             UndirectedEdge[218, 432] -> 
             RGBColor[
              0.28855483307734864`, 0.4206198033703701, 0.9397441429139097], 
             UndirectedEdge[46, 476] -> 
             RGBColor[
              0.1935701933686142, 0.32078492466249675`, 0.9343349081996792], 
             UndirectedEdge[288, 391] -> 
             RGBColor[
              0.5921690661844405, 0.6787336359098497, 0.9617581155601771], 
             UndirectedEdge[259, 486] -> 
             RGBColor[
              0.5483039124595994, 0.6424644459455908, 0.95831212036663], 
             UndirectedEdge[138, 296] -> 
             RGBColor[
              0.18249965208881352`, 0.3091490838645686, 0.9337044572511928], 
             UndirectedEdge[56, 494] -> 
             RGBColor[
              0.38107496711151867`, 0.5044897159524077, 0.9455027378263516], 
             UndirectedEdge[91, 200] -> 
             RGBColor[
              0.3616498178113511, 0.4832425921885635, 0.9444724938641782], 
             UndirectedEdge[172, 493] -> 
             RGBColor[
              0.24219838800103033`, 0.3718962404267834, 0.9371042119450282], 
             UndirectedEdge[340, 461] -> 
             RGBColor[
              0.30853231078714655`, 0.43652792912541416`, 0.9410681811421904],
              UndirectedEdge[33, 274] -> 
             RGBColor[
              0.25017787666220814`, 0.38028318893848334`, 0.9375586320196867],
              UndirectedEdge[235, 345] -> 
             RGBColor[
              0.20397947873922884`, 0.3317257435738243, 0.934927701602378], 
             UndirectedEdge[205, 490] -> 
             RGBColor[
              0.22672461704495903`, 0.3556323260582085, 0.9362230035804727], 
             UndirectedEdge[141, 284] -> 
             RGBColor[
              0.20706959880896725`, 0.33497365569204784`, 0.9351036793689267],
              UndirectedEdge[489, 500] -> 
             RGBColor[
              0.19630488377124938`, 0.3236592576650523, 0.9344906447724974], 
             UndirectedEdge[155, 198] -> 
             RGBColor[
              0.1881672276861966, 0.31510606516246586`, 0.934027217297037], 
             UndirectedEdge[23, 157] -> 
             RGBColor[
              0.36552292420320903`, 0.49012707749646917`, 0.944544444701912], 
             UndirectedEdge[248, 344] -> 
             RGBColor[
              0.18527438940385826`, 0.31206550871118754`, 0.9338624744364286],
              UndirectedEdge[50, 131] -> 
             RGBColor[
              0.8570462990670573, 0.5838526913273292, 0.5841917648474512], 
             UndirectedEdge[442, 500] -> 
             RGBColor[
              0.21944649774055142`, 0.34798256120985954`, 0.9358085254530993],
              UndirectedEdge[18, 305] -> 
             RGBColor[
              0.2994340109078254, 0.43188728681651606`, 0.9403698188221772], 
             UndirectedEdge[134, 278] -> 
             RGBColor[
              0.18429769316254274`, 0.3110389390354465, 0.9338068530303782], 
             UndirectedEdge[158, 422] -> 
             RGBColor[
              0.19912370802149765`, 0.3266220206758434, 0.9346511726434723], 
             UndirectedEdge[229, 393] -> 
             RGBColor[
              0.2280783028843851, 0.35705513570408476`, 0.9363000939864292], 
             UndirectedEdge[17, 143] -> 
             RGBColor[
              0.4780476426696782, 0.5850251620356237, 0.9526370440612968], 
             UndirectedEdge[53, 83] -> 
             RGBColor[
              0.9139507635332944, 0.6222257740273145, 0.45384466479453006`], 
             UndirectedEdge[166, 239] -> 
             RGBColor[
              0.19616306235610437`, 0.3235101943657379, 0.9344825682527109], 
             UndirectedEdge[46, 194] -> 
             RGBColor[
              0.19490869460205182`, 0.32219177432471957`, 0.9344111338647885],
              UndirectedEdge[319, 368] -> 
             RGBColor[
              0.18004736950714773`, 0.30657157938754187`, 0.9335648033859939],
              UndirectedEdge[51, 360] -> 
             RGBColor[
              0.7957080349438885, 0.8376426800925825, 0.8429962638681049], 
             UndirectedEdge[132, 250] -> 
             RGBColor[
              0.24597806511608875`, 0.3758689207200801, 0.9373194589651996], 
             UndirectedEdge[80, 447] -> 
             RGBColor[
              0.2905728038348803, 0.41916551040000816`, 0.9399899729099002], 
             UndirectedEdge[128, 179] -> 
             RGBColor[
              0.19718406775789482`, 0.32458333577850107`, 0.9345407129999008],
              UndirectedEdge[218, 300] -> 
             RGBColor[
              0.25886995308296373`, 0.3894191123661732, 0.938053632913074], 
             UndirectedEdge[130, 241] -> 
             RGBColor[
              0.2592745192308342, 0.38984433703856036`, 0.9380766723566932], 
             UndirectedEdge[134, 252] -> 
             RGBColor[
              0.18321908491971373`, 0.3099052533845207, 0.9337454278866071], 
             UndirectedEdge[266, 317] -> 
             RGBColor[
              0.9054511863291719, 0.561405403936883, 0.35359294828676574`], 
             UndirectedEdge[156, 485] -> 
             RGBColor[
              0.22736985486258326`, 0.3563105119149721, 0.9362597489196426], 
             UndirectedEdge[96, 110] -> 
             RGBColor[
              0.443925135446012, 0.558453392319533, 0.9496384572015815], 
             UndirectedEdge[50, 373] -> 
             RGBColor[
              0.9356814566362912, 0.9489939738190079, 0.8936373423891573], 
             UndirectedEdge[37, 322] -> 
             RGBColor[
              0.8413185031158885, 0.3131717906863145, 0.18698748638021256`], 
             UndirectedEdge[65, 290] -> 
             RGBColor[
              0.18235293121758706`, 0.308994870926269, 0.9336961017146306], 
             UndirectedEdge[333, 450] -> 
             RGBColor[
              0.22365738515605757`, 0.35240847086923904`, 0.9360483292619628],
              UndirectedEdge[238, 266] -> 
             RGBColor[
              0.7401362180244184, 0.7914194702417209, 0.7478504944629321], 
             UndirectedEdge[312, 446] -> 
             RGBColor[
              0.18918799273524178`, 0.31617895394925455`, 0.9340853483564936],
              UndirectedEdge[407, 448] -> 
             RGBColor[
              0.28885681920654693`, 0.42093720993918393`, 0.9397613405772192],
              UndirectedEdge[14, 454] -> 
             RGBColor[
              0.2211862721127522, 0.34981117438310894`, 0.9359076030298306], 
             UndirectedEdge[77, 473] -> 
             RGBColor[
              0.2990309117164457, 0.42925265730827966`, 0.9404278165088418], 
             UndirectedEdge[57, 136] -> 
             RGBColor[
              0.7454315064099696, 0.7997658817940283, 0.9520631322982614], 
             UndirectedEdge[364, 487] -> 
             RGBColor[
              0.19856599617315254`, 0.3260358301622591, 0.9346194117787698], 
             UndirectedEdge[80, 403] -> 
             RGBColor[
              0.5454124576914773, 0.6374059872808763, 0.9592088642229862], 
             UndirectedEdge[330, 352] -> 
             RGBColor[
              0.1864863756783814, 0.3133393831300794, 0.9339314952617896], 
             UndirectedEdge[239, 272] -> 
             RGBColor[
              0.22693559422031087`, 0.3558540764462288, 0.9362350184184962], 
             UndirectedEdge[53, 97] -> 
             RGBColor[
              0.910565728681441, 0.6124407745650613, 0.29428992901066414`], 
             UndirectedEdge[304, 311] -> 
             RGBColor[
              0.19034681505715081`, 0.3173969496831598, 0.9341513415734024], 
             UndirectedEdge[237, 241] -> 
             RGBColor[
              0.2242600552960576, 0.35304191539787294`, 0.9360826504348652], 
             UndirectedEdge[361, 441] -> 
             RGBColor[
              0.22578416559546857`, 0.3546438519567282, 0.9361694462616974], 
             UndirectedEdge[276, 347] -> 
             RGBColor[
              0.20833762491305394`, 0.33630643152494155`, 0.935175891579678], 
             UndirectedEdge[11, 180] -> 
             RGBColor[
              0.31935935180321817`, 0.4468186322301426, 0.9417246461857798], 
             UndirectedEdge[56, 360] -> 
             RGBColor[
              0.501505489718325, 0.6049219892666192, 0.9542481308579387], 
             UndirectedEdge[15, 269] -> 
             RGBColor[
              0.6271401903527347, 0.708025769382796, 0.9638951523188943], 
             UndirectedEdge[8, 387] -> 
             RGBColor[
              0.19318868595476607`, 0.32038393618157524`, 0.9343131819168503],
              UndirectedEdge[139, 278] -> 
             RGBColor[
              0.18353174179525936`, 0.31023387558431004`, 0.933763233233135], 
             UndirectedEdge[15, 449] -> 
             RGBColor[
              0.8180065894164226, 0.8423738625918746, 0.678402399648858], 
             UndirectedEdge[348, 355] -> 
             RGBColor[
              0.5108951424447806, 0.6138067180573811, 0.9546386835652754], 
             UndirectedEdge[173, 499] -> 
             RGBColor[
              0.6745850298425644, 0.7454990333041416, 0.9683443785997534], 
             UndirectedEdge[130, 483] -> 
             RGBColor[
              0.3774799425420655, 0.5008371490852502, 0.9452933918504961], 
             UndirectedEdge[173, 282] -> 
             RGBColor[
              0.7086553123271468, 0.7723261830606026, 0.9715957968385069], 
             UndirectedEdge[84, 244] -> 
             RGBColor[
              0.3611185636561085, 0.4841320917787186, 0.9443436287130234], 
             UndirectedEdge[183, 279] -> 
             RGBColor[
              0.202473790723394, 0.3301431700030478, 0.9348419548973421], 
             UndirectedEdge[124, 381] -> 
             RGBColor[
              0.18683393328431724`, 0.31370468821034303`, 0.9339512881532823],
              UndirectedEdge[81, 213] -> 
             RGBColor[
              0.2202872137263247, 0.3488662070153795, 0.9358564029847612], 
             UndirectedEdge[134, 210] -> 
             RGBColor[
              0.18982747480213708`, 0.31685109014706625`, 0.9341217659141743],
              UndirectedEdge[103, 275] -> 
             RGBColor[
              0.4495582322834861, 0.5628291466682479, 0.9501364705331162], 
             UndirectedEdge[256, 298] -> 
             RGBColor[
              0.2936230158270692, 0.42568683963093007`, 0.9400422862891433], 
             UndirectedEdge[18, 235] -> 
             RGBColor[
              0.2527156376053866, 0.3829505365931011, 0.9377031537511198], 
             UndirectedEdge[255, 334] -> 
             RGBColor[
              0.19201279446501912`, 0.3191479996700246, 0.9342462166360848], 
             UndirectedEdge[209, 372] -> 
             RGBColor[
              0.8043736512463036, 0.8448578989108925, 0.8519927857243978], 
             UndirectedEdge[112, 238] -> 
             RGBColor[
              0.7400652706680888, 0.7928555147204785, 0.8555441529553656], 
             UndirectedEdge[360, 457] -> 
             RGBColor[
              0.5327073882194472, 0.6315148818077295, 0.9563558234535461], 
             UndirectedEdge[233, 404] -> 
             RGBColor[
              0.8996921742722623, 0.9221615303078283, 0.9662816131668808], 
             UndirectedEdge[259, 348] -> 
             RGBColor[
              0.5726768344196096, 0.6633371250706486, 0.9599308796437516], 
             UndirectedEdge[244, 376] -> 
             RGBColor[
              0.40891528656398646`, 0.5286036013669932, 0.947276698363635], 
             UndirectedEdge[182, 371] -> 
             RGBColor[
              0.29953966949074173`, 0.42881389719709484`, 0.9404924339976882],
              UndirectedEdge[21, 77] -> 
             RGBColor[
              0.3172353767281449, 0.44838670426532234`, 0.9414645338601655], 
             UndirectedEdge[153, 493] -> 
             RGBColor[
              0.24427091854425903`, 0.3740746014337428, 0.9372222394934309], 
             UndirectedEdge[276, 382] -> 
             RGBColor[
              0.21283416100439742`, 0.3410325760537981, 0.935431962658051], 
             UndirectedEdge[80, 219] -> 
             RGBColor[
              0.508471196315639, 0.6085471931300863, 0.9555269045247576], 
             UndirectedEdge[60, 136] -> 
             RGBColor[
              0.7568575398761165, 0.8080712748113279, 0.923043362246632], 
             UndirectedEdge[23, 96] -> 
             RGBColor[
              0.4513622669101063, 0.5648950617926353, 0.9501123446420765], 
             UndirectedEdge[53, 281] -> 
             RGBColor[
              0.8255492937831006, 0.19738864455464403`, 0.17209933862148452`],
              UndirectedEdge[141, 162] -> 
             RGBColor[
              0.19531753931264573`, 0.32262149603780554`, 0.9344344169662252],
              UndirectedEdge[28, 149] -> 
             RGBColor[
              0.5184855433089055, 0.6199689474225398, 0.9552362277258538], 
             UndirectedEdge[37, 317] -> 
             RGBColor[
              0.839586880193451, 0.2998617781024568, 0.18532928231409804`], 
             UndirectedEdge[372, 486] -> 
             RGBColor[
              0.5138028974550533, 0.6150817214772912, 0.955167559111667], 
             UndirectedEdge[63, 453] -> 
             RGBColor[
              0.2233707740920417, 0.35210722446876735`, 0.9360320071858701], 
             UndirectedEdge[82, 242] -> 
             RGBColor[
              0.7466175241184303, 0.8003829212442619, 0.9428810481338523], 
             UndirectedEdge[4, 191] -> 
             RGBColor[
              0.18605432886244289`, 0.31288527453317777`, 0.933906890834778], 
             UndirectedEdge[70, 403] -> 
             RGBColor[
              0.5565760155932599, 0.6470753000386655, 0.9599201962609412], 
             UndirectedEdge[144, 458] -> 
             RGBColor[
              0.21795043797046626`, 0.346410107535832, 0.935723327062415], 
             UndirectedEdge[16, 224] -> 
             RGBColor[
              0.23802549514267946`, 0.3675102654559681, 0.9368665718699869], 
             UndirectedEdge[40, 206] -> 
             RGBColor[
              0.18271148860033518`, 0.3093717374693884, 0.9337165210271399], 
             UndirectedEdge[148, 485] -> 
             RGBColor[
              0.26499013859378384`, 0.39585181538021874`, 0.9384021684239121],
              UndirectedEdge[34, 291] -> 
             RGBColor[
              0.19600418397695138`, 0.323343203115777, 0.9344735203640577], 
             UndirectedEdge[222, 339] -> 
             RGBColor[
              0.1886442457825459, 0.3156074414264231, 0.9340543827719392], 
             UndirectedEdge[197, 314] -> 
             RGBColor[
              0.24685083225448304`, 0.3767862543191651, 0.9373691617625879], 
             UndirectedEdge[330, 358] -> 
             RGBColor[
              0.20723187960885475`, 0.33514422310192665`, 0.9351129210204074],
              UndirectedEdge[312, 415] -> 
             RGBColor[
              0.18768399799751473`, 0.31459816012112934`, 0.9339996980811409],
              UndirectedEdge[370, 443] -> 
             RGBColor[
              0.2582982777745515, 0.38881824537072385`, 0.9380210768499777], 
             UndirectedEdge[160, 305] -> 
             RGBColor[
              0.2750017432650342, 0.40620742442870245`, 0.938978437324221], 
             UndirectedEdge[266, 343] -> 
             RGBColor[
              0.9199069923129997, 0.6725190633031569, 0.3674358444223769], 
             UndirectedEdge[47, 468] -> 
             RGBColor[
              0.25155549363265645`, 0.38173115172038535`, 0.9376370852681521],
              UndirectedEdge[388, 436] -> 
             RGBColor[
              0.34210441687378856`, 0.470735384053293, 0.943019568825508], 
             UndirectedEdge[69, 209] -> 
             RGBColor[
              0.7186661516906826, 0.7749926272189318, 0.8453240647103539], 
             UndirectedEdge[197, 470] -> 
             RGBColor[
              0.2127537879512197, 0.3409480988789625, 0.9354273855315738], 
             UndirectedEdge[13, 298] -> 
             RGBColor[
              0.26431690444041933`, 0.3951442035995219, 0.9383638287348387], 
             UndirectedEdge[168, 383] -> 
             RGBColor[
              0.2802434761765292, 0.4118840402971449, 0.9392708234339586], 
             UndirectedEdge[123, 428] -> 
             RGBColor[
              0.18681025928894113`, 0.3136798053401847, 0.9339499399542682], 
             UndirectedEdge[137, 485] -> 
             RGBColor[
              0.2335003285987162, 0.3627540285061326, 0.9366088703296922], 
             UndirectedEdge[394, 467] -> 
             RGBColor[
              0.18730056337306505`, 0.3141951460196734, 0.9339778620465191], 
             UndirectedEdge[232, 395] -> 
             RGBColor[
              0.3913003181998807, 0.5091662530135891, 0.9466381048606165], 
             UndirectedEdge[414, 461] -> 
             RGBColor[
              0.337969115719834, 0.4620246100212727, 0.9429438683225567], 
             UndirectedEdge[224, 333] -> 
             RGBColor[
              0.21886126221320776`, 0.3473674415645458, 0.9357751971555954], 
             UndirectedEdge[33, 182] -> 
             RGBColor[
              0.300634259036329, 0.42996438021049266`, 0.9405547692530093], 
             UndirectedEdge[158, 451] -> 
             RGBColor[
              0.19839700824460316`, 0.32585821313490027`, 0.9346097881662341],
              UndirectedEdge[235, 274] -> 
             RGBColor[
              0.23060114107907964`, 0.35970679860388893`, 0.9364437658894125],
              UndirectedEdge[284, 345] -> 
             RGBColor[
              0.19883561542773992`, 0.32631921709367856`, 0.9346347661964527],
              UndirectedEdge[70, 238] -> 
             RGBColor[
              0.4282161029443493, 0.5444148958180487, 0.9487568881673315], 
             UndirectedEdge[21, 55] -> 
             RGBColor[
              0.4367980074447999, 0.5486800919411015, 0.9499852964304927], 
             UndirectedEdge[55, 60] -> 
             RGBColor[
              0.7795430416292072, 0.8264883871046946, 0.9248292480443663], 
             UndirectedEdge[219, 258] -> 
             RGBColor[
              0.5423535654058886, 0.6378943982586738, 0.9576858591221857], 
             UndirectedEdge[175, 463] -> 
             RGBColor[
              0.476418269168048, 0.5843060667913316, 0.9523419687164218], 
             UndirectedEdge[101, 431] -> 
             RGBColor[
              0.33318158758536665`, 0.45712340432410575`, 0.9426664368181881],
              UndirectedEdge[14, 213] -> 
             RGBColor[
              0.21659885926136652`, 0.3449895126175285, 0.9356463566544133], 
             UndirectedEdge[378, 487] -> 
             RGBColor[
              0.1998521204053707, 0.32738762827530654`, 0.9346926546511444], 
             UndirectedEdge[8, 159] -> 
             RGBColor[
              0.21480140592500557`, 0.34310027519588937`, 0.9355439943460016],
              UndirectedEdge[311, 469] -> 
             RGBColor[
              0.18566856806308635`, 0.31247981547440673`, 0.9338849223279366],
              UndirectedEdge[343, 440] -> 
             RGBColor[
              0.8689315587996673, 0.47858233066244793`, 0.21159581872549427`],
              UndirectedEdge[371, 460] -> 
             RGBColor[
              0.2773778998424177, 0.4088721378819603, 0.9391076331009713], 
             UndirectedEdge[224, 358] -> 
             RGBColor[
              0.21540867556861554`, 0.34373855409444265`, 0.9355785774538301],
              UndirectedEdge[455, 475] -> 
             RGBColor[
              0.47478660322499994`, 0.5813210731496465, 0.9526722731511402], 
             UndirectedEdge[310, 408] -> 
             RGBColor[
              0.7910483812120712, 0.837599492064294, 0.9781391837091735], 
             UndirectedEdge[154, 376] -> 
             RGBColor[
              0.6772879972861523, 0.7415239884313045, 0.9288688968046623], 
             UndirectedEdge[282, 499] -> 
             RGBColor[
              0.6626431389741363, 0.7361699373959933, 0.9671541225213036], 
             UndirectedEdge[14, 192] -> 
             RGBColor[
              0.27198473276549623`, 0.40281125955144237`, 0.9388148648903828],
              UndirectedEdge[75, 147] -> 
             RGBColor[
              0.842199332426149, 0.3144945905899744, 0.187617653595973], 
             UndirectedEdge[175, 351] -> 
             RGBColor[
              0.3189338999580072, 0.4443278119995411, 0.9417752451272612], 
             UndirectedEdge[109, 205] -> 
             RGBColor[
              0.22555863330001114`, 0.354406803214629, 0.9361566025311163], 
             UndirectedEdge[43, 148] -> 
             RGBColor[
              0.2515020287225457, 0.38167495670998786`, 0.9376340405206155], 
             UndirectedEdge[56, 92] -> 
             RGBColor[
              0.33939325721103675`, 0.46498406565042605`, 0.9429714183929231],
              UndirectedEdge[46, 412] -> 
             RGBColor[
              0.19698300619667852`, 0.32437200732962346`, 0.9345292628414335],
              UndirectedEdge[170, 214] -> 
             RGBColor[
              0.18764009951956995`, 0.31455202003748506`, 0.9339971981277639],
              UndirectedEdge[94, 437] -> 
             RGBColor[
              0.18042329707310156`, 0.30696670309454366`, 0.93358621190474], 
             UndirectedEdge[173, 249] -> 
             RGBColor[
              0.72377347409997, 0.7841366059398172, 0.9731026339167677], 
             UndirectedEdge[181, 302] -> 
             RGBColor[
              0.235139155224241, 0.3644765391971686, 0.9367021990815891], 
             UndirectedEdge[188, 279] -> 
             RGBColor[
              0.21597972805042376`, 0.3443387664596417, 0.9356110980478727], 
             UndirectedEdge[317, 471] -> 
             RGBColor[
              0.8870778332354172, 0.5507282185220981, 0.561083222125617], 
             UndirectedEdge[8, 344] -> 
             RGBColor[
              0.19388121074334685`, 0.3211118236429813, 0.9343526201790614], 
             UndirectedEdge[236, 493] -> 
             RGBColor[
              0.23463204109374153`, 0.36394353009312075`, 0.9366733196820654],
              UndirectedEdge[31, 366] -> 
             RGBColor[
              0.18726891335142604`, 0.3141618798402035, 0.9339760596246088], 
             UndirectedEdge[176, 261] -> 
             RGBColor[
              0.32311312036066653`, 0.4542860775439437, 0.941809460205036], 
             UndirectedEdge[144, 145] -> 
             RGBColor[
              0.20296158096381922`, 0.33065586847342227`, 0.9348697338299133],
              UndirectedEdge[144, 375] -> 
             RGBColor[
              0.1998107076045579, 0.3273441007959291, 0.9346902962534028], 
             UndirectedEdge[258, 293] -> 
             RGBColor[
              0.6124648264838737, 0.6926658482781156, 0.9646738943994533], 
             UndirectedEdge[242, 269] -> 
             RGBColor[
              0.787493374586991, 0.8335677780907182, 0.9460989448159113], 
             UndirectedEdge[45, 216] -> 
             RGBColor[
              0.20054621348510776`, 0.32811716411015324`, 0.9347321822252167],
              UndirectedEdge[82, 323] -> 
             RGBColor[
              0.7564161337880024, 0.8062755394340282, 0.8629204050270508], 
             UndirectedEdge[258, 272] -> 
             RGBColor[
              0.33620380123362575`, 0.46086126878688316`, 0.9428179945089592],
              UndirectedEdge[92, 356] -> 
             RGBColor[
              0.2586276684650108, 0.3891644558709726, 0.9380398351625095], 
             UndirectedEdge[114, 327] -> 
             RGBColor[
              0.18260674360457746`, 0.3092616438376308, 0.933710555954588], 
             UndirectedEdge[188, 459] -> 
             RGBColor[
              0.20922832641301886`, 0.3372426152751415, 0.9352266157124262], 
             UndirectedEdge[465, 469] -> 
             RGBColor[
              0.18020092681290795`, 0.30673297785199133`, 0.9335735482473893],
              UndirectedEdge[44, 62] -> 
             RGBColor[
              0.2651018322525842, 0.3959692124974049, 0.9384085292125448], 
             UndirectedEdge[88, 337] -> 
             RGBColor[
              0.18932246677623382`, 0.3163202946924838, 0.9340930064541916], 
             UndirectedEdge[253, 388] -> 
             RGBColor[
              0.3530902196198862, 0.48025073422946185`, 0.9437195744621254], 
             UndirectedEdge[80, 238] -> 
             RGBColor[
              0.4170525450425667, 0.5347455830602593, 0.9480455561293766], 
             UndirectedEdge[171, 272] -> 
             RGBColor[
              0.36396083467584234`, 0.48443119432275983`, 0.9447170138830936],
              UndirectedEdge[297, 392] -> 
             RGBColor[
              0.21605655176504493`, 0.3444195130546133, 0.9356154730447699], 
             UndirectedEdge[82, 499] -> 
             RGBColor[
              0.5743475030967551, 0.6653202029309262, 0.9596338858294544], 
             UndirectedEdge[297, 484] -> 
             RGBColor[
              0.1900371894005843, 0.3170715134867078, 0.934133708850311], 
             UndirectedEdge[73, 240] -> 
             RGBColor[
              0.785852186641644, 0.829344990984529, 0.8179383454805261], 
             UndirectedEdge[229, 263] -> 
             RGBColor[
              0.22958947316632627`, 0.3586434714841348, 0.9363861528984097], 
             UndirectedEdge[87, 91] -> 
             RGBColor[
              0.3843682357663767, 0.5071210898901892, 0.9457662741578293], 
             UndirectedEdge[296, 339] -> 
             RGBColor[
              0.18120773687102673`, 0.3077911990585188, 0.9336308845907572], 
             UndirectedEdge[62, 157] -> 
             RGBColor[
              0.27514441268901324`, 0.40652460127246764`, 0.9389804393117331],
              UndirectedEdge[227, 265] -> 
             RGBColor[
              0.18874076831201309`, 0.315708892724775, 0.9340598795871999], 
             UndirectedEdge[38, 127] -> 
             RGBColor[
              0.6754853554676021, 0.7446194386357212, 0.969557515833958], 
             UndirectedEdge[302, 451] -> 
             RGBColor[
              0.22492379054142386`, 0.35373954322399803`, 0.9361204491751804],
              UndirectedEdge[141, 151] -> 
             RGBColor[
              0.20551109996107267`, 0.3333355745883765, 0.9350149251651315], 
             UndirectedEdge[72, 439] -> 
             RGBColor[
              0.2051731991857032, 0.33298041944931656`, 0.9349956822158536], 
             UndirectedEdge[277, 340] -> 
             RGBColor[
              0.40350978000289583`, 0.523921623272436, 0.9469322642654641], 
             UndirectedEdge[53, 322] -> 
             RGBColor[
              0.8267284539733458, 0.20645218648815844`, 0.17322850375133425`],
              UndirectedEdge[450, 461] -> 
             RGBColor[
              0.23439908756698247`, 0.3636986811663903, 0.9366600533233402], 
             UndirectedEdge[352, 367] -> 
             RGBColor[
              0.1902708306368736, 0.3173170852397579, 0.9341470143730765], 
             UndirectedEdge[239, 251] -> 
             RGBColor[
              0.2177871872756262, 0.3462385207048633, 0.9357140301768516], 
             UndirectedEdge[83, 163] -> 
             RGBColor[
              0.9472677000831091, 0.8139798001662166, 0.4832298213140514], 
             UndirectedEdge[179, 245] -> 
             RGBColor[
              0.22201863728698465`, 0.35068604295622735`, 0.9359550049951293],
              UndirectedEdge[133, 237] -> 
             RGBColor[
              0.21543537025685555`, 0.3437666119043239, 0.9355800976768341], 
             UndirectedEdge[199, 244] -> 
             RGBColor[
              0.4164279851399622, 0.5351107232742938, 0.9477554008736777], 
             UndirectedEdge[173, 269] -> 
             RGBColor[
              0.6612355269183264, 0.7346613054419917, 0.9672934568287169], 
             UndirectedEdge[209, 379] -> 
             RGBColor[
              0.9109503146879699, 0.6018931108868748, 0.4575519033361274], 
             UndirectedEdge[139, 451] -> 
             RGBColor[
              0.19384306282883684`, 0.3210717277661138, 0.9343504477117648], 
             UndirectedEdge[18, 218] -> 
             RGBColor[
              0.2870949982165383, 0.4190854243727823, 0.9396610074782187], 
             UndirectedEdge[59, 287] -> 
             RGBColor[
              0.28357487962969113`, 0.41538555654959675`, 0.9394605419322465],
              UndirectedEdge[167, 274] -> 
             RGBColor[
              0.24197375734068546`, 0.3716601393603544, 0.9370914195612329], 
             UndirectedEdge[402, 461] -> 
             RGBColor[
              0.23570042936850655`, 0.3650664739096279, 0.9367341628137743], 
             UndirectedEdge[472, 488] -> 
             RGBColor[
              0.18283227953141887`, 0.3094986963965447, 0.933723399891971], 
             UndirectedEdge[227, 270] -> 
             RGBColor[
              0.18663641062037617`, 0.3134970793668807, 0.9339400395297794], 
             UndirectedEdge[124, 363] -> 
             RGBColor[
              0.1839911193885881, 0.3107167105611202, 0.9337893941074868], 
             UndirectedEdge[118, 195] -> 
             RGBColor[
              0.19015295783973063`, 0.31719319345639363`, 0.9341403016916563],
              UndirectedEdge[54, 154] -> 
             RGBColor[
              0.9864962902894889, 0.9885634492757301, 0.8680616670608778], 
             UndirectedEdge[313, 498] -> 
             RGBColor[
              0.5679033760595678, 0.6555623513374985, 0.9612024040388176], 
             UndirectedEdge[243, 283] -> 
             RGBColor[
              0.18944836976348856`, 0.3164526267147989, 0.934100176443059], 
             UndirectedEdge[302, 346] -> 
             RGBColor[
              0.343088083847486, 0.46567152269516504`, 0.9432988559850268], 
             UndirectedEdge[13, 477] -> 
             RGBColor[
              0.2253695367356543, 0.3542080507360753, 0.9361458337615195], 
             UndirectedEdge[140, 479] -> 
             RGBColor[
              0.18066625764504995`, 0.3072220700602514, 0.9336000481498845], 
             UndirectedEdge[174, 309] -> 
             RGBColor[
              0.18783655214367595`, 0.3147585042012363, 0.9340083858140811], 
             UndirectedEdge[299, 312] -> 
             RGBColor[
              0.21752114274095335`, 0.3459588910307243, 0.9356988793341796], 
             UndirectedEdge[215, 402] -> 
             RGBColor[
              0.2015459552318014, 0.3291679560732161, 0.9347891160387054], 
             UndirectedEdge[372, 400] -> 
             RGBColor[
              0.8020697769239993, 0.8439051876717503, 0.8901739454806034], 
             UndirectedEdge[29, 426] -> 
             RGBColor[
              0.18589315152803693`, 0.3127158669354839, 0.933897712024024], 
             UndirectedEdge[361, 481] -> 
             RGBColor[
              0.217684758794606, 0.34613086187697023`, 0.935708197026387], 
             UndirectedEdge[188, 335] -> 
             RGBColor[
              0.21717587938379926`, 0.3455959973513941, 0.9356792170967612], 
             UndirectedEdge[168, 443] -> 
             RGBColor[
              0.29027458230294984`, 0.42242736884487553`, 0.9398420800881666],
              UndirectedEdge[81, 500] -> 
             RGBColor[
              0.21967281078147302`, 0.34822043056494373`, 0.9358214136459797],
              UndirectedEdge[75, 310] -> 
             RGBColor[
              0.7550654921994678, 0.6018878314253746, 0.587281607852838], 
             UndirectedEdge[348, 444] -> 
             RGBColor[
              0.5139722729928065, 0.6163048712594199, 0.9548809265539167], 
             UndirectedEdge[262, 482] -> 
             RGBColor[
              0.3377696803255693, 0.46698085312541926`, 0.9427433632457125], 
             UndirectedEdge[83, 395] -> 
             RGBColor[
              0.749683946094778, 0.8003088116491959, 0.8414368525463194], 
             UndirectedEdge[26, 459] -> 
             RGBColor[
              0.18968759946741098`, 0.31670407230166076`, 0.9341138002207887],
              UndirectedEdge[186, 498] -> 
             RGBColor[
              0.8839547752105941, 0.9059796859731515, 0.7464098878256111], 
             UndirectedEdge[167, 284] -> 
             RGBColor[
              0.22334665832655862`, 0.3520818772702168, 0.9360306338287019], 
             UndirectedEdge[175, 359] -> 
             RGBColor[
              0.653601757432396, 0.7247826808114364, 0.9688966182964689], 
             UndirectedEdge[65, 484] -> 
             RGBColor[
              0.1839955650344703, 0.31072138321681264`, 0.9337896472804431], 
             UndirectedEdge[266, 322] -> 
             RGBColor[
              0.9071828092516094, 0.5747154165207407, 0.3552511523528803], 
             UndirectedEdge[210, 252] -> 
             RGBColor[
              0.1889152618740288, 0.3158922965219843, 0.9340698167374166], 
             UndirectedEdge[133, 271] -> 
             RGBColor[
              0.20303817120051487`, 0.3307363696682909, 0.9348740955305881], 
             UndirectedEdge[190, 467] -> 
             RGBColor[
              0.20384534758574807`, 0.33158476322710967`, 0.9349200630316166],
              UndirectedEdge[216, 481] -> 
             RGBColor[
              0.20259193459855807`, 0.33026734670659963`, 0.9348486830162546],
              UndirectedEdge[18, 406] -> 
             RGBColor[
              0.35240776193494094`, 0.47777048741806016`, 0.9437452593947762],
              UndirectedEdge[315, 364] -> 
             RGBColor[
              0.19390091491665387`, 0.32113253397844377`, 0.9343537423025814],
              UndirectedEdge[152, 464] -> 
             RGBColor[
              0.19334471949680462`, 0.32054793732735576`, 0.9343220677962385],
              UndirectedEdge[229, 280] -> 
             RGBColor[
              0.24415725813790062`, 0.37395513714017414`, 0.9372157667014342],
              UndirectedEdge[164, 259] -> 
             RGBColor[
              0.4996492818256195, 0.6003222503432779, 0.9552118903262334], 
             UndirectedEdge[238, 497] -> 
             RGBColor[
              0.4824356353537869, 0.5907020081147285, 0.9523982469164629], 
             UndirectedEdge[7, 478] -> 
             RGBColor[
              0.36083387288200847`, 0.48094610395474147`, 0.9445570026671483],
              UndirectedEdge[137, 227] -> 
             RGBColor[
              0.2024073413896048, 0.33007332754010427`, 0.9348381707060858], 
             UndirectedEdge[44, 157] -> 
             RGBColor[
              0.2890530721263536, 0.4211434842010545, 0.9397725168906719], 
             UndirectedEdge[105, 205] -> 
             RGBColor[
              0.21445329260995954`, 0.34273438603011697`, 0.9355241698076971],
              UndirectedEdge[305, 460] -> 
             RGBColor[
              0.3056141271073153, 0.43838298078417876`, 0.9407217672970755], 
             UndirectedEdge[330, 492] -> 
             RGBColor[
              0.1860947118976098, 0.3129277196635705, 0.9339091905888894], 
             UndirectedEdge[94, 123] -> 
             RGBColor[
              0.18238673674691558`, 0.30903040268098764`, 0.933698026889515], 
             UndirectedEdge[418, 444] -> 
             RGBColor[
              0.5211846971324379, 0.6221602420919774, 0.9554487150021684], 
             UndirectedEdge[203, 295] -> 
             RGBColor[
              0.9149334778554977, 0.6677110589938393, 0.5462140209685634], 
             UndirectedEdge[342, 485] -> 
             RGBColor[
              0.36582891890395064`, 0.48572268889805037`, 0.9448845663511518],
              UndirectedEdge[279, 430] -> 
             RGBColor[
              0.2047694881993928, 0.33255609360594945`, 0.9349726914724201], 
             UndirectedEdge[391, 448] -> 
             RGBColor[
              0.38684939186323586`, 0.5081990768979878, 0.9460468301879315], 
             UndirectedEdge[174, 252] -> 
             RGBColor[
              0.18489202158224743`, 0.3116636158871544, 0.9338406991546504], 
             UndirectedEdge[14, 489] -> 
             RGBColor[
              0.2113006394017466, 0.3394207476185267, 0.935344630871422], 
             UndirectedEdge[6, 158] -> 
             RGBColor[
              0.20305085818934585`, 0.33074970449795377`, 0.9348748180358333],
              UndirectedEdge[201, 493] -> 
             RGBColor[
              0.2591781892002248, 0.38974308806871316`, 0.9380711865039575], 
             UndirectedEdge[66, 446] -> 
             RGBColor[
              0.19064470762485328`, 0.3177100536592947, 0.9341683061144403], 
             UndirectedEdge[449, 499] -> 
             RGBColor[
              0.8060897526290038, 0.8328531529864611, 0.6773590298414771], 
             UndirectedEdge[202, 477] -> 
             RGBColor[
              0.19227698695572149`, 0.31942568272852423`, 0.9342612620075925],
              UndirectedEdge[89, 299] -> 
             RGBColor[
              0.27487744861956126`, 0.4061575123810962, 0.9389684030253784], 
             UndirectedEdge[57, 91] -> 
             RGBColor[
              0.7114825067288603, 0.7722045544678969, 0.9493905426840812], 
             UndirectedEdge[222, 438] -> 
             RGBColor[
              0.19987204711910306`, 0.3274085725148659, 0.9346937894480125], 
             UndirectedEdge[83, 346] -> 
             RGBColor[
              0.7183210910606576, 0.7745238473066297, 0.8390571508964824], 
             UndirectedEdge[38, 388] -> 
             RGBColor[
              0.42375389748919434`, 0.5396775316025662, 0.9487136143198416], 
             UndirectedEdge[345, 472] -> 
             RGBColor[
              0.1869884495343811, 0.3138670945860562, 0.9339600876251372], 
             UndirectedEdge[231, 486] -> 
             RGBColor[
              0.5884962722514289, 0.6738630228882163, 0.9623181191717225], 
             UndirectedEdge[14, 251] -> 
             RGBColor[
              0.23495511782487732`, 0.36428310422179233`, 0.9366917184239543],
              UndirectedEdge[404, 418] -> 
             RGBColor[
              0.6566661186267099, 0.7293072977796211, 0.9681149418691689], 
             UndirectedEdge[10, 370] -> 
             RGBColor[
              0.22777336174590646`, 0.35673462323315885`, 0.9362827280397129],
              UndirectedEdge[216, 224] -> 
             RGBColor[
              0.20292469844545702`, 0.3306171026081368, 0.9348676334250554], 
             UndirectedEdge[116, 143] -> 
             RGBColor[
              0.4285653763865951, 0.5391828000638526, 0.9495933114012363], 
             UndirectedEdge[142, 477] -> 
             RGBColor[
              0.2067532217668407, 0.3346411233613098, 0.9350856621644155], 
             UndirectedEdge[1, 378] -> 
             RGBColor[
              0.20312084702488786`, 0.3308232672016569, 0.9348788037964781], 
             UndirectedEdge[47, 298] -> 
             RGBColor[
              0.2786489927595025, 0.4102081371297621, 0.9391800199621858], 
             UndirectedEdge[50, 340] -> 
             RGBColor[
              0.6220781556562913, 0.698481383789535, 0.9664262896114366], 
             UndirectedEdge[144, 417] -> 
             RGBColor[
              0.19700492333763642`, 0.3243950436343972, 0.9345305109901875], 
             UndirectedEdge[326, 395] -> 
             RGBColor[
              0.6147615284118504, 0.6968583223867169, 0.9636849672850575], 
             UndirectedEdge[14, 166] -> 
             RGBColor[
              0.21333099290535548`, 0.34155477788266697`, 0.9354602564998136],
              UndirectedEdge[41, 132] -> 
             RGBColor[
              0.2677010857798615, 0.3987011927567655, 0.9385565528556723], 
             UndirectedEdge[6, 35] -> 
             RGBColor[
              0.2010217865796709, 0.32861702158561484`, 0.9347592654094047], 
             UndirectedEdge[95, 286] -> 
             RGBColor[
              0.18603827385130794`, 0.3128683996985284, 0.9339059765256451], 
             UndirectedEdge[435, 439] -> 
             RGBColor[
              0.21881441649795172`, 0.3473182037476218, 0.9357725293614136], 
             UndirectedEdge[354, 388] -> 
             RGBColor[
              0.3196378407891415, 0.45127596505171874`, 0.9415880184638075], 
             UndirectedEdge[47, 59] -> 
             RGBColor[
              0.272302702026903, 0.4035377831917274, 0.9388186080934602], 
             UndirectedEdge[305, 493] -> 
             RGBColor[
              0.2857296655888689, 0.41748315098061395`, 0.9395893766300246], 
             UndirectedEdge[26, 335] -> 
             RGBColor[
              0.1976351524381914, 0.3250574543779134, 0.9345664016051236], 
             UndirectedEdge[24, 115] -> 
             RGBColor[
              0.18813870785962614`, 0.3150760890164789, 0.9340255931351051], 
             UndirectedEdge[271, 351] -> 
             RGBColor[
              0.2241430772010206, 0.3529189640031495, 0.9360759887054064], 
             UndirectedEdge[12, 40] -> 
             RGBColor[
              0.18952205245126588`, 0.31653007189140514`, 0.9341043725631242],
              UndirectedEdge[228, 468] -> 
             RGBColor[
              0.23985909159475186`, 0.369437491583826, 0.9369709924753695], 
             UndirectedEdge[1, 108] -> 
             RGBColor[
              0.20444558985732308`, 0.3322156559120931, 0.9349542459410038], 
             UndirectedEdge[97, 343] -> 
             RGBColor[
              0.9173437036143605, 0.6645392600270346, 0.3007805254610556], 
             UndirectedEdge[314, 411] -> 
             RGBColor[
              0.27200862613590066`, 0.4032286907847955, 0.9388018609065139], 
             UndirectedEdge[211, 466] -> 
             RGBColor[
              0.1911846700582075, 0.3182775884123456, 0.9341990561762171], 
             UndirectedEdge[12, 202] -> 
             RGBColor[
              0.1903977819160206, 0.31745051908331734`, 0.9341542440606163], 
             UndirectedEdge[96, 360] -> 
             RGBColor[
              0.5334689580963748, 0.6321331585421514, 0.9564157770239803], 
             UndirectedEdge[199, 482] -> 
             RGBColor[
              0.35925314832548205`, 0.4855887533164457, 0.9441122708295822], 
             UndirectedEdge[9, 357] -> 
             RGBColor[
              0.19116813878282407`, 0.31826021299377427`, 0.9341981147445398],
              UndirectedEdge[330, 441] -> 
             RGBColor[
              0.20552414062024876`, 0.33334928114799606`, 0.9350156678113797],
              UndirectedEdge[375, 461] -> 
             RGBColor[
              0.22800718101290143`, 0.35698038210776833`, 0.9362960437010637],
              UndirectedEdge[170, 268] -> 
             RGBColor[
              0.18701827847814975`, 0.31389844669722133`, 0.9339617863393568],
              UndirectedEdge[66, 245] -> 
             RGBColor[
              0.22090376329813846`, 0.34951423970685647`, 0.9358915145707727],
              UndirectedEdge[235, 308] -> 
             RGBColor[
              0.2040111506020718, 0.33175903270978435`, 0.9349295052681127], 
             UndirectedEdge[42, 315] -> 
             RGBColor[
              0.19198004367677265`, 0.3191135765150577, 0.9342443515271446], 
             UndirectedEdge[238, 403] -> 
             RGBColor[
              0.6150489760394036, 0.6968155368302928, 0.9638964004459423], 
             UndirectedEdge[382, 425] -> 
             RGBColor[
              0.19937423959475875`, 0.32688534524395996`, 0.9346654400459413],
              UndirectedEdge[74, 215] -> 
             RGBColor[
              0.1868347723407586, 0.3137055701118621, 0.9339513359363054], 
             UndirectedEdge[350, 426] -> 
             RGBColor[
              0.1844406280385869, 0.3111891726527635, 0.9338149929601158], 
             UndirectedEdge[78, 497] -> 
             RGBColor[
              0.47412146300073554`, 0.5839521884493253, 0.9517437248130138], 
             UndirectedEdge[109, 490] -> 
             RGBColor[
              0.21480193499900369`, 0.3431008312862066, 0.935544024475983], 
             UndirectedEdge[281, 317] -> 
             RGBColor[
              0.8178714627321924, 0.13837347065034328`, 0.1647470389362648], 
             UndirectedEdge[219, 471] -> 
             RGBColor[
              0.8131815162037359, 0.854543894896763, 0.9628221166971644], 
             UndirectedEdge[183, 243] -> 
             RGBColor[
              0.19677206267761843`, 0.3241502923164997, 0.9345172499200859], 
             UndirectedEdge[93, 151] -> 
             RGBColor[
              0.21317178010893856`, 0.3413874351389585, 0.9354511895665918], 
             UndirectedEdge[176, 478] -> 
             RGBColor[
              0.2831235992471345, 0.4141542435922354, 0.9394625592452028], 
             UndirectedEdge[28, 282] -> 
             RGBColor[
              0.586277448481364, 0.6741728296188088, 0.961142335628971], 
             UndirectedEdge[125, 305] -> 
             RGBColor[
              0.5442522046967718, 0.6349340468295404, 0.9597558326180513], 
             UndirectedEdge[22, 466] -> 
             RGBColor[
              0.188342270881701, 0.3152900466593206, 0.9340371857480678], 
             UndirectedEdge[78, 154] -> 
             RGBColor[
              0.7267639040768494, 0.783922928096006, 0.9321470662934741], 
             UndirectedEdge[273, 421] -> 
             RGBColor[
              0.18574774173175967`, 0.3125630320200829, 0.9338894311512407], 
             UndirectedEdge[221, 234] -> 
             RGBColor[
              0.9443267569423743, 0.8151145515040961, 0.2837836064703105], 
             UndirectedEdge[384, 461] -> 
             RGBColor[
              0.26067331628804735`, 0.3913145614345472, 0.9381563317797668], 
             UndirectedEdge[3, 428] -> 
             RGBColor[
              0.18571633162823864`, 0.3125300180097667, 0.9338876423923121], 
             UndirectedEdge[209, 431] -> 
             RGBColor[
              0.707864048381464, 0.7656363882619854, 0.8446357642394154], 
             UndirectedEdge[33, 237] -> 
             RGBColor[
              0.24458077131553108`, 0.3744002763421501, 0.9372398851503687], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.26751337219857585`, 0.3985038938811058, 0.9385458628449154], 
             UndirectedEdge[202, 243] -> 
             RGBColor[
              0.1916697633639069, 0.3187874522333277, 0.9342266815223454], 
             UndirectedEdge[169, 456] -> 
             RGBColor[
              0.18971194776524802`, 0.31672966390645874`, 0.9341151868203305],
              UndirectedEdge[86, 297] -> 
             RGBColor[
              0.1902871793569701, 0.317334268781148, 0.9341479454085002], 
             UndirectedEdge[40, 202] -> 
             RGBColor[
              0.18588447811869105`, 0.31270675063233544`, 0.933897218086193], 
             UndirectedEdge[396, 477] -> 
             RGBColor[
              0.19761610506605493`, 0.32503743438212485`, 0.9345653168854586],
              UndirectedEdge[209, 355] -> 
             RGBColor[
              0.7770929742760209, 0.8227102163659248, 0.8498451509008846], 
             UndirectedEdge[131, 434] -> 
             RGBColor[
              0.8844045850628767, 0.520292002224005, 0.22327723058043727`], 
             UndirectedEdge[87, 228] -> 
             RGBColor[
              0.28331447723561765`, 0.41511185712296006`, 0.9394457124011348],
              UndirectedEdge[17, 116] -> 
             RGBColor[
              0.32596120839538445`, 0.45376963828216715`, 0.9421001714481905],
              UndirectedEdge[104, 323] -> 
             RGBColor[
              0.958420920419589, 0.8640840271773381, 0.5141442750004963], 
             UndirectedEdge[101, 347] -> 
             RGBColor[
              0.22409394315426182`, 0.3528673210047275, 0.9360731905941307], 
             UndirectedEdge[92, 342] -> 
             RGBColor[
              0.37412603951120016`, 0.4944434887241004, 0.9453570750952447], 
             UndirectedEdge[399, 464] -> 
             RGBColor[
              0.20516649221167577`, 0.332973369994367, 0.9349953002636049], 
             UndirectedEdge[423, 469] -> 
             RGBColor[
              0.18027622515678673`, 0.30681212118559864`, 0.9335778363766793],
              UndirectedEdge[114, 415] -> 
             RGBColor[
              0.18091671513236096`, 0.30748531675933716`, 0.9336143113332682],
              UndirectedEdge[244, 478] -> 
             RGBColor[
              0.34801769220506096`, 0.4703622452404419, 0.9435975534648887], 
             UndirectedEdge[129, 486] -> 
             RGBColor[
              0.3513552004898414, 0.47695704074611134`, 0.9436745944599232], 
             UndirectedEdge[202, 421] -> 
             RGBColor[
              0.18554846728188248`, 0.31235358193853213`, 0.9338780827661202],
              UndirectedEdge[62, 378] -> 
             RGBColor[
              0.22907866033211158`, 0.3581065748079708, 0.9363570628631811], 
             UndirectedEdge[263, 485] -> 
             RGBColor[
              0.23984153552950008`, 0.3694190390461275, 0.9369699926834254], 
             UndirectedEdge[275, 346] -> 
             RGBColor[
              0.4653638430606762, 0.5765191723103537, 0.951143590075486], 
             UndirectedEdge[127, 303] -> 
             RGBColor[
              0.8364744443127496, 0.5917978023235237, 0.5852770137807005], 
             UndirectedEdge[260, 312] -> 
             RGBColor[
              0.2023598436460895, 0.3300234044001388, 0.9348354657798592], 
             UndirectedEdge[32, 299] -> 
             RGBColor[
              0.22987290893586354`, 0.3589413804487841, 0.9364022941461793], 
             UndirectedEdge[283, 396] -> 
             RGBColor[
              0.18987793209336085`, 0.3169041239593195, 0.9341246393822646], 
             UndirectedEdge[87, 253] -> 
             RGBColor[
              0.34295238339538536`, 0.47143899485614194`, 0.9430747302616557],
              UndirectedEdge[298, 409] -> 
             RGBColor[
              0.26446105735967274`, 0.39529571745748016`, 0.9383720380303351],
              UndirectedEdge[208, 258] -> 
             RGBColor[
              0.42089773296190985`, 0.5389821941816072, 0.9480402092524494], 
             UndirectedEdge[142, 161] -> 
             RGBColor[
              0.21478163330642375`, 0.3430794929201034, 0.9355428683246243], 
             UndirectedEdge[71, 211] -> 
             RGBColor[
              0.19261088350739852`, 0.3197766291746009, 0.9342802769222549], 
             UndirectedEdge[14, 453] -> 
             RGBColor[
              0.23545530969286413`, 0.36480883758904264`, 0.9367202036108686],
              UndirectedEdge[89, 478] -> 
             RGBColor[
              0.27949760473699387`, 0.41101358939533483`, 0.9392315140813577],
              UndirectedEdge[159, 251] -> 
             RGBColor[
              0.23552312226059172`, 0.3648801128972894, 0.936724065436281], 
             UndirectedEdge[300, 305] -> 
             RGBColor[
              0.27120896577425085`, 0.40222097480990704`, 0.9387624442570324],
              UndirectedEdge[327, 385] -> 
             RGBColor[
              0.18266732742080666`, 0.30932532126972345`, 0.9337140061132965],
              UndirectedEdge[156, 270] -> 
             RGBColor[
              0.18975438070497386`, 0.3167742636165143, 0.9341176033134739], 
             UndirectedEdge[418, 486] -> 
             RGBColor[
              0.4449199446935177, 0.5591594372838178, 0.9497448407437088], 
             UndirectedEdge[366, 465] -> 
             RGBColor[
              0.18080307297570358`, 0.30736587164736134`, 0.9336078395805651],
              UndirectedEdge[337, 433] -> 
             RGBColor[
              0.1848796930167158, 0.31165065778310447`, 0.9338399970610818], 
             UndirectedEdge[118, 152] -> 
             RGBColor[
              0.1882232378558979, 0.3151649354020718, 0.9340304069933419], 
             UndirectedEdge[151, 162] -> 
             RGBColor[
              0.1935196204092478, 0.32073176927569186`, 0.9343320281444594], 
             UndirectedEdge[80, 251] -> 
             RGBColor[
              0.2931730251986915, 0.4218985079169302, 0.9401380516698865], 
             UndirectedEdge[348, 486] -> 
             RGBColor[
              0.4377075205538863, 0.5533040664512603, 0.949177052295457], 
             UndirectedEdge[376, 455] -> 
             RGBColor[
              0.4920767571056538, 0.5962969354126668, 0.9537739864673327], 
             UndirectedEdge[153, 197] -> 
             RGBColor[
              0.22926543037868818`, 0.35830288196882765`, 0.9363676991410321],
              UndirectedEdge[9, 319] -> 
             RGBColor[
              0.18732739999033735`, 0.3142233530059664, 0.9339793903521716], 
             UndirectedEdge[184, 336] -> 
             RGBColor[
              0.5830930532515349, 0.672420234529121, 0.9603223675736445], 
             UndirectedEdge[41, 56] -> 
             RGBColor[
              0.33496751620801646`, 0.46033233124806494`, 0.9427193789900982],
              UndirectedEdge[99, 313] -> 
             RGBColor[
              0.6704591742575927, 0.7358360174967769, 0.9317439644037724], 
             UndirectedEdge[111, 130] -> 
             RGBColor[
              0.3347552996533061, 0.46383121081799694`, 0.9425710153855427], 
             UndirectedEdge[255, 327] -> 
             RGBColor[
              0.19047479361502342`, 0.3175314632617931, 0.9341586297629458], 
             UndirectedEdge[32, 84] -> 
             RGBColor[
              0.2475939365043437, 0.3775673040012994, 0.9374114804502933], 
             UndirectedEdge[196, 420] -> 
             RGBColor[
              0.19002037884251344`, 0.3170538445243244, 0.9341327515138979], 
             UndirectedEdge[55, 57] -> 
             RGBColor[
              0.7681170081630603, 0.818182994087395, 0.9538490180959958], 
             UndirectedEdge[10, 480] -> 
             RGBColor[
              0.2350739989368308, 0.3644080558079533, 0.9366984885274112], 
             UndirectedEdge[152, 216] -> 
             RGBColor[
              0.19207526490404528`, 0.31921366006229573`, 0.9342497742351705],
              UndirectedEdge[244, 482] -> 
             RGBColor[
              0.3895468312104969, 0.511827618826672, 0.9460425575153633], 
             UndirectedEdge[111, 463] -> 
             RGBColor[
              0.4608753150975682, 0.5708435411870683, 0.9513515854271455], 
             UndirectedEdge[58, 74] -> 
             RGBColor[
              0.19093718319717995`, 0.31801746402983233`, 0.9341849621656055],
              UndirectedEdge[66, 327] -> 
             RGBColor[
              0.19083074135934272`, 0.31790558690946313`, 0.9341789004604073],
              UndirectedEdge[168, 346] -> 
             RGBColor[
              0.3670639021674008, 0.4908716279040769, 0.9446642433693013], 
             UndirectedEdge[53, 471] -> 
             RGBColor[
              0.8947556642863255, 0.6097433924263989, 0.5684355218108367], 
             UndirectedEdge[28, 125] -> 
             RGBColor[
              0.6268956164581168, 0.7059040511517584, 0.965190775014533], 
             UndirectedEdge[405, 423] -> 
             RGBColor[
              0.18042956728835297`, 0.30697329348832747`, 0.9335865689842227],
              UndirectedEdge[314, 493] -> 
             RGBColor[
              0.2618563204200539, 0.3925579737840803, 0.9382237021149867], 
             UndirectedEdge[43, 229] -> 
             RGBColor[
              0.231604699752685, 0.3607616023991431, 0.9365009170712423], 
             UndirectedEdge[281, 397] -> 
             RGBColor[
              0.8202168451405925, 0.15640110759443068`, 0.16699297977927924`],
              UndirectedEdge[203, 324] -> 
             RGBColor[
              0.8924019068162066, 0.6510073815667528, 0.588847136940535], 
             UndirectedEdge[403, 445] -> 
             RGBColor[
              0.8532638533992596, 0.8433645979013125, 0.6431418553174187], 
             UndirectedEdge[147, 303] -> 
             RGBColor[
              0.8299391758302155, 0.23113120162734693`, 0.17630309462746424`],
              UndirectedEdge[356, 457] -> 
             RGBColor[
              0.35728371097557365`, 0.477585785779042, 0.9443210439032999], 
             UndirectedEdge[8, 85] -> 
             RGBColor[
              0.19237812780276942`, 0.31953198817147166`, 0.9342670218292075],
              UndirectedEdge[301, 336] -> 
             RGBColor[
              0.6408993785116156, 0.7191341855671287, 0.9650206560001502], 
             UndirectedEdge[24, 64] -> 
             RGBColor[
              0.18504835804129488`, 0.3118279354179173, 0.933849602284714], 
             UndirectedEdge[30, 488] -> 
             RGBColor[
              0.18073134444068237`, 0.30729048040920226`, 0.9336037547466085],
              UndirectedEdge[191, 366] -> 
             RGBColor[
              0.18657672320149288`, 0.31343434410523346`, 0.9339366404195737],
              UndirectedEdge[185, 481] -> 
             RGBColor[
              0.2084048526461078, 0.33637709213486555`, 0.9351797200996208], 
             UndirectedEdge[308, 389] -> 
             RGBColor[
              0.19291290556353907`, 0.320094073504909, 0.9342974766315505], 
             UndirectedEdge[96, 240] -> 
             RGBColor[
              0.7327901627995155, 0.786266849612556, 0.8137611085910759], 
             UndirectedEdge[108, 113] -> 
             RGBColor[
              0.2031652064588611, 0.33086989177931336`, 0.934881330000619], 
             UndirectedEdge[85, 332] -> 
             RGBColor[
              0.18694868384128802`, 0.31382529832132483`, 0.9339578230277437],
              UndirectedEdge[232, 280] -> 
             RGBColor[
              0.26596668909501486`, 0.3968782318738905, 0.9384577815302801], 
             UndirectedEdge[310, 419] -> 
             RGBColor[
              0.6470494829273306, 0.7241992409118212, 0.9654555035031411], 
             UndirectedEdge[39, 378] -> 
             RGBColor[
              0.22727756338581306`, 0.356213507721269, 0.9362544930565735], 
             UndirectedEdge[53, 257] -> 
             RGBColor[
              0.8978636395827194, 0.5695936454427237, 0.2449447114503845], 
             UndirectedEdge[248, 339] -> 
             RGBColor[
              0.18022958629127006`, 0.30676310078086577`, 0.933575180362284], 
             UndirectedEdge[327, 334] -> 
             RGBColor[
              0.18531717245783108`, 0.3121104764135153, 0.9338649108680606], 
             UndirectedEdge[165, 358] -> 
             RGBColor[
              0.26540482039910535`, 0.39628767224995665`, 0.9384257839392585],
              UndirectedEdge[69, 204] -> 
             RGBColor[
              0.37937968200922045`, 0.5030213452043036, 0.9453947157587149], 
             UndirectedEdge[208, 293] -> 
             RGBColor[
              0.6181817945706438, 0.697617598691705, 0.965038174550626], 
             UndirectedEdge[265, 320] -> 
             RGBColor[
              0.18273053674122575`, 0.3093917582731863, 0.9337176057905845], 
             UndirectedEdge[239, 453] -> 
             RGBColor[
              0.21828737914361301`, 0.34676425407211353`, 0.935742515363766], 
             UndirectedEdge[108, 452] -> 
             RGBColor[
              0.21821098000140754`, 0.3466839537296702, 0.9357381645456397], 
             UndirectedEdge[331, 418] -> 
             RGBColor[
              0.38897001185206387`, 0.5100224409848767, 0.9462045113122062], 
             UndirectedEdge[28, 201] -> 
             RGBColor[
              0.3666465873540202, 0.4866385048510442, 0.9449259979753362], 
             UndirectedEdge[431, 486] -> 
             RGBColor[
              0.4172932945902137, 0.5358602108283841, 0.9478105376266845], 
             UndirectedEdge[269, 419] -> 
             RGBColor[
              0.6255800853713929, 0.7068070035141348, 0.9637396556343641], 
             UndirectedEdge[315, 378] -> 
             RGBColor[
              0.19518703914887203`, 0.3224843320914912, 0.934426985174956], 
             UndirectedEdge[57, 240] -> 
             RGBColor[
              0.9787234021564939, 0.9814785102156434, 0.8120827611030339], 
             UndirectedEdge[7, 176] -> 
             RGBColor[
              0.39464375574399807`, 0.5157254458506131, 0.9465101425420326], 
             UndirectedEdge[6, 302] -> 
             RGBColor[
              0.22957764048616652`, 0.3586310345870516, 0.9363854790447795], 
             UndirectedEdge[176, 455] -> 
             RGBColor[
              0.46498904560871784`, 0.5728349211819872, 0.9520479814434708], 
             UndirectedEdge[161, 396] -> 
             RGBColor[
              0.205644516605638, 0.33347580394091847`, 0.9350225230456672], 
             UndirectedEdge[36, 463] -> 
             RGBColor[
              0.7746453145833472, 0.820791726755383, 0.8525214986025103], 
             UndirectedEdge[131, 373] -> 
             RGBColor[
              0.9123644303428394, 0.625404830056993, 0.48937807328246297`], 
             UndirectedEdge[54, 341] -> 
             RGBColor[
              0.991911410491914, 0.9900737129022821, 0.7219654915810148], 
             UndirectedEdge[272, 453] -> 
             RGBColor[
              0.24857862251541402`, 0.3786022714316334, 0.9374675568619113], 
             UndirectedEdge[169, 236] -> 
             RGBColor[
              0.19608590653883476`, 0.32342909870982617`, 0.9344781743430592],
              UndirectedEdge[69, 101] -> 
             RGBColor[
              0.3439836908945852, 0.4664796432810521, 0.9433547372891266], 
             UndirectedEdge[286, 330] -> 
             RGBColor[
              0.18848828405783719`, 0.3154435157652098, 0.9340455009824417], 
             UndirectedEdge[86, 254] -> 
             RGBColor[
              0.18887066842711453`, 0.3158454259818896, 0.934067277206585], 
             UndirectedEdge[68, 319] -> 
             RGBColor[
              0.1831451884938083, 0.30982758355559015`, 0.9337412195944718], 
             UndirectedEdge[37, 207] -> 
             RGBColor[
              0.8684208855066446, 0.4954117968161807, 0.21191950037856397`], 
             UndirectedEdge[257, 317] -> 
             RGBColor[
              0.8901858085318111, 0.510578471538423, 0.23759241176516477`], 
             UndirectedEdge[94, 158] -> 
             RGBColor[
              0.18531714297239393`, 0.3121104454224513, 0.9338649091889084], 
             UndirectedEdge[253, 336] -> 
             RGBColor[
              0.5014215448022852, 0.6040567843941038, 0.9544617509696633], 
             UndirectedEdge[67, 363] -> 
             RGBColor[
              0.18174309364533237`, 0.30835389297189403`, 0.9336613723670645],
              UndirectedEdge[61, 295] -> 
             RGBColor[
              0.9875274720228682, 0.989110303399177, 0.8563655966561801], 
             UndirectedEdge[16, 116] -> 
             RGBColor[
              0.2732978193858072, 0.4045837146300204, 0.9388752785549055], 
             UndirectedEdge[294, 439] -> 
             RGBColor[
              0.19336116609564466`, 0.3205652237455112, 0.9343230044057118], 
             UndirectedEdge[69, 346] -> 
             RGBColor[
              0.4421357571807656, 0.5573775033058451, 0.9493934773756274], 
             UndirectedEdge[327, 415] -> 
             RGBColor[
              0.1820891431356189, 0.3087176129269901, 0.9336810793736019], 
             UndirectedEdge[54, 61] -> 
             RGBColor[
              0.9898922626687403, 0.9900882051035927, 0.8171748957720661], 
             UndirectedEdge[244, 262] -> 
             RGBColor[
              0.3949445171400494, 0.5165028230832673, 0.9463864932898081], 
             UndirectedEdge[295, 397] -> 
             RGBColor[
              0.9034028373173626, 0.5790815030588307, 0.5351722665672494], 
             UndirectedEdge[61, 264] -> 
             RGBColor[
              0.9279014667399095, 0.7362939743699763, 0.5103077071950994], 
             UndirectedEdge[162, 226] -> 
             RGBColor[
              0.18515287463647273`, 0.3119377889861841, 0.933855554350191], 
             UndirectedEdge[237, 351] -> 
             RGBColor[
              0.2365402762573613, 0.3659492062391825, 0.9367819908516525], 
             UndirectedEdge[243, 273] -> 
             RGBColor[
              0.1918690378137841, 0.3189969023148785, 0.9342380299074659], 
             UndirectedEdge[53, 343] -> 
             RGBColor[
              0.8394526370347362, 0.3042558332705747, 0.18541319582083088`], 
             UndirectedEdge[37, 445] -> 
             RGBColor[
              0.9124867892485535, 0.6764249054783144, 0.25883228336174086`], 
             UndirectedEdge[144, 402] -> 
             RGBColor[
              0.20750395596016302`, 0.3354301925977886, 0.9351284153661135], 
             UndirectedEdge[235, 456] -> 
             RGBColor[
              0.20636469541016642`, 0.3342327575264513, 0.9350635361631761], 
             UndirectedEdge[369, 456] -> 
             RGBColor[
              0.1888191818250698, 0.31579131029870144`, 0.9340643451207662], 
             UndirectedEdge[7, 61] -> 
             RGBColor[
              0.7313065318033417, 0.7863785903909934, 0.8813505639139341], 
             UndirectedEdge[76, 175] -> 
             RGBColor[
              0.404052773600639, 0.5243919370351493, 0.946966863337362], 
             UndirectedEdge[259, 372] -> 
             RGBColor[
              0.6487722113207766, 0.7251147800966794, 0.9659213864599616], 
             UndirectedEdge[187, 224] -> 
             RGBColor[
              0.2135902734770326, 0.34182729820283736`, 0.9354750221447994], 
             UndirectedEdge[142, 183] -> 
             RGBColor[
              0.20633874170827649`, 0.3342054785402052, 0.9350620581382485], 
             UndirectedEdge[255, 299] -> 
             RGBColor[
              0.21862190988624552`, 0.3471158670930945, 0.935761566394665], 
             UndirectedEdge[233, 444] -> 
             RGBColor[
              0.7642107527779903, 0.8150144746201845, 0.9536153862998804], 
             UndirectedEdge[148, 280] -> 
             RGBColor[
              0.2640545871077613, 0.39486849145101877`, 0.9383488901508075], 
             UndirectedEdge[7, 376] -> 
             RGBColor[
              0.421731467240934, 0.5391874600812927, 0.9482361475658946], 
             UndirectedEdge[73, 256] -> 
             RGBColor[
              0.4442279577887227, 0.5558341651072809, 0.9504539244246188], 
             UndirectedEdge[207, 403] -> 
             RGBColor[
              0.8091979496573507, 0.6623514892391787, 0.5962290723342419], 
             UndirectedEdge[233, 346] -> 
             RGBColor[
              0.7019863596204035, 0.7641747233325396, 0.948806151319425], 
             UndirectedEdge[293, 403] -> 
             RGBColor[
              0.7765788883904609, 0.8253885969195616, 0.9783657841185909], 
             UndirectedEdge[321, 391] -> 
             RGBColor[
              0.7292749424513578, 0.7856899772227003, 0.9213526032018919], 
             UndirectedEdge[228, 298] -> 
             RGBColor[
              0.2669525907215979, 0.3979144769932027, 0.9385139271694034], 
             UndirectedEdge[54, 455] -> 
             RGBColor[
              0.8012850501089904, 0.8433363962570924, 0.8929667567235482], 
             UndirectedEdge[323, 419] -> 
             RGBColor[
              0.8209982189868783, 0.8586000678793866, 0.8680770966029969], 
             UndirectedEdge[65, 194] -> 
             RGBColor[
              0.18464315044443147`, 0.3114020365419683, 0.9338265263115236], 
             UndirectedEdge[40, 273] -> 
             RGBColor[
              0.18608375256856824`, 0.31291620071388626`, 0.9339085664713134],
              UndirectedEdge[209, 400] -> 
             RGBColor[
              0.9921722318540724, 0.9910310309542629, 0.7793899060000027], 
             UndirectedEdge[31, 488] -> 
             RGBColor[
              0.1872548538957951, 0.31414710246091443`, 0.9339752589594097], 
             UndirectedEdge[399, 407] -> 
             RGBColor[
              0.2425042792072058, 0.3722177514790964, 0.9371216319966944], 
             UndirectedEdge[292, 399] -> 
             RGBColor[
              0.19649944973854266`, 0.32386375883287244`, 0.9345017250165003],
              UndirectedEdge[93, 218] -> 
             RGBColor[
              0.2542535028794738, 0.3845669305024568, 0.9377907329034113], 
             UndirectedEdge[198, 270] -> 
             RGBColor[
              0.1812627552425552, 0.3078490268553615, 0.9336340178056233], 
             UndirectedEdge[78, 192] -> 
             RGBColor[
              0.39152498613418535`, 0.5130863931305935, 0.946294212255822], 
             UndirectedEdge[286, 492] -> 
             RGBColor[
              0.18500229424892267`, 0.31177951945152094`, 0.9338469790198838],
              UndirectedEdge[317, 343] -> 
             RGBColor[
              0.8317748059838278, 0.24524065936627398`, 0.17806089613561116`],
              UndirectedEdge[51, 203] -> 
             RGBColor[
              0.9201617687823374, 0.6698476352137519, 0.4577172955235477], 
             UndirectedEdge[212, 216] -> 
             RGBColor[
              0.19093042363498117`, 0.31801035930138044`, 0.9341845772185382],
              UndirectedEdge[100, 257] -> 
             RGBColor[
              0.9781397520963673, 0.9374756322249009, 0.407566735110352], 
             UndirectedEdge[189, 302] -> 
             RGBColor[
              0.24836644407899122`, 0.3783792584420631, 0.9374554736138468], 
             UndirectedEdge[306, 382] -> 
             RGBColor[
              0.2264199096398822, 0.3553120592559075, 0.9362056509445278], 
             UndirectedEdge[20, 150] -> 
             RGBColor[
              0.22855902835216374`, 0.35756040865047517`, 0.9363274705906497],
              UndirectedEdge[255, 446] -> 
             RGBColor[
              0.19028875988053398`, 0.31733593001162463`, 0.9341480354169789],
              UndirectedEdge[182, 237] -> 
             RGBColor[
              0.2889436538091614, 0.4176768128895569, 0.9398890065800227], 
             UndirectedEdge[4, 366] -> 
             RGBColor[
              0.18203443666830332`, 0.30866011296125107`, 0.9336779639212193],
              UndirectedEdge[231, 275] -> 
             RGBColor[
              0.6264851574368956, 0.7057897543518528, 0.9650087769508688], 
             UndirectedEdge[97, 231] -> 
             RGBColor[
              0.8760573705850234, 0.8940094298858756, 0.6933676019879993], 
             UndirectedEdge[114, 128] -> 
             RGBColor[
              0.1878451960142834, 0.31476758945729777`, 0.9340088780697248], 
             UndirectedEdge[207, 471] -> 
             RGBColor[
              0.9159118385486107, 0.7462782372358219, 0.5876734401900829], 
             UndirectedEdge[54, 391] -> 
             RGBColor[0.731320111432247, 0.7865357071547434, 0.8874588604609],
              UndirectedEdge[299, 478] -> 
             RGBColor[
              0.24469356026771227`, 0.3745188246821251, 0.9372463083143392], 
             UndirectedEdge[44, 365] -> 
             RGBColor[
              0.24302709585907487`, 0.37276726492870105`, 0.9371514056315804],
              UndirectedEdge[6, 101] -> 
             RGBColor[
              0.22975280750904292`, 0.3588151462343254, 0.9363954545475959], 
             UndirectedEdge[236, 308] -> 
             RGBColor[
              0.19963189940938322`, 0.3271561620457061, 0.9346801133912106], 
             UndirectedEdge[47, 256] -> 
             RGBColor[
              0.2965835068490444, 0.4287985034009982, 0.9402108818731908], 
             UndirectedEdge[304, 427] -> 
             RGBColor[
              0.18861159117236292`, 0.315573119360699, 0.9340525231401974], 
             UndirectedEdge[54, 397] -> 
             RGBColor[
              0.9057676279632347, 0.5800594047632462, 0.4959815656831355], 
             UndirectedEdge[220, 254] -> 
             RGBColor[
              0.20473141614653206`, 0.3325160774644852, 0.9349705233253323], 
             UndirectedEdge[377, 426] -> 
             RGBColor[
              0.1840742886923742, 0.31080412677263786`, 0.9337941304762996], 
             UndirectedEdge[216, 292] -> 
             RGBColor[
              0.19251751538449438`, 0.3196784933575477, 0.9342749597457812], 
             UndirectedEdge[42, 119] -> 
             RGBColor[
              0.1924345707120309, 0.31959131324779266`, 0.9342702361693901], 
             UndirectedEdge[170, 491] -> 
             RGBColor[
              0.18468093358720655`, 0.3114417490206145, 0.9338286780056095], 
             UndirectedEdge[257, 326] -> 
             RGBColor[
              0.8442173233312698, 0.8362115823989578, 0.6421148916132133], 
             UndirectedEdge[98, 347] -> 
             RGBColor[
              0.19568928020766854`, 0.32301221928820867`, 0.9344555870602553],
              UndirectedEdge[271, 311] -> 
             RGBColor[
              0.19904018271004636`, 0.32653423027769746`, 0.9346464160005499],
              UndirectedEdge[156, 227] -> 
             RGBColor[
              0.1962768676534719, 0.3236298109489438, 0.9344890492960363], 
             UndirectedEdge[151, 160] -> 
             RGBColor[
              0.22158100780321188`, 0.3502260666214703, 0.9359300826434431], 
             UndirectedEdge[93, 167] -> 
             RGBColor[
              0.23124675852992788`, 0.3603853834792411, 0.9364805328481329], 
             UndirectedEdge[275, 348] -> 
             RGBColor[
              0.475696405739353, 0.5852307979148967, 0.9518677100746031], 
             UndirectedEdge[34, 394] -> 
             RGBColor[
              0.19619166312976455`, 0.3235402555922485, 0.9344841970244598], 
             UndirectedEdge[405, 488] -> 
             RGBColor[
              0.182093967520493, 0.30872268366137645`, 0.9336813541151835], 
             UndirectedEdge[338, 443] -> 
             RGBColor[
              0.3560845115696105, 0.4809110296827722, 0.9439811523759123], 
             UndirectedEdge[301, 316] -> 
             RGBColor[
              0.547580608865669, 0.6429772459967242, 0.9577838308857021], 
             UndirectedEdge[103, 209] -> 
             RGBColor[
              0.7021401008892698, 0.7606785926382128, 0.8442710393667008], 
             UndirectedEdge[126, 414] -> 
             RGBColor[
              0.45556143140572114`, 0.5680520611940277, 0.9505125663614704], 
             UndirectedEdge[154, 341] -> 
             RGBColor[
              0.9888822096717337, 0.9887006265396945, 0.7667739089616505], 
             UndirectedEdge[306, 347] -> 
             RGBColor[
              0.22192337354853872`, 0.3505859147270508, 0.9359495798661548], 
             UndirectedEdge[20, 388] -> 
             RGBColor[
              0.2852227543233797, 0.4152738080593815, 0.9396218953833091], 
             UndirectedEdge[286, 319] -> 
             RGBColor[
              0.18412936406719407`, 0.310862014483554, 0.9337972669374188], 
             UndirectedEdge[62, 96] -> 
             RGBColor[
              0.36098375539591054`, 0.48129258556863375`, 0.9445483392518976],
              UndirectedEdge[149, 242] -> 
             RGBColor[
              0.767121254823353, 0.8170287735130601, 0.9444951769225841], 
             UndirectedEdge[212, 319] -> 
             RGBColor[
              0.18140430286516612`, 0.3079978023813632, 0.93364207873333], 
             UndirectedEdge[289, 470] -> 
             RGBColor[
              0.20234342031166005`, 0.33000614243435394`, 0.9348345304952597],
              UndirectedEdge[291, 353] -> 
             RGBColor[
              0.18189358061228061`, 0.3085120643155814, 0.9336699423772067], 
             UndirectedEdge[21, 91] -> 
             RGBColor[
              0.3801635060105999, 0.5027016523216035, 0.9455268210185781], 
             UndirectedEdge[95, 224] -> 
             RGBColor[
              0.19530748745975585`, 0.322610930903094, 0.9344338445280735], 
             UndirectedEdge[218, 235] -> 
             RGBColor[
              0.2514972659875934, 0.38166995077357824`, 0.9376337692899057], 
             UndirectedEdge[108, 315] -> 
             RGBColor[
              0.19651178198130725`, 0.3238767208019274, 0.9345024273194817], 
             UndirectedEdge[61, 154] -> 
             RGBColor[
              0.9868630618485601, 0.9887151187410052, 0.8619833131527019], 
             UndirectedEdge[297, 413] -> 
             RGBColor[
              0.2127862490397303, 0.34098221754113894`, 0.9354292341425425], 
             UndirectedEdge[294, 438] -> 
             RGBColor[
              0.19506692603526019`, 0.32235808559347384`, 0.9344201449108273],
              UndirectedEdge[277, 386] -> 
             RGBColor[
              0.3744145130463712, 0.49843012291785427`, 0.9450889814281427], 
             UndirectedEdge[125, 249] -> 
             RGBColor[
              0.7524497512082946, 0.8065387315646185, 0.9759608172238798], 
             UndirectedEdge[211, 308] -> 
             RGBColor[
              0.18919374524082816`, 0.3161850001973557, 0.9340856759531767], 
             UndirectedEdge[273, 477] -> 
             RGBColor[
              0.19247626140559868`, 0.319635132810075, 0.9342726103927129], 
             UndirectedEdge[154, 397] -> 
             RGBColor[
              0.9027384271430544, 0.5786863184006587, 0.5407899830637712], 
             UndirectedEdge[105, 230] -> 
             RGBColor[
              0.19866180408544326`, 0.32613653035264917`, 0.9346248678976397],
              UndirectedEdge[355, 404] -> 
             RGBColor[
              0.6982683944179626, 0.7630818994281268, 0.9713900254136139], 
             UndirectedEdge[250, 263] -> 
             RGBColor[
              0.22198989446995654`, 0.350655832433131, 0.9359533681342207], 
             UndirectedEdge[11, 259] -> 
             RGBColor[
              0.5294234413742529, 0.6261111308515327, 0.9571090734444168], 
             UndirectedEdge[339, 439] -> 
             RGBColor[
              0.18970826562688875`, 0.316725793745582, 0.9341149771279982], 
             UndirectedEdge[303, 379] -> 
             RGBColor[
              0.8341112743268393, 0.26319977889761653`, 0.18029830085954252`],
              UndirectedEdge[416, 468] -> 
             RGBColor[
              0.21536523562869736`, 0.3436928959633374, 0.9355761036135155], 
             UndirectedEdge[77, 336] -> 
             RGBColor[
              0.47990926789082156`, 0.58542393137187, 0.9530910077074245], 
             UndirectedEdge[297, 412] -> 
             RGBColor[
              0.1927590864051722, 0.31993239981676747`, 0.9342887168580365], 
             UndirectedEdge[69, 418] -> 
             RGBColor[
              0.45968074399907377`, 0.5719444997429457, 0.9506853858229966], 
             UndirectedEdge[281, 322] -> 
             RGBColor[
              0.8196030856546299, 0.15168348323420097`, 0.16640524300237935`],
              UndirectedEdge[51, 495] -> 
             RGBColor[
              0.9406722816777016, 0.7839532053527796, 0.47565298592181493`], 
             UndirectedEdge[227, 229] -> 
             RGBColor[
              0.21399982241481183`, 0.34225776010334574`, 0.9354983453509325],
              UndirectedEdge[192, 497] -> 
             RGBColor[
              0.3955857304505306, 0.5163830883010493, 0.9466138889234013], 
             UndirectedEdge[143, 277] -> 
             RGBColor[
              0.5119391923573035, 0.6143803189362278, 0.9547965836382715], 
             UndirectedEdge[87, 161] -> 
             RGBColor[
              0.2611314320863651, 0.3917960701847984, 0.9381824207967593], 
             UndirectedEdge[114, 255] -> 
             RGBColor[
              0.1893023656117655, 0.31629916709414013`, 0.9340918617226122], 
             UndirectedEdge[341, 391] -> 
             RGBColor[
              0.7337060308144916, 0.7866728844187078, 0.7861711023616725], 
             UndirectedEdge[35, 347] -> 
             RGBColor[
              0.19536292222488982`, 0.32266919635601693`, 0.9344370014559396],
              UndirectedEdge[99, 498] -> 
             RGBColor[
              0.8771421221278247, 0.9041056565781206, 0.9487087442796804], 
             UndirectedEdge[89, 448] -> 
             RGBColor[
              0.30513277253024496`, 0.43795777610955633`, 0.9406913989633512],
              UndirectedEdge[130, 371] -> 
             RGBColor[
              0.27850064570472033`, 0.41005221496943967`, 0.9391715718168758],
              UndirectedEdge[187, 481] -> 
             RGBColor[
              0.21325750963013368`, 0.3414775423013001, 0.9354560717359984], 
             UndirectedEdge[427, 500] -> 
             RGBColor[
              0.19375142518042626`, 0.32097541078747177`, 0.9343452290832536],
              UndirectedEdge[134, 247] -> 
             RGBColor[
              0.1842053003124589, 0.3109418282919634, 0.933801591394249], 
             UndirectedEdge[79, 301] -> 
             RGBColor[
              0.7713475583434661, 0.821837420942344, 0.9777022478790838], 
             UndirectedEdge[173, 323] -> 
             RGBColor[
              0.8566536605338118, 0.8864543698072436, 0.8716308977973497], 
             UndirectedEdge[84, 262] -> 
             RGBColor[
              0.3093414127711809, 0.4392853260774658, 0.9410444344433726], 
             UndirectedEdge[262, 391] -> 
             RGBColor[
              0.4081410490049733, 0.5273954680265918, 0.9473758851308575], 
             UndirectedEdge[205, 382] -> 
             RGBColor[
              0.22477554462649751`, 0.3535837273680766, 0.9361120067896356], 
             UndirectedEdge[50, 499] -> 
             RGBColor[
              0.7544680909250315, 0.8083923113644382, 0.9761768691183477], 
             UndirectedEdge[108, 380] -> 
             RGBColor[
              0.19854131235532485`, 0.3260098859046778, 0.934618006071861], 
             UndirectedEdge[300, 493] -> 
             RGBColor[
              0.24638397938180046`, 0.376295562349794, 0.9373425751821356], 
             UndirectedEdge[331, 382] -> 
             RGBColor[
              0.25675225340899854`, 0.38719327573892137`, 0.9379330330494976],
              UndirectedEdge[186, 495] -> 
             RGBColor[
              0.9397076490875935, 0.7818899537818541, 0.3706586815108439], 
             UndirectedEdge[93, 235] -> 
             RGBColor[
              0.21987414226832205`, 0.3484320427227756, 0.9358328791763124], 
             UndirectedEdge[18, 300] -> 
             RGBColor[
              0.26008832470075693`, 0.39069969818569605`, 0.938123017374288], 
             UndirectedEdge[223, 246] -> 
             RGBColor[
              0.22404185527291065`, 0.35281257333886495`, 0.9360702242663449],
              UndirectedEdge[233, 431] -> 
             RGBColor[
              0.6919046963354076, 0.7554424933142063, 0.9481637566497699], 
             UndirectedEdge[182, 351] -> 
             RGBColor[
              0.2925937639781592, 0.42151331010752513`, 0.9400968749542931], 
             UndirectedEdge[163, 209] -> 
             RGBColor[
              0.9468923206889115, 0.8138245711399055, 0.48945082932663964`], 
             UndirectedEdge[70, 182] -> 
             RGBColor[
              0.35737014201408246`, 0.4839577878921605, 0.9439922873324968], 
             UndirectedEdge[59, 335] -> 
             RGBColor[
              0.2366854990874992, 0.3661018446413167, 0.9367902610769909], 
             UndirectedEdge[258, 453] -> 
             RGBColor[
              0.3275555861569279, 0.45177144641276795`, 0.942325491454229], 
             UndirectedEdge[161, 354] -> 
             RGBColor[
              0.262219161885439, 0.39276906224398844`, 0.9382506002184958], 
             UndirectedEdge[213, 489] -> 
             RGBColor[
              0.19691928671610104`, 0.3243050341154881, 0.9345256341112791], 
             UndirectedEdge[260, 407] -> 
             RGBColor[
              0.24344019620099944`, 0.3732014595801383, 0.9371749310849259], 
             UndirectedEdge[95, 185] -> 
             RGBColor[
              0.19811081032671668`, 0.3255574009772055, 0.9345934896182024], 
             UndirectedEdge[117, 479] -> 
             RGBColor[
              0.1829410540251313, 0.30961302528613777`, 0.9337295944384705], 
             UndirectedEdge[164, 444] -> 
             RGBColor[
              0.4409447203988165, 0.5532899965320492, 0.9501619372363984], 
             UndirectedEdge[32, 334] -> 
             RGBColor[
              0.2032637935146371, 0.3309735130257143, 0.934886944387599], 
             UndirectedEdge[46, 325] -> 
             RGBColor[
              0.2186729430619583, 0.3471695061964588, 0.935764472658525], 
             UndirectedEdge[18, 201] -> 
             RGBColor[
              0.27288253451918126`, 0.4041472239046152, 0.93885162869611], 
             UndirectedEdge[328, 398] -> 
             RGBColor[
              0.2246228179747201, 0.35342320197362953`, 0.9361033092327558], 
             UndirectedEdge[376, 448] -> 
             RGBColor[
              0.33584647853732147`, 0.4645604445371366, 0.9426484491510583], 
             UndirectedEdge[326, 355] -> 
             RGBColor[
              0.642545935987291, 0.7194149561297569, 0.9658722576270347], 
             UndirectedEdge[257, 281] -> 
             RGBColor[
              0.8907382712640035, 0.5148249421887663, 0.2381214507014296], 
             UndirectedEdge[32, 89] -> 
             RGBColor[
              0.26467695340514513`, 0.3954361451619938, 0.9383874999131978], 
             UndirectedEdge[341, 397] -> 
             RGBColor[
              0.9081535473454794, 0.5801965820272107, 0.39469380758390815`], 
             UndirectedEdge[160, 274] -> 
             RGBColor[
              0.24176660566523328`, 0.3714424098152794, 0.9370796225797693], 
             UndirectedEdge[151, 235] -> 
             RGBColor[
              0.21041554321705824`, 0.3384904554100799, 0.9352942259530863], 
             UndirectedEdge[11, 372] -> 
             RGBColor[
              0.49492242636970674`, 0.598728406383233, 0.9539645121894538], 
             UndirectedEdge[99, 295] -> 
             RGBColor[
              0.9822469150718874, 0.9861800274834427, 0.9104424780465525], 
             UndirectedEdge[154, 199] -> 
             RGBColor[
              0.684800695862128, 0.748031110338605, 0.9293475993147051], 
             UndirectedEdge[169, 308] -> 
             RGBColor[
              0.18735840295715342`, 0.31425593908979166`, 0.9339811559252671],
              UndirectedEdge[158, 410] -> 
             RGBColor[
              0.18697773490946556`, 0.31385583283592355`, 0.933959477443099], 
             UndirectedEdge[311, 465] -> 
             RGBColor[
              0.1845169561942322, 0.31126939838383133`, 0.9338193397356624], 
             UndirectedEdge[139, 428] -> 
             RGBColor[
              0.1851867200986532, 0.311973362712862, 0.9338574817991923], 
             UndirectedEdge[113, 364] -> 
             RGBColor[
              0.20055433939420772`, 0.3281257049558297, 0.9347326449837188], 
             UndirectedEdge[89, 475] -> 
             RGBColor[
              0.32310504521526556`, 0.4542790832588659, 0.9418089456639116], 
             UndirectedEdge[375, 441] -> 
             RGBColor[
              0.2121051529687783, 0.3402663423865834, 0.9353904467288932], 
             UndirectedEdge[244, 295] -> 
             RGBColor[
              0.7157587889214511, 0.7746651605070033, 0.9256601695039643], 
             UndirectedEdge[187, 260] -> 
             RGBColor[
              0.21549852964428565`, 0.3438329964250494, 0.9355836945105124], 
             UndirectedEdge[207, 322] -> 
             RGBColor[
              0.8478846282356312, 0.34298703129758157`, 0.19246642213058046`],
              UndirectedEdge[100, 457] -> 
             RGBColor[
              0.7312390426759171, 0.7839598047362808, 0.7277634832098476], 
             UndirectedEdge[364, 416] -> 
             RGBColor[
              0.20681043357905127`, 0.33470125660338146`, 0.9350889202924836],
              UndirectedEdge[313, 386] -> 
             RGBColor[
              0.33341144011418006`, 0.4629153220183585, 0.9424763018784972], 
             UndirectedEdge[31, 472] -> 
             RGBColor[
              0.1875584213311225, 0.31446617108273056`, 0.9339925466757639], 
             UndirectedEdge[37, 49] -> 
             RGBColor[
              0.9278898442559633, 0.7275054583426774, 0.39329233295696453`], 
             UndirectedEdge[201, 406] -> 
             RGBColor[
              0.33697692661979073`, 0.46155170113037025`, 0.9428664961514535],
              UndirectedEdge[245, 376] -> 
             RGBColor[
              0.30751706029421144`, 0.43478442977476833`, 0.9410351306917317],
              UndirectedEdge[58, 215] -> 
             RGBColor[
              0.1890650982052305, 0.3160497840062494, 0.9340783496948156], 
             UndirectedEdge[84, 407] -> 
             RGBColor[
              0.27632252286434345`, 0.40776286976323906`, 0.9390475309433604],
              UndirectedEdge[100, 324] -> 
             RGBColor[
              0.9664798274342277, 0.9712473493741347, 0.7455337650413938], 
             UndirectedEdge[89, 176] -> 
             RGBColor[
              0.31330748759898347`, 0.4457929312912065, 0.9411846539562421], 
             UndirectedEdge[75, 379] -> 
             RGBColor[
              0.8463714309227728, 0.346563167860244, 0.1916128598280513], 
             UndirectedEdge[123, 422] -> 
             RGBColor[
              0.1961933017960193, 0.3235419779343797, 0.9344842903440789], 
             UndirectedEdge[407, 455] -> 
             RGBColor[
              0.44508709777487926`, 0.5526737008147141, 0.9508868778934936], 
             UndirectedEdge[333, 358] -> 
             RGBColor[
              0.22833564415577742`, 0.35732561769669713`, 0.9363147491911328],
              UndirectedEdge[120, 124] -> 
             RGBColor[
              0.18263624540769638`, 0.3092926521032311, 0.9337122360386315], 
             UndirectedEdge[88, 433] -> 
             RGBColor[
              0.18511620603054046`, 0.3118992479564254, 0.9338534661273294], 
             UndirectedEdge[345, 456] -> 
             RGBColor[
              0.1932262687729535, 0.32042343810637863`, 0.9343153222027473], 
             UndirectedEdge[392, 474] -> 
             RGBColor[
              0.23318205607902553`, 0.3624195039082944, 0.9365907451805379], 
             UndirectedEdge[165, 333] -> 
             RGBColor[
              0.26885740704369754`, 0.3999165597200598, 0.9386224036410238], 
             UndirectedEdge[31, 133] -> 
             RGBColor[
              0.1949807850604232, 0.3222675459672669, 0.9344152393097445], 
             UndirectedEdge[171, 208] -> 
             RGBColor[
              0.44865476640412644`, 0.5625521197174839, 0.9499392286265838], 
             UndirectedEdge[284, 472] -> 
             RGBColor[
              0.19498301286010505`, 0.32226988752598323`, 0.9344153661796406],
              UndirectedEdge[196, 427] -> 
             RGBColor[
              0.18925515066577042`, 0.3162495411922988, 0.9340891729012859], 
             UndirectedEdge[179, 334] -> 
             RGBColor[
              0.1934836161981846, 0.32069392656706563`, 0.9343299777579028], 
             UndirectedEdge[97, 233] -> 
             RGBColor[
              0.9755070986726647, 0.9721600768096842, 0.6789609948576975], 
             UndirectedEdge[21, 409] -> 
             RGBColor[
              0.27661821411791565`, 0.40807366001865175`, 0.9390643701228152],
              UndirectedEdge[63, 344] -> 
             RGBColor[
              0.19854348560024537`, 0.326012170122881, 0.9346181298349442], 
             UndirectedEdge[292, 398] -> 
             RGBColor[
              0.19568953649861287`, 0.32301248866624094`, 0.9344556016556456],
              UndirectedEdge[71, 197] -> 
             RGBColor[
              0.2143161876130597, 0.34259027998541636`, 0.9355163618809523], 
             UndirectedEdge[81, 121] -> 
             RGBColor[
              0.22174468237743916`, 0.35039809897655055`, 0.9359394036683106],
              UndirectedEdge[163, 317] -> 
             RGBColor[
              0.8583137676007231, 0.3848962000432028, 0.20095545620474106`], 
             UndirectedEdge[167, 172] -> 
             RGBColor[
              0.23167761735264775`, 0.36083824341994686`, 0.9365050696206882],
              UndirectedEdge[191, 488] -> 
             RGBColor[
              0.18656266374586195`, 0.3134195667259444, 0.9339358397543747], 
             UndirectedEdge[392, 490] -> 
             RGBColor[
              0.2264092533563037, 0.355300858826219, 0.9362050440849425], 
             UndirectedEdge[251, 272] -> 
             RGBColor[
              0.24807843064742718`, 0.378076538064383, 0.937439071674997], 
             UndirectedEdge[66, 255] -> 
             RGBColor[
              0.19752636336653073`, 0.32494311016597255`, 0.9345602062284316],
              UndirectedEdge[177, 194] -> 
             RGBColor[
              0.1852447118397448, 0.312034315709638, 0.9338607843430564], 
             UndirectedEdge[36, 359] -> 
             RGBColor[
              0.9518288028476951, 0.9612683407754878, 0.8690761481825573], 
             UndirectedEdge[46, 377] -> 
             RGBColor[
              0.192250993648715, 0.31939836211478956`, 0.9342597817272121], 
             UndirectedEdge[6, 306] -> 
             RGBColor[
              0.22758223790331983`, 0.3565337399566487, 0.93627184381962], 
             UndirectedEdge[7, 455] -> 
             RGBColor[
              0.5426993192435918, 0.6396267815444932, 0.9571424248654161], 
             UndirectedEdge[84, 482] -> 
             RGBColor[
              0.30394372684162835`, 0.43461012182087044`, 0.9407004986689278],
              UndirectedEdge[83, 97] -> 
             RGBColor[
              0.9918418301129188, 0.9825092007837744, 0.5692119944347548], 
             UndirectedEdge[125, 408] -> 
             RGBColor[
              0.8576169370417068, 0.8896033538181681, 0.9847741152357485], 
             UndirectedEdge[184, 473] -> 
             RGBColor[
              0.4022146970771591, 0.5162489604655307, 0.9476591763750619], 
             UndirectedEdge[410, 422] -> 
             RGBColor[
              0.19439415698617535`, 0.3216509626668643, 0.9343818317087544], 
             UndirectedEdge[202, 283] -> 
             RGBColor[
              0.1845388139830274, 0.3112923723057189, 0.9338205845043986], 
             UndirectedEdge[320, 329] -> 
             RGBColor[
              0.18135868640525998`, 0.3079498565897512, 0.9336394809434219], 
             UndirectedEdge[146, 387] -> 
             RGBColor[
              0.18448194243535776`, 0.3112325967032537, 0.9338173457538927], 
             UndirectedEdge[107, 170] -> 
             RGBColor[
              0.19951076544330998`, 0.3270288425670261, 0.9346732149910444], 
             UndirectedEdge[273, 459] -> 
             RGBColor[
              0.19081936422215473`, 0.3178936288169264, 0.9341782525492754], 
             UndirectedEdge[5, 395] -> 
             RGBColor[
              0.5968586468606165, 0.6828724552519535, 0.9619005753639707], 
             UndirectedEdge[104, 242] -> 
             RGBColor[
              0.9486223107500168, 0.8581914089875718, 0.5941049181072977], 
             UndirectedEdge[422, 437] -> 
             RGBColor[
              0.1942298621222053, 0.32147827834793574`, 0.9343724753593039], 
             UndirectedEdge[29, 177] -> 
             RGBColor[
              0.18440587372207073`, 0.31115264366255413`, 0.9338130137532046],
              UndirectedEdge[202, 285] -> 
             RGBColor[
              0.2005739783770007, 0.32814634677192855`, 0.9347337633947355], 
             UndirectedEdge[182, 460] -> 
             RGBColor[
              0.32283537188163536`, 0.453299157442765, 0.9418190897859463], 
             UndirectedEdge[116, 333] -> 
             RGBColor[
              0.2541335864563355, 0.3844408907385981, 0.937783903840514], 
             UndirectedEdge[405, 472] -> 
             RGBColor[
              0.1823975349558204, 0.3090417522831926, 0.9336986418315376], 
             UndirectedEdge[51, 96] -> 
             RGBColor[
              0.7330134148240908, 0.7867443631188805, 0.8380607137143137], 
             UndirectedEdge[115, 402] -> 
             RGBColor[
              0.20455792141877943`, 0.3323337235054161, 0.9349606430572492], 
             UndirectedEdge[67, 120] -> 
             RGBColor[
              0.18038821966444069`, 0.3069298345140049, 0.9335842142982091], 
             UndirectedEdge[72, 222] -> 
             RGBColor[
              0.20410917934136036`, 0.33186206713015765`, 0.9349350878597946],
              UndirectedEdge[84, 328] -> 
             RGBColor[
              0.2592509748717875, 0.3898195904244037, 0.9380753315402763], 
             UndirectedEdge[123, 401] -> 
             RGBColor[
              0.18328689846403934`, 0.309976529719234, 0.9337492897676354], 
             UndirectedEdge[143, 178] -> 
             RGBColor[
              0.5249805981564001, 0.6252419255466224, 0.9557475422356184], 
             UndirectedEdge[2, 385] -> 
             RGBColor[
              0.1828749868990639, 0.3095435845477431, 0.9337258320133786], 
             UndirectedEdge[113, 487] -> 
             RGBColor[
              0.19472843618281724`, 0.32200231129706014`, 0.9344008684144816],
              UndirectedEdge[12, 430] -> 
             RGBColor[
              0.19779577870573095`, 0.32522628276939103`, 0.9345755490334348],
              UndirectedEdge[72, 344] -> 
             RGBColor[
              0.20069596090134978`, 0.3282745581391582, 0.9347407101190403], 
             UndirectedEdge[127, 221] -> 
             RGBColor[
              0.8972130382069989, 0.8767030519388234, 0.6458996213784399], 
             UndirectedEdge[466, 491] -> 
             RGBColor[
              0.1882565372451065, 0.3151999351714332, 0.9340323033442953], 
             UndirectedEdge[236, 289] -> 
             RGBColor[
              0.20921618528861102`, 0.33722985418359713`, 0.9352259242933523],
              UndirectedEdge[200, 298] -> 
             RGBColor[
              0.26933197029652145`, 0.4004153557878257, 0.9386494293162186], 
             UndirectedEdge[231, 431] -> 
             RGBColor[
              0.5924549682477664, 0.6772918463903979, 0.9625703637800718], 
             UndirectedEdge[171, 238] -> 
             RGBColor[
              0.47869194757503297`, 0.5876627137247235, 0.9521035301009391], 
             UndirectedEdge[276, 306] -> 
             RGBColor[
              0.22718429673725105`, 0.3561154785601833, 0.9362491816589136], 
             UndirectedEdge[294, 296] -> 
             RGBColor[
              0.18486063733978264`, 0.311630629058448, 0.9338389118684709], 
             UndirectedEdge[1, 119] -> 
             RGBColor[
              0.1917982653600388, 0.3189225159787594, 0.9342339995209235], 
             UndirectedEdge[103, 444] -> 
             RGBColor[
              0.4878340995369397, 0.5939032200127712, 0.9531496870124296], 
             UndirectedEdge[331, 486] -> 
             RGBColor[
              0.35738466575242234`, 0.48329439102726157`, 0.9440179635868327],
              UndirectedEdge[100, 281] -> 
             RGBColor[
              0.9058254062967486, 0.5652706313368212, 0.33472136228145205`], 
             UndirectedEdge[161, 477] -> 
             RGBColor[
              0.2058221778675803, 0.33366253719159444`, 0.9350326405917087], 
             UndirectedEdge[391, 475] -> 
             RGBColor[
              0.40482166454825647`, 0.5245203840472975, 0.9471643768884919], 
             UndirectedEdge[2, 312] -> 
             RGBColor[
              0.18958168594798847`, 0.3165927504774426, 0.9341077686025426], 
             UndirectedEdge[264, 341] -> 
             RGBColor[
              0.9299206145630832, 0.7362794821686658, 0.415098303004048], 
             UndirectedEdge[73, 434] -> 
             RGBColor[
              0.755989141506491, 0.7238557905975457, 0.6132283330346036], 
             UndirectedEdge[241, 271] -> 
             RGBColor[
              0.2118628562397169, 0.3400116731618399, 0.935376648288619], 
             UndirectedEdge[49, 51] -> 
             RGBColor[
              0.9945887098983145, 0.9908341225748765, 0.6523926509220856], 
             UndirectedEdge[5, 275] -> 
             RGBColor[
              0.5894443177306294, 0.6768531688525092, 0.9613168922152756], 
             UndirectedEdge[18, 274] -> 
             RGBColor[
              0.2661988733080245, 0.397122272203093, 0.9384710040777253], 
             UndirectedEdge[219, 445] -> 
             RGBColor[
              0.8163225920234214, 0.8145058037505225, 0.6394598956191903], 
             UndirectedEdge[177, 297] -> 
             RGBColor[
              0.18982245259063335`, 0.3168458114843493, 0.9341214799066588], 
             UndirectedEdge[250, 365] -> 
             RGBColor[
              0.21334264494811753`, 0.3415670249183921, 0.9354609200664112], 
             UndirectedEdge[325, 474] -> 
             RGBColor[
              0.2315745275844326, 0.3607298895372839, 0.936499198810896], 
             UndirectedEdge[266, 403] -> 
             RGBColor[
              0.868496130673329, 0.8940798744623377, 0.7590138025565417], 
             UndirectedEdge[214, 470] -> 
             RGBColor[
              0.19107951696482092`, 0.31816706584410515`, 0.9341930678631087],
              UndirectedEdge[152, 481] -> 
             RGBColor[
              0.1947520962377352, 0.322027179514913, 0.9344022158196071], 
             UndirectedEdge[289, 466] -> 
             RGBColor[
              0.20247960652430902`, 0.3301492827785526, 0.9348422860986005], 
             UndirectedEdge[126, 269] -> 
             RGBColor[
              0.5451650588175359, 0.6416285800109227, 0.9573365369169786], 
             UndirectedEdge[183, 396] -> 
             RGBColor[
              0.19720162500749072`, 0.32460178956102026`, 0.9345417128592917],
              UndirectedEdge[54, 99] -> 
             RGBColor[
              0.9846117057177595, 0.9871579291878583, 0.8712517771624386], 
             UndirectedEdge[129, 306] -> 
             RGBColor[
              0.2650729238792713, 0.39593882796415625`, 0.9384068829234508], 
             UndirectedEdge[172, 236] -> 
             RGBColor[
              0.21592574989835334`, 0.34428203199940316`, 0.9356080240719657],
              UndirectedEdge[162, 284] -> 
             RGBColor[
              0.19507811925714236`, 0.3223698503793633, 0.9344207823482545], 
             UndirectedEdge[10, 189] -> 
             RGBColor[
              0.23937944149495205`, 0.3689333489173635, 0.9369436771117647], 
             UndirectedEdge[213, 332] -> 
             RGBColor[
              0.19442260484216423`, 0.3216808631672068, 0.9343834517720682], 
             UndirectedEdge[199, 245] -> 
             RGBColor[
              0.31502975887018714`, 0.4412915516820689, 0.9415138332017744], 
             UndirectedEdge[123, 139] -> 
             RGBColor[
              0.1842229343035432, 0.31096036273465255`, 0.9338025956239542], 
             UndirectedEdge[391, 482] -> 
             RGBColor[
              0.4027433630754207, 0.5227202637699965, 0.9470319493564127], 
             UndirectedEdge[184, 354] -> 
             RGBColor[
              0.425711621643709, 0.5407754370503493, 0.9490035262873733], 
             UndirectedEdge[25, 316] -> 
             RGBColor[
              0.36380395841468005`, 0.4876950626233916, 0.9444694464449066], 
             UndirectedEdge[106, 479] -> 
             RGBColor[
              0.18098277247116215`, 0.30755474721069437`, 0.9336180732009899],
              UndirectedEdge[118, 260] -> 
             RGBColor[
              0.20098092756456265`, 0.3285740761701249, 0.9347569385489398], 
             UndirectedEdge[304, 469] -> 
             RGBColor[
              0.18603078567582654`, 0.3128605291513198, 0.9339055500851292], 
             UndirectedEdge[93, 236] -> 
             RGBColor[
              0.21549489107563347`, 0.3438291720586974, 0.9355834872994104], 
             UndirectedEdge[343, 445] -> 
             RGBColor[
              0.9046747150389304, 0.6218037867421315, 0.25156389718325395`], 
             UndirectedEdge[204, 444] -> 
             RGBColor[
              0.44088363514258455`, 0.5532370875533353, 0.9501580449378868], 
             UndirectedEdge[150, 412] -> 
             RGBColor[
              0.20280807626052344`, 0.33049452529749807`, 0.9348609919641505],
              UndirectedEdge[14, 239] -> 
             RGBColor[
              0.21381228139776098`, 0.3420606426036381, 0.9354876651674535], 
             UndirectedEdge[70, 442] -> 
             RGBColor[
              0.3038237186466454, 0.4310287676162611, 0.9408201768359108], 
             UndirectedEdge[93, 493] -> 
             RGBColor[
              0.24176752917831046`, 0.3714433804860776, 0.9370796751724728], 
             UndirectedEdge[228, 279] -> 
             RGBColor[
              0.23309972747079383`, 0.36233297132110764`, 0.9365860566880932],
              UndirectedEdge[300, 456] -> 
             RGBColor[
              0.21373738250553675`, 0.34198191911904635`, 0.9354833997863443],
              UndirectedEdge[168, 326] -> 
             RGBColor[
              0.509047258388588, 0.6051914915809957, 0.9566219374301776], 
             UndirectedEdge[193, 437] -> 
             RGBColor[
              0.18142173090578886`, 0.3080161203570593, 0.933643071234461], 
             UndirectedEdge[224, 361] -> 
             RGBColor[
              0.21801752264150492`, 0.34648061777850747`, 0.9357271474351878],
              UndirectedEdge[12, 477] -> 
             RGBColor[
              0.19591456128829632`, 0.32324900398759393`, 0.9344684164845236],
              UndirectedEdge[212, 224] -> 
             RGBColor[
              0.19394001881557005`, 0.321173634655535, 0.9343559692117758], 
             UndirectedEdge[220, 490] -> 
             RGBColor[
              0.2165006286676464, 0.34488626603534933`, 0.9356407625674201], 
             UndirectedEdge[175, 208] -> 
             RGBColor[
              0.41214605726916764`, 0.531401932568564, 0.9474825602161108], 
             UndirectedEdge[242, 419] -> 
             RGBColor[
              0.8111996093173061, 0.8527074496896203, 0.9480377397097984], 
             UndirectedEdge[164, 205] -> 
             RGBColor[
              0.2767533263359414, 0.40754264705410376`, 0.9390967072865741], 
             UndirectedEdge[257, 322] -> 
             RGBColor[
              0.8919174314542486, 0.5238884841222806, 0.23925061583127932`], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.7309397602442707, 0.7862269209257184, 0.8874289178221101], 
             UndirectedEdge[26, 67] -> 
             RGBColor[
              0.1828839766938226, 0.30955303339202045`, 0.9337263439688908], 
             UndirectedEdge[366, 488] -> 
             RGBColor[
              0.1825427715517224, 0.30919440515401764`, 0.933706912840816], 
             UndirectedEdge[12, 243] -> 
             RGBColor[
              0.19530733769648173`, 0.3226107734923974, 0.9344338359992765], 
             UndirectedEdge[271, 307] -> 
             RGBColor[
              0.199934386249049, 0.3274740948929682, 0.9346973395692404], 
             UndirectedEdge[9, 352] -> 
             RGBColor[
              0.18859199395283752`, 0.3155525214404422, 0.9340514071075369], 
             UndirectedEdge[404, 431] -> 
             RGBColor[
              0.629039468523406, 0.7060080713241875, 0.9661806387521447], 
             UndirectedEdge[256, 287] -> 
             RGBColor[
              0.30785568445183253`, 0.44064627675886753`, 0.9408528157119771],
              UndirectedEdge[254, 412] -> 
             RGBColor[
              0.19134257547531666`, 0.31844355701750904`, 0.9342080486561213],
              UndirectedEdge[42, 380] -> 
             RGBColor[
              0.19400957405079025`, 0.3212467416178081, 0.9343599302795238], 
             UndirectedEdge[379, 404] -> 
             RGBColor[
              0.8321257348299118, 0.5422647939490768, 0.5790967778488565], 
             UndirectedEdge[134, 424] -> 
             RGBColor[
              0.18880157011833354`, 0.31577279927827495`, 0.9340633421601217],
              UndirectedEdge[38, 253] -> 
             RGBColor[
              0.4481561698945121, 0.5608135534661793, 0.9502685055394262], 
             UndirectedEdge[103, 348] -> 
             RGBColor[
              0.4359422690580296, 0.5517750943296691, 0.9490645720310915], 
             UndirectedEdge[42, 452] -> 
             RGBColor[
              0.21367924169687297`, 0.3419208094428005, 0.9354800887533026], 
             UndirectedEdge[164, 331] -> 
             RGBColor[
              0.3087300351184425, 0.44115219542494855`, 0.940917733546436], 
             UndirectedEdge[6, 181] -> 
             RGBColor[
              0.2199559451719783, 0.348518022761122, 0.9358375377306591], 
             UndirectedEdge[172, 197] -> 
             RGBColor[
              0.22719289983545946`, 0.3561245209618682, 0.9362496715926294], 
             UndirectedEdge[80, 258] -> 
             RGBColor[
              0.38129839578489, 0.5046832386394303, 0.9455169745038486], 
             UndirectedEdge[223, 268] -> 
             RGBColor[
              0.19724310055792588`, 0.32464538299422946`, 0.9345440748305314],
              UndirectedEdge[5, 69] -> 
             RGBColor[
              0.5662162318507189, 0.6577114998480007, 0.959566779515417], 
             UndirectedEdge[306, 486] -> 
             RGBColor[
              0.327052321983306, 0.4514131745442476, 0.942290581481863], 
             UndirectedEdge[5, 348] -> 
             RGBColor[
              0.575828354505173, 0.6657991165139304, 0.9602449937132509], 
             UndirectedEdge[279, 409] -> 
             RGBColor[
              0.23060819410886862`, 0.3597142117853851, 0.9364441675490249], 
             UndirectedEdge[463, 483] -> 
             RGBColor[
              0.5035999579863275, 0.6078494794543214, 0.954073961892099], 
             UndirectedEdge[351, 371] -> 
             RGBColor[
              0.2471362919389416, 0.37708629054672044`, 0.937385418269318], 
             UndirectedEdge[335, 421] -> 
             RGBColor[
              0.19735590244149465`, 0.3247639449259127, 0.9345504987309252], 
             UndirectedEdge[259, 418] -> 
             RGBColor[
              0.5798892585592409, 0.6691924959032061, 0.9604986680920036], 
             UndirectedEdge[168, 302] -> 
             RGBColor[
              0.268736668858344, 0.3997896562320101, 0.9386155277799839], 
             UndirectedEdge[87, 336] -> 
             RGBColor[
              0.4668814361724666, 0.5741090231571706, 0.9522620155496091], 
             UndirectedEdge[36, 266] -> 
             RGBColor[
              0.9938574384892986, 0.9902625241719002, 0.644943793687154], 
             UndirectedEdge[161, 430] -> 
             RGBColor[
              0.2077033952850149, 0.33563981597339154`, 0.9351397731406197], 
             UndirectedEdge[220, 412] -> 
             RGBColor[
              0.2036444979201258, 0.3313736574939363, 0.9349086249402898], 
             UndirectedEdge[372, 404] -> 
             RGBColor[
              0.7255490713882455, 0.7852295819730946, 0.9735376602371271], 
             UndirectedEdge[38, 287] -> 
             RGBColor[
              0.4114868433754372, 0.5286278492274263, 0.9479475143104742], 
             UndirectedEdge[171, 497] -> 
             RGBColor[
              0.47443851953832683`, 0.5842095892297761, 0.9517686846650694], 
             UndirectedEdge[246, 411] -> 
             RGBColor[
              0.2605541594338602, 0.3911893200258155, 0.9381495459731974], 
             UndirectedEdge[75, 303] -> 
             RGBColor[
              0.853058182050049, 0.3979604671775163, 0.19801610025913619`], 
             UndirectedEdge[23, 39] -> 
             RGBColor[
              0.3397705873831411, 0.4630597387061178, 0.9430778872171774], 
             UndirectedEdge[61, 391] -> 
             RGBColor[
              0.731686882991318, 0.7866873766200184, 0.8813805065527239], 
             UndirectedEdge[19, 200] -> 
             RGBColor[
              0.23309658772441674`, 0.3623296712485939, 0.936585877884182], 
             UndirectedEdge[208, 403] -> 
             RGBColor[
              0.5850117948684971, 0.6717049428230532, 0.961732098971587], 
             UndirectedEdge[108, 378] -> 
             RGBColor[
              0.20828889068141454`, 0.33625520875755976`, 0.9351731162372818],
              UndirectedEdge[10, 451] -> 
             RGBColor[
              0.2159367879573847, 0.34429363369929844`, 0.9356086526730982], 
             UndirectedEdge[199, 262] -> 
             RGBColor[
              0.36465083425503464`, 0.49026395757304103`, 0.944456206604027], 
             UndirectedEdge[3, 401] -> 
             RGBColor[
              0.18219297080333685`, 0.308826742388816, 0.9336869922056792], 
             UndirectedEdge[241, 311] -> 
             RGBColor[
              0.2028072709740812, 0.33049367889038916`, 0.934860946104279], 
             UndirectedEdge[179, 255] -> 
             RGBColor[
              0.19864123735537692`, 0.32611491341534343`, 0.9346236966527881],
              UndirectedEdge[276, 462] -> 
             RGBColor[
              0.20183278400452248`, 0.3294694312993405, 0.9348054505129868], 
             UndirectedEdge[167, 289] -> 
             RGBColor[
              0.2249680527429054, 0.35378606560414083`, 0.9361229698420748], 
             UndirectedEdge[164, 348] -> 
             RGBColor[
              0.38905288991990644`, 0.5111618708489473, 0.9460768222550604], 
             UndirectedEdge[18, 172] -> 
             RGBColor[
              0.2559027333199868, 0.38630037626268543`, 0.9378846541371808], 
             UndirectedEdge[289, 300] -> 
             RGBColor[
              0.2209681235766699, 0.34958188644027033`, 0.9358951797934225], 
             UndirectedEdge[59, 188] -> 
             RGBColor[
              0.24348630056862833`, 0.373249918193702, 0.937177556660457], 
             UndirectedEdge[352, 357] -> 
             RGBColor[
              0.185968194480225, 0.3127947418362315, 0.9339019856091351], 
             UndirectedEdge[161, 409] -> 
             RGBColor[
              0.23354210119449076`, 0.36279793415282724`, 0.9366112492172245],
              UndirectedEdge[39, 157] -> 
             RGBColor[
              0.2733433157427147, 0.4046315341857658, 0.9388778695051255], 
             UndirectedEdge[216, 398] -> 
             RGBColor[
              0.20308712437898663`, 0.33078782256267547`, 0.9348768833416823],
              UndirectedEdge[279, 396] -> 
             RGBColor[
              0.2027106095200159, 0.3303920815734764, 0.9348554413774677], 
             UndirectedEdge[103, 390] -> 
             RGBColor[
              0.3328589413831152, 0.4578427188183445, 0.9426093080634266], 
             UndirectedEdge[128, 296] -> 
             RGBColor[
              0.1882426629696768, 0.3151853524282767, 0.9340315132248347], 
             UndirectedEdge[362, 369] -> 
             RGBColor[
              0.1806318866536843, 0.30718594396907933`, 0.9335980907727736], 
             UndirectedEdge[86, 412] -> 
             RGBColor[
              0.18778375020070825`, 0.3147030060113407, 0.9340053788215426], 
             UndirectedEdge[261, 299] -> 
             RGBColor[
              0.2846830813812443, 0.4146506586338333, 0.9395932092741723], 
             UndirectedEdge[208, 266] -> 
             RGBColor[
              0.7100990368535118, 0.7663088762344812, 0.7456861929885767], 
             UndirectedEdge[211, 236] -> 
             RGBColor[
              0.1979212488225095, 0.32535815981739014`, 0.934582694370969], 
             UndirectedEdge[19, 124] -> 
             RGBColor[
              0.1942932572468809, 0.3215449106434528, 0.9343760856178694], 
             UndirectedEdge[319, 330] -> 
             RGBColor[
              0.18522178171588122`, 0.3120102146956035, 0.9338594785064245], 
             UndirectedEdge[137, 267] -> 
             RGBColor[
              0.22045636616771785`, 0.34904399695616795`, 0.93586603596606], 
             UndirectedEdge[23, 240] -> 
             RGBColor[
              0.7133780917330446, 0.7699270698367418, 0.8123932263629633], 
             UndirectedEdge[135, 369] -> 
             RGBColor[
              0.18101136995755066`, 0.307584804982074, 0.9336197017855334], 
             UndirectedEdge[13, 335] -> 
             RGBColor[
              0.23166019252299075`, 0.36081992881917935`, 0.936504077302417], 
             UndirectedEdge[176, 178] -> 
             RGBColor[
              0.3931214338805177, 0.5144895563820213, 0.9463902997884908], 
             UndirectedEdge[335, 459] -> 
             RGBColor[
              0.2024275249318897, 0.3300945417227562, 0.93483932012896], 
             UndirectedEdge[83, 326] -> 
             RGBColor[
              0.8603044472818449, 0.8888437109835485, 0.8510148449573589], 
             UndirectedEdge[33, 76] -> 
             RGBColor[
              0.3333497551271607, 0.45830089859572654`, 0.9426393717347399], 
             UndirectedEdge[13, 285] -> 
             RGBColor[
              0.2336665281569335, 0.36292871477947963`, 0.9366183351486626], 
             UndirectedEdge[225, 309] -> 
             RGBColor[
              0.18608052902366917`, 0.31291281256381276`, 0.9339083828952002],
              UndirectedEdge[242, 499] -> 
             RGBColor[
              0.8008428775112291, 0.844405505952868, 0.9471498665869478], 
             UndirectedEdge[13, 287] -> 
             RGBColor[
              0.2785495730651827, 0.41010364072745936`, 0.9391743581576726], 
             UndirectedEdge[265, 270] -> 
             RGBColor[
              0.18221828136351503`, 0.30885334539234544`, 0.9336884336046377],
              UndirectedEdge[191, 311] -> 
             RGBColor[
              0.19029060642002155`, 0.31733787084170345`, 0.934148140574671], 
             UndirectedEdge[47, 452] -> 
             RGBColor[
              0.2542089051352215, 0.3845200554455873, 0.9377881931278527], 
             UndirectedEdge[14, 80] -> 
             RGBColor[
              0.28919811932082623`, 0.417720629815705, 0.9399116866604884], 
             UndirectedEdge[152, 292] -> 
             RGBColor[
              0.18467767702367152`, 0.3114383261658612, 0.9338284925491338], 
             UndirectedEdge[133, 311] -> 
             RGBColor[
              0.19398258593487913`, 0.3212183753968402, 0.9343583933462479], 
             UndirectedEdge[187, 398] -> 
             RGBColor[
              0.21375269941056224`, 0.341998018157376, 0.9354842720614263], 
             UndirectedEdge[130, 442] -> 
             RGBColor[
              0.2704116943765009, 0.4015502142543449, 0.9387109180052648], 
             UndirectedEdge[304, 433] -> 
             RGBColor[
              0.1856912324704567, 0.31250363720355945`, 0.9338862130324074], 
             UndirectedEdge[354, 409] -> 
             RGBColor[
              0.28191067367276634`, 0.4134660896464276, 0.9393720026838029], 
             UndirectedEdge[29, 412] -> 
             RGBColor[
              0.18734250753660958`, 0.3142392319949723, 0.9339802507045822], 
             UndirectedEdge[295, 391] -> 
             RGBColor[
              0.7289553207863748, 0.7855578054503277, 0.9266495613450138], 
             UndirectedEdge[21, 298] -> 
             RGBColor[
              0.2878456584957702, 0.4198744159208656, 0.9397037564706185], 
             UndirectedEdge[383, 395] -> 
             RGBColor[
              0.3859577461997916, 0.503550871102866, 0.9463338532888385], 
             UndirectedEdge[133, 241] -> 
             RGBColor[
              0.2068052594645497, 0.3346958182809826, 0.9350886256343172], 
             UndirectedEdge[142, 473] -> 
             RGBColor[
              0.23965328121814944`, 0.36922117182888525`, 0.9369592718788913],
              UndirectedEdge[95, 330] -> 
             RGBColor[
              0.18713069149999506`, 0.314016599910578, 0.9339681880946508], 
             UndirectedEdge[275, 431] -> 
             RGBColor[
              0.4552821797756804, 0.5677869422920205, 0.9505011954058309], 
             UndirectedEdge[180, 474] -> 
             RGBColor[
              0.24632928568632426`, 0.37623807580806795`, 0.9373394604570903],
              UndirectedEdge[82, 173] -> 
             RGBColor[
              0.6203596764497656, 0.7014764485955354, 0.964075560146658], 
             UndirectedEdge[205, 230] -> 
             RGBColor[
              0.22168982682145016`, 0.35034044230916306`, 0.9359362797255486],
              UndirectedEdge[460, 463] -> 
             RGBColor[
              0.42791636353987605`, 0.5415498055841811, 0.9492787976467367], 
             UndirectedEdge[121, 500] -> 
             RGBColor[
              0.20306057228198376`, 0.33075991462522525`, 0.9348753712390383],
              UndirectedEdge[88, 241] -> 
             RGBColor[
              0.2025944621469051, 0.33027000332016815`, 0.9348488269563937], 
             UndirectedEdge[60, 73] -> 
             RGBColor[
              0.781195634641831, 0.8278300365608096, 0.9249593462199677], 
             UndirectedEdge[75, 400] -> 
             RGBColor[
              0.9275933480888754, 0.7357010879276322, 0.5134508624919265], 
             UndirectedEdge[141, 274] -> 
             RGBColor[
              0.2256966978230941, 0.35455191778218553`, 0.9361644651014577], 
             UndirectedEdge[299, 448] -> 
             RGBColor[
              0.2703287280609633, 0.40146301139634666`, 0.9387061931963326], 
             UndirectedEdge[160, 389] -> 
             RGBColor[
              0.21718512492406264`, 0.34560571500041215`, 0.9356797436166016],
              UndirectedEdge[24, 268] -> 
             RGBColor[
              0.18579615740306293`, 0.3126139199603535, 0.9338921883520968], 
             UndirectedEdge[386, 498] -> 
             RGBColor[
              0.540094387984412, 0.6311849610997022, 0.9594410817544053], 
             UndirectedEdge[350, 476] -> 
             RGBColor[
              0.18247717121909524`, 0.3091254550451252, 0.9337031769989198], 
             UndirectedEdge[180, 331] -> 
             RGBColor[
              0.2822898900471109, 0.4140349510252597, 0.9393873636764902], 
             UndirectedEdge[225, 252] -> 
             RGBColor[
              0.18313599846224066`, 0.30981792424973087`, 0.9337406962357694],
              UndirectedEdge[100, 203] -> 
             RGBColor[
              0.9191489665110915, 0.667681353565574, 0.3474800185895157], 
             UndirectedEdge[445, 471] -> 
             RGBColor[
              0.9599777422905198, 0.9272913458979556, 0.6345862231732597], 
             UndirectedEdge[373, 498] -> 
             RGBColor[
              0.8827929559209364, 0.907189051483757, 0.8884954173694475], 
             UndirectedEdge[102, 309] -> 
             RGBColor[
              0.19381918087775277`, 0.3210466263213213, 0.9343490876699807], 
             UndirectedEdge[46, 86] -> 
             RGBColor[
              0.19451109914847642`, 0.321773876294004, 0.9343884913918972], 
             UndirectedEdge[294, 385] -> 
             RGBColor[
              0.18452375420061845`, 0.3112765435195617, 0.9338197268720694], 
             UndirectedEdge[27, 29] -> 
             RGBColor[
              0.18482045324878804`, 0.31158839303099417`, 0.9338366234439357],
              UndirectedEdge[274, 284] -> 
             RGBColor[
              0.22545727776759072`, 0.3543002721237432, 0.936150830483487], 
             UndirectedEdge[284, 300] -> 
             RGBColor[
              0.2193467291603231, 0.3478776981063463, 0.9358028437800496], 
             UndirectedEdge[159, 453] -> 
             RGBColor[
              0.23602331412857852`, 0.36540584626453976`, 0.9367525506231953],
              UndirectedEdge[229, 232] -> 
             RGBColor[
              0.2566501782178637, 0.3870859882410977, 0.9379272200183691], 
             UndirectedEdge[259, 431] -> 
             RGBColor[
              0.552262608455937, 0.6458932694477724, 0.9585643649749793], 
             UndirectedEdge[112, 483] -> 
             RGBColor[
              0.7227411345359493, 0.7787563213495963, 0.8541899154691762], 
             UndirectedEdge[78, 376] -> 
             RGBColor[
              0.4205848118936931, 0.5382565536141679, 0.9481458786566228], 
             UndirectedEdge[76, 351] -> 
             RGBColor[
              0.32530926006899097`, 0.449849828492759, 0.9421814774360235], 
             UndirectedEdge[178, 498] -> 
             RGBColor[
              0.6219478547908555, 0.7019387588473889, 0.96476604218581], 
             UndirectedEdge[400, 431] -> 
             RGBColor[
              0.7055601740591597, 0.7646836770228431, 0.882816923995621], 
             UndirectedEdge[18, 432] -> 
             RGBColor[
              0.2897732046951418, 0.4219003891898929, 0.9398135273751238], 
             UndirectedEdge[220, 325] -> 
             RGBColor[
              0.22533443478540557`, 0.3541711563607717, 0.9361438347573814], 
             UndirectedEdge[353, 380] -> 
             RGBColor[
              0.18408835379335264`, 0.31081891008554513`, 0.9337949314629927],
              UndirectedEdge[5, 355] -> 
             RGBColor[
              0.624643054436057, 0.7054290889949936, 0.9640878657059478], 
             UndirectedEdge[367, 441] -> 
             RGBColor[
              0.20930859557874099`, 0.3373269832576745, 0.9352311869226664], 
             UndirectedEdge[21, 287] -> 
             RGBColor[
              0.30207832712053356`, 0.43483385304880307`, 0.9405142858934524],
              UndirectedEdge[175, 182] -> 
             RGBColor[
              0.3713372775098073, 0.4960554186499155, 0.9448822608556314], 
             UndirectedEdge[70, 371] -> 
             RGBColor[
              0.31191266997486483`, 0.4395307683313558, 0.9412808306475218], 
             UndirectedEdge[217, 496] -> 
             RGBColor[
              0.1835288398725976, 0.31023082547960007`, 0.9337630679729325], 
             UndirectedEdge[195, 292] -> 
             RGBColor[
              0.18660739700750423`, 0.31346658422018303`, 0.9339383872474483],
              UndirectedEdge[161, 285] -> 
             RGBColor[
              0.21411916928885952`, 0.34238320123499877`, 0.9355051419788516],
              UndirectedEdge[168, 370] -> 
             RGBColor[
              0.2607361826498604, 0.3913806379667703, 0.9381599119260695], 
             UndirectedEdge[50, 173] -> 
             RGBColor[
              0.800480264278042, 0.8445485570290475, 0.9806185434355512], 
             UndirectedEdge[19, 188] -> 
             RGBColor[
              0.21359720872912316`, 0.3418345875925049, 0.9354754170971461], 
             UndirectedEdge[147, 323] -> 
             RGBColor[
              0.905895222039182, 0.5694593928427707, 0.46819019532102185`], 
             UndirectedEdge[255, 260] -> 
             RGBColor[
              0.2034606107913817, 0.33118038046250897`, 0.9348981528403446], 
             UndirectedEdge[29, 350] -> 
             RGBColor[
              0.18297683433485876`, 0.309650632660264, 0.9337316320741772], 
             UndirectedEdge[348, 400] -> 
             RGBColor[
              0.7259744000228323, 0.7821275326457193, 0.8841834386643934], 
             UndirectedEdge[26, 124] -> 
             RGBColor[
              0.18513200243707828`, 0.31191585098124663`, 0.9338543657093131],
              UndirectedEdge[18, 93] -> 
             RGBColor[
              0.25547187449726694`, 0.38584751632197967`, 0.9378601173646254],
              UndirectedEdge[64, 223] -> 
             RGBColor[
              0.19649530119615788`, 0.32385939845179323`, 0.9345014887631486],
              UndirectedEdge[12, 335] -> 
             RGBColor[
              0.20220521707563277`, 0.32986088207069797`, 0.9348266600254211],
              UndirectedEdge[143, 498] -> 
             RGBColor[
              0.6776190672953443, 0.7471351571180758, 0.9691486839645342], 
             UndirectedEdge[44, 92] -> 
             RGBColor[
              0.2754748024457604, 0.40687186185472934`, 0.938999254519612], 
             UndirectedEdge[274, 389] -> 
             RGBColor[
              0.2195028960405469, 0.34804183939901356`, 0.9358117372528503], 
             UndirectedEdge[247, 401] -> 
             RGBColor[
              0.1825033131056717, 0.3091529318254084, 0.9337046657406869], 
             UndirectedEdge[111, 182] -> 
             RGBColor[
              0.35579432343932743`, 0.4825928930456521, 0.9438918775663551], 
             UndirectedEdge[157, 190] -> 
             RGBColor[
              0.2578198120642154, 0.3883153475726824, 0.9379938289356007], 
             UndirectedEdge[100, 360] -> 
             RGBColor[
              0.7946952326726424, 0.8354763984444047, 0.7327589869340729], 
             UndirectedEdge[59, 468] -> 
             RGBColor[
              0.24224871187808175`, 0.37194913401228247`, 0.9371070778153788],
              UndirectedEdge[101, 129] -> 
             RGBColor[
              0.2672434934849943, 0.39822023424183295`, 0.9385304936514267], 
             UndirectedEdge[180, 382] -> 
             RGBColor[
              0.23760741054514092`, 0.36707083203586066`, 0.9368427625706579],
              UndirectedEdge[145, 402] -> 
             RGBColor[
              0.21358684811844986`, 0.34182369793378664`, 0.9354748270756954],
              UndirectedEdge[90, 263] -> 
             RGBColor[
              0.24334458110817345`, 0.37310096205523113`, 0.9371694859468394],
              UndirectedEdge[98, 276] -> 
             RGBColor[
              0.20095020339638087`, 0.3285417831213411, 0.9347551888530141], 
             UndirectedEdge[224, 464] -> 
             RGBColor[
              0.20419415303821636`, 0.3319513798731969, 0.9349399269861233], 
             UndirectedEdge[261, 313] -> 
             RGBColor[
              0.3452565934007724, 0.4734656409279675, 0.9432204227264471], 
             UndirectedEdge[78, 219] -> 
             RGBColor[
              0.5697935423105139, 0.6612069230140997, 0.9595599186442647], 
             UndirectedEdge[393, 424] -> 
             RGBColor[
              0.20739385044843295`, 0.3353144647238677, 0.935122145020107], 
             UndirectedEdge[169, 211] -> 
             RGBColor[
              0.1856477523702797, 0.3124579368614757, 0.9338837369050252], 
             UndirectedEdge[176, 482] -> 
             RGBColor[
              0.3246527382525704, 0.45561961717846555`, 0.9419075632956775], 
             UndirectedEdge[35, 94] -> 
             RGBColor[
              0.18328807136271902`, 0.3099777625101124, 0.9337493565624799], 
             UndirectedEdge[114, 296] -> 
             RGBColor[
              0.18183178255671295`, 0.30844711064095676`, 0.9336664230693641],
              UndirectedEdge[130, 175] -> 
             RGBColor[
              0.350298253723786, 0.4772937364222603, 0.943561398674819], 
             UndirectedEdge[189, 383] -> 
             RGBColor[
              0.25987325139717643`, 0.39047364250719796`, 0.9381107692678216],
              UndirectedEdge[139, 437] -> 
             RGBColor[
              0.18225949462972918`, 0.3088966631482086, 0.9336907806391791], 
             UndirectedEdge[56, 324] -> 
             RGBColor[
              0.6732900844799101, 0.7406929401963493, 0.9670229089652596], 
             UndirectedEdge[398, 399] -> 
             RGBColor[
              0.2070690587330349, 0.3349730880380002, 0.9351036486124014], 
             UndirectedEdge[405, 429] -> 
             RGBColor[
              0.1868041703990252, 0.3136734055308251, 0.9339495932009951], 
             UndirectedEdge[12, 318] -> 
             RGBColor[
              0.19600810188078815`, 0.32334732108111897`, 0.9344737434828851],
              UndirectedEdge[11, 205] -> 
             RGBColor[
              0.3065274858845748, 0.4333315275623586, 0.9409938904047574], 
             UndirectedEdge[226, 389] -> 
             RGBColor[
              0.19095055240575043`, 0.3180315159156967, 0.9341857235222557], 
             UndirectedEdge[294, 327] -> 
             RGBColor[
              0.18563559838764718`, 0.312445162255122, 0.9338830447536945], 
             UndirectedEdge[167, 218] -> 
             RGBColor[
              0.26286988224919927`, 0.3936232915300437, 0.9382814229617262], 
             UndirectedEdge[217, 481] -> 
             RGBColor[
              0.19325559530187433`, 0.3204542621476837, 0.9343169923051846], 
             UndirectedEdge[247, 309] -> 
             RGBColor[
              0.18623761794577917`, 0.3130779229809633, 0.933917328876922], 
             UndirectedEdge[79, 234] -> 
             RGBColor[
              0.9063126289426009, 0.8289774045041336, 0.6243163382349994], 
             UndirectedEdge[331, 372] -> 
             RGBColor[
              0.4578529646135995, 0.56594472517835, 0.9516272296801642], 
             UndirectedEdge[27, 484] -> 
             RGBColor[
              0.1850117059565009, 0.3117894117529224, 0.933847515002707], 
             UndirectedEdge[103, 326] -> 
             RGBColor[
              0.56759306260054, 0.6573833324020449, 0.9602981460928508], 
             UndirectedEdge[155, 394] -> 
             RGBColor[
              0.1886886358497215, 0.3156540982015175, 0.9340569107205956], 
             UndirectedEdge[433, 469] -> 
             RGBColor[
              0.18101298547639227`, 0.3075865029948064, 0.9336197937869416], 
             UndirectedEdge[65, 412] -> 
             RGBColor[
              0.1867174620390582, 0.3135822695468723, 0.9339446552881686], 
             UndirectedEdge[13, 161] -> 
             RGBColor[
              0.23339794827523738`, 0.36264642029486893`, 0.9366030399217282],
              UndirectedEdge[229, 480] -> 
             RGBColor[
              0.23910094988203007`, 0.36864063657479446`, 0.9369278174264002],
              UndirectedEdge[32, 448] -> 
             RGBColor[
              0.26012823284654724`, 0.3907416441772443, 0.938125290084152], 
             UndirectedEdge[251, 453] -> 
             RGBColor[
              0.23943021557072935`, 0.3689867156902678, 0.9369465686202667], 
             UndirectedEdge[282, 310] -> 
             RGBColor[
              0.6707630336058359, 0.74272444693153, 0.9678190486190441], 
             UndirectedEdge[392, 473] -> 
             RGBColor[
              0.2502222365996353, 0.3803298140453018, 0.9375611582524985], 
             UndirectedEdge[222, 344] -> 
             RGBColor[
              0.1936890488951341, 0.3209098493567448, 0.9343416768460837], 
             UndirectedEdge[266, 440] -> 
             RGBColor[
              0.9426079391450114, 0.7947470752330569, 0.3871278708766489], 
             UndirectedEdge[16, 361] -> 
             RGBColor[
              0.2501087241581385, 0.3802105052721842, 0.9375546938868818], 
             UndirectedEdge[412, 426] -> 
             RGBColor[
              0.18880630124033773`, 0.3157777719874718, 0.9340636115905208], 
             UndirectedEdge[274, 460] -> 
             RGBColor[
              0.27237898950751444`, 0.4036179661707557, 0.9388229525526237], 
             UndirectedEdge[180, 230] -> 
             RGBColor[
              0.2345216927400936, 0.3638275469769471, 0.9366670355065708], 
             UndirectedEdge[375, 450] -> 
             RGBColor[
              0.20913463295766446`, 0.3371441375130559, 0.9352212800087508], 
             UndirectedEdge[6, 123] -> 
             RGBColor[
              0.20012045196386746`, 0.3276696617564901, 0.9347079357364398], 
             UndirectedEdge[170, 466] -> 
             RGBColor[
              0.19131064180456064`, 0.3184099927048328, 0.9342062300808134], 
             UndirectedEdge[267, 280] -> 
             RGBColor[
              0.24136535807007609`, 0.3710206731522022, 0.9370567721228178], 
             UndirectedEdge[52, 214] -> 
             RGBColor[
              0.18377002501748835`, 0.3104843263589016, 0.9337768031101326], 
             UndirectedEdge[358, 386] -> 
             RGBColor[
              0.2652427547751048, 0.39611733100357804`, 0.9384165545417262], 
             UndirectedEdge[230, 413] -> 
             RGBColor[
              0.21810416040748024`, 0.34657167956369916`, 0.9357320813277911],
              UndirectedEdge[53, 207] -> 
             RGBColor[
              0.8538308363641018, 0.3886921926180247, 0.19816051774968563`], 
             UndirectedEdge[188, 256] -> 
             RGBColor[
              0.26776710539076976`, 0.3985106384029728, 0.9385698304401877], 
             UndirectedEdge[38, 87] -> 
             RGBColor[
              0.4136160612646935, 0.5308657922292461, 0.9480687701193717], 
             UndirectedEdge[22, 52] -> 
             RGBColor[
              0.18089659272171946`, 0.3074641668299184, 0.9336131653917505], 
             UndirectedEdge[160, 460] -> 
             RGBColor[
              0.27006121839103014`, 0.4011818417721542, 0.938690958916375], 
             UndirectedEdge[63, 159] -> 
             RGBColor[
              0.2194636807819041, 0.34800062167578893`, 0.9358095040018843], 
             UndirectedEdge[285, 430] -> 
             RGBColor[
              0.20797197516671106`, 0.33592211045800224`, 0.935155068367554], 
             UndirectedEdge[132, 356] -> 
             RGBColor[
              0.2588153820462965, 0.38936175474663237`, 0.9380505251732665], 
             UndirectedEdge[99, 373] -> 
             RGBColor[
              0.9853487541189616, 0.9874627176430353, 0.859036977734402], 
             UndirectedEdge[243, 396] -> 
             RGBColor[
              0.19700888147424034`, 0.32439920388692833`, 0.9345307364002116],
              UndirectedEdge[118, 292] -> 
             RGBColor[
              0.188665488336347, 0.3156297686973238, 0.9340555925039526], 
             UndirectedEdge[84, 176] -> 
             RGBColor[
              0.29622447069818203`, 0.4279240901305121, 0.9402086344933376], 
             UndirectedEdge[334, 385] -> 
             RGBColor[
              0.18420532827080235`, 0.310941857677955, 0.9338015929864353], 
             UndirectedEdge[25, 325] -> 
             RGBColor[
              0.26126519476067855`, 0.3919366632365452, 0.9381900383831774], 
             UndirectedEdge[321, 397] -> 
             RGBColor[
              0.9037224589823456, 0.5792136748312032, 0.5298753084241274], 
             UndirectedEdge[201, 235] -> 
             RGBColor[
              0.23728480229023638`, 0.36673175030541116`, 0.9368243905077971],
              UndirectedEdge[321, 498] -> 
             RGBColor[
              0.8800107385388454, 0.9060385330965369, 0.934603959538476], 
             UndirectedEdge[368, 492] -> 
             RGBColor[
              0.18092029968887635`, 0.3074890843555088, 0.9336145154684589], 
             UndirectedEdge[239, 387] -> 
             RGBColor[
              0.1927675658632359, 0.3199413122648211, 0.934289199750629], 
             UndirectedEdge[196, 500] -> 
             RGBColor[
              0.1964924261713618, 0.32385637661844546`, 0.9345013250347398], 
             UndirectedEdge[122, 185] -> 
             RGBColor[
              0.19860974920189184`, 0.3260818173695664, 0.9346219034490297], 
             UndirectedEdge[350, 377] -> 
             RGBColor[
              0.181157971499196, 0.3077388924974179, 0.9336280505264527], 
             UndirectedEdge[315, 353] -> 
             RGBColor[
              0.18205882341933505`, 0.3086857449827948, 0.9336793527106135], 
             UndirectedEdge[102, 480] -> 
             RGBColor[
              0.2214017905721769, 0.3500376979486238, 0.9359198764872638], 
             UndirectedEdge[127, 253] -> 
             RGBColor[
              0.604821677598294, 0.6851926412626169, 0.9645634759762418], 
             UndirectedEdge[159, 192] -> 
             RGBColor[
              0.27255273720121065`, 0.4034082682269394, 0.9388472119027095], 
             UndirectedEdge[201, 289] -> 
             RGBColor[
              0.23376233339509425`, 0.3630294121591895, 0.9366237911152446], 
             UndirectedEdge[29, 194] -> 
             RGBColor[
              0.18526819594198288`, 0.31205899899006834`, 0.9338621217279373],
              UndirectedEdge[79, 388] -> 
             RGBColor[
              0.6074674522288179, 0.6856239979057058, 0.9655884516290124], 
             UndirectedEdge[246, 402] -> 
             RGBColor[
              0.22901412567720097`, 0.3580387447939263, 0.9363533877100543], 
             UndirectedEdge[185, 398] -> 
             RGBColor[
              0.20890004242653637`, 0.3368975679909415, 0.9352079204250486], 
             UndirectedEdge[133, 304] -> 
             RGBColor[
              0.19434480354761932`, 0.3215990890737532, 0.9343790211034406], 
             UndirectedEdge[107, 314] -> 
             RGBColor[
              0.2370472271918243, 0.36648204381384886`, 0.9368108609574035], 
             UndirectedEdge[13, 279] -> 
             RGBColor[
              0.23046404118961528`, 0.35956269792742684`, 0.9364359582535287],
              UndirectedEdge[180, 418] -> 
             RGBColor[
              0.3698251689882062, 0.48989999728181594`, 0.9451142408333664], 
             UndirectedEdge[112, 207] -> 
             RGBColor[
              0.9342142442860358, 0.7583914671293646, 0.48787682484366524`], 
             UndirectedEdge[308, 369] -> 
             RGBColor[
              0.18646563701697516`, 0.31331758548203437`, 0.9339303142257027],
              UndirectedEdge[45, 292] -> 
             RGBColor[
              0.193148625604734, 0.3203418302137187, 0.93431090053918], 
             UndirectedEdge[348, 418] -> 
             RGBColor[
              0.4692928666535278, 0.5800321164088754, 0.9513636000208304], 
             UndirectedEdge[51, 264] -> 
             RGBColor[
              0.930398195461806, 0.7373009794201983, 0.46708003654237346`], 
             UndirectedEdge[201, 218] -> 
             RGBColor[
              0.27166416290138806`, 0.4028666380850924, 0.938782244234896], 
             UndirectedEdge[262, 376] -> 
             RGBColor[
              0.3571381356790589, 0.48375683566574046`, 0.9439775040939842], 
             UndirectedEdge[304, 307] -> 
             RGBColor[
              0.19124101859615344`, 0.3183368142984305, 0.9342022651420929], 
             UndirectedEdge[8, 166] -> 
             RGBColor[
              0.19658418244763454`, 0.3239528182824921, 0.9345065504189323], 
             UndirectedEdge[66, 312] -> 
             RGBColor[
              0.19642559622123856`, 0.32378613410360235`, 0.9344975191679463],
              UndirectedEdge[202, 430] -> 
             RGBColor[
              0.19415820437315612`, 0.32140296151032133`, 0.9343683945565036],
              UndirectedEdge[348, 404] -> 
             RGBColor[
              0.6494536944870786, 0.7234519269470636, 0.967547153420917], 
             UndirectedEdge[1, 113] -> 
             RGBColor[
              0.1979971628023344, 0.3254379502234105, 0.9345870175598152], 
             UndirectedEdge[29, 377] -> 
             RGBColor[
              0.18261049498864607`, 0.3092655867801383, 0.9337107695903608], 
             UndirectedEdge[259, 404] -> 
             RGBColor[
              0.7600500863927916, 0.8126123064413943, 0.97668222149209], 
             UndirectedEdge[131, 449] -> 
             RGBColor[
              0.9086679607710296, 0.6083135329493521, 0.2853739255705805], 
             UndirectedEdge[423, 465] -> 
             RGBColor[
              0.1791246132879326, 0.3056017040950233, 0.9335122537844052], 
             UndirectedEdge[177, 412] -> 
             RGBColor[
              0.1873190234343715, 0.314214548714542, 0.9339789133197014], 
             UndirectedEdge[139, 158] -> 
             RGBColor[
              0.18715334052902155`, 0.3140404054761162, 0.9339694779233476], 
             UndirectedEdge[454, 500] -> 
             RGBColor[
              0.206190516482255, 0.33404968442963456`, 0.9350536169309063], 
             UndirectedEdge[430, 459] -> 
             RGBColor[
              0.19801808656198788`, 0.32545994242144927`, 0.9345882091369736],
              UndirectedEdge[474, 490] -> 
             RGBColor[
              0.22274072146667342`, 0.35144499921186156`, 0.9359961266209347],
              UndirectedEdge[443, 451] -> 
             RGBColor[
              0.24646170398602968`, 0.37637725583686343`, 0.9373470014833631],
              UndirectedEdge[182, 483] -> 
             RGBColor[
              0.3985189663280868, 0.5195988313129054, 0.9466142540313085], 
             UndirectedEdge[92, 457] -> 
             RGBColor[
              0.37059515571215895`, 0.49157695819153635`, 0.9450791109885306],
              UndirectedEdge[38, 184] -> 
             RGBColor[
              0.5298276783437619, 0.6291770036011967, 0.9561291221434074], 
             UndirectedEdge[51, 457] -> 
             RGBColor[
              0.7322518449471631, 0.7861260863844587, 0.8380007601438797], 
             UndirectedEdge[321, 455] -> 
             RGBColor[
              0.7992398811281014, 0.8424906663250493, 0.9268604994645402], 
             UndirectedEdge[251, 435] -> 
             RGBColor[
              0.2386642748374078, 0.3681816634160995, 0.9369029494286119], 
             UndirectedEdge[16, 441] -> 
             RGBColor[
              0.2457921380966431, 0.37567349963418883`, 0.9373088706964965], 
             UndirectedEdge[302, 390] -> 
             RGBColor[
              0.25033731885124844`, 0.38045077278838335`, 0.9375677120164789],
              UndirectedEdge[186, 455] -> 
             RGBColor[
              0.8031839177998501, 0.842431819201664, 0.7386664277516752], 
             UndirectedEdge[349, 353] -> 
             RGBColor[
              0.18295144203234145`, 0.3096239437403533, 0.9337301860201135], 
             UndirectedEdge[125, 406] -> 
             RGBColor[
              0.5972259557238873, 0.6808172474310844, 0.9631312731906503], 
             UndirectedEdge[307, 433] -> 
             RGBColor[
              0.18622321839671918`, 0.3130627881419171, 0.9339165088439054], 
             UndirectedEdge[406, 419] -> 
             RGBColor[
              0.5328942370686292, 0.630560819878426, 0.9567192886891854], 
             UndirectedEdge[237, 274] -> 
             RGBColor[
              0.23848727143504053`, 0.36799562161754756`, 0.9368928693467], 
             UndirectedEdge[203, 264] -> 
             RGBColor[
              0.8553074725725389, 0.4148947299646385, 0.20015613150748274`], 
             UndirectedEdge[69, 231] -> 
             RGBColor[
              0.6032570715569849, 0.6866480853473442, 0.9632586642510103], 
             UndirectedEdge[328, 399] -> 
             RGBColor[
              0.22543273121464985`, 0.354274472140261, 0.9361494325936104], 
             UndirectedEdge[78, 262] -> 
             RGBColor[
              0.4066140424697561, 0.526155775330442, 0.9472556735827959], 
             UndirectedEdge[27, 412] -> 
             RGBColor[
              0.18773360296108882`, 0.31465029808298206`, 0.9340025230104325],
              UndirectedEdge[147, 221] -> 
             RGBColor[
              0.8906777697244648, 0.5160364512426465, 0.23692570222520362`], 
             UndirectedEdge[93, 289] -> 
             RGBColor[
              0.21635167337317993`, 0.34472970457655394`, 0.93563227978376], 
             UndirectedEdge[141, 235] -> 
             RGBColor[
              0.21221346212045616`, 0.34038018217219357`, 0.9353966147748521],
              UndirectedEdge[185, 464] -> 
             RGBColor[
              0.2069974759051772, 0.3348978499473083, 0.9350995720762522], 
             UndirectedEdge[6, 189] -> 
             RGBColor[
              0.23318323402672853`, 0.3624207420060165, 0.9365908122629168], 
             UndirectedEdge[38, 316] -> 
             RGBColor[
              0.4787664530256467, 0.5873266421968035, 0.9522189657129314], 
             UndirectedEdge[322, 343] -> 
             RGBColor[
              0.8335064289062653, 0.2585506719501317, 0.17971910020172568`], 
             UndirectedEdge[93, 141] -> 
             RGBColor[
              0.21496969901233648`, 0.34327716190107216`, 0.9355535783883577],
              UndirectedEdge[191, 237] -> 
             RGBColor[
              0.21174339074199797`, 0.3398861073491872, 0.9353698449052572], 
             UndirectedEdge[145, 461] -> 
             RGBColor[
              0.23115805437216275`, 0.3602921497852615, 0.9364754812775742], 
             UndirectedEdge[420, 500] -> 
             RGBColor[
              0.19451665335716928`, 0.32177971411949735`, 0.9343888076958655],
              UndirectedEdge[402, 458] -> 
             RGBColor[
              0.2285757051250969, 0.3575779369961964, 0.9363284203081972], 
             UndirectedEdge[148, 263] -> 
             RGBColor[
              0.24948680213618696`, 0.3795568257949794, 0.9375192763477829], 
             UndirectedEdge[126, 499] -> 
             RGBColor[
              0.5585145617417738, 0.6524663078730726, 0.9583874586880152], 
             UndirectedEdge[133, 371] -> 
             RGBColor[
              0.22603138593843586`, 0.35490369621186185`, 0.9361835250944996],
              UndirectedEdge[72, 245] -> 
             RGBColor[
              0.22752065341650146`, 0.35646901075632065`, 0.9362683366742017],
              UndirectedEdge[57, 131] -> 
             RGBColor[
              0.8981850447320697, 0.6159608551699692, 0.564028013817431], 
             UndirectedEdge[15, 173] -> 
             RGBColor[
              0.6865018666299831, 0.7550197429095551, 0.9693877484071343], 
             UndirectedEdge[138, 415] -> 
             RGBColor[
              0.18158458466446153`, 0.308187289982949, 0.9336523455150969], 
             UndirectedEdge[105, 109] -> 
             RGBColor[
              0.2025306105640042, 0.3302028912581151, 0.9348451907032074], 
             UndirectedEdge[235, 284] -> 
             RGBColor[
              0.2119740420649528, 0.3401285365137513, 0.9353829801568815], 
             UndirectedEdge[150, 473] -> 
             RGBColor[
              0.23947719025137565`, 0.36903608905799384`, 0.9369492437588367],
              UndirectedEdge[74, 417] -> 
             RGBColor[
              0.1929190076012242, 0.3201004871334076, 0.9342978241335694], 
             UndirectedEdge[20, 413] -> 
             RGBColor[
              0.23603377197510877`, 0.36541683812430875`, 0.9367531461820842],
              UndirectedEdge[34, 467] -> 
             RGBColor[
              0.20003782336254744`, 0.32758281385754684`, 0.9347032301598326],
              UndirectedEdge[62, 110] -> 
             RGBColor[
              0.33413455286534527`, 0.45851113631971724`, 0.9427065695832899],
              UndirectedEdge[93, 389] -> 
             RGBColor[
              0.20877589722978934`, 0.3367670835179003, 0.9352008505397502], 
             UndirectedEdge[28, 408] -> 
             RGBColor[
              0.7065627960875993, 0.7690478747515729, 0.9714624707191005], 
             UndirectedEdge[93, 284] -> 
             RGBColor[
              0.21473027895683314`, 0.3430255162426299, 0.9355399437703871], 
             UndirectedEdge[143, 313] -> 
             RGBColor[
              0.4709361194251123, 0.5788655180367319, 0.9521839040886261], 
             UndirectedEdge[361, 398] -> 
             RGBColor[
              0.21817994857503456`, 0.3466513377330461, 0.9357363973518147], 
             UndirectedEdge[105, 382] -> 
             RGBColor[
              0.2017475218904906, 0.3293798154115627, 0.9348005949617267], 
             UndirectedEdge[240, 495] -> 
             RGBColor[
              0.9404490296531263, 0.7834756918464549, 0.4513533807985771], 
             UndirectedEdge[13, 21] -> 
             RGBColor[
              0.27647406119866225`, 0.4079221461606935, 0.9390561608273189], 
             UndirectedEdge[32, 179] -> 
             RGBColor[
              0.20989223640499494`, 0.3379404267710331, 0.9352644244043025], 
             UndirectedEdge[38, 79] -> 
             RGBColor[
              0.7025334025034438, 0.7661868171424233, 0.9721373827063131], 
             UndirectedEdge[328, 407] -> 
             RGBColor[
              0.26005803844889097`, 0.3906678654147257, 0.9381212926170488], 
             UndirectedEdge[357, 367] -> 
             RGBColor[
              0.19284697546686017`, 0.3200247767930899, 0.9342937220100794], 
             UndirectedEdge[196, 213] -> 
             RGBColor[
              0.19710682911621347`, 0.3245021530688812, 0.9345363143735214], 
             UndirectedEdge[233, 326] -> 
             RGBColor[
              0.8439697158415906, 0.8784945870094583, 0.9607638453803016], 
             UndirectedEdge[164, 372] -> 
             RGBColor[
              0.4651482668210734, 0.5729395258749782, 0.9520673290712703], 
             UndirectedEdge[3, 278] -> 
             RGBColor[
              0.1840613533248448, 0.3107905308812148, 0.9337933938262548], 
             UndirectedEdge[195, 399] -> 
             RGBColor[
              0.19798691924192627`, 0.3254271835919423, 0.9345864342042041], 
             UndirectedEdge[118, 187] -> 
             RGBColor[
              0.20672865124829637`, 0.33461529818845887`, 0.9350842629097332],
              UndirectedEdge[61, 178] -> 
             RGBColor[
              0.7297842099398613, 0.7851427009224017, 0.8812307211603922], 
             UndirectedEdge[2, 496] -> 
             RGBColor[
              0.18500487281902223`, 0.3117822296921864, 0.9338471258656362], 
             UndirectedEdge[103, 404] -> 
             RGBColor[
              0.6233155210312117, 0.7010502757004149, 0.96581591387943], 
             UndirectedEdge[37, 374] -> 
             RGBColor[
              0.8546495293295531, 0.4156398998574755, 0.19975329213765833`], 
             UndirectedEdge[236, 466] -> 
             RGBColor[
              0.2016228242267626, 0.329248750260696, 0.934793493614251], 
             UndirectedEdge[150, 254] -> 
             RGBColor[
              0.20389499448692971`, 0.33163694526804693`, 0.9349228903491928],
              UndirectedEdge[148, 229] -> 
             RGBColor[
              0.25473807623061007`, 0.385076247818226, 0.9378183286388965], 
             UndirectedEdge[160, 432] -> 
             RGBColor[
              0.26534093705235057`, 0.3962205268020793, 0.9384221458771677], 
             UndirectedEdge[48, 198] -> 
             RGBColor[
              0.18614733394130184`, 0.3129830287679211, 0.9339121873364302], 
             UndirectedEdge[89, 178] -> 
             RGBColor[
              0.38949543937037706`, 0.5113489021851207, 0.9461592546246456], 
             UndirectedEdge[63, 239] -> 
             RGBColor[
              0.20172774579693858`, 0.3293590294833628, 0.934799468742455], 
             UndirectedEdge[425, 462] -> 
             RGBColor[
              0.1883728625948838, 0.3153222004895023, 0.9340389279008772], 
             UndirectedEdge[44, 457] -> 
             RGBColor[
              0.3741308449563232, 0.49529319176279873`, 0.9452804632604023], 
             UndirectedEdge[46, 254] -> 
             RGBColor[
              0.1980699244230848, 0.3255144273001723, 0.9345911612264759], 
             UndirectedEdge[1, 452] -> 
             RGBColor[
              0.21304293634488086`, 0.3412520121737673, 0.935443852104836], 
             UndirectedEdge[260, 299] -> 
             RGBColor[
              0.2249121050554158, 0.35372726103730096`, 0.9361197837040394], 
             UndirectedEdge[321, 341] -> 
             RGBColor[
              0.9898662415110249, 0.9892279829702391, 0.7558592343220067], 
             UndirectedEdge[249, 406] -> 
             RGBColor[
              0.5717259495199576, 0.6608964487773493, 0.960589670883349], 
             UndirectedEdge[398, 496] -> 
             RGBColor[
              0.19603720028339988`, 0.32337790534720917`, 0.9344754005938667],
              UndirectedEdge[382, 462] -> 
             RGBColor[
              0.20106839690715364`, 0.3286660119950647, 0.934761919798601], 
             UndirectedEdge[63, 272] -> 
             RGBColor[
              0.23201898916873956`, 0.36119704684288256`, 0.9365245102406003],
              UndirectedEdge[117, 270] -> 
             RGBColor[
              0.18183894581371152`, 0.308454639678239, 0.933666831006253], 
             UndirectedEdge[164, 404] -> 
             RGBColor[
              0.5764261418930885, 0.6604370522196931, 0.9628281641033989], 
             UndirectedEdge[133, 191] -> 
             RGBColor[
              0.19428859491049005`, 0.32154001023229684`, 0.9343758201047092],
              UndirectedEdge[307, 469] -> 
             RGBColor[
              0.186562771602089, 0.31341968008967747`, 0.9339358458966271], 
             UndirectedEdge[31, 237] -> 
             RGBColor[
              0.21243558089193113`, 0.3406136430841573, 0.9354092641102925], 
             UndirectedEdge[1, 468] -> 
             RGBColor[
              0.21038952484231582`, 0.33846310844856536`, 0.9352927442451355],
              UndirectedEdge[346, 395] -> 
             RGBColor[
              0.47277817219066315`, 0.5825384587097979, 0.951727273224181], 
             UndirectedEdge[214, 223] -> 
             RGBColor[
              0.1978649215993461, 0.32529895633449324`, 0.9345794866189384], 
             UndirectedEdge[264, 397] -> 
             RGBColor[
              0.8437768320344039, 0.3262651740296299, 0.18911437710616869`], 
             UndirectedEdge[103, 204] -> 
             RGBColor[
              0.3628536312078076, 0.48870731062358463`, 0.9443416904150619], 
             UndirectedEdge[110, 356] -> 
             RGBColor[
              0.3311960783219361, 0.45542261326454736`, 0.9425392278051263], 
             UndirectedEdge[184, 253] -> 
             RGBColor[
              0.4591640004744537, 0.5697502062280924, 0.9511350822856912], 
             UndirectedEdge[115, 417] -> 
             RGBColor[
              0.19405888879625283`, 0.3212985745420247, 0.9343627386813232], 
             UndirectedEdge[243, 459] -> 
             RGBColor[
              0.19552964555273866`, 0.32284443314445566`, 0.9344464961028154],
              UndirectedEdge[190, 349] -> 
             RGBColor[
              0.20086956962021285`, 0.3284570319101118, 0.9347505968787484], 
             UndirectedEdge[128, 222] -> 
             RGBColor[
              0.19567917188119596`, 0.32300159479618107`, 0.9344550114060167],
              UndirectedEdge[204, 275] -> 
             RGBColor[
              0.402607767889131, 0.5221630142088122, 0.9471448284585735], 
             UndirectedEdge[178, 455] -> 
             RGBColor[
              0.5411769973801115, 0.6383908920759014, 0.9570225821118743], 
             UndirectedEdge[84, 391] -> 
             RGBColor[
              0.3743150955210323, 0.495024736722043, 0.9453330205540728], 
             UndirectedEdge[54, 203] -> 
             RGBColor[
              0.9172982685013698, 0.6686889606982549, 0.5070233200844496], 
             UndirectedEdge[236, 314] -> 
             RGBColor[
              0.23558368231737692`, 0.3649437653567001, 0.9367275142419242], 
             UndirectedEdge[277, 313] -> 
             RGBColor[
              0.4022235011215268, 0.5228075131556505, 0.9468503037125551], 
             UndirectedEdge[186, 397] -> 
             RGBColor[
              0.9076664956540943, 0.5791548277078178, 0.3416812367112626], 
             UndirectedEdge[29, 297] -> 
             RGBColor[
              0.18984593669287142`, 0.3168704947647796, 0.9341228172915397], 
             UndirectedEdge[130, 208] -> 
             RGBColor[
              0.3647668975032984, 0.4898257484488929, 0.9444833278623301], 
             UndirectedEdge[145, 450] -> 
             RGBColor[
              0.21228550631692578`, 0.340455905190549, 0.9354007175852613], 
             UndirectedEdge[86, 350] -> 
             RGBColor[
              0.18341807699895743`, 0.3101144066766324, 0.9337567601911376], 
             UndirectedEdge[37, 281] -> 
             RGBColor[
              0.8401393429256434, 0.30410824875280007`, 0.18585832125036283`],
              UndirectedEdge[281, 445] -> 
             RGBColor[
              0.8907713717872949, 0.5149365980262008, 0.23825003998390762`], 
             UndirectedEdge[116, 224] -> 
             RGBColor[
              0.2412066178691736, 0.37085382713634363`, 0.9370477321032114], 
             UndirectedEdge[112, 163] -> 
             RGBColor[
              0.9463750065735652, 0.8136106484588435, 0.49802406298394036`], 
             UndirectedEdge[148, 480] -> 
             RGBColor[
              0.25899827885189075`, 0.38955399088563913`, 0.9380609408757734],
              UndirectedEdge[42, 487] -> 
             RGBColor[
              0.19664512493327133`, 0.3240168726988731, 0.934510021003333], 
             UndirectedEdge[122, 319] -> 
             RGBColor[
              0.1832707103845271, 0.30995951502128316`, 0.9337483678804552], 
             UndirectedEdge[129, 348] -> 
             RGBColor[
              0.37572812244985154`, 0.497829719871169, 0.9452933537370448], 
             UndirectedEdge[93, 201] -> 
             RGBColor[
              0.24004103918211672`, 0.36962873003428975`, 0.9369813541213027],
              UndirectedEdge[121, 427] -> 
             RGBColor[
              0.19582329677639237`, 0.3231530791990786, 0.9344632191055845], 
             UndirectedEdge[269, 411] -> 
             RGBColor[
              0.441541570634595, 0.5502832522185821, 0.9505633429393294], 
             UndirectedEdge[76, 371] -> 
             RGBColor[
              0.3322551655815734, 0.4571504155823287, 0.9425770364794188], 
             UndirectedEdge[61, 244] -> 
             RGBColor[
              0.7184903511263943, 0.775794731676694, 0.8803911147116745], 
             UndirectedEdge[184, 436] -> 
             RGBColor[
              0.4481781977283561, 0.5602348560519236, 0.9504350766490738], 
             UndirectedEdge[80, 293] -> 
             RGBColor[
              0.578582457393624, 0.6633186431495282, 0.9625149398020252], 
             UndirectedEdge[111, 460] -> 
             RGBColor[
              0.33363255379100343`, 0.46265113373051764`, 0.9425070766696382],
              UndirectedEdge[286, 358] -> 
             RGBColor[
              0.20613946196016764`, 0.33399602288987706`, 0.9350507094514018],
              UndirectedEdge[176, 244] -> 
             RGBColor[
              0.38182757506705056`, 0.5051415871363136, 0.945550693339773], 
             UndirectedEdge[99, 321] -> 
             RGBColor[
              0.9825665367368704, 0.9863121992558153, 0.9051455199034306], 
             UndirectedEdge[187, 478] -> 
             RGBColor[
              0.2352799848565821, 0.36462456006987354`, 0.9367102191208121], 
             UndirectedEdge[116, 185] -> 
             RGBColor[
              0.24400994073613447`, 0.3738002972104551, 0.9372073771933402], 
             UndirectedEdge[97, 257] -> 
             RGBColor[
              0.9757547061623437, 0.9298770721991836, 0.3603120410906092], 
             UndirectedEdge[16, 313] -> 
             RGBColor[
              0.3156685624243244, 0.4442664326028998, 0.9414658712422952], 
             UndirectedEdge[166, 344] -> 
             RGBColor[
              0.19297880215941118`, 0.32016333500525607`, 0.9343012293452001],
              UndirectedEdge[103, 443] -> 
             RGBColor[
              0.3488203865149018, 0.47461920966592475`, 0.9435182887508398], 
             UndirectedEdge[74, 115] -> 
             RGBColor[
              0.18984673852773665`, 0.31687133754406216`, 0.9341228629548491],
              UndirectedEdge[196, 332] -> 
             RGBColor[
              0.18931192738265673`, 0.3163092171215981, 0.934092406251319], 
             UndirectedEdge[49, 203] -> 
             RGBColor[
              0.9194979870090474, 0.6684278731193166, 0.38546874588719493`], 
             UndirectedEdge[95, 122] -> 
             RGBColor[
              0.18517962016864098`, 0.3119659002362576, 0.9338570774686815], 
             UndirectedEdge[97, 209] -> 
             RGBColor[
              0.9914664507187211, 0.9823539717574632, 0.575433002447343], 
             UndirectedEdge[484, 490] -> 
             RGBColor[
              0.2003898909918431, 0.3279528592583135, 0.9347232798904836], 
             UndirectedEdge[128, 415] -> 
             RGBColor[
              0.1873275955453248, 0.3142235585466571, 0.9339794014887388], 
             UndirectedEdge[371, 442] -> 
             RGBColor[
              0.24599324612330464`, 0.37588487692119543`, 0.9373203235011023],
              UndirectedEdge[88, 311] -> 
             RGBColor[
              0.18977178861723454`, 0.3167925604360257, 0.9341185946683245], 
             UndirectedEdge[15, 149] -> 
             RGBColor[
              0.6067680705890965, 0.6914867648051379, 0.9622913844255672], 
             UndirectedEdge[117, 140] -> 
             RGBColor[
              0.1812891715754636, 0.30787679209614044`, 0.933635522176703], 
             UndirectedEdge[199, 475] -> 
             RGBColor[
              0.3613314497983178, 0.4873888735937467, 0.9442446983616614], 
             UndirectedEdge[71, 169] -> 
             RGBColor[
              0.1907755412237238, 0.3178475680670369, 0.9341757568943452], 
             UndirectedEdge[23, 51] -> 
             RGBColor[
              0.7136013437576199, 0.7704045833430664, 0.8366928314862011], 
             UndirectedEdge[381, 416] -> 
             RGBColor[
              0.19876402822087508`, 0.3262439744003725, 0.9346306894109254], 
             UndirectedEdge[121, 447] -> 
             RGBColor[
              0.21943101242653507`, 0.34796628516300276`, 0.9358076435873746],
              UndirectedEdge[244, 407] -> 
             RGBColor[
              0.361925627233212, 0.4849803667690406, 0.9443895897897958], 
             UndirectedEdge[255, 385] -> 
             RGBColor[
              0.1893629494279947, 0.3163628445262328, 0.9340953118813207], 
             UndirectedEdge[30, 469] -> 
             RGBColor[
              0.18014325773351766`, 0.30667236399312137`, 0.9335702640786318],
              UndirectedEdge[80, 171] -> 
             RGBColor[
              0.4090554292271066, 0.5282531641753069, 0.9474159938779831], 
             UndirectedEdge[214, 466] -> 
             RGBColor[
              0.1912157031774699, 0.31831020618830375`, 0.9342008234664497], 
             UndirectedEdge[199, 455] -> 
             RGBColor[
              0.4995894556816295, 0.6028040573199673, 0.9542526889773754], 
             UndirectedEdge[175, 483] -> 
             RGBColor[
              0.4248591023079348, 0.5424133332049215, 0.9482926242042767], 
             UndirectedEdge[124, 416] -> 
             RGBColor[
              0.19729887283700168`, 0.3247040031957048, 0.934547250979317], 
             UndirectedEdge[142, 396] -> 
             RGBColor[
              0.2065755605048984, 0.3344543901106338, 0.9350755446183742], 
             UndirectedEdge[185, 361] -> 
             RGBColor[
              0.22082084550846576`, 0.3494270878526189, 0.9358867925253167], 
             UndirectedEdge[19, 26] -> 
             RGBColor[
              0.1940564817835153, 0.32129604461902417`, 0.9343626016055087], 
             UndirectedEdge[341, 455] -> 
             RGBColor[
              0.8036709694912352, 0.8434735735210568, 0.7916789986243209], 
             UndirectedEdge[159, 239] -> 
             RGBColor[
              0.2143802858334754, 0.34265765127913517`, 0.9355200121797802], 
             UndirectedEdge[261, 482] -> 
             RGBColor[
              0.3308323765041129, 0.4609721092343021, 0.9423013243806262], 
             UndirectedEdge[5, 97] -> 
             RGBColor[
              0.8390165308787574, 0.8650728443865321, 0.6896757172524062], 
             UndirectedEdge[285, 396] -> 
             RGBColor[
              0.20591309648733414`, 0.33375809842552917`, 0.9350378182726016],
              UndirectedEdge[174, 424] -> 
             RGBColor[
              0.19047450678086728`, 0.3175311617809086, 0.934158613428165], 
             UndirectedEdge[99, 186] -> 
             RGBColor[
              0.9865105734086191, 0.9862533521324298, 0.7169514481905657], 
             UndirectedEdge[79, 127] -> 
             RGBColor[
              0.8591989102072256, 0.8905659049388609, 0.9864323531431288], 
             UndirectedEdge[29, 86] -> 
             RGBColor[
              0.18487060048840748`, 0.3116411009593528, 0.9338394792550458], 
             UndirectedEdge[127, 316] -> 
             RGBColor[
              0.6354319607294284, 0.7117057299932411, 0.9665139361497471], 
             UndirectedEdge[197, 466] -> 
             RGBColor[
              0.21288997416386868`, 0.3410912392231611, 0.9354351411349147], 
             UndirectedEdge[183, 206] -> 
             RGBColor[
              0.1886895173788014, 0.31565502474447266`, 0.9340569609223726], 
             UndirectedEdge[25, 392] -> 
             RGBColor[
              0.26287272325527145`, 0.39362627760755575`, 0.9382815847528192],
              UndirectedEdge[73, 91] -> 
             RGBColor[
              0.5186112912140105, 0.6200710352367826, 0.9552461270615734], 
             UndirectedEdge[187, 464] -> 
             RGBColor[
              0.21185013288920307`, 0.3399983001137429, 0.9353759237126298], 
             UndirectedEdge[17, 99] -> 
             RGBColor[
              0.6775706975021587, 0.7419956614956686, 0.932197104376443], 
             UndirectedEdge[110, 157] -> 
             RGBColor[
              0.35808579273911467`, 0.4836854080233668, 0.944070557261417], 
             UndirectedEdge[241, 429] -> 
             RGBColor[
              0.20378953117845383`, 0.33152609664407884`, 0.9349168843697941],
              UndirectedEdge[27, 490] -> 
             RGBColor[
              0.20058973370860944`, 0.328162906624395, 0.9347346606375627], 
             UndirectedEdge[372, 418] -> 
             RGBColor[
              0.5453882435546948, 0.6418097714349063, 0.9573541068370404], 
             UndirectedEdge[65, 350] -> 
             RGBColor[
              0.18235178883730735`, 0.30899367021216395`, 0.9336960366577636],
              UndirectedEdge[189, 390] -> 
             RGBColor[
              0.25394291239181044`, 0.3842404802073483, 0.9377730452346162], 
             UndirectedEdge[263, 267] -> 
             RGBColor[
              0.22679757309850174`, 0.35570900749616285`, 0.9362271583197932],
              UndirectedEdge[25, 490] -> 
             RGBColor[
              0.25243138864291936`, 0.38265177291112284`, 0.937686966193216], 
             UndirectedEdge[360, 494] -> 
             RGBColor[
              0.4757330556093662, 0.5825992022016417, 0.9526059341461844], 
             UndirectedEdge[61, 203] -> 
             RGBColor[
              0.9176650400604409, 0.6688406301635299, 0.5009449661762736], 
             UndirectedEdge[36, 104] -> 
             RGBColor[
              0.9591316136436914, 0.8643779170894872, 0.5023662490620132], 
             UndirectedEdge[33, 241] -> 
             RGBColor[
              0.2359506605232252, 0.3653294827188087, 0.9367484131078517], 
             UndirectedEdge[82, 419] -> 
             RGBColor[
              0.5847042349028322, 0.6736221466676785, 0.9605217589523052], 
             UndirectedEdge[5, 404] -> 
             RGBColor[
              0.763201606478355, 0.8150742978846761, 0.9769963355615894], 
             UndirectedEdge[40, 396] -> 
             RGBColor[
              0.19122359622902446`, 0.31831850228593606`, 0.934201272964059], 
             UndirectedEdge[169, 369] -> 
             RGBColor[
              0.1829196441464267, 0.30959052214615446`, 0.9337283751775514], 
             UndirectedEdge[268, 491] -> 
             RGBColor[
              0.1839641739186956, 0.3106883891638218, 0.9337878596028387], 
             UndirectedEdge[4, 151] -> 
             RGBColor[
              0.19261261169346405`, 0.31977844560772906`, 0.9342803753398946],
              UndirectedEdge[6, 390] -> 
             RGBColor[
              0.23515410879898574`, 0.36449225635233673`, 0.9367030506655489],
              UndirectedEdge[376, 482] -> 
             RGBColor[
              0.35174044974950636`, 0.47908163140914517`, 0.9436335683195394],
              UndirectedEdge[158, 278] -> 
             RGBColor[
              0.18808568721102567`, 0.3150203609530965, 0.9340225736876044], 
             UndirectedEdge[317, 445] -> 
             RGBColor[
              0.8902189090551026, 0.5106901273758575, 0.23772100104764282`], 
             UndirectedEdge[133, 351] -> 
             RGBColor[
              0.21908548042585338`, 0.34760310912229214`, 0.9357879660511045],
              UndirectedEdge[239, 454] -> 
             RGBColor[
              0.20401834156350113`, 0.3317665908661798, 0.9349299147827279], 
             UndirectedEdge[140, 198] -> 
             RGBColor[
              0.18071298100430727`, 0.3072711792732629, 0.9336027089760732], 
             UndirectedEdge[252, 309] -> 
             RGBColor[
              0.18525140255303396`, 0.3120413480735207, 0.9338611653692801], 
             UndirectedEdge[161, 243] -> 
             RGBColor[
              0.20521495427576572`, 0.33302430669639793`, 0.9349980601064616],
              UndirectedEdge[244, 455] -> 
             RGBColor[
              0.5298831385666443, 0.6290429228301937, 0.9561829756631566], 
             UndirectedEdge[401, 451] -> 
             RGBColor[
              0.192907026989333, 0.3200878947506953, 0.934297141855446], 
             UndirectedEdge[210, 225] -> 
             RGBColor[
              0.189744388344664, 0.31676376101227643`, 0.9341170342633367], 
             UndirectedEdge[107, 223] -> 
             RGBColor[
              0.20973558752308613`, 0.3377757788640342, 0.935255503482219], 
             UndirectedEdge[5, 204] -> 
             RGBColor[
              0.502739716654951, 0.6027313328078459, 0.9555221120972213], 
             UndirectedEdge[59, 200] -> 
             RGBColor[
              0.26298567956392194`, 0.393745001849791, 0.9382880174474929], 
             UndirectedEdge[328, 481] -> 
             RGBColor[
              0.22412762819429155`, 0.3529027261175536, 0.9360751089073279], 
             UndirectedEdge[55, 434] -> 
             RGBColor[
              0.7543365484938672, 0.7225141411414309, 0.6130982348590022], 
             UndirectedEdge[269, 499] -> 
             RGBColor[
              0.615223353565316, 0.6985050597773825, 0.9628517825115135], 
             UndirectedEdge[377, 476] -> 
             RGBColor[
              0.18211083187288252`, 0.3087404091649995, 0.9336823145151034], 
             UndirectedEdge[260, 478] -> 
             RGBColor[
              0.22953226117284842`, 0.3585833380515396, 0.9363828947600188], 
             UndirectedEdge[163, 207] -> 
             RGBColor[
              0.8871477729139166, 0.5804462187569267, 0.227545674269207], 
             UndirectedEdge[238, 258] -> 
             RGBColor[
              0.4509349141328164, 0.5640927881888469, 0.9502045107268047], 
             UndirectedEdge[10, 443] -> 
             RGBColor[
              0.2573117613989959, 0.387781354111264, 0.9379648962018101], 
             UndirectedEdge[231, 326] -> 
             RGBColor[
              0.7445199877539495, 0.8003439400856498, 0.9751704525106033], 
             UndirectedEdge[91, 287] -> 
             RGBColor[
              0.38223901787712034`, 0.5048831468883692, 0.9456450183489318], 
             UndirectedEdge[242, 249] -> 
             RGBColor[
              0.8500313217686346, 0.8830430785885436, 0.951908121903962], 
             UndirectedEdge[83, 209] -> 
             RGBColor[
              0.9948514855705746, 0.9921389712197164, 0.7349877382312089], 
             UndirectedEdge[306, 431] -> 
             RGBColor[
              0.33101101797964355`, 0.4548419980464291, 0.9425428260902121], 
             UndirectedEdge[176, 376] -> 
             RGBColor[
              0.34402119360606, 0.47239559971878675`, 0.9431417041439492], 
             UndirectedEdge[30, 191] -> 
             RGBColor[
              0.18476529609045284`, 0.31153041936041803`, 0.9338334823253662],
              UndirectedEdge[209, 444] -> 
             RGBColor[
              0.7801701048240467, 0.8252083695679635, 0.8500873938895259], 
             UndirectedEdge[169, 289] -> 
             RGBColor[
              0.19694268883638122`, 0.3243296312276827, 0.9345269668274088], 
             UndirectedEdge[20, 46] -> 
             RGBColor[
              0.22273395828831882`, 0.35143789068260056`, 0.9359957414679326],
              UndirectedEdge[49, 100] -> 
             RGBColor[
              0.9935759076270685, 0.9886678409266986, 0.5421553739880537], 
             UndirectedEdge[404, 486] -> 
             RGBColor[
              0.6250807725270684, 0.7025792478220061, 0.9659283941437955], 
             UndirectedEdge[103, 431] -> 
             RGBColor[
              0.415528043094357, 0.534331238706793, 0.9476980573623193], 
             UndirectedEdge[219, 238] -> 
             RGBColor[
              0.5781077146635654, 0.6679567426795029, 0.9602144407477138], 
             UndirectedEdge[249, 499] -> 
             RGBColor[
              0.6777613007469594, 0.7479803602752079, 0.9686609595995643], 
             UndirectedEdge[254, 377] -> 
             RGBColor[
              0.18661056292735312`, 0.3134699118026751, 0.9339385675419001], 
             UndirectedEdge[57, 434] -> 
             RGBColor[
              0.9488603570213409, 0.87598930982866, 0.6073727486571113], 
             UndirectedEdge[75, 104] -> 
             RGBColor[
              0.894725030806556, 0.6091192249245418, 0.23357173327544747`], 
             UndirectedEdge[132, 365] -> 
             RGBColor[
              0.23967912019619636`, 0.3692483302330984, 0.9369607433704656], 
             UndirectedEdge[38, 77] -> 
             RGBColor[
              0.4266438929830485, 0.5421807004439456, 0.9488977622771873], 
             UndirectedEdge[172, 314] -> 
             RGBColor[
              0.24315002922466572`, 0.37289647569036266`, 0.9371584065048872],
              UndirectedEdge[398, 481] -> 
             RGBColor[
              0.20576395571267658`, 0.3336013420152928, 0.9350293249261188], 
             UndirectedEdge[143, 165] -> 
             RGBColor[
              0.4432891969739572, 0.5546584690453142, 0.950431811201746], 
             UndirectedEdge[261, 475] -> 
             RGBColor[
              0.3329106779769486, 0.46277222951160313`, 0.9424337519127055], 
             UndirectedEdge[288, 373] -> 
             RGBColor[
              0.8511114942630649, 0.882439252848601, 0.8853377053514828], 
             UndirectedEdge[78, 171] -> 
             RGBColor[
              0.47037777522198154`, 0.5809128940593202, 0.9514490079974901], 
             UndirectedEdge[6, 370] -> 
             RGBColor[
              0.22157715427768293`, 0.35022201632181177`, 0.935929863190865], 
             UndirectedEdge[264, 295] -> 
             RGBColor[
              0.9251699045349664, 0.7351644032002858, 0.5555767619873893], 
             UndirectedEdge[45, 464] -> 
             RGBColor[
              0.2018156680778671, 0.3294514413752133, 0.9348044757862846], 
             UndirectedEdge[228, 318] -> 
             RGBColor[
              0.22809876360932468`, 0.35707664122328114`, 0.9363012591944456],
              UndirectedEdge[7, 295] -> 
             RGBColor[
              0.7285749695983985, 0.7852490192213029, 0.9266196187062239], 
             UndirectedEdge[225, 320] -> 
             RGBColor[
              0.1825517796800877, 0.30920387326807797`, 0.9337074258404], 
             UndirectedEdge[137, 148] -> 
             RGBColor[
              0.24314559520540308`, 0.3728918152549845, 0.9371581539940498], 
             UndirectedEdge[61, 455] -> 
             RGBColor[
              0.8016518216680615, 0.8434880657223675, 0.8868884028153723], 
             UndirectedEdge[11, 331] -> 
             RGBColor[
              0.3385041946670758, 0.46694107593320344`, 0.9428149166646195], 
             UndirectedEdge[20, 392] -> 
             RGBColor[
              0.2393040747004234, 0.36885413363778313`, 0.9369393850843115], 
             UndirectedEdge[348, 431] -> 
             RGBColor[
              0.44166621655022387`, 0.5567328899534418, 0.9494292969038062], 
             UndirectedEdge[241, 351] -> 
             RGBColor[
              0.22791016546505544`, 0.3568784126158412, 0.9362905188091355], 
             UndirectedEdge[343, 374] -> 
             RGBColor[
              0.8468374551199298, 0.3610187811212927, 0.19248490595917145`], 
             UndirectedEdge[162, 389] -> 
             RGBColor[
              0.18912373753009853`, 0.3161114176546337, 0.9340816891176178], 
             UndirectedEdge[207, 266] -> 
             RGBColor[
              0.9342851916423655, 0.7569554226506068, 0.3801831663512317], 
             UndirectedEdge[98, 425] -> 
             RGBColor[
              0.1874902819867422, 0.31439455231150293`, 0.9339886662409045], 
             UndirectedEdge[151, 284] -> 
             RGBColor[
              0.20527167990556933`, 0.33308392892993416`, 0.9350012905471609],
              UndirectedEdge[41, 365] -> 
             RGBColor[
              0.23506566561189032`, 0.36439929695507756`, 0.9366980139568839],
              UndirectedEdge[436, 473] -> 
             RGBColor[
              0.30955738588181175`, 0.4383701601543446, 0.9410985541344632], 
             UndirectedEdge[311, 405] -> 
             RGBColor[
              0.18582191019465255`, 0.3126409877771355, 0.9338936549354799], 
             UndirectedEdge[235, 432] -> 
             RGBColor[
              0.25417547246619693`, 0.38448491559068887`, 0.9377862891868108],
              UndirectedEdge[109, 474] -> 
             RGBColor[
              0.22157473772172553`, 0.350219476368282, 0.9359297255715783], 
             UndirectedEdge[364, 468] -> 
             RGBColor[
              0.21294670143418915`, 0.3411508631809846, 0.9354383716690389], 
             UndirectedEdge[203, 374] -> 
             RGBColor[
              0.8462576720826371, 0.35656231463411475`, 0.19192970506788876`],
              UndirectedEdge[36, 112] -> 
             RGBColor[
              0.993786491132969, 0.9916985686506579, 0.7526374521795876], 
             UndirectedEdge[324, 342] -> 
             RGBColor[
              0.7080228667800735, 0.7701523632700238, 0.969408565667581], 
             UndirectedEdge[374, 445] -> 
             RGBColor[
              0.9052815581912046, 0.6264682491308763, 0.2521450108712031], 
             UndirectedEdge[2, 327] -> 
             RGBColor[
              0.18398683108609262`, 0.3107122032833034, 0.9337891498950037], 
             UndirectedEdge[128, 438] -> 
             RGBColor[
              0.19844895166515433`, 0.32591280896330255`, 0.9346127462671912],
              UndirectedEdge[33, 460] -> 
             RGBColor[
              0.27847248938800495`, 0.41002262089535824`, 0.9391699683562924],
              UndirectedEdge[298, 335] -> 
             RGBColor[
              0.2430317898200987, 0.3727721985793514, 0.9371516729457167], 
             UndirectedEdge[112, 343] -> 
             RGBColor[
              0.91983604495667, 0.6739551077819146, 0.4751295029148105], 
             UndirectedEdge[106, 265] -> 
             RGBColor[
              0.18198502195137928`, 0.3086081749606899, 0.933675149826193], 
             UndirectedEdge[19, 468] -> 
             RGBColor[
              0.21235962003857659`, 0.3405338034110854, 0.9354049382520679], 
             UndirectedEdge[161, 202] -> 
             RGBColor[
              0.2003053984953046, 0.32786405228731785`, 0.9347184681678012], 
             UndirectedEdge[204, 390] -> 
             RGBColor[
              0.2859084769887601, 0.4171765863589087, 0.9396176659888837], 
             UndirectedEdge[211, 289] -> 
             RGBColor[
              0.19877803112005593`, 0.32625869233524674`, 0.9346314868553184],
              UndirectedEdge[48, 479] -> 
             RGBColor[
              0.18610061058204452`, 0.31293391955490957`, 0.9339095265102416],
              UndirectedEdge[57, 495] -> 
             RGBColor[
              0.9243664441871663, 0.7736553444054359, 0.5873941515896481], 
             UndirectedEdge[10, 280] -> 
             RGBColor[
              0.24013030719270134`, 0.36972255637333296`, 0.9369864378024453],
              UndirectedEdge[206, 476] -> 
             RGBColor[
              0.18192213006975788`, 0.30854207160553015`, 0.9336715682265748],
              UndirectedEdge[13, 256] -> 
             RGBColor[
              0.2822514185299613, 0.41373456987075796`, 0.9393946906458437], 
             UndirectedEdge[184, 221] -> 
             RGBColor[
              0.7515553610831588, 0.7612606169042988, 0.6324712276878893], 
             UndirectedEdge[126, 282] -> 
             RGBColor[
              0.5925848442263562, 0.6792934576295336, 0.9616388769267687], 
             UndirectedEdge[53, 266] -> 
             RGBColor[
              0.9131290173800801, 0.6204205778411838, 0.36094524797198546`], 
             UndirectedEdge[194, 220] -> 
             RGBColor[
              0.20157018632549908`, 0.32919342448903244`, 0.9347904959636448],
              UndirectedEdge[375, 417] -> 
             RGBColor[
              0.1999369421366619, 0.32747678129290203`, 0.9346974851232589], 
             UndirectedEdge[245, 448] -> 
             RGBColor[
              0.272254633728537, 0.40348726036243854`, 0.9388158706749788], 
             UndirectedEdge[79, 147] -> 
             RGBColor[
              0.8526636417246913, 0.529899304242684, 0.5774584339898925], 
             UndirectedEdge[77, 253] -> 
             RGBColor[
              0.35598021511374034`, 0.4827539030708413, 0.9439037224194711], 
             UndirectedEdge[180, 205] -> 
             RGBColor[
              0.2503131812646099, 0.38042540265441493`, 0.9375663374166283], 
             UndirectedEdge[28, 432] -> 
             RGBColor[
              0.38353725752998075`, 0.5043916701363219, 0.9458878966543498], 
             UndirectedEdge[84, 245] -> 
             RGBColor[
              0.25972033738633343`, 0.39031292018649366`, 0.9381020610411201],
              UndirectedEdge[19, 459] -> 
             RGBColor[
              0.1988488542772136, 0.32633313196386693`, 0.934635520129345], 
             UndirectedEdge[153, 236] -> 
             RGBColor[
              0.21799828044158207`, 0.3464603930063626, 0.9357260516203685], 
             UndirectedEdge[315, 349] -> 
             RGBColor[
              0.18430254906177113`, 0.31104404289341736`, 0.9338071295666557],
              UndirectedEdge[18, 460] -> 
             RGBColor[
              0.2944934860338214, 0.4268617041599678, 0.940082340414331], 
             UndirectedEdge[126, 449] -> 
             RGBColor[
              0.7360314578812237, 0.7759766732200013, 0.6718437842469422], 
             UndirectedEdge[49, 324] -> 
             RGBColor[
              0.9668288479321837, 0.9719938689278773, 0.783522492339073], 
             UndirectedEdge[334, 415] -> 
             RGBColor[
              0.18362714398561458`, 0.31033414933522163`, 0.9337686662467408],
              UndirectedEdge[5, 444] -> 
             RGBColor[
              0.627720184984083, 0.7079272421970324, 0.964330108694589], 
             UndirectedEdge[147, 449] -> 
             RGBColor[
              0.9013434874873846, 0.5520144216865974, 0.2783600016823526], 
             UndirectedEdge[254, 426] -> 
             RGBColor[
              0.189893219466744, 0.3169201919580207, 0.9341255099755632], 
             UndirectedEdge[186, 321] -> 
             RGBColor[
              0.9893791898196398, 0.9881862286508462, 0.7028466634493613], 
             UndirectedEdge[260, 399] -> 
             RGBColor[
              0.20881488896675832`, 0.33680806630567356`, 0.9352030710614876],
              UndirectedEdge[184, 287] -> 
             RGBColor[
              0.42249467395537876`, 0.5375645019893394, 0.9488140910567393], 
             UndirectedEdge[129, 431] -> 
             RGBColor[
              0.35531389648617895`, 0.48038586424829277`, 0.9439268390682725],
              UndirectedEdge[300, 432] -> 
             RGBColor[
              0.26154815956156724`, 0.39223407718328385`, 0.938206152809979], 
             UndirectedEdge[207, 293] -> 
             RGBColor[
              0.8423679493594973, 0.6882641451078306, 0.5995351479132809], 
             UndirectedEdge[118, 399] -> 
             RGBColor[
              0.200045010570769, 0.32759036806908304`, 0.9347036394607084], 
             UndirectedEdge[138, 179] -> 
             RGBColor[
              0.19144105687703156`, 0.31854706721479287`, 0.9342136570262589],
              UndirectedEdge[40, 161] -> 
             RGBColor[
              0.19942966903054987`, 0.32694360509540565`, 0.9346685966703091],
              UndirectedEdge[243, 279] -> 
             RGBColor[
              0.20228104719014361`, 0.3299405843289558, 0.934830978438262], 
             UndirectedEdge[69, 233] -> 
             RGBColor[
              0.7027067996446262, 0.7647987322711527, 0.9488520571207084], 
             UndirectedEdge[237, 460] -> 
             RGBColor[
              0.26678188416083737`, 0.3977350535744224, 0.9385042056833057], 
             UndirectedEdge[54, 295] -> 
             RGBColor[
              0.9871607004637972, 0.988958633933902, 0.862443950564356], 
             UndirectedEdge[102, 210] -> 
             RGBColor[
              0.19748304019874757`, 0.324897574769785, 0.9345577390381172], 
             UndirectedEdge[137, 156] -> 
             RGBColor[
              0.2055253114742025, 0.33335051178973785`, 0.9350157344897803], 
             UndirectedEdge[231, 444] -> 
             RGBColor[
              0.664761024690349, 0.7368638276963759, 0.9680219934301821], 
             UndirectedEdge[383, 393] -> 
             RGBColor[
              0.24454516184141023`, 0.374362848527078, 0.9372378572434972], 
             UndirectedEdge[43, 137] -> 
             RGBColor[
              0.220012218727478, 0.34857716983590165`, 0.9358407424263956], 
             UndirectedEdge[233, 348] -> 
             RGBColor[
              0.7123189222990802, 0.7728863489370825, 0.9495302713185423], 
             UndirectedEdge[193, 410] -> 
             RGBColor[
              0.1815860257697589, 0.30818880467598786`, 0.9336524275839118], 
             UndirectedEdge[126, 384] -> 
             RGBColor[
              0.3782656319739345, 0.49734201260730226`, 0.9457250298186803], 
             UndirectedEdge[162, 345] -> 
             RGBColor[
              0.1870835559314184, 0.31396705743943626`, 0.9339655037937511], 
             UndirectedEdge[165, 178] -> 
             RGBColor[
              0.3876179844694684, 0.5094620707746275, 0.9460491694230218], 
             UndirectedEdge[154, 455] -> 
             RGBColor[
              0.7982558492888101, 0.8419633098945049, 0.937775174104184], 
             UndirectedEdge[211, 470] -> 
             RGBColor[
              0.19104848384555853`, 0.31813444806814695`, 0.9341913005728761],
              UndirectedEdge[201, 305] -> 
             RGBColor[
              0.2840031755926752, 0.41566850052882615`, 0.9394910555788545], 
             UndirectedEdge[220, 474] -> 
             RGBColor[
              0.22327343139036823`, 0.3520049111174247, 0.9360264636630153], 
             UndirectedEdge[125, 173] -> 
             RGBColor[
              0.7492734803038996, 0.8040574045935522, 0.9756442362240689], 
             UndirectedEdge[189, 443] -> 
             RGBColor[
              0.2699043575235971, 0.40101697105492856`, 0.9386820259220295], 
             UndirectedEdge[307, 500] -> 
             RGBColor[
              0.19638085260421678`, 0.3237391057252033, 0.9344949710851491], 
             UndirectedEdge[102, 134] -> 
             RGBColor[
              0.1917868632444325, 0.31891053163232136`, 0.9342333501873077], 
             UndirectedEdge[102, 174] -> 
             RGBColor[
              0.1934597999069662, 0.32066889413495503`, 0.934328621455351], 
             UndirectedEdge[203, 281] -> 
             RGBColor[
              0.8317474856787275, 0.2450306635294393, 0.1780347341805933], 
             UndirectedEdge[279, 421] -> 
             RGBColor[
              0.19615975110811917`, 0.3235067140341602, 0.9344823796820367], 
             UndirectedEdge[335, 430] -> 
             RGBColor[
              0.2059656395327683, 0.33381332449770196`, 0.9350408105213086], 
             UndirectedEdge[69, 431] -> 
             RGBColor[
              0.4320540938957698, 0.548645273287512, 0.9487510827059723], 
             UndirectedEdge[149, 249] -> 
             RGBColor[
              0.6440396780590834, 0.7206036278354, 0.9660062699352006], 
             UndirectedEdge[141, 345] -> 
             RGBColor[
              0.19907503548324326`, 0.3265708627521209, 0.9346484008144234], 
             UndirectedEdge[12, 283] -> 
             RGBColor[
              0.18817638831560224`, 0.31511569356478863`, 0.9340277389813298],
              UndirectedEdge[119, 381] -> 
             RGBColor[
              0.18630903659373593`, 0.3131529885081697, 0.9339213960632688], 
             UndirectedEdge[396, 430] -> 
             RGBColor[
              0.19949732248348956`, 0.32701471316392194`, 0.9346724494343697],
              UndirectedEdge[49, 360] -> 
             RGBColor[
              0.7950442531705986, 0.8362229179981473, 0.7707477142317521], 
             UndirectedEdge[208, 497] -> 
             RGBColor[
              0.4523984541828804, 0.5655914141074888, 0.9502339454421076], 
             UndirectedEdge[275, 444] -> 
             RGBColor[
              0.5275882362182631, 0.6273589235979986, 0.9559528250559413], 
             UndirectedEdge[269, 323] -> 
             RGBColor[
              0.7972919842565633, 0.8394603962804845, 0.8661383017091098], 
             UndirectedEdge[273, 279] -> 
             RGBColor[
              0.19757076585955963`, 0.32498978000142653`, 0.9345627348847221],
              UndirectedEdge[107, 289] -> 
             RGBColor[
              0.21067973016305835`, 0.3387681326407459, 0.9353092710088315], 
             UndirectedEdge[289, 314] -> 
             RGBColor[
              0.23644046461492338`, 0.36584429787455663`, 0.9367763067262738],
              UndirectedEdge[6, 428] -> 
             RGBColor[
              0.2010842377589775, 0.3286826617346995, 0.9347628219116779], 
             UndirectedEdge[7, 17] -> 
             RGBColor[
              0.4238987520286698, 0.5410646532335288, 0.9483742450361144], 
             UndirectedEdge[309, 424] -> 
             RGBColor[
              0.19083388775165383`, 0.3179088939672749, 0.9341790796427948], 
             UndirectedEdge[128, 385] -> 
             RGBColor[
              0.1879057798305126, 0.31483126688939045`, 0.9340123282284333], 
             UndirectedEdge[71, 362] -> 
             RGBColor[
              0.1884877837309814, 0.3154429898899618, 0.9340454724895675], 
             UndirectedEdge[43, 156] -> 
             RGBColor[
              0.21388174499134507`, 0.34213365324474115`, 0.935491621016346], 
             UndirectedEdge[59, 298] -> 
             RGBColor[
              0.2693422110049278, 0.4004261194216593, 0.9386500125094126], 
             UndirectedEdge[261, 455] -> 
             RGBColor[
              0.47116868386026034`, 0.5781874132378237, 0.9524417425284195], 
             UndirectedEdge[17, 89] -> 
             RGBColor[
              0.3425624838836552, 0.4711321386741221, 0.9430487564503239], 
             UndirectedEdge[9, 68] -> 
             RGBColor[
              0.18960972675890758`, 0.3166222231476087, 0.9341093654852418], 
             UndirectedEdge[73, 298] -> 
             RGBColor[
              0.42629344369918076`, 0.5372437988360448, 0.949423062513614], 
             UndirectedEdge[16, 333] -> 
             RGBColor[
              0.25095246372984137`, 0.3810973290582225, 0.9376027436072896], 
             UndirectedEdge[257, 445] -> 
             RGBColor[
              0.9630857175869136, 0.8871415989142806, 0.3110954128128076], 
             UndirectedEdge[428, 451] -> 
             RGBColor[
              0.19643038781423483`, 0.323791170371646, 0.934497792042079], 
             UndirectedEdge[15, 419] -> 
             RGBColor[
              0.6508464250830497, 0.7271654409816981, 0.9658339472127815], 
             UndirectedEdge[17, 313] -> 
             RGBColor[
              0.3683319514339016, 0.4934523562550466, 0.9446907641355802], 
             UndirectedEdge[5, 326] -> 
             RGBColor[
              0.7074791480476834, 0.7714073545863063, 0.9714785677750102], 
             UndirectedEdge[216, 217] -> 
             RGBColor[
              0.1905787639681844, 0.31764074269506637`, 0.9341645507207481], 
             UndirectedEdge[138, 222] -> 
             RGBColor[
              0.1899361610003327, 0.31696532623247287`, 0.9341279554323748], 
             UndirectedEdge[251, 447] -> 
             RGBColor[
              0.23632980233893142`, 0.3657279848060955, 0.9367700046733661], 
             UndirectedEdge[58, 144] -> 
             RGBColor[
              0.1950230989335921, 0.322312020530822, 0.9344176490222236], 
             UndirectedEdge[11, 404] -> 
             RGBColor[
              0.6062003014417219, 0.6862259327279479, 0.9647253472215822], 
             UndirectedEdge[270, 329] -> 
             RGBColor[
              0.18084643102754924`, 0.3074114437089104, 0.9336103087574752], 
             UndirectedEdge[314, 406] -> 
             RGBColor[
              0.3396550578396198, 0.4643665868457374, 0.9430190117624826], 
             UndirectedEdge[13, 409] -> 
             RGBColor[
              0.2530894600625647, 0.3833434476973081, 0.9377244423870355], 
             UndirectedEdge[279, 335] -> 
             RGBColor[
              0.20917892656929465`, 0.33719069290725634`, 0.9352238024644066],
              UndirectedEdge[195, 446] -> 
             RGBColor[
              0.1857509853248722, 0.31256644124209987`, 0.9338896158690699], 
             UndirectedEdge[22, 170] -> 
             RGBColor[
              0.18476666722380106`, 0.3115318605085019, 0.9338335604093819], 
             UndirectedEdge[159, 166] -> 
             RGBColor[
              0.21389899734106987`, 0.3421517865581641, 0.9354926035121403], 
             UndirectedEdge[59, 87] -> 
             RGBColor[
              0.28570409751894754`, 0.41762349955141664`, 0.939581797741144], 
             UndirectedEdge[176, 407] -> 
             RGBColor[
              0.2970315342752855, 0.4287723651208341, 0.94025459557011], 
             UndirectedEdge[169, 470] -> 
             RGBColor[
              0.1892131415618838, 0.316205386960583, 0.9340867805449665], 
             UndirectedEdge[13, 188] -> 
             RGBColor[
              0.23846099400411988`, 0.36796800237156463`, 0.9368913728858832],
              UndirectedEdge[273, 396] -> 
             RGBColor[
              0.19229860014365638`, 0.3194483995593991, 0.9342624928466716], 
             UndirectedEdge[30, 405] -> 
             RGBColor[
              0.1802965998650839, 0.3068335362958501, 0.9335789966861752], 
             UndirectedEdge[258, 497] -> 
             RGBColor[
              0.44668148609611025`, 0.5606396636938994, 0.9498696652909349], 
             UndirectedEdge[90, 485] -> 
             RGBColor[
              0.25884791756577036`, 0.3893959516404705, 0.9380523780229685], 
             UndirectedEdge[89, 455] -> 
             RGBColor[
              0.4613630510985772, 0.5696942669850865, 0.9518169362796256], 
             UndirectedEdge[422, 451] -> 
             RGBColor[
              0.20581343032131297`, 0.33365334296584104`, 0.9350321424318895],
              UndirectedEdge[99, 178] -> 
             RGBColor[
              0.7245036529888805, 0.7822124250066672, 0.9353076025507647], 
             UndirectedEdge[119, 416] -> 
             RGBColor[
              0.19677397614642037`, 0.32415230349353147`, 0.9345173588893034],
              UndirectedEdge[129, 204] -> 
             RGBColor[
              0.3026394845996296, 0.4347619361650844, 0.9405704721210151], 
             UndirectedEdge[1, 381] -> 
             RGBColor[
              0.1937883174344935, 0.32101418688560046`, 0.9343473300425454], 
             UndirectedEdge[287, 409] -> 
             RGBColor[
              0.2786937259844361, 0.4102551545854176, 0.9391825674531689], 
             UndirectedEdge[340, 384] -> 
             RGBColor[
              0.3159339914529744, 0.4443075647988586, 0.9414896959063039], 
             UndirectedEdge[233, 379] -> 
             RGBColor[
              0.8949909626419136, 0.5916992159390957, 0.5610798957464819], 
             UndirectedEdge[1, 124] -> 
             RGBColor[
              0.1923231620506201, 0.3194742156809328, 0.934263891610937], 
             UndirectedEdge[134, 309] -> 
             RGBColor[
              0.18616361548114224`, 0.31300014169860263`, 0.9339131145460378],
              UndirectedEdge[1, 380] -> 
             RGBColor[
              0.19337326869879815`, 0.3205779443487749, 0.9343236936310573], 
             UndirectedEdge[112, 403] -> 
             RGBColor[
              0.8684251833169994, 0.8955159189410955, 0.8667074610489753], 
             UndirectedEdge[214, 268] -> 
             RGBColor[
              0.186923339851059, 0.31379866018069236`, 0.9339563797249931], 
             UndirectedEdge[404, 444] -> 
             RGBColor[
              0.7013455249659886, 0.7655800526301657, 0.9716322684022551], 
             UndirectedEdge[252, 320] -> 
             RGBColor[
              0.18172265320945252`, 0.3083324087777858, 0.93366020831448], 
             UndirectedEdge[173, 419] -> 
             RGBColor[
              0.6849417616486415, 0.753800977040894, 0.9692322517226041], 
             UndirectedEdge[407, 475] -> 
             RGBColor[
              0.3068290918915676, 0.4372585170884935, 0.9408788872777796], 
             UndirectedEdge[167, 305] -> 
             RGBColor[
              0.27520889494048634`, 0.4064251539737775, 0.9389902343056846], 
             UndirectedEdge[407, 482] -> 
             RGBColor[
              0.3047507904187318, 0.43545839681119247`, 0.9407464597457003], 
             UndirectedEdge[197, 493] -> 
             RGBColor[
              0.24589919103084765`, 0.37578601905558584`, 0.9373149672027289],
              UndirectedEdge[235, 300] -> 
             RGBColor[
              0.22449059247181202`, 0.353284224586492, 0.9360957791859752], 
             UndirectedEdge[312, 385] -> 
             RGBColor[
              0.1882621822827025, 0.31520586846386267`, 0.9340326248208353], 
             UndirectedEdge[188, 318] -> 
             RGBColor[
              0.21097876418895464`, 0.3390824363618151, 0.935326300554225], 
             UndirectedEdge[71, 153] -> 
             RGBColor[
              0.21268791512647112`, 0.34087886236357334`, 0.9354236341716544],
              UndirectedEdge[45, 481] -> 
             RGBColor[
              0.20322304481879772`, 0.33093068356277056`, 0.9348846238096533],
              UndirectedEdge[53, 317] -> 
             RGBColor[
              0.8249968310509084, 0.19314217390430075`, 0.1715702996852197], 
             UndirectedEdge[253, 301] -> 
             RGBColor[
              0.5169703257345344, 0.6164641572661, 0.9558333707121969], 
             UndirectedEdge[442, 447] -> 
             RGBColor[
              0.23581693788510275`, 0.36518893174763706`, 0.9367407978014356],
              UndirectedEdge[118, 464] -> 
             RGBColor[
              0.1973325308094801, 0.3247393798588184, 0.9345491677510571], 
             UndirectedEdge[2, 118] -> 
             RGBColor[
              0.18820276986646162`, 0.31514342224742875`, 0.9340292413716232],
              UndirectedEdge[332, 454] -> 
             RGBColor[
              0.19901001769354992`, 0.3265025249327872, 0.9346446981474854], 
             UndirectedEdge[84, 455] -> 
             RGBColor[
              0.4442800341977758, 0.5518254258243921, 0.9508409168167211], 
             UndirectedEdge[423, 488] -> 
             RGBColor[
              0.18086431186395144`, 0.3074302376016796, 0.933611327044656], 
             UndirectedEdge[5, 231] -> 
             RGBColor[
              0.7266171062027156, 0.7863580729508864, 0.9733860605895166], 
             UndirectedEdge[121, 337] -> 
             RGBColor[
              0.19710919882017952`, 0.3245046437779975, 0.9345364493246566], 
             UndirectedEdge[23, 360] -> 
             RGBColor[
              0.5140568870299039, 0.6157933787663372, 0.9550478947958676], 
             UndirectedEdge[79, 336] -> 
             RGBColor[
              0.7557987774112169, 0.8094300480703478, 0.9763306281365505], 
             UndirectedEdge[237, 371] -> 
             RGBColor[
              0.24348618176994377`, 0.3732497933287522, 0.9371775498950476], 
             UndirectedEdge[9, 330] -> 
             RGBColor[
              0.19168631998098046`, 0.3188048542876222, 0.9342276243971945], 
             UndirectedEdge[76, 111] -> 
             RGBColor[
              0.3885098195301592, 0.510929411430886, 0.9459764800480857], 
             UndirectedEdge[91, 256] -> 
             RGBColor[
              0.3859408633418989, 0.5085140760316679, 0.9458653508371028], 
             UndirectedEdge[35, 193] -> 
             RGBColor[
              0.1842865051954063, 0.311027179772628, 0.9338062158922009], 
             UndirectedEdge[43, 267] -> 
             RGBColor[
              0.22881279968486046`, 0.35782713841117125`, 0.9363419224926257],
              UndirectedEdge[261, 448] -> 
             RGBColor[
              0.314938405291928, 0.4464509223622935, 0.9413162052121451], 
             UndirectedEdge[322, 374] -> 
             RGBColor[
              0.8341132720585396, 0.26321513433887644`, 0.18030021388967482`],
              UndirectedEdge[76, 130] -> 
             RGBColor[
              0.3566736138347697, 0.4828157529154782, 0.9439676309835814], 
             UndirectedEdge[107, 153] -> 
             RGBColor[
              0.21946182531602942`, 0.3479986714635114, 0.9358093983358476], 
             UndirectedEdge[410, 437] -> 
             RGBColor[
              0.1820838890101732, 0.30871209050801585`, 0.9336807801589306], 
             UndirectedEdge[11, 164] -> 
             RGBColor[
              0.3457994968745498, 0.4739358766298315, 0.9432550160557256], 
             UndirectedEdge[213, 500] -> 
             RGBColor[
              0.2016031036308693, 0.32922802266405415`, 0.934792370555489], 
             UndirectedEdge[251, 454] -> 
             RGBColor[
              0.22516117799061744`, 0.3539890524843341, 0.9361339680392287], 
             UndirectedEdge[111, 483] -> 
             RGBColor[
              0.4093161482374549, 0.528950807600658, 0.9473022409150004], 
             UndirectedEdge[5, 233] -> 
             RGBColor[
              0.8260668342903568, 0.864508719874695, 0.9589794534592146], 
             UndirectedEdge[69, 372] -> 
             RGBColor[
              0.5285636967606093, 0.627866783936419, 0.9561081041909547], 
             UndirectedEdge[454, 489] -> 
             RGBColor[
              0.20150669956748674`, 0.32912669588106847`, 0.9347868804866963],
              UndirectedEdge[289, 493] -> 
             RGBColor[
              0.235488823391288, 0.36484406261097735`, 0.9367221121664148], 
             UndirectedEdge[74, 268] -> 
             RGBColor[
              0.18750418807117342`, 0.3144091684879368, 0.9339894581718406], 
             UndirectedEdge[192, 258] -> 
             RGBColor[
              0.36408500922956, 0.4897738683751677, 0.944420152733743], 
             UndirectedEdge[68, 368] -> 
             RGBColor[
              0.18232969627571796`, 0.3089704495291842, 0.9336947785190641], 
             UndirectedEdge[50, 414] -> 
             RGBColor[
              0.6515149605889788, 0.7239780646853934, 0.9683019767918029], 
             UndirectedEdge[358, 441] -> 
             RGBColor[
              0.22317531852257919`, 0.3519017882726634, 0.9360208762803397], 
             UndirectedEdge[71, 289] -> 
             RGBColor[
              0.20390581997350005`, 0.33164832354080787`, 0.9349235068446382],
              UndirectedEdge[54, 321] -> 
             RGBColor[
              0.9874803221287802, 0.9890908057062746, 0.8571469924212342], 
             UndirectedEdge[75, 408] -> 
             RGBColor[
              0.9013012276585859, 0.7170355167790632, 0.6001882350839804], 
             UndirectedEdge[8, 239] -> 
             RGBColor[
              0.19706547094004007`, 0.32445868300346314`, 0.9345339590865722],
              UndirectedEdge[389, 472] -> 
             RGBColor[
              0.18902863113306126`, 0.3160114548012536, 0.9340762729490037], 
             UndirectedEdge[178, 475] -> 
             RGBColor[
              0.40291899149679977`, 0.5229757083496808, 0.9470145914961603], 
             UndirectedEdge[332, 489] -> 
             RGBColor[
              0.1891243849825443, 0.31611209816820496`, 0.9340817259890768], 
             UndirectedEdge[28, 406] -> 
             RGBColor[
              0.44617181476977985`, 0.5602617683644892, 0.9498196286740023], 
             UndirectedEdge[77, 87] -> 
             RGBColor[
              0.32144010648392174`, 0.4528061418339081, 0.9417039869994168], 
             UndirectedEdge[274, 300] -> 
             RGBColor[
              0.23797382817444995`, 0.36745596019648397`, 0.9368636295125807],
              UndirectedEdge[330, 333] -> 
             RGBColor[
              0.210684466253447, 0.33877311057202975`, 0.9353095407221728], 
             UndirectedEdge[325, 490] -> 
             RGBColor[
              0.22480172486171077`, 0.3536112444552085, 0.9361134977153007], 
             UndirectedEdge[420, 489] -> 
             RGBColor[
              0.189832836442401, 0.3168567255709313, 0.9341220712516556], 
             UndirectedEdge[271, 304] -> 
             RGBColor[
              0.19940240032278655`, 0.3269149439546105, 0.9346670437577425], 
             UndirectedEdge[166, 387] -> 
             RGBColor[
              0.19228627737083037`, 0.31943544754385, 0.934261791082989], 
             UndirectedEdge[16, 165] -> 
             RGBColor[
              0.28802163997316926`, 0.4200593836114821, 0.9397137783554151], 
             UndirectedEdge[44, 356] -> 
             RGBColor[
              0.262163357709175, 0.39288068944223503`, 0.9382411874343812], 
             UndirectedEdge[86, 377] -> 
             RGBColor[
              0.18305173765274474`, 0.30972936079650676`, 0.9337358977073213],
              UndirectedEdge[113, 353] -> 
             RGBColor[
              0.1887122478968889, 0.3156789159601807, 0.9340582553917509], 
             UndirectedEdge[63, 222] -> 
             RGBColor[
              0.20195670404025598`, 0.32959967911388044`, 0.9348125075756986],
              UndirectedEdge[71, 493] -> 
             RGBColor[
              0.2293216757786306, 0.35836199945033154`, 0.9363709022333513], 
             UndirectedEdge[106, 270] -> 
             RGBColor[
              0.17988066425974236`, 0.3063963616027956, 0.9335553097687725], 
             UndirectedEdge[414, 498] -> 
             RGBColor[
              0.5986264598736242, 0.6821731423501425, 0.9631600517720931], 
             UndirectedEdge[46, 220] -> 
             RGBColor[
              0.21037184686789395`, 0.33844452777659967`, 0.9352917375106444],
              UndirectedEdge[302, 443] -> 
             RGBColor[
              0.2662987639830351, 0.3972272636359636, 0.9384766927038922], 
             UndirectedEdge[90, 267] -> 
             RGBColor[
              0.24580395513477205`, 0.37568592009050583`, 0.9373095436593363],
              UndirectedEdge[116, 187] -> 
             RGBColor[
              0.24886259772016034`, 0.3789007473768896, 0.9374837288297179], 
             UndirectedEdge[162, 472] -> 
             RGBColor[
              0.18323095336378353`, 0.30991772787174093`, 0.933746103776939], 
             UndirectedEdge[271, 371] -> 
             RGBColor[
              0.23108898271360306`, 0.3602195510927192, 0.9364715477488016], 
             UndirectedEdge[84, 478] -> 
             RGBColor[
              0.2624145878361924, 0.3931447482346404, 0.9382554946184531], 
             UndirectedEdge[5, 163] -> 
             RGBColor[
              0.7944424008489477, 0.6965434437689743, 0.6036935441317027], 
             UndirectedEdge[188, 430] -> 
             RGBColor[
              0.2127664410138974, 0.34096139805008724`, 0.9354281061047747], 
             UndirectedEdge[380, 487] -> 
             RGBColor[
              0.19010454207928099`, 0.31714230542242455`, 0.9341375444857234],
              UndirectedEdge[88, 304] -> 
             RGBColor[
              0.19013400622997473`, 0.3171732741129387, 0.9341392224255172], 
             UndirectedEdge[41, 494] -> 
             RGBColor[
              0.3091950820990577, 0.43800954418308746`, 0.9410771822783439], 
             UndirectedEdge[23, 136] -> 
             RGBColor[
              0.48008619598652036`, 0.5882144414151268, 0.9523735975581908], 
             UndirectedEdge[7, 84] -> 
             RGBColor[
              0.373934744333056, 0.4947159504930181, 0.9453030779152829], 
             UndirectedEdge[218, 493] -> 
             RGBColor[
              0.2733906528975818, 0.4046812885368802, 0.9388805652860661], 
             UndirectedEdge[40, 183] -> 
             RGBColor[
              0.19098677743240255`, 0.31806959071550744`, 0.9341877864839334],
              UndirectedEdge[192, 453] -> 
             RGBColor[
              0.27645983051134826`, 0.4075148710199178, 0.9390697150866952], 
             UndirectedEdge[49, 397] -> 
             RGBColor[
              0.9079673464709124, 0.579798317184308, 0.3744269914858809], 
             UndirectedEdge[291, 467] -> 
             RGBColor[
              0.1871130842202519, 0.31399809354320196`, 0.933967185386117], 
             UndirectedEdge[347, 462] -> 
             RGBColor[
              0.19657186081581016`, 0.32393986746620806`, 0.934505848720228], 
             UndirectedEdge[31, 226] -> 
             RGBColor[
              0.1894803426038117, 0.3164862321971737, 0.9341019972490159], 
             UndirectedEdge[120, 381] -> 
             RGBColor[
              0.18410140079156978`, 0.3108326233078988, 0.9337956744702399], 
             UndirectedEdge[151, 274] -> 
             RGBColor[
              0.22389877891969617`, 0.3526621910200718, 0.9360620762796918], 
             UndirectedEdge[316, 418] -> 
             RGBColor[
              0.45760917454031613`, 0.5701502103978782, 0.9505533872489015], 
             UndirectedEdge[235, 389] -> 
             RGBColor[
              0.20601966033790897`, 0.3338701037890217, 0.9350438869262447], 
             UndirectedEdge[218, 310] -> 
             RGBColor[
              0.4653446361758491, 0.5701283226319324, 0.9524120897475179], 
             UndirectedEdge[408, 463] -> 
             RGBColor[
              0.746221620758815, 0.8012446952293572, 0.9745845586722801], 
             UndirectedEdge[12, 273] -> 
             RGBColor[
              0.1905970563658978, 0.31765996916486816`, 0.9341655924457366], 
             UndirectedEdge[121, 454] -> 
             RGBColor[
              0.20826238807822112`, 0.3362273528412414, 0.9351716069532372], 
             UndirectedEdge[47, 228] -> 
             RGBColor[
              0.2699130817435731, 0.4010261407632708, 0.9386825227534509], 
             UndirectedEdge[438, 439] -> 
             RGBColor[
              0.2009360669634459, 0.3285269248340248, 0.9347543838040715], 
             UndirectedEdge[172, 201] -> 
             RGBColor[
              0.2404718980048366, 0.3700815899749955, 0.9370058908938581], 
             UndirectedEdge[58, 375] -> 
             RGBColor[
              0.19795511773261765`, 0.3253937581893268, 0.934584623155295], 
             UndirectedEdge[168, 280] -> 
             RGBColor[
              0.2730931280966553, 0.40436857110694446`, 0.9388636216888019], 
             UndirectedEdge[77, 301] -> 
             RGBColor[
              0.49545804882307076`, 0.5978313042438662, 0.9544626274499579], 
             UndirectedEdge[283, 477] -> 
             RGBColor[
              0.19005559335530314`, 0.3170908572099954, 0.934134756928306], 
             UndirectedEdge[125, 149] -> 
             RGBColor[
              0.669539684263013, 0.7405244264891351, 0.9685478722425018], 
             UndirectedEdge[7, 407] -> 
             RGBColor[
              0.3747418079101595, 0.4955642254833401, 0.9453490389920554], 
             UndirectedEdge[401, 437] -> 
             RGBColor[
              0.18132345879022535`, 0.30791283013279, 0.9336374747828603], 
             UndirectedEdge[138, 438] -> 
             RGBColor[
              0.19270594078429107`, 0.3198765403995944, 0.9342856902935492], 
             UndirectedEdge[45, 399] -> 
             RGBColor[
              0.20452814783915604`, 0.33230242958547795`, 0.9349589474959358],
              UndirectedEdge[97, 317] -> 
             RGBColor[
              0.9028878976305327, 0.5534256006607606, 0.2869376293254444], 
             UndirectedEdge[71, 201] -> 
             RGBColor[
              0.22759518578243687`, 0.3565473489985437, 0.936272581182181], 
             UndirectedEdge[107, 236] -> 
             RGBColor[
              0.20982294786551192`, 0.3378676001228893, 0.935260478524482], 
             UndirectedEdge[134, 225] -> 
             RGBColor[
              0.1840482113903489, 0.31077671787481287`, 0.933792645412527], 
             UndirectedEdge[59, 91] -> 
             RGBColor[
              0.36166005851975747`, 0.48325335582239703`, 0.9444730770573722],
              UndirectedEdge[161, 287] -> 
             RGBColor[
              0.25900221419710867`, 0.3895581271829785, 0.9380611649878617], 
             UndirectedEdge[101, 486] -> 
             RGBColor[
              0.32922289158902907`, 0.45369458082192426`, 0.9424141922098388],
              UndirectedEdge[185, 330] -> 
             RGBColor[
              0.20056082053324595`, 0.3281325170438868, 0.934733014074999], 
             UndirectedEdge[237, 432] -> 
             RGBColor[
              0.26206160282215785`, 0.3927737386043475, 0.9382353926440985], 
             UndirectedEdge[99, 143] -> 
             RGBColor[
              0.7801748654933693, 0.827408823277354, 0.9396902443294888], 
             UndirectedEdge[107, 411] -> 
             RGBColor[
              0.24624789168403566`, 0.3761525255509848, 0.9373348251890715], 
             UndirectedEdge[187, 407] -> 
             RGBColor[
              0.24918791988473313`, 0.3792426815984722, 0.9375022554457193], 
             UndirectedEdge[185, 357] -> 
             RGBColor[
              0.20004263933508956`, 0.3275878757500389, 0.9347035044223444], 
             UndirectedEdge[80, 208] -> 
             RGBColor[
              0.38701536387166025`, 0.5096349890530197, 0.9458812546550213], 
             UndirectedEdge[60, 240] -> 
             RGBColor[
              0.9901494356226408, 0.989783903232943, 0.7830629910514044], 
             UndirectedEdge[262, 299] -> 
             RGBColor[
              0.2916203852027007, 0.4206594025249505, 0.9400352481392587], 
             UndirectedEdge[82, 282] -> 
             RGBColor[
              0.6084177855813375, 0.6921473526873871, 0.962885304068208], 
             UndirectedEdge[286, 368] -> 
             RGBColor[
              0.18331387184910375`, 0.310004880457148, 0.9337508258620111], 
             UndirectedEdge[81, 454] -> 
             RGBColor[
              0.2248746265777104, 0.3536878687809598, 0.9361176493601785], 
             UndirectedEdge[68, 352] -> 
             RGBColor[
              0.18440978245630846`, 0.311156751990066, 0.933813236349837], 
             UndirectedEdge[196, 337] -> 
             RGBColor[
              0.19054105270955757`, 0.3176011057712177, 0.934162403120358], 
             UndirectedEdge[261, 262] -> 
             RGBColor[
              0.33623006243366543`, 0.4656473134908974, 0.942645260155071], 
             UndirectedEdge[122, 286] -> 
             RGBColor[
              0.1865372127264831, 0.3133928160908893, 0.9339343903564724]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.20904447312210606`, 0.33704937380942024`, 0.9352161455394953],
              316 -> RGBColor[
              0.43871305828747303`, 0.5544129335543235, 0.9491753860287206], 
             308 -> RGBColor[
              0.19090439582770188`, 0.3179830024256716, 0.9341830949734184], 
             160 -> RGBColor[
              0.23944883454874902`, 0.3690062854166779, 0.9369476289435206], 
             245 -> RGBColor[
              0.2439252154854269, 0.3737112456000703, 0.9372025522156523], 
             155 -> RGBColor[
              0.19392286855916088`, 0.32115560864865994`, 0.9343549925300447],
              425 -> RGBColor[
              0.18667870528248892`, 0.31354153373839766`, 0.9339424481482175],
              213 -> RGBColor[
              0.20221750657572096`, 0.32987379911448994`, 0.9348273598942706],
              352 -> RGBColor[
              0.18339204965023842`, 0.3100870502828995, 0.9337552779721321], 
             27 -> RGBColor[
              0.18521154867326725`, 0.3119994591190039, 0.933858895749786], 
             485 -> RGBColor[
              0.255344871987097, 0.38571402863136683`, 0.9378528847595545], 
             454 -> RGBColor[
              0.21139233227849236`, 0.33951712264565065`, 0.9353498526451051],
              367 -> RGBColor[
              0.19714961162350877`, 0.32454712019661625`, 0.9345387507740208],
              19 -> RGBColor[
              0.20321773659331793`, 0.33092510428123034`, 0.934884321514065], 
             164 -> RGBColor[
              0.3160253373259164, 0.44814699612157666`, 0.9413578329375422], 
             190 -> RGBColor[
              0.21654397156564814`, 0.3449318221692476, 0.9356432308813413], 
             103 -> 
             RGBColor[
              0.40980409560216274`, 0.5293734430830204, 0.9473333324896046], 
             138 -> RGBColor[
              0.1827700546655207, 0.3094332941172014, 0.9337198562779115], 
             416 -> RGBColor[
              0.20922896777355948`, 0.3372432893857343, 0.9352266522369601], 
             476 -> RGBColor[
              0.18343003159278173`, 0.31012697171270676`, 0.9337574409875706],
              291 -> RGBColor[
              0.18307944483465585`, 0.30975848280143214`, 0.933737475590342], 
             28 -> RGBColor[
              0.47584147550400935`, 0.5853485720851631, 0.951879130497885], 
             337 -> RGBColor[
              0.1890859537624092, 0.3160717045191629, 0.9340795373879439], 
             195 -> RGBColor[
              0.18809486651088786`, 0.3150300089792529, 0.934023096435152], 
             114 -> RGBColor[
              0.18143431560131953`, 0.3080293476699778, 0.9336437879142542], 
             479 -> RGBColor[
              0.18231814009471767`, 0.3089583032502487, 0.933694120411652], 
             93 -> RGBColor[
              0.2226303791602024, 0.3513290224516542, 0.935989842789818], 34 -> 
             RGBColor[
              0.2089289231192469, 0.33692792343012196`, 0.9352095651377733], 
             161 -> RGBColor[
              0.2138505894071634, 0.34210090675038807`, 0.9354898467519174], 
             22 -> RGBColor[
              0.1817982963009414, 0.30841191446298966`, 0.9336645160766364], 
             124 -> RGBColor[
              0.18536877790044387`, 0.31216471700567533`, 0.9338678497216739],
              84 -> RGBColor[
              0.27551545928723997`, 0.406914594772917, 0.9390015698665879], 
             46 -> RGBColor[
              0.2037103551444467, 0.3314428776122868, 0.934912375411788], 241 -> 
             RGBColor[
              0.21562994450375172`, 0.3439711217745316, 0.9355911783923481], 
             185 -> RGBColor[
              0.21154093935996757`, 0.33967331811051427`, 0.9353583155985506],
              426 -> RGBColor[
              0.18735694523176508`, 0.31425440692798345`, 0.9339810729099627],
              390 -> RGBColor[
              0.25591378716406765`, 0.38631199455366855`, 0.9378852836372484],
              121 -> RGBColor[
              0.20513244387794988`, 0.3329375830368321, 0.9349933612613692], 
             322 -> RGBColor[
              0.820782245844875, 0.16074702516771538`, 0.16753440813222906`], 
             488 -> RGBColor[
              0.18252871209609148`, 0.30917962777472857`, 0.9337061121756168],
              126 -> 
             RGBColor[
              0.4884562669939937, 0.5955898281066129, 0.9528722130934804], 
             433 -> RGBColor[
              0.18067343227102245`, 0.30722961104704605`, 0.9336004567342198],
              236 -> RGBColor[
              0.20835940299106456`, 0.3363293216657406, 0.9351771318090029], 
             78 -> RGBColor[
              0.4700607186843903, 0.5806554932788695, 0.9514240481454346], 
             376 -> RGBColor[
              0.37110890510299593`, 0.49585761394946637`, 0.9448677091678112],
              458 -> RGBColor[
              0.2390221871354001, 0.3685578519342398, 0.9369233320044987], 
             254 -> RGBColor[
              0.19242949370172294`, 0.3195859769880579, 0.9342699470411637], 
             290 -> RGBColor[
              0.18152659560596812`, 0.30812633980575366`, 0.9336490431240029],
              251 -> RGBColor[
              0.23893002370274252`, 0.3684609823230175, 0.9369180834333524], 
             165 -> RGBColor[
              0.3059265832870255, 0.43887861427331937`, 0.9407334383891494], 
             460 -> RGBColor[
              0.3006736022333113, 0.4333573981276305, 0.9404342888892294], 
             100 -> RGBColor[
              0.9932268871291124, 0.987921321372956, 0.5041666466903745], 235 -> 
             RGBColor[
              0.2171179053764417, 0.345535062993897, 0.9356759155628069], 70 -> 
             RGBColor[
              0.3697431424982056, 0.49467465902642144`, 0.9447806839823304], 
             234 -> RGBColor[
              0.9263783006421346, 0.7458215255627042, 0.25962045645451476`], 
             435 -> RGBColor[
              0.23839852597207306`, 0.3679023445091814, 0.9368878154238712], 
             257 -> RGBColor[
              0.9630526170636222, 0.8870299430768459, 0.31096682353032956`], 
             135 -> RGBColor[
              0.17999586170885287`, 0.3065174414257509, 0.93356187009308], 
             265 -> RGBColor[
              0.18432263905515192`, 0.3110651587502397, 0.9338082736620582], 
             111 -> RGBColor[
              0.3665915053486955, 0.49194486933340476`, 0.9445798644500469], 
             497 -> RGBColor[
              0.4781822073170808, 0.587248883619781, 0.9520634014805931], 481 -> 
             RGBColor[
              0.20526876593224802`, 0.3330808661592169, 0.9350011246006911], 
             381 -> RGBColor[
              0.18829908866819065`, 0.31524465941501073`, 0.9340347265848907],
              182 -> RGBColor[
              0.34499714152995936`, 0.4732409167578995, 0.9432038906826632], 
             188 -> 
             RGBColor[
              0.2239766808649284, 0.35274407090377946`, 0.9360665126802272], 
             154 -> RGBColor[
              0.9834670894693087, 0.9871903629131425, 0.9128700844415136], 
             336 -> RGBColor[
              0.6253505975793664, 0.7067268126951324, 0.9636490362576168], 
             463 -> RGBColor[
              0.5551591248464408, 0.6497422130407317, 0.9581233064042441], 
             315 -> RGBColor[
              0.18340993044876472`, 0.3101058441358588, 0.9337562962571558], 
             368 -> RGBColor[
              0.1792318772890574, 0.3057144453611359, 0.9335183623105863], 
             269 -> RGBColor[
              0.6018738506410779, 0.6876673319152327, 0.961800860740477], 208 -> 
             RGBColor[
              0.42661470104868005`, 0.5439339445951966, 0.948404489403622], 
             86 -> RGBColor[
              0.18531184315250615`, 0.31210487497572126`, 0.9338646073720063],
              119 -> RGBColor[
              0.18431898451928125`, 0.31106131760132866`, 0.9338080655416469],
              436 -> RGBColor[
              0.35552088653300873`, 0.4823560557407374, 0.9438744544084752], 
             377 -> RGBColor[
              0.1807916321529833, 0.30735384661729226`, 0.9336071880426363], 
             140 -> RGBColor[
              0.17901437519538227`, 0.3054858368702541, 0.933505975888117], 
             85 -> RGBColor[
              0.18726966457396857`, 0.31416266942272597`, 0.9339761024056213],
              351 -> RGBColor[
              0.24019038642635912`, 0.3697857034571507, 0.9369898592259228], 
             443 -> RGBColor[
              0.2878366774276409, 0.41986497624882907`, 0.9397032450120749], 
             242 -> RGBColor[
              0.9731128985329042, 0.9794682242662037, 0.9303970288913456], 
             117 -> RGBColor[
              0.18356396795554494`, 0.3102677473220268, 0.933765068465289], 
             47 -> RGBColor[
              0.28160948378147765`, 0.4133198008998302, 0.9393486155462334], 
             451 -> RGBColor[
              0.20508673054441848`, 0.33288953542489785`, 0.9349907579546514],
              81 -> RGBColor[
              0.23835692087692842`, 0.36785861491626903`, 0.9368854460752519],
              275 -> RGBColor[
              0.48931236896480956`, 0.5962848502534754, 0.9529396085766279], 
             23 -> RGBColor[
              0.4319501958436354, 0.5485552820168211, 0.9487444624139638], 
             328 -> RGBColor[
              0.24298649045633505`, 0.3727245860758903, 0.9371490932139648], 
             418 -> 
             RGBColor[
              0.4765052907931592, 0.5858874872414329, 0.9519313884690823], 
             110 -> RGBColor[
              0.4170759329154467, 0.5356719430706164, 0.9477966875329739], 6 -> 
             RGBColor[
              0.21439443043390383`, 0.3426725181510049, 0.9355208176938495], 
             218 -> RGBColor[
              0.28587662659874513`, 0.4178048385532594, 0.9395916230170046], 
             108 -> RGBColor[
              0.20961363351384976`, 0.337647597467996, 0.9352485583818076], 
             297 -> RGBColor[
              0.19526251556143404`, 0.32256366258657476`, 0.934431283444994], 
             487 -> RGBColor[
              0.19274009296176206`, 0.31991243650348955`, 0.9342876352095326],
              464 -> RGBColor[
              0.20245401245038683`, 0.33012238178410236`, 0.9348408285539537],
              157 -> RGBColor[
              0.29909565256278264`, 0.4316988729761172, 0.9403444269898601], 
             441 -> RGBColor[
              0.22146757953397317`, 0.3501068463187328, 0.935923623071312], 
             354 -> RGBColor[
              0.31058773436371456`, 0.4434372177375889, 0.9410113536850742], 
             385 -> RGBColor[
              0.18155548323377793`, 0.30815670253416316`, 0.9336506882316712],
              270 -> RGBColor[
              0.18011392367187812`, 0.3066415320344512, 0.9335685935472172], 
             392 -> RGBColor[
              0.23685058796865582`, 0.3662753635226519, 0.9367996626445457], 
             33 -> RGBColor[
              0.25627137654269866`, 0.3866878436630859, 0.9379056478233554], 
             252 -> RGBColor[
              0.18230687199160545`, 0.30894645975943874`, 0.9336934787098494],
              394 -> RGBColor[
              0.18345440314028216`, 0.3101525877543751, 0.9337588289111464], 
             260 -> RGBColor[
              0.20975080596055196`, 0.33779177440671543`, 0.935256370149719], 
             159 -> RGBColor[
              0.2321162208184409, 0.36129924347156134`, 0.9365300474392095], 
             183 -> RGBColor[
              0.19696480621086881`, 0.3243528779905917, 0.934528226379166], 
             99 -> RGBColor[
              0.9796979203258498, 0.9843793227373989, 0.9192503046446351], 
             329 -> RGBColor[
              0.18157893838322037`, 0.30818135538336955`, 0.9336520239677332],
              309 -> RGBColor[
              0.1881959331144625, 0.3151362363876026, 0.9340288520287109], 17 -> 
             RGBColor[
              0.3754434746784675, 0.49961200025393837`, 0.9451439041082509], 
             349 -> 
             RGBColor[
              0.18519516767477753`, 0.31198224165097593`, 0.9338579628761555],
              495 -> RGBColor[
              0.8860920716837987, 0.5756525260362475, 0.22666477128519144`], 
             347 -> RGBColor[
              0.2030767017243416, 0.3307768676918091, 0.9348762897869192], 
             340 -> RGBColor[
              0.36379298595207366`, 0.4895209324897256, 0.9444015452687277], 
             404 -> RGBColor[
              0.8368269464602606, 0.8727271083178094, 0.9842984952692555], 
             277 -> RGBColor[
              0.44322657405371796`, 0.5583223140551463, 0.9494629832622005], 
             104 -> RGBColor[
              0.9241317229671294, 0.73691459370894, 0.25781280732325], 79 -> 
             RGBColor[
              0.8862469572430673, 0.9121332834455631, 0.9890122200154841], 
             327 -> RGBColor[
              0.1837791716078354, 0.31049394000528374`, 0.9337773239949216], 
             191 -> RGBColor[
              0.19059661539563244`, 0.31765950567716017`, 0.9341655673331324],
              50 -> RGBColor[
              0.8803633253605091, 0.9074418350893442, 0.9884510339541455], 
             225 -> RGBColor[
              0.18396512493287584`, 0.310689388740023, 0.9337879137616893], 
             405 -> RGBColor[
              0.1816592229448945, 0.3082657395480243, 0.9336565960547502], 61 -> 
             RGBColor[
              0.9902590342278114, 0.9902398745688678, 0.8110965418638902], 
             196 -> RGBColor[
              0.19199615165670597`, 0.3191305070232725, 0.9342452688527721], 
             1 -> RGBColor[
              0.19927754620079638`, 0.32678371435619025`, 0.9346599335002002],
              263 -> RGBColor[
              0.22433819907190317`, 0.35312404946088816`, 0.9360871006072962],
              201 -> RGBColor[
              0.25745169920403105`, 0.3879284376169253, 0.9379728654527874], 
             371 -> RGBColor[
              0.25408219745152405`, 0.38438687763629015`, 0.9377809773127133],
              293 -> RGBColor[
              0.8097488880926076, 0.8513012527882134, 0.9816718596976299], 
             362 -> RGBColor[
              0.17923689510112015`, 0.3057197193997615, 0.9335186480675601], 
             184 -> RGBColor[
              0.5408355089237035, 0.6381136563631097, 0.9569956988896724], 
             106 -> RGBColor[
              0.17964740484760663`, 0.30615119117114004`, 0.9335420259903278],
              206 -> RGBColor[
              0.18041422854673403`, 0.3069571714983536, 0.933585695465579], 
             358 -> 
             RGBColor[
              0.2248830575111852, 0.353696730226594, 0.9361181294893675], 247 -> 
             RGBColor[
              0.18427930277709584`, 0.31101960957432406`, 0.9338058057251333],
              220 -> RGBColor[
              0.21703333859134122`, 0.34544617794091254`, 0.9356710996095008],
              407 -> RGBColor[
              0.2771295864414469, 0.4086111447535611, 0.9390934920201328], 
             107 -> RGBColor[
              0.21128649273995928`, 0.33940587858003807`, 0.9353438252399612],
              375 -> RGBColor[
              0.20274272640358343`, 0.3304258384544339, 0.9348572703864743], 
             131 -> RGBColor[
              0.8337292727736055, 0.2602635475653142, 0.17993249574075687`], 
             411 -> RGBColor[
              0.281209290628112, 0.4128991725219315, 0.9393258251381819], 462 -> 
             RGBColor[
              0.1900670199072787, 0.31710286724060704`, 0.934135407653537], 
             127 -> RGBColor[
              0.8321508631713839, 0.8689985264321587, 0.9838524862707736], 
             210 -> RGBColor[
              0.19552365175645214`, 0.32283813328452987`, 0.9344461547649839],
              357 -> RGBColor[
              0.18854433931021156`, 0.3155024333895635, 0.934048693246138], 
             181 -> RGBColor[
              0.22551745991005276`, 0.354363527371239, 0.9361542577674687], 
             194 -> RGBColor[
              0.18610703405965695`, 0.3129406710371523, 0.933909892317789], 
             440 -> RGBColor[
              0.8916325056316791, 0.6008103425923479, 0.23128784517976625`], 
             490 -> RGBColor[
              0.2159679187439516, 0.3443263541297861, 0.9356104255253395], 
             118 -> RGBColor[
              0.19221104916857337`, 0.3193563779335344, 0.9342575069481607], 
             348 -> RGBColor[
              0.46208044251389646`, 0.5741767455763179, 0.9507958115725785], 
             276 -> RGBColor[
              0.21359854810176626`, 0.34183599535807396`, 0.9354754933724367],
              305 -> RGBColor[
              0.3105546519813193, 0.443408563440727, 0.9410092457049215], 343 -> 
             RGBColor[
              0.8462306119676556, 0.35635431873254797`, 0.1919037922712223], 
             280 -> RGBColor[
              0.2534737690150518, 0.3837473807729669, 0.9377463282133454], 
             474 -> RGBColor[
              0.22951352418939525`, 0.35856364429393695`, 0.93638182771653], 
             189 -> RGBColor[
              0.2519720376195532, 0.38216896586102805`, 0.9376608068319842], 
             168 -> 
             RGBColor[
              0.29271248717825876`, 0.424989761440922, 0.9399809151642584], 
             363 -> RGBColor[
              0.18261346087673228`, 0.3092687041165651, 0.9337109384932998], 
             41 -> RGBColor[
              0.2630876311955555, 0.3938521594787447, 0.9382938234420904], 14 -> 
             RGBColor[
              0.2309802119470121, 0.36010522612056717`, 0.9364653534145562], 
             77 -> RGBColor[
              0.33446793820227666`, 0.46412105004860754`, 0.9425329791572322],
              51 -> RGBColor[
              0.9952524916716045, 0.9922538846693116, 0.7246412005584384], 
             438 -> RGBColor[
              0.20264182690306143`, 0.3303197866819874, 0.9348515243091869], 
             179 -> RGBColor[
              0.2001120590885424, 0.3276608403123844, 0.9347074577746062], 
             467 -> RGBColor[
              0.19114672360584797`, 0.3182377042849717, 0.934196895181892], 
             223 -> RGBColor[
              0.20818468230621298`, 0.33614567914803034`, 0.9351671817244767],
              456 -> RGBColor[
              0.19561148544389112`, 0.32293045205900567`, 0.9344511567635453],
              323 -> RGBColor[
              0.9927101178720487, 0.9912534606457363, 0.7704757426777427], 
             500 -> RGBColor[
              0.20098870068601762`, 0.3285822462136184, 0.9347573812167074], 
             478 -> RGBColor[
              0.24931371638514488`, 0.37937490169636373`, 0.9375094193703185],
              292 -> RGBColor[
              0.18511992750412062`, 0.3119031594611132, 0.9338536780597445], 
             491 -> RGBColor[
              0.1816268290277524, 0.30823169148721496`, 0.9336547512690914], 
             396 -> RGBColor[
              0.19743844380411263`, 0.32485070113144887`, 0.9345551993394172],
              321 -> RGBColor[
              0.9854351531478911, 0.9882450757742316, 0.8910407351622261], 
             143 -> RGBColor[
              0.5806518106608889, 0.6704383238173092, 0.9601301840143426], 
             112 -> RGBColor[
              0.9934414779456845, 0.9915558968312813, 0.7583552135583986], 
             197 -> RGBColor[
              0.23089370286527677`, 0.3600142995906707, 0.93646042685033], 
             421 -> RGBColor[
              0.1843367269803192, 0.31107996605281657`, 0.9338090759485553], 
             54 -> RGBColor[
              0.9895254911096693, 0.9899365356383177, 0.8232532496802422], 71 -> 
             RGBColor[
              0.19773867236084267`, 0.32516626038016205`, 0.9345722969115747],
              177 -> 
             RGBColor[
              0.18438238961983267`, 0.3111279603821238, 0.9338116763683237], 
             158 -> RGBColor[
              0.19170728594478786`, 0.3188268908449026, 0.9342288183778169], 
             226 -> RGBColor[
              0.1869796895121246, 0.3138578872472471, 0.933959588754829], 432 -> 
             RGBColor[
              0.29123303955595214`, 0.4234347681874807, 0.9398966628108147], 
             350 -> RGBColor[
              0.1815243108454087, 0.3081239383775436, 0.933648913010269], 203 -> 
             RGBColor[
              0.8450710458930704, 0.34744138575819206`, 0.19079339048865696`],
              475 -> RGBColor[
              0.3365285973416883, 0.465905889423426, 0.9426642825354262], 115 -> 
             RGBColor[
              0.19098661972276523`, 0.31806942495267926`, 0.934187777502603], 
             173 -> RGBColor[
              0.720597203195575, 0.7816552789687509, 0.9727860529169569], 212 -> 
             RGBColor[
              0.1819457440050942, 0.3085668913487786, 0.9336729130052586], 
             129 -> RGBColor[
              0.2893758023858067, 0.42148269416601997`, 0.9397908959015111], 
             279 -> RGBColor[
              0.20798277523591915`, 0.3359334620155039, 0.9351556834155181], 
             26 -> RGBColor[
              0.1848952269737127, 0.31166698495681794`, 0.9338408816969523], 
             40 -> RGBColor[
              0.18500874865393632`, 0.31178630344042324`, 0.9338473465887008],
              146 -> RGBColor[
              0.1800731039927536, 0.30659862796357423`, 0.9335662689268784], 
             386 -> RGBColor[
              0.30560245203902436`, 0.43853793178056216`, 0.9407149795940849],
              192 -> RGBColor[
              0.3129892535839804, 0.4455172929823175, 0.9411643763662094], 
             300 -> RGBColor[
              0.23186327956718236`, 0.36103338617908703`, 0.9365156428091433],
              221 -> RGBColor[
              0.9622752132426141, 0.884407577445488, 0.3079467564861062], 62 -> 
             RGBColor[
              0.25119317281524384`, 0.3813503295688181, 0.9376164516336061], 
             286 -> RGBColor[
              0.18739586640915007`, 0.3142953155531602, 0.933983289413436], 
             472 -> RGBColor[
              0.18313584696674626`, 0.3098177650183609, 0.9337406876083251], 
             152 -> RGBColor[
              0.18423542654322242`, 0.31097349287060916`, 0.9338033070385232],
              64 -> RGBColor[
              0.18480592008610275`, 0.3115731177555562, 0.9338357958018207], 
             307 -> 
             RGBColor[
              0.1917730045224159, 0.3188959652367882, 0.934232560953591], 37 -> 
             RGBColor[
              0.861854760386902, 0.4655965562049136, 0.20644056462819607`], 
             148 -> RGBColor[
              0.27463540520047075`, 0.4059896021290707, 0.9389514520882697], 
             261 -> RGBColor[
              0.329292758612209, 0.4596385695997802, 0.9422032212899847], 387 -> 
             RGBColor[
              0.18889078087796188`, 0.3158665654429332, 0.934068422580907], 
             15 -> RGBColor[
              0.6524065300643914, 0.7283842068503593, 0.9659894438973117], 
             136 -> RGBColor[
              0.5282221961294052, 0.6278736008134325, 0.956002732702418], 198 -> 
             RGBColor[
              0.1824115868132323, 0.30905652167627173`, 0.9336994420640293], 
             63 -> RGBColor[
              0.20681114074536727`, 0.3347019998800166, 0.9350889605645591], 
             444 -> RGBColor[
              0.5658641034717166, 0.6584329969425219, 0.9589660415352547], 
             310 -> RGBColor[
              0.644812645752953, 0.7224518067106054, 0.9652325564780311], 171 -> 
             RGBColor[
              0.47069483175957283`, 0.581170294839771, 0.9514739678495456], 
             395 -> RGBColor[
              0.5041410272247835, 0.6083234230523641, 0.954106974874018], 311 -> 
             RGBColor[
              0.18998459744441062`, 0.31701623600624673`, 0.9341307138162097],
              353 -> RGBColor[
              0.18070771638990538`, 0.3072656458297307, 0.9336024091640713], 
             59 -> RGBColor[
              0.26299592027232827`, 0.3937557654836245, 0.9382886006406869], 
             397 -> RGBColor[
              0.8220097648168001, 0.1701822738881748, 0.16870988168602888`], 
             229 -> RGBColor[
              0.2348407472607494, 0.36416289350738135`, 0.9366852051895233], 
             102 -> RGBColor[
              0.19944242864104303`, 0.32695701625504003`, 0.9346693233112505],
              453 -> RGBColor[
              0.23993040743871616`, 0.3695124490575181, 0.936975053807181], 
             299 -> RGBColor[
              0.24007340415027964`, 0.3696627476678865, 0.9369831972583599], 
             128 -> RGBColor[
              0.19425607642724724`, 0.32150583124461773`, 0.9343739682251954],
              12 -> RGBColor[
              0.19403535624859544`, 0.3212738403423871, 0.9343613985375474], 
             222 -> RGBColor[
              0.1971022673351447, 0.32449735834774435`, 0.9345360545868381], 
             483 -> 
             RGBColor[
              0.4520407911262143, 0.5659567458679113, 0.9500246173799538], 92 -> 
             RGBColor[
              0.27193911320159614`, 0.4031556282834669, 0.9387979022477403], 
             271 -> RGBColor[
              0.20809576797568208`, 0.3360522245491482, 0.9351621181848899], 
             361 -> RGBColor[
              0.23010075165696398`, 0.35918085759472357`, 0.9364152694520828],
              344 -> RGBColor[
              0.1902758304551235, 0.3173223403657453, 0.9341472991053292], 
             132 -> RGBColor[
              0.2723145403641676, 0.4035502260347864, 0.938819282269254], 80 -> 
             RGBColor[
              0.3474160266946404, 0.4753360335108428, 0.9433580199064205], 
             324 -> RGBColor[
              0.9397327677393429, 0.9545733773753136, 0.9869008833924131], 
             244 -> RGBColor[
              0.44672166802497704`, 0.5613495887845201, 0.9496856875594589], 
             150 -> RGBColor[
              0.2153604952721365, 0.34368791354803596`, 0.9355758336572221], 
             125 -> RGBColor[
              0.7779497574122243, 0.8264595302183536, 0.978502419531181], 258 -> 
             RGBColor[
              0.41518076487513966`, 0.5340304437680178, 0.9476759291012767], 
             133 -> RGBColor[
              0.19798057442534764`, 0.32542051478743356`, 0.9345860728762861],
              469 -> RGBColor[
              0.18135253868176207`, 0.30794339494256673`, 0.9336391308396634],
              255 -> RGBColor[
              0.19717041562221144`, 0.32456898651830246`, 0.9345399355309701],
              408 -> RGBColor[
              0.9372841166711893, 0.9527471774179826, 0.9910458109403161], 
             326 -> RGBColor[
              0.7253820295989173, 0.7853932217210695, 0.973262959696097], 176 -> 
             RGBColor[
              0.3169334821091241, 0.44893358548810713`, 0.9414156991200873], 
             230 -> RGBColor[
              0.2058983382969339, 0.3337425866316952, 0.9350369778154911], 
             274 -> RGBColor[
              0.24408437678171757`, 0.37387853421388084`, 0.937211616216018], 
             87 -> RGBColor[
              0.30841227476556676`, 0.4414912336192087, 0.9408749948416013], 
             439 -> RGBColor[
              0.19923030702383038`, 0.32673406298606217`, 0.934657243298956], 
             130 -> RGBColor[
              0.30291909395791666`, 0.43571755230258913`, 0.9405621663210384],
              35 -> RGBColor[
              0.187649142725438, 0.3145615250202248, 0.9339977131249598], 379 -> 
             RGBColor[
              0.8274245231995631, 0.21180247958034423`, 0.17389506042845765`],
              31 -> RGBColor[
              0.19198099569549876`, 0.3191145771471003, 0.9342444057432027], 
             18 -> RGBColor[
              0.2883133698343315, 0.42036601019230513`, 0.9397303919394328], 
             24 -> RGBColor[
              0.18529079599648704`, 0.31208275308027844`, 0.9338634087676074],
              151 -> RGBColor[
              0.20371318105767475`, 0.33144584782626274`, 0.9349125363433657],
              137 -> RGBColor[
              0.2116557852103354, 0.33979402838089834`, 0.9353648558998299], 
             330 -> RGBColor[
              0.18958070170652433`, 0.3165917159772593, 0.9341077125514473], 
             296 -> RGBColor[
              0.18222924951210637`, 0.30886487361193576`, 0.9336890582244741],
              266 -> RGBColor[
              0.9935833726583437, 0.9886838078737659, 0.5429678965735315], 
             302 -> RGBColor[
              0.24476085053842922`, 0.3745895510230982, 0.9372501403957095], 
             442 -> RGBColor[
              0.2379042947950852, 0.36738287620610066`, 0.9368596696894913], 
             283 -> RGBColor[
              0.18231742038260904`, 0.3089575467871901, 0.9336940794251122], 
             388 -> RGBColor[
              0.3286879472145684, 0.4591147123658486, 0.9421646832425408], 
             284 -> RGBColor[
              0.20683017875346388`, 0.3347220100336056, 0.935090044750956], 
             417 -> RGBColor[
              0.19713115786974042`, 0.32452772413137015`, 0.9345376998600435],
              318 -> RGBColor[
              0.1979808475129809, 0.32542080181985084`, 0.9345860884282229], 
             413 -> RGBColor[
              0.23030998251802656`, 0.3594007724957031, 0.936427184840091], 
             238 -> RGBColor[
              0.48668906339049306`, 0.5941551326096759, 0.9527330923523326], 
             72 -> RGBColor[
              0.21111609134757603`, 0.339226775912571, 0.9353341211327513], 
             437 -> RGBColor[
              0.18191959414620315`, 0.3085394061890873, 0.93367142380948], 
             288 -> RGBColor[
              0.7112234006140565, 0.7743323931485304, 0.9718517598787967], 
             382 -> RGBColor[
              0.21206977390702858`, 0.3402291567495223, 0.9353884319436652], 
             461 -> RGBColor[
              0.25327163562221944`, 0.38353492576110276`, 0.9377348170156531],
              389 -> RGBColor[
              0.19492141529937626`, 0.32220514458414634`, 0.9344118582896825],
              172 -> 
             RGBColor[
              0.22349209680564214`, 0.35223474233306573`, 0.9360389163349288],
              447 -> RGBColor[
              0.23372958097512028`, 0.36299498728917345`, 0.9366219259133799],
              243 -> RGBColor[
              0.19657931914436805`, 0.32394770664240774`, 0.9345062734610058],
              410 -> RGBColor[
              0.18224818387414324`, 0.30888477482694443`, 0.9336901365083813],
              88 -> RGBColor[
              0.18955897979005848`, 0.3165688848658047, 0.9341064755204392], 
             273 -> RGBColor[
              0.18715875648320013`, 0.3140460979873492, 0.9339697863539259], 
             477 -> RGBColor[
              0.19779376632799722`, 0.32522416763280076`, 0.9345754344314999],
              202 -> RGBColor[
              0.18676020758344578`, 0.31362719782424764`, 0.9339470895836851],
              393 -> RGBColor[
              0.2213158585080208, 0.34994737790078817`, 0.9359149827833353], 
             98 -> RGBColor[
              0.18830185869099547`, 0.3152475708846082, 0.9340348843335916], 
             30 -> RGBColor[
              0.17893397678527326`, 0.30540133304367595`, 0.9335013973176001],
              116 -> RGBColor[
              0.27647894211230134`, 0.40792727631039594`, 0.9390564387881299],
              373 -> RGBColor[
              0.9909995879120733, 0.9905461125486716, 0.7988236508241691], 
             434 -> RGBColor[
              0.9350798973521478, 0.7803204568826958, 0.2666219654201177], 
             401 -> RGBColor[
              0.18072732343424755`, 0.30728625407649274`, 0.9336035257562406],
              240 -> RGBColor[
              0.9948059876224538, 0.9912988576566625, 0.6760419903119628], 
             480 -> RGBColor[
              0.24336115250331075`, 0.37311837964220756`, 0.9371704296632771],
              403 -> RGBColor[
              0.7434088886883141, 0.7994759410509097, 0.9750597085395519], 
             317 -> RGBColor[0.817319, 0.134127, 0.164218], 429 -> 
             RGBColor[
              0.1919491178531559, 0.319081071513626, 0.9342425903472402], 391 -> 
             RGBColor[
              0.47311473175482466`, 0.583134878671169, 0.9516644712415576], 
             73 -> RGBColor[
              0.5768983856608343, 0.6673911243123956, 0.9598347006490895], 
             303 -> RGBColor[
              0.8407980254541154, 0.31459707821488886`, 0.1867015412906274], 
             449 -> RGBColor[
              0.9836066487684537, 0.9563635183333898, 0.39081535540040413`], 
             29 -> 
             RGBColor[
              0.1844293578243088, 0.3111773269429844, 0.9338143511380854], 
             360 -> RGBColor[
              0.5961635782161725, 0.6830314755158533, 0.9613513271777714], 
             320 -> RGBColor[
              0.18113843442729957`, 0.3077183577961329, 0.9336269379191107], 
             482 -> RGBColor[
              0.3323719943960167, 0.4623056488688239, 0.9423994274712677], 75 -> 
             RGBColor[
              0.8653183386459826, 0.4813238561401438, 0.20933065922764493`], 
             200 -> RGBColor[
              0.26297543885551555`, 0.39373423821595743`, 0.938287434254299], 
             301 -> RGBColor[
              0.6564481594438648, 0.7315415584391249, 0.9663922757426836], 
             156 -> RGBColor[
              0.19939483773806957`, 0.32690699519857735`, 0.9346666130797306],
              25 -> RGBColor[
              0.2888948585418871, 0.42097719169245956`, 0.9397635068610926], 
             38 -> RGBColor[
              0.5188198477638203, 0.6202403508392836, 0.9552625453971423], 
             365 -> RGBColor[
              0.20704370002822514`, 0.33494643443141037`, 0.9351022044716772],
              380 -> RGBColor[
              0.1874689911967999, 0.31437217434135956`, 0.9339874537619143], 
             370 -> RGBColor[
              0.22875987812146206`, 0.3577715144926186, 0.9363389086878806], 
             3 -> RGBColor[
              0.18365861817242612`, 0.31036723070113925`, 0.9337704586551179],
              57 -> RGBColor[
              0.9626408166905339, 0.9716581627746242, 0.9481235318941049], 
             227 -> RGBColor[
              0.19315889756887425`, 0.3203526266993102, 0.9343114855123418], 
             494 -> RGBColor[
              0.35530253300255993`, 0.4821669288874302, 0.9438605411145975], 
             39 -> RGBColor[
              0.24759097892264678`, 0.3775641953954144, 0.937411312020391], 
             424 -> RGBColor[
              0.19347184238884513`, 0.3206815515469472, 0.9343293072568787], 
             109 -> RGBColor[
              0.2136359512540558, 0.3418753084426271, 0.9354776234266265], 
             465 -> RGBColor[
              0.1790493149440538, 0.30552256076141593`, 0.9335079656551152], 
             256 -> RGBColor[
              0.3115575299166111, 0.44427720590216613`, 0.9410731482001482], 
             457 -> RGBColor[
              0.4692511982227218, 0.5799982880996057, 0.9513603197293209], 
             339 -> RGBColor[
              0.1801862242299471, 0.30671752450510187`, 0.9335727109570402], 
             420 -> 
             RGBColor[
              0.1880446060283209, 0.31497718202537633`, 0.9340202341750236], 
             287 -> RGBColor[
              0.304153838987054, 0.4370153476155689, 0.9406324832238061], 239 -> 
             RGBColor[
              0.1966443508485099, 0.324016059086709, 0.9345099769203509], 427 -> 
             RGBColor[
              0.18651414967483487`, 0.3133685753613251, 0.9339330769497998], 
             285 -> RGBColor[
              0.21438774917055564`, 0.3426654957196094, 0.9355204372057859], 
             345 -> RGBColor[
              0.19084105210201593`, 0.31791642415375154`, 0.9341794876419492],
              366 -> RGBColor[
              0.18255683100735334`, 0.30920918253330676`, 0.933707713506015], 
             216 -> RGBColor[
              0.19991510326486814`, 0.3274538272539823, 0.934696241431818], 
             21 -> RGBColor[
              0.3000028152540131, 0.4326523584820372, 0.9403960885630988], 
             355 -> RGBColor[
              0.5597098423756648, 0.6534366905384442, 0.9584815555579723], 
             175 -> RGBColor[
              0.39767741348965524`, 0.5188699205419315, 0.9465606310285997], 
             7 -> RGBColor[
              0.47235402937887205`, 0.5825173062131191, 0.951604585963978], 
             13 -> RGBColor[
              0.25294530714331137`, 0.3831919338393498, 0.9377162330915391], 
             294 -> RGBColor[
              0.18749202516745894`, 0.31439638450496027`, 0.9339887655124676],
              412 -> RGBColor[
              0.1902556572489104, 0.31730113704696017`, 0.934146150271079], 
             193 -> RGBColor[
              0.18092386766537458`, 0.30749283452503123`, 0.9336147186594421],
              60 -> RGBColor[
              0.9854928836228277, 0.9882689488092234, 0.890083991790846], 65 -> 
             RGBColor[
              0.183179266829206, 0.30986340204678436`, 0.9337431603052583], 
             448 -> RGBColor[
              0.300584051971647, 0.4332632751248068, 0.9404291891343054], 69 -> 
             RGBColor[
              0.44285619720498837`, 0.5580015122444584, 0.9494393831769108], 
             217 -> RGBColor[
              0.18124242467150065`, 0.3078276581361505, 0.9336328600096782], 
             214 -> RGBColor[
              0.1875451608924792, 0.3144522335209561, 0.9339917915134002], 
             170 -> RGBColor[
              0.1877350381466607, 0.3146518065540141, 0.9340026047421276], 
             359 -> RGBColor[
              0.9095261013751367, 0.9306954410809412, 0.9912326055643381], 74 -> 
             RGBColor[
              0.18870685733270803`, 0.31567325013544506`, 0.9340579484070953],
              246 -> RGBColor[
              0.2398990282396083, 0.3694794675296996, 0.9369732668082131], 
             264 -> RGBColor[
              0.8655438992520076, 0.482348074171085, 0.20951887252630852`], 
             278 -> RGBColor[
              0.18446408847726348`, 0.3112138310612903, 0.9338163289973919], 
             45 -> RGBColor[
              0.2011773237053474, 0.3287805009663242, 0.9347681230186154], 
             492 -> RGBColor[
              0.18260872208869527`, 0.3092637233498817, 0.9337106686263315], 
             306 -> RGBColor[
              0.24077004537273583`, 0.3703949617622926, 0.9370228699453904], 
             237 -> RGBColor[
              0.2328901660883635, 0.3621127090212143, 0.9365741224773821], 
             228 -> RGBColor[
              0.2582166797056685, 0.38873248062671145`, 0.9380164299606684], 
             180 -> RGBColor[
              0.26314504718325327`, 0.39391250732219896`, 0.9382970931976505],
              383 -> RGBColor[
              0.2677744651747997, 0.39877831915336787`, 0.938560731703659], 
             53 -> RGBColor[
              0.8326746621018166, 0.2521573478086015, 0.17892259937043942`], 
             304 -> RGBColor[
              0.190709032669891, 0.3177776633600728, 0.934171969330595], 48 -> 
             RGBColor[
              0.18988308106937135`, 0.3169095358595705, 0.9341249326088312], 
             5 -> RGBColor[
              0.6895762664964494, 0.7574214874515429, 0.9696941758539234], 
             101 -> RGBColor[
              0.24511118458418202`, 0.3749577743176459, 0.9372700914013423], 
             333 -> RGBColor[
              0.23178823080036964`, 0.3609545051668002, 0.9365113688928981], 
             267 -> RGBColor[
              0.22925694712510034`, 0.35829396553143755`, 0.9363672160322901],
              120 -> RGBColor[
              0.1799037129149489, 0.30642058720078685`, 0.9335566223555891], 
             147 -> RGBColor[
              0.8190803262063154, 0.147665325039805, 0.16590464796430104`], 
             89 -> RGBColor[
              0.30968149308884285`, 0.4426522770943059, 0.940953608792397], 
             43 -> RGBColor[
              0.22836865224462058`, 0.35736031129090495`, 0.9363166289529613],
              199 -> RGBColor[
              0.3861343022549474, 0.5088718577640675, 0.9458251141878965], 
             268 -> RGBColor[
              0.1863015188096388, 0.3131450868404286, 0.9339209679365861], 
             169 -> 
             RGBColor[
              0.18381241008660495`, 0.31052887575391175`, 0.9337792168771156],
              20 -> RGBColor[
              0.24175756143219096`, 0.3714329037529144, 0.9370791075240773], 
             4 -> RGBColor[
              0.18151204232925333`, 0.30811104338919537`, 0.9336482143364235],
              167 -> RGBColor[
              0.23986313789965336`, 0.369441744506828, 0.9369712229064477], 
             431 -> RGBColor[
              0.4212519905865513, 0.5392890343305656, 0.9480627822350338], 
             142 -> RGBColor[
              0.21571267720568413`, 0.3440580790898188, 0.9355958898973311], 
             16 -> RGBColor[
              0.27011669665931304`, 0.4012401529496448, 0.9386941183216809], 
             414 -> RGBColor[
              0.4226665958174486, 0.5405142942814426, 0.9481529196294604], 
             281 -> RGBColor[
              0.8184239254643847, 0.14261994130068656`, 0.16527607787252963`],
              289 -> RGBColor[
              0.21007296758615746`, 0.3381303867014537, 0.9352747167777018], 
             398 -> RGBColor[
              0.20625914549310514`, 0.3341218178713687, 0.9350575252515466], 
             178 -> RGBColor[
              0.46930938565191127`, 0.5800455272759355, 0.9513649004568943], 
             58 -> RGBColor[
              0.19316750906165184`, 0.32036167792421966`, 0.9343119759241159],
              186 -> RGBColor[
              0.9933232264913885, 0.9881273815274607, 0.5146525917364964], 
             122 -> RGBColor[
              0.18567855904381614`, 0.3124903166286185, 0.9338854912995088], 
             249 -> RGBColor[
              0.7269497450043649, 0.7866179329108834, 0.9734192149165786], 
             113 -> RGBColor[
              0.19671677940387242`, 0.3240921860906307, 0.9345141016194304], 
             52 -> RGBColor[
              0.1799948891424975, 0.30651641919684713`, 0.9335618147068648], 
             409 -> RGBColor[
              0.2532336129818181, 0.38349496155526636`, 0.9377326516825317], 
             187 -> RGBColor[
              0.22124625332801934`, 0.34987421844338334`, 0.9359110188713058],
              259 -> RGBColor[
              0.6832732263253226, 0.7524975045649791, 0.9690659477149247], 42 -> 
             RGBColor[
              0.2005501569047806, 0.3281213088942566, 0.9347324067971333], 
             134 -> RGBColor[
              0.18413129784782198`, 0.3108640470096027, 0.9337973770633647], 
             470 -> RGBColor[
              0.19461387303716265`, 0.3218818981672542, 0.9343943442128174], 
             313 -> 
             RGBColor[
              0.36122042818933575`, 0.4872927122561548, 0.9442376241629096], 
             248 -> RGBColor[
              0.18027294835259305`, 0.30680867705662973`, 0.933577649767528], 
             174 -> RGBColor[
              0.18747717117288942`, 0.31438077201487, 0.9339879195994514], 
             215 -> RGBColor[
              0.18496268734880916`, 0.3117378900882792, 0.9338447234655154], 
             399 -> RGBColor[
              0.20787897197296468`, 0.3358243582046317, 0.9351497719732561], 
             422 -> RGBColor[
              0.20654013009820746`, 0.33441715050678417`, 0.9350735269091277],
              83 -> RGBColor[
              0.9952268649647723, 0.9922942002460275, 0.7287667302186207], 95 -> 
             RGBColor[
              0.1846806812934658, 0.3114414838438967, 0.9338286636378542], 
             166 -> RGBColor[
              0.19568177386369887`, 0.32300432964476683`, 0.934455159585071], 
             384 -> RGBColor[
              0.2680749969538752, 0.3990941971079916, 0.9385778465438803], 
             233 -> RGBColor[
              0.9625574020842641, 0.9715959522978471, 0.948264731064506], 295 -> 
             RGBColor[
              0.9847959098179251, 0.9879807322294865, 0.9016346514484699], 
             499 -> RGBColor[
              0.628572856489554, 0.7093427876395323, 0.96390270428255], 141 -> 
             RGBColor[
              0.2073090188644706, 0.33522530135049017`, 0.9351173139868973], 
             319 -> RGBColor[
              0.18086286172523808`, 0.3074287134139478, 0.9336112444614015], 
             205 -> RGBColor[
              0.23748131534596645`, 0.36693829798663086`, 0.936835581635606], 
             468 -> RGBColor[
              0.22150150348383524`, 0.3501425025409405, 0.9359255549900708], 
             486 -> RGBColor[
              0.41333459859387617`, 0.5324313873262027, 0.9475582930183354], 
             224 -> RGBColor[
              0.20593429362604587`, 0.3337803779622914, 0.9350390254182929], 
             231 -> RGBColor[
              0.7636579459089816, 0.81529465845023, 0.9770779453251097], 332 -> 
             RGBColor[
              0.18662770310860746`, 0.3134879272199237, 0.9339395436498659], 
             68 -> RGBColor[
              0.18542751526237852`, 0.31222645369723245`, 0.933871194727542], 
             484 -> RGBColor[
              0.1848118632397346, 0.3115793643868409, 0.933836134255628], 10 -> 
             RGBColor[
              0.22678684537035088`, 0.355697731973699, 0.9362265473915452], 
             250 -> 
             RGBColor[
              0.2196415898680099, 0.3481876154053738, 0.9358196356611451], 
             282 -> RGBColor[
              0.6967134214587186, 0.7629970871524544, 0.9704055407600571], 
             374 -> RGBColor[
              0.847444298272204, 0.36568324351003745`, 0.19306601964712058`], 
             232 -> RGBColor[
              0.2784596091749779, 0.41000908297481403`, 0.939169234847215], 
             489 -> RGBColor[
              0.19162106685648111`, 0.3187362691164863, 0.9342239083282876], 
             253 -> RGBColor[
              0.37749249202520396`, 0.5013867560930751, 0.94527446568171], 
             459 -> RGBColor[
              0.1944799719611093, 0.3217411596465035, 0.9343867187446251], 
             415 -> RGBColor[
              0.1803991146634024, 0.3069412858486965, 0.9335848347522823], 55 -> 
             RGBColor[
              0.5735931996355866, 0.6647078254001658, 0.9595745042978867], 
             446 -> RGBColor[
              0.18340710413885652`, 0.31010287350494686`, 0.9337561353029877],
              325 -> RGBColor[
              0.23363553097946993`, 0.3628961347806308, 0.9366165699052621], 
             91 -> RGBColor[
              0.46032419676718667`, 0.5727509461611696, 0.9506575534740573], 
             450 -> RGBColor[
              0.2155265395117455, 0.34386243657167787`, 0.9355852896310274], 
             423 -> RGBColor[
              0.1791999116318114, 0.3056808474286306, 0.9335165419136952], 
             105 -> RGBColor[
              0.1914252698739526, 0.31853047407360313`, 0.9342127579797883], 
             36 -> RGBColor[
              0.9941315043202534, 0.9918412404700345, 0.7469196908007765], 
             123 -> RGBColor[
              0.18584647349383113`, 0.3126668053619753, 0.93389505377903], 94 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 473 -> 
             RGBColor[
              0.2635938852306148, 0.3943842645679517, 0.9383226538604513], 
             312 -> RGBColor[
              0.19496888133162707`, 0.3222550343935622, 0.9344145614099995], 
             96 -> RGBColor[
              0.4707743379765772, 0.5812348415684494, 0.9514802268701891], 
             496 -> RGBColor[
              0.1858152550736946, 0.31263399282304966`, 0.9338932759361868], 
             2 -> RGBColor[
              0.18419449056434983`, 0.3109304665613231, 0.9338009757950858], 
             262 -> RGBColor[
              0.34316736625512184`, 0.47165605738201455`, 0.9430872990201573],
              272 -> RGBColor[
              0.25722683759211185`, 0.3876920938057486, 0.9379600599166416], 
             97 -> RGBColor[
              0.9884567952610653, 0.9727242013215213, 0.40965725865088887`], 
             372 -> RGBColor[
              0.6142711963162304, 0.6977320556283797, 0.9627768252049985], 
             356 -> RGBColor[
              0.24531622372842543`, 0.3751732834584783, 0.9372817680772788], 
             402 -> RGBColor[
              0.21812922311479366`, 0.346598022058153, 0.9357335086118955], 
             455 -> RGBColor[
              0.6130446091083116, 0.6967362568758672, 0.9626802637668542], 
             428 -> RGBColor[
              0.18777404508405116`, 0.31469280531839416`, 0.9340048261295064],
              346 -> RGBColor[
              0.4414153171565428, 0.5567534943672319, 0.9493475715743441], 
             341 -> RGBColor[
              0.9942973298741586, 0.9902108901662465, 0.6206777334817875], 
             209 -> RGBColor[
              0.9944761061763768, 0.9919837421934052, 0.7412087462437971], 
             498 -> RGBColor[
              0.7745863239297996, 0.8238319904188423, 0.9781671839147258], 
             378 -> RGBColor[
              0.20696414784897932`, 0.33486282004712353`, 0.9350976740927561],
              419 -> RGBColor[
              0.649286320101708, 0.725946675113037, 0.9656784505282513], 66 -> 
             RGBColor[
              0.19788231111085003`, 0.3253172338136426, 0.9345804769258931], 
             139 -> RGBColor[
              0.18259939511325524`, 0.3092539201073298, 0.9337101374688782], 
             56 -> RGBColor[
              0.4068474012204774, 0.5268125030173851, 0.9471449345381059], 
             335 -> RGBColor[
              0.21037507790267013`, 0.33844792379900884`, 0.935291921513295], 
             314 -> RGBColor[
              0.2628079616436893, 0.3935582090476596, 0.9382778966748457], 
             144 -> RGBColor[
              0.1968786888055324, 0.3242623631374243, 0.9345233221203314], 
             298 -> RGBColor[
              0.2756885017375273, 0.407096473359694, 0.9390114243781383], 204 -> 
             RGBColor[
              0.3159031668134525, 0.44804117816414885`, 0.941350048340519], 
             452 -> RGBColor[
              0.22680832648896532`, 0.3557203099913444, 0.9362277707094718], 
             466 -> RGBColor[
              0.19488624546246058`, 0.32216817885565147`, 0.9344098554194993],
              207 -> RGBColor[
              0.8749870106263872, 0.5252270374274478, 0.21739843612893187`], 
             334 -> 
             RGBColor[
              0.18685517330782678`, 0.3137270128217468, 0.9339524977411994], 
             149 -> RGBColor[
              0.5611296111138018, 0.6545893227599167, 0.9585933249538227], 
             219 -> RGBColor[
              0.6695263659366376, 0.7417583527493299, 0.9676957891430948], 
             400 -> RGBColor[
              0.989868357531768, 0.9900783197151207, 0.8175710657562082], 9 -> 
             RGBColor[
              0.1937919382554366, 0.32101799259798497`, 0.9343475362429416], 
             11 -> RGBColor[
              0.37557365642318313`, 0.49972475713808634`, 0.9451521991739089],
              44 -> RGBColor[
              0.2790104916899246, 0.4105880954259918, 0.9392006067914836], 
             153 -> RGBColor[
              0.22763715789209957`, 0.35659146434698463`, 0.9362749714317341],
              471 -> RGBColor[
              0.9568366664708343, 0.967329437044196, 0.9579484442512339], 406 -> 
             RGBColor[
              0.41650215403555035`, 0.5351749646438152, 0.9477601268501196], 
             32 -> RGBColor[
              0.21967241372144744`, 0.34822001322968177`, 0.9358213910339986],
              162 -> RGBColor[
              0.18332605976082084`, 0.310017690725121, 0.933751519945553], 
             493 -> RGBColor[
              0.2609046791964185, 0.39155773852050096`, 0.9381695075551277], 
             90 -> RGBColor[
              0.2623509631444437, 0.39307787464957405`, 0.9382518712863824], 
             331 -> RGBColor[
              0.30143473291096856`, 0.4341573947283205, 0.94047763415533], 8 -> 
             RGBColor[
              0.19748659103157024`, 0.32490130692021735`, 0.9345579412527936],
              364 -> RGBColor[
              0.20439189938454302`, 0.3321592238210287, 0.9349511883480071], 
             342 -> RGBColor[
              0.47631296582080423`, 0.5857313491647339, 0.951916247942749], 
             163 -> RGBColor[
              0.899308535201446, 0.6356654000864056, 0.23769291240948212`], 
             49 -> RGBColor[
              0.9939249281250245, 0.9894143604804412, 0.5801441012857329], 
             338 -> RGBColor[
              0.4243323457115801, 0.5419570831167153, 0.9482590597397496], 76 -> 
             RGBColor[
              0.4104281337116228, 0.5299139535283672, 0.9473730956461243], 
             369 -> RGBColor[
              0.18202687820624844`, 0.30865216853839716`, 0.933677533477987], 
             445 -> RGBColor[
              0.9631188181102052, 0.8872532547517151, 0.3112240020952856], 82 -> 
             RGBColor[
              0.5201221497039563, 0.62129761822232, 0.955365067376359], 67 -> 
             RGBColor[
              0.18087272641393248`, 0.30743908182722296`, 0.9336118062408292],
              430 -> RGBColor[
              0.20155620116286646`, 0.329178725196395, 0.9347896995293221], 
             211 -> RGBColor[
              0.1874830946539544, 0.31438699796903974`, 
               0.933988256932935]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw1l3k4VA/cxYfs69jHPjOGGTNjV1rUPZUi6hcVbZKtXVmyRook2RJlqUih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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 42}], {
             RGBColor[
             0.19991385155278849`, 0.32745251162522343`, 0.9346961701486667]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 108}], {
             RGBColor[
             0.20444558985732308`, 0.3322156559120931, 0.9349542459410038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[
             0.1979971628023344, 0.3254379502234105, 0.9345870175598152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 119}], {
             RGBColor[
             0.1917982653600388, 0.3189225159787594, 0.9342339995209235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 120}], {
             RGBColor[
             0.18959062955787265`, 0.3166021507784885, 0.9341082779278946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 124}], {
             RGBColor[
             0.1923231620506201, 0.3194742156809328, 0.934263891610937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 315}], {
             RGBColor[
             0.19134373832478055`, 0.31844477924602455`, 0.934208114878678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 363}], {
             RGBColor[
             0.19094550353876433`, 0.3180262092363777, 0.93418543599675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 364}], {
             RGBColor[
             0.2018347227926697, 0.32947146908860947`, 0.9348055609241036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 378}], {
             RGBColor[
             0.20312084702488786`, 0.3308232672016569, 0.9348788037964781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 380}], {
             RGBColor[
             0.19337326869879815`, 0.3205779443487749, 0.9343236936310573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 381}], {
             RGBColor[
             0.1937883174344935, 0.32101418688560046`, 0.9343473300425454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 416}], {
             RGBColor[
             0.20425325698717794`, 0.33201350187096224`, 0.9349432928685801]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 452}], {
             RGBColor[
             0.21304293634488086`, 0.3412520121737673, 0.935443852104836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 468}], {
             RGBColor[
             0.21038952484231582`, 0.33846310844856536`, 0.9352927442451355]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 487}], {
             RGBColor[
             0.19600881958127922`, 0.3233480754298399, 0.9344737843548664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[
             0.19103840083759993`, 0.31812385018748285`, 0.9341907263604894]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 114}], {
             RGBColor[
             0.1828144030828347, 0.30947990711565043`, 0.93372238185467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 118}], {
             RGBColor[
             0.18820276986646162`, 0.31514342224742875`, 0.9340292413716232]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 195}], {
             RGBColor[
             0.18614467853761885`, 0.312980237770288, 0.933912036115119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 255}], {
             RGBColor[
             0.19068245309328063`, 0.3177497265398128, 0.9341704556630279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 260}], {
             RGBColor[
             0.1969726482624509, 0.32436112048401927`, 0.9345286729724024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 312}], {
             RGBColor[
             0.18958168594798847`, 0.3165927504774426, 0.9341077686025426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 327}], {
             RGBColor[
             0.18398683108609262`, 0.3107122032833034, 0.9337891498950037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 334}], {
             RGBColor[
             0.18552483193608832`, 0.31232873969153496`, 0.9338767367681426]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 385}], {
             RGBColor[
             0.1828749868990639, 0.3095435845477431, 0.9337258320133786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 446}], {
             RGBColor[
             0.18380079735160318`, 0.310516670033135, 0.9337785555490368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 496}], {
             RGBColor[
             0.18500487281902223`, 0.3117822296921864, 0.9338471258656362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[
             0.1847525458331286, 0.3115170180315573, 0.933832756217074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 139}], {
             RGBColor[
             0.18312900664284068`, 0.3098105754042345, 0.933740298061998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 158}], {
             RGBColor[
             0.187682952058607, 0.31459706077302096`, 0.9339996385164674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 247}], {
             RGBColor[
             0.18396896047476097`, 0.31069342013773166`, 0.9337881321901256]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 278}], {
             RGBColor[
             0.1840613533248448, 0.3107905308812148, 0.9337933938262548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 401}], {
             RGBColor[
             0.18219297080333685`, 0.308826742388816, 0.9336869922056792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 428}], {
             RGBColor[
             0.18571633162823864`, 0.3125300180097667, 0.9338876423923121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 437}], {
             RGBColor[
             0.18278910615931465`, 0.30945331844511326`, 0.9337209412322989]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 451}], {
             RGBColor[
             0.19437267435842231`, 0.32162838306301855`, 0.9343806083048847]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 31}], {
             RGBColor[
             0.18674651901237604`, 0.3136128102681478, 0.9339463100398131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 151}], {
             RGBColor[
             0.19261261169346405`, 0.31977844560772906`, 0.9342803753398946]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 162}], {
             RGBColor[
             0.18241905104503708`, 0.3090643670571582, 0.9336998671409883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 191}], {
             RGBColor[
             0.18605432886244289`, 0.31288527453317777`, 0.933906890834778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.18424586592068898`, 0.3109844653182212, 0.9338039015456263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 345}], {
             RGBColor[
             0.18617654721563465`, 0.31301373377147346`, 0.9339138509891864]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 366}], {
             RGBColor[
             0.18203443666830332`, 0.30866011296125107`, 0.9336779639212193]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 389}], {
             RGBColor[
             0.18821672881431478`, 0.31515809398667083`, 0.934030036313053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 405}], {
             RGBColor[
             0.18158563263707392`, 0.3081883914686098, 0.9336524051955868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 429}], {
             RGBColor[
             0.18673058009120463`, 0.3135960574514107, 0.9339454023418319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 472}], {
             RGBColor[
             0.18232394464799978`, 0.30896440420377813`, 0.9336944509723744]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 488}], {
             RGBColor[
             0.1820203772126724, 0.30864533558196194`, 0.9336771632560201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 69}], {
             RGBColor[
             0.5662162318507189, 0.6577114998480007, 0.959566779515417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[
             0.8424015657306109, 0.8748578438487853, 0.849230453036272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 97}], {
             RGBColor[
             0.8390165308787574, 0.8650728443865321, 0.6896757172524062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 103}], {
             RGBColor[
             0.5496901810493061, 0.6433974652672816, 0.958513754171764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 129}], {
             RGBColor[
             0.4894760344411281, 0.5894520908087815, 0.9547425358777173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 163}], {
             RGBColor[
             0.7944424008489477, 0.6965434437689743, 0.6036935441317027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 204}], {
             RGBColor[
             0.502739716654951, 0.6027313328078459, 0.9555221120972213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 209}], {
             RGBColor[
             0.8420261863364131, 0.8747026148224741, 0.8554514610488602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 231}], {
             RGBColor[
             0.7266171062027156, 0.7863580729508864, 0.9733860605895166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 233}], {
             RGBColor[
             0.8260668342903568, 0.864508719874695, 0.9589794534592146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 259}], {
             RGBColor[
             0.686424746410886, 0.7549594960082611, 0.969380061784424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 275}], {
             RGBColor[
             0.5894443177306294, 0.6768531688525092, 0.9613168922152756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 326}], {
             RGBColor[
             0.7074791480476834, 0.7714073545863063, 0.9714785677750102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 346}], {
             RGBColor[
             0.5654957918264961, 0.6570874909093873, 0.9595208737141337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 348}], {
             RGBColor[
             0.575828354505173, 0.6657991165139304, 0.9602449937132509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 355}], {
             RGBColor[
             0.624643054436057, 0.7054290889949936, 0.9640878657059478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 395}], {
             RGBColor[
             0.5968586468606165, 0.6828724552519535, 0.9619005753639707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 404}], {
             RGBColor[
             0.763201606478355, 0.8150742978846761, 0.9769963355615894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 431}], {
             RGBColor[
             0.5554141285415004, 0.6483552608910543, 0.9588784790444786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 444}], {
             RGBColor[
             0.627720184984083, 0.7079272421970324, 0.964330108694589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 486}], {
             RGBColor[
             0.5514554325451628, 0.6449264373888728, 0.9586262344361294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 35}], {
             RGBColor[
             0.2010217865796709, 0.32861702158561484`, 0.9347592654094047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 101}], {
             RGBColor[
             0.22975280750904292`, 0.3588151462343254, 0.9363954545475959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 123}], {
             RGBColor[
             0.20012045196386746`, 0.3276696617564901, 0.9347079357364398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 158}], {
             RGBColor[
             0.20305085818934585`, 0.33074970449795377`, 0.9348748180358333]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 181}], {
             RGBColor[
             0.2199559451719783, 0.348518022761122, 0.9358375377306591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 189}], {
             RGBColor[
             0.23318323402672853`, 0.3624207420060165, 0.9365908122629168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 302}], {
             RGBColor[
             0.22957764048616652`, 0.3586310345870516, 0.9363854790447795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 306}], {
             RGBColor[
             0.22758223790331983`, 0.3565337399566487, 0.93627184381962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 347}], {
             RGBColor[
             0.20873556607912272`, 0.336724692921407, 0.9351985537403844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 370}], {
             RGBColor[
             0.22157715427768293`, 0.35022201632181177`, 0.935929863190865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 390}], {
             RGBColor[
             0.23515410879898574`, 0.36449225635233673`, 0.9367030506655489]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 422}], {
             RGBColor[
             0.21046728026605566`, 0.33854483432889454`, 0.9352971723014887]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 428}], {
             RGBColor[
             0.2010842377589775, 0.3286826617346995, 0.9347628219116779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 451}], {
             RGBColor[
             0.20974058048916117`, 0.3377810267879514, 0.9352557878242505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 17}], {
             RGBColor[
             0.4238987520286698, 0.5410646532335288, 0.9483742450361144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.7309397602442707, 0.7862269209257184, 0.8874289178221101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.7313065318033417, 0.7863785903909934, 0.8813505639139341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.373934744333056, 0.4947159504930181, 0.9453030779152829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 89}], {
             RGBColor[
             0.39101776123385745`, 0.5125847916537125, 0.9462790973781875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 176}], {
             RGBColor[
             0.39464375574399807`, 0.5157254458506131, 0.9465101425420326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 178}], {
             RGBColor[
             0.47083170751539166`, 0.5812814167445273, 0.9514847432104361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 244}], {
             RGBColor[
             0.45953784870192455`, 0.5719334474988196, 0.9506451367617185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 261}], {
             RGBColor[
             0.40082339399554057`, 0.5210779379064496, 0.9469039036269813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 262}], {
             RGBColor[
             0.407760697816997, 0.5270866817975668, 0.9473459424920676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 288}], {
             RGBColor[
             0.5917887149964642, 0.6784248496808247, 0.9617281729213873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 295}], {
             RGBColor[
             0.7285749695983985, 0.7852490192213029, 0.9266196187062239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 313}], {
             RGBColor[
             0.4167872287841039, 0.534905009234637, 0.9479211050634437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 321}], {
             RGBColor[
             0.7288945912633815, 0.7853811909936754, 0.9213226605631021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 341}], {
             RGBColor[
             0.7333256796265153, 0.7863640981896829, 0.7861411597228827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 376}], {
             RGBColor[
             0.421731467240934, 0.5391874600812927, 0.9482361475658946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 391}], {
             RGBColor[
             0.47273438056684836`, 0.582826092442144, 0.9516345286027679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 407}], {
             RGBColor[
             0.3747418079101595, 0.4955642254833401, 0.9453490389920554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 448}], {
             RGBColor[
             0.38646904067525956`, 0.507890290668963, 0.9460168875491417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 455}], {
             RGBColor[
             0.5426993192435918, 0.6396267815444932, 0.9571424248654161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 475}], {
             RGBColor[
             0.40444131336028016`, 0.5242115978182725, 0.9471344342497021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 478}], {
             RGBColor[
             0.36083387288200847`, 0.48094610395474147`, 0.9445570026671483]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 482}], {
             RGBColor[
             0.4023630118874444, 0.5224114775409715, 0.9470020067176228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 63}], {
             RGBColor[
             0.20214886588846875`, 0.32980165340011697`, 0.9348234509086764]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 85}], {
             RGBColor[
             0.19237812780276942`, 0.31953198817147166`, 0.9342670218292075]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 146}], {
             RGBColor[
             0.18877984751216192`, 0.31574996744189576`, 0.934062105089836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 159}], {
             RGBColor[
             0.21480140592500557`, 0.34310027519588937`, 0.9355439943460016]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 166}], {
             RGBColor[
             0.19658418244763454`, 0.3239528182824921, 0.9345065504189323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 239}], {
             RGBColor[
             0.19706547094004007`, 0.32445868300346314`, 0.9345339590865722]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 344}], {
             RGBColor[
             0.19388121074334685`, 0.3211118236429813, 0.9343526201790614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 387}], {
             RGBColor[
             0.19318868595476607`, 0.32038393618157524`, 0.9343131819168503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 435}], {
             RGBColor[
             0.21794255850182165`, 0.34640182571469935`, 0.9357228783383325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 439}], {
             RGBColor[
             0.1983584490277003, 0.3258176849531398, 0.9346075922758748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 453}], {
             RGBColor[
             0.21870849923514318`, 0.34720687798886773`, 0.9357664975299873]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 68}], {
             RGBColor[
             0.18960972675890758`, 0.3166222231476087, 0.9341093654852418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 95}], {
             RGBColor[
             0.18923630977445122`, 0.3162297382209408, 0.934088099940398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 286}], {
             RGBColor[
             0.19059390233229334`, 0.3176566540755726, 0.9341654128281889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 319}], {
             RGBColor[
             0.18732739999033735`, 0.3142233530059664, 0.9339793903521716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 330}], {
             RGBColor[
             0.19168631998098046`, 0.3188048542876222, 0.9342276243971945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 333}], {
             RGBColor[
             0.21279008452790313`, 0.3409862488823926, 0.9354294525679199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 352}], {
             RGBColor[
             0.18859199395283752`, 0.3155525214404422, 0.9340514071075369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 357}], {
             RGBColor[
             0.19116813878282407`, 0.31826021299377427`, 0.9341981147445398]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 358}], {
             RGBColor[
             0.2093374978833109, 0.33735736141228945`, 0.9352328328661546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 367}], {
             RGBColor[
             0.19547077493947268`, 0.3227825563973006, 0.9344431435084812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 368}], {
             RGBColor[
             0.18651190777224702`, 0.3133662189795604, 0.933932949276764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 375}], {
             RGBColor[
             0.19826733232951002`, 0.32572191552620944`, 0.934602403314708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 441}], {
             RGBColor[
             0.2076297588947049, 0.33556241945835885`, 0.9351355796571268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 450}], {
             RGBColor[
             0.20465923888359105`, 0.3324402145848314, 0.9349664129369846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 492}], {
             RGBColor[
             0.18820033017206594`, 0.3151408579739333, 0.9340291024346365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 102}], {
             RGBColor[
             0.21311463700569694`, 0.34132737411436953`, 0.9354479353513978]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 168}], {
             RGBColor[
             0.25974966627430485`, 0.39034374670731053`, 0.9381037312779018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 181}], {
             RGBColor[
             0.22615215264020183`, 0.355030629672469, 0.9361904025795069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.23937944149495205`, 0.3689333489173635, 0.9369436771117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 232}], {
             RGBColor[
             0.2526232272726644, 0.38285340747425656`, 0.9376978911193801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 280}], {
             RGBColor[
             0.24013030719270134`, 0.36972255637333296`, 0.9369864378024453]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 302}], {
             RGBColor[
             0.23577384795439005`, 0.3651436414983986, 0.9367383438936274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 370}], {
             RGBColor[
             0.22777336174590646`, 0.35673462323315885`, 0.9362827280397129]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 383}], {
             RGBColor[
             0.24728065527257528`, 0.3772380255635335, 0.9373936395476021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 390}], {
             RGBColor[
             0.24135031626720926`, 0.37100486326368376`, 0.9370559155143968]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 443}], {
             RGBColor[
             0.2573117613989959, 0.387781354111264, 0.9379648962018101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 451}], {
             RGBColor[
             0.2159367879573847, 0.34429363369929844`, 0.9356086526730982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 480}], {
             RGBColor[
             0.2350739989368308, 0.3644080558079533, 0.9366984885274112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 25}], {
             RGBColor[
             0.3322342574825351, 0.46035097441527295`, 0.9424578530175007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 164}], {
             RGBColor[
             0.3457994968745498, 0.4739358766298315, 0.9432550160557256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 180}], {
             RGBColor[
             0.31935935180321817`, 0.4468186322301426, 0.9417246461857798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 205}], {
             RGBColor[
             0.3065274858845748, 0.4333315275623586, 0.9409938904047574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 259}], {
             RGBColor[
             0.5294234413742529, 0.6261111308515327, 0.9571090734444168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 316}], {
             RGBColor[
             0.4071433573553281, 0.5270688453462049, 0.9471637926013148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 331}], {
             RGBColor[
             0.3385041946670758, 0.46694107593320344`, 0.9428149166646195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 348}], {
             RGBColor[
             0.41882704946853977`, 0.5369507513572022, 0.9479740053732437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 372}], {
             RGBColor[
             0.49492242636970674`, 0.598728406383233, 0.9539645121894538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 404}], {
             RGBColor[
             0.6062003014417219, 0.6862259327279479, 0.9647253472215822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 418}], {
             RGBColor[
             0.4260394736081712, 0.5428061221897597, 0.9485417938214956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 431}], {
             RGBColor[
             0.3984128235048672, 0.519506895734326, 0.9466074907044714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 444}], {
             RGBColor[
             0.4707188799474499, 0.5790788770403041, 0.9520591203545818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 40}], {
             RGBColor[
             0.18952205245126588`, 0.31653007189140514`, 0.9341043725631242]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 161}], {
             RGBColor[
             0.20394297282787943`, 0.33168737354638755`, 0.9349256226447324]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 188}], {
             RGBColor[
             0.20900601855676193`, 0.3370089556230833, 0.9352139556088873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 202}], {
             RGBColor[
             0.1903977819160206, 0.31745051908331734`, 0.9341542440606163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 243}], {
             RGBColor[
             0.19530733769648173`, 0.3226107734923974, 0.9344338359992765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 273}], {
             RGBColor[
             0.1905970563658978, 0.31765996916486816`, 0.9341655924457366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 279}], {
             RGBColor[
             0.2010090657422573, 0.3286036511789455, 0.9347585409765328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 283}], {
             RGBColor[
             0.18817638831560224`, 0.31511569356478863`, 0.9340277389813298]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 285}], {
             RGBColor[
             0.20421155270957553`, 0.33196966803099826`, 0.9349409178716667]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 318}], {
             RGBColor[
             0.19600810188078815`, 0.32334732108111897`, 0.9344737434828851]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 335}], {
             RGBColor[
             0.20220521707563277`, 0.32986088207069797`, 0.9348266600254211]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 396}], {
             RGBColor[
             0.19573690002635402`, 0.32306227073691796`, 0.9344582989384823]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 421}], {
             RGBColor[
             0.18918604161445732`, 0.31617690319760183`, 0.9340852372430514]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 430}], {
             RGBColor[
             0.19779577870573095`, 0.32522628276939103`, 0.9345755490334348]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 459}], {
             RGBColor[
             0.19425766410485237`, 0.3215074999944453, 0.9343740586410862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 477}], {
             RGBColor[
             0.19591456128829632`, 0.32324900398759393`, 0.9344684164845236]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 21}], {
             RGBColor[
             0.27647406119866225`, 0.4079221461606935, 0.9390561608273189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 59}], {
             RGBColor[
             0.2579706137078198, 0.3884738496614871, 0.938002416866113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 77}], {
             RGBColor[
             0.293706622672794, 0.4236564919439787, 0.9401246061243856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 87}], {
             RGBColor[
             0.28067879095443904`, 0.41234158372927926`, 0.9392956139665702]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 161}], {
             RGBColor[
             0.23339794827523738`, 0.36264642029486893`, 0.9366030399217282]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 188}], {
             RGBColor[
             0.23846099400411988`, 0.36796800237156463`, 0.9368913728858832]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 228}], {
             RGBColor[
             0.2555809934244899, 0.38596220723303065`, 0.9378663315261038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 243}], {
             RGBColor[
             0.2247623131438397, 0.3535698202408788, 0.9361112532762724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 256}], {
             RGBColor[
             0.2822514185299613, 0.41373456987075796`, 0.9393946906458437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 279}], {
             RGBColor[
             0.23046404118961528`, 0.35956269792742684`, 0.9364359582535287]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 285}], {
             RGBColor[
             0.2336665281569335, 0.36292871477947963`, 0.9366183351486626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 287}], {
             RGBColor[
             0.2785495730651827, 0.41010364072745936`, 0.9391743581576726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 298}], {
             RGBColor[
             0.26431690444041933`, 0.3951442035995219, 0.9383638287348387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 335}], {
             RGBColor[
             0.23166019252299075`, 0.36081992881917935`, 0.936504077302417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 354}], {
             RGBColor[
             0.28176652075351294`, 0.4133145757884693, 0.9393637933883066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 409}], {
             RGBColor[
             0.2530894600625647, 0.3833434476973081, 0.9377244423870355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 430}], {
             RGBColor[
             0.22725075415308893`, 0.3561853295178724, 0.9362529663104306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 477}], {
             RGBColor[
             0.2253695367356543, 0.3542080507360753, 0.9361458337615195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 80}], {
             RGBColor[
             0.28919811932082623`, 0.417720629815705, 0.9399116866604884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 159}], {
             RGBColor[
             0.2315482163827265, 0.3607022347960642, 0.9364977004268829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 166}], {
             RGBColor[
             0.21333099290535548`, 0.34155477788266697`, 0.9354602564998136]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 192}], {
             RGBColor[
             0.27198473276549623`, 0.40281125955144237`, 0.9388148648903828]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.21659885926136652`, 0.3449895126175285, 0.9356463566544133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 239}], {
             RGBColor[
             0.21381228139776098`, 0.3420606426036381, 0.9354876651674535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 251}], {
             RGBColor[
             0.23495511782487732`, 0.36428310422179233`, 0.9366917184239543]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 272}], {
             RGBColor[
             0.24410352476956199`, 0.37389865996315785`, 0.9372127066655989]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 435}], {
             RGBColor[
             0.23468936895954257`, 0.3640037853148743, 0.9366765844192138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 447}], {
             RGBColor[
             0.2323548964610662, 0.3615501067048703, 0.936543639663968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 453}], {
             RGBColor[
             0.23545530969286413`, 0.36480883758904264`, 0.9367202036108686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 454}], {
             RGBColor[
             0.2211862721127522, 0.34981117438310894`, 0.9359076030298306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 489}], {
             RGBColor[
             0.2113006394017466, 0.3394207476185267, 0.935344630871422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 50}], {
             RGBColor[
             0.7663849277124503, 0.8179130209698517, 0.9772202389257285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 82}], {
             RGBColor[
             0.5862643398841738, 0.6748409125363397, 0.9606772556368353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 126}], {
             RGBColor[
             0.5704313985291926, 0.6619870174784861, 0.9594308284953961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 149}], {
             RGBColor[
             0.6067680705890965, 0.6914867648051379, 0.9622913844255672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 173}], {
             RGBColor[
             0.6865018666299831, 0.7550197429095551, 0.9693877484071343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 242}], {
             RGBColor[
             0.8127597142986478, 0.8539262155582815, 0.9481932363943286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 249}], {
             RGBColor[
             0.6896781375343781, 0.7575010698806214, 0.9697043294069452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 269}], {
             RGBColor[
             0.6271401903527347, 0.708025769382796, 0.9638951523188943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 282}], {
             RGBColor[
             0.674559975761555, 0.7456906470014069, 0.9681974923286845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 323}], {
             RGBColor[
             0.82255832396822, 0.8598188337480478, 0.8682325932875272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 414}], {
             RGBColor[
             0.53753656294092, 0.634449250565901, 0.957071181763386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 419}], {
             RGBColor[
             0.6508464250830497, 0.7271654409816981, 0.9658339472127815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 449}], {
             RGBColor[
             0.8180065894164226, 0.8423738625918746, 0.678402399648858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 499}], {
             RGBColor[
             0.6404896932769727, 0.7188634972449458, 0.9649460740899308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 17}], {
             RGBColor[
             0.32278008566889027`, 0.45042607660179157`, 0.9419190112149659]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 116}], {
             RGBColor[
             0.2732978193858072, 0.4045837146300204, 0.9388752785549055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 143}], {
             RGBColor[
             0.42538425366010096`, 0.535839238383477, 0.9494121511680118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 165}], {
             RGBColor[
             0.28802163997316926`, 0.4200593836114821, 0.9397137783554151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 185}], {
             RGBColor[
             0.2408288180096403, 0.3704567355300795, 0.9370262169601158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.2456814749936662, 0.3755571856965141, 0.9373025685964933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 224}], {
             RGBColor[
             0.23802549514267946`, 0.3675102654559681, 0.9368665718699869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 277}], {
             RGBColor[
             0.35667163535651547`, 0.47978123350239554`, 0.9440785507919407]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 313}], {
             RGBColor[
             0.3156685624243244, 0.4442664326028998, 0.9414658712422952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 333}], {
             RGBColor[
             0.25095246372984137`, 0.3810973290582225, 0.9376027436072896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 358}], {
             RGBColor[
             0.24749987708524912`, 0.37746844158811943`, 0.9374061239055242]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 361}], {
             RGBColor[
             0.2501087241581385, 0.3802105052721842, 0.9375546938868818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 386}], {
             RGBColor[
             0.2878595743491687, 0.4198890423651035, 0.9397045489578829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 441}], {
             RGBColor[
             0.2457921380966431, 0.37567349963418883`, 0.9373088706964965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 89}], {
             RGBColor[
             0.3425624838836552, 0.4711321386741221, 0.9430487564503239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.6775706975021587, 0.7419956614956686, 0.932197104376443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 116}], {
             RGBColor[
             0.32596120839538445`, 0.45376963828216715`, 0.9421001714481905]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 143}], {
             RGBColor[
             0.4780476426696782, 0.5850251620356237, 0.9526370440612968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 165}], {
             RGBColor[
             0.3406850289827465, 0.4692453072636289, 0.9429386712487001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 176}], {
             RGBColor[
             0.3461884783937958, 0.47427279287102275`, 0.943279801614169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 178}], {
             RGBColor[
             0.4223764301651894, 0.5398287637649369, 0.9482544022825725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 261}], {
             RGBColor[
             0.3523681166453383, 0.4796252849268593, 0.9436735626991177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 277}], {
             RGBColor[
             0.4093350243660927, 0.5289671571545423, 0.9473034436852257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 288}], {
             RGBColor[
             0.543333437646262, 0.6369721967012344, 0.9584978319935238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 313}], {
             RGBColor[
             0.3683319514339016, 0.4934523562550466, 0.9446907641355802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 321}], {
             RGBColor[
             0.6804393139131792, 0.743928538014085, 0.9180923196352385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 328}], {
             RGBColor[
             0.30921498256740126`, 0.43616829316491434`, 0.9411464986611078]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 386}], {
             RGBColor[
             0.34052296335874593`, 0.4690749660172503, 0.9429294418511679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 391}], {
             RGBColor[
             0.4242791032166461, 0.5413734394625537, 0.9484041876749043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 407}], {
             RGBColor[
             0.3262865305599572, 0.4541115725037497, 0.9421186980641918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 455}], {
             RGBColor[
             0.49424404189338955`, 0.5981741285649027, 0.9539120839375526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 498}], {
             RGBColor[
             0.5750148993041335, 0.6617219953363903, 0.9616555440114883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 28}], {
             RGBColor[
             0.38207742266917044`, 0.5028572911387341, 0.9458047612186589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 93}], {
             RGBColor[
             0.25547187449726694`, 0.38584751632197967`, 0.9378601173646254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 160}], {
             RGBColor[
             0.26388110219154026`, 0.3946861478044915, 0.9383390104414766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 167}], {
             RGBColor[
             0.2640882538669924, 0.39490387734956656`, 0.9383508074229403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 172}], {
             RGBColor[
             0.2559027333199868, 0.38630037626268543`, 0.9378846541371808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 201}], {
             RGBColor[
             0.27288253451918126`, 0.4041472239046152, 0.93885162869611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 218}], {
             RGBColor[
             0.2870949982165383, 0.4190854243727823, 0.9396610074782187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 235}], {
             RGBColor[
             0.2527156376053866, 0.3829505365931011, 0.9377031537511198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 274}], {
             RGBColor[
             0.2661988733080245, 0.397122272203093, 0.9384710040777253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 300}], {
             RGBColor[
             0.26008832470075693`, 0.39069969818569605`, 0.938123017374288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 305}], {
             RGBColor[
             0.2994340109078254, 0.43188728681651606`, 0.9403698188221772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 310}], {
             RGBColor[
             0.46656300779364224`, 0.5714089084514553, 0.952481474208732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 406}], {
             RGBColor[
             0.35240776193494094`, 0.47777048741806016`, 0.9437452593947762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 432}], {
             RGBColor[
             0.2897732046951418, 0.4219003891898929, 0.9398135273751238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 460}], {
             RGBColor[
             0.2944934860338214, 0.4268617041599678, 0.940082340414331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 493}], {
             RGBColor[
             0.274609024515375, 0.4059618743564031, 0.9389499497472802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 26}], {
             RGBColor[
             0.1940564817835153, 0.32129604461902417`, 0.9343626016055087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 59}], {
             RGBColor[
             0.2331068284328231, 0.3623404348824274, 0.936586461077376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 67}], {
             RGBColor[
             0.1920452315036252, 0.3191820930542266, 0.9342480638774471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 124}], {
             RGBColor[
             0.1942932572468809, 0.3215449106434528, 0.9343760856178694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 188}], {
             RGBColor[
             0.21359720872912316`, 0.3418345875925049, 0.9354754170971461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 200}], {
             RGBColor[
             0.23309658772441674`, 0.3623296712485939, 0.936585877884182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 228}], {
             RGBColor[
             0.2307172081494932, 0.3598287924539709, 0.9364503757373667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 298}], {
             RGBColor[
             0.2394531191654226, 0.3690107888204622, 0.9369478729461016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 318}], {
             RGBColor[
             0.20059929205314941`, 0.3281729530505406, 0.9347352049711439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 335}], {
             RGBColor[
             0.20679640724799403`, 0.3346865140401196, 0.9350881215136799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 459}], {
             RGBColor[
             0.1988488542772136, 0.32633313196386693`, 0.934635520129345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 468}], {
             RGBColor[
             0.21235962003857659`, 0.3405338034110854, 0.9354049382520679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 25}], {
             RGBColor[
             0.26532620998703904`, 0.39620504772268694`, 0.9384213071925849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 46}], {
             RGBColor[
             0.22273395828831882`, 0.35143789068260056`, 0.9359957414679326]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 150}], {
             RGBColor[
             0.22855902835216374`, 0.35756040865047517`, 0.9363274705906497]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 220}], {
             RGBColor[
             0.2293954500117661, 0.35843954084691343`, 0.9363751035667891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 325}], {
             RGBColor[
             0.23769654620583044`, 0.3671645192667726, 0.9368478387146697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 388}], {
             RGBColor[
             0.2852227543233797, 0.4152738080593815, 0.9396218953833091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 392}], {
             RGBColor[
             0.2393040747004234, 0.36885413363778313`, 0.9369393850843115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 413}], {
             RGBColor[
             0.23603377197510877`, 0.36541683812430875`, 0.9367531461820842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 473}], {
             RGBColor[
             0.25267572333140287`, 0.38290858416043305`, 0.9377008806922643]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 474}], {
             RGBColor[
             0.2356355428107931, 0.36499827402342566`, 0.9367304676203037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 490}], {
             RGBColor[
             0.22886274008807128`, 0.3578796289413503, 0.9363447665247084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 55}], {
             RGBColor[
             0.4367980074447999, 0.5486800919411015, 0.9499852964304927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 59}], {
             RGBColor[
             0.2814993677631707, 0.4132040619828309, 0.9393423446018928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 77}], {
             RGBColor[
             0.3172353767281449, 0.44838670426532234`, 0.9414645338601655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[
             0.30420754500978997`, 0.43707179605062296`, 0.94063554170235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 91}], {
             RGBColor[
             0.3801635060105999, 0.5027016523216035, 0.9455268210185781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 188}], {
             RGBColor[
             0.26198974805947073`, 0.39269821469290833`, 0.9382313006216629]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 200}], {
             RGBColor[
             0.28148912705476437`, 0.4131932983489973, 0.9393417614086988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 228}], {
             RGBColor[
             0.2791097474798408, 0.4106924195543743, 0.9392062592618835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 256}], {
             RGBColor[
             0.3057801725853121, 0.43846478219210167`, 0.9407346183816234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 287}], {
             RGBColor[
             0.30207832712053356`, 0.43483385304880307`, 0.9405142858934524]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 298}], {
             RGBColor[
             0.2878456584957702, 0.4198744159208656, 0.9397037564706185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 335}], {
             RGBColor[
             0.2551889465783416, 0.385550141140523, 0.9378440050381969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 336}], {
             RGBColor[
             0.4626767064166898, 0.5696895855885848, 0.9520225624103578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 354}], {
             RGBColor[
             0.30529527480886387`, 0.43804478810981307`, 0.9407037211240865]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 409}], {
             RGBColor[
             0.27661821411791565`, 0.40807366001865175`, 0.9390643701228152]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 24}], {
             RGBColor[
             0.18354454614871424`, 0.31024733377163405`, 0.9337639624221219]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 52}], {
             RGBColor[
             0.18089659272171946`, 0.3074641668299184, 0.9336131653917505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 170}], {
             RGBColor[
             0.18476666722380106`, 0.3115318605085019, 0.9338335604093819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 214}], {
             RGBColor[
             0.1846717285967103, 0.31143207399197287`, 0.9338281537950183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 268}], {
             RGBColor[
             0.1840499075552901, 0.3107785006517091, 0.9337927420066112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 466}], {
             RGBColor[
             0.188342270881701, 0.3152900466593206, 0.9340371857480678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 491}], {
             RGBColor[
             0.1817125626643469, 0.3083218029751023, 0.9336596336728639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 39}], {
             RGBColor[
             0.3397705873831411, 0.4630597387061178, 0.9430778872171774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 51}], {
             RGBColor[
             0.7136013437576199, 0.7704045833430664, 0.8366928314862011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 62}], {
             RGBColor[
             0.34157168432943963`, 0.4649528057928196, 0.943180457023785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 96}], {
             RGBColor[
             0.4513622669101063, 0.5648950617926353, 0.9501123446420765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 110}], {
             RGBColor[
             0.42451306437954106`, 0.5421136125437187, 0.9482705749734688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 136}], {
             RGBColor[
             0.48008619598652036`, 0.5882144414151268, 0.9523735975581908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 157}], {
             RGBColor[
             0.36552292420320903`, 0.49012707749646917`, 0.944544444701912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 240}], {
             RGBColor[
             0.7133780917330446, 0.7699270698367418, 0.8123932263629633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 360}], {
             RGBColor[
             0.5140568870299039, 0.6157933787663372, 0.9550478947958676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 52}], {
             RGBColor[
             0.18264284256949226`, 0.3092995861385628, 0.9337126117372361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 64}], {
             RGBColor[
             0.18504835804129488`, 0.3118279354179173, 0.933849602284714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.18699882666459755`, 0.3138780016078617, 0.9339606785873513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 115}], {
             RGBColor[
             0.18813870785962614`, 0.3150760890164789, 0.9340255931351051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 170}], {
             RGBColor[
             0.18651291707157386`, 0.3133672798171463, 0.9339330067548675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 223}], {
             RGBColor[
             0.19673773915135, 0.32411421611415436`, 0.934515295246042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 268}], {
             RGBColor[
             0.18579615740306293`, 0.3126139199603535, 0.9338921883520968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 491}], {
             RGBColor[
             0.1834588125121197, 0.3101572222837467, 0.9337590800183494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 164}], {
             RGBColor[
             0.3024600979339018, 0.4345620939070181, 0.9405606698993174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.2760199528625702, 0.4074448495073293, 0.9390303000293716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 220}], {
             RGBColor[
             0.25296409856661417`, 0.38321168481668605`, 0.9377173032352967]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 316}], {
             RGBColor[
             0.36380395841468005`, 0.4876950626233916, 0.9444694464449066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 325}], {
             RGBColor[
             0.26126519476067855`, 0.3919366632365452, 0.9381900383831774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 392}], {
             RGBColor[
             0.26287272325527145`, 0.39362627760755575`, 0.9382815847528192]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 413}], {
             RGBColor[
             0.25960242052995686`, 0.39018898209408137`, 0.9380953458505918]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 474}], {
             RGBColor[
             0.2592041913656412, 0.3897704179931982, 0.9380726672888113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 490}], {
             RGBColor[
             0.25243138864291936`, 0.38265177291112284`, 0.937686966193216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 67}], {
             RGBColor[
             0.1828839766938226, 0.30955303339202045`, 0.9337263439688908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 124}], {
             RGBColor[
             0.18513200243707828`, 0.31191585098124663`, 0.9338543657093131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 318}], {
             RGBColor[
             0.1914380372433468, 0.3185438933883344, 0.9342134850625876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 335}], {
             RGBColor[
             0.1976351524381914, 0.3250574543779134, 0.9345664016051236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 459}], {
             RGBColor[
             0.18968759946741098`, 0.31670407230166076`, 0.9341138002207887]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 29}], {
             RGBColor[
             0.18482045324878804`, 0.31158839303099417`, 0.9338366234439357]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 65}], {
             RGBColor[
             0.1841954077512366, 0.31093143058289413`, 0.9338010280275222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 86}], {
             RGBColor[
             0.18526169591288671`, 0.3120521670473626, 0.9338617515608961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 177}], {
             RGBColor[
             0.18479696914654997`, 0.31156370975056386`, 0.9338352860590549]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[
             0.1856592913664621, 0.31247006507807806`, 0.9338843940337875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 290}], {
             RGBColor[
             0.18336907213961767`, 0.31006289946237875`, 0.9337539694368944]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 297}], {
             RGBColor[
             0.19023703211735066`, 0.31728156085278936`, 0.93414508959739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 350}], {
             RGBColor[
             0.18336792975933797`, 0.3100616987482737, 0.9337539043800275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 412}], {
             RGBColor[
             0.18773360296108882`, 0.31465029808298206`, 0.9340025230104325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 484}], {
             RGBColor[
             0.1850117059565009, 0.3117894117529224, 0.933847515002707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 490}], {
             RGBColor[
             0.20058973370860944`, 0.328162906624395, 0.9347346606375627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 125}], {
             RGBColor[
             0.6268956164581168, 0.7059040511517584, 0.965190775014533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 149}], {
             RGBColor[
             0.5184855433089055, 0.6199689474225398, 0.9552362277258538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 201}], {
             RGBColor[
             0.3666465873540202, 0.4866385048510442, 0.9449259979753362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 218}], {
             RGBColor[
             0.38085905105137724`, 0.5015767053192113, 0.9457353767574448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 282}], {
             RGBColor[
             0.586277448481364, 0.6741728296188088, 0.961142335628971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 305}], {
             RGBColor[
             0.3931980637426643, 0.5143785677629451, 0.9464441881014032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 310}], {
             RGBColor[
             0.5603270606284811, 0.6539001893978842, 0.958555843487958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 406}], {
             RGBColor[
             0.44617181476977985`, 0.5602617683644892, 0.9498196286740023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 408}], {
             RGBColor[
             0.7065627960875993, 0.7690478747515729, 0.9714624707191005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 419}], {
             RGBColor[
             0.5625638978028586, 0.6556476235991, 0.9587787905130681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 432}], {
             RGBColor[
             0.38353725752998075`, 0.5043916701363219, 0.9458878966543498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 493}], {
             RGBColor[
             0.36837307735021396`, 0.48845315530283206`, 0.9450243190265064]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 46}], {
             RGBColor[
             0.19406985648437775`, 0.32131010227763557`, 0.9343633632749366]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 65}], {
             RGBColor[
             0.1838043123267574, 0.3105203644948844, 0.9337787557216719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 86}], {
             RGBColor[
             0.18487060048840748`, 0.3116411009593528, 0.9338394792550458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 177}], {
             RGBColor[
             0.18440587372207073`, 0.31115264366255413`, 0.9338130137532046]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 194}], {
             RGBColor[
             0.18526819594198288`, 0.31205899899006834`, 0.9338621217279373]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 254}], {
             RGBColor[
             0.18842942576301586`, 0.31538165196552115`, 0.9340421490896246]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 290}], {
             RGBColor[
             0.18297797671513846`, 0.309651833374369, 0.9337316971310441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 297}], {
             RGBColor[
             0.18984593669287142`, 0.3168704947647796, 0.9341228172915397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 350}], {
             RGBColor[
             0.18297683433485876`, 0.309650632660264, 0.9337316320741772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 377}], {
             RGBColor[
             0.18261049498864607`, 0.3092655867801383, 0.9337107695903608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 412}], {
             RGBColor[
             0.18734250753660958`, 0.3142392319949723, 0.9339802507045822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 426}], {
             RGBColor[
             0.18589315152803693`, 0.3127158669354839, 0.933897712024024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 476}], {
             RGBColor[
             0.18392969470854525`, 0.3106521493278456, 0.933785896062828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 31}], {
             RGBColor[
             0.185457486240386, 0.3122579550953881, 0.9338729015304014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 133}], {
             RGBColor[
             0.18845727560531045`, 0.31541092391555475`, 0.934043735096943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 191}], {
             RGBColor[
             0.18476529609045284`, 0.31153041936041803`, 0.9338334823253662]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 311}], {
             RGBColor[
             0.18445928711484194`, 0.31120878452496137`, 0.9338160555669048]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 366}], {
             RGBColor[
             0.1807454038963133, 0.3073052577884914, 0.9336045554118075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 405}], {
             RGBColor[
             0.1802965998650839, 0.3068335362958501, 0.9335789966861752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 423}], {
             RGBColor[
             0.17906694420854233`, 0.3055410902361533, 0.9335089696156476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 429}], {
             RGBColor[
             0.18544154731921458`, 0.312241202278651, 0.9338719938324201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 465}], {
             RGBColor[
             0.17899164586466354`, 0.3054619469025459, 0.9335046814863577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 469}], {
             RGBColor[
             0.18014325773351766`, 0.30667236399312137`, 0.9335702640786318]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 488}], {
             RGBColor[
             0.18073134444068237`, 0.30729048040920226`, 0.9336037547466085]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 133}], {
             RGBColor[
             0.1949807850604232, 0.3222675459672669, 0.9344152393097445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 191}], {
             RGBColor[
             0.1912888055455656, 0.31838704141213026`, 0.9342049865381675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 226}], {
             RGBColor[
             0.1894803426038117, 0.3164862321971737, 0.9341019972490159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 237}], {
             RGBColor[
             0.21243558089193113`, 0.3406136430841573, 0.9354092641102925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 311}], {
             RGBColor[
             0.1909827965699547, 0.3180654065766735, 0.9341875597797062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 366}], {
             RGBColor[
             0.18726891335142604`, 0.3141618798402035, 0.9339760596246088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 405}], {
             RGBColor[
             0.18682010932019663`, 0.3136901583475623, 0.9339505008989764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 429}], {
             RGBColor[
             0.19196505677432735`, 0.31909782433036316`, 0.9342434980452214]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 472}], {
             RGBColor[
             0.1875584213311225, 0.31446617108273056`, 0.9339925466757639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 488}], {
             RGBColor[
             0.1872548538957951, 0.31414710246091443`, 0.9339752589594097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 66}], {
             RGBColor[
             0.20877736241614875`, 0.33676862352166215`, 0.9352009339799459]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 84}], {
             RGBColor[
             0.2475939365043437, 0.3775673040012994, 0.9374114804502933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 89}], {
             RGBColor[
             0.26467695340514513`, 0.3954361451619938, 0.9383874999131978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 176}], {
             RGBColor[
             0.26830294791528575`, 0.39857679935889445`, 0.938618545077043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 179}], {
             RGBColor[
             0.20989223640499494`, 0.3379404267710331, 0.9352644244043025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 245}], {
             RGBColor[
             0.23179881460343715`, 0.36096562941487603`, 0.9365119716248255]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 255}], {
             RGBColor[
             0.20842141467182945`, 0.3363944998739921, 0.9351806632824844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 260}], {
             RGBColor[
             0.21471160984099968`, 0.34300589381819857`, 0.9355388805918587]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 299}], {
             RGBColor[
             0.22987290893586354`, 0.3589413804487841, 0.9364022941461793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 312}], {
             RGBColor[
             0.20732064752653726`, 0.335237523811622, 0.935117976221999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 328}], {
             RGBColor[
             0.23132945208889125`, 0.36047229965278604`, 0.9364852421239818]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 334}], {
             RGBColor[
             0.2032637935146371, 0.3309735130257143, 0.934886944387599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 407}], {
             RGBColor[
             0.24840100008144717`, 0.3784155789916214, 0.9374574415270658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 448}], {
             RGBColor[
             0.26012823284654724`, 0.3907416441772443, 0.938125290084152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 475}], {
             RGBColor[
             0.27810050553156784`, 0.4070629513265539, 0.9392428367847124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 478}], {
             RGBColor[
             0.23449306505329615`, 0.3637974574630227, 0.9366654052021586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 482}], {
             RGBColor[
             0.27602220405873207`, 0.40526283104925287`, 0.9391104092526332]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 76}], {
             RGBColor[
             0.3333497551271607, 0.45830089859572654`, 0.9426393717347399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 111}], {
             RGBColor[
             0.3114314409456971, 0.4393163564982453, 0.9412427561367012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 160}], {
             RGBColor[
             0.24786010554572385`, 0.3778470645398819, 0.937426638383438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 175}], {
             RGBColor[
             0.326974395016177, 0.4527788821025087, 0.9422331394259775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 182}], {
             RGBColor[
             0.300634259036329, 0.42996438021049266`, 0.9405547692530093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 237}], {
             RGBColor[
             0.24458077131553108`, 0.3744002763421501, 0.9372398851503687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 241}], {
             RGBColor[
             0.2359506605232252, 0.3653294827188087, 0.9367484131078517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 274}], {
             RGBColor[
             0.25017787666220814`, 0.38028318893848334`, 0.9375586320196867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 351}], {
             RGBColor[
             0.24823088148452888`, 0.3782367735601183, 0.937447753524639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 371}], {
             RGBColor[
             0.2551767869971113, 0.385537360649688, 0.9378433125680343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 432}], {
             RGBColor[
             0.27375220804932543`, 0.40506130592528333`, 0.9389011553170851]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 460}], {
             RGBColor[
             0.27847248938800495`, 0.41002262089535824`, 0.9391699683562924]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 463}], {
             RGBColor[
             0.4057152506945697, 0.5182150283519088, 0.9480144771137997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 44}], {
             RGBColor[
             0.24396970740458573`, 0.37375800942805687`, 0.9372050859646285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 62}], {
             RGBColor[
             0.23006104796724536`, 0.35913912649947, 0.9364130083856896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 190}], {
             RGBColor[
             0.2127364473424475, 0.3409298727996848, 0.9354263980095573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 291}], {
             RGBColor[
             0.19600418397695138`, 0.323343203115777, 0.9344735203640577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 356}], {
             RGBColor[
             0.22712257342383618`, 0.3560506034443001, 0.9362456666075261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 394}], {
             RGBColor[
             0.19619166312976455`, 0.3235402555922485, 0.9344841970244598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 467}], {
             RGBColor[
             0.20003782336254744`, 0.32758281385754684`, 0.9347032301598326]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.18328807136271902`, 0.3099777625101124, 0.9337493565624799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 123}], {
             RGBColor[
             0.18674780810963457`, 0.3136141651911, 0.933946383451995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 193}], {
             RGBColor[
             0.1842865051954063, 0.311027179772628, 0.9338062158922009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 347}], {
             RGBColor[
             0.19536292222488982`, 0.32266919635601693`, 0.9344370014559396]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 410}], {
             RGBColor[
             0.18494866329979062`, 0.31172314992358463`, 0.9338439248166706]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 422}], {
             RGBColor[
             0.19709463641182273`, 0.32448933776350447`, 0.9345356200170438]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 428}], {
             RGBColor[
             0.18771159390474457`, 0.31462716516930944`, 0.9340012696272331]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 437}], {
             RGBColor[
             0.18478436843582058`, 0.31155046560465605`, 0.9338345684672199]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 75}], {
             RGBColor[
             0.929724921483118, 0.7365825483050892, 0.4781251750142107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 76}], {
             RGBColor[
             0.7022798190159381, 0.7608775969992009, 0.8471463932234504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 104}], {
             RGBColor[
             0.9591316136436914, 0.8643779170894872, 0.5023662490620132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 112}], {
             RGBColor[
             0.993786491132969, 0.9916985686506579, 0.7526374521795876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 266}], {
             RGBColor[
             0.9938574384892986, 0.9902625241719002, 0.644943793687154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 359}], {
             RGBColor[
             0.9518288028476951, 0.9612683407754878, 0.8690761481825573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 379}], {
             RGBColor[
             0.9107780137599082, 0.6018218600251894, 0.4604073756146171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 408}], {
             RGBColor[
             0.9657078104957213, 0.9722942089440085, 0.8689827508705463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 440}], {
             RGBColor[
             0.9428820049759663, 0.7963257915311912, 0.48910376799027133`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 463}], {
             RGBColor[
             0.7746453145833472, 0.820791726755383, 0.8525214986025103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 49}], {
             RGBColor[
             0.9278898442559633, 0.7275054583426774, 0.39329233295696453`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 53}], {
             RGBColor[
             0.8472647112443593, 0.3588769520067575, 0.19268158199931773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 97}], {
             RGBColor[
             0.9251557778239836, 0.7191603787632175, 0.30804891163954246`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 100}], {
             RGBColor[
             0.9275408237580072, 0.7267589387889348, 0.3553036056592853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 203}], {
             RGBColor[
             0.8534629031399862, 0.4065189709815528, 0.1986169775584265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 207}], {
             RGBColor[
             0.8684208855066446, 0.4954117968161807, 0.21191950037856397`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 257}], {
             RGBColor[
             0.9124536887252621, 0.6763132496408797, 0.2587036940792628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 264}], {
             RGBColor[
             0.8636993298194549, 0.4739723151879993, 0.20797971857725228`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 281}], {
             RGBColor[
             0.8401393429256434, 0.30410824875280007`, 0.18585832125036283`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 317}], {
             RGBColor[
             0.839586880193451, 0.2998617781024568, 0.18532928231409804`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 322}], {
             RGBColor[
             0.8413185031158885, 0.3131717906863145, 0.18698748638021256`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 324}], {
             RGBColor[
             0.9007937640631225, 0.7100849667901136, 0.5966707240103046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 343}], {
             RGBColor[
             0.8540426861772787, 0.4109754374687308, 0.1991721784497092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 374}], {
             RGBColor[
             0.8546495293295531, 0.4156398998574755, 0.19975329213765833`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 397}], {
             RGBColor[
             0.8419322626018511, 0.3178894150465442, 0.18757522315711248`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 445}], {
             RGBColor[
             0.9124867892485535, 0.6764249054783144, 0.25883228336174086`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 77}], {
             RGBColor[
             0.4266438929830485, 0.5421807004439456, 0.9488977622771873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 79}], {
             RGBColor[
             0.7025334025034438, 0.7661868171424233, 0.9721373827063131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 87}], {
             RGBColor[
             0.4136160612646935, 0.5308657922292461, 0.9480687701193717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 127}], {
             RGBColor[
             0.6754853554676021, 0.7446194386357212, 0.969557515833958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 184}], {
             RGBColor[
             0.5298276783437619, 0.6291770036011967, 0.9561291221434074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 221}], {
             RGBColor[
             0.7405475305032172, 0.7523239641423858, 0.6316046509416242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 253}], {
             RGBColor[
             0.4481561698945121, 0.5608135534661793, 0.9502685055394262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 287}], {
             RGBColor[
             0.4114868433754372, 0.5286278492274263, 0.9479475143104742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 301}], {
             RGBColor[
             0.5876340036038425, 0.6758909546392042, 0.9608274105699129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 316}], {
             RGBColor[
             0.4787664530256467, 0.5873266421968035, 0.9522189657129314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 336}], {
             RGBColor[
             0.5720852226715933, 0.663483581767208, 0.9594557908273795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 354}], {
             RGBColor[
             0.4147037910637674, 0.5318387842884362, 0.9481369495411083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 388}], {
             RGBColor[
             0.42375389748919434`, 0.5396775316025662, 0.9487136143198416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 436}], {
             RGBColor[
             0.4371703671484145, 0.5512982032900106, 0.9495684999028087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 473}], {
             RGBColor[
             0.39120686649721753`, 0.5073123077036177, 0.9467925996287968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 62}], {
             RGBColor[
             0.2493920758689453, 0.37945726248211625`, 0.9375138818269986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 96}], {
             RGBColor[
             0.359182658449612, 0.4793995184819319, 0.94444576944529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 108}], {
             RGBColor[
             0.22860230621824829`, 0.3576058964317052, 0.9363299352010993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 113}], {
             RGBColor[
             0.2221538791632596, 0.3508281907430225, 0.9359627068199107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 157}], {
             RGBColor[
             0.2733433157427147, 0.4046315341857658, 0.9388778695051255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 190}], {
             RGBColor[
             0.23206747524414745`, 0.361248008782331, 0.9365272714508661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 378}], {
             RGBColor[
             0.22727756338581306`, 0.356213507721269, 0.9362544930565735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 161}], {
             RGBColor[
             0.19942966903054987`, 0.32694360509540565`, 0.9346685966703091]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 183}], {
             RGBColor[
             0.19098677743240255`, 0.31806959071550744`, 0.9341877864839334]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 202}], {
             RGBColor[
             0.18588447811869105`, 0.31270675063233544`, 0.933897218086193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 206}], {
             RGBColor[
             0.18271148860033518`, 0.3093717374693884, 0.9337165210271399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 243}], {
             RGBColor[
             0.19079403389915217`, 0.3178670050414155, 0.9341768100248533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 273}], {
             RGBColor[
             0.18608375256856824`, 0.31291620071388626`, 0.9339085664713134]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 283}], {
             RGBColor[
             0.18366308451827268`, 0.3103719251138067, 0.9337707130069065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 285}], {
             RGBColor[
             0.19969824891224597`, 0.32722589958001636`, 0.9346838918972433]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 396}], {
             RGBColor[
             0.19122359622902446`, 0.31831850228593606`, 0.934201272964059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 421}], {
             RGBColor[
             0.18467273781712776`, 0.31143313474661993`, 0.933828211268628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 430}], {
             RGBColor[
             0.1932824749084014, 0.32048251431840913`, 0.9343185230590114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 477}], {
             RGBColor[
             0.19140125749096676`, 0.31850523553661203`, 0.9342113905101004]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 44}], {
             RGBColor[
             0.27104906144274005`, 0.40222012745236824`, 0.938747215116787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 56}], {
             RGBColor[
             0.33496751620801646`, 0.46033233124806494`, 0.9427193789900982]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.26751337219857585`, 0.3985038938811058, 0.9385458628449154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 132}], {
             RGBColor[
             0.2677010857798615, 0.3987011927567655, 0.9385565528556723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.2413646105317827, 0.37101988744205927`, 0.9370567295516178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 356}], {
             RGBColor[
             0.25420192746199044`, 0.3845127214686115, 0.9377877957596846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 365}], {
             RGBColor[
             0.23506566561189032`, 0.36439929695507756`, 0.9366980139568839]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 457}], {
             RGBColor[
             0.36616941470913866`, 0.48692522378917524`, 0.9448270715857057]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 485}], {
             RGBColor[
             0.2592162515913262, 0.38978309405505573`, 0.9380733541008225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 494}], {
             RGBColor[
             0.3091950820990577, 0.43800954418308746`, 0.9410771822783439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 108}], {
             RGBColor[
             0.2050818952093152, 0.3328844531811263, 0.9349904825894705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 113}], {
             RGBColor[
             0.1986334681543265, 0.3261067474924436, 0.9346232542082819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 119}], {
             RGBColor[
             0.1924345707120309, 0.31959131324779266`, 0.9342702361693901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 315}], {
             RGBColor[
             0.19198004367677265`, 0.3191135765150577, 0.9342443515271446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 364}], {
             RGBColor[
             0.2024710281446618, 0.33014026635764265`, 0.9348417975725702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 378}], {
             RGBColor[
             0.20375715237687997`, 0.3314920644706901, 0.9349150404449447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 380}], {
             RGBColor[
             0.19400957405079025`, 0.3212467416178081, 0.9343599302795238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 381}], {
             RGBColor[
             0.19442462278648562`, 0.3216829841546337, 0.9343835666910121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 416}], {
             RGBColor[
             0.20488956233917005`, 0.3326822991399955, 0.9349795295170467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 452}], {
             RGBColor[
             0.21367924169687297`, 0.3419208094428005, 0.9354800887533026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 468}], {
             RGBColor[
             0.21102583019430793`, 0.33913190571759855`, 0.9353289808936021]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 487}], {
             RGBColor[
             0.19664512493327133`, 0.3240168726988731, 0.934510021003333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[
             0.24535980769453214`, 0.3752190929702395, 0.9372842501196719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 137}], {
             RGBColor[
             0.220012218727478, 0.34857716983590165`, 0.9358407424263956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 148}], {
             RGBColor[
             0.2515020287225457, 0.38167495670998786`, 0.9376340405206155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 156}], {
             RGBColor[
             0.21388174499134507`, 0.34213365324474115`, 0.935491621016346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 227}], {
             RGBColor[
             0.21076377490674741`, 0.3388564689951076, 0.9353140572326515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 229}], {
             RGBColor[
             0.231604699752685, 0.3607616023991431, 0.9365009170712423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 250}], {
             RGBColor[
             0.22400512105631526`, 0.3527739633481394, 0.9360681323070532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 263}], {
             RGBColor[
             0.2263534256582619, 0.35524218037589655`, 0.9362018647801287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 267}], {
             RGBColor[
             0.22881279968486046`, 0.35782713841117125`, 0.9363419224926257]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 393}], {
             RGBColor[
             0.2248422553763207, 0.3536538445958466, 0.9361158058681482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 485}], {
             RGBColor[
             0.24185676211585877`, 0.3715371699611359, 0.9370847568562579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 56}], {
             RGBColor[
             0.342928946455201, 0.46870029922168843`, 0.9431727706647948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 62}], {
             RGBColor[
             0.2651018322525842, 0.3959692124974049, 0.9384085292125448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 92}], {
             RGBColor[
             0.2754748024457604, 0.40687186185472934`, 0.938999254519612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 110}], {
             RGBColor[
             0.34804321230268565`, 0.4731300192483041, 0.9434986471622288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 132}], {
             RGBColor[
             0.27566251602704606`, 0.4070691607303891, 0.9390099445303688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 157}], {
             RGBColor[
             0.2890530721263536, 0.4211434842010545, 0.9397725168906719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 356}], {
             RGBColor[
             0.262163357709175, 0.39288068944223503`, 0.9382411874343812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 360}], {
             RGBColor[
             0.4375870349530485, 0.5468097854709225, 0.9502759669846275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 365}], {
             RGBColor[
             0.24302709585907487`, 0.37276726492870105`, 0.9371514056315804]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 457}], {
             RGBColor[
             0.3741308449563232, 0.49529319176279873`, 0.9452804632604023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 494}], {
             RGBColor[
             0.31715651234624226`, 0.44637751215671095`, 0.9415305739530406]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 118}], {
             RGBColor[
             0.1966941864369604, 0.3240684394499293, 0.9345128149833881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 152}], {
             RGBColor[
             0.1927063751242849, 0.3198769969184667, 0.9342857150285693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 185}], {
             RGBColor[
             0.2063591315326575, 0.33422690953841927`, 0.935063219308583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 187}], {
             RGBColor[
             0.21121178851668337`, 0.3393273597048538, 0.9353395709449606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 195}], {
             RGBColor[
             0.19463609510811763`, 0.32190525497278855`, 0.9343956097268837]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 216}], {
             RGBColor[
             0.20054621348510776`, 0.32811716411015324`, 0.9347321822252167]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 217}], {
             RGBColor[
             0.19120987418842403`, 0.31830407955123735`, 0.9342004915141469]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 224}], {
             RGBColor[
             0.20355580866569664`, 0.3312804394643078, 0.9349035742184542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 292}], {
             RGBColor[
             0.193148625604734, 0.3203418302137187, 0.93431090053918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 328}], {
             RGBColor[
             0.22208190708084125`, 0.3507525435211073, 0.9359586081162901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 398}], {
             RGBColor[
             0.20371823459922628`, 0.33145115941884645`, 0.934912824135081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 399}], {
             RGBColor[
             0.20452814783915604`, 0.33230242958547795`, 0.9349589474959358]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 464}], {
             RGBColor[
             0.2018156680778671, 0.3294514413752133, 0.9348044757862846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 481}], {
             RGBColor[
             0.20322304481879772`, 0.33093068356277056`, 0.9348846238096533]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 496}], {
             RGBColor[
             0.19349628938952101`, 0.32070724689468694`, 0.9343306994774011]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 86}], {
             RGBColor[
             0.19451109914847642`, 0.321773876294004, 0.9343884913918972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 142}], {
             RGBColor[
             0.2097115161750654, 0.33775047835105276`, 0.9352541326545596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 150}], {
             RGBColor[
             0.2095354252082916, 0.3375653955801614, 0.935244104534505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 194}], {
             RGBColor[
             0.19490869460205182`, 0.32219177432471957`, 0.9344111338647885]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 220}], {
             RGBColor[
             0.21037184686789395`, 0.33844452777659967`, 0.9352917375106444]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 254}], {
             RGBColor[
             0.1980699244230848, 0.3255144273001723, 0.9345911612264759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 297}], {
             RGBColor[
             0.19948643535294036`, 0.32700327009943075`, 0.934671829428391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 325}], {
             RGBColor[
             0.2186729430619583, 0.3471695061964588, 0.935764472658525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 350}], {
             RGBColor[
             0.1926173329949277, 0.3197834079949152, 0.9342806442110285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 377}], {
             RGBColor[
             0.192250993648715, 0.31939836211478956`, 0.9342597817272121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 392}], {
             RGBColor[
             0.22028047155655125`, 0.34885912056746937`, 0.9358560190281668]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 412}], {
             RGBColor[
             0.19698300619667852`, 0.32437200732962346`, 0.9345292628414335]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 426}], {
             RGBColor[
             0.19553365018810587`, 0.3228486422701351, 0.9344467241608754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 476}], {
             RGBColor[
             0.1935701933686142, 0.32078492466249675`, 0.9343349081996792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 55}], {
             RGBColor[
             0.42760134170853215`, 0.539013813149998, 0.94946155992206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 59}], {
             RGBColor[
             0.272302702026903, 0.4035377831917274, 0.9388186080934602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 73}], {
             RGBColor[
             0.42925393472115597`, 0.5403554626061129, 0.9495916580976614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 91}], {
             RGBColor[
             0.37096684027433213`, 0.4930353735304999, 0.9450030845101454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 136}], {
             RGBColor[
             0.40491583995544145`, 0.5205967008566313, 0.9476756741243257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 200}], {
             RGBColor[
             0.2722924613184966, 0.40352701955789383`, 0.9388180249002662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 228}], {
             RGBColor[
             0.2699130817435731, 0.4010261407632708, 0.9386825227534509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 256}], {
             RGBColor[
             0.2965835068490444, 0.4287985034009982, 0.9402108818731908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 298}], {
             RGBColor[
             0.2786489927595025, 0.4102081371297621, 0.9391800199621858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 416}], {
             RGBColor[
             0.24541922577751857`, 0.3752815451427822, 0.9372876338915967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 452}], {
             RGBColor[
             0.2542089051352215, 0.3845200554455873, 0.9377881931278527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 468}], {
             RGBColor[
             0.25155549363265645`, 0.38173115172038535`, 0.9376370852681521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 117}], {
             RGBColor[
             0.18672352451245816`, 0.31358864159079863`, 0.9339450005370601]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 140}], {
             RGBColor[
             0.1844487281323768, 0.3111976863649123, 0.9338154542484741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 155}], {
             RGBColor[
             0.1919029748142661, 0.3190325722541152, 0.934239962569438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 156}], {
             RGBColor[
             0.19463895940372045`, 0.3219082655290739, 0.9343957728442809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 198}], {
             RGBColor[
             0.18614733394130184`, 0.3129830287679211, 0.9339121873364302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 250}], {
             RGBColor[
             0.20476233546869063`, 0.33254857563247214`, 0.9349722841349881]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 365}], {
             RGBColor[
             0.19846339054879825`, 0.32592798514549043`, 0.9346135685402542]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 479}], {
             RGBColor[
             0.18610061058204452`, 0.31293391955490957`, 0.9339095265102416]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 51}], {
             RGBColor[
             0.9945887098983145, 0.9908341225748765, 0.6523926509220856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 100}], {
             RGBColor[
             0.9935759076270685, 0.9886678409266986, 0.5421553739880537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 203}], {
             RGBColor[
             0.9194979870090474, 0.6684278731193166, 0.38546874588719493`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 264}], {
             RGBColor[
             0.9297344136885161, 0.7358812173257631, 0.3948314869060207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 324}], {
             RGBColor[
             0.9668288479321837, 0.9719938689278773, 0.783522492339073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 360}], {
             RGBColor[
             0.7950442531705986, 0.8362229179981473, 0.7707477142317521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 397}], {
             RGBColor[
             0.9079673464709124, 0.579798317184308, 0.3744269914858809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 457}], {
             RGBColor[
             0.7315880631738731, 0.7847063242900234, 0.765752210507527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 82}], {
             RGBColor[
             0.7002427375322327, 0.764369726655832, 0.9719080506652522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 126}], {
             RGBColor[
             0.6844097961772514, 0.7515158315979785, 0.9706616235238129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 131}], {
             RGBColor[
             0.8570462990670573, 0.5838526913273292, 0.5841917648474512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 173}], {
             RGBColor[
             0.800480264278042, 0.8445485570290475, 0.9806185434355512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 242}], {
             RGBColor[
             0.9267381119467066, 0.943455029677774, 0.9594240314227456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 323}], {
             RGBColor[
             0.9365367216162789, 0.9493476478675402, 0.8794633883159441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 340}], {
             RGBColor[
             0.6220781556562913, 0.698481383789535, 0.9664262896114366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 373}], {
             RGBColor[
             0.9356814566362912, 0.9489939738190079, 0.8936373423891573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 414}], {
             RGBColor[
             0.6515149605889788, 0.7239780646853934, 0.9683019767918029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 449}], {
             RGBColor[
             0.9319849870644814, 0.931902676711367, 0.6896331946772748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 499}], {
             RGBColor[
             0.7544680909250315, 0.8083923113644382, 0.9761768691183477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 60}], {
             RGBColor[
             0.9903726876472161, 0.9902614167392676, 0.8073625961746422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 96}], {
             RGBColor[
             0.7330134148240908, 0.7867443631188805, 0.8380607137143137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 100}], {
             RGBColor[
             0.9942396894003585, 0.9900876030211339, 0.6144039236244064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 110}], {
             RGBColor[
             0.7061642122935256, 0.763962913869964, 0.8362189440457062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 203}], {
             RGBColor[
             0.9201617687823374, 0.6698476352137519, 0.4577172955235477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 240}], {
             RGBColor[
             0.995029239647029, 0.991776371162987, 0.7003415954352006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 264}], {
             RGBColor[
             0.930398195461806, 0.7373009794201983, 0.46708003654237346`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 324}], {
             RGBColor[
             0.9674926297054737, 0.9734136310223126, 0.8557710419754258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 360}], {
             RGBColor[
             0.7957080349438885, 0.8376426800925825, 0.8429962638681049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 397}], {
             RGBColor[
             0.9086311282442023, 0.5812180792787432, 0.4466755411222336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 457}], {
             RGBColor[
             0.7322518449471631, 0.7861260863844587, 0.8380007601438797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 495}], {
             RGBColor[
             0.9406722816777016, 0.7839532053527796, 0.47565298592181493`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 170}], {
             RGBColor[
             0.1838649636445791, 0.31058411287543064`, 0.9337822097244962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 214}], {
             RGBColor[
             0.18377002501748835`, 0.3104843263589016, 0.9337768031101326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 268}], {
             RGBColor[
             0.18314820397606815`, 0.30983075301863783`, 0.9337413913217254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 466}], {
             RGBColor[
             0.18744056730247904`, 0.3143422990262493, 0.933985835063182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 491}], {
             RGBColor[
             0.18081085908512495`, 0.30737405534203105`, 0.9336082829879782]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 83}], {
             RGBColor[
             0.9139507635332944, 0.6222257740273145, 0.45384466479453006`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 97}], {
             RGBColor[
             0.910565728681441, 0.6124407745650613, 0.29428992901066414`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 112}], {
             RGBColor[
             0.9130580700237505, 0.6218566223199413, 0.468638906464419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 163}], {
             RGBColor[
             0.8659915986516313, 0.4439113739475036, 0.20830775588996076`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 207}], {
             RGBColor[
             0.8538308363641018, 0.3886921926180247, 0.19816051774968563`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 257}], {
             RGBColor[
             0.8978636395827194, 0.5695936454427237, 0.2449447114503845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 266}], {
             RGBColor[
             0.9131290173800801, 0.6204205778411838, 0.36094524797198546`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 281}], {
             RGBColor[
             0.8255492937831006, 0.19738864455464403`, 0.17209933862148452`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[
             0.8212117750972121, 0.5517293002984074, 0.5802972295340347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 317}], {
             RGBColor[
             0.8249968310509084, 0.19314217390430075`, 0.1715702996852197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 322}], {
             RGBColor[
             0.8267284539733458, 0.20645218648815844`, 0.17322850375133425`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 343}], {
             RGBColor[
             0.8394526370347362, 0.3042558332705747, 0.18541319582083088`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 374}], {
             RGBColor[
             0.8400594801870103, 0.30892029565931944`, 0.18599430950878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 440}], {
             RGBColor[
             0.8621535838667478, 0.42648384520047466`, 0.20510522227510283`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 445}], {
             RGBColor[
             0.897896740106011, 0.5697053012801583, 0.24507330073286251`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 471}], {
             RGBColor[
             0.8947556642863255, 0.6097433924263989, 0.5684355218108367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 61}], {
             RGBColor[
             0.9898922626687403, 0.9900882051035927, 0.8171748957720661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 99}], {
             RGBColor[
             0.9846117057177595, 0.9871579291878583, 0.8712517771624386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 154}], {
             RGBColor[
             0.9864962902894889, 0.9885634492757301, 0.8680616670608778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 186}], {
             RGBColor[
             0.9914243588005289, 0.9890319585828893, 0.6689529207083693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 203}], {
             RGBColor[
             0.9172982685013698, 0.6686889606982549, 0.5070233200844496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 244}], {
             RGBColor[
             0.7181235795673231, 0.775643062211419, 0.8864694686198505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 264}], {
             RGBColor[
             0.9275346951808384, 0.7361423049047013, 0.5163860611032753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 295}], {
             RGBColor[
             0.9871607004637972, 0.988958633933902, 0.862443950564356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 321}], {
             RGBColor[
             0.9874803221287802, 0.9890908057062746, 0.8571469924212342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 341}], {
             RGBColor[
             0.991911410491914, 0.9900737129022821, 0.7219654915810148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 374}], {
             RGBColor[
             0.9184848946909366, 0.6778098895741775, 0.5081596346636814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 391}], {
             RGBColor[
             0.731320111432247, 0.7865357071547434, 0.8874588604609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 397}], {
             RGBColor[
             0.9057676279632347, 0.5800594047632462, 0.4959815656831355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 455}], {
             RGBColor[
             0.8012850501089904, 0.8433363962570924, 0.8929667567235482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 57}], {
             RGBColor[
             0.7681170081630603, 0.818182994087395, 0.9538490180959958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 60}], {
             RGBColor[
             0.7795430416292072, 0.8264883871046946, 0.9248292480443663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 73}], {
             RGBColor[
             0.5752457926482104, 0.6660494748562806, 0.9597046024734881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 91}], {
             RGBColor[
             0.5169586982013866, 0.6187293857806677, 0.955116028885972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 136}], {
             RGBColor[
             0.5509076978824959, 0.6462907131067992, 0.9577886185001523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 200}], {
             RGBColor[
             0.4182843192455511, 0.5292210318080617, 0.9489309692760928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 256}], {
             RGBColor[
             0.4425753647760989, 0.554492515651166, 0.9503238262490175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 298}], {
             RGBColor[
             0.424640850686557, 0.5359021493799299, 0.9492929643380126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 434}], {
             RGBColor[
             0.7543365484938672, 0.7225141411414309, 0.6130982348590022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 92}], {
             RGBColor[
             0.33939325721103675`, 0.46498406565042605`, 0.9429714183929231]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 110}], {
             RGBColor[
             0.41196166706796206`, 0.5312422230440008, 0.9474708110355399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 132}], {
             RGBColor[
             0.3395809707923225, 0.46518136452608577`, 0.94298210840368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 324}], {
             RGBColor[
             0.6732900844799101, 0.7406929401963493, 0.9670229089652596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 342}], {
             RGBColor[
             0.4415801835206408, 0.5562719260910596, 0.9495305912404275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 360}], {
             RGBColor[
             0.501505489718325, 0.6049219892666192, 0.9542481308579387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 457}], {
             RGBColor[
             0.4380492997215996, 0.5534053955584954, 0.9492526271337134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 494}], {
             RGBColor[
             0.38107496711151867`, 0.5044897159524077, 0.9455027378263516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 60}], {
             RGBColor[
             0.9740668501566808, 0.9799635557919238, 0.9191037618424754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 73}], {
             RGBColor[
             0.769769601175684, 0.81952464354351, 0.9539791162715971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 91}], {
             RGBColor[
             0.7114825067288603, 0.7722045544678969, 0.9493905426840812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 131}], {
             RGBColor[
             0.8981850447320697, 0.6159608551699692, 0.564028013817431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 136}], {
             RGBColor[
             0.7454315064099696, 0.7997658817940283, 0.9520631322982614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 234}], {
             RGBColor[
             0.9445095586663342, 0.8587398441686642, 0.6038719941743098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 240}], {
             RGBColor[
             0.9787234021564939, 0.9814785102156434, 0.8120827611030339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 434}], {
             RGBColor[
             0.9488603570213409, 0.87598930982866, 0.6073727486571113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 495}], {
             RGBColor[
             0.9243664441871663, 0.7736553444054359, 0.5873941515896481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 74}], {
             RGBColor[
             0.19093718319717995`, 0.31801746402983233`, 0.9341849621656055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 115}], {
             RGBColor[
             0.19207706439220854`, 0.3192155514384495, 0.9342498767133594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 144}], {
             RGBColor[
             0.1950230989335921, 0.322312020530822, 0.9344176490222236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 145}], {
             RGBColor[
             0.20110599109187893`, 0.32870552586681995`, 0.9347640607318055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 215}], {
             RGBColor[
             0.1890650982052305, 0.3160497840062494, 0.9340783496948156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 375}], {
             RGBColor[
             0.19795511773261765`, 0.3253937581893268, 0.934584623155295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 402}], {
             RGBColor[
             0.20564836608822273`, 0.3334798499911863, 0.9350227422680057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 417}], {
             RGBColor[
             0.19514933346569613`, 0.3224447010277949, 0.9344248378920796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 87}], {
             RGBColor[
             0.28570409751894754`, 0.41762349955141664`, 0.939581797741144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 91}], {
             RGBColor[
             0.36166005851975747`, 0.48325335582239703`, 0.9444730770573722]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 188}], {
             RGBColor[
             0.24348630056862833`, 0.373249918193702, 0.937177556660457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 200}], {
             RGBColor[
             0.26298567956392194`, 0.393745001849791, 0.9382880174474929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 228}], {
             RGBColor[
             0.26060629998899837`, 0.391244123055168, 0.9381525153006776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 256}], {
             RGBColor[
             0.28727672509446966`, 0.4190164856928953, 0.9396808744204175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 279}], {
             RGBColor[
             0.23548934775412372`, 0.36484461374956423`, 0.9367221420281024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 287}], {
             RGBColor[
             0.28357487962969113`, 0.41538555654959675`, 0.9394605419322465]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 298}], {
             RGBColor[
             0.2693422110049278, 0.4004261194216593, 0.9386500125094126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 335}], {
             RGBColor[
             0.2366854990874992, 0.3661018446413167, 0.9367902610769909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 409}], {
             RGBColor[
             0.2581147666270732, 0.38862536351944543`, 0.9380106261616092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 468}], {
             RGBColor[
             0.24224871187808175`, 0.37194913401228247`, 0.9371070778153788]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 73}], {
             RGBColor[
             0.781195634641831, 0.8278300365608096, 0.9249593462199677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 131}], {
             RGBColor[
             0.9096110781982166, 0.6242662481872688, 0.5350082437658015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.7568575398761165, 0.8080712748113279, 0.923043362246632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 240}], {
             RGBColor[
             0.9901494356226408, 0.989783903232943, 0.7830629910514044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 434}], {
             RGBColor[
             0.9602863904874878, 0.8842947028459596, 0.5783529786054818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 495}], {
             RGBColor[
             0.9357924776533132, 0.7819607374227355, 0.5583743815380187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 99}], {
             RGBColor[
             0.9849784772768306, 0.9873095986531333, 0.8651734232542627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 154}], {
             RGBColor[
             0.9868630618485601, 0.9887151187410052, 0.8619833131527019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 178}], {
             RGBColor[
             0.7297842099398613, 0.7851427009224017, 0.8812307211603922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 186}], {
             RGBColor[
             0.9917911303595999, 0.9891836280481643, 0.6628745668001933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 203}], {
             RGBColor[
             0.9176650400604409, 0.6688406301635299, 0.5009449661762736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 244}], {
             RGBColor[
             0.7184903511263943, 0.775794731676694, 0.8803911147116745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 264}], {
             RGBColor[
             0.9279014667399095, 0.7362939743699763, 0.5103077071950994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 288}], {
             RGBColor[
             0.8507412174209339, 0.8822861338586991, 0.8914741508713435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 295}], {
             RGBColor[
             0.9875274720228682, 0.989110303399177, 0.8563655966561801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 321}], {
             RGBColor[
             0.9878470936878512, 0.9892424751715496, 0.8510686385130581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 341}], {
             RGBColor[
             0.992278182050985, 0.9902253823675571, 0.7158871376728388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 391}], {
             RGBColor[
             0.731686882991318, 0.7866873766200184, 0.8813805065527239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 397}], {
             RGBColor[
             0.9061343995223057, 0.5802110742285213, 0.48990321177495955`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 455}], {
             RGBColor[
             0.8016518216680615, 0.8434880657223675, 0.8868884028153723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 96}], {
             RGBColor[
             0.36098375539591054`, 0.48129258556863375`, 0.9445483392518976]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 108}], {
             RGBColor[
             0.2304034031645468, 0.35949896351840704`, 0.9364325050077069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 110}], {
             RGBColor[
             0.33413455286534527`, 0.45851113631971724`, 0.9427065695832899]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 157}], {
             RGBColor[
             0.27514441268901324`, 0.40652460127246764`, 0.9389804393117331]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 190}], {
             RGBColor[
             0.233868572190446, 0.3631410758690329, 0.9366298412574736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 356}], {
             RGBColor[
             0.24825469827183463`, 0.37826180651364816`, 0.9374491098554425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 378}], {
             RGBColor[
             0.22907866033211158`, 0.3581065748079708, 0.9363570628631811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 72}], {
             RGBColor[
             0.20896361604647165`, 0.3369643878962938, 0.9352115408486552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 159}], {
             RGBColor[
             0.2194636807819041, 0.34800062167578893`, 0.9358095040018843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 166}], {
             RGBColor[
             0.20124645730453306`, 0.3288531647623917, 0.9347720600748151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 222}], {
             RGBColor[
             0.20195670404025598`, 0.32959967911388044`, 0.9348125075756986]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 239}], {
             RGBColor[
             0.20172774579693858`, 0.3293590294833628, 0.934799468742455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 272}], {
             RGBColor[
             0.23201898916873956`, 0.36119704684288256`, 0.9365245102406003]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 344}], {
             RGBColor[
             0.19854348560024537`, 0.326012170122881, 0.9346181298349442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 387}], {
             RGBColor[
             0.1978509608116646, 0.3252842826614749, 0.9345786915727331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 435}], {
             RGBColor[
             0.22260483335872017`, 0.351302172194599, 0.9359883879942152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 439}], {
             RGBColor[
             0.20302072388459882`, 0.33071803143303935`, 0.9348731019317575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 453}], {
             RGBColor[
             0.2233707740920417, 0.35210722446876735`, 0.9360320071858701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 74}], {
             RGBColor[
             0.1867563887094054, 0.3136231839455006, 0.933946872104458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 115}], {
             RGBColor[
             0.18789626990443398`, 0.31482127135411775`, 0.9340117866522119]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 170}], {
             RGBColor[
             0.18627047911638173`, 0.31311246215478516`, 0.9339192002719742]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 215}], {
             RGBColor[
             0.18488430371745596`, 0.31165550392191765`, 0.9338402596336681]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 223}], {
             RGBColor[
             0.19649530119615788`, 0.32385939845179323`, 0.9345014887631486]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 268}], {
             RGBColor[
             0.18555371944787077`, 0.31235910229799235`, 0.9338783818692034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 86}], {
             RGBColor[
             0.18424555499085607`, 0.31098413851125284`, 0.9338038838386322]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 177}], {
             RGBColor[
             0.18378082822451933`, 0.3104956812144541, 0.9337774183367911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 194}], {
             RGBColor[
             0.18464315044443147`, 0.3114020365419683, 0.9338265263115236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 290}], {
             RGBColor[
             0.18235293121758706`, 0.308994870926269, 0.9336961017146306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 297}], {
             RGBColor[
             0.18922089119532, 0.3162135323166796, 0.9340872218751262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 350}], {
             RGBColor[
             0.18235178883730735`, 0.30899367021216395`, 0.9336960366577636]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 412}], {
             RGBColor[
             0.1867174620390582, 0.3135822695468723, 0.9339446552881686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 484}], {
             RGBColor[
             0.1839955650344703, 0.31072138321681264`, 0.9337896472804431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 114}], {
             RGBColor[
             0.1896583133560848, 0.31667329074181017`, 0.9341121324200736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 128}], {
             RGBColor[
             0.19606919376904863`, 0.32341153252913013`, 0.9344772225755442]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 179}], {
             RGBColor[
             0.19899718509969622`, 0.32648903706301347`, 0.9346439673502496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 245}], {
             RGBColor[
             0.22090376329813846`, 0.34951423970685647`, 0.9358915145707727]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 255}], {
             RGBColor[
             0.19752636336653073`, 0.32494311016597255`, 0.9345602062284316]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 260}], {
             RGBColor[
             0.203816558535701, 0.331554504110179, 0.9349184235378061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 294}], {
             RGBColor[
             0.19268716813915449`, 0.3198568091593014, 0.9342846212191803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 299}], {
             RGBColor[
             0.21897785763056482`, 0.34748999074076453`, 0.9357818370921265]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 312}], {
             RGBColor[
             0.19642559622123856`, 0.32378613410360235`, 0.9344975191679463]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 327}], {
             RGBColor[
             0.19083074135934272`, 0.31790558690946313`, 0.9341789004604073]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 334}], {
             RGBColor[
             0.19236874220933842`, 0.3195221233176947, 0.9342664873335462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 385}], {
             RGBColor[
             0.189718897172314, 0.31673696817390284`, 0.9341155825787821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 415}], {
             RGBColor[
             0.1891407128871262, 0.3161292598311696, 0.9340826558390877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 446}], {
             RGBColor[
             0.19064470762485328`, 0.3177100536592947, 0.9341683061144403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 119}], {
             RGBColor[
             0.18259585546660687`, 0.3092501997142758, 0.933709935891238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 120}], {
             RGBColor[
             0.18038821966444069`, 0.3069298345140049, 0.9335842142982091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 124}], {
             RGBColor[
             0.18312075215718818`, 0.30980189941644914`, 0.9337398279812515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 363}], {
             RGBColor[
             0.18174309364533237`, 0.30835389297189403`, 0.9336613723670645]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 381}], {
             RGBColor[
             0.18458590754106158`, 0.31134187062111685`, 0.93382326641286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 95}], {
             RGBColor[
             0.18505409827792216`, 0.3118339687705646, 0.933849929182698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 286}], {
             RGBColor[
             0.1864116908357643, 0.3132608846251963, 0.9339272420704889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 319}], {
             RGBColor[
             0.1831451884938083, 0.30982758355559015`, 0.9337412195944718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 330}], {
             RGBColor[
             0.18750410848445143`, 0.3144090848372459, 0.9339894536394946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 352}], {
             RGBColor[
             0.18440978245630846`, 0.311156751990066, 0.933813236349837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 357}], {
             RGBColor[
             0.18698592728629504`, 0.313864443543398, 0.93395994398684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 367}], {
             RGBColor[
             0.19128856344294365`, 0.31838678694692435`, 0.9342049727507814]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 368}], {
             RGBColor[
             0.18232969627571796`, 0.3089704495291842, 0.9336947785190641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 375}], {
             RGBColor[
             0.19408512083298096`, 0.3213261460758332, 0.9343642325570081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 450}], {
             RGBColor[
             0.20047702738706202`, 0.3280444451344552, 0.9347282421792846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 492}], {
             RGBColor[
             0.1840181186755369, 0.3107450885235571, 0.9337909316769367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 101}], {
             RGBColor[
             0.3439836908945852, 0.4664796432810521, 0.9433547372891266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 103}], {
             RGBColor[
             0.4263301464035756, 0.5436874776637394, 0.9483863578332576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 129}], {
             RGBColor[
             0.36611599979539755`, 0.48974210320523914`, 0.944615139539211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 204}], {
             RGBColor[
             0.37937968200922045`, 0.5030213452043036, 0.9453947157587149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 209}], {
             RGBColor[
             0.7186661516906826, 0.7749926272189318, 0.8453240647103539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 231}], {
             RGBColor[
             0.6032570715569849, 0.6866480853473442, 0.9632586642510103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 233}], {
             RGBColor[
             0.7027067996446262, 0.7647987322711527, 0.9488520571207084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 259}], {
             RGBColor[
             0.5630647117651555, 0.6552495084047187, 0.9592526654459177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 275}], {
             RGBColor[
             0.46608428308489896`, 0.5771431812489669, 0.9511894958767693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 306}], {
             RGBColor[
             0.3418131212888621, 0.4641982370033755, 0.9432311265611506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 331}], {
             RGBColor[
             0.37214546505797846`, 0.49607945348638943`, 0.9449585086661204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 346}], {
             RGBColor[
             0.4421357571807656, 0.5573775033058451, 0.9493934773756274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 348}], {
             RGBColor[
             0.4524683198594424, 0.5660891289103882, 0.9501175973747447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 355}], {
             RGBColor[
             0.5012830197903266, 0.6057191013914514, 0.9539604693674415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 372}], {
             RGBColor[
             0.5285636967606093, 0.627866783936419, 0.9561081041909547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 404}], {
             RGBColor[
             0.6398415718326245, 0.7153643102811339, 0.9668689392230831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 418}], {
             RGBColor[
             0.45968074399907377`, 0.5719444997429457, 0.9506853858229966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 431}], {
             RGBColor[
             0.4320540938957698, 0.548645273287512, 0.9487510827059723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 444}], {
             RGBColor[
             0.5043601503383525, 0.6082172545934901, 0.9542027123560828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 486}], {
             RGBColor[
             0.4280953978994323, 0.5452164497853305, 0.9484988380976231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 76}], {
             RGBColor[
             0.3900856381049142, 0.5122943062773944, 0.9460768898142273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 111}], {
             RGBColor[
             0.36816732392345053`, 0.4933097641799131, 0.9446802742161886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 130}], {
             RGBColor[
             0.33633111822806117`, 0.4651961056645053, 0.9426714251516843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 175}], {
             RGBColor[
             0.3837102779939304, 0.5067722897841764, 0.945670657505465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 182}], {
             RGBColor[
             0.35737014201408246`, 0.4839577878921605, 0.9439922873324968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 208}], {
             RGBColor[
             0.39817892177344283`, 0.519304301810809, 0.9465925866929762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[
             0.4282161029443493, 0.5444148958180487, 0.9487568881673315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 351}], {
             RGBColor[
             0.3049667644622824, 0.4322301812417861, 0.9408852716041266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 359}], {
             RGBColor[
             0.6396346219366711, 0.7126850500536813, 0.9680066447733342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 371}], {
             RGBColor[
             0.31191266997486483`, 0.4395307683313558, 0.9412808306475218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 403}], {
             RGBColor[
             0.5565760155932599, 0.6470753000386655, 0.9599201962609412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 442}], {
             RGBColor[
             0.3038237186466454, 0.4310287676162611, 0.9408201768359108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 463}], {
             RGBColor[
             0.4624511336723232, 0.5722084360335765, 0.9514519951932873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 483}], {
             RGBColor[
             0.41089196681220996`, 0.5303157024471664, 0.9474026506811422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 135}], {
             RGBColor[
             0.18886726703484777`, 0.31584185090295647`, 0.9340670835023274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 153}], {
             RGBColor[
             0.21268791512647112`, 0.34087886236357334`, 0.9354236341716544]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 169}], {
             RGBColor[
             0.1907755412237238, 0.3178475680670369, 0.9341757568943452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 172}], {
             RGBColor[
             0.21061538458324242`, 0.3387005013566139, 0.9353056066232517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 197}], {
             RGBColor[
             0.2143161876130597, 0.34259027998541636`, 0.9355163618809523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 201}], {
             RGBColor[
             0.22759518578243687`, 0.3565473489985437, 0.936272581182181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 211}], {
             RGBColor[
             0.19261088350739852`, 0.3197766291746009, 0.9342802769222549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 236}], {
             RGBColor[
             0.20304903767595361`, 0.3307477910229513, 0.9348747143602888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 289}], {
             RGBColor[
             0.20390581997350005`, 0.33164832354080787`, 0.9349235068446382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 308}], {
             RGBColor[
             0.19432153409427227`, 0.32157463140291687`, 0.9343776959424965]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 362}], {
             RGBColor[
             0.1884877837309814, 0.3154429898899618, 0.9340454724895675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 369}], {
             RGBColor[
             0.18988277528354555`, 0.3169092144592796, 0.9341249151947808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 466}], {
             RGBColor[
             0.1963124589116516, 0.3236672196179068, 0.934491076165537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 470}], {
             RGBColor[
             0.19617627269900267`, 0.32352407927370813`, 0.9344833205621961]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 493}], {
             RGBColor[
             0.2293216757786306, 0.35836199945033154`, 0.9363709022333513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 128}], {
             RGBColor[
             0.20268608388741163`, 0.33036630357859437`, 0.9348540446789733]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 159}], {
             RGBColor[
             0.22161615608300847`, 0.35026300969206614`, 0.9359320842859804]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 179}], {
             RGBColor[
             0.20561407521805922`, 0.3334438081124777, 0.9350207894536787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 222}], {
             RGBColor[
             0.20410917934136036`, 0.33186206713015765`, 0.9349350878597946]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 245}], {
             RGBColor[
             0.22752065341650146`, 0.35646901075632065`, 0.9362683366742017]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 294}], {
             RGBColor[
             0.19930405825751749`, 0.32681158020876566`, 0.9346614433226095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 344}], {
             RGBColor[
             0.20069596090134978`, 0.3282745581391582, 0.9347407101190403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 438}], {
             RGBColor[
             0.20687895912531873`, 0.33477328129727923`, 0.9350928227209692]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 439}], {
             RGBColor[
             0.2051731991857032, 0.33298041944931656`, 0.9349956822158536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 453}], {
             RGBColor[
             0.2255232493931461, 0.35436961248504456`, 0.9361545874699662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 91}], {
             RGBColor[
             0.5186112912140105, 0.6200710352367826, 0.9552461270615734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 136}], {
             RGBColor[
             0.5525602908951197, 0.647632362562914, 0.9579187166757537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 200}], {
             RGBColor[
             0.4199369122581749, 0.5305626812641765, 0.9490610674516942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 240}], {
             RGBColor[
             0.785852186641644, 0.829344990984529, 0.8179383454805261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 256}], {
             RGBColor[
             0.4442279577887227, 0.5558341651072809, 0.9504539244246188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 298}], {
             RGBColor[
             0.42629344369918076`, 0.5372437988360448, 0.949423062513614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 434}], {
             RGBColor[
             0.755989141506491, 0.7238557905975457, 0.6132283330346036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 115}], {
             RGBColor[
             0.18984673852773665`, 0.31687133754406216`, 0.9341228629548491]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 144}], {
             RGBColor[
             0.1927927730691202, 0.31996780663643465`, 0.9342906352637134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 215}], {
             RGBColor[
             0.1868347723407586, 0.3137055701118621, 0.9339513359363054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 268}], {
             RGBColor[
             0.18750418807117342`, 0.3144091684879368, 0.9339894581718406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 402}], {
             RGBColor[
             0.20341804022375085`, 0.331135636096799, 0.9348957285094954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 417}], {
             RGBColor[
             0.1929190076012242, 0.3201004871334076, 0.9342978241335694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 104}], {
             RGBColor[
             0.894725030806556, 0.6091192249245418, 0.23357173327544747`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 125}], {
             RGBColor[
             0.8216340480291034, 0.6538916931792487, 0.593916539379413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 147}], {
             RGBColor[
             0.842199332426149, 0.3144945905899744, 0.187617653595973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 303}], {
             RGBColor[
             0.853058182050049, 0.3979604671775163, 0.19801610025913619`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 310}], {
             RGBColor[
             0.7550654921994678, 0.6018878314253746, 0.587281607852838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 323}], {
             RGBColor[
             0.9290142282590157, 0.73628865839294, 0.4899032009526938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 379}], {
             RGBColor[
             0.8463714309227728, 0.346563167860244, 0.1916128598280513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 400}], {
             RGBColor[
             0.9275933480888754, 0.7357010879276322, 0.5134508624919265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 408}], {
             RGBColor[
             0.9013012276585859, 0.7170355167790632, 0.6001882350839804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 111}], {
             RGBColor[
             0.3885098195301592, 0.510929411430886, 0.9459764800480857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 130}], {
             RGBColor[
             0.3566736138347697, 0.4828157529154782, 0.9439676309835814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 175}], {
             RGBColor[
             0.404052773600639, 0.5243919370351493, 0.946966863337362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.3777126376207911, 0.5015774351431334, 0.9452884931643937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 351}], {
             RGBColor[
             0.32530926006899097`, 0.449849828492759, 0.9421814774360235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 359}], {
             RGBColor[
             0.6599771175433797, 0.7303046973046542, 0.9693028506052312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 371}], {
             RGBColor[
             0.3322551655815734, 0.4571504155823287, 0.9425770364794188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 460}], {
             RGBColor[
             0.35555086797246704`, 0.4816356758279989, 0.9439036922676769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 463}], {
             RGBColor[
             0.4827936292790318, 0.5898280832845495, 0.9527482010251842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 483}], {
             RGBColor[
             0.43123446241891855`, 0.5479353496981393, 0.948698856513039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 87}], {
             RGBColor[
             0.32144010648392174`, 0.4528061418339081, 0.9417039869994168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 184}], {
             RGBColor[
             0.4376517235629901, 0.5511173532058586, 0.9497643390234523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 253}], {
             RGBColor[
             0.35598021511374034`, 0.4827539030708413, 0.9439037224194711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 287}], {
             RGBColor[
             0.31931088859466533`, 0.4505681988320882, 0.9415827311905192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 301}], {
             RGBColor[
             0.49545804882307076`, 0.5978313042438662, 0.9544626274499579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 336}], {
             RGBColor[
             0.47990926789082156`, 0.58542393137187, 0.9530910077074245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 354}], {
             RGBColor[
             0.32252783628299564`, 0.4537791338930982, 0.9417721664211531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 388}], {
             RGBColor[
             0.33157794270842256`, 0.4616178812072281, 0.9423488311998864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 409}], {
             RGBColor[
             0.2938507755920474, 0.42380800580193695`, 0.940132815419882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 436}], {
             RGBColor[
             0.3449944123676427, 0.4732385528946725, 0.9432037167828538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 473}], {
             RGBColor[
             0.2990309117164457, 0.42925265730827966`, 0.9404278165088418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 154}], {
             RGBColor[
             0.7267639040768494, 0.783922928096006, 0.9321470662934741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 171}], {
             RGBColor[
             0.47037777522198154`, 0.5809128940593202, 0.9514490079974901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 192}], {
             RGBColor[
             0.39152498613418535`, 0.5130863931305935, 0.946294212255822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.4280975104696688, 0.5447636755214684, 0.9486245811666656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 219}], {
             RGBColor[
             0.5697935423105139, 0.6612069230140997, 0.9595599186442647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 258}], {
             RGBColor[
             0.44262074177976496`, 0.5573429685234437, 0.9495499886233556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 262}], {
             RGBColor[
             0.4066140424697561, 0.526155775330442, 0.9472556735827959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 376}], {
             RGBColor[
             0.4205848118936931, 0.5382565536141679, 0.9481458786566228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 497}], {
             RGBColor[
             0.47412146300073554`, 0.5839521884493253, 0.9517437248130138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 127}], {
             RGBColor[
             0.8591989102072256, 0.8905659049388609, 0.9864323531431288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 147}], {
             RGBColor[
             0.8526636417246913, 0.529899304242684, 0.5774584339898925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 184}], {
             RGBColor[
             0.7135412330833855, 0.7751234699043363, 0.9730039594525782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 221}], {
             RGBColor[
             0.9242610852428408, 0.8982704304455256, 0.6484794882507952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 234}], {
             RGBColor[
             0.9063126289426009, 0.8289774045041336, 0.6243163382349994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 253}], {
             RGBColor[
             0.6318697246341356, 0.7067600197693191, 0.967143342848597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 301}], {
             RGBColor[
             0.7713475583434661, 0.821837420942344, 0.9777022478790838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 316}], {
             RGBColor[
             0.6624800077652702, 0.7332731084999433, 0.9690938030221024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 336}], {
             RGBColor[
             0.7557987774112169, 0.8094300480703478, 0.9763306281365505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 388}], {
             RGBColor[
             0.6074674522288179, 0.6856239979057058, 0.9655884516290124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 436}], {
             RGBColor[
             0.620883921888038, 0.6972446695931502, 0.9664433372119796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 81}], {
             RGBColor[
             0.2928864737857844, 0.4215973242135559, 0.9401217329908362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 171}], {
             RGBColor[
             0.4090554292271066, 0.5282531641753069, 0.9474159938779831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 192}], {
             RGBColor[
             0.3302026401393104, 0.46042666324658016`, 0.9422611981363149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 208}], {
             RGBColor[
             0.38701536387166025`, 0.5096349890530197, 0.9458812546550213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 219}], {
             RGBColor[
             0.508471196315639, 0.6085471931300863, 0.9555269045247576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 238}], {
             RGBColor[
             0.4170525450425667, 0.5347455830602593, 0.9480455561293766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 251}], {
             RGBColor[
             0.2931730251986915, 0.4218985079169302, 0.9401380516698865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 258}], {
             RGBColor[
             0.38129839578489, 0.5046832386394303, 0.9455169745038486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 272}], {
             RGBColor[
             0.30232143214337615`, 0.4315140636582957, 0.9406590399115311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 293}], {
             RGBColor[
             0.578582457393624, 0.6633186431495282, 0.9625149398020252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 403}], {
             RGBColor[
             0.5454124576914773, 0.6374059872808763, 0.9592088642229862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 447}], {
             RGBColor[
             0.2905728038348803, 0.41916551040000816`, 0.9399899729099002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 471}], {
             RGBColor[
             0.6521263465827374, 0.7213327352775194, 0.9506532320788272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 483}], {
             RGBColor[
             0.3997284089104274, 0.520646389689377, 0.9466913186431871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 497}], {
             RGBColor[
             0.4127991170058606, 0.5312924585653119, 0.9477107106935068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 121}], {
             RGBColor[
             0.22174468237743916`, 0.35039809897655055`, 0.9359394036683106]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.27063800741742255`, 0.4017880836094291, 0.9387238061981451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 208}], {
             RGBColor[
             0.3324858109628042, 0.4558962797557328, 0.942644967739437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 213}], {
             RGBColor[
             0.2202872137263247, 0.3488662070153795, 0.9358564029847612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 251}], {
             RGBColor[
             0.23864347228983546`, 0.36815979861964326`, 0.9369017647543021]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 442}], {
             RGBColor[
             0.2381306078360068, 0.36762074556118485`, 0.9368725578823716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 447}], {
             RGBColor[
             0.23604325092602435`, 0.36542680110272124`, 0.936753685994316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 454}], {
             RGBColor[
             0.2248746265777104, 0.3536878687809598, 0.9361176493601785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 500}], {
             RGBColor[
             0.21967281078147302`, 0.34822043056494373`, 0.9358214136459797]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 126}], {
             RGBColor[
             0.504289208348975, 0.6084437231644664, 0.9541186402349197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 149}], {
             RGBColor[
             0.540625880408879, 0.6379434704911183, 0.9569791961650909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 173}], {
             RGBColor[
             0.6203596764497656, 0.7014764485955354, 0.964075560146658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 242}], {
             RGBColor[
             0.7466175241184303, 0.8003829212442619, 0.9428810481338523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 249}], {
             RGBColor[
             0.6235359473541606, 0.7039577755666018, 0.9643921411464688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 269}], {
             RGBColor[
             0.5609980001725171, 0.6544824750687763, 0.958582964058418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 282}], {
             RGBColor[
             0.6084177855813375, 0.6921473526873871, 0.962885304068208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 323}], {
             RGBColor[
             0.7564161337880024, 0.8062755394340282, 0.8629204050270508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 384}], {
             RGBColor[
             0.39409857332891574`, 0.5101959076651558, 0.9469714569601196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 411}], {
             RGBColor[
             0.4006657201660342, 0.5170983953721258, 0.9473454462572704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 419}], {
             RGBColor[
             0.5847042349028322, 0.6736221466676785, 0.9605217589523052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 499}], {
             RGBColor[
             0.5743475030967551, 0.6653202029309262, 0.9596338858294544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 97}], {
             RGBColor[
             0.9918418301129188, 0.9825092007837744, 0.5692119944347548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 163}], {
             RGBColor[
             0.9472677000831091, 0.8139798001662166, 0.4832298213140514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 207}], {
             RGBColor[
             0.9351069377955797, 0.7587606188367377, 0.47308258317377627`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 209}], {
             RGBColor[
             0.9948514855705746, 0.9921389712197164, 0.7349877382312089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 231}], {
             RGBColor[
             0.879442405436877, 0.9037944293481288, 0.8529223377718652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 233}], {
             RGBColor[
             0.9788921335245182, 0.9819450762719373, 0.8385157306415634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 257}], {
             RGBColor[
             0.9791397410141973, 0.9396620716614368, 0.5198667768744751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 317}], {
             RGBColor[
             0.9062729324823862, 0.5632106001230137, 0.44649236510931034`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 326}], {
             RGBColor[
             0.8603044472818449, 0.8888437109835485, 0.8510148449573589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 343}], {
             RGBColor[
             0.920728738466214, 0.6743242594892878, 0.4603352612449215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 346}], {
             RGBColor[
             0.7183210910606576, 0.7745238473066297, 0.8390571508964824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 355}], {
             RGBColor[
             0.7774683536702185, 0.8228654453922359, 0.8436241428882965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 395}], {
             RGBColor[
             0.749683946094778, 0.8003088116491959, 0.8414368525463194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 440}], {
             RGBColor[
             0.9434296852982257, 0.7965522714191877, 0.48002728769919345`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 89}], {
             RGBColor[
             0.2925984761880414, 0.42478343593361145`, 0.9399775893294924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 176}], {
             RGBColor[
             0.29622447069818203`, 0.4279240901305121, 0.9402086344933376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 244}], {
             RGBColor[
             0.3611185636561085, 0.4841320917787186, 0.9443436287130234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 245}], {
             RGBColor[
             0.25972033738633343`, 0.39031292018649366`, 0.9381020610411201]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 260}], {
             RGBColor[
             0.24263313262389596`, 0.37235318458981626`, 0.9371289700081534]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 261}], {
             RGBColor[
             0.30240410894972447`, 0.4332765821863486, 0.9406023955782863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 262}], {
             RGBColor[
             0.3093414127711809, 0.4392853260774658, 0.9410444344433726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 299}], {
             RGBColor[
             0.2577944317187598, 0.3882886712204018, 0.9379923835624739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 328}], {
             RGBColor[
             0.2592509748717875, 0.3898195904244037, 0.9380753315402763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 376}], {
             RGBColor[
             0.3233121821951179, 0.4513861043611917, 0.9419346395171995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 391}], {
             RGBColor[
             0.3743150955210323, 0.495024736722043, 0.9453330205540728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 407}], {
             RGBColor[
             0.27632252286434345`, 0.40776286976323906`, 0.9390475309433604]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 448}], {
             RGBColor[
             0.28804975562944346`, 0.4200889349488619, 0.9397153795004467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 455}], {
             RGBColor[
             0.4442800341977758, 0.5518254258243921, 0.9508409168167211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 475}], {
             RGBColor[
             0.3060220283144641, 0.4364102420981715, 0.9408329262010071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 478}], {
             RGBColor[
             0.2624145878361924, 0.3931447482346404, 0.9382554946184531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 482}], {
             RGBColor[
             0.30394372684162835`, 0.43461012182087044`, 0.9407004986689278]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 146}], {
             RGBColor[
             0.1836713842833611, 0.3103806486931501, 0.9337711856662498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 166}], {
             RGBColor[
             0.19147571921883372`, 0.31858349953374643`, 0.9342156309953462]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 239}], {
             RGBColor[
             0.19195700771123925`, 0.31908936425471746`, 0.9342430396629862]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 332}], {
             RGBColor[
             0.18694868384128802`, 0.31382529832132483`, 0.9339578230277437]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 387}], {
             RGBColor[
             0.18808022272596522`, 0.31501461743282955`, 0.9340222624932641]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 489}], {
             RGBColor[
             0.18944536571522486`, 0.31644946926960615`, 0.9341000053669545]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 177}], {
             RGBColor[
             0.1848471163861694, 0.31161641767892256`, 0.933838141870165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 194}], {
             RGBColor[
             0.18570943860608155`, 0.31252277300643677`, 0.9338872498448976]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 220}], {
             RGBColor[
             0.20117259087192368`, 0.32877552645831687`, 0.9347678534907535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 254}], {
             RGBColor[
             0.18887066842711453`, 0.3158454259818896, 0.934067277206585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 290}], {
             RGBColor[
             0.18341921937923714`, 0.31011560739073746`, 0.9337568252480046]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 297}], {
             RGBColor[
             0.1902871793569701, 0.317334268781148, 0.9341479454085002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 350}], {
             RGBColor[
             0.18341807699895743`, 0.3101144066766324, 0.9337567601911376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 377}], {
             RGBColor[
             0.18305173765274474`, 0.30972936079650676`, 0.9337358977073213]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 412}], {
             RGBColor[
             0.18778375020070825`, 0.3147030060113407, 0.9340053788215426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 426}], {
             RGBColor[
             0.1863343941921356, 0.31317964095185236`, 0.9339228401409845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 476}], {
             RGBColor[
             0.18437093737264393`, 0.311115923344214, 0.9338110241797885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 91}], {
             RGBColor[
             0.3843682357663767, 0.5071210898901892, 0.9457662741578293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 161}], {
             RGBColor[
             0.2611314320863651, 0.3917960701847984, 0.9381824207967593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 184}], {
             RGBColor[
             0.4246238918446351, 0.5398024449911591, 0.9489353468656369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 228}], {
             RGBColor[
             0.28331447723561765`, 0.41511185712296006`, 0.9394457124011348]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 253}], {
             RGBColor[
             0.34295238339538536`, 0.47143899485614194`, 0.9430747302616557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 256}], {
             RGBColor[
             0.30998490234108894`, 0.4428842197606874, 0.9409740715208748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 285}], {
             RGBColor[
             0.2614000119680612, 0.39207836466940904`, 0.9381977160236936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 287}], {
             RGBColor[
             0.3062830568763104, 0.4392532906173888, 0.9407537390327037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 336}], {
             RGBColor[
             0.4668814361724666, 0.5741090231571706, 0.9522620155496091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 354}], {
             RGBColor[
             0.30950000456464066`, 0.4424642256783988, 0.9409431742633377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 388}], {
             RGBColor[
             0.3185501109900676, 0.45030297299252864`, 0.941519839042071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 409}], {
             RGBColor[
             0.28082294387369244`, 0.4124930975872375, 0.9393038232620665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 436}], {
             RGBColor[
             0.33196658064928775`, 0.46192364467997304`, 0.9423747246250382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 473}], {
             RGBColor[
             0.28600307999809077`, 0.4179377490935802, 0.9395988243510263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 133}], {
             RGBColor[
             0.19376977710770305`, 0.3209946998266191, 0.9343462741983627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 241}], {
             RGBColor[
             0.2025944621469051, 0.33027000332016815`, 0.9348488269563937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 271}], {
             RGBColor[
             0.19882737388287028`, 0.32631055470747644`, 0.9346342968526646]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 304}], {
             RGBColor[
             0.19013400622997473`, 0.3171732741129387, 0.9341392224255172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 307}], {
             RGBColor[
             0.1906659921562372, 0.31773242505129645`, 0.9341695182370151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 311}], {
             RGBColor[
             0.18977178861723454`, 0.3167925604360257, 0.9341185946683245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 337}], {
             RGBColor[
             0.18932246677623382`, 0.3163202946924838, 0.9340930064541916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 423}], {
             RGBColor[
             0.18437944571093495`, 0.3111248661472177, 0.9338115087170672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 427}], {
             RGBColor[
             0.18803656473244668`, 0.3149687301135649, 0.9340197762351194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 433}], {
             RGBColor[
             0.18511620603054046`, 0.3118992479564254, 0.9338534661273294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 465}], {
             RGBColor[
             0.18430414736705614`, 0.3110457228136103, 0.9338072205877772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 469}], {
             RGBColor[
             0.1854557592359103, 0.3122561399041857, 0.9338728031800514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 176}], {
             RGBColor[
             0.31330748759898347`, 0.4457929312912065, 0.9411846539562421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 178}], {
             RGBColor[
             0.38949543937037706`, 0.5113489021851207, 0.9461592546246456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 244}], {
             RGBColor[
             0.37820158055690994`, 0.5020009329394131, 0.945319648175928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 261}], {
             RGBColor[
             0.31948712585052597`, 0.45114542334704305`, 0.9415784150411908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 262}], {
             RGBColor[
             0.3264244296719824, 0.4571541672381602, 0.9420204539062771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 299}], {
             RGBColor[
             0.27487744861956126`, 0.4061575123810962, 0.9389684030253784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 328}], {
             RGBColor[
             0.27633399177258894`, 0.4076884315850981, 0.9390513510031808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 376}], {
             RGBColor[
             0.3403951990959194, 0.4692549455218861, 0.9429106589801041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 391}], {
             RGBColor[
             0.39139811242183375`, 0.5128935778827375, 0.9463090400169774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 407}], {
             RGBColor[
             0.2934055397651449, 0.4256317109239335, 0.9400235504062648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 448}], {
             RGBColor[
             0.30513277253024496`, 0.43795777610955633`, 0.9406913989633512]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 455}], {
             RGBColor[
             0.4613630510985772, 0.5696942669850865, 0.9518169362796256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 475}], {
             RGBColor[
             0.32310504521526556`, 0.4542790832588659, 0.9418089456639116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 478}], {
             RGBColor[
             0.27949760473699387`, 0.41101358939533483`, 0.9392315140813577]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 482}], {
             RGBColor[
             0.3210267437424298, 0.45247896298156487`, 0.9416765181318323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 137}], {
             RGBColor[
             0.23700337417738956`, 0.3664359515152362, 0.9368083635931062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 148}], {
             RGBColor[
             0.26849318417245727`, 0.3995337383893224, 0.9386016616873261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 229}], {
             RGBColor[
             0.24859585520259658`, 0.3786203840784777, 0.9374685382379528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 232}], {
             RGBColor[
             0.2704052861597108, 0.40154347881219404`, 0.9387105530667987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 263}], {
             RGBColor[
             0.24334458110817345`, 0.37310096205523113`, 0.9371694859468394]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 267}], {
             RGBColor[
             0.24580395513477205`, 0.37568592009050583`, 0.9373095436593363]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 280}], {
             RGBColor[
             0.25791236607974777`, 0.3884126277112705, 0.937999099749864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 342}], {
             RGBColor[
             0.36933196448262395`, 0.489404611907154, 0.9450840596145658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 393}], {
             RGBColor[
             0.24183341082623228`, 0.3715126262751811, 0.9370834270348589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 480}], {
             RGBColor[
             0.2528560578238772, 0.3830981271458908, 0.9377111504748298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 485}], {
             RGBColor[
             0.25884791756577036`, 0.3893959516404705, 0.9380523780229685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 200}], {
             RGBColor[
             0.3616498178113511, 0.4832425921885635, 0.9444724938641782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 228}], {
             RGBColor[
             0.35927043823642757`, 0.48074171339394056`, 0.9443369917173629]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 256}], {
             RGBColor[
             0.3859408633418989, 0.5085140760316679, 0.9458653508371028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 287}], {
             RGBColor[
             0.38223901787712034`, 0.5048831468883692, 0.9456450183489318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 298}], {
             RGBColor[
             0.368006349252357, 0.4899237097604318, 0.9448344889260978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 336}], {
             RGBColor[
             0.5428373971732765, 0.639738879428151, 0.957153294865837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 132}], {
             RGBColor[
             0.27212682678288186`, 0.40335292715912663`, 0.9388085922584972]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 250}], {
             RGBColor[
             0.24579035153480303`, 0.3756716218444204, 0.9373087689544427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 342}], {
             RGBColor[
             0.37412603951120016`, 0.4944434887241004, 0.9453570750952447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 356}], {
             RGBColor[
             0.2586276684650108, 0.3891644558709726, 0.9380398351625095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 365}], {
             RGBColor[
             0.23949140661491064`, 0.36905103135743866`, 0.9369500533597088]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 457}], {
             RGBColor[
             0.37059515571215895`, 0.49157695819153635`, 0.9450791109885306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 485}], {
             RGBColor[
             0.26364199259434656`, 0.39443482845741684`, 0.9383253935036474]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 494}], {
             RGBColor[
             0.31362082310207806`, 0.44266127858544857`, 0.9413292216811688]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 141}], {
             RGBColor[
             0.21496969901233648`, 0.34327716190107216`, 0.9355535783883577]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 151}], {
             RGBColor[
             0.21317178010893856`, 0.3413874351389585, 0.9354511895665918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 160}], {
             RGBColor[
             0.23103960685447572`, 0.36016765393416605`, 0.9364687358666692]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 167}], {
             RGBColor[
             0.23124675852992788`, 0.3603853834792411, 0.9364805328481329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 172}], {
             RGBColor[
             0.22306123798292227`, 0.35178188239235997`, 0.9360143795623734]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 201}], {
             RGBColor[
             0.24004103918211672`, 0.36962873003428975`, 0.9369813541213027]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 218}], {
             RGBColor[
             0.2542535028794738, 0.3845669305024568, 0.9377907329034113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 235}], {
             RGBColor[
             0.21987414226832205`, 0.3484320427227756, 0.9358328791763124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 236}], {
             RGBColor[
             0.21549489107563347`, 0.3438291720586974, 0.9355834872994104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 274}], {
             RGBColor[
             0.23335737797095998`, 0.3626037783327675, 0.936600729502918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 284}], {
             RGBColor[
             0.21473027895683314`, 0.3430255162426299, 0.9355399437703871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 289}], {
             RGBColor[
             0.21635167337317993`, 0.34472970457655394`, 0.93563227978376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 300}], {
             RGBColor[
             0.2272468293636924, 0.3561812043153706, 0.9362527427994807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 305}], {
             RGBColor[
             0.26659251557076086`, 0.3973687929461906, 0.9384995442473698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 308}], {
             RGBColor[
             0.20676738749395213`, 0.33465601243866294`, 0.9350864688816183]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 389}], {
             RGBColor[
             0.20877589722978934`, 0.3367670835179003, 0.9352008505397502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 432}], {
             RGBColor[
             0.2569317093580773, 0.38738189531956746`, 0.9379432528003164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 456}], {
             RGBColor[
             0.20912093230204676`, 0.3371297372553299, 0.9352204997766816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 493}], {
             RGBColor[
             0.24176752917831046`, 0.3714433804860776, 0.9370796751724728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 123}], {
             RGBColor[
             0.18238673674691558`, 0.30903040268098764`, 0.933698026889515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 139}], {
             RGBColor[
             0.18076319755662762`, 0.3073239600536649, 0.9336055687344391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 158}], {
             RGBColor[
             0.18531714297239393`, 0.3121104454224513, 0.9338649091889084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 193}], {
             RGBColor[
             0.17992543383268728`, 0.3064434172625156, 0.9335578593297211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 401}], {
             RGBColor[
             0.17982716171712376`, 0.30634012703824637`, 0.9335522628781203]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 410}], {
             RGBColor[
             0.18058759193707163`, 0.30713938741347224`, 0.9335955682541907]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 428}], {
             RGBColor[
             0.18335052254202558`, 0.31004340265919705`, 0.9337529130647533]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 437}], {
             RGBColor[
             0.18042329707310156`, 0.30696670309454366`, 0.93358621190474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 122}], {
             RGBColor[
             0.18517962016864098`, 0.3119659002362576, 0.9338570774686815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 185}], {
             RGBColor[
             0.19811081032671668`, 0.3255574009772055, 0.9345934896182024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 212}], {
             RGBColor[
             0.18331321264928, 0.31000418759633763`, 0.9337507883215563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 224}], {
             RGBColor[
             0.19530748745975585`, 0.322610930903094, 0.9344338445280735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 286}], {
             RGBColor[
             0.18603827385130794`, 0.3128683996985284, 0.9339059765256451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 319}], {
             RGBColor[
             0.18277177150935192`, 0.30943509862892227`, 0.9337199540496279]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 330}], {
             RGBColor[
             0.18713069149999506`, 0.314016599910578, 0.9339681880946508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 357}], {
             RGBColor[
             0.18661251030183867`, 0.3134719586167301, 0.9339386784419961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 367}], {
             RGBColor[
             0.19091514645848728`, 0.31799430202025647`, 0.9341837072059376]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 368}], {
             RGBColor[
             0.1819562792912616, 0.3085779646025163, 0.9336735129742202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 492}], {
             RGBColor[
             0.18364470169108055`, 0.3103526035968892, 0.9337696661320929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 110}], {
             RGBColor[
             0.443925135446012, 0.558453392319533, 0.9496384572015815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 136}], {
             RGBColor[
             0.4994982670529912, 0.6045542211909409, 0.9537414797863035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.3849349952696799, 0.5064668572722832, 0.9459123269300246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 240}], {
             RGBColor[
             0.7327901627995155, 0.786266849612556, 0.8137611085910759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 360}], {
             RGBColor[
             0.5334689580963748, 0.6321331585421514, 0.9564157770239803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 457}], {
             RGBColor[
             0.47001276809964954`, 0.5806165648340276, 0.951420273299755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 163}], {
             RGBColor[
             0.9438826652312557, 0.8041948007039634, 0.3236750855301855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 207}], {
             RGBColor[
             0.9317219029437263, 0.7489756193744845, 0.31352784738991035`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 209}], {
             RGBColor[
             0.9914664507187211, 0.9823539717574632, 0.575433002447343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 231}], {
             RGBColor[
             0.8760573705850234, 0.8940094298858756, 0.6933676019879993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 233}], {
             RGBColor[
             0.9755070986726647, 0.9721600768096842, 0.6789609948576975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 257}], {
             RGBColor[
             0.9757547061623437, 0.9298770721991836, 0.3603120410906092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 281}], {
             RGBColor[
             0.903440360362725, 0.5576720713111039, 0.28746666826170925`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 317}], {
             RGBColor[
             0.9028878976305327, 0.5534256006607606, 0.2869376293254444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 322}], {
             RGBColor[
             0.9046195205529701, 0.5667356132446183, 0.288595833391559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 326}], {
             RGBColor[
             0.8569194124299913, 0.8790587115212953, 0.6914601091734929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 343}], {
             RGBColor[
             0.9173437036143605, 0.6645392600270346, 0.3007805254610556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 355}], {
             RGBColor[
             0.7740833188183651, 0.8130804459299827, 0.6840694071044306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 395}], {
             RGBColor[
             0.7462989112429244, 0.7905238121869427, 0.6818821167624534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 440}], {
             RGBColor[
             0.9400446504463722, 0.7867672719569345, 0.32047255191532753`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 105}], {
             RGBColor[
             0.18986356428247403`, 0.31688902247910566`, 0.93412382115669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 276}], {
             RGBColor[
             0.20095020339638087`, 0.3285417831213411, 0.9347551888530141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 347}], {
             RGBColor[
             0.19568928020766854`, 0.32301221928820867`, 0.9344555870602553]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 382}], {
             RGBColor[
             0.20018581629901203`, 0.3277383638170652, 0.9347116581386283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 425}], {
             RGBColor[
             0.1874902819867422, 0.31439455231150293`, 0.9339886662409045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 462}], {
             RGBColor[
             0.18918443929913709`, 0.3161752190626076, 0.9340851459935643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 131}], {
             RGBColor[
             0.9067135965497277, 0.6223214351513566, 0.549591400192696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 143}], {
             RGBColor[
             0.7801748654933693, 0.827408823277354, 0.9396902443294888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 178}], {
             RGBColor[
             0.7245036529888805, 0.7822124250066672, 0.9353076025507647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 186}], {
             RGBColor[
             0.9865105734086191, 0.9862533521324298, 0.7169514481905657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 277}], {
             RGBColor[
             0.7114622471897839, 0.7713508183962726, 0.9343566439534178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 288}], {
             RGBColor[
             0.8454606604699532, 0.8793558579429647, 0.9455510322617159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 295}], {
             RGBColor[
             0.9822469150718874, 0.9861800274834427, 0.9104424780465525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 313}], {
             RGBColor[
             0.6704591742575927, 0.7358360174967769, 0.9317439644037724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 321}], {
             RGBColor[
             0.9825665367368704, 0.9863121992558153, 0.9051455199034306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 341}], {
             RGBColor[
             0.9869976251000042, 0.9872951064518227, 0.7699640190632113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 373}], {
             RGBColor[
             0.9853487541189616, 0.9874627176430353, 0.859036977734402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 498}], {
             RGBColor[
             0.8771421221278247, 0.9041056565781206, 0.9487087442796804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 203}], {
             RGBColor[
             0.9191489665110915, 0.667681353565574, 0.3474800185895157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 257}], {
             RGBColor[
             0.9781397520963673, 0.9374756322249009, 0.407566735110352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 264}], {
             RGBColor[
             0.92938539319056, 0.7351346977720205, 0.3568427596083415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 281}], {
             RGBColor[
             0.9058254062967486, 0.5652706313368212, 0.33472136228145205`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 324}], {
             RGBColor[
             0.9664798274342277, 0.9712473493741347, 0.7455337650413938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 360}], {
             RGBColor[
             0.7946952326726424, 0.8354763984444047, 0.7327589869340729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 374}], {
             RGBColor[
             0.9203355927006582, 0.6768022824414968, 0.3486163331687475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 397}], {
             RGBColor[
             0.9076183259729562, 0.5790517976305654, 0.33643826418820166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 457}], {
             RGBColor[
             0.7312390426759171, 0.7839598047362808, 0.7277634832098476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 103}], {
             RGBColor[
             0.32745764009317235`, 0.4521656087003331, 0.9423017119454735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 129}], {
             RGBColor[
             0.2672434934849943, 0.39822023424183295`, 0.9385304936514267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[
             0.2805071756988172, 0.41149947624089733`, 0.9393100698709307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 276}], {
             RGBColor[
             0.22935486634297414`, 0.3583968848378599, 0.9363727923868895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 306}], {
             RGBColor[
             0.24294061497845892`, 0.37267636803996923`, 0.9371464806733664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 331}], {
             RGBColor[
             0.2732729587475753, 0.4045575845229832, 0.9388738627783362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 347}], {
             RGBColor[
             0.22409394315426182`, 0.3528673210047275, 0.9360731905941307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 390}], {
             RGBColor[
             0.25051248587412484`, 0.3806348844356572, 0.9375776875192954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 431}], {
             RGBColor[
             0.33318158758536665`, 0.45712340432410575`, 0.9426664368181881]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 486}], {
             RGBColor[
             0.32922289158902907`, 0.45369458082192426`, 0.9424141922098388]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 134}], {
             RGBColor[
             0.1917868632444325, 0.31891053163232136`, 0.9342333501873077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 174}], {
             RGBColor[
             0.1934597999069662, 0.32066889413495503`, 0.934328621455351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 210}], {
             RGBColor[
             0.19748304019874757`, 0.324897574769785, 0.9345577390381172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 225}], {
             RGBColor[
             0.19170377678695943`, 0.3188232024975315, 0.9342286185364699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 247}], {
             RGBColor[
             0.19186086570906943`, 0.31898831291468205`, 0.934237564518192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 252}], {
             RGBColor[
             0.19087465031632422`, 0.3179517380072394, 0.93418140101055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 278}], {
             RGBColor[
             0.19195325855915324`, 0.31908542365816517`, 0.9342428261543212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 309}], {
             RGBColor[
             0.19381918087775277`, 0.3210466263213213, 0.9343490876699807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 383}], {
             RGBColor[
             0.23360844690792137`, 0.362867667704204, 0.9366150275074547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 393}], {
             RGBColor[
             0.2103791435745319, 0.3384521970779141, 0.9352921530472929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 451}], {
             RGBColor[
             0.20226457959273075`, 0.32992327583996894`, 0.9348300406329509]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 480}], {
             RGBColor[
             0.2214017905721769, 0.3500376979486238, 0.9359198764872638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 129}], {
             RGBColor[
             0.3495899489939847, 0.47542806862452014`, 0.9435621141955579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 204}], {
             RGBColor[
             0.3628536312078076, 0.48870731062358463`, 0.9443416904150619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 209}], {
             RGBColor[
             0.7021401008892698, 0.7606785926382128, 0.8442710393667008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 231}], {
             RGBColor[
             0.5867310207555722, 0.6723340507666251, 0.9622056389073572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 233}], {
             RGBColor[
             0.6861807488432135, 0.7504846976904338, 0.9477990317770553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 259}], {
             RGBColor[
             0.5465386609637427, 0.6409354738239997, 0.9581996401022647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 275}], {
             RGBColor[
             0.4495582322834861, 0.5628291466682479, 0.9501364705331162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 326}], {
             RGBColor[
             0.56759306260054, 0.6573833324020449, 0.9602981460928508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 346}], {
             RGBColor[
             0.4256097063793528, 0.5430634687251261, 0.9483404520319744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 348}], {
             RGBColor[
             0.4359422690580296, 0.5517750943296691, 0.9490645720310915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 355}], {
             RGBColor[
             0.48475696898891374`, 0.5914050668107322, 0.9529074440237885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 390}], {
             RGBColor[
             0.3328589413831152, 0.4578427188183445, 0.9426093080634266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 404}], {
             RGBColor[
             0.6233155210312117, 0.7010502757004149, 0.96581591387943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 431}], {
             RGBColor[
             0.415528043094357, 0.534331238706793, 0.9476980573623193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 443}], {
             RGBColor[
             0.3488203865149018, 0.47461920966592475`, 0.9435182887508398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 444}], {
             RGBColor[
             0.4878340995369397, 0.5939032200127712, 0.9531496870124296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 486}], {
             RGBColor[
             0.41156934709801946`, 0.5309024152046116, 0.94744581275397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 125}], {
             RGBColor[
             0.8510407401896769, 0.7816870619636468, 0.6181576134272155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 147}], {
             RGBColor[
             0.8716060245867224, 0.4422899593743725, 0.21185872764377553`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 242}], {
             RGBColor[
             0.9486223107500168, 0.8581914089875718, 0.5941049181072977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 303}], {
             RGBColor[
             0.8824648742106225, 0.5257558359619144, 0.2222571743069387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 310}], {
             RGBColor[
             0.7844721843600413, 0.7296832002097726, 0.6115226819006405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 323}], {
             RGBColor[
             0.958420920419589, 0.8640840271773381, 0.5141442750004963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 379}], {
             RGBColor[
             0.8757781230833462, 0.4743585366446421, 0.21585393387585383`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 408}], {
             RGBColor[
             0.9307079198191593, 0.8448308855634613, 0.624429309131783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 109}], {
             RGBColor[
             0.2025306105640042, 0.3302028912581151, 0.9348451907032074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 205}], {
             RGBColor[
             0.21445329260995954`, 0.34273438603011697`, 0.9355241698076971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 230}], {
             RGBColor[
             0.19866180408544326`, 0.32613653035264917`, 0.9346248678976397]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 382}], {
             RGBColor[
             0.2017475218904906, 0.3293798154115627, 0.9348005949617267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 425}], {
             RGBColor[
             0.18905198757822078`, 0.3160360039060004, 0.9340776030640029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 462}], {
             RGBColor[
             0.19074614489061564`, 0.31781667065710506`, 0.9341740828166627]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 484}], {
             RGBColor[
             0.1881185665568436, 0.315054919230222, 0.9340244461177081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 156}], {
             RGBColor[
             0.1895211212928381, 0.31652909318485867`, 0.9341043195350291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 227}], {
             RGBColor[
             0.18640315120824044`, 0.31325190893522514`, 0.9339267557513348]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 265}], {
             RGBColor[
             0.18198502195137928`, 0.3086081749606899, 0.933675149826193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 270}], {
             RGBColor[
             0.17988066425974236`, 0.3063963616027956, 0.9335553097687725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 329}], {
             RGBColor[
             0.18061317161541351`, 0.30716627327725476`, 0.9335970249790304]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 479}], {
             RGBColor[
             0.18098277247116215`, 0.30755474721069437`, 0.9336180732009899]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 153}], {
             RGBColor[
             0.21946182531602942`, 0.3479986714635114, 0.9358093983358476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 170}], {
             RGBColor[
             0.19951076544330998`, 0.3270288425670261, 0.9346732149910444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 197}], {
             RGBColor[
             0.221090097802618, 0.3497100890853544, 0.9359021260451457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 214}], {
             RGBColor[
             0.19941582681621922`, 0.32692905605049705`, 0.9346678083766806]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 223}], {
             RGBColor[
             0.20973558752308613`, 0.3377757788640342, 0.935255503482219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 236}], {
             RGBColor[
             0.20982294786551192`, 0.3378676001228893, 0.935260478524482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 289}], {
             RGBColor[
             0.21067973016305835`, 0.3387681326407459, 0.9353092710088315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 314}], {
             RGBColor[
             0.2370472271918243, 0.36648204381384886`, 0.9368108609574035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 411}], {
             RGBColor[
             0.24624789168403566`, 0.3761525255509848, 0.9373348251890715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 466}], {
             RGBColor[
             0.20308636910120992`, 0.33078702871784477`, 0.9348768403297303]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 470}], {
             RGBColor[
             0.20295018288856098`, 0.3306438883736461, 0.9348690847263893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 113}], {
             RGBColor[
             0.2031652064588611, 0.33086989177931336`, 0.934881330000619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 190}], {
             RGBColor[
             0.21307880253974895`, 0.34128970981862183`, 0.9354458946315745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 315}], {
             RGBColor[
             0.19651178198130725`, 0.3238767208019274, 0.9345024273194817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 349}], {
             RGBColor[
             0.19740440059431363`, 0.32481491955948594`, 0.9345532606289816]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 364}], {
             RGBColor[
             0.2070027664491964, 0.33490341064451234`, 0.9350998733649074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 378}], {
             RGBColor[
             0.20828889068141454`, 0.33625520875755976`, 0.9351731162372818]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 380}], {
             RGBColor[
             0.19854131235532485`, 0.3260098859046778, 0.934618006071861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 416}], {
             RGBColor[
             0.20942130064370462`, 0.3374454434268651, 0.9352376053093838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 452}], {
             RGBColor[
             0.21821098000140754`, 0.3466839537296702, 0.9357381645456397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 487}], {
             RGBColor[
             0.20117686323780593`, 0.3287800169857428, 0.9347680967956702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 164}], {
             RGBColor[
             0.2648306442899861, 0.3950111522821019, 0.9384177281820844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 180}], {
             RGBColor[
             0.23839049921865452`, 0.36789390788241305`, 0.9368873583121385]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 205}], {
             RGBColor[
             0.22555863330001114`, 0.354406803214629, 0.9361566025311163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 230}], {
             RGBColor[
             0.20976714477549485`, 0.3378089475371612, 0.9352573006210588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 382}], {
             RGBColor[
             0.2128528625805422, 0.3410522325960747, 0.9354330276851459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 413}], {
             RGBColor[
             0.22197296688604118`, 0.35063804046916514`, 0.9359524041333588]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 474}], {
             RGBColor[
             0.22157473772172553`, 0.350219476368282, 0.9359297255715783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 490}], {
             RGBColor[
             0.21480193499900369`, 0.3431008312862066, 0.935544024475983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 157}], {
             RGBColor[
             0.35808579273911467`, 0.4836854080233668, 0.944070557261417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 356}], {
             RGBColor[
             0.3311960783219361, 0.45542261326454736`, 0.9425392278051263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 360}], {
             RGBColor[
             0.5066197555658096, 0.6093517092932348, 0.9545740073553726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 457}], {
             RGBColor[
             0.44316356556908426`, 0.5578351155851111, 0.9495785036311474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 494}], {
             RGBColor[
             0.3861892329590033, 0.5089194359790232, 0.9458286143237857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 130}], {
             RGBColor[
             0.3347552996533061, 0.46383121081799694`, 0.9425710153855427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 175}], {
             RGBColor[
             0.38213445941917534`, 0.5054073949376681, 0.9455702477393233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 182}], {
             RGBColor[
             0.35579432343932743`, 0.4825928930456521, 0.9438918775663551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 351}], {
             RGBColor[
             0.3033909458875273, 0.43086528639527777`, 0.9407848618379848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 359}], {
             RGBColor[
             0.6380588033619161, 0.711320155207173, 0.9679062350071925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 371}], {
             RGBColor[
             0.3103368514001098, 0.4381658734848475, 0.9411804208813801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 460}], {
             RGBColor[
             0.33363255379100343`, 0.46265113373051764`, 0.9425070766696382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 463}], {
             RGBColor[
             0.4608753150975682, 0.5708435411870683, 0.9513515854271455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 483}], {
             RGBColor[
             0.4093161482374549, 0.528950807600658, 0.9473022409150004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 163}], {
             RGBColor[
             0.9463750065735652, 0.8136106484588435, 0.49802406298394036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 175}], {
             RGBColor[
             0.6955594457176699, 0.7552129086866064, 0.8524579222934991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 207}], {
             RGBColor[
             0.9342142442860358, 0.7583914671293646, 0.48787682484366524`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 238}], {
             RGBColor[
             0.7400652706680888, 0.7928555147204785, 0.8555441529553656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 266}], {
             RGBColor[
             0.9935124253020141, 0.9901198523525236, 0.6506615550659651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 293}], {
             RGBColor[
             0.901595183019146, 0.9214285748097474, 0.8700135366280143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 317}], {
             RGBColor[
             0.9053802389728423, 0.5628414484156407, 0.4612866067791993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 343}], {
             RGBColor[
             0.91983604495667, 0.6739551077819146, 0.4751295029148105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 359}], {
             RGBColor[
             0.9514837896604106, 0.9611256689561112, 0.8747939095613684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 403}], {
             RGBColor[
             0.8684251833169994, 0.8955159189410955, 0.8667074610489753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 440}], {
             RGBColor[
             0.9425369917886818, 0.7961831197118145, 0.4948215293690824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 445}], {
             RGBColor[
             0.9782801480279448, 0.9394045757914982, 0.5347896078268422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 463}], {
             RGBColor[
             0.7743003013960627, 0.8206490549360065, 0.8582392599813213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 471}], {
             RGBColor[
             0.9751390722082593, 0.9794426669377387, 0.8581518289048162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 483}], {
             RGBColor[
             0.7227411345359493, 0.7787563213495963, 0.8541899154691762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 190}], {
             RGBColor[
             0.20663037548476026`, 0.33451200412993914`, 0.9350786662503858]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 315}], {
             RGBColor[
             0.19006335492631857`, 0.31709901511324473`, 0.9341351989382931]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 349}], {
             RGBColor[
             0.19095597353932497`, 0.3180372138708033, 0.934186032247793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 353}], {
             RGBColor[
             0.1887122478968889, 0.3156789159601807, 0.9340582553917509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 364}], {
             RGBColor[
             0.20055433939420772`, 0.3281257049558297, 0.9347326449837188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 378}], {
             RGBColor[
             0.20184046362642588`, 0.32947750306887713`, 0.9348058878560932]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 380}], {
             RGBColor[
             0.19209288530033616`, 0.3192321802159951, 0.9342507776906723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 487}], {
             RGBColor[
             0.19472843618281724`, 0.32200231129706014`, 0.9344008684144816]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 128}], {
             RGBColor[
             0.1878451960142834, 0.31476758945729777`, 0.9340088780697248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 138}], {
             RGBColor[
             0.18210218513342014`, 0.30873132089358957`, 0.9336818220960829]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 179}], {
             RGBColor[
             0.19077318734493098`, 0.3178450939911811, 0.9341756228444302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 255}], {
             RGBColor[
             0.1893023656117655, 0.31629916709414013`, 0.9340918617226122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 294}], {
             RGBColor[
             0.18446317038438925`, 0.311212866087469, 0.9338162767133609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 296}], {
             RGBColor[
             0.18183178255671295`, 0.30844711064095676`, 0.9336664230693641]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 312}], {
             RGBColor[
             0.1882015984664733, 0.31514219103177, 0.9340291746621268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 327}], {
             RGBColor[
             0.18260674360457746`, 0.3092616438376308, 0.933710555954588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 334}], {
             RGBColor[
             0.18414474445457316`, 0.31087818024586233`, 0.9337981428277268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 385}], {
             RGBColor[
             0.18149489941754873`, 0.3080930251020705, 0.9336472380729627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 415}], {
             RGBColor[
             0.18091671513236096`, 0.30748531675933716`, 0.9336143113332682]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 446}], {
             RGBColor[
             0.18242070987008802`, 0.30906611058746236`, 0.933699961608621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 144}], {
             RGBColor[
             0.1939326542641488, 0.3211658940450518, 0.9343555498114672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 215}], {
             RGBColor[
             0.18797465353578718`, 0.3149036575204792, 0.9340162504840592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 223}], {
             RGBColor[
             0.1995856510144891, 0.3271075520503548, 0.9346774796135398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 268}], {
             RGBColor[
             0.18864406926620203`, 0.3156072558965539, 0.9340543727195945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 402}], {
             RGBColor[
             0.20455792141877943`, 0.3323337235054161, 0.9349606430572492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 417}], {
             RGBColor[
             0.19405888879625283`, 0.3212985745420247, 0.9343627386813232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 143}], {
             RGBColor[
             0.4285653763865951, 0.5391828000638526, 0.9495933114012363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 165}], {
             RGBColor[
             0.2912027626996634, 0.4234029452918576, 0.9398949385886397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 185}], {
             RGBColor[
             0.24400994073613447`, 0.3738002972104551, 0.9372073771933402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 187}], {
             RGBColor[
             0.24886259772016034`, 0.3789007473768896, 0.9374837288297179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 224}], {
             RGBColor[
             0.2412066178691736, 0.37085382713634363`, 0.9370477321032114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 277}], {
             RGBColor[
             0.35985275808300965`, 0.4831247951827711, 0.9442597110251651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 313}], {
             RGBColor[
             0.3188496851508186, 0.44760999428327536`, 0.9416470314755198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 333}], {
             RGBColor[
             0.2541335864563355, 0.3844408907385981, 0.937783903840514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 358}], {
             RGBColor[
             0.2506809998117433, 0.38081200326849496`, 0.9375872841387487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 361}], {
             RGBColor[
             0.25328984688463263`, 0.3835540669525598, 0.9377358541201064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 386}], {
             RGBColor[
             0.2910406970756628, 0.423232604045479, 0.9398857091911075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 441}], {
             RGBColor[
             0.24897326082313725`, 0.37901706131456436`, 0.9374900309297209]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 140}], {
             RGBColor[
             0.1812891715754636, 0.30787679209614044`, 0.933635522176703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 155}], {
             RGBColor[
             0.1887434182573529, 0.3157116779853434, 0.9340600304976668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 156}], {
             RGBColor[
             0.19147940284680726`, 0.31858737126030207`, 0.9342158407725099]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 198}], {
             RGBColor[
             0.18298777738438862`, 0.30966213449914926`, 0.9337322552646592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 270}], {
             RGBColor[
             0.18183894581371152`, 0.308454639678239, 0.933666831006253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 479}], {
             RGBColor[
             0.1829410540251313, 0.30961302528613777`, 0.9337295944384705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 152}], {
             RGBColor[
             0.1882232378558979, 0.3151649354020718, 0.9340304069933419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 187}], {
             RGBColor[
             0.20672865124829637`, 0.33461529818845887`, 0.9350842629097332]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.19015295783973063`, 0.31719319345639363`, 0.9341403016916563]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 255}], {
             RGBColor[
             0.19469073239539242`, 0.3219626822259184, 0.9343987212395655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 260}], {
             RGBColor[
             0.20098092756456265`, 0.3285740761701249, 0.9347569385489398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 292}], {
             RGBColor[
             0.188665488336347, 0.3156297686973238, 0.9340555925039526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 399}], {
             RGBColor[
             0.200045010570769, 0.32759036806908304`, 0.9347036394607084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 446}], {
             RGBColor[
             0.18780907665371493`, 0.3147296257192406, 0.9340068211255742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 464}], {
             RGBColor[
             0.1973325308094801, 0.3247393798588184, 0.9345491677510571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 481}], {
             RGBColor[
             0.1987399075504107, 0.32621862204637564`, 0.9346293157744259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 496}], {
             RGBColor[
             0.18901315212113398`, 0.315995185378292, 0.9340753914421738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 120}], {
             RGBColor[
             0.18211134871711507`, 0.30874095240105776`, 0.9336823439486179]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 124}], {
             RGBColor[
             0.18484388120986256`, 0.311613017303502, 0.9338379576316604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 363}], {
             RGBColor[
             0.18346622269800678`, 0.3101650108589469, 0.9337595020174734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 364}], {
             RGBColor[
             0.19435544195191212`, 0.32161027071117865`, 0.934379626944827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 381}], {
             RGBColor[
             0.18630903659373593`, 0.3131529885081697, 0.9339213960632688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 416}], {
             RGBColor[
             0.19677397614642037`, 0.32415230349353147`, 0.9345173588893034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 124}], {
             RGBColor[
             0.18263624540769638`, 0.3092926521032311, 0.9337122360386315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 315}], {
             RGBColor[
             0.18165682168185682`, 0.3082632156683228, 0.9336564593063725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 363}], {
             RGBColor[
             0.18125858689584057`, 0.307844645658676, 0.9336337804244444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 381}], {
             RGBColor[
             0.18410140079156978`, 0.3108326233078988, 0.9337956744702399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 196}], {
             RGBColor[
             0.19856429776732792`, 0.3260340450300523, 0.9346193150570707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.20367497522683542`, 0.331405691075661, 0.93491036057782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 307}], {
             RGBColor[
             0.1984527242001829, 0.32591677413681014`, 0.93461296110748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 337}], {
             RGBColor[
             0.19710919882017952`, 0.3245046437779975, 0.9345364493246566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 420}], {
             RGBColor[
             0.1965885249531354, 0.3239573825311042, 0.9345067977181964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 427}], {
             RGBColor[
             0.19582329677639237`, 0.3231530791990786, 0.9344632191055845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 442}], {
             RGBColor[
             0.22151836933651753`, 0.35016022962146637`, 0.9359265154754303]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 447}], {
             RGBColor[
             0.21943101242653507`, 0.34796628516300276`, 0.9358076435873746]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 454}], {
             RGBColor[
             0.20826238807822112`, 0.3362273528412414, 0.9351716069532372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 489}], {
             RGBColor[
             0.1983767553672155, 0.32583692607665915`, 0.9346086347948284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 500}], {
             RGBColor[
             0.20306057228198376`, 0.33075991462522525`, 0.9348753712390383]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 185}], {
             RGBColor[
             0.19860974920189184`, 0.3260818173695664, 0.9346219034490297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 212}], {
             RGBColor[
             0.18381215152445518`, 0.3105286039886985, 0.9337792021523836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 216}], {
             RGBColor[
             0.19279683115434215`, 0.3199720719413004, 0.9342908663656634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 217}], {
             RGBColor[
             0.1834604918576584, 0.31015898738238445`, 0.9337591756545935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 224}], {
             RGBColor[
             0.195806426334931, 0.3231353472954549, 0.9344622583589008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 286}], {
             RGBColor[
             0.1865372127264831, 0.3133928160908893, 0.9339343903564724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 319}], {
             RGBColor[
             0.1832707103845271, 0.30995951502128316`, 0.9337483678804552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 330}], {
             RGBColor[
             0.18762963037517022`, 0.3145410163029389, 0.9339966019254781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 357}], {
             RGBColor[
             0.18711144917701383`, 0.313996375009091, 0.9339670922728234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 492}], {
             RGBColor[
             0.1841436405662557, 0.3108770199892501, 0.9337980799629202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 139}], {
             RGBColor[
             0.1842229343035432, 0.31096036273465255`, 0.9338025956239542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 158}], {
             RGBColor[
             0.1887768797193095, 0.31574684810343895`, 0.9340619360784235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 193}], {
             RGBColor[
             0.18338517057960285`, 0.31007981994350325`, 0.9337548862192361]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 401}], {
             RGBColor[
             0.18328689846403934`, 0.309976529719234, 0.9337492897676354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 410}], {
             RGBColor[
             0.18404732868398718`, 0.3107757900944599, 0.9337925951437056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 422}], {
             RGBColor[
             0.1961933017960193, 0.3235419779343797, 0.9344842903440789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 428}], {
             RGBColor[
             0.18681025928894113`, 0.3136798053401847, 0.9339499399542682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 437}], {
             RGBColor[
             0.18388303382001714`, 0.3106031057755313, 0.9337832387942551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 363}], {
             RGBColor[
             0.1839911193885881, 0.3107167105611202, 0.9337893941074868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 381}], {
             RGBColor[
             0.18683393328431724`, 0.31370468821034303`, 0.9339512881532823]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 416}], {
             RGBColor[
             0.19729887283700168`, 0.3247040031957048, 0.934547250979317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.669539684263013, 0.7405244264891351, 0.9685478722425018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 173}], {
             RGBColor[
             0.7492734803038996, 0.8040574045935522, 0.9756442362240689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 242}], {
             RGBColor[
             0.8755313279725643, 0.9029638772422787, 0.9544497242112633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 249}], {
             RGBColor[
             0.7524497512082946, 0.8065387315646185, 0.9759608172238798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 269}], {
             RGBColor[
             0.6899118040266511, 0.7570634310667932, 0.970151640135829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 282}], {
             RGBColor[
             0.7373315894354715, 0.794728308685404, 0.9744539801456191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 305}], {
             RGBColor[
             0.5442522046967718, 0.6349340468295404, 0.9597558326180513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 310}], {
             RGBColor[
             0.7113812015825887, 0.7744556684644794, 0.9718674880046061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 323}], {
             RGBColor[
             0.8853299376421364, 0.9088564954320449, 0.8744890811044619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 406}], {
             RGBColor[
             0.5972259557238873, 0.6808172474310844, 0.9631312731906503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 408}], {
             RGBColor[
             0.8576169370417068, 0.8896033538181681, 0.9847741152357485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 419}], {
             RGBColor[
             0.7136180387569662, 0.7762031026656953, 0.9720904350297161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 173}], {
             RGBColor[
             0.6045267350947843, 0.6886225535376819, 0.9628291330052186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 249}], {
             RGBColor[
             0.6077030059991793, 0.6911038805087482, 0.9631457140050295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 269}], {
             RGBColor[
             0.5451650588175359, 0.6416285800109227, 0.9573365369169786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 282}], {
             RGBColor[
             0.5925848442263562, 0.6792934576295336, 0.9616388769267687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 340}], {
             RGBColor[
             0.4261246264730337, 0.5425553802981693, 0.948636879181104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 384}], {
             RGBColor[
             0.3782656319739345, 0.49734201260730226`, 0.9457250298186803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 414}], {
             RGBColor[
             0.45556143140572114`, 0.5680520611940277, 0.9505125663614704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 449}], {
             RGBColor[
             0.7360314578812237, 0.7759766732200013, 0.6718437842469422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 499}], {
             RGBColor[
             0.5585145617417738, 0.6524663078730726, 0.9583874586880152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 184}], {
             RGBColor[
             0.6864931860475436, 0.7535560913976342, 0.970424092580223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 221}], {
             RGBColor[
             0.8972130382069989, 0.8767030519388234, 0.6458996213784399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 253}], {
             RGBColor[
             0.604821677598294, 0.6851926412626169, 0.9645634759762418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 301}], {
             RGBColor[
             0.7442995113076243, 0.8002700424356418, 0.9751223810067287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 303}], {
             RGBColor[
             0.8364744443127496, 0.5917978023235237, 0.5852770137807005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 316}], {
             RGBColor[
             0.6354319607294284, 0.7117057299932411, 0.9665139361497471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 138}], {
             RGBColor[
             0.18851306554638397`, 0.31546956268090953`, 0.9340469122515535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 179}], {
             RGBColor[
             0.19718406775789482`, 0.32458333577850107`, 0.9345407129999008]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 222}], {
             RGBColor[
             0.19567917188119596`, 0.32300159479618107`, 0.9344550114060167]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 245}], {
             RGBColor[
             0.21909064595633707`, 0.347608538422344, 0.9357882602204238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 294}], {
             RGBColor[
             0.1908740507973531, 0.317951107874789, 0.9341813668688315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 296}], {
             RGBColor[
             0.1882426629696768, 0.3151853524282767, 0.9340315132248347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 312}], {
             RGBColor[
             0.19461247887943717`, 0.32188043281908996`, 0.9343942648175974]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 385}], {
             RGBColor[
             0.1879057798305126, 0.31483126688939045`, 0.9340123282284333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 415}], {
             RGBColor[
             0.1873275955453248, 0.3142235585466571, 0.9339794014887388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 438}], {
             RGBColor[
             0.19844895166515433`, 0.32591280896330255`, 0.9346127462671912]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 439}], {
             RGBColor[
             0.1967431917255388, 0.32411994711534, 0.9345156057620757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 204}], {
             RGBColor[
             0.3026394845996296, 0.4347619361650844, 0.9405704721210151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 275}], {
             RGBColor[
             0.3893440856753081, 0.5088837722097477, 0.9463652522390695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 276}], {
             RGBColor[
             0.2514871752437865, 0.381659344762047, 0.9376331946369739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 306}], {
             RGBColor[
             0.2650729238792713, 0.39593882796415625`, 0.9384068829234508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 331}], {
             RGBColor[
             0.2954052676483876, 0.42782004444717026`, 0.9401342650284206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 346}], {
             RGBColor[
             0.36539555977117477`, 0.4891180942666259, 0.9445692337379277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 348}], {
             RGBColor[
             0.37572812244985154`, 0.497829719871169, 0.9452933537370448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 355}], {
             RGBColor[
             0.4245428223807357, 0.5374596923522321, 0.9491362257297418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 431}], {
             RGBColor[
             0.35531389648617895`, 0.48038586424829277`, 0.9439268390682725]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 444}], {
             RGBColor[
             0.42761995292876165`, 0.539957845554271, 0.9493784687183828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 486}], {
             RGBColor[
             0.3513552004898414, 0.47695704074611134`, 0.9436745944599232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 175}], {
             RGBColor[
             0.350298253723786, 0.4772937364222603, 0.943561398674819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 182}], {
             RGBColor[
             0.323958117743938, 0.4544792345302443, 0.9418830285018508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 208}], {
             RGBColor[
             0.3647668975032984, 0.4898257484488929, 0.9444833278623301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 238}], {
             RGBColor[
             0.39480407867420486`, 0.5149363424561325, 0.9466476293366854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 241}], {
             RGBColor[
             0.2592745192308342, 0.38984433703856036`, 0.9380766723566932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 351}], {
             RGBColor[
             0.2715547401921379, 0.40275162787986996`, 0.9387760127734806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 371}], {
             RGBColor[
             0.27850064570472033`, 0.41005221496943967`, 0.9391715718168758]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 442}], {
             RGBColor[
             0.2704116943765009, 0.4015502142543449, 0.9387109180052648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 483}], {
             RGBColor[
             0.3774799425420655, 0.5008371490852502, 0.9452933918504961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 186}], {
             RGBColor[
             0.913526249632497, 0.6241954645463874, 0.3472925437386266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 234}], {
             RGBColor[
             0.88005378670787, 0.5030425365640092, 0.21977647609763581`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 373}], {
             RGBColor[
             0.9123644303428394, 0.625404830056993, 0.48937807328246297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 434}], {
             RGBColor[
             0.8844045850628767, 0.520292002224005, 0.22327723058043727`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 449}], {
             RGBColor[
             0.9086679607710296, 0.6083135329493521, 0.2853739255705805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 495}], {
             RGBColor[
             0.8599106722287021, 0.41795803680078086`, 0.20329863351297417`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 250}], {
             RGBColor[
             0.24597806511608875`, 0.3758689207200801, 0.9373194589651996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 356}], {
             RGBColor[
             0.2588153820462965, 0.38936175474663237`, 0.9380505251732665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 365}], {
             RGBColor[
             0.23967912019619636`, 0.3692483302330984, 0.9369607433704656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 457}], {
             RGBColor[
             0.37078286929344473`, 0.4917742570671961, 0.9450898009992874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 494}], {
             RGBColor[
             0.3138085366833637, 0.4428585774611083, 0.9413399116919258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 191}], {
             RGBColor[
             0.19428859491049005`, 0.32154001023229684`, 0.9343758201047092]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 237}], {
             RGBColor[
             0.21543537025685555`, 0.3437666119043239, 0.9355800976768341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 241}], {
             RGBColor[
             0.2068052594645497, 0.3346958182809826, 0.9350886256343172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 271}], {
             RGBColor[
             0.20303817120051487`, 0.3307363696682909, 0.9348740955305881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 304}], {
             RGBColor[
             0.19434480354761932`, 0.3215990890737532, 0.9343790211034406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 311}], {
             RGBColor[
             0.19398258593487913`, 0.3212183753968402, 0.9343583933462479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 351}], {
             RGBColor[
             0.21908548042585338`, 0.34760310912229214`, 0.9357879660511045]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 366}], {
             RGBColor[
             0.1902687027163505, 0.3173148486603702, 0.9341468931911505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 371}], {
             RGBColor[
             0.22603138593843586`, 0.35490369621186185`, 0.9361835250944996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 405}], {
             RGBColor[
             0.18981989868512106`, 0.3168431271677289, 0.9341213344655181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 423}], {
             RGBColor[
             0.18859024302857952`, 0.3155506811080321, 0.9340513073949906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 429}], {
             RGBColor[
             0.19496484613925177`, 0.3222507931505298, 0.9344143316117632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 469}], {
             RGBColor[
             0.18966655655355485`, 0.31668195486500017`, 0.9341126018579748]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 488}], {
             RGBColor[
             0.19025464326071956`, 0.31730007128108106`, 0.9341460925259515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 174}], {
             RGBColor[
             0.18580423451035571`, 0.31262240951223635`, 0.9338926483314081]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 210}], {
             RGBColor[
             0.18982747480213708`, 0.31685109014706625`, 0.9341217659141743]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 225}], {
             RGBColor[
             0.1840482113903489, 0.31077671787481287`, 0.933792645412527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 247}], {
             RGBColor[
             0.1842053003124589, 0.3109418282919634, 0.933801591394249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 252}], {
             RGBColor[
             0.18321908491971373`, 0.3099052533845207, 0.9337454278866071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 278}], {
             RGBColor[
             0.18429769316254274`, 0.3110389390354465, 0.9338068530303782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 309}], {
             RGBColor[
             0.18616361548114224`, 0.31300014169860263`, 0.9339131145460378]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 424}], {
             RGBColor[
             0.18880157011833354`, 0.31577279927827495`, 0.9340633421601217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 169}], {
             RGBColor[
             0.1819041358977289, 0.3085231585898313, 0.9336705434850978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 211}], {
             RGBColor[
             0.18373947818140363`, 0.31045221969739534`, 0.9337750635130075]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 362}], {
             RGBColor[
             0.1796163784049865, 0.3061185804127562, 0.9335402590803201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 369}], {
             RGBColor[
             0.18101136995755066`, 0.307584804982074, 0.9336197017855334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 466}], {
             RGBColor[
             0.18744105358565671`, 0.3143428101407012, 0.9339858627562896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 470}], {
             RGBColor[
             0.18730486737300778`, 0.31419966979650255`, 0.9339781071529487]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 240}], {
             RGBColor[
             0.7615140918759296, 0.8095862292350475, 0.8160223615071904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 434}], {
             RGBColor[
             0.7316510467407765, 0.7040970288480641, 0.6113123490612679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 148}], {
             RGBColor[
             0.24314559520540308`, 0.3728918152549845, 0.9371581539940498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 156}], {
             RGBColor[
             0.2055253114742025, 0.33335051178973785`, 0.9350157344897803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 227}], {
             RGBColor[
             0.2024073413896048, 0.33007332754010427`, 0.9348381707060858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 229}], {
             RGBColor[
             0.2232482662355424, 0.35197846094413987`, 0.9360250305446766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 263}], {
             RGBColor[
             0.21799699214111928`, 0.34645903892089325`, 0.935725978253563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 265}], {
             RGBColor[
             0.19798921213274367`, 0.325429593565569, 0.934586564780944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 267}], {
             RGBColor[
             0.22045636616771785`, 0.34904399695616795`, 0.93586603596606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 280}], {
             RGBColor[
             0.2325647771126936, 0.3617707045769326, 0.9365555920565876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 393}], {
             RGBColor[
             0.21648582185917808`, 0.3448707031408432, 0.9356399193415825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 424}], {
             RGBColor[
             0.20256381379959026`, 0.3302377899639228, 0.9348470815783543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 485}], {
             RGBColor[
             0.2335003285987162, 0.3627540285061326, 0.9366088703296922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 179}], {
             RGBColor[
             0.19144105687703156`, 0.31854706721479287`, 0.9342136570262589]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 222}], {
             RGBColor[
             0.1899361610003327, 0.31696532623247287`, 0.9341279554323748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 294}], {
             RGBColor[
             0.18513103991648983`, 0.3119148393110808, 0.9338543108951896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 296}], {
             RGBColor[
             0.18249965208881352`, 0.3091490838645686, 0.9337044572511928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 339}], {
             RGBColor[
             0.1814781394477339, 0.3080754093111516, 0.9336462836174759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 385}], {
             RGBColor[
             0.18216276894964933`, 0.30879499832568225`, 0.9336852722547914]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 415}], {
             RGBColor[
             0.18158458466446153`, 0.308187289982949, 0.9336523455150969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 438}], {
             RGBColor[
             0.19270594078429107`, 0.3198765403995944, 0.9342856902935492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 158}], {
             RGBColor[
             0.18715334052902155`, 0.3140404054761162, 0.9339694779233476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 247}], {
             RGBColor[
             0.18343934894517555`, 0.310136764840827, 0.9337579715970057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 278}], {
             RGBColor[
             0.18353174179525936`, 0.31023387558431004`, 0.933763233233135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 401}], {
             RGBColor[
             0.18166335927375138`, 0.3082700870919113, 0.9336568316125594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 410}], {
             RGBColor[
             0.18242378949369925`, 0.3090693474671371, 0.9337001369886297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 428}], {
             RGBColor[
             0.1851867200986532, 0.311973362712862, 0.9338574817991923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 437}], {
             RGBColor[
             0.18225949462972918`, 0.3088966631482086, 0.9336907806391791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 451}], {
             RGBColor[
             0.19384306282883684`, 0.3210717277661138, 0.9343504477117648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 198}], {
             RGBColor[
             0.18071298100430727`, 0.3072711792732629, 0.9336027089760732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 270}], {
             RGBColor[
             0.1795641494336302, 0.30606368445235266`, 0.9335372847176671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 479}], {
             RGBColor[
             0.18066625764504995`, 0.3072220700602514, 0.9336000481498845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 151}], {
             RGBColor[
             0.20551109996107267`, 0.3333355745883765, 0.9350149251651315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 160}], {
             RGBColor[
             0.2233789267066098, 0.352115793383584, 0.936032471465209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 162}], {
             RGBColor[
             0.19531753931264573`, 0.32262149603780554`, 0.9344344169662252]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 167}], {
             RGBColor[
             0.22358607838206196`, 0.35233352292865905`, 0.9360442684466725]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 235}], {
             RGBColor[
             0.21221346212045616`, 0.34038018217219357`, 0.9353966147748521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 274}], {
             RGBColor[
             0.2256966978230941, 0.35455191778218553`, 0.9361644651014577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 284}], {
             RGBColor[
             0.20706959880896725`, 0.33497365569204784`, 0.9351036793689267]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 300}], {
             RGBColor[
             0.21958614921582648`, 0.3481293437647886, 0.9358164783980203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 345}], {
             RGBColor[
             0.19907503548324326`, 0.3265708627521209, 0.9346484008144234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 389}], {
             RGBColor[
             0.20111521708192343`, 0.32871522296731825`, 0.9347645861382899]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 432}], {
             RGBColor[
             0.24927102921021138`, 0.3793300347689854, 0.937506988398856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 456}], {
             RGBColor[
             0.20146025215418084`, 0.3290778767047479, 0.9347842353752214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 472}], {
             RGBColor[
             0.19522243291560842`, 0.32252153318442556`, 0.9344290007976113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[
             0.2155365862389103, 0.34387299631892737`, 0.9355858617772765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 161}], {
             RGBColor[
             0.21478163330642375`, 0.3430794929201034, 0.9355428683246243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 183}], {
             RGBColor[
             0.20633874170827649`, 0.3342054785402052, 0.9350620581382485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 254}], {
             RGBColor[
             0.20407108545370353`, 0.33182202803893834`, 0.9349329184692474]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 285}], {
             RGBColor[
             0.2150502131881199, 0.3433617874047141, 0.9355581635515585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 388}], {
             RGBColor[
             0.27220031221012625`, 0.4015863957278337, 0.9388802865699359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 396}], {
             RGBColor[
             0.2065755605048984, 0.3344543901106338, 0.9350755446183742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 473}], {
             RGBColor[
             0.23965328121814944`, 0.36922117182888525`, 0.9369592718788913]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 477}], {
             RGBColor[
             0.2067532217668407, 0.3346411233613098, 0.9350856621644155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 165}], {
             RGBColor[
             0.4432891969739572, 0.5546584690453142, 0.950431811201746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 178}], {
             RGBColor[
             0.5249805981564001, 0.6252419255466224, 0.9557475422356184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 186}], {
             RGBColor[
             0.7869875185761387, 0.829282852672385, 0.7373913878754195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 277}], {
             RGBColor[
             0.5119391923573035, 0.6143803189362278, 0.9547965836382715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 288}], {
             RGBColor[
             0.6459376056374727, 0.7223853584829198, 0.9659909719465696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 313}], {
             RGBColor[
             0.4709361194251123, 0.5788655180367319, 0.9521839040886261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 321}], {
             RGBColor[
             0.78304348190439, 0.8293416997957703, 0.9255854595882844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 373}], {
             RGBColor[
             0.7858256992864812, 0.8304922181829903, 0.8794769174192558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 386}], {
             RGBColor[
             0.4431271313499566, 0.5544881277989356, 0.9504225818042138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 414}], {
             RGBColor[
             0.5016592032391687, 0.6054763090493759, 0.9541415518219014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 498}], {
             RGBColor[
             0.6776190672953443, 0.7471351571180758, 0.9691486839645342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 145}], {
             RGBColor[
             0.20296158096381922`, 0.33065586847342227`, 0.9348697338299133]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 215}], {
             RGBColor[
             0.19092068807717077`, 0.3180001266128517, 0.9341840227929235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 246}], {
             RGBColor[
             0.21838885852257034`, 0.34687091533356196`, 0.9357482944642723]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 375}], {
             RGBColor[
             0.1998107076045579, 0.3273441007959291, 0.9346902962534028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 402}], {
             RGBColor[
             0.20750395596016302`, 0.3354301925977886, 0.9351284153661135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 417}], {
             RGBColor[
             0.19700492333763642`, 0.3243950436343972, 0.9345305109901875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 458}], {
             RGBColor[
             0.21795043797046626`, 0.346410107535832, 0.935723327062415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 367}], {
             RGBColor[
             0.2030970423728074, 0.33079824700301824`, 0.9348774481567581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 375}], {
             RGBColor[
             0.20589359976284474`, 0.33373760613192704`, 0.9350367079629848]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 402}], {
             RGBColor[
             0.21358684811844986`, 0.34182369793378664`, 0.9354748270756954]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 417}], {
             RGBColor[
             0.20308781549592325`, 0.3307885489703952, 0.9348769226997694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 450}], {
             RGBColor[
             0.21228550631692578`, 0.340455905190549, 0.9354007175852613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 458}], {
             RGBColor[
             0.2240333301287531, 0.35280361287183004`, 0.936069738771997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 461}], {
             RGBColor[
             0.23115805437216275`, 0.3602921497852615, 0.9364754812775742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 166}], {
             RGBColor[
             0.18787743892822623`, 0.31480147880417053`, 0.9340107142559747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 239}], {
             RGBColor[
             0.18835872742063176`, 0.3153073435251416, 0.9340381229236147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 248}], {
             RGBColor[
             0.18017302617267333`, 0.306703652510102, 0.9335719593472032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 387}], {
             RGBColor[
             0.18448194243535776`, 0.3112325967032537, 0.9338173457538927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 221}], {
             RGBColor[
             0.8906777697244648, 0.5160364512426465, 0.23692570222520362`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 234}], {
             RGBColor[
             0.872729313424225, 0.4467434253012546, 0.2127625522094079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 242}], {
             RGBColor[
             0.8960966123696098, 0.5635667746530044, 0.5481508384278233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 303}], {
             RGBColor[
             0.8299391758302155, 0.23113120162734693`, 0.17630309462746424`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 323}], {
             RGBColor[
             0.905895222039182, 0.5694593928427707, 0.46819019532102185`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 449}], {
             RGBColor[
             0.9013434874873846, 0.5520144216865974, 0.2783600016823526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 229}], {
             RGBColor[
             0.25473807623061007`, 0.385076247818226, 0.9378183286388965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 232}], {
             RGBColor[
             0.27654750718772436`, 0.40799934255194237`, 0.9390603434677424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 263}], {
             RGBColor[
             0.24948680213618696`, 0.3795568257949794, 0.9375192763477829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 267}], {
             RGBColor[
             0.25194617616278553`, 0.3821417838302541, 0.9376593340602799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 280}], {
             RGBColor[
             0.2640545871077613, 0.39486849145101877`, 0.9383488901508075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 342}], {
             RGBColor[
             0.3754741855106375, 0.4958604756469023, 0.9454338500155093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 393}], {
             RGBColor[
             0.24797563185424576`, 0.37796849001492944`, 0.9374332174358024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 480}], {
             RGBColor[
             0.25899827885189075`, 0.38955399088563913`, 0.9380609408757734]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 485}], {
             RGBColor[
             0.26499013859378384`, 0.39585181538021874`, 0.9384021684239121]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 173}], {
             RGBColor[
             0.6408634071546884, 0.7181223008643338, 0.9656896889353898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 242}], {
             RGBColor[
             0.767121254823353, 0.8170287735130601, 0.9444951769225841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 249}], {
             RGBColor[
             0.6440396780590834, 0.7206036278354, 0.9660062699352006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 269}], {
             RGBColor[
             0.5815017308774398, 0.6711283273375747, 0.9601970928471498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 282}], {
             RGBColor[
             0.6289215162862603, 0.7087932049561856, 0.9644994328569398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 310}], {
             RGBColor[
             0.6029711284333774, 0.688520564735261, 0.9619129407159268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 314}], {
             RGBColor[
             0.41196878637874557`, 0.5240737659037882, 0.9484356108143341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 323}], {
             RGBColor[
             0.7769198644929252, 0.8229213917028264, 0.8645345338157826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 406}], {
             RGBColor[
             0.48881588257467606`, 0.5948821437018659, 0.9531767259019711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 411}], {
             RGBColor[
             0.4211694508709569, 0.5337442476409241, 0.9489595750460023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 419}], {
             RGBColor[
             0.6052079656077549, 0.6902679989364768, 0.962135887741037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 220}], {
             RGBColor[
             0.21619691693173887`, 0.3445670457444743, 0.9356234666333614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 254}], {
             RGBColor[
             0.20389499448692971`, 0.33163694526804693`, 0.9349228903491928]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 325}], {
             RGBColor[
             0.2244980131258032, 0.35329202416433336`, 0.9360962017812421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 392}], {
             RGBColor[
             0.22610554162039614`, 0.3549816385353439, 0.9361877481508839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 412}], {
             RGBColor[
             0.20280807626052344`, 0.33049452529749807`, 0.9348609919641505]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 426}], {
             RGBColor[
             0.20135872025195078`, 0.3289711602380097, 0.9347784532835923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 473}], {
             RGBColor[
             0.23947719025137565`, 0.36903608905799384`, 0.9369492437588367]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 160}], {
             RGBColor[
             0.22158100780321188`, 0.3502260666214703, 0.9359300826434431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 162}], {
             RGBColor[
             0.1935196204092478, 0.32073176927569186`, 0.9343320281444594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 226}], {
             RGBColor[
             0.19534643528489967`, 0.3226518675367549, 0.9344360625490973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 235}], {
             RGBColor[
             0.21041554321705824`, 0.3384904554100799, 0.9352942259530863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 237}], {
             RGBColor[
             0.2183016735730191, 0.3467792784237385, 0.9357433294103739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 274}], {
             RGBColor[
             0.22389877891969617`, 0.3526621910200718, 0.9360620762796918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 284}], {
             RGBColor[
             0.20527167990556933`, 0.33308392892993416`, 0.9350012905471609]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 345}], {
             RGBColor[
             0.19727711657984534`, 0.32468113599000714`, 0.9345460119926574]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 389}], {
             RGBColor[
             0.1993172981785255, 0.3268254962052045, 0.9346621973165241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 456}], {
             RGBColor[
             0.19966233325078292`, 0.32718814994263423`, 0.9346818465534554]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 472}], {
             RGBColor[
             0.1934245140122105, 0.3206318064223118, 0.9343266119758453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 195}], {
             RGBColor[
             0.18616514652705513`, 0.313001750924931, 0.9339132017368377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 216}], {
             RGBColor[
             0.19207526490404528`, 0.31921366006229573`, 0.9342497742351705]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 217}], {
             RGBColor[
             0.18273892560736155`, 0.30940057550337985`, 0.9337180835241007]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 292}], {
             RGBColor[
             0.18467767702367152`, 0.3114383261658612, 0.9338284925491338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 398}], {
             RGBColor[
             0.19524728601816377`, 0.32254765537098895`, 0.934430416145035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 399}], {
             RGBColor[
             0.19605719925809356`, 0.3233989255376204, 0.9344765395058896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 464}], {
             RGBColor[
             0.19334471949680462`, 0.32054793732735576`, 0.9343220677962385]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 481}], {
             RGBColor[
             0.1947520962377352, 0.322027179514913, 0.9344022158196071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 496}], {
             RGBColor[
             0.1850253408084585, 0.31180374284682943`, 0.9338482914873549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 172}], {
             RGBColor[
             0.22556462734887084`, 0.3544131033400252, 0.9361569438833315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 197}], {
             RGBColor[
             0.22926543037868818`, 0.35830288196882765`, 0.9363676991410321]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 201}], {
             RGBColor[
             0.2425444285480653, 0.37225995098195497`, 0.9371239184422607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 223}], {
             RGBColor[
             0.21791092009915627`, 0.34636857174750746`, 0.9357210765781054]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 236}], {
             RGBColor[
             0.21799828044158207`, 0.3464603930063626, 0.9357260516203685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 289}], {
             RGBColor[
             0.21885506273912853`, 0.34736092552421916`, 0.935774844104718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 314}], {
             RGBColor[
             0.24522255976789442`, 0.3750748366973221, 0.93727643405329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 411}], {
             RGBColor[
             0.2544232242601058, 0.38474531843445803`, 0.937800398284958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 466}], {
             RGBColor[
             0.2112617016772801, 0.3393798216013181, 0.9353424134256167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 470}], {
             RGBColor[
             0.2111255154646311, 0.3392366812571194, 0.9353346578222758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 493}], {
             RGBColor[
             0.24427091854425903`, 0.3740746014337428, 0.9372222394934309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 199}], {
             RGBColor[
             0.684800695862128, 0.748031110338605, 0.9293475993147051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[
             0.9142690676811895, 0.6673158743356673, 0.5518317374650853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 219}], {
             RGBColor[
             0.8264967277029731, 0.8644743578312362, 0.9402829367923042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 244}], {
             RGBColor[
             0.7150943787471429, 0.7742699758488314, 0.9312778860004862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 295}], {
             RGBColor[
             0.9841314996436169, 0.9875855475713144, 0.9072523679449918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 341}], {
             RGBColor[
             0.9888822096717337, 0.9887006265396945, 0.7667739089616505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 374}], {
             RGBColor[
             0.9154556938707563, 0.6764368032115899, 0.5529680520443171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 376}], {
             RGBColor[
             0.6772879972861523, 0.7415239884313045, 0.9288688968046623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 397}], {
             RGBColor[
             0.9027384271430544, 0.5786863184006587, 0.5407899830637712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 455}], {
             RGBColor[
             0.7982558492888101, 0.8419633098945049, 0.937775174104184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 198}], {
             RGBColor[
             0.1881672276861966, 0.31510606516246586`, 0.934027217297037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 250}], {
             RGBColor[
             0.2067822292135854, 0.3346716120270169, 0.9350873140955949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 365}], {
             RGBColor[
             0.200483284293693, 0.3280510215400352, 0.934728598500861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 394}], {
             RGBColor[
             0.1886886358497215, 0.3156540982015175, 0.9340569107205956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 467}], {
             RGBColor[
             0.19253479608250443`, 0.31969665646681583`, 0.9342759438559683]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 479}], {
             RGBColor[
             0.18812050432693928`, 0.3150569559494543, 0.9340245564708484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 198}], {
             RGBColor[
             0.19090321227565094`, 0.31798175843742454`, 0.93418302757188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 227}], {
             RGBColor[
             0.1962768676534719, 0.3236298109489438, 0.9344890492960363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 250}], {
             RGBColor[
             0.20951821380303975`, 0.3375473053019756, 0.9352431243704379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 263}], {
             RGBColor[
             0.21186651840498638`, 0.34001552232973276`, 0.9353768568435135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 270}], {
             RGBColor[
             0.18975438070497386`, 0.3167742636165143, 0.9341176033134739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 479}], {
             RGBColor[
             0.19085648891639362`, 0.317932649224413, 0.9341803667456914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 485}], {
             RGBColor[
             0.22736985486258326`, 0.3563105119149721, 0.9362597489196426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 190}], {
             RGBColor[
             0.2578198120642154, 0.3883153475726824, 0.9379938289356007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 356}], {
             RGBColor[
             0.272205938145604, 0.40343607821729777`, 0.9388130975335695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 360}], {
             RGBColor[
             0.44762961538947754`, 0.5573651742459853, 0.9508478770838158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.2086123729274203, 0.33659520910807084`, 0.9351915380726428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 193}], {
             RGBColor[
             0.1863155768050812, 0.3131598626849669, 0.9339217685186295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 247}], {
             RGBColor[
             0.18799329436094186`, 0.3149232502096133, 0.9340173120514751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 278}], {
             RGBColor[
             0.18808568721102567`, 0.3150203609530965, 0.9340225736876044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 370}], {
             RGBColor[
             0.21023358203312498`, 0.3382992026687606, 0.9352838635328488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 401}], {
             RGBColor[
             0.1862173046895177, 0.3130565724606977, 0.9339161720670288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 410}], {
             RGBColor[
             0.18697773490946556`, 0.31385583283592355`, 0.933959477443099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 422}], {
             RGBColor[
             0.19912370802149765`, 0.3266220206758434, 0.9346511726434723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 428}], {
             RGBColor[
             0.1897406655144195, 0.31675984808164837`, 0.9341168222536617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 437}], {
             RGBColor[
             0.1868134400454955, 0.31368314851699497`, 0.9339501210936485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 451}], {
             RGBColor[
             0.19839700824460316`, 0.32585821313490027`, 0.9346097881662341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 166}], {
             RGBColor[
             0.21389899734106987`, 0.3421517865581641, 0.9354926035121403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 192}], {
             RGBColor[
             0.27255273720121065`, 0.4034082682269394, 0.9388472119027095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 239}], {
             RGBColor[
             0.2143802858334754, 0.34265765127913517`, 0.9355200121797802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 251}], {
             RGBColor[
             0.23552312226059172`, 0.3648801128972894, 0.936724065436281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 272}], {
             RGBColor[
             0.24467152920527638`, 0.37449566863865497`, 0.9372450536779255]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 344}], {
             RGBColor[
             0.2111960256367822, 0.3393107919186533, 0.9353386732722694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 435}], {
             RGBColor[
             0.23525737339525699`, 0.3646007939903714, 0.9367089314315404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 439}], {
             RGBColor[
             0.21567326392113564`, 0.34401665322881175`, 0.9355936453690827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 453}], {
             RGBColor[
             0.23602331412857852`, 0.36540584626453976`, 0.9367525506231953]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 167}], {
             RGBColor[
             0.2396559862242012, 0.36922401496175294`, 0.9369594259249842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 235}], {
             RGBColor[
             0.22828336996259535`, 0.35727067420528746`, 0.9363117722531638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 237}], {
             RGBColor[
             0.23616950031855627`, 0.3655594972189461, 0.9367608757104513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 274}], {
             RGBColor[
             0.24176660566523328`, 0.3714424098152794, 0.9370796225797693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 284}], {
             RGBColor[
             0.22313950665110643`, 0.35186414772514174`, 0.9360188368472383]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 300}], {
             RGBColor[
             0.2356560570579657, 0.36501983579788244`, 0.936731635876332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 305}], {
             RGBColor[
             0.2750017432650342, 0.40620742442870245`, 0.938978437324221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 389}], {
             RGBColor[
             0.21718512492406264`, 0.34560571500041215`, 0.9356797436166016]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 432}], {
             RGBColor[
             0.26534093705235057`, 0.3962205268020793, 0.9384221458771677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 460}], {
             RGBColor[
             0.27006121839103014`, 0.4011818417721542, 0.938690958916375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 183}], {
             RGBColor[
             0.2054076978090161, 0.33322689237048986`, 0.9350090365655417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 188}], {
             RGBColor[
             0.2189136351360459, 0.34742248882708376`, 0.9357781797160722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 202}], {
             RGBColor[
             0.2003053984953046, 0.32786405228731785`, 0.9347184681678012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 243}], {
             RGBColor[
             0.20521495427576572`, 0.33302430669639793`, 0.9349980601064616]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 273}], {
             RGBColor[
             0.20050467294518176`, 0.3280735023688687, 0.9347298165529216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 279}], {
             RGBColor[
             0.21091668232154126`, 0.339017184382946, 0.9353227650837177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 285}], {
             RGBColor[
             0.21411916928885952`, 0.34238320123499877`, 0.9355051419788516]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 287}], {
             RGBColor[
             0.25900221419710867`, 0.3895581271829785, 0.9380611649878617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 335}], {
             RGBColor[
             0.21211283365491676`, 0.3402744152746985, 0.9353908841326062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 354}], {
             RGBColor[
             0.262219161885439, 0.39276906224398844`, 0.9382506002184958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 396}], {
             RGBColor[
             0.205644516605638, 0.33347580394091847`, 0.9350225230456672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 409}], {
             RGBColor[
             0.23354210119449076`, 0.36279793415282724`, 0.9366112492172245]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 430}], {
             RGBColor[
             0.2077033952850149, 0.33563981597339154`, 0.9351397731406197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 459}], {
             RGBColor[
             0.20416528068413636`, 0.3319210331984458, 0.9349382827482713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 477}], {
             RGBColor[
             0.2058221778675803, 0.33366253719159444`, 0.9350326405917087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 226}], {
             RGBColor[
             0.18515287463647273`, 0.3119377889861841, 0.933855554350191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 284}], {
             RGBColor[
             0.19507811925714236`, 0.3223698503793633, 0.9344207823482545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 345}], {
             RGBColor[
             0.1870835559314184, 0.31396705743943626`, 0.9339655037937511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 389}], {
             RGBColor[
             0.18912373753009853`, 0.3161114176546337, 0.9340816891176178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 456}], {
             RGBColor[
             0.18946877260235598`, 0.3164740713920633, 0.9341013383545491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 472}], {
             RGBColor[
             0.18323095336378353`, 0.30991772787174093`, 0.933746103776939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 207}], {
             RGBColor[
             0.8871477729139166, 0.5804462187569267, 0.227545674269207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 209}], {
             RGBColor[
             0.9468923206889115, 0.8138245711399055, 0.48945082932663964`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 231}], {
             RGBColor[
             0.8314832405552138, 0.7254800292683178, 0.607385428867296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 233}], {
             RGBColor[
             0.9309329686428551, 0.8036306761921264, 0.5929788217369941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 266}], {
             RGBColor[
             0.9464459539298948, 0.8121746039800857, 0.3903304044915068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 317}], {
             RGBColor[
             0.8583137676007231, 0.3848962000432028, 0.20095545620474106`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 326}], {
             RGBColor[
             0.8123452824001817, 0.7105293109037376, 0.6054779360527895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 343}], {
             RGBColor[
             0.8727695735845509, 0.4960098594094768, 0.21479835234035222`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 355}], {
             RGBColor[
             0.7295091887885554, 0.6445510453124249, 0.5980872339837272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 379}], {
             RGBColor[
             0.8633665292005046, 0.42373393983337493`, 0.2057939864189699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 440}], {
             RGBColor[
             0.8954705204165625, 0.6182378713393768, 0.2344903787946242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 180}], {
             RGBColor[
             0.28958519225458484`, 0.42102975172188783`, 0.9398274630675963]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 205}], {
             RGBColor[
             0.2767533263359414, 0.40754264705410376`, 0.9390967072865741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 259}], {
             RGBColor[
             0.4996492818256195, 0.6003222503432779, 0.9552118903262334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 316}], {
             RGBColor[
             0.37736919780669476`, 0.5012799648379501, 0.9452666094831315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 331}], {
             RGBColor[
             0.3087300351184425, 0.44115219542494855`, 0.940917733546436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 348}], {
             RGBColor[
             0.38905288991990644`, 0.5111618708489473, 0.9460768222550604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 372}], {
             RGBColor[
             0.4651482668210734, 0.5729395258749782, 0.9520673290712703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 404}], {
             RGBColor[
             0.5764261418930885, 0.6604370522196931, 0.9628281641033989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 418}], {
             RGBColor[
             0.3962653140595378, 0.5170172416815048, 0.9466446107033122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 431}], {
             RGBColor[
             0.36863866395623385`, 0.49371801522607117`, 0.9447103075862879]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 444}], {
             RGBColor[
             0.4409447203988165, 0.5532899965320492, 0.9501619372363984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 486}], {
             RGBColor[
             0.3646799679598963, 0.49028919172388963`, 0.9444580629779388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 178}], {
             RGBColor[
             0.3876179844694684, 0.5094620707746275, 0.9460491694230218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 185}], {
             RGBColor[
             0.2587337613234965, 0.38927596619191684`, 0.93804587699385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 277}], {
             RGBColor[
             0.37457657867037175`, 0.49860046416423287`, 0.9450982108256749]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 288}], {
             RGBColor[
             0.508574991950541, 0.6066055037109249, 0.956292599133973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 313}], {
             RGBColor[
             0.3335735057381806, 0.4630856632647371, 0.9424855312760294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 333}], {
             RGBColor[
             0.26885740704369754`, 0.3999165597200598, 0.9386224036410238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 358}], {
             RGBColor[
             0.26540482039910535`, 0.39628767224995665`, 0.9384257839392585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 361}], {
             RGBColor[
             0.26801366747199473`, 0.39902973593402147`, 0.9385743539206161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 386}], {
             RGBColor[
             0.3057645176630249, 0.43870827302694076`, 0.9407242089916171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 498}], {
             RGBColor[
             0.5402564536084126, 0.6313553023460808, 0.9594503111519376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.19616306235610437`, 0.3235101943657379, 0.9344825682527109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 344}], {
             RGBColor[
             0.19297880215941118`, 0.32016333500525607`, 0.9343012293452001]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 387}], {
             RGBColor[
             0.19228627737083037`, 0.31943544754385, 0.934261791082989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 435}], {
             RGBColor[
             0.21704014991788595`, 0.3454533370769741, 0.9356714875044712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 439}], {
             RGBColor[
             0.19745604044376464`, 0.3248691963154145, 0.9345562014420135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 453}], {
             RGBColor[
             0.2178060906512075, 0.3462583893511425, 0.935715106696126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 172}], {
             RGBColor[
             0.23167761735264775`, 0.36083824341994686`, 0.9365050696206882]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[
             0.2486574185518422, 0.37868509106187664`, 0.9374720441796176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 218}], {
             RGBColor[
             0.26286988224919927`, 0.3936232915300437, 0.9382814229617262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 235}], {
             RGBColor[
             0.22849052163804753`, 0.3574884037503625, 0.9363235692346273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 236}], {
             RGBColor[
             0.22411127044535895`, 0.3528855330862843, 0.9360741773577252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 274}], {
             RGBColor[
             0.24197375734068546`, 0.3716601393603544, 0.9370914195612329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 284}], {
             RGBColor[
             0.22334665832655862`, 0.3520818772702168, 0.9360306338287019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 289}], {
             RGBColor[
             0.2249680527429054, 0.35378606560414083`, 0.9361229698420748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 300}], {
             RGBColor[
             0.23586320873341787`, 0.3652375653429575, 0.9367434328577955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 305}], {
             RGBColor[
             0.27520889494048634`, 0.4064251539737775, 0.9389902343056846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 432}], {
             RGBColor[
             0.2655480887278028, 0.39643825634715435`, 0.9384339428586312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 456}], {
             RGBColor[
             0.21773731167177224`, 0.3461860982829168, 0.9357111898349966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 493}], {
             RGBColor[
             0.25038390854803594`, 0.3804997415136645, 0.9375703652307877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 181}], {
             RGBColor[
             0.25911497354415575`, 0.3896766444060805, 0.9380675864658636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 189}], {
             RGBColor[
             0.272342262398906, 0.403579363650975, 0.9388208609981212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 232}], {
             RGBColor[
             0.28558604817661837`, 0.417499422207868, 0.9395750750057368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 280}], {
             RGBColor[
             0.2730931280966553, 0.40436857110694446`, 0.9388636216888019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 302}], {
             RGBColor[
             0.268736668858344, 0.3997896562320101, 0.9386155277799839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 326}], {
             RGBColor[
             0.509047258388588, 0.6051914915809957, 0.9566219374301776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 338}], {
             RGBColor[
             0.35852241644491945`, 0.4834734222788186, 0.944119987452004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 346}], {
             RGBColor[
             0.3670639021674008, 0.4908716279040769, 0.9446642433693013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 370}], {
             RGBColor[
             0.2607361826498604, 0.3913806379667703, 0.9381599119260695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 383}], {
             RGBColor[
             0.2802434761765292, 0.4118840402971449, 0.9392708234339586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 390}], {
             RGBColor[
             0.27431313717116323`, 0.40565087799729527`, 0.9389330994007534]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 395}], {
             RGBColor[
             0.3984267572015211, 0.5166565922466431, 0.9470439450191381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 443}], {
             RGBColor[
             0.29027458230294984`, 0.42242736884487553`, 0.9398420800881666]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 480}], {
             RGBColor[
             0.26803681984078476`, 0.3990540705415648, 0.9385756724137677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 211}], {
             RGBColor[
             0.1856477523702797, 0.3124579368614757, 0.9338837369050252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 236}], {
             RGBColor[
             0.19608590653883476`, 0.32342909870982617`, 0.9344781743430592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 289}], {
             RGBColor[
             0.19694268883638122`, 0.3243296312276827, 0.9345269668274088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 308}], {
             RGBColor[
             0.18735840295715342`, 0.31425593908979166`, 0.9339811559252671]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 362}], {
             RGBColor[
             0.18152465259386255`, 0.3081242975768366, 0.9336489324723378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 369}], {
             RGBColor[
             0.1829196441464267, 0.30959052214615446`, 0.9337283751775514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 456}], {
             RGBColor[
             0.18971194776524802`, 0.31672966390645874`, 0.9341151868203305]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 470}], {
             RGBColor[
             0.1892131415618838, 0.316205386960583, 0.9340867805449665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 214}], {
             RGBColor[
             0.18764009951956995`, 0.31455202003748506`, 0.9339971981277639]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 223}], {
             RGBColor[
             0.19795986022643686`, 0.3253987428510222, 0.9345848932333021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 268}], {
             RGBColor[
             0.18701827847814975`, 0.31389844669722133`, 0.9339617863393568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 466}], {
             RGBColor[
             0.19131064180456064`, 0.3184099927048328, 0.9342062300808134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 491}], {
             RGBColor[
             0.18468093358720655`, 0.3114417490206145, 0.9338286780056095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 192}], {
             RGBColor[
             0.3918420426717766, 0.5133437939110442, 0.9463191721078775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 208}], {
             RGBColor[
             0.44865476640412644`, 0.5625521197174839, 0.9499392286265838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 219}], {
             RGBColor[
             0.5701105988481052, 0.6614643237945504, 0.9595848784963202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 238}], {
             RGBColor[
             0.47869194757503297`, 0.5876627137247235, 0.9521035301009391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 258}], {
             RGBColor[
             0.44293779831735625`, 0.5576003693038944, 0.9495749484754112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 272}], {
             RGBColor[
             0.36396083467584234`, 0.48443119432275983`, 0.9447170138830936]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 293}], {
             RGBColor[
             0.6402218599260903, 0.7162357738139922, 0.9665729137735878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 403}], {
             RGBColor[
             0.6070518602239434, 0.6903231179453404, 0.9632668381945488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 471}], {
             RGBColor[
             0.7137657491152036, 0.7742498659419835, 0.9547112060503897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 497}], {
             RGBColor[
             0.47443851953832683`, 0.5842095892297761, 0.9517686846650694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 197}], {
             RGBColor[
             0.22719289983545946`, 0.3561245209618682, 0.9362496715926294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 201}], {
             RGBColor[
             0.2404718980048366, 0.3700815899749955, 0.9370058908938581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 211}], {
             RGBColor[
             0.20548759572979827`, 0.33331087015105276`, 0.9350135866339319]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 218}], {
             RGBColor[
             0.25468436170219366`, 0.3850197904431626, 0.9378152696759667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 235}], {
             RGBColor[
             0.22030500109104192`, 0.3488849026634814, 0.9358574159488678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 236}], {
             RGBColor[
             0.21592574989835334`, 0.34428203199940316`, 0.9356080240719657]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 289}], {
             RGBColor[
             0.2167825321958998, 0.3451825645172597, 0.9356568165563153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 300}], {
             RGBColor[
             0.22767768818641226`, 0.35663406425607636`, 0.936277279572036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 308}], {
             RGBColor[
             0.207198246316672, 0.3351088723793687, 0.9351110056541736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 314}], {
             RGBColor[
             0.24315002922466572`, 0.37289647569036266`, 0.9371584065048872]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 466}], {
             RGBColor[
             0.20918917113405136`, 0.3372014605943586, 0.935224385877214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 470}], {
             RGBColor[
             0.2090529849214024, 0.33705832025015997`, 0.9352166302738731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 493}], {
             RGBColor[
             0.24219838800103033`, 0.3718962404267834, 0.9371042119450282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 242}], {
             RGBColor[
             0.8468550508642396, 0.8805617516174773, 0.9515915409041512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 249}], {
             RGBColor[
             0.72377347409997, 0.7841366059398172, 0.9731026339167677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 269}], {
             RGBColor[
             0.6612355269183264, 0.7346613054419917, 0.9672934568287169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 282}], {
             RGBColor[
             0.7086553123271468, 0.7723261830606026, 0.9715957968385069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 310}], {
             RGBColor[
             0.682704924474264, 0.7520535428396782, 0.9690093046974939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 323}], {
             RGBColor[
             0.8566536605338118, 0.8864543698072436, 0.8716308977973497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 406}], {
             RGBColor[
             0.5685496786155626, 0.658415121806283, 0.9602730898835382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 419}], {
             RGBColor[
             0.6849417616486415, 0.753800977040894, 0.9692322517226041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 499}], {
             RGBColor[
             0.6745850298425644, 0.7454990333041416, 0.9683443785997534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 210}], {
             RGBColor[
             0.19150041146467078`, 0.3186094526497, 0.9342170371822176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 225}], {
             RGBColor[
             0.18572114805288265`, 0.3125350803774465, 0.9338879166805704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 252}], {
             RGBColor[
             0.18489202158224743`, 0.3116636158871544, 0.9338406991546504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 309}], {
             RGBColor[
             0.18783655214367595`, 0.3147585042012363, 0.9340083858140811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 320}], {
             RGBColor[
             0.1843078028000945, 0.31104956490550145`, 0.933807428759281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 393}], {
             RGBColor[
             0.20439651484045512`, 0.33216407495782907`, 0.9349514511913933]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 424}], {
             RGBColor[
             0.19047450678086728`, 0.3175311617809086, 0.934158613428165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 182}], {
             RGBColor[
             0.3713372775098073, 0.4960554186499155, 0.9448822608556314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 208}], {
             RGBColor[
             0.41214605726916764`, 0.531401932568564, 0.9474825602161108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 351}], {
             RGBColor[
             0.3189338999580072, 0.4443278119995411, 0.9417752451272612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 359}], {
             RGBColor[
             0.653601757432396, 0.7247826808114364, 0.9688966182964689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 371}], {
             RGBColor[
             0.32587980547058965`, 0.4516283990891108, 0.9421708041706565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 463}], {
             RGBColor[
             0.476418269168048, 0.5843060667913316, 0.9523419687164218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 483}], {
             RGBColor[
             0.4248591023079348, 0.5424133332049215, 0.9482926242042767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 178}], {
             RGBColor[
             0.3931214338805177, 0.5144895563820213, 0.9463902997884908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 244}], {
             RGBColor[
             0.38182757506705056`, 0.5051415871363136, 0.945550693339773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 261}], {
             RGBColor[
             0.32311312036066653`, 0.4542860775439437, 0.941809460205036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 262}], {
             RGBColor[
             0.33005042418212294`, 0.46029482143506084`, 0.9422514990701223]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 299}], {
             RGBColor[
             0.2785034431297019, 0.4092981665779968, 0.9391994481892236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 313}], {
             RGBColor[
             0.3390769551492299, 0.46811314887213096`, 0.9428266616414984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 328}], {
             RGBColor[
             0.27995998628272956`, 0.4108290857819987, 0.939282396167026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 376}], {
             RGBColor[
             0.34402119360606, 0.47239559971878675`, 0.9431417041439492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 391}], {
             RGBColor[
             0.3950241069319744, 0.5160342320796381, 0.9465400851808224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 407}], {
             RGBColor[
             0.2970315342752855, 0.4287723651208341, 0.94025459557011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 448}], {
             RGBColor[
             0.3087587670403855, 0.44109843030645696`, 0.9409224441271964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 455}], {
             RGBColor[
             0.46498904560871784`, 0.5728349211819872, 0.9520479814434708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 475}], {
             RGBColor[
             0.3267310397254062, 0.4574197374557666, 0.9420399908277568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 478}], {
             RGBColor[
             0.2831235992471345, 0.4141542435922354, 0.9394625592452028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 482}], {
             RGBColor[
             0.3246527382525704, 0.45561961717846555`, 0.9419075632956775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 194}], {
             RGBColor[
             0.1852447118397448, 0.312034315709638, 0.9338607843430564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 290}], {
             RGBColor[
             0.1829544926129004, 0.3096271500939387, 0.9337303597461633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 297}], {
             RGBColor[
             0.18982245259063335`, 0.3168458114843493, 0.9341214799066588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 412}], {
             RGBColor[
             0.1873190234343715, 0.314214548714542, 0.9339789133197014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 484}], {
             RGBColor[
             0.18459712642978363`, 0.31135366238448237`, 0.9338239053119759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 186}], {
             RGBColor[
             0.7313163060716499, 0.7840864544016981, 0.7330087460966953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 244}], {
             RGBColor[
             0.45801552683844415`, 0.5706975580302278, 0.9505252940081765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 261}], {
             RGBColor[
             0.3993010721320601, 0.5198420484378579, 0.9467840608734395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 288}], {
             RGBColor[
             0.5902663931329839, 0.677188960212233, 0.9616083301678455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 313}], {
             RGBColor[
             0.4152649069206235, 0.5336691197660451, 0.9478012623099019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 321}], {
             RGBColor[
             0.7273722693999012, 0.7841453015250835, 0.9212028178095601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 391}], {
             RGBColor[
             0.47121205870336796`, 0.5815902029735522, 0.9515146858492259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 407}], {
             RGBColor[
             0.3732194860466791, 0.4943283360147483, 0.9452291962385135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 455}], {
             RGBColor[
             0.5411769973801115, 0.6383908920759014, 0.9570225821118743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 475}], {
             RGBColor[
             0.40291899149679977`, 0.5229757083496808, 0.9470145914961603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 498}], {
             RGBColor[
             0.6219478547908555, 0.7019387588473889, 0.96476604218581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 222}], {
             RGBColor[
             0.19860716321184355`, 0.3260790993300644, 0.9346217561807222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 245}], {
             RGBColor[
             0.22201863728698465`, 0.35068604295622735`, 0.9359550049951293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 255}], {
             RGBColor[
             0.19864123735537692`, 0.32611491341534343`, 0.9346236966527881]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 294}], {
             RGBColor[
             0.19380204212800067`, 0.3210286124086723, 0.9343481116435368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 296}], {
             RGBColor[
             0.19117065430032437`, 0.31826285696216006`, 0.9341982579995401]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 312}], {
             RGBColor[
             0.19754047021008475`, 0.3249579373529733, 0.9345610095923028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 327}], {
             RGBColor[
             0.1919456153481889, 0.3190773901588341, 0.9342423908847639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 334}], {
             RGBColor[
             0.1934836161981846, 0.32069392656706563`, 0.9343299777579028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 385}], {
             RGBColor[
             0.19083377116116018`, 0.3179087714232738, 0.9341790730031387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 415}], {
             RGBColor[
             0.19025558687597238`, 0.31730106308054046`, 0.9341461462634442]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 438}], {
             RGBColor[
             0.20137694299580192`, 0.3289903134971859, 0.9347794910418965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 205}], {
             RGBColor[
             0.2503131812646099, 0.38042540265441493`, 0.9375663374166283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 230}], {
             RGBColor[
             0.2345216927400936, 0.3638275469769471, 0.9366670355065708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 331}], {
             RGBColor[
             0.2822898900471109, 0.4140349510252597, 0.9393873636764902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 382}], {
             RGBColor[
             0.23760741054514092`, 0.36707083203586066`, 0.9368427625706579]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 413}], {
             RGBColor[
             0.24672751485063993`, 0.37665663990895104`, 0.9373621390188708]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 418}], {
             RGBColor[
             0.3698251689882062, 0.48989999728181594`, 0.9451142408333664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 474}], {
             RGBColor[
             0.24632928568632426`, 0.37623807580806795`, 0.9373394604570903]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 490}], {
             RGBColor[
             0.23955648296360244`, 0.3691194307259925, 0.9369537593614949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 189}], {
             RGBColor[
             0.238744748764803, 0.3682662466161335, 0.9369075322997265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 302}], {
             RGBColor[
             0.235139155224241, 0.3644765391971686, 0.9367021990815891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 370}], {
             RGBColor[
             0.2271386690157574, 0.35606752093192884`, 0.9362465832276747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 390}], {
             RGBColor[
             0.24071562353706022`, 0.37033776096245374`, 0.9370197707023586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 422}], {
             RGBColor[
             0.2160287950041301, 0.3443903389390116, 0.9356138923382982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 443}], {
             RGBColor[
             0.2566770686688468, 0.387114251810034, 0.9379287513897718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 451}], {
             RGBColor[
             0.21530209522723562`, 0.3436265313980684, 0.93557250786106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 237}], {
             RGBColor[
             0.2889436538091614, 0.4176768128895569, 0.9398890065800227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 351}], {
             RGBColor[
             0.2925937639781592, 0.42151331010752513`, 0.9400968749542931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 359}], {
             RGBColor[
             0.6272616214525479, 0.7019681789194203, 0.9672182481235007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 371}], {
             RGBColor[
             0.29953966949074173`, 0.42881389719709484`, 0.9404924339976882]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 460}], {
             RGBColor[
             0.32283537188163536`, 0.453299157442765, 0.9418190897859463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 463}], {
             RGBColor[
             0.4500781331882001, 0.5614915648993155, 0.9506635985434537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 483}], {
             RGBColor[
             0.3985189663280868, 0.5195988313129054, 0.9466142540313085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 202}], {
             RGBColor[
             0.19186250689715728`, 0.31899003790741964`, 0.9342376579814256]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 206}], {
             RGBColor[
             0.1886895173788014, 0.31565502474447266`, 0.9340569609223726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 243}], {
             RGBColor[
             0.19677206267761843`, 0.3241502923164997, 0.9345172499200859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 273}], {
             RGBColor[
             0.19206178134703447`, 0.31919948798897047`, 0.934249006366546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 279}], {
             RGBColor[
             0.202473790723394, 0.3301431700030478, 0.9348419548973421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 283}], {
             RGBColor[
             0.18964111329673894`, 0.31665521238889094`, 0.9341111529021391]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 285}], {
             RGBColor[
             0.20567627769071223`, 0.33350918685510056`, 0.935024331792476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 396}], {
             RGBColor[
             0.19720162500749072`, 0.32460178956102026`, 0.9345417128592917]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 430}], {
             RGBColor[
             0.19926050368686765`, 0.32676580159349333`, 0.9346589629542441]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 477}], {
             RGBColor[
             0.19737928626943302`, 0.32478852281169623`, 0.934551830405333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 221}], {
             RGBColor[
             0.7515553610831588, 0.7612606169042988, 0.6324712276878893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 253}], {
             RGBColor[
             0.4591640004744537, 0.5697502062280924, 0.9511350822856912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 287}], {
             RGBColor[
             0.42249467395537876`, 0.5375645019893394, 0.9488140910567393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 301}], {
             RGBColor[
             0.5986418341837841, 0.6848276074011173, 0.9616939873161781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 316}], {
             RGBColor[
             0.4897742836055883, 0.5962632949587165, 0.9530855424591965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 336}], {
             RGBColor[
             0.5830930532515349, 0.672420234529121, 0.9603223675736445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 354}], {
             RGBColor[
             0.425711621643709, 0.5407754370503493, 0.9490035262873733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 388}], {
             RGBColor[
             0.43476172806913593`, 0.5486141843644792, 0.9495801910661066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 436}], {
             RGBColor[
             0.4481781977283561, 0.5602348560519236, 0.9504350766490738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 473}], {
             RGBColor[
             0.4022146970771591, 0.5162489604655307, 0.9476591763750619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 187}], {
             RGBColor[
             0.21639359634399347`, 0.34477376827694883`, 0.9356346672349283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 216}], {
             RGBColor[
             0.20572802131241785`, 0.3335635726822483, 0.9350272785151843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 224}], {
             RGBColor[
             0.2087376164930067, 0.33672684803640285`, 0.9351986705084218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 286}], {
             RGBColor[
             0.1994684028845588, 0.32698431683183726`, 0.9346708025059933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 330}], {
             RGBColor[
             0.20056082053324595`, 0.3281325170438868, 0.934733014074999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 333}], {
             RGBColor[
             0.22166458508016862`, 0.3503139116386572, 0.9359348422457243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 357}], {
             RGBColor[
             0.20004263933508956`, 0.3275878757500389, 0.9347035044223444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 358}], {
             RGBColor[
             0.21821199843557637`, 0.3466850241685541, 0.935738222543959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 361}], {
             RGBColor[
             0.22082084550846576`, 0.3494270878526189, 0.9358867925253167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 386}], {
             RGBColor[
             0.25857169569949595`, 0.38910562494553824`, 0.9380366475963178]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 398}], {
             RGBColor[
             0.20890004242653637`, 0.3368975679909415, 0.9352079204250486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 441}], {
             RGBColor[
             0.21650425944697038`, 0.34489008221462353`, 0.9356409693349313]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 464}], {
             RGBColor[
             0.2069974759051772, 0.3348978499473083, 0.9350995720762522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 481}], {
             RGBColor[
             0.2084048526461078, 0.33637709213486555`, 0.9351797200996208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 288}], {
             RGBColor[
             0.8522733135527225, 0.8812298873379956, 0.7432521758076465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 295}], {
             RGBColor[
             0.9890595681546568, 0.9880540568784736, 0.7081436215924831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 321}], {
             RGBColor[
             0.9893791898196398, 0.9881862286508462, 0.7028466634493613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 341}], {
             RGBColor[
             0.9938102781827736, 0.9891691358468536, 0.5676651626091419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 373}], {
             RGBColor[
             0.9921614072017308, 0.9893367470380662, 0.6567381212803327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 397}], {
             RGBColor[
             0.9076664956540943, 0.5791548277078178, 0.3416812367112626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 455}], {
             RGBColor[
             0.8031839177998501, 0.842431819201664, 0.7386664277516752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 495}], {
             RGBColor[
             0.9397076490875935, 0.7818899537818541, 0.3706586815108439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 498}], {
             RGBColor[
             0.8839547752105941, 0.9059796859731515, 0.7464098878256111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 216}], {
             RGBColor[
             0.21058067829644372`, 0.3386640228486828, 0.9353036301515618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 224}], {
             RGBColor[
             0.2135902734770326, 0.34182729820283736`, 0.9354750221447994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 260}], {
             RGBColor[
             0.21549852964428565`, 0.3438329964250494, 0.9355836945105124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 328}], {
             RGBColor[
             0.2321163718921772, 0.36129940225963686`, 0.9365300560426353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 398}], {
             RGBColor[
             0.21375269941056224`, 0.341998018157376, 0.9354842720614263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 399}], {
             RGBColor[
             0.214562612650492, 0.3428492883240075, 0.9355303954222809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 407}], {
             RGBColor[
             0.24918791988473313`, 0.3792426815984722, 0.9375022554457193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 464}], {
             RGBColor[
             0.21185013288920307`, 0.3399983001137429, 0.9353759237126298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 478}], {
             RGBColor[
             0.2352799848565821, 0.36462456006987354`, 0.9367102191208121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 481}], {
             RGBColor[
             0.21325750963013368`, 0.3414775423013001, 0.9354560717359984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 200}], {
             RGBColor[
             0.24347605986022197`, 0.37323915455986845`, 0.937176973467263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 228}], {
             RGBColor[
             0.24109668028529843`, 0.37073827576524543`, 0.9370414713204478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 256}], {
             RGBColor[
             0.26776710539076976`, 0.3985106384029728, 0.9385698304401877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 279}], {
             RGBColor[
             0.21597972805042376`, 0.3443387664596417, 0.9356110980478727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 298}], {
             RGBColor[
             0.24983259130122784`, 0.37992027213173674`, 0.9375389685291828]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 318}], {
             RGBColor[
             0.21097876418895464`, 0.3390824363618151, 0.935326300554225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 335}], {
             RGBColor[
             0.21717587938379926`, 0.3455959973513941, 0.9356792170967612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 409}], {
             RGBColor[
             0.23860514692337326`, 0.3681195162295229, 0.9368995821813795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 430}], {
             RGBColor[
             0.2127664410138974, 0.34096139805008724`, 0.9354281061047747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 459}], {
             RGBColor[
             0.20922832641301886`, 0.3372426152751415, 0.9352266157124262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 302}], {
             RGBColor[
             0.24836644407899122`, 0.3783792584420631, 0.9374554736138468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 346}], {
             RGBColor[
             0.346693677388048, 0.46946123011413, 0.9435041892031641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 370}], {
             RGBColor[
             0.24036595787050763`, 0.36997024017682334`, 0.9369998577599323]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 383}], {
             RGBColor[
             0.25987325139717643`, 0.39047364250719796`, 0.9381107692678216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 390}], {
             RGBColor[
             0.25394291239181044`, 0.3842404802073483, 0.9377730452346162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 422}], {
             RGBColor[
             0.22925608385888036`, 0.3582930581839061, 0.936367166870556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 443}], {
             RGBColor[
             0.2699043575235971, 0.40101697105492856`, 0.9386820259220295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 451}], {
             RGBColor[
             0.22852938408198586`, 0.3575292506429629, 0.9363257823933178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 349}], {
             RGBColor[
             0.20086956962021285`, 0.3284570319101118, 0.9347505968787484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 378}], {
             RGBColor[
             0.21175405970731373`, 0.3398973211081856, 0.9353704524870488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 467}], {
             RGBColor[
             0.20384534758574807`, 0.33158476322710967`, 0.9349200630316166]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 487}], {
             RGBColor[
             0.2046420322637051, 0.3324221293363686, 0.9349654330454369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 226}], {
             RGBColor[
             0.18878815245387853`, 0.31575869646220367`, 0.9340625780439806]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 237}], {
             RGBColor[
             0.21174339074199797`, 0.3398861073491872, 0.9353698449052572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 271}], {
             RGBColor[
             0.19934619168565726`, 0.3268558651131542, 0.9346638427590112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 311}], {
             RGBColor[
             0.19029060642002155`, 0.31733787084170345`, 0.934148140574671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 366}], {
             RGBColor[
             0.18657672320149288`, 0.31343434410523346`, 0.9339366404195737]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 405}], {
             RGBColor[
             0.18612791917026347`, 0.3129626226125922, 0.9339110816939413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 423}], {
             RGBColor[
             0.1848982635137219, 0.3116701765528954, 0.9338410546234137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 429}], {
             RGBColor[
             0.1912728666243942, 0.31837028859539307`, 0.9342040788401863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 488}], {
             RGBColor[
             0.18656266374586195`, 0.3134195667259444, 0.9339358397543747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 219}], {
             RGBColor[
             0.49125780976030897`, 0.5936378228658237, 0.9544300827546521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 251}], {
             RGBColor[
             0.2759596386433615, 0.40698913765266753`, 0.9390412298997809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 258}], {
             RGBColor[
             0.36408500922956, 0.4897738683751677, 0.944420152733743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 272}], {
             RGBColor[
             0.28510804558804614`, 0.41660469339403305`, 0.9395622181414255]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 435}], {
             RGBColor[
             0.2756938897780267, 0.40670981874574946`, 0.9390260958950403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 453}], {
             RGBColor[
             0.27645983051134826`, 0.4075148710199178, 0.9390697150866952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 497}], {
             RGBColor[
             0.3955857304505306, 0.5163830883010493, 0.9466138889234013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 410}], {
             RGBColor[
             0.1815860257697589, 0.30818880467598786`, 0.9336524275839118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 428}], {
             RGBColor[
             0.18434895637471288`, 0.31109281992171267`, 0.9338097723944743]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 437}], {
             RGBColor[
             0.18142173090578886`, 0.3080161203570593, 0.933643071234461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 220}], {
             RGBColor[
             0.20157018632549908`, 0.32919342448903244`, 0.9347904959636448]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 254}], {
             RGBColor[
             0.18926826388068996`, 0.3162633240126051, 0.9340899196794763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 290}], {
             RGBColor[
             0.18381681483281254`, 0.31053350542145297`, 0.9337794677208959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 297}], {
             RGBColor[
             0.1906847748105455, 0.3177521668118635, 0.9341705878813915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 350}], {
             RGBColor[
             0.18381567245253283`, 0.31053230470734794`, 0.9337794026640289]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 377}], {
             RGBColor[
             0.1834493331063201, 0.31014725882722227`, 0.9337585401802126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 412}], {
             RGBColor[
             0.18818134565428368`, 0.3151209040420562, 0.934028021294434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 426}], {
             RGBColor[
             0.18673198964571103`, 0.31359753898256787`, 0.9339454826138758]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 476}], {
             RGBColor[
             0.18476853282621936`, 0.3115338213749295, 0.9338336666526799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.19263264106654965`, 0.3197994977487777, 0.9342815159830611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 260}], {
             RGBColor[
             0.1989228362357199, 0.32641089169298415`, 0.9346397332924354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 292}], {
             RGBColor[
             0.18660739700750423`, 0.31346658422018303`, 0.9339383872474483]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 399}], {
             RGBColor[
             0.19798691924192627`, 0.3254271835919423, 0.9345864342042041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 446}], {
             RGBColor[
             0.1857509853248722, 0.31256644124209987`, 0.9338896158690699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 496}], {
             RGBColor[
             0.18695506079229124`, 0.31383200090115126`, 0.9339581861856694]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 213}], {
             RGBColor[
             0.19710682911621347`, 0.3245021530688812, 0.9345363143735214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 332}], {
             RGBColor[
             0.18931192738265673`, 0.3163092171215981, 0.934092406251319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 337}], {
             RGBColor[
             0.19054105270955757`, 0.3176011057712177, 0.934162403120358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 420}], {
             RGBColor[
             0.19002037884251344`, 0.3170538445243244, 0.9341327515138979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 427}], {
             RGBColor[
             0.18925515066577042`, 0.3162495411922988, 0.9340891729012859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 447}], {
             RGBColor[
             0.2128628663159131, 0.341062747156223, 0.9354335973830761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 454}], {
             RGBColor[
             0.20169424196759916`, 0.3293238148344616, 0.9347975607489386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 489}], {
             RGBColor[
             0.19180860925659354`, 0.31893338806987936`, 0.9342345885905299]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 500}], {
             RGBColor[
             0.1964924261713618, 0.32385637661844546`, 0.9345013250347398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 201}], {
             RGBColor[
             0.2441727010346539, 0.373971368603798, 0.9372166461515588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 236}], {
             RGBColor[
             0.21962655292817068`, 0.3481718106282057, 0.9358187793296664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 289}], {
             RGBColor[
             0.22048333522571711`, 0.34907234314606217`, 0.9358675718140159]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 314}], {
             RGBColor[
             0.24685083225448304`, 0.3767862543191651, 0.9373691617625879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 411}], {
             RGBColor[
             0.25605149674669436`, 0.3864567360563011, 0.937893125994256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 466}], {
             RGBColor[
             0.21288997416386868`, 0.3410912392231611, 0.9354351411349147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 470}], {
             RGBColor[
             0.2127537879512197, 0.3409480988789625, 0.9354273855315738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 493}], {
             RGBColor[
             0.24589919103084765`, 0.37578601905558584`, 0.9373149672027289]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 270}], {
             RGBColor[
             0.1812627552425552, 0.3078490268553615, 0.9336340178056233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 479}], {
             RGBColor[
             0.18236486345397498`, 0.30900741246326024`, 0.9336967812378407]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 244}], {
             RGBColor[
             0.4164279851399622, 0.5351107232742938, 0.9477554008736777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 245}], {
             RGBColor[
             0.31502975887018714`, 0.4412915516820689, 0.9415138332017744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 262}], {
             RGBColor[
             0.36465083425503464`, 0.49026395757304103`, 0.944456206604027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 376}], {
             RGBColor[
             0.3786216036789717, 0.5023647358567669, 0.9453464116778538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 448}], {
             RGBColor[
             0.3433591771132972, 0.47106756644443715`, 0.943127151661101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 455}], {
             RGBColor[
             0.4995894556816295, 0.6028040573199673, 0.9542526889773754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 475}], {
             RGBColor[
             0.3613314497983178, 0.4873888735937467, 0.9442446983616614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 482}], {
             RGBColor[
             0.35925314832548205`, 0.4855887533164457, 0.9441122708295822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 228}], {
             RGBColor[
             0.26059605928059204`, 0.3912333594213344, 0.9381519321074836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 256}], {
             RGBColor[
             0.28726648438606334`, 0.4190057220590618, 0.9396802912272235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 298}], {
             RGBColor[
             0.26933197029652145`, 0.4004153557878257, 0.9386494293162186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 452}], {
             RGBColor[
             0.24489188267224044`, 0.3747272741036509, 0.9372576024818854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 468}], {
             RGBColor[
             0.2422384711696754, 0.37193837037844896`, 0.9371064946221849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 218}], {
             RGBColor[
             0.27166416290138806`, 0.4028666380850924, 0.938782244234896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 235}], {
             RGBColor[
             0.23728480229023638`, 0.36673175030541116`, 0.9368243905077971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 236}], {
             RGBColor[
             0.2329055510975478, 0.36212887964133295`, 0.9365749986308951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 289}], {
             RGBColor[
             0.23376233339509425`, 0.3630294121591895, 0.9366237911152446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 300}], {
             RGBColor[
             0.24465748938560672`, 0.37448091189800614`, 0.9372442541309653]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 305}], {
             RGBColor[
             0.2840031755926752, 0.41566850052882615`, 0.9394910555788545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 314}], {
             RGBColor[
             0.2601298304238602, 0.39074332333229245`, 0.9381253810638166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 406}], {
             RGBColor[
             0.33697692661979073`, 0.46155170113037025`, 0.9428664961514535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 493}], {
             RGBColor[
             0.2591781892002248, 0.38974308806871316`, 0.9380711865039575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 243}], {
             RGBColor[
             0.1916697633639069, 0.3187874522333277, 0.9342266815223454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 273}], {
             RGBColor[
             0.18695948203332297`, 0.31383664790579846`, 0.9339584379688055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 279}], {
             RGBColor[
             0.19737149140968246`, 0.32478032991987577`, 0.9345513864996016]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 283}], {
             RGBColor[
             0.1845388139830274, 0.3112923723057189, 0.9338205845043986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 285}], {
             RGBColor[
             0.2005739783770007, 0.32814634677192855`, 0.9347337633947355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 396}], {
             RGBColor[
             0.1920993256937792, 0.31923894947784826`, 0.9342511444615511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 421}], {
             RGBColor[
             0.18554846728188248`, 0.31235358193853213`, 0.9338780827661202]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 430}], {
             RGBColor[
             0.19415820437315612`, 0.32140296151032133`, 0.9343683945565036]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 459}], {
             RGBColor[
             0.19062008977227754`, 0.3176841787353756, 0.9341669041641552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 477}], {
             RGBColor[
             0.19227698695572149`, 0.31942568272852423`, 0.9342612620075925]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 264}], {
             RGBColor[
             0.8553074725725389, 0.4148947299646385, 0.20015613150748274`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 281}], {
             RGBColor[
             0.8317474856787275, 0.2450306635294393, 0.1780347341805933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 295}], {
             RGBColor[
             0.9149334778554977, 0.6677110589938393, 0.5462140209685634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 324}], {
             RGBColor[
             0.8924019068162066, 0.6510073815667528, 0.588847136940535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 341}], {
             RGBColor[
             0.9196841878836145, 0.6688261379622193, 0.4057355619852222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 374}], {
             RGBColor[
             0.8462576720826371, 0.35656231463411475`, 0.19192970506788876`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 397}], {
             RGBColor[
             0.8335404053549352, 0.2588118298231834, 0.1797516360873429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 275}], {
             RGBColor[
             0.402607767889131, 0.5221630142088122, 0.9471448284585735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 306}], {
             RGBColor[
             0.2783366060930942, 0.40921806996322074`, 0.9391864591429547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 331}], {
             RGBColor[
             0.3086689498622105, 0.44109928644623464`, 0.9409138412479245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 346}], {
             RGBColor[
             0.3786592419849977, 0.5023973362656904, 0.9453488099574316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 348}], {
             RGBColor[
             0.38899180466367445`, 0.5111089618702334, 0.9460729299565488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 355}], {
             RGBColor[
             0.4378065045945586, 0.5507389343512965, 0.9499158019492457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 390}], {
             RGBColor[
             0.2859084769887601, 0.4171765863589087, 0.9396176659888837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 431}], {
             RGBColor[
             0.36857757870000185`, 0.49366510624735727`, 0.9447064152877764]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 444}], {
             RGBColor[
             0.44088363514258455`, 0.5532370875533353, 0.9501580449378868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 486}], {
             RGBColor[
             0.3646188827036643, 0.4902362827451757, 0.9444541706794272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 230}], {
             RGBColor[
             0.22168982682145016`, 0.35034044230916306`, 0.9359362797255486]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 331}], {
             RGBColor[
             0.26945802412846753`, 0.40054784635747565`, 0.938656607895468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 382}], {
             RGBColor[
             0.22477554462649751`, 0.3535837273680766, 0.9361120067896356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 413}], {
             RGBColor[
             0.2338956489319965, 0.363169535241167, 0.9366313832378486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 474}], {
             RGBColor[
             0.23349741976768085`, 0.3627509711402839, 0.936608704676068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 490}], {
             RGBColor[
             0.22672461704495903`, 0.3556323260582085, 0.9362230035804727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 254}], {
             RGBColor[
             0.18642186112422848`, 0.31327157424320573`, 0.9339278212533714]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 377}], {
             RGBColor[
             0.18060293034985866`, 0.30715550905782296`, 0.9335964417541076]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 396}], {
             RGBColor[
             0.18892633617542332`, 0.3159039363149012, 0.9340704474024981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 476}], {
             RGBColor[
             0.18192213006975788`, 0.30854207160553015`, 0.9336715682265748]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 257}], {
             RGBColor[
             0.9190198138450048, 0.7061284902521469, 0.2641826298296307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 266}], {
             RGBColor[
             0.9342851916423655, 0.7569554226506068, 0.3801831663512317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 281}], {
             RGBColor[
             0.8467054680453859, 0.3339234893640672, 0.19133725700073073`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 293}], {
             RGBColor[
             0.8423679493594973, 0.6882641451078306, 0.5995351479132809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 317}], {
             RGBColor[
             0.8461530053131936, 0.3296770187137239, 0.19080821806446593`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 322}], {
             RGBColor[
             0.8478846282356312, 0.34298703129758157`, 0.19246642213058046`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 343}], {
             RGBColor[
             0.8606088112970214, 0.4407906780799979, 0.2046511142000771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 374}], {
             RGBColor[
             0.8612156544492956, 0.4454551404687426, 0.20523222788802623`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 403}], {
             RGBColor[
             0.8091979496573507, 0.6623514892391787, 0.5962290723342419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 440}], {
             RGBColor[
             0.8833097581290331, 0.5630186900098979, 0.22434314065434907`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 445}], {
             RGBColor[
             0.9190529143682962, 0.7062401460895815, 0.26431121911210875`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 471}], {
             RGBColor[
             0.9159118385486107, 0.7462782372358219, 0.5876734401900829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 238}], {
             RGBColor[
             0.4566518822195865, 0.5690445386024363, 0.9505687908779773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[
             0.42089773296190985`, 0.5389821941816072, 0.9480402092524494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 266}], {
             RGBColor[
             0.7100990368535118, 0.7663088762344812, 0.7456861929885767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 293}], {
             RGBColor[
             0.6181817945706438, 0.697617598691705, 0.965038174550626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 403}], {
             RGBColor[
             0.5850117948684971, 0.6717049428230532, 0.961732098971587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 471}], {
             RGBColor[
             0.6917256837597572, 0.7556316908196963, 0.953176466827428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 483}], {
             RGBColor[
             0.4393277460874472, 0.554945345231554, 0.949214553391788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 497}], {
             RGBColor[
             0.4523984541828804, 0.5655914141074888, 0.9502339454421076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 231}], {
             RGBColor[
             0.8790670260426792, 0.9036392003218177, 0.8591433457844534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 233}], {
             RGBColor[
             0.9785167541303205, 0.9817898472456261, 0.8447367386541516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 259}], {
             RGBColor[
             0.8388746662508497, 0.8722406233791922, 0.8551373469793608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 275}], {
             RGBColor[
             0.7418942375705933, 0.7941342962234403, 0.8470741774102124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 348}], {
             RGBColor[
             0.7282782743451366, 0.7830802438848616, 0.8460022789081878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 355}], {
             RGBColor[
             0.7770929742760209, 0.8227102163659248, 0.8498451509008846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 372}], {
             RGBColor[
             0.8043736512463036, 0.8448578989108925, 0.8519927857243978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 379}], {
             RGBColor[
             0.9109503146879699, 0.6018931108868748, 0.4575519033361274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 400}], {
             RGBColor[
             0.9921722318540724, 0.9910310309542629, 0.7793899060000027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 404}], {
             RGBColor[
             0.9156515263183187, 0.9323554252556073, 0.8627536207565263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 431}], {
             RGBColor[
             0.707864048381464, 0.7656363882619854, 0.8446357642394154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 444}], {
             RGBColor[
             0.7801701048240467, 0.8252083695679635, 0.8500873938895259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 486}], {
             RGBColor[
             0.7039053523851265, 0.7622075647598039, 0.8443835196310663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 225}], {
             RGBColor[
             0.189744388344664, 0.31676376101227643`, 0.9341170342633367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 252}], {
             RGBColor[
             0.1889152618740288, 0.3158922965219843, 0.9340698167374166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 280}], {
             RGBColor[
             0.22449871038575198`, 0.3532927570287484, 0.9360962414891647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 309}], {
             RGBColor[
             0.1918597924354573, 0.31898718483606625`, 0.9342375033968474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 320}], {
             RGBColor[
             0.18833104309187587`, 0.31527824554033135`, 0.9340365463420472]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 393}], {
             RGBColor[
             0.20841975513223648`, 0.336392755592659, 0.9351805687741597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 424}], {
             RGBColor[
             0.19449774707264864`, 0.3217598424157385, 0.9343877310109313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 480}], {
             RGBColor[
             0.21944240212988145`, 0.3479782564633687, 0.9358082922141305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 236}], {
             RGBColor[
             0.1979212488225095, 0.32535815981739014`, 0.934582694370969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 289}], {
             RGBColor[
             0.19877803112005593`, 0.32625869233524674`, 0.9346314868553184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 308}], {
             RGBColor[
             0.18919374524082816`, 0.3161850001973557, 0.9340856759531767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 362}], {
             RGBColor[
             0.1833599948775373, 0.31005335868440065`, 0.9337534525002475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 369}], {
             RGBColor[
             0.1847549864301014, 0.3115195832537184, 0.933832895205461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 466}], {
             RGBColor[
             0.1911846700582075, 0.3182775884123456, 0.9341990561762171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 470}], {
             RGBColor[
             0.19104848384555853`, 0.31813444806814695`, 0.9341913005728761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 216}], {
             RGBColor[
             0.19093042363498117`, 0.31801035930138044`, 0.9341845772185382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 217}], {
             RGBColor[
             0.18159408433829743`, 0.30819727474246456`, 0.9336528865074684]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 224}], {
             RGBColor[
             0.19394001881557005`, 0.321173634655535, 0.9343559692117758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 286}], {
             RGBColor[
             0.18467080520712215`, 0.3114311034509694, 0.9338281012093472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 319}], {
             RGBColor[
             0.18140430286516612`, 0.3079978023813632, 0.93364207873333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 330}], {
             RGBColor[
             0.18576322285580926`, 0.312579303663019, 0.9338903127783529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 357}], {
             RGBColor[
             0.18524504165765288`, 0.3120346623691711, 0.9338608031256983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 492}], {
             RGBColor[
             0.18227723304689475`, 0.30891530734933015`, 0.933691790815795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 251}], {
             RGBColor[
             0.22057376513923174`, 0.3491673907187537, 0.9358727216638114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 332}], {
             RGBColor[
             0.19442260484216423`, 0.3216808631672068, 0.9343834517720682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 337}], {
             RGBColor[
             0.19565173016906506`, 0.3229727518168264, 0.9344534486411072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 420}], {
             RGBColor[
             0.19513105630202093`, 0.32242549056993314`, 0.9344237970346471]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 447}], {
             RGBColor[
             0.2179735437754206, 0.34643439320183167`, 0.9357246429038253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 454}], {
             RGBColor[
             0.20680491942710666`, 0.3346954608800703, 0.9350886062696878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 489}], {
             RGBColor[
             0.19691928671610104`, 0.3243050341154881, 0.9345256341112791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 500}], {
             RGBColor[
             0.2016031036308693, 0.32922802266405415`, 0.934792370555489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 223}], {
             RGBColor[
             0.1978649215993461, 0.32529895633449324`, 0.9345794866189384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 268}], {
             RGBColor[
             0.186923339851059, 0.31379866018069236`, 0.9339563797249931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 466}], {
             RGBColor[
             0.1912157031774699, 0.31831020618830375`, 0.9342008234664497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 470}], {
             RGBColor[
             0.19107951696482092`, 0.31816706584410515`, 0.9341930678631087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 491}], {
             RGBColor[
             0.1845859949601158, 0.3113419625040855, 0.9338232713912458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 402}], {
             RGBColor[
             0.2015459552318014, 0.3291679560732161, 0.9347891160387054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 417}], {
             RGBColor[
             0.1910469226092748, 0.31813280710982467`, 0.9341912116627795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 217}], {
             RGBColor[
             0.1905787639681844, 0.31764074269506637`, 0.9341645507207481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 224}], {
             RGBColor[
             0.20292469844545702`, 0.3306171026081368, 0.9348676334250554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 292}], {
             RGBColor[
             0.19251751538449438`, 0.3196784933575477, 0.9342749597457812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 358}], {
             RGBColor[
             0.21239908038802668`, 0.34057527874028815`, 0.9354071854605928]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 361}], {
             RGBColor[
             0.21500792746091607`, 0.34331734242435297`, 0.9355557554419504]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 398}], {
             RGBColor[
             0.20308712437898663`, 0.33078782256267547`, 0.9348768833416823]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 399}], {
             RGBColor[
             0.20389703761891642`, 0.33163909272930703`, 0.934923006702537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 464}], {
             RGBColor[
             0.20118455785762748`, 0.32878810451904233`, 0.9347685349928858]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 481}], {
             RGBColor[
             0.20259193459855807`, 0.33026734670659963`, 0.9348486830162546]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 292}], {
             RGBColor[
             0.18318117608781065`, 0.30986540879863184`, 0.9337432690347114]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 398}], {
             RGBColor[
             0.1937507850823029, 0.3209747380037596, 0.9343451926306123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 464}], {
             RGBColor[
             0.19184821856094375`, 0.31897501996012645`, 0.9342368442818159]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 481}], {
             RGBColor[
             0.19325559530187433`, 0.3204542621476837, 0.9343169923051846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 496}], {
             RGBColor[
             0.1835288398725976, 0.31023082547960007`, 0.9337630679729325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 235}], {
             RGBColor[
             0.2514972659875934, 0.38166995077357824`, 0.9376337692899057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 274}], {
             RGBColor[
             0.26498050169023135`, 0.3958416863835701, 0.9384016196165113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.25886995308296373`, 0.3894191123661732, 0.938053632913074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 305}], {
             RGBColor[
             0.29821563929003225`, 0.43060670099699316`, 0.9403004343609631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 310}], {
             RGBColor[
             0.4653446361758491, 0.5701283226319324, 0.9524120897475179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 314}], {
             RGBColor[
             0.27434229412121725`, 0.4056815238004595, 0.9389347598459252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 406}], {
             RGBColor[
             0.35118939031714774`, 0.4764899015985373, 0.9436758749335621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 432}], {
             RGBColor[
             0.28855483307734864`, 0.4206198033703701, 0.9397441429139097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 493}], {
             RGBColor[
             0.2733906528975818, 0.4046812885368802, 0.9388805652860661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 238}], {
             RGBColor[
             0.5781077146635654, 0.6679567426795029, 0.9602144407477138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 258}], {
             RGBColor[
             0.5423535654058886, 0.6378943982586738, 0.9576858591221857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 293}], {
             RGBColor[
             0.7396376270146225, 0.7965298027687717, 0.9746838244203624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 403}], {
             RGBColor[
             0.7064676273124759, 0.7706171469001197, 0.9713777488413233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 445}], {
             RGBColor[
             0.8163225920234214, 0.8145058037505225, 0.6394598956191903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 471}], {
             RGBColor[
             0.8131815162037359, 0.854543894896763, 0.9628221166971644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 497}], {
             RGBColor[
             0.5738542866268592, 0.6645036181845554, 0.959879595311844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 254}], {
             RGBColor[
             0.20473141614653206`, 0.3325160774644852, 0.9349705233253323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 297}], {
             RGBColor[
             0.20614792707638763`, 0.3340049202637436, 0.9350511915272475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 325}], {
             RGBColor[
             0.22533443478540557`, 0.3541711563607717, 0.9361438347573814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 392}], {
             RGBColor[
             0.22694196327999852`, 0.35586077073178224`, 0.9362353811270232]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 412}], {
             RGBColor[
             0.2036444979201258, 0.3313736574939363, 0.9349086249402898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 413}], {
             RGBColor[
             0.2236716605546839, 0.35242347521830786`, 0.9360491422247958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 426}], {
             RGBColor[
             0.20219514191155313`, 0.32985029243444797`, 0.9348260862597317]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 474}], {
             RGBColor[
             0.22327343139036823`, 0.3520049111174247, 0.9360264636630153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 490}], {
             RGBColor[
             0.2165006286676464, 0.34488626603534933`, 0.9356407625674201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 234}], {
             RGBColor[
             0.9443267569423743, 0.8151145515040961, 0.2837836064703105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 301}], {
             RGBColor[
             0.8093616863432395, 0.8079745679423065, 0.6371695161143949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 336}], {
             RGBColor[
             0.7938129054109903, 0.7955671950703103, 0.6357978963718616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 294}], {
             RGBColor[
             0.19229714625130181`, 0.3194468714263523, 0.9342624100496528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 296}], {
             RGBColor[
             0.18966575842362554`, 0.31668111597984006`, 0.934112556405656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 339}], {
             RGBColor[
             0.1886442457825459, 0.3156074414264231, 0.9340543827719392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 344}], {
             RGBColor[
             0.1936890488951341, 0.3209098493567448, 0.9343416768460837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 438}], {
             RGBColor[
             0.19987204711910306`, 0.3274085725148659, 0.9346937894480125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 439}], {
             RGBColor[
             0.19816628717948753`, 0.32561571066690326`, 0.9345966489428971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 246}], {
             RGBColor[
             0.22404185527291065`, 0.35281257333886495`, 0.9360702242663449]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 268}], {
             RGBColor[
             0.19724310055792588`, 0.32464538299422946`, 0.9345440748305314]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 411}], {
             RGBColor[
             0.24469698646716248`, 0.3745224258349809, 0.9372465034313293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 286}], {
             RGBColor[
             0.19666508001759797`, 0.3240378467577258, 0.9345111574158644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 330}], {
             RGBColor[
             0.1977574976662851, 0.3251860469697754, 0.9345733689848701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 333}], {
             RGBColor[
             0.21886126221320776`, 0.3473674415645458, 0.9357751971555954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 358}], {
             RGBColor[
             0.21540867556861554`, 0.34373855409444265`, 0.9355785774538301]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 361}], {
             RGBColor[
             0.21801752264150492`, 0.34648061777850747`, 0.9357271474351878]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 398}], {
             RGBColor[
             0.2060967195595755, 0.33395109791683003`, 0.9350482753349197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 441}], {
             RGBColor[
             0.21370093658000952`, 0.34194361214051205`, 0.9354813242448025]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 464}], {
             RGBColor[
             0.20419415303821636`, 0.3319513798731969, 0.9349399269861233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 481}], {
             RGBColor[
             0.20560152977914695`, 0.33343062206075413`, 0.9350200750094919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 247}], {
             RGBColor[
             0.18412221385498584`, 0.31085449915717356`, 0.9337968597434113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 252}], {
             RGBColor[
             0.18313599846224066`, 0.30981792424973087`, 0.9337406962357694]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 309}], {
             RGBColor[
             0.18608052902366917`, 0.31291281256381276`, 0.9339083828952002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 320}], {
             RGBColor[
             0.1825517796800877, 0.30920387326807797`, 0.9337074258404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 424}], {
             RGBColor[
             0.18871848366086047`, 0.31568547014348514`, 0.9340586105092841]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 284}], {
             RGBColor[
             0.19690493413279425`, 0.3242899486404264, 0.9345248167528926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 345}], {
             RGBColor[
             0.18891037080707027`, 0.3158871557004993, 0.9340695381983891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 366}], {
             RGBColor[
             0.18476826025973897`, 0.3115335348902769, 0.9338336511304219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 389}], {
             RGBColor[
             0.19095055240575043`, 0.3180315159156967, 0.9341857235222557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 405}], {
             RGBColor[
             0.18431945622850954`, 0.3110618133976357, 0.9338080924047896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 429}], {
             RGBColor[
             0.18946440368264025`, 0.31646947938043657`, 0.9341010895510347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 472}], {
             RGBColor[
             0.18505776823943543`, 0.311837826132804, 0.933850138181577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 488}], {
             RGBColor[
             0.18475420080410804`, 0.31151875751098784`, 0.9338328504652229]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 229}], {
             RGBColor[
             0.21399982241481183`, 0.34225776010334574`, 0.9354983453509325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 263}], {
             RGBColor[
             0.2087485483203887, 0.3367383380800992, 0.935199293059819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 265}], {
             RGBColor[
             0.18874076831201309`, 0.315708892724775, 0.9340598795871999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 267}], {
             RGBColor[
             0.2112079223469873, 0.3393232961153739, 0.935339350772316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 270}], {
             RGBColor[
             0.18663641062037617`, 0.3134970793668807, 0.9339400395297794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 329}], {
             RGBColor[
             0.18736891797604732`, 0.31426699104133987`, 0.9339817547400375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 424}], {
             RGBColor[
             0.19331536997885967`, 0.3205170891231287, 0.9343203963846103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 256}], {
             RGBColor[
             0.28488710481113977`, 0.4165048432644388, 0.9395447890804083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 279}], {
             RGBColor[
             0.23309972747079383`, 0.36233297132110764`, 0.9365860566880932]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 287}], {
             RGBColor[
             0.28118525934636124`, 0.41287391412114016`, 0.9393244565922372]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 298}], {
             RGBColor[
             0.2669525907215979, 0.3979144769932027, 0.9385139271694034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 318}], {
             RGBColor[
             0.22809876360932468`, 0.35707664122328114`, 0.9363012591944456]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 335}], {
             RGBColor[
             0.2342958788041693, 0.36359020221286015`, 0.9366541757369817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 409}], {
             RGBColor[
             0.2557251463437433, 0.3861137210909889, 0.9378745408216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 468}], {
             RGBColor[
             0.23985909159475186`, 0.369437491583826, 0.9369709924753695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 232}], {
             RGBColor[
             0.2566501782178637, 0.3870859882410977, 0.9379272200183691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 263}], {
             RGBColor[
             0.22958947316632627`, 0.3586434714841348, 0.9363861528984097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 267}], {
             RGBColor[
             0.23204884719292487`, 0.3612284295194095, 0.9365262106109067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 280}], {
             RGBColor[
             0.24415725813790062`, 0.37395513714017414`, 0.9372157667014342]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 393}], {
             RGBColor[
             0.2280783028843851, 0.35705513570408476`, 0.9363000939864292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 480}], {
             RGBColor[
             0.23910094988203007`, 0.36864063657479446`, 0.9369278174264002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 485}], {
             RGBColor[
             0.2450928096239232, 0.3749384610693741, 0.9372690449745389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 382}], {
             RGBColor[
             0.20898405610198123`, 0.3369858716906088, 0.9352127048795782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 413}], {
             RGBColor[
             0.21810416040748024`, 0.34657167956369916`, 0.9357320813277911]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 474}], {
             RGBColor[
             0.21770593124316456`, 0.3461531154628161, 0.9357094027660106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 484}], {
             RGBColor[
             0.19535510076833423`, 0.3226609755092681, 0.9344365560355595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 490}], {
             RGBColor[
             0.21093312852044277`, 0.33903447038074064`, 0.9353237016704152]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 233}], {
             RGBColor[
             0.8631076739966228, 0.8934453053740385, 0.9626713381948079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 275}], {
             RGBColor[
             0.6264851574368956, 0.7057897543518528, 0.9650087769508688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 326}], {
             RGBColor[
             0.7445199877539495, 0.8003439400856498, 0.9751704525106033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 346}], {
             RGBColor[
             0.6025366315327623, 0.6860240764087309, 0.963212758449727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 355}], {
             RGBColor[
             0.6616838941423232, 0.7343656744943371, 0.9677797504415411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 395}], {
             RGBColor[
             0.6338994865668826, 0.711809040751297, 0.9655924600995638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 404}], {
             RGBColor[
             0.8002424461846211, 0.8440108833840196, 0.9806882202971826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 431}], {
             RGBColor[
             0.5924549682477664, 0.6772918463903979, 0.9625703637800718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 444}], {
             RGBColor[
             0.664761024690349, 0.7368638276963759, 0.9680219934301821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 486}], {
             RGBColor[
             0.5884962722514289, 0.6738630228882163, 0.9623181191717225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 267}], {
             RGBColor[
             0.25385827815003914`, 0.3841515242531258, 0.9377682254397526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 280}], {
             RGBColor[
             0.26596668909501486`, 0.3968782318738905, 0.9384577815302801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 338}], {
             RGBColor[
             0.351395977443279, 0.47598308304576464`, 0.9437141472934822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 383}], {
             RGBColor[
             0.2731170371748888, 0.40439370106409095`, 0.938864983275437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 393}], {
             RGBColor[
             0.24988773384149937`, 0.3799782304378011, 0.9375421088152751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 395}], {
             RGBColor[
             0.3913003181998807, 0.5091662530135891, 0.9466381048606165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 480}], {
             RGBColor[
             0.2609103808391443, 0.3915637313085108, 0.9381698322552461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 259}], {
             RGBColor[
             0.8229153142047934, 0.8620467284314131, 0.9586653393897153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 275}], {
             RGBColor[
             0.7259348855245369, 0.7839404012756612, 0.9506021698205669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 326}], {
             RGBColor[
             0.8439697158415906, 0.8784945870094583, 0.9607638453803016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 346}], {
             RGBColor[
             0.7019863596204035, 0.7641747233325396, 0.948806151319425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 348}], {
             RGBColor[
             0.7123189222990802, 0.7728863489370825, 0.9495302713185423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 355}], {
             RGBColor[
             0.7611336222299645, 0.8125163214181457, 0.9533731433112391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 379}], {
             RGBColor[
             0.8949909626419136, 0.5916992159390957, 0.5610798957464819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 400}], {
             RGBColor[
             0.9762128798080161, 0.9808371360064839, 0.8829178984103572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 404}], {
             RGBColor[
             0.8996921742722623, 0.9221615303078283, 0.9662816131668808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 431}], {
             RGBColor[
             0.6919046963354076, 0.7554424933142063, 0.9481637566497699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 444}], {
             RGBColor[
             0.7642107527779903, 0.8150144746201845, 0.9536153862998804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 486}], {
             RGBColor[
             0.6879460003390702, 0.7520136698120249, 0.9479115120414208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 336}], {
             RGBColor[
             0.7758644491107505, 0.7262741691289183, 0.6116347463560659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 449}], {
             RGBColor[
             0.9549924747052941, 0.851092521948047, 0.32521790592745947`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 274}], {
             RGBColor[
             0.23060114107907964`, 0.35970679860388893`, 0.9364437658894125]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 284}], {
             RGBColor[
             0.2119740420649528, 0.3401285365137513, 0.9353829801568815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 300}], {
             RGBColor[
             0.22449059247181202`, 0.353284224586492, 0.9360957791859752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 305}], {
             RGBColor[
             0.2638362786788805, 0.394471813217312, 0.9383425806338642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 308}], {
             RGBColor[
             0.2040111506020718, 0.33175903270978435`, 0.9349295052681127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 345}], {
             RGBColor[
             0.20397947873922884`, 0.3317257435738243, 0.934927701602378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 389}], {
             RGBColor[
             0.20601966033790897`, 0.3338701037890217, 0.9350438869262447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 432}], {
             RGBColor[
             0.25417547246619693`, 0.38448491559068887`, 0.9377862891868108]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 456}], {
             RGBColor[
             0.20636469541016642`, 0.3342327575264513, 0.9350635361631761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 289}], {
             RGBColor[
             0.20921618528861102`, 0.33722985418359713`, 0.9352259242933523]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 300}], {
             RGBColor[
             0.22011134127912346`, 0.34868135392241384`, 0.9358463873090731]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 308}], {
             RGBColor[
             0.19963189940938322`, 0.3271561620457061, 0.9346801133912106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 314}], {
             RGBColor[
             0.23558368231737692`, 0.3649437653567001, 0.9367275142419242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 466}], {
             RGBColor[
             0.2016228242267626, 0.329248750260696, 0.934793493614251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 470}], {
             RGBColor[
             0.2014866380141136, 0.3291056099164974, 0.9347857380109101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 493}], {
             RGBColor[
             0.23463204109374153`, 0.36394353009312075`, 0.9366733196820654]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 241}], {
             RGBColor[
             0.2242600552960576, 0.35304191539787294`, 0.9360826504348652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 274}], {
             RGBColor[
             0.23848727143504053`, 0.36799562161754756`, 0.9368928693467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 284}], {
             RGBColor[
             0.21986017242091369`, 0.34841735952740993`, 0.9358320836141691]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 351}], {
             RGBColor[
             0.2365402762573613, 0.3659492062391825, 0.9367819908516525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 371}], {
             RGBColor[
             0.24348618176994377`, 0.3732497933287522, 0.9371775498950476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 429}], {
             RGBColor[
             0.2124196419707597, 0.3405968902674201, 0.9354083564123112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 432}], {
             RGBColor[
             0.26206160282215785`, 0.3927737386043475, 0.9382353926440985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 460}], {
             RGBColor[
             0.26678188416083737`, 0.3977350535744224, 0.9385042056833057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 258}], {
             RGBColor[
             0.4509349141328164, 0.5640927881888469, 0.9502045107268047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 266}], {
             RGBColor[
             0.7401362180244184, 0.7914194702417209, 0.7478504944629321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 293}], {
             RGBColor[
             0.6482189757415503, 0.7227281926989446, 0.9672024760249813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 403}], {
             RGBColor[
             0.6150489760394036, 0.6968155368302928, 0.9638964004459423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 445}], {
             RGBColor[
             0.7249039407503491, 0.7407041936806955, 0.6319785472238091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 471}], {
             RGBColor[
             0.7217628649306637, 0.780742284826936, 0.9553407683017833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 483}], {
             RGBColor[
             0.46936492725835366`, 0.5800559392387936, 0.9513788548661433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 497}], {
             RGBColor[
             0.4824356353537869, 0.5907020081147285, 0.9523982469164629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 251}], {
             RGBColor[
             0.2177871872756262, 0.3462385207048633, 0.9357140301768516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 272}], {
             RGBColor[
             0.22693559422031087`, 0.3558540764462288, 0.9362350184184962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 332}], {
             RGBColor[
             0.1916360269785587, 0.31875199315331637`, 0.9342247602851084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 387}], {
             RGBColor[
             0.1927675658632359, 0.3199413122648211, 0.934289199750629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 435}], {
             RGBColor[
             0.21752143841029148`, 0.3459592017979452, 0.9356988961721111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 453}], {
             RGBColor[
             0.21828737914361301`, 0.34676425407211353`, 0.935742515363766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 454}], {
             RGBColor[
             0.20401834156350113`, 0.3317665908661798, 0.9349299147827279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 489}], {
             RGBColor[
             0.1941327088524955, 0.32137616410159764`, 0.9343669426243193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 434}], {
             RGBColor[
             0.9649429424873008, 0.8858096572696792, 0.4713319778660402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 495}], {
             RGBColor[
             0.9404490296531263, 0.7834756918464549, 0.4513533807985771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 271}], {
             RGBColor[
             0.2118628562397169, 0.3400116731618399, 0.935376648288619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 304}], {
             RGBColor[
             0.20316948858682138`, 0.3308743925673022, 0.9348815738614715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 311}], {
             RGBColor[
             0.2028072709740812, 0.33049367889038916`, 0.934860946104279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 351}], {
             RGBColor[
             0.22791016546505544`, 0.3568784126158412, 0.9362905188091355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 371}], {
             RGBColor[
             0.2348560709776379, 0.3641789997054109, 0.9366860778525307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 429}], {
             RGBColor[
             0.20378953117845383`, 0.33152609664407884`, 0.9349168843697941]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 442}], {
             RGBColor[
             0.22676711964941848`, 0.35567699899031613`, 0.9362254240409197]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 249}], {
             RGBColor[
             0.8500313217686346, 0.8830430785885436, 0.951908121903962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 269}], {
             RGBColor[
             0.787493374586991, 0.8335677780907182, 0.9460989448159113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 282}], {
             RGBColor[
             0.8349131599958114, 0.8712326557093291, 0.9504012848257013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 310}], {
             RGBColor[
             0.8089627721429287, 0.8509600154884045, 0.9478147926846883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 323}], {
             RGBColor[
             0.9829115082024764, 0.98536084245597, 0.8504363857845441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 419}], {
             RGBColor[
             0.8111996093173061, 0.8527074496896203, 0.9480377397097984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 449}], {
             RGBColor[
             0.9783597736506789, 0.9679158712997968, 0.6606061921458748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 499}], {
             RGBColor[
             0.8008428775112291, 0.844405505952868, 0.9471498665869478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 273}], {
             RGBColor[
             0.1918690378137841, 0.3189969023148785, 0.9342380299074659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 279}], {
             RGBColor[
             0.20228104719014361`, 0.3299405843289558, 0.934830978438262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 283}], {
             RGBColor[
             0.18944836976348856`, 0.3164526267147989, 0.934100176443059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 285}], {
             RGBColor[
             0.20548353415746184`, 0.3333066011810086, 0.9350133553333959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 318}], {
             RGBColor[
             0.19728008332867447`, 0.3246842542311293, 0.9345461809446143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 335}], {
             RGBColor[
             0.2034771985235191, 0.3311978152207083, 0.9348990974871504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 396}], {
             RGBColor[
             0.19700888147424034`, 0.32439920388692833`, 0.9345307364002116]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 421}], {
             RGBColor[
             0.1904580230623436, 0.31751383634761216`, 0.9341576747047806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 430}], {
             RGBColor[
             0.19906776015361727`, 0.3265632159194014, 0.934647986495164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 459}], {
             RGBColor[
             0.19552964555273866`, 0.32284443314445566`, 0.9344464961028154]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 477}], {
             RGBColor[
             0.19718654273618264`, 0.32458593713760425`, 0.9345408539462529]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 261}], {
             RGBColor[
             0.388007213318593, 0.5104940791921502, 0.9459444544247217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 262}], {
             RGBColor[
             0.3949445171400494, 0.5165028230832673, 0.9463864932898081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 295}], {
             RGBColor[
             0.7157587889214511, 0.7746651605070033, 0.9256601695039643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 341}], {
             RGBColor[
             0.7205094989495678, 0.7757802394753833, 0.7851817105206231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 376}], {
             RGBColor[
             0.40891528656398646`, 0.5286036013669932, 0.947276698363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 391}], {
             RGBColor[
             0.45991819988990085`, 0.5722422337278446, 0.9506750794005083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 407}], {
             RGBColor[
             0.361925627233212, 0.4849803667690406, 0.9443895897897958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 448}], {
             RGBColor[
             0.373652859998312, 0.49730643195466345`, 0.9450574383468822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 455}], {
             RGBColor[
             0.5298831385666443, 0.6290429228301937, 0.9561829756631566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 475}], {
             RGBColor[
             0.39162513268333266`, 0.5136277391039731, 0.9461749850474426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 478}], {
             RGBColor[
             0.34801769220506096`, 0.4703622452404419, 0.9435975534648887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 482}], {
             RGBColor[
             0.3895468312104969, 0.511827618826672, 0.9460425575153633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 262}], {
             RGBColor[
             0.2935462908702744, 0.4226836514910424, 0.9401449256179049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 299}], {
             RGBColor[
             0.24199930981785328`, 0.3716869966339784, 0.9370928747370061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 376}], {
             RGBColor[
             0.30751706029421144`, 0.43478442977476833`, 0.9410351306917317]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 438}], {
             RGBColor[
             0.22328352119424416`, 0.3520155161410289, 0.9360270382624196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 448}], {
             RGBColor[
             0.272254633728537, 0.40348726036243854`, 0.9388158706749788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 475}], {
             RGBColor[
             0.2902269064135576, 0.4198085675117481, 0.9399334173755393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 482}], {
             RGBColor[
             0.2881486049407218, 0.4180084472344471, 0.93980098984346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 384}], {
             RGBColor[
             0.2539870125967417, 0.38428683231884564`, 0.9377755566760467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 402}], {
             RGBColor[
             0.22901412567720097`, 0.3580387447939263, 0.9363533877100543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 411}], {
             RGBColor[
             0.2605541594338602, 0.3911893200258155, 0.9381495459731974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 458}], {
             RGBColor[
             0.2394606076875042, 0.3690186597319697, 0.9369482994063559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 252}], {
             RGBColor[
             0.18329308738435063`, 0.3099830346668814, 0.9337496422174913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 278}], {
             RGBColor[
             0.18437169562717964`, 0.3111167203178072, 0.9338110673612625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 309}], {
             RGBColor[
             0.18623761794577917`, 0.3130779229809633, 0.933917328876922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 401}], {
             RGBColor[
             0.1825033131056717, 0.3091529318254084, 0.9337046657406869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 451}], {
             RGBColor[
             0.19468301666075716`, 0.32195457249961096`, 0.9343982818398924]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 339}], {
             RGBColor[
             0.18022958629127006`, 0.30676310078086577`, 0.933575180362284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 344}], {
             RGBColor[
             0.18527438940385826`, 0.31206550871118754`, 0.9338624744364286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 387}], {
             RGBColor[
             0.18458186461527748`, 0.3113376212497815, 0.9338230361742175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 439}], {
             RGBColor[
             0.18975162768821172`, 0.3167713700213459, 0.934117446533242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 269}], {
             RGBColor[
             0.6644117978227214, 0.7371426324130581, 0.9676100378285277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 282}], {
             RGBColor[
             0.7118315832315418, 0.7748075100316689, 0.9719123778383179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 310}], {
             RGBColor[
             0.685881195378659, 0.7545348698107444, 0.9693258856973048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 323}], {
             RGBColor[
             0.8598299314382067, 0.8889356967783099, 0.8719474787971606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 406}], {
             RGBColor[
             0.5717259495199576, 0.6608964487773493, 0.960589670883349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 419}], {
             RGBColor[
             0.6881180325530365, 0.7562823040119602, 0.9695488327224149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 499}], {
             RGBColor[
             0.6777613007469594, 0.7479803602752079, 0.9686609595995643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 263}], {
             RGBColor[
             0.22198989446995654`, 0.350655832433131, 0.9359533681342207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 365}], {
             RGBColor[
             0.21334264494811753`, 0.3415670249183921, 0.9354609200664112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 485}], {
             RGBColor[
             0.23749323092755345`, 0.3669508220183703, 0.9368362602103498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 258}], {
             RGBColor[
             0.3270553942889411, 0.45124571304551764`, 0.9422970062673146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 272}], {
             RGBColor[
             0.24807843064742718`, 0.378076538064383, 0.937439071674997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 435}], {
             RGBColor[
             0.2386642748374078, 0.3681816634160995, 0.9369029494286119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 447}], {
             RGBColor[
             0.23632980233893142`, 0.3657279848060955, 0.9367700046733661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 453}], {
             RGBColor[
             0.23943021557072935`, 0.3689867156902678, 0.9369465686202667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 454}], {
             RGBColor[
             0.22516117799061744`, 0.3539890524843341, 0.9361339680392287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 309}], {
             RGBColor[
             0.18525140255303396`, 0.3120413480735207, 0.9338611653692801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 320}], {
             RGBColor[
             0.18172265320945252`, 0.3083324087777858, 0.93366020831448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 424}], {
             RGBColor[
             0.1878893571902253, 0.31481400565319295`, 0.934011392983364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 287}], {
             RGBColor[
             0.340823165506129, 0.46920105185432204`, 0.9429534744527581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 301}], {
             RGBColor[
             0.5169703257345344, 0.6164641572661, 0.9558333707121969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 336}], {
             RGBColor[
             0.5014215448022852, 0.6040567843941038, 0.9544617509696633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 354}], {
             RGBColor[
             0.34404011319445926`, 0.47241198691533204`, 0.9431429096833921]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 388}], {
             RGBColor[
             0.3530902196198862, 0.48025073422946185`, 0.9437195744621254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 436}], {
             RGBColor[
             0.36650668927910635`, 0.49187140591690626`, 0.9445744600450926]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 473}], {
             RGBColor[
             0.32054318862790937`, 0.44788551033051344`, 0.9417985597710807]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 350}], {
             RGBColor[
             0.18697690227356584`, 0.31385495768280075`, 0.9339594300257164]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 377}], {
             RGBColor[
             0.18661056292735312`, 0.3134699118026751, 0.9339385675419001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 412}], {
             RGBColor[
             0.19134257547531666`, 0.31844355701750904`, 0.9342080486561213]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 426}], {
             RGBColor[
             0.189893219466744, 0.3169201919580207, 0.9341255099755632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 476}], {
             RGBColor[
             0.18792976264725234`, 0.31485647435038233`, 0.9340136940143672]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 260}], {
             RGBColor[
             0.2034606107913817, 0.33118038046250897`, 0.9348981528403446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 299}], {
             RGBColor[
             0.21862190988624552`, 0.3471158670930945, 0.935761566394665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 312}], {
             RGBColor[
             0.19606964847691927`, 0.3234120104559323, 0.9344772484704849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 327}], {
             RGBColor[
             0.19047479361502342`, 0.3175314632617931, 0.9341586297629458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 334}], {
             RGBColor[
             0.19201279446501912`, 0.3191479996700246, 0.9342462166360848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 385}], {
             RGBColor[
             0.1893629494279947, 0.3163628445262328, 0.9340953118813207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 446}], {
             RGBColor[
             0.19028875988053398`, 0.31733593001162463`, 0.9341480354169789]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 478}], {
             RGBColor[
             0.22324206600367816`, 0.3519719441073331, 0.9360246774506443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 287}], {
             RGBColor[
             0.30785568445183253`, 0.44064627675886753`, 0.9408528157119771]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 298}], {
             RGBColor[
             0.2936230158270692, 0.42568683963093007`, 0.9400422862891433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 409}], {
             RGBColor[
             0.2823955714492146, 0.41388608372871627`, 0.93940289994134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 281}], {
             RGBColor[
             0.8907382712640035, 0.5148249421887663, 0.2381214507014296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 317}], {
             RGBColor[
             0.8901858085318111, 0.510578471538423, 0.23759241176516477`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 322}], {
             RGBColor[
             0.8919174314542486, 0.5238884841222806, 0.23925061583127932`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 324}], {
             RGBColor[
             0.9513926924014826, 0.9208016602260798, 0.6489338534613713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 326}], {
             RGBColor[
             0.8442173233312698, 0.8362115823989578, 0.6421148916132133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 343}], {
             RGBColor[
             0.9046416145156388, 0.621692130904697, 0.25143530790077595`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 374}], {
             RGBColor[
             0.9052484576679132, 0.6263565932934416, 0.25201642158872506`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 445}], {
             RGBColor[
             0.9630857175869136, 0.8871415989142806, 0.3110954128128076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 272}], {
             RGBColor[
             0.33620380123362575`, 0.46086126878688316`, 0.9428179945089592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 293}], {
             RGBColor[
             0.6124648264838737, 0.6926658482781156, 0.9646738943994533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 403}], {
             RGBColor[
             0.5792948267817268, 0.6667531924094637, 0.9613678188204143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 435}], {
             RGBColor[
             0.32678964542360633`, 0.4509663941385996, 0.942281872262574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 453}], {
             RGBColor[
             0.3275555861569279, 0.45177144641276795`, 0.942325491454229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 471}], {
             RGBColor[
             0.686008715672987, 0.7506799404061069, 0.9528121866762553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 497}], {
             RGBColor[
             0.44668148609611025`, 0.5606396636938994, 0.9498696652909349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 275}], {
             RGBColor[
             0.586292797645066, 0.6743911774092273, 0.9610027781457763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 331}], {
             RGBColor[
             0.4923539796181456, 0.5933274496466499, 0.9547717909351274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 348}], {
             RGBColor[
             0.5726768344196096, 0.6633371250706486, 0.9599308796437516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 372}], {
             RGBColor[
             0.6487722113207766, 0.7251147800966794, 0.9659213864599616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 400}], {
             RGBColor[
             0.8365707919285453, 0.8712879121400499, 0.8933185067355665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 404}], {
             RGBColor[
             0.7600500863927916, 0.8126123064413943, 0.97668222149209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 418}], {
             RGBColor[
             0.5798892585592409, 0.6691924959032061, 0.9604986680920036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 431}], {
             RGBColor[
             0.552262608455937, 0.6458932694477724, 0.9585643649749793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 444}], {
             RGBColor[
             0.6245686648985196, 0.7054652507537504, 0.9640159946250897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 486}], {
             RGBColor[
             0.5483039124595994, 0.6424644459455908, 0.95831212036663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 299}], {
             RGBColor[
             0.2249121050554158, 0.35372726103730096`, 0.9361197837040394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 312}], {
             RGBColor[
             0.2023598436460895, 0.3300234044001388, 0.9348354657798592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 328}], {
             RGBColor[
             0.2263686482084435, 0.35525818024130285`, 0.9362027316818419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 334}], {
             RGBColor[
             0.19830298963418935`, 0.3257593936142311, 0.9346044339454591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 399}], {
             RGBColor[
             0.20881488896675832`, 0.33680806630567356`, 0.9352030710614876]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 407}], {
             RGBColor[
             0.24344019620099944`, 0.3732014595801383, 0.9371749310849259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 446}], {
             RGBColor[
             0.19657895504970424`, 0.32394732395583115`, 0.9345062527263533]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 478}], {
             RGBColor[
             0.22953226117284842`, 0.3585833380515396, 0.9363828947600188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 262}], {
             RGBColor[
             0.33623006243366543`, 0.4656473134908974, 0.942645260155071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 299}], {
             RGBColor[
             0.2846830813812443, 0.4146506586338333, 0.9395932092741723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 313}], {
             RGBColor[
             0.3452565934007724, 0.4734656409279675, 0.9432204227264471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 328}], {
             RGBColor[
             0.28613962453427205`, 0.41618157783783527`, 0.9396761572519747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 391}], {
             RGBColor[
             0.40120374518351687`, 0.5213867241354746, 0.9469338462657712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 407}], {
             RGBColor[
             0.30321117252682794`, 0.43412485717667065`, 0.9406483566550587]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 448}], {
             RGBColor[
             0.314938405291928, 0.4464509223622935, 0.9413162052121451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 455}], {
             RGBColor[
             0.47116868386026034`, 0.5781874132378237, 0.9524417425284195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 475}], {
             RGBColor[
             0.3329106779769486, 0.46277222951160313`, 0.9424337519127055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 478}], {
             RGBColor[
             0.2893032374986769, 0.41950673564807195`, 0.9398563203301515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 482}], {
             RGBColor[
             0.3308323765041129, 0.4609721092343021, 0.9423013243806262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 299}], {
             RGBColor[
             0.2916203852027007, 0.4206594025249505, 0.9400352481392587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 376}], {
             RGBColor[
             0.3571381356790589, 0.48375683566574046`, 0.9439775040939842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 391}], {
             RGBColor[
             0.4081410490049733, 0.5273954680265918, 0.9473758851308575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 448}], {
             RGBColor[
             0.3218757091133844, 0.45245966625341066`, 0.9417582440772314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 455}], {
             RGBColor[
             0.47810598768171675`, 0.5841961571289409, 0.9528837813935058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 475}], {
             RGBColor[
             0.33984798179840503`, 0.4687809734027203, 0.9428757907777918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 478}], {
             RGBColor[
             0.29624054132013333`, 0.4255154795391891, 0.9402983591952379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 482}], {
             RGBColor[
             0.3377696803255693, 0.46698085312541926`, 0.9427433632457125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 267}], {
             RGBColor[
             0.22679757309850174`, 0.35570900749616285`, 0.9362271583197932]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 393}], {
             RGBColor[
             0.22282702878996197`, 0.35153571368083814`, 0.9360010416953157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 485}], {
             RGBColor[
             0.23984153552950008`, 0.3694190390461275, 0.9369699926834254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 281}], {
             RGBColor[
             0.8419839123581961, 0.3124840077358858, 0.18739747519941907`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 295}], {
             RGBColor[
             0.9251699045349664, 0.7351644032002858, 0.5555767619873893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 324}], {
             RGBColor[
             0.9026383334956752, 0.7184607257731993, 0.5982098779593608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 341}], {
             RGBColor[
             0.9299206145630832, 0.7362794821686658, 0.415098303004048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 374}], {
             RGBColor[
             0.8564940987621058, 0.42401565884056125`, 0.20129244608671454`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 397}], {
             RGBColor[
             0.8437768320344039, 0.3262651740296299, 0.18911437710616869`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 270}], {
             RGBColor[
             0.18221828136351503`, 0.30885334539234544`, 0.9336884336046377]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 320}], {
             RGBColor[
             0.18273053674122575`, 0.3093917582731863, 0.9337176057905845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 329}], {
             RGBColor[
             0.18295078871918613`, 0.3096232570668046, 0.9337301488148957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 424}], {
             RGBColor[
             0.18889724072199854`, 0.3158733551485935, 0.9340687904594684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 293}], {
             RGBColor[
             0.9016661303754756, 0.9199925303309897, 0.7623198781355807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 317}], {
             RGBColor[
             0.9054511863291719, 0.561405403936883, 0.35359294828676574`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 322}], {
             RGBColor[
             0.9071828092516094, 0.5747154165207407, 0.3552511523528803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 343}], {
             RGBColor[
             0.9199069923129997, 0.6725190633031569, 0.3674358444223769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 359}], {
             RGBColor[
             0.9515547370167402, 0.9596896244773535, 0.7671002510689349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 403}], {
             RGBColor[
             0.868496130673329, 0.8940798744623377, 0.7590138025565417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 440}], {
             RGBColor[
             0.9426079391450114, 0.7947470752330569, 0.3871278708766489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 445}], {
             RGBColor[
             0.9783510953842744, 0.9379685313127405, 0.42709594933440853`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 471}], {
             RGBColor[
             0.975210019564589, 0.978006622458981, 0.7504581704123827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 483}], {
             RGBColor[
             0.722812081892279, 0.7773202768708386, 0.7464962569767426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 280}], {
             RGBColor[
             0.24136535807007609`, 0.3710206731522022, 0.9370567721228178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 393}], {
             RGBColor[
             0.22528640281656057`, 0.35412067171611283`, 0.9361410994078128]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 424}], {
             RGBColor[
             0.21136439475697272`, 0.3394877585391924, 0.9353482616445844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 480}], {
             RGBColor[
             0.23630904981420553`, 0.3657061725868226, 0.9367688228477836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 485}], {
             RGBColor[
             0.24230090955609868`, 0.3720039970814022, 0.9371100503959223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 491}], {
             RGBColor[
             0.1839641739186956, 0.3106883891638218, 0.9337878596028387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 282}], {
             RGBColor[
             0.6492936360498982, 0.7253322095338435, 0.966103200750267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 310}], {
             RGBColor[
             0.6233432481970155, 0.705059569312919, 0.963516708609254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 323}], {
             RGBColor[
             0.7972919842565633, 0.8394603962804845, 0.8661383017091098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 406}], {
             RGBColor[
             0.5091880023383142, 0.611421148279524, 0.9547804937952983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 411}], {
             RGBColor[
             0.441541570634595, 0.5502832522185821, 0.9505633429393294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 419}], {
             RGBColor[
             0.6255800853713929, 0.7068070035141348, 0.9637396556343641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 499}], {
             RGBColor[
             0.615223353565316, 0.6985050597773825, 0.9628517825115135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 329}], {
             RGBColor[
             0.18084643102754924`, 0.3074114437089104, 0.9336103087574752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 479}], {
             RGBColor[
             0.18121603188329788`, 0.30779991764234993`, 0.9336313569794346]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 304}], {
             RGBColor[
             0.19940240032278655`, 0.3269149439546105, 0.9346670437577425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 307}], {
             RGBColor[
             0.199934386249049, 0.3274740948929682, 0.9346973395692404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 311}], {
             RGBColor[
             0.19904018271004636`, 0.32653423027769746`, 0.9346464160005499]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 351}], {
             RGBColor[
             0.2241430772010206, 0.3529189640031495, 0.9360759887054064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 371}], {
             RGBColor[
             0.23108898271360306`, 0.3602195510927192, 0.9364715477488016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 429}], {
             RGBColor[
             0.200022442914419, 0.32756664803138713`, 0.9347023542660651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 442}], {
             RGBColor[
             0.22300003138538366`, 0.3517175503776244, 0.9360108939371906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 435}], {
             RGBColor[
             0.24781268178209245`, 0.377797219157465, 0.9374239376702564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 453}], {
             RGBColor[
             0.24857862251541402`, 0.3786022714316334, 0.9374675568619113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 497}], {
             RGBColor[
             0.3677045224545963, 0.48747048871276477`, 0.9450117306986173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 279}], {
             RGBColor[
             0.19757076585955963`, 0.32498978000142653`, 0.9345627348847221]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 283}], {
             RGBColor[
             0.18473808843290457`, 0.31150182238726964`, 0.933831932889519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 285}], {
             RGBColor[
             0.20077325282687788`, 0.3283557968534793, 0.934745111779856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 396}], {
             RGBColor[
             0.19229860014365638`, 0.3194483995593991, 0.9342624928466716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 421}], {
             RGBColor[
             0.18574774173175967`, 0.3125630320200829, 0.9338894311512407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 430}], {
             RGBColor[
             0.19435747882303328`, 0.32161241159187215`, 0.9343797429416241]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 459}], {
             RGBColor[
             0.19081936422215473`, 0.3178936288169264, 0.9341782525492754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 477}], {
             RGBColor[
             0.19247626140559868`, 0.319635132810075, 0.9342726103927129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 284}], {
             RGBColor[
             0.22545727776759072`, 0.3543002721237432, 0.936150830483487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 300}], {
             RGBColor[
             0.23797382817444995`, 0.36745596019648397`, 0.9368636295125807]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 305}], {
             RGBColor[
             0.2773195143815185, 0.4086435488273039, 0.9391104309604698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 389}], {
             RGBColor[
             0.2195028960405469, 0.34804183939901356`, 0.9358117372528503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 432}], {
             RGBColor[
             0.26765870816883486`, 0.3986566512006808, 0.9385541395134164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 460}], {
             RGBColor[
             0.27237898950751444`, 0.4036179661707557, 0.9388229525526237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 331}], {
             RGBColor[
             0.39537355093788906`, 0.515221122490898, 0.946708621365979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 346}], {
             RGBColor[
             0.4653638430606762, 0.5765191723103537, 0.951143590075486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 348}], {
             RGBColor[
             0.475696405739353, 0.5852307979148967, 0.9518677100746031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 355}], {
             RGBColor[
             0.5245111056702372, 0.6248607703959599, 0.9557105820673001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 372}], {
             RGBColor[
             0.55179178264052, 0.6470084529409276, 0.9578582168908132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 404}], {
             RGBColor[
             0.663069657712535, 0.7345059792856424, 0.9686190519229416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 418}], {
             RGBColor[
             0.48290882987898437`, 0.5910861687474542, 0.9524354985228551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 431}], {
             RGBColor[
             0.4552821797756804, 0.5677869422920205, 0.9505011954058309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 444}], {
             RGBColor[
             0.5275882362182631, 0.6273589235979986, 0.9559528250559413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 486}], {
             RGBColor[
             0.45132348377934284`, 0.564358118789839, 0.9502489507974816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 306}], {
             RGBColor[
             0.22718429673725105`, 0.3561154785601833, 0.9362491816589136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 347}], {
             RGBColor[
             0.20833762491305394`, 0.33630643152494155`, 0.935175891579678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 382}], {
             RGBColor[
             0.21283416100439742`, 0.3410325760537981, 0.935431962658051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 462}], {
             RGBColor[
             0.20183278400452248`, 0.3294694312993405, 0.9348054505129868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 288}], {
             RGBColor[
             0.5772249873338873, 0.6663273536018384, 0.9606573715704986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 313}], {
             RGBColor[
             0.4022235011215268, 0.5228075131556505, 0.9468503037125551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 340}], {
             RGBColor[
             0.40350978000289583`, 0.523921623272436, 0.9469322642654641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 373}], {
             RGBColor[
             0.7171130809828956, 0.774434213301909, 0.8741433170431847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 386}], {
             RGBColor[
             0.3744145130463712, 0.49843012291785427`, 0.9450889814281427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 414}], {
             RGBColor[
             0.43294658493558325`, 0.5494183041682945, 0.9488079514458304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 498}], {
             RGBColor[
             0.6089064489917588, 0.6910771522369943, 0.9638150835884631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 401}], {
             RGBColor[
             0.18259570595575553`, 0.30925004256889155`, 0.9337099273768162]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 451}], {
             RGBColor[
             0.194775409510841, 0.3220516832430941, 0.9344035434760216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.2111852622032374, 0.3392994788675566, 0.935338060310652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 318}], {
             RGBColor[
             0.20298181137445004`, 0.33067713191767734`, 0.9348708859218705]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 335}], {
             RGBColor[
             0.20917892656929465`, 0.33719069290725634`, 0.9352238024644066]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 396}], {
             RGBColor[
             0.2027106095200159, 0.3303920815734764, 0.9348554413774677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 409}], {
             RGBColor[
             0.23060819410886862`, 0.3597142117853851, 0.9364441675490249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 421}], {
             RGBColor[
             0.19615975110811917`, 0.3235067140341602, 0.9344823796820367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 430}], {
             RGBColor[
             0.2047694881993928, 0.33255609360594945`, 0.9349726914724201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 459}], {
             RGBColor[
             0.20123137359851423`, 0.3288373108310037, 0.9347712010800716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 477}], {
             RGBColor[
             0.2028882707819582, 0.3305788148241523, 0.9348655589235091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 338}], {
             RGBColor[
             0.33890305736331594`, 0.4628522319448411, 0.9430026939765475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 383}], {
             RGBColor[
             0.2606241170949257, 0.3912628499631674, 0.9381535299585022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 393}], {
             RGBColor[
             0.23739481376153632`, 0.3668473793368775, 0.9368306554983403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 480}], {
             RGBColor[
             0.24841746075918128`, 0.37843288020758725`, 0.9374583789383113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 317}], {
             RGBColor[
             0.8178714627321924, 0.13837347065034328`, 0.1647470389362648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 322}], {
             RGBColor[
             0.8196030856546299, 0.15168348323420097`, 0.16640524300237935`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 324}], {
             RGBColor[
             0.8790783466018638, 0.5485966593380001, 0.5760884806324713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 343}], {
             RGBColor[
             0.8323272687160201, 0.24948713001661726`, 0.17858993507187598`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 374}], {
             RGBColor[
             0.8329341118682944, 0.254151592405362, 0.1791710487598251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 397}], {
             RGBColor[
             0.8202168451405925, 0.15640110759443068`, 0.16699297977927924`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 445}], {
             RGBColor[
             0.8907713717872949, 0.5149365980262008, 0.23825003998390762`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 310}], {
             RGBColor[
             0.6707630336058359, 0.74272444693153, 0.9678190486190441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 323}], {
             RGBColor[
             0.8447117696653836, 0.8771252738990953, 0.8704406417188999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 406}], {
             RGBColor[
             0.5566077877471345, 0.6490860258981348, 0.9590828338050883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 419}], {
             RGBColor[
             0.6729998707802133, 0.7444718811327458, 0.9680419956441542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 499}], {
             RGBColor[
             0.6626431389741363, 0.7361699373959933, 0.9671541225213036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 396}], {
             RGBColor[
             0.18987793209336085`, 0.3169041239593195, 0.9341246393822646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 421}], {
             RGBColor[
             0.18332707368146411`, 0.3100187564200033, 0.9337515776868337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 430}], {
             RGBColor[
             0.19193681077273775`, 0.31906813599179257`, 0.9342418894772171]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 459}], {
             RGBColor[
             0.18839869617185917`, 0.3153493532168468, 0.9340403990848687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 477}], {
             RGBColor[
             0.19005559335530314`, 0.3170908572099954, 0.934134756928306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 300}], {
             RGBColor[
             0.2193467291603231, 0.3478776981063463, 0.9358028437800496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 345}], {
             RGBColor[
             0.19883561542773992`, 0.32631921709367856`, 0.9346347661964527]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 389}], {
             RGBColor[
             0.20087579702642006`, 0.328463577308876, 0.9347509515203193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 432}], {
             RGBColor[
             0.249031609154708, 0.37907838911054315`, 0.9374933537808854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 456}], {
             RGBColor[
             0.2012208320986775, 0.3288262310463056, 0.9347706007572507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 472}], {
             RGBColor[
             0.19498301286010505`, 0.32226988752598323`, 0.9344153661796406]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 287}], {
             RGBColor[
             0.2592707940788048, 0.38984042166758914`, 0.938076460214796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 354}], {
             RGBColor[
             0.2624877417671351, 0.39305135672859914`, 0.93826589544543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 396}], {
             RGBColor[
             0.20591309648733414`, 0.33375809842552917`, 0.9350378182726016]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 409}], {
             RGBColor[
             0.23381068107618688`, 0.3630802286374379, 0.9366265444441588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 430}], {
             RGBColor[
             0.20797197516671106`, 0.33592211045800224`, 0.935155068367554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 473}], {
             RGBColor[
             0.2389908172005852, 0.3685248801437806, 0.9369215455331186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 477}], {
             RGBColor[
             0.20609075774927643`, 0.3339448316762051, 0.935047935818643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 319}], {
             RGBColor[
             0.18412936406719407`, 0.310862014483554, 0.9337972669374188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 330}], {
             RGBColor[
             0.18848828405783719`, 0.3154435157652098, 0.9340455009824417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 357}], {
             RGBColor[
             0.1879701028596808, 0.3148988744713619, 0.934015991329787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 358}], {
             RGBColor[
             0.20613946196016764`, 0.33399602288987706`, 0.9350507094514018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 367}], {
             RGBColor[
             0.1922727390163294, 0.3194212178748882, 0.9342610200937285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 368}], {
             RGBColor[
             0.18331387184910375`, 0.310004880457148, 0.9337508258620111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 492}], {
             RGBColor[
             0.18500229424892267`, 0.31177951945152094`, 0.9338469790198838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 336}], {
             RGBColor[
             0.46475221828321023`, 0.5718710801553506, 0.9521407597407114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 354}], {
             RGBColor[
             0.3073707866753843, 0.44022628267657893`, 0.9408219184544402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 388}], {
             RGBColor[
             0.31642089310081123`, 0.44806502999070874`, 0.9413985832331735]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 409}], {
             RGBColor[
             0.2786937259844361, 0.4102551545854176, 0.9391825674531689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 436}], {
             RGBColor[
             0.3298373627600314, 0.45968570167815315`, 0.9422534688161406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 473}], {
             RGBColor[
             0.28387386210883436`, 0.4156998060917603, 0.9394775685421287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 313}], {
             RGBColor[
             0.5362219144016962, 0.6308125527023426, 0.9580446920208532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 321}], {
             RGBColor[
             0.8483292768809738, 0.881288734461381, 0.9314462475205114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 373}], {
             RGBColor[
             0.8511114942630649, 0.882439252848601, 0.8853377053514828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 386}], {
             RGBColor[
             0.5084129263265404, 0.6064351624645463, 0.9562833697364408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 391}], {
             RGBColor[
             0.5921690661844405, 0.6787336359098497, 0.9617581155601771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 455}], {
             RGBColor[
             0.6621340048611841, 0.7355343250121988, 0.9672660118228255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 498}], {
             RGBColor[
             0.7429048622719281, 0.7990821917836863, 0.9750094718967612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 300}], {
             RGBColor[
             0.2209681235766699, 0.34958188644027033`, 0.9358951797934225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 308}], {
             RGBColor[
             0.20048868170692968`, 0.3280566945635627, 0.9347289058755601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 314}], {
             RGBColor[
             0.23644046461492338`, 0.36584429787455663`, 0.9367763067262738]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 466}], {
             RGBColor[
             0.20247960652430902`, 0.3301492827785526, 0.9348422860986005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 470}], {
             RGBColor[
             0.20234342031166005`, 0.33000614243435394`, 0.9348345304952597]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 493}], {
             RGBColor[
             0.235488823391288, 0.36484406261097735`, 0.9367221121664148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 297}], {
             RGBColor[
             0.18839455558370108`, 0.3153450011961642, 0.9340401632844985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 484}], {
             RGBColor[
             0.18316922942285135`, 0.3098528520962973, 0.9337425886898154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 349}], {
             RGBColor[
             0.1841373062547167, 0.310870362226204, 0.9337977192332487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 353}], {
             RGBColor[
             0.18189358061228061`, 0.3085120643155814, 0.9336699423772067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 394}], {
             RGBColor[
             0.18326692398746902`, 0.30995553527790365`, 0.9337481522507443]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 467}], {
             RGBColor[
             0.1871130842202519, 0.31399809354320196`, 0.933967185386117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 398}], {
             RGBColor[
             0.19568953649861287`, 0.32301248866624094`, 0.9344556016556456]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 399}], {
             RGBColor[
             0.19649944973854266`, 0.32386375883287244`, 0.9345017250165003]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 464}], {
             RGBColor[
             0.19378696997725373`, 0.3210127706226078, 0.9343472533068491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 481}], {
             RGBColor[
             0.1951943467181843, 0.32249201281016504`, 0.9344274013302178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 496}], {
             RGBColor[
             0.1854675912889076, 0.3122685761420814, 0.9338734769979656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 343}], {
             RGBColor[
             0.8279897500301316, 0.6038277857603807, 0.5867878259844261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 403}], {
             RGBColor[
             0.7765788883904609, 0.8253885969195616, 0.9783657841185909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 440}], {
             RGBColor[
             0.8506906968621433, 0.7260557976902806, 0.6064798524386981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 445}], {
             RGBColor[
             0.8864338531014064, 0.8692772537699642, 0.6464479308964578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 471}], {
             RGBColor[
             0.883292777281721, 0.9093153449162048, 0.969810151974432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 483}], {
             RGBColor[
             0.630894839609411, 0.7086289993280623, 0.9658482385387919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 497}], {
             RGBColor[
             0.6439655477048442, 0.7192750682039972, 0.9668676305891115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 296}], {
             RGBColor[
             0.18486063733978264`, 0.311630629058448, 0.9338389118684709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 327}], {
             RGBColor[
             0.18563559838764718`, 0.312445162255122, 0.9338830447536945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 385}], {
             RGBColor[
             0.18452375420061845`, 0.3112765435195617, 0.9338197268720694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 415}], {
             RGBColor[
             0.18394556991543065`, 0.3106688351768284, 0.9337868001323749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 438}], {
             RGBColor[
             0.19506692603526019`, 0.32235808559347384`, 0.9344201449108273]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 439}], {
             RGBColor[
             0.19336116609564466`, 0.3205652237455112, 0.9343230044057118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 321}], {
             RGBColor[
             0.9851155314829081, 0.988112904001859, 0.896337693305348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 341}], {
             RGBColor[
             0.9895466198460419, 0.9890958111978665, 0.7611561924651287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 391}], {
             RGBColor[
             0.7289553207863748, 0.7855578054503277, 0.9266495613450138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 397}], {
             RGBColor[
             0.9034028373173626, 0.5790815030588307, 0.5351722665672494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 455}], {
             RGBColor[
             0.7989202594631184, 0.8423584945526768, 0.9321574576076621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 327}], {
             RGBColor[
             0.1830042105599709, 0.3096794068086097, 0.9337331911096979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 339}], {
             RGBColor[
             0.18120773687102673`, 0.3077911990585188, 0.9336308845907572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 385}], {
             RGBColor[
             0.18189236637294215`, 0.30851078807304944`, 0.9336698732280726]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 415}], {
             RGBColor[
             0.18131418208775438`, 0.30790307973031616`, 0.9336369464883782]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 438}], {
             RGBColor[
             0.1924355382075839, 0.3195923301469616, 0.9342702912668306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 325}], {
             RGBColor[
             0.21444902327045198`, 0.3427298986836028, 0.9355239266751281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 392}], {
             RGBColor[
             0.21605655176504493`, 0.3444195130546133, 0.9356154730447699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 412}], {
             RGBColor[
             0.1927590864051722, 0.31993239981676747`, 0.9342887168580365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 413}], {
             RGBColor[
             0.2127862490397303, 0.34098221754113894`, 0.9354292341425425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 474}], {
             RGBColor[
             0.21238801987541464`, 0.34056365344025585`, 0.935406555580762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 484}], {
             RGBColor[
             0.1900371894005843, 0.3170715134867078, 0.934133708850311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 490}], {
             RGBColor[
             0.20561521715269282`, 0.3334450083581805, 0.9350208544851668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 335}], {
             RGBColor[
             0.2430317898200987, 0.3727721985793514, 0.9371516729457167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 409}], {
             RGBColor[
             0.26446105735967274`, 0.39529571745748016`, 0.9383720380303351]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 468}], {
             RGBColor[
             0.24859500261068126`, 0.37861948795031725`, 0.9374684896841046]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 312}], {
             RGBColor[
             0.21752114274095335`, 0.3459588910307243, 0.9356988793341796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 328}], {
             RGBColor[
             0.24152994730330735`, 0.3711936668718884, 0.9370661452361624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 399}], {
             RGBColor[
             0.22397618806162217`, 0.3527435529362591, 0.936066484615808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 407}], {
             RGBColor[
             0.2586014952958633, 0.3891369462107238, 0.9380383446392464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 448}], {
             RGBColor[
             0.2703287280609633, 0.40146301139634666`, 0.9387061931963326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 475}], {
             RGBColor[
             0.28830100074598397`, 0.41778431854565623`, 0.939823739896893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 478}], {
             RGBColor[
             0.24469356026771227`, 0.3745188246821251, 0.9372463083143392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 482}], {
             RGBColor[
             0.2862226992731482, 0.4159841982683552, 0.9396913123648138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 305}], {
             RGBColor[
             0.27120896577425085`, 0.40222097480990704`, 0.9387624442570324]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 308}], {
             RGBColor[
             0.21138383769744212`, 0.33950819430237933`, 0.9353493688912808]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 432}], {
             RGBColor[
             0.26154815956156724`, 0.39223407718328385`, 0.938206152809979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 456}], {
             RGBColor[
             0.21373738250553675`, 0.34198191911904635`, 0.9354833997863443]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 493}], {
             RGBColor[
             0.24638397938180046`, 0.376295562349794, 0.9373425751821356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 316}], {
             RGBColor[
             0.547580608865669, 0.6429772459967242, 0.9577838308857021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 336}], {
             RGBColor[
             0.6408993785116156, 0.7191341855671287, 0.9650206560001502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 388}], {
             RGBColor[
             0.4925680533292166, 0.5953281354024867, 0.9542784794926122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 436}], {
             RGBColor[
             0.5059845229884368, 0.6069488070899312, 0.9551333650755793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 346}], {
             RGBColor[
             0.343088083847486, 0.46567152269516504`, 0.9432988559850268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 370}], {
             RGBColor[
             0.23676036432994563`, 0.36618053275785845`, 0.936794524541795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 390}], {
             RGBColor[
             0.25033731885124844`, 0.38045077278838335`, 0.9375677120164789]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 422}], {
             RGBColor[
             0.22565049031831835`, 0.3545033507649412, 0.9361618336524187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 443}], {
             RGBColor[
             0.2662987639830351, 0.3972272636359636, 0.9384766927038922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 451}], {
             RGBColor[
             0.22492379054142386`, 0.35373954322399803`, 0.9361204491751804]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 379}], {
             RGBColor[
             0.8341112743268393, 0.26319977889761653`, 0.18029830085954252`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 400}], {
             RGBColor[
             0.9153331914929417, 0.6523376989650047, 0.5021363035234178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 307}], {
             RGBColor[
             0.19124101859615344`, 0.3183368142984305, 0.9342022651420929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 311}], {
             RGBColor[
             0.19034681505715081`, 0.3173969496831598, 0.9341513415734024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 337}], {
             RGBColor[
             0.1898974932161501, 0.3169246839396178, 0.9341257533592695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 423}], {
             RGBColor[
             0.1849544721508512, 0.3117292553943517, 0.9338442556221451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 427}], {
             RGBColor[
             0.18861159117236292`, 0.315573119360699, 0.9340525231401974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 433}], {
             RGBColor[
             0.1856912324704567, 0.31250363720355945`, 0.9338862130324074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 465}], {
             RGBColor[
             0.18487917380697239`, 0.31165011206074433`, 0.933839967492855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 469}], {
             RGBColor[
             0.18603078567582654`, 0.3128605291513198, 0.9339055500851292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 310}], {
             RGBColor[
             0.4776836488671362, 0.5829301850756662, 0.9531209010914763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 406}], {
             RGBColor[
             0.3635284030084348, 0.4892917640422711, 0.9443846862775205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 432}], {
             RGBColor[
             0.30089384576863576`, 0.43342166581410385`, 0.9404529542578681]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 460}], {
             RGBColor[
             0.3056141271073153, 0.43838298078417876`, 0.9407217672970755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 493}], {
             RGBColor[
             0.2857296655888689, 0.41748315098061395`, 0.9395893766300246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 331}], {
             RGBColor[
             0.2711023891418522, 0.40227617824530654`, 0.9387502520503602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 347}], {
             RGBColor[
             0.22192337354853872`, 0.3505859147270508, 0.9359495798661548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 382}], {
             RGBColor[
             0.2264199096398822, 0.3553120592559075, 0.9362056509445278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 431}], {
             RGBColor[
             0.33101101797964355`, 0.4548419980464291, 0.9425428260902121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 486}], {
             RGBColor[
             0.327052321983306, 0.4514131745442476, 0.942290581481863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 337}], {
             RGBColor[
             0.19042947914241254`, 0.31748383487797555`, 0.9341560491707674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 427}], {
             RGBColor[
             0.1891435770986254, 0.31613227029905666`, 0.9340828189516954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 433}], {
             RGBColor[
             0.18622321839671918`, 0.3130627881419171, 0.9339165088439054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 442}], {
             RGBColor[
             0.21483864965875055`, 0.34313942072144443`, 0.9355461153215412]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 469}], {
             RGBColor[
             0.186562771602089, 0.31341968008967747`, 0.9339358458966271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 500}], {
             RGBColor[
             0.19638085260421678`, 0.3237391057252033, 0.9344949710851491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 362}], {
             RGBColor[
             0.18507064546441102`, 0.3118513609127166, 0.9338508715204893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 369}], {
             RGBColor[
             0.18646563701697516`, 0.31331758548203437`, 0.9339303142257027]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 389}], {
             RGBColor[
             0.19291290556353907`, 0.320094073504909, 0.9342974766315505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 456}], {
             RGBColor[
             0.1932579406357965, 0.32045672724233865`, 0.9343171258684819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 393}], {
             RGBColor[
             0.20475589581124165`, 0.33254180714419534`, 0.9349719174060231]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 424}], {
             RGBColor[
             0.19083388775165383`, 0.3179088939672749, 0.9341790796427948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 323}], {
             RGBColor[
             0.8187613818125008, 0.8568526336781708, 0.8678541495778869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 406}], {
             RGBColor[
             0.5306573998942516, 0.6288133856772102, 0.9564963416640753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 408}], {
             RGBColor[
             0.7910483812120712, 0.837599492064294, 0.9781391837091735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 419}], {
             RGBColor[
             0.6470494829273306, 0.7241992409118212, 0.9654555035031411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 366}], {
             RGBColor[
             0.18627071422588198`, 0.31311270926977675`, 0.9339192136611123]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 405}], {
             RGBColor[
             0.18582191019465255`, 0.3126409877771355, 0.9338936549354799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 423}], {
             RGBColor[
             0.184592254538111, 0.31134854171743864`, 0.9338236278649524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 429}], {
             RGBColor[
             0.19096685764878327`, 0.3180486537599364, 0.934186652081725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 465}], {
             RGBColor[
             0.1845169561942322, 0.31126939838383133`, 0.9338193397356624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 469}], {
             RGBColor[
             0.18566856806308635`, 0.31247981547440673`, 0.9338849223279366]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 488}], {
             RGBColor[
             0.18625665477025105`, 0.3130979318904876, 0.9339184129959133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 327}], {
             RGBColor[
             0.18937402646973123`, 0.31637448719942296`, 0.9340959427024605]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 334}], {
             RGBColor[
             0.19091202731972692`, 0.3179910236076545, 0.9341835295755994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 385}], {
             RGBColor[
             0.1882621822827025, 0.31520586846386267`, 0.9340326248208353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 415}], {
             RGBColor[
             0.18768399799751473`, 0.31459816012112934`, 0.9339996980811409]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 446}], {
             RGBColor[
             0.18918799273524178`, 0.31617895394925455`, 0.9340853483564936]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 386}], {
             RGBColor[
             0.33341144011418006`, 0.4629153220183585, 0.9424763018784972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 391}], {
             RGBColor[
             0.4171675799720802, 0.5352137954636619, 0.9479510477022336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 407}], {
             RGBColor[
             0.31917500731539133`, 0.44795192850485793`, 0.9416655580915212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 498}], {
             RGBColor[
             0.5679033760595678, 0.6555623513374985, 0.9612024040388176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 406}], {
             RGBColor[
             0.3396550578396198, 0.4643665868457374, 0.9430190117624826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 411}], {
             RGBColor[
             0.27200862613590066`, 0.4032286907847955, 0.9388018609065139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 493}], {
             RGBColor[
             0.2618563204200539, 0.3925579737840803, 0.9382237021149867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 349}], {
             RGBColor[
             0.18430254906177113`, 0.31104404289341736`, 0.9338071295666557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 353}], {
             RGBColor[
             0.18205882341933505`, 0.3086857449827948, 0.9336793527106135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 364}], {
             RGBColor[
             0.19390091491665387`, 0.32113253397844377`, 0.9343537423025814]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 378}], {
             RGBColor[
             0.19518703914887203`, 0.3224843320914912, 0.934426985174956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 380}], {
             RGBColor[
             0.18543946082278231`, 0.31223900923860914`, 0.9338718750095351]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 487}], {
             RGBColor[
             0.1880750117052634, 0.3150091403196742, 0.9340219657333442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 372}], {
             RGBColor[
             0.5264921273018517, 0.6260724945913516, 0.9559761056168596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 418}], {
             RGBColor[
             0.45760917454031613`, 0.5701502103978782, 0.9505533872489015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 322}], {
             RGBColor[
             0.8190506229224375, 0.1474370125838577, 0.16587620406611453`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 343}], {
             RGBColor[
             0.8317748059838278, 0.24524065936627398`, 0.17806089613561116`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 374}], {
             RGBColor[
             0.832381649136102, 0.24990512175501872`, 0.1786420098235603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 440}], {
             RGBColor[
             0.8544757528158395, 0.36746867129617394`, 0.19775292258988314`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 445}], {
             RGBColor[
             0.8902189090551026, 0.5106901273758575, 0.23772100104764282`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 471}], {
             RGBColor[
             0.8870778332354172, 0.5507282185220981, 0.561083222125617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 335}], {
             RGBColor[
             0.2041779627078255, 0.33193436280942984`, 0.9349390049707589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 421}], {
             RGBColor[
             0.19115878724665003`, 0.3182503839363337, 0.9341975821883891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 430}], {
             RGBColor[
             0.1997685243379237, 0.32729976350812295`, 0.9346878939787725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 459}], {
             RGBColor[
             0.1962304097370451, 0.3235809807331772, 0.934486403586424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 330}], {
             RGBColor[
             0.18522178171588122`, 0.3120102146956035, 0.9338594785064245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 357}], {
             RGBColor[
             0.18470360051772483`, 0.3114655734017556, 0.9338299688537698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 368}], {
             RGBColor[
             0.18004736950714773`, 0.30657157938754187`, 0.9335648033859939]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 492}], {
             RGBColor[
             0.18173579190696668`, 0.3083462183819148, 0.9336609565438665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 329}], {
             RGBColor[
             0.18135868640525998`, 0.3079498565897512, 0.9336394809434219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 424}], {
             RGBColor[
             0.18730513840807234`, 0.31419995467154005`, 0.9339781225879946]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 341}], {
             RGBColor[
             0.9898662415110249, 0.9892279829702391, 0.7558592343220067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 373}], {
             RGBColor[
             0.9882173705299822, 0.9893955941614516, 0.8449321929931977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 391}], {
             RGBColor[
             0.7292749424513578, 0.7856899772227003, 0.9213526032018919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 397}], {
             RGBColor[
             0.9037224589823456, 0.5792136748312032, 0.5298753084241274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 455}], {
             RGBColor[
             0.7992398811281014, 0.8424906663250493, 0.9268604994645402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 498}], {
             RGBColor[
             0.8800107385388454, 0.9060385330965369, 0.934603959538476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 343}], {
             RGBColor[
             0.8335064289062653, 0.2585506719501317, 0.17971910020172568`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 374}], {
             RGBColor[
             0.8341132720585396, 0.26321513433887644`, 0.18030021388967482`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 440}], {
             RGBColor[
             0.8562073757382771, 0.38077868388003167`, 0.19941112665599764`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 445}], {
             RGBColor[
             0.89195053197754, 0.5240001399597152, 0.23937920511375732`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 471}], {
             RGBColor[
             0.8888094561578547, 0.5640382311059557, 0.5627414261917315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 419}], {
             RGBColor[
             0.8209982189868783, 0.8586000678793866, 0.8680770966029969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 449}], {
             RGBColor[
             0.9881583833202512, 0.9738084894895631, 0.5806455490390734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 499}], {
             RGBColor[
             0.8106414871808013, 0.8502981241426343, 0.8671892234801464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 342}], {
             RGBColor[
             0.7080228667800735, 0.7701523632700238, 0.969408565667581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 360}], {
             RGBColor[
             0.7679481729777577, 0.8188024264455834, 0.9741261052850922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 457}], {
             RGBColor[
             0.7044919829810323, 0.7672858327374596, 0.9691306015608669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 392}], {
             RGBColor[
             0.23524305947406288`, 0.3645857491516413, 0.9367081162749039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 413}], {
             RGBColor[
             0.23197275674874823`, 0.36114845363816694`, 0.9365218773726766]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 474}], {
             RGBColor[
             0.2315745275844326, 0.3607298895372839, 0.936499198810896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 490}], {
             RGBColor[
             0.22480172486171077`, 0.3536112444552085, 0.9361134977153007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 338}], {
             RGBColor[
             0.5748571876552486, 0.6636751524188924, 0.9607610097179233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 346}], {
             RGBColor[
             0.5833986733777301, 0.6710733580441507, 0.9613052656352206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 355}], {
             RGBColor[
             0.642545935987291, 0.7194149561297569, 0.9658722576270347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 395}], {
             RGBColor[
             0.6147615284118504, 0.6968583223867169, 0.9636849672850575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 443}], {
             RGBColor[
             0.5066093535132791, 0.6026290989849493, 0.956483102354086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 334}], {
             RGBColor[
             0.18531717245783108`, 0.3121104764135153, 0.9338649108680606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 385}], {
             RGBColor[
             0.18266732742080666`, 0.30932532126972345`, 0.9337140061132965]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 415}], {
             RGBColor[
             0.1820891431356189, 0.3087176129269901, 0.9336810793736019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 446}], {
             RGBColor[
             0.18359313787334597`, 0.31029840675511533`, 0.9337667296489547]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 398}], {
             RGBColor[
             0.2246228179747201, 0.35342320197362953`, 0.9361033092327558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 399}], {
             RGBColor[
             0.22543273121464985`, 0.354274472140261, 0.9361494325936104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 407}], {
             RGBColor[
             0.26005803844889097`, 0.3906678654147257, 0.9381212926170488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 464}], {
             RGBColor[
             0.22272025145336094`, 0.35142348392999634`, 0.9359949608839593]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 475}], {
             RGBColor[
             0.28975754389901165`, 0.4193152377496582, 0.9399066878746956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 478}], {
             RGBColor[
             0.24615010342073995`, 0.376049743886127, 0.9373292562921416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 481}], {
             RGBColor[
             0.22412762819429155`, 0.3529027261175536, 0.9360751089073279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 333}], {
             RGBColor[
             0.210684466253447, 0.33877311057202975`, 0.9353095407221728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 352}], {
             RGBColor[
             0.1864863756783814, 0.3133393831300794, 0.9339314952617896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 357}], {
             RGBColor[
             0.18906252050836794`, 0.3160470746834114, 0.9340782028987926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 358}], {
             RGBColor[
             0.20723187960885475`, 0.33514422310192665`, 0.9351129210204074]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 367}], {
             RGBColor[
             0.19336515666501655`, 0.3205694180869378, 0.9343232316627341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 368}], {
             RGBColor[
             0.18440628949779087`, 0.3111530806691976, 0.9338130374310167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 441}], {
             RGBColor[
             0.20552414062024876`, 0.33334928114799606`, 0.9350156678113797]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 492}], {
             RGBColor[
             0.1860947118976098, 0.3129277196635705, 0.9339091905888894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 348}], {
             RGBColor[
             0.3817575877124325, 0.5041670701523192, 0.9456367228639543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 372}], {
             RGBColor[
             0.4578529646135995, 0.56594472517835, 0.9516272296801642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 382}], {
             RGBColor[
             0.25675225340899854`, 0.38719327573892137`, 0.9379330330494976]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 404}], {
             RGBColor[
             0.5691308396856145, 0.6534422515230649, 0.9623880647122928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 418}], {
             RGBColor[
             0.38897001185206387`, 0.5100224409848767, 0.9462045113122062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 431}], {
             RGBColor[
             0.3613433617487599, 0.48672321452944306`, 0.9442702081951819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 444}], {
             RGBColor[
             0.43364941819134256`, 0.5462951958354212, 0.9497218378452923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 486}], {
             RGBColor[
             0.35738466575242234`, 0.48329439102726157`, 0.9440179635868327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 420}], {
             RGBColor[
             0.1873361545684642, 0.31423255462265, 0.9339798889124447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 454}], {
             RGBColor[
             0.19901001769354992`, 0.3265025249327872, 0.9346446981474854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 489}], {
             RGBColor[
             0.1891243849825443, 0.31611209816820496`, 0.9340817259890768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 358}], {
             RGBColor[
             0.22833564415577742`, 0.35732561769669713`, 0.9363147491911328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 361}], {
             RGBColor[
             0.2309444912286668, 0.3600676813807619, 0.9364633191724905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 367}], {
             RGBColor[
             0.21446892121193922`, 0.34275081268170826`, 0.9355250598334595]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 386}], {
             RGBColor[
             0.268695341419697, 0.3997462184736812, 0.9386131742434916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 441}], {
             RGBColor[
             0.2266279051671714, 0.35553067574276653`, 0.936217495982105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 450}], {
             RGBColor[
             0.22365738515605757`, 0.35240847086923904`, 0.9360483292619628]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 461}], {
             RGBColor[
             0.24252993321129454`, 0.3722447154639515, 0.9371230929542755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 385}], {
             RGBColor[
             0.18420532827080235`, 0.310941857677955, 0.9338015929864353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 415}], {
             RGBColor[
             0.18362714398561458`, 0.31033414933522163`, 0.9337686662467408]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 446}], {
             RGBColor[
             0.18513113872334164`, 0.31191494316334684`, 0.9338543165220936]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 409}], {
             RGBColor[
             0.23180434544224413`, 0.3609714426771376, 0.9365122865979134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 421}], {
             RGBColor[
             0.19735590244149465`, 0.3247639449259127, 0.9345504987309252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 430}], {
             RGBColor[
             0.2059656395327683, 0.33381332449770196`, 0.9350408105213086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 459}], {
             RGBColor[
             0.2024275249318897, 0.3300945417227562, 0.93483932012896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 354}], {
             RGBColor[
             0.4679691659715405, 0.5750820152163606, 0.9523301949713454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 388}], {
             RGBColor[
             0.4770192723969674, 0.5829207625304905, 0.9529068597500787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 436}], {
             RGBColor[
             0.49043574205618756`, 0.5945414342179349, 0.953761745333046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 420}], {
             RGBColor[
             0.18856527989536503`, 0.3155244432722696, 0.9340498857814837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 427}], {
             RGBColor[
             0.18780005171862202`, 0.314720139940244, 0.9340063071688718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 433}], {
             RGBColor[
             0.1848796930167158, 0.31165065778310447`, 0.9338399970610818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 500}], {
             RGBColor[
             0.1950373272242134, 0.32232697536639066`, 0.9344184593023257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 383}], {
             RGBColor[
             0.34605340544318985`, 0.47036770113504156`, 0.9434098957217043]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 395}], {
             RGBColor[
             0.4642366864681818, 0.5751402530845398, 0.9511830173068838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 443}], {
             RGBColor[
             0.3560845115696105, 0.4809110296827722, 0.9439811523759123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 480}], {
             RGBColor[
             0.3338467491074454, 0.4575377313794614, 0.9427147447015134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 344}], {
             RGBColor[
             0.1852310273425353, 0.3120199324354236, 0.9338600050311847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 387}], {
             RGBColor[
             0.1845385025539545, 0.3112920449740175, 0.9338205667689736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 439}], {
             RGBColor[
             0.18970826562688875`, 0.316725793745582, 0.9341149771279982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 384}], {
             RGBColor[
             0.3159339914529744, 0.4443075647988586, 0.9414896959063039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 414}], {
             RGBColor[
             0.3932297908847611, 0.5150176133855842, 0.946277232449094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 461}], {
             RGBColor[
             0.30853231078714655`, 0.43652792912541416`, 0.9410681811421904]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 499}], {
             RGBColor[
             0.4961829212208138, 0.5994318600646289, 0.9541521247756388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 374}], {
             RGBColor[
             0.9208708140731814, 0.677947066838142, 0.406871876564454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 391}], {
             RGBColor[
             0.7337060308144916, 0.7866728844187078, 0.7861711023616725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 397}], {
             RGBColor[
             0.9081535473454794, 0.5801965820272107, 0.39469380758390815`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 455}], {
             RGBColor[
             0.8036709694912352, 0.8434735735210568, 0.7916789986243209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 485}], {
             RGBColor[
             0.36582891890395064`, 0.48572268889805037`, 0.9448845663511518]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 374}], {
             RGBColor[
             0.8468374551199298, 0.3610187811212927, 0.19248490595917145`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 403}], {
             RGBColor[
             0.7948197503279848, 0.5779151298917289, 0.5834817504053871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 440}], {
             RGBColor[
             0.8689315587996673, 0.47858233066244793`, 0.21159581872549427`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 445}], {
             RGBColor[
             0.9046747150389304, 0.6218037867421315, 0.25156389718325395`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 471}], {
             RGBColor[
             0.901533639219245, 0.661841877888372, 0.5749261182612281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 387}], {
             RGBColor[
             0.1895833056665427, 0.31659445290433924`, 0.9341078608431181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 438}], {
             RGBColor[
             0.19645882867909248`, 0.32382106352386636`, 0.934499411707258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 439}], {
             RGBColor[
             0.19475306873947695`, 0.32202820167590374`, 0.9344022712021427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 389}], {
             RGBColor[
             0.1928812337006961, 0.3200607843689489, 0.9342956729658158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 456}], {
             RGBColor[
             0.1932262687729535, 0.32042343810637863`, 0.9343153222027473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 472}], {
             RGBColor[
             0.1869884495343811, 0.3138670945860562, 0.9339600876251372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 355}], {
             RGBColor[
             0.5005625797661037, 0.605095092452838, 0.9539145635661582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 390}], {
             RGBColor[
             0.34866455216030523`, 0.47153274446045024`, 0.9436164276057963]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 395}], {
             RGBColor[
             0.47277817219066315`, 0.5825384587097979, 0.951727273224181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 431}], {
             RGBColor[
             0.43133365387154704`, 0.5480212643488988, 0.948705176904689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 443}], {
             RGBColor[
             0.3646259972920919, 0.4883092353080305, 0.9445254082932095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 486}], {
             RGBColor[
             0.4273749578752095, 0.5445924408467173, 0.9484529322963398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 382}], {
             RGBColor[
             0.2075732378156851, 0.3355030122206657, 0.9351323608652922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 462}], {
             RGBColor[
             0.19657186081581016`, 0.32393986746620806`, 0.934505848720228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 355}], {
             RGBColor[
             0.5108951424447806, 0.6138067180573811, 0.9546386835652754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 372}], {
             RGBColor[
             0.5381758194150634, 0.6359544006023488, 0.9567863183887886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 400}], {
             RGBColor[
             0.7259744000228323, 0.7821275326457193, 0.8841834386643934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 404}], {
             RGBColor[
             0.6494536944870786, 0.7234519269470636, 0.967547153420917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 418}], {
             RGBColor[
             0.4692928666535278, 0.5800321164088754, 0.9513636000208304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 431}], {
             RGBColor[
             0.44166621655022387`, 0.5567328899534418, 0.9494292969038062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 444}], {
             RGBColor[
             0.5139722729928065, 0.6163048712594199, 0.9548809265539167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 486}], {
             RGBColor[
             0.4377075205538863, 0.5533040664512603, 0.949177052295457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 353}], {
             RGBColor[
             0.18295144203234145`, 0.3096239437403533, 0.9337301860201135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 378}], {
             RGBColor[
             0.1960796577618784, 0.3234225308490497, 0.9344778184844558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 380}], {
             RGBColor[
             0.18633207943578872`, 0.3131772079961678, 0.9339227083190349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 487}], {
             RGBColor[
             0.1889676303182698, 0.3159473390772327, 0.9340727990428441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 377}], {
             RGBColor[
             0.181157971499196, 0.3077388924974179, 0.9336280505264527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 412}], {
             RGBColor[
             0.18588998404715956`, 0.3127125377122519, 0.9338975316406739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 426}], {
             RGBColor[
             0.1844406280385869, 0.3111891726527635, 0.9338149929601158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 476}], {
             RGBColor[
             0.18247717121909524`, 0.3091254550451252, 0.9337031769989198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 371}], {
             RGBColor[
             0.2471362919389416, 0.37708629054672044`, 0.937385418269318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 442}], {
             RGBColor[
             0.23904734061072216`, 0.3685842898316257, 0.936924764457707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 460}], {
             RGBColor[
             0.2704319943298352, 0.4015715507923906, 0.9387120740575761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 357}], {
             RGBColor[
             0.185968194480225, 0.3127947418362315, 0.9339019856091351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 367}], {
             RGBColor[
             0.1902708306368736, 0.3173170852397579, 0.9341470143730765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 368}], {
             RGBColor[
             0.1813119634696479, 0.3079007478220177, 0.9336368201413592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 375}], {
             RGBColor[
             0.19306738802691092`, 0.32025644436866674`, 0.9343062741793031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 380}], {
             RGBColor[
             0.18408835379335264`, 0.31081891008554513`, 0.9337949314629927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 487}], {
             RGBColor[
             0.18672390467583372`, 0.3135890411666101, 0.933945022186802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 388}], {
             RGBColor[
             0.3196378407891415, 0.45127596505171874`, 0.9415880184638075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 409}], {
             RGBColor[
             0.28191067367276634`, 0.4134660896464276, 0.9393720026838029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 436}], {
             RGBColor[
             0.33305431044836165`, 0.46289663673916315`, 0.9424429040467747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 473}], {
             RGBColor[
             0.28709080979716467`, 0.41891074115277027`, 0.9396670037727628]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 395}], {
             RGBColor[
             0.5319254348002241, 0.6308800567954042, 0.9562942652159951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 404}], {
             RGBColor[
             0.6982683944179626, 0.7630818994281268, 0.9713900254136139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 431}], {
             RGBColor[
             0.49048091648110803`, 0.596362862434505, 0.9532721688965031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 443}], {
             RGBColor[
             0.4237732599016528, 0.5366508333936366, 0.9490924002850236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 444}], {
             RGBColor[
             0.5627869729236907, 0.655934843740483, 0.9587237985466135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 486}], {
             RGBColor[
             0.48652222048477045`, 0.5929340389323234, 0.9530199242881539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 365}], {
             RGBColor[
             0.2261799618783253, 0.3550598589449443, 0.9361919862744781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 457}], {
             RGBColor[
             0.35728371097557365`, 0.477585785779042, 0.9443210439032999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 494}], {
             RGBColor[
             0.30030937836549265`, 0.4286701061729542, 0.9405711545959381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 367}], {
             RGBColor[
             0.19284697546686017`, 0.3200247767930899, 0.9342937220100794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 368}], {
             RGBColor[
             0.18388810829963448`, 0.3106084393753497, 0.9337835277783622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 441}], {
             RGBColor[
             0.20500595942209238`, 0.33280463985414815`, 0.9349861581587251]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 492}], {
             RGBColor[
             0.1855765306994534, 0.3123830783697226, 0.9338796809362347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 361}], {
             RGBColor[
             0.2274919045840746, 0.3564387939106588, 0.9362666994707252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 386}], {
             RGBColor[
             0.2652427547751048, 0.39611733100357804`, 0.9384165545417262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 398}], {
             RGBColor[
             0.21557110150214517`, 0.3439092740489813, 0.935587827370457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 441}], {
             RGBColor[
             0.22317531852257919`, 0.3519017882726634, 0.9360208762803397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 408}], {
             RGBColor[
             0.923405109023163, 0.9417213092494618, 0.9911392082523272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 440}], {
             RGBColor[
             0.9005793035034079, 0.7657528918366445, 0.6112602253720522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 463}], {
             RGBColor[
             0.7323426131107887, 0.7902188270608363, 0.9746779559842911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 483}], {
             RGBColor[
             0.6807834462506754, 0.7483260934744262, 0.970628611472146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 457}], {
             RGBColor[
             0.5327073882194472, 0.6315148818077295, 0.9563558234535461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 494}], {
             RGBColor[
             0.4757330556093662, 0.5825992022016417, 0.9526059341461844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 386}], {
             RGBColor[
             0.26785160184799417`, 0.39885939468764287`, 0.9385651245230838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 398}], {
             RGBColor[
             0.21817994857503456`, 0.3466513377330461, 0.9357363973518147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 441}], {
             RGBColor[
             0.22578416559546857`, 0.3546438519567282, 0.9361694462616974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 481}], {
             RGBColor[
             0.217684758794606, 0.34613086187697023`, 0.935708197026387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 369}], {
             RGBColor[
             0.1806318866536843, 0.30718594396907933`, 0.9335980907727736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 470}], {
             RGBColor[
             0.1869253840691414, 0.31380080878350786`, 0.9339564961401887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 381}], {
             RGBColor[
             0.18545627477246146`, 0.3122566817657879, 0.9338728325390953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 378}], {
             RGBColor[
             0.20567802361676119`, 0.3335110219340761, 0.9350244312203816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 380}], {
             RGBColor[
             0.19593044529067147`, 0.3232656990811941, 0.9344693210549606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 381}], {
             RGBColor[
             0.19634549402636683`, 0.3237019416180197, 0.9344929574664489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 416}], {
             RGBColor[
             0.20681043357905127`, 0.33470125660338146`, 0.9350889202924836]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 452}], {
             RGBColor[
             0.21560011293675418`, 0.34393976690618655`, 0.9355894795287394]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 468}], {
             RGBColor[
             0.21294670143418915`, 0.3411508631809846, 0.9354383716690389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 487}], {
             RGBColor[
             0.19856599617315254`, 0.3260358301622591, 0.9346194117787698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 405}], {
             RGBColor[
             0.18210802697612394`, 0.3087374610406655, 0.9336821547803826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 423}], {
             RGBColor[
             0.18087837131958237`, 0.30744501498096866`, 0.933612127709855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 429}], {
             RGBColor[
             0.18725297443025463`, 0.3141451270234664, 0.9339751519266276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 465}], {
             RGBColor[
             0.18080307297570358`, 0.30736587164736134`, 0.9336078395805651]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 469}], {
             RGBColor[
             0.1819546848445577, 0.30857628873793674`, 0.9336734221728392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 488}], {
             RGBColor[
             0.1825427715517224, 0.30919440515401764`, 0.933706912840816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 368}], {
             RGBColor[
             0.1881907444562831, 0.3151307827788761, 0.9340285565423035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 375}], {
             RGBColor[
             0.19994616901354612`, 0.3274864793255251, 0.9346980105802476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 441}], {
             RGBColor[
             0.20930859557874099`, 0.3373269832576745, 0.9352311869226664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 450}], {
             RGBColor[
             0.20633807556762712`, 0.3342047783841471, 0.9350620202025242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 492}], {
             RGBColor[
             0.18092029968887635`, 0.3074890843555088, 0.9336145154684589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 456}], {
             RGBColor[
             0.1888191818250698, 0.31579131029870144`, 0.9340643451207662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 390}], {
             RGBColor[
             0.24233683264276484`, 0.3720417545231436, 0.9371120961625645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 422}], {
             RGBColor[
             0.21765000410983476`, 0.3460943324997014, 0.9357062177985042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 443}], {
             RGBColor[
             0.2582982777745515, 0.38881824537072385`, 0.9380210768499777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 451}], {
             RGBColor[
             0.21692330433294027`, 0.34533052495875827`, 0.935664833321266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 442}], {
             RGBColor[
             0.24599324612330464`, 0.37588487692119543`, 0.9373203235011023]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 460}], {
             RGBColor[
             0.2773778998424177, 0.4088721378819603, 0.9391076331009713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 400}], {
             RGBColor[
             0.8020697769239993, 0.8439051876717503, 0.8901739454806034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 404}], {
             RGBColor[
             0.7255490713882455, 0.7852295819730946, 0.9735376602371271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 418}], {
             RGBColor[
             0.5453882435546948, 0.6418097714349063, 0.9573541068370404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 431}], {
             RGBColor[
             0.5177615934513908, 0.6185105449794727, 0.9554198037200161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 444}], {
             RGBColor[
             0.5900676498939734, 0.6780825262854508, 0.9608714333701266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 486}], {
             RGBColor[
             0.5138028974550533, 0.6150817214772912, 0.955167559111667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 449}], {
             RGBColor[
             0.9873031183402635, 0.9734548154410307, 0.5948195031122866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 498}], {
             RGBColor[
             0.8827929559209364, 0.907189051483757, 0.8884954173694475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 397}], {
             RGBColor[
             0.8347270315445021, 0.26793275869910615`, 0.18088795066657473`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 445}], {
             RGBColor[
             0.9052815581912046, 0.6264682491308763, 0.2521450108712031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 402}], {
             RGBColor[
             0.21043597475918854`, 0.33851193025629345`, 0.9352953894991849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 417}], {
             RGBColor[
             0.1999369421366619, 0.32747678129290203`, 0.9346974851232589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 441}], {
             RGBColor[
             0.2121051529687783, 0.3402663423865834, 0.9353904467288932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 450}], {
             RGBColor[
             0.20913463295766446`, 0.3371441375130559, 0.9352212800087508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 461}], {
             RGBColor[
             0.22800718101290143`, 0.35698038210776833`, 0.9362960437010637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 391}], {
             RGBColor[
             0.4221118184289103, 0.5394962463103177, 0.9482660902046844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 448}], {
             RGBColor[
             0.33584647853732147`, 0.4645604445371366, 0.9426484491510583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 455}], {
             RGBColor[
             0.4920767571056538, 0.5962969354126668, 0.9537739864673327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 475}], {
             RGBColor[
             0.3538187512223421, 0.4808817516864462, 0.9437659958516187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 482}], {
             RGBColor[
             0.35174044974950636`, 0.47908163140914517`, 0.9436335683195394]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 412}], {
             RGBColor[
             0.18552364470094684`, 0.3123274918321262, 0.9338766691568576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 426}], {
             RGBColor[
             0.1840742886923742, 0.31080412677263786`, 0.9337941304762996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 476}], {
             RGBColor[
             0.18211083187288252`, 0.3087404091649995, 0.9336823145151034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 380}], {
             RGBColor[
             0.19721656952288963`, 0.32461749719424154`, 0.9345425639273353]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 416}], {
             RGBColor[
             0.2080965578112694, 0.3360530547164289, 0.9351621631648581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 452}], {
             RGBColor[
             0.21688623716897232`, 0.34529156501923397`, 0.935662722401114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 487}], {
             RGBColor[
             0.1998521204053707, 0.32738762827530654`, 0.9346926546511444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 400}], {
             RGBColor[
             0.9086464403656656, 0.6009403996477325, 0.49573306309233295`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 404}], {
             RGBColor[
             0.8321257348299118, 0.5422647939490768, 0.5790967778488565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 440}], {
             RGBColor[
             0.8595285144156211, 0.406306411086346, 0.20259145280411195`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 487}], {
             RGBColor[
             0.19010454207928099`, 0.31714230542242455`, 0.9341375444857234]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 416}], {
             RGBColor[
             0.19876402822087508`, 0.3262439744003725, 0.9346306894109254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 468}], {
             RGBColor[
             0.20490029607601296`, 0.33269358097797563`, 0.9349801407874807]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 425}], {
             RGBColor[
             0.19937423959475875`, 0.32688534524395996`, 0.9346654400459413]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 462}], {
             RGBColor[
             0.20106839690715364`, 0.3286660119950647, 0.934761919798601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 393}], {
             RGBColor[
             0.24454516184141023`, 0.374362848527078, 0.9372378572434972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 395}], {
             RGBColor[
             0.3859577461997916, 0.503550871102866, 0.9463338532888385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 443}], {
             RGBColor[
             0.2778055713012203, 0.40932164770109847`, 0.9391319883578669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 480}], {
             RGBColor[
             0.2555678088390552, 0.3859483493977877, 0.937865580683468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 402}], {
             RGBColor[
             0.24310211003433443`, 0.3728461095830723, 0.937155677577888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 411}], {
             RGBColor[
             0.2746421437909936, 0.40599668481496154`, 0.9389518358410311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 458}], {
             RGBColor[
             0.25354859204463764`, 0.3838260245211157, 0.9377505892741895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 461}], {
             RGBColor[
             0.26067331628804735`, 0.3913145614345472, 0.9381563317797668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 499}], {
             RGBColor[
             0.4483239267217146, 0.554218492373762, 0.9512402754132152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 415}], {
             RGBColor[
             0.18097729894859016`, 0.30754899419142984`, 0.9336177614919767]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 446}], {
             RGBColor[
             0.18248129368631721`, 0.30912978801955504`, 0.9337034117673295]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 441}], {
             RGBColor[
             0.26353501578649874`, 0.39432238904964745`, 0.9383193013326985]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 498}], {
             RGBColor[
             0.540094387984412, 0.6311849610997022, 0.9594410817544053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 439}], {
             RGBColor[
             0.1940605439508961, 0.3213003142144977, 0.9343628329399316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 436}], {
             RGBColor[
             0.34210441687378856`, 0.470735384053293, 0.943019568825508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 473}], {
             RGBColor[
             0.2961409162225916, 0.4267494884669002, 0.9402436685514961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 456}], {
             RGBColor[
             0.1952664503716337, 0.322567798321576, 0.9344315075266139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 472}], {
             RGBColor[
             0.18902863113306126`, 0.3160114548012536, 0.9340762729490037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 422}], {
             RGBColor[
             0.23122695863113757`, 0.36036457253022636`, 0.9364794052731881]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 443}], {
             RGBColor[
             0.2718752322958543, 0.4030884854012488, 0.9387942643246616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 451}], {
             RGBColor[
             0.23050025885424308`, 0.3596007649892832, 0.93643802079595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 407}], {
             RGBColor[
             0.3751221590981358, 0.49587301171236503`, 0.9453789816308452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 448}], {
             RGBColor[
             0.38684939186323586`, 0.5081990768979878, 0.9460468301879315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 455}], {
             RGBColor[
             0.5430796704315681, 0.6399355677735181, 0.9571723675042059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 475}], {
             RGBColor[
             0.40482166454825647`, 0.5245203840472975, 0.9471643768884919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 478}], {
             RGBColor[
             0.36121422406998477`, 0.4812548901837663, 0.9445869453059381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 482}], {
             RGBColor[
             0.4027433630754207, 0.5227202637699965, 0.9470319493564127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 413}], {
             RGBColor[
             0.23358028524334118`, 0.3628380680091775, 0.9366134237423184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 473}], {
             RGBColor[
             0.2502222365996353, 0.3803298140453018, 0.9375611582524985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 474}], {
             RGBColor[
             0.23318205607902553`, 0.3624195039082944, 0.9365907451805379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 490}], {
             RGBColor[
             0.2264092533563037, 0.355300858826219, 0.9362050440849425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 424}], {
             RGBColor[
             0.20739385044843295`, 0.3353144647238677, 0.935122145020107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 480}], {
             RGBColor[
             0.23233850550566576`, 0.36153287877149787`, 0.9365427062233063]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 467}], {
             RGBColor[
             0.18730056337306505`, 0.3141951460196734, 0.9339778620465191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 443}], {
             RGBColor[
             0.39598885232621217`, 0.5140941996505966, 0.9469051099430464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 430}], {
             RGBColor[
             0.19949732248348956`, 0.32701471316392194`, 0.9346724494343697]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 477}], {
             RGBColor[
             0.19761610506605493`, 0.32503743438212485`, 0.9345653168854586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 495}], {
             RGBColor[
             0.8540509182502993, 0.3729173999622112, 0.19768732648561016`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 399}], {
             RGBColor[
             0.2070690587330349, 0.3349730880380002, 0.9351036486124014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 464}], {
             RGBColor[
             0.20435657897174597`, 0.33212209982773555`, 0.9349491769027501]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 481}], {
             RGBColor[
             0.20576395571267658`, 0.3336013420152928, 0.9350293249261188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 496}], {
             RGBColor[
             0.19603720028339988`, 0.32337790534720917`, 0.9344754005938667]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 407}], {
             RGBColor[
             0.2425042792072058, 0.3722177514790964, 0.9371216319966944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 464}], {
             RGBColor[
             0.20516649221167577`, 0.332973369994367, 0.9349953002636049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 478}], {
             RGBColor[
             0.22859634417905478`, 0.3575996299504977, 0.9363295956717873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 481}], {
             RGBColor[
             0.20657386895260635`, 0.3344526121819243, 0.9350754482869736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 496}], {
             RGBColor[
             0.19684711352332962`, 0.3242291755138407, 0.9345215239547214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 404}], {
             RGBColor[
             0.9133476519960143, 0.9314027140164651, 0.9009347805127319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 418}], {
             RGBColor[
             0.7331868241624636, 0.7879829034782768, 0.8847512271126452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 431}], {
             RGBColor[
             0.7055601740591597, 0.7646836770228431, 0.882816923995621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 444}], {
             RGBColor[
             0.7778662305017423, 0.8242556583288213, 0.8882685536457314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 428}], {
             RGBColor[
             0.18425068425914937`, 0.3109895296974434, 0.9338041759428735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 437}], {
             RGBColor[
             0.18132345879022535`, 0.30791283013279, 0.9336374747828603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 451}], {
             RGBColor[
             0.192907026989333, 0.3200878947506953, 0.934297141855446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 417}], {
             RGBColor[
             0.20763019049226705`, 0.33556287309476157`, 0.9351356042359695]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 458}], {
             RGBColor[
             0.2285757051250969, 0.3575779369961964, 0.9363284203081972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 461}], {
             RGBColor[
             0.23570042936850655`, 0.3650664739096279, 0.9367341628137743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 440}], {
             RGBColor[
             0.8175206971599966, 0.7001431418216288, 0.6031737768596591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 445}], {
             RGBColor[
             0.8532638533992596, 0.8433645979013125, 0.6431418553174187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 471}], {
             RGBColor[
             0.8501227775795742, 0.8834026890475528, 0.9665040763953929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 483}], {
             RGBColor[
             0.5977248399072642, 0.6827163434594106, 0.9625421629597528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 497}], {
             RGBColor[
             0.6107955480026974, 0.6933624123353453, 0.9635615550100725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 418}], {
             RGBColor[
             0.6566661186267099, 0.7293072977796211, 0.9681149418691689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 431}], {
             RGBColor[
             0.629039468523406, 0.7060080713241875, 0.9661806387521447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 444}], {
             RGBColor[
             0.7013455249659886, 0.7655800526301657, 0.9716322684022551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 486}], {
             RGBColor[
             0.6250807725270684, 0.7025792478220061, 0.9659283941437955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 423}], {
             RGBColor[
             0.18042956728835297`, 0.30697329348832747`, 0.9335865689842227]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 429}], {
             RGBColor[
             0.1868041703990252, 0.3136734055308251, 0.9339495932009951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 472}], {
             RGBColor[
             0.1823975349558204, 0.3090417522831926, 0.9336986418315376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 488}], {
             RGBColor[
             0.182093967520493, 0.30872268366137645`, 0.9336813541151835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 419}], {
             RGBColor[
             0.5328942370686292, 0.630560819878426, 0.9567192886891854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 493}], {
             RGBColor[
             0.33870341661598447`, 0.4633663515821581, 0.9429648172026237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 448}], {
             RGBColor[
             0.28885681920654693`, 0.42093720993918393`, 0.9397613405772192]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 455}], {
             RGBColor[
             0.44508709777487926`, 0.5526737008147141, 0.9508868778934936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 475}], {
             RGBColor[
             0.3068290918915676, 0.4372585170884935, 0.9408788872777796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 478}], {
             RGBColor[
             0.2632216514132959, 0.39399302322496244`, 0.9383014556952256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 482}], {
             RGBColor[
             0.3047507904187318, 0.43545839681119247`, 0.9407464597457003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{408, 463}], {
             RGBColor[
             0.746221620758815, 0.8012446952293572, 0.9745845586722801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 430}], {
             RGBColor[
             0.22739490707234228`, 0.3563368433758307, 0.9362611756059269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 422}], {
             RGBColor[
             0.19439415698617535`, 0.3216509626668643, 0.9343818317087544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 428}], {
             RGBColor[
             0.18501111447909718`, 0.3117887900726693, 0.9338474813189439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 437}], {
             RGBColor[
             0.1820838890101732, 0.30871209050801585`, 0.9336807801589306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{412, 426}], {
             RGBColor[
             0.18880630124033773`, 0.3157777719874718, 0.9340636115905208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{412, 476}], {
             RGBColor[
             0.18684284442084606`, 0.31371405437983346`, 0.9339517956293248]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 474}], {
             RGBColor[
             0.2299117533537109, 0.35898220839482003`, 0.9364045062783105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 490}], {
             RGBColor[
             0.2231389506309891, 0.3518635633127446, 0.9360188051827152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 461}], {
             RGBColor[
             0.337969115719834, 0.4620246100212727, 0.9429438683225567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 498}], {
             RGBColor[
             0.5986264598736242, 0.6821731423501425, 0.9631600517720931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 499}], {
             RGBColor[
             0.5256197261535013, 0.6249285409604874, 0.9560278119560052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 452}], {
             RGBColor[
             0.2180186471312624, 0.3464817996885393, 0.935727211473216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 468}], {
             RGBColor[
             0.21536523562869736`, 0.3436928959633374, 0.9355761036135155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{417, 458}], {
             RGBColor[
             0.21807667250257026`, 0.34654278803280497`, 0.9357305159322711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 431}], {
             RGBColor[
             0.4488786406898552, 0.5625882607859993, 0.9499970853520581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 444}], {
             RGBColor[
             0.5211846971324379, 0.6221602420919774, 0.9554487150021684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 486}], {
             RGBColor[
             0.4449199446935177, 0.5591594372838178, 0.9497448407437088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 427}], {
             RGBColor[
             0.1872793778515779, 0.31417287869335075`, 0.9339766555624116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 454}], {
             RGBColor[
             0.19971846915340663`, 0.3272471523355135, 0.9346850434100643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 489}], {
             RGBColor[
             0.189832836442401, 0.3168567255709313, 0.9341220712516556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 500}], {
             RGBColor[
             0.19451665335716928`, 0.32177971411949735`, 0.9343888076958655]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 430}], {
             RGBColor[
             0.19294646407159283`, 0.3201293456246058, 0.9342993877389387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 459}], {
             RGBColor[
             0.18940834947071425`, 0.31641056284966007`, 0.9340978973465902]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 477}], {
             RGBColor[
             0.1910652466541582, 0.31815206684280867`, 0.9341922551900277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 428}], {
             RGBColor[
             0.19715708759112932`, 0.32455497791258914`, 0.9345391765193171]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 437}], {
             RGBColor[
             0.1942298621222053, 0.32147827834793574`, 0.9343724753593039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 451}], {
             RGBColor[
             0.20581343032131297`, 0.33365334296584104`, 0.9350321424318895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 429}], {
             RGBColor[
             0.18557451474248365`, 0.3123809594711283, 0.9338795661304677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 465}], {
             RGBColor[
             0.1791246132879326, 0.3056017040950233, 0.9335122537844052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 469}], {
             RGBColor[
             0.18027622515678673`, 0.30681212118559864`, 0.9335778363766793]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 488}], {
             RGBColor[
             0.18086431186395144`, 0.3074302376016796, 0.933611327044656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{425, 462}], {
             RGBColor[
             0.1883728625948838, 0.3153222004895023, 0.9340389279008772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 476}], {
             RGBColor[
             0.1853934884122734, 0.3121906893203451, 0.9338692569487667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 433}], {
             RGBColor[
             0.18359379097292866`, 0.3102990932041856, 0.9337667668420098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 500}], {
             RGBColor[
             0.19375142518042626`, 0.32097541078747177`, 0.9343452290832536]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 437}], {
             RGBColor[
             0.18484681961512717`, 0.31161610575374077`, 0.9338381249694931]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 451}], {
             RGBColor[
             0.19643038781423483`, 0.323791170371646, 0.934497792042079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{429, 488}], {
             RGBColor[
             0.1872389149746237, 0.3141303496441773, 0.9339743512614285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{430, 459}], {
             RGBColor[
             0.19801808656198788`, 0.32545994242144927`, 0.9345882091369736]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{430, 477}], {
             RGBColor[
             0.19967498374543186`, 0.3272014464145979, 0.9346825669804111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 444}], {
             RGBColor[
             0.4935580470291339, 0.5988610156365437, 0.9535144118851442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 486}], {
             RGBColor[
             0.4172932945902137, 0.5358602108283841, 0.9478105376266845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{432, 460}], {
             RGBColor[
             0.2959533208946317, 0.4283960831575556, 0.9401654758500221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 465}], {
             RGBColor[
             0.17986137360753812`, 0.306376085904231, 0.9335542111946675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 469}], {
             RGBColor[
             0.18101298547639227`, 0.3075865029948064, 0.9336197937869416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 495}], {
             RGBColor[
             0.9105859845179732, 0.6779864914594717, 0.24664336835265455`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{435, 439}], {
             RGBColor[
             0.21881441649795172`, 0.3473182037476218, 0.9357725293614136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{435, 453}], {
             RGBColor[
             0.2391644667053946, 0.36870739678334974`, 0.9369314346155262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 473}], {
             RGBColor[
             0.30955738588181175`, 0.4383701601543446, 0.9410985541344632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 439}], {
             RGBColor[
             0.2009360669634459, 0.3285269248340248, 0.9347543838040715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{439, 453}], {
             RGBColor[
             0.21958035723127328`, 0.3481232560217902, 0.9358161485530685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 445}], {
             RGBColor[
             0.9273756618709421, 0.7440317986720315, 0.27125592363752593`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 471}], {
             RGBColor[
             0.9242345860512566, 0.784069889818272, 0.5946181447155001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 450}], {
             RGBColor[
             0.21849705952285933`, 0.34698464144520536`, 0.9357544563511697]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 461}], {
             RGBColor[
             0.2373696075780963, 0.3668208860399178, 0.9368292200434826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 447}], {
             RGBColor[
             0.23581693788510275`, 0.36518893174763706`, 0.9367407978014356]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 500}], {
             RGBColor[
             0.21944649774055142`, 0.34798256120985954`, 0.9358085254530993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{443, 451}], {
             RGBColor[
             0.24646170398602968`, 0.37637725583686343`, 0.9373470014833631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{444, 486}], {
             RGBColor[
             0.4895993510327964, 0.5954321921343623, 0.953262167276795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{445, 471}], {
             RGBColor[
             0.9599777422905198, 0.9272913458979556, 0.6345862231732597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 454}], {
             RGBColor[
             0.2225609566268063, 0.3512560549674121, 0.9359858892792425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 500}], {
             RGBColor[
             0.21735914083056895`, 0.34578861675139594`, 0.9356896535650436]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 455}], {
             RGBColor[
             0.45681433053997933`, 0.564999766000337, 0.9515547264505798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 475}], {
             RGBColor[
             0.3185563246566676, 0.44958458227411635`, 0.9415467358348658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 478}], {
             RGBColor[
             0.2749488841783959, 0.4063190884105853, 0.938969304252312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 482}], {
             RGBColor[
             0.3164780231838319, 0.4477844619968153, 0.9414143083027866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{449, 499}], {
             RGBColor[
             0.8060897526290038, 0.8328531529864611, 0.6773590298414771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 461}], {
             RGBColor[
             0.23439908756698247`, 0.3636986811663903, 0.9366600533233402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{452, 468}], {
             RGBColor[
             0.22415491498640028`, 0.35293140626614244`, 0.9360766628497713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 489}], {
             RGBColor[
             0.20150669956748674`, 0.32912669588106847`, 0.9347868804866963]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 500}], {
             RGBColor[
             0.206190516482255, 0.33404968442963456`, 0.9350536169309063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{455, 475}], {
             RGBColor[
             0.47478660322499994`, 0.5813210731496465, 0.9526722731511402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{455, 482}], {
             RGBColor[
             0.47270830175216416`, 0.5795209528723455, 0.952539845619061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{457, 494}], {
             RGBColor[
             0.4122768656126409, 0.531082608493518, 0.9476104304219592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{458, 461}], {
             RGBColor[
             0.24614691137880979`, 0.3760463888476713, 0.937329074510076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{459, 477}], {
             RGBColor[
             0.19613686914455325`, 0.32348266363965217`, 0.9344810765880625]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{460, 463}], {
             RGBColor[
             0.42791636353987605`, 0.5415498055841811, 0.9492787976467367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{463, 483}], {
             RGBColor[
             0.5035999579863275, 0.6078494794543214, 0.954073961892099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 481}], {
             RGBColor[
             0.2038613891913174, 0.3316016239716596, 0.9349209765773223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 496}], {
             RGBColor[
             0.1941346337620407, 0.32137818730357604`, 0.9343670522450702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{465, 469}], {
             RGBColor[
             0.18020092681290795`, 0.30673297785199133`, 0.9335735482473893]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 470}], {
             RGBColor[
             0.19475005924981162`, 0.3220250385114528, 0.9344020998161584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 491}], {
             RGBColor[
             0.1882565372451065, 0.3151999351714332, 0.9340323033442953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 483}], {
             RGBColor[
             0.7044387287985243, 0.7666430914560537, 0.9539865308155939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 497}], {
             RGBColor[
             0.7175094368939575, 0.7772891603319885, 0.9550059228659136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{472, 488}], {
             RGBColor[
             0.18283227953141887`, 0.3094986963965447, 0.933723399891971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{474, 490}], {
             RGBColor[
             0.22274072146667342`, 0.35144499921186156`, 0.9359961266209347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{475, 478}], {
             RGBColor[
             0.2929211568634166, 0.42264039555989485`, 0.9400868509528724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{475, 482}], {
             RGBColor[
             0.3344502958688525, 0.46410576914612495`, 0.942531855003347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{478, 482}], {
             RGBColor[
             0.2908428553905808, 0.4208402752825938, 0.939954423420793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{481, 496}], {
             RGBColor[
             0.19554201050297132`, 0.3228574294911333, 0.934447200268439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{484, 490}], {
             RGBColor[
             0.2003898909918431, 0.3279528592583135, 0.9347232798904836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{489, 500}], {
             RGBColor[
             0.19630488377124938`, 0.3236592576650523, 0.9344906447724974]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.028685633809430733`], {
             RGBColor[
             0.19927754620079638`, 0.32678371435619025`, 0.9346599335002002]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.028685633809430733`], {
             RGBColor[
             0.18419449056434983`, 0.3109304665613231, 0.9338009757950858]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.028685633809430733`], {
             RGBColor[
             0.18365861817242612`, 0.31036723070113925`, 0.9337704586551179]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.028685633809430733`], {
             RGBColor[
             0.18151204232925333`, 0.30811104338919537`, 0.9336482143364235]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.028685633809430733`], {
             RGBColor[
             0.6895762664964494, 0.7574214874515429, 0.9696941758539234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.028685633809430733`], {
             RGBColor[
             0.21439443043390383`, 0.3426725181510049, 0.9355208176938495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.028685633809430733`], {
             RGBColor[
             0.47235402937887205`, 0.5825173062131191, 0.951604585963978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.028685633809430733`], {
             RGBColor[
             0.19748659103157024`, 0.32490130692021735`, 0.9345579412527936]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.028685633809430733`], {
             RGBColor[
             0.1937919382554366, 0.32101799259798497`, 0.9343475362429416]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.028685633809430733`], {
             RGBColor[
             0.22678684537035088`, 0.355697731973699, 0.9362265473915452]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.028685633809430733`], {
             RGBColor[
             0.37557365642318313`, 0.49972475713808634`, 0.9451521991739089]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.028685633809430733`], {
             RGBColor[
             0.19403535624859544`, 0.3212738403423871, 0.9343613985375474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.028685633809430733`], {
             RGBColor[
             0.25294530714331137`, 0.3831919338393498, 0.9377162330915391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.028685633809430733`], {
             RGBColor[
             0.2309802119470121, 0.36010522612056717`, 0.9364653534145562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.028685633809430733`], {
             RGBColor[
             0.6524065300643914, 0.7283842068503593, 0.9659894438973117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.028685633809430733`], {
             RGBColor[
             0.27011669665931304`, 0.4012401529496448, 0.9386941183216809]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.028685633809430733`], {
             RGBColor[
             0.3754434746784675, 0.49961200025393837`, 0.9451439041082509]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.028685633809430733`], {
             RGBColor[
             0.2883133698343315, 0.42036601019230513`, 0.9397303919394328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.028685633809430733`], {
             RGBColor[
             0.20321773659331793`, 0.33092510428123034`, 0.934884321514065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.028685633809430733`], {
             RGBColor[
             0.24175756143219096`, 0.3714329037529144, 0.9370791075240773]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.028685633809430733`], {
             RGBColor[
             0.3000028152540131, 0.4326523584820372, 0.9403960885630988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.028685633809430733`], {
             RGBColor[
             0.1817982963009414, 0.30841191446298966`, 0.9336645160766364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.028685633809430733`], {
             RGBColor[
             0.4319501958436354, 0.5485552820168211, 0.9487444624139638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.028685633809430733`], {
             RGBColor[
             0.18529079599648704`, 0.31208275308027844`, 0.9338634087676074]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.028685633809430733`], {
             RGBColor[
             0.2888948585418871, 0.42097719169245956`, 0.9397635068610926]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.028685633809430733`], {
             RGBColor[
             0.1848952269737127, 0.31166698495681794`, 0.9338408816969523]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.028685633809430733`], {
             RGBColor[
             0.18521154867326725`, 0.3119994591190039, 0.933858895749786]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.028685633809430733`], {
             RGBColor[
             0.47584147550400935`, 0.5853485720851631, 0.951879130497885]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.028685633809430733`], {
             RGBColor[
             0.1844293578243088, 0.3111773269429844, 0.9338143511380854]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.028685633809430733`], {
             RGBColor[
             0.17893397678527326`, 0.30540133304367595`, 0.9335013973176001]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.028685633809430733`], {
             RGBColor[
             0.19198099569549876`, 0.3191145771471003, 0.9342444057432027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.028685633809430733`], {
             RGBColor[
             0.21967241372144744`, 0.34822001322968177`, 0.9358213910339986]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.028685633809430733`], {
             RGBColor[
             0.25627137654269866`, 0.3866878436630859, 0.9379056478233554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.028685633809430733`], {
             RGBColor[
             0.2089289231192469, 0.33692792343012196`, 0.9352095651377733]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.028685633809430733`], {
             RGBColor[
             0.187649142725438, 0.3145615250202248, 0.9339977131249598]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.028685633809430733`], {
             RGBColor[
             0.9941315043202534, 0.9918412404700345, 0.7469196908007765]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.028685633809430733`], {
             RGBColor[
             0.861854760386902, 0.4655965562049136, 0.20644056462819607`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.028685633809430733`], {
             RGBColor[
             0.5188198477638203, 0.6202403508392836, 0.9552625453971423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.028685633809430733`], {
             RGBColor[
             0.24759097892264678`, 0.3775641953954144, 0.937411312020391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.028685633809430733`], {
             RGBColor[
             0.18500874865393632`, 0.31178630344042324`, 0.9338473465887008]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.028685633809430733`], {
             RGBColor[
             0.2630876311955555, 0.3938521594787447, 0.9382938234420904]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.028685633809430733`], {
             RGBColor[
             0.2005501569047806, 0.3281213088942566, 0.9347324067971333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.028685633809430733`], {
             RGBColor[
             0.22836865224462058`, 0.35736031129090495`, 0.9363166289529613]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.028685633809430733`], {
             RGBColor[
             0.2790104916899246, 0.4105880954259918, 0.9392006067914836]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.028685633809430733`], {
             RGBColor[
             0.2011773237053474, 0.3287805009663242, 0.9347681230186154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.028685633809430733`], {
             RGBColor[
             0.2037103551444467, 0.3314428776122868, 0.934912375411788]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.028685633809430733`], {
             RGBColor[
             0.28160948378147765`, 0.4133198008998302, 0.9393486155462334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.028685633809430733`], {
             RGBColor[
             0.18988308106937135`, 0.3169095358595705, 0.9341249326088312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.028685633809430733`], {
             RGBColor[
             0.9939249281250245, 0.9894143604804412, 0.5801441012857329]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.028685633809430733`], {
             RGBColor[
             0.8803633253605091, 0.9074418350893442, 0.9884510339541455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.028685633809430733`], {
             RGBColor[
             0.9952524916716045, 0.9922538846693116, 0.7246412005584384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.028685633809430733`], {
             RGBColor[
             0.1799948891424975, 0.30651641919684713`, 0.9335618147068648]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.028685633809430733`], {
             RGBColor[
             0.8326746621018166, 0.2521573478086015, 0.17892259937043942`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.028685633809430733`], {
             RGBColor[
             0.9895254911096693, 0.9899365356383177, 0.8232532496802422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.028685633809430733`], {
             RGBColor[
             0.5735931996355866, 0.6647078254001658, 0.9595745042978867]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.028685633809430733`], {
             RGBColor[
             0.4068474012204774, 0.5268125030173851, 0.9471449345381059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.028685633809430733`], {
             RGBColor[
             0.9626408166905339, 0.9716581627746242, 0.9481235318941049]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.028685633809430733`], {
             RGBColor[
             0.19316750906165184`, 0.32036167792421966`, 0.9343119759241159]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.028685633809430733`], {
             RGBColor[
             0.26299592027232827`, 0.3937557654836245, 0.9382886006406869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.028685633809430733`], {
             RGBColor[
             0.9854928836228277, 0.9882689488092234, 0.890083991790846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.028685633809430733`], {
             RGBColor[
             0.9902590342278114, 0.9902398745688678, 0.8110965418638902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.028685633809430733`], {
             RGBColor[
             0.25119317281524384`, 0.3813503295688181, 0.9376164516336061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.028685633809430733`], {
             RGBColor[
             0.20681114074536727`, 0.3347019998800166, 0.9350889605645591]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.028685633809430733`], {
             RGBColor[
             0.18480592008610275`, 0.3115731177555562, 0.9338357958018207]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.028685633809430733`], {
             RGBColor[
             0.183179266829206, 0.30986340204678436`, 0.9337431603052583]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.028685633809430733`], {
             RGBColor[
             0.19788231111085003`, 0.3253172338136426, 0.9345804769258931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.028685633809430733`], {
             RGBColor[
             0.18087272641393248`, 0.30743908182722296`, 0.9336118062408292]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.028685633809430733`], {
             RGBColor[
             0.18542751526237852`, 0.31222645369723245`, 0.933871194727542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.028685633809430733`], {
             RGBColor[
             0.44285619720498837`, 0.5580015122444584, 0.9494393831769108]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.028685633809430733`], {
             RGBColor[
             0.3697431424982056, 0.49467465902642144`, 0.9447806839823304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.028685633809430733`], {
             RGBColor[
             0.19773867236084267`, 0.32516626038016205`, 0.9345722969115747]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.028685633809430733`], {
             RGBColor[
             0.21111609134757603`, 0.339226775912571, 0.9353341211327513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.028685633809430733`], {
             RGBColor[
             0.5768983856608343, 0.6673911243123956, 0.9598347006490895]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.028685633809430733`], {
             RGBColor[
             0.18870685733270803`, 0.31567325013544506`, 0.9340579484070953]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.028685633809430733`], {
             RGBColor[
             0.8653183386459826, 0.4813238561401438, 0.20933065922764493`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.028685633809430733`], {
             RGBColor[
             0.4104281337116228, 0.5299139535283672, 0.9473730956461243]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.028685633809430733`], {
             RGBColor[
             0.33446793820227666`, 0.46412105004860754`, 0.9425329791572322]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.028685633809430733`], {
             RGBColor[
             0.4700607186843903, 0.5806554932788695, 0.9514240481454346]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.028685633809430733`], {
             RGBColor[
             0.8862469572430673, 0.9121332834455631, 0.9890122200154841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.028685633809430733`], {
             RGBColor[
             0.3474160266946404, 0.4753360335108428, 0.9433580199064205]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.028685633809430733`], {
             RGBColor[
             0.23835692087692842`, 0.36785861491626903`, 0.9368854460752519]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.028685633809430733`], {
             RGBColor[
             0.5201221497039563, 0.62129761822232, 0.955365067376359]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.028685633809430733`], {
             RGBColor[
             0.9952268649647723, 0.9922942002460275, 0.7287667302186207]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.028685633809430733`], {
             RGBColor[
             0.27551545928723997`, 0.406914594772917, 0.9390015698665879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.028685633809430733`], {
             RGBColor[
             0.18726966457396857`, 0.31416266942272597`, 0.9339761024056213]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.028685633809430733`], {
             RGBColor[
             0.18531184315250615`, 0.31210487497572126`, 0.9338646073720063]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.028685633809430733`], {
             RGBColor[
             0.30841227476556676`, 0.4414912336192087, 0.9408749948416013]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.028685633809430733`], {
             RGBColor[
             0.18955897979005848`, 0.3165688848658047, 0.9341064755204392]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.028685633809430733`], {
             RGBColor[
             0.30968149308884285`, 0.4426522770943059, 0.940953608792397]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.028685633809430733`], {
             RGBColor[
             0.2623509631444437, 0.39307787464957405`, 0.9382518712863824]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.028685633809430733`], {
             RGBColor[
             0.46032419676718667`, 0.5727509461611696, 0.9506575534740573]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.028685633809430733`], {
             RGBColor[
             0.27193911320159614`, 0.4031556282834669, 0.9387979022477403]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.028685633809430733`], {
             RGBColor[
             0.2226303791602024, 0.3513290224516542, 0.935989842789818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.028685633809430733`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.028685633809430733`], {
             RGBColor[
             0.1846806812934658, 0.3114414838438967, 0.9338286636378542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.028685633809430733`], {
             RGBColor[
             0.4707743379765772, 0.5812348415684494, 0.9514802268701891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.028685633809430733`], {
             RGBColor[
             0.9884567952610653, 0.9727242013215213, 0.40965725865088887`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.028685633809430733`], {
             RGBColor[
             0.18830185869099547`, 0.3152475708846082, 0.9340348843335916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.028685633809430733`], {
             RGBColor[
             0.9796979203258498, 0.9843793227373989, 0.9192503046446351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.028685633809430733`], {
             RGBColor[
             0.9932268871291124, 0.987921321372956, 0.5041666466903745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.028685633809430733`], {
             RGBColor[
             0.24511118458418202`, 0.3749577743176459, 0.9372700914013423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.028685633809430733`], {
             RGBColor[
             0.19944242864104303`, 0.32695701625504003`, 0.9346693233112505]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.028685633809430733`], {
             RGBColor[
             0.40980409560216274`, 0.5293734430830204, 0.9473333324896046]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.028685633809430733`], {
             RGBColor[
             0.9241317229671294, 0.73691459370894, 0.25781280732325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.028685633809430733`], {
             RGBColor[
             0.1914252698739526, 0.31853047407360313`, 0.9342127579797883]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.028685633809430733`], {
             RGBColor[
             0.17964740484760663`, 0.30615119117114004`, 0.9335420259903278]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.028685633809430733`], {
             RGBColor[
             0.21128649273995928`, 0.33940587858003807`, 0.9353438252399612]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.028685633809430733`], {
             RGBColor[
             0.20961363351384976`, 0.337647597467996, 0.9352485583818076]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.028685633809430733`], {
             RGBColor[
             0.2136359512540558, 0.3418753084426271, 0.9354776234266265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.028685633809430733`], {
             RGBColor[
             0.4170759329154467, 0.5356719430706164, 0.9477966875329739]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.028685633809430733`], {
             RGBColor[
             0.3665915053486955, 0.49194486933340476`, 0.9445798644500469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.028685633809430733`], {
             RGBColor[
             0.9934414779456845, 0.9915558968312813, 0.7583552135583986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.028685633809430733`], {
             RGBColor[
             0.19671677940387242`, 0.3240921860906307, 0.9345141016194304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.028685633809430733`], {
             RGBColor[
             0.18143431560131953`, 0.3080293476699778, 0.9336437879142542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.028685633809430733`], {
             RGBColor[
             0.19098661972276523`, 0.31806942495267926`, 0.934187777502603]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.028685633809430733`], {
             RGBColor[
             0.27647894211230134`, 0.40792727631039594`, 0.9390564387881299]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.028685633809430733`], {
             RGBColor[
             0.18356396795554494`, 0.3102677473220268, 0.933765068465289]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.028685633809430733`], {
             RGBColor[
             0.19221104916857337`, 0.3193563779335344, 0.9342575069481607]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.028685633809430733`], {
             RGBColor[
             0.18431898451928125`, 0.31106131760132866`, 0.9338080655416469]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.028685633809430733`], {
             RGBColor[
             0.1799037129149489, 0.30642058720078685`, 0.9335566223555891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.028685633809430733`], {
             RGBColor[
             0.20513244387794988`, 0.3329375830368321, 0.9349933612613692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.028685633809430733`], {
             RGBColor[
             0.18567855904381614`, 0.3124903166286185, 0.9338854912995088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.028685633809430733`], {
             RGBColor[
             0.18584647349383113`, 0.3126668053619753, 0.93389505377903]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.028685633809430733`], {
             RGBColor[
             0.18536877790044387`, 0.31216471700567533`, 0.9338678497216739]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.028685633809430733`], {
             RGBColor[
             0.7779497574122243, 0.8264595302183536, 0.978502419531181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.028685633809430733`], {
             RGBColor[
             0.4884562669939937, 0.5955898281066129, 0.9528722130934804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.028685633809430733`], {
             RGBColor[
             0.8321508631713839, 0.8689985264321587, 0.9838524862707736]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.028685633809430733`], {
             RGBColor[
             0.19425607642724724`, 0.32150583124461773`, 0.9343739682251954]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.028685633809430733`], {
             RGBColor[
             0.2893758023858067, 0.42148269416601997`, 0.9397908959015111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.028685633809430733`], {
             RGBColor[
             0.30291909395791666`, 0.43571755230258913`, 0.9405621663210384]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.028685633809430733`], {
             RGBColor[
             0.8337292727736055, 0.2602635475653142, 0.17993249574075687`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.028685633809430733`], {
             RGBColor[
             0.2723145403641676, 0.4035502260347864, 0.938819282269254]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.028685633809430733`], {
             RGBColor[
             0.19798057442534764`, 0.32542051478743356`, 0.9345860728762861]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.028685633809430733`], {
             RGBColor[
             0.18413129784782198`, 0.3108640470096027, 0.9337973770633647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.028685633809430733`], {
             RGBColor[
             0.17999586170885287`, 0.3065174414257509, 0.93356187009308]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.028685633809430733`], {
             RGBColor[
             0.5282221961294052, 0.6278736008134325, 0.956002732702418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.028685633809430733`], {
             RGBColor[
             0.2116557852103354, 0.33979402838089834`, 0.9353648558998299]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.028685633809430733`], {
             RGBColor[
             0.1827700546655207, 0.3094332941172014, 0.9337198562779115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.028685633809430733`], {
             RGBColor[
             0.18259939511325524`, 0.3092539201073298, 0.9337101374688782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.028685633809430733`], {
             RGBColor[
             0.17901437519538227`, 0.3054858368702541, 0.933505975888117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.028685633809430733`], {
             RGBColor[
             0.2073090188644706, 0.33522530135049017`, 0.9351173139868973]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.028685633809430733`], {
             RGBColor[
             0.21571267720568413`, 0.3440580790898188, 0.9355958898973311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.028685633809430733`], {
             RGBColor[
             0.5806518106608889, 0.6704383238173092, 0.9601301840143426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.028685633809430733`], {
             RGBColor[
             0.1968786888055324, 0.3242623631374243, 0.9345233221203314]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.028685633809430733`], {
             RGBColor[
             0.20904447312210606`, 0.33704937380942024`, 0.9352161455394953]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.028685633809430733`], {
             RGBColor[
             0.1800731039927536, 0.30659862796357423`, 0.9335662689268784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.028685633809430733`], {
             RGBColor[
             0.8190803262063154, 0.147665325039805, 0.16590464796430104`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.028685633809430733`], {
             RGBColor[
             0.27463540520047075`, 0.4059896021290707, 0.9389514520882697]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.028685633809430733`], {
             RGBColor[
             0.5611296111138018, 0.6545893227599167, 0.9585933249538227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.028685633809430733`], {
             RGBColor[
             0.2153604952721365, 0.34368791354803596`, 0.9355758336572221]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.028685633809430733`], {
             RGBColor[
             0.20371318105767475`, 0.33144584782626274`, 0.9349125363433657]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.028685633809430733`], {
             RGBColor[
             0.18423542654322242`, 0.31097349287060916`, 0.9338033070385232]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.028685633809430733`], {
             RGBColor[
             0.22763715789209957`, 0.35659146434698463`, 0.9362749714317341]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.028685633809430733`], {
             RGBColor[
             0.9834670894693087, 0.9871903629131425, 0.9128700844415136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.028685633809430733`], {
             RGBColor[
             0.19392286855916088`, 0.32115560864865994`, 0.9343549925300447]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.028685633809430733`], {
             RGBColor[
             0.19939483773806957`, 0.32690699519857735`, 0.9346666130797306]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.028685633809430733`], {
             RGBColor[
             0.29909565256278264`, 0.4316988729761172, 0.9403444269898601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.028685633809430733`], {
             RGBColor[
             0.19170728594478786`, 0.3188268908449026, 0.9342288183778169]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.028685633809430733`], {
             RGBColor[
             0.2321162208184409, 0.36129924347156134`, 0.9365300474392095]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.028685633809430733`], {
             RGBColor[
             0.23944883454874902`, 0.3690062854166779, 0.9369476289435206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.028685633809430733`], {
             RGBColor[
             0.2138505894071634, 0.34210090675038807`, 0.9354898467519174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.028685633809430733`], {
             RGBColor[
             0.18332605976082084`, 0.310017690725121, 0.933751519945553]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.028685633809430733`], {
             RGBColor[
             0.899308535201446, 0.6356654000864056, 0.23769291240948212`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.028685633809430733`], {
             RGBColor[
             0.3160253373259164, 0.44814699612157666`, 0.9413578329375422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.028685633809430733`], {
             RGBColor[
             0.3059265832870255, 0.43887861427331937`, 0.9407334383891494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.028685633809430733`], {
             RGBColor[
             0.19568177386369887`, 0.32300432964476683`, 0.934455159585071]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.028685633809430733`], {
             RGBColor[
             0.23986313789965336`, 0.369441744506828, 0.9369712229064477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.028685633809430733`], {
             RGBColor[
             0.29271248717825876`, 0.424989761440922, 0.9399809151642584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.028685633809430733`], {
             RGBColor[
             0.18381241008660495`, 0.31052887575391175`, 0.9337792168771156]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.028685633809430733`], {
             RGBColor[
             0.1877350381466607, 0.3146518065540141, 0.9340026047421276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.028685633809430733`], {
             RGBColor[
             0.47069483175957283`, 0.581170294839771, 0.9514739678495456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.028685633809430733`], {
             RGBColor[
             0.22349209680564214`, 0.35223474233306573`, 0.9360389163349288]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.028685633809430733`], {
             RGBColor[
             0.720597203195575, 0.7816552789687509, 0.9727860529169569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.028685633809430733`], {
             RGBColor[
             0.18747717117288942`, 0.31438077201487, 0.9339879195994514]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.028685633809430733`], {
             RGBColor[
             0.39767741348965524`, 0.5188699205419315, 0.9465606310285997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.028685633809430733`], {
             RGBColor[
             0.3169334821091241, 0.44893358548810713`, 0.9414156991200873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.028685633809430733`], {
             RGBColor[
             0.18438238961983267`, 0.3111279603821238, 0.9338116763683237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.028685633809430733`], {
             RGBColor[
             0.46930938565191127`, 0.5800455272759355, 0.9513649004568943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.028685633809430733`], {
             RGBColor[
             0.2001120590885424, 0.3276608403123844, 0.9347074577746062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.028685633809430733`], {
             RGBColor[
             0.26314504718325327`, 0.39391250732219896`, 0.9382970931976505]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.028685633809430733`], {
             RGBColor[
             0.22551745991005276`, 0.354363527371239, 0.9361542577674687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.028685633809430733`], {
             RGBColor[
             0.34499714152995936`, 0.4732409167578995, 0.9432038906826632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.028685633809430733`], {
             RGBColor[
             0.19696480621086881`, 0.3243528779905917, 0.934528226379166]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.028685633809430733`], {
             RGBColor[
             0.5408355089237035, 0.6381136563631097, 0.9569956988896724]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.028685633809430733`], {
             RGBColor[
             0.21154093935996757`, 0.33967331811051427`, 0.9353583155985506]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.028685633809430733`], {
             RGBColor[
             0.9933232264913885, 0.9881273815274607, 0.5146525917364964]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.028685633809430733`], {
             RGBColor[
             0.22124625332801934`, 0.34987421844338334`, 0.9359110188713058]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.028685633809430733`], {
             RGBColor[
             0.2239766808649284, 0.35274407090377946`, 0.9360665126802272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.028685633809430733`], {
             RGBColor[
             0.2519720376195532, 0.38216896586102805`, 0.9376608068319842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.028685633809430733`], {
             RGBColor[
             0.21654397156564814`, 0.3449318221692476, 0.9356432308813413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.028685633809430733`], {
             RGBColor[
             0.19059661539563244`, 0.31765950567716017`, 0.9341655673331324]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.028685633809430733`], {
             RGBColor[
             0.3129892535839804, 0.4455172929823175, 0.9411643763662094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.028685633809430733`], {
             RGBColor[
             0.18092386766537458`, 0.30749283452503123`, 0.9336147186594421]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.028685633809430733`], {
             RGBColor[
             0.18610703405965695`, 0.3129406710371523, 0.933909892317789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.028685633809430733`], {
             RGBColor[
             0.18809486651088786`, 0.3150300089792529, 0.934023096435152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.028685633809430733`], {
             RGBColor[
             0.19199615165670597`, 0.3191305070232725, 0.9342452688527721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.028685633809430733`], {
             RGBColor[
             0.23089370286527677`, 0.3600142995906707, 0.93646042685033]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.028685633809430733`], {
             RGBColor[
             0.1824115868132323, 0.30905652167627173`, 0.9336994420640293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.028685633809430733`], {
             RGBColor[
             0.3861343022549474, 0.5088718577640675, 0.9458251141878965]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.028685633809430733`], {
             RGBColor[
             0.26297543885551555`, 0.39373423821595743`, 0.938287434254299]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.028685633809430733`], {
             RGBColor[
             0.25745169920403105`, 0.3879284376169253, 0.9379728654527874]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.028685633809430733`], {
             RGBColor[
             0.18676020758344578`, 0.31362719782424764`, 0.9339470895836851]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.028685633809430733`], {
             RGBColor[
             0.8450710458930704, 0.34744138575819206`, 0.19079339048865696`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.028685633809430733`], {
             RGBColor[
             0.3159031668134525, 0.44804117816414885`, 0.941350048340519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.028685633809430733`], {
             RGBColor[
             0.23748131534596645`, 0.36693829798663086`, 0.936835581635606]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.028685633809430733`], {
             RGBColor[
             0.18041422854673403`, 0.3069571714983536, 0.933585695465579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.028685633809430733`], {
             RGBColor[
             0.8749870106263872, 0.5252270374274478, 0.21739843612893187`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.028685633809430733`], {
             RGBColor[
             0.42661470104868005`, 0.5439339445951966, 0.948404489403622]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.028685633809430733`], {
             RGBColor[
             0.9944761061763768, 0.9919837421934052, 0.7412087462437971]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.028685633809430733`], {
             RGBColor[
             0.19552365175645214`, 0.32283813328452987`, 0.9344461547649839]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.028685633809430733`], {
             RGBColor[
             0.1874830946539544, 0.31438699796903974`, 0.933988256932935]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.028685633809430733`], {
             RGBColor[
             0.1819457440050942, 0.3085668913487786, 0.9336729130052586]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.028685633809430733`], {
             RGBColor[
             0.20221750657572096`, 0.32987379911448994`, 0.9348273598942706]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.028685633809430733`], {
             RGBColor[
             0.1875451608924792, 0.3144522335209561, 0.9339917915134002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.028685633809430733`], {
             RGBColor[
             0.18496268734880916`, 0.3117378900882792, 0.9338447234655154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.028685633809430733`], {
             RGBColor[
             0.19991510326486814`, 0.3274538272539823, 0.934696241431818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.028685633809430733`], {
             RGBColor[
             0.18124242467150065`, 0.3078276581361505, 0.9336328600096782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.028685633809430733`], {
             RGBColor[
             0.28587662659874513`, 0.4178048385532594, 0.9395916230170046]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.028685633809430733`], {
             RGBColor[
             0.6695263659366376, 0.7417583527493299, 0.9676957891430948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.028685633809430733`], {
             RGBColor[
             0.21703333859134122`, 0.34544617794091254`, 0.9356710996095008]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.028685633809430733`], {
             RGBColor[
             0.9622752132426141, 0.884407577445488, 0.3079467564861062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.028685633809430733`], {
             RGBColor[
             0.1971022673351447, 0.32449735834774435`, 0.9345360545868381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.028685633809430733`], {
             RGBColor[
             0.20818468230621298`, 0.33614567914803034`, 0.9351671817244767]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.028685633809430733`], {
             RGBColor[
             0.20593429362604587`, 0.3337803779622914, 0.9350390254182929]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.028685633809430733`], {
             RGBColor[
             0.18396512493287584`, 0.310689388740023, 0.9337879137616893]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.028685633809430733`], {
             RGBColor[
             0.1869796895121246, 0.3138578872472471, 0.933959588754829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.028685633809430733`], {
             RGBColor[
             0.19315889756887425`, 0.3203526266993102, 0.9343114855123418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.028685633809430733`], {
             RGBColor[
             0.2582166797056685, 0.38873248062671145`, 0.9380164299606684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.028685633809430733`], {
             RGBColor[
             0.2348407472607494, 0.36416289350738135`, 0.9366852051895233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.028685633809430733`], {
             RGBColor[
             0.2058983382969339, 0.3337425866316952, 0.9350369778154911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.028685633809430733`], {
             RGBColor[
             0.7636579459089816, 0.81529465845023, 0.9770779453251097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.028685633809430733`], {
             RGBColor[
             0.2784596091749779, 0.41000908297481403`, 0.939169234847215]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.028685633809430733`], {
             RGBColor[
             0.9625574020842641, 0.9715959522978471, 0.948264731064506]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.028685633809430733`], {
             RGBColor[
             0.9263783006421346, 0.7458215255627042, 0.25962045645451476`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.028685633809430733`], {
             RGBColor[
             0.2171179053764417, 0.345535062993897, 0.9356759155628069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.028685633809430733`], {
             RGBColor[
             0.20835940299106456`, 0.3363293216657406, 0.9351771318090029]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.028685633809430733`], {
             RGBColor[
             0.2328901660883635, 0.3621127090212143, 0.9365741224773821]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.028685633809430733`], {
             RGBColor[
             0.48668906339049306`, 0.5941551326096759, 0.9527330923523326]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.028685633809430733`], {
             RGBColor[
             0.1966443508485099, 0.324016059086709, 0.9345099769203509]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.028685633809430733`], {
             RGBColor[
             0.9948059876224538, 0.9912988576566625, 0.6760419903119628]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.028685633809430733`], {
             RGBColor[
             0.21562994450375172`, 0.3439711217745316, 0.9355911783923481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.028685633809430733`], {
             RGBColor[
             0.9731128985329042, 0.9794682242662037, 0.9303970288913456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.028685633809430733`], {
             RGBColor[
             0.19657931914436805`, 0.32394770664240774`, 0.9345062734610058]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.028685633809430733`], {
             RGBColor[
             0.44672166802497704`, 0.5613495887845201, 0.9496856875594589]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.028685633809430733`], {
             RGBColor[
             0.2439252154854269, 0.3737112456000703, 0.9372025522156523]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.028685633809430733`], {
             RGBColor[
             0.2398990282396083, 0.3694794675296996, 0.9369732668082131]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.028685633809430733`], {
             RGBColor[
             0.18427930277709584`, 0.31101960957432406`, 0.9338058057251333]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.028685633809430733`], {
             RGBColor[
             0.18027294835259305`, 0.30680867705662973`, 0.933577649767528]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.028685633809430733`], {
             RGBColor[
             0.7269497450043649, 0.7866179329108834, 0.9734192149165786]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.028685633809430733`], {
             RGBColor[
             0.2196415898680099, 0.3481876154053738, 0.9358196356611451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.028685633809430733`], {
             RGBColor[
             0.23893002370274252`, 0.3684609823230175, 0.9369180834333524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.028685633809430733`], {
             RGBColor[
             0.18230687199160545`, 0.30894645975943874`, 0.9336934787098494]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.028685633809430733`], {
             RGBColor[
             0.37749249202520396`, 0.5013867560930751, 0.94527446568171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.028685633809430733`], {
             RGBColor[
             0.19242949370172294`, 0.3195859769880579, 0.9342699470411637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.028685633809430733`], {
             RGBColor[
             0.19717041562221144`, 0.32456898651830246`, 0.9345399355309701]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.028685633809430733`], {
             RGBColor[
             0.3115575299166111, 0.44427720590216613`, 0.9410731482001482]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.028685633809430733`], {
             RGBColor[
             0.9630526170636222, 0.8870299430768459, 0.31096682353032956`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.028685633809430733`], {
             RGBColor[
             0.41518076487513966`, 0.5340304437680178, 0.9476759291012767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.028685633809430733`], {
             RGBColor[
             0.6832732263253226, 0.7524975045649791, 0.9690659477149247]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.028685633809430733`], {
             RGBColor[
             0.20975080596055196`, 0.33779177440671543`, 0.935256370149719]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.028685633809430733`], {
             RGBColor[
             0.329292758612209, 0.4596385695997802, 0.9422032212899847]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.028685633809430733`], {
             RGBColor[
             0.34316736625512184`, 0.47165605738201455`, 0.9430872990201573]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.028685633809430733`], {
             RGBColor[
             0.22433819907190317`, 0.35312404946088816`, 0.9360871006072962]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.028685633809430733`], {
             RGBColor[
             0.8655438992520076, 0.482348074171085, 0.20951887252630852`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.028685633809430733`], {
             RGBColor[
             0.18432263905515192`, 0.3110651587502397, 0.9338082736620582]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.028685633809430733`], {
             RGBColor[
             0.9935833726583437, 0.9886838078737659, 0.5429678965735315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.028685633809430733`], {
             RGBColor[
             0.22925694712510034`, 0.35829396553143755`, 0.9363672160322901]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.028685633809430733`], {
             RGBColor[
             0.1863015188096388, 0.3131450868404286, 0.9339209679365861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.028685633809430733`], {
             RGBColor[
             0.6018738506410779, 0.6876673319152327, 0.961800860740477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.028685633809430733`], {
             RGBColor[
             0.18011392367187812`, 0.3066415320344512, 0.9335685935472172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.028685633809430733`], {
             RGBColor[
             0.20809576797568208`, 0.3360522245491482, 0.9351621181848899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.028685633809430733`], {
             RGBColor[
             0.25722683759211185`, 0.3876920938057486, 0.9379600599166416]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.028685633809430733`], {
             RGBColor[
             0.18715875648320013`, 0.3140460979873492, 0.9339697863539259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.028685633809430733`], {
             RGBColor[
             0.24408437678171757`, 0.37387853421388084`, 0.937211616216018]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.028685633809430733`], {
             RGBColor[
             0.48931236896480956`, 0.5962848502534754, 0.9529396085766279]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.028685633809430733`], {
             RGBColor[
             0.21359854810176626`, 0.34183599535807396`, 0.9354754933724367]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.028685633809430733`], {
             RGBColor[
             0.44322657405371796`, 0.5583223140551463, 0.9494629832622005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.028685633809430733`], {
             RGBColor[
             0.18446408847726348`, 0.3112138310612903, 0.9338163289973919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.028685633809430733`], {
             RGBColor[
             0.20798277523591915`, 0.3359334620155039, 0.9351556834155181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.028685633809430733`], {
             RGBColor[
             0.2534737690150518, 0.3837473807729669, 0.9377463282133454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.028685633809430733`], {
             RGBColor[
             0.8184239254643847, 0.14261994130068656`, 0.16527607787252963`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.028685633809430733`], {
             RGBColor[
             0.6967134214587186, 0.7629970871524544, 0.9704055407600571]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.028685633809430733`], {
             RGBColor[
             0.18231742038260904`, 0.3089575467871901, 0.9336940794251122]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.028685633809430733`], {
             RGBColor[
             0.20683017875346388`, 0.3347220100336056, 0.935090044750956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.028685633809430733`], {
             RGBColor[
             0.21438774917055564`, 0.3426654957196094, 0.9355204372057859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.028685633809430733`], {
             RGBColor[
             0.18739586640915007`, 0.3142953155531602, 0.933983289413436]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.028685633809430733`], {
             RGBColor[
             0.304153838987054, 0.4370153476155689, 0.9406324832238061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.028685633809430733`], {
             RGBColor[
             0.7112234006140565, 0.7743323931485304, 0.9718517598787967]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.028685633809430733`], {
             RGBColor[
             0.21007296758615746`, 0.3381303867014537, 0.9352747167777018]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.028685633809430733`], {
             RGBColor[
             0.18152659560596812`, 0.30812633980575366`, 0.9336490431240029]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.028685633809430733`], {
             RGBColor[
             0.18307944483465585`, 0.30975848280143214`, 0.933737475590342]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.028685633809430733`], {
             RGBColor[
             0.18511992750412062`, 0.3119031594611132, 0.9338536780597445]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.028685633809430733`], {
             RGBColor[
             0.8097488880926076, 0.8513012527882134, 0.9816718596976299]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.028685633809430733`], {
             RGBColor[
             0.18749202516745894`, 0.31439638450496027`, 0.9339887655124676]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.028685633809430733`], {
             RGBColor[
             0.9847959098179251, 0.9879807322294865, 0.9016346514484699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.028685633809430733`], {
             RGBColor[
             0.18222924951210637`, 0.30886487361193576`, 0.9336890582244741]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.028685633809430733`], {
             RGBColor[
             0.19526251556143404`, 0.32256366258657476`, 0.934431283444994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.028685633809430733`], {
             RGBColor[
             0.2756885017375273, 0.407096473359694, 0.9390114243781383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.028685633809430733`], {
             RGBColor[
             0.24007340415027964`, 0.3696627476678865, 0.9369831972583599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.028685633809430733`], {
             RGBColor[
             0.23186327956718236`, 0.36103338617908703`, 0.9365156428091433]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.028685633809430733`], {
             RGBColor[
             0.6564481594438648, 0.7315415584391249, 0.9663922757426836]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.028685633809430733`], {
             RGBColor[
             0.24476085053842922`, 0.3745895510230982, 0.9372501403957095]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.028685633809430733`], {
             RGBColor[
             0.8407980254541154, 0.31459707821488886`, 0.1867015412906274]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.028685633809430733`], {
             RGBColor[
             0.190709032669891, 0.3177776633600728, 0.934171969330595]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.028685633809430733`], {
             RGBColor[
             0.3105546519813193, 0.443408563440727, 0.9410092457049215]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.028685633809430733`], {
             RGBColor[
             0.24077004537273583`, 0.3703949617622926, 0.9370228699453904]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.028685633809430733`], {
             RGBColor[
             0.1917730045224159, 0.3188959652367882, 0.934232560953591]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.028685633809430733`], {
             RGBColor[
             0.19090439582770188`, 0.3179830024256716, 0.9341830949734184]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.028685633809430733`], {
             RGBColor[
             0.1881959331144625, 0.3151362363876026, 0.9340288520287109]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.028685633809430733`], {
             RGBColor[
             0.644812645752953, 0.7224518067106054, 0.9652325564780311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.028685633809430733`], {
             RGBColor[
             0.18998459744441062`, 0.31701623600624673`, 0.9341307138162097]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.028685633809430733`], {
             RGBColor[
             0.19496888133162707`, 0.3222550343935622, 0.9344145614099995]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.028685633809430733`], {
             RGBColor[
             0.36122042818933575`, 0.4872927122561548, 0.9442376241629096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.028685633809430733`], {
             RGBColor[
             0.2628079616436893, 0.3935582090476596, 0.9382778966748457]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.028685633809430733`], {
             RGBColor[
             0.18340993044876472`, 0.3101058441358588, 0.9337562962571558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.028685633809430733`], {
             RGBColor[
             0.43871305828747303`, 0.5544129335543235, 0.9491753860287206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.028685633809430733`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.028685633809430733`], {
             RGBColor[
             0.1979808475129809, 0.32542080181985084`, 0.9345860884282229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.028685633809430733`], {
             RGBColor[
             0.18086286172523808`, 0.3074287134139478, 0.9336112444614015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.028685633809430733`], {
             RGBColor[
             0.18113843442729957`, 0.3077183577961329, 0.9336269379191107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.028685633809430733`], {
             RGBColor[
             0.9854351531478911, 0.9882450757742316, 0.8910407351622261]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.028685633809430733`], {
             RGBColor[
             0.820782245844875, 0.16074702516771538`, 0.16753440813222906`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.028685633809430733`], {
             RGBColor[
             0.9927101178720487, 0.9912534606457363, 0.7704757426777427]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.028685633809430733`], {
             RGBColor[
             0.9397327677393429, 0.9545733773753136, 0.9869008833924131]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.028685633809430733`], {
             RGBColor[
             0.23363553097946993`, 0.3628961347806308, 0.9366165699052621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.028685633809430733`], {
             RGBColor[
             0.7253820295989173, 0.7853932217210695, 0.973262959696097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.028685633809430733`], {
             RGBColor[
             0.1837791716078354, 0.31049394000528374`, 0.9337773239949216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.028685633809430733`], {
             RGBColor[
             0.24298649045633505`, 0.3727245860758903, 0.9371490932139648]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.028685633809430733`], {
             RGBColor[
             0.18157893838322037`, 0.30818135538336955`, 0.9336520239677332]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.028685633809430733`], {
             RGBColor[
             0.18958070170652433`, 0.3165917159772593, 0.9341077125514473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.028685633809430733`], {
             RGBColor[
             0.30143473291096856`, 0.4341573947283205, 0.94047763415533]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.028685633809430733`], {
             RGBColor[
             0.18662770310860746`, 0.3134879272199237, 0.9339395436498659]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.028685633809430733`], {
             RGBColor[
             0.23178823080036964`, 0.3609545051668002, 0.9365113688928981]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.028685633809430733`], {
             RGBColor[
             0.18685517330782678`, 0.3137270128217468, 0.9339524977411994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.028685633809430733`], {
             RGBColor[
             0.21037507790267013`, 0.33844792379900884`, 0.935291921513295]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.028685633809430733`], {
             RGBColor[
             0.6253505975793664, 0.7067268126951324, 0.9636490362576168]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.028685633809430733`], {
             RGBColor[
             0.1890859537624092, 0.3160717045191629, 0.9340795373879439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.028685633809430733`], {
             RGBColor[
             0.4243323457115801, 0.5419570831167153, 0.9482590597397496]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.028685633809430733`], {
             RGBColor[
             0.1801862242299471, 0.30671752450510187`, 0.9335727109570402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.028685633809430733`], {
             RGBColor[
             0.36379298595207366`, 0.4895209324897256, 0.9444015452687277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.028685633809430733`], {
             RGBColor[
             0.9942973298741586, 0.9902108901662465, 0.6206777334817875]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.028685633809430733`], {
             RGBColor[
             0.47631296582080423`, 0.5857313491647339, 0.951916247942749]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.028685633809430733`], {
             RGBColor[
             0.8462306119676556, 0.35635431873254797`, 0.1919037922712223]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.028685633809430733`], {
             RGBColor[
             0.1902758304551235, 0.3173223403657453, 0.9341472991053292]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.028685633809430733`], {
             RGBColor[
             0.19084105210201593`, 0.31791642415375154`, 0.9341794876419492]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.028685633809430733`], {
             RGBColor[
             0.4414153171565428, 0.5567534943672319, 0.9493475715743441]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.028685633809430733`], {
             RGBColor[
             0.2030767017243416, 0.3307768676918091, 0.9348762897869192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.028685633809430733`], {
             RGBColor[
             0.46208044251389646`, 0.5741767455763179, 0.9507958115725785]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.028685633809430733`], {
             RGBColor[
             0.18519516767477753`, 0.31198224165097593`, 0.9338579628761555]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.028685633809430733`], {
             RGBColor[
             0.1815243108454087, 0.3081239383775436, 0.933648913010269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.028685633809430733`], {
             RGBColor[
             0.24019038642635912`, 0.3697857034571507, 0.9369898592259228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.028685633809430733`], {
             RGBColor[
             0.18339204965023842`, 0.3100870502828995, 0.9337552779721321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.028685633809430733`], {
             RGBColor[
             0.18070771638990538`, 0.3072656458297307, 0.9336024091640713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.028685633809430733`], {
             RGBColor[
             0.31058773436371456`, 0.4434372177375889, 0.9410113536850742]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.028685633809430733`], {
             RGBColor[
             0.5597098423756648, 0.6534366905384442, 0.9584815555579723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.028685633809430733`], {
             RGBColor[
             0.24531622372842543`, 0.3751732834584783, 0.9372817680772788]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.028685633809430733`], {
             RGBColor[
             0.18854433931021156`, 0.3155024333895635, 0.934048693246138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.028685633809430733`], {
             RGBColor[
             0.2248830575111852, 0.353696730226594, 0.9361181294893675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.028685633809430733`], {
             RGBColor[
             0.9095261013751367, 0.9306954410809412, 0.9912326055643381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.028685633809430733`], {
             RGBColor[
             0.5961635782161725, 0.6830314755158533, 0.9613513271777714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.028685633809430733`], {
             RGBColor[
             0.23010075165696398`, 0.35918085759472357`, 0.9364152694520828]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.028685633809430733`], {
             RGBColor[
             0.17923689510112015`, 0.3057197193997615, 0.9335186480675601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.028685633809430733`], {
             RGBColor[
             0.18261346087673228`, 0.3092687041165651, 0.9337109384932998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.028685633809430733`], {
             RGBColor[
             0.20439189938454302`, 0.3321592238210287, 0.9349511883480071]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.028685633809430733`], {
             RGBColor[
             0.20704370002822514`, 0.33494643443141037`, 0.9351022044716772]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.028685633809430733`], {
             RGBColor[
             0.18255683100735334`, 0.30920918253330676`, 0.933707713506015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.028685633809430733`], {
             RGBColor[
             0.19714961162350877`, 0.32454712019661625`, 0.9345387507740208]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.028685633809430733`], {
             RGBColor[
             0.1792318772890574, 0.3057144453611359, 0.9335183623105863]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.028685633809430733`], {
             RGBColor[
             0.18202687820624844`, 0.30865216853839716`, 0.933677533477987]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.028685633809430733`], {
             RGBColor[
             0.22875987812146206`, 0.3577715144926186, 0.9363389086878806]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.028685633809430733`], {
             RGBColor[
             0.25408219745152405`, 0.38438687763629015`, 0.9377809773127133]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.028685633809430733`], {
             RGBColor[
             0.6142711963162304, 0.6977320556283797, 0.9627768252049985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.028685633809430733`], {
             RGBColor[
             0.9909995879120733, 0.9905461125486716, 0.7988236508241691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.028685633809430733`], {
             RGBColor[
             0.847444298272204, 0.36568324351003745`, 0.19306601964712058`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.028685633809430733`], {
             RGBColor[
             0.20274272640358343`, 0.3304258384544339, 0.9348572703864743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.028685633809430733`], {
             RGBColor[
             0.37110890510299593`, 0.49585761394946637`, 0.9448677091678112]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.028685633809430733`], {
             RGBColor[
             0.1807916321529833, 0.30735384661729226`, 0.9336071880426363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.028685633809430733`], {
             RGBColor[
             0.20696414784897932`, 0.33486282004712353`, 0.9350976740927561]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.028685633809430733`], {
             RGBColor[
             0.8274245231995631, 0.21180247958034423`, 0.17389506042845765`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.028685633809430733`], {
             RGBColor[
             0.1874689911967999, 0.31437217434135956`, 0.9339874537619143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.028685633809430733`], {
             RGBColor[
             0.18829908866819065`, 0.31524465941501073`, 0.9340347265848907]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.028685633809430733`], {
             RGBColor[
             0.21206977390702858`, 0.3402291567495223, 0.9353884319436652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.028685633809430733`], {
             RGBColor[
             0.2677744651747997, 0.39877831915336787`, 0.938560731703659]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.028685633809430733`], {
             RGBColor[
             0.2680749969538752, 0.3990941971079916, 0.9385778465438803]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.028685633809430733`], {
             RGBColor[
             0.18155548323377793`, 0.30815670253416316`, 0.9336506882316712]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.028685633809430733`], {
             RGBColor[
             0.30560245203902436`, 0.43853793178056216`, 0.9407149795940849]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.028685633809430733`], {
             RGBColor[
             0.18889078087796188`, 0.3158665654429332, 0.934068422580907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.028685633809430733`], {
             RGBColor[
             0.3286879472145684, 0.4591147123658486, 0.9421646832425408]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.028685633809430733`], {
             RGBColor[
             0.19492141529937626`, 0.32220514458414634`, 0.9344118582896825]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.028685633809430733`], {
             RGBColor[
             0.25591378716406765`, 0.38631199455366855`, 0.9378852836372484]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.028685633809430733`], {
             RGBColor[
             0.47311473175482466`, 0.583134878671169, 0.9516644712415576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.028685633809430733`], {
             RGBColor[
             0.23685058796865582`, 0.3662753635226519, 0.9367996626445457]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.028685633809430733`], {
             RGBColor[
             0.2213158585080208, 0.34994737790078817`, 0.9359149827833353]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.028685633809430733`], {
             RGBColor[
             0.18345440314028216`, 0.3101525877543751, 0.9337588289111464]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.028685633809430733`], {
             RGBColor[
             0.5041410272247835, 0.6083234230523641, 0.954106974874018]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.028685633809430733`], {
             RGBColor[
             0.19743844380411263`, 0.32485070113144887`, 0.9345551993394172]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.028685633809430733`], {
             RGBColor[
             0.8220097648168001, 0.1701822738881748, 0.16870988168602888`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.028685633809430733`], {
             RGBColor[
             0.20625914549310514`, 0.3341218178713687, 0.9350575252515466]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.028685633809430733`], {
             RGBColor[
             0.20787897197296468`, 0.3358243582046317, 0.9351497719732561]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.028685633809430733`], {
             RGBColor[
             0.989868357531768, 0.9900783197151207, 0.8175710657562082]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[401, 0.028685633809430733`], {
             RGBColor[
             0.18072732343424755`, 0.30728625407649274`, 0.9336035257562406]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[402, 0.028685633809430733`], {
             RGBColor[
             0.21812922311479366`, 0.346598022058153, 0.9357335086118955]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[403, 0.028685633809430733`], {
             RGBColor[
             0.7434088886883141, 0.7994759410509097, 0.9750597085395519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[404, 0.028685633809430733`], {
             RGBColor[
             0.8368269464602606, 0.8727271083178094, 0.9842984952692555]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[405, 0.028685633809430733`], {
             RGBColor[
             0.1816592229448945, 0.3082657395480243, 0.9336565960547502]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[406, 0.028685633809430733`], {
             RGBColor[
             0.41650215403555035`, 0.5351749646438152, 0.9477601268501196]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[407, 0.028685633809430733`], {
             RGBColor[
             0.2771295864414469, 0.4086111447535611, 0.9390934920201328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[408, 0.028685633809430733`], {
             RGBColor[
             0.9372841166711893, 0.9527471774179826, 0.9910458109403161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[409, 0.028685633809430733`], {
             RGBColor[
             0.2532336129818181, 0.38349496155526636`, 0.9377326516825317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[410, 0.028685633809430733`], {
             RGBColor[
             0.18224818387414324`, 0.30888477482694443`, 0.9336901365083813]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[411, 0.028685633809430733`], {
             RGBColor[
             0.281209290628112, 0.4128991725219315, 0.9393258251381819]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[412, 0.028685633809430733`], {
             RGBColor[
             0.1902556572489104, 0.31730113704696017`, 0.934146150271079]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[413, 0.028685633809430733`], {
             RGBColor[
             0.23030998251802656`, 0.3594007724957031, 0.936427184840091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[414, 0.028685633809430733`], {
             RGBColor[
             0.4226665958174486, 0.5405142942814426, 0.9481529196294604]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[415, 0.028685633809430733`], {
             RGBColor[
             0.1803991146634024, 0.3069412858486965, 0.9335848347522823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[416, 0.028685633809430733`], {
             RGBColor[
             0.20922896777355948`, 0.3372432893857343, 0.9352266522369601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[417, 0.028685633809430733`], {
             RGBColor[
             0.19713115786974042`, 0.32452772413137015`, 0.9345376998600435]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[418, 0.028685633809430733`], {
             RGBColor[
             0.4765052907931592, 0.5858874872414329, 0.9519313884690823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[419, 0.028685633809430733`], {
             RGBColor[
             0.649286320101708, 0.725946675113037, 0.9656784505282513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[420, 0.028685633809430733`], {
             RGBColor[
             0.1880446060283209, 0.31497718202537633`, 0.9340202341750236]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[421, 0.028685633809430733`], {
             RGBColor[
             0.1843367269803192, 0.31107996605281657`, 0.9338090759485553]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[422, 0.028685633809430733`], {
             RGBColor[
             0.20654013009820746`, 0.33441715050678417`, 0.9350735269091277]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[423, 0.028685633809430733`], {
             RGBColor[
             0.1791999116318114, 0.3056808474286306, 0.9335165419136952]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[424, 0.028685633809430733`], {
             RGBColor[
             0.19347184238884513`, 0.3206815515469472, 0.9343293072568787]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[425, 0.028685633809430733`], {
             RGBColor[
             0.18667870528248892`, 0.31354153373839766`, 0.9339424481482175]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[426, 0.028685633809430733`], {
             RGBColor[
             0.18735694523176508`, 0.31425440692798345`, 0.9339810729099627]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[427, 0.028685633809430733`], {
             RGBColor[
             0.18651414967483487`, 0.3133685753613251, 0.9339330769497998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[428, 0.028685633809430733`], {
             RGBColor[
             0.18777404508405116`, 0.31469280531839416`, 0.9340048261295064]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[429, 0.028685633809430733`], {
             RGBColor[
             0.1919491178531559, 0.319081071513626, 0.9342425903472402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[430, 0.028685633809430733`], {
             RGBColor[
             0.20155620116286646`, 0.329178725196395, 0.9347896995293221]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[431, 0.028685633809430733`], {
             RGBColor[
             0.4212519905865513, 0.5392890343305656, 0.9480627822350338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[432, 0.028685633809430733`], {
             RGBColor[
             0.29123303955595214`, 0.4234347681874807, 0.9398966628108147]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[433, 0.028685633809430733`], {
             RGBColor[
             0.18067343227102245`, 0.30722961104704605`, 0.9336004567342198]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[434, 0.028685633809430733`], {
             RGBColor[
             0.9350798973521478, 0.7803204568826958, 0.2666219654201177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[435, 0.028685633809430733`], {
             RGBColor[
             0.23839852597207306`, 0.3679023445091814, 0.9368878154238712]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[436, 0.028685633809430733`], {
             RGBColor[
             0.35552088653300873`, 0.4823560557407374, 0.9438744544084752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[437, 0.028685633809430733`], {
             RGBColor[
             0.18191959414620315`, 0.3085394061890873, 0.93367142380948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[438, 0.028685633809430733`], {
             RGBColor[
             0.20264182690306143`, 0.3303197866819874, 0.9348515243091869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[439, 0.028685633809430733`], {
             RGBColor[
             0.19923030702383038`, 0.32673406298606217`, 0.934657243298956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[440, 0.028685633809430733`], {
             RGBColor[
             0.8916325056316791, 0.6008103425923479, 0.23128784517976625`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[441, 0.028685633809430733`], {
             RGBColor[
             0.22146757953397317`, 0.3501068463187328, 0.935923623071312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[442, 0.028685633809430733`], {
             RGBColor[
             0.2379042947950852, 0.36738287620610066`, 0.9368596696894913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[443, 0.028685633809430733`], {
             RGBColor[
             0.2878366774276409, 0.41986497624882907`, 0.9397032450120749]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[444, 0.028685633809430733`], {
             RGBColor[
             0.5658641034717166, 0.6584329969425219, 0.9589660415352547]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[445, 0.028685633809430733`], {
             RGBColor[
             0.9631188181102052, 0.8872532547517151, 0.3112240020952856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[446, 0.028685633809430733`], {
             RGBColor[
             0.18340710413885652`, 0.31010287350494686`, 0.9337561353029877]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[447, 0.028685633809430733`], {
             RGBColor[
             0.23372958097512028`, 0.36299498728917345`, 0.9366219259133799]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[448, 0.028685633809430733`], {
             RGBColor[
             0.300584051971647, 0.4332632751248068, 0.9404291891343054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[449, 0.028685633809430733`], {
             RGBColor[
             0.9836066487684537, 0.9563635183333898, 0.39081535540040413`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[450, 0.028685633809430733`], {
             RGBColor[
             0.2155265395117455, 0.34386243657167787`, 0.9355852896310274]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[451, 0.028685633809430733`], {
             RGBColor[
             0.20508673054441848`, 0.33288953542489785`, 0.9349907579546514]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[452, 0.028685633809430733`], {
             RGBColor[
             0.22680832648896532`, 0.3557203099913444, 0.9362277707094718]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[453, 0.028685633809430733`], {
             RGBColor[
             0.23993040743871616`, 0.3695124490575181, 0.936975053807181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[454, 0.028685633809430733`], {
             RGBColor[
             0.21139233227849236`, 0.33951712264565065`, 0.9353498526451051]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[455, 0.028685633809430733`], {
             RGBColor[
             0.6130446091083116, 0.6967362568758672, 0.9626802637668542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[456, 0.028685633809430733`], {
             RGBColor[
             0.19561148544389112`, 0.32293045205900567`, 0.9344511567635453]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[457, 0.028685633809430733`], {
             RGBColor[
             0.4692511982227218, 0.5799982880996057, 0.9513603197293209]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[458, 0.028685633809430733`], {
             RGBColor[
             0.2390221871354001, 0.3685578519342398, 0.9369233320044987]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[459, 0.028685633809430733`], {
             RGBColor[
             0.1944799719611093, 0.3217411596465035, 0.9343867187446251]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[460, 0.028685633809430733`], {
             RGBColor[
             0.3006736022333113, 0.4333573981276305, 0.9404342888892294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[461, 0.028685633809430733`], {
             RGBColor[
             0.25327163562221944`, 0.38353492576110276`, 0.9377348170156531]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[462, 0.028685633809430733`], {
             RGBColor[
             0.1900670199072787, 0.31710286724060704`, 0.934135407653537]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[463, 0.028685633809430733`], {
             RGBColor[
             0.5551591248464408, 0.6497422130407317, 0.9581233064042441]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[464, 0.028685633809430733`], {
             RGBColor[
             0.20245401245038683`, 0.33012238178410236`, 0.9348408285539537]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[465, 0.028685633809430733`], {
             RGBColor[
             0.1790493149440538, 0.30552256076141593`, 0.9335079656551152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[466, 0.028685633809430733`], {
             RGBColor[
             0.19488624546246058`, 0.32216817885565147`, 0.9344098554194993]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[467, 0.028685633809430733`], {
             RGBColor[
             0.19114672360584797`, 0.3182377042849717, 0.934196895181892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[468, 0.028685633809430733`], {
             RGBColor[
             0.22150150348383524`, 0.3501425025409405, 0.9359255549900708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[469, 0.028685633809430733`], {
             RGBColor[
             0.18135253868176207`, 0.30794339494256673`, 0.9336391308396634]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[470, 0.028685633809430733`], {
             RGBColor[
             0.19461387303716265`, 0.3218818981672542, 0.9343943442128174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[471, 0.028685633809430733`], {
             RGBColor[
             0.9568366664708343, 0.967329437044196, 0.9579484442512339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[472, 0.028685633809430733`], {
             RGBColor[
             0.18313584696674626`, 0.3098177650183609, 0.9337406876083251]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[473, 0.028685633809430733`], {
             RGBColor[
             0.2635938852306148, 0.3943842645679517, 0.9383226538604513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[474, 0.028685633809430733`], {
             RGBColor[
             0.22951352418939525`, 0.35856364429393695`, 0.93638182771653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[475, 0.028685633809430733`], {
             RGBColor[
             0.3365285973416883, 0.465905889423426, 0.9426642825354262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[476, 0.028685633809430733`], {
             RGBColor[
             0.18343003159278173`, 0.31012697171270676`, 0.9337574409875706]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[477, 0.028685633809430733`], {
             RGBColor[
             0.19779376632799722`, 0.32522416763280076`, 0.9345754344314999]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[478, 0.028685633809430733`], {
             RGBColor[
             0.24931371638514488`, 0.37937490169636373`, 0.9375094193703185]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[479, 0.028685633809430733`], {
             RGBColor[
             0.18231814009471767`, 0.3089583032502487, 0.933694120411652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[480, 0.028685633809430733`], {
             RGBColor[
             0.24336115250331075`, 0.37311837964220756`, 0.9371704296632771]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[481, 0.028685633809430733`], {
             RGBColor[
             0.20526876593224802`, 0.3330808661592169, 0.9350011246006911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[482, 0.028685633809430733`], {
             RGBColor[
             0.3323719943960167, 0.4623056488688239, 0.9423994274712677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[483, 0.028685633809430733`], {
             RGBColor[
             0.4520407911262143, 0.5659567458679113, 0.9500246173799538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[484, 0.028685633809430733`], {
             RGBColor[
             0.1848118632397346, 0.3115793643868409, 0.933836134255628]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[485, 0.028685633809430733`], {
             RGBColor[
             0.255344871987097, 0.38571402863136683`, 0.9378528847595545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[486, 0.028685633809430733`], {
             RGBColor[
             0.41333459859387617`, 0.5324313873262027, 0.9475582930183354]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[487, 0.028685633809430733`], {
             RGBColor[
             0.19274009296176206`, 0.31991243650348955`, 0.9342876352095326]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[488, 0.028685633809430733`], {
             RGBColor[
             0.18252871209609148`, 0.30917962777472857`, 0.9337061121756168]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[489, 0.028685633809430733`], {
             RGBColor[
             0.19162106685648111`, 0.3187362691164863, 0.9342239083282876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[490, 0.028685633809430733`], {
             RGBColor[
             0.2159679187439516, 0.3443263541297861, 0.9356104255253395]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[491, 0.028685633809430733`], {
             RGBColor[
             0.1816268290277524, 0.30823169148721496`, 0.9336547512690914]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[492, 0.028685633809430733`], {
             RGBColor[
             0.18260872208869527`, 0.3092637233498817, 0.9337106686263315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[493, 0.028685633809430733`], {
             RGBColor[
             0.2609046791964185, 0.39155773852050096`, 0.9381695075551277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[494, 0.028685633809430733`], {
             RGBColor[
             0.35530253300255993`, 0.4821669288874302, 0.9438605411145975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[495, 0.028685633809430733`], {
             RGBColor[
             0.8860920716837987, 0.5756525260362475, 0.22666477128519144`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[496, 0.028685633809430733`], {
             RGBColor[
             0.1858152550736946, 0.31263399282304966`, 0.9338932759361868]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[497, 0.028685633809430733`], {
             RGBColor[
             0.4781822073170808, 0.587248883619781, 0.9520634014805931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[498, 0.028685633809430733`], {
             RGBColor[
             0.7745863239297996, 0.8238319904188423, 0.9781671839147258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[499, 0.028685633809430733`], {
             RGBColor[
             0.628572856489554, 0.7093427876395323, 0.96390270428255]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[500, 0.028685633809430733`], {
             RGBColor[
             0.20098870068601762`, 0.3285822462136184, 0.9347573812167074]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{3.8349502435193233`*^9, 3.834957407142641*^9, 
  3.835018921852682*^9, 3.8350190129675236`*^9, 3.8350205474078445`*^9},
 CellLabel->"Out[75]=",ExpressionUUID->"8c78aa03-824b-4930-8c2f-b32e45ea0363"]
}, Open  ]],

Cell["Estimated with absolute Mean Deviation v Calculated: (r=6)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 
  3.8349503922098827`*^9}},ExpressionUUID->"70cda18f-a692-4a7f-a53a-\
2f9473089f32"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphin5", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsi5", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}], 
     "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"AMDi6500", ",", "kri5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502409842243`*^9}, {3.8349504019691753`*^9, 3.834950402221115*^9}, {
   3.8349577477528667`*^9, 3.8349577551942053`*^9}, {3.835018833417392*^9, 
   3.8350188346728773`*^9}},
 CellLabel->"In[76]:=",ExpressionUUID->"6ca87953-01e6-4e64-bd7f-93ace413705f"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1dOWGAgQBNBMbNu2bds2J+bEtm3btm3btu01sjdnH271F1R1ssCg6p0C
ggUL9l38vMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEIS
kZgkJCUZyUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpR
mCIUpRjFKUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGY
JjSlGYE0pwUtaUVr2tCWdrSnAx3pRBCd6UJXutGdHvSkF73pQ1/60Z8BDGQQ
gxnCUIYxnBGMZBSjGcNYxjGeCUxkEpOZwlSmMZ0ZzGQWs5nDXOYxnwUsZBGL
WcJSlrGcFaxkFatZw1rWsZ4NbGQTm9nCVraxnR3sZBe72cNe9rGfAxzkEIc5
wlGOcZwTnOQUpznDWc5xngtc5BKXucJVrnGdG9zkFre5w13ucZ8HPOQRj3nC
U57xnBe85BWvecNb3vGeD3zkE5/5wle+8Z1f+JXf+J0/+JO/+Jt/+Jcf/Cx/
AMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEISkZgkJCUZ
yUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpRmCIUpRjF
KUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGYJjSlGYE0
pwUtaUVr2tCWdrSnAx35Od5BdKYLXelGd3rQk170pg996Ud/BjCQQQxmCEMZ
xnBGMJJRjGYMYxnHeCYwkUlMZgpTmcZ0ZjCTWcxmDnOZx3wWsJBFLGYJS1nG
clawklWsZg1rWcd6NrCRTWxmC1vZxnZ2sJNd7GYPe9nHfg5wkEMc5ghHOcZx
TnCSU5zmDGc5x3kucJFLXOYKV7nGdW5wk1vc5g53ucd9HvCQRzzmCU95xnNe
8JJXvOYNb3nHez7wkU985gtf+Rbw/z//Dz189+A=
          "], {Null, CompressedData["
1:eJxF3Al0ldW5gOF/21YsVqt2QFCqdkClVEWUGRVRJmWoghGKIgREKWUqk4DM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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[13, 59] -> 
             RGBColor[
              0.9762999607106941, 0.9380756696065369, 0.5640810045669997], 
             UndirectedEdge[210, 309] -> 
             RGBColor[
              0.7683455760386578, 0.8191615000304233, 0.977490809090918], 
             UndirectedEdge[88, 427] -> 
             RGBColor[
              0.9831331309252187, 0.9672822489310005, 0.6331814040037522], 
             UndirectedEdge[293, 483] -> 
             RGBColor[
              0.8898718703930992, 0.9150236907957524, 0.9893579674677322], 
             UndirectedEdge[46, 150] -> 
             RGBColor[
              0.9506159965322813, 0.8419159130337758, 0.27912267549957104`], 
             UndirectedEdge[400, 444] -> 
             RGBColor[
              0.9408187308126139, 0.8476523939539551, 0.6036530105790063], 
             UndirectedEdge[98, 105] -> 
             RGBColor[
              0.9191335889945326, 0.8868121659511407, 0.6371485730898431], 
             UndirectedEdge[128, 439] -> 
             RGBColor[
              0.8011506001138679, 0.6459194871114278, 0.5934442188912805], 
             UndirectedEdge[23, 62] -> 
             RGBColor[
              0.8907969326005671, 0.915314874994105, 0.9739680087720437], 
             UndirectedEdge[201, 236] -> 
             RGBColor[
              0.9838437540632845, 0.9868523422826381, 0.8845152499372009], 
             UndirectedEdge[40, 477] -> 
             RGBColor[
              0.7493915067811379, 0.8040666531836949, 0.9760123195771107], 
             UndirectedEdge[455, 482] -> 
             RGBColor[
              0.9461196169925402, 0.9568004014455541, 0.8721969962490217], 
             UndirectedEdge[60, 131] -> 
             RGBColor[
              0.8373953512789388, 0.8729891822705476, 0.941406509933183], 
             UndirectedEdge[179, 222] -> 
             RGBColor[
              0.6156158843603425, 0.6789565666572392, 0.8357905636487193], 
             UndirectedEdge[111, 175] -> 
             RGBColor[
              0.778084048362911, 0.8256346962859819, 0.9374682482955883], 
             UndirectedEdge[51, 110] -> 
             RGBColor[
              0.9373203623990739, 0.9498956999918733, 0.876203134895451], 
             UndirectedEdge[84, 261] -> 
             RGBColor[
              0.9722008518083252, 0.9288080994625839, 0.5796731250762815], 
             UndirectedEdge[156, 479] -> 
             RGBColor[
              0.9444181430661702, 0.9580677226224633, 0.9789697651056924], 
             UndirectedEdge[158, 437] -> 
             RGBColor[
              0.7638963969897007, 0.8128509203415832, 0.8845185200620449], 
             UndirectedEdge[103, 355] -> 
             RGBColor[
              0.8429880665209469, 0.8748503131922261, 0.8123401834146923], 
             UndirectedEdge[13, 228] -> 
             RGBColor[
              0.9098362273822094, 0.6622207284464398, 0.256002119970066], 
             UndirectedEdge[59, 409] -> 
             RGBColor[
              0.8550634675772313, 0.8857423613230712, 0.8955167481623374], 
             UndirectedEdge[243, 430] -> 
             RGBColor[
              0.9889031671601887, 0.9746816922814432, 0.5722093020791963], 
             UndirectedEdge[333, 441] -> 
             RGBColor[
              0.9094822451448232, 0.9268465692494394, 0.8201889155446547], 
             UndirectedEdge[179, 385] -> 
             RGBColor[
              0.5676752763184544, 0.6440284062007076, 0.9634995375975459], 
             UndirectedEdge[81, 447] -> 
             RGBColor[
              0.6815676940176998, 0.6627898348531366, 0.6075683755849104], 
             UndirectedEdge[69, 404] -> 
             RGBColor[
              0.907809866895817, 0.580256586609705, 0.4605760807780218], 
             UndirectedEdge[113, 380] -> 
             RGBColor[
              0.9280671095036155, 0.8232566963121436, 0.6136892015347042], 
             UndirectedEdge[85, 489] -> 
             RGBColor[
              0.935978913571386, 0.9513788782460733, 0.9795644128247024], 
             UndirectedEdge[277, 498] -> 
             RGBColor[
              0.9893666075805596, 0.9754707900885657, 0.4406081320432288], 
             UndirectedEdge[18, 160] -> 
             RGBColor[
              0.9547264604770864, 0.9629328557068765, 0.8252969266307901], 
             UndirectedEdge[355, 431] -> 
             RGBColor[
              0.8421303002716658, 0.873015637918485, 0.7189776207001242], 
             UndirectedEdge[357, 492] -> 
             RGBColor[
              0.9732058948311281, 0.97666070243056, 0.765653538496136], 
             UndirectedEdge[165, 386] -> 
             RGBColor[
              0.9446002266673648, 0.9167949338760214, 0.6538127999183942], 
             UndirectedEdge[218, 274] -> 
             RGBColor[
              0.9716902773436362, 0.9701067589453587, 0.6871058212509529], 
             UndirectedEdge[116, 441] -> 
             RGBColor[
              0.89880084606455, 0.9184670442573166, 0.8191336172163026], 
             UndirectedEdge[258, 435] -> 
             RGBColor[
              0.9579345810119165, 0.965354037302732, 0.8145064456219827], 
             UndirectedEdge[112, 445] -> 
             RGBColor[
              0.5475830567029422, 0.6385053643898193, 0.9596775964665454], 
             UndirectedEdge[114, 179] -> 
             RGBColor[
              0.60627191520238, 0.6737605707789664, 0.9309935353100978], 
             UndirectedEdge[155, 467] -> 
             RGBColor[
              0.9578178341510728, 0.9643669108338606, 0.7420218794865863], 
             UndirectedEdge[243, 421] -> 
             RGBColor[
              0.9324049866835719, 0.9458405347023084, 0.8698383472904325], 
             UndirectedEdge[172, 289] -> 
             RGBColor[
              0.9527147760474276, 0.8388433360391939, 0.37188566322633215`], 
             UndirectedEdge[381, 468] -> 
             RGBColor[
              0.8855485287135434, 0.9085360274407666, 0.8515963191336047], 
             UndirectedEdge[17, 277] -> 
             RGBColor[
              0.9518461694807675, 0.9595477518207933, 0.7367898876066781], 
             UndirectedEdge[279, 477] -> 
             RGBColor[
              0.9291031257533302, 0.9459467681294851, 0.9806579508833035], 
             UndirectedEdge[4, 405] -> 
             RGBColor[
              0.9830140392238614, 0.9855475495463646, 0.8551995830391228], 
             UndirectedEdge[36, 379] -> 
             RGBColor[
              0.9589494316604776, 0.9689051338632965, 0.9543720838825815], 
             UndirectedEdge[278, 401] -> 
             RGBColor[
              0.9685842592659473, 0.9373928080737894, 0.6278353862274028], 
             UndirectedEdge[152, 399] -> 
             RGBColor[
              0.9837612921476214, 0.9564018661275877, 0.43251251323932227`], 
             UndirectedEdge[173, 406] -> 
             RGBColor[
              0.6090435124441835, 0.6905388351807644, 0.964101905303506], 
             UndirectedEdge[239, 332] -> 
             RGBColor[
              0.9121310805135703, 0.9272253896383891, 0.704148033982793], 
             UndirectedEdge[116, 361] -> 
             RGBColor[
              0.8119174548771886, 0.8530024885752373, 0.9818861087764184], 
             UndirectedEdge[288, 498] -> 
             RGBColor[
              0.8851556658015373, 0.8975543437678695, 0.6890717563427508], 
             UndirectedEdge[16, 386] -> 
             RGBColor[
              0.9659169291017053, 0.9329653305110353, 0.6271746706842869], 
             UndirectedEdge[216, 464] -> 
             RGBColor[
              0.8226083177009622, 0.8619585178675628, 0.966309590750569], 
             UndirectedEdge[379, 400] -> 
             RGBColor[
              0.931152655355441, 0.8404434507047415, 0.6200151550117593], 
             UndirectedEdge[22, 24] -> 
             RGBColor[
              0.8476134810205229, 0.8808392453731639, 0.9363489896292518], 
             UndirectedEdge[231, 355] -> 
             RGBColor[
              0.8412161032550252, 0.8746965099996187, 0.8837896923121971], 
             UndirectedEdge[434, 495] -> 
             RGBColor[
              0.9584651186752726, 0.9685439340319203, 0.9551918994374768], 
             UndirectedEdge[75, 323] -> 
             RGBColor[
              0.9942520436265769, 0.9901140274618111, 0.6157486049068341], 
             UndirectedEdge[165, 288] -> 
             RGBColor[
              0.8548689124060885, 0.8873992493302001, 0.9859434672108869], 
             UndirectedEdge[90, 229] -> 
             RGBColor[
              0.9943346301773734, 0.99192523823205, 0.7435533696754317], 
             UndirectedEdge[267, 424] -> 
             RGBColor[
              0.9758412213219514, 0.9778882387097323, 0.7026445278355617], 
             UndirectedEdge[258, 403] -> 
             RGBColor[
              0.937958890989683, 0.9494259643046639, 0.812601146475153], 
             UndirectedEdge[274, 305] -> 
             RGBColor[
              0.9732084317905912, 0.9752278503745538, 0.6930035645979623], 
             UndirectedEdge[399, 478] -> 
             RGBColor[
              0.9586423027608126, 0.8622172066425811, 0.38415829507014276`], 
             UndirectedEdge[359, 463] -> 
             RGBColor[
              0.8849019171202135, 0.9082920399138639, 0.8640134965017905], 
             UndirectedEdge[302, 422] -> 
             RGBColor[
              0.9928385233520958, 0.9890388479353908, 0.6035090318912313], 
             UndirectedEdge[21, 335] -> 
             RGBColor[
              0.9730274210093208, 0.9792240098092655, 0.9224601080399888], 
             UndirectedEdge[266, 445] -> 
             RGBColor[
              0.5636505227856401, 0.651057391010888, 0.9612790513266614], 
             UndirectedEdge[200, 452] -> 
             RGBColor[
              0.9323615195986632, 0.9475754287469664, 0.9466743246238478], 
             UndirectedEdge[112, 471] -> 
             RGBColor[
              0.8771869966497821, 0.9025184467033467, 0.8747330222747902], 
             UndirectedEdge[481, 496] -> 
             RGBColor[
              0.8147150877861454, 0.8545274087830346, 0.9060594902072066], 
             UndirectedEdge[6, 422] -> 
             RGBColor[
              0.9904853022822053, 0.9903334422241834, 0.807346694639628], 
             UndirectedEdge[137, 424] -> 
             RGBColor[
              0.9580579255370023, 0.860401070075907, 0.3540578925710795], 
             UndirectedEdge[89, 482] -> 
             RGBColor[
              0.9449695470436832, 0.9563248179662522, 0.891256631587202], 
             UndirectedEdge[142, 254] -> 
             RGBColor[
              0.9924733254938733, 0.9911555409120743, 0.7744000051831406], 
             UndirectedEdge[178, 321] -> 
             RGBColor[
              0.9932499245277999, 0.9914766845702877, 0.7615297494171012], 
             UndirectedEdge[151, 456] -> 
             RGBColor[
              0.8753639547536418, 0.899427573955746, 0.7582969124473462], 
             UndirectedEdge[346, 431] -> 
             RGBColor[
              0.9701695251709509, 0.9737681996741195, 0.7209655365775596], 
             UndirectedEdge[65, 297] -> 
             RGBColor[
              0.9848739626855207, 0.9657921696184194, 0.5890561693903256], 
             UndirectedEdge[79, 253] -> 
             RGBColor[
              0.9192819684371807, 0.6992843636012387, 0.5459163619661029], 
             UndirectedEdge[376, 475] -> 
             RGBColor[
              0.9600795690507529, 0.9455859791428238, 0.673088690068384], 
             UndirectedEdge[209, 259] -> 
             RGBColor[
              0.9044100042790946, 0.9255213046681281, 0.95279071013465], 
             UndirectedEdge[464, 496] -> 
             RGBColor[
              0.6662866142360043, 0.739211981685086, 0.9673834458697224], 
             UndirectedEdge[101, 103] -> 
             RGBColor[
              0.9815171515433847, 0.9834261954521384, 0.7965715022973218], 
             UndirectedEdge[69, 348] -> 
             RGBColor[
              0.9894421140144426, 0.9765437324728813, 0.5746074524646969], 
             UndirectedEdge[116, 277] -> 
             RGBColor[
              0.8979967910310249, 0.9167472518430403, 0.731617188869556], 
             UndirectedEdge[171, 471] -> 
             RGBColor[
              0.9749644890902947, 0.979455005448962, 0.8648306886703906], 
             UndirectedEdge[133, 429] -> 
             RGBColor[
              0.9863453795373829, 0.9672844723083548, 0.5707800119750596], 
             UndirectedEdge[37, 203] -> 
             RGBColor[
              0.9934770058494862, 0.9884563000249534, 0.5313905258492305], 
             UndirectedEdge[299, 399] -> 
             RGBColor[
              0.9934601920322804, 0.9884203369700881, 0.5295604456092391], 
             UndirectedEdge[311, 429] -> 
             RGBColor[
              0.9871924024949126, 0.967115477824831, 0.5189979113975995], 
             UndirectedEdge[327, 446] -> 
             RGBColor[
              0.9900304184510509, 0.9901453360700199, 0.8148852969234752], 
             UndirectedEdge[15, 249] -> 
             RGBColor[
              0.9624778055504922, 0.9349848907851032, 0.642728135850142], 
             UndirectedEdge[50, 242] -> 
             RGBColor[
              0.823327261769214, 0.862405780262226, 0.9828933368994337], 
             UndirectedEdge[163, 355] -> 
             RGBColor[
              0.823369325855527, 0.8625285954752757, 0.965148912401708], 
             UndirectedEdge[192, 435] -> 
             RGBColor[
              0.957217188372864, 0.9638196069873205, 0.7364226840952803], 
             UndirectedEdge[31, 191] -> 
             RGBColor[
              0.5785018711905476, 0.6472438321158438, 0.9447233825892476], 
             UndirectedEdge[385, 415] -> 
             RGBColor[
              0.9459852800618178, 0.9568280524238648, 0.8780362575755076], 
             UndirectedEdge[207, 257] -> 
             RGBColor[
              0.8333877376387759, 0.5084622758886451, 0.5748605555011811], 
             UndirectedEdge[359, 408] -> 
             RGBColor[
              0.849984531580946, 0.8835753913938161, 0.9854587985499915], 
             UndirectedEdge[183, 202] -> 
             RGBColor[
              0.6853662032300986, 0.7481403458893301, 0.9163620763371638], 
             UndirectedEdge[170, 223] -> 
             RGBColor[
              0.9103735172433871, 0.9311163659636734, 0.982479997326265], 
             UndirectedEdge[40, 430] -> 
             RGBColor[
              0.7870902813103009, 0.8179176747566101, 0.6765901702441784], 
             UndirectedEdge[69, 444] -> 
             RGBColor[
              0.9771129400916736, 0.9808572074672333, 0.8522326217766718], 
             UndirectedEdge[215, 417] -> 
             RGBColor[
              0.8255241767029771, 0.8639860777468289, 0.9539284851525527], 
             UndirectedEdge[423, 429] -> 
             RGBColor[
              0.9871440929275397, 0.9670121485450667, 0.5137397131211399], 
             UndirectedEdge[5, 83] -> 
             RGBColor[
              0.8714639377234252, 0.8995653315419402, 0.9429852801368466], 
             UndirectedEdge[311, 366] -> 
             RGBColor[
              0.8821427500185051, 0.9054852185627437, 0.8200047369151273], 
             UndirectedEdge[133, 366] -> 
             RGBColor[
              0.8812957270609754, 0.9056542130462675, 0.8717868374925875], 
             UndirectedEdge[76, 359] -> 
             RGBColor[
              0.8697001556216191, 0.8985776846924445, 0.9624315616575987], 
             UndirectedEdge[172, 218] -> 
             RGBColor[
              0.9506714900258357, 0.832348429856785, 0.3301407744066094], 
             UndirectedEdge[177, 484] -> 
             RGBColor[
              0.877812326027973, 0.9025295829440144, 0.8531491025674671], 
             UndirectedEdge[45, 328] -> 
             RGBColor[
              0.9673837764373368, 0.973470712641801, 0.8628574789602865], 
             UndirectedEdge[115, 144] -> 
             RGBColor[
              0.8408876758802394, 0.8746633091133704, 0.8938854600190074], 
             UndirectedEdge[63, 72] -> 
             RGBColor[
              0.8027988444917573, 0.8219458936616805, 0.6648623701439087], 
             UndirectedEdge[248, 387] -> 
             RGBColor[
              0.8302388668229261, 0.868164187629729, 0.9794531008326357], 
             UndirectedEdge[34, 44] -> 
             RGBColor[
              0.8091599738219046, 0.7832169265490984, 0.621567164586956], 
             UndirectedEdge[279, 285] -> 
             RGBColor[
              0.9567295077378641, 0.9672495182366032, 0.9581298360346788], 
             UndirectedEdge[13, 77] -> 
             RGBColor[
              0.9647013232051168, 0.9303613976485686, 0.6256292513408785], 
             UndirectedEdge[53, 445] -> 
             RGBColor[
              0.664308800752239, 0.7277031754896617, 0.8329806292282944], 
             UndirectedEdge[91, 298] -> 
             RGBColor[
              0.9071497929996639, 0.928053301491041, 0.96509535001265], 
             UndirectedEdge[6, 451] -> 
             RGBColor[
              0.8818945405338094, 0.9070484124093329, 0.9138535093796248], 
             UndirectedEdge[87, 256] -> 
             RGBColor[
              0.9873895217062911, 0.989053257398111, 0.858651790405839], 
             UndirectedEdge[153, 172] -> 
             RGBColor[
              0.8750611597102442, 0.7817353309799036, 0.6163368230325545], 
             UndirectedEdge[72, 438] -> 
             RGBColor[
              0.9592754352915421, 0.945234893424745, 0.6749776857797025], 
             UndirectedEdge[207, 440] -> 
             RGBColor[
              0.6997719438431207, 0.764211160091507, 0.971613576812606], 
             UndirectedEdge[19, 228] -> 
             RGBColor[
              0.6197939343579975, 0.47211951442016387`, 0.5738623994534655], 
             UndirectedEdge[8, 63] -> 
             RGBColor[
              0.4036742870569239, 0.5073069848958702, 0.9486958973898845], 
             UndirectedEdge[72, 128] -> 
             RGBColor[
              0.9233830143481176, 0.717695949457537, 0.28936445588613163`], 
             UndirectedEdge[229, 485] -> 
             RGBColor[
              0.7930325033804371, 0.83575664248135, 0.855531114694455], 
             UndirectedEdge[32, 407] -> 
             RGBColor[
              0.9839711379884355, 0.9687096360849392, 0.6267642511018067], 
             UndirectedEdge[475, 478] -> 
             RGBColor[
              0.9504926824958093, 0.835209924502616, 0.31140216175445246`], 
             UndirectedEdge[194, 412] -> 
             RGBColor[
              0.9490313458171066, 0.9311445143793191, 0.6701476766266679], 
             UndirectedEdge[370, 390] -> 
             RGBColor[
              0.9814937259254939, 0.9480381907301337, 0.48447145076035447`], 
             UndirectedEdge[231, 233] -> 
             RGBColor[0.9894391777871, 0.9899008428612841, 0.824683684806933],
              UndirectedEdge[114, 385] -> 
             RGBColor[
              0.9375777018414455, 0.952019278262435, 0.9577208080989507], 
             UndirectedEdge[271, 442] -> 
             RGBColor[
              0.98194607884533, 0.9521551665453747, 0.5516890196188715], 
             UndirectedEdge[206, 254] -> 
             RGBColor[
              0.9732235051949576, 0.9784043791037307, 0.8788745580104731], 
             UndirectedEdge[262, 455] -> 
             RGBColor[
              0.9763182739938804, 0.9802805441789404, 0.8542941798409954], 
             UndirectedEdge[7, 341] -> 
             RGBColor[
              0.8907610478946684, 0.9157326967994233, 0.98944277801161], 
             UndirectedEdge[187, 328] -> 
             RGBColor[
              0.9637734652229675, 0.9719777561738931, 0.9226896789683064], 
             UndirectedEdge[44, 56] -> 
             RGBColor[
              0.9638711701338285, 0.9041923510999015, 0.5951590343175865], 
             UndirectedEdge[142, 388] -> 
             RGBColor[0.654648676010762, 0.7196845430103, 0.8464140240592437],
              UndirectedEdge[282, 419] -> 
             RGBColor[
              0.9939284754549598, 0.9894219478604824, 0.5805302062575952], 
             UndirectedEdge[7, 244] -> 
             RGBColor[
              0.9547267175347578, 0.9652689362137197, 0.9427328445211395], 
             UndirectedEdge[107, 470] -> 
             RGBColor[
              0.9715006806229778, 0.9766213944704721, 0.8594846960383187], 
             UndirectedEdge[10, 383] -> 
             RGBColor[
              0.9030276805096844, 0.9236810278640435, 0.9215483551184254], 
             UndirectedEdge[249, 419] -> 
             RGBColor[
              0.9750188637592427, 0.9772055316443702, 0.6985304363604475], 
             UndirectedEdge[191, 271] -> 
             RGBColor[
              0.9646915550785724, 0.9407802742115268, 0.6477785541356498], 
             UndirectedEdge[297, 490] -> 
             RGBColor[
              0.9921660724070709, 0.9910284838646373, 0.7794919839769563], 
             UndirectedEdge[32, 176] -> 
             RGBColor[
              0.9897223913201498, 0.9879058568955092, 0.6664625818096674], 
             UndirectedEdge[353, 487] -> 
             RGBColor[
              0.8274036081274215, 0.8632771610916736, 0.853894964683924], 
             UndirectedEdge[281, 324] -> 
             RGBColor[
              0.9589185807628695, 0.968882125314374, 0.9544243064050294], 
             UndirectedEdge[19, 59] -> 
             RGBColor[
              0.6862576676864822, 0.7479744555802609, 0.8819412840503993], 
             UndirectedEdge[197, 411] -> 
             RGBColor[
              0.6805130920659763, 0.7474383033391743, 0.97091228327929], 
             UndirectedEdge[163, 343] -> 
             RGBColor[
              0.9445704059806868, 0.9581314692418806, 0.9769850515550111], 
             UndirectedEdge[12, 396] -> 
             RGBColor[
              0.865778817581732, 0.8959109672457799, 0.9821196662796887], 
             UndirectedEdge[51, 397] -> 
             RGBColor[
              0.937817890402769, 0.9490863538267212, 0.7941717151666596], 
             UndirectedEdge[448, 482] -> 
             RGBColor[
              0.9448057763469146, 0.9562570945744235, 0.8939707358576354], 
             UndirectedEdge[183, 285] -> 
             RGBColor[
              0.6744476538113565, 0.740244670400079, 0.9459216540426247], 
             UndirectedEdge[155, 365] -> 
             RGBColor[
              0.9932204270413998, 0.9895917391056637, 0.6258896258760804], 
             UndirectedEdge[122, 217] -> 
             RGBColor[
              0.8471840316226904, 0.8811923618346136, 0.9852314862781859], 
             UndirectedEdge[249, 269] -> 
             RGBColor[
              0.9755645879651247, 0.9797121801080557, 0.8552893575594958], 
             UndirectedEdge[101, 331] -> 
             RGBColor[
              0.9814131780952732, 0.9832038067599559, 0.7852546341201179], 
             UndirectedEdge[246, 458] -> 
             RGBColor[
              0.9937566145797971, 0.990607096405499, 0.6746921318321885], 
             UndirectedEdge[35, 437] -> 
             RGBColor[
              0.628953640485403, 0.7084579505881987, 0.9647490079849065], 
             UndirectedEdge[354, 473] -> 
             RGBColor[
              0.9900554832744606, 0.9890332737559665, 0.732881294882352], 
             UndirectedEdge[230, 484] -> 
             RGBColor[
              0.9758490222132876, 0.9286308027633206, 0.5075605607102893], 
             UndirectedEdge[108, 190] -> 
             RGBColor[
              0.9902196054780041, 0.9782842734866057, 0.44935366015834377`], 
             UndirectedEdge[55, 136] -> 
             RGBColor[
              0.9926960486170584, 0.990248992786243, 0.6981176040327906], 
             UndirectedEdge[59, 279] -> 
             RGBColor[
              0.9697204879879022, 0.9760021971336381, 0.8942247161755752], 
             UndirectedEdge[24, 170] -> 
             RGBColor[
              0.9652088000059951, 0.9734659595297759, 0.9389669699070905], 
             UndirectedEdge[184, 388] -> 
             RGBColor[
              0.4567987908974691, 0.5661452243795493, 0.9514143990758924], 
             UndirectedEdge[173, 242] -> 
             RGBColor[
              0.6547521420375612, 0.7267437627759481, 0.9685258261407808], 
             UndirectedEdge[4, 345] -> 
             RGBColor[
              0.974434822921819, 0.9791491840754787, 0.8697219584205069], 
             UndirectedEdge[59, 256] -> 
             RGBColor[
              0.98960013834683, 0.9899674041892302, 0.8220161517796296], 
             UndirectedEdge[232, 480] -> 
             RGBColor[
              0.957196959825084, 0.87402491562105, 0.5855501241055363], 
             UndirectedEdge[3, 437] -> 
             RGBColor[
              0.7654954791852919, 0.8118755347196646, 0.7390506153602077], 
             UndirectedEdge[199, 448] -> 
             RGBColor[
              0.9881309071461408, 0.9893598393302256, 0.8463651150235132], 
             UndirectedEdge[151, 226] -> 
             RGBColor[
              0.9908413916176795, 0.9801171405360922, 0.47426576094091166`], 
             UndirectedEdge[241, 442] -> 
             RGBColor[
              0.7996764294541114, 0.8413022912029227, 0.8624004120814632], 
             UndirectedEdge[303, 400] -> 
             RGBColor[
              0.9345289788773073, 0.7781362487126523, 0.26617868348354246`], 
             UndirectedEdge[42, 378] -> 
             RGBColor[
              0.9906616541400618, 0.9904063682494431, 0.8044240879709683], 
             UndirectedEdge[15, 499] -> 
             RGBColor[
              0.9077950442419332, 0.8919419442723768, 0.6569142336283391], 
             UndirectedEdge[341, 374] -> 
             RGBColor[
              0.9261841189032717, 0.9403919061169672, 0.8402413596936903], 
             UndirectedEdge[312, 334] -> 
             RGBColor[
              0.8635409694777181, 0.8940281451390926, 0.9868465026325505], 
             UndirectedEdge[7, 482] -> 
             RGBColor[
              0.9113372102245563, 0.9321395701162283, 0.9914053507431917], 
             UndirectedEdge[219, 403] -> 
             RGBColor[
              0.9380674012047744, 0.9496580566826787, 0.8244118137404222], 
             UndirectedEdge[50, 449] -> 
             RGBColor[
              0.7847676316075227, 0.8317857053574838, 0.9791819615143115], 
             UndirectedEdge[318, 430] -> 
             RGBColor[
              0.8421086683981647, 0.8616975892105798, 0.6815275177711679], 
             UndirectedEdge[242, 449] -> 
             RGBColor[
              0.842914119898911, 0.8777071826987807, 0.9848455718682059], 
             UndirectedEdge[356, 365] -> 
             RGBColor[
              0.9554020703867948, 0.9642714551796725, 0.876099311917978], 
             UndirectedEdge[154, 219] -> 
             RGBColor[
              0.9685893146783662, 0.973819569664923, 0.8212268039615185], 
             UndirectedEdge[69, 275] -> 
             RGBColor[
              0.9920683540286648, 0.9909880748039186, 0.7811114303942026], 
             UndirectedEdge[173, 310] -> 
             RGBColor[
              0.71080191230723, 0.7669112556593329, 0.7451826158818782], 
             UndirectedEdge[351, 460] -> 
             RGBColor[
              0.9453491902196982, 0.955184672186893, 0.802434152495132], 
             UndirectedEdge[97, 207] -> 
             RGBColor[
              0.6247891122749964, 0.701892316559191, 0.9661097464727999], 
             UndirectedEdge[122, 212] -> 
             RGBColor[
              0.8003902511362709, 0.8439902144696481, 0.9807390782272571], 
             UndirectedEdge[45, 224] -> 
             RGBColor[
              0.6461034569920894, 0.7110929972378143, 0.8399280459078571], 
             UndirectedEdge[144, 215] -> 
             RGBColor[
              0.8363836553132356, 0.871144734014603, 0.8934365413413538], 
             UndirectedEdge[22, 214] -> 
             RGBColor[
              0.8523535235728836, 0.8827993747821022, 0.8577942176997309], 
             UndirectedEdge[142, 150] -> 
             RGBColor[
              0.9700134393774156, 0.9080122463714513, 0.5135272158169901], 
             UndirectedEdge[149, 419] -> 
             RGBColor[
              0.933861862029753, 0.9449476586730305, 0.7140066331618843], 
             UndirectedEdge[11, 418] -> 
             RGBColor[
              0.7966372902093775, 0.8413872895388993, 0.980277733784813], 
             UndirectedEdge[189, 346] -> 
             RGBColor[
              0.9608907491624921, 0.9703529652776832, 0.9510859397283662], 
             UndirectedEdge[185, 224] -> 
             RGBColor[
              0.6228025887993537, 0.6954399896374469, 0.956607797162935], 
             UndirectedEdge[17, 386] -> 
             RGBColor[
              0.9373665419630213, 0.9110269900459185, 0.6531228446137074], 
             UndirectedEdge[194, 476] -> 
             RGBColor[
              0.9694737696192732, 0.9466509096611838, 0.6445746119374542], 
             UndirectedEdge[258, 471] -> 
             RGBColor[
              0.9935137629317746, 0.9908628847017656, 0.7046097872708459], 
             UndirectedEdge[203, 397] -> 
             RGBColor[
              0.9935010699372049, 0.9885077706753314, 0.5340097532910858], 
             UndirectedEdge[126, 173] -> 
             RGBColor[
              0.6959811306056086, 0.717577827964478, 0.6314383527097702], 
             UndirectedEdge[30, 366] -> 
             RGBColor[
              0.8427889777705404, 0.8778882616321506, 0.9847591030650564], 
             UndirectedEdge[95, 368] -> 
             RGBColor[
              0.9905419795801225, 0.9903568797434122, 0.8064074051369965], 
             UndirectedEdge[15, 242] -> 
             RGBColor[
              0.9245147970411143, 0.9052738213088445, 0.6585089785762246], 
             UndirectedEdge[150, 392] -> 
             RGBColor[
              0.9060005832707042, 0.86007513007254, 0.6313059117863722], 
             UndirectedEdge[179, 296] -> 
             RGBColor[
              0.613562215722048, 0.6781073218984277, 0.8698251677093273], 
             UndirectedEdge[3, 123] -> 
             RGBColor[
              0.9919196329706043, 0.9892899276201201, 0.6646091487752002], 
             UndirectedEdge[37, 257] -> 
             RGBColor[
              0.9056881070863778, 0.5619121534801833, 0.3793803106031965], 
             UndirectedEdge[17, 178] -> 
             RGBColor[
              0.9524587750425338, 0.9617477999709072, 0.8681434219693229], 
             UndirectedEdge[68, 367] -> 
             RGBColor[
              0.6469413785142522, 0.7133081092281819, 0.8747823472686942], 
             UndirectedEdge[1, 363] -> 
             RGBColor[
              0.990711956276457, 0.9902685314045279, 0.7920591382985573], 
             UndirectedEdge[227, 329] -> 
             RGBColor[
              0.9936816521643147, 0.9916552150428807, 0.7543749052047435], 
             UndirectedEdge[121, 420] -> 
             RGBColor[
              0.6148066666960205, 0.6856711508728528, 0.9483308619740776], 
             UndirectedEdge[82, 149] -> 
             RGBColor[
              0.6573101805271315, 0.7291790800422742, 0.9685876945903541], 
             UndirectedEdge[129, 355] -> 
             RGBColor[
              0.520629724348846, 0.6181507789635476, 0.9566942056217984], 
             UndirectedEdge[87, 388] -> 
             RGBColor[
              0.650423600095921, 0.717937365540015, 0.9164344661141236], 
             UndirectedEdge[91, 228] -> 
             RGBColor[
              0.8532590269849967, 0.6606392858645791, 0.5938189324223995], 
             UndirectedEdge[12, 161] -> 
             RGBColor[
              0.9636593544935357, 0.9720899998607764, 0.931720453162906], 
             UndirectedEdge[64, 115] -> 
             RGBColor[
              0.8214318507994518, 0.8610935117231013, 0.9689287761185745], 
             UndirectedEdge[56, 342] -> 
             RGBColor[
              0.8367299931805215, 0.8724929592901718, 0.9425327876406187], 
             UndirectedEdge[378, 416] -> 
             RGBColor[
              0.9783241356603714, 0.9830396448551249, 0.907464425702785], 
             UndirectedEdge[119, 363] -> 
             RGBColor[
              0.6543752253909056, 0.7190076528427856, 0.8245222541731652], 
             UndirectedEdge[391, 455] -> 
             RGBColor[
              0.9766041561827699, 0.9804937546473251, 0.8538102558652221], 
             UndirectedEdge[249, 282] -> 
             RGBColor[
              0.9763093787750752, 0.9799658127721527, 0.8389950316983108], 
             UndirectedEdge[226, 429] -> 
             RGBColor[
              0.9839149503329905, 0.9574034919032219, 0.39201304876076404`], 
             UndirectedEdge[181, 189] -> 
             RGBColor[
              0.9839247911034159, 0.9844562078176633, 0.7317488098793044], 
             UndirectedEdge[160, 167] -> 
             RGBColor[
              0.9094895333172397, 0.926862157913291, 0.8209821881348024], 
             UndirectedEdge[16, 277] -> 
             RGBColor[
              0.9803965566194516, 0.9814860922859101, 0.7108417136772576], 
             UndirectedEdge[295, 341] -> 
             RGBColor[
              0.8447238005206649, 0.8790238453911827, 0.9850517042591417], 
             UndirectedEdge[69, 129] -> 
             RGBColor[
              0.6718410987023015, 0.7345908505971563, 0.8480643366042229], 
             UndirectedEdge[352, 368] -> 
             RGBColor[
              0.9910903981966834, 0.9882315673046819, 0.6263460216739295], 
             UndirectedEdge[194, 297] -> 
             RGBColor[
              0.9815524195093449, 0.9545878245497528, 0.5761526013716795], 
             UndirectedEdge[188, 228] -> 
             RGBColor[
              0.8969670858179852, 0.6954564312499886, 0.5967926003188265], 
             UndirectedEdge[273, 430] -> 
             RGBColor[
              0.9586212004369729, 0.8653662645348716, 0.32872588715213014`], 
             UndirectedEdge[200, 468] -> 
             RGBColor[
              0.8802199183219962, 0.9063559130889203, 0.9416063332127325], 
             UndirectedEdge[93, 172] -> 
             RGBColor[
              0.9498420264158245, 0.8394970467197582, 0.553364270501848], 
             UndirectedEdge[61, 341] -> 
             RGBColor[
              0.9218629869932617, 0.9273401305783462, 0.6938291563020764], 
             UndirectedEdge[121, 442] -> 
             RGBColor[
              0.6329413332491336, 0.697702452255663, 0.8507514752980027], 
             UndirectedEdge[287, 336] -> 
             RGBColor[
              0.9928163092275415, 0.9906324891769174, 0.7203858056740162], 
             UndirectedEdge[403, 497] -> 
             RGBColor[
              0.934161166511992, 0.9485784114649747, 0.9280867462668846], 
             UndirectedEdge[17, 407] -> 
             RGBColor[
              0.945999063243582, 0.9401465113376355, 0.6866585596738294], 
             UndirectedEdge[135, 470] -> 
             RGBColor[
              0.9933951031755767, 0.9915367196720645, 0.7591237635131436], 
             UndirectedEdge[322, 471] -> 
             RGBColor[
              0.9863225586311245, 0.9879258351153809, 0.8456044395967397], 
             UndirectedEdge[24, 52] -> 
             RGBColor[
              0.9849546925215857, 0.9880463929579795, 0.89900321113235], 
             UndirectedEdge[163, 440] -> 
             RGBColor[
              0.7527304154329879, 0.8059314587386321, 0.9590746920424087], 
             UndirectedEdge[274, 432] -> 
             RGBColor[
              0.9460650806538345, 0.8782988895477116, 0.6155137389541399], 
             UndirectedEdge[89, 261] -> 
             RGBColor[
              0.9890680716305351, 0.9897473809285513, 0.8308338742131604], 
             UndirectedEdge[255, 312] -> 
             RGBColor[
              0.8930024484203438, 0.8670954028343385, 0.6363030913110044], 
             UndirectedEdge[370, 422] -> 
             RGBColor[
              0.9937338704341929, 0.9909539048105205, 0.7009620363358164], 
             UndirectedEdge[43, 90] -> 
             RGBColor[
              0.9625953327477017, 0.8770559374048531, 0.4999932697361091], 
             UndirectedEdge[373, 449] -> 
             RGBColor[
              0.8770381676560206, 0.8427290051198146, 0.629768708566931], 
             UndirectedEdge[49, 457] -> 
             RGBColor[
              0.8295797349936176, 0.8309217907437434, 0.6496298019546923], 
             UndirectedEdge[234, 449] -> 
             RGBColor[
              0.8832489736397849, 0.8655251211624133, 0.6442845534768203], 
             UndirectedEdge[245, 299] -> 
             RGBColor[
              0.8890884698458729, 0.9102013312735181, 0.7638347303183946], 
             UndirectedEdge[398, 464] -> 
             RGBColor[
              0.8190610261272881, 0.8593129536200736, 0.9723142301029828], 
             UndirectedEdge[245, 262] -> 
             RGBColor[
              0.871743753271357, 0.9002558348783203, 0.9667696827276533], 
             UndirectedEdge[288, 321] -> 
             RGBColor[
              0.8884263771870112, 0.9113601900994777, 0.878639839353978], 
             UndirectedEdge[433, 465] -> 
             RGBColor[
              0.9840640999255599, 0.9863959490694425, 0.8563448477014549], 
             UndirectedEdge[330, 367] -> 
             RGBColor[
              0.9652885644769647, 0.9726035729234218, 0.8975485116039608], 
             UndirectedEdge[106, 156] -> 
             RGBColor[
              0.948562131412888, 0.9611583023462873, 0.9719550737599583], 
             UndirectedEdge[85, 239] -> 
             RGBColor[
              0.9563263866225753, 0.9624655270800835, 0.7083634217330854], 
             UndirectedEdge[336, 388] -> 
             RGBColor[
              0.6532820007328025, 0.7191193876609112, 0.8690633702572761], 
             UndirectedEdge[69, 355] -> 
             RGBColor[
              0.8425766076072234, 0.8752591135126198, 0.8612426143238725], 
             UndirectedEdge[102, 383] -> 
             RGBColor[
              0.9063899636986685, 0.9239663754186889, 0.7855016642749033], 
             UndirectedEdge[296, 327] -> 
             RGBColor[
              0.9904560358528673, 0.9903213398035393, 0.8078317151128492], 
             UndirectedEdge[61, 288] -> 
             RGBColor[
              0.8854671469302124, 0.8986050427541376, 0.6902818017093779], 
             UndirectedEdge[141, 472] -> 
             RGBColor[
              0.985320666505076, 0.9852539457784171, 0.7100808546759749], 
             UndirectedEdge[43, 485] -> 
             RGBColor[
              0.7612932059507656, 0.720887341654153, 0.6119710147551323], 
             UndirectedEdge[9, 358] -> 
             RGBColor[
              0.9865028838287826, 0.9886866098502072, 0.8733456745814276], 
             UndirectedEdge[70, 359] -> 
             RGBColor[
              0.8633180106383765, 0.8938178914137456, 0.9732348683842281], 
             UndirectedEdge[466, 470] -> 
             RGBColor[
              0.9658898310386244, 0.9724368320373844, 0.8689824008406868], 
             UndirectedEdge[41, 356] -> 
             RGBColor[
              0.7732231752555391, 0.8233499940022494, 0.9779624223613794], 
             UndirectedEdge[79, 436] -> 
             RGBColor[
              0.9132938002361402, 0.6950032988630062, 0.564333026817269], 
             UndirectedEdge[33, 175] -> 
             RGBColor[
              0.7696852091002495, 0.819370855715726, 0.951685292399167], 
             UndirectedEdge[176, 448] -> 
             RGBColor[
              0.9919488628275284, 0.9888265600815183, 0.6295641870088455], 
             UndirectedEdge[118, 481] -> 
             RGBColor[
              0.9248690088315175, 0.9409327778742141, 0.9169386526987546], 
             UndirectedEdge[326, 346] -> 
             RGBColor[
              0.9279811723920615, 0.9451081507229167, 0.9824924150840609], 
             UndirectedEdge[63, 435] -> 
             RGBColor[
              0.7749233521094585, 0.8247016866956998, 0.9781291701633781], 
             UndirectedEdge[194, 350] -> 
             RGBColor[
              0.9725623879779103, 0.9191086333711347, 0.34791048776278977`], 
             UndirectedEdge[275, 486] -> 
             RGBColor[
              0.9786748075621889, 0.9825934310231741, 0.8751765910991675], 
             UndirectedEdge[407, 478] -> 
             RGBColor[
              0.952664860193339, 0.842537189927961, 0.3198406619280165], 
             UndirectedEdge[62, 356] -> 
             RGBColor[
              0.8730285343267981, 0.9015932718166617, 0.9877514350375048], 
             UndirectedEdge[150, 426] -> 
             RGBColor[
              0.8222650721361953, 0.7942897645318954, 0.6230582705898171], 
             UndirectedEdge[372, 444] -> 
             RGBColor[
              0.9775368587468705, 0.9804750572739778, 0.8046863568342473], 
             UndirectedEdge[106, 329] -> 
             RGBColor[
              0.9752565599868952, 0.9795660313680883, 0.859553563158274], 
             UndirectedEdge[128, 294] -> 
             RGBColor[
              0.8865225295080765, 0.7132873533968757, 0.6017742593039841], 
             UndirectedEdge[379, 440] -> 
             RGBColor[
              0.7455965798585062, 0.8006110558477674, 0.971150414867701], 
             UndirectedEdge[227, 267] -> 
             RGBColor[
              0.9765409105605418, 0.9803726101207537, 0.8506045157664499], 
             UndirectedEdge[151, 345] -> 
             RGBColor[
              0.9751903376652582, 0.9779739905282809, 0.7490669769122253], 
             UndirectedEdge[275, 418] -> 
             RGBColor[
              0.8614725161470147, 0.8906530169459645, 0.891796063424146], 
             UndirectedEdge[10, 232] -> 
             RGBColor[
              0.9858274700279465, 0.9884073088862184, 0.8845390291761694], 
             UndirectedEdge[5, 431] -> 
             RGBColor[
              0.9886114548785779, 0.9874996421257953, 0.6887397342990693], 
             UndirectedEdge[42, 416] -> 
             RGBColor[
              0.9828970853017773, 0.9849306770512914, 0.8316788157303772], 
             UndirectedEdge[37, 97] -> 
             RGBColor[
              0.6970894817225983, 0.7553421941507292, 0.7706295015748152], 
             UndirectedEdge[441, 450] -> 
             RGBColor[
              0.7924127527546289, 0.8345567248784482, 0.8090762174502968], 
             UndirectedEdge[5, 259] -> 
             RGBColor[
              0.9812388693146021, 0.9855060414417541, 0.9156334542414577], 
             UndirectedEdge[279, 318] -> 
             RGBColor[
              0.8249219799900421, 0.8638434875383795, 0.9704641994468377], 
             UndirectedEdge[275, 355] -> 
             RGBColor[
              0.8408569796752092, 0.8745480031703099, 0.8897412994117782], 
             UndirectedEdge[344, 387] -> 
             RGBColor[
              0.8297105600329439, 0.8677701772907833, 0.980347386423597], 
             UndirectedEdge[239, 489] -> 
             RGBColor[
              0.9719193285388971, 0.9744895984673272, 0.6956594048714297], 
             UndirectedEdge[21, 336] -> 
             RGBColor[
              0.9881997906536109, 0.9893883244307898, 0.8452235370399346], 
             UndirectedEdge[32, 312] -> 
             RGBColor[
              0.9075968403548513, 0.9274423237820292, 0.9275324719666935], 
             UndirectedEdge[77, 436] -> 
             RGBColor[
              0.9699785509551934, 0.9771306329747701, 0.935702661771637], 
             UndirectedEdge[66, 294] -> 
             RGBColor[
              0.9285439054909315, 0.945397261997248, 0.977012767003286], 
             UndirectedEdge[197, 201] -> 
             RGBColor[
              0.7102052515198307, 0.7691485182028919, 0.8993406587932967], 
             UndirectedEdge[228, 256] -> 
             RGBColor[
              0.9231364050183453, 0.7141124630291331, 0.5139372671826958], 
             UndirectedEdge[292, 481] -> 
             RGBColor[
              0.9064331871832263, 0.9262325541189141, 0.9151802275720883], 
             UndirectedEdge[444, 486] -> 
             RGBColor[
              0.9637193936251978, 0.9724625636864889, 0.9462977824816368], 
             UndirectedEdge[154, 244] -> 
             RGBColor[
              0.9639220671841201, 0.9724252260966768, 0.9375136880462324], 
             UndirectedEdge[288, 386] -> 
             RGBColor[
              0.8743348522154528, 0.8610531986941532, 0.6470349388999957], 
             UndirectedEdge[273, 285] -> 
             RGBColor[
              0.9485488078923439, 0.8728179930690745, 0.6056199216364377], 
             UndirectedEdge[190, 487] -> 
             RGBColor[
              0.8238147569341214, 0.8517112118749739, 0.6859906978009995], 
             UndirectedEdge[83, 343] -> 
             RGBColor[
              0.8461838632416729, 0.8806842011012347, 0.9850593056912047], 
             UndirectedEdge[1, 315] -> 
             RGBColor[
              0.9853893826700258, 0.9882261485053867, 0.8917992704306528], 
             UndirectedEdge[4, 429] -> 
             RGBColor[
              0.9858756421765797, 0.9670902238379631, 0.5785647756848907], 
             UndirectedEdge[189, 451] -> 
             RGBColor[
              0.8750900003627384, 0.9025974220753106, 0.9533079604075311], 
             UndirectedEdge[10, 102] -> 
             RGBColor[
              0.9906387847090006, 0.9892918682012455, 0.7244781365357549], 
             UndirectedEdge[357, 368] -> 
             RGBColor[
              0.9917111027692056, 0.9895591916224478, 0.693905883848372], 
             UndirectedEdge[128, 138] -> 
             RGBColor[
              0.9279463848657051, 0.744661987273314, 0.544777810600507], 
             UndirectedEdge[336, 436] -> 
             RGBColor[
              0.9822249724571132, 0.9851127802625153, 0.8634189577671202], 
             UndirectedEdge[196, 454] -> 
             RGBColor[
              0.9530660187834443, 0.9645172941728095, 0.9643311672435648], 
             UndirectedEdge[25, 164] -> 
             RGBColor[
              0.806494126946127, 0.8491780993778485, 0.9549900283162618], 
             UndirectedEdge[125, 282] -> 
             RGBColor[
              0.9883969637330476, 0.9889807138422047, 0.8185339033115306], 
             UndirectedEdge[9, 286] -> 
             RGBColor[
              0.9556273155706941, 0.965556254563346, 0.9241121781479806], 
             UndirectedEdge[421, 477] -> 
             RGBColor[
              0.889791633684836, 0.9149597122225508, 0.98935031441887], 
             UndirectedEdge[105, 484] -> 
             RGBColor[
              0.9384471450593792, 0.9503969059743259, 0.8590602109145999], 
             UndirectedEdge[299, 475] -> 
             RGBColor[
              0.985310571767277, 0.9614130548301231, 0.4568043122935488], 
             UndirectedEdge[247, 252] -> 
             RGBColor[
              0.8005942639101209, 0.8416818393377522, 0.847189519865954], 
             UndirectedEdge[261, 478] -> 
             RGBColor[
              0.9553715516312913, 0.8625865081937356, 0.5635227841106256], 
             UndirectedEdge[104, 303] -> 
             RGBColor[
              0.9709759270280773, 0.9103788858962789, 0.4376957838338863], 
             UndirectedEdge[32, 66] -> 
             RGBColor[
              0.9701218663656495, 0.9768356224653341, 0.9174623910693424], 
             UndirectedEdge[213, 454] -> 
             RGBColor[
              0.9569380133829435, 0.9674050214053066, 0.9577768903645413], 
             UndirectedEdge[129, 331] -> 
             RGBColor[
              0.6721485841679135, 0.73395966158458, 0.7878450375178387], 
             UndirectedEdge[245, 475] -> 
             RGBColor[
              0.8807647517213868, 0.8828216714161135, 0.6721291194054648], 
             UndirectedEdge[90, 148] -> 
             RGBColor[
              0.8821653963430143, 0.9060138436438716, 0.8573741668572452], 
             UndirectedEdge[195, 496] -> 
             RGBColor[
              0.8177726824212517, 0.8548541417346721, 0.7872291775768939], 
             UndirectedEdge[241, 371] -> 
             RGBColor[
              0.4944304028398141, 0.5985221732878385, 0.9538723927540707], 
             UndirectedEdge[13, 243] -> 
             RGBColor[
              0.9782959514748579, 0.9389010630821415, 0.5310022721462906], 
             UndirectedEdge[246, 384] -> 
             RGBColor[
              0.9898060796555245, 0.9900525662128256, 0.8186031713355417], 
             UndirectedEdge[22, 268] -> 
             RGBColor[
              0.851553663309327, 0.8802573975512382, 0.7103180240241912], 
             UndirectedEdge[69, 306] -> 
             RGBColor[
              0.9903019126270933, 0.9902576058888954, 0.8103859358220471], 
             UndirectedEdge[66, 128] -> 
             RGBColor[
              0.9116112898094233, 0.732829989983826, 0.5881334739635166], 
             UndirectedEdge[220, 413] -> 
             RGBColor[
              0.7118767461849018, 0.774842791674085, 0.971916879259437], 
             UndirectedEdge[319, 492] -> 
             RGBColor[
              0.840041688937909, 0.8756020114489776, 0.9692828910175615], 
             UndirectedEdge[61, 186] -> 
             RGBColor[
              0.9826707342973482, 0.9747096878832837, 0.660905782574283], 
             UndirectedEdge[94, 401] -> 
             RGBColor[
              0.9531839291839581, 0.9259072671143682, 0.6539041280068381], 
             UndirectedEdge[429, 488] -> 
             RGBColor[
              0.7096196565346073, 0.7491629455645412, 0.6624424078865665], 
             UndirectedEdge[11, 431] -> 
             RGBColor[
              0.92678682075547, 0.9394788718027185, 0.7273281071311213], 
             UndirectedEdge[349, 487] -> 
             RGBColor[
              0.8272091438442788, 0.8621762387680847, 0.7829377028437887], 
             UndirectedEdge[156, 198] -> 
             RGBColor[
              0.9663875471700492, 0.9709770319156235, 0.7297022059434085], 
             UndirectedEdge[12, 188] -> 
             RGBColor[
              0.9390947923213291, 0.9540975763531476, 0.9879808093644729], 
             UndirectedEdge[70, 111] -> 
             RGBColor[
              0.966407290680152, 0.9744671929090463, 0.9417478738834273], 
             UndirectedEdge[212, 286] -> 
             RGBColor[
              0.8650325382561916, 0.8953274246070626, 0.9869595942993473], 
             UndirectedEdge[242, 282] -> 
             RGBColor[
              0.9383463702656972, 0.9502547432958939, 0.8547758744243934], 
             UndirectedEdge[70, 175] -> 
             RGBColor[
              0.7624705935066816, 0.8139902072188918, 0.9638977547259691], 
             UndirectedEdge[188, 298] -> 
             RGBColor[
              0.9508578518326525, 0.9628704468764505, 0.9680690179090772], 
             UndirectedEdge[286, 367] -> 
             RGBColor[
              0.9570354149045845, 0.966138539824412, 0.9007763281411523], 
             UndirectedEdge[9, 492] -> 
             RGBColor[
              0.9700930151632318, 0.9766545972952723, 0.9103681349192119], 
             UndirectedEdge[37, 343] -> 
             RGBColor[
              0.9639123038384214, 0.9698610481862937, 0.7940436914272238], 
             UndirectedEdge[376, 391] -> 
             RGBColor[
              0.9513444527896127, 0.9632333530734154, 0.9672453294147991], 
             UndirectedEdge[230, 490] -> 
             RGBColor[
              0.9751047816730196, 0.9283230401738103, 0.5198945524953074], 
             UndirectedEdge[346, 355] -> 
             RGBColor[
              0.8194044581530529, 0.8595716036346457, 0.9718603992188833], 
             UndirectedEdge[30, 465] -> 
             RGBColor[
              0.9462235109285795, 0.9589054720562078, 0.9582771132438053], 
             UndirectedEdge[119, 124] -> 
             RGBColor[
              0.5211809715453017, 0.6170421862316539, 0.9574006243994708], 
             UndirectedEdge[301, 436] -> 
             RGBColor[
              0.9116443508559862, 0.9314141116157582, 0.9577915134944417], 
             UndirectedEdge[39, 108] -> 
             RGBColor[
              0.9858135686385638, 0.9634216766405268, 0.4322370390473591], 
             UndirectedEdge[98, 382] -> 
             RGBColor[
              0.9535129937211688, 0.9138443911718637, 0.6272189336332628], 
             UndirectedEdge[81, 208] -> 
             RGBColor[
              0.944357211548269, 0.8726710374243304, 0.6150265622605272], 
             UndirectedEdge[154, 203] -> 
             RGBColor[
              0.9677071872670013, 0.9719327883287759, 0.7252126790937943], 
             UndirectedEdge[145, 367] -> 
             RGBColor[
              0.9919586596762355, 0.9909427133701728, 0.7829293496938386], 
             UndirectedEdge[44, 132] -> 
             RGBColor[
              0.9694698826578952, 0.9051393988873693, 0.39319907433429635`], 
             UndirectedEdge[319, 357] -> 
             RGBColor[
              0.8606327233807588, 0.888081892899139, 0.7698415687880715], 
             UndirectedEdge[364, 378] -> 
             RGBColor[
              0.9836893863537881, 0.9685322421001892, 0.631012787659762], 
             UndirectedEdge[213, 251] -> 
             RGBColor[
              0.9703381014485902, 0.9750589042932809, 0.8131164172106713], 
             UndirectedEdge[73, 136] -> 
             RGBColor[
              0.984754764404582, 0.9855019271510053, 0.7642028124381804], 
             UndirectedEdge[441, 461] -> 
             RGBColor[
              0.9632081139259656, 0.9696861186656642, 0.8253133368706493], 
             UndirectedEdge[90, 480] -> 
             RGBColor[
              0.9623704315589027, 0.8761642791351432, 0.4998123089604919], 
             UndirectedEdge[118, 446] -> 
             RGBColor[
              0.9257809109745958, 0.9413098728451931, 0.9018260742608509], 
             UndirectedEdge[210, 480] -> 
             RGBColor[
              0.8106903571840296, 0.7595303879976372, 0.6162097502897294], 
             UndirectedEdge[95, 492] -> 
             RGBColor[
              0.9720367716420448, 0.9774583905515245, 0.8781550597847605], 
             UndirectedEdge[261, 328] -> 
             RGBColor[
              0.9634693301698516, 0.9718519885135155, 0.9277299838747216], 
             UndirectedEdge[152, 496] -> 
             RGBColor[
              0.8077933815099091, 0.8222359214489883, 0.6596613238870185], 
             UndirectedEdge[86, 177] -> 
             RGBColor[
              0.8764999999296572, 0.8996348047467245, 0.7039250744828682], 
             UndirectedEdge[45, 217] -> 
             RGBColor[
              0.9472713303653721, 0.9575495095195194, 0.864957996890742], 
             UndirectedEdge[306, 331] -> 
             RGBColor[
              0.9906093980927053, 0.9896264168763191, 0.750166636735663], 
             UndirectedEdge[103, 129] -> 
             RGBColor[
              0.672252557616025, 0.7341820502767626, 0.7991619056950425], 
             UndirectedEdge[50, 126] -> 
             RGBColor[
              0.8645562503372615, 0.8532398454507559, 0.6458058634684232], 
             UndirectedEdge[172, 308] -> 
             RGBColor[
              0.7498331403978897, 0.6829197793848223, 0.604469344514523], 
             UndirectedEdge[112, 266] -> 
             RGBColor[
              0.7778579654374765, 0.8263878216300358, 0.9784932705649829], 
             UndirectedEdge[129, 275] -> 
             RGBColor[
              0.6701214707702874, 0.7338797402548464, 0.8765630216921284], 
             UndirectedEdge[297, 325] -> 
             RGBColor[
              0.8304228135380747, 0.86634312182549, 0.8862694413174064], 
             UndirectedEdge[202, 396] -> 
             RGBColor[
              0.888042413575577, 0.912267759894934, 0.9333558839846189], 
             UndirectedEdge[167, 236] -> 
             RGBColor[
              0.9020504967706848, 0.9235981262489307, 0.9511174252001355], 
             UndirectedEdge[184, 301] -> 
             RGBColor[
              0.7240575006576584, 0.7839236249685113, 0.9735296192097712], 
             UndirectedEdge[78, 258] -> 
             RGBColor[
              0.9923646392610284, 0.9903876925327808, 0.7236537403318417], 
             UndirectedEdge[172, 470] -> 
             RGBColor[
              0.9531862468023884, 0.8408799677921461, 0.4979418841315524], 
             UndirectedEdge[72, 159] -> 
             RGBColor[
              0.9608673973891588, 0.9464221761505489, 0.6722829091986504], 
             UndirectedEdge[304, 337] -> 
             RGBColor[
              0.9538056347818127, 0.8481646045880711, 0.3150056576771796], 
             UndirectedEdge[88, 271] -> 
             RGBColor[
              0.9756556833013112, 0.9295430448372477, 0.3599273559743963], 
             UndirectedEdge[392, 413] -> 
             RGBColor[
              0.8106454541657877, 0.852372204847647, 0.9816628890244271], 
             UndirectedEdge[187, 216] -> 
             RGBColor[
              0.9706732709236376, 0.9771236199680581, 0.9110101076746102], 
             UndirectedEdge[33, 432] -> 
             RGBColor[
              0.9515166489735709, 0.8823646602744473, 0.6062856557855613], 
             UndirectedEdge[36, 75] -> 
             RGBColor[
              0.9856580249553277, 0.9864531793990043, 0.784700359932695], 
             UndirectedEdge[243, 335] -> 
             RGBColor[
              0.9772971692176502, 0.9809896604209335, 0.8516993304738163], 
             UndirectedEdge[323, 499] -> 
             RGBColor[
              0.9210076989086855, 0.9355990620464917, 0.7858156639792231], 
             UndirectedEdge[168, 480] -> 
             RGBColor[
              0.9589126895872653, 0.8747344139699557, 0.5571160417799004], 
             UndirectedEdge[301, 388] -> 
             RGBColor[
              0.5827013791316754, 0.6654207190141541, 0.9634359259845977], 
             UndirectedEdge[111, 371] -> 
             RGBColor[
              0.6823551584039561, 0.7459999434497908, 0.9304619932143678], 
             UndirectedEdge[103, 231] -> 
             RGBColor[
              0.9928389365222041, 0.9907277813128337, 0.7262573923854412], 
             UndirectedEdge[99, 131] -> 
             RGBColor[
              0.9143756940638288, 0.9333316404219598, 0.949024835682653], 
             UndirectedEdge[193, 428] -> 
             RGBColor[
              0.9928412887091947, 0.990435944997186, 0.7049342869149474], 
             UndirectedEdge[189, 370] -> 
             RGBColor[
              0.984390923595705, 0.9854532180854456, 0.782484455028696], 
             UndirectedEdge[45, 187] -> 
             RGBColor[
              0.9909631732343558, 0.9905310541436209, 0.799427136272115], 
             UndirectedEdge[346, 443] -> 
             RGBColor[
              0.9661114647986576, 0.9741490034640881, 0.9378795600503512], 
             UndirectedEdge[19, 318] -> 
             RGBColor[
              0.5414591596886222, 0.6358157459850022, 0.9581807673216618], 
             UndirectedEdge[5, 129] -> 
             RGBColor[
              0.667110878955758, 0.732634783170858, 0.9264563192207433], 
             UndirectedEdge[29, 46] -> 
             RGBColor[
              0.8882042066534792, 0.8599596044768907, 0.6327602099791663], 
             UndirectedEdge[227, 263] -> 
             RGBColor[
              0.9935803366639873, 0.9916133184798057, 0.7560539652412792], 
             UndirectedEdge[272, 435] -> 
             RGBColor[
              0.9497939135835707, 0.939091597263388, 0.6810170882860576], 
             UndirectedEdge[208, 483] -> 
             RGBColor[
              0.9181717729011554, 0.9371274006149253, 0.9760441135886102], 
             UndirectedEdge[244, 475] -> 
             RGBColor[
              0.9811567055016226, 0.9611167817990303, 0.6289695748887817], 
             UndirectedEdge[350, 412] -> 
             RGBColor[
              0.9491293483454395, 0.9314750999194739, 0.6705283979430166], 
             UndirectedEdge[217, 398] -> 
             RGBColor[
              0.9234341364809802, 0.9414965110964676, 0.9825456076456509], 
             UndirectedEdge[370, 451] -> 
             RGBColor[
              0.8851431086857972, 0.90766887499567, 0.8074688510758132], 
             UndirectedEdge[265, 424] -> 
             RGBColor[
              0.8623448292849366, 0.8887002724118473, 0.7124135139174386], 
             UndirectedEdge[28, 419] -> 
             RGBColor[
              0.9939213703509738, 0.9894067507614928, 0.5797568595363453], 
             UndirectedEdge[67, 381] -> 
             RGBColor[
              0.81211338380121, 0.8509628607423811, 0.8444171999589154], 
             UndirectedEdge[239, 435] -> 
             RGBColor[
              0.9568459658475779, 0.9628798254504982, 0.7084129796634], 
             UndirectedEdge[302, 370] -> 
             RGBColor[
              0.9935486848366666, 0.9886096141306752, 0.539192341252393], 
             UndirectedEdge[2, 66] -> 
             RGBColor[
              0.9688729802736974, 0.9615062263983685, 0.6780777805246707], 
             UndirectedEdge[36, 408] -> 
             RGBColor[
              0.9504599968608469, 0.9622753141194396, 0.9583963106489727], 
             UndirectedEdge[76, 483] -> 
             RGBColor[
              0.9231460512585299, 0.9408372092692219, 0.9676239578291514], 
             UndirectedEdge[9, 367] -> 
             RGBColor[
              0.9889792692720758, 0.9897106588712119, 0.8323055591059694], 
             UndirectedEdge[133, 469] -> 
             RGBColor[
              0.9918704926020716, 0.9909062540192155, 0.7843905062818095], 
             UndirectedEdge[46, 297] -> 
             RGBColor[
              0.972850125264441, 0.9249658510942913, 0.5437368489649241], 
             UndirectedEdge[159, 435] -> 
             RGBColor[
              0.93299190500686, 0.9491779691845681, 0.9855497092181198], 
             UndirectedEdge[126, 340] -> 
             RGBColor[
              0.970750797178533, 0.9363938060757666, 0.6186172719799726], 
             UndirectedEdge[27, 290] -> 
             RGBColor[
              0.7982783786176033, 0.842613531538552, 0.9547262133232446], 
             UndirectedEdge[326, 338] -> 
             RGBColor[
              0.9513697757826816, 0.9599697643521359, 0.8017471109348311], 
             UndirectedEdge[179, 438] -> 
             RGBColor[
              0.5888721226964031, 0.6607838340175543, 0.9604468454300248], 
             UndirectedEdge[138, 339] -> 
             RGBColor[
              0.9901964968868171, 0.9902140137712303, 0.812132947445615], 
             UndirectedEdge[475, 482] -> 
             RGBColor[
              0.9377671981914211, 0.9279874157015389, 0.6776420811108339], 
             UndirectedEdge[94, 428] -> 
             RGBColor[
              0.9673586163410823, 0.9726303632837685, 0.8017793095769411], 
             UndirectedEdge[186, 295] -> 
             RGBColor[
              0.9055315478247514, 0.92639340269612, 0.9521283305313484], 
             UndirectedEdge[348, 372] -> 
             RGBColor[
              0.9898660326696394, 0.9761615822796259, 0.5270611875222724], 
             UndirectedEdge[293, 343] -> 
             RGBColor[
              0.9153885787818168, 0.9353700214323181, 0.9917917738928826], 
             UndirectedEdge[385, 446] -> 
             RGBColor[
              0.9444423849592971, 0.9561900256483769, 0.9036060223088063], 
             UndirectedEdge[7, 288] -> 
             RGBColor[
              0.8543652078316191, 0.8869976089752145, 0.9858954234189116], 
             UndirectedEdge[242, 323] -> 
             RGBColor[
              0.9377274517078665, 0.9489309390829592, 0.7874104089271085], 
             UndirectedEdge[464, 481] -> 
             RGBColor[
              0.8396514291247766, 0.8740233205726711, 0.9085343467695368], 
             UndirectedEdge[42, 108] -> 
             RGBColor[
              0.9941817642017419, 0.9900045949607075, 0.611071255172997], 
             UndirectedEdge[101, 276] -> 
             RGBColor[
              0.5984445946188878, 0.6667166056806522, 0.9373286408399372], 
             UndirectedEdge[86, 426] -> 
             RGBColor[
              0.8454567341482654, 0.8753835695807428, 0.7008309718655916], 
             UndirectedEdge[37, 324] -> 
             RGBColor[
              0.9725158804195018, 0.9763273923263212, 0.78120705260054], 
             UndirectedEdge[290, 297] -> 
             RGBColor[
              0.8114330094968554, 0.8513529112870946, 0.8844828476035741], 
             UndirectedEdge[315, 380] -> 
             RGBColor[
              0.9482017942081569, 0.8382297555338822, 0.5776648771094071], 
             UndirectedEdge[181, 390] -> 
             RGBColor[
              0.9810275934332047, 0.9470411804623515, 0.4337358056109629], 
             UndirectedEdge[283, 421] -> 
             RGBColor[
              0.7710504616963709, 0.8214820284840392, 0.9777053556394596], 
             UndirectedEdge[97, 355] -> 
             RGBColor[
              0.5457434912631045, 0.6399030616100515, 0.9582944326423428], 
             UndirectedEdge[192, 219] -> 
             RGBColor[
              0.9938351494948026, 0.9892223330684082, 0.5703722514355449], 
             UndirectedEdge[171, 192] -> 
             RGBColor[
              0.9751773654382312, 0.9775823614375898, 0.7187824855698205], 
             UndirectedEdge[122, 216] -> 
             RGBColor[
              0.8741962833953252, 0.90225942875106, 0.9714513970540342], 
             UndirectedEdge[18, 28] -> 
             RGBColor[
              0.9550047966464441, 0.9635281886290291, 0.8555921009736529], 
             UndirectedEdge[178, 288] -> 
             RGBColor[
              0.8894270852949654, 0.9117740086191419, 0.8620555162556114], 
             UndirectedEdge[165, 185] -> 
             RGBColor[
              0.9365530174606269, 0.9519294899614311, 0.9828378835017682], 
             UndirectedEdge[264, 281] -> 
             RGBColor[
              0.9728476065132524, 0.9792703699123232, 0.9308460990813758], 
             UndirectedEdge[80, 192] -> 
             RGBColor[
              0.9004819783041884, 0.9186777187878865, 0.7309854277166312], 
             UndirectedEdge[74, 402] -> 
             RGBColor[
              0.9697579129106889, 0.9740758356677177, 0.7704294191842326], 
             UndirectedEdge[3, 158] -> 
             RGBColor[
              0.9917857662572152, 0.9892345702939163, 0.6668276666520052], 
             UndirectedEdge[426, 476] -> 
             RGBColor[
              0.8324205509782832, 0.8694027877038419, 0.9560944546209449], 
             UndirectedEdge[27, 177] -> 
             RGBColor[
              0.8623878357704946, 0.8928515580098499, 0.9610099123921172], 
             UndirectedEdge[355, 443] -> 
             RGBColor[
              0.8380722398993725, 0.8733964417084534, 0.9358916441729159], 
             UndirectedEdge[21, 256] -> 
             RGBColor[
              0.9873263809026646, 0.9890271470531669, 0.8596981969250928], 
             UndirectedEdge[331, 404] -> 
             RGBColor[
              0.908117352361429, 0.5796253975971287, 0.40035678169163774`], 
             UndirectedEdge[142, 285] -> 
             RGBColor[
              0.9788492431256978, 0.9821410580192071, 0.8487972655555425], 
             UndirectedEdge[232, 267] -> 
             RGBColor[
              0.971661647639304, 0.9783549095114845, 0.9314665294990291], 
             UndirectedEdge[133, 488] -> 
             RGBColor[
              0.7162603204366604, 0.7732460362150009, 0.8575653378651645], 
             UndirectedEdge[148, 393] -> 
             RGBColor[
              0.8786791674372585, 0.9045721983993454, 0.9151500018968183], 
             UndirectedEdge[84, 89] -> 
             RGBColor[
              0.9745243315251053, 0.9297689180361777, 0.5411670531964766], 
             UndirectedEdge[27, 350] -> 
             RGBColor[
              0.9684957911584258, 0.946179030341365, 0.6467766884076986], 
             UndirectedEdge[8, 435] -> 
             RGBColor[
              0.5501760650525347, 0.6227887017998295, 0.9629342727734937], 
             UndirectedEdge[20, 220] -> 
             RGBColor[
              0.724242643071443, 0.7845031243061482, 0.9731493962952108], 
             UndirectedEdge[35, 422] -> 
             RGBColor[
              0.8566624400013254, 0.886403577512151, 0.8690176370871101], 
             UndirectedEdge[65, 177] -> 
             RGBColor[
              0.869775975766155, 0.8769855061082863, 0.6750472797658544], 
             UndirectedEdge[93, 160] -> 
             RGBColor[
              0.9910249025098847, 0.9900097305902452, 0.7586538860811276], 
             UndirectedEdge[277, 373] -> 
             RGBColor[
              0.9713736335435215, 0.9129306546176577, 0.3803207891221114], 
             UndirectedEdge[15, 126] -> 
             RGBColor[
              0.9657437856091617, 0.8961078864973744, 0.321421505145214], 
             UndirectedEdge[95, 367] -> 
             RGBColor[
              0.9909230257508889, 0.990514452127464, 0.800092483971518], 
             UndirectedEdge[304, 465] -> 
             RGBColor[
              0.9532449790564421, 0.871108509049049, 0.5936268853135127], 
             UndirectedEdge[218, 305] -> 
             RGBColor[
              0.9905787787626419, 0.9798821499377592, 0.41790076385155406`], 
             UndirectedEdge[137, 265] -> 
             RGBColor[
              0.8276651689207676, 0.7622265869654218, 0.6155621788423908], 
             UndirectedEdge[325, 392] -> 
             RGBColor[
              0.768017071971826, 0.8190705886900199, 0.9774140902722137], 
             UndirectedEdge[263, 393] -> 
             RGBColor[
              0.9903883165708123, 0.9902933361401033, 0.808953998868387], 
             UndirectedEdge[228, 335] -> 
             RGBColor[
              0.9088374451250016, 0.7043093257852318, 0.5766991782975917], 
             UndirectedEdge[104, 408] -> 
             RGBColor[
              0.9591101687065803, 0.9660562681445113, 0.7955564821284942], 
             UndirectedEdge[145, 375] -> 
             RGBColor[
              0.9933601886660762, 0.9897179092826394, 0.6285435659155745], 
             UndirectedEdge[181, 451] -> 
             RGBColor[
              0.884676976193508, 0.9066718647278877, 0.7567332059264216], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.6094046885186735, 0.6816423643931149, 0.9574750019667715], 
             UndirectedEdge[387, 439] -> 
             RGBColor[
              0.726506228727098, 0.786271454624234, 0.9733750093589559], 
             UndirectedEdge[163, 231] -> 
             RGBColor[
              0.9732201958567842, 0.9784060635958833, 0.8790661213724569], 
             UndirectedEdge[143, 288] -> 
             RGBColor[
              0.8868320811349317, 0.903209286328448, 0.6955843133485164], 
             UndirectedEdge[128, 312] -> 
             RGBColor[
              0.8490862637986251, 0.6834366913005211, 0.5982035548608677], 
             UndirectedEdge[270, 479] -> 
             RGBColor[
              0.6113436784369024, 0.6832391862755567, 0.9550567161967962], 
             UndirectedEdge[119, 120] -> 
             RGBColor[
              0.6498726225554212, 0.7173043489297186, 0.9106733486143419], 
             UndirectedEdge[105, 462] -> 
             RGBColor[
              0.9249224140631305, 0.9421357183866164, 0.9637052238465584], 
             UndirectedEdge[14, 159] -> 
             RGBColor[
              0.8508032445219283, 0.8841516520665669, 0.9775754907779961], 
             UndirectedEdge[58, 417] -> 
             RGBColor[
              0.800509586639877, 0.844299378195538, 0.9515344782351551], 
             UndirectedEdge[66, 299] -> 
             RGBColor[
              0.9736334778420206, 0.976866306635863, 0.7559409524346485], 
             UndirectedEdge[11, 348] -> 
             RGBColor[
              0.9228872601447913, 0.9265668947235062, 0.6915878079132696], 
             UndirectedEdge[4, 31] -> 
             RGBColor[
              0.5951888670661574, 0.6583840370819004, 0.8580392539438924], 
             UndirectedEdge[259, 400] -> 
             RGBColor[
              0.9496748797820858, 0.8542572953547742, 0.5886618604272715], 
             UndirectedEdge[247, 451] -> 
             RGBColor[
              0.691006709930464, 0.7579846103188834, 0.9702157614935503], 
             UndirectedEdge[17, 261] -> 
             RGBColor[
              0.9487057546815343, 0.9601958296034101, 0.9303406818564384], 
             UndirectedEdge[361, 386] -> 
             RGBColor[
              0.8924664578406389, 0.8752248817470465, 0.6488402345073363], 
             UndirectedEdge[212, 492] -> 
             RGBColor[
              0.8794982378487293, 0.9064257673389888, 0.9732155510705787], 
             UndirectedEdge[287, 388] -> 
             RGBColor[
              0.6549769778662252, 0.7191554199411984, 0.792643141267459], 
             UndirectedEdge[383, 480] -> 
             RGBColor[
              0.8743971703068218, 0.8092986345988751, 0.6225594500477922], 
             UndirectedEdge[403, 440] -> 
             RGBColor[
              0.715780581234646, 0.7769760130046234, 0.9731404949380889], 
             UndirectedEdge[13, 354] -> 
             RGBColor[
              0.9744521036676679, 0.9373115332314855, 0.5947047778706795], 
             UndirectedEdge[1, 42] -> 
             RGBColor[
              0.990780202375168, 0.9904553909912102, 0.8024594369222605], 
             UndirectedEdge[161, 188] -> 
             RGBColor[
              0.961600436363713, 0.9705544620907236, 0.9352056645048445], 
             UndirectedEdge[194, 426] -> 
             RGBColor[
              0.8354111668085873, 0.8415299258736381, 0.6590496091299316], 
             UndirectedEdge[257, 324] -> 
             RGBColor[
              0.8841467733331241, 0.5485422388461378, 0.5660447419973436], 
             UndirectedEdge[198, 479] -> 
             RGBColor[
              0.9709682074339565, 0.9743932808403026, 0.7219483429441489], 
             UndirectedEdge[372, 431] -> 
             RGBColor[
              0.9937655932803182, 0.9890735593588382, 0.5628014867401241], 
             UndirectedEdge[107, 466] -> 
             RGBColor[
              0.9433003737928098, 0.9572340921285705, 0.9808618569245748], 
             UndirectedEdge[122, 330] -> 
             RGBColor[
              0.8672943236556624, 0.8971119584781413, 0.9831346145738816], 
             UndirectedEdge[4, 472] -> 
             RGBColor[
              0.98476271640783, 0.9868517101269723, 0.8522395286947176], 
             UndirectedEdge[145, 458] -> 
             RGBColor[
              0.9937805353052157, 0.9906169882401943, 0.6742957035071493], 
             UndirectedEdge[3, 451] -> 
             RGBColor[
              0.8846135169528184, 0.9065361318287664, 0.7498260592024081], 
             UndirectedEdge[146, 239] -> 
             RGBColor[
              0.9846866144634923, 0.9840114194053783, 0.6740477200425612], 
             UndirectedEdge[15, 282] -> 
             RGBColor[
              0.9813874172462091, 0.9472013070012154, 0.5247279057472898], 
             UndirectedEdge[82, 126] -> 
             RGBColor[
              0.7017331623152909, 0.7225599487258851, 0.6318048670839893], 
             UndirectedEdge[413, 474] -> 
             RGBColor[
              0.8714750757172126, 0.8989929718525507, 0.9166386275830969], 
             UndirectedEdge[160, 235] -> 
             RGBColor[
              0.9923577403132087, 0.9845591130791977, 0.5373859036726695], 
             UndirectedEdge[161, 183] -> 
             RGBColor[
              0.6856082512786374, 0.748240438977752, 0.9123507137726052], 
             UndirectedEdge[366, 429] -> 
             RGBColor[
              0.8746550631589223, 0.8815711223958077, 0.6766639075139893], 
             UndirectedEdge[7, 313] -> 
             RGBColor[
              0.8599580151086701, 0.8913667525269564, 0.9864528621805324], 
             UndirectedEdge[129, 444] -> 
             RGBColor[
              0.6551660568332962, 0.7237488729181611, 0.9476842130745977], 
             UndirectedEdge[18, 493] -> 
             RGBColor[
              0.9440409906827688, 0.928212148911682, 0.6712116841356551], 
             UndirectedEdge[149, 411] -> 
             RGBColor[
              0.9018094590041219, 0.9245423999169711, 0.9904965853262627], 
             UndirectedEdge[221, 301] -> 
             RGBColor[
              0.9211638644966436, 0.9371554784447105, 0.880851315879778], 
             UndirectedEdge[45, 496] -> 
             RGBColor[
              0.8179618786730491, 0.8558700402534891, 0.8522517627857437], 
             UndirectedEdge[478, 482] -> 
             RGBColor[
              0.9112730270444394, 0.8291639452314365, 0.6239455414846673], 
             UndirectedEdge[69, 331] -> 
             RGBColor[
              0.9940954674262908, 0.9910679961336522, 0.6923934462199128], 
             UndirectedEdge[16, 143] -> 
             RGBColor[
              0.9784141580211843, 0.9751214181453299, 0.6757240451328076], 
             UndirectedEdge[210, 280] -> 
             RGBColor[
              0.7783020455051214, 0.8271005185218174, 0.9784404660368745], 
             UndirectedEdge[101, 390] -> 
             RGBColor[
              0.9684834116154337, 0.9407612584266491, 0.635316338465219], 
             UndirectedEdge[400, 418] -> 
             RGBColor[
              0.826897934799969, 0.7581593137749962, 0.6147177671385748], 
             UndirectedEdge[84, 299] -> 
             RGBColor[
              0.9756457007973292, 0.928811175628869, 0.41925811363303817`], 
             UndirectedEdge[333, 386] -> 
             RGBColor[
              0.8941985625935518, 0.8766060150602881, 0.6490054442049373], 
             UndirectedEdge[244, 341] -> 
             RGBColor[
              0.9213608877203647, 0.9386639292110457, 0.9395503818874147], 
             UndirectedEdge[143, 373] -> 
             RGBColor[
              0.9693912349452543, 0.9065659804770774, 0.3452031205776615], 
             UndirectedEdge[160, 284] -> 
             RGBColor[
              0.9737746245525845, 0.9776777488364483, 0.8117340107423311], 
             UndirectedEdge[281, 343] -> 
             RGBColor[
              0.9503150041817892, 0.9624157811743466, 0.9672609452317131], 
             UndirectedEdge[207, 445] -> 
             RGBColor[
              0.5914160446643287, 0.6729862427739809, 0.9639832441152931], 
             UndirectedEdge[260, 334] -> 
             RGBColor[
              0.9449958799936948, 0.9563264532320515, 0.8904183821041358], 
             UndirectedEdge[66, 114] -> 
             RGBColor[
              0.9649035032588247, 0.9733456707124462, 0.9442933937371605], 
             UndirectedEdge[364, 381] -> 
             RGBColor[
              0.9882724700915883, 0.9704040620215499, 0.5533580795943545], 
             UndirectedEdge[204, 306] -> 
             RGBColor[
              0.9600734363175589, 0.9692464355527067, 0.9308311335912438], 
             UndirectedEdge[358, 361] -> 
             RGBColor[
              0.9031506734619644, 0.9241228631721934, 0.9369130687286134], 
             UndirectedEdge[294, 415] -> 
             RGBColor[
              0.9482223211778502, 0.9586118082869255, 0.8782496285541849], 
             UndirectedEdge[2, 255] -> 
             RGBColor[
              0.9707677889125612, 0.9130550293318136, 0.34093880927550557`], 
             UndirectedEdge[326, 443] -> 
             RGBColor[
              0.9466489541383811, 0.9589329887967245, 0.9465236600380935], 
             UndirectedEdge[58, 145] -> 
             RGBColor[
              0.8132080603048905, 0.8522185061784704, 0.8605656272000266], 
             UndirectedEdge[103, 346] -> 
             RGBColor[
              0.971027291420232, 0.9756028749478607, 0.8143280992921276], 
             UndirectedEdge[62, 108] -> 
             RGBColor[
              0.9108557691963488, 0.926932545346697, 0.7385080879024772], 
             UndirectedEdge[91, 336] -> 
             RGBColor[
              0.9203705443098239, 0.936762102354453, 0.8911623597886953], 
             UndirectedEdge[338, 395] -> 
             RGBColor[
              0.7475310586312993, 0.7978459447862978, 0.7831024546721947], 
             UndirectedEdge[19, 335] -> 
             RGBColor[
              0.6717330820385348, 0.7380780162885134, 0.9484423978198154], 
             UndirectedEdge[2, 195] -> 
             RGBColor[
              0.9891541933501233, 0.9740323838932168, 0.5011666726164594], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.9918492254979048, 0.9893703031930376, 0.6737348133760187], 
             UndirectedEdge[150, 325] -> 
             RGBColor[
              0.8081886848059151, 0.7832931837649745, 0.6216552678520533], 
             UndirectedEdge[208, 238] -> 
             RGBColor[
              0.9742040414676626, 0.978519869573353, 0.8496383474734066], 
             UndirectedEdge[318, 335] -> 
             RGBColor[
              0.8305026704556263, 0.8680055573500702, 0.9610175461657879], 
             UndirectedEdge[12, 421] -> 
             RGBColor[
              0.906072969094267, 0.927801345169766, 0.9860264041598541], 
             UndirectedEdge[102, 278] -> 
             RGBColor[
              0.9826237381144992, 0.983826707342811, 0.7609939778183846], 
             UndirectedEdge[5, 209] -> 
             RGBColor[
              0.9074986774320843, 0.9278023135200058, 0.9465539664325304], 
             UndirectedEdge[76, 463] -> 
             RGBColor[
              0.978759887289002, 0.9820566456207733, 0.848152701704741], 
             UndirectedEdge[293, 445] -> 
             RGBColor[
              0.6151926890553261, 0.6919450936115433, 0.9662510816829675], 
             UndirectedEdge[48, 250] -> 
             RGBColor[
              0.7159597138888765, 0.7767801679617421, 0.9735473958822207], 
             UndirectedEdge[459, 477] -> 
             RGBColor[
              0.9411457489454038, 0.9264487299440016, 0.6717375472184883], 
             UndirectedEdge[400, 404] -> 
             RGBColor[
              0.8715156576167571, 0.44705177309642674`, 0.21199646958035634`],
              UndirectedEdge[144, 246] -> 
             RGBColor[
              0.9916670349663315, 0.9908221190582143, 0.7877623258375049], 
             UndirectedEdge[90, 393] -> 
             RGBColor[
              0.991239153097758, 0.9906451789094968, 0.7948534357225463], 
             UndirectedEdge[157, 360] -> 
             RGBColor[
              0.8713751999391739, 0.9001943279289448, 0.9781937714794127], 
             UndirectedEdge[156, 250] -> 
             RGBColor[
              0.9342369066626593, 0.9502924463839624, 0.9898894921926609], 
             UndirectedEdge[25, 220] -> 
             RGBColor[
              0.8165618301160521, 0.8570430656115721, 0.9559934828802046], 
             UndirectedEdge[261, 407] -> 
             RGBColor[
              0.9840379004758026, 0.968737244089183, 0.6256578239103562], 
             UndirectedEdge[42, 364] -> 
             RGBColor[
              0.9882623359951941, 0.9704232742963557, 0.5552271776873541], 
             UndirectedEdge[83, 257] -> 
             RGBColor[
              0.7879596664896293, 0.47273530639512423`, 0.5703959248671775], 
             UndirectedEdge[137, 263] -> 
             RGBColor[
              0.9582009870612278, 0.8626552616223588, 0.5112426422353433], 
             UndirectedEdge[27, 65] -> 
             RGBColor[
              0.9717193318062687, 0.9570527898698769, 0.6592995351099961], 
             UndirectedEdge[318, 421] -> 
             RGBColor[
              0.785610487921548, 0.8328564316314452, 0.9791565629824042], 
             UndirectedEdge[203, 341] -> 
             RGBColor[
              0.9251460078032461, 0.9381714914431447, 0.7272493729349767], 
             UndirectedEdge[80, 483] -> 
             RGBColor[
              0.8453443433471852, 0.8796158776699403, 0.9850850907937212], 
             UndirectedEdge[95, 319] -> 
             RGBColor[
              0.8594636001916756, 0.8888795810201034, 0.8823430900766959], 
             UndirectedEdge[84, 376] -> 
             RGBColor[
              0.950414698080805, 0.9129840999415697, 0.6355424914078733], 
             UndirectedEdge[260, 446] -> 
             RGBColor[
              0.9906980708818547, 0.9904214275080421, 0.8038205683159525], 
             UndirectedEdge[174, 393] -> 
             RGBColor[
              0.9706599694570701, 0.977047234894276, 0.9080561912810718], 
             UndirectedEdge[185, 216] -> 
             RGBColor[
              0.9509827139452711, 0.9629635688355985, 0.9678576589216683], 
             UndirectedEdge[143, 321] -> 
             RGBColor[
              0.9906549203677664, 0.9829119622795937, 0.5950585465100062], 
             UndirectedEdge[296, 415] -> 
             RGBColor[
              0.9918722194654115, 0.990906968121585, 0.7843618876872889], 
             UndirectedEdge[42, 113] -> 
             RGBColor[
              0.9697090993717843, 0.9750950987380476, 0.8540026359322499], 
             UndirectedEdge[54, 264] -> 
             RGBColor[
              0.9815291548615062, 0.9857394537414634, 0.9158996908108874], 
             UndirectedEdge[9, 95] -> 
             RGBColor[
              0.9895149264169985, 0.9899321668663981, 0.8234283339783462], 
             UndirectedEdge[47, 55] -> 
             RGBColor[
              0.9516098012066048, 0.9616433460564857, 0.8929221459045159], 
             UndirectedEdge[212, 330] -> 
             RGBColor[
              0.8732856878285717, 0.9017924577060724, 0.9837317777621557], 
             UndirectedEdge[89, 244] -> 
             RGBColor[
              0.9883590543538848, 0.9894541840637436, 0.8425841253651498], 
             UndirectedEdge[3, 247] -> 
             RGBColor[
              0.7997780414304518, 0.8397076631621146, 0.74174946424131], 
             UndirectedEdge[26, 318] -> 
             RGBColor[
              0.8445637628782855, 0.8777103302819282, 0.9021977146214157], 
             UndirectedEdge[46, 426] -> 
             RGBColor[
              0.8267088725636833, 0.8119079524181766, 0.6266338567231762], 
             UndirectedEdge[102, 247] -> 
             RGBColor[
              0.800086151153041, 0.8403666787040613, 0.7752853061123426], 
             UndirectedEdge[285, 287] -> 
             RGBColor[
              0.979177544981161, 0.9816119349501055, 0.7950263827637578], 
             UndirectedEdge[346, 390] -> 
             RGBColor[
              0.957993551492281, 0.9329379379223715, 0.6530729354600248], 
             UndirectedEdge[388, 473] -> 
             RGBColor[
              0.654711792952513, 0.7185882162250756, 0.763779399941477], 
             UndirectedEdge[377, 412] -> 
             RGBColor[
              0.960403005781681, 0.9678345361225461, 0.8562660378872506], 
             UndirectedEdge[7, 321] -> 
             RGBColor[
              0.9581880470644536, 0.9667002849263603, 0.8853696565804012], 
             UndirectedEdge[209, 275] -> 
             RGBColor[
              0.9105092692466137, 0.9290472706039942, 0.8966606689039155], 
             UndirectedEdge[204, 346] -> 
             RGBColor[
              0.940387356196974, 0.9550005049320656, 0.9836757279705045], 
             UndirectedEdge[220, 297] -> 
             RGBColor[
              0.8294660040219779, 0.8655956549594935, 0.8861740754867351], 
             UndirectedEdge[16, 185] -> 
             RGBColor[
              0.9578697198949677, 0.968099886596445, 0.9561997542676608], 
             UndirectedEdge[323, 449] -> 
             RGBColor[
              0.8991678215461751, 0.918310864178217, 0.7836990335419862], 
             UndirectedEdge[224, 481] -> 
             RGBColor[
              0.6428566661051858, 0.7097503657673598, 0.8937357733293199], 
             UndirectedEdge[86, 476] -> 
             RGBColor[
              0.9795193369589514, 0.9805045533682886, 0.6863559746731143], 
             UndirectedEdge[66, 385] -> 
             RGBColor[
              0.9263068643748991, 0.9436135061341873, 0.9767993960246086], 
             UndirectedEdge[184, 316] -> 
             RGBColor[
              0.6869985489381413, 0.7547306046597209, 0.9699002243778572], 
             UndirectedEdge[308, 362] -> 
             RGBColor[
              0.726606447748205, 0.785878146281112, 0.9738624474634523], 
             UndirectedEdge[216, 361] -> 
             RGBColor[
              0.8874302145159187, 0.9126050112572608, 0.9727685382381275], 
             UndirectedEdge[123, 410] -> 
             RGBColor[
              0.913695605163441, 0.9315676837031719, 0.8960837540575517], 
             UndirectedEdge[174, 225] -> 
             RGBColor[
              0.9732627590330163, 0.9761191058588601, 0.7192189198710938], 
             UndirectedEdge[3, 139] -> 
             RGBColor[
              0.9929633525673551, 0.9873576475927883, 0.4754825359898731], 
             UndirectedEdge[226, 472] -> 
             RGBColor[
              0.9828020245642407, 0.977164978192231, 0.665687801770591], 
             UndirectedEdge[9, 441] -> 
             RGBColor[
              0.9911023507587285, 0.9900291826142115, 0.7564563116998679], 
             UndirectedEdge[253, 354] -> 
             RGBColor[
              0.985717499618785, 0.9883618332959196, 0.8863615234502717], 
             UndirectedEdge[47, 73] -> 
             RGBColor[
              0.9436685169941281, 0.956896280421248, 0.9590073543099058], 
             UndirectedEdge[305, 432] -> 
             RGBColor[
              0.9649535820728403, 0.8880742805401122, 0.34630868155474104`], 
             UndirectedEdge[4, 226] -> 
             RGBColor[
              0.9900858768742402, 0.98129233408329, 0.5949207424491932], 
             UndirectedEdge[112, 359] -> 
             RGBColor[
              0.7688163424038046, 0.819324436997251, 0.9775920860797576], 
             UndirectedEdge[101, 204] -> 
             RGBColor[
              0.9508772163201267, 0.9628238254363435, 0.9659191309756987], 
             UndirectedEdge[256, 409] -> 
             RGBColor[
              0.8548378418226275, 0.8856490592752251, 0.8992559508168576], 
             UndirectedEdge[64, 268] -> 
             RGBColor[
              0.9718295690424532, 0.9748832889151926, 0.7083984701472459], 
             UndirectedEdge[97, 395] -> 
             RGBColor[
              0.4504814883507307, 0.5633157891324845, 0.9502817922448841], 
             UndirectedEdge[117, 156] -> 
             RGBColor[
              0.7569924169958517, 0.8099045921468058, 0.9731708786215411], 
             UndirectedEdge[48, 117] -> 
             RGBColor[
              0.538715224222069, 0.6363923137245855, 0.9568287823111009], 
             UndirectedEdge[5, 103] -> 
             RGBColor[
              0.9894692211278591, 0.9893343173995365, 0.7821022970136373], 
             UndirectedEdge[344, 438] -> 
             RGBColor[
              0.9402473523631382, 0.9549571537451851, 0.9860298258494924], 
             UndirectedEdge[42, 381] -> 
             RGBColor[
              0.9952447378778619, 0.9922781881708039, 0.7267693799055607], 
             UndirectedEdge[224, 398] -> 
             RGBColor[
              0.6222662631076974, 0.6950399988147624, 0.957515656662766], 
             UndirectedEdge[226, 405] -> 
             RGBColor[
              0.9810533473802722, 0.9758608176116235, 0.668647856114996], 
             UndirectedEdge[231, 346] -> 
             RGBColor[
              0.9692553281543101, 0.9754490717552533, 0.8857776081896322], 
             UndirectedEdge[168, 181] -> 
             RGBColor[
              0.9906608324972123, 0.9888788721469441, 0.6934295608599925], 
             UndirectedEdge[178, 391] -> 
             RGBColor[
              0.9768836268781322, 0.9806093229619267, 0.8491787031960919], 
             UndirectedEdge[30, 133] -> 
             RGBColor[
              0.954479294149001, 0.9636016115446977, 0.8788752075261266], 
             UndirectedEdge[120, 363] -> 
             RGBColor[
              0.9905955087485614, 0.990220377359178, 0.7939889751923308], 
             UndirectedEdge[452, 468] -> 
             RGBColor[
              0.8279837867294976, 0.8660325946435812, 0.9833603478657635], 
             UndirectedEdge[159, 344] -> 
             RGBColor[
              0.9418393144607549, 0.9561444364709889, 0.9833350492684403], 
             UndirectedEdge[68, 330] -> 
             RGBColor[
              0.6218425743852507, 0.6956187380193257, 0.9633611497735137], 
             UndirectedEdge[359, 440] -> 
             RGBColor[
              0.6629647989307601, 0.7352189236956295, 0.968008199538749], 
             UndirectedEdge[180, 413] -> 
             RGBColor[
              0.8543729666713313, 0.8867858677549088, 0.9701116167253584], 
             UndirectedEdge[81, 442] -> 
             RGBColor[
              0.9641432392605025, 0.8859339212557568, 0.5146518518860309], 
             UndirectedEdge[165, 277] -> 
             RGBColor[
              0.9590798541851109, 0.9653156956508964, 0.7374798429113649], 
             UndirectedEdge[28, 310] -> 
             RGBColor[
              0.99438903543138, 0.990407039080289, 0.6306593174442409], 
             UndirectedEdge[71, 470] -> 
             RGBColor[
              0.9522597894933875, 0.9616199370253342, 0.8694620034349312], 
             UndirectedEdge[129, 276] -> 
             RGBColor[
              0.28918000069152805`, 0.4174724605052763, 0.9399190442376579], 
             UndirectedEdge[192, 251] -> 
             RGBColor[
              0.993788557249317, 0.9891226769665131, 0.565300973048452], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.9877415254708983, 0.9891988200008602, 0.8528181770697547], 
             UndirectedEdge[15, 323] -> 
             RGBColor[
              0.9807684986883785, 0.9458775027882806, 0.4573624402500049], 
             UndirectedEdge[20, 473] -> 
             RGBColor[
              0.8870873241007915, 0.9088733269933972, 0.7824820859730521], 
             UndirectedEdge[336, 354] -> 
             RGBColor[
              0.98862569105475, 0.989564445191802, 0.8381652651981512], 
             UndirectedEdge[36, 440] -> 
             RGBColor[
              0.763440264210661, 0.8139188464212529, 0.9409457116377301], 
             UndirectedEdge[31, 311] -> 
             RGBColor[
              0.5965056273844903, 0.6584092910687682, 0.7984723896566011], 
             UndirectedEdge[366, 405] -> 
             RGBColor[
              0.8717934602062041, 0.9000284481042091, 0.9532987148682215], 
             UndirectedEdge[257, 374] -> 
             RGBColor[
              0.906146009863134, 0.5628915612185925, 0.42922020200474764`], 
             UndirectedEdge[194, 254] -> 
             RGBColor[
              0.9817781768936431, 0.9546811810298602, 0.5724112172724769], 
             UndirectedEdge[284, 456] -> 
             RGBColor[
              0.8550357262418198, 0.8873103988573865, 0.9705207902776822], 
             UndirectedEdge[30, 429] -> 
             RGBColor[
              0.9478386302469479, 0.939518520894238, 0.6837522775475285], 
             UndirectedEdge[182, 463] -> 
             RGBColor[
              0.8852313447892961, 0.9085493913126943, 0.8640463307731681], 
             UndirectedEdge[130, 238] -> 
             RGBColor[
              0.9504673092794167, 0.9600547079032381, 0.8633874406112223], 
             UndirectedEdge[19, 67] -> 
             RGBColor[
              0.5058307334498473, 0.6077774752561047, 0.9547698685404795], 
             UndirectedEdge[114, 446] -> 
             RGBColor[
              0.9830390238432227, 0.9859221902266357, 0.871100020021358], 
             UndirectedEdge[164, 418] -> 
             RGBColor[
              0.6903762271661857, 0.7580464228066672, 0.9697739084574253], 
             UndirectedEdge[96, 457] -> 
             RGBColor[
              0.9563053300424845, 0.9306946495078077, 0.6538413505193488], 
             UndirectedEdge[285, 354] -> 
             RGBColor[
              0.9749869268083695, 0.98054389096499, 0.9128058422878926], 
             UndirectedEdge[432, 460] -> 
             RGBColor[
              0.9660271586228857, 0.8906211636394319, 0.4418506779906268], 
             UndirectedEdge[82, 249] -> 
             RGBColor[
              0.6984671822566215, 0.7614369530136138, 0.9531114977889172], 
             UndirectedEdge[176, 262] -> 
             RGBColor[
              0.9758892862220051, 0.9779910446708404, 0.7078760955842325], 
             UndirectedEdge[216, 358] -> 
             RGBColor[
              0.9697141387733343, 0.9767269941753358, 0.9269054095595715], 
             UndirectedEdge[54, 374] -> 
             RGBColor[
              0.9895993656411333, 0.989700531515969, 0.802653358141945], 
             UndirectedEdge[214, 491] -> 
             RGBColor[
              0.9835060345086996, 0.9557347816694752, 0.5461199025190926], 
             UndirectedEdge[68, 357] -> 
             RGBColor[
              0.648646158848258, 0.7127319291024036, 0.7534036008524467], 
             UndirectedEdge[260, 328] -> 
             RGBColor[
              0.9658432516142919, 0.9728336660377899, 0.8883879620285846], 
             UndirectedEdge[224, 286] -> 
             RGBColor[
              0.6106584453693285, 0.6860730596903231, 0.9664220513673911], 
             UndirectedEdge[219, 293] -> 
             RGBColor[
              0.9458354082042464, 0.9558520546071247, 0.8251527331826136], 
             UndirectedEdge[209, 404] -> 
             RGBColor[
              0.8262507821137659, 0.5183157824097806, 0.5761253192877347], 
             UndirectedEdge[197, 289] -> 
             RGBColor[
              0.712820113051479, 0.7683881641655745, 0.7221359247270408], 
             UndirectedEdge[227, 424] -> 
             RGBColor[
              0.9934372751397618, 0.9893591269333539, 0.5988692155770154], 
             UndirectedEdge[458, 461] -> 
             RGBColor[
              0.962906908068293, 0.9690418697926861, 0.7925289380900615], 
             UndirectedEdge[292, 464] -> 
             RGBColor[
              0.7580047136330852, 0.8109171270209654, 0.9765041832346042], 
             UndirectedEdge[386, 441] -> 
             RGBColor[
              0.9793498490280004, 0.9406894374291257, 0.48608774294722057`], 
             UndirectedEdge[257, 343] -> 
             RGBColor[
              0.8755431967520437, 0.5420758947061104, 0.5788813808240272], 
             UndirectedEdge[132, 457] -> 
             RGBColor[
              0.980543207444438, 0.9455427559423719, 0.4203301462705728], 
             UndirectedEdge[69, 259] -> 
             RGBColor[
              0.9859690890611457, 0.9874621088680524, 0.837241471624937], 
             UndirectedEdge[68, 95] -> 
             RGBColor[
              0.6474770356591748, 0.713529617223368, 0.865905122141071], 
             UndirectedEdge[247, 278] -> 
             RGBColor[
              0.7887088213695556, 0.8346161702909813, 0.9478478382384943], 
             UndirectedEdge[293, 440] -> 
             RGBColor[
              0.723548588234118, 0.7831700109290696, 0.9738814143802803], 
             UndirectedEdge[307, 442] -> 
             RGBColor[0.993307835509069, 0.9899064275562, 0.6446881626815372],
              UndirectedEdge[406, 493] -> 
             RGBColor[
              0.8816668296046583, 0.8787185788843734, 0.665198190027871], 
             UndirectedEdge[155, 479] -> 
             RGBColor[
              0.9710549857611008, 0.9745788909074299, 0.7313936283200633], 
             UndirectedEdge[311, 488] -> 
             RGBColor[
              0.7171073433941901, 0.7730770417314772, 0.8057832372877045], 
             UndirectedEdge[226, 345] -> 
             RGBColor[
              0.9724741310782298, 0.9694624521407376, 0.6831702314963801], 
             UndirectedEdge[183, 273] -> 
             RGBColor[
              0.6591526581023426, 0.6405073150261471, 0.6054543868357459], 
             UndirectedEdge[384, 499] -> 
             RGBColor[
              0.9170821472388107, 0.9350979685087808, 0.932445976545013], 
             UndirectedEdge[20, 325] -> 
             RGBColor[
              0.7251994525875399, 0.7852505911721448, 0.9732447621258821], 
             UndirectedEdge[252, 424] -> 
             RGBColor[
              0.9938774396566579, 0.9895411462728027, 0.5915745504227915], 
             UndirectedEdge[285, 473] -> 
             RGBColor[
              0.9789123600674489, 0.9810447312339827, 0.7661626414377758], 
             UndirectedEdge[71, 236] -> 
             RGBColor[
              0.9450997379744888, 0.957924422644321, 0.9552235002566656], 
             UndirectedEdge[2, 446] -> 
             RGBColor[
              0.9870085008580954, 0.9740827459125582, 0.6048844068088683], 
             UndirectedEdge[33, 351] -> 
             RGBColor[
              0.9308386805703834, 0.9469281688219083, 0.9668691302900665], 
             UndirectedEdge[172, 466] -> 
             RGBColor[
              0.9249859399722205, 0.8214926654502444, 0.6193190450178085], 
             UndirectedEdge[12, 279] -> 
             RGBColor[
              0.9453844611627611, 0.9587884010767003, 0.9773340406242876], 
             UndirectedEdge[171, 219] -> 
             RGBColor[
              0.9760032682923752, 0.9793488841310161, 0.808676914361792], 
             UndirectedEdge[153, 223] -> 
             RGBColor[
              0.856503930595583, 0.8884170013498099, 0.9861753035819336], 
             UndirectedEdge[121, 489] -> 
             RGBColor[
              0.6121364487429248, 0.6836797066955147, 0.9528508444642888], 
             UndirectedEdge[362, 470] -> 
             RGBColor[
              0.9299595541527037, 0.9438383346884358, 0.8673349870804816], 
             UndirectedEdge[168, 232] -> 
             RGBColor[
              0.9860941682980577, 0.9885175954747425, 0.880119148647426], 
             UndirectedEdge[285, 409] -> 
             RGBColor[
              0.8420724873271932, 0.8769896824260361, 0.959421868021441], 
             UndirectedEdge[159, 439] -> 
             RGBColor[
              0.8386349831549089, 0.8746457138044397, 0.9763626722037992], 
             UndirectedEdge[156, 263] -> 
             RGBColor[
              0.9664305958759425, 0.97301730615651, 0.8760011775398033], 
             UndirectedEdge[149, 314] -> 
             RGBColor[
              0.9320731939680327, 0.9389973545609624, 0.6999753379542907], 
             UndirectedEdge[110, 457] -> 
             RGBColor[
              0.980452261537135, 0.9472217400999512, 0.5466155180578114], 
             UndirectedEdge[43, 263] -> 
             RGBColor[
              0.961744496220756, 0.8767040946354596, 0.5140938328819499], 
             UndirectedEdge[141, 160] -> 
             RGBColor[
              0.9939052884182131, 0.9893723531334506, 0.5780064404015339], 
             UndirectedEdge[345, 389] -> 
             RGBColor[
              0.9754695377603835, 0.9785711713002941, 0.7794561842433512], 
             UndirectedEdge[225, 247] -> 
             RGBColor[
              0.7995648688759961, 0.8392517086231851, 0.7185469472373077], 
             UndirectedEdge[171, 293] -> 
             RGBColor[
              0.927177624147675, 0.9442120829763064, 0.9735629673168893], 
             UndirectedEdge[179, 415] -> 
             RGBColor[
              0.6146794934227523, 0.6785693449403962, 0.8513089847866546], 
             UndirectedEdge[143, 414] -> 
             RGBColor[
              0.9921327022892535, 0.9834564466494247, 0.5657255643287517], 
             UndirectedEdge[77, 388] -> 
             RGBColor[
              0.6410355792308827, 0.711137240373166, 0.9413470742617929], 
             UndirectedEdge[305, 406] -> 
             RGBColor[
              0.891076712041722, 0.910460321890055, 0.701753806388671], 
             UndirectedEdge[55, 256] -> 
             RGBColor[
              0.9903211071510235, 0.9902655433178174, 0.810067832886689], 
             UndirectedEdge[367, 450] -> 
             RGBColor[
              0.7902896712679761, 0.8342382011354488, 0.8849254648563982], 
             UndirectedEdge[171, 258] -> 
             RGBColor[
              0.9758947580772838, 0.9791167917530013, 0.7968662470965229], 
             UndirectedEdge[366, 423] -> 
             RGBColor[
              0.882094440451132, 0.9053818892829794, 0.8147465386386677], 
             UndirectedEdge[309, 393] -> 
             RGBColor[
              0.916539421507775, 0.934353745923403, 0.9188692028012537], 
             UndirectedEdge[324, 360] -> 
             RGBColor[
              0.9485656155851243, 0.9611609008362364, 0.97194917596518], 
             UndirectedEdge[125, 310] -> 
             RGBColor[
              0.9875741137976215, 0.9872207210332185, 0.7289717658815629], 
             UndirectedEdge[33, 463] -> 
             RGBColor[
              0.9795923578993273, 0.9826775008389086, 0.8467435461045683], 
             UndirectedEdge[137, 280] -> 
             RGBColor[
              0.8943085614646541, 0.8146546898970526, 0.6221075031141664], 
             UndirectedEdge[72, 179] -> 
             RGBColor[
              0.606772802274528, 0.6502207581244297, 0.6513031051583709], 
             UndirectedEdge[17, 165] -> 
             RGBColor[
              0.917900602153657, 0.9373730406819654, 0.9920313729245984], 
             UndirectedEdge[402, 417] -> 
             RGBColor[
              0.9569355454791206, 0.9674031808466764, 0.9577810678819809], 
             UndirectedEdge[102, 225] -> 
             RGBColor[
              0.9934797856209397, 0.9884622456750147, 0.5316930868171981], 
             UndirectedEdge[83, 231] -> 
             RGBColor[
              0.8748336531177705, 0.9009587954552374, 0.8871403755086504], 
             UndirectedEdge[194, 377] -> 
             RGBColor[
              0.9838360454141518, 0.9554680695742069, 0.5336481277070237], 
             UndirectedEdge[131, 495] -> 
             RGBColor[
              0.962740683894268, 0.9717326435716516, 0.9479544827677213], 
             UndirectedEdge[213, 447] -> 
             RGBColor[
              0.6870694345268625, 0.7522442664884452, 0.9623017079981226], 
             UndirectedEdge[146, 166] -> 
             RGBColor[
              0.9192283381504669, 0.9373639577882127, 0.9551372880297929], 
             UndirectedEdge[422, 428] -> 
             RGBColor[
              0.9936475967323757, 0.9907693740859425, 0.691571676312565], 
             UndirectedEdge[232, 338] -> 
             RGBColor[
              0.9892996641847274, 0.9889277448872777, 0.7604554688854605], 
             UndirectedEdge[366, 469] -> 
             RGBColor[
              0.8801801762236109, 0.9051929041066684, 0.8902744018207394], 
             UndirectedEdge[245, 482] -> 
             RGBColor[
              0.8415450962700168, 0.8767756921449339, 0.9846724991356796], 
             UndirectedEdge[40, 243] -> 
             RGBColor[
              0.7920048597798737, 0.8349474756634525, 0.8565003524486732], 
             UndirectedEdge[174, 320] -> 
             RGBColor[
              0.9436672041131127, 0.9574578627679012, 0.9785139367240394], 
             UndirectedEdge[30, 31] -> 
             RGBColor[
              0.5571518551365255, 0.6308123341381753, 0.9632267558065302], 
             UndirectedEdge[77, 354] -> 
             RGBColor[
              0.9763792695528302, 0.9815822979040568, 0.9104489692026679], 
             UndirectedEdge[24, 223] -> 
             RGBColor[
              0.9300031802692701, 0.9456487355109212, 0.9444424619882578], 
             UndirectedEdge[261, 391] -> 
             RGBColor[
              0.9731306065171326, 0.9790573525944295, 0.9113759630832073], 
             UndirectedEdge[125, 323] -> 
             RGBColor[
              0.987778045175217, 0.98765690962927, 0.7511684378142458], 
             UndirectedEdge[1, 364] -> 
             RGBColor[
              0.9838079345888943, 0.9685812648419563, 0.6290481366110543], 
             UndirectedEdge[88, 133] -> 
             RGBColor[
              0.986793438425762, 0.9687958801480872, 0.5725206361475907], 
             UndirectedEdge[178, 407] -> 
             RGBColor[
              0.9877909208368022, 0.9702892144566804, 0.5634605640232407], 
             UndirectedEdge[103, 486] -> 
             RGBColor[
              0.9808058944079265, 0.9828957410450904, 0.7977754751020816], 
             UndirectedEdge[204, 486] -> 
             RGBColor[
              0.9501659591846685, 0.9622933710292954, 0.9671231037804586], 
             UndirectedEdge[89, 407] -> 
             RGBColor[
              0.9863613801925828, 0.9696980626627768, 0.5871517520305513], 
             UndirectedEdge[38, 301] -> 
             RGBColor[
              0.5827013791316755, 0.6654207190141541, 0.9634359259845977], 
             UndirectedEdge[92, 132] -> 
             RGBColor[
              0.983744919427671, 0.9841691051952536, 0.7199169907335295], 
             UndirectedEdge[8, 146] -> 
             RGBColor[
              0.5780167136684491, 0.6439202957547094, 0.9285690131526549], 
             UndirectedEdge[44, 110] -> 
             RGBColor[
              0.9693789367505923, 0.9068183830449486, 0.5194844461215349], 
             UndirectedEdge[102, 252] -> 
             RGBColor[
              0.9945091806550646, 0.9908923763895818, 0.6603356594458443], 
             UndirectedEdge[273, 283] -> 
             RGBColor[
              0.8021812539193448, 0.7580375592234447, 0.6165030777056519], 
             UndirectedEdge[158, 428] -> 
             RGBColor[
              0.9922290842883765, 0.9901827827362417, 0.7150800985021588], 
             UndirectedEdge[176, 328] -> 
             RGBColor[
              0.9665138920636136, 0.9709988910583112, 0.7237461923999733], 
             UndirectedEdge[45, 398] -> 
             RGBColor[
              0.970736290564333, 0.9759710121884768, 0.8571825470190042], 
             UndirectedEdge[233, 275] -> 
             RGBColor[
              0.9890800542072842, 0.9897523360319752, 0.8306352919065141], 
             UndirectedEdge[250, 485] -> 
             RGBColor[
              0.7603787294663487, 0.8128415258613817, 0.9770442235006946], 
             UndirectedEdge[29, 65] -> 
             RGBColor[
              0.900228044074559, 0.9007859230010188, 0.6780795304045678], 
             UndirectedEdge[166, 453] -> 
             RGBColor[
              0.9146125732273122, 0.8977889756746495, 0.6581690110660618], 
             UndirectedEdge[222, 294] -> 
             RGBColor[
              0.9491587121154403, 0.9589990300037685, 0.8627312074162495], 
             UndirectedEdge[150, 220] -> 
             RGBColor[
              0.8072318752898182, 0.782545716898978, 0.621559902021382], 
             UndirectedEdge[311, 423] -> 
             RGBColor[
              0.9946317797871224, 0.9909262447120026, 0.6570805425222779], 
             UndirectedEdge[210, 424] -> 
             RGBColor[
              0.8420514095774696, 0.8728468987006719, 0.7103908554937877], 
             UndirectedEdge[179, 312] -> 
             RGBColor[
              0.5324760517250353, 0.6159614999674139, 0.9601422041331069], 
             UndirectedEdge[310, 323] -> 
             RGBColor[
              0.9937772219775354, 0.9890984319663441, 0.564067198668206], 
             UndirectedEdge[108, 349] -> 
             RGBColor[
              0.9936139923881615, 0.9887493003797166, 0.546300665201133], 
             UndirectedEdge[355, 395] -> 
             RGBColor[
              0.5961032303413941, 0.6822317694014439, 0.9618598429439893], 
             UndirectedEdge[47, 200] -> 
             RGBColor[
              0.9482747759472753, 0.9602642274055131, 0.94819214522031], 
             UndirectedEdge[152, 217] -> 
             RGBColor[
              0.9371028332022322, 0.9239153907150187, 0.6723675579920169], 
             UndirectedEdge[174, 210] -> 
             RGBColor[
              0.8224661239879529, 0.8618549890012963, 0.9666777975707361], 
             UndirectedEdge[135, 211] -> 
             RGBColor[
              0.9917447467220195, 0.9908542548662923, 0.7864744409341788], 
             UndirectedEdge[52, 491] -> 
             RGBColor[
              0.9788822214460464, 0.9538227161414927, 0.6227484510118803], 
             UndirectedEdge[41, 250] -> 
             RGBColor[
              0.7788041130756098, 0.8278000823294523, 0.9784947371928197], 
             UndirectedEdge[220, 392] -> 
             RGBColor[
              0.7670602624557292, 0.8183231218240234, 0.9773187244415424], 
             UndirectedEdge[182, 359] -> 
             RGBColor[
              0.7761716131219132, 0.8250704303843654, 0.9783251907260259], 
             UndirectedEdge[89, 391] -> 
             RGBColor[
              0.9754540862339129, 0.9800181711680231, 0.8728698912034024], 
             UndirectedEdge[62, 190] -> 
             RGBColor[
              0.9079464500523371, 0.9175050293574974, 0.6943577157133873], 
             UndirectedEdge[21, 87] -> 
             RGBColor[
              0.9853413900167294, 0.9882063023098937, 0.892594632896782], 
             UndirectedEdge[185, 286] -> 
             RGBColor[
              0.9358276046332283, 0.9513510654636701, 0.9827686929787073], 
             UndirectedEdge[114, 294] -> 
             RGBColor[
              0.9398147429574779, 0.9538030341254958, 0.9579341790776279], 
             UndirectedEdge[48, 156] -> 
             RGBColor[
              0.7215602900284801, 0.7811391952755637, 0.9703815317945119], 
             UndirectedEdge[68, 450] -> 
             RGBColor[
              0.44684368117626205`, 0.5572533662313527, 0.9507381030259514], 
             UndirectedEdge[149, 406] -> 
             RGBColor[
              0.8325711272471127, 0.8695755265132583, 0.9838283804914078], 
             UndirectedEdge[123, 158] -> 
             RGBColor[
              0.990320550775013, 0.9902653132420388, 0.8100770534770374], 
             UndirectedEdge[55, 91] -> 
             RGBColor[
              0.9204437291176748, 0.9367923661532632, 0.8899494981263927], 
             UndirectedEdge[135, 169] -> 
             RGBColor[
              0.9934584498437753, 0.9906440083089145, 0.6912791186082909], 
             UndirectedEdge[141, 456] -> 
             RGBColor[
              0.8751663901074486, 0.8990050031543887, 0.736793219936885], 
             UndirectedEdge[287, 354] -> 
             RGBColor[
              0.9903206681881728, 0.9896004774720892, 0.761745036208334], 
             UndirectedEdge[223, 411] -> 
             RGBColor[
              0.9018505259472638, 0.9245751455827, 0.9905005023279605], 
             UndirectedEdge[127, 301] -> 
             RGBColor[
              0.6250409190821529, 0.702093100472104, 0.9661337640308569], 
             UndirectedEdge[167, 201] -> 
             RGBColor[
              0.9061242160029744, 0.9260173629143091, 0.9165044415394368], 
             UndirectedEdge[28, 218] -> 
             RGBColor[
              0.9921327022892535, 0.9834564466494247, 0.5657255643287517], 
             UndirectedEdge[112, 317] -> 
             RGBColor[
              0.7265778663042732, 0.786327418443989, 0.9733821495231575], 
             UndirectedEdge[275, 372] -> 
             RGBColor[
              0.9924922726838615, 0.9906059246106631, 0.7335651654517781], 
             UndirectedEdge[85, 146] -> 
             RGBColor[
              0.9487461994959812, 0.9609006991841242, 0.957952727995834], 
             UndirectedEdge[7, 262] -> 
             RGBColor[
              0.9415358672258964, 0.9556197128496147, 0.9735025343351655], 
             UndirectedEdge[448, 455] -> 
             RGBColor[
              0.9923778505994036, 0.9911160595896182, 0.7759822712656085], 
             UndirectedEdge[9, 368] -> 
             RGBColor[
              0.9885982231013093, 0.98955308648716, 0.8386204802714479], 
             UndirectedEdge[216, 399] -> 
             RGBColor[
              0.9736398870000433, 0.9766285507565258, 0.7366859235405425], 
             UndirectedEdge[205, 474] -> 
             RGBColor[
              0.9863430089389843, 0.9886204974746783, 0.8759952152483381], 
             UndirectedEdge[125, 242] -> 
             RGBColor[
              0.9315243435279528, 0.9470532281498337, 0.9523149761404655], 
             UndirectedEdge[280, 338] -> 
             RGBColor[
              0.9297298737950266, 0.9427146939066712, 0.79968307776508], 
             UndirectedEdge[232, 393] -> 
             RGBColor[
              0.9860656813639394, 0.9885058153954036, 0.8805912508675906], 
             UndirectedEdge[403, 483] -> 
             RGBColor[
              0.8821038633936273, 0.9088296928713062, 0.9886170480255408], 
             UndirectedEdge[427, 433] -> 
             RGBColor[
              0.9886595756454382, 0.9895784573408458, 0.8376037098399378], 
             UndirectedEdge[269, 310] -> 
             RGBColor[
              0.9936513497254156, 0.9901686035151818, 0.6477269900266757], 
             UndirectedEdge[212, 357] -> 
             RGBColor[
              0.9000892722915791, 0.9189056487891503, 0.7737742288410887], 
             UndirectedEdge[88, 307] -> 
             RGBColor[
              0.9870174399650502, 0.967294305848073, 0.4529264990370619], 
             UndirectedEdge[212, 217] -> 
             RGBColor[
              0.8531753957955999, 0.8858728610625447, 0.9858286494664601], 
             UndirectedEdge[67, 124] -> 
             RGBColor[
              0.6788407497605009, 0.7488297468193728, 0.9687643696545176], 
             UndirectedEdge[364, 380] -> 
             RGBColor[
              0.9466203461270253, 0.8185848718704517, 0.3149137432898085], 
             UndirectedEdge[82, 384] -> 
             RGBColor[
              0.712832323724633, 0.7718284714790805, 0.9143761147545701], 
             UndirectedEdge[222, 439] -> 
             RGBColor[
              0.8637867827212318, 0.8916311637183207, 0.854401167003546], 
             UndirectedEdge[337, 420] -> 
             RGBColor[
              0.9672540399216165, 0.9517366565239361, 0.6626423645494863], 
             UndirectedEdge[61, 99] -> 
             RGBColor[
              0.9158283373648979, 0.9225282647708895, 0.6932535660333278], 
             UndirectedEdge[63, 439] -> 
             RGBColor[
              0.6805664302575075, 0.7501694313155713, 0.9689421331490575], 
             UndirectedEdge[37, 53] -> 
             RGBColor[
              0.9946496008130639, 0.9909643620845092, 0.6590202512173791], 
             UndirectedEdge[39, 62] -> 
             RGBColor[
              0.9035404132128968, 0.9026424325114184, 0.6772410946024027], 
             UndirectedEdge[130, 182] -> 
             RGBColor[
              0.8413185727450814, 0.8766600657668635, 0.9846336448262509], 
             UndirectedEdge[152, 398] -> 
             RGBColor[
              0.9605677934011929, 0.942336893383976, 0.664592108120279], 
             UndirectedEdge[23, 110] -> 
             RGBColor[
              0.9730607688856276, 0.977947694681024, 0.8641338948171263], 
             UndirectedEdge[322, 440] -> 
             RGBColor[
              0.7650745178630767, 0.8151376701193795, 0.9381793464858077], 
             UndirectedEdge[141, 432] -> 
             RGBColor[
              0.9654863499242026, 0.8894644285170954, 0.3829869886233766], 
             UndirectedEdge[161, 459] -> 
             RGBColor[
              0.9799327283972187, 0.9557472486287928, 0.6156384920998442], 
             UndirectedEdge[185, 333] -> 
             RGBColor[
              0.8861513533868142, 0.9117405711456978, 0.9780305277883112], 
             UndirectedEdge[297, 474] -> 
             RGBColor[
              0.9890643335542887, 0.9897458351379593, 0.830895823810395], 
             UndirectedEdge[265, 329] -> 
             RGBColor[
              0.8625892063094895, 0.890996360521374, 0.8679192035451666], 
             UndirectedEdge[90, 280] -> 
             RGBColor[
              0.9299821198799945, 0.9437344096593233, 0.862043024707637], 
             UndirectedEdge[183, 430] -> 
             RGBColor[
              0.6845200463559855, 0.7327929418658763, 0.6690276195583171], 
             UndirectedEdge[86, 194] -> 
             RGBColor[
              0.9825099527892556, 0.9526316915380848, 0.389311129182101], 
             UndirectedEdge[143, 186] -> 
             RGBColor[
              0.9840356685020676, 0.979313931457594, 0.6662082942134215], 
             UndirectedEdge[1, 416] -> 
             RGBColor[
              0.9784426838954776, 0.983088667596892, 0.9054997746540772], 
             UndirectedEdge[27, 86] -> 
             RGBColor[
              0.978443355969771, 0.979702088508315, 0.6881773298270099], 
             UndirectedEdge[66, 415] -> 
             RGBColor[
              0.973311081479197, 0.9781544448738759, 0.8646088432137173], 
             UndirectedEdge[413, 490] -> 
             RGBColor[
              0.8745768145699948, 0.9002756205792286, 0.8652347877496581], 
             UndirectedEdge[226, 284] -> 
             RGBColor[
              0.9705131631058574, 0.9679999654377327, 0.6864896387712476], 
             UndirectedEdge[245, 438] -> 
             RGBColor[0.8629587027567, 0.893703958588689, 0.9816404817408335],
              UndirectedEdge[53, 163] -> 
             RGBColor[
              0.9753077029553291, 0.9792347831400962, 0.8419616113451664], 
             UndirectedEdge[367, 368] -> 
             RGBColor[
              0.9900063224351998, 0.990135371748226, 0.8152846302646196], 
             UndirectedEdge[112, 175] -> 
             RGBColor[
              0.6679689252721096, 0.7394967528023972, 0.9682549724214985], 
             UndirectedEdge[277, 288] -> 
             RGBColor[
              0.888814479733199, 0.909573960469028, 0.7307019818929664], 
             UndirectedEdge[249, 323] -> 
             RGBColor[
              0.9756904602172445, 0.978642008559218, 0.771629566201026], 
             UndirectedEdge[416, 452] -> 
             RGBColor[
              0.9253424774141258, 0.9424080319793002, 0.9615737463695364], 
             UndirectedEdge[13, 87] -> 
             RGBColor[
              0.9740893440701551, 0.9371615228154175, 0.6007166431932092], 
             UndirectedEdge[471, 497] -> 
             RGBColor[
              0.9897160384540835, 0.9900153318620764, 0.8200953870625773], 
             UndirectedEdge[17, 321] -> 
             RGBColor[
              0.9514580669345797, 0.9613339814512429, 0.8847277450676897], 
             UndirectedEdge[106, 227] -> 
             RGBColor[
              0.9757118722009328, 0.9797543146695831, 0.8520078614614341], 
             UndirectedEdge[37, 100] -> 
             RGBColor[
              0.9737041866740901, 0.9772136291853203, 0.7791955600714298], 
             UndirectedEdge[9, 375] -> 
             RGBColor[
              0.9903807982619164, 0.9884858547836785, 0.6779197753277052], 
             UndirectedEdge[10, 302] -> 
             RGBColor[
              0.9899649196372929, 0.9878505389510728, 0.6511320820935425], 
             UndirectedEdge[14, 272] -> 
             RGBColor[
              0.867605253098639, 0.8740652801453866, 0.6730428698459338], 
             UndirectedEdge[63, 387] -> 
             RGBColor[
              0.6743613725834381, 0.7453219931004033, 0.9683236709896672], 
             UndirectedEdge[471, 483] -> 
             RGBColor[
              0.9376587353357189, 0.950266613268408, 0.8806256888212336], 
             UndirectedEdge[46, 392] -> 
             RGBColor[
              0.9104443836981924, 0.8776933179588212, 0.6348814979197315], 
             UndirectedEdge[122, 357] -> 
             RGBColor[
              0.8940979081186697, 0.9142251495612191, 0.7731770656528145], 
             UndirectedEdge[75, 125] -> 
             RGBColor[
              0.9880489354466631, 0.9882363165286856, 0.780653172120191], 
             UndirectedEdge[244, 261] -> 
             RGBColor[
              0.9860355746371046, 0.9884933654901499, 0.8810901972449547], 
             UndirectedEdge[7, 178] -> 
             RGBColor[
              0.9591887551724078, 0.9671141034460247, 0.8687853334820346], 
             UndirectedEdge[108, 487] -> 
             RGBColor[
              0.8267240760781333, 0.8611387278641733, 0.7301410699900894], 
             UndirectedEdge[338, 480] -> 
             RGBColor[
              0.9621181854739349, 0.875144563382491, 0.4374523620179348], 
             UndirectedEdge[237, 284] -> 
             RGBColor[
              0.9478557075783371, 0.8876815764631688, 0.6187261349620226], 
             UndirectedEdge[162, 456] -> 
             RGBColor[
              0.606343543965659, 0.689537267454414, 0.9633552071442671], 
             UndirectedEdge[104, 310] -> 
             RGBColor[
              0.9938333751520195, 0.9892185379286089, 0.5701791251735884], 
             UndirectedEdge[168, 390] -> 
             RGBColor[
              0.9781766589962315, 0.9473894021390553, 0.5919913110727604], 
             UndirectedEdge[164, 431] -> 
             RGBColor[
              0.8205257577122784, 0.8561380050704865, 0.7168242818037336], 
             UndirectedEdge[57, 60] -> 
             RGBColor[
              0.5814693938709248, 0.6703513617078967, 0.9607078137315247], 
             UndirectedEdge[158, 247] -> 
             RGBColor[
              0.7981789592348607, 0.8406830487840333, 0.8872173689431473], 
             UndirectedEdge[32, 475] -> 
             RGBColor[
              0.9817989602909059, 0.9613823706595941, 0.6183257509282427], 
             UndirectedEdge[53, 293] -> 
             RGBColor[
              0.9461258757564592, 0.9564733353305336, 0.856768333683038], 
             UndirectedEdge[72, 294] -> 
             RGBColor[
              0.9403156300296258, 0.9302632214709591, 0.678243748925901], 
             UndirectedEdge[87, 287] -> 
             RGBColor[
              0.98995790859066, 0.9894504670560212, 0.7677569015308637], 
             UndirectedEdge[154, 374] -> 
             RGBColor[
              0.968745298367027, 0.9741532030025983, 0.838204665852508], 
             UndirectedEdge[119, 364] -> 
             RGBColor[
              0.647471203703343, 0.697320386280214, 0.6615112524856621], 
             UndirectedEdge[90, 342] -> 
             RGBColor[
              0.8430453076286408, 0.875452933016517, 0.8534750420122106], 
             UndirectedEdge[401, 428] -> 
             RGBColor[
              0.9800967973580049, 0.9434325133872483, 0.4699894440803722], 
             UndirectedEdge[183, 477] -> 
             RGBColor[
              0.6468212718268226, 0.7189419202929609, 0.9684497688912495], 
             UndirectedEdge[82, 269] -> 
             RGBColor[
              0.716632003142388, 0.7733997365656291, 0.8514055935472499], 
             UndirectedEdge[202, 273] -> 
             RGBColor[
              0.9594673573110859, 0.8807136685583254, 0.5760603439309767], 
             UndirectedEdge[147, 242] -> 
             RGBColor[
              0.8866817963595017, 0.9124800123536145, 0.9890536953585949], 
             UndirectedEdge[117, 198] -> 
             RGBColor[
              0.783542481363638, 0.8262301503646452, 0.7161494564599975], 
             UndirectedEdge[240, 434] -> 
             RGBColor[
              0.9824708557842159, 0.9794694803975184, 0.6716647088712671], 
             UndirectedEdge[249, 310] -> 
             RGBColor[
              0.975486528839649, 0.9782058199631665, 0.749432894268343], 
             UndirectedEdge[448, 478] -> 
             RGBColor[
              0.9575312606513029, 0.8634796033755006, 0.5277308165012541], 
             UndirectedEdge[121, 196] -> 
             RGBColor[
              0.6055326939191743, 0.6787546371606177, 0.9640292788457949], 
             UndirectedEdge[200, 256] -> 
             RGBColor[
              0.986986081891694, 0.9888864246668448, 0.8653378322024832], 
             UndirectedEdge[79, 184] -> 
             RGBColor[
              0.7257069500378124, 0.5475128122157592, 0.5800711325325985], 
             UndirectedEdge[51, 240] -> 
             RGBColor[
              0.9357989055798288, 0.9432647583023676, 0.7022382010606607], 
             UndirectedEdge[339, 387] -> 
             RGBColor[
              0.8571956544609105, 0.8866240753941761, 0.8601808935769981], 
             UndirectedEdge[46, 142] -> 
             RGBColor[
              0.9744572398049036, 0.9256304342577324, 0.5171028019503494], 
             UndirectedEdge[233, 259] -> 
             RGBColor[
              0.9829807892397651, 0.9862263700961091, 0.8867653331372486], 
             UndirectedEdge[266, 471] -> 
             RGBColor[
              0.89325446273248, 0.9150704733244155, 0.8763344771349062], 
             UndirectedEdge[167, 456] -> 
             RGBColor[
              0.7907506350064751, 0.8364948079342291, 0.9797689676701535], 
             UndirectedEdge[10, 181] -> 
             RGBColor[
              0.990394134227101, 0.9887685855584203, 0.697849441388736], 
             UndirectedEdge[31, 429] -> 
             RGBColor[
              0.5890179405249075, 0.6344951949018323, 0.655131560255463], 
             UndirectedEdge[317, 322] -> 
             RGBColor[
              0.8357134282856157, 0.8717348068560232, 0.9442535668451069], 
             UndirectedEdge[52, 466] -> 
             RGBColor[
              0.9613802231098749, 0.970571993267209, 0.9437182747112798], 
             UndirectedEdge[207, 281] -> 
             RGBColor[
              0.9081595450685214, 0.9288021623568813, 0.9632401199088669], 
             UndirectedEdge[358, 398] -> 
             RGBColor[
              0.9661668471996605, 0.9740814299278466, 0.9329100489119853], 
             UndirectedEdge[155, 250] -> 
             RGBColor[
              0.9608737493575901, 0.966803614668929, 0.7423133554070316], 
             UndirectedEdge[243, 285] -> 
             RGBColor[
              0.9788307746155596, 0.9821334208156459, 0.8491033365635037], 
             UndirectedEdge[378, 452] -> 
             RGBColor[
              0.9331070462524103, 0.9478837231774518, 0.9343190186101276], 
             UndirectedEdge[100, 264] -> 
             RGBColor[
              0.9660918786712194, 0.974231959149224, 0.9422817841419233], 
             UndirectedEdge[81, 130] -> 
             RGBColor[
              0.9206204793600231, 0.8542058757542155, 0.6287756553983429], 
             UndirectedEdge[1, 120] -> 
             RGBColor[
              0.9862093534409726, 0.9885652274914608, 0.8782102327397341], 
             UndirectedEdge[390, 422] -> 
             RGBColor[
              0.9807835644409231, 0.9484674245348493, 0.5487881413991929], 
             UndirectedEdge[118, 255] -> 
             RGBColor[
              0.9095401990290615, 0.8802821562644485, 0.6378804767274882], 
             UndirectedEdge[137, 229] -> 
             RGBColor[
              0.9586610717620331, 0.8628455184697793, 0.5036178480819611], 
             UndirectedEdge[367, 375] -> 
             RGBColor[
              0.9917888975958069, 0.9890681400447444, 0.654583925320877], 
             UndirectedEdge[230, 382] -> 
             RGBColor[
              0.9534953996737379, 0.9137850423186002, 0.6271505840813505], 
             UndirectedEdge[114, 334] -> 
             RGBColor[
              0.9373368329550628, 0.9518272159506452, 0.9576978338095412], 
             UndirectedEdge[52, 170] -> 
             RGBColor[
              0.9653250294957026, 0.9735140234107316, 0.9370407464703573], 
             UndirectedEdge[4, 389] -> 
             RGBColor[
              0.9930812835563939, 0.9904010532428467, 0.6912066951961642], 
             UndirectedEdge[190, 378] -> 
             RGBColor[
              0.9866994954163241, 0.9786860467753413, 0.6427064929563151], 
             UndirectedEdge[89, 328] -> 
             RGBColor[
              0.965792809886632, 0.9728128070871092, 0.8892239119949167], 
             UndirectedEdge[93, 300] -> 
             RGBColor[
              0.804733903424651, 0.8465593048741127, 0.910920241019761], 
             UndirectedEdge[104, 125] -> 
             RGBColor[
              0.9878341983497012, 0.9877770155915349, 0.7572803643196282], 
             UndirectedEdge[59, 228] -> 
             RGBColor[
              0.9233620307729491, 0.7142057650769793, 0.5101980645281756], 
             UndirectedEdge[96, 136] -> 
             RGBColor[
              0.969470409437899, 0.9741028802426874, 0.7900752385985568], 
             UndirectedEdge[332, 420] -> 
             RGBColor[
              0.8944538254154766, 0.918130184981717, 0.9708290425841988], 
             UndirectedEdge[40, 283] -> 
             RGBColor[
              0.6306503347926729, 0.7105889694451832, 0.9643673607977004], 
             UndirectedEdge[17, 288] -> 
             RGBColor[
              0.8476352277017452, 0.8816313055000972, 0.9852535119062], 
             UndirectedEdge[325, 413] -> 
             RGBColor[
              0.7128335557009986, 0.7755902585400815, 0.9720122450901083], 
             UndirectedEdge[421, 459] -> 
             RGBColor[
              0.92234634299795, 0.9114585939377824, 0.6699444430967925], 
             UndirectedEdge[148, 342] -> 
             RGBColor[
              0.7304853219681413, 0.7893799525063657, 0.9737716081864827], 
             UndirectedEdge[262, 478] -> 
             RGBColor[
              0.9414716840457795, 0.8526440879648228, 0.606042725076641], 
             UndirectedEdge[133, 405] -> 
             RGBColor[
              0.9834837765846647, 0.9857417980167562, 0.8474148193292916], 
             UndirectedEdge[374, 397] -> 
             RGBColor[
              0.9945391810372306, 0.9907281853491539, 0.6470017400497994], 
             UndirectedEdge[151, 389] -> 
             RGBColor[
              0.9938367982998331, 0.9892258596956489, 0.5705517136878827], 
             UndirectedEdge[235, 305] -> 
             RGBColor[
              0.9910821529559548, 0.9815801492896847, 0.41985627753833454`], 
             UndirectedEdge[204, 348] -> 
             RGBColor[
              0.9592136377049081, 0.9555325621366926, 0.6950526502338936], 
             UndirectedEdge[191, 429] -> 
             RGBColor[
              0.96918864630097, 0.9559500188719066, 0.6652489043302461], 
             UndirectedEdge[15, 414] -> 
             RGBColor[
              0.9813803121422233, 0.9471861099022256, 0.5239545590260398], 
             UndirectedEdge[277, 414] -> 
             RGBColor[
              0.9941151008875209, 0.989821120790005, 0.6008432328732016], 
             UndirectedEdge[317, 440] -> 
             RGBColor[
              0.6207263228312287, 0.7022219051423675, 0.9637982629821489], 
             UndirectedEdge[76, 182] -> 
             RGBColor[
              0.8700295832907017, 0.8988350360912749, 0.9624643959289763], 
             UndirectedEdge[199, 376] -> 
             RGBColor[
              0.9641850443986093, 0.9726427446274466, 0.9380264489644765], 
             UndirectedEdge[375, 402] -> 
             RGBColor[
              0.9694642570637053, 0.9734477355041804, 0.7384667924738905], 
             UndirectedEdge[45, 195] -> 
             RGBColor[
              0.9943842881969276, 0.9910081120927117, 0.6745723510552455], 
             UndirectedEdge[149, 269] -> 
             RGBColor[
              0.9344075862356347, 0.947454307136716, 0.8707655543609325], 
             UndirectedEdge[45, 152] -> 
             RGBColor[
              0.9844049872855851, 0.9583898918070279, 0.54700449736537], 
             UndirectedEdge[356, 494] -> 
             RGBColor[
              0.9373415653339168, 0.9523200616986329, 0.9746547280677726], 
             UndirectedEdge[44, 360] -> 
             RGBColor[
              0.9459021358321913, 0.8907910747393337, 0.6255759223155284], 
             UndirectedEdge[284, 432] -> 
             RGBColor[
              0.9453556860585739, 0.8777698242200933, 0.6167145589641738], 
             UndirectedEdge[151, 237] -> 
             RGBColor[
              0.968183936090159, 0.8997987515615284, 0.4065022571316866], 
             UndirectedEdge[207, 343] -> 
             RGBColor[
              0.8916119343908195, 0.9164111705947555, 0.9895239363252083], 
             UndirectedEdge[33, 371] -> 
             RGBColor[
              0.6739563191412945, 0.739736102879535, 0.9446790373179466], 
             UndirectedEdge[280, 480] -> 
             RGBColor[
              0.8976271694353832, 0.8278118646404435, 0.6247777329851558], 
             UndirectedEdge[420, 454] -> 
             RGBColor[
              0.9623399915602904, 0.9714338078850446, 0.9486327503718474], 
             UndirectedEdge[267, 393] -> 
             RGBColor[
              0.9733488904673668, 0.9790526277810513, 0.9035045493935578], 
             UndirectedEdge[337, 427] -> 
             RGBColor[
              0.9816306084438418, 0.9622138877922601, 0.6273443878911646], 
             UndirectedEdge[267, 480] -> 
             RGBColor[
              0.9444801689285114, 0.8645717280066977, 0.6084634226315034], 
             UndirectedEdge[234, 336] -> 
             RGBColor[
              0.9766323948182345, 0.9372797957137092, 0.5521204725671952], 
             UndirectedEdge[122, 492] -> 
             RGBColor[
              0.8735068736758199, 0.9017452681110578, 0.9726183878823045], 
             UndirectedEdge[80, 272] -> 
             RGBColor[
              0.8930587035148951, 0.893949709063954, 0.6755798319074082], 
             UndirectedEdge[331, 444] -> 
             RGBColor[
              0.9774204255572856, 0.980226018454657, 0.7920133226902877], 
             UndirectedEdge[77, 184] -> 
             RGBColor[
              0.7823917007568656, 0.8296401463275233, 0.9514407674869665], 
             UndirectedEdge[266, 359] -> 
             RGBColor[
              0.7848838084865025, 0.8318764636183198, 0.9791935409398735], 
             UndirectedEdge[32, 478] -> 
             RGBColor[
              0.9553047891439241, 0.8625589001894917, 0.5646292113020761], 
             UndirectedEdge[14, 447] -> 
             RGBColor[
              0.592539171574863, 0.6776455186560149, 0.9624569068474866], 
             UndirectedEdge[16, 358] -> 
             RGBColor[
              0.976601144723031, 0.9818633119361821, 0.915247504905564], 
             UndirectedEdge[50, 323] -> 
             RGBColor[
              0.8795809634164782, 0.9030094617416623, 0.781746798573214], 
             UndirectedEdge[92, 365] -> 
             RGBColor[
              0.9837636732953042, 0.9858934530289245, 0.8443843533561586], 
             UndirectedEdge[296, 438] -> 
             RGBColor[
              0.9660648487390622, 0.973121457198743, 0.893499748330659], 
             UndirectedEdge[181, 422] -> 
             RGBColor[
              0.9932677379419038, 0.9899568945427382, 0.6502263911864248], 
             UndirectedEdge[35, 428] -> 
             RGBColor[
              0.8572863277840788, 0.8857898129828574, 0.7953105864250204], 
             UndirectedEdge[19, 298] -> 
             RGBColor[
              0.6736847003726647, 0.7395335300466257, 0.945138817043716], 
             UndirectedEdge[209, 348] -> 
             RGBColor[
              0.9078830292323915, 0.9146029282729569, 0.6901566909744098], 
             UndirectedEdge[27, 194] -> 
             RGBColor[
              0.9683977886300928, 0.9458484448012102, 0.6463959670913499], 
             UndirectedEdge[253, 287] -> 
             RGBColor[
              0.9899081177915765, 0.989429877281035, 0.7685820639261369], 
             UndirectedEdge[412, 476] -> 
             RGBColor[
              0.9460407299868026, 0.959017376209523, 0.9671925221176811], 
             UndirectedEdge[221, 336] -> 
             RGBColor[
              0.9917444860977707, 0.9908541470914676, 0.7864787601524565], 
             UndirectedEdge[146, 248] -> 
             RGBColor[
              0.9586414949648607, 0.9686754751799056, 0.9548933403855078], 
             UndirectedEdge[17, 455] -> 
             RGBColor[
              0.9521793043471715, 0.9616322316563056, 0.8727749746384531], 
             UndirectedEdge[102, 393] -> 
             RGBColor[
              0.9908769960449935, 0.9893903747104307, 0.720530358227176], 
             UndirectedEdge[80, 497] -> 
             RGBColor[
              0.8974016464655499, 0.9193645962636088, 0.9245547890350649], 
             UndirectedEdge[108, 416] -> 
             RGBColor[
              0.9818442457220515, 0.9826378715663893, 0.7141115929048137], 
             UndirectedEdge[8, 453] -> 
             RGBColor[
              0.5734009487452942, 0.6043453136411463, 0.6316007361889238], 
             UndirectedEdge[58, 402] -> 
             RGBColor[
              0.7893121287025195, 0.8359483324000114, 0.9704888537583426], 
             UndirectedEdge[95, 357] -> 
             RGBColor[
              0.9926278060848948, 0.9899382720016858, 0.6787137375552704], 
             UndirectedEdge[183, 283] -> 
             RGBColor[
              0.5280800998383575, 0.6254642365544493, 0.956804810111839], 
             UndirectedEdge[179, 294] -> 
             RGBColor[
              0.5699123174344868, 0.6458121620637685, 0.9637129085762233], 
             UndirectedEdge[136, 240] -> 
             RGBColor[
              0.9920958841133044, 0.9839990291453253, 0.5088844723022291], 
             UndirectedEdge[153, 289] -> 
             RGBColor[
              0.9154935800216873, 0.9306428658140915, 0.7399439579502126], 
             UndirectedEdge[73, 200] -> 
             RGBColor[
              0.9799913922380148, 0.9845308002080403, 0.9157355190604124], 
             UndirectedEdge[196, 447] -> 
             RGBColor[
              0.6831974399273634, 0.7493565392559481, 0.9688559848771462], 
             UndirectedEdge[68, 492] -> 
             RGBColor[
              0.6280551244054082, 0.7002520476522422, 0.9528449230819367], 
             UndirectedEdge[25, 413] -> 
             RGBColor[
              0.8601470218261107, 0.8910921486351957, 0.9603376474630891], 
             UndirectedEdge[220, 426] -> 
             RGBColor[
              0.6833247513212202, 0.7525377562833788, 0.9690710832449874], 
             UndirectedEdge[21, 354] -> 
             RGBColor[
              0.985704149614242, 0.9883563127259616, 0.8865827675742524], 
             UndirectedEdge[125, 269] -> 
             RGBColor[
              0.9876521729230971, 0.9887270811781077, 0.8348282291727155], 
             UndirectedEdge[241, 304] -> 
             RGBColor[
              0.7680933577611944, 0.7256989378842476, 0.6123430918852315], 
             UndirectedEdge[93, 456] -> 
             RGBColor[
              0.8722860041991201, 0.8996423806111833, 0.9174406656164786], 
             UndirectedEdge[295, 455] -> 
             RGBColor[
              0.9128720371030419, 0.9302896837231824, 0.8690258123986964], 
             UndirectedEdge[185, 386] -> 
             RGBColor[
              0.9560189572699913, 0.9255834393253842, 0.6439293551908771], 
             UndirectedEdge[233, 400] -> 
             RGBColor[
              0.9545054728602385, 0.8572586328610069, 0.553556995620943], 
             UndirectedEdge[83, 317] -> 
             RGBColor[
              0.7249827831165132, 0.7850813273346298, 0.9732231665379014], 
             UndirectedEdge[88, 465] -> 
             RGBColor[
              0.9785376552053404, 0.9640997406595972, 0.6519225418652693], 
             UndirectedEdge[418, 431] -> 
             RGBColor[
              0.8627458367434713, 0.8891206516941397, 0.7210323847124921], 
             UndirectedEdge[121, 307] -> 
             RGBColor[
              0.6330675442580772, 0.6961604390582492, 0.7327779803490655], 
             UndirectedEdge[64, 74] -> 
             RGBColor[
              0.9723590243775175, 0.9760157403407492, 0.7660264159494133], 
             UndirectedEdge[185, 358] -> 
             RGBColor[
              0.9667031728913168, 0.9744814207505312, 0.9320021894121543], 
             UndirectedEdge[113, 315] -> 
             RGBColor[
              0.9643182796666421, 0.9728658562522242, 0.9433424694406422], 
             UndirectedEdge[47, 91] -> 
             RGBColor[
              0.8807858286144589, 0.9077787277154983, 0.9884913326916802], 
             UndirectedEdge[158, 401] -> 
             RGBColor[
              0.9780543971312524, 0.9434596865668414, 0.5672049169320558], 
             UndirectedEdge[90, 232] -> 
             RGBColor[
              0.9895519102696952, 0.9899474606399299, 0.8228154158280175], 
             UndirectedEdge[58, 115] -> 
             RGBColor[
              0.6624047804933797, 0.7360498043989314, 0.9670851897065682], 
             UndirectedEdge[132, 494] -> 
             RGBColor[
              0.9752504269701641, 0.9778339266288998, 0.7342959507456326], 
             UndirectedEdge[167, 300] -> 
             RGBColor[
              0.723198534232006, 0.7834117321971585, 0.9732485430734357], 
             UndirectedEdge[284, 389] -> 
             RGBColor[
              0.9735085697880113, 0.9771086845972893, 0.7827755915182186], 
             UndirectedEdge[103, 233] -> 
             RGBColor[
              0.9912111410530218, 0.9900546460538915, 0.7532341759094283], 
             UndirectedEdge[172, 300] -> 
             RGBColor[
              0.7671742327448109, 0.6969980593593607, 0.6058344988265871], 
             UndirectedEdge[70, 76] -> 
             RGBColor[
              0.9571759808071649, 0.9675824971206551, 0.9573740735871785], 
             UndirectedEdge[57, 73] -> 
             RGBColor[
              0.7234793438864746, 0.7815232673802787, 0.9390469361358048], 
             UndirectedEdge[287, 473] -> 
             RGBColor[
              0.9942461014472521, 0.990101317741082, 0.6151018353582172], 
             UndirectedEdge[395, 443] -> 
             RGBColor[
              0.7428102369869989, 0.7968091692308864, 0.9278790037754572], 
             UndirectedEdge[100, 397] -> 
             RGBColor[
              0.973728250761809, 0.9772650998356982, 0.781814787513285], 
             UndirectedEdge[57, 234] -> 
             RGBColor[
              0.716858506015216, 0.7329234080337852, 0.6294890272960791], 
             UndirectedEdge[343, 403] -> 
             RGBColor[
              0.9076205717823449, 0.9291760235078719, 0.9910508544506913], 
             UndirectedEdge[105, 425] -> 
             RGBColor[
              0.8282348268862118, 0.8662415502333995, 0.9833819615663391], 
             UndirectedEdge[133, 423] -> 
             RGBColor[
              0.9937847568295927, 0.9910952391955264, 0.708862643099738], 
             UndirectedEdge[92, 494] -> 
             RGBColor[
              0.9657031682424262, 0.9739420595478852, 0.9429397695059532], 
             UndirectedEdge[51, 100] -> 
             RGBColor[
              0.9174407988163849, 0.936551205401297, 0.9762054265898412], 
             UndirectedEdge[6, 347] -> 
             RGBColor[
              0.7876654103372916, 0.8325937516988846, 0.9050374115124867], 
             UndirectedEdge[333, 461] -> 
             RGBColor[
              0.878056827491517, 0.9056026962968267, 0.9882310381283661], 
             UndirectedEdge[291, 394] -> 
             RGBColor[
              0.9855225474883578, 0.9865944148838214, 0.8041531219924505], 
             UndirectedEdge[143, 386] -> 
             RGBColor[
              0.976563395396208, 0.9326049708742692, 0.36345364605602387`], 
             UndirectedEdge[123, 437] -> 
             RGBColor[
              0.7640302637030898, 0.8129062776677871, 0.8823000021852399], 
             UndirectedEdge[72, 453] -> 
             RGBColor[
              0.9725255061801279, 0.9189842224069567, 0.3477672089429481], 
             UndirectedEdge[391, 478] -> 
             RGBColor[
              0.941757566234669, 0.8528572984332075, 0.6055588011008677], 
             UndirectedEdge[328, 464] -> 
             RGBColor[
              0.815708512000292, 0.8568126540733979, 0.9779891620442653], 
             UndirectedEdge[149, 173] -> 
             RGBColor[
              0.6515581488174492, 0.7241969592808671, 0.9682211802161351], 
             UndirectedEdge[54, 186] -> 
             RGBColor[
              0.9816182121222234, 0.9858058725006884, 0.9157489400983467], 
             UndirectedEdge[355, 444] -> 
             RGBColor[
              0.8259015657382182, 0.8644171358336246, 0.9608624907942473], 
             UndirectedEdge[7, 448] -> 
             RGBColor[
              0.9575954438314198, 0.9664552282602924, 0.8951906257597786], 
             UndirectedEdge[47, 416] -> 
             RGBColor[
              0.9412557337627379, 0.955096830637847, 0.9630915669659986], 
             UndirectedEdge[48, 155] -> 
             RGBColor[
              0.7481971327234107, 0.7976503635605303, 0.7228053950088827], 
             UndirectedEdge[346, 486] -> 
             RGBColor[
              0.9572222860400326, 0.9676170314875099, 0.9572956909062726], 
             UndirectedEdge[24, 491] -> 
             RGBColor[
              0.9787659919563387, 0.9537746522605368, 0.6246746744486135], 
             UndirectedEdge[321, 373] -> 
             RGBColor[
              0.9709855309973336, 0.914716884248107, 0.5282586465831232], 
             UndirectedEdge[209, 231] -> 
             RGBColor[
              0.9108683928264295, 0.9291957774333031, 0.8907090618043344], 
             UndirectedEdge[210, 393] -> 
             RGBColor[
              0.839559078722885, 0.8740112877719908, 0.9112508770517838], 
             UndirectedEdge[188, 409] -> 
             RGBColor[
              0.8286685226222674, 0.8669930274960804, 0.9821112839529884], 
             UndirectedEdge[307, 427] -> 
             RGBColor[
              0.9895497374781811, 0.9883523574417137, 0.7069695726992904], 
             UndirectedEdge[178, 186] -> 
             RGBColor[
              0.9866306726621012, 0.9878786537482881, 0.8326794971205165], 
             UndirectedEdge[328, 475] -> 
             RGBColor[
              0.9585904610343697, 0.9444754048223959, 0.6756093615185486], 
             UndirectedEdge[213, 337] -> 
             RGBColor[
              0.9618520617442694, 0.9477078700441981, 0.6717865045421803], 
             UndirectedEdge[384, 458] -> 
             RGBColor[
              0.9900805849396539, 0.9890869636796472, 0.7356134562291157], 
             UndirectedEdge[87, 473] -> 
             RGBColor[
              0.9896927236769479, 0.9888832633398985, 0.7388931602048816], 
             UndirectedEdge[112, 440] -> 
             RGBColor[
              0.6559389558817341, 0.7297302817073454, 0.9673079291638582], 
             UndirectedEdge[237, 429] -> 
             RGBColor[
              0.96125749480547, 0.877085102928658, 0.3242495449515389], 
             UndirectedEdge[109, 230] -> 
             RGBColor[
              0.9708754103481718, 0.9134180617048429, 0.34135689823024984`], 
             UndirectedEdge[89, 262] -> 
             RGBColor[
              0.9751682040450234, 0.9798049606996386, 0.8733538151791758], 
             UndirectedEdge[280, 383] -> 
             RGBColor[
              0.8420088586279135, 0.8768687651230553, 0.9847901657949374], 
             UndirectedEdge[196, 489] -> 
             RGBColor[
              0.9449681006639572, 0.9584778800984199, 0.9780388303445529], 
             UndirectedEdge[279, 459] -> 
             RGBColor[
              0.9616578350664442, 0.9424456498447167, 0.661252079561226], 
             UndirectedEdge[191, 423] -> 
             RGBColor[
              0.9766280235931797, 0.9797607857590782, 0.8033315354549244], 
             UndirectedEdge[116, 165] -> 
             RGBColor[
              0.8640512237039144, 0.8945725407042122, 0.9868586741874763], 
             UndirectedEdge[176, 313] -> 
             RGBColor[
              0.8943114341047786, 0.9137380843481823, 0.7208264234295995], 
             UndirectedEdge[180, 490] -> 
             RGBColor[
              0.9734878433463658, 0.9781696136364288, 0.8590853606326949], 
             UndirectedEdge[17, 498] -> 
             RGBColor[
              0.9481873555491057, 0.9475281351196347, 0.6951596620564623], 
             UndirectedEdge[108, 364] -> 
             RGBColor[
              0.9872094964154681, 0.9681304688114536, 0.43765995486179077`], 
             UndirectedEdge[29, 254] -> 
             RGBColor[
              0.9062202923424489, 0.9254847111312325, 0.8900574132119575], 
             UndirectedEdge[7, 261] -> 
             RGBColor[
              0.9554357348114082, 0.9655621330785275, 0.93098259336915], 
             UndirectedEdge[122, 224] -> 
             RGBColor[
              0.5460161582494076, 0.6347358495529084, 0.9602015352953008], 
             UndirectedEdge[116, 386] -> 
             RGBColor[
              0.8835171635132787, 0.8682264900681653, 0.6479501458765853], 
             UndirectedEdge[8, 439] -> 
             RGBColor[
              0.45581914320058364`, 0.5482564464197011, 0.9537472357591732], 
             UndirectedEdge[226, 488] -> 
             RGBColor[
              0.7138298912322678, 0.7633650558098681, 0.678798374650869], 
             UndirectedEdge[64, 170] -> 
             RGBColor[
              0.9482597237277661, 0.9609327671898704, 0.9724669710903138], 
             UndirectedEdge[178, 313] -> 
             RGBColor[
              0.8950198925720163, 0.9161431521708838, 0.8626129550172323], 
             UndirectedEdge[81, 251] -> 
             RGBColor[
              0.9648363609394275, 0.8856044726579722, 0.458383084797459], 
             UndirectedEdge[186, 288] -> 
             RGBColor[
              0.8818071253213124, 0.907762159277478, 0.9497895870573935], 
             UndirectedEdge[45, 118] -> 
             RGBColor[
              0.9281157997184212, 0.9422754093446686, 0.8631309252772917], 
             UndirectedEdge[224, 330] -> 
             RGBColor[
              0.6189115949417086, 0.6925380927893328, 0.9631942348301996], 
             UndirectedEdge[35, 410] -> 
             RGBColor[
              0.7786189819457542, 0.8271193566235835, 0.9785327598572182], 
             UndirectedEdge[163, 379] -> 
             RGBColor[
              0.9482395828828044, 0.9609177461806757, 0.9725010642872602], 
             UndirectedEdge[181, 443] -> 
             RGBColor[
              0.9891455067395813, 0.9882522460040681, 0.7185424302012894], 
             UndirectedEdge[167, 235] -> 
             RGBColor[
              0.9071991657063436, 0.9204601020465085, 0.6995103323402385], 
             UndirectedEdge[202, 279] -> 
             RGBColor[
              0.9676480571566062, 0.9751451937258542, 0.9285702583292179], 
             UndirectedEdge[242, 310] -> 
             RGBColor[
              0.9375235203302712, 0.9484947504869077, 0.7652137369944256], 
             UndirectedEdge[299, 482] -> 
             RGBColor[
              0.946090916315907, 0.9553670755589436, 0.7693476920237636], 
             UndirectedEdge[56, 110] -> 
             RGBColor[
              0.987602519724039, 0.9887929086463796, 0.8395185037437378], 
             UndirectedEdge[125, 419] -> 
             RGBColor[
              0.9871064487172153, 0.9862204327144223, 0.6780693079736673], 
             UndirectedEdge[262, 448] -> 
             RGBColor[
              0.9750044333482548, 0.9797372373078098, 0.8760679194496093], 
             UndirectedEdge[95, 212] -> 
             RGBColor[
              0.8989201491024958, 0.9197033369101146, 0.8862757501297129], 
             UndirectedEdge[32, 260] -> 
             RGBColor[
              0.9890517508708281, 0.9897406318749881, 0.8311043514382788], 
             UndirectedEdge[421, 430] -> 
             RGBColor[
              0.927490408213999, 0.9288107337954661, 0.6899281650859377], 
             UndirectedEdge[129, 346] -> 
             RGBColor[
              0.648668949248131, 0.7189033407191822, 0.9586821214992336], 
             UndirectedEdge[16, 17] -> 
             RGBColor[
              0.9392173045879977, 0.9535434373169791, 0.9653932436904911], 
             UndirectedEdge[153, 466] -> 
             RGBColor[
              0.8877647439464802, 0.9132921952251418, 0.987377339741689], 
             UndirectedEdge[244, 391] -> 
             RGBColor[
              0.9724215892404824, 0.9787641557296217, 0.9231262142351968], 
             UndirectedEdge[218, 406] -> 
             RGBColor[
              0.8895585575947669, 0.9053392304608598, 0.6958560630416617], 
             UndirectedEdge[99, 288] -> 
             RGBColor[
              0.8149647283888622, 0.8555807361650838, 0.9821373705164382], 
             UndirectedEdge[399, 481] -> 
             RGBColor[
              0.9906829984238578, 0.9886933534616341, 0.6789106795595103], 
             UndirectedEdge[278, 451] -> 
             RGBColor[
              0.8735442968919221, 0.9014446389576329, 0.9559244331995924], 
             UndirectedEdge[179, 327] -> 
             RGBColor[
              0.6132633098102083, 0.6779837166223506, 0.874778812212215], 
             UndirectedEdge[38, 473] -> 
             RGBColor[
              0.654711792952513, 0.7185882162250756, 0.763779399941477], 
             UndirectedEdge[17, 176] -> 
             RGBColor[
              0.9517503165752962, 0.9593427321482056, 0.7263568903816902], 
             UndirectedEdge[186, 373] -> 
             RGBColor[
              0.964366279131635, 0.9111188534261074, 0.5994083942865385], 
             UndirectedEdge[399, 496] -> 
             RGBColor[
              0.8173181835350855, 0.8538820145740489, 0.7377597786596959], 
             UndirectedEdge[116, 358] -> 
             RGBColor[
              0.8942013791346042, 0.9171244714933123, 0.9360229800978623], 
             UndirectedEdge[71, 135] -> 
             RGBColor[
              0.9515647548001718, 0.9613325223181126, 0.880980526993644], 
             UndirectedEdge[53, 374] -> 
             RGBColor[
              0.99510750358982, 0.9919437698229185, 0.7088601426189302], 
             UndirectedEdge[228, 409] -> 
             RGBColor[
              0.7885997342487464, 0.6098874201629741, 0.5874378635654036], 
             UndirectedEdge[440, 471] -> 
             RGBColor[
              0.7713354531767376, 0.8184129334017252, 0.8651491357337816], 
             UndirectedEdge[403, 471] -> 
             RGBColor[
              0.937028622002694, 0.9497641780006247, 0.8805655880490209], 
             UndirectedEdge[63, 166] -> 
             RGBColor[
              0.7448859115389417, 0.8007506469293735, 0.9752641722670224], 
             UndirectedEdge[159, 272] -> 
             RGBColor[
              0.9613606884853613, 0.948086162848297, 0.6741992519571899], 
             UndirectedEdge[130, 351] -> 
             RGBColor[
              0.9012951994144377, 0.9241323432793617, 0.9904475347875137], 
             UndirectedEdge[113, 378] -> 
             RGBColor[
              0.9651361497303783, 0.9732040665418811, 0.9297882459046577], 
             UndirectedEdge[145, 417] -> 
             RGBColor[
              0.9808314770814914, 0.9836733546251354, 0.8478578413236648], 
             UndirectedEdge[38, 354] -> 
             RGBColor[
              0.6507863596934338, 0.7180873759560829, 0.9104226007915939], 
             UndirectedEdge[334, 446] -> 
             RGBColor[
              0.9442015160729142, 0.9559979633365872, 0.9035830480193969], 
             UndirectedEdge[305, 310] -> 
             RGBColor[
              0.9928351119047685, 0.9868327423686234, 0.48283451696704327`], 
             UndirectedEdge[338, 383] -> 
             RGBColor[
              0.9064998746664652, 0.9242014638651028, 0.7974647948277163], 
             UndirectedEdge[243, 477] -> 
             RGBColor[
              0.9512043926310256, 0.9608306707085278, 0.8716314514121284], 
             UndirectedEdge[38, 221] -> 
             RGBColor[
              0.6539051547364543, 0.7193770778557486, 0.8587360957458993], 
             UndirectedEdge[330, 357] -> 
             RGBColor[
              0.9669933448109705, 0.9720273927976435, 0.7761697651877132], 
             UndirectedEdge[48, 365] -> 
             RGBColor[
              0.7483063915726862, 0.7995682923984768, 0.8571236663512694], 
             UndirectedEdge[384, 411] -> 
             RGBColor[
              0.9573316022016233, 0.9671917913537775, 0.9362850054904788], 
             UndirectedEdge[38, 436] -> 
             RGBColor[
              0.6443856410957969, 0.7136357110267961, 0.9356762933605629], 
             UndirectedEdge[117, 155] -> 
             RGBColor[
              0.7836292596907823, 0.8264157604317723, 0.7255947418359119], 
             UndirectedEdge[68, 286] -> 
             RGBColor[
              0.6135894248128706, 0.689153704920316, 0.9665889663107053], 
             UndirectedEdge[378, 380] -> 
             RGBColor[
              0.949019664271893, 0.838567965823539, 0.5641106535734226], 
             UndirectedEdge[12, 285] -> 
             RGBColor[
              0.9524987570262546, 0.9640942312831033, 0.9652913934329254], 
             UndirectedEdge[93, 432] -> 
             RGBColor[
              0.9626059640158742, 0.8901018059738901, 0.5636344343029702], 
             UndirectedEdge[340, 499] -> 
             RGBColor[
              0.9128020558113044, 0.9322278638507691, 0.9541100004630978], 
             UndirectedEdge[389, 456] -> 
             RGBColor[
              0.875643154848767, 0.9000247547277592, 0.788686119778472], 
             UndirectedEdge[390, 451] -> 
             RGBColor[
              0.8721928026925273, 0.8651823947199988, 0.6552949561391896], 
             UndirectedEdge[92, 485] -> 
             RGBColor[
              0.7831593945547872, 0.830013435383431, 0.9447969501074349], 
             UndirectedEdge[293, 471] -> 
             RGBColor[
              0.9447966290021659, 0.9559581759250708, 0.8813065074912123], 
             UndirectedEdge[111, 359] -> 
             RGBColor[
              0.878931465494606, 0.9054623804808356, 0.9468053619538475], 
             UndirectedEdge[357, 441] -> 
             RGBColor[
              0.9942152304266249, 0.9900352877494991, 0.6117417152767921], 
             UndirectedEdge[52, 268] -> 
             RGBColor[
              0.9888948748103898, 0.9874645451360538, 0.6729722455272894], 
             UndirectedEdge[30, 311] -> 
             RGBColor[
              0.9553263171065307, 0.963432617061174, 0.8270931069486664], 
             UndirectedEdge[164, 486] -> 
             RGBColor[
              0.80757851858136, 0.849986836883877, 0.9531544361324467], 
             UndirectedEdge[194, 290] -> 
             RGBColor[
              0.8023449754370877, 0.8155431345683217, 0.6558600126783357], 
             UndirectedEdge[238, 445] -> 
             RGBColor[
              0.6640870639553862, 0.7276459999133083, 0.8391644968977852], 
             UndirectedEdge[269, 406] -> 
             RGBColor[
              0.8918929498623691, 0.9137961830366133, 0.8666462794483035], 
             UndirectedEdge[99, 341] -> 
             RGBColor[
              0.8513605684519115, 0.8843158239892924, 0.9856847251091366], 
             UndirectedEdge[41, 457] -> 
             RGBColor[
              0.7983830661808156, 0.80634564259862, 0.6466606193366032], 
             UndirectedEdge[217, 292] -> 
             RGBColor[
              0.8623778239867771, 0.8931006844973595, 0.9867355607772723], 
             UndirectedEdge[176, 299] -> 
             RGBColor[
              0.993234002796521, 0.9879365410660383, 0.5049411431749736], 
             UndirectedEdge[218, 314] -> 
             RGBColor[
              0.9890606243156869, 0.974761058508564, 0.4120030205045446], 
             UndirectedEdge[355, 486] -> 
             RGBColor[
              0.8291830611407476, 0.8668644697318754, 0.9553077750288375], 
             UndirectedEdge[213, 420] -> 
             RGBColor[
              0.9515103132165521, 0.9633570515082552, 0.9669645709753181], 
             UndirectedEdge[299, 407] -> 
             RGBColor[
              0.9874827494648066, 0.9687403202554681, 0.46524281246711285`], 
             UndirectedEdge[201, 314] -> 
             RGBColor[
              0.9884890488056306, 0.9820163187282902, 0.6309526433905233], 
             UndirectedEdge[160, 300] -> 
             RGBColor[
              0.808357108838871, 0.8475107432298477, 0.8111241144058667], 
             UndirectedEdge[21, 200] -> 
             RGBColor[
              0.9849379502021323, 0.9880394695786274, 0.8992806746934262], 
             UndirectedEdge[25, 180] -> 
             RGBColor[
              0.9590580506024816, 0.9689861416923959, 0.954188220346126], 
             UndirectedEdge[45, 185] -> 
             RGBColor[
              0.9712726162559893, 0.9763710030111613, 0.8562746875191731], 
             UndirectedEdge[191, 226] -> 
             RGBColor[
              0.9733988809986305, 0.9701521291172335, 0.6816048710945486], 
             UndirectedEdge[50, 82] -> 
             RGBColor[
              0.6023576854558552, 0.6858044061960582, 0.9632287301611053], 
             UndirectedEdge[22, 491] -> 
             RGBColor[
              0.8415410099449836, 0.8466155685566771, 0.660094229508782], 
             UndirectedEdge[99, 277] -> 
             RGBColor[
              0.9191756701678846, 0.93349718248578, 0.7336737462169163], 
             UndirectedEdge[17, 391] -> 
             RGBColor[
              0.935091769284912, 0.9504666198428819, 0.9723766988466804], 
             UndirectedEdge[211, 362] -> 
             RGBColor[
              0.9283091976991465, 0.9431558698826636, 0.8946856645015169], 
             UndirectedEdge[4, 162] -> 
             RGBColor[
              0.723781672673286, 0.7799135659695013, 0.8658757825619594], 
             UndirectedEdge[259, 444] -> 
             RGBColor[
              0.9692940471921404, 0.9766201311890572, 0.9368613480953119], 
             UndirectedEdge[347, 382] -> 
             RGBColor[
              0.7689284261531303, 0.8192435641574836, 0.9646903777747264], 
             UndirectedEdge[66, 179] -> 
             RGBColor[
              0.5950010777358334, 0.6653547986507187, 0.9500721232357557], 
             UndirectedEdge[343, 471] -> 
             RGBColor[
              0.9631754437244364, 0.9706129439049737, 0.8830594952463839], 
             UndirectedEdge[97, 322] -> 
             RGBColor[
              0.6900916862949522, 0.7528188265870637, 0.9326755161460016], 
             UndirectedEdge[363, 381] -> 
             RGBColor[
              0.995176491779151, 0.9920913285841216, 0.7163690812818575], 
             UndirectedEdge[238, 471] -> 
             RGBColor[
              0.9936910039022261, 0.9916590822268357, 0.75421992270603], 
             UndirectedEdge[40, 285] -> 
             RGBColor[
              0.7770178887656718, 0.825369403290813, 0.9534842047284859], 
             UndirectedEdge[70, 208] -> 
             RGBColor[
              0.9522017024497905, 0.9638726884663585, 0.9657942293466375], 
             UndirectedEdge[84, 448] -> 
             RGBColor[
              0.9743605608283368, 0.9297011946443489, 0.54388115746691], 
             UndirectedEdge[152, 195] -> 
             RGBColor[
              0.9842157910337876, 0.9573739932882109, 0.4819819121565203], 
             UndirectedEdge[93, 308] -> 
             RGBColor[
              0.7873928110777297, 0.8324810248995744, 0.9095550867076969], 
             UndirectedEdge[255, 478] -> 
             RGBColor[
              0.9407103972094166, 0.802211979241801, 0.27339983064638695`], 
             UndirectedEdge[112, 293] -> 
             RGBColor[
              0.8294001317071624, 0.8672755242306911, 0.9834653009212889], 
             UndirectedEdge[87, 184] -> 
             RGBColor[
              0.7917797216219039, 0.8364402714943722, 0.9265281593392971], 
             UndirectedEdge[149, 323] -> 
             RGBColor[
              0.9345334584877545, 0.9463841355878783, 0.7871057630024627], 
             UndirectedEdge[272, 497] -> 
             RGBColor[
              0.9825056400127268, 0.9634146781267716, 0.6186415881527844], 
             UndirectedEdge[80, 471] -> 
             RGBColor[
              0.9002691019562519, 0.9205503627992587, 0.8770336308172013], 
             UndirectedEdge[339, 344] -> 
             RGBColor[
              0.9666050434408258, 0.9729702362758933, 0.8677717328010295], 
             UndirectedEdge[137, 393] -> 
             RGBColor[
              0.9555655946824178, 0.861565459147226, 0.5549179141290757], 
             UndirectedEdge[11, 316] -> 
             RGBColor[
              0.8182602298371033, 0.8582792943165066, 0.9824329063290453], 
             UndirectedEdge[88, 423] -> 
             RGBColor[
              0.9875921518159185, 0.968523556384799, 0.515480337293671], 
             UndirectedEdge[70, 351] -> 
             RGBColor[
              0.9236240649768156, 0.9415475203250743, 0.9790815926168686], 
             UndirectedEdge[55, 298] -> 
             RGBColor[
              0.9779737655918097, 0.9819179198320283, 0.8695261632254857], 
             UndirectedEdge[428, 437] -> 
             RGBColor[
              0.7659387972164532, 0.8128237471619901, 0.7873030472103614], 
             UndirectedEdge[90, 137] -> 
             RGBColor[
              0.9590518235881735, 0.8630071043917522, 0.4971420790895025], 
             UndirectedEdge[344, 439] -> 
             RGBColor[
              0.8359156177070133, 0.8726176155059513, 0.9809658485829873], 
             UndirectedEdge[93, 274] -> 
             RGBColor[
              0.970860813733625, 0.9772553758083318, 0.9103293173461915], 
             UndirectedEdge[60, 434] -> 
             RGBColor[
              0.8331197860599435, 0.8698004727308163, 0.9486439266029383], 
             UndirectedEdge[54, 244] -> 
             RGBColor[
              0.9847761344582264, 0.9879725546100475, 0.9019623803356696], 
             UndirectedEdge[243, 318] -> 
             RGBColor[
              0.8470232468677376, 0.8787273901174222, 0.8614376999756627], 
             UndirectedEdge[384, 402] -> 
             RGBColor[
              0.9659340687785722, 0.9737922842690618, 0.9281299695688185], 
             UndirectedEdge[83, 233] -> 
             RGBColor[
              0.8732058576485882, 0.9002856601962952, 0.9141171590326375], 
             UndirectedEdge[153, 201] -> 
             RGBColor[
              0.9128787184900391, 0.9314032198514088, 0.9171486920164684], 
             UndirectedEdge[275, 331] -> 
             RGBColor[
              0.9923758394942768, 0.9903568857913423, 0.7208921313078185], 
             UndirectedEdge[312, 327] -> 
             RGBColor[
              0.9093698718558547, 0.9281755178725253, 0.8981487515366289], 
             UndirectedEdge[181, 370] -> 
             RGBColor[
              0.9939778994264745, 0.9895276607380226, 0.5859097005475865], 
             UndirectedEdge[32, 245] -> 
             RGBColor[
              0.8855768583695017, 0.9101706471029891, 0.9253561689530884], 
             UndirectedEdge[176, 391] -> 
             RGBColor[
              0.9761751684108946, 0.9782042551392252, 0.707392171608459], 
             UndirectedEdge[148, 232] -> 
             RGBColor[
              0.8769919246091955, 0.9038744801297787, 0.9431119820022895], 
             UndirectedEdge[430, 477] -> 
             RGBColor[
              0.9462898141614529, 0.9438008698016854, 0.6917212692076337], 
             UndirectedEdge[7, 475] -> 
             RGBColor[
              0.9505568656759262, 0.9381855493874078, 0.678861971012977], 
             UndirectedEdge[15, 50] -> 
             RGBColor[
              0.866368308749726, 0.8593523439675474, 0.6528453682223301], 
             UndirectedEdge[168, 395] -> 
             RGBColor[
              0.7443255627446297, 0.7974357953737625, 0.9027661344341602], 
             UndirectedEdge[97, 440] -> 
             RGBColor[
              0.4751045808405654, 0.5833059248734078, 0.9522202122830435], 
             UndirectedEdge[71, 308] -> 
             RGBColor[
              0.7489066830888886, 0.8036597486180106, 0.9759894638179019], 
             UndirectedEdge[253, 436] -> 
             RGBColor[
              0.979316781021148, 0.9839101683666329, 0.9116152160192408], 
             UndirectedEdge[13, 430] -> 
             RGBColor[
              0.9733813730052852, 0.9218712621752991, 0.35109208994179586`], 
             UndirectedEdge[209, 233] -> 
             RGBColor[
              0.9092405973572472, 0.9285226421743608, 0.9176858453283214], 
             UndirectedEdge[254, 350] -> 
             RGBColor[
              0.9818761794219759, 0.955011766570015, 0.5727919385888256], 
             UndirectedEdge[115, 268] -> 
             RGBColor[
              0.8423211093664849, 0.8730448562410811, 0.7093978093302907], 
             UndirectedEdge[42, 468] -> 
             RGBColor[
              0.8855383946171491, 0.9085552397155723, 0.8534654172266043], 
             UndirectedEdge[51, 60] -> 
             RGBColor[
              0.7864478358555564, 0.8335957506356655, 0.9792174187923319], 
             UndirectedEdge[331, 348] -> 
             RGBColor[
              0.9897495994800546, 0.9759125434603051, 0.5143881533783128], 
             UndirectedEdge[310, 406] -> 
             RGBColor[
              0.8918148907368935, 0.912289822891724, 0.7607898161571509], 
             UndirectedEdge[70, 130] -> 
             RGBColor[
              0.9284649702615446, 0.9454075267962436, 0.9795433224844532], 
             UndirectedEdge[83, 440] -> 
             RGBColor[
              0.6543438726939741, 0.7284841905979862, 0.9671489461786023], 
             UndirectedEdge[100, 374] -> 
             RGBColor[
              0.9741620894508465, 0.9781930369237295, 0.829035451472981], 
             UndirectedEdge[207, 374] -> 
             RGBColor[
              0.9222147475019099, 0.9372268371072376, 0.8398627575059288], 
             UndirectedEdge[51, 324] -> 
             RGBColor[
              0.9162524925617965, 0.9356649685422979, 0.9782169191189514], 
             UndirectedEdge[164, 180] -> 
             RGBColor[
              0.8007200717913476, 0.8448718184975617, 0.9647639975785309], 
             UndirectedEdge[56, 132] -> 
             RGBColor[
              0.987693465631342, 0.9871139244888003, 0.7132331319564992], 
             UndirectedEdge[30, 423] -> 
             RGBColor[
              0.9552780075391577, 0.9633292877814097, 0.821834908672207], 
             UndirectedEdge[104, 379] -> 
             RGBColor[
              0.9675996035062109, 0.9726860878883681, 0.7915322553621031], 
             UndirectedEdge[324, 457] -> 
             RGBColor[
              0.9593843916998577, 0.9329910086503758, 0.6486293022813119], 
             UndirectedEdge[283, 459] -> 
             RGBColor[
              0.8224045769569388, 0.83297104620549, 0.660092588439078], 
             UndirectedEdge[128, 245] -> 
             RGBColor[
              0.8270662818132755, 0.666165014621481, 0.5960272518472626], 
             UndirectedEdge[34, 62] -> 
             RGBColor[
              0.7506274871270546, 0.8051846644086575, 0.9757607479680246], 
             UndirectedEdge[320, 424] -> 
             RGBColor[
              0.9632524897026293, 0.9684497724672767, 0.7222269946470907], 
             UndirectedEdge[111, 351] -> 
             RGBColor[
              0.939237519833045, 0.9531920093921642, 0.9526520861864878], 
             UndirectedEdge[79, 316] -> 
             RGBColor[
              0.8145505865525018, 0.6175952865415735, 0.5884632646093897], 
             UndirectedEdge[43, 250] -> 
             RGBColor[
              0.9295508070074727, 0.8539792348629119, 0.6279821475348073], 
             UndirectedEdge[116, 313] -> 
             RGBColor[
              0.7993786565290535, 0.843199949074086, 0.9806382519306988], 
             UndirectedEdge[87, 436] -> 
             RGBColor[
              0.9793665718202317, 0.983930758141619, 0.9107900536239677], 
             UndirectedEdge[280, 393] -> 
             RGBColor[
              0.9264958909742386, 0.9422927644147971, 0.9198188597472101], 
             UndirectedEdge[295, 321] -> 
             RGBColor[
              0.9121507996904501, 0.9299914335181196, 0.880978582827933], 
             UndirectedEdge[131, 186] -> 
             RGBColor[
              0.9812180909962791, 0.9855130635343541, 0.9166770522236082], 
             UndirectedEdge[165, 313] -> 
             RGBColor[
              0.8604617196831394, 0.891768392881942, 0.9865009059725077], 
             UndirectedEdge[140, 270] -> 
             RGBColor[
              0.627033048733389, 0.6949402929536904, 0.928498704727978], 
             UndirectedEdge[322, 445] -> 
             RGBColor[
              0.6567186186842846, 0.7239127528018534, 0.9305490137884949], 
             UndirectedEdge[112, 463] -> 
             RGBColor[
              0.8778760740711875, 0.9028033979255798, 0.8633132261268999], 
             UndirectedEdge[115, 223] -> 
             RGBColor[
              0.7835456443150728, 0.8312771104969043, 0.9789418023545258], 
             UndirectedEdge[102, 451] -> 
             RGBColor[
              0.8849216266754076, 0.9071951473707129, 0.7833619010734405], 
             UndirectedEdge[148, 267] -> 
             RGBColor[
              0.8642751337126231, 0.8944212925154262, 0.9660252805282568], 
             UndirectedEdge[447, 500] -> 
             RGBColor[
              0.5968051309868792, 0.6809781185711741, 0.9628820978140191], 
             UndirectedEdge[238, 293] -> 
             RGBColor[
              0.9459041389596066, 0.9564161597541802, 0.8629522013525286], 
             UndirectedEdge[56, 457] -> 
             RGBColor[
              0.9749444949203712, 0.9445957081549041, 0.622290106253863], 
             UndirectedEdge[204, 331] -> 
             RGBColor[
              0.9638669911167563, 0.9700568257974636, 0.8128386439891095], 
             UndirectedEdge[66, 260] -> 
             RGBColor[
              0.9725625502974566, 0.9778449079938524, 0.8770139420317549], 
             UndirectedEdge[225, 424] -> 
             RGBColor[
              0.9928480446225331, 0.9871110155582355, 0.4629319777941452], 
             UndirectedEdge[178, 244] -> 
             RGBColor[
              0.9897885949981042, 0.9900453358576471, 0.8188929373578393], 
             UndirectedEdge[139, 247] -> 
             RGBColor[
              0.7993565455450006, 0.8388061260829054, 0.6958722382810152], 
             UndirectedEdge[244, 448] -> 
             RGBColor[
              0.9881952836571162, 0.9893864606719148, 0.8452982296355833], 
             UndirectedEdge[259, 275] -> 
             RGBColor[
              0.9842494611291315, 0.9867509985257426, 0.8657401567128427], 
             UndirectedEdge[282, 406] -> 
             RGBColor[
              0.8926377406723196, 0.9140498157007102, 0.8503519535871187], 
             UndirectedEdge[286, 357] -> 
             RGBColor[
              0.9587401952385904, 0.9655623596986338, 0.7793975817249048], 
             UndirectedEdge[206, 396] -> 
             RGBColor[
              0.8728794833822594, 0.9012066321735401, 0.9701000912296383], 
             UndirectedEdge[154, 295] -> 
             RGBColor[
              0.8872849799844202, 0.9127851422768138, 0.9830150104179594], 
             UndirectedEdge[410, 428] -> 
             RGBColor[
              0.9156041386768043, 0.9314851531973749, 0.8010867990826731], 
             UndirectedEdge[104, 147] -> 
             RGBColor[
              0.9429916511812501, 0.9532037997953156, 0.7940190835377577], 
             UndirectedEdge[32, 255] -> 
             RGBColor[
              0.9720166750045133, 0.9283844253987792, 0.5803234198201771], 
             UndirectedEdge[165, 498] -> 
             RGBColor[
              0.9554210402534491, 0.9532960789497377, 0.6958496173611491], 
             UndirectedEdge[248, 439] -> 
             RGBColor[
              0.8364439244969955, 0.873011625844897, 0.9800715629920261], 
             UndirectedEdge[141, 389] -> 
             RGBColor[
              0.9936392336536399, 0.9888032888942915, 0.5490480211774216], 
             UndirectedEdge[328, 478] -> 
             RGBColor[
              0.932096289887388, 0.8456519343522935, 0.621912821892382], 
             UndirectedEdge[178, 261] -> 
             RGBColor[
              0.9904976122747544, 0.9903385327224549, 0.8071426862058498], 
             UndirectedEdge[120, 315] -> 
             RGBColor[
              0.9852729351421301, 0.9881779944600368, 0.8937291073244263], 
             UndirectedEdge[47, 136] -> 
             RGBColor[
              0.9530381481138425, 0.9612353543484782, 0.7966594385980781], 
             UndirectedEdge[74, 144] -> 
             RGBColor[
              0.991814849458305, 0.9895855377310183, 0.6909830998498462], 
             UndirectedEdge[165, 361] -> 
             RGBColor[
              0.8730005180312745, 0.9015709323830934, 0.9877487628182273], 
             UndirectedEdge[32, 482] -> 
             RGBColor[
              0.9425793048395359, 0.9553363913884145, 0.9308691306584574], 
             UndirectedEdge[67, 119] -> 
             RGBColor[
              0.47131211741296464`, 0.5778791850010452, 0.9525703728502231], 
             UndirectedEdge[97, 326] -> 
             RGBColor[
              0.6543202055021129, 0.7254396086983226, 0.9689264485075204], 
             UndirectedEdge[409, 430] -> 
             RGBColor[
              0.8521448798718222, 0.8695379538918334, 0.6825278335371334], 
             UndirectedEdge[113, 190] -> 
             RGBColor[
              0.9657469406480466, 0.9633747772639459, 0.6922850409175967], 
             UndirectedEdge[292, 496] -> 
             RGBColor[
              0.733068372294454, 0.7914212152313289, 0.9740293266722739], 
             UndirectedEdge[15, 82] -> 
             RGBColor[
              0.7035452207277555, 0.7286724472426767, 0.6388443718378962], 
             UndirectedEdge[340, 414] -> 
             RGBColor[
              0.9863873237115944, 0.9874720294806179, 0.8211503258607984], 
             UndirectedEdge[149, 282] -> 
             RGBColor[
              0.9351523770455852, 0.947707939800813, 0.8544712284997477], 
             UndirectedEdge[330, 368] -> 
             RGBColor[
              0.9649075183061983, 0.97244600053937, 0.9038634327694393], 
             UndirectedEdge[331, 431] -> 
             RGBColor[
              0.9936491600907333, 0.9888245205395174, 0.5501284525961646], 
             UndirectedEdge[4, 488] -> 
             RGBColor[
              0.7157905830758571, 0.7730517877446093, 0.8653501015749957], 
             UndirectedEdge[87, 409] -> 
             RGBColor[
              0.8528528509366922, 0.8848282145319519, 0.9321523867885468], 
             UndirectedEdge[440, 445] -> 
             RGBColor[
              0.4417315132298978, 0.5543998510881977, 0.9500937099255368], 
             UndirectedEdge[55, 200] -> 
             RGBColor[
              0.9879326764504912, 0.989277865843278, 0.8496503106550225], 
             UndirectedEdge[64, 215] -> 
             RGBColor[
              0.8169278302324481, 0.8575749366243339, 0.9684798574409209], 
             UndirectedEdge[167, 493] -> 
             RGBColor[
              0.8988040635229221, 0.8921414511180965, 0.6668969456396674], 
             UndirectedEdge[153, 470] -> 
             RGBColor[
              0.9159650507766481, 0.9326794975670436, 0.8660001788554328], 
             UndirectedEdge[185, 187] -> 
             RGBColor[
              0.96766230504162, 0.9748780465432535, 0.916106887527193], 
             UndirectedEdge[18, 310] -> 
             RGBColor[
              0.954189051815004, 0.9617833929190327, 0.766803310264935], 
             UndirectedEdge[226, 366] -> 
             RGBColor[
              0.8788652978565827, 0.8957732326411346, 0.6930198742782918], 
             UndirectedEdge[333, 361] -> 
             RGBColor[
              0.8225988539574618, 0.8613820135673601, 0.9829414071047704], 
             UndirectedEdge[236, 300] -> 
             RGBColor[
              0.8009180722923162, 0.8442467115654874, 0.9412593514711998], 
             UndirectedEdge[161, 335] -> 
             RGBColor[
              0.9734707956707292, 0.9794073566259669, 0.9151122424836097], 
             UndirectedEdge[61, 397] -> 
             RGBColor[
              0.9902180491272206, 0.9776764098105328, 0.5005895366581856], 
             UndirectedEdge[393, 480] -> 
             RGBColor[
              0.9588842026531468, 0.8747226338906169, 0.5575881440000651], 
             UndirectedEdge[349, 378] -> 
             RGBColor[
              0.9900938823264815, 0.9891510736684522, 0.7396534979991043], 
             UndirectedEdge[97, 163] -> 
             RGBColor[
              0.6777475838648636, 0.7436126152063162, 0.9535708617026026], 
             UndirectedEdge[229, 267] -> 
             RGBColor[
              0.9764443675469822, 0.9803326871036045, 0.8522044833464433], 
             UndirectedEdge[77, 287] -> 
             RGBColor[
              0.9805698877256217, 0.9826503418891723, 0.792669509678533], 
             UndirectedEdge[41, 485] -> 
             RGBColor[
              0.6105465120189026, 0.6947081891206934, 0.9624836044131447], 
             UndirectedEdge[7, 89] -> 
             RGBColor[
              0.9577592145281884, 0.9665229516521212, 0.8924765214893451], 
             UndirectedEdge[41, 44] -> 
             RGBColor[
              0.7873097413942728, 0.7659422855436172, 0.6195295474003268], 
             UndirectedEdge[147, 234] -> 
             RGBColor[
              0.9270166501003756, 0.9002979508172471, 0.6484926769672095], 
             UndirectedEdge[259, 331] -> 
             RGBColor[
              0.9862765745267577, 0.9868309198554761, 0.777022172538553], 
             UndirectedEdge[77, 409] -> 
             RGBColor[
              0.8434648300716538, 0.8780280893651029, 0.9570649949362162], 
             UndirectedEdge[2, 334] -> 
             RGBColor[
              0.9413063099699355, 0.9399877716365677, 0.6914822205970517], 
             UndirectedEdge[315, 487] -> 
             RGBColor[
              0.822386095952717, 0.8612022908632522, 0.9370481263240451], 
             UndirectedEdge[251, 258] -> 
             RGBColor[
              0.9945059498883695, 0.9906571072819246, 0.6433847345751542], 
             UndirectedEdge[39, 96] -> 
             RGBColor[
              0.9616573180033068, 0.9487481616061939, 0.6746328131090228], 
             UndirectedEdge[219, 497] -> 
             RGBColor[
              0.990754817656164, 0.9899092105441304, 0.7639416127539786], 
             UndirectedEdge[447, 454] -> 
             RGBColor[
              0.6978991128706009, 0.7603210228652346, 0.943969887394652], 
             UndirectedEdge[417, 458] -> 
             RGBColor[
              0.9810820616402023, 0.9826978602572618, 0.765264554542278], 
             UndirectedEdge[189, 422] -> 
             RGBColor[
              0.9836807621111343, 0.9858824518901612, 0.8468011456675343], 
             UndirectedEdge[431, 444] -> 
             RGBColor[
              0.9766666327561162, 0.9786137318730985, 0.7099676281529235], 
             UndirectedEdge[161, 273] -> 
             RGBColor[
              0.9597094053596247, 0.8808137616467475, 0.5720489813664182], 
             UndirectedEdge[109, 413] -> 
             RGBColor[
              0.8703474432451469, 0.8853706421102612, 0.6866971334846006], 
             UndirectedEdge[236, 470] -> 
             RGBColor[
              0.9869300863498937, 0.9881286199982728, 0.8333667367761651], 
             UndirectedEdge[287, 436] -> 
             RGBColor[
              0.983919949590536, 0.9851488125428025, 0.786998728777303], 
             UndirectedEdge[253, 473] -> 
             RGBColor[
              0.9896429328778643, 0.9888626735649124, 0.7397183226001549], 
             UndirectedEdge[166, 435] -> 
             RGBColor[
              0.8913876895345525, 0.9162323638333327, 0.9895025476506317], 
             UndirectedEdge[114, 312] -> 
             RGBColor[
              0.9023784772480264, 0.9239523720291413, 0.9543634746345115], 
             UndirectedEdge[222, 296] -> 
             RGBColor[
              0.9928086104030016, 0.991294189838428, 0.7688434665493535], 
             UndirectedEdge[5, 346] -> 
             RGBColor[
              0.965885612759965, 0.974055607841956, 0.9416225128178284], 
             UndirectedEdge[86, 220] -> 
             RGBColor[
              0.8304235373018884, 0.8636395219478255, 0.6993326032971567], 
             UndirectedEdge[195, 255] -> 
             RGBColor[
              0.975808687507568, 0.9290148590124916, 0.4493219025054419], 
             UndirectedEdge[313, 407] -> 
             RGBColor[
              0.8885601807730645, 0.8945418635376121, 0.6811280927217387], 
             UndirectedEdge[224, 441] -> 
             RGBColor[
              0.6461334805573629, 0.7105459877411884, 0.7987661849192784], 
             UndirectedEdge[172, 211] -> 
             RGBColor[
              0.9515358903488312, 0.840197502986374, 0.5252925615525876], 
             UndirectedEdge[204, 355] -> 
             RGBColor[
              0.8123481312976889, 0.854247943176431, 0.9816878120930692], 
             UndirectedEdge[109, 180] -> 
             RGBColor[
              0.9692584720215178, 0.9632646351674614, 0.6805477063676373], 
             UndirectedEdge[96, 157] -> 
             RGBColor[
              0.8707050693629245, 0.899694545642416, 0.9793281277469568], 
             UndirectedEdge[316, 372] -> 
             RGBColor[
              0.8852390023619515, 0.9078739818726262, 0.8179062859380481], 
             UndirectedEdge[53, 112] -> 
             RGBColor[
              0.8785162434040754, 0.9030336061088096, 0.850194848466616], 
             UndirectedEdge[28, 305] -> 
             RGBColor[
              0.9936508567362086, 0.9885775380786199, 0.5716233076757611], 
             UndirectedEdge[186, 341] -> 
             RGBColor[
              0.9182029653843617, 0.9364972471016867, 0.9533369416500919], 
             UndirectedEdge[65, 86] -> 
             RGBColor[
              0.9858314959654313, 0.9638360366067513, 0.40221469720074715`], 
             UndirectedEdge[10, 390] -> 
             RGBColor[
              0.9779099607261202, 0.9472791155505313, 0.5964111916015039], 
             UndirectedEdge[48, 140] -> 
             RGBColor[
              0.7418303205888741, 0.7962565508783768, 0.9360696573264341], 
             UndirectedEdge[231, 404] -> 
             RGBColor[
              0.9064493625436187, 0.579693983096704, 0.4831231587663463], 
             UndirectedEdge[87, 354] -> 
             RGBColor[
              0.9857672904178685, 0.9883824230709057, 0.8855363610549987], 
             UndirectedEdge[136, 434] -> 
             RGBColor[
              0.9844993671952077, 0.9853114523304285, 0.7646351332953907], 
             UndirectedEdge[205, 413] -> 
             RGBColor[
              0.870329871116732, 0.8985194003198361, 0.9356176315075628], 
             UndirectedEdge[20, 490] -> 
             RGBColor[
              0.8869427114565361, 0.909935953211292, 0.8664673047854319], 
             UndirectedEdge[390, 443] -> 
             RGBColor[
              0.9766613332386007, 0.9467627759961792, 0.6171041804140573], 
             UndirectedEdge[296, 385] -> 
             RGBColor[
              0.9448680023611136, 0.9563660293818963, 0.8965524404981802], 
             UndirectedEdge[86, 290] -> 
             RGBColor[
              0.8123905427767659, 0.8493967782754266, 0.6976413754139956], 
             UndirectedEdge[24, 74] -> 
             RGBColor[
              0.9893081006557464, 0.9885489326806547, 0.7325264147661901], 
             UndirectedEdge[38, 336] -> 
             RGBColor[
              0.6532820007328024, 0.7191193876609112, 0.8690633702572761], 
             UndirectedEdge[383, 443] -> 
             RGBColor[
              0.9017790530221648, 0.9231646883096913, 0.9422413439309787], 
             UndirectedEdge[14, 435] -> 
             RGBColor[
              0.8392364696201378, 0.8751570864816577, 0.9843933271068637], 
             UndirectedEdge[282, 323] -> 
             RGBColor[
              0.9946000719129614, 0.9908584247753303, 0.6536293360981738], 
             UndirectedEdge[307, 337] -> 
             RGBColor[
              0.9855149174836733, 0.9622259447093326, 0.44708948292447426`], 
             UndirectedEdge[157, 356] -> 
             RGBColor[
              0.8570340851286307, 0.8890287871467136, 0.9861757008203207], 
             UndirectedEdge[166, 439] -> 
             RGBColor[
              0.7970307676826015, 0.8417001084532042, 0.9803155106363113], 
             UndirectedEdge[266, 293] -> 
             RGBColor[
              0.8454675977898605, 0.8798275508517599, 0.9850667557814048], 
             UndirectedEdge[2, 260] -> 
             RGBColor[
              0.9878028647788759, 0.9744112358080226, 0.5917197408936072], 
             UndirectedEdge[135, 466] -> 
             RGBColor[
              0.9651947963454086, 0.9721494173301628, 0.8805009243993996], 
             UndirectedEdge[60, 495] -> 
             RGBColor[
              0.816710565869097, 0.8575625031801151, 0.9764204561759865], 
             UndirectedEdge[217, 464] -> 
             RGBColor[
              0.7955960659283274, 0.8408914509511164, 0.9800896799747207], 
             UndirectedEdge[435, 453] -> 
             RGBColor[
              0.944650013797829, 0.9217400154409758, 0.6610340089624175], 
             UndirectedEdge[82, 411] -> 
             RGBColor[
              0.684033875910875, 0.7504878293458843, 0.9711366245125801], 
             UndirectedEdge[94, 193] -> 
             RGBColor[
              0.9659284205351479, 0.9729106987243059, 0.8888489708414132], 
             UndirectedEdge[88, 469] -> 
             RGBColor[
              0.9856778875883975, 0.9683345712084881, 0.5910082004757427], 
             UndirectedEdge[36, 76] -> 
             RGBColor[
              0.97017562090152, 0.977277607418068, 0.9353690737565798], 
             UndirectedEdge[163, 326] -> 
             RGBColor[
              0.9319460400945354, 0.9480651425635467, 0.9757809282668856], 
             UndirectedEdge[151, 472] -> 
             RGBColor[
              0.9855182311512691, 0.9856765165797745, 0.7315845471864362], 
             UndirectedEdge[114, 138] -> 
             RGBColor[
              0.9812385983151065, 0.9851776680019342, 0.9009377303741509], 
             UndirectedEdge[448, 475] -> 
             RGBColor[
              0.9840254317982846, 0.962303073845603, 0.5814273561274207], 
             UndirectedEdge[169, 362] -> 
             RGBColor[
              0.9300229008209024, 0.9429456233252858, 0.7994903421756291], 
             UndirectedEdge[20, 25] -> 
             RGBColor[
              0.8725129187126519, 0.9007524812672589, 0.961570164498863], 
             UndirectedEdge[113, 349] -> 
             RGBColor[
              0.9691413275582039, 0.9738398041570568, 0.7892320459603859], 
             UndirectedEdge[457, 494] -> 
             RGBColor[
              0.9625014562591933, 0.9353157102950035, 0.6433529250429965], 
             UndirectedEdge[364, 452] -> 
             RGBColor[
              0.9307077281075424, 0.9279006292243646, 0.6851221083265133], 
             UndirectedEdge[351, 442] -> 
             RGBColor[
              0.9448179593149171, 0.955860388780903, 0.8763237312752017], 
             UndirectedEdge[71, 466] -> 
             RGBColor[
              0.9240594826632195, 0.9422326346834325, 0.9908391643211872], 
             UndirectedEdge[87, 285] -> 
             RGBColor[
              0.9746241672108568, 0.9803938805489221, 0.9188177076104224], 
             UndirectedEdge[211, 369] -> 
             RGBColor[
              0.9234168006126007, 0.9392548052464331, 0.8942190232999077], 
             UndirectedEdge[164, 316] -> 
             RGBColor[
              0.7119991667939117, 0.7749384275842746, 0.9719290810016574], 
             UndirectedEdge[27, 297] -> 
             RGBColor[
              0.9774858226898604, 0.9816582215199832, 0.8750188020165883], 
             UndirectedEdge[238, 483] -> 
             RGBColor[
              0.9387662452931594, 0.9507245970975173, 0.8622713826825499], 
             UndirectedEdge[109, 164] -> 
             RGBColor[
              0.8166945483651632, 0.843456592852914, 0.681349514337773], 
             UndirectedEdge[83, 355] -> 
             RGBColor[
              0.7249827831165132, 0.7850813273346298, 0.9732231665379014], 
             UndirectedEdge[85, 166] -> 
             RGBColor[
              0.8908681103095499, 0.915818065462918, 0.9894529897203171], 
             UndirectedEdge[34, 190] -> 
             RGBColor[
              0.82999132340871, 0.8565363925485663, 0.6866063202238912], 
             UndirectedEdge[232, 383] -> 
             RGBColor[
              0.9015786490176143, 0.9230818161036618, 0.9455625569153179], 
             UndirectedEdge[185, 441] -> 
             RGBColor[
              0.9713026398212627, 0.9758239935145354, 0.8151128265305946], 
             UndirectedEdge[83, 207] -> 
             RGBColor[
              0.8040284041284051, 0.8470705822837694, 0.9810384803683585], 
             UndirectedEdge[138, 385] -> 
             RGBColor[
              0.9426419594311809, 0.9554455034236753, 0.9334437326615992], 
             UndirectedEdge[131, 234] -> 
             RGBColor[
              0.97278446342323, 0.9355612285964361, 0.6101877234977374], 
             UndirectedEdge[80, 81] -> 
             RGBColor[
              0.8715297819942989, 0.8151595144793455, 0.6240675394656382], 
             UndirectedEdge[5, 486] -> 
             RGBColor[
              0.9756642157476596, 0.9813484739391858, 0.9250698886277824], 
             UndirectedEdge[94, 139] -> 
             RGBColor[
              0.9664938024244696, 0.9707806137622337, 0.7076496517664926], 
             UndirectedEdge[126, 249] -> 
             RGBColor[
              0.9606657471380277, 0.9288723922683116, 0.6356886310962351], 
             UndirectedEdge[359, 483] -> 
             RGBColor[
              0.8292880810897414, 0.8670726035623123, 0.9834847526262009], 
             UndirectedEdge[275, 404] -> 
             RGBColor[
              0.9060902389638028, 0.579545476267395, 0.4890747658659274], 
             UndirectedEdge[313, 391] -> 
             RGBColor[
              0.8776528868143945, 0.9048619720428586, 0.9668462318945898], 
             UndirectedEdge[1, 487] -> 
             RGBColor[
              0.8233225142515594, 0.861589523894676, 0.921529251739353], 
             UndirectedEdge[71, 172] -> 
             RGBColor[
              0.9113558984269835, 0.8106757704381943, 0.6197986476120528], 
             UndirectedEdge[44, 494] -> 
             RGBColor[
              0.9514281314726505, 0.8949123532400007, 0.6162218531067201], 
             UndirectedEdge[85, 387] -> 
             RGBColor[
              0.8203435713540463, 0.8603894116339478, 0.9825124884429619], 
             UndirectedEdge[414, 499] -> 
             RGBColor[
              0.9216195123625301, 0.9369076691604367, 0.852407782755258], 
             UndirectedEdge[89, 376] -> 
             RGBColor[
              0.9672819179030151, 0.9739233814075372, 0.8867032405447521], 
             UndirectedEdge[171, 403] -> 
             RGBColor[
              0.9194096171482031, 0.9380180850518602, 0.9728220478746978], 
             UndirectedEdge[161, 279] -> 
             RGBColor[
              0.9678901052051451, 0.9752452868142762, 0.9245588957646593], 
             UndirectedEdge[149, 310] -> 
             RGBColor[
              0.9343295271101592, 0.9459479469918268, 0.7649090910697799], 
             UndirectedEdge[333, 367] -> 
             RGBColor[
              0.9073591636581704, 0.9265280455064399, 0.8960381629507563], 
             UndirectedEdge[43, 227] -> 
             RGBColor[
              0.9623011239351209, 0.8769342745000293, 0.5048690711485744], 
             UndirectedEdge[71, 369] -> 
             RGBColor[
              0.8832368086907529, 0.9097330726982535, 0.988725109359373], 
             UndirectedEdge[134, 174] -> 
             RGBColor[
              0.9733312322776879, 0.9781518707189246, 0.8637864533368572], 
             UndirectedEdge[158, 370] -> 
             RGBColor[
              0.9923153579901939, 0.9903673134608199, 0.7244704585254103], 
             UndirectedEdge[7, 391] -> 
             RGBColor[
              0.9418217494147859, 0.9558329233179993, 0.9730186103593921], 
             UndirectedEdge[200, 228] -> 
             RGBColor[
              0.9207479743178131, 0.7131247855545939, 0.5535197449510292], 
             UndirectedEdge[201, 300] -> 
             RGBColor[
              0.8049917915246058, 0.8466659482308658, 0.906646367810501], 
             UndirectedEdge[210, 320] -> 
             RGBColor[
              0.8125663133789276, 0.854421915645616, 0.9817086224947512], 
             UndirectedEdge[69, 103] -> 
             RGBColor[
              0.9941994408744024, 0.9912903848258348, 0.7037103143971167], 
             UndirectedEdge[97, 281] -> 
             RGBColor[
              0.6834921820659661, 0.7478969271387821, 0.9438467553793046], 
             UndirectedEdge[192, 272] -> 
             RGBColor[
              0.9855859718513653, 0.9627278006510495, 0.42507222683435053`], 
             UndirectedEdge[70, 463] -> 
             RGBColor[
              0.9723777423057595, 0.9772968523420744, 0.8589560084313703], 
             UndirectedEdge[285, 477] -> 
             RGBColor[
              0.9362174216168238, 0.9512525983358882, 0.9686153036919412], 
             UndirectedEdge[10, 168] -> 
             RGBColor[
              0.9875431997901278, 0.9891168072351241, 0.8561049468505335], 
             UndirectedEdge[298, 468] -> 
             RGBColor[
              0.8702610074633146, 0.8989959670776706, 0.9614821857831957], 
             UndirectedEdge[37, 264] -> 
             RGBColor[
              0.9864449061698847, 0.9867156369242703, 0.7576288452768865], 
             UndirectedEdge[191, 405] -> 
             RGBColor[
              0.9663270433482518, 0.974407344580308, 0.9418837116844782], 
             UndirectedEdge[349, 380] -> 
             RGBColor[
              0.9530248420997187, 0.8392037034387148, 0.4235544536291508], 
             UndirectedEdge[94, 410] -> 
             RGBColor[
              0.8886912705027576, 0.9139599069244947, 0.9850014830091389], 
             UndirectedEdge[335, 409] -> 
             RGBColor[
              0.8405388819292838, 0.8758459220313237, 0.9620178619317536], 
             UndirectedEdge[168, 189] -> 
             RGBColor[
              0.9810738566664428, 0.9848044294943672, 0.8900043153411019], 
             UndirectedEdge[187, 399] -> 
             RGBColor[
              0.9903194780963921, 0.9885430284641807, 0.6849351521460674], 
             UndirectedEdge[153, 314] -> 
             RGBColor[
              0.9134502940000955, 0.9241479596316826, 0.6981990691304898], 
             UndirectedEdge[233, 355] -> 
             RGBColor[
              0.8395883077858428, 0.8740233747406765, 0.910766475836184], 
             UndirectedEdge[233, 486] -> 
             RGBColor[
              0.9774061356728224, 0.9820688025935407, 0.8962017675235734], 
             UndirectedEdge[49, 264] -> 
             RGBColor[
              0.8350989157103909, 0.8712765043835926, 0.945293776344414], 
             UndirectedEdge[205, 331] -> 
             RGBColor[
              0.9898003786152032, 0.9892918665315198, 0.7635741831531664], 
             UndirectedEdge[308, 456] -> 
             RGBColor[
              0.6722771181811853, 0.7430651132762476, 0.9685457396291538], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.977560276873334, 0.9822599377289045, 0.8993522030206027], 
             UndirectedEdge[175, 371] -> 
             RGBColor[
              0.4784184612304857, 0.5855229577596365, 0.9526118740569096], 
             UndirectedEdge[21, 188] -> 
             RGBColor[
              0.9611570617023046, 0.9703711152740222, 0.9425535300612236], 
             UndirectedEdge[79, 221] -> 
             RGBColor[
              0.9228133138767977, 0.7007446656919585, 0.48739282920260535`], 
             UndirectedEdge[158, 193] -> 
             RGBColor[
              0.9907988884824422, 0.9904631181767791, 0.8021497597666309], 
             UndirectedEdge[266, 483] -> 
             RGBColor[
              0.8383297041234133, 0.8741359881950971, 0.9843859371114262], 
             UndirectedEdge[290, 484] -> 
             RGBColor[
              0.8137028688750817, 0.8522915564727165, 0.8468654034985945], 
             UndirectedEdge[153, 411] -> 
             RGBColor[
              0.8831865590361847, 0.9096930049876912, 0.9887203165024618], 
             UndirectedEdge[176, 475] -> 
             RGBColor[
              0.9849102846720349, 0.9605568812086336, 0.4132355322620439], 
             UndirectedEdge[20, 474] -> 
             RGBColor[
              0.8838409726037539, 0.9086533044846139, 0.9178711446188708], 
             UndirectedEdge[70, 483] -> 
             RGBColor[
              0.9167639062752874, 0.936077415990523, 0.9784272645557808], 
             UndirectedEdge[163, 266] -> 
             RGBColor[
              0.8746494249887302, 0.9025889986613225, 0.9702600334435334], 
             UndirectedEdge[69, 486] -> 
             RGBColor[
              0.980394435494203, 0.9833045413654841, 0.8466779060112619], 
             UndirectedEdge[262, 475] -> 
             RGBColor[
              0.9679658551927612, 0.9514675584349253, 0.6597392647028076], 
             UndirectedEdge[18, 167] -> 
             RGBColor[
              0.8695678858702214, 0.8988338446741873, 0.9874213552983593], 
             UndirectedEdge[281, 374] -> 
             RGBColor[
              0.9809178172928795, 0.9832314476868287, 0.8175997664124335], 
             UndirectedEdge[138, 294] -> 
             RGBColor[
              0.9448790005472133, 0.9572292592867362, 0.9336571036402765], 
             UndirectedEdge[291, 349] -> 
             RGBColor[
              0.9851367004398391, 0.9857691270621609, 0.7621560519331674], 
             UndirectedEdge[288, 455] -> 
             RGBColor[
              0.889147614599603, 0.9116584403045404, 0.8666870689247415], 
             UndirectedEdge[12, 459] -> 
             RGBColor[
              0.9574270843548347, 0.9392903628912168, 0.6684136369594725], 
             UndirectedEdge[93, 305] -> 
             RGBColor[
              0.9897493151526309, 0.9870307668007323, 0.6411242599467927], 
             UndirectedEdge[127, 184] -> 
             RGBColor[
              0.4991383308479465, 0.6028176058374992, 0.9541122371221518], 
             UndirectedEdge[204, 431] -> 
             RGBColor[
              0.963113198315587, 0.9684445392159049, 0.7307929494517453], 
             UndirectedEdge[397, 495] -> 
             RGBColor[
              0.9680806204163097, 0.9730531063711708, 0.7913747525503143], 
             UndirectedEdge[28, 493] -> 
             RGBColor[
              0.9842409742991449, 0.9568357950729384, 0.535067691314961], 
             UndirectedEdge[267, 485] -> 
             RGBColor[
              0.7755329925761865, 0.8243256772748775, 0.9577064593730079], 
             UndirectedEdge[110, 494] -> 
             RGBColor[
              0.9751594810628611, 0.979512910786479, 0.8605813225328712], 
             UndirectedEdge[337, 500] -> 
             RGBColor[
              0.871587758204286, 0.876441722126927, 0.6723668943580767], 
             UndirectedEdge[43, 393] -> 
             RGBColor[
              0.9591091038419459, 0.8756142921603269, 0.5577691047756822], 
             UndirectedEdge[167, 432] -> 
             RGBColor[
              0.8810705948232291, 0.826954233296936, 0.6259627363566451], 
             UndirectedEdge[230, 474] -> 
             RGBColor[
              0.9720030428202375, 0.9270403914471324, 0.5712983923287461], 
             UndirectedEdge[40, 421] -> 
             RGBColor[
              0.7305921008336841, 0.7890765171774755, 0.9742192154554148], 
             UndirectedEdge[254, 476] -> 
             RGBColor[
              0.978787561063339, 0.9825540428600641, 0.8694560627634901], 
             UndirectedEdge[107, 197] -> 
             RGBColor[
              0.6907021265606252, 0.7552220560097127, 0.960071601716149], 
             UndirectedEdge[231, 395] -> 
             RGBColor[
              0.7459541003426513, 0.7981092375220517, 0.8757770519147383], 
             UndirectedEdge[420, 427] -> 
             RGBColor[
              0.9712888599161243, 0.9778630692563173, 0.9225224543243025], 
             UndirectedEdge[317, 374] -> 
             RGBColor[
              0.843169126490018, 0.8752375821580981, 0.8320474436754717], 
             UndirectedEdge[188, 200] -> 
             RGBColor[
              0.9608167626913341, 0.9702303928877003, 0.948193165338614], 
             UndirectedEdge[84, 260] -> 
             RGBColor[
              0.9745747732527653, 0.9297897769868583, 0.5403311032301445], 
             UndirectedEdge[33, 160] -> 
             RGBColor[
              0.9799355874675815, 0.9822725848908023, 0.8013051075637185], 
             UndirectedEdge[135, 362] -> 
             RGBColor[
              0.929264519459488, 0.9435509199812142, 0.8788535106391946], 
             UndirectedEdge[123, 193] -> 
             RGBColor[
              0.9909327551958313, 0.9905184755029831, 0.7999312418898259], 
             UndirectedEdge[439, 453] -> 
             RGBColor[
              0.850293091945878, 0.8472077600608474, 0.6518469719480969], 
             UndirectedEdge[269, 282] -> 
             RGBColor[
              0.9944741996608416, 0.991928596324168, 0.7372891274566434], 
             UndirectedEdge[202, 459] -> 
             RGBColor[
              0.9796906803486798, 0.9556471555403708, 0.6196498546644027], 
             UndirectedEdge[25, 474] -> 
             RGBColor[
              0.9761601596483629, 0.9811932457900379, 0.9007152312038644], 
             UndirectedEdge[103, 259] -> 
             RGBColor[
              0.9863805479748692, 0.9870533085476587, 0.7883390407157569], 
             UndirectedEdge[352, 375] -> 
             RGBColor[
              0.9928729733572906, 0.9871643356012003, 0.46564531673018683`], 
             UndirectedEdge[300, 308] -> 
             RGBColor[
              0.604725017406716, 0.689982037539177, 0.962025315032436], 
             UndirectedEdge[32, 328] -> 
             RGBColor[
              0.9634025676824847, 0.9718243805092716, 0.9288364110661721], 
             UndirectedEdge[209, 486] -> 
             RGBColor[
              0.8988353507121519, 0.9213637371655596, 0.9622271445209748], 
             UndirectedEdge[118, 496] -> 
             RGBColor[
              0.7515041939427451, 0.8061214389866289, 0.9757877517989402], 
             UndirectedEdge[31, 405] -> 
             RGBColor[
              0.5861563375721893, 0.6529525206102338, 0.9317663676096952], 
             UndirectedEdge[21, 228] -> 
             RGBColor[
              0.9210882733287835, 0.7132655079409158, 0.5478801096736388], 
             UndirectedEdge[92, 250] -> 
             RGBColor[
              0.9514169956114945, 0.9631053285921898, 0.9608080828871098], 
             UndirectedEdge[177, 290] -> 
             RGBColor[
              0.6963350225774895, 0.7625462477769616, 0.970473957979103], 
             UndirectedEdge[9, 333] -> 
             RGBColor[
              0.90595106432428, 0.9259457602453739, 0.9193740129575846], 
             UndirectedEdge[11, 444] -> 
             RGBColor[
              0.9105580862220224, 0.9308803697178581, 0.9692129772252445], 
             UndirectedEdge[11, 25] -> 
             RGBColor[
              0.9127551899893186, 0.9325189661100806, 0.9654938536436495], 
             UndirectedEdge[168, 338] -> 
             RGBColor[
              0.9910153939469086, 0.9896372432361833, 0.7320213865598244], 
             UndirectedEdge[283, 430] -> 
             RGBColor[
              0.8275486421729877, 0.8503231860631738, 0.6800763104282233], 
             UndirectedEdge[139, 410] -> 
             RGBColor[
              0.9147393247601918, 0.92963540367584, 0.7069571412722246], 
             UndirectedEdge[195, 260] -> 
             RGBColor[
              0.9928437633738827, 0.9903710654887006, 0.7001028341235436], 
             UndirectedEdge[391, 407] -> 
             RGBColor[
              0.9704239150791804, 0.9590080343286549, 0.6676938409005982], 
             UndirectedEdge[33, 111] -> 
             RGBColor[
              0.9736219062737199, 0.9798478414058803, 0.9295354115566252], 
             UndirectedEdge[2, 114] -> 
             RGBColor[
              0.980143817740244, 0.9699119985266162, 0.6589991925990129], 
             UndirectedEdge[101, 306] -> 
             RGBColor[
              0.9776196232960757, 0.9823934165151991, 0.9032471237222521], 
             UndirectedEdge[264, 374] -> 
             RGBColor[
              0.986902808946641, 0.9876950446626795, 0.8074687366784377], 
             UndirectedEdge[172, 235] -> 
             RGBColor[
              0.9511748642191485, 0.8340464292087106, 0.33209628809338987`], 
             UndirectedEdge[84, 475] -> 
             RGBColor[
              0.9673219826728432, 0.9014315157714643, 0.3275525027201085], 
             UndirectedEdge[37, 397] -> 
             RGBColor[
              0.9940812782604743, 0.9897487776107445, 0.5971618486482483], 
             UndirectedEdge[228, 287] -> 
             RGBColor[
              0.9257047919027143, 0.7145096726870435, 0.4230423783077205], 
             UndirectedEdge[68, 375] -> 
             RGBColor[
              0.648342907504093, 0.7120833051406483, 0.7203965634904299], 
             UndirectedEdge[197, 236] -> 
             RGBColor[
              0.706131532287541, 0.7667292815375134, 0.9339536424539956], 
             UndirectedEdge[107, 214] -> 
             RGBColor[
              0.9716148857568814, 0.9766686212282794, 0.8575920214161241], 
             UndirectedEdge[207, 317] -> 
             RGBColor[
              0.7704108542656598, 0.8208082968281507, 0.9776877971719051], 
             UndirectedEdge[98, 462] -> 
             RGBColor[
              0.9623418852644698, 0.9204289640288745, 0.6122739231941601], 
             UndirectedEdge[21, 59] -> 
             RGBColor[
              0.9875520066572683, 0.9891204491010128, 0.8559589942705725], 
             UndirectedEdge[46, 350] -> 
             RGBColor[
              0.9638600937330064, 0.8894866599156732, 0.31549473535603434`], 
             UndirectedEdge[271, 429] -> 
             RGBColor[
              0.9752076244129324, 0.9280316369975153, 0.35818673180186517`], 
             UndirectedEdge[304, 423] -> 
             RGBColor[
              0.9622994756670205, 0.8755323247742508, 0.45718468074191454`], 
             UndirectedEdge[299, 328] -> 
             RGBColor[
              0.9669141791588558, 0.9718550646798005, 0.7673149724314783], 
             UndirectedEdge[55, 73] -> 
             RGBColor[
              0.9833264174973442, 0.9859099188590128, 0.8604655197446183], 
             UndirectedEdge[53, 440] -> 
             RGBColor[
              0.7726646999310309, 0.8189280928071878, 0.8406109619256072], 
             UndirectedEdge[206, 377] -> 
             RGBColor[
              0.9752813737154664, 0.9791912676480774, 0.8401114684450199], 
             UndirectedEdge[39, 113] -> 
             RGBColor[
              0.9613409038086063, 0.9485121804178669, 0.6751684198066119], 
             UndirectedEdge[9, 450] -> 
             RGBColor[
              0.7888815719340856, 0.8336559158743828, 0.9082613148632266], 
             UndirectedEdge[61, 321] -> 
             RGBColor[
              0.9892899861630469, 0.9783077187052833, 0.5897560348708677], 
             UndirectedEdge[76, 460] -> 
             RGBColor[
              0.9789011060500477, 0.9812196489824738, 0.780726633465442], 
             UndirectedEdge[141, 167] -> 
             RGBColor[
              0.9087467138113481, 0.9252733421007614, 0.740130869069103], 
             UndirectedEdge[29, 476] -> 
             RGBColor[
              0.8939158850680791, 0.9174544397625561, 0.9622208078769349], 
             UndirectedEdge[39, 190] -> 
             RGBColor[
              0.9829042494945521, 0.9539941606513274, 0.38808666685826926`], 
             UndirectedEdge[115, 215] -> 
             RGBColor[
              0.6874193705564797, 0.7557365039502223, 0.9694791966239658], 
             UndirectedEdge[208, 471] -> 
             RGBColor[
              0.973096531510222, 0.9780618857442436, 0.8679926536120903], 
             UndirectedEdge[139, 401] -> 
             RGBColor[
              0.9792319834413923, 0.9415827638657135, 0.37585978626992367`], 
             UndirectedEdge[34, 356] -> 
             RGBColor[
              0.7950734076831709, 0.8406246350077305, 0.9800000395480086], 
             UndirectedEdge[288, 313] -> 
             RGBColor[
              0.7901963452312277, 0.8360266577000738, 0.9797230449541092], 
             UndirectedEdge[66, 334] -> 
             RGBColor[
              0.9260659954885162, 0.9434214438223975, 0.9767764217351993], 
             UndirectedEdge[17, 328] -> 
             RGBColor[
              0.925430492937631, 0.943261255761968, 0.9887307196381947], 
             UndirectedEdge[318, 459] -> 
             RGBColor[
              0.8369646031821157, 0.8443454493528961, 0.6615437957820226], 
             UndirectedEdge[163, 233] -> 
             RGBColor[
              0.9715924003876019, 0.9777329283369411, 0.906042904896444], 
             UndirectedEdge[141, 300] -> 
             RGBColor[
              0.8076142893329794, 0.8459219274173181, 0.7302727953401673], 
             UndirectedEdge[354, 436] -> 
             RGBColor[
              0.9797293314177444, 0.984080768557687, 0.904778188301438], 
             UndirectedEdge[29, 290] -> 
             RGBColor[
              0.7267870908858935, 0.7863466646696939, 0.9735062086178163], 
             UndirectedEdge[110, 360] -> 
             RGBColor[
              0.9696334854224018, 0.9753916322858118, 0.8699353917416797], 
             UndirectedEdge[289, 308] -> 
             RGBColor[
              0.7902655607093327, 0.8318273142190102, 0.7280764794321811], 
             UndirectedEdge[264, 324] -> 
             RGBColor[
              0.9649035724166309, 0.9733457222902249, 0.9442932766710335], 
             UndirectedEdge[109, 382] -> 
             RGBColor[
              0.9678529379208995, 0.9622163901365711, 0.6829269089779801], 
             UndirectedEdge[293, 497] -> 
             RGBColor[
              0.941929173511464, 0.9547724093894208, 0.9288276657090759], 
             UndirectedEdge[160, 237] -> 
             RGBColor[
              0.9687291909498574, 0.9009649965727007, 0.4658498836869248], 
             UndirectedEdge[35, 123] -> 
             RGBColor[
              0.8553777942707154, 0.8858723434886544, 0.8903075413998989], 
             UndirectedEdge[218, 432] -> 
             RGBColor[
              0.9634354276258852, 0.882953189110917, 0.34041093820773166`], 
             UndirectedEdge[46, 476] -> 
             RGBColor[
              0.9607714753743694, 0.9170289362057223, 0.6121588595306988], 
             UndirectedEdge[288, 391] -> 
             RGBColor[
              0.8720600795373435, 0.9004928284911167, 0.9662887931329689], 
             UndirectedEdge[259, 486] -> 
             RGBColor[
              0.9725755425946698, 0.979067465087308, 0.931306632329902], 
             UndirectedEdge[138, 296] -> 
             RGBColor[
              0.9885288988347745, 0.9895244191213955, 0.8397693627733804], 
             UndirectedEdge[56, 494] -> 
             RGBColor[
              0.9696517144460972, 0.9768868788414319, 0.9362559107289228], 
             UndirectedEdge[91, 200] -> 
             RGBColor[
              0.9171087038583454, 0.9354132475022907, 0.9452194974421868], 
             UndirectedEdge[172, 493] -> 
             RGBColor[
              0.942779762035727, 0.8057277782802987, 0.29948290139281863`], 
             UndirectedEdge[340, 461] -> 
             RGBColor[
              0.954676281716514, 0.9656172349420009, 0.9581040015114994], 
             UndirectedEdge[33, 274] -> 
             RGBColor[
              0.959771498691322, 0.9695182301088889, 0.9529805388287824], 
             UndirectedEdge[235, 345] -> 
             RGBColor[
              0.9734452249140606, 0.9727381796726707, 0.6869427476728998], 
             UndirectedEdge[205, 490] -> 
             RGBColor[
              0.9894447477917665, 0.9899031462013563, 0.8245913754148992], 
             UndirectedEdge[141, 284] -> 
             RGBColor[
              0.9730318050466928, 0.9760889330239187, 0.7308826916766317], 
             UndirectedEdge[489, 500] -> 
             RGBColor[
              0.858575791723473, 0.890099459413646, 0.9720649432814258], 
             UndirectedEdge[155, 198] -> 
             RGBColor[
              0.9930243898649798, 0.98748820020059, 0.48212606915777934`], 
             UndirectedEdge[23, 157] -> 
             RGBColor[
              0.8748024834023997, 0.9027503903241569, 0.9723922745548594], 
             UndirectedEdge[248, 344] -> 
             RGBColor[
              0.9396482558028414, 0.9545103485114463, 0.9870439400566671], 
             UndirectedEdge[50, 131] -> 
             RGBColor[
              0.8743031213909678, 0.9018218127915065, 0.9450851315352286], 
             UndirectedEdge[442, 500] -> 
             RGBColor[
              0.8793806762296819, 0.9041222049737943, 0.8699655741151396], 
             UndirectedEdge[18, 305] -> 
             RGBColor[
              0.9534508731198326, 0.9599538919173636, 0.7077673004964552], 
             UndirectedEdge[134, 278] -> 
             RGBColor[
              0.9821709290821258, 0.9847445021219994, 0.8488231524091132], 
             UndirectedEdge[158, 422] -> 
             RGBColor[
              0.9916051965056232, 0.9907965472655355, 0.7887871491642486], 
             UndirectedEdge[229, 393] -> 
             RGBColor[
              0.9908484012716176, 0.9904835929875238, 0.8013292047150049], 
             UndirectedEdge[17, 143] -> 
             RGBColor[
              0.9498637708825002, 0.9531830776802133, 0.7016722190622281], 
             UndirectedEdge[53, 83] -> 
             RGBColor[
              0.8769211602163154, 0.9017875149994502, 0.85003586548136], 
             UndirectedEdge[166, 239] -> 
             RGBColor[
              0.926808525277061, 0.9389287856841719, 0.7055479817670444], 
             UndirectedEdge[46, 194] -> 
             RGBColor[
              0.9637620912046734, 0.8891560743755185, 0.31511401403968564`], 
             UndirectedEdge[319, 368] -> 
             RGBColor[
              0.8585468968759865, 0.8885005006408654, 0.8975352363697975], 
             UndirectedEdge[51, 360] -> 
             RGBColor[
              0.9138435614806728, 0.9338683916862585, 0.9822946110894444], 
             UndirectedEdge[132, 250] -> 
             RGBColor[
              0.9609642543392323, 0.9669971956732044, 0.7521642641267893], 
             UndirectedEdge[80, 447] -> 
             RGBColor[
              0.6179926219911192, 0.6975299475745822, 0.9649938689089612], 
             UndirectedEdge[128, 179] -> 
             RGBColor[
              0.5529797017529786, 0.4332448900503463, 0.5748336155364538], 
             UndirectedEdge[218, 300] -> 
             RGBColor[
              0.805563367034662, 0.8394106880111396, 0.6876967449245224], 
             UndirectedEdge[130, 241] -> 
             RGBColor[
              0.7561536695536321, 0.8095742457013815, 0.9765242155937752], 
             UndirectedEdge[134, 252] -> 
             RGBColor[
              0.9940563716226911, 0.9918101711687701, 0.748164834036573], 
             UndirectedEdge[266, 317] -> 
             RGBColor[
              0.7426453323869712, 0.7988794450650578, 0.9749836043832734], 
             UndirectedEdge[156, 485] -> 
             RGBColor[
              0.7659793056059521, 0.8172005531752035, 0.9738783594129858], 
             UndirectedEdge[96, 110] -> 
             RGBColor[
              0.9689633548461524, 0.9748918499992831, 0.8710697480092235], 
             UndirectedEdge[50, 373] -> 
             RGBColor[
              0.8574513095263236, 0.82742760268326, 0.6278164735981588], 
             UndirectedEdge[37, 322] -> 
             RGBColor[
              0.9870594187451095, 0.987173939396701, 0.7565886357775793], 
             UndirectedEdge[65, 290] -> 
             RGBColor[
              0.8056665186132637, 0.8267474796369882, 0.6687635806969818], 
             UndirectedEdge[333, 450] -> 
             RGBColor[
              0.7072614663201803, 0.7704733025096107, 0.9719939187080134], 
             UndirectedEdge[238, 266] -> 
             RGBColor[
              0.8943619726899206, 0.9155284571535248, 0.8579801709962225], 
             UndirectedEdge[312, 446] -> 
             RGBColor[
              0.9092431603658779, 0.9281231194150832, 0.9002486888443673], 
             UndirectedEdge[407, 448] -> 
             RGBColor[
              0.9861976094958143, 0.969630339270948, 0.5898658563009848], 
             UndirectedEdge[14, 454] -> 
             RGBColor[
              0.862407750430944, 0.8928062735728761, 0.9579320892139053], 
             UndirectedEdge[77, 473] -> 
             RGBColor[
              0.9803047028119096, 0.9820831381730496, 0.763805768352551], 
             UndirectedEdge[57, 136] -> 
             RGBColor[
              0.7328489750061888, 0.7858623413075089, 0.776699020423977], 
             UndirectedEdge[364, 487] -> 
             RGBColor[
              0.8208046478715854, 0.8415574071998216, 0.6742969925044465], 
             UndirectedEdge[80, 403] -> 
             RGBColor[
              0.8447142300141603, 0.8791134424021569, 0.9850249900215085], 
             UndirectedEdge[330, 352] -> 
             RGBColor[
              0.9663726402384485, 0.9706997684798777, 0.7086099030132706], 
             UndirectedEdge[239, 272] -> 
             RGBColor[
              0.9852147493260792, 0.9617880191142272, 0.39706252240247014`], 
             UndirectedEdge[53, 97] -> 
             RGBColor[
              0.6976818683629066, 0.7566092492748719, 0.8351071315858012], 
             UndirectedEdge[304, 311] -> 
             RGBColor[
              0.9623477852343933, 0.8756356540540151, 0.4624428790183741], 
             UndirectedEdge[237, 241] -> 
             RGBColor[
              0.7744907541918538, 0.7510624829258263, 0.6174905872195342], 
             UndirectedEdge[361, 441] -> 
             RGBColor[
              0.9077501403919104, 0.9254654359361977, 0.8200237058470536], 
             UndirectedEdge[276, 347] -> 
             RGBColor[
              0.40792485549946345`, 0.5166830812635536, 0.9484911606467696], 
             UndirectedEdge[11, 180] -> 
             RGBColor[
              0.9069811348345392, 0.9282126852297936, 0.9752678229059187], 
             UndirectedEdge[56, 360] -> 
             RGBColor[
              0.964125718805638, 0.9727656003407648, 0.9456099799377312], 
             UndirectedEdge[15, 269] -> 
             RGBColor[
              0.9806426264362587, 0.9469476743371184, 0.5410222316084746], 
             UndirectedEdge[8, 387] -> 
             RGBColor[
              0.44961408552651433`, 0.543409008204533, 0.9531287735997828], 
             UndirectedEdge[139, 278] -> 
             RGBColor[
              0.9818941325064587, 0.9822661547216549, 0.6815809099870573], 
             UndirectedEdge[15, 449] -> 
             RGBColor[
              0.885955166879423, 0.8746537464041022, 0.6547976031911023], 
             UndirectedEdge[348, 355] -> 
             RGBColor[
              0.8382307396609872, 0.8601036608392726, 0.6832373214822725], 
             UndirectedEdge[173, 499] -> 
             RGBColor[
              0.6380323892383801, 0.7134118857394806, 0.9669310811928953], 
             UndirectedEdge[130, 483] -> 
             RGBColor[
              0.8944350407129095, 0.9186622389448104, 0.9897932067264259], 
             UndirectedEdge[173, 282] -> 
             RGBColor[
              0.7116247622426561, 0.7686712484683191, 0.8347447533118459], 
             UndirectedEdge[84, 244] -> 
             RGBColor[
              0.9714918345316748, 0.9285149025977761, 0.591423376228271], 
             UndirectedEdge[183, 279] -> 
             RGBColor[
              0.667333357947863, 0.7349388401936758, 0.957964301233987], 
             UndirectedEdge[124, 381] -> 
             RGBColor[
              0.8619822379335471, 0.8901258619729899, 0.8492474515081632], 
             UndirectedEdge[81, 213] -> 
             RGBColor[
              0.9406065945300424, 0.8698738333932086, 0.6213753785547997], 
             UndirectedEdge[134, 210] -> 
             RGBColor[
              0.8422303415435028, 0.8751159235966394, 0.866981139107569], 
             UndirectedEdge[103, 275] -> 
             RGBColor[
              0.9924798129423883, 0.9905792744835249, 0.7322089994850223], 
             UndirectedEdge[256, 298] -> 
             RGBColor[
              0.9770271710330125, 0.9815264786555951, 0.8852136847729464], 
             UndirectedEdge[18, 235] -> 
             RGBColor[
              0.9524360928661904, 0.956530799840094, 0.7038250708362264], 
             UndirectedEdge[255, 334] -> 
             RGBColor[
              0.9279608041273801, 0.8949702467558425, 0.639637450486034], 
             UndirectedEdge[209, 372] -> 
             RGBColor[
              0.9126528158338245, 0.9293762307530486, 0.8206157188735854], 
             UndirectedEdge[112, 238] -> 
             RGBColor[
              0.8782945066072226, 0.9029764305324561, 0.8563787161361066], 
             UndirectedEdge[360, 457] -> 
             RGBColor[
              0.956975460618734, 0.9311944317943364, 0.6527069942518049], 
             UndirectedEdge[233, 404] -> 
             RGBColor[
              0.9048215670744364, 0.5790208478377616, 0.5100999422903334], 
             UndirectedEdge[259, 348] -> 
             RGBColor[
              0.9816232211149094, 0.9723066561947052, 0.659236178783337], 
             UndirectedEdge[244, 376] -> 
             RGBColor[
              0.9642494209095845, 0.9726693659691357, 0.9369595635765466], 
             UndirectedEdge[182, 371] -> 
             RGBColor[
              0.5795953060312633, 0.6656079933533207, 0.9619818219865464], 
             UndirectedEdge[21, 77] -> 
             RGBColor[
              0.9759533691516911, 0.9814061771430447, 0.9175072410444514], 
             UndirectedEdge[153, 493] -> 
             RGBColor[
              0.9055585660099867, 0.8975273080551962, 0.667541196116699], 
             UndirectedEdge[276, 382] -> 
             RGBColor[
              0.5894693565927989, 0.6600228878563985, 0.9525213777011241], 
             UndirectedEdge[80, 219] -> 
             RGBColor[
              0.9013078811583324, 0.9204442414813128, 0.8208798565086026], 
             UndirectedEdge[60, 136] -> 
             RGBColor[
              0.842744814389032, 0.8743300214786233, 0.7858636900339003], 
             UndirectedEdge[23, 96] -> 
             RGBColor[
              0.9489138373909771, 0.9614206040888804, 0.9713597272786638], 
             UndirectedEdge[53, 281] -> 
             RGBColor[
              0.9810523011564316, 0.9835190950725621, 0.8322375050218684], 
             UndirectedEdge[141, 162] -> 
             RGBColor[
              0.724339622770532, 0.7783158016209462, 0.7237171085432166], 
             UndirectedEdge[28, 149] -> 
             RGBColor[
              0.9351452719415994, 0.9476927427018232, 0.8536978817784977], 
             UndirectedEdge[37, 317] -> 
             RGBColor[
              0.8427112237132617, 0.8742581744196889, 0.7822075522739205], 
             UndirectedEdge[372, 486] -> 
             RGBColor[
              0.9808183541493998, 0.9829223911722287, 0.7991316410688374], 
             UndirectedEdge[63, 453] -> 
             RGBColor[
              0.7981482358022182, 0.8062582985370166, 0.6467956335788082], 
             UndirectedEdge[82, 242] -> 
             RGBColor[
              0.6605041737472436, 0.7317258835373551, 0.9688923405149998], 
             UndirectedEdge[4, 191] -> 
             RGBColor[
              0.9753595728422197, 0.9798388610519746, 0.8681565980186753], 
             UndirectedEdge[70, 403] -> 
             RGBColor[
              0.9161337929422624, 0.9355749807227396, 0.978367163783568], 
             UndirectedEdge[144, 458] -> 
             RGBColor[
              0.991941540250461, 0.9898565165250359, 0.704772610731079], 
             UndirectedEdge[16, 224] -> 
             RGBColor[
              0.6327005606310677, 0.7028218808230979, 0.9398531126563447], 
             UndirectedEdge[40, 206] -> 
             RGBColor[
              0.7727735079910962, 0.8222039510586702, 0.9606688342680445], 
             UndirectedEdge[148, 485] -> 
             RGBColor[
              0.680863269546078, 0.7498452478931716, 0.9693519118762683], 
             UndirectedEdge[34, 291] -> 
             RGBColor[
              0.8244233506043994, 0.8629837352202101, 0.9466120791450154], 
             UndirectedEdge[222, 339] -> 
             RGBColor[
              0.9944762084550443, 0.9919837844882626, 0.741207051221588], 
             UndirectedEdge[197, 314] -> 
             RGBColor[
              0.7107768270298871, 0.7618932579831657, 0.680391035907318], 
             UndirectedEdge[330, 358] -> 
             RGBColor[
              0.9628121790336717, 0.9715795239024171, 0.9385886270794188], 
             UndirectedEdge[312, 415] -> 
             RGBColor[
              0.9107860554683987, 0.9287611461905709, 0.8746789241110685], 
             UndirectedEdge[370, 443] -> 
             RGBColor[
              0.9896116392318706, 0.9892492562718505, 0.7692780753506809], 
             UndirectedEdge[160, 305] -> 
             RGBColor[
              0.9933725205668509, 0.9879822051564673, 0.5413281333328984], 
             UndirectedEdge[266, 343] -> 
             RGBColor[
              0.8638464125121309, 0.8944823188316627, 0.9868197435365766], 
             UndirectedEdge[47, 468] -> 
             RGBColor[
              0.8438970430781096, 0.8787213933021278, 0.9848781684622259], 
             UndirectedEdge[388, 436] -> 
             RGBColor[
              0.6443856410957969, 0.7136357110267961, 0.9356762933605629], 
             UndirectedEdge[69, 209] -> 
             RGBColor[
              0.9122288971786278, 0.9297583809463041, 0.86816198381601], 
             UndirectedEdge[197, 470] -> 
             RGBColor[
              0.7132915838064398, 0.7704247959185266, 0.848192145632261], 
             UndirectedEdge[13, 298] -> 
             RGBColor[
              0.9637269933968766, 0.9296347440729017, 0.6272785375603167], 
             UndirectedEdge[168, 383] -> 
             RGBColor[
              0.9032943787797957, 0.9237913144525675, 0.9171284745896818], 
             UndirectedEdge[123, 428] -> 
             RGBColor[
              0.9923629510017655, 0.9902381400624458, 0.7128615806253538], 
             UndirectedEdge[137, 485] -> 
             RGBColor[
              0.7577496967912374, 0.7068385086410522, 0.6091198241085257], 
             UndirectedEdge[394, 467] -> 
             RGBColor[
              0.9586976271806829, 0.9662486991634764, 0.8377819213064388], 
             UndirectedEdge[232, 395] -> 
             RGBColor[
              0.7426098329824484, 0.7967262970248569, 0.9312002167597963], 
             UndirectedEdge[414, 461] -> 
             RGBColor[
              0.9634937382677398, 0.9702970402516684, 0.8564017838036597], 
             UndirectedEdge[224, 333] -> 
             RGBColor[
              0.5609821941229143, 0.6464625653723509, 0.9616838861769952], 
             UndirectedEdge[33, 182] -> 
             RGBColor[
              0.8708620539010271, 0.8994558913094102, 0.9610552403288036], 
             UndirectedEdge[158, 451] -> 
             RGBColor[
              0.8830144347572273, 0.9075115174506849, 0.8952939639042454], 
             UndirectedEdge[235, 274] -> 
             RGBColor[
              0.972193651536949, 0.9718047582972842, 0.6890613349377334], 
             UndirectedEdge[284, 345] -> 
             RGBColor[
              0.9548621091534364, 0.9658568154299214, 0.9612908547425614], 
             UndirectedEdge[70, 238] -> 
             RGBColor[
              0.9727961748417946, 0.9774698849489507, 0.8520214984405772], 
             UndirectedEdge[21, 55] -> 
             RGBColor[
              0.9882729754614618, 0.9894185882296, 0.8440106753776321], 
             UndirectedEdge[55, 60] -> 
             RGBColor[
              0.8413164674817943, 0.8747380131866308, 0.8821263973403382], 
             UndirectedEdge[219, 258] -> 
             RGBColor[
              0.994552542133855, 0.9907567633838197, 0.6484560129622472], 
             UndirectedEdge[175, 463] -> 
             RGBColor[
              0.7840544999885185, 0.8284643557190101, 0.8546763828435314], 
             UndirectedEdge[101, 431] -> 
             RGBColor[
              0.9806593852941037, 0.9815915201783973, 0.7032089395827537], 
             UndirectedEdge[14, 213] -> 
             RGBColor[
              0.8515780720872056, 0.8847295171960868, 0.976263909817376], 
             UndirectedEdge[378, 487] -> 
             RGBColor[
              0.8232039660164532, 0.8615405011529089, 0.9234939027880606], 
             UndirectedEdge[8, 159] -> 
             RGBColor[
              0.5617428399543254, 0.6317832673847386, 0.9561164364446261], 
             UndirectedEdge[311, 469] -> 
             RGBColor[
              0.9927175155596013, 0.9907372595356918, 0.7326084057043495], 
             UndirectedEdge[343, 440] -> 
             RGBColor[
              0.7419274029563885, 0.7978247789089723, 0.9756344021354519], 
             UndirectedEdge[371, 460] -> 
             RGBColor[
              0.6884668287906093, 0.7479926062445196, 0.780244059523012], 
             UndirectedEdge[224, 358] -> 
             RGBColor[
              0.6415340136274168, 0.7092034149771842, 0.9156555478008381], 
             UndirectedEdge[455, 475] -> 
             RGBColor[
              0.9853392724439102, 0.9628463807167336, 0.5596536165188069], 
             UndirectedEdge[310, 408] -> 
             RGBColor[
              0.9588500841545007, 0.9654999735861949, 0.7672478836904288], 
             UndirectedEdge[154, 376] -> 
             RGBColor[
              0.9428449307332504, 0.9568944234404705, 0.9816328032258348], 
             UndirectedEdge[282, 499] -> 
             RGBColor[
              0.9216266174665162, 0.9369228662594264, 0.8531811294765079], 
             UndirectedEdge[14, 192] -> 
             RGBColor[
              0.8750285278879324, 0.8987932898693192, 0.7284484656551566], 
             UndirectedEdge[75, 147] -> 
             RGBColor[
              0.943206388278212, 0.9536631007324663, 0.8173918913383207], 
             UndirectedEdge[175, 351] -> 
             RGBColor[
              0.7353008226595746, 0.7927150237020099, 0.9748019670290295], 
             UndirectedEdge[109, 205] -> 
             RGBColor[
              0.9852153764669186, 0.9749981677323887, 0.6460537211498417], 
             UndirectedEdge[43, 148] -> 
             RGBColor[
              0.8500353470872022, 0.7909829568947018, 0.6202898359103811], 
             UndirectedEdge[56, 92] -> 
             RGBColor[
              0.9781462069036042, 0.9832220574077857, 0.9218769507168197], 
             UndirectedEdge[46, 412] -> 
             RGBColor[
              0.9403290515722027, 0.9015225409238576, 0.6377319242199124], 
             UndirectedEdge[170, 214] -> 
             RGBColor[
              0.9699488425583558, 0.9754260889387142, 0.8604121979775696], 
             UndirectedEdge[94, 437] -> 
             RGBColor[
              0.7390259290424064, 0.79529850088911, 0.9712177311368272], 
             UndirectedEdge[173, 249] -> 
             RGBColor[
              0.6927151505469391, 0.7564548322522069, 0.9527449834146983], 
             UndirectedEdge[181, 302] -> 
             RGBColor[
              0.9930825523443774, 0.987612603862893, 0.48845669610300146`], 
             UndirectedEdge[188, 279] -> 
             RGBColor[
              0.9433255430329385, 0.9572528633066475, 0.9808192519662262], 
             UndirectedEdge[317, 471] -> 
             RGBColor[
              0.8419743635992767, 0.8750100701383687, 0.8712233560930809], 
             UndirectedEdge[8, 344] -> 
             RGBColor[
              0.5590234745064295, 0.6297551690862502, 0.9607196128238142], 
             UndirectedEdge[236, 493] -> 
             RGBColor[
              0.9765236015832321, 0.9529764304864254, 0.6349077540374315], 
             UndirectedEdge[31, 366] -> 
             RGBColor[
              0.4839682880484999, 0.572864935639745, 0.9561383857729909], 
             UndirectedEdge[176, 261] -> 
             RGBColor[
              0.9897891538075168, 0.9879334648997533, 0.665356154618217], 
             UndirectedEdge[144, 145] -> 
             RGBColor[
              0.9916909556917501, 0.9908320108929094, 0.7873658975124658], 
             UndirectedEdge[144, 375] -> 
             RGBColor[
              0.9915211936113215, 0.988957437567481, 0.6590204731395041], 
             UndirectedEdge[258, 293] -> 
             RGBColor[
              0.9457268979891551, 0.95561996222911, 0.8133420659173445], 
             UndirectedEdge[242, 269] -> 
             RGBColor[
              0.9376015794557467, 0.9500011106317969, 0.8710702002855781], 
             UndirectedEdge[45, 216] -> 
             RGBColor[
              0.9742835821380069, 0.9786165764359659, 0.8511779076665904], 
             UndirectedEdge[82, 323] -> 
             RGBColor[
              0.7167578753945077, 0.7723295650167914, 0.7677458021887802], 
             UndirectedEdge[258, 272] -> 
             RGBColor[
              0.9863033644904178, 0.9642622309664609, 0.5031559883610528], 
             UndirectedEdge[92, 356] -> 
             RGBColor[
              0.9458360577914238, 0.9586552402649868, 0.9602757680556695], 
             UndirectedEdge[114, 327] -> 
             RGBColor[
              0.9831657353331994, 0.985974588684078, 0.8690000827136197], 
             UndirectedEdge[188, 459] -> 
             RGBColor[
              0.9553681662250121, 0.937754825121164, 0.6718988483014111], 
             UndirectedEdge[465, 469] -> 
             RGBColor[
              0.9836147093816501, 0.9862101145307256, 0.8637924119994882], 
             UndirectedEdge[44, 62] -> 
             RGBColor[
              0.8871151004655318, 0.8441855633580295, 0.6293185600764523], 
             UndirectedEdge[88, 337] -> 
             RGBColor[
              0.9790983109307108, 0.9411558361986194, 0.3733013142289361], 
             UndirectedEdge[253, 388] -> 
             RGBColor[
              0.6503738092968374, 0.7179167757650288, 0.9172596285093968], 
             UndirectedEdge[80, 238] -> 
             RGBColor[
              0.9013766119136924, 0.9210083466283681, 0.8586793246785176], 
             UndirectedEdge[171, 272] -> 
             RGBColor[
              0.9677540906489379, 0.9528543517136573, 0.6633768897605976], 
             UndirectedEdge[297, 392] -> 
             RGBColor[
              0.9282347120028638, 0.9431250681330556, 0.8959200852517253], 
             UndirectedEdge[82, 499] -> 
             RGBColor[
              0.6437844209480625, 0.7183940065008876, 0.9672975955671144], 
             UndirectedEdge[297, 484] -> 
             RGBColor[
              0.9929103129473389, 0.9913362464541475, 0.7671579921919383], 
             UndirectedEdge[73, 240] -> 
             RGBColor[
              0.9827262529935901, 0.9796599552180951, 0.6712323880140569], 
             UndirectedEdge[229, 263] -> 
             RGBColor[
              0.9934837936504275, 0.9915733954626565, 0.7576539328212726], 
             UndirectedEdge[87, 91] -> 
             RGBColor[
              0.9175121436729424, 0.9355800802335569, 0.9385334556455427], 
             UndirectedEdge[296, 339] -> 
             RGBColor[
              0.9924225398167498, 0.9911345397294513, 0.7752416552821961], 
             UndirectedEdge[62, 157] -> 
             RGBColor[
              0.8125881645725144, 0.8535888165476406, 0.9819364092403366], 
             UndirectedEdge[227, 265] -> 
             RGBColor[
              0.863044518523527, 0.8911846438228687, 0.8603735018483267], 
             UndirectedEdge[38, 127] -> 
             RGBColor[
              0.3577822093219636, 0.484314699883142, 0.9440185438969781], 
             UndirectedEdge[302, 451] -> 
             RGBColor[
              0.8842477616037, 0.9057538181205402, 0.7100158466312281], 
             UndirectedEdge[141, 151] -> 
             RGBColor[
              0.9933600335585147, 0.9882061081222784, 0.5186588138462958], 
             UndirectedEdge[72, 439] -> 
             RGBColor[
              0.8549437006354172, 0.8628953551855112, 0.6699137085131974], 
             UndirectedEdge[277, 340] -> 
             RGBColor[
              0.9852976443362951, 0.9851413154803373, 0.7025454505810413], 
             UndirectedEdge[53, 322] -> 
             RGBColor[
              0.9876518053854177, 0.9884409945208437, 0.8210662657885653], 
             UndirectedEdge[450, 461] -> 
             RGBColor[
              0.7609873351013227, 0.8133128519258355, 0.977118340034008], 
             UndirectedEdge[352, 367] -> 
             RGBColor[
              0.9914714443674499, 0.9883891396887337, 0.620031100508451], 
             UndirectedEdge[239, 251] -> 
             RGBColor[
              0.9934173347240309, 0.988182895429691, 0.5372912686165716], 
             UndirectedEdge[83, 163] -> 
             RGBColor[
              0.8569868757182724, 0.8887908809308944, 0.9684995955981615], 
             UndirectedEdge[179, 245] -> 
             RGBColor[
              0.5104560697396858, 0.5986898232883737, 0.9579659011195018], 
             UndirectedEdge[133, 237] -> 
             RGBColor[
              0.967898158707523, 0.9011681935791178, 0.5193724749301369], 
             UndirectedEdge[199, 244] -> 
             RGBColor[
              0.985262180849479, 0.9881735472836529, 0.8939073337848741], 
             UndirectedEdge[173, 269] -> 
             RGBColor[
              0.7108799714327056, 0.7684176158042221, 0.8510390791730309], 
             UndirectedEdge[209, 379] -> 
             RGBColor[
              0.8858877798524497, 0.9117074600180953, 0.9841440047191377], 
             UndirectedEdge[139, 451] -> 
             RGBColor[
              0.8841920210673672, 0.905634594749557, 0.7039488332421133], 
             UndirectedEdge[18, 218] -> 
             RGBColor[
              0.9519327186728774, 0.9548328004881683, 0.7018695571494458], 
             UndirectedEdge[59, 287] -> 
             RGBColor[
              0.9921685252311991, 0.9903646138471405, 0.7311212629046543], 
             UndirectedEdge[167, 274] -> 
             RGBColor[
              0.8893254445409801, 0.9141078031313776, 0.9726576193998663], 
             UndirectedEdge[402, 461] -> 
             RGBColor[
              0.9387603919072113, 0.9537471903821007, 0.9850454514297644], 
             UndirectedEdge[472, 488] -> 
             RGBColor[
              0.7085067307658577, 0.7689244318535502, 0.9361171608963934], 
             UndirectedEdge[227, 270] -> 
             RGBColor[
              0.6339127589610397, 0.6984189496741731, 0.8428633668975316], 
             UndirectedEdge[124, 363] -> 
             RGBColor[
              0.8619038577384419, 0.8899582146611134, 0.8407162509774597], 
             UndirectedEdge[118, 195] -> 
             RGBColor[
              0.9279266034666237, 0.9412595108258517, 0.798108340068442], 
             UndirectedEdge[54, 154] -> 
             RGBColor[
              0.9633716442818923, 0.9721976120813822, 0.9466356199849577], 
             UndirectedEdge[313, 498] -> 
             RGBColor[
              0.8907484730785882, 0.9019234873196114, 0.6896291951043716], 
             UndirectedEdge[243, 283] -> 
             RGBColor[
              0.8324632206425606, 0.8673529869700162, 0.8599864926327181], 
             UndirectedEdge[302, 346] -> 
             RGBColor[
              0.9700485104034537, 0.9735093613229129, 0.7077938259520633], 
             UndirectedEdge[13, 477] -> 
             RGBColor[
              0.9356825984761221, 0.9080202406023836, 0.6505142392747281], 
             UndirectedEdge[140, 479] -> 
             RGBColor[
              0.9646881736265642, 0.9731850782252762, 0.9446578906376146], 
             UndirectedEdge[174, 309] -> 
             RGBColor[
              0.8994464667728428, 0.9221974471527086, 0.9742961233202061], 
             UndirectedEdge[299, 312] -> 
             RGBColor[
              0.9111084518312225, 0.9274730079525582, 0.7660110333319996], 
             UndirectedEdge[215, 402] -> 
             RGBColor[
              0.8143267187656196, 0.8556350319513023, 0.9728828606757401], 
             UndirectedEdge[372, 400] -> 
             RGBColor[
              0.9579176913368159, 0.8581122214396948, 0.45648686916620695`], 
             UndirectedEdge[29, 426] -> 
             RGBColor[
              0.7598532822573931, 0.8123334559750104, 0.9766958050694123], 
             UndirectedEdge[361, 481] -> 
             RGBColor[
              0.9044733259397333, 0.924669813962369, 0.9149932942570951], 
             UndirectedEdge[188, 335] -> 
             RGBColor[
              0.9489062334985227, 0.9614149331183381, 0.9713725986851764], 
             UndirectedEdge[168, 443] -> 
             RGBColor[
              0.9862945723026082, 0.988600467680772, 0.8767979356630868], 
             UndirectedEdge[81, 500] -> 
             RGBColor[
              0.8503422909900589, 0.7986076854759374, 0.6219557683706962], 
             UndirectedEdge[75, 310] -> 
             RGBColor[
              0.9940481122489815, 0.9896778388657597, 0.5935519329741512], 
             UndirectedEdge[348, 444] -> 
             RGBColor[
              0.9727670721454373, 0.9657017547938861, 0.6742273289350718], 
             UndirectedEdge[262, 482] -> 
             RGBColor[
              0.9287461997413913, 0.9454215791637457, 0.9722826444330224], 
             UndirectedEdge[83, 395] -> 
             RGBColor[
              0.6297207802041395, 0.7084940548570626, 0.9652105261404427], 
             UndirectedEdge[26, 459] -> 
             RGBColor[
              0.9812996179546876, 0.9563124925882655, 0.5929855947358039], 
             UndirectedEdge[186, 498] -> 
             RGBColor[
              0.9823592531686731, 0.9736589888970155, 0.6596957372076558], 
             UndirectedEdge[167, 284] -> 
             RGBColor[
              0.8886160499457194, 0.9135787378037592, 0.9738584394099001], 
             UndirectedEdge[175, 359] -> 
             RGBColor[
              0.6749947683211356, 0.7449853947906813, 0.9689552427963892], 
             UndirectedEdge[65, 484] -> 
             RGBColor[
              0.9871438220637472, 0.9667308148040412, 0.551438725285346], 
             UndirectedEdge[266, 322] -> 
             RGBColor[
              0.886993527418819, 0.91179521004207, 0.9493646878869322], 
             UndirectedEdge[210, 252] -> 
             RGBColor[
              0.8431912633329561, 0.8755132894511419, 0.851056178270452], 
             UndirectedEdge[133, 271] -> 
             RGBColor[
              0.9818482883149854, 0.9521147276479751, 0.5533096617804631], 
             UndirectedEdge[190, 467] -> 
             RGBColor[
              0.954917393222007, 0.9549583844487052, 0.6988378462043665], 
             UndirectedEdge[216, 481] -> 
             RGBColor[
              0.9710367912511033, 0.9772739449655115, 0.9049856350880532], 
             UndirectedEdge[18, 406] -> 
             RGBColor[
              0.8524306519519576, 0.8854109724404642, 0.9857225996865628], 
             UndirectedEdge[315, 364] -> 
             RGBColor[
              0.9828715162900519, 0.9681940318105323, 0.6445670111957464], 
             UndirectedEdge[152, 464] -> 
             RGBColor[
              0.8327297228485403, 0.8417318332386248, 0.6621361804493487], 
             UndirectedEdge[229, 280] -> 
             RGBColor[
              0.9295913680538539, 0.9435728237373504, 0.8685187937000957], 
             UndirectedEdge[164, 259] -> 
             RGBColor[
              0.8131531721483026, 0.8541444043864452, 0.943718001746122], 
             UndirectedEdge[238, 497] -> 
             RGBColor[
              0.9908235484115242, 0.9904733156911858, 0.8017410809238936], 
             UndirectedEdge[7, 478] -> 
             RGBColor[
              0.9240626945289445, 0.8393620789173054, 0.6251654313868102], 
             UndirectedEdge[137, 227] -> 
             RGBColor[
              0.9587576147755927, 0.8628854414869285, 0.5020178805019677], 
             UndirectedEdge[44, 157] -> 
             RGBColor[
              0.8711206512673644, 0.8316210786880814, 0.6277428258592681], 
             UndirectedEdge[105, 205] -> 
             RGBColor[
              0.9334559610658484, 0.9483329231254232, 0.9417770464575227], 
             UndirectedEdge[305, 460] -> 
             RGBColor[
              0.9931705097596424, 0.9875501244662741, 0.5193405036344492], 
             UndirectedEdge[330, 492] -> 
             RGBColor[
              0.9464023103681207, 0.9595475113474823, 0.9756110874172033], 
             UndirectedEdge[94, 123] -> 
             RGBColor[
              0.9654500828277188, 0.9727128937895656, 0.8967762645518196], 
             UndirectedEdge[418, 444] -> 
             RGBColor[
              0.8465171022100235, 0.8805221496092792, 0.9629172548066152], 
             UndirectedEdge[203, 295] -> 
             RGBColor[
              0.9124745902436355, 0.9280676470375782, 0.726040761816233], 
             UndirectedEdge[342, 485] -> 
             RGBColor[
              0.6417431808317047, 0.719284337265817, 0.9654527870312338], 
             UndirectedEdge[279, 430] -> 
             RGBColor[
              0.9668019002824932, 0.9597977897024004, 0.6812358015503712], 
             UndirectedEdge[391, 448] -> 
             RGBColor[
              0.9752903155371442, 0.9799504477761944, 0.8755839954738358], 
             UndirectedEdge[174, 252] -> 
             RGBColor[
              0.9742921540671412, 0.9785492365734272, 0.8478614924997401], 
             UndirectedEdge[14, 489] -> 
             RGBColor[
              0.8543098323114569, 0.8867668594984867, 0.9716397523148933], 
             UndirectedEdge[6, 158] -> 
             RGBColor[
              0.9890667898382062, 0.9897468508744828, 0.830855116829222], 
             UndirectedEdge[201, 493] -> 
             RGBColor[
              0.9805973208155219, 0.9553956671518039, 0.6002947703767326], 
             UndirectedEdge[66, 446] -> 
             RGBColor[
              0.9717681863766762, 0.977516418098388, 0.890178607947016], 
             UndirectedEdge[449, 499] -> 
             RGBColor[
              0.8261943670997299, 0.8643753056623131, 0.9832508269203204], 
             UndirectedEdge[202, 477] -> 
             RGBColor[
              0.9471359710355658, 0.9591482738251392, 0.9390557259864802], 
             UndirectedEdge[89, 299] -> 
             RGBColor[
              0.9925129206195392, 0.9897504570948363, 0.670418862769917], 
             UndirectedEdge[57, 91] -> 
             RGBColor[
              0.6605966555068054, 0.7324057146745291, 0.9685309145175792], 
             UndirectedEdge[222, 438] -> 
             RGBColor[
              0.9681185173773567, 0.9739707019575544, 0.859465144270051], 
             UndirectedEdge[83, 346] -> 
             RGBColor[
              0.8530220080157982, 0.8858338890902644, 0.9752110824153368], 
             UndirectedEdge[38, 388] -> 
             RGBColor[
              0.3154426693714862, 0.4476423184251921, 0.9413207058507189], 
             UndirectedEdge[345, 472] -> 
             RGBColor[
              0.9671509706118195, 0.9750218281844197, 0.9404890177419045], 
             UndirectedEdge[231, 486] -> 
             RGBColor[
              0.9790339311420048, 0.9827419378524831, 0.8692249839995864], 
             UndirectedEdge[14, 251] -> 
             RGBColor[
              0.8758078384965907, 0.9004601564608503, 0.8132716160600353], 
             UndirectedEdge[404, 418] -> 
             RGBColor[
              0.7772140290141669, 0.4799215287517509, 0.5712607138079653], 
             UndirectedEdge[10, 370] -> 
             RGBColor[
              0.9908602667193901, 0.9897655958262025, 0.7485850865381275], 
             UndirectedEdge[216, 224] -> 
             RGBColor[
              0.6258135546813712, 0.6976855630622515, 0.9515110173103521], 
             UndirectedEdge[116, 143] -> 
             RGBColor[
              0.8960143924327576, 0.9103825777024601, 0.696499520325106], 
             UndirectedEdge[142, 477] -> 
             RGBColor[
              0.9512228611411638, 0.960838307912089, 0.8713253804041672], 
             UndirectedEdge[1, 378] -> 
             RGBColor[
              0.986207252733762, 0.9885643587950436, 0.8782450468946683], 
             UndirectedEdge[47, 298] -> 
             RGBColor[
              0.9383158650885937, 0.9529042813942634, 0.9680679977907732], 
             UndirectedEdge[50, 340] -> 
             RGBColor[
              0.8713753203190971, 0.8996382635459397, 0.9500411350570888], 
             UndirectedEdge[144, 417] -> 
             RGBColor[
              0.9789924820267367, 0.9829128829099771, 0.8783347485475945], 
             UndirectedEdge[326, 395] -> 
             RGBColor[
              0.7046799445804026, 0.767768316489715, 0.9724918588091669], 
             UndirectedEdge[14, 166] -> 
             RGBColor[
              0.8091990290496209, 0.8512060467153313, 0.981528329210508], 
             UndirectedEdge[41, 132] -> 
             RGBColor[
              0.8111320368917863, 0.8488638589325161, 0.7376036450392394], 
             UndirectedEdge[6, 35] -> 
             RGBColor[
              0.8541240333339085, 0.8853538811210984, 0.9110856047520834], 
             UndirectedEdge[95, 286] -> 
             RGBColor[
              0.9575710720495072, 0.9663600478195982, 0.891899103013529], 
             UndirectedEdge[435, 439] -> 
             RGBColor[
              0.8270682082531183, 0.8656511482195306, 0.9831805085326668], 
             UndirectedEdge[354, 388] -> 
             RGBColor[
              0.6507863596934337, 0.7180873759560829, 0.9104226007915939], 
             UndirectedEdge[47, 59] -> 
             RGBColor[
              0.9508888324024113, 0.9613452069278985, 0.9048704647974564], 
             UndirectedEdge[305, 493] -> 
             RGBColor[
              0.9826870507725333, 0.9532614983612728, 0.3872428908377633], 
             UndirectedEdge[26, 335] -> 
             RGBColor[
              0.9748376852281981, 0.9799726005854396, 0.8924593451195694], 
             UndirectedEdge[24, 115] -> 
             RGBColor[
              0.8383809270776807, 0.8736267040630068, 0.9354287749353514], 
             UndirectedEdge[271, 351] -> 
             RGBColor[
              0.9335824136601217, 0.9165671145726639, 0.6653510932635989], 
             UndirectedEdge[12, 40] -> 
             RGBColor[
              0.7656728421905687, 0.81690828613091, 0.9726884093180949], 
             UndirectedEdge[228, 468] -> 
             RGBColor[
              0.8163702414486473, 0.6315819514512087, 0.5902057681929451], 
             UndirectedEdge[1, 108] -> 
             RGBColor[
              0.9897273627954422, 0.988162585506308, 0.6848922140966971], 
             UndirectedEdge[97, 343] -> 
             RGBColor[
              0.6669445713882642, 0.7355059353766564, 0.9701305717956459], 
             UndirectedEdge[314, 411] -> 
             RGBColor[
              0.9587968893517761, 0.9603061038645726, 0.7025242678765167], 
             UndirectedEdge[211, 466] -> 
             RGBColor[
              0.9642394745850672, 0.9717543672316122, 0.896333078261722], 
             UndirectedEdge[12, 202] -> 
             RGBColor[
              0.9634173064449967, 0.9719899067723544, 0.9357318157274644], 
             UndirectedEdge[96, 360] -> 
             RGBColor[
              0.9454865539277513, 0.9588645416936683, 0.977161224203217], 
             UndirectedEdge[199, 482] -> 
             RGBColor[
              0.9418726735392774, 0.9550441811861616, 0.9425798400069263], 
             UndirectedEdge[9, 357] -> 
             RGBColor[
              0.9906840496060816, 0.9891344787454337, 0.7109268126897219], 
             UndirectedEdge[330, 441] -> 
             RGBColor[
              0.9674116459636175, 0.9729220966664214, 0.8216992641978591], 
             UndirectedEdge[375, 461] -> 
             RGBColor[
              0.9624865614291536, 0.9681427908351312, 0.7467768004984867], 
             UndirectedEdge[170, 268] -> 
             RGBColor[
              0.9691489822947992, 0.9728841117078502, 0.7129360043020299], 
             UndirectedEdge[66, 245] -> 
             RGBColor[
              0.8690876577961304, 0.8982749232218534, 0.9712657595465645], 
             UndirectedEdge[235, 308] -> 
             RGBColor[
              0.7887256488810537, 0.8270304073885268, 0.6882871042992389], 
             UndirectedEdge[42, 315] -> 
             RGBColor[
              0.9898437840763257, 0.9900681579597863, 0.8179783115069528], 
             UndirectedEdge[238, 403] -> 
             RGBColor[
              0.9381361319601345, 0.950222161829734, 0.8622112819103371], 
             UndirectedEdge[382, 425] -> 
             RGBColor[
              0.862614231612848, 0.8932737754541227, 0.9734523221097586], 
             UndirectedEdge[74, 215] -> 
             RGBColor[
              0.8383465441345452, 0.8706587325678702, 0.7665768364548045], 
             UndirectedEdge[350, 426] -> 
             RGBColor[
              0.8355091693369201, 0.8418605114137928, 0.6594303304462803], 
             UndirectedEdge[78, 497] -> 
             RGBColor[
              0.9885669147833374, 0.9895401396930916, 0.8391393401235732], 
             UndirectedEdge[109, 490] -> 
             RGBColor[
              0.9894623199201814, 0.9767543879917813, 0.5756708773919371], 
             UndirectedEdge[281, 317] -> 
             RGBColor[
              0.8291139240566294, 0.8668129074077418, 0.9554248060784098], 
             UndirectedEdge[219, 471] -> 
             RGBColor[
              0.993622273146866, 0.9910949770797803, 0.716420454536115], 
             UndirectedEdge[183, 243] -> 
             RGBColor[
              0.6894346248255584, 0.7498227427727187, 0.848937801762812], 
             UndirectedEdge[93, 151] -> 
             RGBColor[
              0.9904796476501863, 0.988843485579073, 0.6993062595258894], 
             UndirectedEdge[176, 478] -> 
             RGBColor[
              0.9584161135250532, 0.8617334107385313, 0.3595389926358773], 
             UndirectedEdge[28, 282] -> 
             RGBColor[
              0.9952118853668062, 0.9921670318892752, 0.7202214548742086], 
             UndirectedEdge[125, 305] -> 
             RGBColor[
              0.98683593510245, 0.9853912200315494, 0.6699357561130831], 
             UndirectedEdge[22, 466] -> 
             RGBColor[
              0.8240390116088121, 0.8633648456823934, 0.9810640532081816], 
             UndirectedEdge[78, 154] -> 
             RGBColor[
              0.9664014118055395, 0.9734504988138841, 0.896424531331113], 
             UndirectedEdge[273, 421] -> 
             RGBColor[
              0.902123019960356, 0.836525106955737, 0.6263549323633664], 
             UndirectedEdge[221, 234] -> 
             RGBColor[
              0.9772555488218864, 0.9375374859085466, 0.5417931980558184], 
             UndirectedEdge[384, 461] -> 
             RGBColor[
              0.9589563731440203, 0.9684873396000127, 0.9364399775934148], 
             UndirectedEdge[3, 428] -> 
             RGBColor[
              0.9938281664839677, 0.9892073971143232, 0.5696121938003216], 
             UndirectedEdge[209, 431] -> 
             RGBColor[
              0.9117825898430703, 0.9275149053521693, 0.7258969901922616], 
             UndirectedEdge[33, 237] -> 
             RGBColor[
              0.9540166704933342, 0.8922764125175228, 0.6082972317834101], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.8015847781640485, 0.8449719918515015, 0.9462474637995599], 
             UndirectedEdge[202, 243] -> 
             RGBColor[
              0.9897493240343016, 0.990029096304897, 0.8195437588580428], 
             UndirectedEdge[169, 456] -> 
             RGBColor[
              0.8756935712538827, 0.9001325903204213, 0.7941736343413306], 
             UndirectedEdge[86, 297] -> 
             RGBColor[
              0.991597986849023, 0.9884414682568576, 0.6179339641073394], 
             UndirectedEdge[40, 202] -> 
             RGBColor[
              0.7879364381844138, 0.833265078780064, 0.923924627023025], 
             UndirectedEdge[396, 477] -> 
             RGBColor[
              0.849497482172301, 0.8830693342985647, 0.9854435765387045], 
             UndirectedEdge[209, 355] -> 
             RGBColor[
              0.7610175228251723, 0.8133183093126954, 0.9767918528335855], 
             UndirectedEdge[131, 434] -> 
             RGBColor[
              0.9791499040851145, 0.9839706131223527, 0.9201779531946732], 
             UndirectedEdge[87, 228] -> 
             RGBColor[
              0.92115141413241, 0.7132916182858601, 0.5468337031543851], 
             UndirectedEdge[17, 116] -> 
             RGBColor[
              0.8568175389995709, 0.8888045968741094, 0.9861687188827895], 
             UndirectedEdge[104, 323] -> 
             RGBColor[
              0.9940373065296149, 0.9896547265246604, 0.5923757971062713], 
             UndirectedEdge[101, 347] -> 
             RGBColor[
              0.7779036641792192, 0.8259372819817372, 0.9494976409135396], 
             UndirectedEdge[92, 342] -> 
             RGBColor[
              0.8327814469768505, 0.869548139996625, 0.949216646417649], 
             UndirectedEdge[399, 464] -> 
             RGBColor[
              0.8422545248737167, 0.8733779263636854, 0.7402346352220261], 
             UndirectedEdge[423, 469] -> 
             RGBColor[
              0.9926692059922282, 0.9906339302559275, 0.7273502074278899], 
             UndirectedEdge[114, 415] -> 
             RGBColor[
              0.9845819189457434, 0.9865602170021237, 0.8455302552880593], 
             UndirectedEdge[244, 478] -> 
             RGBColor[
              0.9546625343546409, 0.8622933113289278, 0.575273035262615], 
             UndirectedEdge[129, 486] -> 
             RGBColor[
              0.6584475522358256, 0.7261962068164118, 0.9421294973091877], 
             UndirectedEdge[202, 421] -> 
             RGBColor[
              0.928336565088112, 0.9441581378189199, 0.9372626218647844], 
             UndirectedEdge[62, 378] -> 
             RGBColor[
              0.9073356591346688, 0.9273343186354326, 0.9318609207004485], 
             UndirectedEdge[263, 485] -> 
             RGBColor[
              0.7925724186796318, 0.8355663856339295, 0.8631559088478371], 
             UndirectedEdge[275, 346] -> 
             RGBColor[
              0.9688962045744942, 0.9753005649259444, 0.8917292152892133], 
             UndirectedEdge[127, 303] -> 
             RGBColor[
              0.6739900718122482, 0.6759850103233622, 0.6118101129996781], 
             UndirectedEdge[260, 312] -> 
             RGBColor[
              0.9100375242866585, 0.9284516093105475, 0.8870840229291062], 
             UndirectedEdge[32, 299] -> 
             RGBColor[
              0.9901226784153919, 0.9887620305169987, 0.7100313618411724], 
             UndirectedEdge[283, 396] -> 
             RGBColor[
              0.7307563101838359, 0.7895916505600531, 0.9737986177592941], 
             UndirectedEdge[87, 253] -> 
             RGBColor[
              0.9853547400212722, 0.9882118228798517, 0.8923733887728015], 
             UndirectedEdge[298, 409] -> 
             RGBColor[
              0.8424905002634137, 0.877301435789436, 0.9587142811556543], 
             UndirectedEdge[208, 258] -> 
             RGBColor[
              0.9740268004972111, 0.9777236720482829, 0.8000282120382225], 
             UndirectedEdge[142, 161] -> 
             RGBColor[
              0.9900098405929787, 0.9901368265968802, 0.8152263252855231], 
             UndirectedEdge[71, 211] -> 
             RGBColor[
              0.9506094330398303, 0.960937472219562, 0.8968126808559664], 
             UndirectedEdge[14, 453] -> 
             RGBColor[
              0.8624613533128973, 0.8567136983229746, 0.6530597905222938], 
             UndirectedEdge[89, 478] -> 
             RGBColor[
              0.9576950313480714, 0.8635473267673293, 0.5250167122308207], 
             UndirectedEdge[159, 251] -> 
             RGBColor[
              0.969563273883313, 0.9744810391637608, 0.8144279981712913], 
             UndirectedEdge[300, 305] -> 
             RGBColor[
              0.8070815214816172, 0.8445317794403349, 0.6935944882715317], 
             UndirectedEdge[327, 385] -> 
             RGBColor[
              0.9445690964492738, 0.956242424105819, 0.9015060850010679], 
             UndirectedEdge[156, 270] -> 
             RGBColor[
              0.606763018172995, 0.6798229373508774, 0.9628105791960558], 
             UndirectedEdge[418, 486] -> 
             RGBColor[
              0.8497985976125529, 0.88296948350753, 0.9573625390412053], 
             UndirectedEdge[366, 465] -> 
             RGBColor[
              0.8730399438405538, 0.9009580735577776, 0.951188743210266], 
             UndirectedEdge[337, 433] -> 
             RGBColor[
              0.9846247556509303, 0.9634520446084647, 0.5777236200651217], 
             UndirectedEdge[118, 152] -> 
             RGBColor[
              0.9179473025552811, 0.9086412905401677, 0.6705404863785666], 
             UndirectedEdge[151, 162] -> 
             RGBColor[
              0.7245371874167252, 0.7787383724223036, 0.7452208010536778], 
             UndirectedEdge[80, 251] -> 
             RGBColor[
              0.9012612889128468, 0.9203445853794177, 0.8158085781215096], 
             UndirectedEdge[348, 486] -> 
             RGBColor[
              0.9760485675479668, 0.9681490886921369, 0.6686726131696618], 
             UndirectedEdge[376, 455] -> 
             RGBColor[
              0.9684319878518721, 0.9743989648868391, 0.8676436052065718], 
             UndirectedEdge[153, 197] -> 
             RGBColor[
              0.6351664967142956, 0.7112801591062843, 0.9665870845332631], 
             UndirectedEdge[9, 319] -> 
             RGBColor[
              0.8575198437128625, 0.8880757877638512, 0.9145561652111474], 
             UndirectedEdge[184, 336] -> 
             RGBColor[
              0.7946381222587854, 0.8376222936152684, 0.8791570634824497], 
             UndirectedEdge[41, 56] -> 
             RGBColor[
              0.8055333243677195, 0.8479168111450484, 0.9395636050225296], 
             UndirectedEdge[99, 313] -> 
             RGBColor[
              0.8205575356659132, 0.8599498797168257, 0.9826948092780591], 
             UndirectedEdge[111, 130] -> 
             RGBColor[
              0.9440784251177741, 0.9570520158633337, 0.9531138160540724], 
             UndirectedEdge[255, 327] -> 
             RGBColor[
              0.9737897065055168, 0.9291176194892752, 0.5509396993901126], 
             UndirectedEdge[32, 84] -> 
             RGBColor[0.972134089320958, 0.92878049145834, 0.580779552267732],
              UndirectedEdge[196, 420] -> 
             RGBColor[
              0.9476383186170529, 0.9604693242757582, 0.9735188478543415], 
             UndirectedEdge[55, 57] -> 
             RGBColor[
              0.7314206280989511, 0.7862703330155164, 0.8729617277304149], 
             UndirectedEdge[10, 480] -> 
             RGBColor[
              0.9586459913171539, 0.8746241273814317, 0.5615359223086438], 
             UndirectedEdge[152, 216] -> 
             RGBColor[
              0.964115084974867, 0.9449824576314652, 0.6585874687678652], 
             UndirectedEdge[244, 482] -> 
             RGBColor[
              0.9419370500502526, 0.9550708025278507, 0.9415129546189964], 
             UndirectedEdge[111, 463] -> 
             RGBColor[
              0.9879911971619889, 0.9889413414091645, 0.8325265020009898], 
             UndirectedEdge[58, 74] -> 
             RGBColor[
              0.8133319540714454, 0.8509720330165793, 0.7641828295374069], 
             UndirectedEdge[66, 327] -> 
             RGBColor[
              0.9718948978666528, 0.9775688165558302, 0.8880786706392777], 
             UndirectedEdge[168, 346] -> 
             RGBColor[
              0.9676267905562885, 0.9747756296069641, 0.9127666907090544], 
             UndirectedEdge[53, 471] -> 
             RGBColor[
              0.9939127406990789, 0.9917162578031892, 0.7480360550365392], 
             UndirectedEdge[28, 125] -> 
             RGBColor[
              0.9883898586290617, 0.988965516743215, 0.8177605565902807], 
             UndirectedEdge[405, 423] -> 
             RGBColor[
              0.9842824899748214, 0.9854694742534682, 0.790374520475372], 
             UndirectedEdge[314, 493] -> 
             RGBColor[
              0.9811688963255782, 0.9481404069320776, 0.38134514749075393`], 
             UndirectedEdge[43, 229] -> 
             RGBColor[
              0.9622045809215612, 0.8768943514828802, 0.5064690387285677], 
             UndirectedEdge[281, 397] -> 
             RGBColor[
              0.9804839786038421, 0.9823035105987974, 0.7703791024527377], 
             UndirectedEdge[203, 324] -> 
             RGBColor[
              0.9719356720962324, 0.975086385390908, 0.7180549572433775], 
             UndirectedEdge[403, 445] -> 
             RGBColor[
              0.6074246820558541, 0.6857510956870972, 0.965510162240776], 
             UndirectedEdge[147, 303] -> 
             RGBColor[
              0.9198741185052282, 0.8738078532046694, 0.6332271437599903], 
             UndirectedEdge[356, 457] -> 
             RGBColor[
              0.9426343458081907, 0.9200288910121053, 0.6606889235927127], 
             UndirectedEdge[8, 85] -> 
             RGBColor[
              0.5496564858275321, 0.6223744034294147, 0.9628847148431792], 
             UndirectedEdge[301, 336] -> 
             RGBColor[
              0.9205407104929917, 0.9368977882498731, 0.8911785903911549], 
             UndirectedEdge[24, 64] -> 
             RGBColor[
              0.9678893867536491, 0.9754651367371183, 0.9344294357523065], 
             UndirectedEdge[30, 488] -> 
             RGBColor[
              0.6777535711462255, 0.7454800848008841, 0.9705376034376335], 
             UndirectedEdge[191, 366] -> 
             RGBColor[
              0.8641389938245624, 0.8943197596098191, 0.9662557298477739], 
             UndirectedEdge[185, 481] -> 
             RGBColor[
              0.9680258253690857, 0.9750283715407069, 0.910082414940636], 
             UndirectedEdge[308, 389] -> 
             RGBColor[
              0.7907499617273765, 0.8328633990161503, 0.7808005408696903], 
             UndirectedEdge[96, 240] -> 
             RGBColor[
              0.9674418980269073, 0.9682609083097773, 0.6971048141744334], 
             UndirectedEdge[108, 113] -> 
             RGBColor[
              0.9686562597920583, 0.9728022932531455, 0.7364354131066865], 
             UndirectedEdge[85, 332] -> 
             RGBColor[
              0.8761906655460592, 0.9041146694171351, 0.9880530419360658], 
             UndirectedEdge[232, 280] -> 
             RGBColor[
              0.9248086481461757, 0.9415950461452303, 0.9477808398526815], 
             UndirectedEdge[310, 419] -> 
             RGBColor[
              0.9931056255195336, 0.9876619550514962, 0.49096806882762745`], 
             UndirectedEdge[39, 378] -> 
             RGBColor[
              0.9822934585768839, 0.9638234499292624, 0.6255898718453303], 
             UndirectedEdge[53, 257] -> 
             RGBColor[
              0.9062804937266861, 0.5631792086043259, 0.4438579406141825], 
             UndirectedEdge[248, 339] -> 
             RGBColor[
              0.9671333502308079, 0.9733642466148391, 0.8668774472100682], 
             UndirectedEdge[327, 334] -> 
             RGBColor[
              0.944328227562891, 0.9560503617940292, 0.9014831107116585], 
             UndirectedEdge[165, 358] -> 
             RGBColor[
              0.9552844422886901, 0.9656929153011684, 0.9418856341396713], 
             UndirectedEdge[69, 204] -> 
             RGBColor[
              0.9635595056511443, 0.9706880148100397, 0.8730579430754937], 
             UndirectedEdge[208, 293] -> 
             RGBColor[
              0.9253096665676024, 0.942818963271588, 0.9767249322585889], 
             UndirectedEdge[265, 320] -> 
             RGBColor[
              0.8328597330863946, 0.8702752893567914, 0.9837312809184021], 
             UndirectedEdge[239, 453] -> 
             RGBColor[
              0.9800708495403375, 0.9444364372918151, 0.3770794430788301], 
             UndirectedEdge[108, 452] -> 
             RGBColor[
              0.9366271563140902, 0.9474819498887163, 0.7409661858121562], 
             UndirectedEdge[331, 418] -> 
             RGBColor[
              0.8634996295446408, 0.8907329382756981, 0.8030780792498563], 
             UndirectedEdge[28, 201] -> 
             RGBColor[
              0.9915611267791973, 0.990711706869151, 0.7846751872147304], 
             UndirectedEdge[431, 486] -> 
             RGBColor[
              0.9799481281586455, 0.9810610657713492, 0.7044129123875136], 
             UndirectedEdge[269, 419] -> 
             RGBColor[
              0.9931836846450093, 0.9891683151963855, 0.5968245321187801], 
             UndirectedEdge[315, 378] -> 
             RGBColor[
              0.9852708344349197, 0.9881771257636196, 0.8937639214793606], 
             UndirectedEdge[57, 240] -> 
             RGBColor[
              0.7308204635951971, 0.7800203693745987, 0.6837285959998535], 
             UndirectedEdge[7, 176] -> 
             RGBColor[
              0.9584802967051701, 0.964709035623323, 0.7269988018944018], 
             UndirectedEdge[6, 302] -> 
             RGBColor[
              0.990300116684679, 0.9879891515443381, 0.6455769995562046], 
             UndirectedEdge[176, 455] -> 
             RGBColor[
              0.993262703473154, 0.9893698669526488, 0.6077904474002317], 
             UndirectedEdge[161, 396] -> 
             RGBColor[
              0.8882844616241159, 0.9123678529833559, 0.9293445214200604], 
             UndirectedEdge[36, 463] -> 
             RGBColor[
              0.9853773824001144, 0.9869919626394874, 0.8369510086007717], 
             UndirectedEdge[131, 373] -> 
             RGBColor[
              0.9665736574394657, 0.9127651125538374, 0.5956718785878481], 
             UndirectedEdge[54, 341] -> 
             RGBColor[
              0.9208104648181369, 0.9384363151957511, 0.94867231382614], 
             UndirectedEdge[272, 453] -> 
             RGBColor[
              0.9730187972763302, 0.9206482091047048, 0.34968355170148757`], 
             UndirectedEdge[169, 236] -> 
             RGBColor[
              0.9869934330180923, 0.9872359086351228, 0.7655220918713126], 
             UndirectedEdge[69, 101] -> 
             RGBColor[
              0.9811056926296612, 0.9838349957725321, 0.845473933206502], 
             UndirectedEdge[286, 330] -> 
             RGBColor[
              0.9319366107755831, 0.948449168615556, 0.9893551306459718], 
             UndirectedEdge[86, 254] -> 
             RGBColor[
              0.9918237442333212, 0.988534824736965, 0.6141925800081368], 
             UndirectedEdge[68, 319] -> 
             RGBColor[
              0.515481952955039, 0.6116732381208212, 0.9570329533738722], 
             UndirectedEdge[37, 207] -> 
             RGBColor[
              0.9217568447251536, 0.9362474293688284, 0.7900228661043776], 
             UndirectedEdge[257, 317] -> 
             RGBColor[
              0.754342116626884, 0.4464730209395055, 0.567045241670724], 
             UndirectedEdge[94, 158] -> 
             RGBColor[
              0.9653162161143298, 0.9726575364633616, 0.8989947824286246], 
             UndirectedEdge[253, 336] -> 
             RGBColor[
              0.9882131406581537, 0.9893938450007478, 0.845002292915954], 
             UndirectedEdge[67, 363] -> 
             RGBColor[
              0.8120350036061048, 0.8507952134305046, 0.835885999428212], 
             UndirectedEdge[61, 295] -> 
             RGBColor[
              0.9091915694336512, 0.9172362861727796, 0.6926205451833328], 
             UndirectedEdge[16, 116] -> 
             RGBColor[
              0.885367926138255, 0.9107429373392261, 0.960220544953369], 
             UndirectedEdge[294, 439] -> 
             RGBColor[
              0.818083215795376, 0.85848675912485, 0.9823235119310499], 
             UndirectedEdge[69, 346] -> 
             RGBColor[
              0.9706158325065084, 0.9760116752682544, 0.8632305302013078], 
             UndirectedEdge[327, 415] -> 
             RGBColor[
              0.9915733135535717, 0.9907833628455076, 0.7893155321901766], 
             UndirectedEdge[54, 61] -> 
             RGBColor[
              0.9852782337311232, 0.976648755977348, 0.6562411547503312], 
             UndirectedEdge[244, 262] -> 
             RGBColor[
              0.9721357070515928, 0.9785509452612371, 0.9236101382109703], 
             UndirectedEdge[295, 397] -> 
             RGBColor[
              0.9130788626546238, 0.9293601246233694, 0.7918120846152508], 
             UndirectedEdge[61, 264] -> 
             RGBColor[
              0.9825816770366309, 0.9746432691240586, 0.6610565332868238], 
             UndirectedEdge[162, 226] -> 
             RGBColor[
              0.7218209808296967, 0.7702268340347602, 0.6793240556378326], 
             UndirectedEdge[237, 351] -> 
             RGBColor[
              0.9196322840526594, 0.8656205805038066, 0.6314139064132727], 
             UndirectedEdge[243, 273] -> 
             RGBColor[
              0.9635357789065457, 0.882396065441714, 0.508636069356625], 
             UndirectedEdge[53, 343] -> 
             RGBColor[
              0.9645046904787298, 0.9711281033104364, 0.8585213214382097], 
             UndirectedEdge[37, 445] -> 
             RGBColor[
              0.6637164141119306, 0.7264361203655191, 0.7685029992173085], 
             UndirectedEdge[144, 402] -> 
             RGBColor[
              0.9677950240893792, 0.9745618371144504, 0.8972891240707819], 
             UndirectedEdge[235, 456] -> 
             RGBColor[
              0.8736188420024441, 0.8941917631001358, 0.6961726832080206], 
             UndirectedEdge[369, 456] -> 
             RGBColor[
              0.8066072437830496, 0.8491384373564905, 0.9812813851706249], 
             UndirectedEdge[7, 61] -> 
             RGBColor[
              0.9552288168076548, 0.9539451375810202, 0.6970116189358011], 
             UndirectedEdge[76, 175] -> 
             RGBColor[
              0.768852738489924, 0.8187500004975907, 0.9530944479993396], 
             UndirectedEdge[259, 372] -> 
             RGBColor[
              0.9863930077163424, 0.9870799586747969, 0.7896952066825125], 
             UndirectedEdge[187, 224] -> 
             RGBColor[
              0.6424931457777201, 0.7096000407699065, 0.8997602459158769], 
             UndirectedEdge[142, 183] -> 
             RGBColor[
              0.6894530933356966, 0.7498303799762798, 0.8486317307548508], 
             UndirectedEdge[255, 299] -> 
             RGBColor[
              0.9755282864808844, 0.9284151095693081, 0.4188019811854833], 
             UndirectedEdge[233, 444] -> 
             RGBColor[
              0.974124640270293, 0.97962146869529, 0.9017564832889833], 
             UndirectedEdge[148, 280] -> 
             RGBColor[
              0.8174221342194947, 0.857661429149172, 0.982339590881909], 
             UndirectedEdge[7, 376] -> 
             RGBColor[
              0.9336495810838881, 0.9497381335575132, 0.9868519597007419], 
             UndirectedEdge[73, 256] -> 
             RGBColor[
              0.982379822938547, 0.9855184776825796, 0.876153041292079], 
             UndirectedEdge[207, 403] -> 
             RGBColor[
              0.8654651126690771, 0.8955624046904066, 0.9870300291278451], 
             UndirectedEdge[233, 346] -> 
             RGBColor[
              0.9676275326851278, 0.974775936496311, 0.9127543917136194], 
             UndirectedEdge[293, 403] -> 
             RGBColor[
              0.8892417570600744, 0.9145212555279691, 0.9892978666955194], 
             UndirectedEdge[321, 391] -> 
             RGBColor[
              0.9758829187701781, 0.9801955044422623, 0.8657630262944587], 
             UndirectedEdge[228, 298] -> 
             RGBColor[
              0.9107890634591315, 0.7057648395433442, 0.5733955975214924], 
             UndirectedEdge[54, 455] -> 
             RGBColor[
              0.9889587014005139, 0.9897021535277508, 0.8326464219656947], 
             UndirectedEdge[323, 419] -> 
             RGBColor[
              0.9933095568971291, 0.9880981436475478, 0.5131647407603104], 
             UndirectedEdge[65, 194] -> 
             RGBColor[
              0.9757859286257532, 0.9299823928996465, 0.3604333344650872], 
             UndirectedEdge[40, 273] -> 
             RGBColor[
              0.761722893056658, 0.7256320479168811, 0.6130169375216071], 
             UndirectedEdge[209, 400] -> 
             RGBColor[
              0.875934687899568, 0.7965535674330259, 0.6195823726183445], 
             UndirectedEdge[31, 488] -> 
             RGBColor[
              0.31893288142418497`, 0.44045675880847845`, 0.941916886145568], 
             UndirectedEdge[399, 407] -> 
             RGBColor[
              0.987308651605324, 0.9683679425380285, 0.44629333486987344`], 
             UndirectedEdge[292, 399] -> 
             RGBColor[
              0.9090362829321663, 0.9255871599099285, 0.7468805160245777], 
             UndirectedEdge[93, 218] -> 
             RGBColor[
              0.9882311607056757, 0.9819096753715371, 0.6352265165997832], 
             UndirectedEdge[198, 270] -> 
             RGBColor[
              0.6333130825407813, 0.6961484955687168, 0.7057891570345123], 
             UndirectedEdge[78, 192] -> 
             RGBColor[
              0.9916472466219759, 0.9888532622173694, 0.6455699788051394], 
             UndirectedEdge[286, 492] -> 
             RGBColor[
              0.9381491607957406, 0.9530824782484724, 0.9788389039543948], 
             UndirectedEdge[317, 343] -> 
             RGBColor[
              0.8125663133789276, 0.854421915645616, 0.9817086224947512], 
             UndirectedEdge[51, 203] -> 
             RGBColor[
              0.9372136179917808, 0.9477938762409301, 0.728400392367642], 
             UndirectedEdge[212, 216] -> 
             RGBColor[
              0.8801876475682345, 0.9069399279789911, 0.9720485602423083], 
             UndirectedEdge[100, 257] -> 
             RGBColor[
              0.8853350795877124, 0.549428475705137, 0.5640332494682333], 
             UndirectedEdge[189, 302] -> 
             RGBColor[
              0.9834955765136079, 0.9835381612103158, 0.6850314505841109], 
             UndirectedEdge[306, 382] -> 
             RGBColor[
              0.9686443852699869, 0.9756996986909454, 0.918439860583439], 
             UndirectedEdge[20, 150] -> 
             RGBColor[
              0.8631829638864181, 0.8262551325546648, 0.6271365836400405], 
             UndirectedEdge[255, 446] -> 
             RGBColor[
              0.97366299501554, 0.9290652210318331, 0.5530396366978507], 
             UndirectedEdge[182, 237] -> 
             RGBColor[
              0.859655657383303, 0.8181483029913085, 0.6256000164520099], 
             UndirectedEdge[4, 366] -> 
             RGBColor[
              0.880825989700172, 0.9054599645758759, 0.8795716012024186], 
             UndirectedEdge[231, 275] -> 
             RGBColor[
              0.9907078496764665, 0.9904254712909175, 0.8036585083825271], 
             UndirectedEdge[97, 231] -> 
             RGBColor[
              0.6955943612643617, 0.7557805297306592, 0.8722116416130917], 
             UndirectedEdge[114, 128] -> 
             RGBColor[
              0.9228821272759697, 0.7412357621120738, 0.5690548860378586], 
             UndirectedEdge[207, 471] -> 
             RGBColor[
              0.9210199846111686, 0.9369993250875084, 0.879038669923538], 
             UndirectedEdge[54, 391] -> 
             RGBColor[
              0.9718711663382544, 0.978536541714327, 0.932248146173922], 
             UndirectedEdge[299, 478] -> 
             RGBColor[
              0.9588164006202953, 0.8625895843600206, 0.4031077726673822], 
             UndirectedEdge[44, 365] -> 
             RGBColor[
              0.9694886365255285, 0.9068637467210403, 0.5176664369569254], 
             UndirectedEdge[6, 101] -> 
             RGBColor[
              0.978185149456716, 0.9826272761159833, 0.8938748917056543], 
             UndirectedEdge[236, 308] -> 
             RGBColor[
              0.7835769799453949, 0.830168431590949, 0.9398941971591359], 
             UndirectedEdge[47, 256] -> 
             RGBColor[
              0.9506632066478076, 0.9612519048800525, 0.9086096674519766], 
             UndirectedEdge[304, 427] -> 
             RGBColor[
              0.9578404547763205, 0.8742910173204523, 0.5748857474519957], 
             UndirectedEdge[54, 397] -> 
             RGBColor[
              0.9891655269520958, 0.9887725944279377, 0.7554326941822491], 
             UndirectedEdge[220, 254] -> 
             RGBColor[
              0.829691761406276, 0.865689011439601, 0.8824326913875326], 
             UndirectedEdge[377, 426] -> 
             RGBColor[
              0.8467828267731616, 0.8782199476168651, 0.8451679703905144], 
             UndirectedEdge[216, 292] -> 
             RGBColor[
              0.8893900757594118, 0.9141677514138058, 0.9729554715531206], 
             UndirectedEdge[42, 119] -> 
             RGBColor[
              0.6544434714896167, 0.719194512429468, 0.8349225527968683], 
             UndirectedEdge[170, 491] -> 
             RGBColor[
              0.9591363289304558, 0.939242282713289, 0.6627122097866207], 
             UndirectedEdge[257, 326] -> 
             RGBColor[
              0.8629188308658924, 0.5320095680277765, 0.5776772575359016], 
             UndirectedEdge[98, 347] -> 
             RGBColor[
              0.7719684926278334, 0.7705045845790187, 0.6231887165789084], 
             UndirectedEdge[271, 311] -> 
             RGBColor[
              0.9826953112725151, 0.9519457331644513, 0.5015275612030031], 
             UndirectedEdge[156, 227] -> 
             RGBColor[
              0.9669872235903075, 0.9732474860210797, 0.8667764158064278], 
             UndirectedEdge[151, 160] -> 
             RGBColor[
              0.9941028530644063, 0.989794923934808, 0.5995101329119952], 
             UndirectedEdge[93, 167] -> 
             RGBColor[
              0.9058663279030197, 0.925910719557556, 0.9207783147486966], 
             UndirectedEdge[275, 348] -> 
             RGBColor[
              0.9877224860824285, 0.9758326221305713, 0.6031061375526025], 
             UndirectedEdge[34, 394] -> 
             RGBColor[
              0.833771557367386, 0.8678267072633377, 0.8255503953259635], 
             UndirectedEdge[405, 488] -> 
             RGBColor[
              0.7067580535818891, 0.7676202712729426, 0.9390772152407986], 
             UndirectedEdge[338, 443] -> 
             RGBColor[
              0.9895000681892778, 0.9890106170933073, 0.7571342559011214], 
             UndirectedEdge[301, 316] -> 
             RGBColor[
              0.8129011371723476, 0.8540060992943255, 0.9819217512865623], 
             UndirectedEdge[103, 209] -> 
             RGBColor[
              0.9126403560923513, 0.9293495806259104, 0.8192595529068296], 
             UndirectedEdge[126, 414] -> 
             RGBColor[
              0.9795682537297588, 0.9410736113854341, 0.5169150542721328], 
             UndirectedEdge[154, 341] -> 
             RGBColor[
              0.8999563975440306, 0.9228889866823804, 0.9842236215367028], 
             UndirectedEdge[306, 347] -> 
             RGBColor[
              0.7870998841766514, 0.8323598920981006, 0.9144096435290847], 
             UndirectedEdge[20, 388] -> 
             RGBColor[
              0.5478182005197646, 0.6379274291935135, 0.960023391882294], 
             UndirectedEdge[286, 319] -> 
             RGBColor[
              0.8255759893453714, 0.8645036687170513, 0.9830269342463303], 
             UndirectedEdge[62, 96] -> 
             RGBColor[
              0.8866995185610917, 0.9122590303123641, 0.9809038619641409], 
             UndirectedEdge[149, 242] -> 
             RGBColor[
              0.8782797568404903, 0.905780454108442, 0.9882523013286824], 
             UndirectedEdge[212, 319] -> 
             RGBColor[
              0.76692506639836, 0.8178469578075678, 0.9774035813625142], 
             UndirectedEdge[289, 470] -> 
             RGBColor[
              0.9936186671138316, 0.9897875026263339, 0.6215490190492104], 
             UndirectedEdge[291, 353] -> 
             RGBColor[
              0.9853311647229819, 0.9868700493857498, 0.8331133137733027], 
             UndirectedEdge[21, 91] -> 
             RGBColor[
              0.9174490028693159, 0.9355539698886126, 0.9395798621647964], 
             UndirectedEdge[95, 224] -> 
             RGBColor[
              0.6445460562156327, 0.7104489719933751, 0.8657382071977568], 
             UndirectedEdge[218, 235] -> 
             RGBColor[
              0.9895639985089997, 0.9764590578604896, 0.4139585341913251], 
             UndirectedEdge[108, 315] -> 
             RGBColor[
              0.9887909444965997, 0.987775352474884, 0.7004110886813893], 
             UndirectedEdge[61, 154] -> 
             RGBColor[
              0.964424166457017, 0.9611014274639774, 0.691792462460894], 
             UndirectedEdge[297, 413] -> 
             RGBColor[
              0.8730511957320364, 0.8996447379831172, 0.8905182400696197], 
             UndirectedEdge[294, 438] -> 
             RGBColor[
              0.9224149504515009, 0.9408262973640836, 0.987387489197555], 
             UndirectedEdge[277, 386] -> 
             RGBColor[
              0.9785457939944753, 0.9389696450148495, 0.3985713146004738], 
             UndirectedEdge[125, 249] -> 
             RGBColor[
              0.9694873520373306, 0.9767642976260924, 0.9365341334143829], 
             UndirectedEdge[211, 308] -> 
             RGBColor[
              0.7890866750107364, 0.8331814811661902, 0.8814833777584365], 
             UndirectedEdge[273, 477] -> 
             RGBColor[
              0.9209224259078099, 0.8515152429619564, 0.6281480364850625], 
             UndirectedEdge[154, 397] -> 
             RGBColor[
              0.9683114596779896, 0.973225265914567, 0.790984001892812], 
             UndirectedEdge[105, 230] -> 
             RGBColor[
              0.9191159949471015, 0.8867528170978771, 0.6370802235379307], 
             UndirectedEdge[355, 404] -> 
             RGBColor[
              0.7565984925423614, 0.46381651497609633`, 0.5692059497955974], 
             UndirectedEdge[250, 263] -> 
             RGBColor[
              0.9608300197363391, 0.9686582788426883, 0.8791670416275121], 
             UndirectedEdge[11, 259] -> 
             RGBColor[
              0.9194142351914942, 0.9374852711186773, 0.9542218270735097], 
             UndirectedEdge[339, 439] -> 
             RGBColor[
              0.8634007121349798, 0.8914715136093441, 0.8607993557363884], 
             UndirectedEdge[303, 379] -> 
             RGBColor[
              0.9444820708301891, 0.8932901412977218, 0.6307403155843356], 
             UndirectedEdge[416, 468] -> 
             RGBColor[
              0.8732008761374588, 0.9011885163212541, 0.956505754958421], 
             UndirectedEdge[77, 336] -> 
             RGBColor[
              0.978874910592199, 0.9826143096088851, 0.8690897386683502], 
             UndirectedEdge[297, 412] -> 
             RGBColor[
              0.9581193798768741, 0.966954291098092, 0.8987705115519062], 
             UndirectedEdge[69, 418] -> 
             RGBColor[
              0.8631921440790288, 0.8913641272882744, 0.8632973783362403], 
             UndirectedEdge[281, 322] -> 
             RGBColor[
              0.9734621190884772, 0.9797286723847538, 0.9298058895820687], 
             UndirectedEdge[51, 495] -> 
             RGBColor[
              0.9117931684708855, 0.9323392119367695, 0.9857653916268704], 
             UndirectedEdge[227, 229] -> 
             RGBColor[
              0.9940404213647925, 0.9918035753272262, 0.748429171087897], 
             UndirectedEdge[192, 497] -> 
             RGBColor[
              0.98992891480202, 0.9881426878507042, 0.6740471839620072], 
             UndirectedEdge[143, 277] -> 
             RGBColor[
              0.9910430229139542, 0.9811257326491442, 0.44712068904899455`], 
             UndirectedEdge[87, 161] -> 
             RGBColor[
              0.9857847646781377, 0.9883896491265951, 0.885246767340403], 
             UndirectedEdge[114, 255] -> 
             RGBColor[
              0.9667983118976884, 0.9248944736458913, 0.6071544224879952], 
             UndirectedEdge[341, 391] -> 
             RGBColor[
              0.9084559196003928, 0.9292279163153253, 0.9698361477256674], 
             UndirectedEdge[35, 347] -> 
             RGBColor[
              0.6538425480564117, 0.7286638869868522, 0.9667083539599688], 
             UndirectedEdge[99, 498] -> 
             RGBColor[
              0.9155168562362228, 0.9214775657846213, 0.6920435206667005], 
             UndirectedEdge[89, 448] -> 
             RGBColor[
              0.9912277806505467, 0.9906404761103162, 0.7950419066037888], 
             UndirectedEdge[130, 371] -> 
             RGBColor[
              0.6444128379853488, 0.7169402773369883, 0.9682574418153937], 
             UndirectedEdge[187, 481] -> 
             RGBColor[
              0.9877163823474521, 0.9891884226731664, 0.8532348636935779], 
             UndirectedEdge[427, 500] -> 
             RGBColor[
              0.8756225781987939, 0.9025681348593082, 0.9322469841328929], 
             UndirectedEdge[134, 247] -> 
             RGBColor[
              0.7996333421206676, 0.8412844734832496, 0.8631144807030712], 
             UndirectedEdge[79, 301] -> 
             RGBColor[
              0.8516095382720188, 0.6467883068503639, 0.5920926594413038], 
             UndirectedEdge[173, 323] -> 
             RGBColor[
              0.7110058436848254, 0.7673474442553844, 0.7673792878145611], 
             UndirectedEdge[84, 262] -> 
             RGBColor[
              0.9583009842228134, 0.9188656792336711, 0.622193066042297], 
             UndirectedEdge[262, 391] -> 
             RGBColor[
              0.9592307389316209, 0.9691149323655167, 0.9538959040492228], 
             UndirectedEdge[205, 382] -> 
             RGBColor[
              0.9678353657924847, 0.9753651483461461, 0.9318474070009424], 
             UndirectedEdge[50, 499] -> 
             RGBColor[
              0.8066075089700329, 0.8490739032257585, 0.9812985919515482], 
             UndirectedEdge[108, 380] -> 
             RGBColor[
              0.9525397743335731, 0.8381661925348034, 0.3707578207754514], 
             UndirectedEdge[300, 493] -> 
             RGBColor[
              0.7976716390445534, 0.8127900364346532, 0.6570388719107316], 
             UndirectedEdge[331, 382] -> 
             RGBColor[
              0.9724379400691843, 0.9765100889357022, 0.8004473709813048], 
             UndirectedEdge[186, 495] -> 
             RGBColor[
              0.9605333055864372, 0.9700863844439216, 0.9516909984664117], 
             UndirectedEdge[93, 235] -> 
             RGBColor[
              0.9887345348989887, 0.9836076747234628, 0.6371820302865637], 
             UndirectedEdge[18, 300] -> 
             RGBColor[
              0.7684354613918527, 0.8194824299907439, 0.9775632815694235], 
             UndirectedEdge[223, 246] -> 
             RGBColor[
              0.934325003401165, 0.9474359204417481, 0.8728186681730233], 
             UndirectedEdge[233, 431] -> 
             RGBColor[
              0.9903533748037407, 0.9882199707801503, 0.6598716131948602], 
             UndirectedEdge[182, 351] -> 
             RGBColor[
              0.8364776674603522, 0.872800059295694, 0.9841719149586663], 
             UndirectedEdge[163, 209] -> 
             RGBColor[
              0.8930216154269314, 0.9170278629089601, 0.9720682818938453], 
             UndirectedEdge[70, 182] -> 
             RGBColor[
              0.8636474383074593, 0.894075242812576, 0.9732677026556057], 
             UndirectedEdge[59, 335] -> 
             RGBColor[
              0.9753011784534864, 0.9801642669453289, 0.8847780628945255], 
             UndirectedEdge[258, 453] -> 
             RGBColor[
              0.9811594647046762, 0.9469106491440489, 0.48317290903741283`], 
             UndirectedEdge[161, 354] -> 
             RGBColor[
              0.9861475242756503, 0.988539659542663, 0.8792349020178734], 
             UndirectedEdge[213, 489] -> 
             RGBColor[
              0.9488400952634564, 0.9613656073309171, 0.9714845534655293], 
             UndirectedEdge[260, 407] -> 
             RGBColor[
              0.9864118219202428, 0.9697189216134574, 0.5863158020642193], 
             UndirectedEdge[95, 185] -> 
             RGBColor[
              0.9697152154795325, 0.9757269777667221, 0.8820848488090729], 
             UndirectedEdge[117, 479] -> 
             RGBColor[
              0.7615730772597591, 0.8133208410714851, 0.9654170156222814], 
             UndirectedEdge[164, 444] -> 
             RGBColor[
              0.8042970231788307, 0.8475395029856261, 0.9587091518978567], 
             UndirectedEdge[32, 334] -> 
             RGBColor[
              0.9425551960618876, 0.9553171677035331, 0.9308668311417232], 
             UndirectedEdge[46, 325] -> 
             RGBColor[
              0.8126324852334033, 0.8009113716512557, 0.6252308539854126], 
             UndirectedEdge[18, 201] -> 
             RGBColor[
              0.9513611431628212, 0.9620880607078947, 0.9208191800354245], 
             UndirectedEdge[328, 398] -> 
             RGBColor[
              0.9435465825529447, 0.9574177142187491, 0.9804450897151955], 
             UndirectedEdge[376, 448] -> 
             RGBColor[
              0.9671181472062464, 0.9738556580157085, 0.8894173448151856], 
             UndirectedEdge[326, 355] -> 
             RGBColor[
              0.7999419474927764, 0.844355588967282, 0.9805044992066256], 
             UndirectedEdge[257, 281] -> 
             RGBColor[
              0.8920908074297456, 0.5544668864682362, 0.5525975644076859], 
             UndirectedEdge[32, 89] -> 
             RGBColor[
              0.9890013091431681, 0.9897197729243075, 0.8319403014046108], 
             UndirectedEdge[341, 397] -> 
             RGBColor[
              0.9257502802142342, 0.9394639690289359, 0.7930206957339945], 
             UndirectedEdge[160, 274] -> 
             RGBColor[
              0.9744840191478451, 0.9782068141640667, 0.8105331907322972], 
             UndirectedEdge[151, 235] -> 
             RGBColor[
              0.9918124854535102, 0.9833928680680255, 0.47803827711743124`], 
             UndirectedEdge[11, 372] -> 
             RGBColor[
              0.9276570467462244, 0.941340197203598, 0.8220468358124451], 
             UndirectedEdge[99, 295] -> 
             RGBColor[
              0.8386891508923011, 0.8742119795837258, 0.984476113990393], 
             UndirectedEdge[154, 199] -> 
             RGBColor[
              0.9638576906731449, 0.9723986047549877, 0.9385805734341622], 
             UndirectedEdge[169, 308] -> 
             RGBColor[
              0.7908003781324924, 0.8329712346088123, 0.7862880554325489], 
             UndirectedEdge[158, 410] -> 
             RGBColor[
              0.9135617384500518, 0.9315123263769679, 0.8983022719343567], 
             UndirectedEdge[311, 465] -> 
             RGBColor[
              0.9855772831765441, 0.9865024289868009, 0.7935227470938762], 
             UndirectedEdge[139, 428] -> 
             RGBColor[
              0.9934066705985164, 0.9883058600351138, 0.5237349678400268], 
             UndirectedEdge[113, 364] -> 
             RGBColor[
              0.9627368315855105, 0.9532209725887937, 0.6805913356210436], 
             UndirectedEdge[89, 475] -> 
             RGBColor[
              0.9841892024950532, 0.9623707972374318, 0.5787132518569873], 
             UndirectedEdge[375, 441] -> 
             RGBColor[
              0.9939119790824598, 0.989386663787744, 0.5787346779147753], 
             UndirectedEdge[244, 295] -> 
             RGBColor[
              0.9086894701607544, 0.9285600848054791, 0.9383417707686712], 
             UndirectedEdge[187, 260] -> 
             RGBColor[
              0.9894226484113109, 0.9898940075396097, 0.8249576193404131], 
             UndirectedEdge[207, 322] -> 
             RGBColor[
              0.9147590492975076, 0.9337240618051628, 0.9520688806755639], 
             UndirectedEdge[100, 457] -> 
             RGBColor[
              0.960572697954446, 0.9338772455093749, 0.6466178097522016], 
             UndirectedEdge[364, 416] -> 
             RGBColor[
              0.9759248175155036, 0.9630565509020375, 0.6582675154191708], 
             UndirectedEdge[313, 386] -> 
             RGBColor[
              0.8799276594925038, 0.8654223422458951, 0.6475923776616166], 
             UndirectedEdge[31, 472] -> 
             RGBColor[
              0.5879050147561579, 0.6542566811908415, 0.92880631326529], 
             UndirectedEdge[37, 49] -> 
             RGBColor[
              0.8427112237132617, 0.8742581744196889, 0.7822075522739205], 
             UndirectedEdge[201, 406] -> 
             RGBColor[
              0.8889869820847106, 0.9125944906805861, 0.9148056859276403], 
             UndirectedEdge[245, 376] -> 
             RGBColor[
              0.8638574671293487, 0.8943742555862189, 0.9801191080932297], 
             UndirectedEdge[58, 215] -> 
             RGBColor[
              0.657900759926376, 0.7325312293001639, 0.9666362710289145], 
             UndirectedEdge[84, 407] -> 
             RGBColor[
              0.9694941603703728, 0.9087587811968094, 0.33599100289367245`], 
             UndirectedEdge[100, 324] -> 
             RGBColor[
              0.9521628529208364, 0.9638437145512748, 0.9658599914655768], 
             UndirectedEdge[89, 176] -> 
             RGBColor[
              0.9921126335242971, 0.988894283473347, 0.626850082738412], 
             UndirectedEdge[75, 379] -> 
             RGBColor[
              0.967814340603173, 0.9731453888255188, 0.814905063162666], 
             UndirectedEdge[123, 422] -> 
             RGBColor[
              0.9917390632190122, 0.9908519045917394, 0.7865686312874436], 
             UndirectedEdge[407, 455] -> 
             RGBColor[
              0.9875114501414398, 0.9701736461420787, 0.5680921166923709], 
             UndirectedEdge[333, 358] -> 
             RGBColor[
              0.9048827782148774, 0.9255039964854351, 0.9370782784262144], 
             UndirectedEdge[120, 124] -> 
             RGBColor[
              0.8574012549029575, 0.8882549107480462, 0.9268673454186365], 
             UndirectedEdge[88, 433] -> 
             RGBColor[
              0.9861272781323074, 0.968520405747205, 0.5835606361777094], 
             UndirectedEdge[345, 456] -> 
             RGBColor[
              0.8569966942141921, 0.8887728855603914, 0.9672013830028147], 
             UndirectedEdge[392, 474] -> 
             RGBColor[
              0.92665859198804, 0.9424733020024891, 0.9220404727652024], 
             UndirectedEdge[165, 333] -> 
             RGBColor[
              0.8747326227841875, 0.902952065696335, 0.9879139725158284], 
             UndirectedEdge[31, 133] -> 
             RGBColor[
              0.5956586044269606, 0.6585782855522921, 0.8502544902340612], 
             UndirectedEdge[171, 208] -> 
             RGBColor[
              0.9554775266557312, 0.9663157927954793, 0.9602491134377673], 
             UndirectedEdge[284, 472] -> 
             RGBColor[
              0.9651900026394473, 0.9735593414814149, 0.9438084250167721], 
             UndirectedEdge[196, 427] -> 
             RGBColor[
              0.9620148871392782, 0.9709465555440822, 0.9382208711960198], 
             UndirectedEdge[179, 334] -> 
             RGBColor[
              0.5674344074320716, 0.6438363438889179, 0.9634765633081366], 
             UndirectedEdge[97, 233] -> 
             RGBColor[
              0.6939665657951793, 0.7551073944717168, 0.8991884251370788], 
             UndirectedEdge[21, 409] -> 
             RGBColor[
              0.8527897101330657, 0.8848021041870078, 0.9331987933078006], 
             UndirectedEdge[63, 344] -> 
             RGBColor[
              0.7837707615633533, 0.8316681539821205, 0.9759145102136986], 
             UndirectedEdge[292, 398] -> 
             RGBColor[
              0.8858427841857379, 0.9115221871663166, 0.9789601109055344], 
             UndirectedEdge[71, 197] -> 
             RGBColor[
              0.6714612354310349, 0.7402205985645749, 0.9700489091127615], 
             UndirectedEdge[81, 121] -> 
             RGBColor[
              0.6039029480095106, 0.5921879327578061, 0.6027416695535592], 
             UndirectedEdge[163, 317] -> 
             RGBColor[
              0.823369325855527, 0.8625285954752757, 0.965148912401708], 
             UndirectedEdge[167, 172] -> 
             RGBColor[
              0.8683066572231796, 0.776349474042804, 0.6156925725555228], 
             UndirectedEdge[191, 488] -> 
             RGBColor[
              0.6991035872002475, 0.7619115827785526, 0.952034230220351], 
             UndirectedEdge[392, 490] -> 
             RGBColor[
              0.9297603308408222, 0.9437559507291671, 0.8706366329317636], 
             UndirectedEdge[251, 272] -> 
             RGBColor[
              0.9863652824600236, 0.9643946672425807, 0.5098953772392291], 
             UndirectedEdge[66, 255] -> 
             RGBColor[
              0.9555274744311419, 0.9164887015176435, 0.6262330104136532], 
             UndirectedEdge[177, 194] -> 
             RGBColor[
              0.866454432589979, 0.8657811610396198, 0.6621437117472083], 
             UndirectedEdge[36, 359] -> 
             RGBColor[
              0.8763176507327315, 0.9035130017111586, 0.9512298685536295], 
             UndirectedEdge[46, 377] -> 
             RGBColor[
              0.9751337511692479, 0.9258460961187455, 0.5012323753002684], 
             UndirectedEdge[6, 306] -> 
             RGBColor[
              0.9873813694541482, 0.9890498862323466, 0.8587868943211994], 
             UndirectedEdge[7, 455] -> 
             RGBColor[
              0.9589092844770454, 0.966998535131423, 0.8734168861511646], 
             UndirectedEdge[84, 482] -> 
             RGBColor[
              0.9281023272214732, 0.8953855365002847, 0.6400958824503232], 
             UndirectedEdge[83, 97] -> 
             RGBColor[
              0.5793610411258499, 0.6661653470656702, 0.9616451158387962], 
             UndirectedEdge[125, 408] -> 
             RGBColor[
              0.9528509073521823, 0.9640584512491208, 0.9543491228364687], 
             UndirectedEdge[184, 473] -> 
             RGBColor[
              0.796067914478496, 0.8370911221794329, 0.7738730931666504], 
             UndirectedEdge[410, 422] -> 
             RGBColor[
              0.914980250894051, 0.9320989177266685, 0.8747938497447629], 
             UndirectedEdge[202, 283] -> 
             RGBColor[
              0.8283947990471008, 0.8656705900866276, 0.9274107672070699], 
             UndirectedEdge[320, 329] -> 
             RGBColor[
              0.9634968667271823, 0.9707458605768035, 0.877732684274819], 
             UndirectedEdge[146, 387] -> 
             RGBColor[
              0.8487037991949633, 0.8819353039592426, 0.9481967867524377], 
             UndirectedEdge[107, 170] -> 
             RGBColor[
              0.9472451801786377, 0.960176122272093, 0.9741843286836522], 
             UndirectedEdge[273, 459] -> 
             RGBColor[
              0.9534771352209239, 0.848014124677188, 0.30874216516298486`], 
             UndirectedEdge[5, 395] -> 
             RGBColor[
              0.7425843849483063, 0.7967157736087545, 0.9316219565429343], 
             UndirectedEdge[104, 242] -> 
             RGBColor[
              0.9377836048823507, 0.9490510450452241, 0.793522335432491], 
             UndirectedEdge[422, 437] -> 
             RGBColor[
              0.7653149094336997, 0.8134375116912838, 0.8610100978724511], 
             UndirectedEdge[29, 177] -> 
             RGBColor[
              0.7908965480387848, 0.836584691140992, 0.9797899076866889], 
             UndirectedEdge[202, 285] -> 
             RGBColor[
              0.9747623530200997, 0.9804510239322574, 0.9165276111378555], 
             UndirectedEdge[182, 460] -> 
             RGBColor[
              0.8853725635503419, 0.9077123946743948, 0.7966202625338692], 
             UndirectedEdge[116, 333] -> 
             RGBColor[
              0.8136495596301014, 0.854383621888479, 0.9820513184740194], 
             UndirectedEdge[405, 472] -> 
             RGBColor[
              0.9757301869138619, 0.9814201936553055, 0.9259666423605205], 
             UndirectedEdge[51, 96] -> 
             RGBColor[
              0.9131734309044234, 0.9333686093997298, 0.9834289673569885], 
             UndirectedEdge[115, 402] -> 
             RGBColor[
              0.8188307393326233, 0.8591536070500698, 0.9733317793533938], 
             UndirectedEdge[67, 120] -> 
             RGBColor[
              0.8075324007706204, 0.8490919095174375, 0.9220370938693887], 
             UndirectedEdge[72, 222] -> 
             RGBColor[
              0.9860191969554816, 0.9634076260644299, 0.550321403998397], 
             UndirectedEdge[84, 328] -> 
             RGBColor[
              0.9489255900644219, 0.9118735256211418, 0.6380631628580379], 
             UndirectedEdge[123, 401] -> 
             RGBColor[
              0.9781882638446415, 0.9435150438930454, 0.5649863990552507], 
             UndirectedEdge[143, 178] -> 
             RGBColor[
              0.9916556284757205, 0.983325780799258, 0.5784742234116396], 
             UndirectedEdge[2, 385] -> 
             RGBColor[
              0.9415471788563183, 0.9401798339483574, 0.691505194886461], 
             UndirectedEdge[113, 487] -> 
             RGBColor[
              0.8022514112481756, 0.8462292316415135, 0.9730724507493422], 
             UndirectedEdge[12, 430] -> 
             RGBColor[
              0.9625711495708837, 0.9566425027489006, 0.6883973589486179], 
             UndirectedEdge[72, 344] -> 
             RGBColor[
              0.9581480319412631, 0.9443940778520605, 0.6768860855778385], 
             UndirectedEdge[127, 221] -> 
             RGBColor[
              0.6962446946869317, 0.7560494593136985, 0.8614339337921586], 
             UndirectedEdge[466, 491] -> 
             RGBColor[
              0.9551915225446279, 0.9363002525697663, 0.6693897380275433], 
             UndirectedEdge[236, 289] -> 
             RGBColor[
              0.9864586155949329, 0.9860919882453206, 0.707310515870945], 
             UndirectedEdge[200, 298] -> 
             RGBColor[
              0.9746387403324803, 0.9805388011810559, 0.9247961625412798], 
             UndirectedEdge[231, 431] -> 
             RGBColor[
              0.9919811702729231, 0.9888931060390926, 0.6328948296708732], 
             UndirectedEdge[171, 238] -> 
             RGBColor[
              0.9760719990477352, 0.9799129892780714, 0.846476382531707], 
             UndirectedEdge[276, 306] -> 
             RGBColor[
              0.60764081461632, 0.6731392157970155, 0.9022406434554823], 
             UndirectedEdge[294, 296] -> 
             RGBColor[
              0.947105043477146, 0.9581497852449572, 0.8967658114768575], 
             UndirectedEdge[1, 119] -> 
             RGBColor[
              0.6499890700833169, 0.7173525029750685, 0.9087435117205684], 
             UndirectedEdge[103, 444] -> 
             RGBColor[
              0.9775243990053972, 0.9804484071468396, 0.8033301908674916], 
             UndirectedEdge[331, 486] -> 
             RGBColor[
              0.980701920959815, 0.9826733523529079, 0.7864586069248778], 
             UndirectedEdge[100, 281] -> 
             RGBColor[
              0.9601068870174578, 0.9697683621733731, 0.9524128138759191], 
             UndirectedEdge[161, 477] -> 
             RGBColor[
              0.9473780190841047, 0.9592483669135612, 0.9350443634219218], 
             UndirectedEdge[391, 475] -> 
             RGBColor[
              0.9682517373816507, 0.9516807689033099, 0.6592553407270343], 
             UndirectedEdge[2, 312] -> 
             RGBColor[
              0.9063479542628992, 0.9121129277150637, 0.688147861422022], 
             UndirectedEdge[264, 341] -> 
             RGBColor[
              0.9181139081236446, 0.9364308283424616, 0.9534876923626326], 
             UndirectedEdge[73, 434] -> 
             RGBColor[
              0.9751297360754934, 0.9809723784031983, 0.9269830490072184], 
             UndirectedEdge[241, 271] -> 
             RGBColor[
              0.7884408837993161, 0.8020090169946836, 0.6514277740698605], 
             UndirectedEdge[49, 51] -> 
             RGBColor[
              0.7864478358555564, 0.8335957506356655, 0.9792174187923319], 
             UndirectedEdge[5, 275] -> 
             RGBColor[
              0.9873381342821212, 0.9890320073776202, 0.8595034130107231], 
             UndirectedEdge[18, 274] -> 
             RGBColor[
              0.9345623717008268, 0.950178500924963, 0.976972357895854], 
             UndirectedEdge[219, 445] -> 
             RGBColor[
              0.6640183332000261, 0.727081894766253, 0.8013650287278702], 
             UndirectedEdge[177, 297] -> 
             RGBColor[
              0.8755424666497467, 0.9015909377583926, 0.8907665466724467], 
             UndirectedEdge[250, 365] -> 
             RGBColor[
              0.9609830082068656, 0.9687215435068754, 0.8766316267494183], 
             UndirectedEdge[325, 474] -> 
             RGBColor[
              0.8288466935232509, 0.8656913556949236, 0.9123898288308836], 
             UndirectedEdge[266, 403] -> 
             RGBColor[
              0.8376995907903884, 0.8736335529273138, 0.9843258363392134], 
             UndirectedEdge[214, 470] -> 
             RGBColor[
              0.994204343002696, 0.9918713611370933, 0.7457125653322361], 
             UndirectedEdge[152, 481] -> 
             RGBColor[
              0.9811581963986814, 0.9570472603365734, 0.6008122247868328], 
             UndirectedEdge[289, 466] -> 
             RGBColor[
              0.9654183602836636, 0.9704002002844322, 0.7429261799354665], 
             UndirectedEdge[126, 269] -> 
             RGBColor[
              0.9788305680237941, 0.9408351758203268, 0.5339827268545676], 
             UndirectedEdge[183, 396] -> 
             RGBColor[
              0.5877277143668338, 0.6720614063627557, 0.962749926889388], 
             UndirectedEdge[54, 99] -> 
             RGBColor[
              0.9147758151897731, 0.9336244493882941, 0.9480967235573914], 
             UndirectedEdge[129, 306] -> 
             RGBColor[
              0.6683550293687159, 0.7331492713398233, 0.905837527119973], 
             UndirectedEdge[172, 236] -> 
             RGBColor[
              0.9460261952834896, 0.8371844534111328, 0.5837033809532868], 
             UndirectedEdge[162, 284] -> 
             RGBColor[
              0.7042089589049033, 0.7666211973239441, 0.9574446788840139], 
             UndirectedEdge[10, 189] -> 
             RGBColor[
              0.9808071583963314, 0.9846941429058431, 0.8944241958698453], 
             UndirectedEdge[213, 332] -> 
             RGBColor[
              0.8890518472381297, 0.914101398501979, 0.9799731825768927], 
             UndirectedEdge[199, 245] -> 
             RGBColor[
              0.8848702270692432, 0.9098784369007361, 0.9370668783015572], 
             UndirectedEdge[123, 139] -> 
             RGBColor[
              0.991498137085153, 0.9883883905409109, 0.6187319228149053], 
             UndirectedEdge[391, 482] -> 
             RGBColor[
              0.9290320819302808, 0.9456347896321304, 0.971798720457249], 
             UndirectedEdge[184, 354] -> 
             RGBColor[
              0.7921424812194167, 0.8365902819104402, 0.9205162940167675], 
             UndirectedEdge[25, 316] -> 
             RGBColor[
              0.8703371456050457, 0.8990527507791088, 0.9613533037692525], 
             UndirectedEdge[106, 479] -> 
             RGBColor[
              0.9531427916767954, 0.9645745512709667, 0.9642012107606988], 
             UndirectedEdge[118, 260] -> 
             RGBColor[
              0.9265752748953763, 0.9416383627406575, 0.8886614083455898], 
             UndirectedEdge[304, 469] -> 
             RGBColor[
              0.9603852114394993, 0.87534333959794, 0.5327125439239861], 
             UndirectedEdge[93, 236] -> 
             RGBColor[
              0.9835858659633298, 0.9867456989258849, 0.8887891231464607], 
             UndirectedEdge[343, 445] -> 
             RGBColor[
              0.6335715037775965, 0.7065998615914462, 0.9680040694381391], 
             UndirectedEdge[204, 444] -> 
             RGBColor[
              0.9468844637821392, 0.9598460371310445, 0.9726778195458685], 
             UndirectedEdge[150, 412] -> 
             RGBColor[
              0.9358852511447145, 0.8839043530375764, 0.6341563380865534], 
             UndirectedEdge[14, 239] -> 
             RGBColor[
              0.8746573053626463, 0.897853508332497, 0.7004387612232763], 
             UndirectedEdge[70, 442] -> 
             RGBColor[
              0.9719877301620239, 0.9771355722977849, 0.8654195189721412], 
             UndirectedEdge[93, 493] -> 
             RGBColor[
              0.980339432715567, 0.9552890237950508, 0.6045686435859925], 
             UndirectedEdge[228, 279] -> 
             RGBColor[
              0.9032567546594175, 0.7001472559735411, 0.5861458315786414], 
             UndirectedEdge[300, 456] -> 
             RGBColor[
              0.6896182105281065, 0.7571433932507858, 0.9699108939412178], 
             UndirectedEdge[168, 326] -> 
             RGBColor[
              0.9481642798960119, 0.9595596149396006, 0.9214107906967965], 
             UndirectedEdge[193, 437] -> 
             RGBColor[
              0.7645086014105189, 0.8131040826025275, 0.8743727084748335], 
             UndirectedEdge[224, 361] -> 
             RGBColor[
              0.5592500893700012, 0.6450814320591092, 0.9615186764793942], 
             UndirectedEdge[12, 477] -> 
             RGBColor[
              0.9248723750417207, 0.9427914811759852, 0.9878195082815501], 
             UndirectedEdge[212, 224] -> 
             RGBColor[
              0.552007522422317, 0.6394163487808395, 0.960798698483575], 
             UndirectedEdge[220, 490] -> 
             RGBColor[
              0.8309916228599363, 0.8662265375556051, 0.8608906231667734], 
             UndirectedEdge[175, 208] -> 
             RGBColor[
              0.7638784601325496, 0.8150401918432941, 0.9615146037587985], 
             UndirectedEdge[242, 419] -> 
             RGBColor[
              0.9370558552498649, 0.9474944621681115, 0.71431127908653], 
             UndirectedEdge[164, 205] -> 
             RGBColor[
              0.8166769762367483, 0.8566053510624889, 0.9302700123607353], 
             UndirectedEdge[257, 322] -> 
             RGBColor[
              0.8986903116587317, 0.5593887859165176, 0.5414263251743828], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.95417629463253, 0.9650413221984251, 0.9518547764598648], 
             UndirectedEdge[26, 67] -> 
             RGBColor[
              0.8089353366395106, 0.8496720595530309, 0.8987868158402335], 
             UndirectedEdge[366, 488] -> 
             RGBColor[
              0.6045700040581997, 0.6875326863024538, 0.9634492334040943], 
             UndirectedEdge[12, 243] -> 
             RGBColor[
              0.9674857280404565, 0.973672303655743, 0.8683075411531127], 
             UndirectedEdge[271, 307] -> 
             RGBColor[
              0.9820722898542738, 0.9506131533479609, 0.4337155246699344], 
             UndirectedEdge[9, 352] -> 
             RGBColor[
              0.9900633450335594, 0.9878068544276677, 0.6433669505152794], 
             UndirectedEdge[404, 431] -> 
             RGBColor[
              0.9073635595602594, 0.5780131110155702, 0.3183110871542736], 
             UndirectedEdge[256, 287] -> 
             RGBColor[
              0.9919428994765953, 0.9902713117992944, 0.7348604655591745], 
             UndirectedEdge[254, 412] -> 
             RGBColor[
              0.9583451372611722, 0.9670476475781994, 0.8950291274527038], 
             UndirectedEdge[42, 380] -> 
             RGBColor[
              0.953592613913299, 0.8404589980197057, 0.4883250436010148], 
             UndirectedEdge[379, 404] -> 
             RGBColor[
              0.8814687495696389, 0.5622056656814962, 0.5765581016811496], 
             UndirectedEdge[134, 424] -> 
             RGBColor[
              0.9929165178672046, 0.9891437804183001, 0.6074995112599086], 
             UndirectedEdge[38, 253] -> 
             RGBColor[
              0.6503738092968374, 0.7179167757650288, 0.9172596285093968], 
             UndirectedEdge[103, 348] -> 
             RGBColor[
              0.9898535729281661, 0.9761349321524876, 0.5257050215555166], 
             UndirectedEdge[42, 452] -> 
             RGBColor[
              0.9376799958938162, 0.9497747553736184, 0.8585334086377197], 
             UndirectedEdge[164, 331] -> 
             RGBColor[
              0.8212795505134478, 0.8577502916520451, 0.7988699763410978], 
             UndirectedEdge[6, 181] -> 
             RGBColor[
              0.9907293312744869, 0.9889071981516855, 0.6922943588513981], 
             UndirectedEdge[172, 197] -> 
             RGBColor[
              0.6723876927400358, 0.6194806293313867, 0.5985287898093827], 
             UndirectedEdge[80, 258] -> 
             RGBColor[
              0.901199370943241, 0.920212149103298, 0.8090691892433335], 
             UndirectedEdge[223, 268] -> 
             RGBColor[
              0.9339433625580742, 0.9450668876889956, 0.7184114963831971], 
             UndirectedEdge[5, 69] -> 
             RGBColor[
              0.9890577622141354, 0.9897431177199302, 0.8310047279228175], 
             UndirectedEdge[306, 486] -> 
             RGBColor[
              0.9769083661606175, 0.981862962108151, 0.904451096527012], 
             UndirectedEdge[5, 348] -> 
             RGBColor[
              0.9847118942678992, 0.974587665046583, 0.6529994350812174], 
             UndirectedEdge[279, 409] -> 
             RGBColor[
              0.8349581914636997, 0.8716838522196331, 0.9714645152128033], 
             UndirectedEdge[463, 483] -> 
             RGBColor[
              0.9383478127571243, 0.9505515644906412, 0.8692058926733433], 
             UndirectedEdge[351, 371] -> 
             RGBColor[
              0.6395719327006197, 0.7130802708658188, 0.9677957119478091], 
             UndirectedEdge[335, 421] -> 
             RGBColor[
              0.9158844102714606, 0.9351187019349565, 0.9694181934805579], 
             UndirectedEdge[259, 418] -> 
             RGBColor[
              0.8553732511794956, 0.8871270510100984, 0.9479261046548805], 
             UndirectedEdge[168, 302] -> 
             RGBColor[
              0.9902316179074042, 0.9879608255395967, 0.646712201564799], 
             UndirectedEdge[87, 336] -> 
             RGBColor[
              0.9882629314572373, 0.9894144347757341, 0.8441771305206809], 
             UndirectedEdge[36, 266] -> 
             RGBColor[
              0.8853592737664034, 0.9105763863439433, 0.9521310530388547], 
             UndirectedEdge[161, 430] -> 
             RGBColor[
              0.9850767936132676, 0.9730993884864766, 0.6356222140889896], 
             UndirectedEdge[220, 412] -> 
             RGBColor[
              0.7969449303297396, 0.8421523447890598, 0.9801691507417236], 
             UndirectedEdge[372, 404] -> 
             RGBColor[
              0.9082337855510138, 0.5798744364164495, 0.4130298158355973], 
             UndirectedEdge[38, 287] -> 
             RGBColor[
              0.6549769778662253, 0.7191554199411984, 0.792643141267459], 
             UndirectedEdge[171, 497] -> 
             RGBColor[
              0.9720970335995927, 0.9782692389133121, 0.9123518468882543], 
             UndirectedEdge[246, 411] -> 
             RGBColor[
              0.9610076318417665, 0.9687119240796294, 0.8753636810935516], 
             UndirectedEdge[75, 303] -> 
             RGBColor[
              0.9711906641250392, 0.9108381868334297, 0.46106859163444913`], 
             UndirectedEdge[23, 39] -> 
             RGBColor[
              0.9657547320427822, 0.9518040062879349, 0.6676969599169256], 
             UndirectedEdge[61, 391] -> 
             RGBColor[
              0.9729236885133792, 0.9674403570969223, 0.6774049886498585], 
             UndirectedEdge[19, 200] -> 
             RGBColor[
              0.6836436112313462, 0.7468934760578755, 0.9252629644732528], 
             UndirectedEdge[208, 403] -> 
             RGBColor[
              0.9175416595681305, 0.9366249653471419, 0.9759840128163975], 
             UndirectedEdge[108, 378] -> 
             RGBColor[
              0.9896088145603359, 0.9881135627645409, 0.6868568651454049], 
             UndirectedEdge[10, 451] -> 
             RGBColor[
              0.8815593434864235, 0.9069097998160676, 0.9194085919169626], 
             UndirectedEdge[199, 262] -> 
             RGBColor[
              0.9720713305406176, 0.9785243239195479, 0.9246770235989001], 
             UndirectedEdge[3, 401] -> 
             RGBColor[
              0.9796534793268437, 0.9424843009449229, 0.4217370122302185], 
             UndirectedEdge[241, 311] -> 
             RGBColor[
              0.8004256618812964, 0.8410928578219994, 0.8122389536655948], 
             UndirectedEdge[179, 255] -> 
             RGBColor[
              0.5968958863746974, 0.6169036015841638, 0.6129331519865905], 
             UndirectedEdge[276, 462] -> 
             RGBColor[
              0.5982982481360999, 0.6666074607134094, 0.9375763672620213], 
             UndirectedEdge[167, 289] -> 
             RGBColor[
              0.9087390775346227, 0.9252570088769918, 0.7392997074731809], 
             UndirectedEdge[164, 348] -> 
             RGBColor[
              0.8166261971015996, 0.8432260279912742, 0.6810839825858817], 
             UndirectedEdge[18, 172] -> 
             RGBColor[
              0.9135435843830263, 0.8124201718363895, 0.6200073110515105], 
             UndirectedEdge[289, 300] -> 
             RGBColor[
              0.807606653056254, 0.8459055941935485, 0.7294416337442451], 
             UndirectedEdge[59, 188] -> 
             RGBColor[
              0.9634308191464701, 0.9713113724100857, 0.9048714849157604], 
             UndirectedEdge[352, 357] -> 
             RGBColor[
              0.9931762247014557, 0.9878129595629555, 0.49865235409220354`], 
             UndirectedEdge[161, 409] -> 
             RGBColor[
              0.853233084794474, 0.8849854510037092, 0.9258509277514215], 
             UndirectedEdge[39, 157] -> 
             RGBColor[
              0.8875459640147294, 0.8900779478414704, 0.6756653603852185], 
             UndirectedEdge[216, 398] -> 
             RGBColor[
              0.9504463882536148, 0.962563578012914, 0.9687655184214993], 
             UndirectedEdge[279, 396] -> 
             RGBColor[
              0.8700095682933414, 0.8990662541992798, 0.9749581088814421], 
             UndirectedEdge[103, 390] -> 
             RGBColor[
              0.981577159860175, 0.9482166474799518, 0.4935527196558337], 
             UndirectedEdge[128, 296] -> 
             RGBColor[
              0.9301724277956378, 0.745582513231535, 0.5078865184370881], 
             UndirectedEdge[362, 369] -> 
             RGBColor[
              0.8609365733500693, 0.8919514703613549, 0.9865980930049234], 
             UndirectedEdge[86, 412] -> 
             RGBColor[
              0.9590769131567847, 0.964998158086424, 0.7119290393623279], 
             UndirectedEdge[261, 299] -> 
             RGBColor[
              0.990189440902759, 0.9887896385212427, 0.708924934649722], 
             UndirectedEdge[208, 266] -> 
             RGBColor[
              0.8737675002979165, 0.9019312606709327, 0.9717529019022828], 
             UndirectedEdge[211, 236] -> 
             RGBColor[
              0.9852797298963365, 0.9874461551925007, 0.8607174141972004], 
             UndirectedEdge[19, 124] -> 
             RGBColor[
              0.5556995875821844, 0.6469404764867135, 0.9596001200897273], 
             UndirectedEdge[319, 330] -> 
             RGBColor[
              0.8338291389177515, 0.8709687018160612, 0.9797991177091386], 
             UndirectedEdge[137, 267] -> 
             RGBColor[
              0.9411615609577824, 0.8514145532633068, 0.605793192760514], 
             UndirectedEdge[23, 240] -> 
             RGBColor[
              0.9715393120663826, 0.9713167529915183, 0.690168960982336], 
             UndirectedEdge[135, 369] -> 
             RGBColor[
              0.9243721223729422, 0.9396498553449837, 0.8783868694375854], 
             UndirectedEdge[13, 335] -> 
             RGBColor[
              0.9617753750627467, 0.9281792303147893, 0.630582118336416], 
             UndirectedEdge[176, 178] -> 
             RGBColor[
              0.9935421741685164, 0.9894854352672504, 0.6031588947311015], 
             UndirectedEdge[335, 459] -> 
             RGBColor[
              0.9672385255320284, 0.9466077196564073, 0.6518054262801762], 
             UndirectedEdge[83, 326] -> 
             RGBColor[
              0.8335594973555217, 0.8706178744229007, 0.983855182403079], 
             UndirectedEdge[33, 76] -> 
             RGBColor[
              0.9643905964007329, 0.9729631456174892, 0.9451616112603765], 
             UndirectedEdge[13, 285] -> 
             RGBColor[
              0.963308980460656, 0.9293229907095018, 0.6279861244261034], 
             UndirectedEdge[225, 309] -> 
             RGBColor[
              0.9191422110837213, 0.9334256168879871, 0.7300319313912755], 
             UndirectedEdge[242, 499] -> 
             RGBColor[
              0.8647539972614213, 0.8949953805670554, 0.9869622023054427], 
             UndirectedEdge[13, 287] -> 
             RGBColor[
              0.9786427218404594, 0.938379577216601, 0.4769253183465447], 
             UndirectedEdge[265, 270] -> 
             RGBColor[
              0.5028203131062146, 0.5977600951526664, 0.9564076652379547], 
             UndirectedEdge[191, 311] -> 
             RGBColor[
              0.9766763331605528, 0.9798641150388425, 0.8085897337313841], 
             UndirectedEdge[47, 452] -> 
             RGBColor[
              0.8960386443547766, 0.919940908960174, 0.9899461598733412], 
             UndirectedEdge[14, 80] -> 
             RGBColor[
              0.7825012595514622, 0.8300151982822237, 0.9789560707282144], 
             UndirectedEdge[152, 292] -> 
             RGBColor[
              0.89951148090699, 0.8939410667848677, 0.6687820612519002], 
             UndirectedEdge[133, 311] -> 
             RGBColor[
              0.9938330663969657, 0.9911985684752908, 0.7141208413761975], 
             UndirectedEdge[187, 398] -> 
             RGBColor[
              0.9671259793499636, 0.974478055720569, 0.917014747027024], 
             UndirectedEdge[130, 442] -> 
             RGBColor[
              0.949658864599646, 0.9597203952520723, 0.8767854611427863], 
             UndirectedEdge[304, 433] -> 
             RGBColor[
              0.9608346019834091, 0.8755291741366569, 0.5252649796259528], 
             UndirectedEdge[354, 409] -> 
             RGBColor[
              0.8532156105342049, 0.8849782249480198, 0.9261405214660172], 
             UndirectedEdge[29, 412] -> 
             RGBColor[
              0.8734734612659124, 0.9019480444806913, 0.9877938725661486], 
             UndirectedEdge[295, 391] -> 
             RGBColor[
              0.8957845020407824, 0.9191240719097586, 0.9686275366069237], 
             UndirectedEdge[21, 298] -> 
             RGBColor[
              0.9749790393434508, 0.9806795235673778, 0.9191565272638894], 
             UndirectedEdge[383, 395] -> 
             RGBColor[
              0.6598100434641863, 0.7320000160026818, 0.9682095427020521], 
             UndirectedEdge[133, 241] -> 
             RGBColor[
              0.7995786389237667, 0.8412618523055231, 0.8640210542430549], 
             UndirectedEdge[142, 473] -> 
             RGBColor[
              0.9939177995917889, 0.9906304408101836, 0.6688727181500018], 
             UndirectedEdge[95, 330] -> 
             RGBColor[
              0.9658242216218873, 0.9728250809186081, 0.8886712864763375], 
             UndirectedEdge[275, 431] -> 
             RGBColor[
              0.9916220466931072, 0.9887445992097837, 0.6388464367704543], 
             UndirectedEdge[180, 474] -> 
             RGBColor[
              0.9703861044935835, 0.9768869649097509, 0.9104892004661337], 
             UndirectedEdge[82, 173] -> 
             RGBColor[
              0.4337825657242024, 0.5501423887097803, 0.9488612194024524], 
             UndirectedEdge[205, 230] -> 
             RGBColor[
              0.9708578382197568, 0.9265668199144178, 0.590277396253212], 
             UndirectedEdge[460, 463] -> 
             RGBColor[
              0.9941028675486421, 0.9909340042038932, 0.6823085683096338], 
             UndirectedEdge[121, 500] -> 
             RGBColor[
              0.51914038497869, 0.6103762164758437, 0.958055391782668], 
             UndirectedEdge[88, 241] -> 
             RGBColor[
              0.7933860339100927, 0.8186901694947957, 0.670638748436988], 
             UndirectedEdge[60, 73] -> 
             RGBColor[
              0.8333751832693177, 0.8699909475513931, 0.9482116057457282], 
             UndirectedEdge[75, 400] -> 
             RGBColor[
              0.9578612486502911, 0.8579914962404493, 0.45034343106187275`], 
             UndirectedEdge[141, 274] -> 
             RGBColor[
              0.9737411996419535, 0.9766179983515371, 0.7296818716665978], 
             UndirectedEdge[299, 448] -> 
             RGBColor[
              0.9923491499227706, 0.9896827337030076, 0.6731329670403504], 
             UndirectedEdge[160, 389] -> 
             RGBColor[
              0.9943820531595315, 0.9903921047068212, 0.629899340243121], 
             UndirectedEdge[24, 268] -> 
             RGBColor[
              0.9887786453206822, 0.9874164812550981, 0.6748984689640226], 
             UndirectedEdge[386, 498] -> 
             RGBColor[
              0.9748869800628135, 0.9269500283136908, 0.3569410890502581], 
             UndirectedEdge[350, 476] -> 
             RGBColor[
              0.9695717721476063, 0.9469814952013386, 0.6449553332538029], 
             UndirectedEdge[180, 331] -> 
             RGBColor[
              0.9738434741698025, 0.9775583339665925, 0.7980681683709621], 
             UndirectedEdge[225, 252] -> 
             RGBColor[
              0.9939878983780197, 0.9897774063087056, 0.6035973005708095], 
             UndirectedEdge[100, 203] -> 
             RGBColor[
              0.9731239783508208, 0.9759726222499071, 0.7160434647142674], 
             UndirectedEdge[445, 471] -> 
             RGBColor[
              0.6629795539979457, 0.727188016084199, 0.8575188030364688], 
             UndirectedEdge[373, 498] -> 
             RGBColor[
              0.9677148196118597, 0.900911037916499, 0.33869056357189575`], 
             UndirectedEdge[102, 309] -> 
             RGBColor[
              0.9196634933607662, 0.9345405869688632, 0.7867702902663104], 
             UndirectedEdge[46, 86] -> 
             RGBColor[
              0.9738076585443516, 0.9230097180826233, 0.3568953767753456], 
             UndirectedEdge[294, 385] -> 
             RGBColor[
              0.9012181040735523, 0.9240708695472369, 0.9904401813650763], 
             UndirectedEdge[27, 29] -> 
             RGBColor[
              0.8928399040788987, 0.9166519749025825, 0.9640421630308306], 
             UndirectedEdge[274, 284] -> 
             RGBColor[
              0.9536105357763247, 0.964923394054535, 0.963409442007395], 
             UndirectedEdge[284, 300] -> 
             RGBColor[
              0.7874836254673507, 0.8342273231203159, 0.9640003656809644], 
             UndirectedEdge[159, 453] -> 
             RGBColor[
              0.9562167886996196, 0.930734581025885, 0.6542161726335498], 
             UndirectedEdge[229, 232] -> 
             RGBColor[
              0.9891611584435547, 0.9897858747179569, 0.8292911848204761], 
             UndirectedEdge[259, 431] -> 
             RGBColor[
              0.985522781725588, 0.9852186332739177, 0.6949764780011888], 
             UndirectedEdge[112, 483] -> 
             RGBColor[
              0.8222622380407154, 0.8615839615740284, 0.9827844822513103], 
             UndirectedEdge[78, 376] -> 
             RGBColor[
              0.966728765531004, 0.973694638686343, 0.8958704068614272], 
             UndirectedEdge[76, 351] -> 
             RGBColor[
              0.9300062099600581, 0.9463073136037732, 0.9682782858902391], 
             UndirectedEdge[178, 498] -> 
             RGBColor[
              0.989979213142326, 0.9776708382386796, 0.5719616664058738], 
             UndirectedEdge[400, 431] -> 
             RGBColor[
              0.9570474653460616, 0.8562508960388154, 0.3617681404848832], 
             UndirectedEdge[18, 432] -> 
             RGBColor[
              0.9263075219830759, 0.8630249310905214, 0.6302774748526329], 
             UndirectedEdge[220, 325] -> 
             RGBColor[
              0.6692483639909401, 0.7415411755164578, 0.9676680805072236], 
             UndirectedEdge[353, 380] -> 
             RGBColor[
              0.9532193063828613, 0.8403046257623037, 0.4945117154692861], 
             UndirectedEdge[5, 355] -> 
             RGBColor[
              0.8378463878606799, 0.8733030460863215, 0.9396345969403931], 
             UndirectedEdge[367, 441] -> 
             RGBColor[
              0.992510450092619, 0.9906114678752774, 0.7331204616930396], 
             UndirectedEdge[21, 287] -> 
             RGBColor[
              0.9898947677870336, 0.989424356711077, 0.7688033080501175], 
             UndirectedEdge[175, 182] -> 
             RGBColor[
              0.6753241959902183, 0.7452427461895117, 0.9689880770677668], 
             UndirectedEdge[70, 371] -> 
             RGBColor[
              0.6667417035477267, 0.7343554543827009, 0.9568914996447486], 
             UndirectedEdge[217, 496] -> 
             RGBColor[
              0.7706597245896962, 0.8213955391614799, 0.9776148234123905], 
             UndirectedEdge[195, 292] -> 
             RGBColor[
              0.9094907818183324, 0.9265592870705517, 0.7963499149417756], 
             UndirectedEdge[161, 285] -> 
             RGBColor[
              0.9750044010686386, 0.9805511170206793, 0.912516248573297], 
             UndirectedEdge[168, 370] -> 
             RGBColor[
              0.9911269649895014, 0.9898758824147265, 0.744165206009384], 
             UndirectedEdge[50, 173] -> 
             RGBColor[
              0.5966056537461728, 0.6808222854346512, 0.9628622157868864], 
             UndirectedEdge[19, 188] -> 
             RGBColor[
              0.6598627227315186, 0.7292251217532701, 0.9685358198410503], 
             UndirectedEdge[147, 323] -> 
             RGBColor[
              0.9429354980067659, 0.9530836938330507, 0.7879071570323752], 
             UndirectedEdge[255, 260] -> 
             RGBColor[
              0.9744573589363206, 0.9293937109272974, 0.5398749707825896], 
             UndirectedEdge[29, 350] -> 
             RGBColor[
              0.8970045034267161, 0.8899121634725069, 0.6655566837022704], 
             UndirectedEdge[348, 400] -> 
             RGBColor[
              0.9531479047353828, 0.843338918959603, 0.3260278412670314], 
             UndirectedEdge[26, 124] -> 
             RGBColor[
              0.8588041907718477, 0.8888350607836396, 0.9036170673894812], 
             UndirectedEdge[18, 93] -> 
             RGBColor[
              0.9511032550628664, 0.9619814173511415, 0.9250930532446844], 
             UndirectedEdge[64, 223] -> 
             RGBColor[
              0.9130541039910411, 0.9331155431710159, 0.977942463171481], 
             UndirectedEdge[12, 335] -> 
             RGBColor[
              0.9509651516283453, 0.9629504708883909, 0.967887387343238], 
             UndirectedEdge[143, 498] -> 
             RGBColor[
              0.9873842089822924, 0.9691061159479855, 0.4054904634987788], 
             UndirectedEdge[44, 92] -> 
             RGBColor[
              0.9599226239301575, 0.9012475318063546, 0.6018428930946169], 
             UndirectedEdge[274, 389] -> 
             RGBColor[
              0.9742179643832719, 0.9776377499249076, 0.7815747715081849], 
             UndirectedEdge[247, 401] -> 
             RGBColor[
              0.7860466723044891, 0.7939327794350399, 0.6421267145213607], 
             UndirectedEdge[111, 182] -> 
             RGBColor[
              0.8792608931636887, 0.905719731879666, 0.946838196225225], 
             UndirectedEdge[157, 190] -> 
             RGBColor[
              0.8919520008541697, 0.9049405446875494, 0.6927819814962032], 
             UndirectedEdge[100, 360] -> 
             RGBColor[
              0.9497539218397127, 0.9620471376952355, 0.9699376834360698], 
             UndirectedEdge[59, 468] -> 
             RGBColor[
              0.8828339747771322, 0.9074368926113057, 0.8982846527898789], 
             UndirectedEdge[101, 129] -> 
             RGBColor[
              0.6591588093712838, 0.72672666122346, 0.9409255245044279], 
             UndirectedEdge[180, 382] -> 
             RGBColor[
              0.951878461347084, 0.9636316157812188, 0.966341392218738], 
             UndirectedEdge[145, 402] -> 
             RGBColor[
              0.9696340191441339, 0.9753223088296088, 0.8668122168468522], 
             UndirectedEdge[90, 263] -> 
             RGBColor[
              0.9938745454765681, 0.9917349813846295, 0.751178163828814], 
             UndirectedEdge[98, 276] -> 
             RGBColor[
              0.5925094230675021, 0.6112839082779337, 0.611019716505306], 
             UndirectedEdge[224, 464] -> 
             RGBColor[
              0.49442819255504467`, 0.5944349386694112, 0.9550597289918357], 
             UndirectedEdge[261, 313] -> 
             RGBColor[
              0.8912668722110167, 0.9145911818033867, 0.9248102149043478], 
             UndirectedEdge[78, 219] -> 
             RGBColor[
              0.9924731494761198, 0.9906197849107956, 0.7354644075971108], 
             UndirectedEdge[393, 424] -> 
             RGBColor[
              0.9902452550465868, 0.9880391445936516, 0.6517692492041233], 
             UndirectedEdge[169, 211] -> 
             RGBColor[
              0.9925031280834339, 0.990248958210364, 0.7071112724706133], 
             UndirectedEdge[176, 482] -> 
             RGBColor[
              0.9456906292206649, 0.9545109019374541, 0.7257789119922586], 
             UndirectedEdge[35, 94] -> 
             RGBColor[
              0.8303734596100321, 0.8682645667099772, 0.9792252703514862], 
             UndirectedEdge[114, 296] -> 
             RGBColor[
              0.9834646412450392, 0.9860981939601552, 0.864046438210732], 
             UndirectedEdge[130, 175] -> 
             RGBColor[
              0.7401417279443037, 0.7965750301731793, 0.9752636968966142], 
             UndirectedEdge[189, 383] -> 
             RGBColor[
              0.8965583373859993, 0.9193686501232865, 0.9554477236089938], 
             UndirectedEdge[139, 437] -> 
             RGBColor[
              0.7650739832998406, 0.8109739976404553, 0.6931733893999128], 
             UndirectedEdge[56, 324] -> 
             RGBColor[
              0.9665346498867616, 0.9745621771968042, 0.9415322879672382], 
             UndirectedEdge[398, 399] -> 
             RGBColor[
              0.9700925954263693, 0.9739829865090366, 0.7426905628929563], 
             UndirectedEdge[405, 429] -> 
             RGBColor[
              0.9768431126826116, 0.9616587073662966, 0.6522918893506936], 
             UndirectedEdge[12, 318] -> 
             RGBColor[
              0.8206912292784327, 0.8606882005848797, 0.9776257568450843], 
             UndirectedEdge[11, 205] -> 
             RGBColor[
              0.92293803927994, 0.939946217794721, 0.9407738376881232], 
             UndirectedEdge[226, 389] -> 
             RGBColor[
              0.9911205917128046, 0.9807143213081054, 0.5046549682720375], 
             UndirectedEdge[294, 327] -> 
             RGBColor[
              0.9468061375653062, 0.9580261799688798, 0.9017194559797452], 
             UndirectedEdge[167, 218] -> 
             RGBColor[
              0.9066957915130307, 0.9187621026945829, 0.697554818653458], 
             UndirectedEdge[217, 481] -> 
             RGBColor[
              0.9440245394784685, 0.9562068780490651, 0.9187657243122049], 
             UndirectedEdge[247, 309] -> 
             RGBColor[
              0.7257485766158226, 0.7853300499170337, 0.97362415068642], 
             UndirectedEdge[79, 234] -> 
             RGBColor[
              0.9077012225972616, 0.6471703143142, 0.25303454161734407`], 
             UndirectedEdge[331, 372] -> 
             RGBColor[
              0.9945193860814876, 0.9906858459403968, 0.6448471812774883], 
             UndirectedEdge[27, 484] -> 
             RGBColor[
              0.9797556820680868, 0.9825968667056049, 0.8374013579116086], 
             UndirectedEdge[103, 326] -> 
             RGBColor[
              0.9515647807599554, 0.960386860280497, 0.8229721992798699], 
             UndirectedEdge[155, 394] -> 
             RGBColor[
              0.9939909612217342, 0.989555598597333, 0.5873313963535461], 
             UndirectedEdge[433, 469] -> 
             RGBColor[
              0.991204332308617, 0.9906307796183335, 0.7954305063119282], 
             UndirectedEdge[65, 412] -> 
             RGBColor[
              0.9523528889932824, 0.9423488594479856, 0.6830512446453141], 
             UndirectedEdge[13, 161] -> 
             RGBColor[
              0.974469577927937, 0.9373187592871748, 0.5944151841560839], 
             UndirectedEdge[229, 480] -> 
             RGBColor[
              0.9619796797327622, 0.8760026932131701, 0.5062880779529505], 
             UndirectedEdge[32, 448] -> 
             RGBColor[
              0.9888375384463994, 0.9896520495324787, 0.8346544056750442], 
             UndirectedEdge[251, 453] -> 
             RGBColor[
              0.9812213826742819, 0.9470430854201686, 0.489912297915589], 
             UndirectedEdge[282, 310] -> 
             RGBColor[
              0.9943961405353661, 0.9904222361792787, 0.6314326641654908], 
             UndirectedEdge[392, 473] -> 
             RGBColor[
              0.9299049434850776, 0.9426933245112723, 0.7866514141193839], 
             UndirectedEdge[222, 344] -> 
             RGBColor[
              0.9669911140270776, 0.9731298863848699, 0.8613735440681869], 
             UndirectedEdge[266, 440] -> 
             RGBColor[
              0.6720064219644322, 0.7422823083284142, 0.9689093840239742], 
             UndirectedEdge[16, 361] -> 
             RGBColor[
              0.8943172204656153, 0.9177413290181071, 0.96111063358412], 
             UndirectedEdge[412, 426] -> 
             RGBColor[
              0.8119781271761164, 0.8538963924219772, 0.9816675193101585], 
             UndirectedEdge[274, 460] -> 
             RGBColor[
              0.9742820083406367, 0.9777747334738736, 0.788545561033848], 
             UndirectedEdge[180, 230] -> 
             RGBColor[
              0.9549009337743561, 0.9148332873494904, 0.6247713814710076], 
             UndirectedEdge[375, 450] -> 
             RGBColor[
              0.7916912002578167, 0.8330133970479152, 0.730539681078134], 
             UndirectedEdge[6, 123] -> 
             RGBColor[
              0.9892006565515953, 0.9898022082006868, 0.8286365989524169], 
             UndirectedEdge[170, 466] -> 
             RGBColor[
              0.9416343305942843, 0.9559915598390053, 0.9836820334860203], 
             UndirectedEdge[267, 280] -> 
             RGBColor[
              0.9120918572496032, 0.9321418585308778, 0.9706941383786486], 
             UndirectedEdge[52, 214] -> 
             RGBColor[
              0.9896947350739465, 0.9900065223669179, 0.8204484392028291], 
             UndirectedEdge[358, 386] -> 
             RGBColor[
              0.9747503820980545, 0.9393468646651215, 0.6029771058287803], 
             UndirectedEdge[230, 413] -> 
             RGBColor[
              0.8559899049979851, 0.8369392942922902, 0.6309208085879708], 
             UndirectedEdge[53, 207] -> 
             RGBColor[
              0.922349231365462, 0.937514484492971, 0.8545004961153636], 
             UndirectedEdge[188, 256] -> 
             RGBColor[
              0.9632051933918664, 0.9712180703622395, 0.9086106875702806], 
             UndirectedEdge[38, 87] -> 
             RGBColor[
              0.6504236000959209, 0.717937365540015, 0.9164344661141236], 
             UndirectedEdge[22, 52] -> 
             RGBColor[
              0.8477297105102306, 0.8808873092541196, 0.9344227661925186], 
             UndirectedEdge[160, 460] -> 
             RGBColor[
              0.9944460971168962, 0.9905290882557869, 0.6368701297687841], 
             UndirectedEdge[63, 159] -> 
             RGBColor[
              0.7864901270112492, 0.8336962522806088, 0.9713113338345105], 
             UndirectedEdge[285, 430] -> 
             RGBColor[
              0.9739161961459868, 0.9651036199088036, 0.669193154359009], 
             UndirectedEdge[132, 356] -> 
             RGBColor[
              0.9553833165191615, 0.9625471073460015, 0.7516319492953489], 
             UndirectedEdge[99, 373] -> 
             RGBColor[
              0.8975238821991847, 0.8589374303137132, 0.6317561777455831], 
             UndirectedEdge[243, 396] -> 
             RGBColor[
              0.8921108351710368, 0.9139501567783226, 0.8659316094102671], 
             UndirectedEdge[118, 292] -> 
             RGBColor[
              0.8432222933398261, 0.8778265843225085, 0.984908489163822], 
             UndirectedEdge[84, 176] -> 
             RGBColor[
              0.9752454137020871, 0.9279550020073795, 0.3756893336015333], 
             UndirectedEdge[334, 385] -> 
             RGBColor[
              0.8987401940711371, 0.9220950513723863, 0.9902038360969896], 
             UndirectedEdge[25, 325] -> 
             RGBColor[
              0.817518639632149, 0.8577905324775685, 0.9560888487108758], 
             UndirectedEdge[321, 397] -> 
             RGBColor[
              0.9931772793840195, 0.9904315571558729, 0.6889475743027857], 
             UndirectedEdge[201, 235] -> 
             RGBColor[
              0.9889924229989434, 0.9837143180802159, 0.6329081570773039], 
             UndirectedEdge[321, 498] -> 
             RGBColor[
              0.9889785050343718, 0.9772570197190151, 0.5885459895042404], 
             UndirectedEdge[368, 492] -> 
             RGBColor[
              0.9711200683263558, 0.9770793101722864, 0.8933472060778621], 
             UndirectedEdge[239, 387] -> 
             RGBColor[
              0.8562839863215574, 0.8835001318552018, 0.6986074804896891], 
             UndirectedEdge[196, 500] -> 
             RGBColor[
              0.8519720368997226, 0.885174389878749, 0.9832433776629319], 
             UndirectedEdge[122, 185] -> 
             RGBColor[
              0.8711853175133075, 0.9000138553262554, 0.9765481769066171], 
             UndirectedEdge[350, 377] -> 
             RGBColor[
              0.9839340479424847, 0.9557986551143617, 0.5340288490233724], 
             UndirectedEdge[315, 353] -> 
             RGBColor[
              0.9894704765458879, 0.9899137857023843, 0.824164983375224], 
             UndirectedEdge[102, 480] -> 
             RGBColor[
              0.962008274506138, 0.8749094749360771, 0.42548923146512174`], 
             UndirectedEdge[127, 253] -> 
             RGBColor[
              0.6927133492473148, 0.7545891572229787, 0.919957466555656], 
             UndirectedEdge[159, 192] -> 
             RGBColor[
              0.9687839632746547, 0.9728141725722297, 0.7296048477664128], 
             UndirectedEdge[201, 289] -> 
             RGBColor[
              0.9905323348272225, 0.9885112249106991, 0.6726975322102461], 
             UndirectedEdge[29, 194] -> 
             RGBColor[
              0.8969065008983832, 0.8895815779323522, 0.6651759623859217], 
             UndirectedEdge[79, 388] -> 
             RGBColor[
              0.5843508285118295, 0.429009906261402, 0.5699774393074251], 
             UndirectedEdge[246, 402] -> 
             RGBColor[
              0.9696100984187155, 0.9753124169949137, 0.8672086451718913], 
             UndirectedEdge[185, 398] -> 
             RGBColor[
              0.9474354223715973, 0.9603180045881095, 0.9738622982740821], 
             UndirectedEdge[133, 304] -> 
             RGBColor[
              0.9615007622768637, 0.8758046485375389, 0.5142249795958341], 
             UndirectedEdge[107, 314] -> 
             RGBColor[
              0.9689859238464251, 0.968089856535111, 0.6916835863133757], 
             UndirectedEdge[13, 279] -> 
             RGBColor[
              0.9561946845971625, 0.9240171605030987, 0.6400287716174657], 
             UndirectedEdge[180, 418] -> 
             RGBColor[
              0.8429401508225405, 0.8778544651212147, 0.9689721004872895], 
             UndirectedEdge[112, 207] -> 
             RGBColor[
              0.8056234873161652, 0.8483166733931287, 0.9811974633536146], 
             UndirectedEdge[308, 369] -> 
             RGBColor[
              0.7217140506616592, 0.7819770816448816, 0.9733958062618432], 
             UndirectedEdge[45, 292] -> 
             RGBColor[
              0.9096799780701299, 0.9275751855893686, 0.8613725001506254], 
             UndirectedEdge[348, 418] -> 
             RGBColor[
              0.8588462761327925, 0.8762086746149272, 0.6852920854946403], 
             UndirectedEdge[51, 264] -> 
             RGBColor[
              0.9301815183121793, 0.946053213140247, 0.9546387117952979], 
             UndirectedEdge[201, 218] -> 
             RGBColor[
              0.9884890488056306, 0.9820163187282902, 0.6309526433905233], 
             UndirectedEdge[262, 376] -> 
             RGBColor[
              0.9510585706007231, 0.9630201426050307, 0.9677292533905726], 
             UndirectedEdge[304, 307] -> 
             RGBColor[
              0.961724763816152, 0.8743030742375247, 0.39463084248530533`], 
             UndirectedEdge[8, 166] -> 
             RGBColor[
              0.5201386244820179, 0.5988376620335032, 0.960069274877138], 
             UndirectedEdge[66, 312] -> 
             RGBColor[
              0.8911076397814799, 0.9155465999008935, 0.9734420625601696], 
             UndirectedEdge[202, 430] -> 
             RGBColor[
              0.9848347455647288, 0.9729992953980546, 0.639633576653548], 
             UndirectedEdge[348, 404] -> 
             RGBColor[
              0.9034639989495807, 0.5651011339363579, 0.2825707879364217], 
             UndirectedEdge[1, 113] -> 
             RGBColor[
              0.9652546979654845, 0.9732530892836482, 0.9278235948559499], 
             UndirectedEdge[29, 377] -> 
             RGBColor[
              0.9082781608629577, 0.9262715996755793, 0.8512943236465045], 
             UndirectedEdge[259, 404] -> 
             RGBColor[
              0.8999909739962837, 0.576019510331529, 0.545204807096662], 
             UndirectedEdge[131, 449] -> 
             RGBColor[
              0.8938899795206647, 0.9171232152280612, 0.9470373665040007], 
             UndirectedEdge[423, 465] -> 
             RGBColor[
              0.9855289736091711, 0.9863990997070365, 0.7882645488174166], 
             UndirectedEdge[177, 412] -> 
             RGBColor[
              0.8430213929575083, 0.878147627587959, 0.9847616219274351], 
             UndirectedEdge[139, 158] -> 
             RGBColor[
              0.9913642703717639, 0.9883330332147069, 0.6209504406917103], 
             UndirectedEdge[454, 500] -> 
             RGBColor[
              0.86667370984296, 0.8961388734880354, 0.9583572801804378], 
             UndirectedEdge[430, 459] -> 
             RGBColor[
              0.9788445234745669, 0.940299751516917, 0.3723153978855561], 
             UndirectedEdge[474, 490] -> 
             RGBColor[
              0.9905899523922471, 0.9903767177340708, 0.8056123714904334], 
             UndirectedEdge[443, 451] -> 
             RGBColor[
              0.8803107159989039, 0.9063934602617154, 0.9401015807295161], 
             UndirectedEdge[182, 483] -> 
             RGBColor[
              0.829617508758824, 0.8673299549611427, 0.9835175868975785], 
             UndirectedEdge[92, 457] -> 
             RGBColor[
              0.9709959487167001, 0.9416508888613573, 0.6289739650308934], 
             UndirectedEdge[38, 184] -> 
             RGBColor[
              0.4567987908974691, 0.5661452243795493, 0.9514143990758924], 
             UndirectedEdge[51, 457] -> 
             RGBColor[
              0.9246623375954061, 0.9056984995003978, 0.6589747374055762], 
             UndirectedEdge[321, 455] -> 
             RGBColor[
              0.9929704538324375, 0.9913611162556861, 0.7661613020862312], 
             UndirectedEdge[251, 435] -> 
             RGBColor[
              0.9579964989815224, 0.9654864735788518, 0.821245834500159], 
             UndirectedEdge[16, 441] -> 
             RGBColor[
              0.9812006116529768, 0.9832058847001864, 0.7983581420240042], 
             UndirectedEdge[302, 390] -> 
             RGBColor[
              0.9805983788433967, 0.946123133855004, 0.3870184463157694], 
             UndirectedEdge[186, 455] -> 
             RGBColor[
              0.9863512019667389, 0.9877630854336865, 0.8373110497896465], 
             UndirectedEdge[349, 353] -> 
             RGBColor[
              0.9942935244374498, 0.9908877336072169, 0.6700545598949676], 
             UndirectedEdge[125, 406] -> 
             RGBColor[
              0.885815713934575, 0.91084830055465, 0.9478910553031907], 
             UndirectedEdge[307, 433] -> 
             RGBColor[
              0.9925438846852697, 0.9895905142579182, 0.6573488048732474], 
             UndirectedEdge[406, 419] -> 
             RGBColor[
              0.8913472256564872, 0.9112895345729278, 0.7098873582492553], 
             UndirectedEdge[237, 274] -> 
             RGBColor[
              0.9485651021735978, 0.8882106417907871, 0.6175253149519887], 
             UndirectedEdge[203, 264] -> 
             RGBColor[
              0.9858646978466152, 0.9854746299888572, 0.6944767499197241], 
             UndirectedEdge[69, 231] -> 
             RGBColor[
              0.9924274776084806, 0.9911365816332274, 0.7751598232946215], 
             UndirectedEdge[328, 399] -> 
             RGBColor[
              0.9667400812993732, 0.971482686962361, 0.7483654948342389], 
             UndirectedEdge[78, 262] -> 
             RGBColor[
              0.9746150516730123, 0.9795762179784444, 0.8825209814958508], 
             UndirectedEdge[27, 412] -> 
             RGBColor[
              0.9449647489976221, 0.9582149113495494, 0.9690138772715768], 
             UndirectedEdge[147, 221] -> 
             RGBColor[
              0.9421287413799118, 0.9538723021950055, 0.8828509645524707], 
             UndirectedEdge[93, 289] -> 
             RGBColor[
              0.9902744467272677, 0.988404581553946, 0.6769714054195061], 
             UndirectedEdge[141, 235] -> 
             RGBColor[
              0.9916149208073171, 0.9829702972666681, 0.45653458460697005`], 
             UndirectedEdge[185, 464] -> 
             RGBColor[
              0.8195973518189446, 0.8597129444427583, 0.9714063706031519], 
             UndirectedEdge[6, 189] -> 
             RGBColor[
              0.9811423554437173, 0.9848327554991085, 0.8888691133325076], 
             UndirectedEdge[38, 316] -> 
             RGBColor[
              0.5456424274121584, 0.6362276987053636, 0.9598065311526836], 
             UndirectedEdge[322, 343] -> 
             RGBColor[
              0.9569145084107754, 0.9673376806226281, 0.95608970599841], 
             UndirectedEdge[93, 141] -> 
             RGBColor[
              0.9902820830039931, 0.9884209147777157, 0.6778025670154282], 
             UndirectedEdge[191, 237] -> 
             RGBColor[
              0.9507414254711102, 0.8898337401426695, 0.6138413672853235], 
             UndirectedEdge[145, 461] -> 
             RGBColor[
              0.9626563235095822, 0.9700173641605596, 0.8751222248714484], 
             UndirectedEdge[420, 500] -> 
             RGBColor[
              0.8612460096765686, 0.8920909035909841, 0.9675449607912145], 
             UndirectedEdge[402, 458] -> 
             RGBColor[
              0.9698846037028448, 0.9743468144617353, 0.7842189300654654], 
             UndirectedEdge[148, 263] -> 
             RGBColor[
              0.8813145598160684, 0.9056620008744782, 0.871474730003086], 
             UndirectedEdge[126, 499] -> 
             RGBColor[
              0.9059829858294687, 0.8858294457555853, 0.6498747288744322], 
             UndirectedEdge[133, 371] -> 
             RGBColor[
              0.6878378073554834, 0.74862788394113, 0.8557542804646734], 
             UndirectedEdge[72, 245] -> 
             RGBColor[
              0.8808593823348249, 0.8831408826955645, 0.6724967414691796], 
             UndirectedEdge[57, 131] -> 
             RGBColor[
              0.7274995118960956, 0.7845215020994332, 0.9322418403232595], 
             UndirectedEdge[15, 173] -> 
             RGBColor[
              0.6977931890180732, 0.7236903264812695, 0.6384778574636771], 
             UndirectedEdge[138, 415] -> 
             RGBColor[
              0.9896461765354788, 0.989986442163364, 0.8212531798507079], 
             UndirectedEdge[105, 109] -> 
             RGBColor[
              0.9334735331942633, 0.9351841649158481, 0.6928565484345605], 
             UndirectedEdge[235, 284] -> 
             RGBColor[
              0.9714842569416884, 0.9712756929696659, 0.6902621549477672], 
             UndirectedEdge[150, 473] -> 
             RGBColor[
              0.9700765563191667, 0.9069159195862269, 0.43089259169922345`], 
             UndirectedEdge[74, 417] -> 
             RGBColor[
              0.9809553708480464, 0.9824268814632443, 0.7514750436610451], 
             UndirectedEdge[20, 413] -> 
             RGBColor[
              0.7678278347815016, 0.8185522073297717, 0.9774935608780955], 
             UndirectedEdge[34, 467] -> 
             RGBColor[
              0.7975984302967245, 0.8426380194998653, 0.9802408784590037], 
             UndirectedEdge[62, 110] -> 
             RGBColor[
              0.9108464500557423, 0.9287861209045076, 0.8736780295026034], 
             UndirectedEdge[93, 389] -> 
             RGBColor[
              0.9907588477453115, 0.9894406663510862, 0.7296954668570153], 
             UndirectedEdge[28, 408] -> 
             RGBColor[
              0.9596658289859408, 0.9672447692961914, 0.8560366743991468], 
             UndirectedEdge[93, 284] -> 
             RGBColor[
              0.9701514191383643, 0.9767263104807133, 0.9115301373562253], 
             UndirectedEdge[143, 313] -> 
             RGBColor[
              0.8924248884119828, 0.9075784298801899, 0.6961417521101374], 
             UndirectedEdge[361, 398] -> 
             RGBColor[
              0.8838829229422449, 0.9099594470097716, 0.9787731775905413], 
             UndirectedEdge[105, 382] -> 
             RGBColor[
              0.9160935225198295, 0.9355511455296055, 0.9786502342856611], 
             UndirectedEdge[240, 495] -> 
             RGBColor[
              0.9660616355933693, 0.9672315108468171, 0.6994412384443153], 
             UndirectedEdge[13, 21] -> 
             RGBColor[
              0.9740262032665286, 0.9371354124704734, 0.6017630497124631], 
             UndirectedEdge[32, 179] -> 
             RGBColor[
              0.6114902783092049, 0.6772505225318544, 0.9041625326422796], 
             UndirectedEdge[38, 79] -> 
             RGBColor[
              0.5843508285118295, 0.429009906261402, 0.5699774393074251], 
             UndirectedEdge[328, 407] -> 
             RGBColor[
              0.9607626387318994, 0.9518026702477409, 0.6840478616921125], 
             UndirectedEdge[357, 367] -> 
             RGBColor[
              0.9920921489399721, 0.9897167640064997, 0.6875909626828935], 
             UndirectedEdge[196, 213] -> 
             RGBColor[
              0.9422363404397059, 0.9564405377960201, 0.9826629878470354], 
             UndirectedEdge[233, 326] -> 
             RGBColor[
              0.9481650220248512, 0.9595599218289474, 0.9213984917013616], 
             UndirectedEdge[164, 372] -> 
             RGBColor[
              0.8213959837030327, 0.8579993304713659, 0.8115430104850573], 
             UndirectedEdge[3, 278] -> 
             RGBColor[
              0.9823156283919101, 0.9831676918008643, 0.7274581359473522], 
             UndirectedEdge[195, 399] -> 
             RGBColor[
              0.993740593058964, 0.9890200864132717, 0.5600803669291977], 
             UndirectedEdge[118, 187] -> 
             RGBColor[
              0.9245054885040518, 0.9407824528767608, 0.9229631252853117], 
             UndirectedEdge[61, 178] -> 
             RGBColor[
              0.990290694271001, 0.9787215372249476, 0.573171711772501], 
             UndirectedEdge[2, 496] -> 
             RGBColor[
              0.8127317838262449, 0.838894312053994, 0.6788460843469577], 
             UndirectedEdge[103, 404] -> 
             RGBColor[
              0.9082213258095405, 0.5798477862893113, 0.4116736498688416], 
             UndirectedEdge[37, 374] -> 
             RGBColor[
              0.9945151169495118, 0.9906767146987758, 0.6443825126079441], 
             UndirectedEdge[236, 466] -> 
             RGBColor[
              0.9587297795197256, 0.9687413176563711, 0.9547438976624212], 
             UndirectedEdge[150, 254] -> 
             RGBColor[
              0.9686320822212511, 0.9074410196881175, 0.5364198787323622], 
             UndirectedEdge[148, 229] -> 
             RGBColor[
              0.8817746445168737, 0.9058522577218987, 0.8638499358497038], 
             UndirectedEdge[160, 432] -> 
             RGBColor[
              0.9662291694300942, 0.8910532443296251, 0.463838307689076], 
             UndirectedEdge[48, 198] -> 
             RGBColor[
              0.7481103543962663, 0.7974647534934032, 0.7133601096329684], 
             UndirectedEdge[89, 178] -> 
             RGBColor[
              0.9928210919915348, 0.9912993512960486, 0.7686366143260449], 
             UndirectedEdge[63, 239] -> 
             RGBColor[
              0.810344187851967, 0.847398108546539, 0.6941746042797907], 
             UndirectedEdge[425, 462] -> 
             RGBColor[
              0.871443123156149, 0.8998583483111334, 0.958507311670656], 
             UndirectedEdge[44, 457] -> 
             RGBColor[
              0.9567209119469244, 0.8626211825534731, 0.30225604863166017`], 
             UndirectedEdge[46, 254] -> 
             RGBColor[
              0.9730758826487391, 0.9250592075743987, 0.5399954648657215], 
             UndirectedEdge[1, 452] -> 
             RGBColor[
              0.9332255944875164, 0.9479327459192189, 0.9323543675614198], 
             UndirectedEdge[260, 299] -> 
             RGBColor[
              0.9925633623471992, 0.989771316045517, 0.669582912803585], 
             UndirectedEdge[321, 341] -> 
             RGBColor[
              0.9248222172500605, 0.9400952779236863, 0.8821871939466766], 
             UndirectedEdge[249, 406] -> 
             RGBColor[
              0.8737281289766026, 0.901833399484598, 0.9683521836899709], 
             UndirectedEdge[398, 496] -> 
             RGBColor[
              0.7941246847886569, 0.8398170418304371, 0.9698393735406525], 
             UndirectedEdge[382, 462] -> 
             RGBColor[
              0.9593018187897667, 0.9691679436073393, 0.953775584389978], 
             UndirectedEdge[63, 272] -> 
             RGBColor[
              0.8032921355879599, 0.8236098803594287, 0.6667787129024482], 
             UndirectedEdge[117, 270] -> 
             RGBColor[
              0.4239179523665839, 0.5350760557998991, 0.9492578297126448], 
             UndirectedEdge[164, 404] -> 
             RGBColor[
              0.734993949982974, 0.44693888212809785`, 0.5670526108992067], 
             UndirectedEdge[133, 191] -> 
             RGBColor[
              0.9758293102030231, 0.9800331095223662, 0.8603718343088441], 
             UndirectedEdge[307, 469] -> 
             RGBColor[
              0.9920944941413599, 0.9894046797192013, 0.6647963691712808], 
             UndirectedEdge[31, 237] -> 
             RGBColor[
              0.5705707196950477, 0.5683789161725954, 0.6037240232105405], 
             UndirectedEdge[1, 468] -> 
             RGBColor[
              0.8810839932108494, 0.9067132302611729, 0.9272863761503045], 
             UndirectedEdge[346, 395] -> 
             RGBColor[
              0.7241424552406792, 0.7829843311570786, 0.9638477588214246], 
             UndirectedEdge[214, 223] -> 
             RGBColor[
              0.9347432228216308, 0.9476088649198595, 0.8658876900587369], 
             UndirectedEdge[264, 397] -> 
             RGBColor[
              0.9864689702576035, 0.9867671075746483, 0.7602480727187417], 
             UndirectedEdge[103, 204] -> 
             RGBColor[
              0.963970964564868, 0.970279214489646, 0.8241555121663134], 
             UndirectedEdge[110, 356] -> 
             RGBColor[
              0.9552923706118586, 0.9642260915035807, 0.8779173210825875], 
             UndirectedEdge[184, 253] -> 
             RGBColor[
              0.7917299308228203, 0.8364196817193861, 0.9273533217345703], 
             UndirectedEdge[115, 417] -> 
             RGBColor[
              0.8300281972699808, 0.8675046528455964, 0.9543774038302064], 
             UndirectedEdge[243, 459] -> 
             RGBColor[
              0.9837591019441396, 0.9573295524237594, 0.552225580090051], 
             UndirectedEdge[190, 349] -> 
             RGBColor[
              0.9907046732441498, 0.9793217843905171, 0.5021502930120432], 
             UndirectedEdge[128, 222] -> 
             RGBColor[
              0.9322260964339322, 0.7464317579903464, 0.4738519143764801], 
             UndirectedEdge[204, 275] -> 
             RGBColor[
              0.9618398777191303, 0.9699769044677298, 0.9015566281633993], 
             UndirectedEdge[178, 455] -> 
             RGBColor[
              0.9939711619403917, 0.9917749347753504, 0.7495769789878646], 
             UndirectedEdge[84, 391] -> 
             RGBColor[
              0.9585868664117029, 0.9190788897020558, 0.6217091420665236], 
             UndirectedEdge[54, 203] -> 
             RGBColor[
              0.9885612545411075, 0.9874801168421465, 0.6896613713832315], 
             UndirectedEdge[236, 314] -> 
             RGBColor[
              0.9844153295733409, 0.9795970820629117, 0.6655656270512221], 
             UndirectedEdge[277, 313] -> 
             RGBColor[0.89440728701025, 0.91394310402077, 0.7312594206545873],
              UndirectedEdge[186, 397] -> 
             RGBColor[
              0.9865580275183208, 0.9868335263338733, 0.7600973220062011], 
             UndirectedEdge[29, 297] -> 
             RGBColor[
              0.9059945349581507, 0.9253913546511251, 0.8937987973111601], 
             UndirectedEdge[130, 208] -> 
             RGBColor[
              0.9298728368874126, 0.9464575114206459, 0.9771601715172826], 
             UndirectedEdge[145, 450] -> 
             RGBColor[
              0.7918609623382453, 0.8348879703733436, 0.8588851054510958], 
             UndirectedEdge[86, 350] -> 
             RGBColor[
              0.9826079553175884, 0.9529622770782396, 0.3896918504984497], 
             UndirectedEdge[37, 281] -> 
             RGBColor[
              0.9804599145161232, 0.9822520399484195, 0.7677598750108824], 
             UndirectedEdge[281, 445] -> 
             RGBColor[
              0.6501191144552984, 0.7189908533535719, 0.9417202530217978], 
             UndirectedEdge[116, 224] -> 
             RGBColor[
              0.5503007950426411, 0.6380830403802281, 0.9606285878486431], 
             UndirectedEdge[112, 163] -> 
             RGBColor[
              0.8585819589060324, 0.8900369720402537, 0.9686585785834174], 
             UndirectedEdge[148, 480] -> 
             RGBColor[
              0.849810445898403, 0.7900912986249918, 0.620108875134764], 
             UndirectedEdge[42, 487] -> 
             RGBColor[
              0.8277769156578592, 0.8634315333490756, 0.8477082928156527], 
             UndirectedEdge[122, 319] -> 
             RGBColor[
              0.7609337022254506, 0.8131664585796368, 0.97680641817424], 
             UndirectedEdge[129, 348] -> 
             RGBColor[
              0.6674952307560652, 0.7194353979238091, 0.6700590437626227], 
             UndirectedEdge[93, 201] -> 
             RGBColor[
              0.9876595851956194, 0.9891649355912634, 0.8541761394857619], 
             UndirectedEdge[121, 427] -> 
             RGBColor[
              0.6291832352182457, 0.6961483821411768, 0.9130328853157559], 
             UndirectedEdge[269, 411] -> 
             RGBColor[
              0.9611312816193782, 0.968763056440326, 0.8733144842831585], 
             UndirectedEdge[76, 371] -> 
             RGBColor[
              0.6731238485309691, 0.7391152476613998, 0.9460881929181192], 
             UndirectedEdge[61, 244] -> 
             RGBColor[
              0.9858286566333512, 0.9768763699926426, 0.6471192228116058], 
             UndirectedEdge[184, 436] -> 
             RGBColor[
              0.7857417626217797, 0.8321386169811534, 0.9457699865857365], 
             UndirectedEdge[80, 293] -> 
             RGBColor[
              0.8524822370136322, 0.8853074403266031, 0.9857659094636999], 
             UndirectedEdge[111, 460] -> 
             RGBColor[
              0.9881324159230347, 0.988104344770865, 0.7651004337616907], 
             UndirectedEdge[286, 358] -> 
             RGBColor[
              0.9545590294612916, 0.9651144908034073, 0.9418164436166104], 
             UndirectedEdge[176, 244] -> 
             RGBColor[
              0.9890801365308666, 0.9876402680349454, 0.6771064057702065], 
             UndirectedEdge[99, 321] -> 
             RGBColor[
              0.9187875676216968, 0.9352834121162295, 0.8816116036779279], 
             UndirectedEdge[187, 478] -> 
             RGBColor[
              0.9556756866844069, 0.8627122758541133, 0.5584824792042105], 
             UndirectedEdge[116, 185] -> 
             RGBColor[
              0.875469954306541, 0.903361046153575, 0.9769752294599592], 
             UndirectedEdge[97, 257] -> 
             RGBColor[
              0.6087203746362205, 0.327557040670546, 0.5554671909716187], 
             UndirectedEdge[16, 313] -> 
             RGBColor[
              0.8817784221174803, 0.9079387895169557, 0.9598627767384004], 
             UndirectedEdge[166, 344] -> 
             RGBColor[
              0.9002350989884473, 0.9231988311197534, 0.9872878877009522], 
             UndirectedEdge[103, 443] -> 
             RGBColor[
              0.9896950731665517, 0.9894277130216684, 0.7783593442461602], 
             UndirectedEdge[74, 115] -> 
             RGBColor[
              0.8428505647015491, 0.8741773076666377, 0.7670257551324582], 
             UndirectedEdge[196, 332] -> 
             RGBColor[
              0.8851798526386305, 0.9112136712694818, 0.9865274594559161], 
             UndirectedEdge[49, 203] -> 
             RGBColor[
              0.8421310153899924, 0.8730171674842757, 0.7190554569167581], 
             UndirectedEdge[95, 122] -> 
             RGBColor[
              0.8929287849295866, 0.9150228376821836, 0.8856785869414389], 
             UndirectedEdge[97, 209] -> 
             RGBColor[
              0.6153957808345089, 0.6944023290437358, 0.9652138021344802], 
             UndirectedEdge[484, 490] -> 
             RGBColor[
              0.9944359317852973, 0.9919671290502591, 0.7418745398719766], 
             UndirectedEdge[128, 415] -> 
             RGBColor[
              0.931289705496342, 0.7460445362735035, 0.48937033551441544`], 
             UndirectedEdge[371, 442] -> 
             RGBColor[
              0.6879355978858281, 0.7486683228385296, 0.8541336383030818], 
             UndirectedEdge[88, 311] -> 
             RGBColor[
              0.9876404613832916, 0.9686268856645633, 0.5207385355701306], 
             UndirectedEdge[15, 149] -> 
             RGBColor[
              0.9213208038210023, 0.9027270178137634, 0.6582043326515788], 
             UndirectedEdge[117, 140] -> 
             RGBColor[
              0.7772624475562457, 0.8250219477496188, 0.9388590041534632], 
             UndirectedEdge[199, 475] -> 
             RGBColor[
              0.9810923289906474, 0.9610901604573411, 0.6300364602767116], 
             UndirectedEdge[71, 169] -> 
             RGBColor[
              0.9523231361615861, 0.9607272256621843, 0.8016173585300785], 
             UndirectedEdge[23, 51] -> 
             RGBColor[
              0.9172708449438987, 0.9364244540814707, 0.9764931141648912], 
             UndirectedEdge[381, 416] -> 
             RGBColor[
              0.9829072193981716, 0.9849114647764857, 0.8298097176373773], 
             UndirectedEdge[121, 447] -> 
             RGBColor[
              0.3503657880063309, 0.4745583658530428, 0.9436679989968821], 
             UndirectedEdge[244, 407] -> 
             RGBColor[
              0.9833288831991522, 0.9684440472243754, 0.6374080750623456], 
             UndirectedEdge[255, 385] -> 
             RGBColor[
              0.9282016730137628, 0.8951623090676324, 0.6396604247754434], 
             UndirectedEdge[30, 469] -> 
             RGBColor[
              0.9533637433116366, 0.9631403026050988, 0.8973627718542785], 
             UndirectedEdge[80, 171] -> 
             RGBColor[
              0.882650097101761, 0.9088042698504943, 0.9692900906428783], 
             UndirectedEdge[214, 466] -> 
             RGBColor[
              0.966004036172528, 0.9724840587951915, 0.8670897262184921], 
             UndirectedEdge[199, 455] -> 
             RGBColor[
              0.9894447477917665, 0.9899031462013563, 0.8245913754148992], 
             UndirectedEdge[175, 483] -> 
             RGBColor[
              0.7284406639580464, 0.7872449193674586, 0.9741476389679418], 
             UndirectedEdge[124, 416] -> 
             RGBColor[
              0.8496345853574625, 0.8827783508534774, 0.9541568873329795], 
             UndirectedEdge[142, 396] -> 
             RGBColor[
              0.892129303681175, 0.9139577939818837, 0.8656255384023058], 
             UndirectedEdge[185, 361] -> 
             RGBColor[
              0.8844192486339012, 0.9103594378324562, 0.9778653180907102], 
             UndirectedEdge[19, 26] -> 
             RGBColor[
              0.685794174461194, 0.7477827892203716, 0.8896225662754431], 
             UndirectedEdge[341, 455] -> 
             RGBColor[
              0.9255434546626523, 0.940393528128749, 0.87023442351744], 
             UndirectedEdge[159, 239] -> 
             RGBColor[
              0.9684127407493686, 0.9718743910354074, 0.7015951433345324], 
             UndirectedEdge[261, 482] -> 
             RGBColor[
              0.942646067326903, 0.9553639993926586, 0.929762703467007], 
             UndirectedEdge[5, 97] -> 
             RGBColor[
              0.6922246458700165, 0.7543870658173619, 0.9280565462412877], 
             UndirectedEdge[285, 396] -> 
             RGBColor[
              0.877123864156835, 0.9043720844056828, 0.9629154616900798], 
             UndirectedEdge[174, 424] -> 
             RGBColor[
              0.9731523003116547, 0.9758828458229571, 0.7071961697230758], 
             UndirectedEdge[99, 186] -> 
             RGBColor[
              0.9121683157559981, 0.9316853812942298, 0.9527613513813433], 
             UndirectedEdge[79, 127] -> 
             RGBColor[
              0.626690368462307, 0.46568228771935194`, 0.5726752773536843], 
             UndirectedEdge[29, 86] -> 
             RGBColor[
              0.9069520682380614, 0.923435221639457, 0.7069573251215816], 
             UndirectedEdge[127, 316] -> 
             RGBColor[
              0.5879819673626359, 0.6729000801633135, 0.9625043691989429], 
             UndirectedEdge[197, 466] -> 
             RGBColor[
              0.6850912769762718, 0.751037493576625, 0.9695693065185171], 
             UndirectedEdge[183, 206] -> 
             RGBColor[
              0.670203273036781, 0.7370792181679362, 0.9531062835821832], 
             UndirectedEdge[25, 392] -> 
             RGBColor[
              0.9153305380969381, 0.9345724787851342, 0.9657394926451948], 
             UndirectedEdge[73, 91] -> 
             RGBColor[
              0.9125024449051984, 0.9320453005180255, 0.9560347065317827], 
             UndirectedEdge[187, 464] -> 
             RGBColor[
              0.839287908797311, 0.8738729955752178, 0.9145588193560938], 
             UndirectedEdge[17, 99] -> 
             RGBColor[
              0.8779964181364307, 0.9055545275168491, 0.9882252762301498], 
             UndirectedEdge[110, 157] -> 
             RGBColor[
              0.894852000857575, 0.9162216362345597, 0.8721022952854193], 
             UndirectedEdge[241, 429] -> 
             RGBColor[
              0.7929379750217136, 0.8171787616550634, 0.6688981242644569], 
             UndirectedEdge[27, 490] -> 
             RGBColor[
              0.9790114415278188, 0.9822891041160946, 0.8497353496966267], 
             UndirectedEdge[372, 418] -> 
             RGBColor[
              0.8636160627342255, 0.8909819770950189, 0.8157511133938158], 
             UndirectedEdge[65, 350] -> 
             RGBColor[
              0.9758839311540861, 0.9303129784398012, 0.3608140557814359], 
             UndirectedEdge[189, 390] -> 
             RGBColor[
              0.9714406176024352, 0.9429667378097744, 0.6303105600920724], 
             UndirectedEdge[263, 267] -> 
             RGBColor[
              0.9759842828461769, 0.9801424302561841, 0.8598292774998255], 
             UndirectedEdge[25, 490] -> 
             RGBColor[
              0.9792618985011452, 0.9824758945167158, 0.8493113913704258], 
             UndirectedEdge[360, 494] -> 
             RGBColor[
              0.95168268014446, 0.9634856024808641, 0.9666727987268646], 
             UndirectedEdge[61, 203] -> 
             RGBColor[
              0.9896137767162324, 0.9763839322247417, 0.43481821385916786`], 
             UndirectedEdge[36, 104] -> 
             RGBColor[
              0.9854432878583658, 0.9859938784618536, 0.7613275521321321], 
             UndirectedEdge[33, 241] -> 
             RGBColor[
              0.7856971507095778, 0.8323700712439281, 0.952945811096328], 
             UndirectedEdge[82, 419] -> 
             RGBColor[
              0.7160862789365061, 0.7708930881019437, 0.6946466723482017], 
             UndirectedEdge[5, 404] -> 
             RGBColor[
              0.9030796471492735, 0.5783005191834067, 0.5389680633945424], 
             UndirectedEdge[40, 396] -> 
             RGBColor[
              0.6902979493211491, 0.7571861392534895, 0.9703124775752493], 
             UndirectedEdge[169, 369] -> 
             RGBColor[
              0.9251305037343567, 0.9390445586890552, 0.79902370097402], 
             UndirectedEdge[268, 491] -> 
             RGBColor[
              0.9827061742451428, 0.9531928044386112, 0.3986437088435529], 
             UndirectedEdge[4, 151] -> 
             RGBColor[
              0.9928020834612687, 0.9898038724708335, 0.6608174878650384], 
             UndirectedEdge[6, 390] -> 
             RGBColor[
              0.9782451577735063, 0.9474177281437967, 0.5908561090641662], 
             UndirectedEdge[376, 482] -> 
             RGBColor[
              0.9208599135993829, 0.9395399998716444, 0.9856320697985987], 
             UndirectedEdge[158, 278] -> 
             RGBColor[
              0.9807165461963189, 0.9841430774227828, 0.8729260406491894], 
             UndirectedEdge[317, 445] -> 
             RGBColor[
              0.5123704236524368, 0.6109969878248412, 0.956167930284836], 
             UndirectedEdge[133, 351] -> 
             RGBColor[
              0.9447201687845723, 0.9558199498835034, 0.8779443734367933], 
             UndirectedEdge[239, 454] -> 
             RGBColor[
              0.9800172466583841, 0.9805290125417168, 0.6819517417704417], 
             UndirectedEdge[140, 198] -> 
             RGBColor[
              0.9866575777304432, 0.9860943875184364, 0.6953903314753307], 
             UndirectedEdge[252, 309] -> 
             RGBColor[
              0.9201716061178462, 0.9358557476025542, 0.858674504019922], 
             UndirectedEdge[161, 243] -> 
             RGBColor[
              0.9899913720828405, 0.990129189393319, 0.8155323962934844], 
             UndirectedEdge[244, 455] -> 
             RGBColor[
              0.9895091243027418, 0.9899297675430454, 0.8235244900269694], 
             UndirectedEdge[401, 451] -> 
             RGBColor[
              0.8708821478268557, 0.8607612481016915, 0.6502033094824586], 
             UndirectedEdge[210, 225] -> 
             RGBColor[
              0.8421618682988313, 0.8730831587365748, 0.7224136056418057], 
             UndirectedEdge[107, 223] -> 
             RGBColor[
              0.9120395604419127, 0.9323588982532385, 0.9796598207648195], 
             UndirectedEdge[5, 204] -> 
             RGBColor[
              0.958829285904601, 0.9687319473837415, 0.9514499256920143], 
             UndirectedEdge[59, 200] -> 
             RGBColor[
              0.9872117076462978, 0.9889797267146909, 0.861598629547963], 
             UndirectedEdge[328, 481] -> 
             RGBColor[
              0.9641369855504331, 0.9721280811713466, 0.9166652063817494], 
             UndirectedEdge[55, 434] -> 
             RGBColor[
              0.98307102028797, 0.985719444038436, 0.8608978406018285], 
             UndirectedEdge[269, 499] -> 
             RGBColor[
              0.9208818266565657, 0.9366692335953294, 0.8694754553376928], 
             UndirectedEdge[377, 476] -> 
             RGBColor[
              0.9808454295838478, 0.9833409314044108, 0.830692973198037], 
             UndirectedEdge[260, 478] -> 
             RGBColor[
              0.9577454730757314, 0.86356818571801, 0.5241807622644886], 
             UndirectedEdge[163, 207] -> 
             RGBColor[
              0.902414946867419, 0.9245178504244154, 0.972964226232165], 
             UndirectedEdge[238, 258] -> 
             RGBColor[
              0.9946212728892152, 0.991320868530875, 0.6862554811321622], 
             UndirectedEdge[10, 443] -> 
             RGBColor[
              0.9860278740324968, 0.988490181092248, 0.8812178161918304], 
             UndirectedEdge[231, 326] -> 
             RGBColor[
              0.9497928174940335, 0.9602330570878898, 0.8944217081773747], 
             UndirectedEdge[91, 287] -> 
             RGBColor[
              0.9220655214432467, 0.9367981346347403, 0.8147421307988781], 
             UndirectedEdge[242, 249] -> 
             RGBColor[
              0.9194367585699803, 0.9380383270797816, 0.9727761045272456], 
             UndirectedEdge[83, 209] -> 
             RGBColor[
              0.7946350726879177, 0.8395805947683141, 0.9801425360300389], 
             UndirectedEdge[306, 431] -> 
             RGBColor[
              0.9898556052915359, 0.9880141302947607, 0.6681209421982988], 
             UndirectedEdge[176, 376] -> 
             RGBColor[
              0.9680030000799968, 0.9721094653787391, 0.7212255209498089], 
             UndirectedEdge[30, 191] -> 
             RGBColor[
              0.9373225609125881, 0.9522671581082495, 0.9733440998813131], 
             UndirectedEdge[209, 444] -> 
             RGBColor[
              0.8955538553096225, 0.918916403267309, 0.9677818602863848], 
             UndirectedEdge[169, 289] -> 
             RGBColor[
              0.9936820137820302, 0.9888947912631839, 0.5537043741443579], 
             UndirectedEdge[20, 46] -> 
             RGBColor[
              0.8676267643139062, 0.8438733204409461, 0.6307121697733997], 
             UndirectedEdge[49, 100] -> 
             RGBColor[
              0.8223581962145963, 0.8617744966446426, 0.9668604911389573], 
             UndirectedEdge[404, 486] -> 
             RGBColor[
              0.8944163204293412, 0.5718619428289606, 0.5546412414829868], 
             UndirectedEdge[103, 431] -> 
             RGBColor[0.993753133538845, 0.9890469092317, 0.5614453207733685],
              UndirectedEdge[219, 238] -> 
             RGBColor[
              0.9947297831043065, 0.9915529609088898, 0.6980661483974313], 
             UndirectedEdge[249, 499] -> 
             RGBColor[
              0.9027170057707992, 0.9247064500433142, 0.9711813595793601], 
             UndirectedEdge[254, 377] -> 
             RGBColor[
              0.9931498368582174, 0.9913712027730872, 0.7585295785330597], 
             UndirectedEdge[57, 434] -> 
             RGBColor[
              0.7232239466771004, 0.7813327925597019, 0.939479256993015], 
             UndirectedEdge[75, 104] -> 
             RGBColor[
              0.9943081968010611, 0.990234133424076, 0.6218605314122165], 
             UndirectedEdge[132, 365] -> 
             RGBColor[
              0.993310932023042, 0.9897853201099391, 0.635740534595838], 
             UndirectedEdge[38, 77] -> 
             RGBColor[
              0.6410355792308826, 0.711137240373166, 0.9413470742617929], 
             UndirectedEdge[172, 314] -> 
             RGBColor[
              0.9506714900258357, 0.832348429856785, 0.3301407744066094], 
             UndirectedEdge[398, 481] -> 
             RGBColor[
              0.9674894996774293, 0.9746283807180223, 0.910990274440467], 
             UndirectedEdge[143, 165] -> 
             RGBColor[
              0.9570974555868437, 0.9589510215103161, 0.702362174366915], 
             UndirectedEdge[261, 475] -> 
             RGBColor[
              0.981865722778273, 0.961409978663838, 0.6172193237367922], 
             UndirectedEdge[288, 373] -> 
             RGBColor[
              0.8671626917644991, 0.8350142082969614, 0.6287844134216334], 
             UndirectedEdge[78, 171] -> 
             RGBColor[
              0.9738153654195485, 0.9789798132799772, 0.8838746417313865], 
             UndirectedEdge[6, 370] -> 
             RGBColor[
              0.9911954637667761, 0.9899042084194678, 0.7430300040007898], 
             UndirectedEdge[264, 295] -> 
             RGBColor[
              0.9054424905640341, 0.926326983936895, 0.952279081243889], 
             UndirectedEdge[45, 464] -> 
             RGBColor[
              0.8428982200116804, 0.8753659520431256, 0.8547266193480739], 
             UndirectedEdge[228, 318] -> 
             RGBColor[
              0.7785635227750889, 0.6020470554817205, 0.5864375477994381], 
             UndirectedEdge[7, 295] -> 
             RGBColor[
              0.8780896303350579, 0.9056288523938567, 0.9882341668928665], 
             UndirectedEdge[225, 320] -> 
             RGBColor[
              0.9633629484239911, 0.9686860325031796, 0.7342497447951088], 
             UndirectedEdge[137, 148] -> 
             RGBColor[
              0.846491837927674, 0.776934123881601, 0.6174386452637746], 
             UndirectedEdge[61, 455] -> 
             RGBColor[
              0.9900112235756386, 0.978605968910346, 0.5778032644416311], 
             UndirectedEdge[11, 331] -> 
             RGBColor[
              0.9275406135566395, 0.9410911583842771, 0.8093738016684855], 
             UndirectedEdge[20, 392] -> 
             RGBColor[
              0.823011351052329, 0.8620325374797102, 0.9828954060602009], 
             UndirectedEdge[348, 431] -> 
             RGBColor[
              0.9889958066788851, 0.9743002568787464, 0.4323424588409486], 
             UndirectedEdge[241, 351] -> 
             RGBColor[
              0.751312764268903, 0.8057142392302119, 0.9760624857261906], 
             UndirectedEdge[343, 374] -> 
             RGBColor[
              0.9643702066151777, 0.970840455924703, 0.8438835828287748], 
             UndirectedEdge[162, 389] -> 
             RGBColor[
              0.7248163875118505, 0.7793355531943167, 0.7756100083848037], 
             UndirectedEdge[207, 266] -> 
             RGBColor[
              0.8216909533988631, 0.8608687000141975, 0.9827989182137304], 
             UndirectedEdge[98, 425] -> 
             RGBColor[
              0.8656542980875512, 0.8445347958756577, 0.6319506609139407], 
             UndirectedEdge[151, 284] -> 
             RGBColor[
              0.973229369692886, 0.9765115038252761, 0.7523863841870928], 
             UndirectedEdge[41, 365] -> 
             RGBColor[
              0.8111507907594195, 0.8505882067661872, 0.8620710076618685], 
             UndirectedEdge[436, 473] -> 
             RGBColor[
              0.9836547646768238, 0.9845816088266798, 0.758134987451321], 
             UndirectedEdge[311, 405] -> 
             RGBColor[
              0.9843307995421944, 0.9855728035332325, 0.7956327187518315], 
             UndirectedEdge[235, 432] -> 
             RGBColor[
              0.9639388018191981, 0.8846511884628425, 0.34236645189451215`], 
             UndirectedEdge[109, 474] -> 
             RGBColor[
              0.9863605810673992, 0.9754717392651033, 0.6270747172253759], 
             UndirectedEdge[364, 468] -> 
             RGBColor[
              0.8785661268308754, 0.8866811135663184, 0.6800541169153981], 
             UndirectedEdge[203, 374] -> 
             RGBColor[
              0.9939349086262423, 0.9894357077633626, 0.5812304172507817], 
             UndirectedEdge[36, 112] -> 
             RGBColor[
              0.8692918076837055, 0.8980243597228745, 0.9505295981787387], 
             UndirectedEdge[324, 342] -> 
             RGBColor[
              0.821169889960008, 0.8608882597856434, 0.9688719836680675], 
             UndirectedEdge[374, 445] -> 
             RGBColor[
              0.6641743168886869, 0.7274155281039283, 0.8183428906188597], 
             UndirectedEdge[2, 327] -> 
             RGBColor[
              0.9871352123480721, 0.9741351443700004, 0.6027844695011301], 
             UndirectedEdge[128, 438] -> 
             RGBColor[
              0.9054823347699927, 0.7282590253506616, 0.5985081961577856], 
             UndirectedEdge[33, 460] -> 
             RGBColor[
              0.9797335766603731, 0.9818405042006091, 0.7793174778652694], 
             UndirectedEdge[298, 335] -> 
             RGBColor[
              0.9627282111396689, 0.9717233414116937, 0.9479755958878424], 
             UndirectedEdge[112, 343] -> 
             RGBColor[
              0.847778946429433, 0.881930292210594, 0.9852182886764607], 
             UndirectedEdge[106, 265] -> 
             RGBColor[
              0.8446194263461075, 0.8790954601480763, 0.9655521598018573], 
             UndirectedEdge[19, 468] -> 
             RGBColor[
              0.5792658783621807, 0.6653506419544902, 0.9619489877151688], 
             UndirectedEdge[161, 202] -> 
             RGBColor[
              0.9859229504873807, 0.9884467925099304, 0.8829566708678361], 
             UndirectedEdge[204, 390] -> 
             RGBColor[
              0.950937224636917, 0.9276142774641568, 0.6629003483342106], 
             UndirectedEdge[211, 289] -> 
             RGBColor[
              0.9919683106602744, 0.9891050378205617, 0.6488996964702457], 
             UndirectedEdge[48, 479] -> 
             RGBColor[
              0.7261409502923875, 0.784555444200243, 0.9626276687952523], 
             UndirectedEdge[57, 495] -> 
             RGBColor[
              0.7068147264862539, 0.7690948230090007, 0.9672557865660631], 
             UndirectedEdge[10, 280] -> 
             RGBColor[
              0.9262576796382457, 0.942194257905612, 0.923766638055789], 
             UndirectedEdge[206, 476] -> 
             RGBColor[
              0.9609190979205879, 0.9703741077350543, 0.9510379526754504], 
             UndirectedEdge[13, 256] -> 
             RGBColor[
              0.9760743349560903, 0.9379823675586907, 0.5678202072215199], 
             UndirectedEdge[184, 221] -> 
             RGBColor[
              0.7952612762624371, 0.8378799838101059, 0.8688297889710728], 
             UndirectedEdge[126, 282] -> 
             RGBColor[
              0.9795753588337446, 0.9410888084844239, 0.5176884009933829], 
             UndirectedEdge[53, 266] -> 
             RGBColor[
              0.8945837094867732, 0.9155856327298783, 0.851796303326732], 
             UndirectedEdge[194, 220] -> 
             RGBColor[
              0.8203779699622102, 0.8297858782407206, 0.6575512405614967], 
             UndirectedEdge[375, 417] -> 
             RGBColor[
              0.9806617150010628, 0.981798781299707, 0.719512416950703], 
             UndirectedEdge[245, 448] -> 
             RGBColor[
              0.8878033298768804, 0.911091350288998, 0.8884577741522663], 
             UndirectedEdge[79, 147] -> 
             RGBColor[
              0.872574415155287, 0.663505130600659, 0.5940923081139964], 
             UndirectedEdge[77, 253] -> 
             RGBColor[
              0.9759667191562339, 0.9814116977130027, 0.9172859969204707], 
             UndirectedEdge[180, 205] -> 
             RGBColor[
              0.969240899893103, 0.9764133933770364, 0.9294682043905995], 
             UndirectedEdge[28, 432] -> 
             RGBColor[
              0.9665075055994519, 0.8916485772517777, 0.4941334820319387], 
             UndirectedEdge[84, 245] -> 
             RGBColor[
              0.871099880751439, 0.8502197922148593, 0.6345829207449541], 
             UndirectedEdge[19, 459] -> 
             RGBColor[
              0.6781950147650242, 0.7144179082913393, 0.64896864743605], 
             UndirectedEdge[153, 236] -> 
             RGBColor[
              0.9088049992577494, 0.9289839831860303, 0.9517616756771673], 
             UndirectedEdge[315, 349] -> 
             RGBColor[
              0.9892760122627453, 0.9888128633787954, 0.7532077215350887], 
             UndirectedEdge[18, 460] -> 
             RGBColor[
              0.9545244496698779, 0.9625007750166832, 0.803309296932341], 
             UndirectedEdge[126, 449] -> 
             RGBColor[
              0.8841431084669584, 0.8685412478873107, 0.6477580984371953], 
             UndirectedEdge[49, 324] -> 
             RGBColor[
              0.821169889960008, 0.8608882597856434, 0.9688719836680675], 
             UndirectedEdge[334, 415] -> 
             RGBColor[
              0.9457444111754351, 0.9566359901120749, 0.8780132832860982], 
             UndirectedEdge[5, 444] -> 
             RGBColor[
              0.9723827203451303, 0.978901140040935, 0.9306246043931924], 
             UndirectedEdge[147, 449] -> 
             RGBColor[
              0.8481221661978103, 0.8818599374488723, 0.9853423199734728], 
             UndirectedEdge[254, 426] -> 
             RGBColor[
              0.8447249582526529, 0.8774330590725183, 0.8839310599559675], 
             UndirectedEdge[186, 321] -> 
             RGBColor[
              0.9856299645541471, 0.9874648352286237, 0.8492638202188831], 
             UndirectedEdge[260, 399] -> 
             RGBColor[
              0.9923892644877166, 0.9893989383280775, 0.6506334352063455], 
             UndirectedEdge[184, 287] -> 
             RGBColor[
              0.7963330993922082, 0.8376583258955557, 0.8027368344926326], 
             UndirectedEdge[129, 431] -> 
             RGBColor[
              0.671394791366744, 0.7323473750030215, 0.7057993429804745], 
             UndirectedEdge[300, 432] -> 
             RGBColor[
              0.7799381703448605, 0.7476028186134926, 0.6161046626277094], 
             UndirectedEdge[207, 293] -> 
             RGBColor[
              0.873233119668549, 0.9017564026148528, 0.9877709485700366], 
             UndirectedEdge[118, 399] -> 
             RGBColor[
              0.9274721045804575, 0.9402873836652285, 0.748638941151244], 
             UndirectedEdge[138, 179] -> 
             RGBColor[
              0.6113361727921154, 0.6771867959402068, 0.9067164598727462], 
             UndirectedEdge[40, 161] -> 
             RGBColor[
              0.7881784862329527, 0.833365171868486, 0.9199132644584666], 
             UndirectedEdge[243, 279] -> 
             RGBColor[
              0.971716478752066, 0.9768275906092427, 0.8611459837548661], 
             UndirectedEdge[69, 233] -> 
             RGBColor[
              0.9907996821392983, 0.9904634463742852, 0.8021366068186084], 
             UndirectedEdge[237, 460] -> 
             RGBColor[
              0.9685271801426489, 0.9005329158825074, 0.44386225398847556`], 
             UndirectedEdge[54, 295] -> 
             RGBColor[
              0.9081390472585265, 0.9283324707901844, 0.9474637027073964], 
             UndirectedEdge[102, 210] -> 
             RGBColor[
              0.8426831505758763, 0.874198128817451, 0.7791519645168404], 
             UndirectedEdge[137, 156] -> 
             RGBColor[
              0.9316078739875481, 0.8442894291636328, 0.621965092800492], 
             UndirectedEdge[231, 444] -> 
             RGBColor[
              0.9757524357394753, 0.9802946039542322, 0.8747796997649964], 
             UndirectedEdge[383, 393] -> 
             RGBColor[
              0.9032658918456773, 0.9237795343732287, 0.9176005768098465], 
             UndirectedEdge[43, 137] -> 
             RGBColor[
              0.9269217743323614, 0.7479762176425824, 0.26005774814263843`], 
             UndirectedEdge[233, 348] -> 
             RGBColor[
              0.986453814193062, 0.9753079937009379, 0.6241313139770084], 
             UndirectedEdge[193, 410] -> 
             RGBColor[
              0.9141739428708702, 0.9317654886379122, 0.8881564603471452], 
             UndirectedEdge[126, 384] -> 
             RGBColor[
              0.9750308886060393, 0.9392639107337784, 0.596953248061888], 
             UndirectedEdge[162, 345] -> 
             RGBColor[
              0.7061699268772756, 0.7680836840269489, 0.9541252716091463], 
             UndirectedEdge[165, 178] -> 
             RGBColor[
              0.9596924597468772, 0.9675157438010102, 0.8688333772740098], 
             UndirectedEdge[154, 455] -> 
             RGBColor[
              0.9681046341264077, 0.9741548250143802, 0.8681977296762575], 
             UndirectedEdge[211, 470] -> 
             RGBColor[
              0.9924397814152353, 0.9911416695735139, 0.7749559173754659], 
             UndirectedEdge[201, 305] -> 
             RGBColor[
              0.9900072032525856, 0.9871374101574855, 0.6368503867375327], 
             UndirectedEdge[220, 474] -> 
             RGBColor[
              0.827889884007154, 0.8649438888289271, 0.9122944630002123], 
             UndirectedEdge[125, 173] -> 
             RGBColor[
              0.7048027355049116, 0.7654697333222589, 0.932283855027918], 
             UndirectedEdge[189, 443] -> 
             RGBColor[
              0.9795585309088117, 0.9841778033514911, 0.9151171846823989], 
             UndirectedEdge[307, 500] -> 
             RGBColor[
              0.8795068872386254, 0.9025801917763806, 0.7519920791662025], 
             UndirectedEdge[102, 134] -> 
             RGBColor[
              0.9935482588656113, 0.9904950105350794, 0.6762606202829615], 
             UndirectedEdge[102, 174] -> 
             RGBColor[
              0.9737840413100614, 0.9772340759397362, 0.7759572787461286], 
             UndirectedEdge[203, 281] -> 
             RGBColor[
              0.9798797061928539, 0.9810110330130063, 0.7046077796537199], 
             UndirectedEdge[279, 421] -> 
             RGBColor[
              0.9103037198058764, 0.9309566321232657, 0.9788648467616076], 
             UndirectedEdge[335, 430] -> 
             RGBColor[
              0.9723825907480774, 0.9639598595140911, 0.6717891482693216], 
             UndirectedEdge[69, 431] -> 
             RGBColor[
              0.9933416746251214, 0.9894557095520937, 0.6103477516825486], 
             UndirectedEdge[149, 249] -> 
             RGBColor[
              0.9162427653498683, 0.9354915235847008, 0.9724714586026], 
             UndirectedEdge[141, 345] -> 
             RGBColor[
              0.9749927730190651, 0.9775514197269236, 0.7275632844017641], 
             UndirectedEdge[12, 283] -> 
             RGBColor[
              0.8061312030532557, 0.8493137974374736, 0.9761745495021397], 
             UndirectedEdge[119, 381] -> 
             RGBColor[
              0.6544536055860108, 0.7191753001546621, 0.8330534547038686], 
             UndirectedEdge[396, 430] -> 
             RGBColor[
              0.887196256701464, 0.8969203558714802, 0.6860214272057723], 
             UndirectedEdge[49, 360] -> 
             RGBColor[
              0.8187609588788842, 0.859091682929604, 0.9729496756385605], 
             UndirectedEdge[208, 497] -> 
             RGBColor[
              0.97022907601952, 0.9768761192085936, 0.915513811829954], 
             UndirectedEdge[275, 444] -> 
             RGBColor[
              0.9753933121596595, 0.9801460971249234, 0.8807313068645775], 
             UndirectedEdge[269, 323] -> 
             RGBColor[
              0.9938552811030109, 0.9906047921112332, 0.6699236619593585], 
             UndirectedEdge[273, 279] -> 
             RGBColor[
              0.9414345120288503, 0.8675121628626713, 0.6176625688277999], 
             UndirectedEdge[107, 289] -> 
             RGBColor[
              0.971029209868017, 0.9745847627175199, 0.7334284751330985], 
             UndirectedEdge[289, 314] -> 
             RGBColor[
              0.9911039103372787, 0.9812559646909729, 0.45374790932426745`], 
             UndirectedEdge[6, 428] -> 
             RGBColor[
              0.9911091900649587, 0.9897196776948898, 0.7336396439775383], 
             UndirectedEdge[7, 17] -> 
             RGBColor[
              0.9173968975791875, 0.9369714003269798, 0.9919833291326232], 
             UndirectedEdge[309, 424] -> 
             RGBColor[
              0.9190317523623596, 0.9331893568520842, 0.7180091812432576], 
             UndirectedEdge[128, 385] -> 
             RGBColor[
              0.8842854883920441, 0.7115035975338149, 0.6015608883253067], 
             UndirectedEdge[71, 362] -> 
             RGBColor[
              0.8881292057772988, 0.913634137334484, 0.9891917505609822], 
             UndirectedEdge[43, 156] -> 
             RGBColor[
              0.9351513831470762, 0.8583382621767337, 0.6248162834470985], 
             UndirectedEdge[59, 298] -> 
             RGBColor[
              0.9772527967876163, 0.9816197807034412, 0.8814744821184262], 
             UndirectedEdge[261, 455] -> 
             RGBColor[
              0.990218141579392, 0.9902229644078533, 0.81177423887498], 
             UndirectedEdge[17, 89] -> 
             RGBColor[
              0.9510292343983144, 0.9611566481770037, 0.8918346099766334], 
             UndirectedEdge[9, 68] -> 
             RGBColor[
              0.6455332791803617, 0.7127258239671159, 0.8981181972755226], 
             UndirectedEdge[73, 298] -> 
             RGBColor[
              0.9700324813793332, 0.9771708541967905, 0.9356113716308756], 
             UndirectedEdge[16, 333] -> 
             RGBColor[
              0.8960493252185282, 0.9191224623313489, 0.961275843281721], 
             UndirectedEdge[257, 445] -> 
             RGBColor[
              0.5753473070255529, 0.29865096688533577`, 0.553340688614112], 
             UndirectedEdge[428, 451] -> 
             RGBColor[
              0.8850568349839798, 0.9074843442710918, 0.7980784910525618], 
             UndirectedEdge[15, 419] -> 
             RGBColor[
              0.9800969022303769, 0.944441025873433, 0.3842633104094264], 
             UndirectedEdge[17, 313] -> 
             RGBColor[
              0.8532280349787962, 0.8860004490518391, 0.9858109506678209], 
             UndirectedEdge[5, 326] -> 
             RGBColor[
              0.9464231020996885, 0.9588395931745926, 0.9502666128055707], 
             UndirectedEdge[216, 217] -> 
             RGBColor[
              0.926981428054654, 0.9441420753439567, 0.9765409682932371], 
             UndirectedEdge[138, 222] -> 
             RGBColor[
              0.990582567473069, 0.990373663880207, 0.8057347587127726], 
             UndirectedEdge[251, 447] -> 
             RGBColor[
              0.7112992009362477, 0.7679749057532088, 0.799309414240782], 
             UndirectedEdge[58, 144] -> 
             RGBColor[
              0.8113690652501357, 0.851458034463312, 0.8910425344239562], 
             UndirectedEdge[11, 404] -> 
             RGBColor[
              0.8412550130261656, 0.5302797488603299, 0.5775564362265945], 
             UndirectedEdge[270, 329] -> 
             RGBColor[
              0.6334574467470022, 0.6982306663726785, 0.8504090685943715], 
             UndirectedEdge[314, 406] -> 
             RGBColor[
              0.8895585575947669, 0.9053392304608598, 0.6958560630416617], 
             UndirectedEdge[13, 409] -> 
             RGBColor[
              0.8415376641864916, 0.8337573246925316, 0.6413208036042279], 
             UndirectedEdge[279, 335] -> 
             RGBColor[
              0.9551959023399548, 0.9661057578418908, 0.9607258299449914], 
             UndirectedEdge[195, 446] -> 
             RGBColor[
              0.9920493994531021, 0.9900425755932363, 0.7132675000388047], 
             UndirectedEdge[22, 170] -> 
             RGBColor[
              0.8279838179946399, 0.866306875825916, 0.9743865249672591], 
             UndirectedEdge[159, 166] -> 
             RGBColor[
              0.9029544644363432, 0.9252269294182418, 0.982684711321764], 
             UndirectedEdge[59, 87] -> 
             RGBColor[
              0.9876151474608948, 0.9891465594459571, 0.8549125877513188], 
             UndirectedEdge[176, 407] -> 
             RGBColor[
              0.9870824623695645, 0.9678841466339787, 0.42167403243560797`], 
             UndirectedEdge[169, 470] -> 
             RGBColor[
              0.994153484536991, 0.9909314230161361, 0.6797605950495781], 
             UndirectedEdge[13, 188] -> 
             RGBColor[
              0.9499050157557304, 0.9193263357795461, 0.6506755403576507], 
             UndirectedEdge[273, 396] -> 
             RGBColor[
              0.861828868447821, 0.804634729031751, 0.622448194483201], 
             UndirectedEdge[30, 405] -> 
             RGBColor[
              0.9449770272942297, 0.9579758466026395, 0.9603870849017606], 
             UndirectedEdge[258, 497] -> 
             RGBColor[
              0.9906463074410727, 0.9896771181661157, 0.7521309454887095], 
             UndirectedEdge[90, 485] -> 
             RGBColor[
              0.7934232552065776, 0.8359182284033229, 0.8490553457019964], 
             UndirectedEdge[89, 455] -> 
             RGBColor[
              0.9925416212961724, 0.9911837829814469, 0.7732681669951751], 
             UndirectedEdge[422, 451] -> 
             RGBColor[
              0.8844329472012264, 0.9080981088003856, 0.8717855417146515], 
             UndirectedEdge[99, 178] -> 
             RGBColor[
              0.9197882757296509, 0.9356972306358938, 0.8650272805795611], 
             UndirectedEdge[119, 416] -> 
             RGBColor[
              0.6421059530099262, 0.7118277890351496, 0.937962890528685], 
             UndirectedEdge[129, 204] -> 
             RGBColor[
              0.641612622392767, 0.7135796802609675, 0.9685095343734196], 
             UndirectedEdge[1, 381] -> 
             RGBColor[
              0.9907903364715622, 0.9904361787164044, 0.8005903388292608], 
             UndirectedEdge[287, 409] -> 
             RGBColor[
              0.8574062287069965, 0.8860462689331353, 0.8083610619418824], 
             UndirectedEdge[340, 384] -> 
             RGBColor[
              0.9818499585878749, 0.9856623288289621, 0.9011885196505536], 
             UndirectedEdge[233, 379] -> 
             RGBColor[
              0.9644585648131202, 0.9724125254460764, 0.9181186277217364], 
             UndirectedEdge[1, 124] -> 
             RGBColor[
              0.8575177024308531, 0.888303064793396, 0.924937508524863], 
             UndirectedEdge[134, 309] -> 
             RGBColor[
              0.9192106843283928, 0.9354583817480516, 0.874599464857039], 
             UndirectedEdge[1, 380] -> 
             RGBColor[
              0.9491382125069991, 0.8386169885653061, 0.5621460025247149], 
             UndirectedEdge[112, 403] -> 
             RGBColor[
              0.8216321247076905, 0.861081526306245, 0.9827243814790976], 
             UndirectedEdge[214, 268] -> 
             RGBColor[
              0.9935186878730429, 0.9893766106640364, 0.5963436970345017], 
             UndirectedEdge[404, 444] -> 
             RGBColor[
              0.8911348250268117, 0.5694146089307097, 0.5601959572483967], 
             UndirectedEdge[252, 320] -> 
             RGBColor[
              0.9643923434581159, 0.9711161632177467, 0.862892317423755], 
             UndirectedEdge[173, 419] -> 
             RGBColor[
              0.7103342472268237, 0.7659109673405367, 0.6942801579739827], 
             UndirectedEdge[407, 475] -> 
             RGBColor[
              0.9791590313403207, 0.9413606603980635, 0.37353720155418313`], 
             UndirectedEdge[167, 305] -> 
             RGBColor[
              0.9082139459599858, 0.9238831941237782, 0.7034525620004675], 
             UndirectedEdge[407, 482] -> 
             RGBColor[
              0.9399393758889507, 0.935314681126884, 0.686080581284398], 
             UndirectedEdge[197, 493] -> 
             RGBColor[
              0.7028850990397784, 0.7352726064066792, 0.6497331628935273], 
             UndirectedEdge[235, 300] -> 
             RGBColor[
              0.806066741227975, 0.8411086873630652, 0.6896522586113027], 
             UndirectedEdge[312, 385] -> 
             RGBColor[
              0.8637818383641008, 0.8942202074508824, 0.9868694769219599], 
             UndirectedEdge[188, 318] -> 
             RGBColor[
              0.81863231114861, 0.8591526628148269, 0.9811109681870228], 
             UndirectedEdge[71, 153] -> 
             RGBColor[
              0.8741347024012432, 0.9024753002130919, 0.9878569423359334], 
             UndirectedEdge[45, 481] -> 
             RGBColor[
              0.9913266935618215, 0.9906813791410742, 0.793402663685558], 
             UndirectedEdge[53, 317] -> 
             RGBColor[
              0.84330361035357, 0.8755252295438315, 0.8466851822849065], 
             UndirectedEdge[253, 301] -> 
             RGBColor[
              0.9176325190570267, 0.9356951763539907, 0.9393748486432756], 
             UndirectedEdge[442, 447] -> 
             RGBColor[
              0.7106060792573227, 0.7683043543509934, 0.8555781813293539], 
             UndirectedEdge[118, 464] -> 
             RGBColor[
              0.7764405352813764, 0.8256173507762654, 0.9782626083612704], 
             UndirectedEdge[2, 118] -> 
             RGBColor[
              0.922885704871617, 0.9252996811451736, 0.6897252468385058], 
             UndirectedEdge[332, 454] -> 
             RGBColor[
              0.899881525581868, 0.9221781548787682, 0.961641361973422], 
             UndirectedEdge[84, 455] -> 
             RGBColor[
              0.9756744014739623, 0.9302445015154794, 0.5221074178582963], 
             UndirectedEdge[423, 488] -> 
             RGBColor[
              0.717059033826817, 0.7729737124517129, 0.8005250390112448], 
             UndirectedEdge[5, 231] -> 
             RGBColor[
              0.9876972578619372, 0.9891805142069292, 0.853551805911142], 
             UndirectedEdge[121, 337] -> 
             RGBColor[
              0.6251484152237379, 0.6700219694087957, 0.6531527955409397], 
             UndirectedEdge[23, 360] -> 
             RGBColor[
              0.9495839679672267, 0.9619203863754092, 0.9702253710111197], 
             UndirectedEdge[79, 336] -> 
             RGBColor[
              0.9221901598731459, 0.700486975497121, 0.4977201037139823], 
             UndirectedEdge[237, 371] -> 
             RGBColor[
              0.6627499226235705, 0.6584285145614333, 0.6092238134411527], 
             UndirectedEdge[9, 330] -> 
             RGBColor[
              0.9638804651430742, 0.9720212876623558, 0.920884361610789], 
             UndirectedEdge[76, 111] -> 
             RGBColor[
              0.9727894356633944, 0.9792269861877452, 0.930944567156798], 
             UndirectedEdge[91, 256] -> 
             RGBColor[
              0.9194971345588776, 0.93640092497683, 0.9056370196738535], 
             UndirectedEdge[35, 193] -> 
             RGBColor[
              0.8558561319781446, 0.8860701484233947, 0.8823802476894925], 
             UndirectedEdge[43, 267] -> 
             RGBColor[
              0.9447050701173105, 0.8654633862764076, 0.6086443834071207], 
             UndirectedEdge[261, 448] -> 
             RGBColor[
              0.9889043009337665, 0.9896796575367226, 0.8335479784835937], 
             UndirectedEdge[322, 374] -> 
             RGBColor[
              0.9875173215218658, 0.9881533471351103, 0.8064285271791305], 
             UndirectedEdge[76, 130] -> 
             RGBColor[
              0.934847115244787, 0.9501673200749425, 0.9687400157578238], 
             UndirectedEdge[107, 153] -> 
             RGBColor[
              0.8933755935308336, 0.9174767576582297, 0.9778796349393208], 
             UndirectedEdge[410, 437] -> 
             RGBColor[
              0.6872714513781286, 0.7541532908027162, 0.9705252206425592], 
             UndirectedEdge[11, 164] -> 
             RGBColor[
              0.7544172111781846, 0.8084046429152463, 0.9760696308760545], 
             UndirectedEdge[213, 500] -> 
             RGBColor[
              0.8558440314992217, 0.8880621171112462, 0.9766891007839085], 
             UndirectedEdge[251, 454] -> 
             RGBColor[
              0.9811677797923286, 0.9831356606700701, 0.7947845966072005], 
             UndirectedEdge[111, 483] -> 
             RGBColor[
              0.9323773611315168, 0.9477219050576129, 0.9519977581254001], 
             UndirectedEdge[5, 233] -> 
             RGBColor[
              0.9860694623927548, 0.9885073789479868, 0.8805285894351291], 
             UndirectedEdge[69, 372] -> 
             RGBColor[
              0.9942119006158756, 0.991317034952973, 0.7050664803638724], 
             UndirectedEdge[454, 489] -> 
             RGBColor[
              0.9596697736071947, 0.9694423637077064, 0.9531527328620586], 
             UndirectedEdge[289, 493] -> 
             RGBColor[
              0.9832121823471701, 0.9546353131144865, 0.4230900363104767], 
             UndirectedEdge[74, 268] -> 
             RGBColor[
              0.9932482829445505, 0.987967084858729, 0.5064954491611294], 
             UndirectedEdge[192, 258] -> 
             RGBColor[
              0.9937266392797112, 0.9889902406903934, 0.5585615841702758], 
             UndirectedEdge[68, 368] -> 
             RGBColor[
              0.6465603323434858, 0.71315053684413, 0.8810972684341727], 
             UndirectedEdge[50, 414] -> 
             RGBColor[
              0.8801927768703229, 0.9043180688556073, 0.848338917349249], 
             UndirectedEdge[358, 441] -> 
             RGBColor[
              0.990034064649326, 0.9895874188542727, 0.7741605771684977], 
             UndirectedEdge[71, 289] -> 
             RGBColor[
              0.9517883187384266, 0.9595833052723821, 0.7434057825297109], 
             UndirectedEdge[54, 321] -> 
             RGBColor[
              0.9882374639879221, 0.989403903322688, 0.8445991923949313], 
             UndirectedEdge[75, 408] -> 
             RGBColor[
              0.9593249058035422, 0.966515569081662, 0.8189292899290571], 
             UndirectedEdge[8, 239] -> 
             RGBColor[
              0.5855969007950432, 0.6454851236506687, 0.6789797068899064], 
             UndirectedEdge[389, 472] -> 
             RGBColor[
              0.9857974312463944, 0.9862736973517876, 0.761973754517562], 
             UndirectedEdge[178, 475] -> 
             RGBColor[
              0.9856187431392726, 0.9629619490313353, 0.5550220638496768], 
             UndirectedEdge[332, 489] -> 
             RGBColor[
              0.891783607462381, 0.9161387408043788, 0.97534902507441], 
             UndirectedEdge[28, 406] -> 
             RGBColor[
              0.8926306355683336, 0.9140346186017205, 0.8495786068658687], 
             UndirectedEdge[77, 87] -> 
             RGBColor[
              0.9760165099553175, 0.9814322874879888, 0.9164608345251977], 
             UndirectedEdge[274, 300] -> 
             RGBColor[
              0.7881930200626114, 0.8347563884479343, 0.9627995456709306], 
             UndirectedEdge[330, 333] -> 
             RGBColor[
              0.8822603595291689, 0.9088386742975838, 0.9846169654555759], 
             UndirectedEdge[325, 490] -> 
             RGBColor[
              0.8319484323760331, 0.8669740044216017, 0.8609859889974447], 
             UndirectedEdge[420, 489] -> 
             RGBColor[
              0.9542420734408035, 0.9653943938106551, 0.9623404134728354], 
             UndirectedEdge[271, 304] -> 
             RGBColor[
              0.9503630071524132, 0.8365518132266995, 0.3016316994226398], 
             UndirectedEdge[166, 387] -> 
             RGBColor[
              0.7908257100085321, 0.8368526702380361, 0.9796970484769207], 
             UndirectedEdge[16, 165] -> 
             RGBColor[
              0.9464509892923411, 0.9593113811470821, 0.9660831989951779], 
             UndirectedEdge[44, 356] -> 
             RGBColor[
              0.9315610210216481, 0.8796255339571025, 0.6335578516564363], 
             UndirectedEdge[86, 377] -> 
             RGBColor[
              0.9938816127538299, 0.9893217132813117, 0.5754294904426838], 
             UndirectedEdge[113, 353] -> 
             RGBColor[
              0.9693357918413466, 0.9749407264806458, 0.8601893078005212], 
             UndirectedEdge[63, 222] -> 
             RGBColor[
              0.8116419265775718, 0.8506817021944899, 0.8493498286342571], 
             UndirectedEdge[71, 493] -> 
             RGBColor[
              0.941853304726726, 0.9264677475134868, 0.6710030206961974], 
             UndirectedEdge[106, 270] -> 
             RGBColor[
              0.6154876667836202, 0.6863297659993808, 0.9480420248510621], 
             UndirectedEdge[414, 498] -> 
             RGBColor[
              0.9904562869558591, 0.9778015040888463, 0.5592130073229858], 
             UndirectedEdge[46, 220] -> 
             RGBColor[
              0.8116756757173064, 0.8001639047852591, 0.6251354881547413], 
             UndirectedEdge[302, 443] -> 
             RGBColor[
              0.9887162921497734, 0.9873341993967206, 0.6718250709060959], 
             UndirectedEdge[90, 267] -> 
             RGBColor[
              0.9768351193731226, 0.9804942730255775, 0.8457287143539847], 
             UndirectedEdge[116, 187] -> 
             RGBColor[
              0.8951605112849074, 0.9175210972860346, 0.9201276782129011], 
             UndirectedEdge[162, 472] -> 
             RGBColor[
              0.7164978203632866, 0.7757862100784423, 0.936642841883357], 
             UndirectedEdge[271, 371] -> 
             RGBColor[
              0.6767000522310328, 0.7093750486302906, 0.6431610002914789], 
             UndirectedEdge[84, 478] -> 
             RGBColor[
              0.9408278115258615, 0.8026080453013619, 0.27385596309394183`], 
             UndirectedEdge[5, 163] -> 
             RGBColor[
              0.969850480462439, 0.9770125996825861, 0.934911026000653], 
             UndirectedEdge[188, 430] -> 
             RGBColor[
              0.960512231441061, 0.955106964978848, 0.6918825702905564], 
             UndirectedEdge[380, 487] -> 
             RGBColor[
              0.7861349257896904, 0.7115931309231716, 0.6073948584181073], 
             UndirectedEdge[88, 304] -> 
             RGBColor[
              0.9553081572631896, 0.8532329657268115, 0.3208426737897673], 
             UndirectedEdge[41, 494] -> 
             RGBColor[
              0.7930902857065416, 0.8386368132851476, 0.9606264238116631], 
             UndirectedEdge[23, 136] -> 
             RGBColor[
              0.9735678234773744, 0.9771587249244285, 0.7831393854064596], 
             UndirectedEdge[7, 84] -> 
             RGBColor[
              0.9408919947059784, 0.9055836701861537, 0.6413157723524663], 
             UndirectedEdge[218, 493] -> 
             RGBColor[
              0.9811688963255782, 0.9481404069320776, 0.38134514749075393`], 
             UndirectedEdge[40, 183] -> 
             RGBColor[
              0.4876217389756706, 0.5930587252478856, 0.9533186699277942], 
             UndirectedEdge[192, 453] -> 
             RGBColor[
              0.9804420720656236, 0.9453762188286374, 0.40508914751071046`], 
             UndirectedEdge[49, 397] -> 
             RGBColor[
              0.8427352878009805, 0.8743096450700668, 0.7848267797157757], 
             UndirectedEdge[291, 467] -> 
             RGBColor[
              0.9493494204176963, 0.961405727120349, 0.9588436051254907], 
             UndirectedEdge[347, 462] -> 
             RGBColor[
              0.7777573176964313, 0.8258281370144944, 0.9497453673356238], 
             UndirectedEdge[31, 226] -> 
             RGBColor[
              0.5932281752225681, 0.6486973051471592, 0.6714875270197656], 
             UndirectedEdge[120, 381] -> 
             RGBColor[
              0.9906738889436666, 0.9903880246710546, 0.8025201757230342], 
             UndirectedEdge[151, 274] -> 
             RGBColor[
              0.9739387642881467, 0.9770405691528945, 0.7511855641770591], 
             UndirectedEdge[316, 418] -> 
             RGBColor[
              0.7542192458251047, 0.8079210742079277, 0.976137183910416], 
             UndirectedEdge[235, 389] -> 
             RGBColor[
              0.9920916855486355, 0.9839900488400386, 0.508427484448557], 
             UndirectedEdge[218, 310] -> 
             RGBColor[
              0.9913169574578133, 0.9817116509394282, 0.47693677362003384`], 
             UndirectedEdge[408, 463] -> 
             RGBColor[
              0.9590442632483289, 0.967054352322145, 0.8711799385971337], 
             UndirectedEdge[12, 273] -> 
             RGBColor[
              0.9372037613172408, 0.8643568759091715, 0.6248241262260466], 
             UndirectedEdge[121, 454] -> 
             RGBColor[
              0.6202343668624117, 0.689719120769904, 0.9391431813633008], 
             UndirectedEdge[47, 228] -> 
             RGBColor[
              0.8844250990739264, 0.6854902657678015, 0.5967915802005226], 
             UndirectedEdge[438, 439] -> 
             RGBColor[
              0.8370430210572923, 0.8734584310786357, 0.9790574487848515], 
             UndirectedEdge[172, 201] -> 
             RGBColor[
              0.9500999145157794, 0.8396036900765114, 0.549090397292588], 
             UndirectedEdge[58, 375] -> 
             RGBColor[
              0.8130382982244618, 0.850343932853042, 0.7322202028270648], 
             UndirectedEdge[168, 280] -> 
             RGBColor[
              0.926524377908357, 0.9423045444941358, 0.9193467575270455], 
             UndirectedEdge[77, 301] -> 
             RGBColor[
              0.9082942889910719, 0.928915640962128, 0.9634622943956717], 
             UndirectedEdge[283, 477] -> 
             RGBColor[
              0.7898498676438248, 0.8364721644902584, 0.9794984597611556], 
             UndirectedEdge[125, 149] -> 
             RGBColor[
              0.9283303503078408, 0.9445064246547528, 0.9520103302158197], 
             UndirectedEdge[7, 407] -> 
             RGBColor[
              0.9527290433734559, 0.945512814812753, 0.6873004711865409], 
             UndirectedEdge[401, 437] -> 
             RGBColor[
              0.7517641100593291, 0.7661006509925898, 0.6394278656402583], 
             UndirectedEdge[138, 438] -> 
             RGBColor[
              0.9638388058091296, 0.972200931240522, 0.9303910404940781], 
             UndirectedEdge[45, 399] -> 
             RGBColor[
              0.9939297893107615, 0.9900359849320886, 0.6251029521380475], 
             UndirectedEdge[97, 317] -> 
             RGBColor[
              0.5457434912631045, 0.6399030616100515, 0.9582944326423428], 
             UndirectedEdge[71, 201] -> 
             RGBColor[
              0.9491734572067784, 0.9603436593096994, 0.9206105165959668], 
             UndirectedEdge[107, 236] -> 
             RGBColor[
              0.964340629104079, 0.9729258800894589, 0.9452461928600532], 
             UndirectedEdge[134, 225] -> 
             RGBColor[
              0.9930269765885663, 0.989380040454203, 0.6195222614079267], 
             UndirectedEdge[59, 91] -> 
             RGBColor[
              0.9197227603134814, 0.9364942270246761, 0.9018978170193332], 
             UndirectedEdge[161, 287] -> 
             RGBColor[
              0.9903381424484419, 0.9896077035277785, 0.7614554424937384], 
             UndirectedEdge[101, 486] -> 
             RGBColor[
              0.9677121461631853, 0.9754403519917878, 0.939539093911467], 
             UndirectedEdge[185, 330] -> 
             RGBColor[
              0.9440807542056084, 0.9578160985626798, 0.9795408764415157], 
             UndirectedEdge[237, 432] -> 
             RGBColor[
              0.9403102524558469, 0.8010570719563455, 0.2708304319087675], 
             UndirectedEdge[99, 143] -> 
             RGBColor[
              0.9171932715696174, 0.9271325083451998, 0.6985560776724663], 
             UndirectedEdge[107, 411] -> 
             RGBColor[
              0.9387221888825144, 0.9536349018911197, 0.9822048336853477], 
             UndirectedEdge[187, 407] -> 
             RGBColor[
              0.9843420355289183, 0.9688630117495608, 0.620617519003941], 
             UndirectedEdge[185, 357] -> 
             RGBColor[
              0.9708843386686157, 0.9749292896457576, 0.7695833275204487], 
             UndirectedEdge[80, 208] -> 
             RGBColor[
              0.8807821395216884, 0.907411150145776, 0.9724520555845779], 
             UndirectedEdge[60, 240] -> 
             RGBColor[
              0.8407163029780402, 0.8684880495457131, 0.6928932656097768], 
             UndirectedEdge[262, 299] -> 
             RGBColor[
              0.9762895733172472, 0.9788472182923299, 0.7514448756157374], 
             UndirectedEdge[82, 282] -> 
             RGBColor[
              0.7173767939523384, 0.773653369229726, 0.835111267686065], 
             UndirectedEdge[286, 368] -> 
             RGBColor[
              0.9566543687338182, 0.9659809674403601, 0.9070912493066308], 
             UndirectedEdge[81, 454] -> 
             RGBColor[
              0.9514362728737806, 0.877950589769998, 0.603043557951329], 
             UndirectedEdge[68, 352] -> 
             RGBColor[
              0.648025454275736, 0.7114043047846377, 0.6858437386780041], 
             UndirectedEdge[196, 337] -> 
             RGBColor[
              0.9579800671447702, 0.944820142811701, 0.6783407814212037], 
             UndirectedEdge[261, 262] -> 
             RGBColor[
              0.9728447243282432, 0.9788441421260449, 0.9118598870589807], 
             UndirectedEdge[122, 286] -> 
             RGBColor[
              0.8590411740832823, 0.8906469253791316, 0.9863624311110732]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.9935299507465049, 0.9915924826080678, 0.7568889902885362], 
             316 -> RGBColor[
              0.7758421854528306, 0.824813078985535, 0.9782923564546483], 308 -> 
             RGBColor[
              0.5873839250597949, 0.6759037575646386, 0.9606601607203721], 
             160 -> RGBColor[
              0.9946481079241047, 0.9909611689459802, 0.6588577594672334], 
             245 -> RGBColor[
              0.7845426497999827, 0.8316099478595085, 0.9791595374303105], 
             155 -> RGBColor[
              0.9931111681921242, 0.9876738102677172, 0.4915713545336937], 
             425 -> RGBColor[
              0.7747555359792304, 0.8239641801579167, 0.9781840493904366], 
             213 -> RGBColor[
              0.9461083350392051, 0.9593282650285173, 0.976108710968012], 352 -> 
             RGBColor[
              0.9925555201289337, 0.9864853352451896, 0.43109249191776094`], 
             27 -> RGBColor[
              0.9643311918106083, 0.9729188417714405, 0.9452621677362588], 
             485 -> RGBColor[
              0.5921211284096414, 0.6797496326526229, 0.9610330907210196], 
             454 -> RGBColor[
              0.9677676917266818, 0.9754817777820959, 0.9394450697610706], 
             367 -> RGBColor[
              0.9903873686059662, 0.9902929441322779, 0.8089697090991411], 19 -> 
             RGBColor[
              0.38268957127153075`, 0.5058882049234454, 0.9456056189756892], 
             164 -> RGBColor[
              0.6481561481349929, 0.7250637761830142, 0.9655658055486667], 
             190 -> RGBColor[
              0.9873102863339923, 0.9688567574974063, 0.405203287969254], 103 -> 
             RGBColor[
              0.994610899788126, 0.9908815845054411, 0.6548078834879365], 138 -> 
             RGBColor[
              0.9863028559048419, 0.9886038931631745, 0.8766606549367995], 
             416 -> RGBColor[
              0.970559566822087, 0.9775639536569732, 0.9347191534621938], 476 -> 
             RGBColor[
              0.9664831537889692, 0.9745237714913877, 0.9416194574284674], 
             291 -> RGBColor[
              0.9761743407253711, 0.9817514428406939, 0.9252148058115024], 28 -> 
             RGBColor[
              0.9952047802628202, 0.9921518347902855, 0.7194481081529587], 
             337 -> RGBColor[
              0.9775957884493338, 0.936087475059879, 0.36746429811634845`], 
             195 -> RGBColor[
              0.9941950919451301, 0.9899922135738948, 0.6095497658463958], 
             114 -> RGBColor[
              0.9761743407253711, 0.9817514428406939, 0.9252148058115024], 
             479 -> RGBColor[
              0.9489988033300776, 0.9614839715471426, 0.9712159021064328], 93 -> 
             RGBColor[
              0.9874016970956646, 0.9890582922345103, 0.8584500126950219], 34 -> 
             RGBColor[
              0.6726723604834276, 0.7442160275997264, 0.9680093524785284], 
             161 -> RGBColor[
              0.9861649985359195, 0.9885468855983524, 0.8789453083032777], 22 -> 
             RGBColor[
              0.7103884990091678, 0.7736801616693041, 0.9717685446894204], 
             124 -> RGBColor[
              0.728709603892838, 0.7879927480499815, 0.9735946212037653], 84 -> 
             RGBColor[
              0.9576571117028954, 0.8688296365702102, 0.2900063040595978], 46 -> 
             RGBColor[
              0.9550597969597695, 0.859534100920057, 0.28269826163293027`], 
             241 -> RGBColor[
              0.6061712344080974, 0.6911561416522317, 0.9621391665324522], 
             185 -> RGBColor[
              0.9479717480632536, 0.960717995410794, 0.9729544387742511], 426 -> 
             RGBColor[
              0.6983579481675971, 0.7642818039162962, 0.9705694518134222], 
             390 -> RGBColor[
              0.968543419932224, 0.9055517104544626, 0.3322975558237309], 121 -> 
             RGBColor[
              0.2727010419981418, 0.4039564637577123, 0.938841292965531], 322 -> 
             RGBColor[
              0.9800616233174635, 0.9846505718330354, 0.9186346503487657], 
             488 -> RGBColor[
              0.4395345974338848, 0.5551245094711873, 0.9492277337766715], 
             126 -> RGBColor[
              0.9639317271966972, 0.8899953879805829, 0.31438200039130704`], 
             433 -> RGBColor[
              0.9916537228525268, 0.9908166141570504, 0.787982942013895], 236 -> 
             RGBColor[
              0.9797700348309949, 0.9844331056172595, 0.9191282335978996], 78 -> 
             RGBColor[
              0.9902852466032931, 0.9902507140597567, 0.8106621349667054], 
             376 -> RGBColor[
              0.9431722844587148, 0.9571385633129293, 0.981078678756149], 458 -> 
             RGBColor[
              0.9940311198639266, 0.9896414938723207, 0.5917024167257625], 
             254 -> RGBColor[
              0.9910919683377087, 0.9905843142287405, 0.7972926680985127], 
             290 -> RGBColor[
              0.6322255654245982, 0.7123082213056635, 0.9641902589102304], 
             251 -> RGBColor[
              0.9945678678579754, 0.9907895435580444, 0.6501241234533305], 
             165 -> RGBColor[
              0.9251342868580004, 0.9431409845120683, 0.9927213282292853], 
             460 -> RGBColor[
              0.9942440863096879, 0.9900970075655937, 0.6148825000703348], 
             100 -> 
             RGBColor[
              0.9533511591754248, 0.964729951410274, 0.9638484989364666], 235 -> 
             RGBColor[
              0.9900673727023126, 0.9781570572124152, 0.4159140478781056], 70 -> 
             RGBColor[
              0.9507938358239225, 0.9628227038419562, 0.968177380313808], 234 -> 
             RGBColor[
              0.9621434575423502, 0.8839631345307882, 0.30743491047055704`], 
             435 -> RGBColor[
              0.9214251301050693, 0.940183403599659, 0.9923675455469874], 257 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 135 -> 
             RGBColor[
              0.9927000684823609, 0.9912493049648429, 0.7706422870718564], 
             265 -> RGBColor[
              0.7319520726687019, 0.790525789301362, 0.9739178001887498], 111 -> 
             RGBColor[
              0.9820207455363814, 0.9861116819761362, 0.9153183674530466], 
             497 -> RGBColor[
              0.9868485829633816, 0.9888295653264264, 0.8676165452804411], 
             481 -> RGBColor[
              0.9880799026749177, 0.9893387476706198, 0.8472103911070209], 
             381 -> RGBColor[
              0.9952548719742562, 0.9922589758959982, 0.7249002818125609], 
             182 -> RGBColor[
              0.7765010407909959, 0.8253277817831959, 0.9783580249974034], 
             188 -> RGBColor[
              0.9370358741915064, 0.952562038583095, 0.9914660207064113], 154 -> 
             RGBColor[
              0.9425175770077859, 0.9566502835680116, 0.9821869276955205], 
             336 -> RGBColor[
              0.9911213320941188, 0.9905964568966302, 0.7968060346638334], 
             463 -> RGBColor[
              0.9939616487875964, 0.9917710008421927, 0.7497346365489328], 
             315 -> RGBColor[
              0.9844529643711835, 0.9878389154739629, 0.907318145015345], 368 -> 
             RGBColor[
              0.9896252762644333, 0.9899777993641742, 0.8215995514300981], 
             269 -> RGBColor[
              0.9937294088508911, 0.9916749636600709, 0.7535834533178283], 
             208 -> RGBColor[
              0.9536095690756585, 0.9649226730907609, 0.9634110783794669], 86 -> 
             RGBColor[
              0.9925555201289337, 0.9864853352451896, 0.43109249191776094`], 
             119 -> RGBColor[
              0.31365233919776553`, 0.4460916244133262, 0.9412066275951763], 
             436 -> RGBColor[
              0.9733286128201075, 0.9796291036284003, 0.930031880870407], 377 -> 
             RGBColor[
              0.9952077053787263, 0.9921580913174339, 0.7197664889676065], 
             140 -> 
             RGBColor[
              0.9803775439230509, 0.98488618490341, 0.9180998791687964], 85 -> 
             RGBColor[
              0.9203859716550642, 0.9393548068588295, 0.9922684296863582], 
             351 -> RGBColor[
              0.8964542941297087, 0.9202723368081922, 0.989985804919929], 443 -> 
             RGBColor[
              0.9847792465449773, 0.9879738415378959, 0.9019108050043838], 
             242 -> RGBColor[
              0.8814737500606024, 0.908327257603523, 0.9885569472533281], 117 -> 
             RGBColor[
              0.5741473511894406, 0.6651577105958275, 0.95961812913813], 47 -> 
             RGBColor[
              0.9119519007033887, 0.9326297076187208, 0.9914639804698034], 
             451 -> RGBColor[
              0.7758421854528306, 0.824813078985535, 0.9782923564546483], 81 -> 
             RGBColor[
              0.9351048540208795, 0.7804194017578999, 0.2666420461415875], 
             275 -> RGBColor[
              0.9903487260966506, 0.9902769644616086, 0.8096101154821082], 23 -> 
             RGBColor[
              0.9530112514304525, 0.9644764487706214, 0.9644238740865665], 
             328 -> RGBColor[
              0.9401940684259484, 0.9549174146720734, 0.9861200216564779], 
             418 -> RGBColor[
              0.7325963061973787, 0.7910290694303204, 0.9739820113661838], 
             110 -> RGBColor[
              0.9931102863408029, 0.9914189405914267, 0.7638439155476862], 6 -> 
             RGBColor[
              0.9879468956147884, 0.9892837458331307, 0.8494146623046014], 
             218 -> RGBColor[
              0.9890606243156869, 0.974761058508564, 0.4120030205045446], 108 -> 
             RGBColor[
              0.993128924622016, 0.9877117894758053, 0.4935040323474336], 297 -> 
             RGBColor[
              0.9906404535691125, 0.9903976012685257, 0.8047754362969178], 
             487 -> RGBColor[
              0.6603192275342505, 0.7345656662525415, 0.9667781076327452], 
             464 -> RGBColor[
              0.6912229555746355, 0.7587078934747225, 0.9698583024320526], 
             157 -> RGBColor[
              0.7965937153743471, 0.8410243318776925, 0.9803606750231524], 
             441 -> RGBColor[
              0.9946335315792718, 0.990929991618277, 0.657271214286938], 354 -> 
             RGBColor[
              0.9861300500153812, 0.9885324334869737, 0.8795244957324689], 
             385 -> RGBColor[
              0.8989810629575199, 0.9222871136841762, 0.9902268103863989], 
             270 -> RGBColor[
              0.27368855354372723`, 0.4049944010039708, 0.9388975302871596], 
             392 -> 
             RGBColor[
              0.8658289704366151, 0.8958525349975854, 0.9870647342065326], 33 -> 
             RGBColor[
              0.9652230670110583, 0.9735840008356245, 0.9437524556602038], 
             252 -> RGBColor[
              0.9950172934121445, 0.9922075370232727, 0.7322398731994558], 
             394 -> RGBColor[
              0.9948707542513443, 0.9914373869269488, 0.6830914381733986], 
             260 -> RGBColor[
              0.9914924348026353, 0.9907499174035064, 0.7906559024006914], 
             159 -> RGBColor[
              0.9445586799086506, 0.9581725347694773, 0.9787318728892521], 
             183 -> RGBColor[
              0.38505150402135535`, 0.5079339923571518, 0.9457561192419329], 
             99 -> RGBColor[
              0.8453259188235478, 0.8795039581818356, 0.985109134840388], 329 -> 
             RGBColor[
              0.9932263399502772, 0.991466931741386, 0.7619206069015835], 309 -> 
             RGBColor[
              0.8453259188235478, 0.8795039581818356, 0.985109134840388], 17 -> 
             RGBColor[
              0.9106669174493136, 0.9316050968518624, 0.9913414176199116], 
             349 -> RGBColor[
              0.9940990601543072, 0.989786811283628, 0.5990972980548324], 495 -> 
             RGBColor[
              0.9420558984844262, 0.9563059644812191, 0.982968429010525], 347 -> 
             RGBColor[
              0.5873839250597949, 0.6759037575646386, 0.9606601607203721], 
             340 -> RGBColor[
              0.9775698671603686, 0.9827922241709504, 0.9228525435686382], 
             404 -> RGBColor[
              0.821831751830955, 0.16881398807318154`, 0.1685394162497467], 
             277 -> RGBColor[
              0.9930254215122214, 0.9874904067897243, 0.48223835759344447`], 
             104 -> RGBColor[
              0.9940934597040991, 0.9897748324869252, 0.5984877236116537], 79 -> 
             RGBColor[
              0.8532589876521729, 0.4103774940976119, 0.19863417276413114`], 
             327 -> RGBColor[
              0.9901571299410277, 0.990197734527462, 0.812785359615737], 191 -> 
             RGBColor[
              0.9586725769666101, 0.968698656085918, 0.9548407266640306], 50 -> 
             RGBColor[
              0.7651807734778256, 0.8164843029209291, 0.9772297265455393], 
             225 -> RGBColor[
              0.9929585033438948, 0.9873472755941385, 0.47495472794216326`], 
             405 -> RGBColor[
              0.9739815097298934, 0.980116033074698, 0.9289266967049257], 61 -> 
             RGBColor[
              0.9863307559062481, 0.9655525713599432, 0.40139799722626757`], 
             196 -> RGBColor[
              0.9383643458402068, 0.953552810563523, 0.989217264726059], 1 -> 
             RGBColor[
              0.9863258009688682, 0.9886133815368107, 0.8762803958459606], 
             263 -> RGBColor[
              0.9930237089496222, 0.9913831386152361, 0.7652787269746547], 
             201 -> RGBColor[
              0.9879174732955742, 0.9892715789480165, 0.849902266276502], 371 -> 
             RGBColor[
              0.38268957127153075`, 0.5058882049234454, 0.9456056189756892], 
             293 -> RGBColor[
              0.8970097640595464, 0.9207152534524152, 0.9900387861377109], 
             362 -> RGBColor[
              0.8658289704366151, 0.8958525349975854, 0.9870647342065326], 
             184 -> RGBColor[
              0.598154912423452, 0.6846481303339066, 0.9615080923010659], 106 -> 
             RGBColor[
              0.9572867800235133, 0.9676651309947907, 0.9571865194149646], 
             206 -> RGBColor[
              0.9553550420522066, 0.9662244439787208, 0.9604564479224335], 
             358 -> RGBColor[
              0.98543459771938, 0.9882448460902684, 0.8910499400500574], 247 -> 
             RGBColor[
              0.6061712344080974, 0.6911561416522317, 0.9621391665324522], 
             220 -> RGBColor[
              0.6682915544748432, 0.7407937086504613, 0.9675727146765524], 
             407 -> RGBColor[
              0.9813312090378503, 0.9486879258234086, 0.38197570172774714`], 
             107 -> RGBColor[
              0.9489112233771633, 0.9614186545616582, 0.9713641521222067], 
             375 -> RGBColor[
              0.9931904265856476, 0.987843335957211, 0.5001981415426127], 131 -> 
             RGBColor[
              0.9834254693041098, 0.987159322662084, 0.9129405365249178], 411 -> 
             RGBColor[
              0.9285331543878653, 0.9458511492205812, 0.9930455152484887], 
             462 -> RGBColor[
              0.9681307103330677, 0.9757525164643501, 0.9388305739508753], 
             127 -> RGBColor[
              0.40012174927244104`, 0.520987081341092, 0.9467163819432375], 
             210 -> RGBColor[
              0.6913652332537679, 0.7588190418790111, 0.969872483341448], 357 -> 
             RGBColor[
              0.9937969292739779, 0.9891405838807213, 0.5662122162666461], 
             181 -> RGBColor[
              0.9935117669341854, 0.9885306504702404, 0.535174055398195], 194 -> 
             RGBColor[
              0.9724643854495774, 0.9187780478309799, 0.34752976644644107`], 
             440 -> RGBColor[
              0.5500874124086897, 0.6456247684057238, 0.9577240426228496], 
             490 -> RGBColor[
              0.9936916912450293, 0.9916593664607488, 0.7542085316569946], 
             118 -> RGBColor[
              0.8616581149881173, 0.8925268080778085, 0.9866669142904883], 
             348 -> RGBColor[
              0.9850962460682063, 0.9613882797995341, 0.39660215962309675`], 
             276 -> RGBColor[
              0.22846578593913205`, 0.35746240496246845`, 0.9363221605731673],
              305 -> RGBColor[
              0.992096933209597, 0.9850032413669544, 0.42379850719856343`], 
             343 -> RGBColor[
              0.9337673935040873, 0.9500247894122209, 0.9935447616480544], 
             280 -> RGBColor[
              0.8652388577564749, 0.8953819951646237, 0.987008448732301], 474 -> 
             RGBColor[
              0.9874882135394649, 0.9890940690073928, 0.8570162113238722], 
             189 -> RGBColor[
              0.9743378152726463, 0.9803817651650862, 0.9283235643604139], 
             168 -> RGBColor[
              0.9878098980602391, 0.989227093823648, 0.85168506632179], 363 -> 
             RGBColor[
              0.9950981115840459, 0.9919236812722451, 0.7078378807511541], 41 -> 
             RGBColor[
              0.6289718956281638, 0.7096667455887641, 0.9639341181052699], 14 -> 
             RGBColor[
              0.7570478091352061, 0.8101307693636564, 0.97641910866674], 77 -> 
             RGBColor[
              0.9666284890902792, 0.9746321623211399, 0.9413734426728669], 51 -> 
             RGBColor[
              0.8815304384573449, 0.9083724593923199, 0.9885623542432158], 
             438 -> RGBColor[
              0.9413747557134172, 0.9557979693178695, 0.9841214260513566], 
             179 -> RGBColor[
              0.2363694896793889, 0.365769698717239, 0.936772264808693], 467 -> 
             RGBColor[
              0.9225245001100215, 0.9410600114000041, 0.9924724044394789], 
             223 -> RGBColor[
              0.8751678975066621, 0.9032991419448188, 0.9879554894074323], 
             456 -> RGBColor[
              0.7571703113025756, 0.8102264689878564, 0.9764313185379355], 
             323 -> RGBColor[
              0.9939811533551307, 0.9895346205623955, 0.5862638706008888], 
             500 -> RGBColor[
              0.7655797279592382, 0.816795969193975, 0.977269490599805], 478 -> 
             RGBColor[
              0.9239985113488276, 0.7363864540325136, 0.25770562212828585`], 
             292 -> 
             RGBColor[
              0.8247864716915349, 0.8631263605672085, 0.9831500640371557], 
             491 -> RGBColor[
              0.9726935208807995, 0.9195509754440501, 0.34841991432814373`], 
             396 -> RGBColor[
              0.7904039247123122, 0.8361888203683595, 0.9797437345368432], 
             321 -> RGBColor[
              0.9922492164198458, 0.9910628660506233, 0.7781140725154678], 
             143 -> RGBColor[
              0.9890606243156869, 0.974761058508564, 0.4120030205045446], 112 -> 
             RGBColor[
              0.7617904993547786, 0.8138357950089671, 0.9768918157048669], 
             197 -> RGBColor[
              0.4324930297440872, 0.5490254574577673, 0.9487790513100914], 
             421 -> RGBColor[
              0.8709922277373823, 0.8999695762163314, 0.987557210297174], 54 -> 
             RGBColor[
              0.9842257115559985, 0.9877449405947528, 0.9110843122743948], 71 -> 
             RGBColor[
              0.9104294411179825, 0.9314157396713825, 0.9913187669154316], 
             177 -> RGBColor[
              0.7604444797303808, 0.8127842742482595, 0.9767576570479756], 
             158 -> RGBColor[
              0.990186684061624, 0.9902099559158348, 0.8122955713538424], 226 -> 
             RGBColor[
              0.9881251850306509, 0.9716056021485489, 0.4083690155250665], 
             432 -> RGBColor[
              0.9378102309360836, 0.79114531971327, 0.2688188559109187], 350 -> 
             RGBColor[
              0.9726603905062432, 0.9194392189112894, 0.34829120907913846`], 
             203 -> RGBColor[
              0.9928967975262167, 0.9872152930895403, 0.4682384304920681], 
             475 -> RGBColor[
              0.976986853642791, 0.9340333949727184, 0.3650987013806191], 115 -> 
             RGBColor[
              0.6919233911234834, 0.7592550790489898, 0.9699281153016194], 
             173 -> RGBColor[
              0.42803053401452, 0.5451602679483732, 0.9484947050282334], 212 -> 
             RGBColor[
              0.8063816153091803, 0.8486707136975791, 0.9813362414155312], 
             129 -> RGBColor[
              0.3498942154439241, 0.4774825160480841, 0.9435159279021487], 
             279 -> RGBColor[
              0.9496152118743706, 0.9619436880302, 0.9701724832260411], 26 -> 
             RGBColor[
              0.9888987776508573, 0.9896773735172977, 0.833639513575197], 40 -> 
             RGBColor[
              0.5901919739299859, 0.6781834581386196, 0.9608812206136554], 
             146 -> RGBColor[
              0.977106427336898, 0.982446591509419, 0.9236370263053097], 386 -> 
             RGBColor[
              0.964066166476729, 0.8904488832399745, 0.3149042716075031], 192 -> 
             RGBColor[
              0.9930092466406586, 0.987455810374982, 0.4804778226435734], 300 -> 
             RGBColor[
              0.6220661097536373, 0.7040603175137152, 0.9633904693445], 221 -> 
             RGBColor[
              0.9923676401014224, 0.991111837286305, 0.7761514856410796], 62 -> 
             RGBColor[
              0.8285826137706818, 0.8661533012175886, 0.9835121434575208], 
             286 -> RGBColor[
              0.923683461203203, 0.9419841355165461, 0.9925829471831634], 472 -> 
             RGBColor[
              0.9774788640978305, 0.9827243542359132, 0.9230065880161153], 
             152 -> RGBColor[
              0.9742364901224451, 0.9247557730025271, 0.35441405846664487`], 
             64 -> RGBColor[
              0.9509403104754203, 0.962931944397213, 0.9679294369355298], 307 -> 
             RGBColor[
              0.9934340465180126, 0.9883644143587862, 0.5267146677326], 37 -> 
             RGBColor[
              0.9940572141727555, 0.9896973069603666, 0.594542621206393], 148 -> 
             RGBColor[
              0.7696054106825146, 0.8199408631337204, 0.9776707330315172], 
             261 -> RGBColor[
              0.9867445919137549, 0.9887865623549577, 0.8693399460929653], 
             387 -> RGBColor[
              0.7203011710530286, 0.781424016409066, 0.9727565471995655], 15 -> 
             RGBColor[
              0.9675558440216263, 0.9022203850141659, 0.32846100989912097`], 
             136 -> RGBColor[
              0.9941243955242962, 0.9898410010782355, 0.6018548967263526], 
             198 -> RGBColor[
              0.9929376115378353, 0.9873025901334628, 0.4726807837818649], 63 -> 
             RGBColor[
              0.6284215741138477, 0.7092199697917405, 0.9638907947797688], 
             444 -> RGBColor[
              0.9604378982226685, 0.9700152297882381, 0.9518524982470467], 
             310 -> RGBColor[
              0.9935732905999399, 0.9886622433702925, 0.541870526735523], 171 -> 
             RGBColor[
              0.9573454842358038, 0.9677089125001976, 0.9570871484960676], 
             395 -> RGBColor[
              0.5008412274290204, 0.6056444969238769, 0.9538472025465305], 
             311 -> RGBColor[
              0.9946800893544954, 0.9910295739917669, 0.6623387407987374], 
             353 -> RGBColor[
              0.9944879887205925, 0.9919886559308059, 0.7410118217351029], 59 -> 
             RGBColor[
              0.9898257641014339, 0.9900607062370763, 0.8182769491251094], 
             397 -> RGBColor[
              0.9941053423481931, 0.9898002482611226, 0.5997810760901036], 
             229 -> RGBColor[
              0.9939438783512329, 0.991763652310077, 0.7500291386678903], 102 -> 
             RGBColor[
              0.9940010678979847, 0.989577215755891, 0.5884314456922328], 453 -> 
             RGBColor[
              0.9678748974905886, 0.9032966272822928, 0.32970047237784755`], 
             299 -> RGBColor[
              0.9936342898917631, 0.9887927146875277, 0.5485099232064785], 
             128 -> RGBColor[
              0.8695899138265684, 0.5007200813834536, 0.21289496626421464`], 
             12 -> RGBColor[
              0.9411537104511517, 0.9556331141232004, 0.9844955980225343], 
             222 -> RGBColor[
              0.9948622790412961, 0.9921434345972393, 0.7348088624887456], 
             483 -> RGBColor[
              0.8827339767266522, 0.9093321281390896, 0.9886771487977536], 92 -> 
             RGBColor[
              0.9741976606999332, 0.980277238114239, 0.9285608094938501], 271 -> 
             RGBColor[
              0.9707105331905348, 0.9128618923371357, 0.3407163816072688], 
             361 -> RGBColor[
              0.8208667492045488, 0.8600008802541184, 0.9827761974071694], 
             344 -> RGBColor[
              0.9391199490128591, 0.9541163381725005, 0.9879382256476283], 
             132 -> RGBColor[
              0.9932921781554087, 0.9880609722762682, 0.511273171973209], 80 -> 
             RGBColor[
              0.8079547099677182, 0.849899627200791, 0.9814930327896889], 324 -> 
             RGBColor[
              0.950974546666248, 0.9629574776922758, 0.967871483994687], 244 -> 
             RGBColor[
              0.9853265573604543, 0.9882001686253421, 0.8928404483969442], 
             150 -> RGBColor[
              0.9461721961047933, 0.8242977251474946, 0.2755470893662118], 
             125 -> RGBColor[
              0.9815749369953032, 0.9857791986961445, 0.9160730050276027], 
             258 -> RGBColor[
              0.9944440319187637, 0.9905246710058049, 0.6366453456969781], 
             133 -> RGBColor[
              0.992986043439436, 0.9913675629588146, 0.7659029419536576], 469 -> 
             RGBColor[
              0.9907549417647071, 0.9904449450796166, 0.8028780706099615], 
             255 -> RGBColor[
              0.9574222830700058, 0.8680375044510885, 0.289094039164488], 408 -> 
             RGBColor[
              0.9241268777090614, 0.9423377038020972, 0.9926252406453347], 
             326 -> RGBColor[
              0.9085186617317849, 0.9298921360555531, 0.9911365150718032], 
             176 -> RGBColor[
              0.9928337157012788, 0.9870803674445489, 0.46137236314346874`], 
             230 -> RGBColor[
              0.95651787210101, 0.8649867138868719, 0.2855805733336201], 274 -> 
             RGBColor[
              0.9543199303715855, 0.9654524593821533, 0.9622086219973611], 87 -> 
             RGBColor[
              0.9854045308203558, 0.9882324126548379, 0.8915482263775283], 
             439 -> RGBColor[
              0.7327112864011673, 0.7911188928394021, 0.9739934715183464], 
             130 -> RGBColor[
              0.9061361046991667, 0.9279923497505311, 0.9909092646550983], 35 -> 
             RGBColor[
              0.7203011710530286, 0.781424016409066, 0.9727565471995655], 379 -> 
             RGBColor[
              0.9411057473083227, 0.9555973432898109, 0.9845767871125526], 31 -> 
             RGBColor[
              0.19833116541448517`, 0.32578900814576967`, 0.9346060385144647],
              18 -> RGBColor[
              0.9148048130300681, 0.9349045424677728, 0.991736093794347], 24 -> 
             RGBColor[
              0.984838463031878, 0.9879983290770237, 0.9009294345690833], 151 -> 
             RGBColor[
              0.9935575982047079, 0.9886286789236357, 0.5401625063567569], 
             137 -> RGBColor[
              0.9233782651728333, 0.7339273846294816, 0.25720655749603183`], 
             330 -> RGBColor[
              0.9401897603479632, 0.9549142017145658, 0.9861273141087803], 
             296 -> RGBColor[
              0.9907549417647071, 0.9904449450796166, 0.8028780706099615], 
             266 -> RGBColor[
              0.7939254315201745, 0.8389398482511046, 0.9800947254250988], 
             302 -> RGBColor[
              0.9926533377545694, 0.9866945572555454, 0.44173933680780797`], 
             442 -> RGBColor[
              0.9931816245001254, 0.9914484407536136, 0.7626616576304743], 
             283 -> RGBColor[
              0.6711086956553597, 0.7429944807517468, 0.9678535009817452], 
             388 -> RGBColor[
              0.3154426693714862, 0.4476423184251921, 0.9413207058507189], 
             284 -> RGBColor[
              0.9529011411810641, 0.9643943287269165, 0.9646102620174288], 
             417 -> RGBColor[
              0.9681330034164781, 0.975754226642203, 0.9388266923587935], 318 -> 
             RGBColor[
              0.7002287481057137, 0.7657432870465589, 0.9707559156676343], 
             413 -> 
             RGBColor[
              0.7554619378949603, 0.8088918746977085, 0.9762610438423216], 
             238 -> RGBColor[
              0.9947985138596667, 0.9921170660559451, 0.7358656165673463], 72 -> 
             RGBColor[
              0.977176114869667, 0.9346718175316204, 0.3658339455080486], 437 -> 
             RGBColor[
              0.5376061099177774, 0.6354918847673315, 0.9567414687702475], 
             288 -> RGBColor[
              0.7846035379541767, 0.8316575141483319, 0.9791656061924884], 
             382 -> RGBColor[
              0.9504729272464657, 0.9625833707503285, 0.9687205948290808], 
             461 -> RGBColor[
              0.9317826962726594, 0.9484422457130515, 0.9933554594543607], 
             389 -> RGBColor[
              0.9941159983949583, 0.989823040467662, 0.6009409210190085], 172 -> 
             RGBColor[
              0.9122823557359845, 0.6899358012050061, 0.24827852830867408`], 
             447 -> RGBColor[
              0.42803053401452, 0.5451602679483732, 0.9484947050282334], 243 -> 
             RGBColor[
              0.9938177456297614, 0.9917114931882856, 0.752119484283691], 410 -> 
             RGBColor[
              0.8369367928384798, 0.872814696838101, 0.984308972514871], 88 -> 
             RGBColor[
              0.9806008334120878, 0.9462241973373597, 0.3791383303415238], 
             273 -> RGBColor[
              0.9332538121833299, 0.7730806376951426, 0.2651526544295589], 
             477 -> RGBColor[
              0.9085910396322898, 0.92994984822877, 0.9911434185405659], 202 -> 
             RGBColor[
              0.9856809024388418, 0.9883466994215084, 0.8869680334323946], 
             393 -> RGBColor[
              0.9877529241920022, 0.9892035336649705, 0.8526292707621194], 98 -> 
             RGBColor[
              0.956553060195872, 0.8651054115933988, 0.2857172724374447], 30 -> 
             RGBColor[
              0.915972544858566, 0.935835660130581, 0.9918474730985956], 116 -> 
             RGBColor[
              0.8029681605498283, 0.8460040968963563, 0.9809960201456673], 
             373 -> RGBColor[
              0.9497218455748215, 0.8383709024455909, 0.2784032206507784], 
             434 -> RGBColor[
              0.9748743388661192, 0.9807819035826215, 0.9274153698644286], 
             401 -> RGBColor[
              0.9659221102008808, 0.896709417217848, 0.3221142625102691], 240 -> 
             RGBColor[
              0.9900673727023126, 0.9781570572124152, 0.4159140478781056], 
             480 -> RGBColor[
              0.9300154811142914, 0.7602417341162633, 0.2625470172380107], 
             403 -> RGBColor[
              0.8814737500606024, 0.908327257603523, 0.9885569472533281], 317 -> 
             RGBColor[
              0.6913652332537679, 0.7588190418790111, 0.969872483341448], 429 -> 
             RGBColor[
              0.9797047156353299, 0.943201381657895, 0.37565708199646153`], 
             391 -> RGBColor[
              0.9595166211205104, 0.9693281428339013, 0.9534119800734494], 73 -> 
             RGBColor[
              0.9753851332848676, 0.9811628532237751, 0.9265507281500083], 
             303 -> RGBColor[
              0.9478583943520554, 0.8309829393056326, 0.27690384405611884`], 
             449 -> RGBColor[
              0.8043544897372197, 0.8470871077940384, 0.9811341964830836], 29 -> 
             RGBColor[
              0.821348616347189, 0.8603851080337245, 0.9828221583254023], 360 -> 
             RGBColor[
              0.9461566845040007, 0.959364323980197, 0.9760268679356731], 320 -> 
             RGBColor[
              0.9337673935040873, 0.9500247894122209, 0.9935447616480544], 
             482 -> RGBColor[
              0.8985475427400511, 0.9219414364303594, 0.9901854608410486], 75 -> 
             RGBColor[
              0.994522933898023, 0.9906934343612267, 0.6452333392127795], 200 -> 
             RGBColor[
              0.9845976511911618, 0.9878987471923055, 0.9049203099708166], 
             301 -> RGBColor[
              0.8499600888918647, 0.883199119603116, 0.9855511461184765], 156 -> 
             RGBColor[
              0.9398374828022629, 0.954651473697784, 0.9867236281049521], 25 -> 
             RGBColor[
              0.964832105757261, 0.9732924225726828, 0.9444142510838568], 38 -> 
             RGBColor[
              0.3154426693714862, 0.4476423184251921, 0.9413207058507189], 
             365 -> RGBColor[
              0.9933296858906753, 0.9915096679436102, 0.760207897218467], 380 -> 
             RGBColor[
              0.9119506240451302, 0.6886205955938016, 0.24801160920346915`], 
             370 -> RGBColor[
              0.9944440319187637, 0.9905246710058049, 0.6366453456969781], 3 -> 
             RGBColor[
              0.9933848484528064, 0.9882591846719976, 0.5213597619501679], 57 -> 
             RGBColor[
              0.47157355448808164`, 0.5818836815367823, 0.9515431441216013], 
             227 -> RGBColor[
              0.9941369643783522, 0.9918434983443754, 0.7468292035079036], 
             494 -> RGBColor[
              0.9572086757849193, 0.9676068809815312, 0.9573187295180563], 39 -> 
             RGBColor[
              0.9784982126551118, 0.9391315638052483, 0.37097004574728454`], 
             424 -> RGBColor[
              0.9927375859011713, 0.9868747555223326, 0.4509092276461272], 
             109 -> RGBColor[
              0.9852329485953335, 0.9618494095228137, 0.39713322312687954`], 
             465 -> RGBColor[
              0.9764744769985929, 0.9819752839818348, 0.9247067533890149], 
             256 -> RGBColor[
              0.9893745125922263, 0.9898741021413842, 0.8257553544341498], 
             457 -> RGBColor[
              0.9677942367334672, 0.9030245396084757, 0.3293871205679366], 
             339 -> RGBColor[
              0.9940901378687924, 0.9918241343792861, 0.7476052399544306], 
             420 -> RGBColor[
              0.9569122913938991, 0.9673858379879933, 0.9578204309826241], 
             287 -> RGBColor[
              0.9945112863609643, 0.9906685214572046, 0.6439655766841992], 
             239 -> RGBColor[
              0.9922668015900864, 0.9855762473013375, 0.4244584137798127], 
             427 -> RGBColor[
              0.9856654284383496, 0.9883403005246413, 0.8872244776659807], 
             285 -> RGBColor[
              0.9638438036013577, 0.9725553484430063, 0.9460871888433164], 
             345 -> RGBColor[
              0.9568230771258086, 0.9673193021329263, 0.9579714474676938], 
             366 -> RGBColor[
              0.7696054106825146, 0.8199408631337204, 0.9776707330315172], 
             216 -> RGBColor[
              0.9539936798272888, 0.9652091422604031, 0.9627608790690855], 21 -> 
             RGBColor[
              0.9852782492131028, 0.9881801919649494, 0.8936410394160358], 
             355 -> RGBColor[
              0.6913652332537679, 0.7588190418790111, 0.969872483341448], 175 -> 
             RGBColor[
              0.5741473511894406, 0.6651577105958275, 0.95961812913813], 7 -> 
             RGBColor[
              0.9241268777090614, 0.9423377038020972, 0.9926252406453347], 13 -> 
             RGBColor[
              0.9627741573199544, 0.8860906329759973, 0.3098850600088902], 
             294 -> RGBColor[
              0.9034551451895847, 0.9258546254102977, 0.9906535523437535], 
             412 -> RGBColor[
              0.9255983061846358, 0.9435109809276583, 0.9927655868068948], 
             193 -> RGBColor[
              0.9914110929032605, 0.9907162804377234, 0.7920039481794195], 60 -> 
             RGBColor[
              0.6913652332537679, 0.7588190418790111, 0.969872483341448], 65 -> 
             RGBColor[
              0.979107471801929, 0.9411867379683131, 0.37333690248373336`], 
             448 -> RGBColor[
              0.9910640099537781, 0.9905727527184875, 0.7977560108742223], 69 -> 
             RGBColor[
              0.9937879819606789, 0.9916991851462285, 0.752612745306297], 217 -> 
             RGBColor[
              0.8999691762820193, 0.9230750084275103, 0.9903210575173889], 
             214 -> RGBColor[
              0.9943185481365996, 0.9919185878949004, 0.7438198907100414], 
             170 -> RGBColor[
              0.945579136980112, 0.958933589982528, 0.9770045052450977], 359 -> 
             RGBColor[
              0.7758421854528306, 0.824813078985535, 0.9782923564546483], 74 -> 
             RGBColor[
              0.9937777382796147, 0.9890995362842856, 0.5641233949632969], 
             246 -> RGBColor[
              0.9934821092956677, 0.9915726989386774, 0.7576818469386144], 
             264 -> RGBColor[
              0.9788325981670138, 0.983733966888174, 0.92071506934738], 278 -> 
             RGBColor[
              0.9712464083310137, 0.978076198929731, 0.9335565099445364], 45 -> 
             RGBColor[
              0.9945734844487251, 0.9920240106115287, 0.7395949362640952], 
             492 -> RGBColor[
              0.9526148603882783, 0.9641808209803987, 0.9650948607256261], 
             306 -> RGBColor[
              0.9868158432935079, 0.9888160266315624, 0.8681591263377972], 
             237 -> RGBColor[
              0.9428102739756101, 0.8109688241994211, 0.2728420079066163], 
             228 -> RGBColor[
              0.8568982974444642, 0.43835082391688224`, 0.2021191799312418], 
             180 -> RGBColor[
              0.9532839954477023, 0.964679860812109, 0.9639621896083952], 383 -> 
             RGBColor[
              0.8187788594993523, 0.8583555350814869, 0.9825718828575737], 53 -> 
             RGBColor[
              0.9952419874533721, 0.9922314172086519, 0.723497881228365], 304 -> 
             RGBColor[
              0.9300154811142914, 0.7602417341162633, 0.2625470172380107], 48 -> 
             RGBColor[
              0.5032830972546972, 0.6076269168533435, 0.9540394354840718], 5 -> 
             RGBColor[
              0.984327542467592, 0.9877870502936319, 0.9093967105393381], 101 -> 
             RGBColor[
              0.9684234032986435, 0.9759708063988358, 0.938335121106707], 333 -> 
             RGBColor[
              0.8243309587103747, 0.8627631468806018, 0.9831066168023714], 
             267 -> RGBColor[
              0.9589448567427314, 0.9689017218971321, 0.9543798280249962], 
             120 -> 
             RGBColor[
              0.9860929059130769, 0.988517073446111, 0.8801400696335077], 147 -> 
             RGBColor[
              0.891889842658401, 0.916632767103706, 0.9895504434638618], 89 -> 
             RGBColor[
              0.9913915513473154, 0.9907081995021451, 0.7923278023333554], 43 -> 
             RGBColor[
              0.9304652834918896, 0.7620250506556833, 0.26290893878924504`], 
             199 -> RGBColor[
              0.9851978043385037, 0.9881469259419637, 0.894974219172804], 268 -> 
             RGBColor[
              0.9927188276094863, 0.9868346334331723, 0.44886750335896203`], 
             169 -> RGBColor[
              0.9942168312051898, 0.9900387116529861, 0.6119159501447256], 20 -> 
             RGBColor[
              0.780193731668043, 0.8282125399618351, 0.9787260779138692], 4 -> 
             RGBColor[
              0.9920465687178295, 0.9909790660180312, 0.7814724693733199], 
             167 -> RGBColor[
              0.8243309587103747, 0.8627631468806018, 0.9831066168023714], 
             431 -> RGBColor[
              0.9928953672895638, 0.9872122339579589, 0.4680827580588004], 
             142 -> RGBColor[
              0.9938546826500378, 0.9917267675954079, 0.7515073422677685], 16 -> 
             RGBColor[
              0.9677676917266818, 0.9754817777820959, 0.9394450697610706], 
             414 -> RGBColor[
              0.9952047802628202, 0.9921518347902855, 0.7194481081529587], 
             281 -> RGBColor[
              0.966862614859491, 0.9748067729364723, 0.9409771288153718], 289 -> 
             RGBColor[
              0.9931471963588707, 0.9877508708733818, 0.4954927981439902], 
             398 -> RGBColor[
              0.9468990966799409, 0.9599180137654248, 0.9747701577739131], 
             178 -> RGBColor[
              0.9942506326357541, 0.9918905030899521, 0.7449454263187344], 58 -> 
             RGBColor[
              0.6328861698632761, 0.712844529748873, 0.9642422641115169], 186 -> 
             RGBColor[
              0.9790107126884483, 0.9838668044066241, 0.9204135679222986], 
             122 -> RGBColor[
              0.7943988869633616, 0.8393097152417169, 0.980141915038983], 249 -> 
             RGBColor[
              0.9573997670793581, 0.9677493965560404, 0.9569952618011631], 
             113 -> RGBColor[
              0.9441835949621007, 0.9578927970304856, 0.9793667938659393], 52 -> 
             RGBColor[
              0.9850709220112933, 0.9880944568389353, 0.8970769876956168], 
             409 -> RGBColor[
              0.7203011710530286, 0.781424016409066, 0.9727565471995655], 187 -> 
             RGBColor[
              0.9873528620199864, 0.989038097675713, 0.859259336280135], 259 -> 
             RGBColor[
              0.9781501961616124, 0.9832250325898764, 0.9218701979435772], 42 -> 
             RGBColor[
              0.9952346037814678, 0.9922974004456097, 0.7286384779985604], 
             134 -> RGBColor[
              0.9930954498332378, 0.9914128053142677, 0.7640897948736901], 
             470 -> RGBColor[
              0.9940901378687924, 0.9918241343792861, 0.7476052399544306], 
             313 -> RGBColor[
              0.7957891525082786, 0.8403958012518157, 0.9802804837157302], 
             248 -> RGBColor[
              0.9401765625928236, 0.954904358850392, 0.9861496544657059], 174 -> 
             RGBColor[
              0.9535670147221379, 0.9648909361235816, 0.9634831118000243], 
             215 -> RGBColor[
              0.6829153499894759, 0.7522179288514548, 0.969030277946312], 399 -> 
             RGBColor[
              0.9932860941727978, 0.9880479592526484, 0.5106109680119997], 
             422 -> RGBColor[
              0.9930237089496222, 0.9913831386152361, 0.7652787269746547], 83 -> 
             RGBColor[
              0.7586003329792586, 0.8113436127902485, 0.9765738497343549], 95 -> 
             RGBColor[
              0.9914586828958115, 0.9907359601226503, 0.7912152588438948], 
             166 -> RGBColor[
              0.8613502489640357, 0.8922813240670063, 0.9866375497542761], 
             384 -> RGBColor[
              0.9861300500153812, 0.9885324334869737, 0.8795244957324689], 
             233 -> RGBColor[
              0.9878113823179177, 0.9892277076023418, 0.85166046833092], 295 -> 
             RGBColor[
              0.8320523829610544, 0.8689200009856161, 0.9838430931403981], 
             499 -> RGBColor[
              0.8480342444622402, 0.8816635035305879, 0.9853674573575573], 
             141 -> RGBColor[
              0.9931624689123215, 0.987783537320921, 0.4971551213358345], 319 -> 
             RGBColor[
              0.7274685174875397, 0.7870232019175566, 0.973470921309497], 205 -> 
             RGBColor[
              0.9851978043385037, 0.9881469259419637, 0.894974219172804], 468 -> 
             RGBColor[
              0.7758421854528306, 0.824813078985535, 0.9782923564546483], 486 -> 
             RGBColor[
              0.9670008890277272, 0.9749098975847397, 0.9407430667162268], 
             224 -> RGBColor[
              0.29763342953545374`, 0.43016198386409993`, 0.9402611555516188],
              231 -> 
             RGBColor[
              0.9910669732562823, 0.9905739781202264, 0.797706901282946], 332 -> 
             RGBColor[
              0.8319953594370542, 0.8688745319754406, 0.9838376541857734], 68 -> 
             RGBColor[
              0.3034953884225382, 0.4363232743240858, 0.9405949854382473], 
             484 -> RGBColor[
              0.9951801723255652, 0.9922748916397693, 0.7295405480869586], 10 -> 
             RGBColor[
              0.9872765015200164, 0.9890065206466001, 0.8605248273792769], 
             250 -> RGBColor[
              0.9286363305230558, 0.9459334190701406, 0.9930553562803696], 
             282 -> RGBColor[
              0.9952189904707921, 0.9921822289882649, 0.7209948015954586], 
             374 -> RGBColor[
              0.9949730197262681, 0.9916561224371852, 0.6942224040094953], 
             232 -> RGBColor[
              0.9843784385358765, 0.9878080971258368, 0.908553230973062], 489 -> 
             RGBColor[
              0.9515718554877077, 0.963402949633317, 0.9668603959630466], 253 -> 
             RGBColor[
              0.9853049492221886, 0.9881912331048655, 0.8931985511680747], 
             459 -> RGBColor[
              0.9737004582585178, 0.9229476116592332, 0.35233167589641085`], 
             415 -> RGBColor[
              0.9929894971661157, 0.9913689911635534, 0.7658457047646162], 55 -> 
             RGBColor[
              0.9912677017098207, 0.9906569844942505, 0.7943803113392284], 
             446 -> RGBColor[
              0.9899037069610742, 0.9900929376125777, 0.8169852342312136], 
             325 -> RGBColor[
              0.6702051735070369, 0.7422886423824544, 0.9677634463378949], 91 -> 
             RGBColor[
              0.849619756525529, 0.8829277478122759, 0.9855186849135571], 450 -> 
             RGBColor[
              0.5901919739299859, 0.6781834581386196, 0.9608812206136554], 
             423 -> RGBColor[
              0.9945834702197494, 0.9908229154322383, 0.6518223442458183], 
             105 -> RGBColor[
              0.8817141177931931, 0.9085189203088825, 0.9885798737422414], 36 -> 
             RGBColor[
              0.9767931160126324, 0.982212924436782, 0.9241673806526106], 123 -> 
             RGBColor[
              0.9904544174884021, 0.9903206705682428, 0.8078585356002324], 94 -> 
             RGBColor[
              0.9404457481670355, 0.9551051170108884, 0.9856939935034069], 
             473 -> RGBColor[
              0.99398091653354, 0.9895341140249593, 0.586238094032235], 312 -> 
             RGBColor[
              0.8285826137706818, 0.8661533012175886, 0.9835121434575208], 96 -> 
             RGBColor[
              0.9448164233515018, 0.9583647594071395, 0.978295580470761], 496 -> 
             RGBColor[
              0.6413502728973731, 0.7197160698954495, 0.9649085893073921], 2 -> 
             RGBColor[
              0.9841132947551167, 0.9580725542125387, 0.39278357938652314`], 
             262 -> RGBColor[
              0.9589448567427314, 0.9689017218971321, 0.9543798280249962], 
             272 -> RGBColor[
              0.9781626970620719, 0.9379997909271169, 0.3696666310251276], 97 -> 
             RGBColor[
              0.40012174927244104`, 0.520987081341092, 0.9467163819432375], 
             372 -> RGBColor[
              0.9946358192710725, 0.9909348847597176, 0.6575202154214479], 
             356 -> RGBColor[
              0.9174744548829143, 0.9370332424157347, 0.9919907266174889], 
             402 -> RGBColor[
              0.9457380875417631, 0.9590521350511498, 0.9767354434051683], 
             455 -> RGBColor[
              0.9936916912450293, 0.9916593664607488, 0.7542085316569946], 
             428 -> RGBColor[
              0.994271484515129, 0.9901556095566487, 0.6178646256504753], 346 -> 
             RGBColor[
              0.947443683052338, 0.9603241653902802, 0.9738483150963186], 341 -> 
             RGBColor[
              0.8573952180802753, 0.8891276897967493, 0.9862603153778853], 
             209 -> RGBColor[
              0.8306698123965767, 0.8678175767463797, 0.9837112223257228], 
             498 -> RGBColor[
              0.9857077936488978, 0.963451173387407, 0.39897790649301307`], 
             378 -> RGBColor[
              0.9860887044986558, 0.9885153360532765, 0.8802096979433761], 
             419 -> RGBColor[
              0.9926379604391274, 0.9866616667327001, 0.4400656109197319], 66 -> 
             RGBColor[
              0.9536326657922781, 0.9649398985841984, 0.9633719816628185], 
             139 -> RGBColor[
              0.9925418566819038, 0.986456110513579, 0.4296053100295783], 56 -> 
             RGBColor[
              0.9820947531072752, 0.9861668767013325, 0.9151930919397894], 
             335 -> RGBColor[
              0.960776592805539, 0.9702678276535814, 0.9512791766639417], 314 -> 
             RGBColor[
              0.9890606243156869, 0.974761058508564, 0.4120030205045446], 144 -> 
             RGBColor[
              0.9898519606369953, 0.9900715391777511, 0.8178428047363955], 
             298 -> RGBColor[
              0.9646798294737987, 0.9731788551698061, 0.944672015111743], 204 -> 
             RGBColor[
              0.9333310293416099, 0.949676844473851, 0.9935031408446904], 452 -> 
             RGBColor[
              0.8801253880061646, 0.9072521103016272, 0.9884283392768789], 
             466 -> RGBColor[
              0.9376895242084564, 0.9530495296954826, 0.9903595617269428], 
             207 -> RGBColor[
              0.8494564752775517, 0.8827975517772902, 0.9855031110023622], 
             334 -> RGBColor[
              0.8984993251847544, 0.9219029890605965, 0.9901808618075801], 
             149 -> RGBColor[
              0.8750857636203784, 0.903233650613361, 0.9879476554040367], 219 -> 
             RGBColor[
              0.9946610523489464, 0.9909888557618344, 0.6602666802275163], 
             400 -> RGBColor[
              0.9211995634025593, 0.725289558119672, 0.255453522910966], 9 -> 
             RGBColor[
              0.9875711699381853, 0.9891283736101459, 0.8556414091127977], 11 -> 
             RGBColor[
              0.8606782742213762, 0.8917455096474782, 0.9865734562034423], 44 -> 
             RGBColor[
              0.9456475871603818, 0.8222178254984703, 0.2751249766953837], 
             153 -> RGBColor[
              0.837839963684504, 0.8735348607548011, 0.984395117756435], 471 -> 
             RGBColor[
              0.9925834939447855, 0.9912010983977264, 0.7725742288447136], 
             406 -> RGBColor[
              0.790056490873847, 0.8359174024131556, 0.9797091055787788], 32 -> 
             RGBColor[
              0.9866110669390208, 0.9887313463464698, 0.8715528004758663], 
             162 -> RGBColor[
              0.4555167766287425, 0.5688480659209715, 0.9502790957505988], 
             493 -> RGBColor[
              0.9732771683354695, 0.9215197553555913, 0.35068727447696324`], 
             90 -> RGBColor[
              0.9947253820035139, 0.9920868241540229, 0.7370776006829731], 
             331 -> RGBColor[
              0.9944029528919028, 0.990436807121076, 0.6321741471335288], 8 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 364 -> 
             RGBColor[
              0.9812900682089203, 0.9485491481471018, 0.38181587737614786`], 
             342 -> RGBColor[
              0.6913652332537679, 0.7588190418790111, 0.969872483341448], 163 -> 
             RGBColor[
              0.9553734184572861, 0.9662381490715404, 0.9604253414619679], 49 -> 
             RGBColor[
              0.6913652332537679, 0.7588190418790111, 0.969872483341448], 338 -> 
             RGBColor[
              0.9942208898335783, 0.9900473926487187, 0.612357706797859], 76 -> 
             RGBColor[
              0.9635581257904074, 0.972342290399354, 0.9465707668605492], 369 -> 
             RGBColor[
              0.8560441762635235, 0.8880504057251245, 0.9861314518033143], 
             445 -> RGBColor[
              0.3333756140511058, 0.4631749337706715, 0.9424633772282239], 82 -> 
             RGBColor[
              0.4395345974338848, 0.5551245094711873, 0.9492277337766715], 67 -> 
             RGBColor[
              0.6289718956281638, 0.7096667455887641, 0.9639341181052699], 
             430 -> RGBColor[
              0.9839885886906158, 0.9576518913746008, 0.39229911987470145`], 
             211 -> RGBColor[
              0.990789424961678, 0.9904592047677417, 0.8023065947965011]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw1l3k4VA/cxYfs69jHPjOGGTNjV1rUPZUi6hcVbZKtXVmyRook2RJlqUih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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 42}], {
             RGBColor[
             0.990780202375168, 0.9904553909912102, 0.8024594369222605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 108}], {
             RGBColor[
             0.9897273627954422, 0.988162585506308, 0.6848922140966971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[
             0.9652546979654845, 0.9732530892836482, 0.9278235948559499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 119}], {
             RGBColor[
             0.6499890700833169, 0.7173525029750685, 0.9087435117205684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 120}], {
             RGBColor[
             0.9862093534409726, 0.9885652274914608, 0.8782102327397341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 124}], {
             RGBColor[
             0.8575177024308531, 0.888303064793396, 0.924937508524863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 315}], {
             RGBColor[
             0.9853893826700258, 0.9882261485053867, 0.8917992704306528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 363}], {
             RGBColor[
             0.990711956276457, 0.9902685314045279, 0.7920591382985573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 364}], {
             RGBColor[
             0.9838079345888943, 0.9685812648419563, 0.6290481366110543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 378}], {
             RGBColor[
             0.986207252733762, 0.9885643587950436, 0.8782450468946683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 380}], {
             RGBColor[
             0.9491382125069991, 0.8386169885653061, 0.5621460025247149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 381}], {
             RGBColor[
             0.9907903364715622, 0.9904361787164044, 0.8005903388292608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 416}], {
             RGBColor[
             0.9784426838954776, 0.983088667596892, 0.9054997746540772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 452}], {
             RGBColor[
             0.9332255944875164, 0.9479327459192189, 0.9323543675614198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 468}], {
             RGBColor[
             0.8810839932108494, 0.9067132302611729, 0.9272863761503045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 487}], {
             RGBColor[
             0.8233225142515594, 0.861589523894676, 0.921529251739353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[
             0.9688729802736974, 0.9615062263983685, 0.6780777805246707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 114}], {
             RGBColor[
             0.980143817740244, 0.9699119985266162, 0.6589991925990129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 118}], {
             RGBColor[
             0.922885704871617, 0.9252996811451736, 0.6897252468385058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 195}], {
             RGBColor[
             0.9891541933501233, 0.9740323838932168, 0.5011666726164594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 255}], {
             RGBColor[
             0.9707677889125612, 0.9130550293318136, 0.34093880927550557`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 260}], {
             RGBColor[
             0.9878028647788759, 0.9744112358080226, 0.5917197408936072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 312}], {
             RGBColor[
             0.9063479542628992, 0.9121129277150637, 0.688147861422022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 327}], {
             RGBColor[
             0.9871352123480721, 0.9741351443700004, 0.6027844695011301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 334}], {
             RGBColor[
             0.9413063099699355, 0.9399877716365677, 0.6914822205970517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 385}], {
             RGBColor[
             0.9415471788563183, 0.9401798339483574, 0.691505194886461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 446}], {
             RGBColor[
             0.9870085008580954, 0.9740827459125582, 0.6048844068088683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 496}], {
             RGBColor[
             0.8127317838262449, 0.838894312053994, 0.6788460843469577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[
             0.9919196329706043, 0.9892899276201201, 0.6646091487752002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 139}], {
             RGBColor[
             0.9929633525673551, 0.9873576475927883, 0.4754825359898731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 158}], {
             RGBColor[
             0.9917857662572152, 0.9892345702939163, 0.6668276666520052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 247}], {
             RGBColor[
             0.7997780414304518, 0.8397076631621146, 0.74174946424131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 278}], {
             RGBColor[
             0.9823156283919101, 0.9831676918008643, 0.7274581359473522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 401}], {
             RGBColor[
             0.9796534793268437, 0.9424843009449229, 0.4217370122302185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 428}], {
             RGBColor[
             0.9938281664839677, 0.9892073971143232, 0.5696121938003216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 437}], {
             RGBColor[
             0.7654954791852919, 0.8118755347196646, 0.7390506153602077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 451}], {
             RGBColor[
             0.8846135169528184, 0.9065361318287664, 0.7498260592024081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 31}], {
             RGBColor[
             0.5951888670661574, 0.6583840370819004, 0.8580392539438924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 151}], {
             RGBColor[
             0.9928020834612687, 0.9898038724708335, 0.6608174878650384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 162}], {
             RGBColor[
             0.723781672673286, 0.7799135659695013, 0.8658757825619594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 191}], {
             RGBColor[
             0.9753595728422197, 0.9798388610519746, 0.8681565980186753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.9900858768742402, 0.98129233408329, 0.5949207424491932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 345}], {
             RGBColor[
             0.974434822921819, 0.9791491840754787, 0.8697219584205069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 366}], {
             RGBColor[
             0.880825989700172, 0.9054599645758759, 0.8795716012024186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 389}], {
             RGBColor[
             0.9930812835563939, 0.9904010532428467, 0.6912066951961642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 405}], {
             RGBColor[
             0.9830140392238614, 0.9855475495463646, 0.8551995830391228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 429}], {
             RGBColor[
             0.9858756421765797, 0.9670902238379631, 0.5785647756848907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 472}], {
             RGBColor[
             0.98476271640783, 0.9868517101269723, 0.8522395286947176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 488}], {
             RGBColor[
             0.7157905830758571, 0.7730517877446093, 0.8653501015749957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 69}], {
             RGBColor[
             0.9890577622141354, 0.9897431177199302, 0.8310047279228175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[
             0.8714639377234252, 0.8995653315419402, 0.9429852801368466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 97}], {
             RGBColor[
             0.6922246458700165, 0.7543870658173619, 0.9280565462412877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 103}], {
             RGBColor[
             0.9894692211278591, 0.9893343173995365, 0.7821022970136373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 129}], {
             RGBColor[
             0.667110878955758, 0.732634783170858, 0.9264563192207433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 163}], {
             RGBColor[
             0.969850480462439, 0.9770125996825861, 0.934911026000653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 204}], {
             RGBColor[
             0.958829285904601, 0.9687319473837415, 0.9514499256920143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 209}], {
             RGBColor[
             0.9074986774320843, 0.9278023135200058, 0.9465539664325304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 231}], {
             RGBColor[
             0.9876972578619372, 0.9891805142069292, 0.853551805911142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 233}], {
             RGBColor[
             0.9860694623927548, 0.9885073789479868, 0.8805285894351291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 259}], {
             RGBColor[
             0.9812388693146021, 0.9855060414417541, 0.9156334542414577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 275}], {
             RGBColor[
             0.9873381342821212, 0.9890320073776202, 0.8595034130107231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 326}], {
             RGBColor[
             0.9464231020996885, 0.9588395931745926, 0.9502666128055707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 346}], {
             RGBColor[
             0.965885612759965, 0.974055607841956, 0.9416225128178284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 348}], {
             RGBColor[
             0.9847118942678992, 0.974587665046583, 0.6529994350812174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 355}], {
             RGBColor[
             0.8378463878606799, 0.8733030460863215, 0.9396345969403931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 395}], {
             RGBColor[
             0.7425843849483063, 0.7967157736087545, 0.9316219565429343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 404}], {
             RGBColor[
             0.9030796471492735, 0.5783005191834067, 0.5389680633945424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 431}], {
             RGBColor[
             0.9886114548785779, 0.9874996421257953, 0.6887397342990693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 444}], {
             RGBColor[
             0.9723827203451303, 0.978901140040935, 0.9306246043931924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 486}], {
             RGBColor[
             0.9756642157476596, 0.9813484739391858, 0.9250698886277824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 35}], {
             RGBColor[
             0.8541240333339085, 0.8853538811210984, 0.9110856047520834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 101}], {
             RGBColor[
             0.978185149456716, 0.9826272761159833, 0.8938748917056543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 123}], {
             RGBColor[
             0.9892006565515953, 0.9898022082006868, 0.8286365989524169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 158}], {
             RGBColor[
             0.9890667898382062, 0.9897468508744828, 0.830855116829222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 181}], {
             RGBColor[
             0.9907293312744869, 0.9889071981516855, 0.6922943588513981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 189}], {
             RGBColor[
             0.9811423554437173, 0.9848327554991085, 0.8888691133325076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 302}], {
             RGBColor[
             0.990300116684679, 0.9879891515443381, 0.6455769995562046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 306}], {
             RGBColor[
             0.9873813694541482, 0.9890498862323466, 0.8587868943211994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 347}], {
             RGBColor[
             0.7876654103372916, 0.8325937516988846, 0.9050374115124867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 370}], {
             RGBColor[
             0.9911954637667761, 0.9899042084194678, 0.7430300040007898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 390}], {
             RGBColor[
             0.9782451577735063, 0.9474177281437967, 0.5908561090641662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 422}], {
             RGBColor[
             0.9904853022822053, 0.9903334422241834, 0.807346694639628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 428}], {
             RGBColor[
             0.9911091900649587, 0.9897196776948898, 0.7336396439775383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 451}], {
             RGBColor[
             0.8818945405338094, 0.9070484124093329, 0.9138535093796248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 17}], {
             RGBColor[
             0.9173968975791875, 0.9369714003269798, 0.9919833291326232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.95417629463253, 0.9650413221984251, 0.9518547764598648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.9552288168076548, 0.9539451375810202, 0.6970116189358011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.9408919947059784, 0.9055836701861537, 0.6413157723524663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 89}], {
             RGBColor[
             0.9577592145281884, 0.9665229516521212, 0.8924765214893451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 176}], {
             RGBColor[
             0.9584802967051701, 0.964709035623323, 0.7269988018944018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 178}], {
             RGBColor[
             0.9591887551724078, 0.9671141034460247, 0.8687853334820346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 244}], {
             RGBColor[
             0.9547267175347578, 0.9652689362137197, 0.9427328445211395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 261}], {
             RGBColor[
             0.9554357348114082, 0.9655621330785275, 0.93098259336915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 262}], {
             RGBColor[
             0.9415358672258964, 0.9556197128496147, 0.9735025343351655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 288}], {
             RGBColor[
             0.8543652078316191, 0.8869976089752145, 0.9858954234189116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 295}], {
             RGBColor[
             0.8780896303350579, 0.9056288523938567, 0.9882341668928665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 313}], {
             RGBColor[
             0.8599580151086701, 0.8913667525269564, 0.9864528621805324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 321}], {
             RGBColor[
             0.9581880470644536, 0.9667002849263603, 0.8853696565804012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 341}], {
             RGBColor[
             0.8907610478946684, 0.9157326967994233, 0.98944277801161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 376}], {
             RGBColor[
             0.9336495810838881, 0.9497381335575132, 0.9868519597007419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 391}], {
             RGBColor[
             0.9418217494147859, 0.9558329233179993, 0.9730186103593921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 407}], {
             RGBColor[
             0.9527290433734559, 0.945512814812753, 0.6873004711865409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 448}], {
             RGBColor[
             0.9575954438314198, 0.9664552282602924, 0.8951906257597786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 455}], {
             RGBColor[
             0.9589092844770454, 0.966998535131423, 0.8734168861511646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 475}], {
             RGBColor[
             0.9505568656759262, 0.9381855493874078, 0.678861971012977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 478}], {
             RGBColor[
             0.9240626945289445, 0.8393620789173054, 0.6251654313868102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 482}], {
             RGBColor[
             0.9113372102245563, 0.9321395701162283, 0.9914053507431917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 63}], {
             RGBColor[
             0.4036742870569239, 0.5073069848958702, 0.9486958973898845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 85}], {
             RGBColor[
             0.5496564858275321, 0.6223744034294147, 0.9628847148431792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 146}], {
             RGBColor[
             0.5780167136684491, 0.6439202957547094, 0.9285690131526549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 159}], {
             RGBColor[
             0.5617428399543254, 0.6317832673847386, 0.9561164364446261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 166}], {
             RGBColor[
             0.5201386244820179, 0.5988376620335032, 0.960069274877138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 239}], {
             RGBColor[
             0.5855969007950432, 0.6454851236506687, 0.6789797068899064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 344}], {
             RGBColor[
             0.5590234745064295, 0.6297551690862502, 0.9607196128238142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 387}], {
             RGBColor[
             0.44961408552651433`, 0.543409008204533, 0.9531287735997828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 435}], {
             RGBColor[
             0.5501760650525347, 0.6227887017998295, 0.9629342727734937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 439}], {
             RGBColor[
             0.45581914320058364`, 0.5482564464197011, 0.9537472357591732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 453}], {
             RGBColor[
             0.5734009487452942, 0.6043453136411463, 0.6316007361889238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 68}], {
             RGBColor[
             0.6455332791803617, 0.7127258239671159, 0.8981181972755226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 95}], {
             RGBColor[
             0.9895149264169985, 0.9899321668663981, 0.8234283339783462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 286}], {
             RGBColor[
             0.9556273155706941, 0.965556254563346, 0.9241121781479806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 319}], {
             RGBColor[
             0.8575198437128625, 0.8880757877638512, 0.9145561652111474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 330}], {
             RGBColor[
             0.9638804651430742, 0.9720212876623558, 0.920884361610789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 333}], {
             RGBColor[
             0.90595106432428, 0.9259457602453739, 0.9193740129575846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 352}], {
             RGBColor[
             0.9900633450335594, 0.9878068544276677, 0.6433669505152794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 357}], {
             RGBColor[
             0.9906840496060816, 0.9891344787454337, 0.7109268126897219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 358}], {
             RGBColor[
             0.9865028838287826, 0.9886866098502072, 0.8733456745814276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 367}], {
             RGBColor[
             0.9889792692720758, 0.9897106588712119, 0.8323055591059694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 368}], {
             RGBColor[
             0.9885982231013093, 0.98955308648716, 0.8386204802714479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 375}], {
             RGBColor[
             0.9903807982619164, 0.9884858547836785, 0.6779197753277052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 441}], {
             RGBColor[
             0.9911023507587285, 0.9900291826142115, 0.7564563116998679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 450}], {
             RGBColor[
             0.7888815719340856, 0.8336559158743828, 0.9082613148632266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 492}], {
             RGBColor[
             0.9700930151632318, 0.9766545972952723, 0.9103681349192119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 102}], {
             RGBColor[
             0.9906387847090006, 0.9892918682012455, 0.7244781365357549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 168}], {
             RGBColor[
             0.9875431997901278, 0.9891168072351241, 0.8561049468505335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 181}], {
             RGBColor[
             0.990394134227101, 0.9887685855584203, 0.697849441388736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.9808071583963314, 0.9846941429058431, 0.8944241958698453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 232}], {
             RGBColor[
             0.9858274700279465, 0.9884073088862184, 0.8845390291761694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 280}], {
             RGBColor[
             0.9262576796382457, 0.942194257905612, 0.923766638055789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 302}], {
             RGBColor[
             0.9899649196372929, 0.9878505389510728, 0.6511320820935425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 370}], {
             RGBColor[
             0.9908602667193901, 0.9897655958262025, 0.7485850865381275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 383}], {
             RGBColor[
             0.9030276805096844, 0.9236810278640435, 0.9215483551184254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 390}], {
             RGBColor[
             0.9779099607261202, 0.9472791155505313, 0.5964111916015039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 443}], {
             RGBColor[
             0.9860278740324968, 0.988490181092248, 0.8812178161918304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 451}], {
             RGBColor[
             0.8815593434864235, 0.9069097998160676, 0.9194085919169626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 480}], {
             RGBColor[
             0.9586459913171539, 0.8746241273814317, 0.5615359223086438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 25}], {
             RGBColor[
             0.9127551899893186, 0.9325189661100806, 0.9654938536436495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 164}], {
             RGBColor[
             0.7544172111781846, 0.8084046429152463, 0.9760696308760545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 180}], {
             RGBColor[
             0.9069811348345392, 0.9282126852297936, 0.9752678229059187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 205}], {
             RGBColor[
             0.92293803927994, 0.939946217794721, 0.9407738376881232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 259}], {
             RGBColor[
             0.9194142351914942, 0.9374852711186773, 0.9542218270735097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 316}], {
             RGBColor[
             0.8182602298371033, 0.8582792943165066, 0.9824329063290453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 331}], {
             RGBColor[
             0.9275406135566395, 0.9410911583842771, 0.8093738016684855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 348}], {
             RGBColor[
             0.9228872601447913, 0.9265668947235062, 0.6915878079132696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 372}], {
             RGBColor[
             0.9276570467462244, 0.941340197203598, 0.8220468358124451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 404}], {
             RGBColor[
             0.8412550130261656, 0.5302797488603299, 0.5775564362265945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 418}], {
             RGBColor[
             0.7966372902093775, 0.8413872895388993, 0.980277733784813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 431}], {
             RGBColor[
             0.92678682075547, 0.9394788718027185, 0.7273281071311213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 444}], {
             RGBColor[
             0.9105580862220224, 0.9308803697178581, 0.9692129772252445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 40}], {
             RGBColor[
             0.7656728421905687, 0.81690828613091, 0.9726884093180949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 161}], {
             RGBColor[
             0.9636593544935357, 0.9720899998607764, 0.931720453162906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 188}], {
             RGBColor[
             0.9390947923213291, 0.9540975763531476, 0.9879808093644729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 202}], {
             RGBColor[
             0.9634173064449967, 0.9719899067723544, 0.9357318157274644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 243}], {
             RGBColor[
             0.9674857280404565, 0.973672303655743, 0.8683075411531127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 273}], {
             RGBColor[
             0.9372037613172408, 0.8643568759091715, 0.6248241262260466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 279}], {
             RGBColor[
             0.9453844611627611, 0.9587884010767003, 0.9773340406242876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 283}], {
             RGBColor[
             0.8061312030532557, 0.8493137974374736, 0.9761745495021397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 285}], {
             RGBColor[
             0.9524987570262546, 0.9640942312831033, 0.9652913934329254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 318}], {
             RGBColor[
             0.8206912292784327, 0.8606882005848797, 0.9776257568450843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 335}], {
             RGBColor[
             0.9509651516283453, 0.9629504708883909, 0.967887387343238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 396}], {
             RGBColor[
             0.865778817581732, 0.8959109672457799, 0.9821196662796887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 421}], {
             RGBColor[
             0.906072969094267, 0.927801345169766, 0.9860264041598541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 430}], {
             RGBColor[
             0.9625711495708837, 0.9566425027489006, 0.6883973589486179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 459}], {
             RGBColor[
             0.9574270843548347, 0.9392903628912168, 0.6684136369594725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 477}], {
             RGBColor[
             0.9248723750417207, 0.9427914811759852, 0.9878195082815501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 21}], {
             RGBColor[
             0.9740262032665286, 0.9371354124704734, 0.6017630497124631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 59}], {
             RGBColor[
             0.9762999607106941, 0.9380756696065369, 0.5640810045669997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 77}], {
             RGBColor[
             0.9647013232051168, 0.9303613976485686, 0.6256292513408785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 87}], {
             RGBColor[
             0.9740893440701551, 0.9371615228154175, 0.6007166431932092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 161}], {
             RGBColor[
             0.974469577927937, 0.9373187592871748, 0.5944151841560839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 188}], {
             RGBColor[
             0.9499050157557304, 0.9193263357795461, 0.6506755403576507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 228}], {
             RGBColor[
             0.9098362273822094, 0.6622207284464398, 0.256002119970066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 243}], {
             RGBColor[
             0.9782959514748579, 0.9389010630821415, 0.5310022721462906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 256}], {
             RGBColor[
             0.9760743349560903, 0.9379823675586907, 0.5678202072215199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 279}], {
             RGBColor[
             0.9561946845971625, 0.9240171605030987, 0.6400287716174657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 285}], {
             RGBColor[
             0.963308980460656, 0.9293229907095018, 0.6279861244261034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 287}], {
             RGBColor[
             0.9786427218404594, 0.938379577216601, 0.4769253183465447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 298}], {
             RGBColor[
             0.9637269933968766, 0.9296347440729017, 0.6272785375603167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 335}], {
             RGBColor[
             0.9617753750627467, 0.9281792303147893, 0.630582118336416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 354}], {
             RGBColor[
             0.9744521036676679, 0.9373115332314855, 0.5947047778706795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 409}], {
             RGBColor[
             0.8415376641864916, 0.8337573246925316, 0.6413208036042279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 430}], {
             RGBColor[
             0.9733813730052852, 0.9218712621752991, 0.35109208994179586`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 477}], {
             RGBColor[
             0.9356825984761221, 0.9080202406023836, 0.6505142392747281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 80}], {
             RGBColor[
             0.7825012595514622, 0.8300151982822237, 0.9789560707282144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 159}], {
             RGBColor[
             0.8508032445219283, 0.8841516520665669, 0.9775754907779961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 166}], {
             RGBColor[
             0.8091990290496209, 0.8512060467153313, 0.981528329210508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 192}], {
             RGBColor[
             0.8750285278879324, 0.8987932898693192, 0.7284484656551566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.8515780720872056, 0.8847295171960868, 0.976263909817376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 239}], {
             RGBColor[
             0.8746573053626463, 0.897853508332497, 0.7004387612232763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 251}], {
             RGBColor[
             0.8758078384965907, 0.9004601564608503, 0.8132716160600353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 272}], {
             RGBColor[
             0.867605253098639, 0.8740652801453866, 0.6730428698459338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 435}], {
             RGBColor[
             0.8392364696201378, 0.8751570864816577, 0.9843933271068637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 447}], {
             RGBColor[
             0.592539171574863, 0.6776455186560149, 0.9624569068474866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 453}], {
             RGBColor[
             0.8624613533128973, 0.8567136983229746, 0.6530597905222938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 454}], {
             RGBColor[
             0.862407750430944, 0.8928062735728761, 0.9579320892139053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 489}], {
             RGBColor[
             0.8543098323114569, 0.8867668594984867, 0.9716397523148933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 50}], {
             RGBColor[
             0.866368308749726, 0.8593523439675474, 0.6528453682223301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 82}], {
             RGBColor[
             0.7035452207277555, 0.7286724472426767, 0.6388443718378962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 126}], {
             RGBColor[
             0.9657437856091617, 0.8961078864973744, 0.321421505145214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 149}], {
             RGBColor[
             0.9213208038210023, 0.9027270178137634, 0.6582043326515788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 173}], {
             RGBColor[
             0.6977931890180732, 0.7236903264812695, 0.6384778574636771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 242}], {
             RGBColor[
             0.9245147970411143, 0.9052738213088445, 0.6585089785762246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 249}], {
             RGBColor[
             0.9624778055504922, 0.9349848907851032, 0.642728135850142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 269}], {
             RGBColor[
             0.9806426264362587, 0.9469476743371184, 0.5410222316084746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 282}], {
             RGBColor[
             0.9813874172462091, 0.9472013070012154, 0.5247279057472898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 323}], {
             RGBColor[
             0.9807684986883785, 0.9458775027882806, 0.4573624402500049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 414}], {
             RGBColor[
             0.9813803121422233, 0.9471861099022256, 0.5239545590260398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 419}], {
             RGBColor[
             0.9800969022303769, 0.944441025873433, 0.3842633104094264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 449}], {
             RGBColor[
             0.885955166879423, 0.8746537464041022, 0.6547976031911023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 499}], {
             RGBColor[
             0.9077950442419332, 0.8919419442723768, 0.6569142336283391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 17}], {
             RGBColor[
             0.9392173045879977, 0.9535434373169791, 0.9653932436904911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 116}], {
             RGBColor[
             0.885367926138255, 0.9107429373392261, 0.960220544953369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 143}], {
             RGBColor[
             0.9784141580211843, 0.9751214181453299, 0.6757240451328076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 165}], {
             RGBColor[
             0.9464509892923411, 0.9593113811470821, 0.9660831989951779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 185}], {
             RGBColor[
             0.9578697198949677, 0.968099886596445, 0.9561997542676608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.977560276873334, 0.9822599377289045, 0.8993522030206027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 224}], {
             RGBColor[
             0.6327005606310677, 0.7028218808230979, 0.9398531126563447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 277}], {
             RGBColor[
             0.9803965566194516, 0.9814860922859101, 0.7108417136772576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 313}], {
             RGBColor[
             0.8817784221174803, 0.9079387895169557, 0.9598627767384004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 333}], {
             RGBColor[
             0.8960493252185282, 0.9191224623313489, 0.961275843281721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 358}], {
             RGBColor[
             0.976601144723031, 0.9818633119361821, 0.915247504905564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 361}], {
             RGBColor[
             0.8943172204656153, 0.9177413290181071, 0.96111063358412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 386}], {
             RGBColor[
             0.9659169291017053, 0.9329653305110353, 0.6271746706842869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 441}], {
             RGBColor[
             0.9812006116529768, 0.9832058847001864, 0.7983581420240042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 89}], {
             RGBColor[
             0.9510292343983144, 0.9611566481770037, 0.8918346099766334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.8779964181364307, 0.9055545275168491, 0.9882252762301498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 116}], {
             RGBColor[
             0.8568175389995709, 0.8888045968741094, 0.9861687188827895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 143}], {
             RGBColor[
             0.9498637708825002, 0.9531830776802133, 0.7016722190622281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 165}], {
             RGBColor[
             0.917900602153657, 0.9373730406819654, 0.9920313729245984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 176}], {
             RGBColor[
             0.9517503165752962, 0.9593427321482056, 0.7263568903816902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 178}], {
             RGBColor[
             0.9524587750425338, 0.9617477999709072, 0.8681434219693229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 261}], {
             RGBColor[
             0.9487057546815343, 0.9601958296034101, 0.9303406818564384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 277}], {
             RGBColor[
             0.9518461694807675, 0.9595477518207933, 0.7367898876066781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 288}], {
             RGBColor[
             0.8476352277017452, 0.8816313055000972, 0.9852535119062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 313}], {
             RGBColor[
             0.8532280349787962, 0.8860004490518391, 0.9858109506678209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 321}], {
             RGBColor[
             0.9514580669345797, 0.9613339814512429, 0.8847277450676897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 328}], {
             RGBColor[
             0.925430492937631, 0.943261255761968, 0.9887307196381947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 386}], {
             RGBColor[
             0.9373665419630213, 0.9110269900459185, 0.6531228446137074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 391}], {
             RGBColor[
             0.935091769284912, 0.9504666198428819, 0.9723766988466804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 407}], {
             RGBColor[
             0.945999063243582, 0.9401465113376355, 0.6866585596738294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 455}], {
             RGBColor[
             0.9521793043471715, 0.9616322316563056, 0.8727749746384531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 498}], {
             RGBColor[
             0.9481873555491057, 0.9475281351196347, 0.6951596620564623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 28}], {
             RGBColor[
             0.9550047966464441, 0.9635281886290291, 0.8555921009736529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 93}], {
             RGBColor[
             0.9511032550628664, 0.9619814173511415, 0.9250930532446844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 160}], {
             RGBColor[
             0.9547264604770864, 0.9629328557068765, 0.8252969266307901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 167}], {
             RGBColor[
             0.8695678858702214, 0.8988338446741873, 0.9874213552983593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 172}], {
             RGBColor[
             0.9135435843830263, 0.8124201718363895, 0.6200073110515105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 201}], {
             RGBColor[
             0.9513611431628212, 0.9620880607078947, 0.9208191800354245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 218}], {
             RGBColor[
             0.9519327186728774, 0.9548328004881683, 0.7018695571494458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 235}], {
             RGBColor[
             0.9524360928661904, 0.956530799840094, 0.7038250708362264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 274}], {
             RGBColor[
             0.9345623717008268, 0.950178500924963, 0.976972357895854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 300}], {
             RGBColor[
             0.7684354613918527, 0.8194824299907439, 0.9775632815694235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 305}], {
             RGBColor[
             0.9534508731198326, 0.9599538919173636, 0.7077673004964552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 310}], {
             RGBColor[
             0.954189051815004, 0.9617833929190327, 0.766803310264935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 406}], {
             RGBColor[
             0.8524306519519576, 0.8854109724404642, 0.9857225996865628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 432}], {
             RGBColor[
             0.9263075219830759, 0.8630249310905214, 0.6302774748526329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 460}], {
             RGBColor[
             0.9545244496698779, 0.9625007750166832, 0.803309296932341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 493}], {
             RGBColor[
             0.9440409906827688, 0.928212148911682, 0.6712116841356551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 26}], {
             RGBColor[
             0.685794174461194, 0.7477827892203716, 0.8896225662754431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 59}], {
             RGBColor[
             0.6862576676864822, 0.7479744555802609, 0.8819412840503993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 67}], {
             RGBColor[
             0.5058307334498473, 0.6077774752561047, 0.9547698685404795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 124}], {
             RGBColor[
             0.5556995875821844, 0.6469404764867135, 0.9596001200897273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 188}], {
             RGBColor[
             0.6598627227315186, 0.7292251217532701, 0.9685358198410503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 200}], {
             RGBColor[
             0.6836436112313462, 0.7468934760578755, 0.9252629644732528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 228}], {
             RGBColor[
             0.6197939343579975, 0.47211951442016387`, 0.5738623994534655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 298}], {
             RGBColor[
             0.6736847003726647, 0.7395335300466257, 0.945138817043716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 318}], {
             RGBColor[
             0.5414591596886222, 0.6358157459850022, 0.9581807673216618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 335}], {
             RGBColor[
             0.6717330820385348, 0.7380780162885134, 0.9484423978198154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 459}], {
             RGBColor[
             0.6781950147650242, 0.7144179082913393, 0.64896864743605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 468}], {
             RGBColor[
             0.5792658783621807, 0.6653506419544902, 0.9619489877151688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 25}], {
             RGBColor[
             0.8725129187126519, 0.9007524812672589, 0.961570164498863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 46}], {
             RGBColor[
             0.8676267643139062, 0.8438733204409461, 0.6307121697733997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 150}], {
             RGBColor[
             0.8631829638864181, 0.8262551325546648, 0.6271365836400405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 220}], {
             RGBColor[
             0.724242643071443, 0.7845031243061482, 0.9731493962952108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 325}], {
             RGBColor[
             0.7251994525875399, 0.7852505911721448, 0.9732447621258821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 388}], {
             RGBColor[
             0.5478182005197646, 0.6379274291935135, 0.960023391882294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 392}], {
             RGBColor[
             0.823011351052329, 0.8620325374797102, 0.9828954060602009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 413}], {
             RGBColor[
             0.7678278347815016, 0.8185522073297717, 0.9774935608780955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 473}], {
             RGBColor[
             0.8870873241007915, 0.9088733269933972, 0.7824820859730521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 474}], {
             RGBColor[
             0.8838409726037539, 0.9086533044846139, 0.9178711446188708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 490}], {
             RGBColor[
             0.8869427114565361, 0.909935953211292, 0.8664673047854319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 55}], {
             RGBColor[
             0.9882729754614618, 0.9894185882296, 0.8440106753776321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 59}], {
             RGBColor[
             0.9875520066572683, 0.9891204491010128, 0.8559589942705725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 77}], {
             RGBColor[
             0.9759533691516911, 0.9814061771430447, 0.9175072410444514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[
             0.9853413900167294, 0.9882063023098937, 0.892594632896782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 91}], {
             RGBColor[
             0.9174490028693159, 0.9355539698886126, 0.9395798621647964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 188}], {
             RGBColor[
             0.9611570617023046, 0.9703711152740222, 0.9425535300612236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 200}], {
             RGBColor[
             0.9849379502021323, 0.9880394695786274, 0.8992806746934262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 228}], {
             RGBColor[
             0.9210882733287835, 0.7132655079409158, 0.5478801096736388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 256}], {
             RGBColor[
             0.9873263809026646, 0.9890271470531669, 0.8596981969250928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 287}], {
             RGBColor[
             0.9898947677870336, 0.989424356711077, 0.7688033080501175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 298}], {
             RGBColor[
             0.9749790393434508, 0.9806795235673778, 0.9191565272638894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 335}], {
             RGBColor[
             0.9730274210093208, 0.9792240098092655, 0.9224601080399888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 336}], {
             RGBColor[
             0.9881997906536109, 0.9893883244307898, 0.8452235370399346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 354}], {
             RGBColor[
             0.985704149614242, 0.9883563127259616, 0.8865827675742524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 409}], {
             RGBColor[
             0.8527897101330657, 0.8848021041870078, 0.9331987933078006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 24}], {
             RGBColor[
             0.8476134810205229, 0.8808392453731639, 0.9363489896292518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 52}], {
             RGBColor[
             0.8477297105102306, 0.8808873092541196, 0.9344227661925186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 170}], {
             RGBColor[
             0.8279838179946399, 0.866306875825916, 0.9743865249672591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 214}], {
             RGBColor[
             0.8523535235728836, 0.8827993747821022, 0.8577942176997309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 268}], {
             RGBColor[
             0.851553663309327, 0.8802573975512382, 0.7103180240241912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 466}], {
             RGBColor[
             0.8240390116088121, 0.8633648456823934, 0.9810640532081816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 491}], {
             RGBColor[
             0.8415410099449836, 0.8466155685566771, 0.660094229508782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 39}], {
             RGBColor[
             0.9657547320427822, 0.9518040062879349, 0.6676969599169256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 51}], {
             RGBColor[
             0.9172708449438987, 0.9364244540814707, 0.9764931141648912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 62}], {
             RGBColor[
             0.8907969326005671, 0.915314874994105, 0.9739680087720437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 96}], {
             RGBColor[
             0.9489138373909771, 0.9614206040888804, 0.9713597272786638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 110}], {
             RGBColor[
             0.9730607688856276, 0.977947694681024, 0.8641338948171263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 136}], {
             RGBColor[
             0.9735678234773744, 0.9771587249244285, 0.7831393854064596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 157}], {
             RGBColor[
             0.8748024834023997, 0.9027503903241569, 0.9723922745548594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 240}], {
             RGBColor[
             0.9715393120663826, 0.9713167529915183, 0.690168960982336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 360}], {
             RGBColor[
             0.9495839679672267, 0.9619203863754092, 0.9702253710111197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 52}], {
             RGBColor[
             0.9849546925215857, 0.9880463929579795, 0.89900321113235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 64}], {
             RGBColor[
             0.9678893867536491, 0.9754651367371183, 0.9344294357523065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.9893081006557464, 0.9885489326806547, 0.7325264147661901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 115}], {
             RGBColor[
             0.8383809270776807, 0.8736267040630068, 0.9354287749353514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 170}], {
             RGBColor[
             0.9652088000059951, 0.9734659595297759, 0.9389669699070905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 223}], {
             RGBColor[
             0.9300031802692701, 0.9456487355109212, 0.9444424619882578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 268}], {
             RGBColor[
             0.9887786453206822, 0.9874164812550981, 0.6748984689640226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 491}], {
             RGBColor[
             0.9787659919563387, 0.9537746522605368, 0.6246746744486135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 164}], {
             RGBColor[
             0.806494126946127, 0.8491780993778485, 0.9549900283162618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.9590580506024816, 0.9689861416923959, 0.954188220346126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 220}], {
             RGBColor[
             0.8165618301160521, 0.8570430656115721, 0.9559934828802046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 316}], {
             RGBColor[
             0.8703371456050457, 0.8990527507791088, 0.9613533037692525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 325}], {
             RGBColor[
             0.817518639632149, 0.8577905324775685, 0.9560888487108758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 392}], {
             RGBColor[
             0.9153305380969381, 0.9345724787851342, 0.9657394926451948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 413}], {
             RGBColor[
             0.8601470218261107, 0.8910921486351957, 0.9603376474630891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 474}], {
             RGBColor[
             0.9761601596483629, 0.9811932457900379, 0.9007152312038644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 490}], {
             RGBColor[
             0.9792618985011452, 0.9824758945167158, 0.8493113913704258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 67}], {
             RGBColor[
             0.8089353366395106, 0.8496720595530309, 0.8987868158402335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 124}], {
             RGBColor[
             0.8588041907718477, 0.8888350607836396, 0.9036170673894812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 318}], {
             RGBColor[
             0.8445637628782855, 0.8777103302819282, 0.9021977146214157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 335}], {
             RGBColor[
             0.9748376852281981, 0.9799726005854396, 0.8924593451195694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 459}], {
             RGBColor[
             0.9812996179546876, 0.9563124925882655, 0.5929855947358039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 29}], {
             RGBColor[
             0.8928399040788987, 0.9166519749025825, 0.9640421630308306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 65}], {
             RGBColor[
             0.9717193318062687, 0.9570527898698769, 0.6592995351099961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 86}], {
             RGBColor[
             0.978443355969771, 0.979702088508315, 0.6881773298270099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 177}], {
             RGBColor[
             0.8623878357704946, 0.8928515580098499, 0.9610099123921172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[
             0.9683977886300928, 0.9458484448012102, 0.6463959670913499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 290}], {
             RGBColor[
             0.7982783786176033, 0.842613531538552, 0.9547262133232446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 297}], {
             RGBColor[
             0.9774858226898604, 0.9816582215199832, 0.8750188020165883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 350}], {
             RGBColor[
             0.9684957911584258, 0.946179030341365, 0.6467766884076986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 412}], {
             RGBColor[
             0.9449647489976221, 0.9582149113495494, 0.9690138772715768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 484}], {
             RGBColor[
             0.9797556820680868, 0.9825968667056049, 0.8374013579116086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 490}], {
             RGBColor[
             0.9790114415278188, 0.9822891041160946, 0.8497353496966267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 125}], {
             RGBColor[
             0.9883898586290617, 0.988965516743215, 0.8177605565902807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 149}], {
             RGBColor[
             0.9351452719415994, 0.9476927427018232, 0.8536978817784977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 201}], {
             RGBColor[
             0.9915611267791973, 0.990711706869151, 0.7846751872147304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 218}], {
             RGBColor[
             0.9921327022892535, 0.9834564466494247, 0.5657255643287517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 282}], {
             RGBColor[
             0.9952118853668062, 0.9921670318892752, 0.7202214548742086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 305}], {
             RGBColor[
             0.9936508567362086, 0.9885775380786199, 0.5716233076757611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 310}], {
             RGBColor[
             0.99438903543138, 0.990407039080289, 0.6306593174442409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 406}], {
             RGBColor[
             0.8926306355683336, 0.9140346186017205, 0.8495786068658687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 408}], {
             RGBColor[
             0.9596658289859408, 0.9672447692961914, 0.8560366743991468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 419}], {
             RGBColor[
             0.9939213703509738, 0.9894067507614928, 0.5797568595363453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 432}], {
             RGBColor[
             0.9665075055994519, 0.8916485772517777, 0.4941334820319387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 493}], {
             RGBColor[
             0.9842409742991449, 0.9568357950729384, 0.535067691314961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 46}], {
             RGBColor[
             0.8882042066534792, 0.8599596044768907, 0.6327602099791663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 65}], {
             RGBColor[
             0.900228044074559, 0.9007859230010188, 0.6780795304045678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 86}], {
             RGBColor[
             0.9069520682380614, 0.923435221639457, 0.7069573251215816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 177}], {
             RGBColor[
             0.7908965480387848, 0.836584691140992, 0.9797899076866889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 194}], {
             RGBColor[
             0.8969065008983832, 0.8895815779323522, 0.6651759623859217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 254}], {
             RGBColor[
             0.9062202923424489, 0.9254847111312325, 0.8900574132119575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 290}], {
             RGBColor[
             0.7267870908858935, 0.7863466646696939, 0.9735062086178163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 297}], {
             RGBColor[
             0.9059945349581507, 0.9253913546511251, 0.8937987973111601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 350}], {
             RGBColor[
             0.8970045034267161, 0.8899121634725069, 0.6655566837022704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 377}], {
             RGBColor[
             0.9082781608629577, 0.9262715996755793, 0.8512943236465045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 412}], {
             RGBColor[
             0.8734734612659124, 0.9019480444806913, 0.9877938725661486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 426}], {
             RGBColor[
             0.7598532822573931, 0.8123334559750104, 0.9766958050694123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 476}], {
             RGBColor[
             0.8939158850680791, 0.9174544397625561, 0.9622208078769349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 31}], {
             RGBColor[
             0.5571518551365255, 0.6308123341381753, 0.9632267558065302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 133}], {
             RGBColor[
             0.954479294149001, 0.9636016115446977, 0.8788752075261266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 191}], {
             RGBColor[
             0.9373225609125881, 0.9522671581082495, 0.9733440998813131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 311}], {
             RGBColor[
             0.9553263171065307, 0.963432617061174, 0.8270931069486664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 366}], {
             RGBColor[
             0.8427889777705404, 0.8778882616321506, 0.9847591030650564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 405}], {
             RGBColor[
             0.9449770272942297, 0.9579758466026395, 0.9603870849017606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 423}], {
             RGBColor[
             0.9552780075391577, 0.9633292877814097, 0.821834908672207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 429}], {
             RGBColor[
             0.9478386302469479, 0.939518520894238, 0.6837522775475285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 465}], {
             RGBColor[
             0.9462235109285795, 0.9589054720562078, 0.9582771132438053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 469}], {
             RGBColor[
             0.9533637433116366, 0.9631403026050988, 0.8973627718542785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 488}], {
             RGBColor[
             0.6777535711462255, 0.7454800848008841, 0.9705376034376335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 133}], {
             RGBColor[
             0.5956586044269606, 0.6585782855522921, 0.8502544902340612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 191}], {
             RGBColor[
             0.5785018711905476, 0.6472438321158438, 0.9447233825892476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 226}], {
             RGBColor[
             0.5932281752225681, 0.6486973051471592, 0.6714875270197656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 237}], {
             RGBColor[
             0.5705707196950477, 0.5683789161725954, 0.6037240232105405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 311}], {
             RGBColor[
             0.5965056273844903, 0.6584092910687682, 0.7984723896566011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 366}], {
             RGBColor[
             0.4839682880484999, 0.572864935639745, 0.9561383857729909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 405}], {
             RGBColor[
             0.5861563375721893, 0.6529525206102338, 0.9317663676096952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 429}], {
             RGBColor[
             0.5890179405249075, 0.6344951949018323, 0.655131560255463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 472}], {
             RGBColor[
             0.5879050147561579, 0.6542566811908415, 0.92880631326529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 488}], {
             RGBColor[
             0.31893288142418497`, 0.44045675880847845`, 0.941916886145568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 66}], {
             RGBColor[
             0.9701218663656495, 0.9768356224653341, 0.9174623910693424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 84}], {
             RGBColor[
             0.972134089320958, 0.92878049145834, 0.580779552267732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 89}], {
             RGBColor[
             0.9890013091431681, 0.9897197729243075, 0.8319403014046108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 176}], {
             RGBColor[
             0.9897223913201498, 0.9879058568955092, 0.6664625818096674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 179}], {
             RGBColor[
             0.6114902783092049, 0.6772505225318544, 0.9041625326422796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 245}], {
             RGBColor[
             0.8855768583695017, 0.9101706471029891, 0.9253561689530884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 255}], {
             RGBColor[
             0.9720166750045133, 0.9283844253987792, 0.5803234198201771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 260}], {
             RGBColor[
             0.9890517508708281, 0.9897406318749881, 0.8311043514382788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 299}], {
             RGBColor[
             0.9901226784153919, 0.9887620305169987, 0.7100313618411724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 312}], {
             RGBColor[
             0.9075968403548513, 0.9274423237820292, 0.9275324719666935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 328}], {
             RGBColor[
             0.9634025676824847, 0.9718243805092716, 0.9288364110661721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 334}], {
             RGBColor[
             0.9425551960618876, 0.9553171677035331, 0.9308668311417232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 407}], {
             RGBColor[
             0.9839711379884355, 0.9687096360849392, 0.6267642511018067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 448}], {
             RGBColor[
             0.9888375384463994, 0.9896520495324787, 0.8346544056750442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 475}], {
             RGBColor[
             0.9817989602909059, 0.9613823706595941, 0.6183257509282427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 478}], {
             RGBColor[
             0.9553047891439241, 0.8625589001894917, 0.5646292113020761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 482}], {
             RGBColor[
             0.9425793048395359, 0.9553363913884145, 0.9308691306584574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 76}], {
             RGBColor[
             0.9643905964007329, 0.9729631456174892, 0.9451616112603765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 111}], {
             RGBColor[
             0.9736219062737199, 0.9798478414058803, 0.9295354115566252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 160}], {
             RGBColor[
             0.9799355874675815, 0.9822725848908023, 0.8013051075637185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 175}], {
             RGBColor[
             0.7696852091002495, 0.819370855715726, 0.951685292399167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 182}], {
             RGBColor[
             0.8708620539010271, 0.8994558913094102, 0.9610552403288036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 237}], {
             RGBColor[
             0.9540166704933342, 0.8922764125175228, 0.6082972317834101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 241}], {
             RGBColor[
             0.7856971507095778, 0.8323700712439281, 0.952945811096328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 274}], {
             RGBColor[
             0.959771498691322, 0.9695182301088889, 0.9529805388287824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 351}], {
             RGBColor[
             0.9308386805703834, 0.9469281688219083, 0.9668691302900665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 371}], {
             RGBColor[
             0.6739563191412945, 0.739736102879535, 0.9446790373179466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 432}], {
             RGBColor[
             0.9515166489735709, 0.8823646602744473, 0.6062856557855613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 460}], {
             RGBColor[
             0.9797335766603731, 0.9818405042006091, 0.7793174778652694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 463}], {
             RGBColor[
             0.9795923578993273, 0.9826775008389086, 0.8467435461045683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 44}], {
             RGBColor[
             0.8091599738219046, 0.7832169265490984, 0.621567164586956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 62}], {
             RGBColor[
             0.7506274871270546, 0.8051846644086575, 0.9757607479680246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 190}], {
             RGBColor[
             0.82999132340871, 0.8565363925485663, 0.6866063202238912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 291}], {
             RGBColor[
             0.8244233506043994, 0.8629837352202101, 0.9466120791450154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 356}], {
             RGBColor[
             0.7950734076831709, 0.8406246350077305, 0.9800000395480086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 394}], {
             RGBColor[
             0.833771557367386, 0.8678267072633377, 0.8255503953259635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 467}], {
             RGBColor[
             0.7975984302967245, 0.8426380194998653, 0.9802408784590037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.8303734596100321, 0.8682645667099772, 0.9792252703514862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 123}], {
             RGBColor[
             0.8553777942707154, 0.8858723434886544, 0.8903075413998989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 193}], {
             RGBColor[
             0.8558561319781446, 0.8860701484233947, 0.8823802476894925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 347}], {
             RGBColor[
             0.6538425480564117, 0.7286638869868522, 0.9667083539599688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 410}], {
             RGBColor[
             0.7786189819457542, 0.8271193566235835, 0.9785327598572182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 422}], {
             RGBColor[
             0.8566624400013254, 0.886403577512151, 0.8690176370871101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 428}], {
             RGBColor[
             0.8572863277840788, 0.8857898129828574, 0.7953105864250204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 437}], {
             RGBColor[
             0.628953640485403, 0.7084579505881987, 0.9647490079849065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 75}], {
             RGBColor[
             0.9856580249553277, 0.9864531793990043, 0.784700359932695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 76}], {
             RGBColor[
             0.97017562090152, 0.977277607418068, 0.9353690737565798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 104}], {
             RGBColor[
             0.9854432878583658, 0.9859938784618536, 0.7613275521321321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 112}], {
             RGBColor[
             0.8692918076837055, 0.8980243597228745, 0.9505295981787387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 266}], {
             RGBColor[
             0.8853592737664034, 0.9105763863439433, 0.9521310530388547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 359}], {
             RGBColor[
             0.8763176507327315, 0.9035130017111586, 0.9512298685536295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 379}], {
             RGBColor[
             0.9589494316604776, 0.9689051338632965, 0.9543720838825815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 408}], {
             RGBColor[
             0.9504599968608469, 0.9622753141194396, 0.9583963106489727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 440}], {
             RGBColor[
             0.763440264210661, 0.8139188464212529, 0.9409457116377301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 463}], {
             RGBColor[
             0.9853773824001144, 0.9869919626394874, 0.8369510086007717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 49}], {
             RGBColor[
             0.8427112237132617, 0.8742581744196889, 0.7822075522739205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 53}], {
             RGBColor[
             0.9946496008130639, 0.9909643620845092, 0.6590202512173791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 97}], {
             RGBColor[
             0.6970894817225983, 0.7553421941507292, 0.7706295015748152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 100}], {
             RGBColor[
             0.9737041866740901, 0.9772136291853203, 0.7791955600714298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 203}], {
             RGBColor[
             0.9934770058494862, 0.9884563000249534, 0.5313905258492305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 207}], {
             RGBColor[
             0.9217568447251536, 0.9362474293688284, 0.7900228661043776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 257}], {
             RGBColor[
             0.9056881070863778, 0.5619121534801833, 0.3793803106031965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 264}], {
             RGBColor[
             0.9864449061698847, 0.9867156369242703, 0.7576288452768865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 281}], {
             RGBColor[
             0.9804599145161232, 0.9822520399484195, 0.7677598750108824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 317}], {
             RGBColor[
             0.8427112237132617, 0.8742581744196889, 0.7822075522739205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 322}], {
             RGBColor[
             0.9870594187451095, 0.987173939396701, 0.7565886357775793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 324}], {
             RGBColor[
             0.9725158804195018, 0.9763273923263212, 0.78120705260054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 343}], {
             RGBColor[
             0.9639123038384214, 0.9698610481862937, 0.7940436914272238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 374}], {
             RGBColor[
             0.9945151169495118, 0.9906767146987758, 0.6443825126079441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 397}], {
             RGBColor[
             0.9940812782604743, 0.9897487776107445, 0.5971618486482483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 445}], {
             RGBColor[
             0.6637164141119306, 0.7264361203655191, 0.7685029992173085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 77}], {
             RGBColor[
             0.6410355792308826, 0.711137240373166, 0.9413470742617929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 79}], {
             RGBColor[
             0.5843508285118295, 0.429009906261402, 0.5699774393074251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 87}], {
             RGBColor[
             0.6504236000959209, 0.717937365540015, 0.9164344661141236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 127}], {
             RGBColor[
             0.3577822093219636, 0.484314699883142, 0.9440185438969781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 184}], {
             RGBColor[
             0.4567987908974691, 0.5661452243795493, 0.9514143990758924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 221}], {
             RGBColor[
             0.6539051547364543, 0.7193770778557486, 0.8587360957458993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 253}], {
             RGBColor[
             0.6503738092968374, 0.7179167757650288, 0.9172596285093968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 287}], {
             RGBColor[
             0.6549769778662253, 0.7191554199411984, 0.792643141267459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 301}], {
             RGBColor[
             0.5827013791316755, 0.6654207190141541, 0.9634359259845977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 316}], {
             RGBColor[
             0.5456424274121584, 0.6362276987053636, 0.9598065311526836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 336}], {
             RGBColor[
             0.6532820007328024, 0.7191193876609112, 0.8690633702572761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 354}], {
             RGBColor[
             0.6507863596934338, 0.7180873759560829, 0.9104226007915939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 388}], {
             RGBColor[
             0.3154426693714862, 0.4476423184251921, 0.9413207058507189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 436}], {
             RGBColor[
             0.6443856410957969, 0.7136357110267961, 0.9356762933605629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 473}], {
             RGBColor[
             0.654711792952513, 0.7185882162250756, 0.763779399941477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 62}], {
             RGBColor[
             0.9035404132128968, 0.9026424325114184, 0.6772410946024027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 96}], {
             RGBColor[
             0.9616573180033068, 0.9487481616061939, 0.6746328131090228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 108}], {
             RGBColor[
             0.9858135686385638, 0.9634216766405268, 0.4322370390473591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 113}], {
             RGBColor[
             0.9613409038086063, 0.9485121804178669, 0.6751684198066119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 157}], {
             RGBColor[
             0.8875459640147294, 0.8900779478414704, 0.6756653603852185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 190}], {
             RGBColor[
             0.9829042494945521, 0.9539941606513274, 0.38808666685826926`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 378}], {
             RGBColor[
             0.9822934585768839, 0.9638234499292624, 0.6255898718453303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 161}], {
             RGBColor[
             0.7881784862329527, 0.833365171868486, 0.9199132644584666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 183}], {
             RGBColor[
             0.4876217389756706, 0.5930587252478856, 0.9533186699277942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 202}], {
             RGBColor[
             0.7879364381844138, 0.833265078780064, 0.923924627023025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 206}], {
             RGBColor[
             0.7727735079910962, 0.8222039510586702, 0.9606688342680445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 243}], {
             RGBColor[
             0.7920048597798737, 0.8349474756634525, 0.8565003524486732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 273}], {
             RGBColor[
             0.761722893056658, 0.7256320479168811, 0.6130169375216071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 283}], {
             RGBColor[
             0.6306503347926729, 0.7105889694451832, 0.9643673607977004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 285}], {
             RGBColor[
             0.7770178887656718, 0.825369403290813, 0.9534842047284859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 396}], {
             RGBColor[
             0.6902979493211491, 0.7571861392534895, 0.9703124775752493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 421}], {
             RGBColor[
             0.7305921008336841, 0.7890765171774755, 0.9742192154554148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 430}], {
             RGBColor[
             0.7870902813103009, 0.8179176747566101, 0.6765901702441784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 477}], {
             RGBColor[
             0.7493915067811379, 0.8040666531836949, 0.9760123195771107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 44}], {
             RGBColor[
             0.7873097413942728, 0.7659422855436172, 0.6195295474003268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 56}], {
             RGBColor[
             0.8055333243677195, 0.8479168111450484, 0.9395636050225296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.8015847781640485, 0.8449719918515015, 0.9462474637995599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 132}], {
             RGBColor[
             0.8111320368917863, 0.8488638589325161, 0.7376036450392394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.7788041130756098, 0.8278000823294523, 0.9784947371928197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 356}], {
             RGBColor[
             0.7732231752555391, 0.8233499940022494, 0.9779624223613794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 365}], {
             RGBColor[
             0.8111507907594195, 0.8505882067661872, 0.8620710076618685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 457}], {
             RGBColor[
             0.7983830661808156, 0.80634564259862, 0.6466606193366032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 485}], {
             RGBColor[
             0.6105465120189026, 0.6947081891206934, 0.9624836044131447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 494}], {
             RGBColor[
             0.7930902857065416, 0.8386368132851476, 0.9606264238116631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 108}], {
             RGBColor[
             0.9941817642017419, 0.9900045949607075, 0.611071255172997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 113}], {
             RGBColor[
             0.9697090993717843, 0.9750950987380476, 0.8540026359322499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 119}], {
             RGBColor[
             0.6544434714896167, 0.719194512429468, 0.8349225527968683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 315}], {
             RGBColor[
             0.9898437840763257, 0.9900681579597863, 0.8179783115069528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 364}], {
             RGBColor[
             0.9882623359951941, 0.9704232742963557, 0.5552271776873541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 378}], {
             RGBColor[
             0.9906616541400618, 0.9904063682494431, 0.8044240879709683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 380}], {
             RGBColor[
             0.953592613913299, 0.8404589980197057, 0.4883250436010148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 381}], {
             RGBColor[
             0.9952447378778619, 0.9922781881708039, 0.7267693799055607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 416}], {
             RGBColor[
             0.9828970853017773, 0.9849306770512914, 0.8316788157303772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 452}], {
             RGBColor[
             0.9376799958938162, 0.9497747553736184, 0.8585334086377197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 468}], {
             RGBColor[
             0.8855383946171491, 0.9085552397155723, 0.8534654172266043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 487}], {
             RGBColor[
             0.8277769156578592, 0.8634315333490756, 0.8477082928156527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[
             0.9625953327477017, 0.8770559374048531, 0.4999932697361091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 137}], {
             RGBColor[
             0.9269217743323614, 0.7479762176425824, 0.26005774814263843`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 148}], {
             RGBColor[
             0.8500353470872022, 0.7909829568947018, 0.6202898359103811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 156}], {
             RGBColor[
             0.9351513831470762, 0.8583382621767337, 0.6248162834470985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 227}], {
             RGBColor[
             0.9623011239351209, 0.8769342745000293, 0.5048690711485744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 229}], {
             RGBColor[
             0.9622045809215612, 0.8768943514828802, 0.5064690387285677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 250}], {
             RGBColor[
             0.9295508070074727, 0.8539792348629119, 0.6279821475348073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 263}], {
             RGBColor[
             0.961744496220756, 0.8767040946354596, 0.5140938328819499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 267}], {
             RGBColor[
             0.9447050701173105, 0.8654633862764076, 0.6086443834071207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 393}], {
             RGBColor[
             0.9591091038419459, 0.8756142921603269, 0.5577691047756822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 485}], {
             RGBColor[
             0.7612932059507656, 0.720887341654153, 0.6119710147551323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 56}], {
             RGBColor[
             0.9638711701338285, 0.9041923510999015, 0.5951590343175865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 62}], {
             RGBColor[
             0.8871151004655318, 0.8441855633580295, 0.6293185600764523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 92}], {
             RGBColor[
             0.9599226239301575, 0.9012475318063546, 0.6018428930946169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 110}], {
             RGBColor[
             0.9693789367505923, 0.9068183830449486, 0.5194844461215349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 132}], {
             RGBColor[
             0.9694698826578952, 0.9051393988873693, 0.39319907433429635`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 157}], {
             RGBColor[
             0.8711206512673644, 0.8316210786880814, 0.6277428258592681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 356}], {
             RGBColor[
             0.9315610210216481, 0.8796255339571025, 0.6335578516564363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 360}], {
             RGBColor[
             0.9459021358321913, 0.8907910747393337, 0.6255759223155284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 365}], {
             RGBColor[
             0.9694886365255285, 0.9068637467210403, 0.5176664369569254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 457}], {
             RGBColor[
             0.9567209119469244, 0.8626211825534731, 0.30225604863166017`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 494}], {
             RGBColor[
             0.9514281314726505, 0.8949123532400007, 0.6162218531067201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 118}], {
             RGBColor[
             0.9281157997184212, 0.9422754093446686, 0.8631309252772917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 152}], {
             RGBColor[
             0.9844049872855851, 0.9583898918070279, 0.54700449736537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 185}], {
             RGBColor[
             0.9712726162559893, 0.9763710030111613, 0.8562746875191731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 187}], {
             RGBColor[
             0.9909631732343558, 0.9905310541436209, 0.799427136272115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 195}], {
             RGBColor[
             0.9943842881969276, 0.9910081120927117, 0.6745723510552455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 216}], {
             RGBColor[
             0.9742835821380069, 0.9786165764359659, 0.8511779076665904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 217}], {
             RGBColor[
             0.9472713303653721, 0.9575495095195194, 0.864957996890742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 224}], {
             RGBColor[
             0.6461034569920894, 0.7110929972378143, 0.8399280459078571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 292}], {
             RGBColor[
             0.9096799780701299, 0.9275751855893686, 0.8613725001506254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 328}], {
             RGBColor[
             0.9673837764373368, 0.973470712641801, 0.8628574789602865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 398}], {
             RGBColor[
             0.970736290564333, 0.9759710121884768, 0.8571825470190042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 399}], {
             RGBColor[
             0.9939297893107615, 0.9900359849320886, 0.6251029521380475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 464}], {
             RGBColor[
             0.8428982200116804, 0.8753659520431256, 0.8547266193480739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 481}], {
             RGBColor[
             0.9913266935618215, 0.9906813791410742, 0.793402663685558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 496}], {
             RGBColor[
             0.8179618786730491, 0.8558700402534891, 0.8522517627857437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 86}], {
             RGBColor[
             0.9738076585443516, 0.9230097180826233, 0.3568953767753456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 142}], {
             RGBColor[
             0.9744572398049036, 0.9256304342577324, 0.5171028019503494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 150}], {
             RGBColor[
             0.9506159965322813, 0.8419159130337758, 0.27912267549957104`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 194}], {
             RGBColor[
             0.9637620912046734, 0.8891560743755185, 0.31511401403968564`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 220}], {
             RGBColor[
             0.8116756757173064, 0.8001639047852591, 0.6251354881547413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 254}], {
             RGBColor[
             0.9730758826487391, 0.9250592075743987, 0.5399954648657215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 297}], {
             RGBColor[
             0.972850125264441, 0.9249658510942913, 0.5437368489649241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 325}], {
             RGBColor[
             0.8126324852334033, 0.8009113716512557, 0.6252308539854126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 350}], {
             RGBColor[
             0.9638600937330064, 0.8894866599156732, 0.31549473535603434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 377}], {
             RGBColor[
             0.9751337511692479, 0.9258460961187455, 0.5012323753002684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 392}], {
             RGBColor[
             0.9104443836981924, 0.8776933179588212, 0.6348814979197315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 412}], {
             RGBColor[
             0.9403290515722027, 0.9015225409238576, 0.6377319242199124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 426}], {
             RGBColor[
             0.8267088725636833, 0.8119079524181766, 0.6266338567231762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 476}], {
             RGBColor[
             0.9607714753743694, 0.9170289362057223, 0.6121588595306988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 55}], {
             RGBColor[
             0.9516098012066048, 0.9616433460564857, 0.8929221459045159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 59}], {
             RGBColor[
             0.9508888324024113, 0.9613452069278985, 0.9048704647974564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 73}], {
             RGBColor[
             0.9436685169941281, 0.956896280421248, 0.9590073543099058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 91}], {
             RGBColor[
             0.8807858286144589, 0.9077787277154983, 0.9884913326916802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 136}], {
             RGBColor[
             0.9530381481138425, 0.9612353543484782, 0.7966594385980781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 200}], {
             RGBColor[
             0.9482747759472753, 0.9602642274055131, 0.94819214522031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 228}], {
             RGBColor[
             0.8844250990739264, 0.6854902657678015, 0.5967915802005226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 256}], {
             RGBColor[
             0.9506632066478076, 0.9612519048800525, 0.9086096674519766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 298}], {
             RGBColor[
             0.9383158650885937, 0.9529042813942634, 0.9680679977907732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 416}], {
             RGBColor[
             0.9412557337627379, 0.955096830637847, 0.9630915669659986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 452}], {
             RGBColor[
             0.8960386443547766, 0.919940908960174, 0.9899461598733412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 468}], {
             RGBColor[
             0.8438970430781096, 0.8787213933021278, 0.9848781684622259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 117}], {
             RGBColor[
             0.538715224222069, 0.6363923137245855, 0.9568287823111009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 140}], {
             RGBColor[
             0.7418303205888741, 0.7962565508783768, 0.9360696573264341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 155}], {
             RGBColor[
             0.7481971327234107, 0.7976503635605303, 0.7228053950088827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 156}], {
             RGBColor[
             0.7215602900284801, 0.7811391952755637, 0.9703815317945119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 198}], {
             RGBColor[
             0.7481103543962663, 0.7974647534934032, 0.7133601096329684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 250}], {
             RGBColor[
             0.7159597138888765, 0.7767801679617421, 0.9735473958822207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 365}], {
             RGBColor[
             0.7483063915726862, 0.7995682923984768, 0.8571236663512694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 479}], {
             RGBColor[
             0.7261409502923875, 0.784555444200243, 0.9626276687952523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 51}], {
             RGBColor[
             0.7864478358555564, 0.8335957506356655, 0.9792174187923319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 100}], {
             RGBColor[
             0.8223581962145963, 0.8617744966446426, 0.9668604911389573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 203}], {
             RGBColor[
             0.8421310153899924, 0.8730171674842757, 0.7190554569167581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 264}], {
             RGBColor[
             0.8350989157103909, 0.8712765043835926, 0.945293776344414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 324}], {
             RGBColor[
             0.821169889960008, 0.8608882597856434, 0.9688719836680675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 360}], {
             RGBColor[
             0.8187609588788842, 0.859091682929604, 0.9729496756385605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 397}], {
             RGBColor[
             0.8427352878009805, 0.8743096450700668, 0.7848267797157757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 457}], {
             RGBColor[
             0.8295797349936176, 0.8309217907437434, 0.6496298019546923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 82}], {
             RGBColor[
             0.6023576854558552, 0.6858044061960582, 0.9632287301611053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 126}], {
             RGBColor[
             0.8645562503372615, 0.8532398454507559, 0.6458058634684232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 131}], {
             RGBColor[
             0.8743031213909678, 0.9018218127915065, 0.9450851315352286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 173}], {
             RGBColor[
             0.5966056537461728, 0.6808222854346512, 0.9628622157868864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 242}], {
             RGBColor[
             0.823327261769214, 0.862405780262226, 0.9828933368994337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 323}], {
             RGBColor[
             0.8795809634164782, 0.9030094617416623, 0.781746798573214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 340}], {
             RGBColor[
             0.8713753203190971, 0.8996382635459397, 0.9500411350570888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 373}], {
             RGBColor[
             0.8574513095263236, 0.82742760268326, 0.6278164735981588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 414}], {
             RGBColor[
             0.8801927768703229, 0.9043180688556073, 0.848338917349249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 449}], {
             RGBColor[
             0.7847676316075227, 0.8317857053574838, 0.9791819615143115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 499}], {
             RGBColor[
             0.8066075089700329, 0.8490739032257585, 0.9812985919515482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 60}], {
             RGBColor[
             0.7864478358555564, 0.8335957506356655, 0.9792174187923319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 96}], {
             RGBColor[
             0.9131734309044234, 0.9333686093997298, 0.9834289673569885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 100}], {
             RGBColor[
             0.9174407988163849, 0.936551205401297, 0.9762054265898412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 110}], {
             RGBColor[
             0.9373203623990739, 0.9498956999918733, 0.876203134895451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 203}], {
             RGBColor[
             0.9372136179917808, 0.9477938762409301, 0.728400392367642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 240}], {
             RGBColor[
             0.9357989055798288, 0.9432647583023676, 0.7022382010606607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 264}], {
             RGBColor[
             0.9301815183121793, 0.946053213140247, 0.9546387117952979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 324}], {
             RGBColor[
             0.9162524925617965, 0.9356649685422979, 0.9782169191189514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 360}], {
             RGBColor[
             0.9138435614806728, 0.9338683916862585, 0.9822946110894444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 397}], {
             RGBColor[
             0.937817890402769, 0.9490863538267212, 0.7941717151666596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 457}], {
             RGBColor[
             0.9246623375954061, 0.9056984995003978, 0.6589747374055762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 495}], {
             RGBColor[
             0.9117931684708855, 0.9323392119367695, 0.9857653916268704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 170}], {
             RGBColor[
             0.9653250294957026, 0.9735140234107316, 0.9370407464703573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 214}], {
             RGBColor[
             0.9896947350739465, 0.9900065223669179, 0.8204484392028291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 268}], {
             RGBColor[
             0.9888948748103898, 0.9874645451360538, 0.6729722455272894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 466}], {
             RGBColor[
             0.9613802231098749, 0.970571993267209, 0.9437182747112798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 491}], {
             RGBColor[
             0.9788822214460464, 0.9538227161414927, 0.6227484510118803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 83}], {
             RGBColor[
             0.8769211602163154, 0.9017875149994502, 0.85003586548136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 97}], {
             RGBColor[
             0.6976818683629066, 0.7566092492748719, 0.8351071315858012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 112}], {
             RGBColor[
             0.8785162434040754, 0.9030336061088096, 0.850194848466616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 163}], {
             RGBColor[
             0.9753077029553291, 0.9792347831400962, 0.8419616113451664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 207}], {
             RGBColor[
             0.922349231365462, 0.937514484492971, 0.8545004961153636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 257}], {
             RGBColor[
             0.9062804937266861, 0.5631792086043259, 0.4438579406141825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 266}], {
             RGBColor[
             0.8945837094867732, 0.9155856327298783, 0.851796303326732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 281}], {
             RGBColor[
             0.9810523011564316, 0.9835190950725621, 0.8322375050218684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[
             0.9461258757564592, 0.9564733353305336, 0.856768333683038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 317}], {
             RGBColor[
             0.84330361035357, 0.8755252295438315, 0.8466851822849065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 322}], {
             RGBColor[
             0.9876518053854177, 0.9884409945208437, 0.8210662657885653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 343}], {
             RGBColor[
             0.9645046904787298, 0.9711281033104364, 0.8585213214382097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 374}], {
             RGBColor[
             0.99510750358982, 0.9919437698229185, 0.7088601426189302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 440}], {
             RGBColor[
             0.7726646999310309, 0.8189280928071878, 0.8406109619256072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 445}], {
             RGBColor[
             0.664308800752239, 0.7277031754896617, 0.8329806292282944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 471}], {
             RGBColor[
             0.9939127406990789, 0.9917162578031892, 0.7480360550365392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 61}], {
             RGBColor[
             0.9852782337311232, 0.976648755977348, 0.6562411547503312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 99}], {
             RGBColor[
             0.9147758151897731, 0.9336244493882941, 0.9480967235573914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 154}], {
             RGBColor[
             0.9633716442818923, 0.9721976120813822, 0.9466356199849577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 186}], {
             RGBColor[
             0.9816182121222234, 0.9858058725006884, 0.9157489400983467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 203}], {
             RGBColor[
             0.9885612545411075, 0.9874801168421465, 0.6896613713832315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 244}], {
             RGBColor[
             0.9847761344582264, 0.9879725546100475, 0.9019623803356696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 264}], {
             RGBColor[
             0.9815291548615062, 0.9857394537414634, 0.9158996908108874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 295}], {
             RGBColor[
             0.9081390472585265, 0.9283324707901844, 0.9474637027073964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 321}], {
             RGBColor[
             0.9882374639879221, 0.989403903322688, 0.8445991923949313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 341}], {
             RGBColor[
             0.9208104648181369, 0.9384363151957511, 0.94867231382614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 374}], {
             RGBColor[
             0.9895993656411333, 0.989700531515969, 0.802653358141945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 391}], {
             RGBColor[
             0.9718711663382544, 0.978536541714327, 0.932248146173922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 397}], {
             RGBColor[
             0.9891655269520958, 0.9887725944279377, 0.7554326941822491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 455}], {
             RGBColor[
             0.9889587014005139, 0.9897021535277508, 0.8326464219656947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 57}], {
             RGBColor[
             0.7314206280989511, 0.7862703330155164, 0.8729617277304149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 60}], {
             RGBColor[
             0.8413164674817943, 0.8747380131866308, 0.8821263973403382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 73}], {
             RGBColor[
             0.9833264174973442, 0.9859099188590128, 0.8604655197446183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 91}], {
             RGBColor[
             0.9204437291176748, 0.9367923661532632, 0.8899494981263927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 136}], {
             RGBColor[
             0.9926960486170584, 0.990248992786243, 0.6981176040327906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 200}], {
             RGBColor[
             0.9879326764504912, 0.989277865843278, 0.8496503106550225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 256}], {
             RGBColor[
             0.9903211071510235, 0.9902655433178174, 0.810067832886689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 298}], {
             RGBColor[
             0.9779737655918097, 0.9819179198320283, 0.8695261632254857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 434}], {
             RGBColor[
             0.98307102028797, 0.985719444038436, 0.8608978406018285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 92}], {
             RGBColor[
             0.9781462069036042, 0.9832220574077857, 0.9218769507168197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 110}], {
             RGBColor[
             0.987602519724039, 0.9887929086463796, 0.8395185037437378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 132}], {
             RGBColor[
             0.987693465631342, 0.9871139244888003, 0.7132331319564992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 324}], {
             RGBColor[
             0.9665346498867616, 0.9745621771968042, 0.9415322879672382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 342}], {
             RGBColor[
             0.8367299931805215, 0.8724929592901718, 0.9425327876406187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 360}], {
             RGBColor[
             0.964125718805638, 0.9727656003407648, 0.9456099799377312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 457}], {
             RGBColor[
             0.9749444949203712, 0.9445957081549041, 0.622290106253863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 494}], {
             RGBColor[
             0.9696517144460972, 0.9768868788414319, 0.9362559107289228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 60}], {
             RGBColor[
             0.5814693938709248, 0.6703513617078967, 0.9607078137315247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 73}], {
             RGBColor[
             0.7234793438864746, 0.7815232673802787, 0.9390469361358048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 91}], {
             RGBColor[
             0.6605966555068054, 0.7324057146745291, 0.9685309145175792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 131}], {
             RGBColor[
             0.7274995118960956, 0.7845215020994332, 0.9322418403232595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 136}], {
             RGBColor[
             0.7328489750061888, 0.7858623413075089, 0.776699020423977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 234}], {
             RGBColor[
             0.716858506015216, 0.7329234080337852, 0.6294890272960791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 240}], {
             RGBColor[
             0.7308204635951971, 0.7800203693745987, 0.6837285959998535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 434}], {
             RGBColor[
             0.7232239466771004, 0.7813327925597019, 0.939479256993015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 495}], {
             RGBColor[
             0.7068147264862539, 0.7690948230090007, 0.9672557865660631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 74}], {
             RGBColor[
             0.8133319540714454, 0.8509720330165793, 0.7641828295374069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 115}], {
             RGBColor[
             0.6624047804933797, 0.7360498043989314, 0.9670851897065682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 144}], {
             RGBColor[
             0.8113690652501357, 0.851458034463312, 0.8910425344239562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 145}], {
             RGBColor[
             0.8132080603048905, 0.8522185061784704, 0.8605656272000266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 215}], {
             RGBColor[
             0.657900759926376, 0.7325312293001639, 0.9666362710289145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 375}], {
             RGBColor[
             0.8130382982244618, 0.850343932853042, 0.7322202028270648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 402}], {
             RGBColor[
             0.7893121287025195, 0.8359483324000114, 0.9704888537583426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 417}], {
             RGBColor[
             0.800509586639877, 0.844299378195538, 0.9515344782351551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 87}], {
             RGBColor[
             0.9876151474608948, 0.9891465594459571, 0.8549125877513188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 91}], {
             RGBColor[
             0.9197227603134814, 0.9364942270246761, 0.9018978170193332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 188}], {
             RGBColor[
             0.9634308191464701, 0.9713113724100857, 0.9048714849157604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 200}], {
             RGBColor[
             0.9872117076462978, 0.9889797267146909, 0.861598629547963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 228}], {
             RGBColor[
             0.9233620307729491, 0.7142057650769793, 0.5101980645281756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 256}], {
             RGBColor[
             0.98960013834683, 0.9899674041892302, 0.8220161517796296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 279}], {
             RGBColor[
             0.9697204879879022, 0.9760021971336381, 0.8942247161755752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 287}], {
             RGBColor[
             0.9921685252311991, 0.9903646138471405, 0.7311212629046543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 298}], {
             RGBColor[
             0.9772527967876163, 0.9816197807034412, 0.8814744821184262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 335}], {
             RGBColor[
             0.9753011784534864, 0.9801642669453289, 0.8847780628945255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 409}], {
             RGBColor[
             0.8550634675772313, 0.8857423613230712, 0.8955167481623374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 468}], {
             RGBColor[
             0.8828339747771322, 0.9074368926113057, 0.8982846527898789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 73}], {
             RGBColor[
             0.8333751832693177, 0.8699909475513931, 0.9482116057457282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 131}], {
             RGBColor[
             0.8373953512789388, 0.8729891822705476, 0.941406509933183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.842744814389032, 0.8743300214786233, 0.7858636900339003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 240}], {
             RGBColor[
             0.8407163029780402, 0.8684880495457131, 0.6928932656097768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 434}], {
             RGBColor[
             0.8331197860599435, 0.8698004727308163, 0.9486439266029383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 495}], {
             RGBColor[
             0.816710565869097, 0.8575625031801151, 0.9764204561759865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 99}], {
             RGBColor[
             0.9158283373648979, 0.9225282647708895, 0.6932535660333278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 154}], {
             RGBColor[
             0.964424166457017, 0.9611014274639774, 0.691792462460894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 178}], {
             RGBColor[
             0.990290694271001, 0.9787215372249476, 0.573171711772501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 186}], {
             RGBColor[
             0.9826707342973482, 0.9747096878832837, 0.660905782574283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 203}], {
             RGBColor[
             0.9896137767162324, 0.9763839322247417, 0.43481821385916786`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 244}], {
             RGBColor[
             0.9858286566333512, 0.9768763699926426, 0.6471192228116058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 264}], {
             RGBColor[
             0.9825816770366309, 0.9746432691240586, 0.6610565332868238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 288}], {
             RGBColor[
             0.8854671469302124, 0.8986050427541376, 0.6902818017093779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 295}], {
             RGBColor[
             0.9091915694336512, 0.9172362861727796, 0.6926205451833328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 321}], {
             RGBColor[
             0.9892899861630469, 0.9783077187052833, 0.5897560348708677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 341}], {
             RGBColor[
             0.9218629869932617, 0.9273401305783462, 0.6938291563020764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 391}], {
             RGBColor[
             0.9729236885133792, 0.9674403570969223, 0.6774049886498585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 397}], {
             RGBColor[
             0.9902180491272206, 0.9776764098105328, 0.5005895366581856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 455}], {
             RGBColor[
             0.9900112235756386, 0.978605968910346, 0.5778032644416311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 96}], {
             RGBColor[
             0.8866995185610917, 0.9122590303123641, 0.9809038619641409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 108}], {
             RGBColor[
             0.9108557691963488, 0.926932545346697, 0.7385080879024772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 110}], {
             RGBColor[
             0.9108464500557423, 0.9287861209045076, 0.8736780295026034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 157}], {
             RGBColor[
             0.8125881645725144, 0.8535888165476406, 0.9819364092403366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 190}], {
             RGBColor[
             0.9079464500523371, 0.9175050293574974, 0.6943577157133873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 356}], {
             RGBColor[
             0.8730285343267981, 0.9015932718166617, 0.9877514350375048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 378}], {
             RGBColor[
             0.9073356591346688, 0.9273343186354326, 0.9318609207004485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 72}], {
             RGBColor[
             0.8027988444917573, 0.8219458936616805, 0.6648623701439087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 159}], {
             RGBColor[
             0.7864901270112492, 0.8336962522806088, 0.9713113338345105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 166}], {
             RGBColor[
             0.7448859115389417, 0.8007506469293735, 0.9752641722670224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 222}], {
             RGBColor[
             0.8116419265775718, 0.8506817021944899, 0.8493498286342571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 239}], {
             RGBColor[
             0.810344187851967, 0.847398108546539, 0.6941746042797907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 272}], {
             RGBColor[
             0.8032921355879599, 0.8236098803594287, 0.6667787129024482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 344}], {
             RGBColor[
             0.7837707615633533, 0.8316681539821205, 0.9759145102136986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 387}], {
             RGBColor[
             0.6743613725834381, 0.7453219931004033, 0.9683236709896672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 435}], {
             RGBColor[
             0.7749233521094585, 0.8247016866956998, 0.9781291701633781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 439}], {
             RGBColor[
             0.6805664302575075, 0.7501694313155713, 0.9689421331490575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 453}], {
             RGBColor[
             0.7981482358022182, 0.8062582985370166, 0.6467956335788082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 74}], {
             RGBColor[
             0.9723590243775175, 0.9760157403407492, 0.7660264159494133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 115}], {
             RGBColor[
             0.8214318507994518, 0.8610935117231013, 0.9689287761185745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 170}], {
             RGBColor[
             0.9482597237277661, 0.9609327671898704, 0.9724669710903138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 215}], {
             RGBColor[
             0.8169278302324481, 0.8575749366243339, 0.9684798574409209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 223}], {
             RGBColor[
             0.9130541039910411, 0.9331155431710159, 0.977942463171481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 268}], {
             RGBColor[
             0.9718295690424532, 0.9748832889151926, 0.7083984701472459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 86}], {
             RGBColor[
             0.9858314959654313, 0.9638360366067513, 0.40221469720074715`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 177}], {
             RGBColor[
             0.869775975766155, 0.8769855061082863, 0.6750472797658544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 194}], {
             RGBColor[
             0.9757859286257532, 0.9299823928996465, 0.3604333344650872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 290}], {
             RGBColor[
             0.8056665186132637, 0.8267474796369882, 0.6687635806969818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 297}], {
             RGBColor[
             0.9848739626855207, 0.9657921696184194, 0.5890561693903256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 350}], {
             RGBColor[
             0.9758839311540861, 0.9303129784398012, 0.3608140557814359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 412}], {
             RGBColor[
             0.9523528889932824, 0.9423488594479856, 0.6830512446453141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 484}], {
             RGBColor[
             0.9871438220637472, 0.9667308148040412, 0.551438725285346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 114}], {
             RGBColor[
             0.9649035032588247, 0.9733456707124462, 0.9442933937371605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 128}], {
             RGBColor[
             0.9116112898094233, 0.732829989983826, 0.5881334739635166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 179}], {
             RGBColor[
             0.5950010777358334, 0.6653547986507187, 0.9500721232357557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 245}], {
             RGBColor[
             0.8690876577961304, 0.8982749232218534, 0.9712657595465645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 255}], {
             RGBColor[
             0.9555274744311419, 0.9164887015176435, 0.6262330104136532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 260}], {
             RGBColor[
             0.9725625502974566, 0.9778449079938524, 0.8770139420317549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 294}], {
             RGBColor[
             0.9285439054909315, 0.945397261997248, 0.977012767003286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 299}], {
             RGBColor[
             0.9736334778420206, 0.976866306635863, 0.7559409524346485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 312}], {
             RGBColor[
             0.8911076397814799, 0.9155465999008935, 0.9734420625601696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 327}], {
             RGBColor[
             0.9718948978666528, 0.9775688165558302, 0.8880786706392777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 334}], {
             RGBColor[
             0.9260659954885162, 0.9434214438223975, 0.9767764217351993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 385}], {
             RGBColor[
             0.9263068643748991, 0.9436135061341873, 0.9767993960246086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 415}], {
             RGBColor[
             0.973311081479197, 0.9781544448738759, 0.8646088432137173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 446}], {
             RGBColor[
             0.9717681863766762, 0.977516418098388, 0.890178607947016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 119}], {
             RGBColor[
             0.47131211741296464`, 0.5778791850010452, 0.9525703728502231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 120}], {
             RGBColor[
             0.8075324007706204, 0.8490919095174375, 0.9220370938693887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 124}], {
             RGBColor[
             0.6788407497605009, 0.7488297468193728, 0.9687643696545176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 363}], {
             RGBColor[
             0.8120350036061048, 0.8507952134305046, 0.835885999428212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 381}], {
             RGBColor[
             0.81211338380121, 0.8509628607423811, 0.8444171999589154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 95}], {
             RGBColor[
             0.6474770356591748, 0.713529617223368, 0.865905122141071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 286}], {
             RGBColor[
             0.6135894248128706, 0.689153704920316, 0.9665889663107053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 319}], {
             RGBColor[
             0.515481952955039, 0.6116732381208212, 0.9570329533738722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 330}], {
             RGBColor[
             0.6218425743852507, 0.6956187380193257, 0.9633611497735137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 352}], {
             RGBColor[
             0.648025454275736, 0.7114043047846377, 0.6858437386780041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 357}], {
             RGBColor[
             0.648646158848258, 0.7127319291024036, 0.7534036008524467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 367}], {
             RGBColor[
             0.6469413785142522, 0.7133081092281819, 0.8747823472686942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 368}], {
             RGBColor[
             0.6465603323434858, 0.71315053684413, 0.8810972684341727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 375}], {
             RGBColor[
             0.648342907504093, 0.7120833051406483, 0.7203965634904299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 450}], {
             RGBColor[
             0.44684368117626205`, 0.5572533662313527, 0.9507381030259514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 492}], {
             RGBColor[
             0.6280551244054082, 0.7002520476522422, 0.9528449230819367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 101}], {
             RGBColor[
             0.9811056926296612, 0.9838349957725321, 0.845473933206502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 103}], {
             RGBColor[
             0.9941994408744024, 0.9912903848258348, 0.7037103143971167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 129}], {
             RGBColor[
             0.6718410987023015, 0.7345908505971563, 0.8480643366042229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 204}], {
             RGBColor[
             0.9635595056511443, 0.9706880148100397, 0.8730579430754937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 209}], {
             RGBColor[
             0.9122288971786278, 0.9297583809463041, 0.86816198381601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 231}], {
             RGBColor[
             0.9924274776084806, 0.9911365816332274, 0.7751598232946215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 233}], {
             RGBColor[
             0.9907996821392983, 0.9904634463742852, 0.8021366068186084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 259}], {
             RGBColor[
             0.9859690890611457, 0.9874621088680524, 0.837241471624937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 275}], {
             RGBColor[
             0.9920683540286648, 0.9909880748039186, 0.7811114303942026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 306}], {
             RGBColor[
             0.9903019126270933, 0.9902576058888954, 0.8103859358220471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 331}], {
             RGBColor[
             0.9940954674262908, 0.9910679961336522, 0.6923934462199128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 346}], {
             RGBColor[
             0.9706158325065084, 0.9760116752682544, 0.8632305302013078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 348}], {
             RGBColor[
             0.9894421140144426, 0.9765437324728813, 0.5746074524646969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 355}], {
             RGBColor[
             0.8425766076072234, 0.8752591135126198, 0.8612426143238725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 372}], {
             RGBColor[
             0.9942119006158756, 0.991317034952973, 0.7050664803638724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 404}], {
             RGBColor[
             0.907809866895817, 0.580256586609705, 0.4605760807780218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 418}], {
             RGBColor[
             0.8631921440790288, 0.8913641272882744, 0.8632973783362403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 431}], {
             RGBColor[
             0.9933416746251214, 0.9894557095520937, 0.6103477516825486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 444}], {
             RGBColor[
             0.9771129400916736, 0.9808572074672333, 0.8522326217766718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 486}], {
             RGBColor[
             0.980394435494203, 0.9833045413654841, 0.8466779060112619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 76}], {
             RGBColor[
             0.9571759808071649, 0.9675824971206551, 0.9573740735871785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 111}], {
             RGBColor[
             0.966407290680152, 0.9744671929090463, 0.9417478738834273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 130}], {
             RGBColor[
             0.9284649702615446, 0.9454075267962436, 0.9795433224844532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 175}], {
             RGBColor[
             0.7624705935066816, 0.8139902072188918, 0.9638977547259691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 182}], {
             RGBColor[
             0.8636474383074593, 0.894075242812576, 0.9732677026556057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 208}], {
             RGBColor[
             0.9522017024497905, 0.9638726884663585, 0.9657942293466375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[
             0.9727961748417946, 0.9774698849489507, 0.8520214984405772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 351}], {
             RGBColor[
             0.9236240649768156, 0.9415475203250743, 0.9790815926168686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 359}], {
             RGBColor[
             0.8633180106383765, 0.8938178914137456, 0.9732348683842281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 371}], {
             RGBColor[
             0.6667417035477267, 0.7343554543827009, 0.9568914996447486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 403}], {
             RGBColor[
             0.9161337929422624, 0.9355749807227396, 0.978367163783568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 442}], {
             RGBColor[
             0.9719877301620239, 0.9771355722977849, 0.8654195189721412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 463}], {
             RGBColor[
             0.9723777423057595, 0.9772968523420744, 0.8589560084313703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 483}], {
             RGBColor[
             0.9167639062752874, 0.936077415990523, 0.9784272645557808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 135}], {
             RGBColor[
             0.9515647548001718, 0.9613325223181126, 0.880980526993644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 153}], {
             RGBColor[
             0.8741347024012432, 0.9024753002130919, 0.9878569423359334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 169}], {
             RGBColor[
             0.9523231361615861, 0.9607272256621843, 0.8016173585300785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 172}], {
             RGBColor[
             0.9113558984269835, 0.8106757704381943, 0.6197986476120528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 197}], {
             RGBColor[
             0.6714612354310349, 0.7402205985645749, 0.9700489091127615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 201}], {
             RGBColor[
             0.9491734572067784, 0.9603436593096994, 0.9206105165959668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 211}], {
             RGBColor[
             0.9506094330398303, 0.960937472219562, 0.8968126808559664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 236}], {
             RGBColor[
             0.9450997379744888, 0.957924422644321, 0.9552235002566656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 289}], {
             RGBColor[
             0.9517883187384266, 0.9595833052723821, 0.7434057825297109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 308}], {
             RGBColor[
             0.7489066830888886, 0.8036597486180106, 0.9759894638179019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 362}], {
             RGBColor[
             0.8881292057772988, 0.913634137334484, 0.9891917505609822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 369}], {
             RGBColor[
             0.8832368086907529, 0.9097330726982535, 0.988725109359373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 466}], {
             RGBColor[
             0.9240594826632195, 0.9422326346834325, 0.9908391643211872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 470}], {
             RGBColor[
             0.9522597894933875, 0.9616199370253342, 0.8694620034349312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 493}], {
             RGBColor[
             0.941853304726726, 0.9264677475134868, 0.6710030206961974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 128}], {
             RGBColor[
             0.9233830143481176, 0.717695949457537, 0.28936445588613163`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 159}], {
             RGBColor[
             0.9608673973891588, 0.9464221761505489, 0.6722829091986504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 179}], {
             RGBColor[
             0.606772802274528, 0.6502207581244297, 0.6513031051583709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 222}], {
             RGBColor[
             0.9860191969554816, 0.9634076260644299, 0.550321403998397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 245}], {
             RGBColor[
             0.8808593823348249, 0.8831408826955645, 0.6724967414691796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 294}], {
             RGBColor[
             0.9403156300296258, 0.9302632214709591, 0.678243748925901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 344}], {
             RGBColor[
             0.9581480319412631, 0.9443940778520605, 0.6768860855778385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 438}], {
             RGBColor[
             0.9592754352915421, 0.945234893424745, 0.6749776857797025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 439}], {
             RGBColor[
             0.8549437006354172, 0.8628953551855112, 0.6699137085131974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 453}], {
             RGBColor[
             0.9725255061801279, 0.9189842224069567, 0.3477672089429481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 91}], {
             RGBColor[
             0.9125024449051984, 0.9320453005180255, 0.9560347065317827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 136}], {
             RGBColor[
             0.984754764404582, 0.9855019271510053, 0.7642028124381804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 200}], {
             RGBColor[
             0.9799913922380148, 0.9845308002080403, 0.9157355190604124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 240}], {
             RGBColor[
             0.9827262529935901, 0.9796599552180951, 0.6712323880140569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 256}], {
             RGBColor[
             0.982379822938547, 0.9855184776825796, 0.876153041292079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 298}], {
             RGBColor[
             0.9700324813793332, 0.9771708541967905, 0.9356113716308756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 434}], {
             RGBColor[
             0.9751297360754934, 0.9809723784031983, 0.9269830490072184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 115}], {
             RGBColor[
             0.8428505647015491, 0.8741773076666377, 0.7670257551324582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 144}], {
             RGBColor[
             0.991814849458305, 0.9895855377310183, 0.6909830998498462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 215}], {
             RGBColor[
             0.8383465441345452, 0.8706587325678702, 0.7665768364548045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 268}], {
             RGBColor[
             0.9932482829445505, 0.987967084858729, 0.5064954491611294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 402}], {
             RGBColor[
             0.9697579129106889, 0.9740758356677177, 0.7704294191842326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 417}], {
             RGBColor[
             0.9809553708480464, 0.9824268814632443, 0.7514750436610451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 104}], {
             RGBColor[
             0.9943081968010611, 0.990234133424076, 0.6218605314122165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 125}], {
             RGBColor[
             0.9880489354466631, 0.9882363165286856, 0.780653172120191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 147}], {
             RGBColor[
             0.943206388278212, 0.9536631007324663, 0.8173918913383207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 303}], {
             RGBColor[
             0.9711906641250392, 0.9108381868334297, 0.46106859163444913`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 310}], {
             RGBColor[
             0.9940481122489815, 0.9896778388657597, 0.5935519329741512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 323}], {
             RGBColor[
             0.9942520436265769, 0.9901140274618111, 0.6157486049068341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 379}], {
             RGBColor[
             0.967814340603173, 0.9731453888255188, 0.814905063162666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 400}], {
             RGBColor[
             0.9578612486502911, 0.8579914962404493, 0.45034343106187275`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 408}], {
             RGBColor[
             0.9593249058035422, 0.966515569081662, 0.8189292899290571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 111}], {
             RGBColor[
             0.9727894356633944, 0.9792269861877452, 0.930944567156798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 130}], {
             RGBColor[
             0.934847115244787, 0.9501673200749425, 0.9687400157578238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 175}], {
             RGBColor[
             0.768852738489924, 0.8187500004975907, 0.9530944479993396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.8700295832907017, 0.8988350360912749, 0.9624643959289763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 351}], {
             RGBColor[
             0.9300062099600581, 0.9463073136037732, 0.9682782858902391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 359}], {
             RGBColor[
             0.8697001556216191, 0.8985776846924445, 0.9624315616575987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 371}], {
             RGBColor[
             0.6731238485309691, 0.7391152476613998, 0.9460881929181192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 460}], {
             RGBColor[
             0.9789011060500477, 0.9812196489824738, 0.780726633465442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 463}], {
             RGBColor[
             0.978759887289002, 0.9820566456207733, 0.848152701704741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 483}], {
             RGBColor[
             0.9231460512585299, 0.9408372092692219, 0.9676239578291514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 87}], {
             RGBColor[
             0.9760165099553175, 0.9814322874879888, 0.9164608345251977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 184}], {
             RGBColor[
             0.7823917007568656, 0.8296401463275233, 0.9514407674869665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 253}], {
             RGBColor[
             0.9759667191562339, 0.9814116977130027, 0.9172859969204707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 287}], {
             RGBColor[
             0.9805698877256217, 0.9826503418891723, 0.792669509678533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 301}], {
             RGBColor[
             0.9082942889910719, 0.928915640962128, 0.9634622943956717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 336}], {
             RGBColor[
             0.978874910592199, 0.9826143096088851, 0.8690897386683502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 354}], {
             RGBColor[
             0.9763792695528302, 0.9815822979040568, 0.9104489692026679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 388}], {
             RGBColor[
             0.6410355792308827, 0.711137240373166, 0.9413470742617929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 409}], {
             RGBColor[
             0.8434648300716538, 0.8780280893651029, 0.9570649949362162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 436}], {
             RGBColor[
             0.9699785509551934, 0.9771306329747701, 0.935702661771637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 473}], {
             RGBColor[
             0.9803047028119096, 0.9820831381730496, 0.763805768352551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 154}], {
             RGBColor[
             0.9664014118055395, 0.9734504988138841, 0.896424531331113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 171}], {
             RGBColor[
             0.9738153654195485, 0.9789798132799772, 0.8838746417313865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 192}], {
             RGBColor[
             0.9916472466219759, 0.9888532622173694, 0.6455699788051394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.9877415254708983, 0.9891988200008602, 0.8528181770697547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 219}], {
             RGBColor[
             0.9924731494761198, 0.9906197849107956, 0.7354644075971108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 258}], {
             RGBColor[
             0.9923646392610284, 0.9903876925327808, 0.7236537403318417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 262}], {
             RGBColor[
             0.9746150516730123, 0.9795762179784444, 0.8825209814958508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 376}], {
             RGBColor[
             0.966728765531004, 0.973694638686343, 0.8958704068614272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 497}], {
             RGBColor[
             0.9885669147833374, 0.9895401396930916, 0.8391393401235732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 127}], {
             RGBColor[
             0.626690368462307, 0.46568228771935194`, 0.5726752773536843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 147}], {
             RGBColor[
             0.872574415155287, 0.663505130600659, 0.5940923081139964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 184}], {
             RGBColor[
             0.7257069500378124, 0.5475128122157592, 0.5800711325325985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 221}], {
             RGBColor[
             0.9228133138767977, 0.7007446656919585, 0.48739282920260535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 234}], {
             RGBColor[
             0.9077012225972616, 0.6471703143142, 0.25303454161734407`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 253}], {
             RGBColor[
             0.9192819684371807, 0.6992843636012387, 0.5459163619661029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 301}], {
             RGBColor[
             0.8516095382720188, 0.6467883068503639, 0.5920926594413038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 316}], {
             RGBColor[
             0.8145505865525018, 0.6175952865415735, 0.5884632646093897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 336}], {
             RGBColor[
             0.9221901598731459, 0.700486975497121, 0.4977201037139823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 388}], {
             RGBColor[
             0.5843508285118295, 0.429009906261402, 0.5699774393074251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 436}], {
             RGBColor[
             0.9132938002361402, 0.6950032988630062, 0.564333026817269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 81}], {
             RGBColor[
             0.8715297819942989, 0.8151595144793455, 0.6240675394656382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 171}], {
             RGBColor[
             0.882650097101761, 0.9088042698504943, 0.9692900906428783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 192}], {
             RGBColor[
             0.9004819783041884, 0.9186777187878865, 0.7309854277166312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 208}], {
             RGBColor[
             0.8807821395216884, 0.907411150145776, 0.9724520555845779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 219}], {
             RGBColor[
             0.9013078811583324, 0.9204442414813128, 0.8208798565086026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 238}], {
             RGBColor[
             0.9013766119136924, 0.9210083466283681, 0.8586793246785176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 251}], {
             RGBColor[
             0.9012612889128468, 0.9203445853794177, 0.8158085781215096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 258}], {
             RGBColor[
             0.901199370943241, 0.920212149103298, 0.8090691892433335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 272}], {
             RGBColor[
             0.8930587035148951, 0.893949709063954, 0.6755798319074082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 293}], {
             RGBColor[
             0.8524822370136322, 0.8853074403266031, 0.9857659094636999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 403}], {
             RGBColor[
             0.8447142300141603, 0.8791134424021569, 0.9850249900215085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 447}], {
             RGBColor[
             0.6179926219911192, 0.6975299475745822, 0.9649938689089612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 471}], {
             RGBColor[
             0.9002691019562519, 0.9205503627992587, 0.8770336308172013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 483}], {
             RGBColor[
             0.8453443433471852, 0.8796158776699403, 0.9850850907937212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 497}], {
             RGBColor[
             0.8974016464655499, 0.9193645962636088, 0.9245547890350649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 121}], {
             RGBColor[
             0.6039029480095106, 0.5921879327578061, 0.6027416695535592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.9206204793600231, 0.8542058757542155, 0.6287756553983429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 208}], {
             RGBColor[
             0.944357211548269, 0.8726710374243304, 0.6150265622605272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 213}], {
             RGBColor[
             0.9406065945300424, 0.8698738333932086, 0.6213753785547997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 251}], {
             RGBColor[
             0.9648363609394275, 0.8856044726579722, 0.458383084797459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 442}], {
             RGBColor[
             0.9641432392605025, 0.8859339212557568, 0.5146518518860309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 447}], {
             RGBColor[
             0.6815676940176998, 0.6627898348531366, 0.6075683755849104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 454}], {
             RGBColor[
             0.9514362728737806, 0.877950589769998, 0.603043557951329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 500}], {
             RGBColor[
             0.8503422909900589, 0.7986076854759374, 0.6219557683706962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 126}], {
             RGBColor[
             0.7017331623152909, 0.7225599487258851, 0.6318048670839893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 149}], {
             RGBColor[
             0.6573101805271315, 0.7291790800422742, 0.9685876945903541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 173}], {
             RGBColor[
             0.4337825657242024, 0.5501423887097803, 0.9488612194024524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 242}], {
             RGBColor[
             0.6605041737472436, 0.7317258835373551, 0.9688923405149998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 249}], {
             RGBColor[
             0.6984671822566215, 0.7614369530136138, 0.9531114977889172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 269}], {
             RGBColor[
             0.716632003142388, 0.7733997365656291, 0.8514055935472499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 282}], {
             RGBColor[
             0.7173767939523384, 0.773653369229726, 0.835111267686065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 323}], {
             RGBColor[
             0.7167578753945077, 0.7723295650167914, 0.7677458021887802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 384}], {
             RGBColor[
             0.712832323724633, 0.7718284714790805, 0.9143761147545701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 411}], {
             RGBColor[
             0.684033875910875, 0.7504878293458843, 0.9711366245125801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 419}], {
             RGBColor[
             0.7160862789365061, 0.7708930881019437, 0.6946466723482017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 499}], {
             RGBColor[
             0.6437844209480625, 0.7183940065008876, 0.9672975955671144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 97}], {
             RGBColor[
             0.5793610411258499, 0.6661653470656702, 0.9616451158387962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 163}], {
             RGBColor[
             0.8569868757182724, 0.8887908809308944, 0.9684995955981615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 207}], {
             RGBColor[
             0.8040284041284051, 0.8470705822837694, 0.9810384803683585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 209}], {
             RGBColor[
             0.7946350726879177, 0.8395805947683141, 0.9801425360300389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 231}], {
             RGBColor[
             0.8748336531177705, 0.9009587954552374, 0.8871403755086504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 233}], {
             RGBColor[
             0.8732058576485882, 0.9002856601962952, 0.9141171590326375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 257}], {
             RGBColor[
             0.7879596664896293, 0.47273530639512423`, 0.5703959248671775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 317}], {
             RGBColor[
             0.7249827831165132, 0.7850813273346298, 0.9732231665379014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 326}], {
             RGBColor[
             0.8335594973555217, 0.8706178744229007, 0.983855182403079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 343}], {
             RGBColor[
             0.8461838632416729, 0.8806842011012347, 0.9850593056912047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 346}], {
             RGBColor[
             0.8530220080157982, 0.8858338890902644, 0.9752110824153368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 355}], {
             RGBColor[
             0.7249827831165132, 0.7850813273346298, 0.9732231665379014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 395}], {
             RGBColor[
             0.6297207802041395, 0.7084940548570626, 0.9652105261404427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 440}], {
             RGBColor[
             0.6543438726939741, 0.7284841905979862, 0.9671489461786023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 89}], {
             RGBColor[
             0.9745243315251053, 0.9297689180361777, 0.5411670531964766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 176}], {
             RGBColor[
             0.9752454137020871, 0.9279550020073795, 0.3756893336015333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 244}], {
             RGBColor[
             0.9714918345316748, 0.9285149025977761, 0.591423376228271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 245}], {
             RGBColor[
             0.871099880751439, 0.8502197922148593, 0.6345829207449541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 260}], {
             RGBColor[
             0.9745747732527653, 0.9297897769868583, 0.5403311032301445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 261}], {
             RGBColor[
             0.9722008518083252, 0.9288080994625839, 0.5796731250762815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 262}], {
             RGBColor[
             0.9583009842228134, 0.9188656792336711, 0.622193066042297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 299}], {
             RGBColor[
             0.9756457007973292, 0.928811175628869, 0.41925811363303817`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 328}], {
             RGBColor[
             0.9489255900644219, 0.9118735256211418, 0.6380631628580379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 376}], {
             RGBColor[
             0.950414698080805, 0.9129840999415697, 0.6355424914078733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 391}], {
             RGBColor[
             0.9585868664117029, 0.9190788897020558, 0.6217091420665236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 407}], {
             RGBColor[
             0.9694941603703728, 0.9087587811968094, 0.33599100289367245`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 448}], {
             RGBColor[
             0.9743605608283368, 0.9297011946443489, 0.54388115746691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 455}], {
             RGBColor[
             0.9756744014739623, 0.9302445015154794, 0.5221074178582963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 475}], {
             RGBColor[
             0.9673219826728432, 0.9014315157714643, 0.3275525027201085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 478}], {
             RGBColor[
             0.9408278115258615, 0.8026080453013619, 0.27385596309394183`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 482}], {
             RGBColor[
             0.9281023272214732, 0.8953855365002847, 0.6400958824503232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 146}], {
             RGBColor[
             0.9487461994959812, 0.9609006991841242, 0.957952727995834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 166}], {
             RGBColor[
             0.8908681103095499, 0.915818065462918, 0.9894529897203171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 239}], {
             RGBColor[
             0.9563263866225753, 0.9624655270800835, 0.7083634217330854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 332}], {
             RGBColor[
             0.8761906655460592, 0.9041146694171351, 0.9880530419360658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 387}], {
             RGBColor[
             0.8203435713540463, 0.8603894116339478, 0.9825124884429619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 489}], {
             RGBColor[
             0.935978913571386, 0.9513788782460733, 0.9795644128247024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 177}], {
             RGBColor[
             0.8764999999296572, 0.8996348047467245, 0.7039250744828682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 194}], {
             RGBColor[
             0.9825099527892556, 0.9526316915380848, 0.389311129182101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 220}], {
             RGBColor[
             0.8304235373018884, 0.8636395219478255, 0.6993326032971567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 254}], {
             RGBColor[
             0.9918237442333212, 0.988534824736965, 0.6141925800081368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 290}], {
             RGBColor[
             0.8123905427767659, 0.8493967782754266, 0.6976413754139956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 297}], {
             RGBColor[
             0.991597986849023, 0.9884414682568576, 0.6179339641073394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 350}], {
             RGBColor[
             0.9826079553175884, 0.9529622770782396, 0.3896918504984497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 377}], {
             RGBColor[
             0.9938816127538299, 0.9893217132813117, 0.5754294904426838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 412}], {
             RGBColor[
             0.9590769131567847, 0.964998158086424, 0.7119290393623279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 426}], {
             RGBColor[
             0.8454567341482654, 0.8753835695807428, 0.7008309718655916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 476}], {
             RGBColor[
             0.9795193369589514, 0.9805045533682886, 0.6863559746731143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 91}], {
             RGBColor[
             0.9175121436729424, 0.9355800802335569, 0.9385334556455427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 161}], {
             RGBColor[
             0.9857847646781377, 0.9883896491265951, 0.885246767340403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 184}], {
             RGBColor[
             0.7917797216219039, 0.8364402714943722, 0.9265281593392971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 228}], {
             RGBColor[
             0.92115141413241, 0.7132916182858601, 0.5468337031543851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 253}], {
             RGBColor[
             0.9853547400212722, 0.9882118228798517, 0.8923733887728015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 256}], {
             RGBColor[
             0.9873895217062911, 0.989053257398111, 0.858651790405839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 285}], {
             RGBColor[
             0.9746241672108568, 0.9803938805489221, 0.9188177076104224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 287}], {
             RGBColor[
             0.98995790859066, 0.9894504670560212, 0.7677569015308637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 336}], {
             RGBColor[
             0.9882629314572373, 0.9894144347757341, 0.8441771305206809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 354}], {
             RGBColor[
             0.9857672904178685, 0.9883824230709057, 0.8855363610549987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 388}], {
             RGBColor[
             0.650423600095921, 0.717937365540015, 0.9164344661141236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 409}], {
             RGBColor[
             0.8528528509366922, 0.8848282145319519, 0.9321523867885468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 436}], {
             RGBColor[
             0.9793665718202317, 0.983930758141619, 0.9107900536239677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 473}], {
             RGBColor[
             0.9896927236769479, 0.9888832633398985, 0.7388931602048816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 133}], {
             RGBColor[
             0.986793438425762, 0.9687958801480872, 0.5725206361475907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 241}], {
             RGBColor[
             0.7933860339100927, 0.8186901694947957, 0.670638748436988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 271}], {
             RGBColor[
             0.9756556833013112, 0.9295430448372477, 0.3599273559743963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 304}], {
             RGBColor[
             0.9553081572631896, 0.8532329657268115, 0.3208426737897673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 307}], {
             RGBColor[
             0.9870174399650502, 0.967294305848073, 0.4529264990370619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 311}], {
             RGBColor[
             0.9876404613832916, 0.9686268856645633, 0.5207385355701306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 337}], {
             RGBColor[
             0.9790983109307108, 0.9411558361986194, 0.3733013142289361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 423}], {
             RGBColor[
             0.9875921518159185, 0.968523556384799, 0.515480337293671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 427}], {
             RGBColor[
             0.9831331309252187, 0.9672822489310005, 0.6331814040037522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 433}], {
             RGBColor[
             0.9861272781323074, 0.968520405747205, 0.5835606361777094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 465}], {
             RGBColor[
             0.9785376552053404, 0.9640997406595972, 0.6519225418652693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 469}], {
             RGBColor[
             0.9856778875883975, 0.9683345712084881, 0.5910082004757427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 176}], {
             RGBColor[
             0.9921126335242971, 0.988894283473347, 0.626850082738412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 178}], {
             RGBColor[
             0.9928210919915348, 0.9912993512960486, 0.7686366143260449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 244}], {
             RGBColor[
             0.9883590543538848, 0.9894541840637436, 0.8425841253651498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 261}], {
             RGBColor[
             0.9890680716305351, 0.9897473809285513, 0.8308338742131604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 262}], {
             RGBColor[
             0.9751682040450234, 0.9798049606996386, 0.8733538151791758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 299}], {
             RGBColor[
             0.9925129206195392, 0.9897504570948363, 0.670418862769917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 328}], {
             RGBColor[
             0.965792809886632, 0.9728128070871092, 0.8892239119949167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 376}], {
             RGBColor[
             0.9672819179030151, 0.9739233814075372, 0.8867032405447521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 391}], {
             RGBColor[
             0.9754540862339129, 0.9800181711680231, 0.8728698912034024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 407}], {
             RGBColor[
             0.9863613801925828, 0.9696980626627768, 0.5871517520305513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 448}], {
             RGBColor[
             0.9912277806505467, 0.9906404761103162, 0.7950419066037888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 455}], {
             RGBColor[
             0.9925416212961724, 0.9911837829814469, 0.7732681669951751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 475}], {
             RGBColor[
             0.9841892024950532, 0.9623707972374318, 0.5787132518569873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 478}], {
             RGBColor[
             0.9576950313480714, 0.8635473267673293, 0.5250167122308207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 482}], {
             RGBColor[
             0.9449695470436832, 0.9563248179662522, 0.891256631587202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 137}], {
             RGBColor[
             0.9590518235881735, 0.8630071043917522, 0.4971420790895025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 148}], {
             RGBColor[
             0.8821653963430143, 0.9060138436438716, 0.8573741668572452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 229}], {
             RGBColor[
             0.9943346301773734, 0.99192523823205, 0.7435533696754317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 232}], {
             RGBColor[
             0.9895519102696952, 0.9899474606399299, 0.8228154158280175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 263}], {
             RGBColor[
             0.9938745454765681, 0.9917349813846295, 0.751178163828814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 267}], {
             RGBColor[
             0.9768351193731226, 0.9804942730255775, 0.8457287143539847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 280}], {
             RGBColor[
             0.9299821198799945, 0.9437344096593233, 0.862043024707637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 342}], {
             RGBColor[
             0.8430453076286408, 0.875452933016517, 0.8534750420122106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 393}], {
             RGBColor[
             0.991239153097758, 0.9906451789094968, 0.7948534357225463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 480}], {
             RGBColor[
             0.9623704315589027, 0.8761642791351432, 0.4998123089604919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 485}], {
             RGBColor[
             0.7934232552065776, 0.8359182284033229, 0.8490553457019964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 200}], {
             RGBColor[
             0.9171087038583454, 0.9354132475022907, 0.9452194974421868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 228}], {
             RGBColor[
             0.8532590269849967, 0.6606392858645791, 0.5938189324223995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 256}], {
             RGBColor[
             0.9194971345588776, 0.93640092497683, 0.9056370196738535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 287}], {
             RGBColor[
             0.9220655214432467, 0.9367981346347403, 0.8147421307988781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 298}], {
             RGBColor[
             0.9071497929996639, 0.928053301491041, 0.96509535001265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 336}], {
             RGBColor[
             0.9203705443098239, 0.936762102354453, 0.8911623597886953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 132}], {
             RGBColor[
             0.983744919427671, 0.9841691051952536, 0.7199169907335295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 250}], {
             RGBColor[
             0.9514169956114945, 0.9631053285921898, 0.9608080828871098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 342}], {
             RGBColor[
             0.8327814469768505, 0.869548139996625, 0.949216646417649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 356}], {
             RGBColor[
             0.9458360577914238, 0.9586552402649868, 0.9602757680556695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 365}], {
             RGBColor[
             0.9837636732953042, 0.9858934530289245, 0.8443843533561586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 457}], {
             RGBColor[
             0.9709959487167001, 0.9416508888613573, 0.6289739650308934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 485}], {
             RGBColor[
             0.7831593945547872, 0.830013435383431, 0.9447969501074349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 494}], {
             RGBColor[
             0.9657031682424262, 0.9739420595478852, 0.9429397695059532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 141}], {
             RGBColor[
             0.9902820830039931, 0.9884209147777157, 0.6778025670154282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 151}], {
             RGBColor[
             0.9904796476501863, 0.988843485579073, 0.6993062595258894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 160}], {
             RGBColor[
             0.9910249025098847, 0.9900097305902452, 0.7586538860811276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 167}], {
             RGBColor[
             0.9058663279030197, 0.925910719557556, 0.9207783147486966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 172}], {
             RGBColor[
             0.9498420264158245, 0.8394970467197582, 0.553364270501848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 201}], {
             RGBColor[
             0.9876595851956194, 0.9891649355912634, 0.8541761394857619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 218}], {
             RGBColor[
             0.9882311607056757, 0.9819096753715371, 0.6352265165997832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 235}], {
             RGBColor[
             0.9887345348989887, 0.9836076747234628, 0.6371820302865637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 236}], {
             RGBColor[
             0.9835858659633298, 0.9867456989258849, 0.8887891231464607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 274}], {
             RGBColor[
             0.970860813733625, 0.9772553758083318, 0.9103293173461915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 284}], {
             RGBColor[
             0.9701514191383643, 0.9767263104807133, 0.9115301373562253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 289}], {
             RGBColor[
             0.9902744467272677, 0.988404581553946, 0.6769714054195061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 300}], {
             RGBColor[
             0.804733903424651, 0.8465593048741127, 0.910920241019761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 305}], {
             RGBColor[
             0.9897493151526309, 0.9870307668007323, 0.6411242599467927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 308}], {
             RGBColor[
             0.7873928110777297, 0.8324810248995744, 0.9095550867076969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 389}], {
             RGBColor[
             0.9907588477453115, 0.9894406663510862, 0.7296954668570153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 432}], {
             RGBColor[
             0.9626059640158742, 0.8901018059738901, 0.5636344343029702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 456}], {
             RGBColor[
             0.8722860041991201, 0.8996423806111833, 0.9174406656164786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 493}], {
             RGBColor[
             0.980339432715567, 0.9552890237950508, 0.6045686435859925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 123}], {
             RGBColor[
             0.9654500828277188, 0.9727128937895656, 0.8967762645518196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 139}], {
             RGBColor[
             0.9664938024244696, 0.9707806137622337, 0.7076496517664926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 158}], {
             RGBColor[
             0.9653162161143298, 0.9726575364633616, 0.8989947824286246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 193}], {
             RGBColor[
             0.9659284205351479, 0.9729106987243059, 0.8888489708414132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 401}], {
             RGBColor[
             0.9531839291839581, 0.9259072671143682, 0.6539041280068381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 410}], {
             RGBColor[
             0.8886912705027576, 0.9139599069244947, 0.9850014830091389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 428}], {
             RGBColor[
             0.9673586163410823, 0.9726303632837685, 0.8017793095769411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 437}], {
             RGBColor[
             0.7390259290424064, 0.79529850088911, 0.9712177311368272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 122}], {
             RGBColor[
             0.8929287849295866, 0.9150228376821836, 0.8856785869414389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 185}], {
             RGBColor[
             0.9697152154795325, 0.9757269777667221, 0.8820848488090729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 212}], {
             RGBColor[
             0.8989201491024958, 0.9197033369101146, 0.8862757501297129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 224}], {
             RGBColor[
             0.6445460562156327, 0.7104489719933751, 0.8657382071977568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 286}], {
             RGBColor[
             0.9575710720495072, 0.9663600478195982, 0.891899103013529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 319}], {
             RGBColor[
             0.8594636001916756, 0.8888795810201034, 0.8823430900766959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 330}], {
             RGBColor[
             0.9658242216218873, 0.9728250809186081, 0.8886712864763375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 357}], {
             RGBColor[
             0.9926278060848948, 0.9899382720016858, 0.6787137375552704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 367}], {
             RGBColor[
             0.9909230257508889, 0.990514452127464, 0.800092483971518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 368}], {
             RGBColor[
             0.9905419795801225, 0.9903568797434122, 0.8064074051369965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 492}], {
             RGBColor[
             0.9720367716420448, 0.9774583905515245, 0.8781550597847605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 110}], {
             RGBColor[
             0.9689633548461524, 0.9748918499992831, 0.8710697480092235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 136}], {
             RGBColor[
             0.969470409437899, 0.9741028802426874, 0.7900752385985568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.8707050693629245, 0.899694545642416, 0.9793281277469568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 240}], {
             RGBColor[
             0.9674418980269073, 0.9682609083097773, 0.6971048141744334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 360}], {
             RGBColor[
             0.9454865539277513, 0.9588645416936683, 0.977161224203217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 457}], {
             RGBColor[
             0.9563053300424845, 0.9306946495078077, 0.6538413505193488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 163}], {
             RGBColor[
             0.6777475838648636, 0.7436126152063162, 0.9535708617026026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 207}], {
             RGBColor[
             0.6247891122749964, 0.701892316559191, 0.9661097464727999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 209}], {
             RGBColor[
             0.6153957808345089, 0.6944023290437358, 0.9652138021344802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 231}], {
             RGBColor[
             0.6955943612643617, 0.7557805297306592, 0.8722116416130917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 233}], {
             RGBColor[
             0.6939665657951793, 0.7551073944717168, 0.8991884251370788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 257}], {
             RGBColor[
             0.6087203746362205, 0.327557040670546, 0.5554671909716187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 281}], {
             RGBColor[
             0.6834921820659661, 0.7478969271387821, 0.9438467553793046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 317}], {
             RGBColor[
             0.5457434912631045, 0.6399030616100515, 0.9582944326423428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 322}], {
             RGBColor[
             0.6900916862949522, 0.7528188265870637, 0.9326755161460016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 326}], {
             RGBColor[
             0.6543202055021129, 0.7254396086983226, 0.9689264485075204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 343}], {
             RGBColor[
             0.6669445713882642, 0.7355059353766564, 0.9701305717956459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 355}], {
             RGBColor[
             0.5457434912631045, 0.6399030616100515, 0.9582944326423428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 395}], {
             RGBColor[
             0.4504814883507307, 0.5633157891324845, 0.9502817922448841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 440}], {
             RGBColor[
             0.4751045808405654, 0.5833059248734078, 0.9522202122830435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 105}], {
             RGBColor[
             0.9191335889945326, 0.8868121659511407, 0.6371485730898431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 276}], {
             RGBColor[
             0.5925094230675021, 0.6112839082779337, 0.611019716505306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 347}], {
             RGBColor[
             0.7719684926278334, 0.7705045845790187, 0.6231887165789084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 382}], {
             RGBColor[
             0.9535129937211688, 0.9138443911718637, 0.6272189336332628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 425}], {
             RGBColor[
             0.8656542980875512, 0.8445347958756577, 0.6319506609139407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 462}], {
             RGBColor[
             0.9623418852644698, 0.9204289640288745, 0.6122739231941601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 131}], {
             RGBColor[
             0.9143756940638288, 0.9333316404219598, 0.949024835682653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 143}], {
             RGBColor[
             0.9171932715696174, 0.9271325083451998, 0.6985560776724663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 178}], {
             RGBColor[
             0.9197882757296509, 0.9356972306358938, 0.8650272805795611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 186}], {
             RGBColor[
             0.9121683157559981, 0.9316853812942298, 0.9527613513813433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 277}], {
             RGBColor[
             0.9191756701678846, 0.93349718248578, 0.7336737462169163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 288}], {
             RGBColor[
             0.8149647283888622, 0.8555807361650838, 0.9821373705164382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 295}], {
             RGBColor[
             0.8386891508923011, 0.8742119795837258, 0.984476113990393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 313}], {
             RGBColor[
             0.8205575356659132, 0.8599498797168257, 0.9826948092780591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 321}], {
             RGBColor[
             0.9187875676216968, 0.9352834121162295, 0.8816116036779279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 341}], {
             RGBColor[
             0.8513605684519115, 0.8843158239892924, 0.9856847251091366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 373}], {
             RGBColor[
             0.8975238821991847, 0.8589374303137132, 0.6317561777455831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 498}], {
             RGBColor[
             0.9155168562362228, 0.9214775657846213, 0.6920435206667005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 203}], {
             RGBColor[
             0.9731239783508208, 0.9759726222499071, 0.7160434647142674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 257}], {
             RGBColor[
             0.8853350795877124, 0.549428475705137, 0.5640332494682333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 264}], {
             RGBColor[
             0.9660918786712194, 0.974231959149224, 0.9422817841419233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 281}], {
             RGBColor[
             0.9601068870174578, 0.9697683621733731, 0.9524128138759191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 324}], {
             RGBColor[
             0.9521628529208364, 0.9638437145512748, 0.9658599914655768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 360}], {
             RGBColor[
             0.9497539218397127, 0.9620471376952355, 0.9699376834360698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 374}], {
             RGBColor[
             0.9741620894508465, 0.9781930369237295, 0.829035451472981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 397}], {
             RGBColor[
             0.973728250761809, 0.9772650998356982, 0.781814787513285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 457}], {
             RGBColor[
             0.960572697954446, 0.9338772455093749, 0.6466178097522016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 103}], {
             RGBColor[
             0.9815171515433847, 0.9834261954521384, 0.7965715022973218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 129}], {
             RGBColor[
             0.6591588093712838, 0.72672666122346, 0.9409255245044279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[
             0.9508772163201267, 0.9628238254363435, 0.9659191309756987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 276}], {
             RGBColor[
             0.5984445946188878, 0.6667166056806522, 0.9373286408399372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 306}], {
             RGBColor[
             0.9776196232960757, 0.9823934165151991, 0.9032471237222521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 331}], {
             RGBColor[
             0.9814131780952732, 0.9832038067599559, 0.7852546341201179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 347}], {
             RGBColor[
             0.7779036641792192, 0.8259372819817372, 0.9494976409135396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 390}], {
             RGBColor[
             0.9684834116154337, 0.9407612584266491, 0.635316338465219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 431}], {
             RGBColor[
             0.9806593852941037, 0.9815915201783973, 0.7032089395827537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 486}], {
             RGBColor[
             0.9677121461631853, 0.9754403519917878, 0.939539093911467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 134}], {
             RGBColor[
             0.9935482588656113, 0.9904950105350794, 0.6762606202829615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 174}], {
             RGBColor[
             0.9737840413100614, 0.9772340759397362, 0.7759572787461286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 210}], {
             RGBColor[
             0.8426831505758763, 0.874198128817451, 0.7791519645168404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 225}], {
             RGBColor[
             0.9934797856209397, 0.9884622456750147, 0.5316930868171981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 247}], {
             RGBColor[
             0.800086151153041, 0.8403666787040613, 0.7752853061123426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 252}], {
             RGBColor[
             0.9945091806550646, 0.9908923763895818, 0.6603356594458443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 278}], {
             RGBColor[
             0.9826237381144992, 0.983826707342811, 0.7609939778183846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 309}], {
             RGBColor[
             0.9196634933607662, 0.9345405869688632, 0.7867702902663104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 383}], {
             RGBColor[
             0.9063899636986685, 0.9239663754186889, 0.7855016642749033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 393}], {
             RGBColor[
             0.9908769960449935, 0.9893903747104307, 0.720530358227176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 451}], {
             RGBColor[
             0.8849216266754076, 0.9071951473707129, 0.7833619010734405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 480}], {
             RGBColor[
             0.962008274506138, 0.8749094749360771, 0.42548923146512174`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 129}], {
             RGBColor[
             0.672252557616025, 0.7341820502767626, 0.7991619056950425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 204}], {
             RGBColor[
             0.963970964564868, 0.970279214489646, 0.8241555121663134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 209}], {
             RGBColor[
             0.9126403560923513, 0.9293495806259104, 0.8192595529068296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 231}], {
             RGBColor[
             0.9928389365222041, 0.9907277813128337, 0.7262573923854412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 233}], {
             RGBColor[
             0.9912111410530218, 0.9900546460538915, 0.7532341759094283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 259}], {
             RGBColor[
             0.9863805479748692, 0.9870533085476587, 0.7883390407157569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 275}], {
             RGBColor[
             0.9924798129423883, 0.9905792744835249, 0.7322089994850223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 326}], {
             RGBColor[
             0.9515647807599554, 0.960386860280497, 0.8229721992798699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 346}], {
             RGBColor[
             0.971027291420232, 0.9756028749478607, 0.8143280992921276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 348}], {
             RGBColor[
             0.9898535729281661, 0.9761349321524876, 0.5257050215555166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 355}], {
             RGBColor[
             0.8429880665209469, 0.8748503131922261, 0.8123401834146923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 390}], {
             RGBColor[
             0.981577159860175, 0.9482166474799518, 0.4935527196558337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 404}], {
             RGBColor[
             0.9082213258095405, 0.5798477862893113, 0.4116736498688416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 431}], {
             RGBColor[
             0.993753133538845, 0.9890469092317, 0.5614453207733685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 443}], {
             RGBColor[
             0.9896950731665517, 0.9894277130216684, 0.7783593442461602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 444}], {
             RGBColor[
             0.9775243990053972, 0.9804484071468396, 0.8033301908674916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 486}], {
             RGBColor[
             0.9808058944079265, 0.9828957410450904, 0.7977754751020816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 125}], {
             RGBColor[
             0.9878341983497012, 0.9877770155915349, 0.7572803643196282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 147}], {
             RGBColor[
             0.9429916511812501, 0.9532037997953156, 0.7940190835377577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 242}], {
             RGBColor[
             0.9377836048823507, 0.9490510450452241, 0.793522335432491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 303}], {
             RGBColor[
             0.9709759270280773, 0.9103788858962789, 0.4376957838338863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 310}], {
             RGBColor[
             0.9938333751520195, 0.9892185379286089, 0.5701791251735884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 323}], {
             RGBColor[
             0.9940373065296149, 0.9896547265246604, 0.5923757971062713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 379}], {
             RGBColor[
             0.9675996035062109, 0.9726860878883681, 0.7915322553621031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 408}], {
             RGBColor[
             0.9591101687065803, 0.9660562681445113, 0.7955564821284942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 109}], {
             RGBColor[
             0.9334735331942633, 0.9351841649158481, 0.6928565484345605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 205}], {
             RGBColor[
             0.9334559610658484, 0.9483329231254232, 0.9417770464575227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 230}], {
             RGBColor[
             0.9191159949471015, 0.8867528170978771, 0.6370802235379307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 382}], {
             RGBColor[
             0.9160935225198295, 0.9355511455296055, 0.9786502342856611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 425}], {
             RGBColor[
             0.8282348268862118, 0.8662415502333995, 0.9833819615663391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 462}], {
             RGBColor[
             0.9249224140631305, 0.9421357183866164, 0.9637052238465584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 484}], {
             RGBColor[
             0.9384471450593792, 0.9503969059743259, 0.8590602109145999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 156}], {
             RGBColor[
             0.948562131412888, 0.9611583023462873, 0.9719550737599583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 227}], {
             RGBColor[
             0.9757118722009328, 0.9797543146695831, 0.8520078614614341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 265}], {
             RGBColor[
             0.8446194263461075, 0.8790954601480763, 0.9655521598018573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 270}], {
             RGBColor[
             0.6154876667836202, 0.6863297659993808, 0.9480420248510621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 329}], {
             RGBColor[
             0.9752565599868952, 0.9795660313680883, 0.859553563158274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 479}], {
             RGBColor[
             0.9531427916767954, 0.9645745512709667, 0.9642012107606988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 153}], {
             RGBColor[
             0.8933755935308336, 0.9174767576582297, 0.9778796349393208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 170}], {
             RGBColor[
             0.9472451801786377, 0.960176122272093, 0.9741843286836522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 197}], {
             RGBColor[
             0.6907021265606252, 0.7552220560097127, 0.960071601716149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 214}], {
             RGBColor[
             0.9716148857568814, 0.9766686212282794, 0.8575920214161241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 223}], {
             RGBColor[
             0.9120395604419127, 0.9323588982532385, 0.9796598207648195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 236}], {
             RGBColor[
             0.964340629104079, 0.9729258800894589, 0.9452461928600532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 289}], {
             RGBColor[
             0.971029209868017, 0.9745847627175199, 0.7334284751330985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 314}], {
             RGBColor[
             0.9689859238464251, 0.968089856535111, 0.6916835863133757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 411}], {
             RGBColor[
             0.9387221888825144, 0.9536349018911197, 0.9822048336853477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 466}], {
             RGBColor[
             0.9433003737928098, 0.9572340921285705, 0.9808618569245748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 470}], {
             RGBColor[
             0.9715006806229778, 0.9766213944704721, 0.8594846960383187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 113}], {
             RGBColor[
             0.9686562597920583, 0.9728022932531455, 0.7364354131066865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 190}], {
             RGBColor[
             0.9902196054780041, 0.9782842734866057, 0.44935366015834377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 315}], {
             RGBColor[
             0.9887909444965997, 0.987775352474884, 0.7004110886813893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 349}], {
             RGBColor[
             0.9936139923881615, 0.9887493003797166, 0.546300665201133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 364}], {
             RGBColor[
             0.9872094964154681, 0.9681304688114536, 0.43765995486179077`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 378}], {
             RGBColor[
             0.9896088145603359, 0.9881135627645409, 0.6868568651454049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 380}], {
             RGBColor[
             0.9525397743335731, 0.8381661925348034, 0.3707578207754514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 416}], {
             RGBColor[
             0.9818442457220515, 0.9826378715663893, 0.7141115929048137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 452}], {
             RGBColor[
             0.9366271563140902, 0.9474819498887163, 0.7409661858121562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 487}], {
             RGBColor[
             0.8267240760781333, 0.8611387278641733, 0.7301410699900894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 164}], {
             RGBColor[
             0.8166945483651632, 0.843456592852914, 0.681349514337773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 180}], {
             RGBColor[
             0.9692584720215178, 0.9632646351674614, 0.6805477063676373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 205}], {
             RGBColor[
             0.9852153764669186, 0.9749981677323887, 0.6460537211498417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 230}], {
             RGBColor[
             0.9708754103481718, 0.9134180617048429, 0.34135689823024984`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 382}], {
             RGBColor[
             0.9678529379208995, 0.9622163901365711, 0.6829269089779801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 413}], {
             RGBColor[
             0.8703474432451469, 0.8853706421102612, 0.6866971334846006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 474}], {
             RGBColor[
             0.9863605810673992, 0.9754717392651033, 0.6270747172253759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 490}], {
             RGBColor[
             0.9894623199201814, 0.9767543879917813, 0.5756708773919371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 157}], {
             RGBColor[
             0.894852000857575, 0.9162216362345597, 0.8721022952854193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 356}], {
             RGBColor[
             0.9552923706118586, 0.9642260915035807, 0.8779173210825875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 360}], {
             RGBColor[
             0.9696334854224018, 0.9753916322858118, 0.8699353917416797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 457}], {
             RGBColor[
             0.980452261537135, 0.9472217400999512, 0.5466155180578114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 494}], {
             RGBColor[
             0.9751594810628611, 0.979512910786479, 0.8605813225328712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 130}], {
             RGBColor[
             0.9440784251177741, 0.9570520158633337, 0.9531138160540724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 175}], {
             RGBColor[
             0.778084048362911, 0.8256346962859819, 0.9374682482955883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 182}], {
             RGBColor[
             0.8792608931636887, 0.905719731879666, 0.946838196225225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 351}], {
             RGBColor[
             0.939237519833045, 0.9531920093921642, 0.9526520861864878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 359}], {
             RGBColor[
             0.878931465494606, 0.9054623804808356, 0.9468053619538475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 371}], {
             RGBColor[
             0.6823551584039561, 0.7459999434497908, 0.9304619932143678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 460}], {
             RGBColor[
             0.9881324159230347, 0.988104344770865, 0.7651004337616907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 463}], {
             RGBColor[
             0.9879911971619889, 0.9889413414091645, 0.8325265020009898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 483}], {
             RGBColor[
             0.9323773611315168, 0.9477219050576129, 0.9519977581254001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 163}], {
             RGBColor[
             0.8585819589060324, 0.8900369720402537, 0.9686585785834174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 175}], {
             RGBColor[
             0.6679689252721096, 0.7394967528023972, 0.9682549724214985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 207}], {
             RGBColor[
             0.8056234873161652, 0.8483166733931287, 0.9811974633536146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 238}], {
             RGBColor[
             0.8782945066072226, 0.9029764305324561, 0.8563787161361066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 266}], {
             RGBColor[
             0.7778579654374765, 0.8263878216300358, 0.9784932705649829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 293}], {
             RGBColor[
             0.8294001317071624, 0.8672755242306911, 0.9834653009212889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 317}], {
             RGBColor[
             0.7265778663042732, 0.786327418443989, 0.9733821495231575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 343}], {
             RGBColor[
             0.847778946429433, 0.881930292210594, 0.9852182886764607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 359}], {
             RGBColor[
             0.7688163424038046, 0.819324436997251, 0.9775920860797576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 403}], {
             RGBColor[
             0.8216321247076905, 0.861081526306245, 0.9827243814790976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 440}], {
             RGBColor[
             0.6559389558817341, 0.7297302817073454, 0.9673079291638582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 445}], {
             RGBColor[
             0.5475830567029422, 0.6385053643898193, 0.9596775964665454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 463}], {
             RGBColor[
             0.8778760740711875, 0.9028033979255798, 0.8633132261268999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 471}], {
             RGBColor[
             0.8771869966497821, 0.9025184467033467, 0.8747330222747902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 483}], {
             RGBColor[
             0.8222622380407154, 0.8615839615740284, 0.9827844822513103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 190}], {
             RGBColor[
             0.9657469406480466, 0.9633747772639459, 0.6922850409175967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 315}], {
             RGBColor[
             0.9643182796666421, 0.9728658562522242, 0.9433424694406422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 349}], {
             RGBColor[
             0.9691413275582039, 0.9738398041570568, 0.7892320459603859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 353}], {
             RGBColor[
             0.9693357918413466, 0.9749407264806458, 0.8601893078005212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 364}], {
             RGBColor[
             0.9627368315855105, 0.9532209725887937, 0.6805913356210436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 378}], {
             RGBColor[
             0.9651361497303783, 0.9732040665418811, 0.9297882459046577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 380}], {
             RGBColor[
             0.9280671095036155, 0.8232566963121436, 0.6136892015347042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 487}], {
             RGBColor[
             0.8022514112481756, 0.8462292316415135, 0.9730724507493422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 128}], {
             RGBColor[
             0.9228821272759697, 0.7412357621120738, 0.5690548860378586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 138}], {
             RGBColor[
             0.9812385983151065, 0.9851776680019342, 0.9009377303741509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 179}], {
             RGBColor[
             0.60627191520238, 0.6737605707789664, 0.9309935353100978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 255}], {
             RGBColor[
             0.9667983118976884, 0.9248944736458913, 0.6071544224879952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 294}], {
             RGBColor[
             0.9398147429574779, 0.9538030341254958, 0.9579341790776279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 296}], {
             RGBColor[
             0.9834646412450392, 0.9860981939601552, 0.864046438210732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 312}], {
             RGBColor[
             0.9023784772480264, 0.9239523720291413, 0.9543634746345115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 327}], {
             RGBColor[
             0.9831657353331994, 0.985974588684078, 0.8690000827136197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 334}], {
             RGBColor[
             0.9373368329550628, 0.9518272159506452, 0.9576978338095412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 385}], {
             RGBColor[
             0.9375777018414455, 0.952019278262435, 0.9577208080989507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 415}], {
             RGBColor[
             0.9845819189457434, 0.9865602170021237, 0.8455302552880593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 446}], {
             RGBColor[
             0.9830390238432227, 0.9859221902266357, 0.871100020021358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 144}], {
             RGBColor[
             0.8408876758802394, 0.8746633091133704, 0.8938854600190074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 215}], {
             RGBColor[
             0.6874193705564797, 0.7557365039502223, 0.9694791966239658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 223}], {
             RGBColor[
             0.7835456443150728, 0.8312771104969043, 0.9789418023545258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 268}], {
             RGBColor[
             0.8423211093664849, 0.8730448562410811, 0.7093978093302907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 402}], {
             RGBColor[
             0.8188307393326233, 0.8591536070500698, 0.9733317793533938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 417}], {
             RGBColor[
             0.8300281972699808, 0.8675046528455964, 0.9543774038302064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 143}], {
             RGBColor[
             0.8960143924327576, 0.9103825777024601, 0.696499520325106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 165}], {
             RGBColor[
             0.8640512237039144, 0.8945725407042122, 0.9868586741874763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 185}], {
             RGBColor[
             0.875469954306541, 0.903361046153575, 0.9769752294599592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 187}], {
             RGBColor[
             0.8951605112849074, 0.9175210972860346, 0.9201276782129011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 224}], {
             RGBColor[
             0.5503007950426411, 0.6380830403802281, 0.9606285878486431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 277}], {
             RGBColor[
             0.8979967910310249, 0.9167472518430403, 0.731617188869556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 313}], {
             RGBColor[
             0.7993786565290535, 0.843199949074086, 0.9806382519306988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 333}], {
             RGBColor[
             0.8136495596301014, 0.854383621888479, 0.9820513184740194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 358}], {
             RGBColor[
             0.8942013791346042, 0.9171244714933123, 0.9360229800978623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 361}], {
             RGBColor[
             0.8119174548771886, 0.8530024885752373, 0.9818861087764184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 386}], {
             RGBColor[
             0.8835171635132787, 0.8682264900681653, 0.6479501458765853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 441}], {
             RGBColor[
             0.89880084606455, 0.9184670442573166, 0.8191336172163026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 140}], {
             RGBColor[
             0.7772624475562457, 0.8250219477496188, 0.9388590041534632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 155}], {
             RGBColor[
             0.7836292596907823, 0.8264157604317723, 0.7255947418359119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 156}], {
             RGBColor[
             0.7569924169958517, 0.8099045921468058, 0.9731708786215411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 198}], {
             RGBColor[
             0.783542481363638, 0.8262301503646452, 0.7161494564599975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 270}], {
             RGBColor[
             0.4239179523665839, 0.5350760557998991, 0.9492578297126448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 479}], {
             RGBColor[
             0.7615730772597591, 0.8133208410714851, 0.9654170156222814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 152}], {
             RGBColor[
             0.9179473025552811, 0.9086412905401677, 0.6705404863785666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 187}], {
             RGBColor[
             0.9245054885040518, 0.9407824528767608, 0.9229631252853117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.9279266034666237, 0.9412595108258517, 0.798108340068442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 255}], {
             RGBColor[
             0.9095401990290615, 0.8802821562644485, 0.6378804767274882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 260}], {
             RGBColor[
             0.9265752748953763, 0.9416383627406575, 0.8886614083455898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 292}], {
             RGBColor[
             0.8432222933398261, 0.8778265843225085, 0.984908489163822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 399}], {
             RGBColor[
             0.9274721045804575, 0.9402873836652285, 0.748638941151244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 446}], {
             RGBColor[
             0.9257809109745958, 0.9413098728451931, 0.9018260742608509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 464}], {
             RGBColor[
             0.7764405352813764, 0.8256173507762654, 0.9782626083612704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 481}], {
             RGBColor[
             0.9248690088315175, 0.9409327778742141, 0.9169386526987546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 496}], {
             RGBColor[
             0.7515041939427451, 0.8061214389866289, 0.9757877517989402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 120}], {
             RGBColor[
             0.6498726225554212, 0.7173043489297186, 0.9106733486143419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 124}], {
             RGBColor[
             0.5211809715453017, 0.6170421862316539, 0.9574006243994708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 363}], {
             RGBColor[
             0.6543752253909056, 0.7190076528427856, 0.8245222541731652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 364}], {
             RGBColor[
             0.647471203703343, 0.697320386280214, 0.6615112524856621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 381}], {
             RGBColor[
             0.6544536055860108, 0.7191753001546621, 0.8330534547038686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 416}], {
             RGBColor[
             0.6421059530099262, 0.7118277890351496, 0.937962890528685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 124}], {
             RGBColor[
             0.8574012549029575, 0.8882549107480462, 0.9268673454186365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 315}], {
             RGBColor[
             0.9852729351421301, 0.9881779944600368, 0.8937291073244263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 363}], {
             RGBColor[
             0.9905955087485614, 0.990220377359178, 0.7939889751923308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 381}], {
             RGBColor[
             0.9906738889436666, 0.9903880246710546, 0.8025201757230342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 196}], {
             RGBColor[
             0.6055326939191743, 0.6787546371606177, 0.9640292788457949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.6094046885186735, 0.6816423643931149, 0.9574750019667715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 307}], {
             RGBColor[
             0.6330675442580772, 0.6961604390582492, 0.7327779803490655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 337}], {
             RGBColor[
             0.6251484152237379, 0.6700219694087957, 0.6531527955409397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 420}], {
             RGBColor[
             0.6148066666960205, 0.6856711508728528, 0.9483308619740776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 427}], {
             RGBColor[
             0.6291832352182457, 0.6961483821411768, 0.9130328853157559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 442}], {
             RGBColor[
             0.6329413332491336, 0.697702452255663, 0.8507514752980027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 447}], {
             RGBColor[
             0.3503657880063309, 0.4745583658530428, 0.9436679989968821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 454}], {
             RGBColor[
             0.6202343668624117, 0.689719120769904, 0.9391431813633008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 489}], {
             RGBColor[
             0.6121364487429248, 0.6836797066955147, 0.9528508444642888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 500}], {
             RGBColor[
             0.51914038497869, 0.6103762164758437, 0.958055391782668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 185}], {
             RGBColor[
             0.8711853175133075, 0.9000138553262554, 0.9765481769066171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 212}], {
             RGBColor[
             0.8003902511362709, 0.8439902144696481, 0.9807390782272571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 216}], {
             RGBColor[
             0.8741962833953252, 0.90225942875106, 0.9714513970540342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 217}], {
             RGBColor[
             0.8471840316226904, 0.8811923618346136, 0.9852314862781859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 224}], {
             RGBColor[
             0.5460161582494076, 0.6347358495529084, 0.9602015352953008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 286}], {
             RGBColor[
             0.8590411740832823, 0.8906469253791316, 0.9863624311110732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 319}], {
             RGBColor[
             0.7609337022254506, 0.8131664585796368, 0.97680641817424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 330}], {
             RGBColor[
             0.8672943236556624, 0.8971119584781413, 0.9831346145738816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 357}], {
             RGBColor[
             0.8940979081186697, 0.9142251495612191, 0.7731770656528145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 492}], {
             RGBColor[
             0.8735068736758199, 0.9017452681110578, 0.9726183878823045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 139}], {
             RGBColor[
             0.991498137085153, 0.9883883905409109, 0.6187319228149053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 158}], {
             RGBColor[
             0.990320550775013, 0.9902653132420388, 0.8100770534770374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 193}], {
             RGBColor[
             0.9909327551958313, 0.9905184755029831, 0.7999312418898259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 401}], {
             RGBColor[
             0.9781882638446415, 0.9435150438930454, 0.5649863990552507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 410}], {
             RGBColor[
             0.913695605163441, 0.9315676837031719, 0.8960837540575517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 422}], {
             RGBColor[
             0.9917390632190122, 0.9908519045917394, 0.7865686312874436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 428}], {
             RGBColor[
             0.9923629510017655, 0.9902381400624458, 0.7128615806253538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 437}], {
             RGBColor[
             0.7640302637030898, 0.8129062776677871, 0.8823000021852399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 363}], {
             RGBColor[
             0.8619038577384419, 0.8899582146611134, 0.8407162509774597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 381}], {
             RGBColor[
             0.8619822379335471, 0.8901258619729899, 0.8492474515081632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 416}], {
             RGBColor[
             0.8496345853574625, 0.8827783508534774, 0.9541568873329795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.9283303503078408, 0.9445064246547528, 0.9520103302158197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 173}], {
             RGBColor[
             0.7048027355049116, 0.7654697333222589, 0.932283855027918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 242}], {
             RGBColor[
             0.9315243435279528, 0.9470532281498337, 0.9523149761404655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 249}], {
             RGBColor[
             0.9694873520373306, 0.9767642976260924, 0.9365341334143829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 269}], {
             RGBColor[
             0.9876521729230971, 0.9887270811781077, 0.8348282291727155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 282}], {
             RGBColor[
             0.9883969637330476, 0.9889807138422047, 0.8185339033115306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 305}], {
             RGBColor[
             0.98683593510245, 0.9853912200315494, 0.6699357561130831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 310}], {
             RGBColor[
             0.9875741137976215, 0.9872207210332185, 0.7289717658815629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 323}], {
             RGBColor[
             0.987778045175217, 0.98765690962927, 0.7511684378142458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 406}], {
             RGBColor[
             0.885815713934575, 0.91084830055465, 0.9478910553031907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 408}], {
             RGBColor[
             0.9528509073521823, 0.9640584512491208, 0.9543491228364687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 419}], {
             RGBColor[
             0.9871064487172153, 0.9862204327144223, 0.6780693079736673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 173}], {
             RGBColor[
             0.6959811306056086, 0.717577827964478, 0.6314383527097702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 249}], {
             RGBColor[
             0.9606657471380277, 0.9288723922683116, 0.6356886310962351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 269}], {
             RGBColor[
             0.9788305680237941, 0.9408351758203268, 0.5339827268545676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 282}], {
             RGBColor[
             0.9795753588337446, 0.9410888084844239, 0.5176884009933829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 340}], {
             RGBColor[
             0.970750797178533, 0.9363938060757666, 0.6186172719799726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 384}], {
             RGBColor[
             0.9750308886060393, 0.9392639107337784, 0.596953248061888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 414}], {
             RGBColor[
             0.9795682537297588, 0.9410736113854341, 0.5169150542721328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 449}], {
             RGBColor[
             0.8841431084669584, 0.8685412478873107, 0.6477580984371953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 499}], {
             RGBColor[
             0.9059829858294687, 0.8858294457555853, 0.6498747288744322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 184}], {
             RGBColor[
             0.4991383308479465, 0.6028176058374992, 0.9541122371221518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 221}], {
             RGBColor[
             0.6962446946869317, 0.7560494593136985, 0.8614339337921586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 253}], {
             RGBColor[
             0.6927133492473148, 0.7545891572229787, 0.919957466555656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 301}], {
             RGBColor[
             0.6250409190821529, 0.702093100472104, 0.9661337640308569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 303}], {
             RGBColor[
             0.6739900718122482, 0.6759850103233622, 0.6118101129996781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 316}], {
             RGBColor[
             0.5879819673626359, 0.6729000801633135, 0.9625043691989429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 138}], {
             RGBColor[
             0.9279463848657051, 0.744661987273314, 0.544777810600507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 179}], {
             RGBColor[
             0.5529797017529786, 0.4332448900503463, 0.5748336155364538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 222}], {
             RGBColor[
             0.9322260964339322, 0.7464317579903464, 0.4738519143764801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 245}], {
             RGBColor[
             0.8270662818132755, 0.666165014621481, 0.5960272518472626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 294}], {
             RGBColor[
             0.8865225295080765, 0.7132873533968757, 0.6017742593039841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 296}], {
             RGBColor[
             0.9301724277956378, 0.745582513231535, 0.5078865184370881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 312}], {
             RGBColor[
             0.8490862637986251, 0.6834366913005211, 0.5982035548608677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 385}], {
             RGBColor[
             0.8842854883920441, 0.7115035975338149, 0.6015608883253067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 415}], {
             RGBColor[
             0.931289705496342, 0.7460445362735035, 0.48937033551441544`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 438}], {
             RGBColor[
             0.9054823347699927, 0.7282590253506616, 0.5985081961577856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 439}], {
             RGBColor[
             0.8011506001138679, 0.6459194871114278, 0.5934442188912805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 204}], {
             RGBColor[
             0.641612622392767, 0.7135796802609675, 0.9685095343734196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 275}], {
             RGBColor[
             0.6701214707702874, 0.7338797402548464, 0.8765630216921284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 276}], {
             RGBColor[
             0.28918000069152805`, 0.4174724605052763, 0.9399190442376579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 306}], {
             RGBColor[
             0.6683550293687159, 0.7331492713398233, 0.905837527119973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 331}], {
             RGBColor[
             0.6721485841679135, 0.73395966158458, 0.7878450375178387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 346}], {
             RGBColor[
             0.648668949248131, 0.7189033407191822, 0.9586821214992336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 348}], {
             RGBColor[
             0.6674952307560652, 0.7194353979238091, 0.6700590437626227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 355}], {
             RGBColor[
             0.520629724348846, 0.6181507789635476, 0.9566942056217984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 431}], {
             RGBColor[
             0.671394791366744, 0.7323473750030215, 0.7057993429804745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 444}], {
             RGBColor[
             0.6551660568332962, 0.7237488729181611, 0.9476842130745977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 486}], {
             RGBColor[
             0.6584475522358256, 0.7261962068164118, 0.9421294973091877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 175}], {
             RGBColor[
             0.7401417279443037, 0.7965750301731793, 0.9752636968966142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 182}], {
             RGBColor[
             0.8413185727450814, 0.8766600657668635, 0.9846336448262509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 208}], {
             RGBColor[
             0.9298728368874126, 0.9464575114206459, 0.9771601715172826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 238}], {
             RGBColor[
             0.9504673092794167, 0.9600547079032381, 0.8633874406112223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 241}], {
             RGBColor[
             0.7561536695536321, 0.8095742457013815, 0.9765242155937752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 351}], {
             RGBColor[
             0.9012951994144377, 0.9241323432793617, 0.9904475347875137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 371}], {
             RGBColor[
             0.6444128379853488, 0.7169402773369883, 0.9682574418153937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 442}], {
             RGBColor[
             0.949658864599646, 0.9597203952520723, 0.8767854611427863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 483}], {
             RGBColor[
             0.8944350407129095, 0.9186622389448104, 0.9897932067264259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 186}], {
             RGBColor[
             0.9812180909962791, 0.9855130635343541, 0.9166770522236082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 234}], {
             RGBColor[
             0.97278446342323, 0.9355612285964361, 0.6101877234977374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 373}], {
             RGBColor[
             0.9665736574394657, 0.9127651125538374, 0.5956718785878481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 434}], {
             RGBColor[
             0.9791499040851145, 0.9839706131223527, 0.9201779531946732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 449}], {
             RGBColor[
             0.8938899795206647, 0.9171232152280612, 0.9470373665040007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 495}], {
             RGBColor[
             0.962740683894268, 0.9717326435716516, 0.9479544827677213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 250}], {
             RGBColor[
             0.9609642543392323, 0.9669971956732044, 0.7521642641267893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 356}], {
             RGBColor[
             0.9553833165191615, 0.9625471073460015, 0.7516319492953489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 365}], {
             RGBColor[
             0.993310932023042, 0.9897853201099391, 0.635740534595838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 457}], {
             RGBColor[
             0.980543207444438, 0.9455427559423719, 0.4203301462705728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 494}], {
             RGBColor[
             0.9752504269701641, 0.9778339266288998, 0.7342959507456326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 191}], {
             RGBColor[
             0.9758293102030231, 0.9800331095223662, 0.8603718343088441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 237}], {
             RGBColor[
             0.967898158707523, 0.9011681935791178, 0.5193724749301369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 241}], {
             RGBColor[
             0.7995786389237667, 0.8412618523055231, 0.8640210542430549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 271}], {
             RGBColor[
             0.9818482883149854, 0.9521147276479751, 0.5533096617804631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 304}], {
             RGBColor[
             0.9615007622768637, 0.8758046485375389, 0.5142249795958341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 311}], {
             RGBColor[
             0.9938330663969657, 0.9911985684752908, 0.7141208413761975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 351}], {
             RGBColor[
             0.9447201687845723, 0.9558199498835034, 0.8779443734367933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 366}], {
             RGBColor[
             0.8812957270609754, 0.9056542130462675, 0.8717868374925875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 371}], {
             RGBColor[
             0.6878378073554834, 0.74862788394113, 0.8557542804646734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 405}], {
             RGBColor[
             0.9834837765846647, 0.9857417980167562, 0.8474148193292916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 423}], {
             RGBColor[
             0.9937847568295927, 0.9910952391955264, 0.708862643099738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 429}], {
             RGBColor[
             0.9863453795373829, 0.9672844723083548, 0.5707800119750596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 469}], {
             RGBColor[
             0.9918704926020716, 0.9909062540192155, 0.7843905062818095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 488}], {
             RGBColor[
             0.7162603204366604, 0.7732460362150009, 0.8575653378651645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 174}], {
             RGBColor[
             0.9733312322776879, 0.9781518707189246, 0.8637864533368572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 210}], {
             RGBColor[
             0.8422303415435028, 0.8751159235966394, 0.866981139107569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 225}], {
             RGBColor[
             0.9930269765885663, 0.989380040454203, 0.6195222614079267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 247}], {
             RGBColor[
             0.7996333421206676, 0.8412844734832496, 0.8631144807030712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 252}], {
             RGBColor[
             0.9940563716226911, 0.9918101711687701, 0.748164834036573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 278}], {
             RGBColor[
             0.9821709290821258, 0.9847445021219994, 0.8488231524091132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 309}], {
             RGBColor[
             0.9192106843283928, 0.9354583817480516, 0.874599464857039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 424}], {
             RGBColor[
             0.9929165178672046, 0.9891437804183001, 0.6074995112599086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 169}], {
             RGBColor[
             0.9934584498437753, 0.9906440083089145, 0.6912791186082909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 211}], {
             RGBColor[
             0.9917447467220195, 0.9908542548662923, 0.7864744409341788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 362}], {
             RGBColor[
             0.929264519459488, 0.9435509199812142, 0.8788535106391946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 369}], {
             RGBColor[
             0.9243721223729422, 0.9396498553449837, 0.8783868694375854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 466}], {
             RGBColor[
             0.9651947963454086, 0.9721494173301628, 0.8805009243993996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 470}], {
             RGBColor[
             0.9933951031755767, 0.9915367196720645, 0.7591237635131436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 240}], {
             RGBColor[
             0.9920958841133044, 0.9839990291453253, 0.5088844723022291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 434}], {
             RGBColor[
             0.9844993671952077, 0.9853114523304285, 0.7646351332953907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 148}], {
             RGBColor[
             0.846491837927674, 0.776934123881601, 0.6174386452637746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 156}], {
             RGBColor[
             0.9316078739875481, 0.8442894291636328, 0.621965092800492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 227}], {
             RGBColor[
             0.9587576147755927, 0.8628854414869285, 0.5020178805019677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 229}], {
             RGBColor[
             0.9586610717620331, 0.8628455184697793, 0.5036178480819611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 263}], {
             RGBColor[
             0.9582009870612278, 0.8626552616223588, 0.5112426422353433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 265}], {
             RGBColor[
             0.8276651689207676, 0.7622265869654218, 0.6155621788423908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 267}], {
             RGBColor[
             0.9411615609577824, 0.8514145532633068, 0.605793192760514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 280}], {
             RGBColor[
             0.8943085614646541, 0.8146546898970526, 0.6221075031141664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 393}], {
             RGBColor[
             0.9555655946824178, 0.861565459147226, 0.5549179141290757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 424}], {
             RGBColor[
             0.9580579255370023, 0.860401070075907, 0.3540578925710795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 485}], {
             RGBColor[
             0.7577496967912374, 0.7068385086410522, 0.6091198241085257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 179}], {
             RGBColor[
             0.6113361727921154, 0.6771867959402068, 0.9067164598727462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 222}], {
             RGBColor[
             0.990582567473069, 0.990373663880207, 0.8057347587127726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 294}], {
             RGBColor[
             0.9448790005472133, 0.9572292592867362, 0.9336571036402765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 296}], {
             RGBColor[
             0.9885288988347745, 0.9895244191213955, 0.8397693627733804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 339}], {
             RGBColor[
             0.9901964968868171, 0.9902140137712303, 0.812132947445615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 385}], {
             RGBColor[
             0.9426419594311809, 0.9554455034236753, 0.9334437326615992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 415}], {
             RGBColor[
             0.9896461765354788, 0.989986442163364, 0.8212531798507079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 438}], {
             RGBColor[
             0.9638388058091296, 0.972200931240522, 0.9303910404940781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 158}], {
             RGBColor[
             0.9913642703717639, 0.9883330332147069, 0.6209504406917103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 247}], {
             RGBColor[
             0.7993565455450006, 0.8388061260829054, 0.6958722382810152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 278}], {
             RGBColor[
             0.9818941325064587, 0.9822661547216549, 0.6815809099870573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 401}], {
             RGBColor[
             0.9792319834413923, 0.9415827638657135, 0.37585978626992367`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 410}], {
             RGBColor[
             0.9147393247601918, 0.92963540367584, 0.7069571412722246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 428}], {
             RGBColor[
             0.9934066705985164, 0.9883058600351138, 0.5237349678400268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 437}], {
             RGBColor[
             0.7650739832998406, 0.8109739976404553, 0.6931733893999128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 451}], {
             RGBColor[
             0.8841920210673672, 0.905634594749557, 0.7039488332421133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 198}], {
             RGBColor[
             0.9866575777304432, 0.9860943875184364, 0.6953903314753307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 270}], {
             RGBColor[
             0.627033048733389, 0.6949402929536904, 0.928498704727978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 479}], {
             RGBColor[
             0.9646881736265642, 0.9731850782252762, 0.9446578906376146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 151}], {
             RGBColor[
             0.9933600335585147, 0.9882061081222784, 0.5186588138462958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 160}], {
             RGBColor[
             0.9939052884182131, 0.9893723531334506, 0.5780064404015339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 162}], {
             RGBColor[
             0.724339622770532, 0.7783158016209462, 0.7237171085432166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 167}], {
             RGBColor[
             0.9087467138113481, 0.9252733421007614, 0.740130869069103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 235}], {
             RGBColor[
             0.9916149208073171, 0.9829702972666681, 0.45653458460697005`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 274}], {
             RGBColor[
             0.9737411996419535, 0.9766179983515371, 0.7296818716665978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 284}], {
             RGBColor[
             0.9730318050466928, 0.9760889330239187, 0.7308826916766317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 300}], {
             RGBColor[
             0.8076142893329794, 0.8459219274173181, 0.7302727953401673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 345}], {
             RGBColor[
             0.9749927730190651, 0.9775514197269236, 0.7275632844017641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 389}], {
             RGBColor[
             0.9936392336536399, 0.9888032888942915, 0.5490480211774216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 432}], {
             RGBColor[
             0.9654863499242026, 0.8894644285170954, 0.3829869886233766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 456}], {
             RGBColor[
             0.8751663901074486, 0.8990050031543887, 0.736793219936885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 472}], {
             RGBColor[
             0.985320666505076, 0.9852539457784171, 0.7100808546759749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[
             0.9700134393774156, 0.9080122463714513, 0.5135272158169901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 161}], {
             RGBColor[
             0.9900098405929787, 0.9901368265968802, 0.8152263252855231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 183}], {
             RGBColor[
             0.6894530933356966, 0.7498303799762798, 0.8486317307548508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 254}], {
             RGBColor[
             0.9924733254938733, 0.9911555409120743, 0.7744000051831406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 285}], {
             RGBColor[
             0.9788492431256978, 0.9821410580192071, 0.8487972655555425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 388}], {
             RGBColor[
             0.654648676010762, 0.7196845430103, 0.8464140240592437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 396}], {
             RGBColor[
             0.892129303681175, 0.9139577939818837, 0.8656255384023058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 473}], {
             RGBColor[
             0.9939177995917889, 0.9906304408101836, 0.6688727181500018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 477}], {
             RGBColor[
             0.9512228611411638, 0.960838307912089, 0.8713253804041672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 165}], {
             RGBColor[
             0.9570974555868437, 0.9589510215103161, 0.702362174366915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 178}], {
             RGBColor[
             0.9916556284757205, 0.983325780799258, 0.5784742234116396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 186}], {
             RGBColor[
             0.9840356685020676, 0.979313931457594, 0.6662082942134215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 277}], {
             RGBColor[
             0.9910430229139542, 0.9811257326491442, 0.44712068904899455`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 288}], {
             RGBColor[
             0.8868320811349317, 0.903209286328448, 0.6955843133485164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 313}], {
             RGBColor[
             0.8924248884119828, 0.9075784298801899, 0.6961417521101374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 321}], {
             RGBColor[
             0.9906549203677664, 0.9829119622795937, 0.5950585465100062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 373}], {
             RGBColor[
             0.9693912349452543, 0.9065659804770774, 0.3452031205776615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 386}], {
             RGBColor[
             0.976563395396208, 0.9326049708742692, 0.36345364605602387`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 414}], {
             RGBColor[
             0.9921327022892535, 0.9834564466494247, 0.5657255643287517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 498}], {
             RGBColor[
             0.9873842089822924, 0.9691061159479855, 0.4054904634987788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 145}], {
             RGBColor[
             0.9916909556917501, 0.9908320108929094, 0.7873658975124658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 215}], {
             RGBColor[
             0.8363836553132356, 0.871144734014603, 0.8934365413413538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 246}], {
             RGBColor[
             0.9916670349663315, 0.9908221190582143, 0.7877623258375049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 375}], {
             RGBColor[
             0.9915211936113215, 0.988957437567481, 0.6590204731395041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 402}], {
             RGBColor[
             0.9677950240893792, 0.9745618371144504, 0.8972891240707819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 417}], {
             RGBColor[
             0.9789924820267367, 0.9829128829099771, 0.8783347485475945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 458}], {
             RGBColor[
             0.991941540250461, 0.9898565165250359, 0.704772610731079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 367}], {
             RGBColor[
             0.9919586596762355, 0.9909427133701728, 0.7829293496938386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 375}], {
             RGBColor[
             0.9933601886660762, 0.9897179092826394, 0.6285435659155745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 402}], {
             RGBColor[
             0.9696340191441339, 0.9753223088296088, 0.8668122168468522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 417}], {
             RGBColor[
             0.9808314770814914, 0.9836733546251354, 0.8478578413236648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 450}], {
             RGBColor[
             0.7918609623382453, 0.8348879703733436, 0.8588851054510958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 458}], {
             RGBColor[
             0.9937805353052157, 0.9906169882401943, 0.6742957035071493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 461}], {
             RGBColor[
             0.9626563235095822, 0.9700173641605596, 0.8751222248714484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 166}], {
             RGBColor[
             0.9192283381504669, 0.9373639577882127, 0.9551372880297929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 239}], {
             RGBColor[
             0.9846866144634923, 0.9840114194053783, 0.6740477200425612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 248}], {
             RGBColor[
             0.9586414949648607, 0.9686754751799056, 0.9548933403855078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 387}], {
             RGBColor[
             0.8487037991949633, 0.8819353039592426, 0.9481967867524377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 221}], {
             RGBColor[
             0.9421287413799118, 0.9538723021950055, 0.8828509645524707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 234}], {
             RGBColor[
             0.9270166501003756, 0.9002979508172471, 0.6484926769672095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 242}], {
             RGBColor[
             0.8866817963595017, 0.9124800123536145, 0.9890536953585949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 303}], {
             RGBColor[
             0.9198741185052282, 0.8738078532046694, 0.6332271437599903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 323}], {
             RGBColor[
             0.9429354980067659, 0.9530836938330507, 0.7879071570323752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 449}], {
             RGBColor[
             0.8481221661978103, 0.8818599374488723, 0.9853423199734728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 229}], {
             RGBColor[
             0.8817746445168737, 0.9058522577218987, 0.8638499358497038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 232}], {
             RGBColor[
             0.8769919246091955, 0.9038744801297787, 0.9431119820022895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 263}], {
             RGBColor[
             0.8813145598160684, 0.9056620008744782, 0.871474730003086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 267}], {
             RGBColor[
             0.8642751337126231, 0.8944212925154262, 0.9660252805282568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 280}], {
             RGBColor[
             0.8174221342194947, 0.857661429149172, 0.982339590881909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 342}], {
             RGBColor[
             0.7304853219681413, 0.7893799525063657, 0.9737716081864827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 393}], {
             RGBColor[
             0.8786791674372585, 0.9045721983993454, 0.9151500018968183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 480}], {
             RGBColor[
             0.849810445898403, 0.7900912986249918, 0.620108875134764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 485}], {
             RGBColor[
             0.680863269546078, 0.7498452478931716, 0.9693519118762683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 173}], {
             RGBColor[
             0.6515581488174492, 0.7241969592808671, 0.9682211802161351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 242}], {
             RGBColor[
             0.8782797568404903, 0.905780454108442, 0.9882523013286824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 249}], {
             RGBColor[
             0.9162427653498683, 0.9354915235847008, 0.9724714586026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 269}], {
             RGBColor[
             0.9344075862356347, 0.947454307136716, 0.8707655543609325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 282}], {
             RGBColor[
             0.9351523770455852, 0.947707939800813, 0.8544712284997477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 310}], {
             RGBColor[
             0.9343295271101592, 0.9459479469918268, 0.7649090910697799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 314}], {
             RGBColor[
             0.9320731939680327, 0.9389973545609624, 0.6999753379542907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 323}], {
             RGBColor[
             0.9345334584877545, 0.9463841355878783, 0.7871057630024627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 406}], {
             RGBColor[
             0.8325711272471127, 0.8695755265132583, 0.9838283804914078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 411}], {
             RGBColor[
             0.9018094590041219, 0.9245423999169711, 0.9904965853262627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 419}], {
             RGBColor[
             0.933861862029753, 0.9449476586730305, 0.7140066331618843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 220}], {
             RGBColor[
             0.8072318752898182, 0.782545716898978, 0.621559902021382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 254}], {
             RGBColor[
             0.9686320822212511, 0.9074410196881175, 0.5364198787323622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 325}], {
             RGBColor[
             0.8081886848059151, 0.7832931837649745, 0.6216552678520533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 392}], {
             RGBColor[
             0.9060005832707042, 0.86007513007254, 0.6313059117863722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 412}], {
             RGBColor[
             0.9358852511447145, 0.8839043530375764, 0.6341563380865534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 426}], {
             RGBColor[
             0.8222650721361953, 0.7942897645318954, 0.6230582705898171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 473}], {
             RGBColor[
             0.9700765563191667, 0.9069159195862269, 0.43089259169922345`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 160}], {
             RGBColor[
             0.9941028530644063, 0.989794923934808, 0.5995101329119952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 162}], {
             RGBColor[
             0.7245371874167252, 0.7787383724223036, 0.7452208010536778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 226}], {
             RGBColor[
             0.9908413916176795, 0.9801171405360922, 0.47426576094091166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 235}], {
             RGBColor[
             0.9918124854535102, 0.9833928680680255, 0.47803827711743124`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 237}], {
             RGBColor[
             0.968183936090159, 0.8997987515615284, 0.4065022571316866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 274}], {
             RGBColor[
             0.9739387642881467, 0.9770405691528945, 0.7511855641770591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 284}], {
             RGBColor[
             0.973229369692886, 0.9765115038252761, 0.7523863841870928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 345}], {
             RGBColor[
             0.9751903376652582, 0.9779739905282809, 0.7490669769122253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 389}], {
             RGBColor[
             0.9938367982998331, 0.9892258596956489, 0.5705517136878827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 456}], {
             RGBColor[
             0.8753639547536418, 0.899427573955746, 0.7582969124473462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 472}], {
             RGBColor[
             0.9855182311512691, 0.9856765165797745, 0.7315845471864362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 195}], {
             RGBColor[
             0.9842157910337876, 0.9573739932882109, 0.4819819121565203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 216}], {
             RGBColor[
             0.964115084974867, 0.9449824576314652, 0.6585874687678652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 217}], {
             RGBColor[
             0.9371028332022322, 0.9239153907150187, 0.6723675579920169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 292}], {
             RGBColor[
             0.89951148090699, 0.8939410667848677, 0.6687820612519002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 398}], {
             RGBColor[
             0.9605677934011929, 0.942336893383976, 0.664592108120279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 399}], {
             RGBColor[
             0.9837612921476214, 0.9564018661275877, 0.43251251323932227`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 464}], {
             RGBColor[
             0.8327297228485403, 0.8417318332386248, 0.6621361804493487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 481}], {
             RGBColor[
             0.9811581963986814, 0.9570472603365734, 0.6008122247868328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 496}], {
             RGBColor[
             0.8077933815099091, 0.8222359214489883, 0.6596613238870185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 172}], {
             RGBColor[
             0.8750611597102442, 0.7817353309799036, 0.6163368230325545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 197}], {
             RGBColor[
             0.6351664967142956, 0.7112801591062843, 0.9665870845332631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 201}], {
             RGBColor[
             0.9128787184900391, 0.9314032198514088, 0.9171486920164684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 223}], {
             RGBColor[
             0.856503930595583, 0.8884170013498099, 0.9861753035819336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 236}], {
             RGBColor[
             0.9088049992577494, 0.9289839831860303, 0.9517616756771673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 289}], {
             RGBColor[
             0.9154935800216873, 0.9306428658140915, 0.7399439579502126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 314}], {
             RGBColor[
             0.9134502940000955, 0.9241479596316826, 0.6981990691304898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 411}], {
             RGBColor[
             0.8831865590361847, 0.9096930049876912, 0.9887203165024618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 466}], {
             RGBColor[
             0.8877647439464802, 0.9132921952251418, 0.987377339741689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 470}], {
             RGBColor[
             0.9159650507766481, 0.9326794975670436, 0.8660001788554328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 493}], {
             RGBColor[
             0.9055585660099867, 0.8975273080551962, 0.667541196116699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 199}], {
             RGBColor[
             0.9638576906731449, 0.9723986047549877, 0.9385805734341622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[
             0.9677071872670013, 0.9719327883287759, 0.7252126790937943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 219}], {
             RGBColor[
             0.9685893146783662, 0.973819569664923, 0.8212268039615185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 244}], {
             RGBColor[
             0.9639220671841201, 0.9724252260966768, 0.9375136880462324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 295}], {
             RGBColor[
             0.8872849799844202, 0.9127851422768138, 0.9830150104179594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 341}], {
             RGBColor[
             0.8999563975440306, 0.9228889866823804, 0.9842236215367028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 374}], {
             RGBColor[
             0.968745298367027, 0.9741532030025983, 0.838204665852508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 376}], {
             RGBColor[
             0.9428449307332504, 0.9568944234404705, 0.9816328032258348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 397}], {
             RGBColor[
             0.9683114596779896, 0.973225265914567, 0.790984001892812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 455}], {
             RGBColor[
             0.9681046341264077, 0.9741548250143802, 0.8681977296762575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 198}], {
             RGBColor[
             0.9930243898649798, 0.98748820020059, 0.48212606915777934`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 250}], {
             RGBColor[
             0.9608737493575901, 0.966803614668929, 0.7423133554070316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 365}], {
             RGBColor[
             0.9932204270413998, 0.9895917391056637, 0.6258896258760804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 394}], {
             RGBColor[
             0.9939909612217342, 0.989555598597333, 0.5873313963535461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 467}], {
             RGBColor[
             0.9578178341510728, 0.9643669108338606, 0.7420218794865863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 479}], {
             RGBColor[
             0.9710549857611008, 0.9745788909074299, 0.7313936283200633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 198}], {
             RGBColor[
             0.9663875471700492, 0.9709770319156235, 0.7297022059434085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 227}], {
             RGBColor[
             0.9669872235903075, 0.9732474860210797, 0.8667764158064278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 250}], {
             RGBColor[
             0.9342369066626593, 0.9502924463839624, 0.9898894921926609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 263}], {
             RGBColor[
             0.9664305958759425, 0.97301730615651, 0.8760011775398033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 270}], {
             RGBColor[
             0.606763018172995, 0.6798229373508774, 0.9628105791960558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 479}], {
             RGBColor[
             0.9444181430661702, 0.9580677226224633, 0.9789697651056924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 485}], {
             RGBColor[
             0.7659793056059521, 0.8172005531752035, 0.9738783594129858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 190}], {
             RGBColor[
             0.8919520008541697, 0.9049405446875494, 0.6927819814962032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 356}], {
             RGBColor[
             0.8570340851286307, 0.8890287871467136, 0.9861757008203207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 360}], {
             RGBColor[
             0.8713751999391739, 0.9001943279289448, 0.9781937714794127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.9918492254979048, 0.9893703031930376, 0.6737348133760187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 193}], {
             RGBColor[
             0.9907988884824422, 0.9904631181767791, 0.8021497597666309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 247}], {
             RGBColor[
             0.7981789592348607, 0.8406830487840333, 0.8872173689431473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 278}], {
             RGBColor[
             0.9807165461963189, 0.9841430774227828, 0.8729260406491894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 370}], {
             RGBColor[
             0.9923153579901939, 0.9903673134608199, 0.7244704585254103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 401}], {
             RGBColor[
             0.9780543971312524, 0.9434596865668414, 0.5672049169320558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 410}], {
             RGBColor[
             0.9135617384500518, 0.9315123263769679, 0.8983022719343567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 422}], {
             RGBColor[
             0.9916051965056232, 0.9907965472655355, 0.7887871491642486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 428}], {
             RGBColor[
             0.9922290842883765, 0.9901827827362417, 0.7150800985021588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 437}], {
             RGBColor[
             0.7638963969897007, 0.8128509203415832, 0.8845185200620449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 451}], {
             RGBColor[
             0.8830144347572273, 0.9075115174506849, 0.8952939639042454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 166}], {
             RGBColor[
             0.9029544644363432, 0.9252269294182418, 0.982684711321764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 192}], {
             RGBColor[
             0.9687839632746547, 0.9728141725722297, 0.7296048477664128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 239}], {
             RGBColor[
             0.9684127407493686, 0.9718743910354074, 0.7015951433345324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 251}], {
             RGBColor[
             0.969563273883313, 0.9744810391637608, 0.8144279981712913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 272}], {
             RGBColor[
             0.9613606884853613, 0.948086162848297, 0.6741992519571899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 344}], {
             RGBColor[
             0.9418393144607549, 0.9561444364709889, 0.9833350492684403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 435}], {
             RGBColor[
             0.93299190500686, 0.9491779691845681, 0.9855497092181198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 439}], {
             RGBColor[
             0.8386349831549089, 0.8746457138044397, 0.9763626722037992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 453}], {
             RGBColor[
             0.9562167886996196, 0.930734581025885, 0.6542161726335498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 167}], {
             RGBColor[
             0.9094895333172397, 0.926862157913291, 0.8209821881348024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 235}], {
             RGBColor[
             0.9923577403132087, 0.9845591130791977, 0.5373859036726695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 237}], {
             RGBColor[
             0.9687291909498574, 0.9009649965727007, 0.4658498836869248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 274}], {
             RGBColor[
             0.9744840191478451, 0.9782068141640667, 0.8105331907322972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 284}], {
             RGBColor[
             0.9737746245525845, 0.9776777488364483, 0.8117340107423311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 300}], {
             RGBColor[
             0.808357108838871, 0.8475107432298477, 0.8111241144058667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 305}], {
             RGBColor[
             0.9933725205668509, 0.9879822051564673, 0.5413281333328984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 389}], {
             RGBColor[
             0.9943820531595315, 0.9903921047068212, 0.629899340243121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 432}], {
             RGBColor[
             0.9662291694300942, 0.8910532443296251, 0.463838307689076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 460}], {
             RGBColor[
             0.9944460971168962, 0.9905290882557869, 0.6368701297687841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 183}], {
             RGBColor[
             0.6856082512786374, 0.748240438977752, 0.9123507137726052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 188}], {
             RGBColor[
             0.961600436363713, 0.9705544620907236, 0.9352056645048445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 202}], {
             RGBColor[
             0.9859229504873807, 0.9884467925099304, 0.8829566708678361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 243}], {
             RGBColor[
             0.9899913720828405, 0.990129189393319, 0.8155323962934844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 273}], {
             RGBColor[
             0.9597094053596247, 0.8808137616467475, 0.5720489813664182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 279}], {
             RGBColor[
             0.9678901052051451, 0.9752452868142762, 0.9245588957646593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 285}], {
             RGBColor[
             0.9750044010686386, 0.9805511170206793, 0.912516248573297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 287}], {
             RGBColor[
             0.9903381424484419, 0.9896077035277785, 0.7614554424937384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 335}], {
             RGBColor[
             0.9734707956707292, 0.9794073566259669, 0.9151122424836097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 354}], {
             RGBColor[
             0.9861475242756503, 0.988539659542663, 0.8792349020178734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 396}], {
             RGBColor[
             0.8882844616241159, 0.9123678529833559, 0.9293445214200604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 409}], {
             RGBColor[
             0.853233084794474, 0.8849854510037092, 0.9258509277514215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 430}], {
             RGBColor[
             0.9850767936132676, 0.9730993884864766, 0.6356222140889896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 459}], {
             RGBColor[
             0.9799327283972187, 0.9557472486287928, 0.6156384920998442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 477}], {
             RGBColor[
             0.9473780190841047, 0.9592483669135612, 0.9350443634219218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 226}], {
             RGBColor[
             0.7218209808296967, 0.7702268340347602, 0.6793240556378326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 284}], {
             RGBColor[
             0.7042089589049033, 0.7666211973239441, 0.9574446788840139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 345}], {
             RGBColor[
             0.7061699268772756, 0.7680836840269489, 0.9541252716091463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 389}], {
             RGBColor[
             0.7248163875118505, 0.7793355531943167, 0.7756100083848037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 456}], {
             RGBColor[
             0.606343543965659, 0.689537267454414, 0.9633552071442671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 472}], {
             RGBColor[
             0.7164978203632866, 0.7757862100784423, 0.936642841883357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 207}], {
             RGBColor[
             0.902414946867419, 0.9245178504244154, 0.972964226232165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 209}], {
             RGBColor[
             0.8930216154269314, 0.9170278629089601, 0.9720682818938453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 231}], {
             RGBColor[
             0.9732201958567842, 0.9784060635958833, 0.8790661213724569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 233}], {
             RGBColor[
             0.9715924003876019, 0.9777329283369411, 0.906042904896444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 266}], {
             RGBColor[
             0.8746494249887302, 0.9025889986613225, 0.9702600334435334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 317}], {
             RGBColor[
             0.823369325855527, 0.8625285954752757, 0.965148912401708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 326}], {
             RGBColor[
             0.9319460400945354, 0.9480651425635467, 0.9757809282668856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 343}], {
             RGBColor[
             0.9445704059806868, 0.9581314692418806, 0.9769850515550111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 355}], {
             RGBColor[
             0.823369325855527, 0.8625285954752757, 0.965148912401708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 379}], {
             RGBColor[
             0.9482395828828044, 0.9609177461806757, 0.9725010642872602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 440}], {
             RGBColor[
             0.7527304154329879, 0.8059314587386321, 0.9590746920424087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 180}], {
             RGBColor[
             0.8007200717913476, 0.8448718184975617, 0.9647639975785309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 205}], {
             RGBColor[
             0.8166769762367483, 0.8566053510624889, 0.9302700123607353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 259}], {
             RGBColor[
             0.8131531721483026, 0.8541444043864452, 0.943718001746122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 316}], {
             RGBColor[
             0.7119991667939117, 0.7749384275842746, 0.9719290810016574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 331}], {
             RGBColor[
             0.8212795505134478, 0.8577502916520451, 0.7988699763410978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 348}], {
             RGBColor[
             0.8166261971015996, 0.8432260279912742, 0.6810839825858817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 372}], {
             RGBColor[
             0.8213959837030327, 0.8579993304713659, 0.8115430104850573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 404}], {
             RGBColor[
             0.734993949982974, 0.44693888212809785`, 0.5670526108992067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 418}], {
             RGBColor[
             0.6903762271661857, 0.7580464228066672, 0.9697739084574253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 431}], {
             RGBColor[
             0.8205257577122784, 0.8561380050704865, 0.7168242818037336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 444}], {
             RGBColor[
             0.8042970231788307, 0.8475395029856261, 0.9587091518978567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 486}], {
             RGBColor[
             0.80757851858136, 0.849986836883877, 0.9531544361324467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 178}], {
             RGBColor[
             0.9596924597468772, 0.9675157438010102, 0.8688333772740098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 185}], {
             RGBColor[
             0.9365530174606269, 0.9519294899614311, 0.9828378835017682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 277}], {
             RGBColor[
             0.9590798541851109, 0.9653156956508964, 0.7374798429113649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 288}], {
             RGBColor[
             0.8548689124060885, 0.8873992493302001, 0.9859434672108869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 313}], {
             RGBColor[
             0.8604617196831394, 0.891768392881942, 0.9865009059725077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 333}], {
             RGBColor[
             0.8747326227841875, 0.902952065696335, 0.9879139725158284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 358}], {
             RGBColor[
             0.9552844422886901, 0.9656929153011684, 0.9418856341396713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 361}], {
             RGBColor[
             0.8730005180312745, 0.9015709323830934, 0.9877487628182273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 386}], {
             RGBColor[
             0.9446002266673648, 0.9167949338760214, 0.6538127999183942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 498}], {
             RGBColor[
             0.9554210402534491, 0.9532960789497377, 0.6958496173611491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.926808525277061, 0.9389287856841719, 0.7055479817670444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 344}], {
             RGBColor[
             0.9002350989884473, 0.9231988311197534, 0.9872878877009522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 387}], {
             RGBColor[
             0.7908257100085321, 0.8368526702380361, 0.9796970484769207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 435}], {
             RGBColor[
             0.8913876895345525, 0.9162323638333327, 0.9895025476506317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 439}], {
             RGBColor[
             0.7970307676826015, 0.8417001084532042, 0.9803155106363113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 453}], {
             RGBColor[
             0.9146125732273122, 0.8977889756746495, 0.6581690110660618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 172}], {
             RGBColor[
             0.8683066572231796, 0.776349474042804, 0.6156925725555228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[
             0.9061242160029744, 0.9260173629143091, 0.9165044415394368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 218}], {
             RGBColor[
             0.9066957915130307, 0.9187621026945829, 0.697554818653458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 235}], {
             RGBColor[
             0.9071991657063436, 0.9204601020465085, 0.6995103323402385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 236}], {
             RGBColor[
             0.9020504967706848, 0.9235981262489307, 0.9511174252001355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 274}], {
             RGBColor[
             0.8893254445409801, 0.9141078031313776, 0.9726576193998663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 284}], {
             RGBColor[
             0.8886160499457194, 0.9135787378037592, 0.9738584394099001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 289}], {
             RGBColor[
             0.9087390775346227, 0.9252570088769918, 0.7392997074731809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 300}], {
             RGBColor[
             0.723198534232006, 0.7834117321971585, 0.9732485430734357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 305}], {
             RGBColor[
             0.9082139459599858, 0.9238831941237782, 0.7034525620004675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 432}], {
             RGBColor[
             0.8810705948232291, 0.826954233296936, 0.6259627363566451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 456}], {
             RGBColor[
             0.7907506350064751, 0.8364948079342291, 0.9797689676701535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 493}], {
             RGBColor[
             0.8988040635229221, 0.8921414511180965, 0.6668969456396674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 181}], {
             RGBColor[
             0.9906608324972123, 0.9888788721469441, 0.6934295608599925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 189}], {
             RGBColor[
             0.9810738566664428, 0.9848044294943672, 0.8900043153411019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 232}], {
             RGBColor[
             0.9860941682980577, 0.9885175954747425, 0.880119148647426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 280}], {
             RGBColor[
             0.926524377908357, 0.9423045444941358, 0.9193467575270455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 302}], {
             RGBColor[
             0.9902316179074042, 0.9879608255395967, 0.646712201564799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 326}], {
             RGBColor[
             0.9481642798960119, 0.9595596149396006, 0.9214107906967965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 338}], {
             RGBColor[
             0.9910153939469086, 0.9896372432361833, 0.7320213865598244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 346}], {
             RGBColor[
             0.9676267905562885, 0.9747756296069641, 0.9127666907090544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 370}], {
             RGBColor[
             0.9911269649895014, 0.9898758824147265, 0.744165206009384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 383}], {
             RGBColor[
             0.9032943787797957, 0.9237913144525675, 0.9171284745896818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 390}], {
             RGBColor[
             0.9781766589962315, 0.9473894021390553, 0.5919913110727604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 395}], {
             RGBColor[
             0.7443255627446297, 0.7974357953737625, 0.9027661344341602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 443}], {
             RGBColor[
             0.9862945723026082, 0.988600467680772, 0.8767979356630868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 480}], {
             RGBColor[
             0.9589126895872653, 0.8747344139699557, 0.5571160417799004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 211}], {
             RGBColor[
             0.9925031280834339, 0.990248958210364, 0.7071112724706133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 236}], {
             RGBColor[
             0.9869934330180923, 0.9872359086351228, 0.7655220918713126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 289}], {
             RGBColor[
             0.9936820137820302, 0.9888947912631839, 0.5537043741443579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 308}], {
             RGBColor[
             0.7908003781324924, 0.8329712346088123, 0.7862880554325489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 362}], {
             RGBColor[
             0.9300229008209024, 0.9429456233252858, 0.7994903421756291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 369}], {
             RGBColor[
             0.9251305037343567, 0.9390445586890552, 0.79902370097402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 456}], {
             RGBColor[
             0.8756935712538827, 0.9001325903204213, 0.7941736343413306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 470}], {
             RGBColor[
             0.994153484536991, 0.9909314230161361, 0.6797605950495781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 214}], {
             RGBColor[
             0.9699488425583558, 0.9754260889387142, 0.8604121979775696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 223}], {
             RGBColor[
             0.9103735172433871, 0.9311163659636734, 0.982479997326265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 268}], {
             RGBColor[
             0.9691489822947992, 0.9728841117078502, 0.7129360043020299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 466}], {
             RGBColor[
             0.9416343305942843, 0.9559915598390053, 0.9836820334860203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 491}], {
             RGBColor[
             0.9591363289304558, 0.939242282713289, 0.6627122097866207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 192}], {
             RGBColor[
             0.9751773654382312, 0.9775823614375898, 0.7187824855698205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 208}], {
             RGBColor[
             0.9554775266557312, 0.9663157927954793, 0.9602491134377673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 219}], {
             RGBColor[
             0.9760032682923752, 0.9793488841310161, 0.808676914361792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 238}], {
             RGBColor[
             0.9760719990477352, 0.9799129892780714, 0.846476382531707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 258}], {
             RGBColor[
             0.9758947580772838, 0.9791167917530013, 0.7968662470965229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 272}], {
             RGBColor[
             0.9677540906489379, 0.9528543517136573, 0.6633768897605976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 293}], {
             RGBColor[
             0.927177624147675, 0.9442120829763064, 0.9735629673168893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 403}], {
             RGBColor[
             0.9194096171482031, 0.9380180850518602, 0.9728220478746978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 471}], {
             RGBColor[
             0.9749644890902947, 0.979455005448962, 0.8648306886703906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 497}], {
             RGBColor[
             0.9720970335995927, 0.9782692389133121, 0.9123518468882543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 197}], {
             RGBColor[
             0.6723876927400358, 0.6194806293313867, 0.5985287898093827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 201}], {
             RGBColor[
             0.9500999145157794, 0.8396036900765114, 0.549090397292588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 211}], {
             RGBColor[
             0.9515358903488312, 0.840197502986374, 0.5252925615525876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 218}], {
             RGBColor[
             0.9506714900258357, 0.832348429856785, 0.3301407744066094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 235}], {
             RGBColor[
             0.9511748642191485, 0.8340464292087106, 0.33209628809338987`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 236}], {
             RGBColor[
             0.9460261952834896, 0.8371844534111328, 0.5837033809532868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 289}], {
             RGBColor[
             0.9527147760474276, 0.8388433360391939, 0.37188566322633215`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 300}], {
             RGBColor[
             0.7671742327448109, 0.6969980593593607, 0.6058344988265871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 308}], {
             RGBColor[
             0.7498331403978897, 0.6829197793848223, 0.604469344514523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 314}], {
             RGBColor[
             0.9506714900258357, 0.832348429856785, 0.3301407744066094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 466}], {
             RGBColor[
             0.9249859399722205, 0.8214926654502444, 0.6193190450178085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 470}], {
             RGBColor[
             0.9531862468023884, 0.8408799677921461, 0.4979418841315524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 493}], {
             RGBColor[
             0.942779762035727, 0.8057277782802987, 0.29948290139281863`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 242}], {
             RGBColor[
             0.6547521420375612, 0.7267437627759481, 0.9685258261407808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 249}], {
             RGBColor[
             0.6927151505469391, 0.7564548322522069, 0.9527449834146983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 269}], {
             RGBColor[
             0.7108799714327056, 0.7684176158042221, 0.8510390791730309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 282}], {
             RGBColor[
             0.7116247622426561, 0.7686712484683191, 0.8347447533118459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 310}], {
             RGBColor[
             0.71080191230723, 0.7669112556593329, 0.7451826158818782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 323}], {
             RGBColor[
             0.7110058436848254, 0.7673474442553844, 0.7673792878145611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 406}], {
             RGBColor[
             0.6090435124441835, 0.6905388351807644, 0.964101905303506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 419}], {
             RGBColor[
             0.7103342472268237, 0.7659109673405367, 0.6942801579739827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 499}], {
             RGBColor[
             0.6380323892383801, 0.7134118857394806, 0.9669310811928953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 210}], {
             RGBColor[
             0.8224661239879529, 0.8618549890012963, 0.9666777975707361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 225}], {
             RGBColor[
             0.9732627590330163, 0.9761191058588601, 0.7192189198710938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 252}], {
             RGBColor[
             0.9742921540671412, 0.9785492365734272, 0.8478614924997401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 309}], {
             RGBColor[
             0.8994464667728428, 0.9221974471527086, 0.9742961233202061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 320}], {
             RGBColor[
             0.9436672041131127, 0.9574578627679012, 0.9785139367240394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 393}], {
             RGBColor[
             0.9706599694570701, 0.977047234894276, 0.9080561912810718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 424}], {
             RGBColor[
             0.9731523003116547, 0.9758828458229571, 0.7071961697230758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 182}], {
             RGBColor[
             0.6753241959902183, 0.7452427461895117, 0.9689880770677668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 208}], {
             RGBColor[
             0.7638784601325496, 0.8150401918432941, 0.9615146037587985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 351}], {
             RGBColor[
             0.7353008226595746, 0.7927150237020099, 0.9748019670290295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 359}], {
             RGBColor[
             0.6749947683211356, 0.7449853947906813, 0.9689552427963892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 371}], {
             RGBColor[
             0.4784184612304857, 0.5855229577596365, 0.9526118740569096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 463}], {
             RGBColor[
             0.7840544999885185, 0.8284643557190101, 0.8546763828435314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 483}], {
             RGBColor[
             0.7284406639580464, 0.7872449193674586, 0.9741476389679418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 178}], {
             RGBColor[
             0.9935421741685164, 0.9894854352672504, 0.6031588947311015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 244}], {
             RGBColor[
             0.9890801365308666, 0.9876402680349454, 0.6771064057702065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 261}], {
             RGBColor[
             0.9897891538075168, 0.9879334648997533, 0.665356154618217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 262}], {
             RGBColor[
             0.9758892862220051, 0.9779910446708404, 0.7078760955842325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 299}], {
             RGBColor[
             0.993234002796521, 0.9879365410660383, 0.5049411431749736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 313}], {
             RGBColor[
             0.8943114341047786, 0.9137380843481823, 0.7208264234295995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 328}], {
             RGBColor[
             0.9665138920636136, 0.9709988910583112, 0.7237461923999733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 376}], {
             RGBColor[
             0.9680030000799968, 0.9721094653787391, 0.7212255209498089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 391}], {
             RGBColor[
             0.9761751684108946, 0.9782042551392252, 0.707392171608459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 407}], {
             RGBColor[
             0.9870824623695645, 0.9678841466339787, 0.42167403243560797`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 448}], {
             RGBColor[
             0.9919488628275284, 0.9888265600815183, 0.6295641870088455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 455}], {
             RGBColor[
             0.993262703473154, 0.9893698669526488, 0.6077904474002317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 475}], {
             RGBColor[
             0.9849102846720349, 0.9605568812086336, 0.4132355322620439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 478}], {
             RGBColor[
             0.9584161135250532, 0.8617334107385313, 0.3595389926358773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 482}], {
             RGBColor[
             0.9456906292206649, 0.9545109019374541, 0.7257789119922586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 194}], {
             RGBColor[
             0.866454432589979, 0.8657811610396198, 0.6621437117472083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 290}], {
             RGBColor[
             0.6963350225774895, 0.7625462477769616, 0.970473957979103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 297}], {
             RGBColor[
             0.8755424666497467, 0.9015909377583926, 0.8907665466724467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 412}], {
             RGBColor[
             0.8430213929575083, 0.878147627587959, 0.9847616219274351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 484}], {
             RGBColor[
             0.877812326027973, 0.9025295829440144, 0.8531491025674671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 186}], {
             RGBColor[
             0.9866306726621012, 0.9878786537482881, 0.8326794971205165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 244}], {
             RGBColor[
             0.9897885949981042, 0.9900453358576471, 0.8188929373578393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 261}], {
             RGBColor[
             0.9904976122747544, 0.9903385327224549, 0.8071426862058498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 288}], {
             RGBColor[
             0.8894270852949654, 0.9117740086191419, 0.8620555162556114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 313}], {
             RGBColor[
             0.8950198925720163, 0.9161431521708838, 0.8626129550172323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 321}], {
             RGBColor[
             0.9932499245277999, 0.9914766845702877, 0.7615297494171012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 391}], {
             RGBColor[
             0.9768836268781322, 0.9806093229619267, 0.8491787031960919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 407}], {
             RGBColor[
             0.9877909208368022, 0.9702892144566804, 0.5634605640232407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 455}], {
             RGBColor[
             0.9939711619403917, 0.9917749347753504, 0.7495769789878646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 475}], {
             RGBColor[
             0.9856187431392726, 0.9629619490313353, 0.5550220638496768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 498}], {
             RGBColor[
             0.989979213142326, 0.9776708382386796, 0.5719616664058738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 222}], {
             RGBColor[
             0.6156158843603425, 0.6789565666572392, 0.8357905636487193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 245}], {
             RGBColor[
             0.5104560697396858, 0.5986898232883737, 0.9579659011195018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 255}], {
             RGBColor[
             0.5968958863746974, 0.6169036015841638, 0.6129331519865905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 294}], {
             RGBColor[
             0.5699123174344868, 0.6458121620637685, 0.9637129085762233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 296}], {
             RGBColor[
             0.613562215722048, 0.6781073218984277, 0.8698251677093273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 312}], {
             RGBColor[
             0.5324760517250353, 0.6159614999674139, 0.9601422041331069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 327}], {
             RGBColor[
             0.6132633098102083, 0.6779837166223506, 0.874778812212215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 334}], {
             RGBColor[
             0.5674344074320716, 0.6438363438889179, 0.9634765633081366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 385}], {
             RGBColor[
             0.5676752763184544, 0.6440284062007076, 0.9634995375975459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 415}], {
             RGBColor[
             0.6146794934227523, 0.6785693449403962, 0.8513089847866546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 438}], {
             RGBColor[
             0.5888721226964031, 0.6607838340175543, 0.9604468454300248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 205}], {
             RGBColor[
             0.969240899893103, 0.9764133933770364, 0.9294682043905995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 230}], {
             RGBColor[
             0.9549009337743561, 0.9148332873494904, 0.6247713814710076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 331}], {
             RGBColor[
             0.9738434741698025, 0.9775583339665925, 0.7980681683709621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 382}], {
             RGBColor[
             0.951878461347084, 0.9636316157812188, 0.966341392218738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 413}], {
             RGBColor[
             0.8543729666713313, 0.8867858677549088, 0.9701116167253584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 418}], {
             RGBColor[
             0.8429401508225405, 0.8778544651212147, 0.9689721004872895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 474}], {
             RGBColor[
             0.9703861044935835, 0.9768869649097509, 0.9104892004661337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 490}], {
             RGBColor[
             0.9734878433463658, 0.9781696136364288, 0.8590853606326949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 189}], {
             RGBColor[
             0.9839247911034159, 0.9844562078176633, 0.7317488098793044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 302}], {
             RGBColor[
             0.9930825523443774, 0.987612603862893, 0.48845669610300146`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 370}], {
             RGBColor[
             0.9939778994264745, 0.9895276607380226, 0.5859097005475865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 390}], {
             RGBColor[
             0.9810275934332047, 0.9470411804623515, 0.4337358056109629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 422}], {
             RGBColor[
             0.9932677379419038, 0.9899568945427382, 0.6502263911864248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 443}], {
             RGBColor[
             0.9891455067395813, 0.9882522460040681, 0.7185424302012894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 451}], {
             RGBColor[
             0.884676976193508, 0.9066718647278877, 0.7567332059264216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 237}], {
             RGBColor[
             0.859655657383303, 0.8181483029913085, 0.6256000164520099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 351}], {
             RGBColor[
             0.8364776674603522, 0.872800059295694, 0.9841719149586663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 359}], {
             RGBColor[
             0.7761716131219132, 0.8250704303843654, 0.9783251907260259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 371}], {
             RGBColor[
             0.5795953060312633, 0.6656079933533207, 0.9619818219865464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 460}], {
             RGBColor[
             0.8853725635503419, 0.9077123946743948, 0.7966202625338692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 463}], {
             RGBColor[
             0.8852313447892961, 0.9085493913126943, 0.8640463307731681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 483}], {
             RGBColor[
             0.829617508758824, 0.8673299549611427, 0.9835175868975785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 202}], {
             RGBColor[
             0.6853662032300986, 0.7481403458893301, 0.9163620763371638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 206}], {
             RGBColor[
             0.670203273036781, 0.7370792181679362, 0.9531062835821832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 243}], {
             RGBColor[
             0.6894346248255584, 0.7498227427727187, 0.848937801762812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 273}], {
             RGBColor[
             0.6591526581023426, 0.6405073150261471, 0.6054543868357459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 279}], {
             RGBColor[
             0.667333357947863, 0.7349388401936758, 0.957964301233987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 283}], {
             RGBColor[
             0.5280800998383575, 0.6254642365544493, 0.956804810111839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 285}], {
             RGBColor[
             0.6744476538113565, 0.740244670400079, 0.9459216540426247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 396}], {
             RGBColor[
             0.5877277143668338, 0.6720614063627557, 0.962749926889388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 430}], {
             RGBColor[
             0.6845200463559855, 0.7327929418658763, 0.6690276195583171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 477}], {
             RGBColor[
             0.6468212718268226, 0.7189419202929609, 0.9684497688912495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 221}], {
             RGBColor[
             0.7952612762624371, 0.8378799838101059, 0.8688297889710728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 253}], {
             RGBColor[
             0.7917299308228203, 0.8364196817193861, 0.9273533217345703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 287}], {
             RGBColor[
             0.7963330993922082, 0.8376583258955557, 0.8027368344926326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 301}], {
             RGBColor[
             0.7240575006576584, 0.7839236249685113, 0.9735296192097712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 316}], {
             RGBColor[
             0.6869985489381413, 0.7547306046597209, 0.9699002243778572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 336}], {
             RGBColor[
             0.7946381222587854, 0.8376222936152684, 0.8791570634824497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 354}], {
             RGBColor[
             0.7921424812194167, 0.8365902819104402, 0.9205162940167675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 388}], {
             RGBColor[
             0.4567987908974691, 0.5661452243795493, 0.9514143990758924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 436}], {
             RGBColor[
             0.7857417626217797, 0.8321386169811534, 0.9457699865857365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 473}], {
             RGBColor[
             0.796067914478496, 0.8370911221794329, 0.7738730931666504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 187}], {
             RGBColor[
             0.96766230504162, 0.9748780465432535, 0.916106887527193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 216}], {
             RGBColor[
             0.9509827139452711, 0.9629635688355985, 0.9678576589216683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 224}], {
             RGBColor[
             0.6228025887993537, 0.6954399896374469, 0.956607797162935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 286}], {
             RGBColor[
             0.9358276046332283, 0.9513510654636701, 0.9827686929787073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 330}], {
             RGBColor[
             0.9440807542056084, 0.9578160985626798, 0.9795408764415157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 333}], {
             RGBColor[
             0.8861513533868142, 0.9117405711456978, 0.9780305277883112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 357}], {
             RGBColor[
             0.9708843386686157, 0.9749292896457576, 0.7695833275204487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 358}], {
             RGBColor[
             0.9667031728913168, 0.9744814207505312, 0.9320021894121543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 361}], {
             RGBColor[
             0.8844192486339012, 0.9103594378324562, 0.9778653180907102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 386}], {
             RGBColor[
             0.9560189572699913, 0.9255834393253842, 0.6439293551908771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 398}], {
             RGBColor[
             0.9474354223715973, 0.9603180045881095, 0.9738622982740821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 441}], {
             RGBColor[
             0.9713026398212627, 0.9758239935145354, 0.8151128265305946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 464}], {
             RGBColor[
             0.8195973518189446, 0.8597129444427583, 0.9714063706031519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 481}], {
             RGBColor[
             0.9680258253690857, 0.9750283715407069, 0.910082414940636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 288}], {
             RGBColor[
             0.8818071253213124, 0.907762159277478, 0.9497895870573935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 295}], {
             RGBColor[
             0.9055315478247514, 0.92639340269612, 0.9521283305313484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 321}], {
             RGBColor[
             0.9856299645541471, 0.9874648352286237, 0.8492638202188831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 341}], {
             RGBColor[
             0.9182029653843617, 0.9364972471016867, 0.9533369416500919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 373}], {
             RGBColor[
             0.964366279131635, 0.9111188534261074, 0.5994083942865385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 397}], {
             RGBColor[
             0.9865580275183208, 0.9868335263338733, 0.7600973220062011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 455}], {
             RGBColor[
             0.9863512019667389, 0.9877630854336865, 0.8373110497896465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 495}], {
             RGBColor[
             0.9605333055864372, 0.9700863844439216, 0.9516909984664117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 498}], {
             RGBColor[
             0.9823592531686731, 0.9736589888970155, 0.6596957372076558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 216}], {
             RGBColor[
             0.9706732709236376, 0.9771236199680581, 0.9110101076746102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 224}], {
             RGBColor[
             0.6424931457777201, 0.7096000407699065, 0.8997602459158769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 260}], {
             RGBColor[
             0.9894226484113109, 0.9898940075396097, 0.8249576193404131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 328}], {
             RGBColor[
             0.9637734652229675, 0.9719777561738931, 0.9226896789683064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 398}], {
             RGBColor[
             0.9671259793499636, 0.974478055720569, 0.917014747027024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 399}], {
             RGBColor[
             0.9903194780963921, 0.9885430284641807, 0.6849351521460674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 407}], {
             RGBColor[
             0.9843420355289183, 0.9688630117495608, 0.620617519003941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 464}], {
             RGBColor[
             0.839287908797311, 0.8738729955752178, 0.9145588193560938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 478}], {
             RGBColor[
             0.9556756866844069, 0.8627122758541133, 0.5584824792042105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 481}], {
             RGBColor[
             0.9877163823474521, 0.9891884226731664, 0.8532348636935779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 200}], {
             RGBColor[
             0.9608167626913341, 0.9702303928877003, 0.948193165338614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 228}], {
             RGBColor[
             0.8969670858179852, 0.6954564312499886, 0.5967926003188265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 256}], {
             RGBColor[
             0.9632051933918664, 0.9712180703622395, 0.9086106875702806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 279}], {
             RGBColor[
             0.9433255430329385, 0.9572528633066475, 0.9808192519662262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 298}], {
             RGBColor[
             0.9508578518326525, 0.9628704468764505, 0.9680690179090772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 318}], {
             RGBColor[
             0.81863231114861, 0.8591526628148269, 0.9811109681870228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 335}], {
             RGBColor[
             0.9489062334985227, 0.9614149331183381, 0.9713725986851764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 409}], {
             RGBColor[
             0.8286685226222674, 0.8669930274960804, 0.9821112839529884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 430}], {
             RGBColor[
             0.960512231441061, 0.955106964978848, 0.6918825702905564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 459}], {
             RGBColor[
             0.9553681662250121, 0.937754825121164, 0.6718988483014111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 302}], {
             RGBColor[
             0.9834955765136079, 0.9835381612103158, 0.6850314505841109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 346}], {
             RGBColor[
             0.9608907491624921, 0.9703529652776832, 0.9510859397283662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 370}], {
             RGBColor[
             0.984390923595705, 0.9854532180854456, 0.782484455028696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 383}], {
             RGBColor[
             0.8965583373859993, 0.9193686501232865, 0.9554477236089938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 390}], {
             RGBColor[
             0.9714406176024352, 0.9429667378097744, 0.6303105600920724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 422}], {
             RGBColor[
             0.9836807621111343, 0.9858824518901612, 0.8468011456675343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 443}], {
             RGBColor[
             0.9795585309088117, 0.9841778033514911, 0.9151171846823989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 451}], {
             RGBColor[
             0.8750900003627384, 0.9025974220753106, 0.9533079604075311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 349}], {
             RGBColor[
             0.9907046732441498, 0.9793217843905171, 0.5021502930120432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 378}], {
             RGBColor[
             0.9866994954163241, 0.9786860467753413, 0.6427064929563151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 467}], {
             RGBColor[
             0.954917393222007, 0.9549583844487052, 0.6988378462043665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 487}], {
             RGBColor[
             0.8238147569341214, 0.8517112118749739, 0.6859906978009995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 226}], {
             RGBColor[
             0.9733988809986305, 0.9701521291172335, 0.6816048710945486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 237}], {
             RGBColor[
             0.9507414254711102, 0.8898337401426695, 0.6138413672853235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 271}], {
             RGBColor[
             0.9646915550785724, 0.9407802742115268, 0.6477785541356498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 311}], {
             RGBColor[
             0.9766763331605528, 0.9798641150388425, 0.8085897337313841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 366}], {
             RGBColor[
             0.8641389938245624, 0.8943197596098191, 0.9662557298477739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 405}], {
             RGBColor[
             0.9663270433482518, 0.974407344580308, 0.9418837116844782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 423}], {
             RGBColor[
             0.9766280235931797, 0.9797607857590782, 0.8033315354549244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 429}], {
             RGBColor[
             0.96918864630097, 0.9559500188719066, 0.6652489043302461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 488}], {
             RGBColor[
             0.6991035872002475, 0.7619115827785526, 0.952034230220351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 219}], {
             RGBColor[
             0.9938351494948026, 0.9892223330684082, 0.5703722514355449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 251}], {
             RGBColor[
             0.993788557249317, 0.9891226769665131, 0.565300973048452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 258}], {
             RGBColor[
             0.9937266392797112, 0.9889902406903934, 0.5585615841702758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 272}], {
             RGBColor[
             0.9855859718513653, 0.9627278006510495, 0.42507222683435053`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 435}], {
             RGBColor[
             0.957217188372864, 0.9638196069873205, 0.7364226840952803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 453}], {
             RGBColor[
             0.9804420720656236, 0.9453762188286374, 0.40508914751071046`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 497}], {
             RGBColor[
             0.98992891480202, 0.9881426878507042, 0.6740471839620072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 410}], {
             RGBColor[
             0.9141739428708702, 0.9317654886379122, 0.8881564603471452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 428}], {
             RGBColor[
             0.9928412887091947, 0.990435944997186, 0.7049342869149474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 437}], {
             RGBColor[
             0.7645086014105189, 0.8131040826025275, 0.8743727084748335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 220}], {
             RGBColor[
             0.8203779699622102, 0.8297858782407206, 0.6575512405614967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 254}], {
             RGBColor[
             0.9817781768936431, 0.9546811810298602, 0.5724112172724769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 290}], {
             RGBColor[
             0.8023449754370877, 0.8155431345683217, 0.6558600126783357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 297}], {
             RGBColor[
             0.9815524195093449, 0.9545878245497528, 0.5761526013716795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 350}], {
             RGBColor[
             0.9725623879779103, 0.9191086333711347, 0.34791048776278977`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 377}], {
             RGBColor[
             0.9838360454141518, 0.9554680695742069, 0.5336481277070237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 412}], {
             RGBColor[
             0.9490313458171066, 0.9311445143793191, 0.6701476766266679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 426}], {
             RGBColor[
             0.8354111668085873, 0.8415299258736381, 0.6590496091299316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 476}], {
             RGBColor[
             0.9694737696192732, 0.9466509096611838, 0.6445746119374542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.975808687507568, 0.9290148590124916, 0.4493219025054419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 260}], {
             RGBColor[
             0.9928437633738827, 0.9903710654887006, 0.7001028341235436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 292}], {
             RGBColor[
             0.9094907818183324, 0.9265592870705517, 0.7963499149417756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 399}], {
             RGBColor[
             0.993740593058964, 0.9890200864132717, 0.5600803669291977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 446}], {
             RGBColor[
             0.9920493994531021, 0.9900425755932363, 0.7132675000388047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 496}], {
             RGBColor[
             0.8177726824212517, 0.8548541417346721, 0.7872291775768939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 213}], {
             RGBColor[
             0.9422363404397059, 0.9564405377960201, 0.9826629878470354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 332}], {
             RGBColor[
             0.8851798526386305, 0.9112136712694818, 0.9865274594559161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 337}], {
             RGBColor[
             0.9579800671447702, 0.944820142811701, 0.6783407814212037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 420}], {
             RGBColor[
             0.9476383186170529, 0.9604693242757582, 0.9735188478543415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 427}], {
             RGBColor[
             0.9620148871392782, 0.9709465555440822, 0.9382208711960198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 447}], {
             RGBColor[
             0.6831974399273634, 0.7493565392559481, 0.9688559848771462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 454}], {
             RGBColor[
             0.9530660187834443, 0.9645172941728095, 0.9643311672435648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 489}], {
             RGBColor[
             0.9449681006639572, 0.9584778800984199, 0.9780388303445529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 500}], {
             RGBColor[
             0.8519720368997226, 0.885174389878749, 0.9832433776629319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 201}], {
             RGBColor[
             0.7102052515198307, 0.7691485182028919, 0.8993406587932967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 236}], {
             RGBColor[
             0.706131532287541, 0.7667292815375134, 0.9339536424539956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 289}], {
             RGBColor[
             0.712820113051479, 0.7683881641655745, 0.7221359247270408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 314}], {
             RGBColor[
             0.7107768270298871, 0.7618932579831657, 0.680391035907318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 411}], {
             RGBColor[
             0.6805130920659763, 0.7474383033391743, 0.97091228327929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 466}], {
             RGBColor[
             0.6850912769762718, 0.751037493576625, 0.9695693065185171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 470}], {
             RGBColor[
             0.7132915838064398, 0.7704247959185266, 0.848192145632261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 493}], {
             RGBColor[
             0.7028850990397784, 0.7352726064066792, 0.6497331628935273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 270}], {
             RGBColor[
             0.6333130825407813, 0.6961484955687168, 0.7057891570345123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 479}], {
             RGBColor[
             0.9709682074339565, 0.9743932808403026, 0.7219483429441489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 244}], {
             RGBColor[
             0.985262180849479, 0.9881735472836529, 0.8939073337848741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 245}], {
             RGBColor[
             0.8848702270692432, 0.9098784369007361, 0.9370668783015572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 262}], {
             RGBColor[
             0.9720713305406176, 0.9785243239195479, 0.9246770235989001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 376}], {
             RGBColor[
             0.9641850443986093, 0.9726427446274466, 0.9380264489644765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 448}], {
             RGBColor[
             0.9881309071461408, 0.9893598393302256, 0.8463651150235132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 455}], {
             RGBColor[
             0.9894447477917665, 0.9899031462013563, 0.8245913754148992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 475}], {
             RGBColor[
             0.9810923289906474, 0.9610901604573411, 0.6300364602767116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 482}], {
             RGBColor[
             0.9418726735392774, 0.9550441811861616, 0.9425798400069263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 228}], {
             RGBColor[
             0.9207479743178131, 0.7131247855545939, 0.5535197449510292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 256}], {
             RGBColor[
             0.986986081891694, 0.9888864246668448, 0.8653378322024832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 298}], {
             RGBColor[
             0.9746387403324803, 0.9805388011810559, 0.9247961625412798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 452}], {
             RGBColor[
             0.9323615195986632, 0.9475754287469664, 0.9466743246238478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 468}], {
             RGBColor[
             0.8802199183219962, 0.9063559130889203, 0.9416063332127325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 218}], {
             RGBColor[
             0.9884890488056306, 0.9820163187282902, 0.6309526433905233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 235}], {
             RGBColor[
             0.9889924229989434, 0.9837143180802159, 0.6329081570773039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 236}], {
             RGBColor[
             0.9838437540632845, 0.9868523422826381, 0.8845152499372009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 289}], {
             RGBColor[
             0.9905323348272225, 0.9885112249106991, 0.6726975322102461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 300}], {
             RGBColor[
             0.8049917915246058, 0.8466659482308658, 0.906646367810501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 305}], {
             RGBColor[
             0.9900072032525856, 0.9871374101574855, 0.6368503867375327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 314}], {
             RGBColor[
             0.9884890488056306, 0.9820163187282902, 0.6309526433905233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 406}], {
             RGBColor[
             0.8889869820847106, 0.9125944906805861, 0.9148056859276403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 493}], {
             RGBColor[
             0.9805973208155219, 0.9553956671518039, 0.6002947703767326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 243}], {
             RGBColor[
             0.9897493240343016, 0.990029096304897, 0.8195437588580428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 273}], {
             RGBColor[
             0.9594673573110859, 0.8807136685583254, 0.5760603439309767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 279}], {
             RGBColor[
             0.9676480571566062, 0.9751451937258542, 0.9285702583292179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 283}], {
             RGBColor[
             0.8283947990471008, 0.8656705900866276, 0.9274107672070699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 285}], {
             RGBColor[
             0.9747623530200997, 0.9804510239322574, 0.9165276111378555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 396}], {
             RGBColor[
             0.888042413575577, 0.912267759894934, 0.9333558839846189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 421}], {
             RGBColor[
             0.928336565088112, 0.9441581378189199, 0.9372626218647844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 430}], {
             RGBColor[
             0.9848347455647288, 0.9729992953980546, 0.639633576653548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 459}], {
             RGBColor[
             0.9796906803486798, 0.9556471555403708, 0.6196498546644027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 477}], {
             RGBColor[
             0.9471359710355658, 0.9591482738251392, 0.9390557259864802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 264}], {
             RGBColor[
             0.9858646978466152, 0.9854746299888572, 0.6944767499197241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 281}], {
             RGBColor[
             0.9798797061928539, 0.9810110330130063, 0.7046077796537199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 295}], {
             RGBColor[
             0.9124745902436355, 0.9280676470375782, 0.726040761816233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 324}], {
             RGBColor[
             0.9719356720962324, 0.975086385390908, 0.7180549572433775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 341}], {
             RGBColor[
             0.9251460078032461, 0.9381714914431447, 0.7272493729349767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 374}], {
             RGBColor[
             0.9939349086262423, 0.9894357077633626, 0.5812304172507817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 397}], {
             RGBColor[
             0.9935010699372049, 0.9885077706753314, 0.5340097532910858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 275}], {
             RGBColor[
             0.9618398777191303, 0.9699769044677298, 0.9015566281633993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 306}], {
             RGBColor[
             0.9600734363175589, 0.9692464355527067, 0.9308311335912438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 331}], {
             RGBColor[
             0.9638669911167563, 0.9700568257974636, 0.8128386439891095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 346}], {
             RGBColor[
             0.940387356196974, 0.9550005049320656, 0.9836757279705045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 348}], {
             RGBColor[
             0.9592136377049081, 0.9555325621366926, 0.6950526502338936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 355}], {
             RGBColor[
             0.8123481312976889, 0.854247943176431, 0.9816878120930692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 390}], {
             RGBColor[
             0.950937224636917, 0.9276142774641568, 0.6629003483342106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 431}], {
             RGBColor[
             0.963113198315587, 0.9684445392159049, 0.7307929494517453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 444}], {
             RGBColor[
             0.9468844637821392, 0.9598460371310445, 0.9726778195458685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 486}], {
             RGBColor[
             0.9501659591846685, 0.9622933710292954, 0.9671231037804586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 230}], {
             RGBColor[
             0.9708578382197568, 0.9265668199144178, 0.590277396253212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 331}], {
             RGBColor[
             0.9898003786152032, 0.9892918665315198, 0.7635741831531664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 382}], {
             RGBColor[
             0.9678353657924847, 0.9753651483461461, 0.9318474070009424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 413}], {
             RGBColor[
             0.870329871116732, 0.8985194003198361, 0.9356176315075628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 474}], {
             RGBColor[
             0.9863430089389843, 0.9886204974746783, 0.8759952152483381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 490}], {
             RGBColor[
             0.9894447477917665, 0.9899031462013563, 0.8245913754148992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 254}], {
             RGBColor[
             0.9732235051949576, 0.9784043791037307, 0.8788745580104731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 377}], {
             RGBColor[
             0.9752813737154664, 0.9791912676480774, 0.8401114684450199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 396}], {
             RGBColor[
             0.8728794833822594, 0.9012066321735401, 0.9701000912296383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 476}], {
             RGBColor[
             0.9609190979205879, 0.9703741077350543, 0.9510379526754504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 257}], {
             RGBColor[
             0.8333877376387759, 0.5084622758886451, 0.5748605555011811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 266}], {
             RGBColor[
             0.8216909533988631, 0.8608687000141975, 0.9827989182137304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 281}], {
             RGBColor[
             0.9081595450685214, 0.9288021623568813, 0.9632401199088669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 293}], {
             RGBColor[
             0.873233119668549, 0.9017564026148528, 0.9877709485700366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 317}], {
             RGBColor[
             0.7704108542656598, 0.8208082968281507, 0.9776877971719051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 322}], {
             RGBColor[
             0.9147590492975076, 0.9337240618051628, 0.9520688806755639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 343}], {
             RGBColor[
             0.8916119343908195, 0.9164111705947555, 0.9895239363252083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 374}], {
             RGBColor[
             0.9222147475019099, 0.9372268371072376, 0.8398627575059288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 403}], {
             RGBColor[
             0.8654651126690771, 0.8955624046904066, 0.9870300291278451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 440}], {
             RGBColor[
             0.6997719438431207, 0.764211160091507, 0.971613576812606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 445}], {
             RGBColor[
             0.5914160446643287, 0.6729862427739809, 0.9639832441152931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 471}], {
             RGBColor[
             0.9210199846111686, 0.9369993250875084, 0.879038669923538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 238}], {
             RGBColor[
             0.9742040414676626, 0.978519869573353, 0.8496383474734066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[
             0.9740268004972111, 0.9777236720482829, 0.8000282120382225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 266}], {
             RGBColor[
             0.8737675002979165, 0.9019312606709327, 0.9717529019022828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 293}], {
             RGBColor[
             0.9253096665676024, 0.942818963271588, 0.9767249322585889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 403}], {
             RGBColor[
             0.9175416595681305, 0.9366249653471419, 0.9759840128163975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 471}], {
             RGBColor[
             0.973096531510222, 0.9780618857442436, 0.8679926536120903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 483}], {
             RGBColor[
             0.9181717729011554, 0.9371274006149253, 0.9760441135886102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 497}], {
             RGBColor[
             0.97022907601952, 0.9768761192085936, 0.915513811829954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 231}], {
             RGBColor[
             0.9108683928264295, 0.9291957774333031, 0.8907090618043344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 233}], {
             RGBColor[
             0.9092405973572472, 0.9285226421743608, 0.9176858453283214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 259}], {
             RGBColor[
             0.9044100042790946, 0.9255213046681281, 0.95279071013465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 275}], {
             RGBColor[
             0.9105092692466137, 0.9290472706039942, 0.8966606689039155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 348}], {
             RGBColor[
             0.9078830292323915, 0.9146029282729569, 0.6901566909744098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 355}], {
             RGBColor[
             0.7610175228251723, 0.8133183093126954, 0.9767918528335855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 372}], {
             RGBColor[
             0.9126528158338245, 0.9293762307530486, 0.8206157188735854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 379}], {
             RGBColor[
             0.8858877798524497, 0.9117074600180953, 0.9841440047191377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 400}], {
             RGBColor[
             0.875934687899568, 0.7965535674330259, 0.6195823726183445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 404}], {
             RGBColor[
             0.8262507821137659, 0.5183157824097806, 0.5761253192877347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 431}], {
             RGBColor[
             0.9117825898430703, 0.9275149053521693, 0.7258969901922616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 444}], {
             RGBColor[
             0.8955538553096225, 0.918916403267309, 0.9677818602863848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 486}], {
             RGBColor[
             0.8988353507121519, 0.9213637371655596, 0.9622271445209748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 225}], {
             RGBColor[
             0.8421618682988313, 0.8730831587365748, 0.7224136056418057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 252}], {
             RGBColor[
             0.8431912633329561, 0.8755132894511419, 0.851056178270452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 280}], {
             RGBColor[
             0.7783020455051214, 0.8271005185218174, 0.9784404660368745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 309}], {
             RGBColor[
             0.7683455760386578, 0.8191615000304233, 0.977490809090918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 320}], {
             RGBColor[
             0.8125663133789276, 0.854421915645616, 0.9817086224947512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 393}], {
             RGBColor[
             0.839559078722885, 0.8740112877719908, 0.9112508770517838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 424}], {
             RGBColor[
             0.8420514095774696, 0.8728468987006719, 0.7103908554937877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 480}], {
             RGBColor[
             0.8106903571840296, 0.7595303879976372, 0.6162097502897294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 236}], {
             RGBColor[
             0.9852797298963365, 0.9874461551925007, 0.8607174141972004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 289}], {
             RGBColor[
             0.9919683106602744, 0.9891050378205617, 0.6488996964702457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 308}], {
             RGBColor[
             0.7890866750107364, 0.8331814811661902, 0.8814833777584365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 362}], {
             RGBColor[
             0.9283091976991465, 0.9431558698826636, 0.8946856645015169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 369}], {
             RGBColor[
             0.9234168006126007, 0.9392548052464331, 0.8942190232999077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 466}], {
             RGBColor[
             0.9642394745850672, 0.9717543672316122, 0.896333078261722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 470}], {
             RGBColor[
             0.9924397814152353, 0.9911416695735139, 0.7749559173754659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 216}], {
             RGBColor[
             0.8801876475682345, 0.9069399279789911, 0.9720485602423083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 217}], {
             RGBColor[
             0.8531753957955999, 0.8858728610625447, 0.9858286494664601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 224}], {
             RGBColor[
             0.552007522422317, 0.6394163487808395, 0.960798698483575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 286}], {
             RGBColor[
             0.8650325382561916, 0.8953274246070626, 0.9869595942993473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 319}], {
             RGBColor[
             0.76692506639836, 0.8178469578075678, 0.9774035813625142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 330}], {
             RGBColor[
             0.8732856878285717, 0.9017924577060724, 0.9837317777621557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 357}], {
             RGBColor[
             0.9000892722915791, 0.9189056487891503, 0.7737742288410887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 492}], {
             RGBColor[
             0.8794982378487293, 0.9064257673389888, 0.9732155510705787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 251}], {
             RGBColor[
             0.9703381014485902, 0.9750589042932809, 0.8131164172106713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 332}], {
             RGBColor[
             0.8890518472381297, 0.914101398501979, 0.9799731825768927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 337}], {
             RGBColor[
             0.9618520617442694, 0.9477078700441981, 0.6717865045421803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 420}], {
             RGBColor[
             0.9515103132165521, 0.9633570515082552, 0.9669645709753181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 447}], {
             RGBColor[
             0.6870694345268625, 0.7522442664884452, 0.9623017079981226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 454}], {
             RGBColor[
             0.9569380133829435, 0.9674050214053066, 0.9577768903645413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 489}], {
             RGBColor[
             0.9488400952634564, 0.9613656073309171, 0.9714845534655293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 500}], {
             RGBColor[
             0.8558440314992217, 0.8880621171112462, 0.9766891007839085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 223}], {
             RGBColor[
             0.9347432228216308, 0.9476088649198595, 0.8658876900587369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 268}], {
             RGBColor[
             0.9935186878730429, 0.9893766106640364, 0.5963436970345017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 466}], {
             RGBColor[
             0.966004036172528, 0.9724840587951915, 0.8670897262184921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 470}], {
             RGBColor[
             0.994204343002696, 0.9918713611370933, 0.7457125653322361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 491}], {
             RGBColor[
             0.9835060345086996, 0.9557347816694752, 0.5461199025190926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 402}], {
             RGBColor[
             0.8143267187656196, 0.8556350319513023, 0.9728828606757401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 417}], {
             RGBColor[
             0.8255241767029771, 0.8639860777468289, 0.9539284851525527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 217}], {
             RGBColor[
             0.926981428054654, 0.9441420753439567, 0.9765409682932371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 224}], {
             RGBColor[
             0.6258135546813712, 0.6976855630622515, 0.9515110173103521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 292}], {
             RGBColor[
             0.8893900757594118, 0.9141677514138058, 0.9729554715531206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 358}], {
             RGBColor[
             0.9697141387733343, 0.9767269941753358, 0.9269054095595715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 361}], {
             RGBColor[
             0.8874302145159187, 0.9126050112572608, 0.9727685382381275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 398}], {
             RGBColor[
             0.9504463882536148, 0.962563578012914, 0.9687655184214993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 399}], {
             RGBColor[
             0.9736398870000433, 0.9766285507565258, 0.7366859235405425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 464}], {
             RGBColor[
             0.8226083177009622, 0.8619585178675628, 0.966309590750569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 481}], {
             RGBColor[
             0.9710367912511033, 0.9772739449655115, 0.9049856350880532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 292}], {
             RGBColor[
             0.8623778239867771, 0.8931006844973595, 0.9867355607772723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 398}], {
             RGBColor[
             0.9234341364809802, 0.9414965110964676, 0.9825456076456509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 464}], {
             RGBColor[
             0.7955960659283274, 0.8408914509511164, 0.9800896799747207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 481}], {
             RGBColor[
             0.9440245394784685, 0.9562068780490651, 0.9187657243122049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 496}], {
             RGBColor[
             0.7706597245896962, 0.8213955391614799, 0.9776148234123905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 235}], {
             RGBColor[
             0.9895639985089997, 0.9764590578604896, 0.4139585341913251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 274}], {
             RGBColor[
             0.9716902773436362, 0.9701067589453587, 0.6871058212509529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.805563367034662, 0.8394106880111396, 0.6876967449245224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 305}], {
             RGBColor[
             0.9905787787626419, 0.9798821499377592, 0.41790076385155406`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 310}], {
             RGBColor[
             0.9913169574578133, 0.9817116509394282, 0.47693677362003384`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 314}], {
             RGBColor[
             0.9890606243156869, 0.974761058508564, 0.4120030205045446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 406}], {
             RGBColor[
             0.8895585575947669, 0.9053392304608598, 0.6958560630416617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 432}], {
             RGBColor[
             0.9634354276258852, 0.882953189110917, 0.34041093820773166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 493}], {
             RGBColor[
             0.9811688963255782, 0.9481404069320776, 0.38134514749075393`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 238}], {
             RGBColor[
             0.9947297831043065, 0.9915529609088898, 0.6980661483974313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 258}], {
             RGBColor[
             0.994552542133855, 0.9907567633838197, 0.6484560129622472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 293}], {
             RGBColor[
             0.9458354082042464, 0.9558520546071247, 0.8251527331826136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 403}], {
             RGBColor[
             0.9380674012047744, 0.9496580566826787, 0.8244118137404222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 445}], {
             RGBColor[
             0.6640183332000261, 0.727081894766253, 0.8013650287278702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 471}], {
             RGBColor[
             0.993622273146866, 0.9910949770797803, 0.716420454536115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 497}], {
             RGBColor[
             0.990754817656164, 0.9899092105441304, 0.7639416127539786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 254}], {
             RGBColor[
             0.829691761406276, 0.865689011439601, 0.8824326913875326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 297}], {
             RGBColor[
             0.8294660040219779, 0.8655956549594935, 0.8861740754867351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 325}], {
             RGBColor[
             0.6692483639909401, 0.7415411755164578, 0.9676680805072236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 392}], {
             RGBColor[
             0.7670602624557292, 0.8183231218240234, 0.9773187244415424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 412}], {
             RGBColor[
             0.7969449303297396, 0.8421523447890598, 0.9801691507417236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 413}], {
             RGBColor[
             0.7118767461849018, 0.774842791674085, 0.971916879259437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 426}], {
             RGBColor[
             0.6833247513212202, 0.7525377562833788, 0.9690710832449874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 474}], {
             RGBColor[
             0.827889884007154, 0.8649438888289271, 0.9122944630002123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 490}], {
             RGBColor[
             0.8309916228599363, 0.8662265375556051, 0.8608906231667734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 234}], {
             RGBColor[
             0.9772555488218864, 0.9375374859085466, 0.5417931980558184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 301}], {
             RGBColor[
             0.9211638644966436, 0.9371554784447105, 0.880851315879778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 336}], {
             RGBColor[
             0.9917444860977707, 0.9908541470914676, 0.7864787601524565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 294}], {
             RGBColor[
             0.9491587121154403, 0.9589990300037685, 0.8627312074162495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 296}], {
             RGBColor[
             0.9928086104030016, 0.991294189838428, 0.7688434665493535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 339}], {
             RGBColor[
             0.9944762084550443, 0.9919837844882626, 0.741207051221588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 344}], {
             RGBColor[
             0.9669911140270776, 0.9731298863848699, 0.8613735440681869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 438}], {
             RGBColor[
             0.9681185173773567, 0.9739707019575544, 0.859465144270051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 439}], {
             RGBColor[
             0.8637867827212318, 0.8916311637183207, 0.854401167003546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 246}], {
             RGBColor[
             0.934325003401165, 0.9474359204417481, 0.8728186681730233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 268}], {
             RGBColor[
             0.9339433625580742, 0.9450668876889956, 0.7184114963831971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 411}], {
             RGBColor[
             0.9018505259472638, 0.9245751455827, 0.9905005023279605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 286}], {
             RGBColor[
             0.6106584453693285, 0.6860730596903231, 0.9664220513673911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 330}], {
             RGBColor[
             0.6189115949417086, 0.6925380927893328, 0.9631942348301996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 333}], {
             RGBColor[
             0.5609821941229143, 0.6464625653723509, 0.9616838861769952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 358}], {
             RGBColor[
             0.6415340136274168, 0.7092034149771842, 0.9156555478008381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 361}], {
             RGBColor[
             0.5592500893700012, 0.6450814320591092, 0.9615186764793942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 398}], {
             RGBColor[
             0.6222662631076974, 0.6950399988147624, 0.957515656662766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 441}], {
             RGBColor[
             0.6461334805573629, 0.7105459877411884, 0.7987661849192784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 464}], {
             RGBColor[
             0.49442819255504467`, 0.5944349386694112, 0.9550597289918357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 481}], {
             RGBColor[
             0.6428566661051858, 0.7097503657673598, 0.8937357733293199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 247}], {
             RGBColor[
             0.7995648688759961, 0.8392517086231851, 0.7185469472373077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 252}], {
             RGBColor[
             0.9939878983780197, 0.9897774063087056, 0.6035973005708095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 309}], {
             RGBColor[
             0.9191422110837213, 0.9334256168879871, 0.7300319313912755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 320}], {
             RGBColor[
             0.9633629484239911, 0.9686860325031796, 0.7342497447951088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 424}], {
             RGBColor[
             0.9928480446225331, 0.9871110155582355, 0.4629319777941452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 284}], {
             RGBColor[
             0.9705131631058574, 0.9679999654377327, 0.6864896387712476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 345}], {
             RGBColor[
             0.9724741310782298, 0.9694624521407376, 0.6831702314963801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 366}], {
             RGBColor[
             0.8788652978565827, 0.8957732326411346, 0.6930198742782918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 389}], {
             RGBColor[
             0.9911205917128046, 0.9807143213081054, 0.5046549682720375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 405}], {
             RGBColor[
             0.9810533473802722, 0.9758608176116235, 0.668647856114996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 429}], {
             RGBColor[
             0.9839149503329905, 0.9574034919032219, 0.39201304876076404`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 472}], {
             RGBColor[
             0.9828020245642407, 0.977164978192231, 0.665687801770591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 488}], {
             RGBColor[
             0.7138298912322678, 0.7633650558098681, 0.678798374650869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 229}], {
             RGBColor[
             0.9940404213647925, 0.9918035753272262, 0.748429171087897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 263}], {
             RGBColor[
             0.9935803366639873, 0.9916133184798057, 0.7560539652412792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 265}], {
             RGBColor[
             0.863044518523527, 0.8911846438228687, 0.8603735018483267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 267}], {
             RGBColor[
             0.9765409105605418, 0.9803726101207537, 0.8506045157664499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 270}], {
             RGBColor[
             0.6339127589610397, 0.6984189496741731, 0.8428633668975316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 329}], {
             RGBColor[
             0.9936816521643147, 0.9916552150428807, 0.7543749052047435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 424}], {
             RGBColor[
             0.9934372751397618, 0.9893591269333539, 0.5988692155770154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 256}], {
             RGBColor[
             0.9231364050183453, 0.7141124630291331, 0.5139372671826958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 279}], {
             RGBColor[
             0.9032567546594175, 0.7001472559735411, 0.5861458315786414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 287}], {
             RGBColor[
             0.9257047919027143, 0.7145096726870435, 0.4230423783077205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 298}], {
             RGBColor[
             0.9107890634591315, 0.7057648395433442, 0.5733955975214924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 318}], {
             RGBColor[
             0.7785635227750889, 0.6020470554817205, 0.5864375477994381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 335}], {
             RGBColor[
             0.9088374451250016, 0.7043093257852318, 0.5766991782975917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 409}], {
             RGBColor[
             0.7885997342487464, 0.6098874201629741, 0.5874378635654036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 468}], {
             RGBColor[
             0.8163702414486473, 0.6315819514512087, 0.5902057681929451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 232}], {
             RGBColor[
             0.9891611584435547, 0.9897858747179569, 0.8292911848204761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 263}], {
             RGBColor[
             0.9934837936504275, 0.9915733954626565, 0.7576539328212726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 267}], {
             RGBColor[
             0.9764443675469822, 0.9803326871036045, 0.8522044833464433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 280}], {
             RGBColor[
             0.9295913680538539, 0.9435728237373504, 0.8685187937000957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 393}], {
             RGBColor[
             0.9908484012716176, 0.9904835929875238, 0.8013292047150049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 480}], {
             RGBColor[
             0.9619796797327622, 0.8760026932131701, 0.5062880779529505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 485}], {
             RGBColor[
             0.7930325033804371, 0.83575664248135, 0.855531114694455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 382}], {
             RGBColor[
             0.9534953996737379, 0.9137850423186002, 0.6271505840813505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 413}], {
             RGBColor[
             0.8559899049979851, 0.8369392942922902, 0.6309208085879708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 474}], {
             RGBColor[
             0.9720030428202375, 0.9270403914471324, 0.5712983923287461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 484}], {
             RGBColor[
             0.9758490222132876, 0.9286308027633206, 0.5075605607102893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 490}], {
             RGBColor[
             0.9751047816730196, 0.9283230401738103, 0.5198945524953074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 233}], {
             RGBColor[
             0.9894391777871, 0.9899008428612841, 0.824683684806933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 275}], {
             RGBColor[
             0.9907078496764665, 0.9904254712909175, 0.8036585083825271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 326}], {
             RGBColor[
             0.9497928174940335, 0.9602330570878898, 0.8944217081773747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 346}], {
             RGBColor[
             0.9692553281543101, 0.9754490717552533, 0.8857776081896322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 355}], {
             RGBColor[
             0.8412161032550252, 0.8746965099996187, 0.8837896923121971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 395}], {
             RGBColor[
             0.7459541003426513, 0.7981092375220517, 0.8757770519147383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 404}], {
             RGBColor[
             0.9064493625436187, 0.579693983096704, 0.4831231587663463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 431}], {
             RGBColor[
             0.9919811702729231, 0.9888931060390926, 0.6328948296708732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 444}], {
             RGBColor[
             0.9757524357394753, 0.9802946039542322, 0.8747796997649964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 486}], {
             RGBColor[
             0.9790339311420048, 0.9827419378524831, 0.8692249839995864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 267}], {
             RGBColor[
             0.971661647639304, 0.9783549095114845, 0.9314665294990291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 280}], {
             RGBColor[
             0.9248086481461757, 0.9415950461452303, 0.9477808398526815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 338}], {
             RGBColor[
             0.9892996641847274, 0.9889277448872777, 0.7604554688854605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 383}], {
             RGBColor[
             0.9015786490176143, 0.9230818161036618, 0.9455625569153179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 393}], {
             RGBColor[
             0.9860656813639394, 0.9885058153954036, 0.8805912508675906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 395}], {
             RGBColor[
             0.7426098329824484, 0.7967262970248569, 0.9312002167597963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 480}], {
             RGBColor[
             0.957196959825084, 0.87402491562105, 0.5855501241055363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 259}], {
             RGBColor[
             0.9829807892397651, 0.9862263700961091, 0.8867653331372486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 275}], {
             RGBColor[
             0.9890800542072842, 0.9897523360319752, 0.8306352919065141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 326}], {
             RGBColor[
             0.9481650220248512, 0.9595599218289474, 0.9213984917013616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 346}], {
             RGBColor[
             0.9676275326851278, 0.974775936496311, 0.9127543917136194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 348}], {
             RGBColor[
             0.986453814193062, 0.9753079937009379, 0.6241313139770084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 355}], {
             RGBColor[
             0.8395883077858428, 0.8740233747406765, 0.910766475836184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 379}], {
             RGBColor[
             0.9644585648131202, 0.9724125254460764, 0.9181186277217364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 400}], {
             RGBColor[
             0.9545054728602385, 0.8572586328610069, 0.553556995620943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 404}], {
             RGBColor[
             0.9048215670744364, 0.5790208478377616, 0.5100999422903334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 431}], {
             RGBColor[
             0.9903533748037407, 0.9882199707801503, 0.6598716131948602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 444}], {
             RGBColor[
             0.974124640270293, 0.97962146869529, 0.9017564832889833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 486}], {
             RGBColor[
             0.9774061356728224, 0.9820688025935407, 0.8962017675235734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 336}], {
             RGBColor[
             0.9766323948182345, 0.9372797957137092, 0.5521204725671952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 449}], {
             RGBColor[
             0.8832489736397849, 0.8655251211624133, 0.6442845534768203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 274}], {
             RGBColor[
             0.972193651536949, 0.9718047582972842, 0.6890613349377334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 284}], {
             RGBColor[
             0.9714842569416884, 0.9712756929696659, 0.6902621549477672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 300}], {
             RGBColor[
             0.806066741227975, 0.8411086873630652, 0.6896522586113027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 305}], {
             RGBColor[
             0.9910821529559548, 0.9815801492896847, 0.41985627753833454`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 308}], {
             RGBColor[
             0.7887256488810537, 0.8270304073885268, 0.6882871042992389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 345}], {
             RGBColor[
             0.9734452249140606, 0.9727381796726707, 0.6869427476728998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 389}], {
             RGBColor[
             0.9920916855486355, 0.9839900488400386, 0.508427484448557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 432}], {
             RGBColor[
             0.9639388018191981, 0.8846511884628425, 0.34236645189451215`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 456}], {
             RGBColor[
             0.8736188420024441, 0.8941917631001358, 0.6961726832080206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 289}], {
             RGBColor[
             0.9864586155949329, 0.9860919882453206, 0.707310515870945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 300}], {
             RGBColor[
             0.8009180722923162, 0.8442467115654874, 0.9412593514711998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 308}], {
             RGBColor[
             0.7835769799453949, 0.830168431590949, 0.9398941971591359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 314}], {
             RGBColor[
             0.9844153295733409, 0.9795970820629117, 0.6655656270512221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 466}], {
             RGBColor[
             0.9587297795197256, 0.9687413176563711, 0.9547438976624212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 470}], {
             RGBColor[
             0.9869300863498937, 0.9881286199982728, 0.8333667367761651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 493}], {
             RGBColor[
             0.9765236015832321, 0.9529764304864254, 0.6349077540374315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 241}], {
             RGBColor[
             0.7744907541918538, 0.7510624829258263, 0.6174905872195342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 274}], {
             RGBColor[
             0.9485651021735978, 0.8882106417907871, 0.6175253149519887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 284}], {
             RGBColor[
             0.9478557075783371, 0.8876815764631688, 0.6187261349620226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 351}], {
             RGBColor[
             0.9196322840526594, 0.8656205805038066, 0.6314139064132727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 371}], {
             RGBColor[
             0.6627499226235705, 0.6584285145614333, 0.6092238134411527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 429}], {
             RGBColor[
             0.96125749480547, 0.877085102928658, 0.3242495449515389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 432}], {
             RGBColor[
             0.9403102524558469, 0.8010570719563455, 0.2708304319087675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 460}], {
             RGBColor[
             0.9685271801426489, 0.9005329158825074, 0.44386225398847556`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 258}], {
             RGBColor[
             0.9946212728892152, 0.991320868530875, 0.6862554811321622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 266}], {
             RGBColor[
             0.8943619726899206, 0.9155284571535248, 0.8579801709962225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 293}], {
             RGBColor[
             0.9459041389596066, 0.9564161597541802, 0.8629522013525286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 403}], {
             RGBColor[
             0.9381361319601345, 0.950222161829734, 0.8622112819103371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 445}], {
             RGBColor[
             0.6640870639553862, 0.7276459999133083, 0.8391644968977852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 471}], {
             RGBColor[
             0.9936910039022261, 0.9916590822268357, 0.75421992270603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 483}], {
             RGBColor[
             0.9387662452931594, 0.9507245970975173, 0.8622713826825499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 497}], {
             RGBColor[
             0.9908235484115242, 0.9904733156911858, 0.8017410809238936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 251}], {
             RGBColor[
             0.9934173347240309, 0.988182895429691, 0.5372912686165716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 272}], {
             RGBColor[
             0.9852147493260792, 0.9617880191142272, 0.39706252240247014`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 332}], {
             RGBColor[
             0.9121310805135703, 0.9272253896383891, 0.704148033982793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 387}], {
             RGBColor[
             0.8562839863215574, 0.8835001318552018, 0.6986074804896891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 435}], {
             RGBColor[
             0.9568459658475779, 0.9628798254504982, 0.7084129796634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 453}], {
             RGBColor[
             0.9800708495403375, 0.9444364372918151, 0.3770794430788301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 454}], {
             RGBColor[
             0.9800172466583841, 0.9805290125417168, 0.6819517417704417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 489}], {
             RGBColor[
             0.9719193285388971, 0.9744895984673272, 0.6956594048714297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 434}], {
             RGBColor[
             0.9824708557842159, 0.9794694803975184, 0.6716647088712671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 495}], {
             RGBColor[
             0.9660616355933693, 0.9672315108468171, 0.6994412384443153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 271}], {
             RGBColor[
             0.7884408837993161, 0.8020090169946836, 0.6514277740698605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 304}], {
             RGBColor[
             0.7680933577611944, 0.7256989378842476, 0.6123430918852315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 311}], {
             RGBColor[
             0.8004256618812964, 0.8410928578219994, 0.8122389536655948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 351}], {
             RGBColor[
             0.751312764268903, 0.8057142392302119, 0.9760624857261906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 371}], {
             RGBColor[
             0.4944304028398141, 0.5985221732878385, 0.9538723927540707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 429}], {
             RGBColor[
             0.7929379750217136, 0.8171787616550634, 0.6688981242644569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 442}], {
             RGBColor[
             0.7996764294541114, 0.8413022912029227, 0.8624004120814632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 249}], {
             RGBColor[
             0.9194367585699803, 0.9380383270797816, 0.9727761045272456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 269}], {
             RGBColor[
             0.9376015794557467, 0.9500011106317969, 0.8710702002855781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 282}], {
             RGBColor[
             0.9383463702656972, 0.9502547432958939, 0.8547758744243934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 310}], {
             RGBColor[
             0.9375235203302712, 0.9484947504869077, 0.7652137369944256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 323}], {
             RGBColor[
             0.9377274517078665, 0.9489309390829592, 0.7874104089271085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 419}], {
             RGBColor[
             0.9370558552498649, 0.9474944621681115, 0.71431127908653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 449}], {
             RGBColor[
             0.842914119898911, 0.8777071826987807, 0.9848455718682059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 499}], {
             RGBColor[
             0.8647539972614213, 0.8949953805670554, 0.9869622023054427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 273}], {
             RGBColor[
             0.9635357789065457, 0.882396065441714, 0.508636069356625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 279}], {
             RGBColor[
             0.971716478752066, 0.9768275906092427, 0.8611459837548661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 283}], {
             RGBColor[
             0.8324632206425606, 0.8673529869700162, 0.8599864926327181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 285}], {
             RGBColor[
             0.9788307746155596, 0.9821334208156459, 0.8491033365635037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 318}], {
             RGBColor[
             0.8470232468677376, 0.8787273901174222, 0.8614376999756627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 335}], {
             RGBColor[
             0.9772971692176502, 0.9809896604209335, 0.8516993304738163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 396}], {
             RGBColor[
             0.8921108351710368, 0.9139501567783226, 0.8659316094102671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 421}], {
             RGBColor[
             0.9324049866835719, 0.9458405347023084, 0.8698383472904325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 430}], {
             RGBColor[
             0.9889031671601887, 0.9746816922814432, 0.5722093020791963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 459}], {
             RGBColor[
             0.9837591019441396, 0.9573295524237594, 0.552225580090051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 477}], {
             RGBColor[
             0.9512043926310256, 0.9608306707085278, 0.8716314514121284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 261}], {
             RGBColor[
             0.9860355746371046, 0.9884933654901499, 0.8810901972449547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 262}], {
             RGBColor[
             0.9721357070515928, 0.9785509452612371, 0.9236101382109703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 295}], {
             RGBColor[
             0.9086894701607544, 0.9285600848054791, 0.9383417707686712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 341}], {
             RGBColor[
             0.9213608877203647, 0.9386639292110457, 0.9395503818874147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 376}], {
             RGBColor[
             0.9642494209095845, 0.9726693659691357, 0.9369595635765466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 391}], {
             RGBColor[
             0.9724215892404824, 0.9787641557296217, 0.9231262142351968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 407}], {
             RGBColor[
             0.9833288831991522, 0.9684440472243754, 0.6374080750623456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 448}], {
             RGBColor[
             0.9881952836571162, 0.9893864606719148, 0.8452982296355833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 455}], {
             RGBColor[
             0.9895091243027418, 0.9899297675430454, 0.8235244900269694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 475}], {
             RGBColor[
             0.9811567055016226, 0.9611167817990303, 0.6289695748887817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 478}], {
             RGBColor[
             0.9546625343546409, 0.8622933113289278, 0.575273035262615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 482}], {
             RGBColor[
             0.9419370500502526, 0.9550708025278507, 0.9415129546189964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 262}], {
             RGBColor[
             0.871743753271357, 0.9002558348783203, 0.9667696827276533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 299}], {
             RGBColor[
             0.8890884698458729, 0.9102013312735181, 0.7638347303183946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 376}], {
             RGBColor[
             0.8638574671293487, 0.8943742555862189, 0.9801191080932297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 438}], {
             RGBColor[
             0.8629587027567, 0.893703958588689, 0.9816404817408335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 448}], {
             RGBColor[
             0.8878033298768804, 0.911091350288998, 0.8884577741522663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 475}], {
             RGBColor[
             0.8807647517213868, 0.8828216714161135, 0.6721291194054648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 482}], {
             RGBColor[
             0.8415450962700168, 0.8767756921449339, 0.9846724991356796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 384}], {
             RGBColor[
             0.9898060796555245, 0.9900525662128256, 0.8186031713355417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 402}], {
             RGBColor[
             0.9696100984187155, 0.9753124169949137, 0.8672086451718913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 411}], {
             RGBColor[
             0.9610076318417665, 0.9687119240796294, 0.8753636810935516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 458}], {
             RGBColor[
             0.9937566145797971, 0.990607096405499, 0.6746921318321885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 252}], {
             RGBColor[
             0.8005942639101209, 0.8416818393377522, 0.847189519865954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 278}], {
             RGBColor[
             0.7887088213695556, 0.8346161702909813, 0.9478478382384943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 309}], {
             RGBColor[
             0.7257485766158226, 0.7853300499170337, 0.97362415068642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 401}], {
             RGBColor[
             0.7860466723044891, 0.7939327794350399, 0.6421267145213607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 451}], {
             RGBColor[
             0.691006709930464, 0.7579846103188834, 0.9702157614935503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 339}], {
             RGBColor[
             0.9671333502308079, 0.9733642466148391, 0.8668774472100682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 344}], {
             RGBColor[
             0.9396482558028414, 0.9545103485114463, 0.9870439400566671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 387}], {
             RGBColor[
             0.8302388668229261, 0.868164187629729, 0.9794531008326357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 439}], {
             RGBColor[
             0.8364439244969955, 0.873011625844897, 0.9800715629920261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 269}], {
             RGBColor[
             0.9755645879651247, 0.9797121801080557, 0.8552893575594958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 282}], {
             RGBColor[
             0.9763093787750752, 0.9799658127721527, 0.8389950316983108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 310}], {
             RGBColor[
             0.975486528839649, 0.9782058199631665, 0.749432894268343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 323}], {
             RGBColor[
             0.9756904602172445, 0.978642008559218, 0.771629566201026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 406}], {
             RGBColor[
             0.8737281289766026, 0.901833399484598, 0.9683521836899709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 419}], {
             RGBColor[
             0.9750188637592427, 0.9772055316443702, 0.6985304363604475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 499}], {
             RGBColor[
             0.9027170057707992, 0.9247064500433142, 0.9711813595793601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 263}], {
             RGBColor[
             0.9608300197363391, 0.9686582788426883, 0.8791670416275121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 365}], {
             RGBColor[
             0.9609830082068656, 0.9687215435068754, 0.8766316267494183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 485}], {
             RGBColor[
             0.7603787294663487, 0.8128415258613817, 0.9770442235006946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 258}], {
             RGBColor[
             0.9945059498883695, 0.9906571072819246, 0.6433847345751542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 272}], {
             RGBColor[
             0.9863652824600236, 0.9643946672425807, 0.5098953772392291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 435}], {
             RGBColor[
             0.9579964989815224, 0.9654864735788518, 0.821245834500159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 447}], {
             RGBColor[
             0.7112992009362477, 0.7679749057532088, 0.799309414240782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 453}], {
             RGBColor[
             0.9812213826742819, 0.9470430854201686, 0.489912297915589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 454}], {
             RGBColor[
             0.9811677797923286, 0.9831356606700701, 0.7947845966072005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 309}], {
             RGBColor[
             0.9201716061178462, 0.9358557476025542, 0.858674504019922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 320}], {
             RGBColor[
             0.9643923434581159, 0.9711161632177467, 0.862892317423755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 424}], {
             RGBColor[
             0.9938774396566579, 0.9895411462728027, 0.5915745504227915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 287}], {
             RGBColor[
             0.9899081177915765, 0.989429877281035, 0.7685820639261369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 301}], {
             RGBColor[
             0.9176325190570267, 0.9356951763539907, 0.9393748486432756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 336}], {
             RGBColor[
             0.9882131406581537, 0.9893938450007478, 0.845002292915954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 354}], {
             RGBColor[
             0.985717499618785, 0.9883618332959196, 0.8863615234502717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 388}], {
             RGBColor[
             0.6503738092968374, 0.7179167757650288, 0.9172596285093968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 436}], {
             RGBColor[
             0.979316781021148, 0.9839101683666329, 0.9116152160192408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 473}], {
             RGBColor[
             0.9896429328778643, 0.9888626735649124, 0.7397183226001549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 350}], {
             RGBColor[
             0.9818761794219759, 0.955011766570015, 0.5727919385888256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 377}], {
             RGBColor[
             0.9931498368582174, 0.9913712027730872, 0.7585295785330597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 412}], {
             RGBColor[
             0.9583451372611722, 0.9670476475781994, 0.8950291274527038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 426}], {
             RGBColor[
             0.8447249582526529, 0.8774330590725183, 0.8839310599559675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 476}], {
             RGBColor[
             0.978787561063339, 0.9825540428600641, 0.8694560627634901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 260}], {
             RGBColor[
             0.9744573589363206, 0.9293937109272974, 0.5398749707825896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 299}], {
             RGBColor[
             0.9755282864808844, 0.9284151095693081, 0.4188019811854833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 312}], {
             RGBColor[
             0.8930024484203438, 0.8670954028343385, 0.6363030913110044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 327}], {
             RGBColor[
             0.9737897065055168, 0.9291176194892752, 0.5509396993901126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 334}], {
             RGBColor[
             0.9279608041273801, 0.8949702467558425, 0.639637450486034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 385}], {
             RGBColor[
             0.9282016730137628, 0.8951623090676324, 0.6396604247754434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 446}], {
             RGBColor[
             0.97366299501554, 0.9290652210318331, 0.5530396366978507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 478}], {
             RGBColor[
             0.9407103972094166, 0.802211979241801, 0.27339983064638695`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 287}], {
             RGBColor[
             0.9919428994765953, 0.9902713117992944, 0.7348604655591745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 298}], {
             RGBColor[
             0.9770271710330125, 0.9815264786555951, 0.8852136847729464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 409}], {
             RGBColor[
             0.8548378418226275, 0.8856490592752251, 0.8992559508168576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 281}], {
             RGBColor[
             0.8920908074297456, 0.5544668864682362, 0.5525975644076859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 317}], {
             RGBColor[
             0.754342116626884, 0.4464730209395055, 0.567045241670724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 322}], {
             RGBColor[
             0.8986903116587317, 0.5593887859165176, 0.5414263251743828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 324}], {
             RGBColor[
             0.8841467733331241, 0.5485422388461378, 0.5660447419973436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 326}], {
             RGBColor[
             0.8629188308658924, 0.5320095680277765, 0.5776772575359016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 343}], {
             RGBColor[
             0.8755431967520437, 0.5420758947061104, 0.5788813808240272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 374}], {
             RGBColor[
             0.906146009863134, 0.5628915612185925, 0.42922020200474764`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 445}], {
             RGBColor[
             0.5753473070255529, 0.29865096688533577`, 0.553340688614112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 272}], {
             RGBColor[
             0.9863033644904178, 0.9642622309664609, 0.5031559883610528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 293}], {
             RGBColor[
             0.9457268979891551, 0.95561996222911, 0.8133420659173445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 403}], {
             RGBColor[
             0.937958890989683, 0.9494259643046639, 0.812601146475153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 435}], {
             RGBColor[
             0.9579345810119165, 0.965354037302732, 0.8145064456219827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 453}], {
             RGBColor[
             0.9811594647046762, 0.9469106491440489, 0.48317290903741283`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 471}], {
             RGBColor[
             0.9935137629317746, 0.9908628847017656, 0.7046097872708459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 497}], {
             RGBColor[
             0.9906463074410727, 0.9896771181661157, 0.7521309454887095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 275}], {
             RGBColor[
             0.9842494611291315, 0.9867509985257426, 0.8657401567128427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 331}], {
             RGBColor[
             0.9862765745267577, 0.9868309198554761, 0.777022172538553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 348}], {
             RGBColor[
             0.9816232211149094, 0.9723066561947052, 0.659236178783337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 372}], {
             RGBColor[
             0.9863930077163424, 0.9870799586747969, 0.7896952066825125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 400}], {
             RGBColor[
             0.9496748797820858, 0.8542572953547742, 0.5886618604272715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 404}], {
             RGBColor[
             0.8999909739962837, 0.576019510331529, 0.545204807096662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 418}], {
             RGBColor[
             0.8553732511794956, 0.8871270510100984, 0.9479261046548805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 431}], {
             RGBColor[
             0.985522781725588, 0.9852186332739177, 0.6949764780011888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 444}], {
             RGBColor[
             0.9692940471921404, 0.9766201311890572, 0.9368613480953119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 486}], {
             RGBColor[
             0.9725755425946698, 0.979067465087308, 0.931306632329902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 299}], {
             RGBColor[
             0.9925633623471992, 0.989771316045517, 0.669582912803585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 312}], {
             RGBColor[
             0.9100375242866585, 0.9284516093105475, 0.8870840229291062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 328}], {
             RGBColor[
             0.9658432516142919, 0.9728336660377899, 0.8883879620285846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 334}], {
             RGBColor[
             0.9449958799936948, 0.9563264532320515, 0.8904183821041358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 399}], {
             RGBColor[
             0.9923892644877166, 0.9893989383280775, 0.6506334352063455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 407}], {
             RGBColor[
             0.9864118219202428, 0.9697189216134574, 0.5863158020642193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 446}], {
             RGBColor[
             0.9906980708818547, 0.9904214275080421, 0.8038205683159525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 478}], {
             RGBColor[
             0.9577454730757314, 0.86356818571801, 0.5241807622644886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 262}], {
             RGBColor[
             0.9728447243282432, 0.9788441421260449, 0.9118598870589807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 299}], {
             RGBColor[
             0.990189440902759, 0.9887896385212427, 0.708924934649722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 313}], {
             RGBColor[
             0.8912668722110167, 0.9145911818033867, 0.9248102149043478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 328}], {
             RGBColor[
             0.9634693301698516, 0.9718519885135155, 0.9277299838747216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 391}], {
             RGBColor[
             0.9731306065171326, 0.9790573525944295, 0.9113759630832073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 407}], {
             RGBColor[
             0.9840379004758026, 0.968737244089183, 0.6256578239103562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 448}], {
             RGBColor[
             0.9889043009337665, 0.9896796575367226, 0.8335479784835937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 455}], {
             RGBColor[
             0.990218141579392, 0.9902229644078533, 0.81177423887498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 475}], {
             RGBColor[
             0.981865722778273, 0.961409978663838, 0.6172193237367922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 478}], {
             RGBColor[
             0.9553715516312913, 0.8625865081937356, 0.5635227841106256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 482}], {
             RGBColor[
             0.942646067326903, 0.9553639993926586, 0.929762703467007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 299}], {
             RGBColor[
             0.9762895733172472, 0.9788472182923299, 0.7514448756157374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 376}], {
             RGBColor[
             0.9510585706007231, 0.9630201426050307, 0.9677292533905726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 391}], {
             RGBColor[
             0.9592307389316209, 0.9691149323655167, 0.9538959040492228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 448}], {
             RGBColor[
             0.9750044333482548, 0.9797372373078098, 0.8760679194496093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 455}], {
             RGBColor[
             0.9763182739938804, 0.9802805441789404, 0.8542941798409954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 475}], {
             RGBColor[
             0.9679658551927612, 0.9514675584349253, 0.6597392647028076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 478}], {
             RGBColor[
             0.9414716840457795, 0.8526440879648228, 0.606042725076641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 482}], {
             RGBColor[
             0.9287461997413913, 0.9454215791637457, 0.9722826444330224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 267}], {
             RGBColor[
             0.9759842828461769, 0.9801424302561841, 0.8598292774998255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 393}], {
             RGBColor[
             0.9903883165708123, 0.9902933361401033, 0.808953998868387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 485}], {
             RGBColor[
             0.7925724186796318, 0.8355663856339295, 0.8631559088478371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 281}], {
             RGBColor[
             0.9728476065132524, 0.9792703699123232, 0.9308460990813758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 295}], {
             RGBColor[
             0.9054424905640341, 0.926326983936895, 0.952279081243889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 324}], {
             RGBColor[
             0.9649035724166309, 0.9733457222902249, 0.9442932766710335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 341}], {
             RGBColor[
             0.9181139081236446, 0.9364308283424616, 0.9534876923626326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 374}], {
             RGBColor[
             0.986902808946641, 0.9876950446626795, 0.8074687366784377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 397}], {
             RGBColor[
             0.9864689702576035, 0.9867671075746483, 0.7602480727187417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 270}], {
             RGBColor[
             0.5028203131062146, 0.5977600951526664, 0.9564076652379547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 320}], {
             RGBColor[
             0.8328597330863946, 0.8702752893567914, 0.9837312809184021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 329}], {
             RGBColor[
             0.8625892063094895, 0.890996360521374, 0.8679192035451666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 424}], {
             RGBColor[
             0.8623448292849366, 0.8887002724118473, 0.7124135139174386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 293}], {
             RGBColor[
             0.8454675977898605, 0.8798275508517599, 0.9850667557814048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 317}], {
             RGBColor[
             0.7426453323869712, 0.7988794450650578, 0.9749836043832734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 322}], {
             RGBColor[
             0.886993527418819, 0.91179521004207, 0.9493646878869322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 343}], {
             RGBColor[
             0.8638464125121309, 0.8944823188316627, 0.9868197435365766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 359}], {
             RGBColor[
             0.7848838084865025, 0.8318764636183198, 0.9791935409398735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 403}], {
             RGBColor[
             0.8376995907903884, 0.8736335529273138, 0.9843258363392134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 440}], {
             RGBColor[
             0.6720064219644322, 0.7422823083284142, 0.9689093840239742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 445}], {
             RGBColor[
             0.5636505227856401, 0.651057391010888, 0.9612790513266614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 471}], {
             RGBColor[
             0.89325446273248, 0.9150704733244155, 0.8763344771349062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 483}], {
             RGBColor[
             0.8383297041234133, 0.8741359881950971, 0.9843859371114262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 280}], {
             RGBColor[
             0.9120918572496032, 0.9321418585308778, 0.9706941383786486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 393}], {
             RGBColor[
             0.9733488904673668, 0.9790526277810513, 0.9035045493935578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 424}], {
             RGBColor[
             0.9758412213219514, 0.9778882387097323, 0.7026445278355617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 480}], {
             RGBColor[
             0.9444801689285114, 0.8645717280066977, 0.6084634226315034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 485}], {
             RGBColor[
             0.7755329925761865, 0.8243256772748775, 0.9577064593730079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 491}], {
             RGBColor[
             0.9827061742451428, 0.9531928044386112, 0.3986437088435529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 282}], {
             RGBColor[
             0.9944741996608416, 0.991928596324168, 0.7372891274566434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 310}], {
             RGBColor[
             0.9936513497254156, 0.9901686035151818, 0.6477269900266757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 323}], {
             RGBColor[
             0.9938552811030109, 0.9906047921112332, 0.6699236619593585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 406}], {
             RGBColor[
             0.8918929498623691, 0.9137961830366133, 0.8666462794483035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 411}], {
             RGBColor[
             0.9611312816193782, 0.968763056440326, 0.8733144842831585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 419}], {
             RGBColor[
             0.9931836846450093, 0.9891683151963855, 0.5968245321187801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 499}], {
             RGBColor[
             0.9208818266565657, 0.9366692335953294, 0.8694754553376928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 329}], {
             RGBColor[
             0.6334574467470022, 0.6982306663726785, 0.8504090685943715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 479}], {
             RGBColor[
             0.6113436784369024, 0.6832391862755567, 0.9550567161967962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 304}], {
             RGBColor[
             0.9503630071524132, 0.8365518132266995, 0.3016316994226398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 307}], {
             RGBColor[
             0.9820722898542738, 0.9506131533479609, 0.4337155246699344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 311}], {
             RGBColor[
             0.9826953112725151, 0.9519457331644513, 0.5015275612030031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 351}], {
             RGBColor[
             0.9335824136601217, 0.9165671145726639, 0.6653510932635989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 371}], {
             RGBColor[
             0.6767000522310328, 0.7093750486302906, 0.6431610002914789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 429}], {
             RGBColor[
             0.9752076244129324, 0.9280316369975153, 0.35818673180186517`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 442}], {
             RGBColor[
             0.98194607884533, 0.9521551665453747, 0.5516890196188715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 435}], {
             RGBColor[
             0.9497939135835707, 0.939091597263388, 0.6810170882860576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 453}], {
             RGBColor[
             0.9730187972763302, 0.9206482091047048, 0.34968355170148757`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 497}], {
             RGBColor[
             0.9825056400127268, 0.9634146781267716, 0.6186415881527844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 279}], {
             RGBColor[
             0.9414345120288503, 0.8675121628626713, 0.6176625688277999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 283}], {
             RGBColor[
             0.8021812539193448, 0.7580375592234447, 0.6165030777056519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 285}], {
             RGBColor[
             0.9485488078923439, 0.8728179930690745, 0.6056199216364377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 396}], {
             RGBColor[
             0.861828868447821, 0.804634729031751, 0.622448194483201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 421}], {
             RGBColor[
             0.902123019960356, 0.836525106955737, 0.6263549323633664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 430}], {
             RGBColor[
             0.9586212004369729, 0.8653662645348716, 0.32872588715213014`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 459}], {
             RGBColor[
             0.9534771352209239, 0.848014124677188, 0.30874216516298486`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 477}], {
             RGBColor[
             0.9209224259078099, 0.8515152429619564, 0.6281480364850625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 284}], {
             RGBColor[
             0.9536105357763247, 0.964923394054535, 0.963409442007395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 300}], {
             RGBColor[
             0.7881930200626114, 0.8347563884479343, 0.9627995456709306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 305}], {
             RGBColor[
             0.9732084317905912, 0.9752278503745538, 0.6930035645979623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 389}], {
             RGBColor[
             0.9742179643832719, 0.9776377499249076, 0.7815747715081849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 432}], {
             RGBColor[
             0.9460650806538345, 0.8782988895477116, 0.6155137389541399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 460}], {
             RGBColor[
             0.9742820083406367, 0.9777747334738736, 0.788545561033848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 331}], {
             RGBColor[
             0.9923758394942768, 0.9903568857913423, 0.7208921313078185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 346}], {
             RGBColor[
             0.9688962045744942, 0.9753005649259444, 0.8917292152892133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 348}], {
             RGBColor[
             0.9877224860824285, 0.9758326221305713, 0.6031061375526025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 355}], {
             RGBColor[
             0.8408569796752092, 0.8745480031703099, 0.8897412994117782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 372}], {
             RGBColor[
             0.9924922726838615, 0.9906059246106631, 0.7335651654517781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 404}], {
             RGBColor[
             0.9060902389638028, 0.579545476267395, 0.4890747658659274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 418}], {
             RGBColor[
             0.8614725161470147, 0.8906530169459645, 0.891796063424146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 431}], {
             RGBColor[
             0.9916220466931072, 0.9887445992097837, 0.6388464367704543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 444}], {
             RGBColor[
             0.9753933121596595, 0.9801460971249234, 0.8807313068645775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 486}], {
             RGBColor[
             0.9786748075621889, 0.9825934310231741, 0.8751765910991675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 306}], {
             RGBColor[
             0.60764081461632, 0.6731392157970155, 0.9022406434554823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 347}], {
             RGBColor[
             0.40792485549946345`, 0.5166830812635536, 0.9484911606467696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 382}], {
             RGBColor[
             0.5894693565927989, 0.6600228878563985, 0.9525213777011241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 462}], {
             RGBColor[
             0.5982982481360999, 0.6666074607134094, 0.9375763672620213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 288}], {
             RGBColor[
             0.888814479733199, 0.909573960469028, 0.7307019818929664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 313}], {
             RGBColor[
             0.89440728701025, 0.91394310402077, 0.7312594206545873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 340}], {
             RGBColor[
             0.9852976443362951, 0.9851413154803373, 0.7025454505810413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 373}], {
             RGBColor[
             0.9713736335435215, 0.9129306546176577, 0.3803207891221114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 386}], {
             RGBColor[
             0.9785457939944753, 0.9389696450148495, 0.3985713146004738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 414}], {
             RGBColor[
             0.9941151008875209, 0.989821120790005, 0.6008432328732016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 498}], {
             RGBColor[
             0.9893666075805596, 0.9754707900885657, 0.4406081320432288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 401}], {
             RGBColor[
             0.9685842592659473, 0.9373928080737894, 0.6278353862274028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 451}], {
             RGBColor[
             0.8735442968919221, 0.9014446389576329, 0.9559244331995924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.9567295077378641, 0.9672495182366032, 0.9581298360346788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 318}], {
             RGBColor[
             0.8249219799900421, 0.8638434875383795, 0.9704641994468377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 335}], {
             RGBColor[
             0.9551959023399548, 0.9661057578418908, 0.9607258299449914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 396}], {
             RGBColor[
             0.8700095682933414, 0.8990662541992798, 0.9749581088814421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 409}], {
             RGBColor[
             0.8349581914636997, 0.8716838522196331, 0.9714645152128033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 421}], {
             RGBColor[
             0.9103037198058764, 0.9309566321232657, 0.9788648467616076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 430}], {
             RGBColor[
             0.9668019002824932, 0.9597977897024004, 0.6812358015503712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 459}], {
             RGBColor[
             0.9616578350664442, 0.9424456498447167, 0.661252079561226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 477}], {
             RGBColor[
             0.9291031257533302, 0.9459467681294851, 0.9806579508833035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 338}], {
             RGBColor[
             0.9297298737950266, 0.9427146939066712, 0.79968307776508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 383}], {
             RGBColor[
             0.8420088586279135, 0.8768687651230553, 0.9847901657949374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 393}], {
             RGBColor[
             0.9264958909742386, 0.9422927644147971, 0.9198188597472101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 480}], {
             RGBColor[
             0.8976271694353832, 0.8278118646404435, 0.6247777329851558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 317}], {
             RGBColor[
             0.8291139240566294, 0.8668129074077418, 0.9554248060784098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 322}], {
             RGBColor[
             0.9734621190884772, 0.9797286723847538, 0.9298058895820687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 324}], {
             RGBColor[
             0.9589185807628695, 0.968882125314374, 0.9544243064050294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 343}], {
             RGBColor[
             0.9503150041817892, 0.9624157811743466, 0.9672609452317131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 374}], {
             RGBColor[
             0.9809178172928795, 0.9832314476868287, 0.8175997664124335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 397}], {
             RGBColor[
             0.9804839786038421, 0.9823035105987974, 0.7703791024527377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 445}], {
             RGBColor[
             0.6501191144552984, 0.7189908533535719, 0.9417202530217978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 310}], {
             RGBColor[
             0.9943961405353661, 0.9904222361792787, 0.6314326641654908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 323}], {
             RGBColor[
             0.9946000719129614, 0.9908584247753303, 0.6536293360981738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 406}], {
             RGBColor[
             0.8926377406723196, 0.9140498157007102, 0.8503519535871187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 419}], {
             RGBColor[
             0.9939284754549598, 0.9894219478604824, 0.5805302062575952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 499}], {
             RGBColor[
             0.9216266174665162, 0.9369228662594264, 0.8531811294765079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 396}], {
             RGBColor[
             0.7307563101838359, 0.7895916505600531, 0.9737986177592941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 421}], {
             RGBColor[
             0.7710504616963709, 0.8214820284840392, 0.9777053556394596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 430}], {
             RGBColor[
             0.8275486421729877, 0.8503231860631738, 0.6800763104282233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 459}], {
             RGBColor[
             0.8224045769569388, 0.83297104620549, 0.660092588439078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 477}], {
             RGBColor[
             0.7898498676438248, 0.8364721644902584, 0.9794984597611556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 300}], {
             RGBColor[
             0.7874836254673507, 0.8342273231203159, 0.9640003656809644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 345}], {
             RGBColor[
             0.9548621091534364, 0.9658568154299214, 0.9612908547425614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 389}], {
             RGBColor[
             0.9735085697880113, 0.9771086845972893, 0.7827755915182186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 432}], {
             RGBColor[
             0.9453556860585739, 0.8777698242200933, 0.6167145589641738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 456}], {
             RGBColor[
             0.8550357262418198, 0.8873103988573865, 0.9705207902776822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 472}], {
             RGBColor[
             0.9651900026394473, 0.9735593414814149, 0.9438084250167721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 287}], {
             RGBColor[
             0.979177544981161, 0.9816119349501055, 0.7950263827637578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 354}], {
             RGBColor[
             0.9749869268083695, 0.98054389096499, 0.9128058422878926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 396}], {
             RGBColor[
             0.877123864156835, 0.9043720844056828, 0.9629154616900798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 409}], {
             RGBColor[
             0.8420724873271932, 0.8769896824260361, 0.959421868021441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 430}], {
             RGBColor[
             0.9739161961459868, 0.9651036199088036, 0.669193154359009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 473}], {
             RGBColor[
             0.9789123600674489, 0.9810447312339827, 0.7661626414377758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 477}], {
             RGBColor[
             0.9362174216168238, 0.9512525983358882, 0.9686153036919412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 319}], {
             RGBColor[
             0.8255759893453714, 0.8645036687170513, 0.9830269342463303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 330}], {
             RGBColor[
             0.9319366107755831, 0.948449168615556, 0.9893551306459718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 357}], {
             RGBColor[
             0.9587401952385904, 0.9655623596986338, 0.7793975817249048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 358}], {
             RGBColor[
             0.9545590294612916, 0.9651144908034073, 0.9418164436166104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 367}], {
             RGBColor[
             0.9570354149045845, 0.966138539824412, 0.9007763281411523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 368}], {
             RGBColor[
             0.9566543687338182, 0.9659809674403601, 0.9070912493066308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 492}], {
             RGBColor[
             0.9381491607957406, 0.9530824782484724, 0.9788389039543948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 336}], {
             RGBColor[
             0.9928163092275415, 0.9906324891769174, 0.7203858056740162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 354}], {
             RGBColor[
             0.9903206681881728, 0.9896004774720892, 0.761745036208334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 388}], {
             RGBColor[
             0.6549769778662252, 0.7191554199411984, 0.792643141267459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 409}], {
             RGBColor[
             0.8574062287069965, 0.8860462689331353, 0.8083610619418824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 436}], {
             RGBColor[
             0.983919949590536, 0.9851488125428025, 0.786998728777303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 473}], {
             RGBColor[
             0.9942461014472521, 0.990101317741082, 0.6151018353582172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 313}], {
             RGBColor[
             0.7901963452312277, 0.8360266577000738, 0.9797230449541092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 321}], {
             RGBColor[
             0.8884263771870112, 0.9113601900994777, 0.878639839353978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 373}], {
             RGBColor[
             0.8671626917644991, 0.8350142082969614, 0.6287844134216334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 386}], {
             RGBColor[
             0.8743348522154528, 0.8610531986941532, 0.6470349388999957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 391}], {
             RGBColor[
             0.8720600795373435, 0.9004928284911167, 0.9662887931329689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 455}], {
             RGBColor[
             0.889147614599603, 0.9116584403045404, 0.8666870689247415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 498}], {
             RGBColor[
             0.8851556658015373, 0.8975543437678695, 0.6890717563427508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 300}], {
             RGBColor[
             0.807606653056254, 0.8459055941935485, 0.7294416337442451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 308}], {
             RGBColor[
             0.7902655607093327, 0.8318273142190102, 0.7280764794321811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 314}], {
             RGBColor[
             0.9911039103372787, 0.9812559646909729, 0.45374790932426745`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 466}], {
             RGBColor[
             0.9654183602836636, 0.9704002002844322, 0.7429261799354665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 470}], {
             RGBColor[
             0.9936186671138316, 0.9897875026263339, 0.6215490190492104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 493}], {
             RGBColor[
             0.9832121823471701, 0.9546353131144865, 0.4230900363104767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 297}], {
             RGBColor[
             0.8114330094968554, 0.8513529112870946, 0.8844828476035741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 484}], {
             RGBColor[
             0.8137028688750817, 0.8522915564727165, 0.8468654034985945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 349}], {
             RGBColor[
             0.9851367004398391, 0.9857691270621609, 0.7621560519331674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 353}], {
             RGBColor[
             0.9853311647229819, 0.9868700493857498, 0.8331133137733027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 394}], {
             RGBColor[
             0.9855225474883578, 0.9865944148838214, 0.8041531219924505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 467}], {
             RGBColor[
             0.9493494204176963, 0.961405727120349, 0.9588436051254907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 398}], {
             RGBColor[
             0.8858427841857379, 0.9115221871663166, 0.9789601109055344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 399}], {
             RGBColor[
             0.9090362829321663, 0.9255871599099285, 0.7468805160245777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 464}], {
             RGBColor[
             0.7580047136330852, 0.8109171270209654, 0.9765041832346042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 481}], {
             RGBColor[
             0.9064331871832263, 0.9262325541189141, 0.9151802275720883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 496}], {
             RGBColor[
             0.733068372294454, 0.7914212152313289, 0.9740293266722739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 343}], {
             RGBColor[
             0.9153885787818168, 0.9353700214323181, 0.9917917738928826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 403}], {
             RGBColor[
             0.8892417570600744, 0.9145212555279691, 0.9892978666955194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 440}], {
             RGBColor[
             0.723548588234118, 0.7831700109290696, 0.9738814143802803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 445}], {
             RGBColor[
             0.6151926890553261, 0.6919450936115433, 0.9662510816829675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 471}], {
             RGBColor[
             0.9447966290021659, 0.9559581759250708, 0.8813065074912123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 483}], {
             RGBColor[
             0.8898718703930992, 0.9150236907957524, 0.9893579674677322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 497}], {
             RGBColor[
             0.941929173511464, 0.9547724093894208, 0.9288276657090759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 296}], {
             RGBColor[
             0.947105043477146, 0.9581497852449572, 0.8967658114768575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 327}], {
             RGBColor[
             0.9468061375653062, 0.9580261799688798, 0.9017194559797452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 385}], {
             RGBColor[
             0.9012181040735523, 0.9240708695472369, 0.9904401813650763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 415}], {
             RGBColor[
             0.9482223211778502, 0.9586118082869255, 0.8782496285541849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 438}], {
             RGBColor[
             0.9224149504515009, 0.9408262973640836, 0.987387489197555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 439}], {
             RGBColor[
             0.818083215795376, 0.85848675912485, 0.9823235119310499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 321}], {
             RGBColor[
             0.9121507996904501, 0.9299914335181196, 0.880978582827933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 341}], {
             RGBColor[
             0.8447238005206649, 0.8790238453911827, 0.9850517042591417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 391}], {
             RGBColor[
             0.8957845020407824, 0.9191240719097586, 0.9686275366069237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 397}], {
             RGBColor[
             0.9130788626546238, 0.9293601246233694, 0.7918120846152508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 455}], {
             RGBColor[
             0.9128720371030419, 0.9302896837231824, 0.8690258123986964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 327}], {
             RGBColor[
             0.9904560358528673, 0.9903213398035393, 0.8078317151128492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 339}], {
             RGBColor[
             0.9924225398167498, 0.9911345397294513, 0.7752416552821961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 385}], {
             RGBColor[
             0.9448680023611136, 0.9563660293818963, 0.8965524404981802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 415}], {
             RGBColor[
             0.9918722194654115, 0.990906968121585, 0.7843618876872889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 438}], {
             RGBColor[
             0.9660648487390622, 0.973121457198743, 0.893499748330659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 325}], {
             RGBColor[
             0.8304228135380747, 0.86634312182549, 0.8862694413174064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 392}], {
             RGBColor[
             0.9282347120028638, 0.9431250681330556, 0.8959200852517253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 412}], {
             RGBColor[
             0.9581193798768741, 0.966954291098092, 0.8987705115519062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 413}], {
             RGBColor[
             0.8730511957320364, 0.8996447379831172, 0.8905182400696197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 474}], {
             RGBColor[
             0.9890643335542887, 0.9897458351379593, 0.830895823810395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 484}], {
             RGBColor[
             0.9929103129473389, 0.9913362464541475, 0.7671579921919383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 490}], {
             RGBColor[
             0.9921660724070709, 0.9910284838646373, 0.7794919839769563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 335}], {
             RGBColor[
             0.9627282111396689, 0.9717233414116937, 0.9479755958878424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 409}], {
             RGBColor[
             0.8424905002634137, 0.877301435789436, 0.9587142811556543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 468}], {
             RGBColor[
             0.8702610074633146, 0.8989959670776706, 0.9614821857831957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 312}], {
             RGBColor[
             0.9111084518312225, 0.9274730079525582, 0.7660110333319996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 328}], {
             RGBColor[
             0.9669141791588558, 0.9718550646798005, 0.7673149724314783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 399}], {
             RGBColor[
             0.9934601920322804, 0.9884203369700881, 0.5295604456092391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 407}], {
             RGBColor[
             0.9874827494648066, 0.9687403202554681, 0.46524281246711285`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 448}], {
             RGBColor[
             0.9923491499227706, 0.9896827337030076, 0.6731329670403504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 475}], {
             RGBColor[
             0.985310571767277, 0.9614130548301231, 0.4568043122935488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 478}], {
             RGBColor[
             0.9588164006202953, 0.8625895843600206, 0.4031077726673822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 482}], {
             RGBColor[
             0.946090916315907, 0.9553670755589436, 0.7693476920237636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 305}], {
             RGBColor[
             0.8070815214816172, 0.8445317794403349, 0.6935944882715317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 308}], {
             RGBColor[
             0.604725017406716, 0.689982037539177, 0.962025315032436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 432}], {
             RGBColor[
             0.7799381703448605, 0.7476028186134926, 0.6161046626277094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 456}], {
             RGBColor[
             0.6896182105281065, 0.7571433932507858, 0.9699108939412178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 493}], {
             RGBColor[
             0.7976716390445534, 0.8127900364346532, 0.6570388719107316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 316}], {
             RGBColor[
             0.8129011371723476, 0.8540060992943255, 0.9819217512865623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 336}], {
             RGBColor[
             0.9205407104929917, 0.9368977882498731, 0.8911785903911549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 388}], {
             RGBColor[
             0.5827013791316754, 0.6654207190141541, 0.9634359259845977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 436}], {
             RGBColor[
             0.9116443508559862, 0.9314141116157582, 0.9577915134944417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 346}], {
             RGBColor[
             0.9700485104034537, 0.9735093613229129, 0.7077938259520633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 370}], {
             RGBColor[
             0.9935486848366666, 0.9886096141306752, 0.539192341252393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 390}], {
             RGBColor[
             0.9805983788433967, 0.946123133855004, 0.3870184463157694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 422}], {
             RGBColor[
             0.9928385233520958, 0.9890388479353908, 0.6035090318912313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 443}], {
             RGBColor[
             0.9887162921497734, 0.9873341993967206, 0.6718250709060959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 451}], {
             RGBColor[
             0.8842477616037, 0.9057538181205402, 0.7100158466312281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 379}], {
             RGBColor[
             0.9444820708301891, 0.8932901412977218, 0.6307403155843356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 400}], {
             RGBColor[
             0.9345289788773073, 0.7781362487126523, 0.26617868348354246`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 307}], {
             RGBColor[
             0.961724763816152, 0.8743030742375247, 0.39463084248530533`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 311}], {
             RGBColor[
             0.9623477852343933, 0.8756356540540151, 0.4624428790183741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 337}], {
             RGBColor[
             0.9538056347818127, 0.8481646045880711, 0.3150056576771796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 423}], {
             RGBColor[
             0.9622994756670205, 0.8755323247742508, 0.45718468074191454`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 427}], {
             RGBColor[
             0.9578404547763205, 0.8742910173204523, 0.5748857474519957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 433}], {
             RGBColor[
             0.9608346019834091, 0.8755291741366569, 0.5252649796259528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 465}], {
             RGBColor[
             0.9532449790564421, 0.871108509049049, 0.5936268853135127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 469}], {
             RGBColor[
             0.9603852114394993, 0.87534333959794, 0.5327125439239861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 310}], {
             RGBColor[
             0.9928351119047685, 0.9868327423686234, 0.48283451696704327`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 406}], {
             RGBColor[
             0.891076712041722, 0.910460321890055, 0.701753806388671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 432}], {
             RGBColor[
             0.9649535820728403, 0.8880742805401122, 0.34630868155474104`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 460}], {
             RGBColor[
             0.9931705097596424, 0.9875501244662741, 0.5193405036344492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 493}], {
             RGBColor[
             0.9826870507725333, 0.9532614983612728, 0.3872428908377633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 331}], {
             RGBColor[
             0.9906093980927053, 0.9896264168763191, 0.750166636735663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 347}], {
             RGBColor[
             0.7870998841766514, 0.8323598920981006, 0.9144096435290847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 382}], {
             RGBColor[
             0.9686443852699869, 0.9756996986909454, 0.918439860583439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 431}], {
             RGBColor[
             0.9898556052915359, 0.9880141302947607, 0.6681209421982988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 486}], {
             RGBColor[
             0.9769083661606175, 0.981862962108151, 0.904451096527012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 337}], {
             RGBColor[
             0.9855149174836733, 0.9622259447093326, 0.44708948292447426`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 427}], {
             RGBColor[
             0.9895497374781811, 0.9883523574417137, 0.7069695726992904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 433}], {
             RGBColor[
             0.9925438846852697, 0.9895905142579182, 0.6573488048732474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 442}], {
             RGBColor[
             0.993307835509069, 0.9899064275562, 0.6446881626815372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 469}], {
             RGBColor[
             0.9920944941413599, 0.9894046797192013, 0.6647963691712808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 500}], {
             RGBColor[
             0.8795068872386254, 0.9025801917763806, 0.7519920791662025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 362}], {
             RGBColor[
             0.726606447748205, 0.785878146281112, 0.9738624474634523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 369}], {
             RGBColor[
             0.7217140506616592, 0.7819770816448816, 0.9733958062618432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 389}], {
             RGBColor[
             0.7907499617273765, 0.8328633990161503, 0.7808005408696903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 456}], {
             RGBColor[
             0.6722771181811853, 0.7430651132762476, 0.9685457396291538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 393}], {
             RGBColor[
             0.916539421507775, 0.934353745923403, 0.9188692028012537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 424}], {
             RGBColor[
             0.9190317523623596, 0.9331893568520842, 0.7180091812432576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 323}], {
             RGBColor[
             0.9937772219775354, 0.9890984319663441, 0.564067198668206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 406}], {
             RGBColor[
             0.8918148907368935, 0.912289822891724, 0.7607898161571509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 408}], {
             RGBColor[
             0.9588500841545007, 0.9654999735861949, 0.7672478836904288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 419}], {
             RGBColor[
             0.9931056255195336, 0.9876619550514962, 0.49096806882762745`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 366}], {
             RGBColor[
             0.8821427500185051, 0.9054852185627437, 0.8200047369151273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 405}], {
             RGBColor[
             0.9843307995421944, 0.9855728035332325, 0.7956327187518315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 423}], {
             RGBColor[
             0.9946317797871224, 0.9909262447120026, 0.6570805425222779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 429}], {
             RGBColor[
             0.9871924024949126, 0.967115477824831, 0.5189979113975995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 465}], {
             RGBColor[
             0.9855772831765441, 0.9865024289868009, 0.7935227470938762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 469}], {
             RGBColor[
             0.9927175155596013, 0.9907372595356918, 0.7326084057043495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 488}], {
             RGBColor[
             0.7171073433941901, 0.7730770417314772, 0.8057832372877045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 327}], {
             RGBColor[
             0.9093698718558547, 0.9281755178725253, 0.8981487515366289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 334}], {
             RGBColor[
             0.8635409694777181, 0.8940281451390926, 0.9868465026325505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 385}], {
             RGBColor[
             0.8637818383641008, 0.8942202074508824, 0.9868694769219599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 415}], {
             RGBColor[
             0.9107860554683987, 0.9287611461905709, 0.8746789241110685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 446}], {
             RGBColor[
             0.9092431603658779, 0.9281231194150832, 0.9002486888443673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 386}], {
             RGBColor[
             0.8799276594925038, 0.8654223422458951, 0.6475923776616166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 391}], {
             RGBColor[
             0.8776528868143945, 0.9048619720428586, 0.9668462318945898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 407}], {
             RGBColor[
             0.8885601807730645, 0.8945418635376121, 0.6811280927217387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 498}], {
             RGBColor[
             0.8907484730785882, 0.9019234873196114, 0.6896291951043716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 406}], {
             RGBColor[
             0.8895585575947669, 0.9053392304608598, 0.6958560630416617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 411}], {
             RGBColor[
             0.9587968893517761, 0.9603061038645726, 0.7025242678765167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 493}], {
             RGBColor[
             0.9811688963255782, 0.9481404069320776, 0.38134514749075393`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 349}], {
             RGBColor[
             0.9892760122627453, 0.9888128633787954, 0.7532077215350887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 353}], {
             RGBColor[
             0.9894704765458879, 0.9899137857023843, 0.824164983375224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 364}], {
             RGBColor[
             0.9828715162900519, 0.9681940318105323, 0.6445670111957464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 378}], {
             RGBColor[
             0.9852708344349197, 0.9881771257636196, 0.8937639214793606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 380}], {
             RGBColor[
             0.9482017942081569, 0.8382297555338822, 0.5776648771094071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 487}], {
             RGBColor[
             0.822386095952717, 0.8612022908632522, 0.9370481263240451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 372}], {
             RGBColor[
             0.8852390023619515, 0.9078739818726262, 0.8179062859380481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 418}], {
             RGBColor[
             0.7542192458251047, 0.8079210742079277, 0.976137183910416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 322}], {
             RGBColor[
             0.8357134282856157, 0.8717348068560232, 0.9442535668451069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 343}], {
             RGBColor[
             0.8125663133789276, 0.854421915645616, 0.9817086224947512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 374}], {
             RGBColor[
             0.843169126490018, 0.8752375821580981, 0.8320474436754717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 440}], {
             RGBColor[
             0.6207263228312287, 0.7022219051423675, 0.9637982629821489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 445}], {
             RGBColor[
             0.5123704236524368, 0.6109969878248412, 0.956167930284836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 471}], {
             RGBColor[
             0.8419743635992767, 0.8750100701383687, 0.8712233560930809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 335}], {
             RGBColor[
             0.8305026704556263, 0.8680055573500702, 0.9610175461657879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 421}], {
             RGBColor[
             0.785610487921548, 0.8328564316314452, 0.9791565629824042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 430}], {
             RGBColor[
             0.8421086683981647, 0.8616975892105798, 0.6815275177711679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 459}], {
             RGBColor[
             0.8369646031821157, 0.8443454493528961, 0.6615437957820226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 330}], {
             RGBColor[
             0.8338291389177515, 0.8709687018160612, 0.9797991177091386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 357}], {
             RGBColor[
             0.8606327233807588, 0.888081892899139, 0.7698415687880715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 368}], {
             RGBColor[
             0.8585468968759865, 0.8885005006408654, 0.8975352363697975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 492}], {
             RGBColor[
             0.840041688937909, 0.8756020114489776, 0.9692828910175615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 329}], {
             RGBColor[
             0.9634968667271823, 0.9707458605768035, 0.877732684274819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 424}], {
             RGBColor[
             0.9632524897026293, 0.9684497724672767, 0.7222269946470907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 341}], {
             RGBColor[
             0.9248222172500605, 0.9400952779236863, 0.8821871939466766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 373}], {
             RGBColor[
             0.9709855309973336, 0.914716884248107, 0.5282586465831232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 391}], {
             RGBColor[
             0.9758829187701781, 0.9801955044422623, 0.8657630262944587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 397}], {
             RGBColor[
             0.9931772793840195, 0.9904315571558729, 0.6889475743027857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 455}], {
             RGBColor[
             0.9929704538324375, 0.9913611162556861, 0.7661613020862312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 498}], {
             RGBColor[
             0.9889785050343718, 0.9772570197190151, 0.5885459895042404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 343}], {
             RGBColor[
             0.9569145084107754, 0.9673376806226281, 0.95608970599841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 374}], {
             RGBColor[
             0.9875173215218658, 0.9881533471351103, 0.8064285271791305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 440}], {
             RGBColor[
             0.7650745178630767, 0.8151376701193795, 0.9381793464858077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 445}], {
             RGBColor[
             0.6567186186842846, 0.7239127528018534, 0.9305490137884949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 471}], {
             RGBColor[
             0.9863225586311245, 0.9879258351153809, 0.8456044395967397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 419}], {
             RGBColor[
             0.9933095568971291, 0.9880981436475478, 0.5131647407603104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 449}], {
             RGBColor[
             0.8991678215461751, 0.918310864178217, 0.7836990335419862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 499}], {
             RGBColor[
             0.9210076989086855, 0.9355990620464917, 0.7858156639792231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 342}], {
             RGBColor[
             0.821169889960008, 0.8608882597856434, 0.9688719836680675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 360}], {
             RGBColor[
             0.9485656155851243, 0.9611609008362364, 0.97194917596518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 457}], {
             RGBColor[
             0.9593843916998577, 0.9329910086503758, 0.6486293022813119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 392}], {
             RGBColor[
             0.768017071971826, 0.8190705886900199, 0.9774140902722137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 413}], {
             RGBColor[
             0.7128335557009986, 0.7755902585400815, 0.9720122450901083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 474}], {
             RGBColor[
             0.8288466935232509, 0.8656913556949236, 0.9123898288308836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 490}], {
             RGBColor[
             0.8319484323760331, 0.8669740044216017, 0.8609859889974447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 338}], {
             RGBColor[
             0.9513697757826816, 0.9599697643521359, 0.8017471109348311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 346}], {
             RGBColor[
             0.9279811723920615, 0.9451081507229167, 0.9824924150840609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 355}], {
             RGBColor[
             0.7999419474927764, 0.844355588967282, 0.9805044992066256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 395}], {
             RGBColor[
             0.7046799445804026, 0.767768316489715, 0.9724918588091669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 443}], {
             RGBColor[
             0.9466489541383811, 0.9589329887967245, 0.9465236600380935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 334}], {
             RGBColor[
             0.944328227562891, 0.9560503617940292, 0.9014831107116585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 385}], {
             RGBColor[
             0.9445690964492738, 0.956242424105819, 0.9015060850010679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 415}], {
             RGBColor[
             0.9915733135535717, 0.9907833628455076, 0.7893155321901766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 446}], {
             RGBColor[
             0.9900304184510509, 0.9901453360700199, 0.8148852969234752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 398}], {
             RGBColor[
             0.9435465825529447, 0.9574177142187491, 0.9804450897151955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 399}], {
             RGBColor[
             0.9667400812993732, 0.971482686962361, 0.7483654948342389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 407}], {
             RGBColor[
             0.9607626387318994, 0.9518026702477409, 0.6840478616921125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 464}], {
             RGBColor[
             0.815708512000292, 0.8568126540733979, 0.9779891620442653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 475}], {
             RGBColor[
             0.9585904610343697, 0.9444754048223959, 0.6756093615185486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 478}], {
             RGBColor[
             0.932096289887388, 0.8456519343522935, 0.621912821892382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 481}], {
             RGBColor[
             0.9641369855504331, 0.9721280811713466, 0.9166652063817494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 333}], {
             RGBColor[
             0.8822603595291689, 0.9088386742975838, 0.9846169654555759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 352}], {
             RGBColor[
             0.9663726402384485, 0.9706997684798777, 0.7086099030132706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 357}], {
             RGBColor[
             0.9669933448109705, 0.9720273927976435, 0.7761697651877132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 358}], {
             RGBColor[
             0.9628121790336717, 0.9715795239024171, 0.9385886270794188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 367}], {
             RGBColor[
             0.9652885644769647, 0.9726035729234218, 0.8975485116039608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 368}], {
             RGBColor[
             0.9649075183061983, 0.97244600053937, 0.9038634327694393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 441}], {
             RGBColor[
             0.9674116459636175, 0.9729220966664214, 0.8216992641978591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 492}], {
             RGBColor[
             0.9464023103681207, 0.9595475113474823, 0.9756110874172033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 348}], {
             RGBColor[
             0.9897495994800546, 0.9759125434603051, 0.5143881533783128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 372}], {
             RGBColor[
             0.9945193860814876, 0.9906858459403968, 0.6448471812774883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 382}], {
             RGBColor[
             0.9724379400691843, 0.9765100889357022, 0.8004473709813048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 404}], {
             RGBColor[
             0.908117352361429, 0.5796253975971287, 0.40035678169163774`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 418}], {
             RGBColor[
             0.8634996295446408, 0.8907329382756981, 0.8030780792498563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 431}], {
             RGBColor[
             0.9936491600907333, 0.9888245205395174, 0.5501284525961646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 444}], {
             RGBColor[
             0.9774204255572856, 0.980226018454657, 0.7920133226902877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 486}], {
             RGBColor[
             0.980701920959815, 0.9826733523529079, 0.7864586069248778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 420}], {
             RGBColor[
             0.8944538254154766, 0.918130184981717, 0.9708290425841988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 454}], {
             RGBColor[
             0.899881525581868, 0.9221781548787682, 0.961641361973422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 489}], {
             RGBColor[
             0.891783607462381, 0.9161387408043788, 0.97534902507441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 358}], {
             RGBColor[
             0.9048827782148774, 0.9255039964854351, 0.9370782784262144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 361}], {
             RGBColor[
             0.8225988539574618, 0.8613820135673601, 0.9829414071047704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 367}], {
             RGBColor[
             0.9073591636581704, 0.9265280455064399, 0.8960381629507563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 386}], {
             RGBColor[
             0.8941985625935518, 0.8766060150602881, 0.6490054442049373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 441}], {
             RGBColor[
             0.9094822451448232, 0.9268465692494394, 0.8201889155446547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 450}], {
             RGBColor[
             0.7072614663201803, 0.7704733025096107, 0.9719939187080134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 461}], {
             RGBColor[
             0.878056827491517, 0.9056026962968267, 0.9882310381283661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 385}], {
             RGBColor[
             0.8987401940711371, 0.9220950513723863, 0.9902038360969896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 415}], {
             RGBColor[
             0.9457444111754351, 0.9566359901120749, 0.8780132832860982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 446}], {
             RGBColor[
             0.9442015160729142, 0.9559979633365872, 0.9035830480193969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 409}], {
             RGBColor[
             0.8405388819292838, 0.8758459220313237, 0.9620178619317536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 421}], {
             RGBColor[
             0.9158844102714606, 0.9351187019349565, 0.9694181934805579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 430}], {
             RGBColor[
             0.9723825907480774, 0.9639598595140911, 0.6717891482693216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 459}], {
             RGBColor[
             0.9672385255320284, 0.9466077196564073, 0.6518054262801762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 354}], {
             RGBColor[
             0.98862569105475, 0.989564445191802, 0.8381652651981512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 388}], {
             RGBColor[
             0.6532820007328025, 0.7191193876609112, 0.8690633702572761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 436}], {
             RGBColor[
             0.9822249724571132, 0.9851127802625153, 0.8634189577671202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 420}], {
             RGBColor[
             0.9672540399216165, 0.9517366565239361, 0.6626423645494863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 427}], {
             RGBColor[
             0.9816306084438418, 0.9622138877922601, 0.6273443878911646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 433}], {
             RGBColor[
             0.9846247556509303, 0.9634520446084647, 0.5777236200651217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 500}], {
             RGBColor[
             0.871587758204286, 0.876441722126927, 0.6723668943580767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 383}], {
             RGBColor[
             0.9064998746664652, 0.9242014638651028, 0.7974647948277163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 395}], {
             RGBColor[
             0.7475310586312993, 0.7978459447862978, 0.7831024546721947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 443}], {
             RGBColor[
             0.9895000681892778, 0.9890106170933073, 0.7571342559011214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 480}], {
             RGBColor[
             0.9621181854739349, 0.875144563382491, 0.4374523620179348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 344}], {
             RGBColor[
             0.9666050434408258, 0.9729702362758933, 0.8677717328010295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 387}], {
             RGBColor[
             0.8571956544609105, 0.8866240753941761, 0.8601808935769981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 439}], {
             RGBColor[
             0.8634007121349798, 0.8914715136093441, 0.8607993557363884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 384}], {
             RGBColor[
             0.9818499585878749, 0.9856623288289621, 0.9011885196505536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 414}], {
             RGBColor[
             0.9863873237115944, 0.9874720294806179, 0.8211503258607984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 461}], {
             RGBColor[
             0.954676281716514, 0.9656172349420009, 0.9581040015114994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 499}], {
             RGBColor[
             0.9128020558113044, 0.9322278638507691, 0.9541100004630978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 374}], {
             RGBColor[
             0.9261841189032717, 0.9403919061169672, 0.8402413596936903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 391}], {
             RGBColor[
             0.9084559196003928, 0.9292279163153253, 0.9698361477256674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 397}], {
             RGBColor[
             0.9257502802142342, 0.9394639690289359, 0.7930206957339945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 455}], {
             RGBColor[
             0.9255434546626523, 0.940393528128749, 0.87023442351744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 485}], {
             RGBColor[
             0.6417431808317047, 0.719284337265817, 0.9654527870312338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 374}], {
             RGBColor[
             0.9643702066151777, 0.970840455924703, 0.8438835828287748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 403}], {
             RGBColor[
             0.9076205717823449, 0.9291760235078719, 0.9910508544506913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 440}], {
             RGBColor[
             0.7419274029563885, 0.7978247789089723, 0.9756344021354519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 445}], {
             RGBColor[
             0.6335715037775965, 0.7065998615914462, 0.9680040694381391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 471}], {
             RGBColor[
             0.9631754437244364, 0.9706129439049737, 0.8830594952463839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 387}], {
             RGBColor[
             0.8297105600329439, 0.8677701772907833, 0.980347386423597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 438}], {
             RGBColor[
             0.9402473523631382, 0.9549571537451851, 0.9860298258494924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 439}], {
             RGBColor[
             0.8359156177070133, 0.8726176155059513, 0.9809658485829873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 389}], {
             RGBColor[
             0.9754695377603835, 0.9785711713002941, 0.7794561842433512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 456}], {
             RGBColor[
             0.8569966942141921, 0.8887728855603914, 0.9672013830028147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 472}], {
             RGBColor[
             0.9671509706118195, 0.9750218281844197, 0.9404890177419045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 355}], {
             RGBColor[
             0.8194044581530529, 0.8595716036346457, 0.9718603992188833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 390}], {
             RGBColor[
             0.957993551492281, 0.9329379379223715, 0.6530729354600248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 395}], {
             RGBColor[
             0.7241424552406792, 0.7829843311570786, 0.9638477588214246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 431}], {
             RGBColor[
             0.9701695251709509, 0.9737681996741195, 0.7209655365775596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 443}], {
             RGBColor[
             0.9661114647986576, 0.9741490034640881, 0.9378795600503512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 486}], {
             RGBColor[
             0.9572222860400326, 0.9676170314875099, 0.9572956909062726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 382}], {
             RGBColor[
             0.7689284261531303, 0.8192435641574836, 0.9646903777747264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 462}], {
             RGBColor[
             0.7777573176964313, 0.8258281370144944, 0.9497453673356238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 355}], {
             RGBColor[
             0.8382307396609872, 0.8601036608392726, 0.6832373214822725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 372}], {
             RGBColor[
             0.9898660326696394, 0.9761615822796259, 0.5270611875222724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 400}], {
             RGBColor[
             0.9531479047353828, 0.843338918959603, 0.3260278412670314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 404}], {
             RGBColor[
             0.9034639989495807, 0.5651011339363579, 0.2825707879364217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 418}], {
             RGBColor[
             0.8588462761327925, 0.8762086746149272, 0.6852920854946403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 431}], {
             RGBColor[
             0.9889958066788851, 0.9743002568787464, 0.4323424588409486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 444}], {
             RGBColor[
             0.9727670721454373, 0.9657017547938861, 0.6742273289350718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 486}], {
             RGBColor[
             0.9760485675479668, 0.9681490886921369, 0.6686726131696618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 353}], {
             RGBColor[
             0.9942935244374498, 0.9908877336072169, 0.6700545598949676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 378}], {
             RGBColor[
             0.9900938823264815, 0.9891510736684522, 0.7396534979991043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 380}], {
             RGBColor[
             0.9530248420997187, 0.8392037034387148, 0.4235544536291508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 487}], {
             RGBColor[
             0.8272091438442788, 0.8621762387680847, 0.7829377028437887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 377}], {
             RGBColor[
             0.9839340479424847, 0.9557986551143617, 0.5340288490233724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 412}], {
             RGBColor[
             0.9491293483454395, 0.9314750999194739, 0.6705283979430166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 426}], {
             RGBColor[
             0.8355091693369201, 0.8418605114137928, 0.6594303304462803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 476}], {
             RGBColor[
             0.9695717721476063, 0.9469814952013386, 0.6449553332538029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 371}], {
             RGBColor[
             0.6395719327006197, 0.7130802708658188, 0.9677957119478091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 442}], {
             RGBColor[
             0.9448179593149171, 0.955860388780903, 0.8763237312752017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 460}], {
             RGBColor[
             0.9453491902196982, 0.955184672186893, 0.802434152495132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 357}], {
             RGBColor[
             0.9931762247014557, 0.9878129595629555, 0.49865235409220354`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 367}], {
             RGBColor[
             0.9914714443674499, 0.9883891396887337, 0.620031100508451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 368}], {
             RGBColor[
             0.9910903981966834, 0.9882315673046819, 0.6263460216739295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 375}], {
             RGBColor[
             0.9928729733572906, 0.9871643356012003, 0.46564531673018683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 380}], {
             RGBColor[
             0.9532193063828613, 0.8403046257623037, 0.4945117154692861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 487}], {
             RGBColor[
             0.8274036081274215, 0.8632771610916736, 0.853894964683924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 388}], {
             RGBColor[
             0.6507863596934337, 0.7180873759560829, 0.9104226007915939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 409}], {
             RGBColor[
             0.8532156105342049, 0.8849782249480198, 0.9261405214660172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 436}], {
             RGBColor[
             0.9797293314177444, 0.984080768557687, 0.904778188301438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 473}], {
             RGBColor[
             0.9900554832744606, 0.9890332737559665, 0.732881294882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 395}], {
             RGBColor[
             0.5961032303413941, 0.6822317694014439, 0.9618598429439893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 404}], {
             RGBColor[
             0.7565984925423614, 0.46381651497609633`, 0.5692059497955974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 431}], {
             RGBColor[
             0.8421303002716658, 0.873015637918485, 0.7189776207001242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 443}], {
             RGBColor[
             0.8380722398993725, 0.8733964417084534, 0.9358916441729159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 444}], {
             RGBColor[
             0.8259015657382182, 0.8644171358336246, 0.9608624907942473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 486}], {
             RGBColor[
             0.8291830611407476, 0.8668644697318754, 0.9553077750288375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 365}], {
             RGBColor[
             0.9554020703867948, 0.9642714551796725, 0.876099311917978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 457}], {
             RGBColor[
             0.9426343458081907, 0.9200288910121053, 0.6606889235927127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 494}], {
             RGBColor[
             0.9373415653339168, 0.9523200616986329, 0.9746547280677726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 367}], {
             RGBColor[
             0.9920921489399721, 0.9897167640064997, 0.6875909626828935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 368}], {
             RGBColor[
             0.9917111027692056, 0.9895591916224478, 0.693905883848372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 441}], {
             RGBColor[
             0.9942152304266249, 0.9900352877494991, 0.6117417152767921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 492}], {
             RGBColor[
             0.9732058948311281, 0.97666070243056, 0.765653538496136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 361}], {
             RGBColor[
             0.9031506734619644, 0.9241228631721934, 0.9369130687286134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 386}], {
             RGBColor[
             0.9747503820980545, 0.9393468646651215, 0.6029771058287803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 398}], {
             RGBColor[
             0.9661668471996605, 0.9740814299278466, 0.9329100489119853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 441}], {
             RGBColor[
             0.990034064649326, 0.9895874188542727, 0.7741605771684977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 408}], {
             RGBColor[
             0.849984531580946, 0.8835753913938161, 0.9854587985499915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 440}], {
             RGBColor[
             0.6629647989307601, 0.7352189236956295, 0.968008199538749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 463}], {
             RGBColor[
             0.8849019171202135, 0.9082920399138639, 0.8640134965017905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 483}], {
             RGBColor[
             0.8292880810897414, 0.8670726035623123, 0.9834847526262009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 457}], {
             RGBColor[
             0.956975460618734, 0.9311944317943364, 0.6527069942518049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 494}], {
             RGBColor[
             0.95168268014446, 0.9634856024808641, 0.9666727987268646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 386}], {
             RGBColor[
             0.8924664578406389, 0.8752248817470465, 0.6488402345073363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 398}], {
             RGBColor[
             0.8838829229422449, 0.9099594470097716, 0.9787731775905413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 441}], {
             RGBColor[
             0.9077501403919104, 0.9254654359361977, 0.8200237058470536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 481}], {
             RGBColor[
             0.9044733259397333, 0.924669813962369, 0.9149932942570951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 369}], {
             RGBColor[
             0.8609365733500693, 0.8919514703613549, 0.9865980930049234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 470}], {
             RGBColor[
             0.9299595541527037, 0.9438383346884358, 0.8673349870804816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 381}], {
             RGBColor[
             0.995176491779151, 0.9920913285841216, 0.7163690812818575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 378}], {
             RGBColor[
             0.9836893863537881, 0.9685322421001892, 0.631012787659762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 380}], {
             RGBColor[
             0.9466203461270253, 0.8185848718704517, 0.3149137432898085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 381}], {
             RGBColor[
             0.9882724700915883, 0.9704040620215499, 0.5533580795943545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 416}], {
             RGBColor[
             0.9759248175155036, 0.9630565509020375, 0.6582675154191708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 452}], {
             RGBColor[
             0.9307077281075424, 0.9279006292243646, 0.6851221083265133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 468}], {
             RGBColor[
             0.8785661268308754, 0.8866811135663184, 0.6800541169153981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 487}], {
             RGBColor[
             0.8208046478715854, 0.8415574071998216, 0.6742969925044465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 405}], {
             RGBColor[
             0.8717934602062041, 0.9000284481042091, 0.9532987148682215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 423}], {
             RGBColor[
             0.882094440451132, 0.9053818892829794, 0.8147465386386677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 429}], {
             RGBColor[
             0.8746550631589223, 0.8815711223958077, 0.6766639075139893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 465}], {
             RGBColor[
             0.8730399438405538, 0.9009580735577776, 0.951188743210266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 469}], {
             RGBColor[
             0.8801801762236109, 0.9051929041066684, 0.8902744018207394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 488}], {
             RGBColor[
             0.6045700040581997, 0.6875326863024538, 0.9634492334040943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 368}], {
             RGBColor[
             0.9900063224351998, 0.990135371748226, 0.8152846302646196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 375}], {
             RGBColor[
             0.9917888975958069, 0.9890681400447444, 0.654583925320877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 441}], {
             RGBColor[
             0.992510450092619, 0.9906114678752774, 0.7331204616930396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 450}], {
             RGBColor[
             0.7902896712679761, 0.8342382011354488, 0.8849254648563982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 492}], {
             RGBColor[
             0.9711200683263558, 0.9770793101722864, 0.8933472060778621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 456}], {
             RGBColor[
             0.8066072437830496, 0.8491384373564905, 0.9812813851706249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 390}], {
             RGBColor[
             0.9814937259254939, 0.9480381907301337, 0.48447145076035447`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 422}], {
             RGBColor[
             0.9937338704341929, 0.9909539048105205, 0.7009620363358164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 443}], {
             RGBColor[
             0.9896116392318706, 0.9892492562718505, 0.7692780753506809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 451}], {
             RGBColor[
             0.8851431086857972, 0.90766887499567, 0.8074688510758132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 442}], {
             RGBColor[
             0.6879355978858281, 0.7486683228385296, 0.8541336383030818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 460}], {
             RGBColor[
             0.6884668287906093, 0.7479926062445196, 0.780244059523012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 400}], {
             RGBColor[
             0.9579176913368159, 0.8581122214396948, 0.45648686916620695`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 404}], {
             RGBColor[
             0.9082337855510138, 0.5798744364164495, 0.4130298158355973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 418}], {
             RGBColor[
             0.8636160627342255, 0.8909819770950189, 0.8157511133938158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 431}], {
             RGBColor[
             0.9937655932803182, 0.9890735593588382, 0.5628014867401241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 444}], {
             RGBColor[
             0.9775368587468705, 0.9804750572739778, 0.8046863568342473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 486}], {
             RGBColor[
             0.9808183541493998, 0.9829223911722287, 0.7991316410688374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 449}], {
             RGBColor[
             0.8770381676560206, 0.8427290051198146, 0.629768708566931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 498}], {
             RGBColor[
             0.9677148196118597, 0.900911037916499, 0.33869056357189575`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 397}], {
             RGBColor[
             0.9945391810372306, 0.9907281853491539, 0.6470017400497994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 445}], {
             RGBColor[
             0.6641743168886869, 0.7274155281039283, 0.8183428906188597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 402}], {
             RGBColor[
             0.9694642570637053, 0.9734477355041804, 0.7384667924738905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 417}], {
             RGBColor[
             0.9806617150010628, 0.981798781299707, 0.719512416950703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 441}], {
             RGBColor[
             0.9939119790824598, 0.989386663787744, 0.5787346779147753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 450}], {
             RGBColor[
             0.7916912002578167, 0.8330133970479152, 0.730539681078134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 461}], {
             RGBColor[
             0.9624865614291536, 0.9681427908351312, 0.7467768004984867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 391}], {
             RGBColor[
             0.9513444527896127, 0.9632333530734154, 0.9672453294147991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 448}], {
             RGBColor[
             0.9671181472062464, 0.9738556580157085, 0.8894173448151856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 455}], {
             RGBColor[
             0.9684319878518721, 0.9743989648868391, 0.8676436052065718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 475}], {
             RGBColor[
             0.9600795690507529, 0.9455859791428238, 0.673088690068384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 482}], {
             RGBColor[
             0.9208599135993829, 0.9395399998716444, 0.9856320697985987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 412}], {
             RGBColor[
             0.960403005781681, 0.9678345361225461, 0.8562660378872506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 426}], {
             RGBColor[
             0.8467828267731616, 0.8782199476168651, 0.8451679703905144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 476}], {
             RGBColor[
             0.9808454295838478, 0.9833409314044108, 0.830692973198037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 380}], {
             RGBColor[
             0.949019664271893, 0.838567965823539, 0.5641106535734226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 416}], {
             RGBColor[
             0.9783241356603714, 0.9830396448551249, 0.907464425702785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 452}], {
             RGBColor[
             0.9331070462524103, 0.9478837231774518, 0.9343190186101276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 487}], {
             RGBColor[
             0.8232039660164532, 0.8615405011529089, 0.9234939027880606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 400}], {
             RGBColor[
             0.931152655355441, 0.8404434507047415, 0.6200151550117593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 404}], {
             RGBColor[
             0.8814687495696389, 0.5622056656814962, 0.5765581016811496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 440}], {
             RGBColor[
             0.7455965798585062, 0.8006110558477674, 0.971150414867701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 487}], {
             RGBColor[
             0.7861349257896904, 0.7115931309231716, 0.6073948584181073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 416}], {
             RGBColor[
             0.9829072193981716, 0.9849114647764857, 0.8298097176373773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 468}], {
             RGBColor[
             0.8855485287135434, 0.9085360274407666, 0.8515963191336047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 425}], {
             RGBColor[
             0.862614231612848, 0.8932737754541227, 0.9734523221097586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 462}], {
             RGBColor[
             0.9593018187897667, 0.9691679436073393, 0.953775584389978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 393}], {
             RGBColor[
             0.9032658918456773, 0.9237795343732287, 0.9176005768098465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 395}], {
             RGBColor[
             0.6598100434641863, 0.7320000160026818, 0.9682095427020521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 443}], {
             RGBColor[
             0.9017790530221648, 0.9231646883096913, 0.9422413439309787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 480}], {
             RGBColor[
             0.8743971703068218, 0.8092986345988751, 0.6225594500477922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 402}], {
             RGBColor[
             0.9659340687785722, 0.9737922842690618, 0.9281299695688185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 411}], {
             RGBColor[
             0.9573316022016233, 0.9671917913537775, 0.9362850054904788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 458}], {
             RGBColor[
             0.9900805849396539, 0.9890869636796472, 0.7356134562291157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 461}], {
             RGBColor[
             0.9589563731440203, 0.9684873396000127, 0.9364399775934148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 499}], {
             RGBColor[
             0.9170821472388107, 0.9350979685087808, 0.932445976545013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 415}], {
             RGBColor[
             0.9459852800618178, 0.9568280524238648, 0.8780362575755076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 446}], {
             RGBColor[
             0.9444423849592971, 0.9561900256483769, 0.9036060223088063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 441}], {
             RGBColor[
             0.9793498490280004, 0.9406894374291257, 0.48608774294722057`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 498}], {
             RGBColor[
             0.9748869800628135, 0.9269500283136908, 0.3569410890502581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 439}], {
             RGBColor[
             0.726506228727098, 0.786271454624234, 0.9733750093589559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 436}], {
             RGBColor[
             0.6443856410957969, 0.7136357110267961, 0.9356762933605629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 473}], {
             RGBColor[
             0.654711792952513, 0.7185882162250756, 0.763779399941477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 456}], {
             RGBColor[
             0.875643154848767, 0.9000247547277592, 0.788686119778472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 472}], {
             RGBColor[
             0.9857974312463944, 0.9862736973517876, 0.761973754517562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 422}], {
             RGBColor[
             0.9807835644409231, 0.9484674245348493, 0.5487881413991929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 443}], {
             RGBColor[
             0.9766613332386007, 0.9467627759961792, 0.6171041804140573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 451}], {
             RGBColor[
             0.8721928026925273, 0.8651823947199988, 0.6552949561391896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 407}], {
             RGBColor[
             0.9704239150791804, 0.9590080343286549, 0.6676938409005982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 448}], {
             RGBColor[
             0.9752903155371442, 0.9799504477761944, 0.8755839954738358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 455}], {
             RGBColor[
             0.9766041561827699, 0.9804937546473251, 0.8538102558652221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 475}], {
             RGBColor[
             0.9682517373816507, 0.9516807689033099, 0.6592553407270343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 478}], {
             RGBColor[
             0.941757566234669, 0.8528572984332075, 0.6055588011008677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 482}], {
             RGBColor[
             0.9290320819302808, 0.9456347896321304, 0.971798720457249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 413}], {
             RGBColor[
             0.8106454541657877, 0.852372204847647, 0.9816628890244271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 473}], {
             RGBColor[
             0.9299049434850776, 0.9426933245112723, 0.7866514141193839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 474}], {
             RGBColor[
             0.92665859198804, 0.9424733020024891, 0.9220404727652024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 490}], {
             RGBColor[
             0.9297603308408222, 0.9437559507291671, 0.8706366329317636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 424}], {
             RGBColor[
             0.9902452550465868, 0.9880391445936516, 0.6517692492041233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 480}], {
             RGBColor[
             0.9588842026531468, 0.8747226338906169, 0.5575881440000651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 467}], {
             RGBColor[
             0.9586976271806829, 0.9662486991634764, 0.8377819213064388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 443}], {
             RGBColor[
             0.7428102369869989, 0.7968091692308864, 0.9278790037754572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 430}], {
             RGBColor[
             0.887196256701464, 0.8969203558714802, 0.6860214272057723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 477}], {
             RGBColor[
             0.849497482172301, 0.8830693342985647, 0.9854435765387045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 495}], {
             RGBColor[
             0.9680806204163097, 0.9730531063711708, 0.7913747525503143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 399}], {
             RGBColor[
             0.9700925954263693, 0.9739829865090366, 0.7426905628929563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 464}], {
             RGBColor[
             0.8190610261272881, 0.8593129536200736, 0.9723142301029828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 481}], {
             RGBColor[
             0.9674894996774293, 0.9746283807180223, 0.910990274440467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 496}], {
             RGBColor[
             0.7941246847886569, 0.8398170418304371, 0.9698393735406525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 407}], {
             RGBColor[
             0.987308651605324, 0.9683679425380285, 0.44629333486987344`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 464}], {
             RGBColor[
             0.8422545248737167, 0.8733779263636854, 0.7402346352220261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 478}], {
             RGBColor[
             0.9586423027608126, 0.8622172066425811, 0.38415829507014276`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 481}], {
             RGBColor[
             0.9906829984238578, 0.9886933534616341, 0.6789106795595103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 496}], {
             RGBColor[
             0.8173181835350855, 0.8538820145740489, 0.7377597786596959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 404}], {
             RGBColor[
             0.8715156576167571, 0.44705177309642674`, 0.21199646958035634`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 418}], {
             RGBColor[
             0.826897934799969, 0.7581593137749962, 0.6147177671385748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 431}], {
             RGBColor[
             0.9570474653460616, 0.8562508960388154, 0.3617681404848832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 444}], {
             RGBColor[
             0.9408187308126139, 0.8476523939539551, 0.6036530105790063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 428}], {
             RGBColor[
             0.9800967973580049, 0.9434325133872483, 0.4699894440803722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 437}], {
             RGBColor[
             0.7517641100593291, 0.7661006509925898, 0.6394278656402583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 451}], {
             RGBColor[
             0.8708821478268557, 0.8607612481016915, 0.6502033094824586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 417}], {
             RGBColor[
             0.9569355454791206, 0.9674031808466764, 0.9577810678819809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 458}], {
             RGBColor[
             0.9698846037028448, 0.9743468144617353, 0.7842189300654654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 461}], {
             RGBColor[
             0.9387603919072113, 0.9537471903821007, 0.9850454514297644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 440}], {
             RGBColor[
             0.715780581234646, 0.7769760130046234, 0.9731404949380889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 445}], {
             RGBColor[
             0.6074246820558541, 0.6857510956870972, 0.965510162240776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 471}], {
             RGBColor[
             0.937028622002694, 0.9497641780006247, 0.8805655880490209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 483}], {
             RGBColor[
             0.8821038633936273, 0.9088296928713062, 0.9886170480255408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 497}], {
             RGBColor[
             0.934161166511992, 0.9485784114649747, 0.9280867462668846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 418}], {
             RGBColor[
             0.7772140290141669, 0.4799215287517509, 0.5712607138079653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 431}], {
             RGBColor[
             0.9073635595602594, 0.5780131110155702, 0.3183110871542736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 444}], {
             RGBColor[
             0.8911348250268117, 0.5694146089307097, 0.5601959572483967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 486}], {
             RGBColor[
             0.8944163204293412, 0.5718619428289606, 0.5546412414829868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 423}], {
             RGBColor[
             0.9842824899748214, 0.9854694742534682, 0.790374520475372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 429}], {
             RGBColor[
             0.9768431126826116, 0.9616587073662966, 0.6522918893506936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 472}], {
             RGBColor[
             0.9757301869138619, 0.9814201936553055, 0.9259666423605205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 488}], {
             RGBColor[
             0.7067580535818891, 0.7676202712729426, 0.9390772152407986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 419}], {
             RGBColor[
             0.8913472256564872, 0.9112895345729278, 0.7098873582492553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 493}], {
             RGBColor[
             0.8816668296046583, 0.8787185788843734, 0.665198190027871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 448}], {
             RGBColor[
             0.9861976094958143, 0.969630339270948, 0.5898658563009848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 455}], {
             RGBColor[
             0.9875114501414398, 0.9701736461420787, 0.5680921166923709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 475}], {
             RGBColor[
             0.9791590313403207, 0.9413606603980635, 0.37353720155418313`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 478}], {
             RGBColor[
             0.952664860193339, 0.842537189927961, 0.3198406619280165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 482}], {
             RGBColor[
             0.9399393758889507, 0.935314681126884, 0.686080581284398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{408, 463}], {
             RGBColor[
             0.9590442632483289, 0.967054352322145, 0.8711799385971337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 430}], {
             RGBColor[
             0.8521448798718222, 0.8695379538918334, 0.6825278335371334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 422}], {
             RGBColor[
             0.914980250894051, 0.9320989177266685, 0.8747938497447629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 428}], {
             RGBColor[
             0.9156041386768043, 0.9314851531973749, 0.8010867990826731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 437}], {
             RGBColor[
             0.6872714513781286, 0.7541532908027162, 0.9705252206425592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{412, 426}], {
             RGBColor[
             0.8119781271761164, 0.8538963924219772, 0.9816675193101585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{412, 476}], {
             RGBColor[
             0.9460407299868026, 0.959017376209523, 0.9671925221176811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 474}], {
             RGBColor[
             0.8714750757172126, 0.8989929718525507, 0.9166386275830969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 490}], {
             RGBColor[
             0.8745768145699948, 0.9002756205792286, 0.8652347877496581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 461}], {
             RGBColor[
             0.9634937382677398, 0.9702970402516684, 0.8564017838036597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 498}], {
             RGBColor[
             0.9904562869558591, 0.9778015040888463, 0.5592130073229858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 499}], {
             RGBColor[
             0.9216195123625301, 0.9369076691604367, 0.852407782755258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 452}], {
             RGBColor[
             0.9253424774141258, 0.9424080319793002, 0.9615737463695364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 468}], {
             RGBColor[
             0.8732008761374588, 0.9011885163212541, 0.956505754958421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{417, 458}], {
             RGBColor[
             0.9810820616402023, 0.9826978602572618, 0.765264554542278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 431}], {
             RGBColor[
             0.8627458367434713, 0.8891206516941397, 0.7210323847124921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 444}], {
             RGBColor[
             0.8465171022100235, 0.8805221496092792, 0.9629172548066152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 486}], {
             RGBColor[
             0.8497985976125529, 0.88296948350753, 0.9573625390412053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 427}], {
             RGBColor[
             0.9712888599161243, 0.9778630692563173, 0.9225224543243025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 454}], {
             RGBColor[
             0.9623399915602904, 0.9714338078850446, 0.9486327503718474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 489}], {
             RGBColor[
             0.9542420734408035, 0.9653943938106551, 0.9623404134728354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 500}], {
             RGBColor[
             0.8612460096765686, 0.8920909035909841, 0.9675449607912145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 430}], {
             RGBColor[
             0.927490408213999, 0.9288107337954661, 0.6899281650859377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 459}], {
             RGBColor[
             0.92234634299795, 0.9114585939377824, 0.6699444430967925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 477}], {
             RGBColor[
             0.889791633684836, 0.9149597122225508, 0.98935031441887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 428}], {
             RGBColor[
             0.9936475967323757, 0.9907693740859425, 0.691571676312565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 437}], {
             RGBColor[
             0.7653149094336997, 0.8134375116912838, 0.8610100978724511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 451}], {
             RGBColor[
             0.8844329472012264, 0.9080981088003856, 0.8717855417146515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 429}], {
             RGBColor[
             0.9871440929275397, 0.9670121485450667, 0.5137397131211399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 465}], {
             RGBColor[
             0.9855289736091711, 0.9863990997070365, 0.7882645488174166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 469}], {
             RGBColor[
             0.9926692059922282, 0.9906339302559275, 0.7273502074278899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 488}], {
             RGBColor[
             0.717059033826817, 0.7729737124517129, 0.8005250390112448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{425, 462}], {
             RGBColor[
             0.871443123156149, 0.8998583483111334, 0.958507311670656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 476}], {
             RGBColor[
             0.8324205509782832, 0.8694027877038419, 0.9560944546209449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 433}], {
             RGBColor[
             0.9886595756454382, 0.9895784573408458, 0.8376037098399378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 500}], {
             RGBColor[
             0.8756225781987939, 0.9025681348593082, 0.9322469841328929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 437}], {
             RGBColor[
             0.7659387972164532, 0.8128237471619901, 0.7873030472103614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 451}], {
             RGBColor[
             0.8850568349839798, 0.9074843442710918, 0.7980784910525618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{429, 488}], {
             RGBColor[
             0.7096196565346073, 0.7491629455645412, 0.6624424078865665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{430, 459}], {
             RGBColor[
             0.9788445234745669, 0.940299751516917, 0.3723153978855561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{430, 477}], {
             RGBColor[
             0.9462898141614529, 0.9438008698016854, 0.6917212692076337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 444}], {
             RGBColor[
             0.9766666327561162, 0.9786137318730985, 0.7099676281529235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 486}], {
             RGBColor[
             0.9799481281586455, 0.9810610657713492, 0.7044129123875136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{432, 460}], {
             RGBColor[
             0.9660271586228857, 0.8906211636394319, 0.4418506779906268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 465}], {
             RGBColor[
             0.9840640999255599, 0.9863959490694425, 0.8563448477014549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 469}], {
             RGBColor[
             0.991204332308617, 0.9906307796183335, 0.7954305063119282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 495}], {
             RGBColor[
             0.9584651186752726, 0.9685439340319203, 0.9551918994374768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{435, 439}], {
             RGBColor[
             0.8270682082531183, 0.8656511482195306, 0.9831805085326668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{435, 453}], {
             RGBColor[
             0.944650013797829, 0.9217400154409758, 0.6610340089624175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 473}], {
             RGBColor[
             0.9836547646768238, 0.9845816088266798, 0.758134987451321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 439}], {
             RGBColor[
             0.8370430210572923, 0.8734584310786357, 0.9790574487848515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{439, 453}], {
             RGBColor[
             0.850293091945878, 0.8472077600608474, 0.6518469719480969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 445}], {
             RGBColor[
             0.4417315132298978, 0.5543998510881977, 0.9500937099255368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 471}], {
             RGBColor[
             0.7713354531767376, 0.8184129334017252, 0.8651491357337816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 450}], {
             RGBColor[
             0.7924127527546289, 0.8345567248784482, 0.8090762174502968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 461}], {
             RGBColor[
             0.9632081139259656, 0.9696861186656642, 0.8253133368706493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 447}], {
             RGBColor[
             0.7106060792573227, 0.7683043543509934, 0.8555781813293539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 500}], {
             RGBColor[
             0.8793806762296819, 0.9041222049737943, 0.8699655741151396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{443, 451}], {
             RGBColor[
             0.8803107159989039, 0.9063934602617154, 0.9401015807295161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{444, 486}], {
             RGBColor[
             0.9637193936251978, 0.9724625636864889, 0.9462977824816368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{445, 471}], {
             RGBColor[
             0.6629795539979457, 0.727188016084199, 0.8575188030364688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 454}], {
             RGBColor[
             0.6978991128706009, 0.7603210228652346, 0.943969887394652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 500}], {
             RGBColor[
             0.5968051309868792, 0.6809781185711741, 0.9628820978140191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 455}], {
             RGBColor[
             0.9923778505994036, 0.9911160595896182, 0.7759822712656085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 475}], {
             RGBColor[
             0.9840254317982846, 0.962303073845603, 0.5814273561274207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 478}], {
             RGBColor[
             0.9575312606513029, 0.8634796033755006, 0.5277308165012541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 482}], {
             RGBColor[
             0.9448057763469146, 0.9562570945744235, 0.8939707358576354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{449, 499}], {
             RGBColor[
             0.8261943670997299, 0.8643753056623131, 0.9832508269203204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 461}], {
             RGBColor[
             0.7609873351013227, 0.8133128519258355, 0.977118340034008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{452, 468}], {
             RGBColor[
             0.8279837867294976, 0.8660325946435812, 0.9833603478657635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 489}], {
             RGBColor[
             0.9596697736071947, 0.9694423637077064, 0.9531527328620586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 500}], {
             RGBColor[
             0.86667370984296, 0.8961388734880354, 0.9583572801804378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{455, 475}], {
             RGBColor[
             0.9853392724439102, 0.9628463807167336, 0.5596536165188069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{455, 482}], {
             RGBColor[
             0.9461196169925402, 0.9568004014455541, 0.8721969962490217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{457, 494}], {
             RGBColor[
             0.9625014562591933, 0.9353157102950035, 0.6433529250429965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{458, 461}], {
             RGBColor[
             0.962906908068293, 0.9690418697926861, 0.7925289380900615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{459, 477}], {
             RGBColor[
             0.9411457489454038, 0.9264487299440016, 0.6717375472184883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{460, 463}], {
             RGBColor[
             0.9941028675486421, 0.9909340042038932, 0.6823085683096338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{463, 483}], {
             RGBColor[
             0.9383478127571243, 0.9505515644906412, 0.8692058926733433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 481}], {
             RGBColor[
             0.8396514291247766, 0.8740233205726711, 0.9085343467695368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 496}], {
             RGBColor[
             0.6662866142360043, 0.739211981685086, 0.9673834458697224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{465, 469}], {
             RGBColor[
             0.9836147093816501, 0.9862101145307256, 0.8637924119994882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 470}], {
             RGBColor[
             0.9658898310386244, 0.9724368320373844, 0.8689824008406868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 491}], {
             RGBColor[
             0.9551915225446279, 0.9363002525697663, 0.6693897380275433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 483}], {
             RGBColor[
             0.9376587353357189, 0.950266613268408, 0.8806256888212336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 497}], {
             RGBColor[
             0.9897160384540835, 0.9900153318620764, 0.8200953870625773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{472, 488}], {
             RGBColor[
             0.7085067307658577, 0.7689244318535502, 0.9361171608963934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{474, 490}], {
             RGBColor[
             0.9905899523922471, 0.9903767177340708, 0.8056123714904334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{475, 478}], {
             RGBColor[
             0.9504926824958093, 0.835209924502616, 0.31140216175445246`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{475, 482}], {
             RGBColor[
             0.9377671981914211, 0.9279874157015389, 0.6776420811108339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{478, 482}], {
             RGBColor[
             0.9112730270444394, 0.8291639452314365, 0.6239455414846673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{481, 496}], {
             RGBColor[
             0.8147150877861454, 0.8545274087830346, 0.9060594902072066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{484, 490}], {
             RGBColor[
             0.9944359317852973, 0.9919671290502591, 0.7418745398719766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{489, 500}], {
             RGBColor[
             0.858575791723473, 0.890099459413646, 0.9720649432814258]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.028685633809430733`], {
             RGBColor[
             0.9863258009688682, 0.9886133815368107, 0.8762803958459606]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.028685633809430733`], {
             RGBColor[
             0.9841132947551167, 0.9580725542125387, 0.39278357938652314`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.028685633809430733`], {
             RGBColor[
             0.9933848484528064, 0.9882591846719976, 0.5213597619501679]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.028685633809430733`], {
             RGBColor[
             0.9920465687178295, 0.9909790660180312, 0.7814724693733199]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.028685633809430733`], {
             RGBColor[
             0.984327542467592, 0.9877870502936319, 0.9093967105393381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.028685633809430733`], {
             RGBColor[
             0.9879468956147884, 0.9892837458331307, 0.8494146623046014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.028685633809430733`], {
             RGBColor[
             0.9241268777090614, 0.9423377038020972, 0.9926252406453347]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.028685633809430733`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.028685633809430733`], {
             RGBColor[
             0.9875711699381853, 0.9891283736101459, 0.8556414091127977]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.028685633809430733`], {
             RGBColor[
             0.9872765015200164, 0.9890065206466001, 0.8605248273792769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.028685633809430733`], {
             RGBColor[
             0.8606782742213762, 0.8917455096474782, 0.9865734562034423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.028685633809430733`], {
             RGBColor[
             0.9411537104511517, 0.9556331141232004, 0.9844955980225343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.028685633809430733`], {
             RGBColor[
             0.9627741573199544, 0.8860906329759973, 0.3098850600088902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.028685633809430733`], {
             RGBColor[
             0.7570478091352061, 0.8101307693636564, 0.97641910866674]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.028685633809430733`], {
             RGBColor[
             0.9675558440216263, 0.9022203850141659, 0.32846100989912097`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.028685633809430733`], {
             RGBColor[
             0.9677676917266818, 0.9754817777820959, 0.9394450697610706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.028685633809430733`], {
             RGBColor[
             0.9106669174493136, 0.9316050968518624, 0.9913414176199116]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.028685633809430733`], {
             RGBColor[
             0.9148048130300681, 0.9349045424677728, 0.991736093794347]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.028685633809430733`], {
             RGBColor[
             0.38268957127153075`, 0.5058882049234454, 0.9456056189756892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.028685633809430733`], {
             RGBColor[
             0.780193731668043, 0.8282125399618351, 0.9787260779138692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.028685633809430733`], {
             RGBColor[
             0.9852782492131028, 0.9881801919649494, 0.8936410394160358]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.028685633809430733`], {
             RGBColor[
             0.7103884990091678, 0.7736801616693041, 0.9717685446894204]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.028685633809430733`], {
             RGBColor[
             0.9530112514304525, 0.9644764487706214, 0.9644238740865665]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.028685633809430733`], {
             RGBColor[
             0.984838463031878, 0.9879983290770237, 0.9009294345690833]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.028685633809430733`], {
             RGBColor[
             0.964832105757261, 0.9732924225726828, 0.9444142510838568]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.028685633809430733`], {
             RGBColor[
             0.9888987776508573, 0.9896773735172977, 0.833639513575197]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.028685633809430733`], {
             RGBColor[
             0.9643311918106083, 0.9729188417714405, 0.9452621677362588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.028685633809430733`], {
             RGBColor[
             0.9952047802628202, 0.9921518347902855, 0.7194481081529587]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.028685633809430733`], {
             RGBColor[
             0.821348616347189, 0.8603851080337245, 0.9828221583254023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.028685633809430733`], {
             RGBColor[
             0.915972544858566, 0.935835660130581, 0.9918474730985956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.028685633809430733`], {
             RGBColor[
             0.19833116541448517`, 0.32578900814576967`, 0.9346060385144647]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.028685633809430733`], {
             RGBColor[
             0.9866110669390208, 0.9887313463464698, 0.8715528004758663]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.028685633809430733`], {
             RGBColor[
             0.9652230670110583, 0.9735840008356245, 0.9437524556602038]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.028685633809430733`], {
             RGBColor[
             0.6726723604834276, 0.7442160275997264, 0.9680093524785284]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.028685633809430733`], {
             RGBColor[
             0.7203011710530286, 0.781424016409066, 0.9727565471995655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.028685633809430733`], {
             RGBColor[
             0.9767931160126324, 0.982212924436782, 0.9241673806526106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.028685633809430733`], {
             RGBColor[
             0.9940572141727555, 0.9896973069603666, 0.594542621206393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.028685633809430733`], {
             RGBColor[
             0.3154426693714862, 0.4476423184251921, 0.9413207058507189]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.028685633809430733`], {
             RGBColor[
             0.9784982126551118, 0.9391315638052483, 0.37097004574728454`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.028685633809430733`], {
             RGBColor[
             0.5901919739299859, 0.6781834581386196, 0.9608812206136554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.028685633809430733`], {
             RGBColor[
             0.6289718956281638, 0.7096667455887641, 0.9639341181052699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.028685633809430733`], {
             RGBColor[
             0.9952346037814678, 0.9922974004456097, 0.7286384779985604]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.028685633809430733`], {
             RGBColor[
             0.9304652834918896, 0.7620250506556833, 0.26290893878924504`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.028685633809430733`], {
             RGBColor[
             0.9456475871603818, 0.8222178254984703, 0.2751249766953837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.028685633809430733`], {
             RGBColor[
             0.9945734844487251, 0.9920240106115287, 0.7395949362640952]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.028685633809430733`], {
             RGBColor[
             0.9550597969597695, 0.859534100920057, 0.28269826163293027`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.028685633809430733`], {
             RGBColor[
             0.9119519007033887, 0.9326297076187208, 0.9914639804698034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.028685633809430733`], {
             RGBColor[
             0.5032830972546972, 0.6076269168533435, 0.9540394354840718]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.028685633809430733`], {
             RGBColor[
             0.6913652332537679, 0.7588190418790111, 0.969872483341448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.028685633809430733`], {
             RGBColor[
             0.7651807734778256, 0.8164843029209291, 0.9772297265455393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.028685633809430733`], {
             RGBColor[
             0.8815304384573449, 0.9083724593923199, 0.9885623542432158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.028685633809430733`], {
             RGBColor[
             0.9850709220112933, 0.9880944568389353, 0.8970769876956168]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.028685633809430733`], {
             RGBColor[
             0.9952419874533721, 0.9922314172086519, 0.723497881228365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.028685633809430733`], {
             RGBColor[
             0.9842257115559985, 0.9877449405947528, 0.9110843122743948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.028685633809430733`], {
             RGBColor[
             0.9912677017098207, 0.9906569844942505, 0.7943803113392284]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.028685633809430733`], {
             RGBColor[
             0.9820947531072752, 0.9861668767013325, 0.9151930919397894]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.028685633809430733`], {
             RGBColor[
             0.47157355448808164`, 0.5818836815367823, 0.9515431441216013]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.028685633809430733`], {
             RGBColor[
             0.6328861698632761, 0.712844529748873, 0.9642422641115169]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.028685633809430733`], {
             RGBColor[
             0.9898257641014339, 0.9900607062370763, 0.8182769491251094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.028685633809430733`], {
             RGBColor[
             0.6913652332537679, 0.7588190418790111, 0.969872483341448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.028685633809430733`], {
             RGBColor[
             0.9863307559062481, 0.9655525713599432, 0.40139799722626757`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.028685633809430733`], {
             RGBColor[
             0.8285826137706818, 0.8661533012175886, 0.9835121434575208]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.028685633809430733`], {
             RGBColor[
             0.6284215741138477, 0.7092199697917405, 0.9638907947797688]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.028685633809430733`], {
             RGBColor[
             0.9509403104754203, 0.962931944397213, 0.9679294369355298]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.028685633809430733`], {
             RGBColor[
             0.979107471801929, 0.9411867379683131, 0.37333690248373336`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.028685633809430733`], {
             RGBColor[
             0.9536326657922781, 0.9649398985841984, 0.9633719816628185]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.028685633809430733`], {
             RGBColor[
             0.6289718956281638, 0.7096667455887641, 0.9639341181052699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.028685633809430733`], {
             RGBColor[
             0.3034953884225382, 0.4363232743240858, 0.9405949854382473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.028685633809430733`], {
             RGBColor[
             0.9937879819606789, 0.9916991851462285, 0.752612745306297]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.028685633809430733`], {
             RGBColor[
             0.9507938358239225, 0.9628227038419562, 0.968177380313808]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.028685633809430733`], {
             RGBColor[
             0.9104294411179825, 0.9314157396713825, 0.9913187669154316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.028685633809430733`], {
             RGBColor[
             0.977176114869667, 0.9346718175316204, 0.3658339455080486]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.028685633809430733`], {
             RGBColor[
             0.9753851332848676, 0.9811628532237751, 0.9265507281500083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.028685633809430733`], {
             RGBColor[
             0.9937777382796147, 0.9890995362842856, 0.5641233949632969]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.028685633809430733`], {
             RGBColor[
             0.994522933898023, 0.9906934343612267, 0.6452333392127795]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.028685633809430733`], {
             RGBColor[
             0.9635581257904074, 0.972342290399354, 0.9465707668605492]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.028685633809430733`], {
             RGBColor[
             0.9666284890902792, 0.9746321623211399, 0.9413734426728669]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.028685633809430733`], {
             RGBColor[
             0.9902852466032931, 0.9902507140597567, 0.8106621349667054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.028685633809430733`], {
             RGBColor[
             0.8532589876521729, 0.4103774940976119, 0.19863417276413114`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.028685633809430733`], {
             RGBColor[
             0.8079547099677182, 0.849899627200791, 0.9814930327896889]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.028685633809430733`], {
             RGBColor[
             0.9351048540208795, 0.7804194017578999, 0.2666420461415875]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.028685633809430733`], {
             RGBColor[
             0.4395345974338848, 0.5551245094711873, 0.9492277337766715]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.028685633809430733`], {
             RGBColor[
             0.7586003329792586, 0.8113436127902485, 0.9765738497343549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.028685633809430733`], {
             RGBColor[
             0.9576571117028954, 0.8688296365702102, 0.2900063040595978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.028685633809430733`], {
             RGBColor[
             0.9203859716550642, 0.9393548068588295, 0.9922684296863582]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.028685633809430733`], {
             RGBColor[
             0.9925555201289337, 0.9864853352451896, 0.43109249191776094`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.028685633809430733`], {
             RGBColor[
             0.9854045308203558, 0.9882324126548379, 0.8915482263775283]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.028685633809430733`], {
             RGBColor[
             0.9806008334120878, 0.9462241973373597, 0.3791383303415238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.028685633809430733`], {
             RGBColor[
             0.9913915513473154, 0.9907081995021451, 0.7923278023333554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.028685633809430733`], {
             RGBColor[
             0.9947253820035139, 0.9920868241540229, 0.7370776006829731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.028685633809430733`], {
             RGBColor[
             0.849619756525529, 0.8829277478122759, 0.9855186849135571]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.028685633809430733`], {
             RGBColor[
             0.9741976606999332, 0.980277238114239, 0.9285608094938501]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.028685633809430733`], {
             RGBColor[
             0.9874016970956646, 0.9890582922345103, 0.8584500126950219]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.028685633809430733`], {
             RGBColor[
             0.9404457481670355, 0.9551051170108884, 0.9856939935034069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.028685633809430733`], {
             RGBColor[
             0.9914586828958115, 0.9907359601226503, 0.7912152588438948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.028685633809430733`], {
             RGBColor[
             0.9448164233515018, 0.9583647594071395, 0.978295580470761]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.028685633809430733`], {
             RGBColor[
             0.40012174927244104`, 0.520987081341092, 0.9467163819432375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.028685633809430733`], {
             RGBColor[
             0.956553060195872, 0.8651054115933988, 0.2857172724374447]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.028685633809430733`], {
             RGBColor[
             0.8453259188235478, 0.8795039581818356, 0.985109134840388]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.028685633809430733`], {
             RGBColor[
             0.9533511591754248, 0.964729951410274, 0.9638484989364666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.028685633809430733`], {
             RGBColor[
             0.9684234032986435, 0.9759708063988358, 0.938335121106707]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.028685633809430733`], {
             RGBColor[
             0.9940010678979847, 0.989577215755891, 0.5884314456922328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.028685633809430733`], {
             RGBColor[
             0.994610899788126, 0.9908815845054411, 0.6548078834879365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.028685633809430733`], {
             RGBColor[
             0.9940934597040991, 0.9897748324869252, 0.5984877236116537]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.028685633809430733`], {
             RGBColor[
             0.8817141177931931, 0.9085189203088825, 0.9885798737422414]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.028685633809430733`], {
             RGBColor[
             0.9572867800235133, 0.9676651309947907, 0.9571865194149646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.028685633809430733`], {
             RGBColor[
             0.9489112233771633, 0.9614186545616582, 0.9713641521222067]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.028685633809430733`], {
             RGBColor[
             0.993128924622016, 0.9877117894758053, 0.4935040323474336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.028685633809430733`], {
             RGBColor[
             0.9852329485953335, 0.9618494095228137, 0.39713322312687954`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.028685633809430733`], {
             RGBColor[
             0.9931102863408029, 0.9914189405914267, 0.7638439155476862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.028685633809430733`], {
             RGBColor[
             0.9820207455363814, 0.9861116819761362, 0.9153183674530466]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.028685633809430733`], {
             RGBColor[
             0.7617904993547786, 0.8138357950089671, 0.9768918157048669]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.028685633809430733`], {
             RGBColor[
             0.9441835949621007, 0.9578927970304856, 0.9793667938659393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.028685633809430733`], {
             RGBColor[
             0.9761743407253711, 0.9817514428406939, 0.9252148058115024]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.028685633809430733`], {
             RGBColor[
             0.6919233911234834, 0.7592550790489898, 0.9699281153016194]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.028685633809430733`], {
             RGBColor[
             0.8029681605498283, 0.8460040968963563, 0.9809960201456673]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.028685633809430733`], {
             RGBColor[
             0.5741473511894406, 0.6651577105958275, 0.95961812913813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.028685633809430733`], {
             RGBColor[
             0.8616581149881173, 0.8925268080778085, 0.9866669142904883]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.028685633809430733`], {
             RGBColor[
             0.31365233919776553`, 0.4460916244133262, 0.9412066275951763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.028685633809430733`], {
             RGBColor[
             0.9860929059130769, 0.988517073446111, 0.8801400696335077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.028685633809430733`], {
             RGBColor[
             0.2727010419981418, 0.4039564637577123, 0.938841292965531]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.028685633809430733`], {
             RGBColor[
             0.7943988869633616, 0.8393097152417169, 0.980141915038983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.028685633809430733`], {
             RGBColor[
             0.9904544174884021, 0.9903206705682428, 0.8078585356002324]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.028685633809430733`], {
             RGBColor[
             0.728709603892838, 0.7879927480499815, 0.9735946212037653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.028685633809430733`], {
             RGBColor[
             0.9815749369953032, 0.9857791986961445, 0.9160730050276027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.028685633809430733`], {
             RGBColor[
             0.9639317271966972, 0.8899953879805829, 0.31438200039130704`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.028685633809430733`], {
             RGBColor[
             0.40012174927244104`, 0.520987081341092, 0.9467163819432375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.028685633809430733`], {
             RGBColor[
             0.8695899138265684, 0.5007200813834536, 0.21289496626421464`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.028685633809430733`], {
             RGBColor[
             0.3498942154439241, 0.4774825160480841, 0.9435159279021487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.028685633809430733`], {
             RGBColor[
             0.9061361046991667, 0.9279923497505311, 0.9909092646550983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.028685633809430733`], {
             RGBColor[
             0.9834254693041098, 0.987159322662084, 0.9129405365249178]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.028685633809430733`], {
             RGBColor[
             0.9932921781554087, 0.9880609722762682, 0.511273171973209]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.028685633809430733`], {
             RGBColor[
             0.992986043439436, 0.9913675629588146, 0.7659029419536576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.028685633809430733`], {
             RGBColor[
             0.9930954498332378, 0.9914128053142677, 0.7640897948736901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.028685633809430733`], {
             RGBColor[
             0.9927000684823609, 0.9912493049648429, 0.7706422870718564]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.028685633809430733`], {
             RGBColor[
             0.9941243955242962, 0.9898410010782355, 0.6018548967263526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.028685633809430733`], {
             RGBColor[
             0.9233782651728333, 0.7339273846294816, 0.25720655749603183`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.028685633809430733`], {
             RGBColor[
             0.9863028559048419, 0.9886038931631745, 0.8766606549367995]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.028685633809430733`], {
             RGBColor[
             0.9925418566819038, 0.986456110513579, 0.4296053100295783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.028685633809430733`], {
             RGBColor[
             0.9803775439230509, 0.98488618490341, 0.9180998791687964]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.028685633809430733`], {
             RGBColor[
             0.9931624689123215, 0.987783537320921, 0.4971551213358345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.028685633809430733`], {
             RGBColor[
             0.9938546826500378, 0.9917267675954079, 0.7515073422677685]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.028685633809430733`], {
             RGBColor[
             0.9890606243156869, 0.974761058508564, 0.4120030205045446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.028685633809430733`], {
             RGBColor[
             0.9898519606369953, 0.9900715391777511, 0.8178428047363955]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.028685633809430733`], {
             RGBColor[
             0.9935299507465049, 0.9915924826080678, 0.7568889902885362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.028685633809430733`], {
             RGBColor[
             0.977106427336898, 0.982446591509419, 0.9236370263053097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.028685633809430733`], {
             RGBColor[
             0.891889842658401, 0.916632767103706, 0.9895504434638618]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.028685633809430733`], {
             RGBColor[
             0.7696054106825146, 0.8199408631337204, 0.9776707330315172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.028685633809430733`], {
             RGBColor[
             0.8750857636203784, 0.903233650613361, 0.9879476554040367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.028685633809430733`], {
             RGBColor[
             0.9461721961047933, 0.8242977251474946, 0.2755470893662118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.028685633809430733`], {
             RGBColor[
             0.9935575982047079, 0.9886286789236357, 0.5401625063567569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.028685633809430733`], {
             RGBColor[
             0.9742364901224451, 0.9247557730025271, 0.35441405846664487`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.028685633809430733`], {
             RGBColor[
             0.837839963684504, 0.8735348607548011, 0.984395117756435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.028685633809430733`], {
             RGBColor[
             0.9425175770077859, 0.9566502835680116, 0.9821869276955205]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.028685633809430733`], {
             RGBColor[
             0.9931111681921242, 0.9876738102677172, 0.4915713545336937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.028685633809430733`], {
             RGBColor[
             0.9398374828022629, 0.954651473697784, 0.9867236281049521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.028685633809430733`], {
             RGBColor[
             0.7965937153743471, 0.8410243318776925, 0.9803606750231524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.028685633809430733`], {
             RGBColor[
             0.990186684061624, 0.9902099559158348, 0.8122955713538424]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.028685633809430733`], {
             RGBColor[
             0.9445586799086506, 0.9581725347694773, 0.9787318728892521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.028685633809430733`], {
             RGBColor[
             0.9946481079241047, 0.9909611689459802, 0.6588577594672334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.028685633809430733`], {
             RGBColor[
             0.9861649985359195, 0.9885468855983524, 0.8789453083032777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.028685633809430733`], {
             RGBColor[
             0.4555167766287425, 0.5688480659209715, 0.9502790957505988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.028685633809430733`], {
             RGBColor[
             0.9553734184572861, 0.9662381490715404, 0.9604253414619679]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.028685633809430733`], {
             RGBColor[
             0.6481561481349929, 0.7250637761830142, 0.9655658055486667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.028685633809430733`], {
             RGBColor[
             0.9251342868580004, 0.9431409845120683, 0.9927213282292853]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.028685633809430733`], {
             RGBColor[
             0.8613502489640357, 0.8922813240670063, 0.9866375497542761]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.028685633809430733`], {
             RGBColor[
             0.8243309587103747, 0.8627631468806018, 0.9831066168023714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.028685633809430733`], {
             RGBColor[
             0.9878098980602391, 0.989227093823648, 0.85168506632179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.028685633809430733`], {
             RGBColor[
             0.9942168312051898, 0.9900387116529861, 0.6119159501447256]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.028685633809430733`], {
             RGBColor[
             0.945579136980112, 0.958933589982528, 0.9770045052450977]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.028685633809430733`], {
             RGBColor[
             0.9573454842358038, 0.9677089125001976, 0.9570871484960676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.028685633809430733`], {
             RGBColor[
             0.9122823557359845, 0.6899358012050061, 0.24827852830867408`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.028685633809430733`], {
             RGBColor[
             0.42803053401452, 0.5451602679483732, 0.9484947050282334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.028685633809430733`], {
             RGBColor[
             0.9535670147221379, 0.9648909361235816, 0.9634831118000243]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.028685633809430733`], {
             RGBColor[
             0.5741473511894406, 0.6651577105958275, 0.95961812913813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.028685633809430733`], {
             RGBColor[
             0.9928337157012788, 0.9870803674445489, 0.46137236314346874`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.028685633809430733`], {
             RGBColor[
             0.7604444797303808, 0.8127842742482595, 0.9767576570479756]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.028685633809430733`], {
             RGBColor[
             0.9942506326357541, 0.9918905030899521, 0.7449454263187344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.028685633809430733`], {
             RGBColor[
             0.2363694896793889, 0.365769698717239, 0.936772264808693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.028685633809430733`], {
             RGBColor[
             0.9532839954477023, 0.964679860812109, 0.9639621896083952]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.028685633809430733`], {
             RGBColor[
             0.9935117669341854, 0.9885306504702404, 0.535174055398195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.028685633809430733`], {
             RGBColor[
             0.7765010407909959, 0.8253277817831959, 0.9783580249974034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.028685633809430733`], {
             RGBColor[
             0.38505150402135535`, 0.5079339923571518, 0.9457561192419329]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.028685633809430733`], {
             RGBColor[
             0.598154912423452, 0.6846481303339066, 0.9615080923010659]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.028685633809430733`], {
             RGBColor[
             0.9479717480632536, 0.960717995410794, 0.9729544387742511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.028685633809430733`], {
             RGBColor[
             0.9790107126884483, 0.9838668044066241, 0.9204135679222986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.028685633809430733`], {
             RGBColor[
             0.9873528620199864, 0.989038097675713, 0.859259336280135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.028685633809430733`], {
             RGBColor[
             0.9370358741915064, 0.952562038583095, 0.9914660207064113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.028685633809430733`], {
             RGBColor[
             0.9743378152726463, 0.9803817651650862, 0.9283235643604139]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.028685633809430733`], {
             RGBColor[
             0.9873102863339923, 0.9688567574974063, 0.405203287969254]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.028685633809430733`], {
             RGBColor[
             0.9586725769666101, 0.968698656085918, 0.9548407266640306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.028685633809430733`], {
             RGBColor[
             0.9930092466406586, 0.987455810374982, 0.4804778226435734]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.028685633809430733`], {
             RGBColor[
             0.9914110929032605, 0.9907162804377234, 0.7920039481794195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.028685633809430733`], {
             RGBColor[
             0.9724643854495774, 0.9187780478309799, 0.34752976644644107`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.028685633809430733`], {
             RGBColor[
             0.9941950919451301, 0.9899922135738948, 0.6095497658463958]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.028685633809430733`], {
             RGBColor[
             0.9383643458402068, 0.953552810563523, 0.989217264726059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.028685633809430733`], {
             RGBColor[
             0.4324930297440872, 0.5490254574577673, 0.9487790513100914]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.028685633809430733`], {
             RGBColor[
             0.9929376115378353, 0.9873025901334628, 0.4726807837818649]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.028685633809430733`], {
             RGBColor[
             0.9851978043385037, 0.9881469259419637, 0.894974219172804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.028685633809430733`], {
             RGBColor[
             0.9845976511911618, 0.9878987471923055, 0.9049203099708166]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.028685633809430733`], {
             RGBColor[
             0.9879174732955742, 0.9892715789480165, 0.849902266276502]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.028685633809430733`], {
             RGBColor[
             0.9856809024388418, 0.9883466994215084, 0.8869680334323946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.028685633809430733`], {
             RGBColor[
             0.9928967975262167, 0.9872152930895403, 0.4682384304920681]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.028685633809430733`], {
             RGBColor[
             0.9333310293416099, 0.949676844473851, 0.9935031408446904]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.028685633809430733`], {
             RGBColor[
             0.9851978043385037, 0.9881469259419637, 0.894974219172804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.028685633809430733`], {
             RGBColor[
             0.9553550420522066, 0.9662244439787208, 0.9604564479224335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.028685633809430733`], {
             RGBColor[
             0.8494564752775517, 0.8827975517772902, 0.9855031110023622]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.028685633809430733`], {
             RGBColor[
             0.9536095690756585, 0.9649226730907609, 0.9634110783794669]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.028685633809430733`], {
             RGBColor[
             0.8306698123965767, 0.8678175767463797, 0.9837112223257228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.028685633809430733`], {
             RGBColor[
             0.6913652332537679, 0.7588190418790111, 0.969872483341448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.028685633809430733`], {
             RGBColor[
             0.990789424961678, 0.9904592047677417, 0.8023065947965011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.028685633809430733`], {
             RGBColor[
             0.8063816153091803, 0.8486707136975791, 0.9813362414155312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.028685633809430733`], {
             RGBColor[
             0.9461083350392051, 0.9593282650285173, 0.976108710968012]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.028685633809430733`], {
             RGBColor[
             0.9943185481365996, 0.9919185878949004, 0.7438198907100414]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.028685633809430733`], {
             RGBColor[
             0.6829153499894759, 0.7522179288514548, 0.969030277946312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.028685633809430733`], {
             RGBColor[
             0.9539936798272888, 0.9652091422604031, 0.9627608790690855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.028685633809430733`], {
             RGBColor[
             0.8999691762820193, 0.9230750084275103, 0.9903210575173889]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.028685633809430733`], {
             RGBColor[
             0.9890606243156869, 0.974761058508564, 0.4120030205045446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.028685633809430733`], {
             RGBColor[
             0.9946610523489464, 0.9909888557618344, 0.6602666802275163]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.028685633809430733`], {
             RGBColor[
             0.6682915544748432, 0.7407937086504613, 0.9675727146765524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.028685633809430733`], {
             RGBColor[
             0.9923676401014224, 0.991111837286305, 0.7761514856410796]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.028685633809430733`], {
             RGBColor[
             0.9948622790412961, 0.9921434345972393, 0.7348088624887456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.028685633809430733`], {
             RGBColor[
             0.8751678975066621, 0.9032991419448188, 0.9879554894074323]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.028685633809430733`], {
             RGBColor[
             0.29763342953545374`, 0.43016198386409993`, 0.9402611555516188]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.028685633809430733`], {
             RGBColor[
             0.9929585033438948, 0.9873472755941385, 0.47495472794216326`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.028685633809430733`], {
             RGBColor[
             0.9881251850306509, 0.9716056021485489, 0.4083690155250665]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.028685633809430733`], {
             RGBColor[
             0.9941369643783522, 0.9918434983443754, 0.7468292035079036]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.028685633809430733`], {
             RGBColor[
             0.8568982974444642, 0.43835082391688224`, 0.2021191799312418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.028685633809430733`], {
             RGBColor[
             0.9939438783512329, 0.991763652310077, 0.7500291386678903]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.028685633809430733`], {
             RGBColor[
             0.95651787210101, 0.8649867138868719, 0.2855805733336201]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.028685633809430733`], {
             RGBColor[
             0.9910669732562823, 0.9905739781202264, 0.797706901282946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.028685633809430733`], {
             RGBColor[
             0.9843784385358765, 0.9878080971258368, 0.908553230973062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.028685633809430733`], {
             RGBColor[
             0.9878113823179177, 0.9892277076023418, 0.85166046833092]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.028685633809430733`], {
             RGBColor[
             0.9621434575423502, 0.8839631345307882, 0.30743491047055704`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.028685633809430733`], {
             RGBColor[
             0.9900673727023126, 0.9781570572124152, 0.4159140478781056]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.028685633809430733`], {
             RGBColor[
             0.9797700348309949, 0.9844331056172595, 0.9191282335978996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.028685633809430733`], {
             RGBColor[
             0.9428102739756101, 0.8109688241994211, 0.2728420079066163]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.028685633809430733`], {
             RGBColor[
             0.9947985138596667, 0.9921170660559451, 0.7358656165673463]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.028685633809430733`], {
             RGBColor[
             0.9922668015900864, 0.9855762473013375, 0.4244584137798127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.028685633809430733`], {
             RGBColor[
             0.9900673727023126, 0.9781570572124152, 0.4159140478781056]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.028685633809430733`], {
             RGBColor[
             0.6061712344080974, 0.6911561416522317, 0.9621391665324522]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.028685633809430733`], {
             RGBColor[
             0.8814737500606024, 0.908327257603523, 0.9885569472533281]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.028685633809430733`], {
             RGBColor[
             0.9938177456297614, 0.9917114931882856, 0.752119484283691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.028685633809430733`], {
             RGBColor[
             0.9853265573604543, 0.9882001686253421, 0.8928404483969442]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.028685633809430733`], {
             RGBColor[
             0.7845426497999827, 0.8316099478595085, 0.9791595374303105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.028685633809430733`], {
             RGBColor[
             0.9934821092956677, 0.9915726989386774, 0.7576818469386144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.028685633809430733`], {
             RGBColor[
             0.6061712344080974, 0.6911561416522317, 0.9621391665324522]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.028685633809430733`], {
             RGBColor[
             0.9401765625928236, 0.954904358850392, 0.9861496544657059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.028685633809430733`], {
             RGBColor[
             0.9573997670793581, 0.9677493965560404, 0.9569952618011631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.028685633809430733`], {
             RGBColor[
             0.9286363305230558, 0.9459334190701406, 0.9930553562803696]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.028685633809430733`], {
             RGBColor[
             0.9945678678579754, 0.9907895435580444, 0.6501241234533305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.028685633809430733`], {
             RGBColor[
             0.9950172934121445, 0.9922075370232727, 0.7322398731994558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.028685633809430733`], {
             RGBColor[
             0.9853049492221886, 0.9881912331048655, 0.8931985511680747]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.028685633809430733`], {
             RGBColor[
             0.9910919683377087, 0.9905843142287405, 0.7972926680985127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.028685633809430733`], {
             RGBColor[
             0.9574222830700058, 0.8680375044510885, 0.289094039164488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.028685633809430733`], {
             RGBColor[
             0.9893745125922263, 0.9898741021413842, 0.8257553544341498]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.028685633809430733`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.028685633809430733`], {
             RGBColor[
             0.9944440319187637, 0.9905246710058049, 0.6366453456969781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.028685633809430733`], {
             RGBColor[
             0.9781501961616124, 0.9832250325898764, 0.9218701979435772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.028685633809430733`], {
             RGBColor[
             0.9914924348026353, 0.9907499174035064, 0.7906559024006914]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.028685633809430733`], {
             RGBColor[
             0.9867445919137549, 0.9887865623549577, 0.8693399460929653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.028685633809430733`], {
             RGBColor[
             0.9589448567427314, 0.9689017218971321, 0.9543798280249962]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.028685633809430733`], {
             RGBColor[
             0.9930237089496222, 0.9913831386152361, 0.7652787269746547]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.028685633809430733`], {
             RGBColor[
             0.9788325981670138, 0.983733966888174, 0.92071506934738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.028685633809430733`], {
             RGBColor[
             0.7319520726687019, 0.790525789301362, 0.9739178001887498]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.028685633809430733`], {
             RGBColor[
             0.7939254315201745, 0.8389398482511046, 0.9800947254250988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.028685633809430733`], {
             RGBColor[
             0.9589448567427314, 0.9689017218971321, 0.9543798280249962]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.028685633809430733`], {
             RGBColor[
             0.9927188276094863, 0.9868346334331723, 0.44886750335896203`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.028685633809430733`], {
             RGBColor[
             0.9937294088508911, 0.9916749636600709, 0.7535834533178283]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.028685633809430733`], {
             RGBColor[
             0.27368855354372723`, 0.4049944010039708, 0.9388975302871596]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.028685633809430733`], {
             RGBColor[
             0.9707105331905348, 0.9128618923371357, 0.3407163816072688]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.028685633809430733`], {
             RGBColor[
             0.9781626970620719, 0.9379997909271169, 0.3696666310251276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.028685633809430733`], {
             RGBColor[
             0.9332538121833299, 0.7730806376951426, 0.2651526544295589]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.028685633809430733`], {
             RGBColor[
             0.9543199303715855, 0.9654524593821533, 0.9622086219973611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.028685633809430733`], {
             RGBColor[
             0.9903487260966506, 0.9902769644616086, 0.8096101154821082]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.028685633809430733`], {
             RGBColor[
             0.22846578593913205`, 0.35746240496246845`, 0.9363221605731673]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.028685633809430733`], {
             RGBColor[
             0.9930254215122214, 0.9874904067897243, 0.48223835759344447`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.028685633809430733`], {
             RGBColor[
             0.9712464083310137, 0.978076198929731, 0.9335565099445364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.028685633809430733`], {
             RGBColor[
             0.9496152118743706, 0.9619436880302, 0.9701724832260411]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.028685633809430733`], {
             RGBColor[
             0.8652388577564749, 0.8953819951646237, 0.987008448732301]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.028685633809430733`], {
             RGBColor[
             0.966862614859491, 0.9748067729364723, 0.9409771288153718]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.028685633809430733`], {
             RGBColor[
             0.9952189904707921, 0.9921822289882649, 0.7209948015954586]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.028685633809430733`], {
             RGBColor[
             0.6711086956553597, 0.7429944807517468, 0.9678535009817452]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.028685633809430733`], {
             RGBColor[
             0.9529011411810641, 0.9643943287269165, 0.9646102620174288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.028685633809430733`], {
             RGBColor[
             0.9638438036013577, 0.9725553484430063, 0.9460871888433164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.028685633809430733`], {
             RGBColor[
             0.923683461203203, 0.9419841355165461, 0.9925829471831634]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.028685633809430733`], {
             RGBColor[
             0.9945112863609643, 0.9906685214572046, 0.6439655766841992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.028685633809430733`], {
             RGBColor[
             0.7846035379541767, 0.8316575141483319, 0.9791656061924884]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.028685633809430733`], {
             RGBColor[
             0.9931471963588707, 0.9877508708733818, 0.4954927981439902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.028685633809430733`], {
             RGBColor[
             0.6322255654245982, 0.7123082213056635, 0.9641902589102304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.028685633809430733`], {
             RGBColor[
             0.9761743407253711, 0.9817514428406939, 0.9252148058115024]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.028685633809430733`], {
             RGBColor[
             0.8247864716915349, 0.8631263605672085, 0.9831500640371557]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.028685633809430733`], {
             RGBColor[
             0.8970097640595464, 0.9207152534524152, 0.9900387861377109]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.028685633809430733`], {
             RGBColor[
             0.9034551451895847, 0.9258546254102977, 0.9906535523437535]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.028685633809430733`], {
             RGBColor[
             0.8320523829610544, 0.8689200009856161, 0.9838430931403981]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.028685633809430733`], {
             RGBColor[
             0.9907549417647071, 0.9904449450796166, 0.8028780706099615]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.028685633809430733`], {
             RGBColor[
             0.9906404535691125, 0.9903976012685257, 0.8047754362969178]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.028685633809430733`], {
             RGBColor[
             0.9646798294737987, 0.9731788551698061, 0.944672015111743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.028685633809430733`], {
             RGBColor[
             0.9936342898917631, 0.9887927146875277, 0.5485099232064785]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.028685633809430733`], {
             RGBColor[
             0.6220661097536373, 0.7040603175137152, 0.9633904693445]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.028685633809430733`], {
             RGBColor[
             0.8499600888918647, 0.883199119603116, 0.9855511461184765]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.028685633809430733`], {
             RGBColor[
             0.9926533377545694, 0.9866945572555454, 0.44173933680780797`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.028685633809430733`], {
             RGBColor[
             0.9478583943520554, 0.8309829393056326, 0.27690384405611884`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.028685633809430733`], {
             RGBColor[
             0.9300154811142914, 0.7602417341162633, 0.2625470172380107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.028685633809430733`], {
             RGBColor[
             0.992096933209597, 0.9850032413669544, 0.42379850719856343`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.028685633809430733`], {
             RGBColor[
             0.9868158432935079, 0.9888160266315624, 0.8681591263377972]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.028685633809430733`], {
             RGBColor[
             0.9934340465180126, 0.9883644143587862, 0.5267146677326]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.028685633809430733`], {
             RGBColor[
             0.5873839250597949, 0.6759037575646386, 0.9606601607203721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.028685633809430733`], {
             RGBColor[
             0.8453259188235478, 0.8795039581818356, 0.985109134840388]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.028685633809430733`], {
             RGBColor[
             0.9935732905999399, 0.9886622433702925, 0.541870526735523]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.028685633809430733`], {
             RGBColor[
             0.9946800893544954, 0.9910295739917669, 0.6623387407987374]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.028685633809430733`], {
             RGBColor[
             0.8285826137706818, 0.8661533012175886, 0.9835121434575208]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.028685633809430733`], {
             RGBColor[
             0.7957891525082786, 0.8403958012518157, 0.9802804837157302]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.028685633809430733`], {
             RGBColor[
             0.9890606243156869, 0.974761058508564, 0.4120030205045446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.028685633809430733`], {
             RGBColor[
             0.9844529643711835, 0.9878389154739629, 0.907318145015345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.028685633809430733`], {
             RGBColor[
             0.7758421854528306, 0.824813078985535, 0.9782923564546483]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.028685633809430733`], {
             RGBColor[
             0.6913652332537679, 0.7588190418790111, 0.969872483341448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.028685633809430733`], {
             RGBColor[
             0.7002287481057137, 0.7657432870465589, 0.9707559156676343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.028685633809430733`], {
             RGBColor[
             0.7274685174875397, 0.7870232019175566, 0.973470921309497]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.028685633809430733`], {
             RGBColor[
             0.9337673935040873, 0.9500247894122209, 0.9935447616480544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.028685633809430733`], {
             RGBColor[
             0.9922492164198458, 0.9910628660506233, 0.7781140725154678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.028685633809430733`], {
             RGBColor[
             0.9800616233174635, 0.9846505718330354, 0.9186346503487657]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.028685633809430733`], {
             RGBColor[
             0.9939811533551307, 0.9895346205623955, 0.5862638706008888]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.028685633809430733`], {
             RGBColor[
             0.950974546666248, 0.9629574776922758, 0.967871483994687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.028685633809430733`], {
             RGBColor[
             0.6702051735070369, 0.7422886423824544, 0.9677634463378949]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.028685633809430733`], {
             RGBColor[
             0.9085186617317849, 0.9298921360555531, 0.9911365150718032]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.028685633809430733`], {
             RGBColor[
             0.9901571299410277, 0.990197734527462, 0.812785359615737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.028685633809430733`], {
             RGBColor[
             0.9401940684259484, 0.9549174146720734, 0.9861200216564779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.028685633809430733`], {
             RGBColor[
             0.9932263399502772, 0.991466931741386, 0.7619206069015835]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.028685633809430733`], {
             RGBColor[
             0.9401897603479632, 0.9549142017145658, 0.9861273141087803]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.028685633809430733`], {
             RGBColor[
             0.9944029528919028, 0.990436807121076, 0.6321741471335288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.028685633809430733`], {
             RGBColor[
             0.8319953594370542, 0.8688745319754406, 0.9838376541857734]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.028685633809430733`], {
             RGBColor[
             0.8243309587103747, 0.8627631468806018, 0.9831066168023714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.028685633809430733`], {
             RGBColor[
             0.8984993251847544, 0.9219029890605965, 0.9901808618075801]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.028685633809430733`], {
             RGBColor[
             0.960776592805539, 0.9702678276535814, 0.9512791766639417]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.028685633809430733`], {
             RGBColor[
             0.9911213320941188, 0.9905964568966302, 0.7968060346638334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.028685633809430733`], {
             RGBColor[
             0.9775957884493338, 0.936087475059879, 0.36746429811634845`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.028685633809430733`], {
             RGBColor[
             0.9942208898335783, 0.9900473926487187, 0.612357706797859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.028685633809430733`], {
             RGBColor[
             0.9940901378687924, 0.9918241343792861, 0.7476052399544306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.028685633809430733`], {
             RGBColor[
             0.9775698671603686, 0.9827922241709504, 0.9228525435686382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.028685633809430733`], {
             RGBColor[
             0.8573952180802753, 0.8891276897967493, 0.9862603153778853]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.028685633809430733`], {
             RGBColor[
             0.6913652332537679, 0.7588190418790111, 0.969872483341448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.028685633809430733`], {
             RGBColor[
             0.9337673935040873, 0.9500247894122209, 0.9935447616480544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.028685633809430733`], {
             RGBColor[
             0.9391199490128591, 0.9541163381725005, 0.9879382256476283]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.028685633809430733`], {
             RGBColor[
             0.9568230771258086, 0.9673193021329263, 0.9579714474676938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.028685633809430733`], {
             RGBColor[
             0.947443683052338, 0.9603241653902802, 0.9738483150963186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.028685633809430733`], {
             RGBColor[
             0.5873839250597949, 0.6759037575646386, 0.9606601607203721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.028685633809430733`], {
             RGBColor[
             0.9850962460682063, 0.9613882797995341, 0.39660215962309675`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.028685633809430733`], {
             RGBColor[
             0.9940990601543072, 0.989786811283628, 0.5990972980548324]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.028685633809430733`], {
             RGBColor[
             0.9726603905062432, 0.9194392189112894, 0.34829120907913846`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.028685633809430733`], {
             RGBColor[
             0.8964542941297087, 0.9202723368081922, 0.989985804919929]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.028685633809430733`], {
             RGBColor[
             0.9925555201289337, 0.9864853352451896, 0.43109249191776094`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.028685633809430733`], {
             RGBColor[
             0.9944879887205925, 0.9919886559308059, 0.7410118217351029]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.028685633809430733`], {
             RGBColor[
             0.9861300500153812, 0.9885324334869737, 0.8795244957324689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.028685633809430733`], {
             RGBColor[
             0.6913652332537679, 0.7588190418790111, 0.969872483341448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.028685633809430733`], {
             RGBColor[
             0.9174744548829143, 0.9370332424157347, 0.9919907266174889]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.028685633809430733`], {
             RGBColor[
             0.9937969292739779, 0.9891405838807213, 0.5662122162666461]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.028685633809430733`], {
             RGBColor[
             0.98543459771938, 0.9882448460902684, 0.8910499400500574]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.028685633809430733`], {
             RGBColor[
             0.7758421854528306, 0.824813078985535, 0.9782923564546483]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.028685633809430733`], {
             RGBColor[
             0.9461566845040007, 0.959364323980197, 0.9760268679356731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.028685633809430733`], {
             RGBColor[
             0.8208667492045488, 0.8600008802541184, 0.9827761974071694]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.028685633809430733`], {
             RGBColor[
             0.8658289704366151, 0.8958525349975854, 0.9870647342065326]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.028685633809430733`], {
             RGBColor[
             0.9950981115840459, 0.9919236812722451, 0.7078378807511541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.028685633809430733`], {
             RGBColor[
             0.9812900682089203, 0.9485491481471018, 0.38181587737614786`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.028685633809430733`], {
             RGBColor[
             0.9933296858906753, 0.9915096679436102, 0.760207897218467]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.028685633809430733`], {
             RGBColor[
             0.7696054106825146, 0.8199408631337204, 0.9776707330315172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.028685633809430733`], {
             RGBColor[
             0.9903873686059662, 0.9902929441322779, 0.8089697090991411]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.028685633809430733`], {
             RGBColor[
             0.9896252762644333, 0.9899777993641742, 0.8215995514300981]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.028685633809430733`], {
             RGBColor[
             0.8560441762635235, 0.8880504057251245, 0.9861314518033143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.028685633809430733`], {
             RGBColor[
             0.9944440319187637, 0.9905246710058049, 0.6366453456969781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.028685633809430733`], {
             RGBColor[
             0.38268957127153075`, 0.5058882049234454, 0.9456056189756892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.028685633809430733`], {
             RGBColor[
             0.9946358192710725, 0.9909348847597176, 0.6575202154214479]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.028685633809430733`], {
             RGBColor[
             0.9497218455748215, 0.8383709024455909, 0.2784032206507784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.028685633809430733`], {
             RGBColor[
             0.9949730197262681, 0.9916561224371852, 0.6942224040094953]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.028685633809430733`], {
             RGBColor[
             0.9931904265856476, 0.987843335957211, 0.5001981415426127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.028685633809430733`], {
             RGBColor[
             0.9431722844587148, 0.9571385633129293, 0.981078678756149]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.028685633809430733`], {
             RGBColor[
             0.9952077053787263, 0.9921580913174339, 0.7197664889676065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.028685633809430733`], {
             RGBColor[
             0.9860887044986558, 0.9885153360532765, 0.8802096979433761]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.028685633809430733`], {
             RGBColor[
             0.9411057473083227, 0.9555973432898109, 0.9845767871125526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.028685633809430733`], {
             RGBColor[
             0.9119506240451302, 0.6886205955938016, 0.24801160920346915`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.028685633809430733`], {
             RGBColor[
             0.9952548719742562, 0.9922589758959982, 0.7249002818125609]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.028685633809430733`], {
             RGBColor[
             0.9504729272464657, 0.9625833707503285, 0.9687205948290808]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.028685633809430733`], {
             RGBColor[
             0.8187788594993523, 0.8583555350814869, 0.9825718828575737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.028685633809430733`], {
             RGBColor[
             0.9861300500153812, 0.9885324334869737, 0.8795244957324689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.028685633809430733`], {
             RGBColor[
             0.8989810629575199, 0.9222871136841762, 0.9902268103863989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.028685633809430733`], {
             RGBColor[
             0.964066166476729, 0.8904488832399745, 0.3149042716075031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.028685633809430733`], {
             RGBColor[
             0.7203011710530286, 0.781424016409066, 0.9727565471995655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.028685633809430733`], {
             RGBColor[
             0.3154426693714862, 0.4476423184251921, 0.9413207058507189]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.028685633809430733`], {
             RGBColor[
             0.9941159983949583, 0.989823040467662, 0.6009409210190085]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.028685633809430733`], {
             RGBColor[
             0.968543419932224, 0.9055517104544626, 0.3322975558237309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.028685633809430733`], {
             RGBColor[
             0.9595166211205104, 0.9693281428339013, 0.9534119800734494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.028685633809430733`], {
             RGBColor[
             0.8658289704366151, 0.8958525349975854, 0.9870647342065326]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.028685633809430733`], {
             RGBColor[
             0.9877529241920022, 0.9892035336649705, 0.8526292707621194]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.028685633809430733`], {
             RGBColor[
             0.9948707542513443, 0.9914373869269488, 0.6830914381733986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.028685633809430733`], {
             RGBColor[
             0.5008412274290204, 0.6056444969238769, 0.9538472025465305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.028685633809430733`], {
             RGBColor[
             0.7904039247123122, 0.8361888203683595, 0.9797437345368432]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.028685633809430733`], {
             RGBColor[
             0.9941053423481931, 0.9898002482611226, 0.5997810760901036]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.028685633809430733`], {
             RGBColor[
             0.9468990966799409, 0.9599180137654248, 0.9747701577739131]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.028685633809430733`], {
             RGBColor[
             0.9932860941727978, 0.9880479592526484, 0.5106109680119997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.028685633809430733`], {
             RGBColor[
             0.9211995634025593, 0.725289558119672, 0.255453522910966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[401, 0.028685633809430733`], {
             RGBColor[
             0.9659221102008808, 0.896709417217848, 0.3221142625102691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[402, 0.028685633809430733`], {
             RGBColor[
             0.9457380875417631, 0.9590521350511498, 0.9767354434051683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[403, 0.028685633809430733`], {
             RGBColor[
             0.8814737500606024, 0.908327257603523, 0.9885569472533281]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[404, 0.028685633809430733`], {
             RGBColor[
             0.821831751830955, 0.16881398807318154`, 0.1685394162497467]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[405, 0.028685633809430733`], {
             RGBColor[
             0.9739815097298934, 0.980116033074698, 0.9289266967049257]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[406, 0.028685633809430733`], {
             RGBColor[
             0.790056490873847, 0.8359174024131556, 0.9797091055787788]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[407, 0.028685633809430733`], {
             RGBColor[
             0.9813312090378503, 0.9486879258234086, 0.38197570172774714`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[408, 0.028685633809430733`], {
             RGBColor[
             0.9241268777090614, 0.9423377038020972, 0.9926252406453347]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[409, 0.028685633809430733`], {
             RGBColor[
             0.7203011710530286, 0.781424016409066, 0.9727565471995655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[410, 0.028685633809430733`], {
             RGBColor[
             0.8369367928384798, 0.872814696838101, 0.984308972514871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[411, 0.028685633809430733`], {
             RGBColor[
             0.9285331543878653, 0.9458511492205812, 0.9930455152484887]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[412, 0.028685633809430733`], {
             RGBColor[
             0.9255983061846358, 0.9435109809276583, 0.9927655868068948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[413, 0.028685633809430733`], {
             RGBColor[
             0.7554619378949603, 0.8088918746977085, 0.9762610438423216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[414, 0.028685633809430733`], {
             RGBColor[
             0.9952047802628202, 0.9921518347902855, 0.7194481081529587]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[415, 0.028685633809430733`], {
             RGBColor[
             0.9929894971661157, 0.9913689911635534, 0.7658457047646162]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[416, 0.028685633809430733`], {
             RGBColor[
             0.970559566822087, 0.9775639536569732, 0.9347191534621938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[417, 0.028685633809430733`], {
             RGBColor[
             0.9681330034164781, 0.975754226642203, 0.9388266923587935]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[418, 0.028685633809430733`], {
             RGBColor[
             0.7325963061973787, 0.7910290694303204, 0.9739820113661838]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[419, 0.028685633809430733`], {
             RGBColor[
             0.9926379604391274, 0.9866616667327001, 0.4400656109197319]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[420, 0.028685633809430733`], {
             RGBColor[
             0.9569122913938991, 0.9673858379879933, 0.9578204309826241]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[421, 0.028685633809430733`], {
             RGBColor[
             0.8709922277373823, 0.8999695762163314, 0.987557210297174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[422, 0.028685633809430733`], {
             RGBColor[
             0.9930237089496222, 0.9913831386152361, 0.7652787269746547]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[423, 0.028685633809430733`], {
             RGBColor[
             0.9945834702197494, 0.9908229154322383, 0.6518223442458183]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[424, 0.028685633809430733`], {
             RGBColor[
             0.9927375859011713, 0.9868747555223326, 0.4509092276461272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[425, 0.028685633809430733`], {
             RGBColor[
             0.7747555359792304, 0.8239641801579167, 0.9781840493904366]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[426, 0.028685633809430733`], {
             RGBColor[
             0.6983579481675971, 0.7642818039162962, 0.9705694518134222]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[427, 0.028685633809430733`], {
             RGBColor[
             0.9856654284383496, 0.9883403005246413, 0.8872244776659807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[428, 0.028685633809430733`], {
             RGBColor[
             0.994271484515129, 0.9901556095566487, 0.6178646256504753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[429, 0.028685633809430733`], {
             RGBColor[
             0.9797047156353299, 0.943201381657895, 0.37565708199646153`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[430, 0.028685633809430733`], {
             RGBColor[
             0.9839885886906158, 0.9576518913746008, 0.39229911987470145`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[431, 0.028685633809430733`], {
             RGBColor[
             0.9928953672895638, 0.9872122339579589, 0.4680827580588004]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[432, 0.028685633809430733`], {
             RGBColor[
             0.9378102309360836, 0.79114531971327, 0.2688188559109187]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[433, 0.028685633809430733`], {
             RGBColor[
             0.9916537228525268, 0.9908166141570504, 0.787982942013895]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[434, 0.028685633809430733`], {
             RGBColor[
             0.9748743388661192, 0.9807819035826215, 0.9274153698644286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[435, 0.028685633809430733`], {
             RGBColor[
             0.9214251301050693, 0.940183403599659, 0.9923675455469874]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[436, 0.028685633809430733`], {
             RGBColor[
             0.9733286128201075, 0.9796291036284003, 0.930031880870407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[437, 0.028685633809430733`], {
             RGBColor[
             0.5376061099177774, 0.6354918847673315, 0.9567414687702475]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[438, 0.028685633809430733`], {
             RGBColor[
             0.9413747557134172, 0.9557979693178695, 0.9841214260513566]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[439, 0.028685633809430733`], {
             RGBColor[
             0.7327112864011673, 0.7911188928394021, 0.9739934715183464]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[440, 0.028685633809430733`], {
             RGBColor[
             0.5500874124086897, 0.6456247684057238, 0.9577240426228496]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[441, 0.028685633809430733`], {
             RGBColor[
             0.9946335315792718, 0.990929991618277, 0.657271214286938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[442, 0.028685633809430733`], {
             RGBColor[
             0.9931816245001254, 0.9914484407536136, 0.7626616576304743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[443, 0.028685633809430733`], {
             RGBColor[
             0.9847792465449773, 0.9879738415378959, 0.9019108050043838]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[444, 0.028685633809430733`], {
             RGBColor[
             0.9604378982226685, 0.9700152297882381, 0.9518524982470467]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[445, 0.028685633809430733`], {
             RGBColor[
             0.3333756140511058, 0.4631749337706715, 0.9424633772282239]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[446, 0.028685633809430733`], {
             RGBColor[
             0.9899037069610742, 0.9900929376125777, 0.8169852342312136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[447, 0.028685633809430733`], {
             RGBColor[
             0.42803053401452, 0.5451602679483732, 0.9484947050282334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[448, 0.028685633809430733`], {
             RGBColor[
             0.9910640099537781, 0.9905727527184875, 0.7977560108742223]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[449, 0.028685633809430733`], {
             RGBColor[
             0.8043544897372197, 0.8470871077940384, 0.9811341964830836]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[450, 0.028685633809430733`], {
             RGBColor[
             0.5901919739299859, 0.6781834581386196, 0.9608812206136554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[451, 0.028685633809430733`], {
             RGBColor[
             0.7758421854528306, 0.824813078985535, 0.9782923564546483]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[452, 0.028685633809430733`], {
             RGBColor[
             0.8801253880061646, 0.9072521103016272, 0.9884283392768789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[453, 0.028685633809430733`], {
             RGBColor[
             0.9678748974905886, 0.9032966272822928, 0.32970047237784755`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[454, 0.028685633809430733`], {
             RGBColor[
             0.9677676917266818, 0.9754817777820959, 0.9394450697610706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[455, 0.028685633809430733`], {
             RGBColor[
             0.9936916912450293, 0.9916593664607488, 0.7542085316569946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[456, 0.028685633809430733`], {
             RGBColor[
             0.7571703113025756, 0.8102264689878564, 0.9764313185379355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[457, 0.028685633809430733`], {
             RGBColor[
             0.9677942367334672, 0.9030245396084757, 0.3293871205679366]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[458, 0.028685633809430733`], {
             RGBColor[
             0.9940311198639266, 0.9896414938723207, 0.5917024167257625]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[459, 0.028685633809430733`], {
             RGBColor[
             0.9737004582585178, 0.9229476116592332, 0.35233167589641085`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[460, 0.028685633809430733`], {
             RGBColor[
             0.9942440863096879, 0.9900970075655937, 0.6148825000703348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[461, 0.028685633809430733`], {
             RGBColor[
             0.9317826962726594, 0.9484422457130515, 0.9933554594543607]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[462, 0.028685633809430733`], {
             RGBColor[
             0.9681307103330677, 0.9757525164643501, 0.9388305739508753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[463, 0.028685633809430733`], {
             RGBColor[
             0.9939616487875964, 0.9917710008421927, 0.7497346365489328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[464, 0.028685633809430733`], {
             RGBColor[
             0.6912229555746355, 0.7587078934747225, 0.9698583024320526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[465, 0.028685633809430733`], {
             RGBColor[
             0.9764744769985929, 0.9819752839818348, 0.9247067533890149]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[466, 0.028685633809430733`], {
             RGBColor[
             0.9376895242084564, 0.9530495296954826, 0.9903595617269428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[467, 0.028685633809430733`], {
             RGBColor[
             0.9225245001100215, 0.9410600114000041, 0.9924724044394789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[468, 0.028685633809430733`], {
             RGBColor[
             0.7758421854528306, 0.824813078985535, 0.9782923564546483]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[469, 0.028685633809430733`], {
             RGBColor[
             0.9907549417647071, 0.9904449450796166, 0.8028780706099615]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[470, 0.028685633809430733`], {
             RGBColor[
             0.9940901378687924, 0.9918241343792861, 0.7476052399544306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[471, 0.028685633809430733`], {
             RGBColor[
             0.9925834939447855, 0.9912010983977264, 0.7725742288447136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[472, 0.028685633809430733`], {
             RGBColor[
             0.9774788640978305, 0.9827243542359132, 0.9230065880161153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[473, 0.028685633809430733`], {
             RGBColor[
             0.99398091653354, 0.9895341140249593, 0.586238094032235]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[474, 0.028685633809430733`], {
             RGBColor[
             0.9874882135394649, 0.9890940690073928, 0.8570162113238722]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[475, 0.028685633809430733`], {
             RGBColor[
             0.976986853642791, 0.9340333949727184, 0.3650987013806191]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[476, 0.028685633809430733`], {
             RGBColor[
             0.9664831537889692, 0.9745237714913877, 0.9416194574284674]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[477, 0.028685633809430733`], {
             RGBColor[
             0.9085910396322898, 0.92994984822877, 0.9911434185405659]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[478, 0.028685633809430733`], {
             RGBColor[
             0.9239985113488276, 0.7363864540325136, 0.25770562212828585`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[479, 0.028685633809430733`], {
             RGBColor[
             0.9489988033300776, 0.9614839715471426, 0.9712159021064328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[480, 0.028685633809430733`], {
             RGBColor[
             0.9300154811142914, 0.7602417341162633, 0.2625470172380107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[481, 0.028685633809430733`], {
             RGBColor[
             0.9880799026749177, 0.9893387476706198, 0.8472103911070209]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[482, 0.028685633809430733`], {
             RGBColor[
             0.8985475427400511, 0.9219414364303594, 0.9901854608410486]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[483, 0.028685633809430733`], {
             RGBColor[
             0.8827339767266522, 0.9093321281390896, 0.9886771487977536]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[484, 0.028685633809430733`], {
             RGBColor[
             0.9951801723255652, 0.9922748916397693, 0.7295405480869586]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[485, 0.028685633809430733`], {
             RGBColor[
             0.5921211284096414, 0.6797496326526229, 0.9610330907210196]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[486, 0.028685633809430733`], {
             RGBColor[
             0.9670008890277272, 0.9749098975847397, 0.9407430667162268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[487, 0.028685633809430733`], {
             RGBColor[
             0.6603192275342505, 0.7345656662525415, 0.9667781076327452]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[488, 0.028685633809430733`], {
             RGBColor[
             0.4395345974338848, 0.5551245094711873, 0.9492277337766715]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[489, 0.028685633809430733`], {
             RGBColor[
             0.9515718554877077, 0.963402949633317, 0.9668603959630466]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[490, 0.028685633809430733`], {
             RGBColor[
             0.9936916912450293, 0.9916593664607488, 0.7542085316569946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[491, 0.028685633809430733`], {
             RGBColor[
             0.9726935208807995, 0.9195509754440501, 0.34841991432814373`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[492, 0.028685633809430733`], {
             RGBColor[
             0.9526148603882783, 0.9641808209803987, 0.9650948607256261]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[493, 0.028685633809430733`], {
             RGBColor[
             0.9732771683354695, 0.9215197553555913, 0.35068727447696324`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[494, 0.028685633809430733`], {
             RGBColor[
             0.9572086757849193, 0.9676068809815312, 0.9573187295180563]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[495, 0.028685633809430733`], {
             RGBColor[
             0.9420558984844262, 0.9563059644812191, 0.982968429010525]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[496, 0.028685633809430733`], {
             RGBColor[
             0.6413502728973731, 0.7197160698954495, 0.9649085893073921]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[497, 0.028685633809430733`], {
             RGBColor[
             0.9868485829633816, 0.9888295653264264, 0.8676165452804411]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[498, 0.028685633809430733`], {
             RGBColor[
             0.9857077936488978, 0.963451173387407, 0.39897790649301307`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[499, 0.028685633809430733`], {
             RGBColor[
             0.8480342444622402, 0.8816635035305879, 0.9853674573575573]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[500, 0.028685633809430733`], {
             RGBColor[
             0.7655797279592382, 0.816795969193975, 0.977269490599805]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1dOWGAgQBNBMbNu2bds2J+bEtm3btm3btu01sjdnH271F1R1ssCg6p0C
ggUL9l38vMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEIS
kZgkJCUZyUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpR
mCIUpRjFKUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGY
JjSlGYE0pwUtaUVr2tCWdrSnAx3pRBCd6UJXutGdHvSkF73pQ1/60Z8BDGQQ
gxnCUIYxnBGMZBSjGcNYxjGeCUxkEpOZwlSmMZ0ZzGQWs5nDXOYxnwUsZBGL
WcJSlrGcFaxkFatZw1rWsZ4NbGQTm9nCVraxnR3sZBe72cNe9rGfAxzkEIc5
wlGOcZwTnOQUpznDWc5xngtc5BKXucJVrnGdG9zkFre5w13ucZ8HPOQRj3nC
U57xnBe85BWvecNb3vGeD3zkE5/5wle+8Z1f+JXf+J0/+JO/+Jt/+Jcf/Cx/
AMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEISkZgkJCUZ
yUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpRmCIUpRjF
KUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGYJjSlGYE0
pwUtaUVr2tCWdrSnAx35Od5BdKYLXelGd3rQk170pg996Ud/BjCQQQxmCEMZ
xnBGMJJRjGYMYxnHeCYwkUlMZgpTmcZ0ZjCTWcxmDnOZx3wWsJBFLGYJS1nG
clawklWsZg1rWcd6NrCRTWxmC1vZxnZ2sJNd7GYPe9nHfg5wkEMc5ghHOcZx
TnCSU5zmDGc5x3kucJFLXOYKV7nGdW5wk1vc5g53ucd9HvCQRzzmCU95xnNe
8JJXvOYNb3nHez7wkU985gtf+Rbw/z//Dz189+A=
          "], {Null, CompressedData["
1:eJxF3Al0ldW5gOF/21YsVqt2QFCqdkClVEWUGRVRJmWoghGKIgREKWUqk4DM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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[13, 59] -> 
             RGBColor[
              0.2579706137078198, 0.3884738496614871, 0.938002416866113], 
             UndirectedEdge[210, 309] -> 
             RGBColor[
              0.1918597924354573, 0.31898718483606625`, 0.9342375033968474], 
             UndirectedEdge[88, 427] -> 
             RGBColor[
              0.18803656473244668`, 0.3149687301135649, 0.9340197762351194], 
             UndirectedEdge[293, 483] -> 
             RGBColor[
              0.630894839609411, 0.7086289993280623, 0.9658482385387919], 
             UndirectedEdge[46, 150] -> 
             RGBColor[
              0.2095354252082916, 0.3375653955801614, 0.935244104534505], 
             UndirectedEdge[400, 444] -> 
             RGBColor[
              0.7778662305017423, 0.8242556583288213, 0.8882685536457314], 
             UndirectedEdge[98, 105] -> 
             RGBColor[
              0.18986356428247403`, 0.31688902247910566`, 0.93412382115669], 
             UndirectedEdge[128, 439] -> 
             RGBColor[
              0.1967431917255388, 0.32411994711534, 0.9345156057620757], 
             UndirectedEdge[23, 62] -> 
             RGBColor[
              0.34157168432943963`, 0.4649528057928196, 0.943180457023785], 
             UndirectedEdge[201, 236] -> 
             RGBColor[
              0.2329055510975478, 0.36212887964133295`, 0.9365749986308951], 
             UndirectedEdge[40, 477] -> 
             RGBColor[
              0.19140125749096676`, 0.31850523553661203`, 0.9342113905101004],
              UndirectedEdge[455, 482] -> 
             RGBColor[
              0.47270830175216416`, 0.5795209528723455, 0.952539845619061], 
             UndirectedEdge[60, 131] -> 
             RGBColor[
              0.9096110781982166, 0.6242662481872688, 0.5350082437658015], 
             UndirectedEdge[179, 222] -> 
             RGBColor[
              0.19860716321184355`, 0.3260790993300644, 0.9346217561807222], 
             UndirectedEdge[111, 175] -> 
             RGBColor[
              0.38213445941917534`, 0.5054073949376681, 0.9455702477393233], 
             UndirectedEdge[51, 110] -> 
             RGBColor[
              0.7061642122935256, 0.763962913869964, 0.8362189440457062], 
             UndirectedEdge[84, 261] -> 
             RGBColor[
              0.30240410894972447`, 0.4332765821863486, 0.9406023955782863], 
             UndirectedEdge[156, 479] -> 
             RGBColor[
              0.19085648891639362`, 0.317932649224413, 0.9341803667456914], 
             UndirectedEdge[158, 437] -> 
             RGBColor[
              0.1868134400454955, 0.31368314851699497`, 0.9339501210936485], 
             UndirectedEdge[103, 355] -> 
             RGBColor[
              0.48475696898891374`, 0.5914050668107322, 0.9529074440237885], 
             UndirectedEdge[13, 228] -> 
             RGBColor[
              0.2555809934244899, 0.38596220723303065`, 0.9378663315261038], 
             UndirectedEdge[59, 409] -> 
             RGBColor[
              0.2581147666270732, 0.38862536351944543`, 0.9380106261616092], 
             UndirectedEdge[243, 430] -> 
             RGBColor[
              0.19906776015361727`, 0.3265632159194014, 0.934647986495164], 
             UndirectedEdge[333, 441] -> 
             RGBColor[
              0.2266279051671714, 0.35553067574276653`, 0.936217495982105], 
             UndirectedEdge[179, 385] -> 
             RGBColor[
              0.19083377116116018`, 0.3179087714232738, 0.9341790730031387], 
             UndirectedEdge[81, 447] -> 
             RGBColor[
              0.23604325092602435`, 0.36542680110272124`, 0.936753685994316], 
             UndirectedEdge[69, 404] -> 
             RGBColor[
              0.6398415718326245, 0.7153643102811339, 0.9668689392230831], 
             UndirectedEdge[113, 380] -> 
             RGBColor[
              0.19209288530033616`, 0.3192321802159951, 0.9342507776906723], 
             UndirectedEdge[85, 489] -> 
             RGBColor[
              0.18944536571522486`, 0.31644946926960615`, 0.9341000053669545],
              UndirectedEdge[277, 498] -> 
             RGBColor[
              0.6089064489917588, 0.6910771522369943, 0.9638150835884631], 
             UndirectedEdge[18, 160] -> 
             RGBColor[
              0.26388110219154026`, 0.3946861478044915, 0.9383390104414766], 
             UndirectedEdge[355, 431] -> 
             RGBColor[
              0.49048091648110803`, 0.596362862434505, 0.9532721688965031], 
             UndirectedEdge[357, 492] -> 
             RGBColor[
              0.1855765306994534, 0.3123830783697226, 0.9338796809362347], 
             UndirectedEdge[165, 386] -> 
             RGBColor[
              0.3057645176630249, 0.43870827302694076`, 0.9407242089916171], 
             UndirectedEdge[218, 274] -> 
             RGBColor[
              0.26498050169023135`, 0.3958416863835701, 0.9384016196165113], 
             UndirectedEdge[116, 441] -> 
             RGBColor[
              0.24897326082313725`, 0.37901706131456436`, 0.9374900309297209],
              UndirectedEdge[258, 435] -> 
             RGBColor[
              0.32678964542360633`, 0.4509663941385996, 0.942281872262574], 
             UndirectedEdge[112, 445] -> 
             RGBColor[
              0.9782801480279448, 0.9394045757914982, 0.5347896078268422], 
             UndirectedEdge[114, 179] -> 
             RGBColor[
              0.19077318734493098`, 0.3178450939911811, 0.9341756228444302], 
             UndirectedEdge[155, 467] -> 
             RGBColor[
              0.19253479608250443`, 0.31969665646681583`, 0.9342759438559683],
              UndirectedEdge[243, 421] -> 
             RGBColor[
              0.1904580230623436, 0.31751383634761216`, 0.9341576747047806], 
             UndirectedEdge[172, 289] -> 
             RGBColor[
              0.2167825321958998, 0.3451825645172597, 0.9356568165563153], 
             UndirectedEdge[381, 468] -> 
             RGBColor[
              0.20490029607601296`, 0.33269358097797563`, 0.9349801407874807],
              UndirectedEdge[17, 277] -> 
             RGBColor[
              0.4093350243660927, 0.5289671571545423, 0.9473034436852257], 
             UndirectedEdge[279, 477] -> 
             RGBColor[
              0.2028882707819582, 0.3305788148241523, 0.9348655589235091], 
             UndirectedEdge[4, 405] -> 
             RGBColor[
              0.18158563263707392`, 0.3081883914686098, 0.9336524051955868], 
             UndirectedEdge[36, 379] -> 
             RGBColor[
              0.9107780137599082, 0.6018218600251894, 0.4604073756146171], 
             UndirectedEdge[278, 401] -> 
             RGBColor[
              0.18259570595575553`, 0.30925004256889155`, 0.9337099273768162],
              UndirectedEdge[152, 399] -> 
             RGBColor[
              0.19605719925809356`, 0.3233989255376204, 0.9344765395058896], 
             UndirectedEdge[173, 406] -> 
             RGBColor[
              0.5685496786155626, 0.658415121806283, 0.9602730898835382], 
             UndirectedEdge[239, 332] -> 
             RGBColor[
              0.1916360269785587, 0.31875199315331637`, 0.9342247602851084], 
             UndirectedEdge[116, 361] -> 
             RGBColor[
              0.25328984688463263`, 0.3835540669525598, 0.9377358541201064], 
             UndirectedEdge[288, 498] -> 
             RGBColor[
              0.7429048622719281, 0.7990821917836863, 0.9750094718967612], 
             UndirectedEdge[16, 386] -> 
             RGBColor[
              0.2878595743491687, 0.4198890423651035, 0.9397045489578829], 
             UndirectedEdge[216, 464] -> 
             RGBColor[
              0.20118455785762748`, 0.32878810451904233`, 0.9347685349928858],
              UndirectedEdge[379, 400] -> 
             RGBColor[
              0.9086464403656656, 0.6009403996477325, 0.49573306309233295`], 
             UndirectedEdge[22, 24] -> 
             RGBColor[
              0.18354454614871424`, 0.31024733377163405`, 0.9337639624221219],
              UndirectedEdge[231, 355] -> 
             RGBColor[
              0.6616838941423232, 0.7343656744943371, 0.9677797504415411], 
             UndirectedEdge[434, 495] -> 
             RGBColor[
              0.9105859845179732, 0.6779864914594717, 0.24664336835265455`], 
             UndirectedEdge[75, 323] -> 
             RGBColor[
              0.9290142282590157, 0.73628865839294, 0.4899032009526938], 
             UndirectedEdge[165, 288] -> 
             RGBColor[
              0.508574991950541, 0.6066055037109249, 0.956292599133973], 
             UndirectedEdge[90, 229] -> 
             RGBColor[
              0.24859585520259658`, 0.3786203840784777, 0.9374685382379528], 
             UndirectedEdge[267, 424] -> 
             RGBColor[
              0.21136439475697272`, 0.3394877585391924, 0.9353482616445844], 
             UndirectedEdge[258, 403] -> 
             RGBColor[
              0.5792948267817268, 0.6667531924094637, 0.9613678188204143], 
             UndirectedEdge[274, 305] -> 
             RGBColor[
              0.2773195143815185, 0.4086435488273039, 0.9391104309604698], 
             UndirectedEdge[399, 478] -> 
             RGBColor[
              0.22859634417905478`, 0.3575996299504977, 0.9363295956717873], 
             UndirectedEdge[359, 463] -> 
             RGBColor[
              0.7323426131107887, 0.7902188270608363, 0.9746779559842911], 
             UndirectedEdge[302, 422] -> 
             RGBColor[
              0.22565049031831835`, 0.3545033507649412, 0.9361618336524187], 
             UndirectedEdge[21, 335] -> 
             RGBColor[
              0.2551889465783416, 0.385550141140523, 0.9378440050381969], 
             UndirectedEdge[266, 445] -> 
             RGBColor[
              0.9783510953842744, 0.9379685313127405, 0.42709594933440853`], 
             UndirectedEdge[200, 452] -> 
             RGBColor[
              0.24489188267224044`, 0.3747272741036509, 0.9372576024818854], 
             UndirectedEdge[112, 471] -> 
             RGBColor[
              0.9751390722082593, 0.9794426669377387, 0.8581518289048162], 
             UndirectedEdge[481, 496] -> 
             RGBColor[
              0.19554201050297132`, 0.3228574294911333, 0.934447200268439], 
             UndirectedEdge[6, 422] -> 
             RGBColor[
              0.21046728026605566`, 0.33854483432889454`, 0.9352971723014887],
              UndirectedEdge[137, 424] -> 
             RGBColor[
              0.20256381379959026`, 0.3302377899639228, 0.9348470815783543], 
             UndirectedEdge[89, 482] -> 
             RGBColor[
              0.3210267437424298, 0.45247896298156487`, 0.9416765181318323], 
             UndirectedEdge[142, 254] -> 
             RGBColor[
              0.20407108545370353`, 0.33182202803893834`, 0.9349329184692474],
              UndirectedEdge[178, 321] -> 
             RGBColor[
              0.7273722693999012, 0.7841453015250835, 0.9212028178095601], 
             UndirectedEdge[151, 456] -> 
             RGBColor[
              0.19966233325078292`, 0.32718814994263423`, 0.9346818465534554],
              UndirectedEdge[346, 431] -> 
             RGBColor[
              0.43133365387154704`, 0.5480212643488988, 0.948705176904689], 
             UndirectedEdge[65, 297] -> 
             RGBColor[
              0.18922089119532, 0.3162135323166796, 0.9340872218751262], 
             UndirectedEdge[79, 253] -> 
             RGBColor[
              0.6318697246341356, 0.7067600197693191, 0.967143342848597], 
             UndirectedEdge[376, 475] -> 
             RGBColor[
              0.3538187512223421, 0.4808817516864462, 0.9437659958516187], 
             UndirectedEdge[209, 259] -> 
             RGBColor[
              0.8388746662508497, 0.8722406233791922, 0.8551373469793608], 
             UndirectedEdge[464, 496] -> 
             RGBColor[
              0.1941346337620407, 0.32137818730357604`, 0.9343670522450702], 
             UndirectedEdge[101, 103] -> 
             RGBColor[
              0.32745764009317235`, 0.4521656087003331, 0.9423017119454735], 
             UndirectedEdge[69, 348] -> 
             RGBColor[
              0.4524683198594424, 0.5660891289103882, 0.9501175973747447], 
             UndirectedEdge[116, 277] -> 
             RGBColor[
              0.35985275808300965`, 0.4831247951827711, 0.9442597110251651], 
             UndirectedEdge[171, 471] -> 
             RGBColor[
              0.7137657491152036, 0.7742498659419835, 0.9547112060503897], 
             UndirectedEdge[133, 429] -> 
             RGBColor[
              0.19496484613925177`, 0.3222507931505298, 0.9344143316117632], 
             UndirectedEdge[37, 203] -> 
             RGBColor[
              0.8534629031399862, 0.4065189709815528, 0.1986169775584265], 
             UndirectedEdge[299, 399] -> 
             RGBColor[
              0.22397618806162217`, 0.3527435529362591, 0.936066484615808], 
             UndirectedEdge[311, 429] -> 
             RGBColor[
              0.19096685764878327`, 0.3180486537599364, 0.934186652081725], 
             UndirectedEdge[327, 446] -> 
             RGBColor[
              0.18359313787334597`, 0.31029840675511533`, 0.9337667296489547],
              UndirectedEdge[15, 249] -> 
             RGBColor[
              0.6896781375343781, 0.7575010698806214, 0.9697043294069452], 
             UndirectedEdge[50, 242] -> 
             RGBColor[
              0.9267381119467066, 0.943455029677774, 0.9594240314227456], 
             UndirectedEdge[163, 355] -> 
             RGBColor[
              0.7295091887885554, 0.6445510453124249, 0.5980872339837272], 
             UndirectedEdge[192, 435] -> 
             RGBColor[
              0.2756938897780267, 0.40670981874574946`, 0.9390260958950403], 
             UndirectedEdge[31, 191] -> 
             RGBColor[
              0.1912888055455656, 0.31838704141213026`, 0.9342049865381675], 
             UndirectedEdge[385, 415] -> 
             RGBColor[
              0.18097729894859016`, 0.30754899419142984`, 0.9336177614919767],
              UndirectedEdge[207, 257] -> 
             RGBColor[
              0.9190198138450048, 0.7061284902521469, 0.2641826298296307], 
             UndirectedEdge[359, 408] -> 
             RGBColor[
              0.923405109023163, 0.9417213092494618, 0.9911392082523272], 
             UndirectedEdge[183, 202] -> 
             RGBColor[
              0.19186250689715728`, 0.31899003790741964`, 0.9342376579814256],
              UndirectedEdge[170, 223] -> 
             RGBColor[
              0.19795986022643686`, 0.3253987428510222, 0.9345848932333021], 
             UndirectedEdge[40, 430] -> 
             RGBColor[
              0.1932824749084014, 0.32048251431840913`, 0.9343185230590114], 
             UndirectedEdge[69, 444] -> 
             RGBColor[
              0.5043601503383525, 0.6082172545934901, 0.9542027123560828], 
             UndirectedEdge[215, 417] -> 
             RGBColor[
              0.1910469226092748, 0.31813280710982467`, 0.9341912116627795], 
             UndirectedEdge[423, 429] -> 
             RGBColor[
              0.18557451474248365`, 0.3123809594711283, 0.9338795661304677], 
             UndirectedEdge[5, 83] -> 
             RGBColor[
              0.8424015657306109, 0.8748578438487853, 0.849230453036272], 
             UndirectedEdge[311, 366] -> 
             RGBColor[
              0.18627071422588198`, 0.31311270926977675`, 0.9339192136611123],
              UndirectedEdge[133, 366] -> 
             RGBColor[
              0.1902687027163505, 0.3173148486603702, 0.9341468931911505], 
             UndirectedEdge[76, 359] -> 
             RGBColor[
              0.6599771175433797, 0.7303046973046542, 0.9693028506052312], 
             UndirectedEdge[172, 218] -> 
             RGBColor[
              0.25468436170219366`, 0.3850197904431626, 0.9378152696759667], 
             UndirectedEdge[177, 484] -> 
             RGBColor[
              0.18459712642978363`, 0.31135366238448237`, 0.9338239053119759],
              UndirectedEdge[45, 328] -> 
             RGBColor[
              0.22208190708084125`, 0.3507525435211073, 0.9359586081162901], 
             UndirectedEdge[115, 144] -> 
             RGBColor[
              0.1939326542641488, 0.3211658940450518, 0.9343555498114672], 
             UndirectedEdge[63, 72] -> 
             RGBColor[
              0.20896361604647165`, 0.3369643878962938, 0.9352115408486552], 
             UndirectedEdge[248, 387] -> 
             RGBColor[
              0.18458186461527748`, 0.3113376212497815, 0.9338230361742175], 
             UndirectedEdge[34, 44] -> 
             RGBColor[
              0.24396970740458573`, 0.37375800942805687`, 0.9372050859646285],
              UndirectedEdge[279, 285] -> 
             RGBColor[
              0.2111852622032374, 0.3392994788675566, 0.935338060310652], 
             UndirectedEdge[13, 77] -> 
             RGBColor[
              0.293706622672794, 0.4236564919439787, 0.9401246061243856], 
             UndirectedEdge[53, 445] -> 
             RGBColor[
              0.897896740106011, 0.5697053012801583, 0.24507330073286251`], 
             UndirectedEdge[91, 298] -> 
             RGBColor[
              0.368006349252357, 0.4899237097604318, 0.9448344889260978], 
             UndirectedEdge[6, 451] -> 
             RGBColor[
              0.20974058048916117`, 0.3377810267879514, 0.9352557878242505], 
             UndirectedEdge[87, 256] -> 
             RGBColor[
              0.30998490234108894`, 0.4428842197606874, 0.9409740715208748], 
             UndirectedEdge[153, 172] -> 
             RGBColor[
              0.22556462734887084`, 0.3544131033400252, 0.9361569438833315], 
             UndirectedEdge[72, 438] -> 
             RGBColor[
              0.20687895912531873`, 0.33477328129727923`, 0.9350928227209692],
              UndirectedEdge[207, 440] -> 
             RGBColor[
              0.8833097581290331, 0.5630186900098979, 0.22434314065434907`], 
             UndirectedEdge[19, 228] -> 
             RGBColor[
              0.2307172081494932, 0.3598287924539709, 0.9364503757373667], 
             UndirectedEdge[8, 63] -> 
             RGBColor[
              0.20214886588846875`, 0.32980165340011697`, 0.9348234509086764],
              UndirectedEdge[72, 128] -> 
             RGBColor[
              0.20268608388741163`, 0.33036630357859437`, 0.9348540446789733],
              UndirectedEdge[229, 485] -> 
             RGBColor[
              0.2450928096239232, 0.3749384610693741, 0.9372690449745389], 
             UndirectedEdge[32, 407] -> 
             RGBColor[
              0.24840100008144717`, 0.3784155789916214, 0.9374574415270658], 
             UndirectedEdge[475, 478] -> 
             RGBColor[
              0.2929211568634166, 0.42264039555989485`, 0.9400868509528724], 
             UndirectedEdge[194, 412] -> 
             RGBColor[
              0.18818134565428368`, 0.3151209040420562, 0.934028021294434], 
             UndirectedEdge[370, 390] -> 
             RGBColor[
              0.24233683264276484`, 0.3720417545231436, 0.9371120961625645], 
             UndirectedEdge[231, 233] -> 
             RGBColor[
              0.8631076739966228, 0.8934453053740385, 0.9626713381948079], 
             UndirectedEdge[114, 385] -> 
             RGBColor[
              0.18149489941754873`, 0.3080930251020705, 0.9336472380729627], 
             UndirectedEdge[271, 442] -> 
             RGBColor[
              0.22300003138538366`, 0.3517175503776244, 0.9360108939371906], 
             UndirectedEdge[206, 254] -> 
             RGBColor[
              0.18642186112422848`, 0.31327157424320573`, 0.9339278212533714],
              UndirectedEdge[262, 455] -> 
             RGBColor[
              0.47810598768171675`, 0.5841961571289409, 0.9528837813935058], 
             UndirectedEdge[7, 341] -> 
             RGBColor[
              0.7333256796265153, 0.7863640981896829, 0.7861411597228827], 
             UndirectedEdge[187, 328] -> 
             RGBColor[
              0.2321163718921772, 0.36129940225963686`, 0.9365300560426353], 
             UndirectedEdge[44, 56] -> 
             RGBColor[
              0.342928946455201, 0.46870029922168843`, 0.9431727706647948], 
             UndirectedEdge[142, 388] -> 
             RGBColor[
              0.27220031221012625`, 0.4015863957278337, 0.9388802865699359], 
             UndirectedEdge[282, 419] -> 
             RGBColor[
              0.6729998707802133, 0.7444718811327458, 0.9680419956441542], 
             UndirectedEdge[7, 244] -> 
             RGBColor[
              0.45953784870192455`, 0.5719334474988196, 0.9506451367617185], 
             UndirectedEdge[107, 470] -> 
             RGBColor[
              0.20295018288856098`, 0.3306438883736461, 0.9348690847263893], 
             UndirectedEdge[10, 383] -> 
             RGBColor[
              0.24728065527257528`, 0.3772380255635335, 0.9373936395476021], 
             UndirectedEdge[249, 419] -> 
             RGBColor[
              0.6881180325530365, 0.7562823040119602, 0.9695488327224149], 
             UndirectedEdge[191, 271] -> 
             RGBColor[
              0.19934619168565726`, 0.3268558651131542, 0.9346638427590112], 
             UndirectedEdge[297, 490] -> 
             RGBColor[
              0.20561521715269282`, 0.3334450083581805, 0.9350208544851668], 
             UndirectedEdge[32, 176] -> 
             RGBColor[
              0.26830294791528575`, 0.39857679935889445`, 0.938618545077043], 
             UndirectedEdge[353, 487] -> 
             RGBColor[
              0.18672390467583372`, 0.3135890411666101, 0.933945022186802], 
             UndirectedEdge[281, 324] -> 
             RGBColor[
              0.8790783466018638, 0.5485966593380001, 0.5760884806324713], 
             UndirectedEdge[19, 59] -> 
             RGBColor[
              0.2331068284328231, 0.3623404348824274, 0.936586461077376], 
             UndirectedEdge[197, 411] -> 
             RGBColor[
              0.25605149674669436`, 0.3864567360563011, 0.937893125994256], 
             UndirectedEdge[163, 343] -> 
             RGBColor[
              0.8727695735845509, 0.4960098594094768, 0.21479835234035222`], 
             UndirectedEdge[12, 396] -> 
             RGBColor[
              0.19573690002635402`, 0.32306227073691796`, 0.9344582989384823],
              UndirectedEdge[51, 397] -> 
             RGBColor[
              0.9086311282442023, 0.5812180792787432, 0.4466755411222336], 
             UndirectedEdge[448, 482] -> 
             RGBColor[
              0.3164780231838319, 0.4477844619968153, 0.9414143083027866], 
             UndirectedEdge[183, 285] -> 
             RGBColor[
              0.20567627769071223`, 0.33350918685510056`, 0.935024331792476], 
             UndirectedEdge[155, 365] -> 
             RGBColor[
              0.200483284293693, 0.3280510215400352, 0.934728598500861], 
             UndirectedEdge[122, 217] -> 
             RGBColor[
              0.1834604918576584, 0.31015898738238445`, 0.9337591756545935], 
             UndirectedEdge[249, 269] -> 
             RGBColor[
              0.6644117978227214, 0.7371426324130581, 0.9676100378285277], 
             UndirectedEdge[101, 331] -> 
             RGBColor[
              0.2732729587475753, 0.4045575845229832, 0.9388738627783362], 
             UndirectedEdge[246, 458] -> 
             RGBColor[
              0.2394606076875042, 0.3690186597319697, 0.9369482994063559], 
             UndirectedEdge[35, 437] -> 
             RGBColor[
              0.18478436843582058`, 0.31155046560465605`, 0.9338345684672199],
              UndirectedEdge[354, 473] -> 
             RGBColor[
              0.28709080979716467`, 0.41891074115277027`, 0.9396670037727628],
              UndirectedEdge[230, 484] -> 
             RGBColor[
              0.19535510076833423`, 0.3226609755092681, 0.9344365560355595], 
             UndirectedEdge[108, 190] -> 
             RGBColor[
              0.21307880253974895`, 0.34128970981862183`, 0.9354458946315745],
              UndirectedEdge[55, 136] -> 
             RGBColor[
              0.5509076978824959, 0.6462907131067992, 0.9577886185001523], 
             UndirectedEdge[59, 279] -> 
             RGBColor[
              0.23548934775412372`, 0.36484461374956423`, 0.9367221420281024],
              UndirectedEdge[24, 170] -> 
             RGBColor[
              0.18651291707157386`, 0.3133672798171463, 0.9339330067548675], 
             UndirectedEdge[184, 388] -> 
             RGBColor[
              0.43476172806913593`, 0.5486141843644792, 0.9495801910661066], 
             UndirectedEdge[173, 242] -> 
             RGBColor[
              0.8468550508642396, 0.8805617516174773, 0.9515915409041512], 
             UndirectedEdge[4, 345] -> 
             RGBColor[
              0.18617654721563465`, 0.31301373377147346`, 0.9339138509891864],
              UndirectedEdge[59, 256] -> 
             RGBColor[
              0.28727672509446966`, 0.4190164856928953, 0.9396808744204175], 
             UndirectedEdge[232, 480] -> 
             RGBColor[
              0.2609103808391443, 0.3915637313085108, 0.9381698322552461], 
             UndirectedEdge[3, 437] -> 
             RGBColor[
              0.18278910615931465`, 0.30945331844511326`, 0.9337209412322989],
              UndirectedEdge[199, 448] -> 
             RGBColor[
              0.3433591771132972, 0.47106756644443715`, 0.943127151661101], 
             UndirectedEdge[151, 226] -> 
             RGBColor[
              0.19534643528489967`, 0.3226518675367549, 0.9344360625490973], 
             UndirectedEdge[241, 442] -> 
             RGBColor[
              0.22676711964941848`, 0.35567699899031613`, 0.9362254240409197],
              UndirectedEdge[303, 400] -> 
             RGBColor[
              0.9153331914929417, 0.6523376989650047, 0.5021363035234178], 
             UndirectedEdge[42, 378] -> 
             RGBColor[
              0.20375715237687997`, 0.3314920644706901, 0.9349150404449447], 
             UndirectedEdge[15, 499] -> 
             RGBColor[
              0.6404896932769727, 0.7188634972449458, 0.9649460740899308], 
             UndirectedEdge[341, 374] -> 
             RGBColor[
              0.9208708140731814, 0.677947066838142, 0.406871876564454], 
             UndirectedEdge[312, 334] -> 
             RGBColor[
              0.19091202731972692`, 0.3179910236076545, 0.9341835295755994], 
             UndirectedEdge[7, 482] -> 
             RGBColor[
              0.4023630118874444, 0.5224114775409715, 0.9470020067176228], 
             UndirectedEdge[219, 403] -> 
             RGBColor[
              0.7064676273124759, 0.7706171469001197, 0.9713777488413233], 
             UndirectedEdge[50, 449] -> 
             RGBColor[
              0.9319849870644814, 0.931902676711367, 0.6896331946772748], 
             UndirectedEdge[318, 430] -> 
             RGBColor[
              0.1997685243379237, 0.32729976350812295`, 0.9346878939787725], 
             UndirectedEdge[242, 449] -> 
             RGBColor[
              0.9783597736506789, 0.9679158712997968, 0.6606061921458748], 
             UndirectedEdge[356, 365] -> 
             RGBColor[
              0.2261799618783253, 0.3550598589449443, 0.9361919862744781], 
             UndirectedEdge[154, 219] -> 
             RGBColor[
              0.8264967277029731, 0.8644743578312362, 0.9402829367923042], 
             UndirectedEdge[69, 275] -> 
             RGBColor[
              0.46608428308489896`, 0.5771431812489669, 0.9511894958767693], 
             UndirectedEdge[173, 310] -> 
             RGBColor[
              0.682704924474264, 0.7520535428396782, 0.9690093046974939], 
             UndirectedEdge[351, 460] -> 
             RGBColor[
              0.2704319943298352, 0.4015715507923906, 0.9387120740575761], 
             UndirectedEdge[97, 207] -> 
             RGBColor[
              0.9317219029437263, 0.7489756193744845, 0.31352784738991035`], 
             UndirectedEdge[122, 212] -> 
             RGBColor[
              0.18381215152445518`, 0.3105286039886985, 0.9337792021523836], 
             UndirectedEdge[45, 224] -> 
             RGBColor[
              0.20355580866569664`, 0.3312804394643078, 0.9349035742184542], 
             UndirectedEdge[144, 215] -> 
             RGBColor[
              0.19092068807717077`, 0.3180001266128517, 0.9341840227929235], 
             UndirectedEdge[22, 214] -> 
             RGBColor[
              0.1846717285967103, 0.31143207399197287`, 0.9338281537950183], 
             UndirectedEdge[142, 150] -> 
             RGBColor[
              0.2155365862389103, 0.34387299631892737`, 0.9355858617772765], 
             UndirectedEdge[149, 419] -> 
             RGBColor[
              0.6052079656077549, 0.6902679989364768, 0.962135887741037], 
             UndirectedEdge[11, 418] -> 
             RGBColor[
              0.4260394736081712, 0.5428061221897597, 0.9485417938214956], 
             UndirectedEdge[189, 346] -> 
             RGBColor[
              0.346693677388048, 0.46946123011413, 0.9435041892031641], 
             UndirectedEdge[185, 224] -> 
             RGBColor[
              0.2087376164930067, 0.33672684803640285`, 0.9351986705084218], 
             UndirectedEdge[17, 386] -> 
             RGBColor[
              0.34052296335874593`, 0.4690749660172503, 0.9429294418511679], 
             UndirectedEdge[194, 476] -> 
             RGBColor[
              0.18476853282621936`, 0.3115338213749295, 0.9338336666526799], 
             UndirectedEdge[258, 471] -> 
             RGBColor[
              0.686008715672987, 0.7506799404061069, 0.9528121866762553], 
             UndirectedEdge[203, 397] -> 
             RGBColor[
              0.8335404053549352, 0.2588118298231834, 0.1797516360873429], 
             UndirectedEdge[126, 173] -> 
             RGBColor[
              0.6045267350947843, 0.6886225535376819, 0.9628291330052186], 
             UndirectedEdge[30, 366] -> 
             RGBColor[
              0.1807454038963133, 0.3073052577884914, 0.9336045554118075], 
             UndirectedEdge[95, 368] -> 
             RGBColor[
              0.1819562792912616, 0.3085779646025163, 0.9336735129742202], 
             UndirectedEdge[15, 242] -> 
             RGBColor[
              0.8127597142986478, 0.8539262155582815, 0.9481932363943286], 
             UndirectedEdge[150, 392] -> 
             RGBColor[
              0.22610554162039614`, 0.3549816385353439, 0.9361877481508839], 
             UndirectedEdge[179, 296] -> 
             RGBColor[
              0.19117065430032437`, 0.31826285696216006`, 0.9341982579995401],
              UndirectedEdge[3, 123] -> 
             RGBColor[
              0.1847525458331286, 0.3115170180315573, 0.933832756217074], 
             UndirectedEdge[37, 257] -> 
             RGBColor[
              0.9124536887252621, 0.6763132496408797, 0.2587036940792628], 
             UndirectedEdge[17, 178] -> 
             RGBColor[
              0.4223764301651894, 0.5398287637649369, 0.9482544022825725], 
             UndirectedEdge[68, 367] -> 
             RGBColor[
              0.19128856344294365`, 0.31838678694692435`, 0.9342049727507814],
              UndirectedEdge[1, 363] -> 
             RGBColor[
              0.19094550353876433`, 0.3180262092363777, 0.93418543599675], 
             UndirectedEdge[227, 329] -> 
             RGBColor[
              0.18736891797604732`, 0.31426699104133987`, 0.9339817547400375],
              UndirectedEdge[121, 420] -> 
             RGBColor[
              0.1965885249531354, 0.3239573825311042, 0.9345067977181964], 
             UndirectedEdge[82, 149] -> 
             RGBColor[
              0.540625880408879, 0.6379434704911183, 0.9569791961650909], 
             UndirectedEdge[129, 355] -> 
             RGBColor[
              0.4245428223807357, 0.5374596923522321, 0.9491362257297418], 
             UndirectedEdge[87, 388] -> 
             RGBColor[
              0.3185501109900676, 0.45030297299252864`, 0.941519839042071], 
             UndirectedEdge[91, 228] -> 
             RGBColor[
              0.35927043823642757`, 0.48074171339394056`, 0.9443369917173629],
              UndirectedEdge[12, 161] -> 
             RGBColor[
              0.20394297282787943`, 0.33168737354638755`, 0.9349256226447324],
              UndirectedEdge[64, 115] -> 
             RGBColor[
              0.18789626990443398`, 0.31482127135411775`, 0.9340117866522119],
              UndirectedEdge[56, 342] -> 
             RGBColor[
              0.4415801835206408, 0.5562719260910596, 0.9495305912404275], 
             UndirectedEdge[378, 416] -> 
             RGBColor[
              0.2080965578112694, 0.3360530547164289, 0.9351621631648581], 
             UndirectedEdge[119, 363] -> 
             RGBColor[
              0.18346622269800678`, 0.3101650108589469, 0.9337595020174734], 
             UndirectedEdge[391, 455] -> 
             RGBColor[
              0.5430796704315681, 0.6399355677735181, 0.9571723675042059], 
             UndirectedEdge[249, 282] -> 
             RGBColor[
              0.7118315832315418, 0.7748075100316689, 0.9719123778383179], 
             UndirectedEdge[226, 429] -> 
             RGBColor[
              0.18946440368264025`, 0.31646947938043657`, 0.9341010895510347],
              UndirectedEdge[181, 189] -> 
             RGBColor[
              0.238744748764803, 0.3682662466161335, 0.9369075322997265], 
             UndirectedEdge[160, 167] -> 
             RGBColor[
              0.2396559862242012, 0.36922401496175294`, 0.9369594259249842], 
             UndirectedEdge[16, 277] -> 
             RGBColor[
              0.35667163535651547`, 0.47978123350239554`, 0.9440785507919407],
              UndirectedEdge[295, 341] -> 
             RGBColor[
              0.9895466198460419, 0.9890958111978665, 0.7611561924651287], 
             UndirectedEdge[69, 129] -> 
             RGBColor[
              0.36611599979539755`, 0.48974210320523914`, 0.944615139539211], 
             UndirectedEdge[352, 368] -> 
             RGBColor[
              0.1813119634696479, 0.3079007478220177, 0.9336368201413592], 
             UndirectedEdge[194, 297] -> 
             RGBColor[
              0.1906847748105455, 0.3177521668118635, 0.9341705878813915], 
             UndirectedEdge[188, 228] -> 
             RGBColor[
              0.24109668028529843`, 0.37073827576524543`, 0.9370414713204478],
              UndirectedEdge[273, 430] -> 
             RGBColor[
              0.19435747882303328`, 0.32161241159187215`, 0.9343797429416241],
              UndirectedEdge[200, 468] -> 
             RGBColor[
              0.2422384711696754, 0.37193837037844896`, 0.9371064946221849], 
             UndirectedEdge[93, 172] -> 
             RGBColor[
              0.22306123798292227`, 0.35178188239235997`, 0.9360143795623734],
              UndirectedEdge[61, 341] -> 
             RGBColor[
              0.992278182050985, 0.9902253823675571, 0.7158871376728388], 
             UndirectedEdge[121, 442] -> 
             RGBColor[
              0.22151836933651753`, 0.35016022962146637`, 0.9359265154754303],
              UndirectedEdge[287, 336] -> 
             RGBColor[
              0.46475221828321023`, 0.5718710801553506, 0.9521407597407114], 
             UndirectedEdge[403, 497] -> 
             RGBColor[
              0.6107955480026974, 0.6933624123353453, 0.9635615550100725], 
             UndirectedEdge[17, 407] -> 
             RGBColor[
              0.3262865305599572, 0.4541115725037497, 0.9421186980641918], 
             UndirectedEdge[135, 470] -> 
             RGBColor[
              0.18730486737300778`, 0.31419966979650255`, 0.9339781071529487],
              UndirectedEdge[322, 471] -> 
             RGBColor[
              0.8888094561578547, 0.5640382311059557, 0.5627414261917315], 
             UndirectedEdge[24, 52] -> 
             RGBColor[
              0.18264284256949226`, 0.3092995861385628, 0.9337126117372361], 
             UndirectedEdge[163, 440] -> 
             RGBColor[
              0.8954705204165625, 0.6182378713393768, 0.2344903787946242], 
             UndirectedEdge[274, 432] -> 
             RGBColor[
              0.26765870816883486`, 0.3986566512006808, 0.9385541395134164], 
             UndirectedEdge[89, 261] -> 
             RGBColor[
              0.31948712585052597`, 0.45114542334704305`, 0.9415784150411908],
              UndirectedEdge[255, 312] -> 
             RGBColor[
              0.19606964847691927`, 0.3234120104559323, 0.9344772484704849], 
             UndirectedEdge[370, 422] -> 
             RGBColor[
              0.21765000410983476`, 0.3460943324997014, 0.9357062177985042], 
             UndirectedEdge[43, 90] -> 
             RGBColor[
              0.24535980769453214`, 0.3752190929702395, 0.9372842501196719], 
             UndirectedEdge[373, 449] -> 
             RGBColor[
              0.9873031183402635, 0.9734548154410307, 0.5948195031122866], 
             UndirectedEdge[49, 457] -> 
             RGBColor[
              0.7315880631738731, 0.7847063242900234, 0.765752210507527], 
             UndirectedEdge[234, 449] -> 
             RGBColor[
              0.9549924747052941, 0.851092521948047, 0.32521790592745947`], 
             UndirectedEdge[245, 299] -> 
             RGBColor[
              0.24199930981785328`, 0.3716869966339784, 0.9370928747370061], 
             UndirectedEdge[398, 464] -> 
             RGBColor[
              0.20435657897174597`, 0.33212209982773555`, 0.9349491769027501],
              UndirectedEdge[245, 262] -> 
             RGBColor[
              0.2935462908702744, 0.4226836514910424, 0.9401449256179049], 
             UndirectedEdge[288, 321] -> 
             RGBColor[
              0.8483292768809738, 0.881288734461381, 0.9314462475205114], 
             UndirectedEdge[433, 465] -> 
             RGBColor[
              0.17986137360753812`, 0.306376085904231, 0.9335542111946675], 
             UndirectedEdge[330, 367] -> 
             RGBColor[
              0.19336515666501655`, 0.3205694180869378, 0.9343232316627341], 
             UndirectedEdge[106, 156] -> 
             RGBColor[
              0.1895211212928381, 0.31652909318485867`, 0.9341043195350291], 
             UndirectedEdge[85, 239] -> 
             RGBColor[
              0.19195700771123925`, 0.31908936425471746`, 0.9342430396629862],
              UndirectedEdge[336, 388] -> 
             RGBColor[
              0.4770192723969674, 0.5829207625304905, 0.9529068597500787], 
             UndirectedEdge[69, 355] -> 
             RGBColor[
              0.5012830197903266, 0.6057191013914514, 0.9539604693674415], 
             UndirectedEdge[102, 383] -> 
             RGBColor[
              0.23360844690792137`, 0.362867667704204, 0.9366150275074547], 
             UndirectedEdge[296, 327] -> 
             RGBColor[
              0.1830042105599709, 0.3096794068086097, 0.9337331911096979], 
             UndirectedEdge[61, 288] -> 
             RGBColor[
              0.8507412174209339, 0.8822861338586991, 0.8914741508713435], 
             UndirectedEdge[141, 472] -> 
             RGBColor[
              0.19522243291560842`, 0.32252153318442556`, 0.9344290007976113],
              UndirectedEdge[43, 485] -> 
             RGBColor[
              0.24185676211585877`, 0.3715371699611359, 0.9370847568562579], 
             UndirectedEdge[9, 358] -> 
             RGBColor[
              0.2093374978833109, 0.33735736141228945`, 0.9352328328661546], 
             UndirectedEdge[70, 359] -> 
             RGBColor[
              0.6396346219366711, 0.7126850500536813, 0.9680066447733342], 
             UndirectedEdge[466, 470] -> 
             RGBColor[
              0.19475005924981162`, 0.3220250385114528, 0.9344020998161584], 
             UndirectedEdge[41, 356] -> 
             RGBColor[
              0.25420192746199044`, 0.3845127214686115, 0.9377877957596846], 
             UndirectedEdge[79, 436] -> 
             RGBColor[
              0.620883921888038, 0.6972446695931502, 0.9664433372119796], 
             UndirectedEdge[33, 175] -> 
             RGBColor[
              0.326974395016177, 0.4527788821025087, 0.9422331394259775], 
             UndirectedEdge[176, 448] -> 
             RGBColor[
              0.3087587670403855, 0.44109843030645696`, 0.9409224441271964], 
             UndirectedEdge[118, 481] -> 
             RGBColor[
              0.1987399075504107, 0.32621862204637564`, 0.9346293157744259], 
             UndirectedEdge[326, 346] -> 
             RGBColor[
              0.5833986733777301, 0.6710733580441507, 0.9613052656352206], 
             UndirectedEdge[63, 435] -> 
             RGBColor[
              0.22260483335872017`, 0.351302172194599, 0.9359883879942152], 
             UndirectedEdge[194, 350] -> 
             RGBColor[
              0.18381567245253283`, 0.31053230470734794`, 0.9337794026640289],
              UndirectedEdge[275, 486] -> 
             RGBColor[
              0.45132348377934284`, 0.564358118789839, 0.9502489507974816], 
             UndirectedEdge[407, 478] -> 
             RGBColor[
              0.2632216514132959, 0.39399302322496244`, 0.9383014556952256], 
             UndirectedEdge[62, 356] -> 
             RGBColor[
              0.24825469827183463`, 0.37826180651364816`, 0.9374491098554425],
              UndirectedEdge[150, 426] -> 
             RGBColor[
              0.20135872025195078`, 0.3289711602380097, 0.9347784532835923], 
             UndirectedEdge[372, 444] -> 
             RGBColor[
              0.5900676498939734, 0.6780825262854508, 0.9608714333701266], 
             UndirectedEdge[106, 329] -> 
             RGBColor[
              0.18061317161541351`, 0.30716627327725476`, 0.9335970249790304],
              UndirectedEdge[128, 294] -> 
             RGBColor[
              0.1908740507973531, 0.317951107874789, 0.9341813668688315], 
             UndirectedEdge[379, 440] -> 
             RGBColor[
              0.8595285144156211, 0.406306411086346, 0.20259145280411195`], 
             UndirectedEdge[227, 267] -> 
             RGBColor[
              0.2112079223469873, 0.3393232961153739, 0.935339350772316], 
             UndirectedEdge[151, 345] -> 
             RGBColor[
              0.19727711657984534`, 0.32468113599000714`, 0.9345460119926574],
              UndirectedEdge[275, 418] -> 
             RGBColor[
              0.48290882987898437`, 0.5910861687474542, 0.9524354985228551], 
             UndirectedEdge[10, 232] -> 
             RGBColor[
              0.2526232272726644, 0.38285340747425656`, 0.9376978911193801], 
             UndirectedEdge[5, 431] -> 
             RGBColor[
              0.5554141285415004, 0.6483552608910543, 0.9588784790444786], 
             UndirectedEdge[42, 416] -> 
             RGBColor[
              0.20488956233917005`, 0.3326822991399955, 0.9349795295170467], 
             UndirectedEdge[37, 97] -> 
             RGBColor[
              0.9251557778239836, 0.7191603787632175, 0.30804891163954246`], 
             UndirectedEdge[441, 450] -> 
             RGBColor[
              0.21849705952285933`, 0.34698464144520536`, 0.9357544563511697],
              UndirectedEdge[5, 259] -> 
             RGBColor[
              0.686424746410886, 0.7549594960082611, 0.969380061784424], 
             UndirectedEdge[279, 318] -> 
             RGBColor[
              0.20298181137445004`, 0.33067713191767734`, 0.9348708859218705],
              UndirectedEdge[275, 355] -> 
             RGBColor[
              0.5245111056702372, 0.6248607703959599, 0.9557105820673001], 
             UndirectedEdge[344, 387] -> 
             RGBColor[
              0.1895833056665427, 0.31659445290433924`, 0.9341078608431181], 
             UndirectedEdge[239, 489] -> 
             RGBColor[
              0.1941327088524955, 0.32137616410159764`, 0.9343669426243193], 
             UndirectedEdge[21, 336] -> 
             RGBColor[
              0.4626767064166898, 0.5696895855885848, 0.9520225624103578], 
             UndirectedEdge[32, 312] -> 
             RGBColor[
              0.20732064752653726`, 0.335237523811622, 0.935117976221999], 
             UndirectedEdge[77, 436] -> 
             RGBColor[
              0.3449944123676427, 0.4732385528946725, 0.9432037167828538], 
             UndirectedEdge[66, 294] -> 
             RGBColor[
              0.19268716813915449`, 0.3198568091593014, 0.9342846212191803], 
             UndirectedEdge[197, 201] -> 
             RGBColor[
              0.2441727010346539, 0.373971368603798, 0.9372166461515588], 
             UndirectedEdge[228, 256] -> 
             RGBColor[
              0.28488710481113977`, 0.4165048432644388, 0.9395447890804083], 
             UndirectedEdge[292, 481] -> 
             RGBColor[
              0.1951943467181843, 0.32249201281016504`, 0.9344274013302178], 
             UndirectedEdge[444, 486] -> 
             RGBColor[
              0.4895993510327964, 0.5954321921343623, 0.953262167276795], 
             UndirectedEdge[154, 244] -> 
             RGBColor[
              0.7150943787471429, 0.7742699758488314, 0.9312778860004862], 
             UndirectedEdge[288, 386] -> 
             RGBColor[
              0.5084129263265404, 0.6064351624645463, 0.9562833697364408], 
             UndirectedEdge[273, 285] -> 
             RGBColor[
              0.20077325282687788`, 0.3283557968534793, 0.934745111779856], 
             UndirectedEdge[190, 487] -> 
             RGBColor[
              0.2046420322637051, 0.3324221293363686, 0.9349654330454369], 
             UndirectedEdge[83, 343] -> 
             RGBColor[
              0.920728738466214, 0.6743242594892878, 0.4603352612449215], 
             UndirectedEdge[1, 315] -> 
             RGBColor[
              0.19134373832478055`, 0.31844477924602455`, 0.934208114878678], 
             UndirectedEdge[4, 429] -> 
             RGBColor[
              0.18673058009120463`, 0.3135960574514107, 0.9339454023418319], 
             UndirectedEdge[189, 451] -> 
             RGBColor[
              0.22852938408198586`, 0.3575292506429629, 0.9363257823933178], 
             UndirectedEdge[10, 102] -> 
             RGBColor[
              0.21311463700569694`, 0.34132737411436953`, 0.9354479353513978],
              UndirectedEdge[357, 368] -> 
             RGBColor[
              0.18388810829963448`, 0.3106084393753497, 0.9337835277783622], 
             UndirectedEdge[128, 138] -> 
             RGBColor[
              0.18851306554638397`, 0.31546956268090953`, 0.9340469122515535],
              UndirectedEdge[336, 436] -> 
             RGBColor[
              0.49043574205618756`, 0.5945414342179349, 0.953761745333046], 
             UndirectedEdge[196, 454] -> 
             RGBColor[
              0.20169424196759916`, 0.3293238148344616, 0.9347975607489386], 
             UndirectedEdge[25, 164] -> 
             RGBColor[
              0.3024600979339018, 0.4345620939070181, 0.9405606698993174], 
             UndirectedEdge[125, 282] -> 
             RGBColor[
              0.7373315894354715, 0.794728308685404, 0.9744539801456191], 
             UndirectedEdge[9, 286] -> 
             RGBColor[
              0.19059390233229334`, 0.3176566540755726, 0.9341654128281889], 
             UndirectedEdge[421, 477] -> 
             RGBColor[
              0.1910652466541582, 0.31815206684280867`, 0.9341922551900277], 
             UndirectedEdge[105, 484] -> 
             RGBColor[
              0.1881185665568436, 0.315054919230222, 0.9340244461177081], 
             UndirectedEdge[299, 475] -> 
             RGBColor[
              0.28830100074598397`, 0.41778431854565623`, 0.939823739896893], 
             UndirectedEdge[247, 252] -> 
             RGBColor[
              0.18329308738435063`, 0.3099830346668814, 0.9337496422174913], 
             UndirectedEdge[261, 478] -> 
             RGBColor[
              0.2893032374986769, 0.41950673564807195`, 0.9398563203301515], 
             UndirectedEdge[104, 303] -> 
             RGBColor[
              0.8824648742106225, 0.5257558359619144, 0.2222571743069387], 
             UndirectedEdge[32, 66] -> 
             RGBColor[
              0.20877736241614875`, 0.33676862352166215`, 0.9352009339799459],
              UndirectedEdge[213, 454] -> 
             RGBColor[
              0.20680491942710666`, 0.3346954608800703, 0.9350886062696878], 
             UndirectedEdge[129, 331] -> 
             RGBColor[
              0.2954052676483876, 0.42782004444717026`, 0.9401342650284206], 
             UndirectedEdge[245, 475] -> 
             RGBColor[
              0.2902269064135576, 0.4198085675117481, 0.9399334173755393], 
             UndirectedEdge[90, 148] -> 
             RGBColor[
              0.26849318417245727`, 0.3995337383893224, 0.9386016616873261], 
             UndirectedEdge[195, 496] -> 
             RGBColor[
              0.18695506079229124`, 0.31383200090115126`, 0.9339581861856694],
              UndirectedEdge[241, 371] -> 
             RGBColor[
              0.2348560709776379, 0.3641789997054109, 0.9366860778525307], 
             UndirectedEdge[13, 243] -> 
             RGBColor[
              0.2247623131438397, 0.3535698202408788, 0.9361112532762724], 
             UndirectedEdge[246, 384] -> 
             RGBColor[
              0.2539870125967417, 0.38428683231884564`, 0.9377755566760467], 
             UndirectedEdge[22, 268] -> 
             RGBColor[
              0.1840499075552901, 0.3107785006517091, 0.9337927420066112], 
             UndirectedEdge[69, 306] -> 
             RGBColor[
              0.3418131212888621, 0.4641982370033755, 0.9432311265611506], 
             UndirectedEdge[66, 128] -> 
             RGBColor[
              0.19606919376904863`, 0.32341153252913013`, 0.9344772225755442],
              UndirectedEdge[220, 413] -> 
             RGBColor[
              0.2236716605546839, 0.35242347521830786`, 0.9360491422247958], 
             UndirectedEdge[319, 492] -> 
             RGBColor[
              0.18173579190696668`, 0.3083462183819148, 0.9336609565438665], 
             UndirectedEdge[61, 186] -> 
             RGBColor[
              0.9917911303595999, 0.9891836280481643, 0.6628745668001933], 
             UndirectedEdge[94, 401] -> 
             RGBColor[
              0.17982716171712376`, 0.30634012703824637`, 0.9335522628781203],
              UndirectedEdge[429, 488] -> 
             RGBColor[
              0.1872389149746237, 0.3141303496441773, 0.9339743512614285], 
             UndirectedEdge[11, 431] -> 
             RGBColor[
              0.3984128235048672, 0.519506895734326, 0.9466074907044714], 
             UndirectedEdge[349, 487] -> 
             RGBColor[
              0.1889676303182698, 0.3159473390772327, 0.9340727990428441], 
             UndirectedEdge[156, 198] -> 
             RGBColor[
              0.19090321227565094`, 0.31798175843742454`, 0.93418302757188], 
             UndirectedEdge[12, 188] -> 
             RGBColor[
              0.20900601855676193`, 0.3370089556230833, 0.9352139556088873], 
             UndirectedEdge[70, 111] -> 
             RGBColor[
              0.36816732392345053`, 0.4933097641799131, 0.9446802742161886], 
             UndirectedEdge[212, 286] -> 
             RGBColor[
              0.18467080520712215`, 0.3114311034509694, 0.9338281012093472], 
             UndirectedEdge[242, 282] -> 
             RGBColor[
              0.8349131599958114, 0.8712326557093291, 0.9504012848257013], 
             UndirectedEdge[70, 175] -> 
             RGBColor[
              0.3837102779939304, 0.5067722897841764, 0.945670657505465], 
             UndirectedEdge[188, 298] -> 
             RGBColor[
              0.24983259130122784`, 0.37992027213173674`, 0.9375389685291828],
              UndirectedEdge[286, 367] -> 
             RGBColor[
              0.1922727390163294, 0.3194212178748882, 0.9342610200937285], 
             UndirectedEdge[9, 492] -> 
             RGBColor[
              0.18820033017206594`, 0.3151408579739333, 0.9340291024346365], 
             UndirectedEdge[37, 343] -> 
             RGBColor[
              0.8540426861772787, 0.4109754374687308, 0.1991721784497092], 
             UndirectedEdge[376, 391] -> 
             RGBColor[
              0.4221118184289103, 0.5394962463103177, 0.9482660902046844], 
             UndirectedEdge[230, 490] -> 
             RGBColor[
              0.21093312852044277`, 0.33903447038074064`, 0.9353237016704152],
              UndirectedEdge[346, 355] -> 
             RGBColor[
              0.5005625797661037, 0.605095092452838, 0.9539145635661582], 
             UndirectedEdge[30, 465] -> 
             RGBColor[
              0.17899164586466354`, 0.3054619469025459, 0.9335046814863577], 
             UndirectedEdge[119, 124] -> 
             RGBColor[
              0.18484388120986256`, 0.311613017303502, 0.9338379576316604], 
             UndirectedEdge[301, 436] -> 
             RGBColor[
              0.5059845229884368, 0.6069488070899312, 0.9551333650755793], 
             UndirectedEdge[39, 108] -> 
             RGBColor[
              0.22860230621824829`, 0.3576058964317052, 0.9363299352010993], 
             UndirectedEdge[98, 382] -> 
             RGBColor[
              0.20018581629901203`, 0.3277383638170652, 0.9347116581386283], 
             UndirectedEdge[81, 208] -> 
             RGBColor[
              0.3324858109628042, 0.4558962797557328, 0.942644967739437], 
             UndirectedEdge[154, 203] -> 
             RGBColor[
              0.9142690676811895, 0.6673158743356673, 0.5518317374650853], 
             UndirectedEdge[145, 367] -> 
             RGBColor[
              0.2030970423728074, 0.33079824700301824`, 0.9348774481567581], 
             UndirectedEdge[44, 132] -> 
             RGBColor[
              0.27566251602704606`, 0.4070691607303891, 0.9390099445303688], 
             UndirectedEdge[319, 357] -> 
             RGBColor[
              0.18470360051772483`, 0.3114655734017556, 0.9338299688537698], 
             UndirectedEdge[364, 378] -> 
             RGBColor[
              0.20567802361676119`, 0.3335110219340761, 0.9350244312203816], 
             UndirectedEdge[213, 251] -> 
             RGBColor[
              0.22057376513923174`, 0.3491673907187537, 0.9358727216638114], 
             UndirectedEdge[73, 136] -> 
             RGBColor[
              0.5525602908951197, 0.647632362562914, 0.9579187166757537], 
             UndirectedEdge[441, 461] -> 
             RGBColor[
              0.2373696075780963, 0.3668208860399178, 0.9368292200434826], 
             UndirectedEdge[90, 480] -> 
             RGBColor[
              0.2528560578238772, 0.3830981271458908, 0.9377111504748298], 
             UndirectedEdge[118, 446] -> 
             RGBColor[
              0.18780907665371493`, 0.3147296257192406, 0.9340068211255742], 
             UndirectedEdge[210, 480] -> 
             RGBColor[
              0.21944240212988145`, 0.3479782564633687, 0.9358082922141305], 
             UndirectedEdge[95, 492] -> 
             RGBColor[
              0.18364470169108055`, 0.3103526035968892, 0.9337696661320929], 
             UndirectedEdge[261, 328] -> 
             RGBColor[
              0.28613962453427205`, 0.41618157783783527`, 0.9396761572519747],
              UndirectedEdge[152, 496] -> 
             RGBColor[
              0.1850253408084585, 0.31180374284682943`, 0.9338482914873549], 
             UndirectedEdge[86, 177] -> 
             RGBColor[
              0.1848471163861694, 0.31161641767892256`, 0.933838141870165], 
             UndirectedEdge[45, 217] -> 
             RGBColor[
              0.19120987418842403`, 0.31830407955123735`, 0.9342004915141469],
              UndirectedEdge[306, 331] -> 
             RGBColor[
              0.2711023891418522, 0.40227617824530654`, 0.9387502520503602], 
             UndirectedEdge[103, 129] -> 
             RGBColor[
              0.3495899489939847, 0.47542806862452014`, 0.9435621141955579], 
             UndirectedEdge[50, 126] -> 
             RGBColor[
              0.6844097961772514, 0.7515158315979785, 0.9706616235238129], 
             UndirectedEdge[172, 308] -> 
             RGBColor[
              0.207198246316672, 0.3351088723793687, 0.9351110056541736], 
             UndirectedEdge[112, 266] -> 
             RGBColor[
              0.9935124253020141, 0.9901198523525236, 0.6506615550659651], 
             UndirectedEdge[129, 275] -> 
             RGBColor[
              0.3893440856753081, 0.5088837722097477, 0.9463652522390695], 
             UndirectedEdge[297, 325] -> 
             RGBColor[
              0.21444902327045198`, 0.3427298986836028, 0.9355239266751281], 
             UndirectedEdge[202, 396] -> 
             RGBColor[
              0.1920993256937792, 0.31923894947784826`, 0.9342511444615511], 
             UndirectedEdge[167, 236] -> 
             RGBColor[
              0.22411127044535895`, 0.3528855330862843, 0.9360741773577252], 
             UndirectedEdge[184, 301] -> 
             RGBColor[
              0.5986418341837841, 0.6848276074011173, 0.9616939873161781], 
             UndirectedEdge[78, 258] -> 
             RGBColor[
              0.44262074177976496`, 0.5573429685234437, 0.9495499886233556], 
             UndirectedEdge[172, 470] -> 
             RGBColor[
              0.2090529849214024, 0.33705832025015997`, 0.9352166302738731], 
             UndirectedEdge[72, 159] -> 
             RGBColor[
              0.22161615608300847`, 0.35026300969206614`, 0.9359320842859804],
              UndirectedEdge[304, 337] -> 
             RGBColor[
              0.1898974932161501, 0.3169246839396178, 0.9341257533592695], 
             UndirectedEdge[88, 271] -> 
             RGBColor[
              0.19882737388287028`, 0.32631055470747644`, 0.9346342968526646],
              UndirectedEdge[392, 413] -> 
             RGBColor[
              0.23358028524334118`, 0.3628380680091775, 0.9366134237423184], 
             UndirectedEdge[187, 216] -> 
             RGBColor[
              0.21058067829644372`, 0.3386640228486828, 0.9353036301515618], 
             UndirectedEdge[33, 432] -> 
             RGBColor[
              0.27375220804932543`, 0.40506130592528333`, 0.9389011553170851],
              UndirectedEdge[36, 75] -> 
             RGBColor[
              0.929724921483118, 0.7365825483050892, 0.4781251750142107], 
             UndirectedEdge[243, 335] -> 
             RGBColor[
              0.2034771985235191, 0.3311978152207083, 0.9348990974871504], 
             UndirectedEdge[323, 499] -> 
             RGBColor[
              0.8106414871808013, 0.8502981241426343, 0.8671892234801464], 
             UndirectedEdge[168, 480] -> 
             RGBColor[
              0.26803681984078476`, 0.3990540705415648, 0.9385756724137677], 
             UndirectedEdge[301, 388] -> 
             RGBColor[
              0.4925680533292166, 0.5953281354024867, 0.9542784794926122], 
             UndirectedEdge[111, 371] -> 
             RGBColor[
              0.3103368514001098, 0.4381658734848475, 0.9411804208813801], 
             UndirectedEdge[103, 231] -> 
             RGBColor[
              0.5867310207555722, 0.6723340507666251, 0.9622056389073572], 
             UndirectedEdge[99, 131] -> 
             RGBColor[
              0.9067135965497277, 0.6223214351513566, 0.549591400192696], 
             UndirectedEdge[193, 428] -> 
             RGBColor[
              0.18434895637471288`, 0.31109281992171267`, 0.9338097723944743],
              UndirectedEdge[189, 370] -> 
             RGBColor[
              0.24036595787050763`, 0.36997024017682334`, 0.9369998577599323],
              UndirectedEdge[45, 187] -> 
             RGBColor[
              0.21121178851668337`, 0.3393273597048538, 0.9353395709449606], 
             UndirectedEdge[346, 443] -> 
             RGBColor[
              0.3646259972920919, 0.4883092353080305, 0.9445254082932095], 
             UndirectedEdge[19, 318] -> 
             RGBColor[
              0.20059929205314941`, 0.3281729530505406, 0.9347352049711439], 
             UndirectedEdge[5, 129] -> 
             RGBColor[
              0.4894760344411281, 0.5894520908087815, 0.9547425358777173], 
             UndirectedEdge[29, 46] -> 
             RGBColor[
              0.19406985648437775`, 0.32131010227763557`, 0.9343633632749366],
              UndirectedEdge[227, 263] -> 
             RGBColor[
              0.2087485483203887, 0.3367383380800992, 0.935199293059819], 
             UndirectedEdge[272, 435] -> 
             RGBColor[
              0.24781268178209245`, 0.377797219157465, 0.9374239376702564], 
             UndirectedEdge[208, 483] -> 
             RGBColor[
              0.4393277460874472, 0.554945345231554, 0.949214553391788], 
             UndirectedEdge[244, 475] -> 
             RGBColor[
              0.39162513268333266`, 0.5136277391039731, 0.9461749850474426], 
             UndirectedEdge[350, 412] -> 
             RGBColor[
              0.18588998404715956`, 0.3127125377122519, 0.9338975316406739], 
             UndirectedEdge[217, 398] -> 
             RGBColor[
              0.1937507850823029, 0.3209747380037596, 0.9343451926306123], 
             UndirectedEdge[370, 451] -> 
             RGBColor[
              0.21692330433294027`, 0.34533052495875827`, 0.935664833321266], 
             UndirectedEdge[265, 424] -> 
             RGBColor[
              0.18889724072199854`, 0.3158733551485935, 0.9340687904594684], 
             UndirectedEdge[28, 419] -> 
             RGBColor[
              0.5625638978028586, 0.6556476235991, 0.9587787905130681], 
             UndirectedEdge[67, 381] -> 
             RGBColor[
              0.18458590754106158`, 0.31134187062111685`, 0.93382326641286], 
             UndirectedEdge[239, 435] -> 
             RGBColor[
              0.21752143841029148`, 0.3459592017979452, 0.9356988961721111], 
             UndirectedEdge[302, 370] -> 
             RGBColor[
              0.23676036432994563`, 0.36618053275785845`, 0.936794524541795], 
             UndirectedEdge[2, 66] -> 
             RGBColor[
              0.19103840083759993`, 0.31812385018748285`, 0.9341907263604894],
              UndirectedEdge[36, 408] -> 
             RGBColor[
              0.9657078104957213, 0.9722942089440085, 0.8689827508705463], 
             UndirectedEdge[76, 483] -> 
             RGBColor[
              0.43123446241891855`, 0.5479353496981393, 0.948698856513039], 
             UndirectedEdge[9, 367] -> 
             RGBColor[
              0.19547077493947268`, 0.3227825563973006, 0.9344431435084812], 
             UndirectedEdge[133, 469] -> 
             RGBColor[
              0.18966655655355485`, 0.31668195486500017`, 0.9341126018579748],
              UndirectedEdge[46, 297] -> 
             RGBColor[
              0.19948643535294036`, 0.32700327009943075`, 0.934671829428391], 
             UndirectedEdge[159, 435] -> 
             RGBColor[
              0.23525737339525699`, 0.3646007939903714, 0.9367089314315404], 
             UndirectedEdge[126, 340] -> 
             RGBColor[
              0.4261246264730337, 0.5425553802981693, 0.948636879181104], 
             UndirectedEdge[27, 290] -> 
             RGBColor[
              0.18336907213961767`, 0.31006289946237875`, 0.9337539694368944],
              UndirectedEdge[326, 338] -> 
             RGBColor[
              0.5748571876552486, 0.6636751524188924, 0.9607610097179233], 
             UndirectedEdge[179, 438] -> 
             RGBColor[
              0.20137694299580192`, 0.3289903134971859, 0.9347794910418965], 
             UndirectedEdge[138, 339] -> 
             RGBColor[
              0.1814781394477339, 0.3080754093111516, 0.9336462836174759], 
             UndirectedEdge[475, 482] -> 
             RGBColor[
              0.3344502958688525, 0.46410576914612495`, 0.942531855003347], 
             UndirectedEdge[94, 428] -> 
             RGBColor[
              0.18335052254202558`, 0.31004340265919705`, 0.9337529130647533],
              UndirectedEdge[186, 295] -> 
             RGBColor[
              0.9890595681546568, 0.9880540568784736, 0.7081436215924831], 
             UndirectedEdge[348, 372] -> 
             RGBColor[
              0.5381758194150634, 0.6359544006023488, 0.9567863183887886], 
             UndirectedEdge[293, 343] -> 
             RGBColor[
              0.8279897500301316, 0.6038277857603807, 0.5867878259844261], 
             UndirectedEdge[385, 446] -> 
             RGBColor[
              0.18248129368631721`, 0.30912978801955504`, 0.9337034117673295],
              UndirectedEdge[7, 288] -> 
             RGBColor[
              0.5917887149964642, 0.6784248496808247, 0.9617281729213873], 
             UndirectedEdge[242, 323] -> 
             RGBColor[
              0.9829115082024764, 0.98536084245597, 0.8504363857845441], 
             UndirectedEdge[464, 481] -> 
             RGBColor[
              0.2038613891913174, 0.3316016239716596, 0.9349209765773223], 
             UndirectedEdge[42, 108] -> 
             RGBColor[
              0.2050818952093152, 0.3328844531811263, 0.9349904825894705], 
             UndirectedEdge[101, 276] -> 
             RGBColor[
              0.22935486634297414`, 0.3583968848378599, 0.9363727923868895], 
             UndirectedEdge[86, 426] -> 
             RGBColor[
              0.1863343941921356, 0.31317964095185236`, 0.9339228401409845], 
             UndirectedEdge[37, 324] -> 
             RGBColor[
              0.9007937640631225, 0.7100849667901136, 0.5966707240103046], 
             UndirectedEdge[290, 297] -> 
             RGBColor[
              0.18839455558370108`, 0.3153450011961642, 0.9340401632844985], 
             UndirectedEdge[315, 380] -> 
             RGBColor[
              0.18543946082278231`, 0.31223900923860914`, 0.9338718750095351],
              UndirectedEdge[181, 390] -> 
             RGBColor[
              0.24071562353706022`, 0.37033776096245374`, 0.9370197707023586],
              UndirectedEdge[283, 421] -> 
             RGBColor[
              0.18332707368146411`, 0.3100187564200033, 0.9337515776868337], 
             UndirectedEdge[97, 355] -> 
             RGBColor[
              0.7740833188183651, 0.8130804459299827, 0.6840694071044306], 
             UndirectedEdge[192, 219] -> 
             RGBColor[
              0.49125780976030897`, 0.5936378228658237, 0.9544300827546521], 
             UndirectedEdge[171, 192] -> 
             RGBColor[
              0.3918420426717766, 0.5133437939110442, 0.9463191721078775], 
             UndirectedEdge[122, 216] -> 
             RGBColor[
              0.19279683115434215`, 0.3199720719413004, 0.9342908663656634], 
             UndirectedEdge[18, 28] -> 
             RGBColor[
              0.38207742266917044`, 0.5028572911387341, 0.9458047612186589], 
             UndirectedEdge[178, 288] -> 
             RGBColor[
              0.5902663931329839, 0.677188960212233, 0.9616083301678455], 
             UndirectedEdge[165, 185] -> 
             RGBColor[
              0.2587337613234965, 0.38927596619191684`, 0.93804587699385], 
             UndirectedEdge[264, 281] -> 
             RGBColor[
              0.8419839123581961, 0.3124840077358858, 0.18739747519941907`], 
             UndirectedEdge[80, 192] -> 
             RGBColor[
              0.3302026401393104, 0.46042666324658016`, 0.9422611981363149], 
             UndirectedEdge[74, 402] -> 
             RGBColor[
              0.20341804022375085`, 0.331135636096799, 0.9348957285094954], 
             UndirectedEdge[3, 158] -> 
             RGBColor[
              0.187682952058607, 0.31459706077302096`, 0.9339996385164674], 
             UndirectedEdge[426, 476] -> 
             RGBColor[
              0.1853934884122734, 0.3121906893203451, 0.9338692569487667], 
             UndirectedEdge[27, 177] -> 
             RGBColor[
              0.18479696914654997`, 0.31156370975056386`, 0.9338352860590549],
              UndirectedEdge[355, 443] -> 
             RGBColor[
              0.4237732599016528, 0.5366508333936366, 0.9490924002850236], 
             UndirectedEdge[21, 256] -> 
             RGBColor[
              0.3057801725853121, 0.43846478219210167`, 0.9407346183816234], 
             UndirectedEdge[331, 404] -> 
             RGBColor[
              0.5691308396856145, 0.6534422515230649, 0.9623880647122928], 
             UndirectedEdge[142, 285] -> 
             RGBColor[
              0.2150502131881199, 0.3433617874047141, 0.9355581635515585], 
             UndirectedEdge[232, 267] -> 
             RGBColor[
              0.25385827815003914`, 0.3841515242531258, 0.9377682254397526], 
             UndirectedEdge[133, 488] -> 
             RGBColor[
              0.19025464326071956`, 0.31730007128108106`, 0.9341460925259515],
              UndirectedEdge[148, 393] -> 
             RGBColor[
              0.24797563185424576`, 0.37796849001492944`, 0.9374332174358024],
              UndirectedEdge[84, 89] -> 
             RGBColor[
              0.2925984761880414, 0.42478343593361145`, 0.9399775893294924], 
             UndirectedEdge[27, 350] -> 
             RGBColor[
              0.18336792975933797`, 0.3100616987482737, 0.9337539043800275], 
             UndirectedEdge[8, 435] -> 
             RGBColor[
              0.21794255850182165`, 0.34640182571469935`, 0.9357228783383325],
              UndirectedEdge[20, 220] -> 
             RGBColor[
              0.2293954500117661, 0.35843954084691343`, 0.9363751035667891], 
             UndirectedEdge[35, 422] -> 
             RGBColor[
              0.19709463641182273`, 0.32448933776350447`, 0.9345356200170438],
              UndirectedEdge[65, 177] -> 
             RGBColor[
              0.18378082822451933`, 0.3104956812144541, 0.9337774183367911], 
             UndirectedEdge[93, 160] -> 
             RGBColor[
              0.23103960685447572`, 0.36016765393416605`, 0.9364687358666692],
              UndirectedEdge[277, 373] -> 
             RGBColor[
              0.7171130809828956, 0.774434213301909, 0.8741433170431847], 
             UndirectedEdge[15, 126] -> 
             RGBColor[
              0.5704313985291926, 0.6619870174784861, 0.9594308284953961], 
             UndirectedEdge[95, 367] -> 
             RGBColor[
              0.19091514645848728`, 0.31799430202025647`, 0.9341837072059376],
              UndirectedEdge[304, 465] -> 
             RGBColor[
              0.18487917380697239`, 0.31165011206074433`, 0.933839967492855], 
             UndirectedEdge[218, 305] -> 
             RGBColor[
              0.29821563929003225`, 0.43060670099699316`, 0.9403004343609631],
              UndirectedEdge[137, 265] -> 
             RGBColor[
              0.19798921213274367`, 0.325429593565569, 0.934586564780944], 
             UndirectedEdge[325, 392] -> 
             RGBColor[
              0.23524305947406288`, 0.3645857491516413, 0.9367081162749039], 
             UndirectedEdge[263, 393] -> 
             RGBColor[
              0.22282702878996197`, 0.35153571368083814`, 0.9360010416953157],
              UndirectedEdge[228, 335] -> 
             RGBColor[
              0.2342958788041693, 0.36359020221286015`, 0.9366541757369817], 
             UndirectedEdge[104, 408] -> 
             RGBColor[
              0.9307079198191593, 0.8448308855634613, 0.624429309131783], 
             UndirectedEdge[145, 375] -> 
             RGBColor[
              0.20589359976284474`, 0.33373760613192704`, 0.9350367079629848],
              UndirectedEdge[181, 451] -> 
             RGBColor[
              0.21530209522723562`, 0.3436265313980684, 0.93557250786106], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.20367497522683542`, 0.331405691075661, 0.93491036057782], 
             UndirectedEdge[387, 439] -> 
             RGBColor[
              0.1940605439508961, 0.3213003142144977, 0.9343628329399316], 
             UndirectedEdge[163, 231] -> 
             RGBColor[
              0.8314832405552138, 0.7254800292683178, 0.607385428867296], 
             UndirectedEdge[143, 288] -> 
             RGBColor[
              0.6459376056374727, 0.7223853584829198, 0.9659909719465696], 
             UndirectedEdge[128, 312] -> 
             RGBColor[
              0.19461247887943717`, 0.32188043281908996`, 0.9343942648175974],
              UndirectedEdge[270, 479] -> 
             RGBColor[
              0.18121603188329788`, 0.30779991764234993`, 0.9336313569794346],
              UndirectedEdge[119, 120] -> 
             RGBColor[
              0.18211134871711507`, 0.30874095240105776`, 0.9336823439486179],
              UndirectedEdge[105, 462] -> 
             RGBColor[
              0.19074614489061564`, 0.31781667065710506`, 0.9341740828166627],
              UndirectedEdge[14, 159] -> 
             RGBColor[
              0.2315482163827265, 0.3607022347960642, 0.9364977004268829], 
             UndirectedEdge[58, 417] -> 
             RGBColor[
              0.19514933346569613`, 0.3224447010277949, 0.9344248378920796], 
             UndirectedEdge[66, 299] -> 
             RGBColor[
              0.21897785763056482`, 0.34748999074076453`, 0.9357818370921265],
              UndirectedEdge[11, 348] -> 
             RGBColor[
              0.41882704946853977`, 0.5369507513572022, 0.9479740053732437], 
             UndirectedEdge[4, 31] -> 
             RGBColor[
              0.18674651901237604`, 0.3136128102681478, 0.9339463100398131], 
             UndirectedEdge[259, 400] -> 
             RGBColor[
              0.8365707919285453, 0.8712879121400499, 0.8933185067355665], 
             UndirectedEdge[247, 451] -> 
             RGBColor[
              0.19468301666075716`, 0.32195457249961096`, 0.9343982818398924],
              UndirectedEdge[17, 261] -> 
             RGBColor[
              0.3523681166453383, 0.4796252849268593, 0.9436735626991177], 
             UndirectedEdge[361, 386] -> 
             RGBColor[
              0.26785160184799417`, 0.39885939468764287`, 0.9385651245230838],
              UndirectedEdge[212, 492] -> 
             RGBColor[
              0.18227723304689475`, 0.30891530734933015`, 0.933691790815795], 
             UndirectedEdge[287, 388] -> 
             RGBColor[
              0.31642089310081123`, 0.44806502999070874`, 0.9413985832331735],
              UndirectedEdge[383, 480] -> 
             RGBColor[
              0.2555678088390552, 0.3859483493977877, 0.937865580683468], 
             UndirectedEdge[403, 440] -> 
             RGBColor[
              0.8175206971599966, 0.7001431418216288, 0.6031737768596591], 
             UndirectedEdge[13, 354] -> 
             RGBColor[
              0.28176652075351294`, 0.4133145757884693, 0.9393637933883066], 
             UndirectedEdge[1, 42] -> 
             RGBColor[
              0.19991385155278849`, 0.32745251162522343`, 0.9346961701486667],
              UndirectedEdge[161, 188] -> 
             RGBColor[
              0.2189136351360459, 0.34742248882708376`, 0.9357781797160722], 
             UndirectedEdge[194, 426] -> 
             RGBColor[
              0.18673198964571103`, 0.31359753898256787`, 0.9339454826138758],
              UndirectedEdge[257, 324] -> 
             RGBColor[
              0.9513926924014826, 0.9208016602260798, 0.6489338534613713], 
             UndirectedEdge[198, 479] -> 
             RGBColor[
              0.18236486345397498`, 0.30900741246326024`, 0.9336967812378407],
              UndirectedEdge[372, 431] -> 
             RGBColor[
              0.5177615934513908, 0.6185105449794727, 0.9554198037200161], 
             UndirectedEdge[107, 466] -> 
             RGBColor[
              0.20308636910120992`, 0.33078702871784477`, 0.9348768403297303],
              UndirectedEdge[122, 330] -> 
             RGBColor[
              0.18762963037517022`, 0.3145410163029389, 0.9339966019254781], 
             UndirectedEdge[4, 472] -> 
             RGBColor[
              0.18232394464799978`, 0.30896440420377813`, 0.9336944509723744],
              UndirectedEdge[145, 458] -> 
             RGBColor[
              0.2240333301287531, 0.35280361287183004`, 0.936069738771997], 
             UndirectedEdge[3, 451] -> 
             RGBColor[
              0.19437267435842231`, 0.32162838306301855`, 0.9343806083048847],
              UndirectedEdge[146, 239] -> 
             RGBColor[
              0.18835872742063176`, 0.3153073435251416, 0.9340381229236147], 
             UndirectedEdge[15, 282] -> 
             RGBColor[
              0.674559975761555, 0.7456906470014069, 0.9681974923286845], 
             UndirectedEdge[82, 126] -> 
             RGBColor[
              0.504289208348975, 0.6084437231644664, 0.9541186402349197], 
             UndirectedEdge[413, 474] -> 
             RGBColor[
              0.2299117533537109, 0.35898220839482003`, 0.9364045062783105], 
             UndirectedEdge[160, 235] -> 
             RGBColor[
              0.22828336996259535`, 0.35727067420528746`, 0.9363117722531638],
              UndirectedEdge[161, 183] -> 
             RGBColor[
              0.2054076978090161, 0.33322689237048986`, 0.9350090365655417], 
             UndirectedEdge[366, 429] -> 
             RGBColor[
              0.18725297443025463`, 0.3141451270234664, 0.9339751519266276], 
             UndirectedEdge[7, 313] -> 
             RGBColor[
              0.4167872287841039, 0.534905009234637, 0.9479211050634437], 
             UndirectedEdge[129, 444] -> 
             RGBColor[
              0.42761995292876165`, 0.539957845554271, 0.9493784687183828], 
             UndirectedEdge[18, 493] -> 
             RGBColor[
              0.274609024515375, 0.4059618743564031, 0.9389499497472802], 
             UndirectedEdge[149, 411] -> 
             RGBColor[
              0.4211694508709569, 0.5337442476409241, 0.9489595750460023], 
             UndirectedEdge[221, 301] -> 
             RGBColor[
              0.8093616863432395, 0.8079745679423065, 0.6371695161143949], 
             UndirectedEdge[45, 496] -> 
             RGBColor[
              0.19349628938952101`, 0.32070724689468694`, 0.9343306994774011],
              UndirectedEdge[478, 482] -> 
             RGBColor[
              0.2908428553905808, 0.4208402752825938, 0.939954423420793], 
             UndirectedEdge[69, 331] -> 
             RGBColor[
              0.37214546505797846`, 0.49607945348638943`, 0.9449585086661204],
              UndirectedEdge[16, 143] -> 
             RGBColor[
              0.42538425366010096`, 0.535839238383477, 0.9494121511680118], 
             UndirectedEdge[210, 280] -> 
             RGBColor[
              0.22449871038575198`, 0.3532927570287484, 0.9360962414891647], 
             UndirectedEdge[101, 390] -> 
             RGBColor[
              0.25051248587412484`, 0.3806348844356572, 0.9375776875192954], 
             UndirectedEdge[400, 418] -> 
             RGBColor[
              0.7331868241624636, 0.7879829034782768, 0.8847512271126452], 
             UndirectedEdge[84, 299] -> 
             RGBColor[
              0.2577944317187598, 0.3882886712204018, 0.9379923835624739], 
             UndirectedEdge[333, 386] -> 
             RGBColor[
              0.268695341419697, 0.3997462184736812, 0.9386131742434916], 
             UndirectedEdge[244, 341] -> 
             RGBColor[
              0.7205094989495678, 0.7757802394753833, 0.7851817105206231], 
             UndirectedEdge[143, 373] -> 
             RGBColor[
              0.7858256992864812, 0.8304922181829903, 0.8794769174192558], 
             UndirectedEdge[160, 284] -> 
             RGBColor[
              0.22313950665110643`, 0.35186414772514174`, 0.9360188368472383],
              UndirectedEdge[281, 343] -> 
             RGBColor[
              0.8323272687160201, 0.24948713001661726`, 0.17858993507187598`],
              UndirectedEdge[207, 445] -> 
             RGBColor[
              0.9190529143682962, 0.7062401460895815, 0.26431121911210875`], 
             UndirectedEdge[260, 334] -> 
             RGBColor[
              0.19830298963418935`, 0.3257593936142311, 0.9346044339454591], 
             UndirectedEdge[66, 114] -> 
             RGBColor[
              0.1896583133560848, 0.31667329074181017`, 0.9341121324200736], 
             UndirectedEdge[364, 381] -> 
             RGBColor[
              0.19634549402636683`, 0.3237019416180197, 0.9344929574664489], 
             UndirectedEdge[204, 306] -> 
             RGBColor[
              0.2783366060930942, 0.40921806996322074`, 0.9391864591429547], 
             UndirectedEdge[358, 361] -> 
             RGBColor[
              0.2274919045840746, 0.3564387939106588, 0.9362666994707252], 
             UndirectedEdge[294, 415] -> 
             RGBColor[
              0.18394556991543065`, 0.3106688351768284, 0.9337868001323749], 
             UndirectedEdge[2, 255] -> 
             RGBColor[
              0.19068245309328063`, 0.3177497265398128, 0.9341704556630279], 
             UndirectedEdge[326, 443] -> 
             RGBColor[
              0.5066093535132791, 0.6026290989849493, 0.956483102354086], 
             UndirectedEdge[58, 145] -> 
             RGBColor[
              0.20110599109187893`, 0.32870552586681995`, 0.9347640607318055],
              UndirectedEdge[103, 346] -> 
             RGBColor[
              0.4256097063793528, 0.5430634687251261, 0.9483404520319744], 
             UndirectedEdge[62, 108] -> 
             RGBColor[
              0.2304034031645468, 0.35949896351840704`, 0.9364325050077069], 
             UndirectedEdge[91, 336] -> 
             RGBColor[
              0.5428373971732765, 0.639738879428151, 0.957153294865837], 
             UndirectedEdge[338, 395] -> 
             RGBColor[
              0.4642366864681818, 0.5751402530845398, 0.9511830173068838], 
             UndirectedEdge[19, 335] -> 
             RGBColor[
              0.20679640724799403`, 0.3346865140401196, 0.9350881215136799], 
             UndirectedEdge[2, 195] -> 
             RGBColor[
              0.18614467853761885`, 0.312980237770288, 0.933912036115119], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.2086123729274203, 0.33659520910807084`, 0.9351915380726428], 
             UndirectedEdge[150, 325] -> 
             RGBColor[
              0.2244980131258032, 0.35329202416433336`, 0.9360962017812421], 
             UndirectedEdge[208, 238] -> 
             RGBColor[
              0.4566518822195865, 0.5690445386024363, 0.9505687908779773], 
             UndirectedEdge[318, 335] -> 
             RGBColor[
              0.2041779627078255, 0.33193436280942984`, 0.9349390049707589], 
             UndirectedEdge[12, 421] -> 
             RGBColor[
              0.18918604161445732`, 0.31617690319760183`, 0.9340852372430514],
              UndirectedEdge[102, 278] -> 
             RGBColor[
              0.19195325855915324`, 0.31908542365816517`, 0.9342428261543212],
              UndirectedEdge[5, 209] -> 
             RGBColor[
              0.8420261863364131, 0.8747026148224741, 0.8554514610488602], 
             UndirectedEdge[76, 463] -> 
             RGBColor[
              0.4827936292790318, 0.5898280832845495, 0.9527482010251842], 
             UndirectedEdge[293, 445] -> 
             RGBColor[
              0.8864338531014064, 0.8692772537699642, 0.6464479308964578], 
             UndirectedEdge[48, 250] -> 
             RGBColor[
              0.20476233546869063`, 0.33254857563247214`, 0.9349722841349881],
              UndirectedEdge[459, 477] -> 
             RGBColor[
              0.19613686914455325`, 0.32348266363965217`, 0.9344810765880625],
              UndirectedEdge[400, 404] -> 
             RGBColor[
              0.9133476519960143, 0.9314027140164651, 0.9009347805127319], 
             UndirectedEdge[144, 246] -> 
             RGBColor[
              0.21838885852257034`, 0.34687091533356196`, 0.9357482944642723],
              UndirectedEdge[90, 393] -> 
             RGBColor[
              0.24183341082623228`, 0.3715126262751811, 0.9370834270348589], 
             UndirectedEdge[157, 360] -> 
             RGBColor[
              0.44762961538947754`, 0.5573651742459853, 0.9508478770838158], 
             UndirectedEdge[156, 250] -> 
             RGBColor[
              0.20951821380303975`, 0.3375473053019756, 0.9352431243704379], 
             UndirectedEdge[25, 220] -> 
             RGBColor[
              0.25296409856661417`, 0.38321168481668605`, 0.9377173032352967],
              UndirectedEdge[261, 407] -> 
             RGBColor[
              0.30321117252682794`, 0.43412485717667065`, 0.9406483566550587],
              UndirectedEdge[42, 364] -> 
             RGBColor[
              0.2024710281446618, 0.33014026635764265`, 0.9348417975725702], 
             UndirectedEdge[83, 257] -> 
             RGBColor[
              0.9791397410141973, 0.9396620716614368, 0.5198667768744751], 
             UndirectedEdge[137, 263] -> 
             RGBColor[
              0.21799699214111928`, 0.34645903892089325`, 0.935725978253563], 
             UndirectedEdge[27, 65] -> 
             RGBColor[
              0.1841954077512366, 0.31093143058289413`, 0.9338010280275222], 
             UndirectedEdge[318, 421] -> 
             RGBColor[
              0.19115878724665003`, 0.3182503839363337, 0.9341975821883891], 
             UndirectedEdge[203, 341] -> 
             RGBColor[
              0.9196841878836145, 0.6688261379622193, 0.4057355619852222], 
             UndirectedEdge[80, 483] -> 
             RGBColor[
              0.3997284089104274, 0.520646389689377, 0.9466913186431871], 
             UndirectedEdge[95, 319] -> 
             RGBColor[
              0.18277177150935192`, 0.30943509862892227`, 0.9337199540496279],
              UndirectedEdge[84, 376] -> 
             RGBColor[
              0.3233121821951179, 0.4513861043611917, 0.9419346395171995], 
             UndirectedEdge[260, 446] -> 
             RGBColor[
              0.19657895504970424`, 0.32394732395583115`, 0.9345062527263533],
              UndirectedEdge[174, 393] -> 
             RGBColor[
              0.20439651484045512`, 0.33216407495782907`, 0.9349514511913933],
              UndirectedEdge[185, 216] -> 
             RGBColor[
              0.20572802131241785`, 0.3335635726822483, 0.9350272785151843], 
             UndirectedEdge[143, 321] -> 
             RGBColor[
              0.78304348190439, 0.8293416997957703, 0.9255854595882844], 
             UndirectedEdge[296, 415] -> 
             RGBColor[
              0.18131418208775438`, 0.30790307973031616`, 0.9336369464883782],
              UndirectedEdge[42, 113] -> 
             RGBColor[
              0.1986334681543265, 0.3261067474924436, 0.9346232542082819], 
             UndirectedEdge[54, 264] -> 
             RGBColor[
              0.9275346951808384, 0.7361423049047013, 0.5163860611032753], 
             UndirectedEdge[9, 95] -> 
             RGBColor[
              0.18923630977445122`, 0.3162297382209408, 0.934088099940398], 
             UndirectedEdge[47, 55] -> 
             RGBColor[
              0.42760134170853215`, 0.539013813149998, 0.94946155992206], 
             UndirectedEdge[212, 330] -> 
             RGBColor[
              0.18576322285580926`, 0.312579303663019, 0.9338903127783529], 
             UndirectedEdge[89, 244] -> 
             RGBColor[
              0.37820158055690994`, 0.5020009329394131, 0.945319648175928], 
             UndirectedEdge[3, 247] -> 
             RGBColor[
              0.18396896047476097`, 0.31069342013773166`, 0.9337881321901256],
              UndirectedEdge[26, 318] -> 
             RGBColor[
              0.1914380372433468, 0.3185438933883344, 0.9342134850625876], 
             UndirectedEdge[46, 426] -> 
             RGBColor[
              0.19553365018810587`, 0.3228486422701351, 0.9344467241608754], 
             UndirectedEdge[102, 247] -> 
             RGBColor[
              0.19186086570906943`, 0.31898831291468205`, 0.934237564518192], 
             UndirectedEdge[285, 287] -> 
             RGBColor[
              0.2592707940788048, 0.38984042166758914`, 0.938076460214796], 
             UndirectedEdge[346, 390] -> 
             RGBColor[
              0.34866455216030523`, 0.47153274446045024`, 0.9436164276057963],
              UndirectedEdge[388, 473] -> 
             RGBColor[
              0.2961409162225916, 0.4267494884669002, 0.9402436685514961], 
             UndirectedEdge[377, 412] -> 
             RGBColor[
              0.18552364470094684`, 0.3123274918321262, 0.9338766691568576], 
             UndirectedEdge[7, 321] -> 
             RGBColor[
              0.7288945912633815, 0.7853811909936754, 0.9213226605631021], 
             UndirectedEdge[209, 275] -> 
             RGBColor[
              0.7418942375705933, 0.7941342962234403, 0.8470741774102124], 
             UndirectedEdge[204, 346] -> 
             RGBColor[
              0.3786592419849977, 0.5023973362656904, 0.9453488099574316], 
             UndirectedEdge[220, 297] -> 
             RGBColor[
              0.20614792707638763`, 0.3340049202637436, 0.9350511915272475], 
             UndirectedEdge[16, 185] -> 
             RGBColor[
              0.2408288180096403, 0.3704567355300795, 0.9370262169601158], 
             UndirectedEdge[323, 449] -> 
             RGBColor[
              0.9881583833202512, 0.9738084894895631, 0.5806455490390734], 
             UndirectedEdge[224, 481] -> 
             RGBColor[
              0.20560152977914695`, 0.33343062206075413`, 0.9350200750094919],
              UndirectedEdge[86, 476] -> 
             RGBColor[
              0.18437093737264393`, 0.311115923344214, 0.9338110241797885], 
             UndirectedEdge[66, 385] -> 
             RGBColor[
              0.189718897172314, 0.31673696817390284`, 0.9341155825787821], 
             UndirectedEdge[184, 316] -> 
             RGBColor[
              0.4897742836055883, 0.5962632949587165, 0.9530855424591965], 
             UndirectedEdge[308, 362] -> 
             RGBColor[
              0.18507064546441102`, 0.3118513609127166, 0.9338508715204893], 
             UndirectedEdge[216, 361] -> 
             RGBColor[
              0.21500792746091607`, 0.34331734242435297`, 0.9355557554419504],
              UndirectedEdge[123, 410] -> 
             RGBColor[
              0.18404732868398718`, 0.3107757900944599, 0.9337925951437056], 
             UndirectedEdge[174, 225] -> 
             RGBColor[
              0.18572114805288265`, 0.3125350803774465, 0.9338879166805704], 
             UndirectedEdge[3, 139] -> 
             RGBColor[
              0.18312900664284068`, 0.3098105754042345, 0.933740298061998], 
             UndirectedEdge[226, 472] -> 
             RGBColor[
              0.18505776823943543`, 0.311837826132804, 0.933850138181577], 
             UndirectedEdge[9, 441] -> 
             RGBColor[
              0.2076297588947049, 0.33556241945835885`, 0.9351355796571268], 
             UndirectedEdge[253, 354] -> 
             RGBColor[
              0.34404011319445926`, 0.47241198691533204`, 0.9431429096833921],
              UndirectedEdge[47, 73] -> 
             RGBColor[
              0.42925393472115597`, 0.5403554626061129, 0.9495916580976614], 
             UndirectedEdge[305, 432] -> 
             RGBColor[
              0.30089384576863576`, 0.43342166581410385`, 0.9404529542578681],
              UndirectedEdge[4, 226] -> 
             RGBColor[
              0.18424586592068898`, 0.3109844653182212, 0.9338039015456263], 
             UndirectedEdge[112, 359] -> 
             RGBColor[
              0.9514837896604106, 0.9611256689561112, 0.8747939095613684], 
             UndirectedEdge[101, 204] -> 
             RGBColor[
              0.2805071756988172, 0.41149947624089733`, 0.9393100698709307], 
             UndirectedEdge[256, 409] -> 
             RGBColor[
              0.2823955714492146, 0.41388608372871627`, 0.93940289994134], 
             UndirectedEdge[64, 268] -> 
             RGBColor[
              0.18555371944787077`, 0.31235910229799235`, 0.9338783818692034],
              UndirectedEdge[97, 395] -> 
             RGBColor[
              0.7462989112429244, 0.7905238121869427, 0.6818821167624534], 
             UndirectedEdge[117, 156] -> 
             RGBColor[
              0.19147940284680726`, 0.31858737126030207`, 0.9342158407725099],
              UndirectedEdge[48, 117] -> 
             RGBColor[
              0.18672352451245816`, 0.31358864159079863`, 0.9339450005370601],
              UndirectedEdge[5, 103] -> 
             RGBColor[
              0.5496901810493061, 0.6433974652672816, 0.958513754171764], 
             UndirectedEdge[344, 438] -> 
             RGBColor[
              0.19645882867909248`, 0.32382106352386636`, 0.934499411707258], 
             UndirectedEdge[42, 381] -> 
             RGBColor[
              0.19442462278648562`, 0.3216829841546337, 0.9343835666910121], 
             UndirectedEdge[224, 398] -> 
             RGBColor[
              0.2060967195595755, 0.33395109791683003`, 0.9350482753349197], 
             UndirectedEdge[226, 405] -> 
             RGBColor[
              0.18431945622850954`, 0.3110618133976357, 0.9338080924047896], 
             UndirectedEdge[231, 346] -> 
             RGBColor[
              0.6025366315327623, 0.6860240764087309, 0.963212758449727], 
             UndirectedEdge[168, 181] -> 
             RGBColor[
              0.25911497354415575`, 0.3896766444060805, 0.9380675864658636], 
             UndirectedEdge[178, 391] -> 
             RGBColor[
              0.47121205870336796`, 0.5815902029735522, 0.9515146858492259], 
             UndirectedEdge[30, 133] -> 
             RGBColor[
              0.18845727560531045`, 0.31541092391555475`, 0.934043735096943], 
             UndirectedEdge[120, 363] -> 
             RGBColor[
              0.18125858689584057`, 0.307844645658676, 0.9336337804244444], 
             UndirectedEdge[452, 468] -> 
             RGBColor[
              0.22415491498640028`, 0.35293140626614244`, 0.9360766628497713],
              UndirectedEdge[159, 344] -> 
             RGBColor[
              0.2111960256367822, 0.3393107919186533, 0.9353386732722694], 
             UndirectedEdge[68, 330] -> 
             RGBColor[
              0.18750410848445143`, 0.3144090848372459, 0.9339894536394946], 
             UndirectedEdge[359, 440] -> 
             RGBColor[
              0.9005793035034079, 0.7657528918366445, 0.6112602253720522], 
             UndirectedEdge[180, 413] -> 
             RGBColor[
              0.24672751485063993`, 0.37665663990895104`, 0.9373621390188708],
              UndirectedEdge[81, 442] -> 
             RGBColor[
              0.2381306078360068, 0.36762074556118485`, 0.9368725578823716], 
             UndirectedEdge[165, 277] -> 
             RGBColor[
              0.37457657867037175`, 0.49860046416423287`, 0.9450982108256749],
              UndirectedEdge[28, 310] -> 
             RGBColor[
              0.5603270606284811, 0.6539001893978842, 0.958555843487958], 
             UndirectedEdge[71, 470] -> 
             RGBColor[
              0.19617627269900267`, 0.32352407927370813`, 0.9344833205621961],
              UndirectedEdge[129, 276] -> 
             RGBColor[
              0.2514871752437865, 0.381659344762047, 0.9376331946369739], 
             UndirectedEdge[192, 251] -> 
             RGBColor[
              0.2759596386433615, 0.40698913765266753`, 0.9390412298997809], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.4280975104696688, 0.5447636755214684, 0.9486245811666656], 
             UndirectedEdge[15, 323] -> 
             RGBColor[
              0.82255832396822, 0.8598188337480478, 0.8682325932875272], 
             UndirectedEdge[20, 473] -> 
             RGBColor[
              0.25267572333140287`, 0.38290858416043305`, 0.9377008806922643],
              UndirectedEdge[336, 354] -> 
             RGBColor[
              0.4679691659715405, 0.5750820152163606, 0.9523301949713454], 
             UndirectedEdge[36, 440] -> 
             RGBColor[
              0.9428820049759663, 0.7963257915311912, 0.48910376799027133`], 
             UndirectedEdge[31, 311] -> 
             RGBColor[
              0.1909827965699547, 0.3180654065766735, 0.9341875597797062], 
             UndirectedEdge[366, 405] -> 
             RGBColor[
              0.18210802697612394`, 0.3087374610406655, 0.9336821547803826], 
             UndirectedEdge[257, 374] -> 
             RGBColor[
              0.9052484576679132, 0.6263565932934416, 0.25201642158872506`], 
             UndirectedEdge[194, 254] -> 
             RGBColor[
              0.18926826388068996`, 0.3162633240126051, 0.9340899196794763], 
             UndirectedEdge[284, 456] -> 
             RGBColor[
              0.2012208320986775, 0.3288262310463056, 0.9347706007572507], 
             UndirectedEdge[30, 429] -> 
             RGBColor[
              0.18544154731921458`, 0.312241202278651, 0.9338719938324201], 
             UndirectedEdge[182, 463] -> 
             RGBColor[
              0.4500781331882001, 0.5614915648993155, 0.9506635985434537], 
             UndirectedEdge[130, 238] -> 
             RGBColor[
              0.39480407867420486`, 0.5149363424561325, 0.9466476293366854], 
             UndirectedEdge[19, 67] -> 
             RGBColor[
              0.1920452315036252, 0.3191820930542266, 0.9342480638774471], 
             UndirectedEdge[114, 446] -> 
             RGBColor[
              0.18242070987008802`, 0.30906611058746236`, 0.933699961608621], 
             UndirectedEdge[164, 418] -> 
             RGBColor[
              0.3962653140595378, 0.5170172416815048, 0.9466446107033122], 
             UndirectedEdge[96, 457] -> 
             RGBColor[
              0.47001276809964954`, 0.5806165648340276, 0.951420273299755], 
             UndirectedEdge[285, 354] -> 
             RGBColor[
              0.2624877417671351, 0.39305135672859914`, 0.93826589544543], 
             UndirectedEdge[432, 460] -> 
             RGBColor[
              0.2959533208946317, 0.4283960831575556, 0.9401654758500221], 
             UndirectedEdge[82, 249] -> 
             RGBColor[
              0.6235359473541606, 0.7039577755666018, 0.9643921411464688], 
             UndirectedEdge[176, 262] -> 
             RGBColor[
              0.33005042418212294`, 0.46029482143506084`, 0.9422514990701223],
              UndirectedEdge[216, 358] -> 
             RGBColor[
              0.21239908038802668`, 0.34057527874028815`, 0.9354071854605928],
              UndirectedEdge[54, 374] -> 
             RGBColor[
              0.9184848946909366, 0.6778098895741775, 0.5081596346636814], 
             UndirectedEdge[214, 491] -> 
             RGBColor[
              0.1845859949601158, 0.3113419625040855, 0.9338232713912458], 
             UndirectedEdge[68, 357] -> 
             RGBColor[
              0.18698592728629504`, 0.313864443543398, 0.93395994398684], 
             UndirectedEdge[260, 328] -> 
             RGBColor[
              0.2263686482084435, 0.35525818024130285`, 0.9362027316818419], 
             UndirectedEdge[224, 286] -> 
             RGBColor[
              0.19666508001759797`, 0.3240378467577258, 0.9345111574158644], 
             UndirectedEdge[219, 293] -> 
             RGBColor[
              0.7396376270146225, 0.7965298027687717, 0.9746838244203624], 
             UndirectedEdge[209, 404] -> 
             RGBColor[
              0.9156515263183187, 0.9323554252556073, 0.8627536207565263], 
             UndirectedEdge[197, 289] -> 
             RGBColor[
              0.22048333522571711`, 0.34907234314606217`, 0.9358675718140159],
              UndirectedEdge[227, 424] -> 
             RGBColor[
              0.19331536997885967`, 0.3205170891231287, 0.9343203963846103], 
             UndirectedEdge[458, 461] -> 
             RGBColor[
              0.24614691137880979`, 0.3760463888476713, 0.937329074510076], 
             UndirectedEdge[292, 464] -> 
             RGBColor[
              0.19378696997725373`, 0.3210127706226078, 0.9343472533068491], 
             UndirectedEdge[386, 441] -> 
             RGBColor[
              0.26353501578649874`, 0.39432238904964745`, 0.9383193013326985],
              UndirectedEdge[257, 343] -> 
             RGBColor[
              0.9046416145156388, 0.621692130904697, 0.25143530790077595`], 
             UndirectedEdge[132, 457] -> 
             RGBColor[
              0.37078286929344473`, 0.4917742570671961, 0.9450898009992874], 
             UndirectedEdge[69, 259] -> 
             RGBColor[
              0.5630647117651555, 0.6552495084047187, 0.9592526654459177], 
             UndirectedEdge[68, 95] -> 
             RGBColor[
              0.18505409827792216`, 0.3118339687705646, 0.933849929182698], 
             UndirectedEdge[247, 278] -> 
             RGBColor[
              0.18437169562717964`, 0.3111167203178072, 0.9338110673612625], 
             UndirectedEdge[293, 440] -> 
             RGBColor[
              0.8506906968621433, 0.7260557976902806, 0.6064798524386981], 
             UndirectedEdge[307, 442] -> 
             RGBColor[
              0.21483864965875055`, 0.34313942072144443`, 0.9355461153215412],
              UndirectedEdge[406, 493] -> 
             RGBColor[
              0.33870341661598447`, 0.4633663515821581, 0.9429648172026237], 
             UndirectedEdge[155, 479] -> 
             RGBColor[
              0.18812050432693928`, 0.3150569559494543, 0.9340245564708484], 
             UndirectedEdge[311, 488] -> 
             RGBColor[
              0.18625665477025105`, 0.3130979318904876, 0.9339184129959133], 
             UndirectedEdge[226, 345] -> 
             RGBColor[
              0.18891037080707027`, 0.3158871557004993, 0.9340695381983891], 
             UndirectedEdge[183, 273] -> 
             RGBColor[
              0.19206178134703447`, 0.31919948798897047`, 0.934249006366546], 
             UndirectedEdge[384, 499] -> 
             RGBColor[
              0.4483239267217146, 0.554218492373762, 0.9512402754132152], 
             UndirectedEdge[20, 325] -> 
             RGBColor[
              0.23769654620583044`, 0.3671645192667726, 0.9368478387146697], 
             UndirectedEdge[252, 424] -> 
             RGBColor[
              0.1878893571902253, 0.31481400565319295`, 0.934011392983364], 
             UndirectedEdge[285, 473] -> 
             RGBColor[
              0.2389908172005852, 0.3685248801437806, 0.9369215455331186], 
             UndirectedEdge[71, 236] -> 
             RGBColor[
              0.20304903767595361`, 0.3307477910229513, 0.9348747143602888], 
             UndirectedEdge[2, 446] -> 
             RGBColor[
              0.18380079735160318`, 0.310516670033135, 0.9337785555490368], 
             UndirectedEdge[33, 351] -> 
             RGBColor[
              0.24823088148452888`, 0.3782367735601183, 0.937447753524639], 
             UndirectedEdge[172, 466] -> 
             RGBColor[
              0.20918917113405136`, 0.3372014605943586, 0.935224385877214], 
             UndirectedEdge[12, 279] -> 
             RGBColor[
              0.2010090657422573, 0.3286036511789455, 0.9347585409765328], 
             UndirectedEdge[171, 219] -> 
             RGBColor[
              0.5701105988481052, 0.6614643237945504, 0.9595848784963202], 
             UndirectedEdge[153, 223] -> 
             RGBColor[
              0.21791092009915627`, 0.34636857174750746`, 0.9357210765781054],
              UndirectedEdge[121, 489] -> 
             RGBColor[
              0.1983767553672155, 0.32583692607665915`, 0.9346086347948284], 
             UndirectedEdge[362, 470] -> 
             RGBColor[
              0.1869253840691414, 0.31380080878350786`, 0.9339564961401887], 
             UndirectedEdge[168, 232] -> 
             RGBColor[
              0.28558604817661837`, 0.417499422207868, 0.9395750750057368], 
             UndirectedEdge[285, 409] -> 
             RGBColor[
              0.23381068107618688`, 0.3630802286374379, 0.9366265444441588], 
             UndirectedEdge[159, 439] -> 
             RGBColor[
              0.21567326392113564`, 0.34401665322881175`, 0.9355936453690827],
              UndirectedEdge[156, 263] -> 
             RGBColor[
              0.21186651840498638`, 0.34001552232973276`, 0.9353768568435135],
              UndirectedEdge[149, 314] -> 
             RGBColor[
              0.41196878637874557`, 0.5240737659037882, 0.9484356108143341], 
             UndirectedEdge[110, 457] -> 
             RGBColor[
              0.44316356556908426`, 0.5578351155851111, 0.9495785036311474], 
             UndirectedEdge[43, 263] -> 
             RGBColor[
              0.2263534256582619, 0.35524218037589655`, 0.9362018647801287], 
             UndirectedEdge[141, 160] -> 
             RGBColor[
              0.2233789267066098, 0.352115793383584, 0.936032471465209], 
             UndirectedEdge[345, 389] -> 
             RGBColor[
              0.1928812337006961, 0.3200607843689489, 0.9342956729658158], 
             UndirectedEdge[225, 247] -> 
             RGBColor[
              0.18412221385498584`, 0.31085449915717356`, 0.9337968597434113],
              UndirectedEdge[171, 293] -> 
             RGBColor[
              0.6402218599260903, 0.7162357738139922, 0.9665729137735878], 
             UndirectedEdge[179, 415] -> 
             RGBColor[
              0.19025558687597238`, 0.31730106308054046`, 0.9341461462634442],
              UndirectedEdge[143, 414] -> 
             RGBColor[
              0.5016592032391687, 0.6054763090493759, 0.9541415518219014], 
             UndirectedEdge[77, 388] -> 
             RGBColor[
              0.33157794270842256`, 0.4616178812072281, 0.9423488311998864], 
             UndirectedEdge[305, 406] -> 
             RGBColor[
              0.3635284030084348, 0.4892917640422711, 0.9443846862775205], 
             UndirectedEdge[55, 256] -> 
             RGBColor[
              0.4425753647760989, 0.554492515651166, 0.9503238262490175], 
             UndirectedEdge[367, 450] -> 
             RGBColor[
              0.20633807556762712`, 0.3342047783841471, 0.9350620202025242], 
             UndirectedEdge[171, 258] -> 
             RGBColor[
              0.44293779831735625`, 0.5576003693038944, 0.9495749484754112], 
             UndirectedEdge[366, 423] -> 
             RGBColor[
              0.18087837131958237`, 0.30744501498096866`, 0.933612127709855], 
             UndirectedEdge[309, 393] -> 
             RGBColor[
              0.20475589581124165`, 0.33254180714419534`, 0.9349719174060231],
              UndirectedEdge[324, 360] -> 
             RGBColor[
              0.7679481729777577, 0.8188024264455834, 0.9741261052850922], 
             UndirectedEdge[125, 310] -> 
             RGBColor[
              0.7113812015825887, 0.7744556684644794, 0.9718674880046061], 
             UndirectedEdge[33, 463] -> 
             RGBColor[
              0.4057152506945697, 0.5182150283519088, 0.9480144771137997], 
             UndirectedEdge[137, 280] -> 
             RGBColor[
              0.2325647771126936, 0.3617707045769326, 0.9365555920565876], 
             UndirectedEdge[72, 179] -> 
             RGBColor[
              0.20561407521805922`, 0.3334438081124777, 0.9350207894536787], 
             UndirectedEdge[17, 165] -> 
             RGBColor[
              0.3406850289827465, 0.4692453072636289, 0.9429386712487001], 
             UndirectedEdge[402, 417] -> 
             RGBColor[
              0.20763019049226705`, 0.33556287309476157`, 0.9351356042359695],
              UndirectedEdge[102, 225] -> 
             RGBColor[
              0.19170377678695943`, 0.3188232024975315, 0.9342286185364699], 
             UndirectedEdge[83, 231] -> 
             RGBColor[
              0.879442405436877, 0.9037944293481288, 0.8529223377718652], 
             UndirectedEdge[194, 377] -> 
             RGBColor[
              0.1834493331063201, 0.31014725882722227`, 0.9337585401802126], 
             UndirectedEdge[131, 495] -> 
             RGBColor[
              0.8599106722287021, 0.41795803680078086`, 0.20329863351297417`],
              UndirectedEdge[213, 447] -> 
             RGBColor[
              0.2179735437754206, 0.34643439320183167`, 0.9357246429038253], 
             UndirectedEdge[146, 166] -> 
             RGBColor[
              0.18787743892822623`, 0.31480147880417053`, 0.9340107142559747],
              UndirectedEdge[422, 428] -> 
             RGBColor[
              0.19715708759112932`, 0.32455497791258914`, 0.9345391765193171],
              UndirectedEdge[232, 338] -> 
             RGBColor[
              0.351395977443279, 0.47598308304576464`, 0.9437141472934822], 
             UndirectedEdge[366, 469] -> 
             RGBColor[
              0.1819546848445577, 0.30857628873793674`, 0.9336734221728392], 
             UndirectedEdge[245, 482] -> 
             RGBColor[
              0.2881486049407218, 0.4180084472344471, 0.93980098984346], 
             UndirectedEdge[40, 243] -> 
             RGBColor[
              0.19079403389915217`, 0.3178670050414155, 0.9341768100248533], 
             UndirectedEdge[174, 320] -> 
             RGBColor[
              0.1843078028000945, 0.31104956490550145`, 0.933807428759281], 
             UndirectedEdge[30, 31] -> 
             RGBColor[
              0.185457486240386, 0.3122579550953881, 0.9338729015304014], 
             UndirectedEdge[77, 354] -> 
             RGBColor[
              0.32252783628299564`, 0.4537791338930982, 0.9417721664211531], 
             UndirectedEdge[24, 223] -> 
             RGBColor[
              0.19673773915135, 0.32411421611415436`, 0.934515295246042], 
             UndirectedEdge[261, 391] -> 
             RGBColor[
              0.40120374518351687`, 0.5213867241354746, 0.9469338462657712], 
             UndirectedEdge[125, 323] -> 
             RGBColor[
              0.8853299376421364, 0.9088564954320449, 0.8744890811044619], 
             UndirectedEdge[1, 364] -> 
             RGBColor[
              0.2018347227926697, 0.32947146908860947`, 0.9348055609241036], 
             UndirectedEdge[88, 133] -> 
             RGBColor[
              0.19376977710770305`, 0.3209946998266191, 0.9343462741983627], 
             UndirectedEdge[178, 407] -> 
             RGBColor[
              0.3732194860466791, 0.4943283360147483, 0.9452291962385135], 
             UndirectedEdge[103, 486] -> 
             RGBColor[
              0.41156934709801946`, 0.5309024152046116, 0.94744581275397], 
             UndirectedEdge[204, 486] -> 
             RGBColor[
              0.3646188827036643, 0.4902362827451757, 0.9444541706794272], 
             UndirectedEdge[89, 407] -> 
             RGBColor[
              0.2934055397651449, 0.4256317109239335, 0.9400235504062648], 
             UndirectedEdge[38, 301] -> 
             RGBColor[
              0.5876340036038425, 0.6758909546392042, 0.9608274105699129], 
             UndirectedEdge[92, 132] -> 
             RGBColor[
              0.27212682678288186`, 0.40335292715912663`, 0.9388085922584972],
              UndirectedEdge[8, 146] -> 
             RGBColor[
              0.18877984751216192`, 0.31574996744189576`, 0.934062105089836], 
             UndirectedEdge[44, 110] -> 
             RGBColor[
              0.34804321230268565`, 0.4731300192483041, 0.9434986471622288], 
             UndirectedEdge[102, 252] -> 
             RGBColor[
              0.19087465031632422`, 0.3179517380072394, 0.93418140101055], 
             UndirectedEdge[273, 283] -> 
             RGBColor[
              0.18473808843290457`, 0.31150182238726964`, 0.933831932889519], 
             UndirectedEdge[158, 428] -> 
             RGBColor[
              0.1897406655144195, 0.31675984808164837`, 0.9341168222536617], 
             UndirectedEdge[176, 328] -> 
             RGBColor[
              0.27995998628272956`, 0.4108290857819987, 0.939282396167026], 
             UndirectedEdge[45, 398] -> 
             RGBColor[
              0.20371823459922628`, 0.33145115941884645`, 0.934912824135081], 
             UndirectedEdge[233, 275] -> 
             RGBColor[
              0.7259348855245369, 0.7839404012756612, 0.9506021698205669], 
             UndirectedEdge[250, 485] -> 
             RGBColor[
              0.23749323092755345`, 0.3669508220183703, 0.9368362602103498], 
             UndirectedEdge[29, 65] -> 
             RGBColor[
              0.1838043123267574, 0.3105203644948844, 0.9337787557216719], 
             UndirectedEdge[166, 453] -> 
             RGBColor[
              0.2178060906512075, 0.3462583893511425, 0.935715106696126], 
             UndirectedEdge[222, 294] -> 
             RGBColor[
              0.19229714625130181`, 0.3194468714263523, 0.9342624100496528], 
             UndirectedEdge[150, 220] -> 
             RGBColor[
              0.21619691693173887`, 0.3445670457444743, 0.9356234666333614], 
             UndirectedEdge[311, 423] -> 
             RGBColor[
              0.184592254538111, 0.31134854171743864`, 0.9338236278649524], 
             UndirectedEdge[210, 424] -> 
             RGBColor[
              0.19449774707264864`, 0.3217598424157385, 0.9343877310109313], 
             UndirectedEdge[179, 312] -> 
             RGBColor[
              0.19754047021008475`, 0.3249579373529733, 0.9345610095923028], 
             UndirectedEdge[310, 323] -> 
             RGBColor[
              0.8187613818125008, 0.8568526336781708, 0.8678541495778869], 
             UndirectedEdge[108, 349] -> 
             RGBColor[
              0.19740440059431363`, 0.32481491955948594`, 0.9345532606289816],
              UndirectedEdge[355, 395] -> 
             RGBColor[
              0.5319254348002241, 0.6308800567954042, 0.9562942652159951], 
             UndirectedEdge[47, 200] -> 
             RGBColor[
              0.2722924613184966, 0.40352701955789383`, 0.9388180249002662], 
             UndirectedEdge[152, 217] -> 
             RGBColor[
              0.18273892560736155`, 0.30940057550337985`, 0.9337180835241007],
              UndirectedEdge[174, 210] -> 
             RGBColor[
              0.19150041146467078`, 0.3186094526497, 0.9342170371822176], 
             UndirectedEdge[135, 211] -> 
             RGBColor[
              0.18373947818140363`, 0.31045221969739534`, 0.9337750635130075],
              UndirectedEdge[52, 491] -> 
             RGBColor[
              0.18081085908512495`, 0.30737405534203105`, 0.9336082829879782],
              UndirectedEdge[41, 250] -> 
             RGBColor[
              0.2413646105317827, 0.37101988744205927`, 0.9370567295516178], 
             UndirectedEdge[220, 392] -> 
             RGBColor[
              0.22694196327999852`, 0.35586077073178224`, 0.9362353811270232],
              UndirectedEdge[182, 359] -> 
             RGBColor[
              0.6272616214525479, 0.7019681789194203, 0.9672182481235007], 
             UndirectedEdge[89, 391] -> 
             RGBColor[
              0.39139811242183375`, 0.5128935778827375, 0.9463090400169774], 
             UndirectedEdge[62, 190] -> 
             RGBColor[
              0.233868572190446, 0.3631410758690329, 0.9366298412574736], 
             UndirectedEdge[21, 87] -> 
             RGBColor[
              0.30420754500978997`, 0.43707179605062296`, 0.94063554170235], 
             UndirectedEdge[185, 286] -> 
             RGBColor[
              0.1994684028845588, 0.32698431683183726`, 0.9346708025059933], 
             UndirectedEdge[114, 294] -> 
             RGBColor[
              0.18446317038438925`, 0.311212866087469, 0.9338162767133609], 
             UndirectedEdge[48, 156] -> 
             RGBColor[
              0.19463895940372045`, 0.3219082655290739, 0.9343957728442809], 
             UndirectedEdge[68, 450] -> 
             RGBColor[
              0.20047702738706202`, 0.3280444451344552, 0.9347282421792846], 
             UndirectedEdge[149, 406] -> 
             RGBColor[
              0.48881588257467606`, 0.5948821437018659, 0.9531767259019711], 
             UndirectedEdge[123, 158] -> 
             RGBColor[
              0.1887768797193095, 0.31574684810343895`, 0.9340619360784235], 
             UndirectedEdge[55, 91] -> 
             RGBColor[
              0.5169586982013866, 0.6187293857806677, 0.955116028885972], 
             UndirectedEdge[135, 169] -> 
             RGBColor[
              0.1819041358977289, 0.3085231585898313, 0.9336705434850978], 
             UndirectedEdge[141, 456] -> 
             RGBColor[
              0.20146025215418084`, 0.3290778767047479, 0.9347842353752214], 
             UndirectedEdge[287, 354] -> 
             RGBColor[
              0.3073707866753843, 0.44022628267657893`, 0.9408219184544402], 
             UndirectedEdge[223, 411] -> 
             RGBColor[
              0.24469698646716248`, 0.3745224258349809, 0.9372465034313293], 
             UndirectedEdge[127, 301] -> 
             RGBColor[
              0.7442995113076243, 0.8002700424356418, 0.9751223810067287], 
             UndirectedEdge[167, 201] -> 
             RGBColor[
              0.2486574185518422, 0.37868509106187664`, 0.9374720441796176], 
             UndirectedEdge[28, 218] -> 
             RGBColor[
              0.38085905105137724`, 0.5015767053192113, 0.9457353767574448], 
             UndirectedEdge[112, 317] -> 
             RGBColor[
              0.9053802389728423, 0.5628414484156407, 0.4612866067791993], 
             UndirectedEdge[275, 372] -> 
             RGBColor[
              0.55179178264052, 0.6470084529409276, 0.9578582168908132], 
             UndirectedEdge[85, 146] -> 
             RGBColor[
              0.1836713842833611, 0.3103806486931501, 0.9337711856662498], 
             UndirectedEdge[7, 262] -> 
             RGBColor[
              0.407760697816997, 0.5270866817975668, 0.9473459424920676], 
             UndirectedEdge[448, 455] -> 
             RGBColor[
              0.45681433053997933`, 0.564999766000337, 0.9515547264505798], 
             UndirectedEdge[9, 368] -> 
             RGBColor[
              0.18651190777224702`, 0.3133662189795604, 0.933932949276764], 
             UndirectedEdge[216, 399] -> 
             RGBColor[
              0.20389703761891642`, 0.33163909272930703`, 0.934923006702537], 
             UndirectedEdge[205, 474] -> 
             RGBColor[
              0.23349741976768085`, 0.3627509711402839, 0.936608704676068], 
             UndirectedEdge[125, 242] -> 
             RGBColor[
              0.8755313279725643, 0.9029638772422787, 0.9544497242112633], 
             UndirectedEdge[280, 338] -> 
             RGBColor[
              0.33890305736331594`, 0.4628522319448411, 0.9430026939765475], 
             UndirectedEdge[232, 393] -> 
             RGBColor[
              0.24988773384149937`, 0.3799782304378011, 0.9375421088152751], 
             UndirectedEdge[403, 483] -> 
             RGBColor[
              0.5977248399072642, 0.6827163434594106, 0.9625421629597528], 
             UndirectedEdge[427, 433] -> 
             RGBColor[
              0.18359379097292866`, 0.3102990932041856, 0.9337667668420098], 
             UndirectedEdge[269, 310] -> 
             RGBColor[
              0.6233432481970155, 0.705059569312919, 0.963516708609254], 
             UndirectedEdge[212, 357] -> 
             RGBColor[
              0.18524504165765288`, 0.3120346623691711, 0.9338608031256983], 
             UndirectedEdge[88, 307] -> 
             RGBColor[
              0.1906659921562372, 0.31773242505129645`, 0.9341695182370151], 
             UndirectedEdge[212, 217] -> 
             RGBColor[
              0.18159408433829743`, 0.30819727474246456`, 0.9336528865074684],
              UndirectedEdge[67, 124] -> 
             RGBColor[
              0.18312075215718818`, 0.30980189941644914`, 0.9337398279812515],
              UndirectedEdge[364, 380] -> 
             RGBColor[
              0.19593044529067147`, 0.3232656990811941, 0.9344693210549606], 
             UndirectedEdge[82, 384] -> 
             RGBColor[
              0.39409857332891574`, 0.5101959076651558, 0.9469714569601196], 
             UndirectedEdge[222, 439] -> 
             RGBColor[
              0.19816628717948753`, 0.32561571066690326`, 0.9345966489428971],
              UndirectedEdge[337, 420] -> 
             RGBColor[
              0.18856527989536503`, 0.3155244432722696, 0.9340498857814837], 
             UndirectedEdge[61, 99] -> 
             RGBColor[
              0.9849784772768306, 0.9873095986531333, 0.8651734232542627], 
             UndirectedEdge[63, 439] -> 
             RGBColor[
              0.20302072388459882`, 0.33071803143303935`, 0.9348731019317575],
              UndirectedEdge[37, 53] -> 
             RGBColor[
              0.8472647112443593, 0.3588769520067575, 0.19268158199931773`], 
             UndirectedEdge[39, 62] -> 
             RGBColor[
              0.2493920758689453, 0.37945726248211625`, 0.9375138818269986], 
             UndirectedEdge[130, 182] -> 
             RGBColor[
              0.323958117743938, 0.4544792345302443, 0.9418830285018508], 
             UndirectedEdge[152, 398] -> 
             RGBColor[
              0.19524728601816377`, 0.32254765537098895`, 0.934430416145035], 
             UndirectedEdge[23, 110] -> 
             RGBColor[
              0.42451306437954106`, 0.5421136125437187, 0.9482705749734688], 
             UndirectedEdge[322, 440] -> 
             RGBColor[
              0.8562073757382771, 0.38077868388003167`, 0.19941112665599764`],
              UndirectedEdge[141, 432] -> 
             RGBColor[
              0.24927102921021138`, 0.3793300347689854, 0.937506988398856], 
             UndirectedEdge[161, 459] -> 
             RGBColor[
              0.20416528068413636`, 0.3319210331984458, 0.9349382827482713], 
             UndirectedEdge[185, 333] -> 
             RGBColor[
              0.22166458508016862`, 0.3503139116386572, 0.9359348422457243], 
             UndirectedEdge[297, 474] -> 
             RGBColor[
              0.21238801987541464`, 0.34056365344025585`, 0.935406555580762], 
             UndirectedEdge[265, 329] -> 
             RGBColor[
              0.18295078871918613`, 0.3096232570668046, 0.9337301488148957], 
             UndirectedEdge[90, 280] -> 
             RGBColor[
              0.25791236607974777`, 0.3884126277112705, 0.937999099749864], 
             UndirectedEdge[183, 430] -> 
             RGBColor[
              0.19926050368686765`, 0.32676580159349333`, 0.9346589629542441],
              UndirectedEdge[86, 194] -> 
             RGBColor[
              0.18570943860608155`, 0.31252277300643677`, 0.9338872498448976],
              UndirectedEdge[143, 186] -> 
             RGBColor[
              0.7869875185761387, 0.829282852672385, 0.7373913878754195], 
             UndirectedEdge[1, 416] -> 
             RGBColor[
              0.20425325698717794`, 0.33201350187096224`, 0.9349432928685801],
              UndirectedEdge[27, 86] -> 
             RGBColor[
              0.18526169591288671`, 0.3120521670473626, 0.9338617515608961], 
             UndirectedEdge[66, 415] -> 
             RGBColor[
              0.1891407128871262, 0.3161292598311696, 0.9340826558390877], 
             UndirectedEdge[413, 490] -> 
             RGBColor[
              0.2231389506309891, 0.3518635633127446, 0.9360188051827152], 
             UndirectedEdge[226, 284] -> 
             RGBColor[
              0.19690493413279425`, 0.3242899486404264, 0.9345248167528926], 
             UndirectedEdge[245, 438] -> 
             RGBColor[
              0.22328352119424416`, 0.3520155161410289, 0.9360270382624196], 
             UndirectedEdge[53, 163] -> 
             RGBColor[
              0.8659915986516313, 0.4439113739475036, 0.20830775588996076`], 
             UndirectedEdge[367, 368] -> 
             RGBColor[
              0.1881907444562831, 0.3151307827788761, 0.9340285565423035], 
             UndirectedEdge[112, 175] -> 
             RGBColor[
              0.6955594457176699, 0.7552129086866064, 0.8524579222934991], 
             UndirectedEdge[277, 288] -> 
             RGBColor[
              0.5772249873338873, 0.6663273536018384, 0.9606573715704986], 
             UndirectedEdge[249, 323] -> 
             RGBColor[
              0.8598299314382067, 0.8889356967783099, 0.8719474787971606], 
             UndirectedEdge[416, 452] -> 
             RGBColor[
              0.2180186471312624, 0.3464817996885393, 0.935727211473216], 
             UndirectedEdge[13, 87] -> 
             RGBColor[
              0.28067879095443904`, 0.41234158372927926`, 0.9392956139665702],
              UndirectedEdge[471, 497] -> 
             RGBColor[
              0.7175094368939575, 0.7772891603319885, 0.9550059228659136], 
             UndirectedEdge[17, 321] -> 
             RGBColor[
              0.6804393139131792, 0.743928538014085, 0.9180923196352385], 
             UndirectedEdge[106, 227] -> 
             RGBColor[
              0.18640315120824044`, 0.31325190893522514`, 0.9339267557513348],
              UndirectedEdge[37, 100] -> 
             RGBColor[
              0.9275408237580072, 0.7267589387889348, 0.3553036056592853], 
             UndirectedEdge[9, 375] -> 
             RGBColor[
              0.19826733232951002`, 0.32572191552620944`, 0.934602403314708], 
             UndirectedEdge[10, 302] -> 
             RGBColor[
              0.23577384795439005`, 0.3651436414983986, 0.9367383438936274], 
             UndirectedEdge[14, 272] -> 
             RGBColor[
              0.24410352476956199`, 0.37389865996315785`, 0.9372127066655989],
              UndirectedEdge[63, 387] -> 
             RGBColor[
              0.1978509608116646, 0.3252842826614749, 0.9345786915727331], 
             UndirectedEdge[471, 483] -> 
             RGBColor[
              0.7044387287985243, 0.7666430914560537, 0.9539865308155939], 
             UndirectedEdge[46, 392] -> 
             RGBColor[
              0.22028047155655125`, 0.34885912056746937`, 0.9358560190281668],
              UndirectedEdge[122, 357] -> 
             RGBColor[
              0.18711144917701383`, 0.313996375009091, 0.9339670922728234], 
             UndirectedEdge[75, 125] -> 
             RGBColor[
              0.8216340480291034, 0.6538916931792487, 0.593916539379413], 
             UndirectedEdge[244, 261] -> 
             RGBColor[
              0.388007213318593, 0.5104940791921502, 0.9459444544247217], 
             UndirectedEdge[7, 178] -> 
             RGBColor[
              0.47083170751539166`, 0.5812814167445273, 0.9514847432104361], 
             UndirectedEdge[108, 487] -> 
             RGBColor[
              0.20117686323780593`, 0.3287800169857428, 0.9347680967956702], 
             UndirectedEdge[338, 480] -> 
             RGBColor[
              0.3338467491074454, 0.4575377313794614, 0.9427147447015134], 
             UndirectedEdge[237, 284] -> 
             RGBColor[
              0.21986017242091369`, 0.34841735952740993`, 0.9358320836141691],
              UndirectedEdge[162, 456] -> 
             RGBColor[
              0.18946877260235598`, 0.3164740713920633, 0.9341013383545491], 
             UndirectedEdge[104, 310] -> 
             RGBColor[
              0.7844721843600413, 0.7296832002097726, 0.6115226819006405], 
             UndirectedEdge[168, 390] -> 
             RGBColor[
              0.27431313717116323`, 0.40565087799729527`, 0.9389330994007534],
              UndirectedEdge[164, 431] -> 
             RGBColor[
              0.36863866395623385`, 0.49371801522607117`, 0.9447103075862879],
              UndirectedEdge[57, 60] -> 
             RGBColor[
              0.9740668501566808, 0.9799635557919238, 0.9191037618424754], 
             UndirectedEdge[158, 247] -> 
             RGBColor[
              0.18799329436094186`, 0.3149232502096133, 0.9340173120514751], 
             UndirectedEdge[32, 475] -> 
             RGBColor[
              0.27810050553156784`, 0.4070629513265539, 0.9392428367847124], 
             UndirectedEdge[53, 293] -> 
             RGBColor[
              0.8212117750972121, 0.5517293002984074, 0.5802972295340347], 
             UndirectedEdge[72, 294] -> 
             RGBColor[
              0.19930405825751749`, 0.32681158020876566`, 0.9346614433226095],
              UndirectedEdge[87, 287] -> 
             RGBColor[
              0.3062830568763104, 0.4392532906173888, 0.9407537390327037], 
             UndirectedEdge[154, 374] -> 
             RGBColor[
              0.9154556938707563, 0.6764368032115899, 0.5529680520443171], 
             UndirectedEdge[119, 364] -> 
             RGBColor[
              0.19435544195191212`, 0.32161027071117865`, 0.934379626944827], 
             UndirectedEdge[90, 342] -> 
             RGBColor[
              0.36933196448262395`, 0.489404611907154, 0.9450840596145658], 
             UndirectedEdge[401, 428] -> 
             RGBColor[
              0.18425068425914937`, 0.3109895296974434, 0.9338041759428735], 
             UndirectedEdge[183, 477] -> 
             RGBColor[
              0.19737928626943302`, 0.32478852281169623`, 0.934551830405333], 
             UndirectedEdge[82, 269] -> 
             RGBColor[
              0.5609980001725171, 0.6544824750687763, 0.958582964058418], 
             UndirectedEdge[202, 273] -> 
             RGBColor[
              0.18695948203332297`, 0.31383664790579846`, 0.9339584379688055],
              UndirectedEdge[147, 242] -> 
             RGBColor[
              0.8960966123696098, 0.5635667746530044, 0.5481508384278233], 
             UndirectedEdge[117, 198] -> 
             RGBColor[
              0.18298777738438862`, 0.30966213449914926`, 0.9337322552646592],
              UndirectedEdge[240, 434] -> 
             RGBColor[
              0.9649429424873008, 0.8858096572696792, 0.4713319778660402], 
             UndirectedEdge[249, 310] -> 
             RGBColor[
              0.685881195378659, 0.7545348698107444, 0.9693258856973048], 
             UndirectedEdge[448, 478] -> 
             RGBColor[
              0.2749488841783959, 0.4063190884105853, 0.938969304252312], 
             UndirectedEdge[121, 196] -> 
             RGBColor[
              0.19856429776732792`, 0.3260340450300523, 0.9346193150570707], 
             UndirectedEdge[200, 256] -> 
             RGBColor[
              0.28726648438606334`, 0.4190057220590618, 0.9396802912272235], 
             UndirectedEdge[79, 184] -> 
             RGBColor[
              0.7135412330833855, 0.7751234699043363, 0.9730039594525782], 
             UndirectedEdge[51, 240] -> 
             RGBColor[
              0.995029239647029, 0.991776371162987, 0.7003415954352006], 
             UndirectedEdge[339, 387] -> 
             RGBColor[
              0.1845385025539545, 0.3112920449740175, 0.9338205667689736], 
             UndirectedEdge[46, 142] -> 
             RGBColor[
              0.2097115161750654, 0.33775047835105276`, 0.9352541326545596], 
             UndirectedEdge[233, 259] -> 
             RGBColor[
              0.8229153142047934, 0.8620467284314131, 0.9586653393897153], 
             UndirectedEdge[266, 471] -> 
             RGBColor[
              0.975210019564589, 0.978006622458981, 0.7504581704123827], 
             UndirectedEdge[167, 456] -> 
             RGBColor[
              0.21773731167177224`, 0.3461860982829168, 0.9357111898349966], 
             UndirectedEdge[10, 181] -> 
             RGBColor[
              0.22615215264020183`, 0.355030629672469, 0.9361904025795069], 
             UndirectedEdge[31, 429] -> 
             RGBColor[
              0.19196505677432735`, 0.31909782433036316`, 0.9342434980452214],
              UndirectedEdge[317, 322] -> 
             RGBColor[
              0.8190506229224375, 0.1474370125838577, 0.16587620406611453`], 
             UndirectedEdge[52, 466] -> 
             RGBColor[
              0.18744056730247904`, 0.3143422990262493, 0.933985835063182], 
             UndirectedEdge[207, 281] -> 
             RGBColor[
              0.8467054680453859, 0.3339234893640672, 0.19133725700073073`], 
             UndirectedEdge[358, 398] -> 
             RGBColor[
              0.21557110150214517`, 0.3439092740489813, 0.935587827370457], 
             UndirectedEdge[155, 250] -> 
             RGBColor[
              0.2067822292135854, 0.3346716120270169, 0.9350873140955949], 
             UndirectedEdge[243, 285] -> 
             RGBColor[
              0.20548353415746184`, 0.3333066011810086, 0.9350133553333959], 
             UndirectedEdge[378, 452] -> 
             RGBColor[
              0.21688623716897232`, 0.34529156501923397`, 0.935662722401114], 
             UndirectedEdge[100, 264] -> 
             RGBColor[
              0.92938539319056, 0.7351346977720205, 0.3568427596083415], 
             UndirectedEdge[81, 130] -> 
             RGBColor[
              0.27063800741742255`, 0.4017880836094291, 0.9387238061981451], 
             UndirectedEdge[1, 120] -> 
             RGBColor[
              0.18959062955787265`, 0.3166021507784885, 0.9341082779278946], 
             UndirectedEdge[390, 422] -> 
             RGBColor[
              0.23122695863113757`, 0.36036457253022636`, 0.9364794052731881],
              UndirectedEdge[118, 255] -> 
             RGBColor[
              0.19469073239539242`, 0.3219626822259184, 0.9343987212395655], 
             UndirectedEdge[137, 229] -> 
             RGBColor[
              0.2232482662355424, 0.35197846094413987`, 0.9360250305446766], 
             UndirectedEdge[367, 375] -> 
             RGBColor[
              0.19994616901354612`, 0.3274864793255251, 0.9346980105802476], 
             UndirectedEdge[230, 382] -> 
             RGBColor[
              0.20898405610198123`, 0.3369858716906088, 0.9352127048795782], 
             UndirectedEdge[114, 334] -> 
             RGBColor[
              0.18414474445457316`, 0.31087818024586233`, 0.9337981428277268],
              UndirectedEdge[52, 170] -> 
             RGBColor[
              0.1838649636445791, 0.31058411287543064`, 0.9337822097244962], 
             UndirectedEdge[4, 389] -> 
             RGBColor[
              0.18821672881431478`, 0.31515809398667083`, 0.934030036313053], 
             UndirectedEdge[190, 378] -> 
             RGBColor[
              0.21175405970731373`, 0.3398973211081856, 0.9353704524870488], 
             UndirectedEdge[89, 328] -> 
             RGBColor[
              0.27633399177258894`, 0.4076884315850981, 0.9390513510031808], 
             UndirectedEdge[93, 300] -> 
             RGBColor[
              0.2272468293636924, 0.3561812043153706, 0.9362527427994807], 
             UndirectedEdge[104, 125] -> 
             RGBColor[
              0.8510407401896769, 0.7816870619636468, 0.6181576134272155], 
             UndirectedEdge[59, 228] -> 
             RGBColor[
              0.26060629998899837`, 0.391244123055168, 0.9381525153006776], 
             UndirectedEdge[96, 136] -> 
             RGBColor[
              0.4994982670529912, 0.6045542211909409, 0.9537414797863035], 
             UndirectedEdge[332, 420] -> 
             RGBColor[
              0.1873361545684642, 0.31423255462265, 0.9339798889124447], 
             UndirectedEdge[40, 283] -> 
             RGBColor[
              0.18366308451827268`, 0.3103719251138067, 0.9337707130069065], 
             UndirectedEdge[17, 288] -> 
             RGBColor[
              0.543333437646262, 0.6369721967012344, 0.9584978319935238], 
             UndirectedEdge[325, 413] -> 
             RGBColor[
              0.23197275674874823`, 0.36114845363816694`, 0.9365218773726766],
              UndirectedEdge[421, 459] -> 
             RGBColor[
              0.18940834947071425`, 0.31641056284966007`, 0.9340978973465902],
              UndirectedEdge[148, 342] -> 
             RGBColor[
              0.3754741855106375, 0.4958604756469023, 0.9454338500155093], 
             UndirectedEdge[262, 478] -> 
             RGBColor[
              0.29624054132013333`, 0.4255154795391891, 0.9402983591952379], 
             UndirectedEdge[133, 405] -> 
             RGBColor[
              0.18981989868512106`, 0.3168431271677289, 0.9341213344655181], 
             UndirectedEdge[374, 397] -> 
             RGBColor[
              0.8347270315445021, 0.26793275869910615`, 0.18088795066657473`],
              UndirectedEdge[151, 389] -> 
             RGBColor[
              0.1993172981785255, 0.3268254962052045, 0.9346621973165241], 
             UndirectedEdge[235, 305] -> 
             RGBColor[
              0.2638362786788805, 0.394471813217312, 0.9383425806338642], 
             UndirectedEdge[204, 348] -> 
             RGBColor[
              0.38899180466367445`, 0.5111089618702334, 0.9460729299565488], 
             UndirectedEdge[191, 429] -> 
             RGBColor[
              0.1912728666243942, 0.31837028859539307`, 0.9342040788401863], 
             UndirectedEdge[15, 414] -> 
             RGBColor[0.53753656294092, 0.634449250565901, 0.957071181763386],
              UndirectedEdge[277, 414] -> 
             RGBColor[
              0.43294658493558325`, 0.5494183041682945, 0.9488079514458304], 
             UndirectedEdge[317, 440] -> 
             RGBColor[
              0.8544757528158395, 0.36746867129617394`, 0.19775292258988314`],
              UndirectedEdge[76, 182] -> 
             RGBColor[
              0.3777126376207911, 0.5015774351431334, 0.9452884931643937], 
             UndirectedEdge[199, 376] -> 
             RGBColor[
              0.3786216036789717, 0.5023647358567669, 0.9453464116778538], 
             UndirectedEdge[375, 402] -> 
             RGBColor[
              0.21043597475918854`, 0.33851193025629345`, 0.9352953894991849],
              UndirectedEdge[45, 195] -> 
             RGBColor[
              0.19463609510811763`, 0.32190525497278855`, 0.9343956097268837],
              UndirectedEdge[149, 269] -> 
             RGBColor[
              0.5815017308774398, 0.6711283273375747, 0.9601970928471498], 
             UndirectedEdge[45, 152] -> 
             RGBColor[
              0.1927063751242849, 0.3198769969184667, 0.9342857150285693], 
             UndirectedEdge[356, 494] -> 
             RGBColor[
              0.30030937836549265`, 0.4286701061729542, 0.9405711545959381], 
             UndirectedEdge[44, 360] -> 
             RGBColor[
              0.4375870349530485, 0.5468097854709225, 0.9502759669846275], 
             UndirectedEdge[284, 432] -> 
             RGBColor[
              0.249031609154708, 0.37907838911054315`, 0.9374933537808854], 
             UndirectedEdge[151, 237] -> 
             RGBColor[
              0.2183016735730191, 0.3467792784237385, 0.9357433294103739], 
             UndirectedEdge[207, 343] -> 
             RGBColor[
              0.8606088112970214, 0.4407906780799979, 0.2046511142000771], 
             UndirectedEdge[33, 371] -> 
             RGBColor[
              0.2551767869971113, 0.385537360649688, 0.9378433125680343], 
             UndirectedEdge[280, 480] -> 
             RGBColor[
              0.24841746075918128`, 0.37843288020758725`, 0.9374583789383113],
              UndirectedEdge[420, 454] -> 
             RGBColor[
              0.19971846915340663`, 0.3272471523355135, 0.9346850434100643], 
             UndirectedEdge[267, 393] -> 
             RGBColor[
              0.22528640281656057`, 0.35412067171611283`, 0.9361410994078128],
              UndirectedEdge[337, 427] -> 
             RGBColor[
              0.18780005171862202`, 0.314720139940244, 0.9340063071688718], 
             UndirectedEdge[267, 480] -> 
             RGBColor[
              0.23630904981420553`, 0.3657061725868226, 0.9367688228477836], 
             UndirectedEdge[234, 336] -> 
             RGBColor[
              0.7758644491107505, 0.7262741691289183, 0.6116347463560659], 
             UndirectedEdge[122, 492] -> 
             RGBColor[
              0.1841436405662557, 0.3108770199892501, 0.9337980799629202], 
             UndirectedEdge[80, 272] -> 
             RGBColor[
              0.30232143214337615`, 0.4315140636582957, 0.9406590399115311], 
             UndirectedEdge[331, 444] -> 
             RGBColor[
              0.43364941819134256`, 0.5462951958354212, 0.9497218378452923], 
             UndirectedEdge[77, 184] -> 
             RGBColor[
              0.4376517235629901, 0.5511173532058586, 0.9497643390234523], 
             UndirectedEdge[266, 359] -> 
             RGBColor[
              0.9515547370167402, 0.9596896244773535, 0.7671002510689349], 
             UndirectedEdge[32, 478] -> 
             RGBColor[
              0.23449306505329615`, 0.3637974574630227, 0.9366654052021586], 
             UndirectedEdge[14, 447] -> 
             RGBColor[
              0.2323548964610662, 0.3615501067048703, 0.936543639663968], 
             UndirectedEdge[16, 358] -> 
             RGBColor[
              0.24749987708524912`, 0.37746844158811943`, 0.9374061239055242],
              UndirectedEdge[50, 323] -> 
             RGBColor[
              0.9365367216162789, 0.9493476478675402, 0.8794633883159441], 
             UndirectedEdge[92, 365] -> 
             RGBColor[
              0.23949140661491064`, 0.36905103135743866`, 0.9369500533597088],
              UndirectedEdge[296, 438] -> 
             RGBColor[
              0.1924355382075839, 0.3195923301469616, 0.9342702912668306], 
             UndirectedEdge[181, 422] -> 
             RGBColor[
              0.2160287950041301, 0.3443903389390116, 0.9356138923382982], 
             UndirectedEdge[35, 428] -> 
             RGBColor[
              0.18771159390474457`, 0.31462716516930944`, 0.9340012696272331],
              UndirectedEdge[19, 298] -> 
             RGBColor[
              0.2394531191654226, 0.3690107888204622, 0.9369478729461016], 
             UndirectedEdge[209, 348] -> 
             RGBColor[
              0.7282782743451366, 0.7830802438848616, 0.8460022789081878], 
             UndirectedEdge[27, 194] -> 
             RGBColor[
              0.1856592913664621, 0.31247006507807806`, 0.9338843940337875], 
             UndirectedEdge[253, 287] -> 
             RGBColor[
              0.340823165506129, 0.46920105185432204`, 0.9429534744527581], 
             UndirectedEdge[412, 476] -> 
             RGBColor[
              0.18684284442084606`, 0.31371405437983346`, 0.9339517956293248],
              UndirectedEdge[221, 336] -> 
             RGBColor[
              0.7938129054109903, 0.7955671950703103, 0.6357978963718616], 
             UndirectedEdge[146, 248] -> 
             RGBColor[
              0.18017302617267333`, 0.306703652510102, 0.9335719593472032], 
             UndirectedEdge[17, 455] -> 
             RGBColor[
              0.49424404189338955`, 0.5981741285649027, 0.9539120839375526], 
             UndirectedEdge[102, 393] -> 
             RGBColor[
              0.2103791435745319, 0.3384521970779141, 0.9352921530472929], 
             UndirectedEdge[80, 497] -> 
             RGBColor[
              0.4127991170058606, 0.5312924585653119, 0.9477107106935068], 
             UndirectedEdge[108, 416] -> 
             RGBColor[
              0.20942130064370462`, 0.3374454434268651, 0.9352376053093838], 
             UndirectedEdge[8, 453] -> 
             RGBColor[
              0.21870849923514318`, 0.34720687798886773`, 0.9357664975299873],
              UndirectedEdge[58, 402] -> 
             RGBColor[
              0.20564836608822273`, 0.3334798499911863, 0.9350227422680057], 
             UndirectedEdge[95, 357] -> 
             RGBColor[
              0.18661251030183867`, 0.3134719586167301, 0.9339386784419961], 
             UndirectedEdge[183, 283] -> 
             RGBColor[
              0.18964111329673894`, 0.31665521238889094`, 0.9341111529021391],
              UndirectedEdge[179, 294] -> 
             RGBColor[
              0.19380204212800067`, 0.3210286124086723, 0.9343481116435368], 
             UndirectedEdge[136, 240] -> 
             RGBColor[
              0.7615140918759296, 0.8095862292350475, 0.8160223615071904], 
             UndirectedEdge[153, 289] -> 
             RGBColor[
              0.21885506273912853`, 0.34736092552421916`, 0.935774844104718], 
             UndirectedEdge[73, 200] -> 
             RGBColor[
              0.4199369122581749, 0.5305626812641765, 0.9490610674516942], 
             UndirectedEdge[196, 447] -> 
             RGBColor[
              0.2128628663159131, 0.341062747156223, 0.9354335973830761], 
             UndirectedEdge[68, 492] -> 
             RGBColor[
              0.1840181186755369, 0.3107450885235571, 0.9337909316769367], 
             UndirectedEdge[25, 413] -> 
             RGBColor[
              0.25960242052995686`, 0.39018898209408137`, 0.9380953458505918],
              UndirectedEdge[220, 426] -> 
             RGBColor[
              0.20219514191155313`, 0.32985029243444797`, 0.9348260862597317],
              UndirectedEdge[21, 354] -> 
             RGBColor[
              0.30529527480886387`, 0.43804478810981307`, 0.9407037211240865],
              UndirectedEdge[125, 269] -> 
             RGBColor[
              0.6899118040266511, 0.7570634310667932, 0.970151640135829], 
             UndirectedEdge[241, 304] -> 
             RGBColor[
              0.20316948858682138`, 0.3308743925673022, 0.9348815738614715], 
             UndirectedEdge[93, 456] -> 
             RGBColor[
              0.20912093230204676`, 0.3371297372553299, 0.9352204997766816], 
             UndirectedEdge[295, 455] -> 
             RGBColor[
              0.7989202594631184, 0.8423584945526768, 0.9321574576076621], 
             UndirectedEdge[185, 386] -> 
             RGBColor[
              0.25857169569949595`, 0.38910562494553824`, 0.9380366475963178],
              UndirectedEdge[233, 400] -> 
             RGBColor[
              0.9762128798080161, 0.9808371360064839, 0.8829178984103572], 
             UndirectedEdge[83, 317] -> 
             RGBColor[
              0.9062729324823862, 0.5632106001230137, 0.44649236510931034`], 
             UndirectedEdge[88, 465] -> 
             RGBColor[
              0.18430414736705614`, 0.3110457228136103, 0.9338072205877772], 
             UndirectedEdge[418, 431] -> 
             RGBColor[
              0.4488786406898552, 0.5625882607859993, 0.9499970853520581], 
             UndirectedEdge[121, 307] -> 
             RGBColor[
              0.1984527242001829, 0.32591677413681014`, 0.93461296110748], 
             UndirectedEdge[64, 74] -> 
             RGBColor[
              0.1867563887094054, 0.3136231839455006, 0.933946872104458], 
             UndirectedEdge[185, 358] -> 
             RGBColor[
              0.21821199843557637`, 0.3466850241685541, 0.935738222543959], 
             UndirectedEdge[113, 315] -> 
             RGBColor[
              0.19006335492631857`, 0.31709901511324473`, 0.9341351989382931],
              UndirectedEdge[47, 91] -> 
             RGBColor[
              0.37096684027433213`, 0.4930353735304999, 0.9450030845101454], 
             UndirectedEdge[158, 401] -> 
             RGBColor[
              0.1862173046895177, 0.3130565724606977, 0.9339161720670288], 
             UndirectedEdge[90, 232] -> 
             RGBColor[
              0.2704052861597108, 0.40154347881219404`, 0.9387105530667987], 
             UndirectedEdge[58, 115] -> 
             RGBColor[
              0.19207706439220854`, 0.3192155514384495, 0.9342498767133594], 
             UndirectedEdge[132, 494] -> 
             RGBColor[
              0.3138085366833637, 0.4428585774611083, 0.9413399116919258], 
             UndirectedEdge[167, 300] -> 
             RGBColor[
              0.23586320873341787`, 0.3652375653429575, 0.9367434328577955], 
             UndirectedEdge[284, 389] -> 
             RGBColor[
              0.20087579702642006`, 0.328463577308876, 0.9347509515203193], 
             UndirectedEdge[103, 233] -> 
             RGBColor[
              0.6861807488432135, 0.7504846976904338, 0.9477990317770553], 
             UndirectedEdge[172, 300] -> 
             RGBColor[
              0.22767768818641226`, 0.35663406425607636`, 0.936277279572036], 
             UndirectedEdge[70, 76] -> 
             RGBColor[
              0.3900856381049142, 0.5122943062773944, 0.9460768898142273], 
             UndirectedEdge[57, 73] -> 
             RGBColor[
              0.769769601175684, 0.81952464354351, 0.9539791162715971], 
             UndirectedEdge[287, 473] -> 
             RGBColor[
              0.28387386210883436`, 0.4156998060917603, 0.9394775685421287], 
             UndirectedEdge[395, 443] -> 
             RGBColor[
              0.39598885232621217`, 0.5140941996505966, 0.9469051099430464], 
             UndirectedEdge[100, 397] -> 
             RGBColor[
              0.9076183259729562, 0.5790517976305654, 0.33643826418820166`], 
             UndirectedEdge[57, 234] -> 
             RGBColor[
              0.9445095586663342, 0.8587398441686642, 0.6038719941743098], 
             UndirectedEdge[343, 403] -> 
             RGBColor[
              0.7948197503279848, 0.5779151298917289, 0.5834817504053871], 
             UndirectedEdge[105, 425] -> 
             RGBColor[
              0.18905198757822078`, 0.3160360039060004, 0.9340776030640029], 
             UndirectedEdge[133, 423] -> 
             RGBColor[
              0.18859024302857952`, 0.3155506811080321, 0.9340513073949906], 
             UndirectedEdge[92, 494] -> 
             RGBColor[
              0.31362082310207806`, 0.44266127858544857`, 0.9413292216811688],
              UndirectedEdge[51, 100] -> 
             RGBColor[
              0.9942396894003585, 0.9900876030211339, 0.6144039236244064], 
             UndirectedEdge[6, 347] -> 
             RGBColor[
              0.20873556607912272`, 0.336724692921407, 0.9351985537403844], 
             UndirectedEdge[333, 461] -> 
             RGBColor[
              0.24252993321129454`, 0.3722447154639515, 0.9371230929542755], 
             UndirectedEdge[291, 394] -> 
             RGBColor[
              0.18326692398746902`, 0.30995553527790365`, 0.9337481522507443],
              UndirectedEdge[143, 386] -> 
             RGBColor[
              0.4431271313499566, 0.5544881277989356, 0.9504225818042138], 
             UndirectedEdge[123, 437] -> 
             RGBColor[
              0.18388303382001714`, 0.3106031057755313, 0.9337832387942551], 
             UndirectedEdge[72, 453] -> 
             RGBColor[
              0.2255232493931461, 0.35436961248504456`, 0.9361545874699662], 
             UndirectedEdge[391, 478] -> 
             RGBColor[
              0.36121422406998477`, 0.4812548901837663, 0.9445869453059381], 
             UndirectedEdge[328, 464] -> 
             RGBColor[
              0.22272025145336094`, 0.35142348392999634`, 0.9359949608839593],
              UndirectedEdge[149, 173] -> 
             RGBColor[
              0.6408634071546884, 0.7181223008643338, 0.9656896889353898], 
             UndirectedEdge[54, 186] -> 
             RGBColor[
              0.9914243588005289, 0.9890319585828893, 0.6689529207083693], 
             UndirectedEdge[355, 444] -> 
             RGBColor[
              0.5627869729236907, 0.655934843740483, 0.9587237985466135], 
             UndirectedEdge[7, 448] -> 
             RGBColor[
              0.38646904067525956`, 0.507890290668963, 0.9460168875491417], 
             UndirectedEdge[47, 416] -> 
             RGBColor[
              0.24541922577751857`, 0.3752815451427822, 0.9372876338915967], 
             UndirectedEdge[48, 155] -> 
             RGBColor[
              0.1919029748142661, 0.3190325722541152, 0.934239962569438], 
             UndirectedEdge[346, 486] -> 
             RGBColor[
              0.4273749578752095, 0.5445924408467173, 0.9484529322963398], 
             UndirectedEdge[24, 491] -> 
             RGBColor[
              0.1834588125121197, 0.3101572222837467, 0.9337590800183494], 
             UndirectedEdge[321, 373] -> 
             RGBColor[
              0.9882173705299822, 0.9893955941614516, 0.8449321929931977], 
             UndirectedEdge[209, 231] -> 
             RGBColor[
              0.8790670260426792, 0.9036392003218177, 0.8591433457844534], 
             UndirectedEdge[210, 393] -> 
             RGBColor[
              0.20841975513223648`, 0.336392755592659, 0.9351805687741597], 
             UndirectedEdge[188, 409] -> 
             RGBColor[
              0.23860514692337326`, 0.3681195162295229, 0.9368995821813795], 
             UndirectedEdge[307, 427] -> 
             RGBColor[
              0.1891435770986254, 0.31613227029905666`, 0.9340828189516954], 
             UndirectedEdge[178, 186] -> 
             RGBColor[
              0.7313163060716499, 0.7840864544016981, 0.7330087460966953], 
             UndirectedEdge[328, 475] -> 
             RGBColor[
              0.28975754389901165`, 0.4193152377496582, 0.9399066878746956], 
             UndirectedEdge[213, 337] -> 
             RGBColor[
              0.19565173016906506`, 0.3229727518168264, 0.9344534486411072], 
             UndirectedEdge[384, 458] -> 
             RGBColor[
              0.25354859204463764`, 0.3838260245211157, 0.9377505892741895], 
             UndirectedEdge[87, 473] -> 
             RGBColor[
              0.28600307999809077`, 0.4179377490935802, 0.9395988243510263], 
             UndirectedEdge[112, 440] -> 
             RGBColor[
              0.9425369917886818, 0.7961831197118145, 0.4948215293690824], 
             UndirectedEdge[237, 429] -> 
             RGBColor[
              0.2124196419707597, 0.3405968902674201, 0.9354083564123112], 
             UndirectedEdge[109, 230] -> 
             RGBColor[
              0.20976714477549485`, 0.3378089475371612, 0.9352573006210588], 
             UndirectedEdge[89, 262] -> 
             RGBColor[
              0.3264244296719824, 0.4571541672381602, 0.9420204539062771], 
             UndirectedEdge[280, 383] -> 
             RGBColor[
              0.2606241170949257, 0.3912628499631674, 0.9381535299585022], 
             UndirectedEdge[196, 489] -> 
             RGBColor[
              0.19180860925659354`, 0.31893338806987936`, 0.9342345885905299],
              UndirectedEdge[279, 459] -> 
             RGBColor[
              0.20123137359851423`, 0.3288373108310037, 0.9347712010800716], 
             UndirectedEdge[191, 423] -> 
             RGBColor[
              0.1848982635137219, 0.3116701765528954, 0.9338410546234137], 
             UndirectedEdge[116, 165] -> 
             RGBColor[
              0.2912027626996634, 0.4234029452918576, 0.9398949385886397], 
             UndirectedEdge[176, 313] -> 
             RGBColor[
              0.3390769551492299, 0.46811314887213096`, 0.9428266616414984], 
             UndirectedEdge[180, 490] -> 
             RGBColor[
              0.23955648296360244`, 0.3691194307259925, 0.9369537593614949], 
             UndirectedEdge[17, 498] -> 
             RGBColor[
              0.5750148993041335, 0.6617219953363903, 0.9616555440114883], 
             UndirectedEdge[108, 364] -> 
             RGBColor[
              0.2070027664491964, 0.33490341064451234`, 0.9350998733649074], 
             UndirectedEdge[29, 254] -> 
             RGBColor[
              0.18842942576301586`, 0.31538165196552115`, 0.9340421490896246],
              UndirectedEdge[7, 261] -> 
             RGBColor[
              0.40082339399554057`, 0.5210779379064496, 0.9469039036269813], 
             UndirectedEdge[122, 224] -> 
             RGBColor[
              0.195806426334931, 0.3231353472954549, 0.9344622583589008], 
             UndirectedEdge[116, 386] -> 
             RGBColor[
              0.2910406970756628, 0.423232604045479, 0.9398857091911075], 
             UndirectedEdge[8, 439] -> 
             RGBColor[
              0.1983584490277003, 0.3258176849531398, 0.9346075922758748], 
             UndirectedEdge[226, 488] -> 
             RGBColor[
              0.18475420080410804`, 0.31151875751098784`, 0.9338328504652229],
              UndirectedEdge[64, 170] -> 
             RGBColor[
              0.18627047911638173`, 0.31311246215478516`, 0.9339192002719742],
              UndirectedEdge[178, 313] -> 
             RGBColor[
              0.4152649069206235, 0.5336691197660451, 0.9478012623099019], 
             UndirectedEdge[81, 251] -> 
             RGBColor[
              0.23864347228983546`, 0.36815979861964326`, 0.9369017647543021],
              UndirectedEdge[186, 288] -> 
             RGBColor[
              0.8522733135527225, 0.8812298873379956, 0.7432521758076465], 
             UndirectedEdge[45, 118] -> 
             RGBColor[
              0.1966941864369604, 0.3240684394499293, 0.9345128149833881], 
             UndirectedEdge[224, 330] -> 
             RGBColor[
              0.1977574976662851, 0.3251860469697754, 0.9345733689848701], 
             UndirectedEdge[35, 410] -> 
             RGBColor[
              0.18494866329979062`, 0.31172314992358463`, 0.9338439248166706],
              UndirectedEdge[163, 379] -> 
             RGBColor[
              0.8633665292005046, 0.42373393983337493`, 0.2057939864189699], 
             UndirectedEdge[181, 443] -> 
             RGBColor[
              0.2566770686688468, 0.387114251810034, 0.9379287513897718], 
             UndirectedEdge[167, 235] -> 
             RGBColor[
              0.22849052163804753`, 0.3574884037503625, 0.9363235692346273], 
             UndirectedEdge[202, 279] -> 
             RGBColor[
              0.19737149140968246`, 0.32478032991987577`, 0.9345513864996016],
              UndirectedEdge[242, 310] -> 
             RGBColor[
              0.8089627721429287, 0.8509600154884045, 0.9478147926846883], 
             UndirectedEdge[299, 482] -> 
             RGBColor[
              0.2862226992731482, 0.4159841982683552, 0.9396913123648138], 
             UndirectedEdge[56, 110] -> 
             RGBColor[
              0.41196166706796206`, 0.5312422230440008, 0.9474708110355399], 
             UndirectedEdge[125, 419] -> 
             RGBColor[
              0.7136180387569662, 0.7762031026656953, 0.9720904350297161], 
             UndirectedEdge[262, 448] -> 
             RGBColor[
              0.3218757091133844, 0.45245966625341066`, 0.9417582440772314], 
             UndirectedEdge[95, 212] -> 
             RGBColor[
              0.18331321264928, 0.31000418759633763`, 0.9337507883215563], 
             UndirectedEdge[32, 260] -> 
             RGBColor[
              0.21471160984099968`, 0.34300589381819857`, 0.9355388805918587],
              UndirectedEdge[421, 430] -> 
             RGBColor[
              0.19294646407159283`, 0.3201293456246058, 0.9342993877389387], 
             UndirectedEdge[129, 346] -> 
             RGBColor[
              0.36539555977117477`, 0.4891180942666259, 0.9445692337379277], 
             UndirectedEdge[16, 17] -> 
             RGBColor[
              0.32278008566889027`, 0.45042607660179157`, 0.9419190112149659],
              UndirectedEdge[153, 466] -> 
             RGBColor[
              0.2112617016772801, 0.3393798216013181, 0.9353424134256167], 
             UndirectedEdge[244, 391] -> 
             RGBColor[
              0.45991819988990085`, 0.5722422337278446, 0.9506750794005083], 
             UndirectedEdge[218, 406] -> 
             RGBColor[
              0.35118939031714774`, 0.4764899015985373, 0.9436758749335621], 
             UndirectedEdge[99, 288] -> 
             RGBColor[
              0.8454606604699532, 0.8793558579429647, 0.9455510322617159], 
             UndirectedEdge[399, 481] -> 
             RGBColor[
              0.20657386895260635`, 0.3344526121819243, 0.9350754482869736], 
             UndirectedEdge[278, 451] -> 
             RGBColor[
              0.194775409510841, 0.3220516832430941, 0.9344035434760216], 
             UndirectedEdge[179, 327] -> 
             RGBColor[
              0.1919456153481889, 0.3190773901588341, 0.9342423908847639], 
             UndirectedEdge[38, 473] -> 
             RGBColor[
              0.39120686649721753`, 0.5073123077036177, 0.9467925996287968], 
             UndirectedEdge[17, 176] -> 
             RGBColor[
              0.3461884783937958, 0.47427279287102275`, 0.943279801614169], 
             UndirectedEdge[186, 373] -> 
             RGBColor[
              0.9921614072017308, 0.9893367470380662, 0.6567381212803327], 
             UndirectedEdge[399, 496] -> 
             RGBColor[
              0.19684711352332962`, 0.3242291755138407, 0.9345215239547214], 
             UndirectedEdge[116, 358] -> 
             RGBColor[
              0.2506809998117433, 0.38081200326849496`, 0.9375872841387487], 
             UndirectedEdge[71, 135] -> 
             RGBColor[
              0.18886726703484777`, 0.31584185090295647`, 0.9340670835023274],
              UndirectedEdge[53, 374] -> 
             RGBColor[
              0.8400594801870103, 0.30892029565931944`, 0.18599430950878], 
             UndirectedEdge[228, 409] -> 
             RGBColor[
              0.2557251463437433, 0.3861137210909889, 0.9378745408216], 
             UndirectedEdge[440, 471] -> 
             RGBColor[
              0.9242345860512566, 0.784069889818272, 0.5946181447155001], 
             UndirectedEdge[403, 471] -> 
             RGBColor[
              0.8501227775795742, 0.8834026890475528, 0.9665040763953929], 
             UndirectedEdge[63, 166] -> 
             RGBColor[
              0.20124645730453306`, 0.3288531647623917, 0.9347720600748151], 
             UndirectedEdge[159, 272] -> 
             RGBColor[
              0.24467152920527638`, 0.37449566863865497`, 0.9372450536779255],
              UndirectedEdge[130, 351] -> 
             RGBColor[
              0.2715547401921379, 0.40275162787986996`, 0.9387760127734806], 
             UndirectedEdge[113, 378] -> 
             RGBColor[
              0.20184046362642588`, 0.32947750306887713`, 0.9348058878560932],
              UndirectedEdge[145, 417] -> 
             RGBColor[
              0.20308781549592325`, 0.3307885489703952, 0.9348769226997694], 
             UndirectedEdge[38, 354] -> 
             RGBColor[
              0.4147037910637674, 0.5318387842884362, 0.9481369495411083], 
             UndirectedEdge[334, 446] -> 
             RGBColor[
              0.18513113872334164`, 0.31191494316334684`, 0.9338543165220936],
              UndirectedEdge[305, 310] -> 
             RGBColor[
              0.4776836488671362, 0.5829301850756662, 0.9531209010914763], 
             UndirectedEdge[338, 383] -> 
             RGBColor[
              0.34605340544318985`, 0.47036770113504156`, 0.9434098957217043],
              UndirectedEdge[243, 477] -> 
             RGBColor[
              0.19718654273618264`, 0.32458593713760425`, 0.9345408539462529],
              UndirectedEdge[38, 221] -> 
             RGBColor[
              0.7405475305032172, 0.7523239641423858, 0.6316046509416242], 
             UndirectedEdge[330, 357] -> 
             RGBColor[
              0.18906252050836794`, 0.3160470746834114, 0.9340782028987926], 
             UndirectedEdge[48, 365] -> 
             RGBColor[
              0.19846339054879825`, 0.32592798514549043`, 0.9346135685402542],
              UndirectedEdge[384, 411] -> 
             RGBColor[
              0.2746421437909936, 0.40599668481496154`, 0.9389518358410311], 
             UndirectedEdge[38, 436] -> 
             RGBColor[
              0.4371703671484145, 0.5512982032900106, 0.9495684999028087], 
             UndirectedEdge[117, 155] -> 
             RGBColor[
              0.1887434182573529, 0.3157116779853434, 0.9340600304976668], 
             UndirectedEdge[68, 286] -> 
             RGBColor[
              0.1864116908357643, 0.3132608846251963, 0.9339272420704889], 
             UndirectedEdge[378, 380] -> 
             RGBColor[
              0.19721656952288963`, 0.32461749719424154`, 0.9345425639273353],
              UndirectedEdge[12, 285] -> 
             RGBColor[
              0.20421155270957553`, 0.33196966803099826`, 0.9349409178716667],
              UndirectedEdge[93, 432] -> 
             RGBColor[
              0.2569317093580773, 0.38738189531956746`, 0.9379432528003164], 
             UndirectedEdge[340, 499] -> 
             RGBColor[
              0.4961829212208138, 0.5994318600646289, 0.9541521247756388], 
             UndirectedEdge[389, 456] -> 
             RGBColor[
              0.1952664503716337, 0.322567798321576, 0.9344315075266139], 
             UndirectedEdge[390, 451] -> 
             RGBColor[
              0.23050025885424308`, 0.3596007649892832, 0.93643802079595], 
             UndirectedEdge[92, 485] -> 
             RGBColor[
              0.26364199259434656`, 0.39443482845741684`, 0.9383253935036474],
              UndirectedEdge[293, 471] -> 
             RGBColor[
              0.883292777281721, 0.9093153449162048, 0.969810151974432], 
             UndirectedEdge[111, 359] -> 
             RGBColor[
              0.6380588033619161, 0.711320155207173, 0.9679062350071925], 
             UndirectedEdge[357, 441] -> 
             RGBColor[
              0.20500595942209238`, 0.33280463985414815`, 0.9349861581587251],
              UndirectedEdge[52, 268] -> 
             RGBColor[
              0.18314820397606815`, 0.30983075301863783`, 0.9337413913217254],
              UndirectedEdge[30, 311] -> 
             RGBColor[
              0.18445928711484194`, 0.31120878452496137`, 0.9338160555669048],
              UndirectedEdge[164, 486] -> 
             RGBColor[
              0.3646799679598963, 0.49028919172388963`, 0.9444580629779388], 
             UndirectedEdge[194, 290] -> 
             RGBColor[
              0.18381681483281254`, 0.31053350542145297`, 0.9337794677208959],
              UndirectedEdge[238, 445] -> 
             RGBColor[
              0.7249039407503491, 0.7407041936806955, 0.6319785472238091], 
             UndirectedEdge[269, 406] -> 
             RGBColor[
              0.5091880023383142, 0.611421148279524, 0.9547804937952983], 
             UndirectedEdge[99, 341] -> 
             RGBColor[
              0.9869976251000042, 0.9872951064518227, 0.7699640190632113], 
             UndirectedEdge[41, 457] -> 
             RGBColor[
              0.36616941470913866`, 0.48692522378917524`, 0.9448270715857057],
              UndirectedEdge[217, 292] -> 
             RGBColor[
              0.18318117608781065`, 0.30986540879863184`, 0.9337432690347114],
              UndirectedEdge[176, 299] -> 
             RGBColor[
              0.2785034431297019, 0.4092981665779968, 0.9391994481892236], 
             UndirectedEdge[218, 314] -> 
             RGBColor[
              0.27434229412121725`, 0.4056815238004595, 0.9389347598459252], 
             UndirectedEdge[355, 486] -> 
             RGBColor[
              0.48652222048477045`, 0.5929340389323234, 0.9530199242881539], 
             UndirectedEdge[213, 420] -> 
             RGBColor[
              0.19513105630202093`, 0.32242549056993314`, 0.9344237970346471],
              UndirectedEdge[299, 407] -> 
             RGBColor[
              0.2586014952958633, 0.3891369462107238, 0.9380383446392464], 
             UndirectedEdge[201, 314] -> 
             RGBColor[
              0.2601298304238602, 0.39074332333229245`, 0.9381253810638166], 
             UndirectedEdge[160, 300] -> 
             RGBColor[
              0.2356560570579657, 0.36501983579788244`, 0.936731635876332], 
             UndirectedEdge[21, 200] -> 
             RGBColor[
              0.28148912705476437`, 0.4131932983489973, 0.9393417614086988], 
             UndirectedEdge[25, 180] -> 
             RGBColor[
              0.2760199528625702, 0.4074448495073293, 0.9390303000293716], 
             UndirectedEdge[45, 185] -> 
             RGBColor[
              0.2063591315326575, 0.33422690953841927`, 0.935063219308583], 
             UndirectedEdge[191, 226] -> 
             RGBColor[
              0.18878815245387853`, 0.31575869646220367`, 0.9340625780439806],
              UndirectedEdge[50, 82] -> 
             RGBColor[
              0.7002427375322327, 0.764369726655832, 0.9719080506652522], 
             UndirectedEdge[22, 491] -> 
             RGBColor[
              0.1817125626643469, 0.3083218029751023, 0.9336596336728639], 
             UndirectedEdge[99, 277] -> 
             RGBColor[
              0.7114622471897839, 0.7713508183962726, 0.9343566439534178], 
             UndirectedEdge[17, 391] -> 
             RGBColor[
              0.4242791032166461, 0.5413734394625537, 0.9484041876749043], 
             UndirectedEdge[211, 362] -> 
             RGBColor[
              0.1833599948775373, 0.31005335868440065`, 0.9337534525002475], 
             UndirectedEdge[4, 162] -> 
             RGBColor[
              0.18241905104503708`, 0.3090643670571582, 0.9336998671409883], 
             UndirectedEdge[259, 444] -> 
             RGBColor[
              0.6245686648985196, 0.7054652507537504, 0.9640159946250897], 
             UndirectedEdge[347, 382] -> 
             RGBColor[
              0.2075732378156851, 0.3355030122206657, 0.9351323608652922], 
             UndirectedEdge[66, 179] -> 
             RGBColor[
              0.19899718509969622`, 0.32648903706301347`, 0.9346439673502496],
              UndirectedEdge[343, 471] -> 
             RGBColor[
              0.901533639219245, 0.661841877888372, 0.5749261182612281], 
             UndirectedEdge[97, 322] -> 
             RGBColor[
              0.9046195205529701, 0.5667356132446183, 0.288595833391559], 
             UndirectedEdge[363, 381] -> 
             RGBColor[
              0.18545627477246146`, 0.3122566817657879, 0.9338728325390953], 
             UndirectedEdge[238, 471] -> 
             RGBColor[
              0.7217628649306637, 0.780742284826936, 0.9553407683017833], 
             UndirectedEdge[40, 285] -> 
             RGBColor[
              0.19969824891224597`, 0.32722589958001636`, 0.9346838918972433],
              UndirectedEdge[70, 208] -> 
             RGBColor[
              0.39817892177344283`, 0.519304301810809, 0.9465925866929762], 
             UndirectedEdge[84, 448] -> 
             RGBColor[
              0.28804975562944346`, 0.4200889349488619, 0.9397153795004467], 
             UndirectedEdge[152, 195] -> 
             RGBColor[
              0.18616514652705513`, 0.313001750924931, 0.9339132017368377], 
             UndirectedEdge[93, 308] -> 
             RGBColor[
              0.20676738749395213`, 0.33465601243866294`, 0.9350864688816183],
              UndirectedEdge[255, 478] -> 
             RGBColor[
              0.22324206600367816`, 0.3519719441073331, 0.9360246774506443], 
             UndirectedEdge[112, 293] -> 
             RGBColor[
              0.901595183019146, 0.9214285748097474, 0.8700135366280143], 
             UndirectedEdge[87, 184] -> 
             RGBColor[
              0.4246238918446351, 0.5398024449911591, 0.9489353468656369], 
             UndirectedEdge[149, 323] -> 
             RGBColor[
              0.7769198644929252, 0.8229213917028264, 0.8645345338157826], 
             UndirectedEdge[272, 497] -> 
             RGBColor[
              0.3677045224545963, 0.48747048871276477`, 0.9450117306986173], 
             UndirectedEdge[80, 471] -> 
             RGBColor[
              0.6521263465827374, 0.7213327352775194, 0.9506532320788272], 
             UndirectedEdge[339, 344] -> 
             RGBColor[
              0.1852310273425353, 0.3120199324354236, 0.9338600050311847], 
             UndirectedEdge[137, 393] -> 
             RGBColor[
              0.21648582185917808`, 0.3448707031408432, 0.9356399193415825], 
             UndirectedEdge[11, 316] -> 
             RGBColor[
              0.4071433573553281, 0.5270688453462049, 0.9471637926013148], 
             UndirectedEdge[88, 423] -> 
             RGBColor[
              0.18437944571093495`, 0.3111248661472177, 0.9338115087170672], 
             UndirectedEdge[70, 351] -> 
             RGBColor[
              0.3049667644622824, 0.4322301812417861, 0.9408852716041266], 
             UndirectedEdge[55, 298] -> 
             RGBColor[
              0.424640850686557, 0.5359021493799299, 0.9492929643380126], 
             UndirectedEdge[428, 437] -> 
             RGBColor[
              0.18484681961512717`, 0.31161610575374077`, 0.9338381249694931],
              UndirectedEdge[90, 137] -> 
             RGBColor[
              0.23700337417738956`, 0.3664359515152362, 0.9368083635931062], 
             UndirectedEdge[344, 439] -> 
             RGBColor[
              0.19475306873947695`, 0.32202820167590374`, 0.9344022712021427],
              UndirectedEdge[93, 274] -> 
             RGBColor[
              0.23335737797095998`, 0.3626037783327675, 0.936600729502918], 
             UndirectedEdge[60, 434] -> 
             RGBColor[
              0.9602863904874878, 0.8842947028459596, 0.5783529786054818], 
             UndirectedEdge[54, 244] -> 
             RGBColor[
              0.7181235795673231, 0.775643062211419, 0.8864694686198505], 
             UndirectedEdge[243, 318] -> 
             RGBColor[
              0.19728008332867447`, 0.3246842542311293, 0.9345461809446143], 
             UndirectedEdge[384, 402] -> 
             RGBColor[
              0.24310211003433443`, 0.3728461095830723, 0.937155677577888], 
             UndirectedEdge[83, 233] -> 
             RGBColor[
              0.9788921335245182, 0.9819450762719373, 0.8385157306415634], 
             UndirectedEdge[153, 201] -> 
             RGBColor[
              0.2425444285480653, 0.37225995098195497`, 0.9371239184422607], 
             UndirectedEdge[275, 331] -> 
             RGBColor[
              0.39537355093788906`, 0.515221122490898, 0.946708621365979], 
             UndirectedEdge[312, 327] -> 
             RGBColor[
              0.18937402646973123`, 0.31637448719942296`, 0.9340959427024605],
              UndirectedEdge[181, 370] -> 
             RGBColor[
              0.2271386690157574, 0.35606752093192884`, 0.9362465832276747], 
             UndirectedEdge[32, 245] -> 
             RGBColor[
              0.23179881460343715`, 0.36096562941487603`, 0.9365119716248255],
              UndirectedEdge[176, 391] -> 
             RGBColor[
              0.3950241069319744, 0.5160342320796381, 0.9465400851808224], 
             UndirectedEdge[148, 232] -> 
             RGBColor[
              0.27654750718772436`, 0.40799934255194237`, 0.9390603434677424],
              UndirectedEdge[430, 477] -> 
             RGBColor[
              0.19967498374543186`, 0.3272014464145979, 0.9346825669804111], 
             UndirectedEdge[7, 475] -> 
             RGBColor[
              0.40444131336028016`, 0.5242115978182725, 0.9471344342497021], 
             UndirectedEdge[15, 50] -> 
             RGBColor[
              0.7663849277124503, 0.8179130209698517, 0.9772202389257285], 
             UndirectedEdge[168, 395] -> 
             RGBColor[
              0.3984267572015211, 0.5166565922466431, 0.9470439450191381], 
             UndirectedEdge[97, 440] -> 
             RGBColor[
              0.9400446504463722, 0.7867672719569345, 0.32047255191532753`], 
             UndirectedEdge[71, 308] -> 
             RGBColor[
              0.19432153409427227`, 0.32157463140291687`, 0.9343776959424965],
              UndirectedEdge[253, 436] -> 
             RGBColor[
              0.36650668927910635`, 0.49187140591690626`, 0.9445744600450926],
              UndirectedEdge[13, 430] -> 
             RGBColor[
              0.22725075415308893`, 0.3561853295178724, 0.9362529663104306], 
             UndirectedEdge[209, 233] -> 
             RGBColor[
              0.9785167541303205, 0.9817898472456261, 0.8447367386541516], 
             UndirectedEdge[254, 350] -> 
             RGBColor[
              0.18697690227356584`, 0.31385495768280075`, 0.9339594300257164],
              UndirectedEdge[115, 268] -> 
             RGBColor[
              0.18864406926620203`, 0.3156072558965539, 0.9340543727195945], 
             UndirectedEdge[42, 468] -> 
             RGBColor[
              0.21102583019430793`, 0.33913190571759855`, 0.9353289808936021],
              UndirectedEdge[51, 60] -> 
             RGBColor[
              0.9903726876472161, 0.9902614167392676, 0.8073625961746422], 
             UndirectedEdge[331, 348] -> 
             RGBColor[
              0.3817575877124325, 0.5041670701523192, 0.9456367228639543], 
             UndirectedEdge[310, 406] -> 
             RGBColor[
              0.5306573998942516, 0.6288133856772102, 0.9564963416640753], 
             UndirectedEdge[70, 130] -> 
             RGBColor[
              0.33633111822806117`, 0.4651961056645053, 0.9426714251516843], 
             UndirectedEdge[83, 440] -> 
             RGBColor[
              0.9434296852982257, 0.7965522714191877, 0.48002728769919345`], 
             UndirectedEdge[100, 374] -> 
             RGBColor[
              0.9203355927006582, 0.6768022824414968, 0.3486163331687475], 
             UndirectedEdge[207, 374] -> 
             RGBColor[
              0.8612156544492956, 0.4454551404687426, 0.20523222788802623`], 
             UndirectedEdge[51, 324] -> 
             RGBColor[
              0.9674926297054737, 0.9734136310223126, 0.8557710419754258], 
             UndirectedEdge[164, 180] -> 
             RGBColor[
              0.28958519225458484`, 0.42102975172188783`, 0.9398274630675963],
              UndirectedEdge[56, 132] -> 
             RGBColor[
              0.3395809707923225, 0.46518136452608577`, 0.94298210840368], 
             UndirectedEdge[30, 423] -> 
             RGBColor[
              0.17906694420854233`, 0.3055410902361533, 0.9335089696156476], 
             UndirectedEdge[104, 379] -> 
             RGBColor[
              0.8757781230833462, 0.4743585366446421, 0.21585393387585383`], 
             UndirectedEdge[324, 457] -> 
             RGBColor[
              0.7044919829810323, 0.7672858327374596, 0.9691306015608669], 
             UndirectedEdge[283, 459] -> 
             RGBColor[
              0.18839869617185917`, 0.3153493532168468, 0.9340403990848687], 
             UndirectedEdge[128, 245] -> 
             RGBColor[
              0.21909064595633707`, 0.347608538422344, 0.9357882602204238], 
             UndirectedEdge[34, 62] -> 
             RGBColor[
              0.23006104796724536`, 0.35913912649947, 0.9364130083856896], 
             UndirectedEdge[320, 424] -> 
             RGBColor[
              0.18730513840807234`, 0.31419995467154005`, 0.9339781225879946],
              UndirectedEdge[111, 351] -> 
             RGBColor[
              0.3033909458875273, 0.43086528639527777`, 0.9407848618379848], 
             UndirectedEdge[79, 316] -> 
             RGBColor[
              0.6624800077652702, 0.7332731084999433, 0.9690938030221024], 
             UndirectedEdge[43, 250] -> 
             RGBColor[
              0.22400512105631526`, 0.3527739633481394, 0.9360681323070532], 
             UndirectedEdge[116, 313] -> 
             RGBColor[
              0.3188496851508186, 0.44760999428327536`, 0.9416470314755198], 
             UndirectedEdge[87, 436] -> 
             RGBColor[
              0.33196658064928775`, 0.46192364467997304`, 0.9423747246250382],
              UndirectedEdge[280, 393] -> 
             RGBColor[
              0.23739481376153632`, 0.3668473793368775, 0.9368306554983403], 
             UndirectedEdge[295, 321] -> 
             RGBColor[
              0.9851155314829081, 0.988112904001859, 0.896337693305348], 
             UndirectedEdge[131, 186] -> 
             RGBColor[
              0.913526249632497, 0.6241954645463874, 0.3472925437386266], 
             UndirectedEdge[165, 313] -> 
             RGBColor[
              0.3335735057381806, 0.4630856632647371, 0.9424855312760294], 
             UndirectedEdge[140, 270] -> 
             RGBColor[
              0.1795641494336302, 0.30606368445235266`, 0.9335372847176671], 
             UndirectedEdge[322, 445] -> 
             RGBColor[
              0.89195053197754, 0.5240001399597152, 0.23937920511375732`], 
             UndirectedEdge[112, 463] -> 
             RGBColor[
              0.7743003013960627, 0.8206490549360065, 0.8582392599813213], 
             UndirectedEdge[115, 223] -> 
             RGBColor[
              0.1995856510144891, 0.3271075520503548, 0.9346774796135398], 
             UndirectedEdge[102, 451] -> 
             RGBColor[
              0.20226457959273075`, 0.32992327583996894`, 0.9348300406329509],
              UndirectedEdge[148, 267] -> 
             RGBColor[
              0.25194617616278553`, 0.3821417838302541, 0.9376593340602799], 
             UndirectedEdge[447, 500] -> 
             RGBColor[
              0.21735914083056895`, 0.34578861675139594`, 0.9356896535650436],
              UndirectedEdge[238, 293] -> 
             RGBColor[
              0.6482189757415503, 0.7227281926989446, 0.9672024760249813], 
             UndirectedEdge[56, 457] -> 
             RGBColor[
              0.4380492997215996, 0.5534053955584954, 0.9492526271337134], 
             UndirectedEdge[204, 331] -> 
             RGBColor[
              0.3086689498622105, 0.44109928644623464`, 0.9409138412479245], 
             UndirectedEdge[66, 260] -> 
             RGBColor[
              0.203816558535701, 0.331554504110179, 0.9349184235378061], 
             UndirectedEdge[225, 424] -> 
             RGBColor[
              0.18871848366086047`, 0.31568547014348514`, 0.9340586105092841],
              UndirectedEdge[178, 244] -> 
             RGBColor[
              0.45801552683844415`, 0.5706975580302278, 0.9505252940081765], 
             UndirectedEdge[139, 247] -> 
             RGBColor[
              0.18343934894517555`, 0.310136764840827, 0.9337579715970057], 
             UndirectedEdge[244, 448] -> 
             RGBColor[
              0.373652859998312, 0.49730643195466345`, 0.9450574383468822], 
             UndirectedEdge[259, 275] -> 
             RGBColor[
              0.586292797645066, 0.6743911774092273, 0.9610027781457763], 
             UndirectedEdge[282, 406] -> 
             RGBColor[
              0.5566077877471345, 0.6490860258981348, 0.9590828338050883], 
             UndirectedEdge[286, 357] -> 
             RGBColor[
              0.1879701028596808, 0.3148988744713619, 0.934015991329787], 
             UndirectedEdge[206, 396] -> 
             RGBColor[
              0.18892633617542332`, 0.3159039363149012, 0.9340704474024981], 
             UndirectedEdge[154, 295] -> 
             RGBColor[
              0.9841314996436169, 0.9875855475713144, 0.9072523679449918], 
             UndirectedEdge[410, 428] -> 
             RGBColor[
              0.18501111447909718`, 0.3117887900726693, 0.9338474813189439], 
             UndirectedEdge[104, 147] -> 
             RGBColor[
              0.8716060245867224, 0.4422899593743725, 0.21185872764377553`], 
             UndirectedEdge[32, 255] -> 
             RGBColor[
              0.20842141467182945`, 0.3363944998739921, 0.9351806632824844], 
             UndirectedEdge[165, 498] -> 
             RGBColor[
              0.5402564536084126, 0.6313553023460808, 0.9594503111519376], 
             UndirectedEdge[248, 439] -> 
             RGBColor[
              0.18975162768821172`, 0.3167713700213459, 0.934117446533242], 
             UndirectedEdge[141, 389] -> 
             RGBColor[
              0.20111521708192343`, 0.32871522296731825`, 0.9347645861382899],
              UndirectedEdge[328, 478] -> 
             RGBColor[
              0.24615010342073995`, 0.376049743886127, 0.9373292562921416], 
             UndirectedEdge[178, 261] -> 
             RGBColor[
              0.3993010721320601, 0.5198420484378579, 0.9467840608734395], 
             UndirectedEdge[120, 315] -> 
             RGBColor[
              0.18165682168185682`, 0.3082632156683228, 0.9336564593063725], 
             UndirectedEdge[47, 136] -> 
             RGBColor[
              0.40491583995544145`, 0.5205967008566313, 0.9476756741243257], 
             UndirectedEdge[74, 144] -> 
             RGBColor[
              0.1927927730691202, 0.31996780663643465`, 0.9342906352637134], 
             UndirectedEdge[165, 361] -> 
             RGBColor[
              0.26801366747199473`, 0.39902973593402147`, 0.9385743539206161],
              UndirectedEdge[32, 482] -> 
             RGBColor[
              0.27602220405873207`, 0.40526283104925287`, 0.9391104092526332],
              UndirectedEdge[67, 119] -> 
             RGBColor[
              0.18259585546660687`, 0.3092501997142758, 0.933709935891238], 
             UndirectedEdge[97, 326] -> 
             RGBColor[
              0.8569194124299913, 0.8790587115212953, 0.6914601091734929], 
             UndirectedEdge[409, 430] -> 
             RGBColor[
              0.22739490707234228`, 0.3563368433758307, 0.9362611756059269], 
             UndirectedEdge[113, 190] -> 
             RGBColor[
              0.20663037548476026`, 0.33451200412993914`, 0.9350786662503858],
              UndirectedEdge[292, 496] -> 
             RGBColor[
              0.1854675912889076, 0.3122685761420814, 0.9338734769979656], 
             UndirectedEdge[15, 82] -> 
             RGBColor[
              0.5862643398841738, 0.6748409125363397, 0.9606772556368353], 
             UndirectedEdge[340, 414] -> 
             RGBColor[
              0.3932297908847611, 0.5150176133855842, 0.946277232449094], 
             UndirectedEdge[149, 282] -> 
             RGBColor[
              0.6289215162862603, 0.7087932049561856, 0.9644994328569398], 
             UndirectedEdge[330, 368] -> 
             RGBColor[
              0.18440628949779087`, 0.3111530806691976, 0.9338130374310167], 
             UndirectedEdge[331, 431] -> 
             RGBColor[
              0.3613433617487599, 0.48672321452944306`, 0.9442702081951819], 
             UndirectedEdge[4, 488] -> 
             RGBColor[
              0.1820203772126724, 0.30864533558196194`, 0.9336771632560201], 
             UndirectedEdge[87, 409] -> 
             RGBColor[
              0.28082294387369244`, 0.4124930975872375, 0.9393038232620665], 
             UndirectedEdge[440, 445] -> 
             RGBColor[
              0.9273756618709421, 0.7440317986720315, 0.27125592363752593`], 
             UndirectedEdge[55, 200] -> 
             RGBColor[
              0.4182843192455511, 0.5292210318080617, 0.9489309692760928], 
             UndirectedEdge[64, 215] -> 
             RGBColor[
              0.18488430371745596`, 0.31165550392191765`, 0.9338402596336681],
              UndirectedEdge[167, 493] -> 
             RGBColor[
              0.25038390854803594`, 0.3804997415136645, 0.9375703652307877], 
             UndirectedEdge[153, 470] -> 
             RGBColor[
              0.2111255154646311, 0.3392366812571194, 0.9353346578222758], 
             UndirectedEdge[185, 187] -> 
             RGBColor[
              0.21639359634399347`, 0.34477376827694883`, 0.9356346672349283],
              UndirectedEdge[18, 310] -> 
             RGBColor[
              0.46656300779364224`, 0.5714089084514553, 0.952481474208732], 
             UndirectedEdge[226, 366] -> 
             RGBColor[
              0.18476826025973897`, 0.3115335348902769, 0.9338336511304219], 
             UndirectedEdge[333, 361] -> 
             RGBColor[
              0.2309444912286668, 0.3600676813807619, 0.9364633191724905], 
             UndirectedEdge[236, 300] -> 
             RGBColor[
              0.22011134127912346`, 0.34868135392241384`, 0.9358463873090731],
              UndirectedEdge[161, 335] -> 
             RGBColor[
              0.21211283365491676`, 0.3402744152746985, 0.9353908841326062], 
             UndirectedEdge[61, 397] -> 
             RGBColor[
              0.9061343995223057, 0.5802110742285213, 0.48990321177495955`], 
             UndirectedEdge[393, 480] -> 
             RGBColor[
              0.23233850550566576`, 0.36153287877149787`, 0.9365427062233063],
              UndirectedEdge[349, 378] -> 
             RGBColor[
              0.1960796577618784, 0.3234225308490497, 0.9344778184844558], 
             UndirectedEdge[97, 163] -> 
             RGBColor[
              0.9438826652312557, 0.8041948007039634, 0.3236750855301855], 
             UndirectedEdge[229, 267] -> 
             RGBColor[
              0.23204884719292487`, 0.3612284295194095, 0.9365262106109067], 
             UndirectedEdge[77, 287] -> 
             RGBColor[
              0.31931088859466533`, 0.4505681988320882, 0.9415827311905192], 
             UndirectedEdge[41, 485] -> 
             RGBColor[
              0.2592162515913262, 0.38978309405505573`, 0.9380733541008225], 
             UndirectedEdge[7, 89] -> 
             RGBColor[
              0.39101776123385745`, 0.5125847916537125, 0.9462790973781875], 
             UndirectedEdge[41, 44] -> 
             RGBColor[
              0.27104906144274005`, 0.40222012745236824`, 0.938747215116787], 
             UndirectedEdge[147, 234] -> 
             RGBColor[
              0.872729313424225, 0.4467434253012546, 0.2127625522094079], 
             UndirectedEdge[259, 331] -> 
             RGBColor[
              0.4923539796181456, 0.5933274496466499, 0.9547717909351274], 
             UndirectedEdge[77, 409] -> 
             RGBColor[
              0.2938507755920474, 0.42380800580193695`, 0.940132815419882], 
             UndirectedEdge[2, 334] -> 
             RGBColor[
              0.18552483193608832`, 0.31232873969153496`, 0.9338767367681426],
              UndirectedEdge[315, 487] -> 
             RGBColor[
              0.1880750117052634, 0.3150091403196742, 0.9340219657333442], 
             UndirectedEdge[251, 258] -> 
             RGBColor[
              0.3270553942889411, 0.45124571304551764`, 0.9422970062673146], 
             UndirectedEdge[39, 96] -> 
             RGBColor[
              0.359182658449612, 0.4793995184819319, 0.94444576944529], 
             UndirectedEdge[219, 497] -> 
             RGBColor[
              0.5738542866268592, 0.6645036181845554, 0.959879595311844], 
             UndirectedEdge[447, 454] -> 
             RGBColor[
              0.2225609566268063, 0.3512560549674121, 0.9359858892792425], 
             UndirectedEdge[417, 458] -> 
             RGBColor[
              0.21807667250257026`, 0.34654278803280497`, 0.9357305159322711],
              UndirectedEdge[189, 422] -> 
             RGBColor[
              0.22925608385888036`, 0.3582930581839061, 0.936367166870556], 
             UndirectedEdge[431, 444] -> 
             RGBColor[
              0.4935580470291339, 0.5988610156365437, 0.9535144118851442], 
             UndirectedEdge[161, 273] -> 
             RGBColor[
              0.20050467294518176`, 0.3280735023688687, 0.9347298165529216], 
             UndirectedEdge[109, 413] -> 
             RGBColor[
              0.22197296688604118`, 0.35063804046916514`, 0.9359524041333588],
              UndirectedEdge[236, 470] -> 
             RGBColor[
              0.2014866380141136, 0.3291056099164974, 0.9347857380109101], 
             UndirectedEdge[287, 436] -> 
             RGBColor[
              0.3298373627600314, 0.45968570167815315`, 0.9422534688161406], 
             UndirectedEdge[253, 473] -> 
             RGBColor[
              0.32054318862790937`, 0.44788551033051344`, 0.9417985597710807],
              UndirectedEdge[166, 435] -> 
             RGBColor[
              0.21704014991788595`, 0.3454533370769741, 0.9356714875044712], 
             UndirectedEdge[114, 312] -> 
             RGBColor[
              0.1882015984664733, 0.31514219103177, 0.9340291746621268], 
             UndirectedEdge[222, 296] -> 
             RGBColor[
              0.18966575842362554`, 0.31668111597984006`, 0.934112556405656], 
             UndirectedEdge[5, 346] -> 
             RGBColor[
              0.5654957918264961, 0.6570874909093873, 0.9595208737141337], 
             UndirectedEdge[86, 220] -> 
             RGBColor[
              0.20117259087192368`, 0.32877552645831687`, 0.9347678534907535],
              UndirectedEdge[195, 255] -> 
             RGBColor[
              0.19263264106654965`, 0.3197994977487777, 0.9342815159830611], 
             UndirectedEdge[313, 407] -> 
             RGBColor[
              0.31917500731539133`, 0.44795192850485793`, 0.9416655580915212],
              UndirectedEdge[224, 441] -> 
             RGBColor[
              0.21370093658000952`, 0.34194361214051205`, 0.9354813242448025],
              UndirectedEdge[172, 211] -> 
             RGBColor[
              0.20548759572979827`, 0.33331087015105276`, 0.9350135866339319],
              UndirectedEdge[204, 355] -> 
             RGBColor[
              0.4378065045945586, 0.5507389343512965, 0.9499158019492457], 
             UndirectedEdge[109, 180] -> 
             RGBColor[
              0.23839049921865452`, 0.36789390788241305`, 0.9368873583121385],
              UndirectedEdge[96, 157] -> 
             RGBColor[
              0.3849349952696799, 0.5064668572722832, 0.9459123269300246], 
             UndirectedEdge[316, 372] -> 
             RGBColor[
              0.5264921273018517, 0.6260724945913516, 0.9559761056168596], 
             UndirectedEdge[53, 112] -> 
             RGBColor[
              0.9130580700237505, 0.6218566223199413, 0.468638906464419], 
             UndirectedEdge[28, 305] -> 
             RGBColor[
              0.3931980637426643, 0.5143785677629451, 0.9464441881014032], 
             UndirectedEdge[186, 341] -> 
             RGBColor[
              0.9938102781827736, 0.9891691358468536, 0.5676651626091419], 
             UndirectedEdge[65, 86] -> 
             RGBColor[
              0.18424555499085607`, 0.31098413851125284`, 0.9338038838386322],
              UndirectedEdge[10, 390] -> 
             RGBColor[
              0.24135031626720926`, 0.37100486326368376`, 0.9370559155143968],
              UndirectedEdge[48, 140] -> 
             RGBColor[
              0.1844487281323768, 0.3111976863649123, 0.9338154542484741], 
             UndirectedEdge[231, 404] -> 
             RGBColor[
              0.8002424461846211, 0.8440108833840196, 0.9806882202971826], 
             UndirectedEdge[87, 354] -> 
             RGBColor[
              0.30950000456464066`, 0.4424642256783988, 0.9409431742633377], 
             UndirectedEdge[136, 434] -> 
             RGBColor[
              0.7316510467407765, 0.7040970288480641, 0.6113123490612679], 
             UndirectedEdge[205, 413] -> 
             RGBColor[
              0.2338956489319965, 0.363169535241167, 0.9366313832378486], 
             UndirectedEdge[20, 490] -> 
             RGBColor[
              0.22886274008807128`, 0.3578796289413503, 0.9363447665247084], 
             UndirectedEdge[390, 443] -> 
             RGBColor[
              0.2718752322958543, 0.4030884854012488, 0.9387942643246616], 
             UndirectedEdge[296, 385] -> 
             RGBColor[
              0.18189236637294215`, 0.30851078807304944`, 0.9336698732280726],
              UndirectedEdge[86, 290] -> 
             RGBColor[
              0.18341921937923714`, 0.31011560739073746`, 0.9337568252480046],
              UndirectedEdge[24, 74] -> 
             RGBColor[
              0.18699882666459755`, 0.3138780016078617, 0.9339606785873513], 
             UndirectedEdge[38, 336] -> 
             RGBColor[
              0.5720852226715933, 0.663483581767208, 0.9594557908273795], 
             UndirectedEdge[383, 443] -> 
             RGBColor[
              0.2778055713012203, 0.40932164770109847`, 0.9391319883578669], 
             UndirectedEdge[14, 435] -> 
             RGBColor[
              0.23468936895954257`, 0.3640037853148743, 0.9366765844192138], 
             UndirectedEdge[282, 323] -> 
             RGBColor[
              0.8447117696653836, 0.8771252738990953, 0.8704406417188999], 
             UndirectedEdge[307, 337] -> 
             RGBColor[
              0.19042947914241254`, 0.31748383487797555`, 0.9341560491707674],
              UndirectedEdge[157, 356] -> 
             RGBColor[
              0.272205938145604, 0.40343607821729777`, 0.9388130975335695], 
             UndirectedEdge[166, 439] -> 
             RGBColor[
              0.19745604044376464`, 0.3248691963154145, 0.9345562014420135], 
             UndirectedEdge[266, 293] -> 
             RGBColor[
              0.9016661303754756, 0.9199925303309897, 0.7623198781355807], 
             UndirectedEdge[2, 260] -> 
             RGBColor[
              0.1969726482624509, 0.32436112048401927`, 0.9345286729724024], 
             UndirectedEdge[135, 466] -> 
             RGBColor[
              0.18744105358565671`, 0.3143428101407012, 0.9339858627562896], 
             UndirectedEdge[60, 495] -> 
             RGBColor[
              0.9357924776533132, 0.7819607374227355, 0.5583743815380187], 
             UndirectedEdge[217, 464] -> 
             RGBColor[
              0.19184821856094375`, 0.31897501996012645`, 0.9342368442818159],
              UndirectedEdge[435, 453] -> 
             RGBColor[
              0.2391644667053946, 0.36870739678334974`, 0.9369314346155262], 
             UndirectedEdge[82, 411] -> 
             RGBColor[
              0.4006657201660342, 0.5170983953721258, 0.9473454462572704], 
             UndirectedEdge[94, 193] -> 
             RGBColor[
              0.17992543383268728`, 0.3064434172625156, 0.9335578593297211], 
             UndirectedEdge[88, 469] -> 
             RGBColor[
              0.1854557592359103, 0.3122561399041857, 0.9338728031800514], 
             UndirectedEdge[36, 76] -> 
             RGBColor[
              0.7022798190159381, 0.7608775969992009, 0.8471463932234504], 
             UndirectedEdge[163, 326] -> 
             RGBColor[
              0.8123452824001817, 0.7105293109037376, 0.6054779360527895], 
             UndirectedEdge[151, 472] -> 
             RGBColor[
              0.1934245140122105, 0.3206318064223118, 0.9343266119758453], 
             UndirectedEdge[114, 138] -> 
             RGBColor[
              0.18210218513342014`, 0.30873132089358957`, 0.9336818220960829],
              UndirectedEdge[448, 475] -> 
             RGBColor[
              0.3185563246566676, 0.44958458227411635`, 0.9415467358348658], 
             UndirectedEdge[169, 362] -> 
             RGBColor[
              0.18152465259386255`, 0.3081242975768366, 0.9336489324723378], 
             UndirectedEdge[20, 25] -> 
             RGBColor[
              0.26532620998703904`, 0.39620504772268694`, 0.9384213071925849],
              UndirectedEdge[113, 349] -> 
             RGBColor[
              0.19095597353932497`, 0.3180372138708033, 0.934186032247793], 
             UndirectedEdge[457, 494] -> 
             RGBColor[
              0.4122768656126409, 0.531082608493518, 0.9476104304219592], 
             UndirectedEdge[364, 452] -> 
             RGBColor[
              0.21560011293675418`, 0.34393976690618655`, 0.9355894795287394],
              UndirectedEdge[351, 442] -> 
             RGBColor[
              0.23904734061072216`, 0.3685842898316257, 0.936924764457707], 
             UndirectedEdge[71, 466] -> 
             RGBColor[
              0.1963124589116516, 0.3236672196179068, 0.934491076165537], 
             UndirectedEdge[87, 285] -> 
             RGBColor[
              0.2614000119680612, 0.39207836466940904`, 0.9381977160236936], 
             UndirectedEdge[211, 369] -> 
             RGBColor[
              0.1847549864301014, 0.3115195832537184, 0.933832895205461], 
             UndirectedEdge[164, 316] -> 
             RGBColor[
              0.37736919780669476`, 0.5012799648379501, 0.9452666094831315], 
             UndirectedEdge[27, 297] -> 
             RGBColor[
              0.19023703211735066`, 0.31728156085278936`, 0.93414508959739], 
             UndirectedEdge[238, 483] -> 
             RGBColor[
              0.46936492725835366`, 0.5800559392387936, 0.9513788548661433], 
             UndirectedEdge[109, 164] -> 
             RGBColor[
              0.2648306442899861, 0.3950111522821019, 0.9384177281820844], 
             UndirectedEdge[83, 355] -> 
             RGBColor[
              0.7774683536702185, 0.8228654453922359, 0.8436241428882965], 
             UndirectedEdge[85, 166] -> 
             RGBColor[
              0.19147571921883372`, 0.31858349953374643`, 0.9342156309953462],
              UndirectedEdge[34, 190] -> 
             RGBColor[
              0.2127364473424475, 0.3409298727996848, 0.9354263980095573], 
             UndirectedEdge[232, 383] -> 
             RGBColor[
              0.2731170371748888, 0.40439370106409095`, 0.938864983275437], 
             UndirectedEdge[185, 441] -> 
             RGBColor[
              0.21650425944697038`, 0.34489008221462353`, 0.9356409693349313],
              UndirectedEdge[83, 207] -> 
             RGBColor[
              0.9351069377955797, 0.7587606188367377, 0.47308258317377627`], 
             UndirectedEdge[138, 385] -> 
             RGBColor[
              0.18216276894964933`, 0.30879499832568225`, 0.9336852722547914],
              UndirectedEdge[131, 234] -> 
             RGBColor[
              0.88005378670787, 0.5030425365640092, 0.21977647609763581`], 
             UndirectedEdge[80, 81] -> 
             RGBColor[
              0.2928864737857844, 0.4215973242135559, 0.9401217329908362], 
             UndirectedEdge[5, 486] -> 
             RGBColor[
              0.5514554325451628, 0.6449264373888728, 0.9586262344361294], 
             UndirectedEdge[94, 139] -> 
             RGBColor[
              0.18076319755662762`, 0.3073239600536649, 0.9336055687344391], 
             UndirectedEdge[126, 249] -> 
             RGBColor[
              0.6077030059991793, 0.6911038805087482, 0.9631457140050295], 
             UndirectedEdge[359, 483] -> 
             RGBColor[
              0.6807834462506754, 0.7483260934744262, 0.970628611472146], 
             UndirectedEdge[275, 404] -> 
             RGBColor[
              0.663069657712535, 0.7345059792856424, 0.9686190519229416], 
             UndirectedEdge[313, 391] -> 
             RGBColor[
              0.4171675799720802, 0.5352137954636619, 0.9479510477022336], 
             UndirectedEdge[1, 487] -> 
             RGBColor[
              0.19600881958127922`, 0.3233480754298399, 0.9344737843548664], 
             UndirectedEdge[71, 172] -> 
             RGBColor[
              0.21061538458324242`, 0.3387005013566139, 0.9353056066232517], 
             UndirectedEdge[44, 494] -> 
             RGBColor[
              0.31715651234624226`, 0.44637751215671095`, 0.9415305739530406],
              UndirectedEdge[85, 387] -> 
             RGBColor[
              0.18808022272596522`, 0.31501461743282955`, 0.9340222624932641],
              UndirectedEdge[414, 499] -> 
             RGBColor[
              0.5256197261535013, 0.6249285409604874, 0.9560278119560052], 
             UndirectedEdge[89, 376] -> 
             RGBColor[
              0.3403951990959194, 0.4692549455218861, 0.9429106589801041], 
             UndirectedEdge[171, 403] -> 
             RGBColor[
              0.6070518602239434, 0.6903231179453404, 0.9632668381945488], 
             UndirectedEdge[161, 279] -> 
             RGBColor[
              0.21091668232154126`, 0.339017184382946, 0.9353227650837177], 
             UndirectedEdge[149, 310] -> 
             RGBColor[
              0.6029711284333774, 0.688520564735261, 0.9619129407159268], 
             UndirectedEdge[333, 367] -> 
             RGBColor[
              0.21446892121193922`, 0.34275081268170826`, 0.9355250598334595],
              UndirectedEdge[43, 227] -> 
             RGBColor[
              0.21076377490674741`, 0.3388564689951076, 0.9353140572326515], 
             UndirectedEdge[71, 369] -> 
             RGBColor[
              0.18988277528354555`, 0.3169092144592796, 0.9341249151947808], 
             UndirectedEdge[134, 174] -> 
             RGBColor[
              0.18580423451035571`, 0.31262240951223635`, 0.9338926483314081],
              UndirectedEdge[158, 370] -> 
             RGBColor[
              0.21023358203312498`, 0.3382992026687606, 0.9352838635328488], 
             UndirectedEdge[7, 391] -> 
             RGBColor[
              0.47273438056684836`, 0.582826092442144, 0.9516345286027679], 
             UndirectedEdge[200, 228] -> 
             RGBColor[
              0.26059605928059204`, 0.3912333594213344, 0.9381519321074836], 
             UndirectedEdge[201, 300] -> 
             RGBColor[
              0.24465748938560672`, 0.37448091189800614`, 0.9372442541309653],
              UndirectedEdge[210, 320] -> 
             RGBColor[
              0.18833104309187587`, 0.31527824554033135`, 0.9340365463420472],
              UndirectedEdge[69, 103] -> 
             RGBColor[
              0.4263301464035756, 0.5436874776637394, 0.9483863578332576], 
             UndirectedEdge[97, 281] -> 
             RGBColor[
              0.903440360362725, 0.5576720713111039, 0.28746666826170925`], 
             UndirectedEdge[192, 272] -> 
             RGBColor[
              0.28510804558804614`, 0.41660469339403305`, 0.9395622181414255],
              UndirectedEdge[70, 463] -> 
             RGBColor[
              0.4624511336723232, 0.5722084360335765, 0.9514519951932873], 
             UndirectedEdge[285, 477] -> 
             RGBColor[
              0.20609075774927643`, 0.3339448316762051, 0.935047935818643], 
             UndirectedEdge[10, 168] -> 
             RGBColor[
              0.25974966627430485`, 0.39034374670731053`, 0.9381037312779018],
              UndirectedEdge[298, 468] -> 
             RGBColor[
              0.24859500261068126`, 0.37861948795031725`, 0.9374684896841046],
              UndirectedEdge[37, 264] -> 
             RGBColor[
              0.8636993298194549, 0.4739723151879993, 0.20797971857725228`], 
             UndirectedEdge[191, 405] -> 
             RGBColor[
              0.18612791917026347`, 0.3129626226125922, 0.9339110816939413], 
             UndirectedEdge[349, 380] -> 
             RGBColor[
              0.18633207943578872`, 0.3131772079961678, 0.9339227083190349], 
             UndirectedEdge[94, 410] -> 
             RGBColor[
              0.18058759193707163`, 0.30713938741347224`, 0.9335955682541907],
              UndirectedEdge[335, 409] -> 
             RGBColor[
              0.23180434544224413`, 0.3609714426771376, 0.9365122865979134], 
             UndirectedEdge[168, 189] -> 
             RGBColor[
              0.272342262398906, 0.403579363650975, 0.9388208609981212], 
             UndirectedEdge[187, 399] -> 
             RGBColor[
              0.214562612650492, 0.3428492883240075, 0.9355303954222809], 
             UndirectedEdge[153, 314] -> 
             RGBColor[
              0.24522255976789442`, 0.3750748366973221, 0.93727643405329], 
             UndirectedEdge[233, 355] -> 
             RGBColor[
              0.7611336222299645, 0.8125163214181457, 0.9533731433112391], 
             UndirectedEdge[233, 486] -> 
             RGBColor[
              0.6879460003390702, 0.7520136698120249, 0.9479115120414208], 
             UndirectedEdge[49, 264] -> 
             RGBColor[
              0.9297344136885161, 0.7358812173257631, 0.3948314869060207], 
             UndirectedEdge[205, 331] -> 
             RGBColor[
              0.26945802412846753`, 0.40054784635747565`, 0.938656607895468], 
             UndirectedEdge[308, 456] -> 
             RGBColor[
              0.1932579406357965, 0.32045672724233865`, 0.9343171258684819], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.2456814749936662, 0.3755571856965141, 0.9373025685964933], 
             UndirectedEdge[175, 371] -> 
             RGBColor[
              0.32587980547058965`, 0.4516283990891108, 0.9421708041706565], 
             UndirectedEdge[21, 188] -> 
             RGBColor[
              0.26198974805947073`, 0.39269821469290833`, 0.9382313006216629],
              UndirectedEdge[79, 221] -> 
             RGBColor[
              0.9242610852428408, 0.8982704304455256, 0.6484794882507952], 
             UndirectedEdge[158, 193] -> 
             RGBColor[
              0.1863155768050812, 0.3131598626849669, 0.9339217685186295], 
             UndirectedEdge[266, 483] -> 
             RGBColor[
              0.722812081892279, 0.7773202768708386, 0.7464962569767426], 
             UndirectedEdge[290, 484] -> 
             RGBColor[
              0.18316922942285135`, 0.3098528520962973, 0.9337425886898154], 
             UndirectedEdge[153, 411] -> 
             RGBColor[
              0.2544232242601058, 0.38474531843445803`, 0.937800398284958], 
             UndirectedEdge[176, 475] -> 
             RGBColor[
              0.3267310397254062, 0.4574197374557666, 0.9420399908277568], 
             UndirectedEdge[20, 474] -> 
             RGBColor[
              0.2356355428107931, 0.36499827402342566`, 0.9367304676203037], 
             UndirectedEdge[70, 483] -> 
             RGBColor[
              0.41089196681220996`, 0.5303157024471664, 0.9474026506811422], 
             UndirectedEdge[163, 266] -> 
             RGBColor[
              0.9464459539298948, 0.8121746039800857, 0.3903304044915068], 
             UndirectedEdge[69, 486] -> 
             RGBColor[
              0.4280953978994323, 0.5452164497853305, 0.9484988380976231], 
             UndirectedEdge[262, 475] -> 
             RGBColor[
              0.33984798179840503`, 0.4687809734027203, 0.9428757907777918], 
             UndirectedEdge[18, 167] -> 
             RGBColor[
              0.2640882538669924, 0.39490387734956656`, 0.9383508074229403], 
             UndirectedEdge[281, 374] -> 
             RGBColor[
              0.8329341118682944, 0.254151592405362, 0.1791710487598251], 
             UndirectedEdge[138, 294] -> 
             RGBColor[
              0.18513103991648983`, 0.3119148393110808, 0.9338543108951896], 
             UndirectedEdge[291, 349] -> 
             RGBColor[
              0.1841373062547167, 0.310870362226204, 0.9337977192332487], 
             UndirectedEdge[288, 455] -> 
             RGBColor[
              0.6621340048611841, 0.7355343250121988, 0.9672660118228255], 
             UndirectedEdge[12, 459] -> 
             RGBColor[
              0.19425766410485237`, 0.3215074999944453, 0.9343740586410862], 
             UndirectedEdge[93, 305] -> 
             RGBColor[
              0.26659251557076086`, 0.3973687929461906, 0.9384995442473698], 
             UndirectedEdge[127, 184] -> 
             RGBColor[
              0.6864931860475436, 0.7535560913976342, 0.970424092580223], 
             UndirectedEdge[204, 431] -> 
             RGBColor[
              0.36857757870000185`, 0.49366510624735727`, 0.9447064152877764],
              UndirectedEdge[397, 495] -> 
             RGBColor[
              0.8540509182502993, 0.3729173999622112, 0.19768732648561016`], 
             UndirectedEdge[28, 493] -> 
             RGBColor[
              0.36837307735021396`, 0.48845315530283206`, 0.9450243190265064],
              UndirectedEdge[267, 485] -> 
             RGBColor[
              0.24230090955609868`, 0.3720039970814022, 0.9371100503959223], 
             UndirectedEdge[110, 494] -> 
             RGBColor[
              0.3861892329590033, 0.5089194359790232, 0.9458286143237857], 
             UndirectedEdge[337, 500] -> 
             RGBColor[
              0.1950373272242134, 0.32232697536639066`, 0.9344184593023257], 
             UndirectedEdge[43, 393] -> 
             RGBColor[
              0.2248422553763207, 0.3536538445958466, 0.9361158058681482], 
             UndirectedEdge[167, 432] -> 
             RGBColor[
              0.2655480887278028, 0.39643825634715435`, 0.9384339428586312], 
             UndirectedEdge[230, 474] -> 
             RGBColor[
              0.21770593124316456`, 0.3461531154628161, 0.9357094027660106], 
             UndirectedEdge[40, 421] -> 
             RGBColor[
              0.18467273781712776`, 0.31143313474661993`, 0.933828211268628], 
             UndirectedEdge[254, 476] -> 
             RGBColor[
              0.18792976264725234`, 0.31485647435038233`, 0.9340136940143672],
              UndirectedEdge[107, 197] -> 
             RGBColor[
              0.221090097802618, 0.3497100890853544, 0.9359021260451457], 
             UndirectedEdge[231, 395] -> 
             RGBColor[
              0.6338994865668826, 0.711809040751297, 0.9655924600995638], 
             UndirectedEdge[420, 427] -> 
             RGBColor[
              0.1872793778515779, 0.31417287869335075`, 0.9339766555624116], 
             UndirectedEdge[317, 374] -> 
             RGBColor[
              0.832381649136102, 0.24990512175501872`, 0.1786420098235603], 
             UndirectedEdge[188, 200] -> 
             RGBColor[
              0.24347605986022197`, 0.37323915455986845`, 0.937176973467263], 
             UndirectedEdge[84, 260] -> 
             RGBColor[
              0.24263313262389596`, 0.37235318458981626`, 0.9371289700081534],
              UndirectedEdge[33, 160] -> 
             RGBColor[
              0.24786010554572385`, 0.3778470645398819, 0.937426638383438], 
             UndirectedEdge[135, 362] -> 
             RGBColor[
              0.1796163784049865, 0.3061185804127562, 0.9335402590803201], 
             UndirectedEdge[123, 193] -> 
             RGBColor[
              0.18338517057960285`, 0.31007981994350325`, 0.9337548862192361],
              UndirectedEdge[439, 453] -> 
             RGBColor[
              0.21958035723127328`, 0.3481232560217902, 0.9358161485530685], 
             UndirectedEdge[269, 282] -> 
             RGBColor[
              0.6492936360498982, 0.7253322095338435, 0.966103200750267], 
             UndirectedEdge[202, 459] -> 
             RGBColor[
              0.19062008977227754`, 0.3176841787353756, 0.9341669041641552], 
             UndirectedEdge[25, 474] -> 
             RGBColor[
              0.2592041913656412, 0.3897704179931982, 0.9380726672888113], 
             UndirectedEdge[103, 259] -> 
             RGBColor[
              0.5465386609637427, 0.6409354738239997, 0.9581996401022647], 
             UndirectedEdge[352, 375] -> 
             RGBColor[
              0.19306738802691092`, 0.32025644436866674`, 0.9343062741793031],
              UndirectedEdge[300, 308] -> 
             RGBColor[
              0.21138383769744212`, 0.33950819430237933`, 0.9353493688912808],
              UndirectedEdge[32, 328] -> 
             RGBColor[
              0.23132945208889125`, 0.36047229965278604`, 0.9364852421239818],
              UndirectedEdge[209, 486] -> 
             RGBColor[
              0.7039053523851265, 0.7622075647598039, 0.8443835196310663], 
             UndirectedEdge[118, 496] -> 
             RGBColor[
              0.18901315212113398`, 0.315995185378292, 0.9340753914421738], 
             UndirectedEdge[31, 405] -> 
             RGBColor[
              0.18682010932019663`, 0.3136901583475623, 0.9339505008989764], 
             UndirectedEdge[21, 228] -> 
             RGBColor[
              0.2791097474798408, 0.4106924195543743, 0.9392062592618835], 
             UndirectedEdge[92, 250] -> 
             RGBColor[
              0.24579035153480303`, 0.3756716218444204, 0.9373087689544427], 
             UndirectedEdge[177, 290] -> 
             RGBColor[
              0.1829544926129004, 0.3096271500939387, 0.9337303597461633], 
             UndirectedEdge[9, 333] -> 
             RGBColor[
              0.21279008452790313`, 0.3409862488823926, 0.9354294525679199], 
             UndirectedEdge[11, 444] -> 
             RGBColor[
              0.4707188799474499, 0.5790788770403041, 0.9520591203545818], 
             UndirectedEdge[11, 25] -> 
             RGBColor[
              0.3322342574825351, 0.46035097441527295`, 0.9424578530175007], 
             UndirectedEdge[168, 338] -> 
             RGBColor[
              0.35852241644491945`, 0.4834734222788186, 0.944119987452004], 
             UndirectedEdge[283, 430] -> 
             RGBColor[
              0.19193681077273775`, 0.31906813599179257`, 0.9342418894772171],
              UndirectedEdge[139, 410] -> 
             RGBColor[
              0.18242378949369925`, 0.3090693474671371, 0.9337001369886297], 
             UndirectedEdge[195, 260] -> 
             RGBColor[
              0.1989228362357199, 0.32641089169298415`, 0.9346397332924354], 
             UndirectedEdge[391, 407] -> 
             RGBColor[
              0.3751221590981358, 0.49587301171236503`, 0.9453789816308452], 
             UndirectedEdge[33, 111] -> 
             RGBColor[
              0.3114314409456971, 0.4393163564982453, 0.9412427561367012], 
             UndirectedEdge[2, 114] -> 
             RGBColor[
              0.1828144030828347, 0.30947990711565043`, 0.93372238185467], 
             UndirectedEdge[101, 306] -> 
             RGBColor[
              0.24294061497845892`, 0.37267636803996923`, 0.9371464806733664],
              UndirectedEdge[264, 374] -> 
             RGBColor[
              0.8564940987621058, 0.42401565884056125`, 0.20129244608671454`],
              UndirectedEdge[172, 235] -> 
             RGBColor[
              0.22030500109104192`, 0.3488849026634814, 0.9358574159488678], 
             UndirectedEdge[84, 475] -> 
             RGBColor[
              0.3060220283144641, 0.4364102420981715, 0.9408329262010071], 
             UndirectedEdge[37, 397] -> 
             RGBColor[
              0.8419322626018511, 0.3178894150465442, 0.18757522315711248`], 
             UndirectedEdge[228, 287] -> 
             RGBColor[
              0.28118525934636124`, 0.41287391412114016`, 0.9393244565922372],
              UndirectedEdge[68, 375] -> 
             RGBColor[
              0.19408512083298096`, 0.3213261460758332, 0.9343642325570081], 
             UndirectedEdge[197, 236] -> 
             RGBColor[
              0.21962655292817068`, 0.3481718106282057, 0.9358187793296664], 
             UndirectedEdge[107, 214] -> 
             RGBColor[
              0.19941582681621922`, 0.32692905605049705`, 0.9346678083766806],
              UndirectedEdge[207, 317] -> 
             RGBColor[
              0.8461530053131936, 0.3296770187137239, 0.19080821806446593`], 
             UndirectedEdge[98, 462] -> 
             RGBColor[
              0.18918443929913709`, 0.3161752190626076, 0.9340851459935643], 
             UndirectedEdge[21, 59] -> 
             RGBColor[
              0.2814993677631707, 0.4132040619828309, 0.9393423446018928], 
             UndirectedEdge[46, 350] -> 
             RGBColor[
              0.1926173329949277, 0.3197834079949152, 0.9342806442110285], 
             UndirectedEdge[271, 429] -> 
             RGBColor[
              0.200022442914419, 0.32756664803138713`, 0.9347023542660651], 
             UndirectedEdge[304, 423] -> 
             RGBColor[
              0.1849544721508512, 0.3117292553943517, 0.9338442556221451], 
             UndirectedEdge[299, 328] -> 
             RGBColor[
              0.24152994730330735`, 0.3711936668718884, 0.9370661452361624], 
             UndirectedEdge[55, 73] -> 
             RGBColor[
              0.5752457926482104, 0.6660494748562806, 0.9597046024734881], 
             UndirectedEdge[53, 440] -> 
             RGBColor[
              0.8621535838667478, 0.42648384520047466`, 0.20510522227510283`],
              UndirectedEdge[206, 377] -> 
             RGBColor[
              0.18060293034985866`, 0.30715550905782296`, 0.9335964417541076],
              UndirectedEdge[39, 113] -> 
             RGBColor[
              0.2221538791632596, 0.3508281907430225, 0.9359627068199107], 
             UndirectedEdge[9, 450] -> 
             RGBColor[
              0.20465923888359105`, 0.3324402145848314, 0.9349664129369846], 
             UndirectedEdge[61, 321] -> 
             RGBColor[
              0.9878470936878512, 0.9892424751715496, 0.8510686385130581], 
             UndirectedEdge[76, 460] -> 
             RGBColor[
              0.35555086797246704`, 0.4816356758279989, 0.9439036922676769], 
             UndirectedEdge[141, 167] -> 
             RGBColor[
              0.22358607838206196`, 0.35233352292865905`, 0.9360442684466725],
              UndirectedEdge[29, 476] -> 
             RGBColor[
              0.18392969470854525`, 0.3106521493278456, 0.933785896062828], 
             UndirectedEdge[39, 190] -> 
             RGBColor[
              0.23206747524414745`, 0.361248008782331, 0.9365272714508661], 
             UndirectedEdge[115, 215] -> 
             RGBColor[
              0.18797465353578718`, 0.3149036575204792, 0.9340162504840592], 
             UndirectedEdge[208, 471] -> 
             RGBColor[
              0.6917256837597572, 0.7556316908196963, 0.953176466827428], 
             UndirectedEdge[139, 401] -> 
             RGBColor[
              0.18166335927375138`, 0.3082700870919113, 0.9336568316125594], 
             UndirectedEdge[34, 356] -> 
             RGBColor[
              0.22712257342383618`, 0.3560506034443001, 0.9362456666075261], 
             UndirectedEdge[288, 313] -> 
             RGBColor[
              0.5362219144016962, 0.6308125527023426, 0.9580446920208532], 
             UndirectedEdge[66, 334] -> 
             RGBColor[
              0.19236874220933842`, 0.3195221233176947, 0.9342664873335462], 
             UndirectedEdge[17, 328] -> 
             RGBColor[
              0.30921498256740126`, 0.43616829316491434`, 0.9411464986611078],
              UndirectedEdge[318, 459] -> 
             RGBColor[
              0.1962304097370451, 0.3235809807331772, 0.934486403586424], 
             UndirectedEdge[163, 233] -> 
             RGBColor[
              0.9309329686428551, 0.8036306761921264, 0.5929788217369941], 
             UndirectedEdge[141, 300] -> 
             RGBColor[
              0.21958614921582648`, 0.3481293437647886, 0.9358164783980203], 
             UndirectedEdge[354, 436] -> 
             RGBColor[
              0.33305431044836165`, 0.46289663673916315`, 0.9424429040467747],
              UndirectedEdge[29, 290] -> 
             RGBColor[
              0.18297797671513846`, 0.309651833374369, 0.9337316971310441], 
             UndirectedEdge[110, 360] -> 
             RGBColor[
              0.5066197555658096, 0.6093517092932348, 0.9545740073553726], 
             UndirectedEdge[289, 308] -> 
             RGBColor[
              0.20048868170692968`, 0.3280566945635627, 0.9347289058755601], 
             UndirectedEdge[264, 324] -> 
             RGBColor[
              0.9026383334956752, 0.7184607257731993, 0.5982098779593608], 
             UndirectedEdge[109, 382] -> 
             RGBColor[
              0.2128528625805422, 0.3410522325960747, 0.9354330276851459], 
             UndirectedEdge[293, 497] -> 
             RGBColor[
              0.6439655477048442, 0.7192750682039972, 0.9668676305891115], 
             UndirectedEdge[160, 237] -> 
             RGBColor[
              0.23616950031855627`, 0.3655594972189461, 0.9367608757104513], 
             UndirectedEdge[35, 123] -> 
             RGBColor[
              0.18674780810963457`, 0.3136141651911, 0.933946383451995], 
             UndirectedEdge[218, 432] -> 
             RGBColor[
              0.28855483307734864`, 0.4206198033703701, 0.9397441429139097], 
             UndirectedEdge[46, 476] -> 
             RGBColor[
              0.1935701933686142, 0.32078492466249675`, 0.9343349081996792], 
             UndirectedEdge[288, 391] -> 
             RGBColor[
              0.5921690661844405, 0.6787336359098497, 0.9617581155601771], 
             UndirectedEdge[259, 486] -> 
             RGBColor[
              0.5483039124595994, 0.6424644459455908, 0.95831212036663], 
             UndirectedEdge[138, 296] -> 
             RGBColor[
              0.18249965208881352`, 0.3091490838645686, 0.9337044572511928], 
             UndirectedEdge[56, 494] -> 
             RGBColor[
              0.38107496711151867`, 0.5044897159524077, 0.9455027378263516], 
             UndirectedEdge[91, 200] -> 
             RGBColor[
              0.3616498178113511, 0.4832425921885635, 0.9444724938641782], 
             UndirectedEdge[172, 493] -> 
             RGBColor[
              0.24219838800103033`, 0.3718962404267834, 0.9371042119450282], 
             UndirectedEdge[340, 461] -> 
             RGBColor[
              0.30853231078714655`, 0.43652792912541416`, 0.9410681811421904],
              UndirectedEdge[33, 274] -> 
             RGBColor[
              0.25017787666220814`, 0.38028318893848334`, 0.9375586320196867],
              UndirectedEdge[235, 345] -> 
             RGBColor[
              0.20397947873922884`, 0.3317257435738243, 0.934927701602378], 
             UndirectedEdge[205, 490] -> 
             RGBColor[
              0.22672461704495903`, 0.3556323260582085, 0.9362230035804727], 
             UndirectedEdge[141, 284] -> 
             RGBColor[
              0.20706959880896725`, 0.33497365569204784`, 0.9351036793689267],
              UndirectedEdge[489, 500] -> 
             RGBColor[
              0.19630488377124938`, 0.3236592576650523, 0.9344906447724974], 
             UndirectedEdge[155, 198] -> 
             RGBColor[
              0.1881672276861966, 0.31510606516246586`, 0.934027217297037], 
             UndirectedEdge[23, 157] -> 
             RGBColor[
              0.36552292420320903`, 0.49012707749646917`, 0.944544444701912], 
             UndirectedEdge[248, 344] -> 
             RGBColor[
              0.18527438940385826`, 0.31206550871118754`, 0.9338624744364286],
              UndirectedEdge[50, 131] -> 
             RGBColor[
              0.8570462990670573, 0.5838526913273292, 0.5841917648474512], 
             UndirectedEdge[442, 500] -> 
             RGBColor[
              0.21944649774055142`, 0.34798256120985954`, 0.9358085254530993],
              UndirectedEdge[18, 305] -> 
             RGBColor[
              0.2994340109078254, 0.43188728681651606`, 0.9403698188221772], 
             UndirectedEdge[134, 278] -> 
             RGBColor[
              0.18429769316254274`, 0.3110389390354465, 0.9338068530303782], 
             UndirectedEdge[158, 422] -> 
             RGBColor[
              0.19912370802149765`, 0.3266220206758434, 0.9346511726434723], 
             UndirectedEdge[229, 393] -> 
             RGBColor[
              0.2280783028843851, 0.35705513570408476`, 0.9363000939864292], 
             UndirectedEdge[17, 143] -> 
             RGBColor[
              0.4780476426696782, 0.5850251620356237, 0.9526370440612968], 
             UndirectedEdge[53, 83] -> 
             RGBColor[
              0.9139507635332944, 0.6222257740273145, 0.45384466479453006`], 
             UndirectedEdge[166, 239] -> 
             RGBColor[
              0.19616306235610437`, 0.3235101943657379, 0.9344825682527109], 
             UndirectedEdge[46, 194] -> 
             RGBColor[
              0.19490869460205182`, 0.32219177432471957`, 0.9344111338647885],
              UndirectedEdge[319, 368] -> 
             RGBColor[
              0.18004736950714773`, 0.30657157938754187`, 0.9335648033859939],
              UndirectedEdge[51, 360] -> 
             RGBColor[
              0.7957080349438885, 0.8376426800925825, 0.8429962638681049], 
             UndirectedEdge[132, 250] -> 
             RGBColor[
              0.24597806511608875`, 0.3758689207200801, 0.9373194589651996], 
             UndirectedEdge[80, 447] -> 
             RGBColor[
              0.2905728038348803, 0.41916551040000816`, 0.9399899729099002], 
             UndirectedEdge[128, 179] -> 
             RGBColor[
              0.19718406775789482`, 0.32458333577850107`, 0.9345407129999008],
              UndirectedEdge[218, 300] -> 
             RGBColor[
              0.25886995308296373`, 0.3894191123661732, 0.938053632913074], 
             UndirectedEdge[130, 241] -> 
             RGBColor[
              0.2592745192308342, 0.38984433703856036`, 0.9380766723566932], 
             UndirectedEdge[134, 252] -> 
             RGBColor[
              0.18321908491971373`, 0.3099052533845207, 0.9337454278866071], 
             UndirectedEdge[266, 317] -> 
             RGBColor[
              0.9054511863291719, 0.561405403936883, 0.35359294828676574`], 
             UndirectedEdge[156, 485] -> 
             RGBColor[
              0.22736985486258326`, 0.3563105119149721, 0.9362597489196426], 
             UndirectedEdge[96, 110] -> 
             RGBColor[
              0.443925135446012, 0.558453392319533, 0.9496384572015815], 
             UndirectedEdge[50, 373] -> 
             RGBColor[
              0.9356814566362912, 0.9489939738190079, 0.8936373423891573], 
             UndirectedEdge[37, 322] -> 
             RGBColor[
              0.8413185031158885, 0.3131717906863145, 0.18698748638021256`], 
             UndirectedEdge[65, 290] -> 
             RGBColor[
              0.18235293121758706`, 0.308994870926269, 0.9336961017146306], 
             UndirectedEdge[333, 450] -> 
             RGBColor[
              0.22365738515605757`, 0.35240847086923904`, 0.9360483292619628],
              UndirectedEdge[238, 266] -> 
             RGBColor[
              0.7401362180244184, 0.7914194702417209, 0.7478504944629321], 
             UndirectedEdge[312, 446] -> 
             RGBColor[
              0.18918799273524178`, 0.31617895394925455`, 0.9340853483564936],
              UndirectedEdge[407, 448] -> 
             RGBColor[
              0.28885681920654693`, 0.42093720993918393`, 0.9397613405772192],
              UndirectedEdge[14, 454] -> 
             RGBColor[
              0.2211862721127522, 0.34981117438310894`, 0.9359076030298306], 
             UndirectedEdge[77, 473] -> 
             RGBColor[
              0.2990309117164457, 0.42925265730827966`, 0.9404278165088418], 
             UndirectedEdge[57, 136] -> 
             RGBColor[
              0.7454315064099696, 0.7997658817940283, 0.9520631322982614], 
             UndirectedEdge[364, 487] -> 
             RGBColor[
              0.19856599617315254`, 0.3260358301622591, 0.9346194117787698], 
             UndirectedEdge[80, 403] -> 
             RGBColor[
              0.5454124576914773, 0.6374059872808763, 0.9592088642229862], 
             UndirectedEdge[330, 352] -> 
             RGBColor[
              0.1864863756783814, 0.3133393831300794, 0.9339314952617896], 
             UndirectedEdge[239, 272] -> 
             RGBColor[
              0.22693559422031087`, 0.3558540764462288, 0.9362350184184962], 
             UndirectedEdge[53, 97] -> 
             RGBColor[
              0.910565728681441, 0.6124407745650613, 0.29428992901066414`], 
             UndirectedEdge[304, 311] -> 
             RGBColor[
              0.19034681505715081`, 0.3173969496831598, 0.9341513415734024], 
             UndirectedEdge[237, 241] -> 
             RGBColor[
              0.2242600552960576, 0.35304191539787294`, 0.9360826504348652], 
             UndirectedEdge[361, 441] -> 
             RGBColor[
              0.22578416559546857`, 0.3546438519567282, 0.9361694462616974], 
             UndirectedEdge[276, 347] -> 
             RGBColor[
              0.20833762491305394`, 0.33630643152494155`, 0.935175891579678], 
             UndirectedEdge[11, 180] -> 
             RGBColor[
              0.31935935180321817`, 0.4468186322301426, 0.9417246461857798], 
             UndirectedEdge[56, 360] -> 
             RGBColor[
              0.501505489718325, 0.6049219892666192, 0.9542481308579387], 
             UndirectedEdge[15, 269] -> 
             RGBColor[
              0.6271401903527347, 0.708025769382796, 0.9638951523188943], 
             UndirectedEdge[8, 387] -> 
             RGBColor[
              0.19318868595476607`, 0.32038393618157524`, 0.9343131819168503],
              UndirectedEdge[139, 278] -> 
             RGBColor[
              0.18353174179525936`, 0.31023387558431004`, 0.933763233233135], 
             UndirectedEdge[15, 449] -> 
             RGBColor[
              0.8180065894164226, 0.8423738625918746, 0.678402399648858], 
             UndirectedEdge[348, 355] -> 
             RGBColor[
              0.5108951424447806, 0.6138067180573811, 0.9546386835652754], 
             UndirectedEdge[173, 499] -> 
             RGBColor[
              0.6745850298425644, 0.7454990333041416, 0.9683443785997534], 
             UndirectedEdge[130, 483] -> 
             RGBColor[
              0.3774799425420655, 0.5008371490852502, 0.9452933918504961], 
             UndirectedEdge[173, 282] -> 
             RGBColor[
              0.7086553123271468, 0.7723261830606026, 0.9715957968385069], 
             UndirectedEdge[84, 244] -> 
             RGBColor[
              0.3611185636561085, 0.4841320917787186, 0.9443436287130234], 
             UndirectedEdge[183, 279] -> 
             RGBColor[
              0.202473790723394, 0.3301431700030478, 0.9348419548973421], 
             UndirectedEdge[124, 381] -> 
             RGBColor[
              0.18683393328431724`, 0.31370468821034303`, 0.9339512881532823],
              UndirectedEdge[81, 213] -> 
             RGBColor[
              0.2202872137263247, 0.3488662070153795, 0.9358564029847612], 
             UndirectedEdge[134, 210] -> 
             RGBColor[
              0.18982747480213708`, 0.31685109014706625`, 0.9341217659141743],
              UndirectedEdge[103, 275] -> 
             RGBColor[
              0.4495582322834861, 0.5628291466682479, 0.9501364705331162], 
             UndirectedEdge[256, 298] -> 
             RGBColor[
              0.2936230158270692, 0.42568683963093007`, 0.9400422862891433], 
             UndirectedEdge[18, 235] -> 
             RGBColor[
              0.2527156376053866, 0.3829505365931011, 0.9377031537511198], 
             UndirectedEdge[255, 334] -> 
             RGBColor[
              0.19201279446501912`, 0.3191479996700246, 0.9342462166360848], 
             UndirectedEdge[209, 372] -> 
             RGBColor[
              0.8043736512463036, 0.8448578989108925, 0.8519927857243978], 
             UndirectedEdge[112, 238] -> 
             RGBColor[
              0.7400652706680888, 0.7928555147204785, 0.8555441529553656], 
             UndirectedEdge[360, 457] -> 
             RGBColor[
              0.5327073882194472, 0.6315148818077295, 0.9563558234535461], 
             UndirectedEdge[233, 404] -> 
             RGBColor[
              0.8996921742722623, 0.9221615303078283, 0.9662816131668808], 
             UndirectedEdge[259, 348] -> 
             RGBColor[
              0.5726768344196096, 0.6633371250706486, 0.9599308796437516], 
             UndirectedEdge[244, 376] -> 
             RGBColor[
              0.40891528656398646`, 0.5286036013669932, 0.947276698363635], 
             UndirectedEdge[182, 371] -> 
             RGBColor[
              0.29953966949074173`, 0.42881389719709484`, 0.9404924339976882],
              UndirectedEdge[21, 77] -> 
             RGBColor[
              0.3172353767281449, 0.44838670426532234`, 0.9414645338601655], 
             UndirectedEdge[153, 493] -> 
             RGBColor[
              0.24427091854425903`, 0.3740746014337428, 0.9372222394934309], 
             UndirectedEdge[276, 382] -> 
             RGBColor[
              0.21283416100439742`, 0.3410325760537981, 0.935431962658051], 
             UndirectedEdge[80, 219] -> 
             RGBColor[
              0.508471196315639, 0.6085471931300863, 0.9555269045247576], 
             UndirectedEdge[60, 136] -> 
             RGBColor[
              0.7568575398761165, 0.8080712748113279, 0.923043362246632], 
             UndirectedEdge[23, 96] -> 
             RGBColor[
              0.4513622669101063, 0.5648950617926353, 0.9501123446420765], 
             UndirectedEdge[53, 281] -> 
             RGBColor[
              0.8255492937831006, 0.19738864455464403`, 0.17209933862148452`],
              UndirectedEdge[141, 162] -> 
             RGBColor[
              0.19531753931264573`, 0.32262149603780554`, 0.9344344169662252],
              UndirectedEdge[28, 149] -> 
             RGBColor[
              0.5184855433089055, 0.6199689474225398, 0.9552362277258538], 
             UndirectedEdge[37, 317] -> 
             RGBColor[
              0.839586880193451, 0.2998617781024568, 0.18532928231409804`], 
             UndirectedEdge[372, 486] -> 
             RGBColor[
              0.5138028974550533, 0.6150817214772912, 0.955167559111667], 
             UndirectedEdge[63, 453] -> 
             RGBColor[
              0.2233707740920417, 0.35210722446876735`, 0.9360320071858701], 
             UndirectedEdge[82, 242] -> 
             RGBColor[
              0.7466175241184303, 0.8003829212442619, 0.9428810481338523], 
             UndirectedEdge[4, 191] -> 
             RGBColor[
              0.18605432886244289`, 0.31288527453317777`, 0.933906890834778], 
             UndirectedEdge[70, 403] -> 
             RGBColor[
              0.5565760155932599, 0.6470753000386655, 0.9599201962609412], 
             UndirectedEdge[144, 458] -> 
             RGBColor[
              0.21795043797046626`, 0.346410107535832, 0.935723327062415], 
             UndirectedEdge[16, 224] -> 
             RGBColor[
              0.23802549514267946`, 0.3675102654559681, 0.9368665718699869], 
             UndirectedEdge[40, 206] -> 
             RGBColor[
              0.18271148860033518`, 0.3093717374693884, 0.9337165210271399], 
             UndirectedEdge[148, 485] -> 
             RGBColor[
              0.26499013859378384`, 0.39585181538021874`, 0.9384021684239121],
              UndirectedEdge[34, 291] -> 
             RGBColor[
              0.19600418397695138`, 0.323343203115777, 0.9344735203640577], 
             UndirectedEdge[222, 339] -> 
             RGBColor[
              0.1886442457825459, 0.3156074414264231, 0.9340543827719392], 
             UndirectedEdge[197, 314] -> 
             RGBColor[
              0.24685083225448304`, 0.3767862543191651, 0.9373691617625879], 
             UndirectedEdge[330, 358] -> 
             RGBColor[
              0.20723187960885475`, 0.33514422310192665`, 0.9351129210204074],
              UndirectedEdge[312, 415] -> 
             RGBColor[
              0.18768399799751473`, 0.31459816012112934`, 0.9339996980811409],
              UndirectedEdge[370, 443] -> 
             RGBColor[
              0.2582982777745515, 0.38881824537072385`, 0.9380210768499777], 
             UndirectedEdge[160, 305] -> 
             RGBColor[
              0.2750017432650342, 0.40620742442870245`, 0.938978437324221], 
             UndirectedEdge[266, 343] -> 
             RGBColor[
              0.9199069923129997, 0.6725190633031569, 0.3674358444223769], 
             UndirectedEdge[47, 468] -> 
             RGBColor[
              0.25155549363265645`, 0.38173115172038535`, 0.9376370852681521],
              UndirectedEdge[388, 436] -> 
             RGBColor[
              0.34210441687378856`, 0.470735384053293, 0.943019568825508], 
             UndirectedEdge[69, 209] -> 
             RGBColor[
              0.7186661516906826, 0.7749926272189318, 0.8453240647103539], 
             UndirectedEdge[197, 470] -> 
             RGBColor[
              0.2127537879512197, 0.3409480988789625, 0.9354273855315738], 
             UndirectedEdge[13, 298] -> 
             RGBColor[
              0.26431690444041933`, 0.3951442035995219, 0.9383638287348387], 
             UndirectedEdge[168, 383] -> 
             RGBColor[
              0.2802434761765292, 0.4118840402971449, 0.9392708234339586], 
             UndirectedEdge[123, 428] -> 
             RGBColor[
              0.18681025928894113`, 0.3136798053401847, 0.9339499399542682], 
             UndirectedEdge[137, 485] -> 
             RGBColor[
              0.2335003285987162, 0.3627540285061326, 0.9366088703296922], 
             UndirectedEdge[394, 467] -> 
             RGBColor[
              0.18730056337306505`, 0.3141951460196734, 0.9339778620465191], 
             UndirectedEdge[232, 395] -> 
             RGBColor[
              0.3913003181998807, 0.5091662530135891, 0.9466381048606165], 
             UndirectedEdge[414, 461] -> 
             RGBColor[
              0.337969115719834, 0.4620246100212727, 0.9429438683225567], 
             UndirectedEdge[224, 333] -> 
             RGBColor[
              0.21886126221320776`, 0.3473674415645458, 0.9357751971555954], 
             UndirectedEdge[33, 182] -> 
             RGBColor[
              0.300634259036329, 0.42996438021049266`, 0.9405547692530093], 
             UndirectedEdge[158, 451] -> 
             RGBColor[
              0.19839700824460316`, 0.32585821313490027`, 0.9346097881662341],
              UndirectedEdge[235, 274] -> 
             RGBColor[
              0.23060114107907964`, 0.35970679860388893`, 0.9364437658894125],
              UndirectedEdge[284, 345] -> 
             RGBColor[
              0.19883561542773992`, 0.32631921709367856`, 0.9346347661964527],
              UndirectedEdge[70, 238] -> 
             RGBColor[
              0.4282161029443493, 0.5444148958180487, 0.9487568881673315], 
             UndirectedEdge[21, 55] -> 
             RGBColor[
              0.4367980074447999, 0.5486800919411015, 0.9499852964304927], 
             UndirectedEdge[55, 60] -> 
             RGBColor[
              0.7795430416292072, 0.8264883871046946, 0.9248292480443663], 
             UndirectedEdge[219, 258] -> 
             RGBColor[
              0.5423535654058886, 0.6378943982586738, 0.9576858591221857], 
             UndirectedEdge[175, 463] -> 
             RGBColor[
              0.476418269168048, 0.5843060667913316, 0.9523419687164218], 
             UndirectedEdge[101, 431] -> 
             RGBColor[
              0.33318158758536665`, 0.45712340432410575`, 0.9426664368181881],
              UndirectedEdge[14, 213] -> 
             RGBColor[
              0.21659885926136652`, 0.3449895126175285, 0.9356463566544133], 
             UndirectedEdge[378, 487] -> 
             RGBColor[
              0.1998521204053707, 0.32738762827530654`, 0.9346926546511444], 
             UndirectedEdge[8, 159] -> 
             RGBColor[
              0.21480140592500557`, 0.34310027519588937`, 0.9355439943460016],
              UndirectedEdge[311, 469] -> 
             RGBColor[
              0.18566856806308635`, 0.31247981547440673`, 0.9338849223279366],
              UndirectedEdge[343, 440] -> 
             RGBColor[
              0.8689315587996673, 0.47858233066244793`, 0.21159581872549427`],
              UndirectedEdge[371, 460] -> 
             RGBColor[
              0.2773778998424177, 0.4088721378819603, 0.9391076331009713], 
             UndirectedEdge[224, 358] -> 
             RGBColor[
              0.21540867556861554`, 0.34373855409444265`, 0.9355785774538301],
              UndirectedEdge[455, 475] -> 
             RGBColor[
              0.47478660322499994`, 0.5813210731496465, 0.9526722731511402], 
             UndirectedEdge[310, 408] -> 
             RGBColor[
              0.7910483812120712, 0.837599492064294, 0.9781391837091735], 
             UndirectedEdge[154, 376] -> 
             RGBColor[
              0.6772879972861523, 0.7415239884313045, 0.9288688968046623], 
             UndirectedEdge[282, 499] -> 
             RGBColor[
              0.6626431389741363, 0.7361699373959933, 0.9671541225213036], 
             UndirectedEdge[14, 192] -> 
             RGBColor[
              0.27198473276549623`, 0.40281125955144237`, 0.9388148648903828],
              UndirectedEdge[75, 147] -> 
             RGBColor[
              0.842199332426149, 0.3144945905899744, 0.187617653595973], 
             UndirectedEdge[175, 351] -> 
             RGBColor[
              0.3189338999580072, 0.4443278119995411, 0.9417752451272612], 
             UndirectedEdge[109, 205] -> 
             RGBColor[
              0.22555863330001114`, 0.354406803214629, 0.9361566025311163], 
             UndirectedEdge[43, 148] -> 
             RGBColor[
              0.2515020287225457, 0.38167495670998786`, 0.9376340405206155], 
             UndirectedEdge[56, 92] -> 
             RGBColor[
              0.33939325721103675`, 0.46498406565042605`, 0.9429714183929231],
              UndirectedEdge[46, 412] -> 
             RGBColor[
              0.19698300619667852`, 0.32437200732962346`, 0.9345292628414335],
              UndirectedEdge[170, 214] -> 
             RGBColor[
              0.18764009951956995`, 0.31455202003748506`, 0.9339971981277639],
              UndirectedEdge[94, 437] -> 
             RGBColor[
              0.18042329707310156`, 0.30696670309454366`, 0.93358621190474], 
             UndirectedEdge[173, 249] -> 
             RGBColor[
              0.72377347409997, 0.7841366059398172, 0.9731026339167677], 
             UndirectedEdge[181, 302] -> 
             RGBColor[
              0.235139155224241, 0.3644765391971686, 0.9367021990815891], 
             UndirectedEdge[188, 279] -> 
             RGBColor[
              0.21597972805042376`, 0.3443387664596417, 0.9356110980478727], 
             UndirectedEdge[317, 471] -> 
             RGBColor[
              0.8870778332354172, 0.5507282185220981, 0.561083222125617], 
             UndirectedEdge[8, 344] -> 
             RGBColor[
              0.19388121074334685`, 0.3211118236429813, 0.9343526201790614], 
             UndirectedEdge[236, 493] -> 
             RGBColor[
              0.23463204109374153`, 0.36394353009312075`, 0.9366733196820654],
              UndirectedEdge[31, 366] -> 
             RGBColor[
              0.18726891335142604`, 0.3141618798402035, 0.9339760596246088], 
             UndirectedEdge[176, 261] -> 
             RGBColor[
              0.32311312036066653`, 0.4542860775439437, 0.941809460205036], 
             UndirectedEdge[144, 145] -> 
             RGBColor[
              0.20296158096381922`, 0.33065586847342227`, 0.9348697338299133],
              UndirectedEdge[144, 375] -> 
             RGBColor[
              0.1998107076045579, 0.3273441007959291, 0.9346902962534028], 
             UndirectedEdge[258, 293] -> 
             RGBColor[
              0.6124648264838737, 0.6926658482781156, 0.9646738943994533], 
             UndirectedEdge[242, 269] -> 
             RGBColor[
              0.787493374586991, 0.8335677780907182, 0.9460989448159113], 
             UndirectedEdge[45, 216] -> 
             RGBColor[
              0.20054621348510776`, 0.32811716411015324`, 0.9347321822252167],
              UndirectedEdge[82, 323] -> 
             RGBColor[
              0.7564161337880024, 0.8062755394340282, 0.8629204050270508], 
             UndirectedEdge[258, 272] -> 
             RGBColor[
              0.33620380123362575`, 0.46086126878688316`, 0.9428179945089592],
              UndirectedEdge[92, 356] -> 
             RGBColor[
              0.2586276684650108, 0.3891644558709726, 0.9380398351625095], 
             UndirectedEdge[114, 327] -> 
             RGBColor[
              0.18260674360457746`, 0.3092616438376308, 0.933710555954588], 
             UndirectedEdge[188, 459] -> 
             RGBColor[
              0.20922832641301886`, 0.3372426152751415, 0.9352266157124262], 
             UndirectedEdge[465, 469] -> 
             RGBColor[
              0.18020092681290795`, 0.30673297785199133`, 0.9335735482473893],
              UndirectedEdge[44, 62] -> 
             RGBColor[
              0.2651018322525842, 0.3959692124974049, 0.9384085292125448], 
             UndirectedEdge[88, 337] -> 
             RGBColor[
              0.18932246677623382`, 0.3163202946924838, 0.9340930064541916], 
             UndirectedEdge[253, 388] -> 
             RGBColor[
              0.3530902196198862, 0.48025073422946185`, 0.9437195744621254], 
             UndirectedEdge[80, 238] -> 
             RGBColor[
              0.4170525450425667, 0.5347455830602593, 0.9480455561293766], 
             UndirectedEdge[171, 272] -> 
             RGBColor[
              0.36396083467584234`, 0.48443119432275983`, 0.9447170138830936],
              UndirectedEdge[297, 392] -> 
             RGBColor[
              0.21605655176504493`, 0.3444195130546133, 0.9356154730447699], 
             UndirectedEdge[82, 499] -> 
             RGBColor[
              0.5743475030967551, 0.6653202029309262, 0.9596338858294544], 
             UndirectedEdge[297, 484] -> 
             RGBColor[
              0.1900371894005843, 0.3170715134867078, 0.934133708850311], 
             UndirectedEdge[73, 240] -> 
             RGBColor[
              0.785852186641644, 0.829344990984529, 0.8179383454805261], 
             UndirectedEdge[229, 263] -> 
             RGBColor[
              0.22958947316632627`, 0.3586434714841348, 0.9363861528984097], 
             UndirectedEdge[87, 91] -> 
             RGBColor[
              0.3843682357663767, 0.5071210898901892, 0.9457662741578293], 
             UndirectedEdge[296, 339] -> 
             RGBColor[
              0.18120773687102673`, 0.3077911990585188, 0.9336308845907572], 
             UndirectedEdge[62, 157] -> 
             RGBColor[
              0.27514441268901324`, 0.40652460127246764`, 0.9389804393117331],
              UndirectedEdge[227, 265] -> 
             RGBColor[
              0.18874076831201309`, 0.315708892724775, 0.9340598795871999], 
             UndirectedEdge[38, 127] -> 
             RGBColor[
              0.6754853554676021, 0.7446194386357212, 0.969557515833958], 
             UndirectedEdge[302, 451] -> 
             RGBColor[
              0.22492379054142386`, 0.35373954322399803`, 0.9361204491751804],
              UndirectedEdge[141, 151] -> 
             RGBColor[
              0.20551109996107267`, 0.3333355745883765, 0.9350149251651315], 
             UndirectedEdge[72, 439] -> 
             RGBColor[
              0.2051731991857032, 0.33298041944931656`, 0.9349956822158536], 
             UndirectedEdge[277, 340] -> 
             RGBColor[
              0.40350978000289583`, 0.523921623272436, 0.9469322642654641], 
             UndirectedEdge[53, 322] -> 
             RGBColor[
              0.8267284539733458, 0.20645218648815844`, 0.17322850375133425`],
              UndirectedEdge[450, 461] -> 
             RGBColor[
              0.23439908756698247`, 0.3636986811663903, 0.9366600533233402], 
             UndirectedEdge[352, 367] -> 
             RGBColor[
              0.1902708306368736, 0.3173170852397579, 0.9341470143730765], 
             UndirectedEdge[239, 251] -> 
             RGBColor[
              0.2177871872756262, 0.3462385207048633, 0.9357140301768516], 
             UndirectedEdge[83, 163] -> 
             RGBColor[
              0.9472677000831091, 0.8139798001662166, 0.4832298213140514], 
             UndirectedEdge[179, 245] -> 
             RGBColor[
              0.22201863728698465`, 0.35068604295622735`, 0.9359550049951293],
              UndirectedEdge[133, 237] -> 
             RGBColor[
              0.21543537025685555`, 0.3437666119043239, 0.9355800976768341], 
             UndirectedEdge[199, 244] -> 
             RGBColor[
              0.4164279851399622, 0.5351107232742938, 0.9477554008736777], 
             UndirectedEdge[173, 269] -> 
             RGBColor[
              0.6612355269183264, 0.7346613054419917, 0.9672934568287169], 
             UndirectedEdge[209, 379] -> 
             RGBColor[
              0.9109503146879699, 0.6018931108868748, 0.4575519033361274], 
             UndirectedEdge[139, 451] -> 
             RGBColor[
              0.19384306282883684`, 0.3210717277661138, 0.9343504477117648], 
             UndirectedEdge[18, 218] -> 
             RGBColor[
              0.2870949982165383, 0.4190854243727823, 0.9396610074782187], 
             UndirectedEdge[59, 287] -> 
             RGBColor[
              0.28357487962969113`, 0.41538555654959675`, 0.9394605419322465],
              UndirectedEdge[167, 274] -> 
             RGBColor[
              0.24197375734068546`, 0.3716601393603544, 0.9370914195612329], 
             UndirectedEdge[402, 461] -> 
             RGBColor[
              0.23570042936850655`, 0.3650664739096279, 0.9367341628137743], 
             UndirectedEdge[472, 488] -> 
             RGBColor[
              0.18283227953141887`, 0.3094986963965447, 0.933723399891971], 
             UndirectedEdge[227, 270] -> 
             RGBColor[
              0.18663641062037617`, 0.3134970793668807, 0.9339400395297794], 
             UndirectedEdge[124, 363] -> 
             RGBColor[
              0.1839911193885881, 0.3107167105611202, 0.9337893941074868], 
             UndirectedEdge[118, 195] -> 
             RGBColor[
              0.19015295783973063`, 0.31719319345639363`, 0.9341403016916563],
              UndirectedEdge[54, 154] -> 
             RGBColor[
              0.9864962902894889, 0.9885634492757301, 0.8680616670608778], 
             UndirectedEdge[313, 498] -> 
             RGBColor[
              0.5679033760595678, 0.6555623513374985, 0.9612024040388176], 
             UndirectedEdge[243, 283] -> 
             RGBColor[
              0.18944836976348856`, 0.3164526267147989, 0.934100176443059], 
             UndirectedEdge[302, 346] -> 
             RGBColor[
              0.343088083847486, 0.46567152269516504`, 0.9432988559850268], 
             UndirectedEdge[13, 477] -> 
             RGBColor[
              0.2253695367356543, 0.3542080507360753, 0.9361458337615195], 
             UndirectedEdge[140, 479] -> 
             RGBColor[
              0.18066625764504995`, 0.3072220700602514, 0.9336000481498845], 
             UndirectedEdge[174, 309] -> 
             RGBColor[
              0.18783655214367595`, 0.3147585042012363, 0.9340083858140811], 
             UndirectedEdge[299, 312] -> 
             RGBColor[
              0.21752114274095335`, 0.3459588910307243, 0.9356988793341796], 
             UndirectedEdge[215, 402] -> 
             RGBColor[
              0.2015459552318014, 0.3291679560732161, 0.9347891160387054], 
             UndirectedEdge[372, 400] -> 
             RGBColor[
              0.8020697769239993, 0.8439051876717503, 0.8901739454806034], 
             UndirectedEdge[29, 426] -> 
             RGBColor[
              0.18589315152803693`, 0.3127158669354839, 0.933897712024024], 
             UndirectedEdge[361, 481] -> 
             RGBColor[
              0.217684758794606, 0.34613086187697023`, 0.935708197026387], 
             UndirectedEdge[188, 335] -> 
             RGBColor[
              0.21717587938379926`, 0.3455959973513941, 0.9356792170967612], 
             UndirectedEdge[168, 443] -> 
             RGBColor[
              0.29027458230294984`, 0.42242736884487553`, 0.9398420800881666],
              UndirectedEdge[81, 500] -> 
             RGBColor[
              0.21967281078147302`, 0.34822043056494373`, 0.9358214136459797],
              UndirectedEdge[75, 310] -> 
             RGBColor[
              0.7550654921994678, 0.6018878314253746, 0.587281607852838], 
             UndirectedEdge[348, 444] -> 
             RGBColor[
              0.5139722729928065, 0.6163048712594199, 0.9548809265539167], 
             UndirectedEdge[262, 482] -> 
             RGBColor[
              0.3377696803255693, 0.46698085312541926`, 0.9427433632457125], 
             UndirectedEdge[83, 395] -> 
             RGBColor[
              0.749683946094778, 0.8003088116491959, 0.8414368525463194], 
             UndirectedEdge[26, 459] -> 
             RGBColor[
              0.18968759946741098`, 0.31670407230166076`, 0.9341138002207887],
              UndirectedEdge[186, 498] -> 
             RGBColor[
              0.8839547752105941, 0.9059796859731515, 0.7464098878256111], 
             UndirectedEdge[167, 284] -> 
             RGBColor[
              0.22334665832655862`, 0.3520818772702168, 0.9360306338287019], 
             UndirectedEdge[175, 359] -> 
             RGBColor[
              0.653601757432396, 0.7247826808114364, 0.9688966182964689], 
             UndirectedEdge[65, 484] -> 
             RGBColor[
              0.1839955650344703, 0.31072138321681264`, 0.9337896472804431], 
             UndirectedEdge[266, 322] -> 
             RGBColor[
              0.9071828092516094, 0.5747154165207407, 0.3552511523528803], 
             UndirectedEdge[210, 252] -> 
             RGBColor[
              0.1889152618740288, 0.3158922965219843, 0.9340698167374166], 
             UndirectedEdge[133, 271] -> 
             RGBColor[
              0.20303817120051487`, 0.3307363696682909, 0.9348740955305881], 
             UndirectedEdge[190, 467] -> 
             RGBColor[
              0.20384534758574807`, 0.33158476322710967`, 0.9349200630316166],
              UndirectedEdge[216, 481] -> 
             RGBColor[
              0.20259193459855807`, 0.33026734670659963`, 0.9348486830162546],
              UndirectedEdge[18, 406] -> 
             RGBColor[
              0.35240776193494094`, 0.47777048741806016`, 0.9437452593947762],
              UndirectedEdge[315, 364] -> 
             RGBColor[
              0.19390091491665387`, 0.32113253397844377`, 0.9343537423025814],
              UndirectedEdge[152, 464] -> 
             RGBColor[
              0.19334471949680462`, 0.32054793732735576`, 0.9343220677962385],
              UndirectedEdge[229, 280] -> 
             RGBColor[
              0.24415725813790062`, 0.37395513714017414`, 0.9372157667014342],
              UndirectedEdge[164, 259] -> 
             RGBColor[
              0.4996492818256195, 0.6003222503432779, 0.9552118903262334], 
             UndirectedEdge[238, 497] -> 
             RGBColor[
              0.4824356353537869, 0.5907020081147285, 0.9523982469164629], 
             UndirectedEdge[7, 478] -> 
             RGBColor[
              0.36083387288200847`, 0.48094610395474147`, 0.9445570026671483],
              UndirectedEdge[137, 227] -> 
             RGBColor[
              0.2024073413896048, 0.33007332754010427`, 0.9348381707060858], 
             UndirectedEdge[44, 157] -> 
             RGBColor[
              0.2890530721263536, 0.4211434842010545, 0.9397725168906719], 
             UndirectedEdge[105, 205] -> 
             RGBColor[
              0.21445329260995954`, 0.34273438603011697`, 0.9355241698076971],
              UndirectedEdge[305, 460] -> 
             RGBColor[
              0.3056141271073153, 0.43838298078417876`, 0.9407217672970755], 
             UndirectedEdge[330, 492] -> 
             RGBColor[
              0.1860947118976098, 0.3129277196635705, 0.9339091905888894], 
             UndirectedEdge[94, 123] -> 
             RGBColor[
              0.18238673674691558`, 0.30903040268098764`, 0.933698026889515], 
             UndirectedEdge[418, 444] -> 
             RGBColor[
              0.5211846971324379, 0.6221602420919774, 0.9554487150021684], 
             UndirectedEdge[203, 295] -> 
             RGBColor[
              0.9149334778554977, 0.6677110589938393, 0.5462140209685634], 
             UndirectedEdge[342, 485] -> 
             RGBColor[
              0.36582891890395064`, 0.48572268889805037`, 0.9448845663511518],
              UndirectedEdge[279, 430] -> 
             RGBColor[
              0.2047694881993928, 0.33255609360594945`, 0.9349726914724201], 
             UndirectedEdge[391, 448] -> 
             RGBColor[
              0.38684939186323586`, 0.5081990768979878, 0.9460468301879315], 
             UndirectedEdge[174, 252] -> 
             RGBColor[
              0.18489202158224743`, 0.3116636158871544, 0.9338406991546504], 
             UndirectedEdge[14, 489] -> 
             RGBColor[
              0.2113006394017466, 0.3394207476185267, 0.935344630871422], 
             UndirectedEdge[6, 158] -> 
             RGBColor[
              0.20305085818934585`, 0.33074970449795377`, 0.9348748180358333],
              UndirectedEdge[201, 493] -> 
             RGBColor[
              0.2591781892002248, 0.38974308806871316`, 0.9380711865039575], 
             UndirectedEdge[66, 446] -> 
             RGBColor[
              0.19064470762485328`, 0.3177100536592947, 0.9341683061144403], 
             UndirectedEdge[449, 499] -> 
             RGBColor[
              0.8060897526290038, 0.8328531529864611, 0.6773590298414771], 
             UndirectedEdge[202, 477] -> 
             RGBColor[
              0.19227698695572149`, 0.31942568272852423`, 0.9342612620075925],
              UndirectedEdge[89, 299] -> 
             RGBColor[
              0.27487744861956126`, 0.4061575123810962, 0.9389684030253784], 
             UndirectedEdge[57, 91] -> 
             RGBColor[
              0.7114825067288603, 0.7722045544678969, 0.9493905426840812], 
             UndirectedEdge[222, 438] -> 
             RGBColor[
              0.19987204711910306`, 0.3274085725148659, 0.9346937894480125], 
             UndirectedEdge[83, 346] -> 
             RGBColor[
              0.7183210910606576, 0.7745238473066297, 0.8390571508964824], 
             UndirectedEdge[38, 388] -> 
             RGBColor[
              0.42375389748919434`, 0.5396775316025662, 0.9487136143198416], 
             UndirectedEdge[345, 472] -> 
             RGBColor[
              0.1869884495343811, 0.3138670945860562, 0.9339600876251372], 
             UndirectedEdge[231, 486] -> 
             RGBColor[
              0.5884962722514289, 0.6738630228882163, 0.9623181191717225], 
             UndirectedEdge[14, 251] -> 
             RGBColor[
              0.23495511782487732`, 0.36428310422179233`, 0.9366917184239543],
              UndirectedEdge[404, 418] -> 
             RGBColor[
              0.6566661186267099, 0.7293072977796211, 0.9681149418691689], 
             UndirectedEdge[10, 370] -> 
             RGBColor[
              0.22777336174590646`, 0.35673462323315885`, 0.9362827280397129],
              UndirectedEdge[216, 224] -> 
             RGBColor[
              0.20292469844545702`, 0.3306171026081368, 0.9348676334250554], 
             UndirectedEdge[116, 143] -> 
             RGBColor[
              0.4285653763865951, 0.5391828000638526, 0.9495933114012363], 
             UndirectedEdge[142, 477] -> 
             RGBColor[
              0.2067532217668407, 0.3346411233613098, 0.9350856621644155], 
             UndirectedEdge[1, 378] -> 
             RGBColor[
              0.20312084702488786`, 0.3308232672016569, 0.9348788037964781], 
             UndirectedEdge[47, 298] -> 
             RGBColor[
              0.2786489927595025, 0.4102081371297621, 0.9391800199621858], 
             UndirectedEdge[50, 340] -> 
             RGBColor[
              0.6220781556562913, 0.698481383789535, 0.9664262896114366], 
             UndirectedEdge[144, 417] -> 
             RGBColor[
              0.19700492333763642`, 0.3243950436343972, 0.9345305109901875], 
             UndirectedEdge[326, 395] -> 
             RGBColor[
              0.6147615284118504, 0.6968583223867169, 0.9636849672850575], 
             UndirectedEdge[14, 166] -> 
             RGBColor[
              0.21333099290535548`, 0.34155477788266697`, 0.9354602564998136],
              UndirectedEdge[41, 132] -> 
             RGBColor[
              0.2677010857798615, 0.3987011927567655, 0.9385565528556723], 
             UndirectedEdge[6, 35] -> 
             RGBColor[
              0.2010217865796709, 0.32861702158561484`, 0.9347592654094047], 
             UndirectedEdge[95, 286] -> 
             RGBColor[
              0.18603827385130794`, 0.3128683996985284, 0.9339059765256451], 
             UndirectedEdge[435, 439] -> 
             RGBColor[
              0.21881441649795172`, 0.3473182037476218, 0.9357725293614136], 
             UndirectedEdge[354, 388] -> 
             RGBColor[
              0.3196378407891415, 0.45127596505171874`, 0.9415880184638075], 
             UndirectedEdge[47, 59] -> 
             RGBColor[
              0.272302702026903, 0.4035377831917274, 0.9388186080934602], 
             UndirectedEdge[305, 493] -> 
             RGBColor[
              0.2857296655888689, 0.41748315098061395`, 0.9395893766300246], 
             UndirectedEdge[26, 335] -> 
             RGBColor[
              0.1976351524381914, 0.3250574543779134, 0.9345664016051236], 
             UndirectedEdge[24, 115] -> 
             RGBColor[
              0.18813870785962614`, 0.3150760890164789, 0.9340255931351051], 
             UndirectedEdge[271, 351] -> 
             RGBColor[
              0.2241430772010206, 0.3529189640031495, 0.9360759887054064], 
             UndirectedEdge[12, 40] -> 
             RGBColor[
              0.18952205245126588`, 0.31653007189140514`, 0.9341043725631242],
              UndirectedEdge[228, 468] -> 
             RGBColor[
              0.23985909159475186`, 0.369437491583826, 0.9369709924753695], 
             UndirectedEdge[1, 108] -> 
             RGBColor[
              0.20444558985732308`, 0.3322156559120931, 0.9349542459410038], 
             UndirectedEdge[97, 343] -> 
             RGBColor[
              0.9173437036143605, 0.6645392600270346, 0.3007805254610556], 
             UndirectedEdge[314, 411] -> 
             RGBColor[
              0.27200862613590066`, 0.4032286907847955, 0.9388018609065139], 
             UndirectedEdge[211, 466] -> 
             RGBColor[
              0.1911846700582075, 0.3182775884123456, 0.9341990561762171], 
             UndirectedEdge[12, 202] -> 
             RGBColor[
              0.1903977819160206, 0.31745051908331734`, 0.9341542440606163], 
             UndirectedEdge[96, 360] -> 
             RGBColor[
              0.5334689580963748, 0.6321331585421514, 0.9564157770239803], 
             UndirectedEdge[199, 482] -> 
             RGBColor[
              0.35925314832548205`, 0.4855887533164457, 0.9441122708295822], 
             UndirectedEdge[9, 357] -> 
             RGBColor[
              0.19116813878282407`, 0.31826021299377427`, 0.9341981147445398],
              UndirectedEdge[330, 441] -> 
             RGBColor[
              0.20552414062024876`, 0.33334928114799606`, 0.9350156678113797],
              UndirectedEdge[375, 461] -> 
             RGBColor[
              0.22800718101290143`, 0.35698038210776833`, 0.9362960437010637],
              UndirectedEdge[170, 268] -> 
             RGBColor[
              0.18701827847814975`, 0.31389844669722133`, 0.9339617863393568],
              UndirectedEdge[66, 245] -> 
             RGBColor[
              0.22090376329813846`, 0.34951423970685647`, 0.9358915145707727],
              UndirectedEdge[235, 308] -> 
             RGBColor[
              0.2040111506020718, 0.33175903270978435`, 0.9349295052681127], 
             UndirectedEdge[42, 315] -> 
             RGBColor[
              0.19198004367677265`, 0.3191135765150577, 0.9342443515271446], 
             UndirectedEdge[238, 403] -> 
             RGBColor[
              0.6150489760394036, 0.6968155368302928, 0.9638964004459423], 
             UndirectedEdge[382, 425] -> 
             RGBColor[
              0.19937423959475875`, 0.32688534524395996`, 0.9346654400459413],
              UndirectedEdge[74, 215] -> 
             RGBColor[
              0.1868347723407586, 0.3137055701118621, 0.9339513359363054], 
             UndirectedEdge[350, 426] -> 
             RGBColor[
              0.1844406280385869, 0.3111891726527635, 0.9338149929601158], 
             UndirectedEdge[78, 497] -> 
             RGBColor[
              0.47412146300073554`, 0.5839521884493253, 0.9517437248130138], 
             UndirectedEdge[109, 490] -> 
             RGBColor[
              0.21480193499900369`, 0.3431008312862066, 0.935544024475983], 
             UndirectedEdge[281, 317] -> 
             RGBColor[
              0.8178714627321924, 0.13837347065034328`, 0.1647470389362648], 
             UndirectedEdge[219, 471] -> 
             RGBColor[
              0.8131815162037359, 0.854543894896763, 0.9628221166971644], 
             UndirectedEdge[183, 243] -> 
             RGBColor[
              0.19677206267761843`, 0.3241502923164997, 0.9345172499200859], 
             UndirectedEdge[93, 151] -> 
             RGBColor[
              0.21317178010893856`, 0.3413874351389585, 0.9354511895665918], 
             UndirectedEdge[176, 478] -> 
             RGBColor[
              0.2831235992471345, 0.4141542435922354, 0.9394625592452028], 
             UndirectedEdge[28, 282] -> 
             RGBColor[
              0.586277448481364, 0.6741728296188088, 0.961142335628971], 
             UndirectedEdge[125, 305] -> 
             RGBColor[
              0.5442522046967718, 0.6349340468295404, 0.9597558326180513], 
             UndirectedEdge[22, 466] -> 
             RGBColor[
              0.188342270881701, 0.3152900466593206, 0.9340371857480678], 
             UndirectedEdge[78, 154] -> 
             RGBColor[
              0.7267639040768494, 0.783922928096006, 0.9321470662934741], 
             UndirectedEdge[273, 421] -> 
             RGBColor[
              0.18574774173175967`, 0.3125630320200829, 0.9338894311512407], 
             UndirectedEdge[221, 234] -> 
             RGBColor[
              0.9443267569423743, 0.8151145515040961, 0.2837836064703105], 
             UndirectedEdge[384, 461] -> 
             RGBColor[
              0.26067331628804735`, 0.3913145614345472, 0.9381563317797668], 
             UndirectedEdge[3, 428] -> 
             RGBColor[
              0.18571633162823864`, 0.3125300180097667, 0.9338876423923121], 
             UndirectedEdge[209, 431] -> 
             RGBColor[
              0.707864048381464, 0.7656363882619854, 0.8446357642394154], 
             UndirectedEdge[33, 237] -> 
             RGBColor[
              0.24458077131553108`, 0.3744002763421501, 0.9372398851503687], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.26751337219857585`, 0.3985038938811058, 0.9385458628449154], 
             UndirectedEdge[202, 243] -> 
             RGBColor[
              0.1916697633639069, 0.3187874522333277, 0.9342266815223454], 
             UndirectedEdge[169, 456] -> 
             RGBColor[
              0.18971194776524802`, 0.31672966390645874`, 0.9341151868203305],
              UndirectedEdge[86, 297] -> 
             RGBColor[
              0.1902871793569701, 0.317334268781148, 0.9341479454085002], 
             UndirectedEdge[40, 202] -> 
             RGBColor[
              0.18588447811869105`, 0.31270675063233544`, 0.933897218086193], 
             UndirectedEdge[396, 477] -> 
             RGBColor[
              0.19761610506605493`, 0.32503743438212485`, 0.9345653168854586],
              UndirectedEdge[209, 355] -> 
             RGBColor[
              0.7770929742760209, 0.8227102163659248, 0.8498451509008846], 
             UndirectedEdge[131, 434] -> 
             RGBColor[
              0.8844045850628767, 0.520292002224005, 0.22327723058043727`], 
             UndirectedEdge[87, 228] -> 
             RGBColor[
              0.28331447723561765`, 0.41511185712296006`, 0.9394457124011348],
              UndirectedEdge[17, 116] -> 
             RGBColor[
              0.32596120839538445`, 0.45376963828216715`, 0.9421001714481905],
              UndirectedEdge[104, 323] -> 
             RGBColor[
              0.958420920419589, 0.8640840271773381, 0.5141442750004963], 
             UndirectedEdge[101, 347] -> 
             RGBColor[
              0.22409394315426182`, 0.3528673210047275, 0.9360731905941307], 
             UndirectedEdge[92, 342] -> 
             RGBColor[
              0.37412603951120016`, 0.4944434887241004, 0.9453570750952447], 
             UndirectedEdge[399, 464] -> 
             RGBColor[
              0.20516649221167577`, 0.332973369994367, 0.9349953002636049], 
             UndirectedEdge[423, 469] -> 
             RGBColor[
              0.18027622515678673`, 0.30681212118559864`, 0.9335778363766793],
              UndirectedEdge[114, 415] -> 
             RGBColor[
              0.18091671513236096`, 0.30748531675933716`, 0.9336143113332682],
              UndirectedEdge[244, 478] -> 
             RGBColor[
              0.34801769220506096`, 0.4703622452404419, 0.9435975534648887], 
             UndirectedEdge[129, 486] -> 
             RGBColor[
              0.3513552004898414, 0.47695704074611134`, 0.9436745944599232], 
             UndirectedEdge[202, 421] -> 
             RGBColor[
              0.18554846728188248`, 0.31235358193853213`, 0.9338780827661202],
              UndirectedEdge[62, 378] -> 
             RGBColor[
              0.22907866033211158`, 0.3581065748079708, 0.9363570628631811], 
             UndirectedEdge[263, 485] -> 
             RGBColor[
              0.23984153552950008`, 0.3694190390461275, 0.9369699926834254], 
             UndirectedEdge[275, 346] -> 
             RGBColor[
              0.4653638430606762, 0.5765191723103537, 0.951143590075486], 
             UndirectedEdge[127, 303] -> 
             RGBColor[
              0.8364744443127496, 0.5917978023235237, 0.5852770137807005], 
             UndirectedEdge[260, 312] -> 
             RGBColor[
              0.2023598436460895, 0.3300234044001388, 0.9348354657798592], 
             UndirectedEdge[32, 299] -> 
             RGBColor[
              0.22987290893586354`, 0.3589413804487841, 0.9364022941461793], 
             UndirectedEdge[283, 396] -> 
             RGBColor[
              0.18987793209336085`, 0.3169041239593195, 0.9341246393822646], 
             UndirectedEdge[87, 253] -> 
             RGBColor[
              0.34295238339538536`, 0.47143899485614194`, 0.9430747302616557],
              UndirectedEdge[298, 409] -> 
             RGBColor[
              0.26446105735967274`, 0.39529571745748016`, 0.9383720380303351],
              UndirectedEdge[208, 258] -> 
             RGBColor[
              0.42089773296190985`, 0.5389821941816072, 0.9480402092524494], 
             UndirectedEdge[142, 161] -> 
             RGBColor[
              0.21478163330642375`, 0.3430794929201034, 0.9355428683246243], 
             UndirectedEdge[71, 211] -> 
             RGBColor[
              0.19261088350739852`, 0.3197766291746009, 0.9342802769222549], 
             UndirectedEdge[14, 453] -> 
             RGBColor[
              0.23545530969286413`, 0.36480883758904264`, 0.9367202036108686],
              UndirectedEdge[89, 478] -> 
             RGBColor[
              0.27949760473699387`, 0.41101358939533483`, 0.9392315140813577],
              UndirectedEdge[159, 251] -> 
             RGBColor[
              0.23552312226059172`, 0.3648801128972894, 0.936724065436281], 
             UndirectedEdge[300, 305] -> 
             RGBColor[
              0.27120896577425085`, 0.40222097480990704`, 0.9387624442570324],
              UndirectedEdge[327, 385] -> 
             RGBColor[
              0.18266732742080666`, 0.30932532126972345`, 0.9337140061132965],
              UndirectedEdge[156, 270] -> 
             RGBColor[
              0.18975438070497386`, 0.3167742636165143, 0.9341176033134739], 
             UndirectedEdge[418, 486] -> 
             RGBColor[
              0.4449199446935177, 0.5591594372838178, 0.9497448407437088], 
             UndirectedEdge[366, 465] -> 
             RGBColor[
              0.18080307297570358`, 0.30736587164736134`, 0.9336078395805651],
              UndirectedEdge[337, 433] -> 
             RGBColor[
              0.1848796930167158, 0.31165065778310447`, 0.9338399970610818], 
             UndirectedEdge[118, 152] -> 
             RGBColor[
              0.1882232378558979, 0.3151649354020718, 0.9340304069933419], 
             UndirectedEdge[151, 162] -> 
             RGBColor[
              0.1935196204092478, 0.32073176927569186`, 0.9343320281444594], 
             UndirectedEdge[80, 251] -> 
             RGBColor[
              0.2931730251986915, 0.4218985079169302, 0.9401380516698865], 
             UndirectedEdge[348, 486] -> 
             RGBColor[
              0.4377075205538863, 0.5533040664512603, 0.949177052295457], 
             UndirectedEdge[376, 455] -> 
             RGBColor[
              0.4920767571056538, 0.5962969354126668, 0.9537739864673327], 
             UndirectedEdge[153, 197] -> 
             RGBColor[
              0.22926543037868818`, 0.35830288196882765`, 0.9363676991410321],
              UndirectedEdge[9, 319] -> 
             RGBColor[
              0.18732739999033735`, 0.3142233530059664, 0.9339793903521716], 
             UndirectedEdge[184, 336] -> 
             RGBColor[
              0.5830930532515349, 0.672420234529121, 0.9603223675736445], 
             UndirectedEdge[41, 56] -> 
             RGBColor[
              0.33496751620801646`, 0.46033233124806494`, 0.9427193789900982],
              UndirectedEdge[99, 313] -> 
             RGBColor[
              0.6704591742575927, 0.7358360174967769, 0.9317439644037724], 
             UndirectedEdge[111, 130] -> 
             RGBColor[
              0.3347552996533061, 0.46383121081799694`, 0.9425710153855427], 
             UndirectedEdge[255, 327] -> 
             RGBColor[
              0.19047479361502342`, 0.3175314632617931, 0.9341586297629458], 
             UndirectedEdge[32, 84] -> 
             RGBColor[
              0.2475939365043437, 0.3775673040012994, 0.9374114804502933], 
             UndirectedEdge[196, 420] -> 
             RGBColor[
              0.19002037884251344`, 0.3170538445243244, 0.9341327515138979], 
             UndirectedEdge[55, 57] -> 
             RGBColor[
              0.7681170081630603, 0.818182994087395, 0.9538490180959958], 
             UndirectedEdge[10, 480] -> 
             RGBColor[
              0.2350739989368308, 0.3644080558079533, 0.9366984885274112], 
             UndirectedEdge[152, 216] -> 
             RGBColor[
              0.19207526490404528`, 0.31921366006229573`, 0.9342497742351705],
              UndirectedEdge[244, 482] -> 
             RGBColor[
              0.3895468312104969, 0.511827618826672, 0.9460425575153633], 
             UndirectedEdge[111, 463] -> 
             RGBColor[
              0.4608753150975682, 0.5708435411870683, 0.9513515854271455], 
             UndirectedEdge[58, 74] -> 
             RGBColor[
              0.19093718319717995`, 0.31801746402983233`, 0.9341849621656055],
              UndirectedEdge[66, 327] -> 
             RGBColor[
              0.19083074135934272`, 0.31790558690946313`, 0.9341789004604073],
              UndirectedEdge[168, 346] -> 
             RGBColor[
              0.3670639021674008, 0.4908716279040769, 0.9446642433693013], 
             UndirectedEdge[53, 471] -> 
             RGBColor[
              0.8947556642863255, 0.6097433924263989, 0.5684355218108367], 
             UndirectedEdge[28, 125] -> 
             RGBColor[
              0.6268956164581168, 0.7059040511517584, 0.965190775014533], 
             UndirectedEdge[405, 423] -> 
             RGBColor[
              0.18042956728835297`, 0.30697329348832747`, 0.9335865689842227],
              UndirectedEdge[314, 493] -> 
             RGBColor[
              0.2618563204200539, 0.3925579737840803, 0.9382237021149867], 
             UndirectedEdge[43, 229] -> 
             RGBColor[
              0.231604699752685, 0.3607616023991431, 0.9365009170712423], 
             UndirectedEdge[281, 397] -> 
             RGBColor[
              0.8202168451405925, 0.15640110759443068`, 0.16699297977927924`],
              UndirectedEdge[203, 324] -> 
             RGBColor[
              0.8924019068162066, 0.6510073815667528, 0.588847136940535], 
             UndirectedEdge[403, 445] -> 
             RGBColor[
              0.8532638533992596, 0.8433645979013125, 0.6431418553174187], 
             UndirectedEdge[147, 303] -> 
             RGBColor[
              0.8299391758302155, 0.23113120162734693`, 0.17630309462746424`],
              UndirectedEdge[356, 457] -> 
             RGBColor[
              0.35728371097557365`, 0.477585785779042, 0.9443210439032999], 
             UndirectedEdge[8, 85] -> 
             RGBColor[
              0.19237812780276942`, 0.31953198817147166`, 0.9342670218292075],
              UndirectedEdge[301, 336] -> 
             RGBColor[
              0.6408993785116156, 0.7191341855671287, 0.9650206560001502], 
             UndirectedEdge[24, 64] -> 
             RGBColor[
              0.18504835804129488`, 0.3118279354179173, 0.933849602284714], 
             UndirectedEdge[30, 488] -> 
             RGBColor[
              0.18073134444068237`, 0.30729048040920226`, 0.9336037547466085],
              UndirectedEdge[191, 366] -> 
             RGBColor[
              0.18657672320149288`, 0.31343434410523346`, 0.9339366404195737],
              UndirectedEdge[185, 481] -> 
             RGBColor[
              0.2084048526461078, 0.33637709213486555`, 0.9351797200996208], 
             UndirectedEdge[308, 389] -> 
             RGBColor[
              0.19291290556353907`, 0.320094073504909, 0.9342974766315505], 
             UndirectedEdge[96, 240] -> 
             RGBColor[
              0.7327901627995155, 0.786266849612556, 0.8137611085910759], 
             UndirectedEdge[108, 113] -> 
             RGBColor[
              0.2031652064588611, 0.33086989177931336`, 0.934881330000619], 
             UndirectedEdge[85, 332] -> 
             RGBColor[
              0.18694868384128802`, 0.31382529832132483`, 0.9339578230277437],
              UndirectedEdge[232, 280] -> 
             RGBColor[
              0.26596668909501486`, 0.3968782318738905, 0.9384577815302801], 
             UndirectedEdge[310, 419] -> 
             RGBColor[
              0.6470494829273306, 0.7241992409118212, 0.9654555035031411], 
             UndirectedEdge[39, 378] -> 
             RGBColor[
              0.22727756338581306`, 0.356213507721269, 0.9362544930565735], 
             UndirectedEdge[53, 257] -> 
             RGBColor[
              0.8978636395827194, 0.5695936454427237, 0.2449447114503845], 
             UndirectedEdge[248, 339] -> 
             RGBColor[
              0.18022958629127006`, 0.30676310078086577`, 0.933575180362284], 
             UndirectedEdge[327, 334] -> 
             RGBColor[
              0.18531717245783108`, 0.3121104764135153, 0.9338649108680606], 
             UndirectedEdge[165, 358] -> 
             RGBColor[
              0.26540482039910535`, 0.39628767224995665`, 0.9384257839392585],
              UndirectedEdge[69, 204] -> 
             RGBColor[
              0.37937968200922045`, 0.5030213452043036, 0.9453947157587149], 
             UndirectedEdge[208, 293] -> 
             RGBColor[
              0.6181817945706438, 0.697617598691705, 0.965038174550626], 
             UndirectedEdge[265, 320] -> 
             RGBColor[
              0.18273053674122575`, 0.3093917582731863, 0.9337176057905845], 
             UndirectedEdge[239, 453] -> 
             RGBColor[
              0.21828737914361301`, 0.34676425407211353`, 0.935742515363766], 
             UndirectedEdge[108, 452] -> 
             RGBColor[
              0.21821098000140754`, 0.3466839537296702, 0.9357381645456397], 
             UndirectedEdge[331, 418] -> 
             RGBColor[
              0.38897001185206387`, 0.5100224409848767, 0.9462045113122062], 
             UndirectedEdge[28, 201] -> 
             RGBColor[
              0.3666465873540202, 0.4866385048510442, 0.9449259979753362], 
             UndirectedEdge[431, 486] -> 
             RGBColor[
              0.4172932945902137, 0.5358602108283841, 0.9478105376266845], 
             UndirectedEdge[269, 419] -> 
             RGBColor[
              0.6255800853713929, 0.7068070035141348, 0.9637396556343641], 
             UndirectedEdge[315, 378] -> 
             RGBColor[
              0.19518703914887203`, 0.3224843320914912, 0.934426985174956], 
             UndirectedEdge[57, 240] -> 
             RGBColor[
              0.9787234021564939, 0.9814785102156434, 0.8120827611030339], 
             UndirectedEdge[7, 176] -> 
             RGBColor[
              0.39464375574399807`, 0.5157254458506131, 0.9465101425420326], 
             UndirectedEdge[6, 302] -> 
             RGBColor[
              0.22957764048616652`, 0.3586310345870516, 0.9363854790447795], 
             UndirectedEdge[176, 455] -> 
             RGBColor[
              0.46498904560871784`, 0.5728349211819872, 0.9520479814434708], 
             UndirectedEdge[161, 396] -> 
             RGBColor[
              0.205644516605638, 0.33347580394091847`, 0.9350225230456672], 
             UndirectedEdge[36, 463] -> 
             RGBColor[
              0.7746453145833472, 0.820791726755383, 0.8525214986025103], 
             UndirectedEdge[131, 373] -> 
             RGBColor[
              0.9123644303428394, 0.625404830056993, 0.48937807328246297`], 
             UndirectedEdge[54, 341] -> 
             RGBColor[
              0.991911410491914, 0.9900737129022821, 0.7219654915810148], 
             UndirectedEdge[272, 453] -> 
             RGBColor[
              0.24857862251541402`, 0.3786022714316334, 0.9374675568619113], 
             UndirectedEdge[169, 236] -> 
             RGBColor[
              0.19608590653883476`, 0.32342909870982617`, 0.9344781743430592],
              UndirectedEdge[69, 101] -> 
             RGBColor[
              0.3439836908945852, 0.4664796432810521, 0.9433547372891266], 
             UndirectedEdge[286, 330] -> 
             RGBColor[
              0.18848828405783719`, 0.3154435157652098, 0.9340455009824417], 
             UndirectedEdge[86, 254] -> 
             RGBColor[
              0.18887066842711453`, 0.3158454259818896, 0.934067277206585], 
             UndirectedEdge[68, 319] -> 
             RGBColor[
              0.1831451884938083, 0.30982758355559015`, 0.9337412195944718], 
             UndirectedEdge[37, 207] -> 
             RGBColor[
              0.8684208855066446, 0.4954117968161807, 0.21191950037856397`], 
             UndirectedEdge[257, 317] -> 
             RGBColor[
              0.8901858085318111, 0.510578471538423, 0.23759241176516477`], 
             UndirectedEdge[94, 158] -> 
             RGBColor[
              0.18531714297239393`, 0.3121104454224513, 0.9338649091889084], 
             UndirectedEdge[253, 336] -> 
             RGBColor[
              0.5014215448022852, 0.6040567843941038, 0.9544617509696633], 
             UndirectedEdge[67, 363] -> 
             RGBColor[
              0.18174309364533237`, 0.30835389297189403`, 0.9336613723670645],
              UndirectedEdge[61, 295] -> 
             RGBColor[
              0.9875274720228682, 0.989110303399177, 0.8563655966561801], 
             UndirectedEdge[16, 116] -> 
             RGBColor[
              0.2732978193858072, 0.4045837146300204, 0.9388752785549055], 
             UndirectedEdge[294, 439] -> 
             RGBColor[
              0.19336116609564466`, 0.3205652237455112, 0.9343230044057118], 
             UndirectedEdge[69, 346] -> 
             RGBColor[
              0.4421357571807656, 0.5573775033058451, 0.9493934773756274], 
             UndirectedEdge[327, 415] -> 
             RGBColor[
              0.1820891431356189, 0.3087176129269901, 0.9336810793736019], 
             UndirectedEdge[54, 61] -> 
             RGBColor[
              0.9898922626687403, 0.9900882051035927, 0.8171748957720661], 
             UndirectedEdge[244, 262] -> 
             RGBColor[
              0.3949445171400494, 0.5165028230832673, 0.9463864932898081], 
             UndirectedEdge[295, 397] -> 
             RGBColor[
              0.9034028373173626, 0.5790815030588307, 0.5351722665672494], 
             UndirectedEdge[61, 264] -> 
             RGBColor[
              0.9279014667399095, 0.7362939743699763, 0.5103077071950994], 
             UndirectedEdge[162, 226] -> 
             RGBColor[
              0.18515287463647273`, 0.3119377889861841, 0.933855554350191], 
             UndirectedEdge[237, 351] -> 
             RGBColor[
              0.2365402762573613, 0.3659492062391825, 0.9367819908516525], 
             UndirectedEdge[243, 273] -> 
             RGBColor[
              0.1918690378137841, 0.3189969023148785, 0.9342380299074659], 
             UndirectedEdge[53, 343] -> 
             RGBColor[
              0.8394526370347362, 0.3042558332705747, 0.18541319582083088`], 
             UndirectedEdge[37, 445] -> 
             RGBColor[
              0.9124867892485535, 0.6764249054783144, 0.25883228336174086`], 
             UndirectedEdge[144, 402] -> 
             RGBColor[
              0.20750395596016302`, 0.3354301925977886, 0.9351284153661135], 
             UndirectedEdge[235, 456] -> 
             RGBColor[
              0.20636469541016642`, 0.3342327575264513, 0.9350635361631761], 
             UndirectedEdge[369, 456] -> 
             RGBColor[
              0.1888191818250698, 0.31579131029870144`, 0.9340643451207662], 
             UndirectedEdge[7, 61] -> 
             RGBColor[
              0.7313065318033417, 0.7863785903909934, 0.8813505639139341], 
             UndirectedEdge[76, 175] -> 
             RGBColor[
              0.404052773600639, 0.5243919370351493, 0.946966863337362], 
             UndirectedEdge[259, 372] -> 
             RGBColor[
              0.6487722113207766, 0.7251147800966794, 0.9659213864599616], 
             UndirectedEdge[187, 224] -> 
             RGBColor[
              0.2135902734770326, 0.34182729820283736`, 0.9354750221447994], 
             UndirectedEdge[142, 183] -> 
             RGBColor[
              0.20633874170827649`, 0.3342054785402052, 0.9350620581382485], 
             UndirectedEdge[255, 299] -> 
             RGBColor[
              0.21862190988624552`, 0.3471158670930945, 0.935761566394665], 
             UndirectedEdge[233, 444] -> 
             RGBColor[
              0.7642107527779903, 0.8150144746201845, 0.9536153862998804], 
             UndirectedEdge[148, 280] -> 
             RGBColor[
              0.2640545871077613, 0.39486849145101877`, 0.9383488901508075], 
             UndirectedEdge[7, 376] -> 
             RGBColor[
              0.421731467240934, 0.5391874600812927, 0.9482361475658946], 
             UndirectedEdge[73, 256] -> 
             RGBColor[
              0.4442279577887227, 0.5558341651072809, 0.9504539244246188], 
             UndirectedEdge[207, 403] -> 
             RGBColor[
              0.8091979496573507, 0.6623514892391787, 0.5962290723342419], 
             UndirectedEdge[233, 346] -> 
             RGBColor[
              0.7019863596204035, 0.7641747233325396, 0.948806151319425], 
             UndirectedEdge[293, 403] -> 
             RGBColor[
              0.7765788883904609, 0.8253885969195616, 0.9783657841185909], 
             UndirectedEdge[321, 391] -> 
             RGBColor[
              0.7292749424513578, 0.7856899772227003, 0.9213526032018919], 
             UndirectedEdge[228, 298] -> 
             RGBColor[
              0.2669525907215979, 0.3979144769932027, 0.9385139271694034], 
             UndirectedEdge[54, 455] -> 
             RGBColor[
              0.8012850501089904, 0.8433363962570924, 0.8929667567235482], 
             UndirectedEdge[323, 419] -> 
             RGBColor[
              0.8209982189868783, 0.8586000678793866, 0.8680770966029969], 
             UndirectedEdge[65, 194] -> 
             RGBColor[
              0.18464315044443147`, 0.3114020365419683, 0.9338265263115236], 
             UndirectedEdge[40, 273] -> 
             RGBColor[
              0.18608375256856824`, 0.31291620071388626`, 0.9339085664713134],
              UndirectedEdge[209, 400] -> 
             RGBColor[
              0.9921722318540724, 0.9910310309542629, 0.7793899060000027], 
             UndirectedEdge[31, 488] -> 
             RGBColor[
              0.1872548538957951, 0.31414710246091443`, 0.9339752589594097], 
             UndirectedEdge[399, 407] -> 
             RGBColor[
              0.2425042792072058, 0.3722177514790964, 0.9371216319966944], 
             UndirectedEdge[292, 399] -> 
             RGBColor[
              0.19649944973854266`, 0.32386375883287244`, 0.9345017250165003],
              UndirectedEdge[93, 218] -> 
             RGBColor[
              0.2542535028794738, 0.3845669305024568, 0.9377907329034113], 
             UndirectedEdge[198, 270] -> 
             RGBColor[
              0.1812627552425552, 0.3078490268553615, 0.9336340178056233], 
             UndirectedEdge[78, 192] -> 
             RGBColor[
              0.39152498613418535`, 0.5130863931305935, 0.946294212255822], 
             UndirectedEdge[286, 492] -> 
             RGBColor[
              0.18500229424892267`, 0.31177951945152094`, 0.9338469790198838],
              UndirectedEdge[317, 343] -> 
             RGBColor[
              0.8317748059838278, 0.24524065936627398`, 0.17806089613561116`],
              UndirectedEdge[51, 203] -> 
             RGBColor[
              0.9201617687823374, 0.6698476352137519, 0.4577172955235477], 
             UndirectedEdge[212, 216] -> 
             RGBColor[
              0.19093042363498117`, 0.31801035930138044`, 0.9341845772185382],
              UndirectedEdge[100, 257] -> 
             RGBColor[
              0.9781397520963673, 0.9374756322249009, 0.407566735110352], 
             UndirectedEdge[189, 302] -> 
             RGBColor[
              0.24836644407899122`, 0.3783792584420631, 0.9374554736138468], 
             UndirectedEdge[306, 382] -> 
             RGBColor[
              0.2264199096398822, 0.3553120592559075, 0.9362056509445278], 
             UndirectedEdge[20, 150] -> 
             RGBColor[
              0.22855902835216374`, 0.35756040865047517`, 0.9363274705906497],
              UndirectedEdge[255, 446] -> 
             RGBColor[
              0.19028875988053398`, 0.31733593001162463`, 0.9341480354169789],
              UndirectedEdge[182, 237] -> 
             RGBColor[
              0.2889436538091614, 0.4176768128895569, 0.9398890065800227], 
             UndirectedEdge[4, 366] -> 
             RGBColor[
              0.18203443666830332`, 0.30866011296125107`, 0.9336779639212193],
              UndirectedEdge[231, 275] -> 
             RGBColor[
              0.6264851574368956, 0.7057897543518528, 0.9650087769508688], 
             UndirectedEdge[97, 231] -> 
             RGBColor[
              0.8760573705850234, 0.8940094298858756, 0.6933676019879993], 
             UndirectedEdge[114, 128] -> 
             RGBColor[
              0.1878451960142834, 0.31476758945729777`, 0.9340088780697248], 
             UndirectedEdge[207, 471] -> 
             RGBColor[
              0.9159118385486107, 0.7462782372358219, 0.5876734401900829], 
             UndirectedEdge[54, 391] -> 
             RGBColor[0.731320111432247, 0.7865357071547434, 0.8874588604609],
              UndirectedEdge[299, 478] -> 
             RGBColor[
              0.24469356026771227`, 0.3745188246821251, 0.9372463083143392], 
             UndirectedEdge[44, 365] -> 
             RGBColor[
              0.24302709585907487`, 0.37276726492870105`, 0.9371514056315804],
              UndirectedEdge[6, 101] -> 
             RGBColor[
              0.22975280750904292`, 0.3588151462343254, 0.9363954545475959], 
             UndirectedEdge[236, 308] -> 
             RGBColor[
              0.19963189940938322`, 0.3271561620457061, 0.9346801133912106], 
             UndirectedEdge[47, 256] -> 
             RGBColor[
              0.2965835068490444, 0.4287985034009982, 0.9402108818731908], 
             UndirectedEdge[304, 427] -> 
             RGBColor[
              0.18861159117236292`, 0.315573119360699, 0.9340525231401974], 
             UndirectedEdge[54, 397] -> 
             RGBColor[
              0.9057676279632347, 0.5800594047632462, 0.4959815656831355], 
             UndirectedEdge[220, 254] -> 
             RGBColor[
              0.20473141614653206`, 0.3325160774644852, 0.9349705233253323], 
             UndirectedEdge[377, 426] -> 
             RGBColor[
              0.1840742886923742, 0.31080412677263786`, 0.9337941304762996], 
             UndirectedEdge[216, 292] -> 
             RGBColor[
              0.19251751538449438`, 0.3196784933575477, 0.9342749597457812], 
             UndirectedEdge[42, 119] -> 
             RGBColor[
              0.1924345707120309, 0.31959131324779266`, 0.9342702361693901], 
             UndirectedEdge[170, 491] -> 
             RGBColor[
              0.18468093358720655`, 0.3114417490206145, 0.9338286780056095], 
             UndirectedEdge[257, 326] -> 
             RGBColor[
              0.8442173233312698, 0.8362115823989578, 0.6421148916132133], 
             UndirectedEdge[98, 347] -> 
             RGBColor[
              0.19568928020766854`, 0.32301221928820867`, 0.9344555870602553],
              UndirectedEdge[271, 311] -> 
             RGBColor[
              0.19904018271004636`, 0.32653423027769746`, 0.9346464160005499],
              UndirectedEdge[156, 227] -> 
             RGBColor[
              0.1962768676534719, 0.3236298109489438, 0.9344890492960363], 
             UndirectedEdge[151, 160] -> 
             RGBColor[
              0.22158100780321188`, 0.3502260666214703, 0.9359300826434431], 
             UndirectedEdge[93, 167] -> 
             RGBColor[
              0.23124675852992788`, 0.3603853834792411, 0.9364805328481329], 
             UndirectedEdge[275, 348] -> 
             RGBColor[
              0.475696405739353, 0.5852307979148967, 0.9518677100746031], 
             UndirectedEdge[34, 394] -> 
             RGBColor[
              0.19619166312976455`, 0.3235402555922485, 0.9344841970244598], 
             UndirectedEdge[405, 488] -> 
             RGBColor[
              0.182093967520493, 0.30872268366137645`, 0.9336813541151835], 
             UndirectedEdge[338, 443] -> 
             RGBColor[
              0.3560845115696105, 0.4809110296827722, 0.9439811523759123], 
             UndirectedEdge[301, 316] -> 
             RGBColor[
              0.547580608865669, 0.6429772459967242, 0.9577838308857021], 
             UndirectedEdge[103, 209] -> 
             RGBColor[
              0.7021401008892698, 0.7606785926382128, 0.8442710393667008], 
             UndirectedEdge[126, 414] -> 
             RGBColor[
              0.45556143140572114`, 0.5680520611940277, 0.9505125663614704], 
             UndirectedEdge[154, 341] -> 
             RGBColor[
              0.9888822096717337, 0.9887006265396945, 0.7667739089616505], 
             UndirectedEdge[306, 347] -> 
             RGBColor[
              0.22192337354853872`, 0.3505859147270508, 0.9359495798661548], 
             UndirectedEdge[20, 388] -> 
             RGBColor[
              0.2852227543233797, 0.4152738080593815, 0.9396218953833091], 
             UndirectedEdge[286, 319] -> 
             RGBColor[
              0.18412936406719407`, 0.310862014483554, 0.9337972669374188], 
             UndirectedEdge[62, 96] -> 
             RGBColor[
              0.36098375539591054`, 0.48129258556863375`, 0.9445483392518976],
              UndirectedEdge[149, 242] -> 
             RGBColor[
              0.767121254823353, 0.8170287735130601, 0.9444951769225841], 
             UndirectedEdge[212, 319] -> 
             RGBColor[
              0.18140430286516612`, 0.3079978023813632, 0.93364207873333], 
             UndirectedEdge[289, 470] -> 
             RGBColor[
              0.20234342031166005`, 0.33000614243435394`, 0.9348345304952597],
              UndirectedEdge[291, 353] -> 
             RGBColor[
              0.18189358061228061`, 0.3085120643155814, 0.9336699423772067], 
             UndirectedEdge[21, 91] -> 
             RGBColor[
              0.3801635060105999, 0.5027016523216035, 0.9455268210185781], 
             UndirectedEdge[95, 224] -> 
             RGBColor[
              0.19530748745975585`, 0.322610930903094, 0.9344338445280735], 
             UndirectedEdge[218, 235] -> 
             RGBColor[
              0.2514972659875934, 0.38166995077357824`, 0.9376337692899057], 
             UndirectedEdge[108, 315] -> 
             RGBColor[
              0.19651178198130725`, 0.3238767208019274, 0.9345024273194817], 
             UndirectedEdge[61, 154] -> 
             RGBColor[
              0.9868630618485601, 0.9887151187410052, 0.8619833131527019], 
             UndirectedEdge[297, 413] -> 
             RGBColor[
              0.2127862490397303, 0.34098221754113894`, 0.9354292341425425], 
             UndirectedEdge[294, 438] -> 
             RGBColor[
              0.19506692603526019`, 0.32235808559347384`, 0.9344201449108273],
              UndirectedEdge[277, 386] -> 
             RGBColor[
              0.3744145130463712, 0.49843012291785427`, 0.9450889814281427], 
             UndirectedEdge[125, 249] -> 
             RGBColor[
              0.7524497512082946, 0.8065387315646185, 0.9759608172238798], 
             UndirectedEdge[211, 308] -> 
             RGBColor[
              0.18919374524082816`, 0.3161850001973557, 0.9340856759531767], 
             UndirectedEdge[273, 477] -> 
             RGBColor[
              0.19247626140559868`, 0.319635132810075, 0.9342726103927129], 
             UndirectedEdge[154, 397] -> 
             RGBColor[
              0.9027384271430544, 0.5786863184006587, 0.5407899830637712], 
             UndirectedEdge[105, 230] -> 
             RGBColor[
              0.19866180408544326`, 0.32613653035264917`, 0.9346248678976397],
              UndirectedEdge[355, 404] -> 
             RGBColor[
              0.6982683944179626, 0.7630818994281268, 0.9713900254136139], 
             UndirectedEdge[250, 263] -> 
             RGBColor[
              0.22198989446995654`, 0.350655832433131, 0.9359533681342207], 
             UndirectedEdge[11, 259] -> 
             RGBColor[
              0.5294234413742529, 0.6261111308515327, 0.9571090734444168], 
             UndirectedEdge[339, 439] -> 
             RGBColor[
              0.18970826562688875`, 0.316725793745582, 0.9341149771279982], 
             UndirectedEdge[303, 379] -> 
             RGBColor[
              0.8341112743268393, 0.26319977889761653`, 0.18029830085954252`],
              UndirectedEdge[416, 468] -> 
             RGBColor[
              0.21536523562869736`, 0.3436928959633374, 0.9355761036135155], 
             UndirectedEdge[77, 336] -> 
             RGBColor[
              0.47990926789082156`, 0.58542393137187, 0.9530910077074245], 
             UndirectedEdge[297, 412] -> 
             RGBColor[
              0.1927590864051722, 0.31993239981676747`, 0.9342887168580365], 
             UndirectedEdge[69, 418] -> 
             RGBColor[
              0.45968074399907377`, 0.5719444997429457, 0.9506853858229966], 
             UndirectedEdge[281, 322] -> 
             RGBColor[
              0.8196030856546299, 0.15168348323420097`, 0.16640524300237935`],
              UndirectedEdge[51, 495] -> 
             RGBColor[
              0.9406722816777016, 0.7839532053527796, 0.47565298592181493`], 
             UndirectedEdge[227, 229] -> 
             RGBColor[
              0.21399982241481183`, 0.34225776010334574`, 0.9354983453509325],
              UndirectedEdge[192, 497] -> 
             RGBColor[
              0.3955857304505306, 0.5163830883010493, 0.9466138889234013], 
             UndirectedEdge[143, 277] -> 
             RGBColor[
              0.5119391923573035, 0.6143803189362278, 0.9547965836382715], 
             UndirectedEdge[87, 161] -> 
             RGBColor[
              0.2611314320863651, 0.3917960701847984, 0.9381824207967593], 
             UndirectedEdge[114, 255] -> 
             RGBColor[
              0.1893023656117655, 0.31629916709414013`, 0.9340918617226122], 
             UndirectedEdge[341, 391] -> 
             RGBColor[
              0.7337060308144916, 0.7866728844187078, 0.7861711023616725], 
             UndirectedEdge[35, 347] -> 
             RGBColor[
              0.19536292222488982`, 0.32266919635601693`, 0.9344370014559396],
              UndirectedEdge[99, 498] -> 
             RGBColor[
              0.8771421221278247, 0.9041056565781206, 0.9487087442796804], 
             UndirectedEdge[89, 448] -> 
             RGBColor[
              0.30513277253024496`, 0.43795777610955633`, 0.9406913989633512],
              UndirectedEdge[130, 371] -> 
             RGBColor[
              0.27850064570472033`, 0.41005221496943967`, 0.9391715718168758],
              UndirectedEdge[187, 481] -> 
             RGBColor[
              0.21325750963013368`, 0.3414775423013001, 0.9354560717359984], 
             UndirectedEdge[427, 500] -> 
             RGBColor[
              0.19375142518042626`, 0.32097541078747177`, 0.9343452290832536],
              UndirectedEdge[134, 247] -> 
             RGBColor[
              0.1842053003124589, 0.3109418282919634, 0.933801591394249], 
             UndirectedEdge[79, 301] -> 
             RGBColor[
              0.7713475583434661, 0.821837420942344, 0.9777022478790838], 
             UndirectedEdge[173, 323] -> 
             RGBColor[
              0.8566536605338118, 0.8864543698072436, 0.8716308977973497], 
             UndirectedEdge[84, 262] -> 
             RGBColor[
              0.3093414127711809, 0.4392853260774658, 0.9410444344433726], 
             UndirectedEdge[262, 391] -> 
             RGBColor[
              0.4081410490049733, 0.5273954680265918, 0.9473758851308575], 
             UndirectedEdge[205, 382] -> 
             RGBColor[
              0.22477554462649751`, 0.3535837273680766, 0.9361120067896356], 
             UndirectedEdge[50, 499] -> 
             RGBColor[
              0.7544680909250315, 0.8083923113644382, 0.9761768691183477], 
             UndirectedEdge[108, 380] -> 
             RGBColor[
              0.19854131235532485`, 0.3260098859046778, 0.934618006071861], 
             UndirectedEdge[300, 493] -> 
             RGBColor[
              0.24638397938180046`, 0.376295562349794, 0.9373425751821356], 
             UndirectedEdge[331, 382] -> 
             RGBColor[
              0.25675225340899854`, 0.38719327573892137`, 0.9379330330494976],
              UndirectedEdge[186, 495] -> 
             RGBColor[
              0.9397076490875935, 0.7818899537818541, 0.3706586815108439], 
             UndirectedEdge[93, 235] -> 
             RGBColor[
              0.21987414226832205`, 0.3484320427227756, 0.9358328791763124], 
             UndirectedEdge[18, 300] -> 
             RGBColor[
              0.26008832470075693`, 0.39069969818569605`, 0.938123017374288], 
             UndirectedEdge[223, 246] -> 
             RGBColor[
              0.22404185527291065`, 0.35281257333886495`, 0.9360702242663449],
              UndirectedEdge[233, 431] -> 
             RGBColor[
              0.6919046963354076, 0.7554424933142063, 0.9481637566497699], 
             UndirectedEdge[182, 351] -> 
             RGBColor[
              0.2925937639781592, 0.42151331010752513`, 0.9400968749542931], 
             UndirectedEdge[163, 209] -> 
             RGBColor[
              0.9468923206889115, 0.8138245711399055, 0.48945082932663964`], 
             UndirectedEdge[70, 182] -> 
             RGBColor[
              0.35737014201408246`, 0.4839577878921605, 0.9439922873324968], 
             UndirectedEdge[59, 335] -> 
             RGBColor[
              0.2366854990874992, 0.3661018446413167, 0.9367902610769909], 
             UndirectedEdge[258, 453] -> 
             RGBColor[
              0.3275555861569279, 0.45177144641276795`, 0.942325491454229], 
             UndirectedEdge[161, 354] -> 
             RGBColor[
              0.262219161885439, 0.39276906224398844`, 0.9382506002184958], 
             UndirectedEdge[213, 489] -> 
             RGBColor[
              0.19691928671610104`, 0.3243050341154881, 0.9345256341112791], 
             UndirectedEdge[260, 407] -> 
             RGBColor[
              0.24344019620099944`, 0.3732014595801383, 0.9371749310849259], 
             UndirectedEdge[95, 185] -> 
             RGBColor[
              0.19811081032671668`, 0.3255574009772055, 0.9345934896182024], 
             UndirectedEdge[117, 479] -> 
             RGBColor[
              0.1829410540251313, 0.30961302528613777`, 0.9337295944384705], 
             UndirectedEdge[164, 444] -> 
             RGBColor[
              0.4409447203988165, 0.5532899965320492, 0.9501619372363984], 
             UndirectedEdge[32, 334] -> 
             RGBColor[
              0.2032637935146371, 0.3309735130257143, 0.934886944387599], 
             UndirectedEdge[46, 325] -> 
             RGBColor[
              0.2186729430619583, 0.3471695061964588, 0.935764472658525], 
             UndirectedEdge[18, 201] -> 
             RGBColor[
              0.27288253451918126`, 0.4041472239046152, 0.93885162869611], 
             UndirectedEdge[328, 398] -> 
             RGBColor[
              0.2246228179747201, 0.35342320197362953`, 0.9361033092327558], 
             UndirectedEdge[376, 448] -> 
             RGBColor[
              0.33584647853732147`, 0.4645604445371366, 0.9426484491510583], 
             UndirectedEdge[326, 355] -> 
             RGBColor[
              0.642545935987291, 0.7194149561297569, 0.9658722576270347], 
             UndirectedEdge[257, 281] -> 
             RGBColor[
              0.8907382712640035, 0.5148249421887663, 0.2381214507014296], 
             UndirectedEdge[32, 89] -> 
             RGBColor[
              0.26467695340514513`, 0.3954361451619938, 0.9383874999131978], 
             UndirectedEdge[341, 397] -> 
             RGBColor[
              0.9081535473454794, 0.5801965820272107, 0.39469380758390815`], 
             UndirectedEdge[160, 274] -> 
             RGBColor[
              0.24176660566523328`, 0.3714424098152794, 0.9370796225797693], 
             UndirectedEdge[151, 235] -> 
             RGBColor[
              0.21041554321705824`, 0.3384904554100799, 0.9352942259530863], 
             UndirectedEdge[11, 372] -> 
             RGBColor[
              0.49492242636970674`, 0.598728406383233, 0.9539645121894538], 
             UndirectedEdge[99, 295] -> 
             RGBColor[
              0.9822469150718874, 0.9861800274834427, 0.9104424780465525], 
             UndirectedEdge[154, 199] -> 
             RGBColor[
              0.684800695862128, 0.748031110338605, 0.9293475993147051], 
             UndirectedEdge[169, 308] -> 
             RGBColor[
              0.18735840295715342`, 0.31425593908979166`, 0.9339811559252671],
              UndirectedEdge[158, 410] -> 
             RGBColor[
              0.18697773490946556`, 0.31385583283592355`, 0.933959477443099], 
             UndirectedEdge[311, 465] -> 
             RGBColor[
              0.1845169561942322, 0.31126939838383133`, 0.9338193397356624], 
             UndirectedEdge[139, 428] -> 
             RGBColor[
              0.1851867200986532, 0.311973362712862, 0.9338574817991923], 
             UndirectedEdge[113, 364] -> 
             RGBColor[
              0.20055433939420772`, 0.3281257049558297, 0.9347326449837188], 
             UndirectedEdge[89, 475] -> 
             RGBColor[
              0.32310504521526556`, 0.4542790832588659, 0.9418089456639116], 
             UndirectedEdge[375, 441] -> 
             RGBColor[
              0.2121051529687783, 0.3402663423865834, 0.9353904467288932], 
             UndirectedEdge[244, 295] -> 
             RGBColor[
              0.7157587889214511, 0.7746651605070033, 0.9256601695039643], 
             UndirectedEdge[187, 260] -> 
             RGBColor[
              0.21549852964428565`, 0.3438329964250494, 0.9355836945105124], 
             UndirectedEdge[207, 322] -> 
             RGBColor[
              0.8478846282356312, 0.34298703129758157`, 0.19246642213058046`],
              UndirectedEdge[100, 457] -> 
             RGBColor[
              0.7312390426759171, 0.7839598047362808, 0.7277634832098476], 
             UndirectedEdge[364, 416] -> 
             RGBColor[
              0.20681043357905127`, 0.33470125660338146`, 0.9350889202924836],
              UndirectedEdge[313, 386] -> 
             RGBColor[
              0.33341144011418006`, 0.4629153220183585, 0.9424763018784972], 
             UndirectedEdge[31, 472] -> 
             RGBColor[
              0.1875584213311225, 0.31446617108273056`, 0.9339925466757639], 
             UndirectedEdge[37, 49] -> 
             RGBColor[
              0.9278898442559633, 0.7275054583426774, 0.39329233295696453`], 
             UndirectedEdge[201, 406] -> 
             RGBColor[
              0.33697692661979073`, 0.46155170113037025`, 0.9428664961514535],
              UndirectedEdge[245, 376] -> 
             RGBColor[
              0.30751706029421144`, 0.43478442977476833`, 0.9410351306917317],
              UndirectedEdge[58, 215] -> 
             RGBColor[
              0.1890650982052305, 0.3160497840062494, 0.9340783496948156], 
             UndirectedEdge[84, 407] -> 
             RGBColor[
              0.27632252286434345`, 0.40776286976323906`, 0.9390475309433604],
              UndirectedEdge[100, 324] -> 
             RGBColor[
              0.9664798274342277, 0.9712473493741347, 0.7455337650413938], 
             UndirectedEdge[89, 176] -> 
             RGBColor[
              0.31330748759898347`, 0.4457929312912065, 0.9411846539562421], 
             UndirectedEdge[75, 379] -> 
             RGBColor[
              0.8463714309227728, 0.346563167860244, 0.1916128598280513], 
             UndirectedEdge[123, 422] -> 
             RGBColor[
              0.1961933017960193, 0.3235419779343797, 0.9344842903440789], 
             UndirectedEdge[407, 455] -> 
             RGBColor[
              0.44508709777487926`, 0.5526737008147141, 0.9508868778934936], 
             UndirectedEdge[333, 358] -> 
             RGBColor[
              0.22833564415577742`, 0.35732561769669713`, 0.9363147491911328],
              UndirectedEdge[120, 124] -> 
             RGBColor[
              0.18263624540769638`, 0.3092926521032311, 0.9337122360386315], 
             UndirectedEdge[88, 433] -> 
             RGBColor[
              0.18511620603054046`, 0.3118992479564254, 0.9338534661273294], 
             UndirectedEdge[345, 456] -> 
             RGBColor[
              0.1932262687729535, 0.32042343810637863`, 0.9343153222027473], 
             UndirectedEdge[392, 474] -> 
             RGBColor[
              0.23318205607902553`, 0.3624195039082944, 0.9365907451805379], 
             UndirectedEdge[165, 333] -> 
             RGBColor[
              0.26885740704369754`, 0.3999165597200598, 0.9386224036410238], 
             UndirectedEdge[31, 133] -> 
             RGBColor[
              0.1949807850604232, 0.3222675459672669, 0.9344152393097445], 
             UndirectedEdge[171, 208] -> 
             RGBColor[
              0.44865476640412644`, 0.5625521197174839, 0.9499392286265838], 
             UndirectedEdge[284, 472] -> 
             RGBColor[
              0.19498301286010505`, 0.32226988752598323`, 0.9344153661796406],
              UndirectedEdge[196, 427] -> 
             RGBColor[
              0.18925515066577042`, 0.3162495411922988, 0.9340891729012859], 
             UndirectedEdge[179, 334] -> 
             RGBColor[
              0.1934836161981846, 0.32069392656706563`, 0.9343299777579028], 
             UndirectedEdge[97, 233] -> 
             RGBColor[
              0.9755070986726647, 0.9721600768096842, 0.6789609948576975], 
             UndirectedEdge[21, 409] -> 
             RGBColor[
              0.27661821411791565`, 0.40807366001865175`, 0.9390643701228152],
              UndirectedEdge[63, 344] -> 
             RGBColor[
              0.19854348560024537`, 0.326012170122881, 0.9346181298349442], 
             UndirectedEdge[292, 398] -> 
             RGBColor[
              0.19568953649861287`, 0.32301248866624094`, 0.9344556016556456],
              UndirectedEdge[71, 197] -> 
             RGBColor[
              0.2143161876130597, 0.34259027998541636`, 0.9355163618809523], 
             UndirectedEdge[81, 121] -> 
             RGBColor[
              0.22174468237743916`, 0.35039809897655055`, 0.9359394036683106],
              UndirectedEdge[163, 317] -> 
             RGBColor[
              0.8583137676007231, 0.3848962000432028, 0.20095545620474106`], 
             UndirectedEdge[167, 172] -> 
             RGBColor[
              0.23167761735264775`, 0.36083824341994686`, 0.9365050696206882],
              UndirectedEdge[191, 488] -> 
             RGBColor[
              0.18656266374586195`, 0.3134195667259444, 0.9339358397543747], 
             UndirectedEdge[392, 490] -> 
             RGBColor[
              0.2264092533563037, 0.355300858826219, 0.9362050440849425], 
             UndirectedEdge[251, 272] -> 
             RGBColor[
              0.24807843064742718`, 0.378076538064383, 0.937439071674997], 
             UndirectedEdge[66, 255] -> 
             RGBColor[
              0.19752636336653073`, 0.32494311016597255`, 0.9345602062284316],
              UndirectedEdge[177, 194] -> 
             RGBColor[
              0.1852447118397448, 0.312034315709638, 0.9338607843430564], 
             UndirectedEdge[36, 359] -> 
             RGBColor[
              0.9518288028476951, 0.9612683407754878, 0.8690761481825573], 
             UndirectedEdge[46, 377] -> 
             RGBColor[
              0.192250993648715, 0.31939836211478956`, 0.9342597817272121], 
             UndirectedEdge[6, 306] -> 
             RGBColor[
              0.22758223790331983`, 0.3565337399566487, 0.93627184381962], 
             UndirectedEdge[7, 455] -> 
             RGBColor[
              0.5426993192435918, 0.6396267815444932, 0.9571424248654161], 
             UndirectedEdge[84, 482] -> 
             RGBColor[
              0.30394372684162835`, 0.43461012182087044`, 0.9407004986689278],
              UndirectedEdge[83, 97] -> 
             RGBColor[
              0.9918418301129188, 0.9825092007837744, 0.5692119944347548], 
             UndirectedEdge[125, 408] -> 
             RGBColor[
              0.8576169370417068, 0.8896033538181681, 0.9847741152357485], 
             UndirectedEdge[184, 473] -> 
             RGBColor[
              0.4022146970771591, 0.5162489604655307, 0.9476591763750619], 
             UndirectedEdge[410, 422] -> 
             RGBColor[
              0.19439415698617535`, 0.3216509626668643, 0.9343818317087544], 
             UndirectedEdge[202, 283] -> 
             RGBColor[
              0.1845388139830274, 0.3112923723057189, 0.9338205845043986], 
             UndirectedEdge[320, 329] -> 
             RGBColor[
              0.18135868640525998`, 0.3079498565897512, 0.9336394809434219], 
             UndirectedEdge[146, 387] -> 
             RGBColor[
              0.18448194243535776`, 0.3112325967032537, 0.9338173457538927], 
             UndirectedEdge[107, 170] -> 
             RGBColor[
              0.19951076544330998`, 0.3270288425670261, 0.9346732149910444], 
             UndirectedEdge[273, 459] -> 
             RGBColor[
              0.19081936422215473`, 0.3178936288169264, 0.9341782525492754], 
             UndirectedEdge[5, 395] -> 
             RGBColor[
              0.5968586468606165, 0.6828724552519535, 0.9619005753639707], 
             UndirectedEdge[104, 242] -> 
             RGBColor[
              0.9486223107500168, 0.8581914089875718, 0.5941049181072977], 
             UndirectedEdge[422, 437] -> 
             RGBColor[
              0.1942298621222053, 0.32147827834793574`, 0.9343724753593039], 
             UndirectedEdge[29, 177] -> 
             RGBColor[
              0.18440587372207073`, 0.31115264366255413`, 0.9338130137532046],
              UndirectedEdge[202, 285] -> 
             RGBColor[
              0.2005739783770007, 0.32814634677192855`, 0.9347337633947355], 
             UndirectedEdge[182, 460] -> 
             RGBColor[
              0.32283537188163536`, 0.453299157442765, 0.9418190897859463], 
             UndirectedEdge[116, 333] -> 
             RGBColor[
              0.2541335864563355, 0.3844408907385981, 0.937783903840514], 
             UndirectedEdge[405, 472] -> 
             RGBColor[
              0.1823975349558204, 0.3090417522831926, 0.9336986418315376], 
             UndirectedEdge[51, 96] -> 
             RGBColor[
              0.7330134148240908, 0.7867443631188805, 0.8380607137143137], 
             UndirectedEdge[115, 402] -> 
             RGBColor[
              0.20455792141877943`, 0.3323337235054161, 0.9349606430572492], 
             UndirectedEdge[67, 120] -> 
             RGBColor[
              0.18038821966444069`, 0.3069298345140049, 0.9335842142982091], 
             UndirectedEdge[72, 222] -> 
             RGBColor[
              0.20410917934136036`, 0.33186206713015765`, 0.9349350878597946],
              UndirectedEdge[84, 328] -> 
             RGBColor[
              0.2592509748717875, 0.3898195904244037, 0.9380753315402763], 
             UndirectedEdge[123, 401] -> 
             RGBColor[
              0.18328689846403934`, 0.309976529719234, 0.9337492897676354], 
             UndirectedEdge[143, 178] -> 
             RGBColor[
              0.5249805981564001, 0.6252419255466224, 0.9557475422356184], 
             UndirectedEdge[2, 385] -> 
             RGBColor[
              0.1828749868990639, 0.3095435845477431, 0.9337258320133786], 
             UndirectedEdge[113, 487] -> 
             RGBColor[
              0.19472843618281724`, 0.32200231129706014`, 0.9344008684144816],
              UndirectedEdge[12, 430] -> 
             RGBColor[
              0.19779577870573095`, 0.32522628276939103`, 0.9345755490334348],
              UndirectedEdge[72, 344] -> 
             RGBColor[
              0.20069596090134978`, 0.3282745581391582, 0.9347407101190403], 
             UndirectedEdge[127, 221] -> 
             RGBColor[
              0.8972130382069989, 0.8767030519388234, 0.6458996213784399], 
             UndirectedEdge[466, 491] -> 
             RGBColor[
              0.1882565372451065, 0.3151999351714332, 0.9340323033442953], 
             UndirectedEdge[236, 289] -> 
             RGBColor[
              0.20921618528861102`, 0.33722985418359713`, 0.9352259242933523],
              UndirectedEdge[200, 298] -> 
             RGBColor[
              0.26933197029652145`, 0.4004153557878257, 0.9386494293162186], 
             UndirectedEdge[231, 431] -> 
             RGBColor[
              0.5924549682477664, 0.6772918463903979, 0.9625703637800718], 
             UndirectedEdge[171, 238] -> 
             RGBColor[
              0.47869194757503297`, 0.5876627137247235, 0.9521035301009391], 
             UndirectedEdge[276, 306] -> 
             RGBColor[
              0.22718429673725105`, 0.3561154785601833, 0.9362491816589136], 
             UndirectedEdge[294, 296] -> 
             RGBColor[
              0.18486063733978264`, 0.311630629058448, 0.9338389118684709], 
             UndirectedEdge[1, 119] -> 
             RGBColor[
              0.1917982653600388, 0.3189225159787594, 0.9342339995209235], 
             UndirectedEdge[103, 444] -> 
             RGBColor[
              0.4878340995369397, 0.5939032200127712, 0.9531496870124296], 
             UndirectedEdge[331, 486] -> 
             RGBColor[
              0.35738466575242234`, 0.48329439102726157`, 0.9440179635868327],
              UndirectedEdge[100, 281] -> 
             RGBColor[
              0.9058254062967486, 0.5652706313368212, 0.33472136228145205`], 
             UndirectedEdge[161, 477] -> 
             RGBColor[
              0.2058221778675803, 0.33366253719159444`, 0.9350326405917087], 
             UndirectedEdge[391, 475] -> 
             RGBColor[
              0.40482166454825647`, 0.5245203840472975, 0.9471643768884919], 
             UndirectedEdge[2, 312] -> 
             RGBColor[
              0.18958168594798847`, 0.3165927504774426, 0.9341077686025426], 
             UndirectedEdge[264, 341] -> 
             RGBColor[
              0.9299206145630832, 0.7362794821686658, 0.415098303004048], 
             UndirectedEdge[73, 434] -> 
             RGBColor[
              0.755989141506491, 0.7238557905975457, 0.6132283330346036], 
             UndirectedEdge[241, 271] -> 
             RGBColor[
              0.2118628562397169, 0.3400116731618399, 0.935376648288619], 
             UndirectedEdge[49, 51] -> 
             RGBColor[
              0.9945887098983145, 0.9908341225748765, 0.6523926509220856], 
             UndirectedEdge[5, 275] -> 
             RGBColor[
              0.5894443177306294, 0.6768531688525092, 0.9613168922152756], 
             UndirectedEdge[18, 274] -> 
             RGBColor[
              0.2661988733080245, 0.397122272203093, 0.9384710040777253], 
             UndirectedEdge[219, 445] -> 
             RGBColor[
              0.8163225920234214, 0.8145058037505225, 0.6394598956191903], 
             UndirectedEdge[177, 297] -> 
             RGBColor[
              0.18982245259063335`, 0.3168458114843493, 0.9341214799066588], 
             UndirectedEdge[250, 365] -> 
             RGBColor[
              0.21334264494811753`, 0.3415670249183921, 0.9354609200664112], 
             UndirectedEdge[325, 474] -> 
             RGBColor[
              0.2315745275844326, 0.3607298895372839, 0.936499198810896], 
             UndirectedEdge[266, 403] -> 
             RGBColor[
              0.868496130673329, 0.8940798744623377, 0.7590138025565417], 
             UndirectedEdge[214, 470] -> 
             RGBColor[
              0.19107951696482092`, 0.31816706584410515`, 0.9341930678631087],
              UndirectedEdge[152, 481] -> 
             RGBColor[
              0.1947520962377352, 0.322027179514913, 0.9344022158196071], 
             UndirectedEdge[289, 466] -> 
             RGBColor[
              0.20247960652430902`, 0.3301492827785526, 0.9348422860986005], 
             UndirectedEdge[126, 269] -> 
             RGBColor[
              0.5451650588175359, 0.6416285800109227, 0.9573365369169786], 
             UndirectedEdge[183, 396] -> 
             RGBColor[
              0.19720162500749072`, 0.32460178956102026`, 0.9345417128592917],
              UndirectedEdge[54, 99] -> 
             RGBColor[
              0.9846117057177595, 0.9871579291878583, 0.8712517771624386], 
             UndirectedEdge[129, 306] -> 
             RGBColor[
              0.2650729238792713, 0.39593882796415625`, 0.9384068829234508], 
             UndirectedEdge[172, 236] -> 
             RGBColor[
              0.21592574989835334`, 0.34428203199940316`, 0.9356080240719657],
              UndirectedEdge[162, 284] -> 
             RGBColor[
              0.19507811925714236`, 0.3223698503793633, 0.9344207823482545], 
             UndirectedEdge[10, 189] -> 
             RGBColor[
              0.23937944149495205`, 0.3689333489173635, 0.9369436771117647], 
             UndirectedEdge[213, 332] -> 
             RGBColor[
              0.19442260484216423`, 0.3216808631672068, 0.9343834517720682], 
             UndirectedEdge[199, 245] -> 
             RGBColor[
              0.31502975887018714`, 0.4412915516820689, 0.9415138332017744], 
             UndirectedEdge[123, 139] -> 
             RGBColor[
              0.1842229343035432, 0.31096036273465255`, 0.9338025956239542], 
             UndirectedEdge[391, 482] -> 
             RGBColor[
              0.4027433630754207, 0.5227202637699965, 0.9470319493564127], 
             UndirectedEdge[184, 354] -> 
             RGBColor[
              0.425711621643709, 0.5407754370503493, 0.9490035262873733], 
             UndirectedEdge[25, 316] -> 
             RGBColor[
              0.36380395841468005`, 0.4876950626233916, 0.9444694464449066], 
             UndirectedEdge[106, 479] -> 
             RGBColor[
              0.18098277247116215`, 0.30755474721069437`, 0.9336180732009899],
              UndirectedEdge[118, 260] -> 
             RGBColor[
              0.20098092756456265`, 0.3285740761701249, 0.9347569385489398], 
             UndirectedEdge[304, 469] -> 
             RGBColor[
              0.18603078567582654`, 0.3128605291513198, 0.9339055500851292], 
             UndirectedEdge[93, 236] -> 
             RGBColor[
              0.21549489107563347`, 0.3438291720586974, 0.9355834872994104], 
             UndirectedEdge[343, 445] -> 
             RGBColor[
              0.9046747150389304, 0.6218037867421315, 0.25156389718325395`], 
             UndirectedEdge[204, 444] -> 
             RGBColor[
              0.44088363514258455`, 0.5532370875533353, 0.9501580449378868], 
             UndirectedEdge[150, 412] -> 
             RGBColor[
              0.20280807626052344`, 0.33049452529749807`, 0.9348609919641505],
              UndirectedEdge[14, 239] -> 
             RGBColor[
              0.21381228139776098`, 0.3420606426036381, 0.9354876651674535], 
             UndirectedEdge[70, 442] -> 
             RGBColor[
              0.3038237186466454, 0.4310287676162611, 0.9408201768359108], 
             UndirectedEdge[93, 493] -> 
             RGBColor[
              0.24176752917831046`, 0.3714433804860776, 0.9370796751724728], 
             UndirectedEdge[228, 279] -> 
             RGBColor[
              0.23309972747079383`, 0.36233297132110764`, 0.9365860566880932],
              UndirectedEdge[300, 456] -> 
             RGBColor[
              0.21373738250553675`, 0.34198191911904635`, 0.9354833997863443],
              UndirectedEdge[168, 326] -> 
             RGBColor[
              0.509047258388588, 0.6051914915809957, 0.9566219374301776], 
             UndirectedEdge[193, 437] -> 
             RGBColor[
              0.18142173090578886`, 0.3080161203570593, 0.933643071234461], 
             UndirectedEdge[224, 361] -> 
             RGBColor[
              0.21801752264150492`, 0.34648061777850747`, 0.9357271474351878],
              UndirectedEdge[12, 477] -> 
             RGBColor[
              0.19591456128829632`, 0.32324900398759393`, 0.9344684164845236],
              UndirectedEdge[212, 224] -> 
             RGBColor[
              0.19394001881557005`, 0.321173634655535, 0.9343559692117758], 
             UndirectedEdge[220, 490] -> 
             RGBColor[
              0.2165006286676464, 0.34488626603534933`, 0.9356407625674201], 
             UndirectedEdge[175, 208] -> 
             RGBColor[
              0.41214605726916764`, 0.531401932568564, 0.9474825602161108], 
             UndirectedEdge[242, 419] -> 
             RGBColor[
              0.8111996093173061, 0.8527074496896203, 0.9480377397097984], 
             UndirectedEdge[164, 205] -> 
             RGBColor[
              0.2767533263359414, 0.40754264705410376`, 0.9390967072865741], 
             UndirectedEdge[257, 322] -> 
             RGBColor[
              0.8919174314542486, 0.5238884841222806, 0.23925061583127932`], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.7309397602442707, 0.7862269209257184, 0.8874289178221101], 
             UndirectedEdge[26, 67] -> 
             RGBColor[
              0.1828839766938226, 0.30955303339202045`, 0.9337263439688908], 
             UndirectedEdge[366, 488] -> 
             RGBColor[
              0.1825427715517224, 0.30919440515401764`, 0.933706912840816], 
             UndirectedEdge[12, 243] -> 
             RGBColor[
              0.19530733769648173`, 0.3226107734923974, 0.9344338359992765], 
             UndirectedEdge[271, 307] -> 
             RGBColor[
              0.199934386249049, 0.3274740948929682, 0.9346973395692404], 
             UndirectedEdge[9, 352] -> 
             RGBColor[
              0.18859199395283752`, 0.3155525214404422, 0.9340514071075369], 
             UndirectedEdge[404, 431] -> 
             RGBColor[
              0.629039468523406, 0.7060080713241875, 0.9661806387521447], 
             UndirectedEdge[256, 287] -> 
             RGBColor[
              0.30785568445183253`, 0.44064627675886753`, 0.9408528157119771],
              UndirectedEdge[254, 412] -> 
             RGBColor[
              0.19134257547531666`, 0.31844355701750904`, 0.9342080486561213],
              UndirectedEdge[42, 380] -> 
             RGBColor[
              0.19400957405079025`, 0.3212467416178081, 0.9343599302795238], 
             UndirectedEdge[379, 404] -> 
             RGBColor[
              0.8321257348299118, 0.5422647939490768, 0.5790967778488565], 
             UndirectedEdge[134, 424] -> 
             RGBColor[
              0.18880157011833354`, 0.31577279927827495`, 0.9340633421601217],
              UndirectedEdge[38, 253] -> 
             RGBColor[
              0.4481561698945121, 0.5608135534661793, 0.9502685055394262], 
             UndirectedEdge[103, 348] -> 
             RGBColor[
              0.4359422690580296, 0.5517750943296691, 0.9490645720310915], 
             UndirectedEdge[42, 452] -> 
             RGBColor[
              0.21367924169687297`, 0.3419208094428005, 0.9354800887533026], 
             UndirectedEdge[164, 331] -> 
             RGBColor[
              0.3087300351184425, 0.44115219542494855`, 0.940917733546436], 
             UndirectedEdge[6, 181] -> 
             RGBColor[
              0.2199559451719783, 0.348518022761122, 0.9358375377306591], 
             UndirectedEdge[172, 197] -> 
             RGBColor[
              0.22719289983545946`, 0.3561245209618682, 0.9362496715926294], 
             UndirectedEdge[80, 258] -> 
             RGBColor[
              0.38129839578489, 0.5046832386394303, 0.9455169745038486], 
             UndirectedEdge[223, 268] -> 
             RGBColor[
              0.19724310055792588`, 0.32464538299422946`, 0.9345440748305314],
              UndirectedEdge[5, 69] -> 
             RGBColor[
              0.5662162318507189, 0.6577114998480007, 0.959566779515417], 
             UndirectedEdge[306, 486] -> 
             RGBColor[
              0.327052321983306, 0.4514131745442476, 0.942290581481863], 
             UndirectedEdge[5, 348] -> 
             RGBColor[
              0.575828354505173, 0.6657991165139304, 0.9602449937132509], 
             UndirectedEdge[279, 409] -> 
             RGBColor[
              0.23060819410886862`, 0.3597142117853851, 0.9364441675490249], 
             UndirectedEdge[463, 483] -> 
             RGBColor[
              0.5035999579863275, 0.6078494794543214, 0.954073961892099], 
             UndirectedEdge[351, 371] -> 
             RGBColor[
              0.2471362919389416, 0.37708629054672044`, 0.937385418269318], 
             UndirectedEdge[335, 421] -> 
             RGBColor[
              0.19735590244149465`, 0.3247639449259127, 0.9345504987309252], 
             UndirectedEdge[259, 418] -> 
             RGBColor[
              0.5798892585592409, 0.6691924959032061, 0.9604986680920036], 
             UndirectedEdge[168, 302] -> 
             RGBColor[
              0.268736668858344, 0.3997896562320101, 0.9386155277799839], 
             UndirectedEdge[87, 336] -> 
             RGBColor[
              0.4668814361724666, 0.5741090231571706, 0.9522620155496091], 
             UndirectedEdge[36, 266] -> 
             RGBColor[
              0.9938574384892986, 0.9902625241719002, 0.644943793687154], 
             UndirectedEdge[161, 430] -> 
             RGBColor[
              0.2077033952850149, 0.33563981597339154`, 0.9351397731406197], 
             UndirectedEdge[220, 412] -> 
             RGBColor[
              0.2036444979201258, 0.3313736574939363, 0.9349086249402898], 
             UndirectedEdge[372, 404] -> 
             RGBColor[
              0.7255490713882455, 0.7852295819730946, 0.9735376602371271], 
             UndirectedEdge[38, 287] -> 
             RGBColor[
              0.4114868433754372, 0.5286278492274263, 0.9479475143104742], 
             UndirectedEdge[171, 497] -> 
             RGBColor[
              0.47443851953832683`, 0.5842095892297761, 0.9517686846650694], 
             UndirectedEdge[246, 411] -> 
             RGBColor[
              0.2605541594338602, 0.3911893200258155, 0.9381495459731974], 
             UndirectedEdge[75, 303] -> 
             RGBColor[
              0.853058182050049, 0.3979604671775163, 0.19801610025913619`], 
             UndirectedEdge[23, 39] -> 
             RGBColor[
              0.3397705873831411, 0.4630597387061178, 0.9430778872171774], 
             UndirectedEdge[61, 391] -> 
             RGBColor[
              0.731686882991318, 0.7866873766200184, 0.8813805065527239], 
             UndirectedEdge[19, 200] -> 
             RGBColor[
              0.23309658772441674`, 0.3623296712485939, 0.936585877884182], 
             UndirectedEdge[208, 403] -> 
             RGBColor[
              0.5850117948684971, 0.6717049428230532, 0.961732098971587], 
             UndirectedEdge[108, 378] -> 
             RGBColor[
              0.20828889068141454`, 0.33625520875755976`, 0.9351731162372818],
              UndirectedEdge[10, 451] -> 
             RGBColor[
              0.2159367879573847, 0.34429363369929844`, 0.9356086526730982], 
             UndirectedEdge[199, 262] -> 
             RGBColor[
              0.36465083425503464`, 0.49026395757304103`, 0.944456206604027], 
             UndirectedEdge[3, 401] -> 
             RGBColor[
              0.18219297080333685`, 0.308826742388816, 0.9336869922056792], 
             UndirectedEdge[241, 311] -> 
             RGBColor[
              0.2028072709740812, 0.33049367889038916`, 0.934860946104279], 
             UndirectedEdge[179, 255] -> 
             RGBColor[
              0.19864123735537692`, 0.32611491341534343`, 0.9346236966527881],
              UndirectedEdge[276, 462] -> 
             RGBColor[
              0.20183278400452248`, 0.3294694312993405, 0.9348054505129868], 
             UndirectedEdge[167, 289] -> 
             RGBColor[
              0.2249680527429054, 0.35378606560414083`, 0.9361229698420748], 
             UndirectedEdge[164, 348] -> 
             RGBColor[
              0.38905288991990644`, 0.5111618708489473, 0.9460768222550604], 
             UndirectedEdge[18, 172] -> 
             RGBColor[
              0.2559027333199868, 0.38630037626268543`, 0.9378846541371808], 
             UndirectedEdge[289, 300] -> 
             RGBColor[
              0.2209681235766699, 0.34958188644027033`, 0.9358951797934225], 
             UndirectedEdge[59, 188] -> 
             RGBColor[
              0.24348630056862833`, 0.373249918193702, 0.937177556660457], 
             UndirectedEdge[352, 357] -> 
             RGBColor[
              0.185968194480225, 0.3127947418362315, 0.9339019856091351], 
             UndirectedEdge[161, 409] -> 
             RGBColor[
              0.23354210119449076`, 0.36279793415282724`, 0.9366112492172245],
              UndirectedEdge[39, 157] -> 
             RGBColor[
              0.2733433157427147, 0.4046315341857658, 0.9388778695051255], 
             UndirectedEdge[216, 398] -> 
             RGBColor[
              0.20308712437898663`, 0.33078782256267547`, 0.9348768833416823],
              UndirectedEdge[279, 396] -> 
             RGBColor[
              0.2027106095200159, 0.3303920815734764, 0.9348554413774677], 
             UndirectedEdge[103, 390] -> 
             RGBColor[
              0.3328589413831152, 0.4578427188183445, 0.9426093080634266], 
             UndirectedEdge[128, 296] -> 
             RGBColor[
              0.1882426629696768, 0.3151853524282767, 0.9340315132248347], 
             UndirectedEdge[362, 369] -> 
             RGBColor[
              0.1806318866536843, 0.30718594396907933`, 0.9335980907727736], 
             UndirectedEdge[86, 412] -> 
             RGBColor[
              0.18778375020070825`, 0.3147030060113407, 0.9340053788215426], 
             UndirectedEdge[261, 299] -> 
             RGBColor[
              0.2846830813812443, 0.4146506586338333, 0.9395932092741723], 
             UndirectedEdge[208, 266] -> 
             RGBColor[
              0.7100990368535118, 0.7663088762344812, 0.7456861929885767], 
             UndirectedEdge[211, 236] -> 
             RGBColor[
              0.1979212488225095, 0.32535815981739014`, 0.934582694370969], 
             UndirectedEdge[19, 124] -> 
             RGBColor[
              0.1942932572468809, 0.3215449106434528, 0.9343760856178694], 
             UndirectedEdge[319, 330] -> 
             RGBColor[
              0.18522178171588122`, 0.3120102146956035, 0.9338594785064245], 
             UndirectedEdge[137, 267] -> 
             RGBColor[
              0.22045636616771785`, 0.34904399695616795`, 0.93586603596606], 
             UndirectedEdge[23, 240] -> 
             RGBColor[
              0.7133780917330446, 0.7699270698367418, 0.8123932263629633], 
             UndirectedEdge[135, 369] -> 
             RGBColor[
              0.18101136995755066`, 0.307584804982074, 0.9336197017855334], 
             UndirectedEdge[13, 335] -> 
             RGBColor[
              0.23166019252299075`, 0.36081992881917935`, 0.936504077302417], 
             UndirectedEdge[176, 178] -> 
             RGBColor[
              0.3931214338805177, 0.5144895563820213, 0.9463902997884908], 
             UndirectedEdge[335, 459] -> 
             RGBColor[
              0.2024275249318897, 0.3300945417227562, 0.93483932012896], 
             UndirectedEdge[83, 326] -> 
             RGBColor[
              0.8603044472818449, 0.8888437109835485, 0.8510148449573589], 
             UndirectedEdge[33, 76] -> 
             RGBColor[
              0.3333497551271607, 0.45830089859572654`, 0.9426393717347399], 
             UndirectedEdge[13, 285] -> 
             RGBColor[
              0.2336665281569335, 0.36292871477947963`, 0.9366183351486626], 
             UndirectedEdge[225, 309] -> 
             RGBColor[
              0.18608052902366917`, 0.31291281256381276`, 0.9339083828952002],
              UndirectedEdge[242, 499] -> 
             RGBColor[
              0.8008428775112291, 0.844405505952868, 0.9471498665869478], 
             UndirectedEdge[13, 287] -> 
             RGBColor[
              0.2785495730651827, 0.41010364072745936`, 0.9391743581576726], 
             UndirectedEdge[265, 270] -> 
             RGBColor[
              0.18221828136351503`, 0.30885334539234544`, 0.9336884336046377],
              UndirectedEdge[191, 311] -> 
             RGBColor[
              0.19029060642002155`, 0.31733787084170345`, 0.934148140574671], 
             UndirectedEdge[47, 452] -> 
             RGBColor[
              0.2542089051352215, 0.3845200554455873, 0.9377881931278527], 
             UndirectedEdge[14, 80] -> 
             RGBColor[
              0.28919811932082623`, 0.417720629815705, 0.9399116866604884], 
             UndirectedEdge[152, 292] -> 
             RGBColor[
              0.18467767702367152`, 0.3114383261658612, 0.9338284925491338], 
             UndirectedEdge[133, 311] -> 
             RGBColor[
              0.19398258593487913`, 0.3212183753968402, 0.9343583933462479], 
             UndirectedEdge[187, 398] -> 
             RGBColor[
              0.21375269941056224`, 0.341998018157376, 0.9354842720614263], 
             UndirectedEdge[130, 442] -> 
             RGBColor[
              0.2704116943765009, 0.4015502142543449, 0.9387109180052648], 
             UndirectedEdge[304, 433] -> 
             RGBColor[
              0.1856912324704567, 0.31250363720355945`, 0.9338862130324074], 
             UndirectedEdge[354, 409] -> 
             RGBColor[
              0.28191067367276634`, 0.4134660896464276, 0.9393720026838029], 
             UndirectedEdge[29, 412] -> 
             RGBColor[
              0.18734250753660958`, 0.3142392319949723, 0.9339802507045822], 
             UndirectedEdge[295, 391] -> 
             RGBColor[
              0.7289553207863748, 0.7855578054503277, 0.9266495613450138], 
             UndirectedEdge[21, 298] -> 
             RGBColor[
              0.2878456584957702, 0.4198744159208656, 0.9397037564706185], 
             UndirectedEdge[383, 395] -> 
             RGBColor[
              0.3859577461997916, 0.503550871102866, 0.9463338532888385], 
             UndirectedEdge[133, 241] -> 
             RGBColor[
              0.2068052594645497, 0.3346958182809826, 0.9350886256343172], 
             UndirectedEdge[142, 473] -> 
             RGBColor[
              0.23965328121814944`, 0.36922117182888525`, 0.9369592718788913],
              UndirectedEdge[95, 330] -> 
             RGBColor[
              0.18713069149999506`, 0.314016599910578, 0.9339681880946508], 
             UndirectedEdge[275, 431] -> 
             RGBColor[
              0.4552821797756804, 0.5677869422920205, 0.9505011954058309], 
             UndirectedEdge[180, 474] -> 
             RGBColor[
              0.24632928568632426`, 0.37623807580806795`, 0.9373394604570903],
              UndirectedEdge[82, 173] -> 
             RGBColor[
              0.6203596764497656, 0.7014764485955354, 0.964075560146658], 
             UndirectedEdge[205, 230] -> 
             RGBColor[
              0.22168982682145016`, 0.35034044230916306`, 0.9359362797255486],
              UndirectedEdge[460, 463] -> 
             RGBColor[
              0.42791636353987605`, 0.5415498055841811, 0.9492787976467367], 
             UndirectedEdge[121, 500] -> 
             RGBColor[
              0.20306057228198376`, 0.33075991462522525`, 0.9348753712390383],
              UndirectedEdge[88, 241] -> 
             RGBColor[
              0.2025944621469051, 0.33027000332016815`, 0.9348488269563937], 
             UndirectedEdge[60, 73] -> 
             RGBColor[
              0.781195634641831, 0.8278300365608096, 0.9249593462199677], 
             UndirectedEdge[75, 400] -> 
             RGBColor[
              0.9275933480888754, 0.7357010879276322, 0.5134508624919265], 
             UndirectedEdge[141, 274] -> 
             RGBColor[
              0.2256966978230941, 0.35455191778218553`, 0.9361644651014577], 
             UndirectedEdge[299, 448] -> 
             RGBColor[
              0.2703287280609633, 0.40146301139634666`, 0.9387061931963326], 
             UndirectedEdge[160, 389] -> 
             RGBColor[
              0.21718512492406264`, 0.34560571500041215`, 0.9356797436166016],
              UndirectedEdge[24, 268] -> 
             RGBColor[
              0.18579615740306293`, 0.3126139199603535, 0.9338921883520968], 
             UndirectedEdge[386, 498] -> 
             RGBColor[
              0.540094387984412, 0.6311849610997022, 0.9594410817544053], 
             UndirectedEdge[350, 476] -> 
             RGBColor[
              0.18247717121909524`, 0.3091254550451252, 0.9337031769989198], 
             UndirectedEdge[180, 331] -> 
             RGBColor[
              0.2822898900471109, 0.4140349510252597, 0.9393873636764902], 
             UndirectedEdge[225, 252] -> 
             RGBColor[
              0.18313599846224066`, 0.30981792424973087`, 0.9337406962357694],
              UndirectedEdge[100, 203] -> 
             RGBColor[
              0.9191489665110915, 0.667681353565574, 0.3474800185895157], 
             UndirectedEdge[445, 471] -> 
             RGBColor[
              0.9599777422905198, 0.9272913458979556, 0.6345862231732597], 
             UndirectedEdge[373, 498] -> 
             RGBColor[
              0.8827929559209364, 0.907189051483757, 0.8884954173694475], 
             UndirectedEdge[102, 309] -> 
             RGBColor[
              0.19381918087775277`, 0.3210466263213213, 0.9343490876699807], 
             UndirectedEdge[46, 86] -> 
             RGBColor[
              0.19451109914847642`, 0.321773876294004, 0.9343884913918972], 
             UndirectedEdge[294, 385] -> 
             RGBColor[
              0.18452375420061845`, 0.3112765435195617, 0.9338197268720694], 
             UndirectedEdge[27, 29] -> 
             RGBColor[
              0.18482045324878804`, 0.31158839303099417`, 0.9338366234439357],
              UndirectedEdge[274, 284] -> 
             RGBColor[
              0.22545727776759072`, 0.3543002721237432, 0.936150830483487], 
             UndirectedEdge[284, 300] -> 
             RGBColor[
              0.2193467291603231, 0.3478776981063463, 0.9358028437800496], 
             UndirectedEdge[159, 453] -> 
             RGBColor[
              0.23602331412857852`, 0.36540584626453976`, 0.9367525506231953],
              UndirectedEdge[229, 232] -> 
             RGBColor[
              0.2566501782178637, 0.3870859882410977, 0.9379272200183691], 
             UndirectedEdge[259, 431] -> 
             RGBColor[
              0.552262608455937, 0.6458932694477724, 0.9585643649749793], 
             UndirectedEdge[112, 483] -> 
             RGBColor[
              0.7227411345359493, 0.7787563213495963, 0.8541899154691762], 
             UndirectedEdge[78, 376] -> 
             RGBColor[
              0.4205848118936931, 0.5382565536141679, 0.9481458786566228], 
             UndirectedEdge[76, 351] -> 
             RGBColor[
              0.32530926006899097`, 0.449849828492759, 0.9421814774360235], 
             UndirectedEdge[178, 498] -> 
             RGBColor[
              0.6219478547908555, 0.7019387588473889, 0.96476604218581], 
             UndirectedEdge[400, 431] -> 
             RGBColor[
              0.7055601740591597, 0.7646836770228431, 0.882816923995621], 
             UndirectedEdge[18, 432] -> 
             RGBColor[
              0.2897732046951418, 0.4219003891898929, 0.9398135273751238], 
             UndirectedEdge[220, 325] -> 
             RGBColor[
              0.22533443478540557`, 0.3541711563607717, 0.9361438347573814], 
             UndirectedEdge[353, 380] -> 
             RGBColor[
              0.18408835379335264`, 0.31081891008554513`, 0.9337949314629927],
              UndirectedEdge[5, 355] -> 
             RGBColor[
              0.624643054436057, 0.7054290889949936, 0.9640878657059478], 
             UndirectedEdge[367, 441] -> 
             RGBColor[
              0.20930859557874099`, 0.3373269832576745, 0.9352311869226664], 
             UndirectedEdge[21, 287] -> 
             RGBColor[
              0.30207832712053356`, 0.43483385304880307`, 0.9405142858934524],
              UndirectedEdge[175, 182] -> 
             RGBColor[
              0.3713372775098073, 0.4960554186499155, 0.9448822608556314], 
             UndirectedEdge[70, 371] -> 
             RGBColor[
              0.31191266997486483`, 0.4395307683313558, 0.9412808306475218], 
             UndirectedEdge[217, 496] -> 
             RGBColor[
              0.1835288398725976, 0.31023082547960007`, 0.9337630679729325], 
             UndirectedEdge[195, 292] -> 
             RGBColor[
              0.18660739700750423`, 0.31346658422018303`, 0.9339383872474483],
              UndirectedEdge[161, 285] -> 
             RGBColor[
              0.21411916928885952`, 0.34238320123499877`, 0.9355051419788516],
              UndirectedEdge[168, 370] -> 
             RGBColor[
              0.2607361826498604, 0.3913806379667703, 0.9381599119260695], 
             UndirectedEdge[50, 173] -> 
             RGBColor[
              0.800480264278042, 0.8445485570290475, 0.9806185434355512], 
             UndirectedEdge[19, 188] -> 
             RGBColor[
              0.21359720872912316`, 0.3418345875925049, 0.9354754170971461], 
             UndirectedEdge[147, 323] -> 
             RGBColor[
              0.905895222039182, 0.5694593928427707, 0.46819019532102185`], 
             UndirectedEdge[255, 260] -> 
             RGBColor[
              0.2034606107913817, 0.33118038046250897`, 0.9348981528403446], 
             UndirectedEdge[29, 350] -> 
             RGBColor[
              0.18297683433485876`, 0.309650632660264, 0.9337316320741772], 
             UndirectedEdge[348, 400] -> 
             RGBColor[
              0.7259744000228323, 0.7821275326457193, 0.8841834386643934], 
             UndirectedEdge[26, 124] -> 
             RGBColor[
              0.18513200243707828`, 0.31191585098124663`, 0.9338543657093131],
              UndirectedEdge[18, 93] -> 
             RGBColor[
              0.25547187449726694`, 0.38584751632197967`, 0.9378601173646254],
              UndirectedEdge[64, 223] -> 
             RGBColor[
              0.19649530119615788`, 0.32385939845179323`, 0.9345014887631486],
              UndirectedEdge[12, 335] -> 
             RGBColor[
              0.20220521707563277`, 0.32986088207069797`, 0.9348266600254211],
              UndirectedEdge[143, 498] -> 
             RGBColor[
              0.6776190672953443, 0.7471351571180758, 0.9691486839645342], 
             UndirectedEdge[44, 92] -> 
             RGBColor[
              0.2754748024457604, 0.40687186185472934`, 0.938999254519612], 
             UndirectedEdge[274, 389] -> 
             RGBColor[
              0.2195028960405469, 0.34804183939901356`, 0.9358117372528503], 
             UndirectedEdge[247, 401] -> 
             RGBColor[
              0.1825033131056717, 0.3091529318254084, 0.9337046657406869], 
             UndirectedEdge[111, 182] -> 
             RGBColor[
              0.35579432343932743`, 0.4825928930456521, 0.9438918775663551], 
             UndirectedEdge[157, 190] -> 
             RGBColor[
              0.2578198120642154, 0.3883153475726824, 0.9379938289356007], 
             UndirectedEdge[100, 360] -> 
             RGBColor[
              0.7946952326726424, 0.8354763984444047, 0.7327589869340729], 
             UndirectedEdge[59, 468] -> 
             RGBColor[
              0.24224871187808175`, 0.37194913401228247`, 0.9371070778153788],
              UndirectedEdge[101, 129] -> 
             RGBColor[
              0.2672434934849943, 0.39822023424183295`, 0.9385304936514267], 
             UndirectedEdge[180, 382] -> 
             RGBColor[
              0.23760741054514092`, 0.36707083203586066`, 0.9368427625706579],
              UndirectedEdge[145, 402] -> 
             RGBColor[
              0.21358684811844986`, 0.34182369793378664`, 0.9354748270756954],
              UndirectedEdge[90, 263] -> 
             RGBColor[
              0.24334458110817345`, 0.37310096205523113`, 0.9371694859468394],
              UndirectedEdge[98, 276] -> 
             RGBColor[
              0.20095020339638087`, 0.3285417831213411, 0.9347551888530141], 
             UndirectedEdge[224, 464] -> 
             RGBColor[
              0.20419415303821636`, 0.3319513798731969, 0.9349399269861233], 
             UndirectedEdge[261, 313] -> 
             RGBColor[
              0.3452565934007724, 0.4734656409279675, 0.9432204227264471], 
             UndirectedEdge[78, 219] -> 
             RGBColor[
              0.5697935423105139, 0.6612069230140997, 0.9595599186442647], 
             UndirectedEdge[393, 424] -> 
             RGBColor[
              0.20739385044843295`, 0.3353144647238677, 0.935122145020107], 
             UndirectedEdge[169, 211] -> 
             RGBColor[
              0.1856477523702797, 0.3124579368614757, 0.9338837369050252], 
             UndirectedEdge[176, 482] -> 
             RGBColor[
              0.3246527382525704, 0.45561961717846555`, 0.9419075632956775], 
             UndirectedEdge[35, 94] -> 
             RGBColor[
              0.18328807136271902`, 0.3099777625101124, 0.9337493565624799], 
             UndirectedEdge[114, 296] -> 
             RGBColor[
              0.18183178255671295`, 0.30844711064095676`, 0.9336664230693641],
              UndirectedEdge[130, 175] -> 
             RGBColor[
              0.350298253723786, 0.4772937364222603, 0.943561398674819], 
             UndirectedEdge[189, 383] -> 
             RGBColor[
              0.25987325139717643`, 0.39047364250719796`, 0.9381107692678216],
              UndirectedEdge[139, 437] -> 
             RGBColor[
              0.18225949462972918`, 0.3088966631482086, 0.9336907806391791], 
             UndirectedEdge[56, 324] -> 
             RGBColor[
              0.6732900844799101, 0.7406929401963493, 0.9670229089652596], 
             UndirectedEdge[398, 399] -> 
             RGBColor[
              0.2070690587330349, 0.3349730880380002, 0.9351036486124014], 
             UndirectedEdge[405, 429] -> 
             RGBColor[
              0.1868041703990252, 0.3136734055308251, 0.9339495932009951], 
             UndirectedEdge[12, 318] -> 
             RGBColor[
              0.19600810188078815`, 0.32334732108111897`, 0.9344737434828851],
              UndirectedEdge[11, 205] -> 
             RGBColor[
              0.3065274858845748, 0.4333315275623586, 0.9409938904047574], 
             UndirectedEdge[226, 389] -> 
             RGBColor[
              0.19095055240575043`, 0.3180315159156967, 0.9341857235222557], 
             UndirectedEdge[294, 327] -> 
             RGBColor[
              0.18563559838764718`, 0.312445162255122, 0.9338830447536945], 
             UndirectedEdge[167, 218] -> 
             RGBColor[
              0.26286988224919927`, 0.3936232915300437, 0.9382814229617262], 
             UndirectedEdge[217, 481] -> 
             RGBColor[
              0.19325559530187433`, 0.3204542621476837, 0.9343169923051846], 
             UndirectedEdge[247, 309] -> 
             RGBColor[
              0.18623761794577917`, 0.3130779229809633, 0.933917328876922], 
             UndirectedEdge[79, 234] -> 
             RGBColor[
              0.9063126289426009, 0.8289774045041336, 0.6243163382349994], 
             UndirectedEdge[331, 372] -> 
             RGBColor[
              0.4578529646135995, 0.56594472517835, 0.9516272296801642], 
             UndirectedEdge[27, 484] -> 
             RGBColor[
              0.1850117059565009, 0.3117894117529224, 0.933847515002707], 
             UndirectedEdge[103, 326] -> 
             RGBColor[
              0.56759306260054, 0.6573833324020449, 0.9602981460928508], 
             UndirectedEdge[155, 394] -> 
             RGBColor[
              0.1886886358497215, 0.3156540982015175, 0.9340569107205956], 
             UndirectedEdge[433, 469] -> 
             RGBColor[
              0.18101298547639227`, 0.3075865029948064, 0.9336197937869416], 
             UndirectedEdge[65, 412] -> 
             RGBColor[
              0.1867174620390582, 0.3135822695468723, 0.9339446552881686], 
             UndirectedEdge[13, 161] -> 
             RGBColor[
              0.23339794827523738`, 0.36264642029486893`, 0.9366030399217282],
              UndirectedEdge[229, 480] -> 
             RGBColor[
              0.23910094988203007`, 0.36864063657479446`, 0.9369278174264002],
              UndirectedEdge[32, 448] -> 
             RGBColor[
              0.26012823284654724`, 0.3907416441772443, 0.938125290084152], 
             UndirectedEdge[251, 453] -> 
             RGBColor[
              0.23943021557072935`, 0.3689867156902678, 0.9369465686202667], 
             UndirectedEdge[282, 310] -> 
             RGBColor[
              0.6707630336058359, 0.74272444693153, 0.9678190486190441], 
             UndirectedEdge[392, 473] -> 
             RGBColor[
              0.2502222365996353, 0.3803298140453018, 0.9375611582524985], 
             UndirectedEdge[222, 344] -> 
             RGBColor[
              0.1936890488951341, 0.3209098493567448, 0.9343416768460837], 
             UndirectedEdge[266, 440] -> 
             RGBColor[
              0.9426079391450114, 0.7947470752330569, 0.3871278708766489], 
             UndirectedEdge[16, 361] -> 
             RGBColor[
              0.2501087241581385, 0.3802105052721842, 0.9375546938868818], 
             UndirectedEdge[412, 426] -> 
             RGBColor[
              0.18880630124033773`, 0.3157777719874718, 0.9340636115905208], 
             UndirectedEdge[274, 460] -> 
             RGBColor[
              0.27237898950751444`, 0.4036179661707557, 0.9388229525526237], 
             UndirectedEdge[180, 230] -> 
             RGBColor[
              0.2345216927400936, 0.3638275469769471, 0.9366670355065708], 
             UndirectedEdge[375, 450] -> 
             RGBColor[
              0.20913463295766446`, 0.3371441375130559, 0.9352212800087508], 
             UndirectedEdge[6, 123] -> 
             RGBColor[
              0.20012045196386746`, 0.3276696617564901, 0.9347079357364398], 
             UndirectedEdge[170, 466] -> 
             RGBColor[
              0.19131064180456064`, 0.3184099927048328, 0.9342062300808134], 
             UndirectedEdge[267, 280] -> 
             RGBColor[
              0.24136535807007609`, 0.3710206731522022, 0.9370567721228178], 
             UndirectedEdge[52, 214] -> 
             RGBColor[
              0.18377002501748835`, 0.3104843263589016, 0.9337768031101326], 
             UndirectedEdge[358, 386] -> 
             RGBColor[
              0.2652427547751048, 0.39611733100357804`, 0.9384165545417262], 
             UndirectedEdge[230, 413] -> 
             RGBColor[
              0.21810416040748024`, 0.34657167956369916`, 0.9357320813277911],
              UndirectedEdge[53, 207] -> 
             RGBColor[
              0.8538308363641018, 0.3886921926180247, 0.19816051774968563`], 
             UndirectedEdge[188, 256] -> 
             RGBColor[
              0.26776710539076976`, 0.3985106384029728, 0.9385698304401877], 
             UndirectedEdge[38, 87] -> 
             RGBColor[
              0.4136160612646935, 0.5308657922292461, 0.9480687701193717], 
             UndirectedEdge[22, 52] -> 
             RGBColor[
              0.18089659272171946`, 0.3074641668299184, 0.9336131653917505], 
             UndirectedEdge[160, 460] -> 
             RGBColor[
              0.27006121839103014`, 0.4011818417721542, 0.938690958916375], 
             UndirectedEdge[63, 159] -> 
             RGBColor[
              0.2194636807819041, 0.34800062167578893`, 0.9358095040018843], 
             UndirectedEdge[285, 430] -> 
             RGBColor[
              0.20797197516671106`, 0.33592211045800224`, 0.935155068367554], 
             UndirectedEdge[132, 356] -> 
             RGBColor[
              0.2588153820462965, 0.38936175474663237`, 0.9380505251732665], 
             UndirectedEdge[99, 373] -> 
             RGBColor[
              0.9853487541189616, 0.9874627176430353, 0.859036977734402], 
             UndirectedEdge[243, 396] -> 
             RGBColor[
              0.19700888147424034`, 0.32439920388692833`, 0.9345307364002116],
              UndirectedEdge[118, 292] -> 
             RGBColor[
              0.188665488336347, 0.3156297686973238, 0.9340555925039526], 
             UndirectedEdge[84, 176] -> 
             RGBColor[
              0.29622447069818203`, 0.4279240901305121, 0.9402086344933376], 
             UndirectedEdge[334, 385] -> 
             RGBColor[
              0.18420532827080235`, 0.310941857677955, 0.9338015929864353], 
             UndirectedEdge[25, 325] -> 
             RGBColor[
              0.26126519476067855`, 0.3919366632365452, 0.9381900383831774], 
             UndirectedEdge[321, 397] -> 
             RGBColor[
              0.9037224589823456, 0.5792136748312032, 0.5298753084241274], 
             UndirectedEdge[201, 235] -> 
             RGBColor[
              0.23728480229023638`, 0.36673175030541116`, 0.9368243905077971],
              UndirectedEdge[321, 498] -> 
             RGBColor[
              0.8800107385388454, 0.9060385330965369, 0.934603959538476], 
             UndirectedEdge[368, 492] -> 
             RGBColor[
              0.18092029968887635`, 0.3074890843555088, 0.9336145154684589], 
             UndirectedEdge[239, 387] -> 
             RGBColor[
              0.1927675658632359, 0.3199413122648211, 0.934289199750629], 
             UndirectedEdge[196, 500] -> 
             RGBColor[
              0.1964924261713618, 0.32385637661844546`, 0.9345013250347398], 
             UndirectedEdge[122, 185] -> 
             RGBColor[
              0.19860974920189184`, 0.3260818173695664, 0.9346219034490297], 
             UndirectedEdge[350, 377] -> 
             RGBColor[
              0.181157971499196, 0.3077388924974179, 0.9336280505264527], 
             UndirectedEdge[315, 353] -> 
             RGBColor[
              0.18205882341933505`, 0.3086857449827948, 0.9336793527106135], 
             UndirectedEdge[102, 480] -> 
             RGBColor[
              0.2214017905721769, 0.3500376979486238, 0.9359198764872638], 
             UndirectedEdge[127, 253] -> 
             RGBColor[
              0.604821677598294, 0.6851926412626169, 0.9645634759762418], 
             UndirectedEdge[159, 192] -> 
             RGBColor[
              0.27255273720121065`, 0.4034082682269394, 0.9388472119027095], 
             UndirectedEdge[201, 289] -> 
             RGBColor[
              0.23376233339509425`, 0.3630294121591895, 0.9366237911152446], 
             UndirectedEdge[29, 194] -> 
             RGBColor[
              0.18526819594198288`, 0.31205899899006834`, 0.9338621217279373],
              UndirectedEdge[79, 388] -> 
             RGBColor[
              0.6074674522288179, 0.6856239979057058, 0.9655884516290124], 
             UndirectedEdge[246, 402] -> 
             RGBColor[
              0.22901412567720097`, 0.3580387447939263, 0.9363533877100543], 
             UndirectedEdge[185, 398] -> 
             RGBColor[
              0.20890004242653637`, 0.3368975679909415, 0.9352079204250486], 
             UndirectedEdge[133, 304] -> 
             RGBColor[
              0.19434480354761932`, 0.3215990890737532, 0.9343790211034406], 
             UndirectedEdge[107, 314] -> 
             RGBColor[
              0.2370472271918243, 0.36648204381384886`, 0.9368108609574035], 
             UndirectedEdge[13, 279] -> 
             RGBColor[
              0.23046404118961528`, 0.35956269792742684`, 0.9364359582535287],
              UndirectedEdge[180, 418] -> 
             RGBColor[
              0.3698251689882062, 0.48989999728181594`, 0.9451142408333664], 
             UndirectedEdge[112, 207] -> 
             RGBColor[
              0.9342142442860358, 0.7583914671293646, 0.48787682484366524`], 
             UndirectedEdge[308, 369] -> 
             RGBColor[
              0.18646563701697516`, 0.31331758548203437`, 0.9339303142257027],
              UndirectedEdge[45, 292] -> 
             RGBColor[
              0.193148625604734, 0.3203418302137187, 0.93431090053918], 
             UndirectedEdge[348, 418] -> 
             RGBColor[
              0.4692928666535278, 0.5800321164088754, 0.9513636000208304], 
             UndirectedEdge[51, 264] -> 
             RGBColor[
              0.930398195461806, 0.7373009794201983, 0.46708003654237346`], 
             UndirectedEdge[201, 218] -> 
             RGBColor[
              0.27166416290138806`, 0.4028666380850924, 0.938782244234896], 
             UndirectedEdge[262, 376] -> 
             RGBColor[
              0.3571381356790589, 0.48375683566574046`, 0.9439775040939842], 
             UndirectedEdge[304, 307] -> 
             RGBColor[
              0.19124101859615344`, 0.3183368142984305, 0.9342022651420929], 
             UndirectedEdge[8, 166] -> 
             RGBColor[
              0.19658418244763454`, 0.3239528182824921, 0.9345065504189323], 
             UndirectedEdge[66, 312] -> 
             RGBColor[
              0.19642559622123856`, 0.32378613410360235`, 0.9344975191679463],
              UndirectedEdge[202, 430] -> 
             RGBColor[
              0.19415820437315612`, 0.32140296151032133`, 0.9343683945565036],
              UndirectedEdge[348, 404] -> 
             RGBColor[
              0.6494536944870786, 0.7234519269470636, 0.967547153420917], 
             UndirectedEdge[1, 113] -> 
             RGBColor[
              0.1979971628023344, 0.3254379502234105, 0.9345870175598152], 
             UndirectedEdge[29, 377] -> 
             RGBColor[
              0.18261049498864607`, 0.3092655867801383, 0.9337107695903608], 
             UndirectedEdge[259, 404] -> 
             RGBColor[
              0.7600500863927916, 0.8126123064413943, 0.97668222149209], 
             UndirectedEdge[131, 449] -> 
             RGBColor[
              0.9086679607710296, 0.6083135329493521, 0.2853739255705805], 
             UndirectedEdge[423, 465] -> 
             RGBColor[
              0.1791246132879326, 0.3056017040950233, 0.9335122537844052], 
             UndirectedEdge[177, 412] -> 
             RGBColor[
              0.1873190234343715, 0.314214548714542, 0.9339789133197014], 
             UndirectedEdge[139, 158] -> 
             RGBColor[
              0.18715334052902155`, 0.3140404054761162, 0.9339694779233476], 
             UndirectedEdge[454, 500] -> 
             RGBColor[
              0.206190516482255, 0.33404968442963456`, 0.9350536169309063], 
             UndirectedEdge[430, 459] -> 
             RGBColor[
              0.19801808656198788`, 0.32545994242144927`, 0.9345882091369736],
              UndirectedEdge[474, 490] -> 
             RGBColor[
              0.22274072146667342`, 0.35144499921186156`, 0.9359961266209347],
              UndirectedEdge[443, 451] -> 
             RGBColor[
              0.24646170398602968`, 0.37637725583686343`, 0.9373470014833631],
              UndirectedEdge[182, 483] -> 
             RGBColor[
              0.3985189663280868, 0.5195988313129054, 0.9466142540313085], 
             UndirectedEdge[92, 457] -> 
             RGBColor[
              0.37059515571215895`, 0.49157695819153635`, 0.9450791109885306],
              UndirectedEdge[38, 184] -> 
             RGBColor[
              0.5298276783437619, 0.6291770036011967, 0.9561291221434074], 
             UndirectedEdge[51, 457] -> 
             RGBColor[
              0.7322518449471631, 0.7861260863844587, 0.8380007601438797], 
             UndirectedEdge[321, 455] -> 
             RGBColor[
              0.7992398811281014, 0.8424906663250493, 0.9268604994645402], 
             UndirectedEdge[251, 435] -> 
             RGBColor[
              0.2386642748374078, 0.3681816634160995, 0.9369029494286119], 
             UndirectedEdge[16, 441] -> 
             RGBColor[
              0.2457921380966431, 0.37567349963418883`, 0.9373088706964965], 
             UndirectedEdge[302, 390] -> 
             RGBColor[
              0.25033731885124844`, 0.38045077278838335`, 0.9375677120164789],
              UndirectedEdge[186, 455] -> 
             RGBColor[
              0.8031839177998501, 0.842431819201664, 0.7386664277516752], 
             UndirectedEdge[349, 353] -> 
             RGBColor[
              0.18295144203234145`, 0.3096239437403533, 0.9337301860201135], 
             UndirectedEdge[125, 406] -> 
             RGBColor[
              0.5972259557238873, 0.6808172474310844, 0.9631312731906503], 
             UndirectedEdge[307, 433] -> 
             RGBColor[
              0.18622321839671918`, 0.3130627881419171, 0.9339165088439054], 
             UndirectedEdge[406, 419] -> 
             RGBColor[
              0.5328942370686292, 0.630560819878426, 0.9567192886891854], 
             UndirectedEdge[237, 274] -> 
             RGBColor[
              0.23848727143504053`, 0.36799562161754756`, 0.9368928693467], 
             UndirectedEdge[203, 264] -> 
             RGBColor[
              0.8553074725725389, 0.4148947299646385, 0.20015613150748274`], 
             UndirectedEdge[69, 231] -> 
             RGBColor[
              0.6032570715569849, 0.6866480853473442, 0.9632586642510103], 
             UndirectedEdge[328, 399] -> 
             RGBColor[
              0.22543273121464985`, 0.354274472140261, 0.9361494325936104], 
             UndirectedEdge[78, 262] -> 
             RGBColor[
              0.4066140424697561, 0.526155775330442, 0.9472556735827959], 
             UndirectedEdge[27, 412] -> 
             RGBColor[
              0.18773360296108882`, 0.31465029808298206`, 0.9340025230104325],
              UndirectedEdge[147, 221] -> 
             RGBColor[
              0.8906777697244648, 0.5160364512426465, 0.23692570222520362`], 
             UndirectedEdge[93, 289] -> 
             RGBColor[
              0.21635167337317993`, 0.34472970457655394`, 0.93563227978376], 
             UndirectedEdge[141, 235] -> 
             RGBColor[
              0.21221346212045616`, 0.34038018217219357`, 0.9353966147748521],
              UndirectedEdge[185, 464] -> 
             RGBColor[
              0.2069974759051772, 0.3348978499473083, 0.9350995720762522], 
             UndirectedEdge[6, 189] -> 
             RGBColor[
              0.23318323402672853`, 0.3624207420060165, 0.9365908122629168], 
             UndirectedEdge[38, 316] -> 
             RGBColor[
              0.4787664530256467, 0.5873266421968035, 0.9522189657129314], 
             UndirectedEdge[322, 343] -> 
             RGBColor[
              0.8335064289062653, 0.2585506719501317, 0.17971910020172568`], 
             UndirectedEdge[93, 141] -> 
             RGBColor[
              0.21496969901233648`, 0.34327716190107216`, 0.9355535783883577],
              UndirectedEdge[191, 237] -> 
             RGBColor[
              0.21174339074199797`, 0.3398861073491872, 0.9353698449052572], 
             UndirectedEdge[145, 461] -> 
             RGBColor[
              0.23115805437216275`, 0.3602921497852615, 0.9364754812775742], 
             UndirectedEdge[420, 500] -> 
             RGBColor[
              0.19451665335716928`, 0.32177971411949735`, 0.9343888076958655],
              UndirectedEdge[402, 458] -> 
             RGBColor[
              0.2285757051250969, 0.3575779369961964, 0.9363284203081972], 
             UndirectedEdge[148, 263] -> 
             RGBColor[
              0.24948680213618696`, 0.3795568257949794, 0.9375192763477829], 
             UndirectedEdge[126, 499] -> 
             RGBColor[
              0.5585145617417738, 0.6524663078730726, 0.9583874586880152], 
             UndirectedEdge[133, 371] -> 
             RGBColor[
              0.22603138593843586`, 0.35490369621186185`, 0.9361835250944996],
              UndirectedEdge[72, 245] -> 
             RGBColor[
              0.22752065341650146`, 0.35646901075632065`, 0.9362683366742017],
              UndirectedEdge[57, 131] -> 
             RGBColor[
              0.8981850447320697, 0.6159608551699692, 0.564028013817431], 
             UndirectedEdge[15, 173] -> 
             RGBColor[
              0.6865018666299831, 0.7550197429095551, 0.9693877484071343], 
             UndirectedEdge[138, 415] -> 
             RGBColor[
              0.18158458466446153`, 0.308187289982949, 0.9336523455150969], 
             UndirectedEdge[105, 109] -> 
             RGBColor[
              0.2025306105640042, 0.3302028912581151, 0.9348451907032074], 
             UndirectedEdge[235, 284] -> 
             RGBColor[
              0.2119740420649528, 0.3401285365137513, 0.9353829801568815], 
             UndirectedEdge[150, 473] -> 
             RGBColor[
              0.23947719025137565`, 0.36903608905799384`, 0.9369492437588367],
              UndirectedEdge[74, 417] -> 
             RGBColor[
              0.1929190076012242, 0.3201004871334076, 0.9342978241335694], 
             UndirectedEdge[20, 413] -> 
             RGBColor[
              0.23603377197510877`, 0.36541683812430875`, 0.9367531461820842],
              UndirectedEdge[34, 467] -> 
             RGBColor[
              0.20003782336254744`, 0.32758281385754684`, 0.9347032301598326],
              UndirectedEdge[62, 110] -> 
             RGBColor[
              0.33413455286534527`, 0.45851113631971724`, 0.9427065695832899],
              UndirectedEdge[93, 389] -> 
             RGBColor[
              0.20877589722978934`, 0.3367670835179003, 0.9352008505397502], 
             UndirectedEdge[28, 408] -> 
             RGBColor[
              0.7065627960875993, 0.7690478747515729, 0.9714624707191005], 
             UndirectedEdge[93, 284] -> 
             RGBColor[
              0.21473027895683314`, 0.3430255162426299, 0.9355399437703871], 
             UndirectedEdge[143, 313] -> 
             RGBColor[
              0.4709361194251123, 0.5788655180367319, 0.9521839040886261], 
             UndirectedEdge[361, 398] -> 
             RGBColor[
              0.21817994857503456`, 0.3466513377330461, 0.9357363973518147], 
             UndirectedEdge[105, 382] -> 
             RGBColor[
              0.2017475218904906, 0.3293798154115627, 0.9348005949617267], 
             UndirectedEdge[240, 495] -> 
             RGBColor[
              0.9404490296531263, 0.7834756918464549, 0.4513533807985771], 
             UndirectedEdge[13, 21] -> 
             RGBColor[
              0.27647406119866225`, 0.4079221461606935, 0.9390561608273189], 
             UndirectedEdge[32, 179] -> 
             RGBColor[
              0.20989223640499494`, 0.3379404267710331, 0.9352644244043025], 
             UndirectedEdge[38, 79] -> 
             RGBColor[
              0.7025334025034438, 0.7661868171424233, 0.9721373827063131], 
             UndirectedEdge[328, 407] -> 
             RGBColor[
              0.26005803844889097`, 0.3906678654147257, 0.9381212926170488], 
             UndirectedEdge[357, 367] -> 
             RGBColor[
              0.19284697546686017`, 0.3200247767930899, 0.9342937220100794], 
             UndirectedEdge[196, 213] -> 
             RGBColor[
              0.19710682911621347`, 0.3245021530688812, 0.9345363143735214], 
             UndirectedEdge[233, 326] -> 
             RGBColor[
              0.8439697158415906, 0.8784945870094583, 0.9607638453803016], 
             UndirectedEdge[164, 372] -> 
             RGBColor[
              0.4651482668210734, 0.5729395258749782, 0.9520673290712703], 
             UndirectedEdge[3, 278] -> 
             RGBColor[
              0.1840613533248448, 0.3107905308812148, 0.9337933938262548], 
             UndirectedEdge[195, 399] -> 
             RGBColor[
              0.19798691924192627`, 0.3254271835919423, 0.9345864342042041], 
             UndirectedEdge[118, 187] -> 
             RGBColor[
              0.20672865124829637`, 0.33461529818845887`, 0.9350842629097332],
              UndirectedEdge[61, 178] -> 
             RGBColor[
              0.7297842099398613, 0.7851427009224017, 0.8812307211603922], 
             UndirectedEdge[2, 496] -> 
             RGBColor[
              0.18500487281902223`, 0.3117822296921864, 0.9338471258656362], 
             UndirectedEdge[103, 404] -> 
             RGBColor[
              0.6233155210312117, 0.7010502757004149, 0.96581591387943], 
             UndirectedEdge[37, 374] -> 
             RGBColor[
              0.8546495293295531, 0.4156398998574755, 0.19975329213765833`], 
             UndirectedEdge[236, 466] -> 
             RGBColor[
              0.2016228242267626, 0.329248750260696, 0.934793493614251], 
             UndirectedEdge[150, 254] -> 
             RGBColor[
              0.20389499448692971`, 0.33163694526804693`, 0.9349228903491928],
              UndirectedEdge[148, 229] -> 
             RGBColor[
              0.25473807623061007`, 0.385076247818226, 0.9378183286388965], 
             UndirectedEdge[160, 432] -> 
             RGBColor[
              0.26534093705235057`, 0.3962205268020793, 0.9384221458771677], 
             UndirectedEdge[48, 198] -> 
             RGBColor[
              0.18614733394130184`, 0.3129830287679211, 0.9339121873364302], 
             UndirectedEdge[89, 178] -> 
             RGBColor[
              0.38949543937037706`, 0.5113489021851207, 0.9461592546246456], 
             UndirectedEdge[63, 239] -> 
             RGBColor[
              0.20172774579693858`, 0.3293590294833628, 0.934799468742455], 
             UndirectedEdge[425, 462] -> 
             RGBColor[
              0.1883728625948838, 0.3153222004895023, 0.9340389279008772], 
             UndirectedEdge[44, 457] -> 
             RGBColor[
              0.3741308449563232, 0.49529319176279873`, 0.9452804632604023], 
             UndirectedEdge[46, 254] -> 
             RGBColor[
              0.1980699244230848, 0.3255144273001723, 0.9345911612264759], 
             UndirectedEdge[1, 452] -> 
             RGBColor[
              0.21304293634488086`, 0.3412520121737673, 0.935443852104836], 
             UndirectedEdge[260, 299] -> 
             RGBColor[
              0.2249121050554158, 0.35372726103730096`, 0.9361197837040394], 
             UndirectedEdge[321, 341] -> 
             RGBColor[
              0.9898662415110249, 0.9892279829702391, 0.7558592343220067], 
             UndirectedEdge[249, 406] -> 
             RGBColor[
              0.5717259495199576, 0.6608964487773493, 0.960589670883349], 
             UndirectedEdge[398, 496] -> 
             RGBColor[
              0.19603720028339988`, 0.32337790534720917`, 0.9344754005938667],
              UndirectedEdge[382, 462] -> 
             RGBColor[
              0.20106839690715364`, 0.3286660119950647, 0.934761919798601], 
             UndirectedEdge[63, 272] -> 
             RGBColor[
              0.23201898916873956`, 0.36119704684288256`, 0.9365245102406003],
              UndirectedEdge[117, 270] -> 
             RGBColor[
              0.18183894581371152`, 0.308454639678239, 0.933666831006253], 
             UndirectedEdge[164, 404] -> 
             RGBColor[
              0.5764261418930885, 0.6604370522196931, 0.9628281641033989], 
             UndirectedEdge[133, 191] -> 
             RGBColor[
              0.19428859491049005`, 0.32154001023229684`, 0.9343758201047092],
              UndirectedEdge[307, 469] -> 
             RGBColor[
              0.186562771602089, 0.31341968008967747`, 0.9339358458966271], 
             UndirectedEdge[31, 237] -> 
             RGBColor[
              0.21243558089193113`, 0.3406136430841573, 0.9354092641102925], 
             UndirectedEdge[1, 468] -> 
             RGBColor[
              0.21038952484231582`, 0.33846310844856536`, 0.9352927442451355],
              UndirectedEdge[346, 395] -> 
             RGBColor[
              0.47277817219066315`, 0.5825384587097979, 0.951727273224181], 
             UndirectedEdge[214, 223] -> 
             RGBColor[
              0.1978649215993461, 0.32529895633449324`, 0.9345794866189384], 
             UndirectedEdge[264, 397] -> 
             RGBColor[
              0.8437768320344039, 0.3262651740296299, 0.18911437710616869`], 
             UndirectedEdge[103, 204] -> 
             RGBColor[
              0.3628536312078076, 0.48870731062358463`, 0.9443416904150619], 
             UndirectedEdge[110, 356] -> 
             RGBColor[
              0.3311960783219361, 0.45542261326454736`, 0.9425392278051263], 
             UndirectedEdge[184, 253] -> 
             RGBColor[
              0.4591640004744537, 0.5697502062280924, 0.9511350822856912], 
             UndirectedEdge[115, 417] -> 
             RGBColor[
              0.19405888879625283`, 0.3212985745420247, 0.9343627386813232], 
             UndirectedEdge[243, 459] -> 
             RGBColor[
              0.19552964555273866`, 0.32284443314445566`, 0.9344464961028154],
              UndirectedEdge[190, 349] -> 
             RGBColor[
              0.20086956962021285`, 0.3284570319101118, 0.9347505968787484], 
             UndirectedEdge[128, 222] -> 
             RGBColor[
              0.19567917188119596`, 0.32300159479618107`, 0.9344550114060167],
              UndirectedEdge[204, 275] -> 
             RGBColor[
              0.402607767889131, 0.5221630142088122, 0.9471448284585735], 
             UndirectedEdge[178, 455] -> 
             RGBColor[
              0.5411769973801115, 0.6383908920759014, 0.9570225821118743], 
             UndirectedEdge[84, 391] -> 
             RGBColor[
              0.3743150955210323, 0.495024736722043, 0.9453330205540728], 
             UndirectedEdge[54, 203] -> 
             RGBColor[
              0.9172982685013698, 0.6686889606982549, 0.5070233200844496], 
             UndirectedEdge[236, 314] -> 
             RGBColor[
              0.23558368231737692`, 0.3649437653567001, 0.9367275142419242], 
             UndirectedEdge[277, 313] -> 
             RGBColor[
              0.4022235011215268, 0.5228075131556505, 0.9468503037125551], 
             UndirectedEdge[186, 397] -> 
             RGBColor[
              0.9076664956540943, 0.5791548277078178, 0.3416812367112626], 
             UndirectedEdge[29, 297] -> 
             RGBColor[
              0.18984593669287142`, 0.3168704947647796, 0.9341228172915397], 
             UndirectedEdge[130, 208] -> 
             RGBColor[
              0.3647668975032984, 0.4898257484488929, 0.9444833278623301], 
             UndirectedEdge[145, 450] -> 
             RGBColor[
              0.21228550631692578`, 0.340455905190549, 0.9354007175852613], 
             UndirectedEdge[86, 350] -> 
             RGBColor[
              0.18341807699895743`, 0.3101144066766324, 0.9337567601911376], 
             UndirectedEdge[37, 281] -> 
             RGBColor[
              0.8401393429256434, 0.30410824875280007`, 0.18585832125036283`],
              UndirectedEdge[281, 445] -> 
             RGBColor[
              0.8907713717872949, 0.5149365980262008, 0.23825003998390762`], 
             UndirectedEdge[116, 224] -> 
             RGBColor[
              0.2412066178691736, 0.37085382713634363`, 0.9370477321032114], 
             UndirectedEdge[112, 163] -> 
             RGBColor[
              0.9463750065735652, 0.8136106484588435, 0.49802406298394036`], 
             UndirectedEdge[148, 480] -> 
             RGBColor[
              0.25899827885189075`, 0.38955399088563913`, 0.9380609408757734],
              UndirectedEdge[42, 487] -> 
             RGBColor[
              0.19664512493327133`, 0.3240168726988731, 0.934510021003333], 
             UndirectedEdge[122, 319] -> 
             RGBColor[
              0.1832707103845271, 0.30995951502128316`, 0.9337483678804552], 
             UndirectedEdge[129, 348] -> 
             RGBColor[
              0.37572812244985154`, 0.497829719871169, 0.9452933537370448], 
             UndirectedEdge[93, 201] -> 
             RGBColor[
              0.24004103918211672`, 0.36962873003428975`, 0.9369813541213027],
              UndirectedEdge[121, 427] -> 
             RGBColor[
              0.19582329677639237`, 0.3231530791990786, 0.9344632191055845], 
             UndirectedEdge[269, 411] -> 
             RGBColor[
              0.441541570634595, 0.5502832522185821, 0.9505633429393294], 
             UndirectedEdge[76, 371] -> 
             RGBColor[
              0.3322551655815734, 0.4571504155823287, 0.9425770364794188], 
             UndirectedEdge[61, 244] -> 
             RGBColor[
              0.7184903511263943, 0.775794731676694, 0.8803911147116745], 
             UndirectedEdge[184, 436] -> 
             RGBColor[
              0.4481781977283561, 0.5602348560519236, 0.9504350766490738], 
             UndirectedEdge[80, 293] -> 
             RGBColor[
              0.578582457393624, 0.6633186431495282, 0.9625149398020252], 
             UndirectedEdge[111, 460] -> 
             RGBColor[
              0.33363255379100343`, 0.46265113373051764`, 0.9425070766696382],
              UndirectedEdge[286, 358] -> 
             RGBColor[
              0.20613946196016764`, 0.33399602288987706`, 0.9350507094514018],
              UndirectedEdge[176, 244] -> 
             RGBColor[
              0.38182757506705056`, 0.5051415871363136, 0.945550693339773], 
             UndirectedEdge[99, 321] -> 
             RGBColor[
              0.9825665367368704, 0.9863121992558153, 0.9051455199034306], 
             UndirectedEdge[187, 478] -> 
             RGBColor[
              0.2352799848565821, 0.36462456006987354`, 0.9367102191208121], 
             UndirectedEdge[116, 185] -> 
             RGBColor[
              0.24400994073613447`, 0.3738002972104551, 0.9372073771933402], 
             UndirectedEdge[97, 257] -> 
             RGBColor[
              0.9757547061623437, 0.9298770721991836, 0.3603120410906092], 
             UndirectedEdge[16, 313] -> 
             RGBColor[
              0.3156685624243244, 0.4442664326028998, 0.9414658712422952], 
             UndirectedEdge[166, 344] -> 
             RGBColor[
              0.19297880215941118`, 0.32016333500525607`, 0.9343012293452001],
              UndirectedEdge[103, 443] -> 
             RGBColor[
              0.3488203865149018, 0.47461920966592475`, 0.9435182887508398], 
             UndirectedEdge[74, 115] -> 
             RGBColor[
              0.18984673852773665`, 0.31687133754406216`, 0.9341228629548491],
              UndirectedEdge[196, 332] -> 
             RGBColor[
              0.18931192738265673`, 0.3163092171215981, 0.934092406251319], 
             UndirectedEdge[49, 203] -> 
             RGBColor[
              0.9194979870090474, 0.6684278731193166, 0.38546874588719493`], 
             UndirectedEdge[95, 122] -> 
             RGBColor[
              0.18517962016864098`, 0.3119659002362576, 0.9338570774686815], 
             UndirectedEdge[97, 209] -> 
             RGBColor[
              0.9914664507187211, 0.9823539717574632, 0.575433002447343], 
             UndirectedEdge[484, 490] -> 
             RGBColor[
              0.2003898909918431, 0.3279528592583135, 0.9347232798904836], 
             UndirectedEdge[128, 415] -> 
             RGBColor[
              0.1873275955453248, 0.3142235585466571, 0.9339794014887388], 
             UndirectedEdge[371, 442] -> 
             RGBColor[
              0.24599324612330464`, 0.37588487692119543`, 0.9373203235011023],
              UndirectedEdge[88, 311] -> 
             RGBColor[
              0.18977178861723454`, 0.3167925604360257, 0.9341185946683245], 
             UndirectedEdge[15, 149] -> 
             RGBColor[
              0.6067680705890965, 0.6914867648051379, 0.9622913844255672], 
             UndirectedEdge[117, 140] -> 
             RGBColor[
              0.1812891715754636, 0.30787679209614044`, 0.933635522176703], 
             UndirectedEdge[199, 475] -> 
             RGBColor[
              0.3613314497983178, 0.4873888735937467, 0.9442446983616614], 
             UndirectedEdge[71, 169] -> 
             RGBColor[
              0.1907755412237238, 0.3178475680670369, 0.9341757568943452], 
             UndirectedEdge[23, 51] -> 
             RGBColor[
              0.7136013437576199, 0.7704045833430664, 0.8366928314862011], 
             UndirectedEdge[381, 416] -> 
             RGBColor[
              0.19876402822087508`, 0.3262439744003725, 0.9346306894109254], 
             UndirectedEdge[121, 447] -> 
             RGBColor[
              0.21943101242653507`, 0.34796628516300276`, 0.9358076435873746],
              UndirectedEdge[244, 407] -> 
             RGBColor[
              0.361925627233212, 0.4849803667690406, 0.9443895897897958], 
             UndirectedEdge[255, 385] -> 
             RGBColor[
              0.1893629494279947, 0.3163628445262328, 0.9340953118813207], 
             UndirectedEdge[30, 469] -> 
             RGBColor[
              0.18014325773351766`, 0.30667236399312137`, 0.9335702640786318],
              UndirectedEdge[80, 171] -> 
             RGBColor[
              0.4090554292271066, 0.5282531641753069, 0.9474159938779831], 
             UndirectedEdge[214, 466] -> 
             RGBColor[
              0.1912157031774699, 0.31831020618830375`, 0.9342008234664497], 
             UndirectedEdge[199, 455] -> 
             RGBColor[
              0.4995894556816295, 0.6028040573199673, 0.9542526889773754], 
             UndirectedEdge[175, 483] -> 
             RGBColor[
              0.4248591023079348, 0.5424133332049215, 0.9482926242042767], 
             UndirectedEdge[124, 416] -> 
             RGBColor[
              0.19729887283700168`, 0.3247040031957048, 0.934547250979317], 
             UndirectedEdge[142, 396] -> 
             RGBColor[
              0.2065755605048984, 0.3344543901106338, 0.9350755446183742], 
             UndirectedEdge[185, 361] -> 
             RGBColor[
              0.22082084550846576`, 0.3494270878526189, 0.9358867925253167], 
             UndirectedEdge[19, 26] -> 
             RGBColor[
              0.1940564817835153, 0.32129604461902417`, 0.9343626016055087], 
             UndirectedEdge[341, 455] -> 
             RGBColor[
              0.8036709694912352, 0.8434735735210568, 0.7916789986243209], 
             UndirectedEdge[159, 239] -> 
             RGBColor[
              0.2143802858334754, 0.34265765127913517`, 0.9355200121797802], 
             UndirectedEdge[261, 482] -> 
             RGBColor[
              0.3308323765041129, 0.4609721092343021, 0.9423013243806262], 
             UndirectedEdge[5, 97] -> 
             RGBColor[
              0.8390165308787574, 0.8650728443865321, 0.6896757172524062], 
             UndirectedEdge[285, 396] -> 
             RGBColor[
              0.20591309648733414`, 0.33375809842552917`, 0.9350378182726016],
              UndirectedEdge[174, 424] -> 
             RGBColor[
              0.19047450678086728`, 0.3175311617809086, 0.934158613428165], 
             UndirectedEdge[99, 186] -> 
             RGBColor[
              0.9865105734086191, 0.9862533521324298, 0.7169514481905657], 
             UndirectedEdge[79, 127] -> 
             RGBColor[
              0.8591989102072256, 0.8905659049388609, 0.9864323531431288], 
             UndirectedEdge[29, 86] -> 
             RGBColor[
              0.18487060048840748`, 0.3116411009593528, 0.9338394792550458], 
             UndirectedEdge[127, 316] -> 
             RGBColor[
              0.6354319607294284, 0.7117057299932411, 0.9665139361497471], 
             UndirectedEdge[197, 466] -> 
             RGBColor[
              0.21288997416386868`, 0.3410912392231611, 0.9354351411349147], 
             UndirectedEdge[183, 206] -> 
             RGBColor[
              0.1886895173788014, 0.31565502474447266`, 0.9340569609223726], 
             UndirectedEdge[25, 392] -> 
             RGBColor[
              0.26287272325527145`, 0.39362627760755575`, 0.9382815847528192],
              UndirectedEdge[73, 91] -> 
             RGBColor[
              0.5186112912140105, 0.6200710352367826, 0.9552461270615734], 
             UndirectedEdge[187, 464] -> 
             RGBColor[
              0.21185013288920307`, 0.3399983001137429, 0.9353759237126298], 
             UndirectedEdge[17, 99] -> 
             RGBColor[
              0.6775706975021587, 0.7419956614956686, 0.932197104376443], 
             UndirectedEdge[110, 157] -> 
             RGBColor[
              0.35808579273911467`, 0.4836854080233668, 0.944070557261417], 
             UndirectedEdge[241, 429] -> 
             RGBColor[
              0.20378953117845383`, 0.33152609664407884`, 0.9349168843697941],
              UndirectedEdge[27, 490] -> 
             RGBColor[
              0.20058973370860944`, 0.328162906624395, 0.9347346606375627], 
             UndirectedEdge[372, 418] -> 
             RGBColor[
              0.5453882435546948, 0.6418097714349063, 0.9573541068370404], 
             UndirectedEdge[65, 350] -> 
             RGBColor[
              0.18235178883730735`, 0.30899367021216395`, 0.9336960366577636],
              UndirectedEdge[189, 390] -> 
             RGBColor[
              0.25394291239181044`, 0.3842404802073483, 0.9377730452346162], 
             UndirectedEdge[263, 267] -> 
             RGBColor[
              0.22679757309850174`, 0.35570900749616285`, 0.9362271583197932],
              UndirectedEdge[25, 490] -> 
             RGBColor[
              0.25243138864291936`, 0.38265177291112284`, 0.937686966193216], 
             UndirectedEdge[360, 494] -> 
             RGBColor[
              0.4757330556093662, 0.5825992022016417, 0.9526059341461844], 
             UndirectedEdge[61, 203] -> 
             RGBColor[
              0.9176650400604409, 0.6688406301635299, 0.5009449661762736], 
             UndirectedEdge[36, 104] -> 
             RGBColor[
              0.9591316136436914, 0.8643779170894872, 0.5023662490620132], 
             UndirectedEdge[33, 241] -> 
             RGBColor[
              0.2359506605232252, 0.3653294827188087, 0.9367484131078517], 
             UndirectedEdge[82, 419] -> 
             RGBColor[
              0.5847042349028322, 0.6736221466676785, 0.9605217589523052], 
             UndirectedEdge[5, 404] -> 
             RGBColor[
              0.763201606478355, 0.8150742978846761, 0.9769963355615894], 
             UndirectedEdge[40, 396] -> 
             RGBColor[
              0.19122359622902446`, 0.31831850228593606`, 0.934201272964059], 
             UndirectedEdge[169, 369] -> 
             RGBColor[
              0.1829196441464267, 0.30959052214615446`, 0.9337283751775514], 
             UndirectedEdge[268, 491] -> 
             RGBColor[
              0.1839641739186956, 0.3106883891638218, 0.9337878596028387], 
             UndirectedEdge[4, 151] -> 
             RGBColor[
              0.19261261169346405`, 0.31977844560772906`, 0.9342803753398946],
              UndirectedEdge[6, 390] -> 
             RGBColor[
              0.23515410879898574`, 0.36449225635233673`, 0.9367030506655489],
              UndirectedEdge[376, 482] -> 
             RGBColor[
              0.35174044974950636`, 0.47908163140914517`, 0.9436335683195394],
              UndirectedEdge[158, 278] -> 
             RGBColor[
              0.18808568721102567`, 0.3150203609530965, 0.9340225736876044], 
             UndirectedEdge[317, 445] -> 
             RGBColor[
              0.8902189090551026, 0.5106901273758575, 0.23772100104764282`], 
             UndirectedEdge[133, 351] -> 
             RGBColor[
              0.21908548042585338`, 0.34760310912229214`, 0.9357879660511045],
              UndirectedEdge[239, 454] -> 
             RGBColor[
              0.20401834156350113`, 0.3317665908661798, 0.9349299147827279], 
             UndirectedEdge[140, 198] -> 
             RGBColor[
              0.18071298100430727`, 0.3072711792732629, 0.9336027089760732], 
             UndirectedEdge[252, 309] -> 
             RGBColor[
              0.18525140255303396`, 0.3120413480735207, 0.9338611653692801], 
             UndirectedEdge[161, 243] -> 
             RGBColor[
              0.20521495427576572`, 0.33302430669639793`, 0.9349980601064616],
              UndirectedEdge[244, 455] -> 
             RGBColor[
              0.5298831385666443, 0.6290429228301937, 0.9561829756631566], 
             UndirectedEdge[401, 451] -> 
             RGBColor[
              0.192907026989333, 0.3200878947506953, 0.934297141855446], 
             UndirectedEdge[210, 225] -> 
             RGBColor[
              0.189744388344664, 0.31676376101227643`, 0.9341170342633367], 
             UndirectedEdge[107, 223] -> 
             RGBColor[
              0.20973558752308613`, 0.3377757788640342, 0.935255503482219], 
             UndirectedEdge[5, 204] -> 
             RGBColor[
              0.502739716654951, 0.6027313328078459, 0.9555221120972213], 
             UndirectedEdge[59, 200] -> 
             RGBColor[
              0.26298567956392194`, 0.393745001849791, 0.9382880174474929], 
             UndirectedEdge[328, 481] -> 
             RGBColor[
              0.22412762819429155`, 0.3529027261175536, 0.9360751089073279], 
             UndirectedEdge[55, 434] -> 
             RGBColor[
              0.7543365484938672, 0.7225141411414309, 0.6130982348590022], 
             UndirectedEdge[269, 499] -> 
             RGBColor[
              0.615223353565316, 0.6985050597773825, 0.9628517825115135], 
             UndirectedEdge[377, 476] -> 
             RGBColor[
              0.18211083187288252`, 0.3087404091649995, 0.9336823145151034], 
             UndirectedEdge[260, 478] -> 
             RGBColor[
              0.22953226117284842`, 0.3585833380515396, 0.9363828947600188], 
             UndirectedEdge[163, 207] -> 
             RGBColor[
              0.8871477729139166, 0.5804462187569267, 0.227545674269207], 
             UndirectedEdge[238, 258] -> 
             RGBColor[
              0.4509349141328164, 0.5640927881888469, 0.9502045107268047], 
             UndirectedEdge[10, 443] -> 
             RGBColor[
              0.2573117613989959, 0.387781354111264, 0.9379648962018101], 
             UndirectedEdge[231, 326] -> 
             RGBColor[
              0.7445199877539495, 0.8003439400856498, 0.9751704525106033], 
             UndirectedEdge[91, 287] -> 
             RGBColor[
              0.38223901787712034`, 0.5048831468883692, 0.9456450183489318], 
             UndirectedEdge[242, 249] -> 
             RGBColor[
              0.8500313217686346, 0.8830430785885436, 0.951908121903962], 
             UndirectedEdge[83, 209] -> 
             RGBColor[
              0.9948514855705746, 0.9921389712197164, 0.7349877382312089], 
             UndirectedEdge[306, 431] -> 
             RGBColor[
              0.33101101797964355`, 0.4548419980464291, 0.9425428260902121], 
             UndirectedEdge[176, 376] -> 
             RGBColor[
              0.34402119360606, 0.47239559971878675`, 0.9431417041439492], 
             UndirectedEdge[30, 191] -> 
             RGBColor[
              0.18476529609045284`, 0.31153041936041803`, 0.9338334823253662],
              UndirectedEdge[209, 444] -> 
             RGBColor[
              0.7801701048240467, 0.8252083695679635, 0.8500873938895259], 
             UndirectedEdge[169, 289] -> 
             RGBColor[
              0.19694268883638122`, 0.3243296312276827, 0.9345269668274088], 
             UndirectedEdge[20, 46] -> 
             RGBColor[
              0.22273395828831882`, 0.35143789068260056`, 0.9359957414679326],
              UndirectedEdge[49, 100] -> 
             RGBColor[
              0.9935759076270685, 0.9886678409266986, 0.5421553739880537], 
             UndirectedEdge[404, 486] -> 
             RGBColor[
              0.6250807725270684, 0.7025792478220061, 0.9659283941437955], 
             UndirectedEdge[103, 431] -> 
             RGBColor[
              0.415528043094357, 0.534331238706793, 0.9476980573623193], 
             UndirectedEdge[219, 238] -> 
             RGBColor[
              0.5781077146635654, 0.6679567426795029, 0.9602144407477138], 
             UndirectedEdge[249, 499] -> 
             RGBColor[
              0.6777613007469594, 0.7479803602752079, 0.9686609595995643], 
             UndirectedEdge[254, 377] -> 
             RGBColor[
              0.18661056292735312`, 0.3134699118026751, 0.9339385675419001], 
             UndirectedEdge[57, 434] -> 
             RGBColor[
              0.9488603570213409, 0.87598930982866, 0.6073727486571113], 
             UndirectedEdge[75, 104] -> 
             RGBColor[
              0.894725030806556, 0.6091192249245418, 0.23357173327544747`], 
             UndirectedEdge[132, 365] -> 
             RGBColor[
              0.23967912019619636`, 0.3692483302330984, 0.9369607433704656], 
             UndirectedEdge[38, 77] -> 
             RGBColor[
              0.4266438929830485, 0.5421807004439456, 0.9488977622771873], 
             UndirectedEdge[172, 314] -> 
             RGBColor[
              0.24315002922466572`, 0.37289647569036266`, 0.9371584065048872],
              UndirectedEdge[398, 481] -> 
             RGBColor[
              0.20576395571267658`, 0.3336013420152928, 0.9350293249261188], 
             UndirectedEdge[143, 165] -> 
             RGBColor[
              0.4432891969739572, 0.5546584690453142, 0.950431811201746], 
             UndirectedEdge[261, 475] -> 
             RGBColor[
              0.3329106779769486, 0.46277222951160313`, 0.9424337519127055], 
             UndirectedEdge[288, 373] -> 
             RGBColor[
              0.8511114942630649, 0.882439252848601, 0.8853377053514828], 
             UndirectedEdge[78, 171] -> 
             RGBColor[
              0.47037777522198154`, 0.5809128940593202, 0.9514490079974901], 
             UndirectedEdge[6, 370] -> 
             RGBColor[
              0.22157715427768293`, 0.35022201632181177`, 0.935929863190865], 
             UndirectedEdge[264, 295] -> 
             RGBColor[
              0.9251699045349664, 0.7351644032002858, 0.5555767619873893], 
             UndirectedEdge[45, 464] -> 
             RGBColor[
              0.2018156680778671, 0.3294514413752133, 0.9348044757862846], 
             UndirectedEdge[228, 318] -> 
             RGBColor[
              0.22809876360932468`, 0.35707664122328114`, 0.9363012591944456],
              UndirectedEdge[7, 295] -> 
             RGBColor[
              0.7285749695983985, 0.7852490192213029, 0.9266196187062239], 
             UndirectedEdge[225, 320] -> 
             RGBColor[
              0.1825517796800877, 0.30920387326807797`, 0.9337074258404], 
             UndirectedEdge[137, 148] -> 
             RGBColor[
              0.24314559520540308`, 0.3728918152549845, 0.9371581539940498], 
             UndirectedEdge[61, 455] -> 
             RGBColor[
              0.8016518216680615, 0.8434880657223675, 0.8868884028153723], 
             UndirectedEdge[11, 331] -> 
             RGBColor[
              0.3385041946670758, 0.46694107593320344`, 0.9428149166646195], 
             UndirectedEdge[20, 392] -> 
             RGBColor[
              0.2393040747004234, 0.36885413363778313`, 0.9369393850843115], 
             UndirectedEdge[348, 431] -> 
             RGBColor[
              0.44166621655022387`, 0.5567328899534418, 0.9494292969038062], 
             UndirectedEdge[241, 351] -> 
             RGBColor[
              0.22791016546505544`, 0.3568784126158412, 0.9362905188091355], 
             UndirectedEdge[343, 374] -> 
             RGBColor[
              0.8468374551199298, 0.3610187811212927, 0.19248490595917145`], 
             UndirectedEdge[162, 389] -> 
             RGBColor[
              0.18912373753009853`, 0.3161114176546337, 0.9340816891176178], 
             UndirectedEdge[207, 266] -> 
             RGBColor[
              0.9342851916423655, 0.7569554226506068, 0.3801831663512317], 
             UndirectedEdge[98, 425] -> 
             RGBColor[
              0.1874902819867422, 0.31439455231150293`, 0.9339886662409045], 
             UndirectedEdge[151, 284] -> 
             RGBColor[
              0.20527167990556933`, 0.33308392892993416`, 0.9350012905471609],
              UndirectedEdge[41, 365] -> 
             RGBColor[
              0.23506566561189032`, 0.36439929695507756`, 0.9366980139568839],
              UndirectedEdge[436, 473] -> 
             RGBColor[
              0.30955738588181175`, 0.4383701601543446, 0.9410985541344632], 
             UndirectedEdge[311, 405] -> 
             RGBColor[
              0.18582191019465255`, 0.3126409877771355, 0.9338936549354799], 
             UndirectedEdge[235, 432] -> 
             RGBColor[
              0.25417547246619693`, 0.38448491559068887`, 0.9377862891868108],
              UndirectedEdge[109, 474] -> 
             RGBColor[
              0.22157473772172553`, 0.350219476368282, 0.9359297255715783], 
             UndirectedEdge[364, 468] -> 
             RGBColor[
              0.21294670143418915`, 0.3411508631809846, 0.9354383716690389], 
             UndirectedEdge[203, 374] -> 
             RGBColor[
              0.8462576720826371, 0.35656231463411475`, 0.19192970506788876`],
              UndirectedEdge[36, 112] -> 
             RGBColor[
              0.993786491132969, 0.9916985686506579, 0.7526374521795876], 
             UndirectedEdge[324, 342] -> 
             RGBColor[
              0.7080228667800735, 0.7701523632700238, 0.969408565667581], 
             UndirectedEdge[374, 445] -> 
             RGBColor[
              0.9052815581912046, 0.6264682491308763, 0.2521450108712031], 
             UndirectedEdge[2, 327] -> 
             RGBColor[
              0.18398683108609262`, 0.3107122032833034, 0.9337891498950037], 
             UndirectedEdge[128, 438] -> 
             RGBColor[
              0.19844895166515433`, 0.32591280896330255`, 0.9346127462671912],
              UndirectedEdge[33, 460] -> 
             RGBColor[
              0.27847248938800495`, 0.41002262089535824`, 0.9391699683562924],
              UndirectedEdge[298, 335] -> 
             RGBColor[
              0.2430317898200987, 0.3727721985793514, 0.9371516729457167], 
             UndirectedEdge[112, 343] -> 
             RGBColor[
              0.91983604495667, 0.6739551077819146, 0.4751295029148105], 
             UndirectedEdge[106, 265] -> 
             RGBColor[
              0.18198502195137928`, 0.3086081749606899, 0.933675149826193], 
             UndirectedEdge[19, 468] -> 
             RGBColor[
              0.21235962003857659`, 0.3405338034110854, 0.9354049382520679], 
             UndirectedEdge[161, 202] -> 
             RGBColor[
              0.2003053984953046, 0.32786405228731785`, 0.9347184681678012], 
             UndirectedEdge[204, 390] -> 
             RGBColor[
              0.2859084769887601, 0.4171765863589087, 0.9396176659888837], 
             UndirectedEdge[211, 289] -> 
             RGBColor[
              0.19877803112005593`, 0.32625869233524674`, 0.9346314868553184],
              UndirectedEdge[48, 479] -> 
             RGBColor[
              0.18610061058204452`, 0.31293391955490957`, 0.9339095265102416],
              UndirectedEdge[57, 495] -> 
             RGBColor[
              0.9243664441871663, 0.7736553444054359, 0.5873941515896481], 
             UndirectedEdge[10, 280] -> 
             RGBColor[
              0.24013030719270134`, 0.36972255637333296`, 0.9369864378024453],
              UndirectedEdge[206, 476] -> 
             RGBColor[
              0.18192213006975788`, 0.30854207160553015`, 0.9336715682265748],
              UndirectedEdge[13, 256] -> 
             RGBColor[
              0.2822514185299613, 0.41373456987075796`, 0.9393946906458437], 
             UndirectedEdge[184, 221] -> 
             RGBColor[
              0.7515553610831588, 0.7612606169042988, 0.6324712276878893], 
             UndirectedEdge[126, 282] -> 
             RGBColor[
              0.5925848442263562, 0.6792934576295336, 0.9616388769267687], 
             UndirectedEdge[53, 266] -> 
             RGBColor[
              0.9131290173800801, 0.6204205778411838, 0.36094524797198546`], 
             UndirectedEdge[194, 220] -> 
             RGBColor[
              0.20157018632549908`, 0.32919342448903244`, 0.9347904959636448],
              UndirectedEdge[375, 417] -> 
             RGBColor[
              0.1999369421366619, 0.32747678129290203`, 0.9346974851232589], 
             UndirectedEdge[245, 448] -> 
             RGBColor[
              0.272254633728537, 0.40348726036243854`, 0.9388158706749788], 
             UndirectedEdge[79, 147] -> 
             RGBColor[
              0.8526636417246913, 0.529899304242684, 0.5774584339898925], 
             UndirectedEdge[77, 253] -> 
             RGBColor[
              0.35598021511374034`, 0.4827539030708413, 0.9439037224194711], 
             UndirectedEdge[180, 205] -> 
             RGBColor[
              0.2503131812646099, 0.38042540265441493`, 0.9375663374166283], 
             UndirectedEdge[28, 432] -> 
             RGBColor[
              0.38353725752998075`, 0.5043916701363219, 0.9458878966543498], 
             UndirectedEdge[84, 245] -> 
             RGBColor[
              0.25972033738633343`, 0.39031292018649366`, 0.9381020610411201],
              UndirectedEdge[19, 459] -> 
             RGBColor[
              0.1988488542772136, 0.32633313196386693`, 0.934635520129345], 
             UndirectedEdge[153, 236] -> 
             RGBColor[
              0.21799828044158207`, 0.3464603930063626, 0.9357260516203685], 
             UndirectedEdge[315, 349] -> 
             RGBColor[
              0.18430254906177113`, 0.31104404289341736`, 0.9338071295666557],
              UndirectedEdge[18, 460] -> 
             RGBColor[
              0.2944934860338214, 0.4268617041599678, 0.940082340414331], 
             UndirectedEdge[126, 449] -> 
             RGBColor[
              0.7360314578812237, 0.7759766732200013, 0.6718437842469422], 
             UndirectedEdge[49, 324] -> 
             RGBColor[
              0.9668288479321837, 0.9719938689278773, 0.783522492339073], 
             UndirectedEdge[334, 415] -> 
             RGBColor[
              0.18362714398561458`, 0.31033414933522163`, 0.9337686662467408],
              UndirectedEdge[5, 444] -> 
             RGBColor[
              0.627720184984083, 0.7079272421970324, 0.964330108694589], 
             UndirectedEdge[147, 449] -> 
             RGBColor[
              0.9013434874873846, 0.5520144216865974, 0.2783600016823526], 
             UndirectedEdge[254, 426] -> 
             RGBColor[
              0.189893219466744, 0.3169201919580207, 0.9341255099755632], 
             UndirectedEdge[186, 321] -> 
             RGBColor[
              0.9893791898196398, 0.9881862286508462, 0.7028466634493613], 
             UndirectedEdge[260, 399] -> 
             RGBColor[
              0.20881488896675832`, 0.33680806630567356`, 0.9352030710614876],
              UndirectedEdge[184, 287] -> 
             RGBColor[
              0.42249467395537876`, 0.5375645019893394, 0.9488140910567393], 
             UndirectedEdge[129, 431] -> 
             RGBColor[
              0.35531389648617895`, 0.48038586424829277`, 0.9439268390682725],
              UndirectedEdge[300, 432] -> 
             RGBColor[
              0.26154815956156724`, 0.39223407718328385`, 0.938206152809979], 
             UndirectedEdge[207, 293] -> 
             RGBColor[
              0.8423679493594973, 0.6882641451078306, 0.5995351479132809], 
             UndirectedEdge[118, 399] -> 
             RGBColor[
              0.200045010570769, 0.32759036806908304`, 0.9347036394607084], 
             UndirectedEdge[138, 179] -> 
             RGBColor[
              0.19144105687703156`, 0.31854706721479287`, 0.9342136570262589],
              UndirectedEdge[40, 161] -> 
             RGBColor[
              0.19942966903054987`, 0.32694360509540565`, 0.9346685966703091],
              UndirectedEdge[243, 279] -> 
             RGBColor[
              0.20228104719014361`, 0.3299405843289558, 0.934830978438262], 
             UndirectedEdge[69, 233] -> 
             RGBColor[
              0.7027067996446262, 0.7647987322711527, 0.9488520571207084], 
             UndirectedEdge[237, 460] -> 
             RGBColor[
              0.26678188416083737`, 0.3977350535744224, 0.9385042056833057], 
             UndirectedEdge[54, 295] -> 
             RGBColor[
              0.9871607004637972, 0.988958633933902, 0.862443950564356], 
             UndirectedEdge[102, 210] -> 
             RGBColor[
              0.19748304019874757`, 0.324897574769785, 0.9345577390381172], 
             UndirectedEdge[137, 156] -> 
             RGBColor[
              0.2055253114742025, 0.33335051178973785`, 0.9350157344897803], 
             UndirectedEdge[231, 444] -> 
             RGBColor[
              0.664761024690349, 0.7368638276963759, 0.9680219934301821], 
             UndirectedEdge[383, 393] -> 
             RGBColor[
              0.24454516184141023`, 0.374362848527078, 0.9372378572434972], 
             UndirectedEdge[43, 137] -> 
             RGBColor[
              0.220012218727478, 0.34857716983590165`, 0.9358407424263956], 
             UndirectedEdge[233, 348] -> 
             RGBColor[
              0.7123189222990802, 0.7728863489370825, 0.9495302713185423], 
             UndirectedEdge[193, 410] -> 
             RGBColor[
              0.1815860257697589, 0.30818880467598786`, 0.9336524275839118], 
             UndirectedEdge[126, 384] -> 
             RGBColor[
              0.3782656319739345, 0.49734201260730226`, 0.9457250298186803], 
             UndirectedEdge[162, 345] -> 
             RGBColor[
              0.1870835559314184, 0.31396705743943626`, 0.9339655037937511], 
             UndirectedEdge[165, 178] -> 
             RGBColor[
              0.3876179844694684, 0.5094620707746275, 0.9460491694230218], 
             UndirectedEdge[154, 455] -> 
             RGBColor[
              0.7982558492888101, 0.8419633098945049, 0.937775174104184], 
             UndirectedEdge[211, 470] -> 
             RGBColor[
              0.19104848384555853`, 0.31813444806814695`, 0.9341913005728761],
              UndirectedEdge[201, 305] -> 
             RGBColor[
              0.2840031755926752, 0.41566850052882615`, 0.9394910555788545], 
             UndirectedEdge[220, 474] -> 
             RGBColor[
              0.22327343139036823`, 0.3520049111174247, 0.9360264636630153], 
             UndirectedEdge[125, 173] -> 
             RGBColor[
              0.7492734803038996, 0.8040574045935522, 0.9756442362240689], 
             UndirectedEdge[189, 443] -> 
             RGBColor[
              0.2699043575235971, 0.40101697105492856`, 0.9386820259220295], 
             UndirectedEdge[307, 500] -> 
             RGBColor[
              0.19638085260421678`, 0.3237391057252033, 0.9344949710851491], 
             UndirectedEdge[102, 134] -> 
             RGBColor[
              0.1917868632444325, 0.31891053163232136`, 0.9342333501873077], 
             UndirectedEdge[102, 174] -> 
             RGBColor[
              0.1934597999069662, 0.32066889413495503`, 0.934328621455351], 
             UndirectedEdge[203, 281] -> 
             RGBColor[
              0.8317474856787275, 0.2450306635294393, 0.1780347341805933], 
             UndirectedEdge[279, 421] -> 
             RGBColor[
              0.19615975110811917`, 0.3235067140341602, 0.9344823796820367], 
             UndirectedEdge[335, 430] -> 
             RGBColor[
              0.2059656395327683, 0.33381332449770196`, 0.9350408105213086], 
             UndirectedEdge[69, 431] -> 
             RGBColor[
              0.4320540938957698, 0.548645273287512, 0.9487510827059723], 
             UndirectedEdge[149, 249] -> 
             RGBColor[
              0.6440396780590834, 0.7206036278354, 0.9660062699352006], 
             UndirectedEdge[141, 345] -> 
             RGBColor[
              0.19907503548324326`, 0.3265708627521209, 0.9346484008144234], 
             UndirectedEdge[12, 283] -> 
             RGBColor[
              0.18817638831560224`, 0.31511569356478863`, 0.9340277389813298],
              UndirectedEdge[119, 381] -> 
             RGBColor[
              0.18630903659373593`, 0.3131529885081697, 0.9339213960632688], 
             UndirectedEdge[396, 430] -> 
             RGBColor[
              0.19949732248348956`, 0.32701471316392194`, 0.9346724494343697],
              UndirectedEdge[49, 360] -> 
             RGBColor[
              0.7950442531705986, 0.8362229179981473, 0.7707477142317521], 
             UndirectedEdge[208, 497] -> 
             RGBColor[
              0.4523984541828804, 0.5655914141074888, 0.9502339454421076], 
             UndirectedEdge[275, 444] -> 
             RGBColor[
              0.5275882362182631, 0.6273589235979986, 0.9559528250559413], 
             UndirectedEdge[269, 323] -> 
             RGBColor[
              0.7972919842565633, 0.8394603962804845, 0.8661383017091098], 
             UndirectedEdge[273, 279] -> 
             RGBColor[
              0.19757076585955963`, 0.32498978000142653`, 0.9345627348847221],
              UndirectedEdge[107, 289] -> 
             RGBColor[
              0.21067973016305835`, 0.3387681326407459, 0.9353092710088315], 
             UndirectedEdge[289, 314] -> 
             RGBColor[
              0.23644046461492338`, 0.36584429787455663`, 0.9367763067262738],
              UndirectedEdge[6, 428] -> 
             RGBColor[
              0.2010842377589775, 0.3286826617346995, 0.9347628219116779], 
             UndirectedEdge[7, 17] -> 
             RGBColor[
              0.4238987520286698, 0.5410646532335288, 0.9483742450361144], 
             UndirectedEdge[309, 424] -> 
             RGBColor[
              0.19083388775165383`, 0.3179088939672749, 0.9341790796427948], 
             UndirectedEdge[128, 385] -> 
             RGBColor[
              0.1879057798305126, 0.31483126688939045`, 0.9340123282284333], 
             UndirectedEdge[71, 362] -> 
             RGBColor[
              0.1884877837309814, 0.3154429898899618, 0.9340454724895675], 
             UndirectedEdge[43, 156] -> 
             RGBColor[
              0.21388174499134507`, 0.34213365324474115`, 0.935491621016346], 
             UndirectedEdge[59, 298] -> 
             RGBColor[
              0.2693422110049278, 0.4004261194216593, 0.9386500125094126], 
             UndirectedEdge[261, 455] -> 
             RGBColor[
              0.47116868386026034`, 0.5781874132378237, 0.9524417425284195], 
             UndirectedEdge[17, 89] -> 
             RGBColor[
              0.3425624838836552, 0.4711321386741221, 0.9430487564503239], 
             UndirectedEdge[9, 68] -> 
             RGBColor[
              0.18960972675890758`, 0.3166222231476087, 0.9341093654852418], 
             UndirectedEdge[73, 298] -> 
             RGBColor[
              0.42629344369918076`, 0.5372437988360448, 0.949423062513614], 
             UndirectedEdge[16, 333] -> 
             RGBColor[
              0.25095246372984137`, 0.3810973290582225, 0.9376027436072896], 
             UndirectedEdge[257, 445] -> 
             RGBColor[
              0.9630857175869136, 0.8871415989142806, 0.3110954128128076], 
             UndirectedEdge[428, 451] -> 
             RGBColor[
              0.19643038781423483`, 0.323791170371646, 0.934497792042079], 
             UndirectedEdge[15, 419] -> 
             RGBColor[
              0.6508464250830497, 0.7271654409816981, 0.9658339472127815], 
             UndirectedEdge[17, 313] -> 
             RGBColor[
              0.3683319514339016, 0.4934523562550466, 0.9446907641355802], 
             UndirectedEdge[5, 326] -> 
             RGBColor[
              0.7074791480476834, 0.7714073545863063, 0.9714785677750102], 
             UndirectedEdge[216, 217] -> 
             RGBColor[
              0.1905787639681844, 0.31764074269506637`, 0.9341645507207481], 
             UndirectedEdge[138, 222] -> 
             RGBColor[
              0.1899361610003327, 0.31696532623247287`, 0.9341279554323748], 
             UndirectedEdge[251, 447] -> 
             RGBColor[
              0.23632980233893142`, 0.3657279848060955, 0.9367700046733661], 
             UndirectedEdge[58, 144] -> 
             RGBColor[
              0.1950230989335921, 0.322312020530822, 0.9344176490222236], 
             UndirectedEdge[11, 404] -> 
             RGBColor[
              0.6062003014417219, 0.6862259327279479, 0.9647253472215822], 
             UndirectedEdge[270, 329] -> 
             RGBColor[
              0.18084643102754924`, 0.3074114437089104, 0.9336103087574752], 
             UndirectedEdge[314, 406] -> 
             RGBColor[
              0.3396550578396198, 0.4643665868457374, 0.9430190117624826], 
             UndirectedEdge[13, 409] -> 
             RGBColor[
              0.2530894600625647, 0.3833434476973081, 0.9377244423870355], 
             UndirectedEdge[279, 335] -> 
             RGBColor[
              0.20917892656929465`, 0.33719069290725634`, 0.9352238024644066],
              UndirectedEdge[195, 446] -> 
             RGBColor[
              0.1857509853248722, 0.31256644124209987`, 0.9338896158690699], 
             UndirectedEdge[22, 170] -> 
             RGBColor[
              0.18476666722380106`, 0.3115318605085019, 0.9338335604093819], 
             UndirectedEdge[159, 166] -> 
             RGBColor[
              0.21389899734106987`, 0.3421517865581641, 0.9354926035121403], 
             UndirectedEdge[59, 87] -> 
             RGBColor[
              0.28570409751894754`, 0.41762349955141664`, 0.939581797741144], 
             UndirectedEdge[176, 407] -> 
             RGBColor[
              0.2970315342752855, 0.4287723651208341, 0.94025459557011], 
             UndirectedEdge[169, 470] -> 
             RGBColor[
              0.1892131415618838, 0.316205386960583, 0.9340867805449665], 
             UndirectedEdge[13, 188] -> 
             RGBColor[
              0.23846099400411988`, 0.36796800237156463`, 0.9368913728858832],
              UndirectedEdge[273, 396] -> 
             RGBColor[
              0.19229860014365638`, 0.3194483995593991, 0.9342624928466716], 
             UndirectedEdge[30, 405] -> 
             RGBColor[
              0.1802965998650839, 0.3068335362958501, 0.9335789966861752], 
             UndirectedEdge[258, 497] -> 
             RGBColor[
              0.44668148609611025`, 0.5606396636938994, 0.9498696652909349], 
             UndirectedEdge[90, 485] -> 
             RGBColor[
              0.25884791756577036`, 0.3893959516404705, 0.9380523780229685], 
             UndirectedEdge[89, 455] -> 
             RGBColor[
              0.4613630510985772, 0.5696942669850865, 0.9518169362796256], 
             UndirectedEdge[422, 451] -> 
             RGBColor[
              0.20581343032131297`, 0.33365334296584104`, 0.9350321424318895],
              UndirectedEdge[99, 178] -> 
             RGBColor[
              0.7245036529888805, 0.7822124250066672, 0.9353076025507647], 
             UndirectedEdge[119, 416] -> 
             RGBColor[
              0.19677397614642037`, 0.32415230349353147`, 0.9345173588893034],
              UndirectedEdge[129, 204] -> 
             RGBColor[
              0.3026394845996296, 0.4347619361650844, 0.9405704721210151], 
             UndirectedEdge[1, 381] -> 
             RGBColor[
              0.1937883174344935, 0.32101418688560046`, 0.9343473300425454], 
             UndirectedEdge[287, 409] -> 
             RGBColor[
              0.2786937259844361, 0.4102551545854176, 0.9391825674531689], 
             UndirectedEdge[340, 384] -> 
             RGBColor[
              0.3159339914529744, 0.4443075647988586, 0.9414896959063039], 
             UndirectedEdge[233, 379] -> 
             RGBColor[
              0.8949909626419136, 0.5916992159390957, 0.5610798957464819], 
             UndirectedEdge[1, 124] -> 
             RGBColor[
              0.1923231620506201, 0.3194742156809328, 0.934263891610937], 
             UndirectedEdge[134, 309] -> 
             RGBColor[
              0.18616361548114224`, 0.31300014169860263`, 0.9339131145460378],
              UndirectedEdge[1, 380] -> 
             RGBColor[
              0.19337326869879815`, 0.3205779443487749, 0.9343236936310573], 
             UndirectedEdge[112, 403] -> 
             RGBColor[
              0.8684251833169994, 0.8955159189410955, 0.8667074610489753], 
             UndirectedEdge[214, 268] -> 
             RGBColor[
              0.186923339851059, 0.31379866018069236`, 0.9339563797249931], 
             UndirectedEdge[404, 444] -> 
             RGBColor[
              0.7013455249659886, 0.7655800526301657, 0.9716322684022551], 
             UndirectedEdge[252, 320] -> 
             RGBColor[
              0.18172265320945252`, 0.3083324087777858, 0.93366020831448], 
             UndirectedEdge[173, 419] -> 
             RGBColor[
              0.6849417616486415, 0.753800977040894, 0.9692322517226041], 
             UndirectedEdge[407, 475] -> 
             RGBColor[
              0.3068290918915676, 0.4372585170884935, 0.9408788872777796], 
             UndirectedEdge[167, 305] -> 
             RGBColor[
              0.27520889494048634`, 0.4064251539737775, 0.9389902343056846], 
             UndirectedEdge[407, 482] -> 
             RGBColor[
              0.3047507904187318, 0.43545839681119247`, 0.9407464597457003], 
             UndirectedEdge[197, 493] -> 
             RGBColor[
              0.24589919103084765`, 0.37578601905558584`, 0.9373149672027289],
              UndirectedEdge[235, 300] -> 
             RGBColor[
              0.22449059247181202`, 0.353284224586492, 0.9360957791859752], 
             UndirectedEdge[312, 385] -> 
             RGBColor[
              0.1882621822827025, 0.31520586846386267`, 0.9340326248208353], 
             UndirectedEdge[188, 318] -> 
             RGBColor[
              0.21097876418895464`, 0.3390824363618151, 0.935326300554225], 
             UndirectedEdge[71, 153] -> 
             RGBColor[
              0.21268791512647112`, 0.34087886236357334`, 0.9354236341716544],
              UndirectedEdge[45, 481] -> 
             RGBColor[
              0.20322304481879772`, 0.33093068356277056`, 0.9348846238096533],
              UndirectedEdge[53, 317] -> 
             RGBColor[
              0.8249968310509084, 0.19314217390430075`, 0.1715702996852197], 
             UndirectedEdge[253, 301] -> 
             RGBColor[
              0.5169703257345344, 0.6164641572661, 0.9558333707121969], 
             UndirectedEdge[442, 447] -> 
             RGBColor[
              0.23581693788510275`, 0.36518893174763706`, 0.9367407978014356],
              UndirectedEdge[118, 464] -> 
             RGBColor[
              0.1973325308094801, 0.3247393798588184, 0.9345491677510571], 
             UndirectedEdge[2, 118] -> 
             RGBColor[
              0.18820276986646162`, 0.31514342224742875`, 0.9340292413716232],
              UndirectedEdge[332, 454] -> 
             RGBColor[
              0.19901001769354992`, 0.3265025249327872, 0.9346446981474854], 
             UndirectedEdge[84, 455] -> 
             RGBColor[
              0.4442800341977758, 0.5518254258243921, 0.9508409168167211], 
             UndirectedEdge[423, 488] -> 
             RGBColor[
              0.18086431186395144`, 0.3074302376016796, 0.933611327044656], 
             UndirectedEdge[5, 231] -> 
             RGBColor[
              0.7266171062027156, 0.7863580729508864, 0.9733860605895166], 
             UndirectedEdge[121, 337] -> 
             RGBColor[
              0.19710919882017952`, 0.3245046437779975, 0.9345364493246566], 
             UndirectedEdge[23, 360] -> 
             RGBColor[
              0.5140568870299039, 0.6157933787663372, 0.9550478947958676], 
             UndirectedEdge[79, 336] -> 
             RGBColor[
              0.7557987774112169, 0.8094300480703478, 0.9763306281365505], 
             UndirectedEdge[237, 371] -> 
             RGBColor[
              0.24348618176994377`, 0.3732497933287522, 0.9371775498950476], 
             UndirectedEdge[9, 330] -> 
             RGBColor[
              0.19168631998098046`, 0.3188048542876222, 0.9342276243971945], 
             UndirectedEdge[76, 111] -> 
             RGBColor[
              0.3885098195301592, 0.510929411430886, 0.9459764800480857], 
             UndirectedEdge[91, 256] -> 
             RGBColor[
              0.3859408633418989, 0.5085140760316679, 0.9458653508371028], 
             UndirectedEdge[35, 193] -> 
             RGBColor[
              0.1842865051954063, 0.311027179772628, 0.9338062158922009], 
             UndirectedEdge[43, 267] -> 
             RGBColor[
              0.22881279968486046`, 0.35782713841117125`, 0.9363419224926257],
              UndirectedEdge[261, 448] -> 
             RGBColor[
              0.314938405291928, 0.4464509223622935, 0.9413162052121451], 
             UndirectedEdge[322, 374] -> 
             RGBColor[
              0.8341132720585396, 0.26321513433887644`, 0.18030021388967482`],
              UndirectedEdge[76, 130] -> 
             RGBColor[
              0.3566736138347697, 0.4828157529154782, 0.9439676309835814], 
             UndirectedEdge[107, 153] -> 
             RGBColor[
              0.21946182531602942`, 0.3479986714635114, 0.9358093983358476], 
             UndirectedEdge[410, 437] -> 
             RGBColor[
              0.1820838890101732, 0.30871209050801585`, 0.9336807801589306], 
             UndirectedEdge[11, 164] -> 
             RGBColor[
              0.3457994968745498, 0.4739358766298315, 0.9432550160557256], 
             UndirectedEdge[213, 500] -> 
             RGBColor[
              0.2016031036308693, 0.32922802266405415`, 0.934792370555489], 
             UndirectedEdge[251, 454] -> 
             RGBColor[
              0.22516117799061744`, 0.3539890524843341, 0.9361339680392287], 
             UndirectedEdge[111, 483] -> 
             RGBColor[
              0.4093161482374549, 0.528950807600658, 0.9473022409150004], 
             UndirectedEdge[5, 233] -> 
             RGBColor[
              0.8260668342903568, 0.864508719874695, 0.9589794534592146], 
             UndirectedEdge[69, 372] -> 
             RGBColor[
              0.5285636967606093, 0.627866783936419, 0.9561081041909547], 
             UndirectedEdge[454, 489] -> 
             RGBColor[
              0.20150669956748674`, 0.32912669588106847`, 0.9347868804866963],
              UndirectedEdge[289, 493] -> 
             RGBColor[
              0.235488823391288, 0.36484406261097735`, 0.9367221121664148], 
             UndirectedEdge[74, 268] -> 
             RGBColor[
              0.18750418807117342`, 0.3144091684879368, 0.9339894581718406], 
             UndirectedEdge[192, 258] -> 
             RGBColor[
              0.36408500922956, 0.4897738683751677, 0.944420152733743], 
             UndirectedEdge[68, 368] -> 
             RGBColor[
              0.18232969627571796`, 0.3089704495291842, 0.9336947785190641], 
             UndirectedEdge[50, 414] -> 
             RGBColor[
              0.6515149605889788, 0.7239780646853934, 0.9683019767918029], 
             UndirectedEdge[358, 441] -> 
             RGBColor[
              0.22317531852257919`, 0.3519017882726634, 0.9360208762803397], 
             UndirectedEdge[71, 289] -> 
             RGBColor[
              0.20390581997350005`, 0.33164832354080787`, 0.9349235068446382],
              UndirectedEdge[54, 321] -> 
             RGBColor[
              0.9874803221287802, 0.9890908057062746, 0.8571469924212342], 
             UndirectedEdge[75, 408] -> 
             RGBColor[
              0.9013012276585859, 0.7170355167790632, 0.6001882350839804], 
             UndirectedEdge[8, 239] -> 
             RGBColor[
              0.19706547094004007`, 0.32445868300346314`, 0.9345339590865722],
              UndirectedEdge[389, 472] -> 
             RGBColor[
              0.18902863113306126`, 0.3160114548012536, 0.9340762729490037], 
             UndirectedEdge[178, 475] -> 
             RGBColor[
              0.40291899149679977`, 0.5229757083496808, 0.9470145914961603], 
             UndirectedEdge[332, 489] -> 
             RGBColor[
              0.1891243849825443, 0.31611209816820496`, 0.9340817259890768], 
             UndirectedEdge[28, 406] -> 
             RGBColor[
              0.44617181476977985`, 0.5602617683644892, 0.9498196286740023], 
             UndirectedEdge[77, 87] -> 
             RGBColor[
              0.32144010648392174`, 0.4528061418339081, 0.9417039869994168], 
             UndirectedEdge[274, 300] -> 
             RGBColor[
              0.23797382817444995`, 0.36745596019648397`, 0.9368636295125807],
              UndirectedEdge[330, 333] -> 
             RGBColor[
              0.210684466253447, 0.33877311057202975`, 0.9353095407221728], 
             UndirectedEdge[325, 490] -> 
             RGBColor[
              0.22480172486171077`, 0.3536112444552085, 0.9361134977153007], 
             UndirectedEdge[420, 489] -> 
             RGBColor[
              0.189832836442401, 0.3168567255709313, 0.9341220712516556], 
             UndirectedEdge[271, 304] -> 
             RGBColor[
              0.19940240032278655`, 0.3269149439546105, 0.9346670437577425], 
             UndirectedEdge[166, 387] -> 
             RGBColor[
              0.19228627737083037`, 0.31943544754385, 0.934261791082989], 
             UndirectedEdge[16, 165] -> 
             RGBColor[
              0.28802163997316926`, 0.4200593836114821, 0.9397137783554151], 
             UndirectedEdge[44, 356] -> 
             RGBColor[
              0.262163357709175, 0.39288068944223503`, 0.9382411874343812], 
             UndirectedEdge[86, 377] -> 
             RGBColor[
              0.18305173765274474`, 0.30972936079650676`, 0.9337358977073213],
              UndirectedEdge[113, 353] -> 
             RGBColor[
              0.1887122478968889, 0.3156789159601807, 0.9340582553917509], 
             UndirectedEdge[63, 222] -> 
             RGBColor[
              0.20195670404025598`, 0.32959967911388044`, 0.9348125075756986],
              UndirectedEdge[71, 493] -> 
             RGBColor[
              0.2293216757786306, 0.35836199945033154`, 0.9363709022333513], 
             UndirectedEdge[106, 270] -> 
             RGBColor[
              0.17988066425974236`, 0.3063963616027956, 0.9335553097687725], 
             UndirectedEdge[414, 498] -> 
             RGBColor[
              0.5986264598736242, 0.6821731423501425, 0.9631600517720931], 
             UndirectedEdge[46, 220] -> 
             RGBColor[
              0.21037184686789395`, 0.33844452777659967`, 0.9352917375106444],
              UndirectedEdge[302, 443] -> 
             RGBColor[
              0.2662987639830351, 0.3972272636359636, 0.9384766927038922], 
             UndirectedEdge[90, 267] -> 
             RGBColor[
              0.24580395513477205`, 0.37568592009050583`, 0.9373095436593363],
              UndirectedEdge[116, 187] -> 
             RGBColor[
              0.24886259772016034`, 0.3789007473768896, 0.9374837288297179], 
             UndirectedEdge[162, 472] -> 
             RGBColor[
              0.18323095336378353`, 0.30991772787174093`, 0.933746103776939], 
             UndirectedEdge[271, 371] -> 
             RGBColor[
              0.23108898271360306`, 0.3602195510927192, 0.9364715477488016], 
             UndirectedEdge[84, 478] -> 
             RGBColor[
              0.2624145878361924, 0.3931447482346404, 0.9382554946184531], 
             UndirectedEdge[5, 163] -> 
             RGBColor[
              0.7944424008489477, 0.6965434437689743, 0.6036935441317027], 
             UndirectedEdge[188, 430] -> 
             RGBColor[
              0.2127664410138974, 0.34096139805008724`, 0.9354281061047747], 
             UndirectedEdge[380, 487] -> 
             RGBColor[
              0.19010454207928099`, 0.31714230542242455`, 0.9341375444857234],
              UndirectedEdge[88, 304] -> 
             RGBColor[
              0.19013400622997473`, 0.3171732741129387, 0.9341392224255172], 
             UndirectedEdge[41, 494] -> 
             RGBColor[
              0.3091950820990577, 0.43800954418308746`, 0.9410771822783439], 
             UndirectedEdge[23, 136] -> 
             RGBColor[
              0.48008619598652036`, 0.5882144414151268, 0.9523735975581908], 
             UndirectedEdge[7, 84] -> 
             RGBColor[
              0.373934744333056, 0.4947159504930181, 0.9453030779152829], 
             UndirectedEdge[218, 493] -> 
             RGBColor[
              0.2733906528975818, 0.4046812885368802, 0.9388805652860661], 
             UndirectedEdge[40, 183] -> 
             RGBColor[
              0.19098677743240255`, 0.31806959071550744`, 0.9341877864839334],
              UndirectedEdge[192, 453] -> 
             RGBColor[
              0.27645983051134826`, 0.4075148710199178, 0.9390697150866952], 
             UndirectedEdge[49, 397] -> 
             RGBColor[
              0.9079673464709124, 0.579798317184308, 0.3744269914858809], 
             UndirectedEdge[291, 467] -> 
             RGBColor[
              0.1871130842202519, 0.31399809354320196`, 0.933967185386117], 
             UndirectedEdge[347, 462] -> 
             RGBColor[
              0.19657186081581016`, 0.32393986746620806`, 0.934505848720228], 
             UndirectedEdge[31, 226] -> 
             RGBColor[
              0.1894803426038117, 0.3164862321971737, 0.9341019972490159], 
             UndirectedEdge[120, 381] -> 
             RGBColor[
              0.18410140079156978`, 0.3108326233078988, 0.9337956744702399], 
             UndirectedEdge[151, 274] -> 
             RGBColor[
              0.22389877891969617`, 0.3526621910200718, 0.9360620762796918], 
             UndirectedEdge[316, 418] -> 
             RGBColor[
              0.45760917454031613`, 0.5701502103978782, 0.9505533872489015], 
             UndirectedEdge[235, 389] -> 
             RGBColor[
              0.20601966033790897`, 0.3338701037890217, 0.9350438869262447], 
             UndirectedEdge[218, 310] -> 
             RGBColor[
              0.4653446361758491, 0.5701283226319324, 0.9524120897475179], 
             UndirectedEdge[408, 463] -> 
             RGBColor[
              0.746221620758815, 0.8012446952293572, 0.9745845586722801], 
             UndirectedEdge[12, 273] -> 
             RGBColor[
              0.1905970563658978, 0.31765996916486816`, 0.9341655924457366], 
             UndirectedEdge[121, 454] -> 
             RGBColor[
              0.20826238807822112`, 0.3362273528412414, 0.9351716069532372], 
             UndirectedEdge[47, 228] -> 
             RGBColor[
              0.2699130817435731, 0.4010261407632708, 0.9386825227534509], 
             UndirectedEdge[438, 439] -> 
             RGBColor[
              0.2009360669634459, 0.3285269248340248, 0.9347543838040715], 
             UndirectedEdge[172, 201] -> 
             RGBColor[
              0.2404718980048366, 0.3700815899749955, 0.9370058908938581], 
             UndirectedEdge[58, 375] -> 
             RGBColor[
              0.19795511773261765`, 0.3253937581893268, 0.934584623155295], 
             UndirectedEdge[168, 280] -> 
             RGBColor[
              0.2730931280966553, 0.40436857110694446`, 0.9388636216888019], 
             UndirectedEdge[77, 301] -> 
             RGBColor[
              0.49545804882307076`, 0.5978313042438662, 0.9544626274499579], 
             UndirectedEdge[283, 477] -> 
             RGBColor[
              0.19005559335530314`, 0.3170908572099954, 0.934134756928306], 
             UndirectedEdge[125, 149] -> 
             RGBColor[
              0.669539684263013, 0.7405244264891351, 0.9685478722425018], 
             UndirectedEdge[7, 407] -> 
             RGBColor[
              0.3747418079101595, 0.4955642254833401, 0.9453490389920554], 
             UndirectedEdge[401, 437] -> 
             RGBColor[
              0.18132345879022535`, 0.30791283013279, 0.9336374747828603], 
             UndirectedEdge[138, 438] -> 
             RGBColor[
              0.19270594078429107`, 0.3198765403995944, 0.9342856902935492], 
             UndirectedEdge[45, 399] -> 
             RGBColor[
              0.20452814783915604`, 0.33230242958547795`, 0.9349589474959358],
              UndirectedEdge[97, 317] -> 
             RGBColor[
              0.9028878976305327, 0.5534256006607606, 0.2869376293254444], 
             UndirectedEdge[71, 201] -> 
             RGBColor[
              0.22759518578243687`, 0.3565473489985437, 0.936272581182181], 
             UndirectedEdge[107, 236] -> 
             RGBColor[
              0.20982294786551192`, 0.3378676001228893, 0.935260478524482], 
             UndirectedEdge[134, 225] -> 
             RGBColor[
              0.1840482113903489, 0.31077671787481287`, 0.933792645412527], 
             UndirectedEdge[59, 91] -> 
             RGBColor[
              0.36166005851975747`, 0.48325335582239703`, 0.9444730770573722],
              UndirectedEdge[161, 287] -> 
             RGBColor[
              0.25900221419710867`, 0.3895581271829785, 0.9380611649878617], 
             UndirectedEdge[101, 486] -> 
             RGBColor[
              0.32922289158902907`, 0.45369458082192426`, 0.9424141922098388],
              UndirectedEdge[185, 330] -> 
             RGBColor[
              0.20056082053324595`, 0.3281325170438868, 0.934733014074999], 
             UndirectedEdge[237, 432] -> 
             RGBColor[
              0.26206160282215785`, 0.3927737386043475, 0.9382353926440985], 
             UndirectedEdge[99, 143] -> 
             RGBColor[
              0.7801748654933693, 0.827408823277354, 0.9396902443294888], 
             UndirectedEdge[107, 411] -> 
             RGBColor[
              0.24624789168403566`, 0.3761525255509848, 0.9373348251890715], 
             UndirectedEdge[187, 407] -> 
             RGBColor[
              0.24918791988473313`, 0.3792426815984722, 0.9375022554457193], 
             UndirectedEdge[185, 357] -> 
             RGBColor[
              0.20004263933508956`, 0.3275878757500389, 0.9347035044223444], 
             UndirectedEdge[80, 208] -> 
             RGBColor[
              0.38701536387166025`, 0.5096349890530197, 0.9458812546550213], 
             UndirectedEdge[60, 240] -> 
             RGBColor[
              0.9901494356226408, 0.989783903232943, 0.7830629910514044], 
             UndirectedEdge[262, 299] -> 
             RGBColor[
              0.2916203852027007, 0.4206594025249505, 0.9400352481392587], 
             UndirectedEdge[82, 282] -> 
             RGBColor[
              0.6084177855813375, 0.6921473526873871, 0.962885304068208], 
             UndirectedEdge[286, 368] -> 
             RGBColor[
              0.18331387184910375`, 0.310004880457148, 0.9337508258620111], 
             UndirectedEdge[81, 454] -> 
             RGBColor[
              0.2248746265777104, 0.3536878687809598, 0.9361176493601785], 
             UndirectedEdge[68, 352] -> 
             RGBColor[
              0.18440978245630846`, 0.311156751990066, 0.933813236349837], 
             UndirectedEdge[196, 337] -> 
             RGBColor[
              0.19054105270955757`, 0.3176011057712177, 0.934162403120358], 
             UndirectedEdge[261, 262] -> 
             RGBColor[
              0.33623006243366543`, 0.4656473134908974, 0.942645260155071], 
             UndirectedEdge[122, 286] -> 
             RGBColor[
              0.1865372127264831, 0.3133928160908893, 0.9339343903564724]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.20904447312210606`, 0.33704937380942024`, 0.9352161455394953],
              316 -> 
             RGBColor[
              0.43871305828747303`, 0.5544129335543235, 0.9491753860287206], 
             308 -> RGBColor[
              0.19090439582770188`, 0.3179830024256716, 0.9341830949734184], 
             160 -> RGBColor[
              0.23944883454874902`, 0.3690062854166779, 0.9369476289435206], 
             245 -> RGBColor[
              0.2439252154854269, 0.3737112456000703, 0.9372025522156523], 
             155 -> RGBColor[
              0.19392286855916088`, 0.32115560864865994`, 0.9343549925300447],
              425 -> RGBColor[
              0.18667870528248892`, 0.31354153373839766`, 0.9339424481482175],
              213 -> RGBColor[
              0.20221750657572096`, 0.32987379911448994`, 0.9348273598942706],
              352 -> RGBColor[
              0.18339204965023842`, 0.3100870502828995, 0.9337552779721321], 
             27 -> RGBColor[
              0.18521154867326725`, 0.3119994591190039, 0.933858895749786], 
             485 -> RGBColor[
              0.255344871987097, 0.38571402863136683`, 0.9378528847595545], 
             454 -> RGBColor[
              0.21139233227849236`, 0.33951712264565065`, 0.9353498526451051],
              367 -> RGBColor[
              0.19714961162350877`, 0.32454712019661625`, 0.9345387507740208],
              19 -> RGBColor[
              0.20321773659331793`, 0.33092510428123034`, 0.934884321514065], 
             164 -> RGBColor[
              0.3160253373259164, 0.44814699612157666`, 0.9413578329375422], 
             190 -> RGBColor[
              0.21654397156564814`, 0.3449318221692476, 0.9356432308813413], 
             103 -> RGBColor[
              0.40980409560216274`, 0.5293734430830204, 0.9473333324896046], 
             138 -> RGBColor[
              0.1827700546655207, 0.3094332941172014, 0.9337198562779115], 
             416 -> RGBColor[
              0.20922896777355948`, 0.3372432893857343, 0.9352266522369601], 
             476 -> RGBColor[
              0.18343003159278173`, 0.31012697171270676`, 0.9337574409875706],
              291 -> RGBColor[
              0.18307944483465585`, 0.30975848280143214`, 0.933737475590342], 
             28 -> RGBColor[
              0.47584147550400935`, 0.5853485720851631, 0.951879130497885], 
             337 -> RGBColor[
              0.1890859537624092, 0.3160717045191629, 0.9340795373879439], 
             195 -> RGBColor[
              0.18809486651088786`, 0.3150300089792529, 0.934023096435152], 
             114 -> RGBColor[
              0.18143431560131953`, 0.3080293476699778, 0.9336437879142542], 
             479 -> 
             RGBColor[
              0.18231814009471767`, 0.3089583032502487, 0.933694120411652], 
             93 -> RGBColor[
              0.2226303791602024, 0.3513290224516542, 0.935989842789818], 34 -> 
             RGBColor[
              0.2089289231192469, 0.33692792343012196`, 0.9352095651377733], 
             161 -> RGBColor[
              0.2138505894071634, 0.34210090675038807`, 0.9354898467519174], 
             22 -> RGBColor[
              0.1817982963009414, 0.30841191446298966`, 0.9336645160766364], 
             124 -> RGBColor[
              0.18536877790044387`, 0.31216471700567533`, 0.9338678497216739],
              84 -> RGBColor[
              0.27551545928723997`, 0.406914594772917, 0.9390015698665879], 
             46 -> RGBColor[
              0.2037103551444467, 0.3314428776122868, 0.934912375411788], 241 -> 
             RGBColor[
              0.21562994450375172`, 0.3439711217745316, 0.9355911783923481], 
             185 -> RGBColor[
              0.21154093935996757`, 0.33967331811051427`, 0.9353583155985506],
              426 -> RGBColor[
              0.18735694523176508`, 0.31425440692798345`, 0.9339810729099627],
              390 -> RGBColor[
              0.25591378716406765`, 0.38631199455366855`, 0.9378852836372484],
              121 -> RGBColor[
              0.20513244387794988`, 0.3329375830368321, 0.9349933612613692], 
             322 -> RGBColor[
              0.820782245844875, 0.16074702516771538`, 0.16753440813222906`], 
             488 -> RGBColor[
              0.18252871209609148`, 0.30917962777472857`, 0.9337061121756168],
              126 -> RGBColor[
              0.4884562669939937, 0.5955898281066129, 0.9528722130934804], 
             433 -> RGBColor[
              0.18067343227102245`, 0.30722961104704605`, 0.9336004567342198],
              236 -> RGBColor[
              0.20835940299106456`, 0.3363293216657406, 0.9351771318090029], 
             78 -> RGBColor[
              0.4700607186843903, 0.5806554932788695, 0.9514240481454346], 
             376 -> RGBColor[
              0.37110890510299593`, 0.49585761394946637`, 0.9448677091678112],
              458 -> RGBColor[
              0.2390221871354001, 0.3685578519342398, 0.9369233320044987], 
             254 -> RGBColor[
              0.19242949370172294`, 0.3195859769880579, 0.9342699470411637], 
             290 -> RGBColor[
              0.18152659560596812`, 0.30812633980575366`, 0.9336490431240029],
              251 -> RGBColor[
              0.23893002370274252`, 0.3684609823230175, 0.9369180834333524], 
             165 -> 
             RGBColor[
              0.3059265832870255, 0.43887861427331937`, 0.9407334383891494], 
             460 -> RGBColor[
              0.3006736022333113, 0.4333573981276305, 0.9404342888892294], 
             100 -> RGBColor[
              0.9932268871291124, 0.987921321372956, 0.5041666466903745], 235 -> 
             RGBColor[
              0.2171179053764417, 0.345535062993897, 0.9356759155628069], 70 -> 
             RGBColor[
              0.3697431424982056, 0.49467465902642144`, 0.9447806839823304], 
             234 -> RGBColor[
              0.9263783006421346, 0.7458215255627042, 0.25962045645451476`], 
             435 -> RGBColor[
              0.23839852597207306`, 0.3679023445091814, 0.9368878154238712], 
             257 -> RGBColor[
              0.9630526170636222, 0.8870299430768459, 0.31096682353032956`], 
             135 -> RGBColor[
              0.17999586170885287`, 0.3065174414257509, 0.93356187009308], 
             265 -> RGBColor[
              0.18432263905515192`, 0.3110651587502397, 0.9338082736620582], 
             111 -> RGBColor[
              0.3665915053486955, 0.49194486933340476`, 0.9445798644500469], 
             497 -> RGBColor[
              0.4781822073170808, 0.587248883619781, 0.9520634014805931], 481 -> 
             RGBColor[
              0.20526876593224802`, 0.3330808661592169, 0.9350011246006911], 
             381 -> RGBColor[
              0.18829908866819065`, 0.31524465941501073`, 0.9340347265848907],
              182 -> RGBColor[
              0.34499714152995936`, 0.4732409167578995, 0.9432038906826632], 
             188 -> RGBColor[
              0.2239766808649284, 0.35274407090377946`, 0.9360665126802272], 
             154 -> RGBColor[
              0.9834670894693087, 0.9871903629131425, 0.9128700844415136], 
             336 -> RGBColor[
              0.6253505975793664, 0.7067268126951324, 0.9636490362576168], 
             463 -> RGBColor[
              0.5551591248464408, 0.6497422130407317, 0.9581233064042441], 
             315 -> RGBColor[
              0.18340993044876472`, 0.3101058441358588, 0.9337562962571558], 
             368 -> RGBColor[
              0.1792318772890574, 0.3057144453611359, 0.9335183623105863], 
             269 -> RGBColor[
              0.6018738506410779, 0.6876673319152327, 0.961800860740477], 208 -> 
             RGBColor[
              0.42661470104868005`, 0.5439339445951966, 0.948404489403622], 
             86 -> RGBColor[
              0.18531184315250615`, 0.31210487497572126`, 0.9338646073720063],
              119 -> 
             RGBColor[
              0.18431898451928125`, 0.31106131760132866`, 0.9338080655416469],
              436 -> RGBColor[
              0.35552088653300873`, 0.4823560557407374, 0.9438744544084752], 
             377 -> RGBColor[
              0.1807916321529833, 0.30735384661729226`, 0.9336071880426363], 
             140 -> RGBColor[
              0.17901437519538227`, 0.3054858368702541, 0.933505975888117], 
             85 -> RGBColor[
              0.18726966457396857`, 0.31416266942272597`, 0.9339761024056213],
              351 -> RGBColor[
              0.24019038642635912`, 0.3697857034571507, 0.9369898592259228], 
             443 -> RGBColor[
              0.2878366774276409, 0.41986497624882907`, 0.9397032450120749], 
             242 -> RGBColor[
              0.9731128985329042, 0.9794682242662037, 0.9303970288913456], 
             117 -> RGBColor[
              0.18356396795554494`, 0.3102677473220268, 0.933765068465289], 
             47 -> RGBColor[
              0.28160948378147765`, 0.4133198008998302, 0.9393486155462334], 
             451 -> RGBColor[
              0.20508673054441848`, 0.33288953542489785`, 0.9349907579546514],
              81 -> RGBColor[
              0.23835692087692842`, 0.36785861491626903`, 0.9368854460752519],
              275 -> RGBColor[
              0.48931236896480956`, 0.5962848502534754, 0.9529396085766279], 
             23 -> RGBColor[
              0.4319501958436354, 0.5485552820168211, 0.9487444624139638], 
             328 -> RGBColor[
              0.24298649045633505`, 0.3727245860758903, 0.9371490932139648], 
             418 -> RGBColor[
              0.4765052907931592, 0.5858874872414329, 0.9519313884690823], 
             110 -> RGBColor[
              0.4170759329154467, 0.5356719430706164, 0.9477966875329739], 6 -> 
             RGBColor[
              0.21439443043390383`, 0.3426725181510049, 0.9355208176938495], 
             218 -> RGBColor[
              0.28587662659874513`, 0.4178048385532594, 0.9395916230170046], 
             108 -> RGBColor[
              0.20961363351384976`, 0.337647597467996, 0.9352485583818076], 
             297 -> RGBColor[
              0.19526251556143404`, 0.32256366258657476`, 0.934431283444994], 
             487 -> RGBColor[
              0.19274009296176206`, 0.31991243650348955`, 0.9342876352095326],
              464 -> RGBColor[
              0.20245401245038683`, 0.33012238178410236`, 0.9348408285539537],
              157 -> RGBColor[
              0.29909565256278264`, 0.4316988729761172, 0.9403444269898601], 
             441 -> 
             RGBColor[
              0.22146757953397317`, 0.3501068463187328, 0.935923623071312], 
             354 -> RGBColor[
              0.31058773436371456`, 0.4434372177375889, 0.9410113536850742], 
             385 -> RGBColor[
              0.18155548323377793`, 0.30815670253416316`, 0.9336506882316712],
              270 -> RGBColor[
              0.18011392367187812`, 0.3066415320344512, 0.9335685935472172], 
             392 -> RGBColor[
              0.23685058796865582`, 0.3662753635226519, 0.9367996626445457], 
             33 -> RGBColor[
              0.25627137654269866`, 0.3866878436630859, 0.9379056478233554], 
             252 -> RGBColor[
              0.18230687199160545`, 0.30894645975943874`, 0.9336934787098494],
              394 -> RGBColor[
              0.18345440314028216`, 0.3101525877543751, 0.9337588289111464], 
             260 -> RGBColor[
              0.20975080596055196`, 0.33779177440671543`, 0.935256370149719], 
             159 -> RGBColor[
              0.2321162208184409, 0.36129924347156134`, 0.9365300474392095], 
             183 -> RGBColor[
              0.19696480621086881`, 0.3243528779905917, 0.934528226379166], 
             99 -> RGBColor[
              0.9796979203258498, 0.9843793227373989, 0.9192503046446351], 
             329 -> RGBColor[
              0.18157893838322037`, 0.30818135538336955`, 0.9336520239677332],
              309 -> RGBColor[
              0.1881959331144625, 0.3151362363876026, 0.9340288520287109], 17 -> 
             RGBColor[
              0.3754434746784675, 0.49961200025393837`, 0.9451439041082509], 
             349 -> RGBColor[
              0.18519516767477753`, 0.31198224165097593`, 0.9338579628761555],
              495 -> RGBColor[
              0.8860920716837987, 0.5756525260362475, 0.22666477128519144`], 
             347 -> RGBColor[
              0.2030767017243416, 0.3307768676918091, 0.9348762897869192], 
             340 -> RGBColor[
              0.36379298595207366`, 0.4895209324897256, 0.9444015452687277], 
             404 -> RGBColor[
              0.8368269464602606, 0.8727271083178094, 0.9842984952692555], 
             277 -> RGBColor[
              0.44322657405371796`, 0.5583223140551463, 0.9494629832622005], 
             104 -> RGBColor[
              0.9241317229671294, 0.73691459370894, 0.25781280732325], 79 -> 
             RGBColor[
              0.8862469572430673, 0.9121332834455631, 0.9890122200154841], 
             327 -> RGBColor[
              0.1837791716078354, 0.31049394000528374`, 0.9337773239949216], 
             191 -> 
             RGBColor[
              0.19059661539563244`, 0.31765950567716017`, 0.9341655673331324],
              50 -> RGBColor[
              0.8803633253605091, 0.9074418350893442, 0.9884510339541455], 
             225 -> RGBColor[
              0.18396512493287584`, 0.310689388740023, 0.9337879137616893], 
             405 -> RGBColor[
              0.1816592229448945, 0.3082657395480243, 0.9336565960547502], 61 -> 
             RGBColor[
              0.9902590342278114, 0.9902398745688678, 0.8110965418638902], 
             196 -> RGBColor[
              0.19199615165670597`, 0.3191305070232725, 0.9342452688527721], 
             1 -> RGBColor[
              0.19927754620079638`, 0.32678371435619025`, 0.9346599335002002],
              263 -> RGBColor[
              0.22433819907190317`, 0.35312404946088816`, 0.9360871006072962],
              201 -> RGBColor[
              0.25745169920403105`, 0.3879284376169253, 0.9379728654527874], 
             371 -> RGBColor[
              0.25408219745152405`, 0.38438687763629015`, 0.9377809773127133],
              293 -> RGBColor[
              0.8097488880926076, 0.8513012527882134, 0.9816718596976299], 
             362 -> RGBColor[
              0.17923689510112015`, 0.3057197193997615, 0.9335186480675601], 
             184 -> RGBColor[
              0.5408355089237035, 0.6381136563631097, 0.9569956988896724], 
             106 -> RGBColor[
              0.17964740484760663`, 0.30615119117114004`, 0.9335420259903278],
              206 -> RGBColor[
              0.18041422854673403`, 0.3069571714983536, 0.933585695465579], 
             358 -> RGBColor[
              0.2248830575111852, 0.353696730226594, 0.9361181294893675], 247 -> 
             RGBColor[
              0.18427930277709584`, 0.31101960957432406`, 0.9338058057251333],
              220 -> RGBColor[
              0.21703333859134122`, 0.34544617794091254`, 0.9356710996095008],
              407 -> RGBColor[
              0.2771295864414469, 0.4086111447535611, 0.9390934920201328], 
             107 -> RGBColor[
              0.21128649273995928`, 0.33940587858003807`, 0.9353438252399612],
              375 -> RGBColor[
              0.20274272640358343`, 0.3304258384544339, 0.9348572703864743], 
             131 -> RGBColor[
              0.8337292727736055, 0.2602635475653142, 0.17993249574075687`], 
             411 -> RGBColor[
              0.281209290628112, 0.4128991725219315, 0.9393258251381819], 462 -> 
             RGBColor[
              0.1900670199072787, 0.31710286724060704`, 0.934135407653537], 
             127 -> 
             RGBColor[
              0.8321508631713839, 0.8689985264321587, 0.9838524862707736], 
             210 -> RGBColor[
              0.19552365175645214`, 0.32283813328452987`, 0.9344461547649839],
              357 -> RGBColor[
              0.18854433931021156`, 0.3155024333895635, 0.934048693246138], 
             181 -> RGBColor[
              0.22551745991005276`, 0.354363527371239, 0.9361542577674687], 
             194 -> RGBColor[
              0.18610703405965695`, 0.3129406710371523, 0.933909892317789], 
             440 -> RGBColor[
              0.8916325056316791, 0.6008103425923479, 0.23128784517976625`], 
             490 -> RGBColor[
              0.2159679187439516, 0.3443263541297861, 0.9356104255253395], 
             118 -> RGBColor[
              0.19221104916857337`, 0.3193563779335344, 0.9342575069481607], 
             348 -> RGBColor[
              0.46208044251389646`, 0.5741767455763179, 0.9507958115725785], 
             276 -> RGBColor[
              0.21359854810176626`, 0.34183599535807396`, 0.9354754933724367],
              305 -> RGBColor[
              0.3105546519813193, 0.443408563440727, 0.9410092457049215], 343 -> 
             RGBColor[
              0.8462306119676556, 0.35635431873254797`, 0.1919037922712223], 
             280 -> RGBColor[
              0.2534737690150518, 0.3837473807729669, 0.9377463282133454], 
             474 -> RGBColor[
              0.22951352418939525`, 0.35856364429393695`, 0.93638182771653], 
             189 -> RGBColor[
              0.2519720376195532, 0.38216896586102805`, 0.9376608068319842], 
             168 -> RGBColor[
              0.29271248717825876`, 0.424989761440922, 0.9399809151642584], 
             363 -> RGBColor[
              0.18261346087673228`, 0.3092687041165651, 0.9337109384932998], 
             41 -> RGBColor[
              0.2630876311955555, 0.3938521594787447, 0.9382938234420904], 14 -> 
             RGBColor[
              0.2309802119470121, 0.36010522612056717`, 0.9364653534145562], 
             77 -> RGBColor[
              0.33446793820227666`, 0.46412105004860754`, 0.9425329791572322],
              51 -> RGBColor[
              0.9952524916716045, 0.9922538846693116, 0.7246412005584384], 
             438 -> RGBColor[
              0.20264182690306143`, 0.3303197866819874, 0.9348515243091869], 
             179 -> RGBColor[
              0.2001120590885424, 0.3276608403123844, 0.9347074577746062], 
             467 -> RGBColor[
              0.19114672360584797`, 0.3182377042849717, 0.934196895181892], 
             223 -> 
             RGBColor[
              0.20818468230621298`, 0.33614567914803034`, 0.9351671817244767],
              456 -> RGBColor[
              0.19561148544389112`, 0.32293045205900567`, 0.9344511567635453],
              323 -> RGBColor[
              0.9927101178720487, 0.9912534606457363, 0.7704757426777427], 
             500 -> RGBColor[
              0.20098870068601762`, 0.3285822462136184, 0.9347573812167074], 
             478 -> RGBColor[
              0.24931371638514488`, 0.37937490169636373`, 0.9375094193703185],
              292 -> RGBColor[
              0.18511992750412062`, 0.3119031594611132, 0.9338536780597445], 
             491 -> RGBColor[
              0.1816268290277524, 0.30823169148721496`, 0.9336547512690914], 
             396 -> RGBColor[
              0.19743844380411263`, 0.32485070113144887`, 0.9345551993394172],
              321 -> RGBColor[
              0.9854351531478911, 0.9882450757742316, 0.8910407351622261], 
             143 -> RGBColor[
              0.5806518106608889, 0.6704383238173092, 0.9601301840143426], 
             112 -> RGBColor[
              0.9934414779456845, 0.9915558968312813, 0.7583552135583986], 
             197 -> RGBColor[
              0.23089370286527677`, 0.3600142995906707, 0.93646042685033], 
             421 -> RGBColor[
              0.1843367269803192, 0.31107996605281657`, 0.9338090759485553], 
             54 -> RGBColor[
              0.9895254911096693, 0.9899365356383177, 0.8232532496802422], 71 -> 
             RGBColor[
              0.19773867236084267`, 0.32516626038016205`, 0.9345722969115747],
              177 -> RGBColor[
              0.18438238961983267`, 0.3111279603821238, 0.9338116763683237], 
             158 -> RGBColor[
              0.19170728594478786`, 0.3188268908449026, 0.9342288183778169], 
             226 -> RGBColor[
              0.1869796895121246, 0.3138578872472471, 0.933959588754829], 432 -> 
             RGBColor[
              0.29123303955595214`, 0.4234347681874807, 0.9398966628108147], 
             350 -> RGBColor[
              0.1815243108454087, 0.3081239383775436, 0.933648913010269], 203 -> 
             RGBColor[
              0.8450710458930704, 0.34744138575819206`, 0.19079339048865696`],
              475 -> RGBColor[
              0.3365285973416883, 0.465905889423426, 0.9426642825354262], 115 -> 
             RGBColor[
              0.19098661972276523`, 0.31806942495267926`, 0.934187777502603], 
             173 -> RGBColor[
              0.720597203195575, 0.7816552789687509, 0.9727860529169569], 212 -> 
             RGBColor[
              0.1819457440050942, 0.3085668913487786, 0.9336729130052586], 
             129 -> RGBColor[
              0.2893758023858067, 0.42148269416601997`, 0.9397908959015111], 
             279 -> RGBColor[
              0.20798277523591915`, 0.3359334620155039, 0.9351556834155181], 
             26 -> RGBColor[
              0.1848952269737127, 0.31166698495681794`, 0.9338408816969523], 
             40 -> RGBColor[
              0.18500874865393632`, 0.31178630344042324`, 0.9338473465887008],
              146 -> RGBColor[
              0.1800731039927536, 0.30659862796357423`, 0.9335662689268784], 
             386 -> RGBColor[
              0.30560245203902436`, 0.43853793178056216`, 0.9407149795940849],
              192 -> RGBColor[
              0.3129892535839804, 0.4455172929823175, 0.9411643763662094], 
             300 -> RGBColor[
              0.23186327956718236`, 0.36103338617908703`, 0.9365156428091433],
              221 -> RGBColor[
              0.9622752132426141, 0.884407577445488, 0.3079467564861062], 62 -> 
             RGBColor[
              0.25119317281524384`, 0.3813503295688181, 0.9376164516336061], 
             286 -> RGBColor[
              0.18739586640915007`, 0.3142953155531602, 0.933983289413436], 
             472 -> RGBColor[
              0.18313584696674626`, 0.3098177650183609, 0.9337406876083251], 
             152 -> RGBColor[
              0.18423542654322242`, 0.31097349287060916`, 0.9338033070385232],
              64 -> RGBColor[
              0.18480592008610275`, 0.3115731177555562, 0.9338357958018207], 
             307 -> RGBColor[
              0.1917730045224159, 0.3188959652367882, 0.934232560953591], 37 -> 
             RGBColor[
              0.861854760386902, 0.4655965562049136, 0.20644056462819607`], 
             148 -> RGBColor[
              0.27463540520047075`, 0.4059896021290707, 0.9389514520882697], 
             261 -> RGBColor[
              0.329292758612209, 0.4596385695997802, 0.9422032212899847], 387 -> 
             RGBColor[
              0.18889078087796188`, 0.3158665654429332, 0.934068422580907], 
             15 -> RGBColor[
              0.6524065300643914, 0.7283842068503593, 0.9659894438973117], 
             136 -> RGBColor[
              0.5282221961294052, 0.6278736008134325, 0.956002732702418], 198 -> 
             RGBColor[
              0.1824115868132323, 0.30905652167627173`, 0.9336994420640293], 
             63 -> RGBColor[
              0.20681114074536727`, 0.3347019998800166, 0.9350889605645591], 
             444 -> 
             RGBColor[
              0.5658641034717166, 0.6584329969425219, 0.9589660415352547], 
             310 -> RGBColor[
              0.644812645752953, 0.7224518067106054, 0.9652325564780311], 171 -> 
             RGBColor[
              0.47069483175957283`, 0.581170294839771, 0.9514739678495456], 
             395 -> RGBColor[
              0.5041410272247835, 0.6083234230523641, 0.954106974874018], 311 -> 
             RGBColor[
              0.18998459744441062`, 0.31701623600624673`, 0.9341307138162097],
              353 -> RGBColor[
              0.18070771638990538`, 0.3072656458297307, 0.9336024091640713], 
             59 -> RGBColor[
              0.26299592027232827`, 0.3937557654836245, 0.9382886006406869], 
             397 -> RGBColor[
              0.8220097648168001, 0.1701822738881748, 0.16870988168602888`], 
             229 -> RGBColor[
              0.2348407472607494, 0.36416289350738135`, 0.9366852051895233], 
             102 -> RGBColor[
              0.19944242864104303`, 0.32695701625504003`, 0.9346693233112505],
              453 -> RGBColor[
              0.23993040743871616`, 0.3695124490575181, 0.936975053807181], 
             299 -> RGBColor[
              0.24007340415027964`, 0.3696627476678865, 0.9369831972583599], 
             128 -> RGBColor[
              0.19425607642724724`, 0.32150583124461773`, 0.9343739682251954],
              12 -> RGBColor[
              0.19403535624859544`, 0.3212738403423871, 0.9343613985375474], 
             222 -> RGBColor[
              0.1971022673351447, 0.32449735834774435`, 0.9345360545868381], 
             483 -> RGBColor[
              0.4520407911262143, 0.5659567458679113, 0.9500246173799538], 92 -> 
             RGBColor[
              0.27193911320159614`, 0.4031556282834669, 0.9387979022477403], 
             271 -> RGBColor[
              0.20809576797568208`, 0.3360522245491482, 0.9351621181848899], 
             361 -> RGBColor[
              0.23010075165696398`, 0.35918085759472357`, 0.9364152694520828],
              344 -> RGBColor[
              0.1902758304551235, 0.3173223403657453, 0.9341472991053292], 
             132 -> RGBColor[
              0.2723145403641676, 0.4035502260347864, 0.938819282269254], 80 -> 
             RGBColor[
              0.3474160266946404, 0.4753360335108428, 0.9433580199064205], 
             324 -> RGBColor[
              0.9397327677393429, 0.9545733773753136, 0.9869008833924131], 
             244 -> RGBColor[
              0.44672166802497704`, 0.5613495887845201, 0.9496856875594589], 
             150 -> 
             RGBColor[
              0.2153604952721365, 0.34368791354803596`, 0.9355758336572221], 
             125 -> RGBColor[
              0.7779497574122243, 0.8264595302183536, 0.978502419531181], 258 -> 
             RGBColor[
              0.41518076487513966`, 0.5340304437680178, 0.9476759291012767], 
             133 -> RGBColor[
              0.19798057442534764`, 0.32542051478743356`, 0.9345860728762861],
              469 -> RGBColor[
              0.18135253868176207`, 0.30794339494256673`, 0.9336391308396634],
              255 -> RGBColor[
              0.19717041562221144`, 0.32456898651830246`, 0.9345399355309701],
              408 -> RGBColor[
              0.9372841166711893, 0.9527471774179826, 0.9910458109403161], 
             326 -> RGBColor[
              0.7253820295989173, 0.7853932217210695, 0.973262959696097], 176 -> 
             RGBColor[
              0.3169334821091241, 0.44893358548810713`, 0.9414156991200873], 
             230 -> RGBColor[
              0.2058983382969339, 0.3337425866316952, 0.9350369778154911], 
             274 -> RGBColor[
              0.24408437678171757`, 0.37387853421388084`, 0.937211616216018], 
             87 -> RGBColor[
              0.30841227476556676`, 0.4414912336192087, 0.9408749948416013], 
             439 -> RGBColor[
              0.19923030702383038`, 0.32673406298606217`, 0.934657243298956], 
             130 -> RGBColor[
              0.30291909395791666`, 0.43571755230258913`, 0.9405621663210384],
              35 -> RGBColor[
              0.187649142725438, 0.3145615250202248, 0.9339977131249598], 379 -> 
             RGBColor[
              0.8274245231995631, 0.21180247958034423`, 0.17389506042845765`],
              31 -> RGBColor[
              0.19198099569549876`, 0.3191145771471003, 0.9342444057432027], 
             18 -> RGBColor[
              0.2883133698343315, 0.42036601019230513`, 0.9397303919394328], 
             24 -> RGBColor[
              0.18529079599648704`, 0.31208275308027844`, 0.9338634087676074],
              151 -> RGBColor[
              0.20371318105767475`, 0.33144584782626274`, 0.9349125363433657],
              137 -> RGBColor[
              0.2116557852103354, 0.33979402838089834`, 0.9353648558998299], 
             330 -> RGBColor[
              0.18958070170652433`, 0.3165917159772593, 0.9341077125514473], 
             296 -> RGBColor[
              0.18222924951210637`, 0.30886487361193576`, 0.9336890582244741],
              266 -> RGBColor[
              0.9935833726583437, 0.9886838078737659, 0.5429678965735315], 
             302 -> 
             RGBColor[
              0.24476085053842922`, 0.3745895510230982, 0.9372501403957095], 
             442 -> RGBColor[
              0.2379042947950852, 0.36738287620610066`, 0.9368596696894913], 
             283 -> RGBColor[
              0.18231742038260904`, 0.3089575467871901, 0.9336940794251122], 
             388 -> RGBColor[
              0.3286879472145684, 0.4591147123658486, 0.9421646832425408], 
             284 -> RGBColor[
              0.20683017875346388`, 0.3347220100336056, 0.935090044750956], 
             417 -> RGBColor[
              0.19713115786974042`, 0.32452772413137015`, 0.9345376998600435],
              318 -> RGBColor[
              0.1979808475129809, 0.32542080181985084`, 0.9345860884282229], 
             413 -> RGBColor[
              0.23030998251802656`, 0.3594007724957031, 0.936427184840091], 
             238 -> RGBColor[
              0.48668906339049306`, 0.5941551326096759, 0.9527330923523326], 
             72 -> RGBColor[
              0.21111609134757603`, 0.339226775912571, 0.9353341211327513], 
             437 -> RGBColor[
              0.18191959414620315`, 0.3085394061890873, 0.93367142380948], 
             288 -> RGBColor[
              0.7112234006140565, 0.7743323931485304, 0.9718517598787967], 
             382 -> RGBColor[
              0.21206977390702858`, 0.3402291567495223, 0.9353884319436652], 
             461 -> RGBColor[
              0.25327163562221944`, 0.38353492576110276`, 0.9377348170156531],
              389 -> RGBColor[
              0.19492141529937626`, 0.32220514458414634`, 0.9344118582896825],
              172 -> RGBColor[
              0.22349209680564214`, 0.35223474233306573`, 0.9360389163349288],
              447 -> RGBColor[
              0.23372958097512028`, 0.36299498728917345`, 0.9366219259133799],
              243 -> RGBColor[
              0.19657931914436805`, 0.32394770664240774`, 0.9345062734610058],
              410 -> RGBColor[
              0.18224818387414324`, 0.30888477482694443`, 0.9336901365083813],
              88 -> RGBColor[
              0.18955897979005848`, 0.3165688848658047, 0.9341064755204392], 
             273 -> RGBColor[
              0.18715875648320013`, 0.3140460979873492, 0.9339697863539259], 
             477 -> RGBColor[
              0.19779376632799722`, 0.32522416763280076`, 0.9345754344314999],
              202 -> RGBColor[
              0.18676020758344578`, 0.31362719782424764`, 0.9339470895836851],
              393 -> RGBColor[
              0.2213158585080208, 0.34994737790078817`, 0.9359149827833353], 
             98 -> 
             RGBColor[
              0.18830185869099547`, 0.3152475708846082, 0.9340348843335916], 
             30 -> RGBColor[
              0.17893397678527326`, 0.30540133304367595`, 0.9335013973176001],
              116 -> RGBColor[
              0.27647894211230134`, 0.40792727631039594`, 0.9390564387881299],
              373 -> RGBColor[
              0.9909995879120733, 0.9905461125486716, 0.7988236508241691], 
             434 -> RGBColor[
              0.9350798973521478, 0.7803204568826958, 0.2666219654201177], 
             401 -> RGBColor[
              0.18072732343424755`, 0.30728625407649274`, 0.9336035257562406],
              240 -> RGBColor[
              0.9948059876224538, 0.9912988576566625, 0.6760419903119628], 
             480 -> RGBColor[
              0.24336115250331075`, 0.37311837964220756`, 0.9371704296632771],
              403 -> RGBColor[
              0.7434088886883141, 0.7994759410509097, 0.9750597085395519], 
             317 -> RGBColor[0.817319, 0.134127, 0.164218], 429 -> 
             RGBColor[
              0.1919491178531559, 0.319081071513626, 0.9342425903472402], 391 -> 
             RGBColor[
              0.47311473175482466`, 0.583134878671169, 0.9516644712415576], 
             73 -> RGBColor[
              0.5768983856608343, 0.6673911243123956, 0.9598347006490895], 
             303 -> RGBColor[
              0.8407980254541154, 0.31459707821488886`, 0.1867015412906274], 
             449 -> RGBColor[
              0.9836066487684537, 0.9563635183333898, 0.39081535540040413`], 
             29 -> RGBColor[
              0.1844293578243088, 0.3111773269429844, 0.9338143511380854], 
             360 -> RGBColor[
              0.5961635782161725, 0.6830314755158533, 0.9613513271777714], 
             320 -> RGBColor[
              0.18113843442729957`, 0.3077183577961329, 0.9336269379191107], 
             482 -> RGBColor[
              0.3323719943960167, 0.4623056488688239, 0.9423994274712677], 75 -> 
             RGBColor[
              0.8653183386459826, 0.4813238561401438, 0.20933065922764493`], 
             200 -> RGBColor[
              0.26297543885551555`, 0.39373423821595743`, 0.938287434254299], 
             301 -> RGBColor[
              0.6564481594438648, 0.7315415584391249, 0.9663922757426836], 
             156 -> RGBColor[
              0.19939483773806957`, 0.32690699519857735`, 0.9346666130797306],
              25 -> RGBColor[
              0.2888948585418871, 0.42097719169245956`, 0.9397635068610926], 
             38 -> RGBColor[
              0.5188198477638203, 0.6202403508392836, 0.9552625453971423], 
             365 -> RGBColor[
              0.20704370002822514`, 0.33494643443141037`, 0.9351022044716772],
              380 -> RGBColor[
              0.1874689911967999, 0.31437217434135956`, 0.9339874537619143], 
             370 -> RGBColor[
              0.22875987812146206`, 0.3577715144926186, 0.9363389086878806], 
             3 -> RGBColor[
              0.18365861817242612`, 0.31036723070113925`, 0.9337704586551179],
              57 -> RGBColor[
              0.9626408166905339, 0.9716581627746242, 0.9481235318941049], 
             227 -> RGBColor[
              0.19315889756887425`, 0.3203526266993102, 0.9343114855123418], 
             494 -> RGBColor[
              0.35530253300255993`, 0.4821669288874302, 0.9438605411145975], 
             39 -> RGBColor[
              0.24759097892264678`, 0.3775641953954144, 0.937411312020391], 
             424 -> RGBColor[
              0.19347184238884513`, 0.3206815515469472, 0.9343293072568787], 
             109 -> RGBColor[
              0.2136359512540558, 0.3418753084426271, 0.9354776234266265], 
             465 -> RGBColor[
              0.1790493149440538, 0.30552256076141593`, 0.9335079656551152], 
             256 -> RGBColor[
              0.3115575299166111, 0.44427720590216613`, 0.9410731482001482], 
             457 -> RGBColor[
              0.4692511982227218, 0.5799982880996057, 0.9513603197293209], 
             339 -> RGBColor[
              0.1801862242299471, 0.30671752450510187`, 0.9335727109570402], 
             420 -> RGBColor[
              0.1880446060283209, 0.31497718202537633`, 0.9340202341750236], 
             287 -> RGBColor[
              0.304153838987054, 0.4370153476155689, 0.9406324832238061], 239 -> 
             RGBColor[
              0.1966443508485099, 0.324016059086709, 0.9345099769203509], 427 -> 
             RGBColor[
              0.18651414967483487`, 0.3133685753613251, 0.9339330769497998], 
             285 -> RGBColor[
              0.21438774917055564`, 0.3426654957196094, 0.9355204372057859], 
             345 -> RGBColor[
              0.19084105210201593`, 0.31791642415375154`, 0.9341794876419492],
              366 -> RGBColor[
              0.18255683100735334`, 0.30920918253330676`, 0.933707713506015], 
             216 -> RGBColor[
              0.19991510326486814`, 0.3274538272539823, 0.934696241431818], 
             21 -> RGBColor[
              0.3000028152540131, 0.4326523584820372, 0.9403960885630988], 
             355 -> 
             RGBColor[
              0.5597098423756648, 0.6534366905384442, 0.9584815555579723], 
             175 -> RGBColor[
              0.39767741348965524`, 0.5188699205419315, 0.9465606310285997], 
             7 -> RGBColor[
              0.47235402937887205`, 0.5825173062131191, 0.951604585963978], 
             13 -> RGBColor[
              0.25294530714331137`, 0.3831919338393498, 0.9377162330915391], 
             294 -> RGBColor[
              0.18749202516745894`, 0.31439638450496027`, 0.9339887655124676],
              412 -> RGBColor[
              0.1902556572489104, 0.31730113704696017`, 0.934146150271079], 
             193 -> RGBColor[
              0.18092386766537458`, 0.30749283452503123`, 0.9336147186594421],
              60 -> RGBColor[
              0.9854928836228277, 0.9882689488092234, 0.890083991790846], 65 -> 
             RGBColor[
              0.183179266829206, 0.30986340204678436`, 0.9337431603052583], 
             448 -> RGBColor[
              0.300584051971647, 0.4332632751248068, 0.9404291891343054], 69 -> 
             RGBColor[
              0.44285619720498837`, 0.5580015122444584, 0.9494393831769108], 
             217 -> RGBColor[
              0.18124242467150065`, 0.3078276581361505, 0.9336328600096782], 
             214 -> RGBColor[
              0.1875451608924792, 0.3144522335209561, 0.9339917915134002], 
             170 -> RGBColor[
              0.1877350381466607, 0.3146518065540141, 0.9340026047421276], 
             359 -> RGBColor[
              0.9095261013751367, 0.9306954410809412, 0.9912326055643381], 74 -> 
             RGBColor[
              0.18870685733270803`, 0.31567325013544506`, 0.9340579484070953],
              246 -> RGBColor[
              0.2398990282396083, 0.3694794675296996, 0.9369732668082131], 
             264 -> RGBColor[
              0.8655438992520076, 0.482348074171085, 0.20951887252630852`], 
             278 -> RGBColor[
              0.18446408847726348`, 0.3112138310612903, 0.9338163289973919], 
             45 -> RGBColor[
              0.2011773237053474, 0.3287805009663242, 0.9347681230186154], 
             492 -> RGBColor[
              0.18260872208869527`, 0.3092637233498817, 0.9337106686263315], 
             306 -> RGBColor[
              0.24077004537273583`, 0.3703949617622926, 0.9370228699453904], 
             237 -> RGBColor[
              0.2328901660883635, 0.3621127090212143, 0.9365741224773821], 
             228 -> RGBColor[
              0.2582166797056685, 0.38873248062671145`, 0.9380164299606684], 
             180 -> 
             RGBColor[
              0.26314504718325327`, 0.39391250732219896`, 0.9382970931976505],
              383 -> RGBColor[
              0.2677744651747997, 0.39877831915336787`, 0.938560731703659], 
             53 -> RGBColor[
              0.8326746621018166, 0.2521573478086015, 0.17892259937043942`], 
             304 -> RGBColor[
              0.190709032669891, 0.3177776633600728, 0.934171969330595], 48 -> 
             RGBColor[
              0.18988308106937135`, 0.3169095358595705, 0.9341249326088312], 
             5 -> RGBColor[
              0.6895762664964494, 0.7574214874515429, 0.9696941758539234], 
             101 -> RGBColor[
              0.24511118458418202`, 0.3749577743176459, 0.9372700914013423], 
             333 -> RGBColor[
              0.23178823080036964`, 0.3609545051668002, 0.9365113688928981], 
             267 -> RGBColor[
              0.22925694712510034`, 0.35829396553143755`, 0.9363672160322901],
              120 -> RGBColor[
              0.1799037129149489, 0.30642058720078685`, 0.9335566223555891], 
             147 -> RGBColor[
              0.8190803262063154, 0.147665325039805, 0.16590464796430104`], 
             89 -> RGBColor[
              0.30968149308884285`, 0.4426522770943059, 0.940953608792397], 
             43 -> RGBColor[
              0.22836865224462058`, 0.35736031129090495`, 0.9363166289529613],
              199 -> RGBColor[
              0.3861343022549474, 0.5088718577640675, 0.9458251141878965], 
             268 -> RGBColor[
              0.1863015188096388, 0.3131450868404286, 0.9339209679365861], 
             169 -> RGBColor[
              0.18381241008660495`, 0.31052887575391175`, 0.9337792168771156],
              20 -> RGBColor[
              0.24175756143219096`, 0.3714329037529144, 0.9370791075240773], 
             4 -> RGBColor[
              0.18151204232925333`, 0.30811104338919537`, 0.9336482143364235],
              167 -> RGBColor[
              0.23986313789965336`, 0.369441744506828, 0.9369712229064477], 
             431 -> RGBColor[
              0.4212519905865513, 0.5392890343305656, 0.9480627822350338], 
             142 -> RGBColor[
              0.21571267720568413`, 0.3440580790898188, 0.9355958898973311], 
             16 -> RGBColor[
              0.27011669665931304`, 0.4012401529496448, 0.9386941183216809], 
             414 -> RGBColor[
              0.4226665958174486, 0.5405142942814426, 0.9481529196294604], 
             281 -> RGBColor[
              0.8184239254643847, 0.14261994130068656`, 0.16527607787252963`],
              289 -> 
             RGBColor[
              0.21007296758615746`, 0.3381303867014537, 0.9352747167777018], 
             398 -> RGBColor[
              0.20625914549310514`, 0.3341218178713687, 0.9350575252515466], 
             178 -> RGBColor[
              0.46930938565191127`, 0.5800455272759355, 0.9513649004568943], 
             58 -> RGBColor[
              0.19316750906165184`, 0.32036167792421966`, 0.9343119759241159],
              186 -> RGBColor[
              0.9933232264913885, 0.9881273815274607, 0.5146525917364964], 
             122 -> RGBColor[
              0.18567855904381614`, 0.3124903166286185, 0.9338854912995088], 
             249 -> RGBColor[
              0.7269497450043649, 0.7866179329108834, 0.9734192149165786], 
             113 -> RGBColor[
              0.19671677940387242`, 0.3240921860906307, 0.9345141016194304], 
             52 -> RGBColor[
              0.1799948891424975, 0.30651641919684713`, 0.9335618147068648], 
             409 -> RGBColor[
              0.2532336129818181, 0.38349496155526636`, 0.9377326516825317], 
             187 -> RGBColor[
              0.22124625332801934`, 0.34987421844338334`, 0.9359110188713058],
              259 -> RGBColor[
              0.6832732263253226, 0.7524975045649791, 0.9690659477149247], 42 -> 
             RGBColor[
              0.2005501569047806, 0.3281213088942566, 0.9347324067971333], 
             134 -> RGBColor[
              0.18413129784782198`, 0.3108640470096027, 0.9337973770633647], 
             470 -> RGBColor[
              0.19461387303716265`, 0.3218818981672542, 0.9343943442128174], 
             313 -> RGBColor[
              0.36122042818933575`, 0.4872927122561548, 0.9442376241629096], 
             248 -> RGBColor[
              0.18027294835259305`, 0.30680867705662973`, 0.933577649767528], 
             174 -> RGBColor[
              0.18747717117288942`, 0.31438077201487, 0.9339879195994514], 
             215 -> RGBColor[
              0.18496268734880916`, 0.3117378900882792, 0.9338447234655154], 
             399 -> RGBColor[
              0.20787897197296468`, 0.3358243582046317, 0.9351497719732561], 
             422 -> RGBColor[
              0.20654013009820746`, 0.33441715050678417`, 0.9350735269091277],
              83 -> RGBColor[
              0.9952268649647723, 0.9922942002460275, 0.7287667302186207], 95 -> 
             RGBColor[
              0.1846806812934658, 0.3114414838438967, 0.9338286636378542], 
             166 -> RGBColor[
              0.19568177386369887`, 0.32300432964476683`, 0.934455159585071], 
             384 -> 
             RGBColor[
              0.2680749969538752, 0.3990941971079916, 0.9385778465438803], 
             233 -> RGBColor[
              0.9625574020842641, 0.9715959522978471, 0.948264731064506], 295 -> 
             RGBColor[
              0.9847959098179251, 0.9879807322294865, 0.9016346514484699], 
             499 -> RGBColor[
              0.628572856489554, 0.7093427876395323, 0.96390270428255], 141 -> 
             RGBColor[
              0.2073090188644706, 0.33522530135049017`, 0.9351173139868973], 
             319 -> RGBColor[
              0.18086286172523808`, 0.3074287134139478, 0.9336112444614015], 
             205 -> RGBColor[
              0.23748131534596645`, 0.36693829798663086`, 0.936835581635606], 
             468 -> RGBColor[
              0.22150150348383524`, 0.3501425025409405, 0.9359255549900708], 
             486 -> RGBColor[
              0.41333459859387617`, 0.5324313873262027, 0.9475582930183354], 
             224 -> RGBColor[
              0.20593429362604587`, 0.3337803779622914, 0.9350390254182929], 
             231 -> RGBColor[
              0.7636579459089816, 0.81529465845023, 0.9770779453251097], 332 -> 
             RGBColor[
              0.18662770310860746`, 0.3134879272199237, 0.9339395436498659], 
             68 -> RGBColor[
              0.18542751526237852`, 0.31222645369723245`, 0.933871194727542], 
             484 -> RGBColor[
              0.1848118632397346, 0.3115793643868409, 0.933836134255628], 10 -> 
             RGBColor[
              0.22678684537035088`, 0.355697731973699, 0.9362265473915452], 
             250 -> RGBColor[
              0.2196415898680099, 0.3481876154053738, 0.9358196356611451], 
             282 -> RGBColor[
              0.6967134214587186, 0.7629970871524544, 0.9704055407600571], 
             374 -> RGBColor[
              0.847444298272204, 0.36568324351003745`, 0.19306601964712058`], 
             232 -> RGBColor[
              0.2784596091749779, 0.41000908297481403`, 0.939169234847215], 
             489 -> RGBColor[
              0.19162106685648111`, 0.3187362691164863, 0.9342239083282876], 
             253 -> RGBColor[
              0.37749249202520396`, 0.5013867560930751, 0.94527446568171], 
             459 -> RGBColor[
              0.1944799719611093, 0.3217411596465035, 0.9343867187446251], 
             415 -> RGBColor[
              0.1803991146634024, 0.3069412858486965, 0.9335848347522823], 55 -> 
             RGBColor[
              0.5735931996355866, 0.6647078254001658, 0.9595745042978867], 
             446 -> 
             RGBColor[
              0.18340710413885652`, 0.31010287350494686`, 0.9337561353029877],
              325 -> RGBColor[
              0.23363553097946993`, 0.3628961347806308, 0.9366165699052621], 
             91 -> RGBColor[
              0.46032419676718667`, 0.5727509461611696, 0.9506575534740573], 
             450 -> RGBColor[
              0.2155265395117455, 0.34386243657167787`, 0.9355852896310274], 
             423 -> RGBColor[
              0.1791999116318114, 0.3056808474286306, 0.9335165419136952], 
             105 -> RGBColor[
              0.1914252698739526, 0.31853047407360313`, 0.9342127579797883], 
             36 -> RGBColor[
              0.9941315043202534, 0.9918412404700345, 0.7469196908007765], 
             123 -> RGBColor[
              0.18584647349383113`, 0.3126668053619753, 0.93389505377903], 94 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 473 -> 
             RGBColor[
              0.2635938852306148, 0.3943842645679517, 0.9383226538604513], 
             312 -> RGBColor[
              0.19496888133162707`, 0.3222550343935622, 0.9344145614099995], 
             96 -> RGBColor[
              0.4707743379765772, 0.5812348415684494, 0.9514802268701891], 
             496 -> RGBColor[
              0.1858152550736946, 0.31263399282304966`, 0.9338932759361868], 
             2 -> RGBColor[
              0.18419449056434983`, 0.3109304665613231, 0.9338009757950858], 
             262 -> RGBColor[
              0.34316736625512184`, 0.47165605738201455`, 0.9430872990201573],
              272 -> RGBColor[
              0.25722683759211185`, 0.3876920938057486, 0.9379600599166416], 
             97 -> RGBColor[
              0.9884567952610653, 0.9727242013215213, 0.40965725865088887`], 
             372 -> RGBColor[
              0.6142711963162304, 0.6977320556283797, 0.9627768252049985], 
             356 -> RGBColor[
              0.24531622372842543`, 0.3751732834584783, 0.9372817680772788], 
             402 -> RGBColor[
              0.21812922311479366`, 0.346598022058153, 0.9357335086118955], 
             455 -> RGBColor[
              0.6130446091083116, 0.6967362568758672, 0.9626802637668542], 
             428 -> RGBColor[
              0.18777404508405116`, 0.31469280531839416`, 0.9340048261295064],
              346 -> RGBColor[
              0.4414153171565428, 0.5567534943672319, 0.9493475715743441], 
             341 -> RGBColor[
              0.9942973298741586, 0.9902108901662465, 0.6206777334817875], 
             209 -> RGBColor[
              0.9944761061763768, 0.9919837421934052, 0.7412087462437971], 
             498 -> RGBColor[
              0.7745863239297996, 0.8238319904188423, 0.9781671839147258], 
             378 -> RGBColor[
              0.20696414784897932`, 0.33486282004712353`, 0.9350976740927561],
              419 -> RGBColor[
              0.649286320101708, 0.725946675113037, 0.9656784505282513], 66 -> 
             RGBColor[
              0.19788231111085003`, 0.3253172338136426, 0.9345804769258931], 
             139 -> RGBColor[
              0.18259939511325524`, 0.3092539201073298, 0.9337101374688782], 
             56 -> RGBColor[
              0.4068474012204774, 0.5268125030173851, 0.9471449345381059], 
             335 -> RGBColor[
              0.21037507790267013`, 0.33844792379900884`, 0.935291921513295], 
             314 -> RGBColor[
              0.2628079616436893, 0.3935582090476596, 0.9382778966748457], 
             144 -> RGBColor[
              0.1968786888055324, 0.3242623631374243, 0.9345233221203314], 
             298 -> RGBColor[
              0.2756885017375273, 0.407096473359694, 0.9390114243781383], 204 -> 
             RGBColor[
              0.3159031668134525, 0.44804117816414885`, 0.941350048340519], 
             452 -> RGBColor[
              0.22680832648896532`, 0.3557203099913444, 0.9362277707094718], 
             466 -> RGBColor[
              0.19488624546246058`, 0.32216817885565147`, 0.9344098554194993],
              207 -> RGBColor[
              0.8749870106263872, 0.5252270374274478, 0.21739843612893187`], 
             334 -> RGBColor[
              0.18685517330782678`, 0.3137270128217468, 0.9339524977411994], 
             149 -> RGBColor[
              0.5611296111138018, 0.6545893227599167, 0.9585933249538227], 
             219 -> RGBColor[
              0.6695263659366376, 0.7417583527493299, 0.9676957891430948], 
             400 -> RGBColor[
              0.989868357531768, 0.9900783197151207, 0.8175710657562082], 9 -> 
             RGBColor[
              0.1937919382554366, 0.32101799259798497`, 0.9343475362429416], 
             11 -> RGBColor[
              0.37557365642318313`, 0.49972475713808634`, 0.9451521991739089],
              44 -> RGBColor[
              0.2790104916899246, 0.4105880954259918, 0.9392006067914836], 
             153 -> RGBColor[
              0.22763715789209957`, 0.35659146434698463`, 0.9362749714317341],
              471 -> RGBColor[
              0.9568366664708343, 0.967329437044196, 0.9579484442512339], 406 -> 
             RGBColor[
              0.41650215403555035`, 0.5351749646438152, 0.9477601268501196], 
             32 -> RGBColor[
              0.21967241372144744`, 0.34822001322968177`, 0.9358213910339986],
              162 -> RGBColor[
              0.18332605976082084`, 0.310017690725121, 0.933751519945553], 
             493 -> RGBColor[
              0.2609046791964185, 0.39155773852050096`, 0.9381695075551277], 
             90 -> RGBColor[
              0.2623509631444437, 0.39307787464957405`, 0.9382518712863824], 
             331 -> RGBColor[
              0.30143473291096856`, 0.4341573947283205, 0.94047763415533], 8 -> 
             RGBColor[
              0.19748659103157024`, 0.32490130692021735`, 0.9345579412527936],
              364 -> RGBColor[
              0.20439189938454302`, 0.3321592238210287, 0.9349511883480071], 
             342 -> RGBColor[
              0.47631296582080423`, 0.5857313491647339, 0.951916247942749], 
             163 -> RGBColor[
              0.899308535201446, 0.6356654000864056, 0.23769291240948212`], 
             49 -> RGBColor[
              0.9939249281250245, 0.9894143604804412, 0.5801441012857329], 
             338 -> RGBColor[
              0.4243323457115801, 0.5419570831167153, 0.9482590597397496], 76 -> 
             RGBColor[
              0.4104281337116228, 0.5299139535283672, 0.9473730956461243], 
             369 -> RGBColor[
              0.18202687820624844`, 0.30865216853839716`, 0.933677533477987], 
             445 -> RGBColor[
              0.9631188181102052, 0.8872532547517151, 0.3112240020952856], 82 -> 
             RGBColor[
              0.5201221497039563, 0.62129761822232, 0.955365067376359], 67 -> 
             RGBColor[
              0.18087272641393248`, 0.30743908182722296`, 0.9336118062408292],
              430 -> RGBColor[
              0.20155620116286646`, 0.329178725196395, 0.9347896995293221], 
             211 -> RGBColor[
              0.1874830946539544, 0.31438699796903974`, 
               0.933988256932935]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw1l3k4VA/cxYfs69jHPjOGGTNjV1rUPZUi6hcVbZKtXVmyRook2RJlqUih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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 42}], {
             RGBColor[
             0.19991385155278849`, 0.32745251162522343`, 0.9346961701486667]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 108}], {
             RGBColor[
             0.20444558985732308`, 0.3322156559120931, 0.9349542459410038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[
             0.1979971628023344, 0.3254379502234105, 0.9345870175598152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 119}], {
             RGBColor[
             0.1917982653600388, 0.3189225159787594, 0.9342339995209235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 120}], {
             RGBColor[
             0.18959062955787265`, 0.3166021507784885, 0.9341082779278946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 124}], {
             RGBColor[
             0.1923231620506201, 0.3194742156809328, 0.934263891610937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 315}], {
             RGBColor[
             0.19134373832478055`, 0.31844477924602455`, 0.934208114878678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 363}], {
             RGBColor[
             0.19094550353876433`, 0.3180262092363777, 0.93418543599675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 364}], {
             RGBColor[
             0.2018347227926697, 0.32947146908860947`, 0.9348055609241036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 378}], {
             RGBColor[
             0.20312084702488786`, 0.3308232672016569, 0.9348788037964781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 380}], {
             RGBColor[
             0.19337326869879815`, 0.3205779443487749, 0.9343236936310573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 381}], {
             RGBColor[
             0.1937883174344935, 0.32101418688560046`, 0.9343473300425454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 416}], {
             RGBColor[
             0.20425325698717794`, 0.33201350187096224`, 0.9349432928685801]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 452}], {
             RGBColor[
             0.21304293634488086`, 0.3412520121737673, 0.935443852104836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 468}], {
             RGBColor[
             0.21038952484231582`, 0.33846310844856536`, 0.9352927442451355]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 487}], {
             RGBColor[
             0.19600881958127922`, 0.3233480754298399, 0.9344737843548664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[
             0.19103840083759993`, 0.31812385018748285`, 0.9341907263604894]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 114}], {
             RGBColor[
             0.1828144030828347, 0.30947990711565043`, 0.93372238185467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 118}], {
             RGBColor[
             0.18820276986646162`, 0.31514342224742875`, 0.9340292413716232]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 195}], {
             RGBColor[
             0.18614467853761885`, 0.312980237770288, 0.933912036115119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 255}], {
             RGBColor[
             0.19068245309328063`, 0.3177497265398128, 0.9341704556630279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 260}], {
             RGBColor[
             0.1969726482624509, 0.32436112048401927`, 0.9345286729724024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 312}], {
             RGBColor[
             0.18958168594798847`, 0.3165927504774426, 0.9341077686025426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 327}], {
             RGBColor[
             0.18398683108609262`, 0.3107122032833034, 0.9337891498950037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 334}], {
             RGBColor[
             0.18552483193608832`, 0.31232873969153496`, 0.9338767367681426]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 385}], {
             RGBColor[
             0.1828749868990639, 0.3095435845477431, 0.9337258320133786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 446}], {
             RGBColor[
             0.18380079735160318`, 0.310516670033135, 0.9337785555490368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 496}], {
             RGBColor[
             0.18500487281902223`, 0.3117822296921864, 0.9338471258656362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[
             0.1847525458331286, 0.3115170180315573, 0.933832756217074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 139}], {
             RGBColor[
             0.18312900664284068`, 0.3098105754042345, 0.933740298061998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 158}], {
             RGBColor[
             0.187682952058607, 0.31459706077302096`, 0.9339996385164674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 247}], {
             RGBColor[
             0.18396896047476097`, 0.31069342013773166`, 0.9337881321901256]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 278}], {
             RGBColor[
             0.1840613533248448, 0.3107905308812148, 0.9337933938262548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 401}], {
             RGBColor[
             0.18219297080333685`, 0.308826742388816, 0.9336869922056792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 428}], {
             RGBColor[
             0.18571633162823864`, 0.3125300180097667, 0.9338876423923121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 437}], {
             RGBColor[
             0.18278910615931465`, 0.30945331844511326`, 0.9337209412322989]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 451}], {
             RGBColor[
             0.19437267435842231`, 0.32162838306301855`, 0.9343806083048847]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 31}], {
             RGBColor[
             0.18674651901237604`, 0.3136128102681478, 0.9339463100398131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 151}], {
             RGBColor[
             0.19261261169346405`, 0.31977844560772906`, 0.9342803753398946]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 162}], {
             RGBColor[
             0.18241905104503708`, 0.3090643670571582, 0.9336998671409883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 191}], {
             RGBColor[
             0.18605432886244289`, 0.31288527453317777`, 0.933906890834778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.18424586592068898`, 0.3109844653182212, 0.9338039015456263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 345}], {
             RGBColor[
             0.18617654721563465`, 0.31301373377147346`, 0.9339138509891864]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 366}], {
             RGBColor[
             0.18203443666830332`, 0.30866011296125107`, 0.9336779639212193]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 389}], {
             RGBColor[
             0.18821672881431478`, 0.31515809398667083`, 0.934030036313053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 405}], {
             RGBColor[
             0.18158563263707392`, 0.3081883914686098, 0.9336524051955868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 429}], {
             RGBColor[
             0.18673058009120463`, 0.3135960574514107, 0.9339454023418319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 472}], {
             RGBColor[
             0.18232394464799978`, 0.30896440420377813`, 0.9336944509723744]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 488}], {
             RGBColor[
             0.1820203772126724, 0.30864533558196194`, 0.9336771632560201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 69}], {
             RGBColor[
             0.5662162318507189, 0.6577114998480007, 0.959566779515417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[
             0.8424015657306109, 0.8748578438487853, 0.849230453036272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 97}], {
             RGBColor[
             0.8390165308787574, 0.8650728443865321, 0.6896757172524062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 103}], {
             RGBColor[
             0.5496901810493061, 0.6433974652672816, 0.958513754171764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 129}], {
             RGBColor[
             0.4894760344411281, 0.5894520908087815, 0.9547425358777173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 163}], {
             RGBColor[
             0.7944424008489477, 0.6965434437689743, 0.6036935441317027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 204}], {
             RGBColor[
             0.502739716654951, 0.6027313328078459, 0.9555221120972213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 209}], {
             RGBColor[
             0.8420261863364131, 0.8747026148224741, 0.8554514610488602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 231}], {
             RGBColor[
             0.7266171062027156, 0.7863580729508864, 0.9733860605895166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 233}], {
             RGBColor[
             0.8260668342903568, 0.864508719874695, 0.9589794534592146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 259}], {
             RGBColor[
             0.686424746410886, 0.7549594960082611, 0.969380061784424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 275}], {
             RGBColor[
             0.5894443177306294, 0.6768531688525092, 0.9613168922152756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 326}], {
             RGBColor[
             0.7074791480476834, 0.7714073545863063, 0.9714785677750102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 346}], {
             RGBColor[
             0.5654957918264961, 0.6570874909093873, 0.9595208737141337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 348}], {
             RGBColor[
             0.575828354505173, 0.6657991165139304, 0.9602449937132509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 355}], {
             RGBColor[
             0.624643054436057, 0.7054290889949936, 0.9640878657059478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 395}], {
             RGBColor[
             0.5968586468606165, 0.6828724552519535, 0.9619005753639707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 404}], {
             RGBColor[
             0.763201606478355, 0.8150742978846761, 0.9769963355615894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 431}], {
             RGBColor[
             0.5554141285415004, 0.6483552608910543, 0.9588784790444786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 444}], {
             RGBColor[
             0.627720184984083, 0.7079272421970324, 0.964330108694589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 486}], {
             RGBColor[
             0.5514554325451628, 0.6449264373888728, 0.9586262344361294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 35}], {
             RGBColor[
             0.2010217865796709, 0.32861702158561484`, 0.9347592654094047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 101}], {
             RGBColor[
             0.22975280750904292`, 0.3588151462343254, 0.9363954545475959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 123}], {
             RGBColor[
             0.20012045196386746`, 0.3276696617564901, 0.9347079357364398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 158}], {
             RGBColor[
             0.20305085818934585`, 0.33074970449795377`, 0.9348748180358333]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 181}], {
             RGBColor[
             0.2199559451719783, 0.348518022761122, 0.9358375377306591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 189}], {
             RGBColor[
             0.23318323402672853`, 0.3624207420060165, 0.9365908122629168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 302}], {
             RGBColor[
             0.22957764048616652`, 0.3586310345870516, 0.9363854790447795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 306}], {
             RGBColor[
             0.22758223790331983`, 0.3565337399566487, 0.93627184381962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 347}], {
             RGBColor[
             0.20873556607912272`, 0.336724692921407, 0.9351985537403844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 370}], {
             RGBColor[
             0.22157715427768293`, 0.35022201632181177`, 0.935929863190865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 390}], {
             RGBColor[
             0.23515410879898574`, 0.36449225635233673`, 0.9367030506655489]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 422}], {
             RGBColor[
             0.21046728026605566`, 0.33854483432889454`, 0.9352971723014887]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 428}], {
             RGBColor[
             0.2010842377589775, 0.3286826617346995, 0.9347628219116779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 451}], {
             RGBColor[
             0.20974058048916117`, 0.3377810267879514, 0.9352557878242505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 17}], {
             RGBColor[
             0.4238987520286698, 0.5410646532335288, 0.9483742450361144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.7309397602442707, 0.7862269209257184, 0.8874289178221101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.7313065318033417, 0.7863785903909934, 0.8813505639139341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.373934744333056, 0.4947159504930181, 0.9453030779152829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 89}], {
             RGBColor[
             0.39101776123385745`, 0.5125847916537125, 0.9462790973781875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 176}], {
             RGBColor[
             0.39464375574399807`, 0.5157254458506131, 0.9465101425420326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 178}], {
             RGBColor[
             0.47083170751539166`, 0.5812814167445273, 0.9514847432104361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 244}], {
             RGBColor[
             0.45953784870192455`, 0.5719334474988196, 0.9506451367617185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 261}], {
             RGBColor[
             0.40082339399554057`, 0.5210779379064496, 0.9469039036269813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 262}], {
             RGBColor[
             0.407760697816997, 0.5270866817975668, 0.9473459424920676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 288}], {
             RGBColor[
             0.5917887149964642, 0.6784248496808247, 0.9617281729213873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 295}], {
             RGBColor[
             0.7285749695983985, 0.7852490192213029, 0.9266196187062239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 313}], {
             RGBColor[
             0.4167872287841039, 0.534905009234637, 0.9479211050634437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 321}], {
             RGBColor[
             0.7288945912633815, 0.7853811909936754, 0.9213226605631021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 341}], {
             RGBColor[
             0.7333256796265153, 0.7863640981896829, 0.7861411597228827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 376}], {
             RGBColor[
             0.421731467240934, 0.5391874600812927, 0.9482361475658946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 391}], {
             RGBColor[
             0.47273438056684836`, 0.582826092442144, 0.9516345286027679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 407}], {
             RGBColor[
             0.3747418079101595, 0.4955642254833401, 0.9453490389920554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 448}], {
             RGBColor[
             0.38646904067525956`, 0.507890290668963, 0.9460168875491417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 455}], {
             RGBColor[
             0.5426993192435918, 0.6396267815444932, 0.9571424248654161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 475}], {
             RGBColor[
             0.40444131336028016`, 0.5242115978182725, 0.9471344342497021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 478}], {
             RGBColor[
             0.36083387288200847`, 0.48094610395474147`, 0.9445570026671483]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 482}], {
             RGBColor[
             0.4023630118874444, 0.5224114775409715, 0.9470020067176228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 63}], {
             RGBColor[
             0.20214886588846875`, 0.32980165340011697`, 0.9348234509086764]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 85}], {
             RGBColor[
             0.19237812780276942`, 0.31953198817147166`, 0.9342670218292075]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 146}], {
             RGBColor[
             0.18877984751216192`, 0.31574996744189576`, 0.934062105089836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 159}], {
             RGBColor[
             0.21480140592500557`, 0.34310027519588937`, 0.9355439943460016]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 166}], {
             RGBColor[
             0.19658418244763454`, 0.3239528182824921, 0.9345065504189323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 239}], {
             RGBColor[
             0.19706547094004007`, 0.32445868300346314`, 0.9345339590865722]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 344}], {
             RGBColor[
             0.19388121074334685`, 0.3211118236429813, 0.9343526201790614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 387}], {
             RGBColor[
             0.19318868595476607`, 0.32038393618157524`, 0.9343131819168503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 435}], {
             RGBColor[
             0.21794255850182165`, 0.34640182571469935`, 0.9357228783383325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 439}], {
             RGBColor[
             0.1983584490277003, 0.3258176849531398, 0.9346075922758748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 453}], {
             RGBColor[
             0.21870849923514318`, 0.34720687798886773`, 0.9357664975299873]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 68}], {
             RGBColor[
             0.18960972675890758`, 0.3166222231476087, 0.9341093654852418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 95}], {
             RGBColor[
             0.18923630977445122`, 0.3162297382209408, 0.934088099940398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 286}], {
             RGBColor[
             0.19059390233229334`, 0.3176566540755726, 0.9341654128281889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 319}], {
             RGBColor[
             0.18732739999033735`, 0.3142233530059664, 0.9339793903521716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 330}], {
             RGBColor[
             0.19168631998098046`, 0.3188048542876222, 0.9342276243971945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 333}], {
             RGBColor[
             0.21279008452790313`, 0.3409862488823926, 0.9354294525679199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 352}], {
             RGBColor[
             0.18859199395283752`, 0.3155525214404422, 0.9340514071075369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 357}], {
             RGBColor[
             0.19116813878282407`, 0.31826021299377427`, 0.9341981147445398]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 358}], {
             RGBColor[
             0.2093374978833109, 0.33735736141228945`, 0.9352328328661546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 367}], {
             RGBColor[
             0.19547077493947268`, 0.3227825563973006, 0.9344431435084812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 368}], {
             RGBColor[
             0.18651190777224702`, 0.3133662189795604, 0.933932949276764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 375}], {
             RGBColor[
             0.19826733232951002`, 0.32572191552620944`, 0.934602403314708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 441}], {
             RGBColor[
             0.2076297588947049, 0.33556241945835885`, 0.9351355796571268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 450}], {
             RGBColor[
             0.20465923888359105`, 0.3324402145848314, 0.9349664129369846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 492}], {
             RGBColor[
             0.18820033017206594`, 0.3151408579739333, 0.9340291024346365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 102}], {
             RGBColor[
             0.21311463700569694`, 0.34132737411436953`, 0.9354479353513978]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 168}], {
             RGBColor[
             0.25974966627430485`, 0.39034374670731053`, 0.9381037312779018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 181}], {
             RGBColor[
             0.22615215264020183`, 0.355030629672469, 0.9361904025795069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.23937944149495205`, 0.3689333489173635, 0.9369436771117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 232}], {
             RGBColor[
             0.2526232272726644, 0.38285340747425656`, 0.9376978911193801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 280}], {
             RGBColor[
             0.24013030719270134`, 0.36972255637333296`, 0.9369864378024453]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 302}], {
             RGBColor[
             0.23577384795439005`, 0.3651436414983986, 0.9367383438936274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 370}], {
             RGBColor[
             0.22777336174590646`, 0.35673462323315885`, 0.9362827280397129]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 383}], {
             RGBColor[
             0.24728065527257528`, 0.3772380255635335, 0.9373936395476021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 390}], {
             RGBColor[
             0.24135031626720926`, 0.37100486326368376`, 0.9370559155143968]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 443}], {
             RGBColor[
             0.2573117613989959, 0.387781354111264, 0.9379648962018101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 451}], {
             RGBColor[
             0.2159367879573847, 0.34429363369929844`, 0.9356086526730982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 480}], {
             RGBColor[
             0.2350739989368308, 0.3644080558079533, 0.9366984885274112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 25}], {
             RGBColor[
             0.3322342574825351, 0.46035097441527295`, 0.9424578530175007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 164}], {
             RGBColor[
             0.3457994968745498, 0.4739358766298315, 0.9432550160557256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 180}], {
             RGBColor[
             0.31935935180321817`, 0.4468186322301426, 0.9417246461857798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 205}], {
             RGBColor[
             0.3065274858845748, 0.4333315275623586, 0.9409938904047574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 259}], {
             RGBColor[
             0.5294234413742529, 0.6261111308515327, 0.9571090734444168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 316}], {
             RGBColor[
             0.4071433573553281, 0.5270688453462049, 0.9471637926013148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 331}], {
             RGBColor[
             0.3385041946670758, 0.46694107593320344`, 0.9428149166646195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 348}], {
             RGBColor[
             0.41882704946853977`, 0.5369507513572022, 0.9479740053732437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 372}], {
             RGBColor[
             0.49492242636970674`, 0.598728406383233, 0.9539645121894538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 404}], {
             RGBColor[
             0.6062003014417219, 0.6862259327279479, 0.9647253472215822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 418}], {
             RGBColor[
             0.4260394736081712, 0.5428061221897597, 0.9485417938214956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 431}], {
             RGBColor[
             0.3984128235048672, 0.519506895734326, 0.9466074907044714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 444}], {
             RGBColor[
             0.4707188799474499, 0.5790788770403041, 0.9520591203545818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 40}], {
             RGBColor[
             0.18952205245126588`, 0.31653007189140514`, 0.9341043725631242]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 161}], {
             RGBColor[
             0.20394297282787943`, 0.33168737354638755`, 0.9349256226447324]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 188}], {
             RGBColor[
             0.20900601855676193`, 0.3370089556230833, 0.9352139556088873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 202}], {
             RGBColor[
             0.1903977819160206, 0.31745051908331734`, 0.9341542440606163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 243}], {
             RGBColor[
             0.19530733769648173`, 0.3226107734923974, 0.9344338359992765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 273}], {
             RGBColor[
             0.1905970563658978, 0.31765996916486816`, 0.9341655924457366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 279}], {
             RGBColor[
             0.2010090657422573, 0.3286036511789455, 0.9347585409765328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 283}], {
             RGBColor[
             0.18817638831560224`, 0.31511569356478863`, 0.9340277389813298]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 285}], {
             RGBColor[
             0.20421155270957553`, 0.33196966803099826`, 0.9349409178716667]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 318}], {
             RGBColor[
             0.19600810188078815`, 0.32334732108111897`, 0.9344737434828851]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 335}], {
             RGBColor[
             0.20220521707563277`, 0.32986088207069797`, 0.9348266600254211]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 396}], {
             RGBColor[
             0.19573690002635402`, 0.32306227073691796`, 0.9344582989384823]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 421}], {
             RGBColor[
             0.18918604161445732`, 0.31617690319760183`, 0.9340852372430514]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 430}], {
             RGBColor[
             0.19779577870573095`, 0.32522628276939103`, 0.9345755490334348]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 459}], {
             RGBColor[
             0.19425766410485237`, 0.3215074999944453, 0.9343740586410862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 477}], {
             RGBColor[
             0.19591456128829632`, 0.32324900398759393`, 0.9344684164845236]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 21}], {
             RGBColor[
             0.27647406119866225`, 0.4079221461606935, 0.9390561608273189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 59}], {
             RGBColor[
             0.2579706137078198, 0.3884738496614871, 0.938002416866113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 77}], {
             RGBColor[
             0.293706622672794, 0.4236564919439787, 0.9401246061243856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 87}], {
             RGBColor[
             0.28067879095443904`, 0.41234158372927926`, 0.9392956139665702]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 161}], {
             RGBColor[
             0.23339794827523738`, 0.36264642029486893`, 0.9366030399217282]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 188}], {
             RGBColor[
             0.23846099400411988`, 0.36796800237156463`, 0.9368913728858832]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 228}], {
             RGBColor[
             0.2555809934244899, 0.38596220723303065`, 0.9378663315261038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 243}], {
             RGBColor[
             0.2247623131438397, 0.3535698202408788, 0.9361112532762724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 256}], {
             RGBColor[
             0.2822514185299613, 0.41373456987075796`, 0.9393946906458437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 279}], {
             RGBColor[
             0.23046404118961528`, 0.35956269792742684`, 0.9364359582535287]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 285}], {
             RGBColor[
             0.2336665281569335, 0.36292871477947963`, 0.9366183351486626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 287}], {
             RGBColor[
             0.2785495730651827, 0.41010364072745936`, 0.9391743581576726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 298}], {
             RGBColor[
             0.26431690444041933`, 0.3951442035995219, 0.9383638287348387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 335}], {
             RGBColor[
             0.23166019252299075`, 0.36081992881917935`, 0.936504077302417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 354}], {
             RGBColor[
             0.28176652075351294`, 0.4133145757884693, 0.9393637933883066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 409}], {
             RGBColor[
             0.2530894600625647, 0.3833434476973081, 0.9377244423870355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 430}], {
             RGBColor[
             0.22725075415308893`, 0.3561853295178724, 0.9362529663104306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 477}], {
             RGBColor[
             0.2253695367356543, 0.3542080507360753, 0.9361458337615195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 80}], {
             RGBColor[
             0.28919811932082623`, 0.417720629815705, 0.9399116866604884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 159}], {
             RGBColor[
             0.2315482163827265, 0.3607022347960642, 0.9364977004268829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 166}], {
             RGBColor[
             0.21333099290535548`, 0.34155477788266697`, 0.9354602564998136]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 192}], {
             RGBColor[
             0.27198473276549623`, 0.40281125955144237`, 0.9388148648903828]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.21659885926136652`, 0.3449895126175285, 0.9356463566544133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 239}], {
             RGBColor[
             0.21381228139776098`, 0.3420606426036381, 0.9354876651674535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 251}], {
             RGBColor[
             0.23495511782487732`, 0.36428310422179233`, 0.9366917184239543]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 272}], {
             RGBColor[
             0.24410352476956199`, 0.37389865996315785`, 0.9372127066655989]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 435}], {
             RGBColor[
             0.23468936895954257`, 0.3640037853148743, 0.9366765844192138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 447}], {
             RGBColor[
             0.2323548964610662, 0.3615501067048703, 0.936543639663968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 453}], {
             RGBColor[
             0.23545530969286413`, 0.36480883758904264`, 0.9367202036108686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 454}], {
             RGBColor[
             0.2211862721127522, 0.34981117438310894`, 0.9359076030298306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 489}], {
             RGBColor[
             0.2113006394017466, 0.3394207476185267, 0.935344630871422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 50}], {
             RGBColor[
             0.7663849277124503, 0.8179130209698517, 0.9772202389257285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 82}], {
             RGBColor[
             0.5862643398841738, 0.6748409125363397, 0.9606772556368353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 126}], {
             RGBColor[
             0.5704313985291926, 0.6619870174784861, 0.9594308284953961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 149}], {
             RGBColor[
             0.6067680705890965, 0.6914867648051379, 0.9622913844255672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 173}], {
             RGBColor[
             0.6865018666299831, 0.7550197429095551, 0.9693877484071343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 242}], {
             RGBColor[
             0.8127597142986478, 0.8539262155582815, 0.9481932363943286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 249}], {
             RGBColor[
             0.6896781375343781, 0.7575010698806214, 0.9697043294069452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 269}], {
             RGBColor[
             0.6271401903527347, 0.708025769382796, 0.9638951523188943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 282}], {
             RGBColor[
             0.674559975761555, 0.7456906470014069, 0.9681974923286845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 323}], {
             RGBColor[
             0.82255832396822, 0.8598188337480478, 0.8682325932875272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 414}], {
             RGBColor[
             0.53753656294092, 0.634449250565901, 0.957071181763386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 419}], {
             RGBColor[
             0.6508464250830497, 0.7271654409816981, 0.9658339472127815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 449}], {
             RGBColor[
             0.8180065894164226, 0.8423738625918746, 0.678402399648858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 499}], {
             RGBColor[
             0.6404896932769727, 0.7188634972449458, 0.9649460740899308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 17}], {
             RGBColor[
             0.32278008566889027`, 0.45042607660179157`, 0.9419190112149659]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 116}], {
             RGBColor[
             0.2732978193858072, 0.4045837146300204, 0.9388752785549055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 143}], {
             RGBColor[
             0.42538425366010096`, 0.535839238383477, 0.9494121511680118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 165}], {
             RGBColor[
             0.28802163997316926`, 0.4200593836114821, 0.9397137783554151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 185}], {
             RGBColor[
             0.2408288180096403, 0.3704567355300795, 0.9370262169601158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.2456814749936662, 0.3755571856965141, 0.9373025685964933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 224}], {
             RGBColor[
             0.23802549514267946`, 0.3675102654559681, 0.9368665718699869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 277}], {
             RGBColor[
             0.35667163535651547`, 0.47978123350239554`, 0.9440785507919407]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 313}], {
             RGBColor[
             0.3156685624243244, 0.4442664326028998, 0.9414658712422952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 333}], {
             RGBColor[
             0.25095246372984137`, 0.3810973290582225, 0.9376027436072896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 358}], {
             RGBColor[
             0.24749987708524912`, 0.37746844158811943`, 0.9374061239055242]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 361}], {
             RGBColor[
             0.2501087241581385, 0.3802105052721842, 0.9375546938868818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 386}], {
             RGBColor[
             0.2878595743491687, 0.4198890423651035, 0.9397045489578829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 441}], {
             RGBColor[
             0.2457921380966431, 0.37567349963418883`, 0.9373088706964965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 89}], {
             RGBColor[
             0.3425624838836552, 0.4711321386741221, 0.9430487564503239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.6775706975021587, 0.7419956614956686, 0.932197104376443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 116}], {
             RGBColor[
             0.32596120839538445`, 0.45376963828216715`, 0.9421001714481905]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 143}], {
             RGBColor[
             0.4780476426696782, 0.5850251620356237, 0.9526370440612968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 165}], {
             RGBColor[
             0.3406850289827465, 0.4692453072636289, 0.9429386712487001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 176}], {
             RGBColor[
             0.3461884783937958, 0.47427279287102275`, 0.943279801614169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 178}], {
             RGBColor[
             0.4223764301651894, 0.5398287637649369, 0.9482544022825725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 261}], {
             RGBColor[
             0.3523681166453383, 0.4796252849268593, 0.9436735626991177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 277}], {
             RGBColor[
             0.4093350243660927, 0.5289671571545423, 0.9473034436852257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 288}], {
             RGBColor[
             0.543333437646262, 0.6369721967012344, 0.9584978319935238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 313}], {
             RGBColor[
             0.3683319514339016, 0.4934523562550466, 0.9446907641355802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 321}], {
             RGBColor[
             0.6804393139131792, 0.743928538014085, 0.9180923196352385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 328}], {
             RGBColor[
             0.30921498256740126`, 0.43616829316491434`, 0.9411464986611078]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 386}], {
             RGBColor[
             0.34052296335874593`, 0.4690749660172503, 0.9429294418511679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 391}], {
             RGBColor[
             0.4242791032166461, 0.5413734394625537, 0.9484041876749043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 407}], {
             RGBColor[
             0.3262865305599572, 0.4541115725037497, 0.9421186980641918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 455}], {
             RGBColor[
             0.49424404189338955`, 0.5981741285649027, 0.9539120839375526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 498}], {
             RGBColor[
             0.5750148993041335, 0.6617219953363903, 0.9616555440114883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 28}], {
             RGBColor[
             0.38207742266917044`, 0.5028572911387341, 0.9458047612186589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 93}], {
             RGBColor[
             0.25547187449726694`, 0.38584751632197967`, 0.9378601173646254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 160}], {
             RGBColor[
             0.26388110219154026`, 0.3946861478044915, 0.9383390104414766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 167}], {
             RGBColor[
             0.2640882538669924, 0.39490387734956656`, 0.9383508074229403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 172}], {
             RGBColor[
             0.2559027333199868, 0.38630037626268543`, 0.9378846541371808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 201}], {
             RGBColor[
             0.27288253451918126`, 0.4041472239046152, 0.93885162869611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 218}], {
             RGBColor[
             0.2870949982165383, 0.4190854243727823, 0.9396610074782187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 235}], {
             RGBColor[
             0.2527156376053866, 0.3829505365931011, 0.9377031537511198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 274}], {
             RGBColor[
             0.2661988733080245, 0.397122272203093, 0.9384710040777253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 300}], {
             RGBColor[
             0.26008832470075693`, 0.39069969818569605`, 0.938123017374288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 305}], {
             RGBColor[
             0.2994340109078254, 0.43188728681651606`, 0.9403698188221772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 310}], {
             RGBColor[
             0.46656300779364224`, 0.5714089084514553, 0.952481474208732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 406}], {
             RGBColor[
             0.35240776193494094`, 0.47777048741806016`, 0.9437452593947762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 432}], {
             RGBColor[
             0.2897732046951418, 0.4219003891898929, 0.9398135273751238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 460}], {
             RGBColor[
             0.2944934860338214, 0.4268617041599678, 0.940082340414331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 493}], {
             RGBColor[
             0.274609024515375, 0.4059618743564031, 0.9389499497472802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 26}], {
             RGBColor[
             0.1940564817835153, 0.32129604461902417`, 0.9343626016055087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 59}], {
             RGBColor[
             0.2331068284328231, 0.3623404348824274, 0.936586461077376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 67}], {
             RGBColor[
             0.1920452315036252, 0.3191820930542266, 0.9342480638774471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 124}], {
             RGBColor[
             0.1942932572468809, 0.3215449106434528, 0.9343760856178694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 188}], {
             RGBColor[
             0.21359720872912316`, 0.3418345875925049, 0.9354754170971461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 200}], {
             RGBColor[
             0.23309658772441674`, 0.3623296712485939, 0.936585877884182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 228}], {
             RGBColor[
             0.2307172081494932, 0.3598287924539709, 0.9364503757373667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 298}], {
             RGBColor[
             0.2394531191654226, 0.3690107888204622, 0.9369478729461016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 318}], {
             RGBColor[
             0.20059929205314941`, 0.3281729530505406, 0.9347352049711439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 335}], {
             RGBColor[
             0.20679640724799403`, 0.3346865140401196, 0.9350881215136799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 459}], {
             RGBColor[
             0.1988488542772136, 0.32633313196386693`, 0.934635520129345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 468}], {
             RGBColor[
             0.21235962003857659`, 0.3405338034110854, 0.9354049382520679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 25}], {
             RGBColor[
             0.26532620998703904`, 0.39620504772268694`, 0.9384213071925849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 46}], {
             RGBColor[
             0.22273395828831882`, 0.35143789068260056`, 0.9359957414679326]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 150}], {
             RGBColor[
             0.22855902835216374`, 0.35756040865047517`, 0.9363274705906497]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 220}], {
             RGBColor[
             0.2293954500117661, 0.35843954084691343`, 0.9363751035667891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 325}], {
             RGBColor[
             0.23769654620583044`, 0.3671645192667726, 0.9368478387146697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 388}], {
             RGBColor[
             0.2852227543233797, 0.4152738080593815, 0.9396218953833091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 392}], {
             RGBColor[
             0.2393040747004234, 0.36885413363778313`, 0.9369393850843115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 413}], {
             RGBColor[
             0.23603377197510877`, 0.36541683812430875`, 0.9367531461820842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 473}], {
             RGBColor[
             0.25267572333140287`, 0.38290858416043305`, 0.9377008806922643]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 474}], {
             RGBColor[
             0.2356355428107931, 0.36499827402342566`, 0.9367304676203037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 490}], {
             RGBColor[
             0.22886274008807128`, 0.3578796289413503, 0.9363447665247084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 55}], {
             RGBColor[
             0.4367980074447999, 0.5486800919411015, 0.9499852964304927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 59}], {
             RGBColor[
             0.2814993677631707, 0.4132040619828309, 0.9393423446018928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 77}], {
             RGBColor[
             0.3172353767281449, 0.44838670426532234`, 0.9414645338601655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[
             0.30420754500978997`, 0.43707179605062296`, 0.94063554170235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 91}], {
             RGBColor[
             0.3801635060105999, 0.5027016523216035, 0.9455268210185781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 188}], {
             RGBColor[
             0.26198974805947073`, 0.39269821469290833`, 0.9382313006216629]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 200}], {
             RGBColor[
             0.28148912705476437`, 0.4131932983489973, 0.9393417614086988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 228}], {
             RGBColor[
             0.2791097474798408, 0.4106924195543743, 0.9392062592618835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 256}], {
             RGBColor[
             0.3057801725853121, 0.43846478219210167`, 0.9407346183816234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 287}], {
             RGBColor[
             0.30207832712053356`, 0.43483385304880307`, 0.9405142858934524]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 298}], {
             RGBColor[
             0.2878456584957702, 0.4198744159208656, 0.9397037564706185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 335}], {
             RGBColor[
             0.2551889465783416, 0.385550141140523, 0.9378440050381969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 336}], {
             RGBColor[
             0.4626767064166898, 0.5696895855885848, 0.9520225624103578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 354}], {
             RGBColor[
             0.30529527480886387`, 0.43804478810981307`, 0.9407037211240865]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 409}], {
             RGBColor[
             0.27661821411791565`, 0.40807366001865175`, 0.9390643701228152]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 24}], {
             RGBColor[
             0.18354454614871424`, 0.31024733377163405`, 0.9337639624221219]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 52}], {
             RGBColor[
             0.18089659272171946`, 0.3074641668299184, 0.9336131653917505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 170}], {
             RGBColor[
             0.18476666722380106`, 0.3115318605085019, 0.9338335604093819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 214}], {
             RGBColor[
             0.1846717285967103, 0.31143207399197287`, 0.9338281537950183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 268}], {
             RGBColor[
             0.1840499075552901, 0.3107785006517091, 0.9337927420066112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 466}], {
             RGBColor[
             0.188342270881701, 0.3152900466593206, 0.9340371857480678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 491}], {
             RGBColor[
             0.1817125626643469, 0.3083218029751023, 0.9336596336728639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 39}], {
             RGBColor[
             0.3397705873831411, 0.4630597387061178, 0.9430778872171774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 51}], {
             RGBColor[
             0.7136013437576199, 0.7704045833430664, 0.8366928314862011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 62}], {
             RGBColor[
             0.34157168432943963`, 0.4649528057928196, 0.943180457023785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 96}], {
             RGBColor[
             0.4513622669101063, 0.5648950617926353, 0.9501123446420765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 110}], {
             RGBColor[
             0.42451306437954106`, 0.5421136125437187, 0.9482705749734688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 136}], {
             RGBColor[
             0.48008619598652036`, 0.5882144414151268, 0.9523735975581908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 157}], {
             RGBColor[
             0.36552292420320903`, 0.49012707749646917`, 0.944544444701912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 240}], {
             RGBColor[
             0.7133780917330446, 0.7699270698367418, 0.8123932263629633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 360}], {
             RGBColor[
             0.5140568870299039, 0.6157933787663372, 0.9550478947958676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 52}], {
             RGBColor[
             0.18264284256949226`, 0.3092995861385628, 0.9337126117372361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 64}], {
             RGBColor[
             0.18504835804129488`, 0.3118279354179173, 0.933849602284714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.18699882666459755`, 0.3138780016078617, 0.9339606785873513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 115}], {
             RGBColor[
             0.18813870785962614`, 0.3150760890164789, 0.9340255931351051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 170}], {
             RGBColor[
             0.18651291707157386`, 0.3133672798171463, 0.9339330067548675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 223}], {
             RGBColor[
             0.19673773915135, 0.32411421611415436`, 0.934515295246042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 268}], {
             RGBColor[
             0.18579615740306293`, 0.3126139199603535, 0.9338921883520968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 491}], {
             RGBColor[
             0.1834588125121197, 0.3101572222837467, 0.9337590800183494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 164}], {
             RGBColor[
             0.3024600979339018, 0.4345620939070181, 0.9405606698993174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.2760199528625702, 0.4074448495073293, 0.9390303000293716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 220}], {
             RGBColor[
             0.25296409856661417`, 0.38321168481668605`, 0.9377173032352967]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 316}], {
             RGBColor[
             0.36380395841468005`, 0.4876950626233916, 0.9444694464449066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 325}], {
             RGBColor[
             0.26126519476067855`, 0.3919366632365452, 0.9381900383831774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 392}], {
             RGBColor[
             0.26287272325527145`, 0.39362627760755575`, 0.9382815847528192]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 413}], {
             RGBColor[
             0.25960242052995686`, 0.39018898209408137`, 0.9380953458505918]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 474}], {
             RGBColor[
             0.2592041913656412, 0.3897704179931982, 0.9380726672888113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 490}], {
             RGBColor[
             0.25243138864291936`, 0.38265177291112284`, 0.937686966193216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 67}], {
             RGBColor[
             0.1828839766938226, 0.30955303339202045`, 0.9337263439688908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 124}], {
             RGBColor[
             0.18513200243707828`, 0.31191585098124663`, 0.9338543657093131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 318}], {
             RGBColor[
             0.1914380372433468, 0.3185438933883344, 0.9342134850625876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 335}], {
             RGBColor[
             0.1976351524381914, 0.3250574543779134, 0.9345664016051236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 459}], {
             RGBColor[
             0.18968759946741098`, 0.31670407230166076`, 0.9341138002207887]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 29}], {
             RGBColor[
             0.18482045324878804`, 0.31158839303099417`, 0.9338366234439357]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 65}], {
             RGBColor[
             0.1841954077512366, 0.31093143058289413`, 0.9338010280275222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 86}], {
             RGBColor[
             0.18526169591288671`, 0.3120521670473626, 0.9338617515608961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 177}], {
             RGBColor[
             0.18479696914654997`, 0.31156370975056386`, 0.9338352860590549]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[
             0.1856592913664621, 0.31247006507807806`, 0.9338843940337875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 290}], {
             RGBColor[
             0.18336907213961767`, 0.31006289946237875`, 0.9337539694368944]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 297}], {
             RGBColor[
             0.19023703211735066`, 0.31728156085278936`, 0.93414508959739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 350}], {
             RGBColor[
             0.18336792975933797`, 0.3100616987482737, 0.9337539043800275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 412}], {
             RGBColor[
             0.18773360296108882`, 0.31465029808298206`, 0.9340025230104325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 484}], {
             RGBColor[
             0.1850117059565009, 0.3117894117529224, 0.933847515002707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 490}], {
             RGBColor[
             0.20058973370860944`, 0.328162906624395, 0.9347346606375627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 125}], {
             RGBColor[
             0.6268956164581168, 0.7059040511517584, 0.965190775014533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 149}], {
             RGBColor[
             0.5184855433089055, 0.6199689474225398, 0.9552362277258538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 201}], {
             RGBColor[
             0.3666465873540202, 0.4866385048510442, 0.9449259979753362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 218}], {
             RGBColor[
             0.38085905105137724`, 0.5015767053192113, 0.9457353767574448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 282}], {
             RGBColor[
             0.586277448481364, 0.6741728296188088, 0.961142335628971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 305}], {
             RGBColor[
             0.3931980637426643, 0.5143785677629451, 0.9464441881014032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 310}], {
             RGBColor[
             0.5603270606284811, 0.6539001893978842, 0.958555843487958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 406}], {
             RGBColor[
             0.44617181476977985`, 0.5602617683644892, 0.9498196286740023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 408}], {
             RGBColor[
             0.7065627960875993, 0.7690478747515729, 0.9714624707191005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 419}], {
             RGBColor[
             0.5625638978028586, 0.6556476235991, 0.9587787905130681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 432}], {
             RGBColor[
             0.38353725752998075`, 0.5043916701363219, 0.9458878966543498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 493}], {
             RGBColor[
             0.36837307735021396`, 0.48845315530283206`, 0.9450243190265064]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 46}], {
             RGBColor[
             0.19406985648437775`, 0.32131010227763557`, 0.9343633632749366]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 65}], {
             RGBColor[
             0.1838043123267574, 0.3105203644948844, 0.9337787557216719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 86}], {
             RGBColor[
             0.18487060048840748`, 0.3116411009593528, 0.9338394792550458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 177}], {
             RGBColor[
             0.18440587372207073`, 0.31115264366255413`, 0.9338130137532046]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 194}], {
             RGBColor[
             0.18526819594198288`, 0.31205899899006834`, 0.9338621217279373]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 254}], {
             RGBColor[
             0.18842942576301586`, 0.31538165196552115`, 0.9340421490896246]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 290}], {
             RGBColor[
             0.18297797671513846`, 0.309651833374369, 0.9337316971310441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 297}], {
             RGBColor[
             0.18984593669287142`, 0.3168704947647796, 0.9341228172915397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 350}], {
             RGBColor[
             0.18297683433485876`, 0.309650632660264, 0.9337316320741772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 377}], {
             RGBColor[
             0.18261049498864607`, 0.3092655867801383, 0.9337107695903608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 412}], {
             RGBColor[
             0.18734250753660958`, 0.3142392319949723, 0.9339802507045822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 426}], {
             RGBColor[
             0.18589315152803693`, 0.3127158669354839, 0.933897712024024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 476}], {
             RGBColor[
             0.18392969470854525`, 0.3106521493278456, 0.933785896062828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 31}], {
             RGBColor[
             0.185457486240386, 0.3122579550953881, 0.9338729015304014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 133}], {
             RGBColor[
             0.18845727560531045`, 0.31541092391555475`, 0.934043735096943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 191}], {
             RGBColor[
             0.18476529609045284`, 0.31153041936041803`, 0.9338334823253662]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 311}], {
             RGBColor[
             0.18445928711484194`, 0.31120878452496137`, 0.9338160555669048]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 366}], {
             RGBColor[
             0.1807454038963133, 0.3073052577884914, 0.9336045554118075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 405}], {
             RGBColor[
             0.1802965998650839, 0.3068335362958501, 0.9335789966861752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 423}], {
             RGBColor[
             0.17906694420854233`, 0.3055410902361533, 0.9335089696156476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 429}], {
             RGBColor[
             0.18544154731921458`, 0.312241202278651, 0.9338719938324201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 465}], {
             RGBColor[
             0.17899164586466354`, 0.3054619469025459, 0.9335046814863577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 469}], {
             RGBColor[
             0.18014325773351766`, 0.30667236399312137`, 0.9335702640786318]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 488}], {
             RGBColor[
             0.18073134444068237`, 0.30729048040920226`, 0.9336037547466085]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 133}], {
             RGBColor[
             0.1949807850604232, 0.3222675459672669, 0.9344152393097445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 191}], {
             RGBColor[
             0.1912888055455656, 0.31838704141213026`, 0.9342049865381675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 226}], {
             RGBColor[
             0.1894803426038117, 0.3164862321971737, 0.9341019972490159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 237}], {
             RGBColor[
             0.21243558089193113`, 0.3406136430841573, 0.9354092641102925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 311}], {
             RGBColor[
             0.1909827965699547, 0.3180654065766735, 0.9341875597797062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 366}], {
             RGBColor[
             0.18726891335142604`, 0.3141618798402035, 0.9339760596246088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 405}], {
             RGBColor[
             0.18682010932019663`, 0.3136901583475623, 0.9339505008989764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 429}], {
             RGBColor[
             0.19196505677432735`, 0.31909782433036316`, 0.9342434980452214]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 472}], {
             RGBColor[
             0.1875584213311225, 0.31446617108273056`, 0.9339925466757639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 488}], {
             RGBColor[
             0.1872548538957951, 0.31414710246091443`, 0.9339752589594097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 66}], {
             RGBColor[
             0.20877736241614875`, 0.33676862352166215`, 0.9352009339799459]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 84}], {
             RGBColor[
             0.2475939365043437, 0.3775673040012994, 0.9374114804502933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 89}], {
             RGBColor[
             0.26467695340514513`, 0.3954361451619938, 0.9383874999131978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 176}], {
             RGBColor[
             0.26830294791528575`, 0.39857679935889445`, 0.938618545077043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 179}], {
             RGBColor[
             0.20989223640499494`, 0.3379404267710331, 0.9352644244043025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 245}], {
             RGBColor[
             0.23179881460343715`, 0.36096562941487603`, 0.9365119716248255]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 255}], {
             RGBColor[
             0.20842141467182945`, 0.3363944998739921, 0.9351806632824844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 260}], {
             RGBColor[
             0.21471160984099968`, 0.34300589381819857`, 0.9355388805918587]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 299}], {
             RGBColor[
             0.22987290893586354`, 0.3589413804487841, 0.9364022941461793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 312}], {
             RGBColor[
             0.20732064752653726`, 0.335237523811622, 0.935117976221999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 328}], {
             RGBColor[
             0.23132945208889125`, 0.36047229965278604`, 0.9364852421239818]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 334}], {
             RGBColor[
             0.2032637935146371, 0.3309735130257143, 0.934886944387599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 407}], {
             RGBColor[
             0.24840100008144717`, 0.3784155789916214, 0.9374574415270658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 448}], {
             RGBColor[
             0.26012823284654724`, 0.3907416441772443, 0.938125290084152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 475}], {
             RGBColor[
             0.27810050553156784`, 0.4070629513265539, 0.9392428367847124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 478}], {
             RGBColor[
             0.23449306505329615`, 0.3637974574630227, 0.9366654052021586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 482}], {
             RGBColor[
             0.27602220405873207`, 0.40526283104925287`, 0.9391104092526332]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 76}], {
             RGBColor[
             0.3333497551271607, 0.45830089859572654`, 0.9426393717347399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 111}], {
             RGBColor[
             0.3114314409456971, 0.4393163564982453, 0.9412427561367012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 160}], {
             RGBColor[
             0.24786010554572385`, 0.3778470645398819, 0.937426638383438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 175}], {
             RGBColor[
             0.326974395016177, 0.4527788821025087, 0.9422331394259775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 182}], {
             RGBColor[
             0.300634259036329, 0.42996438021049266`, 0.9405547692530093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 237}], {
             RGBColor[
             0.24458077131553108`, 0.3744002763421501, 0.9372398851503687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 241}], {
             RGBColor[
             0.2359506605232252, 0.3653294827188087, 0.9367484131078517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 274}], {
             RGBColor[
             0.25017787666220814`, 0.38028318893848334`, 0.9375586320196867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 351}], {
             RGBColor[
             0.24823088148452888`, 0.3782367735601183, 0.937447753524639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 371}], {
             RGBColor[
             0.2551767869971113, 0.385537360649688, 0.9378433125680343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 432}], {
             RGBColor[
             0.27375220804932543`, 0.40506130592528333`, 0.9389011553170851]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 460}], {
             RGBColor[
             0.27847248938800495`, 0.41002262089535824`, 0.9391699683562924]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 463}], {
             RGBColor[
             0.4057152506945697, 0.5182150283519088, 0.9480144771137997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 44}], {
             RGBColor[
             0.24396970740458573`, 0.37375800942805687`, 0.9372050859646285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 62}], {
             RGBColor[
             0.23006104796724536`, 0.35913912649947, 0.9364130083856896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 190}], {
             RGBColor[
             0.2127364473424475, 0.3409298727996848, 0.9354263980095573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 291}], {
             RGBColor[
             0.19600418397695138`, 0.323343203115777, 0.9344735203640577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 356}], {
             RGBColor[
             0.22712257342383618`, 0.3560506034443001, 0.9362456666075261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 394}], {
             RGBColor[
             0.19619166312976455`, 0.3235402555922485, 0.9344841970244598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 467}], {
             RGBColor[
             0.20003782336254744`, 0.32758281385754684`, 0.9347032301598326]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.18328807136271902`, 0.3099777625101124, 0.9337493565624799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 123}], {
             RGBColor[
             0.18674780810963457`, 0.3136141651911, 0.933946383451995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 193}], {
             RGBColor[
             0.1842865051954063, 0.311027179772628, 0.9338062158922009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 347}], {
             RGBColor[
             0.19536292222488982`, 0.32266919635601693`, 0.9344370014559396]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 410}], {
             RGBColor[
             0.18494866329979062`, 0.31172314992358463`, 0.9338439248166706]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 422}], {
             RGBColor[
             0.19709463641182273`, 0.32448933776350447`, 0.9345356200170438]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 428}], {
             RGBColor[
             0.18771159390474457`, 0.31462716516930944`, 0.9340012696272331]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 437}], {
             RGBColor[
             0.18478436843582058`, 0.31155046560465605`, 0.9338345684672199]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 75}], {
             RGBColor[
             0.929724921483118, 0.7365825483050892, 0.4781251750142107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 76}], {
             RGBColor[
             0.7022798190159381, 0.7608775969992009, 0.8471463932234504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 104}], {
             RGBColor[
             0.9591316136436914, 0.8643779170894872, 0.5023662490620132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 112}], {
             RGBColor[
             0.993786491132969, 0.9916985686506579, 0.7526374521795876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 266}], {
             RGBColor[
             0.9938574384892986, 0.9902625241719002, 0.644943793687154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 359}], {
             RGBColor[
             0.9518288028476951, 0.9612683407754878, 0.8690761481825573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 379}], {
             RGBColor[
             0.9107780137599082, 0.6018218600251894, 0.4604073756146171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 408}], {
             RGBColor[
             0.9657078104957213, 0.9722942089440085, 0.8689827508705463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 440}], {
             RGBColor[
             0.9428820049759663, 0.7963257915311912, 0.48910376799027133`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 463}], {
             RGBColor[
             0.7746453145833472, 0.820791726755383, 0.8525214986025103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 49}], {
             RGBColor[
             0.9278898442559633, 0.7275054583426774, 0.39329233295696453`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 53}], {
             RGBColor[
             0.8472647112443593, 0.3588769520067575, 0.19268158199931773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 97}], {
             RGBColor[
             0.9251557778239836, 0.7191603787632175, 0.30804891163954246`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 100}], {
             RGBColor[
             0.9275408237580072, 0.7267589387889348, 0.3553036056592853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 203}], {
             RGBColor[
             0.8534629031399862, 0.4065189709815528, 0.1986169775584265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 207}], {
             RGBColor[
             0.8684208855066446, 0.4954117968161807, 0.21191950037856397`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 257}], {
             RGBColor[
             0.9124536887252621, 0.6763132496408797, 0.2587036940792628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 264}], {
             RGBColor[
             0.8636993298194549, 0.4739723151879993, 0.20797971857725228`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 281}], {
             RGBColor[
             0.8401393429256434, 0.30410824875280007`, 0.18585832125036283`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 317}], {
             RGBColor[
             0.839586880193451, 0.2998617781024568, 0.18532928231409804`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 322}], {
             RGBColor[
             0.8413185031158885, 0.3131717906863145, 0.18698748638021256`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 324}], {
             RGBColor[
             0.9007937640631225, 0.7100849667901136, 0.5966707240103046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 343}], {
             RGBColor[
             0.8540426861772787, 0.4109754374687308, 0.1991721784497092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 374}], {
             RGBColor[
             0.8546495293295531, 0.4156398998574755, 0.19975329213765833`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 397}], {
             RGBColor[
             0.8419322626018511, 0.3178894150465442, 0.18757522315711248`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 445}], {
             RGBColor[
             0.9124867892485535, 0.6764249054783144, 0.25883228336174086`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 77}], {
             RGBColor[
             0.4266438929830485, 0.5421807004439456, 0.9488977622771873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 79}], {
             RGBColor[
             0.7025334025034438, 0.7661868171424233, 0.9721373827063131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 87}], {
             RGBColor[
             0.4136160612646935, 0.5308657922292461, 0.9480687701193717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 127}], {
             RGBColor[
             0.6754853554676021, 0.7446194386357212, 0.969557515833958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 184}], {
             RGBColor[
             0.5298276783437619, 0.6291770036011967, 0.9561291221434074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 221}], {
             RGBColor[
             0.7405475305032172, 0.7523239641423858, 0.6316046509416242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 253}], {
             RGBColor[
             0.4481561698945121, 0.5608135534661793, 0.9502685055394262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 287}], {
             RGBColor[
             0.4114868433754372, 0.5286278492274263, 0.9479475143104742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 301}], {
             RGBColor[
             0.5876340036038425, 0.6758909546392042, 0.9608274105699129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 316}], {
             RGBColor[
             0.4787664530256467, 0.5873266421968035, 0.9522189657129314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 336}], {
             RGBColor[
             0.5720852226715933, 0.663483581767208, 0.9594557908273795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 354}], {
             RGBColor[
             0.4147037910637674, 0.5318387842884362, 0.9481369495411083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 388}], {
             RGBColor[
             0.42375389748919434`, 0.5396775316025662, 0.9487136143198416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 436}], {
             RGBColor[
             0.4371703671484145, 0.5512982032900106, 0.9495684999028087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 473}], {
             RGBColor[
             0.39120686649721753`, 0.5073123077036177, 0.9467925996287968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 62}], {
             RGBColor[
             0.2493920758689453, 0.37945726248211625`, 0.9375138818269986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 96}], {
             RGBColor[
             0.359182658449612, 0.4793995184819319, 0.94444576944529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 108}], {
             RGBColor[
             0.22860230621824829`, 0.3576058964317052, 0.9363299352010993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 113}], {
             RGBColor[
             0.2221538791632596, 0.3508281907430225, 0.9359627068199107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 157}], {
             RGBColor[
             0.2733433157427147, 0.4046315341857658, 0.9388778695051255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 190}], {
             RGBColor[
             0.23206747524414745`, 0.361248008782331, 0.9365272714508661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 378}], {
             RGBColor[
             0.22727756338581306`, 0.356213507721269, 0.9362544930565735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 161}], {
             RGBColor[
             0.19942966903054987`, 0.32694360509540565`, 0.9346685966703091]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 183}], {
             RGBColor[
             0.19098677743240255`, 0.31806959071550744`, 0.9341877864839334]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 202}], {
             RGBColor[
             0.18588447811869105`, 0.31270675063233544`, 0.933897218086193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 206}], {
             RGBColor[
             0.18271148860033518`, 0.3093717374693884, 0.9337165210271399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 243}], {
             RGBColor[
             0.19079403389915217`, 0.3178670050414155, 0.9341768100248533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 273}], {
             RGBColor[
             0.18608375256856824`, 0.31291620071388626`, 0.9339085664713134]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 283}], {
             RGBColor[
             0.18366308451827268`, 0.3103719251138067, 0.9337707130069065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 285}], {
             RGBColor[
             0.19969824891224597`, 0.32722589958001636`, 0.9346838918972433]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 396}], {
             RGBColor[
             0.19122359622902446`, 0.31831850228593606`, 0.934201272964059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 421}], {
             RGBColor[
             0.18467273781712776`, 0.31143313474661993`, 0.933828211268628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 430}], {
             RGBColor[
             0.1932824749084014, 0.32048251431840913`, 0.9343185230590114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 477}], {
             RGBColor[
             0.19140125749096676`, 0.31850523553661203`, 0.9342113905101004]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 44}], {
             RGBColor[
             0.27104906144274005`, 0.40222012745236824`, 0.938747215116787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 56}], {
             RGBColor[
             0.33496751620801646`, 0.46033233124806494`, 0.9427193789900982]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.26751337219857585`, 0.3985038938811058, 0.9385458628449154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 132}], {
             RGBColor[
             0.2677010857798615, 0.3987011927567655, 0.9385565528556723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.2413646105317827, 0.37101988744205927`, 0.9370567295516178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 356}], {
             RGBColor[
             0.25420192746199044`, 0.3845127214686115, 0.9377877957596846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 365}], {
             RGBColor[
             0.23506566561189032`, 0.36439929695507756`, 0.9366980139568839]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 457}], {
             RGBColor[
             0.36616941470913866`, 0.48692522378917524`, 0.9448270715857057]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 485}], {
             RGBColor[
             0.2592162515913262, 0.38978309405505573`, 0.9380733541008225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 494}], {
             RGBColor[
             0.3091950820990577, 0.43800954418308746`, 0.9410771822783439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 108}], {
             RGBColor[
             0.2050818952093152, 0.3328844531811263, 0.9349904825894705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 113}], {
             RGBColor[
             0.1986334681543265, 0.3261067474924436, 0.9346232542082819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 119}], {
             RGBColor[
             0.1924345707120309, 0.31959131324779266`, 0.9342702361693901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 315}], {
             RGBColor[
             0.19198004367677265`, 0.3191135765150577, 0.9342443515271446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 364}], {
             RGBColor[
             0.2024710281446618, 0.33014026635764265`, 0.9348417975725702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 378}], {
             RGBColor[
             0.20375715237687997`, 0.3314920644706901, 0.9349150404449447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 380}], {
             RGBColor[
             0.19400957405079025`, 0.3212467416178081, 0.9343599302795238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 381}], {
             RGBColor[
             0.19442462278648562`, 0.3216829841546337, 0.9343835666910121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 416}], {
             RGBColor[
             0.20488956233917005`, 0.3326822991399955, 0.9349795295170467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 452}], {
             RGBColor[
             0.21367924169687297`, 0.3419208094428005, 0.9354800887533026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 468}], {
             RGBColor[
             0.21102583019430793`, 0.33913190571759855`, 0.9353289808936021]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 487}], {
             RGBColor[
             0.19664512493327133`, 0.3240168726988731, 0.934510021003333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[
             0.24535980769453214`, 0.3752190929702395, 0.9372842501196719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 137}], {
             RGBColor[
             0.220012218727478, 0.34857716983590165`, 0.9358407424263956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 148}], {
             RGBColor[
             0.2515020287225457, 0.38167495670998786`, 0.9376340405206155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 156}], {
             RGBColor[
             0.21388174499134507`, 0.34213365324474115`, 0.935491621016346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 227}], {
             RGBColor[
             0.21076377490674741`, 0.3388564689951076, 0.9353140572326515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 229}], {
             RGBColor[
             0.231604699752685, 0.3607616023991431, 0.9365009170712423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 250}], {
             RGBColor[
             0.22400512105631526`, 0.3527739633481394, 0.9360681323070532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 263}], {
             RGBColor[
             0.2263534256582619, 0.35524218037589655`, 0.9362018647801287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 267}], {
             RGBColor[
             0.22881279968486046`, 0.35782713841117125`, 0.9363419224926257]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 393}], {
             RGBColor[
             0.2248422553763207, 0.3536538445958466, 0.9361158058681482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 485}], {
             RGBColor[
             0.24185676211585877`, 0.3715371699611359, 0.9370847568562579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 56}], {
             RGBColor[
             0.342928946455201, 0.46870029922168843`, 0.9431727706647948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 62}], {
             RGBColor[
             0.2651018322525842, 0.3959692124974049, 0.9384085292125448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 92}], {
             RGBColor[
             0.2754748024457604, 0.40687186185472934`, 0.938999254519612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 110}], {
             RGBColor[
             0.34804321230268565`, 0.4731300192483041, 0.9434986471622288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 132}], {
             RGBColor[
             0.27566251602704606`, 0.4070691607303891, 0.9390099445303688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 157}], {
             RGBColor[
             0.2890530721263536, 0.4211434842010545, 0.9397725168906719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 356}], {
             RGBColor[
             0.262163357709175, 0.39288068944223503`, 0.9382411874343812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 360}], {
             RGBColor[
             0.4375870349530485, 0.5468097854709225, 0.9502759669846275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 365}], {
             RGBColor[
             0.24302709585907487`, 0.37276726492870105`, 0.9371514056315804]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 457}], {
             RGBColor[
             0.3741308449563232, 0.49529319176279873`, 0.9452804632604023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 494}], {
             RGBColor[
             0.31715651234624226`, 0.44637751215671095`, 0.9415305739530406]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 118}], {
             RGBColor[
             0.1966941864369604, 0.3240684394499293, 0.9345128149833881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 152}], {
             RGBColor[
             0.1927063751242849, 0.3198769969184667, 0.9342857150285693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 185}], {
             RGBColor[
             0.2063591315326575, 0.33422690953841927`, 0.935063219308583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 187}], {
             RGBColor[
             0.21121178851668337`, 0.3393273597048538, 0.9353395709449606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 195}], {
             RGBColor[
             0.19463609510811763`, 0.32190525497278855`, 0.9343956097268837]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 216}], {
             RGBColor[
             0.20054621348510776`, 0.32811716411015324`, 0.9347321822252167]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 217}], {
             RGBColor[
             0.19120987418842403`, 0.31830407955123735`, 0.9342004915141469]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 224}], {
             RGBColor[
             0.20355580866569664`, 0.3312804394643078, 0.9349035742184542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 292}], {
             RGBColor[
             0.193148625604734, 0.3203418302137187, 0.93431090053918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 328}], {
             RGBColor[
             0.22208190708084125`, 0.3507525435211073, 0.9359586081162901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 398}], {
             RGBColor[
             0.20371823459922628`, 0.33145115941884645`, 0.934912824135081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 399}], {
             RGBColor[
             0.20452814783915604`, 0.33230242958547795`, 0.9349589474959358]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 464}], {
             RGBColor[
             0.2018156680778671, 0.3294514413752133, 0.9348044757862846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 481}], {
             RGBColor[
             0.20322304481879772`, 0.33093068356277056`, 0.9348846238096533]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 496}], {
             RGBColor[
             0.19349628938952101`, 0.32070724689468694`, 0.9343306994774011]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 86}], {
             RGBColor[
             0.19451109914847642`, 0.321773876294004, 0.9343884913918972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 142}], {
             RGBColor[
             0.2097115161750654, 0.33775047835105276`, 0.9352541326545596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 150}], {
             RGBColor[
             0.2095354252082916, 0.3375653955801614, 0.935244104534505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 194}], {
             RGBColor[
             0.19490869460205182`, 0.32219177432471957`, 0.9344111338647885]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 220}], {
             RGBColor[
             0.21037184686789395`, 0.33844452777659967`, 0.9352917375106444]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 254}], {
             RGBColor[
             0.1980699244230848, 0.3255144273001723, 0.9345911612264759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 297}], {
             RGBColor[
             0.19948643535294036`, 0.32700327009943075`, 0.934671829428391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 325}], {
             RGBColor[
             0.2186729430619583, 0.3471695061964588, 0.935764472658525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 350}], {
             RGBColor[
             0.1926173329949277, 0.3197834079949152, 0.9342806442110285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 377}], {
             RGBColor[
             0.192250993648715, 0.31939836211478956`, 0.9342597817272121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 392}], {
             RGBColor[
             0.22028047155655125`, 0.34885912056746937`, 0.9358560190281668]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 412}], {
             RGBColor[
             0.19698300619667852`, 0.32437200732962346`, 0.9345292628414335]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 426}], {
             RGBColor[
             0.19553365018810587`, 0.3228486422701351, 0.9344467241608754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 476}], {
             RGBColor[
             0.1935701933686142, 0.32078492466249675`, 0.9343349081996792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 55}], {
             RGBColor[
             0.42760134170853215`, 0.539013813149998, 0.94946155992206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 59}], {
             RGBColor[
             0.272302702026903, 0.4035377831917274, 0.9388186080934602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 73}], {
             RGBColor[
             0.42925393472115597`, 0.5403554626061129, 0.9495916580976614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 91}], {
             RGBColor[
             0.37096684027433213`, 0.4930353735304999, 0.9450030845101454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 136}], {
             RGBColor[
             0.40491583995544145`, 0.5205967008566313, 0.9476756741243257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 200}], {
             RGBColor[
             0.2722924613184966, 0.40352701955789383`, 0.9388180249002662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 228}], {
             RGBColor[
             0.2699130817435731, 0.4010261407632708, 0.9386825227534509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 256}], {
             RGBColor[
             0.2965835068490444, 0.4287985034009982, 0.9402108818731908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 298}], {
             RGBColor[
             0.2786489927595025, 0.4102081371297621, 0.9391800199621858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 416}], {
             RGBColor[
             0.24541922577751857`, 0.3752815451427822, 0.9372876338915967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 452}], {
             RGBColor[
             0.2542089051352215, 0.3845200554455873, 0.9377881931278527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 468}], {
             RGBColor[
             0.25155549363265645`, 0.38173115172038535`, 0.9376370852681521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 117}], {
             RGBColor[
             0.18672352451245816`, 0.31358864159079863`, 0.9339450005370601]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 140}], {
             RGBColor[
             0.1844487281323768, 0.3111976863649123, 0.9338154542484741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 155}], {
             RGBColor[
             0.1919029748142661, 0.3190325722541152, 0.934239962569438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 156}], {
             RGBColor[
             0.19463895940372045`, 0.3219082655290739, 0.9343957728442809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 198}], {
             RGBColor[
             0.18614733394130184`, 0.3129830287679211, 0.9339121873364302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 250}], {
             RGBColor[
             0.20476233546869063`, 0.33254857563247214`, 0.9349722841349881]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 365}], {
             RGBColor[
             0.19846339054879825`, 0.32592798514549043`, 0.9346135685402542]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 479}], {
             RGBColor[
             0.18610061058204452`, 0.31293391955490957`, 0.9339095265102416]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 51}], {
             RGBColor[
             0.9945887098983145, 0.9908341225748765, 0.6523926509220856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 100}], {
             RGBColor[
             0.9935759076270685, 0.9886678409266986, 0.5421553739880537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 203}], {
             RGBColor[
             0.9194979870090474, 0.6684278731193166, 0.38546874588719493`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 264}], {
             RGBColor[
             0.9297344136885161, 0.7358812173257631, 0.3948314869060207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 324}], {
             RGBColor[
             0.9668288479321837, 0.9719938689278773, 0.783522492339073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 360}], {
             RGBColor[
             0.7950442531705986, 0.8362229179981473, 0.7707477142317521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 397}], {
             RGBColor[
             0.9079673464709124, 0.579798317184308, 0.3744269914858809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 457}], {
             RGBColor[
             0.7315880631738731, 0.7847063242900234, 0.765752210507527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 82}], {
             RGBColor[
             0.7002427375322327, 0.764369726655832, 0.9719080506652522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 126}], {
             RGBColor[
             0.6844097961772514, 0.7515158315979785, 0.9706616235238129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 131}], {
             RGBColor[
             0.8570462990670573, 0.5838526913273292, 0.5841917648474512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 173}], {
             RGBColor[
             0.800480264278042, 0.8445485570290475, 0.9806185434355512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 242}], {
             RGBColor[
             0.9267381119467066, 0.943455029677774, 0.9594240314227456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 323}], {
             RGBColor[
             0.9365367216162789, 0.9493476478675402, 0.8794633883159441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 340}], {
             RGBColor[
             0.6220781556562913, 0.698481383789535, 0.9664262896114366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 373}], {
             RGBColor[
             0.9356814566362912, 0.9489939738190079, 0.8936373423891573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 414}], {
             RGBColor[
             0.6515149605889788, 0.7239780646853934, 0.9683019767918029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 449}], {
             RGBColor[
             0.9319849870644814, 0.931902676711367, 0.6896331946772748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 499}], {
             RGBColor[
             0.7544680909250315, 0.8083923113644382, 0.9761768691183477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 60}], {
             RGBColor[
             0.9903726876472161, 0.9902614167392676, 0.8073625961746422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 96}], {
             RGBColor[
             0.7330134148240908, 0.7867443631188805, 0.8380607137143137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 100}], {
             RGBColor[
             0.9942396894003585, 0.9900876030211339, 0.6144039236244064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 110}], {
             RGBColor[
             0.7061642122935256, 0.763962913869964, 0.8362189440457062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 203}], {
             RGBColor[
             0.9201617687823374, 0.6698476352137519, 0.4577172955235477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 240}], {
             RGBColor[
             0.995029239647029, 0.991776371162987, 0.7003415954352006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 264}], {
             RGBColor[
             0.930398195461806, 0.7373009794201983, 0.46708003654237346`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 324}], {
             RGBColor[
             0.9674926297054737, 0.9734136310223126, 0.8557710419754258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 360}], {
             RGBColor[
             0.7957080349438885, 0.8376426800925825, 0.8429962638681049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 397}], {
             RGBColor[
             0.9086311282442023, 0.5812180792787432, 0.4466755411222336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 457}], {
             RGBColor[
             0.7322518449471631, 0.7861260863844587, 0.8380007601438797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 495}], {
             RGBColor[
             0.9406722816777016, 0.7839532053527796, 0.47565298592181493`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 170}], {
             RGBColor[
             0.1838649636445791, 0.31058411287543064`, 0.9337822097244962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 214}], {
             RGBColor[
             0.18377002501748835`, 0.3104843263589016, 0.9337768031101326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 268}], {
             RGBColor[
             0.18314820397606815`, 0.30983075301863783`, 0.9337413913217254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 466}], {
             RGBColor[
             0.18744056730247904`, 0.3143422990262493, 0.933985835063182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 491}], {
             RGBColor[
             0.18081085908512495`, 0.30737405534203105`, 0.9336082829879782]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 83}], {
             RGBColor[
             0.9139507635332944, 0.6222257740273145, 0.45384466479453006`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 97}], {
             RGBColor[
             0.910565728681441, 0.6124407745650613, 0.29428992901066414`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 112}], {
             RGBColor[
             0.9130580700237505, 0.6218566223199413, 0.468638906464419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 163}], {
             RGBColor[
             0.8659915986516313, 0.4439113739475036, 0.20830775588996076`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 207}], {
             RGBColor[
             0.8538308363641018, 0.3886921926180247, 0.19816051774968563`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 257}], {
             RGBColor[
             0.8978636395827194, 0.5695936454427237, 0.2449447114503845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 266}], {
             RGBColor[
             0.9131290173800801, 0.6204205778411838, 0.36094524797198546`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 281}], {
             RGBColor[
             0.8255492937831006, 0.19738864455464403`, 0.17209933862148452`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[
             0.8212117750972121, 0.5517293002984074, 0.5802972295340347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 317}], {
             RGBColor[
             0.8249968310509084, 0.19314217390430075`, 0.1715702996852197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 322}], {
             RGBColor[
             0.8267284539733458, 0.20645218648815844`, 0.17322850375133425`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 343}], {
             RGBColor[
             0.8394526370347362, 0.3042558332705747, 0.18541319582083088`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 374}], {
             RGBColor[
             0.8400594801870103, 0.30892029565931944`, 0.18599430950878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 440}], {
             RGBColor[
             0.8621535838667478, 0.42648384520047466`, 0.20510522227510283`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 445}], {
             RGBColor[
             0.897896740106011, 0.5697053012801583, 0.24507330073286251`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 471}], {
             RGBColor[
             0.8947556642863255, 0.6097433924263989, 0.5684355218108367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 61}], {
             RGBColor[
             0.9898922626687403, 0.9900882051035927, 0.8171748957720661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 99}], {
             RGBColor[
             0.9846117057177595, 0.9871579291878583, 0.8712517771624386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 154}], {
             RGBColor[
             0.9864962902894889, 0.9885634492757301, 0.8680616670608778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 186}], {
             RGBColor[
             0.9914243588005289, 0.9890319585828893, 0.6689529207083693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 203}], {
             RGBColor[
             0.9172982685013698, 0.6686889606982549, 0.5070233200844496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 244}], {
             RGBColor[
             0.7181235795673231, 0.775643062211419, 0.8864694686198505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 264}], {
             RGBColor[
             0.9275346951808384, 0.7361423049047013, 0.5163860611032753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 295}], {
             RGBColor[
             0.9871607004637972, 0.988958633933902, 0.862443950564356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 321}], {
             RGBColor[
             0.9874803221287802, 0.9890908057062746, 0.8571469924212342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 341}], {
             RGBColor[
             0.991911410491914, 0.9900737129022821, 0.7219654915810148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 374}], {
             RGBColor[
             0.9184848946909366, 0.6778098895741775, 0.5081596346636814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 391}], {
             RGBColor[
             0.731320111432247, 0.7865357071547434, 0.8874588604609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 397}], {
             RGBColor[
             0.9057676279632347, 0.5800594047632462, 0.4959815656831355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 455}], {
             RGBColor[
             0.8012850501089904, 0.8433363962570924, 0.8929667567235482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 57}], {
             RGBColor[
             0.7681170081630603, 0.818182994087395, 0.9538490180959958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 60}], {
             RGBColor[
             0.7795430416292072, 0.8264883871046946, 0.9248292480443663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 73}], {
             RGBColor[
             0.5752457926482104, 0.6660494748562806, 0.9597046024734881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 91}], {
             RGBColor[
             0.5169586982013866, 0.6187293857806677, 0.955116028885972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 136}], {
             RGBColor[
             0.5509076978824959, 0.6462907131067992, 0.9577886185001523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 200}], {
             RGBColor[
             0.4182843192455511, 0.5292210318080617, 0.9489309692760928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 256}], {
             RGBColor[
             0.4425753647760989, 0.554492515651166, 0.9503238262490175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 298}], {
             RGBColor[
             0.424640850686557, 0.5359021493799299, 0.9492929643380126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 434}], {
             RGBColor[
             0.7543365484938672, 0.7225141411414309, 0.6130982348590022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 92}], {
             RGBColor[
             0.33939325721103675`, 0.46498406565042605`, 0.9429714183929231]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 110}], {
             RGBColor[
             0.41196166706796206`, 0.5312422230440008, 0.9474708110355399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 132}], {
             RGBColor[
             0.3395809707923225, 0.46518136452608577`, 0.94298210840368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 324}], {
             RGBColor[
             0.6732900844799101, 0.7406929401963493, 0.9670229089652596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 342}], {
             RGBColor[
             0.4415801835206408, 0.5562719260910596, 0.9495305912404275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 360}], {
             RGBColor[
             0.501505489718325, 0.6049219892666192, 0.9542481308579387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 457}], {
             RGBColor[
             0.4380492997215996, 0.5534053955584954, 0.9492526271337134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 494}], {
             RGBColor[
             0.38107496711151867`, 0.5044897159524077, 0.9455027378263516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 60}], {
             RGBColor[
             0.9740668501566808, 0.9799635557919238, 0.9191037618424754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 73}], {
             RGBColor[
             0.769769601175684, 0.81952464354351, 0.9539791162715971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 91}], {
             RGBColor[
             0.7114825067288603, 0.7722045544678969, 0.9493905426840812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 131}], {
             RGBColor[
             0.8981850447320697, 0.6159608551699692, 0.564028013817431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 136}], {
             RGBColor[
             0.7454315064099696, 0.7997658817940283, 0.9520631322982614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 234}], {
             RGBColor[
             0.9445095586663342, 0.8587398441686642, 0.6038719941743098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 240}], {
             RGBColor[
             0.9787234021564939, 0.9814785102156434, 0.8120827611030339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 434}], {
             RGBColor[
             0.9488603570213409, 0.87598930982866, 0.6073727486571113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 495}], {
             RGBColor[
             0.9243664441871663, 0.7736553444054359, 0.5873941515896481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 74}], {
             RGBColor[
             0.19093718319717995`, 0.31801746402983233`, 0.9341849621656055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 115}], {
             RGBColor[
             0.19207706439220854`, 0.3192155514384495, 0.9342498767133594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 144}], {
             RGBColor[
             0.1950230989335921, 0.322312020530822, 0.9344176490222236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 145}], {
             RGBColor[
             0.20110599109187893`, 0.32870552586681995`, 0.9347640607318055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 215}], {
             RGBColor[
             0.1890650982052305, 0.3160497840062494, 0.9340783496948156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 375}], {
             RGBColor[
             0.19795511773261765`, 0.3253937581893268, 0.934584623155295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 402}], {
             RGBColor[
             0.20564836608822273`, 0.3334798499911863, 0.9350227422680057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 417}], {
             RGBColor[
             0.19514933346569613`, 0.3224447010277949, 0.9344248378920796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 87}], {
             RGBColor[
             0.28570409751894754`, 0.41762349955141664`, 0.939581797741144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 91}], {
             RGBColor[
             0.36166005851975747`, 0.48325335582239703`, 0.9444730770573722]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 188}], {
             RGBColor[
             0.24348630056862833`, 0.373249918193702, 0.937177556660457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 200}], {
             RGBColor[
             0.26298567956392194`, 0.393745001849791, 0.9382880174474929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 228}], {
             RGBColor[
             0.26060629998899837`, 0.391244123055168, 0.9381525153006776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 256}], {
             RGBColor[
             0.28727672509446966`, 0.4190164856928953, 0.9396808744204175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 279}], {
             RGBColor[
             0.23548934775412372`, 0.36484461374956423`, 0.9367221420281024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 287}], {
             RGBColor[
             0.28357487962969113`, 0.41538555654959675`, 0.9394605419322465]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 298}], {
             RGBColor[
             0.2693422110049278, 0.4004261194216593, 0.9386500125094126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 335}], {
             RGBColor[
             0.2366854990874992, 0.3661018446413167, 0.9367902610769909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 409}], {
             RGBColor[
             0.2581147666270732, 0.38862536351944543`, 0.9380106261616092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 468}], {
             RGBColor[
             0.24224871187808175`, 0.37194913401228247`, 0.9371070778153788]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 73}], {
             RGBColor[
             0.781195634641831, 0.8278300365608096, 0.9249593462199677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 131}], {
             RGBColor[
             0.9096110781982166, 0.6242662481872688, 0.5350082437658015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.7568575398761165, 0.8080712748113279, 0.923043362246632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 240}], {
             RGBColor[
             0.9901494356226408, 0.989783903232943, 0.7830629910514044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 434}], {
             RGBColor[
             0.9602863904874878, 0.8842947028459596, 0.5783529786054818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 495}], {
             RGBColor[
             0.9357924776533132, 0.7819607374227355, 0.5583743815380187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 99}], {
             RGBColor[
             0.9849784772768306, 0.9873095986531333, 0.8651734232542627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 154}], {
             RGBColor[
             0.9868630618485601, 0.9887151187410052, 0.8619833131527019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 178}], {
             RGBColor[
             0.7297842099398613, 0.7851427009224017, 0.8812307211603922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 186}], {
             RGBColor[
             0.9917911303595999, 0.9891836280481643, 0.6628745668001933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 203}], {
             RGBColor[
             0.9176650400604409, 0.6688406301635299, 0.5009449661762736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 244}], {
             RGBColor[
             0.7184903511263943, 0.775794731676694, 0.8803911147116745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 264}], {
             RGBColor[
             0.9279014667399095, 0.7362939743699763, 0.5103077071950994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 288}], {
             RGBColor[
             0.8507412174209339, 0.8822861338586991, 0.8914741508713435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 295}], {
             RGBColor[
             0.9875274720228682, 0.989110303399177, 0.8563655966561801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 321}], {
             RGBColor[
             0.9878470936878512, 0.9892424751715496, 0.8510686385130581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 341}], {
             RGBColor[
             0.992278182050985, 0.9902253823675571, 0.7158871376728388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 391}], {
             RGBColor[
             0.731686882991318, 0.7866873766200184, 0.8813805065527239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 397}], {
             RGBColor[
             0.9061343995223057, 0.5802110742285213, 0.48990321177495955`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 455}], {
             RGBColor[
             0.8016518216680615, 0.8434880657223675, 0.8868884028153723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 96}], {
             RGBColor[
             0.36098375539591054`, 0.48129258556863375`, 0.9445483392518976]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 108}], {
             RGBColor[
             0.2304034031645468, 0.35949896351840704`, 0.9364325050077069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 110}], {
             RGBColor[
             0.33413455286534527`, 0.45851113631971724`, 0.9427065695832899]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 157}], {
             RGBColor[
             0.27514441268901324`, 0.40652460127246764`, 0.9389804393117331]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 190}], {
             RGBColor[
             0.233868572190446, 0.3631410758690329, 0.9366298412574736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 356}], {
             RGBColor[
             0.24825469827183463`, 0.37826180651364816`, 0.9374491098554425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 378}], {
             RGBColor[
             0.22907866033211158`, 0.3581065748079708, 0.9363570628631811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 72}], {
             RGBColor[
             0.20896361604647165`, 0.3369643878962938, 0.9352115408486552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 159}], {
             RGBColor[
             0.2194636807819041, 0.34800062167578893`, 0.9358095040018843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 166}], {
             RGBColor[
             0.20124645730453306`, 0.3288531647623917, 0.9347720600748151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 222}], {
             RGBColor[
             0.20195670404025598`, 0.32959967911388044`, 0.9348125075756986]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 239}], {
             RGBColor[
             0.20172774579693858`, 0.3293590294833628, 0.934799468742455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 272}], {
             RGBColor[
             0.23201898916873956`, 0.36119704684288256`, 0.9365245102406003]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 344}], {
             RGBColor[
             0.19854348560024537`, 0.326012170122881, 0.9346181298349442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 387}], {
             RGBColor[
             0.1978509608116646, 0.3252842826614749, 0.9345786915727331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 435}], {
             RGBColor[
             0.22260483335872017`, 0.351302172194599, 0.9359883879942152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 439}], {
             RGBColor[
             0.20302072388459882`, 0.33071803143303935`, 0.9348731019317575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 453}], {
             RGBColor[
             0.2233707740920417, 0.35210722446876735`, 0.9360320071858701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 74}], {
             RGBColor[
             0.1867563887094054, 0.3136231839455006, 0.933946872104458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 115}], {
             RGBColor[
             0.18789626990443398`, 0.31482127135411775`, 0.9340117866522119]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 170}], {
             RGBColor[
             0.18627047911638173`, 0.31311246215478516`, 0.9339192002719742]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 215}], {
             RGBColor[
             0.18488430371745596`, 0.31165550392191765`, 0.9338402596336681]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 223}], {
             RGBColor[
             0.19649530119615788`, 0.32385939845179323`, 0.9345014887631486]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 268}], {
             RGBColor[
             0.18555371944787077`, 0.31235910229799235`, 0.9338783818692034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 86}], {
             RGBColor[
             0.18424555499085607`, 0.31098413851125284`, 0.9338038838386322]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 177}], {
             RGBColor[
             0.18378082822451933`, 0.3104956812144541, 0.9337774183367911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 194}], {
             RGBColor[
             0.18464315044443147`, 0.3114020365419683, 0.9338265263115236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 290}], {
             RGBColor[
             0.18235293121758706`, 0.308994870926269, 0.9336961017146306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 297}], {
             RGBColor[
             0.18922089119532, 0.3162135323166796, 0.9340872218751262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 350}], {
             RGBColor[
             0.18235178883730735`, 0.30899367021216395`, 0.9336960366577636]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 412}], {
             RGBColor[
             0.1867174620390582, 0.3135822695468723, 0.9339446552881686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 484}], {
             RGBColor[
             0.1839955650344703, 0.31072138321681264`, 0.9337896472804431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 114}], {
             RGBColor[
             0.1896583133560848, 0.31667329074181017`, 0.9341121324200736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 128}], {
             RGBColor[
             0.19606919376904863`, 0.32341153252913013`, 0.9344772225755442]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 179}], {
             RGBColor[
             0.19899718509969622`, 0.32648903706301347`, 0.9346439673502496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 245}], {
             RGBColor[
             0.22090376329813846`, 0.34951423970685647`, 0.9358915145707727]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 255}], {
             RGBColor[
             0.19752636336653073`, 0.32494311016597255`, 0.9345602062284316]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 260}], {
             RGBColor[
             0.203816558535701, 0.331554504110179, 0.9349184235378061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 294}], {
             RGBColor[
             0.19268716813915449`, 0.3198568091593014, 0.9342846212191803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 299}], {
             RGBColor[
             0.21897785763056482`, 0.34748999074076453`, 0.9357818370921265]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 312}], {
             RGBColor[
             0.19642559622123856`, 0.32378613410360235`, 0.9344975191679463]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 327}], {
             RGBColor[
             0.19083074135934272`, 0.31790558690946313`, 0.9341789004604073]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 334}], {
             RGBColor[
             0.19236874220933842`, 0.3195221233176947, 0.9342664873335462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 385}], {
             RGBColor[
             0.189718897172314, 0.31673696817390284`, 0.9341155825787821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 415}], {
             RGBColor[
             0.1891407128871262, 0.3161292598311696, 0.9340826558390877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 446}], {
             RGBColor[
             0.19064470762485328`, 0.3177100536592947, 0.9341683061144403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 119}], {
             RGBColor[
             0.18259585546660687`, 0.3092501997142758, 0.933709935891238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 120}], {
             RGBColor[
             0.18038821966444069`, 0.3069298345140049, 0.9335842142982091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 124}], {
             RGBColor[
             0.18312075215718818`, 0.30980189941644914`, 0.9337398279812515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 363}], {
             RGBColor[
             0.18174309364533237`, 0.30835389297189403`, 0.9336613723670645]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 381}], {
             RGBColor[
             0.18458590754106158`, 0.31134187062111685`, 0.93382326641286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 95}], {
             RGBColor[
             0.18505409827792216`, 0.3118339687705646, 0.933849929182698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 286}], {
             RGBColor[
             0.1864116908357643, 0.3132608846251963, 0.9339272420704889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 319}], {
             RGBColor[
             0.1831451884938083, 0.30982758355559015`, 0.9337412195944718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 330}], {
             RGBColor[
             0.18750410848445143`, 0.3144090848372459, 0.9339894536394946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 352}], {
             RGBColor[
             0.18440978245630846`, 0.311156751990066, 0.933813236349837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 357}], {
             RGBColor[
             0.18698592728629504`, 0.313864443543398, 0.93395994398684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 367}], {
             RGBColor[
             0.19128856344294365`, 0.31838678694692435`, 0.9342049727507814]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 368}], {
             RGBColor[
             0.18232969627571796`, 0.3089704495291842, 0.9336947785190641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 375}], {
             RGBColor[
             0.19408512083298096`, 0.3213261460758332, 0.9343642325570081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 450}], {
             RGBColor[
             0.20047702738706202`, 0.3280444451344552, 0.9347282421792846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 492}], {
             RGBColor[
             0.1840181186755369, 0.3107450885235571, 0.9337909316769367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 101}], {
             RGBColor[
             0.3439836908945852, 0.4664796432810521, 0.9433547372891266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 103}], {
             RGBColor[
             0.4263301464035756, 0.5436874776637394, 0.9483863578332576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 129}], {
             RGBColor[
             0.36611599979539755`, 0.48974210320523914`, 0.944615139539211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 204}], {
             RGBColor[
             0.37937968200922045`, 0.5030213452043036, 0.9453947157587149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 209}], {
             RGBColor[
             0.7186661516906826, 0.7749926272189318, 0.8453240647103539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 231}], {
             RGBColor[
             0.6032570715569849, 0.6866480853473442, 0.9632586642510103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 233}], {
             RGBColor[
             0.7027067996446262, 0.7647987322711527, 0.9488520571207084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 259}], {
             RGBColor[
             0.5630647117651555, 0.6552495084047187, 0.9592526654459177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 275}], {
             RGBColor[
             0.46608428308489896`, 0.5771431812489669, 0.9511894958767693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 306}], {
             RGBColor[
             0.3418131212888621, 0.4641982370033755, 0.9432311265611506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 331}], {
             RGBColor[
             0.37214546505797846`, 0.49607945348638943`, 0.9449585086661204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 346}], {
             RGBColor[
             0.4421357571807656, 0.5573775033058451, 0.9493934773756274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 348}], {
             RGBColor[
             0.4524683198594424, 0.5660891289103882, 0.9501175973747447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 355}], {
             RGBColor[
             0.5012830197903266, 0.6057191013914514, 0.9539604693674415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 372}], {
             RGBColor[
             0.5285636967606093, 0.627866783936419, 0.9561081041909547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 404}], {
             RGBColor[
             0.6398415718326245, 0.7153643102811339, 0.9668689392230831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 418}], {
             RGBColor[
             0.45968074399907377`, 0.5719444997429457, 0.9506853858229966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 431}], {
             RGBColor[
             0.4320540938957698, 0.548645273287512, 0.9487510827059723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 444}], {
             RGBColor[
             0.5043601503383525, 0.6082172545934901, 0.9542027123560828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 486}], {
             RGBColor[
             0.4280953978994323, 0.5452164497853305, 0.9484988380976231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 76}], {
             RGBColor[
             0.3900856381049142, 0.5122943062773944, 0.9460768898142273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 111}], {
             RGBColor[
             0.36816732392345053`, 0.4933097641799131, 0.9446802742161886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 130}], {
             RGBColor[
             0.33633111822806117`, 0.4651961056645053, 0.9426714251516843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 175}], {
             RGBColor[
             0.3837102779939304, 0.5067722897841764, 0.945670657505465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 182}], {
             RGBColor[
             0.35737014201408246`, 0.4839577878921605, 0.9439922873324968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 208}], {
             RGBColor[
             0.39817892177344283`, 0.519304301810809, 0.9465925866929762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[
             0.4282161029443493, 0.5444148958180487, 0.9487568881673315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 351}], {
             RGBColor[
             0.3049667644622824, 0.4322301812417861, 0.9408852716041266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 359}], {
             RGBColor[
             0.6396346219366711, 0.7126850500536813, 0.9680066447733342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 371}], {
             RGBColor[
             0.31191266997486483`, 0.4395307683313558, 0.9412808306475218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 403}], {
             RGBColor[
             0.5565760155932599, 0.6470753000386655, 0.9599201962609412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 442}], {
             RGBColor[
             0.3038237186466454, 0.4310287676162611, 0.9408201768359108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 463}], {
             RGBColor[
             0.4624511336723232, 0.5722084360335765, 0.9514519951932873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 483}], {
             RGBColor[
             0.41089196681220996`, 0.5303157024471664, 0.9474026506811422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 135}], {
             RGBColor[
             0.18886726703484777`, 0.31584185090295647`, 0.9340670835023274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 153}], {
             RGBColor[
             0.21268791512647112`, 0.34087886236357334`, 0.9354236341716544]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 169}], {
             RGBColor[
             0.1907755412237238, 0.3178475680670369, 0.9341757568943452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 172}], {
             RGBColor[
             0.21061538458324242`, 0.3387005013566139, 0.9353056066232517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 197}], {
             RGBColor[
             0.2143161876130597, 0.34259027998541636`, 0.9355163618809523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 201}], {
             RGBColor[
             0.22759518578243687`, 0.3565473489985437, 0.936272581182181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 211}], {
             RGBColor[
             0.19261088350739852`, 0.3197766291746009, 0.9342802769222549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 236}], {
             RGBColor[
             0.20304903767595361`, 0.3307477910229513, 0.9348747143602888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 289}], {
             RGBColor[
             0.20390581997350005`, 0.33164832354080787`, 0.9349235068446382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 308}], {
             RGBColor[
             0.19432153409427227`, 0.32157463140291687`, 0.9343776959424965]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 362}], {
             RGBColor[
             0.1884877837309814, 0.3154429898899618, 0.9340454724895675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 369}], {
             RGBColor[
             0.18988277528354555`, 0.3169092144592796, 0.9341249151947808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 466}], {
             RGBColor[
             0.1963124589116516, 0.3236672196179068, 0.934491076165537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 470}], {
             RGBColor[
             0.19617627269900267`, 0.32352407927370813`, 0.9344833205621961]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 493}], {
             RGBColor[
             0.2293216757786306, 0.35836199945033154`, 0.9363709022333513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 128}], {
             RGBColor[
             0.20268608388741163`, 0.33036630357859437`, 0.9348540446789733]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 159}], {
             RGBColor[
             0.22161615608300847`, 0.35026300969206614`, 0.9359320842859804]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 179}], {
             RGBColor[
             0.20561407521805922`, 0.3334438081124777, 0.9350207894536787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 222}], {
             RGBColor[
             0.20410917934136036`, 0.33186206713015765`, 0.9349350878597946]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 245}], {
             RGBColor[
             0.22752065341650146`, 0.35646901075632065`, 0.9362683366742017]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 294}], {
             RGBColor[
             0.19930405825751749`, 0.32681158020876566`, 0.9346614433226095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 344}], {
             RGBColor[
             0.20069596090134978`, 0.3282745581391582, 0.9347407101190403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 438}], {
             RGBColor[
             0.20687895912531873`, 0.33477328129727923`, 0.9350928227209692]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 439}], {
             RGBColor[
             0.2051731991857032, 0.33298041944931656`, 0.9349956822158536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 453}], {
             RGBColor[
             0.2255232493931461, 0.35436961248504456`, 0.9361545874699662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 91}], {
             RGBColor[
             0.5186112912140105, 0.6200710352367826, 0.9552461270615734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 136}], {
             RGBColor[
             0.5525602908951197, 0.647632362562914, 0.9579187166757537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 200}], {
             RGBColor[
             0.4199369122581749, 0.5305626812641765, 0.9490610674516942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 240}], {
             RGBColor[
             0.785852186641644, 0.829344990984529, 0.8179383454805261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 256}], {
             RGBColor[
             0.4442279577887227, 0.5558341651072809, 0.9504539244246188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 298}], {
             RGBColor[
             0.42629344369918076`, 0.5372437988360448, 0.949423062513614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 434}], {
             RGBColor[
             0.755989141506491, 0.7238557905975457, 0.6132283330346036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 115}], {
             RGBColor[
             0.18984673852773665`, 0.31687133754406216`, 0.9341228629548491]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 144}], {
             RGBColor[
             0.1927927730691202, 0.31996780663643465`, 0.9342906352637134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 215}], {
             RGBColor[
             0.1868347723407586, 0.3137055701118621, 0.9339513359363054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 268}], {
             RGBColor[
             0.18750418807117342`, 0.3144091684879368, 0.9339894581718406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 402}], {
             RGBColor[
             0.20341804022375085`, 0.331135636096799, 0.9348957285094954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 417}], {
             RGBColor[
             0.1929190076012242, 0.3201004871334076, 0.9342978241335694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 104}], {
             RGBColor[
             0.894725030806556, 0.6091192249245418, 0.23357173327544747`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 125}], {
             RGBColor[
             0.8216340480291034, 0.6538916931792487, 0.593916539379413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 147}], {
             RGBColor[
             0.842199332426149, 0.3144945905899744, 0.187617653595973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 303}], {
             RGBColor[
             0.853058182050049, 0.3979604671775163, 0.19801610025913619`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 310}], {
             RGBColor[
             0.7550654921994678, 0.6018878314253746, 0.587281607852838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 323}], {
             RGBColor[
             0.9290142282590157, 0.73628865839294, 0.4899032009526938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 379}], {
             RGBColor[
             0.8463714309227728, 0.346563167860244, 0.1916128598280513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 400}], {
             RGBColor[
             0.9275933480888754, 0.7357010879276322, 0.5134508624919265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 408}], {
             RGBColor[
             0.9013012276585859, 0.7170355167790632, 0.6001882350839804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 111}], {
             RGBColor[
             0.3885098195301592, 0.510929411430886, 0.9459764800480857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 130}], {
             RGBColor[
             0.3566736138347697, 0.4828157529154782, 0.9439676309835814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 175}], {
             RGBColor[
             0.404052773600639, 0.5243919370351493, 0.946966863337362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.3777126376207911, 0.5015774351431334, 0.9452884931643937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 351}], {
             RGBColor[
             0.32530926006899097`, 0.449849828492759, 0.9421814774360235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 359}], {
             RGBColor[
             0.6599771175433797, 0.7303046973046542, 0.9693028506052312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 371}], {
             RGBColor[
             0.3322551655815734, 0.4571504155823287, 0.9425770364794188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 460}], {
             RGBColor[
             0.35555086797246704`, 0.4816356758279989, 0.9439036922676769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 463}], {
             RGBColor[
             0.4827936292790318, 0.5898280832845495, 0.9527482010251842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 483}], {
             RGBColor[
             0.43123446241891855`, 0.5479353496981393, 0.948698856513039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 87}], {
             RGBColor[
             0.32144010648392174`, 0.4528061418339081, 0.9417039869994168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 184}], {
             RGBColor[
             0.4376517235629901, 0.5511173532058586, 0.9497643390234523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 253}], {
             RGBColor[
             0.35598021511374034`, 0.4827539030708413, 0.9439037224194711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 287}], {
             RGBColor[
             0.31931088859466533`, 0.4505681988320882, 0.9415827311905192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 301}], {
             RGBColor[
             0.49545804882307076`, 0.5978313042438662, 0.9544626274499579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 336}], {
             RGBColor[
             0.47990926789082156`, 0.58542393137187, 0.9530910077074245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 354}], {
             RGBColor[
             0.32252783628299564`, 0.4537791338930982, 0.9417721664211531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 388}], {
             RGBColor[
             0.33157794270842256`, 0.4616178812072281, 0.9423488311998864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 409}], {
             RGBColor[
             0.2938507755920474, 0.42380800580193695`, 0.940132815419882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 436}], {
             RGBColor[
             0.3449944123676427, 0.4732385528946725, 0.9432037167828538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 473}], {
             RGBColor[
             0.2990309117164457, 0.42925265730827966`, 0.9404278165088418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 154}], {
             RGBColor[
             0.7267639040768494, 0.783922928096006, 0.9321470662934741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 171}], {
             RGBColor[
             0.47037777522198154`, 0.5809128940593202, 0.9514490079974901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 192}], {
             RGBColor[
             0.39152498613418535`, 0.5130863931305935, 0.946294212255822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.4280975104696688, 0.5447636755214684, 0.9486245811666656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 219}], {
             RGBColor[
             0.5697935423105139, 0.6612069230140997, 0.9595599186442647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 258}], {
             RGBColor[
             0.44262074177976496`, 0.5573429685234437, 0.9495499886233556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 262}], {
             RGBColor[
             0.4066140424697561, 0.526155775330442, 0.9472556735827959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 376}], {
             RGBColor[
             0.4205848118936931, 0.5382565536141679, 0.9481458786566228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 497}], {
             RGBColor[
             0.47412146300073554`, 0.5839521884493253, 0.9517437248130138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 127}], {
             RGBColor[
             0.8591989102072256, 0.8905659049388609, 0.9864323531431288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 147}], {
             RGBColor[
             0.8526636417246913, 0.529899304242684, 0.5774584339898925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 184}], {
             RGBColor[
             0.7135412330833855, 0.7751234699043363, 0.9730039594525782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 221}], {
             RGBColor[
             0.9242610852428408, 0.8982704304455256, 0.6484794882507952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 234}], {
             RGBColor[
             0.9063126289426009, 0.8289774045041336, 0.6243163382349994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 253}], {
             RGBColor[
             0.6318697246341356, 0.7067600197693191, 0.967143342848597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 301}], {
             RGBColor[
             0.7713475583434661, 0.821837420942344, 0.9777022478790838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 316}], {
             RGBColor[
             0.6624800077652702, 0.7332731084999433, 0.9690938030221024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 336}], {
             RGBColor[
             0.7557987774112169, 0.8094300480703478, 0.9763306281365505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 388}], {
             RGBColor[
             0.6074674522288179, 0.6856239979057058, 0.9655884516290124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 436}], {
             RGBColor[
             0.620883921888038, 0.6972446695931502, 0.9664433372119796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 81}], {
             RGBColor[
             0.2928864737857844, 0.4215973242135559, 0.9401217329908362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 171}], {
             RGBColor[
             0.4090554292271066, 0.5282531641753069, 0.9474159938779831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 192}], {
             RGBColor[
             0.3302026401393104, 0.46042666324658016`, 0.9422611981363149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 208}], {
             RGBColor[
             0.38701536387166025`, 0.5096349890530197, 0.9458812546550213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 219}], {
             RGBColor[
             0.508471196315639, 0.6085471931300863, 0.9555269045247576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 238}], {
             RGBColor[
             0.4170525450425667, 0.5347455830602593, 0.9480455561293766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 251}], {
             RGBColor[
             0.2931730251986915, 0.4218985079169302, 0.9401380516698865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 258}], {
             RGBColor[
             0.38129839578489, 0.5046832386394303, 0.9455169745038486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 272}], {
             RGBColor[
             0.30232143214337615`, 0.4315140636582957, 0.9406590399115311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 293}], {
             RGBColor[
             0.578582457393624, 0.6633186431495282, 0.9625149398020252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 403}], {
             RGBColor[
             0.5454124576914773, 0.6374059872808763, 0.9592088642229862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 447}], {
             RGBColor[
             0.2905728038348803, 0.41916551040000816`, 0.9399899729099002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 471}], {
             RGBColor[
             0.6521263465827374, 0.7213327352775194, 0.9506532320788272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 483}], {
             RGBColor[
             0.3997284089104274, 0.520646389689377, 0.9466913186431871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 497}], {
             RGBColor[
             0.4127991170058606, 0.5312924585653119, 0.9477107106935068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 121}], {
             RGBColor[
             0.22174468237743916`, 0.35039809897655055`, 0.9359394036683106]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.27063800741742255`, 0.4017880836094291, 0.9387238061981451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 208}], {
             RGBColor[
             0.3324858109628042, 0.4558962797557328, 0.942644967739437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 213}], {
             RGBColor[
             0.2202872137263247, 0.3488662070153795, 0.9358564029847612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 251}], {
             RGBColor[
             0.23864347228983546`, 0.36815979861964326`, 0.9369017647543021]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 442}], {
             RGBColor[
             0.2381306078360068, 0.36762074556118485`, 0.9368725578823716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 447}], {
             RGBColor[
             0.23604325092602435`, 0.36542680110272124`, 0.936753685994316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 454}], {
             RGBColor[
             0.2248746265777104, 0.3536878687809598, 0.9361176493601785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 500}], {
             RGBColor[
             0.21967281078147302`, 0.34822043056494373`, 0.9358214136459797]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 126}], {
             RGBColor[
             0.504289208348975, 0.6084437231644664, 0.9541186402349197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 149}], {
             RGBColor[
             0.540625880408879, 0.6379434704911183, 0.9569791961650909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 173}], {
             RGBColor[
             0.6203596764497656, 0.7014764485955354, 0.964075560146658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 242}], {
             RGBColor[
             0.7466175241184303, 0.8003829212442619, 0.9428810481338523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 249}], {
             RGBColor[
             0.6235359473541606, 0.7039577755666018, 0.9643921411464688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 269}], {
             RGBColor[
             0.5609980001725171, 0.6544824750687763, 0.958582964058418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 282}], {
             RGBColor[
             0.6084177855813375, 0.6921473526873871, 0.962885304068208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 323}], {
             RGBColor[
             0.7564161337880024, 0.8062755394340282, 0.8629204050270508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 384}], {
             RGBColor[
             0.39409857332891574`, 0.5101959076651558, 0.9469714569601196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 411}], {
             RGBColor[
             0.4006657201660342, 0.5170983953721258, 0.9473454462572704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 419}], {
             RGBColor[
             0.5847042349028322, 0.6736221466676785, 0.9605217589523052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 499}], {
             RGBColor[
             0.5743475030967551, 0.6653202029309262, 0.9596338858294544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 97}], {
             RGBColor[
             0.9918418301129188, 0.9825092007837744, 0.5692119944347548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 163}], {
             RGBColor[
             0.9472677000831091, 0.8139798001662166, 0.4832298213140514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 207}], {
             RGBColor[
             0.9351069377955797, 0.7587606188367377, 0.47308258317377627`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 209}], {
             RGBColor[
             0.9948514855705746, 0.9921389712197164, 0.7349877382312089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 231}], {
             RGBColor[
             0.879442405436877, 0.9037944293481288, 0.8529223377718652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 233}], {
             RGBColor[
             0.9788921335245182, 0.9819450762719373, 0.8385157306415634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 257}], {
             RGBColor[
             0.9791397410141973, 0.9396620716614368, 0.5198667768744751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 317}], {
             RGBColor[
             0.9062729324823862, 0.5632106001230137, 0.44649236510931034`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 326}], {
             RGBColor[
             0.8603044472818449, 0.8888437109835485, 0.8510148449573589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 343}], {
             RGBColor[
             0.920728738466214, 0.6743242594892878, 0.4603352612449215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 346}], {
             RGBColor[
             0.7183210910606576, 0.7745238473066297, 0.8390571508964824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 355}], {
             RGBColor[
             0.7774683536702185, 0.8228654453922359, 0.8436241428882965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 395}], {
             RGBColor[
             0.749683946094778, 0.8003088116491959, 0.8414368525463194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 440}], {
             RGBColor[
             0.9434296852982257, 0.7965522714191877, 0.48002728769919345`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 89}], {
             RGBColor[
             0.2925984761880414, 0.42478343593361145`, 0.9399775893294924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 176}], {
             RGBColor[
             0.29622447069818203`, 0.4279240901305121, 0.9402086344933376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 244}], {
             RGBColor[
             0.3611185636561085, 0.4841320917787186, 0.9443436287130234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 245}], {
             RGBColor[
             0.25972033738633343`, 0.39031292018649366`, 0.9381020610411201]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 260}], {
             RGBColor[
             0.24263313262389596`, 0.37235318458981626`, 0.9371289700081534]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 261}], {
             RGBColor[
             0.30240410894972447`, 0.4332765821863486, 0.9406023955782863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 262}], {
             RGBColor[
             0.3093414127711809, 0.4392853260774658, 0.9410444344433726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 299}], {
             RGBColor[
             0.2577944317187598, 0.3882886712204018, 0.9379923835624739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 328}], {
             RGBColor[
             0.2592509748717875, 0.3898195904244037, 0.9380753315402763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 376}], {
             RGBColor[
             0.3233121821951179, 0.4513861043611917, 0.9419346395171995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 391}], {
             RGBColor[
             0.3743150955210323, 0.495024736722043, 0.9453330205540728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 407}], {
             RGBColor[
             0.27632252286434345`, 0.40776286976323906`, 0.9390475309433604]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 448}], {
             RGBColor[
             0.28804975562944346`, 0.4200889349488619, 0.9397153795004467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 455}], {
             RGBColor[
             0.4442800341977758, 0.5518254258243921, 0.9508409168167211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 475}], {
             RGBColor[
             0.3060220283144641, 0.4364102420981715, 0.9408329262010071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 478}], {
             RGBColor[
             0.2624145878361924, 0.3931447482346404, 0.9382554946184531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 482}], {
             RGBColor[
             0.30394372684162835`, 0.43461012182087044`, 0.9407004986689278]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 146}], {
             RGBColor[
             0.1836713842833611, 0.3103806486931501, 0.9337711856662498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 166}], {
             RGBColor[
             0.19147571921883372`, 0.31858349953374643`, 0.9342156309953462]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 239}], {
             RGBColor[
             0.19195700771123925`, 0.31908936425471746`, 0.9342430396629862]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 332}], {
             RGBColor[
             0.18694868384128802`, 0.31382529832132483`, 0.9339578230277437]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 387}], {
             RGBColor[
             0.18808022272596522`, 0.31501461743282955`, 0.9340222624932641]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 489}], {
             RGBColor[
             0.18944536571522486`, 0.31644946926960615`, 0.9341000053669545]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 177}], {
             RGBColor[
             0.1848471163861694, 0.31161641767892256`, 0.933838141870165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 194}], {
             RGBColor[
             0.18570943860608155`, 0.31252277300643677`, 0.9338872498448976]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 220}], {
             RGBColor[
             0.20117259087192368`, 0.32877552645831687`, 0.9347678534907535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 254}], {
             RGBColor[
             0.18887066842711453`, 0.3158454259818896, 0.934067277206585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 290}], {
             RGBColor[
             0.18341921937923714`, 0.31011560739073746`, 0.9337568252480046]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 297}], {
             RGBColor[
             0.1902871793569701, 0.317334268781148, 0.9341479454085002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 350}], {
             RGBColor[
             0.18341807699895743`, 0.3101144066766324, 0.9337567601911376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 377}], {
             RGBColor[
             0.18305173765274474`, 0.30972936079650676`, 0.9337358977073213]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 412}], {
             RGBColor[
             0.18778375020070825`, 0.3147030060113407, 0.9340053788215426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 426}], {
             RGBColor[
             0.1863343941921356, 0.31317964095185236`, 0.9339228401409845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 476}], {
             RGBColor[
             0.18437093737264393`, 0.311115923344214, 0.9338110241797885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 91}], {
             RGBColor[
             0.3843682357663767, 0.5071210898901892, 0.9457662741578293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 161}], {
             RGBColor[
             0.2611314320863651, 0.3917960701847984, 0.9381824207967593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 184}], {
             RGBColor[
             0.4246238918446351, 0.5398024449911591, 0.9489353468656369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 228}], {
             RGBColor[
             0.28331447723561765`, 0.41511185712296006`, 0.9394457124011348]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 253}], {
             RGBColor[
             0.34295238339538536`, 0.47143899485614194`, 0.9430747302616557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 256}], {
             RGBColor[
             0.30998490234108894`, 0.4428842197606874, 0.9409740715208748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 285}], {
             RGBColor[
             0.2614000119680612, 0.39207836466940904`, 0.9381977160236936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 287}], {
             RGBColor[
             0.3062830568763104, 0.4392532906173888, 0.9407537390327037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 336}], {
             RGBColor[
             0.4668814361724666, 0.5741090231571706, 0.9522620155496091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 354}], {
             RGBColor[
             0.30950000456464066`, 0.4424642256783988, 0.9409431742633377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 388}], {
             RGBColor[
             0.3185501109900676, 0.45030297299252864`, 0.941519839042071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 409}], {
             RGBColor[
             0.28082294387369244`, 0.4124930975872375, 0.9393038232620665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 436}], {
             RGBColor[
             0.33196658064928775`, 0.46192364467997304`, 0.9423747246250382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 473}], {
             RGBColor[
             0.28600307999809077`, 0.4179377490935802, 0.9395988243510263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 133}], {
             RGBColor[
             0.19376977710770305`, 0.3209946998266191, 0.9343462741983627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 241}], {
             RGBColor[
             0.2025944621469051, 0.33027000332016815`, 0.9348488269563937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 271}], {
             RGBColor[
             0.19882737388287028`, 0.32631055470747644`, 0.9346342968526646]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 304}], {
             RGBColor[
             0.19013400622997473`, 0.3171732741129387, 0.9341392224255172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 307}], {
             RGBColor[
             0.1906659921562372, 0.31773242505129645`, 0.9341695182370151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 311}], {
             RGBColor[
             0.18977178861723454`, 0.3167925604360257, 0.9341185946683245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 337}], {
             RGBColor[
             0.18932246677623382`, 0.3163202946924838, 0.9340930064541916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 423}], {
             RGBColor[
             0.18437944571093495`, 0.3111248661472177, 0.9338115087170672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 427}], {
             RGBColor[
             0.18803656473244668`, 0.3149687301135649, 0.9340197762351194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 433}], {
             RGBColor[
             0.18511620603054046`, 0.3118992479564254, 0.9338534661273294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 465}], {
             RGBColor[
             0.18430414736705614`, 0.3110457228136103, 0.9338072205877772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 469}], {
             RGBColor[
             0.1854557592359103, 0.3122561399041857, 0.9338728031800514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 176}], {
             RGBColor[
             0.31330748759898347`, 0.4457929312912065, 0.9411846539562421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 178}], {
             RGBColor[
             0.38949543937037706`, 0.5113489021851207, 0.9461592546246456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 244}], {
             RGBColor[
             0.37820158055690994`, 0.5020009329394131, 0.945319648175928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 261}], {
             RGBColor[
             0.31948712585052597`, 0.45114542334704305`, 0.9415784150411908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 262}], {
             RGBColor[
             0.3264244296719824, 0.4571541672381602, 0.9420204539062771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 299}], {
             RGBColor[
             0.27487744861956126`, 0.4061575123810962, 0.9389684030253784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 328}], {
             RGBColor[
             0.27633399177258894`, 0.4076884315850981, 0.9390513510031808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 376}], {
             RGBColor[
             0.3403951990959194, 0.4692549455218861, 0.9429106589801041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 391}], {
             RGBColor[
             0.39139811242183375`, 0.5128935778827375, 0.9463090400169774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 407}], {
             RGBColor[
             0.2934055397651449, 0.4256317109239335, 0.9400235504062648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 448}], {
             RGBColor[
             0.30513277253024496`, 0.43795777610955633`, 0.9406913989633512]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 455}], {
             RGBColor[
             0.4613630510985772, 0.5696942669850865, 0.9518169362796256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 475}], {
             RGBColor[
             0.32310504521526556`, 0.4542790832588659, 0.9418089456639116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 478}], {
             RGBColor[
             0.27949760473699387`, 0.41101358939533483`, 0.9392315140813577]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 482}], {
             RGBColor[
             0.3210267437424298, 0.45247896298156487`, 0.9416765181318323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 137}], {
             RGBColor[
             0.23700337417738956`, 0.3664359515152362, 0.9368083635931062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 148}], {
             RGBColor[
             0.26849318417245727`, 0.3995337383893224, 0.9386016616873261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 229}], {
             RGBColor[
             0.24859585520259658`, 0.3786203840784777, 0.9374685382379528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 232}], {
             RGBColor[
             0.2704052861597108, 0.40154347881219404`, 0.9387105530667987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 263}], {
             RGBColor[
             0.24334458110817345`, 0.37310096205523113`, 0.9371694859468394]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 267}], {
             RGBColor[
             0.24580395513477205`, 0.37568592009050583`, 0.9373095436593363]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 280}], {
             RGBColor[
             0.25791236607974777`, 0.3884126277112705, 0.937999099749864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 342}], {
             RGBColor[
             0.36933196448262395`, 0.489404611907154, 0.9450840596145658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 393}], {
             RGBColor[
             0.24183341082623228`, 0.3715126262751811, 0.9370834270348589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 480}], {
             RGBColor[
             0.2528560578238772, 0.3830981271458908, 0.9377111504748298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 485}], {
             RGBColor[
             0.25884791756577036`, 0.3893959516404705, 0.9380523780229685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 200}], {
             RGBColor[
             0.3616498178113511, 0.4832425921885635, 0.9444724938641782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 228}], {
             RGBColor[
             0.35927043823642757`, 0.48074171339394056`, 0.9443369917173629]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 256}], {
             RGBColor[
             0.3859408633418989, 0.5085140760316679, 0.9458653508371028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 287}], {
             RGBColor[
             0.38223901787712034`, 0.5048831468883692, 0.9456450183489318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 298}], {
             RGBColor[
             0.368006349252357, 0.4899237097604318, 0.9448344889260978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 336}], {
             RGBColor[
             0.5428373971732765, 0.639738879428151, 0.957153294865837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 132}], {
             RGBColor[
             0.27212682678288186`, 0.40335292715912663`, 0.9388085922584972]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 250}], {
             RGBColor[
             0.24579035153480303`, 0.3756716218444204, 0.9373087689544427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 342}], {
             RGBColor[
             0.37412603951120016`, 0.4944434887241004, 0.9453570750952447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 356}], {
             RGBColor[
             0.2586276684650108, 0.3891644558709726, 0.9380398351625095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 365}], {
             RGBColor[
             0.23949140661491064`, 0.36905103135743866`, 0.9369500533597088]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 457}], {
             RGBColor[
             0.37059515571215895`, 0.49157695819153635`, 0.9450791109885306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 485}], {
             RGBColor[
             0.26364199259434656`, 0.39443482845741684`, 0.9383253935036474]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 494}], {
             RGBColor[
             0.31362082310207806`, 0.44266127858544857`, 0.9413292216811688]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 141}], {
             RGBColor[
             0.21496969901233648`, 0.34327716190107216`, 0.9355535783883577]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 151}], {
             RGBColor[
             0.21317178010893856`, 0.3413874351389585, 0.9354511895665918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 160}], {
             RGBColor[
             0.23103960685447572`, 0.36016765393416605`, 0.9364687358666692]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 167}], {
             RGBColor[
             0.23124675852992788`, 0.3603853834792411, 0.9364805328481329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 172}], {
             RGBColor[
             0.22306123798292227`, 0.35178188239235997`, 0.9360143795623734]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 201}], {
             RGBColor[
             0.24004103918211672`, 0.36962873003428975`, 0.9369813541213027]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 218}], {
             RGBColor[
             0.2542535028794738, 0.3845669305024568, 0.9377907329034113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 235}], {
             RGBColor[
             0.21987414226832205`, 0.3484320427227756, 0.9358328791763124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 236}], {
             RGBColor[
             0.21549489107563347`, 0.3438291720586974, 0.9355834872994104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 274}], {
             RGBColor[
             0.23335737797095998`, 0.3626037783327675, 0.936600729502918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 284}], {
             RGBColor[
             0.21473027895683314`, 0.3430255162426299, 0.9355399437703871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 289}], {
             RGBColor[
             0.21635167337317993`, 0.34472970457655394`, 0.93563227978376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 300}], {
             RGBColor[
             0.2272468293636924, 0.3561812043153706, 0.9362527427994807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 305}], {
             RGBColor[
             0.26659251557076086`, 0.3973687929461906, 0.9384995442473698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 308}], {
             RGBColor[
             0.20676738749395213`, 0.33465601243866294`, 0.9350864688816183]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 389}], {
             RGBColor[
             0.20877589722978934`, 0.3367670835179003, 0.9352008505397502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 432}], {
             RGBColor[
             0.2569317093580773, 0.38738189531956746`, 0.9379432528003164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 456}], {
             RGBColor[
             0.20912093230204676`, 0.3371297372553299, 0.9352204997766816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 493}], {
             RGBColor[
             0.24176752917831046`, 0.3714433804860776, 0.9370796751724728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 123}], {
             RGBColor[
             0.18238673674691558`, 0.30903040268098764`, 0.933698026889515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 139}], {
             RGBColor[
             0.18076319755662762`, 0.3073239600536649, 0.9336055687344391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 158}], {
             RGBColor[
             0.18531714297239393`, 0.3121104454224513, 0.9338649091889084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 193}], {
             RGBColor[
             0.17992543383268728`, 0.3064434172625156, 0.9335578593297211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 401}], {
             RGBColor[
             0.17982716171712376`, 0.30634012703824637`, 0.9335522628781203]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 410}], {
             RGBColor[
             0.18058759193707163`, 0.30713938741347224`, 0.9335955682541907]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 428}], {
             RGBColor[
             0.18335052254202558`, 0.31004340265919705`, 0.9337529130647533]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 437}], {
             RGBColor[
             0.18042329707310156`, 0.30696670309454366`, 0.93358621190474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 122}], {
             RGBColor[
             0.18517962016864098`, 0.3119659002362576, 0.9338570774686815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 185}], {
             RGBColor[
             0.19811081032671668`, 0.3255574009772055, 0.9345934896182024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 212}], {
             RGBColor[
             0.18331321264928, 0.31000418759633763`, 0.9337507883215563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 224}], {
             RGBColor[
             0.19530748745975585`, 0.322610930903094, 0.9344338445280735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 286}], {
             RGBColor[
             0.18603827385130794`, 0.3128683996985284, 0.9339059765256451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 319}], {
             RGBColor[
             0.18277177150935192`, 0.30943509862892227`, 0.9337199540496279]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 330}], {
             RGBColor[
             0.18713069149999506`, 0.314016599910578, 0.9339681880946508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 357}], {
             RGBColor[
             0.18661251030183867`, 0.3134719586167301, 0.9339386784419961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 367}], {
             RGBColor[
             0.19091514645848728`, 0.31799430202025647`, 0.9341837072059376]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 368}], {
             RGBColor[
             0.1819562792912616, 0.3085779646025163, 0.9336735129742202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 492}], {
             RGBColor[
             0.18364470169108055`, 0.3103526035968892, 0.9337696661320929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 110}], {
             RGBColor[
             0.443925135446012, 0.558453392319533, 0.9496384572015815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 136}], {
             RGBColor[
             0.4994982670529912, 0.6045542211909409, 0.9537414797863035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.3849349952696799, 0.5064668572722832, 0.9459123269300246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 240}], {
             RGBColor[
             0.7327901627995155, 0.786266849612556, 0.8137611085910759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 360}], {
             RGBColor[
             0.5334689580963748, 0.6321331585421514, 0.9564157770239803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 457}], {
             RGBColor[
             0.47001276809964954`, 0.5806165648340276, 0.951420273299755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 163}], {
             RGBColor[
             0.9438826652312557, 0.8041948007039634, 0.3236750855301855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 207}], {
             RGBColor[
             0.9317219029437263, 0.7489756193744845, 0.31352784738991035`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 209}], {
             RGBColor[
             0.9914664507187211, 0.9823539717574632, 0.575433002447343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 231}], {
             RGBColor[
             0.8760573705850234, 0.8940094298858756, 0.6933676019879993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 233}], {
             RGBColor[
             0.9755070986726647, 0.9721600768096842, 0.6789609948576975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 257}], {
             RGBColor[
             0.9757547061623437, 0.9298770721991836, 0.3603120410906092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 281}], {
             RGBColor[
             0.903440360362725, 0.5576720713111039, 0.28746666826170925`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 317}], {
             RGBColor[
             0.9028878976305327, 0.5534256006607606, 0.2869376293254444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 322}], {
             RGBColor[
             0.9046195205529701, 0.5667356132446183, 0.288595833391559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 326}], {
             RGBColor[
             0.8569194124299913, 0.8790587115212953, 0.6914601091734929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 343}], {
             RGBColor[
             0.9173437036143605, 0.6645392600270346, 0.3007805254610556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 355}], {
             RGBColor[
             0.7740833188183651, 0.8130804459299827, 0.6840694071044306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 395}], {
             RGBColor[
             0.7462989112429244, 0.7905238121869427, 0.6818821167624534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 440}], {
             RGBColor[
             0.9400446504463722, 0.7867672719569345, 0.32047255191532753`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 105}], {
             RGBColor[
             0.18986356428247403`, 0.31688902247910566`, 0.93412382115669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 276}], {
             RGBColor[
             0.20095020339638087`, 0.3285417831213411, 0.9347551888530141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 347}], {
             RGBColor[
             0.19568928020766854`, 0.32301221928820867`, 0.9344555870602553]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 382}], {
             RGBColor[
             0.20018581629901203`, 0.3277383638170652, 0.9347116581386283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 425}], {
             RGBColor[
             0.1874902819867422, 0.31439455231150293`, 0.9339886662409045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 462}], {
             RGBColor[
             0.18918443929913709`, 0.3161752190626076, 0.9340851459935643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 131}], {
             RGBColor[
             0.9067135965497277, 0.6223214351513566, 0.549591400192696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 143}], {
             RGBColor[
             0.7801748654933693, 0.827408823277354, 0.9396902443294888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 178}], {
             RGBColor[
             0.7245036529888805, 0.7822124250066672, 0.9353076025507647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 186}], {
             RGBColor[
             0.9865105734086191, 0.9862533521324298, 0.7169514481905657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 277}], {
             RGBColor[
             0.7114622471897839, 0.7713508183962726, 0.9343566439534178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 288}], {
             RGBColor[
             0.8454606604699532, 0.8793558579429647, 0.9455510322617159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 295}], {
             RGBColor[
             0.9822469150718874, 0.9861800274834427, 0.9104424780465525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 313}], {
             RGBColor[
             0.6704591742575927, 0.7358360174967769, 0.9317439644037724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 321}], {
             RGBColor[
             0.9825665367368704, 0.9863121992558153, 0.9051455199034306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 341}], {
             RGBColor[
             0.9869976251000042, 0.9872951064518227, 0.7699640190632113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 373}], {
             RGBColor[
             0.9853487541189616, 0.9874627176430353, 0.859036977734402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 498}], {
             RGBColor[
             0.8771421221278247, 0.9041056565781206, 0.9487087442796804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 203}], {
             RGBColor[
             0.9191489665110915, 0.667681353565574, 0.3474800185895157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 257}], {
             RGBColor[
             0.9781397520963673, 0.9374756322249009, 0.407566735110352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 264}], {
             RGBColor[
             0.92938539319056, 0.7351346977720205, 0.3568427596083415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 281}], {
             RGBColor[
             0.9058254062967486, 0.5652706313368212, 0.33472136228145205`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 324}], {
             RGBColor[
             0.9664798274342277, 0.9712473493741347, 0.7455337650413938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 360}], {
             RGBColor[
             0.7946952326726424, 0.8354763984444047, 0.7327589869340729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 374}], {
             RGBColor[
             0.9203355927006582, 0.6768022824414968, 0.3486163331687475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 397}], {
             RGBColor[
             0.9076183259729562, 0.5790517976305654, 0.33643826418820166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 457}], {
             RGBColor[
             0.7312390426759171, 0.7839598047362808, 0.7277634832098476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 103}], {
             RGBColor[
             0.32745764009317235`, 0.4521656087003331, 0.9423017119454735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 129}], {
             RGBColor[
             0.2672434934849943, 0.39822023424183295`, 0.9385304936514267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[
             0.2805071756988172, 0.41149947624089733`, 0.9393100698709307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 276}], {
             RGBColor[
             0.22935486634297414`, 0.3583968848378599, 0.9363727923868895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 306}], {
             RGBColor[
             0.24294061497845892`, 0.37267636803996923`, 0.9371464806733664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 331}], {
             RGBColor[
             0.2732729587475753, 0.4045575845229832, 0.9388738627783362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 347}], {
             RGBColor[
             0.22409394315426182`, 0.3528673210047275, 0.9360731905941307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 390}], {
             RGBColor[
             0.25051248587412484`, 0.3806348844356572, 0.9375776875192954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 431}], {
             RGBColor[
             0.33318158758536665`, 0.45712340432410575`, 0.9426664368181881]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 486}], {
             RGBColor[
             0.32922289158902907`, 0.45369458082192426`, 0.9424141922098388]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 134}], {
             RGBColor[
             0.1917868632444325, 0.31891053163232136`, 0.9342333501873077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 174}], {
             RGBColor[
             0.1934597999069662, 0.32066889413495503`, 0.934328621455351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 210}], {
             RGBColor[
             0.19748304019874757`, 0.324897574769785, 0.9345577390381172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 225}], {
             RGBColor[
             0.19170377678695943`, 0.3188232024975315, 0.9342286185364699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 247}], {
             RGBColor[
             0.19186086570906943`, 0.31898831291468205`, 0.934237564518192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 252}], {
             RGBColor[
             0.19087465031632422`, 0.3179517380072394, 0.93418140101055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 278}], {
             RGBColor[
             0.19195325855915324`, 0.31908542365816517`, 0.9342428261543212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 309}], {
             RGBColor[
             0.19381918087775277`, 0.3210466263213213, 0.9343490876699807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 383}], {
             RGBColor[
             0.23360844690792137`, 0.362867667704204, 0.9366150275074547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 393}], {
             RGBColor[
             0.2103791435745319, 0.3384521970779141, 0.9352921530472929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 451}], {
             RGBColor[
             0.20226457959273075`, 0.32992327583996894`, 0.9348300406329509]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 480}], {
             RGBColor[
             0.2214017905721769, 0.3500376979486238, 0.9359198764872638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 129}], {
             RGBColor[
             0.3495899489939847, 0.47542806862452014`, 0.9435621141955579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 204}], {
             RGBColor[
             0.3628536312078076, 0.48870731062358463`, 0.9443416904150619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 209}], {
             RGBColor[
             0.7021401008892698, 0.7606785926382128, 0.8442710393667008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 231}], {
             RGBColor[
             0.5867310207555722, 0.6723340507666251, 0.9622056389073572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 233}], {
             RGBColor[
             0.6861807488432135, 0.7504846976904338, 0.9477990317770553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 259}], {
             RGBColor[
             0.5465386609637427, 0.6409354738239997, 0.9581996401022647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 275}], {
             RGBColor[
             0.4495582322834861, 0.5628291466682479, 0.9501364705331162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 326}], {
             RGBColor[
             0.56759306260054, 0.6573833324020449, 0.9602981460928508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 346}], {
             RGBColor[
             0.4256097063793528, 0.5430634687251261, 0.9483404520319744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 348}], {
             RGBColor[
             0.4359422690580296, 0.5517750943296691, 0.9490645720310915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 355}], {
             RGBColor[
             0.48475696898891374`, 0.5914050668107322, 0.9529074440237885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 390}], {
             RGBColor[
             0.3328589413831152, 0.4578427188183445, 0.9426093080634266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 404}], {
             RGBColor[
             0.6233155210312117, 0.7010502757004149, 0.96581591387943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 431}], {
             RGBColor[
             0.415528043094357, 0.534331238706793, 0.9476980573623193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 443}], {
             RGBColor[
             0.3488203865149018, 0.47461920966592475`, 0.9435182887508398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 444}], {
             RGBColor[
             0.4878340995369397, 0.5939032200127712, 0.9531496870124296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 486}], {
             RGBColor[
             0.41156934709801946`, 0.5309024152046116, 0.94744581275397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 125}], {
             RGBColor[
             0.8510407401896769, 0.7816870619636468, 0.6181576134272155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 147}], {
             RGBColor[
             0.8716060245867224, 0.4422899593743725, 0.21185872764377553`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 242}], {
             RGBColor[
             0.9486223107500168, 0.8581914089875718, 0.5941049181072977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 303}], {
             RGBColor[
             0.8824648742106225, 0.5257558359619144, 0.2222571743069387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 310}], {
             RGBColor[
             0.7844721843600413, 0.7296832002097726, 0.6115226819006405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 323}], {
             RGBColor[
             0.958420920419589, 0.8640840271773381, 0.5141442750004963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 379}], {
             RGBColor[
             0.8757781230833462, 0.4743585366446421, 0.21585393387585383`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 408}], {
             RGBColor[
             0.9307079198191593, 0.8448308855634613, 0.624429309131783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 109}], {
             RGBColor[
             0.2025306105640042, 0.3302028912581151, 0.9348451907032074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 205}], {
             RGBColor[
             0.21445329260995954`, 0.34273438603011697`, 0.9355241698076971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 230}], {
             RGBColor[
             0.19866180408544326`, 0.32613653035264917`, 0.9346248678976397]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 382}], {
             RGBColor[
             0.2017475218904906, 0.3293798154115627, 0.9348005949617267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 425}], {
             RGBColor[
             0.18905198757822078`, 0.3160360039060004, 0.9340776030640029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 462}], {
             RGBColor[
             0.19074614489061564`, 0.31781667065710506`, 0.9341740828166627]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 484}], {
             RGBColor[
             0.1881185665568436, 0.315054919230222, 0.9340244461177081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 156}], {
             RGBColor[
             0.1895211212928381, 0.31652909318485867`, 0.9341043195350291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 227}], {
             RGBColor[
             0.18640315120824044`, 0.31325190893522514`, 0.9339267557513348]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 265}], {
             RGBColor[
             0.18198502195137928`, 0.3086081749606899, 0.933675149826193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 270}], {
             RGBColor[
             0.17988066425974236`, 0.3063963616027956, 0.9335553097687725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 329}], {
             RGBColor[
             0.18061317161541351`, 0.30716627327725476`, 0.9335970249790304]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 479}], {
             RGBColor[
             0.18098277247116215`, 0.30755474721069437`, 0.9336180732009899]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 153}], {
             RGBColor[
             0.21946182531602942`, 0.3479986714635114, 0.9358093983358476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 170}], {
             RGBColor[
             0.19951076544330998`, 0.3270288425670261, 0.9346732149910444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 197}], {
             RGBColor[
             0.221090097802618, 0.3497100890853544, 0.9359021260451457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 214}], {
             RGBColor[
             0.19941582681621922`, 0.32692905605049705`, 0.9346678083766806]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 223}], {
             RGBColor[
             0.20973558752308613`, 0.3377757788640342, 0.935255503482219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 236}], {
             RGBColor[
             0.20982294786551192`, 0.3378676001228893, 0.935260478524482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 289}], {
             RGBColor[
             0.21067973016305835`, 0.3387681326407459, 0.9353092710088315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 314}], {
             RGBColor[
             0.2370472271918243, 0.36648204381384886`, 0.9368108609574035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 411}], {
             RGBColor[
             0.24624789168403566`, 0.3761525255509848, 0.9373348251890715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 466}], {
             RGBColor[
             0.20308636910120992`, 0.33078702871784477`, 0.9348768403297303]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 470}], {
             RGBColor[
             0.20295018288856098`, 0.3306438883736461, 0.9348690847263893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 113}], {
             RGBColor[
             0.2031652064588611, 0.33086989177931336`, 0.934881330000619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 190}], {
             RGBColor[
             0.21307880253974895`, 0.34128970981862183`, 0.9354458946315745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 315}], {
             RGBColor[
             0.19651178198130725`, 0.3238767208019274, 0.9345024273194817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 349}], {
             RGBColor[
             0.19740440059431363`, 0.32481491955948594`, 0.9345532606289816]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 364}], {
             RGBColor[
             0.2070027664491964, 0.33490341064451234`, 0.9350998733649074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 378}], {
             RGBColor[
             0.20828889068141454`, 0.33625520875755976`, 0.9351731162372818]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 380}], {
             RGBColor[
             0.19854131235532485`, 0.3260098859046778, 0.934618006071861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 416}], {
             RGBColor[
             0.20942130064370462`, 0.3374454434268651, 0.9352376053093838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 452}], {
             RGBColor[
             0.21821098000140754`, 0.3466839537296702, 0.9357381645456397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 487}], {
             RGBColor[
             0.20117686323780593`, 0.3287800169857428, 0.9347680967956702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 164}], {
             RGBColor[
             0.2648306442899861, 0.3950111522821019, 0.9384177281820844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 180}], {
             RGBColor[
             0.23839049921865452`, 0.36789390788241305`, 0.9368873583121385]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 205}], {
             RGBColor[
             0.22555863330001114`, 0.354406803214629, 0.9361566025311163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 230}], {
             RGBColor[
             0.20976714477549485`, 0.3378089475371612, 0.9352573006210588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 382}], {
             RGBColor[
             0.2128528625805422, 0.3410522325960747, 0.9354330276851459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 413}], {
             RGBColor[
             0.22197296688604118`, 0.35063804046916514`, 0.9359524041333588]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 474}], {
             RGBColor[
             0.22157473772172553`, 0.350219476368282, 0.9359297255715783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 490}], {
             RGBColor[
             0.21480193499900369`, 0.3431008312862066, 0.935544024475983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 157}], {
             RGBColor[
             0.35808579273911467`, 0.4836854080233668, 0.944070557261417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 356}], {
             RGBColor[
             0.3311960783219361, 0.45542261326454736`, 0.9425392278051263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 360}], {
             RGBColor[
             0.5066197555658096, 0.6093517092932348, 0.9545740073553726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 457}], {
             RGBColor[
             0.44316356556908426`, 0.5578351155851111, 0.9495785036311474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 494}], {
             RGBColor[
             0.3861892329590033, 0.5089194359790232, 0.9458286143237857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 130}], {
             RGBColor[
             0.3347552996533061, 0.46383121081799694`, 0.9425710153855427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 175}], {
             RGBColor[
             0.38213445941917534`, 0.5054073949376681, 0.9455702477393233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 182}], {
             RGBColor[
             0.35579432343932743`, 0.4825928930456521, 0.9438918775663551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 351}], {
             RGBColor[
             0.3033909458875273, 0.43086528639527777`, 0.9407848618379848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 359}], {
             RGBColor[
             0.6380588033619161, 0.711320155207173, 0.9679062350071925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 371}], {
             RGBColor[
             0.3103368514001098, 0.4381658734848475, 0.9411804208813801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 460}], {
             RGBColor[
             0.33363255379100343`, 0.46265113373051764`, 0.9425070766696382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 463}], {
             RGBColor[
             0.4608753150975682, 0.5708435411870683, 0.9513515854271455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 483}], {
             RGBColor[
             0.4093161482374549, 0.528950807600658, 0.9473022409150004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 163}], {
             RGBColor[
             0.9463750065735652, 0.8136106484588435, 0.49802406298394036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 175}], {
             RGBColor[
             0.6955594457176699, 0.7552129086866064, 0.8524579222934991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 207}], {
             RGBColor[
             0.9342142442860358, 0.7583914671293646, 0.48787682484366524`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 238}], {
             RGBColor[
             0.7400652706680888, 0.7928555147204785, 0.8555441529553656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 266}], {
             RGBColor[
             0.9935124253020141, 0.9901198523525236, 0.6506615550659651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 293}], {
             RGBColor[
             0.901595183019146, 0.9214285748097474, 0.8700135366280143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 317}], {
             RGBColor[
             0.9053802389728423, 0.5628414484156407, 0.4612866067791993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 343}], {
             RGBColor[
             0.91983604495667, 0.6739551077819146, 0.4751295029148105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 359}], {
             RGBColor[
             0.9514837896604106, 0.9611256689561112, 0.8747939095613684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 403}], {
             RGBColor[
             0.8684251833169994, 0.8955159189410955, 0.8667074610489753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 440}], {
             RGBColor[
             0.9425369917886818, 0.7961831197118145, 0.4948215293690824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 445}], {
             RGBColor[
             0.9782801480279448, 0.9394045757914982, 0.5347896078268422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 463}], {
             RGBColor[
             0.7743003013960627, 0.8206490549360065, 0.8582392599813213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 471}], {
             RGBColor[
             0.9751390722082593, 0.9794426669377387, 0.8581518289048162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 483}], {
             RGBColor[
             0.7227411345359493, 0.7787563213495963, 0.8541899154691762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 190}], {
             RGBColor[
             0.20663037548476026`, 0.33451200412993914`, 0.9350786662503858]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 315}], {
             RGBColor[
             0.19006335492631857`, 0.31709901511324473`, 0.9341351989382931]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 349}], {
             RGBColor[
             0.19095597353932497`, 0.3180372138708033, 0.934186032247793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 353}], {
             RGBColor[
             0.1887122478968889, 0.3156789159601807, 0.9340582553917509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 364}], {
             RGBColor[
             0.20055433939420772`, 0.3281257049558297, 0.9347326449837188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 378}], {
             RGBColor[
             0.20184046362642588`, 0.32947750306887713`, 0.9348058878560932]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 380}], {
             RGBColor[
             0.19209288530033616`, 0.3192321802159951, 0.9342507776906723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 487}], {
             RGBColor[
             0.19472843618281724`, 0.32200231129706014`, 0.9344008684144816]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 128}], {
             RGBColor[
             0.1878451960142834, 0.31476758945729777`, 0.9340088780697248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 138}], {
             RGBColor[
             0.18210218513342014`, 0.30873132089358957`, 0.9336818220960829]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 179}], {
             RGBColor[
             0.19077318734493098`, 0.3178450939911811, 0.9341756228444302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 255}], {
             RGBColor[
             0.1893023656117655, 0.31629916709414013`, 0.9340918617226122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 294}], {
             RGBColor[
             0.18446317038438925`, 0.311212866087469, 0.9338162767133609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 296}], {
             RGBColor[
             0.18183178255671295`, 0.30844711064095676`, 0.9336664230693641]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 312}], {
             RGBColor[
             0.1882015984664733, 0.31514219103177, 0.9340291746621268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 327}], {
             RGBColor[
             0.18260674360457746`, 0.3092616438376308, 0.933710555954588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 334}], {
             RGBColor[
             0.18414474445457316`, 0.31087818024586233`, 0.9337981428277268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 385}], {
             RGBColor[
             0.18149489941754873`, 0.3080930251020705, 0.9336472380729627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 415}], {
             RGBColor[
             0.18091671513236096`, 0.30748531675933716`, 0.9336143113332682]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 446}], {
             RGBColor[
             0.18242070987008802`, 0.30906611058746236`, 0.933699961608621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 144}], {
             RGBColor[
             0.1939326542641488, 0.3211658940450518, 0.9343555498114672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 215}], {
             RGBColor[
             0.18797465353578718`, 0.3149036575204792, 0.9340162504840592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 223}], {
             RGBColor[
             0.1995856510144891, 0.3271075520503548, 0.9346774796135398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 268}], {
             RGBColor[
             0.18864406926620203`, 0.3156072558965539, 0.9340543727195945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 402}], {
             RGBColor[
             0.20455792141877943`, 0.3323337235054161, 0.9349606430572492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 417}], {
             RGBColor[
             0.19405888879625283`, 0.3212985745420247, 0.9343627386813232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 143}], {
             RGBColor[
             0.4285653763865951, 0.5391828000638526, 0.9495933114012363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 165}], {
             RGBColor[
             0.2912027626996634, 0.4234029452918576, 0.9398949385886397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 185}], {
             RGBColor[
             0.24400994073613447`, 0.3738002972104551, 0.9372073771933402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 187}], {
             RGBColor[
             0.24886259772016034`, 0.3789007473768896, 0.9374837288297179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 224}], {
             RGBColor[
             0.2412066178691736, 0.37085382713634363`, 0.9370477321032114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 277}], {
             RGBColor[
             0.35985275808300965`, 0.4831247951827711, 0.9442597110251651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 313}], {
             RGBColor[
             0.3188496851508186, 0.44760999428327536`, 0.9416470314755198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 333}], {
             RGBColor[
             0.2541335864563355, 0.3844408907385981, 0.937783903840514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 358}], {
             RGBColor[
             0.2506809998117433, 0.38081200326849496`, 0.9375872841387487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 361}], {
             RGBColor[
             0.25328984688463263`, 0.3835540669525598, 0.9377358541201064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 386}], {
             RGBColor[
             0.2910406970756628, 0.423232604045479, 0.9398857091911075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 441}], {
             RGBColor[
             0.24897326082313725`, 0.37901706131456436`, 0.9374900309297209]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 140}], {
             RGBColor[
             0.1812891715754636, 0.30787679209614044`, 0.933635522176703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 155}], {
             RGBColor[
             0.1887434182573529, 0.3157116779853434, 0.9340600304976668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 156}], {
             RGBColor[
             0.19147940284680726`, 0.31858737126030207`, 0.9342158407725099]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 198}], {
             RGBColor[
             0.18298777738438862`, 0.30966213449914926`, 0.9337322552646592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 270}], {
             RGBColor[
             0.18183894581371152`, 0.308454639678239, 0.933666831006253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 479}], {
             RGBColor[
             0.1829410540251313, 0.30961302528613777`, 0.9337295944384705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 152}], {
             RGBColor[
             0.1882232378558979, 0.3151649354020718, 0.9340304069933419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 187}], {
             RGBColor[
             0.20672865124829637`, 0.33461529818845887`, 0.9350842629097332]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.19015295783973063`, 0.31719319345639363`, 0.9341403016916563]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 255}], {
             RGBColor[
             0.19469073239539242`, 0.3219626822259184, 0.9343987212395655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 260}], {
             RGBColor[
             0.20098092756456265`, 0.3285740761701249, 0.9347569385489398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 292}], {
             RGBColor[
             0.188665488336347, 0.3156297686973238, 0.9340555925039526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 399}], {
             RGBColor[
             0.200045010570769, 0.32759036806908304`, 0.9347036394607084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 446}], {
             RGBColor[
             0.18780907665371493`, 0.3147296257192406, 0.9340068211255742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 464}], {
             RGBColor[
             0.1973325308094801, 0.3247393798588184, 0.9345491677510571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 481}], {
             RGBColor[
             0.1987399075504107, 0.32621862204637564`, 0.9346293157744259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 496}], {
             RGBColor[
             0.18901315212113398`, 0.315995185378292, 0.9340753914421738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 120}], {
             RGBColor[
             0.18211134871711507`, 0.30874095240105776`, 0.9336823439486179]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 124}], {
             RGBColor[
             0.18484388120986256`, 0.311613017303502, 0.9338379576316604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 363}], {
             RGBColor[
             0.18346622269800678`, 0.3101650108589469, 0.9337595020174734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 364}], {
             RGBColor[
             0.19435544195191212`, 0.32161027071117865`, 0.934379626944827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 381}], {
             RGBColor[
             0.18630903659373593`, 0.3131529885081697, 0.9339213960632688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 416}], {
             RGBColor[
             0.19677397614642037`, 0.32415230349353147`, 0.9345173588893034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 124}], {
             RGBColor[
             0.18263624540769638`, 0.3092926521032311, 0.9337122360386315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 315}], {
             RGBColor[
             0.18165682168185682`, 0.3082632156683228, 0.9336564593063725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 363}], {
             RGBColor[
             0.18125858689584057`, 0.307844645658676, 0.9336337804244444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 381}], {
             RGBColor[
             0.18410140079156978`, 0.3108326233078988, 0.9337956744702399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 196}], {
             RGBColor[
             0.19856429776732792`, 0.3260340450300523, 0.9346193150570707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.20367497522683542`, 0.331405691075661, 0.93491036057782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 307}], {
             RGBColor[
             0.1984527242001829, 0.32591677413681014`, 0.93461296110748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 337}], {
             RGBColor[
             0.19710919882017952`, 0.3245046437779975, 0.9345364493246566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 420}], {
             RGBColor[
             0.1965885249531354, 0.3239573825311042, 0.9345067977181964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 427}], {
             RGBColor[
             0.19582329677639237`, 0.3231530791990786, 0.9344632191055845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 442}], {
             RGBColor[
             0.22151836933651753`, 0.35016022962146637`, 0.9359265154754303]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 447}], {
             RGBColor[
             0.21943101242653507`, 0.34796628516300276`, 0.9358076435873746]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 454}], {
             RGBColor[
             0.20826238807822112`, 0.3362273528412414, 0.9351716069532372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 489}], {
             RGBColor[
             0.1983767553672155, 0.32583692607665915`, 0.9346086347948284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 500}], {
             RGBColor[
             0.20306057228198376`, 0.33075991462522525`, 0.9348753712390383]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 185}], {
             RGBColor[
             0.19860974920189184`, 0.3260818173695664, 0.9346219034490297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 212}], {
             RGBColor[
             0.18381215152445518`, 0.3105286039886985, 0.9337792021523836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 216}], {
             RGBColor[
             0.19279683115434215`, 0.3199720719413004, 0.9342908663656634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 217}], {
             RGBColor[
             0.1834604918576584, 0.31015898738238445`, 0.9337591756545935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 224}], {
             RGBColor[
             0.195806426334931, 0.3231353472954549, 0.9344622583589008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 286}], {
             RGBColor[
             0.1865372127264831, 0.3133928160908893, 0.9339343903564724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 319}], {
             RGBColor[
             0.1832707103845271, 0.30995951502128316`, 0.9337483678804552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 330}], {
             RGBColor[
             0.18762963037517022`, 0.3145410163029389, 0.9339966019254781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 357}], {
             RGBColor[
             0.18711144917701383`, 0.313996375009091, 0.9339670922728234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 492}], {
             RGBColor[
             0.1841436405662557, 0.3108770199892501, 0.9337980799629202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 139}], {
             RGBColor[
             0.1842229343035432, 0.31096036273465255`, 0.9338025956239542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 158}], {
             RGBColor[
             0.1887768797193095, 0.31574684810343895`, 0.9340619360784235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 193}], {
             RGBColor[
             0.18338517057960285`, 0.31007981994350325`, 0.9337548862192361]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 401}], {
             RGBColor[
             0.18328689846403934`, 0.309976529719234, 0.9337492897676354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 410}], {
             RGBColor[
             0.18404732868398718`, 0.3107757900944599, 0.9337925951437056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 422}], {
             RGBColor[
             0.1961933017960193, 0.3235419779343797, 0.9344842903440789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 428}], {
             RGBColor[
             0.18681025928894113`, 0.3136798053401847, 0.9339499399542682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 437}], {
             RGBColor[
             0.18388303382001714`, 0.3106031057755313, 0.9337832387942551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 363}], {
             RGBColor[
             0.1839911193885881, 0.3107167105611202, 0.9337893941074868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 381}], {
             RGBColor[
             0.18683393328431724`, 0.31370468821034303`, 0.9339512881532823]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 416}], {
             RGBColor[
             0.19729887283700168`, 0.3247040031957048, 0.934547250979317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.669539684263013, 0.7405244264891351, 0.9685478722425018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 173}], {
             RGBColor[
             0.7492734803038996, 0.8040574045935522, 0.9756442362240689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 242}], {
             RGBColor[
             0.8755313279725643, 0.9029638772422787, 0.9544497242112633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 249}], {
             RGBColor[
             0.7524497512082946, 0.8065387315646185, 0.9759608172238798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 269}], {
             RGBColor[
             0.6899118040266511, 0.7570634310667932, 0.970151640135829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 282}], {
             RGBColor[
             0.7373315894354715, 0.794728308685404, 0.9744539801456191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 305}], {
             RGBColor[
             0.5442522046967718, 0.6349340468295404, 0.9597558326180513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 310}], {
             RGBColor[
             0.7113812015825887, 0.7744556684644794, 0.9718674880046061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 323}], {
             RGBColor[
             0.8853299376421364, 0.9088564954320449, 0.8744890811044619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 406}], {
             RGBColor[
             0.5972259557238873, 0.6808172474310844, 0.9631312731906503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 408}], {
             RGBColor[
             0.8576169370417068, 0.8896033538181681, 0.9847741152357485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 419}], {
             RGBColor[
             0.7136180387569662, 0.7762031026656953, 0.9720904350297161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 173}], {
             RGBColor[
             0.6045267350947843, 0.6886225535376819, 0.9628291330052186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 249}], {
             RGBColor[
             0.6077030059991793, 0.6911038805087482, 0.9631457140050295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 269}], {
             RGBColor[
             0.5451650588175359, 0.6416285800109227, 0.9573365369169786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 282}], {
             RGBColor[
             0.5925848442263562, 0.6792934576295336, 0.9616388769267687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 340}], {
             RGBColor[
             0.4261246264730337, 0.5425553802981693, 0.948636879181104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 384}], {
             RGBColor[
             0.3782656319739345, 0.49734201260730226`, 0.9457250298186803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 414}], {
             RGBColor[
             0.45556143140572114`, 0.5680520611940277, 0.9505125663614704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 449}], {
             RGBColor[
             0.7360314578812237, 0.7759766732200013, 0.6718437842469422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 499}], {
             RGBColor[
             0.5585145617417738, 0.6524663078730726, 0.9583874586880152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 184}], {
             RGBColor[
             0.6864931860475436, 0.7535560913976342, 0.970424092580223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 221}], {
             RGBColor[
             0.8972130382069989, 0.8767030519388234, 0.6458996213784399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 253}], {
             RGBColor[
             0.604821677598294, 0.6851926412626169, 0.9645634759762418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 301}], {
             RGBColor[
             0.7442995113076243, 0.8002700424356418, 0.9751223810067287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 303}], {
             RGBColor[
             0.8364744443127496, 0.5917978023235237, 0.5852770137807005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 316}], {
             RGBColor[
             0.6354319607294284, 0.7117057299932411, 0.9665139361497471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 138}], {
             RGBColor[
             0.18851306554638397`, 0.31546956268090953`, 0.9340469122515535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 179}], {
             RGBColor[
             0.19718406775789482`, 0.32458333577850107`, 0.9345407129999008]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 222}], {
             RGBColor[
             0.19567917188119596`, 0.32300159479618107`, 0.9344550114060167]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 245}], {
             RGBColor[
             0.21909064595633707`, 0.347608538422344, 0.9357882602204238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 294}], {
             RGBColor[
             0.1908740507973531, 0.317951107874789, 0.9341813668688315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 296}], {
             RGBColor[
             0.1882426629696768, 0.3151853524282767, 0.9340315132248347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 312}], {
             RGBColor[
             0.19461247887943717`, 0.32188043281908996`, 0.9343942648175974]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 385}], {
             RGBColor[
             0.1879057798305126, 0.31483126688939045`, 0.9340123282284333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 415}], {
             RGBColor[
             0.1873275955453248, 0.3142235585466571, 0.9339794014887388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 438}], {
             RGBColor[
             0.19844895166515433`, 0.32591280896330255`, 0.9346127462671912]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 439}], {
             RGBColor[
             0.1967431917255388, 0.32411994711534, 0.9345156057620757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 204}], {
             RGBColor[
             0.3026394845996296, 0.4347619361650844, 0.9405704721210151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 275}], {
             RGBColor[
             0.3893440856753081, 0.5088837722097477, 0.9463652522390695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 276}], {
             RGBColor[
             0.2514871752437865, 0.381659344762047, 0.9376331946369739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 306}], {
             RGBColor[
             0.2650729238792713, 0.39593882796415625`, 0.9384068829234508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 331}], {
             RGBColor[
             0.2954052676483876, 0.42782004444717026`, 0.9401342650284206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 346}], {
             RGBColor[
             0.36539555977117477`, 0.4891180942666259, 0.9445692337379277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 348}], {
             RGBColor[
             0.37572812244985154`, 0.497829719871169, 0.9452933537370448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 355}], {
             RGBColor[
             0.4245428223807357, 0.5374596923522321, 0.9491362257297418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 431}], {
             RGBColor[
             0.35531389648617895`, 0.48038586424829277`, 0.9439268390682725]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 444}], {
             RGBColor[
             0.42761995292876165`, 0.539957845554271, 0.9493784687183828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 486}], {
             RGBColor[
             0.3513552004898414, 0.47695704074611134`, 0.9436745944599232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 175}], {
             RGBColor[
             0.350298253723786, 0.4772937364222603, 0.943561398674819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 182}], {
             RGBColor[
             0.323958117743938, 0.4544792345302443, 0.9418830285018508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 208}], {
             RGBColor[
             0.3647668975032984, 0.4898257484488929, 0.9444833278623301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 238}], {
             RGBColor[
             0.39480407867420486`, 0.5149363424561325, 0.9466476293366854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 241}], {
             RGBColor[
             0.2592745192308342, 0.38984433703856036`, 0.9380766723566932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 351}], {
             RGBColor[
             0.2715547401921379, 0.40275162787986996`, 0.9387760127734806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 371}], {
             RGBColor[
             0.27850064570472033`, 0.41005221496943967`, 0.9391715718168758]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 442}], {
             RGBColor[
             0.2704116943765009, 0.4015502142543449, 0.9387109180052648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 483}], {
             RGBColor[
             0.3774799425420655, 0.5008371490852502, 0.9452933918504961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 186}], {
             RGBColor[
             0.913526249632497, 0.6241954645463874, 0.3472925437386266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 234}], {
             RGBColor[
             0.88005378670787, 0.5030425365640092, 0.21977647609763581`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 373}], {
             RGBColor[
             0.9123644303428394, 0.625404830056993, 0.48937807328246297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 434}], {
             RGBColor[
             0.8844045850628767, 0.520292002224005, 0.22327723058043727`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 449}], {
             RGBColor[
             0.9086679607710296, 0.6083135329493521, 0.2853739255705805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 495}], {
             RGBColor[
             0.8599106722287021, 0.41795803680078086`, 0.20329863351297417`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 250}], {
             RGBColor[
             0.24597806511608875`, 0.3758689207200801, 0.9373194589651996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 356}], {
             RGBColor[
             0.2588153820462965, 0.38936175474663237`, 0.9380505251732665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 365}], {
             RGBColor[
             0.23967912019619636`, 0.3692483302330984, 0.9369607433704656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 457}], {
             RGBColor[
             0.37078286929344473`, 0.4917742570671961, 0.9450898009992874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 494}], {
             RGBColor[
             0.3138085366833637, 0.4428585774611083, 0.9413399116919258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 191}], {
             RGBColor[
             0.19428859491049005`, 0.32154001023229684`, 0.9343758201047092]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 237}], {
             RGBColor[
             0.21543537025685555`, 0.3437666119043239, 0.9355800976768341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 241}], {
             RGBColor[
             0.2068052594645497, 0.3346958182809826, 0.9350886256343172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 271}], {
             RGBColor[
             0.20303817120051487`, 0.3307363696682909, 0.9348740955305881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 304}], {
             RGBColor[
             0.19434480354761932`, 0.3215990890737532, 0.9343790211034406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 311}], {
             RGBColor[
             0.19398258593487913`, 0.3212183753968402, 0.9343583933462479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 351}], {
             RGBColor[
             0.21908548042585338`, 0.34760310912229214`, 0.9357879660511045]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 366}], {
             RGBColor[
             0.1902687027163505, 0.3173148486603702, 0.9341468931911505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 371}], {
             RGBColor[
             0.22603138593843586`, 0.35490369621186185`, 0.9361835250944996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 405}], {
             RGBColor[
             0.18981989868512106`, 0.3168431271677289, 0.9341213344655181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 423}], {
             RGBColor[
             0.18859024302857952`, 0.3155506811080321, 0.9340513073949906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 429}], {
             RGBColor[
             0.19496484613925177`, 0.3222507931505298, 0.9344143316117632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 469}], {
             RGBColor[
             0.18966655655355485`, 0.31668195486500017`, 0.9341126018579748]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 488}], {
             RGBColor[
             0.19025464326071956`, 0.31730007128108106`, 0.9341460925259515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 174}], {
             RGBColor[
             0.18580423451035571`, 0.31262240951223635`, 0.9338926483314081]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 210}], {
             RGBColor[
             0.18982747480213708`, 0.31685109014706625`, 0.9341217659141743]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 225}], {
             RGBColor[
             0.1840482113903489, 0.31077671787481287`, 0.933792645412527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 247}], {
             RGBColor[
             0.1842053003124589, 0.3109418282919634, 0.933801591394249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 252}], {
             RGBColor[
             0.18321908491971373`, 0.3099052533845207, 0.9337454278866071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 278}], {
             RGBColor[
             0.18429769316254274`, 0.3110389390354465, 0.9338068530303782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 309}], {
             RGBColor[
             0.18616361548114224`, 0.31300014169860263`, 0.9339131145460378]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 424}], {
             RGBColor[
             0.18880157011833354`, 0.31577279927827495`, 0.9340633421601217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 169}], {
             RGBColor[
             0.1819041358977289, 0.3085231585898313, 0.9336705434850978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 211}], {
             RGBColor[
             0.18373947818140363`, 0.31045221969739534`, 0.9337750635130075]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 362}], {
             RGBColor[
             0.1796163784049865, 0.3061185804127562, 0.9335402590803201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 369}], {
             RGBColor[
             0.18101136995755066`, 0.307584804982074, 0.9336197017855334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 466}], {
             RGBColor[
             0.18744105358565671`, 0.3143428101407012, 0.9339858627562896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 470}], {
             RGBColor[
             0.18730486737300778`, 0.31419966979650255`, 0.9339781071529487]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 240}], {
             RGBColor[
             0.7615140918759296, 0.8095862292350475, 0.8160223615071904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 434}], {
             RGBColor[
             0.7316510467407765, 0.7040970288480641, 0.6113123490612679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 148}], {
             RGBColor[
             0.24314559520540308`, 0.3728918152549845, 0.9371581539940498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 156}], {
             RGBColor[
             0.2055253114742025, 0.33335051178973785`, 0.9350157344897803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 227}], {
             RGBColor[
             0.2024073413896048, 0.33007332754010427`, 0.9348381707060858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 229}], {
             RGBColor[
             0.2232482662355424, 0.35197846094413987`, 0.9360250305446766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 263}], {
             RGBColor[
             0.21799699214111928`, 0.34645903892089325`, 0.935725978253563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 265}], {
             RGBColor[
             0.19798921213274367`, 0.325429593565569, 0.934586564780944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 267}], {
             RGBColor[
             0.22045636616771785`, 0.34904399695616795`, 0.93586603596606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 280}], {
             RGBColor[
             0.2325647771126936, 0.3617707045769326, 0.9365555920565876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 393}], {
             RGBColor[
             0.21648582185917808`, 0.3448707031408432, 0.9356399193415825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 424}], {
             RGBColor[
             0.20256381379959026`, 0.3302377899639228, 0.9348470815783543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 485}], {
             RGBColor[
             0.2335003285987162, 0.3627540285061326, 0.9366088703296922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 179}], {
             RGBColor[
             0.19144105687703156`, 0.31854706721479287`, 0.9342136570262589]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 222}], {
             RGBColor[
             0.1899361610003327, 0.31696532623247287`, 0.9341279554323748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 294}], {
             RGBColor[
             0.18513103991648983`, 0.3119148393110808, 0.9338543108951896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 296}], {
             RGBColor[
             0.18249965208881352`, 0.3091490838645686, 0.9337044572511928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 339}], {
             RGBColor[
             0.1814781394477339, 0.3080754093111516, 0.9336462836174759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 385}], {
             RGBColor[
             0.18216276894964933`, 0.30879499832568225`, 0.9336852722547914]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 415}], {
             RGBColor[
             0.18158458466446153`, 0.308187289982949, 0.9336523455150969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 438}], {
             RGBColor[
             0.19270594078429107`, 0.3198765403995944, 0.9342856902935492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 158}], {
             RGBColor[
             0.18715334052902155`, 0.3140404054761162, 0.9339694779233476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 247}], {
             RGBColor[
             0.18343934894517555`, 0.310136764840827, 0.9337579715970057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 278}], {
             RGBColor[
             0.18353174179525936`, 0.31023387558431004`, 0.933763233233135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 401}], {
             RGBColor[
             0.18166335927375138`, 0.3082700870919113, 0.9336568316125594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 410}], {
             RGBColor[
             0.18242378949369925`, 0.3090693474671371, 0.9337001369886297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 428}], {
             RGBColor[
             0.1851867200986532, 0.311973362712862, 0.9338574817991923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 437}], {
             RGBColor[
             0.18225949462972918`, 0.3088966631482086, 0.9336907806391791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 451}], {
             RGBColor[
             0.19384306282883684`, 0.3210717277661138, 0.9343504477117648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 198}], {
             RGBColor[
             0.18071298100430727`, 0.3072711792732629, 0.9336027089760732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 270}], {
             RGBColor[
             0.1795641494336302, 0.30606368445235266`, 0.9335372847176671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 479}], {
             RGBColor[
             0.18066625764504995`, 0.3072220700602514, 0.9336000481498845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 151}], {
             RGBColor[
             0.20551109996107267`, 0.3333355745883765, 0.9350149251651315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 160}], {
             RGBColor[
             0.2233789267066098, 0.352115793383584, 0.936032471465209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 162}], {
             RGBColor[
             0.19531753931264573`, 0.32262149603780554`, 0.9344344169662252]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 167}], {
             RGBColor[
             0.22358607838206196`, 0.35233352292865905`, 0.9360442684466725]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 235}], {
             RGBColor[
             0.21221346212045616`, 0.34038018217219357`, 0.9353966147748521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 274}], {
             RGBColor[
             0.2256966978230941, 0.35455191778218553`, 0.9361644651014577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 284}], {
             RGBColor[
             0.20706959880896725`, 0.33497365569204784`, 0.9351036793689267]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 300}], {
             RGBColor[
             0.21958614921582648`, 0.3481293437647886, 0.9358164783980203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 345}], {
             RGBColor[
             0.19907503548324326`, 0.3265708627521209, 0.9346484008144234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 389}], {
             RGBColor[
             0.20111521708192343`, 0.32871522296731825`, 0.9347645861382899]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 432}], {
             RGBColor[
             0.24927102921021138`, 0.3793300347689854, 0.937506988398856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 456}], {
             RGBColor[
             0.20146025215418084`, 0.3290778767047479, 0.9347842353752214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 472}], {
             RGBColor[
             0.19522243291560842`, 0.32252153318442556`, 0.9344290007976113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[
             0.2155365862389103, 0.34387299631892737`, 0.9355858617772765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 161}], {
             RGBColor[
             0.21478163330642375`, 0.3430794929201034, 0.9355428683246243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 183}], {
             RGBColor[
             0.20633874170827649`, 0.3342054785402052, 0.9350620581382485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 254}], {
             RGBColor[
             0.20407108545370353`, 0.33182202803893834`, 0.9349329184692474]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 285}], {
             RGBColor[
             0.2150502131881199, 0.3433617874047141, 0.9355581635515585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 388}], {
             RGBColor[
             0.27220031221012625`, 0.4015863957278337, 0.9388802865699359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 396}], {
             RGBColor[
             0.2065755605048984, 0.3344543901106338, 0.9350755446183742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 473}], {
             RGBColor[
             0.23965328121814944`, 0.36922117182888525`, 0.9369592718788913]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 477}], {
             RGBColor[
             0.2067532217668407, 0.3346411233613098, 0.9350856621644155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 165}], {
             RGBColor[
             0.4432891969739572, 0.5546584690453142, 0.950431811201746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 178}], {
             RGBColor[
             0.5249805981564001, 0.6252419255466224, 0.9557475422356184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 186}], {
             RGBColor[
             0.7869875185761387, 0.829282852672385, 0.7373913878754195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 277}], {
             RGBColor[
             0.5119391923573035, 0.6143803189362278, 0.9547965836382715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 288}], {
             RGBColor[
             0.6459376056374727, 0.7223853584829198, 0.9659909719465696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 313}], {
             RGBColor[
             0.4709361194251123, 0.5788655180367319, 0.9521839040886261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 321}], {
             RGBColor[
             0.78304348190439, 0.8293416997957703, 0.9255854595882844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 373}], {
             RGBColor[
             0.7858256992864812, 0.8304922181829903, 0.8794769174192558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 386}], {
             RGBColor[
             0.4431271313499566, 0.5544881277989356, 0.9504225818042138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 414}], {
             RGBColor[
             0.5016592032391687, 0.6054763090493759, 0.9541415518219014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 498}], {
             RGBColor[
             0.6776190672953443, 0.7471351571180758, 0.9691486839645342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 145}], {
             RGBColor[
             0.20296158096381922`, 0.33065586847342227`, 0.9348697338299133]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 215}], {
             RGBColor[
             0.19092068807717077`, 0.3180001266128517, 0.9341840227929235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 246}], {
             RGBColor[
             0.21838885852257034`, 0.34687091533356196`, 0.9357482944642723]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 375}], {
             RGBColor[
             0.1998107076045579, 0.3273441007959291, 0.9346902962534028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 402}], {
             RGBColor[
             0.20750395596016302`, 0.3354301925977886, 0.9351284153661135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 417}], {
             RGBColor[
             0.19700492333763642`, 0.3243950436343972, 0.9345305109901875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 458}], {
             RGBColor[
             0.21795043797046626`, 0.346410107535832, 0.935723327062415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 367}], {
             RGBColor[
             0.2030970423728074, 0.33079824700301824`, 0.9348774481567581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 375}], {
             RGBColor[
             0.20589359976284474`, 0.33373760613192704`, 0.9350367079629848]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 402}], {
             RGBColor[
             0.21358684811844986`, 0.34182369793378664`, 0.9354748270756954]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 417}], {
             RGBColor[
             0.20308781549592325`, 0.3307885489703952, 0.9348769226997694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 450}], {
             RGBColor[
             0.21228550631692578`, 0.340455905190549, 0.9354007175852613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 458}], {
             RGBColor[
             0.2240333301287531, 0.35280361287183004`, 0.936069738771997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 461}], {
             RGBColor[
             0.23115805437216275`, 0.3602921497852615, 0.9364754812775742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 166}], {
             RGBColor[
             0.18787743892822623`, 0.31480147880417053`, 0.9340107142559747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 239}], {
             RGBColor[
             0.18835872742063176`, 0.3153073435251416, 0.9340381229236147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 248}], {
             RGBColor[
             0.18017302617267333`, 0.306703652510102, 0.9335719593472032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 387}], {
             RGBColor[
             0.18448194243535776`, 0.3112325967032537, 0.9338173457538927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 221}], {
             RGBColor[
             0.8906777697244648, 0.5160364512426465, 0.23692570222520362`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 234}], {
             RGBColor[
             0.872729313424225, 0.4467434253012546, 0.2127625522094079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 242}], {
             RGBColor[
             0.8960966123696098, 0.5635667746530044, 0.5481508384278233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 303}], {
             RGBColor[
             0.8299391758302155, 0.23113120162734693`, 0.17630309462746424`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 323}], {
             RGBColor[
             0.905895222039182, 0.5694593928427707, 0.46819019532102185`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 449}], {
             RGBColor[
             0.9013434874873846, 0.5520144216865974, 0.2783600016823526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 229}], {
             RGBColor[
             0.25473807623061007`, 0.385076247818226, 0.9378183286388965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 232}], {
             RGBColor[
             0.27654750718772436`, 0.40799934255194237`, 0.9390603434677424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 263}], {
             RGBColor[
             0.24948680213618696`, 0.3795568257949794, 0.9375192763477829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 267}], {
             RGBColor[
             0.25194617616278553`, 0.3821417838302541, 0.9376593340602799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 280}], {
             RGBColor[
             0.2640545871077613, 0.39486849145101877`, 0.9383488901508075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 342}], {
             RGBColor[
             0.3754741855106375, 0.4958604756469023, 0.9454338500155093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 393}], {
             RGBColor[
             0.24797563185424576`, 0.37796849001492944`, 0.9374332174358024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 480}], {
             RGBColor[
             0.25899827885189075`, 0.38955399088563913`, 0.9380609408757734]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 485}], {
             RGBColor[
             0.26499013859378384`, 0.39585181538021874`, 0.9384021684239121]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 173}], {
             RGBColor[
             0.6408634071546884, 0.7181223008643338, 0.9656896889353898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 242}], {
             RGBColor[
             0.767121254823353, 0.8170287735130601, 0.9444951769225841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 249}], {
             RGBColor[
             0.6440396780590834, 0.7206036278354, 0.9660062699352006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 269}], {
             RGBColor[
             0.5815017308774398, 0.6711283273375747, 0.9601970928471498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 282}], {
             RGBColor[
             0.6289215162862603, 0.7087932049561856, 0.9644994328569398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 310}], {
             RGBColor[
             0.6029711284333774, 0.688520564735261, 0.9619129407159268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 314}], {
             RGBColor[
             0.41196878637874557`, 0.5240737659037882, 0.9484356108143341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 323}], {
             RGBColor[
             0.7769198644929252, 0.8229213917028264, 0.8645345338157826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 406}], {
             RGBColor[
             0.48881588257467606`, 0.5948821437018659, 0.9531767259019711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 411}], {
             RGBColor[
             0.4211694508709569, 0.5337442476409241, 0.9489595750460023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 419}], {
             RGBColor[
             0.6052079656077549, 0.6902679989364768, 0.962135887741037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 220}], {
             RGBColor[
             0.21619691693173887`, 0.3445670457444743, 0.9356234666333614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 254}], {
             RGBColor[
             0.20389499448692971`, 0.33163694526804693`, 0.9349228903491928]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 325}], {
             RGBColor[
             0.2244980131258032, 0.35329202416433336`, 0.9360962017812421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 392}], {
             RGBColor[
             0.22610554162039614`, 0.3549816385353439, 0.9361877481508839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 412}], {
             RGBColor[
             0.20280807626052344`, 0.33049452529749807`, 0.9348609919641505]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 426}], {
             RGBColor[
             0.20135872025195078`, 0.3289711602380097, 0.9347784532835923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 473}], {
             RGBColor[
             0.23947719025137565`, 0.36903608905799384`, 0.9369492437588367]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 160}], {
             RGBColor[
             0.22158100780321188`, 0.3502260666214703, 0.9359300826434431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 162}], {
             RGBColor[
             0.1935196204092478, 0.32073176927569186`, 0.9343320281444594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 226}], {
             RGBColor[
             0.19534643528489967`, 0.3226518675367549, 0.9344360625490973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 235}], {
             RGBColor[
             0.21041554321705824`, 0.3384904554100799, 0.9352942259530863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 237}], {
             RGBColor[
             0.2183016735730191, 0.3467792784237385, 0.9357433294103739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 274}], {
             RGBColor[
             0.22389877891969617`, 0.3526621910200718, 0.9360620762796918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 284}], {
             RGBColor[
             0.20527167990556933`, 0.33308392892993416`, 0.9350012905471609]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 345}], {
             RGBColor[
             0.19727711657984534`, 0.32468113599000714`, 0.9345460119926574]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 389}], {
             RGBColor[
             0.1993172981785255, 0.3268254962052045, 0.9346621973165241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 456}], {
             RGBColor[
             0.19966233325078292`, 0.32718814994263423`, 0.9346818465534554]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 472}], {
             RGBColor[
             0.1934245140122105, 0.3206318064223118, 0.9343266119758453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 195}], {
             RGBColor[
             0.18616514652705513`, 0.313001750924931, 0.9339132017368377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 216}], {
             RGBColor[
             0.19207526490404528`, 0.31921366006229573`, 0.9342497742351705]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 217}], {
             RGBColor[
             0.18273892560736155`, 0.30940057550337985`, 0.9337180835241007]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 292}], {
             RGBColor[
             0.18467767702367152`, 0.3114383261658612, 0.9338284925491338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 398}], {
             RGBColor[
             0.19524728601816377`, 0.32254765537098895`, 0.934430416145035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 399}], {
             RGBColor[
             0.19605719925809356`, 0.3233989255376204, 0.9344765395058896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 464}], {
             RGBColor[
             0.19334471949680462`, 0.32054793732735576`, 0.9343220677962385]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 481}], {
             RGBColor[
             0.1947520962377352, 0.322027179514913, 0.9344022158196071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 496}], {
             RGBColor[
             0.1850253408084585, 0.31180374284682943`, 0.9338482914873549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 172}], {
             RGBColor[
             0.22556462734887084`, 0.3544131033400252, 0.9361569438833315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 197}], {
             RGBColor[
             0.22926543037868818`, 0.35830288196882765`, 0.9363676991410321]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 201}], {
             RGBColor[
             0.2425444285480653, 0.37225995098195497`, 0.9371239184422607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 223}], {
             RGBColor[
             0.21791092009915627`, 0.34636857174750746`, 0.9357210765781054]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 236}], {
             RGBColor[
             0.21799828044158207`, 0.3464603930063626, 0.9357260516203685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 289}], {
             RGBColor[
             0.21885506273912853`, 0.34736092552421916`, 0.935774844104718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 314}], {
             RGBColor[
             0.24522255976789442`, 0.3750748366973221, 0.93727643405329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 411}], {
             RGBColor[
             0.2544232242601058, 0.38474531843445803`, 0.937800398284958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 466}], {
             RGBColor[
             0.2112617016772801, 0.3393798216013181, 0.9353424134256167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 470}], {
             RGBColor[
             0.2111255154646311, 0.3392366812571194, 0.9353346578222758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 493}], {
             RGBColor[
             0.24427091854425903`, 0.3740746014337428, 0.9372222394934309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 199}], {
             RGBColor[
             0.684800695862128, 0.748031110338605, 0.9293475993147051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[
             0.9142690676811895, 0.6673158743356673, 0.5518317374650853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 219}], {
             RGBColor[
             0.8264967277029731, 0.8644743578312362, 0.9402829367923042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 244}], {
             RGBColor[
             0.7150943787471429, 0.7742699758488314, 0.9312778860004862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 295}], {
             RGBColor[
             0.9841314996436169, 0.9875855475713144, 0.9072523679449918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 341}], {
             RGBColor[
             0.9888822096717337, 0.9887006265396945, 0.7667739089616505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 374}], {
             RGBColor[
             0.9154556938707563, 0.6764368032115899, 0.5529680520443171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 376}], {
             RGBColor[
             0.6772879972861523, 0.7415239884313045, 0.9288688968046623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 397}], {
             RGBColor[
             0.9027384271430544, 0.5786863184006587, 0.5407899830637712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 455}], {
             RGBColor[
             0.7982558492888101, 0.8419633098945049, 0.937775174104184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 198}], {
             RGBColor[
             0.1881672276861966, 0.31510606516246586`, 0.934027217297037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 250}], {
             RGBColor[
             0.2067822292135854, 0.3346716120270169, 0.9350873140955949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 365}], {
             RGBColor[
             0.200483284293693, 0.3280510215400352, 0.934728598500861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 394}], {
             RGBColor[
             0.1886886358497215, 0.3156540982015175, 0.9340569107205956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 467}], {
             RGBColor[
             0.19253479608250443`, 0.31969665646681583`, 0.9342759438559683]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 479}], {
             RGBColor[
             0.18812050432693928`, 0.3150569559494543, 0.9340245564708484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 198}], {
             RGBColor[
             0.19090321227565094`, 0.31798175843742454`, 0.93418302757188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 227}], {
             RGBColor[
             0.1962768676534719, 0.3236298109489438, 0.9344890492960363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 250}], {
             RGBColor[
             0.20951821380303975`, 0.3375473053019756, 0.9352431243704379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 263}], {
             RGBColor[
             0.21186651840498638`, 0.34001552232973276`, 0.9353768568435135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 270}], {
             RGBColor[
             0.18975438070497386`, 0.3167742636165143, 0.9341176033134739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 479}], {
             RGBColor[
             0.19085648891639362`, 0.317932649224413, 0.9341803667456914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 485}], {
             RGBColor[
             0.22736985486258326`, 0.3563105119149721, 0.9362597489196426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 190}], {
             RGBColor[
             0.2578198120642154, 0.3883153475726824, 0.9379938289356007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 356}], {
             RGBColor[
             0.272205938145604, 0.40343607821729777`, 0.9388130975335695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 360}], {
             RGBColor[
             0.44762961538947754`, 0.5573651742459853, 0.9508478770838158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.2086123729274203, 0.33659520910807084`, 0.9351915380726428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 193}], {
             RGBColor[
             0.1863155768050812, 0.3131598626849669, 0.9339217685186295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 247}], {
             RGBColor[
             0.18799329436094186`, 0.3149232502096133, 0.9340173120514751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 278}], {
             RGBColor[
             0.18808568721102567`, 0.3150203609530965, 0.9340225736876044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 370}], {
             RGBColor[
             0.21023358203312498`, 0.3382992026687606, 0.9352838635328488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 401}], {
             RGBColor[
             0.1862173046895177, 0.3130565724606977, 0.9339161720670288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 410}], {
             RGBColor[
             0.18697773490946556`, 0.31385583283592355`, 0.933959477443099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 422}], {
             RGBColor[
             0.19912370802149765`, 0.3266220206758434, 0.9346511726434723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 428}], {
             RGBColor[
             0.1897406655144195, 0.31675984808164837`, 0.9341168222536617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 437}], {
             RGBColor[
             0.1868134400454955, 0.31368314851699497`, 0.9339501210936485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 451}], {
             RGBColor[
             0.19839700824460316`, 0.32585821313490027`, 0.9346097881662341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 166}], {
             RGBColor[
             0.21389899734106987`, 0.3421517865581641, 0.9354926035121403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 192}], {
             RGBColor[
             0.27255273720121065`, 0.4034082682269394, 0.9388472119027095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 239}], {
             RGBColor[
             0.2143802858334754, 0.34265765127913517`, 0.9355200121797802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 251}], {
             RGBColor[
             0.23552312226059172`, 0.3648801128972894, 0.936724065436281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 272}], {
             RGBColor[
             0.24467152920527638`, 0.37449566863865497`, 0.9372450536779255]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 344}], {
             RGBColor[
             0.2111960256367822, 0.3393107919186533, 0.9353386732722694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 435}], {
             RGBColor[
             0.23525737339525699`, 0.3646007939903714, 0.9367089314315404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 439}], {
             RGBColor[
             0.21567326392113564`, 0.34401665322881175`, 0.9355936453690827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 453}], {
             RGBColor[
             0.23602331412857852`, 0.36540584626453976`, 0.9367525506231953]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 167}], {
             RGBColor[
             0.2396559862242012, 0.36922401496175294`, 0.9369594259249842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 235}], {
             RGBColor[
             0.22828336996259535`, 0.35727067420528746`, 0.9363117722531638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 237}], {
             RGBColor[
             0.23616950031855627`, 0.3655594972189461, 0.9367608757104513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 274}], {
             RGBColor[
             0.24176660566523328`, 0.3714424098152794, 0.9370796225797693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 284}], {
             RGBColor[
             0.22313950665110643`, 0.35186414772514174`, 0.9360188368472383]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 300}], {
             RGBColor[
             0.2356560570579657, 0.36501983579788244`, 0.936731635876332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 305}], {
             RGBColor[
             0.2750017432650342, 0.40620742442870245`, 0.938978437324221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 389}], {
             RGBColor[
             0.21718512492406264`, 0.34560571500041215`, 0.9356797436166016]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 432}], {
             RGBColor[
             0.26534093705235057`, 0.3962205268020793, 0.9384221458771677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 460}], {
             RGBColor[
             0.27006121839103014`, 0.4011818417721542, 0.938690958916375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 183}], {
             RGBColor[
             0.2054076978090161, 0.33322689237048986`, 0.9350090365655417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 188}], {
             RGBColor[
             0.2189136351360459, 0.34742248882708376`, 0.9357781797160722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 202}], {
             RGBColor[
             0.2003053984953046, 0.32786405228731785`, 0.9347184681678012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 243}], {
             RGBColor[
             0.20521495427576572`, 0.33302430669639793`, 0.9349980601064616]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 273}], {
             RGBColor[
             0.20050467294518176`, 0.3280735023688687, 0.9347298165529216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 279}], {
             RGBColor[
             0.21091668232154126`, 0.339017184382946, 0.9353227650837177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 285}], {
             RGBColor[
             0.21411916928885952`, 0.34238320123499877`, 0.9355051419788516]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 287}], {
             RGBColor[
             0.25900221419710867`, 0.3895581271829785, 0.9380611649878617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 335}], {
             RGBColor[
             0.21211283365491676`, 0.3402744152746985, 0.9353908841326062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 354}], {
             RGBColor[
             0.262219161885439, 0.39276906224398844`, 0.9382506002184958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 396}], {
             RGBColor[
             0.205644516605638, 0.33347580394091847`, 0.9350225230456672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 409}], {
             RGBColor[
             0.23354210119449076`, 0.36279793415282724`, 0.9366112492172245]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 430}], {
             RGBColor[
             0.2077033952850149, 0.33563981597339154`, 0.9351397731406197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 459}], {
             RGBColor[
             0.20416528068413636`, 0.3319210331984458, 0.9349382827482713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 477}], {
             RGBColor[
             0.2058221778675803, 0.33366253719159444`, 0.9350326405917087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 226}], {
             RGBColor[
             0.18515287463647273`, 0.3119377889861841, 0.933855554350191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 284}], {
             RGBColor[
             0.19507811925714236`, 0.3223698503793633, 0.9344207823482545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 345}], {
             RGBColor[
             0.1870835559314184, 0.31396705743943626`, 0.9339655037937511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 389}], {
             RGBColor[
             0.18912373753009853`, 0.3161114176546337, 0.9340816891176178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 456}], {
             RGBColor[
             0.18946877260235598`, 0.3164740713920633, 0.9341013383545491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 472}], {
             RGBColor[
             0.18323095336378353`, 0.30991772787174093`, 0.933746103776939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 207}], {
             RGBColor[
             0.8871477729139166, 0.5804462187569267, 0.227545674269207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 209}], {
             RGBColor[
             0.9468923206889115, 0.8138245711399055, 0.48945082932663964`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 231}], {
             RGBColor[
             0.8314832405552138, 0.7254800292683178, 0.607385428867296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 233}], {
             RGBColor[
             0.9309329686428551, 0.8036306761921264, 0.5929788217369941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 266}], {
             RGBColor[
             0.9464459539298948, 0.8121746039800857, 0.3903304044915068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 317}], {
             RGBColor[
             0.8583137676007231, 0.3848962000432028, 0.20095545620474106`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 326}], {
             RGBColor[
             0.8123452824001817, 0.7105293109037376, 0.6054779360527895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 343}], {
             RGBColor[
             0.8727695735845509, 0.4960098594094768, 0.21479835234035222`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 355}], {
             RGBColor[
             0.7295091887885554, 0.6445510453124249, 0.5980872339837272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 379}], {
             RGBColor[
             0.8633665292005046, 0.42373393983337493`, 0.2057939864189699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 440}], {
             RGBColor[
             0.8954705204165625, 0.6182378713393768, 0.2344903787946242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 180}], {
             RGBColor[
             0.28958519225458484`, 0.42102975172188783`, 0.9398274630675963]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 205}], {
             RGBColor[
             0.2767533263359414, 0.40754264705410376`, 0.9390967072865741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 259}], {
             RGBColor[
             0.4996492818256195, 0.6003222503432779, 0.9552118903262334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 316}], {
             RGBColor[
             0.37736919780669476`, 0.5012799648379501, 0.9452666094831315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 331}], {
             RGBColor[
             0.3087300351184425, 0.44115219542494855`, 0.940917733546436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 348}], {
             RGBColor[
             0.38905288991990644`, 0.5111618708489473, 0.9460768222550604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 372}], {
             RGBColor[
             0.4651482668210734, 0.5729395258749782, 0.9520673290712703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 404}], {
             RGBColor[
             0.5764261418930885, 0.6604370522196931, 0.9628281641033989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 418}], {
             RGBColor[
             0.3962653140595378, 0.5170172416815048, 0.9466446107033122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 431}], {
             RGBColor[
             0.36863866395623385`, 0.49371801522607117`, 0.9447103075862879]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 444}], {
             RGBColor[
             0.4409447203988165, 0.5532899965320492, 0.9501619372363984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 486}], {
             RGBColor[
             0.3646799679598963, 0.49028919172388963`, 0.9444580629779388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 178}], {
             RGBColor[
             0.3876179844694684, 0.5094620707746275, 0.9460491694230218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 185}], {
             RGBColor[
             0.2587337613234965, 0.38927596619191684`, 0.93804587699385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 277}], {
             RGBColor[
             0.37457657867037175`, 0.49860046416423287`, 0.9450982108256749]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 288}], {
             RGBColor[
             0.508574991950541, 0.6066055037109249, 0.956292599133973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 313}], {
             RGBColor[
             0.3335735057381806, 0.4630856632647371, 0.9424855312760294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 333}], {
             RGBColor[
             0.26885740704369754`, 0.3999165597200598, 0.9386224036410238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 358}], {
             RGBColor[
             0.26540482039910535`, 0.39628767224995665`, 0.9384257839392585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 361}], {
             RGBColor[
             0.26801366747199473`, 0.39902973593402147`, 0.9385743539206161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 386}], {
             RGBColor[
             0.3057645176630249, 0.43870827302694076`, 0.9407242089916171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 498}], {
             RGBColor[
             0.5402564536084126, 0.6313553023460808, 0.9594503111519376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.19616306235610437`, 0.3235101943657379, 0.9344825682527109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 344}], {
             RGBColor[
             0.19297880215941118`, 0.32016333500525607`, 0.9343012293452001]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 387}], {
             RGBColor[
             0.19228627737083037`, 0.31943544754385, 0.934261791082989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 435}], {
             RGBColor[
             0.21704014991788595`, 0.3454533370769741, 0.9356714875044712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 439}], {
             RGBColor[
             0.19745604044376464`, 0.3248691963154145, 0.9345562014420135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 453}], {
             RGBColor[
             0.2178060906512075, 0.3462583893511425, 0.935715106696126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 172}], {
             RGBColor[
             0.23167761735264775`, 0.36083824341994686`, 0.9365050696206882]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[
             0.2486574185518422, 0.37868509106187664`, 0.9374720441796176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 218}], {
             RGBColor[
             0.26286988224919927`, 0.3936232915300437, 0.9382814229617262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 235}], {
             RGBColor[
             0.22849052163804753`, 0.3574884037503625, 0.9363235692346273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 236}], {
             RGBColor[
             0.22411127044535895`, 0.3528855330862843, 0.9360741773577252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 274}], {
             RGBColor[
             0.24197375734068546`, 0.3716601393603544, 0.9370914195612329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 284}], {
             RGBColor[
             0.22334665832655862`, 0.3520818772702168, 0.9360306338287019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 289}], {
             RGBColor[
             0.2249680527429054, 0.35378606560414083`, 0.9361229698420748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 300}], {
             RGBColor[
             0.23586320873341787`, 0.3652375653429575, 0.9367434328577955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 305}], {
             RGBColor[
             0.27520889494048634`, 0.4064251539737775, 0.9389902343056846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 432}], {
             RGBColor[
             0.2655480887278028, 0.39643825634715435`, 0.9384339428586312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 456}], {
             RGBColor[
             0.21773731167177224`, 0.3461860982829168, 0.9357111898349966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 493}], {
             RGBColor[
             0.25038390854803594`, 0.3804997415136645, 0.9375703652307877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 181}], {
             RGBColor[
             0.25911497354415575`, 0.3896766444060805, 0.9380675864658636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 189}], {
             RGBColor[
             0.272342262398906, 0.403579363650975, 0.9388208609981212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 232}], {
             RGBColor[
             0.28558604817661837`, 0.417499422207868, 0.9395750750057368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 280}], {
             RGBColor[
             0.2730931280966553, 0.40436857110694446`, 0.9388636216888019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 302}], {
             RGBColor[
             0.268736668858344, 0.3997896562320101, 0.9386155277799839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 326}], {
             RGBColor[
             0.509047258388588, 0.6051914915809957, 0.9566219374301776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 338}], {
             RGBColor[
             0.35852241644491945`, 0.4834734222788186, 0.944119987452004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 346}], {
             RGBColor[
             0.3670639021674008, 0.4908716279040769, 0.9446642433693013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 370}], {
             RGBColor[
             0.2607361826498604, 0.3913806379667703, 0.9381599119260695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 383}], {
             RGBColor[
             0.2802434761765292, 0.4118840402971449, 0.9392708234339586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 390}], {
             RGBColor[
             0.27431313717116323`, 0.40565087799729527`, 0.9389330994007534]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 395}], {
             RGBColor[
             0.3984267572015211, 0.5166565922466431, 0.9470439450191381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 443}], {
             RGBColor[
             0.29027458230294984`, 0.42242736884487553`, 0.9398420800881666]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 480}], {
             RGBColor[
             0.26803681984078476`, 0.3990540705415648, 0.9385756724137677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 211}], {
             RGBColor[
             0.1856477523702797, 0.3124579368614757, 0.9338837369050252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 236}], {
             RGBColor[
             0.19608590653883476`, 0.32342909870982617`, 0.9344781743430592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 289}], {
             RGBColor[
             0.19694268883638122`, 0.3243296312276827, 0.9345269668274088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 308}], {
             RGBColor[
             0.18735840295715342`, 0.31425593908979166`, 0.9339811559252671]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 362}], {
             RGBColor[
             0.18152465259386255`, 0.3081242975768366, 0.9336489324723378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 369}], {
             RGBColor[
             0.1829196441464267, 0.30959052214615446`, 0.9337283751775514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 456}], {
             RGBColor[
             0.18971194776524802`, 0.31672966390645874`, 0.9341151868203305]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 470}], {
             RGBColor[
             0.1892131415618838, 0.316205386960583, 0.9340867805449665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 214}], {
             RGBColor[
             0.18764009951956995`, 0.31455202003748506`, 0.9339971981277639]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 223}], {
             RGBColor[
             0.19795986022643686`, 0.3253987428510222, 0.9345848932333021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 268}], {
             RGBColor[
             0.18701827847814975`, 0.31389844669722133`, 0.9339617863393568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 466}], {
             RGBColor[
             0.19131064180456064`, 0.3184099927048328, 0.9342062300808134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 491}], {
             RGBColor[
             0.18468093358720655`, 0.3114417490206145, 0.9338286780056095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 192}], {
             RGBColor[
             0.3918420426717766, 0.5133437939110442, 0.9463191721078775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 208}], {
             RGBColor[
             0.44865476640412644`, 0.5625521197174839, 0.9499392286265838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 219}], {
             RGBColor[
             0.5701105988481052, 0.6614643237945504, 0.9595848784963202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 238}], {
             RGBColor[
             0.47869194757503297`, 0.5876627137247235, 0.9521035301009391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 258}], {
             RGBColor[
             0.44293779831735625`, 0.5576003693038944, 0.9495749484754112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 272}], {
             RGBColor[
             0.36396083467584234`, 0.48443119432275983`, 0.9447170138830936]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 293}], {
             RGBColor[
             0.6402218599260903, 0.7162357738139922, 0.9665729137735878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 403}], {
             RGBColor[
             0.6070518602239434, 0.6903231179453404, 0.9632668381945488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 471}], {
             RGBColor[
             0.7137657491152036, 0.7742498659419835, 0.9547112060503897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 497}], {
             RGBColor[
             0.47443851953832683`, 0.5842095892297761, 0.9517686846650694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 197}], {
             RGBColor[
             0.22719289983545946`, 0.3561245209618682, 0.9362496715926294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 201}], {
             RGBColor[
             0.2404718980048366, 0.3700815899749955, 0.9370058908938581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 211}], {
             RGBColor[
             0.20548759572979827`, 0.33331087015105276`, 0.9350135866339319]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 218}], {
             RGBColor[
             0.25468436170219366`, 0.3850197904431626, 0.9378152696759667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 235}], {
             RGBColor[
             0.22030500109104192`, 0.3488849026634814, 0.9358574159488678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 236}], {
             RGBColor[
             0.21592574989835334`, 0.34428203199940316`, 0.9356080240719657]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 289}], {
             RGBColor[
             0.2167825321958998, 0.3451825645172597, 0.9356568165563153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 300}], {
             RGBColor[
             0.22767768818641226`, 0.35663406425607636`, 0.936277279572036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 308}], {
             RGBColor[
             0.207198246316672, 0.3351088723793687, 0.9351110056541736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 314}], {
             RGBColor[
             0.24315002922466572`, 0.37289647569036266`, 0.9371584065048872]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 466}], {
             RGBColor[
             0.20918917113405136`, 0.3372014605943586, 0.935224385877214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 470}], {
             RGBColor[
             0.2090529849214024, 0.33705832025015997`, 0.9352166302738731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 493}], {
             RGBColor[
             0.24219838800103033`, 0.3718962404267834, 0.9371042119450282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 242}], {
             RGBColor[
             0.8468550508642396, 0.8805617516174773, 0.9515915409041512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 249}], {
             RGBColor[
             0.72377347409997, 0.7841366059398172, 0.9731026339167677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 269}], {
             RGBColor[
             0.6612355269183264, 0.7346613054419917, 0.9672934568287169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 282}], {
             RGBColor[
             0.7086553123271468, 0.7723261830606026, 0.9715957968385069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 310}], {
             RGBColor[
             0.682704924474264, 0.7520535428396782, 0.9690093046974939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 323}], {
             RGBColor[
             0.8566536605338118, 0.8864543698072436, 0.8716308977973497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 406}], {
             RGBColor[
             0.5685496786155626, 0.658415121806283, 0.9602730898835382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 419}], {
             RGBColor[
             0.6849417616486415, 0.753800977040894, 0.9692322517226041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 499}], {
             RGBColor[
             0.6745850298425644, 0.7454990333041416, 0.9683443785997534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 210}], {
             RGBColor[
             0.19150041146467078`, 0.3186094526497, 0.9342170371822176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 225}], {
             RGBColor[
             0.18572114805288265`, 0.3125350803774465, 0.9338879166805704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 252}], {
             RGBColor[
             0.18489202158224743`, 0.3116636158871544, 0.9338406991546504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 309}], {
             RGBColor[
             0.18783655214367595`, 0.3147585042012363, 0.9340083858140811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 320}], {
             RGBColor[
             0.1843078028000945, 0.31104956490550145`, 0.933807428759281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 393}], {
             RGBColor[
             0.20439651484045512`, 0.33216407495782907`, 0.9349514511913933]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 424}], {
             RGBColor[
             0.19047450678086728`, 0.3175311617809086, 0.934158613428165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 182}], {
             RGBColor[
             0.3713372775098073, 0.4960554186499155, 0.9448822608556314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 208}], {
             RGBColor[
             0.41214605726916764`, 0.531401932568564, 0.9474825602161108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 351}], {
             RGBColor[
             0.3189338999580072, 0.4443278119995411, 0.9417752451272612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 359}], {
             RGBColor[
             0.653601757432396, 0.7247826808114364, 0.9688966182964689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 371}], {
             RGBColor[
             0.32587980547058965`, 0.4516283990891108, 0.9421708041706565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 463}], {
             RGBColor[
             0.476418269168048, 0.5843060667913316, 0.9523419687164218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 483}], {
             RGBColor[
             0.4248591023079348, 0.5424133332049215, 0.9482926242042767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 178}], {
             RGBColor[
             0.3931214338805177, 0.5144895563820213, 0.9463902997884908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 244}], {
             RGBColor[
             0.38182757506705056`, 0.5051415871363136, 0.945550693339773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 261}], {
             RGBColor[
             0.32311312036066653`, 0.4542860775439437, 0.941809460205036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 262}], {
             RGBColor[
             0.33005042418212294`, 0.46029482143506084`, 0.9422514990701223]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 299}], {
             RGBColor[
             0.2785034431297019, 0.4092981665779968, 0.9391994481892236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 313}], {
             RGBColor[
             0.3390769551492299, 0.46811314887213096`, 0.9428266616414984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 328}], {
             RGBColor[
             0.27995998628272956`, 0.4108290857819987, 0.939282396167026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 376}], {
             RGBColor[
             0.34402119360606, 0.47239559971878675`, 0.9431417041439492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 391}], {
             RGBColor[
             0.3950241069319744, 0.5160342320796381, 0.9465400851808224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 407}], {
             RGBColor[
             0.2970315342752855, 0.4287723651208341, 0.94025459557011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 448}], {
             RGBColor[
             0.3087587670403855, 0.44109843030645696`, 0.9409224441271964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 455}], {
             RGBColor[
             0.46498904560871784`, 0.5728349211819872, 0.9520479814434708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 475}], {
             RGBColor[
             0.3267310397254062, 0.4574197374557666, 0.9420399908277568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 478}], {
             RGBColor[
             0.2831235992471345, 0.4141542435922354, 0.9394625592452028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 482}], {
             RGBColor[
             0.3246527382525704, 0.45561961717846555`, 0.9419075632956775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 194}], {
             RGBColor[
             0.1852447118397448, 0.312034315709638, 0.9338607843430564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 290}], {
             RGBColor[
             0.1829544926129004, 0.3096271500939387, 0.9337303597461633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 297}], {
             RGBColor[
             0.18982245259063335`, 0.3168458114843493, 0.9341214799066588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 412}], {
             RGBColor[
             0.1873190234343715, 0.314214548714542, 0.9339789133197014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 484}], {
             RGBColor[
             0.18459712642978363`, 0.31135366238448237`, 0.9338239053119759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 186}], {
             RGBColor[
             0.7313163060716499, 0.7840864544016981, 0.7330087460966953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 244}], {
             RGBColor[
             0.45801552683844415`, 0.5706975580302278, 0.9505252940081765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 261}], {
             RGBColor[
             0.3993010721320601, 0.5198420484378579, 0.9467840608734395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 288}], {
             RGBColor[
             0.5902663931329839, 0.677188960212233, 0.9616083301678455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 313}], {
             RGBColor[
             0.4152649069206235, 0.5336691197660451, 0.9478012623099019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 321}], {
             RGBColor[
             0.7273722693999012, 0.7841453015250835, 0.9212028178095601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 391}], {
             RGBColor[
             0.47121205870336796`, 0.5815902029735522, 0.9515146858492259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 407}], {
             RGBColor[
             0.3732194860466791, 0.4943283360147483, 0.9452291962385135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 455}], {
             RGBColor[
             0.5411769973801115, 0.6383908920759014, 0.9570225821118743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 475}], {
             RGBColor[
             0.40291899149679977`, 0.5229757083496808, 0.9470145914961603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 498}], {
             RGBColor[
             0.6219478547908555, 0.7019387588473889, 0.96476604218581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 222}], {
             RGBColor[
             0.19860716321184355`, 0.3260790993300644, 0.9346217561807222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 245}], {
             RGBColor[
             0.22201863728698465`, 0.35068604295622735`, 0.9359550049951293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 255}], {
             RGBColor[
             0.19864123735537692`, 0.32611491341534343`, 0.9346236966527881]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 294}], {
             RGBColor[
             0.19380204212800067`, 0.3210286124086723, 0.9343481116435368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 296}], {
             RGBColor[
             0.19117065430032437`, 0.31826285696216006`, 0.9341982579995401]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 312}], {
             RGBColor[
             0.19754047021008475`, 0.3249579373529733, 0.9345610095923028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 327}], {
             RGBColor[
             0.1919456153481889, 0.3190773901588341, 0.9342423908847639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 334}], {
             RGBColor[
             0.1934836161981846, 0.32069392656706563`, 0.9343299777579028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 385}], {
             RGBColor[
             0.19083377116116018`, 0.3179087714232738, 0.9341790730031387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 415}], {
             RGBColor[
             0.19025558687597238`, 0.31730106308054046`, 0.9341461462634442]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 438}], {
             RGBColor[
             0.20137694299580192`, 0.3289903134971859, 0.9347794910418965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 205}], {
             RGBColor[
             0.2503131812646099, 0.38042540265441493`, 0.9375663374166283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 230}], {
             RGBColor[
             0.2345216927400936, 0.3638275469769471, 0.9366670355065708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 331}], {
             RGBColor[
             0.2822898900471109, 0.4140349510252597, 0.9393873636764902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 382}], {
             RGBColor[
             0.23760741054514092`, 0.36707083203586066`, 0.9368427625706579]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 413}], {
             RGBColor[
             0.24672751485063993`, 0.37665663990895104`, 0.9373621390188708]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 418}], {
             RGBColor[
             0.3698251689882062, 0.48989999728181594`, 0.9451142408333664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 474}], {
             RGBColor[
             0.24632928568632426`, 0.37623807580806795`, 0.9373394604570903]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 490}], {
             RGBColor[
             0.23955648296360244`, 0.3691194307259925, 0.9369537593614949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 189}], {
             RGBColor[
             0.238744748764803, 0.3682662466161335, 0.9369075322997265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 302}], {
             RGBColor[
             0.235139155224241, 0.3644765391971686, 0.9367021990815891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 370}], {
             RGBColor[
             0.2271386690157574, 0.35606752093192884`, 0.9362465832276747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 390}], {
             RGBColor[
             0.24071562353706022`, 0.37033776096245374`, 0.9370197707023586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 422}], {
             RGBColor[
             0.2160287950041301, 0.3443903389390116, 0.9356138923382982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 443}], {
             RGBColor[
             0.2566770686688468, 0.387114251810034, 0.9379287513897718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 451}], {
             RGBColor[
             0.21530209522723562`, 0.3436265313980684, 0.93557250786106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 237}], {
             RGBColor[
             0.2889436538091614, 0.4176768128895569, 0.9398890065800227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 351}], {
             RGBColor[
             0.2925937639781592, 0.42151331010752513`, 0.9400968749542931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 359}], {
             RGBColor[
             0.6272616214525479, 0.7019681789194203, 0.9672182481235007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 371}], {
             RGBColor[
             0.29953966949074173`, 0.42881389719709484`, 0.9404924339976882]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 460}], {
             RGBColor[
             0.32283537188163536`, 0.453299157442765, 0.9418190897859463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 463}], {
             RGBColor[
             0.4500781331882001, 0.5614915648993155, 0.9506635985434537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 483}], {
             RGBColor[
             0.3985189663280868, 0.5195988313129054, 0.9466142540313085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 202}], {
             RGBColor[
             0.19186250689715728`, 0.31899003790741964`, 0.9342376579814256]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 206}], {
             RGBColor[
             0.1886895173788014, 0.31565502474447266`, 0.9340569609223726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 243}], {
             RGBColor[
             0.19677206267761843`, 0.3241502923164997, 0.9345172499200859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 273}], {
             RGBColor[
             0.19206178134703447`, 0.31919948798897047`, 0.934249006366546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 279}], {
             RGBColor[
             0.202473790723394, 0.3301431700030478, 0.9348419548973421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 283}], {
             RGBColor[
             0.18964111329673894`, 0.31665521238889094`, 0.9341111529021391]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 285}], {
             RGBColor[
             0.20567627769071223`, 0.33350918685510056`, 0.935024331792476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 396}], {
             RGBColor[
             0.19720162500749072`, 0.32460178956102026`, 0.9345417128592917]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 430}], {
             RGBColor[
             0.19926050368686765`, 0.32676580159349333`, 0.9346589629542441]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 477}], {
             RGBColor[
             0.19737928626943302`, 0.32478852281169623`, 0.934551830405333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 221}], {
             RGBColor[
             0.7515553610831588, 0.7612606169042988, 0.6324712276878893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 253}], {
             RGBColor[
             0.4591640004744537, 0.5697502062280924, 0.9511350822856912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 287}], {
             RGBColor[
             0.42249467395537876`, 0.5375645019893394, 0.9488140910567393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 301}], {
             RGBColor[
             0.5986418341837841, 0.6848276074011173, 0.9616939873161781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 316}], {
             RGBColor[
             0.4897742836055883, 0.5962632949587165, 0.9530855424591965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 336}], {
             RGBColor[
             0.5830930532515349, 0.672420234529121, 0.9603223675736445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 354}], {
             RGBColor[
             0.425711621643709, 0.5407754370503493, 0.9490035262873733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 388}], {
             RGBColor[
             0.43476172806913593`, 0.5486141843644792, 0.9495801910661066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 436}], {
             RGBColor[
             0.4481781977283561, 0.5602348560519236, 0.9504350766490738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 473}], {
             RGBColor[
             0.4022146970771591, 0.5162489604655307, 0.9476591763750619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 187}], {
             RGBColor[
             0.21639359634399347`, 0.34477376827694883`, 0.9356346672349283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 216}], {
             RGBColor[
             0.20572802131241785`, 0.3335635726822483, 0.9350272785151843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 224}], {
             RGBColor[
             0.2087376164930067, 0.33672684803640285`, 0.9351986705084218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 286}], {
             RGBColor[
             0.1994684028845588, 0.32698431683183726`, 0.9346708025059933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 330}], {
             RGBColor[
             0.20056082053324595`, 0.3281325170438868, 0.934733014074999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 333}], {
             RGBColor[
             0.22166458508016862`, 0.3503139116386572, 0.9359348422457243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 357}], {
             RGBColor[
             0.20004263933508956`, 0.3275878757500389, 0.9347035044223444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 358}], {
             RGBColor[
             0.21821199843557637`, 0.3466850241685541, 0.935738222543959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 361}], {
             RGBColor[
             0.22082084550846576`, 0.3494270878526189, 0.9358867925253167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 386}], {
             RGBColor[
             0.25857169569949595`, 0.38910562494553824`, 0.9380366475963178]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 398}], {
             RGBColor[
             0.20890004242653637`, 0.3368975679909415, 0.9352079204250486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 441}], {
             RGBColor[
             0.21650425944697038`, 0.34489008221462353`, 0.9356409693349313]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 464}], {
             RGBColor[
             0.2069974759051772, 0.3348978499473083, 0.9350995720762522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 481}], {
             RGBColor[
             0.2084048526461078, 0.33637709213486555`, 0.9351797200996208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 288}], {
             RGBColor[
             0.8522733135527225, 0.8812298873379956, 0.7432521758076465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 295}], {
             RGBColor[
             0.9890595681546568, 0.9880540568784736, 0.7081436215924831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 321}], {
             RGBColor[
             0.9893791898196398, 0.9881862286508462, 0.7028466634493613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 341}], {
             RGBColor[
             0.9938102781827736, 0.9891691358468536, 0.5676651626091419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 373}], {
             RGBColor[
             0.9921614072017308, 0.9893367470380662, 0.6567381212803327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 397}], {
             RGBColor[
             0.9076664956540943, 0.5791548277078178, 0.3416812367112626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 455}], {
             RGBColor[
             0.8031839177998501, 0.842431819201664, 0.7386664277516752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 495}], {
             RGBColor[
             0.9397076490875935, 0.7818899537818541, 0.3706586815108439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 498}], {
             RGBColor[
             0.8839547752105941, 0.9059796859731515, 0.7464098878256111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 216}], {
             RGBColor[
             0.21058067829644372`, 0.3386640228486828, 0.9353036301515618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 224}], {
             RGBColor[
             0.2135902734770326, 0.34182729820283736`, 0.9354750221447994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 260}], {
             RGBColor[
             0.21549852964428565`, 0.3438329964250494, 0.9355836945105124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 328}], {
             RGBColor[
             0.2321163718921772, 0.36129940225963686`, 0.9365300560426353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 398}], {
             RGBColor[
             0.21375269941056224`, 0.341998018157376, 0.9354842720614263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 399}], {
             RGBColor[
             0.214562612650492, 0.3428492883240075, 0.9355303954222809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 407}], {
             RGBColor[
             0.24918791988473313`, 0.3792426815984722, 0.9375022554457193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 464}], {
             RGBColor[
             0.21185013288920307`, 0.3399983001137429, 0.9353759237126298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 478}], {
             RGBColor[
             0.2352799848565821, 0.36462456006987354`, 0.9367102191208121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 481}], {
             RGBColor[
             0.21325750963013368`, 0.3414775423013001, 0.9354560717359984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 200}], {
             RGBColor[
             0.24347605986022197`, 0.37323915455986845`, 0.937176973467263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 228}], {
             RGBColor[
             0.24109668028529843`, 0.37073827576524543`, 0.9370414713204478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 256}], {
             RGBColor[
             0.26776710539076976`, 0.3985106384029728, 0.9385698304401877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 279}], {
             RGBColor[
             0.21597972805042376`, 0.3443387664596417, 0.9356110980478727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 298}], {
             RGBColor[
             0.24983259130122784`, 0.37992027213173674`, 0.9375389685291828]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 318}], {
             RGBColor[
             0.21097876418895464`, 0.3390824363618151, 0.935326300554225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 335}], {
             RGBColor[
             0.21717587938379926`, 0.3455959973513941, 0.9356792170967612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 409}], {
             RGBColor[
             0.23860514692337326`, 0.3681195162295229, 0.9368995821813795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 430}], {
             RGBColor[
             0.2127664410138974, 0.34096139805008724`, 0.9354281061047747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 459}], {
             RGBColor[
             0.20922832641301886`, 0.3372426152751415, 0.9352266157124262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 302}], {
             RGBColor[
             0.24836644407899122`, 0.3783792584420631, 0.9374554736138468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 346}], {
             RGBColor[
             0.346693677388048, 0.46946123011413, 0.9435041892031641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 370}], {
             RGBColor[
             0.24036595787050763`, 0.36997024017682334`, 0.9369998577599323]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 383}], {
             RGBColor[
             0.25987325139717643`, 0.39047364250719796`, 0.9381107692678216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 390}], {
             RGBColor[
             0.25394291239181044`, 0.3842404802073483, 0.9377730452346162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 422}], {
             RGBColor[
             0.22925608385888036`, 0.3582930581839061, 0.936367166870556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 443}], {
             RGBColor[
             0.2699043575235971, 0.40101697105492856`, 0.9386820259220295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 451}], {
             RGBColor[
             0.22852938408198586`, 0.3575292506429629, 0.9363257823933178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 349}], {
             RGBColor[
             0.20086956962021285`, 0.3284570319101118, 0.9347505968787484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 378}], {
             RGBColor[
             0.21175405970731373`, 0.3398973211081856, 0.9353704524870488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 467}], {
             RGBColor[
             0.20384534758574807`, 0.33158476322710967`, 0.9349200630316166]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 487}], {
             RGBColor[
             0.2046420322637051, 0.3324221293363686, 0.9349654330454369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 226}], {
             RGBColor[
             0.18878815245387853`, 0.31575869646220367`, 0.9340625780439806]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 237}], {
             RGBColor[
             0.21174339074199797`, 0.3398861073491872, 0.9353698449052572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 271}], {
             RGBColor[
             0.19934619168565726`, 0.3268558651131542, 0.9346638427590112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 311}], {
             RGBColor[
             0.19029060642002155`, 0.31733787084170345`, 0.934148140574671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 366}], {
             RGBColor[
             0.18657672320149288`, 0.31343434410523346`, 0.9339366404195737]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 405}], {
             RGBColor[
             0.18612791917026347`, 0.3129626226125922, 0.9339110816939413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 423}], {
             RGBColor[
             0.1848982635137219, 0.3116701765528954, 0.9338410546234137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 429}], {
             RGBColor[
             0.1912728666243942, 0.31837028859539307`, 0.9342040788401863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 488}], {
             RGBColor[
             0.18656266374586195`, 0.3134195667259444, 0.9339358397543747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 219}], {
             RGBColor[
             0.49125780976030897`, 0.5936378228658237, 0.9544300827546521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 251}], {
             RGBColor[
             0.2759596386433615, 0.40698913765266753`, 0.9390412298997809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 258}], {
             RGBColor[
             0.36408500922956, 0.4897738683751677, 0.944420152733743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 272}], {
             RGBColor[
             0.28510804558804614`, 0.41660469339403305`, 0.9395622181414255]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 435}], {
             RGBColor[
             0.2756938897780267, 0.40670981874574946`, 0.9390260958950403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 453}], {
             RGBColor[
             0.27645983051134826`, 0.4075148710199178, 0.9390697150866952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 497}], {
             RGBColor[
             0.3955857304505306, 0.5163830883010493, 0.9466138889234013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 410}], {
             RGBColor[
             0.1815860257697589, 0.30818880467598786`, 0.9336524275839118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 428}], {
             RGBColor[
             0.18434895637471288`, 0.31109281992171267`, 0.9338097723944743]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 437}], {
             RGBColor[
             0.18142173090578886`, 0.3080161203570593, 0.933643071234461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 220}], {
             RGBColor[
             0.20157018632549908`, 0.32919342448903244`, 0.9347904959636448]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 254}], {
             RGBColor[
             0.18926826388068996`, 0.3162633240126051, 0.9340899196794763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 290}], {
             RGBColor[
             0.18381681483281254`, 0.31053350542145297`, 0.9337794677208959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 297}], {
             RGBColor[
             0.1906847748105455, 0.3177521668118635, 0.9341705878813915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 350}], {
             RGBColor[
             0.18381567245253283`, 0.31053230470734794`, 0.9337794026640289]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 377}], {
             RGBColor[
             0.1834493331063201, 0.31014725882722227`, 0.9337585401802126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 412}], {
             RGBColor[
             0.18818134565428368`, 0.3151209040420562, 0.934028021294434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 426}], {
             RGBColor[
             0.18673198964571103`, 0.31359753898256787`, 0.9339454826138758]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 476}], {
             RGBColor[
             0.18476853282621936`, 0.3115338213749295, 0.9338336666526799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.19263264106654965`, 0.3197994977487777, 0.9342815159830611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 260}], {
             RGBColor[
             0.1989228362357199, 0.32641089169298415`, 0.9346397332924354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 292}], {
             RGBColor[
             0.18660739700750423`, 0.31346658422018303`, 0.9339383872474483]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 399}], {
             RGBColor[
             0.19798691924192627`, 0.3254271835919423, 0.9345864342042041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 446}], {
             RGBColor[
             0.1857509853248722, 0.31256644124209987`, 0.9338896158690699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 496}], {
             RGBColor[
             0.18695506079229124`, 0.31383200090115126`, 0.9339581861856694]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 213}], {
             RGBColor[
             0.19710682911621347`, 0.3245021530688812, 0.9345363143735214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 332}], {
             RGBColor[
             0.18931192738265673`, 0.3163092171215981, 0.934092406251319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 337}], {
             RGBColor[
             0.19054105270955757`, 0.3176011057712177, 0.934162403120358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 420}], {
             RGBColor[
             0.19002037884251344`, 0.3170538445243244, 0.9341327515138979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 427}], {
             RGBColor[
             0.18925515066577042`, 0.3162495411922988, 0.9340891729012859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 447}], {
             RGBColor[
             0.2128628663159131, 0.341062747156223, 0.9354335973830761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 454}], {
             RGBColor[
             0.20169424196759916`, 0.3293238148344616, 0.9347975607489386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 489}], {
             RGBColor[
             0.19180860925659354`, 0.31893338806987936`, 0.9342345885905299]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 500}], {
             RGBColor[
             0.1964924261713618, 0.32385637661844546`, 0.9345013250347398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 201}], {
             RGBColor[
             0.2441727010346539, 0.373971368603798, 0.9372166461515588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 236}], {
             RGBColor[
             0.21962655292817068`, 0.3481718106282057, 0.9358187793296664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 289}], {
             RGBColor[
             0.22048333522571711`, 0.34907234314606217`, 0.9358675718140159]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 314}], {
             RGBColor[
             0.24685083225448304`, 0.3767862543191651, 0.9373691617625879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 411}], {
             RGBColor[
             0.25605149674669436`, 0.3864567360563011, 0.937893125994256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 466}], {
             RGBColor[
             0.21288997416386868`, 0.3410912392231611, 0.9354351411349147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 470}], {
             RGBColor[
             0.2127537879512197, 0.3409480988789625, 0.9354273855315738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 493}], {
             RGBColor[
             0.24589919103084765`, 0.37578601905558584`, 0.9373149672027289]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 270}], {
             RGBColor[
             0.1812627552425552, 0.3078490268553615, 0.9336340178056233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 479}], {
             RGBColor[
             0.18236486345397498`, 0.30900741246326024`, 0.9336967812378407]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 244}], {
             RGBColor[
             0.4164279851399622, 0.5351107232742938, 0.9477554008736777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 245}], {
             RGBColor[
             0.31502975887018714`, 0.4412915516820689, 0.9415138332017744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 262}], {
             RGBColor[
             0.36465083425503464`, 0.49026395757304103`, 0.944456206604027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 376}], {
             RGBColor[
             0.3786216036789717, 0.5023647358567669, 0.9453464116778538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 448}], {
             RGBColor[
             0.3433591771132972, 0.47106756644443715`, 0.943127151661101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 455}], {
             RGBColor[
             0.4995894556816295, 0.6028040573199673, 0.9542526889773754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 475}], {
             RGBColor[
             0.3613314497983178, 0.4873888735937467, 0.9442446983616614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 482}], {
             RGBColor[
             0.35925314832548205`, 0.4855887533164457, 0.9441122708295822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 228}], {
             RGBColor[
             0.26059605928059204`, 0.3912333594213344, 0.9381519321074836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 256}], {
             RGBColor[
             0.28726648438606334`, 0.4190057220590618, 0.9396802912272235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 298}], {
             RGBColor[
             0.26933197029652145`, 0.4004153557878257, 0.9386494293162186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 452}], {
             RGBColor[
             0.24489188267224044`, 0.3747272741036509, 0.9372576024818854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 468}], {
             RGBColor[
             0.2422384711696754, 0.37193837037844896`, 0.9371064946221849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 218}], {
             RGBColor[
             0.27166416290138806`, 0.4028666380850924, 0.938782244234896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 235}], {
             RGBColor[
             0.23728480229023638`, 0.36673175030541116`, 0.9368243905077971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 236}], {
             RGBColor[
             0.2329055510975478, 0.36212887964133295`, 0.9365749986308951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 289}], {
             RGBColor[
             0.23376233339509425`, 0.3630294121591895, 0.9366237911152446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 300}], {
             RGBColor[
             0.24465748938560672`, 0.37448091189800614`, 0.9372442541309653]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 305}], {
             RGBColor[
             0.2840031755926752, 0.41566850052882615`, 0.9394910555788545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 314}], {
             RGBColor[
             0.2601298304238602, 0.39074332333229245`, 0.9381253810638166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 406}], {
             RGBColor[
             0.33697692661979073`, 0.46155170113037025`, 0.9428664961514535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 493}], {
             RGBColor[
             0.2591781892002248, 0.38974308806871316`, 0.9380711865039575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 243}], {
             RGBColor[
             0.1916697633639069, 0.3187874522333277, 0.9342266815223454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 273}], {
             RGBColor[
             0.18695948203332297`, 0.31383664790579846`, 0.9339584379688055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 279}], {
             RGBColor[
             0.19737149140968246`, 0.32478032991987577`, 0.9345513864996016]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 283}], {
             RGBColor[
             0.1845388139830274, 0.3112923723057189, 0.9338205845043986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 285}], {
             RGBColor[
             0.2005739783770007, 0.32814634677192855`, 0.9347337633947355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 396}], {
             RGBColor[
             0.1920993256937792, 0.31923894947784826`, 0.9342511444615511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 421}], {
             RGBColor[
             0.18554846728188248`, 0.31235358193853213`, 0.9338780827661202]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 430}], {
             RGBColor[
             0.19415820437315612`, 0.32140296151032133`, 0.9343683945565036]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 459}], {
             RGBColor[
             0.19062008977227754`, 0.3176841787353756, 0.9341669041641552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 477}], {
             RGBColor[
             0.19227698695572149`, 0.31942568272852423`, 0.9342612620075925]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 264}], {
             RGBColor[
             0.8553074725725389, 0.4148947299646385, 0.20015613150748274`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 281}], {
             RGBColor[
             0.8317474856787275, 0.2450306635294393, 0.1780347341805933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 295}], {
             RGBColor[
             0.9149334778554977, 0.6677110589938393, 0.5462140209685634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 324}], {
             RGBColor[
             0.8924019068162066, 0.6510073815667528, 0.588847136940535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 341}], {
             RGBColor[
             0.9196841878836145, 0.6688261379622193, 0.4057355619852222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 374}], {
             RGBColor[
             0.8462576720826371, 0.35656231463411475`, 0.19192970506788876`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 397}], {
             RGBColor[
             0.8335404053549352, 0.2588118298231834, 0.1797516360873429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 275}], {
             RGBColor[
             0.402607767889131, 0.5221630142088122, 0.9471448284585735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 306}], {
             RGBColor[
             0.2783366060930942, 0.40921806996322074`, 0.9391864591429547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 331}], {
             RGBColor[
             0.3086689498622105, 0.44109928644623464`, 0.9409138412479245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 346}], {
             RGBColor[
             0.3786592419849977, 0.5023973362656904, 0.9453488099574316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 348}], {
             RGBColor[
             0.38899180466367445`, 0.5111089618702334, 0.9460729299565488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 355}], {
             RGBColor[
             0.4378065045945586, 0.5507389343512965, 0.9499158019492457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 390}], {
             RGBColor[
             0.2859084769887601, 0.4171765863589087, 0.9396176659888837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 431}], {
             RGBColor[
             0.36857757870000185`, 0.49366510624735727`, 0.9447064152877764]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 444}], {
             RGBColor[
             0.44088363514258455`, 0.5532370875533353, 0.9501580449378868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 486}], {
             RGBColor[
             0.3646188827036643, 0.4902362827451757, 0.9444541706794272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 230}], {
             RGBColor[
             0.22168982682145016`, 0.35034044230916306`, 0.9359362797255486]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 331}], {
             RGBColor[
             0.26945802412846753`, 0.40054784635747565`, 0.938656607895468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 382}], {
             RGBColor[
             0.22477554462649751`, 0.3535837273680766, 0.9361120067896356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 413}], {
             RGBColor[
             0.2338956489319965, 0.363169535241167, 0.9366313832378486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 474}], {
             RGBColor[
             0.23349741976768085`, 0.3627509711402839, 0.936608704676068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 490}], {
             RGBColor[
             0.22672461704495903`, 0.3556323260582085, 0.9362230035804727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 254}], {
             RGBColor[
             0.18642186112422848`, 0.31327157424320573`, 0.9339278212533714]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 377}], {
             RGBColor[
             0.18060293034985866`, 0.30715550905782296`, 0.9335964417541076]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 396}], {
             RGBColor[
             0.18892633617542332`, 0.3159039363149012, 0.9340704474024981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 476}], {
             RGBColor[
             0.18192213006975788`, 0.30854207160553015`, 0.9336715682265748]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 257}], {
             RGBColor[
             0.9190198138450048, 0.7061284902521469, 0.2641826298296307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 266}], {
             RGBColor[
             0.9342851916423655, 0.7569554226506068, 0.3801831663512317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 281}], {
             RGBColor[
             0.8467054680453859, 0.3339234893640672, 0.19133725700073073`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 293}], {
             RGBColor[
             0.8423679493594973, 0.6882641451078306, 0.5995351479132809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 317}], {
             RGBColor[
             0.8461530053131936, 0.3296770187137239, 0.19080821806446593`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 322}], {
             RGBColor[
             0.8478846282356312, 0.34298703129758157`, 0.19246642213058046`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 343}], {
             RGBColor[
             0.8606088112970214, 0.4407906780799979, 0.2046511142000771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 374}], {
             RGBColor[
             0.8612156544492956, 0.4454551404687426, 0.20523222788802623`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 403}], {
             RGBColor[
             0.8091979496573507, 0.6623514892391787, 0.5962290723342419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 440}], {
             RGBColor[
             0.8833097581290331, 0.5630186900098979, 0.22434314065434907`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 445}], {
             RGBColor[
             0.9190529143682962, 0.7062401460895815, 0.26431121911210875`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 471}], {
             RGBColor[
             0.9159118385486107, 0.7462782372358219, 0.5876734401900829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 238}], {
             RGBColor[
             0.4566518822195865, 0.5690445386024363, 0.9505687908779773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[
             0.42089773296190985`, 0.5389821941816072, 0.9480402092524494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 266}], {
             RGBColor[
             0.7100990368535118, 0.7663088762344812, 0.7456861929885767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 293}], {
             RGBColor[
             0.6181817945706438, 0.697617598691705, 0.965038174550626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 403}], {
             RGBColor[
             0.5850117948684971, 0.6717049428230532, 0.961732098971587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 471}], {
             RGBColor[
             0.6917256837597572, 0.7556316908196963, 0.953176466827428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 483}], {
             RGBColor[
             0.4393277460874472, 0.554945345231554, 0.949214553391788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 497}], {
             RGBColor[
             0.4523984541828804, 0.5655914141074888, 0.9502339454421076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 231}], {
             RGBColor[
             0.8790670260426792, 0.9036392003218177, 0.8591433457844534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 233}], {
             RGBColor[
             0.9785167541303205, 0.9817898472456261, 0.8447367386541516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 259}], {
             RGBColor[
             0.8388746662508497, 0.8722406233791922, 0.8551373469793608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 275}], {
             RGBColor[
             0.7418942375705933, 0.7941342962234403, 0.8470741774102124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 348}], {
             RGBColor[
             0.7282782743451366, 0.7830802438848616, 0.8460022789081878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 355}], {
             RGBColor[
             0.7770929742760209, 0.8227102163659248, 0.8498451509008846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 372}], {
             RGBColor[
             0.8043736512463036, 0.8448578989108925, 0.8519927857243978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 379}], {
             RGBColor[
             0.9109503146879699, 0.6018931108868748, 0.4575519033361274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 400}], {
             RGBColor[
             0.9921722318540724, 0.9910310309542629, 0.7793899060000027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 404}], {
             RGBColor[
             0.9156515263183187, 0.9323554252556073, 0.8627536207565263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 431}], {
             RGBColor[
             0.707864048381464, 0.7656363882619854, 0.8446357642394154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 444}], {
             RGBColor[
             0.7801701048240467, 0.8252083695679635, 0.8500873938895259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 486}], {
             RGBColor[
             0.7039053523851265, 0.7622075647598039, 0.8443835196310663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 225}], {
             RGBColor[
             0.189744388344664, 0.31676376101227643`, 0.9341170342633367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 252}], {
             RGBColor[
             0.1889152618740288, 0.3158922965219843, 0.9340698167374166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 280}], {
             RGBColor[
             0.22449871038575198`, 0.3532927570287484, 0.9360962414891647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 309}], {
             RGBColor[
             0.1918597924354573, 0.31898718483606625`, 0.9342375033968474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 320}], {
             RGBColor[
             0.18833104309187587`, 0.31527824554033135`, 0.9340365463420472]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 393}], {
             RGBColor[
             0.20841975513223648`, 0.336392755592659, 0.9351805687741597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 424}], {
             RGBColor[
             0.19449774707264864`, 0.3217598424157385, 0.9343877310109313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 480}], {
             RGBColor[
             0.21944240212988145`, 0.3479782564633687, 0.9358082922141305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 236}], {
             RGBColor[
             0.1979212488225095, 0.32535815981739014`, 0.934582694370969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 289}], {
             RGBColor[
             0.19877803112005593`, 0.32625869233524674`, 0.9346314868553184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 308}], {
             RGBColor[
             0.18919374524082816`, 0.3161850001973557, 0.9340856759531767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 362}], {
             RGBColor[
             0.1833599948775373, 0.31005335868440065`, 0.9337534525002475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 369}], {
             RGBColor[
             0.1847549864301014, 0.3115195832537184, 0.933832895205461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 466}], {
             RGBColor[
             0.1911846700582075, 0.3182775884123456, 0.9341990561762171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 470}], {
             RGBColor[
             0.19104848384555853`, 0.31813444806814695`, 0.9341913005728761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 216}], {
             RGBColor[
             0.19093042363498117`, 0.31801035930138044`, 0.9341845772185382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 217}], {
             RGBColor[
             0.18159408433829743`, 0.30819727474246456`, 0.9336528865074684]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 224}], {
             RGBColor[
             0.19394001881557005`, 0.321173634655535, 0.9343559692117758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 286}], {
             RGBColor[
             0.18467080520712215`, 0.3114311034509694, 0.9338281012093472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 319}], {
             RGBColor[
             0.18140430286516612`, 0.3079978023813632, 0.93364207873333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 330}], {
             RGBColor[
             0.18576322285580926`, 0.312579303663019, 0.9338903127783529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 357}], {
             RGBColor[
             0.18524504165765288`, 0.3120346623691711, 0.9338608031256983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 492}], {
             RGBColor[
             0.18227723304689475`, 0.30891530734933015`, 0.933691790815795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 251}], {
             RGBColor[
             0.22057376513923174`, 0.3491673907187537, 0.9358727216638114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 332}], {
             RGBColor[
             0.19442260484216423`, 0.3216808631672068, 0.9343834517720682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 337}], {
             RGBColor[
             0.19565173016906506`, 0.3229727518168264, 0.9344534486411072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 420}], {
             RGBColor[
             0.19513105630202093`, 0.32242549056993314`, 0.9344237970346471]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 447}], {
             RGBColor[
             0.2179735437754206, 0.34643439320183167`, 0.9357246429038253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 454}], {
             RGBColor[
             0.20680491942710666`, 0.3346954608800703, 0.9350886062696878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 489}], {
             RGBColor[
             0.19691928671610104`, 0.3243050341154881, 0.9345256341112791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 500}], {
             RGBColor[
             0.2016031036308693, 0.32922802266405415`, 0.934792370555489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 223}], {
             RGBColor[
             0.1978649215993461, 0.32529895633449324`, 0.9345794866189384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 268}], {
             RGBColor[
             0.186923339851059, 0.31379866018069236`, 0.9339563797249931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 466}], {
             RGBColor[
             0.1912157031774699, 0.31831020618830375`, 0.9342008234664497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 470}], {
             RGBColor[
             0.19107951696482092`, 0.31816706584410515`, 0.9341930678631087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 491}], {
             RGBColor[
             0.1845859949601158, 0.3113419625040855, 0.9338232713912458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 402}], {
             RGBColor[
             0.2015459552318014, 0.3291679560732161, 0.9347891160387054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 417}], {
             RGBColor[
             0.1910469226092748, 0.31813280710982467`, 0.9341912116627795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 217}], {
             RGBColor[
             0.1905787639681844, 0.31764074269506637`, 0.9341645507207481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 224}], {
             RGBColor[
             0.20292469844545702`, 0.3306171026081368, 0.9348676334250554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 292}], {
             RGBColor[
             0.19251751538449438`, 0.3196784933575477, 0.9342749597457812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 358}], {
             RGBColor[
             0.21239908038802668`, 0.34057527874028815`, 0.9354071854605928]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 361}], {
             RGBColor[
             0.21500792746091607`, 0.34331734242435297`, 0.9355557554419504]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 398}], {
             RGBColor[
             0.20308712437898663`, 0.33078782256267547`, 0.9348768833416823]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 399}], {
             RGBColor[
             0.20389703761891642`, 0.33163909272930703`, 0.934923006702537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 464}], {
             RGBColor[
             0.20118455785762748`, 0.32878810451904233`, 0.9347685349928858]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 481}], {
             RGBColor[
             0.20259193459855807`, 0.33026734670659963`, 0.9348486830162546]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 292}], {
             RGBColor[
             0.18318117608781065`, 0.30986540879863184`, 0.9337432690347114]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 398}], {
             RGBColor[
             0.1937507850823029, 0.3209747380037596, 0.9343451926306123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 464}], {
             RGBColor[
             0.19184821856094375`, 0.31897501996012645`, 0.9342368442818159]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 481}], {
             RGBColor[
             0.19325559530187433`, 0.3204542621476837, 0.9343169923051846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 496}], {
             RGBColor[
             0.1835288398725976, 0.31023082547960007`, 0.9337630679729325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 235}], {
             RGBColor[
             0.2514972659875934, 0.38166995077357824`, 0.9376337692899057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 274}], {
             RGBColor[
             0.26498050169023135`, 0.3958416863835701, 0.9384016196165113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.25886995308296373`, 0.3894191123661732, 0.938053632913074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 305}], {
             RGBColor[
             0.29821563929003225`, 0.43060670099699316`, 0.9403004343609631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 310}], {
             RGBColor[
             0.4653446361758491, 0.5701283226319324, 0.9524120897475179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 314}], {
             RGBColor[
             0.27434229412121725`, 0.4056815238004595, 0.9389347598459252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 406}], {
             RGBColor[
             0.35118939031714774`, 0.4764899015985373, 0.9436758749335621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 432}], {
             RGBColor[
             0.28855483307734864`, 0.4206198033703701, 0.9397441429139097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 493}], {
             RGBColor[
             0.2733906528975818, 0.4046812885368802, 0.9388805652860661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 238}], {
             RGBColor[
             0.5781077146635654, 0.6679567426795029, 0.9602144407477138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 258}], {
             RGBColor[
             0.5423535654058886, 0.6378943982586738, 0.9576858591221857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 293}], {
             RGBColor[
             0.7396376270146225, 0.7965298027687717, 0.9746838244203624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 403}], {
             RGBColor[
             0.7064676273124759, 0.7706171469001197, 0.9713777488413233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 445}], {
             RGBColor[
             0.8163225920234214, 0.8145058037505225, 0.6394598956191903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 471}], {
             RGBColor[
             0.8131815162037359, 0.854543894896763, 0.9628221166971644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 497}], {
             RGBColor[
             0.5738542866268592, 0.6645036181845554, 0.959879595311844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 254}], {
             RGBColor[
             0.20473141614653206`, 0.3325160774644852, 0.9349705233253323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 297}], {
             RGBColor[
             0.20614792707638763`, 0.3340049202637436, 0.9350511915272475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 325}], {
             RGBColor[
             0.22533443478540557`, 0.3541711563607717, 0.9361438347573814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 392}], {
             RGBColor[
             0.22694196327999852`, 0.35586077073178224`, 0.9362353811270232]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 412}], {
             RGBColor[
             0.2036444979201258, 0.3313736574939363, 0.9349086249402898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 413}], {
             RGBColor[
             0.2236716605546839, 0.35242347521830786`, 0.9360491422247958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 426}], {
             RGBColor[
             0.20219514191155313`, 0.32985029243444797`, 0.9348260862597317]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 474}], {
             RGBColor[
             0.22327343139036823`, 0.3520049111174247, 0.9360264636630153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 490}], {
             RGBColor[
             0.2165006286676464, 0.34488626603534933`, 0.9356407625674201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 234}], {
             RGBColor[
             0.9443267569423743, 0.8151145515040961, 0.2837836064703105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 301}], {
             RGBColor[
             0.8093616863432395, 0.8079745679423065, 0.6371695161143949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 336}], {
             RGBColor[
             0.7938129054109903, 0.7955671950703103, 0.6357978963718616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 294}], {
             RGBColor[
             0.19229714625130181`, 0.3194468714263523, 0.9342624100496528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 296}], {
             RGBColor[
             0.18966575842362554`, 0.31668111597984006`, 0.934112556405656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 339}], {
             RGBColor[
             0.1886442457825459, 0.3156074414264231, 0.9340543827719392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 344}], {
             RGBColor[
             0.1936890488951341, 0.3209098493567448, 0.9343416768460837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 438}], {
             RGBColor[
             0.19987204711910306`, 0.3274085725148659, 0.9346937894480125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 439}], {
             RGBColor[
             0.19816628717948753`, 0.32561571066690326`, 0.9345966489428971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 246}], {
             RGBColor[
             0.22404185527291065`, 0.35281257333886495`, 0.9360702242663449]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 268}], {
             RGBColor[
             0.19724310055792588`, 0.32464538299422946`, 0.9345440748305314]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 411}], {
             RGBColor[
             0.24469698646716248`, 0.3745224258349809, 0.9372465034313293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 286}], {
             RGBColor[
             0.19666508001759797`, 0.3240378467577258, 0.9345111574158644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 330}], {
             RGBColor[
             0.1977574976662851, 0.3251860469697754, 0.9345733689848701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 333}], {
             RGBColor[
             0.21886126221320776`, 0.3473674415645458, 0.9357751971555954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 358}], {
             RGBColor[
             0.21540867556861554`, 0.34373855409444265`, 0.9355785774538301]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 361}], {
             RGBColor[
             0.21801752264150492`, 0.34648061777850747`, 0.9357271474351878]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 398}], {
             RGBColor[
             0.2060967195595755, 0.33395109791683003`, 0.9350482753349197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 441}], {
             RGBColor[
             0.21370093658000952`, 0.34194361214051205`, 0.9354813242448025]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 464}], {
             RGBColor[
             0.20419415303821636`, 0.3319513798731969, 0.9349399269861233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 481}], {
             RGBColor[
             0.20560152977914695`, 0.33343062206075413`, 0.9350200750094919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 247}], {
             RGBColor[
             0.18412221385498584`, 0.31085449915717356`, 0.9337968597434113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 252}], {
             RGBColor[
             0.18313599846224066`, 0.30981792424973087`, 0.9337406962357694]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 309}], {
             RGBColor[
             0.18608052902366917`, 0.31291281256381276`, 0.9339083828952002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 320}], {
             RGBColor[
             0.1825517796800877, 0.30920387326807797`, 0.9337074258404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 424}], {
             RGBColor[
             0.18871848366086047`, 0.31568547014348514`, 0.9340586105092841]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 284}], {
             RGBColor[
             0.19690493413279425`, 0.3242899486404264, 0.9345248167528926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 345}], {
             RGBColor[
             0.18891037080707027`, 0.3158871557004993, 0.9340695381983891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 366}], {
             RGBColor[
             0.18476826025973897`, 0.3115335348902769, 0.9338336511304219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 389}], {
             RGBColor[
             0.19095055240575043`, 0.3180315159156967, 0.9341857235222557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 405}], {
             RGBColor[
             0.18431945622850954`, 0.3110618133976357, 0.9338080924047896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 429}], {
             RGBColor[
             0.18946440368264025`, 0.31646947938043657`, 0.9341010895510347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 472}], {
             RGBColor[
             0.18505776823943543`, 0.311837826132804, 0.933850138181577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 488}], {
             RGBColor[
             0.18475420080410804`, 0.31151875751098784`, 0.9338328504652229]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 229}], {
             RGBColor[
             0.21399982241481183`, 0.34225776010334574`, 0.9354983453509325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 263}], {
             RGBColor[
             0.2087485483203887, 0.3367383380800992, 0.935199293059819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 265}], {
             RGBColor[
             0.18874076831201309`, 0.315708892724775, 0.9340598795871999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 267}], {
             RGBColor[
             0.2112079223469873, 0.3393232961153739, 0.935339350772316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 270}], {
             RGBColor[
             0.18663641062037617`, 0.3134970793668807, 0.9339400395297794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 329}], {
             RGBColor[
             0.18736891797604732`, 0.31426699104133987`, 0.9339817547400375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 424}], {
             RGBColor[
             0.19331536997885967`, 0.3205170891231287, 0.9343203963846103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 256}], {
             RGBColor[
             0.28488710481113977`, 0.4165048432644388, 0.9395447890804083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 279}], {
             RGBColor[
             0.23309972747079383`, 0.36233297132110764`, 0.9365860566880932]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 287}], {
             RGBColor[
             0.28118525934636124`, 0.41287391412114016`, 0.9393244565922372]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 298}], {
             RGBColor[
             0.2669525907215979, 0.3979144769932027, 0.9385139271694034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 318}], {
             RGBColor[
             0.22809876360932468`, 0.35707664122328114`, 0.9363012591944456]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 335}], {
             RGBColor[
             0.2342958788041693, 0.36359020221286015`, 0.9366541757369817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 409}], {
             RGBColor[
             0.2557251463437433, 0.3861137210909889, 0.9378745408216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 468}], {
             RGBColor[
             0.23985909159475186`, 0.369437491583826, 0.9369709924753695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 232}], {
             RGBColor[
             0.2566501782178637, 0.3870859882410977, 0.9379272200183691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 263}], {
             RGBColor[
             0.22958947316632627`, 0.3586434714841348, 0.9363861528984097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 267}], {
             RGBColor[
             0.23204884719292487`, 0.3612284295194095, 0.9365262106109067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 280}], {
             RGBColor[
             0.24415725813790062`, 0.37395513714017414`, 0.9372157667014342]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 393}], {
             RGBColor[
             0.2280783028843851, 0.35705513570408476`, 0.9363000939864292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 480}], {
             RGBColor[
             0.23910094988203007`, 0.36864063657479446`, 0.9369278174264002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 485}], {
             RGBColor[
             0.2450928096239232, 0.3749384610693741, 0.9372690449745389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 382}], {
             RGBColor[
             0.20898405610198123`, 0.3369858716906088, 0.9352127048795782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 413}], {
             RGBColor[
             0.21810416040748024`, 0.34657167956369916`, 0.9357320813277911]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 474}], {
             RGBColor[
             0.21770593124316456`, 0.3461531154628161, 0.9357094027660106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 484}], {
             RGBColor[
             0.19535510076833423`, 0.3226609755092681, 0.9344365560355595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 490}], {
             RGBColor[
             0.21093312852044277`, 0.33903447038074064`, 0.9353237016704152]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 233}], {
             RGBColor[
             0.8631076739966228, 0.8934453053740385, 0.9626713381948079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 275}], {
             RGBColor[
             0.6264851574368956, 0.7057897543518528, 0.9650087769508688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 326}], {
             RGBColor[
             0.7445199877539495, 0.8003439400856498, 0.9751704525106033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 346}], {
             RGBColor[
             0.6025366315327623, 0.6860240764087309, 0.963212758449727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 355}], {
             RGBColor[
             0.6616838941423232, 0.7343656744943371, 0.9677797504415411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 395}], {
             RGBColor[
             0.6338994865668826, 0.711809040751297, 0.9655924600995638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 404}], {
             RGBColor[
             0.8002424461846211, 0.8440108833840196, 0.9806882202971826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 431}], {
             RGBColor[
             0.5924549682477664, 0.6772918463903979, 0.9625703637800718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 444}], {
             RGBColor[
             0.664761024690349, 0.7368638276963759, 0.9680219934301821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 486}], {
             RGBColor[
             0.5884962722514289, 0.6738630228882163, 0.9623181191717225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 267}], {
             RGBColor[
             0.25385827815003914`, 0.3841515242531258, 0.9377682254397526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 280}], {
             RGBColor[
             0.26596668909501486`, 0.3968782318738905, 0.9384577815302801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 338}], {
             RGBColor[
             0.351395977443279, 0.47598308304576464`, 0.9437141472934822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 383}], {
             RGBColor[
             0.2731170371748888, 0.40439370106409095`, 0.938864983275437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 393}], {
             RGBColor[
             0.24988773384149937`, 0.3799782304378011, 0.9375421088152751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 395}], {
             RGBColor[
             0.3913003181998807, 0.5091662530135891, 0.9466381048606165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 480}], {
             RGBColor[
             0.2609103808391443, 0.3915637313085108, 0.9381698322552461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 259}], {
             RGBColor[
             0.8229153142047934, 0.8620467284314131, 0.9586653393897153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 275}], {
             RGBColor[
             0.7259348855245369, 0.7839404012756612, 0.9506021698205669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 326}], {
             RGBColor[
             0.8439697158415906, 0.8784945870094583, 0.9607638453803016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 346}], {
             RGBColor[
             0.7019863596204035, 0.7641747233325396, 0.948806151319425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 348}], {
             RGBColor[
             0.7123189222990802, 0.7728863489370825, 0.9495302713185423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 355}], {
             RGBColor[
             0.7611336222299645, 0.8125163214181457, 0.9533731433112391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 379}], {
             RGBColor[
             0.8949909626419136, 0.5916992159390957, 0.5610798957464819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 400}], {
             RGBColor[
             0.9762128798080161, 0.9808371360064839, 0.8829178984103572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 404}], {
             RGBColor[
             0.8996921742722623, 0.9221615303078283, 0.9662816131668808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 431}], {
             RGBColor[
             0.6919046963354076, 0.7554424933142063, 0.9481637566497699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 444}], {
             RGBColor[
             0.7642107527779903, 0.8150144746201845, 0.9536153862998804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 486}], {
             RGBColor[
             0.6879460003390702, 0.7520136698120249, 0.9479115120414208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 336}], {
             RGBColor[
             0.7758644491107505, 0.7262741691289183, 0.6116347463560659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 449}], {
             RGBColor[
             0.9549924747052941, 0.851092521948047, 0.32521790592745947`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 274}], {
             RGBColor[
             0.23060114107907964`, 0.35970679860388893`, 0.9364437658894125]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 284}], {
             RGBColor[
             0.2119740420649528, 0.3401285365137513, 0.9353829801568815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 300}], {
             RGBColor[
             0.22449059247181202`, 0.353284224586492, 0.9360957791859752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 305}], {
             RGBColor[
             0.2638362786788805, 0.394471813217312, 0.9383425806338642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 308}], {
             RGBColor[
             0.2040111506020718, 0.33175903270978435`, 0.9349295052681127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 345}], {
             RGBColor[
             0.20397947873922884`, 0.3317257435738243, 0.934927701602378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 389}], {
             RGBColor[
             0.20601966033790897`, 0.3338701037890217, 0.9350438869262447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 432}], {
             RGBColor[
             0.25417547246619693`, 0.38448491559068887`, 0.9377862891868108]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 456}], {
             RGBColor[
             0.20636469541016642`, 0.3342327575264513, 0.9350635361631761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 289}], {
             RGBColor[
             0.20921618528861102`, 0.33722985418359713`, 0.9352259242933523]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 300}], {
             RGBColor[
             0.22011134127912346`, 0.34868135392241384`, 0.9358463873090731]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 308}], {
             RGBColor[
             0.19963189940938322`, 0.3271561620457061, 0.9346801133912106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 314}], {
             RGBColor[
             0.23558368231737692`, 0.3649437653567001, 0.9367275142419242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 466}], {
             RGBColor[
             0.2016228242267626, 0.329248750260696, 0.934793493614251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 470}], {
             RGBColor[
             0.2014866380141136, 0.3291056099164974, 0.9347857380109101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 493}], {
             RGBColor[
             0.23463204109374153`, 0.36394353009312075`, 0.9366733196820654]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 241}], {
             RGBColor[
             0.2242600552960576, 0.35304191539787294`, 0.9360826504348652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 274}], {
             RGBColor[
             0.23848727143504053`, 0.36799562161754756`, 0.9368928693467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 284}], {
             RGBColor[
             0.21986017242091369`, 0.34841735952740993`, 0.9358320836141691]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 351}], {
             RGBColor[
             0.2365402762573613, 0.3659492062391825, 0.9367819908516525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 371}], {
             RGBColor[
             0.24348618176994377`, 0.3732497933287522, 0.9371775498950476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 429}], {
             RGBColor[
             0.2124196419707597, 0.3405968902674201, 0.9354083564123112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 432}], {
             RGBColor[
             0.26206160282215785`, 0.3927737386043475, 0.9382353926440985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 460}], {
             RGBColor[
             0.26678188416083737`, 0.3977350535744224, 0.9385042056833057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 258}], {
             RGBColor[
             0.4509349141328164, 0.5640927881888469, 0.9502045107268047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 266}], {
             RGBColor[
             0.7401362180244184, 0.7914194702417209, 0.7478504944629321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 293}], {
             RGBColor[
             0.6482189757415503, 0.7227281926989446, 0.9672024760249813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 403}], {
             RGBColor[
             0.6150489760394036, 0.6968155368302928, 0.9638964004459423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 445}], {
             RGBColor[
             0.7249039407503491, 0.7407041936806955, 0.6319785472238091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 471}], {
             RGBColor[
             0.7217628649306637, 0.780742284826936, 0.9553407683017833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 483}], {
             RGBColor[
             0.46936492725835366`, 0.5800559392387936, 0.9513788548661433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 497}], {
             RGBColor[
             0.4824356353537869, 0.5907020081147285, 0.9523982469164629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 251}], {
             RGBColor[
             0.2177871872756262, 0.3462385207048633, 0.9357140301768516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 272}], {
             RGBColor[
             0.22693559422031087`, 0.3558540764462288, 0.9362350184184962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 332}], {
             RGBColor[
             0.1916360269785587, 0.31875199315331637`, 0.9342247602851084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 387}], {
             RGBColor[
             0.1927675658632359, 0.3199413122648211, 0.934289199750629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 435}], {
             RGBColor[
             0.21752143841029148`, 0.3459592017979452, 0.9356988961721111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 453}], {
             RGBColor[
             0.21828737914361301`, 0.34676425407211353`, 0.935742515363766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 454}], {
             RGBColor[
             0.20401834156350113`, 0.3317665908661798, 0.9349299147827279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 489}], {
             RGBColor[
             0.1941327088524955, 0.32137616410159764`, 0.9343669426243193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 434}], {
             RGBColor[
             0.9649429424873008, 0.8858096572696792, 0.4713319778660402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 495}], {
             RGBColor[
             0.9404490296531263, 0.7834756918464549, 0.4513533807985771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 271}], {
             RGBColor[
             0.2118628562397169, 0.3400116731618399, 0.935376648288619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 304}], {
             RGBColor[
             0.20316948858682138`, 0.3308743925673022, 0.9348815738614715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 311}], {
             RGBColor[
             0.2028072709740812, 0.33049367889038916`, 0.934860946104279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 351}], {
             RGBColor[
             0.22791016546505544`, 0.3568784126158412, 0.9362905188091355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 371}], {
             RGBColor[
             0.2348560709776379, 0.3641789997054109, 0.9366860778525307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 429}], {
             RGBColor[
             0.20378953117845383`, 0.33152609664407884`, 0.9349168843697941]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 442}], {
             RGBColor[
             0.22676711964941848`, 0.35567699899031613`, 0.9362254240409197]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 249}], {
             RGBColor[
             0.8500313217686346, 0.8830430785885436, 0.951908121903962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 269}], {
             RGBColor[
             0.787493374586991, 0.8335677780907182, 0.9460989448159113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 282}], {
             RGBColor[
             0.8349131599958114, 0.8712326557093291, 0.9504012848257013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 310}], {
             RGBColor[
             0.8089627721429287, 0.8509600154884045, 0.9478147926846883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 323}], {
             RGBColor[
             0.9829115082024764, 0.98536084245597, 0.8504363857845441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 419}], {
             RGBColor[
             0.8111996093173061, 0.8527074496896203, 0.9480377397097984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 449}], {
             RGBColor[
             0.9783597736506789, 0.9679158712997968, 0.6606061921458748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 499}], {
             RGBColor[
             0.8008428775112291, 0.844405505952868, 0.9471498665869478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 273}], {
             RGBColor[
             0.1918690378137841, 0.3189969023148785, 0.9342380299074659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 279}], {
             RGBColor[
             0.20228104719014361`, 0.3299405843289558, 0.934830978438262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 283}], {
             RGBColor[
             0.18944836976348856`, 0.3164526267147989, 0.934100176443059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 285}], {
             RGBColor[
             0.20548353415746184`, 0.3333066011810086, 0.9350133553333959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 318}], {
             RGBColor[
             0.19728008332867447`, 0.3246842542311293, 0.9345461809446143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 335}], {
             RGBColor[
             0.2034771985235191, 0.3311978152207083, 0.9348990974871504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 396}], {
             RGBColor[
             0.19700888147424034`, 0.32439920388692833`, 0.9345307364002116]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 421}], {
             RGBColor[
             0.1904580230623436, 0.31751383634761216`, 0.9341576747047806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 430}], {
             RGBColor[
             0.19906776015361727`, 0.3265632159194014, 0.934647986495164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 459}], {
             RGBColor[
             0.19552964555273866`, 0.32284443314445566`, 0.9344464961028154]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 477}], {
             RGBColor[
             0.19718654273618264`, 0.32458593713760425`, 0.9345408539462529]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 261}], {
             RGBColor[
             0.388007213318593, 0.5104940791921502, 0.9459444544247217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 262}], {
             RGBColor[
             0.3949445171400494, 0.5165028230832673, 0.9463864932898081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 295}], {
             RGBColor[
             0.7157587889214511, 0.7746651605070033, 0.9256601695039643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 341}], {
             RGBColor[
             0.7205094989495678, 0.7757802394753833, 0.7851817105206231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 376}], {
             RGBColor[
             0.40891528656398646`, 0.5286036013669932, 0.947276698363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 391}], {
             RGBColor[
             0.45991819988990085`, 0.5722422337278446, 0.9506750794005083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 407}], {
             RGBColor[
             0.361925627233212, 0.4849803667690406, 0.9443895897897958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 448}], {
             RGBColor[
             0.373652859998312, 0.49730643195466345`, 0.9450574383468822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 455}], {
             RGBColor[
             0.5298831385666443, 0.6290429228301937, 0.9561829756631566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 475}], {
             RGBColor[
             0.39162513268333266`, 0.5136277391039731, 0.9461749850474426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 478}], {
             RGBColor[
             0.34801769220506096`, 0.4703622452404419, 0.9435975534648887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 482}], {
             RGBColor[
             0.3895468312104969, 0.511827618826672, 0.9460425575153633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 262}], {
             RGBColor[
             0.2935462908702744, 0.4226836514910424, 0.9401449256179049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 299}], {
             RGBColor[
             0.24199930981785328`, 0.3716869966339784, 0.9370928747370061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 376}], {
             RGBColor[
             0.30751706029421144`, 0.43478442977476833`, 0.9410351306917317]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 438}], {
             RGBColor[
             0.22328352119424416`, 0.3520155161410289, 0.9360270382624196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 448}], {
             RGBColor[
             0.272254633728537, 0.40348726036243854`, 0.9388158706749788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 475}], {
             RGBColor[
             0.2902269064135576, 0.4198085675117481, 0.9399334173755393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 482}], {
             RGBColor[
             0.2881486049407218, 0.4180084472344471, 0.93980098984346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 384}], {
             RGBColor[
             0.2539870125967417, 0.38428683231884564`, 0.9377755566760467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 402}], {
             RGBColor[
             0.22901412567720097`, 0.3580387447939263, 0.9363533877100543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 411}], {
             RGBColor[
             0.2605541594338602, 0.3911893200258155, 0.9381495459731974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 458}], {
             RGBColor[
             0.2394606076875042, 0.3690186597319697, 0.9369482994063559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 252}], {
             RGBColor[
             0.18329308738435063`, 0.3099830346668814, 0.9337496422174913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 278}], {
             RGBColor[
             0.18437169562717964`, 0.3111167203178072, 0.9338110673612625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 309}], {
             RGBColor[
             0.18623761794577917`, 0.3130779229809633, 0.933917328876922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 401}], {
             RGBColor[
             0.1825033131056717, 0.3091529318254084, 0.9337046657406869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 451}], {
             RGBColor[
             0.19468301666075716`, 0.32195457249961096`, 0.9343982818398924]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 339}], {
             RGBColor[
             0.18022958629127006`, 0.30676310078086577`, 0.933575180362284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 344}], {
             RGBColor[
             0.18527438940385826`, 0.31206550871118754`, 0.9338624744364286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 387}], {
             RGBColor[
             0.18458186461527748`, 0.3113376212497815, 0.9338230361742175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 439}], {
             RGBColor[
             0.18975162768821172`, 0.3167713700213459, 0.934117446533242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 269}], {
             RGBColor[
             0.6644117978227214, 0.7371426324130581, 0.9676100378285277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 282}], {
             RGBColor[
             0.7118315832315418, 0.7748075100316689, 0.9719123778383179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 310}], {
             RGBColor[
             0.685881195378659, 0.7545348698107444, 0.9693258856973048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 323}], {
             RGBColor[
             0.8598299314382067, 0.8889356967783099, 0.8719474787971606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 406}], {
             RGBColor[
             0.5717259495199576, 0.6608964487773493, 0.960589670883349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 419}], {
             RGBColor[
             0.6881180325530365, 0.7562823040119602, 0.9695488327224149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 499}], {
             RGBColor[
             0.6777613007469594, 0.7479803602752079, 0.9686609595995643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 263}], {
             RGBColor[
             0.22198989446995654`, 0.350655832433131, 0.9359533681342207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 365}], {
             RGBColor[
             0.21334264494811753`, 0.3415670249183921, 0.9354609200664112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 485}], {
             RGBColor[
             0.23749323092755345`, 0.3669508220183703, 0.9368362602103498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 258}], {
             RGBColor[
             0.3270553942889411, 0.45124571304551764`, 0.9422970062673146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 272}], {
             RGBColor[
             0.24807843064742718`, 0.378076538064383, 0.937439071674997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 435}], {
             RGBColor[
             0.2386642748374078, 0.3681816634160995, 0.9369029494286119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 447}], {
             RGBColor[
             0.23632980233893142`, 0.3657279848060955, 0.9367700046733661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 453}], {
             RGBColor[
             0.23943021557072935`, 0.3689867156902678, 0.9369465686202667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 454}], {
             RGBColor[
             0.22516117799061744`, 0.3539890524843341, 0.9361339680392287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 309}], {
             RGBColor[
             0.18525140255303396`, 0.3120413480735207, 0.9338611653692801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 320}], {
             RGBColor[
             0.18172265320945252`, 0.3083324087777858, 0.93366020831448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 424}], {
             RGBColor[
             0.1878893571902253, 0.31481400565319295`, 0.934011392983364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 287}], {
             RGBColor[
             0.340823165506129, 0.46920105185432204`, 0.9429534744527581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 301}], {
             RGBColor[
             0.5169703257345344, 0.6164641572661, 0.9558333707121969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 336}], {
             RGBColor[
             0.5014215448022852, 0.6040567843941038, 0.9544617509696633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 354}], {
             RGBColor[
             0.34404011319445926`, 0.47241198691533204`, 0.9431429096833921]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 388}], {
             RGBColor[
             0.3530902196198862, 0.48025073422946185`, 0.9437195744621254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 436}], {
             RGBColor[
             0.36650668927910635`, 0.49187140591690626`, 0.9445744600450926]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 473}], {
             RGBColor[
             0.32054318862790937`, 0.44788551033051344`, 0.9417985597710807]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 350}], {
             RGBColor[
             0.18697690227356584`, 0.31385495768280075`, 0.9339594300257164]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 377}], {
             RGBColor[
             0.18661056292735312`, 0.3134699118026751, 0.9339385675419001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 412}], {
             RGBColor[
             0.19134257547531666`, 0.31844355701750904`, 0.9342080486561213]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 426}], {
             RGBColor[
             0.189893219466744, 0.3169201919580207, 0.9341255099755632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 476}], {
             RGBColor[
             0.18792976264725234`, 0.31485647435038233`, 0.9340136940143672]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 260}], {
             RGBColor[
             0.2034606107913817, 0.33118038046250897`, 0.9348981528403446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 299}], {
             RGBColor[
             0.21862190988624552`, 0.3471158670930945, 0.935761566394665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 312}], {
             RGBColor[
             0.19606964847691927`, 0.3234120104559323, 0.9344772484704849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 327}], {
             RGBColor[
             0.19047479361502342`, 0.3175314632617931, 0.9341586297629458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 334}], {
             RGBColor[
             0.19201279446501912`, 0.3191479996700246, 0.9342462166360848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 385}], {
             RGBColor[
             0.1893629494279947, 0.3163628445262328, 0.9340953118813207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 446}], {
             RGBColor[
             0.19028875988053398`, 0.31733593001162463`, 0.9341480354169789]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 478}], {
             RGBColor[
             0.22324206600367816`, 0.3519719441073331, 0.9360246774506443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 287}], {
             RGBColor[
             0.30785568445183253`, 0.44064627675886753`, 0.9408528157119771]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 298}], {
             RGBColor[
             0.2936230158270692, 0.42568683963093007`, 0.9400422862891433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 409}], {
             RGBColor[
             0.2823955714492146, 0.41388608372871627`, 0.93940289994134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 281}], {
             RGBColor[
             0.8907382712640035, 0.5148249421887663, 0.2381214507014296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 317}], {
             RGBColor[
             0.8901858085318111, 0.510578471538423, 0.23759241176516477`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 322}], {
             RGBColor[
             0.8919174314542486, 0.5238884841222806, 0.23925061583127932`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 324}], {
             RGBColor[
             0.9513926924014826, 0.9208016602260798, 0.6489338534613713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 326}], {
             RGBColor[
             0.8442173233312698, 0.8362115823989578, 0.6421148916132133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 343}], {
             RGBColor[
             0.9046416145156388, 0.621692130904697, 0.25143530790077595`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 374}], {
             RGBColor[
             0.9052484576679132, 0.6263565932934416, 0.25201642158872506`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 445}], {
             RGBColor[
             0.9630857175869136, 0.8871415989142806, 0.3110954128128076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 272}], {
             RGBColor[
             0.33620380123362575`, 0.46086126878688316`, 0.9428179945089592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 293}], {
             RGBColor[
             0.6124648264838737, 0.6926658482781156, 0.9646738943994533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 403}], {
             RGBColor[
             0.5792948267817268, 0.6667531924094637, 0.9613678188204143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 435}], {
             RGBColor[
             0.32678964542360633`, 0.4509663941385996, 0.942281872262574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 453}], {
             RGBColor[
             0.3275555861569279, 0.45177144641276795`, 0.942325491454229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 471}], {
             RGBColor[
             0.686008715672987, 0.7506799404061069, 0.9528121866762553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 497}], {
             RGBColor[
             0.44668148609611025`, 0.5606396636938994, 0.9498696652909349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 275}], {
             RGBColor[
             0.586292797645066, 0.6743911774092273, 0.9610027781457763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 331}], {
             RGBColor[
             0.4923539796181456, 0.5933274496466499, 0.9547717909351274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 348}], {
             RGBColor[
             0.5726768344196096, 0.6633371250706486, 0.9599308796437516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 372}], {
             RGBColor[
             0.6487722113207766, 0.7251147800966794, 0.9659213864599616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 400}], {
             RGBColor[
             0.8365707919285453, 0.8712879121400499, 0.8933185067355665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 404}], {
             RGBColor[
             0.7600500863927916, 0.8126123064413943, 0.97668222149209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 418}], {
             RGBColor[
             0.5798892585592409, 0.6691924959032061, 0.9604986680920036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 431}], {
             RGBColor[
             0.552262608455937, 0.6458932694477724, 0.9585643649749793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 444}], {
             RGBColor[
             0.6245686648985196, 0.7054652507537504, 0.9640159946250897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 486}], {
             RGBColor[
             0.5483039124595994, 0.6424644459455908, 0.95831212036663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 299}], {
             RGBColor[
             0.2249121050554158, 0.35372726103730096`, 0.9361197837040394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 312}], {
             RGBColor[
             0.2023598436460895, 0.3300234044001388, 0.9348354657798592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 328}], {
             RGBColor[
             0.2263686482084435, 0.35525818024130285`, 0.9362027316818419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 334}], {
             RGBColor[
             0.19830298963418935`, 0.3257593936142311, 0.9346044339454591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 399}], {
             RGBColor[
             0.20881488896675832`, 0.33680806630567356`, 0.9352030710614876]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 407}], {
             RGBColor[
             0.24344019620099944`, 0.3732014595801383, 0.9371749310849259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 446}], {
             RGBColor[
             0.19657895504970424`, 0.32394732395583115`, 0.9345062527263533]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 478}], {
             RGBColor[
             0.22953226117284842`, 0.3585833380515396, 0.9363828947600188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 262}], {
             RGBColor[
             0.33623006243366543`, 0.4656473134908974, 0.942645260155071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 299}], {
             RGBColor[
             0.2846830813812443, 0.4146506586338333, 0.9395932092741723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 313}], {
             RGBColor[
             0.3452565934007724, 0.4734656409279675, 0.9432204227264471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 328}], {
             RGBColor[
             0.28613962453427205`, 0.41618157783783527`, 0.9396761572519747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 391}], {
             RGBColor[
             0.40120374518351687`, 0.5213867241354746, 0.9469338462657712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 407}], {
             RGBColor[
             0.30321117252682794`, 0.43412485717667065`, 0.9406483566550587]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 448}], {
             RGBColor[
             0.314938405291928, 0.4464509223622935, 0.9413162052121451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 455}], {
             RGBColor[
             0.47116868386026034`, 0.5781874132378237, 0.9524417425284195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 475}], {
             RGBColor[
             0.3329106779769486, 0.46277222951160313`, 0.9424337519127055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 478}], {
             RGBColor[
             0.2893032374986769, 0.41950673564807195`, 0.9398563203301515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 482}], {
             RGBColor[
             0.3308323765041129, 0.4609721092343021, 0.9423013243806262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 299}], {
             RGBColor[
             0.2916203852027007, 0.4206594025249505, 0.9400352481392587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 376}], {
             RGBColor[
             0.3571381356790589, 0.48375683566574046`, 0.9439775040939842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 391}], {
             RGBColor[
             0.4081410490049733, 0.5273954680265918, 0.9473758851308575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 448}], {
             RGBColor[
             0.3218757091133844, 0.45245966625341066`, 0.9417582440772314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 455}], {
             RGBColor[
             0.47810598768171675`, 0.5841961571289409, 0.9528837813935058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 475}], {
             RGBColor[
             0.33984798179840503`, 0.4687809734027203, 0.9428757907777918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 478}], {
             RGBColor[
             0.29624054132013333`, 0.4255154795391891, 0.9402983591952379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 482}], {
             RGBColor[
             0.3377696803255693, 0.46698085312541926`, 0.9427433632457125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 267}], {
             RGBColor[
             0.22679757309850174`, 0.35570900749616285`, 0.9362271583197932]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 393}], {
             RGBColor[
             0.22282702878996197`, 0.35153571368083814`, 0.9360010416953157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 485}], {
             RGBColor[
             0.23984153552950008`, 0.3694190390461275, 0.9369699926834254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 281}], {
             RGBColor[
             0.8419839123581961, 0.3124840077358858, 0.18739747519941907`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 295}], {
             RGBColor[
             0.9251699045349664, 0.7351644032002858, 0.5555767619873893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 324}], {
             RGBColor[
             0.9026383334956752, 0.7184607257731993, 0.5982098779593608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 341}], {
             RGBColor[
             0.9299206145630832, 0.7362794821686658, 0.415098303004048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 374}], {
             RGBColor[
             0.8564940987621058, 0.42401565884056125`, 0.20129244608671454`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 397}], {
             RGBColor[
             0.8437768320344039, 0.3262651740296299, 0.18911437710616869`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 270}], {
             RGBColor[
             0.18221828136351503`, 0.30885334539234544`, 0.9336884336046377]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 320}], {
             RGBColor[
             0.18273053674122575`, 0.3093917582731863, 0.9337176057905845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 329}], {
             RGBColor[
             0.18295078871918613`, 0.3096232570668046, 0.9337301488148957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 424}], {
             RGBColor[
             0.18889724072199854`, 0.3158733551485935, 0.9340687904594684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 293}], {
             RGBColor[
             0.9016661303754756, 0.9199925303309897, 0.7623198781355807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 317}], {
             RGBColor[
             0.9054511863291719, 0.561405403936883, 0.35359294828676574`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 322}], {
             RGBColor[
             0.9071828092516094, 0.5747154165207407, 0.3552511523528803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 343}], {
             RGBColor[
             0.9199069923129997, 0.6725190633031569, 0.3674358444223769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 359}], {
             RGBColor[
             0.9515547370167402, 0.9596896244773535, 0.7671002510689349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 403}], {
             RGBColor[
             0.868496130673329, 0.8940798744623377, 0.7590138025565417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 440}], {
             RGBColor[
             0.9426079391450114, 0.7947470752330569, 0.3871278708766489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 445}], {
             RGBColor[
             0.9783510953842744, 0.9379685313127405, 0.42709594933440853`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 471}], {
             RGBColor[
             0.975210019564589, 0.978006622458981, 0.7504581704123827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 483}], {
             RGBColor[
             0.722812081892279, 0.7773202768708386, 0.7464962569767426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 280}], {
             RGBColor[
             0.24136535807007609`, 0.3710206731522022, 0.9370567721228178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 393}], {
             RGBColor[
             0.22528640281656057`, 0.35412067171611283`, 0.9361410994078128]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 424}], {
             RGBColor[
             0.21136439475697272`, 0.3394877585391924, 0.9353482616445844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 480}], {
             RGBColor[
             0.23630904981420553`, 0.3657061725868226, 0.9367688228477836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 485}], {
             RGBColor[
             0.24230090955609868`, 0.3720039970814022, 0.9371100503959223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 491}], {
             RGBColor[
             0.1839641739186956, 0.3106883891638218, 0.9337878596028387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 282}], {
             RGBColor[
             0.6492936360498982, 0.7253322095338435, 0.966103200750267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 310}], {
             RGBColor[
             0.6233432481970155, 0.705059569312919, 0.963516708609254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 323}], {
             RGBColor[
             0.7972919842565633, 0.8394603962804845, 0.8661383017091098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 406}], {
             RGBColor[
             0.5091880023383142, 0.611421148279524, 0.9547804937952983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 411}], {
             RGBColor[
             0.441541570634595, 0.5502832522185821, 0.9505633429393294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 419}], {
             RGBColor[
             0.6255800853713929, 0.7068070035141348, 0.9637396556343641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 499}], {
             RGBColor[
             0.615223353565316, 0.6985050597773825, 0.9628517825115135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 329}], {
             RGBColor[
             0.18084643102754924`, 0.3074114437089104, 0.9336103087574752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 479}], {
             RGBColor[
             0.18121603188329788`, 0.30779991764234993`, 0.9336313569794346]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 304}], {
             RGBColor[
             0.19940240032278655`, 0.3269149439546105, 0.9346670437577425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 307}], {
             RGBColor[
             0.199934386249049, 0.3274740948929682, 0.9346973395692404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 311}], {
             RGBColor[
             0.19904018271004636`, 0.32653423027769746`, 0.9346464160005499]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 351}], {
             RGBColor[
             0.2241430772010206, 0.3529189640031495, 0.9360759887054064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 371}], {
             RGBColor[
             0.23108898271360306`, 0.3602195510927192, 0.9364715477488016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 429}], {
             RGBColor[
             0.200022442914419, 0.32756664803138713`, 0.9347023542660651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 442}], {
             RGBColor[
             0.22300003138538366`, 0.3517175503776244, 0.9360108939371906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 435}], {
             RGBColor[
             0.24781268178209245`, 0.377797219157465, 0.9374239376702564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 453}], {
             RGBColor[
             0.24857862251541402`, 0.3786022714316334, 0.9374675568619113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 497}], {
             RGBColor[
             0.3677045224545963, 0.48747048871276477`, 0.9450117306986173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 279}], {
             RGBColor[
             0.19757076585955963`, 0.32498978000142653`, 0.9345627348847221]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 283}], {
             RGBColor[
             0.18473808843290457`, 0.31150182238726964`, 0.933831932889519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 285}], {
             RGBColor[
             0.20077325282687788`, 0.3283557968534793, 0.934745111779856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 396}], {
             RGBColor[
             0.19229860014365638`, 0.3194483995593991, 0.9342624928466716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 421}], {
             RGBColor[
             0.18574774173175967`, 0.3125630320200829, 0.9338894311512407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 430}], {
             RGBColor[
             0.19435747882303328`, 0.32161241159187215`, 0.9343797429416241]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 459}], {
             RGBColor[
             0.19081936422215473`, 0.3178936288169264, 0.9341782525492754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 477}], {
             RGBColor[
             0.19247626140559868`, 0.319635132810075, 0.9342726103927129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 284}], {
             RGBColor[
             0.22545727776759072`, 0.3543002721237432, 0.936150830483487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 300}], {
             RGBColor[
             0.23797382817444995`, 0.36745596019648397`, 0.9368636295125807]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 305}], {
             RGBColor[
             0.2773195143815185, 0.4086435488273039, 0.9391104309604698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 389}], {
             RGBColor[
             0.2195028960405469, 0.34804183939901356`, 0.9358117372528503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 432}], {
             RGBColor[
             0.26765870816883486`, 0.3986566512006808, 0.9385541395134164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 460}], {
             RGBColor[
             0.27237898950751444`, 0.4036179661707557, 0.9388229525526237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 331}], {
             RGBColor[
             0.39537355093788906`, 0.515221122490898, 0.946708621365979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 346}], {
             RGBColor[
             0.4653638430606762, 0.5765191723103537, 0.951143590075486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 348}], {
             RGBColor[
             0.475696405739353, 0.5852307979148967, 0.9518677100746031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 355}], {
             RGBColor[
             0.5245111056702372, 0.6248607703959599, 0.9557105820673001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 372}], {
             RGBColor[
             0.55179178264052, 0.6470084529409276, 0.9578582168908132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 404}], {
             RGBColor[
             0.663069657712535, 0.7345059792856424, 0.9686190519229416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 418}], {
             RGBColor[
             0.48290882987898437`, 0.5910861687474542, 0.9524354985228551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 431}], {
             RGBColor[
             0.4552821797756804, 0.5677869422920205, 0.9505011954058309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 444}], {
             RGBColor[
             0.5275882362182631, 0.6273589235979986, 0.9559528250559413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 486}], {
             RGBColor[
             0.45132348377934284`, 0.564358118789839, 0.9502489507974816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 306}], {
             RGBColor[
             0.22718429673725105`, 0.3561154785601833, 0.9362491816589136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 347}], {
             RGBColor[
             0.20833762491305394`, 0.33630643152494155`, 0.935175891579678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 382}], {
             RGBColor[
             0.21283416100439742`, 0.3410325760537981, 0.935431962658051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 462}], {
             RGBColor[
             0.20183278400452248`, 0.3294694312993405, 0.9348054505129868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 288}], {
             RGBColor[
             0.5772249873338873, 0.6663273536018384, 0.9606573715704986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 313}], {
             RGBColor[
             0.4022235011215268, 0.5228075131556505, 0.9468503037125551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 340}], {
             RGBColor[
             0.40350978000289583`, 0.523921623272436, 0.9469322642654641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 373}], {
             RGBColor[
             0.7171130809828956, 0.774434213301909, 0.8741433170431847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 386}], {
             RGBColor[
             0.3744145130463712, 0.49843012291785427`, 0.9450889814281427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 414}], {
             RGBColor[
             0.43294658493558325`, 0.5494183041682945, 0.9488079514458304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 498}], {
             RGBColor[
             0.6089064489917588, 0.6910771522369943, 0.9638150835884631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 401}], {
             RGBColor[
             0.18259570595575553`, 0.30925004256889155`, 0.9337099273768162]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 451}], {
             RGBColor[
             0.194775409510841, 0.3220516832430941, 0.9344035434760216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.2111852622032374, 0.3392994788675566, 0.935338060310652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 318}], {
             RGBColor[
             0.20298181137445004`, 0.33067713191767734`, 0.9348708859218705]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 335}], {
             RGBColor[
             0.20917892656929465`, 0.33719069290725634`, 0.9352238024644066]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 396}], {
             RGBColor[
             0.2027106095200159, 0.3303920815734764, 0.9348554413774677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 409}], {
             RGBColor[
             0.23060819410886862`, 0.3597142117853851, 0.9364441675490249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 421}], {
             RGBColor[
             0.19615975110811917`, 0.3235067140341602, 0.9344823796820367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 430}], {
             RGBColor[
             0.2047694881993928, 0.33255609360594945`, 0.9349726914724201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 459}], {
             RGBColor[
             0.20123137359851423`, 0.3288373108310037, 0.9347712010800716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 477}], {
             RGBColor[
             0.2028882707819582, 0.3305788148241523, 0.9348655589235091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 338}], {
             RGBColor[
             0.33890305736331594`, 0.4628522319448411, 0.9430026939765475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 383}], {
             RGBColor[
             0.2606241170949257, 0.3912628499631674, 0.9381535299585022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 393}], {
             RGBColor[
             0.23739481376153632`, 0.3668473793368775, 0.9368306554983403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 480}], {
             RGBColor[
             0.24841746075918128`, 0.37843288020758725`, 0.9374583789383113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 317}], {
             RGBColor[
             0.8178714627321924, 0.13837347065034328`, 0.1647470389362648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 322}], {
             RGBColor[
             0.8196030856546299, 0.15168348323420097`, 0.16640524300237935`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 324}], {
             RGBColor[
             0.8790783466018638, 0.5485966593380001, 0.5760884806324713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 343}], {
             RGBColor[
             0.8323272687160201, 0.24948713001661726`, 0.17858993507187598`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 374}], {
             RGBColor[
             0.8329341118682944, 0.254151592405362, 0.1791710487598251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 397}], {
             RGBColor[
             0.8202168451405925, 0.15640110759443068`, 0.16699297977927924`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 445}], {
             RGBColor[
             0.8907713717872949, 0.5149365980262008, 0.23825003998390762`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 310}], {
             RGBColor[
             0.6707630336058359, 0.74272444693153, 0.9678190486190441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 323}], {
             RGBColor[
             0.8447117696653836, 0.8771252738990953, 0.8704406417188999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 406}], {
             RGBColor[
             0.5566077877471345, 0.6490860258981348, 0.9590828338050883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 419}], {
             RGBColor[
             0.6729998707802133, 0.7444718811327458, 0.9680419956441542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 499}], {
             RGBColor[
             0.6626431389741363, 0.7361699373959933, 0.9671541225213036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 396}], {
             RGBColor[
             0.18987793209336085`, 0.3169041239593195, 0.9341246393822646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 421}], {
             RGBColor[
             0.18332707368146411`, 0.3100187564200033, 0.9337515776868337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 430}], {
             RGBColor[
             0.19193681077273775`, 0.31906813599179257`, 0.9342418894772171]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 459}], {
             RGBColor[
             0.18839869617185917`, 0.3153493532168468, 0.9340403990848687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 477}], {
             RGBColor[
             0.19005559335530314`, 0.3170908572099954, 0.934134756928306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 300}], {
             RGBColor[
             0.2193467291603231, 0.3478776981063463, 0.9358028437800496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 345}], {
             RGBColor[
             0.19883561542773992`, 0.32631921709367856`, 0.9346347661964527]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 389}], {
             RGBColor[
             0.20087579702642006`, 0.328463577308876, 0.9347509515203193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 432}], {
             RGBColor[
             0.249031609154708, 0.37907838911054315`, 0.9374933537808854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 456}], {
             RGBColor[
             0.2012208320986775, 0.3288262310463056, 0.9347706007572507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 472}], {
             RGBColor[
             0.19498301286010505`, 0.32226988752598323`, 0.9344153661796406]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 287}], {
             RGBColor[
             0.2592707940788048, 0.38984042166758914`, 0.938076460214796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 354}], {
             RGBColor[
             0.2624877417671351, 0.39305135672859914`, 0.93826589544543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 396}], {
             RGBColor[
             0.20591309648733414`, 0.33375809842552917`, 0.9350378182726016]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 409}], {
             RGBColor[
             0.23381068107618688`, 0.3630802286374379, 0.9366265444441588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 430}], {
             RGBColor[
             0.20797197516671106`, 0.33592211045800224`, 0.935155068367554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 473}], {
             RGBColor[
             0.2389908172005852, 0.3685248801437806, 0.9369215455331186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 477}], {
             RGBColor[
             0.20609075774927643`, 0.3339448316762051, 0.935047935818643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 319}], {
             RGBColor[
             0.18412936406719407`, 0.310862014483554, 0.9337972669374188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 330}], {
             RGBColor[
             0.18848828405783719`, 0.3154435157652098, 0.9340455009824417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 357}], {
             RGBColor[
             0.1879701028596808, 0.3148988744713619, 0.934015991329787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 358}], {
             RGBColor[
             0.20613946196016764`, 0.33399602288987706`, 0.9350507094514018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 367}], {
             RGBColor[
             0.1922727390163294, 0.3194212178748882, 0.9342610200937285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 368}], {
             RGBColor[
             0.18331387184910375`, 0.310004880457148, 0.9337508258620111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 492}], {
             RGBColor[
             0.18500229424892267`, 0.31177951945152094`, 0.9338469790198838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 336}], {
             RGBColor[
             0.46475221828321023`, 0.5718710801553506, 0.9521407597407114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 354}], {
             RGBColor[
             0.3073707866753843, 0.44022628267657893`, 0.9408219184544402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 388}], {
             RGBColor[
             0.31642089310081123`, 0.44806502999070874`, 0.9413985832331735]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 409}], {
             RGBColor[
             0.2786937259844361, 0.4102551545854176, 0.9391825674531689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 436}], {
             RGBColor[
             0.3298373627600314, 0.45968570167815315`, 0.9422534688161406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 473}], {
             RGBColor[
             0.28387386210883436`, 0.4156998060917603, 0.9394775685421287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 313}], {
             RGBColor[
             0.5362219144016962, 0.6308125527023426, 0.9580446920208532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 321}], {
             RGBColor[
             0.8483292768809738, 0.881288734461381, 0.9314462475205114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 373}], {
             RGBColor[
             0.8511114942630649, 0.882439252848601, 0.8853377053514828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 386}], {
             RGBColor[
             0.5084129263265404, 0.6064351624645463, 0.9562833697364408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 391}], {
             RGBColor[
             0.5921690661844405, 0.6787336359098497, 0.9617581155601771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 455}], {
             RGBColor[
             0.6621340048611841, 0.7355343250121988, 0.9672660118228255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 498}], {
             RGBColor[
             0.7429048622719281, 0.7990821917836863, 0.9750094718967612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 300}], {
             RGBColor[
             0.2209681235766699, 0.34958188644027033`, 0.9358951797934225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 308}], {
             RGBColor[
             0.20048868170692968`, 0.3280566945635627, 0.9347289058755601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 314}], {
             RGBColor[
             0.23644046461492338`, 0.36584429787455663`, 0.9367763067262738]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 466}], {
             RGBColor[
             0.20247960652430902`, 0.3301492827785526, 0.9348422860986005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 470}], {
             RGBColor[
             0.20234342031166005`, 0.33000614243435394`, 0.9348345304952597]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 493}], {
             RGBColor[
             0.235488823391288, 0.36484406261097735`, 0.9367221121664148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 297}], {
             RGBColor[
             0.18839455558370108`, 0.3153450011961642, 0.9340401632844985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 484}], {
             RGBColor[
             0.18316922942285135`, 0.3098528520962973, 0.9337425886898154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 349}], {
             RGBColor[
             0.1841373062547167, 0.310870362226204, 0.9337977192332487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 353}], {
             RGBColor[
             0.18189358061228061`, 0.3085120643155814, 0.9336699423772067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 394}], {
             RGBColor[
             0.18326692398746902`, 0.30995553527790365`, 0.9337481522507443]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 467}], {
             RGBColor[
             0.1871130842202519, 0.31399809354320196`, 0.933967185386117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 398}], {
             RGBColor[
             0.19568953649861287`, 0.32301248866624094`, 0.9344556016556456]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 399}], {
             RGBColor[
             0.19649944973854266`, 0.32386375883287244`, 0.9345017250165003]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 464}], {
             RGBColor[
             0.19378696997725373`, 0.3210127706226078, 0.9343472533068491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 481}], {
             RGBColor[
             0.1951943467181843, 0.32249201281016504`, 0.9344274013302178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 496}], {
             RGBColor[
             0.1854675912889076, 0.3122685761420814, 0.9338734769979656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 343}], {
             RGBColor[
             0.8279897500301316, 0.6038277857603807, 0.5867878259844261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 403}], {
             RGBColor[
             0.7765788883904609, 0.8253885969195616, 0.9783657841185909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 440}], {
             RGBColor[
             0.8506906968621433, 0.7260557976902806, 0.6064798524386981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 445}], {
             RGBColor[
             0.8864338531014064, 0.8692772537699642, 0.6464479308964578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 471}], {
             RGBColor[
             0.883292777281721, 0.9093153449162048, 0.969810151974432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 483}], {
             RGBColor[
             0.630894839609411, 0.7086289993280623, 0.9658482385387919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 497}], {
             RGBColor[
             0.6439655477048442, 0.7192750682039972, 0.9668676305891115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 296}], {
             RGBColor[
             0.18486063733978264`, 0.311630629058448, 0.9338389118684709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 327}], {
             RGBColor[
             0.18563559838764718`, 0.312445162255122, 0.9338830447536945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 385}], {
             RGBColor[
             0.18452375420061845`, 0.3112765435195617, 0.9338197268720694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 415}], {
             RGBColor[
             0.18394556991543065`, 0.3106688351768284, 0.9337868001323749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 438}], {
             RGBColor[
             0.19506692603526019`, 0.32235808559347384`, 0.9344201449108273]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 439}], {
             RGBColor[
             0.19336116609564466`, 0.3205652237455112, 0.9343230044057118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 321}], {
             RGBColor[
             0.9851155314829081, 0.988112904001859, 0.896337693305348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 341}], {
             RGBColor[
             0.9895466198460419, 0.9890958111978665, 0.7611561924651287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 391}], {
             RGBColor[
             0.7289553207863748, 0.7855578054503277, 0.9266495613450138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 397}], {
             RGBColor[
             0.9034028373173626, 0.5790815030588307, 0.5351722665672494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 455}], {
             RGBColor[
             0.7989202594631184, 0.8423584945526768, 0.9321574576076621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 327}], {
             RGBColor[
             0.1830042105599709, 0.3096794068086097, 0.9337331911096979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 339}], {
             RGBColor[
             0.18120773687102673`, 0.3077911990585188, 0.9336308845907572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 385}], {
             RGBColor[
             0.18189236637294215`, 0.30851078807304944`, 0.9336698732280726]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 415}], {
             RGBColor[
             0.18131418208775438`, 0.30790307973031616`, 0.9336369464883782]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 438}], {
             RGBColor[
             0.1924355382075839, 0.3195923301469616, 0.9342702912668306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 325}], {
             RGBColor[
             0.21444902327045198`, 0.3427298986836028, 0.9355239266751281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 392}], {
             RGBColor[
             0.21605655176504493`, 0.3444195130546133, 0.9356154730447699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 412}], {
             RGBColor[
             0.1927590864051722, 0.31993239981676747`, 0.9342887168580365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 413}], {
             RGBColor[
             0.2127862490397303, 0.34098221754113894`, 0.9354292341425425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 474}], {
             RGBColor[
             0.21238801987541464`, 0.34056365344025585`, 0.935406555580762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 484}], {
             RGBColor[
             0.1900371894005843, 0.3170715134867078, 0.934133708850311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 490}], {
             RGBColor[
             0.20561521715269282`, 0.3334450083581805, 0.9350208544851668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 335}], {
             RGBColor[
             0.2430317898200987, 0.3727721985793514, 0.9371516729457167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 409}], {
             RGBColor[
             0.26446105735967274`, 0.39529571745748016`, 0.9383720380303351]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 468}], {
             RGBColor[
             0.24859500261068126`, 0.37861948795031725`, 0.9374684896841046]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 312}], {
             RGBColor[
             0.21752114274095335`, 0.3459588910307243, 0.9356988793341796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 328}], {
             RGBColor[
             0.24152994730330735`, 0.3711936668718884, 0.9370661452361624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 399}], {
             RGBColor[
             0.22397618806162217`, 0.3527435529362591, 0.936066484615808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 407}], {
             RGBColor[
             0.2586014952958633, 0.3891369462107238, 0.9380383446392464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 448}], {
             RGBColor[
             0.2703287280609633, 0.40146301139634666`, 0.9387061931963326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 475}], {
             RGBColor[
             0.28830100074598397`, 0.41778431854565623`, 0.939823739896893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 478}], {
             RGBColor[
             0.24469356026771227`, 0.3745188246821251, 0.9372463083143392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 482}], {
             RGBColor[
             0.2862226992731482, 0.4159841982683552, 0.9396913123648138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 305}], {
             RGBColor[
             0.27120896577425085`, 0.40222097480990704`, 0.9387624442570324]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 308}], {
             RGBColor[
             0.21138383769744212`, 0.33950819430237933`, 0.9353493688912808]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 432}], {
             RGBColor[
             0.26154815956156724`, 0.39223407718328385`, 0.938206152809979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 456}], {
             RGBColor[
             0.21373738250553675`, 0.34198191911904635`, 0.9354833997863443]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 493}], {
             RGBColor[
             0.24638397938180046`, 0.376295562349794, 0.9373425751821356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 316}], {
             RGBColor[
             0.547580608865669, 0.6429772459967242, 0.9577838308857021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 336}], {
             RGBColor[
             0.6408993785116156, 0.7191341855671287, 0.9650206560001502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 388}], {
             RGBColor[
             0.4925680533292166, 0.5953281354024867, 0.9542784794926122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 436}], {
             RGBColor[
             0.5059845229884368, 0.6069488070899312, 0.9551333650755793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 346}], {
             RGBColor[
             0.343088083847486, 0.46567152269516504`, 0.9432988559850268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 370}], {
             RGBColor[
             0.23676036432994563`, 0.36618053275785845`, 0.936794524541795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 390}], {
             RGBColor[
             0.25033731885124844`, 0.38045077278838335`, 0.9375677120164789]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 422}], {
             RGBColor[
             0.22565049031831835`, 0.3545033507649412, 0.9361618336524187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 443}], {
             RGBColor[
             0.2662987639830351, 0.3972272636359636, 0.9384766927038922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 451}], {
             RGBColor[
             0.22492379054142386`, 0.35373954322399803`, 0.9361204491751804]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 379}], {
             RGBColor[
             0.8341112743268393, 0.26319977889761653`, 0.18029830085954252`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 400}], {
             RGBColor[
             0.9153331914929417, 0.6523376989650047, 0.5021363035234178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 307}], {
             RGBColor[
             0.19124101859615344`, 0.3183368142984305, 0.9342022651420929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 311}], {
             RGBColor[
             0.19034681505715081`, 0.3173969496831598, 0.9341513415734024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 337}], {
             RGBColor[
             0.1898974932161501, 0.3169246839396178, 0.9341257533592695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 423}], {
             RGBColor[
             0.1849544721508512, 0.3117292553943517, 0.9338442556221451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 427}], {
             RGBColor[
             0.18861159117236292`, 0.315573119360699, 0.9340525231401974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 433}], {
             RGBColor[
             0.1856912324704567, 0.31250363720355945`, 0.9338862130324074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 465}], {
             RGBColor[
             0.18487917380697239`, 0.31165011206074433`, 0.933839967492855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 469}], {
             RGBColor[
             0.18603078567582654`, 0.3128605291513198, 0.9339055500851292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 310}], {
             RGBColor[
             0.4776836488671362, 0.5829301850756662, 0.9531209010914763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 406}], {
             RGBColor[
             0.3635284030084348, 0.4892917640422711, 0.9443846862775205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 432}], {
             RGBColor[
             0.30089384576863576`, 0.43342166581410385`, 0.9404529542578681]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 460}], {
             RGBColor[
             0.3056141271073153, 0.43838298078417876`, 0.9407217672970755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 493}], {
             RGBColor[
             0.2857296655888689, 0.41748315098061395`, 0.9395893766300246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 331}], {
             RGBColor[
             0.2711023891418522, 0.40227617824530654`, 0.9387502520503602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 347}], {
             RGBColor[
             0.22192337354853872`, 0.3505859147270508, 0.9359495798661548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 382}], {
             RGBColor[
             0.2264199096398822, 0.3553120592559075, 0.9362056509445278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 431}], {
             RGBColor[
             0.33101101797964355`, 0.4548419980464291, 0.9425428260902121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 486}], {
             RGBColor[
             0.327052321983306, 0.4514131745442476, 0.942290581481863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 337}], {
             RGBColor[
             0.19042947914241254`, 0.31748383487797555`, 0.9341560491707674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 427}], {
             RGBColor[
             0.1891435770986254, 0.31613227029905666`, 0.9340828189516954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 433}], {
             RGBColor[
             0.18622321839671918`, 0.3130627881419171, 0.9339165088439054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 442}], {
             RGBColor[
             0.21483864965875055`, 0.34313942072144443`, 0.9355461153215412]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 469}], {
             RGBColor[
             0.186562771602089, 0.31341968008967747`, 0.9339358458966271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 500}], {
             RGBColor[
             0.19638085260421678`, 0.3237391057252033, 0.9344949710851491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 362}], {
             RGBColor[
             0.18507064546441102`, 0.3118513609127166, 0.9338508715204893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 369}], {
             RGBColor[
             0.18646563701697516`, 0.31331758548203437`, 0.9339303142257027]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 389}], {
             RGBColor[
             0.19291290556353907`, 0.320094073504909, 0.9342974766315505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 456}], {
             RGBColor[
             0.1932579406357965, 0.32045672724233865`, 0.9343171258684819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 393}], {
             RGBColor[
             0.20475589581124165`, 0.33254180714419534`, 0.9349719174060231]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 424}], {
             RGBColor[
             0.19083388775165383`, 0.3179088939672749, 0.9341790796427948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 323}], {
             RGBColor[
             0.8187613818125008, 0.8568526336781708, 0.8678541495778869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 406}], {
             RGBColor[
             0.5306573998942516, 0.6288133856772102, 0.9564963416640753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 408}], {
             RGBColor[
             0.7910483812120712, 0.837599492064294, 0.9781391837091735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 419}], {
             RGBColor[
             0.6470494829273306, 0.7241992409118212, 0.9654555035031411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 366}], {
             RGBColor[
             0.18627071422588198`, 0.31311270926977675`, 0.9339192136611123]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 405}], {
             RGBColor[
             0.18582191019465255`, 0.3126409877771355, 0.9338936549354799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 423}], {
             RGBColor[
             0.184592254538111, 0.31134854171743864`, 0.9338236278649524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 429}], {
             RGBColor[
             0.19096685764878327`, 0.3180486537599364, 0.934186652081725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 465}], {
             RGBColor[
             0.1845169561942322, 0.31126939838383133`, 0.9338193397356624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 469}], {
             RGBColor[
             0.18566856806308635`, 0.31247981547440673`, 0.9338849223279366]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 488}], {
             RGBColor[
             0.18625665477025105`, 0.3130979318904876, 0.9339184129959133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 327}], {
             RGBColor[
             0.18937402646973123`, 0.31637448719942296`, 0.9340959427024605]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 334}], {
             RGBColor[
             0.19091202731972692`, 0.3179910236076545, 0.9341835295755994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 385}], {
             RGBColor[
             0.1882621822827025, 0.31520586846386267`, 0.9340326248208353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 415}], {
             RGBColor[
             0.18768399799751473`, 0.31459816012112934`, 0.9339996980811409]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 446}], {
             RGBColor[
             0.18918799273524178`, 0.31617895394925455`, 0.9340853483564936]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 386}], {
             RGBColor[
             0.33341144011418006`, 0.4629153220183585, 0.9424763018784972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 391}], {
             RGBColor[
             0.4171675799720802, 0.5352137954636619, 0.9479510477022336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 407}], {
             RGBColor[
             0.31917500731539133`, 0.44795192850485793`, 0.9416655580915212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 498}], {
             RGBColor[
             0.5679033760595678, 0.6555623513374985, 0.9612024040388176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 406}], {
             RGBColor[
             0.3396550578396198, 0.4643665868457374, 0.9430190117624826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 411}], {
             RGBColor[
             0.27200862613590066`, 0.4032286907847955, 0.9388018609065139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 493}], {
             RGBColor[
             0.2618563204200539, 0.3925579737840803, 0.9382237021149867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 349}], {
             RGBColor[
             0.18430254906177113`, 0.31104404289341736`, 0.9338071295666557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 353}], {
             RGBColor[
             0.18205882341933505`, 0.3086857449827948, 0.9336793527106135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 364}], {
             RGBColor[
             0.19390091491665387`, 0.32113253397844377`, 0.9343537423025814]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 378}], {
             RGBColor[
             0.19518703914887203`, 0.3224843320914912, 0.934426985174956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 380}], {
             RGBColor[
             0.18543946082278231`, 0.31223900923860914`, 0.9338718750095351]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 487}], {
             RGBColor[
             0.1880750117052634, 0.3150091403196742, 0.9340219657333442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 372}], {
             RGBColor[
             0.5264921273018517, 0.6260724945913516, 0.9559761056168596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 418}], {
             RGBColor[
             0.45760917454031613`, 0.5701502103978782, 0.9505533872489015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 322}], {
             RGBColor[
             0.8190506229224375, 0.1474370125838577, 0.16587620406611453`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 343}], {
             RGBColor[
             0.8317748059838278, 0.24524065936627398`, 0.17806089613561116`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 374}], {
             RGBColor[
             0.832381649136102, 0.24990512175501872`, 0.1786420098235603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 440}], {
             RGBColor[
             0.8544757528158395, 0.36746867129617394`, 0.19775292258988314`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 445}], {
             RGBColor[
             0.8902189090551026, 0.5106901273758575, 0.23772100104764282`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 471}], {
             RGBColor[
             0.8870778332354172, 0.5507282185220981, 0.561083222125617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 335}], {
             RGBColor[
             0.2041779627078255, 0.33193436280942984`, 0.9349390049707589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 421}], {
             RGBColor[
             0.19115878724665003`, 0.3182503839363337, 0.9341975821883891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 430}], {
             RGBColor[
             0.1997685243379237, 0.32729976350812295`, 0.9346878939787725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 459}], {
             RGBColor[
             0.1962304097370451, 0.3235809807331772, 0.934486403586424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 330}], {
             RGBColor[
             0.18522178171588122`, 0.3120102146956035, 0.9338594785064245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 357}], {
             RGBColor[
             0.18470360051772483`, 0.3114655734017556, 0.9338299688537698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 368}], {
             RGBColor[
             0.18004736950714773`, 0.30657157938754187`, 0.9335648033859939]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 492}], {
             RGBColor[
             0.18173579190696668`, 0.3083462183819148, 0.9336609565438665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 329}], {
             RGBColor[
             0.18135868640525998`, 0.3079498565897512, 0.9336394809434219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 424}], {
             RGBColor[
             0.18730513840807234`, 0.31419995467154005`, 0.9339781225879946]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 341}], {
             RGBColor[
             0.9898662415110249, 0.9892279829702391, 0.7558592343220067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 373}], {
             RGBColor[
             0.9882173705299822, 0.9893955941614516, 0.8449321929931977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 391}], {
             RGBColor[
             0.7292749424513578, 0.7856899772227003, 0.9213526032018919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 397}], {
             RGBColor[
             0.9037224589823456, 0.5792136748312032, 0.5298753084241274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 455}], {
             RGBColor[
             0.7992398811281014, 0.8424906663250493, 0.9268604994645402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 498}], {
             RGBColor[
             0.8800107385388454, 0.9060385330965369, 0.934603959538476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 343}], {
             RGBColor[
             0.8335064289062653, 0.2585506719501317, 0.17971910020172568`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 374}], {
             RGBColor[
             0.8341132720585396, 0.26321513433887644`, 0.18030021388967482`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 440}], {
             RGBColor[
             0.8562073757382771, 0.38077868388003167`, 0.19941112665599764`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 445}], {
             RGBColor[
             0.89195053197754, 0.5240001399597152, 0.23937920511375732`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 471}], {
             RGBColor[
             0.8888094561578547, 0.5640382311059557, 0.5627414261917315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 419}], {
             RGBColor[
             0.8209982189868783, 0.8586000678793866, 0.8680770966029969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 449}], {
             RGBColor[
             0.9881583833202512, 0.9738084894895631, 0.5806455490390734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 499}], {
             RGBColor[
             0.8106414871808013, 0.8502981241426343, 0.8671892234801464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 342}], {
             RGBColor[
             0.7080228667800735, 0.7701523632700238, 0.969408565667581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 360}], {
             RGBColor[
             0.7679481729777577, 0.8188024264455834, 0.9741261052850922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 457}], {
             RGBColor[
             0.7044919829810323, 0.7672858327374596, 0.9691306015608669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 392}], {
             RGBColor[
             0.23524305947406288`, 0.3645857491516413, 0.9367081162749039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 413}], {
             RGBColor[
             0.23197275674874823`, 0.36114845363816694`, 0.9365218773726766]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 474}], {
             RGBColor[
             0.2315745275844326, 0.3607298895372839, 0.936499198810896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 490}], {
             RGBColor[
             0.22480172486171077`, 0.3536112444552085, 0.9361134977153007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 338}], {
             RGBColor[
             0.5748571876552486, 0.6636751524188924, 0.9607610097179233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 346}], {
             RGBColor[
             0.5833986733777301, 0.6710733580441507, 0.9613052656352206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 355}], {
             RGBColor[
             0.642545935987291, 0.7194149561297569, 0.9658722576270347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 395}], {
             RGBColor[
             0.6147615284118504, 0.6968583223867169, 0.9636849672850575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 443}], {
             RGBColor[
             0.5066093535132791, 0.6026290989849493, 0.956483102354086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 334}], {
             RGBColor[
             0.18531717245783108`, 0.3121104764135153, 0.9338649108680606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 385}], {
             RGBColor[
             0.18266732742080666`, 0.30932532126972345`, 0.9337140061132965]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 415}], {
             RGBColor[
             0.1820891431356189, 0.3087176129269901, 0.9336810793736019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 446}], {
             RGBColor[
             0.18359313787334597`, 0.31029840675511533`, 0.9337667296489547]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 398}], {
             RGBColor[
             0.2246228179747201, 0.35342320197362953`, 0.9361033092327558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 399}], {
             RGBColor[
             0.22543273121464985`, 0.354274472140261, 0.9361494325936104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 407}], {
             RGBColor[
             0.26005803844889097`, 0.3906678654147257, 0.9381212926170488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 464}], {
             RGBColor[
             0.22272025145336094`, 0.35142348392999634`, 0.9359949608839593]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 475}], {
             RGBColor[
             0.28975754389901165`, 0.4193152377496582, 0.9399066878746956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 478}], {
             RGBColor[
             0.24615010342073995`, 0.376049743886127, 0.9373292562921416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 481}], {
             RGBColor[
             0.22412762819429155`, 0.3529027261175536, 0.9360751089073279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 333}], {
             RGBColor[
             0.210684466253447, 0.33877311057202975`, 0.9353095407221728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 352}], {
             RGBColor[
             0.1864863756783814, 0.3133393831300794, 0.9339314952617896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 357}], {
             RGBColor[
             0.18906252050836794`, 0.3160470746834114, 0.9340782028987926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 358}], {
             RGBColor[
             0.20723187960885475`, 0.33514422310192665`, 0.9351129210204074]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 367}], {
             RGBColor[
             0.19336515666501655`, 0.3205694180869378, 0.9343232316627341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 368}], {
             RGBColor[
             0.18440628949779087`, 0.3111530806691976, 0.9338130374310167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 441}], {
             RGBColor[
             0.20552414062024876`, 0.33334928114799606`, 0.9350156678113797]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 492}], {
             RGBColor[
             0.1860947118976098, 0.3129277196635705, 0.9339091905888894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 348}], {
             RGBColor[
             0.3817575877124325, 0.5041670701523192, 0.9456367228639543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 372}], {
             RGBColor[
             0.4578529646135995, 0.56594472517835, 0.9516272296801642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 382}], {
             RGBColor[
             0.25675225340899854`, 0.38719327573892137`, 0.9379330330494976]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 404}], {
             RGBColor[
             0.5691308396856145, 0.6534422515230649, 0.9623880647122928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 418}], {
             RGBColor[
             0.38897001185206387`, 0.5100224409848767, 0.9462045113122062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 431}], {
             RGBColor[
             0.3613433617487599, 0.48672321452944306`, 0.9442702081951819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 444}], {
             RGBColor[
             0.43364941819134256`, 0.5462951958354212, 0.9497218378452923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 486}], {
             RGBColor[
             0.35738466575242234`, 0.48329439102726157`, 0.9440179635868327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 420}], {
             RGBColor[
             0.1873361545684642, 0.31423255462265, 0.9339798889124447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 454}], {
             RGBColor[
             0.19901001769354992`, 0.3265025249327872, 0.9346446981474854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 489}], {
             RGBColor[
             0.1891243849825443, 0.31611209816820496`, 0.9340817259890768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 358}], {
             RGBColor[
             0.22833564415577742`, 0.35732561769669713`, 0.9363147491911328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 361}], {
             RGBColor[
             0.2309444912286668, 0.3600676813807619, 0.9364633191724905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 367}], {
             RGBColor[
             0.21446892121193922`, 0.34275081268170826`, 0.9355250598334595]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 386}], {
             RGBColor[
             0.268695341419697, 0.3997462184736812, 0.9386131742434916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 441}], {
             RGBColor[
             0.2266279051671714, 0.35553067574276653`, 0.936217495982105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 450}], {
             RGBColor[
             0.22365738515605757`, 0.35240847086923904`, 0.9360483292619628]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 461}], {
             RGBColor[
             0.24252993321129454`, 0.3722447154639515, 0.9371230929542755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 385}], {
             RGBColor[
             0.18420532827080235`, 0.310941857677955, 0.9338015929864353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 415}], {
             RGBColor[
             0.18362714398561458`, 0.31033414933522163`, 0.9337686662467408]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 446}], {
             RGBColor[
             0.18513113872334164`, 0.31191494316334684`, 0.9338543165220936]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 409}], {
             RGBColor[
             0.23180434544224413`, 0.3609714426771376, 0.9365122865979134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 421}], {
             RGBColor[
             0.19735590244149465`, 0.3247639449259127, 0.9345504987309252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 430}], {
             RGBColor[
             0.2059656395327683, 0.33381332449770196`, 0.9350408105213086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 459}], {
             RGBColor[
             0.2024275249318897, 0.3300945417227562, 0.93483932012896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 354}], {
             RGBColor[
             0.4679691659715405, 0.5750820152163606, 0.9523301949713454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 388}], {
             RGBColor[
             0.4770192723969674, 0.5829207625304905, 0.9529068597500787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 436}], {
             RGBColor[
             0.49043574205618756`, 0.5945414342179349, 0.953761745333046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 420}], {
             RGBColor[
             0.18856527989536503`, 0.3155244432722696, 0.9340498857814837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 427}], {
             RGBColor[
             0.18780005171862202`, 0.314720139940244, 0.9340063071688718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 433}], {
             RGBColor[
             0.1848796930167158, 0.31165065778310447`, 0.9338399970610818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 500}], {
             RGBColor[
             0.1950373272242134, 0.32232697536639066`, 0.9344184593023257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 383}], {
             RGBColor[
             0.34605340544318985`, 0.47036770113504156`, 0.9434098957217043]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 395}], {
             RGBColor[
             0.4642366864681818, 0.5751402530845398, 0.9511830173068838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 443}], {
             RGBColor[
             0.3560845115696105, 0.4809110296827722, 0.9439811523759123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 480}], {
             RGBColor[
             0.3338467491074454, 0.4575377313794614, 0.9427147447015134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 344}], {
             RGBColor[
             0.1852310273425353, 0.3120199324354236, 0.9338600050311847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 387}], {
             RGBColor[
             0.1845385025539545, 0.3112920449740175, 0.9338205667689736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 439}], {
             RGBColor[
             0.18970826562688875`, 0.316725793745582, 0.9341149771279982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 384}], {
             RGBColor[
             0.3159339914529744, 0.4443075647988586, 0.9414896959063039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 414}], {
             RGBColor[
             0.3932297908847611, 0.5150176133855842, 0.946277232449094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 461}], {
             RGBColor[
             0.30853231078714655`, 0.43652792912541416`, 0.9410681811421904]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 499}], {
             RGBColor[
             0.4961829212208138, 0.5994318600646289, 0.9541521247756388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 374}], {
             RGBColor[
             0.9208708140731814, 0.677947066838142, 0.406871876564454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 391}], {
             RGBColor[
             0.7337060308144916, 0.7866728844187078, 0.7861711023616725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 397}], {
             RGBColor[
             0.9081535473454794, 0.5801965820272107, 0.39469380758390815`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 455}], {
             RGBColor[
             0.8036709694912352, 0.8434735735210568, 0.7916789986243209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 485}], {
             RGBColor[
             0.36582891890395064`, 0.48572268889805037`, 0.9448845663511518]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 374}], {
             RGBColor[
             0.8468374551199298, 0.3610187811212927, 0.19248490595917145`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 403}], {
             RGBColor[
             0.7948197503279848, 0.5779151298917289, 0.5834817504053871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 440}], {
             RGBColor[
             0.8689315587996673, 0.47858233066244793`, 0.21159581872549427`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 445}], {
             RGBColor[
             0.9046747150389304, 0.6218037867421315, 0.25156389718325395`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 471}], {
             RGBColor[
             0.901533639219245, 0.661841877888372, 0.5749261182612281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 387}], {
             RGBColor[
             0.1895833056665427, 0.31659445290433924`, 0.9341078608431181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 438}], {
             RGBColor[
             0.19645882867909248`, 0.32382106352386636`, 0.934499411707258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 439}], {
             RGBColor[
             0.19475306873947695`, 0.32202820167590374`, 0.9344022712021427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 389}], {
             RGBColor[
             0.1928812337006961, 0.3200607843689489, 0.9342956729658158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 456}], {
             RGBColor[
             0.1932262687729535, 0.32042343810637863`, 0.9343153222027473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 472}], {
             RGBColor[
             0.1869884495343811, 0.3138670945860562, 0.9339600876251372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 355}], {
             RGBColor[
             0.5005625797661037, 0.605095092452838, 0.9539145635661582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 390}], {
             RGBColor[
             0.34866455216030523`, 0.47153274446045024`, 0.9436164276057963]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 395}], {
             RGBColor[
             0.47277817219066315`, 0.5825384587097979, 0.951727273224181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 431}], {
             RGBColor[
             0.43133365387154704`, 0.5480212643488988, 0.948705176904689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 443}], {
             RGBColor[
             0.3646259972920919, 0.4883092353080305, 0.9445254082932095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 486}], {
             RGBColor[
             0.4273749578752095, 0.5445924408467173, 0.9484529322963398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 382}], {
             RGBColor[
             0.2075732378156851, 0.3355030122206657, 0.9351323608652922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 462}], {
             RGBColor[
             0.19657186081581016`, 0.32393986746620806`, 0.934505848720228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 355}], {
             RGBColor[
             0.5108951424447806, 0.6138067180573811, 0.9546386835652754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 372}], {
             RGBColor[
             0.5381758194150634, 0.6359544006023488, 0.9567863183887886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 400}], {
             RGBColor[
             0.7259744000228323, 0.7821275326457193, 0.8841834386643934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 404}], {
             RGBColor[
             0.6494536944870786, 0.7234519269470636, 0.967547153420917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 418}], {
             RGBColor[
             0.4692928666535278, 0.5800321164088754, 0.9513636000208304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 431}], {
             RGBColor[
             0.44166621655022387`, 0.5567328899534418, 0.9494292969038062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 444}], {
             RGBColor[
             0.5139722729928065, 0.6163048712594199, 0.9548809265539167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 486}], {
             RGBColor[
             0.4377075205538863, 0.5533040664512603, 0.949177052295457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 353}], {
             RGBColor[
             0.18295144203234145`, 0.3096239437403533, 0.9337301860201135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 378}], {
             RGBColor[
             0.1960796577618784, 0.3234225308490497, 0.9344778184844558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 380}], {
             RGBColor[
             0.18633207943578872`, 0.3131772079961678, 0.9339227083190349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 487}], {
             RGBColor[
             0.1889676303182698, 0.3159473390772327, 0.9340727990428441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 377}], {
             RGBColor[
             0.181157971499196, 0.3077388924974179, 0.9336280505264527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 412}], {
             RGBColor[
             0.18588998404715956`, 0.3127125377122519, 0.9338975316406739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 426}], {
             RGBColor[
             0.1844406280385869, 0.3111891726527635, 0.9338149929601158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 476}], {
             RGBColor[
             0.18247717121909524`, 0.3091254550451252, 0.9337031769989198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 371}], {
             RGBColor[
             0.2471362919389416, 0.37708629054672044`, 0.937385418269318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 442}], {
             RGBColor[
             0.23904734061072216`, 0.3685842898316257, 0.936924764457707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 460}], {
             RGBColor[
             0.2704319943298352, 0.4015715507923906, 0.9387120740575761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 357}], {
             RGBColor[
             0.185968194480225, 0.3127947418362315, 0.9339019856091351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 367}], {
             RGBColor[
             0.1902708306368736, 0.3173170852397579, 0.9341470143730765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 368}], {
             RGBColor[
             0.1813119634696479, 0.3079007478220177, 0.9336368201413592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 375}], {
             RGBColor[
             0.19306738802691092`, 0.32025644436866674`, 0.9343062741793031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 380}], {
             RGBColor[
             0.18408835379335264`, 0.31081891008554513`, 0.9337949314629927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 487}], {
             RGBColor[
             0.18672390467583372`, 0.3135890411666101, 0.933945022186802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 388}], {
             RGBColor[
             0.3196378407891415, 0.45127596505171874`, 0.9415880184638075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 409}], {
             RGBColor[
             0.28191067367276634`, 0.4134660896464276, 0.9393720026838029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 436}], {
             RGBColor[
             0.33305431044836165`, 0.46289663673916315`, 0.9424429040467747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 473}], {
             RGBColor[
             0.28709080979716467`, 0.41891074115277027`, 0.9396670037727628]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 395}], {
             RGBColor[
             0.5319254348002241, 0.6308800567954042, 0.9562942652159951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 404}], {
             RGBColor[
             0.6982683944179626, 0.7630818994281268, 0.9713900254136139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 431}], {
             RGBColor[
             0.49048091648110803`, 0.596362862434505, 0.9532721688965031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 443}], {
             RGBColor[
             0.4237732599016528, 0.5366508333936366, 0.9490924002850236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 444}], {
             RGBColor[
             0.5627869729236907, 0.655934843740483, 0.9587237985466135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 486}], {
             RGBColor[
             0.48652222048477045`, 0.5929340389323234, 0.9530199242881539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 365}], {
             RGBColor[
             0.2261799618783253, 0.3550598589449443, 0.9361919862744781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 457}], {
             RGBColor[
             0.35728371097557365`, 0.477585785779042, 0.9443210439032999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 494}], {
             RGBColor[
             0.30030937836549265`, 0.4286701061729542, 0.9405711545959381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 367}], {
             RGBColor[
             0.19284697546686017`, 0.3200247767930899, 0.9342937220100794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 368}], {
             RGBColor[
             0.18388810829963448`, 0.3106084393753497, 0.9337835277783622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 441}], {
             RGBColor[
             0.20500595942209238`, 0.33280463985414815`, 0.9349861581587251]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 492}], {
             RGBColor[
             0.1855765306994534, 0.3123830783697226, 0.9338796809362347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 361}], {
             RGBColor[
             0.2274919045840746, 0.3564387939106588, 0.9362666994707252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 386}], {
             RGBColor[
             0.2652427547751048, 0.39611733100357804`, 0.9384165545417262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 398}], {
             RGBColor[
             0.21557110150214517`, 0.3439092740489813, 0.935587827370457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 441}], {
             RGBColor[
             0.22317531852257919`, 0.3519017882726634, 0.9360208762803397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 408}], {
             RGBColor[
             0.923405109023163, 0.9417213092494618, 0.9911392082523272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 440}], {
             RGBColor[
             0.9005793035034079, 0.7657528918366445, 0.6112602253720522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 463}], {
             RGBColor[
             0.7323426131107887, 0.7902188270608363, 0.9746779559842911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 483}], {
             RGBColor[
             0.6807834462506754, 0.7483260934744262, 0.970628611472146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 457}], {
             RGBColor[
             0.5327073882194472, 0.6315148818077295, 0.9563558234535461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 494}], {
             RGBColor[
             0.4757330556093662, 0.5825992022016417, 0.9526059341461844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 386}], {
             RGBColor[
             0.26785160184799417`, 0.39885939468764287`, 0.9385651245230838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 398}], {
             RGBColor[
             0.21817994857503456`, 0.3466513377330461, 0.9357363973518147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 441}], {
             RGBColor[
             0.22578416559546857`, 0.3546438519567282, 0.9361694462616974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 481}], {
             RGBColor[
             0.217684758794606, 0.34613086187697023`, 0.935708197026387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 369}], {
             RGBColor[
             0.1806318866536843, 0.30718594396907933`, 0.9335980907727736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 470}], {
             RGBColor[
             0.1869253840691414, 0.31380080878350786`, 0.9339564961401887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 381}], {
             RGBColor[
             0.18545627477246146`, 0.3122566817657879, 0.9338728325390953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 378}], {
             RGBColor[
             0.20567802361676119`, 0.3335110219340761, 0.9350244312203816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 380}], {
             RGBColor[
             0.19593044529067147`, 0.3232656990811941, 0.9344693210549606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 381}], {
             RGBColor[
             0.19634549402636683`, 0.3237019416180197, 0.9344929574664489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 416}], {
             RGBColor[
             0.20681043357905127`, 0.33470125660338146`, 0.9350889202924836]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 452}], {
             RGBColor[
             0.21560011293675418`, 0.34393976690618655`, 0.9355894795287394]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 468}], {
             RGBColor[
             0.21294670143418915`, 0.3411508631809846, 0.9354383716690389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 487}], {
             RGBColor[
             0.19856599617315254`, 0.3260358301622591, 0.9346194117787698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 405}], {
             RGBColor[
             0.18210802697612394`, 0.3087374610406655, 0.9336821547803826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 423}], {
             RGBColor[
             0.18087837131958237`, 0.30744501498096866`, 0.933612127709855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 429}], {
             RGBColor[
             0.18725297443025463`, 0.3141451270234664, 0.9339751519266276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 465}], {
             RGBColor[
             0.18080307297570358`, 0.30736587164736134`, 0.9336078395805651]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 469}], {
             RGBColor[
             0.1819546848445577, 0.30857628873793674`, 0.9336734221728392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 488}], {
             RGBColor[
             0.1825427715517224, 0.30919440515401764`, 0.933706912840816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 368}], {
             RGBColor[
             0.1881907444562831, 0.3151307827788761, 0.9340285565423035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 375}], {
             RGBColor[
             0.19994616901354612`, 0.3274864793255251, 0.9346980105802476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 441}], {
             RGBColor[
             0.20930859557874099`, 0.3373269832576745, 0.9352311869226664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 450}], {
             RGBColor[
             0.20633807556762712`, 0.3342047783841471, 0.9350620202025242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 492}], {
             RGBColor[
             0.18092029968887635`, 0.3074890843555088, 0.9336145154684589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 456}], {
             RGBColor[
             0.1888191818250698, 0.31579131029870144`, 0.9340643451207662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 390}], {
             RGBColor[
             0.24233683264276484`, 0.3720417545231436, 0.9371120961625645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 422}], {
             RGBColor[
             0.21765000410983476`, 0.3460943324997014, 0.9357062177985042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 443}], {
             RGBColor[
             0.2582982777745515, 0.38881824537072385`, 0.9380210768499777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 451}], {
             RGBColor[
             0.21692330433294027`, 0.34533052495875827`, 0.935664833321266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 442}], {
             RGBColor[
             0.24599324612330464`, 0.37588487692119543`, 0.9373203235011023]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 460}], {
             RGBColor[
             0.2773778998424177, 0.4088721378819603, 0.9391076331009713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 400}], {
             RGBColor[
             0.8020697769239993, 0.8439051876717503, 0.8901739454806034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 404}], {
             RGBColor[
             0.7255490713882455, 0.7852295819730946, 0.9735376602371271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 418}], {
             RGBColor[
             0.5453882435546948, 0.6418097714349063, 0.9573541068370404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 431}], {
             RGBColor[
             0.5177615934513908, 0.6185105449794727, 0.9554198037200161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 444}], {
             RGBColor[
             0.5900676498939734, 0.6780825262854508, 0.9608714333701266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 486}], {
             RGBColor[
             0.5138028974550533, 0.6150817214772912, 0.955167559111667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 449}], {
             RGBColor[
             0.9873031183402635, 0.9734548154410307, 0.5948195031122866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 498}], {
             RGBColor[
             0.8827929559209364, 0.907189051483757, 0.8884954173694475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 397}], {
             RGBColor[
             0.8347270315445021, 0.26793275869910615`, 0.18088795066657473`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 445}], {
             RGBColor[
             0.9052815581912046, 0.6264682491308763, 0.2521450108712031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 402}], {
             RGBColor[
             0.21043597475918854`, 0.33851193025629345`, 0.9352953894991849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 417}], {
             RGBColor[
             0.1999369421366619, 0.32747678129290203`, 0.9346974851232589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 441}], {
             RGBColor[
             0.2121051529687783, 0.3402663423865834, 0.9353904467288932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 450}], {
             RGBColor[
             0.20913463295766446`, 0.3371441375130559, 0.9352212800087508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 461}], {
             RGBColor[
             0.22800718101290143`, 0.35698038210776833`, 0.9362960437010637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 391}], {
             RGBColor[
             0.4221118184289103, 0.5394962463103177, 0.9482660902046844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 448}], {
             RGBColor[
             0.33584647853732147`, 0.4645604445371366, 0.9426484491510583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 455}], {
             RGBColor[
             0.4920767571056538, 0.5962969354126668, 0.9537739864673327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 475}], {
             RGBColor[
             0.3538187512223421, 0.4808817516864462, 0.9437659958516187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 482}], {
             RGBColor[
             0.35174044974950636`, 0.47908163140914517`, 0.9436335683195394]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 412}], {
             RGBColor[
             0.18552364470094684`, 0.3123274918321262, 0.9338766691568576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 426}], {
             RGBColor[
             0.1840742886923742, 0.31080412677263786`, 0.9337941304762996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 476}], {
             RGBColor[
             0.18211083187288252`, 0.3087404091649995, 0.9336823145151034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 380}], {
             RGBColor[
             0.19721656952288963`, 0.32461749719424154`, 0.9345425639273353]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 416}], {
             RGBColor[
             0.2080965578112694, 0.3360530547164289, 0.9351621631648581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 452}], {
             RGBColor[
             0.21688623716897232`, 0.34529156501923397`, 0.935662722401114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 487}], {
             RGBColor[
             0.1998521204053707, 0.32738762827530654`, 0.9346926546511444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 400}], {
             RGBColor[
             0.9086464403656656, 0.6009403996477325, 0.49573306309233295`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 404}], {
             RGBColor[
             0.8321257348299118, 0.5422647939490768, 0.5790967778488565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 440}], {
             RGBColor[
             0.8595285144156211, 0.406306411086346, 0.20259145280411195`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 487}], {
             RGBColor[
             0.19010454207928099`, 0.31714230542242455`, 0.9341375444857234]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 416}], {
             RGBColor[
             0.19876402822087508`, 0.3262439744003725, 0.9346306894109254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 468}], {
             RGBColor[
             0.20490029607601296`, 0.33269358097797563`, 0.9349801407874807]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 425}], {
             RGBColor[
             0.19937423959475875`, 0.32688534524395996`, 0.9346654400459413]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 462}], {
             RGBColor[
             0.20106839690715364`, 0.3286660119950647, 0.934761919798601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 393}], {
             RGBColor[
             0.24454516184141023`, 0.374362848527078, 0.9372378572434972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 395}], {
             RGBColor[
             0.3859577461997916, 0.503550871102866, 0.9463338532888385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 443}], {
             RGBColor[
             0.2778055713012203, 0.40932164770109847`, 0.9391319883578669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 480}], {
             RGBColor[
             0.2555678088390552, 0.3859483493977877, 0.937865580683468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 402}], {
             RGBColor[
             0.24310211003433443`, 0.3728461095830723, 0.937155677577888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 411}], {
             RGBColor[
             0.2746421437909936, 0.40599668481496154`, 0.9389518358410311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 458}], {
             RGBColor[
             0.25354859204463764`, 0.3838260245211157, 0.9377505892741895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 461}], {
             RGBColor[
             0.26067331628804735`, 0.3913145614345472, 0.9381563317797668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 499}], {
             RGBColor[
             0.4483239267217146, 0.554218492373762, 0.9512402754132152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 415}], {
             RGBColor[
             0.18097729894859016`, 0.30754899419142984`, 0.9336177614919767]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 446}], {
             RGBColor[
             0.18248129368631721`, 0.30912978801955504`, 0.9337034117673295]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 441}], {
             RGBColor[
             0.26353501578649874`, 0.39432238904964745`, 0.9383193013326985]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 498}], {
             RGBColor[
             0.540094387984412, 0.6311849610997022, 0.9594410817544053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 439}], {
             RGBColor[
             0.1940605439508961, 0.3213003142144977, 0.9343628329399316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 436}], {
             RGBColor[
             0.34210441687378856`, 0.470735384053293, 0.943019568825508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 473}], {
             RGBColor[
             0.2961409162225916, 0.4267494884669002, 0.9402436685514961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 456}], {
             RGBColor[
             0.1952664503716337, 0.322567798321576, 0.9344315075266139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 472}], {
             RGBColor[
             0.18902863113306126`, 0.3160114548012536, 0.9340762729490037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 422}], {
             RGBColor[
             0.23122695863113757`, 0.36036457253022636`, 0.9364794052731881]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 443}], {
             RGBColor[
             0.2718752322958543, 0.4030884854012488, 0.9387942643246616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 451}], {
             RGBColor[
             0.23050025885424308`, 0.3596007649892832, 0.93643802079595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 407}], {
             RGBColor[
             0.3751221590981358, 0.49587301171236503`, 0.9453789816308452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 448}], {
             RGBColor[
             0.38684939186323586`, 0.5081990768979878, 0.9460468301879315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 455}], {
             RGBColor[
             0.5430796704315681, 0.6399355677735181, 0.9571723675042059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 475}], {
             RGBColor[
             0.40482166454825647`, 0.5245203840472975, 0.9471643768884919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 478}], {
             RGBColor[
             0.36121422406998477`, 0.4812548901837663, 0.9445869453059381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 482}], {
             RGBColor[
             0.4027433630754207, 0.5227202637699965, 0.9470319493564127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 413}], {
             RGBColor[
             0.23358028524334118`, 0.3628380680091775, 0.9366134237423184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 473}], {
             RGBColor[
             0.2502222365996353, 0.3803298140453018, 0.9375611582524985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 474}], {
             RGBColor[
             0.23318205607902553`, 0.3624195039082944, 0.9365907451805379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 490}], {
             RGBColor[
             0.2264092533563037, 0.355300858826219, 0.9362050440849425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 424}], {
             RGBColor[
             0.20739385044843295`, 0.3353144647238677, 0.935122145020107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 480}], {
             RGBColor[
             0.23233850550566576`, 0.36153287877149787`, 0.9365427062233063]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 467}], {
             RGBColor[
             0.18730056337306505`, 0.3141951460196734, 0.9339778620465191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 443}], {
             RGBColor[
             0.39598885232621217`, 0.5140941996505966, 0.9469051099430464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 430}], {
             RGBColor[
             0.19949732248348956`, 0.32701471316392194`, 0.9346724494343697]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 477}], {
             RGBColor[
             0.19761610506605493`, 0.32503743438212485`, 0.9345653168854586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 495}], {
             RGBColor[
             0.8540509182502993, 0.3729173999622112, 0.19768732648561016`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 399}], {
             RGBColor[
             0.2070690587330349, 0.3349730880380002, 0.9351036486124014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 464}], {
             RGBColor[
             0.20435657897174597`, 0.33212209982773555`, 0.9349491769027501]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 481}], {
             RGBColor[
             0.20576395571267658`, 0.3336013420152928, 0.9350293249261188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 496}], {
             RGBColor[
             0.19603720028339988`, 0.32337790534720917`, 0.9344754005938667]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 407}], {
             RGBColor[
             0.2425042792072058, 0.3722177514790964, 0.9371216319966944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 464}], {
             RGBColor[
             0.20516649221167577`, 0.332973369994367, 0.9349953002636049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 478}], {
             RGBColor[
             0.22859634417905478`, 0.3575996299504977, 0.9363295956717873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 481}], {
             RGBColor[
             0.20657386895260635`, 0.3344526121819243, 0.9350754482869736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 496}], {
             RGBColor[
             0.19684711352332962`, 0.3242291755138407, 0.9345215239547214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 404}], {
             RGBColor[
             0.9133476519960143, 0.9314027140164651, 0.9009347805127319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 418}], {
             RGBColor[
             0.7331868241624636, 0.7879829034782768, 0.8847512271126452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 431}], {
             RGBColor[
             0.7055601740591597, 0.7646836770228431, 0.882816923995621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 444}], {
             RGBColor[
             0.7778662305017423, 0.8242556583288213, 0.8882685536457314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 428}], {
             RGBColor[
             0.18425068425914937`, 0.3109895296974434, 0.9338041759428735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 437}], {
             RGBColor[
             0.18132345879022535`, 0.30791283013279, 0.9336374747828603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 451}], {
             RGBColor[
             0.192907026989333, 0.3200878947506953, 0.934297141855446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 417}], {
             RGBColor[
             0.20763019049226705`, 0.33556287309476157`, 0.9351356042359695]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 458}], {
             RGBColor[
             0.2285757051250969, 0.3575779369961964, 0.9363284203081972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 461}], {
             RGBColor[
             0.23570042936850655`, 0.3650664739096279, 0.9367341628137743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 440}], {
             RGBColor[
             0.8175206971599966, 0.7001431418216288, 0.6031737768596591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 445}], {
             RGBColor[
             0.8532638533992596, 0.8433645979013125, 0.6431418553174187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 471}], {
             RGBColor[
             0.8501227775795742, 0.8834026890475528, 0.9665040763953929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 483}], {
             RGBColor[
             0.5977248399072642, 0.6827163434594106, 0.9625421629597528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 497}], {
             RGBColor[
             0.6107955480026974, 0.6933624123353453, 0.9635615550100725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 418}], {
             RGBColor[
             0.6566661186267099, 0.7293072977796211, 0.9681149418691689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 431}], {
             RGBColor[
             0.629039468523406, 0.7060080713241875, 0.9661806387521447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 444}], {
             RGBColor[
             0.7013455249659886, 0.7655800526301657, 0.9716322684022551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 486}], {
             RGBColor[
             0.6250807725270684, 0.7025792478220061, 0.9659283941437955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 423}], {
             RGBColor[
             0.18042956728835297`, 0.30697329348832747`, 0.9335865689842227]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 429}], {
             RGBColor[
             0.1868041703990252, 0.3136734055308251, 0.9339495932009951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 472}], {
             RGBColor[
             0.1823975349558204, 0.3090417522831926, 0.9336986418315376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 488}], {
             RGBColor[
             0.182093967520493, 0.30872268366137645`, 0.9336813541151835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 419}], {
             RGBColor[
             0.5328942370686292, 0.630560819878426, 0.9567192886891854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 493}], {
             RGBColor[
             0.33870341661598447`, 0.4633663515821581, 0.9429648172026237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 448}], {
             RGBColor[
             0.28885681920654693`, 0.42093720993918393`, 0.9397613405772192]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 455}], {
             RGBColor[
             0.44508709777487926`, 0.5526737008147141, 0.9508868778934936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 475}], {
             RGBColor[
             0.3068290918915676, 0.4372585170884935, 0.9408788872777796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 478}], {
             RGBColor[
             0.2632216514132959, 0.39399302322496244`, 0.9383014556952256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 482}], {
             RGBColor[
             0.3047507904187318, 0.43545839681119247`, 0.9407464597457003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{408, 463}], {
             RGBColor[
             0.746221620758815, 0.8012446952293572, 0.9745845586722801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 430}], {
             RGBColor[
             0.22739490707234228`, 0.3563368433758307, 0.9362611756059269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 422}], {
             RGBColor[
             0.19439415698617535`, 0.3216509626668643, 0.9343818317087544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 428}], {
             RGBColor[
             0.18501111447909718`, 0.3117887900726693, 0.9338474813189439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 437}], {
             RGBColor[
             0.1820838890101732, 0.30871209050801585`, 0.9336807801589306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{412, 426}], {
             RGBColor[
             0.18880630124033773`, 0.3157777719874718, 0.9340636115905208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{412, 476}], {
             RGBColor[
             0.18684284442084606`, 0.31371405437983346`, 0.9339517956293248]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 474}], {
             RGBColor[
             0.2299117533537109, 0.35898220839482003`, 0.9364045062783105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 490}], {
             RGBColor[
             0.2231389506309891, 0.3518635633127446, 0.9360188051827152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 461}], {
             RGBColor[
             0.337969115719834, 0.4620246100212727, 0.9429438683225567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 498}], {
             RGBColor[
             0.5986264598736242, 0.6821731423501425, 0.9631600517720931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 499}], {
             RGBColor[
             0.5256197261535013, 0.6249285409604874, 0.9560278119560052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 452}], {
             RGBColor[
             0.2180186471312624, 0.3464817996885393, 0.935727211473216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 468}], {
             RGBColor[
             0.21536523562869736`, 0.3436928959633374, 0.9355761036135155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{417, 458}], {
             RGBColor[
             0.21807667250257026`, 0.34654278803280497`, 0.9357305159322711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 431}], {
             RGBColor[
             0.4488786406898552, 0.5625882607859993, 0.9499970853520581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 444}], {
             RGBColor[
             0.5211846971324379, 0.6221602420919774, 0.9554487150021684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 486}], {
             RGBColor[
             0.4449199446935177, 0.5591594372838178, 0.9497448407437088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 427}], {
             RGBColor[
             0.1872793778515779, 0.31417287869335075`, 0.9339766555624116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 454}], {
             RGBColor[
             0.19971846915340663`, 0.3272471523355135, 0.9346850434100643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 489}], {
             RGBColor[
             0.189832836442401, 0.3168567255709313, 0.9341220712516556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 500}], {
             RGBColor[
             0.19451665335716928`, 0.32177971411949735`, 0.9343888076958655]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 430}], {
             RGBColor[
             0.19294646407159283`, 0.3201293456246058, 0.9342993877389387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 459}], {
             RGBColor[
             0.18940834947071425`, 0.31641056284966007`, 0.9340978973465902]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 477}], {
             RGBColor[
             0.1910652466541582, 0.31815206684280867`, 0.9341922551900277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 428}], {
             RGBColor[
             0.19715708759112932`, 0.32455497791258914`, 0.9345391765193171]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 437}], {
             RGBColor[
             0.1942298621222053, 0.32147827834793574`, 0.9343724753593039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 451}], {
             RGBColor[
             0.20581343032131297`, 0.33365334296584104`, 0.9350321424318895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 429}], {
             RGBColor[
             0.18557451474248365`, 0.3123809594711283, 0.9338795661304677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 465}], {
             RGBColor[
             0.1791246132879326, 0.3056017040950233, 0.9335122537844052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 469}], {
             RGBColor[
             0.18027622515678673`, 0.30681212118559864`, 0.9335778363766793]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 488}], {
             RGBColor[
             0.18086431186395144`, 0.3074302376016796, 0.933611327044656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{425, 462}], {
             RGBColor[
             0.1883728625948838, 0.3153222004895023, 0.9340389279008772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 476}], {
             RGBColor[
             0.1853934884122734, 0.3121906893203451, 0.9338692569487667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 433}], {
             RGBColor[
             0.18359379097292866`, 0.3102990932041856, 0.9337667668420098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 500}], {
             RGBColor[
             0.19375142518042626`, 0.32097541078747177`, 0.9343452290832536]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 437}], {
             RGBColor[
             0.18484681961512717`, 0.31161610575374077`, 0.9338381249694931]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 451}], {
             RGBColor[
             0.19643038781423483`, 0.323791170371646, 0.934497792042079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{429, 488}], {
             RGBColor[
             0.1872389149746237, 0.3141303496441773, 0.9339743512614285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{430, 459}], {
             RGBColor[
             0.19801808656198788`, 0.32545994242144927`, 0.9345882091369736]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{430, 477}], {
             RGBColor[
             0.19967498374543186`, 0.3272014464145979, 0.9346825669804111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 444}], {
             RGBColor[
             0.4935580470291339, 0.5988610156365437, 0.9535144118851442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 486}], {
             RGBColor[
             0.4172932945902137, 0.5358602108283841, 0.9478105376266845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{432, 460}], {
             RGBColor[
             0.2959533208946317, 0.4283960831575556, 0.9401654758500221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 465}], {
             RGBColor[
             0.17986137360753812`, 0.306376085904231, 0.9335542111946675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 469}], {
             RGBColor[
             0.18101298547639227`, 0.3075865029948064, 0.9336197937869416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 495}], {
             RGBColor[
             0.9105859845179732, 0.6779864914594717, 0.24664336835265455`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{435, 439}], {
             RGBColor[
             0.21881441649795172`, 0.3473182037476218, 0.9357725293614136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{435, 453}], {
             RGBColor[
             0.2391644667053946, 0.36870739678334974`, 0.9369314346155262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 473}], {
             RGBColor[
             0.30955738588181175`, 0.4383701601543446, 0.9410985541344632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 439}], {
             RGBColor[
             0.2009360669634459, 0.3285269248340248, 0.9347543838040715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{439, 453}], {
             RGBColor[
             0.21958035723127328`, 0.3481232560217902, 0.9358161485530685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 445}], {
             RGBColor[
             0.9273756618709421, 0.7440317986720315, 0.27125592363752593`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 471}], {
             RGBColor[
             0.9242345860512566, 0.784069889818272, 0.5946181447155001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 450}], {
             RGBColor[
             0.21849705952285933`, 0.34698464144520536`, 0.9357544563511697]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 461}], {
             RGBColor[
             0.2373696075780963, 0.3668208860399178, 0.9368292200434826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 447}], {
             RGBColor[
             0.23581693788510275`, 0.36518893174763706`, 0.9367407978014356]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 500}], {
             RGBColor[
             0.21944649774055142`, 0.34798256120985954`, 0.9358085254530993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{443, 451}], {
             RGBColor[
             0.24646170398602968`, 0.37637725583686343`, 0.9373470014833631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{444, 486}], {
             RGBColor[
             0.4895993510327964, 0.5954321921343623, 0.953262167276795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{445, 471}], {
             RGBColor[
             0.9599777422905198, 0.9272913458979556, 0.6345862231732597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 454}], {
             RGBColor[
             0.2225609566268063, 0.3512560549674121, 0.9359858892792425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 500}], {
             RGBColor[
             0.21735914083056895`, 0.34578861675139594`, 0.9356896535650436]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 455}], {
             RGBColor[
             0.45681433053997933`, 0.564999766000337, 0.9515547264505798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 475}], {
             RGBColor[
             0.3185563246566676, 0.44958458227411635`, 0.9415467358348658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 478}], {
             RGBColor[
             0.2749488841783959, 0.4063190884105853, 0.938969304252312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 482}], {
             RGBColor[
             0.3164780231838319, 0.4477844619968153, 0.9414143083027866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{449, 499}], {
             RGBColor[
             0.8060897526290038, 0.8328531529864611, 0.6773590298414771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 461}], {
             RGBColor[
             0.23439908756698247`, 0.3636986811663903, 0.9366600533233402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{452, 468}], {
             RGBColor[
             0.22415491498640028`, 0.35293140626614244`, 0.9360766628497713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 489}], {
             RGBColor[
             0.20150669956748674`, 0.32912669588106847`, 0.9347868804866963]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 500}], {
             RGBColor[
             0.206190516482255, 0.33404968442963456`, 0.9350536169309063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{455, 475}], {
             RGBColor[
             0.47478660322499994`, 0.5813210731496465, 0.9526722731511402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{455, 482}], {
             RGBColor[
             0.47270830175216416`, 0.5795209528723455, 0.952539845619061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{457, 494}], {
             RGBColor[
             0.4122768656126409, 0.531082608493518, 0.9476104304219592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{458, 461}], {
             RGBColor[
             0.24614691137880979`, 0.3760463888476713, 0.937329074510076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{459, 477}], {
             RGBColor[
             0.19613686914455325`, 0.32348266363965217`, 0.9344810765880625]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{460, 463}], {
             RGBColor[
             0.42791636353987605`, 0.5415498055841811, 0.9492787976467367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{463, 483}], {
             RGBColor[
             0.5035999579863275, 0.6078494794543214, 0.954073961892099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 481}], {
             RGBColor[
             0.2038613891913174, 0.3316016239716596, 0.9349209765773223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 496}], {
             RGBColor[
             0.1941346337620407, 0.32137818730357604`, 0.9343670522450702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{465, 469}], {
             RGBColor[
             0.18020092681290795`, 0.30673297785199133`, 0.9335735482473893]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 470}], {
             RGBColor[
             0.19475005924981162`, 0.3220250385114528, 0.9344020998161584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 491}], {
             RGBColor[
             0.1882565372451065, 0.3151999351714332, 0.9340323033442953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 483}], {
             RGBColor[
             0.7044387287985243, 0.7666430914560537, 0.9539865308155939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 497}], {
             RGBColor[
             0.7175094368939575, 0.7772891603319885, 0.9550059228659136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{472, 488}], {
             RGBColor[
             0.18283227953141887`, 0.3094986963965447, 0.933723399891971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{474, 490}], {
             RGBColor[
             0.22274072146667342`, 0.35144499921186156`, 0.9359961266209347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{475, 478}], {
             RGBColor[
             0.2929211568634166, 0.42264039555989485`, 0.9400868509528724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{475, 482}], {
             RGBColor[
             0.3344502958688525, 0.46410576914612495`, 0.942531855003347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{478, 482}], {
             RGBColor[
             0.2908428553905808, 0.4208402752825938, 0.939954423420793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{481, 496}], {
             RGBColor[
             0.19554201050297132`, 0.3228574294911333, 0.934447200268439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{484, 490}], {
             RGBColor[
             0.2003898909918431, 0.3279528592583135, 0.9347232798904836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{489, 500}], {
             RGBColor[
             0.19630488377124938`, 0.3236592576650523, 0.9344906447724974]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.028685633809430733`], {
             RGBColor[
             0.19927754620079638`, 0.32678371435619025`, 0.9346599335002002]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.028685633809430733`], {
             RGBColor[
             0.18419449056434983`, 0.3109304665613231, 0.9338009757950858]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.028685633809430733`], {
             RGBColor[
             0.18365861817242612`, 0.31036723070113925`, 0.9337704586551179]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.028685633809430733`], {
             RGBColor[
             0.18151204232925333`, 0.30811104338919537`, 0.9336482143364235]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.028685633809430733`], {
             RGBColor[
             0.6895762664964494, 0.7574214874515429, 0.9696941758539234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.028685633809430733`], {
             RGBColor[
             0.21439443043390383`, 0.3426725181510049, 0.9355208176938495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.028685633809430733`], {
             RGBColor[
             0.47235402937887205`, 0.5825173062131191, 0.951604585963978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.028685633809430733`], {
             RGBColor[
             0.19748659103157024`, 0.32490130692021735`, 0.9345579412527936]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.028685633809430733`], {
             RGBColor[
             0.1937919382554366, 0.32101799259798497`, 0.9343475362429416]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.028685633809430733`], {
             RGBColor[
             0.22678684537035088`, 0.355697731973699, 0.9362265473915452]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.028685633809430733`], {
             RGBColor[
             0.37557365642318313`, 0.49972475713808634`, 0.9451521991739089]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.028685633809430733`], {
             RGBColor[
             0.19403535624859544`, 0.3212738403423871, 0.9343613985375474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.028685633809430733`], {
             RGBColor[
             0.25294530714331137`, 0.3831919338393498, 0.9377162330915391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.028685633809430733`], {
             RGBColor[
             0.2309802119470121, 0.36010522612056717`, 0.9364653534145562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.028685633809430733`], {
             RGBColor[
             0.6524065300643914, 0.7283842068503593, 0.9659894438973117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.028685633809430733`], {
             RGBColor[
             0.27011669665931304`, 0.4012401529496448, 0.9386941183216809]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.028685633809430733`], {
             RGBColor[
             0.3754434746784675, 0.49961200025393837`, 0.9451439041082509]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.028685633809430733`], {
             RGBColor[
             0.2883133698343315, 0.42036601019230513`, 0.9397303919394328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.028685633809430733`], {
             RGBColor[
             0.20321773659331793`, 0.33092510428123034`, 0.934884321514065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.028685633809430733`], {
             RGBColor[
             0.24175756143219096`, 0.3714329037529144, 0.9370791075240773]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.028685633809430733`], {
             RGBColor[
             0.3000028152540131, 0.4326523584820372, 0.9403960885630988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.028685633809430733`], {
             RGBColor[
             0.1817982963009414, 0.30841191446298966`, 0.9336645160766364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.028685633809430733`], {
             RGBColor[
             0.4319501958436354, 0.5485552820168211, 0.9487444624139638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.028685633809430733`], {
             RGBColor[
             0.18529079599648704`, 0.31208275308027844`, 0.9338634087676074]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.028685633809430733`], {
             RGBColor[
             0.2888948585418871, 0.42097719169245956`, 0.9397635068610926]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.028685633809430733`], {
             RGBColor[
             0.1848952269737127, 0.31166698495681794`, 0.9338408816969523]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.028685633809430733`], {
             RGBColor[
             0.18521154867326725`, 0.3119994591190039, 0.933858895749786]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.028685633809430733`], {
             RGBColor[
             0.47584147550400935`, 0.5853485720851631, 0.951879130497885]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.028685633809430733`], {
             RGBColor[
             0.1844293578243088, 0.3111773269429844, 0.9338143511380854]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.028685633809430733`], {
             RGBColor[
             0.17893397678527326`, 0.30540133304367595`, 0.9335013973176001]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.028685633809430733`], {
             RGBColor[
             0.19198099569549876`, 0.3191145771471003, 0.9342444057432027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.028685633809430733`], {
             RGBColor[
             0.21967241372144744`, 0.34822001322968177`, 0.9358213910339986]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.028685633809430733`], {
             RGBColor[
             0.25627137654269866`, 0.3866878436630859, 0.9379056478233554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.028685633809430733`], {
             RGBColor[
             0.2089289231192469, 0.33692792343012196`, 0.9352095651377733]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.028685633809430733`], {
             RGBColor[
             0.187649142725438, 0.3145615250202248, 0.9339977131249598]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.028685633809430733`], {
             RGBColor[
             0.9941315043202534, 0.9918412404700345, 0.7469196908007765]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.028685633809430733`], {
             RGBColor[
             0.861854760386902, 0.4655965562049136, 0.20644056462819607`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.028685633809430733`], {
             RGBColor[
             0.5188198477638203, 0.6202403508392836, 0.9552625453971423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.028685633809430733`], {
             RGBColor[
             0.24759097892264678`, 0.3775641953954144, 0.937411312020391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.028685633809430733`], {
             RGBColor[
             0.18500874865393632`, 0.31178630344042324`, 0.9338473465887008]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.028685633809430733`], {
             RGBColor[
             0.2630876311955555, 0.3938521594787447, 0.9382938234420904]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.028685633809430733`], {
             RGBColor[
             0.2005501569047806, 0.3281213088942566, 0.9347324067971333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.028685633809430733`], {
             RGBColor[
             0.22836865224462058`, 0.35736031129090495`, 0.9363166289529613]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.028685633809430733`], {
             RGBColor[
             0.2790104916899246, 0.4105880954259918, 0.9392006067914836]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.028685633809430733`], {
             RGBColor[
             0.2011773237053474, 0.3287805009663242, 0.9347681230186154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.028685633809430733`], {
             RGBColor[
             0.2037103551444467, 0.3314428776122868, 0.934912375411788]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.028685633809430733`], {
             RGBColor[
             0.28160948378147765`, 0.4133198008998302, 0.9393486155462334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.028685633809430733`], {
             RGBColor[
             0.18988308106937135`, 0.3169095358595705, 0.9341249326088312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.028685633809430733`], {
             RGBColor[
             0.9939249281250245, 0.9894143604804412, 0.5801441012857329]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.028685633809430733`], {
             RGBColor[
             0.8803633253605091, 0.9074418350893442, 0.9884510339541455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.028685633809430733`], {
             RGBColor[
             0.9952524916716045, 0.9922538846693116, 0.7246412005584384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.028685633809430733`], {
             RGBColor[
             0.1799948891424975, 0.30651641919684713`, 0.9335618147068648]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.028685633809430733`], {
             RGBColor[
             0.8326746621018166, 0.2521573478086015, 0.17892259937043942`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.028685633809430733`], {
             RGBColor[
             0.9895254911096693, 0.9899365356383177, 0.8232532496802422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.028685633809430733`], {
             RGBColor[
             0.5735931996355866, 0.6647078254001658, 0.9595745042978867]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.028685633809430733`], {
             RGBColor[
             0.4068474012204774, 0.5268125030173851, 0.9471449345381059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.028685633809430733`], {
             RGBColor[
             0.9626408166905339, 0.9716581627746242, 0.9481235318941049]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.028685633809430733`], {
             RGBColor[
             0.19316750906165184`, 0.32036167792421966`, 0.9343119759241159]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.028685633809430733`], {
             RGBColor[
             0.26299592027232827`, 0.3937557654836245, 0.9382886006406869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.028685633809430733`], {
             RGBColor[
             0.9854928836228277, 0.9882689488092234, 0.890083991790846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.028685633809430733`], {
             RGBColor[
             0.9902590342278114, 0.9902398745688678, 0.8110965418638902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.028685633809430733`], {
             RGBColor[
             0.25119317281524384`, 0.3813503295688181, 0.9376164516336061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.028685633809430733`], {
             RGBColor[
             0.20681114074536727`, 0.3347019998800166, 0.9350889605645591]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.028685633809430733`], {
             RGBColor[
             0.18480592008610275`, 0.3115731177555562, 0.9338357958018207]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.028685633809430733`], {
             RGBColor[
             0.183179266829206, 0.30986340204678436`, 0.9337431603052583]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.028685633809430733`], {
             RGBColor[
             0.19788231111085003`, 0.3253172338136426, 0.9345804769258931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.028685633809430733`], {
             RGBColor[
             0.18087272641393248`, 0.30743908182722296`, 0.9336118062408292]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.028685633809430733`], {
             RGBColor[
             0.18542751526237852`, 0.31222645369723245`, 0.933871194727542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.028685633809430733`], {
             RGBColor[
             0.44285619720498837`, 0.5580015122444584, 0.9494393831769108]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.028685633809430733`], {
             RGBColor[
             0.3697431424982056, 0.49467465902642144`, 0.9447806839823304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.028685633809430733`], {
             RGBColor[
             0.19773867236084267`, 0.32516626038016205`, 0.9345722969115747]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.028685633809430733`], {
             RGBColor[
             0.21111609134757603`, 0.339226775912571, 0.9353341211327513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.028685633809430733`], {
             RGBColor[
             0.5768983856608343, 0.6673911243123956, 0.9598347006490895]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.028685633809430733`], {
             RGBColor[
             0.18870685733270803`, 0.31567325013544506`, 0.9340579484070953]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.028685633809430733`], {
             RGBColor[
             0.8653183386459826, 0.4813238561401438, 0.20933065922764493`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.028685633809430733`], {
             RGBColor[
             0.4104281337116228, 0.5299139535283672, 0.9473730956461243]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.028685633809430733`], {
             RGBColor[
             0.33446793820227666`, 0.46412105004860754`, 0.9425329791572322]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.028685633809430733`], {
             RGBColor[
             0.4700607186843903, 0.5806554932788695, 0.9514240481454346]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.028685633809430733`], {
             RGBColor[
             0.8862469572430673, 0.9121332834455631, 0.9890122200154841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.028685633809430733`], {
             RGBColor[
             0.3474160266946404, 0.4753360335108428, 0.9433580199064205]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.028685633809430733`], {
             RGBColor[
             0.23835692087692842`, 0.36785861491626903`, 0.9368854460752519]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.028685633809430733`], {
             RGBColor[
             0.5201221497039563, 0.62129761822232, 0.955365067376359]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.028685633809430733`], {
             RGBColor[
             0.9952268649647723, 0.9922942002460275, 0.7287667302186207]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.028685633809430733`], {
             RGBColor[
             0.27551545928723997`, 0.406914594772917, 0.9390015698665879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.028685633809430733`], {
             RGBColor[
             0.18726966457396857`, 0.31416266942272597`, 0.9339761024056213]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.028685633809430733`], {
             RGBColor[
             0.18531184315250615`, 0.31210487497572126`, 0.9338646073720063]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.028685633809430733`], {
             RGBColor[
             0.30841227476556676`, 0.4414912336192087, 0.9408749948416013]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.028685633809430733`], {
             RGBColor[
             0.18955897979005848`, 0.3165688848658047, 0.9341064755204392]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.028685633809430733`], {
             RGBColor[
             0.30968149308884285`, 0.4426522770943059, 0.940953608792397]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.028685633809430733`], {
             RGBColor[
             0.2623509631444437, 0.39307787464957405`, 0.9382518712863824]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.028685633809430733`], {
             RGBColor[
             0.46032419676718667`, 0.5727509461611696, 0.9506575534740573]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.028685633809430733`], {
             RGBColor[
             0.27193911320159614`, 0.4031556282834669, 0.9387979022477403]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.028685633809430733`], {
             RGBColor[
             0.2226303791602024, 0.3513290224516542, 0.935989842789818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.028685633809430733`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.028685633809430733`], {
             RGBColor[
             0.1846806812934658, 0.3114414838438967, 0.9338286636378542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.028685633809430733`], {
             RGBColor[
             0.4707743379765772, 0.5812348415684494, 0.9514802268701891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.028685633809430733`], {
             RGBColor[
             0.9884567952610653, 0.9727242013215213, 0.40965725865088887`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.028685633809430733`], {
             RGBColor[
             0.18830185869099547`, 0.3152475708846082, 0.9340348843335916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.028685633809430733`], {
             RGBColor[
             0.9796979203258498, 0.9843793227373989, 0.9192503046446351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.028685633809430733`], {
             RGBColor[
             0.9932268871291124, 0.987921321372956, 0.5041666466903745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.028685633809430733`], {
             RGBColor[
             0.24511118458418202`, 0.3749577743176459, 0.9372700914013423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.028685633809430733`], {
             RGBColor[
             0.19944242864104303`, 0.32695701625504003`, 0.9346693233112505]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.028685633809430733`], {
             RGBColor[
             0.40980409560216274`, 0.5293734430830204, 0.9473333324896046]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.028685633809430733`], {
             RGBColor[
             0.9241317229671294, 0.73691459370894, 0.25781280732325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.028685633809430733`], {
             RGBColor[
             0.1914252698739526, 0.31853047407360313`, 0.9342127579797883]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.028685633809430733`], {
             RGBColor[
             0.17964740484760663`, 0.30615119117114004`, 0.9335420259903278]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.028685633809430733`], {
             RGBColor[
             0.21128649273995928`, 0.33940587858003807`, 0.9353438252399612]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.028685633809430733`], {
             RGBColor[
             0.20961363351384976`, 0.337647597467996, 0.9352485583818076]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.028685633809430733`], {
             RGBColor[
             0.2136359512540558, 0.3418753084426271, 0.9354776234266265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.028685633809430733`], {
             RGBColor[
             0.4170759329154467, 0.5356719430706164, 0.9477966875329739]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.028685633809430733`], {
             RGBColor[
             0.3665915053486955, 0.49194486933340476`, 0.9445798644500469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.028685633809430733`], {
             RGBColor[
             0.9934414779456845, 0.9915558968312813, 0.7583552135583986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.028685633809430733`], {
             RGBColor[
             0.19671677940387242`, 0.3240921860906307, 0.9345141016194304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.028685633809430733`], {
             RGBColor[
             0.18143431560131953`, 0.3080293476699778, 0.9336437879142542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.028685633809430733`], {
             RGBColor[
             0.19098661972276523`, 0.31806942495267926`, 0.934187777502603]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.028685633809430733`], {
             RGBColor[
             0.27647894211230134`, 0.40792727631039594`, 0.9390564387881299]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.028685633809430733`], {
             RGBColor[
             0.18356396795554494`, 0.3102677473220268, 0.933765068465289]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.028685633809430733`], {
             RGBColor[
             0.19221104916857337`, 0.3193563779335344, 0.9342575069481607]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.028685633809430733`], {
             RGBColor[
             0.18431898451928125`, 0.31106131760132866`, 0.9338080655416469]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.028685633809430733`], {
             RGBColor[
             0.1799037129149489, 0.30642058720078685`, 0.9335566223555891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.028685633809430733`], {
             RGBColor[
             0.20513244387794988`, 0.3329375830368321, 0.9349933612613692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.028685633809430733`], {
             RGBColor[
             0.18567855904381614`, 0.3124903166286185, 0.9338854912995088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.028685633809430733`], {
             RGBColor[
             0.18584647349383113`, 0.3126668053619753, 0.93389505377903]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.028685633809430733`], {
             RGBColor[
             0.18536877790044387`, 0.31216471700567533`, 0.9338678497216739]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.028685633809430733`], {
             RGBColor[
             0.7779497574122243, 0.8264595302183536, 0.978502419531181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.028685633809430733`], {
             RGBColor[
             0.4884562669939937, 0.5955898281066129, 0.9528722130934804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.028685633809430733`], {
             RGBColor[
             0.8321508631713839, 0.8689985264321587, 0.9838524862707736]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.028685633809430733`], {
             RGBColor[
             0.19425607642724724`, 0.32150583124461773`, 0.9343739682251954]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.028685633809430733`], {
             RGBColor[
             0.2893758023858067, 0.42148269416601997`, 0.9397908959015111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.028685633809430733`], {
             RGBColor[
             0.30291909395791666`, 0.43571755230258913`, 0.9405621663210384]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.028685633809430733`], {
             RGBColor[
             0.8337292727736055, 0.2602635475653142, 0.17993249574075687`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.028685633809430733`], {
             RGBColor[
             0.2723145403641676, 0.4035502260347864, 0.938819282269254]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.028685633809430733`], {
             RGBColor[
             0.19798057442534764`, 0.32542051478743356`, 0.9345860728762861]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.028685633809430733`], {
             RGBColor[
             0.18413129784782198`, 0.3108640470096027, 0.9337973770633647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.028685633809430733`], {
             RGBColor[
             0.17999586170885287`, 0.3065174414257509, 0.93356187009308]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.028685633809430733`], {
             RGBColor[
             0.5282221961294052, 0.6278736008134325, 0.956002732702418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.028685633809430733`], {
             RGBColor[
             0.2116557852103354, 0.33979402838089834`, 0.9353648558998299]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.028685633809430733`], {
             RGBColor[
             0.1827700546655207, 0.3094332941172014, 0.9337198562779115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.028685633809430733`], {
             RGBColor[
             0.18259939511325524`, 0.3092539201073298, 0.9337101374688782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.028685633809430733`], {
             RGBColor[
             0.17901437519538227`, 0.3054858368702541, 0.933505975888117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.028685633809430733`], {
             RGBColor[
             0.2073090188644706, 0.33522530135049017`, 0.9351173139868973]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.028685633809430733`], {
             RGBColor[
             0.21571267720568413`, 0.3440580790898188, 0.9355958898973311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.028685633809430733`], {
             RGBColor[
             0.5806518106608889, 0.6704383238173092, 0.9601301840143426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.028685633809430733`], {
             RGBColor[
             0.1968786888055324, 0.3242623631374243, 0.9345233221203314]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.028685633809430733`], {
             RGBColor[
             0.20904447312210606`, 0.33704937380942024`, 0.9352161455394953]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.028685633809430733`], {
             RGBColor[
             0.1800731039927536, 0.30659862796357423`, 0.9335662689268784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.028685633809430733`], {
             RGBColor[
             0.8190803262063154, 0.147665325039805, 0.16590464796430104`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.028685633809430733`], {
             RGBColor[
             0.27463540520047075`, 0.4059896021290707, 0.9389514520882697]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.028685633809430733`], {
             RGBColor[
             0.5611296111138018, 0.6545893227599167, 0.9585933249538227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.028685633809430733`], {
             RGBColor[
             0.2153604952721365, 0.34368791354803596`, 0.9355758336572221]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.028685633809430733`], {
             RGBColor[
             0.20371318105767475`, 0.33144584782626274`, 0.9349125363433657]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.028685633809430733`], {
             RGBColor[
             0.18423542654322242`, 0.31097349287060916`, 0.9338033070385232]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.028685633809430733`], {
             RGBColor[
             0.22763715789209957`, 0.35659146434698463`, 0.9362749714317341]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.028685633809430733`], {
             RGBColor[
             0.9834670894693087, 0.9871903629131425, 0.9128700844415136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.028685633809430733`], {
             RGBColor[
             0.19392286855916088`, 0.32115560864865994`, 0.9343549925300447]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.028685633809430733`], {
             RGBColor[
             0.19939483773806957`, 0.32690699519857735`, 0.9346666130797306]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.028685633809430733`], {
             RGBColor[
             0.29909565256278264`, 0.4316988729761172, 0.9403444269898601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.028685633809430733`], {
             RGBColor[
             0.19170728594478786`, 0.3188268908449026, 0.9342288183778169]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.028685633809430733`], {
             RGBColor[
             0.2321162208184409, 0.36129924347156134`, 0.9365300474392095]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.028685633809430733`], {
             RGBColor[
             0.23944883454874902`, 0.3690062854166779, 0.9369476289435206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.028685633809430733`], {
             RGBColor[
             0.2138505894071634, 0.34210090675038807`, 0.9354898467519174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.028685633809430733`], {
             RGBColor[
             0.18332605976082084`, 0.310017690725121, 0.933751519945553]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.028685633809430733`], {
             RGBColor[
             0.899308535201446, 0.6356654000864056, 0.23769291240948212`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.028685633809430733`], {
             RGBColor[
             0.3160253373259164, 0.44814699612157666`, 0.9413578329375422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.028685633809430733`], {
             RGBColor[
             0.3059265832870255, 0.43887861427331937`, 0.9407334383891494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.028685633809430733`], {
             RGBColor[
             0.19568177386369887`, 0.32300432964476683`, 0.934455159585071]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.028685633809430733`], {
             RGBColor[
             0.23986313789965336`, 0.369441744506828, 0.9369712229064477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.028685633809430733`], {
             RGBColor[
             0.29271248717825876`, 0.424989761440922, 0.9399809151642584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.028685633809430733`], {
             RGBColor[
             0.18381241008660495`, 0.31052887575391175`, 0.9337792168771156]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.028685633809430733`], {
             RGBColor[
             0.1877350381466607, 0.3146518065540141, 0.9340026047421276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.028685633809430733`], {
             RGBColor[
             0.47069483175957283`, 0.581170294839771, 0.9514739678495456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.028685633809430733`], {
             RGBColor[
             0.22349209680564214`, 0.35223474233306573`, 0.9360389163349288]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.028685633809430733`], {
             RGBColor[
             0.720597203195575, 0.7816552789687509, 0.9727860529169569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.028685633809430733`], {
             RGBColor[
             0.18747717117288942`, 0.31438077201487, 0.9339879195994514]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.028685633809430733`], {
             RGBColor[
             0.39767741348965524`, 0.5188699205419315, 0.9465606310285997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.028685633809430733`], {
             RGBColor[
             0.3169334821091241, 0.44893358548810713`, 0.9414156991200873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.028685633809430733`], {
             RGBColor[
             0.18438238961983267`, 0.3111279603821238, 0.9338116763683237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.028685633809430733`], {
             RGBColor[
             0.46930938565191127`, 0.5800455272759355, 0.9513649004568943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.028685633809430733`], {
             RGBColor[
             0.2001120590885424, 0.3276608403123844, 0.9347074577746062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.028685633809430733`], {
             RGBColor[
             0.26314504718325327`, 0.39391250732219896`, 0.9382970931976505]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.028685633809430733`], {
             RGBColor[
             0.22551745991005276`, 0.354363527371239, 0.9361542577674687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.028685633809430733`], {
             RGBColor[
             0.34499714152995936`, 0.4732409167578995, 0.9432038906826632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.028685633809430733`], {
             RGBColor[
             0.19696480621086881`, 0.3243528779905917, 0.934528226379166]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.028685633809430733`], {
             RGBColor[
             0.5408355089237035, 0.6381136563631097, 0.9569956988896724]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.028685633809430733`], {
             RGBColor[
             0.21154093935996757`, 0.33967331811051427`, 0.9353583155985506]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.028685633809430733`], {
             RGBColor[
             0.9933232264913885, 0.9881273815274607, 0.5146525917364964]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.028685633809430733`], {
             RGBColor[
             0.22124625332801934`, 0.34987421844338334`, 0.9359110188713058]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.028685633809430733`], {
             RGBColor[
             0.2239766808649284, 0.35274407090377946`, 0.9360665126802272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.028685633809430733`], {
             RGBColor[
             0.2519720376195532, 0.38216896586102805`, 0.9376608068319842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.028685633809430733`], {
             RGBColor[
             0.21654397156564814`, 0.3449318221692476, 0.9356432308813413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.028685633809430733`], {
             RGBColor[
             0.19059661539563244`, 0.31765950567716017`, 0.9341655673331324]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.028685633809430733`], {
             RGBColor[
             0.3129892535839804, 0.4455172929823175, 0.9411643763662094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.028685633809430733`], {
             RGBColor[
             0.18092386766537458`, 0.30749283452503123`, 0.9336147186594421]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.028685633809430733`], {
             RGBColor[
             0.18610703405965695`, 0.3129406710371523, 0.933909892317789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.028685633809430733`], {
             RGBColor[
             0.18809486651088786`, 0.3150300089792529, 0.934023096435152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.028685633809430733`], {
             RGBColor[
             0.19199615165670597`, 0.3191305070232725, 0.9342452688527721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.028685633809430733`], {
             RGBColor[
             0.23089370286527677`, 0.3600142995906707, 0.93646042685033]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.028685633809430733`], {
             RGBColor[
             0.1824115868132323, 0.30905652167627173`, 0.9336994420640293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.028685633809430733`], {
             RGBColor[
             0.3861343022549474, 0.5088718577640675, 0.9458251141878965]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.028685633809430733`], {
             RGBColor[
             0.26297543885551555`, 0.39373423821595743`, 0.938287434254299]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.028685633809430733`], {
             RGBColor[
             0.25745169920403105`, 0.3879284376169253, 0.9379728654527874]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.028685633809430733`], {
             RGBColor[
             0.18676020758344578`, 0.31362719782424764`, 0.9339470895836851]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.028685633809430733`], {
             RGBColor[
             0.8450710458930704, 0.34744138575819206`, 0.19079339048865696`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.028685633809430733`], {
             RGBColor[
             0.3159031668134525, 0.44804117816414885`, 0.941350048340519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.028685633809430733`], {
             RGBColor[
             0.23748131534596645`, 0.36693829798663086`, 0.936835581635606]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.028685633809430733`], {
             RGBColor[
             0.18041422854673403`, 0.3069571714983536, 0.933585695465579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.028685633809430733`], {
             RGBColor[
             0.8749870106263872, 0.5252270374274478, 0.21739843612893187`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.028685633809430733`], {
             RGBColor[
             0.42661470104868005`, 0.5439339445951966, 0.948404489403622]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.028685633809430733`], {
             RGBColor[
             0.9944761061763768, 0.9919837421934052, 0.7412087462437971]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.028685633809430733`], {
             RGBColor[
             0.19552365175645214`, 0.32283813328452987`, 0.9344461547649839]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.028685633809430733`], {
             RGBColor[
             0.1874830946539544, 0.31438699796903974`, 0.933988256932935]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.028685633809430733`], {
             RGBColor[
             0.1819457440050942, 0.3085668913487786, 0.9336729130052586]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.028685633809430733`], {
             RGBColor[
             0.20221750657572096`, 0.32987379911448994`, 0.9348273598942706]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.028685633809430733`], {
             RGBColor[
             0.1875451608924792, 0.3144522335209561, 0.9339917915134002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.028685633809430733`], {
             RGBColor[
             0.18496268734880916`, 0.3117378900882792, 0.9338447234655154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.028685633809430733`], {
             RGBColor[
             0.19991510326486814`, 0.3274538272539823, 0.934696241431818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.028685633809430733`], {
             RGBColor[
             0.18124242467150065`, 0.3078276581361505, 0.9336328600096782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.028685633809430733`], {
             RGBColor[
             0.28587662659874513`, 0.4178048385532594, 0.9395916230170046]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.028685633809430733`], {
             RGBColor[
             0.6695263659366376, 0.7417583527493299, 0.9676957891430948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.028685633809430733`], {
             RGBColor[
             0.21703333859134122`, 0.34544617794091254`, 0.9356710996095008]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.028685633809430733`], {
             RGBColor[
             0.9622752132426141, 0.884407577445488, 0.3079467564861062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.028685633809430733`], {
             RGBColor[
             0.1971022673351447, 0.32449735834774435`, 0.9345360545868381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.028685633809430733`], {
             RGBColor[
             0.20818468230621298`, 0.33614567914803034`, 0.9351671817244767]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.028685633809430733`], {
             RGBColor[
             0.20593429362604587`, 0.3337803779622914, 0.9350390254182929]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.028685633809430733`], {
             RGBColor[
             0.18396512493287584`, 0.310689388740023, 0.9337879137616893]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.028685633809430733`], {
             RGBColor[
             0.1869796895121246, 0.3138578872472471, 0.933959588754829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.028685633809430733`], {
             RGBColor[
             0.19315889756887425`, 0.3203526266993102, 0.9343114855123418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.028685633809430733`], {
             RGBColor[
             0.2582166797056685, 0.38873248062671145`, 0.9380164299606684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.028685633809430733`], {
             RGBColor[
             0.2348407472607494, 0.36416289350738135`, 0.9366852051895233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.028685633809430733`], {
             RGBColor[
             0.2058983382969339, 0.3337425866316952, 0.9350369778154911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.028685633809430733`], {
             RGBColor[
             0.7636579459089816, 0.81529465845023, 0.9770779453251097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.028685633809430733`], {
             RGBColor[
             0.2784596091749779, 0.41000908297481403`, 0.939169234847215]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.028685633809430733`], {
             RGBColor[
             0.9625574020842641, 0.9715959522978471, 0.948264731064506]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.028685633809430733`], {
             RGBColor[
             0.9263783006421346, 0.7458215255627042, 0.25962045645451476`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.028685633809430733`], {
             RGBColor[
             0.2171179053764417, 0.345535062993897, 0.9356759155628069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.028685633809430733`], {
             RGBColor[
             0.20835940299106456`, 0.3363293216657406, 0.9351771318090029]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.028685633809430733`], {
             RGBColor[
             0.2328901660883635, 0.3621127090212143, 0.9365741224773821]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.028685633809430733`], {
             RGBColor[
             0.48668906339049306`, 0.5941551326096759, 0.9527330923523326]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.028685633809430733`], {
             RGBColor[
             0.1966443508485099, 0.324016059086709, 0.9345099769203509]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.028685633809430733`], {
             RGBColor[
             0.9948059876224538, 0.9912988576566625, 0.6760419903119628]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.028685633809430733`], {
             RGBColor[
             0.21562994450375172`, 0.3439711217745316, 0.9355911783923481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.028685633809430733`], {
             RGBColor[
             0.9731128985329042, 0.9794682242662037, 0.9303970288913456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.028685633809430733`], {
             RGBColor[
             0.19657931914436805`, 0.32394770664240774`, 0.9345062734610058]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.028685633809430733`], {
             RGBColor[
             0.44672166802497704`, 0.5613495887845201, 0.9496856875594589]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.028685633809430733`], {
             RGBColor[
             0.2439252154854269, 0.3737112456000703, 0.9372025522156523]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.028685633809430733`], {
             RGBColor[
             0.2398990282396083, 0.3694794675296996, 0.9369732668082131]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.028685633809430733`], {
             RGBColor[
             0.18427930277709584`, 0.31101960957432406`, 0.9338058057251333]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.028685633809430733`], {
             RGBColor[
             0.18027294835259305`, 0.30680867705662973`, 0.933577649767528]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.028685633809430733`], {
             RGBColor[
             0.7269497450043649, 0.7866179329108834, 0.9734192149165786]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.028685633809430733`], {
             RGBColor[
             0.2196415898680099, 0.3481876154053738, 0.9358196356611451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.028685633809430733`], {
             RGBColor[
             0.23893002370274252`, 0.3684609823230175, 0.9369180834333524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.028685633809430733`], {
             RGBColor[
             0.18230687199160545`, 0.30894645975943874`, 0.9336934787098494]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.028685633809430733`], {
             RGBColor[
             0.37749249202520396`, 0.5013867560930751, 0.94527446568171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.028685633809430733`], {
             RGBColor[
             0.19242949370172294`, 0.3195859769880579, 0.9342699470411637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.028685633809430733`], {
             RGBColor[
             0.19717041562221144`, 0.32456898651830246`, 0.9345399355309701]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.028685633809430733`], {
             RGBColor[
             0.3115575299166111, 0.44427720590216613`, 0.9410731482001482]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.028685633809430733`], {
             RGBColor[
             0.9630526170636222, 0.8870299430768459, 0.31096682353032956`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.028685633809430733`], {
             RGBColor[
             0.41518076487513966`, 0.5340304437680178, 0.9476759291012767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.028685633809430733`], {
             RGBColor[
             0.6832732263253226, 0.7524975045649791, 0.9690659477149247]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.028685633809430733`], {
             RGBColor[
             0.20975080596055196`, 0.33779177440671543`, 0.935256370149719]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.028685633809430733`], {
             RGBColor[
             0.329292758612209, 0.4596385695997802, 0.9422032212899847]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.028685633809430733`], {
             RGBColor[
             0.34316736625512184`, 0.47165605738201455`, 0.9430872990201573]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.028685633809430733`], {
             RGBColor[
             0.22433819907190317`, 0.35312404946088816`, 0.9360871006072962]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.028685633809430733`], {
             RGBColor[
             0.8655438992520076, 0.482348074171085, 0.20951887252630852`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.028685633809430733`], {
             RGBColor[
             0.18432263905515192`, 0.3110651587502397, 0.9338082736620582]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.028685633809430733`], {
             RGBColor[
             0.9935833726583437, 0.9886838078737659, 0.5429678965735315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.028685633809430733`], {
             RGBColor[
             0.22925694712510034`, 0.35829396553143755`, 0.9363672160322901]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.028685633809430733`], {
             RGBColor[
             0.1863015188096388, 0.3131450868404286, 0.9339209679365861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.028685633809430733`], {
             RGBColor[
             0.6018738506410779, 0.6876673319152327, 0.961800860740477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.028685633809430733`], {
             RGBColor[
             0.18011392367187812`, 0.3066415320344512, 0.9335685935472172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.028685633809430733`], {
             RGBColor[
             0.20809576797568208`, 0.3360522245491482, 0.9351621181848899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.028685633809430733`], {
             RGBColor[
             0.25722683759211185`, 0.3876920938057486, 0.9379600599166416]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.028685633809430733`], {
             RGBColor[
             0.18715875648320013`, 0.3140460979873492, 0.9339697863539259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.028685633809430733`], {
             RGBColor[
             0.24408437678171757`, 0.37387853421388084`, 0.937211616216018]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.028685633809430733`], {
             RGBColor[
             0.48931236896480956`, 0.5962848502534754, 0.9529396085766279]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.028685633809430733`], {
             RGBColor[
             0.21359854810176626`, 0.34183599535807396`, 0.9354754933724367]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.028685633809430733`], {
             RGBColor[
             0.44322657405371796`, 0.5583223140551463, 0.9494629832622005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.028685633809430733`], {
             RGBColor[
             0.18446408847726348`, 0.3112138310612903, 0.9338163289973919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.028685633809430733`], {
             RGBColor[
             0.20798277523591915`, 0.3359334620155039, 0.9351556834155181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.028685633809430733`], {
             RGBColor[
             0.2534737690150518, 0.3837473807729669, 0.9377463282133454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.028685633809430733`], {
             RGBColor[
             0.8184239254643847, 0.14261994130068656`, 0.16527607787252963`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.028685633809430733`], {
             RGBColor[
             0.6967134214587186, 0.7629970871524544, 0.9704055407600571]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.028685633809430733`], {
             RGBColor[
             0.18231742038260904`, 0.3089575467871901, 0.9336940794251122]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.028685633809430733`], {
             RGBColor[
             0.20683017875346388`, 0.3347220100336056, 0.935090044750956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.028685633809430733`], {
             RGBColor[
             0.21438774917055564`, 0.3426654957196094, 0.9355204372057859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.028685633809430733`], {
             RGBColor[
             0.18739586640915007`, 0.3142953155531602, 0.933983289413436]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.028685633809430733`], {
             RGBColor[
             0.304153838987054, 0.4370153476155689, 0.9406324832238061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.028685633809430733`], {
             RGBColor[
             0.7112234006140565, 0.7743323931485304, 0.9718517598787967]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.028685633809430733`], {
             RGBColor[
             0.21007296758615746`, 0.3381303867014537, 0.9352747167777018]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.028685633809430733`], {
             RGBColor[
             0.18152659560596812`, 0.30812633980575366`, 0.9336490431240029]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.028685633809430733`], {
             RGBColor[
             0.18307944483465585`, 0.30975848280143214`, 0.933737475590342]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.028685633809430733`], {
             RGBColor[
             0.18511992750412062`, 0.3119031594611132, 0.9338536780597445]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.028685633809430733`], {
             RGBColor[
             0.8097488880926076, 0.8513012527882134, 0.9816718596976299]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.028685633809430733`], {
             RGBColor[
             0.18749202516745894`, 0.31439638450496027`, 0.9339887655124676]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.028685633809430733`], {
             RGBColor[
             0.9847959098179251, 0.9879807322294865, 0.9016346514484699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.028685633809430733`], {
             RGBColor[
             0.18222924951210637`, 0.30886487361193576`, 0.9336890582244741]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.028685633809430733`], {
             RGBColor[
             0.19526251556143404`, 0.32256366258657476`, 0.934431283444994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.028685633809430733`], {
             RGBColor[
             0.2756885017375273, 0.407096473359694, 0.9390114243781383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.028685633809430733`], {
             RGBColor[
             0.24007340415027964`, 0.3696627476678865, 0.9369831972583599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.028685633809430733`], {
             RGBColor[
             0.23186327956718236`, 0.36103338617908703`, 0.9365156428091433]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.028685633809430733`], {
             RGBColor[
             0.6564481594438648, 0.7315415584391249, 0.9663922757426836]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.028685633809430733`], {
             RGBColor[
             0.24476085053842922`, 0.3745895510230982, 0.9372501403957095]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.028685633809430733`], {
             RGBColor[
             0.8407980254541154, 0.31459707821488886`, 0.1867015412906274]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.028685633809430733`], {
             RGBColor[
             0.190709032669891, 0.3177776633600728, 0.934171969330595]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.028685633809430733`], {
             RGBColor[
             0.3105546519813193, 0.443408563440727, 0.9410092457049215]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.028685633809430733`], {
             RGBColor[
             0.24077004537273583`, 0.3703949617622926, 0.9370228699453904]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.028685633809430733`], {
             RGBColor[
             0.1917730045224159, 0.3188959652367882, 0.934232560953591]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.028685633809430733`], {
             RGBColor[
             0.19090439582770188`, 0.3179830024256716, 0.9341830949734184]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.028685633809430733`], {
             RGBColor[
             0.1881959331144625, 0.3151362363876026, 0.9340288520287109]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.028685633809430733`], {
             RGBColor[
             0.644812645752953, 0.7224518067106054, 0.9652325564780311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.028685633809430733`], {
             RGBColor[
             0.18998459744441062`, 0.31701623600624673`, 0.9341307138162097]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.028685633809430733`], {
             RGBColor[
             0.19496888133162707`, 0.3222550343935622, 0.9344145614099995]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.028685633809430733`], {
             RGBColor[
             0.36122042818933575`, 0.4872927122561548, 0.9442376241629096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.028685633809430733`], {
             RGBColor[
             0.2628079616436893, 0.3935582090476596, 0.9382778966748457]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.028685633809430733`], {
             RGBColor[
             0.18340993044876472`, 0.3101058441358588, 0.9337562962571558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.028685633809430733`], {
             RGBColor[
             0.43871305828747303`, 0.5544129335543235, 0.9491753860287206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.028685633809430733`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.028685633809430733`], {
             RGBColor[
             0.1979808475129809, 0.32542080181985084`, 0.9345860884282229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.028685633809430733`], {
             RGBColor[
             0.18086286172523808`, 0.3074287134139478, 0.9336112444614015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.028685633809430733`], {
             RGBColor[
             0.18113843442729957`, 0.3077183577961329, 0.9336269379191107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.028685633809430733`], {
             RGBColor[
             0.9854351531478911, 0.9882450757742316, 0.8910407351622261]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.028685633809430733`], {
             RGBColor[
             0.820782245844875, 0.16074702516771538`, 0.16753440813222906`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.028685633809430733`], {
             RGBColor[
             0.9927101178720487, 0.9912534606457363, 0.7704757426777427]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.028685633809430733`], {
             RGBColor[
             0.9397327677393429, 0.9545733773753136, 0.9869008833924131]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.028685633809430733`], {
             RGBColor[
             0.23363553097946993`, 0.3628961347806308, 0.9366165699052621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.028685633809430733`], {
             RGBColor[
             0.7253820295989173, 0.7853932217210695, 0.973262959696097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.028685633809430733`], {
             RGBColor[
             0.1837791716078354, 0.31049394000528374`, 0.9337773239949216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.028685633809430733`], {
             RGBColor[
             0.24298649045633505`, 0.3727245860758903, 0.9371490932139648]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.028685633809430733`], {
             RGBColor[
             0.18157893838322037`, 0.30818135538336955`, 0.9336520239677332]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.028685633809430733`], {
             RGBColor[
             0.18958070170652433`, 0.3165917159772593, 0.9341077125514473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.028685633809430733`], {
             RGBColor[
             0.30143473291096856`, 0.4341573947283205, 0.94047763415533]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.028685633809430733`], {
             RGBColor[
             0.18662770310860746`, 0.3134879272199237, 0.9339395436498659]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.028685633809430733`], {
             RGBColor[
             0.23178823080036964`, 0.3609545051668002, 0.9365113688928981]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.028685633809430733`], {
             RGBColor[
             0.18685517330782678`, 0.3137270128217468, 0.9339524977411994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.028685633809430733`], {
             RGBColor[
             0.21037507790267013`, 0.33844792379900884`, 0.935291921513295]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.028685633809430733`], {
             RGBColor[
             0.6253505975793664, 0.7067268126951324, 0.9636490362576168]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.028685633809430733`], {
             RGBColor[
             0.1890859537624092, 0.3160717045191629, 0.9340795373879439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.028685633809430733`], {
             RGBColor[
             0.4243323457115801, 0.5419570831167153, 0.9482590597397496]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.028685633809430733`], {
             RGBColor[
             0.1801862242299471, 0.30671752450510187`, 0.9335727109570402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.028685633809430733`], {
             RGBColor[
             0.36379298595207366`, 0.4895209324897256, 0.9444015452687277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.028685633809430733`], {
             RGBColor[
             0.9942973298741586, 0.9902108901662465, 0.6206777334817875]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.028685633809430733`], {
             RGBColor[
             0.47631296582080423`, 0.5857313491647339, 0.951916247942749]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.028685633809430733`], {
             RGBColor[
             0.8462306119676556, 0.35635431873254797`, 0.1919037922712223]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.028685633809430733`], {
             RGBColor[
             0.1902758304551235, 0.3173223403657453, 0.9341472991053292]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.028685633809430733`], {
             RGBColor[
             0.19084105210201593`, 0.31791642415375154`, 0.9341794876419492]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.028685633809430733`], {
             RGBColor[
             0.4414153171565428, 0.5567534943672319, 0.9493475715743441]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.028685633809430733`], {
             RGBColor[
             0.2030767017243416, 0.3307768676918091, 0.9348762897869192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.028685633809430733`], {
             RGBColor[
             0.46208044251389646`, 0.5741767455763179, 0.9507958115725785]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.028685633809430733`], {
             RGBColor[
             0.18519516767477753`, 0.31198224165097593`, 0.9338579628761555]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.028685633809430733`], {
             RGBColor[
             0.1815243108454087, 0.3081239383775436, 0.933648913010269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.028685633809430733`], {
             RGBColor[
             0.24019038642635912`, 0.3697857034571507, 0.9369898592259228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.028685633809430733`], {
             RGBColor[
             0.18339204965023842`, 0.3100870502828995, 0.9337552779721321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.028685633809430733`], {
             RGBColor[
             0.18070771638990538`, 0.3072656458297307, 0.9336024091640713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.028685633809430733`], {
             RGBColor[
             0.31058773436371456`, 0.4434372177375889, 0.9410113536850742]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.028685633809430733`], {
             RGBColor[
             0.5597098423756648, 0.6534366905384442, 0.9584815555579723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.028685633809430733`], {
             RGBColor[
             0.24531622372842543`, 0.3751732834584783, 0.9372817680772788]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.028685633809430733`], {
             RGBColor[
             0.18854433931021156`, 0.3155024333895635, 0.934048693246138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.028685633809430733`], {
             RGBColor[
             0.2248830575111852, 0.353696730226594, 0.9361181294893675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.028685633809430733`], {
             RGBColor[
             0.9095261013751367, 0.9306954410809412, 0.9912326055643381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.028685633809430733`], {
             RGBColor[
             0.5961635782161725, 0.6830314755158533, 0.9613513271777714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.028685633809430733`], {
             RGBColor[
             0.23010075165696398`, 0.35918085759472357`, 0.9364152694520828]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.028685633809430733`], {
             RGBColor[
             0.17923689510112015`, 0.3057197193997615, 0.9335186480675601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.028685633809430733`], {
             RGBColor[
             0.18261346087673228`, 0.3092687041165651, 0.9337109384932998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.028685633809430733`], {
             RGBColor[
             0.20439189938454302`, 0.3321592238210287, 0.9349511883480071]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.028685633809430733`], {
             RGBColor[
             0.20704370002822514`, 0.33494643443141037`, 0.9351022044716772]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.028685633809430733`], {
             RGBColor[
             0.18255683100735334`, 0.30920918253330676`, 0.933707713506015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.028685633809430733`], {
             RGBColor[
             0.19714961162350877`, 0.32454712019661625`, 0.9345387507740208]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.028685633809430733`], {
             RGBColor[
             0.1792318772890574, 0.3057144453611359, 0.9335183623105863]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.028685633809430733`], {
             RGBColor[
             0.18202687820624844`, 0.30865216853839716`, 0.933677533477987]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.028685633809430733`], {
             RGBColor[
             0.22875987812146206`, 0.3577715144926186, 0.9363389086878806]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.028685633809430733`], {
             RGBColor[
             0.25408219745152405`, 0.38438687763629015`, 0.9377809773127133]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.028685633809430733`], {
             RGBColor[
             0.6142711963162304, 0.6977320556283797, 0.9627768252049985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.028685633809430733`], {
             RGBColor[
             0.9909995879120733, 0.9905461125486716, 0.7988236508241691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.028685633809430733`], {
             RGBColor[
             0.847444298272204, 0.36568324351003745`, 0.19306601964712058`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.028685633809430733`], {
             RGBColor[
             0.20274272640358343`, 0.3304258384544339, 0.9348572703864743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.028685633809430733`], {
             RGBColor[
             0.37110890510299593`, 0.49585761394946637`, 0.9448677091678112]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.028685633809430733`], {
             RGBColor[
             0.1807916321529833, 0.30735384661729226`, 0.9336071880426363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.028685633809430733`], {
             RGBColor[
             0.20696414784897932`, 0.33486282004712353`, 0.9350976740927561]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.028685633809430733`], {
             RGBColor[
             0.8274245231995631, 0.21180247958034423`, 0.17389506042845765`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.028685633809430733`], {
             RGBColor[
             0.1874689911967999, 0.31437217434135956`, 0.9339874537619143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.028685633809430733`], {
             RGBColor[
             0.18829908866819065`, 0.31524465941501073`, 0.9340347265848907]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.028685633809430733`], {
             RGBColor[
             0.21206977390702858`, 0.3402291567495223, 0.9353884319436652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.028685633809430733`], {
             RGBColor[
             0.2677744651747997, 0.39877831915336787`, 0.938560731703659]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.028685633809430733`], {
             RGBColor[
             0.2680749969538752, 0.3990941971079916, 0.9385778465438803]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.028685633809430733`], {
             RGBColor[
             0.18155548323377793`, 0.30815670253416316`, 0.9336506882316712]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.028685633809430733`], {
             RGBColor[
             0.30560245203902436`, 0.43853793178056216`, 0.9407149795940849]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.028685633809430733`], {
             RGBColor[
             0.18889078087796188`, 0.3158665654429332, 0.934068422580907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.028685633809430733`], {
             RGBColor[
             0.3286879472145684, 0.4591147123658486, 0.9421646832425408]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.028685633809430733`], {
             RGBColor[
             0.19492141529937626`, 0.32220514458414634`, 0.9344118582896825]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.028685633809430733`], {
             RGBColor[
             0.25591378716406765`, 0.38631199455366855`, 0.9378852836372484]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.028685633809430733`], {
             RGBColor[
             0.47311473175482466`, 0.583134878671169, 0.9516644712415576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.028685633809430733`], {
             RGBColor[
             0.23685058796865582`, 0.3662753635226519, 0.9367996626445457]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.028685633809430733`], {
             RGBColor[
             0.2213158585080208, 0.34994737790078817`, 0.9359149827833353]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.028685633809430733`], {
             RGBColor[
             0.18345440314028216`, 0.3101525877543751, 0.9337588289111464]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.028685633809430733`], {
             RGBColor[
             0.5041410272247835, 0.6083234230523641, 0.954106974874018]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.028685633809430733`], {
             RGBColor[
             0.19743844380411263`, 0.32485070113144887`, 0.9345551993394172]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.028685633809430733`], {
             RGBColor[
             0.8220097648168001, 0.1701822738881748, 0.16870988168602888`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.028685633809430733`], {
             RGBColor[
             0.20625914549310514`, 0.3341218178713687, 0.9350575252515466]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.028685633809430733`], {
             RGBColor[
             0.20787897197296468`, 0.3358243582046317, 0.9351497719732561]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.028685633809430733`], {
             RGBColor[
             0.989868357531768, 0.9900783197151207, 0.8175710657562082]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[401, 0.028685633809430733`], {
             RGBColor[
             0.18072732343424755`, 0.30728625407649274`, 0.9336035257562406]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[402, 0.028685633809430733`], {
             RGBColor[
             0.21812922311479366`, 0.346598022058153, 0.9357335086118955]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[403, 0.028685633809430733`], {
             RGBColor[
             0.7434088886883141, 0.7994759410509097, 0.9750597085395519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[404, 0.028685633809430733`], {
             RGBColor[
             0.8368269464602606, 0.8727271083178094, 0.9842984952692555]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[405, 0.028685633809430733`], {
             RGBColor[
             0.1816592229448945, 0.3082657395480243, 0.9336565960547502]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[406, 0.028685633809430733`], {
             RGBColor[
             0.41650215403555035`, 0.5351749646438152, 0.9477601268501196]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[407, 0.028685633809430733`], {
             RGBColor[
             0.2771295864414469, 0.4086111447535611, 0.9390934920201328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[408, 0.028685633809430733`], {
             RGBColor[
             0.9372841166711893, 0.9527471774179826, 0.9910458109403161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[409, 0.028685633809430733`], {
             RGBColor[
             0.2532336129818181, 0.38349496155526636`, 0.9377326516825317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[410, 0.028685633809430733`], {
             RGBColor[
             0.18224818387414324`, 0.30888477482694443`, 0.9336901365083813]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[411, 0.028685633809430733`], {
             RGBColor[
             0.281209290628112, 0.4128991725219315, 0.9393258251381819]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[412, 0.028685633809430733`], {
             RGBColor[
             0.1902556572489104, 0.31730113704696017`, 0.934146150271079]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[413, 0.028685633809430733`], {
             RGBColor[
             0.23030998251802656`, 0.3594007724957031, 0.936427184840091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[414, 0.028685633809430733`], {
             RGBColor[
             0.4226665958174486, 0.5405142942814426, 0.9481529196294604]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[415, 0.028685633809430733`], {
             RGBColor[
             0.1803991146634024, 0.3069412858486965, 0.9335848347522823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[416, 0.028685633809430733`], {
             RGBColor[
             0.20922896777355948`, 0.3372432893857343, 0.9352266522369601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[417, 0.028685633809430733`], {
             RGBColor[
             0.19713115786974042`, 0.32452772413137015`, 0.9345376998600435]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[418, 0.028685633809430733`], {
             RGBColor[
             0.4765052907931592, 0.5858874872414329, 0.9519313884690823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[419, 0.028685633809430733`], {
             RGBColor[
             0.649286320101708, 0.725946675113037, 0.9656784505282513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[420, 0.028685633809430733`], {
             RGBColor[
             0.1880446060283209, 0.31497718202537633`, 0.9340202341750236]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[421, 0.028685633809430733`], {
             RGBColor[
             0.1843367269803192, 0.31107996605281657`, 0.9338090759485553]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[422, 0.028685633809430733`], {
             RGBColor[
             0.20654013009820746`, 0.33441715050678417`, 0.9350735269091277]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[423, 0.028685633809430733`], {
             RGBColor[
             0.1791999116318114, 0.3056808474286306, 0.9335165419136952]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[424, 0.028685633809430733`], {
             RGBColor[
             0.19347184238884513`, 0.3206815515469472, 0.9343293072568787]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[425, 0.028685633809430733`], {
             RGBColor[
             0.18667870528248892`, 0.31354153373839766`, 0.9339424481482175]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[426, 0.028685633809430733`], {
             RGBColor[
             0.18735694523176508`, 0.31425440692798345`, 0.9339810729099627]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[427, 0.028685633809430733`], {
             RGBColor[
             0.18651414967483487`, 0.3133685753613251, 0.9339330769497998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[428, 0.028685633809430733`], {
             RGBColor[
             0.18777404508405116`, 0.31469280531839416`, 0.9340048261295064]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[429, 0.028685633809430733`], {
             RGBColor[
             0.1919491178531559, 0.319081071513626, 0.9342425903472402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[430, 0.028685633809430733`], {
             RGBColor[
             0.20155620116286646`, 0.329178725196395, 0.9347896995293221]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[431, 0.028685633809430733`], {
             RGBColor[
             0.4212519905865513, 0.5392890343305656, 0.9480627822350338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[432, 0.028685633809430733`], {
             RGBColor[
             0.29123303955595214`, 0.4234347681874807, 0.9398966628108147]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[433, 0.028685633809430733`], {
             RGBColor[
             0.18067343227102245`, 0.30722961104704605`, 0.9336004567342198]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[434, 0.028685633809430733`], {
             RGBColor[
             0.9350798973521478, 0.7803204568826958, 0.2666219654201177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[435, 0.028685633809430733`], {
             RGBColor[
             0.23839852597207306`, 0.3679023445091814, 0.9368878154238712]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[436, 0.028685633809430733`], {
             RGBColor[
             0.35552088653300873`, 0.4823560557407374, 0.9438744544084752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[437, 0.028685633809430733`], {
             RGBColor[
             0.18191959414620315`, 0.3085394061890873, 0.93367142380948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[438, 0.028685633809430733`], {
             RGBColor[
             0.20264182690306143`, 0.3303197866819874, 0.9348515243091869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[439, 0.028685633809430733`], {
             RGBColor[
             0.19923030702383038`, 0.32673406298606217`, 0.934657243298956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[440, 0.028685633809430733`], {
             RGBColor[
             0.8916325056316791, 0.6008103425923479, 0.23128784517976625`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[441, 0.028685633809430733`], {
             RGBColor[
             0.22146757953397317`, 0.3501068463187328, 0.935923623071312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[442, 0.028685633809430733`], {
             RGBColor[
             0.2379042947950852, 0.36738287620610066`, 0.9368596696894913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[443, 0.028685633809430733`], {
             RGBColor[
             0.2878366774276409, 0.41986497624882907`, 0.9397032450120749]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[444, 0.028685633809430733`], {
             RGBColor[
             0.5658641034717166, 0.6584329969425219, 0.9589660415352547]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[445, 0.028685633809430733`], {
             RGBColor[
             0.9631188181102052, 0.8872532547517151, 0.3112240020952856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[446, 0.028685633809430733`], {
             RGBColor[
             0.18340710413885652`, 0.31010287350494686`, 0.9337561353029877]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[447, 0.028685633809430733`], {
             RGBColor[
             0.23372958097512028`, 0.36299498728917345`, 0.9366219259133799]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[448, 0.028685633809430733`], {
             RGBColor[
             0.300584051971647, 0.4332632751248068, 0.9404291891343054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[449, 0.028685633809430733`], {
             RGBColor[
             0.9836066487684537, 0.9563635183333898, 0.39081535540040413`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[450, 0.028685633809430733`], {
             RGBColor[
             0.2155265395117455, 0.34386243657167787`, 0.9355852896310274]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[451, 0.028685633809430733`], {
             RGBColor[
             0.20508673054441848`, 0.33288953542489785`, 0.9349907579546514]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[452, 0.028685633809430733`], {
             RGBColor[
             0.22680832648896532`, 0.3557203099913444, 0.9362277707094718]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[453, 0.028685633809430733`], {
             RGBColor[
             0.23993040743871616`, 0.3695124490575181, 0.936975053807181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[454, 0.028685633809430733`], {
             RGBColor[
             0.21139233227849236`, 0.33951712264565065`, 0.9353498526451051]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[455, 0.028685633809430733`], {
             RGBColor[
             0.6130446091083116, 0.6967362568758672, 0.9626802637668542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[456, 0.028685633809430733`], {
             RGBColor[
             0.19561148544389112`, 0.32293045205900567`, 0.9344511567635453]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[457, 0.028685633809430733`], {
             RGBColor[
             0.4692511982227218, 0.5799982880996057, 0.9513603197293209]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[458, 0.028685633809430733`], {
             RGBColor[
             0.2390221871354001, 0.3685578519342398, 0.9369233320044987]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[459, 0.028685633809430733`], {
             RGBColor[
             0.1944799719611093, 0.3217411596465035, 0.9343867187446251]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[460, 0.028685633809430733`], {
             RGBColor[
             0.3006736022333113, 0.4333573981276305, 0.9404342888892294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[461, 0.028685633809430733`], {
             RGBColor[
             0.25327163562221944`, 0.38353492576110276`, 0.9377348170156531]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[462, 0.028685633809430733`], {
             RGBColor[
             0.1900670199072787, 0.31710286724060704`, 0.934135407653537]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[463, 0.028685633809430733`], {
             RGBColor[
             0.5551591248464408, 0.6497422130407317, 0.9581233064042441]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[464, 0.028685633809430733`], {
             RGBColor[
             0.20245401245038683`, 0.33012238178410236`, 0.9348408285539537]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[465, 0.028685633809430733`], {
             RGBColor[
             0.1790493149440538, 0.30552256076141593`, 0.9335079656551152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[466, 0.028685633809430733`], {
             RGBColor[
             0.19488624546246058`, 0.32216817885565147`, 0.9344098554194993]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[467, 0.028685633809430733`], {
             RGBColor[
             0.19114672360584797`, 0.3182377042849717, 0.934196895181892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[468, 0.028685633809430733`], {
             RGBColor[
             0.22150150348383524`, 0.3501425025409405, 0.9359255549900708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[469, 0.028685633809430733`], {
             RGBColor[
             0.18135253868176207`, 0.30794339494256673`, 0.9336391308396634]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[470, 0.028685633809430733`], {
             RGBColor[
             0.19461387303716265`, 0.3218818981672542, 0.9343943442128174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[471, 0.028685633809430733`], {
             RGBColor[
             0.9568366664708343, 0.967329437044196, 0.9579484442512339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[472, 0.028685633809430733`], {
             RGBColor[
             0.18313584696674626`, 0.3098177650183609, 0.9337406876083251]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[473, 0.028685633809430733`], {
             RGBColor[
             0.2635938852306148, 0.3943842645679517, 0.9383226538604513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[474, 0.028685633809430733`], {
             RGBColor[
             0.22951352418939525`, 0.35856364429393695`, 0.93638182771653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[475, 0.028685633809430733`], {
             RGBColor[
             0.3365285973416883, 0.465905889423426, 0.9426642825354262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[476, 0.028685633809430733`], {
             RGBColor[
             0.18343003159278173`, 0.31012697171270676`, 0.9337574409875706]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[477, 0.028685633809430733`], {
             RGBColor[
             0.19779376632799722`, 0.32522416763280076`, 0.9345754344314999]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[478, 0.028685633809430733`], {
             RGBColor[
             0.24931371638514488`, 0.37937490169636373`, 0.9375094193703185]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[479, 0.028685633809430733`], {
             RGBColor[
             0.18231814009471767`, 0.3089583032502487, 0.933694120411652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[480, 0.028685633809430733`], {
             RGBColor[
             0.24336115250331075`, 0.37311837964220756`, 0.9371704296632771]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[481, 0.028685633809430733`], {
             RGBColor[
             0.20526876593224802`, 0.3330808661592169, 0.9350011246006911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[482, 0.028685633809430733`], {
             RGBColor[
             0.3323719943960167, 0.4623056488688239, 0.9423994274712677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[483, 0.028685633809430733`], {
             RGBColor[
             0.4520407911262143, 0.5659567458679113, 0.9500246173799538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[484, 0.028685633809430733`], {
             RGBColor[
             0.1848118632397346, 0.3115793643868409, 0.933836134255628]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[485, 0.028685633809430733`], {
             RGBColor[
             0.255344871987097, 0.38571402863136683`, 0.9378528847595545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[486, 0.028685633809430733`], {
             RGBColor[
             0.41333459859387617`, 0.5324313873262027, 0.9475582930183354]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[487, 0.028685633809430733`], {
             RGBColor[
             0.19274009296176206`, 0.31991243650348955`, 0.9342876352095326]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[488, 0.028685633809430733`], {
             RGBColor[
             0.18252871209609148`, 0.30917962777472857`, 0.9337061121756168]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[489, 0.028685633809430733`], {
             RGBColor[
             0.19162106685648111`, 0.3187362691164863, 0.9342239083282876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[490, 0.028685633809430733`], {
             RGBColor[
             0.2159679187439516, 0.3443263541297861, 0.9356104255253395]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[491, 0.028685633809430733`], {
             RGBColor[
             0.1816268290277524, 0.30823169148721496`, 0.9336547512690914]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[492, 0.028685633809430733`], {
             RGBColor[
             0.18260872208869527`, 0.3092637233498817, 0.9337106686263315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[493, 0.028685633809430733`], {
             RGBColor[
             0.2609046791964185, 0.39155773852050096`, 0.9381695075551277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[494, 0.028685633809430733`], {
             RGBColor[
             0.35530253300255993`, 0.4821669288874302, 0.9438605411145975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[495, 0.028685633809430733`], {
             RGBColor[
             0.8860920716837987, 0.5756525260362475, 0.22666477128519144`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[496, 0.028685633809430733`], {
             RGBColor[
             0.1858152550736946, 0.31263399282304966`, 0.9338932759361868]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[497, 0.028685633809430733`], {
             RGBColor[
             0.4781822073170808, 0.587248883619781, 0.9520634014805931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[498, 0.028685633809430733`], {
             RGBColor[
             0.7745863239297996, 0.8238319904188423, 0.9781671839147258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[499, 0.028685633809430733`], {
             RGBColor[
             0.628572856489554, 0.7093427876395323, 0.96390270428255]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[500, 0.028685633809430733`], {
             RGBColor[
             0.20098870068601762`, 0.3285822462136184, 0.9347573812167074]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{3.8349504055390835`*^9, 3.834957759852075*^9, 
  3.835018922383715*^9, 3.835019017360054*^9, 3.835020551743785*^9},
 CellLabel->"Out[76]=",ExpressionUUID->"5eca06b3-3d68-4fc0-9251-66dc617f1d1c"]
}, Open  ]],

Cell["Estimated with Max-Min Deviation v Calculated: (r = 3)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 3.8349503922098827`*^9}, {3.8349504781120467`*^9, 
  3.8349504928656063`*^9}},ExpressionUUID->"303aa71f-d419-41da-bcbf-\
8a6b167182db"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphin5", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsi5", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}], 
     "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"mMDi3500", ",", "kri5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502554527807`*^9}, {3.8349577716948586`*^9, 
   3.8349577796673746`*^9}, {3.835018835203446*^9, 3.8350188366714215`*^9}, 
   3.8350558445568604`*^9},
 CellLabel->"In[77]:=",ExpressionUUID->"af3b01fa-d110-4b6d-a557-746a6985f1fb"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1dOWGAgQBNBMbNu2bds2J+bEtm3btm3btu01sjdnH271F1R1ssCg6p0C
ggUL9l38vMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEIS
kZgkJCUZyUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpR
mCIUpRjFKUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGY
JjSlGYE0pwUtaUVr2tCWdrSnAx3pRBCd6UJXutGdHvSkF73pQ1/60Z8BDGQQ
gxnCUIYxnBGMZBSjGcNYxjGeCUxkEpOZwlSmMZ0ZzGQWs5nDXOYxnwUsZBGL
WcJSlrGcFaxkFatZw1rWsZ4NbGQTm9nCVraxnR3sZBe72cNe9rGfAxzkEIc5
wlGOcZwTnOQUpznDWc5xngtc5BKXucJVrnGdG9zkFre5w13ucZ8HPOQRj3nC
U57xnBe85BWvecNb3vGeD3zkE5/5wle+8Z1f+JXf+J0/+JO/+Jt/+Jcf/Cx/
AMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEISkZgkJCUZ
yUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpRmCIUpRjF
KUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGYJjSlGYE0
pwUtaUVr2tCWdrSnAx35Od5BdKYLXelGd3rQk170pg996Ud/BjCQQQxmCEMZ
xnBGMJJRjGYMYxnHeCYwkUlMZgpTmcZ0ZjCTWcxmDnOZx3wWsJBFLGYJS1nG
clawklWsZg1rWcd6NrCRTWxmC1vZxnZ2sJNd7GYPe9nHfg5wkEMc5ghHOcZx
TnCSU5zmDGc5x3kucJFLXOYKV7nGdW5wk1vc5g53ucd9HvCQRzzmCU95xnNe
8JJXvOYNb3nHez7wkU985gtf+Rbw/z//Dz189+A=
          "], {Null, CompressedData["
1:eJxF3Al0ldW5gOF/21YsVqt2QFCqdkClVEWUGRVRJmWoghGKIgREKWUqk4DM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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[13, 59] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[210, 309] -> 
             RGBColor[
              0.6328412352941177, 0.696838794117647, 0.8243899117647061], 
             UndirectedEdge[88, 427] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.608346705882353], 
             UndirectedEdge[293, 483] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[46, 150] -> 
             RGBColor[
              0.863816294117647, 0.40812864705882373`, 0.20545620588235297`], 
             UndirectedEdge[400, 444] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[98, 105] -> 
             RGBColor[
              0.8068343235294118, 0.6648019411764707, 0.5968332647058824], 
             UndirectedEdge[128, 439] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[23, 62] -> 
             RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             UndirectedEdge[201, 236] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[40, 477] -> 
             RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             UndirectedEdge[455, 482] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.830958529411765], 
             UndirectedEdge[60, 131] -> 
             RGBColor[
              0.6328412352941177, 0.696838794117647, 0.8243899117647061], 
             UndirectedEdge[179, 222] -> 
             RGBColor[
              0.6807162647058824, 0.7405875882352941, 0.7206171176470587], 
             UndirectedEdge[111, 175] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[51, 110] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647057], 
             UndirectedEdge[84, 261] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529414, 0.6198870882352941], 
             UndirectedEdge[156, 479] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[158, 437] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[103, 355] -> 
             RGBColor[
              0.6293350294117647, 0.6955299117647059, 0.8927477647058825], 
             UndirectedEdge[13, 228] -> 
             RGBColor[
              0.9285733529411766, 0.7545241764705886, 0.26138664705882364`], 
             UndirectedEdge[59, 409] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[243, 430] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[333, 441] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             UndirectedEdge[179, 385] -> 
             RGBColor[
              0.6807162647058824, 0.7405875882352941, 0.7206171176470587], 
             UndirectedEdge[81, 447] -> 
             RGBColor[
              0.5539096176470588, 0.6257657352941176, 0.9632903823529412], 
             UndirectedEdge[69, 404] -> 
             RGBColor[
              0.9361957058823529, 0.7637870000000002, 0.464683029411765], 
             UndirectedEdge[113, 380] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[85, 489] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[277, 498] -> 
             RGBColor[
              0.8970220882352942, 0.8539625882352943, 0.630683911764706], 
             UndirectedEdge[18, 160] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529411], 
             UndirectedEdge[355, 431] -> 
             RGBColor[
              0.631860411764706, 0.6947409117647059, 0.7176333235294117], 
             UndirectedEdge[357, 492] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[165, 386] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882355], 
             UndirectedEdge[218, 274] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[116, 441] -> 
             RGBColor[
              0.6807162647058824, 0.7405875882352941, 0.7206171176470587], 
             UndirectedEdge[258, 435] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[112, 445] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[114, 179] -> 
             RGBColor[
              0.6485839411764706, 0.7197705294117647, 0.9688834705882352], 
             UndirectedEdge[155, 467] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[243, 421] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[172, 289] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[381, 468] -> 
             RGBColor[
              0.4576613823529412, 0.5496956176470588, 0.9539308529411765], 
             UndirectedEdge[17, 277] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[279, 477] -> 
             RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             UndirectedEdge[4, 405] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[36, 379] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[278, 401] -> 
             RGBColor[
              0.9468331176470589, 0.8269180588235298, 0.27607888235294126`], 
             UndirectedEdge[152, 399] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[173, 406] -> 
             RGBColor[
              0.5539096176470588, 0.6257657352941177, 0.9632903823529412], 
             UndirectedEdge[239, 332] -> 
             RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             UndirectedEdge[116, 361] -> 
             RGBColor[
              0.6816970882352942, 0.7426854705882353, 0.8273737058823531], 
             UndirectedEdge[288, 498] -> 
             RGBColor[
              0.9674696176470589, 0.908133823529412, 0.561427411764706], 
             UndirectedEdge[16, 386] -> 
             RGBColor[
              0.6328412352941177, 0.696838794117647, 0.8243899117647061], 
             UndirectedEdge[216, 464] -> 
             RGBColor[
              0.7918034117647059, 0.8375021764705881, 0.9798248235294118], 
             UndirectedEdge[379, 400] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[22, 24] -> 
             RGBColor[
              0.6575543823529413, 0.660160823529412, 0.6103830294117647], 
             UndirectedEdge[231, 355] -> 
             RGBColor[
              0.5997280882352941, 0.6739238529411764, 0.9658996764705883], 
             UndirectedEdge[434, 495] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[75, 323] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[165, 288] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[90, 229] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[267, 424] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[258, 403] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[274, 305] -> 
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352], 
             UndirectedEdge[399, 478] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[359, 463] -> 
             RGBColor[
              0.5539096176470588, 0.6257657352941177, 0.9632903823529412], 
             UndirectedEdge[302, 422] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[21, 335] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882355], 
             UndirectedEdge[266, 445] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.830958529411765], 
             UndirectedEdge[200, 452] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[112, 471] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[481, 496] -> 
             RGBColor[
              0.7880378235294117, 0.8342091176470589, 0.9514881470588235], 
             UndirectedEdge[6, 422] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529414, 0.6198870882352941], 
             UndirectedEdge[137, 424] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[89, 482] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[142, 254] -> 
             RGBColor[
              0.8318199411764706, 0.2455875882352943, 0.17810411764705886`], 
             UndirectedEdge[178, 321] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[151, 456] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[346, 431] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[65, 297] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[79, 253] -> 
             RGBColor[
              0.961070411764706, 0.8776436470588238, 0.31732720588235297`], 
             UndirectedEdge[376, 475] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[209, 259] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[464, 496] -> 
             RGBColor[
              0.672697294117647, 0.7437244705882353, 0.9683612352941176], 
             UndirectedEdge[101, 103] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[69, 348] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[116, 277] -> 
             RGBColor[
              0.6077433529411764, 0.6872053529411765, 0.9649880588235293], 
             UndirectedEdge[171, 471] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[133, 429] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[37, 203] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[299, 399] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[311, 429] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[327, 446] -> 
             RGBColor[
              0.7880378235294117, 0.8342091176470589, 0.9514881470588235], 
             UndirectedEdge[15, 249] -> 
             RGBColor[0.9326895, 0.762478117647059, 0.5330408823529413], 
             UndirectedEdge[50, 242] -> 
             RGBColor[
              0.599728088235294, 0.6739238529411764, 0.9658996764705883], 
             UndirectedEdge[163, 355] -> 
             RGBColor[0.5588875, 0.6413586764705882, 0.9620042647058824], 
             UndirectedEdge[192, 435] -> 
             RGBColor[
              0.938695205882353, 0.8285484117647062, 0.5936544705882354], 
             UndirectedEdge[31, 191] -> 
             RGBColor[
              0.7918034117647059, 0.8375021764705881, 0.9798248235294118], 
             UndirectedEdge[385, 415] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             UndirectedEdge[207, 257] -> 
             RGBColor[
              0.7913583235294117, 0.5755227058823531, 0.5831754705882353], 
             UndirectedEdge[359, 408] -> 
             RGBColor[
              0.3939629117647059, 0.4994228529411765, 0.9479313823529412], 
             UndirectedEdge[183, 202] -> 
             RGBColor[
              0.6676762352941177, 0.7341850588235295, 0.9426508529411765], 
             UndirectedEdge[170, 223] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[40, 430] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[69, 444] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882355], 
             UndirectedEdge[215, 417] -> 
             RGBColor[
              0.7596562058823529, 0.6877910000000003, 0.6045280882352941], 
             UndirectedEdge[423, 429] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[5, 83] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[311, 366] -> 
             RGBColor[
              0.7880378235294117, 0.8342091176470589, 0.9514881470588235], 
             UndirectedEdge[133, 366] -> 
             RGBColor[
              0.7779159705882353, 0.7601848823529413, 0.6192203235294118], 
             UndirectedEdge[76, 359] -> 
             RGBColor[
              0.5126239411764706, 0.3312210882352943, 0.5627456176470589], 
             UndirectedEdge[172, 218] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[177, 484] -> 
             RGBColor[
              0.6575543823529413, 0.660160823529412, 0.6103830294117647], 
             UndirectedEdge[45, 328] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[115, 144] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[63, 72] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[248, 387] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[34, 44] -> 
             RGBColor[
              0.6781908823529412, 0.7413765882352942, 0.8957315588235295], 
             UndirectedEdge[279, 285] -> 
             RGBColor[
              0.7779159705882353, 0.7601848823529413, 0.6192203235294118], 
             UndirectedEdge[13, 77] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.6083467058823531], 
             UndirectedEdge[53, 445] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[91, 298] -> 
             RGBColor[
              0.7318321176470588, 0.7872340588235294, 0.8993163823529413], 
             UndirectedEdge[6, 451] -> 
             RGBColor[
              0.5446202941176471, 0.4937621470588237, 0.590097705882353], 
             UndirectedEdge[87, 256] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[153, 172] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[72, 438] -> 
             RGBColor[
              0.7281049411764706, 0.7872294117647058, 0.9738253529411764], 
             UndirectedEdge[207, 440] -> 
             RGBColor[
              0.7918034117647059, 0.8375021764705881, 0.9798248235294118], 
             UndirectedEdge[19, 228] -> 
             RGBColor[
              0.6929358529411764, 0.6336244117647061, 0.5992756176470588], 
             UndirectedEdge[8, 63] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[72, 128] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[229, 485] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[32, 407] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[475, 478] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[194, 412] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[370, 390] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[231, 233] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[114, 385] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[271, 442] -> 
             RGBColor[0.9326895, 0.762478117647059, 0.5330408823529413], 
             UndirectedEdge[206, 254] -> 
             RGBColor[
              0.8731056176470589, 0.5401322352941176, 0.5786488823529412], 
             UndirectedEdge[262, 455] -> 
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647], 
             UndirectedEdge[7, 341] -> 
             RGBColor[
              0.7281049411764706, 0.7872294117647058, 0.9738253529411764], 
             UndirectedEdge[187, 328] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[44, 56] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[142, 388] -> 
             RGBColor[0.9172135, 0.6731988823529413, 0.5193830882352943], 
             UndirectedEdge[282, 419] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[7, 244] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[107, 470] -> 
             RGBColor[
              0.8467659705882353, 0.6190276470588236, 0.5886395882352942], 
             UndirectedEdge[10, 383] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[249, 419] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[191, 271] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[297, 490] -> 
             RGBColor[
              0.6613845882352941, 0.7330628235294117, 0.9685728823529411], 
             UndirectedEdge[32, 176] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[353, 487] -> 
             RGBColor[
              0.6717916764705882, 0.7108864117647059, 0.6516313529411765], 
             UndirectedEdge[281, 324] -> 
             RGBColor[
              0.7918034117647059, 0.8375021764705881, 0.9798248235294118], 
             UndirectedEdge[19, 59] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.830958529411765], 
             UndirectedEdge[197, 411] -> 
             RGBColor[
              0.7318321176470588, 0.7872340588235294, 0.8993163823529413], 
             UndirectedEdge[163, 343] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[12, 396] -> 
             RGBColor[
              0.6717916764705882, 0.7108864117647059, 0.6516313529411765], 
             UndirectedEdge[51, 397] -> 
             RGBColor[0.7276598529411764, 0.5252499411764708, 0.577176], 
             UndirectedEdge[448, 482] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[183, 285] -> 
             RGBColor[
              0.6575543823529413, 0.660160823529412, 0.6103830294117647], 
             UndirectedEdge[155, 365] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[122, 217] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[249, 269] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[101, 331] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[246, 458] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[35, 437] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[354, 473] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.608346705882353], 
             UndirectedEdge[230, 484] -> 
             RGBColor[
              0.961070411764706, 0.8776436470588238, 0.31732720588235297`], 
             UndirectedEdge[108, 190] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[55, 136] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[59, 279] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[24, 170] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[184, 388] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[173, 242] -> 
             RGBColor[
              0.5539096176470588, 0.6257657352941177, 0.9632903823529412], 
             UndirectedEdge[4, 345] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[59, 256] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[232, 480] -> 
             RGBColor[
              0.9285733529411766, 0.7545241764705886, 0.26138664705882364`], 
             UndirectedEdge[3, 437] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[199, 448] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647057], 
             UndirectedEdge[151, 226] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[241, 442] -> 
             RGBColor[0.6227742647058824, 0.514505117647059, 0.5819965], 
             UndirectedEdge[303, 400] -> 
             RGBColor[
              0.9262902941176471, 0.7319879411764708, 0.2889406764705883], 
             UndirectedEdge[42, 378] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[15, 499] -> 
             RGBColor[0.6227742647058824, 0.514505117647059, 0.5819965], 
             UndirectedEdge[341, 374] -> 
             RGBColor[
              0.8787623235294117, 0.781568705882353, 0.6159916764705883], 
             UndirectedEdge[312, 334] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[7, 482] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[219, 403] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[50, 449] -> 
             RGBColor[
              0.4397813823529412, 0.5475809705882353, 0.9505406764705882], 
             UndirectedEdge[318, 430] -> 
             RGBColor[
              0.6717916764705882, 0.7108864117647059, 0.6516313529411765], 
             UndirectedEdge[242, 449] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[356, 365] -> 
             RGBColor[
              0.7213174705882353, 0.7800425294117648, 0.9462356764705883], 
             UndirectedEdge[154, 219] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[69, 275] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[173, 310] -> 
             RGBColor[
              0.5730019117647058, 0.6401802647058823, 0.9370577647058824], 
             UndirectedEdge[351, 460] -> 
             RGBColor[
              0.7254329117647058, 0.7567438823529412, 0.6552161764705883], 
             UndirectedEdge[97, 207] -> 
             RGBColor[
              0.5523357058823529, 0.6437004117647058, 0.9595239411764706], 
             UndirectedEdge[122, 212] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[45, 224] -> 
             RGBColor[
              0.7880378235294117, 0.8342091176470589, 0.9514881470588235], 
             UndirectedEdge[144, 215] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[22, 214] -> 
             RGBColor[
              0.6676762352941177, 0.7341850588235295, 0.9426508529411765], 
             UndirectedEdge[142, 150] -> 
             RGBColor[
              0.8318199411764706, 0.2455875882352943, 0.17810411764705886`], 
             UndirectedEdge[149, 419] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[11, 418] -> 
             RGBColor[
              0.9030825588235294, 0.7408720588235296, 0.606192794117647], 
             UndirectedEdge[189, 346] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[185, 224] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[17, 386] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[194, 476] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[258, 471] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[203, 397] -> 
             RGBColor[
              0.920719705882353, 0.6745077647058826, 0.45102523529411787`], 
             UndirectedEdge[126, 173] -> 
             RGBColor[
              0.5835165588235294, 0.6473717941176471, 0.8901384705882354], 
             UndirectedEdge[30, 366] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647057], 
             UndirectedEdge[95, 368] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[15, 242] -> 
             RGBColor[
              0.9030825588235294, 0.7408720588235296, 0.606192794117647], 
             UndirectedEdge[150, 392] -> 
             RGBColor[
              0.8322650294117647, 0.5075670588235294, 0.5747534705882353], 
             UndirectedEdge[179, 296] -> 
             RGBColor[
              0.5523357058823529, 0.6437004117647058, 0.9595239411764706], 
             UndirectedEdge[3, 123] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[37, 257] -> 
             RGBColor[
              0.9197388823529412, 0.6724098823529414, 0.34426864705882343`], 
             UndirectedEdge[17, 178] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[68, 367] -> 
             RGBColor[
              0.6717916764705882, 0.7108864117647059, 0.6516313529411765], 
             UndirectedEdge[1, 363] -> 
             RGBColor[
              0.7254329117647058, 0.7567438823529412, 0.6552161764705883], 
             UndirectedEdge[227, 329] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[121, 420] -> 
             RGBColor[
              0.631860411764706, 0.6947409117647059, 0.7176333235294117], 
             UndirectedEdge[82, 149] -> 
             RGBColor[
              0.5870227647058823, 0.6486806764705881, 0.821780617647059], 
             UndirectedEdge[129, 355] -> 
             RGBColor[
              0.2247454705882353, 0.35355211764705885`, 0.9361102941176471], 
             UndirectedEdge[87, 388] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[91, 228] -> 
             RGBColor[
              0.6929358529411764, 0.6336244117647061, 0.5992756176470588], 
             UndirectedEdge[12, 161] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[64, 115] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[56, 342] -> 
             RGBColor[0.5588875, 0.6413586764705882, 0.9620042647058824], 
             UndirectedEdge[378, 416] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[119, 363] -> 
             RGBColor[
              0.7318321176470588, 0.7872340588235294, 0.8993163823529413], 
             UndirectedEdge[391, 455] -> 
             RGBColor[
              0.6059769411764705, 0.6895578823529411, 0.9631087647058824], 
             UndirectedEdge[249, 282] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[226, 429] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[181, 189] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[160, 167] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             UndirectedEdge[16, 277] -> 
             RGBColor[0.5588875, 0.6413586764705882, 0.9620042647058824], 
             UndirectedEdge[295, 341] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[69, 129] -> 
             RGBColor[
              0.5870227647058823, 0.6486806764705882, 0.821780617647059], 
             UndirectedEdge[352, 368] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[194, 297] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[188, 228] -> 
             RGBColor[
              0.9527160588235295, 0.837048823529412, 0.47837732352941204`], 
             UndirectedEdge[273, 430] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[200, 468] -> 
             RGBColor[
              0.5860419411764706, 0.6465827941176471, 0.7150240294117647], 
             UndirectedEdge[93, 172] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[61, 341] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[121, 442] -> 
             RGBColor[
              0.5739184117647058, 0.46865844117647076`, 0.579012705882353], 
             UndirectedEdge[287, 336] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[403, 497] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529414, 0.6198870882352941], 
             UndirectedEdge[17, 407] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[135, 470] -> 
             RGBColor[0.9172135, 0.6731988823529413, 0.5193830882352942], 
             UndirectedEdge[322, 471] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[24, 52] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.6083467058823531], 
             UndirectedEdge[163, 440] -> 
             RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             UndirectedEdge[274, 432] -> 
             RGBColor[
              0.9197388823529412, 0.6724098823529414, 0.34426864705882343`], 
             UndirectedEdge[89, 261] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[255, 312] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[370, 422] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[43, 90] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[373, 449] -> 
             RGBColor[
              0.7880378235294117, 0.8342091176470589, 0.9514881470588235], 
             UndirectedEdge[49, 457] -> 
             RGBColor[
              0.631860411764706, 0.6947409117647059, 0.7176333235294117], 
             UndirectedEdge[234, 449] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[245, 299] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[398, 464] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[245, 262] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[288, 321] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[433, 465] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[330, 367] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[106, 156] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[85, 239] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[336, 388] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[69, 355] -> 
             RGBColor[
              0.6328412352941176, 0.696838794117647, 0.8243899117647061], 
             UndirectedEdge[102, 383] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[296, 327] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[61, 288] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[141, 472] -> 
             RGBColor[
              0.9674696176470589, 0.908133823529412, 0.561427411764706], 
             UndirectedEdge[43, 485] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[9, 358] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[70, 359] -> 
             RGBColor[
              0.5730019117647058, 0.6401802647058824, 0.9370577647058824], 
             UndirectedEdge[466, 470] -> 
             RGBColor[
              0.8965770000000001, 0.5919831176470591, 0.23403455882352947`], 
             UndirectedEdge[41, 356] -> 
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647], 
             UndirectedEdge[79, 436] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[33, 175] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[176, 448] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[118, 481] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[326, 346] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[63, 435] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[194, 350] -> 
             RGBColor[
              0.9197388823529412, 0.6724098823529414, 0.34426864705882343`], 
             UndirectedEdge[275, 486] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[407, 478] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[62, 356] -> 
             RGBColor[
              0.6613845882352941, 0.7330628235294117, 0.9685728823529411], 
             UndirectedEdge[150, 426] -> 
             RGBColor[
              0.7768573823529412, 0.4640621176470588, 0.5692893529411764], 
             UndirectedEdge[372, 444] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[106, 329] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[128, 294] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[379, 440] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[227, 267] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[151, 345] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[275, 418] -> 
             RGBColor[
              0.9352148823529411, 0.761689117647059, 0.35792644117647054`], 
             UndirectedEdge[10, 232] -> 
             RGBColor[
              0.8416144411764706, 0.8104576470588236, 0.625219794117647], 
             UndirectedEdge[5, 431] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[42, 416] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[37, 97] -> 
             RGBColor[
              0.6807162647058824, 0.7405875882352941, 0.7206171176470587], 
             UndirectedEdge[441, 450] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647057], 
             UndirectedEdge[5, 259] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705883], 
             UndirectedEdge[279, 318] -> 
             RGBColor[
              0.4886372352941176, 0.5934276470588236, 0.9535244705882353], 
             UndirectedEdge[275, 355] -> 
             RGBColor[
              0.6318604117647059, 0.6947409117647059, 0.7176333235294117], 
             UndirectedEdge[344, 387] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[239, 489] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[21, 336] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[32, 312] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[77, 436] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[66, 294] -> 
             RGBColor[0.9326895, 0.762478117647059, 0.5330408823529413], 
             UndirectedEdge[197, 201] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.830958529411765], 
             UndirectedEdge[228, 256] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[292, 481] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[444, 486] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[154, 244] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[288, 386] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[273, 285] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[190, 487] -> 
             RGBColor[
              0.6717916764705882, 0.7108864117647059, 0.6516313529411765], 
             UndirectedEdge[83, 343] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[1, 315] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[4, 429] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[189, 451] -> 
             RGBColor[
              0.5130690294117647, 0.5932005588235294, 0.9593949705882353], 
             UndirectedEdge[10, 102] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[357, 368] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[128, 138] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[336, 436] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[196, 454] -> 
             RGBColor[
              0.6086985294117647, 0.6143141470588237, 0.6073992352941178], 
             UndirectedEdge[25, 164] -> 
             RGBColor[
              0.5523357058823529, 0.6437004117647058, 0.9595239411764706], 
             UndirectedEdge[125, 282] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[9, 286] -> 
             RGBColor[
              0.938695205882353, 0.8285484117647062, 0.5936544705882354], 
             UndirectedEdge[421, 477] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[105, 484] -> 
             RGBColor[
              0.8416144411764706, 0.8104576470588236, 0.625219794117647], 
             UndirectedEdge[299, 475] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[247, 252] -> 
             RGBColor[
              0.6077433529411764, 0.6872053529411765, 0.9649880588235293], 
             UndirectedEdge[261, 478] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[104, 303] -> 
             RGBColor[
              0.8772728823529412, 0.5356066470588239, 0.21930582352941183`], 
             UndirectedEdge[32, 66] -> 
             RGBColor[
              0.9030825588235294, 0.7408720588235296, 0.606192794117647], 
             UndirectedEdge[213, 454] -> 
             RGBColor[
              0.5997280882352941, 0.6739238529411764, 0.9658996764705883], 
             UndirectedEdge[129, 331] -> 
             RGBColor[
              0.5771173529411764, 0.6168816176470588, 0.6460382647058824], 
             UndirectedEdge[245, 475] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[90, 148] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[195, 496] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[241, 371] -> 
             RGBColor[0.4219168823529411, 0.5392610588235294, 0.948272], 
             UndirectedEdge[13, 243] -> 
             RGBColor[
              0.961070411764706, 0.8776436470588238, 0.31732720588235297`], 
             UndirectedEdge[246, 384] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[22, 268] -> 
             RGBColor[
              0.6676762352941177, 0.7341850588235295, 0.9426508529411765], 
             UndirectedEdge[69, 306] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[66, 128] -> 
             RGBColor[
              0.9361957058823529, 0.7637870000000002, 0.464683029411765], 
             UndirectedEdge[220, 413] -> 
             RGBColor[
              0.5280999411764706, 0.4205003235294119, 0.5764034117647059], 
             UndirectedEdge[319, 492] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[61, 186] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[94, 401] -> 
             RGBColor[0.912053, 0.6812623529411768, 0.24769235294117653`], 
             UndirectedEdge[429, 488] -> 
             RGBColor[
              0.5870227647058823, 0.6486806764705882, 0.821780617647059], 
             UndirectedEdge[11, 431] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[349, 487] -> 
             RGBColor[
              0.6781908823529412, 0.7413765882352942, 0.8957315588235295], 
             UndirectedEdge[156, 198] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[12, 188] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[70, 111] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[212, 286] -> 
             RGBColor[
              0.8787623235294117, 0.781568705882353, 0.6159916764705883], 
             UndirectedEdge[242, 282] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[70, 175] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[188, 298] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[286, 367] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[9, 492] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[37, 343] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[376, 391] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529411], 
             UndirectedEdge[230, 490] -> 
             RGBColor[
              0.7254329117647058, 0.7567438823529412, 0.6552161764705883], 
             UndirectedEdge[346, 355] -> 
             RGBColor[
              0.6188203823529411, 0.6883383823529412, 0.9396670588235294], 
             UndirectedEdge[30, 465] -> 
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352], 
             UndirectedEdge[119, 124] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[301, 436] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[39, 108] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[98, 382] -> 
             RGBColor[
              0.9361957058823529, 0.7637870000000002, 0.464683029411765], 
             UndirectedEdge[81, 208] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[154, 203] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[145, 367] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[44, 132] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705883], 
             UndirectedEdge[319, 357] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[364, 378] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[213, 251] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[73, 136] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[441, 461] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[90, 480] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705883], 
             UndirectedEdge[118, 446] -> 
             RGBColor[
              0.7880378235294117, 0.8342091176470589, 0.9514881470588235], 
             UndirectedEdge[210, 480] -> 
             RGBColor[
              0.5904387647058824, 0.5419202647058825, 0.5927070000000001], 
             UndirectedEdge[95, 492] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[261, 328] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[152, 496] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[86, 177] -> 
             RGBColor[
              0.6676762352941177, 0.7341850588235295, 0.9426508529411765], 
             UndirectedEdge[45, 217] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[306, 331] -> 
             RGBColor[
              0.961070411764706, 0.8776436470588238, 0.31732720588235297`], 
             UndirectedEdge[103, 129] -> 
             RGBColor[
              0.5835165588235294, 0.6473717941176471, 0.8901384705882354], 
             UndirectedEdge[50, 126] -> 
             RGBColor[
              0.6293350294117648, 0.6955299117647059, 0.8927477647058825], 
             UndirectedEdge[172, 308] -> 
             RGBColor[
              0.7318321176470588, 0.7872340588235294, 0.8993163823529413], 
             UndirectedEdge[112, 266] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.830958529411765], 
             UndirectedEdge[129, 275] -> 
             RGBColor[
              0.5860419411764706, 0.6465827941176472, 0.7150240294117647], 
             UndirectedEdge[297, 325] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[202, 396] -> 
             RGBColor[
              0.6676762352941177, 0.7341850588235295, 0.9426508529411765], 
             UndirectedEdge[167, 236] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[184, 301] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[78, 258] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[172, 470] -> 
             RGBColor[0.9172135, 0.6731988823529413, 0.5193830882352942], 
             UndirectedEdge[72, 159] -> 
             RGBColor[
              0.6613845882352941, 0.7330628235294117, 0.9685728823529411], 
             UndirectedEdge[304, 337] -> 
             RGBColor[
              0.8787623235294117, 0.781568705882353, 0.6159916764705883], 
             UndirectedEdge[88, 271] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[392, 413] -> 
             RGBColor[
              0.5130690294117647, 0.5932005588235294, 0.9593949705882353], 
             UndirectedEdge[187, 216] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[33, 432] -> 
             RGBColor[0.9172135, 0.6731988823529413, 0.5193830882352942], 
             UndirectedEdge[36, 75] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[243, 335] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[323, 499] -> 
             RGBColor[
              0.6807162647058824, 0.7405875882352941, 0.7206171176470587], 
             UndirectedEdge[168, 480] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529414, 0.6198870882352941], 
             UndirectedEdge[301, 388] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[111, 371] -> 
             RGBColor[
              0.7213174705882353, 0.7800425294117648, 0.9462356764705883], 
             UndirectedEdge[103, 231] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[99, 131] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[193, 428] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[189, 370] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[45, 187] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[346, 443] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[19, 318] -> 
             RGBColor[0.4219168823529411, 0.5392610588235294, 0.948272], 
             UndirectedEdge[5, 129] -> 
             RGBColor[
              0.5835165588235294, 0.6473717941176471, 0.8901384705882354], 
             UndirectedEdge[29, 46] -> 
             RGBColor[
              0.938695205882353, 0.8285484117647062, 0.5936544705882354], 
             UndirectedEdge[227, 263] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[272, 435] -> 
             RGBColor[
              0.938695205882353, 0.8285484117647062, 0.5936544705882354], 
             UndirectedEdge[208, 483] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[244, 475] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[350, 412] -> 
             RGBColor[
              0.9066988529411765, 0.6660073529411767, 0.5663023823529412], 
             UndirectedEdge[217, 398] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[370, 451] -> 
             RGBColor[
              0.5771173529411765, 0.6168816176470588, 0.6460382647058824], 
             UndirectedEdge[265, 424] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[28, 419] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[67, 381] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[239, 435] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[302, 370] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[2, 66] -> 
             RGBColor[
              0.9030825588235294, 0.7408720588235296, 0.606192794117647], 
             UndirectedEdge[36, 408] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[76, 483] -> 
             RGBColor[0.8876065588235293, 0.651592823529412, 0.592535], 
             UndirectedEdge[9, 367] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[133, 469] -> 
             RGBColor[
              0.8416144411764706, 0.8104576470588236, 0.6252197941176472], 
             UndirectedEdge[46, 297] -> 
             RGBColor[
              0.8787623235294117, 0.781568705882353, 0.6159916764705883], 
             UndirectedEdge[159, 435] -> 
             RGBColor[
              0.7213174705882353, 0.7800425294117648, 0.9462356764705883], 
             UndirectedEdge[126, 340] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[27, 290] -> 
             RGBColor[
              0.47555811764705874`, 0.5851185294117647, 0.9518568235294118], 
             UndirectedEdge[326, 338] -> 
             RGBColor[
              0.8068343235294118, 0.6648019411764707, 0.5968332647058824], 
             UndirectedEdge[179, 438] -> 
             RGBColor[
              0.4886372352941176, 0.5934276470588236, 0.9535244705882353], 
             UndirectedEdge[138, 339] -> 
             RGBColor[
              0.920719705882353, 0.6745077647058826, 0.45102523529411787`], 
             UndirectedEdge[475, 482] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[94, 428] -> 
             RGBColor[0.9326895, 0.762478117647059, 0.5330408823529413], 
             UndirectedEdge[186, 295] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[348, 372] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[293, 343] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[385, 446] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647057], 
             UndirectedEdge[7, 288] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[242, 323] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[464, 481] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[42, 108] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[101, 276] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647057], 
             UndirectedEdge[86, 426] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[37, 324] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529411], 
             UndirectedEdge[290, 297] -> 
             RGBColor[
              0.6613845882352941, 0.7330628235294117, 0.9685728823529411], 
             UndirectedEdge[315, 380] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[181, 390] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[283, 421] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[97, 355] -> 
             RGBColor[
              0.3194197941176471, 0.4475569117647059, 0.9417033823529412], 
             UndirectedEdge[192, 219] -> 
             RGBColor[
              0.9527160588235295, 0.837048823529412, 0.47837732352941204`], 
             UndirectedEdge[171, 192] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705883], 
             UndirectedEdge[122, 216] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[18, 28] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[178, 288] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[165, 185] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882355], 
             UndirectedEdge[264, 281] -> 
             RGBColor[
              0.7281049411764706, 0.7872294117647058, 0.9738253529411764], 
             UndirectedEdge[80, 192] -> 
             RGBColor[
              0.9527160588235295, 0.837048823529412, 0.47837732352941204`], 
             UndirectedEdge[74, 402] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[3, 158] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[426, 476] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882355], 
             UndirectedEdge[27, 177] -> 
             RGBColor[0.4219168823529411, 0.5392610588235294, 0.948272], 
             UndirectedEdge[355, 443] -> 
             RGBColor[
              0.631860411764706, 0.6947409117647059, 0.7176333235294117], 
             UndirectedEdge[21, 256] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[331, 404] -> 
             RGBColor[
              0.9262902941176471, 0.7319879411764708, 0.2889406764705883], 
             UndirectedEdge[142, 285] -> 
             RGBColor[
              0.8965770000000001, 0.5919831176470591, 0.23403455882352947`], 
             UndirectedEdge[232, 267] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058825, 0.6345793235294117], 
             UndirectedEdge[133, 488] -> 
             RGBColor[
              0.5628800588235294, 0.5661560294117649, 0.6047899411764706], 
             UndirectedEdge[148, 393] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[84, 89] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705883], 
             UndirectedEdge[27, 350] -> 
             RGBColor[0.6609395, 0.47108335294117665`, 0.5719235294117647], 
             UndirectedEdge[8, 435] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[20, 220] -> 
             RGBColor[
              0.7431358529411765, 0.6145291764705885, 0.5908337941176471], 
             UndirectedEdge[35, 422] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[65, 177] -> 
             RGBColor[
              0.6816970882352942, 0.7426854705882353, 0.8273737058823531], 
             UndirectedEdge[93, 160] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             UndirectedEdge[277, 373] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[15, 126] -> 
             RGBColor[0.9326895, 0.762478117647059, 0.5330408823529413], 
             UndirectedEdge[95, 367] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[304, 465] -> 
             RGBColor[
              0.9285733529411766, 0.7545241764705886, 0.26138664705882364`], 
             UndirectedEdge[218, 305] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.608346705882353], 
             UndirectedEdge[137, 265] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705883], 
             UndirectedEdge[325, 392] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[263, 393] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[228, 335] -> 
             RGBColor[
              0.8233546764705882, 0.7380637647058825, 0.6105275588235295], 
             UndirectedEdge[104, 408] -> 
             RGBColor[
              0.7431358529411765, 0.6145291764705885, 0.590833794117647], 
             UndirectedEdge[145, 375] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764708, 0.3716207352941176], 
             UndirectedEdge[181, 451] -> 
             RGBColor[
              0.5870227647058823, 0.6486806764705882, 0.821780617647059], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.599728088235294, 0.6739238529411764, 0.9658996764705883], 
             UndirectedEdge[387, 439] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[163, 231] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[143, 288] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[128, 312] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[270, 479] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[119, 120] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[105, 462] -> 
             RGBColor[
              0.672697294117647, 0.7437244705882353, 0.9683612352941176], 
             UndirectedEdge[14, 159] -> 
             RGBColor[
              0.7254329117647058, 0.7567438823529412, 0.6552161764705883], 
             UndirectedEdge[58, 417] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764708, 0.3716207352941176], 
             UndirectedEdge[66, 299] -> 
             RGBColor[
              0.9262902941176471, 0.7319879411764708, 0.2889406764705883], 
             UndirectedEdge[11, 348] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[4, 31] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[259, 400] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[247, 451] -> 
             RGBColor[
              0.2736013235294118, 0.39939879411764706`, 0.9390940882352941], 
             UndirectedEdge[17, 261] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[361, 386] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[212, 492] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[287, 388] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[383, 480] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529414, 0.6198870882352941], 
             UndirectedEdge[403, 440] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[13, 354] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.6083467058823531], 
             UndirectedEdge[1, 42] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[161, 188] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[194, 426] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529411], 
             UndirectedEdge[257, 324] -> 
             RGBColor[
              0.7913583235294117, 0.5755227058823531, 0.5831754705882353], 
             UndirectedEdge[198, 479] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[372, 431] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[107, 466] -> 
             RGBColor[
              0.8970220882352942, 0.8539625882352943, 0.630683911764706], 
             UndirectedEdge[122, 330] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[4, 472] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[145, 458] -> 
             RGBColor[
              0.8233546764705882, 0.7380637647058825, 0.6105275588235295], 
             UndirectedEdge[3, 451] -> 
             RGBColor[
              0.5730019117647058, 0.6401802647058824, 0.9370577647058824], 
             UndirectedEdge[146, 239] -> 
             RGBColor[
              0.8787623235294117, 0.781568705882353, 0.6159916764705883], 
             UndirectedEdge[15, 282] -> 
             RGBColor[0.9326895, 0.762478117647059, 0.5330408823529413], 
             UndirectedEdge[82, 126] -> 
             RGBColor[
              0.5835165588235294, 0.6473717941176471, 0.8901384705882354], 
             UndirectedEdge[413, 474] -> 
             RGBColor[
              0.5860419411764706, 0.6465827941176472, 0.7150240294117647], 
             UndirectedEdge[160, 235] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[161, 183] -> 
             RGBColor[
              0.6781908823529412, 0.7413765882352942, 0.8957315588235295], 
             UndirectedEdge[366, 429] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[7, 313] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[129, 444] -> 
             RGBColor[
              0.4576613823529411, 0.5496956176470588, 0.9539308529411765], 
             UndirectedEdge[18, 493] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[149, 411] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[221, 301] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[45, 496] -> 
             RGBColor[
              0.7880378235294117, 0.8342091176470589, 0.9514881470588235], 
             UndirectedEdge[478, 482] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[69, 331] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[16, 143] -> 
             RGBColor[
              0.6188203823529412, 0.6883383823529412, 0.9396670588235294], 
             UndirectedEdge[210, 280] -> 
             RGBColor[
              0.6229358235294118, 0.6650397352941178, 0.6486475588235294], 
             UndirectedEdge[101, 390] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[400, 418] -> 
             RGBColor[
              0.9262902941176471, 0.7319879411764708, 0.2889406764705883], 
             UndirectedEdge[84, 299] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[333, 386] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[244, 341] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[143, 373] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[160, 284] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[281, 343] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[207, 445] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882355], 
             UndirectedEdge[260, 334] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[66, 114] -> 
             RGBColor[
              0.9030825588235294, 0.7408720588235296, 0.606192794117647], 
             UndirectedEdge[364, 381] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[204, 306] -> 
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352], 
             UndirectedEdge[358, 361] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[294, 415] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[2, 255] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[326, 443] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529411], 
             UndirectedEdge[58, 145] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764708, 0.3716207352941176], 
             UndirectedEdge[103, 346] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[62, 108] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[91, 336] -> 
             RGBColor[
              0.7318321176470588, 0.7872340588235294, 0.8993163823529413], 
             UndirectedEdge[338, 395] -> 
             RGBColor[0.6227742647058824, 0.514505117647059, 0.5819965], 
             UndirectedEdge[19, 335] -> 
             RGBColor[
              0.6059769411764705, 0.6895578823529411, 0.9631087647058824], 
             UndirectedEdge[2, 195] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[150, 325] -> 
             RGBColor[
              0.9027125588235294, 0.5617382941176471, 0.5054969705882354], 
             UndirectedEdge[208, 238] -> 
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352], 
             UndirectedEdge[318, 335] -> 
             RGBColor[
              0.5523357058823529, 0.6437004117647058, 0.9595239411764706], 
             UndirectedEdge[12, 421] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[102, 278] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.608346705882353], 
             UndirectedEdge[5, 209] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[76, 463] -> 
             RGBColor[0.8876065588235293, 0.651592823529412, 0.592535], 
             UndirectedEdge[293, 445] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[48, 250] -> 
             RGBColor[
              0.7880378235294117, 0.8342091176470589, 0.9514881470588235], 
             UndirectedEdge[459, 477] -> 
             RGBColor[
              0.7779159705882353, 0.7601848823529413, 0.6192203235294118], 
             UndirectedEdge[400, 404] -> 
             RGBColor[
              0.9262902941176471, 0.7319879411764708, 0.2889406764705883], 
             UndirectedEdge[144, 246] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[90, 393] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[157, 360] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[156, 250] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[25, 220] -> 
             RGBColor[
              0.8068343235294118, 0.6648019411764707, 0.5968332647058824], 
             UndirectedEdge[261, 407] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[42, 364] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[83, 257] -> 
             RGBColor[
              0.7913583235294117, 0.5755227058823531, 0.5831754705882353], 
             UndirectedEdge[137, 263] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529414, 0.6198870882352941], 
             UndirectedEdge[27, 65] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.830958529411765], 
             UndirectedEdge[318, 421] -> 
             RGBColor[
              0.6816970882352942, 0.7426854705882353, 0.8273737058823531], 
             UndirectedEdge[203, 341] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[80, 483] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[95, 319] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[84, 376] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764708, 0.3716207352941176], 
             UndirectedEdge[260, 446] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[174, 393] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[185, 216] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[143, 321] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[296, 415] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529411], 
             UndirectedEdge[42, 113] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[54, 264] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[9, 95] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[47, 55] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[212, 330] -> 
             RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             UndirectedEdge[89, 244] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[3, 247] -> 
             RGBColor[
              0.6676762352941177, 0.7341850588235295, 0.9426508529411765], 
             UndirectedEdge[26, 318] -> 
             RGBColor[
              0.6575543823529413, 0.660160823529412, 0.6103830294117647], 
             UndirectedEdge[46, 426] -> 
             RGBColor[
              0.8233546764705882, 0.7380637647058825, 0.6105275588235295], 
             UndirectedEdge[102, 247] -> 
             RGBColor[
              0.6676762352941177, 0.7341850588235295, 0.9426508529411765], 
             UndirectedEdge[285, 287] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.6083467058823531], 
             UndirectedEdge[346, 390] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[388, 473] -> 
             RGBColor[
              0.9674696176470589, 0.908133823529412, 0.561427411764706], 
             UndirectedEdge[377, 412] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[7, 321] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[209, 275] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[204, 346] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[220, 297] -> 
             RGBColor[
              0.8622419705882354, 0.7083068823529413, 0.6022973823529412], 
             UndirectedEdge[16, 185] -> 
             RGBColor[
              0.6328412352941177, 0.696838794117647, 0.8243899117647061], 
             UndirectedEdge[323, 449] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647057], 
             UndirectedEdge[224, 481] -> 
             RGBColor[
              0.7880378235294117, 0.8342091176470589, 0.9514881470588235], 
             UndirectedEdge[86, 476] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[66, 385] -> 
             RGBColor[
              0.9352148823529411, 0.761689117647059, 0.35792644117647054`], 
             UndirectedEdge[184, 316] -> 
             RGBColor[
              0.5870227647058823, 0.6486806764705882, 0.821780617647059], 
             UndirectedEdge[308, 362] -> 
             RGBColor[
              0.6613845882352941, 0.7330628235294117, 0.9685728823529411], 
             UndirectedEdge[216, 361] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[123, 410] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[174, 225] -> 
             RGBColor[
              0.7913583235294117, 0.5755227058823531, 0.5831754705882353], 
             UndirectedEdge[3, 139] -> 
             RGBColor[
              0.938695205882353, 0.8285484117647062, 0.5936544705882354], 
             UndirectedEdge[226, 472] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[9, 441] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[253, 354] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.6083467058823531], 
             UndirectedEdge[47, 73] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             UndirectedEdge[305, 432] -> 
             RGBColor[
              0.8965770000000001, 0.5919831176470591, 0.23403455882352947`], 
             UndirectedEdge[4, 226] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[112, 359] -> 
             RGBColor[
              0.5870227647058823, 0.6486806764705882, 0.821780617647059], 
             UndirectedEdge[101, 204] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             UndirectedEdge[256, 409] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[64, 268] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[97, 395] -> 
             RGBColor[
              0.36827564705882354`, 0.4934035882352941, 0.9446871764705882], 
             UndirectedEdge[117, 156] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[48, 117] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[5, 103] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[344, 438] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[42, 381] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[224, 398] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[226, 405] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[231, 346] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[168, 181] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[178, 391] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[30, 133] -> 
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352], 
             UndirectedEdge[120, 363] -> 
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647], 
             UndirectedEdge[452, 468] -> 
             RGBColor[
              0.5835165588235294, 0.6473717941176471, 0.8901384705882354], 
             UndirectedEdge[159, 344] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.830958529411765], 
             UndirectedEdge[68, 330] -> 
             RGBColor[
              0.6077433529411764, 0.6872053529411765, 0.9649880588235293], 
             UndirectedEdge[359, 440] -> 
             RGBColor[
              0.5130690294117648, 0.5932005588235294, 0.9593949705882353], 
             UndirectedEdge[180, 413] -> 
             RGBColor[
              0.5130690294117647, 0.5932005588235294, 0.9593949705882353], 
             UndirectedEdge[81, 442] -> 
             RGBColor[
              0.9030825588235294, 0.7408720588235296, 0.606192794117647], 
             UndirectedEdge[165, 277] -> 
             RGBColor[
              0.7918034117647059, 0.8375021764705881, 0.9798248235294118], 
             UndirectedEdge[28, 310] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[71, 470] -> 
             RGBColor[0.8876065588235293, 0.651592823529412, 0.592535], 
             UndirectedEdge[129, 276] -> 
             RGBColor[
              0.3939629117647059, 0.4994228529411765, 0.9479313823529412], 
             UndirectedEdge[192, 251] -> 
             RGBColor[
              0.9527160588235295, 0.837048823529412, 0.47837732352941204`], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647057], 
             UndirectedEdge[15, 323] -> 
             RGBColor[
              0.9352148823529411, 0.761689117647059, 0.35792644117647054`], 
             UndirectedEdge[20, 473] -> 
             RGBColor[
              0.7779159705882353, 0.7601848823529413, 0.6192203235294118], 
             UndirectedEdge[336, 354] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[36, 440] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[31, 311] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[366, 405] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[257, 374] -> 
             RGBColor[
              0.8783172352941178, 0.519589235294118, 0.21934232352941183`], 
             UndirectedEdge[194, 254] -> 
             RGBColor[
              0.9052379411764706, 0.560949294117647, 0.3303825294117646], 
             UndirectedEdge[284, 456] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[30, 429] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[182, 463] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529414, 0.6198870882352941], 
             UndirectedEdge[130, 238] -> 
             RGBColor[
              0.961070411764706, 0.8776436470588238, 0.31732720588235297`], 
             UndirectedEdge[19, 67] -> 
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647], 
             UndirectedEdge[114, 446] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[164, 418] -> 
             RGBColor[0.6227742647058824, 0.514505117647059, 0.5819965], 
             UndirectedEdge[96, 457] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[285, 354] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.6083467058823531], 
             UndirectedEdge[432, 460] -> 
             RGBColor[
              0.9108142941176471, 0.6427087058823532, 0.2752828823529412], 
             UndirectedEdge[82, 249] -> 
             RGBColor[
              0.5835165588235294, 0.6473717941176471, 0.8901384705882354], 
             UndirectedEdge[176, 262] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[216, 358] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[54, 374] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705883], 
             UndirectedEdge[214, 491] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.608346705882353], 
             UndirectedEdge[68, 357] -> 
             RGBColor[
              0.6781908823529412, 0.7413765882352942, 0.8957315588235295], 
             UndirectedEdge[260, 328] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[224, 286] -> 
             RGBColor[
              0.7596562058823529, 0.6877910000000003, 0.6045280882352941], 
             UndirectedEdge[219, 293] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[209, 404] -> 
             RGBColor[
              0.9262902941176471, 0.7319879411764708, 0.2889406764705883], 
             UndirectedEdge[197, 289] -> 
             RGBColor[
              0.7213174705882353, 0.7800425294117648, 0.9462356764705883], 
             UndirectedEdge[227, 424] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[458, 461] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[292, 464] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[386, 441] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[257, 343] -> 
             RGBColor[
              0.9066988529411765, 0.6660073529411767, 0.5663023823529412], 
             UndirectedEdge[132, 457] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764708, 0.3716207352941176], 
             UndirectedEdge[69, 259] -> 
             RGBColor[
              0.9527160588235295, 0.837048823529412, 0.47837732352941204`], 
             UndirectedEdge[68, 95] -> 
             RGBColor[
              0.6717916764705882, 0.7108864117647059, 0.6516313529411765], 
             UndirectedEdge[247, 278] -> 
             RGBColor[
              0.6575543823529413, 0.660160823529412, 0.6103830294117647], 
             UndirectedEdge[293, 440] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[307, 442] -> 
             RGBColor[
              0.8622419705882354, 0.7083068823529413, 0.6022973823529412], 
             UndirectedEdge[406, 493] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[155, 479] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[311, 488] -> 
             RGBColor[
              0.5730019117647058, 0.6401802647058824, 0.9370577647058824], 
             UndirectedEdge[226, 345] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[183, 273] -> 
             RGBColor[
              0.6816970882352942, 0.7426854705882353, 0.8273737058823531], 
             UndirectedEdge[384, 499] -> 
             RGBColor[
              0.6676762352941177, 0.7341850588235295, 0.9426508529411765], 
             UndirectedEdge[20, 325] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[252, 424] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[285, 473] -> 
             RGBColor[
              0.9468331176470589, 0.8269180588235298, 0.27607888235294126`], 
             UndirectedEdge[71, 236] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[2, 446] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[33, 351] -> 
             RGBColor[
              0.7318321176470588, 0.7872340588235294, 0.8993163823529413], 
             UndirectedEdge[172, 466] -> 
             RGBColor[
              0.9674696176470589, 0.908133823529412, 0.561427411764706], 
             UndirectedEdge[12, 279] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[171, 219] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[153, 223] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529411], 
             UndirectedEdge[121, 489] -> 
             RGBColor[
              0.6293350294117648, 0.6955299117647059, 0.8927477647058825], 
             UndirectedEdge[362, 470] -> 
             RGBColor[
              0.8467659705882353, 0.6190276470588236, 0.5886395882352942], 
             UndirectedEdge[168, 232] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058825, 0.6345793235294118], 
             UndirectedEdge[285, 409] -> 
             RGBColor[
              0.961070411764706, 0.8776436470588238, 0.31732720588235297`], 
             UndirectedEdge[159, 439] -> 
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647], 
             UndirectedEdge[156, 263] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[149, 314] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[110, 457] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             UndirectedEdge[43, 263] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[141, 160] -> 
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352], 
             UndirectedEdge[345, 389] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             UndirectedEdge[225, 247] -> 
             RGBColor[
              0.6072982647058824, 0.42522588235294134`, 0.568338705882353], 
             UndirectedEdge[171, 293] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[179, 415] -> 
             RGBColor[
              0.6807162647058824, 0.7405875882352941, 0.7206171176470587], 
             UndirectedEdge[143, 414] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[77, 388] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[305, 406] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058825, 0.6345793235294117], 
             UndirectedEdge[55, 256] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[367, 450] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[171, 258] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[366, 423] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[309, 393] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[324, 360] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882355], 
             UndirectedEdge[125, 310] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[33, 463] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[137, 280] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[72, 179] -> 
             RGBColor[
              0.6077433529411764, 0.6872053529411765, 0.9649880588235293], 
             UndirectedEdge[17, 165] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[402, 417] -> 
             RGBColor[
              0.8233546764705882, 0.7380637647058825, 0.6105275588235295], 
             UndirectedEdge[102, 225] -> 
             RGBColor[
              0.9066988529411765, 0.6660073529411767, 0.5663023823529412], 
             UndirectedEdge[83, 231] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[194, 377] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[131, 495] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[213, 447] -> 
             RGBColor[
              0.5539096176470588, 0.6257657352941176, 0.9632903823529412], 
             UndirectedEdge[146, 166] -> 
             RGBColor[
              0.6392946176470589, 0.5877669411764708, 0.595690794117647], 
             UndirectedEdge[422, 428] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[232, 338] -> 
             RGBColor[0.912053, 0.6812623529411768, 0.24769235294117653`], 
             UndirectedEdge[366, 469] -> 
             RGBColor[
              0.672697294117647, 0.7437244705882353, 0.9683612352941176], 
             UndirectedEdge[245, 482] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[40, 243] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[174, 320] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[30, 31] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[77, 354] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[24, 223] -> 
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352], 
             UndirectedEdge[261, 391] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[125, 323] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[1, 364] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[88, 133] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.608346705882353], 
             UndirectedEdge[178, 407] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[103, 486] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[204, 486] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[89, 407] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[38, 301] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[92, 132] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529414, 0.6198870882352941], 
             UndirectedEdge[8, 146] -> 
             RGBColor[
              0.8233546764705882, 0.7380637647058825, 0.6105275588235295], 
             UndirectedEdge[44, 110] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[102, 252] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[273, 283] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[158, 428] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[176, 328] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[45, 398] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[233, 275] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[250, 485] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[29, 65] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[166, 453] -> 
             RGBColor[0.6227742647058824, 0.514505117647059, 0.5819965], 
             UndirectedEdge[222, 294] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[150, 220] -> 
             RGBColor[
              0.8472959411764707, 0.33486682352941194`, 0.19176191176470592`],
              UndirectedEdge[311, 423] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[210, 424] -> 
             RGBColor[
              0.6229358235294118, 0.6650397352941178, 0.6486475588235294], 
             UndirectedEdge[179, 312] -> 
             RGBColor[
              0.6077433529411764, 0.6872053529411765, 0.9649880588235293], 
             UndirectedEdge[310, 323] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[108, 349] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[355, 395] -> 
             RGBColor[
              0.3194197941176471, 0.4475569117647059, 0.9417033823529412], 
             UndirectedEdge[47, 200] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             UndirectedEdge[152, 217] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[174, 210] -> 
             RGBColor[
              0.5034798529411765, 0.5978537352941176, 0.9565401470588235], 
             UndirectedEdge[135, 211] -> 
             RGBColor[
              0.9674696176470589, 0.908133823529412, 0.561427411764706], 
             UndirectedEdge[52, 491] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.608346705882353], 
             UndirectedEdge[41, 250] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[220, 392] -> 
             RGBColor[
              0.8622419705882354, 0.7083068823529413, 0.6022973823529412], 
             UndirectedEdge[182, 359] -> 
             RGBColor[
              0.5446202941176471, 0.4937621470588237, 0.590097705882353], 
             UndirectedEdge[89, 391] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[62, 190] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[21, 87] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[185, 286] -> 
             RGBColor[
              0.9527160588235295, 0.837048823529412, 0.47837732352941204`], 
             UndirectedEdge[114, 294] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[48, 156] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[68, 450] -> 
             RGBColor[
              0.4886372352941176, 0.5934276470588236, 0.9535244705882353], 
             UndirectedEdge[149, 406] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[123, 158] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[55, 91] -> 
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647], 
             UndirectedEdge[135, 169] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705883], 
             UndirectedEdge[141, 456] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058825, 0.6345793235294117], 
             UndirectedEdge[287, 354] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[223, 411] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[127, 301] -> 
             RGBColor[
              0.6485839411764706, 0.7197705294117647, 0.9688834705882352], 
             UndirectedEdge[167, 201] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[28, 218] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[112, 317] -> 
             RGBColor[
              0.6328412352941176, 0.696838794117647, 0.8243899117647061], 
             UndirectedEdge[275, 372] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[85, 146] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[7, 262] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[448, 455] -> 
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764705], 
             UndirectedEdge[9, 368] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[216, 399] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[205, 474] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647057], 
             UndirectedEdge[125, 242] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[280, 338] -> 
             RGBColor[
              0.9262902941176471, 0.7319879411764708, 0.2889406764705883], 
             UndirectedEdge[232, 393] -> 
             RGBColor[
              0.961070411764706, 0.8776436470588238, 0.31732720588235297`], 
             UndirectedEdge[403, 483] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[427, 433] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[269, 310] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[212, 357] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[88, 307] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[212, 217] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[67, 124] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[364, 380] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[82, 384] -> 
             RGBColor[
              0.5730019117647058, 0.6401802647058823, 0.9370577647058824], 
             UndirectedEdge[222, 439] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[337, 420] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[61, 99] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[63, 439] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[37, 53] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[39, 62] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[130, 182] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[152, 398] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[23, 110] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[322, 440] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[141, 432] -> 
             RGBColor[
              0.8965770000000001, 0.5919831176470591, 0.23403455882352947`], 
             UndirectedEdge[161, 459] -> 
             RGBColor[
              0.9674696176470589, 0.908133823529412, 0.561427411764706], 
             UndirectedEdge[185, 333] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[297, 474] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[265, 329] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[90, 280] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[183, 430] -> 
             RGBColor[
              0.6717916764705882, 0.7108864117647059, 0.6516313529411765], 
             UndirectedEdge[86, 194] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[143, 186] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[1, 416] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[27, 86] -> 
             RGBColor[
              0.7213174705882353, 0.7800425294117648, 0.9462356764705883], 
             UndirectedEdge[66, 415] -> 
             RGBColor[
              0.9352148823529411, 0.761689117647059, 0.35792644117647054`], 
             UndirectedEdge[413, 490] -> 
             RGBColor[
              0.3272425588235294, 0.4452562647058823, 0.9426789117647059], 
             UndirectedEdge[226, 284] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[245, 438] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[53, 163] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[367, 368] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[112, 175] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[277, 288] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[249, 323] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[416, 452] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[13, 87] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[471, 497] -> 
             RGBColor[
              0.9527160588235295, 0.837048823529412, 0.47837732352941204`], 
             UndirectedEdge[17, 321] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[106, 227] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[37, 100] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[9, 375] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[10, 302] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529411], 
             UndirectedEdge[14, 272] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[63, 387] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[471, 483] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[46, 392] -> 
             RGBColor[
              0.8787623235294117, 0.781568705882353, 0.6159916764705883], 
             UndirectedEdge[122, 357] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[75, 125] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[244, 261] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[7, 178] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[108, 487] -> 
             RGBColor[
              0.6781908823529412, 0.7413765882352942, 0.8957315588235295], 
             UndirectedEdge[338, 480] -> 
             RGBColor[
              0.8937932352941177, 0.6088684705882357, 0.2330001176470589], 
             UndirectedEdge[237, 284] -> 
             RGBColor[
              0.9527160588235295, 0.837048823529412, 0.47837732352941204`], 
             UndirectedEdge[162, 456] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[104, 310] -> 
             RGBColor[
              0.9221748529411764, 0.7552865882352944, 0.5799601764705883], 
             UndirectedEdge[168, 390] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[164, 431] -> 
             RGBColor[
              0.6807162647058824, 0.7405875882352941, 0.7206171176470587], 
             UndirectedEdge[57, 60] -> 
             RGBColor[
              0.3194197941176471, 0.4475569117647059, 0.9417033823529412], 
             UndirectedEdge[158, 247] -> 
             RGBColor[
              0.6807162647058824, 0.7405875882352941, 0.7206171176470587], 
             UndirectedEdge[32, 475] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[53, 293] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[72, 294] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[87, 287] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[154, 374] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[119, 364] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[90, 342] -> 
             RGBColor[
              0.6293350294117647, 0.6955299117647059, 0.8927477647058825], 
             UndirectedEdge[401, 428] -> 
             RGBColor[
              0.9674696176470589, 0.908133823529412, 0.561427411764706], 
             UndirectedEdge[183, 477] -> 
             RGBColor[
              0.4886372352941176, 0.5934276470588236, 0.9535244705882353], 
             UndirectedEdge[82, 269] -> 
             RGBColor[
              0.5730019117647058, 0.6401802647058823, 0.9370577647058824], 
             UndirectedEdge[202, 273] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[147, 242] -> 
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647], 
             UndirectedEdge[117, 198] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[240, 434] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[249, 310] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[448, 478] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[121, 196] -> 
             RGBColor[
              0.6086985294117648, 0.6143141470588237, 0.6073992352941177], 
             UndirectedEdge[200, 256] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[79, 184] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[51, 240] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[339, 387] -> 
             RGBColor[
              0.9108142941176471, 0.6427087058823532, 0.2752828823529412], 
             UndirectedEdge[46, 142] -> 
             RGBColor[
              0.8783172352941178, 0.519589235294118, 0.21934232352941183`], 
             UndirectedEdge[233, 259] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[266, 471] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.830958529411765], 
             UndirectedEdge[167, 456] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[10, 181] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882355], 
             UndirectedEdge[31, 429] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[317, 322] -> 
             RGBColor[
              0.631860411764706, 0.6947409117647059, 0.7176333235294117], 
             UndirectedEdge[52, 466] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.608346705882353], 
             UndirectedEdge[207, 281] -> 
             RGBColor[
              0.7918034117647059, 0.8375021764705881, 0.9798248235294118], 
             UndirectedEdge[358, 398] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[155, 250] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[243, 285] -> 
             RGBColor[
              0.961070411764706, 0.8776436470588238, 0.31732720588235297`], 
             UndirectedEdge[378, 452] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[100, 264] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[81, 130] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[1, 120] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[390, 422] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[118, 255] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[137, 229] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764708, 0.3716207352941176], 
             UndirectedEdge[367, 375] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[230, 382] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[114, 334] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[52, 170] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[4, 389] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[190, 378] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[89, 328] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[93, 300] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[104, 125] -> 
             RGBColor[
              0.9030825588235294, 0.7408720588235296, 0.606192794117647], 
             UndirectedEdge[59, 228] -> 
             RGBColor[
              0.9527160588235295, 0.837048823529412, 0.47837732352941204`], 
             UndirectedEdge[96, 136] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[332, 420] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[40, 283] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647057], 
             UndirectedEdge[17, 288] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[325, 413] -> 
             RGBColor[
              0.5835165588235294, 0.6473717941176471, 0.8901384705882354], 
             UndirectedEdge[421, 459] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[148, 342] -> 
             RGBColor[
              0.4397813823529412, 0.5475809705882353, 0.9505406764705882], 
             UndirectedEdge[262, 478] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[133, 405] -> 
             RGBColor[
              0.9674696176470589, 0.908133823529412, 0.561427411764706], 
             UndirectedEdge[374, 397] -> 
             RGBColor[
              0.8783172352941178, 0.519589235294118, 0.21934232352941183`], 
             UndirectedEdge[151, 389] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[235, 305] -> 
             RGBColor[
              0.9674696176470589, 0.908133823529412, 0.561427411764706], 
             UndirectedEdge[204, 348] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[191, 429] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882355], 
             UndirectedEdge[15, 414] -> 
             RGBColor[0.9326895, 0.762478117647059, 0.5330408823529413], 
             UndirectedEdge[277, 414] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[317, 440] -> 
             RGBColor[0.5588875, 0.6413586764705882, 0.9620042647058824], 
             UndirectedEdge[76, 182] -> 
             RGBColor[
              0.8783172352941178, 0.519589235294118, 0.21934232352941183`], 
             UndirectedEdge[199, 376] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647057], 
             UndirectedEdge[375, 402] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529411], 
             UndirectedEdge[45, 195] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[149, 269] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[45, 152] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[356, 494] -> 
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647], 
             UndirectedEdge[44, 360] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[284, 432] -> 
             RGBColor[
              0.920719705882353, 0.6745077647058826, 0.45102523529411787`], 
             UndirectedEdge[151, 237] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[207, 343] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[33, 371] -> 
             RGBColor[
              0.7318321176470588, 0.7872340588235294, 0.8993163823529413], 
             UndirectedEdge[280, 480] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[420, 454] -> 
             RGBColor[
              0.6318604117647059, 0.6947409117647059, 0.7176333235294117], 
             UndirectedEdge[267, 393] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[337, 427] -> 
             RGBColor[
              0.8970220882352942, 0.8539625882352943, 0.630683911764706], 
             UndirectedEdge[267, 480] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529414, 0.6198870882352941], 
             UndirectedEdge[234, 336] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[122, 492] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[80, 272] -> 
             RGBColor[
              0.9527160588235295, 0.837048823529412, 0.47837732352941204`], 
             UndirectedEdge[331, 444] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[77, 184] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[266, 359] -> 
             RGBColor[
              0.3272425588235294, 0.4452562647058823, 0.9426789117647059], 
             UndirectedEdge[32, 478] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[14, 447] -> 
             RGBColor[
              0.5771173529411765, 0.6168816176470588, 0.6460382647058824], 
             UndirectedEdge[16, 358] -> 
             RGBColor[
              0.6188203823529412, 0.6883383823529412, 0.9396670588235294], 
             UndirectedEdge[50, 323] -> 
             RGBColor[
              0.631860411764706, 0.6947409117647059, 0.7176333235294117], 
             UndirectedEdge[92, 365] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[296, 438] -> 
             RGBColor[
              0.672697294117647, 0.7437244705882353, 0.9683612352941176], 
             UndirectedEdge[181, 422] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[35, 428] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[19, 298] -> 
             RGBColor[
              0.7318321176470588, 0.7872340588235294, 0.8993163823529413], 
             UndirectedEdge[209, 348] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[27, 194] -> 
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764705], 
             UndirectedEdge[253, 287] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.6083467058823531], 
             UndirectedEdge[412, 476] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[221, 336] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[146, 248] -> 
             RGBColor[
              0.7596562058823529, 0.6877910000000003, 0.6045280882352941], 
             UndirectedEdge[17, 455] -> 
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647], 
             UndirectedEdge[102, 393] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[80, 497] -> 
             RGBColor[
              0.9527160588235295, 0.837048823529412, 0.47837732352941204`], 
             UndirectedEdge[108, 416] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[8, 453] -> 
             RGBColor[
              0.8068343235294118, 0.6648019411764707, 0.5968332647058824], 
             UndirectedEdge[58, 402] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529411], 
             UndirectedEdge[95, 357] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[183, 283] -> 
             RGBColor[
              0.6807162647058824, 0.7405875882352941, 0.7206171176470587], 
             UndirectedEdge[179, 294] -> 
             RGBColor[
              0.6781908823529412, 0.7413765882352942, 0.8957315588235295], 
             UndirectedEdge[136, 240] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[153, 289] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[73, 200] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             UndirectedEdge[196, 447] -> 
             RGBColor[
              0.5628800588235294, 0.5661560294117649, 0.6047899411764706], 
             UndirectedEdge[68, 492] -> 
             RGBColor[
              0.6717916764705882, 0.7108864117647059, 0.6516313529411765], 
             UndirectedEdge[25, 413] -> 
             RGBColor[
              0.4576613823529412, 0.5496956176470588, 0.9539308529411765], 
             UndirectedEdge[220, 426] -> 
             RGBColor[
              0.8068343235294118, 0.6648019411764707, 0.5968332647058824], 
             UndirectedEdge[21, 354] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[125, 269] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[241, 304] -> 
             RGBColor[
              0.6392946176470589, 0.5877669411764708, 0.595690794117647], 
             UndirectedEdge[93, 456] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[295, 455] -> 
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647], 
             UndirectedEdge[185, 386] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[233, 400] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[83, 317] -> 
             RGBColor[
              0.5034798529411765, 0.5978537352941176, 0.9565401470588235], 
             UndirectedEdge[88, 465] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.608346705882353], 
             UndirectedEdge[418, 431] -> 
             RGBColor[
              0.9352148823529411, 0.761689117647059, 0.35792644117647054`], 
             UndirectedEdge[121, 307] -> 
             RGBColor[0.5588875, 0.6413586764705882, 0.9620042647058824], 
             UndirectedEdge[64, 74] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[185, 358] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[113, 315] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[47, 91] -> 
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764705], 
             UndirectedEdge[158, 401] -> 
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352], 
             UndirectedEdge[90, 232] -> 
             RGBColor[
              0.9674696176470589, 0.908133823529412, 0.561427411764706], 
             UndirectedEdge[58, 115] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[132, 494] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529414, 0.6198870882352941], 
             UndirectedEdge[167, 300] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[284, 389] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[103, 233] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[172, 300] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[70, 76] -> 
             RGBColor[
              0.9066988529411765, 0.6660073529411767, 0.5663023823529412], 
             UndirectedEdge[57, 73] -> 
             RGBColor[
              0.6807162647058824, 0.7405875882352941, 0.7206171176470587], 
             UndirectedEdge[287, 473] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.608346705882353], 
             UndirectedEdge[395, 443] -> 
             RGBColor[
              0.6807162647058824, 0.7405875882352941, 0.7206171176470587], 
             UndirectedEdge[100, 397] -> 
             RGBColor[
              0.9108142941176471, 0.6427087058823532, 0.2752828823529412], 
             UndirectedEdge[57, 234] -> 
             RGBColor[
              0.6816970882352942, 0.7426854705882353, 0.8273737058823531], 
             UndirectedEdge[343, 403] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[105, 425] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[133, 423] -> 
             RGBColor[
              0.9674696176470589, 0.908133823529412, 0.561427411764706], 
             UndirectedEdge[92, 494] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[51, 100] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[6, 347] -> 
             RGBColor[
              0.6929358529411764, 0.6336244117647061, 0.5992756176470588], 
             UndirectedEdge[333, 461] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[291, 394] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[143, 386] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[123, 437] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[72, 453] -> 
             RGBColor[
              0.8622419705882354, 0.7083068823529413, 0.6022973823529412], 
             UndirectedEdge[391, 478] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[328, 464] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[149, 173] -> 
             RGBColor[
              0.5870227647058823, 0.6486806764705882, 0.821780617647059], 
             UndirectedEdge[54, 186] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[355, 444] -> 
             RGBColor[
              0.5034798529411765, 0.5978537352941176, 0.9565401470588235], 
             UndirectedEdge[7, 448] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647057], 
             UndirectedEdge[47, 416] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[48, 155] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[346, 486] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[24, 491] -> 
             RGBColor[
              0.9468331176470589, 0.8269180588235298, 0.27607888235294126`], 
             UndirectedEdge[321, 373] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[209, 231] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[210, 393] -> 
             RGBColor[
              0.6229358235294118, 0.6650397352941178, 0.6486475588235294], 
             UndirectedEdge[188, 409] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[307, 427] -> 
             RGBColor[
              0.8970220882352942, 0.8539625882352943, 0.630683911764706], 
             UndirectedEdge[178, 186] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[328, 475] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[213, 337] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[384, 458] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[87, 473] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[112, 440] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[237, 429] -> 
             RGBColor[
              0.9527160588235295, 0.837048823529412, 0.47837732352941204`], 
             UndirectedEdge[109, 230] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[89, 262] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[280, 383] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[196, 489] -> 
             RGBColor[
              0.9674696176470589, 0.908133823529412, 0.561427411764706], 
             UndirectedEdge[279, 459] -> 
             RGBColor[
              0.7779159705882353, 0.7601848823529413, 0.6192203235294118], 
             UndirectedEdge[191, 423] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[116, 165] -> 
             RGBColor[
              0.5523357058823529, 0.6437004117647058, 0.9595239411764706], 
             UndirectedEdge[176, 313] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[180, 490] -> 
             RGBColor[
              0.6613845882352941, 0.7330628235294117, 0.9685728823529411], 
             UndirectedEdge[17, 498] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058825, 0.6345793235294118], 
             UndirectedEdge[108, 364] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[29, 254] -> 
             RGBColor[
              0.8921979117647059, 0.5545467647058824, 0.5524162647058823], 
             UndirectedEdge[7, 261] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[122, 224] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[116, 386] -> 
             RGBColor[
              0.6816970882352942, 0.7426854705882353, 0.8273737058823531], 
             UndirectedEdge[8, 439] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[226, 488] -> 
             RGBColor[
              0.5771173529411765, 0.6168816176470588, 0.6460382647058824], 
             UndirectedEdge[64, 170] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[178, 313] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[81, 251] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[186, 288] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[45, 118] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[224, 330] -> 
             RGBColor[
              0.7281049411764706, 0.7872294117647058, 0.9738253529411764], 
             UndirectedEdge[35, 410] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[163, 379] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[181, 443] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[167, 235] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[202, 279] -> 
             RGBColor[
              0.7880378235294117, 0.8342091176470589, 0.9514881470588235], 
             UndirectedEdge[242, 310] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[299, 482] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[56, 110] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[125, 419] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[262, 448] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[95, 212] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[32, 260] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[421, 430] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[129, 346] -> 
             RGBColor[
              0.5730019117647058, 0.6401802647058823, 0.9370577647058824], 
             UndirectedEdge[16, 17] -> 
             RGBColor[
              0.599728088235294, 0.6739238529411764, 0.9658996764705883], 
             UndirectedEdge[153, 466] -> 
             RGBColor[
              0.8416144411764706, 0.8104576470588236, 0.625219794117647], 
             UndirectedEdge[244, 391] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882355], 
             UndirectedEdge[218, 406] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[99, 288] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[399, 481] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[278, 451] -> 
             RGBColor[
              0.5628800588235294, 0.5661560294117649, 0.6047899411764706], 
             UndirectedEdge[179, 327] -> 
             RGBColor[
              0.6676762352941177, 0.7341850588235295, 0.9426508529411765], 
             UndirectedEdge[38, 473] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[17, 176] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[186, 373] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[399, 496] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[116, 358] -> 
             RGBColor[
              0.6676762352941177, 0.7341850588235295, 0.9426508529411765], 
             UndirectedEdge[71, 135] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[53, 374] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529414, 0.6198870882352941], 
             UndirectedEdge[228, 409] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[440, 471] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[403, 471] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[63, 166] -> 
             RGBColor[
              0.6781908823529412, 0.7413765882352942, 0.8957315588235295], 
             UndirectedEdge[159, 272] -> 
             RGBColor[
              0.6929358529411764, 0.6336244117647061, 0.5992756176470588], 
             UndirectedEdge[130, 351] -> 
             RGBColor[
              0.7254329117647058, 0.7567438823529412, 0.6552161764705883], 
             UndirectedEdge[113, 378] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[145, 417] -> 
             RGBColor[
              0.9103135882352942, 0.6821302941176475, 0.24669441176470597`], 
             UndirectedEdge[38, 354] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[334, 446] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[305, 310] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.6083467058823531], 
             UndirectedEdge[338, 383] -> 
             RGBColor[
              0.9030825588235294, 0.7408720588235296, 0.606192794117647], 
             UndirectedEdge[243, 477] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[38, 221] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[330, 357] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[48, 365] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[384, 411] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[38, 436] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[117, 155] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[68, 286] -> 
             RGBColor[
              0.6392946176470589, 0.5877669411764708, 0.595690794117647], 
             UndirectedEdge[378, 380] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[12, 285] -> 
             RGBColor[
              0.961070411764706, 0.8776436470588238, 0.31732720588235297`], 
             UndirectedEdge[93, 432] -> 
             RGBColor[
              0.9197388823529412, 0.6724098823529414, 0.34426864705882343`], 
             UndirectedEdge[340, 499] -> 
             RGBColor[
              0.6676762352941177, 0.7341850588235295, 0.9426508529411765], 
             UndirectedEdge[389, 456] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[390, 451] -> 
             RGBColor[
              0.5130690294117647, 0.5932005588235294, 0.9593949705882353], 
             UndirectedEdge[92, 485] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[293, 471] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[111, 359] -> 
             RGBColor[
              0.5730019117647058, 0.6401802647058824, 0.9370577647058824], 
             UndirectedEdge[357, 441] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[52, 268] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[30, 311] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[164, 486] -> 
             RGBColor[
              0.6781908823529412, 0.7413765882352942, 0.8957315588235295], 
             UndirectedEdge[194, 290] -> 
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764705], 
             UndirectedEdge[238, 445] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[269, 406] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[99, 341] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[41, 457] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[217, 292] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[176, 299] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[218, 314] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[355, 486] -> 
             RGBColor[
              0.6293350294117648, 0.6955299117647059, 0.8927477647058825], 
             UndirectedEdge[213, 420] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[299, 407] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[201, 314] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[160, 300] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[21, 200] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[25, 180] -> 
             RGBColor[
              0.7918034117647059, 0.8375021764705881, 0.9798248235294118], 
             UndirectedEdge[45, 185] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[191, 226] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[50, 82] -> 
             RGBColor[
              0.2247454705882353, 0.35355211764705885`, 0.9361102941176471], 
             UndirectedEdge[22, 491] -> 
             RGBColor[
              0.6575543823529413, 0.660160823529412, 0.6103830294117647], 
             UndirectedEdge[99, 277] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[17, 391] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[211, 362] -> 
             RGBColor[
              0.8970220882352942, 0.8539625882352943, 0.6306839117647058], 
             UndirectedEdge[4, 162] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[259, 444] -> 
             RGBColor[
              0.8233546764705882, 0.7380637647058825, 0.6105275588235295], 
             UndirectedEdge[347, 382] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.830958529411765], 
             UndirectedEdge[66, 179] -> 
             RGBColor[0.6227742647058824, 0.514505117647059, 0.5819965], 
             UndirectedEdge[343, 471] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[97, 322] -> 
             RGBColor[
              0.6807162647058824, 0.7405875882352941, 0.7206171176470587], 
             UndirectedEdge[363, 381] -> 
             RGBColor[
              0.6059769411764705, 0.6895578823529411, 0.9631087647058824], 
             UndirectedEdge[238, 471] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[40, 285] -> 
             RGBColor[
              0.7779159705882353, 0.7601848823529413, 0.6192203235294118], 
             UndirectedEdge[70, 208] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[84, 448] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764708, 0.3716207352941176], 
             UndirectedEdge[152, 195] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[93, 308] -> 
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764705], 
             UndirectedEdge[255, 478] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[112, 293] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[87, 184] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[149, 323] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[272, 497] -> 
             RGBColor[
              0.9103135882352942, 0.6821302941176475, 0.24669441176470597`], 
             UndirectedEdge[80, 471] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[339, 344] -> 
             RGBColor[
              0.920719705882353, 0.6745077647058826, 0.4510252352941179], 
             UndirectedEdge[137, 393] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[11, 316] -> 
             RGBColor[
              0.5539096176470588, 0.6257657352941176, 0.9632903823529412], 
             UndirectedEdge[88, 423] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[70, 351] -> 
             RGBColor[
              0.7213174705882353, 0.7800425294117648, 0.9462356764705883], 
             UndirectedEdge[55, 298] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[428, 437] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[90, 137] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705883], 
             UndirectedEdge[344, 439] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[93, 274] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             UndirectedEdge[60, 434] -> 
             RGBColor[
              0.6229358235294118, 0.6650397352941178, 0.6486475588235294], 
             UndirectedEdge[54, 244] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[243, 318] -> 
             RGBColor[
              0.6717916764705882, 0.7108864117647059, 0.6516313529411765], 
             UndirectedEdge[384, 402] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[83, 233] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[153, 201] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882355], 
             UndirectedEdge[275, 331] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[312, 327] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[181, 370] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[32, 245] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[176, 391] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[148, 232] -> 
             RGBColor[
              0.7779159705882353, 0.7601848823529413, 0.6192203235294118], 
             UndirectedEdge[430, 477] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[7, 475] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[15, 50] -> 
             RGBColor[
              0.5739184117647059, 0.46865844117647076`, 0.579012705882353], 
             UndirectedEdge[168, 395] -> 
             RGBColor[
              0.6485839411764706, 0.7197705294117647, 0.9688834705882352], 
             UndirectedEdge[97, 440] -> 
             RGBColor[
              0.6077433529411764, 0.6872053529411765, 0.9649880588235293], 
             UndirectedEdge[71, 308] -> 
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647], 
             UndirectedEdge[253, 436] -> 
             RGBColor[
              0.9674696176470589, 0.908133823529412, 0.561427411764706], 
             UndirectedEdge[13, 430] -> 
             RGBColor[
              0.961070411764706, 0.8776436470588238, 0.31732720588235297`], 
             UndirectedEdge[209, 233] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[254, 350] -> 
             RGBColor[
              0.8318199411764706, 0.2455875882352943, 0.17810411764705886`], 
             UndirectedEdge[115, 268] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[42, 468] -> 
             RGBColor[
              0.5835165588235294, 0.6473717941176471, 0.8901384705882354], 
             UndirectedEdge[51, 60] -> 
             RGBColor[
              0.4397813823529412, 0.5475809705882353, 0.9505406764705882], 
             UndirectedEdge[331, 348] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[310, 406] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[70, 130] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[83, 440] -> 
             RGBColor[
              0.7918034117647059, 0.8375021764705881, 0.9798248235294118], 
             UndirectedEdge[100, 374] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[207, 374] -> 
             RGBColor[
              0.8233546764705882, 0.7380637647058825, 0.6105275588235295], 
             UndirectedEdge[51, 324] -> 
             RGBColor[
              0.672697294117647, 0.7437244705882353, 0.9683612352941176], 
             UndirectedEdge[164, 180] -> 
             RGBColor[
              0.6077433529411764, 0.6872053529411765, 0.9649880588235293], 
             UndirectedEdge[56, 132] -> 
             RGBColor[
              0.8787623235294117, 0.781568705882353, 0.6159916764705883], 
             UndirectedEdge[30, 423] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[104, 379] -> 
             RGBColor[
              0.9361957058823529, 0.7637870000000002, 0.464683029411765], 
             UndirectedEdge[324, 457] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529411], 
             UndirectedEdge[283, 459] -> 
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352], 
             UndirectedEdge[128, 245] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[34, 62] -> 
             RGBColor[
              0.6077433529411764, 0.6872053529411765, 0.9649880588235293], 
             UndirectedEdge[320, 424] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[111, 351] -> 
             RGBColor[
              0.7213174705882353, 0.7800425294117648, 0.9462356764705883], 
             UndirectedEdge[79, 316] -> 
             RGBColor[
              0.5771173529411765, 0.6168816176470588, 0.6460382647058824], 
             UndirectedEdge[43, 250] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[116, 313] -> 
             RGBColor[
              0.6717916764705882, 0.7108864117647059, 0.6516313529411765], 
             UndirectedEdge[87, 436] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[280, 393] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[295, 321] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[131, 186] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[165, 313] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[140, 270] -> 
             RGBColor[
              0.8233546764705882, 0.7380637647058825, 0.6105275588235295], 
             UndirectedEdge[322, 445] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[112, 463] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[115, 223] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[102, 451] -> 
             RGBColor[
              0.5730019117647058, 0.6401802647058824, 0.9370577647058824], 
             UndirectedEdge[148, 267] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[447, 500] -> 
             RGBColor[
              0.5730019117647058, 0.6401802647058823, 0.9370577647058824], 
             UndirectedEdge[238, 293] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[56, 457] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[204, 331] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[66, 260] -> 
             RGBColor[
              0.9030825588235294, 0.7408720588235296, 0.606192794117647], 
             UndirectedEdge[225, 424] -> 
             RGBColor[
              0.9108142941176471, 0.6427087058823532, 0.2752828823529412], 
             UndirectedEdge[178, 244] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[139, 247] -> 
             RGBColor[
              0.6392946176470589, 0.5877669411764708, 0.595690794117647], 
             UndirectedEdge[244, 448] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[259, 275] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764708, 0.3716207352941176], 
             UndirectedEdge[282, 406] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[286, 357] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705883], 
             UndirectedEdge[206, 396] -> 
             RGBColor[
              0.6485839411764706, 0.7197705294117647, 0.9688834705882352], 
             UndirectedEdge[154, 295] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[410, 428] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[104, 147] -> 
             RGBColor[0.6764155, 0.5603625882352943, 0.5855813235294118], 
             UndirectedEdge[32, 255] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[165, 498] -> 
             RGBColor[
              0.8416144411764706, 0.8104576470588236, 0.625219794117647], 
             UndirectedEdge[248, 439] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[141, 389] -> 
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352], 
             UndirectedEdge[328, 478] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[178, 261] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[120, 315] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[47, 136] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[74, 144] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[165, 361] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882355], 
             UndirectedEdge[32, 482] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[67, 119] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[97, 326] -> 
             RGBColor[
              0.5523357058823529, 0.6437004117647058, 0.9595239411764706], 
             UndirectedEdge[409, 430] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[113, 190] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[292, 496] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[15, 82] -> 
             RGBColor[
              0.5280999411764706, 0.4205003235294119, 0.5764034117647059], 
             UndirectedEdge[340, 414] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[149, 282] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[330, 368] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[331, 431] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[4, 488] -> 
             RGBColor[
              0.5771173529411765, 0.6168816176470588, 0.6460382647058824], 
             UndirectedEdge[87, 409] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[440, 445] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[55, 200] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[64, 215] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647057], 
             UndirectedEdge[167, 493] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[153, 470] -> 
             RGBColor[
              0.7913583235294117, 0.5755227058823531, 0.5831754705882353], 
             UndirectedEdge[185, 187] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[18, 310] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[226, 366] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[333, 361] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[236, 300] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[161, 335] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[61, 397] -> 
             RGBColor[0.9172135, 0.6731988823529413, 0.5193830882352942], 
             UndirectedEdge[393, 480] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[349, 378] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[97, 163] -> 
             RGBColor[
              0.6077433529411764, 0.6872053529411765, 0.9649880588235293], 
             UndirectedEdge[229, 267] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[77, 287] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[41, 485] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[7, 89] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[41, 44] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[147, 234] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.830958529411765], 
             UndirectedEdge[259, 331] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[77, 409] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[2, 334] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[315, 487] -> 
             RGBColor[
              0.6781908823529412, 0.7413765882352942, 0.8957315588235295], 
             UndirectedEdge[251, 258] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[39, 96] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[219, 497] -> 
             RGBColor[
              0.9527160588235295, 0.837048823529412, 0.47837732352941204`], 
             UndirectedEdge[447, 454] -> 
             RGBColor[
              0.2247454705882353, 0.35355211764705885`, 0.9361102941176471], 
             UndirectedEdge[417, 458] -> 
             RGBColor[
              0.8233546764705882, 0.7380637647058825, 0.6105275588235295], 
             UndirectedEdge[189, 422] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[431, 444] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529411], 
             UndirectedEdge[161, 273] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[109, 413] -> 
             RGBColor[
              0.5446202941176471, 0.4937621470588237, 0.590097705882353], 
             UndirectedEdge[236, 470] -> 
             RGBColor[0.9172135, 0.6731988823529413, 0.5193830882352942], 
             UndirectedEdge[287, 436] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[253, 473] -> 
             RGBColor[
              0.9468331176470589, 0.8269180588235298, 0.27607888235294126`], 
             UndirectedEdge[166, 435] -> 
             RGBColor[
              0.6676762352941177, 0.7341850588235295, 0.9426508529411765], 
             UndirectedEdge[114, 312] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[222, 296] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529411], 
             UndirectedEdge[5, 346] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[86, 220] -> 
             RGBColor[
              0.9221748529411764, 0.7552865882352944, 0.5799601764705883], 
             UndirectedEdge[195, 255] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[313, 407] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[224, 441] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647057], 
             UndirectedEdge[172, 211] -> 
             RGBColor[
              0.9674696176470589, 0.908133823529412, 0.561427411764706], 
             UndirectedEdge[204, 355] -> 
             RGBColor[
              0.6318604117647059, 0.6947409117647059, 0.7176333235294117], 
             UndirectedEdge[109, 180] -> 
             RGBColor[
              0.8787623235294117, 0.781568705882353, 0.6159916764705883], 
             UndirectedEdge[96, 157] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[316, 372] -> 
             RGBColor[
              0.5771173529411764, 0.6168816176470588, 0.6460382647058824], 
             UndirectedEdge[53, 112] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[28, 305] -> 
             RGBColor[
              0.9674696176470589, 0.908133823529412, 0.561427411764706], 
             UndirectedEdge[186, 341] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[65, 86] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[10, 390] -> 
             RGBColor[
              0.7918034117647059, 0.8375021764705881, 0.9798248235294118], 
             UndirectedEdge[48, 140] -> 
             RGBColor[
              0.938695205882353, 0.8285484117647062, 0.5936544705882354], 
             UndirectedEdge[231, 404] -> 
             RGBColor[
              0.9030825588235294, 0.7408720588235296, 0.606192794117647], 
             UndirectedEdge[87, 354] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[136, 434] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[205, 413] -> 
             RGBColor[
              0.3939629117647059, 0.4994228529411765, 0.9479313823529412], 
             UndirectedEdge[20, 490] -> 
             RGBColor[
              0.5422784705882352, 0.6392851176470589, 0.9571092941176471], 
             UndirectedEdge[390, 443] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[296, 385] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529411], 
             UndirectedEdge[86, 290] -> 
             RGBColor[
              0.7213174705882353, 0.7800425294117648, 0.9462356764705883], 
             UndirectedEdge[24, 74] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058825, 0.6345793235294117], 
             UndirectedEdge[38, 336] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[383, 443] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[14, 435] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[282, 323] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[307, 337] -> 
             RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             UndirectedEdge[157, 356] -> 
             RGBColor[
              0.7318321176470588, 0.7872340588235294, 0.8993163823529413], 
             UndirectedEdge[166, 439] -> 
             RGBColor[
              0.6485839411764706, 0.7197705294117647, 0.9688834705882352], 
             UndirectedEdge[266, 293] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.830958529411765], 
             UndirectedEdge[2, 260] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[135, 466] -> 
             RGBColor[
              0.9674696176470589, 0.908133823529412, 0.561427411764706], 
             UndirectedEdge[60, 495] -> 
             RGBColor[0.5588875, 0.6413586764705882, 0.9620042647058824], 
             UndirectedEdge[217, 464] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[435, 453] -> 
             RGBColor[
              0.9221748529411764, 0.7552865882352944, 0.5799601764705883], 
             UndirectedEdge[82, 411] -> 
             RGBColor[
              0.5835165588235294, 0.6473717941176471, 0.8901384705882354], 
             UndirectedEdge[94, 193] -> 
             RGBColor[
              0.7431358529411765, 0.6145291764705885, 0.590833794117647], 
             UndirectedEdge[88, 469] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[36, 76] -> 
             RGBColor[
              0.920719705882353, 0.6745077647058826, 0.45102523529411787`], 
             UndirectedEdge[163, 326] -> 
             RGBColor[
              0.7918034117647059, 0.8375021764705881, 0.9798248235294118], 
             UndirectedEdge[151, 472] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[114, 138] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[448, 475] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[169, 362] -> 
             RGBColor[
              0.8787623235294117, 0.781568705882353, 0.6159916764705883], 
             UndirectedEdge[20, 25] -> 
             RGBColor[
              0.672697294117647, 0.7437244705882353, 0.9683612352941176], 
             UndirectedEdge[113, 349] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[457, 494] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[364, 452] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[351, 442] -> 
             RGBColor[0.6764155, 0.5603625882352943, 0.5855813235294118], 
             UndirectedEdge[71, 466] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058825, 0.6345793235294118], 
             UndirectedEdge[87, 285] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[211, 369] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058825, 0.6345793235294117], 
             UndirectedEdge[164, 316] -> 
             RGBColor[
              0.2736013235294118, 0.39939879411764706`, 0.9390940882352941], 
             UndirectedEdge[27, 297] -> 
             RGBColor[
              0.6613845882352941, 0.7330628235294117, 0.9685728823529411], 
             UndirectedEdge[238, 483] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058825, 0.6345793235294117], 
             UndirectedEdge[109, 164] -> 
             RGBColor[
              0.6392946176470589, 0.5877669411764708, 0.595690794117647], 
             UndirectedEdge[83, 355] -> 
             RGBColor[
              0.5034798529411765, 0.5978537352941176, 0.9565401470588235], 
             UndirectedEdge[85, 166] -> 
             RGBColor[
              0.6717916764705882, 0.7108864117647059, 0.6516313529411765], 
             UndirectedEdge[34, 190] -> 
             RGBColor[
              0.6717916764705882, 0.7108864117647059, 0.6516313529411765], 
             UndirectedEdge[232, 383] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058825, 0.6345793235294117], 
             UndirectedEdge[185, 441] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[83, 207] -> 
             RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 
             UndirectedEdge[138, 385] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[131, 234] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[80, 81] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[5, 486] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[94, 139] -> 
             RGBColor[
              0.8937932352941177, 0.6088684705882357, 0.2330001176470589], 
             UndirectedEdge[126, 249] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[359, 483] -> 
             RGBColor[
              0.5539096176470588, 0.6257657352941177, 0.9632903823529412], 
             UndirectedEdge[275, 404] -> 
             RGBColor[
              0.9352148823529411, 0.761689117647059, 0.35792644117647054`], 
             UndirectedEdge[313, 391] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[1, 487] -> 
             RGBColor[
              0.6717916764705882, 0.7108864117647059, 0.6516313529411765], 
             UndirectedEdge[71, 172] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[44, 494] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[85, 387] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[414, 499] -> 
             RGBColor[
              0.6781908823529412, 0.7413765882352942, 0.8957315588235295], 
             UndirectedEdge[89, 376] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[171, 403] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[161, 279] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[149, 310] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[333, 367] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[43, 227] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[71, 369] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[134, 174] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[158, 370] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[7, 391] -> 
             RGBColor[
              0.672697294117647, 0.7437244705882353, 0.9683612352941176], 
             UndirectedEdge[200, 228] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764708, 0.3716207352941176], 
             UndirectedEdge[201, 300] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[210, 320] -> 
             RGBColor[
              0.6188203823529412, 0.6883383823529412, 0.9396670588235294], 
             UndirectedEdge[69, 103] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[97, 281] -> 
             RGBColor[
              0.6077433529411764, 0.6872053529411765, 0.9649880588235293], 
             UndirectedEdge[192, 272] -> 
             RGBColor[
              0.9103135882352942, 0.6821302941176475, 0.24669441176470597`], 
             UndirectedEdge[70, 463] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[285, 477] -> 
             RGBColor[
              0.7779159705882353, 0.7601848823529413, 0.6192203235294118], 
             UndirectedEdge[10, 168] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[298, 468] -> 
             RGBColor[
              0.5835165588235294, 0.6473717941176471, 0.8901384705882354], 
             UndirectedEdge[37, 264] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647057], 
             UndirectedEdge[191, 405] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[349, 380] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[94, 410] -> 
             RGBColor[0.9326895, 0.762478117647059, 0.5330408823529413], 
             UndirectedEdge[335, 409] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[168, 189] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[187, 399] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[153, 314] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[233, 355] -> 
             RGBColor[
              0.6229358235294118, 0.6650397352941178, 0.6486475588235294], 
             UndirectedEdge[233, 486] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[49, 264] -> 
             RGBColor[
              0.4397813823529412, 0.5475809705882353, 0.9505406764705882], 
             UndirectedEdge[205, 331] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[308, 456] -> 
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.6188203823529412, 0.6883383823529412, 0.9396670588235294], 
             UndirectedEdge[175, 371] -> 
             RGBColor[
              0.6613845882352941, 0.7330628235294117, 0.9685728823529411], 
             UndirectedEdge[21, 188] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[79, 221] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[158, 193] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647057], 
             UndirectedEdge[266, 483] -> 
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647], 
             UndirectedEdge[290, 484] -> 
             RGBColor[
              0.7111956176470589, 0.7060182941176472, 0.6139678529411765], 
             UndirectedEdge[153, 411] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[176, 475] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[20, 474] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647057], 
             UndirectedEdge[70, 483] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[163, 266] -> 
             RGBColor[
              0.6613845882352941, 0.7330628235294117, 0.9685728823529411], 
             UndirectedEdge[69, 486] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[262, 475] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[18, 167] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529411], 
             UndirectedEdge[281, 374] -> 
             RGBColor[
              0.8787623235294117, 0.781568705882353, 0.6159916764705883], 
             UndirectedEdge[138, 294] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[291, 349] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[288, 455] -> 
             RGBColor[
              0.7318321176470588, 0.7872340588235294, 0.8993163823529413], 
             UndirectedEdge[12, 459] -> 
             RGBColor[
              0.961070411764706, 0.8776436470588238, 0.31732720588235297`], 
             UndirectedEdge[93, 305] -> 
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352], 
             UndirectedEdge[127, 184] -> 
             RGBColor[
              0.6816970882352942, 0.7426854705882353, 0.8273737058823531], 
             UndirectedEdge[204, 431] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             UndirectedEdge[397, 495] -> 
             RGBColor[
              0.8467659705882353, 0.6190276470588236, 0.5886395882352942], 
             UndirectedEdge[28, 493] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[267, 485] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[110, 494] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[337, 500] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[43, 393] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[167, 432] -> 
             RGBColor[
              0.9197388823529412, 0.6724098823529414, 0.34426864705882343`], 
             UndirectedEdge[230, 474] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[40, 421] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[254, 476] -> 
             RGBColor[
              0.9062187647058824, 0.5630471764705882, 0.43713911764705904`], 
             UndirectedEdge[107, 197] -> 
             RGBColor[
              0.6613845882352941, 0.7330628235294117, 0.9685728823529411], 
             UndirectedEdge[231, 395] -> 
             RGBColor[
              0.6485839411764706, 0.7197705294117647, 0.9688834705882352], 
             UndirectedEdge[420, 427] -> 
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352], 
             UndirectedEdge[317, 374] -> 
             RGBColor[
              0.5904387647058824, 0.5419202647058825, 0.5927070000000001], 
             UndirectedEdge[188, 200] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[84, 260] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529414, 0.6198870882352941], 
             UndirectedEdge[33, 160] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[135, 362] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[123, 193] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[439, 453] -> 
             RGBColor[
              0.9030825588235294, 0.7408720588235296, 0.606192794117647], 
             UndirectedEdge[269, 282] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[202, 459] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.608346705882353], 
             UndirectedEdge[25, 474] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529411], 
             UndirectedEdge[103, 259] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705883], 
             UndirectedEdge[352, 375] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[300, 308] -> 
             RGBColor[
              0.6613845882352941, 0.7330628235294117, 0.9685728823529411], 
             UndirectedEdge[32, 328] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[209, 486] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[118, 496] -> 
             RGBColor[
              0.7880378235294117, 0.8342091176470589, 0.9514881470588235], 
             UndirectedEdge[31, 405] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[21, 228] -> 
             RGBColor[
              0.9527160588235295, 0.837048823529412, 0.47837732352941204`], 
             UndirectedEdge[92, 250] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[177, 290] -> 
             RGBColor[0.4219168823529411, 0.5392610588235294, 0.948272], 
             UndirectedEdge[9, 333] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[11, 444] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[11, 25] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[168, 338] -> 
             RGBColor[
              0.9030825588235294, 0.7408720588235296, 0.606192794117647], 
             UndirectedEdge[283, 430] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[139, 410] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705883], 
             UndirectedEdge[195, 260] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[391, 407] -> 
             RGBColor[
              0.7918034117647059, 0.8375021764705881, 0.9798248235294118], 
             UndirectedEdge[33, 111] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[2, 114] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[101, 306] -> 
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352], 
             UndirectedEdge[264, 374] -> 
             RGBColor[
              0.7596562058823529, 0.6877910000000003, 0.6045280882352941], 
             UndirectedEdge[172, 235] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[84, 475] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529414, 0.6198870882352941], 
             UndirectedEdge[37, 397] -> 
             RGBColor[
              0.9197388823529412, 0.6724098823529414, 0.34426864705882343`], 
             UndirectedEdge[228, 287] -> 
             RGBColor[
              0.938695205882353, 0.8285484117647062, 0.5936544705882354], 
             UndirectedEdge[68, 375] -> 
             RGBColor[
              0.6807162647058824, 0.7405875882352941, 0.7206171176470587], 
             UndirectedEdge[197, 236] -> 
             RGBColor[
              0.7318321176470588, 0.7872340588235294, 0.8993163823529413], 
             UndirectedEdge[107, 214] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[207, 317] -> 
             RGBColor[
              0.5034798529411765, 0.5978537352941176, 0.9565401470588235], 
             UndirectedEdge[98, 462] -> 
             RGBColor[
              0.7431358529411765, 0.6145291764705885, 0.590833794117647], 
             UndirectedEdge[21, 59] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[46, 350] -> 
             RGBColor[
              0.8783172352941178, 0.519589235294118, 0.21934232352941183`], 
             UndirectedEdge[271, 429] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[304, 423] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705883], 
             UndirectedEdge[299, 328] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[55, 73] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[53, 440] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[206, 377] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[39, 113] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[9, 450] -> 
             RGBColor[
              0.7880378235294117, 0.8342091176470589, 0.9514881470588235], 
             UndirectedEdge[61, 321] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[76, 460] -> 
             RGBColor[
              0.9108142941176471, 0.6427087058823532, 0.2752828823529412], 
             UndirectedEdge[141, 167] -> 
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352], 
             UndirectedEdge[29, 476] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[39, 190] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[115, 215] -> 
             RGBColor[
              0.7281049411764706, 0.7872294117647058, 0.9738253529411764], 
             UndirectedEdge[208, 471] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[139, 401] -> 
             RGBColor[
              0.9285733529411766, 0.7545241764705886, 0.26138664705882364`], 
             UndirectedEdge[34, 356] -> 
             RGBColor[0.4219168823529411, 0.5392610588235294, 0.948272], 
             UndirectedEdge[288, 313] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[66, 334] -> 
             RGBColor[0.9326895, 0.762478117647059, 0.5330408823529413], 
             UndirectedEdge[17, 328] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[318, 459] -> 
             RGBColor[
              0.6575543823529413, 0.660160823529412, 0.6103830294117647], 
             UndirectedEdge[163, 233] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[141, 300] -> 
             RGBColor[
              0.8970220882352942, 0.8539625882352943, 0.6306839117647058], 
             UndirectedEdge[354, 436] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[29, 290] -> 
             RGBColor[
              0.7213174705882353, 0.7800425294117648, 0.9462356764705883], 
             UndirectedEdge[110, 360] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[289, 308] -> 
             RGBColor[
              0.7213174705882353, 0.7800425294117648, 0.9462356764705883], 
             UndirectedEdge[264, 324] -> 
             RGBColor[
              0.672697294117647, 0.7437244705882353, 0.9683612352941176], 
             UndirectedEdge[109, 382] -> 
             RGBColor[
              0.9527160588235295, 0.837048823529412, 0.47837732352941204`], 
             UndirectedEdge[293, 497] -> 
             RGBColor[
              0.9527160588235295, 0.837048823529412, 0.47837732352941204`], 
             UndirectedEdge[160, 237] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764708, 0.3716207352941176], 
             UndirectedEdge[35, 123] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[218, 432] -> 
             RGBColor[
              0.9066988529411765, 0.6660073529411767, 0.5663023823529412], 
             UndirectedEdge[46, 476] -> 
             RGBColor[
              0.9527160588235295, 0.837048823529412, 0.47837732352941204`], 
             UndirectedEdge[288, 391] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[259, 486] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705883], 
             UndirectedEdge[138, 296] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882355], 
             UndirectedEdge[56, 494] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[91, 200] -> 
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764705], 
             UndirectedEdge[172, 493] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[340, 461] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[33, 274] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[235, 345] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[205, 490] -> 
             RGBColor[
              0.5422784705882352, 0.6392851176470589, 0.9571092941176471], 
             UndirectedEdge[141, 284] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[489, 500] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[155, 198] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[23, 157] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[248, 344] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[50, 131] -> 
             RGBColor[
              0.6328412352941177, 0.696838794117647, 0.8243899117647061], 
             UndirectedEdge[442, 500] -> 
             RGBColor[
              0.9221748529411764, 0.7552865882352944, 0.5799601764705883], 
             UndirectedEdge[18, 305] -> 
             RGBColor[
              0.8416144411764706, 0.8104576470588236, 0.625219794117647], 
             UndirectedEdge[134, 278] -> 
             RGBColor[
              0.9674696176470589, 0.908133823529412, 0.561427411764706], 
             UndirectedEdge[158, 422] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[229, 393] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[17, 143] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[53, 83] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[166, 239] -> 
             RGBColor[
              0.6077433529411764, 0.6872053529411765, 0.9649880588235293], 
             UndirectedEdge[46, 194] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764708, 0.3716207352941176], 
             UndirectedEdge[319, 368] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[51, 360] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[132, 250] -> 
             RGBColor[
              0.7596562058823529, 0.6877910000000003, 0.6045280882352941], 
             UndirectedEdge[80, 447] -> 
             RGBColor[
              0.5870227647058823, 0.6486806764705882, 0.821780617647059], 
             UndirectedEdge[128, 179] -> 
             RGBColor[
              0.6816970882352942, 0.7426854705882353, 0.8273737058823531], 
             UndirectedEdge[218, 300] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[130, 241] -> 
             RGBColor[
              0.6717916764705882, 0.7108864117647059, 0.6516313529411765], 
             UndirectedEdge[134, 252] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[266, 317] -> 
             RGBColor[
              0.37306102941176467`, 0.49341438235294116`, 0.945288205882353], 
             UndirectedEdge[156, 485] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[96, 110] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[50, 373] -> 
             RGBColor[
              0.6188203823529412, 0.6883383823529412, 0.9396670588235294], 
             UndirectedEdge[37, 322] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             UndirectedEdge[65, 290] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.830958529411765], 
             UndirectedEdge[333, 450] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647057], 
             UndirectedEdge[238, 266] -> 
             RGBColor[
              0.7111956176470589, 0.7060182941176472, 0.6139678529411765], 
             UndirectedEdge[312, 446] -> 
             RGBColor[
              0.7281049411764706, 0.7872294117647058, 0.9738253529411764], 
             UndirectedEdge[407, 448] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[14, 454] -> 
             RGBColor[
              0.6229358235294118, 0.6650397352941178, 0.6486475588235294], 
             UndirectedEdge[77, 473] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.608346705882353], 
             UndirectedEdge[57, 136] -> 
             RGBColor[
              0.6781908823529412, 0.7413765882352942, 0.8957315588235295], 
             UndirectedEdge[364, 487] -> 
             RGBColor[
              0.6485839411764706, 0.7197705294117647, 0.9688834705882352], 
             UndirectedEdge[80, 403] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[330, 352] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[239, 272] -> 
             RGBColor[
              0.8787623235294117, 0.781568705882353, 0.6159916764705883], 
             UndirectedEdge[53, 97] -> 
             RGBColor[
              0.6485839411764706, 0.7197705294117647, 0.9688834705882352], 
             UndirectedEdge[304, 311] -> 
             RGBColor[
              0.938695205882353, 0.8285484117647062, 0.5936544705882354], 
             UndirectedEdge[237, 241] -> 
             RGBColor[
              0.6392946176470589, 0.5877669411764708, 0.595690794117647], 
             UndirectedEdge[361, 441] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[276, 347] -> 
             RGBColor[
              0.5422784705882352, 0.6392851176470589, 0.9571092941176471], 
             UndirectedEdge[11, 180] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[56, 360] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[15, 269] -> 
             RGBColor[
              0.9221748529411764, 0.7552865882352944, 0.5799601764705883], 
             UndirectedEdge[8, 387] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[139, 278] -> 
             RGBColor[
              0.9285733529411766, 0.7545241764705886, 0.26138664705882364`], 
             UndirectedEdge[15, 449] -> 
             RGBColor[
              0.7431358529411765, 0.6145291764705885, 0.590833794117647], 
             UndirectedEdge[348, 355] -> 
             RGBColor[
              0.6328412352941176, 0.696838794117647, 0.8243899117647061], 
             UndirectedEdge[173, 499] -> 
             RGBColor[
              0.2736013235294118, 0.39939879411764706`, 0.9390940882352941], 
             UndirectedEdge[130, 483] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[173, 282] -> 
             RGBColor[
              0.5835165588235294, 0.6473717941176471, 0.8901384705882354], 
             UndirectedEdge[84, 244] -> 
             RGBColor[
              0.9527160588235295, 0.837048823529412, 0.47837732352941204`], 
             UndirectedEdge[183, 279] -> 
             RGBColor[
              0.4886372352941176, 0.5934276470588236, 0.9535244705882353], 
             UndirectedEdge[124, 381] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882355], 
             UndirectedEdge[81, 213] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[134, 210] -> 
             RGBColor[
              0.6293350294117647, 0.6955299117647059, 0.8927477647058825], 
             UndirectedEdge[103, 275] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[256, 298] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[18, 235] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[255, 334] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[209, 372] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[112, 238] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[360, 457] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[233, 404] -> 
             RGBColor[
              0.9262902941176471, 0.7319879411764708, 0.2889406764705883], 
             UndirectedEdge[259, 348] -> 
             RGBColor[
              0.9527160588235295, 0.837048823529412, 0.47837732352941204`], 
             UndirectedEdge[244, 376] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[182, 371] -> 
             RGBColor[
              0.6929358529411764, 0.6336244117647061, 0.5992756176470588], 
             UndirectedEdge[21, 77] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[153, 493] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[276, 382] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[80, 219] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[60, 136] -> 
             RGBColor[
              0.6293350294117648, 0.6955299117647059, 0.8927477647058825], 
             UndirectedEdge[23, 96] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[53, 281] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[141, 162] -> 
             RGBColor[
              0.9674696176470589, 0.908133823529412, 0.561427411764706], 
             UndirectedEdge[28, 149] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[37, 317] -> 
             RGBColor[
              0.6318604117647059, 0.6947409117647059, 0.7176333235294117], 
             UndirectedEdge[372, 486] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[63, 453] -> 
             RGBColor[0.9326895, 0.762478117647059, 0.5330408823529413], 
             UndirectedEdge[82, 242] -> 
             RGBColor[
              0.5539096176470588, 0.6257657352941177, 0.9632903823529412], 
             UndirectedEdge[4, 191] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[70, 403] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[144, 458] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[16, 224] -> 
             RGBColor[
              0.4397813823529412, 0.5475809705882353, 0.9505406764705882], 
             UndirectedEdge[40, 206] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[148, 485] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[34, 291] -> 
             RGBColor[
              0.6485839411764706, 0.7197705294117647, 0.9688834705882352], 
             UndirectedEdge[222, 339] -> 
             RGBColor[
              0.9197388823529412, 0.6724098823529414, 0.34426864705882343`], 
             UndirectedEdge[197, 314] -> 
             RGBColor[
              0.7213174705882353, 0.7800425294117648, 0.9462356764705883], 
             UndirectedEdge[330, 358] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[312, 415] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[370, 443] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[160, 305] -> 
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352], 
             UndirectedEdge[266, 343] -> 
             RGBColor[
              0.7213174705882353, 0.7800425294117648, 0.9462356764705883], 
             UndirectedEdge[47, 468] -> 
             RGBColor[
              0.5860419411764706, 0.6465827941176471, 0.7150240294117647], 
             UndirectedEdge[388, 436] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[69, 209] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[197, 470] -> 
             RGBColor[0.6609395, 0.47108335294117665`, 0.5719235294117647], 
             UndirectedEdge[13, 298] -> 
             RGBColor[
              0.9674696176470589, 0.908133823529412, 0.561427411764706], 
             UndirectedEdge[168, 383] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[123, 428] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[137, 485] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529414, 0.6198870882352941], 
             UndirectedEdge[394, 467] -> 
             RGBColor[
              0.961070411764706, 0.8776436470588238, 0.31732720588235297`], 
             UndirectedEdge[232, 395] -> 
             RGBColor[
              0.6575543823529413, 0.660160823529412, 0.6103830294117647], 
             UndirectedEdge[414, 461] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[224, 333] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647057], 
             UndirectedEdge[33, 182] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705883], 
             UndirectedEdge[158, 451] -> 
             RGBColor[
              0.5860419411764706, 0.6465827941176471, 0.7150240294117647], 
             UndirectedEdge[235, 274] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[284, 345] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[70, 238] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.608346705882353], 
             UndirectedEdge[21, 55] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[55, 60] -> 
             RGBColor[
              0.5997280882352941, 0.6739238529411764, 0.9658996764705883], 
             UndirectedEdge[219, 258] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[175, 463] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[101, 431] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             UndirectedEdge[14, 213] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[378, 487] -> 
             RGBColor[
              0.6676762352941177, 0.7341850588235295, 0.9426508529411765], 
             UndirectedEdge[8, 159] -> 
             RGBColor[
              0.6059769411764705, 0.6895578823529411, 0.9631087647058824], 
             UndirectedEdge[311, 469] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[343, 440] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[371, 460] -> 
             RGBColor[
              0.7254329117647058, 0.7567438823529412, 0.6552161764705883], 
             UndirectedEdge[224, 358] -> 
             RGBColor[
              0.7880378235294117, 0.8342091176470589, 0.9514881470588235], 
             UndirectedEdge[455, 475] -> 
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647], 
             UndirectedEdge[310, 408] -> 
             RGBColor[
              0.7880378235294117, 0.8342091176470589, 0.9514881470588235], 
             UndirectedEdge[154, 376] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[282, 499] -> 
             RGBColor[
              0.6781908823529412, 0.7413765882352942, 0.8957315588235295], 
             UndirectedEdge[14, 192] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[75, 147] -> 
             RGBColor[
              0.7254329117647058, 0.7567438823529412, 0.6552161764705883], 
             UndirectedEdge[175, 351] -> 
             RGBColor[
              0.6613845882352941, 0.7330628235294117, 0.9685728823529411], 
             UndirectedEdge[109, 205] -> 
             RGBColor[
              0.7596562058823529, 0.6877910000000003, 0.6045280882352941], 
             UndirectedEdge[43, 148] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[56, 92] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[46, 412] -> 
             RGBColor[
              0.938695205882353, 0.8285484117647062, 0.5936544705882354], 
             UndirectedEdge[170, 214] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[94, 437] -> 
             RGBColor[
              0.9030825588235294, 0.7408720588235296, 0.606192794117647], 
             UndirectedEdge[173, 249] -> 
             RGBColor[
              0.5835165588235294, 0.6473717941176471, 0.8901384705882354], 
             UndirectedEdge[181, 302] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[188, 279] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[317, 471] -> 
             RGBColor[
              0.6328412352941177, 0.696838794117647, 0.8243899117647061], 
             UndirectedEdge[8, 344] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882355], 
             UndirectedEdge[236, 493] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[31, 366] -> 
             RGBColor[
              0.7281049411764706, 0.7872294117647058, 0.9738253529411764], 
             UndirectedEdge[176, 261] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[144, 145] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705883], 
             UndirectedEdge[144, 375] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[258, 293] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[242, 269] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[45, 216] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[82, 323] -> 
             RGBColor[
              0.5860419411764706, 0.6465827941176472, 0.7150240294117647], 
             UndirectedEdge[258, 272] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[92, 356] -> 
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647], 
             UndirectedEdge[114, 327] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[188, 459] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[465, 469] -> 
             RGBColor[
              0.8416144411764706, 0.8104576470588236, 0.6252197941176472], 
             UndirectedEdge[44, 62] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[88, 337] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[253, 388] -> 
             RGBColor[
              0.9674696176470589, 0.908133823529412, 0.561427411764706], 
             UndirectedEdge[80, 238] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[171, 272] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705883], 
             UndirectedEdge[297, 392] -> 
             RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             UndirectedEdge[82, 499] -> 
             RGBColor[
              0.2736013235294118, 0.39939879411764706`, 0.9390940882352941], 
             UndirectedEdge[297, 484] -> 
             RGBColor[
              0.8970220882352942, 0.8539625882352943, 0.630683911764706], 
             UndirectedEdge[73, 240] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[229, 263] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[87, 91] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.830958529411765], 
             UndirectedEdge[296, 339] -> 
             RGBColor[
              0.7913583235294117, 0.5755227058823531, 0.5831754705882353], 
             UndirectedEdge[62, 157] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[227, 265] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[38, 127] -> 
             RGBColor[
              0.6816970882352942, 0.7426854705882353, 0.8273737058823531], 
             UndirectedEdge[302, 451] -> 
             RGBColor[
              0.5860419411764706, 0.6465827941176471, 0.7150240294117647], 
             UndirectedEdge[141, 151] -> 
             RGBColor[
              0.961070411764706, 0.8776436470588238, 0.31732720588235297`], 
             UndirectedEdge[72, 439] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[277, 340] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[53, 322] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[450, 461] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[352, 367] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[239, 251] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[83, 163] -> 
             RGBColor[
              0.7918034117647059, 0.8375021764705881, 0.9798248235294118], 
             UndirectedEdge[179, 245] -> 
             RGBColor[
              0.6816970882352942, 0.7426854705882353, 0.8273737058823531], 
             UndirectedEdge[133, 237] -> 
             RGBColor[
              0.9285733529411766, 0.7545241764705886, 0.26138664705882364`], 
             UndirectedEdge[199, 244] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[173, 269] -> 
             RGBColor[
              0.5730019117647058, 0.6401802647058823, 0.9370577647058824], 
             UndirectedEdge[209, 379] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[139, 451] -> 
             RGBColor[
              0.5446202941176471, 0.4937621470588237, 0.590097705882353], 
             UndirectedEdge[18, 218] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[59, 287] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[167, 274] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             UndirectedEdge[402, 461] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[472, 488] -> 
             RGBColor[
              0.5835165588235294, 0.6473717941176471, 0.8901384705882354], 
             UndirectedEdge[227, 270] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[124, 363] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.830958529411765], 
             UndirectedEdge[118, 195] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[54, 154] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[313, 498] -> 
             RGBColor[
              0.961070411764706, 0.8776436470588238, 0.31732720588235297`], 
             UndirectedEdge[243, 283] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[302, 346] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[13, 477] -> 
             RGBColor[
              0.7779159705882353, 0.7601848823529413, 0.6192203235294118], 
             UndirectedEdge[140, 479] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[174, 309] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882355], 
             UndirectedEdge[299, 312] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[215, 402] -> 
             RGBColor[
              0.672697294117647, 0.7437244705882353, 0.9683612352941176], 
             UndirectedEdge[372, 400] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[29, 426] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[361, 481] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[188, 335] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882355], 
             UndirectedEdge[168, 443] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[81, 500] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[75, 310] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[348, 444] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882355], 
             UndirectedEdge[262, 482] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[83, 395] -> 
             RGBColor[
              0.5523357058823529, 0.6437004117647058, 0.9595239411764706], 
             UndirectedEdge[26, 459] -> 
             RGBColor[
              0.9468331176470589, 0.8269180588235298, 0.27607888235294126`], 
             UndirectedEdge[186, 498] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.608346705882353], 
             UndirectedEdge[167, 284] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[175, 359] -> 
             RGBColor[
              0.5130690294117647, 0.5932005588235294, 0.9593949705882353], 
             UndirectedEdge[65, 484] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[266, 322] -> 
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764705], 
             UndirectedEdge[210, 252] -> 
             RGBColor[0.5588875, 0.6413586764705882, 0.9620042647058824], 
             UndirectedEdge[133, 271] -> 
             RGBColor[
              0.9674696176470589, 0.908133823529412, 0.561427411764706], 
             UndirectedEdge[190, 467] -> 
             RGBColor[
              0.961070411764706, 0.8776436470588238, 0.31732720588235297`], 
             UndirectedEdge[216, 481] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[18, 406] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[315, 364] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[152, 464] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882355], 
             UndirectedEdge[229, 280] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[164, 259] -> 
             RGBColor[
              0.6392946176470589, 0.5877669411764708, 0.595690794117647], 
             UndirectedEdge[238, 497] -> 
             RGBColor[
              0.9285733529411766, 0.7545241764705886, 0.26138664705882364`], 
             UndirectedEdge[7, 478] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[137, 227] -> 
             RGBColor[
              0.938695205882353, 0.8285484117647062, 0.5936544705882354], 
             UndirectedEdge[44, 157] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[105, 205] -> 
             RGBColor[
              0.672697294117647, 0.7437244705882353, 0.9683612352941176], 
             UndirectedEdge[305, 460] -> 
             RGBColor[
              0.961070411764706, 0.8776436470588238, 0.31732720588235297`], 
             UndirectedEdge[330, 492] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[94, 123] -> 
             RGBColor[
              0.9262902941176471, 0.7319879411764708, 0.2889406764705883], 
             UndirectedEdge[418, 444] -> 
             RGBColor[
              0.8068343235294118, 0.6648019411764707, 0.5968332647058824], 
             UndirectedEdge[203, 295] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[342, 485] -> 
             RGBColor[
              0.599728088235294, 0.6739238529411764, 0.9658996764705883], 
             UndirectedEdge[279, 430] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[391, 448] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529411], 
             UndirectedEdge[174, 252] -> 
             RGBColor[
              0.7918034117647059, 0.8375021764705881, 0.9798248235294118], 
             UndirectedEdge[14, 489] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[6, 158] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764708, 0.3716207352941176], 
             UndirectedEdge[201, 493] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[66, 446] -> 
             RGBColor[
              0.7431358529411765, 0.6145291764705885, 0.590833794117647], 
             UndirectedEdge[449, 499] -> 
             RGBColor[
              0.4886372352941176, 0.5934276470588236, 0.9535244705882353], 
             UndirectedEdge[202, 477] -> 
             RGBColor[
              0.7880378235294117, 0.8342091176470589, 0.9514881470588235], 
             UndirectedEdge[89, 299] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[57, 91] -> 
             RGBColor[0.4219168823529411, 0.5392610588235294, 0.948272], 
             UndirectedEdge[222, 438] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647057], 
             UndirectedEdge[83, 346] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[38, 388] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[345, 472] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[231, 486] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[14, 251] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[404, 418] -> 
             RGBColor[
              0.8772728823529412, 0.5356066470588239, 0.21930582352941183`], 
             UndirectedEdge[10, 370] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[216, 224] -> 
             RGBColor[
              0.7281049411764706, 0.7872294117647058, 0.9738253529411764], 
             UndirectedEdge[116, 143] -> 
             RGBColor[
              0.6676762352941177, 0.7341850588235295, 0.9426508529411765], 
             UndirectedEdge[142, 477] -> 
             RGBColor[
              0.7276598529411764, 0.5252499411764708, 0.5771759999999999], 
             UndirectedEdge[1, 378] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[47, 298] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[50, 340] -> 
             RGBColor[
              0.6188203823529412, 0.6883383823529412, 0.9396670588235294], 
             UndirectedEdge[144, 417] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705883], 
             UndirectedEdge[326, 395] -> 
             RGBColor[
              0.5523357058823529, 0.6437004117647058, 0.9595239411764706], 
             UndirectedEdge[14, 166] -> 
             RGBColor[
              0.6717916764705882, 0.7108864117647059, 0.6516313529411765], 
             UndirectedEdge[41, 132] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529414, 0.6198870882352941], 
             UndirectedEdge[6, 35] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[95, 286] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[435, 439] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[354, 388] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[47, 59] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[305, 493] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.6083467058823531], 
             UndirectedEdge[26, 335] -> 
             RGBColor[
              0.8416144411764706, 0.8104576470588236, 0.6252197941176472], 
             UndirectedEdge[24, 115] -> 
             RGBColor[
              0.8970220882352942, 0.8539625882352943, 0.6306839117647058], 
             UndirectedEdge[271, 351] -> 
             RGBColor[
              0.7318321176470588, 0.7872340588235294, 0.8993163823529413], 
             UndirectedEdge[12, 40] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[228, 468] -> 
             RGBColor[
              0.5446202941176471, 0.4937621470588237, 0.590097705882353], 
             UndirectedEdge[1, 108] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[97, 343] -> 
             RGBColor[
              0.6676762352941177, 0.7341850588235295, 0.9426508529411765], 
             UndirectedEdge[314, 411] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[211, 466] -> 
             RGBColor[
              0.9468331176470589, 0.8269180588235298, 0.27607888235294126`], 
             UndirectedEdge[12, 202] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[96, 360] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[199, 482] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[9, 357] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[330, 441] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[375, 461] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[170, 268] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[66, 245] -> 
             RGBColor[
              0.9361957058823529, 0.7637870000000002, 0.464683029411765], 
             UndirectedEdge[235, 308] -> 
             RGBColor[
              0.7318321176470588, 0.7872340588235294, 0.8993163823529413], 
             UndirectedEdge[42, 315] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[238, 403] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058825, 0.6345793235294117], 
             UndirectedEdge[382, 425] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[74, 215] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[350, 426] -> 
             RGBColor[
              0.7913583235294117, 0.5755227058823531, 0.5831754705882353], 
             UndirectedEdge[78, 497] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764708, 0.3716207352941176], 
             UndirectedEdge[109, 490] -> 
             RGBColor[
              0.6929358529411764, 0.6336244117647061, 0.5992756176470588], 
             UndirectedEdge[281, 317] -> 
             RGBColor[0.5588875, 0.6413586764705882, 0.9620042647058824], 
             UndirectedEdge[219, 471] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[183, 243] -> 
             RGBColor[
              0.6717916764705882, 0.7108864117647059, 0.6516313529411765], 
             UndirectedEdge[93, 151] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[176, 478] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[28, 282] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[125, 305] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058825, 0.6345793235294118], 
             UndirectedEdge[22, 466] -> 
             RGBColor[
              0.6575543823529413, 0.660160823529412, 0.6103830294117647], 
             UndirectedEdge[78, 154] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[273, 421] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[221, 234] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[384, 461] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[3, 428] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[209, 431] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[33, 237] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705883], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[202, 243] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[169, 456] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529414, 0.6198870882352941], 
             UndirectedEdge[86, 297] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[40, 202] -> 
             RGBColor[
              0.7880378235294117, 0.8342091176470589, 0.9514881470588235], 
             UndirectedEdge[396, 477] -> 
             RGBColor[
              0.4886372352941176, 0.5934276470588236, 0.9535244705882353], 
             UndirectedEdge[209, 355] -> 
             RGBColor[
              0.6229358235294118, 0.6650397352941178, 0.6486475588235294], 
             UndirectedEdge[131, 434] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[87, 228] -> 
             RGBColor[
              0.9527160588235295, 0.837048823529412, 0.47837732352941204`], 
             UndirectedEdge[17, 116] -> 
             RGBColor[
              0.6485839411764706, 0.7197705294117647, 0.9688834705882352], 
             UndirectedEdge[104, 323] -> 
             RGBColor[
              0.9352148823529411, 0.761689117647059, 0.35792644117647054`], 
             UndirectedEdge[101, 347] -> 
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764705], 
             UndirectedEdge[92, 342] -> 
             RGBColor[
              0.5997280882352941, 0.6739238529411764, 0.9658996764705883], 
             UndirectedEdge[399, 464] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[423, 469] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[114, 415] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[244, 478] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[129, 486] -> 
             RGBColor[
              0.5835165588235294, 0.6473717941176471, 0.8901384705882354], 
             UndirectedEdge[202, 421] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[62, 378] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[263, 485] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[275, 346] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[127, 303] -> 
             RGBColor[0.6227742647058824, 0.514505117647059, 0.5819965], 
             UndirectedEdge[260, 312] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[32, 299] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[283, 396] -> 
             RGBColor[
              0.6807162647058824, 0.7405875882352941, 0.7206171176470587], 
             UndirectedEdge[87, 253] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[298, 409] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[208, 258] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[142, 161] -> 
             RGBColor[0.9172135, 0.6731988823529413, 0.5193830882352943], 
             UndirectedEdge[71, 211] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058825, 0.6345793235294118], 
             UndirectedEdge[14, 453] -> 
             RGBColor[
              0.9262902941176471, 0.7319879411764708, 0.2889406764705883], 
             UndirectedEdge[89, 478] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[159, 251] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.830958529411765], 
             UndirectedEdge[300, 305] -> 
             RGBColor[
              0.8970220882352942, 0.8539625882352943, 0.630683911764706], 
             UndirectedEdge[327, 385] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[156, 270] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[418, 486] -> 
             RGBColor[0.9326895, 0.762478117647059, 0.5330408823529413], 
             UndirectedEdge[366, 465] -> 
             RGBColor[
              0.7779159705882353, 0.7601848823529413, 0.6192203235294118], 
             UndirectedEdge[337, 433] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[118, 152] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[151, 162] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[80, 251] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[348, 486] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[376, 455] -> 
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764705], 
             UndirectedEdge[153, 197] -> 
             RGBColor[
              0.6059769411764705, 0.6895578823529411, 0.9631087647058824], 
             UndirectedEdge[9, 319] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[184, 336] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[41, 56] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[99, 313] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[111, 130] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[255, 327] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[32, 84] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529414, 0.6198870882352941], 
             UndirectedEdge[196, 420] -> 
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352], 
             UndirectedEdge[55, 57] -> 
             RGBColor[
              0.6485839411764706, 0.7197705294117647, 0.9688834705882352], 
             UndirectedEdge[10, 480] -> 
             RGBColor[
              0.8233546764705882, 0.7380637647058825, 0.6105275588235295], 
             UndirectedEdge[152, 216] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[244, 482] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[111, 463] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[58, 74] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[66, 327] -> 
             RGBColor[
              0.9221748529411764, 0.7552865882352944, 0.5799601764705883], 
             UndirectedEdge[168, 346] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[53, 471] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[28, 125] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[405, 423] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[314, 493] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[43, 229] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[281, 397] -> 
             RGBColor[
              0.8467659705882353, 0.6190276470588236, 0.5886395882352942], 
             UndirectedEdge[203, 324] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882355], 
             UndirectedEdge[403, 445] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[147, 303] -> 
             RGBColor[0.6764155, 0.5603625882352943, 0.5855813235294118], 
             UndirectedEdge[356, 457] -> 
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764705], 
             UndirectedEdge[8, 85] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[301, 336] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[24, 64] -> 
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352], 
             UndirectedEdge[30, 488] -> 
             RGBColor[
              0.5860419411764706, 0.6465827941176471, 0.7150240294117647], 
             UndirectedEdge[191, 366] -> 
             RGBColor[
              0.672697294117647, 0.7437244705882353, 0.9683612352941176], 
             UndirectedEdge[185, 481] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[308, 389] -> 
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764705], 
             UndirectedEdge[96, 240] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[108, 113] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[85, 332] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[232, 280] -> 
             RGBColor[
              0.961070411764706, 0.8776436470588238, 0.31732720588235297`], 
             UndirectedEdge[310, 419] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[39, 378] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[53, 257] -> 
             RGBColor[0.8876065588235293, 0.651592823529412, 0.592535], 
             UndirectedEdge[248, 339] -> 
             RGBColor[0.7276598529411764, 0.5252499411764708, 0.577176], 
             UndirectedEdge[327, 334] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[165, 358] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[69, 204] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[208, 293] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[265, 320] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[239, 453] -> 
             RGBColor[
              0.8622419705882354, 0.7083068823529413, 0.6022973823529412], 
             UndirectedEdge[108, 452] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[331, 418] -> 
             RGBColor[
              0.9262902941176471, 0.7319879411764708, 0.2889406764705883], 
             UndirectedEdge[28, 201] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[431, 486] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[269, 419] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[315, 378] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[57, 240] -> 
             RGBColor[
              0.6781908823529412, 0.7413765882352942, 0.8957315588235295], 
             UndirectedEdge[7, 176] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[6, 302] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764708, 0.3716207352941176], 
             UndirectedEdge[176, 455] -> 
             RGBColor[
              0.7318321176470588, 0.7872340588235294, 0.8993163823529413], 
             UndirectedEdge[161, 396] -> 
             RGBColor[
              0.6781908823529412, 0.7413765882352942, 0.8957315588235295], 
             UndirectedEdge[36, 463] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[131, 373] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[54, 341] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[272, 453] -> 
             RGBColor[
              0.8937932352941177, 0.6088684705882357, 0.2330001176470589], 
             UndirectedEdge[169, 236] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705883], 
             UndirectedEdge[69, 101] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[286, 330] -> 
             RGBColor[
              0.8787623235294117, 0.781568705882353, 0.6159916764705883], 
             UndirectedEdge[86, 254] -> 
             RGBColor[
              0.8921979117647059, 0.5545467647058824, 0.5524162647058823], 
             UndirectedEdge[68, 319] -> 
             RGBColor[
              0.6077433529411764, 0.6872053529411765, 0.9649880588235293], 
             UndirectedEdge[37, 207] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529411], 
             UndirectedEdge[257, 317] -> 
             RGBColor[
              0.5584424117647059, 0.37937920588235313`, 0.5653549117647059], 
             UndirectedEdge[94, 158] -> 
             RGBColor[
              0.9352148823529411, 0.761689117647059, 0.35792644117647054`], 
             UndirectedEdge[253, 336] -> 
             RGBColor[
              0.9674696176470589, 0.908133823529412, 0.561427411764706], 
             UndirectedEdge[67, 363] -> 
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647], 
             UndirectedEdge[61, 295] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[16, 116] -> 
             RGBColor[
              0.3194197941176471, 0.4475569117647059, 0.9417033823529412], 
             UndirectedEdge[294, 439] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[69, 346] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[327, 415] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[54, 61] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[244, 262] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[295, 397] -> 
             RGBColor[0.8876065588235293, 0.651592823529412, 0.592535], 
             UndirectedEdge[61, 264] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[162, 226] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[237, 351] -> 
             RGBColor[
              0.6929358529411764, 0.6336244117647061, 0.5992756176470588], 
             UndirectedEdge[243, 273] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[53, 343] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[37, 445] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[144, 402] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[235, 456] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[369, 456] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[7, 61] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[76, 175] -> 
             RGBColor[
              0.8467659705882353, 0.6190276470588236, 0.5886395882352942], 
             UndirectedEdge[259, 372] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[187, 224] -> 
             RGBColor[
              0.7880378235294117, 0.8342091176470589, 0.9514881470588235], 
             UndirectedEdge[142, 183] -> 
             RGBColor[
              0.6072982647058824, 0.42522588235294134`, 0.568338705882353], 
             UndirectedEdge[255, 299] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[233, 444] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[148, 280] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[7, 376] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647057], 
             UndirectedEdge[73, 256] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[207, 403] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[233, 346] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[293, 403] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[321, 391] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[228, 298] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705883], 
             UndirectedEdge[54, 455] -> 
             RGBColor[
              0.7318321176470588, 0.7872340588235294, 0.8993163823529413], 
             UndirectedEdge[323, 419] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             UndirectedEdge[65, 194] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[40, 273] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[209, 400] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[31, 488] -> 
             RGBColor[
              0.5130690294117647, 0.5932005588235294, 0.9593949705882353], 
             UndirectedEdge[399, 407] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[292, 399] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[93, 218] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[198, 270] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882355], 
             UndirectedEdge[78, 192] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764708, 0.3716207352941176], 
             UndirectedEdge[286, 492] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[317, 343] -> 
             RGBColor[
              0.6188203823529412, 0.6883383823529412, 0.9396670588235294], 
             UndirectedEdge[51, 203] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[212, 216] -> 
             RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             UndirectedEdge[100, 257] -> 
             RGBColor[
              0.9108142941176471, 0.6427087058823532, 0.2752828823529412], 
             UndirectedEdge[189, 302] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[306, 382] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[20, 150] -> 
             RGBColor[
              0.7131589117647059, 0.41378935294117647`, 0.5632898823529411], 
             UndirectedEdge[255, 446] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[182, 237] -> 
             RGBColor[
              0.9103135882352942, 0.6821302941176475, 0.24669441176470597`], 
             UndirectedEdge[4, 366] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[231, 275] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[97, 231] -> 
             RGBColor[
              0.6485839411764706, 0.7197705294117647, 0.9688834705882352], 
             UndirectedEdge[114, 128] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[207, 471] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882355], 
             UndirectedEdge[54, 391] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[299, 478] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[44, 365] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[6, 101] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764708, 0.3716207352941176], 
             UndirectedEdge[236, 308] -> 
             RGBColor[
              0.7318321176470588, 0.7872340588235294, 0.8993163823529413], 
             UndirectedEdge[47, 256] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[304, 427] -> 
             RGBColor[
              0.9285733529411766, 0.7545241764705886, 0.26138664705882364`], 
             UndirectedEdge[54, 397] -> 
             RGBColor[0.9172135, 0.6731988823529413, 0.5193830882352942], 
             UndirectedEdge[220, 254] -> 
             RGBColor[
              0.8472959411764707, 0.33486682352941194`, 0.19176191176470592`],
              UndirectedEdge[377, 426] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[216, 292] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[42, 119] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[170, 491] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[257, 326] -> 
             RGBColor[
              0.7913583235294117, 0.5755227058823531, 0.5831754705882353], 
             UndirectedEdge[98, 347] -> 
             RGBColor[0.6764155, 0.5603625882352943, 0.5855813235294118], 
             UndirectedEdge[271, 311] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[156, 227] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[151, 160] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[93, 167] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             UndirectedEdge[275, 348] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[34, 394] -> 
             RGBColor[
              0.6717916764705882, 0.7108864117647059, 0.6516313529411765], 
             UndirectedEdge[405, 488] -> 
             RGBColor[
              0.5835165588235294, 0.6473717941176471, 0.8901384705882354], 
             UndirectedEdge[338, 443] -> 
             RGBColor[
              0.9352148823529411, 0.761689117647059, 0.35792644117647054`], 
             UndirectedEdge[301, 316] -> 
             RGBColor[
              0.5539096176470588, 0.6257657352941176, 0.9632903823529412], 
             UndirectedEdge[103, 209] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[126, 414] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[154, 341] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[306, 347] -> 
             RGBColor[
              0.7111956176470589, 0.7060182941176472, 0.6139678529411765], 
             UndirectedEdge[20, 388] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[286, 319] -> 
             RGBColor[
              0.8787623235294117, 0.781568705882353, 0.6159916764705883], 
             UndirectedEdge[62, 96] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[149, 242] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[212, 319] -> 
             RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             UndirectedEdge[289, 470] -> 
             RGBColor[
              0.9066988529411765, 0.6660073529411767, 0.5663023823529412], 
             UndirectedEdge[291, 353] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[21, 91] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.830958529411765], 
             UndirectedEdge[95, 224] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[218, 235] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[108, 315] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[61, 154] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[297, 413] -> 
             RGBColor[
              0.5130690294117647, 0.5932005588235294, 0.9593949705882353], 
             UndirectedEdge[294, 438] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[277, 386] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[125, 249] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[211, 308] -> 
             RGBColor[
              0.7111956176470589, 0.7060182941176472, 0.6139678529411765], 
             UndirectedEdge[273, 477] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[154, 397] -> 
             RGBColor[
              0.9108142941176471, 0.6427087058823532, 0.2752828823529412], 
             UndirectedEdge[105, 230] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[355, 404] -> 
             RGBColor[
              0.5739184117647058, 0.46865844117647076`, 0.579012705882353], 
             UndirectedEdge[250, 263] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[11, 259] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529414, 0.6198870882352941], 
             UndirectedEdge[339, 439] -> 
             RGBColor[0.8876065588235293, 0.651592823529412, 0.592535], 
             UndirectedEdge[303, 379] -> 
             RGBColor[
              0.9361957058823529, 0.7637870000000002, 0.464683029411765], 
             UndirectedEdge[416, 468] -> 
             RGBColor[
              0.5771173529411765, 0.6168816176470588, 0.6460382647058824], 
             UndirectedEdge[77, 336] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[297, 412] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[69, 418] -> 
             RGBColor[
              0.9361957058823529, 0.7637870000000002, 0.464683029411765], 
             UndirectedEdge[281, 322] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[51, 495] -> 
             RGBColor[
              0.7281049411764706, 0.7872294117647058, 0.9738253529411764], 
             UndirectedEdge[227, 229] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[192, 497] -> 
             RGBColor[
              0.9103135882352942, 0.6821302941176475, 0.24669441176470597`], 
             UndirectedEdge[143, 277] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[87, 161] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[114, 255] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[341, 391] -> 
             RGBColor[
              0.7918034117647059, 0.8375021764705881, 0.9798248235294118], 
             UndirectedEdge[35, 347] -> 
             RGBColor[
              0.7254329117647058, 0.7567438823529412, 0.6552161764705883], 
             UndirectedEdge[99, 498] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[89, 448] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[130, 371] -> 
             RGBColor[
              0.7254329117647058, 0.7567438823529412, 0.6552161764705883], 
             UndirectedEdge[187, 481] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[427, 500] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.6083467058823531], 
             UndirectedEdge[134, 247] -> 
             RGBColor[
              0.6781908823529412, 0.7413765882352942, 0.8957315588235295], 
             UndirectedEdge[79, 301] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[173, 323] -> 
             RGBColor[
              0.5860419411764706, 0.6465827941176472, 0.7150240294117647], 
             UndirectedEdge[84, 262] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529414, 0.6198870882352941], 
             UndirectedEdge[262, 391] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[205, 382] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[50, 499] -> 
             RGBColor[
              0.3194197941176471, 0.4475569117647059, 0.9417033823529412], 
             UndirectedEdge[108, 380] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[300, 493] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[331, 382] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[186, 495] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[93, 235] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[18, 300] -> 
             RGBColor[
              0.7918034117647059, 0.8375021764705881, 0.9798248235294118], 
             UndirectedEdge[223, 246] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[233, 431] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[182, 351] -> 
             RGBColor[
              0.6929358529411764, 0.6336244117647061, 0.5992756176470588], 
             UndirectedEdge[163, 209] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[70, 182] -> 
             RGBColor[
              0.938695205882353, 0.8285484117647062, 0.5936544705882354], 
             UndirectedEdge[59, 335] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882355], 
             UndirectedEdge[258, 453] -> 
             RGBColor[
              0.9262902941176471, 0.7319879411764708, 0.2889406764705883], 
             UndirectedEdge[161, 354] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[213, 489] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[260, 407] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[95, 185] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[117, 479] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[164, 444] -> 
             RGBColor[
              0.5523357058823529, 0.6437004117647058, 0.9595239411764706], 
             UndirectedEdge[32, 334] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[46, 325] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705883], 
             UndirectedEdge[18, 201] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882355], 
             UndirectedEdge[328, 398] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[376, 448] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             UndirectedEdge[326, 355] -> 
             RGBColor[
              0.5034798529411765, 0.5978537352941176, 0.9565401470588235], 
             UndirectedEdge[257, 281] -> 
             RGBColor[
              0.8467659705882353, 0.6190276470588236, 0.5886395882352942], 
             UndirectedEdge[32, 89] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[341, 397] -> 
             RGBColor[
              0.8467659705882353, 0.6190276470588236, 0.5886395882352942], 
             UndirectedEdge[160, 274] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             UndirectedEdge[151, 235] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[11, 372] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[99, 295] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[154, 199] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[169, 308] -> 
             RGBColor[
              0.6929358529411764, 0.6336244117647061, 0.5992756176470588], 
             UndirectedEdge[158, 410] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[311, 465] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.608346705882353], 
             UndirectedEdge[139, 428] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705883], 
             UndirectedEdge[113, 364] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[89, 475] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[375, 441] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             UndirectedEdge[244, 295] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[187, 260] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[207, 322] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529411], 
             UndirectedEdge[100, 457] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[364, 416] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[313, 386] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[31, 472] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[37, 49] -> 
             RGBColor[
              0.6318604117647059, 0.6947409117647059, 0.7176333235294117], 
             UndirectedEdge[201, 406] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[245, 376] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[58, 215] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647057], 
             UndirectedEdge[84, 407] -> 
             RGBColor[
              0.8787623235294117, 0.781568705882353, 0.6159916764705883], 
             UndirectedEdge[100, 324] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[89, 176] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[75, 379] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[123, 422] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[407, 455] -> 
             RGBColor[
              0.6613845882352941, 0.7330628235294117, 0.9685728823529411], 
             UndirectedEdge[333, 358] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[120, 124] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[88, 433] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[345, 456] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[392, 474] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[165, 333] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529411], 
             UndirectedEdge[31, 133] -> 
             RGBColor[
              0.8970220882352942, 0.8539625882352943, 0.630683911764706], 
             UndirectedEdge[171, 208] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[284, 472] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[196, 427] -> 
             RGBColor[
              0.9468331176470589, 0.8269180588235298, 0.27607888235294126`], 
             UndirectedEdge[179, 334] -> 
             RGBColor[
              0.6781908823529412, 0.7413765882352942, 0.8957315588235295], 
             UndirectedEdge[97, 233] -> 
             RGBColor[
              0.6717916764705882, 0.7108864117647059, 0.6516313529411765], 
             UndirectedEdge[21, 409] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[63, 344] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[292, 398] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[71, 197] -> 
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647], 
             UndirectedEdge[81, 121] -> 
             RGBColor[
              0.5997280882352941, 0.6739238529411764, 0.9658996764705883], 
             UndirectedEdge[163, 317] -> 
             RGBColor[0.5588875, 0.6413586764705882, 0.9620042647058824], 
             UndirectedEdge[167, 172] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[191, 488] -> 
             RGBColor[
              0.4576613823529412, 0.5496956176470588, 0.9539308529411765], 
             UndirectedEdge[392, 490] -> 
             RGBColor[
              0.6613845882352941, 0.7330628235294117, 0.9685728823529411], 
             UndirectedEdge[251, 272] -> 
             RGBColor[
              0.9527160588235295, 0.837048823529412, 0.47837732352941204`], 
             UndirectedEdge[66, 255] -> 
             RGBColor[0.9326895, 0.762478117647059, 0.5330408823529413], 
             UndirectedEdge[177, 194] -> 
             RGBColor[
              0.6807162647058824, 0.7405875882352941, 0.7206171176470587], 
             UndirectedEdge[36, 359] -> 
             RGBColor[
              0.5870227647058823, 0.6486806764705882, 0.821780617647059], 
             UndirectedEdge[46, 377] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[6, 306] -> 
             RGBColor[
              0.9285733529411766, 0.7545241764705886, 0.26138664705882364`], 
             UndirectedEdge[7, 455] -> 
             RGBColor[
              0.5422784705882352, 0.6392851176470589, 0.9571092941176471], 
             UndirectedEdge[84, 482] -> 
             RGBColor[
              0.9527160588235295, 0.837048823529412, 0.47837732352941204`], 
             UndirectedEdge[83, 97] -> 
             RGBColor[
              0.5523357058823529, 0.6437004117647058, 0.9595239411764706], 
             UndirectedEdge[125, 408] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[184, 473] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[410, 422] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[202, 283] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[320, 329] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[146, 387] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[107, 170] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[273, 459] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[5, 395] -> 
             RGBColor[
              0.6781908823529412, 0.7413765882352942, 0.8957315588235295], 
             UndirectedEdge[104, 242] -> 
             RGBColor[
              0.9030825588235294, 0.7408720588235296, 0.606192794117647], 
             UndirectedEdge[422, 437] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[29, 177] -> 
             RGBColor[
              0.6676762352941177, 0.7341850588235295, 0.9426508529411765], 
             UndirectedEdge[202, 285] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.608346705882353], 
             UndirectedEdge[182, 460] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[116, 333] -> 
             RGBColor[
              0.6807162647058824, 0.7405875882352941, 0.7206171176470587], 
             UndirectedEdge[405, 472] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[51, 96] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[115, 402] -> 
             RGBColor[
              0.7918034117647059, 0.8375021764705881, 0.9798248235294118], 
             UndirectedEdge[67, 120] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[72, 222] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[84, 328] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[123, 401] -> 
             RGBColor[
              0.961070411764706, 0.8776436470588238, 0.31732720588235297`], 
             UndirectedEdge[143, 178] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[2, 385] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[113, 487] -> 
             RGBColor[
              0.6485839411764706, 0.7197705294117647, 0.9688834705882352], 
             UndirectedEdge[12, 430] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[72, 344] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[127, 221] -> 
             RGBColor[
              0.6816970882352942, 0.7426854705882353, 0.8273737058823531], 
             UndirectedEdge[466, 491] -> 
             RGBColor[
              0.9468331176470589, 0.8269180588235298, 0.27607888235294126`], 
             UndirectedEdge[236, 289] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[200, 298] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[231, 431] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[171, 238] -> 
             RGBColor[
              0.9674696176470589, 0.908133823529412, 0.561427411764706], 
             UndirectedEdge[276, 306] -> 
             RGBColor[
              0.7779159705882353, 0.7601848823529413, 0.6192203235294118], 
             UndirectedEdge[294, 296] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[1, 119] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[103, 444] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[331, 486] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[100, 281] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[161, 477] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[391, 475] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[2, 312] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[264, 341] -> 
             RGBColor[
              0.7281049411764706, 0.7872294117647058, 0.9738253529411764], 
             UndirectedEdge[73, 434] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[241, 271] -> 
             RGBColor[
              0.6781908823529412, 0.7413765882352942, 0.8957315588235295], 
             UndirectedEdge[49, 51] -> 
             RGBColor[
              0.4397813823529412, 0.5475809705882353, 0.9505406764705882], 
             UndirectedEdge[5, 275] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[18, 274] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529411], 
             UndirectedEdge[219, 445] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[177, 297] -> 
             RGBColor[
              0.6077433529411764, 0.6872053529411765, 0.9649880588235293], 
             UndirectedEdge[250, 365] -> 
             RGBColor[
              0.7880378235294117, 0.8342091176470589, 0.9514881470588235], 
             UndirectedEdge[325, 474] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[266, 403] -> 
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647], 
             UndirectedEdge[214, 470] -> 
             RGBColor[
              0.9066988529411765, 0.6660073529411767, 0.5663023823529412], 
             UndirectedEdge[152, 481] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[289, 466] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.608346705882353], 
             UndirectedEdge[126, 269] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[183, 396] -> 
             RGBColor[
              0.36827564705882354`, 0.4934035882352941, 0.9446871764705882], 
             UndirectedEdge[54, 99] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[129, 306] -> 
             RGBColor[
              0.5628800588235294, 0.5661560294117649, 0.6047899411764707], 
             UndirectedEdge[172, 236] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[162, 284] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[10, 189] -> 
             RGBColor[
              0.7918034117647059, 0.8375021764705881, 0.9798248235294118], 
             UndirectedEdge[213, 332] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[199, 245] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[123, 139] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[391, 482] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882355], 
             UndirectedEdge[184, 354] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[25, 316] -> 
             RGBColor[
              0.4576613823529412, 0.5496956176470588, 0.9539308529411765], 
             UndirectedEdge[106, 479] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[118, 260] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[304, 469] -> 
             RGBColor[
              0.8233546764705882, 0.7380637647058825, 0.6105275588235295], 
             UndirectedEdge[93, 236] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[343, 445] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[204, 444] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529411], 
             UndirectedEdge[150, 412] -> 
             RGBColor[
              0.8921979117647059, 0.5545467647058824, 0.5524162647058823], 
             UndirectedEdge[14, 239] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[70, 442] -> 
             RGBColor[
              0.9221748529411764, 0.7552865882352944, 0.5799601764705883], 
             UndirectedEdge[93, 493] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[228, 279] -> 
             RGBColor[
              0.7596562058823529, 0.6877910000000003, 0.6045280882352941], 
             UndirectedEdge[300, 456] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[168, 326] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[193, 437] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[224, 361] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[12, 477] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[212, 224] -> 
             RGBColor[
              0.7281049411764706, 0.7872294117647058, 0.9738253529411764], 
             UndirectedEdge[220, 490] -> 
             RGBColor[0.6764155, 0.5603625882352943, 0.5855813235294118], 
             UndirectedEdge[175, 208] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[242, 419] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[164, 205] -> 
             RGBColor[
              0.4886372352941176, 0.5934276470588236, 0.9535244705882353], 
             UndirectedEdge[257, 322] -> 
             RGBColor[
              0.9197388823529412, 0.6724098823529414, 0.34426864705882343`], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[26, 67] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058825, 0.6345793235294117], 
             UndirectedEdge[366, 488] -> 
             RGBColor[
              0.3939629117647059, 0.4994228529411765, 0.9479313823529412], 
             UndirectedEdge[12, 243] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[271, 307] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[9, 352] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[404, 431] -> 
             RGBColor[
              0.9352148823529411, 0.761689117647059, 0.35792644117647054`], 
             UndirectedEdge[256, 287] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[254, 412] -> 
             RGBColor[
              0.8921979117647059, 0.5545467647058824, 0.5524162647058823], 
             UndirectedEdge[42, 380] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[379, 404] -> 
             RGBColor[
              0.9361957058823529, 0.7637870000000002, 0.464683029411765], 
             UndirectedEdge[134, 424] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[38, 253] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[103, 348] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[42, 452] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[164, 331] -> 
             RGBColor[
              0.6717916764705882, 0.7108864117647059, 0.6516313529411765], 
             UndirectedEdge[6, 181] -> 
             RGBColor[
              0.9527160588235295, 0.837048823529412, 0.47837732352941204`], 
             UndirectedEdge[172, 197] -> 
             RGBColor[
              0.7318321176470588, 0.7872340588235294, 0.8993163823529413], 
             UndirectedEdge[80, 258] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[223, 268] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[5, 69] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[306, 486] -> 
             RGBColor[
              0.9674696176470589, 0.908133823529412, 0.561427411764706], 
             UndirectedEdge[5, 348] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[279, 409] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[463, 483] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[351, 371] -> 
             RGBColor[
              0.47555811764705874`, 0.5851185294117647, 0.9518568235294118], 
             UndirectedEdge[335, 421] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882355], 
             UndirectedEdge[259, 418] -> 
             RGBColor[
              0.8937932352941177, 0.6088684705882357, 0.2330001176470589], 
             UndirectedEdge[168, 302] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[87, 336] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[36, 266] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.830958529411765], 
             UndirectedEdge[161, 430] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[220, 412] -> 
             RGBColor[
              0.9221748529411764, 0.7552865882352944, 0.5799601764705883], 
             UndirectedEdge[372, 404] -> 
             RGBColor[
              0.9262902941176471, 0.7319879411764708, 0.2889406764705883], 
             UndirectedEdge[38, 287] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[171, 497] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705883], 
             UndirectedEdge[246, 411] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[75, 303] -> 
             RGBColor[
              0.9262902941176471, 0.7319879411764708, 0.2889406764705883], 
             UndirectedEdge[23, 39] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[61, 391] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[19, 200] -> 
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764705], 
             UndirectedEdge[208, 403] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[108, 378] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[10, 451] -> 
             RGBColor[
              0.4576613823529412, 0.5496956176470588, 0.9539308529411765], 
             UndirectedEdge[199, 262] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[3, 401] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.608346705882353], 
             UndirectedEdge[241, 311] -> 
             RGBColor[
              0.6676762352941177, 0.7341850588235295, 0.9426508529411765], 
             UndirectedEdge[179, 255] -> 
             RGBColor[
              0.6781908823529412, 0.7413765882352942, 0.8957315588235295], 
             UndirectedEdge[276, 462] -> 
             RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             UndirectedEdge[167, 289] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[164, 348] -> 
             RGBColor[
              0.6816970882352942, 0.7426854705882353, 0.8273737058823531], 
             UndirectedEdge[18, 172] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[289, 300] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[59, 188] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[352, 357] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[161, 409] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[39, 157] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[216, 398] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[279, 396] -> 
             RGBColor[
              0.4886372352941176, 0.5934276470588236, 0.9535244705882353], 
             UndirectedEdge[103, 390] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[128, 296] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882355], 
             UndirectedEdge[362, 369] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[86, 412] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[261, 299] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[208, 266] -> 
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764705], 
             UndirectedEdge[211, 236] -> 
             RGBColor[
              0.9674696176470589, 0.908133823529412, 0.561427411764706], 
             UndirectedEdge[19, 124] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.830958529411765], 
             UndirectedEdge[319, 330] -> 
             RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             UndirectedEdge[137, 267] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529414, 0.6198870882352941], 
             UndirectedEdge[23, 240] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[135, 369] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[13, 335] -> 
             RGBColor[
              0.8416144411764706, 0.8104576470588236, 0.6252197941176472], 
             UndirectedEdge[176, 178] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[335, 459] -> 
             RGBColor[
              0.8416144411764706, 0.8104576470588236, 0.625219794117647], 
             UndirectedEdge[83, 326] -> 
             RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 
             UndirectedEdge[33, 76] -> 
             RGBColor[0.9172135, 0.6731988823529413, 0.5193830882352942], 
             UndirectedEdge[13, 285] -> 
             RGBColor[
              0.9468331176470589, 0.8269180588235298, 0.27607888235294126`], 
             UndirectedEdge[225, 309] -> 
             RGBColor[
              0.920719705882353, 0.6745077647058826, 0.4510252352941179], 
             UndirectedEdge[242, 499] -> 
             RGBColor[
              0.6485839411764706, 0.7197705294117647, 0.9688834705882352], 
             UndirectedEdge[13, 287] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.6083467058823531], 
             UndirectedEdge[265, 270] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[191, 311] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[47, 452] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[14, 80] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[152, 292] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[133, 311] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.6083467058823531], 
             UndirectedEdge[187, 398] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[130, 442] -> 
             RGBColor[
              0.9262902941176471, 0.7319879411764708, 0.2889406764705883], 
             UndirectedEdge[304, 433] -> 
             RGBColor[
              0.9527160588235295, 0.837048823529412, 0.47837732352941204`], 
             UndirectedEdge[354, 409] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[29, 412] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[295, 391] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[21, 298] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[383, 395] -> 
             RGBColor[
              0.6485839411764706, 0.7197705294117647, 0.9688834705882352], 
             UndirectedEdge[133, 241] -> 
             RGBColor[
              0.6575543823529413, 0.660160823529412, 0.6103830294117647], 
             UndirectedEdge[142, 473] -> 
             RGBColor[
              0.8965770000000001, 0.5919831176470591, 0.23403455882352947`], 
             UndirectedEdge[95, 330] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[275, 431] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             UndirectedEdge[180, 474] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[82, 173] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[205, 230] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[460, 463] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[121, 500] -> 
             RGBColor[
              0.6188203823529412, 0.6883383823529412, 0.9396670588235294], 
             UndirectedEdge[88, 241] -> 
             RGBColor[
              0.6676762352941177, 0.7341850588235295, 0.9426508529411765], 
             UndirectedEdge[60, 73] -> 
             RGBColor[
              0.631860411764706, 0.6947409117647059, 0.7176333235294117], 
             UndirectedEdge[75, 400] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[141, 274] -> 
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352], 
             UndirectedEdge[299, 448] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[160, 389] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             UndirectedEdge[24, 268] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.6083467058823531], 
             UndirectedEdge[386, 498] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[350, 476] -> 
             RGBColor[
              0.920719705882353, 0.6745077647058826, 0.4510252352941179], 
             UndirectedEdge[180, 331] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[225, 252] -> 
             RGBColor[
              0.8467659705882353, 0.6190276470588236, 0.5886395882352942], 
             UndirectedEdge[100, 203] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[445, 471] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[373, 498] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.608346705882353], 
             UndirectedEdge[102, 309] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[46, 86] -> 
             RGBColor[
              0.938695205882353, 0.8285484117647062, 0.5936544705882354], 
             UndirectedEdge[294, 385] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[27, 29] -> 
             RGBColor[
              0.7213174705882353, 0.7800425294117648, 0.9462356764705883], 
             UndirectedEdge[274, 284] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[284, 300] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[159, 453] -> 
             RGBColor[0.6764155, 0.5603625882352943, 0.5855813235294118], 
             UndirectedEdge[229, 232] -> 
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352], 
             UndirectedEdge[259, 431] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764708, 0.3716207352941176], 
             UndirectedEdge[112, 483] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[78, 376] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             UndirectedEdge[76, 351] -> 
             RGBColor[0.6609395, 0.47108335294117665`, 0.5719235294117648], 
             UndirectedEdge[178, 498] -> 
             RGBColor[
              0.961070411764706, 0.8776436470588238, 0.31732720588235297`], 
             UndirectedEdge[400, 431] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[18, 432] -> 
             RGBColor[
              0.7913583235294117, 0.5755227058823531, 0.5831754705882353], 
             UndirectedEdge[220, 325] -> 
             RGBColor[0.9326895, 0.762478117647059, 0.5330408823529413], 
             UndirectedEdge[353, 380] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[5, 355] -> 
             RGBColor[
              0.6293350294117647, 0.6955299117647059, 0.8927477647058825], 
             UndirectedEdge[367, 441] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[21, 287] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[175, 182] -> 
             RGBColor[
              0.8787623235294117, 0.781568705882353, 0.6159916764705883], 
             UndirectedEdge[70, 371] -> 
             RGBColor[
              0.7213174705882353, 0.7800425294117648, 0.9462356764705883], 
             UndirectedEdge[217, 496] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[195, 292] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[161, 285] -> 
             RGBColor[
              0.9674696176470589, 0.908133823529412, 0.561427411764706], 
             UndirectedEdge[168, 370] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[50, 173] -> 
             RGBColor[
              0.2247454705882353, 0.35355211764705885`, 0.9361102941176471], 
             UndirectedEdge[19, 188] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.830958529411765], 
             UndirectedEdge[147, 323] -> 
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764705], 
             UndirectedEdge[255, 260] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[29, 350] -> 
             RGBColor[
              0.9066988529411765, 0.6660073529411767, 0.5663023823529412], 
             UndirectedEdge[348, 400] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[26, 124] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[18, 93] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529411], 
             UndirectedEdge[64, 223] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             UndirectedEdge[12, 335] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[143, 498] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.608346705882353], 
             UndirectedEdge[44, 92] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[274, 389] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             UndirectedEdge[247, 401] -> 
             RGBColor[
              0.6575543823529413, 0.660160823529412, 0.6103830294117647], 
             UndirectedEdge[111, 182] -> 
             RGBColor[
              0.938695205882353, 0.8285484117647062, 0.5936544705882354], 
             UndirectedEdge[157, 190] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[100, 360] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[59, 468] -> 
             RGBColor[
              0.5870227647058823, 0.6486806764705882, 0.821780617647059], 
             UndirectedEdge[101, 129] -> 
             RGBColor[
              0.5860419411764706, 0.6465827941176471, 0.7150240294117647], 
             UndirectedEdge[180, 382] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[145, 402] -> 
             RGBColor[
              0.8233546764705882, 0.7380637647058825, 0.6105275588235295], 
             UndirectedEdge[90, 263] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[98, 276] -> 
             RGBColor[
              0.7431358529411765, 0.6145291764705885, 0.590833794117647], 
             UndirectedEdge[224, 464] -> 
             RGBColor[
              0.672697294117647, 0.7437244705882353, 0.9683612352941176], 
             UndirectedEdge[261, 313] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[78, 219] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[393, 424] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[169, 211] -> 
             RGBColor[
              0.9285733529411766, 0.7545241764705886, 0.26138664705882364`], 
             UndirectedEdge[176, 482] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[35, 94] -> 
             RGBColor[
              0.9262902941176471, 0.7319879411764708, 0.2889406764705883], 
             UndirectedEdge[114, 296] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[130, 175] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[189, 383] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[139, 437] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529414, 0.6198870882352941], 
             UndirectedEdge[56, 324] -> 
             RGBColor[
              0.7918034117647059, 0.8375021764705881, 0.9798248235294118], 
             UndirectedEdge[398, 399] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[405, 429] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[12, 318] -> 
             RGBColor[
              0.6717916764705882, 0.7108864117647059, 0.6516313529411765], 
             UndirectedEdge[11, 205] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[226, 389] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[294, 327] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[167, 218] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[217, 481] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[247, 309] -> 
             RGBColor[
              0.6816970882352942, 0.7426854705882353, 0.8273737058823531], 
             UndirectedEdge[79, 234] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[331, 372] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[27, 484] -> 
             RGBColor[
              0.7111956176470589, 0.7060182941176472, 0.6139678529411765], 
             UndirectedEdge[103, 326] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[155, 394] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[433, 469] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882355], 
             UndirectedEdge[65, 412] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[13, 161] -> 
             RGBColor[
              0.9674696176470589, 0.908133823529412, 0.561427411764706], 
             UndirectedEdge[229, 480] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764708, 0.3716207352941176], 
             UndirectedEdge[32, 448] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[251, 453] -> 
             RGBColor[
              0.9361957058823529, 0.7637870000000002, 0.464683029411765], 
             UndirectedEdge[282, 310] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[392, 473] -> 
             RGBColor[
              0.8970220882352942, 0.8539625882352943, 0.630683911764706], 
             UndirectedEdge[222, 344] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[266, 440] -> 
             RGBColor[
              0.6613845882352941, 0.7330628235294117, 0.9685728823529411], 
             UndirectedEdge[16, 361] -> 
             RGBColor[
              0.6328412352941177, 0.696838794117647, 0.8243899117647061], 
             UndirectedEdge[412, 426] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[274, 460] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[180, 230] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[375, 450] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647057], 
             UndirectedEdge[6, 123] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[170, 466] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[267, 280] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[52, 214] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[358, 386] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[230, 413] -> 
             RGBColor[
              0.5771173529411765, 0.6168816176470588, 0.6460382647058824], 
             UndirectedEdge[53, 207] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[188, 256] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[38, 87] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[22, 52] -> 
             RGBColor[
              0.6676762352941177, 0.7341850588235295, 0.9426508529411765], 
             UndirectedEdge[160, 460] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[63, 159] -> 
             RGBColor[
              0.7318321176470588, 0.7872340588235294, 0.8993163823529413], 
             UndirectedEdge[285, 430] -> 
             RGBColor[
              0.961070411764706, 0.8776436470588238, 0.31732720588235297`], 
             UndirectedEdge[132, 356] -> 
             RGBColor[
              0.6929358529411764, 0.6336244117647061, 0.5992756176470588], 
             UndirectedEdge[99, 373] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[243, 396] -> 
             RGBColor[
              0.6717916764705882, 0.7108864117647059, 0.6516313529411765], 
             UndirectedEdge[118, 292] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[84, 176] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705883], 
             UndirectedEdge[334, 385] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[25, 325] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[321, 397] -> 
             RGBColor[0.9172135, 0.6731988823529413, 0.5193830882352942], 
             UndirectedEdge[201, 235] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[321, 498] -> 
             RGBColor[
              0.9674696176470589, 0.908133823529412, 0.561427411764706], 
             UndirectedEdge[368, 492] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[239, 387] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[196, 500] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.6083467058823531], 
             UndirectedEdge[122, 185] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[350, 377] -> 
             RGBColor[
              0.9108142941176471, 0.6427087058823532, 0.2752828823529412], 
             UndirectedEdge[315, 353] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[102, 480] -> 
             RGBColor[
              0.938695205882353, 0.8285484117647062, 0.5936544705882354], 
             UndirectedEdge[127, 253] -> 
             RGBColor[
              0.6575543823529413, 0.660160823529412, 0.6103830294117647], 
             UndirectedEdge[159, 192] -> 
             RGBColor[
              0.6929358529411764, 0.6336244117647061, 0.5992756176470588], 
             UndirectedEdge[201, 289] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[29, 194] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[79, 388] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[246, 402] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[185, 398] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[133, 304] -> 
             RGBColor[
              0.9285733529411766, 0.7545241764705886, 0.26138664705882364`], 
             UndirectedEdge[107, 314] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[13, 279] -> 
             RGBColor[
              0.7779159705882353, 0.7601848823529413, 0.6192203235294118], 
             UndirectedEdge[180, 418] -> 
             RGBColor[
              0.8622419705882354, 0.7083068823529413, 0.6022973823529412], 
             UndirectedEdge[112, 207] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882355], 
             UndirectedEdge[308, 369] -> 
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647], 
             UndirectedEdge[45, 292] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[348, 418] -> 
             RGBColor[
              0.9361957058823529, 0.7637870000000002, 0.464683029411765], 
             UndirectedEdge[51, 264] -> 
             RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             UndirectedEdge[201, 218] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[262, 376] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[304, 307] -> 
             RGBColor[
              0.8787623235294117, 0.781568705882353, 0.6159916764705883], 
             UndirectedEdge[8, 166] -> 
             RGBColor[
              0.5523357058823529, 0.6437004117647058, 0.9595239411764706], 
             UndirectedEdge[66, 312] -> 
             RGBColor[
              0.8622419705882354, 0.7083068823529413, 0.6022973823529412], 
             UndirectedEdge[202, 430] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[348, 404] -> 
             RGBColor[
              0.9361957058823529, 0.7637870000000002, 0.464683029411765], 
             UndirectedEdge[1, 113] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[29, 377] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[259, 404] -> 
             RGBColor[
              0.8937932352941177, 0.6088684705882357, 0.2330001176470589], 
             UndirectedEdge[131, 449] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[423, 465] -> 
             RGBColor[
              0.9674696176470589, 0.908133823529412, 0.561427411764706], 
             UndirectedEdge[177, 412] -> 
             RGBColor[
              0.6676762352941177, 0.7341850588235295, 0.9426508529411765], 
             UndirectedEdge[139, 158] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764708, 0.3716207352941176], 
             UndirectedEdge[454, 500] -> 
             RGBColor[
              0.6188203823529412, 0.6883383823529412, 0.9396670588235294], 
             UndirectedEdge[430, 459] -> 
             RGBColor[
              0.961070411764706, 0.8776436470588238, 0.31732720588235297`], 
             UndirectedEdge[474, 490] -> 
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764705], 
             UndirectedEdge[443, 451] -> 
             RGBColor[
              0.5860419411764706, 0.6465827941176471, 0.7150240294117647], 
             UndirectedEdge[182, 483] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529414, 0.6198870882352941], 
             UndirectedEdge[92, 457] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[38, 184] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[51, 457] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647057], 
             UndirectedEdge[321, 455] -> 
             RGBColor[
              0.7318321176470588, 0.7872340588235294, 0.8993163823529413], 
             UndirectedEdge[251, 435] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[16, 441] -> 
             RGBColor[
              0.631860411764706, 0.6947409117647059, 0.7176333235294117], 
             UndirectedEdge[302, 390] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[186, 455] -> 
             RGBColor[
              0.7213174705882353, 0.7800425294117648, 0.9462356764705883], 
             UndirectedEdge[349, 353] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[125, 406] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[307, 433] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[406, 419] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[237, 274] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764708, 0.3716207352941176], 
             UndirectedEdge[203, 264] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[69, 231] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[328, 399] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[78, 262] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[27, 412] -> 
             RGBColor[
              0.7213174705882353, 0.7800425294117648, 0.9462356764705883], 
             UndirectedEdge[147, 221] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.830958529411765], 
             UndirectedEdge[93, 289] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[141, 235] -> 
             RGBColor[
              0.9674696176470589, 0.908133823529412, 0.561427411764706], 
             UndirectedEdge[185, 464] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882355], 
             UndirectedEdge[6, 189] -> 
             RGBColor[
              0.8787623235294117, 0.781568705882353, 0.6159916764705883], 
             UndirectedEdge[38, 316] -> 
             RGBColor[
              0.5870227647058823, 0.6486806764705882, 0.821780617647059], 
             UndirectedEdge[322, 343] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[93, 141] -> 
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352], 
             UndirectedEdge[191, 237] -> 
             RGBColor[
              0.8233546764705882, 0.7380637647058825, 0.6105275588235295], 
             UndirectedEdge[145, 461] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705883], 
             UndirectedEdge[420, 500] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[402, 458] -> 
             RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 
             UndirectedEdge[148, 263] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[126, 499] -> 
             RGBColor[
              0.6781908823529412, 0.7413765882352942, 0.8957315588235295], 
             UndirectedEdge[133, 371] -> 
             RGBColor[
              0.7111956176470589, 0.7060182941176472, 0.6139678529411765], 
             UndirectedEdge[72, 245] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[57, 131] -> 
             RGBColor[
              0.6816970882352942, 0.7426854705882353, 0.8273737058823531], 
             UndirectedEdge[15, 173] -> 
             RGBColor[
              0.5280999411764706, 0.4205003235294119, 0.5764034117647059], 
             UndirectedEdge[138, 415] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[105, 109] -> 
             RGBColor[
              0.8233546764705882, 0.7380637647058825, 0.6105275588235295], 
             UndirectedEdge[235, 284] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[150, 473] -> 
             RGBColor[
              0.8820760588235295, 0.4805225294117649, 0.22014844117647064`], 
             UndirectedEdge[74, 417] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529414, 0.6198870882352941], 
             UndirectedEdge[20, 413] -> 
             RGBColor[
              0.3939629117647059, 0.4994228529411765, 0.9479313823529412], 
             UndirectedEdge[34, 467] -> 
             RGBColor[
              0.6575543823529413, 0.660160823529412, 0.6103830294117647], 
             UndirectedEdge[62, 110] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[93, 389] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             UndirectedEdge[28, 408] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[93, 284] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[143, 313] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[361, 398] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[105, 382] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882355], 
             UndirectedEdge[240, 495] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[13, 21] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[32, 179] -> 
             RGBColor[
              0.6485839411764706, 0.7197705294117647, 0.9688834705882352], 
             UndirectedEdge[38, 79] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[328, 407] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[357, 367] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[196, 213] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058825, 0.6345793235294117], 
             UndirectedEdge[233, 326] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[164, 372] -> 
             RGBColor[
              0.6717916764705882, 0.7108864117647059, 0.6516313529411765], 
             UndirectedEdge[3, 278] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.608346705882353], 
             UndirectedEdge[195, 399] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[118, 187] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[61, 178] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[2, 496] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[103, 404] -> 
             RGBColor[0.9326895, 0.762478117647059, 0.5330408823529413], 
             UndirectedEdge[37, 374] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764708, 0.3716207352941176], 
             UndirectedEdge[236, 466] -> 
             RGBColor[
              0.9674696176470589, 0.908133823529412, 0.561427411764706], 
             UndirectedEdge[150, 254] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[148, 229] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647057], 
             UndirectedEdge[160, 432] -> 
             RGBColor[
              0.9197388823529412, 0.6724098823529414, 0.34426864705882343`], 
             UndirectedEdge[48, 198] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[89, 178] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[63, 239] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[425, 462] -> 
             RGBColor[
              0.7880378235294117, 0.8342091176470589, 0.9514881470588235], 
             UndirectedEdge[44, 457] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[46, 254] -> 
             RGBColor[
              0.863816294117647, 0.40812864705882373`, 0.20545620588235297`], 
             UndirectedEdge[1, 452] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[260, 299] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[321, 341] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[249, 406] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[398, 496] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[382, 462] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[63, 272] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705883], 
             UndirectedEdge[117, 270] -> 
             RGBColor[
              0.7918034117647059, 0.8375021764705881, 0.9798248235294118], 
             UndirectedEdge[164, 404] -> 
             RGBColor[0.6227742647058824, 0.514505117647059, 0.5819965], 
             UndirectedEdge[133, 191] -> 
             RGBColor[
              0.8416144411764706, 0.8104576470588236, 0.6252197941176472], 
             UndirectedEdge[307, 469] -> 
             RGBColor[
              0.7918034117647059, 0.8375021764705881, 0.9798248235294118], 
             UndirectedEdge[31, 237] -> 
             RGBColor[
              0.8787623235294117, 0.781568705882353, 0.6159916764705883], 
             UndirectedEdge[1, 468] -> 
             RGBColor[
              0.5771173529411765, 0.6168816176470588, 0.6460382647058824], 
             UndirectedEdge[346, 395] -> 
             RGBColor[
              0.6676762352941177, 0.7341850588235295, 0.9426508529411765], 
             UndirectedEdge[214, 223] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[264, 397] -> 
             RGBColor[0.7276598529411764, 0.5252499411764708, 0.577176], 
             UndirectedEdge[103, 204] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[110, 356] -> 
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764705], 
             UndirectedEdge[184, 253] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[115, 417] -> 
             RGBColor[
              0.8787623235294117, 0.781568705882353, 0.6159916764705883], 
             UndirectedEdge[243, 459] -> 
             RGBColor[
              0.961070411764706, 0.8776436470588238, 0.31732720588235297`], 
             UndirectedEdge[190, 349] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[128, 222] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[204, 275] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             UndirectedEdge[178, 455] -> 
             RGBColor[
              0.7254329117647058, 0.7567438823529412, 0.6552161764705883], 
             UndirectedEdge[84, 391] -> 
             RGBColor[
              0.8233546764705882, 0.7380637647058825, 0.6105275588235295], 
             UndirectedEdge[54, 203] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[236, 314] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[277, 313] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[186, 397] -> 
             RGBColor[
              0.9066988529411765, 0.6660073529411767, 0.5663023823529412], 
             UndirectedEdge[29, 297] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[130, 208] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[145, 450] -> 
             RGBColor[
              0.7596562058823529, 0.6877910000000003, 0.6045280882352941], 
             UndirectedEdge[86, 350] -> 
             RGBColor[
              0.9066988529411765, 0.6660073529411767, 0.5663023823529412], 
             UndirectedEdge[37, 281] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[281, 445] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[116, 224] -> 
             RGBColor[
              0.4886372352941176, 0.5934276470588236, 0.9535244705882353], 
             UndirectedEdge[112, 163] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[148, 480] -> 
             RGBColor[
              0.7596562058823529, 0.6877910000000003, 0.6045280882352941], 
             UndirectedEdge[42, 487] -> 
             RGBColor[
              0.6781908823529412, 0.7413765882352942, 0.8957315588235295], 
             UndirectedEdge[122, 319] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[129, 348] -> 
             RGBColor[
              0.5870227647058823, 0.6486806764705881, 0.821780617647059], 
             UndirectedEdge[93, 201] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[121, 427] -> 
             RGBColor[
              0.6086985294117648, 0.6143141470588237, 0.6073992352941177], 
             UndirectedEdge[269, 411] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[76, 371] -> 
             RGBColor[0.6609395, 0.47108335294117665`, 0.5719235294117648], 
             UndirectedEdge[61, 244] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[184, 436] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[80, 293] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[111, 460] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[286, 358] -> 
             RGBColor[
              0.938695205882353, 0.8285484117647062, 0.5936544705882354], 
             UndirectedEdge[176, 244] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[99, 321] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[187, 478] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[116, 185] -> 
             RGBColor[
              0.6816970882352942, 0.7426854705882353, 0.8273737058823531], 
             UndirectedEdge[97, 257] -> 
             RGBColor[
              0.6072982647058824, 0.42522588235294134`, 0.5683387058823529], 
             UndirectedEdge[16, 313] -> 
             RGBColor[
              0.6229358235294118, 0.6650397352941178, 0.6486475588235294], 
             UndirectedEdge[166, 344] -> 
             RGBColor[
              0.6816970882352942, 0.7426854705882353, 0.8273737058823531], 
             UndirectedEdge[103, 443] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[74, 115] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[196, 332] -> 
             RGBColor[
              0.8970220882352942, 0.8539625882352943, 0.6306839117647058], 
             UndirectedEdge[49, 203] -> 
             RGBColor[
              0.6328412352941177, 0.696838794117647, 0.8243899117647061], 
             UndirectedEdge[95, 122] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[97, 209] -> 
             RGBColor[
              0.6717916764705882, 0.7108864117647059, 0.6516313529411765], 
             UndirectedEdge[484, 490] -> 
             RGBColor[
              0.7111956176470589, 0.7060182941176472, 0.6139678529411765], 
             UndirectedEdge[128, 415] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[371, 442] -> 
             RGBColor[0.6764155, 0.5603625882352943, 0.5855813235294118], 
             UndirectedEdge[88, 311] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[15, 149] -> 
             RGBColor[
              0.9361957058823529, 0.7637870000000002, 0.464683029411765], 
             UndirectedEdge[117, 140] -> 
             RGBColor[
              0.8787623235294117, 0.781568705882353, 0.6159916764705883], 
             UndirectedEdge[199, 475] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[71, 169] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529414, 0.6198870882352941], 
             UndirectedEdge[23, 51] -> 
             RGBColor[
              0.7281049411764706, 0.7872294117647058, 0.9738253529411764], 
             UndirectedEdge[381, 416] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[121, 447] -> 
             RGBColor[
              0.2247454705882353, 0.35355211764705885`, 0.9361102941176471], 
             UndirectedEdge[244, 407] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[255, 385] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[30, 469] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529411], 
             UndirectedEdge[80, 171] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[214, 466] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.608346705882353], 
             UndirectedEdge[199, 455] -> 
             RGBColor[
              0.5422784705882352, 0.6392851176470589, 0.9571092941176471], 
             UndirectedEdge[175, 483] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[124, 416] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[142, 396] -> 
             RGBColor[
              0.6072982647058824, 0.42522588235294134`, 0.568338705882353], 
             UndirectedEdge[185, 361] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[19, 26] -> 
             RGBColor[
              0.7111956176470589, 0.7060182941176472, 0.6139678529411765], 
             UndirectedEdge[341, 455] -> 
             RGBColor[
              0.6613845882352941, 0.7330628235294117, 0.9685728823529411], 
             UndirectedEdge[159, 239] -> 
             RGBColor[
              0.6613845882352941, 0.7330628235294117, 0.9685728823529411], 
             UndirectedEdge[261, 482] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[5, 97] -> 
             RGBColor[
              0.6781908823529412, 0.7413765882352942, 0.8957315588235295], 
             UndirectedEdge[285, 396] -> 
             RGBColor[
              0.6575543823529413, 0.660160823529412, 0.6103830294117647], 
             UndirectedEdge[174, 424] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[99, 186] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[79, 127] -> 
             RGBColor[
              0.6717916764705882, 0.7108864117647059, 0.6516313529411765], 
             UndirectedEdge[29, 86] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[127, 316] -> 
             RGBColor[
              0.2736013235294118, 0.39939879411764706`, 0.9390940882352941], 
             UndirectedEdge[197, 466] -> 
             RGBColor[
              0.7111956176470589, 0.7060182941176472, 0.6139678529411765], 
             UndirectedEdge[183, 206] -> 
             RGBColor[
              0.6485839411764706, 0.7197705294117647, 0.9688834705882352], 
             UndirectedEdge[25, 392] -> 
             RGBColor[
              0.7918034117647059, 0.8375021764705881, 0.9798248235294118], 
             UndirectedEdge[73, 91] -> 
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764705], 
             UndirectedEdge[187, 464] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[17, 99] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[110, 157] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[241, 429] -> 
             RGBColor[
              0.6816970882352942, 0.7426854705882353, 0.8273737058823531], 
             UndirectedEdge[27, 490] -> 
             RGBColor[
              0.47555811764705874`, 0.5851185294117647, 0.9518568235294118], 
             UndirectedEdge[372, 418] -> 
             RGBColor[
              0.9262902941176471, 0.7319879411764708, 0.2889406764705883], 
             UndirectedEdge[65, 350] -> 
             RGBColor[
              0.920719705882353, 0.6745077647058826, 0.45102523529411787`], 
             UndirectedEdge[189, 390] -> 
             RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             UndirectedEdge[263, 267] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[25, 490] -> 
             RGBColor[
              0.6059769411764705, 0.6895578823529411, 0.9631087647058824], 
             UndirectedEdge[360, 494] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[61, 203] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[36, 104] -> 
             RGBColor[
              0.9361957058823529, 0.7637870000000002, 0.464683029411765], 
             UndirectedEdge[33, 241] -> 
             RGBColor[
              0.6781908823529412, 0.7413765882352942, 0.8957315588235295], 
             UndirectedEdge[82, 419] -> 
             RGBColor[
              0.5860419411764706, 0.6465827941176472, 0.7150240294117647], 
             UndirectedEdge[5, 404] -> 
             RGBColor[0.9326895, 0.762478117647059, 0.5330408823529413], 
             UndirectedEdge[40, 396] -> 
             RGBColor[
              0.4886372352941176, 0.5934276470588236, 0.9535244705882353], 
             UndirectedEdge[169, 369] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529414, 0.6198870882352941], 
             UndirectedEdge[268, 491] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.608346705882353], 
             UndirectedEdge[4, 151] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[6, 390] -> 
             RGBColor[
              0.8787623235294117, 0.781568705882353, 0.6159916764705883], 
             UndirectedEdge[376, 482] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[158, 278] -> 
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352], 
             UndirectedEdge[317, 445] -> 
             RGBColor[
              0.6328412352941177, 0.696838794117647, 0.8243899117647061], 
             UndirectedEdge[133, 351] -> 
             RGBColor[
              0.7111956176470589, 0.7060182941176472, 0.6139678529411765], 
             UndirectedEdge[239, 454] -> 
             RGBColor[0.5588875, 0.6413586764705882, 0.9620042647058824], 
             UndirectedEdge[140, 198] -> 
             RGBColor[
              0.9527160588235295, 0.837048823529412, 0.47837732352941204`], 
             UndirectedEdge[252, 309] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[161, 243] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[244, 455] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.830958529411765], 
             UndirectedEdge[401, 451] -> 
             RGBColor[
              0.5628800588235294, 0.5661560294117649, 0.6047899411764706], 
             UndirectedEdge[210, 225] -> 
             RGBColor[
              0.558442411764706, 0.37937920588235313`, 0.5653549117647059], 
             UndirectedEdge[107, 223] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[5, 204] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[59, 200] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[328, 481] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[55, 434] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[269, 499] -> 
             RGBColor[
              0.6676762352941177, 0.7341850588235295, 0.9426508529411765], 
             UndirectedEdge[377, 476] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[260, 478] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[163, 207] -> 
             RGBColor[
              0.7918034117647059, 0.8375021764705881, 0.9798248235294118], 
             UndirectedEdge[238, 258] -> 
             RGBColor[
              0.961070411764706, 0.8776436470588238, 0.31732720588235297`], 
             UndirectedEdge[10, 443] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529411], 
             UndirectedEdge[231, 326] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[91, 287] -> 
             RGBColor[
              0.7213174705882353, 0.7800425294117648, 0.9462356764705883], 
             UndirectedEdge[242, 249] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[83, 209] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[306, 431] -> 
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352], 
             UndirectedEdge[176, 376] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[30, 191] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529411], 
             UndirectedEdge[209, 444] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[169, 289] -> 
             RGBColor[
              0.938695205882353, 0.8285484117647062, 0.5936544705882354], 
             UndirectedEdge[20, 46] -> 
             RGBColor[
              0.7596562058823529, 0.6877910000000003, 0.6045280882352941], 
             UndirectedEdge[49, 100] -> 
             RGBColor[
              0.6229358235294118, 0.6650397352941178, 0.6486475588235294], 
             UndirectedEdge[404, 486] -> 
             RGBColor[0.9326895, 0.762478117647059, 0.5330408823529413], 
             UndirectedEdge[103, 431] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[219, 238] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[249, 499] -> 
             RGBColor[
              0.6781908823529412, 0.7413765882352942, 0.8957315588235295], 
             UndirectedEdge[254, 377] -> 
             RGBColor[
              0.8963133529411764, 0.5312481176470589, 0.26139676470588236`], 
             UndirectedEdge[57, 434] -> 
             RGBColor[
              0.6717916764705882, 0.7108864117647059, 0.6516313529411765], 
             UndirectedEdge[75, 104] -> 
             RGBColor[
              0.9262902941176471, 0.7319879411764708, 0.2889406764705883], 
             UndirectedEdge[132, 365] -> 
             RGBColor[
              0.938695205882353, 0.8285484117647062, 0.5936544705882354], 
             UndirectedEdge[38, 77] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[172, 314] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[398, 481] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[143, 165] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[261, 475] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[288, 373] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[78, 171] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[6, 370] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[264, 295] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[45, 464] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[228, 318] -> 
             RGBColor[
              0.6392946176470589, 0.5877669411764708, 0.595690794117647], 
             UndirectedEdge[7, 295] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[225, 320] -> 
             RGBColor[
              0.9066988529411765, 0.6660073529411767, 0.5663023823529412], 
             UndirectedEdge[137, 148] -> 
             RGBColor[
              0.7596562058823529, 0.6877910000000003, 0.6045280882352941], 
             UndirectedEdge[61, 455] -> 
             RGBColor[
              0.7318321176470588, 0.7872340588235294, 0.8993163823529413], 
             UndirectedEdge[11, 331] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[20, 392] -> 
             RGBColor[
              0.7281049411764706, 0.7872294117647058, 0.9738253529411764], 
             UndirectedEdge[348, 431] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[241, 351] -> 
             RGBColor[0.4219168823529411, 0.5392610588235294, 0.948272], 
             UndirectedEdge[343, 374] -> 
             RGBColor[
              0.938695205882353, 0.8285484117647062, 0.5936544705882354], 
             UndirectedEdge[162, 389] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[207, 266] -> 
             RGBColor[
              0.6059769411764705, 0.6895578823529411, 0.9631087647058824], 
             UndirectedEdge[98, 425] -> 
             RGBColor[
              0.9221748529411764, 0.7552865882352944, 0.5799601764705883], 
             UndirectedEdge[151, 284] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[41, 365] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[436, 473] -> 
             RGBColor[
              0.9674696176470589, 0.908133823529412, 0.561427411764706], 
             UndirectedEdge[311, 405] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[235, 432] -> 
             RGBColor[0.9172135, 0.6731988823529413, 0.5193830882352942], 
             UndirectedEdge[109, 474] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764708, 0.3716207352941176], 
             UndirectedEdge[364, 468] -> 
             RGBColor[
              0.5539096176470588, 0.6257657352941176, 0.9632903823529412], 
             UndirectedEdge[203, 374] -> 
             RGBColor[
              0.9527160588235295, 0.837048823529412, 0.47837732352941204`], 
             UndirectedEdge[36, 112] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[324, 342] -> 
             RGBColor[
              0.5034798529411765, 0.5978537352941176, 0.9565401470588235], 
             UndirectedEdge[374, 445] -> 
             RGBColor[
              0.9527160588235295, 0.837048823529412, 0.47837732352941204`], 
             UndirectedEdge[2, 327] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[128, 438] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[33, 460] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[298, 335] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[112, 343] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[106, 265] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[19, 468] -> 
             RGBColor[
              0.3272425588235294, 0.4452562647058823, 0.9426789117647059], 
             UndirectedEdge[161, 202] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[204, 390] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[211, 289] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.6083467058823531], 
             UndirectedEdge[48, 479] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[57, 495] -> 
             RGBColor[
              0.6077433529411764, 0.6872053529411765, 0.9649880588235293], 
             UndirectedEdge[10, 280] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[206, 476] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[13, 256] -> 
             RGBColor[
              0.961070411764706, 0.8776436470588238, 0.31732720588235297`], 
             UndirectedEdge[184, 221] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[126, 282] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[53, 266] -> 
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647], 
             UndirectedEdge[194, 220] -> 
             RGBColor[
              0.9352148823529411, 0.761689117647059, 0.35792644117647054`], 
             UndirectedEdge[375, 417] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764708, 0.3716207352941176], 
             UndirectedEdge[245, 448] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[79, 147] -> 
             RGBColor[
              0.7254329117647058, 0.7567438823529412, 0.6552161764705883], 
             UndirectedEdge[77, 253] -> 
             RGBColor[
              0.9569549705882353, 0.9009422941176473, 0.608346705882353], 
             UndirectedEdge[180, 205] -> 
             RGBColor[
              0.7281049411764706, 0.7872294117647058, 0.9738253529411764], 
             UndirectedEdge[28, 432] -> 
             RGBColor[0.9172135, 0.6731988823529413, 0.5193830882352942], 
             UndirectedEdge[84, 245] -> 
             RGBColor[
              0.9527160588235295, 0.837048823529412, 0.47837732352941204`], 
             UndirectedEdge[19, 459] -> 
             RGBColor[
              0.7111956176470589, 0.7060182941176472, 0.6139678529411765], 
             UndirectedEdge[153, 236] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[315, 349] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[18, 460] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[126, 449] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[49, 324] -> 
             RGBColor[
              0.5034798529411765, 0.5978537352941176, 0.9565401470588235], 
             UndirectedEdge[334, 415] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[5, 444] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[147, 449] -> 
             RGBColor[
              0.5422784705882352, 0.6392851176470589, 0.9571092941176471], 
             UndirectedEdge[254, 426] -> 
             RGBColor[
              0.7768573823529412, 0.4640621176470588, 0.5692893529411764], 
             UndirectedEdge[186, 321] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[260, 399] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[184, 287] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[129, 431] -> 
             RGBColor[
              0.5860419411764706, 0.6465827941176472, 0.7150240294117647], 
             UndirectedEdge[300, 432] -> 
             RGBColor[
              0.8467659705882353, 0.6190276470588236, 0.5886395882352942], 
             UndirectedEdge[207, 293] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882355], 
             UndirectedEdge[118, 399] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[138, 179] -> 
             RGBColor[
              0.6816970882352942, 0.7426854705882353, 0.8273737058823531], 
             UndirectedEdge[40, 161] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[243, 279] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[69, 233] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[237, 460] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[54, 295] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[102, 210] -> 
             RGBColor[
              0.6188203823529411, 0.6883383823529412, 0.9396670588235294], 
             UndirectedEdge[137, 156] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705883], 
             UndirectedEdge[231, 444] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[383, 393] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[43, 137] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[233, 348] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[193, 410] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[126, 384] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[162, 345] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[165, 178] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[154, 455] -> 
             RGBColor[
              0.7254329117647058, 0.7567438823529412, 0.6552161764705883], 
             UndirectedEdge[211, 470] -> 
             RGBColor[
              0.8965770000000001, 0.5919831176470591, 0.23403455882352947`], 
             UndirectedEdge[201, 305] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[220, 474] -> 
             RGBColor[
              0.9352148823529411, 0.761689117647059, 0.35792644117647054`], 
             UndirectedEdge[125, 173] -> 
             RGBColor[
              0.5539096176470588, 0.6257657352941176, 0.9632903823529412], 
             UndirectedEdge[189, 443] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[307, 500] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[102, 134] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[102, 174] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[203, 281] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[279, 421] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[335, 430] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[69, 431] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[149, 249] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[141, 345] -> 
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352], 
             UndirectedEdge[12, 283] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[119, 381] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[396, 430] -> 
             RGBColor[
              0.6717916764705882, 0.7108864117647059, 0.6516313529411765], 
             UndirectedEdge[49, 360] -> 
             RGBColor[
              0.6328412352941177, 0.696838794117647, 0.8243899117647061], 
             UndirectedEdge[208, 497] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764708, 0.3716207352941176], 
             UndirectedEdge[275, 444] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529411], 
             UndirectedEdge[269, 323] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[273, 279] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[107, 289] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[289, 314] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[6, 428] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705883], 
             UndirectedEdge[7, 17] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[309, 424] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[128, 385] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[71, 362] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[43, 156] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[59, 298] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[261, 455] -> 
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647], 
             UndirectedEdge[17, 89] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[9, 68] -> 
             RGBColor[
              0.6676762352941177, 0.7341850588235295, 0.9426508529411765], 
             UndirectedEdge[73, 298] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[16, 333] -> 
             RGBColor[
              0.631860411764706, 0.6947409117647059, 0.7176333235294117], 
             UndirectedEdge[257, 445] -> 
             RGBColor[
              0.920719705882353, 0.6745077647058826, 0.4510252352941179], 
             UndirectedEdge[428, 451] -> 
             RGBColor[
              0.5835165588235294, 0.6473717941176471, 0.8901384705882354], 
             UndirectedEdge[15, 419] -> 
             RGBColor[
              0.9352148823529411, 0.761689117647059, 0.35792644117647054`], 
             UndirectedEdge[17, 313] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[5, 326] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[216, 217] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[138, 222] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[251, 447] -> 
             RGBColor[
              0.5870227647058823, 0.6486806764705882, 0.821780617647059], 
             UndirectedEdge[58, 144] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[11, 404] -> 
             RGBColor[
              0.9030825588235294, 0.7408720588235296, 0.606192794117647], 
             UndirectedEdge[270, 329] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[314, 406] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[13, 409] -> 
             RGBColor[
              0.961070411764706, 0.8776436470588238, 0.31732720588235297`], 
             UndirectedEdge[279, 335] -> 
             RGBColor[
              0.672697294117647, 0.7437244705882353, 0.9683612352941176], 
             UndirectedEdge[195, 446] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[22, 170] -> 
             RGBColor[
              0.6816970882352942, 0.7426854705882353, 0.8273737058823531], 
             UndirectedEdge[159, 166] -> 
             RGBColor[0.4219168823529411, 0.5392610588235294, 0.948272], 
             UndirectedEdge[59, 87] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[176, 407] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[169, 470] -> 
             RGBColor[
              0.8783172352941178, 0.519589235294118, 0.21934232352941183`], 
             UndirectedEdge[13, 188] -> 
             RGBColor[
              0.9709758235294118, 0.9094427058823531, 0.49306955882352965`], 
             UndirectedEdge[273, 396] -> 
             RGBColor[
              0.6816970882352942, 0.7426854705882353, 0.8273737058823531], 
             UndirectedEdge[30, 405] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[258, 497] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[90, 485] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[89, 455] -> 
             RGBColor[
              0.7318321176470588, 0.7872340588235294, 0.8993163823529413], 
             UndirectedEdge[422, 451] -> 
             RGBColor[
              0.5539096176470588, 0.6257657352941176, 0.9632903823529412], 
             UndirectedEdge[99, 178] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[119, 416] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[129, 204] -> 
             RGBColor[
              0.5860419411764706, 0.6465827941176472, 0.7150240294117647], 
             UndirectedEdge[1, 381] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[287, 409] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[340, 384] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[233, 379] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[1, 124] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[134, 309] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[1, 380] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[112, 403] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[214, 268] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[404, 444] -> 
             RGBColor[
              0.8068343235294118, 0.6648019411764707, 0.5968332647058824], 
             UndirectedEdge[252, 320] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[173, 419] -> 
             RGBColor[
              0.5860419411764706, 0.6465827941176472, 0.7150240294117647], 
             UndirectedEdge[407, 475] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[167, 305] -> 
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352], 
             UndirectedEdge[407, 482] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[197, 493] -> 
             RGBColor[
              0.7213174705882353, 0.7800425294117648, 0.9462356764705883], 
             UndirectedEdge[235, 300] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[312, 385] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[188, 318] -> 
             RGBColor[
              0.6816970882352942, 0.7426854705882353, 0.8273737058823531], 
             UndirectedEdge[71, 153] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[45, 481] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[53, 317] -> 
             RGBColor[
              0.5997280882352941, 0.6739238529411764, 0.9658996764705883], 
             UndirectedEdge[253, 301] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058825, 0.6345793235294117], 
             UndirectedEdge[442, 447] -> 
             RGBColor[
              0.5280999411764706, 0.4205003235294119, 0.5764034117647059], 
             UndirectedEdge[118, 464] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[2, 118] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[332, 454] -> 
             RGBColor[0.5588875, 0.6413586764705882, 0.9620042647058824], 
             UndirectedEdge[84, 455] -> 
             RGBColor[
              0.6929358529411764, 0.6336244117647061, 0.5992756176470588], 
             UndirectedEdge[423, 488] -> 
             RGBColor[
              0.5835165588235294, 0.6473717941176471, 0.8901384705882354], 
             UndirectedEdge[5, 231] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[121, 337] -> 
             RGBColor[0.5588875, 0.6413586764705882, 0.9620042647058824], 
             UndirectedEdge[23, 360] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[79, 336] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[237, 371] -> 
             RGBColor[
              0.6929358529411764, 0.6336244117647061, 0.5992756176470588], 
             UndirectedEdge[9, 330] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[76, 111] -> 
             RGBColor[
              0.9066988529411765, 0.6660073529411767, 0.5663023823529412], 
             UndirectedEdge[91, 256] -> 
             RGBColor[
              0.7254329117647058, 0.7567438823529412, 0.6552161764705883], 
             UndirectedEdge[35, 193] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[43, 267] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[261, 448] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.7448134117647058], 
             UndirectedEdge[322, 374] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764708, 0.3716207352941176], 
             UndirectedEdge[76, 130] -> 
             RGBColor[
              0.9108142941176471, 0.6427087058823532, 0.2752828823529412], 
             UndirectedEdge[107, 153] -> 
             RGBColor[
              0.7918034117647059, 0.8375021764705881, 0.9798248235294118], 
             UndirectedEdge[410, 437] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[11, 164] -> 
             RGBColor[
              0.6485839411764706, 0.7197705294117647, 0.9688834705882352], 
             UndirectedEdge[213, 500] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[251, 454] -> 
             RGBColor[
              0.6328412352941176, 0.696838794117647, 0.8243899117647061], 
             UndirectedEdge[111, 483] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[5, 233] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[69, 372] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[454, 489] -> 
             RGBColor[
              0.6293350294117648, 0.6955299117647059, 0.8927477647058825], 
             UndirectedEdge[289, 493] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[74, 268] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[192, 258] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058826, 0.30263497058823535`], 
             UndirectedEdge[68, 368] -> 
             RGBColor[
              0.6676762352941177, 0.7341850588235295, 0.9426508529411765], 
             UndirectedEdge[50, 414] -> 
             RGBColor[
              0.6293350294117648, 0.6955299117647059, 0.8927477647058825], 
             UndirectedEdge[358, 441] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.718580794117647], 
             UndirectedEdge[71, 289] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[54, 321] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[75, 408] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[8, 239] -> 
             RGBColor[
              0.7918034117647059, 0.8375021764705881, 0.9798248235294118], 
             UndirectedEdge[389, 472] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[178, 475] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[332, 489] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[28, 406] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[77, 87] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[274, 300] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[330, 333] -> 
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918], 
             UndirectedEdge[325, 490] -> 
             RGBColor[
              0.7318321176470588, 0.7872340588235294, 0.8993163823529413], 
             UndirectedEdge[420, 489] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[271, 304] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705883], 
             UndirectedEdge[166, 387] -> 
             RGBColor[
              0.6717916764705882, 0.7108864117647059, 0.6516313529411765], 
             UndirectedEdge[16, 165] -> 
             RGBColor[
              0.5034798529411765, 0.5978537352941176, 0.9565401470588235], 
             UndirectedEdge[44, 356] -> 
             RGBColor[
              0.7318321176470588, 0.7872340588235294, 0.8993163823529413], 
             UndirectedEdge[86, 377] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[113, 353] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[63, 222] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[71, 493] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[106, 270] -> 
             RGBColor[
              0.7918034117647059, 0.8375021764705881, 0.9798248235294118], 
             UndirectedEdge[414, 498] -> 
             RGBColor[
              0.9674696176470589, 0.908133823529412, 0.561427411764706], 
             UndirectedEdge[46, 220] -> 
             RGBColor[
              0.8937932352941177, 0.6088684705882357, 0.2330001176470589], 
             UndirectedEdge[302, 443] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             UndirectedEdge[90, 267] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[116, 187] -> 
             RGBColor[
              0.6676762352941177, 0.7341850588235295, 0.9426508529411765], 
             UndirectedEdge[162, 472] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[271, 371] -> 
             RGBColor[
              0.7318321176470588, 0.7872340588235294, 0.8993163823529413], 
             UndirectedEdge[84, 478] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705883], 
             UndirectedEdge[5, 163] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[188, 430] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[380, 487] -> 
             RGBColor[
              0.6816970882352942, 0.7426854705882353, 0.8273737058823531], 
             UndirectedEdge[88, 304] -> 
             RGBColor[
              0.938695205882353, 0.8285484117647062, 0.5936544705882354], 
             UndirectedEdge[41, 494] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[23, 136] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[7, 84] -> 
             RGBColor[
              0.7596562058823529, 0.6877910000000003, 0.6045280882352941], 
             UndirectedEdge[218, 493] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[40, 183] -> 
             RGBColor[
              0.4886372352941176, 0.5934276470588236, 0.9535244705882353], 
             UndirectedEdge[192, 453] -> 
             RGBColor[
              0.8937932352941177, 0.6088684705882357, 0.2330001176470589], 
             UndirectedEdge[49, 397] -> 
             RGBColor[
              0.558442411764706, 0.37937920588235313`, 0.5653549117647059], 
             UndirectedEdge[291, 467] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058825, 0.6345793235294118], 
             UndirectedEdge[347, 462] -> 
             RGBColor[
              0.5422784705882352, 0.6392851176470589, 0.9571092941176471], 
             UndirectedEdge[31, 226] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[120, 381] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[151, 274] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.427561294117647], 
             UndirectedEdge[316, 418] -> 
             RGBColor[
              0.5280999411764706, 0.4205003235294119, 0.5764034117647059], 
             UndirectedEdge[235, 389] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[218, 310] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[408, 463] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[12, 273] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[121, 454] -> 
             RGBColor[
              0.2705639411764706, 0.40171023529411765`, 0.9387195882352941], 
             UndirectedEdge[47, 228] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764708, 0.3716207352941176], 
             UndirectedEdge[438, 439] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[172, 201] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[58, 375] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             UndirectedEdge[168, 280] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[77, 301] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[283, 477] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647057], 
             UndirectedEdge[125, 149] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[7, 407] -> 
             RGBColor[
              0.7281049411764706, 0.7872294117647058, 0.9738253529411764], 
             UndirectedEdge[401, 437] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058825, 0.6345793235294117], 
             UndirectedEdge[138, 438] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[45, 399] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[97, 317] -> 
             RGBColor[
              0.3194197941176471, 0.4475569117647059, 0.9417033823529412], 
             UndirectedEdge[71, 201] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[107, 236] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[134, 225] -> 
             RGBColor[0.9172135, 0.6731988823529413, 0.5193830882352942], 
             UndirectedEdge[59, 91] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.830958529411765], 
             UndirectedEdge[161, 287] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[101, 486] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615], 
             UndirectedEdge[185, 330] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[237, 432] -> 
             RGBColor[
              0.8783172352941178, 0.519589235294118, 0.21934232352941183`], 
             UndirectedEdge[99, 143] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529414], 
             UndirectedEdge[107, 411] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[187, 407] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[185, 357] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[80, 208] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[60, 240] -> 
             RGBColor[
              0.6293350294117648, 0.6955299117647059, 0.8927477647058825], 
             UndirectedEdge[262, 299] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[82, 282] -> 
             RGBColor[
              0.5835165588235294, 0.6473717941176471, 0.8901384705882354], 
             UndirectedEdge[286, 368] -> 
             RGBColor[
              0.938695205882353, 0.8285484117647062, 0.5936544705882354], 
             UndirectedEdge[81, 454] -> 
             RGBColor[
              0.5997280882352941, 0.6739238529411764, 0.9658996764705883], 
             UndirectedEdge[68, 352] -> 
             RGBColor[
              0.6676762352941177, 0.7341850588235295, 0.9426508529411765], 
             UndirectedEdge[196, 337] -> 
             RGBColor[
              0.8970220882352942, 0.8539625882352943, 0.6306839117647058], 
             UndirectedEdge[261, 262] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[122, 286] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529414, 0.6198870882352941]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.9103135882352942, 0.6821302941176475, 0.24669441176470597`], 
             316 -> RGBColor[0.178927, 0.305394, 0.933501], 308 -> 
             RGBColor[
              0.47555811764705874`, 0.5851185294117647, 0.9518568235294118], 
             160 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             245 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             155 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             425 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             213 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             352 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 27 -> 
             RGBColor[
              0.47555811764705874`, 0.5851185294117647, 0.9518568235294118], 
             485 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             454 -> RGBColor[
              0.2705639411764706, 0.40171023529411765`, 0.9387195882352941], 
             367 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             19 -> RGBColor[
              0.47555811764705874`, 0.5851185294117647, 0.9518568235294118], 
             164 -> RGBColor[
              0.36827564705882354`, 0.4934035882352941, 0.9446871764705882], 
             190 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             103 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             138 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             416 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             476 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             291 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 28 -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             337 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             195 -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             114 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             479 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             93 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             34 -> RGBColor[
              0.36827564705882354`, 0.4934035882352941, 0.9446871764705882], 
             161 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 22 -> 
             RGBColor[
              0.36827564705882354`, 0.4934035882352941, 0.9446871764705882], 
             124 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 84 -> 
             RGBColor[
              0.9103135882352942, 0.6821302941176475, 0.24669441176470597`], 
             46 -> RGBColor[
              0.9103135882352942, 0.6821302941176475, 0.24669441176470597`], 
             241 -> RGBColor[
              0.36827564705882354`, 0.4934035882352941, 0.9446871764705882], 
             185 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             426 -> RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 
             390 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             121 -> RGBColor[
              0.2705639411764706, 0.40171023529411765`, 0.9387195882352941], 
             322 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             488 -> RGBColor[0.178927, 0.305394, 0.933501], 126 -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             433 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             236 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 78 -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             376 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             458 -> RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 
             254 -> RGBColor[0.817319, 0.134127, 0.164218], 290 -> 
             RGBColor[
              0.47555811764705874`, 0.5851185294117647, 0.9518568235294118], 
             251 -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             165 -> RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 
             460 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             100 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             235 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 70 -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             234 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             435 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             257 -> RGBColor[
              0.8463208823529412, 0.3570481764705886, 0.19199023529411768`], 
             135 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             265 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             111 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             497 -> RGBColor[
              0.9103135882352942, 0.6821302941176475, 0.24669441176470597`], 
             481 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             381 -> RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 
             182 -> RGBColor[
              0.9103135882352942, 0.6821302941176475, 0.24669441176470597`], 
             188 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             154 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             336 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             463 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             315 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             368 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             269 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             208 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             86 -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             119 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             436 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             377 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             140 -> RGBColor[
              0.9103135882352942, 0.6821302941176475, 0.24669441176470597`], 
             85 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             351 -> RGBColor[
              0.47555811764705874`, 0.5851185294117647, 0.9518568235294118], 
             443 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             242 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             117 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 47 -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             451 -> RGBColor[0.178927, 0.305394, 0.933501], 81 -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             275 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             23 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             328 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             418 -> RGBColor[
              0.8772728823529412, 0.5356066470588239, 0.21930582352941183`], 
             110 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             6 -> RGBColor[
              0.9103135882352942, 0.6821302941176475, 0.24669441176470597`], 
             218 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             108 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             297 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             487 -> RGBColor[
              0.36827564705882354`, 0.4934035882352941, 0.9446871764705882], 
             464 -> RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 
             157 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             441 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             354 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             385 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             270 -> RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 
             392 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 33 -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             252 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             394 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             260 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             159 -> RGBColor[
              0.47555811764705874`, 0.5851185294117647, 0.9518568235294118], 
             183 -> RGBColor[
              0.36827564705882354`, 0.4934035882352941, 0.9446871764705882], 
             99 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             329 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             309 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 17 -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             349 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             495 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             347 -> RGBColor[
              0.47555811764705874`, 0.5851185294117647, 0.9518568235294118], 
             340 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             404 -> RGBColor[
              0.8772728823529412, 0.5356066470588239, 0.21930582352941183`], 
             277 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             104 -> RGBColor[
              0.8772728823529412, 0.5356066470588239, 0.21930582352941183`], 
             79 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             327 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             191 -> RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 50 -> 
             RGBColor[
              0.2705639411764706, 0.40171023529411765`, 0.9387195882352941], 
             225 -> RGBColor[
              0.8463208823529412, 0.3570481764705886, 0.19199023529411768`], 
             405 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 61 -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             196 -> RGBColor[
              0.9468331176470589, 0.8269180588235298, 0.27607888235294126`], 
             1 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             263 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             201 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             371 -> RGBColor[
              0.47555811764705874`, 0.5851185294117647, 0.9518568235294118], 
             293 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             362 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             184 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             106 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             206 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             358 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             247 -> RGBColor[
              0.36827564705882354`, 0.4934035882352941, 0.9446871764705882], 
             220 -> RGBColor[
              0.8772728823529412, 0.5356066470588239, 0.21930582352941183`], 
             407 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             107 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             375 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             131 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             411 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             462 -> RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             127 -> RGBColor[
              0.36827564705882354`, 0.4934035882352941, 0.9446871764705882], 
             210 -> RGBColor[
              0.2705639411764706, 0.40171023529411765`, 0.9387195882352941], 
             357 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             181 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             194 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             440 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             490 -> RGBColor[
              0.47555811764705874`, 0.5851185294117647, 0.9518568235294118], 
             118 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             348 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             276 -> RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             305 -> RGBColor[
              0.9468331176470589, 0.8269180588235298, 0.27607888235294126`], 
             343 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             280 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             474 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             189 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             168 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             363 -> RGBColor[
              0.47555811764705874`, 0.5851185294117647, 0.9518568235294118], 
             41 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 14 -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             77 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 51 -> 
             RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             438 -> RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             179 -> RGBColor[
              0.36827564705882354`, 0.4934035882352941, 0.9446871764705882], 
             467 -> 
             RGBColor[
              0.9468331176470589, 0.8269180588235298, 0.27607888235294126`], 
             223 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             456 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             323 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             500 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             478 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             292 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             491 -> RGBColor[
              0.9468331176470589, 0.8269180588235298, 0.27607888235294126`], 
             396 -> RGBColor[
              0.36827564705882354`, 0.4934035882352941, 0.9446871764705882], 
             321 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             143 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             112 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             197 -> RGBColor[
              0.47555811764705874`, 0.5851185294117647, 0.9518568235294118], 
             421 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 54 -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 71 -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             177 -> RGBColor[
              0.36827564705882354`, 0.4934035882352941, 0.9446871764705882], 
             158 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             226 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             432 -> RGBColor[
              0.8463208823529412, 0.3570481764705886, 0.19199023529411768`], 
             350 -> RGBColor[
              0.8463208823529412, 0.3570481764705886, 0.19199023529411768`], 
             203 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             475 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             115 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             173 -> RGBColor[0.178927, 0.305394, 0.933501], 212 -> 
             RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             129 -> RGBColor[0.178927, 0.305394, 0.933501], 279 -> 
             RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 26 -> 
             RGBColor[
              0.9468331176470589, 0.8269180588235298, 0.27607888235294126`], 
             40 -> RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             146 -> RGBColor[
              0.9103135882352942, 0.6821302941176475, 0.24669441176470597`], 
             386 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             192 -> RGBColor[
              0.9103135882352942, 0.6821302941176475, 0.24669441176470597`], 
             300 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             221 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 62 -> 
             RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             286 -> RGBColor[
              0.9103135882352942, 0.6821302941176475, 0.24669441176470597`], 
             472 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             152 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 64 -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             307 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 37 -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             148 -> RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             261 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             387 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             15 -> RGBColor[
              0.8772728823529412, 0.5356066470588239, 0.21930582352941183`], 
             136 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             198 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 63 -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             444 -> 
             RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 
             310 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             171 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             395 -> RGBColor[
              0.36827564705882354`, 0.4934035882352941, 0.9446871764705882], 
             311 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             353 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             59 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             397 -> RGBColor[
              0.8463208823529412, 0.3570481764705886, 0.19199023529411768`], 
             229 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             102 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             453 -> RGBColor[
              0.8772728823529412, 0.5356066470588239, 0.21930582352941183`], 
             299 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             128 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 12 -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             222 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             483 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 92 -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             271 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             361 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             344 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             132 -> RGBColor[
              0.9103135882352942, 0.6821302941176475, 0.24669441176470597`], 
             80 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             324 -> RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 
             244 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             150 -> RGBColor[0.817319, 0.134127, 0.164218], 125 -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             258 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             133 -> RGBColor[
              0.9468331176470589, 0.8269180588235298, 0.27607888235294126`], 
             469 -> RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 
             255 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             408 -> RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             326 -> RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 
             176 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             230 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             274 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             87 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             439 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             130 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             35 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             379 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 31 -> 
             RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 18 -> 
             RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 24 -> 
             RGBColor[
              0.9468331176470589, 0.8269180588235298, 0.27607888235294126`], 
             151 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             137 -> RGBColor[
              0.9103135882352942, 0.6821302941176475, 0.24669441176470597`], 
             330 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             296 -> RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 
             266 -> RGBColor[
              0.47555811764705874`, 0.5851185294117647, 0.9518568235294118], 
             302 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             442 -> RGBColor[
              0.8772728823529412, 0.5356066470588239, 0.21930582352941183`], 
             283 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             388 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             284 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             417 -> RGBColor[
              0.9103135882352942, 0.6821302941176475, 0.24669441176470597`], 
             318 -> RGBColor[
              0.36827564705882354`, 0.4934035882352941, 0.9446871764705882], 
             413 -> RGBColor[0.178927, 0.305394, 0.933501], 238 -> 
             RGBColor[
              0.9468331176470589, 0.8269180588235298, 0.27607888235294126`], 
             72 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             437 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             288 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             382 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             461 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             389 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             172 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             447 -> RGBColor[0.178927, 0.305394, 0.933501], 243 -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             410 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 88 -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             273 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             477 -> RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             202 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             393 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             98 -> RGBColor[
              0.8772728823529412, 0.5356066470588239, 0.21930582352941183`], 
             30 -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             116 -> RGBColor[
              0.36827564705882354`, 0.4934035882352941, 0.9446871764705882], 
             373 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             434 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             401 -> RGBColor[
              0.9468331176470589, 0.8269180588235298, 0.27607888235294126`], 
             240 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             480 -> RGBColor[
              0.9103135882352942, 0.6821302941176475, 0.24669441176470597`], 
             403 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             317 -> RGBColor[
              0.2705639411764706, 0.40171023529411765`, 0.9387195882352941], 
             429 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             391 -> RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 73 -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             303 -> RGBColor[
              0.8772728823529412, 0.5356066470588239, 0.21930582352941183`], 
             449 -> RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 29 -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             360 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             320 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             482 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 75 -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             200 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             301 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             156 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 25 -> 
             RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 38 -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             365 -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             380 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             370 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             3 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 57 -> 
             RGBColor[
              0.36827564705882354`, 0.4934035882352941, 0.9446871764705882], 
             227 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             494 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 39 -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             424 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             109 -> RGBColor[
              0.9103135882352942, 0.6821302941176475, 0.24669441176470597`], 
             465 -> RGBColor[
              0.9468331176470589, 0.8269180588235298, 0.27607888235294126`], 
             256 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             457 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             339 -> RGBColor[
              0.8463208823529412, 0.3570481764705886, 0.19199023529411768`], 
             420 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             287 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             239 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             427 -> RGBColor[
              0.9468331176470589, 0.8269180588235298, 0.27607888235294126`], 
             285 -> RGBColor[
              0.9468331176470589, 0.8269180588235298, 0.27607888235294126`], 
             345 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             366 -> RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             216 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 21 -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             355 -> RGBColor[
              0.2705639411764706, 0.40171023529411765`, 0.9387195882352941], 
             175 -> 
             RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 7 -> 
             RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 13 -> 
             RGBColor[
              0.9468331176470589, 0.8269180588235298, 0.27607888235294126`], 
             294 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             412 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             193 -> RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 60 -> 
             RGBColor[
              0.2705639411764706, 0.40171023529411765`, 0.9387195882352941], 
             65 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             448 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             69 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             217 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             214 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             170 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             359 -> RGBColor[0.178927, 0.305394, 0.933501], 74 -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             246 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             264 -> RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             278 -> RGBColor[
              0.9468331176470589, 0.8269180588235298, 0.27607888235294126`], 
             45 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             492 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             306 -> RGBColor[
              0.9468331176470589, 0.8269180588235298, 0.27607888235294126`], 
             237 -> RGBColor[
              0.9103135882352942, 0.6821302941176475, 0.24669441176470597`], 
             228 -> RGBColor[
              0.9103135882352942, 0.6821302941176475, 0.24669441176470597`], 
             180 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             383 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 53 -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             304 -> RGBColor[
              0.9103135882352942, 0.6821302941176475, 0.24669441176470597`], 
             48 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 5 -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             101 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             333 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             267 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             120 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             147 -> RGBColor[
              0.47555811764705874`, 0.5851185294117647, 0.9518568235294118], 
             89 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 43 -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             199 -> RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             268 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             169 -> RGBColor[
              0.9103135882352942, 0.6821302941176475, 0.24669441176470597`], 
             20 -> RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 4 -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             167 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             431 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             142 -> RGBColor[
              0.8463208823529412, 0.3570481764705886, 0.19199023529411768`], 
             16 -> RGBColor[
              0.2705639411764706, 0.40171023529411765`, 0.9387195882352941], 
             414 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             281 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             289 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             398 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             178 -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             58 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             186 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             122 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             249 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             113 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 52 -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             409 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             187 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             259 -> RGBColor[
              0.9103135882352942, 0.6821302941176475, 0.24669441176470597`], 
             42 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             134 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             470 -> RGBColor[
              0.8463208823529412, 0.3570481764705886, 0.19199023529411768`], 
             313 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             248 -> RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             174 -> RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 
             215 -> RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             399 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             422 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 83 -> 
             RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 95 -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             166 -> RGBColor[
              0.36827564705882354`, 0.4934035882352941, 0.9446871764705882], 
             384 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             233 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             295 -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             499 -> RGBColor[
              0.36827564705882354`, 0.4934035882352941, 0.9446871764705882], 
             141 -> RGBColor[
              0.9468331176470589, 0.8269180588235298, 0.27607888235294126`], 
             319 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             205 -> RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             468 -> RGBColor[0.178927, 0.305394, 0.933501], 486 -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             224 -> RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             231 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             332 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 68 -> 
             RGBColor[
              0.36827564705882354`, 0.4934035882352941, 0.9446871764705882], 
             484 -> RGBColor[
              0.9468331176470589, 0.8269180588235298, 0.27607888235294126`], 
             10 -> RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 
             250 -> RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             282 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             374 -> RGBColor[
              0.9103135882352942, 0.6821302941176475, 0.24669441176470597`], 
             232 -> RGBColor[
              0.9468331176470589, 0.8269180588235298, 0.27607888235294126`], 
             489 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             253 -> RGBColor[
              0.9468331176470589, 0.8269180588235298, 0.27607888235294126`], 
             459 -> RGBColor[
              0.9468331176470589, 0.8269180588235298, 0.27607888235294126`], 
             415 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             55 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             446 -> RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             325 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 91 -> 
             RGBColor[
              0.47555811764705874`, 0.5851185294117647, 0.9518568235294118], 
             450 -> 
             RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             423 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             105 -> RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 36 -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             123 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             94 -> RGBColor[
              0.8772728823529412, 0.5356066470588239, 0.21930582352941183`], 
             473 -> RGBColor[
              0.9468331176470589, 0.8269180588235298, 0.27607888235294126`], 
             312 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 96 -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             496 -> RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 2 -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             262 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             272 -> RGBColor[
              0.9103135882352942, 0.6821302941176475, 0.24669441176470597`], 
             97 -> RGBColor[
              0.36827564705882354`, 0.4934035882352941, 0.9446871764705882], 
             372 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             356 -> RGBColor[
              0.47555811764705874`, 0.5851185294117647, 0.9518568235294118], 
             402 -> RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 
             455 -> RGBColor[
              0.47555811764705874`, 0.5851185294117647, 0.9518568235294118], 
             428 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             346 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             341 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             209 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             498 -> RGBColor[
              0.9468331176470589, 0.8269180588235298, 0.27607888235294126`], 
             378 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             419 -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             66 -> RGBColor[
              0.8772728823529412, 0.5356066470588239, 0.21930582352941183`], 
             139 -> RGBColor[
              0.9103135882352942, 0.6821302941176475, 0.24669441176470597`], 
             56 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             335 -> RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 
             314 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             144 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             298 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             204 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.49654705882352923`], 
             452 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             466 -> RGBColor[
              0.9468331176470589, 0.8269180588235298, 0.27607888235294126`], 
             207 -> RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 
             334 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             149 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             219 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             400 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             9 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 11 -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 44 -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             153 -> RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 
             471 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             406 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 32 -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             162 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             493 -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 90 -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             331 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             8 -> RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 
             364 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             342 -> RGBColor[
              0.2705639411764706, 0.40171023529411765`, 0.9387195882352941], 
             163 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 49 -> 
             RGBColor[
              0.2705639411764706, 0.40171023529411765`, 0.9387195882352941], 
             338 -> RGBColor[
              0.8772728823529412, 0.5356066470588239, 0.21930582352941183`], 
             76 -> RGBColor[
              0.8463208823529412, 0.3570481764705886, 0.19199023529411768`], 
             369 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             445 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 82 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 67 -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             430 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             211 -> RGBColor[
              0.9468331176470589, 0.8269180588235298, 
               0.27607888235294126`]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw1l3k4VA/cxYfs69jHPjOGGTNjV1rUPZUi6hcVbZKtXVmyRook2RJlqUih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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 42}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 108}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 119}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 120}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 124}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 315}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 363}], {
             RGBColor[
             0.7254329117647058, 0.7567438823529412, 0.6552161764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 364}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 378}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 380}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 381}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 416}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 452}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 468}], {
             RGBColor[
             0.5771173529411765, 0.6168816176470588, 0.6460382647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 487}], {
             RGBColor[
             0.6717916764705882, 0.7108864117647059, 0.6516313529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[
             0.9030825588235294, 0.7408720588235296, 0.606192794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 114}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 118}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 195}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 255}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 260}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 312}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 327}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 334}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 385}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 446}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 496}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 139}], {
             RGBColor[
             0.938695205882353, 0.8285484117647062, 0.5936544705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 158}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 247}], {
             RGBColor[
             0.6676762352941177, 0.7341850588235295, 0.9426508529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 278}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 401}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 428}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 437}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 451}], {
             RGBColor[
             0.5730019117647058, 0.6401802647058824, 0.9370577647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 31}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 151}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 162}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 191}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 345}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 366}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 389}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 405}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 429}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 472}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 488}], {
             RGBColor[
             0.5771173529411765, 0.6168816176470588, 0.6460382647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 69}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 97}], {
             RGBColor[
             0.6781908823529412, 0.7413765882352942, 0.8957315588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 103}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 129}], {
             RGBColor[
             0.5835165588235294, 0.6473717941176471, 0.8901384705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 163}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 204}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 209}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 231}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 233}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 259}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 275}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 326}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 346}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 348}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 355}], {
             RGBColor[
             0.6293350294117647, 0.6955299117647059, 0.8927477647058825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 395}], {
             RGBColor[
             0.6781908823529412, 0.7413765882352942, 0.8957315588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 404}], {
             RGBColor[0.9326895, 0.762478117647059, 0.5330408823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 431}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 444}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 486}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 35}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 101}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764708, 0.3716207352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 123}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 158}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764708, 0.3716207352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 181}], {
             RGBColor[
             0.9527160588235295, 0.837048823529412, 0.47837732352941204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 189}], {
             RGBColor[
             0.8787623235294117, 0.781568705882353, 0.6159916764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 302}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764708, 0.3716207352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 306}], {
             RGBColor[
             0.9285733529411766, 0.7545241764705886, 0.26138664705882364`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 347}], {
             RGBColor[
             0.6929358529411764, 0.6336244117647061, 0.5992756176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 370}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 390}], {
             RGBColor[
             0.8787623235294117, 0.781568705882353, 0.6159916764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 422}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529414, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 428}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 451}], {
             RGBColor[
             0.5446202941176471, 0.4937621470588237, 0.590097705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 17}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.7596562058823529, 0.6877910000000003, 0.6045280882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 89}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 176}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 178}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 244}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 261}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 262}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 288}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 295}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 313}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 321}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 341}], {
             RGBColor[
             0.7281049411764706, 0.7872294117647058, 0.9738253529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 376}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 391}], {
             RGBColor[
             0.672697294117647, 0.7437244705882353, 0.9683612352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 407}], {
             RGBColor[
             0.7281049411764706, 0.7872294117647058, 0.9738253529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 448}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 455}], {
             RGBColor[
             0.5422784705882352, 0.6392851176470589, 0.9571092941176471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 475}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 478}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 482}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 63}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 85}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 146}], {
             RGBColor[
             0.8233546764705882, 0.7380637647058825, 0.6105275588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 159}], {
             RGBColor[
             0.6059769411764705, 0.6895578823529411, 0.9631087647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 166}], {
             RGBColor[
             0.5523357058823529, 0.6437004117647058, 0.9595239411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 239}], {
             RGBColor[
             0.7918034117647059, 0.8375021764705881, 0.9798248235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 344}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 387}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 435}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 439}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 453}], {
             RGBColor[
             0.8068343235294118, 0.6648019411764707, 0.5968332647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 68}], {
             RGBColor[
             0.6676762352941177, 0.7341850588235295, 0.9426508529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 95}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 286}], {
             RGBColor[
             0.938695205882353, 0.8285484117647062, 0.5936544705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 319}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 330}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 333}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 352}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 357}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 358}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 367}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 368}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 375}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 441}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 450}], {
             RGBColor[
             0.7880378235294117, 0.8342091176470589, 0.9514881470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 492}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 102}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 168}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 181}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.7918034117647059, 0.8375021764705881, 0.9798248235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 232}], {
             RGBColor[
             0.8416144411764706, 0.8104576470588236, 0.625219794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 280}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 302}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 370}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 383}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 390}], {
             RGBColor[
             0.7918034117647059, 0.8375021764705881, 0.9798248235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 443}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 451}], {
             RGBColor[
             0.4576613823529412, 0.5496956176470588, 0.9539308529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 480}], {
             RGBColor[
             0.8233546764705882, 0.7380637647058825, 0.6105275588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 25}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 164}], {
             RGBColor[
             0.6485839411764706, 0.7197705294117647, 0.9688834705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 180}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 205}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 259}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529414, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 316}], {
             RGBColor[
             0.5539096176470588, 0.6257657352941176, 0.9632903823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 331}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 348}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 372}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 404}], {
             RGBColor[
             0.9030825588235294, 0.7408720588235296, 0.606192794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 418}], {
             RGBColor[
             0.9030825588235294, 0.7408720588235296, 0.606192794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 431}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 444}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 40}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 161}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 188}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 202}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 243}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 273}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 279}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 283}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 285}], {
             RGBColor[
             0.961070411764706, 0.8776436470588238, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 318}], {
             RGBColor[
             0.6717916764705882, 0.7108864117647059, 0.6516313529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 335}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 396}], {
             RGBColor[
             0.6717916764705882, 0.7108864117647059, 0.6516313529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 421}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 430}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 459}], {
             RGBColor[
             0.961070411764706, 0.8776436470588238, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 477}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 21}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 59}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 77}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.6083467058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 87}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 161}], {
             RGBColor[
             0.9674696176470589, 0.908133823529412, 0.561427411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 188}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 228}], {
             RGBColor[
             0.9285733529411766, 0.7545241764705886, 0.26138664705882364`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 243}], {
             RGBColor[
             0.961070411764706, 0.8776436470588238, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 256}], {
             RGBColor[
             0.961070411764706, 0.8776436470588238, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 279}], {
             RGBColor[
             0.7779159705882353, 0.7601848823529413, 0.6192203235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 285}], {
             RGBColor[
             0.9468331176470589, 0.8269180588235298, 0.27607888235294126`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 287}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.6083467058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 298}], {
             RGBColor[
             0.9674696176470589, 0.908133823529412, 0.561427411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 335}], {
             RGBColor[
             0.8416144411764706, 0.8104576470588236, 0.6252197941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 354}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.6083467058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 409}], {
             RGBColor[
             0.961070411764706, 0.8776436470588238, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 430}], {
             RGBColor[
             0.961070411764706, 0.8776436470588238, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 477}], {
             RGBColor[
             0.7779159705882353, 0.7601848823529413, 0.6192203235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 80}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 159}], {
             RGBColor[
             0.7254329117647058, 0.7567438823529412, 0.6552161764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 166}], {
             RGBColor[
             0.6717916764705882, 0.7108864117647059, 0.6516313529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 192}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 239}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 251}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 272}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 435}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 447}], {
             RGBColor[
             0.5771173529411765, 0.6168816176470588, 0.6460382647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 453}], {
             RGBColor[
             0.9262902941176471, 0.7319879411764708, 0.2889406764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 454}], {
             RGBColor[
             0.6229358235294118, 0.6650397352941178, 0.6486475588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 489}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 50}], {
             RGBColor[
             0.5739184117647059, 0.46865844117647076`, 0.579012705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 82}], {
             RGBColor[
             0.5280999411764706, 0.4205003235294119, 0.5764034117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 126}], {
             RGBColor[0.9326895, 0.762478117647059, 0.5330408823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 149}], {
             RGBColor[
             0.9361957058823529, 0.7637870000000002, 0.464683029411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 173}], {
             RGBColor[
             0.5280999411764706, 0.4205003235294119, 0.5764034117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 242}], {
             RGBColor[
             0.9030825588235294, 0.7408720588235296, 0.606192794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 249}], {
             RGBColor[0.9326895, 0.762478117647059, 0.5330408823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 269}], {
             RGBColor[
             0.9221748529411764, 0.7552865882352944, 0.5799601764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 282}], {
             RGBColor[0.9326895, 0.762478117647059, 0.5330408823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 323}], {
             RGBColor[
             0.9352148823529411, 0.761689117647059, 0.35792644117647054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 414}], {
             RGBColor[0.9326895, 0.762478117647059, 0.5330408823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 419}], {
             RGBColor[
             0.9352148823529411, 0.761689117647059, 0.35792644117647054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 449}], {
             RGBColor[
             0.7431358529411765, 0.6145291764705885, 0.590833794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 499}], {
             RGBColor[0.6227742647058824, 0.514505117647059, 0.5819965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 17}], {
             RGBColor[
             0.599728088235294, 0.6739238529411764, 0.9658996764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 116}], {
             RGBColor[
             0.3194197941176471, 0.4475569117647059, 0.9417033823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 143}], {
             RGBColor[
             0.6188203823529412, 0.6883383823529412, 0.9396670588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 165}], {
             RGBColor[
             0.5034798529411765, 0.5978537352941176, 0.9565401470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 185}], {
             RGBColor[
             0.6328412352941177, 0.696838794117647, 0.8243899117647061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.6188203823529412, 0.6883383823529412, 0.9396670588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 224}], {
             RGBColor[
             0.4397813823529412, 0.5475809705882353, 0.9505406764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 277}], {
             RGBColor[0.5588875, 0.6413586764705882, 0.9620042647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 313}], {
             RGBColor[
             0.6229358235294118, 0.6650397352941178, 0.6486475588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 333}], {
             RGBColor[
             0.631860411764706, 0.6947409117647059, 0.7176333235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 358}], {
             RGBColor[
             0.6188203823529412, 0.6883383823529412, 0.9396670588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 361}], {
             RGBColor[
             0.6328412352941177, 0.696838794117647, 0.8243899117647061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 386}], {
             RGBColor[
             0.6328412352941177, 0.696838794117647, 0.8243899117647061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 441}], {
             RGBColor[
             0.631860411764706, 0.6947409117647059, 0.7176333235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 89}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 116}], {
             RGBColor[
             0.6485839411764706, 0.7197705294117647, 0.9688834705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 143}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 165}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 176}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 178}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 261}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 277}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 288}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 313}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 321}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 328}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 386}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 391}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 407}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 455}], {
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 498}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058825, 0.6345793235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 28}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 93}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 160}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 167}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 172}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 201}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 218}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 235}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 274}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 300}], {
             RGBColor[
             0.7918034117647059, 0.8375021764705881, 0.9798248235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 305}], {
             RGBColor[
             0.8416144411764706, 0.8104576470588236, 0.625219794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 310}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 406}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 432}], {
             RGBColor[
             0.7913583235294117, 0.5755227058823531, 0.5831754705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 460}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 493}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 26}], {
             RGBColor[
             0.7111956176470589, 0.7060182941176472, 0.6139678529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 59}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.830958529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 67}], {
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 124}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.830958529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 188}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.830958529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 200}], {
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 228}], {
             RGBColor[
             0.6929358529411764, 0.6336244117647061, 0.5992756176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 298}], {
             RGBColor[
             0.7318321176470588, 0.7872340588235294, 0.8993163823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 318}], {
             RGBColor[0.4219168823529411, 0.5392610588235294, 0.948272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 335}], {
             RGBColor[
             0.6059769411764705, 0.6895578823529411, 0.9631087647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 459}], {
             RGBColor[
             0.7111956176470589, 0.7060182941176472, 0.6139678529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 468}], {
             RGBColor[
             0.3272425588235294, 0.4452562647058823, 0.9426789117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 25}], {
             RGBColor[
             0.672697294117647, 0.7437244705882353, 0.9683612352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 46}], {
             RGBColor[
             0.7596562058823529, 0.6877910000000003, 0.6045280882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 150}], {
             RGBColor[
             0.7131589117647059, 0.41378935294117647`, 0.5632898823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 220}], {
             RGBColor[
             0.7431358529411765, 0.6145291764705885, 0.5908337941176471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 325}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 388}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 392}], {
             RGBColor[
             0.7281049411764706, 0.7872294117647058, 0.9738253529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 413}], {
             RGBColor[
             0.3939629117647059, 0.4994228529411765, 0.9479313823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 473}], {
             RGBColor[
             0.7779159705882353, 0.7601848823529413, 0.6192203235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 474}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 490}], {
             RGBColor[
             0.5422784705882352, 0.6392851176470589, 0.9571092941176471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 55}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 59}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 77}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 91}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.830958529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 188}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 200}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 228}], {
             RGBColor[
             0.9527160588235295, 0.837048823529412, 0.47837732352941204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 256}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 287}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 298}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 335}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 336}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 354}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 409}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 24}], {
             RGBColor[
             0.6575543823529413, 0.660160823529412, 0.6103830294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 52}], {
             RGBColor[
             0.6676762352941177, 0.7341850588235295, 0.9426508529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 170}], {
             RGBColor[
             0.6816970882352942, 0.7426854705882353, 0.8273737058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 214}], {
             RGBColor[
             0.6676762352941177, 0.7341850588235295, 0.9426508529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 268}], {
             RGBColor[
             0.6676762352941177, 0.7341850588235295, 0.9426508529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 466}], {
             RGBColor[
             0.6575543823529413, 0.660160823529412, 0.6103830294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 491}], {
             RGBColor[
             0.6575543823529413, 0.660160823529412, 0.6103830294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 39}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 51}], {
             RGBColor[
             0.7281049411764706, 0.7872294117647058, 0.9738253529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 62}], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 96}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 110}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 136}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 157}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 240}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 360}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 52}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.6083467058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 64}], {
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058825, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 115}], {
             RGBColor[
             0.8970220882352942, 0.8539625882352943, 0.6306839117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 170}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 223}], {
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 268}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.6083467058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 491}], {
             RGBColor[
             0.9468331176470589, 0.8269180588235298, 0.27607888235294126`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 164}], {
             RGBColor[
             0.5523357058823529, 0.6437004117647058, 0.9595239411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.7918034117647059, 0.8375021764705881, 0.9798248235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 220}], {
             RGBColor[
             0.8068343235294118, 0.6648019411764707, 0.5968332647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 316}], {
             RGBColor[
             0.4576613823529412, 0.5496956176470588, 0.9539308529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 325}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 392}], {
             RGBColor[
             0.7918034117647059, 0.8375021764705881, 0.9798248235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 413}], {
             RGBColor[
             0.4576613823529412, 0.5496956176470588, 0.9539308529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 474}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 490}], {
             RGBColor[
             0.6059769411764705, 0.6895578823529411, 0.9631087647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 67}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058825, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 124}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 318}], {
             RGBColor[
             0.6575543823529413, 0.660160823529412, 0.6103830294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 335}], {
             RGBColor[
             0.8416144411764706, 0.8104576470588236, 0.6252197941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 459}], {
             RGBColor[
             0.9468331176470589, 0.8269180588235298, 0.27607888235294126`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 29}], {
             RGBColor[
             0.7213174705882353, 0.7800425294117648, 0.9462356764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 65}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.830958529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 86}], {
             RGBColor[
             0.7213174705882353, 0.7800425294117648, 0.9462356764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 177}], {
             RGBColor[0.4219168823529411, 0.5392610588235294, 0.948272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 290}], {
             RGBColor[
             0.47555811764705874`, 0.5851185294117647, 0.9518568235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 297}], {
             RGBColor[
             0.6613845882352941, 0.7330628235294117, 0.9685728823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 350}], {
             RGBColor[0.6609395, 0.47108335294117665`, 0.5719235294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 412}], {
             RGBColor[
             0.7213174705882353, 0.7800425294117648, 0.9462356764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 484}], {
             RGBColor[
             0.7111956176470589, 0.7060182941176472, 0.6139678529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 490}], {
             RGBColor[
             0.47555811764705874`, 0.5851185294117647, 0.9518568235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 125}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 149}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 201}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 218}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 282}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 305}], {
             RGBColor[
             0.9674696176470589, 0.908133823529412, 0.561427411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 310}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 406}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 408}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 419}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 432}], {
             RGBColor[0.9172135, 0.6731988823529413, 0.5193830882352942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 493}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 46}], {
             RGBColor[
             0.938695205882353, 0.8285484117647062, 0.5936544705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 65}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 86}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 177}], {
             RGBColor[
             0.6676762352941177, 0.7341850588235295, 0.9426508529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 194}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 254}], {
             RGBColor[
             0.8921979117647059, 0.5545467647058824, 0.5524162647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 290}], {
             RGBColor[
             0.7213174705882353, 0.7800425294117648, 0.9462356764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 297}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 350}], {
             RGBColor[
             0.9066988529411765, 0.6660073529411767, 0.5663023823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 377}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 412}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 426}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 476}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 31}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 133}], {
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 191}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 311}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 366}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 405}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 423}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 429}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 465}], {
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 469}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 488}], {
             RGBColor[
             0.5860419411764706, 0.6465827941176471, 0.7150240294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 133}], {
             RGBColor[
             0.8970220882352942, 0.8539625882352943, 0.630683911764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 191}], {
             RGBColor[
             0.7918034117647059, 0.8375021764705881, 0.9798248235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 226}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 237}], {
             RGBColor[
             0.8787623235294117, 0.781568705882353, 0.6159916764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 311}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 366}], {
             RGBColor[
             0.7281049411764706, 0.7872294117647058, 0.9738253529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 405}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 429}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 472}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 488}], {
             RGBColor[
             0.5130690294117647, 0.5932005588235294, 0.9593949705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 66}], {
             RGBColor[
             0.9030825588235294, 0.7408720588235296, 0.606192794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 84}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529414, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 89}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 176}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 179}], {
             RGBColor[
             0.6485839411764706, 0.7197705294117647, 0.9688834705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 245}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 255}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 260}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 299}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 312}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 328}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 334}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 407}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 448}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 475}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 478}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 482}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 76}], {
             RGBColor[0.9172135, 0.6731988823529413, 0.5193830882352942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 111}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 160}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 175}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 182}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 237}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 241}], {
             RGBColor[
             0.6781908823529412, 0.7413765882352942, 0.8957315588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 274}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 351}], {
             RGBColor[
             0.7318321176470588, 0.7872340588235294, 0.8993163823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 371}], {
             RGBColor[
             0.7318321176470588, 0.7872340588235294, 0.8993163823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 432}], {
             RGBColor[0.9172135, 0.6731988823529413, 0.5193830882352942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 460}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 463}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 44}], {
             RGBColor[
             0.6781908823529412, 0.7413765882352942, 0.8957315588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 62}], {
             RGBColor[
             0.6077433529411764, 0.6872053529411765, 0.9649880588235293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 190}], {
             RGBColor[
             0.6717916764705882, 0.7108864117647059, 0.6516313529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 291}], {
             RGBColor[
             0.6485839411764706, 0.7197705294117647, 0.9688834705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 356}], {
             RGBColor[0.4219168823529411, 0.5392610588235294, 0.948272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 394}], {
             RGBColor[
             0.6717916764705882, 0.7108864117647059, 0.6516313529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 467}], {
             RGBColor[
             0.6575543823529413, 0.660160823529412, 0.6103830294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.9262902941176471, 0.7319879411764708, 0.2889406764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 123}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 193}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 347}], {
             RGBColor[
             0.7254329117647058, 0.7567438823529412, 0.6552161764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 410}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 422}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 428}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 437}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 75}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 76}], {
             RGBColor[
             0.920719705882353, 0.6745077647058826, 0.45102523529411787`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 104}], {
             RGBColor[
             0.9361957058823529, 0.7637870000000002, 0.464683029411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 112}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 266}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.830958529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 359}], {
             RGBColor[
             0.5870227647058823, 0.6486806764705882, 0.821780617647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 379}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 408}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 440}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 463}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 49}], {
             RGBColor[
             0.6318604117647059, 0.6947409117647059, 0.7176333235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 53}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 97}], {
             RGBColor[
             0.6807162647058824, 0.7405875882352941, 0.7206171176470587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 100}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 203}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 207}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 257}], {
             RGBColor[
             0.9197388823529412, 0.6724098823529414, 0.34426864705882343`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 264}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 281}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 317}], {
             RGBColor[
             0.6318604117647059, 0.6947409117647059, 0.7176333235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 322}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 324}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 343}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 374}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764708, 0.3716207352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 397}], {
             RGBColor[
             0.9197388823529412, 0.6724098823529414, 0.34426864705882343`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 445}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 77}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 79}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 87}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 127}], {
             RGBColor[
             0.6816970882352942, 0.7426854705882353, 0.8273737058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 184}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 221}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 253}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 287}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 301}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 316}], {
             RGBColor[
             0.5870227647058823, 0.6486806764705882, 0.821780617647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 336}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 354}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 388}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 436}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 473}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 62}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 96}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 108}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 113}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 157}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 190}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 378}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 161}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 183}], {
             RGBColor[
             0.4886372352941176, 0.5934276470588236, 0.9535244705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 202}], {
             RGBColor[
             0.7880378235294117, 0.8342091176470589, 0.9514881470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 206}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 243}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 273}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 283}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 285}], {
             RGBColor[
             0.7779159705882353, 0.7601848823529413, 0.6192203235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 396}], {
             RGBColor[
             0.4886372352941176, 0.5934276470588236, 0.9535244705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 421}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 430}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 477}], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 44}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 56}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 132}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529414, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 356}], {
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 365}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 457}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 485}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 494}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 108}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 113}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 119}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 315}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 364}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 378}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 380}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 381}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 416}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 452}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 468}], {
             RGBColor[
             0.5835165588235294, 0.6473717941176471, 0.8901384705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 487}], {
             RGBColor[
             0.6781908823529412, 0.7413765882352942, 0.8957315588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 137}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 148}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 156}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 227}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 229}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 250}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 263}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 267}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 393}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 485}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 56}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 62}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 92}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 110}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 132}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 157}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 356}], {
             RGBColor[
             0.7318321176470588, 0.7872340588235294, 0.8993163823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 360}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 365}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 457}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 494}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 118}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 152}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 185}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 187}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 195}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 216}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 217}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 224}], {
             RGBColor[
             0.7880378235294117, 0.8342091176470589, 0.9514881470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 292}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 328}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 398}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 399}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 464}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 481}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 496}], {
             RGBColor[
             0.7880378235294117, 0.8342091176470589, 0.9514881470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 86}], {
             RGBColor[
             0.938695205882353, 0.8285484117647062, 0.5936544705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 142}], {
             RGBColor[
             0.8783172352941178, 0.519589235294118, 0.21934232352941183`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 150}], {
             RGBColor[
             0.863816294117647, 0.40812864705882373`, 0.20545620588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 194}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764708, 0.3716207352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 220}], {
             RGBColor[
             0.8937932352941177, 0.6088684705882357, 0.2330001176470589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 254}], {
             RGBColor[
             0.863816294117647, 0.40812864705882373`, 0.20545620588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 297}], {
             RGBColor[
             0.8787623235294117, 0.781568705882353, 0.6159916764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 325}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 350}], {
             RGBColor[
             0.8783172352941178, 0.519589235294118, 0.21934232352941183`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 377}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 392}], {
             RGBColor[
             0.8787623235294117, 0.781568705882353, 0.6159916764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 412}], {
             RGBColor[
             0.938695205882353, 0.8285484117647062, 0.5936544705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 426}], {
             RGBColor[
             0.8233546764705882, 0.7380637647058825, 0.6105275588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 476}], {
             RGBColor[
             0.9527160588235295, 0.837048823529412, 0.47837732352941204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 55}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 59}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 73}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 91}], {
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 136}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 200}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 228}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764708, 0.3716207352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 256}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 298}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 416}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 452}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 468}], {
             RGBColor[
             0.5860419411764706, 0.6465827941176471, 0.7150240294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 117}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 140}], {
             RGBColor[
             0.938695205882353, 0.8285484117647062, 0.5936544705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 155}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 156}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 198}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 250}], {
             RGBColor[
             0.7880378235294117, 0.8342091176470589, 0.9514881470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 365}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 479}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 51}], {
             RGBColor[
             0.4397813823529412, 0.5475809705882353, 0.9505406764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 100}], {
             RGBColor[
             0.6229358235294118, 0.6650397352941178, 0.6486475588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 203}], {
             RGBColor[
             0.6328412352941177, 0.696838794117647, 0.8243899117647061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 264}], {
             RGBColor[
             0.4397813823529412, 0.5475809705882353, 0.9505406764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 324}], {
             RGBColor[
             0.5034798529411765, 0.5978537352941176, 0.9565401470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 360}], {
             RGBColor[
             0.6328412352941177, 0.696838794117647, 0.8243899117647061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 397}], {
             RGBColor[
             0.558442411764706, 0.37937920588235313`, 0.5653549117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 457}], {
             RGBColor[
             0.631860411764706, 0.6947409117647059, 0.7176333235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 82}], {
             RGBColor[
             0.2247454705882353, 0.35355211764705885`, 0.9361102941176471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 126}], {
             RGBColor[
             0.6293350294117648, 0.6955299117647059, 0.8927477647058825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 131}], {
             RGBColor[
             0.6328412352941177, 0.696838794117647, 0.8243899117647061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 173}], {
             RGBColor[
             0.2247454705882353, 0.35355211764705885`, 0.9361102941176471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 242}], {
             RGBColor[
             0.599728088235294, 0.6739238529411764, 0.9658996764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 323}], {
             RGBColor[
             0.631860411764706, 0.6947409117647059, 0.7176333235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 340}], {
             RGBColor[
             0.6188203823529412, 0.6883383823529412, 0.9396670588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 373}], {
             RGBColor[
             0.6188203823529412, 0.6883383823529412, 0.9396670588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 414}], {
             RGBColor[
             0.6293350294117648, 0.6955299117647059, 0.8927477647058825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 449}], {
             RGBColor[
             0.4397813823529412, 0.5475809705882353, 0.9505406764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 499}], {
             RGBColor[
             0.3194197941176471, 0.4475569117647059, 0.9417033823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 60}], {
             RGBColor[
             0.4397813823529412, 0.5475809705882353, 0.9505406764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 96}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 100}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 110}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 203}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 240}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 264}], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 324}], {
             RGBColor[
             0.672697294117647, 0.7437244705882353, 0.9683612352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 360}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 397}], {
             RGBColor[0.7276598529411764, 0.5252499411764708, 0.577176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 457}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 495}], {
             RGBColor[
             0.7281049411764706, 0.7872294117647058, 0.9738253529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 170}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 214}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 268}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 466}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 491}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 83}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 97}], {
             RGBColor[
             0.6485839411764706, 0.7197705294117647, 0.9688834705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 112}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 163}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 207}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 257}], {
             RGBColor[0.8876065588235293, 0.651592823529412, 0.592535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 266}], {
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 281}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 317}], {
             RGBColor[
             0.5997280882352941, 0.6739238529411764, 0.9658996764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 322}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 343}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 374}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529414, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 440}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 445}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 471}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 61}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 99}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 154}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 186}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 203}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 244}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 264}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 295}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 321}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 341}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 374}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 391}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 397}], {
             RGBColor[0.9172135, 0.6731988823529413, 0.5193830882352942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 455}], {
             RGBColor[
             0.7318321176470588, 0.7872340588235294, 0.8993163823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 57}], {
             RGBColor[
             0.6485839411764706, 0.7197705294117647, 0.9688834705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 60}], {
             RGBColor[
             0.5997280882352941, 0.6739238529411764, 0.9658996764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 73}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 91}], {
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 136}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 200}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 256}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 298}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 434}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 92}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 110}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 132}], {
             RGBColor[
             0.8787623235294117, 0.781568705882353, 0.6159916764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 324}], {
             RGBColor[
             0.7918034117647059, 0.8375021764705881, 0.9798248235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 342}], {
             RGBColor[0.5588875, 0.6413586764705882, 0.9620042647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 360}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 457}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 494}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 60}], {
             RGBColor[
             0.3194197941176471, 0.4475569117647059, 0.9417033823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 73}], {
             RGBColor[
             0.6807162647058824, 0.7405875882352941, 0.7206171176470587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 91}], {
             RGBColor[0.4219168823529411, 0.5392610588235294, 0.948272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 131}], {
             RGBColor[
             0.6816970882352942, 0.7426854705882353, 0.8273737058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 136}], {
             RGBColor[
             0.6781908823529412, 0.7413765882352942, 0.8957315588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 234}], {
             RGBColor[
             0.6816970882352942, 0.7426854705882353, 0.8273737058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 240}], {
             RGBColor[
             0.6781908823529412, 0.7413765882352942, 0.8957315588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 434}], {
             RGBColor[
             0.6717916764705882, 0.7108864117647059, 0.6516313529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 495}], {
             RGBColor[
             0.6077433529411764, 0.6872053529411765, 0.9649880588235293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 74}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 115}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 144}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 145}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764708, 0.3716207352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 215}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 375}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 402}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 417}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764708, 0.3716207352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 87}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 91}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.830958529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 188}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 200}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 228}], {
             RGBColor[
             0.9527160588235295, 0.837048823529412, 0.47837732352941204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 256}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 279}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 287}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 298}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 335}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 409}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 468}], {
             RGBColor[
             0.5870227647058823, 0.6486806764705882, 0.821780617647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 73}], {
             RGBColor[
             0.631860411764706, 0.6947409117647059, 0.7176333235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 131}], {
             RGBColor[
             0.6328412352941177, 0.696838794117647, 0.8243899117647061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.6293350294117648, 0.6955299117647059, 0.8927477647058825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 240}], {
             RGBColor[
             0.6293350294117648, 0.6955299117647059, 0.8927477647058825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 434}], {
             RGBColor[
             0.6229358235294118, 0.6650397352941178, 0.6486475588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 495}], {
             RGBColor[0.5588875, 0.6413586764705882, 0.9620042647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 99}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 154}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 178}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 186}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 203}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 244}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 264}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 288}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 295}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 321}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 341}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 391}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 397}], {
             RGBColor[0.9172135, 0.6731988823529413, 0.5193830882352942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 455}], {
             RGBColor[
             0.7318321176470588, 0.7872340588235294, 0.8993163823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 96}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 108}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 110}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 157}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 190}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 356}], {
             RGBColor[
             0.6613845882352941, 0.7330628235294117, 0.9685728823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 378}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 72}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 159}], {
             RGBColor[
             0.7318321176470588, 0.7872340588235294, 0.8993163823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 166}], {
             RGBColor[
             0.6781908823529412, 0.7413765882352942, 0.8957315588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 222}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 239}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 272}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 344}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 387}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 435}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 439}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 453}], {
             RGBColor[0.9326895, 0.762478117647059, 0.5330408823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 74}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 115}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 170}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 215}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 223}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 268}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 86}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 177}], {
             RGBColor[
             0.6816970882352942, 0.7426854705882353, 0.8273737058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 194}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 290}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.830958529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 297}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 350}], {
             RGBColor[
             0.920719705882353, 0.6745077647058826, 0.45102523529411787`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 412}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 484}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 114}], {
             RGBColor[
             0.9030825588235294, 0.7408720588235296, 0.606192794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 128}], {
             RGBColor[
             0.9361957058823529, 0.7637870000000002, 0.464683029411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 179}], {
             RGBColor[0.6227742647058824, 0.514505117647059, 0.5819965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 245}], {
             RGBColor[
             0.9361957058823529, 0.7637870000000002, 0.464683029411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 255}], {
             RGBColor[0.9326895, 0.762478117647059, 0.5330408823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 260}], {
             RGBColor[
             0.9030825588235294, 0.7408720588235296, 0.606192794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 294}], {
             RGBColor[0.9326895, 0.762478117647059, 0.5330408823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 299}], {
             RGBColor[
             0.9262902941176471, 0.7319879411764708, 0.2889406764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 312}], {
             RGBColor[
             0.8622419705882354, 0.7083068823529413, 0.6022973823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 327}], {
             RGBColor[
             0.9221748529411764, 0.7552865882352944, 0.5799601764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 334}], {
             RGBColor[0.9326895, 0.762478117647059, 0.5330408823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 385}], {
             RGBColor[
             0.9352148823529411, 0.761689117647059, 0.35792644117647054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 415}], {
             RGBColor[
             0.9352148823529411, 0.761689117647059, 0.35792644117647054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 446}], {
             RGBColor[
             0.7431358529411765, 0.6145291764705885, 0.590833794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 119}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 120}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 124}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 363}], {
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 381}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 95}], {
             RGBColor[
             0.6717916764705882, 0.7108864117647059, 0.6516313529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 286}], {
             RGBColor[
             0.6392946176470589, 0.5877669411764708, 0.595690794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 319}], {
             RGBColor[
             0.6077433529411764, 0.6872053529411765, 0.9649880588235293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 330}], {
             RGBColor[
             0.6077433529411764, 0.6872053529411765, 0.9649880588235293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 352}], {
             RGBColor[
             0.6676762352941177, 0.7341850588235295, 0.9426508529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 357}], {
             RGBColor[
             0.6781908823529412, 0.7413765882352942, 0.8957315588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 367}], {
             RGBColor[
             0.6717916764705882, 0.7108864117647059, 0.6516313529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 368}], {
             RGBColor[
             0.6676762352941177, 0.7341850588235295, 0.9426508529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 375}], {
             RGBColor[
             0.6807162647058824, 0.7405875882352941, 0.7206171176470587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 450}], {
             RGBColor[
             0.4886372352941176, 0.5934276470588236, 0.9535244705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 492}], {
             RGBColor[
             0.6717916764705882, 0.7108864117647059, 0.6516313529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 101}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 103}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 129}], {
             RGBColor[
             0.5870227647058823, 0.6486806764705882, 0.821780617647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 204}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 209}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 231}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 233}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 259}], {
             RGBColor[
             0.9527160588235295, 0.837048823529412, 0.47837732352941204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 275}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 306}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 331}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 346}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 348}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 355}], {
             RGBColor[
             0.6328412352941176, 0.696838794117647, 0.8243899117647061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 372}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 404}], {
             RGBColor[
             0.9361957058823529, 0.7637870000000002, 0.464683029411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 418}], {
             RGBColor[
             0.9361957058823529, 0.7637870000000002, 0.464683029411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 431}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 444}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 486}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 76}], {
             RGBColor[
             0.9066988529411765, 0.6660073529411767, 0.5663023823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 111}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 130}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 175}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 182}], {
             RGBColor[
             0.938695205882353, 0.8285484117647062, 0.5936544705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 208}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 351}], {
             RGBColor[
             0.7213174705882353, 0.7800425294117648, 0.9462356764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 359}], {
             RGBColor[
             0.5730019117647058, 0.6401802647058824, 0.9370577647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 371}], {
             RGBColor[
             0.7213174705882353, 0.7800425294117648, 0.9462356764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 403}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 442}], {
             RGBColor[
             0.9221748529411764, 0.7552865882352944, 0.5799601764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 463}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 483}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 135}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 153}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 169}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529414, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 172}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 197}], {
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 201}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 211}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058825, 0.6345793235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 236}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 289}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 308}], {
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 362}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 369}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 466}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058825, 0.6345793235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 470}], {
             RGBColor[0.8876065588235293, 0.651592823529412, 0.592535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 493}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 128}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 159}], {
             RGBColor[
             0.6613845882352941, 0.7330628235294117, 0.9685728823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 179}], {
             RGBColor[
             0.6077433529411764, 0.6872053529411765, 0.9649880588235293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 222}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 245}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 294}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 344}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 438}], {
             RGBColor[
             0.7281049411764706, 0.7872294117647058, 0.9738253529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 439}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 453}], {
             RGBColor[
             0.8622419705882354, 0.7083068823529413, 0.6022973823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 91}], {
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 136}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 200}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 240}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 256}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 298}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 434}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 115}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 144}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 215}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 268}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 402}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 417}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529414, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 104}], {
             RGBColor[
             0.9262902941176471, 0.7319879411764708, 0.2889406764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 125}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 147}], {
             RGBColor[
             0.7254329117647058, 0.7567438823529412, 0.6552161764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 303}], {
             RGBColor[
             0.9262902941176471, 0.7319879411764708, 0.2889406764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 310}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 323}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 379}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 400}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 408}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 111}], {
             RGBColor[
             0.9066988529411765, 0.6660073529411767, 0.5663023823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 130}], {
             RGBColor[
             0.9108142941176471, 0.6427087058823532, 0.2752828823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 175}], {
             RGBColor[
             0.8467659705882353, 0.6190276470588236, 0.5886395882352942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.8783172352941178, 0.519589235294118, 0.21934232352941183`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 351}], {
             RGBColor[0.6609395, 0.47108335294117665`, 0.5719235294117648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 359}], {
             RGBColor[
             0.5126239411764706, 0.3312210882352943, 0.5627456176470589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 371}], {
             RGBColor[0.6609395, 0.47108335294117665`, 0.5719235294117648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 460}], {
             RGBColor[
             0.9108142941176471, 0.6427087058823532, 0.2752828823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 463}], {
             RGBColor[0.8876065588235293, 0.651592823529412, 0.592535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 483}], {
             RGBColor[0.8876065588235293, 0.651592823529412, 0.592535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 87}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 184}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 253}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 287}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 301}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 336}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 354}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 388}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 409}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 436}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 473}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 154}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 171}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 192}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764708, 0.3716207352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 219}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 258}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 262}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 376}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 497}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764708, 0.3716207352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 127}], {
             RGBColor[
             0.6717916764705882, 0.7108864117647059, 0.6516313529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 147}], {
             RGBColor[
             0.7254329117647058, 0.7567438823529412, 0.6552161764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 184}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 221}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 234}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 253}], {
             RGBColor[
             0.961070411764706, 0.8776436470588238, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 301}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 316}], {
             RGBColor[
             0.5771173529411765, 0.6168816176470588, 0.6460382647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 336}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 388}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 436}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 81}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 171}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 192}], {
             RGBColor[
             0.9527160588235295, 0.837048823529412, 0.47837732352941204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 208}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 219}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 238}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 251}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 258}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 272}], {
             RGBColor[
             0.9527160588235295, 0.837048823529412, 0.47837732352941204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 293}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 403}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 447}], {
             RGBColor[
             0.5870227647058823, 0.6486806764705882, 0.821780617647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 471}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 483}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 497}], {
             RGBColor[
             0.9527160588235295, 0.837048823529412, 0.47837732352941204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 121}], {
             RGBColor[
             0.5997280882352941, 0.6739238529411764, 0.9658996764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 208}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 213}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 251}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 442}], {
             RGBColor[
             0.9030825588235294, 0.7408720588235296, 0.606192794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 447}], {
             RGBColor[
             0.5539096176470588, 0.6257657352941176, 0.9632903823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 454}], {
             RGBColor[
             0.5997280882352941, 0.6739238529411764, 0.9658996764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 500}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 126}], {
             RGBColor[
             0.5835165588235294, 0.6473717941176471, 0.8901384705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 149}], {
             RGBColor[
             0.5870227647058823, 0.6486806764705881, 0.821780617647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 173}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 242}], {
             RGBColor[
             0.5539096176470588, 0.6257657352941177, 0.9632903823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 249}], {
             RGBColor[
             0.5835165588235294, 0.6473717941176471, 0.8901384705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 269}], {
             RGBColor[
             0.5730019117647058, 0.6401802647058823, 0.9370577647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 282}], {
             RGBColor[
             0.5835165588235294, 0.6473717941176471, 0.8901384705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 323}], {
             RGBColor[
             0.5860419411764706, 0.6465827941176472, 0.7150240294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 384}], {
             RGBColor[
             0.5730019117647058, 0.6401802647058823, 0.9370577647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 411}], {
             RGBColor[
             0.5835165588235294, 0.6473717941176471, 0.8901384705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 419}], {
             RGBColor[
             0.5860419411764706, 0.6465827941176472, 0.7150240294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 499}], {
             RGBColor[
             0.2736013235294118, 0.39939879411764706`, 0.9390940882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 97}], {
             RGBColor[
             0.5523357058823529, 0.6437004117647058, 0.9595239411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 163}], {
             RGBColor[
             0.7918034117647059, 0.8375021764705881, 0.9798248235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 207}], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 209}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 231}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 233}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 257}], {
             RGBColor[
             0.7913583235294117, 0.5755227058823531, 0.5831754705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 317}], {
             RGBColor[
             0.5034798529411765, 0.5978537352941176, 0.9565401470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 326}], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 343}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 346}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 355}], {
             RGBColor[
             0.5034798529411765, 0.5978537352941176, 0.9565401470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 395}], {
             RGBColor[
             0.5523357058823529, 0.6437004117647058, 0.9595239411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 440}], {
             RGBColor[
             0.7918034117647059, 0.8375021764705881, 0.9798248235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 89}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 176}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 244}], {
             RGBColor[
             0.9527160588235295, 0.837048823529412, 0.47837732352941204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 245}], {
             RGBColor[
             0.9527160588235295, 0.837048823529412, 0.47837732352941204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 260}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529414, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 261}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529414, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 262}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529414, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 299}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 328}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 376}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764708, 0.3716207352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 391}], {
             RGBColor[
             0.8233546764705882, 0.7380637647058825, 0.6105275588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 407}], {
             RGBColor[
             0.8787623235294117, 0.781568705882353, 0.6159916764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 448}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764708, 0.3716207352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 455}], {
             RGBColor[
             0.6929358529411764, 0.6336244117647061, 0.5992756176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 475}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529414, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 478}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 482}], {
             RGBColor[
             0.9527160588235295, 0.837048823529412, 0.47837732352941204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 146}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 166}], {
             RGBColor[
             0.6717916764705882, 0.7108864117647059, 0.6516313529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 239}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 332}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 387}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 489}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 177}], {
             RGBColor[
             0.6676762352941177, 0.7341850588235295, 0.9426508529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 194}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 220}], {
             RGBColor[
             0.9221748529411764, 0.7552865882352944, 0.5799601764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 254}], {
             RGBColor[
             0.8921979117647059, 0.5545467647058824, 0.5524162647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 290}], {
             RGBColor[
             0.7213174705882353, 0.7800425294117648, 0.9462356764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 297}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 350}], {
             RGBColor[
             0.9066988529411765, 0.6660073529411767, 0.5663023823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 377}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 412}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 426}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 476}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 91}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.830958529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 161}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 184}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 228}], {
             RGBColor[
             0.9527160588235295, 0.837048823529412, 0.47837732352941204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 253}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 256}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 285}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 287}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 336}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 354}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 388}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 409}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 436}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 473}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 133}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 241}], {
             RGBColor[
             0.6676762352941177, 0.7341850588235295, 0.9426508529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 271}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 304}], {
             RGBColor[
             0.938695205882353, 0.8285484117647062, 0.5936544705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 307}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 311}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 337}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 423}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 427}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 433}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 465}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 469}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 176}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 178}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 244}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 261}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 262}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 299}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 328}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 376}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 391}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 407}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 448}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 455}], {
             RGBColor[
             0.7318321176470588, 0.7872340588235294, 0.8993163823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 475}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 478}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 482}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 137}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 148}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 229}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 232}], {
             RGBColor[
             0.9674696176470589, 0.908133823529412, 0.561427411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 263}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 267}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 280}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 342}], {
             RGBColor[
             0.6293350294117647, 0.6955299117647059, 0.8927477647058825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 393}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 480}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 485}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 200}], {
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 228}], {
             RGBColor[
             0.6929358529411764, 0.6336244117647061, 0.5992756176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 256}], {
             RGBColor[
             0.7254329117647058, 0.7567438823529412, 0.6552161764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 287}], {
             RGBColor[
             0.7213174705882353, 0.7800425294117648, 0.9462356764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 298}], {
             RGBColor[
             0.7318321176470588, 0.7872340588235294, 0.8993163823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 336}], {
             RGBColor[
             0.7318321176470588, 0.7872340588235294, 0.8993163823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 132}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529414, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 250}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 342}], {
             RGBColor[
             0.5997280882352941, 0.6739238529411764, 0.9658996764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 356}], {
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 365}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 457}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 485}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 494}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 141}], {
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 151}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 160}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 167}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 172}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 201}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 218}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 235}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 236}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 274}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 284}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 289}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 300}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 305}], {
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 308}], {
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 389}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 432}], {
             RGBColor[
             0.9197388823529412, 0.6724098823529414, 0.34426864705882343`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 456}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 493}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 123}], {
             RGBColor[
             0.9262902941176471, 0.7319879411764708, 0.2889406764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 139}], {
             RGBColor[
             0.8937932352941177, 0.6088684705882357, 0.2330001176470589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 158}], {
             RGBColor[
             0.9352148823529411, 0.761689117647059, 0.35792644117647054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 193}], {
             RGBColor[
             0.7431358529411765, 0.6145291764705885, 0.590833794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 401}], {
             RGBColor[0.912053, 0.6812623529411768, 0.24769235294117653`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 410}], {
             RGBColor[0.9326895, 0.762478117647059, 0.5330408823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 428}], {
             RGBColor[0.9326895, 0.762478117647059, 0.5330408823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 437}], {
             RGBColor[
             0.9030825588235294, 0.7408720588235296, 0.606192794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 122}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 185}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 212}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 224}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 286}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 319}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 330}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 357}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 367}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 368}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 492}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 110}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 136}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 240}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 360}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 457}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 163}], {
             RGBColor[
             0.6077433529411764, 0.6872053529411765, 0.9649880588235293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 207}], {
             RGBColor[
             0.5523357058823529, 0.6437004117647058, 0.9595239411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 209}], {
             RGBColor[
             0.6717916764705882, 0.7108864117647059, 0.6516313529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 231}], {
             RGBColor[
             0.6485839411764706, 0.7197705294117647, 0.9688834705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 233}], {
             RGBColor[
             0.6717916764705882, 0.7108864117647059, 0.6516313529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 257}], {
             RGBColor[
             0.6072982647058824, 0.42522588235294134`, 0.5683387058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 281}], {
             RGBColor[
             0.6077433529411764, 0.6872053529411765, 0.9649880588235293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 317}], {
             RGBColor[
             0.3194197941176471, 0.4475569117647059, 0.9417033823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 322}], {
             RGBColor[
             0.6807162647058824, 0.7405875882352941, 0.7206171176470587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 326}], {
             RGBColor[
             0.5523357058823529, 0.6437004117647058, 0.9595239411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 343}], {
             RGBColor[
             0.6676762352941177, 0.7341850588235295, 0.9426508529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 355}], {
             RGBColor[
             0.3194197941176471, 0.4475569117647059, 0.9417033823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 395}], {
             RGBColor[
             0.36827564705882354`, 0.4934035882352941, 0.9446871764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 440}], {
             RGBColor[
             0.6077433529411764, 0.6872053529411765, 0.9649880588235293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 105}], {
             RGBColor[
             0.8068343235294118, 0.6648019411764707, 0.5968332647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 276}], {
             RGBColor[
             0.7431358529411765, 0.6145291764705885, 0.590833794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 347}], {
             RGBColor[0.6764155, 0.5603625882352943, 0.5855813235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 382}], {
             RGBColor[
             0.9361957058823529, 0.7637870000000002, 0.464683029411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 425}], {
             RGBColor[
             0.9221748529411764, 0.7552865882352944, 0.5799601764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 462}], {
             RGBColor[
             0.7431358529411765, 0.6145291764705885, 0.590833794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 131}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 143}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 178}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 186}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 277}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 288}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 295}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 313}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 321}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 341}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 373}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 498}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 203}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 257}], {
             RGBColor[
             0.9108142941176471, 0.6427087058823532, 0.2752828823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 264}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 281}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 324}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 360}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 374}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 397}], {
             RGBColor[
             0.9108142941176471, 0.6427087058823532, 0.2752828823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 457}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 103}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 129}], {
             RGBColor[
             0.5860419411764706, 0.6465827941176471, 0.7150240294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 276}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 306}], {
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 331}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 347}], {
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 390}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 431}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 486}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 134}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 174}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 210}], {
             RGBColor[
             0.6188203823529411, 0.6883383823529412, 0.9396670588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 225}], {
             RGBColor[
             0.9066988529411765, 0.6660073529411767, 0.5663023823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 247}], {
             RGBColor[
             0.6676762352941177, 0.7341850588235295, 0.9426508529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 252}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 278}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 309}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 383}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 393}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 451}], {
             RGBColor[
             0.5730019117647058, 0.6401802647058824, 0.9370577647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 480}], {
             RGBColor[
             0.938695205882353, 0.8285484117647062, 0.5936544705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 129}], {
             RGBColor[
             0.5835165588235294, 0.6473717941176471, 0.8901384705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 204}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 209}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 231}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 233}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 259}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 275}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 326}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 346}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 348}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 355}], {
             RGBColor[
             0.6293350294117647, 0.6955299117647059, 0.8927477647058825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 390}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 404}], {
             RGBColor[0.9326895, 0.762478117647059, 0.5330408823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 431}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 443}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 444}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 486}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 125}], {
             RGBColor[
             0.9030825588235294, 0.7408720588235296, 0.606192794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 147}], {
             RGBColor[0.6764155, 0.5603625882352943, 0.5855813235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 242}], {
             RGBColor[
             0.9030825588235294, 0.7408720588235296, 0.606192794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 303}], {
             RGBColor[
             0.8772728823529412, 0.5356066470588239, 0.21930582352941183`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 310}], {
             RGBColor[
             0.9221748529411764, 0.7552865882352944, 0.5799601764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 323}], {
             RGBColor[
             0.9352148823529411, 0.761689117647059, 0.35792644117647054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 379}], {
             RGBColor[
             0.9361957058823529, 0.7637870000000002, 0.464683029411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 408}], {
             RGBColor[
             0.7431358529411765, 0.6145291764705885, 0.590833794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 109}], {
             RGBColor[
             0.8233546764705882, 0.7380637647058825, 0.6105275588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 205}], {
             RGBColor[
             0.672697294117647, 0.7437244705882353, 0.9683612352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 230}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 382}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 425}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 462}], {
             RGBColor[
             0.672697294117647, 0.7437244705882353, 0.9683612352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 484}], {
             RGBColor[
             0.8416144411764706, 0.8104576470588236, 0.625219794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 156}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 227}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 265}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 270}], {
             RGBColor[
             0.7918034117647059, 0.8375021764705881, 0.9798248235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 329}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 479}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 153}], {
             RGBColor[
             0.7918034117647059, 0.8375021764705881, 0.9798248235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 170}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 197}], {
             RGBColor[
             0.6613845882352941, 0.7330628235294117, 0.9685728823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 214}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 223}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 236}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 289}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 314}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 411}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 466}], {
             RGBColor[
             0.8970220882352942, 0.8539625882352943, 0.630683911764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 470}], {
             RGBColor[
             0.8467659705882353, 0.6190276470588236, 0.5886395882352942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 113}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 190}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 315}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 349}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 364}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 378}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 380}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 416}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 452}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 487}], {
             RGBColor[
             0.6781908823529412, 0.7413765882352942, 0.8957315588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 164}], {
             RGBColor[
             0.6392946176470589, 0.5877669411764708, 0.595690794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 180}], {
             RGBColor[
             0.8787623235294117, 0.781568705882353, 0.6159916764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 205}], {
             RGBColor[
             0.7596562058823529, 0.6877910000000003, 0.6045280882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 230}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 382}], {
             RGBColor[
             0.9527160588235295, 0.837048823529412, 0.47837732352941204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 413}], {
             RGBColor[
             0.5446202941176471, 0.4937621470588237, 0.590097705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 474}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764708, 0.3716207352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 490}], {
             RGBColor[
             0.6929358529411764, 0.6336244117647061, 0.5992756176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 157}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 356}], {
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 360}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 457}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 494}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 130}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 175}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 182}], {
             RGBColor[
             0.938695205882353, 0.8285484117647062, 0.5936544705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 351}], {
             RGBColor[
             0.7213174705882353, 0.7800425294117648, 0.9462356764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 359}], {
             RGBColor[
             0.5730019117647058, 0.6401802647058824, 0.9370577647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 371}], {
             RGBColor[
             0.7213174705882353, 0.7800425294117648, 0.9462356764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 460}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 463}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 483}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 163}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 175}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 207}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 238}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 266}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.830958529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 293}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 317}], {
             RGBColor[
             0.6328412352941176, 0.696838794117647, 0.8243899117647061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 343}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 359}], {
             RGBColor[
             0.5870227647058823, 0.6486806764705882, 0.821780617647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 403}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 440}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 445}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 463}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 471}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 483}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 190}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 315}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 349}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 353}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 364}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 378}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 380}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 487}], {
             RGBColor[
             0.6485839411764706, 0.7197705294117647, 0.9688834705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 128}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 138}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 179}], {
             RGBColor[
             0.6485839411764706, 0.7197705294117647, 0.9688834705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 255}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 294}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 296}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 312}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 327}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 334}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 385}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 415}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 446}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 144}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 215}], {
             RGBColor[
             0.7281049411764706, 0.7872294117647058, 0.9738253529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 223}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 268}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 402}], {
             RGBColor[
             0.7918034117647059, 0.8375021764705881, 0.9798248235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 417}], {
             RGBColor[
             0.8787623235294117, 0.781568705882353, 0.6159916764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 143}], {
             RGBColor[
             0.6676762352941177, 0.7341850588235295, 0.9426508529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 165}], {
             RGBColor[
             0.5523357058823529, 0.6437004117647058, 0.9595239411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 185}], {
             RGBColor[
             0.6816970882352942, 0.7426854705882353, 0.8273737058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 187}], {
             RGBColor[
             0.6676762352941177, 0.7341850588235295, 0.9426508529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 224}], {
             RGBColor[
             0.4886372352941176, 0.5934276470588236, 0.9535244705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 277}], {
             RGBColor[
             0.6077433529411764, 0.6872053529411765, 0.9649880588235293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 313}], {
             RGBColor[
             0.6717916764705882, 0.7108864117647059, 0.6516313529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 333}], {
             RGBColor[
             0.6807162647058824, 0.7405875882352941, 0.7206171176470587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 358}], {
             RGBColor[
             0.6676762352941177, 0.7341850588235295, 0.9426508529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 361}], {
             RGBColor[
             0.6816970882352942, 0.7426854705882353, 0.8273737058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 386}], {
             RGBColor[
             0.6816970882352942, 0.7426854705882353, 0.8273737058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 441}], {
             RGBColor[
             0.6807162647058824, 0.7405875882352941, 0.7206171176470587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 140}], {
             RGBColor[
             0.8787623235294117, 0.781568705882353, 0.6159916764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 155}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 156}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 198}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 270}], {
             RGBColor[
             0.7918034117647059, 0.8375021764705881, 0.9798248235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 479}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 152}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 187}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 255}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 260}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 292}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 399}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 446}], {
             RGBColor[
             0.7880378235294117, 0.8342091176470589, 0.9514881470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 464}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 481}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 496}], {
             RGBColor[
             0.7880378235294117, 0.8342091176470589, 0.9514881470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 120}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 124}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 363}], {
             RGBColor[
             0.7318321176470588, 0.7872340588235294, 0.8993163823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 364}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 381}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 416}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 124}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 315}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 363}], {
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 381}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 196}], {
             RGBColor[
             0.6086985294117648, 0.6143141470588237, 0.6073992352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.599728088235294, 0.6739238529411764, 0.9658996764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 307}], {
             RGBColor[0.5588875, 0.6413586764705882, 0.9620042647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 337}], {
             RGBColor[0.5588875, 0.6413586764705882, 0.9620042647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 420}], {
             RGBColor[
             0.631860411764706, 0.6947409117647059, 0.7176333235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 427}], {
             RGBColor[
             0.6086985294117648, 0.6143141470588237, 0.6073992352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 442}], {
             RGBColor[
             0.5739184117647058, 0.46865844117647076`, 0.579012705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 447}], {
             RGBColor[
             0.2247454705882353, 0.35355211764705885`, 0.9361102941176471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 454}], {
             RGBColor[
             0.2705639411764706, 0.40171023529411765`, 0.9387195882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 489}], {
             RGBColor[
             0.6293350294117648, 0.6955299117647059, 0.8927477647058825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 500}], {
             RGBColor[
             0.6188203823529412, 0.6883383823529412, 0.9396670588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 185}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 212}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 216}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 217}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 224}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 286}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529414, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 319}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 330}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 357}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 492}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 139}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 158}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 193}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 401}], {
             RGBColor[
             0.961070411764706, 0.8776436470588238, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 410}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 422}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 428}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 437}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 363}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.830958529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 381}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 416}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 173}], {
             RGBColor[
             0.5539096176470588, 0.6257657352941176, 0.9632903823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 242}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 249}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 269}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 282}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 305}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058825, 0.6345793235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 310}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 323}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 406}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 408}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 419}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 173}], {
             RGBColor[
             0.5835165588235294, 0.6473717941176471, 0.8901384705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 249}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 269}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 282}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 340}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 384}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 414}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 449}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 499}], {
             RGBColor[
             0.6781908823529412, 0.7413765882352942, 0.8957315588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 184}], {
             RGBColor[
             0.6816970882352942, 0.7426854705882353, 0.8273737058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 221}], {
             RGBColor[
             0.6816970882352942, 0.7426854705882353, 0.8273737058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 253}], {
             RGBColor[
             0.6575543823529413, 0.660160823529412, 0.6103830294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 301}], {
             RGBColor[
             0.6485839411764706, 0.7197705294117647, 0.9688834705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 303}], {
             RGBColor[0.6227742647058824, 0.514505117647059, 0.5819965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 316}], {
             RGBColor[
             0.2736013235294118, 0.39939879411764706`, 0.9390940882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 138}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 179}], {
             RGBColor[
             0.6816970882352942, 0.7426854705882353, 0.8273737058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 222}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 245}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 294}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 296}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 312}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 385}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 415}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 438}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 439}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 204}], {
             RGBColor[
             0.5860419411764706, 0.6465827941176472, 0.7150240294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 275}], {
             RGBColor[
             0.5860419411764706, 0.6465827941176472, 0.7150240294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 276}], {
             RGBColor[
             0.3939629117647059, 0.4994228529411765, 0.9479313823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 306}], {
             RGBColor[
             0.5628800588235294, 0.5661560294117649, 0.6047899411764707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 331}], {
             RGBColor[
             0.5771173529411764, 0.6168816176470588, 0.6460382647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 346}], {
             RGBColor[
             0.5730019117647058, 0.6401802647058823, 0.9370577647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 348}], {
             RGBColor[
             0.5870227647058823, 0.6486806764705881, 0.821780617647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 355}], {
             RGBColor[
             0.2247454705882353, 0.35355211764705885`, 0.9361102941176471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 431}], {
             RGBColor[
             0.5860419411764706, 0.6465827941176472, 0.7150240294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 444}], {
             RGBColor[
             0.4576613823529411, 0.5496956176470588, 0.9539308529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 486}], {
             RGBColor[
             0.5835165588235294, 0.6473717941176471, 0.8901384705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 175}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 182}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 208}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 238}], {
             RGBColor[
             0.961070411764706, 0.8776436470588238, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 241}], {
             RGBColor[
             0.6717916764705882, 0.7108864117647059, 0.6516313529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 351}], {
             RGBColor[
             0.7254329117647058, 0.7567438823529412, 0.6552161764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 371}], {
             RGBColor[
             0.7254329117647058, 0.7567438823529412, 0.6552161764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 442}], {
             RGBColor[
             0.9262902941176471, 0.7319879411764708, 0.2889406764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 483}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 186}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 234}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 373}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 434}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 449}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 495}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 250}], {
             RGBColor[
             0.7596562058823529, 0.6877910000000003, 0.6045280882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 356}], {
             RGBColor[
             0.6929358529411764, 0.6336244117647061, 0.5992756176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 365}], {
             RGBColor[
             0.938695205882353, 0.8285484117647062, 0.5936544705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 457}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764708, 0.3716207352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 494}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529414, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 191}], {
             RGBColor[
             0.8416144411764706, 0.8104576470588236, 0.6252197941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 237}], {
             RGBColor[
             0.9285733529411766, 0.7545241764705886, 0.26138664705882364`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 241}], {
             RGBColor[
             0.6575543823529413, 0.660160823529412, 0.6103830294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 271}], {
             RGBColor[
             0.9674696176470589, 0.908133823529412, 0.561427411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 304}], {
             RGBColor[
             0.9285733529411766, 0.7545241764705886, 0.26138664705882364`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 311}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.6083467058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 351}], {
             RGBColor[
             0.7111956176470589, 0.7060182941176472, 0.6139678529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 366}], {
             RGBColor[
             0.7779159705882353, 0.7601848823529413, 0.6192203235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 371}], {
             RGBColor[
             0.7111956176470589, 0.7060182941176472, 0.6139678529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 405}], {
             RGBColor[
             0.9674696176470589, 0.908133823529412, 0.561427411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 423}], {
             RGBColor[
             0.9674696176470589, 0.908133823529412, 0.561427411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 429}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 469}], {
             RGBColor[
             0.8416144411764706, 0.8104576470588236, 0.6252197941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 488}], {
             RGBColor[
             0.5628800588235294, 0.5661560294117649, 0.6047899411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 174}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 210}], {
             RGBColor[
             0.6293350294117647, 0.6955299117647059, 0.8927477647058825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 225}], {
             RGBColor[0.9172135, 0.6731988823529413, 0.5193830882352942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 247}], {
             RGBColor[
             0.6781908823529412, 0.7413765882352942, 0.8957315588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 252}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 278}], {
             RGBColor[
             0.9674696176470589, 0.908133823529412, 0.561427411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 309}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 424}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 169}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 211}], {
             RGBColor[
             0.9674696176470589, 0.908133823529412, 0.561427411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 362}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 369}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 466}], {
             RGBColor[
             0.9674696176470589, 0.908133823529412, 0.561427411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 470}], {
             RGBColor[0.9172135, 0.6731988823529413, 0.5193830882352942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 240}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 434}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 148}], {
             RGBColor[
             0.7596562058823529, 0.6877910000000003, 0.6045280882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 156}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 227}], {
             RGBColor[
             0.938695205882353, 0.8285484117647062, 0.5936544705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 229}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764708, 0.3716207352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 263}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529414, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 265}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 267}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529414, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 280}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 393}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 424}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 485}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529414, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 179}], {
             RGBColor[
             0.6816970882352942, 0.7426854705882353, 0.8273737058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 222}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 294}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 296}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 339}], {
             RGBColor[
             0.920719705882353, 0.6745077647058826, 0.45102523529411787`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 385}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 415}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 438}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 158}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764708, 0.3716207352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 247}], {
             RGBColor[
             0.6392946176470589, 0.5877669411764708, 0.595690794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 278}], {
             RGBColor[
             0.9285733529411766, 0.7545241764705886, 0.26138664705882364`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 401}], {
             RGBColor[
             0.9285733529411766, 0.7545241764705886, 0.26138664705882364`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 410}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 428}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 437}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529414, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 451}], {
             RGBColor[
             0.5446202941176471, 0.4937621470588237, 0.590097705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 198}], {
             RGBColor[
             0.9527160588235295, 0.837048823529412, 0.47837732352941204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 270}], {
             RGBColor[
             0.8233546764705882, 0.7380637647058825, 0.6105275588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 479}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 151}], {
             RGBColor[
             0.961070411764706, 0.8776436470588238, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 160}], {
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 162}], {
             RGBColor[
             0.9674696176470589, 0.908133823529412, 0.561427411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 167}], {
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 235}], {
             RGBColor[
             0.9674696176470589, 0.908133823529412, 0.561427411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 274}], {
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 284}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 300}], {
             RGBColor[
             0.8970220882352942, 0.8539625882352943, 0.6306839117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 345}], {
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 389}], {
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 432}], {
             RGBColor[
             0.8965770000000001, 0.5919831176470591, 0.23403455882352947`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 456}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058825, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 472}], {
             RGBColor[
             0.9674696176470589, 0.908133823529412, 0.561427411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[
             0.8318199411764706, 0.2455875882352943, 0.17810411764705886`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 161}], {
             RGBColor[0.9172135, 0.6731988823529413, 0.5193830882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 183}], {
             RGBColor[
             0.6072982647058824, 0.42522588235294134`, 0.568338705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 254}], {
             RGBColor[
             0.8318199411764706, 0.2455875882352943, 0.17810411764705886`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 285}], {
             RGBColor[
             0.8965770000000001, 0.5919831176470591, 0.23403455882352947`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 388}], {
             RGBColor[0.9172135, 0.6731988823529413, 0.5193830882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 396}], {
             RGBColor[
             0.6072982647058824, 0.42522588235294134`, 0.568338705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 473}], {
             RGBColor[
             0.8965770000000001, 0.5919831176470591, 0.23403455882352947`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 477}], {
             RGBColor[
             0.7276598529411764, 0.5252499411764708, 0.5771759999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 165}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 178}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 186}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 277}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 288}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 313}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 321}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 373}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 386}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 414}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 498}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 145}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 215}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 246}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 375}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 402}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 417}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 458}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 367}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 375}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764708, 0.3716207352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 402}], {
             RGBColor[
             0.8233546764705882, 0.7380637647058825, 0.6105275588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 417}], {
             RGBColor[
             0.9103135882352942, 0.6821302941176475, 0.24669441176470597`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 450}], {
             RGBColor[
             0.7596562058823529, 0.6877910000000003, 0.6045280882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 458}], {
             RGBColor[
             0.8233546764705882, 0.7380637647058825, 0.6105275588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 461}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 166}], {
             RGBColor[
             0.6392946176470589, 0.5877669411764708, 0.595690794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 239}], {
             RGBColor[
             0.8787623235294117, 0.781568705882353, 0.6159916764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 248}], {
             RGBColor[
             0.7596562058823529, 0.6877910000000003, 0.6045280882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 387}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 221}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.830958529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 234}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.830958529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 242}], {
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 303}], {
             RGBColor[0.6764155, 0.5603625882352943, 0.5855813235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 323}], {
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 449}], {
             RGBColor[
             0.5422784705882352, 0.6392851176470589, 0.9571092941176471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 229}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 232}], {
             RGBColor[
             0.7779159705882353, 0.7601848823529413, 0.6192203235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 263}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 267}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 280}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 342}], {
             RGBColor[
             0.4397813823529412, 0.5475809705882353, 0.9505406764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 393}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 480}], {
             RGBColor[
             0.7596562058823529, 0.6877910000000003, 0.6045280882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 485}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 173}], {
             RGBColor[
             0.5870227647058823, 0.6486806764705882, 0.821780617647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 242}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 249}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 269}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 282}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 310}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 314}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 323}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 406}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 411}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 419}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 220}], {
             RGBColor[
             0.8472959411764707, 0.33486682352941194`, 0.19176191176470592`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 254}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 325}], {
             RGBColor[
             0.9027125588235294, 0.5617382941176471, 0.5054969705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 392}], {
             RGBColor[
             0.8322650294117647, 0.5075670588235294, 0.5747534705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 412}], {
             RGBColor[
             0.8921979117647059, 0.5545467647058824, 0.5524162647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 426}], {
             RGBColor[
             0.7768573823529412, 0.4640621176470588, 0.5692893529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 473}], {
             RGBColor[
             0.8820760588235295, 0.4805225294117649, 0.22014844117647064`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 160}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 162}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 226}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 235}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 237}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 274}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 284}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 345}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 389}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 456}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 472}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 195}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 216}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 217}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 292}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 398}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 399}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 464}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 481}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 496}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 172}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 197}], {
             RGBColor[
             0.6059769411764705, 0.6895578823529411, 0.9631087647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 201}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 223}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 236}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 289}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 314}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 411}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 466}], {
             RGBColor[
             0.8416144411764706, 0.8104576470588236, 0.625219794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 470}], {
             RGBColor[
             0.7913583235294117, 0.5755227058823531, 0.5831754705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 493}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 199}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 219}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 244}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 295}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 341}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 374}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 376}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 397}], {
             RGBColor[
             0.9108142941176471, 0.6427087058823532, 0.2752828823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 455}], {
             RGBColor[
             0.7254329117647058, 0.7567438823529412, 0.6552161764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 198}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 250}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 365}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 394}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 467}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 479}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 198}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 227}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 250}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 263}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 270}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 479}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 485}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 190}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 356}], {
             RGBColor[
             0.7318321176470588, 0.7872340588235294, 0.8993163823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 360}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 193}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 247}], {
             RGBColor[
             0.6807162647058824, 0.7405875882352941, 0.7206171176470587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 278}], {
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 370}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 401}], {
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 410}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 422}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 428}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 437}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 451}], {
             RGBColor[
             0.5860419411764706, 0.6465827941176471, 0.7150240294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 166}], {
             RGBColor[0.4219168823529411, 0.5392610588235294, 0.948272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 192}], {
             RGBColor[
             0.6929358529411764, 0.6336244117647061, 0.5992756176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 239}], {
             RGBColor[
             0.6613845882352941, 0.7330628235294117, 0.9685728823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 251}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.830958529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 272}], {
             RGBColor[
             0.6929358529411764, 0.6336244117647061, 0.5992756176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 344}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.830958529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 435}], {
             RGBColor[
             0.7213174705882353, 0.7800425294117648, 0.9462356764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 439}], {
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 453}], {
             RGBColor[0.6764155, 0.5603625882352943, 0.5855813235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 167}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 235}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 237}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764708, 0.3716207352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 274}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 284}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 300}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 305}], {
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 389}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 432}], {
             RGBColor[
             0.9197388823529412, 0.6724098823529414, 0.34426864705882343`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 460}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 183}], {
             RGBColor[
             0.6781908823529412, 0.7413765882352942, 0.8957315588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 188}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 202}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 243}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 273}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 279}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 285}], {
             RGBColor[
             0.9674696176470589, 0.908133823529412, 0.561427411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 287}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 335}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 354}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 396}], {
             RGBColor[
             0.6781908823529412, 0.7413765882352942, 0.8957315588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 409}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 430}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 459}], {
             RGBColor[
             0.9674696176470589, 0.908133823529412, 0.561427411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 477}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 226}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 284}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 345}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 389}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 456}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 472}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 207}], {
             RGBColor[
             0.7918034117647059, 0.8375021764705881, 0.9798248235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 209}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 231}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 233}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 266}], {
             RGBColor[
             0.6613845882352941, 0.7330628235294117, 0.9685728823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 317}], {
             RGBColor[0.5588875, 0.6413586764705882, 0.9620042647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 326}], {
             RGBColor[
             0.7918034117647059, 0.8375021764705881, 0.9798248235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 343}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 355}], {
             RGBColor[0.5588875, 0.6413586764705882, 0.9620042647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 379}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 440}], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 180}], {
             RGBColor[
             0.6077433529411764, 0.6872053529411765, 0.9649880588235293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 205}], {
             RGBColor[
             0.4886372352941176, 0.5934276470588236, 0.9535244705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 259}], {
             RGBColor[
             0.6392946176470589, 0.5877669411764708, 0.595690794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 316}], {
             RGBColor[
             0.2736013235294118, 0.39939879411764706`, 0.9390940882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 331}], {
             RGBColor[
             0.6717916764705882, 0.7108864117647059, 0.6516313529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 348}], {
             RGBColor[
             0.6816970882352942, 0.7426854705882353, 0.8273737058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 372}], {
             RGBColor[
             0.6717916764705882, 0.7108864117647059, 0.6516313529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 404}], {
             RGBColor[0.6227742647058824, 0.514505117647059, 0.5819965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 418}], {
             RGBColor[0.6227742647058824, 0.514505117647059, 0.5819965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 431}], {
             RGBColor[
             0.6807162647058824, 0.7405875882352941, 0.7206171176470587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 444}], {
             RGBColor[
             0.5523357058823529, 0.6437004117647058, 0.9595239411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 486}], {
             RGBColor[
             0.6781908823529412, 0.7413765882352942, 0.8957315588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 178}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 185}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 277}], {
             RGBColor[
             0.7918034117647059, 0.8375021764705881, 0.9798248235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 288}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 313}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 333}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 358}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 361}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 386}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 498}], {
             RGBColor[
             0.8416144411764706, 0.8104576470588236, 0.625219794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.6077433529411764, 0.6872053529411765, 0.9649880588235293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 344}], {
             RGBColor[
             0.6816970882352942, 0.7426854705882353, 0.8273737058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 387}], {
             RGBColor[
             0.6717916764705882, 0.7108864117647059, 0.6516313529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 435}], {
             RGBColor[
             0.6676762352941177, 0.7341850588235295, 0.9426508529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 439}], {
             RGBColor[
             0.6485839411764706, 0.7197705294117647, 0.9688834705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 453}], {
             RGBColor[0.6227742647058824, 0.514505117647059, 0.5819965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 172}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 218}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 235}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 236}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 274}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 284}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 289}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 300}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 305}], {
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 432}], {
             RGBColor[
             0.9197388823529412, 0.6724098823529414, 0.34426864705882343`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 456}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 493}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 181}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 189}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 232}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058825, 0.6345793235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 280}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 302}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 326}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 338}], {
             RGBColor[
             0.9030825588235294, 0.7408720588235296, 0.606192794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 346}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 370}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 383}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 390}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 395}], {
             RGBColor[
             0.6485839411764706, 0.7197705294117647, 0.9688834705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 443}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 480}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529414, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 211}], {
             RGBColor[
             0.9285733529411766, 0.7545241764705886, 0.26138664705882364`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 236}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 289}], {
             RGBColor[
             0.938695205882353, 0.8285484117647062, 0.5936544705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 308}], {
             RGBColor[
             0.6929358529411764, 0.6336244117647061, 0.5992756176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 362}], {
             RGBColor[
             0.8787623235294117, 0.781568705882353, 0.6159916764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 369}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529414, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 456}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529414, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 470}], {
             RGBColor[
             0.8783172352941178, 0.519589235294118, 0.21934232352941183`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 214}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 223}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 268}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 466}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 491}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 192}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 208}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 219}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 238}], {
             RGBColor[
             0.9674696176470589, 0.908133823529412, 0.561427411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 258}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 272}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 293}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 403}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 471}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 497}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 197}], {
             RGBColor[
             0.7318321176470588, 0.7872340588235294, 0.8993163823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 201}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 211}], {
             RGBColor[
             0.9674696176470589, 0.908133823529412, 0.561427411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 218}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 235}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 236}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 289}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 300}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 308}], {
             RGBColor[
             0.7318321176470588, 0.7872340588235294, 0.8993163823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 314}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 466}], {
             RGBColor[
             0.9674696176470589, 0.908133823529412, 0.561427411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 470}], {
             RGBColor[0.9172135, 0.6731988823529413, 0.5193830882352942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 493}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 242}], {
             RGBColor[
             0.5539096176470588, 0.6257657352941177, 0.9632903823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 249}], {
             RGBColor[
             0.5835165588235294, 0.6473717941176471, 0.8901384705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 269}], {
             RGBColor[
             0.5730019117647058, 0.6401802647058823, 0.9370577647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 282}], {
             RGBColor[
             0.5835165588235294, 0.6473717941176471, 0.8901384705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 310}], {
             RGBColor[
             0.5730019117647058, 0.6401802647058823, 0.9370577647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 323}], {
             RGBColor[
             0.5860419411764706, 0.6465827941176472, 0.7150240294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 406}], {
             RGBColor[
             0.5539096176470588, 0.6257657352941177, 0.9632903823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 419}], {
             RGBColor[
             0.5860419411764706, 0.6465827941176472, 0.7150240294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 499}], {
             RGBColor[
             0.2736013235294118, 0.39939879411764706`, 0.9390940882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 210}], {
             RGBColor[
             0.5034798529411765, 0.5978537352941176, 0.9565401470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 225}], {
             RGBColor[
             0.7913583235294117, 0.5755227058823531, 0.5831754705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 252}], {
             RGBColor[
             0.7918034117647059, 0.8375021764705881, 0.9798248235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 309}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 320}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 393}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 424}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 182}], {
             RGBColor[
             0.8787623235294117, 0.781568705882353, 0.6159916764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 208}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 351}], {
             RGBColor[
             0.6613845882352941, 0.7330628235294117, 0.9685728823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 359}], {
             RGBColor[
             0.5130690294117647, 0.5932005588235294, 0.9593949705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 371}], {
             RGBColor[
             0.6613845882352941, 0.7330628235294117, 0.9685728823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 463}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 483}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 178}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 244}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 261}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 262}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 299}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 313}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 328}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 376}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 391}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 407}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 448}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 455}], {
             RGBColor[
             0.7318321176470588, 0.7872340588235294, 0.8993163823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 475}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 478}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 482}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 194}], {
             RGBColor[
             0.6807162647058824, 0.7405875882352941, 0.7206171176470587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 290}], {
             RGBColor[0.4219168823529411, 0.5392610588235294, 0.948272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 297}], {
             RGBColor[
             0.6077433529411764, 0.6872053529411765, 0.9649880588235293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 412}], {
             RGBColor[
             0.6676762352941177, 0.7341850588235295, 0.9426508529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 484}], {
             RGBColor[
             0.6575543823529413, 0.660160823529412, 0.6103830294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 186}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 244}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 261}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 288}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 313}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 321}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 391}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 407}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 455}], {
             RGBColor[
             0.7254329117647058, 0.7567438823529412, 0.6552161764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 475}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 498}], {
             RGBColor[
             0.961070411764706, 0.8776436470588238, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 222}], {
             RGBColor[
             0.6807162647058824, 0.7405875882352941, 0.7206171176470587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 245}], {
             RGBColor[
             0.6816970882352942, 0.7426854705882353, 0.8273737058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 255}], {
             RGBColor[
             0.6781908823529412, 0.7413765882352942, 0.8957315588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 294}], {
             RGBColor[
             0.6781908823529412, 0.7413765882352942, 0.8957315588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 296}], {
             RGBColor[
             0.5523357058823529, 0.6437004117647058, 0.9595239411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 312}], {
             RGBColor[
             0.6077433529411764, 0.6872053529411765, 0.9649880588235293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 327}], {
             RGBColor[
             0.6676762352941177, 0.7341850588235295, 0.9426508529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 334}], {
             RGBColor[
             0.6781908823529412, 0.7413765882352942, 0.8957315588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 385}], {
             RGBColor[
             0.6807162647058824, 0.7405875882352941, 0.7206171176470587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 415}], {
             RGBColor[
             0.6807162647058824, 0.7405875882352941, 0.7206171176470587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 438}], {
             RGBColor[
             0.4886372352941176, 0.5934276470588236, 0.9535244705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 205}], {
             RGBColor[
             0.7281049411764706, 0.7872294117647058, 0.9738253529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 230}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 331}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 382}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 413}], {
             RGBColor[
             0.5130690294117647, 0.5932005588235294, 0.9593949705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 418}], {
             RGBColor[
             0.8622419705882354, 0.7083068823529413, 0.6022973823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 474}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 490}], {
             RGBColor[
             0.6613845882352941, 0.7330628235294117, 0.9685728823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 189}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 302}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 370}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 390}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 422}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 443}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 451}], {
             RGBColor[
             0.5870227647058823, 0.6486806764705882, 0.821780617647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 237}], {
             RGBColor[
             0.9103135882352942, 0.6821302941176475, 0.24669441176470597`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 351}], {
             RGBColor[
             0.6929358529411764, 0.6336244117647061, 0.5992756176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 359}], {
             RGBColor[
             0.5446202941176471, 0.4937621470588237, 0.590097705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 371}], {
             RGBColor[
             0.6929358529411764, 0.6336244117647061, 0.5992756176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 460}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 463}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529414, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 483}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529414, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 202}], {
             RGBColor[
             0.6676762352941177, 0.7341850588235295, 0.9426508529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 206}], {
             RGBColor[
             0.6485839411764706, 0.7197705294117647, 0.9688834705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 243}], {
             RGBColor[
             0.6717916764705882, 0.7108864117647059, 0.6516313529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 273}], {
             RGBColor[
             0.6816970882352942, 0.7426854705882353, 0.8273737058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 279}], {
             RGBColor[
             0.4886372352941176, 0.5934276470588236, 0.9535244705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 283}], {
             RGBColor[
             0.6807162647058824, 0.7405875882352941, 0.7206171176470587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 285}], {
             RGBColor[
             0.6575543823529413, 0.660160823529412, 0.6103830294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 396}], {
             RGBColor[
             0.36827564705882354`, 0.4934035882352941, 0.9446871764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 430}], {
             RGBColor[
             0.6717916764705882, 0.7108864117647059, 0.6516313529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 477}], {
             RGBColor[
             0.4886372352941176, 0.5934276470588236, 0.9535244705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 221}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 253}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 287}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 301}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 316}], {
             RGBColor[
             0.5870227647058823, 0.6486806764705882, 0.821780617647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 336}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 354}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 388}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 436}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 473}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 187}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 216}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 224}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 286}], {
             RGBColor[
             0.9527160588235295, 0.837048823529412, 0.47837732352941204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 330}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 333}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 357}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 358}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 361}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 386}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 398}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 441}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 464}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 481}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 288}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 295}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 321}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 341}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 373}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 397}], {
             RGBColor[
             0.9066988529411765, 0.6660073529411767, 0.5663023823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 455}], {
             RGBColor[
             0.7213174705882353, 0.7800425294117648, 0.9462356764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 495}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 498}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 216}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 224}], {
             RGBColor[
             0.7880378235294117, 0.8342091176470589, 0.9514881470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 260}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 328}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 398}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 399}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 407}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 464}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 478}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 481}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 200}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 228}], {
             RGBColor[
             0.9527160588235295, 0.837048823529412, 0.47837732352941204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 256}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 279}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 298}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 318}], {
             RGBColor[
             0.6816970882352942, 0.7426854705882353, 0.8273737058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 335}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 409}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 430}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 459}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 302}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 346}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 370}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 383}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 390}], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 422}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 443}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 451}], {
             RGBColor[
             0.5130690294117647, 0.5932005588235294, 0.9593949705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 349}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 378}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 467}], {
             RGBColor[
             0.961070411764706, 0.8776436470588238, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 487}], {
             RGBColor[
             0.6717916764705882, 0.7108864117647059, 0.6516313529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 226}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 237}], {
             RGBColor[
             0.8233546764705882, 0.7380637647058825, 0.6105275588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 271}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 311}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 366}], {
             RGBColor[
             0.672697294117647, 0.7437244705882353, 0.9683612352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 405}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 423}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 429}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 488}], {
             RGBColor[
             0.4576613823529412, 0.5496956176470588, 0.9539308529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 219}], {
             RGBColor[
             0.9527160588235295, 0.837048823529412, 0.47837732352941204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 251}], {
             RGBColor[
             0.9527160588235295, 0.837048823529412, 0.47837732352941204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 258}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 272}], {
             RGBColor[
             0.9103135882352942, 0.6821302941176475, 0.24669441176470597`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 435}], {
             RGBColor[
             0.938695205882353, 0.8285484117647062, 0.5936544705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 453}], {
             RGBColor[
             0.8937932352941177, 0.6088684705882357, 0.2330001176470589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 497}], {
             RGBColor[
             0.9103135882352942, 0.6821302941176475, 0.24669441176470597`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 410}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 428}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 437}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 220}], {
             RGBColor[
             0.9352148823529411, 0.761689117647059, 0.35792644117647054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 254}], {
             RGBColor[
             0.9052379411764706, 0.560949294117647, 0.3303825294117646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 290}], {
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 297}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 350}], {
             RGBColor[
             0.9197388823529412, 0.6724098823529414, 0.34426864705882343`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 377}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 412}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 426}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 476}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 260}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 292}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 399}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 446}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 496}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 213}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058825, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 332}], {
             RGBColor[
             0.8970220882352942, 0.8539625882352943, 0.6306839117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 337}], {
             RGBColor[
             0.8970220882352942, 0.8539625882352943, 0.6306839117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 420}], {
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 427}], {
             RGBColor[
             0.9468331176470589, 0.8269180588235298, 0.27607888235294126`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 447}], {
             RGBColor[
             0.5628800588235294, 0.5661560294117649, 0.6047899411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 454}], {
             RGBColor[
             0.6086985294117647, 0.6143141470588237, 0.6073992352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 489}], {
             RGBColor[
             0.9674696176470589, 0.908133823529412, 0.561427411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 500}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.6083467058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 201}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.830958529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 236}], {
             RGBColor[
             0.7318321176470588, 0.7872340588235294, 0.8993163823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 289}], {
             RGBColor[
             0.7213174705882353, 0.7800425294117648, 0.9462356764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 314}], {
             RGBColor[
             0.7213174705882353, 0.7800425294117648, 0.9462356764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 411}], {
             RGBColor[
             0.7318321176470588, 0.7872340588235294, 0.8993163823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 466}], {
             RGBColor[
             0.7111956176470589, 0.7060182941176472, 0.6139678529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 470}], {
             RGBColor[0.6609395, 0.47108335294117665`, 0.5719235294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 493}], {
             RGBColor[
             0.7213174705882353, 0.7800425294117648, 0.9462356764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 270}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 479}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 244}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 245}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 262}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 376}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 448}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 455}], {
             RGBColor[
             0.5422784705882352, 0.6392851176470589, 0.9571092941176471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 475}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 482}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 228}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764708, 0.3716207352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 256}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 298}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 452}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 468}], {
             RGBColor[
             0.5860419411764706, 0.6465827941176471, 0.7150240294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 218}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 235}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 236}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 289}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 300}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 305}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 314}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 406}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 493}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 243}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 273}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 279}], {
             RGBColor[
             0.7880378235294117, 0.8342091176470589, 0.9514881470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 283}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 285}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 396}], {
             RGBColor[
             0.6676762352941177, 0.7341850588235295, 0.9426508529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 421}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 430}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 459}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 477}], {
             RGBColor[
             0.7880378235294117, 0.8342091176470589, 0.9514881470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 264}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 281}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 295}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 324}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 341}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 374}], {
             RGBColor[
             0.9527160588235295, 0.837048823529412, 0.47837732352941204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 397}], {
             RGBColor[
             0.920719705882353, 0.6745077647058826, 0.45102523529411787`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 275}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 306}], {
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 331}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 346}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 348}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 355}], {
             RGBColor[
             0.6318604117647059, 0.6947409117647059, 0.7176333235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 390}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 431}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 444}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 486}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 230}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 331}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 382}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 413}], {
             RGBColor[
             0.3939629117647059, 0.4994228529411765, 0.9479313823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 474}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 490}], {
             RGBColor[
             0.5422784705882352, 0.6392851176470589, 0.9571092941176471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 254}], {
             RGBColor[
             0.8731056176470589, 0.5401322352941176, 0.5786488823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 377}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 396}], {
             RGBColor[
             0.6485839411764706, 0.7197705294117647, 0.9688834705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 476}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 257}], {
             RGBColor[
             0.7913583235294117, 0.5755227058823531, 0.5831754705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 266}], {
             RGBColor[
             0.6059769411764705, 0.6895578823529411, 0.9631087647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 281}], {
             RGBColor[
             0.7918034117647059, 0.8375021764705881, 0.9798248235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 293}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 317}], {
             RGBColor[
             0.5034798529411765, 0.5978537352941176, 0.9565401470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 322}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 343}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 374}], {
             RGBColor[
             0.8233546764705882, 0.7380637647058825, 0.6105275588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 403}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 440}], {
             RGBColor[
             0.7918034117647059, 0.8375021764705881, 0.9798248235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 445}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 471}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 238}], {
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 266}], {
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 293}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 403}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 471}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 483}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 497}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764708, 0.3716207352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 231}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 233}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 259}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 275}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 348}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 355}], {
             RGBColor[
             0.6229358235294118, 0.6650397352941178, 0.6486475588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 372}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 379}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 400}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 404}], {
             RGBColor[
             0.9262902941176471, 0.7319879411764708, 0.2889406764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 431}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 444}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 486}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 225}], {
             RGBColor[
             0.558442411764706, 0.37937920588235313`, 0.5653549117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 252}], {
             RGBColor[0.5588875, 0.6413586764705882, 0.9620042647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 280}], {
             RGBColor[
             0.6229358235294118, 0.6650397352941178, 0.6486475588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 309}], {
             RGBColor[
             0.6328412352941177, 0.696838794117647, 0.8243899117647061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 320}], {
             RGBColor[
             0.6188203823529412, 0.6883383823529412, 0.9396670588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 393}], {
             RGBColor[
             0.6229358235294118, 0.6650397352941178, 0.6486475588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 424}], {
             RGBColor[
             0.6229358235294118, 0.6650397352941178, 0.6486475588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 480}], {
             RGBColor[
             0.5904387647058824, 0.5419202647058825, 0.5927070000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 236}], {
             RGBColor[
             0.9674696176470589, 0.908133823529412, 0.561427411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 289}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.6083467058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 308}], {
             RGBColor[
             0.7111956176470589, 0.7060182941176472, 0.6139678529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 362}], {
             RGBColor[
             0.8970220882352942, 0.8539625882352943, 0.6306839117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 369}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058825, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 466}], {
             RGBColor[
             0.9468331176470589, 0.8269180588235298, 0.27607888235294126`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 470}], {
             RGBColor[
             0.8965770000000001, 0.5919831176470591, 0.23403455882352947`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 216}], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 217}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 224}], {
             RGBColor[
             0.7281049411764706, 0.7872294117647058, 0.9738253529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 286}], {
             RGBColor[
             0.8787623235294117, 0.781568705882353, 0.6159916764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 319}], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 330}], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 357}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 492}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 251}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 332}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 337}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 420}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 447}], {
             RGBColor[
             0.5539096176470588, 0.6257657352941176, 0.9632903823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 454}], {
             RGBColor[
             0.5997280882352941, 0.6739238529411764, 0.9658996764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 489}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 500}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 223}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 268}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 466}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 470}], {
             RGBColor[
             0.9066988529411765, 0.6660073529411767, 0.5663023823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 491}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 402}], {
             RGBColor[
             0.672697294117647, 0.7437244705882353, 0.9683612352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 417}], {
             RGBColor[
             0.7596562058823529, 0.6877910000000003, 0.6045280882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 217}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 224}], {
             RGBColor[
             0.7281049411764706, 0.7872294117647058, 0.9738253529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 292}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 358}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 361}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 398}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 399}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 464}], {
             RGBColor[
             0.7918034117647059, 0.8375021764705881, 0.9798248235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 481}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 292}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 398}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 464}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 481}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 496}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 235}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 274}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 305}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 310}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 314}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 406}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 432}], {
             RGBColor[
             0.9066988529411765, 0.6660073529411767, 0.5663023823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 493}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 238}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 258}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 293}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 403}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 445}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 471}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 497}], {
             RGBColor[
             0.9527160588235295, 0.837048823529412, 0.47837732352941204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 254}], {
             RGBColor[
             0.8472959411764707, 0.33486682352941194`, 0.19176191176470592`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 297}], {
             RGBColor[
             0.8622419705882354, 0.7083068823529413, 0.6022973823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 325}], {
             RGBColor[0.9326895, 0.762478117647059, 0.5330408823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 392}], {
             RGBColor[
             0.8622419705882354, 0.7083068823529413, 0.6022973823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 412}], {
             RGBColor[
             0.9221748529411764, 0.7552865882352944, 0.5799601764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 413}], {
             RGBColor[
             0.5280999411764706, 0.4205003235294119, 0.5764034117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 426}], {
             RGBColor[
             0.8068343235294118, 0.6648019411764707, 0.5968332647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 474}], {
             RGBColor[
             0.9352148823529411, 0.761689117647059, 0.35792644117647054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 490}], {
             RGBColor[0.6764155, 0.5603625882352943, 0.5855813235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 234}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 301}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 336}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 294}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 296}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 339}], {
             RGBColor[
             0.9197388823529412, 0.6724098823529414, 0.34426864705882343`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 344}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 438}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 439}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 246}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 268}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 411}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 286}], {
             RGBColor[
             0.7596562058823529, 0.6877910000000003, 0.6045280882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 330}], {
             RGBColor[
             0.7281049411764706, 0.7872294117647058, 0.9738253529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 333}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 358}], {
             RGBColor[
             0.7880378235294117, 0.8342091176470589, 0.9514881470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 361}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 398}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 441}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 464}], {
             RGBColor[
             0.672697294117647, 0.7437244705882353, 0.9683612352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 481}], {
             RGBColor[
             0.7880378235294117, 0.8342091176470589, 0.9514881470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 247}], {
             RGBColor[
             0.6072982647058824, 0.42522588235294134`, 0.568338705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 252}], {
             RGBColor[
             0.8467659705882353, 0.6190276470588236, 0.5886395882352942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 309}], {
             RGBColor[
             0.920719705882353, 0.6745077647058826, 0.4510252352941179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 320}], {
             RGBColor[
             0.9066988529411765, 0.6660073529411767, 0.5663023823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 424}], {
             RGBColor[
             0.9108142941176471, 0.6427087058823532, 0.2752828823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 284}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 345}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 366}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 389}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 405}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 429}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 472}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 488}], {
             RGBColor[
             0.5771173529411765, 0.6168816176470588, 0.6460382647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 229}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 263}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 265}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 267}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 270}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 329}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 424}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 256}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 279}], {
             RGBColor[
             0.7596562058823529, 0.6877910000000003, 0.6045280882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 287}], {
             RGBColor[
             0.938695205882353, 0.8285484117647062, 0.5936544705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 298}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 318}], {
             RGBColor[
             0.6392946176470589, 0.5877669411764708, 0.595690794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 335}], {
             RGBColor[
             0.8233546764705882, 0.7380637647058825, 0.6105275588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 409}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 468}], {
             RGBColor[
             0.5446202941176471, 0.4937621470588237, 0.590097705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 232}], {
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 263}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 267}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 280}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 393}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 480}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764708, 0.3716207352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 485}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 382}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 413}], {
             RGBColor[
             0.5771173529411765, 0.6168816176470588, 0.6460382647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 474}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 484}], {
             RGBColor[
             0.961070411764706, 0.8776436470588238, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 490}], {
             RGBColor[
             0.7254329117647058, 0.7567438823529412, 0.6552161764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 233}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 275}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 326}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 346}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 355}], {
             RGBColor[
             0.5997280882352941, 0.6739238529411764, 0.9658996764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 395}], {
             RGBColor[
             0.6485839411764706, 0.7197705294117647, 0.9688834705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 404}], {
             RGBColor[
             0.9030825588235294, 0.7408720588235296, 0.606192794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 431}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 444}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 486}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 267}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058825, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 280}], {
             RGBColor[
             0.961070411764706, 0.8776436470588238, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 338}], {
             RGBColor[0.912053, 0.6812623529411768, 0.24769235294117653`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 383}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058825, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 393}], {
             RGBColor[
             0.961070411764706, 0.8776436470588238, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 395}], {
             RGBColor[
             0.6575543823529413, 0.660160823529412, 0.6103830294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 480}], {
             RGBColor[
             0.9285733529411766, 0.7545241764705886, 0.26138664705882364`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 259}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 275}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 326}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 346}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 348}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 355}], {
             RGBColor[
             0.6229358235294118, 0.6650397352941178, 0.6486475588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 379}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 400}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 404}], {
             RGBColor[
             0.9262902941176471, 0.7319879411764708, 0.2889406764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 431}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 444}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 486}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 336}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 449}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 274}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 284}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 300}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 305}], {
             RGBColor[
             0.9674696176470589, 0.908133823529412, 0.561427411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 308}], {
             RGBColor[
             0.7318321176470588, 0.7872340588235294, 0.8993163823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 345}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 389}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 432}], {
             RGBColor[0.9172135, 0.6731988823529413, 0.5193830882352942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 456}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 289}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 300}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 308}], {
             RGBColor[
             0.7318321176470588, 0.7872340588235294, 0.8993163823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 314}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 466}], {
             RGBColor[
             0.9674696176470589, 0.908133823529412, 0.561427411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 470}], {
             RGBColor[0.9172135, 0.6731988823529413, 0.5193830882352942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 493}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 241}], {
             RGBColor[
             0.6392946176470589, 0.5877669411764708, 0.595690794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 274}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764708, 0.3716207352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 284}], {
             RGBColor[
             0.9527160588235295, 0.837048823529412, 0.47837732352941204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 351}], {
             RGBColor[
             0.6929358529411764, 0.6336244117647061, 0.5992756176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 371}], {
             RGBColor[
             0.6929358529411764, 0.6336244117647061, 0.5992756176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 429}], {
             RGBColor[
             0.9527160588235295, 0.837048823529412, 0.47837732352941204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 432}], {
             RGBColor[
             0.8783172352941178, 0.519589235294118, 0.21934232352941183`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 460}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 258}], {
             RGBColor[
             0.961070411764706, 0.8776436470588238, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 266}], {
             RGBColor[
             0.7111956176470589, 0.7060182941176472, 0.6139678529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 293}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 403}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058825, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 445}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 471}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 483}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058825, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 497}], {
             RGBColor[
             0.9285733529411766, 0.7545241764705886, 0.26138664705882364`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 251}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 272}], {
             RGBColor[
             0.8787623235294117, 0.781568705882353, 0.6159916764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 332}], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 387}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 435}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 453}], {
             RGBColor[
             0.8622419705882354, 0.7083068823529413, 0.6022973823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 454}], {
             RGBColor[0.5588875, 0.6413586764705882, 0.9620042647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 489}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 434}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 495}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 271}], {
             RGBColor[
             0.6781908823529412, 0.7413765882352942, 0.8957315588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 304}], {
             RGBColor[
             0.6392946176470589, 0.5877669411764708, 0.595690794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 311}], {
             RGBColor[
             0.6676762352941177, 0.7341850588235295, 0.9426508529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 351}], {
             RGBColor[0.4219168823529411, 0.5392610588235294, 0.948272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 371}], {
             RGBColor[0.4219168823529411, 0.5392610588235294, 0.948272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 429}], {
             RGBColor[
             0.6816970882352942, 0.7426854705882353, 0.8273737058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 442}], {
             RGBColor[0.6227742647058824, 0.514505117647059, 0.5819965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 249}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 269}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 282}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 310}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 323}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 419}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 449}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 499}], {
             RGBColor[
             0.6485839411764706, 0.7197705294117647, 0.9688834705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 273}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 279}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 283}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 285}], {
             RGBColor[
             0.961070411764706, 0.8776436470588238, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 318}], {
             RGBColor[
             0.6717916764705882, 0.7108864117647059, 0.6516313529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 335}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 396}], {
             RGBColor[
             0.6717916764705882, 0.7108864117647059, 0.6516313529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 421}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 430}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 459}], {
             RGBColor[
             0.961070411764706, 0.8776436470588238, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 477}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 261}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 262}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 295}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 341}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 376}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 391}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 407}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 448}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 455}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.830958529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 475}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 478}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 482}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 262}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 299}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 376}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 438}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 448}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 475}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 482}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 384}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 402}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 411}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 458}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 252}], {
             RGBColor[
             0.6077433529411764, 0.6872053529411765, 0.9649880588235293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 278}], {
             RGBColor[
             0.6575543823529413, 0.660160823529412, 0.6103830294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 309}], {
             RGBColor[
             0.6816970882352942, 0.7426854705882353, 0.8273737058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 401}], {
             RGBColor[
             0.6575543823529413, 0.660160823529412, 0.6103830294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 451}], {
             RGBColor[
             0.2736013235294118, 0.39939879411764706`, 0.9390940882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 339}], {
             RGBColor[0.7276598529411764, 0.5252499411764708, 0.577176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 344}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 387}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 439}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 269}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 282}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 310}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 323}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 406}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 419}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 499}], {
             RGBColor[
             0.6781908823529412, 0.7413765882352942, 0.8957315588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 263}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 365}], {
             RGBColor[
             0.7880378235294117, 0.8342091176470589, 0.9514881470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 485}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 258}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 272}], {
             RGBColor[
             0.9527160588235295, 0.837048823529412, 0.47837732352941204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 435}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 447}], {
             RGBColor[
             0.5870227647058823, 0.6486806764705882, 0.821780617647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 453}], {
             RGBColor[
             0.9361957058823529, 0.7637870000000002, 0.464683029411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 454}], {
             RGBColor[
             0.6328412352941176, 0.696838794117647, 0.8243899117647061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 309}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 320}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 424}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 287}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.6083467058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 301}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058825, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 336}], {
             RGBColor[
             0.9674696176470589, 0.908133823529412, 0.561427411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 354}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.6083467058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 388}], {
             RGBColor[
             0.9674696176470589, 0.908133823529412, 0.561427411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 436}], {
             RGBColor[
             0.9674696176470589, 0.908133823529412, 0.561427411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 473}], {
             RGBColor[
             0.9468331176470589, 0.8269180588235298, 0.27607888235294126`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 350}], {
             RGBColor[
             0.8318199411764706, 0.2455875882352943, 0.17810411764705886`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 377}], {
             RGBColor[
             0.8963133529411764, 0.5312481176470589, 0.26139676470588236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 412}], {
             RGBColor[
             0.8921979117647059, 0.5545467647058824, 0.5524162647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 426}], {
             RGBColor[
             0.7768573823529412, 0.4640621176470588, 0.5692893529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 476}], {
             RGBColor[
             0.9062187647058824, 0.5630471764705882, 0.43713911764705904`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 260}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 299}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 312}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 327}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 334}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 385}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 446}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 478}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 287}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 298}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 409}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 281}], {
             RGBColor[
             0.8467659705882353, 0.6190276470588236, 0.5886395882352942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 317}], {
             RGBColor[
             0.5584424117647059, 0.37937920588235313`, 0.5653549117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 322}], {
             RGBColor[
             0.9197388823529412, 0.6724098823529414, 0.34426864705882343`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 324}], {
             RGBColor[
             0.7913583235294117, 0.5755227058823531, 0.5831754705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 326}], {
             RGBColor[
             0.7913583235294117, 0.5755227058823531, 0.5831754705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 343}], {
             RGBColor[
             0.9066988529411765, 0.6660073529411767, 0.5663023823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 374}], {
             RGBColor[
             0.8783172352941178, 0.519589235294118, 0.21934232352941183`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 445}], {
             RGBColor[
             0.920719705882353, 0.6745077647058826, 0.4510252352941179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 272}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 293}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 403}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 435}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 453}], {
             RGBColor[
             0.9262902941176471, 0.7319879411764708, 0.2889406764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 471}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 497}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 275}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764708, 0.3716207352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 331}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 348}], {
             RGBColor[
             0.9527160588235295, 0.837048823529412, 0.47837732352941204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 372}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 400}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 404}], {
             RGBColor[
             0.8937932352941177, 0.6088684705882357, 0.2330001176470589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 418}], {
             RGBColor[
             0.8937932352941177, 0.6088684705882357, 0.2330001176470589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 431}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764708, 0.3716207352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 444}], {
             RGBColor[
             0.8233546764705882, 0.7380637647058825, 0.6105275588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 486}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 299}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 312}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 328}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 334}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 399}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 407}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 446}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 478}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 262}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 299}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 313}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 328}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 391}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 407}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 448}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 455}], {
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 475}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 478}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 482}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 299}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 376}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 391}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 448}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 455}], {
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 475}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 478}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 482}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 267}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 393}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 485}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 281}], {
             RGBColor[
             0.7281049411764706, 0.7872294117647058, 0.9738253529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 295}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 324}], {
             RGBColor[
             0.672697294117647, 0.7437244705882353, 0.9683612352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 341}], {
             RGBColor[
             0.7281049411764706, 0.7872294117647058, 0.9738253529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 374}], {
             RGBColor[
             0.7596562058823529, 0.6877910000000003, 0.6045280882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 397}], {
             RGBColor[0.7276598529411764, 0.5252499411764708, 0.577176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 270}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 320}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 329}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 424}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 293}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.830958529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 317}], {
             RGBColor[
             0.37306102941176467`, 0.49341438235294116`, 0.945288205882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 322}], {
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 343}], {
             RGBColor[
             0.7213174705882353, 0.7800425294117648, 0.9462356764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 359}], {
             RGBColor[
             0.3272425588235294, 0.4452562647058823, 0.9426789117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 403}], {
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 440}], {
             RGBColor[
             0.6613845882352941, 0.7330628235294117, 0.9685728823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 445}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.830958529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 471}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.830958529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 483}], {
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 280}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 393}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 424}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 480}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529414, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 485}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 491}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 282}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 310}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 323}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 406}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 411}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 419}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 499}], {
             RGBColor[
             0.6676762352941177, 0.7341850588235295, 0.9426508529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 329}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 479}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 304}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 307}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 311}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 351}], {
             RGBColor[
             0.7318321176470588, 0.7872340588235294, 0.8993163823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 371}], {
             RGBColor[
             0.7318321176470588, 0.7872340588235294, 0.8993163823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 429}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 442}], {
             RGBColor[0.9326895, 0.762478117647059, 0.5330408823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 435}], {
             RGBColor[
             0.938695205882353, 0.8285484117647062, 0.5936544705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 453}], {
             RGBColor[
             0.8937932352941177, 0.6088684705882357, 0.2330001176470589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 497}], {
             RGBColor[
             0.9103135882352942, 0.6821302941176475, 0.24669441176470597`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 279}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 283}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 285}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 396}], {
             RGBColor[
             0.6816970882352942, 0.7426854705882353, 0.8273737058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 421}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 430}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 459}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 477}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 284}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 300}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 305}], {
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 389}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 432}], {
             RGBColor[
             0.9197388823529412, 0.6724098823529414, 0.34426864705882343`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 460}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 331}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 346}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 348}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 355}], {
             RGBColor[
             0.6318604117647059, 0.6947409117647059, 0.7176333235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 372}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 404}], {
             RGBColor[
             0.9352148823529411, 0.761689117647059, 0.35792644117647054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 418}], {
             RGBColor[
             0.9352148823529411, 0.761689117647059, 0.35792644117647054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 431}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 444}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 486}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 306}], {
             RGBColor[
             0.7779159705882353, 0.7601848823529413, 0.6192203235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 347}], {
             RGBColor[
             0.5422784705882352, 0.6392851176470589, 0.9571092941176471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 382}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 462}], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 288}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 313}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 340}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 373}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 386}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 414}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 498}], {
             RGBColor[
             0.8970220882352942, 0.8539625882352943, 0.630683911764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 401}], {
             RGBColor[
             0.9468331176470589, 0.8269180588235298, 0.27607888235294126`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 451}], {
             RGBColor[
             0.5628800588235294, 0.5661560294117649, 0.6047899411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.7779159705882353, 0.7601848823529413, 0.6192203235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 318}], {
             RGBColor[
             0.4886372352941176, 0.5934276470588236, 0.9535244705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 335}], {
             RGBColor[
             0.672697294117647, 0.7437244705882353, 0.9683612352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 396}], {
             RGBColor[
             0.4886372352941176, 0.5934276470588236, 0.9535244705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 409}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 421}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 430}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 459}], {
             RGBColor[
             0.7779159705882353, 0.7601848823529413, 0.6192203235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 477}], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 338}], {
             RGBColor[
             0.9262902941176471, 0.7319879411764708, 0.2889406764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 383}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 393}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 480}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 317}], {
             RGBColor[0.5588875, 0.6413586764705882, 0.9620042647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 322}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 324}], {
             RGBColor[
             0.7918034117647059, 0.8375021764705881, 0.9798248235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 343}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 374}], {
             RGBColor[
             0.8787623235294117, 0.781568705882353, 0.6159916764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 397}], {
             RGBColor[
             0.8467659705882353, 0.6190276470588236, 0.5886395882352942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 445}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 310}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 323}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 406}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 419}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 499}], {
             RGBColor[
             0.6781908823529412, 0.7413765882352942, 0.8957315588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 396}], {
             RGBColor[
             0.6807162647058824, 0.7405875882352941, 0.7206171176470587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 421}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 430}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 459}], {
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 477}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 300}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 345}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 389}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 432}], {
             RGBColor[
             0.920719705882353, 0.6745077647058826, 0.45102523529411787`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 456}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 472}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 287}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.6083467058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 354}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.6083467058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 396}], {
             RGBColor[
             0.6575543823529413, 0.660160823529412, 0.6103830294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 409}], {
             RGBColor[
             0.961070411764706, 0.8776436470588238, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 430}], {
             RGBColor[
             0.961070411764706, 0.8776436470588238, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 473}], {
             RGBColor[
             0.9468331176470589, 0.8269180588235298, 0.27607888235294126`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 477}], {
             RGBColor[
             0.7779159705882353, 0.7601848823529413, 0.6192203235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 319}], {
             RGBColor[
             0.8787623235294117, 0.781568705882353, 0.6159916764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 330}], {
             RGBColor[
             0.8787623235294117, 0.781568705882353, 0.6159916764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 357}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 358}], {
             RGBColor[
             0.938695205882353, 0.8285484117647062, 0.5936544705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 367}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 368}], {
             RGBColor[
             0.938695205882353, 0.8285484117647062, 0.5936544705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 492}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 336}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 354}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 388}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 409}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 436}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 473}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 313}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 321}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 373}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 386}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 391}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 455}], {
             RGBColor[
             0.7318321176470588, 0.7872340588235294, 0.8993163823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 498}], {
             RGBColor[
             0.9674696176470589, 0.908133823529412, 0.561427411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 300}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 308}], {
             RGBColor[
             0.7213174705882353, 0.7800425294117648, 0.9462356764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 314}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 466}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 470}], {
             RGBColor[
             0.9066988529411765, 0.6660073529411767, 0.5663023823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 493}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 297}], {
             RGBColor[
             0.6613845882352941, 0.7330628235294117, 0.9685728823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 484}], {
             RGBColor[
             0.7111956176470589, 0.7060182941176472, 0.6139678529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 349}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 353}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 394}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 467}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058825, 0.6345793235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 398}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 399}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 464}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 481}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 496}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 343}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 403}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 440}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 445}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 471}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 483}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 497}], {
             RGBColor[
             0.9527160588235295, 0.837048823529412, 0.47837732352941204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 296}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 327}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 385}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 415}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 438}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 439}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 321}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 341}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 391}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 397}], {
             RGBColor[0.8876065588235293, 0.651592823529412, 0.592535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 455}], {
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 327}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 339}], {
             RGBColor[
             0.7913583235294117, 0.5755227058823531, 0.5831754705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 385}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 415}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 438}], {
             RGBColor[
             0.672697294117647, 0.7437244705882353, 0.9683612352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 325}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 392}], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 412}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 413}], {
             RGBColor[
             0.5130690294117647, 0.5932005588235294, 0.9593949705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 474}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 484}], {
             RGBColor[
             0.8970220882352942, 0.8539625882352943, 0.630683911764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 490}], {
             RGBColor[
             0.6613845882352941, 0.7330628235294117, 0.9685728823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 335}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 409}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 468}], {
             RGBColor[
             0.5835165588235294, 0.6473717941176471, 0.8901384705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 312}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 328}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 399}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 407}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 448}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 475}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 478}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 482}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 305}], {
             RGBColor[
             0.8970220882352942, 0.8539625882352943, 0.630683911764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 308}], {
             RGBColor[
             0.6613845882352941, 0.7330628235294117, 0.9685728823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 432}], {
             RGBColor[
             0.8467659705882353, 0.6190276470588236, 0.5886395882352942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 456}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 493}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 316}], {
             RGBColor[
             0.5539096176470588, 0.6257657352941176, 0.9632903823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 336}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 388}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 436}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 346}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 370}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 390}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 422}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 443}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 451}], {
             RGBColor[
             0.5860419411764706, 0.6465827941176471, 0.7150240294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 379}], {
             RGBColor[
             0.9361957058823529, 0.7637870000000002, 0.464683029411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 400}], {
             RGBColor[
             0.9262902941176471, 0.7319879411764708, 0.2889406764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 307}], {
             RGBColor[
             0.8787623235294117, 0.781568705882353, 0.6159916764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 311}], {
             RGBColor[
             0.938695205882353, 0.8285484117647062, 0.5936544705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 337}], {
             RGBColor[
             0.8787623235294117, 0.781568705882353, 0.6159916764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 423}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 427}], {
             RGBColor[
             0.9285733529411766, 0.7545241764705886, 0.26138664705882364`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 433}], {
             RGBColor[
             0.9527160588235295, 0.837048823529412, 0.47837732352941204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 465}], {
             RGBColor[
             0.9285733529411766, 0.7545241764705886, 0.26138664705882364`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 469}], {
             RGBColor[
             0.8233546764705882, 0.7380637647058825, 0.6105275588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 310}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.6083467058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 406}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058825, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 432}], {
             RGBColor[
             0.8965770000000001, 0.5919831176470591, 0.23403455882352947`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 460}], {
             RGBColor[
             0.961070411764706, 0.8776436470588238, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 493}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.6083467058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 331}], {
             RGBColor[
             0.961070411764706, 0.8776436470588238, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 347}], {
             RGBColor[
             0.7111956176470589, 0.7060182941176472, 0.6139678529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 382}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 431}], {
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 486}], {
             RGBColor[
             0.9674696176470589, 0.908133823529412, 0.561427411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 337}], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 427}], {
             RGBColor[
             0.8970220882352942, 0.8539625882352943, 0.630683911764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 433}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 442}], {
             RGBColor[
             0.8622419705882354, 0.7083068823529413, 0.6022973823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 469}], {
             RGBColor[
             0.7918034117647059, 0.8375021764705881, 0.9798248235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 500}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 362}], {
             RGBColor[
             0.6613845882352941, 0.7330628235294117, 0.9685728823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 369}], {
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 389}], {
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 456}], {
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 393}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 424}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 323}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 406}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 408}], {
             RGBColor[
             0.7880378235294117, 0.8342091176470589, 0.9514881470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 419}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 366}], {
             RGBColor[
             0.7880378235294117, 0.8342091176470589, 0.9514881470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 405}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 423}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 429}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 465}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 469}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 488}], {
             RGBColor[
             0.5730019117647058, 0.6401802647058824, 0.9370577647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 327}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 334}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 385}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 415}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 446}], {
             RGBColor[
             0.7281049411764706, 0.7872294117647058, 0.9738253529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 386}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 391}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 407}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 498}], {
             RGBColor[
             0.961070411764706, 0.8776436470588238, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 406}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 411}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 493}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 349}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 353}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 364}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 378}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 380}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 487}], {
             RGBColor[
             0.6781908823529412, 0.7413765882352942, 0.8957315588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 372}], {
             RGBColor[
             0.5771173529411764, 0.6168816176470588, 0.6460382647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 418}], {
             RGBColor[
             0.5280999411764706, 0.4205003235294119, 0.5764034117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 322}], {
             RGBColor[
             0.631860411764706, 0.6947409117647059, 0.7176333235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 343}], {
             RGBColor[
             0.6188203823529412, 0.6883383823529412, 0.9396670588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 374}], {
             RGBColor[
             0.5904387647058824, 0.5419202647058825, 0.5927070000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 440}], {
             RGBColor[0.5588875, 0.6413586764705882, 0.9620042647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 445}], {
             RGBColor[
             0.6328412352941177, 0.696838794117647, 0.8243899117647061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 471}], {
             RGBColor[
             0.6328412352941177, 0.696838794117647, 0.8243899117647061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 335}], {
             RGBColor[
             0.5523357058823529, 0.6437004117647058, 0.9595239411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 421}], {
             RGBColor[
             0.6816970882352942, 0.7426854705882353, 0.8273737058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 430}], {
             RGBColor[
             0.6717916764705882, 0.7108864117647059, 0.6516313529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 459}], {
             RGBColor[
             0.6575543823529413, 0.660160823529412, 0.6103830294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 330}], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 357}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 368}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 492}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 329}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 424}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 341}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 373}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 391}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 397}], {
             RGBColor[0.9172135, 0.6731988823529413, 0.5193830882352942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 455}], {
             RGBColor[
             0.7318321176470588, 0.7872340588235294, 0.8993163823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 498}], {
             RGBColor[
             0.9674696176470589, 0.908133823529412, 0.561427411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 343}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 374}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764708, 0.3716207352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 440}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 445}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 471}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 419}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 449}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 499}], {
             RGBColor[
             0.6807162647058824, 0.7405875882352941, 0.7206171176470587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 342}], {
             RGBColor[
             0.5034798529411765, 0.5978537352941176, 0.9565401470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 360}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 457}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 392}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 413}], {
             RGBColor[
             0.5835165588235294, 0.6473717941176471, 0.8901384705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 474}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 490}], {
             RGBColor[
             0.7318321176470588, 0.7872340588235294, 0.8993163823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 338}], {
             RGBColor[
             0.8068343235294118, 0.6648019411764707, 0.5968332647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 346}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 355}], {
             RGBColor[
             0.5034798529411765, 0.5978537352941176, 0.9565401470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 395}], {
             RGBColor[
             0.5523357058823529, 0.6437004117647058, 0.9595239411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 443}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 334}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 385}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 415}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 446}], {
             RGBColor[
             0.7880378235294117, 0.8342091176470589, 0.9514881470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 398}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 399}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 407}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 464}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 475}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 478}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 481}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 333}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 352}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 357}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 358}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 367}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 368}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 441}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 492}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 348}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 372}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 382}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 404}], {
             RGBColor[
             0.9262902941176471, 0.7319879411764708, 0.2889406764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 418}], {
             RGBColor[
             0.9262902941176471, 0.7319879411764708, 0.2889406764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 431}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 444}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 486}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 420}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 454}], {
             RGBColor[0.5588875, 0.6413586764705882, 0.9620042647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 489}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 358}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 361}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 367}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 386}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 441}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 450}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 461}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 385}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 415}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 446}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 409}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 421}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 430}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 459}], {
             RGBColor[
             0.8416144411764706, 0.8104576470588236, 0.625219794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 354}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 388}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 436}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 420}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 427}], {
             RGBColor[
             0.8970220882352942, 0.8539625882352943, 0.630683911764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 433}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 500}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 383}], {
             RGBColor[
             0.9030825588235294, 0.7408720588235296, 0.606192794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 395}], {
             RGBColor[0.6227742647058824, 0.514505117647059, 0.5819965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 443}], {
             RGBColor[
             0.9352148823529411, 0.761689117647059, 0.35792644117647054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 480}], {
             RGBColor[
             0.8937932352941177, 0.6088684705882357, 0.2330001176470589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 344}], {
             RGBColor[
             0.920719705882353, 0.6745077647058826, 0.4510252352941179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 387}], {
             RGBColor[
             0.9108142941176471, 0.6427087058823532, 0.2752828823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 439}], {
             RGBColor[0.8876065588235293, 0.651592823529412, 0.592535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 384}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 414}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 461}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 499}], {
             RGBColor[
             0.6676762352941177, 0.7341850588235295, 0.9426508529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 374}], {
             RGBColor[
             0.8787623235294117, 0.781568705882353, 0.6159916764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 391}], {
             RGBColor[
             0.7918034117647059, 0.8375021764705881, 0.9798248235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 397}], {
             RGBColor[
             0.8467659705882353, 0.6190276470588236, 0.5886395882352942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 455}], {
             RGBColor[
             0.6613845882352941, 0.7330628235294117, 0.9685728823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 485}], {
             RGBColor[
             0.599728088235294, 0.6739238529411764, 0.9658996764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 374}], {
             RGBColor[
             0.938695205882353, 0.8285484117647062, 0.5936544705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 403}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 440}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 445}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 471}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 387}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 438}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 439}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 389}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 456}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 472}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 355}], {
             RGBColor[
             0.6188203823529411, 0.6883383823529412, 0.9396670588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 390}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 395}], {
             RGBColor[
             0.6676762352941177, 0.7341850588235295, 0.9426508529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 431}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 443}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 486}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 382}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.830958529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 462}], {
             RGBColor[
             0.5422784705882352, 0.6392851176470589, 0.9571092941176471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 355}], {
             RGBColor[
             0.6328412352941176, 0.696838794117647, 0.8243899117647061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 372}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 400}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 404}], {
             RGBColor[
             0.9361957058823529, 0.7637870000000002, 0.464683029411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 418}], {
             RGBColor[
             0.9361957058823529, 0.7637870000000002, 0.464683029411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 431}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 444}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 486}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 353}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 378}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 380}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 487}], {
             RGBColor[
             0.6781908823529412, 0.7413765882352942, 0.8957315588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 377}], {
             RGBColor[
             0.9108142941176471, 0.6427087058823532, 0.2752828823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 412}], {
             RGBColor[
             0.9066988529411765, 0.6660073529411767, 0.5663023823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 426}], {
             RGBColor[
             0.7913583235294117, 0.5755227058823531, 0.5831754705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 476}], {
             RGBColor[
             0.920719705882353, 0.6745077647058826, 0.4510252352941179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 371}], {
             RGBColor[
             0.47555811764705874`, 0.5851185294117647, 0.9518568235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 442}], {
             RGBColor[0.6764155, 0.5603625882352943, 0.5855813235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 460}], {
             RGBColor[
             0.7254329117647058, 0.7567438823529412, 0.6552161764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 357}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 367}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 368}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 375}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 380}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 487}], {
             RGBColor[
             0.6717916764705882, 0.7108864117647059, 0.6516313529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 388}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 409}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 436}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 473}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 395}], {
             RGBColor[
             0.3194197941176471, 0.4475569117647059, 0.9417033823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 404}], {
             RGBColor[
             0.5739184117647058, 0.46865844117647076`, 0.579012705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 431}], {
             RGBColor[
             0.631860411764706, 0.6947409117647059, 0.7176333235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 443}], {
             RGBColor[
             0.631860411764706, 0.6947409117647059, 0.7176333235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 444}], {
             RGBColor[
             0.5034798529411765, 0.5978537352941176, 0.9565401470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 486}], {
             RGBColor[
             0.6293350294117648, 0.6955299117647059, 0.8927477647058825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 365}], {
             RGBColor[
             0.7213174705882353, 0.7800425294117648, 0.9462356764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 457}], {
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 494}], {
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 367}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 368}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 441}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 492}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 361}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 386}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 398}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 441}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 408}], {
             RGBColor[
             0.3939629117647059, 0.4994228529411765, 0.9479313823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 440}], {
             RGBColor[
             0.5130690294117648, 0.5932005588235294, 0.9593949705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 463}], {
             RGBColor[
             0.5539096176470588, 0.6257657352941177, 0.9632903823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 483}], {
             RGBColor[
             0.5539096176470588, 0.6257657352941177, 0.9632903823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 457}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 494}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 386}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 398}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 441}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 481}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 369}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 470}], {
             RGBColor[
             0.8467659705882353, 0.6190276470588236, 0.5886395882352942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 381}], {
             RGBColor[
             0.6059769411764705, 0.6895578823529411, 0.9631087647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 378}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 380}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 381}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 416}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 452}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 468}], {
             RGBColor[
             0.5539096176470588, 0.6257657352941176, 0.9632903823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 487}], {
             RGBColor[
             0.6485839411764706, 0.7197705294117647, 0.9688834705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 405}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 423}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 429}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 465}], {
             RGBColor[
             0.7779159705882353, 0.7601848823529413, 0.6192203235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 469}], {
             RGBColor[
             0.672697294117647, 0.7437244705882353, 0.9683612352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 488}], {
             RGBColor[
             0.3939629117647059, 0.4994228529411765, 0.9479313823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 368}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 375}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 441}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 450}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 492}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 456}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 390}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 422}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 443}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 451}], {
             RGBColor[
             0.5771173529411765, 0.6168816176470588, 0.6460382647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 442}], {
             RGBColor[0.6764155, 0.5603625882352943, 0.5855813235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 460}], {
             RGBColor[
             0.7254329117647058, 0.7567438823529412, 0.6552161764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 400}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 404}], {
             RGBColor[
             0.9262902941176471, 0.7319879411764708, 0.2889406764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 418}], {
             RGBColor[
             0.9262902941176471, 0.7319879411764708, 0.2889406764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 431}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 444}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 486}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 449}], {
             RGBColor[
             0.7880378235294117, 0.8342091176470589, 0.9514881470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 498}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 397}], {
             RGBColor[
             0.8783172352941178, 0.519589235294118, 0.21934232352941183`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 445}], {
             RGBColor[
             0.9527160588235295, 0.837048823529412, 0.47837732352941204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 402}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 417}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764708, 0.3716207352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 441}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 450}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 461}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 391}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 448}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 455}], {
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 475}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 482}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 412}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 426}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 476}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 380}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 416}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 452}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 487}], {
             RGBColor[
             0.6676762352941177, 0.7341850588235295, 0.9426508529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 400}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 404}], {
             RGBColor[
             0.9361957058823529, 0.7637870000000002, 0.464683029411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 440}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 487}], {
             RGBColor[
             0.6816970882352942, 0.7426854705882353, 0.8273737058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 416}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 468}], {
             RGBColor[
             0.4576613823529412, 0.5496956176470588, 0.9539308529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 425}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 462}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 393}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 395}], {
             RGBColor[
             0.6485839411764706, 0.7197705294117647, 0.9688834705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 443}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 480}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529414, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 402}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 411}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 458}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 461}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 499}], {
             RGBColor[
             0.6676762352941177, 0.7341850588235295, 0.9426508529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 415}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 446}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 441}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 498}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 439}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 436}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 473}], {
             RGBColor[
             0.9674696176470589, 0.908133823529412, 0.561427411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 456}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 472}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 422}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 443}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 451}], {
             RGBColor[
             0.5130690294117647, 0.5932005588235294, 0.9593949705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 407}], {
             RGBColor[
             0.7918034117647059, 0.8375021764705881, 0.9798248235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 448}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 455}], {
             RGBColor[
             0.6059769411764705, 0.6895578823529411, 0.9631087647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 475}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 478}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 482}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 413}], {
             RGBColor[
             0.5130690294117647, 0.5932005588235294, 0.9593949705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 473}], {
             RGBColor[
             0.8970220882352942, 0.8539625882352943, 0.630683911764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 474}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 490}], {
             RGBColor[
             0.6613845882352941, 0.7330628235294117, 0.9685728823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 424}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 480}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058826, 0.30263497058823535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 467}], {
             RGBColor[
             0.961070411764706, 0.8776436470588238, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 443}], {
             RGBColor[
             0.6807162647058824, 0.7405875882352941, 0.7206171176470587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 430}], {
             RGBColor[
             0.6717916764705882, 0.7108864117647059, 0.6516313529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 477}], {
             RGBColor[
             0.4886372352941176, 0.5934276470588236, 0.9535244705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 495}], {
             RGBColor[
             0.8467659705882353, 0.6190276470588236, 0.5886395882352942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 399}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 464}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 481}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 496}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 407}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 464}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 478}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 481}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 496}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 404}], {
             RGBColor[
             0.9262902941176471, 0.7319879411764708, 0.2889406764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 418}], {
             RGBColor[
             0.9262902941176471, 0.7319879411764708, 0.2889406764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 431}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.427561294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 444}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 428}], {
             RGBColor[
             0.9674696176470589, 0.908133823529412, 0.561427411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 437}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058825, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 451}], {
             RGBColor[
             0.5628800588235294, 0.5661560294117649, 0.6047899411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 417}], {
             RGBColor[
             0.8233546764705882, 0.7380637647058825, 0.6105275588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 458}], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 461}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 440}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 445}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 471}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 483}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 497}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529414, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 418}], {
             RGBColor[
             0.8772728823529412, 0.5356066470588239, 0.21930582352941183`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 431}], {
             RGBColor[
             0.9352148823529411, 0.761689117647059, 0.35792644117647054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 444}], {
             RGBColor[
             0.8068343235294118, 0.6648019411764707, 0.5968332647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 486}], {
             RGBColor[0.9326895, 0.762478117647059, 0.5330408823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 423}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 429}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 472}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 488}], {
             RGBColor[
             0.5835165588235294, 0.6473717941176471, 0.8901384705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 419}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 493}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 448}], {
             RGBColor[0.9201839705882353, 0.9343893529411764, 0.740918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 455}], {
             RGBColor[
             0.6613845882352941, 0.7330628235294117, 0.9685728823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 475}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 478}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 482}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{408, 463}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 430}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 422}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 428}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 437}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{412, 426}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{412, 476}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 474}], {
             RGBColor[
             0.5860419411764706, 0.6465827941176472, 0.7150240294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 490}], {
             RGBColor[
             0.3272425588235294, 0.4452562647058823, 0.9426789117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 461}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 498}], {
             RGBColor[
             0.9674696176470589, 0.908133823529412, 0.561427411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 499}], {
             RGBColor[
             0.6781908823529412, 0.7413765882352942, 0.8957315588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 452}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 468}], {
             RGBColor[
             0.5771173529411765, 0.6168816176470588, 0.6460382647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{417, 458}], {
             RGBColor[
             0.8233546764705882, 0.7380637647058825, 0.6105275588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 431}], {
             RGBColor[
             0.9352148823529411, 0.761689117647059, 0.35792644117647054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 444}], {
             RGBColor[
             0.8068343235294118, 0.6648019411764707, 0.5968332647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 486}], {
             RGBColor[0.9326895, 0.762478117647059, 0.5330408823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 427}], {
             RGBColor[0.969995, 0.9073448235294119, 0.3863129705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 454}], {
             RGBColor[
             0.6318604117647059, 0.6947409117647059, 0.7176333235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 489}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 500}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.718580794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 430}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 459}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 477}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 428}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 437}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 451}], {
             RGBColor[
             0.5539096176470588, 0.6257657352941176, 0.9632903823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 429}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 465}], {
             RGBColor[
             0.9674696176470589, 0.908133823529412, 0.561427411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 469}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 488}], {
             RGBColor[
             0.5835165588235294, 0.6473717941176471, 0.8901384705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{425, 462}], {
             RGBColor[
             0.7880378235294117, 0.8342091176470589, 0.9514881470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 476}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 433}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 500}], {
             RGBColor[
             0.9569549705882353, 0.9009422941176473, 0.6083467058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 437}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 451}], {
             RGBColor[
             0.5835165588235294, 0.6473717941176471, 0.8901384705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{429, 488}], {
             RGBColor[
             0.5870227647058823, 0.6486806764705882, 0.821780617647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{430, 459}], {
             RGBColor[
             0.961070411764706, 0.8776436470588238, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{430, 477}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 444}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 486}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{432, 460}], {
             RGBColor[
             0.9108142941176471, 0.6427087058823532, 0.2752828823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 465}], {
             RGBColor[
             0.9709758235294118, 0.9094427058823531, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 469}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 495}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{435, 439}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{435, 453}], {
             RGBColor[
             0.9221748529411764, 0.7552865882352944, 0.5799601764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 473}], {
             RGBColor[
             0.9674696176470589, 0.908133823529412, 0.561427411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 439}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{439, 453}], {
             RGBColor[
             0.9030825588235294, 0.7408720588235296, 0.606192794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 445}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 471}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 450}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 461}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 447}], {
             RGBColor[
             0.5280999411764706, 0.4205003235294119, 0.5764034117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 500}], {
             RGBColor[
             0.9221748529411764, 0.7552865882352944, 0.5799601764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{443, 451}], {
             RGBColor[
             0.5860419411764706, 0.6465827941176471, 0.7150240294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{444, 486}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{445, 471}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 454}], {
             RGBColor[
             0.2247454705882353, 0.35355211764705885`, 0.9361102941176471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 500}], {
             RGBColor[
             0.5730019117647058, 0.6401802647058823, 0.9370577647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 455}], {
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 475}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 478}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 482}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{449, 499}], {
             RGBColor[
             0.4886372352941176, 0.5934276470588236, 0.9535244705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 461}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{452, 468}], {
             RGBColor[
             0.5835165588235294, 0.6473717941176471, 0.8901384705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 489}], {
             RGBColor[
             0.6293350294117648, 0.6955299117647059, 0.8927477647058825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 500}], {
             RGBColor[
             0.6188203823529412, 0.6883383823529412, 0.9396670588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{455, 475}], {
             RGBColor[0.7022251764705881, 0.765628, 0.972468294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{455, 482}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.830958529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{457, 494}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.7448134117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{458, 461}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{459, 477}], {
             RGBColor[
             0.7779159705882353, 0.7601848823529413, 0.6192203235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{460, 463}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{463, 483}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 481}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 496}], {
             RGBColor[
             0.672697294117647, 0.7437244705882353, 0.9683612352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{465, 469}], {
             RGBColor[
             0.8416144411764706, 0.8104576470588236, 0.6252197941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 470}], {
             RGBColor[
             0.8965770000000001, 0.5919831176470591, 0.23403455882352947`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 491}], {
             RGBColor[
             0.9468331176470589, 0.8269180588235298, 0.27607888235294126`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 483}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 497}], {
             RGBColor[
             0.9527160588235295, 0.837048823529412, 0.47837732352941204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{472, 488}], {
             RGBColor[
             0.5835165588235294, 0.6473717941176471, 0.8901384705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{474, 490}], {
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{475, 478}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{475, 482}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{478, 482}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{481, 496}], {
             RGBColor[
             0.7880378235294117, 0.8342091176470589, 0.9514881470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{484, 490}], {
             RGBColor[
             0.7111956176470589, 0.7060182941176472, 0.6139678529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{489, 500}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.028685633809430733`], {
             RGBColor[
             0.9103135882352942, 0.6821302941176475, 0.24669441176470597`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.028685633809430733`], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.028685633809430733`], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.028685633809430733`], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.028685633809430733`], {
             RGBColor[
             0.9468331176470589, 0.8269180588235298, 0.27607888235294126`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.028685633809430733`], {
             RGBColor[
             0.8772728823529412, 0.5356066470588239, 0.21930582352941183`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.028685633809430733`], {
             RGBColor[
             0.2705639411764706, 0.40171023529411765`, 0.9387195882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.028685633809430733`], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.028685633809430733`], {
             RGBColor[
             0.47555811764705874`, 0.5851185294117647, 0.9518568235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.028685633809430733`], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.028685633809430733`], {
             RGBColor[
             0.36827564705882354`, 0.4934035882352941, 0.9446871764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.028685633809430733`], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.028685633809430733`], {
             RGBColor[
             0.9468331176470589, 0.8269180588235298, 0.27607888235294126`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.028685633809430733`], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.028685633809430733`], {
             RGBColor[
             0.9468331176470589, 0.8269180588235298, 0.27607888235294126`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.028685633809430733`], {
             RGBColor[
             0.47555811764705874`, 0.5851185294117647, 0.9518568235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.028685633809430733`], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.028685633809430733`], {
             RGBColor[
             0.36827564705882354`, 0.4934035882352941, 0.9446871764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.028685633809430733`], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.028685633809430733`], {
             RGBColor[
             0.9103135882352942, 0.6821302941176475, 0.24669441176470597`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.028685633809430733`], {
             RGBColor[
             0.2705639411764706, 0.40171023529411765`, 0.9387195882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.028685633809430733`], {
             RGBColor[
             0.2705639411764706, 0.40171023529411765`, 0.9387195882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.028685633809430733`], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.028685633809430733`], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.028685633809430733`], {
             RGBColor[
             0.36827564705882354`, 0.4934035882352941, 0.9446871764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.028685633809430733`], {
             RGBColor[
             0.2705639411764706, 0.40171023529411765`, 0.9387195882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.028685633809430733`], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.028685633809430733`], {
             RGBColor[
             0.8772728823529412, 0.5356066470588239, 0.21930582352941183`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.028685633809430733`], {
             RGBColor[
             0.36827564705882354`, 0.4934035882352941, 0.9446871764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.028685633809430733`], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.028685633809430733`], {
             RGBColor[
             0.8463208823529412, 0.3570481764705886, 0.19199023529411768`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.028685633809430733`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.028685633809430733`], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.028685633809430733`], {
             RGBColor[
             0.9103135882352942, 0.6821302941176475, 0.24669441176470597`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.028685633809430733`], {
             RGBColor[
             0.47555811764705874`, 0.5851185294117647, 0.9518568235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.028685633809430733`], {
             RGBColor[
             0.8772728823529412, 0.5356066470588239, 0.21930582352941183`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.028685633809430733`], {
             RGBColor[
             0.36827564705882354`, 0.4934035882352941, 0.9446871764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.028685633809430733`], {
             RGBColor[
             0.8772728823529412, 0.5356066470588239, 0.21930582352941183`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.028685633809430733`], {
             RGBColor[
             0.8772728823529412, 0.5356066470588239, 0.21930582352941183`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.028685633809430733`], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.028685633809430733`], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.028685633809430733`], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.028685633809430733`], {
             RGBColor[
             0.9103135882352942, 0.6821302941176475, 0.24669441176470597`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.028685633809430733`], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.028685633809430733`], {
             RGBColor[
             0.36827564705882354`, 0.4934035882352941, 0.9446871764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.028685633809430733`], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.028685633809430733`], {
             RGBColor[
             0.2705639411764706, 0.40171023529411765`, 0.9387195882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.028685633809430733`], {
             RGBColor[
             0.36827564705882354`, 0.4934035882352941, 0.9446871764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.028685633809430733`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.028685633809430733`], {
             RGBColor[
             0.9103135882352942, 0.6821302941176475, 0.24669441176470597`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.028685633809430733`], {
             RGBColor[
             0.9468331176470589, 0.8269180588235298, 0.27607888235294126`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.028685633809430733`], {
             RGBColor[
             0.9103135882352942, 0.6821302941176475, 0.24669441176470597`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.028685633809430733`], {
             RGBColor[
             0.9103135882352942, 0.6821302941176475, 0.24669441176470597`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.028685633809430733`], {
             RGBColor[
             0.9103135882352942, 0.6821302941176475, 0.24669441176470597`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.028685633809430733`], {
             RGBColor[
             0.9468331176470589, 0.8269180588235298, 0.27607888235294126`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.028685633809430733`], {
             RGBColor[
             0.8463208823529412, 0.3570481764705886, 0.19199023529411768`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.028685633809430733`], {
             RGBColor[
             0.9103135882352942, 0.6821302941176475, 0.24669441176470597`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.028685633809430733`], {
             RGBColor[
             0.9103135882352942, 0.6821302941176475, 0.24669441176470597`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.028685633809430733`], {
             RGBColor[
             0.47555811764705874`, 0.5851185294117647, 0.9518568235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.028685633809430733`], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.028685633809430733`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.028685633809430733`], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.028685633809430733`], {
             RGBColor[
             0.47555811764705874`, 0.5851185294117647, 0.9518568235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.028685633809430733`], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.028685633809430733`], {
             RGBColor[
             0.36827564705882354`, 0.4934035882352941, 0.9446871764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.028685633809430733`], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.028685633809430733`], {
             RGBColor[
             0.36827564705882354`, 0.4934035882352941, 0.9446871764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.028685633809430733`], {
             RGBColor[
             0.9103135882352942, 0.6821302941176475, 0.24669441176470597`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.028685633809430733`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.028685633809430733`], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.028685633809430733`], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.028685633809430733`], {
             RGBColor[
             0.36827564705882354`, 0.4934035882352941, 0.9446871764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.028685633809430733`], {
             RGBColor[
             0.36827564705882354`, 0.4934035882352941, 0.9446871764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.028685633809430733`], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.028685633809430733`], {
             RGBColor[
             0.9103135882352942, 0.6821302941176475, 0.24669441176470597`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.028685633809430733`], {
             RGBColor[
             0.36827564705882354`, 0.4934035882352941, 0.9446871764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.028685633809430733`], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.028685633809430733`], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.028685633809430733`], {
             RGBColor[
             0.9103135882352942, 0.6821302941176475, 0.24669441176470597`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.028685633809430733`], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.028685633809430733`], {
             RGBColor[
             0.9468331176470589, 0.8269180588235298, 0.27607888235294126`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.028685633809430733`], {
             RGBColor[
             0.47555811764705874`, 0.5851185294117647, 0.9518568235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.028685633809430733`], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.028685633809430733`], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.028685633809430733`], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.028685633809430733`], {
             RGBColor[
             0.2705639411764706, 0.40171023529411765`, 0.9387195882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.028685633809430733`], {
             RGBColor[
             0.9468331176470589, 0.8269180588235298, 0.27607888235294126`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.028685633809430733`], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.028685633809430733`], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.028685633809430733`], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.028685633809430733`], {
             RGBColor[
             0.8772728823529412, 0.5356066470588239, 0.21930582352941183`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.028685633809430733`], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.028685633809430733`], {
             RGBColor[
             0.8463208823529412, 0.3570481764705886, 0.19199023529411768`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.028685633809430733`], {
             RGBColor[
             0.9103135882352942, 0.6821302941176475, 0.24669441176470597`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.028685633809430733`], {
             RGBColor[
             0.9468331176470589, 0.8269180588235298, 0.27607888235294126`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.028685633809430733`], {
             RGBColor[
             0.9103135882352942, 0.6821302941176475, 0.24669441176470597`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.028685633809430733`], {
             RGBColor[
             0.9468331176470589, 0.8269180588235298, 0.27607888235294126`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.028685633809430733`], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.028685633809430733`], {
             RGBColor[
             0.36827564705882354`, 0.4934035882352941, 0.9446871764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.028685633809430733`], {
             RGBColor[
             0.36827564705882354`, 0.4934035882352941, 0.9446871764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.028685633809430733`], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.028685633809430733`], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.028685633809430733`], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.028685633809430733`], {
             RGBColor[
             0.9468331176470589, 0.8269180588235298, 0.27607888235294126`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.028685633809430733`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.028685633809430733`], {
             RGBColor[
             0.8463208823529412, 0.3570481764705886, 0.19199023529411768`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.028685633809430733`], {
             RGBColor[
             0.9103135882352942, 0.6821302941176475, 0.24669441176470597`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.028685633809430733`], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.028685633809430733`], {
             RGBColor[
             0.47555811764705874`, 0.5851185294117647, 0.9518568235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.028685633809430733`], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.028685633809430733`], {
             RGBColor[
             0.9103135882352942, 0.6821302941176475, 0.24669441176470597`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.028685633809430733`], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.028685633809430733`], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.028685633809430733`], {
             RGBColor[
             0.9468331176470589, 0.8269180588235298, 0.27607888235294126`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.028685633809430733`], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.028685633809430733`], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.028685633809430733`], {
             RGBColor[
             0.9468331176470589, 0.8269180588235298, 0.27607888235294126`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.028685633809430733`], {
             RGBColor[
             0.9103135882352942, 0.6821302941176475, 0.24669441176470597`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.028685633809430733`], {
             RGBColor[
             0.47555811764705874`, 0.5851185294117647, 0.9518568235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.028685633809430733`], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.028685633809430733`], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.028685633809430733`], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.028685633809430733`], {
             RGBColor[
             0.8772728823529412, 0.5356066470588239, 0.21930582352941183`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.028685633809430733`], {
             RGBColor[
             0.9103135882352942, 0.6821302941176475, 0.24669441176470597`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.028685633809430733`], {
             RGBColor[
             0.9468331176470589, 0.8269180588235298, 0.27607888235294126`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.028685633809430733`], {
             RGBColor[
             0.9468331176470589, 0.8269180588235298, 0.27607888235294126`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.028685633809430733`], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.028685633809430733`], {
             RGBColor[
             0.47555811764705874`, 0.5851185294117647, 0.9518568235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.028685633809430733`], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.028685633809430733`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.028685633809430733`], {
             RGBColor[
             0.2705639411764706, 0.40171023529411765`, 0.9387195882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.028685633809430733`], {
             RGBColor[
             0.36827564705882354`, 0.4934035882352941, 0.9446871764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.028685633809430733`], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.028685633809430733`], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.028685633809430733`], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.028685633809430733`], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.028685633809430733`], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.028685633809430733`], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.028685633809430733`], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.028685633809430733`], {
             RGBColor[
             0.8772728823529412, 0.5356066470588239, 0.21930582352941183`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.028685633809430733`], {
             RGBColor[
             0.8463208823529412, 0.3570481764705886, 0.19199023529411768`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.028685633809430733`], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.028685633809430733`], {
             RGBColor[
             0.2705639411764706, 0.40171023529411765`, 0.9387195882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.028685633809430733`], {
             RGBColor[
             0.47555811764705874`, 0.5851185294117647, 0.9518568235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.028685633809430733`], {
             RGBColor[
             0.8463208823529412, 0.3570481764705886, 0.19199023529411768`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.028685633809430733`], {
             RGBColor[
             0.47555811764705874`, 0.5851185294117647, 0.9518568235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.028685633809430733`], {
             RGBColor[
             0.2705639411764706, 0.40171023529411765`, 0.9387195882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.028685633809430733`], {
             RGBColor[
             0.47555811764705874`, 0.5851185294117647, 0.9518568235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.028685633809430733`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.028685633809430733`], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.028685633809430733`], {
             RGBColor[
             0.47555811764705874`, 0.5851185294117647, 0.9518568235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.028685633809430733`], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.028685633809430733`], {
             RGBColor[
             0.47555811764705874`, 0.5851185294117647, 0.9518568235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.028685633809430733`], {
             RGBColor[
             0.9103135882352942, 0.6821302941176475, 0.24669441176470597`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.028685633809430733`], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.028685633809430733`], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.028685633809430733`], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.028685633809430733`], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.028685633809430733`], {
             RGBColor[
             0.36827564705882354`, 0.4934035882352941, 0.9446871764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.028685633809430733`], {
             RGBColor[
             0.36827564705882354`, 0.4934035882352941, 0.9446871764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.028685633809430733`], {
             RGBColor[
             0.8463208823529412, 0.3570481764705886, 0.19199023529411768`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[401, 0.028685633809430733`], {
             RGBColor[
             0.9468331176470589, 0.8269180588235298, 0.27607888235294126`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[402, 0.028685633809430733`], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[403, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[404, 0.028685633809430733`], {
             RGBColor[
             0.8772728823529412, 0.5356066470588239, 0.21930582352941183`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[405, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[406, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[407, 0.028685633809430733`], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[408, 0.028685633809430733`], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[409, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[410, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[411, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[412, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[413, 0.028685633809430733`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[414, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[415, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[416, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[417, 0.028685633809430733`], {
             RGBColor[
             0.9103135882352942, 0.6821302941176475, 0.24669441176470597`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[418, 0.028685633809430733`], {
             RGBColor[
             0.8772728823529412, 0.5356066470588239, 0.21930582352941183`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[419, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[420, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[421, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[422, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[423, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[424, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[425, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[426, 0.028685633809430733`], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[427, 0.028685633809430733`], {
             RGBColor[
             0.9468331176470589, 0.8269180588235298, 0.27607888235294126`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[428, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[429, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[430, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[431, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[432, 0.028685633809430733`], {
             RGBColor[
             0.8463208823529412, 0.3570481764705886, 0.19199023529411768`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[433, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[434, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[435, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[436, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[437, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[438, 0.028685633809430733`], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[439, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[440, 0.028685633809430733`], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[441, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[442, 0.028685633809430733`], {
             RGBColor[
             0.8772728823529412, 0.5356066470588239, 0.21930582352941183`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[443, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[444, 0.028685633809430733`], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[445, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[446, 0.028685633809430733`], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[447, 0.028685633809430733`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[448, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[449, 0.028685633809430733`], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[450, 0.028685633809430733`], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[451, 0.028685633809430733`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[452, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[453, 0.028685633809430733`], {
             RGBColor[
             0.8772728823529412, 0.5356066470588239, 0.21930582352941183`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[454, 0.028685633809430733`], {
             RGBColor[
             0.2705639411764706, 0.40171023529411765`, 0.9387195882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[455, 0.028685633809430733`], {
             RGBColor[
             0.47555811764705874`, 0.5851185294117647, 0.9518568235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[456, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[457, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[458, 0.028685633809430733`], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[459, 0.028685633809430733`], {
             RGBColor[
             0.9468331176470589, 0.8269180588235298, 0.27607888235294126`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[460, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[461, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[462, 0.028685633809430733`], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[463, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[464, 0.028685633809430733`], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[465, 0.028685633809430733`], {
             RGBColor[
             0.9468331176470589, 0.8269180588235298, 0.27607888235294126`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[466, 0.028685633809430733`], {
             RGBColor[
             0.9468331176470589, 0.8269180588235298, 0.27607888235294126`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[467, 0.028685633809430733`], {
             RGBColor[
             0.9468331176470589, 0.8269180588235298, 0.27607888235294126`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[468, 0.028685633809430733`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[469, 0.028685633809430733`], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[470, 0.028685633809430733`], {
             RGBColor[
             0.8463208823529412, 0.3570481764705886, 0.19199023529411768`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[471, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[472, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[473, 0.028685633809430733`], {
             RGBColor[
             0.9468331176470589, 0.8269180588235298, 0.27607888235294126`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[474, 0.028685633809430733`], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.49654705882352923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[475, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[476, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[477, 0.028685633809430733`], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[478, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[479, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[480, 0.028685633809430733`], {
             RGBColor[
             0.9103135882352942, 0.6821302941176475, 0.24669441176470597`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[481, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[482, 0.028685633809430733`], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[483, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[484, 0.028685633809430733`], {
             RGBColor[
             0.9468331176470589, 0.8269180588235298, 0.27607888235294126`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[485, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[486, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[487, 0.028685633809430733`], {
             RGBColor[
             0.36827564705882354`, 0.4934035882352941, 0.9446871764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[488, 0.028685633809430733`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[489, 0.028685633809430733`], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[490, 0.028685633809430733`], {
             RGBColor[
             0.47555811764705874`, 0.5851185294117647, 0.9518568235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[491, 0.028685633809430733`], {
             RGBColor[
             0.9468331176470589, 0.8269180588235298, 0.27607888235294126`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[492, 0.028685633809430733`], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[493, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[494, 0.028685633809430733`], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[495, 0.028685633809430733`], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[496, 0.028685633809430733`], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[497, 0.028685633809430733`], {
             RGBColor[
             0.9103135882352942, 0.6821302941176475, 0.24669441176470597`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[498, 0.028685633809430733`], {
             RGBColor[
             0.9468331176470589, 0.8269180588235298, 0.27607888235294126`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[499, 0.028685633809430733`], {
             RGBColor[
             0.36827564705882354`, 0.4934035882352941, 0.9446871764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[500, 0.028685633809430733`], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1dOWGAgQBNBMbNu2bds2J+bEtm3btm3btu01sjdnH271F1R1ssCg6p0C
ggUL9l38vMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEIS
kZgkJCUZyUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpR
mCIUpRjFKUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGY
JjSlGYE0pwUtaUVr2tCWdrSnAx3pRBCd6UJXutGdHvSkF73pQ1/60Z8BDGQQ
gxnCUIYxnBGMZBSjGcNYxjGeCUxkEpOZwlSmMZ0ZzGQWs5nDXOYxnwUsZBGL
WcJSlrGcFaxkFatZw1rWsZ4NbGQTm9nCVraxnR3sZBe72cNe9rGfAxzkEIc5
wlGOcZwTnOQUpznDWc5xngtc5BKXucJVrnGdG9zkFre5w13ucZ8HPOQRj3nC
U57xnBe85BWvecNb3vGeD3zkE5/5wle+8Z1f+JXf+J0/+JO/+Jt/+Jcf/Cx/
AMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEISkZgkJCUZ
yUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpRmCIUpRjF
KUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGYJjSlGYE0
pwUtaUVr2tCWdrSnAx35Od5BdKYLXelGd3rQk170pg996Ud/BjCQQQxmCEMZ
xnBGMJJRjGYMYxnHeCYwkUlMZgpTmcZ0ZjCTWcxmDnOZx3wWsJBFLGYJS1nG
clawklWsZg1rWcd6NrCRTWxmC1vZxnZ2sJNd7GYPe9nHfg5wkEMc5ghHOcZx
TnCSU5zmDGc5x3kucJFLXOYKV7nGdW5wk1vc5g53ucd9HvCQRzzmCU95xnNe
8JJXvOYNb3nHez7wkU985gtf+Rbw/z//Dz189+A=
          "], {Null, CompressedData["
1:eJxF3Al0ldW5gOF/21YsVqt2QFCqdkClVEWUGRVRJmWoghGKIgREKWUqk4DM
MSCTTAmozEMQUCJjEAMUZAhDSUCGmoo0QGkEEUnpbcV673nZL+uu5beeJjnn
P+ffw7e/vc+hd3Tu9VTPq5IkefYHSYJXhSRZnYoeqf+9KRWp/3n5f5dPRd/U
DydSXp8yN+XOEH9/POWwlG1CfPw8n4/fS9ktFdel4lOunXKurkt5PuWXXvfa
EIPrhVTkp+Jer8Pj7woxnta5us7XSQ/xtfD7KXv7vCY+rokx1+tXNPJ9fPMQ
o7f3tdTgvpd6n3k+viT1c0bKOf69Gm2SitdSPz+Y8uok/u1q//6blIUplySx
fT9P2TrEGJOKBrYnj78/5bKUP7B9VoUYtNPw1M/1U96dirG+/lrff1fff1fj
yv1fNGingiS+V6ybstg+x3yv92aIwXUXp37+SYjRxuedMbjOGdsBc329lrZz
S2Ou/TPSsTDS4D5H2l+0z+QQg3aqnMR75HX7pyI7iW2e7Wtn+7p3pHwyifL6
sx23VZLYVlVsryq2N47xfr8K8d6/sv0nOh4mGl86Th7z9zgiifc4wjYd4bgc
4bgeYTszDwb592M+55jB4/FpXee4P+U4eyrEOO74r2Ws8vpVbOcqPh+rOMar
2PZVbPcqzo/Oqce9nMR+WGjQ7siYHpOyi+3Xxf6YadAnMx2/zPuSEO8dGbP4
nH2CBXpGq/n3DM21f18Jse+6hRi8j6ucr1c5ju5MYi7B2brJeZWfxHma7zzN
N/ra/n18fB+v0cfYpJ1CzFvXpXwp5QXjOsfrePtjvP2B6cq9LjBKNMPnFTnO
i2znIiPdeX3YYH6TF08msZ9Pel9rvS+co0t1rfe41vukP7KdN9nGTi2x/V4w
Zut5+6pdiO8bS/SMEtxPBduwgs+t4HUqeB3auV6I7Yt9dJAStPNNjoWbHB83
OT5ucnzc5LigHXY53ncZtAt59afmJ/yj7YdTndd5SZzzeQbzHlsr85482SLE
vIbkS6yViiLH51nf41mD94d1HVcDjUHK+nQo5WYtdVxVCnE8IWMKH0nie8Zl
+gPnwQnnwQnH4xDnJxbpEOcJ1y/z+mVev8zXwDZKu9b0ejV9fE0fX9PH49Qk
rk208zcG6xh9XmB+QHIgdtFf2L/4eojjd4gxR1lLcK3jqYbxgp5Xro0TtUDJ
w5kpDxpnfZ9LQ6wb8Bslj+KDSs7bl4pZ9uksnz/L/kyVPZfrkruTeI/YxZ8L
9JSPq+B8xZNKfOq4qGr00D46UJkLVR0vvP8DxjfKez7gfSD5/3nb8Hnb83nb
83nbk/XrBmO1sp5NcrxP8v7o338bT/v8KfbLFOcVMremGFyfPL0sxFy9zP69
J8T8hEt1reYr0dd5+ZsQ5+VvnIdI1NfWyvtlDG73vrZ7P9u9t+22P419r9bS
XXpSWT+2JXEdw5lKkCsXOS6wvv132v7BHtpHNyl9eNoxf9rXqR3iuoyrlWii
LXWujz8f4vvCmbpNeW9YqDx+gPcxwJip25TnYKGed97nJDGf5RgFekbPKvkN
c329vsYIXa3UEniX1tYm2lK5T/JrnRDXJ6SOq2OwNj2S+v2RJObCIwZ5nDps
VRKfj7m6yutgtrLOkbdzjCLnaWXHSWXHf2XnaWXjUx93Y4hRQSsrf2+bxDmD
S7TU+XCPMUmpU/EVHavLfB9pSZwHaUaenlQGX5rvE1sr82FGEnM2XufPlbSm
ksd+7Hv5sc/7se/j50kcu/gLf+6i5GvqldIk1iu4UIuUoG7BIT7+wxAfjyN1
kRZpqfJcJI+eCzHHIu8BC7RcEvu+nH1ezj4vZ7+Xs9/L2e9YYj9OsJ8n2H8T
7NMJ9ukEg35l/f9ZiNFcuyr7JebLrhDrI1ygOXpGmTPYTjOU8fHzEONu39/8
JI6D+fb3fMfOfIP3jBW0sk5Q3jf5enwS8/V4Y46Ss3GKvqlrbadM51Wm8zHT
+ZPpfMw0snWnlvj8QT4PL+ogHzPIxw/y8azHzUI8I8DlSdxr4VX+fIOyTo1I
uT7EOYbH9N9KzsGndbWuU4J14WdJzAWYo0XOg4rGIiXfV3R+XOvvrvXvuE/r
+/cPnS8HQ5xLyFzC15X+XG9/rjfo1/X263r7db39uj75/zxU5vgo8/llPr/M
4DplXqfM65R5nTKvQ76fl8R9MD6n2Urk6BllDGOGkv9fSWINi5v9mbx3fxJr
Trygbfx9fy1zvNzpeMM7HSc4URkvNyQxx+NP/LmOUo/fx3UNxlKTJNaAOEsL
9KCyntFP1ZKYb6oZY3S2knuwQMk/5L20EPf7WFGJPOV85DtJnIM4XufoT/37
FGX+Ub/uSWJ77DG49h7bBx/TibbjaONzpX1xlX7p+y0fYqRpN83TfD1hv7S1
X9r6em3tj7ZGpk5U+mlKEtdl6vaxSay7sJa+oMR5XWX/TbD/Jhj0Y9Mkznlc
rcf0olbxcet0vTLPya/vG+RYJM9yvjEsxHof9ylnTEjeH+j9IDHV33c0WAOw
uXbV3j5uq89HxuhWr4PU8+8ZB/Qbpa5H6vrUf8nHIdaZeK/u0pPKHuFjx0Oj
EPdvOEMvKDUBVtKaSjAfqRt/GWJdiDN1mxKTtVDPe7+9vP9e3jfSRthcW2hX
JXrrQKV9yCPLQ8xP65K4311nMG7xyjjdEuJ6gxeV9WWLYxSzdYvjFEt83xtC
zCMbfJ8bfJ8bfJ8bfF8bfI8bjK2297tJzHU4Q4kLSptjJa2pjZR2vy/E9Qhz
dLmyLrFOlgsxrlX2mdP9PV6rx/WU4/+vIdZ6SM2Jy5R1IMtxkuX7wQLlvWc5
XrIcL1hXeX71ENcPnKc5WqBnlDWkulFTs5T1hHWtnnmjnpGmu/SkMjmwgjL+
U/8lvw9xD42DlHy/PYlrwXajQM9qXR/3gPeDB/WMnlXu4wEjQ6nnWP/XJLFG
wEVK7FPyC/vh4SHuhzFfOTccboxX+vOaJO4pcKou0dX+fb1utx0+CjFv4L3a
Q3cpeeMj42Pv/50krp3vGAf1rHKvuMvHdw/x8d39fXfbrbvt0t3x+EyIa9cz
BuOTfNM0xPmLxGTNVvIM+fCREHMlfqNEMyVffjeJNQwu0BJt59+vnLvuTeK+
BEcqwRqA6Uo9R921OMT6CamxsIIS1FXkrRrO2xoG85h97utJXMteN1brMWUd
w7v0aZ2rrG/UCdtCPFfZ5jjC8TpH12q+UmvgPdpXpyjXXeF18XkdouN1jvI8
fFOJtbrN+XNriH2B83SB5miJntFbnVvYTjM0V6/smxoa7yvrO7K+k89HhVgz
IjUj1tEWSpDL2V8UGuw7sLye0K9s75sdz7hUDyg5+GbjKR2ux22XiUa2ztMF
mqNnlHvGatpOMzRXaRfOY74b4vqN25SorU21pU7WbMf57iTuK3C9EmXK2McK
Wlkn6GL91Hn2oxDnGY7UvVqkpUqkK/OuehJrYtyjj/n7iUpdTr2xO8Qabbfj
49skrns4SQnWQFymrIOp/5KhSVw3cJASrB9IriTfHQgx3+EsXabb9aAe1rP6
K+/hV94PBn9fUR/TNJ2o1OfXJzHv4yG9wd+v1s26XdmPtUziGMdivcrfD9Kv
fPwlr33J4HGXfJ1Lvs4lX+eSr0MddizEPH7M8XTMsYaZOlmzdYsS1GPsvz8J
cf3ENbpPmds4Vu9I/b5XEuvDXsY6pU5E5u8Pk1ir4TCdoe/qBb3Ox1fSRnql
Pj6axLr4qEENjJO10PYotj1wlV5U2gUHaaZm6xbdqcW2UbHtRJ7+hfG8DlFy
Mq5Q8vJPkzhG8bD+wN8fsB07htiOHW03XKfUeSuSOP7xOZ2lOUps1wI9qGf0
rJLP8AGtq7wf9i+vGjP0Xb2g9NOr9hNW15raSLO83r0hfq6ABOeT5LtbQsxz
uFvLlFx3izFBFyv5jXq1c4jntZim8zVPyZHYWgnOXdmH/jjEvIjE/TrM67Yy
hmuefq58FoL1tbWOcZwscRzgEJ2jazVfqQ+wr76pxApdq9scPw8Yy/SwMr4e
sD+pS+cmMb9gUyWW6CUlz+BqXa/kGeq3f4R4Xoclyt4JczT1XzI4xM+isar2
0D66SfmcZrAxTz9SPrehrvvIOKTUdbhZS31fGQY1INbSjpqjvE/W65Eh1oc4
Ql/X1UptiHdpbW2iLZW48rnRo0ZfHaGr9aKSq7GK1tYm2lJHKtfnvGZHEs9r
cIISnNuQL/8UYs7FYTpaP9cLylzF/kqQb9mfPxziuQJynvCw0Vy7KucI1Bun
k1hv4EItUqJUqTEwXccrdQf5bm+IeRGf1F46T9cpuQc7aq6ynv3FeYxpOknz
lPyAnXWMjtXL+/kkngOcMi6fASR+FyiJNSYe11OO2w9C3Id84Pv7wNjsvHw2
xPn4rPMMl+gx/beyJ3nWWKfMT9a7hiGeF+Iq5bywodFW+2umTlTWOj7fmx9i
PYdHlHMXnKoEdR75t2qI+1uspfV0l55UEkNV42NfZ1+I+wFsowN1qm7Qrbpb
b3cOYa6u1ov6XR9XW5tqS83WLVqsx5T1nnr27RDrWWyo7+u3Sn2EryixTKlz
yTs/DDHu0xpaSzsqY6RuEvsEp+gRHejfpyp9ckfKlUmcL9hLiXVaqLwOdlPq
NNataUlcr6cZn+sFZe3GRkqu4Ly5ZxLP57GGvqDEbOU8HwuU83zW/z8b3ypt
iBOU9qNO3mlc1Mufadl/l/+mxVpiu+wPsV2wl67UdUpb4F4laBfqrj4h7jvw
HT2o1FDYXQn2g+TD9iHmQxypSzVf9+ppLVVyJN6jRLqSL6mf3gtxHuJ8Xa+7
tUypp7CC3qKVdYIuVoI6i/1PgxDzObJnwvJaUYk0zVP2TeSnds7HdkaurlLm
ZTv7EzM1W7foTi3WY0o/cz6w0fbeaDvjWs1X2hOf0vaarn11uI5XgrqLvdy0
EOcSFit7tWm2yzTbYpqRp/l6Qtn3jUviGoMn9JSW8+/X6s26VE/puOA1Qjyv
wwN6Si9fK3it4LVC/MxjnPc7zliqxx1nrRxnWE/n60ktU8YXVtVWjqlWjqnG
5qjG5qjG5qTG5qnG5qnG5qnG5qnGtjN+oPuV9qS+3RHiuosf6SG9pKy9O4xS
x82Lxmv6nh7Qb5SzPHxQh+s43aa0G+vxm0nMW28aO3WPFitrNbbVQTpRGffU
RTeFmM/wOZ2o2TpPc/SMErdqNa2uGZqr5EDqxhEhrssjjKm6W/cp9SLnfRdC
nNPIuR/W0YbaX0cp/bbFdsK5uly32E54SZlreIOu1u3KvKLu+zSJ6xoO12ma
p8Tnyn4O2ceRt9okMW+1Mdpprl5U6gxsqoM0U7N1i+7UYj2mJb7vNSG+b0zT
POU9YmvtrGOUoG5l/ekQ4uci2E1H6iLdq0Vaqqw/HYx0pT4n33w/xFyFxPX6
iDbTpb7+Al8P1yjXx/raQRf4Orz/6T5/uu9/uteZ7vvF01qqXHe615vue8ch
Ot3XmB7+//OFh0LMY1im5LGHjFa6WMlj7Ov/lMQzIByic5RgD48rlP07+eqc
4xsLtVjPOb6xvE7TfD2hjHPW5wEh5gnco6zTWFEbaFtNU2KiXlmvv+d4xHaa
q6uUqKNNNVOzdYvu1GI9pox31pWfGLW0nqbpLj2p7CWwqrbS1sqcYB/8nySe
Q+EwnaHv6gUlONfCSlpTG2mWXvn+zO0h5nlcrKuU/He7UUcban8dpZm6Uy/Y
Li28X6yiLWwXzFNyQgvvv4X3j2N0jZIX2Bc/HuI5L96j7F8eN8bqJz5+to/H
NbpPed5sHz/b5842PrGdahoN9E3do6x/2FDb6gDN1Il65XtJk43Fukpp+8n2
A9bRhtpfRyntzfnypBDPl/GocsY8yTE+yZishcr3MDgfuy2J51C3GRlaouzz
kPMn9s3NHPPNjLG6S88r472Z4x353k5D5kOI36PB95XP4k7aL8j+7KUQ92dY
XWvoC9pTZyufhbxkFCj7td5J3AvgSj2n5f17A03TbjpN8zRf9yt5jXz2aIj5
C8trRW2gRJoO0DzN9zrXeL/XeL/XOH6wge7Ra3wNvFMf07Y6QK98LtQlidfH
GtrFcY3cQxevjxX1MX1JB+hEpb2pI/+WxJoU39MDSnyj1KP4iLLucv78Woj1
LXbTpbpW83Wvsj/C9tpXiSW6Ual3OccaHeJ3JHCqLtF/K+dX+KwSnF+x/u4J
cT+Bu7VM2bdiBb1FH9JWuljfU4L967POQ/yhP9+nNbSW5uhy5fs/5K9/JnHc
YANto+30Tc3VVbpTCdY8vFPb6iDN1Gzdoju1WI9pie3+ZIj7HTykxA5ln0Od
3dpYrlu0UIv1nF5S6hG8QafpZj2h1CPUa0+EWGfiIl2je3WfUq/h/Up00GE6
XRcodRvn0oONo8oZNT6szZVzar5n+nUSz89xjBLsjZH9NPXZqCTuUbGXEit1
nRbqOWW/ih8o7cI6tTGJ6wsO0I2+b2T/gE11kk7WbC1U+p/8sz8xfyYxJ+83
yDtYXitqA31U03SATtM8JY/+K4l7PJyq7P+or55K4ucMTxnDdIa+qxf0P0qd
hZW0kY5Q6ivOXbcmsT7Bhvq+Et8qax7era/o27pMOUeknvpdEtdfrKX1tJmm
KbFLTyrrMVZV6i72Kysd/9hNR+oi3atFelpLlfmw0vmw0vGO7bWDput0XaAr
nR+041sh9gXO0u36L6UvsK6O0NR/SY/gv5ML8fM77KMD9fK/KTUG6zz9SD9W
Ps+j/vkiiecYmKHZOk/XKcGZBN6qHTVXOa8g/xwJcT7gct2vhVqs55TchuW1
gT6qaTpN8zRfiRNK/uP8aVGI+RgPKXl4kbFcdyj5mXX0YaOpztUlekzJw/is
jtbVul6v/HuLQyGuZ5ihrIFYQ2tpjhYp9eXfk5i/cZ8S5GecrZ8odSf1cE9f
v6f93tPXxxLldXsaOVqkh5R6mfz5lyTmc5ypR5WgVsdJWqjnHc9DHc9DHc9D
Hc9DHcfYSXvoYB3q+GWeNw5xfuNCXaqntVTJxY2Np7S9put4pa76ZRLXHnxJ
e2t5/95Nh2ieUkezznVIYr3fwRijXyvfAcUuWqCnlDqf/eesEPMl1tMWmqbz
9aTS0FhBK2tVbaWdlaBm43OWO0I818RZmqPv6ArdrgV6UM8qUU0f0LrK9yL4
fPsxo6NSP+DD2ly7ai/trQOVzyapD9OTWB+mG6N1sq5S9qd4u96pdbShttX+
yj6V+uWzED//xwm6QzmL+8z7ezHE+gMX61HlXrG5tlBilE5SPoP9URLHAA7V
XXpSq/q4h7SV7lHWAerpG5P4vm402mm6TtbFmqurlDr6RtvxRtvxRtvvRtsP
m+oozdRs3akXnNd/d17jSF2ke7VIT2upsm7j/fqEttcOmq7TdYGu1A+VfP3b
ENcT/EgPKfkbayixSJfb7xuSmDc3OMZxsC5WYqMeVcbGBsc/ttCu+qKO0km6
Qcm73ZN4Rozf9+frtZkyTh/BJH7WjbN0mR5W4l/K95vwLcf5WechdtTByr3g
w9pcu2pv5Xztv0nMb9hK03S45inBuRu21s46Rtco527k5dpJzMu1jQ7aU8co
5wP4jL6kBXrO+VTJGKrMu0rOu0rOO+r0hSHWg/iqztB39YL+R6kLsZLW1Eaa
peSjt5KYj94ydujXyr+9xINKv/86iZ8l4HQ9oaf0ay3n46+98jxlvWKdui3E
deo2+xHraQtN09/pfM3Tk/pfZR3Dykq01s46RmfpGr38vSL6L4n7F2yoxPu6
Vb9V9jF4t76ib+syZR9DfTUjxPoKb9MMLVHqK+ypRI5e+R7cphC/S4N9dYBu
U/aoWFubaEsdqeTRp42Ful+L9LSWKjUSNtDGmqbtNV3HK3UPdf+vQqyRcLnu
10It1nNK3Y/llUjTaZqn+XpETyj1PnX7l0k8X8GHta1O1bm6RIlLSj2PT+po
Xa3bdYeyX+DfjfxPEs8J8TUdr3P0b0p8o3yOjQ/qFL3yvdIzIX5/FJfpYSX3
4gEl/74QYv5F8usLRlftpb2Vuolzvw+TOH/xR/oTrafzldilJ5U5ihW0qj6k
rXSWvqfkRb439UYS1503jCl6RP+lvF+cqvN1t+11s/GAPqJ/1GX6mdKGN9ue
1L2HQ/x+Ec7Sd3SFbteDeljPKnUtdtcDyuc3f03i5zd4jz6jW5X4Vsk/+LiO
1bd1ti5T9n2cf9dP4nlKfaOZjtaxel75HAP5d9J8v+FW41WdoQXKWoTVtaZm
6ULN9b6zvF+cpFneY5b3m+V9ZnmfWd5nlveH5PM76M8QzwfxSe2lozRDV+o6
/UI5g8aOSnygnGNQt70cYn2GG/SoUovhi0qM0klKHXZLEtcgbKjP6Pu6VX/u
4+/Wt5V9/O+TOCZ/7zjG7XpYP9OzeofPq6tv6QFlXDJO6hj1tZn+TkfrWP1c
zyvjp47jh36fGeI+GF/SV5Wxgt2U2G+/fpXEehtHaYZ+oQR9h/dpLe2of1T6
k89d/pHE2gaX6iklqGfwZn1Kh+s4Ha98r4jP8x5K4v9/At6p1ZR4QXtoT52t
m5T9P3LGwb+H+HOI5z3Iv4PAYUq98W6I9Qbephlaol/oV0qbYS3tqTM0R4l/
OP77JXFf1s+YrIt1g25U9oFYR1voi/qyjlLmB/Xj20msX7G79tdxSuzQE/q1
Upfi9fqZnnIcPmG8pK/qNOX7tFhTG+kQZYxSv88J8Zwdh+lk5d6xjRL79IKW
2b/v2L/v2K/vGFf696j9ihM1WxdoiXIWi+00Q2foUfuTefV+iHMGa+hvdbkS
RXrI/PN8iDkM79GG+oxu1W+VeEXf1mVK3cznJg8aT2tvXaj7lboUy2tF/ZU2
0Ec1TQdonubrEfv1jRBrYSxVxgJ20CFKTNcFulI5K+Dzhn4hnlP087rIeQTW
1ye0g/bzGv28fj+v38/r9/P6yHkE5zZXh/g9PWyj7TRXd+o/9aJyZnO1MUgz
dYvu1GI9pnzOyb6iUxL7r5P908k+7GQs1P1apKe1VOnXTvZnJ/uxk/2IjTVN
03W80q+cM3ycxHOGj42j+hfl7AEf1ubaVTl3IEc/F+I5NG5S/n+LsJ4SnXSw
DlXOpZnXfzAW6Rrdp39X5j7OVuo36vG7jPm6Xnfrn7VM+Wweb9HKOkEX63vK
5/HUvc2TWH/jI0r8Ud/QI0q9jFOV+pt96/8m8fuZ+Kj21QG6WrcpwV4Wa2sT
bakjdZNeHof0m9FNR+peZc3E+/UJfU1XKvOJ8+IPknhejOk6WifrKiU458Q7
taG21f46UXfql8p6wD6rURLPhxoZA3WQDtXfO+8eN7pqNx2pe7VIT2upkose
t10et12wvXbQdO2n03WBrtQPlXakzv88xP0N3qJ/0DW6T/+qf1dqXnxcx+ps
/URPKuPgdyF+/xM7a1dlDOD9SgxT1ln2OZ8ksV7F5zRHV2iBEmeUz0GxmlbX
mlpXs5R9EPXU8SSeA2NH7aeDdYNu1I/1qBLkM2yuLfRFfVkn6QYt9L6/CPG+
sYk+p7M0R1fodi3QT/SsstfAalpd62qWcv76hxDrZLxPO+gYfUu/Vmpk5Bz+
nyGew+MhpZ7B3+oiXa4f6GbdoaWa+i95NcTPJbGRDtRBOlSZk9hDiXnK5yvU
cZuTWKfjbZqhRIl+odToWEt76gzN0XeVuu72lL8OMe9iG22nuXpR/1fJvfg9
vVqJ2tpUJ2u2btFiPaZX6oPvhFgP4ePaTRdpkZYq8SN9QjtoP31Dp+sCXakf
KvmIfUV7Y5xO11P6D2X/gNfqzfqMjtPjeuX/t+dvIa5vOFM36EY9qn/R48pn
5H+zjfFlnaSTtVAJPj/nnPW3xis6Sgv1kF5Sxj5u1h3KuP8/ONwSDw==
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[13, 59] -> 
             RGBColor[
              0.2579706137078198, 0.3884738496614871, 0.938002416866113], 
             UndirectedEdge[210, 309] -> 
             RGBColor[
              0.1918597924354573, 0.31898718483606625`, 0.9342375033968474], 
             UndirectedEdge[88, 427] -> 
             RGBColor[
              0.18803656473244668`, 0.3149687301135649, 0.9340197762351194], 
             UndirectedEdge[293, 483] -> 
             RGBColor[
              0.630894839609411, 0.7086289993280623, 0.9658482385387919], 
             UndirectedEdge[46, 150] -> 
             RGBColor[
              0.2095354252082916, 0.3375653955801614, 0.935244104534505], 
             UndirectedEdge[400, 444] -> 
             RGBColor[
              0.7778662305017423, 0.8242556583288213, 0.8882685536457314], 
             UndirectedEdge[98, 105] -> 
             RGBColor[
              0.18986356428247403`, 0.31688902247910566`, 0.93412382115669], 
             UndirectedEdge[128, 439] -> 
             RGBColor[
              0.1967431917255388, 0.32411994711534, 0.9345156057620757], 
             UndirectedEdge[23, 62] -> 
             RGBColor[
              0.34157168432943963`, 0.4649528057928196, 0.943180457023785], 
             UndirectedEdge[201, 236] -> 
             RGBColor[
              0.2329055510975478, 0.36212887964133295`, 0.9365749986308951], 
             UndirectedEdge[40, 477] -> 
             RGBColor[
              0.19140125749096676`, 0.31850523553661203`, 0.9342113905101004],
              UndirectedEdge[455, 482] -> 
             RGBColor[
              0.47270830175216416`, 0.5795209528723455, 0.952539845619061], 
             UndirectedEdge[60, 131] -> 
             RGBColor[
              0.9096110781982166, 0.6242662481872688, 0.5350082437658015], 
             UndirectedEdge[179, 222] -> 
             RGBColor[
              0.19860716321184355`, 0.3260790993300644, 0.9346217561807222], 
             UndirectedEdge[111, 175] -> 
             RGBColor[
              0.38213445941917534`, 0.5054073949376681, 0.9455702477393233], 
             UndirectedEdge[51, 110] -> 
             RGBColor[
              0.7061642122935256, 0.763962913869964, 0.8362189440457062], 
             UndirectedEdge[84, 261] -> 
             RGBColor[
              0.30240410894972447`, 0.4332765821863486, 0.9406023955782863], 
             UndirectedEdge[156, 479] -> 
             RGBColor[
              0.19085648891639362`, 0.317932649224413, 0.9341803667456914], 
             UndirectedEdge[158, 437] -> 
             RGBColor[
              0.1868134400454955, 0.31368314851699497`, 0.9339501210936485], 
             UndirectedEdge[103, 355] -> 
             RGBColor[
              0.48475696898891374`, 0.5914050668107322, 0.9529074440237885], 
             UndirectedEdge[13, 228] -> 
             RGBColor[
              0.2555809934244899, 0.38596220723303065`, 0.9378663315261038], 
             UndirectedEdge[59, 409] -> 
             RGBColor[
              0.2581147666270732, 0.38862536351944543`, 0.9380106261616092], 
             UndirectedEdge[243, 430] -> 
             RGBColor[
              0.19906776015361727`, 0.3265632159194014, 0.934647986495164], 
             UndirectedEdge[333, 441] -> 
             RGBColor[
              0.2266279051671714, 0.35553067574276653`, 0.936217495982105], 
             UndirectedEdge[179, 385] -> 
             RGBColor[
              0.19083377116116018`, 0.3179087714232738, 0.9341790730031387], 
             UndirectedEdge[81, 447] -> 
             RGBColor[
              0.23604325092602435`, 0.36542680110272124`, 0.936753685994316], 
             UndirectedEdge[69, 404] -> 
             RGBColor[
              0.6398415718326245, 0.7153643102811339, 0.9668689392230831], 
             UndirectedEdge[113, 380] -> 
             RGBColor[
              0.19209288530033616`, 0.3192321802159951, 0.9342507776906723], 
             UndirectedEdge[85, 489] -> 
             RGBColor[
              0.18944536571522486`, 0.31644946926960615`, 0.9341000053669545],
              UndirectedEdge[277, 498] -> 
             RGBColor[
              0.6089064489917588, 0.6910771522369943, 0.9638150835884631], 
             UndirectedEdge[18, 160] -> 
             RGBColor[
              0.26388110219154026`, 0.3946861478044915, 0.9383390104414766], 
             UndirectedEdge[355, 431] -> 
             RGBColor[
              0.49048091648110803`, 0.596362862434505, 0.9532721688965031], 
             UndirectedEdge[357, 492] -> 
             RGBColor[
              0.1855765306994534, 0.3123830783697226, 0.9338796809362347], 
             UndirectedEdge[165, 386] -> 
             RGBColor[
              0.3057645176630249, 0.43870827302694076`, 0.9407242089916171], 
             UndirectedEdge[218, 274] -> 
             RGBColor[
              0.26498050169023135`, 0.3958416863835701, 0.9384016196165113], 
             UndirectedEdge[116, 441] -> 
             RGBColor[
              0.24897326082313725`, 0.37901706131456436`, 0.9374900309297209],
              UndirectedEdge[258, 435] -> 
             RGBColor[
              0.32678964542360633`, 0.4509663941385996, 0.942281872262574], 
             UndirectedEdge[112, 445] -> 
             RGBColor[
              0.9782801480279448, 0.9394045757914982, 0.5347896078268422], 
             UndirectedEdge[114, 179] -> 
             RGBColor[
              0.19077318734493098`, 0.3178450939911811, 0.9341756228444302], 
             UndirectedEdge[155, 467] -> 
             RGBColor[
              0.19253479608250443`, 0.31969665646681583`, 0.9342759438559683],
              UndirectedEdge[243, 421] -> 
             RGBColor[
              0.1904580230623436, 0.31751383634761216`, 0.9341576747047806], 
             UndirectedEdge[172, 289] -> 
             RGBColor[
              0.2167825321958998, 0.3451825645172597, 0.9356568165563153], 
             UndirectedEdge[381, 468] -> 
             RGBColor[
              0.20490029607601296`, 0.33269358097797563`, 0.9349801407874807],
              UndirectedEdge[17, 277] -> 
             RGBColor[
              0.4093350243660927, 0.5289671571545423, 0.9473034436852257], 
             UndirectedEdge[279, 477] -> 
             RGBColor[
              0.2028882707819582, 0.3305788148241523, 0.9348655589235091], 
             UndirectedEdge[4, 405] -> 
             RGBColor[
              0.18158563263707392`, 0.3081883914686098, 0.9336524051955868], 
             UndirectedEdge[36, 379] -> 
             RGBColor[
              0.9107780137599082, 0.6018218600251894, 0.4604073756146171], 
             UndirectedEdge[278, 401] -> 
             RGBColor[
              0.18259570595575553`, 0.30925004256889155`, 0.9337099273768162],
              UndirectedEdge[152, 399] -> 
             RGBColor[
              0.19605719925809356`, 0.3233989255376204, 0.9344765395058896], 
             UndirectedEdge[173, 406] -> 
             RGBColor[
              0.5685496786155626, 0.658415121806283, 0.9602730898835382], 
             UndirectedEdge[239, 332] -> 
             RGBColor[
              0.1916360269785587, 0.31875199315331637`, 0.9342247602851084], 
             UndirectedEdge[116, 361] -> 
             RGBColor[
              0.25328984688463263`, 0.3835540669525598, 0.9377358541201064], 
             UndirectedEdge[288, 498] -> 
             RGBColor[
              0.7429048622719281, 0.7990821917836863, 0.9750094718967612], 
             UndirectedEdge[16, 386] -> 
             RGBColor[
              0.2878595743491687, 0.4198890423651035, 0.9397045489578829], 
             UndirectedEdge[216, 464] -> 
             RGBColor[
              0.20118455785762748`, 0.32878810451904233`, 0.9347685349928858],
              UndirectedEdge[379, 400] -> 
             RGBColor[
              0.9086464403656656, 0.6009403996477325, 0.49573306309233295`], 
             UndirectedEdge[22, 24] -> 
             RGBColor[
              0.18354454614871424`, 0.31024733377163405`, 0.9337639624221219],
              UndirectedEdge[231, 355] -> 
             RGBColor[
              0.6616838941423232, 0.7343656744943371, 0.9677797504415411], 
             UndirectedEdge[434, 495] -> 
             RGBColor[
              0.9105859845179732, 0.6779864914594717, 0.24664336835265455`], 
             UndirectedEdge[75, 323] -> 
             RGBColor[
              0.9290142282590157, 0.73628865839294, 0.4899032009526938], 
             UndirectedEdge[165, 288] -> 
             RGBColor[
              0.508574991950541, 0.6066055037109249, 0.956292599133973], 
             UndirectedEdge[90, 229] -> 
             RGBColor[
              0.24859585520259658`, 0.3786203840784777, 0.9374685382379528], 
             UndirectedEdge[267, 424] -> 
             RGBColor[
              0.21136439475697272`, 0.3394877585391924, 0.9353482616445844], 
             UndirectedEdge[258, 403] -> 
             RGBColor[
              0.5792948267817268, 0.6667531924094637, 0.9613678188204143], 
             UndirectedEdge[274, 305] -> 
             RGBColor[
              0.2773195143815185, 0.4086435488273039, 0.9391104309604698], 
             UndirectedEdge[399, 478] -> 
             RGBColor[
              0.22859634417905478`, 0.3575996299504977, 0.9363295956717873], 
             UndirectedEdge[359, 463] -> 
             RGBColor[
              0.7323426131107887, 0.7902188270608363, 0.9746779559842911], 
             UndirectedEdge[302, 422] -> 
             RGBColor[
              0.22565049031831835`, 0.3545033507649412, 0.9361618336524187], 
             UndirectedEdge[21, 335] -> 
             RGBColor[
              0.2551889465783416, 0.385550141140523, 0.9378440050381969], 
             UndirectedEdge[266, 445] -> 
             RGBColor[
              0.9783510953842744, 0.9379685313127405, 0.42709594933440853`], 
             UndirectedEdge[200, 452] -> 
             RGBColor[
              0.24489188267224044`, 0.3747272741036509, 0.9372576024818854], 
             UndirectedEdge[112, 471] -> 
             RGBColor[
              0.9751390722082593, 0.9794426669377387, 0.8581518289048162], 
             UndirectedEdge[481, 496] -> 
             RGBColor[
              0.19554201050297132`, 0.3228574294911333, 0.934447200268439], 
             UndirectedEdge[6, 422] -> 
             RGBColor[
              0.21046728026605566`, 0.33854483432889454`, 0.9352971723014887],
              UndirectedEdge[137, 424] -> 
             RGBColor[
              0.20256381379959026`, 0.3302377899639228, 0.9348470815783543], 
             UndirectedEdge[89, 482] -> 
             RGBColor[
              0.3210267437424298, 0.45247896298156487`, 0.9416765181318323], 
             UndirectedEdge[142, 254] -> 
             RGBColor[
              0.20407108545370353`, 0.33182202803893834`, 0.9349329184692474],
              UndirectedEdge[178, 321] -> 
             RGBColor[
              0.7273722693999012, 0.7841453015250835, 0.9212028178095601], 
             UndirectedEdge[151, 456] -> 
             RGBColor[
              0.19966233325078292`, 0.32718814994263423`, 0.9346818465534554],
              UndirectedEdge[346, 431] -> 
             RGBColor[
              0.43133365387154704`, 0.5480212643488988, 0.948705176904689], 
             UndirectedEdge[65, 297] -> 
             RGBColor[
              0.18922089119532, 0.3162135323166796, 0.9340872218751262], 
             UndirectedEdge[79, 253] -> 
             RGBColor[
              0.6318697246341356, 0.7067600197693191, 0.967143342848597], 
             UndirectedEdge[376, 475] -> 
             RGBColor[
              0.3538187512223421, 0.4808817516864462, 0.9437659958516187], 
             UndirectedEdge[209, 259] -> 
             RGBColor[
              0.8388746662508497, 0.8722406233791922, 0.8551373469793608], 
             UndirectedEdge[464, 496] -> 
             RGBColor[
              0.1941346337620407, 0.32137818730357604`, 0.9343670522450702], 
             UndirectedEdge[101, 103] -> 
             RGBColor[
              0.32745764009317235`, 0.4521656087003331, 0.9423017119454735], 
             UndirectedEdge[69, 348] -> 
             RGBColor[
              0.4524683198594424, 0.5660891289103882, 0.9501175973747447], 
             UndirectedEdge[116, 277] -> 
             RGBColor[
              0.35985275808300965`, 0.4831247951827711, 0.9442597110251651], 
             UndirectedEdge[171, 471] -> 
             RGBColor[
              0.7137657491152036, 0.7742498659419835, 0.9547112060503897], 
             UndirectedEdge[133, 429] -> 
             RGBColor[
              0.19496484613925177`, 0.3222507931505298, 0.9344143316117632], 
             UndirectedEdge[37, 203] -> 
             RGBColor[
              0.8534629031399862, 0.4065189709815528, 0.1986169775584265], 
             UndirectedEdge[299, 399] -> 
             RGBColor[
              0.22397618806162217`, 0.3527435529362591, 0.936066484615808], 
             UndirectedEdge[311, 429] -> 
             RGBColor[
              0.19096685764878327`, 0.3180486537599364, 0.934186652081725], 
             UndirectedEdge[327, 446] -> 
             RGBColor[
              0.18359313787334597`, 0.31029840675511533`, 0.9337667296489547],
              UndirectedEdge[15, 249] -> 
             RGBColor[
              0.6896781375343781, 0.7575010698806214, 0.9697043294069452], 
             UndirectedEdge[50, 242] -> 
             RGBColor[
              0.9267381119467066, 0.943455029677774, 0.9594240314227456], 
             UndirectedEdge[163, 355] -> 
             RGBColor[
              0.7295091887885554, 0.6445510453124249, 0.5980872339837272], 
             UndirectedEdge[192, 435] -> 
             RGBColor[
              0.2756938897780267, 0.40670981874574946`, 0.9390260958950403], 
             UndirectedEdge[31, 191] -> 
             RGBColor[
              0.1912888055455656, 0.31838704141213026`, 0.9342049865381675], 
             UndirectedEdge[385, 415] -> 
             RGBColor[
              0.18097729894859016`, 0.30754899419142984`, 0.9336177614919767],
              UndirectedEdge[207, 257] -> 
             RGBColor[
              0.9190198138450048, 0.7061284902521469, 0.2641826298296307], 
             UndirectedEdge[359, 408] -> 
             RGBColor[
              0.923405109023163, 0.9417213092494618, 0.9911392082523272], 
             UndirectedEdge[183, 202] -> 
             RGBColor[
              0.19186250689715728`, 0.31899003790741964`, 0.9342376579814256],
              UndirectedEdge[170, 223] -> 
             RGBColor[
              0.19795986022643686`, 0.3253987428510222, 0.9345848932333021], 
             UndirectedEdge[40, 430] -> 
             RGBColor[
              0.1932824749084014, 0.32048251431840913`, 0.9343185230590114], 
             UndirectedEdge[69, 444] -> 
             RGBColor[
              0.5043601503383525, 0.6082172545934901, 0.9542027123560828], 
             UndirectedEdge[215, 417] -> 
             RGBColor[
              0.1910469226092748, 0.31813280710982467`, 0.9341912116627795], 
             UndirectedEdge[423, 429] -> 
             RGBColor[
              0.18557451474248365`, 0.3123809594711283, 0.9338795661304677], 
             UndirectedEdge[5, 83] -> 
             RGBColor[
              0.8424015657306109, 0.8748578438487853, 0.849230453036272], 
             UndirectedEdge[311, 366] -> 
             RGBColor[
              0.18627071422588198`, 0.31311270926977675`, 0.9339192136611123],
              UndirectedEdge[133, 366] -> 
             RGBColor[
              0.1902687027163505, 0.3173148486603702, 0.9341468931911505], 
             UndirectedEdge[76, 359] -> 
             RGBColor[
              0.6599771175433797, 0.7303046973046542, 0.9693028506052312], 
             UndirectedEdge[172, 218] -> 
             RGBColor[
              0.25468436170219366`, 0.3850197904431626, 0.9378152696759667], 
             UndirectedEdge[177, 484] -> 
             RGBColor[
              0.18459712642978363`, 0.31135366238448237`, 0.9338239053119759],
              UndirectedEdge[45, 328] -> 
             RGBColor[
              0.22208190708084125`, 0.3507525435211073, 0.9359586081162901], 
             UndirectedEdge[115, 144] -> 
             RGBColor[
              0.1939326542641488, 0.3211658940450518, 0.9343555498114672], 
             UndirectedEdge[63, 72] -> 
             RGBColor[
              0.20896361604647165`, 0.3369643878962938, 0.9352115408486552], 
             UndirectedEdge[248, 387] -> 
             RGBColor[
              0.18458186461527748`, 0.3113376212497815, 0.9338230361742175], 
             UndirectedEdge[34, 44] -> 
             RGBColor[
              0.24396970740458573`, 0.37375800942805687`, 0.9372050859646285],
              UndirectedEdge[279, 285] -> 
             RGBColor[
              0.2111852622032374, 0.3392994788675566, 0.935338060310652], 
             UndirectedEdge[13, 77] -> 
             RGBColor[
              0.293706622672794, 0.4236564919439787, 0.9401246061243856], 
             UndirectedEdge[53, 445] -> 
             RGBColor[
              0.897896740106011, 0.5697053012801583, 0.24507330073286251`], 
             UndirectedEdge[91, 298] -> 
             RGBColor[
              0.368006349252357, 0.4899237097604318, 0.9448344889260978], 
             UndirectedEdge[6, 451] -> 
             RGBColor[
              0.20974058048916117`, 0.3377810267879514, 0.9352557878242505], 
             UndirectedEdge[87, 256] -> 
             RGBColor[
              0.30998490234108894`, 0.4428842197606874, 0.9409740715208748], 
             UndirectedEdge[153, 172] -> 
             RGBColor[
              0.22556462734887084`, 0.3544131033400252, 0.9361569438833315], 
             UndirectedEdge[72, 438] -> 
             RGBColor[
              0.20687895912531873`, 0.33477328129727923`, 0.9350928227209692],
              UndirectedEdge[207, 440] -> 
             RGBColor[
              0.8833097581290331, 0.5630186900098979, 0.22434314065434907`], 
             UndirectedEdge[19, 228] -> 
             RGBColor[
              0.2307172081494932, 0.3598287924539709, 0.9364503757373667], 
             UndirectedEdge[8, 63] -> 
             RGBColor[
              0.20214886588846875`, 0.32980165340011697`, 0.9348234509086764],
              UndirectedEdge[72, 128] -> 
             RGBColor[
              0.20268608388741163`, 0.33036630357859437`, 0.9348540446789733],
              UndirectedEdge[229, 485] -> 
             RGBColor[
              0.2450928096239232, 0.3749384610693741, 0.9372690449745389], 
             UndirectedEdge[32, 407] -> 
             RGBColor[
              0.24840100008144717`, 0.3784155789916214, 0.9374574415270658], 
             UndirectedEdge[475, 478] -> 
             RGBColor[
              0.2929211568634166, 0.42264039555989485`, 0.9400868509528724], 
             UndirectedEdge[194, 412] -> 
             RGBColor[
              0.18818134565428368`, 0.3151209040420562, 0.934028021294434], 
             UndirectedEdge[370, 390] -> 
             RGBColor[
              0.24233683264276484`, 0.3720417545231436, 0.9371120961625645], 
             UndirectedEdge[231, 233] -> 
             RGBColor[
              0.8631076739966228, 0.8934453053740385, 0.9626713381948079], 
             UndirectedEdge[114, 385] -> 
             RGBColor[
              0.18149489941754873`, 0.3080930251020705, 0.9336472380729627], 
             UndirectedEdge[271, 442] -> 
             RGBColor[
              0.22300003138538366`, 0.3517175503776244, 0.9360108939371906], 
             UndirectedEdge[206, 254] -> 
             RGBColor[
              0.18642186112422848`, 0.31327157424320573`, 0.9339278212533714],
              UndirectedEdge[262, 455] -> 
             RGBColor[
              0.47810598768171675`, 0.5841961571289409, 0.9528837813935058], 
             UndirectedEdge[7, 341] -> 
             RGBColor[
              0.7333256796265153, 0.7863640981896829, 0.7861411597228827], 
             UndirectedEdge[187, 328] -> 
             RGBColor[
              0.2321163718921772, 0.36129940225963686`, 0.9365300560426353], 
             UndirectedEdge[44, 56] -> 
             RGBColor[
              0.342928946455201, 0.46870029922168843`, 0.9431727706647948], 
             UndirectedEdge[142, 388] -> 
             RGBColor[
              0.27220031221012625`, 0.4015863957278337, 0.9388802865699359], 
             UndirectedEdge[282, 419] -> 
             RGBColor[
              0.6729998707802133, 0.7444718811327458, 0.9680419956441542], 
             UndirectedEdge[7, 244] -> 
             RGBColor[
              0.45953784870192455`, 0.5719334474988196, 0.9506451367617185], 
             UndirectedEdge[107, 470] -> 
             RGBColor[
              0.20295018288856098`, 0.3306438883736461, 0.9348690847263893], 
             UndirectedEdge[10, 383] -> 
             RGBColor[
              0.24728065527257528`, 0.3772380255635335, 0.9373936395476021], 
             UndirectedEdge[249, 419] -> 
             RGBColor[
              0.6881180325530365, 0.7562823040119602, 0.9695488327224149], 
             UndirectedEdge[191, 271] -> 
             RGBColor[
              0.19934619168565726`, 0.3268558651131542, 0.9346638427590112], 
             UndirectedEdge[297, 490] -> 
             RGBColor[
              0.20561521715269282`, 0.3334450083581805, 0.9350208544851668], 
             UndirectedEdge[32, 176] -> 
             RGBColor[
              0.26830294791528575`, 0.39857679935889445`, 0.938618545077043], 
             UndirectedEdge[353, 487] -> 
             RGBColor[
              0.18672390467583372`, 0.3135890411666101, 0.933945022186802], 
             UndirectedEdge[281, 324] -> 
             RGBColor[
              0.8790783466018638, 0.5485966593380001, 0.5760884806324713], 
             UndirectedEdge[19, 59] -> 
             RGBColor[
              0.2331068284328231, 0.3623404348824274, 0.936586461077376], 
             UndirectedEdge[197, 411] -> 
             RGBColor[
              0.25605149674669436`, 0.3864567360563011, 0.937893125994256], 
             UndirectedEdge[163, 343] -> 
             RGBColor[
              0.8727695735845509, 0.4960098594094768, 0.21479835234035222`], 
             UndirectedEdge[12, 396] -> 
             RGBColor[
              0.19573690002635402`, 0.32306227073691796`, 0.9344582989384823],
              UndirectedEdge[51, 397] -> 
             RGBColor[
              0.9086311282442023, 0.5812180792787432, 0.4466755411222336], 
             UndirectedEdge[448, 482] -> 
             RGBColor[
              0.3164780231838319, 0.4477844619968153, 0.9414143083027866], 
             UndirectedEdge[183, 285] -> 
             RGBColor[
              0.20567627769071223`, 0.33350918685510056`, 0.935024331792476], 
             UndirectedEdge[155, 365] -> 
             RGBColor[
              0.200483284293693, 0.3280510215400352, 0.934728598500861], 
             UndirectedEdge[122, 217] -> 
             RGBColor[
              0.1834604918576584, 0.31015898738238445`, 0.9337591756545935], 
             UndirectedEdge[249, 269] -> 
             RGBColor[
              0.6644117978227214, 0.7371426324130581, 0.9676100378285277], 
             UndirectedEdge[101, 331] -> 
             RGBColor[
              0.2732729587475753, 0.4045575845229832, 0.9388738627783362], 
             UndirectedEdge[246, 458] -> 
             RGBColor[
              0.2394606076875042, 0.3690186597319697, 0.9369482994063559], 
             UndirectedEdge[35, 437] -> 
             RGBColor[
              0.18478436843582058`, 0.31155046560465605`, 0.9338345684672199],
              UndirectedEdge[354, 473] -> 
             RGBColor[
              0.28709080979716467`, 0.41891074115277027`, 0.9396670037727628],
              UndirectedEdge[230, 484] -> 
             RGBColor[
              0.19535510076833423`, 0.3226609755092681, 0.9344365560355595], 
             UndirectedEdge[108, 190] -> 
             RGBColor[
              0.21307880253974895`, 0.34128970981862183`, 0.9354458946315745],
              UndirectedEdge[55, 136] -> 
             RGBColor[
              0.5509076978824959, 0.6462907131067992, 0.9577886185001523], 
             UndirectedEdge[59, 279] -> 
             RGBColor[
              0.23548934775412372`, 0.36484461374956423`, 0.9367221420281024],
              UndirectedEdge[24, 170] -> 
             RGBColor[
              0.18651291707157386`, 0.3133672798171463, 0.9339330067548675], 
             UndirectedEdge[184, 388] -> 
             RGBColor[
              0.43476172806913593`, 0.5486141843644792, 0.9495801910661066], 
             UndirectedEdge[173, 242] -> 
             RGBColor[
              0.8468550508642396, 0.8805617516174773, 0.9515915409041512], 
             UndirectedEdge[4, 345] -> 
             RGBColor[
              0.18617654721563465`, 0.31301373377147346`, 0.9339138509891864],
              UndirectedEdge[59, 256] -> 
             RGBColor[
              0.28727672509446966`, 0.4190164856928953, 0.9396808744204175], 
             UndirectedEdge[232, 480] -> 
             RGBColor[
              0.2609103808391443, 0.3915637313085108, 0.9381698322552461], 
             UndirectedEdge[3, 437] -> 
             RGBColor[
              0.18278910615931465`, 0.30945331844511326`, 0.9337209412322989],
              UndirectedEdge[199, 448] -> 
             RGBColor[
              0.3433591771132972, 0.47106756644443715`, 0.943127151661101], 
             UndirectedEdge[151, 226] -> 
             RGBColor[
              0.19534643528489967`, 0.3226518675367549, 0.9344360625490973], 
             UndirectedEdge[241, 442] -> 
             RGBColor[
              0.22676711964941848`, 0.35567699899031613`, 0.9362254240409197],
              UndirectedEdge[303, 400] -> 
             RGBColor[
              0.9153331914929417, 0.6523376989650047, 0.5021363035234178], 
             UndirectedEdge[42, 378] -> 
             RGBColor[
              0.20375715237687997`, 0.3314920644706901, 0.9349150404449447], 
             UndirectedEdge[15, 499] -> 
             RGBColor[
              0.6404896932769727, 0.7188634972449458, 0.9649460740899308], 
             UndirectedEdge[341, 374] -> 
             RGBColor[
              0.9208708140731814, 0.677947066838142, 0.406871876564454], 
             UndirectedEdge[312, 334] -> 
             RGBColor[
              0.19091202731972692`, 0.3179910236076545, 0.9341835295755994], 
             UndirectedEdge[7, 482] -> 
             RGBColor[
              0.4023630118874444, 0.5224114775409715, 0.9470020067176228], 
             UndirectedEdge[219, 403] -> 
             RGBColor[
              0.7064676273124759, 0.7706171469001197, 0.9713777488413233], 
             UndirectedEdge[50, 449] -> 
             RGBColor[
              0.9319849870644814, 0.931902676711367, 0.6896331946772748], 
             UndirectedEdge[318, 430] -> 
             RGBColor[
              0.1997685243379237, 0.32729976350812295`, 0.9346878939787725], 
             UndirectedEdge[242, 449] -> 
             RGBColor[
              0.9783597736506789, 0.9679158712997968, 0.6606061921458748], 
             UndirectedEdge[356, 365] -> 
             RGBColor[
              0.2261799618783253, 0.3550598589449443, 0.9361919862744781], 
             UndirectedEdge[154, 219] -> 
             RGBColor[
              0.8264967277029731, 0.8644743578312362, 0.9402829367923042], 
             UndirectedEdge[69, 275] -> 
             RGBColor[
              0.46608428308489896`, 0.5771431812489669, 0.9511894958767693], 
             UndirectedEdge[173, 310] -> 
             RGBColor[
              0.682704924474264, 0.7520535428396782, 0.9690093046974939], 
             UndirectedEdge[351, 460] -> 
             RGBColor[
              0.2704319943298352, 0.4015715507923906, 0.9387120740575761], 
             UndirectedEdge[97, 207] -> 
             RGBColor[
              0.9317219029437263, 0.7489756193744845, 0.31352784738991035`], 
             UndirectedEdge[122, 212] -> 
             RGBColor[
              0.18381215152445518`, 0.3105286039886985, 0.9337792021523836], 
             UndirectedEdge[45, 224] -> 
             RGBColor[
              0.20355580866569664`, 0.3312804394643078, 0.9349035742184542], 
             UndirectedEdge[144, 215] -> 
             RGBColor[
              0.19092068807717077`, 0.3180001266128517, 0.9341840227929235], 
             UndirectedEdge[22, 214] -> 
             RGBColor[
              0.1846717285967103, 0.31143207399197287`, 0.9338281537950183], 
             UndirectedEdge[142, 150] -> 
             RGBColor[
              0.2155365862389103, 0.34387299631892737`, 0.9355858617772765], 
             UndirectedEdge[149, 419] -> 
             RGBColor[
              0.6052079656077549, 0.6902679989364768, 0.962135887741037], 
             UndirectedEdge[11, 418] -> 
             RGBColor[
              0.4260394736081712, 0.5428061221897597, 0.9485417938214956], 
             UndirectedEdge[189, 346] -> 
             RGBColor[
              0.346693677388048, 0.46946123011413, 0.9435041892031641], 
             UndirectedEdge[185, 224] -> 
             RGBColor[
              0.2087376164930067, 0.33672684803640285`, 0.9351986705084218], 
             UndirectedEdge[17, 386] -> 
             RGBColor[
              0.34052296335874593`, 0.4690749660172503, 0.9429294418511679], 
             UndirectedEdge[194, 476] -> 
             RGBColor[
              0.18476853282621936`, 0.3115338213749295, 0.9338336666526799], 
             UndirectedEdge[258, 471] -> 
             RGBColor[
              0.686008715672987, 0.7506799404061069, 0.9528121866762553], 
             UndirectedEdge[203, 397] -> 
             RGBColor[
              0.8335404053549352, 0.2588118298231834, 0.1797516360873429], 
             UndirectedEdge[126, 173] -> 
             RGBColor[
              0.6045267350947843, 0.6886225535376819, 0.9628291330052186], 
             UndirectedEdge[30, 366] -> 
             RGBColor[
              0.1807454038963133, 0.3073052577884914, 0.9336045554118075], 
             UndirectedEdge[95, 368] -> 
             RGBColor[
              0.1819562792912616, 0.3085779646025163, 0.9336735129742202], 
             UndirectedEdge[15, 242] -> 
             RGBColor[
              0.8127597142986478, 0.8539262155582815, 0.9481932363943286], 
             UndirectedEdge[150, 392] -> 
             RGBColor[
              0.22610554162039614`, 0.3549816385353439, 0.9361877481508839], 
             UndirectedEdge[179, 296] -> 
             RGBColor[
              0.19117065430032437`, 0.31826285696216006`, 0.9341982579995401],
              UndirectedEdge[3, 123] -> 
             RGBColor[
              0.1847525458331286, 0.3115170180315573, 0.933832756217074], 
             UndirectedEdge[37, 257] -> 
             RGBColor[
              0.9124536887252621, 0.6763132496408797, 0.2587036940792628], 
             UndirectedEdge[17, 178] -> 
             RGBColor[
              0.4223764301651894, 0.5398287637649369, 0.9482544022825725], 
             UndirectedEdge[68, 367] -> 
             RGBColor[
              0.19128856344294365`, 0.31838678694692435`, 0.9342049727507814],
              UndirectedEdge[1, 363] -> 
             RGBColor[
              0.19094550353876433`, 0.3180262092363777, 0.93418543599675], 
             UndirectedEdge[227, 329] -> 
             RGBColor[
              0.18736891797604732`, 0.31426699104133987`, 0.9339817547400375],
              UndirectedEdge[121, 420] -> 
             RGBColor[
              0.1965885249531354, 0.3239573825311042, 0.9345067977181964], 
             UndirectedEdge[82, 149] -> 
             RGBColor[
              0.540625880408879, 0.6379434704911183, 0.9569791961650909], 
             UndirectedEdge[129, 355] -> 
             RGBColor[
              0.4245428223807357, 0.5374596923522321, 0.9491362257297418], 
             UndirectedEdge[87, 388] -> 
             RGBColor[
              0.3185501109900676, 0.45030297299252864`, 0.941519839042071], 
             UndirectedEdge[91, 228] -> 
             RGBColor[
              0.35927043823642757`, 0.48074171339394056`, 0.9443369917173629],
              UndirectedEdge[12, 161] -> 
             RGBColor[
              0.20394297282787943`, 0.33168737354638755`, 0.9349256226447324],
              UndirectedEdge[64, 115] -> 
             RGBColor[
              0.18789626990443398`, 0.31482127135411775`, 0.9340117866522119],
              UndirectedEdge[56, 342] -> 
             RGBColor[
              0.4415801835206408, 0.5562719260910596, 0.9495305912404275], 
             UndirectedEdge[378, 416] -> 
             RGBColor[
              0.2080965578112694, 0.3360530547164289, 0.9351621631648581], 
             UndirectedEdge[119, 363] -> 
             RGBColor[
              0.18346622269800678`, 0.3101650108589469, 0.9337595020174734], 
             UndirectedEdge[391, 455] -> 
             RGBColor[
              0.5430796704315681, 0.6399355677735181, 0.9571723675042059], 
             UndirectedEdge[249, 282] -> 
             RGBColor[
              0.7118315832315418, 0.7748075100316689, 0.9719123778383179], 
             UndirectedEdge[226, 429] -> 
             RGBColor[
              0.18946440368264025`, 0.31646947938043657`, 0.9341010895510347],
              UndirectedEdge[181, 189] -> 
             RGBColor[
              0.238744748764803, 0.3682662466161335, 0.9369075322997265], 
             UndirectedEdge[160, 167] -> 
             RGBColor[
              0.2396559862242012, 0.36922401496175294`, 0.9369594259249842], 
             UndirectedEdge[16, 277] -> 
             RGBColor[
              0.35667163535651547`, 0.47978123350239554`, 0.9440785507919407],
              UndirectedEdge[295, 341] -> 
             RGBColor[
              0.9895466198460419, 0.9890958111978665, 0.7611561924651287], 
             UndirectedEdge[69, 129] -> 
             RGBColor[
              0.36611599979539755`, 0.48974210320523914`, 0.944615139539211], 
             UndirectedEdge[352, 368] -> 
             RGBColor[
              0.1813119634696479, 0.3079007478220177, 0.9336368201413592], 
             UndirectedEdge[194, 297] -> 
             RGBColor[
              0.1906847748105455, 0.3177521668118635, 0.9341705878813915], 
             UndirectedEdge[188, 228] -> 
             RGBColor[
              0.24109668028529843`, 0.37073827576524543`, 0.9370414713204478],
              UndirectedEdge[273, 430] -> 
             RGBColor[
              0.19435747882303328`, 0.32161241159187215`, 0.9343797429416241],
              UndirectedEdge[200, 468] -> 
             RGBColor[
              0.2422384711696754, 0.37193837037844896`, 0.9371064946221849], 
             UndirectedEdge[93, 172] -> 
             RGBColor[
              0.22306123798292227`, 0.35178188239235997`, 0.9360143795623734],
              UndirectedEdge[61, 341] -> 
             RGBColor[
              0.992278182050985, 0.9902253823675571, 0.7158871376728388], 
             UndirectedEdge[121, 442] -> 
             RGBColor[
              0.22151836933651753`, 0.35016022962146637`, 0.9359265154754303],
              UndirectedEdge[287, 336] -> 
             RGBColor[
              0.46475221828321023`, 0.5718710801553506, 0.9521407597407114], 
             UndirectedEdge[403, 497] -> 
             RGBColor[
              0.6107955480026974, 0.6933624123353453, 0.9635615550100725], 
             UndirectedEdge[17, 407] -> 
             RGBColor[
              0.3262865305599572, 0.4541115725037497, 0.9421186980641918], 
             UndirectedEdge[135, 470] -> 
             RGBColor[
              0.18730486737300778`, 0.31419966979650255`, 0.9339781071529487],
              UndirectedEdge[322, 471] -> 
             RGBColor[
              0.8888094561578547, 0.5640382311059557, 0.5627414261917315], 
             UndirectedEdge[24, 52] -> 
             RGBColor[
              0.18264284256949226`, 0.3092995861385628, 0.9337126117372361], 
             UndirectedEdge[163, 440] -> 
             RGBColor[
              0.8954705204165625, 0.6182378713393768, 0.2344903787946242], 
             UndirectedEdge[274, 432] -> 
             RGBColor[
              0.26765870816883486`, 0.3986566512006808, 0.9385541395134164], 
             UndirectedEdge[89, 261] -> 
             RGBColor[
              0.31948712585052597`, 0.45114542334704305`, 0.9415784150411908],
              UndirectedEdge[255, 312] -> 
             RGBColor[
              0.19606964847691927`, 0.3234120104559323, 0.9344772484704849], 
             UndirectedEdge[370, 422] -> 
             RGBColor[
              0.21765000410983476`, 0.3460943324997014, 0.9357062177985042], 
             UndirectedEdge[43, 90] -> 
             RGBColor[
              0.24535980769453214`, 0.3752190929702395, 0.9372842501196719], 
             UndirectedEdge[373, 449] -> 
             RGBColor[
              0.9873031183402635, 0.9734548154410307, 0.5948195031122866], 
             UndirectedEdge[49, 457] -> 
             RGBColor[
              0.7315880631738731, 0.7847063242900234, 0.765752210507527], 
             UndirectedEdge[234, 449] -> 
             RGBColor[
              0.9549924747052941, 0.851092521948047, 0.32521790592745947`], 
             UndirectedEdge[245, 299] -> 
             RGBColor[
              0.24199930981785328`, 0.3716869966339784, 0.9370928747370061], 
             UndirectedEdge[398, 464] -> 
             RGBColor[
              0.20435657897174597`, 0.33212209982773555`, 0.9349491769027501],
              UndirectedEdge[245, 262] -> 
             RGBColor[
              0.2935462908702744, 0.4226836514910424, 0.9401449256179049], 
             UndirectedEdge[288, 321] -> 
             RGBColor[
              0.8483292768809738, 0.881288734461381, 0.9314462475205114], 
             UndirectedEdge[433, 465] -> 
             RGBColor[
              0.17986137360753812`, 0.306376085904231, 0.9335542111946675], 
             UndirectedEdge[330, 367] -> 
             RGBColor[
              0.19336515666501655`, 0.3205694180869378, 0.9343232316627341], 
             UndirectedEdge[106, 156] -> 
             RGBColor[
              0.1895211212928381, 0.31652909318485867`, 0.9341043195350291], 
             UndirectedEdge[85, 239] -> 
             RGBColor[
              0.19195700771123925`, 0.31908936425471746`, 0.9342430396629862],
              UndirectedEdge[336, 388] -> 
             RGBColor[
              0.4770192723969674, 0.5829207625304905, 0.9529068597500787], 
             UndirectedEdge[69, 355] -> 
             RGBColor[
              0.5012830197903266, 0.6057191013914514, 0.9539604693674415], 
             UndirectedEdge[102, 383] -> 
             RGBColor[
              0.23360844690792137`, 0.362867667704204, 0.9366150275074547], 
             UndirectedEdge[296, 327] -> 
             RGBColor[
              0.1830042105599709, 0.3096794068086097, 0.9337331911096979], 
             UndirectedEdge[61, 288] -> 
             RGBColor[
              0.8507412174209339, 0.8822861338586991, 0.8914741508713435], 
             UndirectedEdge[141, 472] -> 
             RGBColor[
              0.19522243291560842`, 0.32252153318442556`, 0.9344290007976113],
              UndirectedEdge[43, 485] -> 
             RGBColor[
              0.24185676211585877`, 0.3715371699611359, 0.9370847568562579], 
             UndirectedEdge[9, 358] -> 
             RGBColor[
              0.2093374978833109, 0.33735736141228945`, 0.9352328328661546], 
             UndirectedEdge[70, 359] -> 
             RGBColor[
              0.6396346219366711, 0.7126850500536813, 0.9680066447733342], 
             UndirectedEdge[466, 470] -> 
             RGBColor[
              0.19475005924981162`, 0.3220250385114528, 0.9344020998161584], 
             UndirectedEdge[41, 356] -> 
             RGBColor[
              0.25420192746199044`, 0.3845127214686115, 0.9377877957596846], 
             UndirectedEdge[79, 436] -> 
             RGBColor[
              0.620883921888038, 0.6972446695931502, 0.9664433372119796], 
             UndirectedEdge[33, 175] -> 
             RGBColor[
              0.326974395016177, 0.4527788821025087, 0.9422331394259775], 
             UndirectedEdge[176, 448] -> 
             RGBColor[
              0.3087587670403855, 0.44109843030645696`, 0.9409224441271964], 
             UndirectedEdge[118, 481] -> 
             RGBColor[
              0.1987399075504107, 0.32621862204637564`, 0.9346293157744259], 
             UndirectedEdge[326, 346] -> 
             RGBColor[
              0.5833986733777301, 0.6710733580441507, 0.9613052656352206], 
             UndirectedEdge[63, 435] -> 
             RGBColor[
              0.22260483335872017`, 0.351302172194599, 0.9359883879942152], 
             UndirectedEdge[194, 350] -> 
             RGBColor[
              0.18381567245253283`, 0.31053230470734794`, 0.9337794026640289],
              UndirectedEdge[275, 486] -> 
             RGBColor[
              0.45132348377934284`, 0.564358118789839, 0.9502489507974816], 
             UndirectedEdge[407, 478] -> 
             RGBColor[
              0.2632216514132959, 0.39399302322496244`, 0.9383014556952256], 
             UndirectedEdge[62, 356] -> 
             RGBColor[
              0.24825469827183463`, 0.37826180651364816`, 0.9374491098554425],
              UndirectedEdge[150, 426] -> 
             RGBColor[
              0.20135872025195078`, 0.3289711602380097, 0.9347784532835923], 
             UndirectedEdge[372, 444] -> 
             RGBColor[
              0.5900676498939734, 0.6780825262854508, 0.9608714333701266], 
             UndirectedEdge[106, 329] -> 
             RGBColor[
              0.18061317161541351`, 0.30716627327725476`, 0.9335970249790304],
              UndirectedEdge[128, 294] -> 
             RGBColor[
              0.1908740507973531, 0.317951107874789, 0.9341813668688315], 
             UndirectedEdge[379, 440] -> 
             RGBColor[
              0.8595285144156211, 0.406306411086346, 0.20259145280411195`], 
             UndirectedEdge[227, 267] -> 
             RGBColor[
              0.2112079223469873, 0.3393232961153739, 0.935339350772316], 
             UndirectedEdge[151, 345] -> 
             RGBColor[
              0.19727711657984534`, 0.32468113599000714`, 0.9345460119926574],
              UndirectedEdge[275, 418] -> 
             RGBColor[
              0.48290882987898437`, 0.5910861687474542, 0.9524354985228551], 
             UndirectedEdge[10, 232] -> 
             RGBColor[
              0.2526232272726644, 0.38285340747425656`, 0.9376978911193801], 
             UndirectedEdge[5, 431] -> 
             RGBColor[
              0.5554141285415004, 0.6483552608910543, 0.9588784790444786], 
             UndirectedEdge[42, 416] -> 
             RGBColor[
              0.20488956233917005`, 0.3326822991399955, 0.9349795295170467], 
             UndirectedEdge[37, 97] -> 
             RGBColor[
              0.9251557778239836, 0.7191603787632175, 0.30804891163954246`], 
             UndirectedEdge[441, 450] -> 
             RGBColor[
              0.21849705952285933`, 0.34698464144520536`, 0.9357544563511697],
              UndirectedEdge[5, 259] -> 
             RGBColor[
              0.686424746410886, 0.7549594960082611, 0.969380061784424], 
             UndirectedEdge[279, 318] -> 
             RGBColor[
              0.20298181137445004`, 0.33067713191767734`, 0.9348708859218705],
              UndirectedEdge[275, 355] -> 
             RGBColor[
              0.5245111056702372, 0.6248607703959599, 0.9557105820673001], 
             UndirectedEdge[344, 387] -> 
             RGBColor[
              0.1895833056665427, 0.31659445290433924`, 0.9341078608431181], 
             UndirectedEdge[239, 489] -> 
             RGBColor[
              0.1941327088524955, 0.32137616410159764`, 0.9343669426243193], 
             UndirectedEdge[21, 336] -> 
             RGBColor[
              0.4626767064166898, 0.5696895855885848, 0.9520225624103578], 
             UndirectedEdge[32, 312] -> 
             RGBColor[
              0.20732064752653726`, 0.335237523811622, 0.935117976221999], 
             UndirectedEdge[77, 436] -> 
             RGBColor[
              0.3449944123676427, 0.4732385528946725, 0.9432037167828538], 
             UndirectedEdge[66, 294] -> 
             RGBColor[
              0.19268716813915449`, 0.3198568091593014, 0.9342846212191803], 
             UndirectedEdge[197, 201] -> 
             RGBColor[
              0.2441727010346539, 0.373971368603798, 0.9372166461515588], 
             UndirectedEdge[228, 256] -> 
             RGBColor[
              0.28488710481113977`, 0.4165048432644388, 0.9395447890804083], 
             UndirectedEdge[292, 481] -> 
             RGBColor[
              0.1951943467181843, 0.32249201281016504`, 0.9344274013302178], 
             UndirectedEdge[444, 486] -> 
             RGBColor[
              0.4895993510327964, 0.5954321921343623, 0.953262167276795], 
             UndirectedEdge[154, 244] -> 
             RGBColor[
              0.7150943787471429, 0.7742699758488314, 0.9312778860004862], 
             UndirectedEdge[288, 386] -> 
             RGBColor[
              0.5084129263265404, 0.6064351624645463, 0.9562833697364408], 
             UndirectedEdge[273, 285] -> 
             RGBColor[
              0.20077325282687788`, 0.3283557968534793, 0.934745111779856], 
             UndirectedEdge[190, 487] -> 
             RGBColor[
              0.2046420322637051, 0.3324221293363686, 0.9349654330454369], 
             UndirectedEdge[83, 343] -> 
             RGBColor[
              0.920728738466214, 0.6743242594892878, 0.4603352612449215], 
             UndirectedEdge[1, 315] -> 
             RGBColor[
              0.19134373832478055`, 0.31844477924602455`, 0.934208114878678], 
             UndirectedEdge[4, 429] -> 
             RGBColor[
              0.18673058009120463`, 0.3135960574514107, 0.9339454023418319], 
             UndirectedEdge[189, 451] -> 
             RGBColor[
              0.22852938408198586`, 0.3575292506429629, 0.9363257823933178], 
             UndirectedEdge[10, 102] -> 
             RGBColor[
              0.21311463700569694`, 0.34132737411436953`, 0.9354479353513978],
              UndirectedEdge[357, 368] -> 
             RGBColor[
              0.18388810829963448`, 0.3106084393753497, 0.9337835277783622], 
             UndirectedEdge[128, 138] -> 
             RGBColor[
              0.18851306554638397`, 0.31546956268090953`, 0.9340469122515535],
              UndirectedEdge[336, 436] -> 
             RGBColor[
              0.49043574205618756`, 0.5945414342179349, 0.953761745333046], 
             UndirectedEdge[196, 454] -> 
             RGBColor[
              0.20169424196759916`, 0.3293238148344616, 0.9347975607489386], 
             UndirectedEdge[25, 164] -> 
             RGBColor[
              0.3024600979339018, 0.4345620939070181, 0.9405606698993174], 
             UndirectedEdge[125, 282] -> 
             RGBColor[
              0.7373315894354715, 0.794728308685404, 0.9744539801456191], 
             UndirectedEdge[9, 286] -> 
             RGBColor[
              0.19059390233229334`, 0.3176566540755726, 0.9341654128281889], 
             UndirectedEdge[421, 477] -> 
             RGBColor[
              0.1910652466541582, 0.31815206684280867`, 0.9341922551900277], 
             UndirectedEdge[105, 484] -> 
             RGBColor[
              0.1881185665568436, 0.315054919230222, 0.9340244461177081], 
             UndirectedEdge[299, 475] -> 
             RGBColor[
              0.28830100074598397`, 0.41778431854565623`, 0.939823739896893], 
             UndirectedEdge[247, 252] -> 
             RGBColor[
              0.18329308738435063`, 0.3099830346668814, 0.9337496422174913], 
             UndirectedEdge[261, 478] -> 
             RGBColor[
              0.2893032374986769, 0.41950673564807195`, 0.9398563203301515], 
             UndirectedEdge[104, 303] -> 
             RGBColor[
              0.8824648742106225, 0.5257558359619144, 0.2222571743069387], 
             UndirectedEdge[32, 66] -> 
             RGBColor[
              0.20877736241614875`, 0.33676862352166215`, 0.9352009339799459],
              UndirectedEdge[213, 454] -> 
             RGBColor[
              0.20680491942710666`, 0.3346954608800703, 0.9350886062696878], 
             UndirectedEdge[129, 331] -> 
             RGBColor[
              0.2954052676483876, 0.42782004444717026`, 0.9401342650284206], 
             UndirectedEdge[245, 475] -> 
             RGBColor[
              0.2902269064135576, 0.4198085675117481, 0.9399334173755393], 
             UndirectedEdge[90, 148] -> 
             RGBColor[
              0.26849318417245727`, 0.3995337383893224, 0.9386016616873261], 
             UndirectedEdge[195, 496] -> 
             RGBColor[
              0.18695506079229124`, 0.31383200090115126`, 0.9339581861856694],
              UndirectedEdge[241, 371] -> 
             RGBColor[
              0.2348560709776379, 0.3641789997054109, 0.9366860778525307], 
             UndirectedEdge[13, 243] -> 
             RGBColor[
              0.2247623131438397, 0.3535698202408788, 0.9361112532762724], 
             UndirectedEdge[246, 384] -> 
             RGBColor[
              0.2539870125967417, 0.38428683231884564`, 0.9377755566760467], 
             UndirectedEdge[22, 268] -> 
             RGBColor[
              0.1840499075552901, 0.3107785006517091, 0.9337927420066112], 
             UndirectedEdge[69, 306] -> 
             RGBColor[
              0.3418131212888621, 0.4641982370033755, 0.9432311265611506], 
             UndirectedEdge[66, 128] -> 
             RGBColor[
              0.19606919376904863`, 0.32341153252913013`, 0.9344772225755442],
              UndirectedEdge[220, 413] -> 
             RGBColor[
              0.2236716605546839, 0.35242347521830786`, 0.9360491422247958], 
             UndirectedEdge[319, 492] -> 
             RGBColor[
              0.18173579190696668`, 0.3083462183819148, 0.9336609565438665], 
             UndirectedEdge[61, 186] -> 
             RGBColor[
              0.9917911303595999, 0.9891836280481643, 0.6628745668001933], 
             UndirectedEdge[94, 401] -> 
             RGBColor[
              0.17982716171712376`, 0.30634012703824637`, 0.9335522628781203],
              UndirectedEdge[429, 488] -> 
             RGBColor[
              0.1872389149746237, 0.3141303496441773, 0.9339743512614285], 
             UndirectedEdge[11, 431] -> 
             RGBColor[
              0.3984128235048672, 0.519506895734326, 0.9466074907044714], 
             UndirectedEdge[349, 487] -> 
             RGBColor[
              0.1889676303182698, 0.3159473390772327, 0.9340727990428441], 
             UndirectedEdge[156, 198] -> 
             RGBColor[
              0.19090321227565094`, 0.31798175843742454`, 0.93418302757188], 
             UndirectedEdge[12, 188] -> 
             RGBColor[
              0.20900601855676193`, 0.3370089556230833, 0.9352139556088873], 
             UndirectedEdge[70, 111] -> 
             RGBColor[
              0.36816732392345053`, 0.4933097641799131, 0.9446802742161886], 
             UndirectedEdge[212, 286] -> 
             RGBColor[
              0.18467080520712215`, 0.3114311034509694, 0.9338281012093472], 
             UndirectedEdge[242, 282] -> 
             RGBColor[
              0.8349131599958114, 0.8712326557093291, 0.9504012848257013], 
             UndirectedEdge[70, 175] -> 
             RGBColor[
              0.3837102779939304, 0.5067722897841764, 0.945670657505465], 
             UndirectedEdge[188, 298] -> 
             RGBColor[
              0.24983259130122784`, 0.37992027213173674`, 0.9375389685291828],
              UndirectedEdge[286, 367] -> 
             RGBColor[
              0.1922727390163294, 0.3194212178748882, 0.9342610200937285], 
             UndirectedEdge[9, 492] -> 
             RGBColor[
              0.18820033017206594`, 0.3151408579739333, 0.9340291024346365], 
             UndirectedEdge[37, 343] -> 
             RGBColor[
              0.8540426861772787, 0.4109754374687308, 0.1991721784497092], 
             UndirectedEdge[376, 391] -> 
             RGBColor[
              0.4221118184289103, 0.5394962463103177, 0.9482660902046844], 
             UndirectedEdge[230, 490] -> 
             RGBColor[
              0.21093312852044277`, 0.33903447038074064`, 0.9353237016704152],
              UndirectedEdge[346, 355] -> 
             RGBColor[
              0.5005625797661037, 0.605095092452838, 0.9539145635661582], 
             UndirectedEdge[30, 465] -> 
             RGBColor[
              0.17899164586466354`, 0.3054619469025459, 0.9335046814863577], 
             UndirectedEdge[119, 124] -> 
             RGBColor[
              0.18484388120986256`, 0.311613017303502, 0.9338379576316604], 
             UndirectedEdge[301, 436] -> 
             RGBColor[
              0.5059845229884368, 0.6069488070899312, 0.9551333650755793], 
             UndirectedEdge[39, 108] -> 
             RGBColor[
              0.22860230621824829`, 0.3576058964317052, 0.9363299352010993], 
             UndirectedEdge[98, 382] -> 
             RGBColor[
              0.20018581629901203`, 0.3277383638170652, 0.9347116581386283], 
             UndirectedEdge[81, 208] -> 
             RGBColor[
              0.3324858109628042, 0.4558962797557328, 0.942644967739437], 
             UndirectedEdge[154, 203] -> 
             RGBColor[
              0.9142690676811895, 0.6673158743356673, 0.5518317374650853], 
             UndirectedEdge[145, 367] -> 
             RGBColor[
              0.2030970423728074, 0.33079824700301824`, 0.9348774481567581], 
             UndirectedEdge[44, 132] -> 
             RGBColor[
              0.27566251602704606`, 0.4070691607303891, 0.9390099445303688], 
             UndirectedEdge[319, 357] -> 
             RGBColor[
              0.18470360051772483`, 0.3114655734017556, 0.9338299688537698], 
             UndirectedEdge[364, 378] -> 
             RGBColor[
              0.20567802361676119`, 0.3335110219340761, 0.9350244312203816], 
             UndirectedEdge[213, 251] -> 
             RGBColor[
              0.22057376513923174`, 0.3491673907187537, 0.9358727216638114], 
             UndirectedEdge[73, 136] -> 
             RGBColor[
              0.5525602908951197, 0.647632362562914, 0.9579187166757537], 
             UndirectedEdge[441, 461] -> 
             RGBColor[
              0.2373696075780963, 0.3668208860399178, 0.9368292200434826], 
             UndirectedEdge[90, 480] -> 
             RGBColor[
              0.2528560578238772, 0.3830981271458908, 0.9377111504748298], 
             UndirectedEdge[118, 446] -> 
             RGBColor[
              0.18780907665371493`, 0.3147296257192406, 0.9340068211255742], 
             UndirectedEdge[210, 480] -> 
             RGBColor[
              0.21944240212988145`, 0.3479782564633687, 0.9358082922141305], 
             UndirectedEdge[95, 492] -> 
             RGBColor[
              0.18364470169108055`, 0.3103526035968892, 0.9337696661320929], 
             UndirectedEdge[261, 328] -> 
             RGBColor[
              0.28613962453427205`, 0.41618157783783527`, 0.9396761572519747],
              UndirectedEdge[152, 496] -> 
             RGBColor[
              0.1850253408084585, 0.31180374284682943`, 0.9338482914873549], 
             UndirectedEdge[86, 177] -> 
             RGBColor[
              0.1848471163861694, 0.31161641767892256`, 0.933838141870165], 
             UndirectedEdge[45, 217] -> 
             RGBColor[
              0.19120987418842403`, 0.31830407955123735`, 0.9342004915141469],
              UndirectedEdge[306, 331] -> 
             RGBColor[
              0.2711023891418522, 0.40227617824530654`, 0.9387502520503602], 
             UndirectedEdge[103, 129] -> 
             RGBColor[
              0.3495899489939847, 0.47542806862452014`, 0.9435621141955579], 
             UndirectedEdge[50, 126] -> 
             RGBColor[
              0.6844097961772514, 0.7515158315979785, 0.9706616235238129], 
             UndirectedEdge[172, 308] -> 
             RGBColor[
              0.207198246316672, 0.3351088723793687, 0.9351110056541736], 
             UndirectedEdge[112, 266] -> 
             RGBColor[
              0.9935124253020141, 0.9901198523525236, 0.6506615550659651], 
             UndirectedEdge[129, 275] -> 
             RGBColor[
              0.3893440856753081, 0.5088837722097477, 0.9463652522390695], 
             UndirectedEdge[297, 325] -> 
             RGBColor[
              0.21444902327045198`, 0.3427298986836028, 0.9355239266751281], 
             UndirectedEdge[202, 396] -> 
             RGBColor[
              0.1920993256937792, 0.31923894947784826`, 0.9342511444615511], 
             UndirectedEdge[167, 236] -> 
             RGBColor[
              0.22411127044535895`, 0.3528855330862843, 0.9360741773577252], 
             UndirectedEdge[184, 301] -> 
             RGBColor[
              0.5986418341837841, 0.6848276074011173, 0.9616939873161781], 
             UndirectedEdge[78, 258] -> 
             RGBColor[
              0.44262074177976496`, 0.5573429685234437, 0.9495499886233556], 
             UndirectedEdge[172, 470] -> 
             RGBColor[
              0.2090529849214024, 0.33705832025015997`, 0.9352166302738731], 
             UndirectedEdge[72, 159] -> 
             RGBColor[
              0.22161615608300847`, 0.35026300969206614`, 0.9359320842859804],
              UndirectedEdge[304, 337] -> 
             RGBColor[
              0.1898974932161501, 0.3169246839396178, 0.9341257533592695], 
             UndirectedEdge[88, 271] -> 
             RGBColor[
              0.19882737388287028`, 0.32631055470747644`, 0.9346342968526646],
              UndirectedEdge[392, 413] -> 
             RGBColor[
              0.23358028524334118`, 0.3628380680091775, 0.9366134237423184], 
             UndirectedEdge[187, 216] -> 
             RGBColor[
              0.21058067829644372`, 0.3386640228486828, 0.9353036301515618], 
             UndirectedEdge[33, 432] -> 
             RGBColor[
              0.27375220804932543`, 0.40506130592528333`, 0.9389011553170851],
              UndirectedEdge[36, 75] -> 
             RGBColor[
              0.929724921483118, 0.7365825483050892, 0.4781251750142107], 
             UndirectedEdge[243, 335] -> 
             RGBColor[
              0.2034771985235191, 0.3311978152207083, 0.9348990974871504], 
             UndirectedEdge[323, 499] -> 
             RGBColor[
              0.8106414871808013, 0.8502981241426343, 0.8671892234801464], 
             UndirectedEdge[168, 480] -> 
             RGBColor[
              0.26803681984078476`, 0.3990540705415648, 0.9385756724137677], 
             UndirectedEdge[301, 388] -> 
             RGBColor[
              0.4925680533292166, 0.5953281354024867, 0.9542784794926122], 
             UndirectedEdge[111, 371] -> 
             RGBColor[
              0.3103368514001098, 0.4381658734848475, 0.9411804208813801], 
             UndirectedEdge[103, 231] -> 
             RGBColor[
              0.5867310207555722, 0.6723340507666251, 0.9622056389073572], 
             UndirectedEdge[99, 131] -> 
             RGBColor[
              0.9067135965497277, 0.6223214351513566, 0.549591400192696], 
             UndirectedEdge[193, 428] -> 
             RGBColor[
              0.18434895637471288`, 0.31109281992171267`, 0.9338097723944743],
              UndirectedEdge[189, 370] -> 
             RGBColor[
              0.24036595787050763`, 0.36997024017682334`, 0.9369998577599323],
              UndirectedEdge[45, 187] -> 
             RGBColor[
              0.21121178851668337`, 0.3393273597048538, 0.9353395709449606], 
             UndirectedEdge[346, 443] -> 
             RGBColor[
              0.3646259972920919, 0.4883092353080305, 0.9445254082932095], 
             UndirectedEdge[19, 318] -> 
             RGBColor[
              0.20059929205314941`, 0.3281729530505406, 0.9347352049711439], 
             UndirectedEdge[5, 129] -> 
             RGBColor[
              0.4894760344411281, 0.5894520908087815, 0.9547425358777173], 
             UndirectedEdge[29, 46] -> 
             RGBColor[
              0.19406985648437775`, 0.32131010227763557`, 0.9343633632749366],
              UndirectedEdge[227, 263] -> 
             RGBColor[
              0.2087485483203887, 0.3367383380800992, 0.935199293059819], 
             UndirectedEdge[272, 435] -> 
             RGBColor[
              0.24781268178209245`, 0.377797219157465, 0.9374239376702564], 
             UndirectedEdge[208, 483] -> 
             RGBColor[
              0.4393277460874472, 0.554945345231554, 0.949214553391788], 
             UndirectedEdge[244, 475] -> 
             RGBColor[
              0.39162513268333266`, 0.5136277391039731, 0.9461749850474426], 
             UndirectedEdge[350, 412] -> 
             RGBColor[
              0.18588998404715956`, 0.3127125377122519, 0.9338975316406739], 
             UndirectedEdge[217, 398] -> 
             RGBColor[
              0.1937507850823029, 0.3209747380037596, 0.9343451926306123], 
             UndirectedEdge[370, 451] -> 
             RGBColor[
              0.21692330433294027`, 0.34533052495875827`, 0.935664833321266], 
             UndirectedEdge[265, 424] -> 
             RGBColor[
              0.18889724072199854`, 0.3158733551485935, 0.9340687904594684], 
             UndirectedEdge[28, 419] -> 
             RGBColor[
              0.5625638978028586, 0.6556476235991, 0.9587787905130681], 
             UndirectedEdge[67, 381] -> 
             RGBColor[
              0.18458590754106158`, 0.31134187062111685`, 0.93382326641286], 
             UndirectedEdge[239, 435] -> 
             RGBColor[
              0.21752143841029148`, 0.3459592017979452, 0.9356988961721111], 
             UndirectedEdge[302, 370] -> 
             RGBColor[
              0.23676036432994563`, 0.36618053275785845`, 0.936794524541795], 
             UndirectedEdge[2, 66] -> 
             RGBColor[
              0.19103840083759993`, 0.31812385018748285`, 0.9341907263604894],
              UndirectedEdge[36, 408] -> 
             RGBColor[
              0.9657078104957213, 0.9722942089440085, 0.8689827508705463], 
             UndirectedEdge[76, 483] -> 
             RGBColor[
              0.43123446241891855`, 0.5479353496981393, 0.948698856513039], 
             UndirectedEdge[9, 367] -> 
             RGBColor[
              0.19547077493947268`, 0.3227825563973006, 0.9344431435084812], 
             UndirectedEdge[133, 469] -> 
             RGBColor[
              0.18966655655355485`, 0.31668195486500017`, 0.9341126018579748],
              UndirectedEdge[46, 297] -> 
             RGBColor[
              0.19948643535294036`, 0.32700327009943075`, 0.934671829428391], 
             UndirectedEdge[159, 435] -> 
             RGBColor[
              0.23525737339525699`, 0.3646007939903714, 0.9367089314315404], 
             UndirectedEdge[126, 340] -> 
             RGBColor[
              0.4261246264730337, 0.5425553802981693, 0.948636879181104], 
             UndirectedEdge[27, 290] -> 
             RGBColor[
              0.18336907213961767`, 0.31006289946237875`, 0.9337539694368944],
              UndirectedEdge[326, 338] -> 
             RGBColor[
              0.5748571876552486, 0.6636751524188924, 0.9607610097179233], 
             UndirectedEdge[179, 438] -> 
             RGBColor[
              0.20137694299580192`, 0.3289903134971859, 0.9347794910418965], 
             UndirectedEdge[138, 339] -> 
             RGBColor[
              0.1814781394477339, 0.3080754093111516, 0.9336462836174759], 
             UndirectedEdge[475, 482] -> 
             RGBColor[
              0.3344502958688525, 0.46410576914612495`, 0.942531855003347], 
             UndirectedEdge[94, 428] -> 
             RGBColor[
              0.18335052254202558`, 0.31004340265919705`, 0.9337529130647533],
              UndirectedEdge[186, 295] -> 
             RGBColor[
              0.9890595681546568, 0.9880540568784736, 0.7081436215924831], 
             UndirectedEdge[348, 372] -> 
             RGBColor[
              0.5381758194150634, 0.6359544006023488, 0.9567863183887886], 
             UndirectedEdge[293, 343] -> 
             RGBColor[
              0.8279897500301316, 0.6038277857603807, 0.5867878259844261], 
             UndirectedEdge[385, 446] -> 
             RGBColor[
              0.18248129368631721`, 0.30912978801955504`, 0.9337034117673295],
              UndirectedEdge[7, 288] -> 
             RGBColor[
              0.5917887149964642, 0.6784248496808247, 0.9617281729213873], 
             UndirectedEdge[242, 323] -> 
             RGBColor[
              0.9829115082024764, 0.98536084245597, 0.8504363857845441], 
             UndirectedEdge[464, 481] -> 
             RGBColor[
              0.2038613891913174, 0.3316016239716596, 0.9349209765773223], 
             UndirectedEdge[42, 108] -> 
             RGBColor[
              0.2050818952093152, 0.3328844531811263, 0.9349904825894705], 
             UndirectedEdge[101, 276] -> 
             RGBColor[
              0.22935486634297414`, 0.3583968848378599, 0.9363727923868895], 
             UndirectedEdge[86, 426] -> 
             RGBColor[
              0.1863343941921356, 0.31317964095185236`, 0.9339228401409845], 
             UndirectedEdge[37, 324] -> 
             RGBColor[
              0.9007937640631225, 0.7100849667901136, 0.5966707240103046], 
             UndirectedEdge[290, 297] -> 
             RGBColor[
              0.18839455558370108`, 0.3153450011961642, 0.9340401632844985], 
             UndirectedEdge[315, 380] -> 
             RGBColor[
              0.18543946082278231`, 0.31223900923860914`, 0.9338718750095351],
              UndirectedEdge[181, 390] -> 
             RGBColor[
              0.24071562353706022`, 0.37033776096245374`, 0.9370197707023586],
              UndirectedEdge[283, 421] -> 
             RGBColor[
              0.18332707368146411`, 0.3100187564200033, 0.9337515776868337], 
             UndirectedEdge[97, 355] -> 
             RGBColor[
              0.7740833188183651, 0.8130804459299827, 0.6840694071044306], 
             UndirectedEdge[192, 219] -> 
             RGBColor[
              0.49125780976030897`, 0.5936378228658237, 0.9544300827546521], 
             UndirectedEdge[171, 192] -> 
             RGBColor[
              0.3918420426717766, 0.5133437939110442, 0.9463191721078775], 
             UndirectedEdge[122, 216] -> 
             RGBColor[
              0.19279683115434215`, 0.3199720719413004, 0.9342908663656634], 
             UndirectedEdge[18, 28] -> 
             RGBColor[
              0.38207742266917044`, 0.5028572911387341, 0.9458047612186589], 
             UndirectedEdge[178, 288] -> 
             RGBColor[
              0.5902663931329839, 0.677188960212233, 0.9616083301678455], 
             UndirectedEdge[165, 185] -> 
             RGBColor[
              0.2587337613234965, 0.38927596619191684`, 0.93804587699385], 
             UndirectedEdge[264, 281] -> 
             RGBColor[
              0.8419839123581961, 0.3124840077358858, 0.18739747519941907`], 
             UndirectedEdge[80, 192] -> 
             RGBColor[
              0.3302026401393104, 0.46042666324658016`, 0.9422611981363149], 
             UndirectedEdge[74, 402] -> 
             RGBColor[
              0.20341804022375085`, 0.331135636096799, 0.9348957285094954], 
             UndirectedEdge[3, 158] -> 
             RGBColor[
              0.187682952058607, 0.31459706077302096`, 0.9339996385164674], 
             UndirectedEdge[426, 476] -> 
             RGBColor[
              0.1853934884122734, 0.3121906893203451, 0.9338692569487667], 
             UndirectedEdge[27, 177] -> 
             RGBColor[
              0.18479696914654997`, 0.31156370975056386`, 0.9338352860590549],
              UndirectedEdge[355, 443] -> 
             RGBColor[
              0.4237732599016528, 0.5366508333936366, 0.9490924002850236], 
             UndirectedEdge[21, 256] -> 
             RGBColor[
              0.3057801725853121, 0.43846478219210167`, 0.9407346183816234], 
             UndirectedEdge[331, 404] -> 
             RGBColor[
              0.5691308396856145, 0.6534422515230649, 0.9623880647122928], 
             UndirectedEdge[142, 285] -> 
             RGBColor[
              0.2150502131881199, 0.3433617874047141, 0.9355581635515585], 
             UndirectedEdge[232, 267] -> 
             RGBColor[
              0.25385827815003914`, 0.3841515242531258, 0.9377682254397526], 
             UndirectedEdge[133, 488] -> 
             RGBColor[
              0.19025464326071956`, 0.31730007128108106`, 0.9341460925259515],
              UndirectedEdge[148, 393] -> 
             RGBColor[
              0.24797563185424576`, 0.37796849001492944`, 0.9374332174358024],
              UndirectedEdge[84, 89] -> 
             RGBColor[
              0.2925984761880414, 0.42478343593361145`, 0.9399775893294924], 
             UndirectedEdge[27, 350] -> 
             RGBColor[
              0.18336792975933797`, 0.3100616987482737, 0.9337539043800275], 
             UndirectedEdge[8, 435] -> 
             RGBColor[
              0.21794255850182165`, 0.34640182571469935`, 0.9357228783383325],
              UndirectedEdge[20, 220] -> 
             RGBColor[
              0.2293954500117661, 0.35843954084691343`, 0.9363751035667891], 
             UndirectedEdge[35, 422] -> 
             RGBColor[
              0.19709463641182273`, 0.32448933776350447`, 0.9345356200170438],
              UndirectedEdge[65, 177] -> 
             RGBColor[
              0.18378082822451933`, 0.3104956812144541, 0.9337774183367911], 
             UndirectedEdge[93, 160] -> 
             RGBColor[
              0.23103960685447572`, 0.36016765393416605`, 0.9364687358666692],
              UndirectedEdge[277, 373] -> 
             RGBColor[
              0.7171130809828956, 0.774434213301909, 0.8741433170431847], 
             UndirectedEdge[15, 126] -> 
             RGBColor[
              0.5704313985291926, 0.6619870174784861, 0.9594308284953961], 
             UndirectedEdge[95, 367] -> 
             RGBColor[
              0.19091514645848728`, 0.31799430202025647`, 0.9341837072059376],
              UndirectedEdge[304, 465] -> 
             RGBColor[
              0.18487917380697239`, 0.31165011206074433`, 0.933839967492855], 
             UndirectedEdge[218, 305] -> 
             RGBColor[
              0.29821563929003225`, 0.43060670099699316`, 0.9403004343609631],
              UndirectedEdge[137, 265] -> 
             RGBColor[
              0.19798921213274367`, 0.325429593565569, 0.934586564780944], 
             UndirectedEdge[325, 392] -> 
             RGBColor[
              0.23524305947406288`, 0.3645857491516413, 0.9367081162749039], 
             UndirectedEdge[263, 393] -> 
             RGBColor[
              0.22282702878996197`, 0.35153571368083814`, 0.9360010416953157],
              UndirectedEdge[228, 335] -> 
             RGBColor[
              0.2342958788041693, 0.36359020221286015`, 0.9366541757369817], 
             UndirectedEdge[104, 408] -> 
             RGBColor[
              0.9307079198191593, 0.8448308855634613, 0.624429309131783], 
             UndirectedEdge[145, 375] -> 
             RGBColor[
              0.20589359976284474`, 0.33373760613192704`, 0.9350367079629848],
              UndirectedEdge[181, 451] -> 
             RGBColor[
              0.21530209522723562`, 0.3436265313980684, 0.93557250786106], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.20367497522683542`, 0.331405691075661, 0.93491036057782], 
             UndirectedEdge[387, 439] -> 
             RGBColor[
              0.1940605439508961, 0.3213003142144977, 0.9343628329399316], 
             UndirectedEdge[163, 231] -> 
             RGBColor[
              0.8314832405552138, 0.7254800292683178, 0.607385428867296], 
             UndirectedEdge[143, 288] -> 
             RGBColor[
              0.6459376056374727, 0.7223853584829198, 0.9659909719465696], 
             UndirectedEdge[128, 312] -> 
             RGBColor[
              0.19461247887943717`, 0.32188043281908996`, 0.9343942648175974],
              UndirectedEdge[270, 479] -> 
             RGBColor[
              0.18121603188329788`, 0.30779991764234993`, 0.9336313569794346],
              UndirectedEdge[119, 120] -> 
             RGBColor[
              0.18211134871711507`, 0.30874095240105776`, 0.9336823439486179],
              UndirectedEdge[105, 462] -> 
             RGBColor[
              0.19074614489061564`, 0.31781667065710506`, 0.9341740828166627],
              UndirectedEdge[14, 159] -> 
             RGBColor[
              0.2315482163827265, 0.3607022347960642, 0.9364977004268829], 
             UndirectedEdge[58, 417] -> 
             RGBColor[
              0.19514933346569613`, 0.3224447010277949, 0.9344248378920796], 
             UndirectedEdge[66, 299] -> 
             RGBColor[
              0.21897785763056482`, 0.34748999074076453`, 0.9357818370921265],
              UndirectedEdge[11, 348] -> 
             RGBColor[
              0.41882704946853977`, 0.5369507513572022, 0.9479740053732437], 
             UndirectedEdge[4, 31] -> 
             RGBColor[
              0.18674651901237604`, 0.3136128102681478, 0.9339463100398131], 
             UndirectedEdge[259, 400] -> 
             RGBColor[
              0.8365707919285453, 0.8712879121400499, 0.8933185067355665], 
             UndirectedEdge[247, 451] -> 
             RGBColor[
              0.19468301666075716`, 0.32195457249961096`, 0.9343982818398924],
              UndirectedEdge[17, 261] -> 
             RGBColor[
              0.3523681166453383, 0.4796252849268593, 0.9436735626991177], 
             UndirectedEdge[361, 386] -> 
             RGBColor[
              0.26785160184799417`, 0.39885939468764287`, 0.9385651245230838],
              UndirectedEdge[212, 492] -> 
             RGBColor[
              0.18227723304689475`, 0.30891530734933015`, 0.933691790815795], 
             UndirectedEdge[287, 388] -> 
             RGBColor[
              0.31642089310081123`, 0.44806502999070874`, 0.9413985832331735],
              UndirectedEdge[383, 480] -> 
             RGBColor[
              0.2555678088390552, 0.3859483493977877, 0.937865580683468], 
             UndirectedEdge[403, 440] -> 
             RGBColor[
              0.8175206971599966, 0.7001431418216288, 0.6031737768596591], 
             UndirectedEdge[13, 354] -> 
             RGBColor[
              0.28176652075351294`, 0.4133145757884693, 0.9393637933883066], 
             UndirectedEdge[1, 42] -> 
             RGBColor[
              0.19991385155278849`, 0.32745251162522343`, 0.9346961701486667],
              UndirectedEdge[161, 188] -> 
             RGBColor[
              0.2189136351360459, 0.34742248882708376`, 0.9357781797160722], 
             UndirectedEdge[194, 426] -> 
             RGBColor[
              0.18673198964571103`, 0.31359753898256787`, 0.9339454826138758],
              UndirectedEdge[257, 324] -> 
             RGBColor[
              0.9513926924014826, 0.9208016602260798, 0.6489338534613713], 
             UndirectedEdge[198, 479] -> 
             RGBColor[
              0.18236486345397498`, 0.30900741246326024`, 0.9336967812378407],
              UndirectedEdge[372, 431] -> 
             RGBColor[
              0.5177615934513908, 0.6185105449794727, 0.9554198037200161], 
             UndirectedEdge[107, 466] -> 
             RGBColor[
              0.20308636910120992`, 0.33078702871784477`, 0.9348768403297303],
              UndirectedEdge[122, 330] -> 
             RGBColor[
              0.18762963037517022`, 0.3145410163029389, 0.9339966019254781], 
             UndirectedEdge[4, 472] -> 
             RGBColor[
              0.18232394464799978`, 0.30896440420377813`, 0.9336944509723744],
              UndirectedEdge[145, 458] -> 
             RGBColor[
              0.2240333301287531, 0.35280361287183004`, 0.936069738771997], 
             UndirectedEdge[3, 451] -> 
             RGBColor[
              0.19437267435842231`, 0.32162838306301855`, 0.9343806083048847],
              UndirectedEdge[146, 239] -> 
             RGBColor[
              0.18835872742063176`, 0.3153073435251416, 0.9340381229236147], 
             UndirectedEdge[15, 282] -> 
             RGBColor[
              0.674559975761555, 0.7456906470014069, 0.9681974923286845], 
             UndirectedEdge[82, 126] -> 
             RGBColor[
              0.504289208348975, 0.6084437231644664, 0.9541186402349197], 
             UndirectedEdge[413, 474] -> 
             RGBColor[
              0.2299117533537109, 0.35898220839482003`, 0.9364045062783105], 
             UndirectedEdge[160, 235] -> 
             RGBColor[
              0.22828336996259535`, 0.35727067420528746`, 0.9363117722531638],
              UndirectedEdge[161, 183] -> 
             RGBColor[
              0.2054076978090161, 0.33322689237048986`, 0.9350090365655417], 
             UndirectedEdge[366, 429] -> 
             RGBColor[
              0.18725297443025463`, 0.3141451270234664, 0.9339751519266276], 
             UndirectedEdge[7, 313] -> 
             RGBColor[
              0.4167872287841039, 0.534905009234637, 0.9479211050634437], 
             UndirectedEdge[129, 444] -> 
             RGBColor[
              0.42761995292876165`, 0.539957845554271, 0.9493784687183828], 
             UndirectedEdge[18, 493] -> 
             RGBColor[
              0.274609024515375, 0.4059618743564031, 0.9389499497472802], 
             UndirectedEdge[149, 411] -> 
             RGBColor[
              0.4211694508709569, 0.5337442476409241, 0.9489595750460023], 
             UndirectedEdge[221, 301] -> 
             RGBColor[
              0.8093616863432395, 0.8079745679423065, 0.6371695161143949], 
             UndirectedEdge[45, 496] -> 
             RGBColor[
              0.19349628938952101`, 0.32070724689468694`, 0.9343306994774011],
              UndirectedEdge[478, 482] -> 
             RGBColor[
              0.2908428553905808, 0.4208402752825938, 0.939954423420793], 
             UndirectedEdge[69, 331] -> 
             RGBColor[
              0.37214546505797846`, 0.49607945348638943`, 0.9449585086661204],
              UndirectedEdge[16, 143] -> 
             RGBColor[
              0.42538425366010096`, 0.535839238383477, 0.9494121511680118], 
             UndirectedEdge[210, 280] -> 
             RGBColor[
              0.22449871038575198`, 0.3532927570287484, 0.9360962414891647], 
             UndirectedEdge[101, 390] -> 
             RGBColor[
              0.25051248587412484`, 0.3806348844356572, 0.9375776875192954], 
             UndirectedEdge[400, 418] -> 
             RGBColor[
              0.7331868241624636, 0.7879829034782768, 0.8847512271126452], 
             UndirectedEdge[84, 299] -> 
             RGBColor[
              0.2577944317187598, 0.3882886712204018, 0.9379923835624739], 
             UndirectedEdge[333, 386] -> 
             RGBColor[
              0.268695341419697, 0.3997462184736812, 0.9386131742434916], 
             UndirectedEdge[244, 341] -> 
             RGBColor[
              0.7205094989495678, 0.7757802394753833, 0.7851817105206231], 
             UndirectedEdge[143, 373] -> 
             RGBColor[
              0.7858256992864812, 0.8304922181829903, 0.8794769174192558], 
             UndirectedEdge[160, 284] -> 
             RGBColor[
              0.22313950665110643`, 0.35186414772514174`, 0.9360188368472383],
              UndirectedEdge[281, 343] -> 
             RGBColor[
              0.8323272687160201, 0.24948713001661726`, 0.17858993507187598`],
              UndirectedEdge[207, 445] -> 
             RGBColor[
              0.9190529143682962, 0.7062401460895815, 0.26431121911210875`], 
             UndirectedEdge[260, 334] -> 
             RGBColor[
              0.19830298963418935`, 0.3257593936142311, 0.9346044339454591], 
             UndirectedEdge[66, 114] -> 
             RGBColor[
              0.1896583133560848, 0.31667329074181017`, 0.9341121324200736], 
             UndirectedEdge[364, 381] -> 
             RGBColor[
              0.19634549402636683`, 0.3237019416180197, 0.9344929574664489], 
             UndirectedEdge[204, 306] -> 
             RGBColor[
              0.2783366060930942, 0.40921806996322074`, 0.9391864591429547], 
             UndirectedEdge[358, 361] -> 
             RGBColor[
              0.2274919045840746, 0.3564387939106588, 0.9362666994707252], 
             UndirectedEdge[294, 415] -> 
             RGBColor[
              0.18394556991543065`, 0.3106688351768284, 0.9337868001323749], 
             UndirectedEdge[2, 255] -> 
             RGBColor[
              0.19068245309328063`, 0.3177497265398128, 0.9341704556630279], 
             UndirectedEdge[326, 443] -> 
             RGBColor[
              0.5066093535132791, 0.6026290989849493, 0.956483102354086], 
             UndirectedEdge[58, 145] -> 
             RGBColor[
              0.20110599109187893`, 0.32870552586681995`, 0.9347640607318055],
              UndirectedEdge[103, 346] -> 
             RGBColor[
              0.4256097063793528, 0.5430634687251261, 0.9483404520319744], 
             UndirectedEdge[62, 108] -> 
             RGBColor[
              0.2304034031645468, 0.35949896351840704`, 0.9364325050077069], 
             UndirectedEdge[91, 336] -> 
             RGBColor[
              0.5428373971732765, 0.639738879428151, 0.957153294865837], 
             UndirectedEdge[338, 395] -> 
             RGBColor[
              0.4642366864681818, 0.5751402530845398, 0.9511830173068838], 
             UndirectedEdge[19, 335] -> 
             RGBColor[
              0.20679640724799403`, 0.3346865140401196, 0.9350881215136799], 
             UndirectedEdge[2, 195] -> 
             RGBColor[
              0.18614467853761885`, 0.312980237770288, 0.933912036115119], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.2086123729274203, 0.33659520910807084`, 0.9351915380726428], 
             UndirectedEdge[150, 325] -> 
             RGBColor[
              0.2244980131258032, 0.35329202416433336`, 0.9360962017812421], 
             UndirectedEdge[208, 238] -> 
             RGBColor[
              0.4566518822195865, 0.5690445386024363, 0.9505687908779773], 
             UndirectedEdge[318, 335] -> 
             RGBColor[
              0.2041779627078255, 0.33193436280942984`, 0.9349390049707589], 
             UndirectedEdge[12, 421] -> 
             RGBColor[
              0.18918604161445732`, 0.31617690319760183`, 0.9340852372430514],
              UndirectedEdge[102, 278] -> 
             RGBColor[
              0.19195325855915324`, 0.31908542365816517`, 0.9342428261543212],
              UndirectedEdge[5, 209] -> 
             RGBColor[
              0.8420261863364131, 0.8747026148224741, 0.8554514610488602], 
             UndirectedEdge[76, 463] -> 
             RGBColor[
              0.4827936292790318, 0.5898280832845495, 0.9527482010251842], 
             UndirectedEdge[293, 445] -> 
             RGBColor[
              0.8864338531014064, 0.8692772537699642, 0.6464479308964578], 
             UndirectedEdge[48, 250] -> 
             RGBColor[
              0.20476233546869063`, 0.33254857563247214`, 0.9349722841349881],
              UndirectedEdge[459, 477] -> 
             RGBColor[
              0.19613686914455325`, 0.32348266363965217`, 0.9344810765880625],
              UndirectedEdge[400, 404] -> 
             RGBColor[
              0.9133476519960143, 0.9314027140164651, 0.9009347805127319], 
             UndirectedEdge[144, 246] -> 
             RGBColor[
              0.21838885852257034`, 0.34687091533356196`, 0.9357482944642723],
              UndirectedEdge[90, 393] -> 
             RGBColor[
              0.24183341082623228`, 0.3715126262751811, 0.9370834270348589], 
             UndirectedEdge[157, 360] -> 
             RGBColor[
              0.44762961538947754`, 0.5573651742459853, 0.9508478770838158], 
             UndirectedEdge[156, 250] -> 
             RGBColor[
              0.20951821380303975`, 0.3375473053019756, 0.9352431243704379], 
             UndirectedEdge[25, 220] -> 
             RGBColor[
              0.25296409856661417`, 0.38321168481668605`, 0.9377173032352967],
              UndirectedEdge[261, 407] -> 
             RGBColor[
              0.30321117252682794`, 0.43412485717667065`, 0.9406483566550587],
              UndirectedEdge[42, 364] -> 
             RGBColor[
              0.2024710281446618, 0.33014026635764265`, 0.9348417975725702], 
             UndirectedEdge[83, 257] -> 
             RGBColor[
              0.9791397410141973, 0.9396620716614368, 0.5198667768744751], 
             UndirectedEdge[137, 263] -> 
             RGBColor[
              0.21799699214111928`, 0.34645903892089325`, 0.935725978253563], 
             UndirectedEdge[27, 65] -> 
             RGBColor[
              0.1841954077512366, 0.31093143058289413`, 0.9338010280275222], 
             UndirectedEdge[318, 421] -> 
             RGBColor[
              0.19115878724665003`, 0.3182503839363337, 0.9341975821883891], 
             UndirectedEdge[203, 341] -> 
             RGBColor[
              0.9196841878836145, 0.6688261379622193, 0.4057355619852222], 
             UndirectedEdge[80, 483] -> 
             RGBColor[
              0.3997284089104274, 0.520646389689377, 0.9466913186431871], 
             UndirectedEdge[95, 319] -> 
             RGBColor[
              0.18277177150935192`, 0.30943509862892227`, 0.9337199540496279],
              UndirectedEdge[84, 376] -> 
             RGBColor[
              0.3233121821951179, 0.4513861043611917, 0.9419346395171995], 
             UndirectedEdge[260, 446] -> 
             RGBColor[
              0.19657895504970424`, 0.32394732395583115`, 0.9345062527263533],
              UndirectedEdge[174, 393] -> 
             RGBColor[
              0.20439651484045512`, 0.33216407495782907`, 0.9349514511913933],
              UndirectedEdge[185, 216] -> 
             RGBColor[
              0.20572802131241785`, 0.3335635726822483, 0.9350272785151843], 
             UndirectedEdge[143, 321] -> 
             RGBColor[
              0.78304348190439, 0.8293416997957703, 0.9255854595882844], 
             UndirectedEdge[296, 415] -> 
             RGBColor[
              0.18131418208775438`, 0.30790307973031616`, 0.9336369464883782],
              UndirectedEdge[42, 113] -> 
             RGBColor[
              0.1986334681543265, 0.3261067474924436, 0.9346232542082819], 
             UndirectedEdge[54, 264] -> 
             RGBColor[
              0.9275346951808384, 0.7361423049047013, 0.5163860611032753], 
             UndirectedEdge[9, 95] -> 
             RGBColor[
              0.18923630977445122`, 0.3162297382209408, 0.934088099940398], 
             UndirectedEdge[47, 55] -> 
             RGBColor[
              0.42760134170853215`, 0.539013813149998, 0.94946155992206], 
             UndirectedEdge[212, 330] -> 
             RGBColor[
              0.18576322285580926`, 0.312579303663019, 0.9338903127783529], 
             UndirectedEdge[89, 244] -> 
             RGBColor[
              0.37820158055690994`, 0.5020009329394131, 0.945319648175928], 
             UndirectedEdge[3, 247] -> 
             RGBColor[
              0.18396896047476097`, 0.31069342013773166`, 0.9337881321901256],
              UndirectedEdge[26, 318] -> 
             RGBColor[
              0.1914380372433468, 0.3185438933883344, 0.9342134850625876], 
             UndirectedEdge[46, 426] -> 
             RGBColor[
              0.19553365018810587`, 0.3228486422701351, 0.9344467241608754], 
             UndirectedEdge[102, 247] -> 
             RGBColor[
              0.19186086570906943`, 0.31898831291468205`, 0.934237564518192], 
             UndirectedEdge[285, 287] -> 
             RGBColor[
              0.2592707940788048, 0.38984042166758914`, 0.938076460214796], 
             UndirectedEdge[346, 390] -> 
             RGBColor[
              0.34866455216030523`, 0.47153274446045024`, 0.9436164276057963],
              UndirectedEdge[388, 473] -> 
             RGBColor[
              0.2961409162225916, 0.4267494884669002, 0.9402436685514961], 
             UndirectedEdge[377, 412] -> 
             RGBColor[
              0.18552364470094684`, 0.3123274918321262, 0.9338766691568576], 
             UndirectedEdge[7, 321] -> 
             RGBColor[
              0.7288945912633815, 0.7853811909936754, 0.9213226605631021], 
             UndirectedEdge[209, 275] -> 
             RGBColor[
              0.7418942375705933, 0.7941342962234403, 0.8470741774102124], 
             UndirectedEdge[204, 346] -> 
             RGBColor[
              0.3786592419849977, 0.5023973362656904, 0.9453488099574316], 
             UndirectedEdge[220, 297] -> 
             RGBColor[
              0.20614792707638763`, 0.3340049202637436, 0.9350511915272475], 
             UndirectedEdge[16, 185] -> 
             RGBColor[
              0.2408288180096403, 0.3704567355300795, 0.9370262169601158], 
             UndirectedEdge[323, 449] -> 
             RGBColor[
              0.9881583833202512, 0.9738084894895631, 0.5806455490390734], 
             UndirectedEdge[224, 481] -> 
             RGBColor[
              0.20560152977914695`, 0.33343062206075413`, 0.9350200750094919],
              UndirectedEdge[86, 476] -> 
             RGBColor[
              0.18437093737264393`, 0.311115923344214, 0.9338110241797885], 
             UndirectedEdge[66, 385] -> 
             RGBColor[
              0.189718897172314, 0.31673696817390284`, 0.9341155825787821], 
             UndirectedEdge[184, 316] -> 
             RGBColor[
              0.4897742836055883, 0.5962632949587165, 0.9530855424591965], 
             UndirectedEdge[308, 362] -> 
             RGBColor[
              0.18507064546441102`, 0.3118513609127166, 0.9338508715204893], 
             UndirectedEdge[216, 361] -> 
             RGBColor[
              0.21500792746091607`, 0.34331734242435297`, 0.9355557554419504],
              UndirectedEdge[123, 410] -> 
             RGBColor[
              0.18404732868398718`, 0.3107757900944599, 0.9337925951437056], 
             UndirectedEdge[174, 225] -> 
             RGBColor[
              0.18572114805288265`, 0.3125350803774465, 0.9338879166805704], 
             UndirectedEdge[3, 139] -> 
             RGBColor[
              0.18312900664284068`, 0.3098105754042345, 0.933740298061998], 
             UndirectedEdge[226, 472] -> 
             RGBColor[
              0.18505776823943543`, 0.311837826132804, 0.933850138181577], 
             UndirectedEdge[9, 441] -> 
             RGBColor[
              0.2076297588947049, 0.33556241945835885`, 0.9351355796571268], 
             UndirectedEdge[253, 354] -> 
             RGBColor[
              0.34404011319445926`, 0.47241198691533204`, 0.9431429096833921],
              UndirectedEdge[47, 73] -> 
             RGBColor[
              0.42925393472115597`, 0.5403554626061129, 0.9495916580976614], 
             UndirectedEdge[305, 432] -> 
             RGBColor[
              0.30089384576863576`, 0.43342166581410385`, 0.9404529542578681],
              UndirectedEdge[4, 226] -> 
             RGBColor[
              0.18424586592068898`, 0.3109844653182212, 0.9338039015456263], 
             UndirectedEdge[112, 359] -> 
             RGBColor[
              0.9514837896604106, 0.9611256689561112, 0.8747939095613684], 
             UndirectedEdge[101, 204] -> 
             RGBColor[
              0.2805071756988172, 0.41149947624089733`, 0.9393100698709307], 
             UndirectedEdge[256, 409] -> 
             RGBColor[
              0.2823955714492146, 0.41388608372871627`, 0.93940289994134], 
             UndirectedEdge[64, 268] -> 
             RGBColor[
              0.18555371944787077`, 0.31235910229799235`, 0.9338783818692034],
              UndirectedEdge[97, 395] -> 
             RGBColor[
              0.7462989112429244, 0.7905238121869427, 0.6818821167624534], 
             UndirectedEdge[117, 156] -> 
             RGBColor[
              0.19147940284680726`, 0.31858737126030207`, 0.9342158407725099],
              UndirectedEdge[48, 117] -> 
             RGBColor[
              0.18672352451245816`, 0.31358864159079863`, 0.9339450005370601],
              UndirectedEdge[5, 103] -> 
             RGBColor[
              0.5496901810493061, 0.6433974652672816, 0.958513754171764], 
             UndirectedEdge[344, 438] -> 
             RGBColor[
              0.19645882867909248`, 0.32382106352386636`, 0.934499411707258], 
             UndirectedEdge[42, 381] -> 
             RGBColor[
              0.19442462278648562`, 0.3216829841546337, 0.9343835666910121], 
             UndirectedEdge[224, 398] -> 
             RGBColor[
              0.2060967195595755, 0.33395109791683003`, 0.9350482753349197], 
             UndirectedEdge[226, 405] -> 
             RGBColor[
              0.18431945622850954`, 0.3110618133976357, 0.9338080924047896], 
             UndirectedEdge[231, 346] -> 
             RGBColor[
              0.6025366315327623, 0.6860240764087309, 0.963212758449727], 
             UndirectedEdge[168, 181] -> 
             RGBColor[
              0.25911497354415575`, 0.3896766444060805, 0.9380675864658636], 
             UndirectedEdge[178, 391] -> 
             RGBColor[
              0.47121205870336796`, 0.5815902029735522, 0.9515146858492259], 
             UndirectedEdge[30, 133] -> 
             RGBColor[
              0.18845727560531045`, 0.31541092391555475`, 0.934043735096943], 
             UndirectedEdge[120, 363] -> 
             RGBColor[
              0.18125858689584057`, 0.307844645658676, 0.9336337804244444], 
             UndirectedEdge[452, 468] -> 
             RGBColor[
              0.22415491498640028`, 0.35293140626614244`, 0.9360766628497713],
              UndirectedEdge[159, 344] -> 
             RGBColor[
              0.2111960256367822, 0.3393107919186533, 0.9353386732722694], 
             UndirectedEdge[68, 330] -> 
             RGBColor[
              0.18750410848445143`, 0.3144090848372459, 0.9339894536394946], 
             UndirectedEdge[359, 440] -> 
             RGBColor[
              0.9005793035034079, 0.7657528918366445, 0.6112602253720522], 
             UndirectedEdge[180, 413] -> 
             RGBColor[
              0.24672751485063993`, 0.37665663990895104`, 0.9373621390188708],
              UndirectedEdge[81, 442] -> 
             RGBColor[
              0.2381306078360068, 0.36762074556118485`, 0.9368725578823716], 
             UndirectedEdge[165, 277] -> 
             RGBColor[
              0.37457657867037175`, 0.49860046416423287`, 0.9450982108256749],
              UndirectedEdge[28, 310] -> 
             RGBColor[
              0.5603270606284811, 0.6539001893978842, 0.958555843487958], 
             UndirectedEdge[71, 470] -> 
             RGBColor[
              0.19617627269900267`, 0.32352407927370813`, 0.9344833205621961],
              UndirectedEdge[129, 276] -> 
             RGBColor[
              0.2514871752437865, 0.381659344762047, 0.9376331946369739], 
             UndirectedEdge[192, 251] -> 
             RGBColor[
              0.2759596386433615, 0.40698913765266753`, 0.9390412298997809], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.4280975104696688, 0.5447636755214684, 0.9486245811666656], 
             UndirectedEdge[15, 323] -> 
             RGBColor[
              0.82255832396822, 0.8598188337480478, 0.8682325932875272], 
             UndirectedEdge[20, 473] -> 
             RGBColor[
              0.25267572333140287`, 0.38290858416043305`, 0.9377008806922643],
              UndirectedEdge[336, 354] -> 
             RGBColor[
              0.4679691659715405, 0.5750820152163606, 0.9523301949713454], 
             UndirectedEdge[36, 440] -> 
             RGBColor[
              0.9428820049759663, 0.7963257915311912, 0.48910376799027133`], 
             UndirectedEdge[31, 311] -> 
             RGBColor[
              0.1909827965699547, 0.3180654065766735, 0.9341875597797062], 
             UndirectedEdge[366, 405] -> 
             RGBColor[
              0.18210802697612394`, 0.3087374610406655, 0.9336821547803826], 
             UndirectedEdge[257, 374] -> 
             RGBColor[
              0.9052484576679132, 0.6263565932934416, 0.25201642158872506`], 
             UndirectedEdge[194, 254] -> 
             RGBColor[
              0.18926826388068996`, 0.3162633240126051, 0.9340899196794763], 
             UndirectedEdge[284, 456] -> 
             RGBColor[
              0.2012208320986775, 0.3288262310463056, 0.9347706007572507], 
             UndirectedEdge[30, 429] -> 
             RGBColor[
              0.18544154731921458`, 0.312241202278651, 0.9338719938324201], 
             UndirectedEdge[182, 463] -> 
             RGBColor[
              0.4500781331882001, 0.5614915648993155, 0.9506635985434537], 
             UndirectedEdge[130, 238] -> 
             RGBColor[
              0.39480407867420486`, 0.5149363424561325, 0.9466476293366854], 
             UndirectedEdge[19, 67] -> 
             RGBColor[
              0.1920452315036252, 0.3191820930542266, 0.9342480638774471], 
             UndirectedEdge[114, 446] -> 
             RGBColor[
              0.18242070987008802`, 0.30906611058746236`, 0.933699961608621], 
             UndirectedEdge[164, 418] -> 
             RGBColor[
              0.3962653140595378, 0.5170172416815048, 0.9466446107033122], 
             UndirectedEdge[96, 457] -> 
             RGBColor[
              0.47001276809964954`, 0.5806165648340276, 0.951420273299755], 
             UndirectedEdge[285, 354] -> 
             RGBColor[
              0.2624877417671351, 0.39305135672859914`, 0.93826589544543], 
             UndirectedEdge[432, 460] -> 
             RGBColor[
              0.2959533208946317, 0.4283960831575556, 0.9401654758500221], 
             UndirectedEdge[82, 249] -> 
             RGBColor[
              0.6235359473541606, 0.7039577755666018, 0.9643921411464688], 
             UndirectedEdge[176, 262] -> 
             RGBColor[
              0.33005042418212294`, 0.46029482143506084`, 0.9422514990701223],
              UndirectedEdge[216, 358] -> 
             RGBColor[
              0.21239908038802668`, 0.34057527874028815`, 0.9354071854605928],
              UndirectedEdge[54, 374] -> 
             RGBColor[
              0.9184848946909366, 0.6778098895741775, 0.5081596346636814], 
             UndirectedEdge[214, 491] -> 
             RGBColor[
              0.1845859949601158, 0.3113419625040855, 0.9338232713912458], 
             UndirectedEdge[68, 357] -> 
             RGBColor[
              0.18698592728629504`, 0.313864443543398, 0.93395994398684], 
             UndirectedEdge[260, 328] -> 
             RGBColor[
              0.2263686482084435, 0.35525818024130285`, 0.9362027316818419], 
             UndirectedEdge[224, 286] -> 
             RGBColor[
              0.19666508001759797`, 0.3240378467577258, 0.9345111574158644], 
             UndirectedEdge[219, 293] -> 
             RGBColor[
              0.7396376270146225, 0.7965298027687717, 0.9746838244203624], 
             UndirectedEdge[209, 404] -> 
             RGBColor[
              0.9156515263183187, 0.9323554252556073, 0.8627536207565263], 
             UndirectedEdge[197, 289] -> 
             RGBColor[
              0.22048333522571711`, 0.34907234314606217`, 0.9358675718140159],
              UndirectedEdge[227, 424] -> 
             RGBColor[
              0.19331536997885967`, 0.3205170891231287, 0.9343203963846103], 
             UndirectedEdge[458, 461] -> 
             RGBColor[
              0.24614691137880979`, 0.3760463888476713, 0.937329074510076], 
             UndirectedEdge[292, 464] -> 
             RGBColor[
              0.19378696997725373`, 0.3210127706226078, 0.9343472533068491], 
             UndirectedEdge[386, 441] -> 
             RGBColor[
              0.26353501578649874`, 0.39432238904964745`, 0.9383193013326985],
              UndirectedEdge[257, 343] -> 
             RGBColor[
              0.9046416145156388, 0.621692130904697, 0.25143530790077595`], 
             UndirectedEdge[132, 457] -> 
             RGBColor[
              0.37078286929344473`, 0.4917742570671961, 0.9450898009992874], 
             UndirectedEdge[69, 259] -> 
             RGBColor[
              0.5630647117651555, 0.6552495084047187, 0.9592526654459177], 
             UndirectedEdge[68, 95] -> 
             RGBColor[
              0.18505409827792216`, 0.3118339687705646, 0.933849929182698], 
             UndirectedEdge[247, 278] -> 
             RGBColor[
              0.18437169562717964`, 0.3111167203178072, 0.9338110673612625], 
             UndirectedEdge[293, 440] -> 
             RGBColor[
              0.8506906968621433, 0.7260557976902806, 0.6064798524386981], 
             UndirectedEdge[307, 442] -> 
             RGBColor[
              0.21483864965875055`, 0.34313942072144443`, 0.9355461153215412],
              UndirectedEdge[406, 493] -> 
             RGBColor[
              0.33870341661598447`, 0.4633663515821581, 0.9429648172026237], 
             UndirectedEdge[155, 479] -> 
             RGBColor[
              0.18812050432693928`, 0.3150569559494543, 0.9340245564708484], 
             UndirectedEdge[311, 488] -> 
             RGBColor[
              0.18625665477025105`, 0.3130979318904876, 0.9339184129959133], 
             UndirectedEdge[226, 345] -> 
             RGBColor[
              0.18891037080707027`, 0.3158871557004993, 0.9340695381983891], 
             UndirectedEdge[183, 273] -> 
             RGBColor[
              0.19206178134703447`, 0.31919948798897047`, 0.934249006366546], 
             UndirectedEdge[384, 499] -> 
             RGBColor[
              0.4483239267217146, 0.554218492373762, 0.9512402754132152], 
             UndirectedEdge[20, 325] -> 
             RGBColor[
              0.23769654620583044`, 0.3671645192667726, 0.9368478387146697], 
             UndirectedEdge[252, 424] -> 
             RGBColor[
              0.1878893571902253, 0.31481400565319295`, 0.934011392983364], 
             UndirectedEdge[285, 473] -> 
             RGBColor[
              0.2389908172005852, 0.3685248801437806, 0.9369215455331186], 
             UndirectedEdge[71, 236] -> 
             RGBColor[
              0.20304903767595361`, 0.3307477910229513, 0.9348747143602888], 
             UndirectedEdge[2, 446] -> 
             RGBColor[
              0.18380079735160318`, 0.310516670033135, 0.9337785555490368], 
             UndirectedEdge[33, 351] -> 
             RGBColor[
              0.24823088148452888`, 0.3782367735601183, 0.937447753524639], 
             UndirectedEdge[172, 466] -> 
             RGBColor[
              0.20918917113405136`, 0.3372014605943586, 0.935224385877214], 
             UndirectedEdge[12, 279] -> 
             RGBColor[
              0.2010090657422573, 0.3286036511789455, 0.9347585409765328], 
             UndirectedEdge[171, 219] -> 
             RGBColor[
              0.5701105988481052, 0.6614643237945504, 0.9595848784963202], 
             UndirectedEdge[153, 223] -> 
             RGBColor[
              0.21791092009915627`, 0.34636857174750746`, 0.9357210765781054],
              UndirectedEdge[121, 489] -> 
             RGBColor[
              0.1983767553672155, 0.32583692607665915`, 0.9346086347948284], 
             UndirectedEdge[362, 470] -> 
             RGBColor[
              0.1869253840691414, 0.31380080878350786`, 0.9339564961401887], 
             UndirectedEdge[168, 232] -> 
             RGBColor[
              0.28558604817661837`, 0.417499422207868, 0.9395750750057368], 
             UndirectedEdge[285, 409] -> 
             RGBColor[
              0.23381068107618688`, 0.3630802286374379, 0.9366265444441588], 
             UndirectedEdge[159, 439] -> 
             RGBColor[
              0.21567326392113564`, 0.34401665322881175`, 0.9355936453690827],
              UndirectedEdge[156, 263] -> 
             RGBColor[
              0.21186651840498638`, 0.34001552232973276`, 0.9353768568435135],
              UndirectedEdge[149, 314] -> 
             RGBColor[
              0.41196878637874557`, 0.5240737659037882, 0.9484356108143341], 
             UndirectedEdge[110, 457] -> 
             RGBColor[
              0.44316356556908426`, 0.5578351155851111, 0.9495785036311474], 
             UndirectedEdge[43, 263] -> 
             RGBColor[
              0.2263534256582619, 0.35524218037589655`, 0.9362018647801287], 
             UndirectedEdge[141, 160] -> 
             RGBColor[
              0.2233789267066098, 0.352115793383584, 0.936032471465209], 
             UndirectedEdge[345, 389] -> 
             RGBColor[
              0.1928812337006961, 0.3200607843689489, 0.9342956729658158], 
             UndirectedEdge[225, 247] -> 
             RGBColor[
              0.18412221385498584`, 0.31085449915717356`, 0.9337968597434113],
              UndirectedEdge[171, 293] -> 
             RGBColor[
              0.6402218599260903, 0.7162357738139922, 0.9665729137735878], 
             UndirectedEdge[179, 415] -> 
             RGBColor[
              0.19025558687597238`, 0.31730106308054046`, 0.9341461462634442],
              UndirectedEdge[143, 414] -> 
             RGBColor[
              0.5016592032391687, 0.6054763090493759, 0.9541415518219014], 
             UndirectedEdge[77, 388] -> 
             RGBColor[
              0.33157794270842256`, 0.4616178812072281, 0.9423488311998864], 
             UndirectedEdge[305, 406] -> 
             RGBColor[
              0.3635284030084348, 0.4892917640422711, 0.9443846862775205], 
             UndirectedEdge[55, 256] -> 
             RGBColor[
              0.4425753647760989, 0.554492515651166, 0.9503238262490175], 
             UndirectedEdge[367, 450] -> 
             RGBColor[
              0.20633807556762712`, 0.3342047783841471, 0.9350620202025242], 
             UndirectedEdge[171, 258] -> 
             RGBColor[
              0.44293779831735625`, 0.5576003693038944, 0.9495749484754112], 
             UndirectedEdge[366, 423] -> 
             RGBColor[
              0.18087837131958237`, 0.30744501498096866`, 0.933612127709855], 
             UndirectedEdge[309, 393] -> 
             RGBColor[
              0.20475589581124165`, 0.33254180714419534`, 0.9349719174060231],
              UndirectedEdge[324, 360] -> 
             RGBColor[
              0.7679481729777577, 0.8188024264455834, 0.9741261052850922], 
             UndirectedEdge[125, 310] -> 
             RGBColor[
              0.7113812015825887, 0.7744556684644794, 0.9718674880046061], 
             UndirectedEdge[33, 463] -> 
             RGBColor[
              0.4057152506945697, 0.5182150283519088, 0.9480144771137997], 
             UndirectedEdge[137, 280] -> 
             RGBColor[
              0.2325647771126936, 0.3617707045769326, 0.9365555920565876], 
             UndirectedEdge[72, 179] -> 
             RGBColor[
              0.20561407521805922`, 0.3334438081124777, 0.9350207894536787], 
             UndirectedEdge[17, 165] -> 
             RGBColor[
              0.3406850289827465, 0.4692453072636289, 0.9429386712487001], 
             UndirectedEdge[402, 417] -> 
             RGBColor[
              0.20763019049226705`, 0.33556287309476157`, 0.9351356042359695],
              UndirectedEdge[102, 225] -> 
             RGBColor[
              0.19170377678695943`, 0.3188232024975315, 0.9342286185364699], 
             UndirectedEdge[83, 231] -> 
             RGBColor[
              0.879442405436877, 0.9037944293481288, 0.8529223377718652], 
             UndirectedEdge[194, 377] -> 
             RGBColor[
              0.1834493331063201, 0.31014725882722227`, 0.9337585401802126], 
             UndirectedEdge[131, 495] -> 
             RGBColor[
              0.8599106722287021, 0.41795803680078086`, 0.20329863351297417`],
              UndirectedEdge[213, 447] -> 
             RGBColor[
              0.2179735437754206, 0.34643439320183167`, 0.9357246429038253], 
             UndirectedEdge[146, 166] -> 
             RGBColor[
              0.18787743892822623`, 0.31480147880417053`, 0.9340107142559747],
              UndirectedEdge[422, 428] -> 
             RGBColor[
              0.19715708759112932`, 0.32455497791258914`, 0.9345391765193171],
              UndirectedEdge[232, 338] -> 
             RGBColor[
              0.351395977443279, 0.47598308304576464`, 0.9437141472934822], 
             UndirectedEdge[366, 469] -> 
             RGBColor[
              0.1819546848445577, 0.30857628873793674`, 0.9336734221728392], 
             UndirectedEdge[245, 482] -> 
             RGBColor[
              0.2881486049407218, 0.4180084472344471, 0.93980098984346], 
             UndirectedEdge[40, 243] -> 
             RGBColor[
              0.19079403389915217`, 0.3178670050414155, 0.9341768100248533], 
             UndirectedEdge[174, 320] -> 
             RGBColor[
              0.1843078028000945, 0.31104956490550145`, 0.933807428759281], 
             UndirectedEdge[30, 31] -> 
             RGBColor[
              0.185457486240386, 0.3122579550953881, 0.9338729015304014], 
             UndirectedEdge[77, 354] -> 
             RGBColor[
              0.32252783628299564`, 0.4537791338930982, 0.9417721664211531], 
             UndirectedEdge[24, 223] -> 
             RGBColor[
              0.19673773915135, 0.32411421611415436`, 0.934515295246042], 
             UndirectedEdge[261, 391] -> 
             RGBColor[
              0.40120374518351687`, 0.5213867241354746, 0.9469338462657712], 
             UndirectedEdge[125, 323] -> 
             RGBColor[
              0.8853299376421364, 0.9088564954320449, 0.8744890811044619], 
             UndirectedEdge[1, 364] -> 
             RGBColor[
              0.2018347227926697, 0.32947146908860947`, 0.9348055609241036], 
             UndirectedEdge[88, 133] -> 
             RGBColor[
              0.19376977710770305`, 0.3209946998266191, 0.9343462741983627], 
             UndirectedEdge[178, 407] -> 
             RGBColor[
              0.3732194860466791, 0.4943283360147483, 0.9452291962385135], 
             UndirectedEdge[103, 486] -> 
             RGBColor[
              0.41156934709801946`, 0.5309024152046116, 0.94744581275397], 
             UndirectedEdge[204, 486] -> 
             RGBColor[
              0.3646188827036643, 0.4902362827451757, 0.9444541706794272], 
             UndirectedEdge[89, 407] -> 
             RGBColor[
              0.2934055397651449, 0.4256317109239335, 0.9400235504062648], 
             UndirectedEdge[38, 301] -> 
             RGBColor[
              0.5876340036038425, 0.6758909546392042, 0.9608274105699129], 
             UndirectedEdge[92, 132] -> 
             RGBColor[
              0.27212682678288186`, 0.40335292715912663`, 0.9388085922584972],
              UndirectedEdge[8, 146] -> 
             RGBColor[
              0.18877984751216192`, 0.31574996744189576`, 0.934062105089836], 
             UndirectedEdge[44, 110] -> 
             RGBColor[
              0.34804321230268565`, 0.4731300192483041, 0.9434986471622288], 
             UndirectedEdge[102, 252] -> 
             RGBColor[
              0.19087465031632422`, 0.3179517380072394, 0.93418140101055], 
             UndirectedEdge[273, 283] -> 
             RGBColor[
              0.18473808843290457`, 0.31150182238726964`, 0.933831932889519], 
             UndirectedEdge[158, 428] -> 
             RGBColor[
              0.1897406655144195, 0.31675984808164837`, 0.9341168222536617], 
             UndirectedEdge[176, 328] -> 
             RGBColor[
              0.27995998628272956`, 0.4108290857819987, 0.939282396167026], 
             UndirectedEdge[45, 398] -> 
             RGBColor[
              0.20371823459922628`, 0.33145115941884645`, 0.934912824135081], 
             UndirectedEdge[233, 275] -> 
             RGBColor[
              0.7259348855245369, 0.7839404012756612, 0.9506021698205669], 
             UndirectedEdge[250, 485] -> 
             RGBColor[
              0.23749323092755345`, 0.3669508220183703, 0.9368362602103498], 
             UndirectedEdge[29, 65] -> 
             RGBColor[
              0.1838043123267574, 0.3105203644948844, 0.9337787557216719], 
             UndirectedEdge[166, 453] -> 
             RGBColor[
              0.2178060906512075, 0.3462583893511425, 0.935715106696126], 
             UndirectedEdge[222, 294] -> 
             RGBColor[
              0.19229714625130181`, 0.3194468714263523, 0.9342624100496528], 
             UndirectedEdge[150, 220] -> 
             RGBColor[
              0.21619691693173887`, 0.3445670457444743, 0.9356234666333614], 
             UndirectedEdge[311, 423] -> 
             RGBColor[
              0.184592254538111, 0.31134854171743864`, 0.9338236278649524], 
             UndirectedEdge[210, 424] -> 
             RGBColor[
              0.19449774707264864`, 0.3217598424157385, 0.9343877310109313], 
             UndirectedEdge[179, 312] -> 
             RGBColor[
              0.19754047021008475`, 0.3249579373529733, 0.9345610095923028], 
             UndirectedEdge[310, 323] -> 
             RGBColor[
              0.8187613818125008, 0.8568526336781708, 0.8678541495778869], 
             UndirectedEdge[108, 349] -> 
             RGBColor[
              0.19740440059431363`, 0.32481491955948594`, 0.9345532606289816],
              UndirectedEdge[355, 395] -> 
             RGBColor[
              0.5319254348002241, 0.6308800567954042, 0.9562942652159951], 
             UndirectedEdge[47, 200] -> 
             RGBColor[
              0.2722924613184966, 0.40352701955789383`, 0.9388180249002662], 
             UndirectedEdge[152, 217] -> 
             RGBColor[
              0.18273892560736155`, 0.30940057550337985`, 0.9337180835241007],
              UndirectedEdge[174, 210] -> 
             RGBColor[
              0.19150041146467078`, 0.3186094526497, 0.9342170371822176], 
             UndirectedEdge[135, 211] -> 
             RGBColor[
              0.18373947818140363`, 0.31045221969739534`, 0.9337750635130075],
              UndirectedEdge[52, 491] -> 
             RGBColor[
              0.18081085908512495`, 0.30737405534203105`, 0.9336082829879782],
              UndirectedEdge[41, 250] -> 
             RGBColor[
              0.2413646105317827, 0.37101988744205927`, 0.9370567295516178], 
             UndirectedEdge[220, 392] -> 
             RGBColor[
              0.22694196327999852`, 0.35586077073178224`, 0.9362353811270232],
              UndirectedEdge[182, 359] -> 
             RGBColor[
              0.6272616214525479, 0.7019681789194203, 0.9672182481235007], 
             UndirectedEdge[89, 391] -> 
             RGBColor[
              0.39139811242183375`, 0.5128935778827375, 0.9463090400169774], 
             UndirectedEdge[62, 190] -> 
             RGBColor[
              0.233868572190446, 0.3631410758690329, 0.9366298412574736], 
             UndirectedEdge[21, 87] -> 
             RGBColor[
              0.30420754500978997`, 0.43707179605062296`, 0.94063554170235], 
             UndirectedEdge[185, 286] -> 
             RGBColor[
              0.1994684028845588, 0.32698431683183726`, 0.9346708025059933], 
             UndirectedEdge[114, 294] -> 
             RGBColor[
              0.18446317038438925`, 0.311212866087469, 0.9338162767133609], 
             UndirectedEdge[48, 156] -> 
             RGBColor[
              0.19463895940372045`, 0.3219082655290739, 0.9343957728442809], 
             UndirectedEdge[68, 450] -> 
             RGBColor[
              0.20047702738706202`, 0.3280444451344552, 0.9347282421792846], 
             UndirectedEdge[149, 406] -> 
             RGBColor[
              0.48881588257467606`, 0.5948821437018659, 0.9531767259019711], 
             UndirectedEdge[123, 158] -> 
             RGBColor[
              0.1887768797193095, 0.31574684810343895`, 0.9340619360784235], 
             UndirectedEdge[55, 91] -> 
             RGBColor[
              0.5169586982013866, 0.6187293857806677, 0.955116028885972], 
             UndirectedEdge[135, 169] -> 
             RGBColor[
              0.1819041358977289, 0.3085231585898313, 0.9336705434850978], 
             UndirectedEdge[141, 456] -> 
             RGBColor[
              0.20146025215418084`, 0.3290778767047479, 0.9347842353752214], 
             UndirectedEdge[287, 354] -> 
             RGBColor[
              0.3073707866753843, 0.44022628267657893`, 0.9408219184544402], 
             UndirectedEdge[223, 411] -> 
             RGBColor[
              0.24469698646716248`, 0.3745224258349809, 0.9372465034313293], 
             UndirectedEdge[127, 301] -> 
             RGBColor[
              0.7442995113076243, 0.8002700424356418, 0.9751223810067287], 
             UndirectedEdge[167, 201] -> 
             RGBColor[
              0.2486574185518422, 0.37868509106187664`, 0.9374720441796176], 
             UndirectedEdge[28, 218] -> 
             RGBColor[
              0.38085905105137724`, 0.5015767053192113, 0.9457353767574448], 
             UndirectedEdge[112, 317] -> 
             RGBColor[
              0.9053802389728423, 0.5628414484156407, 0.4612866067791993], 
             UndirectedEdge[275, 372] -> 
             RGBColor[
              0.55179178264052, 0.6470084529409276, 0.9578582168908132], 
             UndirectedEdge[85, 146] -> 
             RGBColor[
              0.1836713842833611, 0.3103806486931501, 0.9337711856662498], 
             UndirectedEdge[7, 262] -> 
             RGBColor[
              0.407760697816997, 0.5270866817975668, 0.9473459424920676], 
             UndirectedEdge[448, 455] -> 
             RGBColor[
              0.45681433053997933`, 0.564999766000337, 0.9515547264505798], 
             UndirectedEdge[9, 368] -> 
             RGBColor[
              0.18651190777224702`, 0.3133662189795604, 0.933932949276764], 
             UndirectedEdge[216, 399] -> 
             RGBColor[
              0.20389703761891642`, 0.33163909272930703`, 0.934923006702537], 
             UndirectedEdge[205, 474] -> 
             RGBColor[
              0.23349741976768085`, 0.3627509711402839, 0.936608704676068], 
             UndirectedEdge[125, 242] -> 
             RGBColor[
              0.8755313279725643, 0.9029638772422787, 0.9544497242112633], 
             UndirectedEdge[280, 338] -> 
             RGBColor[
              0.33890305736331594`, 0.4628522319448411, 0.9430026939765475], 
             UndirectedEdge[232, 393] -> 
             RGBColor[
              0.24988773384149937`, 0.3799782304378011, 0.9375421088152751], 
             UndirectedEdge[403, 483] -> 
             RGBColor[
              0.5977248399072642, 0.6827163434594106, 0.9625421629597528], 
             UndirectedEdge[427, 433] -> 
             RGBColor[
              0.18359379097292866`, 0.3102990932041856, 0.9337667668420098], 
             UndirectedEdge[269, 310] -> 
             RGBColor[
              0.6233432481970155, 0.705059569312919, 0.963516708609254], 
             UndirectedEdge[212, 357] -> 
             RGBColor[
              0.18524504165765288`, 0.3120346623691711, 0.9338608031256983], 
             UndirectedEdge[88, 307] -> 
             RGBColor[
              0.1906659921562372, 0.31773242505129645`, 0.9341695182370151], 
             UndirectedEdge[212, 217] -> 
             RGBColor[
              0.18159408433829743`, 0.30819727474246456`, 0.9336528865074684],
              UndirectedEdge[67, 124] -> 
             RGBColor[
              0.18312075215718818`, 0.30980189941644914`, 0.9337398279812515],
              UndirectedEdge[364, 380] -> 
             RGBColor[
              0.19593044529067147`, 0.3232656990811941, 0.9344693210549606], 
             UndirectedEdge[82, 384] -> 
             RGBColor[
              0.39409857332891574`, 0.5101959076651558, 0.9469714569601196], 
             UndirectedEdge[222, 439] -> 
             RGBColor[
              0.19816628717948753`, 0.32561571066690326`, 0.9345966489428971],
              UndirectedEdge[337, 420] -> 
             RGBColor[
              0.18856527989536503`, 0.3155244432722696, 0.9340498857814837], 
             UndirectedEdge[61, 99] -> 
             RGBColor[
              0.9849784772768306, 0.9873095986531333, 0.8651734232542627], 
             UndirectedEdge[63, 439] -> 
             RGBColor[
              0.20302072388459882`, 0.33071803143303935`, 0.9348731019317575],
              UndirectedEdge[37, 53] -> 
             RGBColor[
              0.8472647112443593, 0.3588769520067575, 0.19268158199931773`], 
             UndirectedEdge[39, 62] -> 
             RGBColor[
              0.2493920758689453, 0.37945726248211625`, 0.9375138818269986], 
             UndirectedEdge[130, 182] -> 
             RGBColor[
              0.323958117743938, 0.4544792345302443, 0.9418830285018508], 
             UndirectedEdge[152, 398] -> 
             RGBColor[
              0.19524728601816377`, 0.32254765537098895`, 0.934430416145035], 
             UndirectedEdge[23, 110] -> 
             RGBColor[
              0.42451306437954106`, 0.5421136125437187, 0.9482705749734688], 
             UndirectedEdge[322, 440] -> 
             RGBColor[
              0.8562073757382771, 0.38077868388003167`, 0.19941112665599764`],
              UndirectedEdge[141, 432] -> 
             RGBColor[
              0.24927102921021138`, 0.3793300347689854, 0.937506988398856], 
             UndirectedEdge[161, 459] -> 
             RGBColor[
              0.20416528068413636`, 0.3319210331984458, 0.9349382827482713], 
             UndirectedEdge[185, 333] -> 
             RGBColor[
              0.22166458508016862`, 0.3503139116386572, 0.9359348422457243], 
             UndirectedEdge[297, 474] -> 
             RGBColor[
              0.21238801987541464`, 0.34056365344025585`, 0.935406555580762], 
             UndirectedEdge[265, 329] -> 
             RGBColor[
              0.18295078871918613`, 0.3096232570668046, 0.9337301488148957], 
             UndirectedEdge[90, 280] -> 
             RGBColor[
              0.25791236607974777`, 0.3884126277112705, 0.937999099749864], 
             UndirectedEdge[183, 430] -> 
             RGBColor[
              0.19926050368686765`, 0.32676580159349333`, 0.9346589629542441],
              UndirectedEdge[86, 194] -> 
             RGBColor[
              0.18570943860608155`, 0.31252277300643677`, 0.9338872498448976],
              UndirectedEdge[143, 186] -> 
             RGBColor[
              0.7869875185761387, 0.829282852672385, 0.7373913878754195], 
             UndirectedEdge[1, 416] -> 
             RGBColor[
              0.20425325698717794`, 0.33201350187096224`, 0.9349432928685801],
              UndirectedEdge[27, 86] -> 
             RGBColor[
              0.18526169591288671`, 0.3120521670473626, 0.9338617515608961], 
             UndirectedEdge[66, 415] -> 
             RGBColor[
              0.1891407128871262, 0.3161292598311696, 0.9340826558390877], 
             UndirectedEdge[413, 490] -> 
             RGBColor[
              0.2231389506309891, 0.3518635633127446, 0.9360188051827152], 
             UndirectedEdge[226, 284] -> 
             RGBColor[
              0.19690493413279425`, 0.3242899486404264, 0.9345248167528926], 
             UndirectedEdge[245, 438] -> 
             RGBColor[
              0.22328352119424416`, 0.3520155161410289, 0.9360270382624196], 
             UndirectedEdge[53, 163] -> 
             RGBColor[
              0.8659915986516313, 0.4439113739475036, 0.20830775588996076`], 
             UndirectedEdge[367, 368] -> 
             RGBColor[
              0.1881907444562831, 0.3151307827788761, 0.9340285565423035], 
             UndirectedEdge[112, 175] -> 
             RGBColor[
              0.6955594457176699, 0.7552129086866064, 0.8524579222934991], 
             UndirectedEdge[277, 288] -> 
             RGBColor[
              0.5772249873338873, 0.6663273536018384, 0.9606573715704986], 
             UndirectedEdge[249, 323] -> 
             RGBColor[
              0.8598299314382067, 0.8889356967783099, 0.8719474787971606], 
             UndirectedEdge[416, 452] -> 
             RGBColor[
              0.2180186471312624, 0.3464817996885393, 0.935727211473216], 
             UndirectedEdge[13, 87] -> 
             RGBColor[
              0.28067879095443904`, 0.41234158372927926`, 0.9392956139665702],
              UndirectedEdge[471, 497] -> 
             RGBColor[
              0.7175094368939575, 0.7772891603319885, 0.9550059228659136], 
             UndirectedEdge[17, 321] -> 
             RGBColor[
              0.6804393139131792, 0.743928538014085, 0.9180923196352385], 
             UndirectedEdge[106, 227] -> 
             RGBColor[
              0.18640315120824044`, 0.31325190893522514`, 0.9339267557513348],
              UndirectedEdge[37, 100] -> 
             RGBColor[
              0.9275408237580072, 0.7267589387889348, 0.3553036056592853], 
             UndirectedEdge[9, 375] -> 
             RGBColor[
              0.19826733232951002`, 0.32572191552620944`, 0.934602403314708], 
             UndirectedEdge[10, 302] -> 
             RGBColor[
              0.23577384795439005`, 0.3651436414983986, 0.9367383438936274], 
             UndirectedEdge[14, 272] -> 
             RGBColor[
              0.24410352476956199`, 0.37389865996315785`, 0.9372127066655989],
              UndirectedEdge[63, 387] -> 
             RGBColor[
              0.1978509608116646, 0.3252842826614749, 0.9345786915727331], 
             UndirectedEdge[471, 483] -> 
             RGBColor[
              0.7044387287985243, 0.7666430914560537, 0.9539865308155939], 
             UndirectedEdge[46, 392] -> 
             RGBColor[
              0.22028047155655125`, 0.34885912056746937`, 0.9358560190281668],
              UndirectedEdge[122, 357] -> 
             RGBColor[
              0.18711144917701383`, 0.313996375009091, 0.9339670922728234], 
             UndirectedEdge[75, 125] -> 
             RGBColor[
              0.8216340480291034, 0.6538916931792487, 0.593916539379413], 
             UndirectedEdge[244, 261] -> 
             RGBColor[
              0.388007213318593, 0.5104940791921502, 0.9459444544247217], 
             UndirectedEdge[7, 178] -> 
             RGBColor[
              0.47083170751539166`, 0.5812814167445273, 0.9514847432104361], 
             UndirectedEdge[108, 487] -> 
             RGBColor[
              0.20117686323780593`, 0.3287800169857428, 0.9347680967956702], 
             UndirectedEdge[338, 480] -> 
             RGBColor[
              0.3338467491074454, 0.4575377313794614, 0.9427147447015134], 
             UndirectedEdge[237, 284] -> 
             RGBColor[
              0.21986017242091369`, 0.34841735952740993`, 0.9358320836141691],
              UndirectedEdge[162, 456] -> 
             RGBColor[
              0.18946877260235598`, 0.3164740713920633, 0.9341013383545491], 
             UndirectedEdge[104, 310] -> 
             RGBColor[
              0.7844721843600413, 0.7296832002097726, 0.6115226819006405], 
             UndirectedEdge[168, 390] -> 
             RGBColor[
              0.27431313717116323`, 0.40565087799729527`, 0.9389330994007534],
              UndirectedEdge[164, 431] -> 
             RGBColor[
              0.36863866395623385`, 0.49371801522607117`, 0.9447103075862879],
              UndirectedEdge[57, 60] -> 
             RGBColor[
              0.9740668501566808, 0.9799635557919238, 0.9191037618424754], 
             UndirectedEdge[158, 247] -> 
             RGBColor[
              0.18799329436094186`, 0.3149232502096133, 0.9340173120514751], 
             UndirectedEdge[32, 475] -> 
             RGBColor[
              0.27810050553156784`, 0.4070629513265539, 0.9392428367847124], 
             UndirectedEdge[53, 293] -> 
             RGBColor[
              0.8212117750972121, 0.5517293002984074, 0.5802972295340347], 
             UndirectedEdge[72, 294] -> 
             RGBColor[
              0.19930405825751749`, 0.32681158020876566`, 0.9346614433226095],
              UndirectedEdge[87, 287] -> 
             RGBColor[
              0.3062830568763104, 0.4392532906173888, 0.9407537390327037], 
             UndirectedEdge[154, 374] -> 
             RGBColor[
              0.9154556938707563, 0.6764368032115899, 0.5529680520443171], 
             UndirectedEdge[119, 364] -> 
             RGBColor[
              0.19435544195191212`, 0.32161027071117865`, 0.934379626944827], 
             UndirectedEdge[90, 342] -> 
             RGBColor[
              0.36933196448262395`, 0.489404611907154, 0.9450840596145658], 
             UndirectedEdge[401, 428] -> 
             RGBColor[
              0.18425068425914937`, 0.3109895296974434, 0.9338041759428735], 
             UndirectedEdge[183, 477] -> 
             RGBColor[
              0.19737928626943302`, 0.32478852281169623`, 0.934551830405333], 
             UndirectedEdge[82, 269] -> 
             RGBColor[
              0.5609980001725171, 0.6544824750687763, 0.958582964058418], 
             UndirectedEdge[202, 273] -> 
             RGBColor[
              0.18695948203332297`, 0.31383664790579846`, 0.9339584379688055],
              UndirectedEdge[147, 242] -> 
             RGBColor[
              0.8960966123696098, 0.5635667746530044, 0.5481508384278233], 
             UndirectedEdge[117, 198] -> 
             RGBColor[
              0.18298777738438862`, 0.30966213449914926`, 0.9337322552646592],
              UndirectedEdge[240, 434] -> 
             RGBColor[
              0.9649429424873008, 0.8858096572696792, 0.4713319778660402], 
             UndirectedEdge[249, 310] -> 
             RGBColor[
              0.685881195378659, 0.7545348698107444, 0.9693258856973048], 
             UndirectedEdge[448, 478] -> 
             RGBColor[
              0.2749488841783959, 0.4063190884105853, 0.938969304252312], 
             UndirectedEdge[121, 196] -> 
             RGBColor[
              0.19856429776732792`, 0.3260340450300523, 0.9346193150570707], 
             UndirectedEdge[200, 256] -> 
             RGBColor[
              0.28726648438606334`, 0.4190057220590618, 0.9396802912272235], 
             UndirectedEdge[79, 184] -> 
             RGBColor[
              0.7135412330833855, 0.7751234699043363, 0.9730039594525782], 
             UndirectedEdge[51, 240] -> 
             RGBColor[
              0.995029239647029, 0.991776371162987, 0.7003415954352006], 
             UndirectedEdge[339, 387] -> 
             RGBColor[
              0.1845385025539545, 0.3112920449740175, 0.9338205667689736], 
             UndirectedEdge[46, 142] -> 
             RGBColor[
              0.2097115161750654, 0.33775047835105276`, 0.9352541326545596], 
             UndirectedEdge[233, 259] -> 
             RGBColor[
              0.8229153142047934, 0.8620467284314131, 0.9586653393897153], 
             UndirectedEdge[266, 471] -> 
             RGBColor[
              0.975210019564589, 0.978006622458981, 0.7504581704123827], 
             UndirectedEdge[167, 456] -> 
             RGBColor[
              0.21773731167177224`, 0.3461860982829168, 0.9357111898349966], 
             UndirectedEdge[10, 181] -> 
             RGBColor[
              0.22615215264020183`, 0.355030629672469, 0.9361904025795069], 
             UndirectedEdge[31, 429] -> 
             RGBColor[
              0.19196505677432735`, 0.31909782433036316`, 0.9342434980452214],
              UndirectedEdge[317, 322] -> 
             RGBColor[
              0.8190506229224375, 0.1474370125838577, 0.16587620406611453`], 
             UndirectedEdge[52, 466] -> 
             RGBColor[
              0.18744056730247904`, 0.3143422990262493, 0.933985835063182], 
             UndirectedEdge[207, 281] -> 
             RGBColor[
              0.8467054680453859, 0.3339234893640672, 0.19133725700073073`], 
             UndirectedEdge[358, 398] -> 
             RGBColor[
              0.21557110150214517`, 0.3439092740489813, 0.935587827370457], 
             UndirectedEdge[155, 250] -> 
             RGBColor[
              0.2067822292135854, 0.3346716120270169, 0.9350873140955949], 
             UndirectedEdge[243, 285] -> 
             RGBColor[
              0.20548353415746184`, 0.3333066011810086, 0.9350133553333959], 
             UndirectedEdge[378, 452] -> 
             RGBColor[
              0.21688623716897232`, 0.34529156501923397`, 0.935662722401114], 
             UndirectedEdge[100, 264] -> 
             RGBColor[
              0.92938539319056, 0.7351346977720205, 0.3568427596083415], 
             UndirectedEdge[81, 130] -> 
             RGBColor[
              0.27063800741742255`, 0.4017880836094291, 0.9387238061981451], 
             UndirectedEdge[1, 120] -> 
             RGBColor[
              0.18959062955787265`, 0.3166021507784885, 0.9341082779278946], 
             UndirectedEdge[390, 422] -> 
             RGBColor[
              0.23122695863113757`, 0.36036457253022636`, 0.9364794052731881],
              UndirectedEdge[118, 255] -> 
             RGBColor[
              0.19469073239539242`, 0.3219626822259184, 0.9343987212395655], 
             UndirectedEdge[137, 229] -> 
             RGBColor[
              0.2232482662355424, 0.35197846094413987`, 0.9360250305446766], 
             UndirectedEdge[367, 375] -> 
             RGBColor[
              0.19994616901354612`, 0.3274864793255251, 0.9346980105802476], 
             UndirectedEdge[230, 382] -> 
             RGBColor[
              0.20898405610198123`, 0.3369858716906088, 0.9352127048795782], 
             UndirectedEdge[114, 334] -> 
             RGBColor[
              0.18414474445457316`, 0.31087818024586233`, 0.9337981428277268],
              UndirectedEdge[52, 170] -> 
             RGBColor[
              0.1838649636445791, 0.31058411287543064`, 0.9337822097244962], 
             UndirectedEdge[4, 389] -> 
             RGBColor[
              0.18821672881431478`, 0.31515809398667083`, 0.934030036313053], 
             UndirectedEdge[190, 378] -> 
             RGBColor[
              0.21175405970731373`, 0.3398973211081856, 0.9353704524870488], 
             UndirectedEdge[89, 328] -> 
             RGBColor[
              0.27633399177258894`, 0.4076884315850981, 0.9390513510031808], 
             UndirectedEdge[93, 300] -> 
             RGBColor[
              0.2272468293636924, 0.3561812043153706, 0.9362527427994807], 
             UndirectedEdge[104, 125] -> 
             RGBColor[
              0.8510407401896769, 0.7816870619636468, 0.6181576134272155], 
             UndirectedEdge[59, 228] -> 
             RGBColor[
              0.26060629998899837`, 0.391244123055168, 0.9381525153006776], 
             UndirectedEdge[96, 136] -> 
             RGBColor[
              0.4994982670529912, 0.6045542211909409, 0.9537414797863035], 
             UndirectedEdge[332, 420] -> 
             RGBColor[
              0.1873361545684642, 0.31423255462265, 0.9339798889124447], 
             UndirectedEdge[40, 283] -> 
             RGBColor[
              0.18366308451827268`, 0.3103719251138067, 0.9337707130069065], 
             UndirectedEdge[17, 288] -> 
             RGBColor[
              0.543333437646262, 0.6369721967012344, 0.9584978319935238], 
             UndirectedEdge[325, 413] -> 
             RGBColor[
              0.23197275674874823`, 0.36114845363816694`, 0.9365218773726766],
              UndirectedEdge[421, 459] -> 
             RGBColor[
              0.18940834947071425`, 0.31641056284966007`, 0.9340978973465902],
              UndirectedEdge[148, 342] -> 
             RGBColor[
              0.3754741855106375, 0.4958604756469023, 0.9454338500155093], 
             UndirectedEdge[262, 478] -> 
             RGBColor[
              0.29624054132013333`, 0.4255154795391891, 0.9402983591952379], 
             UndirectedEdge[133, 405] -> 
             RGBColor[
              0.18981989868512106`, 0.3168431271677289, 0.9341213344655181], 
             UndirectedEdge[374, 397] -> 
             RGBColor[
              0.8347270315445021, 0.26793275869910615`, 0.18088795066657473`],
              UndirectedEdge[151, 389] -> 
             RGBColor[
              0.1993172981785255, 0.3268254962052045, 0.9346621973165241], 
             UndirectedEdge[235, 305] -> 
             RGBColor[
              0.2638362786788805, 0.394471813217312, 0.9383425806338642], 
             UndirectedEdge[204, 348] -> 
             RGBColor[
              0.38899180466367445`, 0.5111089618702334, 0.9460729299565488], 
             UndirectedEdge[191, 429] -> 
             RGBColor[
              0.1912728666243942, 0.31837028859539307`, 0.9342040788401863], 
             UndirectedEdge[15, 414] -> 
             RGBColor[0.53753656294092, 0.634449250565901, 0.957071181763386],
              UndirectedEdge[277, 414] -> 
             RGBColor[
              0.43294658493558325`, 0.5494183041682945, 0.9488079514458304], 
             UndirectedEdge[317, 440] -> 
             RGBColor[
              0.8544757528158395, 0.36746867129617394`, 0.19775292258988314`],
              UndirectedEdge[76, 182] -> 
             RGBColor[
              0.3777126376207911, 0.5015774351431334, 0.9452884931643937], 
             UndirectedEdge[199, 376] -> 
             RGBColor[
              0.3786216036789717, 0.5023647358567669, 0.9453464116778538], 
             UndirectedEdge[375, 402] -> 
             RGBColor[
              0.21043597475918854`, 0.33851193025629345`, 0.9352953894991849],
              UndirectedEdge[45, 195] -> 
             RGBColor[
              0.19463609510811763`, 0.32190525497278855`, 0.9343956097268837],
              UndirectedEdge[149, 269] -> 
             RGBColor[
              0.5815017308774398, 0.6711283273375747, 0.9601970928471498], 
             UndirectedEdge[45, 152] -> 
             RGBColor[
              0.1927063751242849, 0.3198769969184667, 0.9342857150285693], 
             UndirectedEdge[356, 494] -> 
             RGBColor[
              0.30030937836549265`, 0.4286701061729542, 0.9405711545959381], 
             UndirectedEdge[44, 360] -> 
             RGBColor[
              0.4375870349530485, 0.5468097854709225, 0.9502759669846275], 
             UndirectedEdge[284, 432] -> 
             RGBColor[
              0.249031609154708, 0.37907838911054315`, 0.9374933537808854], 
             UndirectedEdge[151, 237] -> 
             RGBColor[
              0.2183016735730191, 0.3467792784237385, 0.9357433294103739], 
             UndirectedEdge[207, 343] -> 
             RGBColor[
              0.8606088112970214, 0.4407906780799979, 0.2046511142000771], 
             UndirectedEdge[33, 371] -> 
             RGBColor[
              0.2551767869971113, 0.385537360649688, 0.9378433125680343], 
             UndirectedEdge[280, 480] -> 
             RGBColor[
              0.24841746075918128`, 0.37843288020758725`, 0.9374583789383113],
              UndirectedEdge[420, 454] -> 
             RGBColor[
              0.19971846915340663`, 0.3272471523355135, 0.9346850434100643], 
             UndirectedEdge[267, 393] -> 
             RGBColor[
              0.22528640281656057`, 0.35412067171611283`, 0.9361410994078128],
              UndirectedEdge[337, 427] -> 
             RGBColor[
              0.18780005171862202`, 0.314720139940244, 0.9340063071688718], 
             UndirectedEdge[267, 480] -> 
             RGBColor[
              0.23630904981420553`, 0.3657061725868226, 0.9367688228477836], 
             UndirectedEdge[234, 336] -> 
             RGBColor[
              0.7758644491107505, 0.7262741691289183, 0.6116347463560659], 
             UndirectedEdge[122, 492] -> 
             RGBColor[
              0.1841436405662557, 0.3108770199892501, 0.9337980799629202], 
             UndirectedEdge[80, 272] -> 
             RGBColor[
              0.30232143214337615`, 0.4315140636582957, 0.9406590399115311], 
             UndirectedEdge[331, 444] -> 
             RGBColor[
              0.43364941819134256`, 0.5462951958354212, 0.9497218378452923], 
             UndirectedEdge[77, 184] -> 
             RGBColor[
              0.4376517235629901, 0.5511173532058586, 0.9497643390234523], 
             UndirectedEdge[266, 359] -> 
             RGBColor[
              0.9515547370167402, 0.9596896244773535, 0.7671002510689349], 
             UndirectedEdge[32, 478] -> 
             RGBColor[
              0.23449306505329615`, 0.3637974574630227, 0.9366654052021586], 
             UndirectedEdge[14, 447] -> 
             RGBColor[
              0.2323548964610662, 0.3615501067048703, 0.936543639663968], 
             UndirectedEdge[16, 358] -> 
             RGBColor[
              0.24749987708524912`, 0.37746844158811943`, 0.9374061239055242],
              UndirectedEdge[50, 323] -> 
             RGBColor[
              0.9365367216162789, 0.9493476478675402, 0.8794633883159441], 
             UndirectedEdge[92, 365] -> 
             RGBColor[
              0.23949140661491064`, 0.36905103135743866`, 0.9369500533597088],
              UndirectedEdge[296, 438] -> 
             RGBColor[
              0.1924355382075839, 0.3195923301469616, 0.9342702912668306], 
             UndirectedEdge[181, 422] -> 
             RGBColor[
              0.2160287950041301, 0.3443903389390116, 0.9356138923382982], 
             UndirectedEdge[35, 428] -> 
             RGBColor[
              0.18771159390474457`, 0.31462716516930944`, 0.9340012696272331],
              UndirectedEdge[19, 298] -> 
             RGBColor[
              0.2394531191654226, 0.3690107888204622, 0.9369478729461016], 
             UndirectedEdge[209, 348] -> 
             RGBColor[
              0.7282782743451366, 0.7830802438848616, 0.8460022789081878], 
             UndirectedEdge[27, 194] -> 
             RGBColor[
              0.1856592913664621, 0.31247006507807806`, 0.9338843940337875], 
             UndirectedEdge[253, 287] -> 
             RGBColor[
              0.340823165506129, 0.46920105185432204`, 0.9429534744527581], 
             UndirectedEdge[412, 476] -> 
             RGBColor[
              0.18684284442084606`, 0.31371405437983346`, 0.9339517956293248],
              UndirectedEdge[221, 336] -> 
             RGBColor[
              0.7938129054109903, 0.7955671950703103, 0.6357978963718616], 
             UndirectedEdge[146, 248] -> 
             RGBColor[
              0.18017302617267333`, 0.306703652510102, 0.9335719593472032], 
             UndirectedEdge[17, 455] -> 
             RGBColor[
              0.49424404189338955`, 0.5981741285649027, 0.9539120839375526], 
             UndirectedEdge[102, 393] -> 
             RGBColor[
              0.2103791435745319, 0.3384521970779141, 0.9352921530472929], 
             UndirectedEdge[80, 497] -> 
             RGBColor[
              0.4127991170058606, 0.5312924585653119, 0.9477107106935068], 
             UndirectedEdge[108, 416] -> 
             RGBColor[
              0.20942130064370462`, 0.3374454434268651, 0.9352376053093838], 
             UndirectedEdge[8, 453] -> 
             RGBColor[
              0.21870849923514318`, 0.34720687798886773`, 0.9357664975299873],
              UndirectedEdge[58, 402] -> 
             RGBColor[
              0.20564836608822273`, 0.3334798499911863, 0.9350227422680057], 
             UndirectedEdge[95, 357] -> 
             RGBColor[
              0.18661251030183867`, 0.3134719586167301, 0.9339386784419961], 
             UndirectedEdge[183, 283] -> 
             RGBColor[
              0.18964111329673894`, 0.31665521238889094`, 0.9341111529021391],
              UndirectedEdge[179, 294] -> 
             RGBColor[
              0.19380204212800067`, 0.3210286124086723, 0.9343481116435368], 
             UndirectedEdge[136, 240] -> 
             RGBColor[
              0.7615140918759296, 0.8095862292350475, 0.8160223615071904], 
             UndirectedEdge[153, 289] -> 
             RGBColor[
              0.21885506273912853`, 0.34736092552421916`, 0.935774844104718], 
             UndirectedEdge[73, 200] -> 
             RGBColor[
              0.4199369122581749, 0.5305626812641765, 0.9490610674516942], 
             UndirectedEdge[196, 447] -> 
             RGBColor[
              0.2128628663159131, 0.341062747156223, 0.9354335973830761], 
             UndirectedEdge[68, 492] -> 
             RGBColor[
              0.1840181186755369, 0.3107450885235571, 0.9337909316769367], 
             UndirectedEdge[25, 413] -> 
             RGBColor[
              0.25960242052995686`, 0.39018898209408137`, 0.9380953458505918],
              UndirectedEdge[220, 426] -> 
             RGBColor[
              0.20219514191155313`, 0.32985029243444797`, 0.9348260862597317],
              UndirectedEdge[21, 354] -> 
             RGBColor[
              0.30529527480886387`, 0.43804478810981307`, 0.9407037211240865],
              UndirectedEdge[125, 269] -> 
             RGBColor[
              0.6899118040266511, 0.7570634310667932, 0.970151640135829], 
             UndirectedEdge[241, 304] -> 
             RGBColor[
              0.20316948858682138`, 0.3308743925673022, 0.9348815738614715], 
             UndirectedEdge[93, 456] -> 
             RGBColor[
              0.20912093230204676`, 0.3371297372553299, 0.9352204997766816], 
             UndirectedEdge[295, 455] -> 
             RGBColor[
              0.7989202594631184, 0.8423584945526768, 0.9321574576076621], 
             UndirectedEdge[185, 386] -> 
             RGBColor[
              0.25857169569949595`, 0.38910562494553824`, 0.9380366475963178],
              UndirectedEdge[233, 400] -> 
             RGBColor[
              0.9762128798080161, 0.9808371360064839, 0.8829178984103572], 
             UndirectedEdge[83, 317] -> 
             RGBColor[
              0.9062729324823862, 0.5632106001230137, 0.44649236510931034`], 
             UndirectedEdge[88, 465] -> 
             RGBColor[
              0.18430414736705614`, 0.3110457228136103, 0.9338072205877772], 
             UndirectedEdge[418, 431] -> 
             RGBColor[
              0.4488786406898552, 0.5625882607859993, 0.9499970853520581], 
             UndirectedEdge[121, 307] -> 
             RGBColor[
              0.1984527242001829, 0.32591677413681014`, 0.93461296110748], 
             UndirectedEdge[64, 74] -> 
             RGBColor[
              0.1867563887094054, 0.3136231839455006, 0.933946872104458], 
             UndirectedEdge[185, 358] -> 
             RGBColor[
              0.21821199843557637`, 0.3466850241685541, 0.935738222543959], 
             UndirectedEdge[113, 315] -> 
             RGBColor[
              0.19006335492631857`, 0.31709901511324473`, 0.9341351989382931],
              UndirectedEdge[47, 91] -> 
             RGBColor[
              0.37096684027433213`, 0.4930353735304999, 0.9450030845101454], 
             UndirectedEdge[158, 401] -> 
             RGBColor[
              0.1862173046895177, 0.3130565724606977, 0.9339161720670288], 
             UndirectedEdge[90, 232] -> 
             RGBColor[
              0.2704052861597108, 0.40154347881219404`, 0.9387105530667987], 
             UndirectedEdge[58, 115] -> 
             RGBColor[
              0.19207706439220854`, 0.3192155514384495, 0.9342498767133594], 
             UndirectedEdge[132, 494] -> 
             RGBColor[
              0.3138085366833637, 0.4428585774611083, 0.9413399116919258], 
             UndirectedEdge[167, 300] -> 
             RGBColor[
              0.23586320873341787`, 0.3652375653429575, 0.9367434328577955], 
             UndirectedEdge[284, 389] -> 
             RGBColor[
              0.20087579702642006`, 0.328463577308876, 0.9347509515203193], 
             UndirectedEdge[103, 233] -> 
             RGBColor[
              0.6861807488432135, 0.7504846976904338, 0.9477990317770553], 
             UndirectedEdge[172, 300] -> 
             RGBColor[
              0.22767768818641226`, 0.35663406425607636`, 0.936277279572036], 
             UndirectedEdge[70, 76] -> 
             RGBColor[
              0.3900856381049142, 0.5122943062773944, 0.9460768898142273], 
             UndirectedEdge[57, 73] -> 
             RGBColor[
              0.769769601175684, 0.81952464354351, 0.9539791162715971], 
             UndirectedEdge[287, 473] -> 
             RGBColor[
              0.28387386210883436`, 0.4156998060917603, 0.9394775685421287], 
             UndirectedEdge[395, 443] -> 
             RGBColor[
              0.39598885232621217`, 0.5140941996505966, 0.9469051099430464], 
             UndirectedEdge[100, 397] -> 
             RGBColor[
              0.9076183259729562, 0.5790517976305654, 0.33643826418820166`], 
             UndirectedEdge[57, 234] -> 
             RGBColor[
              0.9445095586663342, 0.8587398441686642, 0.6038719941743098], 
             UndirectedEdge[343, 403] -> 
             RGBColor[
              0.7948197503279848, 0.5779151298917289, 0.5834817504053871], 
             UndirectedEdge[105, 425] -> 
             RGBColor[
              0.18905198757822078`, 0.3160360039060004, 0.9340776030640029], 
             UndirectedEdge[133, 423] -> 
             RGBColor[
              0.18859024302857952`, 0.3155506811080321, 0.9340513073949906], 
             UndirectedEdge[92, 494] -> 
             RGBColor[
              0.31362082310207806`, 0.44266127858544857`, 0.9413292216811688],
              UndirectedEdge[51, 100] -> 
             RGBColor[
              0.9942396894003585, 0.9900876030211339, 0.6144039236244064], 
             UndirectedEdge[6, 347] -> 
             RGBColor[
              0.20873556607912272`, 0.336724692921407, 0.9351985537403844], 
             UndirectedEdge[333, 461] -> 
             RGBColor[
              0.24252993321129454`, 0.3722447154639515, 0.9371230929542755], 
             UndirectedEdge[291, 394] -> 
             RGBColor[
              0.18326692398746902`, 0.30995553527790365`, 0.9337481522507443],
              UndirectedEdge[143, 386] -> 
             RGBColor[
              0.4431271313499566, 0.5544881277989356, 0.9504225818042138], 
             UndirectedEdge[123, 437] -> 
             RGBColor[
              0.18388303382001714`, 0.3106031057755313, 0.9337832387942551], 
             UndirectedEdge[72, 453] -> 
             RGBColor[
              0.2255232493931461, 0.35436961248504456`, 0.9361545874699662], 
             UndirectedEdge[391, 478] -> 
             RGBColor[
              0.36121422406998477`, 0.4812548901837663, 0.9445869453059381], 
             UndirectedEdge[328, 464] -> 
             RGBColor[
              0.22272025145336094`, 0.35142348392999634`, 0.9359949608839593],
              UndirectedEdge[149, 173] -> 
             RGBColor[
              0.6408634071546884, 0.7181223008643338, 0.9656896889353898], 
             UndirectedEdge[54, 186] -> 
             RGBColor[
              0.9914243588005289, 0.9890319585828893, 0.6689529207083693], 
             UndirectedEdge[355, 444] -> 
             RGBColor[
              0.5627869729236907, 0.655934843740483, 0.9587237985466135], 
             UndirectedEdge[7, 448] -> 
             RGBColor[
              0.38646904067525956`, 0.507890290668963, 0.9460168875491417], 
             UndirectedEdge[47, 416] -> 
             RGBColor[
              0.24541922577751857`, 0.3752815451427822, 0.9372876338915967], 
             UndirectedEdge[48, 155] -> 
             RGBColor[
              0.1919029748142661, 0.3190325722541152, 0.934239962569438], 
             UndirectedEdge[346, 486] -> 
             RGBColor[
              0.4273749578752095, 0.5445924408467173, 0.9484529322963398], 
             UndirectedEdge[24, 491] -> 
             RGBColor[
              0.1834588125121197, 0.3101572222837467, 0.9337590800183494], 
             UndirectedEdge[321, 373] -> 
             RGBColor[
              0.9882173705299822, 0.9893955941614516, 0.8449321929931977], 
             UndirectedEdge[209, 231] -> 
             RGBColor[
              0.8790670260426792, 0.9036392003218177, 0.8591433457844534], 
             UndirectedEdge[210, 393] -> 
             RGBColor[
              0.20841975513223648`, 0.336392755592659, 0.9351805687741597], 
             UndirectedEdge[188, 409] -> 
             RGBColor[
              0.23860514692337326`, 0.3681195162295229, 0.9368995821813795], 
             UndirectedEdge[307, 427] -> 
             RGBColor[
              0.1891435770986254, 0.31613227029905666`, 0.9340828189516954], 
             UndirectedEdge[178, 186] -> 
             RGBColor[
              0.7313163060716499, 0.7840864544016981, 0.7330087460966953], 
             UndirectedEdge[328, 475] -> 
             RGBColor[
              0.28975754389901165`, 0.4193152377496582, 0.9399066878746956], 
             UndirectedEdge[213, 337] -> 
             RGBColor[
              0.19565173016906506`, 0.3229727518168264, 0.9344534486411072], 
             UndirectedEdge[384, 458] -> 
             RGBColor[
              0.25354859204463764`, 0.3838260245211157, 0.9377505892741895], 
             UndirectedEdge[87, 473] -> 
             RGBColor[
              0.28600307999809077`, 0.4179377490935802, 0.9395988243510263], 
             UndirectedEdge[112, 440] -> 
             RGBColor[
              0.9425369917886818, 0.7961831197118145, 0.4948215293690824], 
             UndirectedEdge[237, 429] -> 
             RGBColor[
              0.2124196419707597, 0.3405968902674201, 0.9354083564123112], 
             UndirectedEdge[109, 230] -> 
             RGBColor[
              0.20976714477549485`, 0.3378089475371612, 0.9352573006210588], 
             UndirectedEdge[89, 262] -> 
             RGBColor[
              0.3264244296719824, 0.4571541672381602, 0.9420204539062771], 
             UndirectedEdge[280, 383] -> 
             RGBColor[
              0.2606241170949257, 0.3912628499631674, 0.9381535299585022], 
             UndirectedEdge[196, 489] -> 
             RGBColor[
              0.19180860925659354`, 0.31893338806987936`, 0.9342345885905299],
              UndirectedEdge[279, 459] -> 
             RGBColor[
              0.20123137359851423`, 0.3288373108310037, 0.9347712010800716], 
             UndirectedEdge[191, 423] -> 
             RGBColor[
              0.1848982635137219, 0.3116701765528954, 0.9338410546234137], 
             UndirectedEdge[116, 165] -> 
             RGBColor[
              0.2912027626996634, 0.4234029452918576, 0.9398949385886397], 
             UndirectedEdge[176, 313] -> 
             RGBColor[
              0.3390769551492299, 0.46811314887213096`, 0.9428266616414984], 
             UndirectedEdge[180, 490] -> 
             RGBColor[
              0.23955648296360244`, 0.3691194307259925, 0.9369537593614949], 
             UndirectedEdge[17, 498] -> 
             RGBColor[
              0.5750148993041335, 0.6617219953363903, 0.9616555440114883], 
             UndirectedEdge[108, 364] -> 
             RGBColor[
              0.2070027664491964, 0.33490341064451234`, 0.9350998733649074], 
             UndirectedEdge[29, 254] -> 
             RGBColor[
              0.18842942576301586`, 0.31538165196552115`, 0.9340421490896246],
              UndirectedEdge[7, 261] -> 
             RGBColor[
              0.40082339399554057`, 0.5210779379064496, 0.9469039036269813], 
             UndirectedEdge[122, 224] -> 
             RGBColor[
              0.195806426334931, 0.3231353472954549, 0.9344622583589008], 
             UndirectedEdge[116, 386] -> 
             RGBColor[
              0.2910406970756628, 0.423232604045479, 0.9398857091911075], 
             UndirectedEdge[8, 439] -> 
             RGBColor[
              0.1983584490277003, 0.3258176849531398, 0.9346075922758748], 
             UndirectedEdge[226, 488] -> 
             RGBColor[
              0.18475420080410804`, 0.31151875751098784`, 0.9338328504652229],
              UndirectedEdge[64, 170] -> 
             RGBColor[
              0.18627047911638173`, 0.31311246215478516`, 0.9339192002719742],
              UndirectedEdge[178, 313] -> 
             RGBColor[
              0.4152649069206235, 0.5336691197660451, 0.9478012623099019], 
             UndirectedEdge[81, 251] -> 
             RGBColor[
              0.23864347228983546`, 0.36815979861964326`, 0.9369017647543021],
              UndirectedEdge[186, 288] -> 
             RGBColor[
              0.8522733135527225, 0.8812298873379956, 0.7432521758076465], 
             UndirectedEdge[45, 118] -> 
             RGBColor[
              0.1966941864369604, 0.3240684394499293, 0.9345128149833881], 
             UndirectedEdge[224, 330] -> 
             RGBColor[
              0.1977574976662851, 0.3251860469697754, 0.9345733689848701], 
             UndirectedEdge[35, 410] -> 
             RGBColor[
              0.18494866329979062`, 0.31172314992358463`, 0.9338439248166706],
              UndirectedEdge[163, 379] -> 
             RGBColor[
              0.8633665292005046, 0.42373393983337493`, 0.2057939864189699], 
             UndirectedEdge[181, 443] -> 
             RGBColor[
              0.2566770686688468, 0.387114251810034, 0.9379287513897718], 
             UndirectedEdge[167, 235] -> 
             RGBColor[
              0.22849052163804753`, 0.3574884037503625, 0.9363235692346273], 
             UndirectedEdge[202, 279] -> 
             RGBColor[
              0.19737149140968246`, 0.32478032991987577`, 0.9345513864996016],
              UndirectedEdge[242, 310] -> 
             RGBColor[
              0.8089627721429287, 0.8509600154884045, 0.9478147926846883], 
             UndirectedEdge[299, 482] -> 
             RGBColor[
              0.2862226992731482, 0.4159841982683552, 0.9396913123648138], 
             UndirectedEdge[56, 110] -> 
             RGBColor[
              0.41196166706796206`, 0.5312422230440008, 0.9474708110355399], 
             UndirectedEdge[125, 419] -> 
             RGBColor[
              0.7136180387569662, 0.7762031026656953, 0.9720904350297161], 
             UndirectedEdge[262, 448] -> 
             RGBColor[
              0.3218757091133844, 0.45245966625341066`, 0.9417582440772314], 
             UndirectedEdge[95, 212] -> 
             RGBColor[
              0.18331321264928, 0.31000418759633763`, 0.9337507883215563], 
             UndirectedEdge[32, 260] -> 
             RGBColor[
              0.21471160984099968`, 0.34300589381819857`, 0.9355388805918587],
              UndirectedEdge[421, 430] -> 
             RGBColor[
              0.19294646407159283`, 0.3201293456246058, 0.9342993877389387], 
             UndirectedEdge[129, 346] -> 
             RGBColor[
              0.36539555977117477`, 0.4891180942666259, 0.9445692337379277], 
             UndirectedEdge[16, 17] -> 
             RGBColor[
              0.32278008566889027`, 0.45042607660179157`, 0.9419190112149659],
              UndirectedEdge[153, 466] -> 
             RGBColor[
              0.2112617016772801, 0.3393798216013181, 0.9353424134256167], 
             UndirectedEdge[244, 391] -> 
             RGBColor[
              0.45991819988990085`, 0.5722422337278446, 0.9506750794005083], 
             UndirectedEdge[218, 406] -> 
             RGBColor[
              0.35118939031714774`, 0.4764899015985373, 0.9436758749335621], 
             UndirectedEdge[99, 288] -> 
             RGBColor[
              0.8454606604699532, 0.8793558579429647, 0.9455510322617159], 
             UndirectedEdge[399, 481] -> 
             RGBColor[
              0.20657386895260635`, 0.3344526121819243, 0.9350754482869736], 
             UndirectedEdge[278, 451] -> 
             RGBColor[
              0.194775409510841, 0.3220516832430941, 0.9344035434760216], 
             UndirectedEdge[179, 327] -> 
             RGBColor[
              0.1919456153481889, 0.3190773901588341, 0.9342423908847639], 
             UndirectedEdge[38, 473] -> 
             RGBColor[
              0.39120686649721753`, 0.5073123077036177, 0.9467925996287968], 
             UndirectedEdge[17, 176] -> 
             RGBColor[
              0.3461884783937958, 0.47427279287102275`, 0.943279801614169], 
             UndirectedEdge[186, 373] -> 
             RGBColor[
              0.9921614072017308, 0.9893367470380662, 0.6567381212803327], 
             UndirectedEdge[399, 496] -> 
             RGBColor[
              0.19684711352332962`, 0.3242291755138407, 0.9345215239547214], 
             UndirectedEdge[116, 358] -> 
             RGBColor[
              0.2506809998117433, 0.38081200326849496`, 0.9375872841387487], 
             UndirectedEdge[71, 135] -> 
             RGBColor[
              0.18886726703484777`, 0.31584185090295647`, 0.9340670835023274],
              UndirectedEdge[53, 374] -> 
             RGBColor[
              0.8400594801870103, 0.30892029565931944`, 0.18599430950878], 
             UndirectedEdge[228, 409] -> 
             RGBColor[
              0.2557251463437433, 0.3861137210909889, 0.9378745408216], 
             UndirectedEdge[440, 471] -> 
             RGBColor[
              0.9242345860512566, 0.784069889818272, 0.5946181447155001], 
             UndirectedEdge[403, 471] -> 
             RGBColor[
              0.8501227775795742, 0.8834026890475528, 0.9665040763953929], 
             UndirectedEdge[63, 166] -> 
             RGBColor[
              0.20124645730453306`, 0.3288531647623917, 0.9347720600748151], 
             UndirectedEdge[159, 272] -> 
             RGBColor[
              0.24467152920527638`, 0.37449566863865497`, 0.9372450536779255],
              UndirectedEdge[130, 351] -> 
             RGBColor[
              0.2715547401921379, 0.40275162787986996`, 0.9387760127734806], 
             UndirectedEdge[113, 378] -> 
             RGBColor[
              0.20184046362642588`, 0.32947750306887713`, 0.9348058878560932],
              UndirectedEdge[145, 417] -> 
             RGBColor[
              0.20308781549592325`, 0.3307885489703952, 0.9348769226997694], 
             UndirectedEdge[38, 354] -> 
             RGBColor[
              0.4147037910637674, 0.5318387842884362, 0.9481369495411083], 
             UndirectedEdge[334, 446] -> 
             RGBColor[
              0.18513113872334164`, 0.31191494316334684`, 0.9338543165220936],
              UndirectedEdge[305, 310] -> 
             RGBColor[
              0.4776836488671362, 0.5829301850756662, 0.9531209010914763], 
             UndirectedEdge[338, 383] -> 
             RGBColor[
              0.34605340544318985`, 0.47036770113504156`, 0.9434098957217043],
              UndirectedEdge[243, 477] -> 
             RGBColor[
              0.19718654273618264`, 0.32458593713760425`, 0.9345408539462529],
              UndirectedEdge[38, 221] -> 
             RGBColor[
              0.7405475305032172, 0.7523239641423858, 0.6316046509416242], 
             UndirectedEdge[330, 357] -> 
             RGBColor[
              0.18906252050836794`, 0.3160470746834114, 0.9340782028987926], 
             UndirectedEdge[48, 365] -> 
             RGBColor[
              0.19846339054879825`, 0.32592798514549043`, 0.9346135685402542],
              UndirectedEdge[384, 411] -> 
             RGBColor[
              0.2746421437909936, 0.40599668481496154`, 0.9389518358410311], 
             UndirectedEdge[38, 436] -> 
             RGBColor[
              0.4371703671484145, 0.5512982032900106, 0.9495684999028087], 
             UndirectedEdge[117, 155] -> 
             RGBColor[
              0.1887434182573529, 0.3157116779853434, 0.9340600304976668], 
             UndirectedEdge[68, 286] -> 
             RGBColor[
              0.1864116908357643, 0.3132608846251963, 0.9339272420704889], 
             UndirectedEdge[378, 380] -> 
             RGBColor[
              0.19721656952288963`, 0.32461749719424154`, 0.9345425639273353],
              UndirectedEdge[12, 285] -> 
             RGBColor[
              0.20421155270957553`, 0.33196966803099826`, 0.9349409178716667],
              UndirectedEdge[93, 432] -> 
             RGBColor[
              0.2569317093580773, 0.38738189531956746`, 0.9379432528003164], 
             UndirectedEdge[340, 499] -> 
             RGBColor[
              0.4961829212208138, 0.5994318600646289, 0.9541521247756388], 
             UndirectedEdge[389, 456] -> 
             RGBColor[
              0.1952664503716337, 0.322567798321576, 0.9344315075266139], 
             UndirectedEdge[390, 451] -> 
             RGBColor[
              0.23050025885424308`, 0.3596007649892832, 0.93643802079595], 
             UndirectedEdge[92, 485] -> 
             RGBColor[
              0.26364199259434656`, 0.39443482845741684`, 0.9383253935036474],
              UndirectedEdge[293, 471] -> 
             RGBColor[
              0.883292777281721, 0.9093153449162048, 0.969810151974432], 
             UndirectedEdge[111, 359] -> 
             RGBColor[
              0.6380588033619161, 0.711320155207173, 0.9679062350071925], 
             UndirectedEdge[357, 441] -> 
             RGBColor[
              0.20500595942209238`, 0.33280463985414815`, 0.9349861581587251],
              UndirectedEdge[52, 268] -> 
             RGBColor[
              0.18314820397606815`, 0.30983075301863783`, 0.9337413913217254],
              UndirectedEdge[30, 311] -> 
             RGBColor[
              0.18445928711484194`, 0.31120878452496137`, 0.9338160555669048],
              UndirectedEdge[164, 486] -> 
             RGBColor[
              0.3646799679598963, 0.49028919172388963`, 0.9444580629779388], 
             UndirectedEdge[194, 290] -> 
             RGBColor[
              0.18381681483281254`, 0.31053350542145297`, 0.9337794677208959],
              UndirectedEdge[238, 445] -> 
             RGBColor[
              0.7249039407503491, 0.7407041936806955, 0.6319785472238091], 
             UndirectedEdge[269, 406] -> 
             RGBColor[
              0.5091880023383142, 0.611421148279524, 0.9547804937952983], 
             UndirectedEdge[99, 341] -> 
             RGBColor[
              0.9869976251000042, 0.9872951064518227, 0.7699640190632113], 
             UndirectedEdge[41, 457] -> 
             RGBColor[
              0.36616941470913866`, 0.48692522378917524`, 0.9448270715857057],
              UndirectedEdge[217, 292] -> 
             RGBColor[
              0.18318117608781065`, 0.30986540879863184`, 0.9337432690347114],
              UndirectedEdge[176, 299] -> 
             RGBColor[
              0.2785034431297019, 0.4092981665779968, 0.9391994481892236], 
             UndirectedEdge[218, 314] -> 
             RGBColor[
              0.27434229412121725`, 0.4056815238004595, 0.9389347598459252], 
             UndirectedEdge[355, 486] -> 
             RGBColor[
              0.48652222048477045`, 0.5929340389323234, 0.9530199242881539], 
             UndirectedEdge[213, 420] -> 
             RGBColor[
              0.19513105630202093`, 0.32242549056993314`, 0.9344237970346471],
              UndirectedEdge[299, 407] -> 
             RGBColor[
              0.2586014952958633, 0.3891369462107238, 0.9380383446392464], 
             UndirectedEdge[201, 314] -> 
             RGBColor[
              0.2601298304238602, 0.39074332333229245`, 0.9381253810638166], 
             UndirectedEdge[160, 300] -> 
             RGBColor[
              0.2356560570579657, 0.36501983579788244`, 0.936731635876332], 
             UndirectedEdge[21, 200] -> 
             RGBColor[
              0.28148912705476437`, 0.4131932983489973, 0.9393417614086988], 
             UndirectedEdge[25, 180] -> 
             RGBColor[
              0.2760199528625702, 0.4074448495073293, 0.9390303000293716], 
             UndirectedEdge[45, 185] -> 
             RGBColor[
              0.2063591315326575, 0.33422690953841927`, 0.935063219308583], 
             UndirectedEdge[191, 226] -> 
             RGBColor[
              0.18878815245387853`, 0.31575869646220367`, 0.9340625780439806],
              UndirectedEdge[50, 82] -> 
             RGBColor[
              0.7002427375322327, 0.764369726655832, 0.9719080506652522], 
             UndirectedEdge[22, 491] -> 
             RGBColor[
              0.1817125626643469, 0.3083218029751023, 0.9336596336728639], 
             UndirectedEdge[99, 277] -> 
             RGBColor[
              0.7114622471897839, 0.7713508183962726, 0.9343566439534178], 
             UndirectedEdge[17, 391] -> 
             RGBColor[
              0.4242791032166461, 0.5413734394625537, 0.9484041876749043], 
             UndirectedEdge[211, 362] -> 
             RGBColor[
              0.1833599948775373, 0.31005335868440065`, 0.9337534525002475], 
             UndirectedEdge[4, 162] -> 
             RGBColor[
              0.18241905104503708`, 0.3090643670571582, 0.9336998671409883], 
             UndirectedEdge[259, 444] -> 
             RGBColor[
              0.6245686648985196, 0.7054652507537504, 0.9640159946250897], 
             UndirectedEdge[347, 382] -> 
             RGBColor[
              0.2075732378156851, 0.3355030122206657, 0.9351323608652922], 
             UndirectedEdge[66, 179] -> 
             RGBColor[
              0.19899718509969622`, 0.32648903706301347`, 0.9346439673502496],
              UndirectedEdge[343, 471] -> 
             RGBColor[
              0.901533639219245, 0.661841877888372, 0.5749261182612281], 
             UndirectedEdge[97, 322] -> 
             RGBColor[
              0.9046195205529701, 0.5667356132446183, 0.288595833391559], 
             UndirectedEdge[363, 381] -> 
             RGBColor[
              0.18545627477246146`, 0.3122566817657879, 0.9338728325390953], 
             UndirectedEdge[238, 471] -> 
             RGBColor[
              0.7217628649306637, 0.780742284826936, 0.9553407683017833], 
             UndirectedEdge[40, 285] -> 
             RGBColor[
              0.19969824891224597`, 0.32722589958001636`, 0.9346838918972433],
              UndirectedEdge[70, 208] -> 
             RGBColor[
              0.39817892177344283`, 0.519304301810809, 0.9465925866929762], 
             UndirectedEdge[84, 448] -> 
             RGBColor[
              0.28804975562944346`, 0.4200889349488619, 0.9397153795004467], 
             UndirectedEdge[152, 195] -> 
             RGBColor[
              0.18616514652705513`, 0.313001750924931, 0.9339132017368377], 
             UndirectedEdge[93, 308] -> 
             RGBColor[
              0.20676738749395213`, 0.33465601243866294`, 0.9350864688816183],
              UndirectedEdge[255, 478] -> 
             RGBColor[
              0.22324206600367816`, 0.3519719441073331, 0.9360246774506443], 
             UndirectedEdge[112, 293] -> 
             RGBColor[
              0.901595183019146, 0.9214285748097474, 0.8700135366280143], 
             UndirectedEdge[87, 184] -> 
             RGBColor[
              0.4246238918446351, 0.5398024449911591, 0.9489353468656369], 
             UndirectedEdge[149, 323] -> 
             RGBColor[
              0.7769198644929252, 0.8229213917028264, 0.8645345338157826], 
             UndirectedEdge[272, 497] -> 
             RGBColor[
              0.3677045224545963, 0.48747048871276477`, 0.9450117306986173], 
             UndirectedEdge[80, 471] -> 
             RGBColor[
              0.6521263465827374, 0.7213327352775194, 0.9506532320788272], 
             UndirectedEdge[339, 344] -> 
             RGBColor[
              0.1852310273425353, 0.3120199324354236, 0.9338600050311847], 
             UndirectedEdge[137, 393] -> 
             RGBColor[
              0.21648582185917808`, 0.3448707031408432, 0.9356399193415825], 
             UndirectedEdge[11, 316] -> 
             RGBColor[
              0.4071433573553281, 0.5270688453462049, 0.9471637926013148], 
             UndirectedEdge[88, 423] -> 
             RGBColor[
              0.18437944571093495`, 0.3111248661472177, 0.9338115087170672], 
             UndirectedEdge[70, 351] -> 
             RGBColor[
              0.3049667644622824, 0.4322301812417861, 0.9408852716041266], 
             UndirectedEdge[55, 298] -> 
             RGBColor[
              0.424640850686557, 0.5359021493799299, 0.9492929643380126], 
             UndirectedEdge[428, 437] -> 
             RGBColor[
              0.18484681961512717`, 0.31161610575374077`, 0.9338381249694931],
              UndirectedEdge[90, 137] -> 
             RGBColor[
              0.23700337417738956`, 0.3664359515152362, 0.9368083635931062], 
             UndirectedEdge[344, 439] -> 
             RGBColor[
              0.19475306873947695`, 0.32202820167590374`, 0.9344022712021427],
              UndirectedEdge[93, 274] -> 
             RGBColor[
              0.23335737797095998`, 0.3626037783327675, 0.936600729502918], 
             UndirectedEdge[60, 434] -> 
             RGBColor[
              0.9602863904874878, 0.8842947028459596, 0.5783529786054818], 
             UndirectedEdge[54, 244] -> 
             RGBColor[
              0.7181235795673231, 0.775643062211419, 0.8864694686198505], 
             UndirectedEdge[243, 318] -> 
             RGBColor[
              0.19728008332867447`, 0.3246842542311293, 0.9345461809446143], 
             UndirectedEdge[384, 402] -> 
             RGBColor[
              0.24310211003433443`, 0.3728461095830723, 0.937155677577888], 
             UndirectedEdge[83, 233] -> 
             RGBColor[
              0.9788921335245182, 0.9819450762719373, 0.8385157306415634], 
             UndirectedEdge[153, 201] -> 
             RGBColor[
              0.2425444285480653, 0.37225995098195497`, 0.9371239184422607], 
             UndirectedEdge[275, 331] -> 
             RGBColor[
              0.39537355093788906`, 0.515221122490898, 0.946708621365979], 
             UndirectedEdge[312, 327] -> 
             RGBColor[
              0.18937402646973123`, 0.31637448719942296`, 0.9340959427024605],
              UndirectedEdge[181, 370] -> 
             RGBColor[
              0.2271386690157574, 0.35606752093192884`, 0.9362465832276747], 
             UndirectedEdge[32, 245] -> 
             RGBColor[
              0.23179881460343715`, 0.36096562941487603`, 0.9365119716248255],
              UndirectedEdge[176, 391] -> 
             RGBColor[
              0.3950241069319744, 0.5160342320796381, 0.9465400851808224], 
             UndirectedEdge[148, 232] -> 
             RGBColor[
              0.27654750718772436`, 0.40799934255194237`, 0.9390603434677424],
              UndirectedEdge[430, 477] -> 
             RGBColor[
              0.19967498374543186`, 0.3272014464145979, 0.9346825669804111], 
             UndirectedEdge[7, 475] -> 
             RGBColor[
              0.40444131336028016`, 0.5242115978182725, 0.9471344342497021], 
             UndirectedEdge[15, 50] -> 
             RGBColor[
              0.7663849277124503, 0.8179130209698517, 0.9772202389257285], 
             UndirectedEdge[168, 395] -> 
             RGBColor[
              0.3984267572015211, 0.5166565922466431, 0.9470439450191381], 
             UndirectedEdge[97, 440] -> 
             RGBColor[
              0.9400446504463722, 0.7867672719569345, 0.32047255191532753`], 
             UndirectedEdge[71, 308] -> 
             RGBColor[
              0.19432153409427227`, 0.32157463140291687`, 0.9343776959424965],
              UndirectedEdge[253, 436] -> 
             RGBColor[
              0.36650668927910635`, 0.49187140591690626`, 0.9445744600450926],
              UndirectedEdge[13, 430] -> 
             RGBColor[
              0.22725075415308893`, 0.3561853295178724, 0.9362529663104306], 
             UndirectedEdge[209, 233] -> 
             RGBColor[
              0.9785167541303205, 0.9817898472456261, 0.8447367386541516], 
             UndirectedEdge[254, 350] -> 
             RGBColor[
              0.18697690227356584`, 0.31385495768280075`, 0.9339594300257164],
              UndirectedEdge[115, 268] -> 
             RGBColor[
              0.18864406926620203`, 0.3156072558965539, 0.9340543727195945], 
             UndirectedEdge[42, 468] -> 
             RGBColor[
              0.21102583019430793`, 0.33913190571759855`, 0.9353289808936021],
              UndirectedEdge[51, 60] -> 
             RGBColor[
              0.9903726876472161, 0.9902614167392676, 0.8073625961746422], 
             UndirectedEdge[331, 348] -> 
             RGBColor[
              0.3817575877124325, 0.5041670701523192, 0.9456367228639543], 
             UndirectedEdge[310, 406] -> 
             RGBColor[
              0.5306573998942516, 0.6288133856772102, 0.9564963416640753], 
             UndirectedEdge[70, 130] -> 
             RGBColor[
              0.33633111822806117`, 0.4651961056645053, 0.9426714251516843], 
             UndirectedEdge[83, 440] -> 
             RGBColor[
              0.9434296852982257, 0.7965522714191877, 0.48002728769919345`], 
             UndirectedEdge[100, 374] -> 
             RGBColor[
              0.9203355927006582, 0.6768022824414968, 0.3486163331687475], 
             UndirectedEdge[207, 374] -> 
             RGBColor[
              0.8612156544492956, 0.4454551404687426, 0.20523222788802623`], 
             UndirectedEdge[51, 324] -> 
             RGBColor[
              0.9674926297054737, 0.9734136310223126, 0.8557710419754258], 
             UndirectedEdge[164, 180] -> 
             RGBColor[
              0.28958519225458484`, 0.42102975172188783`, 0.9398274630675963],
              UndirectedEdge[56, 132] -> 
             RGBColor[
              0.3395809707923225, 0.46518136452608577`, 0.94298210840368], 
             UndirectedEdge[30, 423] -> 
             RGBColor[
              0.17906694420854233`, 0.3055410902361533, 0.9335089696156476], 
             UndirectedEdge[104, 379] -> 
             RGBColor[
              0.8757781230833462, 0.4743585366446421, 0.21585393387585383`], 
             UndirectedEdge[324, 457] -> 
             RGBColor[
              0.7044919829810323, 0.7672858327374596, 0.9691306015608669], 
             UndirectedEdge[283, 459] -> 
             RGBColor[
              0.18839869617185917`, 0.3153493532168468, 0.9340403990848687], 
             UndirectedEdge[128, 245] -> 
             RGBColor[
              0.21909064595633707`, 0.347608538422344, 0.9357882602204238], 
             UndirectedEdge[34, 62] -> 
             RGBColor[
              0.23006104796724536`, 0.35913912649947, 0.9364130083856896], 
             UndirectedEdge[320, 424] -> 
             RGBColor[
              0.18730513840807234`, 0.31419995467154005`, 0.9339781225879946],
              UndirectedEdge[111, 351] -> 
             RGBColor[
              0.3033909458875273, 0.43086528639527777`, 0.9407848618379848], 
             UndirectedEdge[79, 316] -> 
             RGBColor[
              0.6624800077652702, 0.7332731084999433, 0.9690938030221024], 
             UndirectedEdge[43, 250] -> 
             RGBColor[
              0.22400512105631526`, 0.3527739633481394, 0.9360681323070532], 
             UndirectedEdge[116, 313] -> 
             RGBColor[
              0.3188496851508186, 0.44760999428327536`, 0.9416470314755198], 
             UndirectedEdge[87, 436] -> 
             RGBColor[
              0.33196658064928775`, 0.46192364467997304`, 0.9423747246250382],
              UndirectedEdge[280, 393] -> 
             RGBColor[
              0.23739481376153632`, 0.3668473793368775, 0.9368306554983403], 
             UndirectedEdge[295, 321] -> 
             RGBColor[
              0.9851155314829081, 0.988112904001859, 0.896337693305348], 
             UndirectedEdge[131, 186] -> 
             RGBColor[
              0.913526249632497, 0.6241954645463874, 0.3472925437386266], 
             UndirectedEdge[165, 313] -> 
             RGBColor[
              0.3335735057381806, 0.4630856632647371, 0.9424855312760294], 
             UndirectedEdge[140, 270] -> 
             RGBColor[
              0.1795641494336302, 0.30606368445235266`, 0.9335372847176671], 
             UndirectedEdge[322, 445] -> 
             RGBColor[
              0.89195053197754, 0.5240001399597152, 0.23937920511375732`], 
             UndirectedEdge[112, 463] -> 
             RGBColor[
              0.7743003013960627, 0.8206490549360065, 0.8582392599813213], 
             UndirectedEdge[115, 223] -> 
             RGBColor[
              0.1995856510144891, 0.3271075520503548, 0.9346774796135398], 
             UndirectedEdge[102, 451] -> 
             RGBColor[
              0.20226457959273075`, 0.32992327583996894`, 0.9348300406329509],
              UndirectedEdge[148, 267] -> 
             RGBColor[
              0.25194617616278553`, 0.3821417838302541, 0.9376593340602799], 
             UndirectedEdge[447, 500] -> 
             RGBColor[
              0.21735914083056895`, 0.34578861675139594`, 0.9356896535650436],
              UndirectedEdge[238, 293] -> 
             RGBColor[
              0.6482189757415503, 0.7227281926989446, 0.9672024760249813], 
             UndirectedEdge[56, 457] -> 
             RGBColor[
              0.4380492997215996, 0.5534053955584954, 0.9492526271337134], 
             UndirectedEdge[204, 331] -> 
             RGBColor[
              0.3086689498622105, 0.44109928644623464`, 0.9409138412479245], 
             UndirectedEdge[66, 260] -> 
             RGBColor[
              0.203816558535701, 0.331554504110179, 0.9349184235378061], 
             UndirectedEdge[225, 424] -> 
             RGBColor[
              0.18871848366086047`, 0.31568547014348514`, 0.9340586105092841],
              UndirectedEdge[178, 244] -> 
             RGBColor[
              0.45801552683844415`, 0.5706975580302278, 0.9505252940081765], 
             UndirectedEdge[139, 247] -> 
             RGBColor[
              0.18343934894517555`, 0.310136764840827, 0.9337579715970057], 
             UndirectedEdge[244, 448] -> 
             RGBColor[
              0.373652859998312, 0.49730643195466345`, 0.9450574383468822], 
             UndirectedEdge[259, 275] -> 
             RGBColor[
              0.586292797645066, 0.6743911774092273, 0.9610027781457763], 
             UndirectedEdge[282, 406] -> 
             RGBColor[
              0.5566077877471345, 0.6490860258981348, 0.9590828338050883], 
             UndirectedEdge[286, 357] -> 
             RGBColor[
              0.1879701028596808, 0.3148988744713619, 0.934015991329787], 
             UndirectedEdge[206, 396] -> 
             RGBColor[
              0.18892633617542332`, 0.3159039363149012, 0.9340704474024981], 
             UndirectedEdge[154, 295] -> 
             RGBColor[
              0.9841314996436169, 0.9875855475713144, 0.9072523679449918], 
             UndirectedEdge[410, 428] -> 
             RGBColor[
              0.18501111447909718`, 0.3117887900726693, 0.9338474813189439], 
             UndirectedEdge[104, 147] -> 
             RGBColor[
              0.8716060245867224, 0.4422899593743725, 0.21185872764377553`], 
             UndirectedEdge[32, 255] -> 
             RGBColor[
              0.20842141467182945`, 0.3363944998739921, 0.9351806632824844], 
             UndirectedEdge[165, 498] -> 
             RGBColor[
              0.5402564536084126, 0.6313553023460808, 0.9594503111519376], 
             UndirectedEdge[248, 439] -> 
             RGBColor[
              0.18975162768821172`, 0.3167713700213459, 0.934117446533242], 
             UndirectedEdge[141, 389] -> 
             RGBColor[
              0.20111521708192343`, 0.32871522296731825`, 0.9347645861382899],
              UndirectedEdge[328, 478] -> 
             RGBColor[
              0.24615010342073995`, 0.376049743886127, 0.9373292562921416], 
             UndirectedEdge[178, 261] -> 
             RGBColor[
              0.3993010721320601, 0.5198420484378579, 0.9467840608734395], 
             UndirectedEdge[120, 315] -> 
             RGBColor[
              0.18165682168185682`, 0.3082632156683228, 0.9336564593063725], 
             UndirectedEdge[47, 136] -> 
             RGBColor[
              0.40491583995544145`, 0.5205967008566313, 0.9476756741243257], 
             UndirectedEdge[74, 144] -> 
             RGBColor[
              0.1927927730691202, 0.31996780663643465`, 0.9342906352637134], 
             UndirectedEdge[165, 361] -> 
             RGBColor[
              0.26801366747199473`, 0.39902973593402147`, 0.9385743539206161],
              UndirectedEdge[32, 482] -> 
             RGBColor[
              0.27602220405873207`, 0.40526283104925287`, 0.9391104092526332],
              UndirectedEdge[67, 119] -> 
             RGBColor[
              0.18259585546660687`, 0.3092501997142758, 0.933709935891238], 
             UndirectedEdge[97, 326] -> 
             RGBColor[
              0.8569194124299913, 0.8790587115212953, 0.6914601091734929], 
             UndirectedEdge[409, 430] -> 
             RGBColor[
              0.22739490707234228`, 0.3563368433758307, 0.9362611756059269], 
             UndirectedEdge[113, 190] -> 
             RGBColor[
              0.20663037548476026`, 0.33451200412993914`, 0.9350786662503858],
              UndirectedEdge[292, 496] -> 
             RGBColor[
              0.1854675912889076, 0.3122685761420814, 0.9338734769979656], 
             UndirectedEdge[15, 82] -> 
             RGBColor[
              0.5862643398841738, 0.6748409125363397, 0.9606772556368353], 
             UndirectedEdge[340, 414] -> 
             RGBColor[
              0.3932297908847611, 0.5150176133855842, 0.946277232449094], 
             UndirectedEdge[149, 282] -> 
             RGBColor[
              0.6289215162862603, 0.7087932049561856, 0.9644994328569398], 
             UndirectedEdge[330, 368] -> 
             RGBColor[
              0.18440628949779087`, 0.3111530806691976, 0.9338130374310167], 
             UndirectedEdge[331, 431] -> 
             RGBColor[
              0.3613433617487599, 0.48672321452944306`, 0.9442702081951819], 
             UndirectedEdge[4, 488] -> 
             RGBColor[
              0.1820203772126724, 0.30864533558196194`, 0.9336771632560201], 
             UndirectedEdge[87, 409] -> 
             RGBColor[
              0.28082294387369244`, 0.4124930975872375, 0.9393038232620665], 
             UndirectedEdge[440, 445] -> 
             RGBColor[
              0.9273756618709421, 0.7440317986720315, 0.27125592363752593`], 
             UndirectedEdge[55, 200] -> 
             RGBColor[
              0.4182843192455511, 0.5292210318080617, 0.9489309692760928], 
             UndirectedEdge[64, 215] -> 
             RGBColor[
              0.18488430371745596`, 0.31165550392191765`, 0.9338402596336681],
              UndirectedEdge[167, 493] -> 
             RGBColor[
              0.25038390854803594`, 0.3804997415136645, 0.9375703652307877], 
             UndirectedEdge[153, 470] -> 
             RGBColor[
              0.2111255154646311, 0.3392366812571194, 0.9353346578222758], 
             UndirectedEdge[185, 187] -> 
             RGBColor[
              0.21639359634399347`, 0.34477376827694883`, 0.9356346672349283],
              UndirectedEdge[18, 310] -> 
             RGBColor[
              0.46656300779364224`, 0.5714089084514553, 0.952481474208732], 
             UndirectedEdge[226, 366] -> 
             RGBColor[
              0.18476826025973897`, 0.3115335348902769, 0.9338336511304219], 
             UndirectedEdge[333, 361] -> 
             RGBColor[
              0.2309444912286668, 0.3600676813807619, 0.9364633191724905], 
             UndirectedEdge[236, 300] -> 
             RGBColor[
              0.22011134127912346`, 0.34868135392241384`, 0.9358463873090731],
              UndirectedEdge[161, 335] -> 
             RGBColor[
              0.21211283365491676`, 0.3402744152746985, 0.9353908841326062], 
             UndirectedEdge[61, 397] -> 
             RGBColor[
              0.9061343995223057, 0.5802110742285213, 0.48990321177495955`], 
             UndirectedEdge[393, 480] -> 
             RGBColor[
              0.23233850550566576`, 0.36153287877149787`, 0.9365427062233063],
              UndirectedEdge[349, 378] -> 
             RGBColor[
              0.1960796577618784, 0.3234225308490497, 0.9344778184844558], 
             UndirectedEdge[97, 163] -> 
             RGBColor[
              0.9438826652312557, 0.8041948007039634, 0.3236750855301855], 
             UndirectedEdge[229, 267] -> 
             RGBColor[
              0.23204884719292487`, 0.3612284295194095, 0.9365262106109067], 
             UndirectedEdge[77, 287] -> 
             RGBColor[
              0.31931088859466533`, 0.4505681988320882, 0.9415827311905192], 
             UndirectedEdge[41, 485] -> 
             RGBColor[
              0.2592162515913262, 0.38978309405505573`, 0.9380733541008225], 
             UndirectedEdge[7, 89] -> 
             RGBColor[
              0.39101776123385745`, 0.5125847916537125, 0.9462790973781875], 
             UndirectedEdge[41, 44] -> 
             RGBColor[
              0.27104906144274005`, 0.40222012745236824`, 0.938747215116787], 
             UndirectedEdge[147, 234] -> 
             RGBColor[
              0.872729313424225, 0.4467434253012546, 0.2127625522094079], 
             UndirectedEdge[259, 331] -> 
             RGBColor[
              0.4923539796181456, 0.5933274496466499, 0.9547717909351274], 
             UndirectedEdge[77, 409] -> 
             RGBColor[
              0.2938507755920474, 0.42380800580193695`, 0.940132815419882], 
             UndirectedEdge[2, 334] -> 
             RGBColor[
              0.18552483193608832`, 0.31232873969153496`, 0.9338767367681426],
              UndirectedEdge[315, 487] -> 
             RGBColor[
              0.1880750117052634, 0.3150091403196742, 0.9340219657333442], 
             UndirectedEdge[251, 258] -> 
             RGBColor[
              0.3270553942889411, 0.45124571304551764`, 0.9422970062673146], 
             UndirectedEdge[39, 96] -> 
             RGBColor[
              0.359182658449612, 0.4793995184819319, 0.94444576944529], 
             UndirectedEdge[219, 497] -> 
             RGBColor[
              0.5738542866268592, 0.6645036181845554, 0.959879595311844], 
             UndirectedEdge[447, 454] -> 
             RGBColor[
              0.2225609566268063, 0.3512560549674121, 0.9359858892792425], 
             UndirectedEdge[417, 458] -> 
             RGBColor[
              0.21807667250257026`, 0.34654278803280497`, 0.9357305159322711],
              UndirectedEdge[189, 422] -> 
             RGBColor[
              0.22925608385888036`, 0.3582930581839061, 0.936367166870556], 
             UndirectedEdge[431, 444] -> 
             RGBColor[
              0.4935580470291339, 0.5988610156365437, 0.9535144118851442], 
             UndirectedEdge[161, 273] -> 
             RGBColor[
              0.20050467294518176`, 0.3280735023688687, 0.9347298165529216], 
             UndirectedEdge[109, 413] -> 
             RGBColor[
              0.22197296688604118`, 0.35063804046916514`, 0.9359524041333588],
              UndirectedEdge[236, 470] -> 
             RGBColor[
              0.2014866380141136, 0.3291056099164974, 0.9347857380109101], 
             UndirectedEdge[287, 436] -> 
             RGBColor[
              0.3298373627600314, 0.45968570167815315`, 0.9422534688161406], 
             UndirectedEdge[253, 473] -> 
             RGBColor[
              0.32054318862790937`, 0.44788551033051344`, 0.9417985597710807],
              UndirectedEdge[166, 435] -> 
             RGBColor[
              0.21704014991788595`, 0.3454533370769741, 0.9356714875044712], 
             UndirectedEdge[114, 312] -> 
             RGBColor[
              0.1882015984664733, 0.31514219103177, 0.9340291746621268], 
             UndirectedEdge[222, 296] -> 
             RGBColor[
              0.18966575842362554`, 0.31668111597984006`, 0.934112556405656], 
             UndirectedEdge[5, 346] -> 
             RGBColor[
              0.5654957918264961, 0.6570874909093873, 0.9595208737141337], 
             UndirectedEdge[86, 220] -> 
             RGBColor[
              0.20117259087192368`, 0.32877552645831687`, 0.9347678534907535],
              UndirectedEdge[195, 255] -> 
             RGBColor[
              0.19263264106654965`, 0.3197994977487777, 0.9342815159830611], 
             UndirectedEdge[313, 407] -> 
             RGBColor[
              0.31917500731539133`, 0.44795192850485793`, 0.9416655580915212],
              UndirectedEdge[224, 441] -> 
             RGBColor[
              0.21370093658000952`, 0.34194361214051205`, 0.9354813242448025],
              UndirectedEdge[172, 211] -> 
             RGBColor[
              0.20548759572979827`, 0.33331087015105276`, 0.9350135866339319],
              UndirectedEdge[204, 355] -> 
             RGBColor[
              0.4378065045945586, 0.5507389343512965, 0.9499158019492457], 
             UndirectedEdge[109, 180] -> 
             RGBColor[
              0.23839049921865452`, 0.36789390788241305`, 0.9368873583121385],
              UndirectedEdge[96, 157] -> 
             RGBColor[
              0.3849349952696799, 0.5064668572722832, 0.9459123269300246], 
             UndirectedEdge[316, 372] -> 
             RGBColor[
              0.5264921273018517, 0.6260724945913516, 0.9559761056168596], 
             UndirectedEdge[53, 112] -> 
             RGBColor[
              0.9130580700237505, 0.6218566223199413, 0.468638906464419], 
             UndirectedEdge[28, 305] -> 
             RGBColor[
              0.3931980637426643, 0.5143785677629451, 0.9464441881014032], 
             UndirectedEdge[186, 341] -> 
             RGBColor[
              0.9938102781827736, 0.9891691358468536, 0.5676651626091419], 
             UndirectedEdge[65, 86] -> 
             RGBColor[
              0.18424555499085607`, 0.31098413851125284`, 0.9338038838386322],
              UndirectedEdge[10, 390] -> 
             RGBColor[
              0.24135031626720926`, 0.37100486326368376`, 0.9370559155143968],
              UndirectedEdge[48, 140] -> 
             RGBColor[
              0.1844487281323768, 0.3111976863649123, 0.9338154542484741], 
             UndirectedEdge[231, 404] -> 
             RGBColor[
              0.8002424461846211, 0.8440108833840196, 0.9806882202971826], 
             UndirectedEdge[87, 354] -> 
             RGBColor[
              0.30950000456464066`, 0.4424642256783988, 0.9409431742633377], 
             UndirectedEdge[136, 434] -> 
             RGBColor[
              0.7316510467407765, 0.7040970288480641, 0.6113123490612679], 
             UndirectedEdge[205, 413] -> 
             RGBColor[
              0.2338956489319965, 0.363169535241167, 0.9366313832378486], 
             UndirectedEdge[20, 490] -> 
             RGBColor[
              0.22886274008807128`, 0.3578796289413503, 0.9363447665247084], 
             UndirectedEdge[390, 443] -> 
             RGBColor[
              0.2718752322958543, 0.4030884854012488, 0.9387942643246616], 
             UndirectedEdge[296, 385] -> 
             RGBColor[
              0.18189236637294215`, 0.30851078807304944`, 0.9336698732280726],
              UndirectedEdge[86, 290] -> 
             RGBColor[
              0.18341921937923714`, 0.31011560739073746`, 0.9337568252480046],
              UndirectedEdge[24, 74] -> 
             RGBColor[
              0.18699882666459755`, 0.3138780016078617, 0.9339606785873513], 
             UndirectedEdge[38, 336] -> 
             RGBColor[
              0.5720852226715933, 0.663483581767208, 0.9594557908273795], 
             UndirectedEdge[383, 443] -> 
             RGBColor[
              0.2778055713012203, 0.40932164770109847`, 0.9391319883578669], 
             UndirectedEdge[14, 435] -> 
             RGBColor[
              0.23468936895954257`, 0.3640037853148743, 0.9366765844192138], 
             UndirectedEdge[282, 323] -> 
             RGBColor[
              0.8447117696653836, 0.8771252738990953, 0.8704406417188999], 
             UndirectedEdge[307, 337] -> 
             RGBColor[
              0.19042947914241254`, 0.31748383487797555`, 0.9341560491707674],
              UndirectedEdge[157, 356] -> 
             RGBColor[
              0.272205938145604, 0.40343607821729777`, 0.9388130975335695], 
             UndirectedEdge[166, 439] -> 
             RGBColor[
              0.19745604044376464`, 0.3248691963154145, 0.9345562014420135], 
             UndirectedEdge[266, 293] -> 
             RGBColor[
              0.9016661303754756, 0.9199925303309897, 0.7623198781355807], 
             UndirectedEdge[2, 260] -> 
             RGBColor[
              0.1969726482624509, 0.32436112048401927`, 0.9345286729724024], 
             UndirectedEdge[135, 466] -> 
             RGBColor[
              0.18744105358565671`, 0.3143428101407012, 0.9339858627562896], 
             UndirectedEdge[60, 495] -> 
             RGBColor[
              0.9357924776533132, 0.7819607374227355, 0.5583743815380187], 
             UndirectedEdge[217, 464] -> 
             RGBColor[
              0.19184821856094375`, 0.31897501996012645`, 0.9342368442818159],
              UndirectedEdge[435, 453] -> 
             RGBColor[
              0.2391644667053946, 0.36870739678334974`, 0.9369314346155262], 
             UndirectedEdge[82, 411] -> 
             RGBColor[
              0.4006657201660342, 0.5170983953721258, 0.9473454462572704], 
             UndirectedEdge[94, 193] -> 
             RGBColor[
              0.17992543383268728`, 0.3064434172625156, 0.9335578593297211], 
             UndirectedEdge[88, 469] -> 
             RGBColor[
              0.1854557592359103, 0.3122561399041857, 0.9338728031800514], 
             UndirectedEdge[36, 76] -> 
             RGBColor[
              0.7022798190159381, 0.7608775969992009, 0.8471463932234504], 
             UndirectedEdge[163, 326] -> 
             RGBColor[
              0.8123452824001817, 0.7105293109037376, 0.6054779360527895], 
             UndirectedEdge[151, 472] -> 
             RGBColor[
              0.1934245140122105, 0.3206318064223118, 0.9343266119758453], 
             UndirectedEdge[114, 138] -> 
             RGBColor[
              0.18210218513342014`, 0.30873132089358957`, 0.9336818220960829],
              UndirectedEdge[448, 475] -> 
             RGBColor[
              0.3185563246566676, 0.44958458227411635`, 0.9415467358348658], 
             UndirectedEdge[169, 362] -> 
             RGBColor[
              0.18152465259386255`, 0.3081242975768366, 0.9336489324723378], 
             UndirectedEdge[20, 25] -> 
             RGBColor[
              0.26532620998703904`, 0.39620504772268694`, 0.9384213071925849],
              UndirectedEdge[113, 349] -> 
             RGBColor[
              0.19095597353932497`, 0.3180372138708033, 0.934186032247793], 
             UndirectedEdge[457, 494] -> 
             RGBColor[
              0.4122768656126409, 0.531082608493518, 0.9476104304219592], 
             UndirectedEdge[364, 452] -> 
             RGBColor[
              0.21560011293675418`, 0.34393976690618655`, 0.9355894795287394],
              UndirectedEdge[351, 442] -> 
             RGBColor[
              0.23904734061072216`, 0.3685842898316257, 0.936924764457707], 
             UndirectedEdge[71, 466] -> 
             RGBColor[
              0.1963124589116516, 0.3236672196179068, 0.934491076165537], 
             UndirectedEdge[87, 285] -> 
             RGBColor[
              0.2614000119680612, 0.39207836466940904`, 0.9381977160236936], 
             UndirectedEdge[211, 369] -> 
             RGBColor[
              0.1847549864301014, 0.3115195832537184, 0.933832895205461], 
             UndirectedEdge[164, 316] -> 
             RGBColor[
              0.37736919780669476`, 0.5012799648379501, 0.9452666094831315], 
             UndirectedEdge[27, 297] -> 
             RGBColor[
              0.19023703211735066`, 0.31728156085278936`, 0.93414508959739], 
             UndirectedEdge[238, 483] -> 
             RGBColor[
              0.46936492725835366`, 0.5800559392387936, 0.9513788548661433], 
             UndirectedEdge[109, 164] -> 
             RGBColor[
              0.2648306442899861, 0.3950111522821019, 0.9384177281820844], 
             UndirectedEdge[83, 355] -> 
             RGBColor[
              0.7774683536702185, 0.8228654453922359, 0.8436241428882965], 
             UndirectedEdge[85, 166] -> 
             RGBColor[
              0.19147571921883372`, 0.31858349953374643`, 0.9342156309953462],
              UndirectedEdge[34, 190] -> 
             RGBColor[
              0.2127364473424475, 0.3409298727996848, 0.9354263980095573], 
             UndirectedEdge[232, 383] -> 
             RGBColor[
              0.2731170371748888, 0.40439370106409095`, 0.938864983275437], 
             UndirectedEdge[185, 441] -> 
             RGBColor[
              0.21650425944697038`, 0.34489008221462353`, 0.9356409693349313],
              UndirectedEdge[83, 207] -> 
             RGBColor[
              0.9351069377955797, 0.7587606188367377, 0.47308258317377627`], 
             UndirectedEdge[138, 385] -> 
             RGBColor[
              0.18216276894964933`, 0.30879499832568225`, 0.9336852722547914],
              UndirectedEdge[131, 234] -> 
             RGBColor[
              0.88005378670787, 0.5030425365640092, 0.21977647609763581`], 
             UndirectedEdge[80, 81] -> 
             RGBColor[
              0.2928864737857844, 0.4215973242135559, 0.9401217329908362], 
             UndirectedEdge[5, 486] -> 
             RGBColor[
              0.5514554325451628, 0.6449264373888728, 0.9586262344361294], 
             UndirectedEdge[94, 139] -> 
             RGBColor[
              0.18076319755662762`, 0.3073239600536649, 0.9336055687344391], 
             UndirectedEdge[126, 249] -> 
             RGBColor[
              0.6077030059991793, 0.6911038805087482, 0.9631457140050295], 
             UndirectedEdge[359, 483] -> 
             RGBColor[
              0.6807834462506754, 0.7483260934744262, 0.970628611472146], 
             UndirectedEdge[275, 404] -> 
             RGBColor[
              0.663069657712535, 0.7345059792856424, 0.9686190519229416], 
             UndirectedEdge[313, 391] -> 
             RGBColor[
              0.4171675799720802, 0.5352137954636619, 0.9479510477022336], 
             UndirectedEdge[1, 487] -> 
             RGBColor[
              0.19600881958127922`, 0.3233480754298399, 0.9344737843548664], 
             UndirectedEdge[71, 172] -> 
             RGBColor[
              0.21061538458324242`, 0.3387005013566139, 0.9353056066232517], 
             UndirectedEdge[44, 494] -> 
             RGBColor[
              0.31715651234624226`, 0.44637751215671095`, 0.9415305739530406],
              UndirectedEdge[85, 387] -> 
             RGBColor[
              0.18808022272596522`, 0.31501461743282955`, 0.9340222624932641],
              UndirectedEdge[414, 499] -> 
             RGBColor[
              0.5256197261535013, 0.6249285409604874, 0.9560278119560052], 
             UndirectedEdge[89, 376] -> 
             RGBColor[
              0.3403951990959194, 0.4692549455218861, 0.9429106589801041], 
             UndirectedEdge[171, 403] -> 
             RGBColor[
              0.6070518602239434, 0.6903231179453404, 0.9632668381945488], 
             UndirectedEdge[161, 279] -> 
             RGBColor[
              0.21091668232154126`, 0.339017184382946, 0.9353227650837177], 
             UndirectedEdge[149, 310] -> 
             RGBColor[
              0.6029711284333774, 0.688520564735261, 0.9619129407159268], 
             UndirectedEdge[333, 367] -> 
             RGBColor[
              0.21446892121193922`, 0.34275081268170826`, 0.9355250598334595],
              UndirectedEdge[43, 227] -> 
             RGBColor[
              0.21076377490674741`, 0.3388564689951076, 0.9353140572326515], 
             UndirectedEdge[71, 369] -> 
             RGBColor[
              0.18988277528354555`, 0.3169092144592796, 0.9341249151947808], 
             UndirectedEdge[134, 174] -> 
             RGBColor[
              0.18580423451035571`, 0.31262240951223635`, 0.9338926483314081],
              UndirectedEdge[158, 370] -> 
             RGBColor[
              0.21023358203312498`, 0.3382992026687606, 0.9352838635328488], 
             UndirectedEdge[7, 391] -> 
             RGBColor[
              0.47273438056684836`, 0.582826092442144, 0.9516345286027679], 
             UndirectedEdge[200, 228] -> 
             RGBColor[
              0.26059605928059204`, 0.3912333594213344, 0.9381519321074836], 
             UndirectedEdge[201, 300] -> 
             RGBColor[
              0.24465748938560672`, 0.37448091189800614`, 0.9372442541309653],
              UndirectedEdge[210, 320] -> 
             RGBColor[
              0.18833104309187587`, 0.31527824554033135`, 0.9340365463420472],
              UndirectedEdge[69, 103] -> 
             RGBColor[
              0.4263301464035756, 0.5436874776637394, 0.9483863578332576], 
             UndirectedEdge[97, 281] -> 
             RGBColor[
              0.903440360362725, 0.5576720713111039, 0.28746666826170925`], 
             UndirectedEdge[192, 272] -> 
             RGBColor[
              0.28510804558804614`, 0.41660469339403305`, 0.9395622181414255],
              UndirectedEdge[70, 463] -> 
             RGBColor[
              0.4624511336723232, 0.5722084360335765, 0.9514519951932873], 
             UndirectedEdge[285, 477] -> 
             RGBColor[
              0.20609075774927643`, 0.3339448316762051, 0.935047935818643], 
             UndirectedEdge[10, 168] -> 
             RGBColor[
              0.25974966627430485`, 0.39034374670731053`, 0.9381037312779018],
              UndirectedEdge[298, 468] -> 
             RGBColor[
              0.24859500261068126`, 0.37861948795031725`, 0.9374684896841046],
              UndirectedEdge[37, 264] -> 
             RGBColor[
              0.8636993298194549, 0.4739723151879993, 0.20797971857725228`], 
             UndirectedEdge[191, 405] -> 
             RGBColor[
              0.18612791917026347`, 0.3129626226125922, 0.9339110816939413], 
             UndirectedEdge[349, 380] -> 
             RGBColor[
              0.18633207943578872`, 0.3131772079961678, 0.9339227083190349], 
             UndirectedEdge[94, 410] -> 
             RGBColor[
              0.18058759193707163`, 0.30713938741347224`, 0.9335955682541907],
              UndirectedEdge[335, 409] -> 
             RGBColor[
              0.23180434544224413`, 0.3609714426771376, 0.9365122865979134], 
             UndirectedEdge[168, 189] -> 
             RGBColor[
              0.272342262398906, 0.403579363650975, 0.9388208609981212], 
             UndirectedEdge[187, 399] -> 
             RGBColor[
              0.214562612650492, 0.3428492883240075, 0.9355303954222809], 
             UndirectedEdge[153, 314] -> 
             RGBColor[
              0.24522255976789442`, 0.3750748366973221, 0.93727643405329], 
             UndirectedEdge[233, 355] -> 
             RGBColor[
              0.7611336222299645, 0.8125163214181457, 0.9533731433112391], 
             UndirectedEdge[233, 486] -> 
             RGBColor[
              0.6879460003390702, 0.7520136698120249, 0.9479115120414208], 
             UndirectedEdge[49, 264] -> 
             RGBColor[
              0.9297344136885161, 0.7358812173257631, 0.3948314869060207], 
             UndirectedEdge[205, 331] -> 
             RGBColor[
              0.26945802412846753`, 0.40054784635747565`, 0.938656607895468], 
             UndirectedEdge[308, 456] -> 
             RGBColor[
              0.1932579406357965, 0.32045672724233865`, 0.9343171258684819], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.2456814749936662, 0.3755571856965141, 0.9373025685964933], 
             UndirectedEdge[175, 371] -> 
             RGBColor[
              0.32587980547058965`, 0.4516283990891108, 0.9421708041706565], 
             UndirectedEdge[21, 188] -> 
             RGBColor[
              0.26198974805947073`, 0.39269821469290833`, 0.9382313006216629],
              UndirectedEdge[79, 221] -> 
             RGBColor[
              0.9242610852428408, 0.8982704304455256, 0.6484794882507952], 
             UndirectedEdge[158, 193] -> 
             RGBColor[
              0.1863155768050812, 0.3131598626849669, 0.9339217685186295], 
             UndirectedEdge[266, 483] -> 
             RGBColor[
              0.722812081892279, 0.7773202768708386, 0.7464962569767426], 
             UndirectedEdge[290, 484] -> 
             RGBColor[
              0.18316922942285135`, 0.3098528520962973, 0.9337425886898154], 
             UndirectedEdge[153, 411] -> 
             RGBColor[
              0.2544232242601058, 0.38474531843445803`, 0.937800398284958], 
             UndirectedEdge[176, 475] -> 
             RGBColor[
              0.3267310397254062, 0.4574197374557666, 0.9420399908277568], 
             UndirectedEdge[20, 474] -> 
             RGBColor[
              0.2356355428107931, 0.36499827402342566`, 0.9367304676203037], 
             UndirectedEdge[70, 483] -> 
             RGBColor[
              0.41089196681220996`, 0.5303157024471664, 0.9474026506811422], 
             UndirectedEdge[163, 266] -> 
             RGBColor[
              0.9464459539298948, 0.8121746039800857, 0.3903304044915068], 
             UndirectedEdge[69, 486] -> 
             RGBColor[
              0.4280953978994323, 0.5452164497853305, 0.9484988380976231], 
             UndirectedEdge[262, 475] -> 
             RGBColor[
              0.33984798179840503`, 0.4687809734027203, 0.9428757907777918], 
             UndirectedEdge[18, 167] -> 
             RGBColor[
              0.2640882538669924, 0.39490387734956656`, 0.9383508074229403], 
             UndirectedEdge[281, 374] -> 
             RGBColor[
              0.8329341118682944, 0.254151592405362, 0.1791710487598251], 
             UndirectedEdge[138, 294] -> 
             RGBColor[
              0.18513103991648983`, 0.3119148393110808, 0.9338543108951896], 
             UndirectedEdge[291, 349] -> 
             RGBColor[
              0.1841373062547167, 0.310870362226204, 0.9337977192332487], 
             UndirectedEdge[288, 455] -> 
             RGBColor[
              0.6621340048611841, 0.7355343250121988, 0.9672660118228255], 
             UndirectedEdge[12, 459] -> 
             RGBColor[
              0.19425766410485237`, 0.3215074999944453, 0.9343740586410862], 
             UndirectedEdge[93, 305] -> 
             RGBColor[
              0.26659251557076086`, 0.3973687929461906, 0.9384995442473698], 
             UndirectedEdge[127, 184] -> 
             RGBColor[
              0.6864931860475436, 0.7535560913976342, 0.970424092580223], 
             UndirectedEdge[204, 431] -> 
             RGBColor[
              0.36857757870000185`, 0.49366510624735727`, 0.9447064152877764],
              UndirectedEdge[397, 495] -> 
             RGBColor[
              0.8540509182502993, 0.3729173999622112, 0.19768732648561016`], 
             UndirectedEdge[28, 493] -> 
             RGBColor[
              0.36837307735021396`, 0.48845315530283206`, 0.9450243190265064],
              UndirectedEdge[267, 485] -> 
             RGBColor[
              0.24230090955609868`, 0.3720039970814022, 0.9371100503959223], 
             UndirectedEdge[110, 494] -> 
             RGBColor[
              0.3861892329590033, 0.5089194359790232, 0.9458286143237857], 
             UndirectedEdge[337, 500] -> 
             RGBColor[
              0.1950373272242134, 0.32232697536639066`, 0.9344184593023257], 
             UndirectedEdge[43, 393] -> 
             RGBColor[
              0.2248422553763207, 0.3536538445958466, 0.9361158058681482], 
             UndirectedEdge[167, 432] -> 
             RGBColor[
              0.2655480887278028, 0.39643825634715435`, 0.9384339428586312], 
             UndirectedEdge[230, 474] -> 
             RGBColor[
              0.21770593124316456`, 0.3461531154628161, 0.9357094027660106], 
             UndirectedEdge[40, 421] -> 
             RGBColor[
              0.18467273781712776`, 0.31143313474661993`, 0.933828211268628], 
             UndirectedEdge[254, 476] -> 
             RGBColor[
              0.18792976264725234`, 0.31485647435038233`, 0.9340136940143672],
              UndirectedEdge[107, 197] -> 
             RGBColor[
              0.221090097802618, 0.3497100890853544, 0.9359021260451457], 
             UndirectedEdge[231, 395] -> 
             RGBColor[
              0.6338994865668826, 0.711809040751297, 0.9655924600995638], 
             UndirectedEdge[420, 427] -> 
             RGBColor[
              0.1872793778515779, 0.31417287869335075`, 0.9339766555624116], 
             UndirectedEdge[317, 374] -> 
             RGBColor[
              0.832381649136102, 0.24990512175501872`, 0.1786420098235603], 
             UndirectedEdge[188, 200] -> 
             RGBColor[
              0.24347605986022197`, 0.37323915455986845`, 0.937176973467263], 
             UndirectedEdge[84, 260] -> 
             RGBColor[
              0.24263313262389596`, 0.37235318458981626`, 0.9371289700081534],
              UndirectedEdge[33, 160] -> 
             RGBColor[
              0.24786010554572385`, 0.3778470645398819, 0.937426638383438], 
             UndirectedEdge[135, 362] -> 
             RGBColor[
              0.1796163784049865, 0.3061185804127562, 0.9335402590803201], 
             UndirectedEdge[123, 193] -> 
             RGBColor[
              0.18338517057960285`, 0.31007981994350325`, 0.9337548862192361],
              UndirectedEdge[439, 453] -> 
             RGBColor[
              0.21958035723127328`, 0.3481232560217902, 0.9358161485530685], 
             UndirectedEdge[269, 282] -> 
             RGBColor[
              0.6492936360498982, 0.7253322095338435, 0.966103200750267], 
             UndirectedEdge[202, 459] -> 
             RGBColor[
              0.19062008977227754`, 0.3176841787353756, 0.9341669041641552], 
             UndirectedEdge[25, 474] -> 
             RGBColor[
              0.2592041913656412, 0.3897704179931982, 0.9380726672888113], 
             UndirectedEdge[103, 259] -> 
             RGBColor[
              0.5465386609637427, 0.6409354738239997, 0.9581996401022647], 
             UndirectedEdge[352, 375] -> 
             RGBColor[
              0.19306738802691092`, 0.32025644436866674`, 0.9343062741793031],
              UndirectedEdge[300, 308] -> 
             RGBColor[
              0.21138383769744212`, 0.33950819430237933`, 0.9353493688912808],
              UndirectedEdge[32, 328] -> 
             RGBColor[
              0.23132945208889125`, 0.36047229965278604`, 0.9364852421239818],
              UndirectedEdge[209, 486] -> 
             RGBColor[
              0.7039053523851265, 0.7622075647598039, 0.8443835196310663], 
             UndirectedEdge[118, 496] -> 
             RGBColor[
              0.18901315212113398`, 0.315995185378292, 0.9340753914421738], 
             UndirectedEdge[31, 405] -> 
             RGBColor[
              0.18682010932019663`, 0.3136901583475623, 0.9339505008989764], 
             UndirectedEdge[21, 228] -> 
             RGBColor[
              0.2791097474798408, 0.4106924195543743, 0.9392062592618835], 
             UndirectedEdge[92, 250] -> 
             RGBColor[
              0.24579035153480303`, 0.3756716218444204, 0.9373087689544427], 
             UndirectedEdge[177, 290] -> 
             RGBColor[
              0.1829544926129004, 0.3096271500939387, 0.9337303597461633], 
             UndirectedEdge[9, 333] -> 
             RGBColor[
              0.21279008452790313`, 0.3409862488823926, 0.9354294525679199], 
             UndirectedEdge[11, 444] -> 
             RGBColor[
              0.4707188799474499, 0.5790788770403041, 0.9520591203545818], 
             UndirectedEdge[11, 25] -> 
             RGBColor[
              0.3322342574825351, 0.46035097441527295`, 0.9424578530175007], 
             UndirectedEdge[168, 338] -> 
             RGBColor[
              0.35852241644491945`, 0.4834734222788186, 0.944119987452004], 
             UndirectedEdge[283, 430] -> 
             RGBColor[
              0.19193681077273775`, 0.31906813599179257`, 0.9342418894772171],
              UndirectedEdge[139, 410] -> 
             RGBColor[
              0.18242378949369925`, 0.3090693474671371, 0.9337001369886297], 
             UndirectedEdge[195, 260] -> 
             RGBColor[
              0.1989228362357199, 0.32641089169298415`, 0.9346397332924354], 
             UndirectedEdge[391, 407] -> 
             RGBColor[
              0.3751221590981358, 0.49587301171236503`, 0.9453789816308452], 
             UndirectedEdge[33, 111] -> 
             RGBColor[
              0.3114314409456971, 0.4393163564982453, 0.9412427561367012], 
             UndirectedEdge[2, 114] -> 
             RGBColor[
              0.1828144030828347, 0.30947990711565043`, 0.93372238185467], 
             UndirectedEdge[101, 306] -> 
             RGBColor[
              0.24294061497845892`, 0.37267636803996923`, 0.9371464806733664],
              UndirectedEdge[264, 374] -> 
             RGBColor[
              0.8564940987621058, 0.42401565884056125`, 0.20129244608671454`],
              UndirectedEdge[172, 235] -> 
             RGBColor[
              0.22030500109104192`, 0.3488849026634814, 0.9358574159488678], 
             UndirectedEdge[84, 475] -> 
             RGBColor[
              0.3060220283144641, 0.4364102420981715, 0.9408329262010071], 
             UndirectedEdge[37, 397] -> 
             RGBColor[
              0.8419322626018511, 0.3178894150465442, 0.18757522315711248`], 
             UndirectedEdge[228, 287] -> 
             RGBColor[
              0.28118525934636124`, 0.41287391412114016`, 0.9393244565922372],
              UndirectedEdge[68, 375] -> 
             RGBColor[
              0.19408512083298096`, 0.3213261460758332, 0.9343642325570081], 
             UndirectedEdge[197, 236] -> 
             RGBColor[
              0.21962655292817068`, 0.3481718106282057, 0.9358187793296664], 
             UndirectedEdge[107, 214] -> 
             RGBColor[
              0.19941582681621922`, 0.32692905605049705`, 0.9346678083766806],
              UndirectedEdge[207, 317] -> 
             RGBColor[
              0.8461530053131936, 0.3296770187137239, 0.19080821806446593`], 
             UndirectedEdge[98, 462] -> 
             RGBColor[
              0.18918443929913709`, 0.3161752190626076, 0.9340851459935643], 
             UndirectedEdge[21, 59] -> 
             RGBColor[
              0.2814993677631707, 0.4132040619828309, 0.9393423446018928], 
             UndirectedEdge[46, 350] -> 
             RGBColor[
              0.1926173329949277, 0.3197834079949152, 0.9342806442110285], 
             UndirectedEdge[271, 429] -> 
             RGBColor[
              0.200022442914419, 0.32756664803138713`, 0.9347023542660651], 
             UndirectedEdge[304, 423] -> 
             RGBColor[
              0.1849544721508512, 0.3117292553943517, 0.9338442556221451], 
             UndirectedEdge[299, 328] -> 
             RGBColor[
              0.24152994730330735`, 0.3711936668718884, 0.9370661452361624], 
             UndirectedEdge[55, 73] -> 
             RGBColor[
              0.5752457926482104, 0.6660494748562806, 0.9597046024734881], 
             UndirectedEdge[53, 440] -> 
             RGBColor[
              0.8621535838667478, 0.42648384520047466`, 0.20510522227510283`],
              UndirectedEdge[206, 377] -> 
             RGBColor[
              0.18060293034985866`, 0.30715550905782296`, 0.9335964417541076],
              UndirectedEdge[39, 113] -> 
             RGBColor[
              0.2221538791632596, 0.3508281907430225, 0.9359627068199107], 
             UndirectedEdge[9, 450] -> 
             RGBColor[
              0.20465923888359105`, 0.3324402145848314, 0.9349664129369846], 
             UndirectedEdge[61, 321] -> 
             RGBColor[
              0.9878470936878512, 0.9892424751715496, 0.8510686385130581], 
             UndirectedEdge[76, 460] -> 
             RGBColor[
              0.35555086797246704`, 0.4816356758279989, 0.9439036922676769], 
             UndirectedEdge[141, 167] -> 
             RGBColor[
              0.22358607838206196`, 0.35233352292865905`, 0.9360442684466725],
              UndirectedEdge[29, 476] -> 
             RGBColor[
              0.18392969470854525`, 0.3106521493278456, 0.933785896062828], 
             UndirectedEdge[39, 190] -> 
             RGBColor[
              0.23206747524414745`, 0.361248008782331, 0.9365272714508661], 
             UndirectedEdge[115, 215] -> 
             RGBColor[
              0.18797465353578718`, 0.3149036575204792, 0.9340162504840592], 
             UndirectedEdge[208, 471] -> 
             RGBColor[
              0.6917256837597572, 0.7556316908196963, 0.953176466827428], 
             UndirectedEdge[139, 401] -> 
             RGBColor[
              0.18166335927375138`, 0.3082700870919113, 0.9336568316125594], 
             UndirectedEdge[34, 356] -> 
             RGBColor[
              0.22712257342383618`, 0.3560506034443001, 0.9362456666075261], 
             UndirectedEdge[288, 313] -> 
             RGBColor[
              0.5362219144016962, 0.6308125527023426, 0.9580446920208532], 
             UndirectedEdge[66, 334] -> 
             RGBColor[
              0.19236874220933842`, 0.3195221233176947, 0.9342664873335462], 
             UndirectedEdge[17, 328] -> 
             RGBColor[
              0.30921498256740126`, 0.43616829316491434`, 0.9411464986611078],
              UndirectedEdge[318, 459] -> 
             RGBColor[
              0.1962304097370451, 0.3235809807331772, 0.934486403586424], 
             UndirectedEdge[163, 233] -> 
             RGBColor[
              0.9309329686428551, 0.8036306761921264, 0.5929788217369941], 
             UndirectedEdge[141, 300] -> 
             RGBColor[
              0.21958614921582648`, 0.3481293437647886, 0.9358164783980203], 
             UndirectedEdge[354, 436] -> 
             RGBColor[
              0.33305431044836165`, 0.46289663673916315`, 0.9424429040467747],
              UndirectedEdge[29, 290] -> 
             RGBColor[
              0.18297797671513846`, 0.309651833374369, 0.9337316971310441], 
             UndirectedEdge[110, 360] -> 
             RGBColor[
              0.5066197555658096, 0.6093517092932348, 0.9545740073553726], 
             UndirectedEdge[289, 308] -> 
             RGBColor[
              0.20048868170692968`, 0.3280566945635627, 0.9347289058755601], 
             UndirectedEdge[264, 324] -> 
             RGBColor[
              0.9026383334956752, 0.7184607257731993, 0.5982098779593608], 
             UndirectedEdge[109, 382] -> 
             RGBColor[
              0.2128528625805422, 0.3410522325960747, 0.9354330276851459], 
             UndirectedEdge[293, 497] -> 
             RGBColor[
              0.6439655477048442, 0.7192750682039972, 0.9668676305891115], 
             UndirectedEdge[160, 237] -> 
             RGBColor[
              0.23616950031855627`, 0.3655594972189461, 0.9367608757104513], 
             UndirectedEdge[35, 123] -> 
             RGBColor[
              0.18674780810963457`, 0.3136141651911, 0.933946383451995], 
             UndirectedEdge[218, 432] -> 
             RGBColor[
              0.28855483307734864`, 0.4206198033703701, 0.9397441429139097], 
             UndirectedEdge[46, 476] -> 
             RGBColor[
              0.1935701933686142, 0.32078492466249675`, 0.9343349081996792], 
             UndirectedEdge[288, 391] -> 
             RGBColor[
              0.5921690661844405, 0.6787336359098497, 0.9617581155601771], 
             UndirectedEdge[259, 486] -> 
             RGBColor[
              0.5483039124595994, 0.6424644459455908, 0.95831212036663], 
             UndirectedEdge[138, 296] -> 
             RGBColor[
              0.18249965208881352`, 0.3091490838645686, 0.9337044572511928], 
             UndirectedEdge[56, 494] -> 
             RGBColor[
              0.38107496711151867`, 0.5044897159524077, 0.9455027378263516], 
             UndirectedEdge[91, 200] -> 
             RGBColor[
              0.3616498178113511, 0.4832425921885635, 0.9444724938641782], 
             UndirectedEdge[172, 493] -> 
             RGBColor[
              0.24219838800103033`, 0.3718962404267834, 0.9371042119450282], 
             UndirectedEdge[340, 461] -> 
             RGBColor[
              0.30853231078714655`, 0.43652792912541416`, 0.9410681811421904],
              UndirectedEdge[33, 274] -> 
             RGBColor[
              0.25017787666220814`, 0.38028318893848334`, 0.9375586320196867],
              UndirectedEdge[235, 345] -> 
             RGBColor[
              0.20397947873922884`, 0.3317257435738243, 0.934927701602378], 
             UndirectedEdge[205, 490] -> 
             RGBColor[
              0.22672461704495903`, 0.3556323260582085, 0.9362230035804727], 
             UndirectedEdge[141, 284] -> 
             RGBColor[
              0.20706959880896725`, 0.33497365569204784`, 0.9351036793689267],
              UndirectedEdge[489, 500] -> 
             RGBColor[
              0.19630488377124938`, 0.3236592576650523, 0.9344906447724974], 
             UndirectedEdge[155, 198] -> 
             RGBColor[
              0.1881672276861966, 0.31510606516246586`, 0.934027217297037], 
             UndirectedEdge[23, 157] -> 
             RGBColor[
              0.36552292420320903`, 0.49012707749646917`, 0.944544444701912], 
             UndirectedEdge[248, 344] -> 
             RGBColor[
              0.18527438940385826`, 0.31206550871118754`, 0.9338624744364286],
              UndirectedEdge[50, 131] -> 
             RGBColor[
              0.8570462990670573, 0.5838526913273292, 0.5841917648474512], 
             UndirectedEdge[442, 500] -> 
             RGBColor[
              0.21944649774055142`, 0.34798256120985954`, 0.9358085254530993],
              UndirectedEdge[18, 305] -> 
             RGBColor[
              0.2994340109078254, 0.43188728681651606`, 0.9403698188221772], 
             UndirectedEdge[134, 278] -> 
             RGBColor[
              0.18429769316254274`, 0.3110389390354465, 0.9338068530303782], 
             UndirectedEdge[158, 422] -> 
             RGBColor[
              0.19912370802149765`, 0.3266220206758434, 0.9346511726434723], 
             UndirectedEdge[229, 393] -> 
             RGBColor[
              0.2280783028843851, 0.35705513570408476`, 0.9363000939864292], 
             UndirectedEdge[17, 143] -> 
             RGBColor[
              0.4780476426696782, 0.5850251620356237, 0.9526370440612968], 
             UndirectedEdge[53, 83] -> 
             RGBColor[
              0.9139507635332944, 0.6222257740273145, 0.45384466479453006`], 
             UndirectedEdge[166, 239] -> 
             RGBColor[
              0.19616306235610437`, 0.3235101943657379, 0.9344825682527109], 
             UndirectedEdge[46, 194] -> 
             RGBColor[
              0.19490869460205182`, 0.32219177432471957`, 0.9344111338647885],
              UndirectedEdge[319, 368] -> 
             RGBColor[
              0.18004736950714773`, 0.30657157938754187`, 0.9335648033859939],
              UndirectedEdge[51, 360] -> 
             RGBColor[
              0.7957080349438885, 0.8376426800925825, 0.8429962638681049], 
             UndirectedEdge[132, 250] -> 
             RGBColor[
              0.24597806511608875`, 0.3758689207200801, 0.9373194589651996], 
             UndirectedEdge[80, 447] -> 
             RGBColor[
              0.2905728038348803, 0.41916551040000816`, 0.9399899729099002], 
             UndirectedEdge[128, 179] -> 
             RGBColor[
              0.19718406775789482`, 0.32458333577850107`, 0.9345407129999008],
              UndirectedEdge[218, 300] -> 
             RGBColor[
              0.25886995308296373`, 0.3894191123661732, 0.938053632913074], 
             UndirectedEdge[130, 241] -> 
             RGBColor[
              0.2592745192308342, 0.38984433703856036`, 0.9380766723566932], 
             UndirectedEdge[134, 252] -> 
             RGBColor[
              0.18321908491971373`, 0.3099052533845207, 0.9337454278866071], 
             UndirectedEdge[266, 317] -> 
             RGBColor[
              0.9054511863291719, 0.561405403936883, 0.35359294828676574`], 
             UndirectedEdge[156, 485] -> 
             RGBColor[
              0.22736985486258326`, 0.3563105119149721, 0.9362597489196426], 
             UndirectedEdge[96, 110] -> 
             RGBColor[
              0.443925135446012, 0.558453392319533, 0.9496384572015815], 
             UndirectedEdge[50, 373] -> 
             RGBColor[
              0.9356814566362912, 0.9489939738190079, 0.8936373423891573], 
             UndirectedEdge[37, 322] -> 
             RGBColor[
              0.8413185031158885, 0.3131717906863145, 0.18698748638021256`], 
             UndirectedEdge[65, 290] -> 
             RGBColor[
              0.18235293121758706`, 0.308994870926269, 0.9336961017146306], 
             UndirectedEdge[333, 450] -> 
             RGBColor[
              0.22365738515605757`, 0.35240847086923904`, 0.9360483292619628],
              UndirectedEdge[238, 266] -> 
             RGBColor[
              0.7401362180244184, 0.7914194702417209, 0.7478504944629321], 
             UndirectedEdge[312, 446] -> 
             RGBColor[
              0.18918799273524178`, 0.31617895394925455`, 0.9340853483564936],
              UndirectedEdge[407, 448] -> 
             RGBColor[
              0.28885681920654693`, 0.42093720993918393`, 0.9397613405772192],
              UndirectedEdge[14, 454] -> 
             RGBColor[
              0.2211862721127522, 0.34981117438310894`, 0.9359076030298306], 
             UndirectedEdge[77, 473] -> 
             RGBColor[
              0.2990309117164457, 0.42925265730827966`, 0.9404278165088418], 
             UndirectedEdge[57, 136] -> 
             RGBColor[
              0.7454315064099696, 0.7997658817940283, 0.9520631322982614], 
             UndirectedEdge[364, 487] -> 
             RGBColor[
              0.19856599617315254`, 0.3260358301622591, 0.9346194117787698], 
             UndirectedEdge[80, 403] -> 
             RGBColor[
              0.5454124576914773, 0.6374059872808763, 0.9592088642229862], 
             UndirectedEdge[330, 352] -> 
             RGBColor[
              0.1864863756783814, 0.3133393831300794, 0.9339314952617896], 
             UndirectedEdge[239, 272] -> 
             RGBColor[
              0.22693559422031087`, 0.3558540764462288, 0.9362350184184962], 
             UndirectedEdge[53, 97] -> 
             RGBColor[
              0.910565728681441, 0.6124407745650613, 0.29428992901066414`], 
             UndirectedEdge[304, 311] -> 
             RGBColor[
              0.19034681505715081`, 0.3173969496831598, 0.9341513415734024], 
             UndirectedEdge[237, 241] -> 
             RGBColor[
              0.2242600552960576, 0.35304191539787294`, 0.9360826504348652], 
             UndirectedEdge[361, 441] -> 
             RGBColor[
              0.22578416559546857`, 0.3546438519567282, 0.9361694462616974], 
             UndirectedEdge[276, 347] -> 
             RGBColor[
              0.20833762491305394`, 0.33630643152494155`, 0.935175891579678], 
             UndirectedEdge[11, 180] -> 
             RGBColor[
              0.31935935180321817`, 0.4468186322301426, 0.9417246461857798], 
             UndirectedEdge[56, 360] -> 
             RGBColor[
              0.501505489718325, 0.6049219892666192, 0.9542481308579387], 
             UndirectedEdge[15, 269] -> 
             RGBColor[
              0.6271401903527347, 0.708025769382796, 0.9638951523188943], 
             UndirectedEdge[8, 387] -> 
             RGBColor[
              0.19318868595476607`, 0.32038393618157524`, 0.9343131819168503],
              UndirectedEdge[139, 278] -> 
             RGBColor[
              0.18353174179525936`, 0.31023387558431004`, 0.933763233233135], 
             UndirectedEdge[15, 449] -> 
             RGBColor[
              0.8180065894164226, 0.8423738625918746, 0.678402399648858], 
             UndirectedEdge[348, 355] -> 
             RGBColor[
              0.5108951424447806, 0.6138067180573811, 0.9546386835652754], 
             UndirectedEdge[173, 499] -> 
             RGBColor[
              0.6745850298425644, 0.7454990333041416, 0.9683443785997534], 
             UndirectedEdge[130, 483] -> 
             RGBColor[
              0.3774799425420655, 0.5008371490852502, 0.9452933918504961], 
             UndirectedEdge[173, 282] -> 
             RGBColor[
              0.7086553123271468, 0.7723261830606026, 0.9715957968385069], 
             UndirectedEdge[84, 244] -> 
             RGBColor[
              0.3611185636561085, 0.4841320917787186, 0.9443436287130234], 
             UndirectedEdge[183, 279] -> 
             RGBColor[
              0.202473790723394, 0.3301431700030478, 0.9348419548973421], 
             UndirectedEdge[124, 381] -> 
             RGBColor[
              0.18683393328431724`, 0.31370468821034303`, 0.9339512881532823],
              UndirectedEdge[81, 213] -> 
             RGBColor[
              0.2202872137263247, 0.3488662070153795, 0.9358564029847612], 
             UndirectedEdge[134, 210] -> 
             RGBColor[
              0.18982747480213708`, 0.31685109014706625`, 0.9341217659141743],
              UndirectedEdge[103, 275] -> 
             RGBColor[
              0.4495582322834861, 0.5628291466682479, 0.9501364705331162], 
             UndirectedEdge[256, 298] -> 
             RGBColor[
              0.2936230158270692, 0.42568683963093007`, 0.9400422862891433], 
             UndirectedEdge[18, 235] -> 
             RGBColor[
              0.2527156376053866, 0.3829505365931011, 0.9377031537511198], 
             UndirectedEdge[255, 334] -> 
             RGBColor[
              0.19201279446501912`, 0.3191479996700246, 0.9342462166360848], 
             UndirectedEdge[209, 372] -> 
             RGBColor[
              0.8043736512463036, 0.8448578989108925, 0.8519927857243978], 
             UndirectedEdge[112, 238] -> 
             RGBColor[
              0.7400652706680888, 0.7928555147204785, 0.8555441529553656], 
             UndirectedEdge[360, 457] -> 
             RGBColor[
              0.5327073882194472, 0.6315148818077295, 0.9563558234535461], 
             UndirectedEdge[233, 404] -> 
             RGBColor[
              0.8996921742722623, 0.9221615303078283, 0.9662816131668808], 
             UndirectedEdge[259, 348] -> 
             RGBColor[
              0.5726768344196096, 0.6633371250706486, 0.9599308796437516], 
             UndirectedEdge[244, 376] -> 
             RGBColor[
              0.40891528656398646`, 0.5286036013669932, 0.947276698363635], 
             UndirectedEdge[182, 371] -> 
             RGBColor[
              0.29953966949074173`, 0.42881389719709484`, 0.9404924339976882],
              UndirectedEdge[21, 77] -> 
             RGBColor[
              0.3172353767281449, 0.44838670426532234`, 0.9414645338601655], 
             UndirectedEdge[153, 493] -> 
             RGBColor[
              0.24427091854425903`, 0.3740746014337428, 0.9372222394934309], 
             UndirectedEdge[276, 382] -> 
             RGBColor[
              0.21283416100439742`, 0.3410325760537981, 0.935431962658051], 
             UndirectedEdge[80, 219] -> 
             RGBColor[
              0.508471196315639, 0.6085471931300863, 0.9555269045247576], 
             UndirectedEdge[60, 136] -> 
             RGBColor[
              0.7568575398761165, 0.8080712748113279, 0.923043362246632], 
             UndirectedEdge[23, 96] -> 
             RGBColor[
              0.4513622669101063, 0.5648950617926353, 0.9501123446420765], 
             UndirectedEdge[53, 281] -> 
             RGBColor[
              0.8255492937831006, 0.19738864455464403`, 0.17209933862148452`],
              UndirectedEdge[141, 162] -> 
             RGBColor[
              0.19531753931264573`, 0.32262149603780554`, 0.9344344169662252],
              UndirectedEdge[28, 149] -> 
             RGBColor[
              0.5184855433089055, 0.6199689474225398, 0.9552362277258538], 
             UndirectedEdge[37, 317] -> 
             RGBColor[
              0.839586880193451, 0.2998617781024568, 0.18532928231409804`], 
             UndirectedEdge[372, 486] -> 
             RGBColor[
              0.5138028974550533, 0.6150817214772912, 0.955167559111667], 
             UndirectedEdge[63, 453] -> 
             RGBColor[
              0.2233707740920417, 0.35210722446876735`, 0.9360320071858701], 
             UndirectedEdge[82, 242] -> 
             RGBColor[
              0.7466175241184303, 0.8003829212442619, 0.9428810481338523], 
             UndirectedEdge[4, 191] -> 
             RGBColor[
              0.18605432886244289`, 0.31288527453317777`, 0.933906890834778], 
             UndirectedEdge[70, 403] -> 
             RGBColor[
              0.5565760155932599, 0.6470753000386655, 0.9599201962609412], 
             UndirectedEdge[144, 458] -> 
             RGBColor[
              0.21795043797046626`, 0.346410107535832, 0.935723327062415], 
             UndirectedEdge[16, 224] -> 
             RGBColor[
              0.23802549514267946`, 0.3675102654559681, 0.9368665718699869], 
             UndirectedEdge[40, 206] -> 
             RGBColor[
              0.18271148860033518`, 0.3093717374693884, 0.9337165210271399], 
             UndirectedEdge[148, 485] -> 
             RGBColor[
              0.26499013859378384`, 0.39585181538021874`, 0.9384021684239121],
              UndirectedEdge[34, 291] -> 
             RGBColor[
              0.19600418397695138`, 0.323343203115777, 0.9344735203640577], 
             UndirectedEdge[222, 339] -> 
             RGBColor[
              0.1886442457825459, 0.3156074414264231, 0.9340543827719392], 
             UndirectedEdge[197, 314] -> 
             RGBColor[
              0.24685083225448304`, 0.3767862543191651, 0.9373691617625879], 
             UndirectedEdge[330, 358] -> 
             RGBColor[
              0.20723187960885475`, 0.33514422310192665`, 0.9351129210204074],
              UndirectedEdge[312, 415] -> 
             RGBColor[
              0.18768399799751473`, 0.31459816012112934`, 0.9339996980811409],
              UndirectedEdge[370, 443] -> 
             RGBColor[
              0.2582982777745515, 0.38881824537072385`, 0.9380210768499777], 
             UndirectedEdge[160, 305] -> 
             RGBColor[
              0.2750017432650342, 0.40620742442870245`, 0.938978437324221], 
             UndirectedEdge[266, 343] -> 
             RGBColor[
              0.9199069923129997, 0.6725190633031569, 0.3674358444223769], 
             UndirectedEdge[47, 468] -> 
             RGBColor[
              0.25155549363265645`, 0.38173115172038535`, 0.9376370852681521],
              UndirectedEdge[388, 436] -> 
             RGBColor[
              0.34210441687378856`, 0.470735384053293, 0.943019568825508], 
             UndirectedEdge[69, 209] -> 
             RGBColor[
              0.7186661516906826, 0.7749926272189318, 0.8453240647103539], 
             UndirectedEdge[197, 470] -> 
             RGBColor[
              0.2127537879512197, 0.3409480988789625, 0.9354273855315738], 
             UndirectedEdge[13, 298] -> 
             RGBColor[
              0.26431690444041933`, 0.3951442035995219, 0.9383638287348387], 
             UndirectedEdge[168, 383] -> 
             RGBColor[
              0.2802434761765292, 0.4118840402971449, 0.9392708234339586], 
             UndirectedEdge[123, 428] -> 
             RGBColor[
              0.18681025928894113`, 0.3136798053401847, 0.9339499399542682], 
             UndirectedEdge[137, 485] -> 
             RGBColor[
              0.2335003285987162, 0.3627540285061326, 0.9366088703296922], 
             UndirectedEdge[394, 467] -> 
             RGBColor[
              0.18730056337306505`, 0.3141951460196734, 0.9339778620465191], 
             UndirectedEdge[232, 395] -> 
             RGBColor[
              0.3913003181998807, 0.5091662530135891, 0.9466381048606165], 
             UndirectedEdge[414, 461] -> 
             RGBColor[
              0.337969115719834, 0.4620246100212727, 0.9429438683225567], 
             UndirectedEdge[224, 333] -> 
             RGBColor[
              0.21886126221320776`, 0.3473674415645458, 0.9357751971555954], 
             UndirectedEdge[33, 182] -> 
             RGBColor[
              0.300634259036329, 0.42996438021049266`, 0.9405547692530093], 
             UndirectedEdge[158, 451] -> 
             RGBColor[
              0.19839700824460316`, 0.32585821313490027`, 0.9346097881662341],
              UndirectedEdge[235, 274] -> 
             RGBColor[
              0.23060114107907964`, 0.35970679860388893`, 0.9364437658894125],
              UndirectedEdge[284, 345] -> 
             RGBColor[
              0.19883561542773992`, 0.32631921709367856`, 0.9346347661964527],
              UndirectedEdge[70, 238] -> 
             RGBColor[
              0.4282161029443493, 0.5444148958180487, 0.9487568881673315], 
             UndirectedEdge[21, 55] -> 
             RGBColor[
              0.4367980074447999, 0.5486800919411015, 0.9499852964304927], 
             UndirectedEdge[55, 60] -> 
             RGBColor[
              0.7795430416292072, 0.8264883871046946, 0.9248292480443663], 
             UndirectedEdge[219, 258] -> 
             RGBColor[
              0.5423535654058886, 0.6378943982586738, 0.9576858591221857], 
             UndirectedEdge[175, 463] -> 
             RGBColor[
              0.476418269168048, 0.5843060667913316, 0.9523419687164218], 
             UndirectedEdge[101, 431] -> 
             RGBColor[
              0.33318158758536665`, 0.45712340432410575`, 0.9426664368181881],
              UndirectedEdge[14, 213] -> 
             RGBColor[
              0.21659885926136652`, 0.3449895126175285, 0.9356463566544133], 
             UndirectedEdge[378, 487] -> 
             RGBColor[
              0.1998521204053707, 0.32738762827530654`, 0.9346926546511444], 
             UndirectedEdge[8, 159] -> 
             RGBColor[
              0.21480140592500557`, 0.34310027519588937`, 0.9355439943460016],
              UndirectedEdge[311, 469] -> 
             RGBColor[
              0.18566856806308635`, 0.31247981547440673`, 0.9338849223279366],
              UndirectedEdge[343, 440] -> 
             RGBColor[
              0.8689315587996673, 0.47858233066244793`, 0.21159581872549427`],
              UndirectedEdge[371, 460] -> 
             RGBColor[
              0.2773778998424177, 0.4088721378819603, 0.9391076331009713], 
             UndirectedEdge[224, 358] -> 
             RGBColor[
              0.21540867556861554`, 0.34373855409444265`, 0.9355785774538301],
              UndirectedEdge[455, 475] -> 
             RGBColor[
              0.47478660322499994`, 0.5813210731496465, 0.9526722731511402], 
             UndirectedEdge[310, 408] -> 
             RGBColor[
              0.7910483812120712, 0.837599492064294, 0.9781391837091735], 
             UndirectedEdge[154, 376] -> 
             RGBColor[
              0.6772879972861523, 0.7415239884313045, 0.9288688968046623], 
             UndirectedEdge[282, 499] -> 
             RGBColor[
              0.6626431389741363, 0.7361699373959933, 0.9671541225213036], 
             UndirectedEdge[14, 192] -> 
             RGBColor[
              0.27198473276549623`, 0.40281125955144237`, 0.9388148648903828],
              UndirectedEdge[75, 147] -> 
             RGBColor[
              0.842199332426149, 0.3144945905899744, 0.187617653595973], 
             UndirectedEdge[175, 351] -> 
             RGBColor[
              0.3189338999580072, 0.4443278119995411, 0.9417752451272612], 
             UndirectedEdge[109, 205] -> 
             RGBColor[
              0.22555863330001114`, 0.354406803214629, 0.9361566025311163], 
             UndirectedEdge[43, 148] -> 
             RGBColor[
              0.2515020287225457, 0.38167495670998786`, 0.9376340405206155], 
             UndirectedEdge[56, 92] -> 
             RGBColor[
              0.33939325721103675`, 0.46498406565042605`, 0.9429714183929231],
              UndirectedEdge[46, 412] -> 
             RGBColor[
              0.19698300619667852`, 0.32437200732962346`, 0.9345292628414335],
              UndirectedEdge[170, 214] -> 
             RGBColor[
              0.18764009951956995`, 0.31455202003748506`, 0.9339971981277639],
              UndirectedEdge[94, 437] -> 
             RGBColor[
              0.18042329707310156`, 0.30696670309454366`, 0.93358621190474], 
             UndirectedEdge[173, 249] -> 
             RGBColor[
              0.72377347409997, 0.7841366059398172, 0.9731026339167677], 
             UndirectedEdge[181, 302] -> 
             RGBColor[
              0.235139155224241, 0.3644765391971686, 0.9367021990815891], 
             UndirectedEdge[188, 279] -> 
             RGBColor[
              0.21597972805042376`, 0.3443387664596417, 0.9356110980478727], 
             UndirectedEdge[317, 471] -> 
             RGBColor[
              0.8870778332354172, 0.5507282185220981, 0.561083222125617], 
             UndirectedEdge[8, 344] -> 
             RGBColor[
              0.19388121074334685`, 0.3211118236429813, 0.9343526201790614], 
             UndirectedEdge[236, 493] -> 
             RGBColor[
              0.23463204109374153`, 0.36394353009312075`, 0.9366733196820654],
              UndirectedEdge[31, 366] -> 
             RGBColor[
              0.18726891335142604`, 0.3141618798402035, 0.9339760596246088], 
             UndirectedEdge[176, 261] -> 
             RGBColor[
              0.32311312036066653`, 0.4542860775439437, 0.941809460205036], 
             UndirectedEdge[144, 145] -> 
             RGBColor[
              0.20296158096381922`, 0.33065586847342227`, 0.9348697338299133],
              UndirectedEdge[144, 375] -> 
             RGBColor[
              0.1998107076045579, 0.3273441007959291, 0.9346902962534028], 
             UndirectedEdge[258, 293] -> 
             RGBColor[
              0.6124648264838737, 0.6926658482781156, 0.9646738943994533], 
             UndirectedEdge[242, 269] -> 
             RGBColor[
              0.787493374586991, 0.8335677780907182, 0.9460989448159113], 
             UndirectedEdge[45, 216] -> 
             RGBColor[
              0.20054621348510776`, 0.32811716411015324`, 0.9347321822252167],
              UndirectedEdge[82, 323] -> 
             RGBColor[
              0.7564161337880024, 0.8062755394340282, 0.8629204050270508], 
             UndirectedEdge[258, 272] -> 
             RGBColor[
              0.33620380123362575`, 0.46086126878688316`, 0.9428179945089592],
              UndirectedEdge[92, 356] -> 
             RGBColor[
              0.2586276684650108, 0.3891644558709726, 0.9380398351625095], 
             UndirectedEdge[114, 327] -> 
             RGBColor[
              0.18260674360457746`, 0.3092616438376308, 0.933710555954588], 
             UndirectedEdge[188, 459] -> 
             RGBColor[
              0.20922832641301886`, 0.3372426152751415, 0.9352266157124262], 
             UndirectedEdge[465, 469] -> 
             RGBColor[
              0.18020092681290795`, 0.30673297785199133`, 0.9335735482473893],
              UndirectedEdge[44, 62] -> 
             RGBColor[
              0.2651018322525842, 0.3959692124974049, 0.9384085292125448], 
             UndirectedEdge[88, 337] -> 
             RGBColor[
              0.18932246677623382`, 0.3163202946924838, 0.9340930064541916], 
             UndirectedEdge[253, 388] -> 
             RGBColor[
              0.3530902196198862, 0.48025073422946185`, 0.9437195744621254], 
             UndirectedEdge[80, 238] -> 
             RGBColor[
              0.4170525450425667, 0.5347455830602593, 0.9480455561293766], 
             UndirectedEdge[171, 272] -> 
             RGBColor[
              0.36396083467584234`, 0.48443119432275983`, 0.9447170138830936],
              UndirectedEdge[297, 392] -> 
             RGBColor[
              0.21605655176504493`, 0.3444195130546133, 0.9356154730447699], 
             UndirectedEdge[82, 499] -> 
             RGBColor[
              0.5743475030967551, 0.6653202029309262, 0.9596338858294544], 
             UndirectedEdge[297, 484] -> 
             RGBColor[
              0.1900371894005843, 0.3170715134867078, 0.934133708850311], 
             UndirectedEdge[73, 240] -> 
             RGBColor[
              0.785852186641644, 0.829344990984529, 0.8179383454805261], 
             UndirectedEdge[229, 263] -> 
             RGBColor[
              0.22958947316632627`, 0.3586434714841348, 0.9363861528984097], 
             UndirectedEdge[87, 91] -> 
             RGBColor[
              0.3843682357663767, 0.5071210898901892, 0.9457662741578293], 
             UndirectedEdge[296, 339] -> 
             RGBColor[
              0.18120773687102673`, 0.3077911990585188, 0.9336308845907572], 
             UndirectedEdge[62, 157] -> 
             RGBColor[
              0.27514441268901324`, 0.40652460127246764`, 0.9389804393117331],
              UndirectedEdge[227, 265] -> 
             RGBColor[
              0.18874076831201309`, 0.315708892724775, 0.9340598795871999], 
             UndirectedEdge[38, 127] -> 
             RGBColor[
              0.6754853554676021, 0.7446194386357212, 0.969557515833958], 
             UndirectedEdge[302, 451] -> 
             RGBColor[
              0.22492379054142386`, 0.35373954322399803`, 0.9361204491751804],
              UndirectedEdge[141, 151] -> 
             RGBColor[
              0.20551109996107267`, 0.3333355745883765, 0.9350149251651315], 
             UndirectedEdge[72, 439] -> 
             RGBColor[
              0.2051731991857032, 0.33298041944931656`, 0.9349956822158536], 
             UndirectedEdge[277, 340] -> 
             RGBColor[
              0.40350978000289583`, 0.523921623272436, 0.9469322642654641], 
             UndirectedEdge[53, 322] -> 
             RGBColor[
              0.8267284539733458, 0.20645218648815844`, 0.17322850375133425`],
              UndirectedEdge[450, 461] -> 
             RGBColor[
              0.23439908756698247`, 0.3636986811663903, 0.9366600533233402], 
             UndirectedEdge[352, 367] -> 
             RGBColor[
              0.1902708306368736, 0.3173170852397579, 0.9341470143730765], 
             UndirectedEdge[239, 251] -> 
             RGBColor[
              0.2177871872756262, 0.3462385207048633, 0.9357140301768516], 
             UndirectedEdge[83, 163] -> 
             RGBColor[
              0.9472677000831091, 0.8139798001662166, 0.4832298213140514], 
             UndirectedEdge[179, 245] -> 
             RGBColor[
              0.22201863728698465`, 0.35068604295622735`, 0.9359550049951293],
              UndirectedEdge[133, 237] -> 
             RGBColor[
              0.21543537025685555`, 0.3437666119043239, 0.9355800976768341], 
             UndirectedEdge[199, 244] -> 
             RGBColor[
              0.4164279851399622, 0.5351107232742938, 0.9477554008736777], 
             UndirectedEdge[173, 269] -> 
             RGBColor[
              0.6612355269183264, 0.7346613054419917, 0.9672934568287169], 
             UndirectedEdge[209, 379] -> 
             RGBColor[
              0.9109503146879699, 0.6018931108868748, 0.4575519033361274], 
             UndirectedEdge[139, 451] -> 
             RGBColor[
              0.19384306282883684`, 0.3210717277661138, 0.9343504477117648], 
             UndirectedEdge[18, 218] -> 
             RGBColor[
              0.2870949982165383, 0.4190854243727823, 0.9396610074782187], 
             UndirectedEdge[59, 287] -> 
             RGBColor[
              0.28357487962969113`, 0.41538555654959675`, 0.9394605419322465],
              UndirectedEdge[167, 274] -> 
             RGBColor[
              0.24197375734068546`, 0.3716601393603544, 0.9370914195612329], 
             UndirectedEdge[402, 461] -> 
             RGBColor[
              0.23570042936850655`, 0.3650664739096279, 0.9367341628137743], 
             UndirectedEdge[472, 488] -> 
             RGBColor[
              0.18283227953141887`, 0.3094986963965447, 0.933723399891971], 
             UndirectedEdge[227, 270] -> 
             RGBColor[
              0.18663641062037617`, 0.3134970793668807, 0.9339400395297794], 
             UndirectedEdge[124, 363] -> 
             RGBColor[
              0.1839911193885881, 0.3107167105611202, 0.9337893941074868], 
             UndirectedEdge[118, 195] -> 
             RGBColor[
              0.19015295783973063`, 0.31719319345639363`, 0.9341403016916563],
              UndirectedEdge[54, 154] -> 
             RGBColor[
              0.9864962902894889, 0.9885634492757301, 0.8680616670608778], 
             UndirectedEdge[313, 498] -> 
             RGBColor[
              0.5679033760595678, 0.6555623513374985, 0.9612024040388176], 
             UndirectedEdge[243, 283] -> 
             RGBColor[
              0.18944836976348856`, 0.3164526267147989, 0.934100176443059], 
             UndirectedEdge[302, 346] -> 
             RGBColor[
              0.343088083847486, 0.46567152269516504`, 0.9432988559850268], 
             UndirectedEdge[13, 477] -> 
             RGBColor[
              0.2253695367356543, 0.3542080507360753, 0.9361458337615195], 
             UndirectedEdge[140, 479] -> 
             RGBColor[
              0.18066625764504995`, 0.3072220700602514, 0.9336000481498845], 
             UndirectedEdge[174, 309] -> 
             RGBColor[
              0.18783655214367595`, 0.3147585042012363, 0.9340083858140811], 
             UndirectedEdge[299, 312] -> 
             RGBColor[
              0.21752114274095335`, 0.3459588910307243, 0.9356988793341796], 
             UndirectedEdge[215, 402] -> 
             RGBColor[
              0.2015459552318014, 0.3291679560732161, 0.9347891160387054], 
             UndirectedEdge[372, 400] -> 
             RGBColor[
              0.8020697769239993, 0.8439051876717503, 0.8901739454806034], 
             UndirectedEdge[29, 426] -> 
             RGBColor[
              0.18589315152803693`, 0.3127158669354839, 0.933897712024024], 
             UndirectedEdge[361, 481] -> 
             RGBColor[
              0.217684758794606, 0.34613086187697023`, 0.935708197026387], 
             UndirectedEdge[188, 335] -> 
             RGBColor[
              0.21717587938379926`, 0.3455959973513941, 0.9356792170967612], 
             UndirectedEdge[168, 443] -> 
             RGBColor[
              0.29027458230294984`, 0.42242736884487553`, 0.9398420800881666],
              UndirectedEdge[81, 500] -> 
             RGBColor[
              0.21967281078147302`, 0.34822043056494373`, 0.9358214136459797],
              UndirectedEdge[75, 310] -> 
             RGBColor[
              0.7550654921994678, 0.6018878314253746, 0.587281607852838], 
             UndirectedEdge[348, 444] -> 
             RGBColor[
              0.5139722729928065, 0.6163048712594199, 0.9548809265539167], 
             UndirectedEdge[262, 482] -> 
             RGBColor[
              0.3377696803255693, 0.46698085312541926`, 0.9427433632457125], 
             UndirectedEdge[83, 395] -> 
             RGBColor[
              0.749683946094778, 0.8003088116491959, 0.8414368525463194], 
             UndirectedEdge[26, 459] -> 
             RGBColor[
              0.18968759946741098`, 0.31670407230166076`, 0.9341138002207887],
              UndirectedEdge[186, 498] -> 
             RGBColor[
              0.8839547752105941, 0.9059796859731515, 0.7464098878256111], 
             UndirectedEdge[167, 284] -> 
             RGBColor[
              0.22334665832655862`, 0.3520818772702168, 0.9360306338287019], 
             UndirectedEdge[175, 359] -> 
             RGBColor[
              0.653601757432396, 0.7247826808114364, 0.9688966182964689], 
             UndirectedEdge[65, 484] -> 
             RGBColor[
              0.1839955650344703, 0.31072138321681264`, 0.9337896472804431], 
             UndirectedEdge[266, 322] -> 
             RGBColor[
              0.9071828092516094, 0.5747154165207407, 0.3552511523528803], 
             UndirectedEdge[210, 252] -> 
             RGBColor[
              0.1889152618740288, 0.3158922965219843, 0.9340698167374166], 
             UndirectedEdge[133, 271] -> 
             RGBColor[
              0.20303817120051487`, 0.3307363696682909, 0.9348740955305881], 
             UndirectedEdge[190, 467] -> 
             RGBColor[
              0.20384534758574807`, 0.33158476322710967`, 0.9349200630316166],
              UndirectedEdge[216, 481] -> 
             RGBColor[
              0.20259193459855807`, 0.33026734670659963`, 0.9348486830162546],
              UndirectedEdge[18, 406] -> 
             RGBColor[
              0.35240776193494094`, 0.47777048741806016`, 0.9437452593947762],
              UndirectedEdge[315, 364] -> 
             RGBColor[
              0.19390091491665387`, 0.32113253397844377`, 0.9343537423025814],
              UndirectedEdge[152, 464] -> 
             RGBColor[
              0.19334471949680462`, 0.32054793732735576`, 0.9343220677962385],
              UndirectedEdge[229, 280] -> 
             RGBColor[
              0.24415725813790062`, 0.37395513714017414`, 0.9372157667014342],
              UndirectedEdge[164, 259] -> 
             RGBColor[
              0.4996492818256195, 0.6003222503432779, 0.9552118903262334], 
             UndirectedEdge[238, 497] -> 
             RGBColor[
              0.4824356353537869, 0.5907020081147285, 0.9523982469164629], 
             UndirectedEdge[7, 478] -> 
             RGBColor[
              0.36083387288200847`, 0.48094610395474147`, 0.9445570026671483],
              UndirectedEdge[137, 227] -> 
             RGBColor[
              0.2024073413896048, 0.33007332754010427`, 0.9348381707060858], 
             UndirectedEdge[44, 157] -> 
             RGBColor[
              0.2890530721263536, 0.4211434842010545, 0.9397725168906719], 
             UndirectedEdge[105, 205] -> 
             RGBColor[
              0.21445329260995954`, 0.34273438603011697`, 0.9355241698076971],
              UndirectedEdge[305, 460] -> 
             RGBColor[
              0.3056141271073153, 0.43838298078417876`, 0.9407217672970755], 
             UndirectedEdge[330, 492] -> 
             RGBColor[
              0.1860947118976098, 0.3129277196635705, 0.9339091905888894], 
             UndirectedEdge[94, 123] -> 
             RGBColor[
              0.18238673674691558`, 0.30903040268098764`, 0.933698026889515], 
             UndirectedEdge[418, 444] -> 
             RGBColor[
              0.5211846971324379, 0.6221602420919774, 0.9554487150021684], 
             UndirectedEdge[203, 295] -> 
             RGBColor[
              0.9149334778554977, 0.6677110589938393, 0.5462140209685634], 
             UndirectedEdge[342, 485] -> 
             RGBColor[
              0.36582891890395064`, 0.48572268889805037`, 0.9448845663511518],
              UndirectedEdge[279, 430] -> 
             RGBColor[
              0.2047694881993928, 0.33255609360594945`, 0.9349726914724201], 
             UndirectedEdge[391, 448] -> 
             RGBColor[
              0.38684939186323586`, 0.5081990768979878, 0.9460468301879315], 
             UndirectedEdge[174, 252] -> 
             RGBColor[
              0.18489202158224743`, 0.3116636158871544, 0.9338406991546504], 
             UndirectedEdge[14, 489] -> 
             RGBColor[
              0.2113006394017466, 0.3394207476185267, 0.935344630871422], 
             UndirectedEdge[6, 158] -> 
             RGBColor[
              0.20305085818934585`, 0.33074970449795377`, 0.9348748180358333],
              UndirectedEdge[201, 493] -> 
             RGBColor[
              0.2591781892002248, 0.38974308806871316`, 0.9380711865039575], 
             UndirectedEdge[66, 446] -> 
             RGBColor[
              0.19064470762485328`, 0.3177100536592947, 0.9341683061144403], 
             UndirectedEdge[449, 499] -> 
             RGBColor[
              0.8060897526290038, 0.8328531529864611, 0.6773590298414771], 
             UndirectedEdge[202, 477] -> 
             RGBColor[
              0.19227698695572149`, 0.31942568272852423`, 0.9342612620075925],
              UndirectedEdge[89, 299] -> 
             RGBColor[
              0.27487744861956126`, 0.4061575123810962, 0.9389684030253784], 
             UndirectedEdge[57, 91] -> 
             RGBColor[
              0.7114825067288603, 0.7722045544678969, 0.9493905426840812], 
             UndirectedEdge[222, 438] -> 
             RGBColor[
              0.19987204711910306`, 0.3274085725148659, 0.9346937894480125], 
             UndirectedEdge[83, 346] -> 
             RGBColor[
              0.7183210910606576, 0.7745238473066297, 0.8390571508964824], 
             UndirectedEdge[38, 388] -> 
             RGBColor[
              0.42375389748919434`, 0.5396775316025662, 0.9487136143198416], 
             UndirectedEdge[345, 472] -> 
             RGBColor[
              0.1869884495343811, 0.3138670945860562, 0.9339600876251372], 
             UndirectedEdge[231, 486] -> 
             RGBColor[
              0.5884962722514289, 0.6738630228882163, 0.9623181191717225], 
             UndirectedEdge[14, 251] -> 
             RGBColor[
              0.23495511782487732`, 0.36428310422179233`, 0.9366917184239543],
              UndirectedEdge[404, 418] -> 
             RGBColor[
              0.6566661186267099, 0.7293072977796211, 0.9681149418691689], 
             UndirectedEdge[10, 370] -> 
             RGBColor[
              0.22777336174590646`, 0.35673462323315885`, 0.9362827280397129],
              UndirectedEdge[216, 224] -> 
             RGBColor[
              0.20292469844545702`, 0.3306171026081368, 0.9348676334250554], 
             UndirectedEdge[116, 143] -> 
             RGBColor[
              0.4285653763865951, 0.5391828000638526, 0.9495933114012363], 
             UndirectedEdge[142, 477] -> 
             RGBColor[
              0.2067532217668407, 0.3346411233613098, 0.9350856621644155], 
             UndirectedEdge[1, 378] -> 
             RGBColor[
              0.20312084702488786`, 0.3308232672016569, 0.9348788037964781], 
             UndirectedEdge[47, 298] -> 
             RGBColor[
              0.2786489927595025, 0.4102081371297621, 0.9391800199621858], 
             UndirectedEdge[50, 340] -> 
             RGBColor[
              0.6220781556562913, 0.698481383789535, 0.9664262896114366], 
             UndirectedEdge[144, 417] -> 
             RGBColor[
              0.19700492333763642`, 0.3243950436343972, 0.9345305109901875], 
             UndirectedEdge[326, 395] -> 
             RGBColor[
              0.6147615284118504, 0.6968583223867169, 0.9636849672850575], 
             UndirectedEdge[14, 166] -> 
             RGBColor[
              0.21333099290535548`, 0.34155477788266697`, 0.9354602564998136],
              UndirectedEdge[41, 132] -> 
             RGBColor[
              0.2677010857798615, 0.3987011927567655, 0.9385565528556723], 
             UndirectedEdge[6, 35] -> 
             RGBColor[
              0.2010217865796709, 0.32861702158561484`, 0.9347592654094047], 
             UndirectedEdge[95, 286] -> 
             RGBColor[
              0.18603827385130794`, 0.3128683996985284, 0.9339059765256451], 
             UndirectedEdge[435, 439] -> 
             RGBColor[
              0.21881441649795172`, 0.3473182037476218, 0.9357725293614136], 
             UndirectedEdge[354, 388] -> 
             RGBColor[
              0.3196378407891415, 0.45127596505171874`, 0.9415880184638075], 
             UndirectedEdge[47, 59] -> 
             RGBColor[
              0.272302702026903, 0.4035377831917274, 0.9388186080934602], 
             UndirectedEdge[305, 493] -> 
             RGBColor[
              0.2857296655888689, 0.41748315098061395`, 0.9395893766300246], 
             UndirectedEdge[26, 335] -> 
             RGBColor[
              0.1976351524381914, 0.3250574543779134, 0.9345664016051236], 
             UndirectedEdge[24, 115] -> 
             RGBColor[
              0.18813870785962614`, 0.3150760890164789, 0.9340255931351051], 
             UndirectedEdge[271, 351] -> 
             RGBColor[
              0.2241430772010206, 0.3529189640031495, 0.9360759887054064], 
             UndirectedEdge[12, 40] -> 
             RGBColor[
              0.18952205245126588`, 0.31653007189140514`, 0.9341043725631242],
              UndirectedEdge[228, 468] -> 
             RGBColor[
              0.23985909159475186`, 0.369437491583826, 0.9369709924753695], 
             UndirectedEdge[1, 108] -> 
             RGBColor[
              0.20444558985732308`, 0.3322156559120931, 0.9349542459410038], 
             UndirectedEdge[97, 343] -> 
             RGBColor[
              0.9173437036143605, 0.6645392600270346, 0.3007805254610556], 
             UndirectedEdge[314, 411] -> 
             RGBColor[
              0.27200862613590066`, 0.4032286907847955, 0.9388018609065139], 
             UndirectedEdge[211, 466] -> 
             RGBColor[
              0.1911846700582075, 0.3182775884123456, 0.9341990561762171], 
             UndirectedEdge[12, 202] -> 
             RGBColor[
              0.1903977819160206, 0.31745051908331734`, 0.9341542440606163], 
             UndirectedEdge[96, 360] -> 
             RGBColor[
              0.5334689580963748, 0.6321331585421514, 0.9564157770239803], 
             UndirectedEdge[199, 482] -> 
             RGBColor[
              0.35925314832548205`, 0.4855887533164457, 0.9441122708295822], 
             UndirectedEdge[9, 357] -> 
             RGBColor[
              0.19116813878282407`, 0.31826021299377427`, 0.9341981147445398],
              UndirectedEdge[330, 441] -> 
             RGBColor[
              0.20552414062024876`, 0.33334928114799606`, 0.9350156678113797],
              UndirectedEdge[375, 461] -> 
             RGBColor[
              0.22800718101290143`, 0.35698038210776833`, 0.9362960437010637],
              UndirectedEdge[170, 268] -> 
             RGBColor[
              0.18701827847814975`, 0.31389844669722133`, 0.9339617863393568],
              UndirectedEdge[66, 245] -> 
             RGBColor[
              0.22090376329813846`, 0.34951423970685647`, 0.9358915145707727],
              UndirectedEdge[235, 308] -> 
             RGBColor[
              0.2040111506020718, 0.33175903270978435`, 0.9349295052681127], 
             UndirectedEdge[42, 315] -> 
             RGBColor[
              0.19198004367677265`, 0.3191135765150577, 0.9342443515271446], 
             UndirectedEdge[238, 403] -> 
             RGBColor[
              0.6150489760394036, 0.6968155368302928, 0.9638964004459423], 
             UndirectedEdge[382, 425] -> 
             RGBColor[
              0.19937423959475875`, 0.32688534524395996`, 0.9346654400459413],
              UndirectedEdge[74, 215] -> 
             RGBColor[
              0.1868347723407586, 0.3137055701118621, 0.9339513359363054], 
             UndirectedEdge[350, 426] -> 
             RGBColor[
              0.1844406280385869, 0.3111891726527635, 0.9338149929601158], 
             UndirectedEdge[78, 497] -> 
             RGBColor[
              0.47412146300073554`, 0.5839521884493253, 0.9517437248130138], 
             UndirectedEdge[109, 490] -> 
             RGBColor[
              0.21480193499900369`, 0.3431008312862066, 0.935544024475983], 
             UndirectedEdge[281, 317] -> 
             RGBColor[
              0.8178714627321924, 0.13837347065034328`, 0.1647470389362648], 
             UndirectedEdge[219, 471] -> 
             RGBColor[
              0.8131815162037359, 0.854543894896763, 0.9628221166971644], 
             UndirectedEdge[183, 243] -> 
             RGBColor[
              0.19677206267761843`, 0.3241502923164997, 0.9345172499200859], 
             UndirectedEdge[93, 151] -> 
             RGBColor[
              0.21317178010893856`, 0.3413874351389585, 0.9354511895665918], 
             UndirectedEdge[176, 478] -> 
             RGBColor[
              0.2831235992471345, 0.4141542435922354, 0.9394625592452028], 
             UndirectedEdge[28, 282] -> 
             RGBColor[
              0.586277448481364, 0.6741728296188088, 0.961142335628971], 
             UndirectedEdge[125, 305] -> 
             RGBColor[
              0.5442522046967718, 0.6349340468295404, 0.9597558326180513], 
             UndirectedEdge[22, 466] -> 
             RGBColor[
              0.188342270881701, 0.3152900466593206, 0.9340371857480678], 
             UndirectedEdge[78, 154] -> 
             RGBColor[
              0.7267639040768494, 0.783922928096006, 0.9321470662934741], 
             UndirectedEdge[273, 421] -> 
             RGBColor[
              0.18574774173175967`, 0.3125630320200829, 0.9338894311512407], 
             UndirectedEdge[221, 234] -> 
             RGBColor[
              0.9443267569423743, 0.8151145515040961, 0.2837836064703105], 
             UndirectedEdge[384, 461] -> 
             RGBColor[
              0.26067331628804735`, 0.3913145614345472, 0.9381563317797668], 
             UndirectedEdge[3, 428] -> 
             RGBColor[
              0.18571633162823864`, 0.3125300180097667, 0.9338876423923121], 
             UndirectedEdge[209, 431] -> 
             RGBColor[
              0.707864048381464, 0.7656363882619854, 0.8446357642394154], 
             UndirectedEdge[33, 237] -> 
             RGBColor[
              0.24458077131553108`, 0.3744002763421501, 0.9372398851503687], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.26751337219857585`, 0.3985038938811058, 0.9385458628449154], 
             UndirectedEdge[202, 243] -> 
             RGBColor[
              0.1916697633639069, 0.3187874522333277, 0.9342266815223454], 
             UndirectedEdge[169, 456] -> 
             RGBColor[
              0.18971194776524802`, 0.31672966390645874`, 0.9341151868203305],
              UndirectedEdge[86, 297] -> 
             RGBColor[
              0.1902871793569701, 0.317334268781148, 0.9341479454085002], 
             UndirectedEdge[40, 202] -> 
             RGBColor[
              0.18588447811869105`, 0.31270675063233544`, 0.933897218086193], 
             UndirectedEdge[396, 477] -> 
             RGBColor[
              0.19761610506605493`, 0.32503743438212485`, 0.9345653168854586],
              UndirectedEdge[209, 355] -> 
             RGBColor[
              0.7770929742760209, 0.8227102163659248, 0.8498451509008846], 
             UndirectedEdge[131, 434] -> 
             RGBColor[
              0.8844045850628767, 0.520292002224005, 0.22327723058043727`], 
             UndirectedEdge[87, 228] -> 
             RGBColor[
              0.28331447723561765`, 0.41511185712296006`, 0.9394457124011348],
              UndirectedEdge[17, 116] -> 
             RGBColor[
              0.32596120839538445`, 0.45376963828216715`, 0.9421001714481905],
              UndirectedEdge[104, 323] -> 
             RGBColor[
              0.958420920419589, 0.8640840271773381, 0.5141442750004963], 
             UndirectedEdge[101, 347] -> 
             RGBColor[
              0.22409394315426182`, 0.3528673210047275, 0.9360731905941307], 
             UndirectedEdge[92, 342] -> 
             RGBColor[
              0.37412603951120016`, 0.4944434887241004, 0.9453570750952447], 
             UndirectedEdge[399, 464] -> 
             RGBColor[
              0.20516649221167577`, 0.332973369994367, 0.9349953002636049], 
             UndirectedEdge[423, 469] -> 
             RGBColor[
              0.18027622515678673`, 0.30681212118559864`, 0.9335778363766793],
              UndirectedEdge[114, 415] -> 
             RGBColor[
              0.18091671513236096`, 0.30748531675933716`, 0.9336143113332682],
              UndirectedEdge[244, 478] -> 
             RGBColor[
              0.34801769220506096`, 0.4703622452404419, 0.9435975534648887], 
             UndirectedEdge[129, 486] -> 
             RGBColor[
              0.3513552004898414, 0.47695704074611134`, 0.9436745944599232], 
             UndirectedEdge[202, 421] -> 
             RGBColor[
              0.18554846728188248`, 0.31235358193853213`, 0.9338780827661202],
              UndirectedEdge[62, 378] -> 
             RGBColor[
              0.22907866033211158`, 0.3581065748079708, 0.9363570628631811], 
             UndirectedEdge[263, 485] -> 
             RGBColor[
              0.23984153552950008`, 0.3694190390461275, 0.9369699926834254], 
             UndirectedEdge[275, 346] -> 
             RGBColor[
              0.4653638430606762, 0.5765191723103537, 0.951143590075486], 
             UndirectedEdge[127, 303] -> 
             RGBColor[
              0.8364744443127496, 0.5917978023235237, 0.5852770137807005], 
             UndirectedEdge[260, 312] -> 
             RGBColor[
              0.2023598436460895, 0.3300234044001388, 0.9348354657798592], 
             UndirectedEdge[32, 299] -> 
             RGBColor[
              0.22987290893586354`, 0.3589413804487841, 0.9364022941461793], 
             UndirectedEdge[283, 396] -> 
             RGBColor[
              0.18987793209336085`, 0.3169041239593195, 0.9341246393822646], 
             UndirectedEdge[87, 253] -> 
             RGBColor[
              0.34295238339538536`, 0.47143899485614194`, 0.9430747302616557],
              UndirectedEdge[298, 409] -> 
             RGBColor[
              0.26446105735967274`, 0.39529571745748016`, 0.9383720380303351],
              UndirectedEdge[208, 258] -> 
             RGBColor[
              0.42089773296190985`, 0.5389821941816072, 0.9480402092524494], 
             UndirectedEdge[142, 161] -> 
             RGBColor[
              0.21478163330642375`, 0.3430794929201034, 0.9355428683246243], 
             UndirectedEdge[71, 211] -> 
             RGBColor[
              0.19261088350739852`, 0.3197766291746009, 0.9342802769222549], 
             UndirectedEdge[14, 453] -> 
             RGBColor[
              0.23545530969286413`, 0.36480883758904264`, 0.9367202036108686],
              UndirectedEdge[89, 478] -> 
             RGBColor[
              0.27949760473699387`, 0.41101358939533483`, 0.9392315140813577],
              UndirectedEdge[159, 251] -> 
             RGBColor[
              0.23552312226059172`, 0.3648801128972894, 0.936724065436281], 
             UndirectedEdge[300, 305] -> 
             RGBColor[
              0.27120896577425085`, 0.40222097480990704`, 0.9387624442570324],
              UndirectedEdge[327, 385] -> 
             RGBColor[
              0.18266732742080666`, 0.30932532126972345`, 0.9337140061132965],
              UndirectedEdge[156, 270] -> 
             RGBColor[
              0.18975438070497386`, 0.3167742636165143, 0.9341176033134739], 
             UndirectedEdge[418, 486] -> 
             RGBColor[
              0.4449199446935177, 0.5591594372838178, 0.9497448407437088], 
             UndirectedEdge[366, 465] -> 
             RGBColor[
              0.18080307297570358`, 0.30736587164736134`, 0.9336078395805651],
              UndirectedEdge[337, 433] -> 
             RGBColor[
              0.1848796930167158, 0.31165065778310447`, 0.9338399970610818], 
             UndirectedEdge[118, 152] -> 
             RGBColor[
              0.1882232378558979, 0.3151649354020718, 0.9340304069933419], 
             UndirectedEdge[151, 162] -> 
             RGBColor[
              0.1935196204092478, 0.32073176927569186`, 0.9343320281444594], 
             UndirectedEdge[80, 251] -> 
             RGBColor[
              0.2931730251986915, 0.4218985079169302, 0.9401380516698865], 
             UndirectedEdge[348, 486] -> 
             RGBColor[
              0.4377075205538863, 0.5533040664512603, 0.949177052295457], 
             UndirectedEdge[376, 455] -> 
             RGBColor[
              0.4920767571056538, 0.5962969354126668, 0.9537739864673327], 
             UndirectedEdge[153, 197] -> 
             RGBColor[
              0.22926543037868818`, 0.35830288196882765`, 0.9363676991410321],
              UndirectedEdge[9, 319] -> 
             RGBColor[
              0.18732739999033735`, 0.3142233530059664, 0.9339793903521716], 
             UndirectedEdge[184, 336] -> 
             RGBColor[
              0.5830930532515349, 0.672420234529121, 0.9603223675736445], 
             UndirectedEdge[41, 56] -> 
             RGBColor[
              0.33496751620801646`, 0.46033233124806494`, 0.9427193789900982],
              UndirectedEdge[99, 313] -> 
             RGBColor[
              0.6704591742575927, 0.7358360174967769, 0.9317439644037724], 
             UndirectedEdge[111, 130] -> 
             RGBColor[
              0.3347552996533061, 0.46383121081799694`, 0.9425710153855427], 
             UndirectedEdge[255, 327] -> 
             RGBColor[
              0.19047479361502342`, 0.3175314632617931, 0.9341586297629458], 
             UndirectedEdge[32, 84] -> 
             RGBColor[
              0.2475939365043437, 0.3775673040012994, 0.9374114804502933], 
             UndirectedEdge[196, 420] -> 
             RGBColor[
              0.19002037884251344`, 0.3170538445243244, 0.9341327515138979], 
             UndirectedEdge[55, 57] -> 
             RGBColor[
              0.7681170081630603, 0.818182994087395, 0.9538490180959958], 
             UndirectedEdge[10, 480] -> 
             RGBColor[
              0.2350739989368308, 0.3644080558079533, 0.9366984885274112], 
             UndirectedEdge[152, 216] -> 
             RGBColor[
              0.19207526490404528`, 0.31921366006229573`, 0.9342497742351705],
              UndirectedEdge[244, 482] -> 
             RGBColor[
              0.3895468312104969, 0.511827618826672, 0.9460425575153633], 
             UndirectedEdge[111, 463] -> 
             RGBColor[
              0.4608753150975682, 0.5708435411870683, 0.9513515854271455], 
             UndirectedEdge[58, 74] -> 
             RGBColor[
              0.19093718319717995`, 0.31801746402983233`, 0.9341849621656055],
              UndirectedEdge[66, 327] -> 
             RGBColor[
              0.19083074135934272`, 0.31790558690946313`, 0.9341789004604073],
              UndirectedEdge[168, 346] -> 
             RGBColor[
              0.3670639021674008, 0.4908716279040769, 0.9446642433693013], 
             UndirectedEdge[53, 471] -> 
             RGBColor[
              0.8947556642863255, 0.6097433924263989, 0.5684355218108367], 
             UndirectedEdge[28, 125] -> 
             RGBColor[
              0.6268956164581168, 0.7059040511517584, 0.965190775014533], 
             UndirectedEdge[405, 423] -> 
             RGBColor[
              0.18042956728835297`, 0.30697329348832747`, 0.9335865689842227],
              UndirectedEdge[314, 493] -> 
             RGBColor[
              0.2618563204200539, 0.3925579737840803, 0.9382237021149867], 
             UndirectedEdge[43, 229] -> 
             RGBColor[
              0.231604699752685, 0.3607616023991431, 0.9365009170712423], 
             UndirectedEdge[281, 397] -> 
             RGBColor[
              0.8202168451405925, 0.15640110759443068`, 0.16699297977927924`],
              UndirectedEdge[203, 324] -> 
             RGBColor[
              0.8924019068162066, 0.6510073815667528, 0.588847136940535], 
             UndirectedEdge[403, 445] -> 
             RGBColor[
              0.8532638533992596, 0.8433645979013125, 0.6431418553174187], 
             UndirectedEdge[147, 303] -> 
             RGBColor[
              0.8299391758302155, 0.23113120162734693`, 0.17630309462746424`],
              UndirectedEdge[356, 457] -> 
             RGBColor[
              0.35728371097557365`, 0.477585785779042, 0.9443210439032999], 
             UndirectedEdge[8, 85] -> 
             RGBColor[
              0.19237812780276942`, 0.31953198817147166`, 0.9342670218292075],
              UndirectedEdge[301, 336] -> 
             RGBColor[
              0.6408993785116156, 0.7191341855671287, 0.9650206560001502], 
             UndirectedEdge[24, 64] -> 
             RGBColor[
              0.18504835804129488`, 0.3118279354179173, 0.933849602284714], 
             UndirectedEdge[30, 488] -> 
             RGBColor[
              0.18073134444068237`, 0.30729048040920226`, 0.9336037547466085],
              UndirectedEdge[191, 366] -> 
             RGBColor[
              0.18657672320149288`, 0.31343434410523346`, 0.9339366404195737],
              UndirectedEdge[185, 481] -> 
             RGBColor[
              0.2084048526461078, 0.33637709213486555`, 0.9351797200996208], 
             UndirectedEdge[308, 389] -> 
             RGBColor[
              0.19291290556353907`, 0.320094073504909, 0.9342974766315505], 
             UndirectedEdge[96, 240] -> 
             RGBColor[
              0.7327901627995155, 0.786266849612556, 0.8137611085910759], 
             UndirectedEdge[108, 113] -> 
             RGBColor[
              0.2031652064588611, 0.33086989177931336`, 0.934881330000619], 
             UndirectedEdge[85, 332] -> 
             RGBColor[
              0.18694868384128802`, 0.31382529832132483`, 0.9339578230277437],
              UndirectedEdge[232, 280] -> 
             RGBColor[
              0.26596668909501486`, 0.3968782318738905, 0.9384577815302801], 
             UndirectedEdge[310, 419] -> 
             RGBColor[
              0.6470494829273306, 0.7241992409118212, 0.9654555035031411], 
             UndirectedEdge[39, 378] -> 
             RGBColor[
              0.22727756338581306`, 0.356213507721269, 0.9362544930565735], 
             UndirectedEdge[53, 257] -> 
             RGBColor[
              0.8978636395827194, 0.5695936454427237, 0.2449447114503845], 
             UndirectedEdge[248, 339] -> 
             RGBColor[
              0.18022958629127006`, 0.30676310078086577`, 0.933575180362284], 
             UndirectedEdge[327, 334] -> 
             RGBColor[
              0.18531717245783108`, 0.3121104764135153, 0.9338649108680606], 
             UndirectedEdge[165, 358] -> 
             RGBColor[
              0.26540482039910535`, 0.39628767224995665`, 0.9384257839392585],
              UndirectedEdge[69, 204] -> 
             RGBColor[
              0.37937968200922045`, 0.5030213452043036, 0.9453947157587149], 
             UndirectedEdge[208, 293] -> 
             RGBColor[
              0.6181817945706438, 0.697617598691705, 0.965038174550626], 
             UndirectedEdge[265, 320] -> 
             RGBColor[
              0.18273053674122575`, 0.3093917582731863, 0.9337176057905845], 
             UndirectedEdge[239, 453] -> 
             RGBColor[
              0.21828737914361301`, 0.34676425407211353`, 0.935742515363766], 
             UndirectedEdge[108, 452] -> 
             RGBColor[
              0.21821098000140754`, 0.3466839537296702, 0.9357381645456397], 
             UndirectedEdge[331, 418] -> 
             RGBColor[
              0.38897001185206387`, 0.5100224409848767, 0.9462045113122062], 
             UndirectedEdge[28, 201] -> 
             RGBColor[
              0.3666465873540202, 0.4866385048510442, 0.9449259979753362], 
             UndirectedEdge[431, 486] -> 
             RGBColor[
              0.4172932945902137, 0.5358602108283841, 0.9478105376266845], 
             UndirectedEdge[269, 419] -> 
             RGBColor[
              0.6255800853713929, 0.7068070035141348, 0.9637396556343641], 
             UndirectedEdge[315, 378] -> 
             RGBColor[
              0.19518703914887203`, 0.3224843320914912, 0.934426985174956], 
             UndirectedEdge[57, 240] -> 
             RGBColor[
              0.9787234021564939, 0.9814785102156434, 0.8120827611030339], 
             UndirectedEdge[7, 176] -> 
             RGBColor[
              0.39464375574399807`, 0.5157254458506131, 0.9465101425420326], 
             UndirectedEdge[6, 302] -> 
             RGBColor[
              0.22957764048616652`, 0.3586310345870516, 0.9363854790447795], 
             UndirectedEdge[176, 455] -> 
             RGBColor[
              0.46498904560871784`, 0.5728349211819872, 0.9520479814434708], 
             UndirectedEdge[161, 396] -> 
             RGBColor[
              0.205644516605638, 0.33347580394091847`, 0.9350225230456672], 
             UndirectedEdge[36, 463] -> 
             RGBColor[
              0.7746453145833472, 0.820791726755383, 0.8525214986025103], 
             UndirectedEdge[131, 373] -> 
             RGBColor[
              0.9123644303428394, 0.625404830056993, 0.48937807328246297`], 
             UndirectedEdge[54, 341] -> 
             RGBColor[
              0.991911410491914, 0.9900737129022821, 0.7219654915810148], 
             UndirectedEdge[272, 453] -> 
             RGBColor[
              0.24857862251541402`, 0.3786022714316334, 0.9374675568619113], 
             UndirectedEdge[169, 236] -> 
             RGBColor[
              0.19608590653883476`, 0.32342909870982617`, 0.9344781743430592],
              UndirectedEdge[69, 101] -> 
             RGBColor[
              0.3439836908945852, 0.4664796432810521, 0.9433547372891266], 
             UndirectedEdge[286, 330] -> 
             RGBColor[
              0.18848828405783719`, 0.3154435157652098, 0.9340455009824417], 
             UndirectedEdge[86, 254] -> 
             RGBColor[
              0.18887066842711453`, 0.3158454259818896, 0.934067277206585], 
             UndirectedEdge[68, 319] -> 
             RGBColor[
              0.1831451884938083, 0.30982758355559015`, 0.9337412195944718], 
             UndirectedEdge[37, 207] -> 
             RGBColor[
              0.8684208855066446, 0.4954117968161807, 0.21191950037856397`], 
             UndirectedEdge[257, 317] -> 
             RGBColor[
              0.8901858085318111, 0.510578471538423, 0.23759241176516477`], 
             UndirectedEdge[94, 158] -> 
             RGBColor[
              0.18531714297239393`, 0.3121104454224513, 0.9338649091889084], 
             UndirectedEdge[253, 336] -> 
             RGBColor[
              0.5014215448022852, 0.6040567843941038, 0.9544617509696633], 
             UndirectedEdge[67, 363] -> 
             RGBColor[
              0.18174309364533237`, 0.30835389297189403`, 0.9336613723670645],
              UndirectedEdge[61, 295] -> 
             RGBColor[
              0.9875274720228682, 0.989110303399177, 0.8563655966561801], 
             UndirectedEdge[16, 116] -> 
             RGBColor[
              0.2732978193858072, 0.4045837146300204, 0.9388752785549055], 
             UndirectedEdge[294, 439] -> 
             RGBColor[
              0.19336116609564466`, 0.3205652237455112, 0.9343230044057118], 
             UndirectedEdge[69, 346] -> 
             RGBColor[
              0.4421357571807656, 0.5573775033058451, 0.9493934773756274], 
             UndirectedEdge[327, 415] -> 
             RGBColor[
              0.1820891431356189, 0.3087176129269901, 0.9336810793736019], 
             UndirectedEdge[54, 61] -> 
             RGBColor[
              0.9898922626687403, 0.9900882051035927, 0.8171748957720661], 
             UndirectedEdge[244, 262] -> 
             RGBColor[
              0.3949445171400494, 0.5165028230832673, 0.9463864932898081], 
             UndirectedEdge[295, 397] -> 
             RGBColor[
              0.9034028373173626, 0.5790815030588307, 0.5351722665672494], 
             UndirectedEdge[61, 264] -> 
             RGBColor[
              0.9279014667399095, 0.7362939743699763, 0.5103077071950994], 
             UndirectedEdge[162, 226] -> 
             RGBColor[
              0.18515287463647273`, 0.3119377889861841, 0.933855554350191], 
             UndirectedEdge[237, 351] -> 
             RGBColor[
              0.2365402762573613, 0.3659492062391825, 0.9367819908516525], 
             UndirectedEdge[243, 273] -> 
             RGBColor[
              0.1918690378137841, 0.3189969023148785, 0.9342380299074659], 
             UndirectedEdge[53, 343] -> 
             RGBColor[
              0.8394526370347362, 0.3042558332705747, 0.18541319582083088`], 
             UndirectedEdge[37, 445] -> 
             RGBColor[
              0.9124867892485535, 0.6764249054783144, 0.25883228336174086`], 
             UndirectedEdge[144, 402] -> 
             RGBColor[
              0.20750395596016302`, 0.3354301925977886, 0.9351284153661135], 
             UndirectedEdge[235, 456] -> 
             RGBColor[
              0.20636469541016642`, 0.3342327575264513, 0.9350635361631761], 
             UndirectedEdge[369, 456] -> 
             RGBColor[
              0.1888191818250698, 0.31579131029870144`, 0.9340643451207662], 
             UndirectedEdge[7, 61] -> 
             RGBColor[
              0.7313065318033417, 0.7863785903909934, 0.8813505639139341], 
             UndirectedEdge[76, 175] -> 
             RGBColor[
              0.404052773600639, 0.5243919370351493, 0.946966863337362], 
             UndirectedEdge[259, 372] -> 
             RGBColor[
              0.6487722113207766, 0.7251147800966794, 0.9659213864599616], 
             UndirectedEdge[187, 224] -> 
             RGBColor[
              0.2135902734770326, 0.34182729820283736`, 0.9354750221447994], 
             UndirectedEdge[142, 183] -> 
             RGBColor[
              0.20633874170827649`, 0.3342054785402052, 0.9350620581382485], 
             UndirectedEdge[255, 299] -> 
             RGBColor[
              0.21862190988624552`, 0.3471158670930945, 0.935761566394665], 
             UndirectedEdge[233, 444] -> 
             RGBColor[
              0.7642107527779903, 0.8150144746201845, 0.9536153862998804], 
             UndirectedEdge[148, 280] -> 
             RGBColor[
              0.2640545871077613, 0.39486849145101877`, 0.9383488901508075], 
             UndirectedEdge[7, 376] -> 
             RGBColor[
              0.421731467240934, 0.5391874600812927, 0.9482361475658946], 
             UndirectedEdge[73, 256] -> 
             RGBColor[
              0.4442279577887227, 0.5558341651072809, 0.9504539244246188], 
             UndirectedEdge[207, 403] -> 
             RGBColor[
              0.8091979496573507, 0.6623514892391787, 0.5962290723342419], 
             UndirectedEdge[233, 346] -> 
             RGBColor[
              0.7019863596204035, 0.7641747233325396, 0.948806151319425], 
             UndirectedEdge[293, 403] -> 
             RGBColor[
              0.7765788883904609, 0.8253885969195616, 0.9783657841185909], 
             UndirectedEdge[321, 391] -> 
             RGBColor[
              0.7292749424513578, 0.7856899772227003, 0.9213526032018919], 
             UndirectedEdge[228, 298] -> 
             RGBColor[
              0.2669525907215979, 0.3979144769932027, 0.9385139271694034], 
             UndirectedEdge[54, 455] -> 
             RGBColor[
              0.8012850501089904, 0.8433363962570924, 0.8929667567235482], 
             UndirectedEdge[323, 419] -> 
             RGBColor[
              0.8209982189868783, 0.8586000678793866, 0.8680770966029969], 
             UndirectedEdge[65, 194] -> 
             RGBColor[
              0.18464315044443147`, 0.3114020365419683, 0.9338265263115236], 
             UndirectedEdge[40, 273] -> 
             RGBColor[
              0.18608375256856824`, 0.31291620071388626`, 0.9339085664713134],
              UndirectedEdge[209, 400] -> 
             RGBColor[
              0.9921722318540724, 0.9910310309542629, 0.7793899060000027], 
             UndirectedEdge[31, 488] -> 
             RGBColor[
              0.1872548538957951, 0.31414710246091443`, 0.9339752589594097], 
             UndirectedEdge[399, 407] -> 
             RGBColor[
              0.2425042792072058, 0.3722177514790964, 0.9371216319966944], 
             UndirectedEdge[292, 399] -> 
             RGBColor[
              0.19649944973854266`, 0.32386375883287244`, 0.9345017250165003],
              UndirectedEdge[93, 218] -> 
             RGBColor[
              0.2542535028794738, 0.3845669305024568, 0.9377907329034113], 
             UndirectedEdge[198, 270] -> 
             RGBColor[
              0.1812627552425552, 0.3078490268553615, 0.9336340178056233], 
             UndirectedEdge[78, 192] -> 
             RGBColor[
              0.39152498613418535`, 0.5130863931305935, 0.946294212255822], 
             UndirectedEdge[286, 492] -> 
             RGBColor[
              0.18500229424892267`, 0.31177951945152094`, 0.9338469790198838],
              UndirectedEdge[317, 343] -> 
             RGBColor[
              0.8317748059838278, 0.24524065936627398`, 0.17806089613561116`],
              UndirectedEdge[51, 203] -> 
             RGBColor[
              0.9201617687823374, 0.6698476352137519, 0.4577172955235477], 
             UndirectedEdge[212, 216] -> 
             RGBColor[
              0.19093042363498117`, 0.31801035930138044`, 0.9341845772185382],
              UndirectedEdge[100, 257] -> 
             RGBColor[
              0.9781397520963673, 0.9374756322249009, 0.407566735110352], 
             UndirectedEdge[189, 302] -> 
             RGBColor[
              0.24836644407899122`, 0.3783792584420631, 0.9374554736138468], 
             UndirectedEdge[306, 382] -> 
             RGBColor[
              0.2264199096398822, 0.3553120592559075, 0.9362056509445278], 
             UndirectedEdge[20, 150] -> 
             RGBColor[
              0.22855902835216374`, 0.35756040865047517`, 0.9363274705906497],
              UndirectedEdge[255, 446] -> 
             RGBColor[
              0.19028875988053398`, 0.31733593001162463`, 0.9341480354169789],
              UndirectedEdge[182, 237] -> 
             RGBColor[
              0.2889436538091614, 0.4176768128895569, 0.9398890065800227], 
             UndirectedEdge[4, 366] -> 
             RGBColor[
              0.18203443666830332`, 0.30866011296125107`, 0.9336779639212193],
              UndirectedEdge[231, 275] -> 
             RGBColor[
              0.6264851574368956, 0.7057897543518528, 0.9650087769508688], 
             UndirectedEdge[97, 231] -> 
             RGBColor[
              0.8760573705850234, 0.8940094298858756, 0.6933676019879993], 
             UndirectedEdge[114, 128] -> 
             RGBColor[
              0.1878451960142834, 0.31476758945729777`, 0.9340088780697248], 
             UndirectedEdge[207, 471] -> 
             RGBColor[
              0.9159118385486107, 0.7462782372358219, 0.5876734401900829], 
             UndirectedEdge[54, 391] -> 
             RGBColor[0.731320111432247, 0.7865357071547434, 0.8874588604609],
              UndirectedEdge[299, 478] -> 
             RGBColor[
              0.24469356026771227`, 0.3745188246821251, 0.9372463083143392], 
             UndirectedEdge[44, 365] -> 
             RGBColor[
              0.24302709585907487`, 0.37276726492870105`, 0.9371514056315804],
              UndirectedEdge[6, 101] -> 
             RGBColor[
              0.22975280750904292`, 0.3588151462343254, 0.9363954545475959], 
             UndirectedEdge[236, 308] -> 
             RGBColor[
              0.19963189940938322`, 0.3271561620457061, 0.9346801133912106], 
             UndirectedEdge[47, 256] -> 
             RGBColor[
              0.2965835068490444, 0.4287985034009982, 0.9402108818731908], 
             UndirectedEdge[304, 427] -> 
             RGBColor[
              0.18861159117236292`, 0.315573119360699, 0.9340525231401974], 
             UndirectedEdge[54, 397] -> 
             RGBColor[
              0.9057676279632347, 0.5800594047632462, 0.4959815656831355], 
             UndirectedEdge[220, 254] -> 
             RGBColor[
              0.20473141614653206`, 0.3325160774644852, 0.9349705233253323], 
             UndirectedEdge[377, 426] -> 
             RGBColor[
              0.1840742886923742, 0.31080412677263786`, 0.9337941304762996], 
             UndirectedEdge[216, 292] -> 
             RGBColor[
              0.19251751538449438`, 0.3196784933575477, 0.9342749597457812], 
             UndirectedEdge[42, 119] -> 
             RGBColor[
              0.1924345707120309, 0.31959131324779266`, 0.9342702361693901], 
             UndirectedEdge[170, 491] -> 
             RGBColor[
              0.18468093358720655`, 0.3114417490206145, 0.9338286780056095], 
             UndirectedEdge[257, 326] -> 
             RGBColor[
              0.8442173233312698, 0.8362115823989578, 0.6421148916132133], 
             UndirectedEdge[98, 347] -> 
             RGBColor[
              0.19568928020766854`, 0.32301221928820867`, 0.9344555870602553],
              UndirectedEdge[271, 311] -> 
             RGBColor[
              0.19904018271004636`, 0.32653423027769746`, 0.9346464160005499],
              UndirectedEdge[156, 227] -> 
             RGBColor[
              0.1962768676534719, 0.3236298109489438, 0.9344890492960363], 
             UndirectedEdge[151, 160] -> 
             RGBColor[
              0.22158100780321188`, 0.3502260666214703, 0.9359300826434431], 
             UndirectedEdge[93, 167] -> 
             RGBColor[
              0.23124675852992788`, 0.3603853834792411, 0.9364805328481329], 
             UndirectedEdge[275, 348] -> 
             RGBColor[
              0.475696405739353, 0.5852307979148967, 0.9518677100746031], 
             UndirectedEdge[34, 394] -> 
             RGBColor[
              0.19619166312976455`, 0.3235402555922485, 0.9344841970244598], 
             UndirectedEdge[405, 488] -> 
             RGBColor[
              0.182093967520493, 0.30872268366137645`, 0.9336813541151835], 
             UndirectedEdge[338, 443] -> 
             RGBColor[
              0.3560845115696105, 0.4809110296827722, 0.9439811523759123], 
             UndirectedEdge[301, 316] -> 
             RGBColor[
              0.547580608865669, 0.6429772459967242, 0.9577838308857021], 
             UndirectedEdge[103, 209] -> 
             RGBColor[
              0.7021401008892698, 0.7606785926382128, 0.8442710393667008], 
             UndirectedEdge[126, 414] -> 
             RGBColor[
              0.45556143140572114`, 0.5680520611940277, 0.9505125663614704], 
             UndirectedEdge[154, 341] -> 
             RGBColor[
              0.9888822096717337, 0.9887006265396945, 0.7667739089616505], 
             UndirectedEdge[306, 347] -> 
             RGBColor[
              0.22192337354853872`, 0.3505859147270508, 0.9359495798661548], 
             UndirectedEdge[20, 388] -> 
             RGBColor[
              0.2852227543233797, 0.4152738080593815, 0.9396218953833091], 
             UndirectedEdge[286, 319] -> 
             RGBColor[
              0.18412936406719407`, 0.310862014483554, 0.9337972669374188], 
             UndirectedEdge[62, 96] -> 
             RGBColor[
              0.36098375539591054`, 0.48129258556863375`, 0.9445483392518976],
              UndirectedEdge[149, 242] -> 
             RGBColor[
              0.767121254823353, 0.8170287735130601, 0.9444951769225841], 
             UndirectedEdge[212, 319] -> 
             RGBColor[
              0.18140430286516612`, 0.3079978023813632, 0.93364207873333], 
             UndirectedEdge[289, 470] -> 
             RGBColor[
              0.20234342031166005`, 0.33000614243435394`, 0.9348345304952597],
              UndirectedEdge[291, 353] -> 
             RGBColor[
              0.18189358061228061`, 0.3085120643155814, 0.9336699423772067], 
             UndirectedEdge[21, 91] -> 
             RGBColor[
              0.3801635060105999, 0.5027016523216035, 0.9455268210185781], 
             UndirectedEdge[95, 224] -> 
             RGBColor[
              0.19530748745975585`, 0.322610930903094, 0.9344338445280735], 
             UndirectedEdge[218, 235] -> 
             RGBColor[
              0.2514972659875934, 0.38166995077357824`, 0.9376337692899057], 
             UndirectedEdge[108, 315] -> 
             RGBColor[
              0.19651178198130725`, 0.3238767208019274, 0.9345024273194817], 
             UndirectedEdge[61, 154] -> 
             RGBColor[
              0.9868630618485601, 0.9887151187410052, 0.8619833131527019], 
             UndirectedEdge[297, 413] -> 
             RGBColor[
              0.2127862490397303, 0.34098221754113894`, 0.9354292341425425], 
             UndirectedEdge[294, 438] -> 
             RGBColor[
              0.19506692603526019`, 0.32235808559347384`, 0.9344201449108273],
              UndirectedEdge[277, 386] -> 
             RGBColor[
              0.3744145130463712, 0.49843012291785427`, 0.9450889814281427], 
             UndirectedEdge[125, 249] -> 
             RGBColor[
              0.7524497512082946, 0.8065387315646185, 0.9759608172238798], 
             UndirectedEdge[211, 308] -> 
             RGBColor[
              0.18919374524082816`, 0.3161850001973557, 0.9340856759531767], 
             UndirectedEdge[273, 477] -> 
             RGBColor[
              0.19247626140559868`, 0.319635132810075, 0.9342726103927129], 
             UndirectedEdge[154, 397] -> 
             RGBColor[
              0.9027384271430544, 0.5786863184006587, 0.5407899830637712], 
             UndirectedEdge[105, 230] -> 
             RGBColor[
              0.19866180408544326`, 0.32613653035264917`, 0.9346248678976397],
              UndirectedEdge[355, 404] -> 
             RGBColor[
              0.6982683944179626, 0.7630818994281268, 0.9713900254136139], 
             UndirectedEdge[250, 263] -> 
             RGBColor[
              0.22198989446995654`, 0.350655832433131, 0.9359533681342207], 
             UndirectedEdge[11, 259] -> 
             RGBColor[
              0.5294234413742529, 0.6261111308515327, 0.9571090734444168], 
             UndirectedEdge[339, 439] -> 
             RGBColor[
              0.18970826562688875`, 0.316725793745582, 0.9341149771279982], 
             UndirectedEdge[303, 379] -> 
             RGBColor[
              0.8341112743268393, 0.26319977889761653`, 0.18029830085954252`],
              UndirectedEdge[416, 468] -> 
             RGBColor[
              0.21536523562869736`, 0.3436928959633374, 0.9355761036135155], 
             UndirectedEdge[77, 336] -> 
             RGBColor[
              0.47990926789082156`, 0.58542393137187, 0.9530910077074245], 
             UndirectedEdge[297, 412] -> 
             RGBColor[
              0.1927590864051722, 0.31993239981676747`, 0.9342887168580365], 
             UndirectedEdge[69, 418] -> 
             RGBColor[
              0.45968074399907377`, 0.5719444997429457, 0.9506853858229966], 
             UndirectedEdge[281, 322] -> 
             RGBColor[
              0.8196030856546299, 0.15168348323420097`, 0.16640524300237935`],
              UndirectedEdge[51, 495] -> 
             RGBColor[
              0.9406722816777016, 0.7839532053527796, 0.47565298592181493`], 
             UndirectedEdge[227, 229] -> 
             RGBColor[
              0.21399982241481183`, 0.34225776010334574`, 0.9354983453509325],
              UndirectedEdge[192, 497] -> 
             RGBColor[
              0.3955857304505306, 0.5163830883010493, 0.9466138889234013], 
             UndirectedEdge[143, 277] -> 
             RGBColor[
              0.5119391923573035, 0.6143803189362278, 0.9547965836382715], 
             UndirectedEdge[87, 161] -> 
             RGBColor[
              0.2611314320863651, 0.3917960701847984, 0.9381824207967593], 
             UndirectedEdge[114, 255] -> 
             RGBColor[
              0.1893023656117655, 0.31629916709414013`, 0.9340918617226122], 
             UndirectedEdge[341, 391] -> 
             RGBColor[
              0.7337060308144916, 0.7866728844187078, 0.7861711023616725], 
             UndirectedEdge[35, 347] -> 
             RGBColor[
              0.19536292222488982`, 0.32266919635601693`, 0.9344370014559396],
              UndirectedEdge[99, 498] -> 
             RGBColor[
              0.8771421221278247, 0.9041056565781206, 0.9487087442796804], 
             UndirectedEdge[89, 448] -> 
             RGBColor[
              0.30513277253024496`, 0.43795777610955633`, 0.9406913989633512],
              UndirectedEdge[130, 371] -> 
             RGBColor[
              0.27850064570472033`, 0.41005221496943967`, 0.9391715718168758],
              UndirectedEdge[187, 481] -> 
             RGBColor[
              0.21325750963013368`, 0.3414775423013001, 0.9354560717359984], 
             UndirectedEdge[427, 500] -> 
             RGBColor[
              0.19375142518042626`, 0.32097541078747177`, 0.9343452290832536],
              UndirectedEdge[134, 247] -> 
             RGBColor[
              0.1842053003124589, 0.3109418282919634, 0.933801591394249], 
             UndirectedEdge[79, 301] -> 
             RGBColor[
              0.7713475583434661, 0.821837420942344, 0.9777022478790838], 
             UndirectedEdge[173, 323] -> 
             RGBColor[
              0.8566536605338118, 0.8864543698072436, 0.8716308977973497], 
             UndirectedEdge[84, 262] -> 
             RGBColor[
              0.3093414127711809, 0.4392853260774658, 0.9410444344433726], 
             UndirectedEdge[262, 391] -> 
             RGBColor[
              0.4081410490049733, 0.5273954680265918, 0.9473758851308575], 
             UndirectedEdge[205, 382] -> 
             RGBColor[
              0.22477554462649751`, 0.3535837273680766, 0.9361120067896356], 
             UndirectedEdge[50, 499] -> 
             RGBColor[
              0.7544680909250315, 0.8083923113644382, 0.9761768691183477], 
             UndirectedEdge[108, 380] -> 
             RGBColor[
              0.19854131235532485`, 0.3260098859046778, 0.934618006071861], 
             UndirectedEdge[300, 493] -> 
             RGBColor[
              0.24638397938180046`, 0.376295562349794, 0.9373425751821356], 
             UndirectedEdge[331, 382] -> 
             RGBColor[
              0.25675225340899854`, 0.38719327573892137`, 0.9379330330494976],
              UndirectedEdge[186, 495] -> 
             RGBColor[
              0.9397076490875935, 0.7818899537818541, 0.3706586815108439], 
             UndirectedEdge[93, 235] -> 
             RGBColor[
              0.21987414226832205`, 0.3484320427227756, 0.9358328791763124], 
             UndirectedEdge[18, 300] -> 
             RGBColor[
              0.26008832470075693`, 0.39069969818569605`, 0.938123017374288], 
             UndirectedEdge[223, 246] -> 
             RGBColor[
              0.22404185527291065`, 0.35281257333886495`, 0.9360702242663449],
              UndirectedEdge[233, 431] -> 
             RGBColor[
              0.6919046963354076, 0.7554424933142063, 0.9481637566497699], 
             UndirectedEdge[182, 351] -> 
             RGBColor[
              0.2925937639781592, 0.42151331010752513`, 0.9400968749542931], 
             UndirectedEdge[163, 209] -> 
             RGBColor[
              0.9468923206889115, 0.8138245711399055, 0.48945082932663964`], 
             UndirectedEdge[70, 182] -> 
             RGBColor[
              0.35737014201408246`, 0.4839577878921605, 0.9439922873324968], 
             UndirectedEdge[59, 335] -> 
             RGBColor[
              0.2366854990874992, 0.3661018446413167, 0.9367902610769909], 
             UndirectedEdge[258, 453] -> 
             RGBColor[
              0.3275555861569279, 0.45177144641276795`, 0.942325491454229], 
             UndirectedEdge[161, 354] -> 
             RGBColor[
              0.262219161885439, 0.39276906224398844`, 0.9382506002184958], 
             UndirectedEdge[213, 489] -> 
             RGBColor[
              0.19691928671610104`, 0.3243050341154881, 0.9345256341112791], 
             UndirectedEdge[260, 407] -> 
             RGBColor[
              0.24344019620099944`, 0.3732014595801383, 0.9371749310849259], 
             UndirectedEdge[95, 185] -> 
             RGBColor[
              0.19811081032671668`, 0.3255574009772055, 0.9345934896182024], 
             UndirectedEdge[117, 479] -> 
             RGBColor[
              0.1829410540251313, 0.30961302528613777`, 0.9337295944384705], 
             UndirectedEdge[164, 444] -> 
             RGBColor[
              0.4409447203988165, 0.5532899965320492, 0.9501619372363984], 
             UndirectedEdge[32, 334] -> 
             RGBColor[
              0.2032637935146371, 0.3309735130257143, 0.934886944387599], 
             UndirectedEdge[46, 325] -> 
             RGBColor[
              0.2186729430619583, 0.3471695061964588, 0.935764472658525], 
             UndirectedEdge[18, 201] -> 
             RGBColor[
              0.27288253451918126`, 0.4041472239046152, 0.93885162869611], 
             UndirectedEdge[328, 398] -> 
             RGBColor[
              0.2246228179747201, 0.35342320197362953`, 0.9361033092327558], 
             UndirectedEdge[376, 448] -> 
             RGBColor[
              0.33584647853732147`, 0.4645604445371366, 0.9426484491510583], 
             UndirectedEdge[326, 355] -> 
             RGBColor[
              0.642545935987291, 0.7194149561297569, 0.9658722576270347], 
             UndirectedEdge[257, 281] -> 
             RGBColor[
              0.8907382712640035, 0.5148249421887663, 0.2381214507014296], 
             UndirectedEdge[32, 89] -> 
             RGBColor[
              0.26467695340514513`, 0.3954361451619938, 0.9383874999131978], 
             UndirectedEdge[341, 397] -> 
             RGBColor[
              0.9081535473454794, 0.5801965820272107, 0.39469380758390815`], 
             UndirectedEdge[160, 274] -> 
             RGBColor[
              0.24176660566523328`, 0.3714424098152794, 0.9370796225797693], 
             UndirectedEdge[151, 235] -> 
             RGBColor[
              0.21041554321705824`, 0.3384904554100799, 0.9352942259530863], 
             UndirectedEdge[11, 372] -> 
             RGBColor[
              0.49492242636970674`, 0.598728406383233, 0.9539645121894538], 
             UndirectedEdge[99, 295] -> 
             RGBColor[
              0.9822469150718874, 0.9861800274834427, 0.9104424780465525], 
             UndirectedEdge[154, 199] -> 
             RGBColor[
              0.684800695862128, 0.748031110338605, 0.9293475993147051], 
             UndirectedEdge[169, 308] -> 
             RGBColor[
              0.18735840295715342`, 0.31425593908979166`, 0.9339811559252671],
              UndirectedEdge[158, 410] -> 
             RGBColor[
              0.18697773490946556`, 0.31385583283592355`, 0.933959477443099], 
             UndirectedEdge[311, 465] -> 
             RGBColor[
              0.1845169561942322, 0.31126939838383133`, 0.9338193397356624], 
             UndirectedEdge[139, 428] -> 
             RGBColor[
              0.1851867200986532, 0.311973362712862, 0.9338574817991923], 
             UndirectedEdge[113, 364] -> 
             RGBColor[
              0.20055433939420772`, 0.3281257049558297, 0.9347326449837188], 
             UndirectedEdge[89, 475] -> 
             RGBColor[
              0.32310504521526556`, 0.4542790832588659, 0.9418089456639116], 
             UndirectedEdge[375, 441] -> 
             RGBColor[
              0.2121051529687783, 0.3402663423865834, 0.9353904467288932], 
             UndirectedEdge[244, 295] -> 
             RGBColor[
              0.7157587889214511, 0.7746651605070033, 0.9256601695039643], 
             UndirectedEdge[187, 260] -> 
             RGBColor[
              0.21549852964428565`, 0.3438329964250494, 0.9355836945105124], 
             UndirectedEdge[207, 322] -> 
             RGBColor[
              0.8478846282356312, 0.34298703129758157`, 0.19246642213058046`],
              UndirectedEdge[100, 457] -> 
             RGBColor[
              0.7312390426759171, 0.7839598047362808, 0.7277634832098476], 
             UndirectedEdge[364, 416] -> 
             RGBColor[
              0.20681043357905127`, 0.33470125660338146`, 0.9350889202924836],
              UndirectedEdge[313, 386] -> 
             RGBColor[
              0.33341144011418006`, 0.4629153220183585, 0.9424763018784972], 
             UndirectedEdge[31, 472] -> 
             RGBColor[
              0.1875584213311225, 0.31446617108273056`, 0.9339925466757639], 
             UndirectedEdge[37, 49] -> 
             RGBColor[
              0.9278898442559633, 0.7275054583426774, 0.39329233295696453`], 
             UndirectedEdge[201, 406] -> 
             RGBColor[
              0.33697692661979073`, 0.46155170113037025`, 0.9428664961514535],
              UndirectedEdge[245, 376] -> 
             RGBColor[
              0.30751706029421144`, 0.43478442977476833`, 0.9410351306917317],
              UndirectedEdge[58, 215] -> 
             RGBColor[
              0.1890650982052305, 0.3160497840062494, 0.9340783496948156], 
             UndirectedEdge[84, 407] -> 
             RGBColor[
              0.27632252286434345`, 0.40776286976323906`, 0.9390475309433604],
              UndirectedEdge[100, 324] -> 
             RGBColor[
              0.9664798274342277, 0.9712473493741347, 0.7455337650413938], 
             UndirectedEdge[89, 176] -> 
             RGBColor[
              0.31330748759898347`, 0.4457929312912065, 0.9411846539562421], 
             UndirectedEdge[75, 379] -> 
             RGBColor[
              0.8463714309227728, 0.346563167860244, 0.1916128598280513], 
             UndirectedEdge[123, 422] -> 
             RGBColor[
              0.1961933017960193, 0.3235419779343797, 0.9344842903440789], 
             UndirectedEdge[407, 455] -> 
             RGBColor[
              0.44508709777487926`, 0.5526737008147141, 0.9508868778934936], 
             UndirectedEdge[333, 358] -> 
             RGBColor[
              0.22833564415577742`, 0.35732561769669713`, 0.9363147491911328],
              UndirectedEdge[120, 124] -> 
             RGBColor[
              0.18263624540769638`, 0.3092926521032311, 0.9337122360386315], 
             UndirectedEdge[88, 433] -> 
             RGBColor[
              0.18511620603054046`, 0.3118992479564254, 0.9338534661273294], 
             UndirectedEdge[345, 456] -> 
             RGBColor[
              0.1932262687729535, 0.32042343810637863`, 0.9343153222027473], 
             UndirectedEdge[392, 474] -> 
             RGBColor[
              0.23318205607902553`, 0.3624195039082944, 0.9365907451805379], 
             UndirectedEdge[165, 333] -> 
             RGBColor[
              0.26885740704369754`, 0.3999165597200598, 0.9386224036410238], 
             UndirectedEdge[31, 133] -> 
             RGBColor[
              0.1949807850604232, 0.3222675459672669, 0.9344152393097445], 
             UndirectedEdge[171, 208] -> 
             RGBColor[
              0.44865476640412644`, 0.5625521197174839, 0.9499392286265838], 
             UndirectedEdge[284, 472] -> 
             RGBColor[
              0.19498301286010505`, 0.32226988752598323`, 0.9344153661796406],
              UndirectedEdge[196, 427] -> 
             RGBColor[
              0.18925515066577042`, 0.3162495411922988, 0.9340891729012859], 
             UndirectedEdge[179, 334] -> 
             RGBColor[
              0.1934836161981846, 0.32069392656706563`, 0.9343299777579028], 
             UndirectedEdge[97, 233] -> 
             RGBColor[
              0.9755070986726647, 0.9721600768096842, 0.6789609948576975], 
             UndirectedEdge[21, 409] -> 
             RGBColor[
              0.27661821411791565`, 0.40807366001865175`, 0.9390643701228152],
              UndirectedEdge[63, 344] -> 
             RGBColor[
              0.19854348560024537`, 0.326012170122881, 0.9346181298349442], 
             UndirectedEdge[292, 398] -> 
             RGBColor[
              0.19568953649861287`, 0.32301248866624094`, 0.9344556016556456],
              UndirectedEdge[71, 197] -> 
             RGBColor[
              0.2143161876130597, 0.34259027998541636`, 0.9355163618809523], 
             UndirectedEdge[81, 121] -> 
             RGBColor[
              0.22174468237743916`, 0.35039809897655055`, 0.9359394036683106],
              UndirectedEdge[163, 317] -> 
             RGBColor[
              0.8583137676007231, 0.3848962000432028, 0.20095545620474106`], 
             UndirectedEdge[167, 172] -> 
             RGBColor[
              0.23167761735264775`, 0.36083824341994686`, 0.9365050696206882],
              UndirectedEdge[191, 488] -> 
             RGBColor[
              0.18656266374586195`, 0.3134195667259444, 0.9339358397543747], 
             UndirectedEdge[392, 490] -> 
             RGBColor[
              0.2264092533563037, 0.355300858826219, 0.9362050440849425], 
             UndirectedEdge[251, 272] -> 
             RGBColor[
              0.24807843064742718`, 0.378076538064383, 0.937439071674997], 
             UndirectedEdge[66, 255] -> 
             RGBColor[
              0.19752636336653073`, 0.32494311016597255`, 0.9345602062284316],
              UndirectedEdge[177, 194] -> 
             RGBColor[
              0.1852447118397448, 0.312034315709638, 0.9338607843430564], 
             UndirectedEdge[36, 359] -> 
             RGBColor[
              0.9518288028476951, 0.9612683407754878, 0.8690761481825573], 
             UndirectedEdge[46, 377] -> 
             RGBColor[
              0.192250993648715, 0.31939836211478956`, 0.9342597817272121], 
             UndirectedEdge[6, 306] -> 
             RGBColor[
              0.22758223790331983`, 0.3565337399566487, 0.93627184381962], 
             UndirectedEdge[7, 455] -> 
             RGBColor[
              0.5426993192435918, 0.6396267815444932, 0.9571424248654161], 
             UndirectedEdge[84, 482] -> 
             RGBColor[
              0.30394372684162835`, 0.43461012182087044`, 0.9407004986689278],
              UndirectedEdge[83, 97] -> 
             RGBColor[
              0.9918418301129188, 0.9825092007837744, 0.5692119944347548], 
             UndirectedEdge[125, 408] -> 
             RGBColor[
              0.8576169370417068, 0.8896033538181681, 0.9847741152357485], 
             UndirectedEdge[184, 473] -> 
             RGBColor[
              0.4022146970771591, 0.5162489604655307, 0.9476591763750619], 
             UndirectedEdge[410, 422] -> 
             RGBColor[
              0.19439415698617535`, 0.3216509626668643, 0.9343818317087544], 
             UndirectedEdge[202, 283] -> 
             RGBColor[
              0.1845388139830274, 0.3112923723057189, 0.9338205845043986], 
             UndirectedEdge[320, 329] -> 
             RGBColor[
              0.18135868640525998`, 0.3079498565897512, 0.9336394809434219], 
             UndirectedEdge[146, 387] -> 
             RGBColor[
              0.18448194243535776`, 0.3112325967032537, 0.9338173457538927], 
             UndirectedEdge[107, 170] -> 
             RGBColor[
              0.19951076544330998`, 0.3270288425670261, 0.9346732149910444], 
             UndirectedEdge[273, 459] -> 
             RGBColor[
              0.19081936422215473`, 0.3178936288169264, 0.9341782525492754], 
             UndirectedEdge[5, 395] -> 
             RGBColor[
              0.5968586468606165, 0.6828724552519535, 0.9619005753639707], 
             UndirectedEdge[104, 242] -> 
             RGBColor[
              0.9486223107500168, 0.8581914089875718, 0.5941049181072977], 
             UndirectedEdge[422, 437] -> 
             RGBColor[
              0.1942298621222053, 0.32147827834793574`, 0.9343724753593039], 
             UndirectedEdge[29, 177] -> 
             RGBColor[
              0.18440587372207073`, 0.31115264366255413`, 0.9338130137532046],
              UndirectedEdge[202, 285] -> 
             RGBColor[
              0.2005739783770007, 0.32814634677192855`, 0.9347337633947355], 
             UndirectedEdge[182, 460] -> 
             RGBColor[
              0.32283537188163536`, 0.453299157442765, 0.9418190897859463], 
             UndirectedEdge[116, 333] -> 
             RGBColor[
              0.2541335864563355, 0.3844408907385981, 0.937783903840514], 
             UndirectedEdge[405, 472] -> 
             RGBColor[
              0.1823975349558204, 0.3090417522831926, 0.9336986418315376], 
             UndirectedEdge[51, 96] -> 
             RGBColor[
              0.7330134148240908, 0.7867443631188805, 0.8380607137143137], 
             UndirectedEdge[115, 402] -> 
             RGBColor[
              0.20455792141877943`, 0.3323337235054161, 0.9349606430572492], 
             UndirectedEdge[67, 120] -> 
             RGBColor[
              0.18038821966444069`, 0.3069298345140049, 0.9335842142982091], 
             UndirectedEdge[72, 222] -> 
             RGBColor[
              0.20410917934136036`, 0.33186206713015765`, 0.9349350878597946],
              UndirectedEdge[84, 328] -> 
             RGBColor[
              0.2592509748717875, 0.3898195904244037, 0.9380753315402763], 
             UndirectedEdge[123, 401] -> 
             RGBColor[
              0.18328689846403934`, 0.309976529719234, 0.9337492897676354], 
             UndirectedEdge[143, 178] -> 
             RGBColor[
              0.5249805981564001, 0.6252419255466224, 0.9557475422356184], 
             UndirectedEdge[2, 385] -> 
             RGBColor[
              0.1828749868990639, 0.3095435845477431, 0.9337258320133786], 
             UndirectedEdge[113, 487] -> 
             RGBColor[
              0.19472843618281724`, 0.32200231129706014`, 0.9344008684144816],
              UndirectedEdge[12, 430] -> 
             RGBColor[
              0.19779577870573095`, 0.32522628276939103`, 0.9345755490334348],
              UndirectedEdge[72, 344] -> 
             RGBColor[
              0.20069596090134978`, 0.3282745581391582, 0.9347407101190403], 
             UndirectedEdge[127, 221] -> 
             RGBColor[
              0.8972130382069989, 0.8767030519388234, 0.6458996213784399], 
             UndirectedEdge[466, 491] -> 
             RGBColor[
              0.1882565372451065, 0.3151999351714332, 0.9340323033442953], 
             UndirectedEdge[236, 289] -> 
             RGBColor[
              0.20921618528861102`, 0.33722985418359713`, 0.9352259242933523],
              UndirectedEdge[200, 298] -> 
             RGBColor[
              0.26933197029652145`, 0.4004153557878257, 0.9386494293162186], 
             UndirectedEdge[231, 431] -> 
             RGBColor[
              0.5924549682477664, 0.6772918463903979, 0.9625703637800718], 
             UndirectedEdge[171, 238] -> 
             RGBColor[
              0.47869194757503297`, 0.5876627137247235, 0.9521035301009391], 
             UndirectedEdge[276, 306] -> 
             RGBColor[
              0.22718429673725105`, 0.3561154785601833, 0.9362491816589136], 
             UndirectedEdge[294, 296] -> 
             RGBColor[
              0.18486063733978264`, 0.311630629058448, 0.9338389118684709], 
             UndirectedEdge[1, 119] -> 
             RGBColor[
              0.1917982653600388, 0.3189225159787594, 0.9342339995209235], 
             UndirectedEdge[103, 444] -> 
             RGBColor[
              0.4878340995369397, 0.5939032200127712, 0.9531496870124296], 
             UndirectedEdge[331, 486] -> 
             RGBColor[
              0.35738466575242234`, 0.48329439102726157`, 0.9440179635868327],
              UndirectedEdge[100, 281] -> 
             RGBColor[
              0.9058254062967486, 0.5652706313368212, 0.33472136228145205`], 
             UndirectedEdge[161, 477] -> 
             RGBColor[
              0.2058221778675803, 0.33366253719159444`, 0.9350326405917087], 
             UndirectedEdge[391, 475] -> 
             RGBColor[
              0.40482166454825647`, 0.5245203840472975, 0.9471643768884919], 
             UndirectedEdge[2, 312] -> 
             RGBColor[
              0.18958168594798847`, 0.3165927504774426, 0.9341077686025426], 
             UndirectedEdge[264, 341] -> 
             RGBColor[
              0.9299206145630832, 0.7362794821686658, 0.415098303004048], 
             UndirectedEdge[73, 434] -> 
             RGBColor[
              0.755989141506491, 0.7238557905975457, 0.6132283330346036], 
             UndirectedEdge[241, 271] -> 
             RGBColor[
              0.2118628562397169, 0.3400116731618399, 0.935376648288619], 
             UndirectedEdge[49, 51] -> 
             RGBColor[
              0.9945887098983145, 0.9908341225748765, 0.6523926509220856], 
             UndirectedEdge[5, 275] -> 
             RGBColor[
              0.5894443177306294, 0.6768531688525092, 0.9613168922152756], 
             UndirectedEdge[18, 274] -> 
             RGBColor[
              0.2661988733080245, 0.397122272203093, 0.9384710040777253], 
             UndirectedEdge[219, 445] -> 
             RGBColor[
              0.8163225920234214, 0.8145058037505225, 0.6394598956191903], 
             UndirectedEdge[177, 297] -> 
             RGBColor[
              0.18982245259063335`, 0.3168458114843493, 0.9341214799066588], 
             UndirectedEdge[250, 365] -> 
             RGBColor[
              0.21334264494811753`, 0.3415670249183921, 0.9354609200664112], 
             UndirectedEdge[325, 474] -> 
             RGBColor[
              0.2315745275844326, 0.3607298895372839, 0.936499198810896], 
             UndirectedEdge[266, 403] -> 
             RGBColor[
              0.868496130673329, 0.8940798744623377, 0.7590138025565417], 
             UndirectedEdge[214, 470] -> 
             RGBColor[
              0.19107951696482092`, 0.31816706584410515`, 0.9341930678631087],
              UndirectedEdge[152, 481] -> 
             RGBColor[
              0.1947520962377352, 0.322027179514913, 0.9344022158196071], 
             UndirectedEdge[289, 466] -> 
             RGBColor[
              0.20247960652430902`, 0.3301492827785526, 0.9348422860986005], 
             UndirectedEdge[126, 269] -> 
             RGBColor[
              0.5451650588175359, 0.6416285800109227, 0.9573365369169786], 
             UndirectedEdge[183, 396] -> 
             RGBColor[
              0.19720162500749072`, 0.32460178956102026`, 0.9345417128592917],
              UndirectedEdge[54, 99] -> 
             RGBColor[
              0.9846117057177595, 0.9871579291878583, 0.8712517771624386], 
             UndirectedEdge[129, 306] -> 
             RGBColor[
              0.2650729238792713, 0.39593882796415625`, 0.9384068829234508], 
             UndirectedEdge[172, 236] -> 
             RGBColor[
              0.21592574989835334`, 0.34428203199940316`, 0.9356080240719657],
              UndirectedEdge[162, 284] -> 
             RGBColor[
              0.19507811925714236`, 0.3223698503793633, 0.9344207823482545], 
             UndirectedEdge[10, 189] -> 
             RGBColor[
              0.23937944149495205`, 0.3689333489173635, 0.9369436771117647], 
             UndirectedEdge[213, 332] -> 
             RGBColor[
              0.19442260484216423`, 0.3216808631672068, 0.9343834517720682], 
             UndirectedEdge[199, 245] -> 
             RGBColor[
              0.31502975887018714`, 0.4412915516820689, 0.9415138332017744], 
             UndirectedEdge[123, 139] -> 
             RGBColor[
              0.1842229343035432, 0.31096036273465255`, 0.9338025956239542], 
             UndirectedEdge[391, 482] -> 
             RGBColor[
              0.4027433630754207, 0.5227202637699965, 0.9470319493564127], 
             UndirectedEdge[184, 354] -> 
             RGBColor[
              0.425711621643709, 0.5407754370503493, 0.9490035262873733], 
             UndirectedEdge[25, 316] -> 
             RGBColor[
              0.36380395841468005`, 0.4876950626233916, 0.9444694464449066], 
             UndirectedEdge[106, 479] -> 
             RGBColor[
              0.18098277247116215`, 0.30755474721069437`, 0.9336180732009899],
              UndirectedEdge[118, 260] -> 
             RGBColor[
              0.20098092756456265`, 0.3285740761701249, 0.9347569385489398], 
             UndirectedEdge[304, 469] -> 
             RGBColor[
              0.18603078567582654`, 0.3128605291513198, 0.9339055500851292], 
             UndirectedEdge[93, 236] -> 
             RGBColor[
              0.21549489107563347`, 0.3438291720586974, 0.9355834872994104], 
             UndirectedEdge[343, 445] -> 
             RGBColor[
              0.9046747150389304, 0.6218037867421315, 0.25156389718325395`], 
             UndirectedEdge[204, 444] -> 
             RGBColor[
              0.44088363514258455`, 0.5532370875533353, 0.9501580449378868], 
             UndirectedEdge[150, 412] -> 
             RGBColor[
              0.20280807626052344`, 0.33049452529749807`, 0.9348609919641505],
              UndirectedEdge[14, 239] -> 
             RGBColor[
              0.21381228139776098`, 0.3420606426036381, 0.9354876651674535], 
             UndirectedEdge[70, 442] -> 
             RGBColor[
              0.3038237186466454, 0.4310287676162611, 0.9408201768359108], 
             UndirectedEdge[93, 493] -> 
             RGBColor[
              0.24176752917831046`, 0.3714433804860776, 0.9370796751724728], 
             UndirectedEdge[228, 279] -> 
             RGBColor[
              0.23309972747079383`, 0.36233297132110764`, 0.9365860566880932],
              UndirectedEdge[300, 456] -> 
             RGBColor[
              0.21373738250553675`, 0.34198191911904635`, 0.9354833997863443],
              UndirectedEdge[168, 326] -> 
             RGBColor[
              0.509047258388588, 0.6051914915809957, 0.9566219374301776], 
             UndirectedEdge[193, 437] -> 
             RGBColor[
              0.18142173090578886`, 0.3080161203570593, 0.933643071234461], 
             UndirectedEdge[224, 361] -> 
             RGBColor[
              0.21801752264150492`, 0.34648061777850747`, 0.9357271474351878],
              UndirectedEdge[12, 477] -> 
             RGBColor[
              0.19591456128829632`, 0.32324900398759393`, 0.9344684164845236],
              UndirectedEdge[212, 224] -> 
             RGBColor[
              0.19394001881557005`, 0.321173634655535, 0.9343559692117758], 
             UndirectedEdge[220, 490] -> 
             RGBColor[
              0.2165006286676464, 0.34488626603534933`, 0.9356407625674201], 
             UndirectedEdge[175, 208] -> 
             RGBColor[
              0.41214605726916764`, 0.531401932568564, 0.9474825602161108], 
             UndirectedEdge[242, 419] -> 
             RGBColor[
              0.8111996093173061, 0.8527074496896203, 0.9480377397097984], 
             UndirectedEdge[164, 205] -> 
             RGBColor[
              0.2767533263359414, 0.40754264705410376`, 0.9390967072865741], 
             UndirectedEdge[257, 322] -> 
             RGBColor[
              0.8919174314542486, 0.5238884841222806, 0.23925061583127932`], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.7309397602442707, 0.7862269209257184, 0.8874289178221101], 
             UndirectedEdge[26, 67] -> 
             RGBColor[
              0.1828839766938226, 0.30955303339202045`, 0.9337263439688908], 
             UndirectedEdge[366, 488] -> 
             RGBColor[
              0.1825427715517224, 0.30919440515401764`, 0.933706912840816], 
             UndirectedEdge[12, 243] -> 
             RGBColor[
              0.19530733769648173`, 0.3226107734923974, 0.9344338359992765], 
             UndirectedEdge[271, 307] -> 
             RGBColor[
              0.199934386249049, 0.3274740948929682, 0.9346973395692404], 
             UndirectedEdge[9, 352] -> 
             RGBColor[
              0.18859199395283752`, 0.3155525214404422, 0.9340514071075369], 
             UndirectedEdge[404, 431] -> 
             RGBColor[
              0.629039468523406, 0.7060080713241875, 0.9661806387521447], 
             UndirectedEdge[256, 287] -> 
             RGBColor[
              0.30785568445183253`, 0.44064627675886753`, 0.9408528157119771],
              UndirectedEdge[254, 412] -> 
             RGBColor[
              0.19134257547531666`, 0.31844355701750904`, 0.9342080486561213],
              UndirectedEdge[42, 380] -> 
             RGBColor[
              0.19400957405079025`, 0.3212467416178081, 0.9343599302795238], 
             UndirectedEdge[379, 404] -> 
             RGBColor[
              0.8321257348299118, 0.5422647939490768, 0.5790967778488565], 
             UndirectedEdge[134, 424] -> 
             RGBColor[
              0.18880157011833354`, 0.31577279927827495`, 0.9340633421601217],
              UndirectedEdge[38, 253] -> 
             RGBColor[
              0.4481561698945121, 0.5608135534661793, 0.9502685055394262], 
             UndirectedEdge[103, 348] -> 
             RGBColor[
              0.4359422690580296, 0.5517750943296691, 0.9490645720310915], 
             UndirectedEdge[42, 452] -> 
             RGBColor[
              0.21367924169687297`, 0.3419208094428005, 0.9354800887533026], 
             UndirectedEdge[164, 331] -> 
             RGBColor[
              0.3087300351184425, 0.44115219542494855`, 0.940917733546436], 
             UndirectedEdge[6, 181] -> 
             RGBColor[
              0.2199559451719783, 0.348518022761122, 0.9358375377306591], 
             UndirectedEdge[172, 197] -> 
             RGBColor[
              0.22719289983545946`, 0.3561245209618682, 0.9362496715926294], 
             UndirectedEdge[80, 258] -> 
             RGBColor[
              0.38129839578489, 0.5046832386394303, 0.9455169745038486], 
             UndirectedEdge[223, 268] -> 
             RGBColor[
              0.19724310055792588`, 0.32464538299422946`, 0.9345440748305314],
              UndirectedEdge[5, 69] -> 
             RGBColor[
              0.5662162318507189, 0.6577114998480007, 0.959566779515417], 
             UndirectedEdge[306, 486] -> 
             RGBColor[
              0.327052321983306, 0.4514131745442476, 0.942290581481863], 
             UndirectedEdge[5, 348] -> 
             RGBColor[
              0.575828354505173, 0.6657991165139304, 0.9602449937132509], 
             UndirectedEdge[279, 409] -> 
             RGBColor[
              0.23060819410886862`, 0.3597142117853851, 0.9364441675490249], 
             UndirectedEdge[463, 483] -> 
             RGBColor[
              0.5035999579863275, 0.6078494794543214, 0.954073961892099], 
             UndirectedEdge[351, 371] -> 
             RGBColor[
              0.2471362919389416, 0.37708629054672044`, 0.937385418269318], 
             UndirectedEdge[335, 421] -> 
             RGBColor[
              0.19735590244149465`, 0.3247639449259127, 0.9345504987309252], 
             UndirectedEdge[259, 418] -> 
             RGBColor[
              0.5798892585592409, 0.6691924959032061, 0.9604986680920036], 
             UndirectedEdge[168, 302] -> 
             RGBColor[
              0.268736668858344, 0.3997896562320101, 0.9386155277799839], 
             UndirectedEdge[87, 336] -> 
             RGBColor[
              0.4668814361724666, 0.5741090231571706, 0.9522620155496091], 
             UndirectedEdge[36, 266] -> 
             RGBColor[
              0.9938574384892986, 0.9902625241719002, 0.644943793687154], 
             UndirectedEdge[161, 430] -> 
             RGBColor[
              0.2077033952850149, 0.33563981597339154`, 0.9351397731406197], 
             UndirectedEdge[220, 412] -> 
             RGBColor[
              0.2036444979201258, 0.3313736574939363, 0.9349086249402898], 
             UndirectedEdge[372, 404] -> 
             RGBColor[
              0.7255490713882455, 0.7852295819730946, 0.9735376602371271], 
             UndirectedEdge[38, 287] -> 
             RGBColor[
              0.4114868433754372, 0.5286278492274263, 0.9479475143104742], 
             UndirectedEdge[171, 497] -> 
             RGBColor[
              0.47443851953832683`, 0.5842095892297761, 0.9517686846650694], 
             UndirectedEdge[246, 411] -> 
             RGBColor[
              0.2605541594338602, 0.3911893200258155, 0.9381495459731974], 
             UndirectedEdge[75, 303] -> 
             RGBColor[
              0.853058182050049, 0.3979604671775163, 0.19801610025913619`], 
             UndirectedEdge[23, 39] -> 
             RGBColor[
              0.3397705873831411, 0.4630597387061178, 0.9430778872171774], 
             UndirectedEdge[61, 391] -> 
             RGBColor[
              0.731686882991318, 0.7866873766200184, 0.8813805065527239], 
             UndirectedEdge[19, 200] -> 
             RGBColor[
              0.23309658772441674`, 0.3623296712485939, 0.936585877884182], 
             UndirectedEdge[208, 403] -> 
             RGBColor[
              0.5850117948684971, 0.6717049428230532, 0.961732098971587], 
             UndirectedEdge[108, 378] -> 
             RGBColor[
              0.20828889068141454`, 0.33625520875755976`, 0.9351731162372818],
              UndirectedEdge[10, 451] -> 
             RGBColor[
              0.2159367879573847, 0.34429363369929844`, 0.9356086526730982], 
             UndirectedEdge[199, 262] -> 
             RGBColor[
              0.36465083425503464`, 0.49026395757304103`, 0.944456206604027], 
             UndirectedEdge[3, 401] -> 
             RGBColor[
              0.18219297080333685`, 0.308826742388816, 0.9336869922056792], 
             UndirectedEdge[241, 311] -> 
             RGBColor[
              0.2028072709740812, 0.33049367889038916`, 0.934860946104279], 
             UndirectedEdge[179, 255] -> 
             RGBColor[
              0.19864123735537692`, 0.32611491341534343`, 0.9346236966527881],
              UndirectedEdge[276, 462] -> 
             RGBColor[
              0.20183278400452248`, 0.3294694312993405, 0.9348054505129868], 
             UndirectedEdge[167, 289] -> 
             RGBColor[
              0.2249680527429054, 0.35378606560414083`, 0.9361229698420748], 
             UndirectedEdge[164, 348] -> 
             RGBColor[
              0.38905288991990644`, 0.5111618708489473, 0.9460768222550604], 
             UndirectedEdge[18, 172] -> 
             RGBColor[
              0.2559027333199868, 0.38630037626268543`, 0.9378846541371808], 
             UndirectedEdge[289, 300] -> 
             RGBColor[
              0.2209681235766699, 0.34958188644027033`, 0.9358951797934225], 
             UndirectedEdge[59, 188] -> 
             RGBColor[
              0.24348630056862833`, 0.373249918193702, 0.937177556660457], 
             UndirectedEdge[352, 357] -> 
             RGBColor[
              0.185968194480225, 0.3127947418362315, 0.9339019856091351], 
             UndirectedEdge[161, 409] -> 
             RGBColor[
              0.23354210119449076`, 0.36279793415282724`, 0.9366112492172245],
              UndirectedEdge[39, 157] -> 
             RGBColor[
              0.2733433157427147, 0.4046315341857658, 0.9388778695051255], 
             UndirectedEdge[216, 398] -> 
             RGBColor[
              0.20308712437898663`, 0.33078782256267547`, 0.9348768833416823],
              UndirectedEdge[279, 396] -> 
             RGBColor[
              0.2027106095200159, 0.3303920815734764, 0.9348554413774677], 
             UndirectedEdge[103, 390] -> 
             RGBColor[
              0.3328589413831152, 0.4578427188183445, 0.9426093080634266], 
             UndirectedEdge[128, 296] -> 
             RGBColor[
              0.1882426629696768, 0.3151853524282767, 0.9340315132248347], 
             UndirectedEdge[362, 369] -> 
             RGBColor[
              0.1806318866536843, 0.30718594396907933`, 0.9335980907727736], 
             UndirectedEdge[86, 412] -> 
             RGBColor[
              0.18778375020070825`, 0.3147030060113407, 0.9340053788215426], 
             UndirectedEdge[261, 299] -> 
             RGBColor[
              0.2846830813812443, 0.4146506586338333, 0.9395932092741723], 
             UndirectedEdge[208, 266] -> 
             RGBColor[
              0.7100990368535118, 0.7663088762344812, 0.7456861929885767], 
             UndirectedEdge[211, 236] -> 
             RGBColor[
              0.1979212488225095, 0.32535815981739014`, 0.934582694370969], 
             UndirectedEdge[19, 124] -> 
             RGBColor[
              0.1942932572468809, 0.3215449106434528, 0.9343760856178694], 
             UndirectedEdge[319, 330] -> 
             RGBColor[
              0.18522178171588122`, 0.3120102146956035, 0.9338594785064245], 
             UndirectedEdge[137, 267] -> 
             RGBColor[
              0.22045636616771785`, 0.34904399695616795`, 0.93586603596606], 
             UndirectedEdge[23, 240] -> 
             RGBColor[
              0.7133780917330446, 0.7699270698367418, 0.8123932263629633], 
             UndirectedEdge[135, 369] -> 
             RGBColor[
              0.18101136995755066`, 0.307584804982074, 0.9336197017855334], 
             UndirectedEdge[13, 335] -> 
             RGBColor[
              0.23166019252299075`, 0.36081992881917935`, 0.936504077302417], 
             UndirectedEdge[176, 178] -> 
             RGBColor[
              0.3931214338805177, 0.5144895563820213, 0.9463902997884908], 
             UndirectedEdge[335, 459] -> 
             RGBColor[
              0.2024275249318897, 0.3300945417227562, 0.93483932012896], 
             UndirectedEdge[83, 326] -> 
             RGBColor[
              0.8603044472818449, 0.8888437109835485, 0.8510148449573589], 
             UndirectedEdge[33, 76] -> 
             RGBColor[
              0.3333497551271607, 0.45830089859572654`, 0.9426393717347399], 
             UndirectedEdge[13, 285] -> 
             RGBColor[
              0.2336665281569335, 0.36292871477947963`, 0.9366183351486626], 
             UndirectedEdge[225, 309] -> 
             RGBColor[
              0.18608052902366917`, 0.31291281256381276`, 0.9339083828952002],
              UndirectedEdge[242, 499] -> 
             RGBColor[
              0.8008428775112291, 0.844405505952868, 0.9471498665869478], 
             UndirectedEdge[13, 287] -> 
             RGBColor[
              0.2785495730651827, 0.41010364072745936`, 0.9391743581576726], 
             UndirectedEdge[265, 270] -> 
             RGBColor[
              0.18221828136351503`, 0.30885334539234544`, 0.9336884336046377],
              UndirectedEdge[191, 311] -> 
             RGBColor[
              0.19029060642002155`, 0.31733787084170345`, 0.934148140574671], 
             UndirectedEdge[47, 452] -> 
             RGBColor[
              0.2542089051352215, 0.3845200554455873, 0.9377881931278527], 
             UndirectedEdge[14, 80] -> 
             RGBColor[
              0.28919811932082623`, 0.417720629815705, 0.9399116866604884], 
             UndirectedEdge[152, 292] -> 
             RGBColor[
              0.18467767702367152`, 0.3114383261658612, 0.9338284925491338], 
             UndirectedEdge[133, 311] -> 
             RGBColor[
              0.19398258593487913`, 0.3212183753968402, 0.9343583933462479], 
             UndirectedEdge[187, 398] -> 
             RGBColor[
              0.21375269941056224`, 0.341998018157376, 0.9354842720614263], 
             UndirectedEdge[130, 442] -> 
             RGBColor[
              0.2704116943765009, 0.4015502142543449, 0.9387109180052648], 
             UndirectedEdge[304, 433] -> 
             RGBColor[
              0.1856912324704567, 0.31250363720355945`, 0.9338862130324074], 
             UndirectedEdge[354, 409] -> 
             RGBColor[
              0.28191067367276634`, 0.4134660896464276, 0.9393720026838029], 
             UndirectedEdge[29, 412] -> 
             RGBColor[
              0.18734250753660958`, 0.3142392319949723, 0.9339802507045822], 
             UndirectedEdge[295, 391] -> 
             RGBColor[
              0.7289553207863748, 0.7855578054503277, 0.9266495613450138], 
             UndirectedEdge[21, 298] -> 
             RGBColor[
              0.2878456584957702, 0.4198744159208656, 0.9397037564706185], 
             UndirectedEdge[383, 395] -> 
             RGBColor[
              0.3859577461997916, 0.503550871102866, 0.9463338532888385], 
             UndirectedEdge[133, 241] -> 
             RGBColor[
              0.2068052594645497, 0.3346958182809826, 0.9350886256343172], 
             UndirectedEdge[142, 473] -> 
             RGBColor[
              0.23965328121814944`, 0.36922117182888525`, 0.9369592718788913],
              UndirectedEdge[95, 330] -> 
             RGBColor[
              0.18713069149999506`, 0.314016599910578, 0.9339681880946508], 
             UndirectedEdge[275, 431] -> 
             RGBColor[
              0.4552821797756804, 0.5677869422920205, 0.9505011954058309], 
             UndirectedEdge[180, 474] -> 
             RGBColor[
              0.24632928568632426`, 0.37623807580806795`, 0.9373394604570903],
              UndirectedEdge[82, 173] -> 
             RGBColor[
              0.6203596764497656, 0.7014764485955354, 0.964075560146658], 
             UndirectedEdge[205, 230] -> 
             RGBColor[
              0.22168982682145016`, 0.35034044230916306`, 0.9359362797255486],
              UndirectedEdge[460, 463] -> 
             RGBColor[
              0.42791636353987605`, 0.5415498055841811, 0.9492787976467367], 
             UndirectedEdge[121, 500] -> 
             RGBColor[
              0.20306057228198376`, 0.33075991462522525`, 0.9348753712390383],
              UndirectedEdge[88, 241] -> 
             RGBColor[
              0.2025944621469051, 0.33027000332016815`, 0.9348488269563937], 
             UndirectedEdge[60, 73] -> 
             RGBColor[
              0.781195634641831, 0.8278300365608096, 0.9249593462199677], 
             UndirectedEdge[75, 400] -> 
             RGBColor[
              0.9275933480888754, 0.7357010879276322, 0.5134508624919265], 
             UndirectedEdge[141, 274] -> 
             RGBColor[
              0.2256966978230941, 0.35455191778218553`, 0.9361644651014577], 
             UndirectedEdge[299, 448] -> 
             RGBColor[
              0.2703287280609633, 0.40146301139634666`, 0.9387061931963326], 
             UndirectedEdge[160, 389] -> 
             RGBColor[
              0.21718512492406264`, 0.34560571500041215`, 0.9356797436166016],
              UndirectedEdge[24, 268] -> 
             RGBColor[
              0.18579615740306293`, 0.3126139199603535, 0.9338921883520968], 
             UndirectedEdge[386, 498] -> 
             RGBColor[
              0.540094387984412, 0.6311849610997022, 0.9594410817544053], 
             UndirectedEdge[350, 476] -> 
             RGBColor[
              0.18247717121909524`, 0.3091254550451252, 0.9337031769989198], 
             UndirectedEdge[180, 331] -> 
             RGBColor[
              0.2822898900471109, 0.4140349510252597, 0.9393873636764902], 
             UndirectedEdge[225, 252] -> 
             RGBColor[
              0.18313599846224066`, 0.30981792424973087`, 0.9337406962357694],
              UndirectedEdge[100, 203] -> 
             RGBColor[
              0.9191489665110915, 0.667681353565574, 0.3474800185895157], 
             UndirectedEdge[445, 471] -> 
             RGBColor[
              0.9599777422905198, 0.9272913458979556, 0.6345862231732597], 
             UndirectedEdge[373, 498] -> 
             RGBColor[
              0.8827929559209364, 0.907189051483757, 0.8884954173694475], 
             UndirectedEdge[102, 309] -> 
             RGBColor[
              0.19381918087775277`, 0.3210466263213213, 0.9343490876699807], 
             UndirectedEdge[46, 86] -> 
             RGBColor[
              0.19451109914847642`, 0.321773876294004, 0.9343884913918972], 
             UndirectedEdge[294, 385] -> 
             RGBColor[
              0.18452375420061845`, 0.3112765435195617, 0.9338197268720694], 
             UndirectedEdge[27, 29] -> 
             RGBColor[
              0.18482045324878804`, 0.31158839303099417`, 0.9338366234439357],
              UndirectedEdge[274, 284] -> 
             RGBColor[
              0.22545727776759072`, 0.3543002721237432, 0.936150830483487], 
             UndirectedEdge[284, 300] -> 
             RGBColor[
              0.2193467291603231, 0.3478776981063463, 0.9358028437800496], 
             UndirectedEdge[159, 453] -> 
             RGBColor[
              0.23602331412857852`, 0.36540584626453976`, 0.9367525506231953],
              UndirectedEdge[229, 232] -> 
             RGBColor[
              0.2566501782178637, 0.3870859882410977, 0.9379272200183691], 
             UndirectedEdge[259, 431] -> 
             RGBColor[
              0.552262608455937, 0.6458932694477724, 0.9585643649749793], 
             UndirectedEdge[112, 483] -> 
             RGBColor[
              0.7227411345359493, 0.7787563213495963, 0.8541899154691762], 
             UndirectedEdge[78, 376] -> 
             RGBColor[
              0.4205848118936931, 0.5382565536141679, 0.9481458786566228], 
             UndirectedEdge[76, 351] -> 
             RGBColor[
              0.32530926006899097`, 0.449849828492759, 0.9421814774360235], 
             UndirectedEdge[178, 498] -> 
             RGBColor[
              0.6219478547908555, 0.7019387588473889, 0.96476604218581], 
             UndirectedEdge[400, 431] -> 
             RGBColor[
              0.7055601740591597, 0.7646836770228431, 0.882816923995621], 
             UndirectedEdge[18, 432] -> 
             RGBColor[
              0.2897732046951418, 0.4219003891898929, 0.9398135273751238], 
             UndirectedEdge[220, 325] -> 
             RGBColor[
              0.22533443478540557`, 0.3541711563607717, 0.9361438347573814], 
             UndirectedEdge[353, 380] -> 
             RGBColor[
              0.18408835379335264`, 0.31081891008554513`, 0.9337949314629927],
              UndirectedEdge[5, 355] -> 
             RGBColor[
              0.624643054436057, 0.7054290889949936, 0.9640878657059478], 
             UndirectedEdge[367, 441] -> 
             RGBColor[
              0.20930859557874099`, 0.3373269832576745, 0.9352311869226664], 
             UndirectedEdge[21, 287] -> 
             RGBColor[
              0.30207832712053356`, 0.43483385304880307`, 0.9405142858934524],
              UndirectedEdge[175, 182] -> 
             RGBColor[
              0.3713372775098073, 0.4960554186499155, 0.9448822608556314], 
             UndirectedEdge[70, 371] -> 
             RGBColor[
              0.31191266997486483`, 0.4395307683313558, 0.9412808306475218], 
             UndirectedEdge[217, 496] -> 
             RGBColor[
              0.1835288398725976, 0.31023082547960007`, 0.9337630679729325], 
             UndirectedEdge[195, 292] -> 
             RGBColor[
              0.18660739700750423`, 0.31346658422018303`, 0.9339383872474483],
              UndirectedEdge[161, 285] -> 
             RGBColor[
              0.21411916928885952`, 0.34238320123499877`, 0.9355051419788516],
              UndirectedEdge[168, 370] -> 
             RGBColor[
              0.2607361826498604, 0.3913806379667703, 0.9381599119260695], 
             UndirectedEdge[50, 173] -> 
             RGBColor[
              0.800480264278042, 0.8445485570290475, 0.9806185434355512], 
             UndirectedEdge[19, 188] -> 
             RGBColor[
              0.21359720872912316`, 0.3418345875925049, 0.9354754170971461], 
             UndirectedEdge[147, 323] -> 
             RGBColor[
              0.905895222039182, 0.5694593928427707, 0.46819019532102185`], 
             UndirectedEdge[255, 260] -> 
             RGBColor[
              0.2034606107913817, 0.33118038046250897`, 0.9348981528403446], 
             UndirectedEdge[29, 350] -> 
             RGBColor[
              0.18297683433485876`, 0.309650632660264, 0.9337316320741772], 
             UndirectedEdge[348, 400] -> 
             RGBColor[
              0.7259744000228323, 0.7821275326457193, 0.8841834386643934], 
             UndirectedEdge[26, 124] -> 
             RGBColor[
              0.18513200243707828`, 0.31191585098124663`, 0.9338543657093131],
              UndirectedEdge[18, 93] -> 
             RGBColor[
              0.25547187449726694`, 0.38584751632197967`, 0.9378601173646254],
              UndirectedEdge[64, 223] -> 
             RGBColor[
              0.19649530119615788`, 0.32385939845179323`, 0.9345014887631486],
              UndirectedEdge[12, 335] -> 
             RGBColor[
              0.20220521707563277`, 0.32986088207069797`, 0.9348266600254211],
              UndirectedEdge[143, 498] -> 
             RGBColor[
              0.6776190672953443, 0.7471351571180758, 0.9691486839645342], 
             UndirectedEdge[44, 92] -> 
             RGBColor[
              0.2754748024457604, 0.40687186185472934`, 0.938999254519612], 
             UndirectedEdge[274, 389] -> 
             RGBColor[
              0.2195028960405469, 0.34804183939901356`, 0.9358117372528503], 
             UndirectedEdge[247, 401] -> 
             RGBColor[
              0.1825033131056717, 0.3091529318254084, 0.9337046657406869], 
             UndirectedEdge[111, 182] -> 
             RGBColor[
              0.35579432343932743`, 0.4825928930456521, 0.9438918775663551], 
             UndirectedEdge[157, 190] -> 
             RGBColor[
              0.2578198120642154, 0.3883153475726824, 0.9379938289356007], 
             UndirectedEdge[100, 360] -> 
             RGBColor[
              0.7946952326726424, 0.8354763984444047, 0.7327589869340729], 
             UndirectedEdge[59, 468] -> 
             RGBColor[
              0.24224871187808175`, 0.37194913401228247`, 0.9371070778153788],
              UndirectedEdge[101, 129] -> 
             RGBColor[
              0.2672434934849943, 0.39822023424183295`, 0.9385304936514267], 
             UndirectedEdge[180, 382] -> 
             RGBColor[
              0.23760741054514092`, 0.36707083203586066`, 0.9368427625706579],
              UndirectedEdge[145, 402] -> 
             RGBColor[
              0.21358684811844986`, 0.34182369793378664`, 0.9354748270756954],
              UndirectedEdge[90, 263] -> 
             RGBColor[
              0.24334458110817345`, 0.37310096205523113`, 0.9371694859468394],
              UndirectedEdge[98, 276] -> 
             RGBColor[
              0.20095020339638087`, 0.3285417831213411, 0.9347551888530141], 
             UndirectedEdge[224, 464] -> 
             RGBColor[
              0.20419415303821636`, 0.3319513798731969, 0.9349399269861233], 
             UndirectedEdge[261, 313] -> 
             RGBColor[
              0.3452565934007724, 0.4734656409279675, 0.9432204227264471], 
             UndirectedEdge[78, 219] -> 
             RGBColor[
              0.5697935423105139, 0.6612069230140997, 0.9595599186442647], 
             UndirectedEdge[393, 424] -> 
             RGBColor[
              0.20739385044843295`, 0.3353144647238677, 0.935122145020107], 
             UndirectedEdge[169, 211] -> 
             RGBColor[
              0.1856477523702797, 0.3124579368614757, 0.9338837369050252], 
             UndirectedEdge[176, 482] -> 
             RGBColor[
              0.3246527382525704, 0.45561961717846555`, 0.9419075632956775], 
             UndirectedEdge[35, 94] -> 
             RGBColor[
              0.18328807136271902`, 0.3099777625101124, 0.9337493565624799], 
             UndirectedEdge[114, 296] -> 
             RGBColor[
              0.18183178255671295`, 0.30844711064095676`, 0.9336664230693641],
              UndirectedEdge[130, 175] -> 
             RGBColor[
              0.350298253723786, 0.4772937364222603, 0.943561398674819], 
             UndirectedEdge[189, 383] -> 
             RGBColor[
              0.25987325139717643`, 0.39047364250719796`, 0.9381107692678216],
              UndirectedEdge[139, 437] -> 
             RGBColor[
              0.18225949462972918`, 0.3088966631482086, 0.9336907806391791], 
             UndirectedEdge[56, 324] -> 
             RGBColor[
              0.6732900844799101, 0.7406929401963493, 0.9670229089652596], 
             UndirectedEdge[398, 399] -> 
             RGBColor[
              0.2070690587330349, 0.3349730880380002, 0.9351036486124014], 
             UndirectedEdge[405, 429] -> 
             RGBColor[
              0.1868041703990252, 0.3136734055308251, 0.9339495932009951], 
             UndirectedEdge[12, 318] -> 
             RGBColor[
              0.19600810188078815`, 0.32334732108111897`, 0.9344737434828851],
              UndirectedEdge[11, 205] -> 
             RGBColor[
              0.3065274858845748, 0.4333315275623586, 0.9409938904047574], 
             UndirectedEdge[226, 389] -> 
             RGBColor[
              0.19095055240575043`, 0.3180315159156967, 0.9341857235222557], 
             UndirectedEdge[294, 327] -> 
             RGBColor[
              0.18563559838764718`, 0.312445162255122, 0.9338830447536945], 
             UndirectedEdge[167, 218] -> 
             RGBColor[
              0.26286988224919927`, 0.3936232915300437, 0.9382814229617262], 
             UndirectedEdge[217, 481] -> 
             RGBColor[
              0.19325559530187433`, 0.3204542621476837, 0.9343169923051846], 
             UndirectedEdge[247, 309] -> 
             RGBColor[
              0.18623761794577917`, 0.3130779229809633, 0.933917328876922], 
             UndirectedEdge[79, 234] -> 
             RGBColor[
              0.9063126289426009, 0.8289774045041336, 0.6243163382349994], 
             UndirectedEdge[331, 372] -> 
             RGBColor[
              0.4578529646135995, 0.56594472517835, 0.9516272296801642], 
             UndirectedEdge[27, 484] -> 
             RGBColor[
              0.1850117059565009, 0.3117894117529224, 0.933847515002707], 
             UndirectedEdge[103, 326] -> 
             RGBColor[
              0.56759306260054, 0.6573833324020449, 0.9602981460928508], 
             UndirectedEdge[155, 394] -> 
             RGBColor[
              0.1886886358497215, 0.3156540982015175, 0.9340569107205956], 
             UndirectedEdge[433, 469] -> 
             RGBColor[
              0.18101298547639227`, 0.3075865029948064, 0.9336197937869416], 
             UndirectedEdge[65, 412] -> 
             RGBColor[
              0.1867174620390582, 0.3135822695468723, 0.9339446552881686], 
             UndirectedEdge[13, 161] -> 
             RGBColor[
              0.23339794827523738`, 0.36264642029486893`, 0.9366030399217282],
              UndirectedEdge[229, 480] -> 
             RGBColor[
              0.23910094988203007`, 0.36864063657479446`, 0.9369278174264002],
              UndirectedEdge[32, 448] -> 
             RGBColor[
              0.26012823284654724`, 0.3907416441772443, 0.938125290084152], 
             UndirectedEdge[251, 453] -> 
             RGBColor[
              0.23943021557072935`, 0.3689867156902678, 0.9369465686202667], 
             UndirectedEdge[282, 310] -> 
             RGBColor[
              0.6707630336058359, 0.74272444693153, 0.9678190486190441], 
             UndirectedEdge[392, 473] -> 
             RGBColor[
              0.2502222365996353, 0.3803298140453018, 0.9375611582524985], 
             UndirectedEdge[222, 344] -> 
             RGBColor[
              0.1936890488951341, 0.3209098493567448, 0.9343416768460837], 
             UndirectedEdge[266, 440] -> 
             RGBColor[
              0.9426079391450114, 0.7947470752330569, 0.3871278708766489], 
             UndirectedEdge[16, 361] -> 
             RGBColor[
              0.2501087241581385, 0.3802105052721842, 0.9375546938868818], 
             UndirectedEdge[412, 426] -> 
             RGBColor[
              0.18880630124033773`, 0.3157777719874718, 0.9340636115905208], 
             UndirectedEdge[274, 460] -> 
             RGBColor[
              0.27237898950751444`, 0.4036179661707557, 0.9388229525526237], 
             UndirectedEdge[180, 230] -> 
             RGBColor[
              0.2345216927400936, 0.3638275469769471, 0.9366670355065708], 
             UndirectedEdge[375, 450] -> 
             RGBColor[
              0.20913463295766446`, 0.3371441375130559, 0.9352212800087508], 
             UndirectedEdge[6, 123] -> 
             RGBColor[
              0.20012045196386746`, 0.3276696617564901, 0.9347079357364398], 
             UndirectedEdge[170, 466] -> 
             RGBColor[
              0.19131064180456064`, 0.3184099927048328, 0.9342062300808134], 
             UndirectedEdge[267, 280] -> 
             RGBColor[
              0.24136535807007609`, 0.3710206731522022, 0.9370567721228178], 
             UndirectedEdge[52, 214] -> 
             RGBColor[
              0.18377002501748835`, 0.3104843263589016, 0.9337768031101326], 
             UndirectedEdge[358, 386] -> 
             RGBColor[
              0.2652427547751048, 0.39611733100357804`, 0.9384165545417262], 
             UndirectedEdge[230, 413] -> 
             RGBColor[
              0.21810416040748024`, 0.34657167956369916`, 0.9357320813277911],
              UndirectedEdge[53, 207] -> 
             RGBColor[
              0.8538308363641018, 0.3886921926180247, 0.19816051774968563`], 
             UndirectedEdge[188, 256] -> 
             RGBColor[
              0.26776710539076976`, 0.3985106384029728, 0.9385698304401877], 
             UndirectedEdge[38, 87] -> 
             RGBColor[
              0.4136160612646935, 0.5308657922292461, 0.9480687701193717], 
             UndirectedEdge[22, 52] -> 
             RGBColor[
              0.18089659272171946`, 0.3074641668299184, 0.9336131653917505], 
             UndirectedEdge[160, 460] -> 
             RGBColor[
              0.27006121839103014`, 0.4011818417721542, 0.938690958916375], 
             UndirectedEdge[63, 159] -> 
             RGBColor[
              0.2194636807819041, 0.34800062167578893`, 0.9358095040018843], 
             UndirectedEdge[285, 430] -> 
             RGBColor[
              0.20797197516671106`, 0.33592211045800224`, 0.935155068367554], 
             UndirectedEdge[132, 356] -> 
             RGBColor[
              0.2588153820462965, 0.38936175474663237`, 0.9380505251732665], 
             UndirectedEdge[99, 373] -> 
             RGBColor[
              0.9853487541189616, 0.9874627176430353, 0.859036977734402], 
             UndirectedEdge[243, 396] -> 
             RGBColor[
              0.19700888147424034`, 0.32439920388692833`, 0.9345307364002116],
              UndirectedEdge[118, 292] -> 
             RGBColor[
              0.188665488336347, 0.3156297686973238, 0.9340555925039526], 
             UndirectedEdge[84, 176] -> 
             RGBColor[
              0.29622447069818203`, 0.4279240901305121, 0.9402086344933376], 
             UndirectedEdge[334, 385] -> 
             RGBColor[
              0.18420532827080235`, 0.310941857677955, 0.9338015929864353], 
             UndirectedEdge[25, 325] -> 
             RGBColor[
              0.26126519476067855`, 0.3919366632365452, 0.9381900383831774], 
             UndirectedEdge[321, 397] -> 
             RGBColor[
              0.9037224589823456, 0.5792136748312032, 0.5298753084241274], 
             UndirectedEdge[201, 235] -> 
             RGBColor[
              0.23728480229023638`, 0.36673175030541116`, 0.9368243905077971],
              UndirectedEdge[321, 498] -> 
             RGBColor[
              0.8800107385388454, 0.9060385330965369, 0.934603959538476], 
             UndirectedEdge[368, 492] -> 
             RGBColor[
              0.18092029968887635`, 0.3074890843555088, 0.9336145154684589], 
             UndirectedEdge[239, 387] -> 
             RGBColor[
              0.1927675658632359, 0.3199413122648211, 0.934289199750629], 
             UndirectedEdge[196, 500] -> 
             RGBColor[
              0.1964924261713618, 0.32385637661844546`, 0.9345013250347398], 
             UndirectedEdge[122, 185] -> 
             RGBColor[
              0.19860974920189184`, 0.3260818173695664, 0.9346219034490297], 
             UndirectedEdge[350, 377] -> 
             RGBColor[
              0.181157971499196, 0.3077388924974179, 0.9336280505264527], 
             UndirectedEdge[315, 353] -> 
             RGBColor[
              0.18205882341933505`, 0.3086857449827948, 0.9336793527106135], 
             UndirectedEdge[102, 480] -> 
             RGBColor[
              0.2214017905721769, 0.3500376979486238, 0.9359198764872638], 
             UndirectedEdge[127, 253] -> 
             RGBColor[
              0.604821677598294, 0.6851926412626169, 0.9645634759762418], 
             UndirectedEdge[159, 192] -> 
             RGBColor[
              0.27255273720121065`, 0.4034082682269394, 0.9388472119027095], 
             UndirectedEdge[201, 289] -> 
             RGBColor[
              0.23376233339509425`, 0.3630294121591895, 0.9366237911152446], 
             UndirectedEdge[29, 194] -> 
             RGBColor[
              0.18526819594198288`, 0.31205899899006834`, 0.9338621217279373],
              UndirectedEdge[79, 388] -> 
             RGBColor[
              0.6074674522288179, 0.6856239979057058, 0.9655884516290124], 
             UndirectedEdge[246, 402] -> 
             RGBColor[
              0.22901412567720097`, 0.3580387447939263, 0.9363533877100543], 
             UndirectedEdge[185, 398] -> 
             RGBColor[
              0.20890004242653637`, 0.3368975679909415, 0.9352079204250486], 
             UndirectedEdge[133, 304] -> 
             RGBColor[
              0.19434480354761932`, 0.3215990890737532, 0.9343790211034406], 
             UndirectedEdge[107, 314] -> 
             RGBColor[
              0.2370472271918243, 0.36648204381384886`, 0.9368108609574035], 
             UndirectedEdge[13, 279] -> 
             RGBColor[
              0.23046404118961528`, 0.35956269792742684`, 0.9364359582535287],
              UndirectedEdge[180, 418] -> 
             RGBColor[
              0.3698251689882062, 0.48989999728181594`, 0.9451142408333664], 
             UndirectedEdge[112, 207] -> 
             RGBColor[
              0.9342142442860358, 0.7583914671293646, 0.48787682484366524`], 
             UndirectedEdge[308, 369] -> 
             RGBColor[
              0.18646563701697516`, 0.31331758548203437`, 0.9339303142257027],
              UndirectedEdge[45, 292] -> 
             RGBColor[
              0.193148625604734, 0.3203418302137187, 0.93431090053918], 
             UndirectedEdge[348, 418] -> 
             RGBColor[
              0.4692928666535278, 0.5800321164088754, 0.9513636000208304], 
             UndirectedEdge[51, 264] -> 
             RGBColor[
              0.930398195461806, 0.7373009794201983, 0.46708003654237346`], 
             UndirectedEdge[201, 218] -> 
             RGBColor[
              0.27166416290138806`, 0.4028666380850924, 0.938782244234896], 
             UndirectedEdge[262, 376] -> 
             RGBColor[
              0.3571381356790589, 0.48375683566574046`, 0.9439775040939842], 
             UndirectedEdge[304, 307] -> 
             RGBColor[
              0.19124101859615344`, 0.3183368142984305, 0.9342022651420929], 
             UndirectedEdge[8, 166] -> 
             RGBColor[
              0.19658418244763454`, 0.3239528182824921, 0.9345065504189323], 
             UndirectedEdge[66, 312] -> 
             RGBColor[
              0.19642559622123856`, 0.32378613410360235`, 0.9344975191679463],
              UndirectedEdge[202, 430] -> 
             RGBColor[
              0.19415820437315612`, 0.32140296151032133`, 0.9343683945565036],
              UndirectedEdge[348, 404] -> 
             RGBColor[
              0.6494536944870786, 0.7234519269470636, 0.967547153420917], 
             UndirectedEdge[1, 113] -> 
             RGBColor[
              0.1979971628023344, 0.3254379502234105, 0.9345870175598152], 
             UndirectedEdge[29, 377] -> 
             RGBColor[
              0.18261049498864607`, 0.3092655867801383, 0.9337107695903608], 
             UndirectedEdge[259, 404] -> 
             RGBColor[
              0.7600500863927916, 0.8126123064413943, 0.97668222149209], 
             UndirectedEdge[131, 449] -> 
             RGBColor[
              0.9086679607710296, 0.6083135329493521, 0.2853739255705805], 
             UndirectedEdge[423, 465] -> 
             RGBColor[
              0.1791246132879326, 0.3056017040950233, 0.9335122537844052], 
             UndirectedEdge[177, 412] -> 
             RGBColor[
              0.1873190234343715, 0.314214548714542, 0.9339789133197014], 
             UndirectedEdge[139, 158] -> 
             RGBColor[
              0.18715334052902155`, 0.3140404054761162, 0.9339694779233476], 
             UndirectedEdge[454, 500] -> 
             RGBColor[
              0.206190516482255, 0.33404968442963456`, 0.9350536169309063], 
             UndirectedEdge[430, 459] -> 
             RGBColor[
              0.19801808656198788`, 0.32545994242144927`, 0.9345882091369736],
              UndirectedEdge[474, 490] -> 
             RGBColor[
              0.22274072146667342`, 0.35144499921186156`, 0.9359961266209347],
              UndirectedEdge[443, 451] -> 
             RGBColor[
              0.24646170398602968`, 0.37637725583686343`, 0.9373470014833631],
              UndirectedEdge[182, 483] -> 
             RGBColor[
              0.3985189663280868, 0.5195988313129054, 0.9466142540313085], 
             UndirectedEdge[92, 457] -> 
             RGBColor[
              0.37059515571215895`, 0.49157695819153635`, 0.9450791109885306],
              UndirectedEdge[38, 184] -> 
             RGBColor[
              0.5298276783437619, 0.6291770036011967, 0.9561291221434074], 
             UndirectedEdge[51, 457] -> 
             RGBColor[
              0.7322518449471631, 0.7861260863844587, 0.8380007601438797], 
             UndirectedEdge[321, 455] -> 
             RGBColor[
              0.7992398811281014, 0.8424906663250493, 0.9268604994645402], 
             UndirectedEdge[251, 435] -> 
             RGBColor[
              0.2386642748374078, 0.3681816634160995, 0.9369029494286119], 
             UndirectedEdge[16, 441] -> 
             RGBColor[
              0.2457921380966431, 0.37567349963418883`, 0.9373088706964965], 
             UndirectedEdge[302, 390] -> 
             RGBColor[
              0.25033731885124844`, 0.38045077278838335`, 0.9375677120164789],
              UndirectedEdge[186, 455] -> 
             RGBColor[
              0.8031839177998501, 0.842431819201664, 0.7386664277516752], 
             UndirectedEdge[349, 353] -> 
             RGBColor[
              0.18295144203234145`, 0.3096239437403533, 0.9337301860201135], 
             UndirectedEdge[125, 406] -> 
             RGBColor[
              0.5972259557238873, 0.6808172474310844, 0.9631312731906503], 
             UndirectedEdge[307, 433] -> 
             RGBColor[
              0.18622321839671918`, 0.3130627881419171, 0.9339165088439054], 
             UndirectedEdge[406, 419] -> 
             RGBColor[
              0.5328942370686292, 0.630560819878426, 0.9567192886891854], 
             UndirectedEdge[237, 274] -> 
             RGBColor[
              0.23848727143504053`, 0.36799562161754756`, 0.9368928693467], 
             UndirectedEdge[203, 264] -> 
             RGBColor[
              0.8553074725725389, 0.4148947299646385, 0.20015613150748274`], 
             UndirectedEdge[69, 231] -> 
             RGBColor[
              0.6032570715569849, 0.6866480853473442, 0.9632586642510103], 
             UndirectedEdge[328, 399] -> 
             RGBColor[
              0.22543273121464985`, 0.354274472140261, 0.9361494325936104], 
             UndirectedEdge[78, 262] -> 
             RGBColor[
              0.4066140424697561, 0.526155775330442, 0.9472556735827959], 
             UndirectedEdge[27, 412] -> 
             RGBColor[
              0.18773360296108882`, 0.31465029808298206`, 0.9340025230104325],
              UndirectedEdge[147, 221] -> 
             RGBColor[
              0.8906777697244648, 0.5160364512426465, 0.23692570222520362`], 
             UndirectedEdge[93, 289] -> 
             RGBColor[
              0.21635167337317993`, 0.34472970457655394`, 0.93563227978376], 
             UndirectedEdge[141, 235] -> 
             RGBColor[
              0.21221346212045616`, 0.34038018217219357`, 0.9353966147748521],
              UndirectedEdge[185, 464] -> 
             RGBColor[
              0.2069974759051772, 0.3348978499473083, 0.9350995720762522], 
             UndirectedEdge[6, 189] -> 
             RGBColor[
              0.23318323402672853`, 0.3624207420060165, 0.9365908122629168], 
             UndirectedEdge[38, 316] -> 
             RGBColor[
              0.4787664530256467, 0.5873266421968035, 0.9522189657129314], 
             UndirectedEdge[322, 343] -> 
             RGBColor[
              0.8335064289062653, 0.2585506719501317, 0.17971910020172568`], 
             UndirectedEdge[93, 141] -> 
             RGBColor[
              0.21496969901233648`, 0.34327716190107216`, 0.9355535783883577],
              UndirectedEdge[191, 237] -> 
             RGBColor[
              0.21174339074199797`, 0.3398861073491872, 0.9353698449052572], 
             UndirectedEdge[145, 461] -> 
             RGBColor[
              0.23115805437216275`, 0.3602921497852615, 0.9364754812775742], 
             UndirectedEdge[420, 500] -> 
             RGBColor[
              0.19451665335716928`, 0.32177971411949735`, 0.9343888076958655],
              UndirectedEdge[402, 458] -> 
             RGBColor[
              0.2285757051250969, 0.3575779369961964, 0.9363284203081972], 
             UndirectedEdge[148, 263] -> 
             RGBColor[
              0.24948680213618696`, 0.3795568257949794, 0.9375192763477829], 
             UndirectedEdge[126, 499] -> 
             RGBColor[
              0.5585145617417738, 0.6524663078730726, 0.9583874586880152], 
             UndirectedEdge[133, 371] -> 
             RGBColor[
              0.22603138593843586`, 0.35490369621186185`, 0.9361835250944996],
              UndirectedEdge[72, 245] -> 
             RGBColor[
              0.22752065341650146`, 0.35646901075632065`, 0.9362683366742017],
              UndirectedEdge[57, 131] -> 
             RGBColor[
              0.8981850447320697, 0.6159608551699692, 0.564028013817431], 
             UndirectedEdge[15, 173] -> 
             RGBColor[
              0.6865018666299831, 0.7550197429095551, 0.9693877484071343], 
             UndirectedEdge[138, 415] -> 
             RGBColor[
              0.18158458466446153`, 0.308187289982949, 0.9336523455150969], 
             UndirectedEdge[105, 109] -> 
             RGBColor[
              0.2025306105640042, 0.3302028912581151, 0.9348451907032074], 
             UndirectedEdge[235, 284] -> 
             RGBColor[
              0.2119740420649528, 0.3401285365137513, 0.9353829801568815], 
             UndirectedEdge[150, 473] -> 
             RGBColor[
              0.23947719025137565`, 0.36903608905799384`, 0.9369492437588367],
              UndirectedEdge[74, 417] -> 
             RGBColor[
              0.1929190076012242, 0.3201004871334076, 0.9342978241335694], 
             UndirectedEdge[20, 413] -> 
             RGBColor[
              0.23603377197510877`, 0.36541683812430875`, 0.9367531461820842],
              UndirectedEdge[34, 467] -> 
             RGBColor[
              0.20003782336254744`, 0.32758281385754684`, 0.9347032301598326],
              UndirectedEdge[62, 110] -> 
             RGBColor[
              0.33413455286534527`, 0.45851113631971724`, 0.9427065695832899],
              UndirectedEdge[93, 389] -> 
             RGBColor[
              0.20877589722978934`, 0.3367670835179003, 0.9352008505397502], 
             UndirectedEdge[28, 408] -> 
             RGBColor[
              0.7065627960875993, 0.7690478747515729, 0.9714624707191005], 
             UndirectedEdge[93, 284] -> 
             RGBColor[
              0.21473027895683314`, 0.3430255162426299, 0.9355399437703871], 
             UndirectedEdge[143, 313] -> 
             RGBColor[
              0.4709361194251123, 0.5788655180367319, 0.9521839040886261], 
             UndirectedEdge[361, 398] -> 
             RGBColor[
              0.21817994857503456`, 0.3466513377330461, 0.9357363973518147], 
             UndirectedEdge[105, 382] -> 
             RGBColor[
              0.2017475218904906, 0.3293798154115627, 0.9348005949617267], 
             UndirectedEdge[240, 495] -> 
             RGBColor[
              0.9404490296531263, 0.7834756918464549, 0.4513533807985771], 
             UndirectedEdge[13, 21] -> 
             RGBColor[
              0.27647406119866225`, 0.4079221461606935, 0.9390561608273189], 
             UndirectedEdge[32, 179] -> 
             RGBColor[
              0.20989223640499494`, 0.3379404267710331, 0.9352644244043025], 
             UndirectedEdge[38, 79] -> 
             RGBColor[
              0.7025334025034438, 0.7661868171424233, 0.9721373827063131], 
             UndirectedEdge[328, 407] -> 
             RGBColor[
              0.26005803844889097`, 0.3906678654147257, 0.9381212926170488], 
             UndirectedEdge[357, 367] -> 
             RGBColor[
              0.19284697546686017`, 0.3200247767930899, 0.9342937220100794], 
             UndirectedEdge[196, 213] -> 
             RGBColor[
              0.19710682911621347`, 0.3245021530688812, 0.9345363143735214], 
             UndirectedEdge[233, 326] -> 
             RGBColor[
              0.8439697158415906, 0.8784945870094583, 0.9607638453803016], 
             UndirectedEdge[164, 372] -> 
             RGBColor[
              0.4651482668210734, 0.5729395258749782, 0.9520673290712703], 
             UndirectedEdge[3, 278] -> 
             RGBColor[
              0.1840613533248448, 0.3107905308812148, 0.9337933938262548], 
             UndirectedEdge[195, 399] -> 
             RGBColor[
              0.19798691924192627`, 0.3254271835919423, 0.9345864342042041], 
             UndirectedEdge[118, 187] -> 
             RGBColor[
              0.20672865124829637`, 0.33461529818845887`, 0.9350842629097332],
              UndirectedEdge[61, 178] -> 
             RGBColor[
              0.7297842099398613, 0.7851427009224017, 0.8812307211603922], 
             UndirectedEdge[2, 496] -> 
             RGBColor[
              0.18500487281902223`, 0.3117822296921864, 0.9338471258656362], 
             UndirectedEdge[103, 404] -> 
             RGBColor[
              0.6233155210312117, 0.7010502757004149, 0.96581591387943], 
             UndirectedEdge[37, 374] -> 
             RGBColor[
              0.8546495293295531, 0.4156398998574755, 0.19975329213765833`], 
             UndirectedEdge[236, 466] -> 
             RGBColor[
              0.2016228242267626, 0.329248750260696, 0.934793493614251], 
             UndirectedEdge[150, 254] -> 
             RGBColor[
              0.20389499448692971`, 0.33163694526804693`, 0.9349228903491928],
              UndirectedEdge[148, 229] -> 
             RGBColor[
              0.25473807623061007`, 0.385076247818226, 0.9378183286388965], 
             UndirectedEdge[160, 432] -> 
             RGBColor[
              0.26534093705235057`, 0.3962205268020793, 0.9384221458771677], 
             UndirectedEdge[48, 198] -> 
             RGBColor[
              0.18614733394130184`, 0.3129830287679211, 0.9339121873364302], 
             UndirectedEdge[89, 178] -> 
             RGBColor[
              0.38949543937037706`, 0.5113489021851207, 0.9461592546246456], 
             UndirectedEdge[63, 239] -> 
             RGBColor[
              0.20172774579693858`, 0.3293590294833628, 0.934799468742455], 
             UndirectedEdge[425, 462] -> 
             RGBColor[
              0.1883728625948838, 0.3153222004895023, 0.9340389279008772], 
             UndirectedEdge[44, 457] -> 
             RGBColor[
              0.3741308449563232, 0.49529319176279873`, 0.9452804632604023], 
             UndirectedEdge[46, 254] -> 
             RGBColor[
              0.1980699244230848, 0.3255144273001723, 0.9345911612264759], 
             UndirectedEdge[1, 452] -> 
             RGBColor[
              0.21304293634488086`, 0.3412520121737673, 0.935443852104836], 
             UndirectedEdge[260, 299] -> 
             RGBColor[
              0.2249121050554158, 0.35372726103730096`, 0.9361197837040394], 
             UndirectedEdge[321, 341] -> 
             RGBColor[
              0.9898662415110249, 0.9892279829702391, 0.7558592343220067], 
             UndirectedEdge[249, 406] -> 
             RGBColor[
              0.5717259495199576, 0.6608964487773493, 0.960589670883349], 
             UndirectedEdge[398, 496] -> 
             RGBColor[
              0.19603720028339988`, 0.32337790534720917`, 0.9344754005938667],
              UndirectedEdge[382, 462] -> 
             RGBColor[
              0.20106839690715364`, 0.3286660119950647, 0.934761919798601], 
             UndirectedEdge[63, 272] -> 
             RGBColor[
              0.23201898916873956`, 0.36119704684288256`, 0.9365245102406003],
              UndirectedEdge[117, 270] -> 
             RGBColor[
              0.18183894581371152`, 0.308454639678239, 0.933666831006253], 
             UndirectedEdge[164, 404] -> 
             RGBColor[
              0.5764261418930885, 0.6604370522196931, 0.9628281641033989], 
             UndirectedEdge[133, 191] -> 
             RGBColor[
              0.19428859491049005`, 0.32154001023229684`, 0.9343758201047092],
              UndirectedEdge[307, 469] -> 
             RGBColor[
              0.186562771602089, 0.31341968008967747`, 0.9339358458966271], 
             UndirectedEdge[31, 237] -> 
             RGBColor[
              0.21243558089193113`, 0.3406136430841573, 0.9354092641102925], 
             UndirectedEdge[1, 468] -> 
             RGBColor[
              0.21038952484231582`, 0.33846310844856536`, 0.9352927442451355],
              UndirectedEdge[346, 395] -> 
             RGBColor[
              0.47277817219066315`, 0.5825384587097979, 0.951727273224181], 
             UndirectedEdge[214, 223] -> 
             RGBColor[
              0.1978649215993461, 0.32529895633449324`, 0.9345794866189384], 
             UndirectedEdge[264, 397] -> 
             RGBColor[
              0.8437768320344039, 0.3262651740296299, 0.18911437710616869`], 
             UndirectedEdge[103, 204] -> 
             RGBColor[
              0.3628536312078076, 0.48870731062358463`, 0.9443416904150619], 
             UndirectedEdge[110, 356] -> 
             RGBColor[
              0.3311960783219361, 0.45542261326454736`, 0.9425392278051263], 
             UndirectedEdge[184, 253] -> 
             RGBColor[
              0.4591640004744537, 0.5697502062280924, 0.9511350822856912], 
             UndirectedEdge[115, 417] -> 
             RGBColor[
              0.19405888879625283`, 0.3212985745420247, 0.9343627386813232], 
             UndirectedEdge[243, 459] -> 
             RGBColor[
              0.19552964555273866`, 0.32284443314445566`, 0.9344464961028154],
              UndirectedEdge[190, 349] -> 
             RGBColor[
              0.20086956962021285`, 0.3284570319101118, 0.9347505968787484], 
             UndirectedEdge[128, 222] -> 
             RGBColor[
              0.19567917188119596`, 0.32300159479618107`, 0.9344550114060167],
              UndirectedEdge[204, 275] -> 
             RGBColor[
              0.402607767889131, 0.5221630142088122, 0.9471448284585735], 
             UndirectedEdge[178, 455] -> 
             RGBColor[
              0.5411769973801115, 0.6383908920759014, 0.9570225821118743], 
             UndirectedEdge[84, 391] -> 
             RGBColor[
              0.3743150955210323, 0.495024736722043, 0.9453330205540728], 
             UndirectedEdge[54, 203] -> 
             RGBColor[
              0.9172982685013698, 0.6686889606982549, 0.5070233200844496], 
             UndirectedEdge[236, 314] -> 
             RGBColor[
              0.23558368231737692`, 0.3649437653567001, 0.9367275142419242], 
             UndirectedEdge[277, 313] -> 
             RGBColor[
              0.4022235011215268, 0.5228075131556505, 0.9468503037125551], 
             UndirectedEdge[186, 397] -> 
             RGBColor[
              0.9076664956540943, 0.5791548277078178, 0.3416812367112626], 
             UndirectedEdge[29, 297] -> 
             RGBColor[
              0.18984593669287142`, 0.3168704947647796, 0.9341228172915397], 
             UndirectedEdge[130, 208] -> 
             RGBColor[
              0.3647668975032984, 0.4898257484488929, 0.9444833278623301], 
             UndirectedEdge[145, 450] -> 
             RGBColor[
              0.21228550631692578`, 0.340455905190549, 0.9354007175852613], 
             UndirectedEdge[86, 350] -> 
             RGBColor[
              0.18341807699895743`, 0.3101144066766324, 0.9337567601911376], 
             UndirectedEdge[37, 281] -> 
             RGBColor[
              0.8401393429256434, 0.30410824875280007`, 0.18585832125036283`],
              UndirectedEdge[281, 445] -> 
             RGBColor[
              0.8907713717872949, 0.5149365980262008, 0.23825003998390762`], 
             UndirectedEdge[116, 224] -> 
             RGBColor[
              0.2412066178691736, 0.37085382713634363`, 0.9370477321032114], 
             UndirectedEdge[112, 163] -> 
             RGBColor[
              0.9463750065735652, 0.8136106484588435, 0.49802406298394036`], 
             UndirectedEdge[148, 480] -> 
             RGBColor[
              0.25899827885189075`, 0.38955399088563913`, 0.9380609408757734],
              UndirectedEdge[42, 487] -> 
             RGBColor[
              0.19664512493327133`, 0.3240168726988731, 0.934510021003333], 
             UndirectedEdge[122, 319] -> 
             RGBColor[
              0.1832707103845271, 0.30995951502128316`, 0.9337483678804552], 
             UndirectedEdge[129, 348] -> 
             RGBColor[
              0.37572812244985154`, 0.497829719871169, 0.9452933537370448], 
             UndirectedEdge[93, 201] -> 
             RGBColor[
              0.24004103918211672`, 0.36962873003428975`, 0.9369813541213027],
              UndirectedEdge[121, 427] -> 
             RGBColor[
              0.19582329677639237`, 0.3231530791990786, 0.9344632191055845], 
             UndirectedEdge[269, 411] -> 
             RGBColor[
              0.441541570634595, 0.5502832522185821, 0.9505633429393294], 
             UndirectedEdge[76, 371] -> 
             RGBColor[
              0.3322551655815734, 0.4571504155823287, 0.9425770364794188], 
             UndirectedEdge[61, 244] -> 
             RGBColor[
              0.7184903511263943, 0.775794731676694, 0.8803911147116745], 
             UndirectedEdge[184, 436] -> 
             RGBColor[
              0.4481781977283561, 0.5602348560519236, 0.9504350766490738], 
             UndirectedEdge[80, 293] -> 
             RGBColor[
              0.578582457393624, 0.6633186431495282, 0.9625149398020252], 
             UndirectedEdge[111, 460] -> 
             RGBColor[
              0.33363255379100343`, 0.46265113373051764`, 0.9425070766696382],
              UndirectedEdge[286, 358] -> 
             RGBColor[
              0.20613946196016764`, 0.33399602288987706`, 0.9350507094514018],
              UndirectedEdge[176, 244] -> 
             RGBColor[
              0.38182757506705056`, 0.5051415871363136, 0.945550693339773], 
             UndirectedEdge[99, 321] -> 
             RGBColor[
              0.9825665367368704, 0.9863121992558153, 0.9051455199034306], 
             UndirectedEdge[187, 478] -> 
             RGBColor[
              0.2352799848565821, 0.36462456006987354`, 0.9367102191208121], 
             UndirectedEdge[116, 185] -> 
             RGBColor[
              0.24400994073613447`, 0.3738002972104551, 0.9372073771933402], 
             UndirectedEdge[97, 257] -> 
             RGBColor[
              0.9757547061623437, 0.9298770721991836, 0.3603120410906092], 
             UndirectedEdge[16, 313] -> 
             RGBColor[
              0.3156685624243244, 0.4442664326028998, 0.9414658712422952], 
             UndirectedEdge[166, 344] -> 
             RGBColor[
              0.19297880215941118`, 0.32016333500525607`, 0.9343012293452001],
              UndirectedEdge[103, 443] -> 
             RGBColor[
              0.3488203865149018, 0.47461920966592475`, 0.9435182887508398], 
             UndirectedEdge[74, 115] -> 
             RGBColor[
              0.18984673852773665`, 0.31687133754406216`, 0.9341228629548491],
              UndirectedEdge[196, 332] -> 
             RGBColor[
              0.18931192738265673`, 0.3163092171215981, 0.934092406251319], 
             UndirectedEdge[49, 203] -> 
             RGBColor[
              0.9194979870090474, 0.6684278731193166, 0.38546874588719493`], 
             UndirectedEdge[95, 122] -> 
             RGBColor[
              0.18517962016864098`, 0.3119659002362576, 0.9338570774686815], 
             UndirectedEdge[97, 209] -> 
             RGBColor[
              0.9914664507187211, 0.9823539717574632, 0.575433002447343], 
             UndirectedEdge[484, 490] -> 
             RGBColor[
              0.2003898909918431, 0.3279528592583135, 0.9347232798904836], 
             UndirectedEdge[128, 415] -> 
             RGBColor[
              0.1873275955453248, 0.3142235585466571, 0.9339794014887388], 
             UndirectedEdge[371, 442] -> 
             RGBColor[
              0.24599324612330464`, 0.37588487692119543`, 0.9373203235011023],
              UndirectedEdge[88, 311] -> 
             RGBColor[
              0.18977178861723454`, 0.3167925604360257, 0.9341185946683245], 
             UndirectedEdge[15, 149] -> 
             RGBColor[
              0.6067680705890965, 0.6914867648051379, 0.9622913844255672], 
             UndirectedEdge[117, 140] -> 
             RGBColor[
              0.1812891715754636, 0.30787679209614044`, 0.933635522176703], 
             UndirectedEdge[199, 475] -> 
             RGBColor[
              0.3613314497983178, 0.4873888735937467, 0.9442446983616614], 
             UndirectedEdge[71, 169] -> 
             RGBColor[
              0.1907755412237238, 0.3178475680670369, 0.9341757568943452], 
             UndirectedEdge[23, 51] -> 
             RGBColor[
              0.7136013437576199, 0.7704045833430664, 0.8366928314862011], 
             UndirectedEdge[381, 416] -> 
             RGBColor[
              0.19876402822087508`, 0.3262439744003725, 0.9346306894109254], 
             UndirectedEdge[121, 447] -> 
             RGBColor[
              0.21943101242653507`, 0.34796628516300276`, 0.9358076435873746],
              UndirectedEdge[244, 407] -> 
             RGBColor[
              0.361925627233212, 0.4849803667690406, 0.9443895897897958], 
             UndirectedEdge[255, 385] -> 
             RGBColor[
              0.1893629494279947, 0.3163628445262328, 0.9340953118813207], 
             UndirectedEdge[30, 469] -> 
             RGBColor[
              0.18014325773351766`, 0.30667236399312137`, 0.9335702640786318],
              UndirectedEdge[80, 171] -> 
             RGBColor[
              0.4090554292271066, 0.5282531641753069, 0.9474159938779831], 
             UndirectedEdge[214, 466] -> 
             RGBColor[
              0.1912157031774699, 0.31831020618830375`, 0.9342008234664497], 
             UndirectedEdge[199, 455] -> 
             RGBColor[
              0.4995894556816295, 0.6028040573199673, 0.9542526889773754], 
             UndirectedEdge[175, 483] -> 
             RGBColor[
              0.4248591023079348, 0.5424133332049215, 0.9482926242042767], 
             UndirectedEdge[124, 416] -> 
             RGBColor[
              0.19729887283700168`, 0.3247040031957048, 0.934547250979317], 
             UndirectedEdge[142, 396] -> 
             RGBColor[
              0.2065755605048984, 0.3344543901106338, 0.9350755446183742], 
             UndirectedEdge[185, 361] -> 
             RGBColor[
              0.22082084550846576`, 0.3494270878526189, 0.9358867925253167], 
             UndirectedEdge[19, 26] -> 
             RGBColor[
              0.1940564817835153, 0.32129604461902417`, 0.9343626016055087], 
             UndirectedEdge[341, 455] -> 
             RGBColor[
              0.8036709694912352, 0.8434735735210568, 0.7916789986243209], 
             UndirectedEdge[159, 239] -> 
             RGBColor[
              0.2143802858334754, 0.34265765127913517`, 0.9355200121797802], 
             UndirectedEdge[261, 482] -> 
             RGBColor[
              0.3308323765041129, 0.4609721092343021, 0.9423013243806262], 
             UndirectedEdge[5, 97] -> 
             RGBColor[
              0.8390165308787574, 0.8650728443865321, 0.6896757172524062], 
             UndirectedEdge[285, 396] -> 
             RGBColor[
              0.20591309648733414`, 0.33375809842552917`, 0.9350378182726016],
              UndirectedEdge[174, 424] -> 
             RGBColor[
              0.19047450678086728`, 0.3175311617809086, 0.934158613428165], 
             UndirectedEdge[99, 186] -> 
             RGBColor[
              0.9865105734086191, 0.9862533521324298, 0.7169514481905657], 
             UndirectedEdge[79, 127] -> 
             RGBColor[
              0.8591989102072256, 0.8905659049388609, 0.9864323531431288], 
             UndirectedEdge[29, 86] -> 
             RGBColor[
              0.18487060048840748`, 0.3116411009593528, 0.9338394792550458], 
             UndirectedEdge[127, 316] -> 
             RGBColor[
              0.6354319607294284, 0.7117057299932411, 0.9665139361497471], 
             UndirectedEdge[197, 466] -> 
             RGBColor[
              0.21288997416386868`, 0.3410912392231611, 0.9354351411349147], 
             UndirectedEdge[183, 206] -> 
             RGBColor[
              0.1886895173788014, 0.31565502474447266`, 0.9340569609223726], 
             UndirectedEdge[25, 392] -> 
             RGBColor[
              0.26287272325527145`, 0.39362627760755575`, 0.9382815847528192],
              UndirectedEdge[73, 91] -> 
             RGBColor[
              0.5186112912140105, 0.6200710352367826, 0.9552461270615734], 
             UndirectedEdge[187, 464] -> 
             RGBColor[
              0.21185013288920307`, 0.3399983001137429, 0.9353759237126298], 
             UndirectedEdge[17, 99] -> 
             RGBColor[
              0.6775706975021587, 0.7419956614956686, 0.932197104376443], 
             UndirectedEdge[110, 157] -> 
             RGBColor[
              0.35808579273911467`, 0.4836854080233668, 0.944070557261417], 
             UndirectedEdge[241, 429] -> 
             RGBColor[
              0.20378953117845383`, 0.33152609664407884`, 0.9349168843697941],
              UndirectedEdge[27, 490] -> 
             RGBColor[
              0.20058973370860944`, 0.328162906624395, 0.9347346606375627], 
             UndirectedEdge[372, 418] -> 
             RGBColor[
              0.5453882435546948, 0.6418097714349063, 0.9573541068370404], 
             UndirectedEdge[65, 350] -> 
             RGBColor[
              0.18235178883730735`, 0.30899367021216395`, 0.9336960366577636],
              UndirectedEdge[189, 390] -> 
             RGBColor[
              0.25394291239181044`, 0.3842404802073483, 0.9377730452346162], 
             UndirectedEdge[263, 267] -> 
             RGBColor[
              0.22679757309850174`, 0.35570900749616285`, 0.9362271583197932],
              UndirectedEdge[25, 490] -> 
             RGBColor[
              0.25243138864291936`, 0.38265177291112284`, 0.937686966193216], 
             UndirectedEdge[360, 494] -> 
             RGBColor[
              0.4757330556093662, 0.5825992022016417, 0.9526059341461844], 
             UndirectedEdge[61, 203] -> 
             RGBColor[
              0.9176650400604409, 0.6688406301635299, 0.5009449661762736], 
             UndirectedEdge[36, 104] -> 
             RGBColor[
              0.9591316136436914, 0.8643779170894872, 0.5023662490620132], 
             UndirectedEdge[33, 241] -> 
             RGBColor[
              0.2359506605232252, 0.3653294827188087, 0.9367484131078517], 
             UndirectedEdge[82, 419] -> 
             RGBColor[
              0.5847042349028322, 0.6736221466676785, 0.9605217589523052], 
             UndirectedEdge[5, 404] -> 
             RGBColor[
              0.763201606478355, 0.8150742978846761, 0.9769963355615894], 
             UndirectedEdge[40, 396] -> 
             RGBColor[
              0.19122359622902446`, 0.31831850228593606`, 0.934201272964059], 
             UndirectedEdge[169, 369] -> 
             RGBColor[
              0.1829196441464267, 0.30959052214615446`, 0.9337283751775514], 
             UndirectedEdge[268, 491] -> 
             RGBColor[
              0.1839641739186956, 0.3106883891638218, 0.9337878596028387], 
             UndirectedEdge[4, 151] -> 
             RGBColor[
              0.19261261169346405`, 0.31977844560772906`, 0.9342803753398946],
              UndirectedEdge[6, 390] -> 
             RGBColor[
              0.23515410879898574`, 0.36449225635233673`, 0.9367030506655489],
              UndirectedEdge[376, 482] -> 
             RGBColor[
              0.35174044974950636`, 0.47908163140914517`, 0.9436335683195394],
              UndirectedEdge[158, 278] -> 
             RGBColor[
              0.18808568721102567`, 0.3150203609530965, 0.9340225736876044], 
             UndirectedEdge[317, 445] -> 
             RGBColor[
              0.8902189090551026, 0.5106901273758575, 0.23772100104764282`], 
             UndirectedEdge[133, 351] -> 
             RGBColor[
              0.21908548042585338`, 0.34760310912229214`, 0.9357879660511045],
              UndirectedEdge[239, 454] -> 
             RGBColor[
              0.20401834156350113`, 0.3317665908661798, 0.9349299147827279], 
             UndirectedEdge[140, 198] -> 
             RGBColor[
              0.18071298100430727`, 0.3072711792732629, 0.9336027089760732], 
             UndirectedEdge[252, 309] -> 
             RGBColor[
              0.18525140255303396`, 0.3120413480735207, 0.9338611653692801], 
             UndirectedEdge[161, 243] -> 
             RGBColor[
              0.20521495427576572`, 0.33302430669639793`, 0.9349980601064616],
              UndirectedEdge[244, 455] -> 
             RGBColor[
              0.5298831385666443, 0.6290429228301937, 0.9561829756631566], 
             UndirectedEdge[401, 451] -> 
             RGBColor[
              0.192907026989333, 0.3200878947506953, 0.934297141855446], 
             UndirectedEdge[210, 225] -> 
             RGBColor[
              0.189744388344664, 0.31676376101227643`, 0.9341170342633367], 
             UndirectedEdge[107, 223] -> 
             RGBColor[
              0.20973558752308613`, 0.3377757788640342, 0.935255503482219], 
             UndirectedEdge[5, 204] -> 
             RGBColor[
              0.502739716654951, 0.6027313328078459, 0.9555221120972213], 
             UndirectedEdge[59, 200] -> 
             RGBColor[
              0.26298567956392194`, 0.393745001849791, 0.9382880174474929], 
             UndirectedEdge[328, 481] -> 
             RGBColor[
              0.22412762819429155`, 0.3529027261175536, 0.9360751089073279], 
             UndirectedEdge[55, 434] -> 
             RGBColor[
              0.7543365484938672, 0.7225141411414309, 0.6130982348590022], 
             UndirectedEdge[269, 499] -> 
             RGBColor[
              0.615223353565316, 0.6985050597773825, 0.9628517825115135], 
             UndirectedEdge[377, 476] -> 
             RGBColor[
              0.18211083187288252`, 0.3087404091649995, 0.9336823145151034], 
             UndirectedEdge[260, 478] -> 
             RGBColor[
              0.22953226117284842`, 0.3585833380515396, 0.9363828947600188], 
             UndirectedEdge[163, 207] -> 
             RGBColor[
              0.8871477729139166, 0.5804462187569267, 0.227545674269207], 
             UndirectedEdge[238, 258] -> 
             RGBColor[
              0.4509349141328164, 0.5640927881888469, 0.9502045107268047], 
             UndirectedEdge[10, 443] -> 
             RGBColor[
              0.2573117613989959, 0.387781354111264, 0.9379648962018101], 
             UndirectedEdge[231, 326] -> 
             RGBColor[
              0.7445199877539495, 0.8003439400856498, 0.9751704525106033], 
             UndirectedEdge[91, 287] -> 
             RGBColor[
              0.38223901787712034`, 0.5048831468883692, 0.9456450183489318], 
             UndirectedEdge[242, 249] -> 
             RGBColor[
              0.8500313217686346, 0.8830430785885436, 0.951908121903962], 
             UndirectedEdge[83, 209] -> 
             RGBColor[
              0.9948514855705746, 0.9921389712197164, 0.7349877382312089], 
             UndirectedEdge[306, 431] -> 
             RGBColor[
              0.33101101797964355`, 0.4548419980464291, 0.9425428260902121], 
             UndirectedEdge[176, 376] -> 
             RGBColor[
              0.34402119360606, 0.47239559971878675`, 0.9431417041439492], 
             UndirectedEdge[30, 191] -> 
             RGBColor[
              0.18476529609045284`, 0.31153041936041803`, 0.9338334823253662],
              UndirectedEdge[209, 444] -> 
             RGBColor[
              0.7801701048240467, 0.8252083695679635, 0.8500873938895259], 
             UndirectedEdge[169, 289] -> 
             RGBColor[
              0.19694268883638122`, 0.3243296312276827, 0.9345269668274088], 
             UndirectedEdge[20, 46] -> 
             RGBColor[
              0.22273395828831882`, 0.35143789068260056`, 0.9359957414679326],
              UndirectedEdge[49, 100] -> 
             RGBColor[
              0.9935759076270685, 0.9886678409266986, 0.5421553739880537], 
             UndirectedEdge[404, 486] -> 
             RGBColor[
              0.6250807725270684, 0.7025792478220061, 0.9659283941437955], 
             UndirectedEdge[103, 431] -> 
             RGBColor[
              0.415528043094357, 0.534331238706793, 0.9476980573623193], 
             UndirectedEdge[219, 238] -> 
             RGBColor[
              0.5781077146635654, 0.6679567426795029, 0.9602144407477138], 
             UndirectedEdge[249, 499] -> 
             RGBColor[
              0.6777613007469594, 0.7479803602752079, 0.9686609595995643], 
             UndirectedEdge[254, 377] -> 
             RGBColor[
              0.18661056292735312`, 0.3134699118026751, 0.9339385675419001], 
             UndirectedEdge[57, 434] -> 
             RGBColor[
              0.9488603570213409, 0.87598930982866, 0.6073727486571113], 
             UndirectedEdge[75, 104] -> 
             RGBColor[
              0.894725030806556, 0.6091192249245418, 0.23357173327544747`], 
             UndirectedEdge[132, 365] -> 
             RGBColor[
              0.23967912019619636`, 0.3692483302330984, 0.9369607433704656], 
             UndirectedEdge[38, 77] -> 
             RGBColor[
              0.4266438929830485, 0.5421807004439456, 0.9488977622771873], 
             UndirectedEdge[172, 314] -> 
             RGBColor[
              0.24315002922466572`, 0.37289647569036266`, 0.9371584065048872],
              UndirectedEdge[398, 481] -> 
             RGBColor[
              0.20576395571267658`, 0.3336013420152928, 0.9350293249261188], 
             UndirectedEdge[143, 165] -> 
             RGBColor[
              0.4432891969739572, 0.5546584690453142, 0.950431811201746], 
             UndirectedEdge[261, 475] -> 
             RGBColor[
              0.3329106779769486, 0.46277222951160313`, 0.9424337519127055], 
             UndirectedEdge[288, 373] -> 
             RGBColor[
              0.8511114942630649, 0.882439252848601, 0.8853377053514828], 
             UndirectedEdge[78, 171] -> 
             RGBColor[
              0.47037777522198154`, 0.5809128940593202, 0.9514490079974901], 
             UndirectedEdge[6, 370] -> 
             RGBColor[
              0.22157715427768293`, 0.35022201632181177`, 0.935929863190865], 
             UndirectedEdge[264, 295] -> 
             RGBColor[
              0.9251699045349664, 0.7351644032002858, 0.5555767619873893], 
             UndirectedEdge[45, 464] -> 
             RGBColor[
              0.2018156680778671, 0.3294514413752133, 0.9348044757862846], 
             UndirectedEdge[228, 318] -> 
             RGBColor[
              0.22809876360932468`, 0.35707664122328114`, 0.9363012591944456],
              UndirectedEdge[7, 295] -> 
             RGBColor[
              0.7285749695983985, 0.7852490192213029, 0.9266196187062239], 
             UndirectedEdge[225, 320] -> 
             RGBColor[
              0.1825517796800877, 0.30920387326807797`, 0.9337074258404], 
             UndirectedEdge[137, 148] -> 
             RGBColor[
              0.24314559520540308`, 0.3728918152549845, 0.9371581539940498], 
             UndirectedEdge[61, 455] -> 
             RGBColor[
              0.8016518216680615, 0.8434880657223675, 0.8868884028153723], 
             UndirectedEdge[11, 331] -> 
             RGBColor[
              0.3385041946670758, 0.46694107593320344`, 0.9428149166646195], 
             UndirectedEdge[20, 392] -> 
             RGBColor[
              0.2393040747004234, 0.36885413363778313`, 0.9369393850843115], 
             UndirectedEdge[348, 431] -> 
             RGBColor[
              0.44166621655022387`, 0.5567328899534418, 0.9494292969038062], 
             UndirectedEdge[241, 351] -> 
             RGBColor[
              0.22791016546505544`, 0.3568784126158412, 0.9362905188091355], 
             UndirectedEdge[343, 374] -> 
             RGBColor[
              0.8468374551199298, 0.3610187811212927, 0.19248490595917145`], 
             UndirectedEdge[162, 389] -> 
             RGBColor[
              0.18912373753009853`, 0.3161114176546337, 0.9340816891176178], 
             UndirectedEdge[207, 266] -> 
             RGBColor[
              0.9342851916423655, 0.7569554226506068, 0.3801831663512317], 
             UndirectedEdge[98, 425] -> 
             RGBColor[
              0.1874902819867422, 0.31439455231150293`, 0.9339886662409045], 
             UndirectedEdge[151, 284] -> 
             RGBColor[
              0.20527167990556933`, 0.33308392892993416`, 0.9350012905471609],
              UndirectedEdge[41, 365] -> 
             RGBColor[
              0.23506566561189032`, 0.36439929695507756`, 0.9366980139568839],
              UndirectedEdge[436, 473] -> 
             RGBColor[
              0.30955738588181175`, 0.4383701601543446, 0.9410985541344632], 
             UndirectedEdge[311, 405] -> 
             RGBColor[
              0.18582191019465255`, 0.3126409877771355, 0.9338936549354799], 
             UndirectedEdge[235, 432] -> 
             RGBColor[
              0.25417547246619693`, 0.38448491559068887`, 0.9377862891868108],
              UndirectedEdge[109, 474] -> 
             RGBColor[
              0.22157473772172553`, 0.350219476368282, 0.9359297255715783], 
             UndirectedEdge[364, 468] -> 
             RGBColor[
              0.21294670143418915`, 0.3411508631809846, 0.9354383716690389], 
             UndirectedEdge[203, 374] -> 
             RGBColor[
              0.8462576720826371, 0.35656231463411475`, 0.19192970506788876`],
              UndirectedEdge[36, 112] -> 
             RGBColor[
              0.993786491132969, 0.9916985686506579, 0.7526374521795876], 
             UndirectedEdge[324, 342] -> 
             RGBColor[
              0.7080228667800735, 0.7701523632700238, 0.969408565667581], 
             UndirectedEdge[374, 445] -> 
             RGBColor[
              0.9052815581912046, 0.6264682491308763, 0.2521450108712031], 
             UndirectedEdge[2, 327] -> 
             RGBColor[
              0.18398683108609262`, 0.3107122032833034, 0.9337891498950037], 
             UndirectedEdge[128, 438] -> 
             RGBColor[
              0.19844895166515433`, 0.32591280896330255`, 0.9346127462671912],
              UndirectedEdge[33, 460] -> 
             RGBColor[
              0.27847248938800495`, 0.41002262089535824`, 0.9391699683562924],
              UndirectedEdge[298, 335] -> 
             RGBColor[
              0.2430317898200987, 0.3727721985793514, 0.9371516729457167], 
             UndirectedEdge[112, 343] -> 
             RGBColor[
              0.91983604495667, 0.6739551077819146, 0.4751295029148105], 
             UndirectedEdge[106, 265] -> 
             RGBColor[
              0.18198502195137928`, 0.3086081749606899, 0.933675149826193], 
             UndirectedEdge[19, 468] -> 
             RGBColor[
              0.21235962003857659`, 0.3405338034110854, 0.9354049382520679], 
             UndirectedEdge[161, 202] -> 
             RGBColor[
              0.2003053984953046, 0.32786405228731785`, 0.9347184681678012], 
             UndirectedEdge[204, 390] -> 
             RGBColor[
              0.2859084769887601, 0.4171765863589087, 0.9396176659888837], 
             UndirectedEdge[211, 289] -> 
             RGBColor[
              0.19877803112005593`, 0.32625869233524674`, 0.9346314868553184],
              UndirectedEdge[48, 479] -> 
             RGBColor[
              0.18610061058204452`, 0.31293391955490957`, 0.9339095265102416],
              UndirectedEdge[57, 495] -> 
             RGBColor[
              0.9243664441871663, 0.7736553444054359, 0.5873941515896481], 
             UndirectedEdge[10, 280] -> 
             RGBColor[
              0.24013030719270134`, 0.36972255637333296`, 0.9369864378024453],
              UndirectedEdge[206, 476] -> 
             RGBColor[
              0.18192213006975788`, 0.30854207160553015`, 0.9336715682265748],
              UndirectedEdge[13, 256] -> 
             RGBColor[
              0.2822514185299613, 0.41373456987075796`, 0.9393946906458437], 
             UndirectedEdge[184, 221] -> 
             RGBColor[
              0.7515553610831588, 0.7612606169042988, 0.6324712276878893], 
             UndirectedEdge[126, 282] -> 
             RGBColor[
              0.5925848442263562, 0.6792934576295336, 0.9616388769267687], 
             UndirectedEdge[53, 266] -> 
             RGBColor[
              0.9131290173800801, 0.6204205778411838, 0.36094524797198546`], 
             UndirectedEdge[194, 220] -> 
             RGBColor[
              0.20157018632549908`, 0.32919342448903244`, 0.9347904959636448],
              UndirectedEdge[375, 417] -> 
             RGBColor[
              0.1999369421366619, 0.32747678129290203`, 0.9346974851232589], 
             UndirectedEdge[245, 448] -> 
             RGBColor[
              0.272254633728537, 0.40348726036243854`, 0.9388158706749788], 
             UndirectedEdge[79, 147] -> 
             RGBColor[
              0.8526636417246913, 0.529899304242684, 0.5774584339898925], 
             UndirectedEdge[77, 253] -> 
             RGBColor[
              0.35598021511374034`, 0.4827539030708413, 0.9439037224194711], 
             UndirectedEdge[180, 205] -> 
             RGBColor[
              0.2503131812646099, 0.38042540265441493`, 0.9375663374166283], 
             UndirectedEdge[28, 432] -> 
             RGBColor[
              0.38353725752998075`, 0.5043916701363219, 0.9458878966543498], 
             UndirectedEdge[84, 245] -> 
             RGBColor[
              0.25972033738633343`, 0.39031292018649366`, 0.9381020610411201],
              UndirectedEdge[19, 459] -> 
             RGBColor[
              0.1988488542772136, 0.32633313196386693`, 0.934635520129345], 
             UndirectedEdge[153, 236] -> 
             RGBColor[
              0.21799828044158207`, 0.3464603930063626, 0.9357260516203685], 
             UndirectedEdge[315, 349] -> 
             RGBColor[
              0.18430254906177113`, 0.31104404289341736`, 0.9338071295666557],
              UndirectedEdge[18, 460] -> 
             RGBColor[
              0.2944934860338214, 0.4268617041599678, 0.940082340414331], 
             UndirectedEdge[126, 449] -> 
             RGBColor[
              0.7360314578812237, 0.7759766732200013, 0.6718437842469422], 
             UndirectedEdge[49, 324] -> 
             RGBColor[
              0.9668288479321837, 0.9719938689278773, 0.783522492339073], 
             UndirectedEdge[334, 415] -> 
             RGBColor[
              0.18362714398561458`, 0.31033414933522163`, 0.9337686662467408],
              UndirectedEdge[5, 444] -> 
             RGBColor[
              0.627720184984083, 0.7079272421970324, 0.964330108694589], 
             UndirectedEdge[147, 449] -> 
             RGBColor[
              0.9013434874873846, 0.5520144216865974, 0.2783600016823526], 
             UndirectedEdge[254, 426] -> 
             RGBColor[
              0.189893219466744, 0.3169201919580207, 0.9341255099755632], 
             UndirectedEdge[186, 321] -> 
             RGBColor[
              0.9893791898196398, 0.9881862286508462, 0.7028466634493613], 
             UndirectedEdge[260, 399] -> 
             RGBColor[
              0.20881488896675832`, 0.33680806630567356`, 0.9352030710614876],
              UndirectedEdge[184, 287] -> 
             RGBColor[
              0.42249467395537876`, 0.5375645019893394, 0.9488140910567393], 
             UndirectedEdge[129, 431] -> 
             RGBColor[
              0.35531389648617895`, 0.48038586424829277`, 0.9439268390682725],
              UndirectedEdge[300, 432] -> 
             RGBColor[
              0.26154815956156724`, 0.39223407718328385`, 0.938206152809979], 
             UndirectedEdge[207, 293] -> 
             RGBColor[
              0.8423679493594973, 0.6882641451078306, 0.5995351479132809], 
             UndirectedEdge[118, 399] -> 
             RGBColor[
              0.200045010570769, 0.32759036806908304`, 0.9347036394607084], 
             UndirectedEdge[138, 179] -> 
             RGBColor[
              0.19144105687703156`, 0.31854706721479287`, 0.9342136570262589],
              UndirectedEdge[40, 161] -> 
             RGBColor[
              0.19942966903054987`, 0.32694360509540565`, 0.9346685966703091],
              UndirectedEdge[243, 279] -> 
             RGBColor[
              0.20228104719014361`, 0.3299405843289558, 0.934830978438262], 
             UndirectedEdge[69, 233] -> 
             RGBColor[
              0.7027067996446262, 0.7647987322711527, 0.9488520571207084], 
             UndirectedEdge[237, 460] -> 
             RGBColor[
              0.26678188416083737`, 0.3977350535744224, 0.9385042056833057], 
             UndirectedEdge[54, 295] -> 
             RGBColor[
              0.9871607004637972, 0.988958633933902, 0.862443950564356], 
             UndirectedEdge[102, 210] -> 
             RGBColor[
              0.19748304019874757`, 0.324897574769785, 0.9345577390381172], 
             UndirectedEdge[137, 156] -> 
             RGBColor[
              0.2055253114742025, 0.33335051178973785`, 0.9350157344897803], 
             UndirectedEdge[231, 444] -> 
             RGBColor[
              0.664761024690349, 0.7368638276963759, 0.9680219934301821], 
             UndirectedEdge[383, 393] -> 
             RGBColor[
              0.24454516184141023`, 0.374362848527078, 0.9372378572434972], 
             UndirectedEdge[43, 137] -> 
             RGBColor[
              0.220012218727478, 0.34857716983590165`, 0.9358407424263956], 
             UndirectedEdge[233, 348] -> 
             RGBColor[
              0.7123189222990802, 0.7728863489370825, 0.9495302713185423], 
             UndirectedEdge[193, 410] -> 
             RGBColor[
              0.1815860257697589, 0.30818880467598786`, 0.9336524275839118], 
             UndirectedEdge[126, 384] -> 
             RGBColor[
              0.3782656319739345, 0.49734201260730226`, 0.9457250298186803], 
             UndirectedEdge[162, 345] -> 
             RGBColor[
              0.1870835559314184, 0.31396705743943626`, 0.9339655037937511], 
             UndirectedEdge[165, 178] -> 
             RGBColor[
              0.3876179844694684, 0.5094620707746275, 0.9460491694230218], 
             UndirectedEdge[154, 455] -> 
             RGBColor[
              0.7982558492888101, 0.8419633098945049, 0.937775174104184], 
             UndirectedEdge[211, 470] -> 
             RGBColor[
              0.19104848384555853`, 0.31813444806814695`, 0.9341913005728761],
              UndirectedEdge[201, 305] -> 
             RGBColor[
              0.2840031755926752, 0.41566850052882615`, 0.9394910555788545], 
             UndirectedEdge[220, 474] -> 
             RGBColor[
              0.22327343139036823`, 0.3520049111174247, 0.9360264636630153], 
             UndirectedEdge[125, 173] -> 
             RGBColor[
              0.7492734803038996, 0.8040574045935522, 0.9756442362240689], 
             UndirectedEdge[189, 443] -> 
             RGBColor[
              0.2699043575235971, 0.40101697105492856`, 0.9386820259220295], 
             UndirectedEdge[307, 500] -> 
             RGBColor[
              0.19638085260421678`, 0.3237391057252033, 0.9344949710851491], 
             UndirectedEdge[102, 134] -> 
             RGBColor[
              0.1917868632444325, 0.31891053163232136`, 0.9342333501873077], 
             UndirectedEdge[102, 174] -> 
             RGBColor[
              0.1934597999069662, 0.32066889413495503`, 0.934328621455351], 
             UndirectedEdge[203, 281] -> 
             RGBColor[
              0.8317474856787275, 0.2450306635294393, 0.1780347341805933], 
             UndirectedEdge[279, 421] -> 
             RGBColor[
              0.19615975110811917`, 0.3235067140341602, 0.9344823796820367], 
             UndirectedEdge[335, 430] -> 
             RGBColor[
              0.2059656395327683, 0.33381332449770196`, 0.9350408105213086], 
             UndirectedEdge[69, 431] -> 
             RGBColor[
              0.4320540938957698, 0.548645273287512, 0.9487510827059723], 
             UndirectedEdge[149, 249] -> 
             RGBColor[
              0.6440396780590834, 0.7206036278354, 0.9660062699352006], 
             UndirectedEdge[141, 345] -> 
             RGBColor[
              0.19907503548324326`, 0.3265708627521209, 0.9346484008144234], 
             UndirectedEdge[12, 283] -> 
             RGBColor[
              0.18817638831560224`, 0.31511569356478863`, 0.9340277389813298],
              UndirectedEdge[119, 381] -> 
             RGBColor[
              0.18630903659373593`, 0.3131529885081697, 0.9339213960632688], 
             UndirectedEdge[396, 430] -> 
             RGBColor[
              0.19949732248348956`, 0.32701471316392194`, 0.9346724494343697],
              UndirectedEdge[49, 360] -> 
             RGBColor[
              0.7950442531705986, 0.8362229179981473, 0.7707477142317521], 
             UndirectedEdge[208, 497] -> 
             RGBColor[
              0.4523984541828804, 0.5655914141074888, 0.9502339454421076], 
             UndirectedEdge[275, 444] -> 
             RGBColor[
              0.5275882362182631, 0.6273589235979986, 0.9559528250559413], 
             UndirectedEdge[269, 323] -> 
             RGBColor[
              0.7972919842565633, 0.8394603962804845, 0.8661383017091098], 
             UndirectedEdge[273, 279] -> 
             RGBColor[
              0.19757076585955963`, 0.32498978000142653`, 0.9345627348847221],
              UndirectedEdge[107, 289] -> 
             RGBColor[
              0.21067973016305835`, 0.3387681326407459, 0.9353092710088315], 
             UndirectedEdge[289, 314] -> 
             RGBColor[
              0.23644046461492338`, 0.36584429787455663`, 0.9367763067262738],
              UndirectedEdge[6, 428] -> 
             RGBColor[
              0.2010842377589775, 0.3286826617346995, 0.9347628219116779], 
             UndirectedEdge[7, 17] -> 
             RGBColor[
              0.4238987520286698, 0.5410646532335288, 0.9483742450361144], 
             UndirectedEdge[309, 424] -> 
             RGBColor[
              0.19083388775165383`, 0.3179088939672749, 0.9341790796427948], 
             UndirectedEdge[128, 385] -> 
             RGBColor[
              0.1879057798305126, 0.31483126688939045`, 0.9340123282284333], 
             UndirectedEdge[71, 362] -> 
             RGBColor[
              0.1884877837309814, 0.3154429898899618, 0.9340454724895675], 
             UndirectedEdge[43, 156] -> 
             RGBColor[
              0.21388174499134507`, 0.34213365324474115`, 0.935491621016346], 
             UndirectedEdge[59, 298] -> 
             RGBColor[
              0.2693422110049278, 0.4004261194216593, 0.9386500125094126], 
             UndirectedEdge[261, 455] -> 
             RGBColor[
              0.47116868386026034`, 0.5781874132378237, 0.9524417425284195], 
             UndirectedEdge[17, 89] -> 
             RGBColor[
              0.3425624838836552, 0.4711321386741221, 0.9430487564503239], 
             UndirectedEdge[9, 68] -> 
             RGBColor[
              0.18960972675890758`, 0.3166222231476087, 0.9341093654852418], 
             UndirectedEdge[73, 298] -> 
             RGBColor[
              0.42629344369918076`, 0.5372437988360448, 0.949423062513614], 
             UndirectedEdge[16, 333] -> 
             RGBColor[
              0.25095246372984137`, 0.3810973290582225, 0.9376027436072896], 
             UndirectedEdge[257, 445] -> 
             RGBColor[
              0.9630857175869136, 0.8871415989142806, 0.3110954128128076], 
             UndirectedEdge[428, 451] -> 
             RGBColor[
              0.19643038781423483`, 0.323791170371646, 0.934497792042079], 
             UndirectedEdge[15, 419] -> 
             RGBColor[
              0.6508464250830497, 0.7271654409816981, 0.9658339472127815], 
             UndirectedEdge[17, 313] -> 
             RGBColor[
              0.3683319514339016, 0.4934523562550466, 0.9446907641355802], 
             UndirectedEdge[5, 326] -> 
             RGBColor[
              0.7074791480476834, 0.7714073545863063, 0.9714785677750102], 
             UndirectedEdge[216, 217] -> 
             RGBColor[
              0.1905787639681844, 0.31764074269506637`, 0.9341645507207481], 
             UndirectedEdge[138, 222] -> 
             RGBColor[
              0.1899361610003327, 0.31696532623247287`, 0.9341279554323748], 
             UndirectedEdge[251, 447] -> 
             RGBColor[
              0.23632980233893142`, 0.3657279848060955, 0.9367700046733661], 
             UndirectedEdge[58, 144] -> 
             RGBColor[
              0.1950230989335921, 0.322312020530822, 0.9344176490222236], 
             UndirectedEdge[11, 404] -> 
             RGBColor[
              0.6062003014417219, 0.6862259327279479, 0.9647253472215822], 
             UndirectedEdge[270, 329] -> 
             RGBColor[
              0.18084643102754924`, 0.3074114437089104, 0.9336103087574752], 
             UndirectedEdge[314, 406] -> 
             RGBColor[
              0.3396550578396198, 0.4643665868457374, 0.9430190117624826], 
             UndirectedEdge[13, 409] -> 
             RGBColor[
              0.2530894600625647, 0.3833434476973081, 0.9377244423870355], 
             UndirectedEdge[279, 335] -> 
             RGBColor[
              0.20917892656929465`, 0.33719069290725634`, 0.9352238024644066],
              UndirectedEdge[195, 446] -> 
             RGBColor[
              0.1857509853248722, 0.31256644124209987`, 0.9338896158690699], 
             UndirectedEdge[22, 170] -> 
             RGBColor[
              0.18476666722380106`, 0.3115318605085019, 0.9338335604093819], 
             UndirectedEdge[159, 166] -> 
             RGBColor[
              0.21389899734106987`, 0.3421517865581641, 0.9354926035121403], 
             UndirectedEdge[59, 87] -> 
             RGBColor[
              0.28570409751894754`, 0.41762349955141664`, 0.939581797741144], 
             UndirectedEdge[176, 407] -> 
             RGBColor[
              0.2970315342752855, 0.4287723651208341, 0.94025459557011], 
             UndirectedEdge[169, 470] -> 
             RGBColor[
              0.1892131415618838, 0.316205386960583, 0.9340867805449665], 
             UndirectedEdge[13, 188] -> 
             RGBColor[
              0.23846099400411988`, 0.36796800237156463`, 0.9368913728858832],
              UndirectedEdge[273, 396] -> 
             RGBColor[
              0.19229860014365638`, 0.3194483995593991, 0.9342624928466716], 
             UndirectedEdge[30, 405] -> 
             RGBColor[
              0.1802965998650839, 0.3068335362958501, 0.9335789966861752], 
             UndirectedEdge[258, 497] -> 
             RGBColor[
              0.44668148609611025`, 0.5606396636938994, 0.9498696652909349], 
             UndirectedEdge[90, 485] -> 
             RGBColor[
              0.25884791756577036`, 0.3893959516404705, 0.9380523780229685], 
             UndirectedEdge[89, 455] -> 
             RGBColor[
              0.4613630510985772, 0.5696942669850865, 0.9518169362796256], 
             UndirectedEdge[422, 451] -> 
             RGBColor[
              0.20581343032131297`, 0.33365334296584104`, 0.9350321424318895],
              UndirectedEdge[99, 178] -> 
             RGBColor[
              0.7245036529888805, 0.7822124250066672, 0.9353076025507647], 
             UndirectedEdge[119, 416] -> 
             RGBColor[
              0.19677397614642037`, 0.32415230349353147`, 0.9345173588893034],
              UndirectedEdge[129, 204] -> 
             RGBColor[
              0.3026394845996296, 0.4347619361650844, 0.9405704721210151], 
             UndirectedEdge[1, 381] -> 
             RGBColor[
              0.1937883174344935, 0.32101418688560046`, 0.9343473300425454], 
             UndirectedEdge[287, 409] -> 
             RGBColor[
              0.2786937259844361, 0.4102551545854176, 0.9391825674531689], 
             UndirectedEdge[340, 384] -> 
             RGBColor[
              0.3159339914529744, 0.4443075647988586, 0.9414896959063039], 
             UndirectedEdge[233, 379] -> 
             RGBColor[
              0.8949909626419136, 0.5916992159390957, 0.5610798957464819], 
             UndirectedEdge[1, 124] -> 
             RGBColor[
              0.1923231620506201, 0.3194742156809328, 0.934263891610937], 
             UndirectedEdge[134, 309] -> 
             RGBColor[
              0.18616361548114224`, 0.31300014169860263`, 0.9339131145460378],
              UndirectedEdge[1, 380] -> 
             RGBColor[
              0.19337326869879815`, 0.3205779443487749, 0.9343236936310573], 
             UndirectedEdge[112, 403] -> 
             RGBColor[
              0.8684251833169994, 0.8955159189410955, 0.8667074610489753], 
             UndirectedEdge[214, 268] -> 
             RGBColor[
              0.186923339851059, 0.31379866018069236`, 0.9339563797249931], 
             UndirectedEdge[404, 444] -> 
             RGBColor[
              0.7013455249659886, 0.7655800526301657, 0.9716322684022551], 
             UndirectedEdge[252, 320] -> 
             RGBColor[
              0.18172265320945252`, 0.3083324087777858, 0.93366020831448], 
             UndirectedEdge[173, 419] -> 
             RGBColor[
              0.6849417616486415, 0.753800977040894, 0.9692322517226041], 
             UndirectedEdge[407, 475] -> 
             RGBColor[
              0.3068290918915676, 0.4372585170884935, 0.9408788872777796], 
             UndirectedEdge[167, 305] -> 
             RGBColor[
              0.27520889494048634`, 0.4064251539737775, 0.9389902343056846], 
             UndirectedEdge[407, 482] -> 
             RGBColor[
              0.3047507904187318, 0.43545839681119247`, 0.9407464597457003], 
             UndirectedEdge[197, 493] -> 
             RGBColor[
              0.24589919103084765`, 0.37578601905558584`, 0.9373149672027289],
              UndirectedEdge[235, 300] -> 
             RGBColor[
              0.22449059247181202`, 0.353284224586492, 0.9360957791859752], 
             UndirectedEdge[312, 385] -> 
             RGBColor[
              0.1882621822827025, 0.31520586846386267`, 0.9340326248208353], 
             UndirectedEdge[188, 318] -> 
             RGBColor[
              0.21097876418895464`, 0.3390824363618151, 0.935326300554225], 
             UndirectedEdge[71, 153] -> 
             RGBColor[
              0.21268791512647112`, 0.34087886236357334`, 0.9354236341716544],
              UndirectedEdge[45, 481] -> 
             RGBColor[
              0.20322304481879772`, 0.33093068356277056`, 0.9348846238096533],
              UndirectedEdge[53, 317] -> 
             RGBColor[
              0.8249968310509084, 0.19314217390430075`, 0.1715702996852197], 
             UndirectedEdge[253, 301] -> 
             RGBColor[
              0.5169703257345344, 0.6164641572661, 0.9558333707121969], 
             UndirectedEdge[442, 447] -> 
             RGBColor[
              0.23581693788510275`, 0.36518893174763706`, 0.9367407978014356],
              UndirectedEdge[118, 464] -> 
             RGBColor[
              0.1973325308094801, 0.3247393798588184, 0.9345491677510571], 
             UndirectedEdge[2, 118] -> 
             RGBColor[
              0.18820276986646162`, 0.31514342224742875`, 0.9340292413716232],
              UndirectedEdge[332, 454] -> 
             RGBColor[
              0.19901001769354992`, 0.3265025249327872, 0.9346446981474854], 
             UndirectedEdge[84, 455] -> 
             RGBColor[
              0.4442800341977758, 0.5518254258243921, 0.9508409168167211], 
             UndirectedEdge[423, 488] -> 
             RGBColor[
              0.18086431186395144`, 0.3074302376016796, 0.933611327044656], 
             UndirectedEdge[5, 231] -> 
             RGBColor[
              0.7266171062027156, 0.7863580729508864, 0.9733860605895166], 
             UndirectedEdge[121, 337] -> 
             RGBColor[
              0.19710919882017952`, 0.3245046437779975, 0.9345364493246566], 
             UndirectedEdge[23, 360] -> 
             RGBColor[
              0.5140568870299039, 0.6157933787663372, 0.9550478947958676], 
             UndirectedEdge[79, 336] -> 
             RGBColor[
              0.7557987774112169, 0.8094300480703478, 0.9763306281365505], 
             UndirectedEdge[237, 371] -> 
             RGBColor[
              0.24348618176994377`, 0.3732497933287522, 0.9371775498950476], 
             UndirectedEdge[9, 330] -> 
             RGBColor[
              0.19168631998098046`, 0.3188048542876222, 0.9342276243971945], 
             UndirectedEdge[76, 111] -> 
             RGBColor[
              0.3885098195301592, 0.510929411430886, 0.9459764800480857], 
             UndirectedEdge[91, 256] -> 
             RGBColor[
              0.3859408633418989, 0.5085140760316679, 0.9458653508371028], 
             UndirectedEdge[35, 193] -> 
             RGBColor[
              0.1842865051954063, 0.311027179772628, 0.9338062158922009], 
             UndirectedEdge[43, 267] -> 
             RGBColor[
              0.22881279968486046`, 0.35782713841117125`, 0.9363419224926257],
              UndirectedEdge[261, 448] -> 
             RGBColor[
              0.314938405291928, 0.4464509223622935, 0.9413162052121451], 
             UndirectedEdge[322, 374] -> 
             RGBColor[
              0.8341132720585396, 0.26321513433887644`, 0.18030021388967482`],
              UndirectedEdge[76, 130] -> 
             RGBColor[
              0.3566736138347697, 0.4828157529154782, 0.9439676309835814], 
             UndirectedEdge[107, 153] -> 
             RGBColor[
              0.21946182531602942`, 0.3479986714635114, 0.9358093983358476], 
             UndirectedEdge[410, 437] -> 
             RGBColor[
              0.1820838890101732, 0.30871209050801585`, 0.9336807801589306], 
             UndirectedEdge[11, 164] -> 
             RGBColor[
              0.3457994968745498, 0.4739358766298315, 0.9432550160557256], 
             UndirectedEdge[213, 500] -> 
             RGBColor[
              0.2016031036308693, 0.32922802266405415`, 0.934792370555489], 
             UndirectedEdge[251, 454] -> 
             RGBColor[
              0.22516117799061744`, 0.3539890524843341, 0.9361339680392287], 
             UndirectedEdge[111, 483] -> 
             RGBColor[
              0.4093161482374549, 0.528950807600658, 0.9473022409150004], 
             UndirectedEdge[5, 233] -> 
             RGBColor[
              0.8260668342903568, 0.864508719874695, 0.9589794534592146], 
             UndirectedEdge[69, 372] -> 
             RGBColor[
              0.5285636967606093, 0.627866783936419, 0.9561081041909547], 
             UndirectedEdge[454, 489] -> 
             RGBColor[
              0.20150669956748674`, 0.32912669588106847`, 0.9347868804866963],
              UndirectedEdge[289, 493] -> 
             RGBColor[
              0.235488823391288, 0.36484406261097735`, 0.9367221121664148], 
             UndirectedEdge[74, 268] -> 
             RGBColor[
              0.18750418807117342`, 0.3144091684879368, 0.9339894581718406], 
             UndirectedEdge[192, 258] -> 
             RGBColor[
              0.36408500922956, 0.4897738683751677, 0.944420152733743], 
             UndirectedEdge[68, 368] -> 
             RGBColor[
              0.18232969627571796`, 0.3089704495291842, 0.9336947785190641], 
             UndirectedEdge[50, 414] -> 
             RGBColor[
              0.6515149605889788, 0.7239780646853934, 0.9683019767918029], 
             UndirectedEdge[358, 441] -> 
             RGBColor[
              0.22317531852257919`, 0.3519017882726634, 0.9360208762803397], 
             UndirectedEdge[71, 289] -> 
             RGBColor[
              0.20390581997350005`, 0.33164832354080787`, 0.9349235068446382],
              UndirectedEdge[54, 321] -> 
             RGBColor[
              0.9874803221287802, 0.9890908057062746, 0.8571469924212342], 
             UndirectedEdge[75, 408] -> 
             RGBColor[
              0.9013012276585859, 0.7170355167790632, 0.6001882350839804], 
             UndirectedEdge[8, 239] -> 
             RGBColor[
              0.19706547094004007`, 0.32445868300346314`, 0.9345339590865722],
              UndirectedEdge[389, 472] -> 
             RGBColor[
              0.18902863113306126`, 0.3160114548012536, 0.9340762729490037], 
             UndirectedEdge[178, 475] -> 
             RGBColor[
              0.40291899149679977`, 0.5229757083496808, 0.9470145914961603], 
             UndirectedEdge[332, 489] -> 
             RGBColor[
              0.1891243849825443, 0.31611209816820496`, 0.9340817259890768], 
             UndirectedEdge[28, 406] -> 
             RGBColor[
              0.44617181476977985`, 0.5602617683644892, 0.9498196286740023], 
             UndirectedEdge[77, 87] -> 
             RGBColor[
              0.32144010648392174`, 0.4528061418339081, 0.9417039869994168], 
             UndirectedEdge[274, 300] -> 
             RGBColor[
              0.23797382817444995`, 0.36745596019648397`, 0.9368636295125807],
              UndirectedEdge[330, 333] -> 
             RGBColor[
              0.210684466253447, 0.33877311057202975`, 0.9353095407221728], 
             UndirectedEdge[325, 490] -> 
             RGBColor[
              0.22480172486171077`, 0.3536112444552085, 0.9361134977153007], 
             UndirectedEdge[420, 489] -> 
             RGBColor[
              0.189832836442401, 0.3168567255709313, 0.9341220712516556], 
             UndirectedEdge[271, 304] -> 
             RGBColor[
              0.19940240032278655`, 0.3269149439546105, 0.9346670437577425], 
             UndirectedEdge[166, 387] -> 
             RGBColor[
              0.19228627737083037`, 0.31943544754385, 0.934261791082989], 
             UndirectedEdge[16, 165] -> 
             RGBColor[
              0.28802163997316926`, 0.4200593836114821, 0.9397137783554151], 
             UndirectedEdge[44, 356] -> 
             RGBColor[
              0.262163357709175, 0.39288068944223503`, 0.9382411874343812], 
             UndirectedEdge[86, 377] -> 
             RGBColor[
              0.18305173765274474`, 0.30972936079650676`, 0.9337358977073213],
              UndirectedEdge[113, 353] -> 
             RGBColor[
              0.1887122478968889, 0.3156789159601807, 0.9340582553917509], 
             UndirectedEdge[63, 222] -> 
             RGBColor[
              0.20195670404025598`, 0.32959967911388044`, 0.9348125075756986],
              UndirectedEdge[71, 493] -> 
             RGBColor[
              0.2293216757786306, 0.35836199945033154`, 0.9363709022333513], 
             UndirectedEdge[106, 270] -> 
             RGBColor[
              0.17988066425974236`, 0.3063963616027956, 0.9335553097687725], 
             UndirectedEdge[414, 498] -> 
             RGBColor[
              0.5986264598736242, 0.6821731423501425, 0.9631600517720931], 
             UndirectedEdge[46, 220] -> 
             RGBColor[
              0.21037184686789395`, 0.33844452777659967`, 0.9352917375106444],
              UndirectedEdge[302, 443] -> 
             RGBColor[
              0.2662987639830351, 0.3972272636359636, 0.9384766927038922], 
             UndirectedEdge[90, 267] -> 
             RGBColor[
              0.24580395513477205`, 0.37568592009050583`, 0.9373095436593363],
              UndirectedEdge[116, 187] -> 
             RGBColor[
              0.24886259772016034`, 0.3789007473768896, 0.9374837288297179], 
             UndirectedEdge[162, 472] -> 
             RGBColor[
              0.18323095336378353`, 0.30991772787174093`, 0.933746103776939], 
             UndirectedEdge[271, 371] -> 
             RGBColor[
              0.23108898271360306`, 0.3602195510927192, 0.9364715477488016], 
             UndirectedEdge[84, 478] -> 
             RGBColor[
              0.2624145878361924, 0.3931447482346404, 0.9382554946184531], 
             UndirectedEdge[5, 163] -> 
             RGBColor[
              0.7944424008489477, 0.6965434437689743, 0.6036935441317027], 
             UndirectedEdge[188, 430] -> 
             RGBColor[
              0.2127664410138974, 0.34096139805008724`, 0.9354281061047747], 
             UndirectedEdge[380, 487] -> 
             RGBColor[
              0.19010454207928099`, 0.31714230542242455`, 0.9341375444857234],
              UndirectedEdge[88, 304] -> 
             RGBColor[
              0.19013400622997473`, 0.3171732741129387, 0.9341392224255172], 
             UndirectedEdge[41, 494] -> 
             RGBColor[
              0.3091950820990577, 0.43800954418308746`, 0.9410771822783439], 
             UndirectedEdge[23, 136] -> 
             RGBColor[
              0.48008619598652036`, 0.5882144414151268, 0.9523735975581908], 
             UndirectedEdge[7, 84] -> 
             RGBColor[
              0.373934744333056, 0.4947159504930181, 0.9453030779152829], 
             UndirectedEdge[218, 493] -> 
             RGBColor[
              0.2733906528975818, 0.4046812885368802, 0.9388805652860661], 
             UndirectedEdge[40, 183] -> 
             RGBColor[
              0.19098677743240255`, 0.31806959071550744`, 0.9341877864839334],
              UndirectedEdge[192, 453] -> 
             RGBColor[
              0.27645983051134826`, 0.4075148710199178, 0.9390697150866952], 
             UndirectedEdge[49, 397] -> 
             RGBColor[
              0.9079673464709124, 0.579798317184308, 0.3744269914858809], 
             UndirectedEdge[291, 467] -> 
             RGBColor[
              0.1871130842202519, 0.31399809354320196`, 0.933967185386117], 
             UndirectedEdge[347, 462] -> 
             RGBColor[
              0.19657186081581016`, 0.32393986746620806`, 0.934505848720228], 
             UndirectedEdge[31, 226] -> 
             RGBColor[
              0.1894803426038117, 0.3164862321971737, 0.9341019972490159], 
             UndirectedEdge[120, 381] -> 
             RGBColor[
              0.18410140079156978`, 0.3108326233078988, 0.9337956744702399], 
             UndirectedEdge[151, 274] -> 
             RGBColor[
              0.22389877891969617`, 0.3526621910200718, 0.9360620762796918], 
             UndirectedEdge[316, 418] -> 
             RGBColor[
              0.45760917454031613`, 0.5701502103978782, 0.9505533872489015], 
             UndirectedEdge[235, 389] -> 
             RGBColor[
              0.20601966033790897`, 0.3338701037890217, 0.9350438869262447], 
             UndirectedEdge[218, 310] -> 
             RGBColor[
              0.4653446361758491, 0.5701283226319324, 0.9524120897475179], 
             UndirectedEdge[408, 463] -> 
             RGBColor[
              0.746221620758815, 0.8012446952293572, 0.9745845586722801], 
             UndirectedEdge[12, 273] -> 
             RGBColor[
              0.1905970563658978, 0.31765996916486816`, 0.9341655924457366], 
             UndirectedEdge[121, 454] -> 
             RGBColor[
              0.20826238807822112`, 0.3362273528412414, 0.9351716069532372], 
             UndirectedEdge[47, 228] -> 
             RGBColor[
              0.2699130817435731, 0.4010261407632708, 0.9386825227534509], 
             UndirectedEdge[438, 439] -> 
             RGBColor[
              0.2009360669634459, 0.3285269248340248, 0.9347543838040715], 
             UndirectedEdge[172, 201] -> 
             RGBColor[
              0.2404718980048366, 0.3700815899749955, 0.9370058908938581], 
             UndirectedEdge[58, 375] -> 
             RGBColor[
              0.19795511773261765`, 0.3253937581893268, 0.934584623155295], 
             UndirectedEdge[168, 280] -> 
             RGBColor[
              0.2730931280966553, 0.40436857110694446`, 0.9388636216888019], 
             UndirectedEdge[77, 301] -> 
             RGBColor[
              0.49545804882307076`, 0.5978313042438662, 0.9544626274499579], 
             UndirectedEdge[283, 477] -> 
             RGBColor[
              0.19005559335530314`, 0.3170908572099954, 0.934134756928306], 
             UndirectedEdge[125, 149] -> 
             RGBColor[
              0.669539684263013, 0.7405244264891351, 0.9685478722425018], 
             UndirectedEdge[7, 407] -> 
             RGBColor[
              0.3747418079101595, 0.4955642254833401, 0.9453490389920554], 
             UndirectedEdge[401, 437] -> 
             RGBColor[
              0.18132345879022535`, 0.30791283013279, 0.9336374747828603], 
             UndirectedEdge[138, 438] -> 
             RGBColor[
              0.19270594078429107`, 0.3198765403995944, 0.9342856902935492], 
             UndirectedEdge[45, 399] -> 
             RGBColor[
              0.20452814783915604`, 0.33230242958547795`, 0.9349589474959358],
              UndirectedEdge[97, 317] -> 
             RGBColor[
              0.9028878976305327, 0.5534256006607606, 0.2869376293254444], 
             UndirectedEdge[71, 201] -> 
             RGBColor[
              0.22759518578243687`, 0.3565473489985437, 0.936272581182181], 
             UndirectedEdge[107, 236] -> 
             RGBColor[
              0.20982294786551192`, 0.3378676001228893, 0.935260478524482], 
             UndirectedEdge[134, 225] -> 
             RGBColor[
              0.1840482113903489, 0.31077671787481287`, 0.933792645412527], 
             UndirectedEdge[59, 91] -> 
             RGBColor[
              0.36166005851975747`, 0.48325335582239703`, 0.9444730770573722],
              UndirectedEdge[161, 287] -> 
             RGBColor[
              0.25900221419710867`, 0.3895581271829785, 0.9380611649878617], 
             UndirectedEdge[101, 486] -> 
             RGBColor[
              0.32922289158902907`, 0.45369458082192426`, 0.9424141922098388],
              UndirectedEdge[185, 330] -> 
             RGBColor[
              0.20056082053324595`, 0.3281325170438868, 0.934733014074999], 
             UndirectedEdge[237, 432] -> 
             RGBColor[
              0.26206160282215785`, 0.3927737386043475, 0.9382353926440985], 
             UndirectedEdge[99, 143] -> 
             RGBColor[
              0.7801748654933693, 0.827408823277354, 0.9396902443294888], 
             UndirectedEdge[107, 411] -> 
             RGBColor[
              0.24624789168403566`, 0.3761525255509848, 0.9373348251890715], 
             UndirectedEdge[187, 407] -> 
             RGBColor[
              0.24918791988473313`, 0.3792426815984722, 0.9375022554457193], 
             UndirectedEdge[185, 357] -> 
             RGBColor[
              0.20004263933508956`, 0.3275878757500389, 0.9347035044223444], 
             UndirectedEdge[80, 208] -> 
             RGBColor[
              0.38701536387166025`, 0.5096349890530197, 0.9458812546550213], 
             UndirectedEdge[60, 240] -> 
             RGBColor[
              0.9901494356226408, 0.989783903232943, 0.7830629910514044], 
             UndirectedEdge[262, 299] -> 
             RGBColor[
              0.2916203852027007, 0.4206594025249505, 0.9400352481392587], 
             UndirectedEdge[82, 282] -> 
             RGBColor[
              0.6084177855813375, 0.6921473526873871, 0.962885304068208], 
             UndirectedEdge[286, 368] -> 
             RGBColor[
              0.18331387184910375`, 0.310004880457148, 0.9337508258620111], 
             UndirectedEdge[81, 454] -> 
             RGBColor[
              0.2248746265777104, 0.3536878687809598, 0.9361176493601785], 
             UndirectedEdge[68, 352] -> 
             RGBColor[
              0.18440978245630846`, 0.311156751990066, 0.933813236349837], 
             UndirectedEdge[196, 337] -> 
             RGBColor[
              0.19054105270955757`, 0.3176011057712177, 0.934162403120358], 
             UndirectedEdge[261, 262] -> 
             RGBColor[
              0.33623006243366543`, 0.4656473134908974, 0.942645260155071], 
             UndirectedEdge[122, 286] -> 
             RGBColor[
              0.1865372127264831, 0.3133928160908893, 0.9339343903564724]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.20904447312210606`, 0.33704937380942024`, 0.9352161455394953],
              316 -> 
             RGBColor[
              0.43871305828747303`, 0.5544129335543235, 0.9491753860287206], 
             308 -> RGBColor[
              0.19090439582770188`, 0.3179830024256716, 0.9341830949734184], 
             160 -> RGBColor[
              0.23944883454874902`, 0.3690062854166779, 0.9369476289435206], 
             245 -> RGBColor[
              0.2439252154854269, 0.3737112456000703, 0.9372025522156523], 
             155 -> RGBColor[
              0.19392286855916088`, 0.32115560864865994`, 0.9343549925300447],
              425 -> RGBColor[
              0.18667870528248892`, 0.31354153373839766`, 0.9339424481482175],
              213 -> RGBColor[
              0.20221750657572096`, 0.32987379911448994`, 0.9348273598942706],
              352 -> RGBColor[
              0.18339204965023842`, 0.3100870502828995, 0.9337552779721321], 
             27 -> RGBColor[
              0.18521154867326725`, 0.3119994591190039, 0.933858895749786], 
             485 -> RGBColor[
              0.255344871987097, 0.38571402863136683`, 0.9378528847595545], 
             454 -> RGBColor[
              0.21139233227849236`, 0.33951712264565065`, 0.9353498526451051],
              367 -> RGBColor[
              0.19714961162350877`, 0.32454712019661625`, 0.9345387507740208],
              19 -> RGBColor[
              0.20321773659331793`, 0.33092510428123034`, 0.934884321514065], 
             164 -> RGBColor[
              0.3160253373259164, 0.44814699612157666`, 0.9413578329375422], 
             190 -> RGBColor[
              0.21654397156564814`, 0.3449318221692476, 0.9356432308813413], 
             103 -> RGBColor[
              0.40980409560216274`, 0.5293734430830204, 0.9473333324896046], 
             138 -> RGBColor[
              0.1827700546655207, 0.3094332941172014, 0.9337198562779115], 
             416 -> RGBColor[
              0.20922896777355948`, 0.3372432893857343, 0.9352266522369601], 
             476 -> RGBColor[
              0.18343003159278173`, 0.31012697171270676`, 0.9337574409875706],
              291 -> RGBColor[
              0.18307944483465585`, 0.30975848280143214`, 0.933737475590342], 
             28 -> RGBColor[
              0.47584147550400935`, 0.5853485720851631, 0.951879130497885], 
             337 -> RGBColor[
              0.1890859537624092, 0.3160717045191629, 0.9340795373879439], 
             195 -> RGBColor[
              0.18809486651088786`, 0.3150300089792529, 0.934023096435152], 
             114 -> RGBColor[
              0.18143431560131953`, 0.3080293476699778, 0.9336437879142542], 
             479 -> 
             RGBColor[
              0.18231814009471767`, 0.3089583032502487, 0.933694120411652], 
             93 -> RGBColor[
              0.2226303791602024, 0.3513290224516542, 0.935989842789818], 34 -> 
             RGBColor[
              0.2089289231192469, 0.33692792343012196`, 0.9352095651377733], 
             161 -> RGBColor[
              0.2138505894071634, 0.34210090675038807`, 0.9354898467519174], 
             22 -> RGBColor[
              0.1817982963009414, 0.30841191446298966`, 0.9336645160766364], 
             124 -> RGBColor[
              0.18536877790044387`, 0.31216471700567533`, 0.9338678497216739],
              84 -> RGBColor[
              0.27551545928723997`, 0.406914594772917, 0.9390015698665879], 
             46 -> RGBColor[
              0.2037103551444467, 0.3314428776122868, 0.934912375411788], 241 -> 
             RGBColor[
              0.21562994450375172`, 0.3439711217745316, 0.9355911783923481], 
             185 -> RGBColor[
              0.21154093935996757`, 0.33967331811051427`, 0.9353583155985506],
              426 -> RGBColor[
              0.18735694523176508`, 0.31425440692798345`, 0.9339810729099627],
              390 -> RGBColor[
              0.25591378716406765`, 0.38631199455366855`, 0.9378852836372484],
              121 -> RGBColor[
              0.20513244387794988`, 0.3329375830368321, 0.9349933612613692], 
             322 -> RGBColor[
              0.820782245844875, 0.16074702516771538`, 0.16753440813222906`], 
             488 -> RGBColor[
              0.18252871209609148`, 0.30917962777472857`, 0.9337061121756168],
              126 -> RGBColor[
              0.4884562669939937, 0.5955898281066129, 0.9528722130934804], 
             433 -> RGBColor[
              0.18067343227102245`, 0.30722961104704605`, 0.9336004567342198],
              236 -> RGBColor[
              0.20835940299106456`, 0.3363293216657406, 0.9351771318090029], 
             78 -> RGBColor[
              0.4700607186843903, 0.5806554932788695, 0.9514240481454346], 
             376 -> RGBColor[
              0.37110890510299593`, 0.49585761394946637`, 0.9448677091678112],
              458 -> RGBColor[
              0.2390221871354001, 0.3685578519342398, 0.9369233320044987], 
             254 -> RGBColor[
              0.19242949370172294`, 0.3195859769880579, 0.9342699470411637], 
             290 -> RGBColor[
              0.18152659560596812`, 0.30812633980575366`, 0.9336490431240029],
              251 -> RGBColor[
              0.23893002370274252`, 0.3684609823230175, 0.9369180834333524], 
             165 -> 
             RGBColor[
              0.3059265832870255, 0.43887861427331937`, 0.9407334383891494], 
             460 -> RGBColor[
              0.3006736022333113, 0.4333573981276305, 0.9404342888892294], 
             100 -> RGBColor[
              0.9932268871291124, 0.987921321372956, 0.5041666466903745], 235 -> 
             RGBColor[
              0.2171179053764417, 0.345535062993897, 0.9356759155628069], 70 -> 
             RGBColor[
              0.3697431424982056, 0.49467465902642144`, 0.9447806839823304], 
             234 -> RGBColor[
              0.9263783006421346, 0.7458215255627042, 0.25962045645451476`], 
             435 -> RGBColor[
              0.23839852597207306`, 0.3679023445091814, 0.9368878154238712], 
             257 -> RGBColor[
              0.9630526170636222, 0.8870299430768459, 0.31096682353032956`], 
             135 -> RGBColor[
              0.17999586170885287`, 0.3065174414257509, 0.93356187009308], 
             265 -> RGBColor[
              0.18432263905515192`, 0.3110651587502397, 0.9338082736620582], 
             111 -> RGBColor[
              0.3665915053486955, 0.49194486933340476`, 0.9445798644500469], 
             497 -> RGBColor[
              0.4781822073170808, 0.587248883619781, 0.9520634014805931], 481 -> 
             RGBColor[
              0.20526876593224802`, 0.3330808661592169, 0.9350011246006911], 
             381 -> RGBColor[
              0.18829908866819065`, 0.31524465941501073`, 0.9340347265848907],
              182 -> RGBColor[
              0.34499714152995936`, 0.4732409167578995, 0.9432038906826632], 
             188 -> RGBColor[
              0.2239766808649284, 0.35274407090377946`, 0.9360665126802272], 
             154 -> RGBColor[
              0.9834670894693087, 0.9871903629131425, 0.9128700844415136], 
             336 -> RGBColor[
              0.6253505975793664, 0.7067268126951324, 0.9636490362576168], 
             463 -> RGBColor[
              0.5551591248464408, 0.6497422130407317, 0.9581233064042441], 
             315 -> RGBColor[
              0.18340993044876472`, 0.3101058441358588, 0.9337562962571558], 
             368 -> RGBColor[
              0.1792318772890574, 0.3057144453611359, 0.9335183623105863], 
             269 -> RGBColor[
              0.6018738506410779, 0.6876673319152327, 0.961800860740477], 208 -> 
             RGBColor[
              0.42661470104868005`, 0.5439339445951966, 0.948404489403622], 
             86 -> RGBColor[
              0.18531184315250615`, 0.31210487497572126`, 0.9338646073720063],
              119 -> 
             RGBColor[
              0.18431898451928125`, 0.31106131760132866`, 0.9338080655416469],
              436 -> RGBColor[
              0.35552088653300873`, 0.4823560557407374, 0.9438744544084752], 
             377 -> RGBColor[
              0.1807916321529833, 0.30735384661729226`, 0.9336071880426363], 
             140 -> RGBColor[
              0.17901437519538227`, 0.3054858368702541, 0.933505975888117], 
             85 -> RGBColor[
              0.18726966457396857`, 0.31416266942272597`, 0.9339761024056213],
              351 -> RGBColor[
              0.24019038642635912`, 0.3697857034571507, 0.9369898592259228], 
             443 -> RGBColor[
              0.2878366774276409, 0.41986497624882907`, 0.9397032450120749], 
             242 -> RGBColor[
              0.9731128985329042, 0.9794682242662037, 0.9303970288913456], 
             117 -> RGBColor[
              0.18356396795554494`, 0.3102677473220268, 0.933765068465289], 
             47 -> RGBColor[
              0.28160948378147765`, 0.4133198008998302, 0.9393486155462334], 
             451 -> RGBColor[
              0.20508673054441848`, 0.33288953542489785`, 0.9349907579546514],
              81 -> RGBColor[
              0.23835692087692842`, 0.36785861491626903`, 0.9368854460752519],
              275 -> RGBColor[
              0.48931236896480956`, 0.5962848502534754, 0.9529396085766279], 
             23 -> RGBColor[
              0.4319501958436354, 0.5485552820168211, 0.9487444624139638], 
             328 -> RGBColor[
              0.24298649045633505`, 0.3727245860758903, 0.9371490932139648], 
             418 -> RGBColor[
              0.4765052907931592, 0.5858874872414329, 0.9519313884690823], 
             110 -> RGBColor[
              0.4170759329154467, 0.5356719430706164, 0.9477966875329739], 6 -> 
             RGBColor[
              0.21439443043390383`, 0.3426725181510049, 0.9355208176938495], 
             218 -> RGBColor[
              0.28587662659874513`, 0.4178048385532594, 0.9395916230170046], 
             108 -> RGBColor[
              0.20961363351384976`, 0.337647597467996, 0.9352485583818076], 
             297 -> RGBColor[
              0.19526251556143404`, 0.32256366258657476`, 0.934431283444994], 
             487 -> RGBColor[
              0.19274009296176206`, 0.31991243650348955`, 0.9342876352095326],
              464 -> RGBColor[
              0.20245401245038683`, 0.33012238178410236`, 0.9348408285539537],
              157 -> RGBColor[
              0.29909565256278264`, 0.4316988729761172, 0.9403444269898601], 
             441 -> 
             RGBColor[
              0.22146757953397317`, 0.3501068463187328, 0.935923623071312], 
             354 -> RGBColor[
              0.31058773436371456`, 0.4434372177375889, 0.9410113536850742], 
             385 -> RGBColor[
              0.18155548323377793`, 0.30815670253416316`, 0.9336506882316712],
              270 -> RGBColor[
              0.18011392367187812`, 0.3066415320344512, 0.9335685935472172], 
             392 -> RGBColor[
              0.23685058796865582`, 0.3662753635226519, 0.9367996626445457], 
             33 -> RGBColor[
              0.25627137654269866`, 0.3866878436630859, 0.9379056478233554], 
             252 -> RGBColor[
              0.18230687199160545`, 0.30894645975943874`, 0.9336934787098494],
              394 -> RGBColor[
              0.18345440314028216`, 0.3101525877543751, 0.9337588289111464], 
             260 -> RGBColor[
              0.20975080596055196`, 0.33779177440671543`, 0.935256370149719], 
             159 -> RGBColor[
              0.2321162208184409, 0.36129924347156134`, 0.9365300474392095], 
             183 -> RGBColor[
              0.19696480621086881`, 0.3243528779905917, 0.934528226379166], 
             99 -> RGBColor[
              0.9796979203258498, 0.9843793227373989, 0.9192503046446351], 
             329 -> RGBColor[
              0.18157893838322037`, 0.30818135538336955`, 0.9336520239677332],
              309 -> RGBColor[
              0.1881959331144625, 0.3151362363876026, 0.9340288520287109], 17 -> 
             RGBColor[
              0.3754434746784675, 0.49961200025393837`, 0.9451439041082509], 
             349 -> RGBColor[
              0.18519516767477753`, 0.31198224165097593`, 0.9338579628761555],
              495 -> RGBColor[
              0.8860920716837987, 0.5756525260362475, 0.22666477128519144`], 
             347 -> RGBColor[
              0.2030767017243416, 0.3307768676918091, 0.9348762897869192], 
             340 -> RGBColor[
              0.36379298595207366`, 0.4895209324897256, 0.9444015452687277], 
             404 -> RGBColor[
              0.8368269464602606, 0.8727271083178094, 0.9842984952692555], 
             277 -> RGBColor[
              0.44322657405371796`, 0.5583223140551463, 0.9494629832622005], 
             104 -> RGBColor[
              0.9241317229671294, 0.73691459370894, 0.25781280732325], 79 -> 
             RGBColor[
              0.8862469572430673, 0.9121332834455631, 0.9890122200154841], 
             327 -> RGBColor[
              0.1837791716078354, 0.31049394000528374`, 0.9337773239949216], 
             191 -> 
             RGBColor[
              0.19059661539563244`, 0.31765950567716017`, 0.9341655673331324],
              50 -> RGBColor[
              0.8803633253605091, 0.9074418350893442, 0.9884510339541455], 
             225 -> RGBColor[
              0.18396512493287584`, 0.310689388740023, 0.9337879137616893], 
             405 -> RGBColor[
              0.1816592229448945, 0.3082657395480243, 0.9336565960547502], 61 -> 
             RGBColor[
              0.9902590342278114, 0.9902398745688678, 0.8110965418638902], 
             196 -> RGBColor[
              0.19199615165670597`, 0.3191305070232725, 0.9342452688527721], 
             1 -> RGBColor[
              0.19927754620079638`, 0.32678371435619025`, 0.9346599335002002],
              263 -> RGBColor[
              0.22433819907190317`, 0.35312404946088816`, 0.9360871006072962],
              201 -> RGBColor[
              0.25745169920403105`, 0.3879284376169253, 0.9379728654527874], 
             371 -> RGBColor[
              0.25408219745152405`, 0.38438687763629015`, 0.9377809773127133],
              293 -> RGBColor[
              0.8097488880926076, 0.8513012527882134, 0.9816718596976299], 
             362 -> RGBColor[
              0.17923689510112015`, 0.3057197193997615, 0.9335186480675601], 
             184 -> RGBColor[
              0.5408355089237035, 0.6381136563631097, 0.9569956988896724], 
             106 -> RGBColor[
              0.17964740484760663`, 0.30615119117114004`, 0.9335420259903278],
              206 -> RGBColor[
              0.18041422854673403`, 0.3069571714983536, 0.933585695465579], 
             358 -> RGBColor[
              0.2248830575111852, 0.353696730226594, 0.9361181294893675], 247 -> 
             RGBColor[
              0.18427930277709584`, 0.31101960957432406`, 0.9338058057251333],
              220 -> RGBColor[
              0.21703333859134122`, 0.34544617794091254`, 0.9356710996095008],
              407 -> RGBColor[
              0.2771295864414469, 0.4086111447535611, 0.9390934920201328], 
             107 -> RGBColor[
              0.21128649273995928`, 0.33940587858003807`, 0.9353438252399612],
              375 -> RGBColor[
              0.20274272640358343`, 0.3304258384544339, 0.9348572703864743], 
             131 -> RGBColor[
              0.8337292727736055, 0.2602635475653142, 0.17993249574075687`], 
             411 -> RGBColor[
              0.281209290628112, 0.4128991725219315, 0.9393258251381819], 462 -> 
             RGBColor[
              0.1900670199072787, 0.31710286724060704`, 0.934135407653537], 
             127 -> 
             RGBColor[
              0.8321508631713839, 0.8689985264321587, 0.9838524862707736], 
             210 -> RGBColor[
              0.19552365175645214`, 0.32283813328452987`, 0.9344461547649839],
              357 -> RGBColor[
              0.18854433931021156`, 0.3155024333895635, 0.934048693246138], 
             181 -> RGBColor[
              0.22551745991005276`, 0.354363527371239, 0.9361542577674687], 
             194 -> RGBColor[
              0.18610703405965695`, 0.3129406710371523, 0.933909892317789], 
             440 -> RGBColor[
              0.8916325056316791, 0.6008103425923479, 0.23128784517976625`], 
             490 -> RGBColor[
              0.2159679187439516, 0.3443263541297861, 0.9356104255253395], 
             118 -> RGBColor[
              0.19221104916857337`, 0.3193563779335344, 0.9342575069481607], 
             348 -> RGBColor[
              0.46208044251389646`, 0.5741767455763179, 0.9507958115725785], 
             276 -> RGBColor[
              0.21359854810176626`, 0.34183599535807396`, 0.9354754933724367],
              305 -> RGBColor[
              0.3105546519813193, 0.443408563440727, 0.9410092457049215], 343 -> 
             RGBColor[
              0.8462306119676556, 0.35635431873254797`, 0.1919037922712223], 
             280 -> RGBColor[
              0.2534737690150518, 0.3837473807729669, 0.9377463282133454], 
             474 -> RGBColor[
              0.22951352418939525`, 0.35856364429393695`, 0.93638182771653], 
             189 -> RGBColor[
              0.2519720376195532, 0.38216896586102805`, 0.9376608068319842], 
             168 -> RGBColor[
              0.29271248717825876`, 0.424989761440922, 0.9399809151642584], 
             363 -> RGBColor[
              0.18261346087673228`, 0.3092687041165651, 0.9337109384932998], 
             41 -> RGBColor[
              0.2630876311955555, 0.3938521594787447, 0.9382938234420904], 14 -> 
             RGBColor[
              0.2309802119470121, 0.36010522612056717`, 0.9364653534145562], 
             77 -> RGBColor[
              0.33446793820227666`, 0.46412105004860754`, 0.9425329791572322],
              51 -> RGBColor[
              0.9952524916716045, 0.9922538846693116, 0.7246412005584384], 
             438 -> RGBColor[
              0.20264182690306143`, 0.3303197866819874, 0.9348515243091869], 
             179 -> RGBColor[
              0.2001120590885424, 0.3276608403123844, 0.9347074577746062], 
             467 -> RGBColor[
              0.19114672360584797`, 0.3182377042849717, 0.934196895181892], 
             223 -> 
             RGBColor[
              0.20818468230621298`, 0.33614567914803034`, 0.9351671817244767],
              456 -> RGBColor[
              0.19561148544389112`, 0.32293045205900567`, 0.9344511567635453],
              323 -> RGBColor[
              0.9927101178720487, 0.9912534606457363, 0.7704757426777427], 
             500 -> RGBColor[
              0.20098870068601762`, 0.3285822462136184, 0.9347573812167074], 
             478 -> RGBColor[
              0.24931371638514488`, 0.37937490169636373`, 0.9375094193703185],
              292 -> RGBColor[
              0.18511992750412062`, 0.3119031594611132, 0.9338536780597445], 
             491 -> RGBColor[
              0.1816268290277524, 0.30823169148721496`, 0.9336547512690914], 
             396 -> RGBColor[
              0.19743844380411263`, 0.32485070113144887`, 0.9345551993394172],
              321 -> RGBColor[
              0.9854351531478911, 0.9882450757742316, 0.8910407351622261], 
             143 -> RGBColor[
              0.5806518106608889, 0.6704383238173092, 0.9601301840143426], 
             112 -> RGBColor[
              0.9934414779456845, 0.9915558968312813, 0.7583552135583986], 
             197 -> RGBColor[
              0.23089370286527677`, 0.3600142995906707, 0.93646042685033], 
             421 -> RGBColor[
              0.1843367269803192, 0.31107996605281657`, 0.9338090759485553], 
             54 -> RGBColor[
              0.9895254911096693, 0.9899365356383177, 0.8232532496802422], 71 -> 
             RGBColor[
              0.19773867236084267`, 0.32516626038016205`, 0.9345722969115747],
              177 -> RGBColor[
              0.18438238961983267`, 0.3111279603821238, 0.9338116763683237], 
             158 -> RGBColor[
              0.19170728594478786`, 0.3188268908449026, 0.9342288183778169], 
             226 -> RGBColor[
              0.1869796895121246, 0.3138578872472471, 0.933959588754829], 432 -> 
             RGBColor[
              0.29123303955595214`, 0.4234347681874807, 0.9398966628108147], 
             350 -> RGBColor[
              0.1815243108454087, 0.3081239383775436, 0.933648913010269], 203 -> 
             RGBColor[
              0.8450710458930704, 0.34744138575819206`, 0.19079339048865696`],
              475 -> RGBColor[
              0.3365285973416883, 0.465905889423426, 0.9426642825354262], 115 -> 
             RGBColor[
              0.19098661972276523`, 0.31806942495267926`, 0.934187777502603], 
             173 -> RGBColor[
              0.720597203195575, 0.7816552789687509, 0.9727860529169569], 212 -> 
             RGBColor[
              0.1819457440050942, 0.3085668913487786, 0.9336729130052586], 
             129 -> RGBColor[
              0.2893758023858067, 0.42148269416601997`, 0.9397908959015111], 
             279 -> RGBColor[
              0.20798277523591915`, 0.3359334620155039, 0.9351556834155181], 
             26 -> RGBColor[
              0.1848952269737127, 0.31166698495681794`, 0.9338408816969523], 
             40 -> RGBColor[
              0.18500874865393632`, 0.31178630344042324`, 0.9338473465887008],
              146 -> RGBColor[
              0.1800731039927536, 0.30659862796357423`, 0.9335662689268784], 
             386 -> RGBColor[
              0.30560245203902436`, 0.43853793178056216`, 0.9407149795940849],
              192 -> RGBColor[
              0.3129892535839804, 0.4455172929823175, 0.9411643763662094], 
             300 -> RGBColor[
              0.23186327956718236`, 0.36103338617908703`, 0.9365156428091433],
              221 -> RGBColor[
              0.9622752132426141, 0.884407577445488, 0.3079467564861062], 62 -> 
             RGBColor[
              0.25119317281524384`, 0.3813503295688181, 0.9376164516336061], 
             286 -> RGBColor[
              0.18739586640915007`, 0.3142953155531602, 0.933983289413436], 
             472 -> RGBColor[
              0.18313584696674626`, 0.3098177650183609, 0.9337406876083251], 
             152 -> RGBColor[
              0.18423542654322242`, 0.31097349287060916`, 0.9338033070385232],
              64 -> RGBColor[
              0.18480592008610275`, 0.3115731177555562, 0.9338357958018207], 
             307 -> RGBColor[
              0.1917730045224159, 0.3188959652367882, 0.934232560953591], 37 -> 
             RGBColor[
              0.861854760386902, 0.4655965562049136, 0.20644056462819607`], 
             148 -> RGBColor[
              0.27463540520047075`, 0.4059896021290707, 0.9389514520882697], 
             261 -> RGBColor[
              0.329292758612209, 0.4596385695997802, 0.9422032212899847], 387 -> 
             RGBColor[
              0.18889078087796188`, 0.3158665654429332, 0.934068422580907], 
             15 -> RGBColor[
              0.6524065300643914, 0.7283842068503593, 0.9659894438973117], 
             136 -> RGBColor[
              0.5282221961294052, 0.6278736008134325, 0.956002732702418], 198 -> 
             RGBColor[
              0.1824115868132323, 0.30905652167627173`, 0.9336994420640293], 
             63 -> RGBColor[
              0.20681114074536727`, 0.3347019998800166, 0.9350889605645591], 
             444 -> 
             RGBColor[
              0.5658641034717166, 0.6584329969425219, 0.9589660415352547], 
             310 -> RGBColor[
              0.644812645752953, 0.7224518067106054, 0.9652325564780311], 171 -> 
             RGBColor[
              0.47069483175957283`, 0.581170294839771, 0.9514739678495456], 
             395 -> RGBColor[
              0.5041410272247835, 0.6083234230523641, 0.954106974874018], 311 -> 
             RGBColor[
              0.18998459744441062`, 0.31701623600624673`, 0.9341307138162097],
              353 -> RGBColor[
              0.18070771638990538`, 0.3072656458297307, 0.9336024091640713], 
             59 -> RGBColor[
              0.26299592027232827`, 0.3937557654836245, 0.9382886006406869], 
             397 -> RGBColor[
              0.8220097648168001, 0.1701822738881748, 0.16870988168602888`], 
             229 -> RGBColor[
              0.2348407472607494, 0.36416289350738135`, 0.9366852051895233], 
             102 -> RGBColor[
              0.19944242864104303`, 0.32695701625504003`, 0.9346693233112505],
              453 -> RGBColor[
              0.23993040743871616`, 0.3695124490575181, 0.936975053807181], 
             299 -> RGBColor[
              0.24007340415027964`, 0.3696627476678865, 0.9369831972583599], 
             128 -> RGBColor[
              0.19425607642724724`, 0.32150583124461773`, 0.9343739682251954],
              12 -> RGBColor[
              0.19403535624859544`, 0.3212738403423871, 0.9343613985375474], 
             222 -> RGBColor[
              0.1971022673351447, 0.32449735834774435`, 0.9345360545868381], 
             483 -> RGBColor[
              0.4520407911262143, 0.5659567458679113, 0.9500246173799538], 92 -> 
             RGBColor[
              0.27193911320159614`, 0.4031556282834669, 0.9387979022477403], 
             271 -> RGBColor[
              0.20809576797568208`, 0.3360522245491482, 0.9351621181848899], 
             361 -> RGBColor[
              0.23010075165696398`, 0.35918085759472357`, 0.9364152694520828],
              344 -> RGBColor[
              0.1902758304551235, 0.3173223403657453, 0.9341472991053292], 
             132 -> RGBColor[
              0.2723145403641676, 0.4035502260347864, 0.938819282269254], 80 -> 
             RGBColor[
              0.3474160266946404, 0.4753360335108428, 0.9433580199064205], 
             324 -> RGBColor[
              0.9397327677393429, 0.9545733773753136, 0.9869008833924131], 
             244 -> RGBColor[
              0.44672166802497704`, 0.5613495887845201, 0.9496856875594589], 
             150 -> 
             RGBColor[
              0.2153604952721365, 0.34368791354803596`, 0.9355758336572221], 
             125 -> RGBColor[
              0.7779497574122243, 0.8264595302183536, 0.978502419531181], 258 -> 
             RGBColor[
              0.41518076487513966`, 0.5340304437680178, 0.9476759291012767], 
             133 -> RGBColor[
              0.19798057442534764`, 0.32542051478743356`, 0.9345860728762861],
              469 -> RGBColor[
              0.18135253868176207`, 0.30794339494256673`, 0.9336391308396634],
              255 -> RGBColor[
              0.19717041562221144`, 0.32456898651830246`, 0.9345399355309701],
              408 -> RGBColor[
              0.9372841166711893, 0.9527471774179826, 0.9910458109403161], 
             326 -> RGBColor[
              0.7253820295989173, 0.7853932217210695, 0.973262959696097], 176 -> 
             RGBColor[
              0.3169334821091241, 0.44893358548810713`, 0.9414156991200873], 
             230 -> RGBColor[
              0.2058983382969339, 0.3337425866316952, 0.9350369778154911], 
             274 -> RGBColor[
              0.24408437678171757`, 0.37387853421388084`, 0.937211616216018], 
             87 -> RGBColor[
              0.30841227476556676`, 0.4414912336192087, 0.9408749948416013], 
             439 -> RGBColor[
              0.19923030702383038`, 0.32673406298606217`, 0.934657243298956], 
             130 -> RGBColor[
              0.30291909395791666`, 0.43571755230258913`, 0.9405621663210384],
              35 -> RGBColor[
              0.187649142725438, 0.3145615250202248, 0.9339977131249598], 379 -> 
             RGBColor[
              0.8274245231995631, 0.21180247958034423`, 0.17389506042845765`],
              31 -> RGBColor[
              0.19198099569549876`, 0.3191145771471003, 0.9342444057432027], 
             18 -> RGBColor[
              0.2883133698343315, 0.42036601019230513`, 0.9397303919394328], 
             24 -> RGBColor[
              0.18529079599648704`, 0.31208275308027844`, 0.9338634087676074],
              151 -> RGBColor[
              0.20371318105767475`, 0.33144584782626274`, 0.9349125363433657],
              137 -> RGBColor[
              0.2116557852103354, 0.33979402838089834`, 0.9353648558998299], 
             330 -> RGBColor[
              0.18958070170652433`, 0.3165917159772593, 0.9341077125514473], 
             296 -> RGBColor[
              0.18222924951210637`, 0.30886487361193576`, 0.9336890582244741],
              266 -> RGBColor[
              0.9935833726583437, 0.9886838078737659, 0.5429678965735315], 
             302 -> 
             RGBColor[
              0.24476085053842922`, 0.3745895510230982, 0.9372501403957095], 
             442 -> RGBColor[
              0.2379042947950852, 0.36738287620610066`, 0.9368596696894913], 
             283 -> RGBColor[
              0.18231742038260904`, 0.3089575467871901, 0.9336940794251122], 
             388 -> RGBColor[
              0.3286879472145684, 0.4591147123658486, 0.9421646832425408], 
             284 -> RGBColor[
              0.20683017875346388`, 0.3347220100336056, 0.935090044750956], 
             417 -> RGBColor[
              0.19713115786974042`, 0.32452772413137015`, 0.9345376998600435],
              318 -> RGBColor[
              0.1979808475129809, 0.32542080181985084`, 0.9345860884282229], 
             413 -> RGBColor[
              0.23030998251802656`, 0.3594007724957031, 0.936427184840091], 
             238 -> RGBColor[
              0.48668906339049306`, 0.5941551326096759, 0.9527330923523326], 
             72 -> RGBColor[
              0.21111609134757603`, 0.339226775912571, 0.9353341211327513], 
             437 -> RGBColor[
              0.18191959414620315`, 0.3085394061890873, 0.93367142380948], 
             288 -> RGBColor[
              0.7112234006140565, 0.7743323931485304, 0.9718517598787967], 
             382 -> RGBColor[
              0.21206977390702858`, 0.3402291567495223, 0.9353884319436652], 
             461 -> RGBColor[
              0.25327163562221944`, 0.38353492576110276`, 0.9377348170156531],
              389 -> RGBColor[
              0.19492141529937626`, 0.32220514458414634`, 0.9344118582896825],
              172 -> RGBColor[
              0.22349209680564214`, 0.35223474233306573`, 0.9360389163349288],
              447 -> RGBColor[
              0.23372958097512028`, 0.36299498728917345`, 0.9366219259133799],
              243 -> RGBColor[
              0.19657931914436805`, 0.32394770664240774`, 0.9345062734610058],
              410 -> RGBColor[
              0.18224818387414324`, 0.30888477482694443`, 0.9336901365083813],
              88 -> RGBColor[
              0.18955897979005848`, 0.3165688848658047, 0.9341064755204392], 
             273 -> RGBColor[
              0.18715875648320013`, 0.3140460979873492, 0.9339697863539259], 
             477 -> RGBColor[
              0.19779376632799722`, 0.32522416763280076`, 0.9345754344314999],
              202 -> RGBColor[
              0.18676020758344578`, 0.31362719782424764`, 0.9339470895836851],
              393 -> RGBColor[
              0.2213158585080208, 0.34994737790078817`, 0.9359149827833353], 
             98 -> 
             RGBColor[
              0.18830185869099547`, 0.3152475708846082, 0.9340348843335916], 
             30 -> RGBColor[
              0.17893397678527326`, 0.30540133304367595`, 0.9335013973176001],
              116 -> RGBColor[
              0.27647894211230134`, 0.40792727631039594`, 0.9390564387881299],
              373 -> RGBColor[
              0.9909995879120733, 0.9905461125486716, 0.7988236508241691], 
             434 -> RGBColor[
              0.9350798973521478, 0.7803204568826958, 0.2666219654201177], 
             401 -> RGBColor[
              0.18072732343424755`, 0.30728625407649274`, 0.9336035257562406],
              240 -> RGBColor[
              0.9948059876224538, 0.9912988576566625, 0.6760419903119628], 
             480 -> RGBColor[
              0.24336115250331075`, 0.37311837964220756`, 0.9371704296632771],
              403 -> RGBColor[
              0.7434088886883141, 0.7994759410509097, 0.9750597085395519], 
             317 -> RGBColor[0.817319, 0.134127, 0.164218], 429 -> 
             RGBColor[
              0.1919491178531559, 0.319081071513626, 0.9342425903472402], 391 -> 
             RGBColor[
              0.47311473175482466`, 0.583134878671169, 0.9516644712415576], 
             73 -> RGBColor[
              0.5768983856608343, 0.6673911243123956, 0.9598347006490895], 
             303 -> RGBColor[
              0.8407980254541154, 0.31459707821488886`, 0.1867015412906274], 
             449 -> RGBColor[
              0.9836066487684537, 0.9563635183333898, 0.39081535540040413`], 
             29 -> RGBColor[
              0.1844293578243088, 0.3111773269429844, 0.9338143511380854], 
             360 -> RGBColor[
              0.5961635782161725, 0.6830314755158533, 0.9613513271777714], 
             320 -> RGBColor[
              0.18113843442729957`, 0.3077183577961329, 0.9336269379191107], 
             482 -> RGBColor[
              0.3323719943960167, 0.4623056488688239, 0.9423994274712677], 75 -> 
             RGBColor[
              0.8653183386459826, 0.4813238561401438, 0.20933065922764493`], 
             200 -> RGBColor[
              0.26297543885551555`, 0.39373423821595743`, 0.938287434254299], 
             301 -> RGBColor[
              0.6564481594438648, 0.7315415584391249, 0.9663922757426836], 
             156 -> RGBColor[
              0.19939483773806957`, 0.32690699519857735`, 0.9346666130797306],
              25 -> RGBColor[
              0.2888948585418871, 0.42097719169245956`, 0.9397635068610926], 
             38 -> RGBColor[
              0.5188198477638203, 0.6202403508392836, 0.9552625453971423], 
             365 -> RGBColor[
              0.20704370002822514`, 0.33494643443141037`, 0.9351022044716772],
              380 -> RGBColor[
              0.1874689911967999, 0.31437217434135956`, 0.9339874537619143], 
             370 -> RGBColor[
              0.22875987812146206`, 0.3577715144926186, 0.9363389086878806], 
             3 -> RGBColor[
              0.18365861817242612`, 0.31036723070113925`, 0.9337704586551179],
              57 -> RGBColor[
              0.9626408166905339, 0.9716581627746242, 0.9481235318941049], 
             227 -> RGBColor[
              0.19315889756887425`, 0.3203526266993102, 0.9343114855123418], 
             494 -> RGBColor[
              0.35530253300255993`, 0.4821669288874302, 0.9438605411145975], 
             39 -> RGBColor[
              0.24759097892264678`, 0.3775641953954144, 0.937411312020391], 
             424 -> RGBColor[
              0.19347184238884513`, 0.3206815515469472, 0.9343293072568787], 
             109 -> RGBColor[
              0.2136359512540558, 0.3418753084426271, 0.9354776234266265], 
             465 -> RGBColor[
              0.1790493149440538, 0.30552256076141593`, 0.9335079656551152], 
             256 -> RGBColor[
              0.3115575299166111, 0.44427720590216613`, 0.9410731482001482], 
             457 -> RGBColor[
              0.4692511982227218, 0.5799982880996057, 0.9513603197293209], 
             339 -> RGBColor[
              0.1801862242299471, 0.30671752450510187`, 0.9335727109570402], 
             420 -> RGBColor[
              0.1880446060283209, 0.31497718202537633`, 0.9340202341750236], 
             287 -> RGBColor[
              0.304153838987054, 0.4370153476155689, 0.9406324832238061], 239 -> 
             RGBColor[
              0.1966443508485099, 0.324016059086709, 0.9345099769203509], 427 -> 
             RGBColor[
              0.18651414967483487`, 0.3133685753613251, 0.9339330769497998], 
             285 -> RGBColor[
              0.21438774917055564`, 0.3426654957196094, 0.9355204372057859], 
             345 -> RGBColor[
              0.19084105210201593`, 0.31791642415375154`, 0.9341794876419492],
              366 -> RGBColor[
              0.18255683100735334`, 0.30920918253330676`, 0.933707713506015], 
             216 -> RGBColor[
              0.19991510326486814`, 0.3274538272539823, 0.934696241431818], 
             21 -> RGBColor[
              0.3000028152540131, 0.4326523584820372, 0.9403960885630988], 
             355 -> 
             RGBColor[
              0.5597098423756648, 0.6534366905384442, 0.9584815555579723], 
             175 -> RGBColor[
              0.39767741348965524`, 0.5188699205419315, 0.9465606310285997], 
             7 -> RGBColor[
              0.47235402937887205`, 0.5825173062131191, 0.951604585963978], 
             13 -> RGBColor[
              0.25294530714331137`, 0.3831919338393498, 0.9377162330915391], 
             294 -> RGBColor[
              0.18749202516745894`, 0.31439638450496027`, 0.9339887655124676],
              412 -> RGBColor[
              0.1902556572489104, 0.31730113704696017`, 0.934146150271079], 
             193 -> RGBColor[
              0.18092386766537458`, 0.30749283452503123`, 0.9336147186594421],
              60 -> RGBColor[
              0.9854928836228277, 0.9882689488092234, 0.890083991790846], 65 -> 
             RGBColor[
              0.183179266829206, 0.30986340204678436`, 0.9337431603052583], 
             448 -> RGBColor[
              0.300584051971647, 0.4332632751248068, 0.9404291891343054], 69 -> 
             RGBColor[
              0.44285619720498837`, 0.5580015122444584, 0.9494393831769108], 
             217 -> RGBColor[
              0.18124242467150065`, 0.3078276581361505, 0.9336328600096782], 
             214 -> RGBColor[
              0.1875451608924792, 0.3144522335209561, 0.9339917915134002], 
             170 -> RGBColor[
              0.1877350381466607, 0.3146518065540141, 0.9340026047421276], 
             359 -> RGBColor[
              0.9095261013751367, 0.9306954410809412, 0.9912326055643381], 74 -> 
             RGBColor[
              0.18870685733270803`, 0.31567325013544506`, 0.9340579484070953],
              246 -> RGBColor[
              0.2398990282396083, 0.3694794675296996, 0.9369732668082131], 
             264 -> RGBColor[
              0.8655438992520076, 0.482348074171085, 0.20951887252630852`], 
             278 -> RGBColor[
              0.18446408847726348`, 0.3112138310612903, 0.9338163289973919], 
             45 -> RGBColor[
              0.2011773237053474, 0.3287805009663242, 0.9347681230186154], 
             492 -> RGBColor[
              0.18260872208869527`, 0.3092637233498817, 0.9337106686263315], 
             306 -> RGBColor[
              0.24077004537273583`, 0.3703949617622926, 0.9370228699453904], 
             237 -> RGBColor[
              0.2328901660883635, 0.3621127090212143, 0.9365741224773821], 
             228 -> RGBColor[
              0.2582166797056685, 0.38873248062671145`, 0.9380164299606684], 
             180 -> 
             RGBColor[
              0.26314504718325327`, 0.39391250732219896`, 0.9382970931976505],
              383 -> RGBColor[
              0.2677744651747997, 0.39877831915336787`, 0.938560731703659], 
             53 -> RGBColor[
              0.8326746621018166, 0.2521573478086015, 0.17892259937043942`], 
             304 -> RGBColor[
              0.190709032669891, 0.3177776633600728, 0.934171969330595], 48 -> 
             RGBColor[
              0.18988308106937135`, 0.3169095358595705, 0.9341249326088312], 
             5 -> RGBColor[
              0.6895762664964494, 0.7574214874515429, 0.9696941758539234], 
             101 -> RGBColor[
              0.24511118458418202`, 0.3749577743176459, 0.9372700914013423], 
             333 -> RGBColor[
              0.23178823080036964`, 0.3609545051668002, 0.9365113688928981], 
             267 -> RGBColor[
              0.22925694712510034`, 0.35829396553143755`, 0.9363672160322901],
              120 -> RGBColor[
              0.1799037129149489, 0.30642058720078685`, 0.9335566223555891], 
             147 -> RGBColor[
              0.8190803262063154, 0.147665325039805, 0.16590464796430104`], 
             89 -> RGBColor[
              0.30968149308884285`, 0.4426522770943059, 0.940953608792397], 
             43 -> RGBColor[
              0.22836865224462058`, 0.35736031129090495`, 0.9363166289529613],
              199 -> RGBColor[
              0.3861343022549474, 0.5088718577640675, 0.9458251141878965], 
             268 -> RGBColor[
              0.1863015188096388, 0.3131450868404286, 0.9339209679365861], 
             169 -> RGBColor[
              0.18381241008660495`, 0.31052887575391175`, 0.9337792168771156],
              20 -> RGBColor[
              0.24175756143219096`, 0.3714329037529144, 0.9370791075240773], 
             4 -> RGBColor[
              0.18151204232925333`, 0.30811104338919537`, 0.9336482143364235],
              167 -> RGBColor[
              0.23986313789965336`, 0.369441744506828, 0.9369712229064477], 
             431 -> RGBColor[
              0.4212519905865513, 0.5392890343305656, 0.9480627822350338], 
             142 -> RGBColor[
              0.21571267720568413`, 0.3440580790898188, 0.9355958898973311], 
             16 -> RGBColor[
              0.27011669665931304`, 0.4012401529496448, 0.9386941183216809], 
             414 -> RGBColor[
              0.4226665958174486, 0.5405142942814426, 0.9481529196294604], 
             281 -> RGBColor[
              0.8184239254643847, 0.14261994130068656`, 0.16527607787252963`],
              289 -> 
             RGBColor[
              0.21007296758615746`, 0.3381303867014537, 0.9352747167777018], 
             398 -> RGBColor[
              0.20625914549310514`, 0.3341218178713687, 0.9350575252515466], 
             178 -> RGBColor[
              0.46930938565191127`, 0.5800455272759355, 0.9513649004568943], 
             58 -> RGBColor[
              0.19316750906165184`, 0.32036167792421966`, 0.9343119759241159],
              186 -> RGBColor[
              0.9933232264913885, 0.9881273815274607, 0.5146525917364964], 
             122 -> RGBColor[
              0.18567855904381614`, 0.3124903166286185, 0.9338854912995088], 
             249 -> RGBColor[
              0.7269497450043649, 0.7866179329108834, 0.9734192149165786], 
             113 -> RGBColor[
              0.19671677940387242`, 0.3240921860906307, 0.9345141016194304], 
             52 -> RGBColor[
              0.1799948891424975, 0.30651641919684713`, 0.9335618147068648], 
             409 -> RGBColor[
              0.2532336129818181, 0.38349496155526636`, 0.9377326516825317], 
             187 -> RGBColor[
              0.22124625332801934`, 0.34987421844338334`, 0.9359110188713058],
              259 -> RGBColor[
              0.6832732263253226, 0.7524975045649791, 0.9690659477149247], 42 -> 
             RGBColor[
              0.2005501569047806, 0.3281213088942566, 0.9347324067971333], 
             134 -> RGBColor[
              0.18413129784782198`, 0.3108640470096027, 0.9337973770633647], 
             470 -> RGBColor[
              0.19461387303716265`, 0.3218818981672542, 0.9343943442128174], 
             313 -> RGBColor[
              0.36122042818933575`, 0.4872927122561548, 0.9442376241629096], 
             248 -> RGBColor[
              0.18027294835259305`, 0.30680867705662973`, 0.933577649767528], 
             174 -> RGBColor[
              0.18747717117288942`, 0.31438077201487, 0.9339879195994514], 
             215 -> RGBColor[
              0.18496268734880916`, 0.3117378900882792, 0.9338447234655154], 
             399 -> RGBColor[
              0.20787897197296468`, 0.3358243582046317, 0.9351497719732561], 
             422 -> RGBColor[
              0.20654013009820746`, 0.33441715050678417`, 0.9350735269091277],
              83 -> RGBColor[
              0.9952268649647723, 0.9922942002460275, 0.7287667302186207], 95 -> 
             RGBColor[
              0.1846806812934658, 0.3114414838438967, 0.9338286636378542], 
             166 -> RGBColor[
              0.19568177386369887`, 0.32300432964476683`, 0.934455159585071], 
             384 -> 
             RGBColor[
              0.2680749969538752, 0.3990941971079916, 0.9385778465438803], 
             233 -> RGBColor[
              0.9625574020842641, 0.9715959522978471, 0.948264731064506], 295 -> 
             RGBColor[
              0.9847959098179251, 0.9879807322294865, 0.9016346514484699], 
             499 -> RGBColor[
              0.628572856489554, 0.7093427876395323, 0.96390270428255], 141 -> 
             RGBColor[
              0.2073090188644706, 0.33522530135049017`, 0.9351173139868973], 
             319 -> RGBColor[
              0.18086286172523808`, 0.3074287134139478, 0.9336112444614015], 
             205 -> RGBColor[
              0.23748131534596645`, 0.36693829798663086`, 0.936835581635606], 
             468 -> RGBColor[
              0.22150150348383524`, 0.3501425025409405, 0.9359255549900708], 
             486 -> RGBColor[
              0.41333459859387617`, 0.5324313873262027, 0.9475582930183354], 
             224 -> RGBColor[
              0.20593429362604587`, 0.3337803779622914, 0.9350390254182929], 
             231 -> RGBColor[
              0.7636579459089816, 0.81529465845023, 0.9770779453251097], 332 -> 
             RGBColor[
              0.18662770310860746`, 0.3134879272199237, 0.9339395436498659], 
             68 -> RGBColor[
              0.18542751526237852`, 0.31222645369723245`, 0.933871194727542], 
             484 -> RGBColor[
              0.1848118632397346, 0.3115793643868409, 0.933836134255628], 10 -> 
             RGBColor[
              0.22678684537035088`, 0.355697731973699, 0.9362265473915452], 
             250 -> RGBColor[
              0.2196415898680099, 0.3481876154053738, 0.9358196356611451], 
             282 -> RGBColor[
              0.6967134214587186, 0.7629970871524544, 0.9704055407600571], 
             374 -> RGBColor[
              0.847444298272204, 0.36568324351003745`, 0.19306601964712058`], 
             232 -> RGBColor[
              0.2784596091749779, 0.41000908297481403`, 0.939169234847215], 
             489 -> RGBColor[
              0.19162106685648111`, 0.3187362691164863, 0.9342239083282876], 
             253 -> RGBColor[
              0.37749249202520396`, 0.5013867560930751, 0.94527446568171], 
             459 -> RGBColor[
              0.1944799719611093, 0.3217411596465035, 0.9343867187446251], 
             415 -> RGBColor[
              0.1803991146634024, 0.3069412858486965, 0.9335848347522823], 55 -> 
             RGBColor[
              0.5735931996355866, 0.6647078254001658, 0.9595745042978867], 
             446 -> 
             RGBColor[
              0.18340710413885652`, 0.31010287350494686`, 0.9337561353029877],
              325 -> RGBColor[
              0.23363553097946993`, 0.3628961347806308, 0.9366165699052621], 
             91 -> RGBColor[
              0.46032419676718667`, 0.5727509461611696, 0.9506575534740573], 
             450 -> RGBColor[
              0.2155265395117455, 0.34386243657167787`, 0.9355852896310274], 
             423 -> RGBColor[
              0.1791999116318114, 0.3056808474286306, 0.9335165419136952], 
             105 -> RGBColor[
              0.1914252698739526, 0.31853047407360313`, 0.9342127579797883], 
             36 -> RGBColor[
              0.9941315043202534, 0.9918412404700345, 0.7469196908007765], 
             123 -> RGBColor[
              0.18584647349383113`, 0.3126668053619753, 0.93389505377903], 94 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 473 -> 
             RGBColor[
              0.2635938852306148, 0.3943842645679517, 0.9383226538604513], 
             312 -> RGBColor[
              0.19496888133162707`, 0.3222550343935622, 0.9344145614099995], 
             96 -> RGBColor[
              0.4707743379765772, 0.5812348415684494, 0.9514802268701891], 
             496 -> RGBColor[
              0.1858152550736946, 0.31263399282304966`, 0.9338932759361868], 
             2 -> RGBColor[
              0.18419449056434983`, 0.3109304665613231, 0.9338009757950858], 
             262 -> RGBColor[
              0.34316736625512184`, 0.47165605738201455`, 0.9430872990201573],
              272 -> RGBColor[
              0.25722683759211185`, 0.3876920938057486, 0.9379600599166416], 
             97 -> RGBColor[
              0.9884567952610653, 0.9727242013215213, 0.40965725865088887`], 
             372 -> RGBColor[
              0.6142711963162304, 0.6977320556283797, 0.9627768252049985], 
             356 -> RGBColor[
              0.24531622372842543`, 0.3751732834584783, 0.9372817680772788], 
             402 -> RGBColor[
              0.21812922311479366`, 0.346598022058153, 0.9357335086118955], 
             455 -> RGBColor[
              0.6130446091083116, 0.6967362568758672, 0.9626802637668542], 
             428 -> RGBColor[
              0.18777404508405116`, 0.31469280531839416`, 0.9340048261295064],
              346 -> RGBColor[
              0.4414153171565428, 0.5567534943672319, 0.9493475715743441], 
             341 -> RGBColor[
              0.9942973298741586, 0.9902108901662465, 0.6206777334817875], 
             209 -> RGBColor[
              0.9944761061763768, 0.9919837421934052, 0.7412087462437971], 
             498 -> RGBColor[
              0.7745863239297996, 0.8238319904188423, 0.9781671839147258], 
             378 -> RGBColor[
              0.20696414784897932`, 0.33486282004712353`, 0.9350976740927561],
              419 -> RGBColor[
              0.649286320101708, 0.725946675113037, 0.9656784505282513], 66 -> 
             RGBColor[
              0.19788231111085003`, 0.3253172338136426, 0.9345804769258931], 
             139 -> RGBColor[
              0.18259939511325524`, 0.3092539201073298, 0.9337101374688782], 
             56 -> RGBColor[
              0.4068474012204774, 0.5268125030173851, 0.9471449345381059], 
             335 -> RGBColor[
              0.21037507790267013`, 0.33844792379900884`, 0.935291921513295], 
             314 -> RGBColor[
              0.2628079616436893, 0.3935582090476596, 0.9382778966748457], 
             144 -> RGBColor[
              0.1968786888055324, 0.3242623631374243, 0.9345233221203314], 
             298 -> RGBColor[
              0.2756885017375273, 0.407096473359694, 0.9390114243781383], 204 -> 
             RGBColor[
              0.3159031668134525, 0.44804117816414885`, 0.941350048340519], 
             452 -> RGBColor[
              0.22680832648896532`, 0.3557203099913444, 0.9362277707094718], 
             466 -> RGBColor[
              0.19488624546246058`, 0.32216817885565147`, 0.9344098554194993],
              207 -> RGBColor[
              0.8749870106263872, 0.5252270374274478, 0.21739843612893187`], 
             334 -> RGBColor[
              0.18685517330782678`, 0.3137270128217468, 0.9339524977411994], 
             149 -> RGBColor[
              0.5611296111138018, 0.6545893227599167, 0.9585933249538227], 
             219 -> RGBColor[
              0.6695263659366376, 0.7417583527493299, 0.9676957891430948], 
             400 -> RGBColor[
              0.989868357531768, 0.9900783197151207, 0.8175710657562082], 9 -> 
             RGBColor[
              0.1937919382554366, 0.32101799259798497`, 0.9343475362429416], 
             11 -> RGBColor[
              0.37557365642318313`, 0.49972475713808634`, 0.9451521991739089],
              44 -> RGBColor[
              0.2790104916899246, 0.4105880954259918, 0.9392006067914836], 
             153 -> RGBColor[
              0.22763715789209957`, 0.35659146434698463`, 0.9362749714317341],
              471 -> RGBColor[
              0.9568366664708343, 0.967329437044196, 0.9579484442512339], 406 -> 
             RGBColor[
              0.41650215403555035`, 0.5351749646438152, 0.9477601268501196], 
             32 -> RGBColor[
              0.21967241372144744`, 0.34822001322968177`, 0.9358213910339986],
              162 -> RGBColor[
              0.18332605976082084`, 0.310017690725121, 0.933751519945553], 
             493 -> RGBColor[
              0.2609046791964185, 0.39155773852050096`, 0.9381695075551277], 
             90 -> RGBColor[
              0.2623509631444437, 0.39307787464957405`, 0.9382518712863824], 
             331 -> RGBColor[
              0.30143473291096856`, 0.4341573947283205, 0.94047763415533], 8 -> 
             RGBColor[
              0.19748659103157024`, 0.32490130692021735`, 0.9345579412527936],
              364 -> RGBColor[
              0.20439189938454302`, 0.3321592238210287, 0.9349511883480071], 
             342 -> RGBColor[
              0.47631296582080423`, 0.5857313491647339, 0.951916247942749], 
             163 -> RGBColor[
              0.899308535201446, 0.6356654000864056, 0.23769291240948212`], 
             49 -> RGBColor[
              0.9939249281250245, 0.9894143604804412, 0.5801441012857329], 
             338 -> RGBColor[
              0.4243323457115801, 0.5419570831167153, 0.9482590597397496], 76 -> 
             RGBColor[
              0.4104281337116228, 0.5299139535283672, 0.9473730956461243], 
             369 -> RGBColor[
              0.18202687820624844`, 0.30865216853839716`, 0.933677533477987], 
             445 -> RGBColor[
              0.9631188181102052, 0.8872532547517151, 0.3112240020952856], 82 -> 
             RGBColor[
              0.5201221497039563, 0.62129761822232, 0.955365067376359], 67 -> 
             RGBColor[
              0.18087272641393248`, 0.30743908182722296`, 0.9336118062408292],
              430 -> RGBColor[
              0.20155620116286646`, 0.329178725196395, 0.9347896995293221], 
             211 -> RGBColor[
              0.1874830946539544, 0.31438699796903974`, 
               0.933988256932935]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw1l3k4VA/cxYfs69jHPjOGGTNjV1rUPZUi6hcVbZKtXVmyRook2RJlqUih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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 42}], {
             RGBColor[
             0.19991385155278849`, 0.32745251162522343`, 0.9346961701486667]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 108}], {
             RGBColor[
             0.20444558985732308`, 0.3322156559120931, 0.9349542459410038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[
             0.1979971628023344, 0.3254379502234105, 0.9345870175598152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 119}], {
             RGBColor[
             0.1917982653600388, 0.3189225159787594, 0.9342339995209235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 120}], {
             RGBColor[
             0.18959062955787265`, 0.3166021507784885, 0.9341082779278946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 124}], {
             RGBColor[
             0.1923231620506201, 0.3194742156809328, 0.934263891610937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 315}], {
             RGBColor[
             0.19134373832478055`, 0.31844477924602455`, 0.934208114878678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 363}], {
             RGBColor[
             0.19094550353876433`, 0.3180262092363777, 0.93418543599675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 364}], {
             RGBColor[
             0.2018347227926697, 0.32947146908860947`, 0.9348055609241036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 378}], {
             RGBColor[
             0.20312084702488786`, 0.3308232672016569, 0.9348788037964781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 380}], {
             RGBColor[
             0.19337326869879815`, 0.3205779443487749, 0.9343236936310573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 381}], {
             RGBColor[
             0.1937883174344935, 0.32101418688560046`, 0.9343473300425454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 416}], {
             RGBColor[
             0.20425325698717794`, 0.33201350187096224`, 0.9349432928685801]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 452}], {
             RGBColor[
             0.21304293634488086`, 0.3412520121737673, 0.935443852104836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 468}], {
             RGBColor[
             0.21038952484231582`, 0.33846310844856536`, 0.9352927442451355]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 487}], {
             RGBColor[
             0.19600881958127922`, 0.3233480754298399, 0.9344737843548664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[
             0.19103840083759993`, 0.31812385018748285`, 0.9341907263604894]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 114}], {
             RGBColor[
             0.1828144030828347, 0.30947990711565043`, 0.93372238185467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 118}], {
             RGBColor[
             0.18820276986646162`, 0.31514342224742875`, 0.9340292413716232]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 195}], {
             RGBColor[
             0.18614467853761885`, 0.312980237770288, 0.933912036115119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 255}], {
             RGBColor[
             0.19068245309328063`, 0.3177497265398128, 0.9341704556630279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 260}], {
             RGBColor[
             0.1969726482624509, 0.32436112048401927`, 0.9345286729724024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 312}], {
             RGBColor[
             0.18958168594798847`, 0.3165927504774426, 0.9341077686025426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 327}], {
             RGBColor[
             0.18398683108609262`, 0.3107122032833034, 0.9337891498950037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 334}], {
             RGBColor[
             0.18552483193608832`, 0.31232873969153496`, 0.9338767367681426]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 385}], {
             RGBColor[
             0.1828749868990639, 0.3095435845477431, 0.9337258320133786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 446}], {
             RGBColor[
             0.18380079735160318`, 0.310516670033135, 0.9337785555490368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 496}], {
             RGBColor[
             0.18500487281902223`, 0.3117822296921864, 0.9338471258656362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[
             0.1847525458331286, 0.3115170180315573, 0.933832756217074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 139}], {
             RGBColor[
             0.18312900664284068`, 0.3098105754042345, 0.933740298061998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 158}], {
             RGBColor[
             0.187682952058607, 0.31459706077302096`, 0.9339996385164674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 247}], {
             RGBColor[
             0.18396896047476097`, 0.31069342013773166`, 0.9337881321901256]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 278}], {
             RGBColor[
             0.1840613533248448, 0.3107905308812148, 0.9337933938262548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 401}], {
             RGBColor[
             0.18219297080333685`, 0.308826742388816, 0.9336869922056792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 428}], {
             RGBColor[
             0.18571633162823864`, 0.3125300180097667, 0.9338876423923121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 437}], {
             RGBColor[
             0.18278910615931465`, 0.30945331844511326`, 0.9337209412322989]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 451}], {
             RGBColor[
             0.19437267435842231`, 0.32162838306301855`, 0.9343806083048847]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 31}], {
             RGBColor[
             0.18674651901237604`, 0.3136128102681478, 0.9339463100398131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 151}], {
             RGBColor[
             0.19261261169346405`, 0.31977844560772906`, 0.9342803753398946]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 162}], {
             RGBColor[
             0.18241905104503708`, 0.3090643670571582, 0.9336998671409883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 191}], {
             RGBColor[
             0.18605432886244289`, 0.31288527453317777`, 0.933906890834778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.18424586592068898`, 0.3109844653182212, 0.9338039015456263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 345}], {
             RGBColor[
             0.18617654721563465`, 0.31301373377147346`, 0.9339138509891864]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 366}], {
             RGBColor[
             0.18203443666830332`, 0.30866011296125107`, 0.9336779639212193]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 389}], {
             RGBColor[
             0.18821672881431478`, 0.31515809398667083`, 0.934030036313053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 405}], {
             RGBColor[
             0.18158563263707392`, 0.3081883914686098, 0.9336524051955868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 429}], {
             RGBColor[
             0.18673058009120463`, 0.3135960574514107, 0.9339454023418319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 472}], {
             RGBColor[
             0.18232394464799978`, 0.30896440420377813`, 0.9336944509723744]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 488}], {
             RGBColor[
             0.1820203772126724, 0.30864533558196194`, 0.9336771632560201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 69}], {
             RGBColor[
             0.5662162318507189, 0.6577114998480007, 0.959566779515417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[
             0.8424015657306109, 0.8748578438487853, 0.849230453036272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 97}], {
             RGBColor[
             0.8390165308787574, 0.8650728443865321, 0.6896757172524062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 103}], {
             RGBColor[
             0.5496901810493061, 0.6433974652672816, 0.958513754171764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 129}], {
             RGBColor[
             0.4894760344411281, 0.5894520908087815, 0.9547425358777173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 163}], {
             RGBColor[
             0.7944424008489477, 0.6965434437689743, 0.6036935441317027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 204}], {
             RGBColor[
             0.502739716654951, 0.6027313328078459, 0.9555221120972213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 209}], {
             RGBColor[
             0.8420261863364131, 0.8747026148224741, 0.8554514610488602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 231}], {
             RGBColor[
             0.7266171062027156, 0.7863580729508864, 0.9733860605895166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 233}], {
             RGBColor[
             0.8260668342903568, 0.864508719874695, 0.9589794534592146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 259}], {
             RGBColor[
             0.686424746410886, 0.7549594960082611, 0.969380061784424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 275}], {
             RGBColor[
             0.5894443177306294, 0.6768531688525092, 0.9613168922152756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 326}], {
             RGBColor[
             0.7074791480476834, 0.7714073545863063, 0.9714785677750102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 346}], {
             RGBColor[
             0.5654957918264961, 0.6570874909093873, 0.9595208737141337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 348}], {
             RGBColor[
             0.575828354505173, 0.6657991165139304, 0.9602449937132509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 355}], {
             RGBColor[
             0.624643054436057, 0.7054290889949936, 0.9640878657059478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 395}], {
             RGBColor[
             0.5968586468606165, 0.6828724552519535, 0.9619005753639707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 404}], {
             RGBColor[
             0.763201606478355, 0.8150742978846761, 0.9769963355615894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 431}], {
             RGBColor[
             0.5554141285415004, 0.6483552608910543, 0.9588784790444786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 444}], {
             RGBColor[
             0.627720184984083, 0.7079272421970324, 0.964330108694589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 486}], {
             RGBColor[
             0.5514554325451628, 0.6449264373888728, 0.9586262344361294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 35}], {
             RGBColor[
             0.2010217865796709, 0.32861702158561484`, 0.9347592654094047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 101}], {
             RGBColor[
             0.22975280750904292`, 0.3588151462343254, 0.9363954545475959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 123}], {
             RGBColor[
             0.20012045196386746`, 0.3276696617564901, 0.9347079357364398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 158}], {
             RGBColor[
             0.20305085818934585`, 0.33074970449795377`, 0.9348748180358333]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 181}], {
             RGBColor[
             0.2199559451719783, 0.348518022761122, 0.9358375377306591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 189}], {
             RGBColor[
             0.23318323402672853`, 0.3624207420060165, 0.9365908122629168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 302}], {
             RGBColor[
             0.22957764048616652`, 0.3586310345870516, 0.9363854790447795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 306}], {
             RGBColor[
             0.22758223790331983`, 0.3565337399566487, 0.93627184381962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 347}], {
             RGBColor[
             0.20873556607912272`, 0.336724692921407, 0.9351985537403844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 370}], {
             RGBColor[
             0.22157715427768293`, 0.35022201632181177`, 0.935929863190865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 390}], {
             RGBColor[
             0.23515410879898574`, 0.36449225635233673`, 0.9367030506655489]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 422}], {
             RGBColor[
             0.21046728026605566`, 0.33854483432889454`, 0.9352971723014887]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 428}], {
             RGBColor[
             0.2010842377589775, 0.3286826617346995, 0.9347628219116779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 451}], {
             RGBColor[
             0.20974058048916117`, 0.3377810267879514, 0.9352557878242505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 17}], {
             RGBColor[
             0.4238987520286698, 0.5410646532335288, 0.9483742450361144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.7309397602442707, 0.7862269209257184, 0.8874289178221101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.7313065318033417, 0.7863785903909934, 0.8813505639139341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.373934744333056, 0.4947159504930181, 0.9453030779152829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 89}], {
             RGBColor[
             0.39101776123385745`, 0.5125847916537125, 0.9462790973781875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 176}], {
             RGBColor[
             0.39464375574399807`, 0.5157254458506131, 0.9465101425420326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 178}], {
             RGBColor[
             0.47083170751539166`, 0.5812814167445273, 0.9514847432104361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 244}], {
             RGBColor[
             0.45953784870192455`, 0.5719334474988196, 0.9506451367617185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 261}], {
             RGBColor[
             0.40082339399554057`, 0.5210779379064496, 0.9469039036269813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 262}], {
             RGBColor[
             0.407760697816997, 0.5270866817975668, 0.9473459424920676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 288}], {
             RGBColor[
             0.5917887149964642, 0.6784248496808247, 0.9617281729213873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 295}], {
             RGBColor[
             0.7285749695983985, 0.7852490192213029, 0.9266196187062239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 313}], {
             RGBColor[
             0.4167872287841039, 0.534905009234637, 0.9479211050634437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 321}], {
             RGBColor[
             0.7288945912633815, 0.7853811909936754, 0.9213226605631021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 341}], {
             RGBColor[
             0.7333256796265153, 0.7863640981896829, 0.7861411597228827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 376}], {
             RGBColor[
             0.421731467240934, 0.5391874600812927, 0.9482361475658946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 391}], {
             RGBColor[
             0.47273438056684836`, 0.582826092442144, 0.9516345286027679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 407}], {
             RGBColor[
             0.3747418079101595, 0.4955642254833401, 0.9453490389920554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 448}], {
             RGBColor[
             0.38646904067525956`, 0.507890290668963, 0.9460168875491417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 455}], {
             RGBColor[
             0.5426993192435918, 0.6396267815444932, 0.9571424248654161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 475}], {
             RGBColor[
             0.40444131336028016`, 0.5242115978182725, 0.9471344342497021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 478}], {
             RGBColor[
             0.36083387288200847`, 0.48094610395474147`, 0.9445570026671483]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 482}], {
             RGBColor[
             0.4023630118874444, 0.5224114775409715, 0.9470020067176228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 63}], {
             RGBColor[
             0.20214886588846875`, 0.32980165340011697`, 0.9348234509086764]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 85}], {
             RGBColor[
             0.19237812780276942`, 0.31953198817147166`, 0.9342670218292075]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 146}], {
             RGBColor[
             0.18877984751216192`, 0.31574996744189576`, 0.934062105089836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 159}], {
             RGBColor[
             0.21480140592500557`, 0.34310027519588937`, 0.9355439943460016]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 166}], {
             RGBColor[
             0.19658418244763454`, 0.3239528182824921, 0.9345065504189323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 239}], {
             RGBColor[
             0.19706547094004007`, 0.32445868300346314`, 0.9345339590865722]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 344}], {
             RGBColor[
             0.19388121074334685`, 0.3211118236429813, 0.9343526201790614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 387}], {
             RGBColor[
             0.19318868595476607`, 0.32038393618157524`, 0.9343131819168503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 435}], {
             RGBColor[
             0.21794255850182165`, 0.34640182571469935`, 0.9357228783383325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 439}], {
             RGBColor[
             0.1983584490277003, 0.3258176849531398, 0.9346075922758748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 453}], {
             RGBColor[
             0.21870849923514318`, 0.34720687798886773`, 0.9357664975299873]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 68}], {
             RGBColor[
             0.18960972675890758`, 0.3166222231476087, 0.9341093654852418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 95}], {
             RGBColor[
             0.18923630977445122`, 0.3162297382209408, 0.934088099940398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 286}], {
             RGBColor[
             0.19059390233229334`, 0.3176566540755726, 0.9341654128281889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 319}], {
             RGBColor[
             0.18732739999033735`, 0.3142233530059664, 0.9339793903521716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 330}], {
             RGBColor[
             0.19168631998098046`, 0.3188048542876222, 0.9342276243971945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 333}], {
             RGBColor[
             0.21279008452790313`, 0.3409862488823926, 0.9354294525679199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 352}], {
             RGBColor[
             0.18859199395283752`, 0.3155525214404422, 0.9340514071075369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 357}], {
             RGBColor[
             0.19116813878282407`, 0.31826021299377427`, 0.9341981147445398]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 358}], {
             RGBColor[
             0.2093374978833109, 0.33735736141228945`, 0.9352328328661546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 367}], {
             RGBColor[
             0.19547077493947268`, 0.3227825563973006, 0.9344431435084812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 368}], {
             RGBColor[
             0.18651190777224702`, 0.3133662189795604, 0.933932949276764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 375}], {
             RGBColor[
             0.19826733232951002`, 0.32572191552620944`, 0.934602403314708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 441}], {
             RGBColor[
             0.2076297588947049, 0.33556241945835885`, 0.9351355796571268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 450}], {
             RGBColor[
             0.20465923888359105`, 0.3324402145848314, 0.9349664129369846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 492}], {
             RGBColor[
             0.18820033017206594`, 0.3151408579739333, 0.9340291024346365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 102}], {
             RGBColor[
             0.21311463700569694`, 0.34132737411436953`, 0.9354479353513978]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 168}], {
             RGBColor[
             0.25974966627430485`, 0.39034374670731053`, 0.9381037312779018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 181}], {
             RGBColor[
             0.22615215264020183`, 0.355030629672469, 0.9361904025795069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.23937944149495205`, 0.3689333489173635, 0.9369436771117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 232}], {
             RGBColor[
             0.2526232272726644, 0.38285340747425656`, 0.9376978911193801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 280}], {
             RGBColor[
             0.24013030719270134`, 0.36972255637333296`, 0.9369864378024453]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 302}], {
             RGBColor[
             0.23577384795439005`, 0.3651436414983986, 0.9367383438936274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 370}], {
             RGBColor[
             0.22777336174590646`, 0.35673462323315885`, 0.9362827280397129]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 383}], {
             RGBColor[
             0.24728065527257528`, 0.3772380255635335, 0.9373936395476021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 390}], {
             RGBColor[
             0.24135031626720926`, 0.37100486326368376`, 0.9370559155143968]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 443}], {
             RGBColor[
             0.2573117613989959, 0.387781354111264, 0.9379648962018101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 451}], {
             RGBColor[
             0.2159367879573847, 0.34429363369929844`, 0.9356086526730982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 480}], {
             RGBColor[
             0.2350739989368308, 0.3644080558079533, 0.9366984885274112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 25}], {
             RGBColor[
             0.3322342574825351, 0.46035097441527295`, 0.9424578530175007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 164}], {
             RGBColor[
             0.3457994968745498, 0.4739358766298315, 0.9432550160557256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 180}], {
             RGBColor[
             0.31935935180321817`, 0.4468186322301426, 0.9417246461857798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 205}], {
             RGBColor[
             0.3065274858845748, 0.4333315275623586, 0.9409938904047574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 259}], {
             RGBColor[
             0.5294234413742529, 0.6261111308515327, 0.9571090734444168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 316}], {
             RGBColor[
             0.4071433573553281, 0.5270688453462049, 0.9471637926013148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 331}], {
             RGBColor[
             0.3385041946670758, 0.46694107593320344`, 0.9428149166646195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 348}], {
             RGBColor[
             0.41882704946853977`, 0.5369507513572022, 0.9479740053732437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 372}], {
             RGBColor[
             0.49492242636970674`, 0.598728406383233, 0.9539645121894538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 404}], {
             RGBColor[
             0.6062003014417219, 0.6862259327279479, 0.9647253472215822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 418}], {
             RGBColor[
             0.4260394736081712, 0.5428061221897597, 0.9485417938214956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 431}], {
             RGBColor[
             0.3984128235048672, 0.519506895734326, 0.9466074907044714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 444}], {
             RGBColor[
             0.4707188799474499, 0.5790788770403041, 0.9520591203545818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 40}], {
             RGBColor[
             0.18952205245126588`, 0.31653007189140514`, 0.9341043725631242]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 161}], {
             RGBColor[
             0.20394297282787943`, 0.33168737354638755`, 0.9349256226447324]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 188}], {
             RGBColor[
             0.20900601855676193`, 0.3370089556230833, 0.9352139556088873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 202}], {
             RGBColor[
             0.1903977819160206, 0.31745051908331734`, 0.9341542440606163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 243}], {
             RGBColor[
             0.19530733769648173`, 0.3226107734923974, 0.9344338359992765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 273}], {
             RGBColor[
             0.1905970563658978, 0.31765996916486816`, 0.9341655924457366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 279}], {
             RGBColor[
             0.2010090657422573, 0.3286036511789455, 0.9347585409765328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 283}], {
             RGBColor[
             0.18817638831560224`, 0.31511569356478863`, 0.9340277389813298]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 285}], {
             RGBColor[
             0.20421155270957553`, 0.33196966803099826`, 0.9349409178716667]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 318}], {
             RGBColor[
             0.19600810188078815`, 0.32334732108111897`, 0.9344737434828851]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 335}], {
             RGBColor[
             0.20220521707563277`, 0.32986088207069797`, 0.9348266600254211]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 396}], {
             RGBColor[
             0.19573690002635402`, 0.32306227073691796`, 0.9344582989384823]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 421}], {
             RGBColor[
             0.18918604161445732`, 0.31617690319760183`, 0.9340852372430514]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 430}], {
             RGBColor[
             0.19779577870573095`, 0.32522628276939103`, 0.9345755490334348]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 459}], {
             RGBColor[
             0.19425766410485237`, 0.3215074999944453, 0.9343740586410862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 477}], {
             RGBColor[
             0.19591456128829632`, 0.32324900398759393`, 0.9344684164845236]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 21}], {
             RGBColor[
             0.27647406119866225`, 0.4079221461606935, 0.9390561608273189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 59}], {
             RGBColor[
             0.2579706137078198, 0.3884738496614871, 0.938002416866113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 77}], {
             RGBColor[
             0.293706622672794, 0.4236564919439787, 0.9401246061243856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 87}], {
             RGBColor[
             0.28067879095443904`, 0.41234158372927926`, 0.9392956139665702]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 161}], {
             RGBColor[
             0.23339794827523738`, 0.36264642029486893`, 0.9366030399217282]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 188}], {
             RGBColor[
             0.23846099400411988`, 0.36796800237156463`, 0.9368913728858832]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 228}], {
             RGBColor[
             0.2555809934244899, 0.38596220723303065`, 0.9378663315261038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 243}], {
             RGBColor[
             0.2247623131438397, 0.3535698202408788, 0.9361112532762724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 256}], {
             RGBColor[
             0.2822514185299613, 0.41373456987075796`, 0.9393946906458437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 279}], {
             RGBColor[
             0.23046404118961528`, 0.35956269792742684`, 0.9364359582535287]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 285}], {
             RGBColor[
             0.2336665281569335, 0.36292871477947963`, 0.9366183351486626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 287}], {
             RGBColor[
             0.2785495730651827, 0.41010364072745936`, 0.9391743581576726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 298}], {
             RGBColor[
             0.26431690444041933`, 0.3951442035995219, 0.9383638287348387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 335}], {
             RGBColor[
             0.23166019252299075`, 0.36081992881917935`, 0.936504077302417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 354}], {
             RGBColor[
             0.28176652075351294`, 0.4133145757884693, 0.9393637933883066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 409}], {
             RGBColor[
             0.2530894600625647, 0.3833434476973081, 0.9377244423870355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 430}], {
             RGBColor[
             0.22725075415308893`, 0.3561853295178724, 0.9362529663104306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 477}], {
             RGBColor[
             0.2253695367356543, 0.3542080507360753, 0.9361458337615195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 80}], {
             RGBColor[
             0.28919811932082623`, 0.417720629815705, 0.9399116866604884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 159}], {
             RGBColor[
             0.2315482163827265, 0.3607022347960642, 0.9364977004268829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 166}], {
             RGBColor[
             0.21333099290535548`, 0.34155477788266697`, 0.9354602564998136]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 192}], {
             RGBColor[
             0.27198473276549623`, 0.40281125955144237`, 0.9388148648903828]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.21659885926136652`, 0.3449895126175285, 0.9356463566544133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 239}], {
             RGBColor[
             0.21381228139776098`, 0.3420606426036381, 0.9354876651674535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 251}], {
             RGBColor[
             0.23495511782487732`, 0.36428310422179233`, 0.9366917184239543]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 272}], {
             RGBColor[
             0.24410352476956199`, 0.37389865996315785`, 0.9372127066655989]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 435}], {
             RGBColor[
             0.23468936895954257`, 0.3640037853148743, 0.9366765844192138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 447}], {
             RGBColor[
             0.2323548964610662, 0.3615501067048703, 0.936543639663968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 453}], {
             RGBColor[
             0.23545530969286413`, 0.36480883758904264`, 0.9367202036108686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 454}], {
             RGBColor[
             0.2211862721127522, 0.34981117438310894`, 0.9359076030298306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 489}], {
             RGBColor[
             0.2113006394017466, 0.3394207476185267, 0.935344630871422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 50}], {
             RGBColor[
             0.7663849277124503, 0.8179130209698517, 0.9772202389257285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 82}], {
             RGBColor[
             0.5862643398841738, 0.6748409125363397, 0.9606772556368353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 126}], {
             RGBColor[
             0.5704313985291926, 0.6619870174784861, 0.9594308284953961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 149}], {
             RGBColor[
             0.6067680705890965, 0.6914867648051379, 0.9622913844255672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 173}], {
             RGBColor[
             0.6865018666299831, 0.7550197429095551, 0.9693877484071343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 242}], {
             RGBColor[
             0.8127597142986478, 0.8539262155582815, 0.9481932363943286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 249}], {
             RGBColor[
             0.6896781375343781, 0.7575010698806214, 0.9697043294069452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 269}], {
             RGBColor[
             0.6271401903527347, 0.708025769382796, 0.9638951523188943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 282}], {
             RGBColor[
             0.674559975761555, 0.7456906470014069, 0.9681974923286845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 323}], {
             RGBColor[
             0.82255832396822, 0.8598188337480478, 0.8682325932875272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 414}], {
             RGBColor[
             0.53753656294092, 0.634449250565901, 0.957071181763386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 419}], {
             RGBColor[
             0.6508464250830497, 0.7271654409816981, 0.9658339472127815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 449}], {
             RGBColor[
             0.8180065894164226, 0.8423738625918746, 0.678402399648858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 499}], {
             RGBColor[
             0.6404896932769727, 0.7188634972449458, 0.9649460740899308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 17}], {
             RGBColor[
             0.32278008566889027`, 0.45042607660179157`, 0.9419190112149659]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 116}], {
             RGBColor[
             0.2732978193858072, 0.4045837146300204, 0.9388752785549055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 143}], {
             RGBColor[
             0.42538425366010096`, 0.535839238383477, 0.9494121511680118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 165}], {
             RGBColor[
             0.28802163997316926`, 0.4200593836114821, 0.9397137783554151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 185}], {
             RGBColor[
             0.2408288180096403, 0.3704567355300795, 0.9370262169601158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.2456814749936662, 0.3755571856965141, 0.9373025685964933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 224}], {
             RGBColor[
             0.23802549514267946`, 0.3675102654559681, 0.9368665718699869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 277}], {
             RGBColor[
             0.35667163535651547`, 0.47978123350239554`, 0.9440785507919407]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 313}], {
             RGBColor[
             0.3156685624243244, 0.4442664326028998, 0.9414658712422952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 333}], {
             RGBColor[
             0.25095246372984137`, 0.3810973290582225, 0.9376027436072896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 358}], {
             RGBColor[
             0.24749987708524912`, 0.37746844158811943`, 0.9374061239055242]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 361}], {
             RGBColor[
             0.2501087241581385, 0.3802105052721842, 0.9375546938868818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 386}], {
             RGBColor[
             0.2878595743491687, 0.4198890423651035, 0.9397045489578829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 441}], {
             RGBColor[
             0.2457921380966431, 0.37567349963418883`, 0.9373088706964965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 89}], {
             RGBColor[
             0.3425624838836552, 0.4711321386741221, 0.9430487564503239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.6775706975021587, 0.7419956614956686, 0.932197104376443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 116}], {
             RGBColor[
             0.32596120839538445`, 0.45376963828216715`, 0.9421001714481905]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 143}], {
             RGBColor[
             0.4780476426696782, 0.5850251620356237, 0.9526370440612968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 165}], {
             RGBColor[
             0.3406850289827465, 0.4692453072636289, 0.9429386712487001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 176}], {
             RGBColor[
             0.3461884783937958, 0.47427279287102275`, 0.943279801614169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 178}], {
             RGBColor[
             0.4223764301651894, 0.5398287637649369, 0.9482544022825725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 261}], {
             RGBColor[
             0.3523681166453383, 0.4796252849268593, 0.9436735626991177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 277}], {
             RGBColor[
             0.4093350243660927, 0.5289671571545423, 0.9473034436852257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 288}], {
             RGBColor[
             0.543333437646262, 0.6369721967012344, 0.9584978319935238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 313}], {
             RGBColor[
             0.3683319514339016, 0.4934523562550466, 0.9446907641355802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 321}], {
             RGBColor[
             0.6804393139131792, 0.743928538014085, 0.9180923196352385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 328}], {
             RGBColor[
             0.30921498256740126`, 0.43616829316491434`, 0.9411464986611078]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 386}], {
             RGBColor[
             0.34052296335874593`, 0.4690749660172503, 0.9429294418511679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 391}], {
             RGBColor[
             0.4242791032166461, 0.5413734394625537, 0.9484041876749043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 407}], {
             RGBColor[
             0.3262865305599572, 0.4541115725037497, 0.9421186980641918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 455}], {
             RGBColor[
             0.49424404189338955`, 0.5981741285649027, 0.9539120839375526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 498}], {
             RGBColor[
             0.5750148993041335, 0.6617219953363903, 0.9616555440114883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 28}], {
             RGBColor[
             0.38207742266917044`, 0.5028572911387341, 0.9458047612186589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 93}], {
             RGBColor[
             0.25547187449726694`, 0.38584751632197967`, 0.9378601173646254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 160}], {
             RGBColor[
             0.26388110219154026`, 0.3946861478044915, 0.9383390104414766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 167}], {
             RGBColor[
             0.2640882538669924, 0.39490387734956656`, 0.9383508074229403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 172}], {
             RGBColor[
             0.2559027333199868, 0.38630037626268543`, 0.9378846541371808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 201}], {
             RGBColor[
             0.27288253451918126`, 0.4041472239046152, 0.93885162869611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 218}], {
             RGBColor[
             0.2870949982165383, 0.4190854243727823, 0.9396610074782187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 235}], {
             RGBColor[
             0.2527156376053866, 0.3829505365931011, 0.9377031537511198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 274}], {
             RGBColor[
             0.2661988733080245, 0.397122272203093, 0.9384710040777253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 300}], {
             RGBColor[
             0.26008832470075693`, 0.39069969818569605`, 0.938123017374288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 305}], {
             RGBColor[
             0.2994340109078254, 0.43188728681651606`, 0.9403698188221772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 310}], {
             RGBColor[
             0.46656300779364224`, 0.5714089084514553, 0.952481474208732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 406}], {
             RGBColor[
             0.35240776193494094`, 0.47777048741806016`, 0.9437452593947762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 432}], {
             RGBColor[
             0.2897732046951418, 0.4219003891898929, 0.9398135273751238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 460}], {
             RGBColor[
             0.2944934860338214, 0.4268617041599678, 0.940082340414331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 493}], {
             RGBColor[
             0.274609024515375, 0.4059618743564031, 0.9389499497472802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 26}], {
             RGBColor[
             0.1940564817835153, 0.32129604461902417`, 0.9343626016055087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 59}], {
             RGBColor[
             0.2331068284328231, 0.3623404348824274, 0.936586461077376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 67}], {
             RGBColor[
             0.1920452315036252, 0.3191820930542266, 0.9342480638774471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 124}], {
             RGBColor[
             0.1942932572468809, 0.3215449106434528, 0.9343760856178694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 188}], {
             RGBColor[
             0.21359720872912316`, 0.3418345875925049, 0.9354754170971461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 200}], {
             RGBColor[
             0.23309658772441674`, 0.3623296712485939, 0.936585877884182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 228}], {
             RGBColor[
             0.2307172081494932, 0.3598287924539709, 0.9364503757373667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 298}], {
             RGBColor[
             0.2394531191654226, 0.3690107888204622, 0.9369478729461016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 318}], {
             RGBColor[
             0.20059929205314941`, 0.3281729530505406, 0.9347352049711439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 335}], {
             RGBColor[
             0.20679640724799403`, 0.3346865140401196, 0.9350881215136799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 459}], {
             RGBColor[
             0.1988488542772136, 0.32633313196386693`, 0.934635520129345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 468}], {
             RGBColor[
             0.21235962003857659`, 0.3405338034110854, 0.9354049382520679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 25}], {
             RGBColor[
             0.26532620998703904`, 0.39620504772268694`, 0.9384213071925849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 46}], {
             RGBColor[
             0.22273395828831882`, 0.35143789068260056`, 0.9359957414679326]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 150}], {
             RGBColor[
             0.22855902835216374`, 0.35756040865047517`, 0.9363274705906497]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 220}], {
             RGBColor[
             0.2293954500117661, 0.35843954084691343`, 0.9363751035667891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 325}], {
             RGBColor[
             0.23769654620583044`, 0.3671645192667726, 0.9368478387146697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 388}], {
             RGBColor[
             0.2852227543233797, 0.4152738080593815, 0.9396218953833091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 392}], {
             RGBColor[
             0.2393040747004234, 0.36885413363778313`, 0.9369393850843115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 413}], {
             RGBColor[
             0.23603377197510877`, 0.36541683812430875`, 0.9367531461820842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 473}], {
             RGBColor[
             0.25267572333140287`, 0.38290858416043305`, 0.9377008806922643]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 474}], {
             RGBColor[
             0.2356355428107931, 0.36499827402342566`, 0.9367304676203037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 490}], {
             RGBColor[
             0.22886274008807128`, 0.3578796289413503, 0.9363447665247084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 55}], {
             RGBColor[
             0.4367980074447999, 0.5486800919411015, 0.9499852964304927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 59}], {
             RGBColor[
             0.2814993677631707, 0.4132040619828309, 0.9393423446018928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 77}], {
             RGBColor[
             0.3172353767281449, 0.44838670426532234`, 0.9414645338601655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[
             0.30420754500978997`, 0.43707179605062296`, 0.94063554170235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 91}], {
             RGBColor[
             0.3801635060105999, 0.5027016523216035, 0.9455268210185781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 188}], {
             RGBColor[
             0.26198974805947073`, 0.39269821469290833`, 0.9382313006216629]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 200}], {
             RGBColor[
             0.28148912705476437`, 0.4131932983489973, 0.9393417614086988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 228}], {
             RGBColor[
             0.2791097474798408, 0.4106924195543743, 0.9392062592618835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 256}], {
             RGBColor[
             0.3057801725853121, 0.43846478219210167`, 0.9407346183816234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 287}], {
             RGBColor[
             0.30207832712053356`, 0.43483385304880307`, 0.9405142858934524]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 298}], {
             RGBColor[
             0.2878456584957702, 0.4198744159208656, 0.9397037564706185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 335}], {
             RGBColor[
             0.2551889465783416, 0.385550141140523, 0.9378440050381969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 336}], {
             RGBColor[
             0.4626767064166898, 0.5696895855885848, 0.9520225624103578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 354}], {
             RGBColor[
             0.30529527480886387`, 0.43804478810981307`, 0.9407037211240865]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 409}], {
             RGBColor[
             0.27661821411791565`, 0.40807366001865175`, 0.9390643701228152]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 24}], {
             RGBColor[
             0.18354454614871424`, 0.31024733377163405`, 0.9337639624221219]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 52}], {
             RGBColor[
             0.18089659272171946`, 0.3074641668299184, 0.9336131653917505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 170}], {
             RGBColor[
             0.18476666722380106`, 0.3115318605085019, 0.9338335604093819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 214}], {
             RGBColor[
             0.1846717285967103, 0.31143207399197287`, 0.9338281537950183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 268}], {
             RGBColor[
             0.1840499075552901, 0.3107785006517091, 0.9337927420066112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 466}], {
             RGBColor[
             0.188342270881701, 0.3152900466593206, 0.9340371857480678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 491}], {
             RGBColor[
             0.1817125626643469, 0.3083218029751023, 0.9336596336728639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 39}], {
             RGBColor[
             0.3397705873831411, 0.4630597387061178, 0.9430778872171774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 51}], {
             RGBColor[
             0.7136013437576199, 0.7704045833430664, 0.8366928314862011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 62}], {
             RGBColor[
             0.34157168432943963`, 0.4649528057928196, 0.943180457023785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 96}], {
             RGBColor[
             0.4513622669101063, 0.5648950617926353, 0.9501123446420765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 110}], {
             RGBColor[
             0.42451306437954106`, 0.5421136125437187, 0.9482705749734688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 136}], {
             RGBColor[
             0.48008619598652036`, 0.5882144414151268, 0.9523735975581908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 157}], {
             RGBColor[
             0.36552292420320903`, 0.49012707749646917`, 0.944544444701912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 240}], {
             RGBColor[
             0.7133780917330446, 0.7699270698367418, 0.8123932263629633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 360}], {
             RGBColor[
             0.5140568870299039, 0.6157933787663372, 0.9550478947958676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 52}], {
             RGBColor[
             0.18264284256949226`, 0.3092995861385628, 0.9337126117372361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 64}], {
             RGBColor[
             0.18504835804129488`, 0.3118279354179173, 0.933849602284714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.18699882666459755`, 0.3138780016078617, 0.9339606785873513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 115}], {
             RGBColor[
             0.18813870785962614`, 0.3150760890164789, 0.9340255931351051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 170}], {
             RGBColor[
             0.18651291707157386`, 0.3133672798171463, 0.9339330067548675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 223}], {
             RGBColor[
             0.19673773915135, 0.32411421611415436`, 0.934515295246042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 268}], {
             RGBColor[
             0.18579615740306293`, 0.3126139199603535, 0.9338921883520968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 491}], {
             RGBColor[
             0.1834588125121197, 0.3101572222837467, 0.9337590800183494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 164}], {
             RGBColor[
             0.3024600979339018, 0.4345620939070181, 0.9405606698993174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.2760199528625702, 0.4074448495073293, 0.9390303000293716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 220}], {
             RGBColor[
             0.25296409856661417`, 0.38321168481668605`, 0.9377173032352967]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 316}], {
             RGBColor[
             0.36380395841468005`, 0.4876950626233916, 0.9444694464449066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 325}], {
             RGBColor[
             0.26126519476067855`, 0.3919366632365452, 0.9381900383831774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 392}], {
             RGBColor[
             0.26287272325527145`, 0.39362627760755575`, 0.9382815847528192]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 413}], {
             RGBColor[
             0.25960242052995686`, 0.39018898209408137`, 0.9380953458505918]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 474}], {
             RGBColor[
             0.2592041913656412, 0.3897704179931982, 0.9380726672888113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 490}], {
             RGBColor[
             0.25243138864291936`, 0.38265177291112284`, 0.937686966193216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 67}], {
             RGBColor[
             0.1828839766938226, 0.30955303339202045`, 0.9337263439688908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 124}], {
             RGBColor[
             0.18513200243707828`, 0.31191585098124663`, 0.9338543657093131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 318}], {
             RGBColor[
             0.1914380372433468, 0.3185438933883344, 0.9342134850625876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 335}], {
             RGBColor[
             0.1976351524381914, 0.3250574543779134, 0.9345664016051236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 459}], {
             RGBColor[
             0.18968759946741098`, 0.31670407230166076`, 0.9341138002207887]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 29}], {
             RGBColor[
             0.18482045324878804`, 0.31158839303099417`, 0.9338366234439357]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 65}], {
             RGBColor[
             0.1841954077512366, 0.31093143058289413`, 0.9338010280275222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 86}], {
             RGBColor[
             0.18526169591288671`, 0.3120521670473626, 0.9338617515608961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 177}], {
             RGBColor[
             0.18479696914654997`, 0.31156370975056386`, 0.9338352860590549]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[
             0.1856592913664621, 0.31247006507807806`, 0.9338843940337875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 290}], {
             RGBColor[
             0.18336907213961767`, 0.31006289946237875`, 0.9337539694368944]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 297}], {
             RGBColor[
             0.19023703211735066`, 0.31728156085278936`, 0.93414508959739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 350}], {
             RGBColor[
             0.18336792975933797`, 0.3100616987482737, 0.9337539043800275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 412}], {
             RGBColor[
             0.18773360296108882`, 0.31465029808298206`, 0.9340025230104325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 484}], {
             RGBColor[
             0.1850117059565009, 0.3117894117529224, 0.933847515002707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 490}], {
             RGBColor[
             0.20058973370860944`, 0.328162906624395, 0.9347346606375627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 125}], {
             RGBColor[
             0.6268956164581168, 0.7059040511517584, 0.965190775014533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 149}], {
             RGBColor[
             0.5184855433089055, 0.6199689474225398, 0.9552362277258538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 201}], {
             RGBColor[
             0.3666465873540202, 0.4866385048510442, 0.9449259979753362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 218}], {
             RGBColor[
             0.38085905105137724`, 0.5015767053192113, 0.9457353767574448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 282}], {
             RGBColor[
             0.586277448481364, 0.6741728296188088, 0.961142335628971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 305}], {
             RGBColor[
             0.3931980637426643, 0.5143785677629451, 0.9464441881014032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 310}], {
             RGBColor[
             0.5603270606284811, 0.6539001893978842, 0.958555843487958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 406}], {
             RGBColor[
             0.44617181476977985`, 0.5602617683644892, 0.9498196286740023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 408}], {
             RGBColor[
             0.7065627960875993, 0.7690478747515729, 0.9714624707191005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 419}], {
             RGBColor[
             0.5625638978028586, 0.6556476235991, 0.9587787905130681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 432}], {
             RGBColor[
             0.38353725752998075`, 0.5043916701363219, 0.9458878966543498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 493}], {
             RGBColor[
             0.36837307735021396`, 0.48845315530283206`, 0.9450243190265064]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 46}], {
             RGBColor[
             0.19406985648437775`, 0.32131010227763557`, 0.9343633632749366]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 65}], {
             RGBColor[
             0.1838043123267574, 0.3105203644948844, 0.9337787557216719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 86}], {
             RGBColor[
             0.18487060048840748`, 0.3116411009593528, 0.9338394792550458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 177}], {
             RGBColor[
             0.18440587372207073`, 0.31115264366255413`, 0.9338130137532046]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 194}], {
             RGBColor[
             0.18526819594198288`, 0.31205899899006834`, 0.9338621217279373]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 254}], {
             RGBColor[
             0.18842942576301586`, 0.31538165196552115`, 0.9340421490896246]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 290}], {
             RGBColor[
             0.18297797671513846`, 0.309651833374369, 0.9337316971310441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 297}], {
             RGBColor[
             0.18984593669287142`, 0.3168704947647796, 0.9341228172915397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 350}], {
             RGBColor[
             0.18297683433485876`, 0.309650632660264, 0.9337316320741772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 377}], {
             RGBColor[
             0.18261049498864607`, 0.3092655867801383, 0.9337107695903608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 412}], {
             RGBColor[
             0.18734250753660958`, 0.3142392319949723, 0.9339802507045822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 426}], {
             RGBColor[
             0.18589315152803693`, 0.3127158669354839, 0.933897712024024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 476}], {
             RGBColor[
             0.18392969470854525`, 0.3106521493278456, 0.933785896062828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 31}], {
             RGBColor[
             0.185457486240386, 0.3122579550953881, 0.9338729015304014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 133}], {
             RGBColor[
             0.18845727560531045`, 0.31541092391555475`, 0.934043735096943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 191}], {
             RGBColor[
             0.18476529609045284`, 0.31153041936041803`, 0.9338334823253662]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 311}], {
             RGBColor[
             0.18445928711484194`, 0.31120878452496137`, 0.9338160555669048]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 366}], {
             RGBColor[
             0.1807454038963133, 0.3073052577884914, 0.9336045554118075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 405}], {
             RGBColor[
             0.1802965998650839, 0.3068335362958501, 0.9335789966861752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 423}], {
             RGBColor[
             0.17906694420854233`, 0.3055410902361533, 0.9335089696156476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 429}], {
             RGBColor[
             0.18544154731921458`, 0.312241202278651, 0.9338719938324201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 465}], {
             RGBColor[
             0.17899164586466354`, 0.3054619469025459, 0.9335046814863577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 469}], {
             RGBColor[
             0.18014325773351766`, 0.30667236399312137`, 0.9335702640786318]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 488}], {
             RGBColor[
             0.18073134444068237`, 0.30729048040920226`, 0.9336037547466085]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 133}], {
             RGBColor[
             0.1949807850604232, 0.3222675459672669, 0.9344152393097445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 191}], {
             RGBColor[
             0.1912888055455656, 0.31838704141213026`, 0.9342049865381675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 226}], {
             RGBColor[
             0.1894803426038117, 0.3164862321971737, 0.9341019972490159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 237}], {
             RGBColor[
             0.21243558089193113`, 0.3406136430841573, 0.9354092641102925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 311}], {
             RGBColor[
             0.1909827965699547, 0.3180654065766735, 0.9341875597797062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 366}], {
             RGBColor[
             0.18726891335142604`, 0.3141618798402035, 0.9339760596246088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 405}], {
             RGBColor[
             0.18682010932019663`, 0.3136901583475623, 0.9339505008989764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 429}], {
             RGBColor[
             0.19196505677432735`, 0.31909782433036316`, 0.9342434980452214]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 472}], {
             RGBColor[
             0.1875584213311225, 0.31446617108273056`, 0.9339925466757639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 488}], {
             RGBColor[
             0.1872548538957951, 0.31414710246091443`, 0.9339752589594097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 66}], {
             RGBColor[
             0.20877736241614875`, 0.33676862352166215`, 0.9352009339799459]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 84}], {
             RGBColor[
             0.2475939365043437, 0.3775673040012994, 0.9374114804502933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 89}], {
             RGBColor[
             0.26467695340514513`, 0.3954361451619938, 0.9383874999131978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 176}], {
             RGBColor[
             0.26830294791528575`, 0.39857679935889445`, 0.938618545077043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 179}], {
             RGBColor[
             0.20989223640499494`, 0.3379404267710331, 0.9352644244043025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 245}], {
             RGBColor[
             0.23179881460343715`, 0.36096562941487603`, 0.9365119716248255]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 255}], {
             RGBColor[
             0.20842141467182945`, 0.3363944998739921, 0.9351806632824844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 260}], {
             RGBColor[
             0.21471160984099968`, 0.34300589381819857`, 0.9355388805918587]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 299}], {
             RGBColor[
             0.22987290893586354`, 0.3589413804487841, 0.9364022941461793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 312}], {
             RGBColor[
             0.20732064752653726`, 0.335237523811622, 0.935117976221999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 328}], {
             RGBColor[
             0.23132945208889125`, 0.36047229965278604`, 0.9364852421239818]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 334}], {
             RGBColor[
             0.2032637935146371, 0.3309735130257143, 0.934886944387599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 407}], {
             RGBColor[
             0.24840100008144717`, 0.3784155789916214, 0.9374574415270658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 448}], {
             RGBColor[
             0.26012823284654724`, 0.3907416441772443, 0.938125290084152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 475}], {
             RGBColor[
             0.27810050553156784`, 0.4070629513265539, 0.9392428367847124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 478}], {
             RGBColor[
             0.23449306505329615`, 0.3637974574630227, 0.9366654052021586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 482}], {
             RGBColor[
             0.27602220405873207`, 0.40526283104925287`, 0.9391104092526332]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 76}], {
             RGBColor[
             0.3333497551271607, 0.45830089859572654`, 0.9426393717347399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 111}], {
             RGBColor[
             0.3114314409456971, 0.4393163564982453, 0.9412427561367012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 160}], {
             RGBColor[
             0.24786010554572385`, 0.3778470645398819, 0.937426638383438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 175}], {
             RGBColor[
             0.326974395016177, 0.4527788821025087, 0.9422331394259775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 182}], {
             RGBColor[
             0.300634259036329, 0.42996438021049266`, 0.9405547692530093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 237}], {
             RGBColor[
             0.24458077131553108`, 0.3744002763421501, 0.9372398851503687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 241}], {
             RGBColor[
             0.2359506605232252, 0.3653294827188087, 0.9367484131078517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 274}], {
             RGBColor[
             0.25017787666220814`, 0.38028318893848334`, 0.9375586320196867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 351}], {
             RGBColor[
             0.24823088148452888`, 0.3782367735601183, 0.937447753524639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 371}], {
             RGBColor[
             0.2551767869971113, 0.385537360649688, 0.9378433125680343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 432}], {
             RGBColor[
             0.27375220804932543`, 0.40506130592528333`, 0.9389011553170851]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 460}], {
             RGBColor[
             0.27847248938800495`, 0.41002262089535824`, 0.9391699683562924]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 463}], {
             RGBColor[
             0.4057152506945697, 0.5182150283519088, 0.9480144771137997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 44}], {
             RGBColor[
             0.24396970740458573`, 0.37375800942805687`, 0.9372050859646285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 62}], {
             RGBColor[
             0.23006104796724536`, 0.35913912649947, 0.9364130083856896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 190}], {
             RGBColor[
             0.2127364473424475, 0.3409298727996848, 0.9354263980095573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 291}], {
             RGBColor[
             0.19600418397695138`, 0.323343203115777, 0.9344735203640577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 356}], {
             RGBColor[
             0.22712257342383618`, 0.3560506034443001, 0.9362456666075261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 394}], {
             RGBColor[
             0.19619166312976455`, 0.3235402555922485, 0.9344841970244598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 467}], {
             RGBColor[
             0.20003782336254744`, 0.32758281385754684`, 0.9347032301598326]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.18328807136271902`, 0.3099777625101124, 0.9337493565624799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 123}], {
             RGBColor[
             0.18674780810963457`, 0.3136141651911, 0.933946383451995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 193}], {
             RGBColor[
             0.1842865051954063, 0.311027179772628, 0.9338062158922009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 347}], {
             RGBColor[
             0.19536292222488982`, 0.32266919635601693`, 0.9344370014559396]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 410}], {
             RGBColor[
             0.18494866329979062`, 0.31172314992358463`, 0.9338439248166706]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 422}], {
             RGBColor[
             0.19709463641182273`, 0.32448933776350447`, 0.9345356200170438]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 428}], {
             RGBColor[
             0.18771159390474457`, 0.31462716516930944`, 0.9340012696272331]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 437}], {
             RGBColor[
             0.18478436843582058`, 0.31155046560465605`, 0.9338345684672199]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 75}], {
             RGBColor[
             0.929724921483118, 0.7365825483050892, 0.4781251750142107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 76}], {
             RGBColor[
             0.7022798190159381, 0.7608775969992009, 0.8471463932234504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 104}], {
             RGBColor[
             0.9591316136436914, 0.8643779170894872, 0.5023662490620132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 112}], {
             RGBColor[
             0.993786491132969, 0.9916985686506579, 0.7526374521795876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 266}], {
             RGBColor[
             0.9938574384892986, 0.9902625241719002, 0.644943793687154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 359}], {
             RGBColor[
             0.9518288028476951, 0.9612683407754878, 0.8690761481825573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 379}], {
             RGBColor[
             0.9107780137599082, 0.6018218600251894, 0.4604073756146171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 408}], {
             RGBColor[
             0.9657078104957213, 0.9722942089440085, 0.8689827508705463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 440}], {
             RGBColor[
             0.9428820049759663, 0.7963257915311912, 0.48910376799027133`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 463}], {
             RGBColor[
             0.7746453145833472, 0.820791726755383, 0.8525214986025103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 49}], {
             RGBColor[
             0.9278898442559633, 0.7275054583426774, 0.39329233295696453`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 53}], {
             RGBColor[
             0.8472647112443593, 0.3588769520067575, 0.19268158199931773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 97}], {
             RGBColor[
             0.9251557778239836, 0.7191603787632175, 0.30804891163954246`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 100}], {
             RGBColor[
             0.9275408237580072, 0.7267589387889348, 0.3553036056592853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 203}], {
             RGBColor[
             0.8534629031399862, 0.4065189709815528, 0.1986169775584265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 207}], {
             RGBColor[
             0.8684208855066446, 0.4954117968161807, 0.21191950037856397`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 257}], {
             RGBColor[
             0.9124536887252621, 0.6763132496408797, 0.2587036940792628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 264}], {
             RGBColor[
             0.8636993298194549, 0.4739723151879993, 0.20797971857725228`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 281}], {
             RGBColor[
             0.8401393429256434, 0.30410824875280007`, 0.18585832125036283`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 317}], {
             RGBColor[
             0.839586880193451, 0.2998617781024568, 0.18532928231409804`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 322}], {
             RGBColor[
             0.8413185031158885, 0.3131717906863145, 0.18698748638021256`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 324}], {
             RGBColor[
             0.9007937640631225, 0.7100849667901136, 0.5966707240103046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 343}], {
             RGBColor[
             0.8540426861772787, 0.4109754374687308, 0.1991721784497092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 374}], {
             RGBColor[
             0.8546495293295531, 0.4156398998574755, 0.19975329213765833`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 397}], {
             RGBColor[
             0.8419322626018511, 0.3178894150465442, 0.18757522315711248`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 445}], {
             RGBColor[
             0.9124867892485535, 0.6764249054783144, 0.25883228336174086`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 77}], {
             RGBColor[
             0.4266438929830485, 0.5421807004439456, 0.9488977622771873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 79}], {
             RGBColor[
             0.7025334025034438, 0.7661868171424233, 0.9721373827063131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 87}], {
             RGBColor[
             0.4136160612646935, 0.5308657922292461, 0.9480687701193717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 127}], {
             RGBColor[
             0.6754853554676021, 0.7446194386357212, 0.969557515833958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 184}], {
             RGBColor[
             0.5298276783437619, 0.6291770036011967, 0.9561291221434074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 221}], {
             RGBColor[
             0.7405475305032172, 0.7523239641423858, 0.6316046509416242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 253}], {
             RGBColor[
             0.4481561698945121, 0.5608135534661793, 0.9502685055394262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 287}], {
             RGBColor[
             0.4114868433754372, 0.5286278492274263, 0.9479475143104742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 301}], {
             RGBColor[
             0.5876340036038425, 0.6758909546392042, 0.9608274105699129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 316}], {
             RGBColor[
             0.4787664530256467, 0.5873266421968035, 0.9522189657129314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 336}], {
             RGBColor[
             0.5720852226715933, 0.663483581767208, 0.9594557908273795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 354}], {
             RGBColor[
             0.4147037910637674, 0.5318387842884362, 0.9481369495411083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 388}], {
             RGBColor[
             0.42375389748919434`, 0.5396775316025662, 0.9487136143198416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 436}], {
             RGBColor[
             0.4371703671484145, 0.5512982032900106, 0.9495684999028087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 473}], {
             RGBColor[
             0.39120686649721753`, 0.5073123077036177, 0.9467925996287968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 62}], {
             RGBColor[
             0.2493920758689453, 0.37945726248211625`, 0.9375138818269986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 96}], {
             RGBColor[
             0.359182658449612, 0.4793995184819319, 0.94444576944529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 108}], {
             RGBColor[
             0.22860230621824829`, 0.3576058964317052, 0.9363299352010993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 113}], {
             RGBColor[
             0.2221538791632596, 0.3508281907430225, 0.9359627068199107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 157}], {
             RGBColor[
             0.2733433157427147, 0.4046315341857658, 0.9388778695051255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 190}], {
             RGBColor[
             0.23206747524414745`, 0.361248008782331, 0.9365272714508661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 378}], {
             RGBColor[
             0.22727756338581306`, 0.356213507721269, 0.9362544930565735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 161}], {
             RGBColor[
             0.19942966903054987`, 0.32694360509540565`, 0.9346685966703091]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 183}], {
             RGBColor[
             0.19098677743240255`, 0.31806959071550744`, 0.9341877864839334]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 202}], {
             RGBColor[
             0.18588447811869105`, 0.31270675063233544`, 0.933897218086193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 206}], {
             RGBColor[
             0.18271148860033518`, 0.3093717374693884, 0.9337165210271399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 243}], {
             RGBColor[
             0.19079403389915217`, 0.3178670050414155, 0.9341768100248533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 273}], {
             RGBColor[
             0.18608375256856824`, 0.31291620071388626`, 0.9339085664713134]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 283}], {
             RGBColor[
             0.18366308451827268`, 0.3103719251138067, 0.9337707130069065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 285}], {
             RGBColor[
             0.19969824891224597`, 0.32722589958001636`, 0.9346838918972433]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 396}], {
             RGBColor[
             0.19122359622902446`, 0.31831850228593606`, 0.934201272964059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 421}], {
             RGBColor[
             0.18467273781712776`, 0.31143313474661993`, 0.933828211268628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 430}], {
             RGBColor[
             0.1932824749084014, 0.32048251431840913`, 0.9343185230590114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 477}], {
             RGBColor[
             0.19140125749096676`, 0.31850523553661203`, 0.9342113905101004]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 44}], {
             RGBColor[
             0.27104906144274005`, 0.40222012745236824`, 0.938747215116787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 56}], {
             RGBColor[
             0.33496751620801646`, 0.46033233124806494`, 0.9427193789900982]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.26751337219857585`, 0.3985038938811058, 0.9385458628449154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 132}], {
             RGBColor[
             0.2677010857798615, 0.3987011927567655, 0.9385565528556723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.2413646105317827, 0.37101988744205927`, 0.9370567295516178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 356}], {
             RGBColor[
             0.25420192746199044`, 0.3845127214686115, 0.9377877957596846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 365}], {
             RGBColor[
             0.23506566561189032`, 0.36439929695507756`, 0.9366980139568839]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 457}], {
             RGBColor[
             0.36616941470913866`, 0.48692522378917524`, 0.9448270715857057]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 485}], {
             RGBColor[
             0.2592162515913262, 0.38978309405505573`, 0.9380733541008225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 494}], {
             RGBColor[
             0.3091950820990577, 0.43800954418308746`, 0.9410771822783439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 108}], {
             RGBColor[
             0.2050818952093152, 0.3328844531811263, 0.9349904825894705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 113}], {
             RGBColor[
             0.1986334681543265, 0.3261067474924436, 0.9346232542082819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 119}], {
             RGBColor[
             0.1924345707120309, 0.31959131324779266`, 0.9342702361693901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 315}], {
             RGBColor[
             0.19198004367677265`, 0.3191135765150577, 0.9342443515271446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 364}], {
             RGBColor[
             0.2024710281446618, 0.33014026635764265`, 0.9348417975725702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 378}], {
             RGBColor[
             0.20375715237687997`, 0.3314920644706901, 0.9349150404449447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 380}], {
             RGBColor[
             0.19400957405079025`, 0.3212467416178081, 0.9343599302795238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 381}], {
             RGBColor[
             0.19442462278648562`, 0.3216829841546337, 0.9343835666910121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 416}], {
             RGBColor[
             0.20488956233917005`, 0.3326822991399955, 0.9349795295170467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 452}], {
             RGBColor[
             0.21367924169687297`, 0.3419208094428005, 0.9354800887533026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 468}], {
             RGBColor[
             0.21102583019430793`, 0.33913190571759855`, 0.9353289808936021]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 487}], {
             RGBColor[
             0.19664512493327133`, 0.3240168726988731, 0.934510021003333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[
             0.24535980769453214`, 0.3752190929702395, 0.9372842501196719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 137}], {
             RGBColor[
             0.220012218727478, 0.34857716983590165`, 0.9358407424263956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 148}], {
             RGBColor[
             0.2515020287225457, 0.38167495670998786`, 0.9376340405206155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 156}], {
             RGBColor[
             0.21388174499134507`, 0.34213365324474115`, 0.935491621016346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 227}], {
             RGBColor[
             0.21076377490674741`, 0.3388564689951076, 0.9353140572326515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 229}], {
             RGBColor[
             0.231604699752685, 0.3607616023991431, 0.9365009170712423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 250}], {
             RGBColor[
             0.22400512105631526`, 0.3527739633481394, 0.9360681323070532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 263}], {
             RGBColor[
             0.2263534256582619, 0.35524218037589655`, 0.9362018647801287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 267}], {
             RGBColor[
             0.22881279968486046`, 0.35782713841117125`, 0.9363419224926257]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 393}], {
             RGBColor[
             0.2248422553763207, 0.3536538445958466, 0.9361158058681482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 485}], {
             RGBColor[
             0.24185676211585877`, 0.3715371699611359, 0.9370847568562579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 56}], {
             RGBColor[
             0.342928946455201, 0.46870029922168843`, 0.9431727706647948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 62}], {
             RGBColor[
             0.2651018322525842, 0.3959692124974049, 0.9384085292125448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 92}], {
             RGBColor[
             0.2754748024457604, 0.40687186185472934`, 0.938999254519612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 110}], {
             RGBColor[
             0.34804321230268565`, 0.4731300192483041, 0.9434986471622288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 132}], {
             RGBColor[
             0.27566251602704606`, 0.4070691607303891, 0.9390099445303688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 157}], {
             RGBColor[
             0.2890530721263536, 0.4211434842010545, 0.9397725168906719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 356}], {
             RGBColor[
             0.262163357709175, 0.39288068944223503`, 0.9382411874343812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 360}], {
             RGBColor[
             0.4375870349530485, 0.5468097854709225, 0.9502759669846275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 365}], {
             RGBColor[
             0.24302709585907487`, 0.37276726492870105`, 0.9371514056315804]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 457}], {
             RGBColor[
             0.3741308449563232, 0.49529319176279873`, 0.9452804632604023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 494}], {
             RGBColor[
             0.31715651234624226`, 0.44637751215671095`, 0.9415305739530406]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 118}], {
             RGBColor[
             0.1966941864369604, 0.3240684394499293, 0.9345128149833881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 152}], {
             RGBColor[
             0.1927063751242849, 0.3198769969184667, 0.9342857150285693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 185}], {
             RGBColor[
             0.2063591315326575, 0.33422690953841927`, 0.935063219308583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 187}], {
             RGBColor[
             0.21121178851668337`, 0.3393273597048538, 0.9353395709449606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 195}], {
             RGBColor[
             0.19463609510811763`, 0.32190525497278855`, 0.9343956097268837]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 216}], {
             RGBColor[
             0.20054621348510776`, 0.32811716411015324`, 0.9347321822252167]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 217}], {
             RGBColor[
             0.19120987418842403`, 0.31830407955123735`, 0.9342004915141469]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 224}], {
             RGBColor[
             0.20355580866569664`, 0.3312804394643078, 0.9349035742184542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 292}], {
             RGBColor[
             0.193148625604734, 0.3203418302137187, 0.93431090053918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 328}], {
             RGBColor[
             0.22208190708084125`, 0.3507525435211073, 0.9359586081162901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 398}], {
             RGBColor[
             0.20371823459922628`, 0.33145115941884645`, 0.934912824135081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 399}], {
             RGBColor[
             0.20452814783915604`, 0.33230242958547795`, 0.9349589474959358]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 464}], {
             RGBColor[
             0.2018156680778671, 0.3294514413752133, 0.9348044757862846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 481}], {
             RGBColor[
             0.20322304481879772`, 0.33093068356277056`, 0.9348846238096533]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 496}], {
             RGBColor[
             0.19349628938952101`, 0.32070724689468694`, 0.9343306994774011]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 86}], {
             RGBColor[
             0.19451109914847642`, 0.321773876294004, 0.9343884913918972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 142}], {
             RGBColor[
             0.2097115161750654, 0.33775047835105276`, 0.9352541326545596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 150}], {
             RGBColor[
             0.2095354252082916, 0.3375653955801614, 0.935244104534505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 194}], {
             RGBColor[
             0.19490869460205182`, 0.32219177432471957`, 0.9344111338647885]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 220}], {
             RGBColor[
             0.21037184686789395`, 0.33844452777659967`, 0.9352917375106444]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 254}], {
             RGBColor[
             0.1980699244230848, 0.3255144273001723, 0.9345911612264759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 297}], {
             RGBColor[
             0.19948643535294036`, 0.32700327009943075`, 0.934671829428391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 325}], {
             RGBColor[
             0.2186729430619583, 0.3471695061964588, 0.935764472658525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 350}], {
             RGBColor[
             0.1926173329949277, 0.3197834079949152, 0.9342806442110285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 377}], {
             RGBColor[
             0.192250993648715, 0.31939836211478956`, 0.9342597817272121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 392}], {
             RGBColor[
             0.22028047155655125`, 0.34885912056746937`, 0.9358560190281668]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 412}], {
             RGBColor[
             0.19698300619667852`, 0.32437200732962346`, 0.9345292628414335]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 426}], {
             RGBColor[
             0.19553365018810587`, 0.3228486422701351, 0.9344467241608754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 476}], {
             RGBColor[
             0.1935701933686142, 0.32078492466249675`, 0.9343349081996792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 55}], {
             RGBColor[
             0.42760134170853215`, 0.539013813149998, 0.94946155992206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 59}], {
             RGBColor[
             0.272302702026903, 0.4035377831917274, 0.9388186080934602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 73}], {
             RGBColor[
             0.42925393472115597`, 0.5403554626061129, 0.9495916580976614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 91}], {
             RGBColor[
             0.37096684027433213`, 0.4930353735304999, 0.9450030845101454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 136}], {
             RGBColor[
             0.40491583995544145`, 0.5205967008566313, 0.9476756741243257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 200}], {
             RGBColor[
             0.2722924613184966, 0.40352701955789383`, 0.9388180249002662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 228}], {
             RGBColor[
             0.2699130817435731, 0.4010261407632708, 0.9386825227534509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 256}], {
             RGBColor[
             0.2965835068490444, 0.4287985034009982, 0.9402108818731908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 298}], {
             RGBColor[
             0.2786489927595025, 0.4102081371297621, 0.9391800199621858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 416}], {
             RGBColor[
             0.24541922577751857`, 0.3752815451427822, 0.9372876338915967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 452}], {
             RGBColor[
             0.2542089051352215, 0.3845200554455873, 0.9377881931278527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 468}], {
             RGBColor[
             0.25155549363265645`, 0.38173115172038535`, 0.9376370852681521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 117}], {
             RGBColor[
             0.18672352451245816`, 0.31358864159079863`, 0.9339450005370601]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 140}], {
             RGBColor[
             0.1844487281323768, 0.3111976863649123, 0.9338154542484741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 155}], {
             RGBColor[
             0.1919029748142661, 0.3190325722541152, 0.934239962569438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 156}], {
             RGBColor[
             0.19463895940372045`, 0.3219082655290739, 0.9343957728442809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 198}], {
             RGBColor[
             0.18614733394130184`, 0.3129830287679211, 0.9339121873364302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 250}], {
             RGBColor[
             0.20476233546869063`, 0.33254857563247214`, 0.9349722841349881]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 365}], {
             RGBColor[
             0.19846339054879825`, 0.32592798514549043`, 0.9346135685402542]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 479}], {
             RGBColor[
             0.18610061058204452`, 0.31293391955490957`, 0.9339095265102416]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 51}], {
             RGBColor[
             0.9945887098983145, 0.9908341225748765, 0.6523926509220856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 100}], {
             RGBColor[
             0.9935759076270685, 0.9886678409266986, 0.5421553739880537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 203}], {
             RGBColor[
             0.9194979870090474, 0.6684278731193166, 0.38546874588719493`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 264}], {
             RGBColor[
             0.9297344136885161, 0.7358812173257631, 0.3948314869060207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 324}], {
             RGBColor[
             0.9668288479321837, 0.9719938689278773, 0.783522492339073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 360}], {
             RGBColor[
             0.7950442531705986, 0.8362229179981473, 0.7707477142317521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 397}], {
             RGBColor[
             0.9079673464709124, 0.579798317184308, 0.3744269914858809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 457}], {
             RGBColor[
             0.7315880631738731, 0.7847063242900234, 0.765752210507527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 82}], {
             RGBColor[
             0.7002427375322327, 0.764369726655832, 0.9719080506652522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 126}], {
             RGBColor[
             0.6844097961772514, 0.7515158315979785, 0.9706616235238129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 131}], {
             RGBColor[
             0.8570462990670573, 0.5838526913273292, 0.5841917648474512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 173}], {
             RGBColor[
             0.800480264278042, 0.8445485570290475, 0.9806185434355512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 242}], {
             RGBColor[
             0.9267381119467066, 0.943455029677774, 0.9594240314227456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 323}], {
             RGBColor[
             0.9365367216162789, 0.9493476478675402, 0.8794633883159441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 340}], {
             RGBColor[
             0.6220781556562913, 0.698481383789535, 0.9664262896114366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 373}], {
             RGBColor[
             0.9356814566362912, 0.9489939738190079, 0.8936373423891573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 414}], {
             RGBColor[
             0.6515149605889788, 0.7239780646853934, 0.9683019767918029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 449}], {
             RGBColor[
             0.9319849870644814, 0.931902676711367, 0.6896331946772748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 499}], {
             RGBColor[
             0.7544680909250315, 0.8083923113644382, 0.9761768691183477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 60}], {
             RGBColor[
             0.9903726876472161, 0.9902614167392676, 0.8073625961746422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 96}], {
             RGBColor[
             0.7330134148240908, 0.7867443631188805, 0.8380607137143137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 100}], {
             RGBColor[
             0.9942396894003585, 0.9900876030211339, 0.6144039236244064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 110}], {
             RGBColor[
             0.7061642122935256, 0.763962913869964, 0.8362189440457062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 203}], {
             RGBColor[
             0.9201617687823374, 0.6698476352137519, 0.4577172955235477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 240}], {
             RGBColor[
             0.995029239647029, 0.991776371162987, 0.7003415954352006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 264}], {
             RGBColor[
             0.930398195461806, 0.7373009794201983, 0.46708003654237346`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 324}], {
             RGBColor[
             0.9674926297054737, 0.9734136310223126, 0.8557710419754258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 360}], {
             RGBColor[
             0.7957080349438885, 0.8376426800925825, 0.8429962638681049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 397}], {
             RGBColor[
             0.9086311282442023, 0.5812180792787432, 0.4466755411222336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 457}], {
             RGBColor[
             0.7322518449471631, 0.7861260863844587, 0.8380007601438797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 495}], {
             RGBColor[
             0.9406722816777016, 0.7839532053527796, 0.47565298592181493`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 170}], {
             RGBColor[
             0.1838649636445791, 0.31058411287543064`, 0.9337822097244962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 214}], {
             RGBColor[
             0.18377002501748835`, 0.3104843263589016, 0.9337768031101326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 268}], {
             RGBColor[
             0.18314820397606815`, 0.30983075301863783`, 0.9337413913217254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 466}], {
             RGBColor[
             0.18744056730247904`, 0.3143422990262493, 0.933985835063182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 491}], {
             RGBColor[
             0.18081085908512495`, 0.30737405534203105`, 0.9336082829879782]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 83}], {
             RGBColor[
             0.9139507635332944, 0.6222257740273145, 0.45384466479453006`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 97}], {
             RGBColor[
             0.910565728681441, 0.6124407745650613, 0.29428992901066414`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 112}], {
             RGBColor[
             0.9130580700237505, 0.6218566223199413, 0.468638906464419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 163}], {
             RGBColor[
             0.8659915986516313, 0.4439113739475036, 0.20830775588996076`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 207}], {
             RGBColor[
             0.8538308363641018, 0.3886921926180247, 0.19816051774968563`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 257}], {
             RGBColor[
             0.8978636395827194, 0.5695936454427237, 0.2449447114503845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 266}], {
             RGBColor[
             0.9131290173800801, 0.6204205778411838, 0.36094524797198546`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 281}], {
             RGBColor[
             0.8255492937831006, 0.19738864455464403`, 0.17209933862148452`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[
             0.8212117750972121, 0.5517293002984074, 0.5802972295340347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 317}], {
             RGBColor[
             0.8249968310509084, 0.19314217390430075`, 0.1715702996852197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 322}], {
             RGBColor[
             0.8267284539733458, 0.20645218648815844`, 0.17322850375133425`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 343}], {
             RGBColor[
             0.8394526370347362, 0.3042558332705747, 0.18541319582083088`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 374}], {
             RGBColor[
             0.8400594801870103, 0.30892029565931944`, 0.18599430950878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 440}], {
             RGBColor[
             0.8621535838667478, 0.42648384520047466`, 0.20510522227510283`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 445}], {
             RGBColor[
             0.897896740106011, 0.5697053012801583, 0.24507330073286251`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 471}], {
             RGBColor[
             0.8947556642863255, 0.6097433924263989, 0.5684355218108367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 61}], {
             RGBColor[
             0.9898922626687403, 0.9900882051035927, 0.8171748957720661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 99}], {
             RGBColor[
             0.9846117057177595, 0.9871579291878583, 0.8712517771624386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 154}], {
             RGBColor[
             0.9864962902894889, 0.9885634492757301, 0.8680616670608778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 186}], {
             RGBColor[
             0.9914243588005289, 0.9890319585828893, 0.6689529207083693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 203}], {
             RGBColor[
             0.9172982685013698, 0.6686889606982549, 0.5070233200844496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 244}], {
             RGBColor[
             0.7181235795673231, 0.775643062211419, 0.8864694686198505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 264}], {
             RGBColor[
             0.9275346951808384, 0.7361423049047013, 0.5163860611032753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 295}], {
             RGBColor[
             0.9871607004637972, 0.988958633933902, 0.862443950564356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 321}], {
             RGBColor[
             0.9874803221287802, 0.9890908057062746, 0.8571469924212342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 341}], {
             RGBColor[
             0.991911410491914, 0.9900737129022821, 0.7219654915810148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 374}], {
             RGBColor[
             0.9184848946909366, 0.6778098895741775, 0.5081596346636814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 391}], {
             RGBColor[
             0.731320111432247, 0.7865357071547434, 0.8874588604609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 397}], {
             RGBColor[
             0.9057676279632347, 0.5800594047632462, 0.4959815656831355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 455}], {
             RGBColor[
             0.8012850501089904, 0.8433363962570924, 0.8929667567235482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 57}], {
             RGBColor[
             0.7681170081630603, 0.818182994087395, 0.9538490180959958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 60}], {
             RGBColor[
             0.7795430416292072, 0.8264883871046946, 0.9248292480443663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 73}], {
             RGBColor[
             0.5752457926482104, 0.6660494748562806, 0.9597046024734881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 91}], {
             RGBColor[
             0.5169586982013866, 0.6187293857806677, 0.955116028885972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 136}], {
             RGBColor[
             0.5509076978824959, 0.6462907131067992, 0.9577886185001523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 200}], {
             RGBColor[
             0.4182843192455511, 0.5292210318080617, 0.9489309692760928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 256}], {
             RGBColor[
             0.4425753647760989, 0.554492515651166, 0.9503238262490175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 298}], {
             RGBColor[
             0.424640850686557, 0.5359021493799299, 0.9492929643380126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 434}], {
             RGBColor[
             0.7543365484938672, 0.7225141411414309, 0.6130982348590022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 92}], {
             RGBColor[
             0.33939325721103675`, 0.46498406565042605`, 0.9429714183929231]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 110}], {
             RGBColor[
             0.41196166706796206`, 0.5312422230440008, 0.9474708110355399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 132}], {
             RGBColor[
             0.3395809707923225, 0.46518136452608577`, 0.94298210840368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 324}], {
             RGBColor[
             0.6732900844799101, 0.7406929401963493, 0.9670229089652596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 342}], {
             RGBColor[
             0.4415801835206408, 0.5562719260910596, 0.9495305912404275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 360}], {
             RGBColor[
             0.501505489718325, 0.6049219892666192, 0.9542481308579387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 457}], {
             RGBColor[
             0.4380492997215996, 0.5534053955584954, 0.9492526271337134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 494}], {
             RGBColor[
             0.38107496711151867`, 0.5044897159524077, 0.9455027378263516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 60}], {
             RGBColor[
             0.9740668501566808, 0.9799635557919238, 0.9191037618424754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 73}], {
             RGBColor[
             0.769769601175684, 0.81952464354351, 0.9539791162715971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 91}], {
             RGBColor[
             0.7114825067288603, 0.7722045544678969, 0.9493905426840812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 131}], {
             RGBColor[
             0.8981850447320697, 0.6159608551699692, 0.564028013817431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 136}], {
             RGBColor[
             0.7454315064099696, 0.7997658817940283, 0.9520631322982614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 234}], {
             RGBColor[
             0.9445095586663342, 0.8587398441686642, 0.6038719941743098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 240}], {
             RGBColor[
             0.9787234021564939, 0.9814785102156434, 0.8120827611030339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 434}], {
             RGBColor[
             0.9488603570213409, 0.87598930982866, 0.6073727486571113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 495}], {
             RGBColor[
             0.9243664441871663, 0.7736553444054359, 0.5873941515896481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 74}], {
             RGBColor[
             0.19093718319717995`, 0.31801746402983233`, 0.9341849621656055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 115}], {
             RGBColor[
             0.19207706439220854`, 0.3192155514384495, 0.9342498767133594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 144}], {
             RGBColor[
             0.1950230989335921, 0.322312020530822, 0.9344176490222236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 145}], {
             RGBColor[
             0.20110599109187893`, 0.32870552586681995`, 0.9347640607318055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 215}], {
             RGBColor[
             0.1890650982052305, 0.3160497840062494, 0.9340783496948156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 375}], {
             RGBColor[
             0.19795511773261765`, 0.3253937581893268, 0.934584623155295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 402}], {
             RGBColor[
             0.20564836608822273`, 0.3334798499911863, 0.9350227422680057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 417}], {
             RGBColor[
             0.19514933346569613`, 0.3224447010277949, 0.9344248378920796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 87}], {
             RGBColor[
             0.28570409751894754`, 0.41762349955141664`, 0.939581797741144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 91}], {
             RGBColor[
             0.36166005851975747`, 0.48325335582239703`, 0.9444730770573722]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 188}], {
             RGBColor[
             0.24348630056862833`, 0.373249918193702, 0.937177556660457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 200}], {
             RGBColor[
             0.26298567956392194`, 0.393745001849791, 0.9382880174474929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 228}], {
             RGBColor[
             0.26060629998899837`, 0.391244123055168, 0.9381525153006776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 256}], {
             RGBColor[
             0.28727672509446966`, 0.4190164856928953, 0.9396808744204175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 279}], {
             RGBColor[
             0.23548934775412372`, 0.36484461374956423`, 0.9367221420281024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 287}], {
             RGBColor[
             0.28357487962969113`, 0.41538555654959675`, 0.9394605419322465]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 298}], {
             RGBColor[
             0.2693422110049278, 0.4004261194216593, 0.9386500125094126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 335}], {
             RGBColor[
             0.2366854990874992, 0.3661018446413167, 0.9367902610769909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 409}], {
             RGBColor[
             0.2581147666270732, 0.38862536351944543`, 0.9380106261616092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 468}], {
             RGBColor[
             0.24224871187808175`, 0.37194913401228247`, 0.9371070778153788]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 73}], {
             RGBColor[
             0.781195634641831, 0.8278300365608096, 0.9249593462199677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 131}], {
             RGBColor[
             0.9096110781982166, 0.6242662481872688, 0.5350082437658015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.7568575398761165, 0.8080712748113279, 0.923043362246632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 240}], {
             RGBColor[
             0.9901494356226408, 0.989783903232943, 0.7830629910514044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 434}], {
             RGBColor[
             0.9602863904874878, 0.8842947028459596, 0.5783529786054818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 495}], {
             RGBColor[
             0.9357924776533132, 0.7819607374227355, 0.5583743815380187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 99}], {
             RGBColor[
             0.9849784772768306, 0.9873095986531333, 0.8651734232542627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 154}], {
             RGBColor[
             0.9868630618485601, 0.9887151187410052, 0.8619833131527019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 178}], {
             RGBColor[
             0.7297842099398613, 0.7851427009224017, 0.8812307211603922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 186}], {
             RGBColor[
             0.9917911303595999, 0.9891836280481643, 0.6628745668001933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 203}], {
             RGBColor[
             0.9176650400604409, 0.6688406301635299, 0.5009449661762736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 244}], {
             RGBColor[
             0.7184903511263943, 0.775794731676694, 0.8803911147116745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 264}], {
             RGBColor[
             0.9279014667399095, 0.7362939743699763, 0.5103077071950994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 288}], {
             RGBColor[
             0.8507412174209339, 0.8822861338586991, 0.8914741508713435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 295}], {
             RGBColor[
             0.9875274720228682, 0.989110303399177, 0.8563655966561801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 321}], {
             RGBColor[
             0.9878470936878512, 0.9892424751715496, 0.8510686385130581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 341}], {
             RGBColor[
             0.992278182050985, 0.9902253823675571, 0.7158871376728388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 391}], {
             RGBColor[
             0.731686882991318, 0.7866873766200184, 0.8813805065527239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 397}], {
             RGBColor[
             0.9061343995223057, 0.5802110742285213, 0.48990321177495955`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 455}], {
             RGBColor[
             0.8016518216680615, 0.8434880657223675, 0.8868884028153723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 96}], {
             RGBColor[
             0.36098375539591054`, 0.48129258556863375`, 0.9445483392518976]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 108}], {
             RGBColor[
             0.2304034031645468, 0.35949896351840704`, 0.9364325050077069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 110}], {
             RGBColor[
             0.33413455286534527`, 0.45851113631971724`, 0.9427065695832899]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 157}], {
             RGBColor[
             0.27514441268901324`, 0.40652460127246764`, 0.9389804393117331]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 190}], {
             RGBColor[
             0.233868572190446, 0.3631410758690329, 0.9366298412574736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 356}], {
             RGBColor[
             0.24825469827183463`, 0.37826180651364816`, 0.9374491098554425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 378}], {
             RGBColor[
             0.22907866033211158`, 0.3581065748079708, 0.9363570628631811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 72}], {
             RGBColor[
             0.20896361604647165`, 0.3369643878962938, 0.9352115408486552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 159}], {
             RGBColor[
             0.2194636807819041, 0.34800062167578893`, 0.9358095040018843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 166}], {
             RGBColor[
             0.20124645730453306`, 0.3288531647623917, 0.9347720600748151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 222}], {
             RGBColor[
             0.20195670404025598`, 0.32959967911388044`, 0.9348125075756986]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 239}], {
             RGBColor[
             0.20172774579693858`, 0.3293590294833628, 0.934799468742455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 272}], {
             RGBColor[
             0.23201898916873956`, 0.36119704684288256`, 0.9365245102406003]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 344}], {
             RGBColor[
             0.19854348560024537`, 0.326012170122881, 0.9346181298349442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 387}], {
             RGBColor[
             0.1978509608116646, 0.3252842826614749, 0.9345786915727331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 435}], {
             RGBColor[
             0.22260483335872017`, 0.351302172194599, 0.9359883879942152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 439}], {
             RGBColor[
             0.20302072388459882`, 0.33071803143303935`, 0.9348731019317575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 453}], {
             RGBColor[
             0.2233707740920417, 0.35210722446876735`, 0.9360320071858701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 74}], {
             RGBColor[
             0.1867563887094054, 0.3136231839455006, 0.933946872104458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 115}], {
             RGBColor[
             0.18789626990443398`, 0.31482127135411775`, 0.9340117866522119]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 170}], {
             RGBColor[
             0.18627047911638173`, 0.31311246215478516`, 0.9339192002719742]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 215}], {
             RGBColor[
             0.18488430371745596`, 0.31165550392191765`, 0.9338402596336681]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 223}], {
             RGBColor[
             0.19649530119615788`, 0.32385939845179323`, 0.9345014887631486]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 268}], {
             RGBColor[
             0.18555371944787077`, 0.31235910229799235`, 0.9338783818692034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 86}], {
             RGBColor[
             0.18424555499085607`, 0.31098413851125284`, 0.9338038838386322]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 177}], {
             RGBColor[
             0.18378082822451933`, 0.3104956812144541, 0.9337774183367911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 194}], {
             RGBColor[
             0.18464315044443147`, 0.3114020365419683, 0.9338265263115236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 290}], {
             RGBColor[
             0.18235293121758706`, 0.308994870926269, 0.9336961017146306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 297}], {
             RGBColor[
             0.18922089119532, 0.3162135323166796, 0.9340872218751262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 350}], {
             RGBColor[
             0.18235178883730735`, 0.30899367021216395`, 0.9336960366577636]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 412}], {
             RGBColor[
             0.1867174620390582, 0.3135822695468723, 0.9339446552881686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 484}], {
             RGBColor[
             0.1839955650344703, 0.31072138321681264`, 0.9337896472804431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 114}], {
             RGBColor[
             0.1896583133560848, 0.31667329074181017`, 0.9341121324200736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 128}], {
             RGBColor[
             0.19606919376904863`, 0.32341153252913013`, 0.9344772225755442]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 179}], {
             RGBColor[
             0.19899718509969622`, 0.32648903706301347`, 0.9346439673502496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 245}], {
             RGBColor[
             0.22090376329813846`, 0.34951423970685647`, 0.9358915145707727]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 255}], {
             RGBColor[
             0.19752636336653073`, 0.32494311016597255`, 0.9345602062284316]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 260}], {
             RGBColor[
             0.203816558535701, 0.331554504110179, 0.9349184235378061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 294}], {
             RGBColor[
             0.19268716813915449`, 0.3198568091593014, 0.9342846212191803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 299}], {
             RGBColor[
             0.21897785763056482`, 0.34748999074076453`, 0.9357818370921265]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 312}], {
             RGBColor[
             0.19642559622123856`, 0.32378613410360235`, 0.9344975191679463]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 327}], {
             RGBColor[
             0.19083074135934272`, 0.31790558690946313`, 0.9341789004604073]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 334}], {
             RGBColor[
             0.19236874220933842`, 0.3195221233176947, 0.9342664873335462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 385}], {
             RGBColor[
             0.189718897172314, 0.31673696817390284`, 0.9341155825787821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 415}], {
             RGBColor[
             0.1891407128871262, 0.3161292598311696, 0.9340826558390877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 446}], {
             RGBColor[
             0.19064470762485328`, 0.3177100536592947, 0.9341683061144403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 119}], {
             RGBColor[
             0.18259585546660687`, 0.3092501997142758, 0.933709935891238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 120}], {
             RGBColor[
             0.18038821966444069`, 0.3069298345140049, 0.9335842142982091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 124}], {
             RGBColor[
             0.18312075215718818`, 0.30980189941644914`, 0.9337398279812515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 363}], {
             RGBColor[
             0.18174309364533237`, 0.30835389297189403`, 0.9336613723670645]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 381}], {
             RGBColor[
             0.18458590754106158`, 0.31134187062111685`, 0.93382326641286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 95}], {
             RGBColor[
             0.18505409827792216`, 0.3118339687705646, 0.933849929182698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 286}], {
             RGBColor[
             0.1864116908357643, 0.3132608846251963, 0.9339272420704889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 319}], {
             RGBColor[
             0.1831451884938083, 0.30982758355559015`, 0.9337412195944718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 330}], {
             RGBColor[
             0.18750410848445143`, 0.3144090848372459, 0.9339894536394946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 352}], {
             RGBColor[
             0.18440978245630846`, 0.311156751990066, 0.933813236349837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 357}], {
             RGBColor[
             0.18698592728629504`, 0.313864443543398, 0.93395994398684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 367}], {
             RGBColor[
             0.19128856344294365`, 0.31838678694692435`, 0.9342049727507814]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 368}], {
             RGBColor[
             0.18232969627571796`, 0.3089704495291842, 0.9336947785190641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 375}], {
             RGBColor[
             0.19408512083298096`, 0.3213261460758332, 0.9343642325570081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 450}], {
             RGBColor[
             0.20047702738706202`, 0.3280444451344552, 0.9347282421792846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 492}], {
             RGBColor[
             0.1840181186755369, 0.3107450885235571, 0.9337909316769367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 101}], {
             RGBColor[
             0.3439836908945852, 0.4664796432810521, 0.9433547372891266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 103}], {
             RGBColor[
             0.4263301464035756, 0.5436874776637394, 0.9483863578332576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 129}], {
             RGBColor[
             0.36611599979539755`, 0.48974210320523914`, 0.944615139539211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 204}], {
             RGBColor[
             0.37937968200922045`, 0.5030213452043036, 0.9453947157587149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 209}], {
             RGBColor[
             0.7186661516906826, 0.7749926272189318, 0.8453240647103539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 231}], {
             RGBColor[
             0.6032570715569849, 0.6866480853473442, 0.9632586642510103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 233}], {
             RGBColor[
             0.7027067996446262, 0.7647987322711527, 0.9488520571207084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 259}], {
             RGBColor[
             0.5630647117651555, 0.6552495084047187, 0.9592526654459177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 275}], {
             RGBColor[
             0.46608428308489896`, 0.5771431812489669, 0.9511894958767693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 306}], {
             RGBColor[
             0.3418131212888621, 0.4641982370033755, 0.9432311265611506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 331}], {
             RGBColor[
             0.37214546505797846`, 0.49607945348638943`, 0.9449585086661204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 346}], {
             RGBColor[
             0.4421357571807656, 0.5573775033058451, 0.9493934773756274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 348}], {
             RGBColor[
             0.4524683198594424, 0.5660891289103882, 0.9501175973747447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 355}], {
             RGBColor[
             0.5012830197903266, 0.6057191013914514, 0.9539604693674415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 372}], {
             RGBColor[
             0.5285636967606093, 0.627866783936419, 0.9561081041909547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 404}], {
             RGBColor[
             0.6398415718326245, 0.7153643102811339, 0.9668689392230831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 418}], {
             RGBColor[
             0.45968074399907377`, 0.5719444997429457, 0.9506853858229966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 431}], {
             RGBColor[
             0.4320540938957698, 0.548645273287512, 0.9487510827059723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 444}], {
             RGBColor[
             0.5043601503383525, 0.6082172545934901, 0.9542027123560828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 486}], {
             RGBColor[
             0.4280953978994323, 0.5452164497853305, 0.9484988380976231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 76}], {
             RGBColor[
             0.3900856381049142, 0.5122943062773944, 0.9460768898142273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 111}], {
             RGBColor[
             0.36816732392345053`, 0.4933097641799131, 0.9446802742161886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 130}], {
             RGBColor[
             0.33633111822806117`, 0.4651961056645053, 0.9426714251516843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 175}], {
             RGBColor[
             0.3837102779939304, 0.5067722897841764, 0.945670657505465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 182}], {
             RGBColor[
             0.35737014201408246`, 0.4839577878921605, 0.9439922873324968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 208}], {
             RGBColor[
             0.39817892177344283`, 0.519304301810809, 0.9465925866929762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[
             0.4282161029443493, 0.5444148958180487, 0.9487568881673315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 351}], {
             RGBColor[
             0.3049667644622824, 0.4322301812417861, 0.9408852716041266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 359}], {
             RGBColor[
             0.6396346219366711, 0.7126850500536813, 0.9680066447733342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 371}], {
             RGBColor[
             0.31191266997486483`, 0.4395307683313558, 0.9412808306475218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 403}], {
             RGBColor[
             0.5565760155932599, 0.6470753000386655, 0.9599201962609412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 442}], {
             RGBColor[
             0.3038237186466454, 0.4310287676162611, 0.9408201768359108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 463}], {
             RGBColor[
             0.4624511336723232, 0.5722084360335765, 0.9514519951932873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 483}], {
             RGBColor[
             0.41089196681220996`, 0.5303157024471664, 0.9474026506811422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 135}], {
             RGBColor[
             0.18886726703484777`, 0.31584185090295647`, 0.9340670835023274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 153}], {
             RGBColor[
             0.21268791512647112`, 0.34087886236357334`, 0.9354236341716544]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 169}], {
             RGBColor[
             0.1907755412237238, 0.3178475680670369, 0.9341757568943452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 172}], {
             RGBColor[
             0.21061538458324242`, 0.3387005013566139, 0.9353056066232517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 197}], {
             RGBColor[
             0.2143161876130597, 0.34259027998541636`, 0.9355163618809523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 201}], {
             RGBColor[
             0.22759518578243687`, 0.3565473489985437, 0.936272581182181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 211}], {
             RGBColor[
             0.19261088350739852`, 0.3197766291746009, 0.9342802769222549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 236}], {
             RGBColor[
             0.20304903767595361`, 0.3307477910229513, 0.9348747143602888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 289}], {
             RGBColor[
             0.20390581997350005`, 0.33164832354080787`, 0.9349235068446382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 308}], {
             RGBColor[
             0.19432153409427227`, 0.32157463140291687`, 0.9343776959424965]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 362}], {
             RGBColor[
             0.1884877837309814, 0.3154429898899618, 0.9340454724895675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 369}], {
             RGBColor[
             0.18988277528354555`, 0.3169092144592796, 0.9341249151947808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 466}], {
             RGBColor[
             0.1963124589116516, 0.3236672196179068, 0.934491076165537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 470}], {
             RGBColor[
             0.19617627269900267`, 0.32352407927370813`, 0.9344833205621961]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 493}], {
             RGBColor[
             0.2293216757786306, 0.35836199945033154`, 0.9363709022333513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 128}], {
             RGBColor[
             0.20268608388741163`, 0.33036630357859437`, 0.9348540446789733]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 159}], {
             RGBColor[
             0.22161615608300847`, 0.35026300969206614`, 0.9359320842859804]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 179}], {
             RGBColor[
             0.20561407521805922`, 0.3334438081124777, 0.9350207894536787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 222}], {
             RGBColor[
             0.20410917934136036`, 0.33186206713015765`, 0.9349350878597946]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 245}], {
             RGBColor[
             0.22752065341650146`, 0.35646901075632065`, 0.9362683366742017]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 294}], {
             RGBColor[
             0.19930405825751749`, 0.32681158020876566`, 0.9346614433226095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 344}], {
             RGBColor[
             0.20069596090134978`, 0.3282745581391582, 0.9347407101190403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 438}], {
             RGBColor[
             0.20687895912531873`, 0.33477328129727923`, 0.9350928227209692]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 439}], {
             RGBColor[
             0.2051731991857032, 0.33298041944931656`, 0.9349956822158536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 453}], {
             RGBColor[
             0.2255232493931461, 0.35436961248504456`, 0.9361545874699662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 91}], {
             RGBColor[
             0.5186112912140105, 0.6200710352367826, 0.9552461270615734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 136}], {
             RGBColor[
             0.5525602908951197, 0.647632362562914, 0.9579187166757537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 200}], {
             RGBColor[
             0.4199369122581749, 0.5305626812641765, 0.9490610674516942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 240}], {
             RGBColor[
             0.785852186641644, 0.829344990984529, 0.8179383454805261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 256}], {
             RGBColor[
             0.4442279577887227, 0.5558341651072809, 0.9504539244246188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 298}], {
             RGBColor[
             0.42629344369918076`, 0.5372437988360448, 0.949423062513614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 434}], {
             RGBColor[
             0.755989141506491, 0.7238557905975457, 0.6132283330346036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 115}], {
             RGBColor[
             0.18984673852773665`, 0.31687133754406216`, 0.9341228629548491]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 144}], {
             RGBColor[
             0.1927927730691202, 0.31996780663643465`, 0.9342906352637134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 215}], {
             RGBColor[
             0.1868347723407586, 0.3137055701118621, 0.9339513359363054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 268}], {
             RGBColor[
             0.18750418807117342`, 0.3144091684879368, 0.9339894581718406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 402}], {
             RGBColor[
             0.20341804022375085`, 0.331135636096799, 0.9348957285094954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 417}], {
             RGBColor[
             0.1929190076012242, 0.3201004871334076, 0.9342978241335694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 104}], {
             RGBColor[
             0.894725030806556, 0.6091192249245418, 0.23357173327544747`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 125}], {
             RGBColor[
             0.8216340480291034, 0.6538916931792487, 0.593916539379413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 147}], {
             RGBColor[
             0.842199332426149, 0.3144945905899744, 0.187617653595973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 303}], {
             RGBColor[
             0.853058182050049, 0.3979604671775163, 0.19801610025913619`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 310}], {
             RGBColor[
             0.7550654921994678, 0.6018878314253746, 0.587281607852838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 323}], {
             RGBColor[
             0.9290142282590157, 0.73628865839294, 0.4899032009526938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 379}], {
             RGBColor[
             0.8463714309227728, 0.346563167860244, 0.1916128598280513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 400}], {
             RGBColor[
             0.9275933480888754, 0.7357010879276322, 0.5134508624919265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 408}], {
             RGBColor[
             0.9013012276585859, 0.7170355167790632, 0.6001882350839804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 111}], {
             RGBColor[
             0.3885098195301592, 0.510929411430886, 0.9459764800480857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 130}], {
             RGBColor[
             0.3566736138347697, 0.4828157529154782, 0.9439676309835814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 175}], {
             RGBColor[
             0.404052773600639, 0.5243919370351493, 0.946966863337362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.3777126376207911, 0.5015774351431334, 0.9452884931643937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 351}], {
             RGBColor[
             0.32530926006899097`, 0.449849828492759, 0.9421814774360235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 359}], {
             RGBColor[
             0.6599771175433797, 0.7303046973046542, 0.9693028506052312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 371}], {
             RGBColor[
             0.3322551655815734, 0.4571504155823287, 0.9425770364794188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 460}], {
             RGBColor[
             0.35555086797246704`, 0.4816356758279989, 0.9439036922676769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 463}], {
             RGBColor[
             0.4827936292790318, 0.5898280832845495, 0.9527482010251842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 483}], {
             RGBColor[
             0.43123446241891855`, 0.5479353496981393, 0.948698856513039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 87}], {
             RGBColor[
             0.32144010648392174`, 0.4528061418339081, 0.9417039869994168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 184}], {
             RGBColor[
             0.4376517235629901, 0.5511173532058586, 0.9497643390234523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 253}], {
             RGBColor[
             0.35598021511374034`, 0.4827539030708413, 0.9439037224194711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 287}], {
             RGBColor[
             0.31931088859466533`, 0.4505681988320882, 0.9415827311905192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 301}], {
             RGBColor[
             0.49545804882307076`, 0.5978313042438662, 0.9544626274499579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 336}], {
             RGBColor[
             0.47990926789082156`, 0.58542393137187, 0.9530910077074245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 354}], {
             RGBColor[
             0.32252783628299564`, 0.4537791338930982, 0.9417721664211531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 388}], {
             RGBColor[
             0.33157794270842256`, 0.4616178812072281, 0.9423488311998864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 409}], {
             RGBColor[
             0.2938507755920474, 0.42380800580193695`, 0.940132815419882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 436}], {
             RGBColor[
             0.3449944123676427, 0.4732385528946725, 0.9432037167828538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 473}], {
             RGBColor[
             0.2990309117164457, 0.42925265730827966`, 0.9404278165088418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 154}], {
             RGBColor[
             0.7267639040768494, 0.783922928096006, 0.9321470662934741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 171}], {
             RGBColor[
             0.47037777522198154`, 0.5809128940593202, 0.9514490079974901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 192}], {
             RGBColor[
             0.39152498613418535`, 0.5130863931305935, 0.946294212255822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.4280975104696688, 0.5447636755214684, 0.9486245811666656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 219}], {
             RGBColor[
             0.5697935423105139, 0.6612069230140997, 0.9595599186442647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 258}], {
             RGBColor[
             0.44262074177976496`, 0.5573429685234437, 0.9495499886233556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 262}], {
             RGBColor[
             0.4066140424697561, 0.526155775330442, 0.9472556735827959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 376}], {
             RGBColor[
             0.4205848118936931, 0.5382565536141679, 0.9481458786566228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 497}], {
             RGBColor[
             0.47412146300073554`, 0.5839521884493253, 0.9517437248130138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 127}], {
             RGBColor[
             0.8591989102072256, 0.8905659049388609, 0.9864323531431288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 147}], {
             RGBColor[
             0.8526636417246913, 0.529899304242684, 0.5774584339898925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 184}], {
             RGBColor[
             0.7135412330833855, 0.7751234699043363, 0.9730039594525782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 221}], {
             RGBColor[
             0.9242610852428408, 0.8982704304455256, 0.6484794882507952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 234}], {
             RGBColor[
             0.9063126289426009, 0.8289774045041336, 0.6243163382349994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 253}], {
             RGBColor[
             0.6318697246341356, 0.7067600197693191, 0.967143342848597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 301}], {
             RGBColor[
             0.7713475583434661, 0.821837420942344, 0.9777022478790838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 316}], {
             RGBColor[
             0.6624800077652702, 0.7332731084999433, 0.9690938030221024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 336}], {
             RGBColor[
             0.7557987774112169, 0.8094300480703478, 0.9763306281365505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 388}], {
             RGBColor[
             0.6074674522288179, 0.6856239979057058, 0.9655884516290124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 436}], {
             RGBColor[
             0.620883921888038, 0.6972446695931502, 0.9664433372119796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 81}], {
             RGBColor[
             0.2928864737857844, 0.4215973242135559, 0.9401217329908362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 171}], {
             RGBColor[
             0.4090554292271066, 0.5282531641753069, 0.9474159938779831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 192}], {
             RGBColor[
             0.3302026401393104, 0.46042666324658016`, 0.9422611981363149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 208}], {
             RGBColor[
             0.38701536387166025`, 0.5096349890530197, 0.9458812546550213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 219}], {
             RGBColor[
             0.508471196315639, 0.6085471931300863, 0.9555269045247576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 238}], {
             RGBColor[
             0.4170525450425667, 0.5347455830602593, 0.9480455561293766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 251}], {
             RGBColor[
             0.2931730251986915, 0.4218985079169302, 0.9401380516698865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 258}], {
             RGBColor[
             0.38129839578489, 0.5046832386394303, 0.9455169745038486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 272}], {
             RGBColor[
             0.30232143214337615`, 0.4315140636582957, 0.9406590399115311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 293}], {
             RGBColor[
             0.578582457393624, 0.6633186431495282, 0.9625149398020252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 403}], {
             RGBColor[
             0.5454124576914773, 0.6374059872808763, 0.9592088642229862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 447}], {
             RGBColor[
             0.2905728038348803, 0.41916551040000816`, 0.9399899729099002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 471}], {
             RGBColor[
             0.6521263465827374, 0.7213327352775194, 0.9506532320788272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 483}], {
             RGBColor[
             0.3997284089104274, 0.520646389689377, 0.9466913186431871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 497}], {
             RGBColor[
             0.4127991170058606, 0.5312924585653119, 0.9477107106935068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 121}], {
             RGBColor[
             0.22174468237743916`, 0.35039809897655055`, 0.9359394036683106]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.27063800741742255`, 0.4017880836094291, 0.9387238061981451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 208}], {
             RGBColor[
             0.3324858109628042, 0.4558962797557328, 0.942644967739437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 213}], {
             RGBColor[
             0.2202872137263247, 0.3488662070153795, 0.9358564029847612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 251}], {
             RGBColor[
             0.23864347228983546`, 0.36815979861964326`, 0.9369017647543021]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 442}], {
             RGBColor[
             0.2381306078360068, 0.36762074556118485`, 0.9368725578823716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 447}], {
             RGBColor[
             0.23604325092602435`, 0.36542680110272124`, 0.936753685994316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 454}], {
             RGBColor[
             0.2248746265777104, 0.3536878687809598, 0.9361176493601785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 500}], {
             RGBColor[
             0.21967281078147302`, 0.34822043056494373`, 0.9358214136459797]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 126}], {
             RGBColor[
             0.504289208348975, 0.6084437231644664, 0.9541186402349197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 149}], {
             RGBColor[
             0.540625880408879, 0.6379434704911183, 0.9569791961650909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 173}], {
             RGBColor[
             0.6203596764497656, 0.7014764485955354, 0.964075560146658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 242}], {
             RGBColor[
             0.7466175241184303, 0.8003829212442619, 0.9428810481338523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 249}], {
             RGBColor[
             0.6235359473541606, 0.7039577755666018, 0.9643921411464688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 269}], {
             RGBColor[
             0.5609980001725171, 0.6544824750687763, 0.958582964058418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 282}], {
             RGBColor[
             0.6084177855813375, 0.6921473526873871, 0.962885304068208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 323}], {
             RGBColor[
             0.7564161337880024, 0.8062755394340282, 0.8629204050270508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 384}], {
             RGBColor[
             0.39409857332891574`, 0.5101959076651558, 0.9469714569601196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 411}], {
             RGBColor[
             0.4006657201660342, 0.5170983953721258, 0.9473454462572704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 419}], {
             RGBColor[
             0.5847042349028322, 0.6736221466676785, 0.9605217589523052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 499}], {
             RGBColor[
             0.5743475030967551, 0.6653202029309262, 0.9596338858294544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 97}], {
             RGBColor[
             0.9918418301129188, 0.9825092007837744, 0.5692119944347548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 163}], {
             RGBColor[
             0.9472677000831091, 0.8139798001662166, 0.4832298213140514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 207}], {
             RGBColor[
             0.9351069377955797, 0.7587606188367377, 0.47308258317377627`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 209}], {
             RGBColor[
             0.9948514855705746, 0.9921389712197164, 0.7349877382312089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 231}], {
             RGBColor[
             0.879442405436877, 0.9037944293481288, 0.8529223377718652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 233}], {
             RGBColor[
             0.9788921335245182, 0.9819450762719373, 0.8385157306415634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 257}], {
             RGBColor[
             0.9791397410141973, 0.9396620716614368, 0.5198667768744751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 317}], {
             RGBColor[
             0.9062729324823862, 0.5632106001230137, 0.44649236510931034`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 326}], {
             RGBColor[
             0.8603044472818449, 0.8888437109835485, 0.8510148449573589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 343}], {
             RGBColor[
             0.920728738466214, 0.6743242594892878, 0.4603352612449215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 346}], {
             RGBColor[
             0.7183210910606576, 0.7745238473066297, 0.8390571508964824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 355}], {
             RGBColor[
             0.7774683536702185, 0.8228654453922359, 0.8436241428882965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 395}], {
             RGBColor[
             0.749683946094778, 0.8003088116491959, 0.8414368525463194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 440}], {
             RGBColor[
             0.9434296852982257, 0.7965522714191877, 0.48002728769919345`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 89}], {
             RGBColor[
             0.2925984761880414, 0.42478343593361145`, 0.9399775893294924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 176}], {
             RGBColor[
             0.29622447069818203`, 0.4279240901305121, 0.9402086344933376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 244}], {
             RGBColor[
             0.3611185636561085, 0.4841320917787186, 0.9443436287130234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 245}], {
             RGBColor[
             0.25972033738633343`, 0.39031292018649366`, 0.9381020610411201]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 260}], {
             RGBColor[
             0.24263313262389596`, 0.37235318458981626`, 0.9371289700081534]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 261}], {
             RGBColor[
             0.30240410894972447`, 0.4332765821863486, 0.9406023955782863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 262}], {
             RGBColor[
             0.3093414127711809, 0.4392853260774658, 0.9410444344433726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 299}], {
             RGBColor[
             0.2577944317187598, 0.3882886712204018, 0.9379923835624739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 328}], {
             RGBColor[
             0.2592509748717875, 0.3898195904244037, 0.9380753315402763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 376}], {
             RGBColor[
             0.3233121821951179, 0.4513861043611917, 0.9419346395171995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 391}], {
             RGBColor[
             0.3743150955210323, 0.495024736722043, 0.9453330205540728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 407}], {
             RGBColor[
             0.27632252286434345`, 0.40776286976323906`, 0.9390475309433604]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 448}], {
             RGBColor[
             0.28804975562944346`, 0.4200889349488619, 0.9397153795004467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 455}], {
             RGBColor[
             0.4442800341977758, 0.5518254258243921, 0.9508409168167211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 475}], {
             RGBColor[
             0.3060220283144641, 0.4364102420981715, 0.9408329262010071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 478}], {
             RGBColor[
             0.2624145878361924, 0.3931447482346404, 0.9382554946184531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 482}], {
             RGBColor[
             0.30394372684162835`, 0.43461012182087044`, 0.9407004986689278]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 146}], {
             RGBColor[
             0.1836713842833611, 0.3103806486931501, 0.9337711856662498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 166}], {
             RGBColor[
             0.19147571921883372`, 0.31858349953374643`, 0.9342156309953462]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 239}], {
             RGBColor[
             0.19195700771123925`, 0.31908936425471746`, 0.9342430396629862]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 332}], {
             RGBColor[
             0.18694868384128802`, 0.31382529832132483`, 0.9339578230277437]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 387}], {
             RGBColor[
             0.18808022272596522`, 0.31501461743282955`, 0.9340222624932641]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 489}], {
             RGBColor[
             0.18944536571522486`, 0.31644946926960615`, 0.9341000053669545]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 177}], {
             RGBColor[
             0.1848471163861694, 0.31161641767892256`, 0.933838141870165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 194}], {
             RGBColor[
             0.18570943860608155`, 0.31252277300643677`, 0.9338872498448976]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 220}], {
             RGBColor[
             0.20117259087192368`, 0.32877552645831687`, 0.9347678534907535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 254}], {
             RGBColor[
             0.18887066842711453`, 0.3158454259818896, 0.934067277206585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 290}], {
             RGBColor[
             0.18341921937923714`, 0.31011560739073746`, 0.9337568252480046]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 297}], {
             RGBColor[
             0.1902871793569701, 0.317334268781148, 0.9341479454085002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 350}], {
             RGBColor[
             0.18341807699895743`, 0.3101144066766324, 0.9337567601911376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 377}], {
             RGBColor[
             0.18305173765274474`, 0.30972936079650676`, 0.9337358977073213]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 412}], {
             RGBColor[
             0.18778375020070825`, 0.3147030060113407, 0.9340053788215426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 426}], {
             RGBColor[
             0.1863343941921356, 0.31317964095185236`, 0.9339228401409845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 476}], {
             RGBColor[
             0.18437093737264393`, 0.311115923344214, 0.9338110241797885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 91}], {
             RGBColor[
             0.3843682357663767, 0.5071210898901892, 0.9457662741578293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 161}], {
             RGBColor[
             0.2611314320863651, 0.3917960701847984, 0.9381824207967593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 184}], {
             RGBColor[
             0.4246238918446351, 0.5398024449911591, 0.9489353468656369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 228}], {
             RGBColor[
             0.28331447723561765`, 0.41511185712296006`, 0.9394457124011348]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 253}], {
             RGBColor[
             0.34295238339538536`, 0.47143899485614194`, 0.9430747302616557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 256}], {
             RGBColor[
             0.30998490234108894`, 0.4428842197606874, 0.9409740715208748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 285}], {
             RGBColor[
             0.2614000119680612, 0.39207836466940904`, 0.9381977160236936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 287}], {
             RGBColor[
             0.3062830568763104, 0.4392532906173888, 0.9407537390327037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 336}], {
             RGBColor[
             0.4668814361724666, 0.5741090231571706, 0.9522620155496091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 354}], {
             RGBColor[
             0.30950000456464066`, 0.4424642256783988, 0.9409431742633377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 388}], {
             RGBColor[
             0.3185501109900676, 0.45030297299252864`, 0.941519839042071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 409}], {
             RGBColor[
             0.28082294387369244`, 0.4124930975872375, 0.9393038232620665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 436}], {
             RGBColor[
             0.33196658064928775`, 0.46192364467997304`, 0.9423747246250382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 473}], {
             RGBColor[
             0.28600307999809077`, 0.4179377490935802, 0.9395988243510263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 133}], {
             RGBColor[
             0.19376977710770305`, 0.3209946998266191, 0.9343462741983627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 241}], {
             RGBColor[
             0.2025944621469051, 0.33027000332016815`, 0.9348488269563937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 271}], {
             RGBColor[
             0.19882737388287028`, 0.32631055470747644`, 0.9346342968526646]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 304}], {
             RGBColor[
             0.19013400622997473`, 0.3171732741129387, 0.9341392224255172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 307}], {
             RGBColor[
             0.1906659921562372, 0.31773242505129645`, 0.9341695182370151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 311}], {
             RGBColor[
             0.18977178861723454`, 0.3167925604360257, 0.9341185946683245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 337}], {
             RGBColor[
             0.18932246677623382`, 0.3163202946924838, 0.9340930064541916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 423}], {
             RGBColor[
             0.18437944571093495`, 0.3111248661472177, 0.9338115087170672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 427}], {
             RGBColor[
             0.18803656473244668`, 0.3149687301135649, 0.9340197762351194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 433}], {
             RGBColor[
             0.18511620603054046`, 0.3118992479564254, 0.9338534661273294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 465}], {
             RGBColor[
             0.18430414736705614`, 0.3110457228136103, 0.9338072205877772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 469}], {
             RGBColor[
             0.1854557592359103, 0.3122561399041857, 0.9338728031800514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 176}], {
             RGBColor[
             0.31330748759898347`, 0.4457929312912065, 0.9411846539562421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 178}], {
             RGBColor[
             0.38949543937037706`, 0.5113489021851207, 0.9461592546246456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 244}], {
             RGBColor[
             0.37820158055690994`, 0.5020009329394131, 0.945319648175928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 261}], {
             RGBColor[
             0.31948712585052597`, 0.45114542334704305`, 0.9415784150411908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 262}], {
             RGBColor[
             0.3264244296719824, 0.4571541672381602, 0.9420204539062771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 299}], {
             RGBColor[
             0.27487744861956126`, 0.4061575123810962, 0.9389684030253784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 328}], {
             RGBColor[
             0.27633399177258894`, 0.4076884315850981, 0.9390513510031808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 376}], {
             RGBColor[
             0.3403951990959194, 0.4692549455218861, 0.9429106589801041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 391}], {
             RGBColor[
             0.39139811242183375`, 0.5128935778827375, 0.9463090400169774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 407}], {
             RGBColor[
             0.2934055397651449, 0.4256317109239335, 0.9400235504062648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 448}], {
             RGBColor[
             0.30513277253024496`, 0.43795777610955633`, 0.9406913989633512]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 455}], {
             RGBColor[
             0.4613630510985772, 0.5696942669850865, 0.9518169362796256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 475}], {
             RGBColor[
             0.32310504521526556`, 0.4542790832588659, 0.9418089456639116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 478}], {
             RGBColor[
             0.27949760473699387`, 0.41101358939533483`, 0.9392315140813577]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 482}], {
             RGBColor[
             0.3210267437424298, 0.45247896298156487`, 0.9416765181318323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 137}], {
             RGBColor[
             0.23700337417738956`, 0.3664359515152362, 0.9368083635931062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 148}], {
             RGBColor[
             0.26849318417245727`, 0.3995337383893224, 0.9386016616873261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 229}], {
             RGBColor[
             0.24859585520259658`, 0.3786203840784777, 0.9374685382379528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 232}], {
             RGBColor[
             0.2704052861597108, 0.40154347881219404`, 0.9387105530667987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 263}], {
             RGBColor[
             0.24334458110817345`, 0.37310096205523113`, 0.9371694859468394]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 267}], {
             RGBColor[
             0.24580395513477205`, 0.37568592009050583`, 0.9373095436593363]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 280}], {
             RGBColor[
             0.25791236607974777`, 0.3884126277112705, 0.937999099749864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 342}], {
             RGBColor[
             0.36933196448262395`, 0.489404611907154, 0.9450840596145658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 393}], {
             RGBColor[
             0.24183341082623228`, 0.3715126262751811, 0.9370834270348589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 480}], {
             RGBColor[
             0.2528560578238772, 0.3830981271458908, 0.9377111504748298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 485}], {
             RGBColor[
             0.25884791756577036`, 0.3893959516404705, 0.9380523780229685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 200}], {
             RGBColor[
             0.3616498178113511, 0.4832425921885635, 0.9444724938641782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 228}], {
             RGBColor[
             0.35927043823642757`, 0.48074171339394056`, 0.9443369917173629]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 256}], {
             RGBColor[
             0.3859408633418989, 0.5085140760316679, 0.9458653508371028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 287}], {
             RGBColor[
             0.38223901787712034`, 0.5048831468883692, 0.9456450183489318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 298}], {
             RGBColor[
             0.368006349252357, 0.4899237097604318, 0.9448344889260978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 336}], {
             RGBColor[
             0.5428373971732765, 0.639738879428151, 0.957153294865837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 132}], {
             RGBColor[
             0.27212682678288186`, 0.40335292715912663`, 0.9388085922584972]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 250}], {
             RGBColor[
             0.24579035153480303`, 0.3756716218444204, 0.9373087689544427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 342}], {
             RGBColor[
             0.37412603951120016`, 0.4944434887241004, 0.9453570750952447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 356}], {
             RGBColor[
             0.2586276684650108, 0.3891644558709726, 0.9380398351625095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 365}], {
             RGBColor[
             0.23949140661491064`, 0.36905103135743866`, 0.9369500533597088]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 457}], {
             RGBColor[
             0.37059515571215895`, 0.49157695819153635`, 0.9450791109885306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 485}], {
             RGBColor[
             0.26364199259434656`, 0.39443482845741684`, 0.9383253935036474]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 494}], {
             RGBColor[
             0.31362082310207806`, 0.44266127858544857`, 0.9413292216811688]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 141}], {
             RGBColor[
             0.21496969901233648`, 0.34327716190107216`, 0.9355535783883577]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 151}], {
             RGBColor[
             0.21317178010893856`, 0.3413874351389585, 0.9354511895665918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 160}], {
             RGBColor[
             0.23103960685447572`, 0.36016765393416605`, 0.9364687358666692]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 167}], {
             RGBColor[
             0.23124675852992788`, 0.3603853834792411, 0.9364805328481329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 172}], {
             RGBColor[
             0.22306123798292227`, 0.35178188239235997`, 0.9360143795623734]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 201}], {
             RGBColor[
             0.24004103918211672`, 0.36962873003428975`, 0.9369813541213027]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 218}], {
             RGBColor[
             0.2542535028794738, 0.3845669305024568, 0.9377907329034113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 235}], {
             RGBColor[
             0.21987414226832205`, 0.3484320427227756, 0.9358328791763124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 236}], {
             RGBColor[
             0.21549489107563347`, 0.3438291720586974, 0.9355834872994104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 274}], {
             RGBColor[
             0.23335737797095998`, 0.3626037783327675, 0.936600729502918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 284}], {
             RGBColor[
             0.21473027895683314`, 0.3430255162426299, 0.9355399437703871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 289}], {
             RGBColor[
             0.21635167337317993`, 0.34472970457655394`, 0.93563227978376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 300}], {
             RGBColor[
             0.2272468293636924, 0.3561812043153706, 0.9362527427994807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 305}], {
             RGBColor[
             0.26659251557076086`, 0.3973687929461906, 0.9384995442473698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 308}], {
             RGBColor[
             0.20676738749395213`, 0.33465601243866294`, 0.9350864688816183]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 389}], {
             RGBColor[
             0.20877589722978934`, 0.3367670835179003, 0.9352008505397502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 432}], {
             RGBColor[
             0.2569317093580773, 0.38738189531956746`, 0.9379432528003164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 456}], {
             RGBColor[
             0.20912093230204676`, 0.3371297372553299, 0.9352204997766816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 493}], {
             RGBColor[
             0.24176752917831046`, 0.3714433804860776, 0.9370796751724728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 123}], {
             RGBColor[
             0.18238673674691558`, 0.30903040268098764`, 0.933698026889515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 139}], {
             RGBColor[
             0.18076319755662762`, 0.3073239600536649, 0.9336055687344391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 158}], {
             RGBColor[
             0.18531714297239393`, 0.3121104454224513, 0.9338649091889084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 193}], {
             RGBColor[
             0.17992543383268728`, 0.3064434172625156, 0.9335578593297211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 401}], {
             RGBColor[
             0.17982716171712376`, 0.30634012703824637`, 0.9335522628781203]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 410}], {
             RGBColor[
             0.18058759193707163`, 0.30713938741347224`, 0.9335955682541907]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 428}], {
             RGBColor[
             0.18335052254202558`, 0.31004340265919705`, 0.9337529130647533]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 437}], {
             RGBColor[
             0.18042329707310156`, 0.30696670309454366`, 0.93358621190474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 122}], {
             RGBColor[
             0.18517962016864098`, 0.3119659002362576, 0.9338570774686815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 185}], {
             RGBColor[
             0.19811081032671668`, 0.3255574009772055, 0.9345934896182024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 212}], {
             RGBColor[
             0.18331321264928, 0.31000418759633763`, 0.9337507883215563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 224}], {
             RGBColor[
             0.19530748745975585`, 0.322610930903094, 0.9344338445280735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 286}], {
             RGBColor[
             0.18603827385130794`, 0.3128683996985284, 0.9339059765256451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 319}], {
             RGBColor[
             0.18277177150935192`, 0.30943509862892227`, 0.9337199540496279]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 330}], {
             RGBColor[
             0.18713069149999506`, 0.314016599910578, 0.9339681880946508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 357}], {
             RGBColor[
             0.18661251030183867`, 0.3134719586167301, 0.9339386784419961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 367}], {
             RGBColor[
             0.19091514645848728`, 0.31799430202025647`, 0.9341837072059376]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 368}], {
             RGBColor[
             0.1819562792912616, 0.3085779646025163, 0.9336735129742202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 492}], {
             RGBColor[
             0.18364470169108055`, 0.3103526035968892, 0.9337696661320929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 110}], {
             RGBColor[
             0.443925135446012, 0.558453392319533, 0.9496384572015815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 136}], {
             RGBColor[
             0.4994982670529912, 0.6045542211909409, 0.9537414797863035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.3849349952696799, 0.5064668572722832, 0.9459123269300246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 240}], {
             RGBColor[
             0.7327901627995155, 0.786266849612556, 0.8137611085910759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 360}], {
             RGBColor[
             0.5334689580963748, 0.6321331585421514, 0.9564157770239803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 457}], {
             RGBColor[
             0.47001276809964954`, 0.5806165648340276, 0.951420273299755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 163}], {
             RGBColor[
             0.9438826652312557, 0.8041948007039634, 0.3236750855301855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 207}], {
             RGBColor[
             0.9317219029437263, 0.7489756193744845, 0.31352784738991035`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 209}], {
             RGBColor[
             0.9914664507187211, 0.9823539717574632, 0.575433002447343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 231}], {
             RGBColor[
             0.8760573705850234, 0.8940094298858756, 0.6933676019879993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 233}], {
             RGBColor[
             0.9755070986726647, 0.9721600768096842, 0.6789609948576975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 257}], {
             RGBColor[
             0.9757547061623437, 0.9298770721991836, 0.3603120410906092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 281}], {
             RGBColor[
             0.903440360362725, 0.5576720713111039, 0.28746666826170925`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 317}], {
             RGBColor[
             0.9028878976305327, 0.5534256006607606, 0.2869376293254444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 322}], {
             RGBColor[
             0.9046195205529701, 0.5667356132446183, 0.288595833391559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 326}], {
             RGBColor[
             0.8569194124299913, 0.8790587115212953, 0.6914601091734929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 343}], {
             RGBColor[
             0.9173437036143605, 0.6645392600270346, 0.3007805254610556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 355}], {
             RGBColor[
             0.7740833188183651, 0.8130804459299827, 0.6840694071044306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 395}], {
             RGBColor[
             0.7462989112429244, 0.7905238121869427, 0.6818821167624534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 440}], {
             RGBColor[
             0.9400446504463722, 0.7867672719569345, 0.32047255191532753`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 105}], {
             RGBColor[
             0.18986356428247403`, 0.31688902247910566`, 0.93412382115669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 276}], {
             RGBColor[
             0.20095020339638087`, 0.3285417831213411, 0.9347551888530141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 347}], {
             RGBColor[
             0.19568928020766854`, 0.32301221928820867`, 0.9344555870602553]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 382}], {
             RGBColor[
             0.20018581629901203`, 0.3277383638170652, 0.9347116581386283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 425}], {
             RGBColor[
             0.1874902819867422, 0.31439455231150293`, 0.9339886662409045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 462}], {
             RGBColor[
             0.18918443929913709`, 0.3161752190626076, 0.9340851459935643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 131}], {
             RGBColor[
             0.9067135965497277, 0.6223214351513566, 0.549591400192696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 143}], {
             RGBColor[
             0.7801748654933693, 0.827408823277354, 0.9396902443294888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 178}], {
             RGBColor[
             0.7245036529888805, 0.7822124250066672, 0.9353076025507647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 186}], {
             RGBColor[
             0.9865105734086191, 0.9862533521324298, 0.7169514481905657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 277}], {
             RGBColor[
             0.7114622471897839, 0.7713508183962726, 0.9343566439534178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 288}], {
             RGBColor[
             0.8454606604699532, 0.8793558579429647, 0.9455510322617159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 295}], {
             RGBColor[
             0.9822469150718874, 0.9861800274834427, 0.9104424780465525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 313}], {
             RGBColor[
             0.6704591742575927, 0.7358360174967769, 0.9317439644037724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 321}], {
             RGBColor[
             0.9825665367368704, 0.9863121992558153, 0.9051455199034306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 341}], {
             RGBColor[
             0.9869976251000042, 0.9872951064518227, 0.7699640190632113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 373}], {
             RGBColor[
             0.9853487541189616, 0.9874627176430353, 0.859036977734402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 498}], {
             RGBColor[
             0.8771421221278247, 0.9041056565781206, 0.9487087442796804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 203}], {
             RGBColor[
             0.9191489665110915, 0.667681353565574, 0.3474800185895157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 257}], {
             RGBColor[
             0.9781397520963673, 0.9374756322249009, 0.407566735110352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 264}], {
             RGBColor[
             0.92938539319056, 0.7351346977720205, 0.3568427596083415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 281}], {
             RGBColor[
             0.9058254062967486, 0.5652706313368212, 0.33472136228145205`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 324}], {
             RGBColor[
             0.9664798274342277, 0.9712473493741347, 0.7455337650413938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 360}], {
             RGBColor[
             0.7946952326726424, 0.8354763984444047, 0.7327589869340729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 374}], {
             RGBColor[
             0.9203355927006582, 0.6768022824414968, 0.3486163331687475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 397}], {
             RGBColor[
             0.9076183259729562, 0.5790517976305654, 0.33643826418820166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 457}], {
             RGBColor[
             0.7312390426759171, 0.7839598047362808, 0.7277634832098476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 103}], {
             RGBColor[
             0.32745764009317235`, 0.4521656087003331, 0.9423017119454735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 129}], {
             RGBColor[
             0.2672434934849943, 0.39822023424183295`, 0.9385304936514267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[
             0.2805071756988172, 0.41149947624089733`, 0.9393100698709307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 276}], {
             RGBColor[
             0.22935486634297414`, 0.3583968848378599, 0.9363727923868895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 306}], {
             RGBColor[
             0.24294061497845892`, 0.37267636803996923`, 0.9371464806733664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 331}], {
             RGBColor[
             0.2732729587475753, 0.4045575845229832, 0.9388738627783362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 347}], {
             RGBColor[
             0.22409394315426182`, 0.3528673210047275, 0.9360731905941307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 390}], {
             RGBColor[
             0.25051248587412484`, 0.3806348844356572, 0.9375776875192954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 431}], {
             RGBColor[
             0.33318158758536665`, 0.45712340432410575`, 0.9426664368181881]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 486}], {
             RGBColor[
             0.32922289158902907`, 0.45369458082192426`, 0.9424141922098388]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 134}], {
             RGBColor[
             0.1917868632444325, 0.31891053163232136`, 0.9342333501873077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 174}], {
             RGBColor[
             0.1934597999069662, 0.32066889413495503`, 0.934328621455351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 210}], {
             RGBColor[
             0.19748304019874757`, 0.324897574769785, 0.9345577390381172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 225}], {
             RGBColor[
             0.19170377678695943`, 0.3188232024975315, 0.9342286185364699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 247}], {
             RGBColor[
             0.19186086570906943`, 0.31898831291468205`, 0.934237564518192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 252}], {
             RGBColor[
             0.19087465031632422`, 0.3179517380072394, 0.93418140101055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 278}], {
             RGBColor[
             0.19195325855915324`, 0.31908542365816517`, 0.9342428261543212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 309}], {
             RGBColor[
             0.19381918087775277`, 0.3210466263213213, 0.9343490876699807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 383}], {
             RGBColor[
             0.23360844690792137`, 0.362867667704204, 0.9366150275074547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 393}], {
             RGBColor[
             0.2103791435745319, 0.3384521970779141, 0.9352921530472929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 451}], {
             RGBColor[
             0.20226457959273075`, 0.32992327583996894`, 0.9348300406329509]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 480}], {
             RGBColor[
             0.2214017905721769, 0.3500376979486238, 0.9359198764872638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 129}], {
             RGBColor[
             0.3495899489939847, 0.47542806862452014`, 0.9435621141955579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 204}], {
             RGBColor[
             0.3628536312078076, 0.48870731062358463`, 0.9443416904150619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 209}], {
             RGBColor[
             0.7021401008892698, 0.7606785926382128, 0.8442710393667008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 231}], {
             RGBColor[
             0.5867310207555722, 0.6723340507666251, 0.9622056389073572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 233}], {
             RGBColor[
             0.6861807488432135, 0.7504846976904338, 0.9477990317770553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 259}], {
             RGBColor[
             0.5465386609637427, 0.6409354738239997, 0.9581996401022647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 275}], {
             RGBColor[
             0.4495582322834861, 0.5628291466682479, 0.9501364705331162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 326}], {
             RGBColor[
             0.56759306260054, 0.6573833324020449, 0.9602981460928508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 346}], {
             RGBColor[
             0.4256097063793528, 0.5430634687251261, 0.9483404520319744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 348}], {
             RGBColor[
             0.4359422690580296, 0.5517750943296691, 0.9490645720310915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 355}], {
             RGBColor[
             0.48475696898891374`, 0.5914050668107322, 0.9529074440237885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 390}], {
             RGBColor[
             0.3328589413831152, 0.4578427188183445, 0.9426093080634266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 404}], {
             RGBColor[
             0.6233155210312117, 0.7010502757004149, 0.96581591387943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 431}], {
             RGBColor[
             0.415528043094357, 0.534331238706793, 0.9476980573623193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 443}], {
             RGBColor[
             0.3488203865149018, 0.47461920966592475`, 0.9435182887508398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 444}], {
             RGBColor[
             0.4878340995369397, 0.5939032200127712, 0.9531496870124296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 486}], {
             RGBColor[
             0.41156934709801946`, 0.5309024152046116, 0.94744581275397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 125}], {
             RGBColor[
             0.8510407401896769, 0.7816870619636468, 0.6181576134272155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 147}], {
             RGBColor[
             0.8716060245867224, 0.4422899593743725, 0.21185872764377553`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 242}], {
             RGBColor[
             0.9486223107500168, 0.8581914089875718, 0.5941049181072977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 303}], {
             RGBColor[
             0.8824648742106225, 0.5257558359619144, 0.2222571743069387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 310}], {
             RGBColor[
             0.7844721843600413, 0.7296832002097726, 0.6115226819006405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 323}], {
             RGBColor[
             0.958420920419589, 0.8640840271773381, 0.5141442750004963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 379}], {
             RGBColor[
             0.8757781230833462, 0.4743585366446421, 0.21585393387585383`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 408}], {
             RGBColor[
             0.9307079198191593, 0.8448308855634613, 0.624429309131783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 109}], {
             RGBColor[
             0.2025306105640042, 0.3302028912581151, 0.9348451907032074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 205}], {
             RGBColor[
             0.21445329260995954`, 0.34273438603011697`, 0.9355241698076971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 230}], {
             RGBColor[
             0.19866180408544326`, 0.32613653035264917`, 0.9346248678976397]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 382}], {
             RGBColor[
             0.2017475218904906, 0.3293798154115627, 0.9348005949617267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 425}], {
             RGBColor[
             0.18905198757822078`, 0.3160360039060004, 0.9340776030640029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 462}], {
             RGBColor[
             0.19074614489061564`, 0.31781667065710506`, 0.9341740828166627]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 484}], {
             RGBColor[
             0.1881185665568436, 0.315054919230222, 0.9340244461177081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 156}], {
             RGBColor[
             0.1895211212928381, 0.31652909318485867`, 0.9341043195350291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 227}], {
             RGBColor[
             0.18640315120824044`, 0.31325190893522514`, 0.9339267557513348]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 265}], {
             RGBColor[
             0.18198502195137928`, 0.3086081749606899, 0.933675149826193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 270}], {
             RGBColor[
             0.17988066425974236`, 0.3063963616027956, 0.9335553097687725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 329}], {
             RGBColor[
             0.18061317161541351`, 0.30716627327725476`, 0.9335970249790304]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 479}], {
             RGBColor[
             0.18098277247116215`, 0.30755474721069437`, 0.9336180732009899]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 153}], {
             RGBColor[
             0.21946182531602942`, 0.3479986714635114, 0.9358093983358476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 170}], {
             RGBColor[
             0.19951076544330998`, 0.3270288425670261, 0.9346732149910444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 197}], {
             RGBColor[
             0.221090097802618, 0.3497100890853544, 0.9359021260451457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 214}], {
             RGBColor[
             0.19941582681621922`, 0.32692905605049705`, 0.9346678083766806]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 223}], {
             RGBColor[
             0.20973558752308613`, 0.3377757788640342, 0.935255503482219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 236}], {
             RGBColor[
             0.20982294786551192`, 0.3378676001228893, 0.935260478524482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 289}], {
             RGBColor[
             0.21067973016305835`, 0.3387681326407459, 0.9353092710088315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 314}], {
             RGBColor[
             0.2370472271918243, 0.36648204381384886`, 0.9368108609574035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 411}], {
             RGBColor[
             0.24624789168403566`, 0.3761525255509848, 0.9373348251890715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 466}], {
             RGBColor[
             0.20308636910120992`, 0.33078702871784477`, 0.9348768403297303]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 470}], {
             RGBColor[
             0.20295018288856098`, 0.3306438883736461, 0.9348690847263893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 113}], {
             RGBColor[
             0.2031652064588611, 0.33086989177931336`, 0.934881330000619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 190}], {
             RGBColor[
             0.21307880253974895`, 0.34128970981862183`, 0.9354458946315745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 315}], {
             RGBColor[
             0.19651178198130725`, 0.3238767208019274, 0.9345024273194817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 349}], {
             RGBColor[
             0.19740440059431363`, 0.32481491955948594`, 0.9345532606289816]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 364}], {
             RGBColor[
             0.2070027664491964, 0.33490341064451234`, 0.9350998733649074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 378}], {
             RGBColor[
             0.20828889068141454`, 0.33625520875755976`, 0.9351731162372818]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 380}], {
             RGBColor[
             0.19854131235532485`, 0.3260098859046778, 0.934618006071861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 416}], {
             RGBColor[
             0.20942130064370462`, 0.3374454434268651, 0.9352376053093838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 452}], {
             RGBColor[
             0.21821098000140754`, 0.3466839537296702, 0.9357381645456397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 487}], {
             RGBColor[
             0.20117686323780593`, 0.3287800169857428, 0.9347680967956702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 164}], {
             RGBColor[
             0.2648306442899861, 0.3950111522821019, 0.9384177281820844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 180}], {
             RGBColor[
             0.23839049921865452`, 0.36789390788241305`, 0.9368873583121385]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 205}], {
             RGBColor[
             0.22555863330001114`, 0.354406803214629, 0.9361566025311163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 230}], {
             RGBColor[
             0.20976714477549485`, 0.3378089475371612, 0.9352573006210588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 382}], {
             RGBColor[
             0.2128528625805422, 0.3410522325960747, 0.9354330276851459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 413}], {
             RGBColor[
             0.22197296688604118`, 0.35063804046916514`, 0.9359524041333588]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 474}], {
             RGBColor[
             0.22157473772172553`, 0.350219476368282, 0.9359297255715783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 490}], {
             RGBColor[
             0.21480193499900369`, 0.3431008312862066, 0.935544024475983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 157}], {
             RGBColor[
             0.35808579273911467`, 0.4836854080233668, 0.944070557261417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 356}], {
             RGBColor[
             0.3311960783219361, 0.45542261326454736`, 0.9425392278051263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 360}], {
             RGBColor[
             0.5066197555658096, 0.6093517092932348, 0.9545740073553726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 457}], {
             RGBColor[
             0.44316356556908426`, 0.5578351155851111, 0.9495785036311474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 494}], {
             RGBColor[
             0.3861892329590033, 0.5089194359790232, 0.9458286143237857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 130}], {
             RGBColor[
             0.3347552996533061, 0.46383121081799694`, 0.9425710153855427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 175}], {
             RGBColor[
             0.38213445941917534`, 0.5054073949376681, 0.9455702477393233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 182}], {
             RGBColor[
             0.35579432343932743`, 0.4825928930456521, 0.9438918775663551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 351}], {
             RGBColor[
             0.3033909458875273, 0.43086528639527777`, 0.9407848618379848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 359}], {
             RGBColor[
             0.6380588033619161, 0.711320155207173, 0.9679062350071925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 371}], {
             RGBColor[
             0.3103368514001098, 0.4381658734848475, 0.9411804208813801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 460}], {
             RGBColor[
             0.33363255379100343`, 0.46265113373051764`, 0.9425070766696382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 463}], {
             RGBColor[
             0.4608753150975682, 0.5708435411870683, 0.9513515854271455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 483}], {
             RGBColor[
             0.4093161482374549, 0.528950807600658, 0.9473022409150004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 163}], {
             RGBColor[
             0.9463750065735652, 0.8136106484588435, 0.49802406298394036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 175}], {
             RGBColor[
             0.6955594457176699, 0.7552129086866064, 0.8524579222934991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 207}], {
             RGBColor[
             0.9342142442860358, 0.7583914671293646, 0.48787682484366524`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 238}], {
             RGBColor[
             0.7400652706680888, 0.7928555147204785, 0.8555441529553656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 266}], {
             RGBColor[
             0.9935124253020141, 0.9901198523525236, 0.6506615550659651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 293}], {
             RGBColor[
             0.901595183019146, 0.9214285748097474, 0.8700135366280143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 317}], {
             RGBColor[
             0.9053802389728423, 0.5628414484156407, 0.4612866067791993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 343}], {
             RGBColor[
             0.91983604495667, 0.6739551077819146, 0.4751295029148105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 359}], {
             RGBColor[
             0.9514837896604106, 0.9611256689561112, 0.8747939095613684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 403}], {
             RGBColor[
             0.8684251833169994, 0.8955159189410955, 0.8667074610489753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 440}], {
             RGBColor[
             0.9425369917886818, 0.7961831197118145, 0.4948215293690824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 445}], {
             RGBColor[
             0.9782801480279448, 0.9394045757914982, 0.5347896078268422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 463}], {
             RGBColor[
             0.7743003013960627, 0.8206490549360065, 0.8582392599813213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 471}], {
             RGBColor[
             0.9751390722082593, 0.9794426669377387, 0.8581518289048162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 483}], {
             RGBColor[
             0.7227411345359493, 0.7787563213495963, 0.8541899154691762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 190}], {
             RGBColor[
             0.20663037548476026`, 0.33451200412993914`, 0.9350786662503858]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 315}], {
             RGBColor[
             0.19006335492631857`, 0.31709901511324473`, 0.9341351989382931]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 349}], {
             RGBColor[
             0.19095597353932497`, 0.3180372138708033, 0.934186032247793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 353}], {
             RGBColor[
             0.1887122478968889, 0.3156789159601807, 0.9340582553917509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 364}], {
             RGBColor[
             0.20055433939420772`, 0.3281257049558297, 0.9347326449837188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 378}], {
             RGBColor[
             0.20184046362642588`, 0.32947750306887713`, 0.9348058878560932]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 380}], {
             RGBColor[
             0.19209288530033616`, 0.3192321802159951, 0.9342507776906723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 487}], {
             RGBColor[
             0.19472843618281724`, 0.32200231129706014`, 0.9344008684144816]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 128}], {
             RGBColor[
             0.1878451960142834, 0.31476758945729777`, 0.9340088780697248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 138}], {
             RGBColor[
             0.18210218513342014`, 0.30873132089358957`, 0.9336818220960829]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 179}], {
             RGBColor[
             0.19077318734493098`, 0.3178450939911811, 0.9341756228444302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 255}], {
             RGBColor[
             0.1893023656117655, 0.31629916709414013`, 0.9340918617226122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 294}], {
             RGBColor[
             0.18446317038438925`, 0.311212866087469, 0.9338162767133609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 296}], {
             RGBColor[
             0.18183178255671295`, 0.30844711064095676`, 0.9336664230693641]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 312}], {
             RGBColor[
             0.1882015984664733, 0.31514219103177, 0.9340291746621268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 327}], {
             RGBColor[
             0.18260674360457746`, 0.3092616438376308, 0.933710555954588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 334}], {
             RGBColor[
             0.18414474445457316`, 0.31087818024586233`, 0.9337981428277268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 385}], {
             RGBColor[
             0.18149489941754873`, 0.3080930251020705, 0.9336472380729627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 415}], {
             RGBColor[
             0.18091671513236096`, 0.30748531675933716`, 0.9336143113332682]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 446}], {
             RGBColor[
             0.18242070987008802`, 0.30906611058746236`, 0.933699961608621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 144}], {
             RGBColor[
             0.1939326542641488, 0.3211658940450518, 0.9343555498114672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 215}], {
             RGBColor[
             0.18797465353578718`, 0.3149036575204792, 0.9340162504840592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 223}], {
             RGBColor[
             0.1995856510144891, 0.3271075520503548, 0.9346774796135398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 268}], {
             RGBColor[
             0.18864406926620203`, 0.3156072558965539, 0.9340543727195945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 402}], {
             RGBColor[
             0.20455792141877943`, 0.3323337235054161, 0.9349606430572492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 417}], {
             RGBColor[
             0.19405888879625283`, 0.3212985745420247, 0.9343627386813232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 143}], {
             RGBColor[
             0.4285653763865951, 0.5391828000638526, 0.9495933114012363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 165}], {
             RGBColor[
             0.2912027626996634, 0.4234029452918576, 0.9398949385886397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 185}], {
             RGBColor[
             0.24400994073613447`, 0.3738002972104551, 0.9372073771933402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 187}], {
             RGBColor[
             0.24886259772016034`, 0.3789007473768896, 0.9374837288297179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 224}], {
             RGBColor[
             0.2412066178691736, 0.37085382713634363`, 0.9370477321032114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 277}], {
             RGBColor[
             0.35985275808300965`, 0.4831247951827711, 0.9442597110251651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 313}], {
             RGBColor[
             0.3188496851508186, 0.44760999428327536`, 0.9416470314755198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 333}], {
             RGBColor[
             0.2541335864563355, 0.3844408907385981, 0.937783903840514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 358}], {
             RGBColor[
             0.2506809998117433, 0.38081200326849496`, 0.9375872841387487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 361}], {
             RGBColor[
             0.25328984688463263`, 0.3835540669525598, 0.9377358541201064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 386}], {
             RGBColor[
             0.2910406970756628, 0.423232604045479, 0.9398857091911075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 441}], {
             RGBColor[
             0.24897326082313725`, 0.37901706131456436`, 0.9374900309297209]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 140}], {
             RGBColor[
             0.1812891715754636, 0.30787679209614044`, 0.933635522176703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 155}], {
             RGBColor[
             0.1887434182573529, 0.3157116779853434, 0.9340600304976668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 156}], {
             RGBColor[
             0.19147940284680726`, 0.31858737126030207`, 0.9342158407725099]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 198}], {
             RGBColor[
             0.18298777738438862`, 0.30966213449914926`, 0.9337322552646592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 270}], {
             RGBColor[
             0.18183894581371152`, 0.308454639678239, 0.933666831006253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 479}], {
             RGBColor[
             0.1829410540251313, 0.30961302528613777`, 0.9337295944384705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 152}], {
             RGBColor[
             0.1882232378558979, 0.3151649354020718, 0.9340304069933419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 187}], {
             RGBColor[
             0.20672865124829637`, 0.33461529818845887`, 0.9350842629097332]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.19015295783973063`, 0.31719319345639363`, 0.9341403016916563]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 255}], {
             RGBColor[
             0.19469073239539242`, 0.3219626822259184, 0.9343987212395655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 260}], {
             RGBColor[
             0.20098092756456265`, 0.3285740761701249, 0.9347569385489398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 292}], {
             RGBColor[
             0.188665488336347, 0.3156297686973238, 0.9340555925039526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 399}], {
             RGBColor[
             0.200045010570769, 0.32759036806908304`, 0.9347036394607084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 446}], {
             RGBColor[
             0.18780907665371493`, 0.3147296257192406, 0.9340068211255742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 464}], {
             RGBColor[
             0.1973325308094801, 0.3247393798588184, 0.9345491677510571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 481}], {
             RGBColor[
             0.1987399075504107, 0.32621862204637564`, 0.9346293157744259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 496}], {
             RGBColor[
             0.18901315212113398`, 0.315995185378292, 0.9340753914421738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 120}], {
             RGBColor[
             0.18211134871711507`, 0.30874095240105776`, 0.9336823439486179]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 124}], {
             RGBColor[
             0.18484388120986256`, 0.311613017303502, 0.9338379576316604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 363}], {
             RGBColor[
             0.18346622269800678`, 0.3101650108589469, 0.9337595020174734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 364}], {
             RGBColor[
             0.19435544195191212`, 0.32161027071117865`, 0.934379626944827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 381}], {
             RGBColor[
             0.18630903659373593`, 0.3131529885081697, 0.9339213960632688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 416}], {
             RGBColor[
             0.19677397614642037`, 0.32415230349353147`, 0.9345173588893034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 124}], {
             RGBColor[
             0.18263624540769638`, 0.3092926521032311, 0.9337122360386315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 315}], {
             RGBColor[
             0.18165682168185682`, 0.3082632156683228, 0.9336564593063725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 363}], {
             RGBColor[
             0.18125858689584057`, 0.307844645658676, 0.9336337804244444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 381}], {
             RGBColor[
             0.18410140079156978`, 0.3108326233078988, 0.9337956744702399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 196}], {
             RGBColor[
             0.19856429776732792`, 0.3260340450300523, 0.9346193150570707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.20367497522683542`, 0.331405691075661, 0.93491036057782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 307}], {
             RGBColor[
             0.1984527242001829, 0.32591677413681014`, 0.93461296110748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 337}], {
             RGBColor[
             0.19710919882017952`, 0.3245046437779975, 0.9345364493246566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 420}], {
             RGBColor[
             0.1965885249531354, 0.3239573825311042, 0.9345067977181964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 427}], {
             RGBColor[
             0.19582329677639237`, 0.3231530791990786, 0.9344632191055845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 442}], {
             RGBColor[
             0.22151836933651753`, 0.35016022962146637`, 0.9359265154754303]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 447}], {
             RGBColor[
             0.21943101242653507`, 0.34796628516300276`, 0.9358076435873746]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 454}], {
             RGBColor[
             0.20826238807822112`, 0.3362273528412414, 0.9351716069532372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 489}], {
             RGBColor[
             0.1983767553672155, 0.32583692607665915`, 0.9346086347948284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 500}], {
             RGBColor[
             0.20306057228198376`, 0.33075991462522525`, 0.9348753712390383]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 185}], {
             RGBColor[
             0.19860974920189184`, 0.3260818173695664, 0.9346219034490297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 212}], {
             RGBColor[
             0.18381215152445518`, 0.3105286039886985, 0.9337792021523836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 216}], {
             RGBColor[
             0.19279683115434215`, 0.3199720719413004, 0.9342908663656634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 217}], {
             RGBColor[
             0.1834604918576584, 0.31015898738238445`, 0.9337591756545935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 224}], {
             RGBColor[
             0.195806426334931, 0.3231353472954549, 0.9344622583589008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 286}], {
             RGBColor[
             0.1865372127264831, 0.3133928160908893, 0.9339343903564724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 319}], {
             RGBColor[
             0.1832707103845271, 0.30995951502128316`, 0.9337483678804552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 330}], {
             RGBColor[
             0.18762963037517022`, 0.3145410163029389, 0.9339966019254781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 357}], {
             RGBColor[
             0.18711144917701383`, 0.313996375009091, 0.9339670922728234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 492}], {
             RGBColor[
             0.1841436405662557, 0.3108770199892501, 0.9337980799629202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 139}], {
             RGBColor[
             0.1842229343035432, 0.31096036273465255`, 0.9338025956239542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 158}], {
             RGBColor[
             0.1887768797193095, 0.31574684810343895`, 0.9340619360784235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 193}], {
             RGBColor[
             0.18338517057960285`, 0.31007981994350325`, 0.9337548862192361]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 401}], {
             RGBColor[
             0.18328689846403934`, 0.309976529719234, 0.9337492897676354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 410}], {
             RGBColor[
             0.18404732868398718`, 0.3107757900944599, 0.9337925951437056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 422}], {
             RGBColor[
             0.1961933017960193, 0.3235419779343797, 0.9344842903440789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 428}], {
             RGBColor[
             0.18681025928894113`, 0.3136798053401847, 0.9339499399542682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 437}], {
             RGBColor[
             0.18388303382001714`, 0.3106031057755313, 0.9337832387942551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 363}], {
             RGBColor[
             0.1839911193885881, 0.3107167105611202, 0.9337893941074868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 381}], {
             RGBColor[
             0.18683393328431724`, 0.31370468821034303`, 0.9339512881532823]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 416}], {
             RGBColor[
             0.19729887283700168`, 0.3247040031957048, 0.934547250979317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.669539684263013, 0.7405244264891351, 0.9685478722425018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 173}], {
             RGBColor[
             0.7492734803038996, 0.8040574045935522, 0.9756442362240689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 242}], {
             RGBColor[
             0.8755313279725643, 0.9029638772422787, 0.9544497242112633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 249}], {
             RGBColor[
             0.7524497512082946, 0.8065387315646185, 0.9759608172238798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 269}], {
             RGBColor[
             0.6899118040266511, 0.7570634310667932, 0.970151640135829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 282}], {
             RGBColor[
             0.7373315894354715, 0.794728308685404, 0.9744539801456191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 305}], {
             RGBColor[
             0.5442522046967718, 0.6349340468295404, 0.9597558326180513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 310}], {
             RGBColor[
             0.7113812015825887, 0.7744556684644794, 0.9718674880046061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 323}], {
             RGBColor[
             0.8853299376421364, 0.9088564954320449, 0.8744890811044619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 406}], {
             RGBColor[
             0.5972259557238873, 0.6808172474310844, 0.9631312731906503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 408}], {
             RGBColor[
             0.8576169370417068, 0.8896033538181681, 0.9847741152357485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 419}], {
             RGBColor[
             0.7136180387569662, 0.7762031026656953, 0.9720904350297161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 173}], {
             RGBColor[
             0.6045267350947843, 0.6886225535376819, 0.9628291330052186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 249}], {
             RGBColor[
             0.6077030059991793, 0.6911038805087482, 0.9631457140050295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 269}], {
             RGBColor[
             0.5451650588175359, 0.6416285800109227, 0.9573365369169786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 282}], {
             RGBColor[
             0.5925848442263562, 0.6792934576295336, 0.9616388769267687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 340}], {
             RGBColor[
             0.4261246264730337, 0.5425553802981693, 0.948636879181104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 384}], {
             RGBColor[
             0.3782656319739345, 0.49734201260730226`, 0.9457250298186803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 414}], {
             RGBColor[
             0.45556143140572114`, 0.5680520611940277, 0.9505125663614704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 449}], {
             RGBColor[
             0.7360314578812237, 0.7759766732200013, 0.6718437842469422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 499}], {
             RGBColor[
             0.5585145617417738, 0.6524663078730726, 0.9583874586880152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 184}], {
             RGBColor[
             0.6864931860475436, 0.7535560913976342, 0.970424092580223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 221}], {
             RGBColor[
             0.8972130382069989, 0.8767030519388234, 0.6458996213784399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 253}], {
             RGBColor[
             0.604821677598294, 0.6851926412626169, 0.9645634759762418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 301}], {
             RGBColor[
             0.7442995113076243, 0.8002700424356418, 0.9751223810067287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 303}], {
             RGBColor[
             0.8364744443127496, 0.5917978023235237, 0.5852770137807005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 316}], {
             RGBColor[
             0.6354319607294284, 0.7117057299932411, 0.9665139361497471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 138}], {
             RGBColor[
             0.18851306554638397`, 0.31546956268090953`, 0.9340469122515535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 179}], {
             RGBColor[
             0.19718406775789482`, 0.32458333577850107`, 0.9345407129999008]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 222}], {
             RGBColor[
             0.19567917188119596`, 0.32300159479618107`, 0.9344550114060167]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 245}], {
             RGBColor[
             0.21909064595633707`, 0.347608538422344, 0.9357882602204238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 294}], {
             RGBColor[
             0.1908740507973531, 0.317951107874789, 0.9341813668688315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 296}], {
             RGBColor[
             0.1882426629696768, 0.3151853524282767, 0.9340315132248347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 312}], {
             RGBColor[
             0.19461247887943717`, 0.32188043281908996`, 0.9343942648175974]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 385}], {
             RGBColor[
             0.1879057798305126, 0.31483126688939045`, 0.9340123282284333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 415}], {
             RGBColor[
             0.1873275955453248, 0.3142235585466571, 0.9339794014887388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 438}], {
             RGBColor[
             0.19844895166515433`, 0.32591280896330255`, 0.9346127462671912]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 439}], {
             RGBColor[
             0.1967431917255388, 0.32411994711534, 0.9345156057620757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 204}], {
             RGBColor[
             0.3026394845996296, 0.4347619361650844, 0.9405704721210151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 275}], {
             RGBColor[
             0.3893440856753081, 0.5088837722097477, 0.9463652522390695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 276}], {
             RGBColor[
             0.2514871752437865, 0.381659344762047, 0.9376331946369739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 306}], {
             RGBColor[
             0.2650729238792713, 0.39593882796415625`, 0.9384068829234508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 331}], {
             RGBColor[
             0.2954052676483876, 0.42782004444717026`, 0.9401342650284206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 346}], {
             RGBColor[
             0.36539555977117477`, 0.4891180942666259, 0.9445692337379277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 348}], {
             RGBColor[
             0.37572812244985154`, 0.497829719871169, 0.9452933537370448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 355}], {
             RGBColor[
             0.4245428223807357, 0.5374596923522321, 0.9491362257297418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 431}], {
             RGBColor[
             0.35531389648617895`, 0.48038586424829277`, 0.9439268390682725]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 444}], {
             RGBColor[
             0.42761995292876165`, 0.539957845554271, 0.9493784687183828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 486}], {
             RGBColor[
             0.3513552004898414, 0.47695704074611134`, 0.9436745944599232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 175}], {
             RGBColor[
             0.350298253723786, 0.4772937364222603, 0.943561398674819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 182}], {
             RGBColor[
             0.323958117743938, 0.4544792345302443, 0.9418830285018508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 208}], {
             RGBColor[
             0.3647668975032984, 0.4898257484488929, 0.9444833278623301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 238}], {
             RGBColor[
             0.39480407867420486`, 0.5149363424561325, 0.9466476293366854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 241}], {
             RGBColor[
             0.2592745192308342, 0.38984433703856036`, 0.9380766723566932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 351}], {
             RGBColor[
             0.2715547401921379, 0.40275162787986996`, 0.9387760127734806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 371}], {
             RGBColor[
             0.27850064570472033`, 0.41005221496943967`, 0.9391715718168758]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 442}], {
             RGBColor[
             0.2704116943765009, 0.4015502142543449, 0.9387109180052648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 483}], {
             RGBColor[
             0.3774799425420655, 0.5008371490852502, 0.9452933918504961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 186}], {
             RGBColor[
             0.913526249632497, 0.6241954645463874, 0.3472925437386266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 234}], {
             RGBColor[
             0.88005378670787, 0.5030425365640092, 0.21977647609763581`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 373}], {
             RGBColor[
             0.9123644303428394, 0.625404830056993, 0.48937807328246297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 434}], {
             RGBColor[
             0.8844045850628767, 0.520292002224005, 0.22327723058043727`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 449}], {
             RGBColor[
             0.9086679607710296, 0.6083135329493521, 0.2853739255705805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 495}], {
             RGBColor[
             0.8599106722287021, 0.41795803680078086`, 0.20329863351297417`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 250}], {
             RGBColor[
             0.24597806511608875`, 0.3758689207200801, 0.9373194589651996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 356}], {
             RGBColor[
             0.2588153820462965, 0.38936175474663237`, 0.9380505251732665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 365}], {
             RGBColor[
             0.23967912019619636`, 0.3692483302330984, 0.9369607433704656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 457}], {
             RGBColor[
             0.37078286929344473`, 0.4917742570671961, 0.9450898009992874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 494}], {
             RGBColor[
             0.3138085366833637, 0.4428585774611083, 0.9413399116919258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 191}], {
             RGBColor[
             0.19428859491049005`, 0.32154001023229684`, 0.9343758201047092]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 237}], {
             RGBColor[
             0.21543537025685555`, 0.3437666119043239, 0.9355800976768341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 241}], {
             RGBColor[
             0.2068052594645497, 0.3346958182809826, 0.9350886256343172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 271}], {
             RGBColor[
             0.20303817120051487`, 0.3307363696682909, 0.9348740955305881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 304}], {
             RGBColor[
             0.19434480354761932`, 0.3215990890737532, 0.9343790211034406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 311}], {
             RGBColor[
             0.19398258593487913`, 0.3212183753968402, 0.9343583933462479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 351}], {
             RGBColor[
             0.21908548042585338`, 0.34760310912229214`, 0.9357879660511045]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 366}], {
             RGBColor[
             0.1902687027163505, 0.3173148486603702, 0.9341468931911505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 371}], {
             RGBColor[
             0.22603138593843586`, 0.35490369621186185`, 0.9361835250944996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 405}], {
             RGBColor[
             0.18981989868512106`, 0.3168431271677289, 0.9341213344655181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 423}], {
             RGBColor[
             0.18859024302857952`, 0.3155506811080321, 0.9340513073949906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 429}], {
             RGBColor[
             0.19496484613925177`, 0.3222507931505298, 0.9344143316117632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 469}], {
             RGBColor[
             0.18966655655355485`, 0.31668195486500017`, 0.9341126018579748]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 488}], {
             RGBColor[
             0.19025464326071956`, 0.31730007128108106`, 0.9341460925259515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 174}], {
             RGBColor[
             0.18580423451035571`, 0.31262240951223635`, 0.9338926483314081]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 210}], {
             RGBColor[
             0.18982747480213708`, 0.31685109014706625`, 0.9341217659141743]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 225}], {
             RGBColor[
             0.1840482113903489, 0.31077671787481287`, 0.933792645412527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 247}], {
             RGBColor[
             0.1842053003124589, 0.3109418282919634, 0.933801591394249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 252}], {
             RGBColor[
             0.18321908491971373`, 0.3099052533845207, 0.9337454278866071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 278}], {
             RGBColor[
             0.18429769316254274`, 0.3110389390354465, 0.9338068530303782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 309}], {
             RGBColor[
             0.18616361548114224`, 0.31300014169860263`, 0.9339131145460378]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 424}], {
             RGBColor[
             0.18880157011833354`, 0.31577279927827495`, 0.9340633421601217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 169}], {
             RGBColor[
             0.1819041358977289, 0.3085231585898313, 0.9336705434850978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 211}], {
             RGBColor[
             0.18373947818140363`, 0.31045221969739534`, 0.9337750635130075]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 362}], {
             RGBColor[
             0.1796163784049865, 0.3061185804127562, 0.9335402590803201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 369}], {
             RGBColor[
             0.18101136995755066`, 0.307584804982074, 0.9336197017855334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 466}], {
             RGBColor[
             0.18744105358565671`, 0.3143428101407012, 0.9339858627562896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 470}], {
             RGBColor[
             0.18730486737300778`, 0.31419966979650255`, 0.9339781071529487]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 240}], {
             RGBColor[
             0.7615140918759296, 0.8095862292350475, 0.8160223615071904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 434}], {
             RGBColor[
             0.7316510467407765, 0.7040970288480641, 0.6113123490612679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 148}], {
             RGBColor[
             0.24314559520540308`, 0.3728918152549845, 0.9371581539940498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 156}], {
             RGBColor[
             0.2055253114742025, 0.33335051178973785`, 0.9350157344897803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 227}], {
             RGBColor[
             0.2024073413896048, 0.33007332754010427`, 0.9348381707060858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 229}], {
             RGBColor[
             0.2232482662355424, 0.35197846094413987`, 0.9360250305446766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 263}], {
             RGBColor[
             0.21799699214111928`, 0.34645903892089325`, 0.935725978253563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 265}], {
             RGBColor[
             0.19798921213274367`, 0.325429593565569, 0.934586564780944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 267}], {
             RGBColor[
             0.22045636616771785`, 0.34904399695616795`, 0.93586603596606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 280}], {
             RGBColor[
             0.2325647771126936, 0.3617707045769326, 0.9365555920565876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 393}], {
             RGBColor[
             0.21648582185917808`, 0.3448707031408432, 0.9356399193415825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 424}], {
             RGBColor[
             0.20256381379959026`, 0.3302377899639228, 0.9348470815783543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 485}], {
             RGBColor[
             0.2335003285987162, 0.3627540285061326, 0.9366088703296922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 179}], {
             RGBColor[
             0.19144105687703156`, 0.31854706721479287`, 0.9342136570262589]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 222}], {
             RGBColor[
             0.1899361610003327, 0.31696532623247287`, 0.9341279554323748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 294}], {
             RGBColor[
             0.18513103991648983`, 0.3119148393110808, 0.9338543108951896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 296}], {
             RGBColor[
             0.18249965208881352`, 0.3091490838645686, 0.9337044572511928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 339}], {
             RGBColor[
             0.1814781394477339, 0.3080754093111516, 0.9336462836174759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 385}], {
             RGBColor[
             0.18216276894964933`, 0.30879499832568225`, 0.9336852722547914]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 415}], {
             RGBColor[
             0.18158458466446153`, 0.308187289982949, 0.9336523455150969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 438}], {
             RGBColor[
             0.19270594078429107`, 0.3198765403995944, 0.9342856902935492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 158}], {
             RGBColor[
             0.18715334052902155`, 0.3140404054761162, 0.9339694779233476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 247}], {
             RGBColor[
             0.18343934894517555`, 0.310136764840827, 0.9337579715970057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 278}], {
             RGBColor[
             0.18353174179525936`, 0.31023387558431004`, 0.933763233233135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 401}], {
             RGBColor[
             0.18166335927375138`, 0.3082700870919113, 0.9336568316125594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 410}], {
             RGBColor[
             0.18242378949369925`, 0.3090693474671371, 0.9337001369886297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 428}], {
             RGBColor[
             0.1851867200986532, 0.311973362712862, 0.9338574817991923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 437}], {
             RGBColor[
             0.18225949462972918`, 0.3088966631482086, 0.9336907806391791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 451}], {
             RGBColor[
             0.19384306282883684`, 0.3210717277661138, 0.9343504477117648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 198}], {
             RGBColor[
             0.18071298100430727`, 0.3072711792732629, 0.9336027089760732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 270}], {
             RGBColor[
             0.1795641494336302, 0.30606368445235266`, 0.9335372847176671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 479}], {
             RGBColor[
             0.18066625764504995`, 0.3072220700602514, 0.9336000481498845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 151}], {
             RGBColor[
             0.20551109996107267`, 0.3333355745883765, 0.9350149251651315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 160}], {
             RGBColor[
             0.2233789267066098, 0.352115793383584, 0.936032471465209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 162}], {
             RGBColor[
             0.19531753931264573`, 0.32262149603780554`, 0.9344344169662252]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 167}], {
             RGBColor[
             0.22358607838206196`, 0.35233352292865905`, 0.9360442684466725]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 235}], {
             RGBColor[
             0.21221346212045616`, 0.34038018217219357`, 0.9353966147748521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 274}], {
             RGBColor[
             0.2256966978230941, 0.35455191778218553`, 0.9361644651014577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 284}], {
             RGBColor[
             0.20706959880896725`, 0.33497365569204784`, 0.9351036793689267]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 300}], {
             RGBColor[
             0.21958614921582648`, 0.3481293437647886, 0.9358164783980203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 345}], {
             RGBColor[
             0.19907503548324326`, 0.3265708627521209, 0.9346484008144234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 389}], {
             RGBColor[
             0.20111521708192343`, 0.32871522296731825`, 0.9347645861382899]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 432}], {
             RGBColor[
             0.24927102921021138`, 0.3793300347689854, 0.937506988398856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 456}], {
             RGBColor[
             0.20146025215418084`, 0.3290778767047479, 0.9347842353752214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 472}], {
             RGBColor[
             0.19522243291560842`, 0.32252153318442556`, 0.9344290007976113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[
             0.2155365862389103, 0.34387299631892737`, 0.9355858617772765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 161}], {
             RGBColor[
             0.21478163330642375`, 0.3430794929201034, 0.9355428683246243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 183}], {
             RGBColor[
             0.20633874170827649`, 0.3342054785402052, 0.9350620581382485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 254}], {
             RGBColor[
             0.20407108545370353`, 0.33182202803893834`, 0.9349329184692474]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 285}], {
             RGBColor[
             0.2150502131881199, 0.3433617874047141, 0.9355581635515585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 388}], {
             RGBColor[
             0.27220031221012625`, 0.4015863957278337, 0.9388802865699359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 396}], {
             RGBColor[
             0.2065755605048984, 0.3344543901106338, 0.9350755446183742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 473}], {
             RGBColor[
             0.23965328121814944`, 0.36922117182888525`, 0.9369592718788913]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 477}], {
             RGBColor[
             0.2067532217668407, 0.3346411233613098, 0.9350856621644155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 165}], {
             RGBColor[
             0.4432891969739572, 0.5546584690453142, 0.950431811201746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 178}], {
             RGBColor[
             0.5249805981564001, 0.6252419255466224, 0.9557475422356184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 186}], {
             RGBColor[
             0.7869875185761387, 0.829282852672385, 0.7373913878754195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 277}], {
             RGBColor[
             0.5119391923573035, 0.6143803189362278, 0.9547965836382715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 288}], {
             RGBColor[
             0.6459376056374727, 0.7223853584829198, 0.9659909719465696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 313}], {
             RGBColor[
             0.4709361194251123, 0.5788655180367319, 0.9521839040886261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 321}], {
             RGBColor[
             0.78304348190439, 0.8293416997957703, 0.9255854595882844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 373}], {
             RGBColor[
             0.7858256992864812, 0.8304922181829903, 0.8794769174192558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 386}], {
             RGBColor[
             0.4431271313499566, 0.5544881277989356, 0.9504225818042138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 414}], {
             RGBColor[
             0.5016592032391687, 0.6054763090493759, 0.9541415518219014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 498}], {
             RGBColor[
             0.6776190672953443, 0.7471351571180758, 0.9691486839645342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 145}], {
             RGBColor[
             0.20296158096381922`, 0.33065586847342227`, 0.9348697338299133]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 215}], {
             RGBColor[
             0.19092068807717077`, 0.3180001266128517, 0.9341840227929235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 246}], {
             RGBColor[
             0.21838885852257034`, 0.34687091533356196`, 0.9357482944642723]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 375}], {
             RGBColor[
             0.1998107076045579, 0.3273441007959291, 0.9346902962534028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 402}], {
             RGBColor[
             0.20750395596016302`, 0.3354301925977886, 0.9351284153661135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 417}], {
             RGBColor[
             0.19700492333763642`, 0.3243950436343972, 0.9345305109901875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 458}], {
             RGBColor[
             0.21795043797046626`, 0.346410107535832, 0.935723327062415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 367}], {
             RGBColor[
             0.2030970423728074, 0.33079824700301824`, 0.9348774481567581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 375}], {
             RGBColor[
             0.20589359976284474`, 0.33373760613192704`, 0.9350367079629848]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 402}], {
             RGBColor[
             0.21358684811844986`, 0.34182369793378664`, 0.9354748270756954]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 417}], {
             RGBColor[
             0.20308781549592325`, 0.3307885489703952, 0.9348769226997694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 450}], {
             RGBColor[
             0.21228550631692578`, 0.340455905190549, 0.9354007175852613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 458}], {
             RGBColor[
             0.2240333301287531, 0.35280361287183004`, 0.936069738771997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 461}], {
             RGBColor[
             0.23115805437216275`, 0.3602921497852615, 0.9364754812775742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 166}], {
             RGBColor[
             0.18787743892822623`, 0.31480147880417053`, 0.9340107142559747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 239}], {
             RGBColor[
             0.18835872742063176`, 0.3153073435251416, 0.9340381229236147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 248}], {
             RGBColor[
             0.18017302617267333`, 0.306703652510102, 0.9335719593472032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 387}], {
             RGBColor[
             0.18448194243535776`, 0.3112325967032537, 0.9338173457538927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 221}], {
             RGBColor[
             0.8906777697244648, 0.5160364512426465, 0.23692570222520362`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 234}], {
             RGBColor[
             0.872729313424225, 0.4467434253012546, 0.2127625522094079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 242}], {
             RGBColor[
             0.8960966123696098, 0.5635667746530044, 0.5481508384278233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 303}], {
             RGBColor[
             0.8299391758302155, 0.23113120162734693`, 0.17630309462746424`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 323}], {
             RGBColor[
             0.905895222039182, 0.5694593928427707, 0.46819019532102185`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 449}], {
             RGBColor[
             0.9013434874873846, 0.5520144216865974, 0.2783600016823526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 229}], {
             RGBColor[
             0.25473807623061007`, 0.385076247818226, 0.9378183286388965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 232}], {
             RGBColor[
             0.27654750718772436`, 0.40799934255194237`, 0.9390603434677424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 263}], {
             RGBColor[
             0.24948680213618696`, 0.3795568257949794, 0.9375192763477829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 267}], {
             RGBColor[
             0.25194617616278553`, 0.3821417838302541, 0.9376593340602799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 280}], {
             RGBColor[
             0.2640545871077613, 0.39486849145101877`, 0.9383488901508075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 342}], {
             RGBColor[
             0.3754741855106375, 0.4958604756469023, 0.9454338500155093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 393}], {
             RGBColor[
             0.24797563185424576`, 0.37796849001492944`, 0.9374332174358024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 480}], {
             RGBColor[
             0.25899827885189075`, 0.38955399088563913`, 0.9380609408757734]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 485}], {
             RGBColor[
             0.26499013859378384`, 0.39585181538021874`, 0.9384021684239121]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 173}], {
             RGBColor[
             0.6408634071546884, 0.7181223008643338, 0.9656896889353898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 242}], {
             RGBColor[
             0.767121254823353, 0.8170287735130601, 0.9444951769225841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 249}], {
             RGBColor[
             0.6440396780590834, 0.7206036278354, 0.9660062699352006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 269}], {
             RGBColor[
             0.5815017308774398, 0.6711283273375747, 0.9601970928471498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 282}], {
             RGBColor[
             0.6289215162862603, 0.7087932049561856, 0.9644994328569398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 310}], {
             RGBColor[
             0.6029711284333774, 0.688520564735261, 0.9619129407159268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 314}], {
             RGBColor[
             0.41196878637874557`, 0.5240737659037882, 0.9484356108143341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 323}], {
             RGBColor[
             0.7769198644929252, 0.8229213917028264, 0.8645345338157826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 406}], {
             RGBColor[
             0.48881588257467606`, 0.5948821437018659, 0.9531767259019711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 411}], {
             RGBColor[
             0.4211694508709569, 0.5337442476409241, 0.9489595750460023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 419}], {
             RGBColor[
             0.6052079656077549, 0.6902679989364768, 0.962135887741037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 220}], {
             RGBColor[
             0.21619691693173887`, 0.3445670457444743, 0.9356234666333614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 254}], {
             RGBColor[
             0.20389499448692971`, 0.33163694526804693`, 0.9349228903491928]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 325}], {
             RGBColor[
             0.2244980131258032, 0.35329202416433336`, 0.9360962017812421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 392}], {
             RGBColor[
             0.22610554162039614`, 0.3549816385353439, 0.9361877481508839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 412}], {
             RGBColor[
             0.20280807626052344`, 0.33049452529749807`, 0.9348609919641505]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 426}], {
             RGBColor[
             0.20135872025195078`, 0.3289711602380097, 0.9347784532835923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 473}], {
             RGBColor[
             0.23947719025137565`, 0.36903608905799384`, 0.9369492437588367]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 160}], {
             RGBColor[
             0.22158100780321188`, 0.3502260666214703, 0.9359300826434431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 162}], {
             RGBColor[
             0.1935196204092478, 0.32073176927569186`, 0.9343320281444594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 226}], {
             RGBColor[
             0.19534643528489967`, 0.3226518675367549, 0.9344360625490973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 235}], {
             RGBColor[
             0.21041554321705824`, 0.3384904554100799, 0.9352942259530863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 237}], {
             RGBColor[
             0.2183016735730191, 0.3467792784237385, 0.9357433294103739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 274}], {
             RGBColor[
             0.22389877891969617`, 0.3526621910200718, 0.9360620762796918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 284}], {
             RGBColor[
             0.20527167990556933`, 0.33308392892993416`, 0.9350012905471609]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 345}], {
             RGBColor[
             0.19727711657984534`, 0.32468113599000714`, 0.9345460119926574]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 389}], {
             RGBColor[
             0.1993172981785255, 0.3268254962052045, 0.9346621973165241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 456}], {
             RGBColor[
             0.19966233325078292`, 0.32718814994263423`, 0.9346818465534554]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 472}], {
             RGBColor[
             0.1934245140122105, 0.3206318064223118, 0.9343266119758453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 195}], {
             RGBColor[
             0.18616514652705513`, 0.313001750924931, 0.9339132017368377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 216}], {
             RGBColor[
             0.19207526490404528`, 0.31921366006229573`, 0.9342497742351705]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 217}], {
             RGBColor[
             0.18273892560736155`, 0.30940057550337985`, 0.9337180835241007]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 292}], {
             RGBColor[
             0.18467767702367152`, 0.3114383261658612, 0.9338284925491338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 398}], {
             RGBColor[
             0.19524728601816377`, 0.32254765537098895`, 0.934430416145035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 399}], {
             RGBColor[
             0.19605719925809356`, 0.3233989255376204, 0.9344765395058896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 464}], {
             RGBColor[
             0.19334471949680462`, 0.32054793732735576`, 0.9343220677962385]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 481}], {
             RGBColor[
             0.1947520962377352, 0.322027179514913, 0.9344022158196071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 496}], {
             RGBColor[
             0.1850253408084585, 0.31180374284682943`, 0.9338482914873549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 172}], {
             RGBColor[
             0.22556462734887084`, 0.3544131033400252, 0.9361569438833315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 197}], {
             RGBColor[
             0.22926543037868818`, 0.35830288196882765`, 0.9363676991410321]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 201}], {
             RGBColor[
             0.2425444285480653, 0.37225995098195497`, 0.9371239184422607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 223}], {
             RGBColor[
             0.21791092009915627`, 0.34636857174750746`, 0.9357210765781054]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 236}], {
             RGBColor[
             0.21799828044158207`, 0.3464603930063626, 0.9357260516203685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 289}], {
             RGBColor[
             0.21885506273912853`, 0.34736092552421916`, 0.935774844104718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 314}], {
             RGBColor[
             0.24522255976789442`, 0.3750748366973221, 0.93727643405329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 411}], {
             RGBColor[
             0.2544232242601058, 0.38474531843445803`, 0.937800398284958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 466}], {
             RGBColor[
             0.2112617016772801, 0.3393798216013181, 0.9353424134256167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 470}], {
             RGBColor[
             0.2111255154646311, 0.3392366812571194, 0.9353346578222758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 493}], {
             RGBColor[
             0.24427091854425903`, 0.3740746014337428, 0.9372222394934309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 199}], {
             RGBColor[
             0.684800695862128, 0.748031110338605, 0.9293475993147051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[
             0.9142690676811895, 0.6673158743356673, 0.5518317374650853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 219}], {
             RGBColor[
             0.8264967277029731, 0.8644743578312362, 0.9402829367923042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 244}], {
             RGBColor[
             0.7150943787471429, 0.7742699758488314, 0.9312778860004862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 295}], {
             RGBColor[
             0.9841314996436169, 0.9875855475713144, 0.9072523679449918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 341}], {
             RGBColor[
             0.9888822096717337, 0.9887006265396945, 0.7667739089616505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 374}], {
             RGBColor[
             0.9154556938707563, 0.6764368032115899, 0.5529680520443171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 376}], {
             RGBColor[
             0.6772879972861523, 0.7415239884313045, 0.9288688968046623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 397}], {
             RGBColor[
             0.9027384271430544, 0.5786863184006587, 0.5407899830637712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 455}], {
             RGBColor[
             0.7982558492888101, 0.8419633098945049, 0.937775174104184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 198}], {
             RGBColor[
             0.1881672276861966, 0.31510606516246586`, 0.934027217297037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 250}], {
             RGBColor[
             0.2067822292135854, 0.3346716120270169, 0.9350873140955949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 365}], {
             RGBColor[
             0.200483284293693, 0.3280510215400352, 0.934728598500861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 394}], {
             RGBColor[
             0.1886886358497215, 0.3156540982015175, 0.9340569107205956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 467}], {
             RGBColor[
             0.19253479608250443`, 0.31969665646681583`, 0.9342759438559683]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 479}], {
             RGBColor[
             0.18812050432693928`, 0.3150569559494543, 0.9340245564708484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 198}], {
             RGBColor[
             0.19090321227565094`, 0.31798175843742454`, 0.93418302757188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 227}], {
             RGBColor[
             0.1962768676534719, 0.3236298109489438, 0.9344890492960363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 250}], {
             RGBColor[
             0.20951821380303975`, 0.3375473053019756, 0.9352431243704379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 263}], {
             RGBColor[
             0.21186651840498638`, 0.34001552232973276`, 0.9353768568435135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 270}], {
             RGBColor[
             0.18975438070497386`, 0.3167742636165143, 0.9341176033134739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 479}], {
             RGBColor[
             0.19085648891639362`, 0.317932649224413, 0.9341803667456914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 485}], {
             RGBColor[
             0.22736985486258326`, 0.3563105119149721, 0.9362597489196426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 190}], {
             RGBColor[
             0.2578198120642154, 0.3883153475726824, 0.9379938289356007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 356}], {
             RGBColor[
             0.272205938145604, 0.40343607821729777`, 0.9388130975335695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 360}], {
             RGBColor[
             0.44762961538947754`, 0.5573651742459853, 0.9508478770838158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.2086123729274203, 0.33659520910807084`, 0.9351915380726428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 193}], {
             RGBColor[
             0.1863155768050812, 0.3131598626849669, 0.9339217685186295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 247}], {
             RGBColor[
             0.18799329436094186`, 0.3149232502096133, 0.9340173120514751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 278}], {
             RGBColor[
             0.18808568721102567`, 0.3150203609530965, 0.9340225736876044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 370}], {
             RGBColor[
             0.21023358203312498`, 0.3382992026687606, 0.9352838635328488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 401}], {
             RGBColor[
             0.1862173046895177, 0.3130565724606977, 0.9339161720670288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 410}], {
             RGBColor[
             0.18697773490946556`, 0.31385583283592355`, 0.933959477443099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 422}], {
             RGBColor[
             0.19912370802149765`, 0.3266220206758434, 0.9346511726434723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 428}], {
             RGBColor[
             0.1897406655144195, 0.31675984808164837`, 0.9341168222536617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 437}], {
             RGBColor[
             0.1868134400454955, 0.31368314851699497`, 0.9339501210936485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 451}], {
             RGBColor[
             0.19839700824460316`, 0.32585821313490027`, 0.9346097881662341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 166}], {
             RGBColor[
             0.21389899734106987`, 0.3421517865581641, 0.9354926035121403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 192}], {
             RGBColor[
             0.27255273720121065`, 0.4034082682269394, 0.9388472119027095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 239}], {
             RGBColor[
             0.2143802858334754, 0.34265765127913517`, 0.9355200121797802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 251}], {
             RGBColor[
             0.23552312226059172`, 0.3648801128972894, 0.936724065436281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 272}], {
             RGBColor[
             0.24467152920527638`, 0.37449566863865497`, 0.9372450536779255]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 344}], {
             RGBColor[
             0.2111960256367822, 0.3393107919186533, 0.9353386732722694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 435}], {
             RGBColor[
             0.23525737339525699`, 0.3646007939903714, 0.9367089314315404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 439}], {
             RGBColor[
             0.21567326392113564`, 0.34401665322881175`, 0.9355936453690827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 453}], {
             RGBColor[
             0.23602331412857852`, 0.36540584626453976`, 0.9367525506231953]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 167}], {
             RGBColor[
             0.2396559862242012, 0.36922401496175294`, 0.9369594259249842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 235}], {
             RGBColor[
             0.22828336996259535`, 0.35727067420528746`, 0.9363117722531638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 237}], {
             RGBColor[
             0.23616950031855627`, 0.3655594972189461, 0.9367608757104513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 274}], {
             RGBColor[
             0.24176660566523328`, 0.3714424098152794, 0.9370796225797693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 284}], {
             RGBColor[
             0.22313950665110643`, 0.35186414772514174`, 0.9360188368472383]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 300}], {
             RGBColor[
             0.2356560570579657, 0.36501983579788244`, 0.936731635876332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 305}], {
             RGBColor[
             0.2750017432650342, 0.40620742442870245`, 0.938978437324221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 389}], {
             RGBColor[
             0.21718512492406264`, 0.34560571500041215`, 0.9356797436166016]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 432}], {
             RGBColor[
             0.26534093705235057`, 0.3962205268020793, 0.9384221458771677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 460}], {
             RGBColor[
             0.27006121839103014`, 0.4011818417721542, 0.938690958916375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 183}], {
             RGBColor[
             0.2054076978090161, 0.33322689237048986`, 0.9350090365655417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 188}], {
             RGBColor[
             0.2189136351360459, 0.34742248882708376`, 0.9357781797160722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 202}], {
             RGBColor[
             0.2003053984953046, 0.32786405228731785`, 0.9347184681678012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 243}], {
             RGBColor[
             0.20521495427576572`, 0.33302430669639793`, 0.9349980601064616]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 273}], {
             RGBColor[
             0.20050467294518176`, 0.3280735023688687, 0.9347298165529216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 279}], {
             RGBColor[
             0.21091668232154126`, 0.339017184382946, 0.9353227650837177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 285}], {
             RGBColor[
             0.21411916928885952`, 0.34238320123499877`, 0.9355051419788516]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 287}], {
             RGBColor[
             0.25900221419710867`, 0.3895581271829785, 0.9380611649878617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 335}], {
             RGBColor[
             0.21211283365491676`, 0.3402744152746985, 0.9353908841326062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 354}], {
             RGBColor[
             0.262219161885439, 0.39276906224398844`, 0.9382506002184958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 396}], {
             RGBColor[
             0.205644516605638, 0.33347580394091847`, 0.9350225230456672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 409}], {
             RGBColor[
             0.23354210119449076`, 0.36279793415282724`, 0.9366112492172245]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 430}], {
             RGBColor[
             0.2077033952850149, 0.33563981597339154`, 0.9351397731406197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 459}], {
             RGBColor[
             0.20416528068413636`, 0.3319210331984458, 0.9349382827482713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 477}], {
             RGBColor[
             0.2058221778675803, 0.33366253719159444`, 0.9350326405917087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 226}], {
             RGBColor[
             0.18515287463647273`, 0.3119377889861841, 0.933855554350191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 284}], {
             RGBColor[
             0.19507811925714236`, 0.3223698503793633, 0.9344207823482545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 345}], {
             RGBColor[
             0.1870835559314184, 0.31396705743943626`, 0.9339655037937511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 389}], {
             RGBColor[
             0.18912373753009853`, 0.3161114176546337, 0.9340816891176178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 456}], {
             RGBColor[
             0.18946877260235598`, 0.3164740713920633, 0.9341013383545491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 472}], {
             RGBColor[
             0.18323095336378353`, 0.30991772787174093`, 0.933746103776939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 207}], {
             RGBColor[
             0.8871477729139166, 0.5804462187569267, 0.227545674269207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 209}], {
             RGBColor[
             0.9468923206889115, 0.8138245711399055, 0.48945082932663964`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 231}], {
             RGBColor[
             0.8314832405552138, 0.7254800292683178, 0.607385428867296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 233}], {
             RGBColor[
             0.9309329686428551, 0.8036306761921264, 0.5929788217369941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 266}], {
             RGBColor[
             0.9464459539298948, 0.8121746039800857, 0.3903304044915068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 317}], {
             RGBColor[
             0.8583137676007231, 0.3848962000432028, 0.20095545620474106`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 326}], {
             RGBColor[
             0.8123452824001817, 0.7105293109037376, 0.6054779360527895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 343}], {
             RGBColor[
             0.8727695735845509, 0.4960098594094768, 0.21479835234035222`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 355}], {
             RGBColor[
             0.7295091887885554, 0.6445510453124249, 0.5980872339837272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 379}], {
             RGBColor[
             0.8633665292005046, 0.42373393983337493`, 0.2057939864189699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 440}], {
             RGBColor[
             0.8954705204165625, 0.6182378713393768, 0.2344903787946242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 180}], {
             RGBColor[
             0.28958519225458484`, 0.42102975172188783`, 0.9398274630675963]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 205}], {
             RGBColor[
             0.2767533263359414, 0.40754264705410376`, 0.9390967072865741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 259}], {
             RGBColor[
             0.4996492818256195, 0.6003222503432779, 0.9552118903262334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 316}], {
             RGBColor[
             0.37736919780669476`, 0.5012799648379501, 0.9452666094831315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 331}], {
             RGBColor[
             0.3087300351184425, 0.44115219542494855`, 0.940917733546436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 348}], {
             RGBColor[
             0.38905288991990644`, 0.5111618708489473, 0.9460768222550604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 372}], {
             RGBColor[
             0.4651482668210734, 0.5729395258749782, 0.9520673290712703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 404}], {
             RGBColor[
             0.5764261418930885, 0.6604370522196931, 0.9628281641033989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 418}], {
             RGBColor[
             0.3962653140595378, 0.5170172416815048, 0.9466446107033122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 431}], {
             RGBColor[
             0.36863866395623385`, 0.49371801522607117`, 0.9447103075862879]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 444}], {
             RGBColor[
             0.4409447203988165, 0.5532899965320492, 0.9501619372363984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 486}], {
             RGBColor[
             0.3646799679598963, 0.49028919172388963`, 0.9444580629779388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 178}], {
             RGBColor[
             0.3876179844694684, 0.5094620707746275, 0.9460491694230218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 185}], {
             RGBColor[
             0.2587337613234965, 0.38927596619191684`, 0.93804587699385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 277}], {
             RGBColor[
             0.37457657867037175`, 0.49860046416423287`, 0.9450982108256749]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 288}], {
             RGBColor[
             0.508574991950541, 0.6066055037109249, 0.956292599133973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 313}], {
             RGBColor[
             0.3335735057381806, 0.4630856632647371, 0.9424855312760294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 333}], {
             RGBColor[
             0.26885740704369754`, 0.3999165597200598, 0.9386224036410238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 358}], {
             RGBColor[
             0.26540482039910535`, 0.39628767224995665`, 0.9384257839392585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 361}], {
             RGBColor[
             0.26801366747199473`, 0.39902973593402147`, 0.9385743539206161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 386}], {
             RGBColor[
             0.3057645176630249, 0.43870827302694076`, 0.9407242089916171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 498}], {
             RGBColor[
             0.5402564536084126, 0.6313553023460808, 0.9594503111519376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.19616306235610437`, 0.3235101943657379, 0.9344825682527109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 344}], {
             RGBColor[
             0.19297880215941118`, 0.32016333500525607`, 0.9343012293452001]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 387}], {
             RGBColor[
             0.19228627737083037`, 0.31943544754385, 0.934261791082989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 435}], {
             RGBColor[
             0.21704014991788595`, 0.3454533370769741, 0.9356714875044712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 439}], {
             RGBColor[
             0.19745604044376464`, 0.3248691963154145, 0.9345562014420135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 453}], {
             RGBColor[
             0.2178060906512075, 0.3462583893511425, 0.935715106696126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 172}], {
             RGBColor[
             0.23167761735264775`, 0.36083824341994686`, 0.9365050696206882]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[
             0.2486574185518422, 0.37868509106187664`, 0.9374720441796176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 218}], {
             RGBColor[
             0.26286988224919927`, 0.3936232915300437, 0.9382814229617262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 235}], {
             RGBColor[
             0.22849052163804753`, 0.3574884037503625, 0.9363235692346273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 236}], {
             RGBColor[
             0.22411127044535895`, 0.3528855330862843, 0.9360741773577252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 274}], {
             RGBColor[
             0.24197375734068546`, 0.3716601393603544, 0.9370914195612329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 284}], {
             RGBColor[
             0.22334665832655862`, 0.3520818772702168, 0.9360306338287019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 289}], {
             RGBColor[
             0.2249680527429054, 0.35378606560414083`, 0.9361229698420748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 300}], {
             RGBColor[
             0.23586320873341787`, 0.3652375653429575, 0.9367434328577955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 305}], {
             RGBColor[
             0.27520889494048634`, 0.4064251539737775, 0.9389902343056846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 432}], {
             RGBColor[
             0.2655480887278028, 0.39643825634715435`, 0.9384339428586312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 456}], {
             RGBColor[
             0.21773731167177224`, 0.3461860982829168, 0.9357111898349966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 493}], {
             RGBColor[
             0.25038390854803594`, 0.3804997415136645, 0.9375703652307877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 181}], {
             RGBColor[
             0.25911497354415575`, 0.3896766444060805, 0.9380675864658636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 189}], {
             RGBColor[
             0.272342262398906, 0.403579363650975, 0.9388208609981212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 232}], {
             RGBColor[
             0.28558604817661837`, 0.417499422207868, 0.9395750750057368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 280}], {
             RGBColor[
             0.2730931280966553, 0.40436857110694446`, 0.9388636216888019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 302}], {
             RGBColor[
             0.268736668858344, 0.3997896562320101, 0.9386155277799839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 326}], {
             RGBColor[
             0.509047258388588, 0.6051914915809957, 0.9566219374301776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 338}], {
             RGBColor[
             0.35852241644491945`, 0.4834734222788186, 0.944119987452004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 346}], {
             RGBColor[
             0.3670639021674008, 0.4908716279040769, 0.9446642433693013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 370}], {
             RGBColor[
             0.2607361826498604, 0.3913806379667703, 0.9381599119260695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 383}], {
             RGBColor[
             0.2802434761765292, 0.4118840402971449, 0.9392708234339586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 390}], {
             RGBColor[
             0.27431313717116323`, 0.40565087799729527`, 0.9389330994007534]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 395}], {
             RGBColor[
             0.3984267572015211, 0.5166565922466431, 0.9470439450191381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 443}], {
             RGBColor[
             0.29027458230294984`, 0.42242736884487553`, 0.9398420800881666]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 480}], {
             RGBColor[
             0.26803681984078476`, 0.3990540705415648, 0.9385756724137677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 211}], {
             RGBColor[
             0.1856477523702797, 0.3124579368614757, 0.9338837369050252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 236}], {
             RGBColor[
             0.19608590653883476`, 0.32342909870982617`, 0.9344781743430592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 289}], {
             RGBColor[
             0.19694268883638122`, 0.3243296312276827, 0.9345269668274088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 308}], {
             RGBColor[
             0.18735840295715342`, 0.31425593908979166`, 0.9339811559252671]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 362}], {
             RGBColor[
             0.18152465259386255`, 0.3081242975768366, 0.9336489324723378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 369}], {
             RGBColor[
             0.1829196441464267, 0.30959052214615446`, 0.9337283751775514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 456}], {
             RGBColor[
             0.18971194776524802`, 0.31672966390645874`, 0.9341151868203305]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 470}], {
             RGBColor[
             0.1892131415618838, 0.316205386960583, 0.9340867805449665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 214}], {
             RGBColor[
             0.18764009951956995`, 0.31455202003748506`, 0.9339971981277639]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 223}], {
             RGBColor[
             0.19795986022643686`, 0.3253987428510222, 0.9345848932333021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 268}], {
             RGBColor[
             0.18701827847814975`, 0.31389844669722133`, 0.9339617863393568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 466}], {
             RGBColor[
             0.19131064180456064`, 0.3184099927048328, 0.9342062300808134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 491}], {
             RGBColor[
             0.18468093358720655`, 0.3114417490206145, 0.9338286780056095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 192}], {
             RGBColor[
             0.3918420426717766, 0.5133437939110442, 0.9463191721078775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 208}], {
             RGBColor[
             0.44865476640412644`, 0.5625521197174839, 0.9499392286265838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 219}], {
             RGBColor[
             0.5701105988481052, 0.6614643237945504, 0.9595848784963202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 238}], {
             RGBColor[
             0.47869194757503297`, 0.5876627137247235, 0.9521035301009391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 258}], {
             RGBColor[
             0.44293779831735625`, 0.5576003693038944, 0.9495749484754112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 272}], {
             RGBColor[
             0.36396083467584234`, 0.48443119432275983`, 0.9447170138830936]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 293}], {
             RGBColor[
             0.6402218599260903, 0.7162357738139922, 0.9665729137735878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 403}], {
             RGBColor[
             0.6070518602239434, 0.6903231179453404, 0.9632668381945488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 471}], {
             RGBColor[
             0.7137657491152036, 0.7742498659419835, 0.9547112060503897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 497}], {
             RGBColor[
             0.47443851953832683`, 0.5842095892297761, 0.9517686846650694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 197}], {
             RGBColor[
             0.22719289983545946`, 0.3561245209618682, 0.9362496715926294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 201}], {
             RGBColor[
             0.2404718980048366, 0.3700815899749955, 0.9370058908938581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 211}], {
             RGBColor[
             0.20548759572979827`, 0.33331087015105276`, 0.9350135866339319]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 218}], {
             RGBColor[
             0.25468436170219366`, 0.3850197904431626, 0.9378152696759667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 235}], {
             RGBColor[
             0.22030500109104192`, 0.3488849026634814, 0.9358574159488678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 236}], {
             RGBColor[
             0.21592574989835334`, 0.34428203199940316`, 0.9356080240719657]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 289}], {
             RGBColor[
             0.2167825321958998, 0.3451825645172597, 0.9356568165563153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 300}], {
             RGBColor[
             0.22767768818641226`, 0.35663406425607636`, 0.936277279572036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 308}], {
             RGBColor[
             0.207198246316672, 0.3351088723793687, 0.9351110056541736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 314}], {
             RGBColor[
             0.24315002922466572`, 0.37289647569036266`, 0.9371584065048872]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 466}], {
             RGBColor[
             0.20918917113405136`, 0.3372014605943586, 0.935224385877214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 470}], {
             RGBColor[
             0.2090529849214024, 0.33705832025015997`, 0.9352166302738731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 493}], {
             RGBColor[
             0.24219838800103033`, 0.3718962404267834, 0.9371042119450282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 242}], {
             RGBColor[
             0.8468550508642396, 0.8805617516174773, 0.9515915409041512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 249}], {
             RGBColor[
             0.72377347409997, 0.7841366059398172, 0.9731026339167677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 269}], {
             RGBColor[
             0.6612355269183264, 0.7346613054419917, 0.9672934568287169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 282}], {
             RGBColor[
             0.7086553123271468, 0.7723261830606026, 0.9715957968385069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 310}], {
             RGBColor[
             0.682704924474264, 0.7520535428396782, 0.9690093046974939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 323}], {
             RGBColor[
             0.8566536605338118, 0.8864543698072436, 0.8716308977973497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 406}], {
             RGBColor[
             0.5685496786155626, 0.658415121806283, 0.9602730898835382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 419}], {
             RGBColor[
             0.6849417616486415, 0.753800977040894, 0.9692322517226041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 499}], {
             RGBColor[
             0.6745850298425644, 0.7454990333041416, 0.9683443785997534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 210}], {
             RGBColor[
             0.19150041146467078`, 0.3186094526497, 0.9342170371822176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 225}], {
             RGBColor[
             0.18572114805288265`, 0.3125350803774465, 0.9338879166805704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 252}], {
             RGBColor[
             0.18489202158224743`, 0.3116636158871544, 0.9338406991546504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 309}], {
             RGBColor[
             0.18783655214367595`, 0.3147585042012363, 0.9340083858140811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 320}], {
             RGBColor[
             0.1843078028000945, 0.31104956490550145`, 0.933807428759281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 393}], {
             RGBColor[
             0.20439651484045512`, 0.33216407495782907`, 0.9349514511913933]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 424}], {
             RGBColor[
             0.19047450678086728`, 0.3175311617809086, 0.934158613428165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 182}], {
             RGBColor[
             0.3713372775098073, 0.4960554186499155, 0.9448822608556314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 208}], {
             RGBColor[
             0.41214605726916764`, 0.531401932568564, 0.9474825602161108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 351}], {
             RGBColor[
             0.3189338999580072, 0.4443278119995411, 0.9417752451272612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 359}], {
             RGBColor[
             0.653601757432396, 0.7247826808114364, 0.9688966182964689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 371}], {
             RGBColor[
             0.32587980547058965`, 0.4516283990891108, 0.9421708041706565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 463}], {
             RGBColor[
             0.476418269168048, 0.5843060667913316, 0.9523419687164218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 483}], {
             RGBColor[
             0.4248591023079348, 0.5424133332049215, 0.9482926242042767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 178}], {
             RGBColor[
             0.3931214338805177, 0.5144895563820213, 0.9463902997884908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 244}], {
             RGBColor[
             0.38182757506705056`, 0.5051415871363136, 0.945550693339773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 261}], {
             RGBColor[
             0.32311312036066653`, 0.4542860775439437, 0.941809460205036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 262}], {
             RGBColor[
             0.33005042418212294`, 0.46029482143506084`, 0.9422514990701223]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 299}], {
             RGBColor[
             0.2785034431297019, 0.4092981665779968, 0.9391994481892236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 313}], {
             RGBColor[
             0.3390769551492299, 0.46811314887213096`, 0.9428266616414984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 328}], {
             RGBColor[
             0.27995998628272956`, 0.4108290857819987, 0.939282396167026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 376}], {
             RGBColor[
             0.34402119360606, 0.47239559971878675`, 0.9431417041439492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 391}], {
             RGBColor[
             0.3950241069319744, 0.5160342320796381, 0.9465400851808224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 407}], {
             RGBColor[
             0.2970315342752855, 0.4287723651208341, 0.94025459557011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 448}], {
             RGBColor[
             0.3087587670403855, 0.44109843030645696`, 0.9409224441271964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 455}], {
             RGBColor[
             0.46498904560871784`, 0.5728349211819872, 0.9520479814434708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 475}], {
             RGBColor[
             0.3267310397254062, 0.4574197374557666, 0.9420399908277568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 478}], {
             RGBColor[
             0.2831235992471345, 0.4141542435922354, 0.9394625592452028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 482}], {
             RGBColor[
             0.3246527382525704, 0.45561961717846555`, 0.9419075632956775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 194}], {
             RGBColor[
             0.1852447118397448, 0.312034315709638, 0.9338607843430564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 290}], {
             RGBColor[
             0.1829544926129004, 0.3096271500939387, 0.9337303597461633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 297}], {
             RGBColor[
             0.18982245259063335`, 0.3168458114843493, 0.9341214799066588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 412}], {
             RGBColor[
             0.1873190234343715, 0.314214548714542, 0.9339789133197014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 484}], {
             RGBColor[
             0.18459712642978363`, 0.31135366238448237`, 0.9338239053119759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 186}], {
             RGBColor[
             0.7313163060716499, 0.7840864544016981, 0.7330087460966953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 244}], {
             RGBColor[
             0.45801552683844415`, 0.5706975580302278, 0.9505252940081765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 261}], {
             RGBColor[
             0.3993010721320601, 0.5198420484378579, 0.9467840608734395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 288}], {
             RGBColor[
             0.5902663931329839, 0.677188960212233, 0.9616083301678455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 313}], {
             RGBColor[
             0.4152649069206235, 0.5336691197660451, 0.9478012623099019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 321}], {
             RGBColor[
             0.7273722693999012, 0.7841453015250835, 0.9212028178095601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 391}], {
             RGBColor[
             0.47121205870336796`, 0.5815902029735522, 0.9515146858492259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 407}], {
             RGBColor[
             0.3732194860466791, 0.4943283360147483, 0.9452291962385135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 455}], {
             RGBColor[
             0.5411769973801115, 0.6383908920759014, 0.9570225821118743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 475}], {
             RGBColor[
             0.40291899149679977`, 0.5229757083496808, 0.9470145914961603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 498}], {
             RGBColor[
             0.6219478547908555, 0.7019387588473889, 0.96476604218581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 222}], {
             RGBColor[
             0.19860716321184355`, 0.3260790993300644, 0.9346217561807222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 245}], {
             RGBColor[
             0.22201863728698465`, 0.35068604295622735`, 0.9359550049951293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 255}], {
             RGBColor[
             0.19864123735537692`, 0.32611491341534343`, 0.9346236966527881]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 294}], {
             RGBColor[
             0.19380204212800067`, 0.3210286124086723, 0.9343481116435368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 296}], {
             RGBColor[
             0.19117065430032437`, 0.31826285696216006`, 0.9341982579995401]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 312}], {
             RGBColor[
             0.19754047021008475`, 0.3249579373529733, 0.9345610095923028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 327}], {
             RGBColor[
             0.1919456153481889, 0.3190773901588341, 0.9342423908847639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 334}], {
             RGBColor[
             0.1934836161981846, 0.32069392656706563`, 0.9343299777579028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 385}], {
             RGBColor[
             0.19083377116116018`, 0.3179087714232738, 0.9341790730031387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 415}], {
             RGBColor[
             0.19025558687597238`, 0.31730106308054046`, 0.9341461462634442]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 438}], {
             RGBColor[
             0.20137694299580192`, 0.3289903134971859, 0.9347794910418965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 205}], {
             RGBColor[
             0.2503131812646099, 0.38042540265441493`, 0.9375663374166283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 230}], {
             RGBColor[
             0.2345216927400936, 0.3638275469769471, 0.9366670355065708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 331}], {
             RGBColor[
             0.2822898900471109, 0.4140349510252597, 0.9393873636764902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 382}], {
             RGBColor[
             0.23760741054514092`, 0.36707083203586066`, 0.9368427625706579]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 413}], {
             RGBColor[
             0.24672751485063993`, 0.37665663990895104`, 0.9373621390188708]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 418}], {
             RGBColor[
             0.3698251689882062, 0.48989999728181594`, 0.9451142408333664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 474}], {
             RGBColor[
             0.24632928568632426`, 0.37623807580806795`, 0.9373394604570903]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 490}], {
             RGBColor[
             0.23955648296360244`, 0.3691194307259925, 0.9369537593614949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 189}], {
             RGBColor[
             0.238744748764803, 0.3682662466161335, 0.9369075322997265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 302}], {
             RGBColor[
             0.235139155224241, 0.3644765391971686, 0.9367021990815891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 370}], {
             RGBColor[
             0.2271386690157574, 0.35606752093192884`, 0.9362465832276747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 390}], {
             RGBColor[
             0.24071562353706022`, 0.37033776096245374`, 0.9370197707023586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 422}], {
             RGBColor[
             0.2160287950041301, 0.3443903389390116, 0.9356138923382982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 443}], {
             RGBColor[
             0.2566770686688468, 0.387114251810034, 0.9379287513897718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 451}], {
             RGBColor[
             0.21530209522723562`, 0.3436265313980684, 0.93557250786106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 237}], {
             RGBColor[
             0.2889436538091614, 0.4176768128895569, 0.9398890065800227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 351}], {
             RGBColor[
             0.2925937639781592, 0.42151331010752513`, 0.9400968749542931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 359}], {
             RGBColor[
             0.6272616214525479, 0.7019681789194203, 0.9672182481235007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 371}], {
             RGBColor[
             0.29953966949074173`, 0.42881389719709484`, 0.9404924339976882]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 460}], {
             RGBColor[
             0.32283537188163536`, 0.453299157442765, 0.9418190897859463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 463}], {
             RGBColor[
             0.4500781331882001, 0.5614915648993155, 0.9506635985434537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 483}], {
             RGBColor[
             0.3985189663280868, 0.5195988313129054, 0.9466142540313085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 202}], {
             RGBColor[
             0.19186250689715728`, 0.31899003790741964`, 0.9342376579814256]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 206}], {
             RGBColor[
             0.1886895173788014, 0.31565502474447266`, 0.9340569609223726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 243}], {
             RGBColor[
             0.19677206267761843`, 0.3241502923164997, 0.9345172499200859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 273}], {
             RGBColor[
             0.19206178134703447`, 0.31919948798897047`, 0.934249006366546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 279}], {
             RGBColor[
             0.202473790723394, 0.3301431700030478, 0.9348419548973421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 283}], {
             RGBColor[
             0.18964111329673894`, 0.31665521238889094`, 0.9341111529021391]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 285}], {
             RGBColor[
             0.20567627769071223`, 0.33350918685510056`, 0.935024331792476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 396}], {
             RGBColor[
             0.19720162500749072`, 0.32460178956102026`, 0.9345417128592917]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 430}], {
             RGBColor[
             0.19926050368686765`, 0.32676580159349333`, 0.9346589629542441]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 477}], {
             RGBColor[
             0.19737928626943302`, 0.32478852281169623`, 0.934551830405333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 221}], {
             RGBColor[
             0.7515553610831588, 0.7612606169042988, 0.6324712276878893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 253}], {
             RGBColor[
             0.4591640004744537, 0.5697502062280924, 0.9511350822856912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 287}], {
             RGBColor[
             0.42249467395537876`, 0.5375645019893394, 0.9488140910567393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 301}], {
             RGBColor[
             0.5986418341837841, 0.6848276074011173, 0.9616939873161781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 316}], {
             RGBColor[
             0.4897742836055883, 0.5962632949587165, 0.9530855424591965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 336}], {
             RGBColor[
             0.5830930532515349, 0.672420234529121, 0.9603223675736445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 354}], {
             RGBColor[
             0.425711621643709, 0.5407754370503493, 0.9490035262873733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 388}], {
             RGBColor[
             0.43476172806913593`, 0.5486141843644792, 0.9495801910661066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 436}], {
             RGBColor[
             0.4481781977283561, 0.5602348560519236, 0.9504350766490738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 473}], {
             RGBColor[
             0.4022146970771591, 0.5162489604655307, 0.9476591763750619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 187}], {
             RGBColor[
             0.21639359634399347`, 0.34477376827694883`, 0.9356346672349283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 216}], {
             RGBColor[
             0.20572802131241785`, 0.3335635726822483, 0.9350272785151843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 224}], {
             RGBColor[
             0.2087376164930067, 0.33672684803640285`, 0.9351986705084218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 286}], {
             RGBColor[
             0.1994684028845588, 0.32698431683183726`, 0.9346708025059933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 330}], {
             RGBColor[
             0.20056082053324595`, 0.3281325170438868, 0.934733014074999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 333}], {
             RGBColor[
             0.22166458508016862`, 0.3503139116386572, 0.9359348422457243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 357}], {
             RGBColor[
             0.20004263933508956`, 0.3275878757500389, 0.9347035044223444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 358}], {
             RGBColor[
             0.21821199843557637`, 0.3466850241685541, 0.935738222543959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 361}], {
             RGBColor[
             0.22082084550846576`, 0.3494270878526189, 0.9358867925253167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 386}], {
             RGBColor[
             0.25857169569949595`, 0.38910562494553824`, 0.9380366475963178]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 398}], {
             RGBColor[
             0.20890004242653637`, 0.3368975679909415, 0.9352079204250486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 441}], {
             RGBColor[
             0.21650425944697038`, 0.34489008221462353`, 0.9356409693349313]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 464}], {
             RGBColor[
             0.2069974759051772, 0.3348978499473083, 0.9350995720762522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 481}], {
             RGBColor[
             0.2084048526461078, 0.33637709213486555`, 0.9351797200996208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 288}], {
             RGBColor[
             0.8522733135527225, 0.8812298873379956, 0.7432521758076465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 295}], {
             RGBColor[
             0.9890595681546568, 0.9880540568784736, 0.7081436215924831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 321}], {
             RGBColor[
             0.9893791898196398, 0.9881862286508462, 0.7028466634493613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 341}], {
             RGBColor[
             0.9938102781827736, 0.9891691358468536, 0.5676651626091419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 373}], {
             RGBColor[
             0.9921614072017308, 0.9893367470380662, 0.6567381212803327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 397}], {
             RGBColor[
             0.9076664956540943, 0.5791548277078178, 0.3416812367112626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 455}], {
             RGBColor[
             0.8031839177998501, 0.842431819201664, 0.7386664277516752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 495}], {
             RGBColor[
             0.9397076490875935, 0.7818899537818541, 0.3706586815108439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 498}], {
             RGBColor[
             0.8839547752105941, 0.9059796859731515, 0.7464098878256111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 216}], {
             RGBColor[
             0.21058067829644372`, 0.3386640228486828, 0.9353036301515618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 224}], {
             RGBColor[
             0.2135902734770326, 0.34182729820283736`, 0.9354750221447994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 260}], {
             RGBColor[
             0.21549852964428565`, 0.3438329964250494, 0.9355836945105124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 328}], {
             RGBColor[
             0.2321163718921772, 0.36129940225963686`, 0.9365300560426353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 398}], {
             RGBColor[
             0.21375269941056224`, 0.341998018157376, 0.9354842720614263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 399}], {
             RGBColor[
             0.214562612650492, 0.3428492883240075, 0.9355303954222809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 407}], {
             RGBColor[
             0.24918791988473313`, 0.3792426815984722, 0.9375022554457193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 464}], {
             RGBColor[
             0.21185013288920307`, 0.3399983001137429, 0.9353759237126298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 478}], {
             RGBColor[
             0.2352799848565821, 0.36462456006987354`, 0.9367102191208121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 481}], {
             RGBColor[
             0.21325750963013368`, 0.3414775423013001, 0.9354560717359984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 200}], {
             RGBColor[
             0.24347605986022197`, 0.37323915455986845`, 0.937176973467263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 228}], {
             RGBColor[
             0.24109668028529843`, 0.37073827576524543`, 0.9370414713204478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 256}], {
             RGBColor[
             0.26776710539076976`, 0.3985106384029728, 0.9385698304401877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 279}], {
             RGBColor[
             0.21597972805042376`, 0.3443387664596417, 0.9356110980478727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 298}], {
             RGBColor[
             0.24983259130122784`, 0.37992027213173674`, 0.9375389685291828]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 318}], {
             RGBColor[
             0.21097876418895464`, 0.3390824363618151, 0.935326300554225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 335}], {
             RGBColor[
             0.21717587938379926`, 0.3455959973513941, 0.9356792170967612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 409}], {
             RGBColor[
             0.23860514692337326`, 0.3681195162295229, 0.9368995821813795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 430}], {
             RGBColor[
             0.2127664410138974, 0.34096139805008724`, 0.9354281061047747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 459}], {
             RGBColor[
             0.20922832641301886`, 0.3372426152751415, 0.9352266157124262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 302}], {
             RGBColor[
             0.24836644407899122`, 0.3783792584420631, 0.9374554736138468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 346}], {
             RGBColor[
             0.346693677388048, 0.46946123011413, 0.9435041892031641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 370}], {
             RGBColor[
             0.24036595787050763`, 0.36997024017682334`, 0.9369998577599323]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 383}], {
             RGBColor[
             0.25987325139717643`, 0.39047364250719796`, 0.9381107692678216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 390}], {
             RGBColor[
             0.25394291239181044`, 0.3842404802073483, 0.9377730452346162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 422}], {
             RGBColor[
             0.22925608385888036`, 0.3582930581839061, 0.936367166870556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 443}], {
             RGBColor[
             0.2699043575235971, 0.40101697105492856`, 0.9386820259220295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 451}], {
             RGBColor[
             0.22852938408198586`, 0.3575292506429629, 0.9363257823933178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 349}], {
             RGBColor[
             0.20086956962021285`, 0.3284570319101118, 0.9347505968787484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 378}], {
             RGBColor[
             0.21175405970731373`, 0.3398973211081856, 0.9353704524870488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 467}], {
             RGBColor[
             0.20384534758574807`, 0.33158476322710967`, 0.9349200630316166]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 487}], {
             RGBColor[
             0.2046420322637051, 0.3324221293363686, 0.9349654330454369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 226}], {
             RGBColor[
             0.18878815245387853`, 0.31575869646220367`, 0.9340625780439806]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 237}], {
             RGBColor[
             0.21174339074199797`, 0.3398861073491872, 0.9353698449052572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 271}], {
             RGBColor[
             0.19934619168565726`, 0.3268558651131542, 0.9346638427590112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 311}], {
             RGBColor[
             0.19029060642002155`, 0.31733787084170345`, 0.934148140574671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 366}], {
             RGBColor[
             0.18657672320149288`, 0.31343434410523346`, 0.9339366404195737]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 405}], {
             RGBColor[
             0.18612791917026347`, 0.3129626226125922, 0.9339110816939413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 423}], {
             RGBColor[
             0.1848982635137219, 0.3116701765528954, 0.9338410546234137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 429}], {
             RGBColor[
             0.1912728666243942, 0.31837028859539307`, 0.9342040788401863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 488}], {
             RGBColor[
             0.18656266374586195`, 0.3134195667259444, 0.9339358397543747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 219}], {
             RGBColor[
             0.49125780976030897`, 0.5936378228658237, 0.9544300827546521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 251}], {
             RGBColor[
             0.2759596386433615, 0.40698913765266753`, 0.9390412298997809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 258}], {
             RGBColor[
             0.36408500922956, 0.4897738683751677, 0.944420152733743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 272}], {
             RGBColor[
             0.28510804558804614`, 0.41660469339403305`, 0.9395622181414255]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 435}], {
             RGBColor[
             0.2756938897780267, 0.40670981874574946`, 0.9390260958950403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 453}], {
             RGBColor[
             0.27645983051134826`, 0.4075148710199178, 0.9390697150866952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 497}], {
             RGBColor[
             0.3955857304505306, 0.5163830883010493, 0.9466138889234013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 410}], {
             RGBColor[
             0.1815860257697589, 0.30818880467598786`, 0.9336524275839118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 428}], {
             RGBColor[
             0.18434895637471288`, 0.31109281992171267`, 0.9338097723944743]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 437}], {
             RGBColor[
             0.18142173090578886`, 0.3080161203570593, 0.933643071234461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 220}], {
             RGBColor[
             0.20157018632549908`, 0.32919342448903244`, 0.9347904959636448]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 254}], {
             RGBColor[
             0.18926826388068996`, 0.3162633240126051, 0.9340899196794763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 290}], {
             RGBColor[
             0.18381681483281254`, 0.31053350542145297`, 0.9337794677208959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 297}], {
             RGBColor[
             0.1906847748105455, 0.3177521668118635, 0.9341705878813915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 350}], {
             RGBColor[
             0.18381567245253283`, 0.31053230470734794`, 0.9337794026640289]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 377}], {
             RGBColor[
             0.1834493331063201, 0.31014725882722227`, 0.9337585401802126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 412}], {
             RGBColor[
             0.18818134565428368`, 0.3151209040420562, 0.934028021294434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 426}], {
             RGBColor[
             0.18673198964571103`, 0.31359753898256787`, 0.9339454826138758]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 476}], {
             RGBColor[
             0.18476853282621936`, 0.3115338213749295, 0.9338336666526799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.19263264106654965`, 0.3197994977487777, 0.9342815159830611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 260}], {
             RGBColor[
             0.1989228362357199, 0.32641089169298415`, 0.9346397332924354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 292}], {
             RGBColor[
             0.18660739700750423`, 0.31346658422018303`, 0.9339383872474483]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 399}], {
             RGBColor[
             0.19798691924192627`, 0.3254271835919423, 0.9345864342042041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 446}], {
             RGBColor[
             0.1857509853248722, 0.31256644124209987`, 0.9338896158690699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 496}], {
             RGBColor[
             0.18695506079229124`, 0.31383200090115126`, 0.9339581861856694]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 213}], {
             RGBColor[
             0.19710682911621347`, 0.3245021530688812, 0.9345363143735214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 332}], {
             RGBColor[
             0.18931192738265673`, 0.3163092171215981, 0.934092406251319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 337}], {
             RGBColor[
             0.19054105270955757`, 0.3176011057712177, 0.934162403120358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 420}], {
             RGBColor[
             0.19002037884251344`, 0.3170538445243244, 0.9341327515138979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 427}], {
             RGBColor[
             0.18925515066577042`, 0.3162495411922988, 0.9340891729012859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 447}], {
             RGBColor[
             0.2128628663159131, 0.341062747156223, 0.9354335973830761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 454}], {
             RGBColor[
             0.20169424196759916`, 0.3293238148344616, 0.9347975607489386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 489}], {
             RGBColor[
             0.19180860925659354`, 0.31893338806987936`, 0.9342345885905299]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 500}], {
             RGBColor[
             0.1964924261713618, 0.32385637661844546`, 0.9345013250347398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 201}], {
             RGBColor[
             0.2441727010346539, 0.373971368603798, 0.9372166461515588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 236}], {
             RGBColor[
             0.21962655292817068`, 0.3481718106282057, 0.9358187793296664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 289}], {
             RGBColor[
             0.22048333522571711`, 0.34907234314606217`, 0.9358675718140159]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 314}], {
             RGBColor[
             0.24685083225448304`, 0.3767862543191651, 0.9373691617625879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 411}], {
             RGBColor[
             0.25605149674669436`, 0.3864567360563011, 0.937893125994256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 466}], {
             RGBColor[
             0.21288997416386868`, 0.3410912392231611, 0.9354351411349147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 470}], {
             RGBColor[
             0.2127537879512197, 0.3409480988789625, 0.9354273855315738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 493}], {
             RGBColor[
             0.24589919103084765`, 0.37578601905558584`, 0.9373149672027289]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 270}], {
             RGBColor[
             0.1812627552425552, 0.3078490268553615, 0.9336340178056233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 479}], {
             RGBColor[
             0.18236486345397498`, 0.30900741246326024`, 0.9336967812378407]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 244}], {
             RGBColor[
             0.4164279851399622, 0.5351107232742938, 0.9477554008736777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 245}], {
             RGBColor[
             0.31502975887018714`, 0.4412915516820689, 0.9415138332017744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 262}], {
             RGBColor[
             0.36465083425503464`, 0.49026395757304103`, 0.944456206604027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 376}], {
             RGBColor[
             0.3786216036789717, 0.5023647358567669, 0.9453464116778538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 448}], {
             RGBColor[
             0.3433591771132972, 0.47106756644443715`, 0.943127151661101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 455}], {
             RGBColor[
             0.4995894556816295, 0.6028040573199673, 0.9542526889773754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 475}], {
             RGBColor[
             0.3613314497983178, 0.4873888735937467, 0.9442446983616614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 482}], {
             RGBColor[
             0.35925314832548205`, 0.4855887533164457, 0.9441122708295822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 228}], {
             RGBColor[
             0.26059605928059204`, 0.3912333594213344, 0.9381519321074836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 256}], {
             RGBColor[
             0.28726648438606334`, 0.4190057220590618, 0.9396802912272235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 298}], {
             RGBColor[
             0.26933197029652145`, 0.4004153557878257, 0.9386494293162186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 452}], {
             RGBColor[
             0.24489188267224044`, 0.3747272741036509, 0.9372576024818854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 468}], {
             RGBColor[
             0.2422384711696754, 0.37193837037844896`, 0.9371064946221849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 218}], {
             RGBColor[
             0.27166416290138806`, 0.4028666380850924, 0.938782244234896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 235}], {
             RGBColor[
             0.23728480229023638`, 0.36673175030541116`, 0.9368243905077971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 236}], {
             RGBColor[
             0.2329055510975478, 0.36212887964133295`, 0.9365749986308951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 289}], {
             RGBColor[
             0.23376233339509425`, 0.3630294121591895, 0.9366237911152446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 300}], {
             RGBColor[
             0.24465748938560672`, 0.37448091189800614`, 0.9372442541309653]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 305}], {
             RGBColor[
             0.2840031755926752, 0.41566850052882615`, 0.9394910555788545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 314}], {
             RGBColor[
             0.2601298304238602, 0.39074332333229245`, 0.9381253810638166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 406}], {
             RGBColor[
             0.33697692661979073`, 0.46155170113037025`, 0.9428664961514535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 493}], {
             RGBColor[
             0.2591781892002248, 0.38974308806871316`, 0.9380711865039575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 243}], {
             RGBColor[
             0.1916697633639069, 0.3187874522333277, 0.9342266815223454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 273}], {
             RGBColor[
             0.18695948203332297`, 0.31383664790579846`, 0.9339584379688055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 279}], {
             RGBColor[
             0.19737149140968246`, 0.32478032991987577`, 0.9345513864996016]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 283}], {
             RGBColor[
             0.1845388139830274, 0.3112923723057189, 0.9338205845043986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 285}], {
             RGBColor[
             0.2005739783770007, 0.32814634677192855`, 0.9347337633947355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 396}], {
             RGBColor[
             0.1920993256937792, 0.31923894947784826`, 0.9342511444615511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 421}], {
             RGBColor[
             0.18554846728188248`, 0.31235358193853213`, 0.9338780827661202]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 430}], {
             RGBColor[
             0.19415820437315612`, 0.32140296151032133`, 0.9343683945565036]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 459}], {
             RGBColor[
             0.19062008977227754`, 0.3176841787353756, 0.9341669041641552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 477}], {
             RGBColor[
             0.19227698695572149`, 0.31942568272852423`, 0.9342612620075925]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 264}], {
             RGBColor[
             0.8553074725725389, 0.4148947299646385, 0.20015613150748274`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 281}], {
             RGBColor[
             0.8317474856787275, 0.2450306635294393, 0.1780347341805933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 295}], {
             RGBColor[
             0.9149334778554977, 0.6677110589938393, 0.5462140209685634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 324}], {
             RGBColor[
             0.8924019068162066, 0.6510073815667528, 0.588847136940535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 341}], {
             RGBColor[
             0.9196841878836145, 0.6688261379622193, 0.4057355619852222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 374}], {
             RGBColor[
             0.8462576720826371, 0.35656231463411475`, 0.19192970506788876`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 397}], {
             RGBColor[
             0.8335404053549352, 0.2588118298231834, 0.1797516360873429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 275}], {
             RGBColor[
             0.402607767889131, 0.5221630142088122, 0.9471448284585735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 306}], {
             RGBColor[
             0.2783366060930942, 0.40921806996322074`, 0.9391864591429547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 331}], {
             RGBColor[
             0.3086689498622105, 0.44109928644623464`, 0.9409138412479245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 346}], {
             RGBColor[
             0.3786592419849977, 0.5023973362656904, 0.9453488099574316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 348}], {
             RGBColor[
             0.38899180466367445`, 0.5111089618702334, 0.9460729299565488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 355}], {
             RGBColor[
             0.4378065045945586, 0.5507389343512965, 0.9499158019492457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 390}], {
             RGBColor[
             0.2859084769887601, 0.4171765863589087, 0.9396176659888837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 431}], {
             RGBColor[
             0.36857757870000185`, 0.49366510624735727`, 0.9447064152877764]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 444}], {
             RGBColor[
             0.44088363514258455`, 0.5532370875533353, 0.9501580449378868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 486}], {
             RGBColor[
             0.3646188827036643, 0.4902362827451757, 0.9444541706794272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 230}], {
             RGBColor[
             0.22168982682145016`, 0.35034044230916306`, 0.9359362797255486]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 331}], {
             RGBColor[
             0.26945802412846753`, 0.40054784635747565`, 0.938656607895468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 382}], {
             RGBColor[
             0.22477554462649751`, 0.3535837273680766, 0.9361120067896356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 413}], {
             RGBColor[
             0.2338956489319965, 0.363169535241167, 0.9366313832378486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 474}], {
             RGBColor[
             0.23349741976768085`, 0.3627509711402839, 0.936608704676068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 490}], {
             RGBColor[
             0.22672461704495903`, 0.3556323260582085, 0.9362230035804727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 254}], {
             RGBColor[
             0.18642186112422848`, 0.31327157424320573`, 0.9339278212533714]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 377}], {
             RGBColor[
             0.18060293034985866`, 0.30715550905782296`, 0.9335964417541076]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 396}], {
             RGBColor[
             0.18892633617542332`, 0.3159039363149012, 0.9340704474024981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 476}], {
             RGBColor[
             0.18192213006975788`, 0.30854207160553015`, 0.9336715682265748]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 257}], {
             RGBColor[
             0.9190198138450048, 0.7061284902521469, 0.2641826298296307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 266}], {
             RGBColor[
             0.9342851916423655, 0.7569554226506068, 0.3801831663512317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 281}], {
             RGBColor[
             0.8467054680453859, 0.3339234893640672, 0.19133725700073073`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 293}], {
             RGBColor[
             0.8423679493594973, 0.6882641451078306, 0.5995351479132809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 317}], {
             RGBColor[
             0.8461530053131936, 0.3296770187137239, 0.19080821806446593`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 322}], {
             RGBColor[
             0.8478846282356312, 0.34298703129758157`, 0.19246642213058046`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 343}], {
             RGBColor[
             0.8606088112970214, 0.4407906780799979, 0.2046511142000771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 374}], {
             RGBColor[
             0.8612156544492956, 0.4454551404687426, 0.20523222788802623`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 403}], {
             RGBColor[
             0.8091979496573507, 0.6623514892391787, 0.5962290723342419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 440}], {
             RGBColor[
             0.8833097581290331, 0.5630186900098979, 0.22434314065434907`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 445}], {
             RGBColor[
             0.9190529143682962, 0.7062401460895815, 0.26431121911210875`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 471}], {
             RGBColor[
             0.9159118385486107, 0.7462782372358219, 0.5876734401900829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 238}], {
             RGBColor[
             0.4566518822195865, 0.5690445386024363, 0.9505687908779773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[
             0.42089773296190985`, 0.5389821941816072, 0.9480402092524494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 266}], {
             RGBColor[
             0.7100990368535118, 0.7663088762344812, 0.7456861929885767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 293}], {
             RGBColor[
             0.6181817945706438, 0.697617598691705, 0.965038174550626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 403}], {
             RGBColor[
             0.5850117948684971, 0.6717049428230532, 0.961732098971587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 471}], {
             RGBColor[
             0.6917256837597572, 0.7556316908196963, 0.953176466827428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 483}], {
             RGBColor[
             0.4393277460874472, 0.554945345231554, 0.949214553391788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 497}], {
             RGBColor[
             0.4523984541828804, 0.5655914141074888, 0.9502339454421076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 231}], {
             RGBColor[
             0.8790670260426792, 0.9036392003218177, 0.8591433457844534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 233}], {
             RGBColor[
             0.9785167541303205, 0.9817898472456261, 0.8447367386541516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 259}], {
             RGBColor[
             0.8388746662508497, 0.8722406233791922, 0.8551373469793608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 275}], {
             RGBColor[
             0.7418942375705933, 0.7941342962234403, 0.8470741774102124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 348}], {
             RGBColor[
             0.7282782743451366, 0.7830802438848616, 0.8460022789081878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 355}], {
             RGBColor[
             0.7770929742760209, 0.8227102163659248, 0.8498451509008846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 372}], {
             RGBColor[
             0.8043736512463036, 0.8448578989108925, 0.8519927857243978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 379}], {
             RGBColor[
             0.9109503146879699, 0.6018931108868748, 0.4575519033361274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 400}], {
             RGBColor[
             0.9921722318540724, 0.9910310309542629, 0.7793899060000027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 404}], {
             RGBColor[
             0.9156515263183187, 0.9323554252556073, 0.8627536207565263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 431}], {
             RGBColor[
             0.707864048381464, 0.7656363882619854, 0.8446357642394154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 444}], {
             RGBColor[
             0.7801701048240467, 0.8252083695679635, 0.8500873938895259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 486}], {
             RGBColor[
             0.7039053523851265, 0.7622075647598039, 0.8443835196310663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 225}], {
             RGBColor[
             0.189744388344664, 0.31676376101227643`, 0.9341170342633367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 252}], {
             RGBColor[
             0.1889152618740288, 0.3158922965219843, 0.9340698167374166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 280}], {
             RGBColor[
             0.22449871038575198`, 0.3532927570287484, 0.9360962414891647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 309}], {
             RGBColor[
             0.1918597924354573, 0.31898718483606625`, 0.9342375033968474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 320}], {
             RGBColor[
             0.18833104309187587`, 0.31527824554033135`, 0.9340365463420472]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 393}], {
             RGBColor[
             0.20841975513223648`, 0.336392755592659, 0.9351805687741597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 424}], {
             RGBColor[
             0.19449774707264864`, 0.3217598424157385, 0.9343877310109313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 480}], {
             RGBColor[
             0.21944240212988145`, 0.3479782564633687, 0.9358082922141305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 236}], {
             RGBColor[
             0.1979212488225095, 0.32535815981739014`, 0.934582694370969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 289}], {
             RGBColor[
             0.19877803112005593`, 0.32625869233524674`, 0.9346314868553184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 308}], {
             RGBColor[
             0.18919374524082816`, 0.3161850001973557, 0.9340856759531767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 362}], {
             RGBColor[
             0.1833599948775373, 0.31005335868440065`, 0.9337534525002475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 369}], {
             RGBColor[
             0.1847549864301014, 0.3115195832537184, 0.933832895205461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 466}], {
             RGBColor[
             0.1911846700582075, 0.3182775884123456, 0.9341990561762171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 470}], {
             RGBColor[
             0.19104848384555853`, 0.31813444806814695`, 0.9341913005728761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 216}], {
             RGBColor[
             0.19093042363498117`, 0.31801035930138044`, 0.9341845772185382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 217}], {
             RGBColor[
             0.18159408433829743`, 0.30819727474246456`, 0.9336528865074684]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 224}], {
             RGBColor[
             0.19394001881557005`, 0.321173634655535, 0.9343559692117758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 286}], {
             RGBColor[
             0.18467080520712215`, 0.3114311034509694, 0.9338281012093472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 319}], {
             RGBColor[
             0.18140430286516612`, 0.3079978023813632, 0.93364207873333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 330}], {
             RGBColor[
             0.18576322285580926`, 0.312579303663019, 0.9338903127783529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 357}], {
             RGBColor[
             0.18524504165765288`, 0.3120346623691711, 0.9338608031256983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 492}], {
             RGBColor[
             0.18227723304689475`, 0.30891530734933015`, 0.933691790815795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 251}], {
             RGBColor[
             0.22057376513923174`, 0.3491673907187537, 0.9358727216638114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 332}], {
             RGBColor[
             0.19442260484216423`, 0.3216808631672068, 0.9343834517720682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 337}], {
             RGBColor[
             0.19565173016906506`, 0.3229727518168264, 0.9344534486411072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 420}], {
             RGBColor[
             0.19513105630202093`, 0.32242549056993314`, 0.9344237970346471]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 447}], {
             RGBColor[
             0.2179735437754206, 0.34643439320183167`, 0.9357246429038253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 454}], {
             RGBColor[
             0.20680491942710666`, 0.3346954608800703, 0.9350886062696878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 489}], {
             RGBColor[
             0.19691928671610104`, 0.3243050341154881, 0.9345256341112791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 500}], {
             RGBColor[
             0.2016031036308693, 0.32922802266405415`, 0.934792370555489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 223}], {
             RGBColor[
             0.1978649215993461, 0.32529895633449324`, 0.9345794866189384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 268}], {
             RGBColor[
             0.186923339851059, 0.31379866018069236`, 0.9339563797249931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 466}], {
             RGBColor[
             0.1912157031774699, 0.31831020618830375`, 0.9342008234664497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 470}], {
             RGBColor[
             0.19107951696482092`, 0.31816706584410515`, 0.9341930678631087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 491}], {
             RGBColor[
             0.1845859949601158, 0.3113419625040855, 0.9338232713912458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 402}], {
             RGBColor[
             0.2015459552318014, 0.3291679560732161, 0.9347891160387054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 417}], {
             RGBColor[
             0.1910469226092748, 0.31813280710982467`, 0.9341912116627795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 217}], {
             RGBColor[
             0.1905787639681844, 0.31764074269506637`, 0.9341645507207481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 224}], {
             RGBColor[
             0.20292469844545702`, 0.3306171026081368, 0.9348676334250554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 292}], {
             RGBColor[
             0.19251751538449438`, 0.3196784933575477, 0.9342749597457812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 358}], {
             RGBColor[
             0.21239908038802668`, 0.34057527874028815`, 0.9354071854605928]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 361}], {
             RGBColor[
             0.21500792746091607`, 0.34331734242435297`, 0.9355557554419504]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 398}], {
             RGBColor[
             0.20308712437898663`, 0.33078782256267547`, 0.9348768833416823]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 399}], {
             RGBColor[
             0.20389703761891642`, 0.33163909272930703`, 0.934923006702537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 464}], {
             RGBColor[
             0.20118455785762748`, 0.32878810451904233`, 0.9347685349928858]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 481}], {
             RGBColor[
             0.20259193459855807`, 0.33026734670659963`, 0.9348486830162546]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 292}], {
             RGBColor[
             0.18318117608781065`, 0.30986540879863184`, 0.9337432690347114]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 398}], {
             RGBColor[
             0.1937507850823029, 0.3209747380037596, 0.9343451926306123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 464}], {
             RGBColor[
             0.19184821856094375`, 0.31897501996012645`, 0.9342368442818159]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 481}], {
             RGBColor[
             0.19325559530187433`, 0.3204542621476837, 0.9343169923051846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 496}], {
             RGBColor[
             0.1835288398725976, 0.31023082547960007`, 0.9337630679729325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 235}], {
             RGBColor[
             0.2514972659875934, 0.38166995077357824`, 0.9376337692899057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 274}], {
             RGBColor[
             0.26498050169023135`, 0.3958416863835701, 0.9384016196165113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.25886995308296373`, 0.3894191123661732, 0.938053632913074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 305}], {
             RGBColor[
             0.29821563929003225`, 0.43060670099699316`, 0.9403004343609631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 310}], {
             RGBColor[
             0.4653446361758491, 0.5701283226319324, 0.9524120897475179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 314}], {
             RGBColor[
             0.27434229412121725`, 0.4056815238004595, 0.9389347598459252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 406}], {
             RGBColor[
             0.35118939031714774`, 0.4764899015985373, 0.9436758749335621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 432}], {
             RGBColor[
             0.28855483307734864`, 0.4206198033703701, 0.9397441429139097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 493}], {
             RGBColor[
             0.2733906528975818, 0.4046812885368802, 0.9388805652860661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 238}], {
             RGBColor[
             0.5781077146635654, 0.6679567426795029, 0.9602144407477138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 258}], {
             RGBColor[
             0.5423535654058886, 0.6378943982586738, 0.9576858591221857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 293}], {
             RGBColor[
             0.7396376270146225, 0.7965298027687717, 0.9746838244203624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 403}], {
             RGBColor[
             0.7064676273124759, 0.7706171469001197, 0.9713777488413233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 445}], {
             RGBColor[
             0.8163225920234214, 0.8145058037505225, 0.6394598956191903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 471}], {
             RGBColor[
             0.8131815162037359, 0.854543894896763, 0.9628221166971644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 497}], {
             RGBColor[
             0.5738542866268592, 0.6645036181845554, 0.959879595311844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 254}], {
             RGBColor[
             0.20473141614653206`, 0.3325160774644852, 0.9349705233253323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 297}], {
             RGBColor[
             0.20614792707638763`, 0.3340049202637436, 0.9350511915272475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 325}], {
             RGBColor[
             0.22533443478540557`, 0.3541711563607717, 0.9361438347573814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 392}], {
             RGBColor[
             0.22694196327999852`, 0.35586077073178224`, 0.9362353811270232]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 412}], {
             RGBColor[
             0.2036444979201258, 0.3313736574939363, 0.9349086249402898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 413}], {
             RGBColor[
             0.2236716605546839, 0.35242347521830786`, 0.9360491422247958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 426}], {
             RGBColor[
             0.20219514191155313`, 0.32985029243444797`, 0.9348260862597317]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 474}], {
             RGBColor[
             0.22327343139036823`, 0.3520049111174247, 0.9360264636630153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 490}], {
             RGBColor[
             0.2165006286676464, 0.34488626603534933`, 0.9356407625674201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 234}], {
             RGBColor[
             0.9443267569423743, 0.8151145515040961, 0.2837836064703105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 301}], {
             RGBColor[
             0.8093616863432395, 0.8079745679423065, 0.6371695161143949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 336}], {
             RGBColor[
             0.7938129054109903, 0.7955671950703103, 0.6357978963718616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 294}], {
             RGBColor[
             0.19229714625130181`, 0.3194468714263523, 0.9342624100496528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 296}], {
             RGBColor[
             0.18966575842362554`, 0.31668111597984006`, 0.934112556405656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 339}], {
             RGBColor[
             0.1886442457825459, 0.3156074414264231, 0.9340543827719392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 344}], {
             RGBColor[
             0.1936890488951341, 0.3209098493567448, 0.9343416768460837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 438}], {
             RGBColor[
             0.19987204711910306`, 0.3274085725148659, 0.9346937894480125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 439}], {
             RGBColor[
             0.19816628717948753`, 0.32561571066690326`, 0.9345966489428971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 246}], {
             RGBColor[
             0.22404185527291065`, 0.35281257333886495`, 0.9360702242663449]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 268}], {
             RGBColor[
             0.19724310055792588`, 0.32464538299422946`, 0.9345440748305314]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 411}], {
             RGBColor[
             0.24469698646716248`, 0.3745224258349809, 0.9372465034313293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 286}], {
             RGBColor[
             0.19666508001759797`, 0.3240378467577258, 0.9345111574158644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 330}], {
             RGBColor[
             0.1977574976662851, 0.3251860469697754, 0.9345733689848701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 333}], {
             RGBColor[
             0.21886126221320776`, 0.3473674415645458, 0.9357751971555954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 358}], {
             RGBColor[
             0.21540867556861554`, 0.34373855409444265`, 0.9355785774538301]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 361}], {
             RGBColor[
             0.21801752264150492`, 0.34648061777850747`, 0.9357271474351878]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 398}], {
             RGBColor[
             0.2060967195595755, 0.33395109791683003`, 0.9350482753349197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 441}], {
             RGBColor[
             0.21370093658000952`, 0.34194361214051205`, 0.9354813242448025]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 464}], {
             RGBColor[
             0.20419415303821636`, 0.3319513798731969, 0.9349399269861233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 481}], {
             RGBColor[
             0.20560152977914695`, 0.33343062206075413`, 0.9350200750094919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 247}], {
             RGBColor[
             0.18412221385498584`, 0.31085449915717356`, 0.9337968597434113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 252}], {
             RGBColor[
             0.18313599846224066`, 0.30981792424973087`, 0.9337406962357694]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 309}], {
             RGBColor[
             0.18608052902366917`, 0.31291281256381276`, 0.9339083828952002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 320}], {
             RGBColor[
             0.1825517796800877, 0.30920387326807797`, 0.9337074258404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 424}], {
             RGBColor[
             0.18871848366086047`, 0.31568547014348514`, 0.9340586105092841]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 284}], {
             RGBColor[
             0.19690493413279425`, 0.3242899486404264, 0.9345248167528926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 345}], {
             RGBColor[
             0.18891037080707027`, 0.3158871557004993, 0.9340695381983891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 366}], {
             RGBColor[
             0.18476826025973897`, 0.3115335348902769, 0.9338336511304219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 389}], {
             RGBColor[
             0.19095055240575043`, 0.3180315159156967, 0.9341857235222557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 405}], {
             RGBColor[
             0.18431945622850954`, 0.3110618133976357, 0.9338080924047896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 429}], {
             RGBColor[
             0.18946440368264025`, 0.31646947938043657`, 0.9341010895510347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 472}], {
             RGBColor[
             0.18505776823943543`, 0.311837826132804, 0.933850138181577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 488}], {
             RGBColor[
             0.18475420080410804`, 0.31151875751098784`, 0.9338328504652229]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 229}], {
             RGBColor[
             0.21399982241481183`, 0.34225776010334574`, 0.9354983453509325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 263}], {
             RGBColor[
             0.2087485483203887, 0.3367383380800992, 0.935199293059819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 265}], {
             RGBColor[
             0.18874076831201309`, 0.315708892724775, 0.9340598795871999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 267}], {
             RGBColor[
             0.2112079223469873, 0.3393232961153739, 0.935339350772316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 270}], {
             RGBColor[
             0.18663641062037617`, 0.3134970793668807, 0.9339400395297794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 329}], {
             RGBColor[
             0.18736891797604732`, 0.31426699104133987`, 0.9339817547400375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 424}], {
             RGBColor[
             0.19331536997885967`, 0.3205170891231287, 0.9343203963846103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 256}], {
             RGBColor[
             0.28488710481113977`, 0.4165048432644388, 0.9395447890804083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 279}], {
             RGBColor[
             0.23309972747079383`, 0.36233297132110764`, 0.9365860566880932]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 287}], {
             RGBColor[
             0.28118525934636124`, 0.41287391412114016`, 0.9393244565922372]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 298}], {
             RGBColor[
             0.2669525907215979, 0.3979144769932027, 0.9385139271694034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 318}], {
             RGBColor[
             0.22809876360932468`, 0.35707664122328114`, 0.9363012591944456]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 335}], {
             RGBColor[
             0.2342958788041693, 0.36359020221286015`, 0.9366541757369817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 409}], {
             RGBColor[
             0.2557251463437433, 0.3861137210909889, 0.9378745408216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 468}], {
             RGBColor[
             0.23985909159475186`, 0.369437491583826, 0.9369709924753695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 232}], {
             RGBColor[
             0.2566501782178637, 0.3870859882410977, 0.9379272200183691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 263}], {
             RGBColor[
             0.22958947316632627`, 0.3586434714841348, 0.9363861528984097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 267}], {
             RGBColor[
             0.23204884719292487`, 0.3612284295194095, 0.9365262106109067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 280}], {
             RGBColor[
             0.24415725813790062`, 0.37395513714017414`, 0.9372157667014342]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 393}], {
             RGBColor[
             0.2280783028843851, 0.35705513570408476`, 0.9363000939864292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 480}], {
             RGBColor[
             0.23910094988203007`, 0.36864063657479446`, 0.9369278174264002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 485}], {
             RGBColor[
             0.2450928096239232, 0.3749384610693741, 0.9372690449745389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 382}], {
             RGBColor[
             0.20898405610198123`, 0.3369858716906088, 0.9352127048795782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 413}], {
             RGBColor[
             0.21810416040748024`, 0.34657167956369916`, 0.9357320813277911]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 474}], {
             RGBColor[
             0.21770593124316456`, 0.3461531154628161, 0.9357094027660106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 484}], {
             RGBColor[
             0.19535510076833423`, 0.3226609755092681, 0.9344365560355595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 490}], {
             RGBColor[
             0.21093312852044277`, 0.33903447038074064`, 0.9353237016704152]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 233}], {
             RGBColor[
             0.8631076739966228, 0.8934453053740385, 0.9626713381948079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 275}], {
             RGBColor[
             0.6264851574368956, 0.7057897543518528, 0.9650087769508688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 326}], {
             RGBColor[
             0.7445199877539495, 0.8003439400856498, 0.9751704525106033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 346}], {
             RGBColor[
             0.6025366315327623, 0.6860240764087309, 0.963212758449727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 355}], {
             RGBColor[
             0.6616838941423232, 0.7343656744943371, 0.9677797504415411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 395}], {
             RGBColor[
             0.6338994865668826, 0.711809040751297, 0.9655924600995638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 404}], {
             RGBColor[
             0.8002424461846211, 0.8440108833840196, 0.9806882202971826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 431}], {
             RGBColor[
             0.5924549682477664, 0.6772918463903979, 0.9625703637800718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 444}], {
             RGBColor[
             0.664761024690349, 0.7368638276963759, 0.9680219934301821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 486}], {
             RGBColor[
             0.5884962722514289, 0.6738630228882163, 0.9623181191717225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 267}], {
             RGBColor[
             0.25385827815003914`, 0.3841515242531258, 0.9377682254397526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 280}], {
             RGBColor[
             0.26596668909501486`, 0.3968782318738905, 0.9384577815302801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 338}], {
             RGBColor[
             0.351395977443279, 0.47598308304576464`, 0.9437141472934822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 383}], {
             RGBColor[
             0.2731170371748888, 0.40439370106409095`, 0.938864983275437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 393}], {
             RGBColor[
             0.24988773384149937`, 0.3799782304378011, 0.9375421088152751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 395}], {
             RGBColor[
             0.3913003181998807, 0.5091662530135891, 0.9466381048606165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 480}], {
             RGBColor[
             0.2609103808391443, 0.3915637313085108, 0.9381698322552461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 259}], {
             RGBColor[
             0.8229153142047934, 0.8620467284314131, 0.9586653393897153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 275}], {
             RGBColor[
             0.7259348855245369, 0.7839404012756612, 0.9506021698205669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 326}], {
             RGBColor[
             0.8439697158415906, 0.8784945870094583, 0.9607638453803016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 346}], {
             RGBColor[
             0.7019863596204035, 0.7641747233325396, 0.948806151319425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 348}], {
             RGBColor[
             0.7123189222990802, 0.7728863489370825, 0.9495302713185423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 355}], {
             RGBColor[
             0.7611336222299645, 0.8125163214181457, 0.9533731433112391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 379}], {
             RGBColor[
             0.8949909626419136, 0.5916992159390957, 0.5610798957464819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 400}], {
             RGBColor[
             0.9762128798080161, 0.9808371360064839, 0.8829178984103572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 404}], {
             RGBColor[
             0.8996921742722623, 0.9221615303078283, 0.9662816131668808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 431}], {
             RGBColor[
             0.6919046963354076, 0.7554424933142063, 0.9481637566497699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 444}], {
             RGBColor[
             0.7642107527779903, 0.8150144746201845, 0.9536153862998804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 486}], {
             RGBColor[
             0.6879460003390702, 0.7520136698120249, 0.9479115120414208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 336}], {
             RGBColor[
             0.7758644491107505, 0.7262741691289183, 0.6116347463560659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 449}], {
             RGBColor[
             0.9549924747052941, 0.851092521948047, 0.32521790592745947`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 274}], {
             RGBColor[
             0.23060114107907964`, 0.35970679860388893`, 0.9364437658894125]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 284}], {
             RGBColor[
             0.2119740420649528, 0.3401285365137513, 0.9353829801568815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 300}], {
             RGBColor[
             0.22449059247181202`, 0.353284224586492, 0.9360957791859752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 305}], {
             RGBColor[
             0.2638362786788805, 0.394471813217312, 0.9383425806338642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 308}], {
             RGBColor[
             0.2040111506020718, 0.33175903270978435`, 0.9349295052681127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 345}], {
             RGBColor[
             0.20397947873922884`, 0.3317257435738243, 0.934927701602378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 389}], {
             RGBColor[
             0.20601966033790897`, 0.3338701037890217, 0.9350438869262447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 432}], {
             RGBColor[
             0.25417547246619693`, 0.38448491559068887`, 0.9377862891868108]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 456}], {
             RGBColor[
             0.20636469541016642`, 0.3342327575264513, 0.9350635361631761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 289}], {
             RGBColor[
             0.20921618528861102`, 0.33722985418359713`, 0.9352259242933523]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 300}], {
             RGBColor[
             0.22011134127912346`, 0.34868135392241384`, 0.9358463873090731]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 308}], {
             RGBColor[
             0.19963189940938322`, 0.3271561620457061, 0.9346801133912106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 314}], {
             RGBColor[
             0.23558368231737692`, 0.3649437653567001, 0.9367275142419242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 466}], {
             RGBColor[
             0.2016228242267626, 0.329248750260696, 0.934793493614251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 470}], {
             RGBColor[
             0.2014866380141136, 0.3291056099164974, 0.9347857380109101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 493}], {
             RGBColor[
             0.23463204109374153`, 0.36394353009312075`, 0.9366733196820654]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 241}], {
             RGBColor[
             0.2242600552960576, 0.35304191539787294`, 0.9360826504348652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 274}], {
             RGBColor[
             0.23848727143504053`, 0.36799562161754756`, 0.9368928693467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 284}], {
             RGBColor[
             0.21986017242091369`, 0.34841735952740993`, 0.9358320836141691]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 351}], {
             RGBColor[
             0.2365402762573613, 0.3659492062391825, 0.9367819908516525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 371}], {
             RGBColor[
             0.24348618176994377`, 0.3732497933287522, 0.9371775498950476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 429}], {
             RGBColor[
             0.2124196419707597, 0.3405968902674201, 0.9354083564123112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 432}], {
             RGBColor[
             0.26206160282215785`, 0.3927737386043475, 0.9382353926440985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 460}], {
             RGBColor[
             0.26678188416083737`, 0.3977350535744224, 0.9385042056833057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 258}], {
             RGBColor[
             0.4509349141328164, 0.5640927881888469, 0.9502045107268047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 266}], {
             RGBColor[
             0.7401362180244184, 0.7914194702417209, 0.7478504944629321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 293}], {
             RGBColor[
             0.6482189757415503, 0.7227281926989446, 0.9672024760249813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 403}], {
             RGBColor[
             0.6150489760394036, 0.6968155368302928, 0.9638964004459423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 445}], {
             RGBColor[
             0.7249039407503491, 0.7407041936806955, 0.6319785472238091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 471}], {
             RGBColor[
             0.7217628649306637, 0.780742284826936, 0.9553407683017833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 483}], {
             RGBColor[
             0.46936492725835366`, 0.5800559392387936, 0.9513788548661433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 497}], {
             RGBColor[
             0.4824356353537869, 0.5907020081147285, 0.9523982469164629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 251}], {
             RGBColor[
             0.2177871872756262, 0.3462385207048633, 0.9357140301768516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 272}], {
             RGBColor[
             0.22693559422031087`, 0.3558540764462288, 0.9362350184184962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 332}], {
             RGBColor[
             0.1916360269785587, 0.31875199315331637`, 0.9342247602851084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 387}], {
             RGBColor[
             0.1927675658632359, 0.3199413122648211, 0.934289199750629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 435}], {
             RGBColor[
             0.21752143841029148`, 0.3459592017979452, 0.9356988961721111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 453}], {
             RGBColor[
             0.21828737914361301`, 0.34676425407211353`, 0.935742515363766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 454}], {
             RGBColor[
             0.20401834156350113`, 0.3317665908661798, 0.9349299147827279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 489}], {
             RGBColor[
             0.1941327088524955, 0.32137616410159764`, 0.9343669426243193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 434}], {
             RGBColor[
             0.9649429424873008, 0.8858096572696792, 0.4713319778660402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 495}], {
             RGBColor[
             0.9404490296531263, 0.7834756918464549, 0.4513533807985771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 271}], {
             RGBColor[
             0.2118628562397169, 0.3400116731618399, 0.935376648288619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 304}], {
             RGBColor[
             0.20316948858682138`, 0.3308743925673022, 0.9348815738614715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 311}], {
             RGBColor[
             0.2028072709740812, 0.33049367889038916`, 0.934860946104279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 351}], {
             RGBColor[
             0.22791016546505544`, 0.3568784126158412, 0.9362905188091355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 371}], {
             RGBColor[
             0.2348560709776379, 0.3641789997054109, 0.9366860778525307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 429}], {
             RGBColor[
             0.20378953117845383`, 0.33152609664407884`, 0.9349168843697941]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 442}], {
             RGBColor[
             0.22676711964941848`, 0.35567699899031613`, 0.9362254240409197]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 249}], {
             RGBColor[
             0.8500313217686346, 0.8830430785885436, 0.951908121903962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 269}], {
             RGBColor[
             0.787493374586991, 0.8335677780907182, 0.9460989448159113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 282}], {
             RGBColor[
             0.8349131599958114, 0.8712326557093291, 0.9504012848257013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 310}], {
             RGBColor[
             0.8089627721429287, 0.8509600154884045, 0.9478147926846883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 323}], {
             RGBColor[
             0.9829115082024764, 0.98536084245597, 0.8504363857845441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 419}], {
             RGBColor[
             0.8111996093173061, 0.8527074496896203, 0.9480377397097984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 449}], {
             RGBColor[
             0.9783597736506789, 0.9679158712997968, 0.6606061921458748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 499}], {
             RGBColor[
             0.8008428775112291, 0.844405505952868, 0.9471498665869478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 273}], {
             RGBColor[
             0.1918690378137841, 0.3189969023148785, 0.9342380299074659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 279}], {
             RGBColor[
             0.20228104719014361`, 0.3299405843289558, 0.934830978438262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 283}], {
             RGBColor[
             0.18944836976348856`, 0.3164526267147989, 0.934100176443059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 285}], {
             RGBColor[
             0.20548353415746184`, 0.3333066011810086, 0.9350133553333959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 318}], {
             RGBColor[
             0.19728008332867447`, 0.3246842542311293, 0.9345461809446143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 335}], {
             RGBColor[
             0.2034771985235191, 0.3311978152207083, 0.9348990974871504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 396}], {
             RGBColor[
             0.19700888147424034`, 0.32439920388692833`, 0.9345307364002116]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 421}], {
             RGBColor[
             0.1904580230623436, 0.31751383634761216`, 0.9341576747047806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 430}], {
             RGBColor[
             0.19906776015361727`, 0.3265632159194014, 0.934647986495164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 459}], {
             RGBColor[
             0.19552964555273866`, 0.32284443314445566`, 0.9344464961028154]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 477}], {
             RGBColor[
             0.19718654273618264`, 0.32458593713760425`, 0.9345408539462529]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 261}], {
             RGBColor[
             0.388007213318593, 0.5104940791921502, 0.9459444544247217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 262}], {
             RGBColor[
             0.3949445171400494, 0.5165028230832673, 0.9463864932898081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 295}], {
             RGBColor[
             0.7157587889214511, 0.7746651605070033, 0.9256601695039643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 341}], {
             RGBColor[
             0.7205094989495678, 0.7757802394753833, 0.7851817105206231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 376}], {
             RGBColor[
             0.40891528656398646`, 0.5286036013669932, 0.947276698363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 391}], {
             RGBColor[
             0.45991819988990085`, 0.5722422337278446, 0.9506750794005083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 407}], {
             RGBColor[
             0.361925627233212, 0.4849803667690406, 0.9443895897897958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 448}], {
             RGBColor[
             0.373652859998312, 0.49730643195466345`, 0.9450574383468822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 455}], {
             RGBColor[
             0.5298831385666443, 0.6290429228301937, 0.9561829756631566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 475}], {
             RGBColor[
             0.39162513268333266`, 0.5136277391039731, 0.9461749850474426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 478}], {
             RGBColor[
             0.34801769220506096`, 0.4703622452404419, 0.9435975534648887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 482}], {
             RGBColor[
             0.3895468312104969, 0.511827618826672, 0.9460425575153633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 262}], {
             RGBColor[
             0.2935462908702744, 0.4226836514910424, 0.9401449256179049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 299}], {
             RGBColor[
             0.24199930981785328`, 0.3716869966339784, 0.9370928747370061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 376}], {
             RGBColor[
             0.30751706029421144`, 0.43478442977476833`, 0.9410351306917317]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 438}], {
             RGBColor[
             0.22328352119424416`, 0.3520155161410289, 0.9360270382624196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 448}], {
             RGBColor[
             0.272254633728537, 0.40348726036243854`, 0.9388158706749788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 475}], {
             RGBColor[
             0.2902269064135576, 0.4198085675117481, 0.9399334173755393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 482}], {
             RGBColor[
             0.2881486049407218, 0.4180084472344471, 0.93980098984346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 384}], {
             RGBColor[
             0.2539870125967417, 0.38428683231884564`, 0.9377755566760467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 402}], {
             RGBColor[
             0.22901412567720097`, 0.3580387447939263, 0.9363533877100543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 411}], {
             RGBColor[
             0.2605541594338602, 0.3911893200258155, 0.9381495459731974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 458}], {
             RGBColor[
             0.2394606076875042, 0.3690186597319697, 0.9369482994063559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 252}], {
             RGBColor[
             0.18329308738435063`, 0.3099830346668814, 0.9337496422174913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 278}], {
             RGBColor[
             0.18437169562717964`, 0.3111167203178072, 0.9338110673612625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 309}], {
             RGBColor[
             0.18623761794577917`, 0.3130779229809633, 0.933917328876922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 401}], {
             RGBColor[
             0.1825033131056717, 0.3091529318254084, 0.9337046657406869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 451}], {
             RGBColor[
             0.19468301666075716`, 0.32195457249961096`, 0.9343982818398924]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 339}], {
             RGBColor[
             0.18022958629127006`, 0.30676310078086577`, 0.933575180362284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 344}], {
             RGBColor[
             0.18527438940385826`, 0.31206550871118754`, 0.9338624744364286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 387}], {
             RGBColor[
             0.18458186461527748`, 0.3113376212497815, 0.9338230361742175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 439}], {
             RGBColor[
             0.18975162768821172`, 0.3167713700213459, 0.934117446533242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 269}], {
             RGBColor[
             0.6644117978227214, 0.7371426324130581, 0.9676100378285277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 282}], {
             RGBColor[
             0.7118315832315418, 0.7748075100316689, 0.9719123778383179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 310}], {
             RGBColor[
             0.685881195378659, 0.7545348698107444, 0.9693258856973048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 323}], {
             RGBColor[
             0.8598299314382067, 0.8889356967783099, 0.8719474787971606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 406}], {
             RGBColor[
             0.5717259495199576, 0.6608964487773493, 0.960589670883349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 419}], {
             RGBColor[
             0.6881180325530365, 0.7562823040119602, 0.9695488327224149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 499}], {
             RGBColor[
             0.6777613007469594, 0.7479803602752079, 0.9686609595995643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 263}], {
             RGBColor[
             0.22198989446995654`, 0.350655832433131, 0.9359533681342207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 365}], {
             RGBColor[
             0.21334264494811753`, 0.3415670249183921, 0.9354609200664112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 485}], {
             RGBColor[
             0.23749323092755345`, 0.3669508220183703, 0.9368362602103498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 258}], {
             RGBColor[
             0.3270553942889411, 0.45124571304551764`, 0.9422970062673146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 272}], {
             RGBColor[
             0.24807843064742718`, 0.378076538064383, 0.937439071674997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 435}], {
             RGBColor[
             0.2386642748374078, 0.3681816634160995, 0.9369029494286119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 447}], {
             RGBColor[
             0.23632980233893142`, 0.3657279848060955, 0.9367700046733661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 453}], {
             RGBColor[
             0.23943021557072935`, 0.3689867156902678, 0.9369465686202667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 454}], {
             RGBColor[
             0.22516117799061744`, 0.3539890524843341, 0.9361339680392287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 309}], {
             RGBColor[
             0.18525140255303396`, 0.3120413480735207, 0.9338611653692801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 320}], {
             RGBColor[
             0.18172265320945252`, 0.3083324087777858, 0.93366020831448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 424}], {
             RGBColor[
             0.1878893571902253, 0.31481400565319295`, 0.934011392983364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 287}], {
             RGBColor[
             0.340823165506129, 0.46920105185432204`, 0.9429534744527581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 301}], {
             RGBColor[
             0.5169703257345344, 0.6164641572661, 0.9558333707121969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 336}], {
             RGBColor[
             0.5014215448022852, 0.6040567843941038, 0.9544617509696633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 354}], {
             RGBColor[
             0.34404011319445926`, 0.47241198691533204`, 0.9431429096833921]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 388}], {
             RGBColor[
             0.3530902196198862, 0.48025073422946185`, 0.9437195744621254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 436}], {
             RGBColor[
             0.36650668927910635`, 0.49187140591690626`, 0.9445744600450926]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 473}], {
             RGBColor[
             0.32054318862790937`, 0.44788551033051344`, 0.9417985597710807]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 350}], {
             RGBColor[
             0.18697690227356584`, 0.31385495768280075`, 0.9339594300257164]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 377}], {
             RGBColor[
             0.18661056292735312`, 0.3134699118026751, 0.9339385675419001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 412}], {
             RGBColor[
             0.19134257547531666`, 0.31844355701750904`, 0.9342080486561213]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 426}], {
             RGBColor[
             0.189893219466744, 0.3169201919580207, 0.9341255099755632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 476}], {
             RGBColor[
             0.18792976264725234`, 0.31485647435038233`, 0.9340136940143672]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 260}], {
             RGBColor[
             0.2034606107913817, 0.33118038046250897`, 0.9348981528403446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 299}], {
             RGBColor[
             0.21862190988624552`, 0.3471158670930945, 0.935761566394665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 312}], {
             RGBColor[
             0.19606964847691927`, 0.3234120104559323, 0.9344772484704849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 327}], {
             RGBColor[
             0.19047479361502342`, 0.3175314632617931, 0.9341586297629458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 334}], {
             RGBColor[
             0.19201279446501912`, 0.3191479996700246, 0.9342462166360848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 385}], {
             RGBColor[
             0.1893629494279947, 0.3163628445262328, 0.9340953118813207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 446}], {
             RGBColor[
             0.19028875988053398`, 0.31733593001162463`, 0.9341480354169789]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 478}], {
             RGBColor[
             0.22324206600367816`, 0.3519719441073331, 0.9360246774506443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 287}], {
             RGBColor[
             0.30785568445183253`, 0.44064627675886753`, 0.9408528157119771]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 298}], {
             RGBColor[
             0.2936230158270692, 0.42568683963093007`, 0.9400422862891433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 409}], {
             RGBColor[
             0.2823955714492146, 0.41388608372871627`, 0.93940289994134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 281}], {
             RGBColor[
             0.8907382712640035, 0.5148249421887663, 0.2381214507014296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 317}], {
             RGBColor[
             0.8901858085318111, 0.510578471538423, 0.23759241176516477`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 322}], {
             RGBColor[
             0.8919174314542486, 0.5238884841222806, 0.23925061583127932`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 324}], {
             RGBColor[
             0.9513926924014826, 0.9208016602260798, 0.6489338534613713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 326}], {
             RGBColor[
             0.8442173233312698, 0.8362115823989578, 0.6421148916132133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 343}], {
             RGBColor[
             0.9046416145156388, 0.621692130904697, 0.25143530790077595`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 374}], {
             RGBColor[
             0.9052484576679132, 0.6263565932934416, 0.25201642158872506`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 445}], {
             RGBColor[
             0.9630857175869136, 0.8871415989142806, 0.3110954128128076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 272}], {
             RGBColor[
             0.33620380123362575`, 0.46086126878688316`, 0.9428179945089592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 293}], {
             RGBColor[
             0.6124648264838737, 0.6926658482781156, 0.9646738943994533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 403}], {
             RGBColor[
             0.5792948267817268, 0.6667531924094637, 0.9613678188204143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 435}], {
             RGBColor[
             0.32678964542360633`, 0.4509663941385996, 0.942281872262574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 453}], {
             RGBColor[
             0.3275555861569279, 0.45177144641276795`, 0.942325491454229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 471}], {
             RGBColor[
             0.686008715672987, 0.7506799404061069, 0.9528121866762553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 497}], {
             RGBColor[
             0.44668148609611025`, 0.5606396636938994, 0.9498696652909349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 275}], {
             RGBColor[
             0.586292797645066, 0.6743911774092273, 0.9610027781457763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 331}], {
             RGBColor[
             0.4923539796181456, 0.5933274496466499, 0.9547717909351274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 348}], {
             RGBColor[
             0.5726768344196096, 0.6633371250706486, 0.9599308796437516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 372}], {
             RGBColor[
             0.6487722113207766, 0.7251147800966794, 0.9659213864599616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 400}], {
             RGBColor[
             0.8365707919285453, 0.8712879121400499, 0.8933185067355665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 404}], {
             RGBColor[
             0.7600500863927916, 0.8126123064413943, 0.97668222149209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 418}], {
             RGBColor[
             0.5798892585592409, 0.6691924959032061, 0.9604986680920036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 431}], {
             RGBColor[
             0.552262608455937, 0.6458932694477724, 0.9585643649749793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 444}], {
             RGBColor[
             0.6245686648985196, 0.7054652507537504, 0.9640159946250897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 486}], {
             RGBColor[
             0.5483039124595994, 0.6424644459455908, 0.95831212036663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 299}], {
             RGBColor[
             0.2249121050554158, 0.35372726103730096`, 0.9361197837040394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 312}], {
             RGBColor[
             0.2023598436460895, 0.3300234044001388, 0.9348354657798592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 328}], {
             RGBColor[
             0.2263686482084435, 0.35525818024130285`, 0.9362027316818419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 334}], {
             RGBColor[
             0.19830298963418935`, 0.3257593936142311, 0.9346044339454591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 399}], {
             RGBColor[
             0.20881488896675832`, 0.33680806630567356`, 0.9352030710614876]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 407}], {
             RGBColor[
             0.24344019620099944`, 0.3732014595801383, 0.9371749310849259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 446}], {
             RGBColor[
             0.19657895504970424`, 0.32394732395583115`, 0.9345062527263533]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 478}], {
             RGBColor[
             0.22953226117284842`, 0.3585833380515396, 0.9363828947600188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 262}], {
             RGBColor[
             0.33623006243366543`, 0.4656473134908974, 0.942645260155071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 299}], {
             RGBColor[
             0.2846830813812443, 0.4146506586338333, 0.9395932092741723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 313}], {
             RGBColor[
             0.3452565934007724, 0.4734656409279675, 0.9432204227264471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 328}], {
             RGBColor[
             0.28613962453427205`, 0.41618157783783527`, 0.9396761572519747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 391}], {
             RGBColor[
             0.40120374518351687`, 0.5213867241354746, 0.9469338462657712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 407}], {
             RGBColor[
             0.30321117252682794`, 0.43412485717667065`, 0.9406483566550587]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 448}], {
             RGBColor[
             0.314938405291928, 0.4464509223622935, 0.9413162052121451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 455}], {
             RGBColor[
             0.47116868386026034`, 0.5781874132378237, 0.9524417425284195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 475}], {
             RGBColor[
             0.3329106779769486, 0.46277222951160313`, 0.9424337519127055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 478}], {
             RGBColor[
             0.2893032374986769, 0.41950673564807195`, 0.9398563203301515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 482}], {
             RGBColor[
             0.3308323765041129, 0.4609721092343021, 0.9423013243806262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 299}], {
             RGBColor[
             0.2916203852027007, 0.4206594025249505, 0.9400352481392587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 376}], {
             RGBColor[
             0.3571381356790589, 0.48375683566574046`, 0.9439775040939842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 391}], {
             RGBColor[
             0.4081410490049733, 0.5273954680265918, 0.9473758851308575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 448}], {
             RGBColor[
             0.3218757091133844, 0.45245966625341066`, 0.9417582440772314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 455}], {
             RGBColor[
             0.47810598768171675`, 0.5841961571289409, 0.9528837813935058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 475}], {
             RGBColor[
             0.33984798179840503`, 0.4687809734027203, 0.9428757907777918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 478}], {
             RGBColor[
             0.29624054132013333`, 0.4255154795391891, 0.9402983591952379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 482}], {
             RGBColor[
             0.3377696803255693, 0.46698085312541926`, 0.9427433632457125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 267}], {
             RGBColor[
             0.22679757309850174`, 0.35570900749616285`, 0.9362271583197932]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 393}], {
             RGBColor[
             0.22282702878996197`, 0.35153571368083814`, 0.9360010416953157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 485}], {
             RGBColor[
             0.23984153552950008`, 0.3694190390461275, 0.9369699926834254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 281}], {
             RGBColor[
             0.8419839123581961, 0.3124840077358858, 0.18739747519941907`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 295}], {
             RGBColor[
             0.9251699045349664, 0.7351644032002858, 0.5555767619873893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 324}], {
             RGBColor[
             0.9026383334956752, 0.7184607257731993, 0.5982098779593608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 341}], {
             RGBColor[
             0.9299206145630832, 0.7362794821686658, 0.415098303004048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 374}], {
             RGBColor[
             0.8564940987621058, 0.42401565884056125`, 0.20129244608671454`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 397}], {
             RGBColor[
             0.8437768320344039, 0.3262651740296299, 0.18911437710616869`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 270}], {
             RGBColor[
             0.18221828136351503`, 0.30885334539234544`, 0.9336884336046377]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 320}], {
             RGBColor[
             0.18273053674122575`, 0.3093917582731863, 0.9337176057905845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 329}], {
             RGBColor[
             0.18295078871918613`, 0.3096232570668046, 0.9337301488148957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 424}], {
             RGBColor[
             0.18889724072199854`, 0.3158733551485935, 0.9340687904594684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 293}], {
             RGBColor[
             0.9016661303754756, 0.9199925303309897, 0.7623198781355807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 317}], {
             RGBColor[
             0.9054511863291719, 0.561405403936883, 0.35359294828676574`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 322}], {
             RGBColor[
             0.9071828092516094, 0.5747154165207407, 0.3552511523528803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 343}], {
             RGBColor[
             0.9199069923129997, 0.6725190633031569, 0.3674358444223769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 359}], {
             RGBColor[
             0.9515547370167402, 0.9596896244773535, 0.7671002510689349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 403}], {
             RGBColor[
             0.868496130673329, 0.8940798744623377, 0.7590138025565417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 440}], {
             RGBColor[
             0.9426079391450114, 0.7947470752330569, 0.3871278708766489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 445}], {
             RGBColor[
             0.9783510953842744, 0.9379685313127405, 0.42709594933440853`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 471}], {
             RGBColor[
             0.975210019564589, 0.978006622458981, 0.7504581704123827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 483}], {
             RGBColor[
             0.722812081892279, 0.7773202768708386, 0.7464962569767426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 280}], {
             RGBColor[
             0.24136535807007609`, 0.3710206731522022, 0.9370567721228178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 393}], {
             RGBColor[
             0.22528640281656057`, 0.35412067171611283`, 0.9361410994078128]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 424}], {
             RGBColor[
             0.21136439475697272`, 0.3394877585391924, 0.9353482616445844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 480}], {
             RGBColor[
             0.23630904981420553`, 0.3657061725868226, 0.9367688228477836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 485}], {
             RGBColor[
             0.24230090955609868`, 0.3720039970814022, 0.9371100503959223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 491}], {
             RGBColor[
             0.1839641739186956, 0.3106883891638218, 0.9337878596028387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 282}], {
             RGBColor[
             0.6492936360498982, 0.7253322095338435, 0.966103200750267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 310}], {
             RGBColor[
             0.6233432481970155, 0.705059569312919, 0.963516708609254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 323}], {
             RGBColor[
             0.7972919842565633, 0.8394603962804845, 0.8661383017091098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 406}], {
             RGBColor[
             0.5091880023383142, 0.611421148279524, 0.9547804937952983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 411}], {
             RGBColor[
             0.441541570634595, 0.5502832522185821, 0.9505633429393294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 419}], {
             RGBColor[
             0.6255800853713929, 0.7068070035141348, 0.9637396556343641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 499}], {
             RGBColor[
             0.615223353565316, 0.6985050597773825, 0.9628517825115135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 329}], {
             RGBColor[
             0.18084643102754924`, 0.3074114437089104, 0.9336103087574752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 479}], {
             RGBColor[
             0.18121603188329788`, 0.30779991764234993`, 0.9336313569794346]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 304}], {
             RGBColor[
             0.19940240032278655`, 0.3269149439546105, 0.9346670437577425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 307}], {
             RGBColor[
             0.199934386249049, 0.3274740948929682, 0.9346973395692404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 311}], {
             RGBColor[
             0.19904018271004636`, 0.32653423027769746`, 0.9346464160005499]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 351}], {
             RGBColor[
             0.2241430772010206, 0.3529189640031495, 0.9360759887054064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 371}], {
             RGBColor[
             0.23108898271360306`, 0.3602195510927192, 0.9364715477488016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 429}], {
             RGBColor[
             0.200022442914419, 0.32756664803138713`, 0.9347023542660651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 442}], {
             RGBColor[
             0.22300003138538366`, 0.3517175503776244, 0.9360108939371906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 435}], {
             RGBColor[
             0.24781268178209245`, 0.377797219157465, 0.9374239376702564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 453}], {
             RGBColor[
             0.24857862251541402`, 0.3786022714316334, 0.9374675568619113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 497}], {
             RGBColor[
             0.3677045224545963, 0.48747048871276477`, 0.9450117306986173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 279}], {
             RGBColor[
             0.19757076585955963`, 0.32498978000142653`, 0.9345627348847221]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 283}], {
             RGBColor[
             0.18473808843290457`, 0.31150182238726964`, 0.933831932889519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 285}], {
             RGBColor[
             0.20077325282687788`, 0.3283557968534793, 0.934745111779856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 396}], {
             RGBColor[
             0.19229860014365638`, 0.3194483995593991, 0.9342624928466716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 421}], {
             RGBColor[
             0.18574774173175967`, 0.3125630320200829, 0.9338894311512407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 430}], {
             RGBColor[
             0.19435747882303328`, 0.32161241159187215`, 0.9343797429416241]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 459}], {
             RGBColor[
             0.19081936422215473`, 0.3178936288169264, 0.9341782525492754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 477}], {
             RGBColor[
             0.19247626140559868`, 0.319635132810075, 0.9342726103927129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 284}], {
             RGBColor[
             0.22545727776759072`, 0.3543002721237432, 0.936150830483487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 300}], {
             RGBColor[
             0.23797382817444995`, 0.36745596019648397`, 0.9368636295125807]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 305}], {
             RGBColor[
             0.2773195143815185, 0.4086435488273039, 0.9391104309604698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 389}], {
             RGBColor[
             0.2195028960405469, 0.34804183939901356`, 0.9358117372528503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 432}], {
             RGBColor[
             0.26765870816883486`, 0.3986566512006808, 0.9385541395134164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 460}], {
             RGBColor[
             0.27237898950751444`, 0.4036179661707557, 0.9388229525526237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 331}], {
             RGBColor[
             0.39537355093788906`, 0.515221122490898, 0.946708621365979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 346}], {
             RGBColor[
             0.4653638430606762, 0.5765191723103537, 0.951143590075486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 348}], {
             RGBColor[
             0.475696405739353, 0.5852307979148967, 0.9518677100746031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 355}], {
             RGBColor[
             0.5245111056702372, 0.6248607703959599, 0.9557105820673001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 372}], {
             RGBColor[
             0.55179178264052, 0.6470084529409276, 0.9578582168908132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 404}], {
             RGBColor[
             0.663069657712535, 0.7345059792856424, 0.9686190519229416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 418}], {
             RGBColor[
             0.48290882987898437`, 0.5910861687474542, 0.9524354985228551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 431}], {
             RGBColor[
             0.4552821797756804, 0.5677869422920205, 0.9505011954058309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 444}], {
             RGBColor[
             0.5275882362182631, 0.6273589235979986, 0.9559528250559413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 486}], {
             RGBColor[
             0.45132348377934284`, 0.564358118789839, 0.9502489507974816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 306}], {
             RGBColor[
             0.22718429673725105`, 0.3561154785601833, 0.9362491816589136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 347}], {
             RGBColor[
             0.20833762491305394`, 0.33630643152494155`, 0.935175891579678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 382}], {
             RGBColor[
             0.21283416100439742`, 0.3410325760537981, 0.935431962658051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 462}], {
             RGBColor[
             0.20183278400452248`, 0.3294694312993405, 0.9348054505129868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 288}], {
             RGBColor[
             0.5772249873338873, 0.6663273536018384, 0.9606573715704986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 313}], {
             RGBColor[
             0.4022235011215268, 0.5228075131556505, 0.9468503037125551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 340}], {
             RGBColor[
             0.40350978000289583`, 0.523921623272436, 0.9469322642654641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 373}], {
             RGBColor[
             0.7171130809828956, 0.774434213301909, 0.8741433170431847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 386}], {
             RGBColor[
             0.3744145130463712, 0.49843012291785427`, 0.9450889814281427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 414}], {
             RGBColor[
             0.43294658493558325`, 0.5494183041682945, 0.9488079514458304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 498}], {
             RGBColor[
             0.6089064489917588, 0.6910771522369943, 0.9638150835884631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 401}], {
             RGBColor[
             0.18259570595575553`, 0.30925004256889155`, 0.9337099273768162]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 451}], {
             RGBColor[
             0.194775409510841, 0.3220516832430941, 0.9344035434760216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.2111852622032374, 0.3392994788675566, 0.935338060310652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 318}], {
             RGBColor[
             0.20298181137445004`, 0.33067713191767734`, 0.9348708859218705]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 335}], {
             RGBColor[
             0.20917892656929465`, 0.33719069290725634`, 0.9352238024644066]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 396}], {
             RGBColor[
             0.2027106095200159, 0.3303920815734764, 0.9348554413774677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 409}], {
             RGBColor[
             0.23060819410886862`, 0.3597142117853851, 0.9364441675490249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 421}], {
             RGBColor[
             0.19615975110811917`, 0.3235067140341602, 0.9344823796820367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 430}], {
             RGBColor[
             0.2047694881993928, 0.33255609360594945`, 0.9349726914724201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 459}], {
             RGBColor[
             0.20123137359851423`, 0.3288373108310037, 0.9347712010800716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 477}], {
             RGBColor[
             0.2028882707819582, 0.3305788148241523, 0.9348655589235091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 338}], {
             RGBColor[
             0.33890305736331594`, 0.4628522319448411, 0.9430026939765475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 383}], {
             RGBColor[
             0.2606241170949257, 0.3912628499631674, 0.9381535299585022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 393}], {
             RGBColor[
             0.23739481376153632`, 0.3668473793368775, 0.9368306554983403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 480}], {
             RGBColor[
             0.24841746075918128`, 0.37843288020758725`, 0.9374583789383113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 317}], {
             RGBColor[
             0.8178714627321924, 0.13837347065034328`, 0.1647470389362648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 322}], {
             RGBColor[
             0.8196030856546299, 0.15168348323420097`, 0.16640524300237935`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 324}], {
             RGBColor[
             0.8790783466018638, 0.5485966593380001, 0.5760884806324713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 343}], {
             RGBColor[
             0.8323272687160201, 0.24948713001661726`, 0.17858993507187598`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 374}], {
             RGBColor[
             0.8329341118682944, 0.254151592405362, 0.1791710487598251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 397}], {
             RGBColor[
             0.8202168451405925, 0.15640110759443068`, 0.16699297977927924`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 445}], {
             RGBColor[
             0.8907713717872949, 0.5149365980262008, 0.23825003998390762`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 310}], {
             RGBColor[
             0.6707630336058359, 0.74272444693153, 0.9678190486190441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 323}], {
             RGBColor[
             0.8447117696653836, 0.8771252738990953, 0.8704406417188999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 406}], {
             RGBColor[
             0.5566077877471345, 0.6490860258981348, 0.9590828338050883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 419}], {
             RGBColor[
             0.6729998707802133, 0.7444718811327458, 0.9680419956441542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 499}], {
             RGBColor[
             0.6626431389741363, 0.7361699373959933, 0.9671541225213036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 396}], {
             RGBColor[
             0.18987793209336085`, 0.3169041239593195, 0.9341246393822646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 421}], {
             RGBColor[
             0.18332707368146411`, 0.3100187564200033, 0.9337515776868337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 430}], {
             RGBColor[
             0.19193681077273775`, 0.31906813599179257`, 0.9342418894772171]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 459}], {
             RGBColor[
             0.18839869617185917`, 0.3153493532168468, 0.9340403990848687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 477}], {
             RGBColor[
             0.19005559335530314`, 0.3170908572099954, 0.934134756928306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 300}], {
             RGBColor[
             0.2193467291603231, 0.3478776981063463, 0.9358028437800496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 345}], {
             RGBColor[
             0.19883561542773992`, 0.32631921709367856`, 0.9346347661964527]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 389}], {
             RGBColor[
             0.20087579702642006`, 0.328463577308876, 0.9347509515203193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 432}], {
             RGBColor[
             0.249031609154708, 0.37907838911054315`, 0.9374933537808854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 456}], {
             RGBColor[
             0.2012208320986775, 0.3288262310463056, 0.9347706007572507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 472}], {
             RGBColor[
             0.19498301286010505`, 0.32226988752598323`, 0.9344153661796406]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 287}], {
             RGBColor[
             0.2592707940788048, 0.38984042166758914`, 0.938076460214796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 354}], {
             RGBColor[
             0.2624877417671351, 0.39305135672859914`, 0.93826589544543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 396}], {
             RGBColor[
             0.20591309648733414`, 0.33375809842552917`, 0.9350378182726016]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 409}], {
             RGBColor[
             0.23381068107618688`, 0.3630802286374379, 0.9366265444441588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 430}], {
             RGBColor[
             0.20797197516671106`, 0.33592211045800224`, 0.935155068367554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 473}], {
             RGBColor[
             0.2389908172005852, 0.3685248801437806, 0.9369215455331186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 477}], {
             RGBColor[
             0.20609075774927643`, 0.3339448316762051, 0.935047935818643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 319}], {
             RGBColor[
             0.18412936406719407`, 0.310862014483554, 0.9337972669374188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 330}], {
             RGBColor[
             0.18848828405783719`, 0.3154435157652098, 0.9340455009824417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 357}], {
             RGBColor[
             0.1879701028596808, 0.3148988744713619, 0.934015991329787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 358}], {
             RGBColor[
             0.20613946196016764`, 0.33399602288987706`, 0.9350507094514018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 367}], {
             RGBColor[
             0.1922727390163294, 0.3194212178748882, 0.9342610200937285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 368}], {
             RGBColor[
             0.18331387184910375`, 0.310004880457148, 0.9337508258620111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 492}], {
             RGBColor[
             0.18500229424892267`, 0.31177951945152094`, 0.9338469790198838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 336}], {
             RGBColor[
             0.46475221828321023`, 0.5718710801553506, 0.9521407597407114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 354}], {
             RGBColor[
             0.3073707866753843, 0.44022628267657893`, 0.9408219184544402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 388}], {
             RGBColor[
             0.31642089310081123`, 0.44806502999070874`, 0.9413985832331735]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 409}], {
             RGBColor[
             0.2786937259844361, 0.4102551545854176, 0.9391825674531689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 436}], {
             RGBColor[
             0.3298373627600314, 0.45968570167815315`, 0.9422534688161406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 473}], {
             RGBColor[
             0.28387386210883436`, 0.4156998060917603, 0.9394775685421287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 313}], {
             RGBColor[
             0.5362219144016962, 0.6308125527023426, 0.9580446920208532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 321}], {
             RGBColor[
             0.8483292768809738, 0.881288734461381, 0.9314462475205114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 373}], {
             RGBColor[
             0.8511114942630649, 0.882439252848601, 0.8853377053514828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 386}], {
             RGBColor[
             0.5084129263265404, 0.6064351624645463, 0.9562833697364408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 391}], {
             RGBColor[
             0.5921690661844405, 0.6787336359098497, 0.9617581155601771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 455}], {
             RGBColor[
             0.6621340048611841, 0.7355343250121988, 0.9672660118228255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 498}], {
             RGBColor[
             0.7429048622719281, 0.7990821917836863, 0.9750094718967612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 300}], {
             RGBColor[
             0.2209681235766699, 0.34958188644027033`, 0.9358951797934225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 308}], {
             RGBColor[
             0.20048868170692968`, 0.3280566945635627, 0.9347289058755601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 314}], {
             RGBColor[
             0.23644046461492338`, 0.36584429787455663`, 0.9367763067262738]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 466}], {
             RGBColor[
             0.20247960652430902`, 0.3301492827785526, 0.9348422860986005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 470}], {
             RGBColor[
             0.20234342031166005`, 0.33000614243435394`, 0.9348345304952597]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 493}], {
             RGBColor[
             0.235488823391288, 0.36484406261097735`, 0.9367221121664148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 297}], {
             RGBColor[
             0.18839455558370108`, 0.3153450011961642, 0.9340401632844985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 484}], {
             RGBColor[
             0.18316922942285135`, 0.3098528520962973, 0.9337425886898154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 349}], {
             RGBColor[
             0.1841373062547167, 0.310870362226204, 0.9337977192332487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 353}], {
             RGBColor[
             0.18189358061228061`, 0.3085120643155814, 0.9336699423772067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 394}], {
             RGBColor[
             0.18326692398746902`, 0.30995553527790365`, 0.9337481522507443]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 467}], {
             RGBColor[
             0.1871130842202519, 0.31399809354320196`, 0.933967185386117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 398}], {
             RGBColor[
             0.19568953649861287`, 0.32301248866624094`, 0.9344556016556456]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 399}], {
             RGBColor[
             0.19649944973854266`, 0.32386375883287244`, 0.9345017250165003]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 464}], {
             RGBColor[
             0.19378696997725373`, 0.3210127706226078, 0.9343472533068491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 481}], {
             RGBColor[
             0.1951943467181843, 0.32249201281016504`, 0.9344274013302178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 496}], {
             RGBColor[
             0.1854675912889076, 0.3122685761420814, 0.9338734769979656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 343}], {
             RGBColor[
             0.8279897500301316, 0.6038277857603807, 0.5867878259844261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 403}], {
             RGBColor[
             0.7765788883904609, 0.8253885969195616, 0.9783657841185909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 440}], {
             RGBColor[
             0.8506906968621433, 0.7260557976902806, 0.6064798524386981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 445}], {
             RGBColor[
             0.8864338531014064, 0.8692772537699642, 0.6464479308964578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 471}], {
             RGBColor[
             0.883292777281721, 0.9093153449162048, 0.969810151974432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 483}], {
             RGBColor[
             0.630894839609411, 0.7086289993280623, 0.9658482385387919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 497}], {
             RGBColor[
             0.6439655477048442, 0.7192750682039972, 0.9668676305891115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 296}], {
             RGBColor[
             0.18486063733978264`, 0.311630629058448, 0.9338389118684709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 327}], {
             RGBColor[
             0.18563559838764718`, 0.312445162255122, 0.9338830447536945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 385}], {
             RGBColor[
             0.18452375420061845`, 0.3112765435195617, 0.9338197268720694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 415}], {
             RGBColor[
             0.18394556991543065`, 0.3106688351768284, 0.9337868001323749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 438}], {
             RGBColor[
             0.19506692603526019`, 0.32235808559347384`, 0.9344201449108273]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 439}], {
             RGBColor[
             0.19336116609564466`, 0.3205652237455112, 0.9343230044057118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 321}], {
             RGBColor[
             0.9851155314829081, 0.988112904001859, 0.896337693305348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 341}], {
             RGBColor[
             0.9895466198460419, 0.9890958111978665, 0.7611561924651287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 391}], {
             RGBColor[
             0.7289553207863748, 0.7855578054503277, 0.9266495613450138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 397}], {
             RGBColor[
             0.9034028373173626, 0.5790815030588307, 0.5351722665672494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 455}], {
             RGBColor[
             0.7989202594631184, 0.8423584945526768, 0.9321574576076621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 327}], {
             RGBColor[
             0.1830042105599709, 0.3096794068086097, 0.9337331911096979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 339}], {
             RGBColor[
             0.18120773687102673`, 0.3077911990585188, 0.9336308845907572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 385}], {
             RGBColor[
             0.18189236637294215`, 0.30851078807304944`, 0.9336698732280726]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 415}], {
             RGBColor[
             0.18131418208775438`, 0.30790307973031616`, 0.9336369464883782]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 438}], {
             RGBColor[
             0.1924355382075839, 0.3195923301469616, 0.9342702912668306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 325}], {
             RGBColor[
             0.21444902327045198`, 0.3427298986836028, 0.9355239266751281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 392}], {
             RGBColor[
             0.21605655176504493`, 0.3444195130546133, 0.9356154730447699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 412}], {
             RGBColor[
             0.1927590864051722, 0.31993239981676747`, 0.9342887168580365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 413}], {
             RGBColor[
             0.2127862490397303, 0.34098221754113894`, 0.9354292341425425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 474}], {
             RGBColor[
             0.21238801987541464`, 0.34056365344025585`, 0.935406555580762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 484}], {
             RGBColor[
             0.1900371894005843, 0.3170715134867078, 0.934133708850311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 490}], {
             RGBColor[
             0.20561521715269282`, 0.3334450083581805, 0.9350208544851668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 335}], {
             RGBColor[
             0.2430317898200987, 0.3727721985793514, 0.9371516729457167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 409}], {
             RGBColor[
             0.26446105735967274`, 0.39529571745748016`, 0.9383720380303351]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 468}], {
             RGBColor[
             0.24859500261068126`, 0.37861948795031725`, 0.9374684896841046]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 312}], {
             RGBColor[
             0.21752114274095335`, 0.3459588910307243, 0.9356988793341796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 328}], {
             RGBColor[
             0.24152994730330735`, 0.3711936668718884, 0.9370661452361624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 399}], {
             RGBColor[
             0.22397618806162217`, 0.3527435529362591, 0.936066484615808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 407}], {
             RGBColor[
             0.2586014952958633, 0.3891369462107238, 0.9380383446392464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 448}], {
             RGBColor[
             0.2703287280609633, 0.40146301139634666`, 0.9387061931963326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 475}], {
             RGBColor[
             0.28830100074598397`, 0.41778431854565623`, 0.939823739896893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 478}], {
             RGBColor[
             0.24469356026771227`, 0.3745188246821251, 0.9372463083143392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 482}], {
             RGBColor[
             0.2862226992731482, 0.4159841982683552, 0.9396913123648138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 305}], {
             RGBColor[
             0.27120896577425085`, 0.40222097480990704`, 0.9387624442570324]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 308}], {
             RGBColor[
             0.21138383769744212`, 0.33950819430237933`, 0.9353493688912808]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 432}], {
             RGBColor[
             0.26154815956156724`, 0.39223407718328385`, 0.938206152809979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 456}], {
             RGBColor[
             0.21373738250553675`, 0.34198191911904635`, 0.9354833997863443]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 493}], {
             RGBColor[
             0.24638397938180046`, 0.376295562349794, 0.9373425751821356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 316}], {
             RGBColor[
             0.547580608865669, 0.6429772459967242, 0.9577838308857021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 336}], {
             RGBColor[
             0.6408993785116156, 0.7191341855671287, 0.9650206560001502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 388}], {
             RGBColor[
             0.4925680533292166, 0.5953281354024867, 0.9542784794926122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 436}], {
             RGBColor[
             0.5059845229884368, 0.6069488070899312, 0.9551333650755793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 346}], {
             RGBColor[
             0.343088083847486, 0.46567152269516504`, 0.9432988559850268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 370}], {
             RGBColor[
             0.23676036432994563`, 0.36618053275785845`, 0.936794524541795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 390}], {
             RGBColor[
             0.25033731885124844`, 0.38045077278838335`, 0.9375677120164789]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 422}], {
             RGBColor[
             0.22565049031831835`, 0.3545033507649412, 0.9361618336524187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 443}], {
             RGBColor[
             0.2662987639830351, 0.3972272636359636, 0.9384766927038922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 451}], {
             RGBColor[
             0.22492379054142386`, 0.35373954322399803`, 0.9361204491751804]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 379}], {
             RGBColor[
             0.8341112743268393, 0.26319977889761653`, 0.18029830085954252`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 400}], {
             RGBColor[
             0.9153331914929417, 0.6523376989650047, 0.5021363035234178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 307}], {
             RGBColor[
             0.19124101859615344`, 0.3183368142984305, 0.9342022651420929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 311}], {
             RGBColor[
             0.19034681505715081`, 0.3173969496831598, 0.9341513415734024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 337}], {
             RGBColor[
             0.1898974932161501, 0.3169246839396178, 0.9341257533592695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 423}], {
             RGBColor[
             0.1849544721508512, 0.3117292553943517, 0.9338442556221451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 427}], {
             RGBColor[
             0.18861159117236292`, 0.315573119360699, 0.9340525231401974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 433}], {
             RGBColor[
             0.1856912324704567, 0.31250363720355945`, 0.9338862130324074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 465}], {
             RGBColor[
             0.18487917380697239`, 0.31165011206074433`, 0.933839967492855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 469}], {
             RGBColor[
             0.18603078567582654`, 0.3128605291513198, 0.9339055500851292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 310}], {
             RGBColor[
             0.4776836488671362, 0.5829301850756662, 0.9531209010914763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 406}], {
             RGBColor[
             0.3635284030084348, 0.4892917640422711, 0.9443846862775205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 432}], {
             RGBColor[
             0.30089384576863576`, 0.43342166581410385`, 0.9404529542578681]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 460}], {
             RGBColor[
             0.3056141271073153, 0.43838298078417876`, 0.9407217672970755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 493}], {
             RGBColor[
             0.2857296655888689, 0.41748315098061395`, 0.9395893766300246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 331}], {
             RGBColor[
             0.2711023891418522, 0.40227617824530654`, 0.9387502520503602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 347}], {
             RGBColor[
             0.22192337354853872`, 0.3505859147270508, 0.9359495798661548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 382}], {
             RGBColor[
             0.2264199096398822, 0.3553120592559075, 0.9362056509445278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 431}], {
             RGBColor[
             0.33101101797964355`, 0.4548419980464291, 0.9425428260902121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 486}], {
             RGBColor[
             0.327052321983306, 0.4514131745442476, 0.942290581481863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 337}], {
             RGBColor[
             0.19042947914241254`, 0.31748383487797555`, 0.9341560491707674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 427}], {
             RGBColor[
             0.1891435770986254, 0.31613227029905666`, 0.9340828189516954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 433}], {
             RGBColor[
             0.18622321839671918`, 0.3130627881419171, 0.9339165088439054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 442}], {
             RGBColor[
             0.21483864965875055`, 0.34313942072144443`, 0.9355461153215412]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 469}], {
             RGBColor[
             0.186562771602089, 0.31341968008967747`, 0.9339358458966271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 500}], {
             RGBColor[
             0.19638085260421678`, 0.3237391057252033, 0.9344949710851491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 362}], {
             RGBColor[
             0.18507064546441102`, 0.3118513609127166, 0.9338508715204893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 369}], {
             RGBColor[
             0.18646563701697516`, 0.31331758548203437`, 0.9339303142257027]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 389}], {
             RGBColor[
             0.19291290556353907`, 0.320094073504909, 0.9342974766315505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 456}], {
             RGBColor[
             0.1932579406357965, 0.32045672724233865`, 0.9343171258684819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 393}], {
             RGBColor[
             0.20475589581124165`, 0.33254180714419534`, 0.9349719174060231]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 424}], {
             RGBColor[
             0.19083388775165383`, 0.3179088939672749, 0.9341790796427948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 323}], {
             RGBColor[
             0.8187613818125008, 0.8568526336781708, 0.8678541495778869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 406}], {
             RGBColor[
             0.5306573998942516, 0.6288133856772102, 0.9564963416640753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 408}], {
             RGBColor[
             0.7910483812120712, 0.837599492064294, 0.9781391837091735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 419}], {
             RGBColor[
             0.6470494829273306, 0.7241992409118212, 0.9654555035031411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 366}], {
             RGBColor[
             0.18627071422588198`, 0.31311270926977675`, 0.9339192136611123]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 405}], {
             RGBColor[
             0.18582191019465255`, 0.3126409877771355, 0.9338936549354799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 423}], {
             RGBColor[
             0.184592254538111, 0.31134854171743864`, 0.9338236278649524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 429}], {
             RGBColor[
             0.19096685764878327`, 0.3180486537599364, 0.934186652081725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 465}], {
             RGBColor[
             0.1845169561942322, 0.31126939838383133`, 0.9338193397356624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 469}], {
             RGBColor[
             0.18566856806308635`, 0.31247981547440673`, 0.9338849223279366]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 488}], {
             RGBColor[
             0.18625665477025105`, 0.3130979318904876, 0.9339184129959133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 327}], {
             RGBColor[
             0.18937402646973123`, 0.31637448719942296`, 0.9340959427024605]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 334}], {
             RGBColor[
             0.19091202731972692`, 0.3179910236076545, 0.9341835295755994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 385}], {
             RGBColor[
             0.1882621822827025, 0.31520586846386267`, 0.9340326248208353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 415}], {
             RGBColor[
             0.18768399799751473`, 0.31459816012112934`, 0.9339996980811409]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 446}], {
             RGBColor[
             0.18918799273524178`, 0.31617895394925455`, 0.9340853483564936]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 386}], {
             RGBColor[
             0.33341144011418006`, 0.4629153220183585, 0.9424763018784972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 391}], {
             RGBColor[
             0.4171675799720802, 0.5352137954636619, 0.9479510477022336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 407}], {
             RGBColor[
             0.31917500731539133`, 0.44795192850485793`, 0.9416655580915212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 498}], {
             RGBColor[
             0.5679033760595678, 0.6555623513374985, 0.9612024040388176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 406}], {
             RGBColor[
             0.3396550578396198, 0.4643665868457374, 0.9430190117624826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 411}], {
             RGBColor[
             0.27200862613590066`, 0.4032286907847955, 0.9388018609065139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 493}], {
             RGBColor[
             0.2618563204200539, 0.3925579737840803, 0.9382237021149867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 349}], {
             RGBColor[
             0.18430254906177113`, 0.31104404289341736`, 0.9338071295666557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 353}], {
             RGBColor[
             0.18205882341933505`, 0.3086857449827948, 0.9336793527106135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 364}], {
             RGBColor[
             0.19390091491665387`, 0.32113253397844377`, 0.9343537423025814]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 378}], {
             RGBColor[
             0.19518703914887203`, 0.3224843320914912, 0.934426985174956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 380}], {
             RGBColor[
             0.18543946082278231`, 0.31223900923860914`, 0.9338718750095351]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 487}], {
             RGBColor[
             0.1880750117052634, 0.3150091403196742, 0.9340219657333442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 372}], {
             RGBColor[
             0.5264921273018517, 0.6260724945913516, 0.9559761056168596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 418}], {
             RGBColor[
             0.45760917454031613`, 0.5701502103978782, 0.9505533872489015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 322}], {
             RGBColor[
             0.8190506229224375, 0.1474370125838577, 0.16587620406611453`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 343}], {
             RGBColor[
             0.8317748059838278, 0.24524065936627398`, 0.17806089613561116`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 374}], {
             RGBColor[
             0.832381649136102, 0.24990512175501872`, 0.1786420098235603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 440}], {
             RGBColor[
             0.8544757528158395, 0.36746867129617394`, 0.19775292258988314`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 445}], {
             RGBColor[
             0.8902189090551026, 0.5106901273758575, 0.23772100104764282`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 471}], {
             RGBColor[
             0.8870778332354172, 0.5507282185220981, 0.561083222125617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 335}], {
             RGBColor[
             0.2041779627078255, 0.33193436280942984`, 0.9349390049707589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 421}], {
             RGBColor[
             0.19115878724665003`, 0.3182503839363337, 0.9341975821883891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 430}], {
             RGBColor[
             0.1997685243379237, 0.32729976350812295`, 0.9346878939787725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 459}], {
             RGBColor[
             0.1962304097370451, 0.3235809807331772, 0.934486403586424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 330}], {
             RGBColor[
             0.18522178171588122`, 0.3120102146956035, 0.9338594785064245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 357}], {
             RGBColor[
             0.18470360051772483`, 0.3114655734017556, 0.9338299688537698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 368}], {
             RGBColor[
             0.18004736950714773`, 0.30657157938754187`, 0.9335648033859939]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 492}], {
             RGBColor[
             0.18173579190696668`, 0.3083462183819148, 0.9336609565438665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 329}], {
             RGBColor[
             0.18135868640525998`, 0.3079498565897512, 0.9336394809434219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 424}], {
             RGBColor[
             0.18730513840807234`, 0.31419995467154005`, 0.9339781225879946]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 341}], {
             RGBColor[
             0.9898662415110249, 0.9892279829702391, 0.7558592343220067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 373}], {
             RGBColor[
             0.9882173705299822, 0.9893955941614516, 0.8449321929931977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 391}], {
             RGBColor[
             0.7292749424513578, 0.7856899772227003, 0.9213526032018919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 397}], {
             RGBColor[
             0.9037224589823456, 0.5792136748312032, 0.5298753084241274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 455}], {
             RGBColor[
             0.7992398811281014, 0.8424906663250493, 0.9268604994645402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 498}], {
             RGBColor[
             0.8800107385388454, 0.9060385330965369, 0.934603959538476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 343}], {
             RGBColor[
             0.8335064289062653, 0.2585506719501317, 0.17971910020172568`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 374}], {
             RGBColor[
             0.8341132720585396, 0.26321513433887644`, 0.18030021388967482`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 440}], {
             RGBColor[
             0.8562073757382771, 0.38077868388003167`, 0.19941112665599764`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 445}], {
             RGBColor[
             0.89195053197754, 0.5240001399597152, 0.23937920511375732`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 471}], {
             RGBColor[
             0.8888094561578547, 0.5640382311059557, 0.5627414261917315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 419}], {
             RGBColor[
             0.8209982189868783, 0.8586000678793866, 0.8680770966029969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 449}], {
             RGBColor[
             0.9881583833202512, 0.9738084894895631, 0.5806455490390734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 499}], {
             RGBColor[
             0.8106414871808013, 0.8502981241426343, 0.8671892234801464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 342}], {
             RGBColor[
             0.7080228667800735, 0.7701523632700238, 0.969408565667581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 360}], {
             RGBColor[
             0.7679481729777577, 0.8188024264455834, 0.9741261052850922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 457}], {
             RGBColor[
             0.7044919829810323, 0.7672858327374596, 0.9691306015608669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 392}], {
             RGBColor[
             0.23524305947406288`, 0.3645857491516413, 0.9367081162749039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 413}], {
             RGBColor[
             0.23197275674874823`, 0.36114845363816694`, 0.9365218773726766]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 474}], {
             RGBColor[
             0.2315745275844326, 0.3607298895372839, 0.936499198810896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 490}], {
             RGBColor[
             0.22480172486171077`, 0.3536112444552085, 0.9361134977153007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 338}], {
             RGBColor[
             0.5748571876552486, 0.6636751524188924, 0.9607610097179233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 346}], {
             RGBColor[
             0.5833986733777301, 0.6710733580441507, 0.9613052656352206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 355}], {
             RGBColor[
             0.642545935987291, 0.7194149561297569, 0.9658722576270347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 395}], {
             RGBColor[
             0.6147615284118504, 0.6968583223867169, 0.9636849672850575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 443}], {
             RGBColor[
             0.5066093535132791, 0.6026290989849493, 0.956483102354086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 334}], {
             RGBColor[
             0.18531717245783108`, 0.3121104764135153, 0.9338649108680606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 385}], {
             RGBColor[
             0.18266732742080666`, 0.30932532126972345`, 0.9337140061132965]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 415}], {
             RGBColor[
             0.1820891431356189, 0.3087176129269901, 0.9336810793736019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 446}], {
             RGBColor[
             0.18359313787334597`, 0.31029840675511533`, 0.9337667296489547]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 398}], {
             RGBColor[
             0.2246228179747201, 0.35342320197362953`, 0.9361033092327558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 399}], {
             RGBColor[
             0.22543273121464985`, 0.354274472140261, 0.9361494325936104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 407}], {
             RGBColor[
             0.26005803844889097`, 0.3906678654147257, 0.9381212926170488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 464}], {
             RGBColor[
             0.22272025145336094`, 0.35142348392999634`, 0.9359949608839593]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 475}], {
             RGBColor[
             0.28975754389901165`, 0.4193152377496582, 0.9399066878746956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 478}], {
             RGBColor[
             0.24615010342073995`, 0.376049743886127, 0.9373292562921416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 481}], {
             RGBColor[
             0.22412762819429155`, 0.3529027261175536, 0.9360751089073279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 333}], {
             RGBColor[
             0.210684466253447, 0.33877311057202975`, 0.9353095407221728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 352}], {
             RGBColor[
             0.1864863756783814, 0.3133393831300794, 0.9339314952617896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 357}], {
             RGBColor[
             0.18906252050836794`, 0.3160470746834114, 0.9340782028987926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 358}], {
             RGBColor[
             0.20723187960885475`, 0.33514422310192665`, 0.9351129210204074]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 367}], {
             RGBColor[
             0.19336515666501655`, 0.3205694180869378, 0.9343232316627341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 368}], {
             RGBColor[
             0.18440628949779087`, 0.3111530806691976, 0.9338130374310167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 441}], {
             RGBColor[
             0.20552414062024876`, 0.33334928114799606`, 0.9350156678113797]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 492}], {
             RGBColor[
             0.1860947118976098, 0.3129277196635705, 0.9339091905888894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 348}], {
             RGBColor[
             0.3817575877124325, 0.5041670701523192, 0.9456367228639543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 372}], {
             RGBColor[
             0.4578529646135995, 0.56594472517835, 0.9516272296801642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 382}], {
             RGBColor[
             0.25675225340899854`, 0.38719327573892137`, 0.9379330330494976]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 404}], {
             RGBColor[
             0.5691308396856145, 0.6534422515230649, 0.9623880647122928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 418}], {
             RGBColor[
             0.38897001185206387`, 0.5100224409848767, 0.9462045113122062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 431}], {
             RGBColor[
             0.3613433617487599, 0.48672321452944306`, 0.9442702081951819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 444}], {
             RGBColor[
             0.43364941819134256`, 0.5462951958354212, 0.9497218378452923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 486}], {
             RGBColor[
             0.35738466575242234`, 0.48329439102726157`, 0.9440179635868327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 420}], {
             RGBColor[
             0.1873361545684642, 0.31423255462265, 0.9339798889124447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 454}], {
             RGBColor[
             0.19901001769354992`, 0.3265025249327872, 0.9346446981474854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 489}], {
             RGBColor[
             0.1891243849825443, 0.31611209816820496`, 0.9340817259890768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 358}], {
             RGBColor[
             0.22833564415577742`, 0.35732561769669713`, 0.9363147491911328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 361}], {
             RGBColor[
             0.2309444912286668, 0.3600676813807619, 0.9364633191724905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 367}], {
             RGBColor[
             0.21446892121193922`, 0.34275081268170826`, 0.9355250598334595]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 386}], {
             RGBColor[
             0.268695341419697, 0.3997462184736812, 0.9386131742434916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 441}], {
             RGBColor[
             0.2266279051671714, 0.35553067574276653`, 0.936217495982105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 450}], {
             RGBColor[
             0.22365738515605757`, 0.35240847086923904`, 0.9360483292619628]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 461}], {
             RGBColor[
             0.24252993321129454`, 0.3722447154639515, 0.9371230929542755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 385}], {
             RGBColor[
             0.18420532827080235`, 0.310941857677955, 0.9338015929864353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 415}], {
             RGBColor[
             0.18362714398561458`, 0.31033414933522163`, 0.9337686662467408]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 446}], {
             RGBColor[
             0.18513113872334164`, 0.31191494316334684`, 0.9338543165220936]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 409}], {
             RGBColor[
             0.23180434544224413`, 0.3609714426771376, 0.9365122865979134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 421}], {
             RGBColor[
             0.19735590244149465`, 0.3247639449259127, 0.9345504987309252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 430}], {
             RGBColor[
             0.2059656395327683, 0.33381332449770196`, 0.9350408105213086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 459}], {
             RGBColor[
             0.2024275249318897, 0.3300945417227562, 0.93483932012896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 354}], {
             RGBColor[
             0.4679691659715405, 0.5750820152163606, 0.9523301949713454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 388}], {
             RGBColor[
             0.4770192723969674, 0.5829207625304905, 0.9529068597500787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 436}], {
             RGBColor[
             0.49043574205618756`, 0.5945414342179349, 0.953761745333046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 420}], {
             RGBColor[
             0.18856527989536503`, 0.3155244432722696, 0.9340498857814837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 427}], {
             RGBColor[
             0.18780005171862202`, 0.314720139940244, 0.9340063071688718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 433}], {
             RGBColor[
             0.1848796930167158, 0.31165065778310447`, 0.9338399970610818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 500}], {
             RGBColor[
             0.1950373272242134, 0.32232697536639066`, 0.9344184593023257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 383}], {
             RGBColor[
             0.34605340544318985`, 0.47036770113504156`, 0.9434098957217043]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 395}], {
             RGBColor[
             0.4642366864681818, 0.5751402530845398, 0.9511830173068838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 443}], {
             RGBColor[
             0.3560845115696105, 0.4809110296827722, 0.9439811523759123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 480}], {
             RGBColor[
             0.3338467491074454, 0.4575377313794614, 0.9427147447015134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 344}], {
             RGBColor[
             0.1852310273425353, 0.3120199324354236, 0.9338600050311847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 387}], {
             RGBColor[
             0.1845385025539545, 0.3112920449740175, 0.9338205667689736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 439}], {
             RGBColor[
             0.18970826562688875`, 0.316725793745582, 0.9341149771279982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 384}], {
             RGBColor[
             0.3159339914529744, 0.4443075647988586, 0.9414896959063039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 414}], {
             RGBColor[
             0.3932297908847611, 0.5150176133855842, 0.946277232449094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 461}], {
             RGBColor[
             0.30853231078714655`, 0.43652792912541416`, 0.9410681811421904]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 499}], {
             RGBColor[
             0.4961829212208138, 0.5994318600646289, 0.9541521247756388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 374}], {
             RGBColor[
             0.9208708140731814, 0.677947066838142, 0.406871876564454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 391}], {
             RGBColor[
             0.7337060308144916, 0.7866728844187078, 0.7861711023616725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 397}], {
             RGBColor[
             0.9081535473454794, 0.5801965820272107, 0.39469380758390815`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 455}], {
             RGBColor[
             0.8036709694912352, 0.8434735735210568, 0.7916789986243209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 485}], {
             RGBColor[
             0.36582891890395064`, 0.48572268889805037`, 0.9448845663511518]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 374}], {
             RGBColor[
             0.8468374551199298, 0.3610187811212927, 0.19248490595917145`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 403}], {
             RGBColor[
             0.7948197503279848, 0.5779151298917289, 0.5834817504053871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 440}], {
             RGBColor[
             0.8689315587996673, 0.47858233066244793`, 0.21159581872549427`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 445}], {
             RGBColor[
             0.9046747150389304, 0.6218037867421315, 0.25156389718325395`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 471}], {
             RGBColor[
             0.901533639219245, 0.661841877888372, 0.5749261182612281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 387}], {
             RGBColor[
             0.1895833056665427, 0.31659445290433924`, 0.9341078608431181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 438}], {
             RGBColor[
             0.19645882867909248`, 0.32382106352386636`, 0.934499411707258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 439}], {
             RGBColor[
             0.19475306873947695`, 0.32202820167590374`, 0.9344022712021427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 389}], {
             RGBColor[
             0.1928812337006961, 0.3200607843689489, 0.9342956729658158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 456}], {
             RGBColor[
             0.1932262687729535, 0.32042343810637863`, 0.9343153222027473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 472}], {
             RGBColor[
             0.1869884495343811, 0.3138670945860562, 0.9339600876251372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 355}], {
             RGBColor[
             0.5005625797661037, 0.605095092452838, 0.9539145635661582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 390}], {
             RGBColor[
             0.34866455216030523`, 0.47153274446045024`, 0.9436164276057963]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 395}], {
             RGBColor[
             0.47277817219066315`, 0.5825384587097979, 0.951727273224181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 431}], {
             RGBColor[
             0.43133365387154704`, 0.5480212643488988, 0.948705176904689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 443}], {
             RGBColor[
             0.3646259972920919, 0.4883092353080305, 0.9445254082932095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 486}], {
             RGBColor[
             0.4273749578752095, 0.5445924408467173, 0.9484529322963398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 382}], {
             RGBColor[
             0.2075732378156851, 0.3355030122206657, 0.9351323608652922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 462}], {
             RGBColor[
             0.19657186081581016`, 0.32393986746620806`, 0.934505848720228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 355}], {
             RGBColor[
             0.5108951424447806, 0.6138067180573811, 0.9546386835652754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 372}], {
             RGBColor[
             0.5381758194150634, 0.6359544006023488, 0.9567863183887886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 400}], {
             RGBColor[
             0.7259744000228323, 0.7821275326457193, 0.8841834386643934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 404}], {
             RGBColor[
             0.6494536944870786, 0.7234519269470636, 0.967547153420917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 418}], {
             RGBColor[
             0.4692928666535278, 0.5800321164088754, 0.9513636000208304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 431}], {
             RGBColor[
             0.44166621655022387`, 0.5567328899534418, 0.9494292969038062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 444}], {
             RGBColor[
             0.5139722729928065, 0.6163048712594199, 0.9548809265539167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 486}], {
             RGBColor[
             0.4377075205538863, 0.5533040664512603, 0.949177052295457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 353}], {
             RGBColor[
             0.18295144203234145`, 0.3096239437403533, 0.9337301860201135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 378}], {
             RGBColor[
             0.1960796577618784, 0.3234225308490497, 0.9344778184844558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 380}], {
             RGBColor[
             0.18633207943578872`, 0.3131772079961678, 0.9339227083190349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 487}], {
             RGBColor[
             0.1889676303182698, 0.3159473390772327, 0.9340727990428441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 377}], {
             RGBColor[
             0.181157971499196, 0.3077388924974179, 0.9336280505264527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 412}], {
             RGBColor[
             0.18588998404715956`, 0.3127125377122519, 0.9338975316406739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 426}], {
             RGBColor[
             0.1844406280385869, 0.3111891726527635, 0.9338149929601158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 476}], {
             RGBColor[
             0.18247717121909524`, 0.3091254550451252, 0.9337031769989198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 371}], {
             RGBColor[
             0.2471362919389416, 0.37708629054672044`, 0.937385418269318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 442}], {
             RGBColor[
             0.23904734061072216`, 0.3685842898316257, 0.936924764457707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 460}], {
             RGBColor[
             0.2704319943298352, 0.4015715507923906, 0.9387120740575761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 357}], {
             RGBColor[
             0.185968194480225, 0.3127947418362315, 0.9339019856091351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 367}], {
             RGBColor[
             0.1902708306368736, 0.3173170852397579, 0.9341470143730765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 368}], {
             RGBColor[
             0.1813119634696479, 0.3079007478220177, 0.9336368201413592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 375}], {
             RGBColor[
             0.19306738802691092`, 0.32025644436866674`, 0.9343062741793031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 380}], {
             RGBColor[
             0.18408835379335264`, 0.31081891008554513`, 0.9337949314629927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 487}], {
             RGBColor[
             0.18672390467583372`, 0.3135890411666101, 0.933945022186802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 388}], {
             RGBColor[
             0.3196378407891415, 0.45127596505171874`, 0.9415880184638075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 409}], {
             RGBColor[
             0.28191067367276634`, 0.4134660896464276, 0.9393720026838029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 436}], {
             RGBColor[
             0.33305431044836165`, 0.46289663673916315`, 0.9424429040467747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 473}], {
             RGBColor[
             0.28709080979716467`, 0.41891074115277027`, 0.9396670037727628]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 395}], {
             RGBColor[
             0.5319254348002241, 0.6308800567954042, 0.9562942652159951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 404}], {
             RGBColor[
             0.6982683944179626, 0.7630818994281268, 0.9713900254136139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 431}], {
             RGBColor[
             0.49048091648110803`, 0.596362862434505, 0.9532721688965031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 443}], {
             RGBColor[
             0.4237732599016528, 0.5366508333936366, 0.9490924002850236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 444}], {
             RGBColor[
             0.5627869729236907, 0.655934843740483, 0.9587237985466135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 486}], {
             RGBColor[
             0.48652222048477045`, 0.5929340389323234, 0.9530199242881539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 365}], {
             RGBColor[
             0.2261799618783253, 0.3550598589449443, 0.9361919862744781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 457}], {
             RGBColor[
             0.35728371097557365`, 0.477585785779042, 0.9443210439032999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 494}], {
             RGBColor[
             0.30030937836549265`, 0.4286701061729542, 0.9405711545959381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 367}], {
             RGBColor[
             0.19284697546686017`, 0.3200247767930899, 0.9342937220100794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 368}], {
             RGBColor[
             0.18388810829963448`, 0.3106084393753497, 0.9337835277783622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 441}], {
             RGBColor[
             0.20500595942209238`, 0.33280463985414815`, 0.9349861581587251]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 492}], {
             RGBColor[
             0.1855765306994534, 0.3123830783697226, 0.9338796809362347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 361}], {
             RGBColor[
             0.2274919045840746, 0.3564387939106588, 0.9362666994707252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 386}], {
             RGBColor[
             0.2652427547751048, 0.39611733100357804`, 0.9384165545417262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 398}], {
             RGBColor[
             0.21557110150214517`, 0.3439092740489813, 0.935587827370457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 441}], {
             RGBColor[
             0.22317531852257919`, 0.3519017882726634, 0.9360208762803397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 408}], {
             RGBColor[
             0.923405109023163, 0.9417213092494618, 0.9911392082523272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 440}], {
             RGBColor[
             0.9005793035034079, 0.7657528918366445, 0.6112602253720522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 463}], {
             RGBColor[
             0.7323426131107887, 0.7902188270608363, 0.9746779559842911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 483}], {
             RGBColor[
             0.6807834462506754, 0.7483260934744262, 0.970628611472146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 457}], {
             RGBColor[
             0.5327073882194472, 0.6315148818077295, 0.9563558234535461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 494}], {
             RGBColor[
             0.4757330556093662, 0.5825992022016417, 0.9526059341461844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 386}], {
             RGBColor[
             0.26785160184799417`, 0.39885939468764287`, 0.9385651245230838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 398}], {
             RGBColor[
             0.21817994857503456`, 0.3466513377330461, 0.9357363973518147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 441}], {
             RGBColor[
             0.22578416559546857`, 0.3546438519567282, 0.9361694462616974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 481}], {
             RGBColor[
             0.217684758794606, 0.34613086187697023`, 0.935708197026387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 369}], {
             RGBColor[
             0.1806318866536843, 0.30718594396907933`, 0.9335980907727736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 470}], {
             RGBColor[
             0.1869253840691414, 0.31380080878350786`, 0.9339564961401887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 381}], {
             RGBColor[
             0.18545627477246146`, 0.3122566817657879, 0.9338728325390953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 378}], {
             RGBColor[
             0.20567802361676119`, 0.3335110219340761, 0.9350244312203816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 380}], {
             RGBColor[
             0.19593044529067147`, 0.3232656990811941, 0.9344693210549606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 381}], {
             RGBColor[
             0.19634549402636683`, 0.3237019416180197, 0.9344929574664489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 416}], {
             RGBColor[
             0.20681043357905127`, 0.33470125660338146`, 0.9350889202924836]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 452}], {
             RGBColor[
             0.21560011293675418`, 0.34393976690618655`, 0.9355894795287394]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 468}], {
             RGBColor[
             0.21294670143418915`, 0.3411508631809846, 0.9354383716690389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 487}], {
             RGBColor[
             0.19856599617315254`, 0.3260358301622591, 0.9346194117787698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 405}], {
             RGBColor[
             0.18210802697612394`, 0.3087374610406655, 0.9336821547803826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 423}], {
             RGBColor[
             0.18087837131958237`, 0.30744501498096866`, 0.933612127709855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 429}], {
             RGBColor[
             0.18725297443025463`, 0.3141451270234664, 0.9339751519266276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 465}], {
             RGBColor[
             0.18080307297570358`, 0.30736587164736134`, 0.9336078395805651]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 469}], {
             RGBColor[
             0.1819546848445577, 0.30857628873793674`, 0.9336734221728392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 488}], {
             RGBColor[
             0.1825427715517224, 0.30919440515401764`, 0.933706912840816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 368}], {
             RGBColor[
             0.1881907444562831, 0.3151307827788761, 0.9340285565423035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 375}], {
             RGBColor[
             0.19994616901354612`, 0.3274864793255251, 0.9346980105802476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 441}], {
             RGBColor[
             0.20930859557874099`, 0.3373269832576745, 0.9352311869226664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 450}], {
             RGBColor[
             0.20633807556762712`, 0.3342047783841471, 0.9350620202025242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 492}], {
             RGBColor[
             0.18092029968887635`, 0.3074890843555088, 0.9336145154684589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 456}], {
             RGBColor[
             0.1888191818250698, 0.31579131029870144`, 0.9340643451207662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 390}], {
             RGBColor[
             0.24233683264276484`, 0.3720417545231436, 0.9371120961625645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 422}], {
             RGBColor[
             0.21765000410983476`, 0.3460943324997014, 0.9357062177985042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 443}], {
             RGBColor[
             0.2582982777745515, 0.38881824537072385`, 0.9380210768499777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 451}], {
             RGBColor[
             0.21692330433294027`, 0.34533052495875827`, 0.935664833321266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 442}], {
             RGBColor[
             0.24599324612330464`, 0.37588487692119543`, 0.9373203235011023]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 460}], {
             RGBColor[
             0.2773778998424177, 0.4088721378819603, 0.9391076331009713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 400}], {
             RGBColor[
             0.8020697769239993, 0.8439051876717503, 0.8901739454806034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 404}], {
             RGBColor[
             0.7255490713882455, 0.7852295819730946, 0.9735376602371271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 418}], {
             RGBColor[
             0.5453882435546948, 0.6418097714349063, 0.9573541068370404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 431}], {
             RGBColor[
             0.5177615934513908, 0.6185105449794727, 0.9554198037200161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 444}], {
             RGBColor[
             0.5900676498939734, 0.6780825262854508, 0.9608714333701266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 486}], {
             RGBColor[
             0.5138028974550533, 0.6150817214772912, 0.955167559111667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 449}], {
             RGBColor[
             0.9873031183402635, 0.9734548154410307, 0.5948195031122866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 498}], {
             RGBColor[
             0.8827929559209364, 0.907189051483757, 0.8884954173694475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 397}], {
             RGBColor[
             0.8347270315445021, 0.26793275869910615`, 0.18088795066657473`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 445}], {
             RGBColor[
             0.9052815581912046, 0.6264682491308763, 0.2521450108712031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 402}], {
             RGBColor[
             0.21043597475918854`, 0.33851193025629345`, 0.9352953894991849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 417}], {
             RGBColor[
             0.1999369421366619, 0.32747678129290203`, 0.9346974851232589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 441}], {
             RGBColor[
             0.2121051529687783, 0.3402663423865834, 0.9353904467288932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 450}], {
             RGBColor[
             0.20913463295766446`, 0.3371441375130559, 0.9352212800087508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 461}], {
             RGBColor[
             0.22800718101290143`, 0.35698038210776833`, 0.9362960437010637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 391}], {
             RGBColor[
             0.4221118184289103, 0.5394962463103177, 0.9482660902046844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 448}], {
             RGBColor[
             0.33584647853732147`, 0.4645604445371366, 0.9426484491510583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 455}], {
             RGBColor[
             0.4920767571056538, 0.5962969354126668, 0.9537739864673327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 475}], {
             RGBColor[
             0.3538187512223421, 0.4808817516864462, 0.9437659958516187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 482}], {
             RGBColor[
             0.35174044974950636`, 0.47908163140914517`, 0.9436335683195394]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 412}], {
             RGBColor[
             0.18552364470094684`, 0.3123274918321262, 0.9338766691568576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 426}], {
             RGBColor[
             0.1840742886923742, 0.31080412677263786`, 0.9337941304762996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 476}], {
             RGBColor[
             0.18211083187288252`, 0.3087404091649995, 0.9336823145151034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 380}], {
             RGBColor[
             0.19721656952288963`, 0.32461749719424154`, 0.9345425639273353]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 416}], {
             RGBColor[
             0.2080965578112694, 0.3360530547164289, 0.9351621631648581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 452}], {
             RGBColor[
             0.21688623716897232`, 0.34529156501923397`, 0.935662722401114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 487}], {
             RGBColor[
             0.1998521204053707, 0.32738762827530654`, 0.9346926546511444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 400}], {
             RGBColor[
             0.9086464403656656, 0.6009403996477325, 0.49573306309233295`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 404}], {
             RGBColor[
             0.8321257348299118, 0.5422647939490768, 0.5790967778488565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 440}], {
             RGBColor[
             0.8595285144156211, 0.406306411086346, 0.20259145280411195`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 487}], {
             RGBColor[
             0.19010454207928099`, 0.31714230542242455`, 0.9341375444857234]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 416}], {
             RGBColor[
             0.19876402822087508`, 0.3262439744003725, 0.9346306894109254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 468}], {
             RGBColor[
             0.20490029607601296`, 0.33269358097797563`, 0.9349801407874807]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 425}], {
             RGBColor[
             0.19937423959475875`, 0.32688534524395996`, 0.9346654400459413]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 462}], {
             RGBColor[
             0.20106839690715364`, 0.3286660119950647, 0.934761919798601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 393}], {
             RGBColor[
             0.24454516184141023`, 0.374362848527078, 0.9372378572434972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 395}], {
             RGBColor[
             0.3859577461997916, 0.503550871102866, 0.9463338532888385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 443}], {
             RGBColor[
             0.2778055713012203, 0.40932164770109847`, 0.9391319883578669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 480}], {
             RGBColor[
             0.2555678088390552, 0.3859483493977877, 0.937865580683468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 402}], {
             RGBColor[
             0.24310211003433443`, 0.3728461095830723, 0.937155677577888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 411}], {
             RGBColor[
             0.2746421437909936, 0.40599668481496154`, 0.9389518358410311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 458}], {
             RGBColor[
             0.25354859204463764`, 0.3838260245211157, 0.9377505892741895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 461}], {
             RGBColor[
             0.26067331628804735`, 0.3913145614345472, 0.9381563317797668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 499}], {
             RGBColor[
             0.4483239267217146, 0.554218492373762, 0.9512402754132152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 415}], {
             RGBColor[
             0.18097729894859016`, 0.30754899419142984`, 0.9336177614919767]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 446}], {
             RGBColor[
             0.18248129368631721`, 0.30912978801955504`, 0.9337034117673295]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 441}], {
             RGBColor[
             0.26353501578649874`, 0.39432238904964745`, 0.9383193013326985]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 498}], {
             RGBColor[
             0.540094387984412, 0.6311849610997022, 0.9594410817544053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 439}], {
             RGBColor[
             0.1940605439508961, 0.3213003142144977, 0.9343628329399316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 436}], {
             RGBColor[
             0.34210441687378856`, 0.470735384053293, 0.943019568825508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 473}], {
             RGBColor[
             0.2961409162225916, 0.4267494884669002, 0.9402436685514961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 456}], {
             RGBColor[
             0.1952664503716337, 0.322567798321576, 0.9344315075266139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 472}], {
             RGBColor[
             0.18902863113306126`, 0.3160114548012536, 0.9340762729490037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 422}], {
             RGBColor[
             0.23122695863113757`, 0.36036457253022636`, 0.9364794052731881]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 443}], {
             RGBColor[
             0.2718752322958543, 0.4030884854012488, 0.9387942643246616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 451}], {
             RGBColor[
             0.23050025885424308`, 0.3596007649892832, 0.93643802079595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 407}], {
             RGBColor[
             0.3751221590981358, 0.49587301171236503`, 0.9453789816308452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 448}], {
             RGBColor[
             0.38684939186323586`, 0.5081990768979878, 0.9460468301879315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 455}], {
             RGBColor[
             0.5430796704315681, 0.6399355677735181, 0.9571723675042059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 475}], {
             RGBColor[
             0.40482166454825647`, 0.5245203840472975, 0.9471643768884919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 478}], {
             RGBColor[
             0.36121422406998477`, 0.4812548901837663, 0.9445869453059381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 482}], {
             RGBColor[
             0.4027433630754207, 0.5227202637699965, 0.9470319493564127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 413}], {
             RGBColor[
             0.23358028524334118`, 0.3628380680091775, 0.9366134237423184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 473}], {
             RGBColor[
             0.2502222365996353, 0.3803298140453018, 0.9375611582524985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 474}], {
             RGBColor[
             0.23318205607902553`, 0.3624195039082944, 0.9365907451805379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 490}], {
             RGBColor[
             0.2264092533563037, 0.355300858826219, 0.9362050440849425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 424}], {
             RGBColor[
             0.20739385044843295`, 0.3353144647238677, 0.935122145020107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 480}], {
             RGBColor[
             0.23233850550566576`, 0.36153287877149787`, 0.9365427062233063]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 467}], {
             RGBColor[
             0.18730056337306505`, 0.3141951460196734, 0.9339778620465191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 443}], {
             RGBColor[
             0.39598885232621217`, 0.5140941996505966, 0.9469051099430464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 430}], {
             RGBColor[
             0.19949732248348956`, 0.32701471316392194`, 0.9346724494343697]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 477}], {
             RGBColor[
             0.19761610506605493`, 0.32503743438212485`, 0.9345653168854586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 495}], {
             RGBColor[
             0.8540509182502993, 0.3729173999622112, 0.19768732648561016`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 399}], {
             RGBColor[
             0.2070690587330349, 0.3349730880380002, 0.9351036486124014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 464}], {
             RGBColor[
             0.20435657897174597`, 0.33212209982773555`, 0.9349491769027501]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 481}], {
             RGBColor[
             0.20576395571267658`, 0.3336013420152928, 0.9350293249261188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 496}], {
             RGBColor[
             0.19603720028339988`, 0.32337790534720917`, 0.9344754005938667]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 407}], {
             RGBColor[
             0.2425042792072058, 0.3722177514790964, 0.9371216319966944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 464}], {
             RGBColor[
             0.20516649221167577`, 0.332973369994367, 0.9349953002636049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 478}], {
             RGBColor[
             0.22859634417905478`, 0.3575996299504977, 0.9363295956717873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 481}], {
             RGBColor[
             0.20657386895260635`, 0.3344526121819243, 0.9350754482869736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 496}], {
             RGBColor[
             0.19684711352332962`, 0.3242291755138407, 0.9345215239547214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 404}], {
             RGBColor[
             0.9133476519960143, 0.9314027140164651, 0.9009347805127319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 418}], {
             RGBColor[
             0.7331868241624636, 0.7879829034782768, 0.8847512271126452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 431}], {
             RGBColor[
             0.7055601740591597, 0.7646836770228431, 0.882816923995621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 444}], {
             RGBColor[
             0.7778662305017423, 0.8242556583288213, 0.8882685536457314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 428}], {
             RGBColor[
             0.18425068425914937`, 0.3109895296974434, 0.9338041759428735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 437}], {
             RGBColor[
             0.18132345879022535`, 0.30791283013279, 0.9336374747828603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 451}], {
             RGBColor[
             0.192907026989333, 0.3200878947506953, 0.934297141855446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 417}], {
             RGBColor[
             0.20763019049226705`, 0.33556287309476157`, 0.9351356042359695]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 458}], {
             RGBColor[
             0.2285757051250969, 0.3575779369961964, 0.9363284203081972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 461}], {
             RGBColor[
             0.23570042936850655`, 0.3650664739096279, 0.9367341628137743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 440}], {
             RGBColor[
             0.8175206971599966, 0.7001431418216288, 0.6031737768596591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 445}], {
             RGBColor[
             0.8532638533992596, 0.8433645979013125, 0.6431418553174187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 471}], {
             RGBColor[
             0.8501227775795742, 0.8834026890475528, 0.9665040763953929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 483}], {
             RGBColor[
             0.5977248399072642, 0.6827163434594106, 0.9625421629597528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 497}], {
             RGBColor[
             0.6107955480026974, 0.6933624123353453, 0.9635615550100725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 418}], {
             RGBColor[
             0.6566661186267099, 0.7293072977796211, 0.9681149418691689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 431}], {
             RGBColor[
             0.629039468523406, 0.7060080713241875, 0.9661806387521447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 444}], {
             RGBColor[
             0.7013455249659886, 0.7655800526301657, 0.9716322684022551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 486}], {
             RGBColor[
             0.6250807725270684, 0.7025792478220061, 0.9659283941437955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 423}], {
             RGBColor[
             0.18042956728835297`, 0.30697329348832747`, 0.9335865689842227]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 429}], {
             RGBColor[
             0.1868041703990252, 0.3136734055308251, 0.9339495932009951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 472}], {
             RGBColor[
             0.1823975349558204, 0.3090417522831926, 0.9336986418315376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 488}], {
             RGBColor[
             0.182093967520493, 0.30872268366137645`, 0.9336813541151835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 419}], {
             RGBColor[
             0.5328942370686292, 0.630560819878426, 0.9567192886891854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 493}], {
             RGBColor[
             0.33870341661598447`, 0.4633663515821581, 0.9429648172026237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 448}], {
             RGBColor[
             0.28885681920654693`, 0.42093720993918393`, 0.9397613405772192]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 455}], {
             RGBColor[
             0.44508709777487926`, 0.5526737008147141, 0.9508868778934936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 475}], {
             RGBColor[
             0.3068290918915676, 0.4372585170884935, 0.9408788872777796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 478}], {
             RGBColor[
             0.2632216514132959, 0.39399302322496244`, 0.9383014556952256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 482}], {
             RGBColor[
             0.3047507904187318, 0.43545839681119247`, 0.9407464597457003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{408, 463}], {
             RGBColor[
             0.746221620758815, 0.8012446952293572, 0.9745845586722801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 430}], {
             RGBColor[
             0.22739490707234228`, 0.3563368433758307, 0.9362611756059269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 422}], {
             RGBColor[
             0.19439415698617535`, 0.3216509626668643, 0.9343818317087544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 428}], {
             RGBColor[
             0.18501111447909718`, 0.3117887900726693, 0.9338474813189439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 437}], {
             RGBColor[
             0.1820838890101732, 0.30871209050801585`, 0.9336807801589306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{412, 426}], {
             RGBColor[
             0.18880630124033773`, 0.3157777719874718, 0.9340636115905208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{412, 476}], {
             RGBColor[
             0.18684284442084606`, 0.31371405437983346`, 0.9339517956293248]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 474}], {
             RGBColor[
             0.2299117533537109, 0.35898220839482003`, 0.9364045062783105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 490}], {
             RGBColor[
             0.2231389506309891, 0.3518635633127446, 0.9360188051827152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 461}], {
             RGBColor[
             0.337969115719834, 0.4620246100212727, 0.9429438683225567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 498}], {
             RGBColor[
             0.5986264598736242, 0.6821731423501425, 0.9631600517720931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 499}], {
             RGBColor[
             0.5256197261535013, 0.6249285409604874, 0.9560278119560052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 452}], {
             RGBColor[
             0.2180186471312624, 0.3464817996885393, 0.935727211473216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 468}], {
             RGBColor[
             0.21536523562869736`, 0.3436928959633374, 0.9355761036135155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{417, 458}], {
             RGBColor[
             0.21807667250257026`, 0.34654278803280497`, 0.9357305159322711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 431}], {
             RGBColor[
             0.4488786406898552, 0.5625882607859993, 0.9499970853520581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 444}], {
             RGBColor[
             0.5211846971324379, 0.6221602420919774, 0.9554487150021684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 486}], {
             RGBColor[
             0.4449199446935177, 0.5591594372838178, 0.9497448407437088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 427}], {
             RGBColor[
             0.1872793778515779, 0.31417287869335075`, 0.9339766555624116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 454}], {
             RGBColor[
             0.19971846915340663`, 0.3272471523355135, 0.9346850434100643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 489}], {
             RGBColor[
             0.189832836442401, 0.3168567255709313, 0.9341220712516556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 500}], {
             RGBColor[
             0.19451665335716928`, 0.32177971411949735`, 0.9343888076958655]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 430}], {
             RGBColor[
             0.19294646407159283`, 0.3201293456246058, 0.9342993877389387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 459}], {
             RGBColor[
             0.18940834947071425`, 0.31641056284966007`, 0.9340978973465902]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 477}], {
             RGBColor[
             0.1910652466541582, 0.31815206684280867`, 0.9341922551900277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 428}], {
             RGBColor[
             0.19715708759112932`, 0.32455497791258914`, 0.9345391765193171]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 437}], {
             RGBColor[
             0.1942298621222053, 0.32147827834793574`, 0.9343724753593039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 451}], {
             RGBColor[
             0.20581343032131297`, 0.33365334296584104`, 0.9350321424318895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 429}], {
             RGBColor[
             0.18557451474248365`, 0.3123809594711283, 0.9338795661304677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 465}], {
             RGBColor[
             0.1791246132879326, 0.3056017040950233, 0.9335122537844052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 469}], {
             RGBColor[
             0.18027622515678673`, 0.30681212118559864`, 0.9335778363766793]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 488}], {
             RGBColor[
             0.18086431186395144`, 0.3074302376016796, 0.933611327044656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{425, 462}], {
             RGBColor[
             0.1883728625948838, 0.3153222004895023, 0.9340389279008772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 476}], {
             RGBColor[
             0.1853934884122734, 0.3121906893203451, 0.9338692569487667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 433}], {
             RGBColor[
             0.18359379097292866`, 0.3102990932041856, 0.9337667668420098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 500}], {
             RGBColor[
             0.19375142518042626`, 0.32097541078747177`, 0.9343452290832536]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 437}], {
             RGBColor[
             0.18484681961512717`, 0.31161610575374077`, 0.9338381249694931]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 451}], {
             RGBColor[
             0.19643038781423483`, 0.323791170371646, 0.934497792042079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{429, 488}], {
             RGBColor[
             0.1872389149746237, 0.3141303496441773, 0.9339743512614285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{430, 459}], {
             RGBColor[
             0.19801808656198788`, 0.32545994242144927`, 0.9345882091369736]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{430, 477}], {
             RGBColor[
             0.19967498374543186`, 0.3272014464145979, 0.9346825669804111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 444}], {
             RGBColor[
             0.4935580470291339, 0.5988610156365437, 0.9535144118851442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 486}], {
             RGBColor[
             0.4172932945902137, 0.5358602108283841, 0.9478105376266845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{432, 460}], {
             RGBColor[
             0.2959533208946317, 0.4283960831575556, 0.9401654758500221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 465}], {
             RGBColor[
             0.17986137360753812`, 0.306376085904231, 0.9335542111946675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 469}], {
             RGBColor[
             0.18101298547639227`, 0.3075865029948064, 0.9336197937869416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 495}], {
             RGBColor[
             0.9105859845179732, 0.6779864914594717, 0.24664336835265455`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{435, 439}], {
             RGBColor[
             0.21881441649795172`, 0.3473182037476218, 0.9357725293614136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{435, 453}], {
             RGBColor[
             0.2391644667053946, 0.36870739678334974`, 0.9369314346155262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 473}], {
             RGBColor[
             0.30955738588181175`, 0.4383701601543446, 0.9410985541344632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 439}], {
             RGBColor[
             0.2009360669634459, 0.3285269248340248, 0.9347543838040715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{439, 453}], {
             RGBColor[
             0.21958035723127328`, 0.3481232560217902, 0.9358161485530685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 445}], {
             RGBColor[
             0.9273756618709421, 0.7440317986720315, 0.27125592363752593`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 471}], {
             RGBColor[
             0.9242345860512566, 0.784069889818272, 0.5946181447155001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 450}], {
             RGBColor[
             0.21849705952285933`, 0.34698464144520536`, 0.9357544563511697]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 461}], {
             RGBColor[
             0.2373696075780963, 0.3668208860399178, 0.9368292200434826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 447}], {
             RGBColor[
             0.23581693788510275`, 0.36518893174763706`, 0.9367407978014356]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 500}], {
             RGBColor[
             0.21944649774055142`, 0.34798256120985954`, 0.9358085254530993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{443, 451}], {
             RGBColor[
             0.24646170398602968`, 0.37637725583686343`, 0.9373470014833631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{444, 486}], {
             RGBColor[
             0.4895993510327964, 0.5954321921343623, 0.953262167276795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{445, 471}], {
             RGBColor[
             0.9599777422905198, 0.9272913458979556, 0.6345862231732597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 454}], {
             RGBColor[
             0.2225609566268063, 0.3512560549674121, 0.9359858892792425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 500}], {
             RGBColor[
             0.21735914083056895`, 0.34578861675139594`, 0.9356896535650436]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 455}], {
             RGBColor[
             0.45681433053997933`, 0.564999766000337, 0.9515547264505798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 475}], {
             RGBColor[
             0.3185563246566676, 0.44958458227411635`, 0.9415467358348658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 478}], {
             RGBColor[
             0.2749488841783959, 0.4063190884105853, 0.938969304252312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 482}], {
             RGBColor[
             0.3164780231838319, 0.4477844619968153, 0.9414143083027866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{449, 499}], {
             RGBColor[
             0.8060897526290038, 0.8328531529864611, 0.6773590298414771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 461}], {
             RGBColor[
             0.23439908756698247`, 0.3636986811663903, 0.9366600533233402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{452, 468}], {
             RGBColor[
             0.22415491498640028`, 0.35293140626614244`, 0.9360766628497713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 489}], {
             RGBColor[
             0.20150669956748674`, 0.32912669588106847`, 0.9347868804866963]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 500}], {
             RGBColor[
             0.206190516482255, 0.33404968442963456`, 0.9350536169309063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{455, 475}], {
             RGBColor[
             0.47478660322499994`, 0.5813210731496465, 0.9526722731511402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{455, 482}], {
             RGBColor[
             0.47270830175216416`, 0.5795209528723455, 0.952539845619061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{457, 494}], {
             RGBColor[
             0.4122768656126409, 0.531082608493518, 0.9476104304219592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{458, 461}], {
             RGBColor[
             0.24614691137880979`, 0.3760463888476713, 0.937329074510076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{459, 477}], {
             RGBColor[
             0.19613686914455325`, 0.32348266363965217`, 0.9344810765880625]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{460, 463}], {
             RGBColor[
             0.42791636353987605`, 0.5415498055841811, 0.9492787976467367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{463, 483}], {
             RGBColor[
             0.5035999579863275, 0.6078494794543214, 0.954073961892099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 481}], {
             RGBColor[
             0.2038613891913174, 0.3316016239716596, 0.9349209765773223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 496}], {
             RGBColor[
             0.1941346337620407, 0.32137818730357604`, 0.9343670522450702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{465, 469}], {
             RGBColor[
             0.18020092681290795`, 0.30673297785199133`, 0.9335735482473893]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 470}], {
             RGBColor[
             0.19475005924981162`, 0.3220250385114528, 0.9344020998161584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 491}], {
             RGBColor[
             0.1882565372451065, 0.3151999351714332, 0.9340323033442953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 483}], {
             RGBColor[
             0.7044387287985243, 0.7666430914560537, 0.9539865308155939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 497}], {
             RGBColor[
             0.7175094368939575, 0.7772891603319885, 0.9550059228659136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{472, 488}], {
             RGBColor[
             0.18283227953141887`, 0.3094986963965447, 0.933723399891971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{474, 490}], {
             RGBColor[
             0.22274072146667342`, 0.35144499921186156`, 0.9359961266209347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{475, 478}], {
             RGBColor[
             0.2929211568634166, 0.42264039555989485`, 0.9400868509528724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{475, 482}], {
             RGBColor[
             0.3344502958688525, 0.46410576914612495`, 0.942531855003347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{478, 482}], {
             RGBColor[
             0.2908428553905808, 0.4208402752825938, 0.939954423420793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{481, 496}], {
             RGBColor[
             0.19554201050297132`, 0.3228574294911333, 0.934447200268439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{484, 490}], {
             RGBColor[
             0.2003898909918431, 0.3279528592583135, 0.9347232798904836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{489, 500}], {
             RGBColor[
             0.19630488377124938`, 0.3236592576650523, 0.9344906447724974]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.028685633809430733`], {
             RGBColor[
             0.19927754620079638`, 0.32678371435619025`, 0.9346599335002002]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.028685633809430733`], {
             RGBColor[
             0.18419449056434983`, 0.3109304665613231, 0.9338009757950858]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.028685633809430733`], {
             RGBColor[
             0.18365861817242612`, 0.31036723070113925`, 0.9337704586551179]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.028685633809430733`], {
             RGBColor[
             0.18151204232925333`, 0.30811104338919537`, 0.9336482143364235]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.028685633809430733`], {
             RGBColor[
             0.6895762664964494, 0.7574214874515429, 0.9696941758539234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.028685633809430733`], {
             RGBColor[
             0.21439443043390383`, 0.3426725181510049, 0.9355208176938495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.028685633809430733`], {
             RGBColor[
             0.47235402937887205`, 0.5825173062131191, 0.951604585963978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.028685633809430733`], {
             RGBColor[
             0.19748659103157024`, 0.32490130692021735`, 0.9345579412527936]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.028685633809430733`], {
             RGBColor[
             0.1937919382554366, 0.32101799259798497`, 0.9343475362429416]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.028685633809430733`], {
             RGBColor[
             0.22678684537035088`, 0.355697731973699, 0.9362265473915452]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.028685633809430733`], {
             RGBColor[
             0.37557365642318313`, 0.49972475713808634`, 0.9451521991739089]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.028685633809430733`], {
             RGBColor[
             0.19403535624859544`, 0.3212738403423871, 0.9343613985375474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.028685633809430733`], {
             RGBColor[
             0.25294530714331137`, 0.3831919338393498, 0.9377162330915391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.028685633809430733`], {
             RGBColor[
             0.2309802119470121, 0.36010522612056717`, 0.9364653534145562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.028685633809430733`], {
             RGBColor[
             0.6524065300643914, 0.7283842068503593, 0.9659894438973117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.028685633809430733`], {
             RGBColor[
             0.27011669665931304`, 0.4012401529496448, 0.9386941183216809]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.028685633809430733`], {
             RGBColor[
             0.3754434746784675, 0.49961200025393837`, 0.9451439041082509]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.028685633809430733`], {
             RGBColor[
             0.2883133698343315, 0.42036601019230513`, 0.9397303919394328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.028685633809430733`], {
             RGBColor[
             0.20321773659331793`, 0.33092510428123034`, 0.934884321514065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.028685633809430733`], {
             RGBColor[
             0.24175756143219096`, 0.3714329037529144, 0.9370791075240773]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.028685633809430733`], {
             RGBColor[
             0.3000028152540131, 0.4326523584820372, 0.9403960885630988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.028685633809430733`], {
             RGBColor[
             0.1817982963009414, 0.30841191446298966`, 0.9336645160766364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.028685633809430733`], {
             RGBColor[
             0.4319501958436354, 0.5485552820168211, 0.9487444624139638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.028685633809430733`], {
             RGBColor[
             0.18529079599648704`, 0.31208275308027844`, 0.9338634087676074]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.028685633809430733`], {
             RGBColor[
             0.2888948585418871, 0.42097719169245956`, 0.9397635068610926]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.028685633809430733`], {
             RGBColor[
             0.1848952269737127, 0.31166698495681794`, 0.9338408816969523]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.028685633809430733`], {
             RGBColor[
             0.18521154867326725`, 0.3119994591190039, 0.933858895749786]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.028685633809430733`], {
             RGBColor[
             0.47584147550400935`, 0.5853485720851631, 0.951879130497885]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.028685633809430733`], {
             RGBColor[
             0.1844293578243088, 0.3111773269429844, 0.9338143511380854]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.028685633809430733`], {
             RGBColor[
             0.17893397678527326`, 0.30540133304367595`, 0.9335013973176001]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.028685633809430733`], {
             RGBColor[
             0.19198099569549876`, 0.3191145771471003, 0.9342444057432027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.028685633809430733`], {
             RGBColor[
             0.21967241372144744`, 0.34822001322968177`, 0.9358213910339986]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.028685633809430733`], {
             RGBColor[
             0.25627137654269866`, 0.3866878436630859, 0.9379056478233554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.028685633809430733`], {
             RGBColor[
             0.2089289231192469, 0.33692792343012196`, 0.9352095651377733]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.028685633809430733`], {
             RGBColor[
             0.187649142725438, 0.3145615250202248, 0.9339977131249598]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.028685633809430733`], {
             RGBColor[
             0.9941315043202534, 0.9918412404700345, 0.7469196908007765]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.028685633809430733`], {
             RGBColor[
             0.861854760386902, 0.4655965562049136, 0.20644056462819607`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.028685633809430733`], {
             RGBColor[
             0.5188198477638203, 0.6202403508392836, 0.9552625453971423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.028685633809430733`], {
             RGBColor[
             0.24759097892264678`, 0.3775641953954144, 0.937411312020391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.028685633809430733`], {
             RGBColor[
             0.18500874865393632`, 0.31178630344042324`, 0.9338473465887008]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.028685633809430733`], {
             RGBColor[
             0.2630876311955555, 0.3938521594787447, 0.9382938234420904]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.028685633809430733`], {
             RGBColor[
             0.2005501569047806, 0.3281213088942566, 0.9347324067971333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.028685633809430733`], {
             RGBColor[
             0.22836865224462058`, 0.35736031129090495`, 0.9363166289529613]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.028685633809430733`], {
             RGBColor[
             0.2790104916899246, 0.4105880954259918, 0.9392006067914836]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.028685633809430733`], {
             RGBColor[
             0.2011773237053474, 0.3287805009663242, 0.9347681230186154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.028685633809430733`], {
             RGBColor[
             0.2037103551444467, 0.3314428776122868, 0.934912375411788]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.028685633809430733`], {
             RGBColor[
             0.28160948378147765`, 0.4133198008998302, 0.9393486155462334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.028685633809430733`], {
             RGBColor[
             0.18988308106937135`, 0.3169095358595705, 0.9341249326088312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.028685633809430733`], {
             RGBColor[
             0.9939249281250245, 0.9894143604804412, 0.5801441012857329]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.028685633809430733`], {
             RGBColor[
             0.8803633253605091, 0.9074418350893442, 0.9884510339541455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.028685633809430733`], {
             RGBColor[
             0.9952524916716045, 0.9922538846693116, 0.7246412005584384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.028685633809430733`], {
             RGBColor[
             0.1799948891424975, 0.30651641919684713`, 0.9335618147068648]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.028685633809430733`], {
             RGBColor[
             0.8326746621018166, 0.2521573478086015, 0.17892259937043942`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.028685633809430733`], {
             RGBColor[
             0.9895254911096693, 0.9899365356383177, 0.8232532496802422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.028685633809430733`], {
             RGBColor[
             0.5735931996355866, 0.6647078254001658, 0.9595745042978867]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.028685633809430733`], {
             RGBColor[
             0.4068474012204774, 0.5268125030173851, 0.9471449345381059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.028685633809430733`], {
             RGBColor[
             0.9626408166905339, 0.9716581627746242, 0.9481235318941049]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.028685633809430733`], {
             RGBColor[
             0.19316750906165184`, 0.32036167792421966`, 0.9343119759241159]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.028685633809430733`], {
             RGBColor[
             0.26299592027232827`, 0.3937557654836245, 0.9382886006406869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.028685633809430733`], {
             RGBColor[
             0.9854928836228277, 0.9882689488092234, 0.890083991790846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.028685633809430733`], {
             RGBColor[
             0.9902590342278114, 0.9902398745688678, 0.8110965418638902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.028685633809430733`], {
             RGBColor[
             0.25119317281524384`, 0.3813503295688181, 0.9376164516336061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.028685633809430733`], {
             RGBColor[
             0.20681114074536727`, 0.3347019998800166, 0.9350889605645591]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.028685633809430733`], {
             RGBColor[
             0.18480592008610275`, 0.3115731177555562, 0.9338357958018207]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.028685633809430733`], {
             RGBColor[
             0.183179266829206, 0.30986340204678436`, 0.9337431603052583]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.028685633809430733`], {
             RGBColor[
             0.19788231111085003`, 0.3253172338136426, 0.9345804769258931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.028685633809430733`], {
             RGBColor[
             0.18087272641393248`, 0.30743908182722296`, 0.9336118062408292]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.028685633809430733`], {
             RGBColor[
             0.18542751526237852`, 0.31222645369723245`, 0.933871194727542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.028685633809430733`], {
             RGBColor[
             0.44285619720498837`, 0.5580015122444584, 0.9494393831769108]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.028685633809430733`], {
             RGBColor[
             0.3697431424982056, 0.49467465902642144`, 0.9447806839823304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.028685633809430733`], {
             RGBColor[
             0.19773867236084267`, 0.32516626038016205`, 0.9345722969115747]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.028685633809430733`], {
             RGBColor[
             0.21111609134757603`, 0.339226775912571, 0.9353341211327513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.028685633809430733`], {
             RGBColor[
             0.5768983856608343, 0.6673911243123956, 0.9598347006490895]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.028685633809430733`], {
             RGBColor[
             0.18870685733270803`, 0.31567325013544506`, 0.9340579484070953]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.028685633809430733`], {
             RGBColor[
             0.8653183386459826, 0.4813238561401438, 0.20933065922764493`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.028685633809430733`], {
             RGBColor[
             0.4104281337116228, 0.5299139535283672, 0.9473730956461243]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.028685633809430733`], {
             RGBColor[
             0.33446793820227666`, 0.46412105004860754`, 0.9425329791572322]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.028685633809430733`], {
             RGBColor[
             0.4700607186843903, 0.5806554932788695, 0.9514240481454346]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.028685633809430733`], {
             RGBColor[
             0.8862469572430673, 0.9121332834455631, 0.9890122200154841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.028685633809430733`], {
             RGBColor[
             0.3474160266946404, 0.4753360335108428, 0.9433580199064205]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.028685633809430733`], {
             RGBColor[
             0.23835692087692842`, 0.36785861491626903`, 0.9368854460752519]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.028685633809430733`], {
             RGBColor[
             0.5201221497039563, 0.62129761822232, 0.955365067376359]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.028685633809430733`], {
             RGBColor[
             0.9952268649647723, 0.9922942002460275, 0.7287667302186207]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.028685633809430733`], {
             RGBColor[
             0.27551545928723997`, 0.406914594772917, 0.9390015698665879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.028685633809430733`], {
             RGBColor[
             0.18726966457396857`, 0.31416266942272597`, 0.9339761024056213]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.028685633809430733`], {
             RGBColor[
             0.18531184315250615`, 0.31210487497572126`, 0.9338646073720063]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.028685633809430733`], {
             RGBColor[
             0.30841227476556676`, 0.4414912336192087, 0.9408749948416013]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.028685633809430733`], {
             RGBColor[
             0.18955897979005848`, 0.3165688848658047, 0.9341064755204392]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.028685633809430733`], {
             RGBColor[
             0.30968149308884285`, 0.4426522770943059, 0.940953608792397]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.028685633809430733`], {
             RGBColor[
             0.2623509631444437, 0.39307787464957405`, 0.9382518712863824]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.028685633809430733`], {
             RGBColor[
             0.46032419676718667`, 0.5727509461611696, 0.9506575534740573]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.028685633809430733`], {
             RGBColor[
             0.27193911320159614`, 0.4031556282834669, 0.9387979022477403]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.028685633809430733`], {
             RGBColor[
             0.2226303791602024, 0.3513290224516542, 0.935989842789818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.028685633809430733`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.028685633809430733`], {
             RGBColor[
             0.1846806812934658, 0.3114414838438967, 0.9338286636378542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.028685633809430733`], {
             RGBColor[
             0.4707743379765772, 0.5812348415684494, 0.9514802268701891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.028685633809430733`], {
             RGBColor[
             0.9884567952610653, 0.9727242013215213, 0.40965725865088887`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.028685633809430733`], {
             RGBColor[
             0.18830185869099547`, 0.3152475708846082, 0.9340348843335916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.028685633809430733`], {
             RGBColor[
             0.9796979203258498, 0.9843793227373989, 0.9192503046446351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.028685633809430733`], {
             RGBColor[
             0.9932268871291124, 0.987921321372956, 0.5041666466903745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.028685633809430733`], {
             RGBColor[
             0.24511118458418202`, 0.3749577743176459, 0.9372700914013423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.028685633809430733`], {
             RGBColor[
             0.19944242864104303`, 0.32695701625504003`, 0.9346693233112505]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.028685633809430733`], {
             RGBColor[
             0.40980409560216274`, 0.5293734430830204, 0.9473333324896046]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.028685633809430733`], {
             RGBColor[
             0.9241317229671294, 0.73691459370894, 0.25781280732325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.028685633809430733`], {
             RGBColor[
             0.1914252698739526, 0.31853047407360313`, 0.9342127579797883]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.028685633809430733`], {
             RGBColor[
             0.17964740484760663`, 0.30615119117114004`, 0.9335420259903278]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.028685633809430733`], {
             RGBColor[
             0.21128649273995928`, 0.33940587858003807`, 0.9353438252399612]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.028685633809430733`], {
             RGBColor[
             0.20961363351384976`, 0.337647597467996, 0.9352485583818076]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.028685633809430733`], {
             RGBColor[
             0.2136359512540558, 0.3418753084426271, 0.9354776234266265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.028685633809430733`], {
             RGBColor[
             0.4170759329154467, 0.5356719430706164, 0.9477966875329739]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.028685633809430733`], {
             RGBColor[
             0.3665915053486955, 0.49194486933340476`, 0.9445798644500469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.028685633809430733`], {
             RGBColor[
             0.9934414779456845, 0.9915558968312813, 0.7583552135583986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.028685633809430733`], {
             RGBColor[
             0.19671677940387242`, 0.3240921860906307, 0.9345141016194304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.028685633809430733`], {
             RGBColor[
             0.18143431560131953`, 0.3080293476699778, 0.9336437879142542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.028685633809430733`], {
             RGBColor[
             0.19098661972276523`, 0.31806942495267926`, 0.934187777502603]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.028685633809430733`], {
             RGBColor[
             0.27647894211230134`, 0.40792727631039594`, 0.9390564387881299]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.028685633809430733`], {
             RGBColor[
             0.18356396795554494`, 0.3102677473220268, 0.933765068465289]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.028685633809430733`], {
             RGBColor[
             0.19221104916857337`, 0.3193563779335344, 0.9342575069481607]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.028685633809430733`], {
             RGBColor[
             0.18431898451928125`, 0.31106131760132866`, 0.9338080655416469]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.028685633809430733`], {
             RGBColor[
             0.1799037129149489, 0.30642058720078685`, 0.9335566223555891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.028685633809430733`], {
             RGBColor[
             0.20513244387794988`, 0.3329375830368321, 0.9349933612613692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.028685633809430733`], {
             RGBColor[
             0.18567855904381614`, 0.3124903166286185, 0.9338854912995088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.028685633809430733`], {
             RGBColor[
             0.18584647349383113`, 0.3126668053619753, 0.93389505377903]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.028685633809430733`], {
             RGBColor[
             0.18536877790044387`, 0.31216471700567533`, 0.9338678497216739]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.028685633809430733`], {
             RGBColor[
             0.7779497574122243, 0.8264595302183536, 0.978502419531181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.028685633809430733`], {
             RGBColor[
             0.4884562669939937, 0.5955898281066129, 0.9528722130934804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.028685633809430733`], {
             RGBColor[
             0.8321508631713839, 0.8689985264321587, 0.9838524862707736]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.028685633809430733`], {
             RGBColor[
             0.19425607642724724`, 0.32150583124461773`, 0.9343739682251954]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.028685633809430733`], {
             RGBColor[
             0.2893758023858067, 0.42148269416601997`, 0.9397908959015111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.028685633809430733`], {
             RGBColor[
             0.30291909395791666`, 0.43571755230258913`, 0.9405621663210384]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.028685633809430733`], {
             RGBColor[
             0.8337292727736055, 0.2602635475653142, 0.17993249574075687`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.028685633809430733`], {
             RGBColor[
             0.2723145403641676, 0.4035502260347864, 0.938819282269254]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.028685633809430733`], {
             RGBColor[
             0.19798057442534764`, 0.32542051478743356`, 0.9345860728762861]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.028685633809430733`], {
             RGBColor[
             0.18413129784782198`, 0.3108640470096027, 0.9337973770633647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.028685633809430733`], {
             RGBColor[
             0.17999586170885287`, 0.3065174414257509, 0.93356187009308]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.028685633809430733`], {
             RGBColor[
             0.5282221961294052, 0.6278736008134325, 0.956002732702418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.028685633809430733`], {
             RGBColor[
             0.2116557852103354, 0.33979402838089834`, 0.9353648558998299]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.028685633809430733`], {
             RGBColor[
             0.1827700546655207, 0.3094332941172014, 0.9337198562779115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.028685633809430733`], {
             RGBColor[
             0.18259939511325524`, 0.3092539201073298, 0.9337101374688782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.028685633809430733`], {
             RGBColor[
             0.17901437519538227`, 0.3054858368702541, 0.933505975888117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.028685633809430733`], {
             RGBColor[
             0.2073090188644706, 0.33522530135049017`, 0.9351173139868973]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.028685633809430733`], {
             RGBColor[
             0.21571267720568413`, 0.3440580790898188, 0.9355958898973311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.028685633809430733`], {
             RGBColor[
             0.5806518106608889, 0.6704383238173092, 0.9601301840143426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.028685633809430733`], {
             RGBColor[
             0.1968786888055324, 0.3242623631374243, 0.9345233221203314]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.028685633809430733`], {
             RGBColor[
             0.20904447312210606`, 0.33704937380942024`, 0.9352161455394953]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.028685633809430733`], {
             RGBColor[
             0.1800731039927536, 0.30659862796357423`, 0.9335662689268784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.028685633809430733`], {
             RGBColor[
             0.8190803262063154, 0.147665325039805, 0.16590464796430104`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.028685633809430733`], {
             RGBColor[
             0.27463540520047075`, 0.4059896021290707, 0.9389514520882697]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.028685633809430733`], {
             RGBColor[
             0.5611296111138018, 0.6545893227599167, 0.9585933249538227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.028685633809430733`], {
             RGBColor[
             0.2153604952721365, 0.34368791354803596`, 0.9355758336572221]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.028685633809430733`], {
             RGBColor[
             0.20371318105767475`, 0.33144584782626274`, 0.9349125363433657]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.028685633809430733`], {
             RGBColor[
             0.18423542654322242`, 0.31097349287060916`, 0.9338033070385232]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.028685633809430733`], {
             RGBColor[
             0.22763715789209957`, 0.35659146434698463`, 0.9362749714317341]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.028685633809430733`], {
             RGBColor[
             0.9834670894693087, 0.9871903629131425, 0.9128700844415136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.028685633809430733`], {
             RGBColor[
             0.19392286855916088`, 0.32115560864865994`, 0.9343549925300447]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.028685633809430733`], {
             RGBColor[
             0.19939483773806957`, 0.32690699519857735`, 0.9346666130797306]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.028685633809430733`], {
             RGBColor[
             0.29909565256278264`, 0.4316988729761172, 0.9403444269898601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.028685633809430733`], {
             RGBColor[
             0.19170728594478786`, 0.3188268908449026, 0.9342288183778169]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.028685633809430733`], {
             RGBColor[
             0.2321162208184409, 0.36129924347156134`, 0.9365300474392095]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.028685633809430733`], {
             RGBColor[
             0.23944883454874902`, 0.3690062854166779, 0.9369476289435206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.028685633809430733`], {
             RGBColor[
             0.2138505894071634, 0.34210090675038807`, 0.9354898467519174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.028685633809430733`], {
             RGBColor[
             0.18332605976082084`, 0.310017690725121, 0.933751519945553]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.028685633809430733`], {
             RGBColor[
             0.899308535201446, 0.6356654000864056, 0.23769291240948212`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.028685633809430733`], {
             RGBColor[
             0.3160253373259164, 0.44814699612157666`, 0.9413578329375422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.028685633809430733`], {
             RGBColor[
             0.3059265832870255, 0.43887861427331937`, 0.9407334383891494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.028685633809430733`], {
             RGBColor[
             0.19568177386369887`, 0.32300432964476683`, 0.934455159585071]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.028685633809430733`], {
             RGBColor[
             0.23986313789965336`, 0.369441744506828, 0.9369712229064477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.028685633809430733`], {
             RGBColor[
             0.29271248717825876`, 0.424989761440922, 0.9399809151642584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.028685633809430733`], {
             RGBColor[
             0.18381241008660495`, 0.31052887575391175`, 0.9337792168771156]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.028685633809430733`], {
             RGBColor[
             0.1877350381466607, 0.3146518065540141, 0.9340026047421276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.028685633809430733`], {
             RGBColor[
             0.47069483175957283`, 0.581170294839771, 0.9514739678495456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.028685633809430733`], {
             RGBColor[
             0.22349209680564214`, 0.35223474233306573`, 0.9360389163349288]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.028685633809430733`], {
             RGBColor[
             0.720597203195575, 0.7816552789687509, 0.9727860529169569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.028685633809430733`], {
             RGBColor[
             0.18747717117288942`, 0.31438077201487, 0.9339879195994514]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.028685633809430733`], {
             RGBColor[
             0.39767741348965524`, 0.5188699205419315, 0.9465606310285997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.028685633809430733`], {
             RGBColor[
             0.3169334821091241, 0.44893358548810713`, 0.9414156991200873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.028685633809430733`], {
             RGBColor[
             0.18438238961983267`, 0.3111279603821238, 0.9338116763683237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.028685633809430733`], {
             RGBColor[
             0.46930938565191127`, 0.5800455272759355, 0.9513649004568943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.028685633809430733`], {
             RGBColor[
             0.2001120590885424, 0.3276608403123844, 0.9347074577746062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.028685633809430733`], {
             RGBColor[
             0.26314504718325327`, 0.39391250732219896`, 0.9382970931976505]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.028685633809430733`], {
             RGBColor[
             0.22551745991005276`, 0.354363527371239, 0.9361542577674687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.028685633809430733`], {
             RGBColor[
             0.34499714152995936`, 0.4732409167578995, 0.9432038906826632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.028685633809430733`], {
             RGBColor[
             0.19696480621086881`, 0.3243528779905917, 0.934528226379166]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.028685633809430733`], {
             RGBColor[
             0.5408355089237035, 0.6381136563631097, 0.9569956988896724]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.028685633809430733`], {
             RGBColor[
             0.21154093935996757`, 0.33967331811051427`, 0.9353583155985506]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.028685633809430733`], {
             RGBColor[
             0.9933232264913885, 0.9881273815274607, 0.5146525917364964]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.028685633809430733`], {
             RGBColor[
             0.22124625332801934`, 0.34987421844338334`, 0.9359110188713058]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.028685633809430733`], {
             RGBColor[
             0.2239766808649284, 0.35274407090377946`, 0.9360665126802272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.028685633809430733`], {
             RGBColor[
             0.2519720376195532, 0.38216896586102805`, 0.9376608068319842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.028685633809430733`], {
             RGBColor[
             0.21654397156564814`, 0.3449318221692476, 0.9356432308813413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.028685633809430733`], {
             RGBColor[
             0.19059661539563244`, 0.31765950567716017`, 0.9341655673331324]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.028685633809430733`], {
             RGBColor[
             0.3129892535839804, 0.4455172929823175, 0.9411643763662094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.028685633809430733`], {
             RGBColor[
             0.18092386766537458`, 0.30749283452503123`, 0.9336147186594421]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.028685633809430733`], {
             RGBColor[
             0.18610703405965695`, 0.3129406710371523, 0.933909892317789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.028685633809430733`], {
             RGBColor[
             0.18809486651088786`, 0.3150300089792529, 0.934023096435152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.028685633809430733`], {
             RGBColor[
             0.19199615165670597`, 0.3191305070232725, 0.9342452688527721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.028685633809430733`], {
             RGBColor[
             0.23089370286527677`, 0.3600142995906707, 0.93646042685033]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.028685633809430733`], {
             RGBColor[
             0.1824115868132323, 0.30905652167627173`, 0.9336994420640293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.028685633809430733`], {
             RGBColor[
             0.3861343022549474, 0.5088718577640675, 0.9458251141878965]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.028685633809430733`], {
             RGBColor[
             0.26297543885551555`, 0.39373423821595743`, 0.938287434254299]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.028685633809430733`], {
             RGBColor[
             0.25745169920403105`, 0.3879284376169253, 0.9379728654527874]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.028685633809430733`], {
             RGBColor[
             0.18676020758344578`, 0.31362719782424764`, 0.9339470895836851]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.028685633809430733`], {
             RGBColor[
             0.8450710458930704, 0.34744138575819206`, 0.19079339048865696`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.028685633809430733`], {
             RGBColor[
             0.3159031668134525, 0.44804117816414885`, 0.941350048340519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.028685633809430733`], {
             RGBColor[
             0.23748131534596645`, 0.36693829798663086`, 0.936835581635606]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.028685633809430733`], {
             RGBColor[
             0.18041422854673403`, 0.3069571714983536, 0.933585695465579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.028685633809430733`], {
             RGBColor[
             0.8749870106263872, 0.5252270374274478, 0.21739843612893187`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.028685633809430733`], {
             RGBColor[
             0.42661470104868005`, 0.5439339445951966, 0.948404489403622]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.028685633809430733`], {
             RGBColor[
             0.9944761061763768, 0.9919837421934052, 0.7412087462437971]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.028685633809430733`], {
             RGBColor[
             0.19552365175645214`, 0.32283813328452987`, 0.9344461547649839]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.028685633809430733`], {
             RGBColor[
             0.1874830946539544, 0.31438699796903974`, 0.933988256932935]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.028685633809430733`], {
             RGBColor[
             0.1819457440050942, 0.3085668913487786, 0.9336729130052586]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.028685633809430733`], {
             RGBColor[
             0.20221750657572096`, 0.32987379911448994`, 0.9348273598942706]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.028685633809430733`], {
             RGBColor[
             0.1875451608924792, 0.3144522335209561, 0.9339917915134002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.028685633809430733`], {
             RGBColor[
             0.18496268734880916`, 0.3117378900882792, 0.9338447234655154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.028685633809430733`], {
             RGBColor[
             0.19991510326486814`, 0.3274538272539823, 0.934696241431818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.028685633809430733`], {
             RGBColor[
             0.18124242467150065`, 0.3078276581361505, 0.9336328600096782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.028685633809430733`], {
             RGBColor[
             0.28587662659874513`, 0.4178048385532594, 0.9395916230170046]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.028685633809430733`], {
             RGBColor[
             0.6695263659366376, 0.7417583527493299, 0.9676957891430948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.028685633809430733`], {
             RGBColor[
             0.21703333859134122`, 0.34544617794091254`, 0.9356710996095008]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.028685633809430733`], {
             RGBColor[
             0.9622752132426141, 0.884407577445488, 0.3079467564861062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.028685633809430733`], {
             RGBColor[
             0.1971022673351447, 0.32449735834774435`, 0.9345360545868381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.028685633809430733`], {
             RGBColor[
             0.20818468230621298`, 0.33614567914803034`, 0.9351671817244767]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.028685633809430733`], {
             RGBColor[
             0.20593429362604587`, 0.3337803779622914, 0.9350390254182929]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.028685633809430733`], {
             RGBColor[
             0.18396512493287584`, 0.310689388740023, 0.9337879137616893]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.028685633809430733`], {
             RGBColor[
             0.1869796895121246, 0.3138578872472471, 0.933959588754829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.028685633809430733`], {
             RGBColor[
             0.19315889756887425`, 0.3203526266993102, 0.9343114855123418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.028685633809430733`], {
             RGBColor[
             0.2582166797056685, 0.38873248062671145`, 0.9380164299606684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.028685633809430733`], {
             RGBColor[
             0.2348407472607494, 0.36416289350738135`, 0.9366852051895233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.028685633809430733`], {
             RGBColor[
             0.2058983382969339, 0.3337425866316952, 0.9350369778154911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.028685633809430733`], {
             RGBColor[
             0.7636579459089816, 0.81529465845023, 0.9770779453251097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.028685633809430733`], {
             RGBColor[
             0.2784596091749779, 0.41000908297481403`, 0.939169234847215]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.028685633809430733`], {
             RGBColor[
             0.9625574020842641, 0.9715959522978471, 0.948264731064506]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.028685633809430733`], {
             RGBColor[
             0.9263783006421346, 0.7458215255627042, 0.25962045645451476`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.028685633809430733`], {
             RGBColor[
             0.2171179053764417, 0.345535062993897, 0.9356759155628069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.028685633809430733`], {
             RGBColor[
             0.20835940299106456`, 0.3363293216657406, 0.9351771318090029]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.028685633809430733`], {
             RGBColor[
             0.2328901660883635, 0.3621127090212143, 0.9365741224773821]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.028685633809430733`], {
             RGBColor[
             0.48668906339049306`, 0.5941551326096759, 0.9527330923523326]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.028685633809430733`], {
             RGBColor[
             0.1966443508485099, 0.324016059086709, 0.9345099769203509]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.028685633809430733`], {
             RGBColor[
             0.9948059876224538, 0.9912988576566625, 0.6760419903119628]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.028685633809430733`], {
             RGBColor[
             0.21562994450375172`, 0.3439711217745316, 0.9355911783923481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.028685633809430733`], {
             RGBColor[
             0.9731128985329042, 0.9794682242662037, 0.9303970288913456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.028685633809430733`], {
             RGBColor[
             0.19657931914436805`, 0.32394770664240774`, 0.9345062734610058]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.028685633809430733`], {
             RGBColor[
             0.44672166802497704`, 0.5613495887845201, 0.9496856875594589]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.028685633809430733`], {
             RGBColor[
             0.2439252154854269, 0.3737112456000703, 0.9372025522156523]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.028685633809430733`], {
             RGBColor[
             0.2398990282396083, 0.3694794675296996, 0.9369732668082131]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.028685633809430733`], {
             RGBColor[
             0.18427930277709584`, 0.31101960957432406`, 0.9338058057251333]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.028685633809430733`], {
             RGBColor[
             0.18027294835259305`, 0.30680867705662973`, 0.933577649767528]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.028685633809430733`], {
             RGBColor[
             0.7269497450043649, 0.7866179329108834, 0.9734192149165786]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.028685633809430733`], {
             RGBColor[
             0.2196415898680099, 0.3481876154053738, 0.9358196356611451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.028685633809430733`], {
             RGBColor[
             0.23893002370274252`, 0.3684609823230175, 0.9369180834333524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.028685633809430733`], {
             RGBColor[
             0.18230687199160545`, 0.30894645975943874`, 0.9336934787098494]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.028685633809430733`], {
             RGBColor[
             0.37749249202520396`, 0.5013867560930751, 0.94527446568171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.028685633809430733`], {
             RGBColor[
             0.19242949370172294`, 0.3195859769880579, 0.9342699470411637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.028685633809430733`], {
             RGBColor[
             0.19717041562221144`, 0.32456898651830246`, 0.9345399355309701]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.028685633809430733`], {
             RGBColor[
             0.3115575299166111, 0.44427720590216613`, 0.9410731482001482]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.028685633809430733`], {
             RGBColor[
             0.9630526170636222, 0.8870299430768459, 0.31096682353032956`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.028685633809430733`], {
             RGBColor[
             0.41518076487513966`, 0.5340304437680178, 0.9476759291012767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.028685633809430733`], {
             RGBColor[
             0.6832732263253226, 0.7524975045649791, 0.9690659477149247]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.028685633809430733`], {
             RGBColor[
             0.20975080596055196`, 0.33779177440671543`, 0.935256370149719]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.028685633809430733`], {
             RGBColor[
             0.329292758612209, 0.4596385695997802, 0.9422032212899847]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.028685633809430733`], {
             RGBColor[
             0.34316736625512184`, 0.47165605738201455`, 0.9430872990201573]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.028685633809430733`], {
             RGBColor[
             0.22433819907190317`, 0.35312404946088816`, 0.9360871006072962]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.028685633809430733`], {
             RGBColor[
             0.8655438992520076, 0.482348074171085, 0.20951887252630852`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.028685633809430733`], {
             RGBColor[
             0.18432263905515192`, 0.3110651587502397, 0.9338082736620582]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.028685633809430733`], {
             RGBColor[
             0.9935833726583437, 0.9886838078737659, 0.5429678965735315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.028685633809430733`], {
             RGBColor[
             0.22925694712510034`, 0.35829396553143755`, 0.9363672160322901]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.028685633809430733`], {
             RGBColor[
             0.1863015188096388, 0.3131450868404286, 0.9339209679365861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.028685633809430733`], {
             RGBColor[
             0.6018738506410779, 0.6876673319152327, 0.961800860740477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.028685633809430733`], {
             RGBColor[
             0.18011392367187812`, 0.3066415320344512, 0.9335685935472172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.028685633809430733`], {
             RGBColor[
             0.20809576797568208`, 0.3360522245491482, 0.9351621181848899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.028685633809430733`], {
             RGBColor[
             0.25722683759211185`, 0.3876920938057486, 0.9379600599166416]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.028685633809430733`], {
             RGBColor[
             0.18715875648320013`, 0.3140460979873492, 0.9339697863539259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.028685633809430733`], {
             RGBColor[
             0.24408437678171757`, 0.37387853421388084`, 0.937211616216018]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.028685633809430733`], {
             RGBColor[
             0.48931236896480956`, 0.5962848502534754, 0.9529396085766279]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.028685633809430733`], {
             RGBColor[
             0.21359854810176626`, 0.34183599535807396`, 0.9354754933724367]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.028685633809430733`], {
             RGBColor[
             0.44322657405371796`, 0.5583223140551463, 0.9494629832622005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.028685633809430733`], {
             RGBColor[
             0.18446408847726348`, 0.3112138310612903, 0.9338163289973919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.028685633809430733`], {
             RGBColor[
             0.20798277523591915`, 0.3359334620155039, 0.9351556834155181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.028685633809430733`], {
             RGBColor[
             0.2534737690150518, 0.3837473807729669, 0.9377463282133454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.028685633809430733`], {
             RGBColor[
             0.8184239254643847, 0.14261994130068656`, 0.16527607787252963`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.028685633809430733`], {
             RGBColor[
             0.6967134214587186, 0.7629970871524544, 0.9704055407600571]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.028685633809430733`], {
             RGBColor[
             0.18231742038260904`, 0.3089575467871901, 0.9336940794251122]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.028685633809430733`], {
             RGBColor[
             0.20683017875346388`, 0.3347220100336056, 0.935090044750956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.028685633809430733`], {
             RGBColor[
             0.21438774917055564`, 0.3426654957196094, 0.9355204372057859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.028685633809430733`], {
             RGBColor[
             0.18739586640915007`, 0.3142953155531602, 0.933983289413436]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.028685633809430733`], {
             RGBColor[
             0.304153838987054, 0.4370153476155689, 0.9406324832238061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.028685633809430733`], {
             RGBColor[
             0.7112234006140565, 0.7743323931485304, 0.9718517598787967]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.028685633809430733`], {
             RGBColor[
             0.21007296758615746`, 0.3381303867014537, 0.9352747167777018]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.028685633809430733`], {
             RGBColor[
             0.18152659560596812`, 0.30812633980575366`, 0.9336490431240029]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.028685633809430733`], {
             RGBColor[
             0.18307944483465585`, 0.30975848280143214`, 0.933737475590342]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.028685633809430733`], {
             RGBColor[
             0.18511992750412062`, 0.3119031594611132, 0.9338536780597445]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.028685633809430733`], {
             RGBColor[
             0.8097488880926076, 0.8513012527882134, 0.9816718596976299]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.028685633809430733`], {
             RGBColor[
             0.18749202516745894`, 0.31439638450496027`, 0.9339887655124676]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.028685633809430733`], {
             RGBColor[
             0.9847959098179251, 0.9879807322294865, 0.9016346514484699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.028685633809430733`], {
             RGBColor[
             0.18222924951210637`, 0.30886487361193576`, 0.9336890582244741]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.028685633809430733`], {
             RGBColor[
             0.19526251556143404`, 0.32256366258657476`, 0.934431283444994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.028685633809430733`], {
             RGBColor[
             0.2756885017375273, 0.407096473359694, 0.9390114243781383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.028685633809430733`], {
             RGBColor[
             0.24007340415027964`, 0.3696627476678865, 0.9369831972583599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.028685633809430733`], {
             RGBColor[
             0.23186327956718236`, 0.36103338617908703`, 0.9365156428091433]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.028685633809430733`], {
             RGBColor[
             0.6564481594438648, 0.7315415584391249, 0.9663922757426836]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.028685633809430733`], {
             RGBColor[
             0.24476085053842922`, 0.3745895510230982, 0.9372501403957095]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.028685633809430733`], {
             RGBColor[
             0.8407980254541154, 0.31459707821488886`, 0.1867015412906274]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.028685633809430733`], {
             RGBColor[
             0.190709032669891, 0.3177776633600728, 0.934171969330595]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.028685633809430733`], {
             RGBColor[
             0.3105546519813193, 0.443408563440727, 0.9410092457049215]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.028685633809430733`], {
             RGBColor[
             0.24077004537273583`, 0.3703949617622926, 0.9370228699453904]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.028685633809430733`], {
             RGBColor[
             0.1917730045224159, 0.3188959652367882, 0.934232560953591]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.028685633809430733`], {
             RGBColor[
             0.19090439582770188`, 0.3179830024256716, 0.9341830949734184]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.028685633809430733`], {
             RGBColor[
             0.1881959331144625, 0.3151362363876026, 0.9340288520287109]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.028685633809430733`], {
             RGBColor[
             0.644812645752953, 0.7224518067106054, 0.9652325564780311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.028685633809430733`], {
             RGBColor[
             0.18998459744441062`, 0.31701623600624673`, 0.9341307138162097]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.028685633809430733`], {
             RGBColor[
             0.19496888133162707`, 0.3222550343935622, 0.9344145614099995]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.028685633809430733`], {
             RGBColor[
             0.36122042818933575`, 0.4872927122561548, 0.9442376241629096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.028685633809430733`], {
             RGBColor[
             0.2628079616436893, 0.3935582090476596, 0.9382778966748457]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.028685633809430733`], {
             RGBColor[
             0.18340993044876472`, 0.3101058441358588, 0.9337562962571558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.028685633809430733`], {
             RGBColor[
             0.43871305828747303`, 0.5544129335543235, 0.9491753860287206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.028685633809430733`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.028685633809430733`], {
             RGBColor[
             0.1979808475129809, 0.32542080181985084`, 0.9345860884282229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.028685633809430733`], {
             RGBColor[
             0.18086286172523808`, 0.3074287134139478, 0.9336112444614015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.028685633809430733`], {
             RGBColor[
             0.18113843442729957`, 0.3077183577961329, 0.9336269379191107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.028685633809430733`], {
             RGBColor[
             0.9854351531478911, 0.9882450757742316, 0.8910407351622261]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.028685633809430733`], {
             RGBColor[
             0.820782245844875, 0.16074702516771538`, 0.16753440813222906`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.028685633809430733`], {
             RGBColor[
             0.9927101178720487, 0.9912534606457363, 0.7704757426777427]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.028685633809430733`], {
             RGBColor[
             0.9397327677393429, 0.9545733773753136, 0.9869008833924131]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.028685633809430733`], {
             RGBColor[
             0.23363553097946993`, 0.3628961347806308, 0.9366165699052621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.028685633809430733`], {
             RGBColor[
             0.7253820295989173, 0.7853932217210695, 0.973262959696097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.028685633809430733`], {
             RGBColor[
             0.1837791716078354, 0.31049394000528374`, 0.9337773239949216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.028685633809430733`], {
             RGBColor[
             0.24298649045633505`, 0.3727245860758903, 0.9371490932139648]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.028685633809430733`], {
             RGBColor[
             0.18157893838322037`, 0.30818135538336955`, 0.9336520239677332]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.028685633809430733`], {
             RGBColor[
             0.18958070170652433`, 0.3165917159772593, 0.9341077125514473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.028685633809430733`], {
             RGBColor[
             0.30143473291096856`, 0.4341573947283205, 0.94047763415533]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.028685633809430733`], {
             RGBColor[
             0.18662770310860746`, 0.3134879272199237, 0.9339395436498659]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.028685633809430733`], {
             RGBColor[
             0.23178823080036964`, 0.3609545051668002, 0.9365113688928981]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.028685633809430733`], {
             RGBColor[
             0.18685517330782678`, 0.3137270128217468, 0.9339524977411994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.028685633809430733`], {
             RGBColor[
             0.21037507790267013`, 0.33844792379900884`, 0.935291921513295]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.028685633809430733`], {
             RGBColor[
             0.6253505975793664, 0.7067268126951324, 0.9636490362576168]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.028685633809430733`], {
             RGBColor[
             0.1890859537624092, 0.3160717045191629, 0.9340795373879439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.028685633809430733`], {
             RGBColor[
             0.4243323457115801, 0.5419570831167153, 0.9482590597397496]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.028685633809430733`], {
             RGBColor[
             0.1801862242299471, 0.30671752450510187`, 0.9335727109570402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.028685633809430733`], {
             RGBColor[
             0.36379298595207366`, 0.4895209324897256, 0.9444015452687277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.028685633809430733`], {
             RGBColor[
             0.9942973298741586, 0.9902108901662465, 0.6206777334817875]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.028685633809430733`], {
             RGBColor[
             0.47631296582080423`, 0.5857313491647339, 0.951916247942749]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.028685633809430733`], {
             RGBColor[
             0.8462306119676556, 0.35635431873254797`, 0.1919037922712223]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.028685633809430733`], {
             RGBColor[
             0.1902758304551235, 0.3173223403657453, 0.9341472991053292]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.028685633809430733`], {
             RGBColor[
             0.19084105210201593`, 0.31791642415375154`, 0.9341794876419492]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.028685633809430733`], {
             RGBColor[
             0.4414153171565428, 0.5567534943672319, 0.9493475715743441]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.028685633809430733`], {
             RGBColor[
             0.2030767017243416, 0.3307768676918091, 0.9348762897869192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.028685633809430733`], {
             RGBColor[
             0.46208044251389646`, 0.5741767455763179, 0.9507958115725785]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.028685633809430733`], {
             RGBColor[
             0.18519516767477753`, 0.31198224165097593`, 0.9338579628761555]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.028685633809430733`], {
             RGBColor[
             0.1815243108454087, 0.3081239383775436, 0.933648913010269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.028685633809430733`], {
             RGBColor[
             0.24019038642635912`, 0.3697857034571507, 0.9369898592259228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.028685633809430733`], {
             RGBColor[
             0.18339204965023842`, 0.3100870502828995, 0.9337552779721321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.028685633809430733`], {
             RGBColor[
             0.18070771638990538`, 0.3072656458297307, 0.9336024091640713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.028685633809430733`], {
             RGBColor[
             0.31058773436371456`, 0.4434372177375889, 0.9410113536850742]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.028685633809430733`], {
             RGBColor[
             0.5597098423756648, 0.6534366905384442, 0.9584815555579723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.028685633809430733`], {
             RGBColor[
             0.24531622372842543`, 0.3751732834584783, 0.9372817680772788]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.028685633809430733`], {
             RGBColor[
             0.18854433931021156`, 0.3155024333895635, 0.934048693246138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.028685633809430733`], {
             RGBColor[
             0.2248830575111852, 0.353696730226594, 0.9361181294893675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.028685633809430733`], {
             RGBColor[
             0.9095261013751367, 0.9306954410809412, 0.9912326055643381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.028685633809430733`], {
             RGBColor[
             0.5961635782161725, 0.6830314755158533, 0.9613513271777714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.028685633809430733`], {
             RGBColor[
             0.23010075165696398`, 0.35918085759472357`, 0.9364152694520828]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.028685633809430733`], {
             RGBColor[
             0.17923689510112015`, 0.3057197193997615, 0.9335186480675601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.028685633809430733`], {
             RGBColor[
             0.18261346087673228`, 0.3092687041165651, 0.9337109384932998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.028685633809430733`], {
             RGBColor[
             0.20439189938454302`, 0.3321592238210287, 0.9349511883480071]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.028685633809430733`], {
             RGBColor[
             0.20704370002822514`, 0.33494643443141037`, 0.9351022044716772]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.028685633809430733`], {
             RGBColor[
             0.18255683100735334`, 0.30920918253330676`, 0.933707713506015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.028685633809430733`], {
             RGBColor[
             0.19714961162350877`, 0.32454712019661625`, 0.9345387507740208]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.028685633809430733`], {
             RGBColor[
             0.1792318772890574, 0.3057144453611359, 0.9335183623105863]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.028685633809430733`], {
             RGBColor[
             0.18202687820624844`, 0.30865216853839716`, 0.933677533477987]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.028685633809430733`], {
             RGBColor[
             0.22875987812146206`, 0.3577715144926186, 0.9363389086878806]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.028685633809430733`], {
             RGBColor[
             0.25408219745152405`, 0.38438687763629015`, 0.9377809773127133]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.028685633809430733`], {
             RGBColor[
             0.6142711963162304, 0.6977320556283797, 0.9627768252049985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.028685633809430733`], {
             RGBColor[
             0.9909995879120733, 0.9905461125486716, 0.7988236508241691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.028685633809430733`], {
             RGBColor[
             0.847444298272204, 0.36568324351003745`, 0.19306601964712058`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.028685633809430733`], {
             RGBColor[
             0.20274272640358343`, 0.3304258384544339, 0.9348572703864743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.028685633809430733`], {
             RGBColor[
             0.37110890510299593`, 0.49585761394946637`, 0.9448677091678112]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.028685633809430733`], {
             RGBColor[
             0.1807916321529833, 0.30735384661729226`, 0.9336071880426363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.028685633809430733`], {
             RGBColor[
             0.20696414784897932`, 0.33486282004712353`, 0.9350976740927561]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.028685633809430733`], {
             RGBColor[
             0.8274245231995631, 0.21180247958034423`, 0.17389506042845765`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.028685633809430733`], {
             RGBColor[
             0.1874689911967999, 0.31437217434135956`, 0.9339874537619143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.028685633809430733`], {
             RGBColor[
             0.18829908866819065`, 0.31524465941501073`, 0.9340347265848907]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.028685633809430733`], {
             RGBColor[
             0.21206977390702858`, 0.3402291567495223, 0.9353884319436652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.028685633809430733`], {
             RGBColor[
             0.2677744651747997, 0.39877831915336787`, 0.938560731703659]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.028685633809430733`], {
             RGBColor[
             0.2680749969538752, 0.3990941971079916, 0.9385778465438803]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.028685633809430733`], {
             RGBColor[
             0.18155548323377793`, 0.30815670253416316`, 0.9336506882316712]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.028685633809430733`], {
             RGBColor[
             0.30560245203902436`, 0.43853793178056216`, 0.9407149795940849]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.028685633809430733`], {
             RGBColor[
             0.18889078087796188`, 0.3158665654429332, 0.934068422580907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.028685633809430733`], {
             RGBColor[
             0.3286879472145684, 0.4591147123658486, 0.9421646832425408]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.028685633809430733`], {
             RGBColor[
             0.19492141529937626`, 0.32220514458414634`, 0.9344118582896825]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.028685633809430733`], {
             RGBColor[
             0.25591378716406765`, 0.38631199455366855`, 0.9378852836372484]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.028685633809430733`], {
             RGBColor[
             0.47311473175482466`, 0.583134878671169, 0.9516644712415576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.028685633809430733`], {
             RGBColor[
             0.23685058796865582`, 0.3662753635226519, 0.9367996626445457]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.028685633809430733`], {
             RGBColor[
             0.2213158585080208, 0.34994737790078817`, 0.9359149827833353]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.028685633809430733`], {
             RGBColor[
             0.18345440314028216`, 0.3101525877543751, 0.9337588289111464]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.028685633809430733`], {
             RGBColor[
             0.5041410272247835, 0.6083234230523641, 0.954106974874018]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.028685633809430733`], {
             RGBColor[
             0.19743844380411263`, 0.32485070113144887`, 0.9345551993394172]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.028685633809430733`], {
             RGBColor[
             0.8220097648168001, 0.1701822738881748, 0.16870988168602888`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.028685633809430733`], {
             RGBColor[
             0.20625914549310514`, 0.3341218178713687, 0.9350575252515466]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.028685633809430733`], {
             RGBColor[
             0.20787897197296468`, 0.3358243582046317, 0.9351497719732561]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.028685633809430733`], {
             RGBColor[
             0.989868357531768, 0.9900783197151207, 0.8175710657562082]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[401, 0.028685633809430733`], {
             RGBColor[
             0.18072732343424755`, 0.30728625407649274`, 0.9336035257562406]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[402, 0.028685633809430733`], {
             RGBColor[
             0.21812922311479366`, 0.346598022058153, 0.9357335086118955]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[403, 0.028685633809430733`], {
             RGBColor[
             0.7434088886883141, 0.7994759410509097, 0.9750597085395519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[404, 0.028685633809430733`], {
             RGBColor[
             0.8368269464602606, 0.8727271083178094, 0.9842984952692555]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[405, 0.028685633809430733`], {
             RGBColor[
             0.1816592229448945, 0.3082657395480243, 0.9336565960547502]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[406, 0.028685633809430733`], {
             RGBColor[
             0.41650215403555035`, 0.5351749646438152, 0.9477601268501196]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[407, 0.028685633809430733`], {
             RGBColor[
             0.2771295864414469, 0.4086111447535611, 0.9390934920201328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[408, 0.028685633809430733`], {
             RGBColor[
             0.9372841166711893, 0.9527471774179826, 0.9910458109403161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[409, 0.028685633809430733`], {
             RGBColor[
             0.2532336129818181, 0.38349496155526636`, 0.9377326516825317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[410, 0.028685633809430733`], {
             RGBColor[
             0.18224818387414324`, 0.30888477482694443`, 0.9336901365083813]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[411, 0.028685633809430733`], {
             RGBColor[
             0.281209290628112, 0.4128991725219315, 0.9393258251381819]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[412, 0.028685633809430733`], {
             RGBColor[
             0.1902556572489104, 0.31730113704696017`, 0.934146150271079]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[413, 0.028685633809430733`], {
             RGBColor[
             0.23030998251802656`, 0.3594007724957031, 0.936427184840091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[414, 0.028685633809430733`], {
             RGBColor[
             0.4226665958174486, 0.5405142942814426, 0.9481529196294604]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[415, 0.028685633809430733`], {
             RGBColor[
             0.1803991146634024, 0.3069412858486965, 0.9335848347522823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[416, 0.028685633809430733`], {
             RGBColor[
             0.20922896777355948`, 0.3372432893857343, 0.9352266522369601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[417, 0.028685633809430733`], {
             RGBColor[
             0.19713115786974042`, 0.32452772413137015`, 0.9345376998600435]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[418, 0.028685633809430733`], {
             RGBColor[
             0.4765052907931592, 0.5858874872414329, 0.9519313884690823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[419, 0.028685633809430733`], {
             RGBColor[
             0.649286320101708, 0.725946675113037, 0.9656784505282513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[420, 0.028685633809430733`], {
             RGBColor[
             0.1880446060283209, 0.31497718202537633`, 0.9340202341750236]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[421, 0.028685633809430733`], {
             RGBColor[
             0.1843367269803192, 0.31107996605281657`, 0.9338090759485553]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[422, 0.028685633809430733`], {
             RGBColor[
             0.20654013009820746`, 0.33441715050678417`, 0.9350735269091277]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[423, 0.028685633809430733`], {
             RGBColor[
             0.1791999116318114, 0.3056808474286306, 0.9335165419136952]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[424, 0.028685633809430733`], {
             RGBColor[
             0.19347184238884513`, 0.3206815515469472, 0.9343293072568787]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[425, 0.028685633809430733`], {
             RGBColor[
             0.18667870528248892`, 0.31354153373839766`, 0.9339424481482175]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[426, 0.028685633809430733`], {
             RGBColor[
             0.18735694523176508`, 0.31425440692798345`, 0.9339810729099627]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[427, 0.028685633809430733`], {
             RGBColor[
             0.18651414967483487`, 0.3133685753613251, 0.9339330769497998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[428, 0.028685633809430733`], {
             RGBColor[
             0.18777404508405116`, 0.31469280531839416`, 0.9340048261295064]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[429, 0.028685633809430733`], {
             RGBColor[
             0.1919491178531559, 0.319081071513626, 0.9342425903472402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[430, 0.028685633809430733`], {
             RGBColor[
             0.20155620116286646`, 0.329178725196395, 0.9347896995293221]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[431, 0.028685633809430733`], {
             RGBColor[
             0.4212519905865513, 0.5392890343305656, 0.9480627822350338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[432, 0.028685633809430733`], {
             RGBColor[
             0.29123303955595214`, 0.4234347681874807, 0.9398966628108147]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[433, 0.028685633809430733`], {
             RGBColor[
             0.18067343227102245`, 0.30722961104704605`, 0.9336004567342198]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[434, 0.028685633809430733`], {
             RGBColor[
             0.9350798973521478, 0.7803204568826958, 0.2666219654201177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[435, 0.028685633809430733`], {
             RGBColor[
             0.23839852597207306`, 0.3679023445091814, 0.9368878154238712]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[436, 0.028685633809430733`], {
             RGBColor[
             0.35552088653300873`, 0.4823560557407374, 0.9438744544084752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[437, 0.028685633809430733`], {
             RGBColor[
             0.18191959414620315`, 0.3085394061890873, 0.93367142380948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[438, 0.028685633809430733`], {
             RGBColor[
             0.20264182690306143`, 0.3303197866819874, 0.9348515243091869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[439, 0.028685633809430733`], {
             RGBColor[
             0.19923030702383038`, 0.32673406298606217`, 0.934657243298956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[440, 0.028685633809430733`], {
             RGBColor[
             0.8916325056316791, 0.6008103425923479, 0.23128784517976625`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[441, 0.028685633809430733`], {
             RGBColor[
             0.22146757953397317`, 0.3501068463187328, 0.935923623071312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[442, 0.028685633809430733`], {
             RGBColor[
             0.2379042947950852, 0.36738287620610066`, 0.9368596696894913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[443, 0.028685633809430733`], {
             RGBColor[
             0.2878366774276409, 0.41986497624882907`, 0.9397032450120749]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[444, 0.028685633809430733`], {
             RGBColor[
             0.5658641034717166, 0.6584329969425219, 0.9589660415352547]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[445, 0.028685633809430733`], {
             RGBColor[
             0.9631188181102052, 0.8872532547517151, 0.3112240020952856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[446, 0.028685633809430733`], {
             RGBColor[
             0.18340710413885652`, 0.31010287350494686`, 0.9337561353029877]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[447, 0.028685633809430733`], {
             RGBColor[
             0.23372958097512028`, 0.36299498728917345`, 0.9366219259133799]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[448, 0.028685633809430733`], {
             RGBColor[
             0.300584051971647, 0.4332632751248068, 0.9404291891343054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[449, 0.028685633809430733`], {
             RGBColor[
             0.9836066487684537, 0.9563635183333898, 0.39081535540040413`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[450, 0.028685633809430733`], {
             RGBColor[
             0.2155265395117455, 0.34386243657167787`, 0.9355852896310274]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[451, 0.028685633809430733`], {
             RGBColor[
             0.20508673054441848`, 0.33288953542489785`, 0.9349907579546514]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[452, 0.028685633809430733`], {
             RGBColor[
             0.22680832648896532`, 0.3557203099913444, 0.9362277707094718]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[453, 0.028685633809430733`], {
             RGBColor[
             0.23993040743871616`, 0.3695124490575181, 0.936975053807181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[454, 0.028685633809430733`], {
             RGBColor[
             0.21139233227849236`, 0.33951712264565065`, 0.9353498526451051]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[455, 0.028685633809430733`], {
             RGBColor[
             0.6130446091083116, 0.6967362568758672, 0.9626802637668542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[456, 0.028685633809430733`], {
             RGBColor[
             0.19561148544389112`, 0.32293045205900567`, 0.9344511567635453]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[457, 0.028685633809430733`], {
             RGBColor[
             0.4692511982227218, 0.5799982880996057, 0.9513603197293209]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[458, 0.028685633809430733`], {
             RGBColor[
             0.2390221871354001, 0.3685578519342398, 0.9369233320044987]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[459, 0.028685633809430733`], {
             RGBColor[
             0.1944799719611093, 0.3217411596465035, 0.9343867187446251]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[460, 0.028685633809430733`], {
             RGBColor[
             0.3006736022333113, 0.4333573981276305, 0.9404342888892294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[461, 0.028685633809430733`], {
             RGBColor[
             0.25327163562221944`, 0.38353492576110276`, 0.9377348170156531]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[462, 0.028685633809430733`], {
             RGBColor[
             0.1900670199072787, 0.31710286724060704`, 0.934135407653537]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[463, 0.028685633809430733`], {
             RGBColor[
             0.5551591248464408, 0.6497422130407317, 0.9581233064042441]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[464, 0.028685633809430733`], {
             RGBColor[
             0.20245401245038683`, 0.33012238178410236`, 0.9348408285539537]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[465, 0.028685633809430733`], {
             RGBColor[
             0.1790493149440538, 0.30552256076141593`, 0.9335079656551152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[466, 0.028685633809430733`], {
             RGBColor[
             0.19488624546246058`, 0.32216817885565147`, 0.9344098554194993]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[467, 0.028685633809430733`], {
             RGBColor[
             0.19114672360584797`, 0.3182377042849717, 0.934196895181892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[468, 0.028685633809430733`], {
             RGBColor[
             0.22150150348383524`, 0.3501425025409405, 0.9359255549900708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[469, 0.028685633809430733`], {
             RGBColor[
             0.18135253868176207`, 0.30794339494256673`, 0.9336391308396634]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[470, 0.028685633809430733`], {
             RGBColor[
             0.19461387303716265`, 0.3218818981672542, 0.9343943442128174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[471, 0.028685633809430733`], {
             RGBColor[
             0.9568366664708343, 0.967329437044196, 0.9579484442512339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[472, 0.028685633809430733`], {
             RGBColor[
             0.18313584696674626`, 0.3098177650183609, 0.9337406876083251]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[473, 0.028685633809430733`], {
             RGBColor[
             0.2635938852306148, 0.3943842645679517, 0.9383226538604513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[474, 0.028685633809430733`], {
             RGBColor[
             0.22951352418939525`, 0.35856364429393695`, 0.93638182771653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[475, 0.028685633809430733`], {
             RGBColor[
             0.3365285973416883, 0.465905889423426, 0.9426642825354262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[476, 0.028685633809430733`], {
             RGBColor[
             0.18343003159278173`, 0.31012697171270676`, 0.9337574409875706]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[477, 0.028685633809430733`], {
             RGBColor[
             0.19779376632799722`, 0.32522416763280076`, 0.9345754344314999]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[478, 0.028685633809430733`], {
             RGBColor[
             0.24931371638514488`, 0.37937490169636373`, 0.9375094193703185]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[479, 0.028685633809430733`], {
             RGBColor[
             0.18231814009471767`, 0.3089583032502487, 0.933694120411652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[480, 0.028685633809430733`], {
             RGBColor[
             0.24336115250331075`, 0.37311837964220756`, 0.9371704296632771]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[481, 0.028685633809430733`], {
             RGBColor[
             0.20526876593224802`, 0.3330808661592169, 0.9350011246006911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[482, 0.028685633809430733`], {
             RGBColor[
             0.3323719943960167, 0.4623056488688239, 0.9423994274712677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[483, 0.028685633809430733`], {
             RGBColor[
             0.4520407911262143, 0.5659567458679113, 0.9500246173799538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[484, 0.028685633809430733`], {
             RGBColor[
             0.1848118632397346, 0.3115793643868409, 0.933836134255628]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[485, 0.028685633809430733`], {
             RGBColor[
             0.255344871987097, 0.38571402863136683`, 0.9378528847595545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[486, 0.028685633809430733`], {
             RGBColor[
             0.41333459859387617`, 0.5324313873262027, 0.9475582930183354]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[487, 0.028685633809430733`], {
             RGBColor[
             0.19274009296176206`, 0.31991243650348955`, 0.9342876352095326]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[488, 0.028685633809430733`], {
             RGBColor[
             0.18252871209609148`, 0.30917962777472857`, 0.9337061121756168]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[489, 0.028685633809430733`], {
             RGBColor[
             0.19162106685648111`, 0.3187362691164863, 0.9342239083282876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[490, 0.028685633809430733`], {
             RGBColor[
             0.2159679187439516, 0.3443263541297861, 0.9356104255253395]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[491, 0.028685633809430733`], {
             RGBColor[
             0.1816268290277524, 0.30823169148721496`, 0.9336547512690914]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[492, 0.028685633809430733`], {
             RGBColor[
             0.18260872208869527`, 0.3092637233498817, 0.9337106686263315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[493, 0.028685633809430733`], {
             RGBColor[
             0.2609046791964185, 0.39155773852050096`, 0.9381695075551277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[494, 0.028685633809430733`], {
             RGBColor[
             0.35530253300255993`, 0.4821669288874302, 0.9438605411145975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[495, 0.028685633809430733`], {
             RGBColor[
             0.8860920716837987, 0.5756525260362475, 0.22666477128519144`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[496, 0.028685633809430733`], {
             RGBColor[
             0.1858152550736946, 0.31263399282304966`, 0.9338932759361868]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[497, 0.028685633809430733`], {
             RGBColor[
             0.4781822073170808, 0.587248883619781, 0.9520634014805931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[498, 0.028685633809430733`], {
             RGBColor[
             0.7745863239297996, 0.8238319904188423, 0.9781671839147258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[499, 0.028685633809430733`], {
             RGBColor[
             0.628572856489554, 0.7093427876395323, 0.96390270428255]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[500, 0.028685633809430733`], {
             RGBColor[
             0.20098870068601762`, 0.3285822462136184, 0.9347573812167074]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{{3.8349502435193233`*^9, 3.8349502581408367`*^9}, 
   3.8349577843740606`*^9, 3.83501892289773*^9, 3.8350190217900667`*^9, 
   3.835020556050778*^9},
 CellLabel->"Out[77]=",ExpressionUUID->"08cbe25d-f0c6-4b64-8e3a-02fd0e2381e5"]
}, Open  ]],

Cell["Estimated with Max-Min Deviation v Calculated: (r = 6)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 3.8349503922098827`*^9}, {3.8349504781120467`*^9, 
  3.834950521977162*^9}},ExpressionUUID->"747af179-7448-4fc3-bfc7-\
ee2b69cd7286"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphin5", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsi5", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}], 
     "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"mMDi6500", ",", "kri5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502554527807`*^9}, {3.8349505249112787`*^9, 3.834950525026289*^9}, {
   3.834957796266032*^9, 3.834957804349044*^9}, {3.835018837121126*^9, 
   3.835018838508815*^9}},
 CellLabel->"In[78]:=",ExpressionUUID->"7e712cbf-50a7-4a3e-9f62-804c9def8983"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1dOWGAgQBNBMbNu2bds2J+bEtm3btm3btu01sjdnH271F1R1ssCg6p0C
ggUL9l38vMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEIS
kZgkJCUZyUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpR
mCIUpRjFKUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGY
JjSlGYE0pwUtaUVr2tCWdrSnAx3pRBCd6UJXutGdHvSkF73pQ1/60Z8BDGQQ
gxnCUIYxnBGMZBSjGcNYxjGeCUxkEpOZwlSmMZ0ZzGQWs5nDXOYxnwUsZBGL
WcJSlrGcFaxkFatZw1rWsZ4NbGQTm9nCVraxnR3sZBe72cNe9rGfAxzkEIc5
wlGOcZwTnOQUpznDWc5xngtc5BKXucJVrnGdG9zkFre5w13ucZ8HPOQRj3nC
U57xnBe85BWvecNb3vGeD3zkE5/5wle+8Z1f+JXf+J0/+JO/+Jt/+Jcf/Cx/
AMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEISkZgkJCUZ
yUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpRmCIUpRjF
KUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGYJjSlGYE0
pwUtaUVr2tCWdrSnAx35Od5BdKYLXelGd3rQk170pg996Ud/BjCQQQxmCEMZ
xnBGMJJRjGYMYxnHeCYwkUlMZgpTmcZ0ZjCTWcxmDnOZx3wWsJBFLGYJS1nG
clawklWsZg1rWcd6NrCRTWxmC1vZxnZ2sJNd7GYPe9nHfg5wkEMc5ghHOcZx
TnCSU5zmDGc5x3kucJFLXOYKV7nGdW5wk1vc5g53ucd9HvCQRzzmCU95xnNe
8JJXvOYNb3nHez7wkU985gtf+Rbw/z//Dz189+A=
          "], {Null, CompressedData["
1:eJxF3Al0ldW5gOF/21YsVqt2QFCqdkClVEWUGRVRJmWoghGKIgREKWUqk4DM
MSCTTAmozEMQUCJjEAMUZAhDSUCGmoo0QGkEEUnpbcV673nZL+uu5beeJjnn
P+ffw7e/vc+hd3Tu9VTPq5IkefYHSYJXhSRZnYoeqf+9KRWp/3n5f5dPRd/U
DydSXp8yN+XOEH9/POWwlG1CfPw8n4/fS9ktFdel4lOunXKurkt5PuWXXvfa
EIPrhVTkp+Jer8Pj7woxnta5us7XSQ/xtfD7KXv7vCY+rokx1+tXNPJ9fPMQ
o7f3tdTgvpd6n3k+viT1c0bKOf69Gm2SitdSPz+Y8uok/u1q//6blIUplySx
fT9P2TrEGJOKBrYnj78/5bKUP7B9VoUYtNPw1M/1U96dirG+/lrff1fff1fj
yv1fNGingiS+V6ybstg+x3yv92aIwXUXp37+SYjRxuedMbjOGdsBc329lrZz
S2Ou/TPSsTDS4D5H2l+0z+QQg3aqnMR75HX7pyI7iW2e7Wtn+7p3pHwyifL6
sx23VZLYVlVsryq2N47xfr8K8d6/sv0nOh4mGl86Th7z9zgiifc4wjYd4bgc
4bgeYTszDwb592M+55jB4/FpXee4P+U4eyrEOO74r2Ws8vpVbOcqPh+rOMar
2PZVbPcqzo/Oqce9nMR+WGjQ7siYHpOyi+3Xxf6YadAnMx2/zPuSEO8dGbP4
nH2CBXpGq/n3DM21f18Jse+6hRi8j6ucr1c5ju5MYi7B2brJeZWfxHma7zzN
N/ra/n18fB+v0cfYpJ1CzFvXpXwp5QXjOsfrePtjvP2B6cq9LjBKNMPnFTnO
i2znIiPdeX3YYH6TF08msZ9Pel9rvS+co0t1rfe41vukP7KdN9nGTi2x/V4w
Zut5+6pdiO8bS/SMEtxPBduwgs+t4HUqeB3auV6I7Yt9dJAStPNNjoWbHB83
OT5ucnzc5LigHXY53ncZtAt59afmJ/yj7YdTndd5SZzzeQbzHlsr85482SLE
vIbkS6yViiLH51nf41mD94d1HVcDjUHK+nQo5WYtdVxVCnE8IWMKH0nie8Zl
+gPnwQnnwQnH4xDnJxbpEOcJ1y/z+mVev8zXwDZKu9b0ejV9fE0fX9PH49Qk
rk208zcG6xh9XmB+QHIgdtFf2L/4eojjd4gxR1lLcK3jqYbxgp5Xro0TtUDJ
w5kpDxpnfZ9LQ6wb8Bslj+KDSs7bl4pZ9uksnz/L/kyVPZfrkruTeI/YxZ8L
9JSPq+B8xZNKfOq4qGr00D46UJkLVR0vvP8DxjfKez7gfSD5/3nb8Hnb83nb
83nbk/XrBmO1sp5NcrxP8v7o338bT/v8KfbLFOcVMremGFyfPL0sxFy9zP69
J8T8hEt1reYr0dd5+ZsQ5+VvnIdI1NfWyvtlDG73vrZ7P9u9t+22P419r9bS
XXpSWT+2JXEdw5lKkCsXOS6wvv132v7BHtpHNyl9eNoxf9rXqR3iuoyrlWii
LXWujz8f4vvCmbpNeW9YqDx+gPcxwJip25TnYKGed97nJDGf5RgFekbPKvkN
c329vsYIXa3UEniX1tYm2lK5T/JrnRDXJ6SOq2OwNj2S+v2RJObCIwZ5nDps
VRKfj7m6yutgtrLOkbdzjCLnaWXHSWXHf2XnaWXjUx93Y4hRQSsrf2+bxDmD
S7TU+XCPMUmpU/EVHavLfB9pSZwHaUaenlQGX5rvE1sr82FGEnM2XufPlbSm
ksd+7Hv5sc/7se/j50kcu/gLf+6i5GvqldIk1iu4UIuUoG7BIT7+wxAfjyN1
kRZpqfJcJI+eCzHHIu8BC7RcEvu+nH1ezj4vZ7+Xs9/L2e9YYj9OsJ8n2H8T
7NMJ9ukEg35l/f9ZiNFcuyr7JebLrhDrI1ygOXpGmTPYTjOU8fHzEONu39/8
JI6D+fb3fMfOfIP3jBW0sk5Q3jf5enwS8/V4Y46Ss3GKvqlrbadM51Wm8zHT
+ZPpfMw0snWnlvj8QT4PL+ogHzPIxw/y8azHzUI8I8DlSdxr4VX+fIOyTo1I
uT7EOYbH9N9KzsGndbWuU4J14WdJzAWYo0XOg4rGIiXfV3R+XOvvrvXvuE/r
+/cPnS8HQ5xLyFzC15X+XG9/rjfo1/X263r7db39uj75/zxU5vgo8/llPr/M
4DplXqfM65R5nTKvQ76fl8R9MD6n2Urk6BllDGOGkv9fSWINi5v9mbx3fxJr
Trygbfx9fy1zvNzpeMM7HSc4URkvNyQxx+NP/LmOUo/fx3UNxlKTJNaAOEsL
9KCyntFP1ZKYb6oZY3S2knuwQMk/5L20EPf7WFGJPOV85DtJnIM4XufoT/37
FGX+Ub/uSWJ77DG49h7bBx/TibbjaONzpX1xlX7p+y0fYqRpN83TfD1hv7S1
X9r6em3tj7ZGpk5U+mlKEtdl6vaxSay7sJa+oMR5XWX/TbD/Jhj0Y9Mkznlc
rcf0olbxcet0vTLPya/vG+RYJM9yvjEsxHof9ylnTEjeH+j9IDHV33c0WAOw
uXbV3j5uq89HxuhWr4PU8+8ZB/Qbpa5H6vrUf8nHIdaZeK/u0pPKHuFjx0Oj
EPdvOEMvKDUBVtKaSjAfqRt/GWJdiDN1mxKTtVDPe7+9vP9e3jfSRthcW2hX
JXrrQKV9yCPLQ8xP65K4311nMG7xyjjdEuJ6gxeV9WWLYxSzdYvjFEt83xtC
zCMbfJ8bfJ8bfJ8bfF8bfI8bjK2297tJzHU4Q4kLSptjJa2pjZR2vy/E9Qhz
dLmyLrFOlgsxrlX2mdP9PV6rx/WU4/+vIdZ6SM2Jy5R1IMtxkuX7wQLlvWc5
XrIcL1hXeX71ENcPnKc5WqBnlDWkulFTs5T1hHWtnnmjnpGmu/SkMjmwgjL+
U/8lvw9xD42DlHy/PYlrwXajQM9qXR/3gPeDB/WMnlXu4wEjQ6nnWP/XJLFG
wEVK7FPyC/vh4SHuhzFfOTccboxX+vOaJO4pcKou0dX+fb1utx0+CjFv4L3a
Q3cpeeMj42Pv/50krp3vGAf1rHKvuMvHdw/x8d39fXfbrbvt0t3x+EyIa9cz
BuOTfNM0xPmLxGTNVvIM+fCREHMlfqNEMyVffjeJNQwu0BJt59+vnLvuTeK+
BEcqwRqA6Uo9R921OMT6CamxsIIS1FXkrRrO2xoG85h97utJXMteN1brMWUd
w7v0aZ2rrG/UCdtCPFfZ5jjC8TpH12q+UmvgPdpXpyjXXeF18XkdouN1jvI8
fFOJtbrN+XNriH2B83SB5miJntFbnVvYTjM0V6/smxoa7yvrO7K+k89HhVgz
IjUj1tEWSpDL2V8UGuw7sLye0K9s75sdz7hUDyg5+GbjKR2ux22XiUa2ztMF
mqNnlHvGatpOMzRXaRfOY74b4vqN25SorU21pU7WbMf57iTuK3C9EmXK2McK
Wlkn6GL91Hn2oxDnGY7UvVqkpUqkK/OuehJrYtyjj/n7iUpdTr2xO8Qabbfj
49skrns4SQnWQFymrIOp/5KhSVw3cJASrB9IriTfHQgx3+EsXabb9aAe1rP6
K+/hV94PBn9fUR/TNJ2o1OfXJzHv4yG9wd+v1s26XdmPtUziGMdivcrfD9Kv
fPwlr33J4HGXfJ1Lvs4lX+eSr0MddizEPH7M8XTMsYaZOlmzdYsS1GPsvz8J
cf3ENbpPmds4Vu9I/b5XEuvDXsY6pU5E5u8Pk1ir4TCdoe/qBb3Ox1fSRnql
Pj6axLr4qEENjJO10PYotj1wlV5U2gUHaaZm6xbdqcW2UbHtRJ7+hfG8DlFy
Mq5Q8vJPkzhG8bD+wN8fsB07htiOHW03XKfUeSuSOP7xOZ2lOUps1wI9qGf0
rJLP8AGtq7wf9i+vGjP0Xb2g9NOr9hNW15raSLO83r0hfq6ABOeT5LtbQsxz
uFvLlFx3izFBFyv5jXq1c4jntZim8zVPyZHYWgnOXdmH/jjEvIjE/TrM67Yy
hmuefq58FoL1tbWOcZwscRzgEJ2jazVfqQ+wr76pxApdq9scPw8Yy/SwMr4e
sD+pS+cmMb9gUyWW6CUlz+BqXa/kGeq3f4R4Xoclyt4JczT1XzI4xM+isar2
0D66SfmcZrAxTz9SPrehrvvIOKTUdbhZS31fGQY1INbSjpqjvE/W65Eh1oc4
Ql/X1UptiHdpbW2iLZW48rnRo0ZfHaGr9aKSq7GK1tYm2lJHKtfnvGZHEs9r
cIISnNuQL/8UYs7FYTpaP9cLylzF/kqQb9mfPxziuQJynvCw0Vy7KucI1Bun
k1hv4EItUqJUqTEwXccrdQf5bm+IeRGf1F46T9cpuQc7aq6ynv3FeYxpOknz
lPyAnXWMjtXL+/kkngOcMi6fASR+FyiJNSYe11OO2w9C3Id84Pv7wNjsvHw2
xPn4rPMMl+gx/beyJ3nWWKfMT9a7hiGeF+Iq5bywodFW+2umTlTWOj7fmx9i
PYdHlHMXnKoEdR75t2qI+1uspfV0l55UEkNV42NfZ1+I+wFsowN1qm7Qrbpb
b3cOYa6u1ov6XR9XW5tqS83WLVqsx5T1nnr27RDrWWyo7+u3Sn2EryixTKlz
yTs/DDHu0xpaSzsqY6RuEvsEp+gRHejfpyp9ckfKlUmcL9hLiXVaqLwOdlPq
NNataUlcr6cZn+sFZe3GRkqu4Ly5ZxLP57GGvqDEbOU8HwuU83zW/z8b3ypt
iBOU9qNO3mlc1Mufadl/l/+mxVpiu+wPsV2wl67UdUpb4F4laBfqrj4h7jvw
HT2o1FDYXQn2g+TD9iHmQxypSzVf9+ppLVVyJN6jRLqSL6mf3gtxHuJ8Xa+7
tUypp7CC3qKVdYIuVoI6i/1PgxDzObJnwvJaUYk0zVP2TeSnds7HdkaurlLm
ZTv7EzM1W7foTi3WY0o/cz6w0fbeaDvjWs1X2hOf0vaarn11uI5XgrqLvdy0
EOcSFit7tWm2yzTbYpqRp/l6Qtn3jUviGoMn9JSW8+/X6s26VE/puOA1Qjyv
wwN6Si9fK3it4LVC/MxjnPc7zliqxx1nrRxnWE/n60ktU8YXVtVWjqlWjqnG
5qjG5qjG5qTG5qnG5qnG5qnG5qnGtjN+oPuV9qS+3RHiuosf6SG9pKy9O4xS
x82Lxmv6nh7Qb5SzPHxQh+s43aa0G+vxm0nMW28aO3WPFitrNbbVQTpRGffU
RTeFmM/wOZ2o2TpPc/SMErdqNa2uGZqr5EDqxhEhrssjjKm6W/cp9SLnfRdC
nNPIuR/W0YbaX0cp/bbFdsK5uly32E54SZlreIOu1u3KvKLu+zSJ6xoO12ma
p8Tnyn4O2ceRt9okMW+1Mdpprl5U6gxsqoM0U7N1i+7UYj2mJb7vNSG+b0zT
POU9YmvtrGOUoG5l/ekQ4uci2E1H6iLdq0Vaqqw/HYx0pT4n33w/xFyFxPX6
iDbTpb7+Al8P1yjXx/raQRf4Orz/6T5/uu9/uteZ7vvF01qqXHe615vue8ch
Ot3XmB7+//OFh0LMY1im5LGHjFa6WMlj7Ov/lMQzIByic5RgD48rlP07+eqc
4xsLtVjPOb6xvE7TfD2hjHPW5wEh5gnco6zTWFEbaFtNU2KiXlmvv+d4xHaa
q6uUqKNNNVOzdYvu1GI9pox31pWfGLW0nqbpLj2p7CWwqrbS1sqcYB/8nySe
Q+EwnaHv6gUlONfCSlpTG2mWXvn+zO0h5nlcrKuU/He7UUcban8dpZm6Uy/Y
Li28X6yiLWwXzFNyQgvvv4X3j2N0jZIX2Bc/HuI5L96j7F8eN8bqJz5+to/H
NbpPed5sHz/b5842PrGdahoN9E3do6x/2FDb6gDN1Il65XtJk43Fukpp+8n2
A9bRhtpfRyntzfnypBDPl/GocsY8yTE+yZishcr3MDgfuy2J51C3GRlaouzz
kPMn9s3NHPPNjLG6S88r472Z4x353k5D5kOI36PB95XP4k7aL8j+7KUQ92dY
XWvoC9pTZyufhbxkFCj7td5J3AvgSj2n5f17A03TbjpN8zRf9yt5jXz2aIj5
C8trRW2gRJoO0DzN9zrXeL/XeL/XOH6wge7Ra3wNvFMf07Y6QK98LtQlidfH
GtrFcY3cQxevjxX1MX1JB+hEpb2pI/+WxJoU39MDSnyj1KP4iLLucv78Woj1
LXbTpbpW83Wvsj/C9tpXiSW6Ual3OccaHeJ3JHCqLtF/K+dX+KwSnF+x/u4J
cT+Bu7VM2bdiBb1FH9JWuljfU4L967POQ/yhP9+nNbSW5uhy5fs/5K9/JnHc
YANto+30Tc3VVbpTCdY8vFPb6iDN1Gzdoju1WI9pie3+ZIj7HTykxA5ln0Od
3dpYrlu0UIv1nF5S6hG8QafpZj2h1CPUa0+EWGfiIl2je3WfUq/h/Up00GE6
XRcodRvn0oONo8oZNT6szZVzar5n+nUSz89xjBLsjZH9NPXZqCTuUbGXEit1
nRbqOWW/ih8o7cI6tTGJ6wsO0I2+b2T/gE11kk7WbC1U+p/8sz8xfyYxJ+83
yDtYXitqA31U03SATtM8JY/+K4l7PJyq7P+or55K4ucMTxnDdIa+qxf0P0qd
hZW0kY5Q6ivOXbcmsT7Bhvq+Et8qax7era/o27pMOUeknvpdEtdfrKX1tJmm
KbFLTyrrMVZV6i72Kysd/9hNR+oi3atFelpLlfmw0vmw0vGO7bWDput0XaAr
nR+041sh9gXO0u36L6UvsK6O0NR/SY/gv5ML8fM77KMD9fK/KTUG6zz9SD9W
Ps+j/vkiiecYmKHZOk/XKcGZBN6qHTVXOa8g/xwJcT7gct2vhVqs55TchuW1
gT6qaTpN8zRfiRNK/uP8aVGI+RgPKXl4kbFcdyj5mXX0YaOpztUlekzJw/is
jtbVul6v/HuLQyGuZ5ihrIFYQ2tpjhYp9eXfk5i/cZ8S5GecrZ8odSf1cE9f
v6f93tPXxxLldXsaOVqkh5R6mfz5lyTmc5ypR5WgVsdJWqjnHc9DHc9DHc9D
Hc9DHcfYSXvoYB3q+GWeNw5xfuNCXaqntVTJxY2Np7S9put4pa76ZRLXHnxJ
e2t5/95Nh2ieUkezznVIYr3fwRijXyvfAcUuWqCnlDqf/eesEPMl1tMWmqbz
9aTS0FhBK2tVbaWdlaBm43OWO0I818RZmqPv6ArdrgV6UM8qUU0f0LrK9yL4
fPsxo6NSP+DD2ly7ai/trQOVzyapD9OTWB+mG6N1sq5S9qd4u96pdbShttX+
yj6V+uWzED//xwm6QzmL+8z7ezHE+gMX61HlXrG5tlBilE5SPoP9URLHAA7V
XXpSq/q4h7SV7lHWAerpG5P4vm402mm6TtbFmqurlDr6RtvxRtvxRtvvRtsP
m+oozdRs3akXnNd/d17jSF2ke7VIT2upsm7j/fqEttcOmq7TdYGu1A+VfP3b
ENcT/EgPKfkbayixSJfb7xuSmDc3OMZxsC5WYqMeVcbGBsc/ttCu+qKO0km6
Qcm73ZN4Rozf9+frtZkyTh/BJH7WjbN0mR5W4l/K95vwLcf5WechdtTByr3g
w9pcu2pv5Xztv0nMb9hK03S45inBuRu21s46Rtco527k5dpJzMu1jQ7aU8co
5wP4jL6kBXrO+VTJGKrMu0rOu0rOO+r0hSHWg/iqztB39YL+R6kLsZLW1Eaa
peSjt5KYj94ydujXyr+9xINKv/86iZ8l4HQ9oaf0ay3n46+98jxlvWKdui3E
deo2+xHraQtN09/pfM3Tk/pfZR3Dykq01s46RmfpGr38vSL6L4n7F2yoxPu6
Vb9V9jF4t76ib+syZR9DfTUjxPoKb9MMLVHqK+ypRI5e+R7cphC/S4N9dYBu
U/aoWFubaEsdqeTRp42Ful+L9LSWKjUSNtDGmqbtNV3HK3UPdf+vQqyRcLnu
10It1nNK3Y/llUjTaZqn+XpETyj1PnX7l0k8X8GHta1O1bm6RIlLSj2PT+po
Xa3bdYeyX+DfjfxPEs8J8TUdr3P0b0p8o3yOjQ/qFL3yvdIzIX5/FJfpYSX3
4gEl/74QYv5F8usLRlftpb2Vuolzvw+TOH/xR/oTrafzldilJ5U5ihW0qj6k
rXSWvqfkRb439UYS1503jCl6RP+lvF+cqvN1t+11s/GAPqJ/1GX6mdKGN9ue
1L2HQ/x+Ec7Sd3SFbteDeljPKnUtdtcDyuc3f03i5zd4jz6jW5X4Vsk/+LiO
1bd1ti5T9n2cf9dP4nlKfaOZjtaxel75HAP5d9J8v+FW41WdoQXKWoTVtaZm
6ULN9b6zvF+cpFneY5b3m+V9ZnmfWd5nlveH5PM76M8QzwfxSe2lozRDV+o6
/UI5g8aOSnygnGNQt70cYn2GG/SoUovhi0qM0klKHXZLEtcgbKjP6Pu6VX/u
4+/Wt5V9/O+TOCZ/7zjG7XpYP9OzeofPq6tv6QFlXDJO6hj1tZn+TkfrWP1c
zyvjp47jh36fGeI+GF/SV5Wxgt2U2G+/fpXEehtHaYZ+oQR9h/dpLe2of1T6
k89d/pHE2gaX6iklqGfwZn1Kh+s4Ha98r4jP8x5K4v9/At6p1ZR4QXtoT52t
m5T9P3LGwb+H+HOI5z3Iv4PAYUq98W6I9Qbephlaol/oV0qbYS3tqTM0R4l/
OP77JXFf1s+YrIt1g25U9oFYR1voi/qyjlLmB/Xj20msX7G79tdxSuzQE/q1
Upfi9fqZnnIcPmG8pK/qNOX7tFhTG+kQZYxSv88J8Zwdh+lk5d6xjRL79IKW
2b/v2L/v2K/vGFf696j9ihM1WxdoiXIWi+00Q2foUfuTefV+iHMGa+hvdbkS
RXrI/PN8iDkM79GG+oxu1W+VeEXf1mVK3cznJg8aT2tvXaj7lboUy2tF/ZU2
0Ec1TQdonubrEfv1jRBrYSxVxgJ20CFKTNcFulI5K+Dzhn4hnlP087rIeQTW
1ye0g/bzGv28fj+v38/r9/P6yHkE5zZXh/g9PWyj7TRXd+o/9aJyZnO1MUgz
dYvu1GI9pnzOyb6iUxL7r5P908k+7GQs1P1apKe1VOnXTvZnJ/uxk/2IjTVN
03W80q+cM3ycxHOGj42j+hfl7AEf1ubaVTl3IEc/F+I5NG5S/n+LsJ4SnXSw
DlXOpZnXfzAW6Rrdp39X5j7OVuo36vG7jPm6Xnfrn7VM+Wweb9HKOkEX63vK
5/HUvc2TWH/jI0r8Ud/QI0q9jFOV+pt96/8m8fuZ+Kj21QG6WrcpwV4Wa2sT
bakjdZNeHof0m9FNR+peZc3E+/UJfU1XKvOJ8+IPknhejOk6WifrKiU458Q7
taG21f46UXfql8p6wD6rURLPhxoZA3WQDtXfO+8eN7pqNx2pe7VIT2upkose
t10et12wvXbQdO2n03WBrtQPlXakzv88xP0N3qJ/0DW6T/+qf1dqXnxcx+ps
/URPKuPgdyF+/xM7a1dlDOD9SgxT1ln2OZ8ksV7F5zRHV2iBEmeUz0GxmlbX
mlpXs5R9EPXU8SSeA2NH7aeDdYNu1I/1qBLkM2yuLfRFfVkn6QYt9L6/CPG+
sYk+p7M0R1fodi3QT/SsstfAalpd62qWcv76hxDrZLxPO+gYfUu/Vmpk5Bz+
nyGew+MhpZ7B3+oiXa4f6GbdoaWa+i95NcTPJbGRDtRBOlSZk9hDiXnK5yvU
cZuTWKfjbZqhRIl+odToWEt76gzN0XeVuu72lL8OMe9iG22nuXpR/1fJvfg9
vVqJ2tpUJ2u2btFiPaZX6oPvhFgP4ePaTRdpkZYq8SN9QjtoP31Dp+sCXakf
KvmIfUV7Y5xO11P6D2X/gNfqzfqMjtPjeuX/t+dvIa5vOFM36EY9qn/R48pn
5H+zjfFlnaSTtVAJPj/nnPW3xis6Sgv1kF5Sxj5u1h3KuP8/ONwSDw==
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[13, 59] -> 
             RGBColor[
              0.9097917272727272, 0.7418666818181816, 0.5981349545454546], 
             UndirectedEdge[210, 309] -> 
             RGBColor[
              0.7418808181818182, 0.7974818181818182, 0.9678374090909091], 
             UndirectedEdge[88, 427] -> 
             RGBColor[
              0.9718003181818182, 0.9659832727272727, 0.6779919545454545], 
             UndirectedEdge[293, 483] -> 
             RGBColor[
              0.8006537727272727, 0.8445361818181818, 0.9806750909090909], 
             UndirectedEdge[46, 150] -> 
             RGBColor[
              0.9896106818181818, 0.9897538181818182, 0.8059990454545456], 
             UndirectedEdge[400, 444] -> 
             RGBColor[
              0.9555194090909092, 0.9535697272727273, 0.6961461818181818], 
             UndirectedEdge[98, 105] -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             UndirectedEdge[128, 439] -> 
             RGBColor[0.8662555, 0.8938532727272728, 0.8679570454545456], 
             UndirectedEdge[23, 62] -> 
             RGBColor[
              0.8308844090909091, 0.8681233636363637, 0.9519232272727272], 
             UndirectedEdge[201, 236] -> 
             RGBColor[
              0.9926352272727272, 0.9910045454545455, 0.7558745000000001], 
             UndirectedEdge[40, 477] -> 
             RGBColor[
              0.6408022727272726, 0.7185290909090908, 0.9653728181818182], 
             UndirectedEdge[455, 482] -> 
             RGBColor[
              0.8000501363636363, 0.8442695454545455, 0.9607025909090909], 
             UndirectedEdge[60, 131] -> 
             RGBColor[
              0.7418808181818182, 0.7974818181818182, 0.9678374090909091], 
             UndirectedEdge[179, 222] -> 
             RGBColor[
              0.6774155909090909, 0.7379556818181818, 0.7398057272727274], 
             UndirectedEdge[111, 175] -> 
             RGBColor[
              0.6924691818181818, 0.7546295454545455, 0.9291995909090909], 
             UndirectedEdge[51, 110] -> 
             RGBColor[
              0.9414603636363637, 0.9555905454545455, 0.974571409090909], 
             UndirectedEdge[84, 261] -> 
             RGBColor[
              0.9552221818181819, 0.9274357272727274, 0.650471590909091], 
             UndirectedEdge[156, 479] -> 
             RGBColor[
              0.8875097272727273, 0.9129128181818182, 0.9812498181818182], 
             UndirectedEdge[158, 437] -> 
             RGBColor[
              0.6471835909090908, 0.7197705454545454, 0.9682358636363636], 
             UndirectedEdge[103, 355] -> 
             RGBColor[
              0.7625525454545454, 0.8003927272727274, 0.6782186363636362], 
             UndirectedEdge[13, 228] -> 
             RGBColor[
              0.8573985454545454, 0.41598849999999976`, 0.20157199999999997`],
              UndirectedEdge[59, 409] -> 
             RGBColor[
              0.6726311363636364, 0.7398343636363636, 0.9627802272727273], 
             UndirectedEdge[243, 430] -> 
             RGBColor[
              0.9511285909090909, 0.9630723636363636, 0.9676107272727272], 
             UndirectedEdge[333, 441] -> 
             RGBColor[
              0.8551059999999999, 0.8870454545454545, 0.954337409090909], 
             UndirectedEdge[179, 385] -> 
             RGBColor[
              0.5959105909090909, 0.6775309545454545, 0.9639695909090908], 
             UndirectedEdge[81, 447] -> 
             RGBColor[0.6781735, 0.7395767727272726, 0.8222994545454547], 
             UndirectedEdge[69, 404] -> 
             RGBColor[
              0.9164975909090909, 0.6489337272727271, 0.4734738636363637], 
             UndirectedEdge[113, 380] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[85, 489] -> 
             RGBColor[
              0.8390093636363636, 0.8736804545454545, 0.9156674090909092], 
             UndirectedEdge[277, 498] -> 
             RGBColor[
              0.8921227272727272, 0.6322624545454545, 0.5822413181818182], 
             UndirectedEdge[18, 160] -> 
             RGBColor[
              0.9880502272727272, 0.9770974545454545, 0.605480318181818], 
             UndirectedEdge[355, 431] -> 
             RGBColor[
              0.7551061818181819, 0.8073452727272727, 0.9454503181818181], 
             UndirectedEdge[357, 492] -> 
             RGBColor[
              0.8164330909090909, 0.8571181818181818, 0.9821801363636363], 
             UndirectedEdge[165, 386] -> 
             RGBColor[
              0.8617186818181818, 0.8919771818181819, 0.9431438636363636], 
             UndirectedEdge[218, 274] -> 
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181], 
             UndirectedEdge[116, 441] -> 
             RGBColor[
              0.8793275909090909, 0.9059675454545455, 0.9567515909090909], 
             UndirectedEdge[258, 435] -> 
             RGBColor[
              0.8551059999999999, 0.8870454545454545, 0.954337409090909], 
             UndirectedEdge[112, 445] -> 
             RGBColor[
              0.5457742727272727, 0.6399536363636363, 0.9582862727272727], 
             UndirectedEdge[114, 179] -> 
             RGBColor[
              0.6727548181818181, 0.7375539545454545, 0.9279434090909091], 
             UndirectedEdge[155, 467] -> 
             RGBColor[
              0.9818611363636364, 0.9823904545454546, 0.6934519999999997], 
             UndirectedEdge[243, 421] -> 
             RGBColor[
              0.8661022272727272, 0.8961040909090909, 0.9791386818181818], 
             UndirectedEdge[172, 289] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[381, 468] -> 
             RGBColor[
              0.7409802727272726, 0.7925612727272726, 0.7853365909090907], 
             UndirectedEdge[17, 277] -> 
             RGBColor[
              0.9348476818181818, 0.9506588181818182, 0.9857649545454545], 
             UndirectedEdge[279, 477] -> 
             RGBColor[
              0.5892456363636362, 0.6766730909090908, 0.9613140909090909], 
             UndirectedEdge[4, 405] -> 
             RGBColor[
              0.9930106363636364, 0.9891982727272728, 0.6070716363636363], 
             UndirectedEdge[36, 379] -> 
             RGBColor[
              0.9322937272727272, 0.9479402727272728, 0.9618728181818181], 
             UndirectedEdge[278, 401] -> 
             RGBColor[
              0.9821161363636364, 0.9846753636363637, 0.8476497272727272], 
             UndirectedEdge[152, 399] -> 
             RGBColor[
              0.9937685454545454, 0.9908193636363636, 0.6895653636363634], 
             UndirectedEdge[173, 406] -> 
             RGBColor[
              0.6116899090909089, 0.6901129545454544, 0.9654746363636364], 
             UndirectedEdge[239, 332] -> 
             RGBColor[
              0.9281668181818181, 0.9415022727272726, 0.8022834090909089], 
             UndirectedEdge[116, 361] -> 
             RGBColor[
              0.8793275909090909, 0.9059675454545455, 0.9567515909090909], 
             UndirectedEdge[288, 498] -> 
             RGBColor[
              0.8351165454545455, 0.5870346363636363, 0.5846868636363636], 
             UndirectedEdge[16, 386] -> 
             RGBColor[0.7874971818181817, 0.833205, 0.9362861363636363], 
             UndirectedEdge[216, 464] -> 
             RGBColor[0.7006539545454545, 0.7648360000000001, 0.971788], 
             UndirectedEdge[379, 400] -> 
             RGBColor[
              0.9397400909090909, 0.9409877272727272, 0.6946411363636362], 
             UndirectedEdge[22, 24] -> 
             RGBColor[
              0.7227151818181817, 0.7814855454545454, 0.9546144999999999], 
             UndirectedEdge[231, 355] -> 
             RGBColor[
              0.6894876363636364, 0.47160363636363634`, 0.5712744545454546], 
             UndirectedEdge[434, 495] -> 
             RGBColor[
              0.8322124090909091, 0.8697001818181818, 0.9836851818181818], 
             UndirectedEdge[75, 323] -> 
             RGBColor[
              0.9434432272727272, 0.9547480909090909, 0.8754924545454545], 
             UndirectedEdge[165, 288] -> 
             RGBColor[
              0.7848744545454546, 0.8319541818181818, 0.9791700454545454], 
             UndirectedEdge[90, 229] -> 
             RGBColor[
              0.9419309545454545, 0.9541227272727273, 0.9005547272727272], 
             UndirectedEdge[267, 424] -> 
             RGBColor[
              0.9304634545454544, 0.7447775909090908, 0.3085161818181817], 
             UndirectedEdge[258, 403] -> 
             RGBColor[
              0.7150237727272727, 0.7773012727272727, 0.9722305454545455], 
             UndirectedEdge[274, 305] -> 
             RGBColor[
              0.9601044090909091, 0.9674768181818182, 0.8465403636363638], 
             UndirectedEdge[399, 478] -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             UndirectedEdge[359, 463] -> 
             RGBColor[
              0.7161024999999999, 0.7765538181818181, 0.9658080454545455], 
             UndirectedEdge[302, 422] -> 
             RGBColor[
              0.8748133181818182, 0.7375936363636364, 0.6072994090909092], 
             UndirectedEdge[21, 335] -> 
             RGBColor[
              0.8406546818181817, 0.8760402727272727, 0.9845943181818182], 
             UndirectedEdge[266, 445] -> 
             RGBColor[
              0.6792438181818181, 0.744766090909091, 0.9515866818181817], 
             UndirectedEdge[200, 452] -> 
             RGBColor[0.8132755, 0.854133, 0.9383155], 
             UndirectedEdge[112, 471] -> 
             RGBColor[
              0.8390093636363636, 0.8736804545454545, 0.9156674090909092], 
             UndirectedEdge[481, 496] -> 
             RGBColor[0.7064342727272727, 0.769072, 0.9727687272727272], 
             UndirectedEdge[6, 422] -> 
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273], 
             UndirectedEdge[137, 424] -> 
             RGBColor[
              0.9718003181818182, 0.9659832727272727, 0.6779919545454545], 
             UndirectedEdge[89, 482] -> 
             RGBColor[
              0.8941224090909091, 0.9178445454545454, 0.9700562727272728], 
             UndirectedEdge[142, 254] -> 
             RGBColor[
              0.9755034545454545, 0.9797436363636364, 0.8588432727272728], 
             UndirectedEdge[178, 321] -> 
             RGBColor[
              0.9865379545454545, 0.9764720909090909, 0.6305425909090908], 
             UndirectedEdge[151, 456] -> 
             RGBColor[
              0.9847037272727273, 0.9594405454545455, 0.44811022727272737`], 
             UndirectedEdge[346, 431] -> 
             RGBColor[
              0.8793275909090909, 0.9059675454545455, 0.9567515909090909], 
             UndirectedEdge[65, 297] -> 
             RGBColor[
              0.9950293636363636, 0.9917766363636363, 0.7003550909090913], 
             UndirectedEdge[79, 253] -> 
             RGBColor[
              0.9911229545454545, 0.9903791818181817, 0.7809367727272729], 
             UndirectedEdge[376, 475] -> 
             RGBColor[
              0.8308844090909091, 0.8681233636363637, 0.9519232272727272], 
             UndirectedEdge[209, 259] -> 
             RGBColor[0.9073477727272727, 0.927708, 0.9476691818181818], 
             UndirectedEdge[464, 496] -> 
             RGBColor[
              0.513467409090909, 0.6158950000000001, 0.9548411818181818], 
             UndirectedEdge[101, 103] -> 
             RGBColor[
              0.9850256818181817, 0.9758467272727273, 0.6556048636363635], 
             UndirectedEdge[69, 348] -> 
             RGBColor[
              0.9930106363636364, 0.9891982727272728, 0.6070716363636363], 
             UndirectedEdge[116, 277] -> 
             RGBColor[
              0.8661022272727272, 0.8961040909090909, 0.9791386818181818], 
             UndirectedEdge[171, 471] -> 
             RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454546], 
             UndirectedEdge[133, 429] -> 
             RGBColor[0.9822400909090909, 0.983201, 0.7346988636363638], 
             UndirectedEdge[37, 203] -> 
             RGBColor[
              0.9690147272727272, 0.9733375454545454, 0.7570859545454547], 
             UndirectedEdge[299, 399] -> 
             RGBColor[
              0.9746143181818181, 0.9272990909090909, 0.5223471818181818], 
             UndirectedEdge[311, 429] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[327, 446] -> 
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181], 
             UndirectedEdge[15, 249] -> 
             RGBColor[
              0.8164330909090909, 0.8571181818181818, 0.9821801363636363], 
             UndirectedEdge[50, 242] -> 
             RGBColor[
              0.7150237727272727, 0.7773012727272727, 0.9722305454545455], 
             UndirectedEdge[163, 355] -> 
             RGBColor[
              0.7617188636363637, 0.8122770000000001, 0.9342567727272727], 
             UndirectedEdge[192, 435] -> 
             RGBColor[
              0.9806038636363636, 0.9840500000000001, 0.8727119999999999], 
             UndirectedEdge[31, 191] -> 
             RGBColor[
              0.515825590909091, 0.23836704545454543`, 0.5498676363636363], 
             UndirectedEdge[385, 415] -> 
             RGBColor[
              0.8941224090909091, 0.9178445454545454, 0.9700562727272728], 
             UndirectedEdge[207, 257] -> 
             RGBColor[
              0.9750602272727273, 0.9422309090909092, 0.6168909545454546], 
             UndirectedEdge[359, 408] -> 
             RGBColor[
              0.7404773636363635, 0.7932250909090909, 0.857040590909091], 
             UndirectedEdge[183, 202] -> 
             RGBColor[
              0.5869781818181818, 0.6485853181818182, 0.8169280454545457], 
             UndirectedEdge[170, 223] -> 
             RGBColor[
              0.8793275909090909, 0.9059675454545455, 0.9567515909090909], 
             UndirectedEdge[40, 430] -> 
             RGBColor[
              0.774271818181818, 0.8233415454545454, 0.9586732272727272], 
             UndirectedEdge[69, 444] -> 
             RGBColor[
              0.9592225454545454, 0.967330090909091, 0.8769975000000001], 
             UndirectedEdge[215, 417] -> 
             RGBColor[
              0.7676591363636363, 0.818409818181818, 0.9698667727272727], 
             UndirectedEdge[423, 429] -> 
             RGBColor[0.978413, 0.970915, 0.6667984090909089], 
             UndirectedEdge[5, 83] -> 
             RGBColor[
              0.8875097272727273, 0.9129128181818182, 0.9812498181818182], 
             UndirectedEdge[311, 366] -> 
             RGBColor[
              0.8661022272727272, 0.8961040909090909, 0.9791386818181818], 
             UndirectedEdge[133, 366] -> 
             RGBColor[0.8906010454545454, 0.911301, 0.7574203636363638], 
             UndirectedEdge[76, 359] -> 
             RGBColor[
              0.5892456363636362, 0.6766730909090908, 0.9613140909090909], 
             UndirectedEdge[172, 218] -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             UndirectedEdge[177, 484] -> 
             RGBColor[
              0.8902220909090909, 0.9104904545454546, 0.7161734999999998], 
             UndirectedEdge[45, 328] -> 
             RGBColor[
              0.993134590909091, 0.9877239090909091, 0.49412077272727273`], 
             UndirectedEdge[115, 144] -> 
             RGBColor[0.7837692272727272, 0.831856, 0.9788568181818181], 
             UndirectedEdge[63, 72] -> 
             RGBColor[0.8662555, 0.8938532727272728, 0.8679570454545456], 
             UndirectedEdge[248, 387] -> 
             RGBColor[
              0.5942174545454545, 0.6777978181818182, 0.9631146363636363], 
             UndirectedEdge[34, 44] -> 
             RGBColor[
              0.7662556818181818, 0.814153090909091, 0.8590699545454545], 
             UndirectedEdge[279, 285] -> 
             RGBColor[
              0.6376888181818181, 0.7145172727272726, 0.9661424545454544], 
             UndirectedEdge[13, 77] -> 
             RGBColor[
              0.9296297727272727, 0.7566618636363636, 0.5645543181818182], 
             UndirectedEdge[53, 445] -> 
             RGBColor[
              0.6792438181818181, 0.744766090909091, 0.9515866818181817], 
             UndirectedEdge[91, 298] -> 
             RGBColor[
              0.7264322727272725, 0.7857639999999999, 0.9738173636363636], 
             UndirectedEdge[6, 451] -> 
             RGBColor[0.7359405454545453, 0.791349, 0.9322274090909091], 
             UndirectedEdge[87, 256] -> 
             RGBColor[
              0.9081814545454545, 0.9158237272727272, 0.6916310454545453], 
             UndirectedEdge[153, 172] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[72, 438] -> 
             RGBColor[
              0.9755034545454545, 0.9797436363636364, 0.8588432727272728], 
             UndirectedEdge[207, 440] -> 
             RGBColor[0.7359405454545453, 0.791349, 0.9322274090909091], 
             UndirectedEdge[19, 228] -> 
             RGBColor[
              0.8137090454545454, 0.570225909090909, 0.5825757272727272], 
             UndirectedEdge[8, 63] -> 
             RGBColor[
              0.4590861818181818, 0.5508086818181818, 0.9540728636363636], 
             UndirectedEdge[72, 128] -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             UndirectedEdge[229, 485] -> 
             RGBColor[
              0.6954937272727273, 0.7558802727272728, 0.8790750454545453], 
             UndirectedEdge[32, 407] -> 
             RGBColor[
              0.8874525454545454, 0.9115246363636363, 0.9204957727272727], 
             UndirectedEdge[475, 478] -> 
             RGBColor[
              0.9821161363636364, 0.9846753636363637, 0.8476497272727272], 
             UndirectedEdge[194, 412] -> 
             RGBColor[
              0.9348476818181818, 0.9506588181818182, 0.9857649545454545], 
             UndirectedEdge[370, 390] -> 
             RGBColor[
              0.8671373636363636, 0.8939999999999999, 0.8374999090909092], 
             UndirectedEdge[231, 233] -> 
             RGBColor[
              0.9119607727272727, 0.6470576363636362, 0.5486606818181818], 
             UndirectedEdge[114, 385] -> 
             RGBColor[0.9073477727272727, 0.927708, 0.9476691818181818], 
             UndirectedEdge[271, 442] -> 
             RGBColor[
              0.9226528636363637, 0.7751711818181819, 0.5921552727272728], 
             UndirectedEdge[206, 254] -> 
             RGBColor[
              0.7920339999999999, 0.8350810909090909, 0.8610993181818183], 
             UndirectedEdge[262, 455] -> 
             RGBColor[
              0.7587132727272727, 0.6230638636363635, 0.5912268181818181], 
             UndirectedEdge[7, 341] -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909092], 
             UndirectedEdge[187, 328] -> 
             RGBColor[0.9938925000000001, 0.989345, 0.5766145], 
             UndirectedEdge[44, 56] -> 
             RGBColor[0.8662555, 0.8938532727272728, 0.8679570454545456], 
             UndirectedEdge[142, 388] -> 
             RGBColor[0.6595294545454544, 0.7276904999999999, 0.9503305], 
             UndirectedEdge[282, 419] -> 
             RGBColor[
              0.9419309545454545, 0.9541227272727273, 0.9005547272727272], 
             UndirectedEdge[7, 244] -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909092], 
             UndirectedEdge[107, 470] -> 
             RGBColor[
              0.7676591363636363, 0.818409818181818, 0.9698667727272727], 
             UndirectedEdge[10, 383] -> 
             RGBColor[
              0.9760063636363636, 0.9790798181818181, 0.7871392727272726], 
             UndirectedEdge[249, 419] -> 
             RGBColor[
              0.9419309545454545, 0.9541227272727273, 0.9005547272727272], 
             UndirectedEdge[191, 271] -> 
             RGBColor[
              0.8875301363636363, 0.5510655454545454, 0.560317590909091], 
             UndirectedEdge[297, 490] -> 
             RGBColor[
              0.8186941818181819, 0.8561558181818182, 0.8326715454545457], 
             UndirectedEdge[32, 176] -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909092], 
             UndirectedEdge[353, 487] -> 
             RGBColor[
              0.6792438181818181, 0.744766090909091, 0.9515866818181817], 
             UndirectedEdge[281, 324] -> 
             RGBColor[
              0.9690147272727272, 0.9733375454545454, 0.7570859545454547], 
             UndirectedEdge[19, 59] -> 
             RGBColor[
              0.8661022272727272, 0.8961040909090909, 0.9791386818181818], 
             UndirectedEdge[197, 411] -> 
             RGBColor[
              0.7317914999999999, 0.7626568181818181, 0.6568323181818181], 
             UndirectedEdge[163, 343] -> 
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273], 
             UndirectedEdge[12, 396] -> 
             RGBColor[
              0.8405216363636363, 0.8743058181818182, 0.8906051363636363], 
             UndirectedEdge[51, 397] -> 
             RGBColor[
              0.9597254545454545, 0.9666662727272728, 0.8052934999999998], 
             UndirectedEdge[448, 482] -> 
             RGBColor[
              0.9414603636363637, 0.9555905454545455, 0.974571409090909], 
             UndirectedEdge[183, 285] -> 
             RGBColor[
              0.4833077727272727, 0.5697307727272727, 0.9564870454545454], 
             UndirectedEdge[155, 365] -> 
             RGBColor[
              0.9634648181818182, 0.9204912727272727, 0.6087275454545454], 
             UndirectedEdge[122, 217] -> 
             RGBColor[0.7522105909090908, 0.806692, 0.9758467272727273], 
             UndirectedEdge[249, 269] -> 
             RGBColor[
              0.9322937272727272, 0.9479402727272728, 0.9618728181818181], 
             UndirectedEdge[101, 331] -> 
             RGBColor[
              0.9888527727272727, 0.9881327272727274, 0.7235053181818183], 
             UndirectedEdge[246, 458] -> 
             RGBColor[
              0.8425368181818181, 0.8742673636363636, 0.7938388636363634], 
             UndirectedEdge[35, 437] -> 
             RGBColor[
              0.4007463636363636, 0.5215280909090909, 0.9467561818181818], 
             UndirectedEdge[354, 473] -> 
             RGBColor[
              0.9688907727272726, 0.9748119090909091, 0.8700368181818183], 
             UndirectedEdge[230, 484] -> 
             RGBColor[
              0.9914983636363637, 0.9885729090909092, 0.6321339090909088], 
             UndirectedEdge[108, 190] -> 
             RGBColor[
              0.9930106363636364, 0.9891982727272728, 0.6070716363636363], 
             UndirectedEdge[55, 136] -> 
             RGBColor[
              0.9167686363636363, 0.7233573636363635, 0.5705339999999999], 
             UndirectedEdge[59, 279] -> 
             RGBColor[
              0.7161024999999999, 0.7765538181818181, 0.9658080454545455], 
             UndirectedEdge[24, 170] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[184, 388] -> 
             RGBColor[
              0.6432485454545454, 0.7152769545454545, 0.9684847272727273], 
             UndirectedEdge[173, 242] -> 
             RGBColor[
              0.526059909090909, 0.6228780454545454, 0.9570300909090909], 
             UndirectedEdge[4, 345] -> 
             RGBColor[
              0.9688907727272726, 0.9748119090909091, 0.8700368181818183], 
             UndirectedEdge[59, 256] -> 
             RGBColor[
              0.8875097272727273, 0.9129128181818182, 0.9812498181818182], 
             UndirectedEdge[232, 480] -> 
             RGBColor[
              0.9718003181818182, 0.9659832727272727, 0.6779919545454545], 
             UndirectedEdge[3, 437] -> 
             RGBColor[
              0.6883201363636364, 0.7259373636363636, 0.6538044999999999], 
             UndirectedEdge[199, 448] -> 
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363], 
             UndirectedEdge[151, 226] -> 
             RGBColor[
              0.9815552272727273, 0.9596641818181818, 0.6111856363636363], 
             UndirectedEdge[241, 442] -> 
             RGBColor[
              0.6244410454545455, 0.534857590909091, 0.5860685909090909], 
             UndirectedEdge[303, 400] -> 
             RGBColor[
              0.9895624999999999, 0.9777228181818182, 0.5804180454545455], 
             UndirectedEdge[42, 378] -> 
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454], 
             UndirectedEdge[15, 499] -> 
             RGBColor[
              0.7150237727272727, 0.7773012727272727, 0.9722305454545455], 
             UndirectedEdge[341, 374] -> 
             RGBColor[0.956198, 0.9660793636363636, 0.9271220454545455], 
             UndirectedEdge[312, 334] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[7, 482] -> 
             RGBColor[
              0.9755034545454545, 0.9797436363636364, 0.8588432727272728], 
             UndirectedEdge[219, 403] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[50, 449] -> 
             RGBColor[
              0.8164330909090909, 0.8571181818181818, 0.9821801363636363], 
             UndirectedEdge[318, 430] -> 
             RGBColor[0.7484935, 0.8024135454545456, 0.9566438636363637], 
             UndirectedEdge[242, 449] -> 
             RGBColor[0.7922115, 0.8381960909090909, 0.9797659545454545], 
             UndirectedEdge[356, 365] -> 
             RGBColor[0.9405712272727274, 0.903146, 0.6380753181818182], 
             UndirectedEdge[154, 219] -> 
             RGBColor[
              0.6792438181818181, 0.744766090909091, 0.9515866818181817], 
             UndirectedEdge[69, 275] -> 
             RGBColor[
              0.9821161363636364, 0.9846753636363637, 0.8476497272727272], 
             UndirectedEdge[173, 310] -> 
             RGBColor[
              0.6529167727272727, 0.7227587727272726, 0.9615240454545455], 
             UndirectedEdge[351, 460] -> 
             RGBColor[
              0.9887288181818181, 0.9896070909090909, 0.8364561818181817], 
             UndirectedEdge[97, 207] -> 
             RGBColor[
              0.6727548181818181, 0.7375539545454546, 0.9279434090909091], 
             UndirectedEdge[122, 212] -> 
             RGBColor[
              0.8000501363636363, 0.8442695454545455, 0.9607025909090909], 
             UndirectedEdge[45, 224] -> 
             RGBColor[
              0.8421578636363636, 0.8734568181818182, 0.7525920000000001], 
             UndirectedEdge[144, 215] -> 
             RGBColor[
              0.7579909090909089, 0.8109279999999999, 0.9768274545454545], 
             UndirectedEdge[22, 214] -> 
             RGBColor[
              0.7374528181818181, 0.7919743636363636, 0.9071651363636364], 
             UndirectedEdge[142, 150] -> 
             RGBColor[
              0.9763853181818182, 0.9798903636363636, 0.8283861363636366], 
             UndirectedEdge[149, 419] -> 
             RGBColor[0.8889648181818182, 0.91215, 0.8954334999999999], 
             UndirectedEdge[11, 418] -> 
             RGBColor[
              0.7606528636363636, 0.8130320909090909, 0.9767558636363636], 
             UndirectedEdge[189, 346] -> 
             RGBColor[
              0.8248753636363635, 0.8634582727272726, 0.9830892727272726], 
             UndirectedEdge[185, 224] -> 
             RGBColor[0.8079908181818182, 0.850778090909091, 0.981271], 
             UndirectedEdge[17, 386] -> 
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181], 
             UndirectedEdge[194, 476] -> 
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181], 
             UndirectedEdge[258, 471] -> 
             RGBColor[
              0.8632309545454545, 0.8926025454545454, 0.9180815909090909], 
             UndirectedEdge[203, 397] -> 
             RGBColor[
              0.9693936818181818, 0.9741480909090909, 0.798332818181818], 
             UndirectedEdge[126, 173] -> 
             RGBColor[0.6595294545454544, 0.7276904999999999, 0.9503305], 
             UndirectedEdge[30, 366] -> 
             RGBColor[
              0.8661022272727272, 0.8961040909090909, 0.9791386818181818], 
             UndirectedEdge[95, 368] -> 
             RGBColor[
              0.9724789090909091, 0.9784929090909091, 0.9089678181818182], 
             UndirectedEdge[15, 242] -> 
             RGBColor[
              0.7150237727272727, 0.7773012727272727, 0.9722305454545455], 
             UndirectedEdge[150, 392] -> 
             RGBColor[
              0.8671373636363636, 0.8939999999999999, 0.8374999090909092], 
             UndirectedEdge[179, 296] -> 
             RGBColor[
              0.6116899090909089, 0.6901129545454544, 0.9654746363636364], 
             UndirectedEdge[3, 123] -> 
             RGBColor[
              0.9189780454545454, 0.9115978181818181, 0.6737791363636363], 
             UndirectedEdge[37, 257] -> 
             RGBColor[
              0.9797210000000001, 0.9426326363636366, 0.42875327272727304`], 
             UndirectedEdge[17, 178] -> 
             RGBColor[
              0.9555194090909092, 0.9535697272727273, 0.6961461818181817], 
             UndirectedEdge[68, 367] -> 
             RGBColor[0.567445, 0.5842544999999999, 0.608463], 
             UndirectedEdge[1, 363] -> 
             RGBColor[
              0.8647432272727272, 0.8932279090909091, 0.893019318181818], 
             UndirectedEdge[227, 329] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[121, 420] -> 
             RGBColor[
              0.6742670909090909, 0.7381793181818181, 0.9028811363636364], 
             UndirectedEdge[82, 149] -> 
             RGBColor[
              0.5745030909090908, 0.6607222272727272, 0.9618584545454545], 
             UndirectedEdge[129, 355] -> 
             RGBColor[0.43056731818181815`, 0.5450243636363636, 0.949301], 
             UndirectedEdge[87, 388] -> 
             RGBColor[
              0.6735884999999999, 0.7256696818181817, 0.6719052727272725], 
             UndirectedEdge[91, 228] -> 
             RGBColor[
              0.7152659545454544, 0.49253163636363617`, 0.5733038181818182], 
             UndirectedEdge[12, 161] -> 
             RGBColor[0.9830675, 0.9602895454545455, 0.5861233636363634], 
             UndirectedEdge[64, 115] -> 
             RGBColor[0.7522105909090908, 0.806692, 0.9758467272727273], 
             UndirectedEdge[56, 342] -> 
             RGBColor[
              0.6392455454545455, 0.7165231818181819, 0.9657576363636363], 
             UndirectedEdge[378, 416] -> 
             RGBColor[0.8620621818181818, 0.892849, 0.9867054545454546], 
             UndirectedEdge[119, 363] -> 
             RGBColor[
              0.6392455454545455, 0.7165231818181819, 0.9657576363636363], 
             UndirectedEdge[391, 455] -> 
             RGBColor[
              0.7712101818181818, 0.6798094090909093, 0.6016545454545454], 
             UndirectedEdge[249, 282] -> 
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454], 
             UndirectedEdge[226, 429] -> 
             RGBColor[
              0.9790915909090909, 0.9834246363636363, 0.8977742727272727], 
             UndirectedEdge[181, 189] -> 
             RGBColor[
              0.927663909090909, 0.9421660909090909, 0.8739874090909092], 
             UndirectedEdge[160, 167] -> 
             RGBColor[
              0.8625523636363637, 0.8800929090909091, 0.6871057272727272], 
             UndirectedEdge[16, 277] -> 
             RGBColor[
              0.7676591363636363, 0.818409818181818, 0.9698667727272727], 
             UndirectedEdge[295, 341] -> 
             RGBColor[
              0.9246393636363636, 0.9409153636363636, 0.9241119545454546], 
             UndirectedEdge[69, 129] -> 
             RGBColor[
              0.6575772727272726, 0.7223544545454545, 0.8515004090909092], 
             UndirectedEdge[352, 368] -> 
             RGBColor[
              0.9739911818181818, 0.9791182727272727, 0.8839055454545454], 
             UndirectedEdge[194, 297] -> 
             RGBColor[
              0.9601044090909091, 0.9674768181818182, 0.8465403636363638], 
             UndirectedEdge[188, 228] -> 
             RGBColor[
              0.9173794545454546, 0.6490804545454545, 0.44301672727272745`], 
             UndirectedEdge[273, 430] -> 
             RGBColor[
              0.9756274090909092, 0.9782692727272728, 0.7458924090909093], 
             UndirectedEdge[200, 468] -> 
             RGBColor[0.7359405454545453, 0.791349, 0.9322274090909091], 
             UndirectedEdge[93, 172] -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             UndirectedEdge[61, 341] -> 
             RGBColor[
              0.9790915909090909, 0.9834246363636363, 0.8977742727272727], 
             UndirectedEdge[121, 442] -> 
             RGBColor[
              0.6244410454545455, 0.534857590909091, 0.5860685909090909], 
             UndirectedEdge[287, 336] -> 
             RGBColor[
              0.9896106818181818, 0.9897538181818182, 0.8059990454545456], 
             UndirectedEdge[403, 497] -> 
             RGBColor[0.8283653181818182, 0.827555, 0.6459776363636365], 
             UndirectedEdge[17, 407] -> 
             RGBColor[
              0.8564339999999999, 0.8886222727272728, 0.9860993636363635], 
             UndirectedEdge[135, 470] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[322, 471] -> 
             RGBColor[
              0.8390093636363636, 0.8736804545454545, 0.9156674090909092], 
             UndirectedEdge[24, 52] -> 
             RGBColor[
              0.9724789090909091, 0.9784929090909091, 0.9089678181818182], 
             UndirectedEdge[163, 440] -> 
             RGBColor[0.7359405454545453, 0.791349, 0.9322274090909091], 
             UndirectedEdge[274, 432] -> 
             RGBColor[
              0.9505366818181819, 0.9367618181818183, 0.6767892272727272], 
             UndirectedEdge[89, 261] -> 
             RGBColor[
              0.8982160000000001, 0.8822079090909092, 0.6529171363636366], 
             UndirectedEdge[255, 312] -> 
             RGBColor[
              0.8333480454545454, 0.844362909090909, 0.6653345909090909], 
             UndirectedEdge[370, 422] -> 
             RGBColor[
              0.8006537727272727, 0.8445361818181818, 0.9806750909090909], 
             UndirectedEdge[43, 90] -> 
             RGBColor[0.8620621818181818, 0.892849, 0.9867054545454546], 
             UndirectedEdge[373, 449] -> 
             RGBColor[
              0.938906409090909, 0.9528719999999999, 0.9506792727272727], 
             UndirectedEdge[49, 457] -> 
             RGBColor[
              0.7617188636363637, 0.8122770000000001, 0.9342567727272727], 
             UndirectedEdge[234, 449] -> 
             RGBColor[
              0.9247919090909091, 0.8905639999999999, 0.6365702727272726], 
             UndirectedEdge[245, 299] -> 
             RGBColor[
              0.9751172272727273, 0.9266352727272726, 0.45064318181818164`], 
             UndirectedEdge[398, 464] -> 
             RGBColor[0.7484935, 0.8024135454545456, 0.9566438636363637], 
             UndirectedEdge[245, 262] -> 
             RGBColor[
              0.9346694999999999, 0.7578741363636362, 0.41766349999999974`], 
             UndirectedEdge[288, 321] -> 
             RGBColor[
              0.9088600454545455, 0.9283333636363637, 0.9226069090909091], 
             UndirectedEdge[433, 465] -> 
             RGBColor[
              0.9850826818181818, 0.9602510909090909, 0.48935709090909063`], 
             UndirectedEdge[330, 367] -> 
             RGBColor[0.799161, 0.791825, 0.6242065], 
             UndirectedEdge[106, 156] -> 
             RGBColor[
              0.9032890454545454, 0.9254948181818181, 0.9827548636363637], 
             UndirectedEdge[85, 239] -> 
             RGBColor[
              0.8425368181818181, 0.8742673636363636, 0.7938388636363634], 
             UndirectedEdge[336, 388] -> 
             RGBColor[
              0.6727548181818181, 0.7375539545454545, 0.9279434090909091], 
             UndirectedEdge[69, 355] -> 
             RGBColor[
              0.7662556818181818, 0.814153090909091, 0.8590699545454545], 
             UndirectedEdge[102, 383] -> 
             RGBColor[
              0.8941224090909091, 0.9178445454545454, 0.9700562727272728], 
             UndirectedEdge[296, 327] -> 
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273], 
             UndirectedEdge[61, 288] -> 
             RGBColor[
              0.900735090909091, 0.9227762727272728, 0.9588627272727273], 
             UndirectedEdge[141, 472] -> 
             RGBColor[
              0.9927556363636364, 0.9869133636363637, 0.4528739090909087], 
             UndirectedEdge[43, 485] -> 
             RGBColor[
              0.6156249545454546, 0.6946065454545455, 0.9652257727272727], 
             UndirectedEdge[9, 358] -> 
             RGBColor[
              0.8421578636363636, 0.8734568181818182, 0.7525920000000001], 
             UndirectedEdge[70, 359] -> 
             RGBColor[
              0.7161024999999999, 0.7765538181818181, 0.9658080454545455], 
             UndirectedEdge[466, 470] -> 
             RGBColor[
              0.9697726363636363, 0.9749586363636363, 0.839579681818182], 
             UndirectedEdge[41, 356] -> 
             RGBColor[
              0.8322124090909091, 0.8697001818181818, 0.9836851818181818], 
             UndirectedEdge[79, 436] -> 
             RGBColor[
              0.9754961818181818, 0.9274458181818181, 0.4918900454545456], 
             UndirectedEdge[33, 175] -> 
             RGBColor[
              0.6792438181818181, 0.744766090909091, 0.9515866818181817], 
             UndirectedEdge[176, 448] -> 
             RGBColor[
              0.9592225454545454, 0.967330090909091, 0.8769975000000001], 
             UndirectedEdge[118, 481] -> 
             RGBColor[0.956198, 0.9660793636363636, 0.9271220454545455], 
             UndirectedEdge[326, 346] -> 
             RGBColor[
              0.6892454545454544, 0.7563732727272726, 0.9702011818181817], 
             UndirectedEdge[63, 435] -> 
             RGBColor[
              0.8551059999999999, 0.8870454545454545, 0.954337409090909], 
             UndirectedEdge[194, 350] -> 
             RGBColor[
              0.9592225454545454, 0.967330090909091, 0.8769975000000001], 
             UndirectedEdge[275, 486] -> 
             RGBColor[
              0.9480730454545454, 0.9605222727272728, 0.9633778636363636], 
             UndirectedEdge[407, 478] -> 
             RGBColor[
              0.8904770909090909, 0.9127753636363636, 0.8703712272727273], 
             UndirectedEdge[62, 356] -> 
             RGBColor[0.8079908181818182, 0.850778090909091, 0.981271], 
             UndirectedEdge[150, 426] -> 
             RGBColor[
              0.8671373636363636, 0.8939999999999999, 0.8374999090909092], 
             UndirectedEdge[372, 444] -> 
             RGBColor[
              0.8768518636363636, 0.5817163181818181, 0.583836909090909], 
             UndirectedEdge[106, 329] -> 
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273], 
             UndirectedEdge[128, 294] -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             UndirectedEdge[379, 440] -> 
             RGBColor[
              0.6906549545454544, 0.7564899999999999, 0.9712636818181818], 
             UndirectedEdge[227, 267] -> 
             RGBColor[
              0.9296297727272727, 0.7566618636363636, 0.5645543181818181], 
             UndirectedEdge[151, 345] -> 
             RGBColor[
              0.960204909090909, 0.9442436363636364, 0.6698285454545454], 
             UndirectedEdge[275, 418] -> 
             RGBColor[
              0.8308844090909091, 0.8681233636363637, 0.9519232272727272], 
             UndirectedEdge[10, 232] -> 
             RGBColor[
              0.9900654090909091, 0.9770589999999999, 0.5087140454545451], 
             UndirectedEdge[5, 431] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[42, 416] -> 
             RGBColor[0.8620621818181818, 0.892849, 0.9867054545454546], 
             UndirectedEdge[37, 97] -> 
             RGBColor[
              0.6774155909090909, 0.7379556818181818, 0.7398057272727274], 
             UndirectedEdge[441, 450] -> 
             RGBColor[
              0.7808844999999999, 0.8282732727272726, 0.9474796818181818], 
             UndirectedEdge[5, 259] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[279, 318] -> 
             RGBColor[
              0.513467409090909, 0.6158950000000001, 0.9548411818181818], 
             UndirectedEdge[275, 355] -> 
             RGBColor[
              0.7551061818181819, 0.8073452727272727, 0.9454503181818181], 
             UndirectedEdge[344, 387] -> 
             RGBColor[
              0.6792438181818181, 0.744766090909091, 0.9515866818181817], 
             UndirectedEdge[239, 489] -> 
             RGBColor[0.990744, 0.9895686363636363, 0.7396899090909089], 
             UndirectedEdge[21, 336] -> 
             RGBColor[
              0.8859402727272727, 0.9108992727272727, 0.9455580454545454], 
             UndirectedEdge[32, 312] -> 
             RGBColor[
              0.8390093636363636, 0.8736804545454545, 0.9156674090909092], 
             UndirectedEdge[77, 436] -> 
             RGBColor[0.9700774999999999, 0.925423, 0.597534], 
             UndirectedEdge[66, 294] -> 
             RGBColor[
              0.8178123181818182, 0.8560090909090909, 0.8631286818181818], 
             UndirectedEdge[197, 201] -> 
             RGBColor[
              0.7413592272727272, 0.7933718181818181, 0.8265834545454547], 
             UndirectedEdge[228, 256] -> 
             RGBColor[
              0.8351165454545455, 0.5870346363636363, 0.5846868636363637], 
             UndirectedEdge[292, 481] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[444, 486] -> 
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363], 
             UndirectedEdge[154, 244] -> 
             RGBColor[
              0.6939814545454546, 0.7552549090909091, 0.9041373181818182], 
             UndirectedEdge[288, 386] -> 
             RGBColor[0.9073477727272727, 0.927708, 0.9476691818181818], 
             UndirectedEdge[273, 285] -> 
             RGBColor[0.8906010454545454, 0.911301, 0.7574203636363638], 
             UndirectedEdge[190, 487] -> 
             RGBColor[0.696751, 0.7542207272727273, 0.6998150454545452], 
             UndirectedEdge[83, 343] -> 
             RGBColor[
              0.8462828636363636, 0.8802669999999999, 0.9852004090909091], 
             UndirectedEdge[1, 315] -> 
             RGBColor[
              0.9739911818181818, 0.9791182727272727, 0.8839055454545454], 
             UndirectedEdge[4, 429] -> 
             RGBColor[
              0.9821161363636364, 0.9846753636363637, 0.8476497272727272], 
             UndirectedEdge[189, 451] -> 
             RGBColor[
              0.6748756363636362, 0.7439079999999999, 0.9697586363636364], 
             UndirectedEdge[10, 102] -> 
             RGBColor[0.9123875, 0.9289202727272727, 0.8007783636363635], 
             UndirectedEdge[357, 368] -> 
             RGBColor[
              0.9256810454545454, 0.9430085454545454, 0.9730663636363637], 
             UndirectedEdge[128, 138] -> 
             RGBColor[
              0.842033909090909, 0.8749311818181817, 0.8655428636363637], 
             UndirectedEdge[336, 436] -> 
             RGBColor[0.9700774999999999, 0.925423, 0.597534], 
             UndirectedEdge[196, 454] -> 
             RGBColor[
              0.6408022727272726, 0.7185290909090908, 0.9653728181818182], 
             UndirectedEdge[25, 164] -> 
             RGBColor[
              0.7422115909090907, 0.7983459999999999, 0.9753224090909091], 
             UndirectedEdge[125, 282] -> 
             RGBColor[
              0.9434432272727272, 0.9547480909090909, 0.8754924545454545], 
             UndirectedEdge[9, 286] -> 
             RGBColor[
              0.842033909090909, 0.8749311818181817, 0.8655428636363637], 
             UndirectedEdge[421, 477] -> 
             RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 
             UndirectedEdge[105, 484] -> 
             RGBColor[
              0.9752484545454545, 0.9774587272727273, 0.7046455454545453], 
             UndirectedEdge[299, 475] -> 
             RGBColor[
              0.9634648181818182, 0.9204912727272727, 0.6087275454545453], 
             UndirectedEdge[247, 252] -> 
             RGBColor[
              0.6529167727272727, 0.7227587727272726, 0.9615240454545455], 
             UndirectedEdge[261, 478] -> 
             RGBColor[
              0.9795970454545455, 0.9441070000000001, 0.5417041363636366], 
             UndirectedEdge[104, 303] -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             UndirectedEdge[32, 66] -> 
             RGBColor[
              0.8147877727272728, 0.8547583636363636, 0.9132532272727273], 
             UndirectedEdge[213, 454] -> 
             RGBColor[0.7874971818181817, 0.833205, 0.9362861363636363], 
             UndirectedEdge[129, 331] -> 
             RGBColor[
              0.6577012272727272, 0.7208800909090909, 0.7385495454545457], 
             UndirectedEdge[245, 475] -> 
             RGBColor[
              0.9826190454545454, 0.9840115454545455, 0.775945727272727], 
             UndirectedEdge[90, 148] -> 
             RGBColor[
              0.8406546818181817, 0.8760402727272727, 0.9845943181818182], 
             UndirectedEdge[195, 496] -> 
             RGBColor[
              0.7227151818181817, 0.7814855454545454, 0.9546144999999999], 
             UndirectedEdge[241, 371] -> 
             RGBColor[
              0.5745030909090908, 0.6607222272727272, 0.9618584545454545], 
             UndirectedEdge[13, 243] -> 
             RGBColor[
              0.9097917272727272, 0.7418666818181816, 0.5981349545454546], 
             UndirectedEdge[246, 384] -> 
             RGBColor[
              0.9693936818181818, 0.9741480909090909, 0.798332818181818], 
             UndirectedEdge[22, 268] -> 
             RGBColor[
              0.7389650909090908, 0.7925997272727272, 0.8821028636363635], 
             UndirectedEdge[69, 306] -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909092], 
             UndirectedEdge[66, 128] -> 
             RGBColor[
              0.8178123181818182, 0.8560090909090909, 0.8631286818181818], 
             UndirectedEdge[220, 413] -> 
             RGBColor[0.3810319999999999, 0.5044525, 0.9455], 
             UndirectedEdge[319, 492] -> 
             RGBColor[
              0.7150237727272727, 0.7773012727272727, 0.9722305454545455], 
             UndirectedEdge[61, 186] -> 
             RGBColor[
              0.916514409090909, 0.9353582727272727, 0.9603677727272727], 
             UndirectedEdge[94, 401] -> 
             RGBColor[
              0.9434432272727272, 0.9547480909090909, 0.8754924545454545], 
             UndirectedEdge[429, 488] -> 
             RGBColor[
              0.6661421363636363, 0.7326222272727272, 0.9391369545454544], 
             UndirectedEdge[11, 431] -> 
             RGBColor[
              0.900735090909091, 0.9227762727272728, 0.9588627272727273], 
             UndirectedEdge[349, 487] -> 
             RGBColor[0.697006, 0.7565056363636364, 0.8540127727272728], 
             UndirectedEdge[156, 198] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[12, 188] -> 
             RGBColor[
              0.9926352272727272, 0.9910045454545455, 0.7558745000000001], 
             UndirectedEdge[70, 111] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[212, 286] -> 
             RGBColor[
              0.9755034545454545, 0.9797436363636364, 0.8588432727272728], 
             UndirectedEdge[242, 282] -> 
             RGBColor[0.7922115, 0.8381960909090909, 0.9797659545454545], 
             UndirectedEdge[70, 175] -> 
             RGBColor[
              0.6726311363636364, 0.7398343636363636, 0.9627802272727273], 
             UndirectedEdge[188, 298] -> 
             RGBColor[
              0.9285457727272727, 0.9423128181818181, 0.8435302727272729], 
             UndirectedEdge[286, 367] -> 
             RGBColor[
              0.9746143181818181, 0.9272990909090909, 0.5223471818181818], 
             UndirectedEdge[9, 492] -> 
             RGBColor[
              0.7150237727272727, 0.7773012727272727, 0.9722305454545455], 
             UndirectedEdge[37, 343] -> 
             RGBColor[
              0.9277878636363637, 0.9406917272727273, 0.7610365454545456], 
             UndirectedEdge[376, 391] -> 
             RGBColor[
              0.7954317727272727, 0.6987315000000001, 0.6040687272727273], 
             UndirectedEdge[230, 490] -> 
             RGBColor[
              0.8163000454545455, 0.8553837272727274, 0.8881909545454545], 
             UndirectedEdge[346, 355] -> 
             RGBColor[
              0.6634671363636364, 0.7354452727272728, 0.9681718181818182], 
             UndirectedEdge[30, 465] -> 
             RGBColor[
              0.9693936818181818, 0.9741480909090909, 0.798332818181818], 
             UndirectedEdge[119, 124] -> 
             RGBColor[
              0.6848746363636364, 0.7522540000000001, 0.9702829545454545], 
             UndirectedEdge[301, 436] -> 
             RGBColor[
              0.8718257727272727, 0.8485912727272726, 0.6314490454545454], 
             UndirectedEdge[39, 108] -> 
             RGBColor[
              0.9917533636363636, 0.9908578181818182, 0.7863316363636363], 
             UndirectedEdge[98, 382] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[81, 208] -> 
             RGBColor[0.982998, 0.9848220909090909, 0.8171925909090911], 
             UndirectedEdge[154, 203] -> 
             RGBColor[
              0.6726311363636364, 0.7398343636363636, 0.9627802272727273], 
             UndirectedEdge[145, 367] -> 
             RGBColor[
              0.9746143181818181, 0.9272990909090909, 0.5223471818181818], 
             UndirectedEdge[44, 132] -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             UndirectedEdge[319, 357] -> 
             RGBColor[0.7922115, 0.8381960909090909, 0.9797659545454545], 
             UndirectedEdge[364, 378] -> 
             RGBColor[
              0.9322937272727272, 0.9479402727272728, 0.9618728181818181], 
             UndirectedEdge[213, 251] -> 
             RGBColor[
              0.9888527727272727, 0.9881327272727274, 0.7235053181818183], 
             UndirectedEdge[73, 136] -> 
             RGBColor[
              0.9192322727272727, 0.6995969090909089, 0.2839453636363635], 
             UndirectedEdge[441, 461] -> 
             RGBColor[
              0.9790915909090909, 0.9834246363636363, 0.8977742727272727], 
             UndirectedEdge[90, 480] -> 
             RGBColor[
              0.9256810454545454, 0.9430085454545454, 0.9730663636363637], 
             UndirectedEdge[118, 446] -> 
             RGBColor[0.956198, 0.9660793636363636, 0.9271220454545455], 
             UndirectedEdge[210, 480] -> 
             RGBColor[0.7484935, 0.8024135454545456, 0.9566438636363637], 
             UndirectedEdge[95, 492] -> 
             RGBColor[
              0.8632309545454545, 0.8926025454545454, 0.9180815909090909], 
             UndirectedEdge[261, 328] -> 
             RGBColor[
              0.9793420454545455, 0.9418220909090911, 0.38750640909090905`], 
             UndirectedEdge[152, 496] -> 
             RGBColor[
              0.7409802727272726, 0.7925612727272726, 0.7853365909090907], 
             UndirectedEdge[86, 177] -> 
             RGBColor[0.8889648181818182, 0.91215, 0.8954334999999999], 
             UndirectedEdge[45, 217] -> 
             RGBColor[
              0.9277878636363637, 0.9406917272727273, 0.7610365454545456], 
             UndirectedEdge[306, 331] -> 
             RGBColor[
              0.9903650454545454, 0.988758090909091, 0.6984430454545456], 
             UndirectedEdge[103, 129] -> 
             RGBColor[
              0.6538741363636363, 0.7085940909090909, 0.6706490909090908], 
             UndirectedEdge[50, 126] -> 
             RGBColor[
              0.8484933181818182, 0.8821137272727273, 0.9655309545454545], 
             UndirectedEdge[172, 308] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[112, 266] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[129, 275] -> 
             RGBColor[
              0.6464277727272727, 0.7155466363636362, 0.9378807727272727], 
             UndirectedEdge[297, 325] -> 
             RGBColor[
              0.8429157727272727, 0.8750779090909091, 0.8350857272727275], 
             UndirectedEdge[202, 396] -> 
             RGBColor[
              0.8429157727272727, 0.8750779090909091, 0.8350857272727275], 
             UndirectedEdge[167, 236] -> 
             RGBColor[
              0.8647432272727272, 0.8932279090909091, 0.893019318181818], 
             UndirectedEdge[184, 301] -> 
             RGBColor[
              0.8564339999999999, 0.8886222727272728, 0.9860993636363635], 
             UndirectedEdge[78, 258] -> 
             RGBColor[
              0.8667584090909091, 0.8931894545454545, 0.7962530454545452], 
             UndirectedEdge[172, 470] -> 
             RGBColor[
              0.9511285909090909, 0.9630723636363636, 0.9676107272727272], 
             UndirectedEdge[72, 159] -> 
             RGBColor[
              0.9688907727272726, 0.9748119090909091, 0.8700368181818183], 
             UndirectedEdge[304, 337] -> 
             RGBColor[
              0.9755034545454545, 0.9797436363636364, 0.8588432727272728], 
             UndirectedEdge[88, 271] -> 
             RGBColor[
              0.9718003181818182, 0.9659832727272727, 0.6779919545454545], 
             UndirectedEdge[392, 413] -> 
             RGBColor[
              0.5502814999999999, 0.6418001363636363, 0.9594442727272727], 
             UndirectedEdge[187, 216] -> 
             RGBColor[
              0.9285457727272727, 0.9423128181818181, 0.8435302727272729], 
             UndirectedEdge[33, 432] -> 
             RGBColor[
              0.9668175909090909, 0.9491753636363636, 0.6586349999999999], 
             UndirectedEdge[36, 75] -> 
             RGBColor[
              0.9821161363636364, 0.9846753636363637, 0.8476497272727272], 
             UndirectedEdge[243, 335] -> 
             RGBColor[
              0.9190683636363636, 0.9380768181818182, 0.9842599090909091], 
             UndirectedEdge[323, 499] -> 
             RGBColor[0.7922115, 0.8381960909090909, 0.9797659545454545], 
             UndirectedEdge[168, 480] -> 
             RGBColor[
              0.9763853181818182, 0.9798903636363636, 0.8283861363636366], 
             UndirectedEdge[301, 388] -> 
             RGBColor[
              0.5745030909090908, 0.6607222272727272, 0.9618584545454545], 
             UndirectedEdge[111, 371] -> 
             RGBColor[
              0.8859402727272727, 0.9108992727272727, 0.9455580454545454], 
             UndirectedEdge[103, 231] -> 
             RGBColor[
              0.9127944545454545, 0.6351733636363635, 0.29262254545454536`], 
             UndirectedEdge[99, 131] -> 
             RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 
             UndirectedEdge[193, 428] -> 
             RGBColor[
              0.900735090909091, 0.9227762727272728, 0.9588627272727273], 
             UndirectedEdge[189, 370] -> 
             RGBColor[
              0.8006537727272727, 0.8445361818181818, 0.9806750909090909], 
             UndirectedEdge[45, 187] -> 
             RGBColor[
              0.9942714545454545, 0.9901555454545454, 0.617861363636364], 
             UndirectedEdge[346, 443] -> 
             RGBColor[
              0.872714909090909, 0.9010358181818181, 0.9679451363636363], 
             UndirectedEdge[19, 318] -> 
             RGBColor[
              0.6634671363636364, 0.7354452727272728, 0.9681718181818182], 
             UndirectedEdge[5, 129] -> 
             RGBColor[
              0.633202409090909, 0.7056831818181817, 0.9602678636363637], 
             UndirectedEdge[29, 46] -> 
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181], 
             UndirectedEdge[227, 263] -> 
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273], 
             UndirectedEdge[272, 435] -> 
             RGBColor[
              0.9790915909090909, 0.9834246363636363, 0.8977742727272727], 
             UndirectedEdge[208, 483] -> 
             RGBColor[
              0.8551059999999999, 0.8870454545454545, 0.954337409090909], 
             UndirectedEdge[244, 475] -> 
             RGBColor[
              0.9790915909090909, 0.9834246363636363, 0.8977742727272727], 
             UndirectedEdge[350, 412] -> 
             RGBColor[
              0.9688907727272726, 0.9748119090909091, 0.8700368181818183], 
             UndirectedEdge[217, 398] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[370, 451] -> 
             RGBColor[
              0.6134672272727272, 0.6955951818181818, 0.9637282727272727], 
             UndirectedEdge[265, 424] -> 
             RGBColor[
              0.9239607727272727, 0.9284057272727272, 0.6931360909090908], 
             UndirectedEdge[28, 419] -> 
             RGBColor[
              0.9806038636363636, 0.9840500000000001, 0.8727119999999999], 
             UndirectedEdge[67, 381] -> 
             RGBColor[
              0.8667584090909091, 0.8931894545454545, 0.7962530454545452], 
             UndirectedEdge[239, 435] -> 
             RGBColor[
              0.9826190454545454, 0.9840115454545455, 0.775945727272727], 
             UndirectedEdge[302, 370] -> 
             RGBColor[
              0.8134049090909091, 0.6892808181818183, 0.6012690454545455], 
             UndirectedEdge[2, 66] -> 
             RGBColor[
              0.8000501363636363, 0.8442695454545455, 0.9607025909090909], 
             UndirectedEdge[36, 408] -> 
             RGBColor[
              0.9821161363636364, 0.9846753636363637, 0.8476497272727272], 
             UndirectedEdge[76, 483] -> 
             RGBColor[
              0.7150237727272727, 0.7773012727272727, 0.9722305454545455], 
             UndirectedEdge[9, 367] -> 
             RGBColor[
              0.8233825909090908, 0.8107470909090908, 0.6266206818181818], 
             UndirectedEdge[133, 469] -> 
             RGBColor[
              0.9277878636363637, 0.9406917272727273, 0.7610365454545456], 
             UndirectedEdge[46, 297] -> 
             RGBColor[
              0.9896106818181818, 0.9897538181818182, 0.8059990454545456], 
             UndirectedEdge[159, 435] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[126, 340] -> 
             RGBColor[
              0.9256810454545454, 0.9430085454545454, 0.9730663636363637], 
             UndirectedEdge[27, 290] -> 
             RGBColor[0.8418806363636363, 0.8771819999999999, 0.9767245], 
             UndirectedEdge[326, 338] -> 
             RGBColor[
              0.7921579545454545, 0.8336067272727272, 0.7481484545454546], 
             UndirectedEdge[179, 438] -> 
             RGBColor[0.6595294545454544, 0.7276904999999999, 0.9503305], 
             UndirectedEdge[138, 339] -> 
             RGBColor[
              0.8176590454545454, 0.8582599090909091, 0.9743103181818182], 
             UndirectedEdge[475, 482] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[94, 428] -> 
             RGBColor[
              0.9322937272727272, 0.9479402727272728, 0.9618728181818181], 
             UndirectedEdge[186, 295] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             UndirectedEdge[348, 372] -> 
             RGBColor[0.9106399545454545, 0.6035845, 0.31391104545454523`], 
             UndirectedEdge[293, 343] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             UndirectedEdge[385, 446] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[7, 288] -> 
             RGBColor[
              0.9118845909090909, 0.9295840909090909, 0.8724823636363637], 
             UndirectedEdge[242, 323] -> 
             RGBColor[0.7922115, 0.8381960909090909, 0.9797659545454545], 
             UndirectedEdge[464, 481] -> 
             RGBColor[0.732212590909091, 0.79, 0.9747980909090909], 
             UndirectedEdge[42, 108] -> 
             RGBColor[
              0.9434432272727272, 0.9547480909090909, 0.8754924545454545], 
             UndirectedEdge[101, 276] -> 
             RGBColor[
              0.6346672727272727, 0.7023821363636364, 0.925596409090909], 
             UndirectedEdge[86, 426] -> 
             RGBColor[
              0.8647432272727272, 0.8932279090909091, 0.893019318181818], 
             UndirectedEdge[37, 324] -> 
             RGBColor[
              0.9935135454545455, 0.9885344545454546, 0.5353676363636367], 
             UndirectedEdge[290, 297] -> 
             RGBColor[
              0.8671373636363636, 0.8939999999999999, 0.8374999090909092], 
             UndirectedEdge[315, 380] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[181, 390] -> 
             RGBColor[0.9941475, 0.9916299090909091, 0.7308122272727275], 
             UndirectedEdge[283, 421] -> 
             RGBColor[
              0.5942174545454545, 0.6777978181818182, 0.9631146363636363], 
             UndirectedEdge[97, 355] -> 
             RGBColor[
              0.4502816818181818, 0.5620999545454546, 0.9505571818181817], 
             UndirectedEdge[192, 219] -> 
             RGBColor[
              0.9739911818181818, 0.9791182727272727, 0.8839055454545454], 
             UndirectedEdge[171, 192] -> 
             RGBColor[
              0.9887288181818181, 0.9896070909090909, 0.8364561818181817], 
             UndirectedEdge[122, 216] -> 
             RGBColor[0.7522105909090908, 0.806692, 0.9758467272727273], 
             UndirectedEdge[18, 28] -> 
             RGBColor[
              0.9806038636363636, 0.9840500000000001, 0.8727119999999999], 
             UndirectedEdge[178, 288] -> 
             RGBColor[
              0.9081814545454545, 0.9158237272727272, 0.6916310454545453], 
             UndirectedEdge[165, 185] -> 
             RGBColor[
              0.8322124090909091, 0.8697001818181818, 0.9836851818181818], 
             UndirectedEdge[264, 281] -> 
             RGBColor[
              0.8176590454545454, 0.8582599090909091, 0.9743103181818182], 
             UndirectedEdge[80, 192] -> 
             RGBColor[
              0.6954937272727273, 0.7558802727272728, 0.8790750454545453], 
             UndirectedEdge[74, 402] -> 
             RGBColor[
              0.9032890454545454, 0.9254948181818181, 0.9827548636363637], 
             UndirectedEdge[3, 158] -> 
             RGBColor[
              0.9347573636363636, 0.9241798181818182, 0.6752841818181817], 
             UndirectedEdge[426, 476] -> 
             RGBColor[
              0.8617186818181818, 0.8919771818181819, 0.9431438636363636], 
             UndirectedEdge[27, 177] -> 
             RGBColor[
              0.8661022272727272, 0.8961040909090909, 0.9791386818181818], 
             UndirectedEdge[355, 443] -> 
             RGBColor[0.7484935, 0.8024135454545456, 0.9566438636363637], 
             UndirectedEdge[21, 256] -> 
             RGBColor[
              0.8090960454545455, 0.8508762727272727, 0.9815842272727273], 
             UndirectedEdge[331, 404] -> 
             RGBColor[
              0.9166215454545454, 0.6474593636363636, 0.36052300000000015`], 
             UndirectedEdge[142, 285] -> 
             RGBColor[
              0.872714909090909, 0.9010358181818181, 0.9679451363636363], 
             UndirectedEdge[232, 267] -> 
             RGBColor[
              0.9304634545454544, 0.7447775909090908, 0.3085161818181817], 
             UndirectedEdge[133, 488] -> 
             RGBColor[
              0.6774155909090909, 0.7379556818181818, 0.7398057272727274], 
             UndirectedEdge[148, 393] -> 
             RGBColor[
              0.8913589545454546, 0.9129220909090909, 0.8399140909090911], 
             UndirectedEdge[84, 89] -> 
             RGBColor[
              0.8875097272727273, 0.9129128181818182, 0.9812498181818182], 
             UndirectedEdge[27, 350] -> 
             RGBColor[
              0.9688907727272726, 0.9748119090909091, 0.8700368181818183], 
             UndirectedEdge[8, 435] -> 
             RGBColor[
              0.5749468181818183, 0.6416307727272728, 0.9337655454545455], 
             UndirectedEdge[20, 220] -> 
             RGBColor[
              0.5215526818181818, 0.6210315454545454, 0.9558720909090909], 
             UndirectedEdge[35, 422] -> 
             RGBColor[
              0.6314042727272726, 0.7071885454545455, 0.9667308181818182], 
             UndirectedEdge[65, 177] -> 
             RGBColor[
              0.8913589545454546, 0.9129220909090909, 0.8399140909090911], 
             UndirectedEdge[93, 160] -> 
             RGBColor[
              0.9850256818181817, 0.9758467272727273, 0.6556048636363635], 
             UndirectedEdge[277, 373] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[15, 126] -> 
             RGBColor[
              0.8484933181818182, 0.8821137272727273, 0.9655309545454545], 
             UndirectedEdge[95, 367] -> 
             RGBColor[
              0.9715897727272726, 0.9260483636363637, 0.5724717272727273], 
             UndirectedEdge[304, 465] -> 
             RGBColor[
              0.9760063636363636, 0.9790798181818181, 0.7871392727272726], 
             UndirectedEdge[218, 305] -> 
             RGBColor[
              0.9896106818181818, 0.9897538181818182, 0.8059990454545456], 
             UndirectedEdge[137, 265] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[325, 392] -> 
             RGBColor[
              0.7150237727272727, 0.7773012727272727, 0.9722305454545455], 
             UndirectedEdge[263, 393] -> 
             RGBColor[
              0.9285457727272727, 0.9423128181818181, 0.8435302727272729], 
             UndirectedEdge[228, 335] -> 
             RGBColor[
              0.8666751818181817, 0.6121986363636363, 0.5876969545454546], 
             UndirectedEdge[104, 408] -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             UndirectedEdge[145, 375] -> 
             RGBColor[
              0.9221002272727272, 0.6919980454545457, 0.47883895454545466`], 
             UndirectedEdge[181, 451] -> 
             RGBColor[
              0.7404773636363635, 0.7932250909090909, 0.857040590909091], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.6727548181818181, 0.7375539545454546, 0.9279434090909091], 
             UndirectedEdge[387, 439] -> 
             RGBColor[
              0.5699958636363636, 0.6588757272727273, 0.9607004545454545], 
             UndirectedEdge[163, 231] -> 
             RGBColor[
              0.9119607727272727, 0.6470576363636362, 0.5486606818181818], 
             UndirectedEdge[143, 288] -> 
             RGBColor[0.9073477727272727, 0.927708, 0.9476691818181818], 
             UndirectedEdge[128, 312] -> 
             RGBColor[
              0.842033909090909, 0.8749311818181817, 0.8655428636363637], 
             UndirectedEdge[270, 479] -> 
             RGBColor[
              0.7364312727272728, 0.7941100000000001, 0.9743416818181818], 
             UndirectedEdge[119, 120] -> 
             RGBColor[0.7632311363636364, 0.8129023636363637, 0.9091945], 
             UndirectedEdge[105, 462] -> 
             RGBColor[0.7484935, 0.8024135454545456, 0.9566438636363637], 
             UndirectedEdge[14, 159] -> 
             RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 
             UndirectedEdge[58, 417] -> 
             RGBColor[
              0.6923454999999998, 0.7569099545454544, 0.964036409090909], 
             UndirectedEdge[66, 299] -> 
             RGBColor[0.799161, 0.791825, 0.6242065], UndirectedEdge[11, 348] -> 
             RGBColor[
              0.911629590909091, 0.9272991818181819, 0.7182846363636362], 
             UndirectedEdge[4, 31] -> 
             RGBColor[
              0.603798909090909, 0.6670451363636364, 0.8483933181818182], 
             UndirectedEdge[259, 400] -> 
             RGBColor[
              0.9850256818181817, 0.9758467272727273, 0.6556048636363635], 
             UndirectedEdge[247, 451] -> 
             RGBColor[
              0.42450336363636354`, 0.5411719545454544, 0.9485278181818182], 
             UndirectedEdge[17, 261] -> 
             RGBColor[
              0.9455539545454545, 0.9199539090909092, 0.6574322727272728], 
             UndirectedEdge[361, 386] -> 
             RGBColor[
              0.9775793181818182, 0.9827992727272727, 0.9228365454545454], 
             UndirectedEdge[212, 492] -> 
             RGBColor[
              0.8484933181818182, 0.8821137272727273, 0.9655309545454545], 
             UndirectedEdge[287, 388] -> 
             RGBColor[0.6781735, 0.7395767727272726, 0.8222994545454547], 
             UndirectedEdge[383, 480] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[403, 440] -> 
             RGBColor[
              0.5892456363636362, 0.6766730909090908, 0.9613140909090909], 
             UndirectedEdge[13, 354] -> 
             RGBColor[
              0.9097917272727272, 0.7418666818181816, 0.5981349545454546], 
             UndirectedEdge[1, 42] -> 
             RGBColor[
              0.9419309545454545, 0.9541227272727273, 0.9005547272727272], 
             UndirectedEdge[161, 188] -> 
             RGBColor[
              0.9854616363636364, 0.9610616363636364, 0.5306039545454546], 
             UndirectedEdge[194, 426] -> 
             RGBColor[
              0.8322124090909091, 0.8697001818181818, 0.9836851818181818], 
             UndirectedEdge[257, 324] -> 
             RGBColor[
              0.9797210000000001, 0.9426326363636366, 0.42875327272727304`], 
             UndirectedEdge[198, 479] -> 
             RGBColor[
              0.900735090909091, 0.9227762727272728, 0.9588627272727273], 
             UndirectedEdge[372, 431] -> 
             RGBColor[
              0.8997454545454545, 0.5990615909090908, 0.5544891363636363], 
             UndirectedEdge[107, 466] -> 
             RGBColor[
              0.7929158636363636, 0.835227818181818, 0.830642181818182], 
             UndirectedEdge[122, 330] -> 
             RGBColor[0.642359, 0.720535, 0.964988], UndirectedEdge[4, 472] -> 
             RGBColor[
              0.9930106363636364, 0.9891982727272728, 0.6070716363636363], 
             UndirectedEdge[145, 458] -> 
             RGBColor[
              0.842033909090909, 0.8749311818181817, 0.8655428636363637], 
             UndirectedEdge[3, 451] -> 
             RGBColor[
              0.7317914999999999, 0.7626568181818181, 0.6568323181818181], 
             UndirectedEdge[146, 239] -> 
             RGBColor[0.990744, 0.9895686363636363, 0.7396899090909089], 
             UndirectedEdge[15, 282] -> 
             RGBColor[
              0.8164330909090909, 0.8571181818181818, 0.9821801363636363], 
             UndirectedEdge[82, 126] -> 
             RGBColor[0.6595294545454544, 0.7276904999999999, 0.9503305], 
             UndirectedEdge[413, 474] -> 
             RGBColor[
              0.6116899090909089, 0.6901129545454544, 0.9654746363636364], 
             UndirectedEdge[160, 235] -> 
             RGBColor[0.9893075, 0.9754379090909091, 0.4262203181818179], 
             UndirectedEdge[161, 183] -> 
             RGBColor[
              0.5774104545454546, 0.6178703181818181, 0.647176909090909], 
             UndirectedEdge[366, 429] -> 
             RGBColor[
              0.8793275909090909, 0.9059675454545455, 0.9567515909090909], 
             UndirectedEdge[7, 313] -> 
             RGBColor[
              0.842033909090909, 0.8749311818181817, 0.8655428636363637], 
             UndirectedEdge[129, 444] -> 
             RGBColor[
              0.6235341818181819, 0.6982013636363635, 0.9672285454545455], 
             UndirectedEdge[18, 493] -> 
             RGBColor[
              0.9577102727272727, 0.9667047272727274, 0.9020597727272726], 
             UndirectedEdge[149, 411] -> 
             RGBColor[
              0.8817912272727273, 0.8822070909090909, 0.6701629545454544], 
             UndirectedEdge[221, 301] -> 
             RGBColor[
              0.8661022272727272, 0.8961040909090909, 0.9791386818181818], 
             UndirectedEdge[45, 496] -> 
             RGBColor[
              0.7406013181818182, 0.7917507272727273, 0.7440897272727274], 
             UndirectedEdge[478, 482] -> 
             RGBColor[
              0.9755034545454545, 0.9797436363636364, 0.8588432727272728], 
             UndirectedEdge[69, 331] -> 
             RGBColor[
              0.9933895909090908, 0.9900088181818183, 0.6483185000000002], 
             UndirectedEdge[16, 143] -> 
             RGBColor[0.7874971818181817, 0.833205, 0.9362861363636363], 
             UndirectedEdge[210, 280] -> 
             RGBColor[
              0.513467409090909, 0.6158950000000001, 0.9548411818181818], 
             UndirectedEdge[101, 390] -> 
             RGBColor[
              0.9896106818181818, 0.9897538181818182, 0.8059990454545456], 
             UndirectedEdge[400, 418] -> 
             RGBColor[
              0.8383307727272726, 0.8611708181818181, 0.6846915454545452], 
             UndirectedEdge[84, 299] -> 
             RGBColor[
              0.9502394545454544, 0.9106278181818181, 0.6311146363636364], 
             UndirectedEdge[333, 386] -> 
             RGBColor[
              0.8617186818181818, 0.8919771818181819, 0.9431438636363636], 
             UndirectedEdge[244, 341] -> 
             RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454546], 
             UndirectedEdge[143, 373] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[160, 284] -> 
             RGBColor[
              0.9239607727272727, 0.9284057272727272, 0.6931360909090909], 
             UndirectedEdge[281, 343] -> 
             RGBColor[
              0.9032890454545454, 0.9254948181818181, 0.9827548636363637], 
             UndirectedEdge[207, 445] -> 
             RGBColor[
              0.6924691818181818, 0.7546295454545455, 0.9291995909090909], 
             UndirectedEdge[260, 334] -> 
             RGBColor[
              0.9414603636363637, 0.9555905454545455, 0.974571409090909], 
             UndirectedEdge[66, 114] -> 
             RGBColor[0.8132755, 0.854133, 0.9383155], 
             UndirectedEdge[364, 381] -> 
             RGBColor[
              0.9826190454545454, 0.9840115454545455, 0.775945727272727], 
             UndirectedEdge[204, 306] -> 
             RGBColor[
              0.9088600454545455, 0.9283333636363637, 0.9226069090909091], 
             UndirectedEdge[358, 361] -> 
             RGBColor[0.9822400909090909, 0.983201, 0.7346988636363638], 
             UndirectedEdge[294, 415] -> 
             RGBColor[
              0.9755034545454545, 0.9797436363636364, 0.8588432727272728], 
             UndirectedEdge[2, 255] -> 
             RGBColor[
              0.9668175909090909, 0.9491753636363636, 0.6586349999999999], 
             UndirectedEdge[326, 443] -> 
             RGBColor[
              0.774271818181818, 0.8233415454545454, 0.9586732272727272], 
             UndirectedEdge[58, 145] -> 
             RGBColor[
              0.7167203636363635, 0.7735812272727272, 0.8552689545454546], 
             UndirectedEdge[103, 346] -> 
             RGBColor[
              0.8867739545454545, 0.8990149999999999, 0.689519909090909], 
             UndirectedEdge[62, 108] -> 
             RGBColor[
              0.842033909090909, 0.8749311818181817, 0.8655428636363637], 
             UndirectedEdge[91, 336] -> 
             RGBColor[0.7874971818181817, 0.833205, 0.9362861363636363], 
             UndirectedEdge[338, 395] -> 
             RGBColor[
              0.5862202727272727, 0.6469642272727273, 0.7344343181818184], 
             UndirectedEdge[19, 335] -> 
             RGBColor[
              0.8406546818181817, 0.8760402727272727, 0.9845943181818182], 
             UndirectedEdge[2, 195] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.9434432272727272, 0.9547480909090909, 0.8754924545454545], 
             UndirectedEdge[150, 325] -> 
             RGBColor[
              0.8429157727272727, 0.8750779090909091, 0.8350857272727275], 
             UndirectedEdge[208, 238] -> 
             RGBColor[0.982998, 0.9848220909090909, 0.8171925909090911], 
             UndirectedEdge[318, 335] -> 
             RGBColor[0.7164332727272728, 0.777418, 0.9732930454545454], 
             UndirectedEdge[12, 421] -> 
             RGBColor[0.8889648181818182, 0.91215, 0.8954334999999999], 
             UndirectedEdge[102, 278] -> 
             RGBColor[
              0.900735090909091, 0.9227762727272728, 0.9588627272727273], 
             UndirectedEdge[5, 209] -> 
             RGBColor[
              0.8875097272727273, 0.9129128181818182, 0.9812498181818182], 
             UndirectedEdge[76, 463] -> 
             RGBColor[
              0.8176590454545454, 0.8582599090909091, 0.9743103181818182], 
             UndirectedEdge[293, 445] -> 
             RGBColor[
              0.6314042727272726, 0.7071885454545455, 0.9667308181818182], 
             UndirectedEdge[48, 250] -> 
             RGBColor[
              0.7808844999999999, 0.8282732727272726, 0.9474796818181818], 
             UndirectedEdge[459, 477] -> 
             RGBColor[
              0.8429157727272727, 0.8750779090909091, 0.8350857272727275], 
             UndirectedEdge[400, 404] -> 
             RGBColor[
              0.9127944545454545, 0.6351733636363635, 0.29262254545454536`], 
             UndirectedEdge[144, 246] -> 
             RGBColor[
              0.9597254545454545, 0.9666662727272728, 0.8052934999999998], 
             UndirectedEdge[90, 393] -> 
             RGBColor[
              0.9443250909090909, 0.9548948181818182, 0.8450353181818184], 
             UndirectedEdge[157, 360] -> 
             RGBColor[
              0.8484933181818182, 0.8821137272727273, 0.9655309545454545], 
             UndirectedEdge[156, 250] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[25, 220] -> 
             RGBColor[
              0.6471835909090908, 0.7197705454545454, 0.9682358636363636], 
             UndirectedEdge[261, 407] -> 
             RGBColor[0.8768085, 0.8653991818181819, 0.6508060000000001], 
             UndirectedEdge[42, 364] -> 
             RGBColor[
              0.9322937272727272, 0.9479402727272728, 0.9618728181818181], 
             UndirectedEdge[83, 257] -> 
             RGBColor[
              0.8982160000000001, 0.8822079090909092, 0.6529171363636366], 
             UndirectedEdge[137, 263] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[27, 65] -> 
             RGBColor[
              0.9697726363636363, 0.9749586363636363, 0.839579681818182], 
             UndirectedEdge[318, 421] -> 
             RGBColor[
              0.6634671363636364, 0.7354452727272728, 0.9681718181818182], 
             UndirectedEdge[203, 341] -> 
             RGBColor[
              0.9658662272727272, 0.9735611818181817, 0.9201613636363637], 
             UndirectedEdge[80, 483] -> 
             RGBColor[
              0.5699958636363636, 0.6588757272727273, 0.9607004545454545], 
             UndirectedEdge[95, 319] -> 
             RGBColor[
              0.8390093636363636, 0.8736804545454545, 0.9156674090909092], 
             UndirectedEdge[84, 376] -> 
             RGBColor[
              0.8176590454545454, 0.8582599090909091, 0.9743103181818182], 
             UndirectedEdge[260, 446] -> 
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363], 
             UndirectedEdge[174, 393] -> 
             RGBColor[
              0.9896106818181818, 0.9897538181818182, 0.8059990454545456], 
             UndirectedEdge[185, 216] -> 
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454], 
             UndirectedEdge[143, 321] -> 
             RGBColor[
              0.9857042727272727, 0.9883563636363637, 0.8865807272727273], 
             UndirectedEdge[296, 415] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[42, 113] -> 
             RGBColor[
              0.9256810454545454, 0.9430085454545454, 0.9730663636363637], 
             UndirectedEdge[54, 264] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[9, 95] -> 
             RGBColor[
              0.8390093636363636, 0.8736804545454545, 0.9156674090909092], 
             UndirectedEdge[47, 55] -> 
             RGBColor[
              0.8793275909090909, 0.9059675454545455, 0.9567515909090909], 
             UndirectedEdge[212, 330] -> 
             RGBColor[
              0.8000501363636363, 0.8442695454545455, 0.9607025909090909], 
             UndirectedEdge[89, 244] -> 
             RGBColor[
              0.9088600454545455, 0.9283333636363637, 0.9226069090909091], 
             UndirectedEdge[3, 247] -> 
             RGBColor[
              0.6686057727272727, 0.7088617727272727, 0.6525483181818181], 
             UndirectedEdge[26, 318] -> 
             RGBColor[
              0.7647434090909091, 0.8135277272727274, 0.8841322272727272], 
             UndirectedEdge[46, 426] -> 
             RGBColor[
              0.8617186818181818, 0.8919771818181819, 0.9431438636363636], 
             UndirectedEdge[102, 247] -> 
             RGBColor[
              0.5959105909090909, 0.6775309545454545, 0.9639695909090908], 
             UndirectedEdge[285, 287] -> 
             RGBColor[
              0.8913589545454546, 0.9129220909090909, 0.8399140909090911], 
             UndirectedEdge[346, 390] -> 
             RGBColor[
              0.8913589545454546, 0.9129220909090909, 0.8399140909090911], 
             UndirectedEdge[388, 473] -> 
             RGBColor[
              0.6772916363636363, 0.7394300454545455, 0.852756590909091], 
             UndirectedEdge[377, 412] -> 
             RGBColor[
              0.9097917272727272, 0.7418666818181816, 0.5981349545454546], 
             UndirectedEdge[7, 321] -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909092], 
             UndirectedEdge[209, 275] -> 
             RGBColor[
              0.900735090909091, 0.9227762727272728, 0.9588627272727273], 
             UndirectedEdge[204, 346] -> 
             RGBColor[
              0.8090960454545455, 0.8508762727272727, 0.9815842272727273], 
             UndirectedEdge[220, 297] -> 
             RGBColor[
              0.6978878636363637, 0.7566523636363636, 0.8235556363636365], 
             UndirectedEdge[16, 185] -> 
             RGBColor[
              0.7579909090909089, 0.8109279999999999, 0.9768274545454545], 
             UndirectedEdge[323, 449] -> 
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454], 
             UndirectedEdge[224, 481] -> 
             RGBColor[0.8079908181818182, 0.850778090909091, 0.981271], 
             UndirectedEdge[86, 476] -> 
             RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454544], 
             UndirectedEdge[66, 385] -> 
             RGBColor[
              0.7364312727272728, 0.7941100000000001, 0.9743416818181818], 
             UndirectedEdge[184, 316] -> 
             RGBColor[0.7064342727272727, 0.769072, 0.9727687272727272], 
             UndirectedEdge[308, 362] -> 
             RGBColor[
              0.7150237727272727, 0.7773012727272727, 0.9722305454545455], 
             UndirectedEdge[216, 361] -> 
             RGBColor[
              0.916514409090909, 0.9353582727272727, 0.9603677727272727], 
             UndirectedEdge[123, 410] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             UndirectedEdge[174, 225] -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             UndirectedEdge[3, 139] -> 
             RGBColor[0.9830675, 0.9602895454545455, 0.5861233636363634], 
             UndirectedEdge[226, 472] -> 
             RGBColor[
              0.989986090909091, 0.9879475454545454, 0.6571961818181816], 
             UndirectedEdge[9, 441] -> 
             RGBColor[
              0.8308844090909091, 0.8681233636363637, 0.9519232272727272], 
             UndirectedEdge[253, 354] -> 
             RGBColor[
              0.9658662272727272, 0.9735611818181817, 0.9201613636363637], 
             UndirectedEdge[47, 73] -> 
             RGBColor[
              0.8817912272727273, 0.8822070909090909, 0.6701629545454544], 
             UndirectedEdge[305, 432] -> 
             RGBColor[
              0.9854616363636364, 0.9610616363636364, 0.5306039545454546], 
             UndirectedEdge[4, 226] -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909092], 
             UndirectedEdge[112, 359] -> 
             RGBColor[
              0.5892456363636362, 0.6766730909090908, 0.9613140909090909], 
             UndirectedEdge[101, 204] -> 
             RGBColor[0.9073477727272727, 0.927708, 0.9476691818181818], 
             UndirectedEdge[256, 409] -> 
             RGBColor[
              0.6156249545454546, 0.6946065454545455, 0.9652257727272727], 
             UndirectedEdge[64, 268] -> 
             RGBColor[
              0.9261516363636363, 0.9415407272727272, 0.8990496818181817], 
             UndirectedEdge[97, 395] -> 
             RGBColor[
              0.2701223181818181, 0.3963854545454545, 0.9388724090909091], 
             UndirectedEdge[117, 156] -> 
             RGBColor[
              0.6726311363636364, 0.7398343636363636, 0.9627802272727273], 
             UndirectedEdge[48, 117] -> 
             RGBColor[
              0.4957743636363635, 0.6001035454545454, 0.9538427272727272], 
             UndirectedEdge[5, 103] -> 
             RGBColor[
              0.9651876363636362, 0.9610515454545454, 0.6891854999999999], 
             UndirectedEdge[344, 438] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[42, 381] -> 
             RGBColor[
              0.9439461363636363, 0.9540842727272727, 0.8037884545454543], 
             UndirectedEdge[224, 398] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[226, 405] -> 
             RGBColor[
              0.989986090909091, 0.9879475454545454, 0.6571961818181816], 
             UndirectedEdge[231, 346] -> 
             RGBColor[
              0.8137090454545454, 0.570225909090909, 0.5825757272727272], 
             UndirectedEdge[168, 181] -> 
             RGBColor[0.9941475, 0.9916299090909091, 0.7308122272727275], 
             UndirectedEdge[178, 391] -> 
             RGBColor[
              0.9429603636363637, 0.8015231363636365, 0.31894390909090903`], 
             UndirectedEdge[30, 133] -> 
             RGBColor[
              0.9690147272727272, 0.9733375454545454, 0.7570859545454547], 
             UndirectedEdge[120, 363] -> 
             RGBColor[
              0.8632309545454545, 0.8926025454545454, 0.9180815909090909], 
             UndirectedEdge[452, 468] -> 
             RGBColor[0.5650240454545454, 0.657751, 0.958899909090909], 
             UndirectedEdge[159, 344] -> 
             RGBColor[
              0.9511285909090909, 0.9630723636363636, 0.9676107272727272], 
             UndirectedEdge[68, 330] -> 
             RGBColor[0.410643, 0.5129645, 0.9492445], 
             UndirectedEdge[359, 440] -> 
             RGBColor[
              0.4876890909090908, 0.5949669999999999, 0.9528118181818181], 
             UndirectedEdge[180, 413] -> 
             RGBColor[
              0.5018383181818181, 0.6039559545454545, 0.954615909090909], 
             UndirectedEdge[81, 442] -> 
             RGBColor[
              0.9412969090909091, 0.7870574545454547, 0.4641242272727275], 
             UndirectedEdge[165, 277] -> 
             RGBColor[0.8418806363636363, 0.8771819999999999, 0.9767245], 
             UndirectedEdge[28, 310] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[71, 470] -> 
             RGBColor[0.9651876363636362, 0.9610515454545454, 0.6891855], 
             UndirectedEdge[129, 276] -> 
             RGBColor[
              0.30351572727272724`, 0.43512949999999995`, 0.9406406363636364],
              UndirectedEdge[192, 251] -> 
             RGBColor[
              0.9918773181818181, 0.9893834545454546, 0.6733807727272728], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.9597254545454545, 0.9666662727272728, 0.8052934999999998], 
             UndirectedEdge[15, 323] -> 
             RGBColor[
              0.8164330909090909, 0.8571181818181818, 0.9821801363636363], 
             UndirectedEdge[20, 473] -> 
             RGBColor[
              0.8178123181818182, 0.8560090909090909, 0.8631286818181818], 
             UndirectedEdge[336, 354] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[36, 440] -> 
             RGBColor[
              0.7293278636363636, 0.7864172727272727, 0.9434209545454545], 
             UndirectedEdge[31, 311] -> 
             RGBColor[
              0.5794240454545454, 0.6503738636363636, 0.9571607727272727], 
             UndirectedEdge[366, 405] -> 
             RGBColor[
              0.8902220909090909, 0.9104904545454546, 0.7161734999999998], 
             UndirectedEdge[257, 374] -> 
             RGBColor[
              0.9455539545454545, 0.9199539090909092, 0.6574322727272728], 
             UndirectedEdge[194, 254] -> 
             RGBColor[
              0.9592225454545454, 0.967330090909091, 0.8769975000000001], 
             UndirectedEdge[284, 456] -> 
             RGBColor[
              0.9277878636363637, 0.9406917272727273, 0.7610365454545456], 
             UndirectedEdge[30, 429] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[182, 463] -> 
             RGBColor[
              0.8875097272727273, 0.9129128181818182, 0.9812498181818182], 
             UndirectedEdge[130, 238] -> 
             RGBColor[
              0.9697726363636363, 0.9749586363636363, 0.839579681818182], 
             UndirectedEdge[19, 67] -> 
             RGBColor[
              0.7634669545454544, 0.8151454545454545, 0.977058909090909], 
             UndirectedEdge[114, 446] -> 
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181], 
             UndirectedEdge[164, 418] -> 
             RGBColor[
              0.6408022727272726, 0.7185290909090908, 0.9653728181818182], 
             UndirectedEdge[96, 457] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[285, 354] -> 
             RGBColor[
              0.8661022272727272, 0.8961040909090909, 0.9791386818181818], 
             UndirectedEdge[432, 460] -> 
             RGBColor[0.9830675, 0.9602895454545455, 0.5861233636363634], 
             UndirectedEdge[82, 249] -> 
             RGBColor[
              0.6274692272727271, 0.7026949545454545, 0.9669796818181817], 
             UndirectedEdge[176, 262] -> 
             RGBColor[
              0.9341665909090908, 0.7585379545454545, 0.48936750000000007`], 
             UndirectedEdge[216, 358] -> 
             RGBColor[
              0.9277878636363637, 0.9406917272727273, 0.7610365454545456], 
             UndirectedEdge[54, 374] -> 
             RGBColor[
              0.9414603636363637, 0.9555905454545455, 0.974571409090909], 
             UndirectedEdge[214, 491] -> 
             RGBColor[
              0.9504250454545453, 0.8421372727272726, 0.5554420909090909], 
             UndirectedEdge[68, 357] -> 
             RGBColor[0.536273909090909, 0.6117035, 0.9616082727272728], 
             UndirectedEdge[260, 328] -> 
             RGBColor[
              0.9589675454545454, 0.9650451818181819, 0.7227997727272725], 
             UndirectedEdge[224, 286] -> 
             RGBColor[
              0.842033909090909, 0.8749311818181817, 0.8655428636363637], 
             UndirectedEdge[219, 293] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[209, 404] -> 
             RGBColor[
              0.8351165454545455, 0.5870346363636363, 0.5846868636363636], 
             UndirectedEdge[197, 289] -> 
             RGBColor[
              0.6748756363636362, 0.7439079999999999, 0.9697586363636364], 
             UndirectedEdge[227, 424] -> 
             RGBColor[
              0.9850256818181817, 0.9758467272727273, 0.6556048636363635], 
             UndirectedEdge[458, 461] -> 
             RGBColor[
              0.8390093636363636, 0.8736804545454545, 0.9156674090909092], 
             UndirectedEdge[292, 464] -> 
             RGBColor[
              0.6848746363636364, 0.7522540000000001, 0.9702829545454545], 
             UndirectedEdge[386, 441] -> 
             RGBColor[
              0.9775793181818182, 0.9827992727272727, 0.9228365454545454], 
             UndirectedEdge[257, 343] -> 
             RGBColor[
              0.9139953181818181, 0.8947899090909092, 0.6544221818181819], 
             UndirectedEdge[132, 457] -> 
             RGBColor[
              0.9887288181818181, 0.9896070909090909, 0.8364561818181819], 
             UndirectedEdge[69, 259] -> 
             RGBColor[
              0.9887288181818181, 0.9896070909090909, 0.8364561818181819], 
             UndirectedEdge[68, 95] -> 
             RGBColor[
              0.5830717727272727, 0.6471878636363637, 0.8975097272727273], 
             UndirectedEdge[247, 278] -> 
             RGBColor[
              0.6661421363636363, 0.7326222272727272, 0.9391369545454544], 
             UndirectedEdge[293, 440] -> 
             RGBColor[
              0.6748756363636362, 0.7439079999999999, 0.9697586363636364], 
             UndirectedEdge[307, 442] -> 
             RGBColor[
              0.9226528636363637, 0.7751711818181819, 0.5921552727272728], 
             UndirectedEdge[406, 493] -> 
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454], 
             UndirectedEdge[155, 479] -> 
             RGBColor[
              0.900735090909091, 0.9227762727272728, 0.9588627272727273], 
             UndirectedEdge[311, 488] -> 
             RGBColor[
              0.6529167727272727, 0.7227587727272726, 0.9615240454545455], 
             UndirectedEdge[226, 345] -> 
             RGBColor[
              0.9658662272727272, 0.9735611818181817, 0.9201613636363637], 
             UndirectedEdge[183, 273] -> 
             RGBColor[
              0.5862202727272727, 0.6469642272727274, 0.7344343181818184], 
             UndirectedEdge[384, 499] -> 
             RGBColor[
              0.8176590454545454, 0.8582599090909091, 0.9743103181818182], 
             UndirectedEdge[20, 325] -> 
             RGBColor[
              0.6665805909090909, 0.739457090909091, 0.9674021818181817], 
             UndirectedEdge[252, 424] -> 
             RGBColor[
              0.9651876363636362, 0.9610515454545454, 0.6891854999999999], 
             UndirectedEdge[285, 473] -> 
             RGBColor[
              0.8904770909090909, 0.9127753636363636, 0.8703712272727273], 
             UndirectedEdge[71, 236] -> 
             RGBColor[
              0.9880502272727272, 0.9770974545454545, 0.605480318181818], 
             UndirectedEdge[2, 446] -> 
             RGBColor[
              0.9414603636363637, 0.9555905454545455, 0.974571409090909], 
             UndirectedEdge[33, 351] -> 
             RGBColor[
              0.9724789090909091, 0.9784929090909091, 0.9089678181818182], 
             UndirectedEdge[172, 466] -> 
             RGBColor[
              0.9763853181818182, 0.9798903636363636, 0.8283861363636366], 
             UndirectedEdge[12, 279] -> 
             RGBColor[
              0.7389650909090908, 0.7925997272727272, 0.8821028636363635], 
             UndirectedEdge[171, 219] -> 
             RGBColor[
              0.9724789090909091, 0.9784929090909091, 0.9089678181818182], 
             UndirectedEdge[153, 223] -> 
             RGBColor[
              0.8248753636363635, 0.8634582727272726, 0.9830892727272726], 
             UndirectedEdge[121, 489] -> 
             RGBColor[
              0.6742670909090909, 0.7381793181818181, 0.9028811363636364], 
             UndirectedEdge[362, 470] -> 
             RGBColor[0.8418806363636363, 0.8771819999999999, 0.9767245], 
             UndirectedEdge[168, 232] -> 
             RGBColor[
              0.9904443636363636, 0.9778695454545454, 0.5499609090909092], 
             UndirectedEdge[285, 409] -> 
             RGBColor[
              0.5942174545454545, 0.6777978181818182, 0.9631146363636363], 
             UndirectedEdge[159, 439] -> 
             RGBColor[0.8418806363636363, 0.8771819999999999, 0.9767245], 
             UndirectedEdge[156, 263] -> 
             RGBColor[
              0.9032890454545454, 0.9254948181818181, 0.9827548636363637], 
             UndirectedEdge[149, 314] -> 
             RGBColor[
              0.8859402727272727, 0.9108992727272727, 0.9455580454545454], 
             UndirectedEdge[110, 457] -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             UndirectedEdge[43, 263] -> 
             RGBColor[
              0.8462828636363636, 0.8802669999999999, 0.9852004090909091], 
             UndirectedEdge[141, 160] -> 
             RGBColor[0.9893075, 0.9754379090909091, 0.4262203181818179], 
             UndirectedEdge[345, 389] -> 
             RGBColor[0.9686357727272727, 0.972527, 0.7158390909090907], 
             UndirectedEdge[225, 247] -> 
             RGBColor[0.6595294545454544, 0.7276904999999999, 0.9503305], 
             UndirectedEdge[171, 293] -> 
             RGBColor[
              0.9246393636363636, 0.9409153636363636, 0.9241119545454546], 
             UndirectedEdge[179, 415] -> 
             RGBColor[0.6595294545454544, 0.7276904999999999, 0.9503305], 
             UndirectedEdge[143, 414] -> 
             RGBColor[
              0.9775793181818182, 0.9827992727272727, 0.9228365454545454], 
             UndirectedEdge[77, 388] -> 
             RGBColor[
              0.6727548181818181, 0.7375539545454545, 0.9279434090909091], 
             UndirectedEdge[305, 406] -> 
             RGBColor[
              0.9285457727272727, 0.9423128181818181, 0.8435302727272729], 
             UndirectedEdge[55, 256] -> 
             RGBColor[
              0.900735090909091, 0.9227762727272728, 0.9588627272727273], 
             UndirectedEdge[367, 450] -> 
             RGBColor[
              0.7733826818181817, 0.7708969999999999, 0.6221771363636364], 
             UndirectedEdge[171, 258] -> 
             RGBColor[
              0.8632309545454545, 0.8926025454545454, 0.9180815909090909], 
             UndirectedEdge[366, 423] -> 
             RGBColor[
              0.8867739545454545, 0.8990149999999999, 0.689519909090909], 
             UndirectedEdge[309, 393] -> 
             RGBColor[
              0.9697726363636363, 0.9749586363636363, 0.839579681818182], 
             UndirectedEdge[324, 360] -> 
             RGBColor[
              0.8663794545454546, 0.8923789090909091, 0.7550061818181819], 
             UndirectedEdge[125, 310] -> 
             RGBColor[
              0.9688907727272726, 0.9748119090909091, 0.8700368181818183], 
             UndirectedEdge[33, 463] -> 
             RGBColor[
              0.9511285909090909, 0.9630723636363636, 0.9676107272727272], 
             UndirectedEdge[137, 280] -> 
             RGBColor[
              0.7227151818181817, 0.7814855454545454, 0.9546144999999999], 
             UndirectedEdge[72, 179] -> 
             RGBColor[
              0.6772916363636363, 0.7394300454545454, 0.852756590909091], 
             UndirectedEdge[17, 165] -> 
             RGBColor[
              0.8322124090909091, 0.8697001818181818, 0.9836851818181818], 
             UndirectedEdge[402, 417] -> 
             RGBColor[
              0.9032890454545454, 0.9254948181818181, 0.9827548636363637], 
             UndirectedEdge[102, 225] -> 
             RGBColor[
              0.8941224090909091, 0.9178445454545454, 0.9700562727272728], 
             UndirectedEdge[83, 231] -> 
             RGBColor[
              0.8351165454545455, 0.5870346363636363, 0.5846868636363636], 
             UndirectedEdge[194, 377] -> 
             RGBColor[0.9001235, 0.7343848636363635, 0.6050956363636363], 
             UndirectedEdge[131, 495] -> 
             RGBColor[
              0.9348476818181818, 0.9506588181818182, 0.9857649545454545], 
             UndirectedEdge[213, 447] -> 
             RGBColor[
              0.6727548181818181, 0.7375539545454545, 0.9279434090909091], 
             UndirectedEdge[146, 166] -> 
             RGBColor[
              0.8874525454545454, 0.9115246363636363, 0.9204957727272727], 
             UndirectedEdge[422, 428] -> 
             RGBColor[
              0.916514409090909, 0.9353582727272727, 0.9603677727272727], 
             UndirectedEdge[232, 338] -> 
             RGBColor[
              0.9896864545454546, 0.9762484545454546, 0.4674671818181819], 
             UndirectedEdge[366, 469] -> 
             RGBColor[
              0.8248753636363635, 0.8634582727272726, 0.9830892727272726], 
             UndirectedEdge[245, 482] -> 
             RGBColor[
              0.9760063636363636, 0.9790798181818181, 0.7871392727272726], 
             UndirectedEdge[40, 243] -> 
             RGBColor[
              0.7676591363636363, 0.818409818181818, 0.9698667727272727], 
             UndirectedEdge[174, 320] -> 
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273], 
             UndirectedEdge[30, 31] -> 
             RGBColor[
              0.5794240454545454, 0.6503738636363636, 0.9571607727272727], 
             UndirectedEdge[77, 354] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[24, 223] -> 
             RGBColor[
              0.872714909090909, 0.9010358181818181, 0.9679451363636363], 
             UndirectedEdge[261, 391] -> 
             RGBColor[
              0.9329949090909091, 0.7679073181818185, 0.2802300000000002], 
             UndirectedEdge[125, 323] -> 
             RGBColor[
              0.9434432272727272, 0.9547480909090909, 0.8754924545454545], 
             UndirectedEdge[1, 364] -> 
             RGBColor[
              0.9806038636363636, 0.9840500000000001, 0.8727119999999999], 
             UndirectedEdge[88, 133] -> 
             RGBColor[
              0.9896864545454546, 0.9762484545454546, 0.4674671818181819], 
             UndirectedEdge[178, 407] -> 
             RGBColor[
              0.8867739545454545, 0.8990149999999999, 0.689519909090909], 
             UndirectedEdge[103, 486] -> 
             RGBColor[
              0.9555194090909092, 0.9535697272727273, 0.6961461818181818], 
             UndirectedEdge[204, 486] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[89, 407] -> 
             RGBColor[
              0.8090960454545455, 0.8508762727272727, 0.9815842272727273], 
             UndirectedEdge[38, 301] -> 
             RGBColor[
              0.5745030909090908, 0.6607222272727272, 0.9618584545454545], 
             UndirectedEdge[92, 132] -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909092], 
             UndirectedEdge[8, 146] -> 
             RGBColor[
              0.5830717727272727, 0.6471878636363637, 0.8975097272727273], 
             UndirectedEdge[44, 110] -> 
             RGBColor[
              0.9755034545454545, 0.9797436363636364, 0.8588432727272728], 
             UndirectedEdge[102, 252] -> 
             RGBColor[
              0.8875097272727273, 0.9129128181818182, 0.9812498181818182], 
             UndirectedEdge[273, 283] -> 
             RGBColor[
              0.6971299545454546, 0.7550312727272728, 0.7410619090909092], 
             UndirectedEdge[158, 428] -> 
             RGBColor[
              0.9322937272727272, 0.9479402727272728, 0.9618728181818181], 
             UndirectedEdge[176, 328] -> 
             RGBColor[
              0.9930106363636364, 0.9891982727272728, 0.6070716363636363], 
             UndirectedEdge[45, 398] -> 
             RGBColor[
              0.9756274090909092, 0.9782692727272728, 0.7458924090909093], 
             UndirectedEdge[233, 275] -> 
             RGBColor[
              0.9775793181818182, 0.9827992727272727, 0.9228365454545454], 
             UndirectedEdge[250, 485] -> 
             RGBColor[0.6858565, 0.7496978181818181, 0.9403931363636363], 
             UndirectedEdge[29, 65] -> 
             RGBColor[
              0.9601044090909091, 0.9674768181818182, 0.8465403636363638], 
             UndirectedEdge[166, 453] -> 
             RGBColor[
              0.8909799999999999, 0.9121115454545454, 0.7986672272727271], 
             UndirectedEdge[222, 294] -> 
             RGBColor[
              0.9933895909090908, 0.9900088181818183, 0.6483185000000002], 
             UndirectedEdge[150, 220] -> 
             RGBColor[
              0.6978878636363637, 0.7566523636363636, 0.8235556363636365], 
             UndirectedEdge[311, 423] -> 
             RGBColor[
              0.9651876363636362, 0.9610515454545454, 0.6891854999999999], 
             UndirectedEdge[210, 424] -> 
             RGBColor[
              0.7625525454545454, 0.8003927272727274, 0.6782186363636362], 
             UndirectedEdge[179, 312] -> 
             RGBColor[
              0.526059909090909, 0.6228780454545454, 0.9570300909090909], 
             UndirectedEdge[310, 323] -> 
             RGBColor[
              0.9190683636363636, 0.9380768181818182, 0.9842599090909091], 
             UndirectedEdge[108, 349] -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             UndirectedEdge[355, 395] -> 
             RGBColor[
              0.3590863636363637, 0.47110850000000004`, 0.9451857727272728], 
             UndirectedEdge[47, 200] -> 
             RGBColor[
              0.8859402727272727, 0.9108992727272727, 0.9455580454545454], 
             UndirectedEdge[152, 217] -> 
             RGBColor[
              0.9281668181818181, 0.9415022727272726, 0.8022834090909089], 
             UndirectedEdge[174, 210] -> 
             RGBColor[
              0.7617188636363637, 0.8122770000000001, 0.9342567727272727], 
             UndirectedEdge[135, 211] -> 
             RGBColor[
              0.9821161363636364, 0.9846753636363637, 0.8476497272727272], 
             UndirectedEdge[52, 491] -> 
             RGBColor[
              0.9504250454545453, 0.8421372727272726, 0.5554420909090909], 
             UndirectedEdge[41, 250] -> 
             RGBColor[
              0.8551059999999999, 0.8870454545454545, 0.954337409090909], 
             UndirectedEdge[220, 392] -> 
             RGBColor[
              0.5699958636363636, 0.6588757272727273, 0.9607004545454545], 
             UndirectedEdge[182, 359] -> 
             RGBColor[
              0.6590963181818181, 0.7313259999999999, 0.9682535909090909], 
             UndirectedEdge[89, 391] -> 
             RGBColor[
              0.8652824545454546, 0.7533844090909092, 0.6110082272727273], 
             UndirectedEdge[62, 190] -> 
             RGBColor[
              0.8417789090909091, 0.8726462727272728, 0.7113451363636362], 
             UndirectedEdge[21, 87] -> 
             RGBColor[
              0.8867739545454545, 0.8990149999999999, 0.689519909090909], 
             UndirectedEdge[185, 286] -> 
             RGBColor[
              0.9592225454545454, 0.967330090909091, 0.8769975000000001], 
             UndirectedEdge[114, 294] -> 
             RGBColor[
              0.9887288181818181, 0.9896070909090909, 0.8364561818181819], 
             UndirectedEdge[48, 156] -> 
             RGBColor[
              0.7676591363636363, 0.818409818181818, 0.9698667727272727], 
             UndirectedEdge[68, 450] -> 
             RGBColor[
              0.3848646818181817, 0.4920364999999999, 0.9472151363636363], 
             UndirectedEdge[149, 406] -> 
             RGBColor[
              0.8248753636363635, 0.8634582727272726, 0.9830892727272726], 
             UndirectedEdge[123, 158] -> 
             RGBColor[0.8778414999999999, 0.9054309999999999, 0.9882105], 
             UndirectedEdge[55, 91] -> 
             RGBColor[
              0.7808844999999999, 0.8282732727272726, 0.9474796818181818], 
             UndirectedEdge[135, 169] -> 
             RGBColor[
              0.9826190454545454, 0.9840115454545455, 0.775945727272727], 
             UndirectedEdge[141, 456] -> 
             RGBColor[
              0.993134590909091, 0.9877239090909091, 0.49412077272727273`], 
             UndirectedEdge[287, 354] -> 
             RGBColor[
              0.9697726363636363, 0.9749586363636363, 0.839579681818182], 
             UndirectedEdge[223, 411] -> 
             RGBColor[
              0.8817912272727273, 0.8822070909090909, 0.6701629545454544], 
             UndirectedEdge[127, 301] -> 
             RGBColor[
              0.5745030909090908, 0.6607222272727272, 0.9618584545454545], 
             UndirectedEdge[167, 201] -> 
             RGBColor[
              0.8671373636363636, 0.8939999999999999, 0.8374999090909092], 
             UndirectedEdge[28, 218] -> 
             RGBColor[
              0.9775793181818182, 0.9827992727272727, 0.9228365454545454], 
             UndirectedEdge[112, 317] -> 
             RGBColor[
              0.6150239545454546, 0.697601090909091, 0.9633434545454544], 
             UndirectedEdge[275, 372] -> 
             RGBColor[
              0.8997454545454545, 0.5990615909090908, 0.5544891363636364], 
             UndirectedEdge[85, 146] -> 
             RGBColor[
              0.8390093636363636, 0.8736804545454545, 0.9156674090909092], 
             UndirectedEdge[7, 262] -> 
             RGBColor[
              0.9341665909090908, 0.7585379545454545, 0.48936750000000007`], 
             UndirectedEdge[448, 455] -> 
             RGBColor[0.7837692272727272, 0.831856, 0.9788568181818181], 
             UndirectedEdge[9, 368] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[216, 399] -> 
             RGBColor[
              0.927663909090909, 0.9421660909090909, 0.8739874090909092], 
             UndirectedEdge[205, 474] -> 
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454], 
             UndirectedEdge[125, 242] -> 
             RGBColor[
              0.842033909090909, 0.8749311818181817, 0.8655428636363637], 
             UndirectedEdge[280, 338] -> 
             RGBColor[
              0.7406013181818181, 0.7917507272727273, 0.7440897272727274], 
             UndirectedEdge[232, 393] -> 
             RGBColor[
              0.9904443636363636, 0.9778695454545454, 0.5499609090909092], 
             UndirectedEdge[403, 483] -> 
             RGBColor[
              0.7150237727272727, 0.7773012727272727, 0.9722305454545455], 
             UndirectedEdge[427, 433] -> 
             RGBColor[
              0.9668175909090909, 0.9491753636363636, 0.6586349999999999], 
             UndirectedEdge[269, 310] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[212, 357] -> 
             RGBColor[
              0.9256810454545454, 0.9430085454545454, 0.9730663636363637], 
             UndirectedEdge[88, 307] -> 
             RGBColor[
              0.9718003181818182, 0.9659832727272727, 0.6779919545454545], 
             UndirectedEdge[212, 217] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[67, 124] -> 
             RGBColor[
              0.7848744545454546, 0.8319541818181818, 0.9791700454545454], 
             UndirectedEdge[364, 380] -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             UndirectedEdge[82, 384] -> 
             RGBColor[
              0.6529167727272727, 0.7227587727272726, 0.9615240454545455], 
             UndirectedEdge[222, 439] -> 
             RGBColor[
              0.8663794545454546, 0.8923789090909091, 0.7550061818181819], 
             UndirectedEdge[337, 420] -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909092], 
             UndirectedEdge[61, 99] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[63, 439] -> 
             RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 
             UndirectedEdge[37, 53] -> 
             RGBColor[
              0.9756274090909092, 0.9782692727272728, 0.7458924090909093], 
             UndirectedEdge[39, 62] -> 
             RGBColor[
              0.8405216363636363, 0.8743058181818182, 0.8906051363636363], 
             UndirectedEdge[130, 182] -> 
             RGBColor[
              0.8875097272727273, 0.9129128181818182, 0.9812498181818182], 
             UndirectedEdge[152, 398] -> 
             RGBColor[
              0.9760063636363636, 0.9790798181818181, 0.7871392727272726], 
             UndirectedEdge[23, 110] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[322, 440] -> 
             RGBColor[
              0.5892456363636362, 0.6766730909090908, 0.9613140909090909], 
             UndirectedEdge[141, 432] -> 
             RGBColor[
              0.9843247727272728, 0.9586300000000001, 0.40686336363636333`], 
             UndirectedEdge[161, 459] -> 
             RGBColor[
              0.9854616363636364, 0.9610616363636364, 0.5306039545454546], 
             UndirectedEdge[185, 333] -> 
             RGBColor[
              0.8322124090909091, 0.8697001818181818, 0.9836851818181818], 
             UndirectedEdge[297, 474] -> 
             RGBColor[
              0.9285457727272727, 0.9423128181818181, 0.8435302727272729], 
             UndirectedEdge[265, 329] -> 
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273], 
             UndirectedEdge[90, 280] -> 
             RGBColor[
              0.6906549545454544, 0.7564899999999999, 0.9712636818181818], 
             UndirectedEdge[183, 430] -> 
             RGBColor[
              0.5683341363636363, 0.6366990454545454, 0.9449590909090909], 
             UndirectedEdge[86, 194] -> 
             RGBColor[
              0.9577102727272727, 0.9667047272727274, 0.9020597727272726], 
             UndirectedEdge[143, 186] -> 
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273], 
             UndirectedEdge[1, 416] -> 
             RGBColor[
              0.9103723181818182, 0.9289587272727273, 0.8975446363636364], 
             UndirectedEdge[27, 86] -> 
             RGBColor[
              0.9673784999999999, 0.9741865454545455, 0.8950990909090908], 
             UndirectedEdge[66, 415] -> 
             RGBColor[
              0.8000501363636363, 0.8442695454545455, 0.9607025909090909], 
             UndirectedEdge[413, 490] -> 
             RGBColor[
              0.5018383181818181, 0.6039559545454545, 0.954615909090909], 
             UndirectedEdge[226, 284] -> 
             RGBColor[
              0.9246393636363636, 0.9409153636363636, 0.9241119545454546], 
             UndirectedEdge[245, 438] -> 
             RGBColor[
              0.9760063636363636, 0.9790798181818181, 0.7871392727272726], 
             UndirectedEdge[53, 163] -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             UndirectedEdge[367, 368] -> 
             RGBColor[
              0.9568521363636364, 0.9155595454545454, 0.6199210909090909], 
             UndirectedEdge[112, 175] -> 
             RGBColor[
              0.5457742727272727, 0.6399536363636363, 0.9582862727272727], 
             UndirectedEdge[277, 288] -> 
             RGBColor[
              0.8875097272727273, 0.9129128181818182, 0.9812498181818182], 
             UndirectedEdge[249, 323] -> 
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454], 
             UndirectedEdge[416, 452] -> 
             RGBColor[
              0.7364312727272728, 0.7941100000000001, 0.9743416818181818], 
             UndirectedEdge[13, 87] -> 
             RGBColor[
              0.9304634545454544, 0.7447775909090908, 0.3085161818181817], 
             UndirectedEdge[471, 497] -> 
             RGBColor[
              0.9765725000000001, 0.9428562727272729, 0.5918286818181819], 
             UndirectedEdge[17, 321] -> 
             RGBColor[0.956198, 0.9660793636363636, 0.9271220454545455], 
             UndirectedEdge[106, 227] -> 
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273], 
             UndirectedEdge[37, 100] -> 
             RGBColor[0.9938925000000001, 0.989345, 0.5766145], 
             UndirectedEdge[9, 375] -> 
             RGBColor[0.7708685, 0.5754460454545457, 0.5831124545454546], 
             UndirectedEdge[10, 302] -> 
             RGBColor[
              0.9409179545454546, 0.7862469090909092, 0.42287736363636347`], 
             UndirectedEdge[14, 272] -> 
             RGBColor[
              0.9658662272727272, 0.9735611818181817, 0.9201613636363637], 
             UndirectedEdge[63, 387] -> 
             RGBColor[
              0.5699958636363636, 0.6588757272727273, 0.9607004545454545], 
             UndirectedEdge[471, 483] -> 
             RGBColor[
              0.8632309545454545, 0.8926025454545454, 0.9180815909090909], 
             UndirectedEdge[46, 392] -> 
             RGBColor[
              0.8617186818181818, 0.8919771818181819, 0.9431438636363636], 
             UndirectedEdge[122, 357] -> 
             RGBColor[
              0.767989909090909, 0.8192740000000001, 0.9773517727272727], 
             UndirectedEdge[75, 125] -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             UndirectedEdge[244, 261] -> 
             RGBColor[
              0.9765725000000001, 0.9428562727272729, 0.5918286818181819], 
             UndirectedEdge[7, 178] -> 
             RGBColor[
              0.9895624999999999, 0.9777228181818182, 0.5804180454545455], 
             UndirectedEdge[108, 487] -> 
             RGBColor[0.697006, 0.7565056363636364, 0.8540127727272728], 
             UndirectedEdge[338, 480] -> 
             RGBColor[
              0.9756274090909092, 0.9782692727272728, 0.7458924090909093], 
             UndirectedEdge[237, 284] -> 
             RGBColor[
              0.8396905909090908, 0.5134879999999999, 0.5754617272727273], 
             UndirectedEdge[162, 456] -> 
             RGBColor[
              0.8179362727272728, 0.8545347272727273, 0.7501778181818184], 
             UndirectedEdge[104, 310] -> 
             RGBColor[
              0.9688907727272726, 0.9748119090909091, 0.8700368181818183], 
             UndirectedEdge[168, 390] -> 
             RGBColor[
              0.9950293636363636, 0.9917766363636363, 0.7003550909090913], 
             UndirectedEdge[164, 431] -> 
             RGBColor[
              0.7808844999999999, 0.8282732727272726, 0.9474796818181818], 
             UndirectedEdge[57, 60] -> 
             RGBColor[
              0.513467409090909, 0.6158950000000001, 0.9548411818181818], 
             UndirectedEdge[158, 247] -> 
             RGBColor[
              0.6274692272727271, 0.7026949545454545, 0.9669796818181817], 
             UndirectedEdge[32, 475] -> 
             RGBColor[
              0.9790915909090909, 0.9834246363636363, 0.8977742727272727], 
             UndirectedEdge[53, 293] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[72, 294] -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             UndirectedEdge[87, 287] -> 
             RGBColor[
              0.9904443636363636, 0.9778695454545454, 0.5499609090909092], 
             UndirectedEdge[154, 374] -> 
             RGBColor[
              0.662962909090909, 0.7323525454545454, 0.969740909090909], 
             UndirectedEdge[119, 364] -> 
             RGBColor[
              0.7551061818181819, 0.8073452727272727, 0.9454503181818181], 
             UndirectedEdge[90, 342] -> 
             RGBColor[0.7164332727272728, 0.777418, 0.9732930454545454], 
             UndirectedEdge[401, 428] -> 
             RGBColor[
              0.9821161363636364, 0.9846753636363637, 0.8476497272727272], 
             UndirectedEdge[183, 477] -> 
             RGBColor[
              0.43486459090909085`, 0.5318865909090909, 0.9516586818181818], 
             UndirectedEdge[82, 269] -> 
             RGBColor[
              0.6661421363636363, 0.7326222272727272, 0.9391369545454544], 
             UndirectedEdge[202, 273] -> 
             RGBColor[
              0.9942714545454545, 0.9901555454545454, 0.617861363636364], 
             UndirectedEdge[147, 242] -> 
             RGBColor[
              0.8390093636363636, 0.8736804545454545, 0.9156674090909092], 
             UndirectedEdge[117, 198] -> 
             RGBColor[0.6858565, 0.7496978181818181, 0.9403931363636363], 
             UndirectedEdge[240, 434] -> 
             RGBColor[0.8660005, 0.8915683636363636, 0.713759318181818], 
             UndirectedEdge[249, 310] -> 
             RGBColor[
              0.9190683636363636, 0.9380768181818182, 0.9842599090909091], 
             UndirectedEdge[448, 478] -> 
             RGBColor[
              0.9592225454545454, 0.967330090909091, 0.8769975000000001], 
             UndirectedEdge[121, 196] -> 
             RGBColor[
              0.526059909090909, 0.6228780454545454, 0.9570300909090909], 
             UndirectedEdge[200, 256] -> 
             RGBColor[0.9073477727272727, 0.927708, 0.9476691818181818], 
             UndirectedEdge[79, 184] -> 
             RGBColor[
              0.9601044090909091, 0.9674768181818182, 0.8465403636363638], 
             UndirectedEdge[51, 240] -> 
             RGBColor[
              0.9589675454545454, 0.9650451818181819, 0.7227997727272725], 
             UndirectedEdge[339, 387] -> 
             RGBColor[
              0.6726311363636364, 0.7398343636363636, 0.9627802272727273], 
             UndirectedEdge[46, 142] -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             UndirectedEdge[233, 259] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[266, 471] -> 
             RGBColor[
              0.9724789090909091, 0.9784929090909091, 0.9089678181818182], 
             UndirectedEdge[167, 456] -> 
             RGBColor[
              0.8663794545454546, 0.8923789090909091, 0.7550061818181819], 
             UndirectedEdge[10, 181] -> 
             RGBColor[
              0.9937685454545454, 0.9908193636363636, 0.6895653636363634], 
             UndirectedEdge[31, 429] -> 
             RGBColor[
              0.5926494090909091, 0.6602373181818182, 0.9347736818181818], 
             UndirectedEdge[317, 322] -> 
             RGBColor[
              0.6150239545454546, 0.697601090909091, 0.9633434545454544], 
             UndirectedEdge[52, 466] -> 
             RGBColor[
              0.9911229545454545, 0.9903791818181817, 0.7809367727272729], 
             UndirectedEdge[207, 281] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[358, 398] -> 
             RGBColor[
              0.9756274090909092, 0.9782692727272728, 0.7458924090909093], 
             UndirectedEdge[155, 250] -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             UndirectedEdge[243, 285] -> 
             RGBColor[
              0.8661022272727272, 0.8961040909090909, 0.9791386818181818], 
             UndirectedEdge[378, 452] -> 
             RGBColor[
              0.767989909090909, 0.8192740000000001, 0.9773517727272727], 
             UndirectedEdge[100, 264] -> 
             RGBColor[
              0.8425368181818181, 0.8742673636363636, 0.7938388636363634], 
             UndirectedEdge[81, 130] -> 
             RGBColor[
              0.9697726363636363, 0.9749586363636363, 0.839579681818182], 
             UndirectedEdge[1, 120] -> 
             RGBColor[
              0.9887288181818181, 0.9896070909090909, 0.8364561818181817], 
             UndirectedEdge[390, 422] -> 
             RGBColor[
              0.9285457727272727, 0.9423128181818181, 0.8435302727272729], 
             UndirectedEdge[118, 255] -> 
             RGBColor[
              0.9815552272727273, 0.9596641818181818, 0.6111856363636363], 
             UndirectedEdge[137, 229] -> 
             RGBColor[
              0.9739911818181818, 0.9791182727272727, 0.8839055454545454], 
             UndirectedEdge[367, 375] -> 
             RGBColor[
              0.9034489090909091, 0.6278139545454547, 0.23991677272727274`], 
             UndirectedEdge[230, 382] -> 
             RGBColor[
              0.9673784999999999, 0.9741865454545455, 0.8950990909090908], 
             UndirectedEdge[114, 334] -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             UndirectedEdge[52, 170] -> 
             RGBColor[
              0.9790915909090909, 0.9834246363636363, 0.8977742727272727], 
             UndirectedEdge[4, 389] -> 
             RGBColor[
              0.9930106363636364, 0.9891982727272728, 0.6070716363636363], 
             UndirectedEdge[190, 378] -> 
             RGBColor[
              0.9431882272727272, 0.9524631818181819, 0.721294727272727], 
             UndirectedEdge[89, 328] -> 
             RGBColor[
              0.911629590909091, 0.9272991818181819, 0.7182846363636362], 
             UndirectedEdge[93, 300] -> 
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181], 
             UndirectedEdge[104, 125] -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             UndirectedEdge[59, 228] -> 
             RGBColor[
              0.8921227272727272, 0.6322624545454545, 0.5822413181818182], 
             UndirectedEdge[96, 136] -> 
             RGBColor[
              0.9035432727272726, 0.7134939090909089, 0.592921090909091], 
             UndirectedEdge[332, 420] -> 
             RGBColor[
              0.9246393636363636, 0.9409153636363636, 0.9241119545454546], 
             UndirectedEdge[40, 283] -> 
             RGBColor[
              0.4957743636363635, 0.6001035454545454, 0.9538427272727272], 
             UndirectedEdge[17, 288] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[325, 413] -> 
             RGBColor[
              0.526059909090909, 0.6228780454545454, 0.9570300909090909], 
             UndirectedEdge[421, 459] -> 
             RGBColor[
              0.8913589545454546, 0.9129220909090909, 0.8399140909090911], 
             UndirectedEdge[148, 342] -> 
             RGBColor[
              0.6634671363636364, 0.7354452727272728, 0.9681718181818182], 
             UndirectedEdge[262, 478] -> 
             RGBColor[0.9341665909090908, 0.7585379545454545, 0.4893675], 
             UndirectedEdge[133, 405] -> 
             RGBColor[
              0.993134590909091, 0.9877239090909091, 0.49412077272727273`], 
             UndirectedEdge[374, 397] -> 
             RGBColor[
              0.9597254545454545, 0.9666662727272728, 0.8052934999999998], 
             UndirectedEdge[151, 389] -> 
             RGBColor[
              0.9843247727272728, 0.9586300000000001, 0.40686336363636333`], 
             UndirectedEdge[235, 305] -> 
             RGBColor[0.9938925000000001, 0.989345, 0.5766145], 
             UndirectedEdge[204, 348] -> 
             RGBColor[
              0.911629590909091, 0.9272991818181819, 0.7182846363636362], 
             UndirectedEdge[191, 429] -> 
             RGBColor[
              0.8941428181818182, 0.5559972727272727, 0.5491240454545454], 
             UndirectedEdge[15, 414] -> 
             RGBColor[
              0.8551059999999999, 0.8870454545454545, 0.954337409090909], 
             UndirectedEdge[277, 414] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[317, 440] -> 
             RGBColor[
              0.513467409090909, 0.6158950000000001, 0.9548411818181818], 
             UndirectedEdge[76, 182] -> 
             RGBColor[
              0.7606528636363636, 0.8130320909090909, 0.9767558636363636], 
             UndirectedEdge[199, 376] -> 
             RGBColor[0.8079908181818182, 0.850778090909091, 0.981271], 
             UndirectedEdge[375, 402] -> 
             RGBColor[0.8564985, 0.6426809545454548, 0.5915570000000001], 
             UndirectedEdge[45, 195] -> 
             RGBColor[
              0.9756274090909092, 0.9782692727272728, 0.7458924090909093], 
             UndirectedEdge[149, 269] -> 
             RGBColor[
              0.8793275909090909, 0.9059675454545455, 0.9567515909090909], 
             UndirectedEdge[45, 152] -> 
             RGBColor[0.9938925000000001, 0.989345, 0.5766145], 
             UndirectedEdge[356, 494] -> 
             RGBColor[
              0.9094001363636364, 0.9305950000000001, 0.9912205909090909], 
             UndirectedEdge[44, 360] -> 
             RGBColor[0.8662555, 0.8938532727272728, 0.8679570454545456], 
             UndirectedEdge[284, 432] -> 
             RGBColor[
              0.9189780454545454, 0.9115978181818181, 0.6737791363636363], 
             UndirectedEdge[151, 237] -> 
             RGBColor[
              0.8966064545454546, 0.5322368181818182, 0.262535409090909], 
             UndirectedEdge[207, 343] -> 
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273], 
             UndirectedEdge[33, 371] -> 
             RGBColor[
              0.872714909090909, 0.9010358181818181, 0.9679451363636363], 
             UndirectedEdge[280, 480] -> 
             RGBColor[
              0.7227151818181817, 0.7814855454545454, 0.9546144999999999], 
             UndirectedEdge[420, 454] -> 
             RGBColor[
              0.7890094545454545, 0.8338303636363635, 0.9112238636363637], 
             UndirectedEdge[267, 393] -> 
             RGBColor[
              0.9350484545454545, 0.7586846818181816, 0.45891036363636384`], 
             UndirectedEdge[337, 427] -> 
             RGBColor[
              0.9755034545454545, 0.9797436363636364, 0.8588432727272728], 
             UndirectedEdge[267, 480] -> 
             RGBColor[
              0.916404409090909, 0.746798409090909, 0.5869414090909091], 
             UndirectedEdge[234, 336] -> 
             RGBColor[0.9700774999999999, 0.925423, 0.597534], 
             UndirectedEdge[122, 492] -> 
             RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             UndirectedEdge[80, 272] -> 
             RGBColor[
              0.6939814545454546, 0.7552549090909091, 0.9041373181818182], 
             UndirectedEdge[331, 444] -> 
             RGBColor[
              0.9593465000000001, 0.9658557272727273, 0.7640466363636365], 
             UndirectedEdge[77, 184] -> 
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181], 
             UndirectedEdge[266, 359] -> 
             RGBColor[
              0.7227151818181817, 0.7814855454545454, 0.9546144999999999], 
             UndirectedEdge[32, 478] -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909092], 
             UndirectedEdge[14, 447] -> 
             RGBColor[
              0.6529167727272727, 0.7227587727272726, 0.9615240454545455], 
             UndirectedEdge[16, 358] -> 
             RGBColor[
              0.7921579545454545, 0.8336067272727272, 0.7481484545454546], 
             UndirectedEdge[50, 323] -> 
             RGBColor[
              0.8164330909090909, 0.8571181818181818, 0.9821801363636363], 
             UndirectedEdge[92, 365] -> 
             RGBColor[
              0.9715897727272726, 0.9260483636363637, 0.5724717272727273], 
             UndirectedEdge[296, 438] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[181, 422] -> 
             RGBColor[
              0.927663909090909, 0.9421660909090909, 0.8739874090909092], 
             UndirectedEdge[35, 428] -> 
             RGBColor[0.6858565, 0.7496978181818181, 0.9403931363636363], 
             UndirectedEdge[19, 298] -> 
             RGBColor[
              0.8248753636363635, 0.8634582727272726, 0.9830892727272726], 
             UndirectedEdge[209, 348] -> 
             RGBColor[
              0.911629590909091, 0.9272991818181819, 0.7182846363636362], 
             UndirectedEdge[27, 194] -> 
             RGBColor[
              0.9348476818181818, 0.9506588181818182, 0.9857649545454545], 
             UndirectedEdge[253, 287] -> 
             RGBColor[
              0.9911229545454545, 0.9903791818181817, 0.7809367727272729], 
             UndirectedEdge[412, 476] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[221, 336] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[146, 248] -> 
             RGBColor[
              0.8874525454545454, 0.9115246363636363, 0.9204957727272727], 
             UndirectedEdge[17, 455] -> 
             RGBColor[0.7837692272727272, 0.831856, 0.9788568181818181], 
             UndirectedEdge[102, 393] -> 
             RGBColor[
              0.9127664545454546, 0.9297308181818182, 0.8420252272727275], 
             UndirectedEdge[80, 497] -> 
             RGBColor[
              0.6833374090909091, 0.7091294545454547, 0.6344475454545455], 
             UndirectedEdge[108, 416] -> 
             RGBColor[
              0.9118845909090909, 0.9295840909090909, 0.8724823636363637], 
             UndirectedEdge[8, 453] -> 
             RGBColor[
              0.5865992272727272, 0.6477747727272727, 0.7756811818181817], 
             UndirectedEdge[58, 402] -> 
             RGBColor[
              0.6511186363636362, 0.7242641363636362, 0.9679869999999999], 
             UndirectedEdge[95, 357] -> 
             RGBColor[0.9404186818181818, 0.9534973636363636, 0.925617], 
             UndirectedEdge[183, 283] -> 
             RGBColor[
              0.2898366818181818, 0.41346104545454543`, 0.9401285909090908], 
             UndirectedEdge[179, 294] -> 
             RGBColor[
              0.6772916363636363, 0.7394300454545455, 0.852756590909091], 
             UndirectedEdge[136, 240] -> 
             RGBColor[
              0.9276631363636363, 0.7278802727272726, 0.3299559090909089], 
             UndirectedEdge[153, 289] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             UndirectedEdge[73, 200] -> 
             RGBColor[
              0.9800429545454545, 0.9590388181818181, 0.636247909090909], 
             UndirectedEdge[196, 447] -> 
             RGBColor[
              0.526059909090909, 0.6228780454545454, 0.9570300909090909], 
             UndirectedEdge[68, 492] -> 
             RGBColor[
              0.4590861818181818, 0.5508086818181818, 0.9540728636363636], 
             UndirectedEdge[25, 413] -> 
             RGBColor[
              0.6274692272727271, 0.7026949545454545, 0.9669796818181817], 
             UndirectedEdge[220, 426] -> 
             RGBColor[
              0.5699958636363636, 0.6588757272727273, 0.9607004545454545], 
             UndirectedEdge[21, 354] -> 
             RGBColor[
              0.8661022272727272, 0.8961040909090909, 0.9791386818181818], 
             UndirectedEdge[125, 269] -> 
             RGBColor[
              0.9821161363636364, 0.9846753636363637, 0.8476497272727272], 
             UndirectedEdge[241, 304] -> 
             RGBColor[0.6595294545454544, 0.7276904999999999, 0.9503305], 
             UndirectedEdge[93, 456] -> 
             RGBColor[
              0.9888527727272727, 0.9881327272727274, 0.7235053181818183], 
             UndirectedEdge[295, 455] -> 
             RGBColor[0.7522105909090908, 0.806692, 0.9758467272727273], 
             UndirectedEdge[185, 386] -> 
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181], 
             UndirectedEdge[233, 400] -> 
             RGBColor[
              0.9850256818181817, 0.9758467272727273, 0.6556048636363635], 
             UndirectedEdge[83, 317] -> 
             RGBColor[
              0.6848746363636364, 0.7522540000000001, 0.9702829545454545], 
             UndirectedEdge[88, 465] -> 
             RGBColor[
              0.9900654090909091, 0.9770589999999999, 0.5087140454545451], 
             UndirectedEdge[418, 431] -> 
             RGBColor[
              0.8308844090909091, 0.8681233636363637, 0.9519232272727272], 
             UndirectedEdge[121, 307] -> 
             RGBColor[0.6595294545454544, 0.7276904999999999, 0.9503305], 
             UndirectedEdge[64, 74] -> 
             RGBColor[
              0.9032890454545454, 0.9254948181818181, 0.9827548636363637], 
             UndirectedEdge[185, 358] -> 
             RGBColor[
              0.9593465000000001, 0.9658557272727273, 0.7640466363636365], 
             UndirectedEdge[113, 315] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[47, 91] -> 
             RGBColor[
              0.6892454545454544, 0.7563732727272726, 0.9702011818181817], 
             UndirectedEdge[158, 401] -> 
             RGBColor[
              0.9434432272727272, 0.9547480909090909, 0.8754924545454545], 
             UndirectedEdge[90, 232] -> 
             RGBColor[
              0.9397400909090909, 0.9409877272727272, 0.6946411363636362], 
             UndirectedEdge[58, 115] -> 
             RGBColor[
              0.5412670454545454, 0.6381071363636363, 0.9571282727272727], 
             UndirectedEdge[132, 494] -> 
             RGBColor[
              0.9434432272727272, 0.9547480909090909, 0.8754924545454545], 
             UndirectedEdge[167, 300] -> 
             RGBColor[
              0.8322124090909091, 0.8697001818181818, 0.9836851818181818], 
             UndirectedEdge[284, 389] -> 
             RGBColor[
              0.927408909090909, 0.9398811818181818, 0.7197896818181816], 
             UndirectedEdge[103, 233] -> 
             RGBColor[
              0.9850256818181817, 0.9758467272727273, 0.6556048636363636], 
             UndirectedEdge[172, 300] -> 
             RGBColor[
              0.9414603636363637, 0.9555905454545455, 0.974571409090909], 
             UndirectedEdge[70, 76] -> 
             RGBColor[
              0.8176590454545454, 0.8582599090909091, 0.9743103181818182], 
             UndirectedEdge[57, 73] -> 
             RGBColor[
              0.7317914999999999, 0.7626568181818181, 0.6568323181818181], 
             UndirectedEdge[287, 473] -> 
             RGBColor[0.9941475, 0.9916299090909091, 0.7308122272727275], 
             UndirectedEdge[395, 443] -> 
             RGBColor[
              0.5683341363636363, 0.6366990454545454, 0.9449590909090909], 
             UndirectedEdge[100, 397] -> 
             RGBColor[
              0.9942714545454545, 0.9901555454545454, 0.6178613636363632], 
             UndirectedEdge[57, 234] -> 
             RGBColor[
              0.7218260454545454, 0.7290409999999999, 0.6181184090909091], 
             UndirectedEdge[343, 403] -> 
             RGBColor[
              0.7764321818181817, 0.8256140909090908, 0.9782609090909091], 
             UndirectedEdge[105, 425] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[133, 423] -> 
             RGBColor[
              0.9896864545454546, 0.9762484545454546, 0.4674671818181819], 
             UndirectedEdge[92, 494] -> 
             RGBColor[0.9404186818181818, 0.9534973636363636, 0.925617], 
             UndirectedEdge[51, 100] -> 
             RGBColor[
              0.9597254545454545, 0.9666662727272728, 0.8052934999999998], 
             UndirectedEdge[6, 347] -> 
             RGBColor[
              0.8374970909090909, 0.8730550909090908, 0.9407296818181818], 
             UndirectedEdge[333, 461] -> 
             RGBColor[
              0.8632309545454545, 0.8926025454545454, 0.9180815909090909], 
             UndirectedEdge[291, 394] -> 
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181], 
             UndirectedEdge[143, 386] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[123, 437] -> 
             RGBColor[
              0.6314042727272726, 0.7071885454545455, 0.9667308181818182], 
             UndirectedEdge[72, 453] -> 
             RGBColor[
              0.9937685454545454, 0.9908193636363636, 0.6895653636363634], 
             UndirectedEdge[391, 478] -> 
             RGBColor[0.9466635, 0.8152835000000002, 0.49979522727272735`], 
             UndirectedEdge[328, 464] -> 
             RGBColor[
              0.7660006818181819, 0.8118681818181819, 0.704872227272727], 
             UndirectedEdge[149, 173] -> 
             RGBColor[
              0.5745030909090908, 0.6607222272727272, 0.9618584545454545], 
             UndirectedEdge[54, 186] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[355, 444] -> 
             RGBColor[0.732212590909091, 0.79, 0.9747980909090909], 
             UndirectedEdge[7, 448] -> 
             RGBColor[
              0.9592225454545454, 0.967330090909091, 0.8769975000000001], 
             UndirectedEdge[47, 416] -> 
             RGBColor[
              0.8090960454545455, 0.8508762727272727, 0.9815842272727273], 
             UndirectedEdge[48, 155] -> 
             RGBColor[
              0.7808844999999999, 0.8282732727272726, 0.9474796818181818], 
             UndirectedEdge[346, 486] -> 
             RGBColor[
              0.8564339999999999, 0.8886222727272728, 0.9860993636363635], 
             UndirectedEdge[24, 491] -> 
             RGBColor[
              0.9356874090909091, 0.8316484545454543, 0.6028914545454545], 
             UndirectedEdge[321, 373] -> 
             RGBColor[
              0.9857042727272727, 0.9883563636363637, 0.8865807272727273], 
             UndirectedEdge[209, 231] -> 
             RGBColor[
              0.8351165454545455, 0.5870346363636363, 0.5846868636363636], 
             UndirectedEdge[210, 393] -> 
             RGBColor[
              0.7671375454545455, 0.8142998181818182, 0.8286128181818184], 
             UndirectedEdge[188, 409] -> 
             RGBColor[
              0.6978878636363637, 0.7566523636363636, 0.8235556363636365], 
             UndirectedEdge[307, 427] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[178, 186] -> 
             RGBColor[
              0.9239607727272727, 0.9284057272727272, 0.6931360909090909], 
             UndirectedEdge[328, 475] -> 
             RGBColor[
              0.9818611363636364, 0.9823904545454546, 0.6934519999999997], 
             UndirectedEdge[213, 337] -> 
             RGBColor[
              0.9887288181818181, 0.9896070909090909, 0.8364561818181819], 
             UndirectedEdge[384, 458] -> 
             RGBColor[
              0.8176590454545454, 0.8582599090909091, 0.9743103181818182], 
             UndirectedEdge[87, 473] -> 
             RGBColor[
              0.9895624999999999, 0.9777228181818182, 0.5804180454545455], 
             UndirectedEdge[112, 440] -> 
             RGBColor[
              0.5892456363636362, 0.6766730909090908, 0.9613140909090909], 
             UndirectedEdge[237, 429] -> 
             RGBColor[
              0.8941428181818182, 0.5559972727272727, 0.5491240454545454], 
             UndirectedEdge[109, 230] -> 
             RGBColor[
              0.9326543181818181, 0.7579125909090908, 0.5144297727272726], 
             UndirectedEdge[89, 262] -> 
             RGBColor[0.8527855454545454, 0.6966388636363635, 0.6005805], 
             UndirectedEdge[280, 383] -> 
             RGBColor[
              0.7227151818181817, 0.7814855454545454, 0.9546144999999999], 
             UndirectedEdge[196, 489] -> 
             RGBColor[
              0.8390093636363636, 0.8736804545454545, 0.9156674090909092], 
             UndirectedEdge[279, 459] -> 
             RGBColor[
              0.7413592272727272, 0.7933718181818181, 0.8265834545454547], 
             UndirectedEdge[191, 423] -> 
             RGBColor[
              0.9015891818181818, 0.5490447272727272, 0.28189236363636355`], 
             UndirectedEdge[116, 165] -> 
             RGBColor[
              0.7634669545454544, 0.8151454545454545, 0.977058909090909], 
             UndirectedEdge[176, 313] -> 
             RGBColor[
              0.842033909090909, 0.8749311818181817, 0.8655428636363637], 
             UndirectedEdge[180, 490] -> 
             RGBColor[0.642359, 0.720535, 0.964988], UndirectedEdge[17, 498] -> 
             RGBColor[0.8824544999999999, 0.6247806363636363, 0.589202], 
             UndirectedEdge[108, 364] -> 
             RGBColor[
              0.9821161363636364, 0.9846753636363637, 0.8476497272727272], 
             UndirectedEdge[29, 254] -> 
             RGBColor[
              0.9592225454545454, 0.967330090909091, 0.8769975000000001], 
             UndirectedEdge[7, 261] -> 
             RGBColor[
              0.9795970454545455, 0.9441070000000001, 0.5417041363636366], 
             UndirectedEdge[122, 224] -> 
             RGBColor[
              0.6665805909090909, 0.739457090909091, 0.9674021818181817], 
             UndirectedEdge[116, 386] -> 
             RGBColor[
              0.8859402727272727, 0.9108992727272727, 0.9455580454545454], 
             UndirectedEdge[8, 439] -> 
             RGBColor[
              0.4590861818181818, 0.5508086818181818, 0.9540728636363636], 
             UndirectedEdge[226, 488] -> 
             RGBColor[
              0.6742670909090909, 0.7381793181818181, 0.9028811363636364], 
             UndirectedEdge[64, 170] -> 
             RGBColor[
              0.916514409090909, 0.9353582727272727, 0.9603677727272727], 
             UndirectedEdge[178, 313] -> 
             RGBColor[
              0.8383307727272726, 0.8611708181818181, 0.6846915454545452], 
             UndirectedEdge[81, 251] -> 
             RGBColor[
              0.9942714545454545, 0.9901555454545454, 0.617861363636364], 
             UndirectedEdge[186, 288] -> 
             RGBColor[
              0.8462828636363636, 0.8802669999999999, 0.9852004090909091], 
             UndirectedEdge[45, 118] -> 
             RGBColor[
              0.9903650454545454, 0.988758090909091, 0.6984430454545456], 
             UndirectedEdge[224, 330] -> 
             RGBColor[
              0.6665805909090909, 0.739457090909091, 0.9674021818181817], 
             UndirectedEdge[35, 410] -> 
             RGBColor[
              0.6314042727272726, 0.7071885454545455, 0.9667308181818182], 
             UndirectedEdge[163, 379] -> 
             RGBColor[
              0.938906409090909, 0.9528719999999999, 0.9506792727272727], 
             UndirectedEdge[181, 443] -> 
             RGBColor[
              0.9755034545454545, 0.9797436363636364, 0.8588432727272728], 
             UndirectedEdge[167, 235] -> 
             RGBColor[0.8660005, 0.8915683636363636, 0.7137593181818179], 
             UndirectedEdge[202, 279] -> 
             RGBColor[
              0.7413592272727272, 0.7933718181818181, 0.8265834545454547], 
             UndirectedEdge[242, 310] -> 
             RGBColor[
              0.8176590454545454, 0.8582599090909091, 0.9743103181818182], 
             UndirectedEdge[299, 482] -> 
             RGBColor[
              0.9568521363636364, 0.9155595454545454, 0.6199210909090909], 
             UndirectedEdge[56, 110] -> 
             RGBColor[
              0.8484933181818182, 0.8821137272727273, 0.9655309545454545], 
             UndirectedEdge[125, 419] -> 
             RGBColor[
              0.9917533636363636, 0.9908578181818182, 0.7863316363636363], 
             UndirectedEdge[262, 448] -> 
             RGBColor[0.9001235, 0.7343848636363635, 0.6050956363636364], 
             UndirectedEdge[95, 212] -> 
             RGBColor[
              0.9724789090909091, 0.9784929090909091, 0.9089678181818182], 
             UndirectedEdge[32, 260] -> 
             RGBColor[0.956198, 0.9660793636363636, 0.9271220454545455], 
             UndirectedEdge[421, 430] -> 
             RGBColor[
              0.872714909090909, 0.9010358181818181, 0.9679451363636363], 
             UndirectedEdge[129, 346] -> 
             RGBColor[
              0.5547887272727272, 0.6436466363636363, 0.9606022727272727], 
             UndirectedEdge[16, 17] -> 
             RGBColor[
              0.7579909090909089, 0.8109279999999999, 0.9768274545454545], 
             UndirectedEdge[153, 466] -> 
             RGBColor[
              0.9285457727272727, 0.9423128181818181, 0.8435302727272729], 
             UndirectedEdge[244, 391] -> 
             RGBColor[
              0.9436389545454545, 0.8140327727272729, 0.5499197727272728], 
             UndirectedEdge[218, 406] -> 
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273], 
             UndirectedEdge[99, 288] -> 
             RGBColor[
              0.8875097272727273, 0.9129128181818182, 0.9812498181818182], 
             UndirectedEdge[399, 481] -> 
             RGBColor[
              0.9592225454545454, 0.967330090909091, 0.8769975000000001], 
             UndirectedEdge[278, 451] -> 
             RGBColor[
              0.7293278636363636, 0.7864172727272727, 0.9434209545454545], 
             UndirectedEdge[179, 327] -> 
             RGBColor[
              0.6727548181818181, 0.7375539545454546, 0.9279434090909091], 
             UndirectedEdge[38, 473] -> 
             RGBColor[
              0.6772916363636363, 0.7394300454545455, 0.852756590909091], 
             UndirectedEdge[17, 176] -> 
             RGBColor[
              0.9592225454545454, 0.967330090909091, 0.8769975000000001], 
             UndirectedEdge[186, 373] -> 
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273], 
             UndirectedEdge[399, 496] -> 
             RGBColor[
              0.7404773636363635, 0.7932250909090909, 0.857040590909091], 
             UndirectedEdge[116, 358] -> 
             RGBColor[0.8906010454545454, 0.911301, 0.7574203636363638], 
             UndirectedEdge[71, 135] -> 
             RGBColor[0.978413, 0.970915, 0.6667984090909089], 
             UndirectedEdge[53, 374] -> 
             RGBColor[
              0.9414603636363637, 0.9555905454545455, 0.974571409090909], 
             UndirectedEdge[228, 409] -> 
             RGBColor[
              0.6202379545454545, 0.4139561818181817, 0.5662172727272727], 
             UndirectedEdge[440, 471] -> 
             RGBColor[
              0.7374528181818181, 0.7919743636363636, 0.9071651363636364], 
             UndirectedEdge[403, 471] -> 
             RGBColor[
              0.8390093636363636, 0.8736804545454545, 0.9156674090909092], 
             UndirectedEdge[63, 166] -> 
             RGBColor[
              0.7634669545454544, 0.8151454545454545, 0.977058909090909], 
             UndirectedEdge[159, 272] -> 
             RGBColor[
              0.9658662272727272, 0.9735611818181817, 0.9201613636363637], 
             UndirectedEdge[130, 351] -> 
             RGBColor[
              0.9658662272727272, 0.9735611818181817, 0.9201613636363637], 
             UndirectedEdge[113, 378] -> 
             RGBColor[
              0.9256810454545454, 0.9430085454545454, 0.9730663636363637], 
             UndirectedEdge[145, 417] -> 
             RGBColor[
              0.9688907727272726, 0.9748119090909091, 0.8700368181818183], 
             UndirectedEdge[38, 354] -> 
             RGBColor[
              0.6529167727272727, 0.7227587727272726, 0.9615240454545455], 
             UndirectedEdge[334, 446] -> 
             RGBColor[
              0.9414603636363637, 0.9555905454545455, 0.974571409090909], 
             UndirectedEdge[305, 310] -> 
             RGBColor[
              0.9697726363636363, 0.9749586363636363, 0.839579681818182], 
             UndirectedEdge[338, 383] -> 
             RGBColor[
              0.9756274090909092, 0.9782692727272728, 0.7458924090909093], 
             UndirectedEdge[243, 477] -> 
             RGBColor[
              0.8176590454545454, 0.8582599090909091, 0.9743103181818182], 
             UndirectedEdge[38, 221] -> 
             RGBColor[
              0.6529167727272727, 0.7227587727272726, 0.9615240454545455], 
             UndirectedEdge[330, 357] -> 
             RGBColor[
              0.767989909090909, 0.8192740000000001, 0.9773517727272727], 
             UndirectedEdge[48, 365] -> 
             RGBColor[
              0.7733826818181817, 0.7708969999999999, 0.6221771363636364], 
             UndirectedEdge[384, 411] -> 
             RGBColor[
              0.960204909090909, 0.9442436363636364, 0.6698285454545454], 
             UndirectedEdge[38, 436] -> 
             RGBColor[
              0.6586403181818181, 0.6752459545454544, 0.613834409090909], 
             UndirectedEdge[117, 155] -> 
             RGBColor[0.6858565, 0.7496978181818181, 0.9403931363636363], 
             UndirectedEdge[68, 286] -> 
             RGBColor[
              0.5860963181818182, 0.6484385909090908, 0.8473851818181819], 
             UndirectedEdge[378, 380] -> 
             RGBColor[
              0.9322937272727272, 0.9479402727272728, 0.9618728181818181], 
             UndirectedEdge[12, 285] -> 
             RGBColor[0.8889648181818182, 0.91215, 0.8954334999999999], 
             UndirectedEdge[93, 432] -> 
             RGBColor[
              0.9800429545454545, 0.9590388181818181, 0.636247909090909], 
             UndirectedEdge[340, 499] -> 
             RGBColor[0.7922115, 0.8381960909090909, 0.9797659545454545], 
             UndirectedEdge[389, 456] -> 
             RGBColor[
              0.993134590909091, 0.9877239090909091, 0.49412077272727273`], 
             UndirectedEdge[390, 451] -> 
             RGBColor[
              0.7413592272727272, 0.7933718181818181, 0.8265834545454547], 
             UndirectedEdge[92, 485] -> 
             RGBColor[
              0.6939814545454546, 0.7552549090909091, 0.9041373181818182], 
             UndirectedEdge[293, 471] -> 
             RGBColor[
              0.9246393636363636, 0.9409153636363636, 0.9241119545454546], 
             UndirectedEdge[111, 359] -> 
             RGBColor[0.7359405454545453, 0.791349, 0.9322274090909091], 
             UndirectedEdge[357, 441] -> 
             RGBColor[
              0.9322937272727272, 0.9479402727272728, 0.9618728181818181], 
             UndirectedEdge[52, 268] -> 
             RGBColor[
              0.9887288181818181, 0.9896070909090909, 0.8364561818181817], 
             UndirectedEdge[30, 311] -> 
             RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 
             UndirectedEdge[164, 486] -> 
             RGBColor[
              0.7579909090909089, 0.8109279999999999, 0.9768274545454545], 
             UndirectedEdge[194, 290] -> 
             RGBColor[
              0.8322124090909091, 0.8697001818181818, 0.9836851818181818], 
             UndirectedEdge[238, 445] -> 
             RGBColor[
              0.6978878636363637, 0.7566523636363636, 0.8235556363636365], 
             UndirectedEdge[269, 406] -> 
             RGBColor[
              0.916514409090909, 0.9353582727272727, 0.9603677727272727], 
             UndirectedEdge[99, 341] -> 
             RGBColor[
              0.9658662272727272, 0.9735611818181817, 0.9201613636363637], 
             UndirectedEdge[41, 457] -> 
             RGBColor[
              0.8617186818181818, 0.8919771818181819, 0.9431438636363636], 
             UndirectedEdge[217, 292] -> 
             RGBColor[
              0.8462828636363636, 0.8802669999999999, 0.9852004090909091], 
             UndirectedEdge[176, 299] -> 
             RGBColor[
              0.9746143181818181, 0.9272990909090909, 0.5223471818181818], 
             UndirectedEdge[218, 314] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[355, 486] -> 
             RGBColor[0.732212590909091, 0.79, 0.9747980909090909], 
             UndirectedEdge[213, 420] -> 
             RGBColor[
              0.9857042727272727, 0.9883563636363637, 0.8865807272727273], 
             UndirectedEdge[299, 407] -> 
             RGBColor[
              0.8718257727272727, 0.8485912727272726, 0.6314490454545454], 
             UndirectedEdge[201, 314] -> 
             RGBColor[
              0.9896106818181818, 0.9897538181818182, 0.8059990454545456], 
             UndirectedEdge[160, 300] -> 
             RGBColor[
              0.9555194090909092, 0.9535697272727273, 0.6961461818181818], 
             UndirectedEdge[21, 200] -> 
             RGBColor[
              0.8859402727272727, 0.9108992727272727, 0.9455580454545454], 
             UndirectedEdge[25, 180] -> 
             RGBColor[
              0.767989909090909, 0.8192740000000001, 0.9773517727272727], 
             UndirectedEdge[45, 185] -> 
             RGBColor[
              0.9593465000000001, 0.9658557272727273, 0.7640466363636365], 
             UndirectedEdge[191, 226] -> 
             RGBColor[
              0.9022677727272728, 0.5615543636363636, 0.5128682272727273], 
             UndirectedEdge[50, 82] -> 
             RGBColor[
              0.5502814999999999, 0.6418001363636363, 0.9594442727272727], 
             UndirectedEdge[22, 491] -> 
             RGBColor[
              0.7006613181818181, 0.6451299090909088, 0.6010887727272727], 
             UndirectedEdge[99, 277] -> 
             RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 
             UndirectedEdge[17, 391] -> 
             RGBColor[
              0.9126204090909091, 0.7911304090909093, 0.6155233636363636], 
             UndirectedEdge[211, 362] -> 
             RGBColor[0.8662555, 0.8938532727272728, 0.8679570454545456], 
             UndirectedEdge[4, 162] -> 
             RGBColor[
              0.8178123181818182, 0.8560090909090909, 0.8631286818181818], 
             UndirectedEdge[259, 444] -> 
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181], 
             UndirectedEdge[347, 382] -> 
             RGBColor[
              0.8176590454545454, 0.8582599090909091, 0.9743103181818182], 
             UndirectedEdge[66, 179] -> 
             RGBColor[
              0.5018383181818181, 0.6039559545454545, 0.954615909090909], 
             UndirectedEdge[343, 471] -> 
             RGBColor[
              0.9246393636363636, 0.9409153636363636, 0.9241119545454546], 
             UndirectedEdge[97, 322] -> 
             RGBColor[
              0.526059909090909, 0.6228780454545454, 0.9570300909090909], 
             UndirectedEdge[363, 381] -> 
             RGBColor[
              0.8667584090909091, 0.8931894545454545, 0.7962530454545452], 
             UndirectedEdge[238, 471] -> 
             RGBColor[
              0.9911229545454545, 0.9903791818181817, 0.7809367727272729], 
             UndirectedEdge[40, 285] -> 
             RGBColor[
              0.6892454545454544, 0.7563732727272726, 0.9702011818181817], 
             UndirectedEdge[70, 208] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[84, 448] -> 
             RGBColor[
              0.9348476818181818, 0.9506588181818182, 0.9857649545454545], 
             UndirectedEdge[152, 195] -> 
             RGBColor[
              0.9760063636363636, 0.9790798181818181, 0.7871392727272726], 
             UndirectedEdge[93, 308] -> 
             RGBColor[
              0.8374970909090909, 0.8730550909090908, 0.9407296818181818], 
             UndirectedEdge[255, 478] -> 
             RGBColor[
              0.9845797727272727, 0.960914909090909, 0.561061090909091], 
             UndirectedEdge[112, 293] -> 
             RGBColor[
              0.7764321818181817, 0.8256140909090908, 0.9782609090909091], 
             UndirectedEdge[87, 184] -> 
             RGBColor[
              0.9555194090909092, 0.9535697272727273, 0.6961461818181818], 
             UndirectedEdge[149, 323] -> 
             RGBColor[
              0.8406546818181817, 0.8760402727272727, 0.9845943181818182], 
             UndirectedEdge[272, 497] -> 
             RGBColor[
              0.9765725000000001, 0.9428562727272729, 0.5918286818181819], 
             UndirectedEdge[80, 471] -> 
             RGBColor[
              0.6939814545454546, 0.7552549090909091, 0.9041373181818182], 
             UndirectedEdge[339, 344] -> 
             RGBColor[
              0.9511285909090909, 0.9630723636363636, 0.9676107272727272], 
             UndirectedEdge[137, 393] -> 
             RGBColor[
              0.9763853181818182, 0.9798903636363636, 0.8283861363636366], 
             UndirectedEdge[11, 316] -> 
             RGBColor[
              0.6590963181818181, 0.7313259999999999, 0.9682535909090909], 
             UndirectedEdge[88, 423] -> 
             RGBColor[
              0.9858593636363636, 0.9639624545454545, 0.3995667272727271], 
             UndirectedEdge[70, 351] -> 
             RGBColor[
              0.9658662272727272, 0.9735611818181817, 0.9201613636363637], 
             UndirectedEdge[55, 298] -> 
             RGBColor[
              0.916514409090909, 0.9353582727272727, 0.9603677727272727], 
             UndirectedEdge[428, 437] -> 
             RGBColor[0.6858565, 0.7496978181818181, 0.9403931363636363], 
             UndirectedEdge[90, 137] -> 
             RGBColor[
              0.9256810454545454, 0.9430085454545454, 0.9730663636363637], 
             UndirectedEdge[344, 439] -> 
             RGBColor[
              0.8484933181818182, 0.8821137272727273, 0.9655309545454545], 
             UndirectedEdge[93, 274] -> 
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181], 
             UndirectedEdge[60, 434] -> 
             RGBColor[
              0.6392455454545455, 0.7165231818181819, 0.9657576363636363], 
             UndirectedEdge[54, 244] -> 
             RGBColor[
              0.9724789090909091, 0.9784929090909091, 0.9089678181818182], 
             UndirectedEdge[243, 318] -> 
             RGBColor[
              0.7418808181818182, 0.7974818181818182, 0.9678374090909091], 
             UndirectedEdge[384, 402] -> 
             RGBColor[
              0.9032890454545454, 0.9254948181818181, 0.9827548636363637], 
             UndirectedEdge[83, 233] -> 
             RGBColor[0.9073477727272727, 0.927708, 0.9476691818181818], 
             UndirectedEdge[153, 201] -> 
             RGBColor[
              0.9285457727272727, 0.9423128181818181, 0.8435302727272729], 
             UndirectedEdge[275, 331] -> 
             RGBColor[0.9822400909090909, 0.983201, 0.7346988636363638], 
             UndirectedEdge[312, 327] -> 
             RGBColor[
              0.8374970909090909, 0.8730550909090908, 0.9407296818181818], 
             UndirectedEdge[181, 370] -> 
             RGBColor[0.8662555, 0.8938532727272728, 0.8679570454545456], 
             UndirectedEdge[32, 245] -> 
             RGBColor[0.990744, 0.9895686363636363, 0.7396899090909089], 
             UndirectedEdge[176, 391] -> 
             RGBColor[0.9466635, 0.8152835000000002, 0.4997952272727274], 
             UndirectedEdge[148, 232] -> 
             RGBColor[
              0.8867739545454545, 0.8990149999999999, 0.689519909090909], 
             UndirectedEdge[430, 477] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[7, 475] -> 
             RGBColor[
              0.9821161363636364, 0.9846753636363637, 0.8476497272727272], 
             UndirectedEdge[15, 50] -> 
             RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 
             UndirectedEdge[168, 395] -> 
             RGBColor[
              0.5869781818181818, 0.6485853181818182, 0.8169280454545457], 
             UndirectedEdge[97, 440] -> 
             RGBColor[
              0.42450336363636354`, 0.5411719545454544, 0.9485278181818182], 
             UndirectedEdge[71, 308] -> 
             RGBColor[
              0.8383307727272726, 0.8611708181818181, 0.6846915454545452], 
             UndirectedEdge[253, 436] -> 
             RGBColor[
              0.9715897727272726, 0.9260483636363637, 0.5724717272727273], 
             UndirectedEdge[13, 430] -> 
             RGBColor[
              0.916404409090909, 0.746798409090909, 0.5869414090909091], 
             UndirectedEdge[209, 233] -> 
             RGBColor[0.9073477727272727, 0.927708, 0.9476691818181818], 
             UndirectedEdge[254, 350] -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             UndirectedEdge[115, 268] -> 
             RGBColor[
              0.8163000454545455, 0.8553837272727274, 0.8881909545454545], 
             UndirectedEdge[42, 468] -> 
             RGBColor[
              0.6906549545454544, 0.7564899999999999, 0.9712636818181818], 
             UndirectedEdge[51, 60] -> 
             RGBColor[0.732212590909091, 0.79, 0.9747980909090909], 
             UndirectedEdge[331, 348] -> 
             RGBColor[
              0.993134590909091, 0.9877239090909091, 0.49412077272727273`], 
             UndirectedEdge[310, 406] -> 
             RGBColor[
              0.9032890454545454, 0.9254948181818181, 0.9827548636363637], 
             UndirectedEdge[70, 130] -> 
             RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 
             UndirectedEdge[83, 440] -> 
             RGBColor[
              0.6590963181818181, 0.7313259999999999, 0.9682535909090909], 
             UndirectedEdge[100, 374] -> 
             RGBColor[
              0.9597254545454545, 0.9666662727272728, 0.8052934999999998], 
             UndirectedEdge[207, 374] -> 
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181], 
             UndirectedEdge[51, 324] -> 
             RGBColor[
              0.9593465000000001, 0.9658557272727273, 0.7640466363636365], 
             UndirectedEdge[164, 180] -> 
             RGBColor[
              0.6165806818181817, 0.6996069999999999, 0.9629586363636363], 
             UndirectedEdge[56, 132] -> 
             RGBColor[0.8662555, 0.8938532727272728, 0.8679570454545456], 
             UndirectedEdge[30, 423] -> 
             RGBColor[
              0.9651876363636362, 0.9610515454545454, 0.6891854999999999], 
             UndirectedEdge[104, 379] -> 
             RGBColor[
              0.9434432272727272, 0.9547480909090909, 0.8754924545454545], 
             UndirectedEdge[324, 457] -> 
             RGBColor[
              0.9888527727272727, 0.9881327272727274, 0.7235053181818183], 
             UndirectedEdge[283, 459] -> 
             RGBColor[
              0.6978878636363637, 0.7566523636363636, 0.8235556363636365], 
             UndirectedEdge[128, 245] -> 
             RGBColor[
              0.9937685454545454, 0.9908193636363636, 0.6895653636363634], 
             UndirectedEdge[34, 62] -> 
             RGBColor[
              0.6150239545454546, 0.697601090909091, 0.9633434545454544], 
             UndirectedEdge[320, 424] -> 
             RGBColor[
              0.9239607727272727, 0.9284057272727272, 0.6931360909090908], 
             UndirectedEdge[111, 351] -> 
             RGBColor[
              0.9857042727272727, 0.9883563636363637, 0.8865807272727273], 
             UndirectedEdge[79, 316] -> 
             RGBColor[
              0.7413592272727272, 0.7933718181818181, 0.8265834545454547], 
             UndirectedEdge[43, 250] -> 
             RGBColor[
              0.900735090909091, 0.9227762727272728, 0.9588627272727273], 
             UndirectedEdge[116, 313] -> 
             RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 
             UndirectedEdge[87, 436] -> 
             RGBColor[
              0.9709111818181818, 0.9135387272727272, 0.34149586363636353`], 
             UndirectedEdge[280, 393] -> 
             RGBColor[
              0.7413592272727272, 0.7933718181818181, 0.8265834545454547], 
             UndirectedEdge[295, 321] -> 
             RGBColor[
              0.9246393636363636, 0.9409153636363636, 0.9241119545454546], 
             UndirectedEdge[131, 186] -> 
             RGBColor[
              0.9032890454545454, 0.9254948181818181, 0.9827548636363637], 
             UndirectedEdge[165, 313] -> 
             RGBColor[
              0.7150237727272727, 0.7773012727272727, 0.9722305454545455], 
             UndirectedEdge[140, 270] -> 
             RGBColor[
              0.8178123181818182, 0.8560090909090909, 0.8631286818181818], 
             UndirectedEdge[322, 445] -> 
             RGBColor[
              0.5457742727272727, 0.6399536363636363, 0.9582862727272727], 
             UndirectedEdge[112, 463] -> 
             RGBColor[
              0.8176590454545454, 0.8582599090909091, 0.9743103181818182], 
             UndirectedEdge[115, 223] -> 
             RGBColor[
              0.7150237727272727, 0.7773012727272728, 0.9722305454545455], 
             UndirectedEdge[102, 451] -> 
             RGBColor[
              0.6590963181818181, 0.7313259999999999, 0.9682535909090909], 
             UndirectedEdge[148, 267] -> 
             RGBColor[
              0.8313780454545454, 0.6798301363636362, 0.5984693636363636], 
             UndirectedEdge[447, 500] -> 
             RGBColor[
              0.40074636363636346`, 0.5215280909090907, 0.9467561818181818], 
             UndirectedEdge[238, 293] -> 
             RGBColor[
              0.9285457727272727, 0.9423128181818181, 0.8435302727272729], 
             UndirectedEdge[56, 457] -> 
             RGBColor[
              0.8617186818181818, 0.8919771818181819, 0.9431438636363636], 
             UndirectedEdge[204, 331] -> 
             RGBColor[
              0.9120085454545455, 0.9281097272727273, 0.7595315000000002], 
             UndirectedEdge[66, 260] -> 
             RGBColor[0.7837692272727272, 0.831856, 0.9788568181818181], 
             UndirectedEdge[225, 424] -> 
             RGBColor[
              0.9718003181818182, 0.9659832727272727, 0.6779919545454545], 
             UndirectedEdge[178, 244] -> 
             RGBColor[
              0.9865379545454545, 0.9764720909090909, 0.6305425909090908], 
             UndirectedEdge[139, 247] -> 
             RGBColor[
              0.6757793636363636, 0.7388046818181818, 0.8778188636363635], 
             UndirectedEdge[244, 448] -> 
             RGBColor[0.956198, 0.9660793636363636, 0.9271220454545455], 
             UndirectedEdge[259, 275] -> 
             RGBColor[
              0.9775793181818182, 0.9827992727272727, 0.9228365454545454], 
             UndirectedEdge[282, 406] -> 
             RGBColor[0.8778414999999999, 0.9054309999999999, 0.9882105], 
             UndirectedEdge[286, 357] -> 
             RGBColor[
              0.9434432272727272, 0.9547480909090909, 0.8754924545454545], 
             UndirectedEdge[206, 396] -> 
             RGBColor[
              0.6408022727272726, 0.7185290909090908, 0.9653728181818182], 
             UndirectedEdge[154, 295] -> 
             RGBColor[
              0.6314042727272726, 0.7071885454545455, 0.9667308181818182], 
             UndirectedEdge[410, 428] -> 
             RGBColor[
              0.916514409090909, 0.9353582727272727, 0.9603677727272727], 
             UndirectedEdge[104, 147] -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909092], 
             UndirectedEdge[32, 255] -> 
             RGBColor[
              0.9815552272727273, 0.9596641818181818, 0.6111856363636363], 
             UndirectedEdge[165, 498] -> 
             RGBColor[
              0.7894874545454544, 0.5513038181818181, 0.5801615454545455], 
             UndirectedEdge[248, 439] -> 
             RGBColor[
              0.7634669545454544, 0.8151454545454545, 0.977058909090909], 
             UndirectedEdge[141, 389] -> 
             RGBColor[
              0.9927556363636364, 0.9869133636363637, 0.4528739090909087], 
             UndirectedEdge[328, 478] -> 
             RGBColor[
              0.9930106363636364, 0.9891982727272728, 0.6070716363636363], 
             UndirectedEdge[178, 261] -> 
             RGBColor[
              0.9758939090909091, 0.9303466363636365, 0.36085281818181825`], 
             UndirectedEdge[120, 315] -> 
             RGBColor[
              0.9724789090909091, 0.9784929090909091, 0.9089678181818182], 
             UndirectedEdge[47, 136] -> 
             RGBColor[
              0.8251295909090908, 0.6514573636363634, 0.5932554999999999], 
             UndirectedEdge[74, 144] -> 
             RGBColor[
              0.9348476818181818, 0.9506588181818182, 0.9857649545454545], 
             UndirectedEdge[165, 361] -> 
             RGBColor[
              0.8551059999999999, 0.8870454545454545, 0.954337409090909], 
             UndirectedEdge[32, 482] -> 
             RGBColor[
              0.9724789090909091, 0.9784929090909091, 0.9089678181818182], 
             UndirectedEdge[67, 119] -> 
             RGBColor[
              0.6392455454545455, 0.7165231818181819, 0.9657576363636363], 
             UndirectedEdge[97, 326] -> 
             RGBColor[
              0.4760599999999998, 0.5830279545454544, 0.9525865454545455], 
             UndirectedEdge[409, 430] -> 
             RGBColor[
              0.6792438181818181, 0.744766090909091, 0.9515866818181817], 
             UndirectedEdge[113, 190] -> 
             RGBColor[
              0.9752484545454545, 0.9774587272727273, 0.7046455454545453], 
             UndirectedEdge[292, 496] -> 
             RGBColor[
              0.6590963181818181, 0.7313259999999999, 0.9682535909090909], 
             UndirectedEdge[15, 82] -> 
             RGBColor[
              0.5502814999999999, 0.6418001363636363, 0.9594442727272727], 
             UndirectedEdge[340, 414] -> 
             RGBColor[
              0.9322937272727272, 0.9479402727272728, 0.9618728181818181], 
             UndirectedEdge[149, 282] -> 
             RGBColor[
              0.8406546818181817, 0.8760402727272727, 0.9845943181818182], 
             UndirectedEdge[330, 368] -> 
             RGBColor[
              0.8000501363636363, 0.8442695454545455, 0.9607025909090909], 
             UndirectedEdge[331, 431] -> 
             RGBColor[0.9822400909090909, 0.983201, 0.7346988636363638], 
             UndirectedEdge[4, 488] -> 
             RGBColor[
              0.6772916363636363, 0.7394300454545454, 0.852756590909091], 
             UndirectedEdge[87, 409] -> 
             RGBColor[
              0.6933028636363636, 0.7427452727272728, 0.6731614545454545], 
             UndirectedEdge[440, 445] -> 
             RGBColor[0.44421772727272724`, 0.5582475454545455, 0.949784], 
             UndirectedEdge[55, 200] -> 
             RGBColor[
              0.9775793181818182, 0.9827992727272727, 0.9228365454545454], 
             UndirectedEdge[64, 215] -> 
             RGBColor[
              0.7264322727272725, 0.7857639999999999, 0.9738173636363636], 
             UndirectedEdge[167, 493] -> 
             RGBColor[
              0.8322124090909091, 0.8697001818181818, 0.9836851818181818], 
             UndirectedEdge[153, 470] -> 
             RGBColor[
              0.9032890454545454, 0.9254948181818181, 0.9827548636363637], 
             UndirectedEdge[185, 187] -> 
             RGBColor[
              0.9601044090909091, 0.9674768181818182, 0.8465403636363638], 
             UndirectedEdge[18, 310] -> 
             RGBColor[
              0.9673784999999999, 0.9741865454545455, 0.8950990909090908], 
             UndirectedEdge[226, 366] -> 
             RGBColor[
              0.8874525454545454, 0.9115246363636363, 0.9204957727272727], 
             UndirectedEdge[333, 361] -> 
             RGBColor[
              0.8551059999999999, 0.8870454545454545, 0.954337409090909], 
             UndirectedEdge[236, 300] -> 
             RGBColor[
              0.9577102727272727, 0.9667047272727274, 0.9020597727272726], 
             UndirectedEdge[161, 335] -> 
             RGBColor[
              0.9347573636363636, 0.9241798181818182, 0.6752841818181817], 
             UndirectedEdge[61, 397] -> 
             RGBColor[
              0.9826190454545454, 0.9840115454545455, 0.775945727272727], 
             UndirectedEdge[393, 480] -> 
             RGBColor[
              0.9763853181818182, 0.9798903636363636, 0.8283861363636366], 
             UndirectedEdge[349, 378] -> 
             RGBColor[
              0.9434432272727272, 0.9547480909090909, 0.8754924545454545], 
             UndirectedEdge[97, 163] -> 
             RGBColor[
              0.6727548181818181, 0.7375539545454546, 0.9279434090909091], 
             UndirectedEdge[229, 267] -> 
             RGBColor[
              0.9326543181818181, 0.7579125909090908, 0.5144297727272726], 
             UndirectedEdge[77, 287] -> 
             RGBColor[
              0.9896106818181818, 0.9897538181818182, 0.8059990454545456], 
             UndirectedEdge[41, 485] -> 
             RGBColor[
              0.5699958636363636, 0.6588757272727273, 0.9607004545454545], 
             UndirectedEdge[7, 89] -> 
             RGBColor[
              0.9118845909090909, 0.9295840909090909, 0.8724823636363637], 
             UndirectedEdge[41, 44] -> 
             RGBColor[0.8662555, 0.8938532727272728, 0.8679570454545456], 
             UndirectedEdge[147, 234] -> 
             RGBColor[
              0.9715897727272726, 0.9260483636363637, 0.5724717272727273], 
             UndirectedEdge[259, 331] -> 
             RGBColor[
              0.9888527727272727, 0.9881327272727274, 0.7235053181818183], 
             UndirectedEdge[77, 409] -> 
             RGBColor[
              0.6924691818181818, 0.7546295454545455, 0.9291995909090909], 
             UndirectedEdge[2, 334] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[315, 487] -> 
             RGBColor[
              0.6792438181818181, 0.744766090909091, 0.9515866818181817], 
             UndirectedEdge[251, 258] -> 
             RGBColor[
              0.8663794545454546, 0.8923789090909091, 0.7550061818181819], 
             UndirectedEdge[39, 96] -> 
             RGBColor[
              0.9673784999999999, 0.9741865454545455, 0.8950990909090908], 
             UndirectedEdge[219, 497] -> 
             RGBColor[
              0.9618348636363636, 0.9323674545454547, 0.6392780454545456], 
             UndirectedEdge[447, 454] -> 
             RGBColor[
              0.4760599999999998, 0.5830279545454544, 0.9525865454545455], 
             UndirectedEdge[417, 458] -> 
             RGBColor[
              0.8176590454545454, 0.8582599090909091, 0.9743103181818182], 
             UndirectedEdge[189, 422] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             UndirectedEdge[431, 444] -> 
             RGBColor[
              0.9480730454545454, 0.9605222727272728, 0.9633778636363636], 
             UndirectedEdge[161, 273] -> 
             RGBColor[
              0.9847037272727273, 0.9594405454545455, 0.44811022727272737`], 
             UndirectedEdge[109, 413] -> 
             RGBColor[
              0.6181925909090908, 0.506484818181818, 0.5808547272727271], 
             UndirectedEdge[236, 470] -> 
             RGBColor[
              0.9673784999999999, 0.9741865454545455, 0.8950990909090908], 
             UndirectedEdge[287, 436] -> 
             RGBColor[
              0.9754961818181818, 0.9274458181818181, 0.4918900454545456], 
             UndirectedEdge[253, 473] -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909092], 
             UndirectedEdge[166, 435] -> 
             RGBColor[
              0.8793275909090909, 0.9059675454545455, 0.9567515909090909], 
             UndirectedEdge[114, 312] -> 
             RGBColor[
              0.8374970909090909, 0.8730550909090908, 0.9407296818181818], 
             UndirectedEdge[222, 296] -> 
             RGBColor[
              0.9277878636363637, 0.9406917272727273, 0.7610365454545456], 
             UndirectedEdge[5, 346] -> 
             RGBColor[
              0.8661022272727272, 0.8961040909090909, 0.9791386818181818], 
             UndirectedEdge[86, 220] -> 
             RGBColor[
              0.6954937272727273, 0.7558802727272728, 0.8790750454545453], 
             UndirectedEdge[195, 255] -> 
             RGBColor[
              0.9668175909090909, 0.9491753636363636, 0.6586349999999999], 
             UndirectedEdge[313, 407] -> 
             RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 
             UndirectedEdge[224, 441] -> 
             RGBColor[
              0.8308844090909091, 0.8681233636363637, 0.9519232272727272], 
             UndirectedEdge[172, 211] -> 
             RGBColor[
              0.9755034545454545, 0.9797436363636364, 0.8588432727272728], 
             UndirectedEdge[204, 355] -> 
             RGBColor[
              0.6848746363636364, 0.7522540000000001, 0.9702829545454545], 
             UndirectedEdge[109, 180] -> 
             RGBColor[
              0.7587132727272727, 0.6230638636363635, 0.5912268181818181], 
             UndirectedEdge[96, 157] -> 
             RGBColor[
              0.9511285909090909, 0.9630723636363636, 0.9676107272727272], 
             UndirectedEdge[316, 372] -> 
             RGBColor[
              0.6581066818181818, 0.40761131818181806`, 0.5638799999999999], 
             UndirectedEdge[53, 112] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[28, 305] -> 
             RGBColor[0.982998, 0.9848220909090909, 0.8171925909090911], 
             UndirectedEdge[186, 341] -> 
             RGBColor[
              0.9246393636363636, 0.9409153636363636, 0.9241119545454546], 
             UndirectedEdge[65, 86] -> 
             RGBColor[
              0.9926352272727272, 0.9910045454545455, 0.7558745000000001], 
             UndirectedEdge[10, 390] -> 
             RGBColor[
              0.9946504090909091, 0.9909660909090909, 0.6591082272727273], 
             UndirectedEdge[48, 140] -> 
             RGBColor[
              0.7920339999999999, 0.8350810909090909, 0.8610993181818183], 
             UndirectedEdge[231, 404] -> 
             RGBColor[
              0.8397295454545454, 0.30638427272727253`, 0.1856783636363636], 
             UndirectedEdge[87, 354] -> 
             RGBColor[0.9651876363636362, 0.9610515454545454, 0.6891855], 
             UndirectedEdge[136, 434] -> 
             RGBColor[0.800908, 0.6325352727272726, 0.5908413181818182], 
             UndirectedEdge[205, 413] -> 
             RGBColor[
              0.6432485454545454, 0.7152769545454545, 0.9684847272727273], 
             UndirectedEdge[20, 490] -> 
             RGBColor[0.642359, 0.720535, 0.964988], UndirectedEdge[390, 443] -> 
             RGBColor[
              0.9763853181818182, 0.9798903636363636, 0.8283861363636366], 
             UndirectedEdge[296, 385] -> 
             RGBColor[
              0.8462828636363636, 0.8802669999999999, 0.9852004090909091], 
             UndirectedEdge[86, 290] -> 
             RGBColor[
              0.8647432272727272, 0.8932279090909091, 0.893019318181818], 
             UndirectedEdge[24, 74] -> 
             RGBColor[
              0.9511285909090909, 0.9630723636363636, 0.9676107272727272], 
             UndirectedEdge[38, 336] -> 
             RGBColor[
              0.6727548181818181, 0.7375539545454546, 0.9279434090909091], 
             UndirectedEdge[383, 443] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[14, 435] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[282, 323] -> 
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454], 
             UndirectedEdge[307, 337] -> 
             RGBColor[
              0.9755034545454545, 0.9797436363636364, 0.8588432727272728], 
             UndirectedEdge[157, 356] -> 
             RGBColor[
              0.9414603636363637, 0.9555905454545455, 0.974571409090909], 
             UndirectedEdge[166, 439] -> 
             RGBColor[
              0.7634669545454544, 0.8151454545454545, 0.977058909090909], 
             UndirectedEdge[266, 293] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[2, 260] -> 
             RGBColor[
              0.9414603636363637, 0.9555905454545455, 0.974571409090909], 
             UndirectedEdge[135, 466] -> 
             RGBColor[0.982998, 0.9848220909090909, 0.8171925909090911], 
             UndirectedEdge[60, 495] -> 
             RGBColor[0.732212590909091, 0.79, 0.9747980909090909], 
             UndirectedEdge[217, 464] -> 
             RGBColor[0.7006539545454545, 0.7648360000000001, 0.971788], 
             UndirectedEdge[435, 453] -> 
             RGBColor[
              0.9826190454545454, 0.9840115454545455, 0.775945727272727], 
             UndirectedEdge[82, 411] -> 
             RGBColor[
              0.6686057727272727, 0.7088617727272727, 0.6525483181818181], 
             UndirectedEdge[94, 193] -> 
             RGBColor[0.8620621818181818, 0.892849, 0.9867054545454546], 
             UndirectedEdge[88, 469] -> 
             RGBColor[
              0.9239607727272727, 0.9284057272727272, 0.6931360909090909], 
             UndirectedEdge[36, 76] -> 
             RGBColor[
              0.8308844090909091, 0.8681233636363637, 0.9519232272727272], 
             UndirectedEdge[163, 326] -> 
             RGBColor[0.7874971818181817, 0.833205, 0.9362861363636363], 
             UndirectedEdge[151, 472] -> 
             RGBColor[
              0.9843247727272728, 0.9586300000000001, 0.40686336363636333`], 
             UndirectedEdge[114, 138] -> 
             RGBColor[
              0.8374970909090909, 0.8730550909090908, 0.9407296818181818], 
             UndirectedEdge[448, 475] -> 
             RGBColor[
              0.9480730454545454, 0.9605222727272728, 0.9633778636363636], 
             UndirectedEdge[169, 362] -> 
             RGBColor[
              0.8667584090909091, 0.8931894545454545, 0.7962530454545452], 
             UndirectedEdge[20, 25] -> 
             RGBColor[
              0.767989909090909, 0.8192740000000001, 0.9773517727272727], 
             UndirectedEdge[113, 349] -> 
             RGBColor[
              0.9755034545454545, 0.9797436363636364, 0.8588432727272728], 
             UndirectedEdge[457, 494] -> 
             RGBColor[
              0.938906409090909, 0.9528719999999999, 0.9506792727272727], 
             UndirectedEdge[364, 452] -> 
             RGBColor[
              0.8066628181818182, 0.8492012727272727, 0.9495090454545454], 
             UndirectedEdge[351, 442] -> 
             RGBColor[0.9373905, 0.7856600000000001, 0.5447059090909092], 
             UndirectedEdge[71, 466] -> 
             RGBColor[
              0.9904443636363636, 0.9778695454545454, 0.5499609090909092], 
             UndirectedEdge[87, 285] -> 
             RGBColor[
              0.8867739545454545, 0.8990149999999999, 0.689519909090909], 
             UndirectedEdge[211, 369] -> 
             RGBColor[0.8662555, 0.8938532727272728, 0.8679570454545456], 
             UndirectedEdge[164, 316] -> 
             RGBColor[
              0.5392457272727271, 0.6368229999999999, 0.9568705454545454], 
             UndirectedEdge[27, 297] -> 
             RGBColor[
              0.9697726363636363, 0.9749586363636363, 0.839579681818182], 
             UndirectedEdge[238, 483] -> 
             RGBColor[
              0.8671373636363636, 0.8939999999999999, 0.8374999090909092], 
             UndirectedEdge[109, 164] -> 
             RGBColor[
              0.7329349545454544, 0.6021358636363634, 0.5891974545454546], 
             UndirectedEdge[83, 355] -> 
             RGBColor[
              0.6848746363636364, 0.7522540000000001, 0.9702829545454545], 
             UndirectedEdge[85, 166] -> 
             RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 
             UndirectedEdge[34, 190] -> 
             RGBColor[
              0.7660006818181819, 0.8118681818181819, 0.704872227272727], 
             UndirectedEdge[232, 383] -> 
             RGBColor[
              0.9718003181818182, 0.9659832727272727, 0.6779919545454545], 
             UndirectedEdge[185, 441] -> 
             RGBColor[
              0.9480730454545454, 0.9605222727272728, 0.9633778636363636], 
             UndirectedEdge[83, 207] -> 
             RGBColor[0.9073477727272727, 0.927708, 0.9476691818181818], 
             UndirectedEdge[138, 385] -> 
             RGBColor[
              0.7606528636363636, 0.8130320909090909, 0.9767558636363636], 
             UndirectedEdge[131, 234] -> 
             RGBColor[
              0.9502394545454544, 0.9106278181818181, 0.6311146363636364], 
             UndirectedEdge[80, 81] -> 
             RGBColor[
              0.6978878636363637, 0.7566523636363636, 0.8235556363636365], 
             UndirectedEdge[5, 486] -> 
             RGBColor[
              0.9348476818181818, 0.9506588181818182, 0.9857649545454545], 
             UndirectedEdge[94, 139] -> 
             RGBColor[
              0.9419309545454545, 0.9541227272727273, 0.9005547272727272], 
             UndirectedEdge[126, 249] -> 
             RGBColor[
              0.9256810454545454, 0.9430085454545454, 0.9730663636363637], 
             UndirectedEdge[359, 483] -> 
             RGBColor[
              0.6134672272727272, 0.6955951818181818, 0.9637282727272727], 
             UndirectedEdge[275, 404] -> 
             RGBColor[
              0.9053480909090909, 0.642125909090909, 0.5598542272727272], 
             UndirectedEdge[313, 391] -> 
             RGBColor[
              0.7954317727272727, 0.6987315000000001, 0.6040687272727273], 
             UndirectedEdge[1, 487] -> 
             RGBColor[
              0.6954937272727273, 0.7558802727272728, 0.8790750454545453], 
             UndirectedEdge[71, 172] -> 
             RGBColor[
              0.9718003181818182, 0.9659832727272727, 0.6779919545454545], 
             UndirectedEdge[44, 494] -> 
             RGBColor[
              0.9434432272727272, 0.9547480909090909, 0.8754924545454545], 
             UndirectedEdge[85, 387] -> 
             RGBColor[
              0.5457742727272727, 0.6399536363636363, 0.9582862727272727], 
             UndirectedEdge[414, 499] -> 
             RGBColor[
              0.8308844090909091, 0.8681233636363637, 0.9519232272727272], 
             UndirectedEdge[89, 376] -> 
             RGBColor[
              0.7606528636363636, 0.8130320909090909, 0.9767558636363636], 
             UndirectedEdge[171, 403] -> 
             RGBColor[
              0.8390093636363636, 0.8736804545454545, 0.9156674090909092], 
             UndirectedEdge[161, 279] -> 
             RGBColor[
              0.7317914999999999, 0.7626568181818181, 0.6568323181818181], 
             UndirectedEdge[149, 310] -> 
             RGBColor[
              0.8661022272727272, 0.8961040909090909, 0.9791386818181818], 
             UndirectedEdge[333, 367] -> 
             RGBColor[
              0.8476041818181819, 0.8296691818181818, 0.6290348636363636], 
             UndirectedEdge[43, 227] -> 
             RGBColor[0.9073477727272727, 0.927708, 0.9476691818181818], 
             UndirectedEdge[71, 369] -> 
             RGBColor[
              0.8625523636363637, 0.8800929090909091, 0.6871057272727272], 
             UndirectedEdge[134, 174] -> 
             RGBColor[
              0.9850256818181817, 0.9758467272727273, 0.6556048636363636], 
             UndirectedEdge[158, 370] -> 
             RGBColor[
              0.8164330909090909, 0.8571181818181818, 0.9821801363636363], 
             UndirectedEdge[7, 391] -> 
             RGBColor[0.9466635, 0.8152835000000002, 0.4997952272727274], 
             UndirectedEdge[200, 228] -> 
             RGBColor[
              0.9119607727272727, 0.6470576363636362, 0.5486606818181818], 
             UndirectedEdge[201, 300] -> 
             RGBColor[
              0.9601044090909091, 0.9674768181818182, 0.8465403636363638], 
             UndirectedEdge[210, 320] -> 
             RGBColor[0.7006539545454545, 0.7648360000000001, 0.971788], 
             UndirectedEdge[69, 103] -> 
             RGBColor[
              0.9895624999999999, 0.9777228181818182, 0.5804180454545455], 
             UndirectedEdge[97, 281] -> 
             RGBColor[
              0.6529167727272727, 0.7227587727272726, 0.9615240454545455], 
             UndirectedEdge[192, 272] -> 
             RGBColor[
              0.9887288181818181, 0.9896070909090909, 0.8364561818181817], 
             UndirectedEdge[70, 463] -> 
             RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 
             UndirectedEdge[285, 477] -> 
             RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 
             UndirectedEdge[10, 168] -> 
             RGBColor[
              0.9946504090909091, 0.9909660909090909, 0.6591082272727273], 
             UndirectedEdge[298, 468] -> 
             RGBColor[
              0.6748756363636362, 0.7439079999999999, 0.9697586363636364], 
             UndirectedEdge[37, 264] -> 
             RGBColor[
              0.8421578636363636, 0.8734568181818182, 0.7525920000000001], 
             UndirectedEdge[191, 405] -> 
             RGBColor[
              0.9050373181818182, 0.5605201818181819, 0.3085459545454543], 
             UndirectedEdge[349, 380] -> 
             RGBColor[
              0.9821161363636364, 0.9846753636363637, 0.8476497272727272], 
             UndirectedEdge[94, 410] -> 
             RGBColor[0.8778414999999999, 0.9054309999999999, 0.9882105], 
             UndirectedEdge[335, 409] -> 
             RGBColor[
              0.6471835909090908, 0.7197705454545454, 0.9682358636363636], 
             UndirectedEdge[168, 189] -> 
             RGBColor[
              0.9285457727272727, 0.9423128181818181, 0.8435302727272729], 
             UndirectedEdge[187, 399] -> 
             RGBColor[0.9941475, 0.9916299090909091, 0.7308122272727275], 
             UndirectedEdge[153, 314] -> 
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273], 
             UndirectedEdge[233, 355] -> 
             RGBColor[
              0.7617188636363637, 0.8122770000000001, 0.9342567727272727], 
             UndirectedEdge[233, 486] -> 
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181], 
             UndirectedEdge[49, 264] -> 
             RGBColor[
              0.6150239545454546, 0.697601090909091, 0.9633434545454544], 
             UndirectedEdge[205, 331] -> 
             RGBColor[
              0.9593465000000001, 0.9658557272727273, 0.7640466363636365], 
             UndirectedEdge[308, 456] -> 
             RGBColor[
              0.8421578636363636, 0.8734568181818182, 0.7525920000000001], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.7929158636363636, 0.835227818181818, 0.830642181818182], 
             UndirectedEdge[175, 371] -> 
             RGBColor[
              0.5942174545454545, 0.6777978181818182, 0.9631146363636363], 
             UndirectedEdge[21, 188] -> 
             RGBColor[
              0.8913589545454546, 0.9129220909090909, 0.8399140909090911], 
             UndirectedEdge[79, 221] -> 
             RGBColor[
              0.9697726363636363, 0.9749586363636363, 0.839579681818182], 
             UndirectedEdge[158, 193] -> 
             RGBColor[0.8620621818181818, 0.892849, 0.9867054545454546], 
             UndirectedEdge[266, 483] -> 
             RGBColor[
              0.8484933181818182, 0.8821137272727273, 0.9655309545454545], 
             UndirectedEdge[290, 484] -> 
             RGBColor[0.8660005, 0.8915683636363636, 0.7137593181818179], 
             UndirectedEdge[153, 411] -> 
             RGBColor[
              0.9189780454545454, 0.9115978181818181, 0.6737791363636363], 
             UndirectedEdge[176, 475] -> 
             RGBColor[
              0.9821161363636364, 0.9846753636363637, 0.8476497272727272], 
             UndirectedEdge[20, 474] -> 
             RGBColor[0.7522105909090908, 0.806692, 0.9758467272727273], 
             UndirectedEdge[70, 483] -> 
             RGBColor[0.8418806363636363, 0.8771819999999999, 0.9767245], 
             UndirectedEdge[163, 266] -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             UndirectedEdge[69, 486] -> 
             RGBColor[
              0.9592225454545454, 0.967330090909091, 0.8769975000000001], 
             UndirectedEdge[262, 475] -> 
             RGBColor[
              0.9230170909090909, 0.7517301363636362, 0.5757478636363635], 
             UndirectedEdge[18, 167] -> 
             RGBColor[
              0.8647432272727272, 0.8932279090909091, 0.893019318181818], 
             UndirectedEdge[281, 374] -> 
             RGBColor[
              0.9348476818181818, 0.9506588181818182, 0.9857649545454545], 
             UndirectedEdge[138, 294] -> 
             RGBColor[
              0.842033909090909, 0.8749311818181817, 0.8655428636363637], 
             UndirectedEdge[291, 349] -> 
             RGBColor[
              0.9887288181818181, 0.9896070909090909, 0.8364561818181819], 
             UndirectedEdge[288, 455] -> 
             RGBColor[
              0.7364312727272728, 0.7941100000000001, 0.9743416818181818], 
             UndirectedEdge[12, 459] -> 
             RGBColor[
              0.9926352272727272, 0.9910045454545455, 0.7558745000000001], 
             UndirectedEdge[93, 305] -> 
             RGBColor[
              0.9896106818181818, 0.9897538181818182, 0.8059990454545456], 
             UndirectedEdge[127, 184] -> 
             RGBColor[
              0.6432485454545454, 0.7152769545454545, 0.9684847272727273], 
             UndirectedEdge[204, 431] -> 
             RGBColor[
              0.900735090909091, 0.9227762727272728, 0.9588627272727273], 
             UndirectedEdge[397, 495] -> 
             RGBColor[
              0.9597254545454545, 0.9666662727272728, 0.8052934999999998], 
             UndirectedEdge[28, 493] -> 
             RGBColor[
              0.9480730454545454, 0.9605222727272728, 0.9633778636363636], 
             UndirectedEdge[267, 485] -> 
             RGBColor[
              0.6379069545454545, 0.523560409090909, 0.5821109090909091], 
             UndirectedEdge[110, 494] -> 
             RGBColor[
              0.9256810454545454, 0.9430085454545454, 0.9730663636363637], 
             UndirectedEdge[337, 500] -> 
             RGBColor[
              0.7167203636363635, 0.7735812272727272, 0.8552689545454546], 
             UndirectedEdge[43, 393] -> 
             RGBColor[
              0.9127664545454546, 0.9297308181818182, 0.8420252272727275], 
             UndirectedEdge[167, 432] -> 
             RGBColor[0.8575696363636364, 0.863285, 0.6677487727272726], 
             UndirectedEdge[230, 474] -> 
             RGBColor[
              0.9261516363636363, 0.9415407272727272, 0.8990496818181817], 
             UndirectedEdge[40, 421] -> 
             RGBColor[
              0.6892454545454544, 0.7563732727272726, 0.9702011818181817], 
             UndirectedEdge[254, 476] -> 
             RGBColor[
              0.9887288181818181, 0.9896070909090909, 0.8364561818181819], 
             UndirectedEdge[107, 197] -> 
             RGBColor[
              0.5392457272727271, 0.6368229999999999, 0.9568705454545454], 
             UndirectedEdge[231, 395] -> 
             RGBColor[
              0.5093282727272727, 0.30588913636363624`, 0.5595896818181818], 
             UndirectedEdge[420, 427] -> 
             RGBColor[
              0.9724789090909091, 0.9784929090909091, 0.9089678181818182], 
             UndirectedEdge[317, 374] -> 
             RGBColor[0.732212590909091, 0.79, 0.9747980909090909], 
             UndirectedEdge[188, 200] -> 
             RGBColor[
              0.9896106818181818, 0.9897538181818182, 0.8059990454545456], 
             UndirectedEdge[84, 260] -> 
             RGBColor[
              0.9348476818181818, 0.9506588181818182, 0.9857649545454545], 
             UndirectedEdge[33, 160] -> 
             RGBColor[
              0.9718003181818182, 0.9659832727272727, 0.6779919545454545], 
             UndirectedEdge[135, 362] -> 
             RGBColor[
              0.8551059999999999, 0.8870454545454545, 0.954337409090909], 
             UndirectedEdge[123, 193] -> 
             RGBColor[
              0.8462828636363636, 0.8802669999999999, 0.9852004090909091], 
             UndirectedEdge[439, 453] -> 
             RGBColor[
              0.8667584090909091, 0.8931894545454545, 0.7962530454545452], 
             UndirectedEdge[269, 282] -> 
             RGBColor[
              0.9322937272727272, 0.9479402727272728, 0.9618728181818181], 
             UndirectedEdge[202, 459] -> 
             RGBColor[
              0.9950293636363636, 0.9917766363636363, 0.7003550909090913], 
             UndirectedEdge[25, 474] -> 
             RGBColor[0.8778414999999999, 0.9054309999999999, 0.9882105], 
             UndirectedEdge[103, 259] -> 
             RGBColor[
              0.9850256818181817, 0.9758467272727273, 0.6556048636363636], 
             UndirectedEdge[352, 375] -> 
             RGBColor[
              0.9205879545454545, 0.6913726818181821, 0.5039012272727272], 
             UndirectedEdge[300, 308] -> 
             RGBColor[0.8079908181818182, 0.850778090909091, 0.981271], 
             UndirectedEdge[32, 328] -> 
             RGBColor[
              0.989986090909091, 0.9879475454545454, 0.6571961818181816], 
             UndirectedEdge[209, 486] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[118, 496] -> 
             RGBColor[
              0.7374528181818181, 0.7919743636363636, 0.9071651363636364], 
             UndirectedEdge[31, 405] -> 
             RGBColor[
              0.6035439090909092, 0.6647602272727273, 0.6941955909090907], 
             UndirectedEdge[21, 228] -> 
             RGBColor[
              0.8137090454545454, 0.570225909090909, 0.5825757272727272], 
             UndirectedEdge[92, 250] -> 
             RGBColor[
              0.9790915909090909, 0.9834246363636363, 0.8977742727272727], 
             UndirectedEdge[177, 290] -> 
             RGBColor[
              0.7634669545454544, 0.8151454545454545, 0.977058909090909], 
             UndirectedEdge[9, 333] -> 
             RGBColor[
              0.7150237727272727, 0.7773012727272727, 0.9722305454545455], 
             UndirectedEdge[11, 444] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[11, 25] -> 
             RGBColor[0.8620621818181818, 0.892849, 0.9867054545454546], 
             UndirectedEdge[168, 338] -> 
             RGBColor[
              0.9942714545454545, 0.9901555454545454, 0.617861363636364], 
             UndirectedEdge[283, 430] -> 
             RGBColor[
              0.6792438181818181, 0.744766090909091, 0.9515866818181817], 
             UndirectedEdge[139, 410] -> 
             RGBColor[
              0.9261516363636363, 0.9415407272727272, 0.8990496818181817], 
             UndirectedEdge[195, 260] -> 
             RGBColor[
              0.9414603636363637, 0.9555905454545455, 0.974571409090909], 
             UndirectedEdge[391, 407] -> 
             RGBColor[
              0.8438749545454545, 0.7365756818181819, 0.6088970909090909], 
             UndirectedEdge[33, 111] -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             UndirectedEdge[2, 114] -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             UndirectedEdge[101, 306] -> 
             RGBColor[
              0.9857042727272727, 0.9883563636363637, 0.8865807272727273], 
             UndirectedEdge[264, 374] -> 
             RGBColor[0.8079908181818182, 0.850778090909091, 0.981271], 
             UndirectedEdge[172, 235] -> 
             RGBColor[
              0.9752484545454545, 0.9774587272727273, 0.7046455454545453], 
             UndirectedEdge[84, 475] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[37, 397] -> 
             RGBColor[0.9938925000000001, 0.989345, 0.5766145], 
             UndirectedEdge[228, 287] -> 
             RGBColor[
              0.9173794545454546, 0.6490804545454545, 0.44301672727272745`], 
             UndirectedEdge[68, 375] -> 
             RGBColor[
              0.5149309090909091, 0.3489534545454548, 0.5649547727272728], 
             UndirectedEdge[197, 236] -> 
             RGBColor[
              0.7389650909090908, 0.7925997272727272, 0.8821028636363635], 
             UndirectedEdge[107, 214] -> 
             RGBColor[
              0.7890094545454545, 0.8338303636363635, 0.9112238636363637], 
             UndirectedEdge[207, 317] -> 
             RGBColor[
              0.7617188636363637, 0.8122770000000001, 0.9342567727272727], 
             UndirectedEdge[98, 462] -> 
             RGBColor[
              0.7617188636363637, 0.8122770000000001, 0.9342567727272727], 
             UndirectedEdge[21, 59] -> 
             RGBColor[
              0.8661022272727272, 0.8961040909090909, 0.9791386818181818], 
             UndirectedEdge[46, 350] -> 
             RGBColor[
              0.9887288181818181, 0.9896070909090909, 0.8364561818181819], 
             UndirectedEdge[271, 429] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[304, 423] -> 
             RGBColor[
              0.9718003181818182, 0.9659832727272727, 0.6779919545454545], 
             UndirectedEdge[299, 328] -> 
             RGBColor[
              0.9743593181818182, 0.9250141818181818, 0.36814945454545434`], 
             UndirectedEdge[55, 73] -> 
             RGBColor[
              0.9734302727272728, 0.954107090909091, 0.6474414545454544], 
             UndirectedEdge[53, 440] -> 
             RGBColor[
              0.7227151818181817, 0.7814855454545454, 0.9546144999999999], 
             UndirectedEdge[206, 377] -> 
             RGBColor[
              0.7329349545454544, 0.6021358636363634, 0.5891974545454545], 
             UndirectedEdge[39, 113] -> 
             RGBColor[
              0.9739911818181818, 0.9791182727272727, 0.8839055454545454], 
             UndirectedEdge[9, 450] -> 
             RGBColor[
              0.6408022727272726, 0.7185290909090908, 0.9653728181818182], 
             UndirectedEdge[61, 321] -> 
             RGBColor[
              0.9790915909090909, 0.9834246363636363, 0.8977742727272727], 
             UndirectedEdge[76, 460] -> 
             RGBColor[
              0.8405216363636363, 0.8743058181818182, 0.8906051363636363], 
             UndirectedEdge[141, 167] -> 
             RGBColor[0.8660005, 0.8915683636363636, 0.713759318181818], 
             UndirectedEdge[29, 476] -> 
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181], 
             UndirectedEdge[39, 190] -> 
             RGBColor[
              0.9914983636363637, 0.9885729090909092, 0.6321339090909088], 
             UndirectedEdge[115, 215] -> 
             RGBColor[
              0.6165806818181817, 0.6996069999999999, 0.9629586363636363], 
             UndirectedEdge[208, 471] -> 
             RGBColor[
              0.9790915909090909, 0.9834246363636363, 0.8977742727272727], 
             UndirectedEdge[139, 401] -> 
             RGBColor[
              0.9917533636363636, 0.9908578181818182, 0.7863316363636363], 
             UndirectedEdge[34, 356] -> 
             RGBColor[0.732212590909091, 0.79, 0.9747980909090909], 
             UndirectedEdge[288, 313] -> 
             RGBColor[
              0.7606528636363636, 0.8130320909090909, 0.9767558636363636], 
             UndirectedEdge[66, 334] -> 
             RGBColor[
              0.8000501363636363, 0.8442695454545455, 0.9607025909090909], 
             UndirectedEdge[17, 328] -> 
             RGBColor[
              0.9589675454545454, 0.9650451818181819, 0.7227997727272725], 
             UndirectedEdge[318, 459] -> 
             RGBColor[
              0.7671375454545455, 0.8142998181818182, 0.8286128181818184], 
             UndirectedEdge[163, 233] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[141, 300] -> 
             RGBColor[
              0.9589675454545454, 0.9650451818181819, 0.7227997727272726], 
             UndirectedEdge[354, 436] -> 
             RGBColor[
              0.9502394545454544, 0.9106278181818181, 0.6311146363636364], 
             UndirectedEdge[29, 290] -> 
             RGBColor[
              0.8322124090909091, 0.8697001818181818, 0.9836851818181818], 
             UndirectedEdge[110, 360] -> 
             RGBColor[
              0.8484933181818182, 0.8821137272727273, 0.9655309545454545], 
             UndirectedEdge[289, 308] -> 
             RGBColor[
              0.7764321818181817, 0.8256140909090908, 0.9782609090909091], 
             UndirectedEdge[264, 324] -> 
             RGBColor[
              0.8421578636363636, 0.8734568181818182, 0.7525920000000001], 
             UndirectedEdge[109, 382] -> 
             RGBColor[
              0.9097917272727272, 0.7418666818181816, 0.5981349545454546], 
             UndirectedEdge[293, 497] -> 
             RGBColor[
              0.9139953181818181, 0.8947899090909092, 0.6544221818181819], 
             UndirectedEdge[160, 237] -> 
             RGBColor[
              0.9015891818181818, 0.5490447272727272, 0.28189236363636355`], 
             UndirectedEdge[35, 123] -> 
             RGBColor[
              0.6314042727272726, 0.7071885454545455, 0.9667308181818182], 
             UndirectedEdge[218, 432] -> 
             RGBColor[
              0.9800429545454545, 0.9590388181818181, 0.636247909090909], 
             UndirectedEdge[46, 476] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[288, 391] -> 
             RGBColor[
              0.8652824545454546, 0.7533844090909092, 0.6110082272727273], 
             UndirectedEdge[259, 486] -> 
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181], 
             UndirectedEdge[138, 296] -> 
             RGBColor[
              0.7764321818181817, 0.8256140909090908, 0.9782609090909091], 
             UndirectedEdge[56, 494] -> 
             RGBColor[
              0.8164330909090909, 0.8571181818181818, 0.9821801363636363], 
             UndirectedEdge[91, 200] -> 
             RGBColor[0.7874971818181817, 0.833205, 0.9362861363636363], 
             UndirectedEdge[172, 493] -> 
             RGBColor[
              0.9414603636363637, 0.9555905454545455, 0.974571409090909], 
             UndirectedEdge[340, 461] -> 
             RGBColor[0.9404186818181818, 0.9534973636363636, 0.925617], 
             UndirectedEdge[33, 274] -> 
             RGBColor[
              0.9414603636363637, 0.9555905454545455, 0.974571409090909], 
             UndirectedEdge[235, 345] -> 
             RGBColor[0.9686357727272727, 0.972527, 0.7158390909090908], 
             UndirectedEdge[205, 490] -> 
             RGBColor[0.7837692272727272, 0.831856, 0.9788568181818181], 
             UndirectedEdge[141, 284] -> 
             RGBColor[
              0.927408909090909, 0.9398811818181818, 0.7197896818181817], 
             UndirectedEdge[489, 500] -> 
             RGBColor[0.713695818181818, 0.7723304999999998, 0.9053935], 
             UndirectedEdge[155, 198] -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             UndirectedEdge[23, 157] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[248, 344] -> 
             RGBColor[
              0.872714909090909, 0.9010358181818181, 0.9679451363636363], 
             UndirectedEdge[50, 131] -> 
             RGBColor[0.8418806363636363, 0.8771819999999999, 0.9767245], 
             UndirectedEdge[442, 500] -> 
             RGBColor[
              0.6638697727272727, 0.5690087727272728, 0.5885809545454546], 
             UndirectedEdge[18, 305] -> 
             RGBColor[
              0.9926352272727272, 0.9910045454545455, 0.7558745000000001], 
             UndirectedEdge[134, 278] -> 
             RGBColor[0.978413, 0.970915, 0.6667984090909089], 
             UndirectedEdge[158, 422] -> 
             RGBColor[0.8778414999999999, 0.9054309999999999, 0.9882105], 
             UndirectedEdge[229, 393] -> 
             RGBColor[
              0.9926352272727272, 0.9910045454545455, 0.7558745000000001], 
             UndirectedEdge[17, 143] -> 
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181], 
             UndirectedEdge[53, 83] -> 
             RGBColor[
              0.8941224090909091, 0.9178445454545454, 0.9700562727272728], 
             UndirectedEdge[166, 239] -> 
             RGBColor[
              0.8909799999999999, 0.9121115454545454, 0.7986672272727271], 
             UndirectedEdge[46, 194] -> 
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181], 
             UndirectedEdge[319, 368] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[51, 360] -> 
             RGBColor[
              0.8322124090909091, 0.8697001818181818, 0.9836851818181818], 
             UndirectedEdge[132, 250] -> 
             RGBColor[
              0.9821161363636364, 0.9846753636363637, 0.8476497272727272], 
             UndirectedEdge[80, 447] -> 
             RGBColor[0.3810319999999999, 0.5044525, 0.9455], 
             UndirectedEdge[128, 179] -> 
             RGBColor[
              0.6772916363636363, 0.7394300454545454, 0.852756590909091], 
             UndirectedEdge[218, 300] -> 
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181], 
             UndirectedEdge[130, 241] -> 
             RGBColor[
              0.6529167727272727, 0.7227587727272726, 0.9615240454545455], 
             UndirectedEdge[134, 252] -> 
             RGBColor[0.9651876363636362, 0.9610515454545454, 0.6891855], 
             UndirectedEdge[266, 317] -> 
             RGBColor[0.7484935, 0.8024135454545456, 0.9566438636363637], 
             UndirectedEdge[156, 485] -> 
             RGBColor[
              0.6726311363636364, 0.7398343636363636, 0.9627802272727273], 
             UndirectedEdge[96, 110] -> 
             RGBColor[
              0.9511285909090909, 0.9630723636363636, 0.9676107272727272], 
             UndirectedEdge[50, 373] -> 
             RGBColor[
              0.8617186818181818, 0.8919771818181819, 0.9431438636363636], 
             UndirectedEdge[37, 322] -> 
             RGBColor[
              0.8421578636363636, 0.8734568181818182, 0.7525920000000001], 
             UndirectedEdge[65, 290] -> 
             RGBColor[
              0.8671373636363636, 0.8939999999999999, 0.8374999090909092], 
             UndirectedEdge[333, 450] -> 
             RGBColor[0.6650238636363635, 0.7374511818181817, 0.967787], 
             UndirectedEdge[238, 266] -> 
             RGBColor[
              0.9763853181818182, 0.9798903636363636, 0.8283861363636366], 
             UndirectedEdge[312, 446] -> 
             RGBColor[0.8079908181818182, 0.850778090909091, 0.981271], 
             UndirectedEdge[407, 448] -> 
             RGBColor[
              0.8564339999999999, 0.8886222727272728, 0.9860993636363635], 
             UndirectedEdge[14, 454] -> 
             RGBColor[
              0.7676591363636363, 0.818409818181818, 0.9698667727272727], 
             UndirectedEdge[77, 473] -> 
             RGBColor[
              0.9887288181818181, 0.9896070909090909, 0.8364561818181819], 
             UndirectedEdge[57, 136] -> 
             RGBColor[
              0.6751298636363635, 0.5319070909090907, 0.5799248636363636], 
             UndirectedEdge[364, 487] -> 
             RGBColor[0.6858565, 0.7496978181818181, 0.9403931363636363], 
             UndirectedEdge[80, 403] -> 
             RGBColor[
              0.5457742727272727, 0.6399536363636363, 0.9582862727272727], 
             UndirectedEdge[330, 352] -> 
             RGBColor[
              0.8163000454545455, 0.8553837272727274, 0.8881909545454545], 
             UndirectedEdge[239, 272] -> 
             RGBColor[0.990744, 0.9895686363636363, 0.7396899090909089], 
             UndirectedEdge[53, 97] -> 
             RGBColor[0.6595294545454544, 0.7276904999999999, 0.9503305], 
             UndirectedEdge[304, 311] -> 
             RGBColor[
              0.9511285909090909, 0.9630723636363636, 0.9676107272727272], 
             UndirectedEdge[237, 241] -> 
             RGBColor[
              0.5893183181818181, 0.31075195454545446`, 0.5542309090909091], 
             UndirectedEdge[361, 441] -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             UndirectedEdge[276, 347] -> 
             RGBColor[
              0.48797236363636365`, 0.5877062272727273, 0.9546830909090909], 
             UndirectedEdge[11, 180] -> 
             RGBColor[
              0.7364312727272728, 0.7941100000000001, 0.9743416818181818], 
             UndirectedEdge[56, 360] -> 
             RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 
             UndirectedEdge[15, 269] -> 
             RGBColor[
              0.8551059999999999, 0.8870454545454545, 0.954337409090909], 
             UndirectedEdge[8, 387] -> 
             RGBColor[
              0.2898366818181818, 0.41346104545454543`, 0.9401285909090908], 
             UndirectedEdge[139, 278] -> 
             RGBColor[
              0.9806038636363636, 0.9840500000000001, 0.8727119999999999], 
             UndirectedEdge[15, 449] -> 
             RGBColor[
              0.8164330909090909, 0.8571181818181818, 0.9821801363636363], 
             UndirectedEdge[348, 355] -> 
             RGBColor[
              0.7660006818181819, 0.8118681818181819, 0.704872227272727], 
             UndirectedEdge[173, 499] -> 
             RGBColor[
              0.526059909090909, 0.6228780454545454, 0.9570300909090909], 
             UndirectedEdge[130, 483] -> 
             RGBColor[0.8418806363636363, 0.8771819999999999, 0.9767245], 
             UndirectedEdge[173, 282] -> 
             RGBColor[
              0.6274692272727271, 0.7026949545454545, 0.9669796818181817], 
             UndirectedEdge[84, 244] -> 
             RGBColor[
              0.9658662272727272, 0.9735611818181817, 0.9201613636363637], 
             UndirectedEdge[183, 279] -> 
             RGBColor[0.3333080454545454, 0.4501805, 0.943156409090909], 
             UndirectedEdge[124, 381] -> 
             RGBColor[0.9123875, 0.9289202727272727, 0.8007783636363635], 
             UndirectedEdge[81, 213] -> 
             RGBColor[
              0.9896106818181818, 0.9897538181818182, 0.8059990454545456], 
             UndirectedEdge[134, 210] -> 
             RGBColor[
              0.7625525454545454, 0.8003927272727274, 0.6782186363636362], 
             UndirectedEdge[103, 275] -> 
             RGBColor[0.978413, 0.970915, 0.6667984090909089], 
             UndirectedEdge[256, 298] -> 
             RGBColor[
              0.8462828636363636, 0.8802669999999999, 0.9852004090909091], 
             UndirectedEdge[18, 235] -> 
             RGBColor[
              0.9914983636363637, 0.9885729090909092, 0.6321339090909088], 
             UndirectedEdge[255, 334] -> 
             RGBColor[
              0.9668175909090909, 0.9491753636363636, 0.6586349999999999], 
             UndirectedEdge[209, 372] -> 
             RGBColor[
              0.8295139090909092, 0.5439703181818182, 0.5793217727272728], 
             UndirectedEdge[112, 238] -> 
             RGBColor[
              0.8429157727272727, 0.8750779090909091, 0.8350857272727275], 
             UndirectedEdge[360, 457] -> 
             RGBColor[
              0.8617186818181818, 0.8919771818181819, 0.9431438636363636], 
             UndirectedEdge[233, 404] -> 
             RGBColor[
              0.9119607727272727, 0.6470576363636362, 0.5486606818181818], 
             UndirectedEdge[259, 348] -> 
             RGBColor[
              0.9884738181818182, 0.9873221818181819, 0.6822584545454543], 
             UndirectedEdge[244, 376] -> 
             RGBColor[
              0.8390093636363636, 0.8736804545454545, 0.9156674090909092], 
             UndirectedEdge[182, 371] -> 
             RGBColor[
              0.8090960454545455, 0.8508762727272727, 0.9815842272727273], 
             UndirectedEdge[21, 77] -> 
             RGBColor[
              0.8859402727272727, 0.9108992727272727, 0.9455580454545454], 
             UndirectedEdge[153, 493] -> 
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454], 
             UndirectedEdge[276, 382] -> 
             RGBColor[
              0.6148292272727272, 0.6875869545454545, 0.9591770454545454], 
             UndirectedEdge[80, 219] -> 
             RGBColor[
              0.6792438181818181, 0.744766090909091, 0.9515866818181817], 
             UndirectedEdge[60, 136] -> 
             RGBColor[
              0.7009081818181818, 0.5528350909090909, 0.5819542272727272], 
             UndirectedEdge[23, 96] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[53, 281] -> 
             RGBColor[
              0.9511285909090909, 0.9630723636363636, 0.9676107272727272], 
             UndirectedEdge[141, 162] -> 
             RGBColor[
              0.8175573181818182, 0.8537241818181819, 0.7089309545454543], 
             UndirectedEdge[28, 149] -> 
             RGBColor[
              0.8793275909090909, 0.9059675454545455, 0.9567515909090909], 
             UndirectedEdge[37, 317] -> 
             RGBColor[
              0.7663796363636364, 0.8126787272727274, 0.7461190909090911], 
             UndirectedEdge[372, 486] -> 
             RGBColor[
              0.8768518636363636, 0.5817163181818181, 0.583836909090909], 
             UndirectedEdge[63, 453] -> 
             RGBColor[
              0.8667584090909091, 0.8931894545454545, 0.7962530454545452], 
             UndirectedEdge[82, 242] -> 
             RGBColor[
              0.526059909090909, 0.6228780454545454, 0.9570300909090909], 
             UndirectedEdge[4, 191] -> 
             RGBColor[
              0.9052923181818182, 0.5628050909090909, 0.4627436818181819], 
             UndirectedEdge[70, 403] -> 
             RGBColor[
              0.8176590454545454, 0.8582599090909091, 0.9743103181818182], 
             UndirectedEdge[144, 458] -> 
             RGBColor[0.8079908181818182, 0.850778090909091, 0.981271], 
             UndirectedEdge[16, 224] -> 
             RGBColor[
              0.6408022727272726, 0.7185290909090908, 0.9653728181818182], 
             UndirectedEdge[40, 206] -> 
             RGBColor[
              0.5908023636363634, 0.6786789999999998, 0.9609292727272727], 
             UndirectedEdge[148, 485] -> 
             RGBColor[
              0.5942174545454545, 0.6777978181818182, 0.9631146363636363], 
             UndirectedEdge[34, 291] -> 
             RGBColor[
              0.7617188636363637, 0.8122770000000001, 0.9342567727272727], 
             UndirectedEdge[222, 339] -> 
             RGBColor[
              0.9690147272727272, 0.9733375454545454, 0.7570859545454547], 
             UndirectedEdge[197, 314] -> 
             RGBColor[0.7359405454545453, 0.791349, 0.9322274090909091], 
             UndirectedEdge[330, 358] -> 
             RGBColor[
              0.8179362727272728, 0.8545347272727273, 0.7501778181818184], 
             UndirectedEdge[312, 415] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[370, 443] -> 
             RGBColor[
              0.8484933181818182, 0.8821137272727273, 0.9655309545454545], 
             UndirectedEdge[160, 305] -> 
             RGBColor[
              0.9904443636363636, 0.9778695454545454, 0.5499609090909092], 
             UndirectedEdge[266, 343] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[47, 468] -> 
             RGBColor[
              0.6376888181818181, 0.7145172727272726, 0.9661424545454544], 
             UndirectedEdge[388, 436] -> 
             RGBColor[
              0.6586403181818181, 0.6752459545454544, 0.613834409090909], 
             UndirectedEdge[69, 209] -> 
             RGBColor[
              0.9118845909090909, 0.9295840909090909, 0.8724823636363637], 
             UndirectedEdge[197, 470] -> 
             RGBColor[
              0.7161024999999999, 0.7765538181818181, 0.9658080454545455], 
             UndirectedEdge[13, 298] -> 
             RGBColor[
              0.8685648636363635, 0.7092208636363635, 0.6020855454545455], 
             UndirectedEdge[168, 383] -> 
             RGBColor[
              0.9763853181818182, 0.9798903636363636, 0.8283861363636366], 
             UndirectedEdge[123, 428] -> 
             RGBColor[
              0.916514409090909, 0.9353582727272727, 0.9603677727272727], 
             UndirectedEdge[137, 485] -> 
             RGBColor[
              0.6792438181818181, 0.744766090909091, 0.9515866818181817], 
             UndirectedEdge[394, 467] -> 
             RGBColor[
              0.9589675454545454, 0.9650451818181819, 0.7227997727272725], 
             UndirectedEdge[232, 395] -> 
             RGBColor[
              0.5823931818181818, 0.6346782272727273, 0.6665338636363636], 
             UndirectedEdge[414, 461] -> 
             RGBColor[
              0.9790915909090909, 0.9834246363636363, 0.8977742727272727], 
             UndirectedEdge[224, 333] -> 
             RGBColor[
              0.7150237727272727, 0.7773012727272727, 0.9722305454545455], 
             UndirectedEdge[33, 182] -> 
             RGBColor[
              0.8941224090909091, 0.9178445454545454, 0.9700562727272728], 
             UndirectedEdge[158, 451] -> 
             RGBColor[
              0.6906549545454544, 0.7564899999999999, 0.9712636818181818], 
             UndirectedEdge[235, 274] -> 
             RGBColor[
              0.9589675454545454, 0.9650451818181819, 0.7227997727272726], 
             UndirectedEdge[284, 345] -> 
             RGBColor[
              0.9032890454545454, 0.9254948181818181, 0.9827548636363637], 
             UndirectedEdge[70, 238] -> 
             RGBColor[
              0.9697726363636363, 0.9749586363636363, 0.839579681818182], 
             UndirectedEdge[21, 55] -> 
             RGBColor[
              0.8793275909090909, 0.9059675454545455, 0.9567515909090909], 
             UndirectedEdge[55, 60] -> 
             RGBColor[
              0.7551061818181819, 0.8073452727272727, 0.9454503181818181], 
             UndirectedEdge[219, 258] -> 
             RGBColor[
              0.8484933181818182, 0.8821137272727273, 0.9655309545454545], 
             UndirectedEdge[175, 463] -> 
             RGBColor[
              0.6726311363636364, 0.7398343636363636, 0.9627802272727273], 
             UndirectedEdge[101, 431] -> 
             RGBColor[
              0.9775793181818182, 0.9827992727272727, 0.9228365454545454], 
             UndirectedEdge[14, 213] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[378, 487] -> 
             RGBColor[
              0.6471835909090908, 0.7197705454545454, 0.9682358636363636], 
             UndirectedEdge[8, 159] -> 
             RGBColor[
              0.5617214545454545, 0.6317673181818182, 0.9561526363636363], 
             UndirectedEdge[311, 469] -> 
             RGBColor[
              0.9032890454545454, 0.9254948181818181, 0.9827548636363637], 
             UndirectedEdge[343, 440] -> 
             RGBColor[
              0.6748756363636362, 0.7439079999999999, 0.9697586363636364], 
             UndirectedEdge[371, 460] -> 
             RGBColor[0.8889648181818182, 0.91215, 0.8954334999999999], 
             UndirectedEdge[224, 358] -> 
             RGBColor[
              0.8421578636363636, 0.8734568181818182, 0.7525920000000001], 
             UndirectedEdge[455, 475] -> 
             RGBColor[
              0.8066628181818182, 0.8492012727272727, 0.9495090454545454], 
             UndirectedEdge[310, 408] -> 
             RGBColor[
              0.9688907727272726, 0.9748119090909091, 0.8700368181818183], 
             UndirectedEdge[154, 376] -> 
             RGBColor[
              0.5457742727272727, 0.6399536363636363, 0.9582862727272727], 
             UndirectedEdge[282, 499] -> 
             RGBColor[0.7922115, 0.8381960909090909, 0.9797659545454545], 
             UndirectedEdge[14, 192] -> 
             RGBColor[
              0.9673784999999999, 0.9741865454545455, 0.8950990909090908], 
             UndirectedEdge[75, 147] -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909092], 
             UndirectedEdge[175, 351] -> 
             RGBColor[
              0.6939814545454546, 0.7552549090909091, 0.9041373181818182], 
             UndirectedEdge[109, 205] -> 
             RGBColor[0.9001235, 0.7343848636363635, 0.6050956363636364], 
             UndirectedEdge[43, 148] -> 
             RGBColor[
              0.8090960454545455, 0.8508762727272727, 0.9815842272727273], 
             UndirectedEdge[56, 92] -> 
             RGBColor[
              0.8632309545454545, 0.8926025454545454, 0.9180815909090909], 
             UndirectedEdge[46, 412] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[170, 214] -> 
             RGBColor[
              0.9790915909090909, 0.9834246363636363, 0.8977742727272727], 
             UndirectedEdge[94, 437] -> 
             RGBColor[
              0.6471835909090908, 0.7197705454545454, 0.9682358636363636], 
             UndirectedEdge[173, 249] -> 
             RGBColor[
              0.6274692272727271, 0.7026949545454545, 0.9669796818181817], 
             UndirectedEdge[181, 302] -> 
             RGBColor[
              0.9404150454545455, 0.7869107272727274, 0.49458136363636374`], 
             UndirectedEdge[188, 279] -> 
             RGBColor[
              0.7413592272727272, 0.7933718181818181, 0.8265834545454547], 
             UndirectedEdge[317, 471] -> 
             RGBColor[0.7632311363636364, 0.8129023636363637, 0.9091945], 
             UndirectedEdge[8, 344] -> 
             RGBColor[
              0.5683341363636363, 0.6366990454545454, 0.9449590909090909], 
             UndirectedEdge[236, 493] -> 
             RGBColor[
              0.9577102727272727, 0.9667047272727274, 0.9020597727272726], 
             UndirectedEdge[31, 366] -> 
             RGBColor[
              0.5010103636363636, 0.5883373181818181, 0.9574951818181818], 
             UndirectedEdge[176, 261] -> 
             RGBColor[
              0.9795970454545455, 0.9441070000000001, 0.5417041363636366], 
             UndirectedEdge[144, 145] -> 
             RGBColor[
              0.9592225454545454, 0.967330090909091, 0.8769975000000001], 
             UndirectedEdge[144, 375] -> 
             RGBColor[
              0.8880571363636365, 0.6678449545454548, 0.5945670909090909], 
             UndirectedEdge[258, 293] -> 
             RGBColor[
              0.8006537727272727, 0.8445361818181818, 0.9806750909090909], 
             UndirectedEdge[242, 269] -> 
             RGBColor[
              0.8308844090909091, 0.8681233636363637, 0.9519232272727272], 
             UndirectedEdge[45, 216] -> 
             RGBColor[
              0.9277878636363637, 0.9406917272727273, 0.7610365454545456], 
             UndirectedEdge[82, 323] -> 
             RGBColor[
              0.6274692272727271, 0.7026949545454545, 0.9669796818181817], 
             UndirectedEdge[258, 272] -> 
             RGBColor[
              0.8632309545454545, 0.8926025454545454, 0.9180815909090909], 
             UndirectedEdge[92, 356] -> 
             RGBColor[0.956198, 0.9660793636363636, 0.9271220454545455], 
             UndirectedEdge[114, 327] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[188, 459] -> 
             RGBColor[
              0.9950293636363636, 0.9917766363636363, 0.7003550909090913], 
             UndirectedEdge[465, 469] -> 
             RGBColor[
              0.9281668181818181, 0.9415022727272726, 0.8022834090909089], 
             UndirectedEdge[44, 62] -> 
             RGBColor[
              0.842033909090909, 0.8749311818181817, 0.8655428636363637], 
             UndirectedEdge[88, 337] -> 
             RGBColor[
              0.9895624999999999, 0.9777228181818182, 0.5804180454545455], 
             UndirectedEdge[253, 388] -> 
             RGBColor[
              0.6742670909090909, 0.7381793181818181, 0.9028811363636364], 
             UndirectedEdge[80, 238] -> 
             RGBColor[
              0.6978878636363637, 0.7566523636363636, 0.8235556363636365], 
             UndirectedEdge[171, 272] -> 
             RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454546], 
             UndirectedEdge[297, 392] -> 
             RGBColor[
              0.8671373636363636, 0.8939999999999999, 0.8374999090909092], 
             UndirectedEdge[82, 499] -> 
             RGBColor[
              0.526059909090909, 0.6228780454545454, 0.9570300909090909], 
             UndirectedEdge[297, 484] -> 
             RGBColor[0.9938925000000001, 0.989345, 0.5766145], 
             UndirectedEdge[73, 240] -> 
             RGBColor[
              0.9843247727272728, 0.9586300000000001, 0.40686336363636333`], 
             UndirectedEdge[229, 263] -> 
             RGBColor[
              0.9261516363636363, 0.9415407272727272, 0.8990496818181817], 
             UndirectedEdge[87, 91] -> 
             RGBColor[0.7883308636363635, 0.8213207272727272, 0.680248], 
             UndirectedEdge[296, 339] -> 
             RGBColor[
              0.9032890454545454, 0.9254948181818181, 0.9827548636363637], 
             UndirectedEdge[62, 157] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[227, 265] -> 
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273], 
             UndirectedEdge[38, 127] -> 
             RGBColor[
              0.36131763636363623`, 0.48737690909090897`, 0.9442438181818181],
              UndirectedEdge[302, 451] -> 
             RGBColor[
              0.6876267727272727, 0.5886526363636364, 0.590352590909091], 
             UndirectedEdge[141, 151] -> 
             RGBColor[
              0.9843247727272728, 0.9586300000000001, 0.40686336363636333`], 
             UndirectedEdge[72, 439] -> 
             RGBColor[0.8662555, 0.8938532727272728, 0.8679570454545456], 
             UndirectedEdge[277, 340] -> 
             RGBColor[
              0.9190683636363636, 0.9380768181818182, 0.9842599090909091], 
             UndirectedEdge[53, 322] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[450, 461] -> 
             RGBColor[
              0.7890094545454545, 0.8338303636363635, 0.9112238636363637], 
             UndirectedEdge[352, 367] -> 
             RGBColor[
              0.9731020454545454, 0.9266737272727272, 0.5474094545454544], 
             UndirectedEdge[239, 251] -> 
             RGBColor[0.9938925000000001, 0.989345, 0.5766145], 
             UndirectedEdge[83, 163] -> 
             RGBColor[0.9073477727272727, 0.927708, 0.9476691818181818], 
             UndirectedEdge[179, 245] -> 
             RGBColor[
              0.6777945454545453, 0.7387662272727271, 0.7810525909090906], 
             UndirectedEdge[133, 237] -> 
             RGBColor[
              0.9054162727272728, 0.5613307272727273, 0.34979281818181834`], 
             UndirectedEdge[199, 244] -> 
             RGBColor[0.956198, 0.9660793636363636, 0.9271220454545455], 
             UndirectedEdge[173, 269] -> 
             RGBColor[
              0.6661421363636363, 0.7326222272727272, 0.9391369545454544], 
             UndirectedEdge[209, 379] -> 
             RGBColor[0.8620621818181818, 0.892849, 0.9867054545454546], 
             UndirectedEdge[139, 451] -> 
             RGBColor[
              0.7389650909090908, 0.7925997272727272, 0.8821028636363635], 
             UndirectedEdge[18, 218] -> 
             RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454544], 
             UndirectedEdge[59, 287] -> 
             RGBColor[
              0.9697726363636363, 0.9749586363636363, 0.839579681818182], 
             UndirectedEdge[167, 274] -> 
             RGBColor[
              0.8322124090909091, 0.8697001818181818, 0.9836851818181818], 
             UndirectedEdge[402, 461] -> 
             RGBColor[
              0.9246393636363636, 0.9409153636363636, 0.9241119545454546], 
             UndirectedEdge[472, 488] -> 
             RGBColor[
              0.6770366363636363, 0.7371451363636363, 0.6985588636363634], 
             UndirectedEdge[227, 270] -> 
             RGBColor[0.8132755, 0.854133, 0.9383155], 
             UndirectedEdge[124, 363] -> 
             RGBColor[
              0.7848744545454546, 0.8319541818181818, 0.9791700454545454], 
             UndirectedEdge[118, 195] -> 
             RGBColor[
              0.9724789090909091, 0.9784929090909091, 0.9089678181818182], 
             UndirectedEdge[54, 154] -> 
             RGBColor[
              0.6792438181818181, 0.744766090909091, 0.9515866818181817], 
             UndirectedEdge[313, 498] -> 
             RGBColor[
              0.7652658636363636, 0.5323817272727271, 0.5777473636363636], 
             UndirectedEdge[243, 283] -> 
             RGBColor[
              0.6726311363636364, 0.7398343636363636, 0.9627802272727273], 
             UndirectedEdge[302, 346] -> 
             RGBColor[0.8376265, 0.7082029090909092, 0.6036832272727273], 
             UndirectedEdge[13, 477] -> 
             RGBColor[
              0.7829348636363636, 0.6419859545454544, 0.5936409999999999], 
             UndirectedEdge[140, 479] -> 
             RGBColor[
              0.9118845909090909, 0.9295840909090909, 0.8724823636363637], 
             UndirectedEdge[174, 309] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[299, 312] -> 
             RGBColor[
              0.8233825909090908, 0.8107470909090908, 0.6266206818181819], 
             UndirectedEdge[215, 402] -> 
             RGBColor[
              0.7264322727272725, 0.7857639999999999, 0.9738173636363636], 
             UndirectedEdge[372, 400] -> 
             RGBColor[
              0.9071918181818182, 0.5921090454545455, 0.2872574545454544], 
             UndirectedEdge[29, 426] -> 
             RGBColor[
              0.8322124090909091, 0.8697001818181818, 0.9836851818181818], 
             UndirectedEdge[361, 481] -> 
             RGBColor[
              0.9480730454545454, 0.9605222727272728, 0.9633778636363636], 
             UndirectedEdge[188, 335] -> 
             RGBColor[
              0.9443250909090909, 0.9548948181818182, 0.8450353181818184], 
             UndirectedEdge[168, 443] -> 
             RGBColor[
              0.9763853181818182, 0.9798903636363636, 0.8283861363636366], 
             UndirectedEdge[81, 500] -> 
             RGBColor[
              0.7176022272727272, 0.7737279545454544, 0.8248118181818184], 
             UndirectedEdge[75, 310] -> 
             RGBColor[
              0.9688907727272726, 0.9748119090909091, 0.8700368181818183], 
             UndirectedEdge[348, 444] -> 
             RGBColor[
              0.9589675454545454, 0.9650451818181819, 0.7227997727272726], 
             UndirectedEdge[262, 482] -> 
             RGBColor[
              0.916404409090909, 0.746798409090909, 0.5869414090909091], 
             UndirectedEdge[83, 395] -> 
             RGBColor[0.5047152727272728, 0.5865395, 0.9585981818181819], 
             UndirectedEdge[26, 459] -> 
             RGBColor[
              0.9926352272727272, 0.9910045454545455, 0.7558745000000001], 
             UndirectedEdge[186, 498] -> 
             RGBColor[
              0.8508958636363635, 0.5996166363636362, 0.5861919090909091], 
             UndirectedEdge[167, 284] -> 
             RGBColor[
              0.8006537727272727, 0.8445361818181818, 0.9806750909090909], 
             UndirectedEdge[175, 359] -> 
             RGBColor[0.44421772727272724`, 0.5582475454545455, 0.949784], 
             UndirectedEdge[65, 484] -> 
             RGBColor[0.9938925000000001, 0.989345, 0.5766145], 
             UndirectedEdge[266, 322] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[210, 252] -> 
             RGBColor[
              0.7418808181818182, 0.7974818181818182, 0.9678374090909091], 
             UndirectedEdge[133, 271] -> 
             RGBColor[
              0.9756274090909092, 0.9782692727272728, 0.7458924090909093], 
             UndirectedEdge[190, 467] -> 
             RGBColor[
              0.9927556363636364, 0.9869133636363637, 0.4528739090909087], 
             UndirectedEdge[216, 481] -> 
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454], 
             UndirectedEdge[18, 406] -> 
             RGBColor[
              0.9261516363636363, 0.9415407272727272, 0.8990496818181817], 
             UndirectedEdge[315, 364] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[152, 464] -> 
             RGBColor[
              0.7667585909090909, 0.8134892727272728, 0.7873659545454543], 
             UndirectedEdge[229, 280] -> 
             RGBColor[
              0.7389650909090908, 0.7925997272727272, 0.8821028636363635], 
             UndirectedEdge[164, 259] -> 
             RGBColor[0.7874971818181817, 0.833205, 0.9362861363636363], 
             UndirectedEdge[238, 497] -> 
             RGBColor[
              0.9804789090909092, 0.9442537272727274, 0.5112470000000003], 
             UndirectedEdge[7, 478] -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             UndirectedEdge[137, 227] -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             UndirectedEdge[44, 157] -> 
             RGBColor[
              0.9755034545454545, 0.9797436363636364, 0.8588432727272728], 
             UndirectedEdge[105, 205] -> 
             RGBColor[
              0.9414603636363637, 0.9555905454545455, 0.974571409090909], 
             UndirectedEdge[305, 460] -> 
             RGBColor[
              0.9926352272727272, 0.9910045454545455, 0.7558745000000001], 
             UndirectedEdge[330, 492] -> 
             RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             UndirectedEdge[94, 123] -> 
             RGBColor[0.8778414999999999, 0.9054309999999999, 0.9882105], 
             UndirectedEdge[418, 444] -> 
             RGBColor[0.8079908181818182, 0.850778090909091, 0.981271], 
             UndirectedEdge[203, 295] -> 
             RGBColor[
              0.9032890454545454, 0.9254948181818181, 0.9827548636363637], 
             UndirectedEdge[342, 485] -> 
             RGBColor[
              0.4699960454545455, 0.5791755454545455, 0.9518133636363636], 
             UndirectedEdge[279, 430] -> 
             RGBColor[
              0.7227151818181817, 0.7814855454545454, 0.9546144999999999], 
             UndirectedEdge[391, 448] -> 
             RGBColor[
              0.9126204090909091, 0.7911304090909093, 0.6155233636363637], 
             UndirectedEdge[174, 252] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[14, 489] -> 
             RGBColor[
              0.9658662272727272, 0.9735611818181817, 0.9201613636363637], 
             UndirectedEdge[6, 158] -> 
             RGBColor[
              0.938906409090909, 0.9528719999999999, 0.9506792727272727], 
             UndirectedEdge[201, 493] -> 
             RGBColor[
              0.9601044090909091, 0.9674768181818182, 0.8465403636363638], 
             UndirectedEdge[66, 446] -> 
             RGBColor[0.7837692272727272, 0.831856, 0.9788568181818181], 
             UndirectedEdge[449, 499] -> 
             RGBColor[0.7922115, 0.8381960909090909, 0.9797659545454545], 
             UndirectedEdge[202, 477] -> 
             RGBColor[
              0.8429157727272727, 0.8750779090909091, 0.8350857272727275], 
             UndirectedEdge[89, 299] -> 
             RGBColor[0.8932332727272727, 0.8654, 0.6335601818181819], 
             UndirectedEdge[57, 91] -> 
             RGBColor[
              0.5392457272727271, 0.6368229999999999, 0.9568705454545454], 
             UndirectedEdge[222, 438] -> 
             RGBColor[
              0.9756274090909092, 0.9782692727272728, 0.7458924090909093], 
             UndirectedEdge[83, 346] -> 
             RGBColor[
              0.8090960454545455, 0.8508762727272727, 0.9815842272727273], 
             UndirectedEdge[38, 388] -> 
             RGBColor[
              0.36131763636363623`, 0.48737690909090897`, 0.9442438181818181],
              UndirectedEdge[345, 472] -> 
             RGBColor[0.9686357727272727, 0.972527, 0.7158390909090907], 
             UndirectedEdge[231, 486] -> 
             RGBColor[0.8824544999999999, 0.6247806363636363, 0.589202], 
             UndirectedEdge[14, 251] -> 
             RGBColor[
              0.9690147272727272, 0.9733375454545454, 0.7570859545454547], 
             UndirectedEdge[404, 418] -> 
             RGBColor[
              0.7652658636363636, 0.5323817272727271, 0.5777473636363636], 
             UndirectedEdge[10, 370] -> 
             RGBColor[
              0.8667584090909091, 0.8931894545454545, 0.7962530454545452], 
             UndirectedEdge[216, 224] -> 
             RGBColor[
              0.7764321818181817, 0.8256140909090908, 0.9782609090909091], 
             UndirectedEdge[116, 143] -> 
             RGBColor[
              0.8859402727272727, 0.9108992727272727, 0.9455580454545454], 
             UndirectedEdge[142, 477] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[1, 378] -> 
             RGBColor[
              0.9419309545454545, 0.9541227272727273, 0.9005547272727272], 
             UndirectedEdge[47, 298] -> 
             RGBColor[
              0.8248753636363635, 0.8634582727272726, 0.9830892727272726], 
             UndirectedEdge[50, 340] -> 
             RGBColor[
              0.8164330909090909, 0.8571181818181818, 0.9821801363636363], 
             UndirectedEdge[144, 417] -> 
             RGBColor[
              0.9348476818181818, 0.9506588181818182, 0.9857649545454545], 
             UndirectedEdge[326, 395] -> 
             RGBColor[
              0.3848646818181817, 0.4920364999999999, 0.9472151363636363], 
             UndirectedEdge[14, 166] -> 
             RGBColor[
              0.8661022272727272, 0.8961040909090909, 0.9791386818181818], 
             UndirectedEdge[41, 132] -> 
             RGBColor[0.8662555, 0.8938532727272728, 0.8679570454545456], 
             UndirectedEdge[6, 35] -> 
             RGBColor[
              0.6924691818181818, 0.7546295454545455, 0.9291995909090909], 
             UndirectedEdge[95, 286] -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909092], 
             UndirectedEdge[435, 439] -> 
             RGBColor[
              0.8551059999999999, 0.8870454545454545, 0.954337409090909], 
             UndirectedEdge[354, 388] -> 
             RGBColor[
              0.6529167727272727, 0.7227587727272726, 0.9615240454545455], 
             UndirectedEdge[47, 59] -> 
             RGBColor[
              0.8661022272727272, 0.8961040909090909, 0.9791386818181818], 
             UndirectedEdge[305, 493] -> 
             RGBColor[
              0.9601044090909091, 0.9674768181818182, 0.8465403636363638], 
             UndirectedEdge[26, 335] -> 
             RGBColor[
              0.9419309545454545, 0.9541227272727273, 0.9005547272727272], 
             UndirectedEdge[24, 115] -> 
             RGBColor[
              0.8000501363636363, 0.8442695454545455, 0.9607025909090909], 
             UndirectedEdge[271, 351] -> 
             RGBColor[
              0.9724789090909091, 0.9784929090909091, 0.9089678181818182], 
             UndirectedEdge[12, 40] -> 
             RGBColor[
              0.7905217272727272, 0.8344557272727272, 0.8861615909090907], 
             UndirectedEdge[228, 468] -> 
             RGBColor[
              0.6637093181818181, 0.4506756363636362, 0.5692450909090909], 
             UndirectedEdge[1, 108] -> 
             RGBColor[
              0.9917533636363636, 0.9908578181818182, 0.7863316363636363], 
             UndirectedEdge[97, 343] -> 
             RGBColor[
              0.6116899090909089, 0.6901129545454544, 0.9654746363636364], 
             UndirectedEdge[314, 411] -> 
             RGBColor[
              0.9800429545454545, 0.9590388181818181, 0.636247909090909], 
             UndirectedEdge[211, 466] -> 
             RGBColor[0.9941475, 0.9916299090909091, 0.7308122272727275], 
             UndirectedEdge[12, 202] -> 
             RGBColor[
              0.9926352272727272, 0.9910045454545455, 0.7558745000000001], 
             UndirectedEdge[96, 360] -> 
             RGBColor[0.8418806363636363, 0.8771819999999999, 0.9767245], 
             UndirectedEdge[199, 482] -> 
             RGBColor[
              0.9414603636363637, 0.9555905454545455, 0.974571409090909], 
             UndirectedEdge[9, 357] -> 
             RGBColor[0.7922115, 0.8381960909090909, 0.9797659545454545], 
             UndirectedEdge[330, 441] -> 
             RGBColor[
              0.8066628181818182, 0.8492012727272727, 0.9495090454545454], 
             UndirectedEdge[375, 461] -> 
             RGBColor[
              0.9190756818181818, 0.6907473181818184, 0.5289635000000001], 
             UndirectedEdge[170, 268] -> 
             RGBColor[
              0.9806038636363636, 0.9840500000000001, 0.8727119999999999], 
             UndirectedEdge[66, 245] -> 
             RGBColor[
              0.8183152272727272, 0.8553452727272728, 0.7914246818181816], 
             UndirectedEdge[235, 308] -> 
             RGBColor[
              0.8417789090909091, 0.8726462727272728, 0.711345136363636], 
             UndirectedEdge[42, 315] -> 
             RGBColor[
              0.9256810454545454, 0.9430085454545454, 0.9730663636363637], 
             UndirectedEdge[238, 403] -> 
             RGBColor[
              0.8429157727272727, 0.8750779090909091, 0.8350857272727275], 
             UndirectedEdge[382, 425] -> 
             RGBColor[
              0.8176590454545454, 0.8582599090909091, 0.9743103181818182], 
             UndirectedEdge[74, 215] -> 
             RGBColor[
              0.7676591363636363, 0.818409818181818, 0.9698667727272727], 
             UndirectedEdge[350, 426] -> 
             RGBColor[0.8662555, 0.8938532727272728, 0.8679570454545456], 
             UndirectedEdge[78, 497] -> 
             RGBColor[
              0.9800999545454545, 0.9434431818181819, 0.4700001363636363], 
             UndirectedEdge[109, 490] -> 
             RGBColor[
              0.7587132727272727, 0.6230638636363635, 0.5912268181818181], 
             UndirectedEdge[281, 317] -> 
             RGBColor[
              0.7418808181818182, 0.7974818181818182, 0.9678374090909091], 
             UndirectedEdge[219, 471] -> 
             RGBColor[
              0.9724789090909091, 0.9784929090909091, 0.9089678181818182], 
             UndirectedEdge[183, 243] -> 
             RGBColor[
              0.5617214545454545, 0.6317673181818182, 0.9561526363636363], 
             UndirectedEdge[93, 151] -> 
             RGBColor[
              0.9800429545454545, 0.9590388181818181, 0.636247909090909], 
             UndirectedEdge[176, 478] -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             UndirectedEdge[28, 282] -> 
             RGBColor[
              0.9322937272727272, 0.9479402727272728, 0.9618728181818181], 
             UndirectedEdge[125, 305] -> 
             RGBColor[0.9941475, 0.9916299090909091, 0.7308122272727275], 
             UndirectedEdge[22, 466] -> 
             RGBColor[
              0.7413592272727272, 0.7933718181818181, 0.8265834545454547], 
             UndirectedEdge[78, 154] -> 
             RGBColor[
              0.697508909090909, 0.7558418181818182, 0.7823087727272725], 
             UndirectedEdge[273, 421] -> 
             RGBColor[0.8906010454545454, 0.911301, 0.7574203636363638], 
             UndirectedEdge[221, 234] -> 
             RGBColor[
              0.9502394545454544, 0.9106278181818181, 0.6311146363636364], 
             UndirectedEdge[384, 461] -> 
             RGBColor[
              0.9658662272727272, 0.9735611818181817, 0.9201613636363637], 
             UndirectedEdge[3, 428] -> 
             RGBColor[
              0.9734302727272728, 0.954107090909091, 0.6474414545454544], 
             UndirectedEdge[209, 431] -> 
             RGBColor[
              0.900735090909091, 0.9227762727272728, 0.9588627272727273], 
             UndirectedEdge[33, 237] -> 
             RGBColor[
              0.8875301363636363, 0.5510655454545454, 0.560317590909091], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.8632309545454545, 0.8926025454545454, 0.9180815909090909], 
             UndirectedEdge[202, 243] -> 
             RGBColor[
              0.9697726363636363, 0.9749586363636363, 0.839579681818182], 
             UndirectedEdge[169, 456] -> 
             RGBColor[0.9938925000000001, 0.989345, 0.5766145], 
             UndirectedEdge[86, 297] -> 
             RGBColor[
              0.9926352272727272, 0.9910045454545455, 0.7558745000000001], 
             UndirectedEdge[40, 202] -> 
             RGBColor[
              0.7929158636363636, 0.835227818181818, 0.830642181818182], 
             UndirectedEdge[396, 477] -> 
             RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             UndirectedEdge[209, 355] -> 
             RGBColor[
              0.6848746363636364, 0.7522540000000001, 0.9702829545454545], 
             UndirectedEdge[131, 434] -> 
             RGBColor[0.8418806363636363, 0.8771819999999999, 0.9767245], 
             UndirectedEdge[87, 228] -> 
             RGBColor[
              0.9127944545454545, 0.6351733636363635, 0.29262254545454536`], 
             UndirectedEdge[17, 116] -> 
             RGBColor[
              0.8564339999999999, 0.8886222727272728, 0.9860993636363635], 
             UndirectedEdge[104, 323] -> 
             RGBColor[
              0.9434432272727272, 0.9547480909090909, 0.8754924545454545], 
             UndirectedEdge[101, 347] -> 
             RGBColor[
              0.8374970909090909, 0.8730550909090908, 0.9407296818181818], 
             UndirectedEdge[92, 342] -> 
             RGBColor[0.7632311363636364, 0.8129023636363637, 0.9091945], 
             UndirectedEdge[399, 464] -> 
             RGBColor[
              0.7662556818181818, 0.814153090909091, 0.8590699545454545], 
             UndirectedEdge[423, 469] -> 
             RGBColor[
              0.9239607727272727, 0.9284057272727272, 0.6931360909090909], 
             UndirectedEdge[114, 415] -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             UndirectedEdge[244, 478] -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909092], 
             UndirectedEdge[129, 486] -> 
             RGBColor[
              0.6235341818181819, 0.6982013636363635, 0.9672285454545455], 
             UndirectedEdge[202, 421] -> 
             RGBColor[
              0.8913589545454546, 0.9129220909090909, 0.8399140909090911], 
             UndirectedEdge[62, 378] -> 
             RGBColor[0.7922115, 0.8381960909090909, 0.9797659545454545], 
             UndirectedEdge[263, 485] -> 
             RGBColor[
              0.6314042727272726, 0.7071885454545455, 0.9667308181818182], 
             UndirectedEdge[275, 346] -> 
             RGBColor[
              0.8793275909090909, 0.9059675454545455, 0.9567515909090909], 
             UndirectedEdge[127, 303] -> 
             RGBColor[
              0.6772916363636363, 0.7394300454545455, 0.852756590909091], 
             UndirectedEdge[260, 312] -> 
             RGBColor[0.8079908181818182, 0.850778090909091, 0.981271], 
             UndirectedEdge[32, 299] -> 
             RGBColor[
              0.9715897727272726, 0.9260483636363637, 0.5724717272727273], 
             UndirectedEdge[283, 396] -> 
             RGBColor[
              0.5457742727272727, 0.6399536363636363, 0.9582862727272727], 
             UndirectedEdge[87, 253] -> 
             RGBColor[
              0.9865379545454545, 0.9764720909090909, 0.6305425909090908], 
             UndirectedEdge[298, 409] -> 
             RGBColor[
              0.6314042727272726, 0.7071885454545455, 0.9667308181818182], 
             UndirectedEdge[208, 258] -> 
             RGBColor[
              0.8551059999999999, 0.8870454545454545, 0.954337409090909], 
             UndirectedEdge[142, 161] -> 
             RGBColor[
              0.9668175909090909, 0.9491753636363636, 0.6586349999999999], 
             UndirectedEdge[71, 211] -> 
             RGBColor[
              0.9895624999999999, 0.9777228181818182, 0.5804180454545455], 
             UndirectedEdge[14, 453] -> 
             RGBColor[
              0.9693936818181818, 0.9741480909090909, 0.798332818181818], 
             UndirectedEdge[89, 478] -> 
             RGBColor[
              0.9118845909090909, 0.9295840909090909, 0.8724823636363637], 
             UndirectedEdge[159, 251] -> 
             RGBColor[
              0.9690147272727272, 0.9733375454545454, 0.7570859545454547], 
             UndirectedEdge[300, 305] -> 
             RGBColor[
              0.9601044090909091, 0.9674768181818182, 0.8465403636363638], 
             UndirectedEdge[327, 385] -> 
             RGBColor[0.9073477727272727, 0.927708, 0.9476691818181818], 
             UndirectedEdge[156, 270] -> 
             RGBColor[
              0.7934374545454546, 0.8393378181818182, 0.9718961363636364], 
             UndirectedEdge[418, 486] -> 
             RGBColor[0.8079908181818182, 0.850778090909091, 0.981271], 
             UndirectedEdge[366, 465] -> 
             RGBColor[
              0.8909799999999999, 0.9121115454545454, 0.7986672272727271], 
             UndirectedEdge[337, 433] -> 
             RGBColor[
              0.9845797727272727, 0.960914909090909, 0.561061090909091], 
             UndirectedEdge[118, 152] -> 
             RGBColor[0.990744, 0.9895686363636363, 0.7396899090909089], 
             UndirectedEdge[151, 162] -> 
             RGBColor[
              0.8091264545454546, 0.8254408181818182, 0.662920409090909], 
             UndirectedEdge[80, 251] -> 
             RGBColor[
              0.6971299545454546, 0.7550312727272728, 0.7410619090909092], 
             UndirectedEdge[348, 486] -> 
             RGBColor[
              0.9589675454545454, 0.9650451818181819, 0.7227997727272726], 
             UndirectedEdge[376, 455] -> 
             RGBColor[
              0.6665805909090909, 0.739457090909091, 0.9674021818181817], 
             UndirectedEdge[153, 197] -> 
             RGBColor[
              0.6748756363636362, 0.7439079999999999, 0.9697586363636364], 
             UndirectedEdge[9, 319] -> 
             RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             UndirectedEdge[184, 336] -> 
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181], 
             UndirectedEdge[41, 56] -> 
             RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 
             UndirectedEdge[99, 313] -> 
             RGBColor[
              0.8176590454545454, 0.8582599090909091, 0.9743103181818182], 
             UndirectedEdge[111, 130] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[255, 327] -> 
             RGBColor[
              0.9800429545454545, 0.9590388181818181, 0.636247909090909], 
             UndirectedEdge[32, 84] -> 
             RGBColor[
              0.9658662272727272, 0.9735611818181817, 0.9201613636363637], 
             UndirectedEdge[196, 420] -> 
             RGBColor[
              0.8390093636363636, 0.8736804545454545, 0.9156674090909092], 
             UndirectedEdge[55, 57] -> 
             RGBColor[
              0.7293278636363636, 0.7864172727272727, 0.9434209545454545], 
             UndirectedEdge[10, 480] -> 
             RGBColor[
              0.9760063636363636, 0.9790798181818181, 0.7871392727272726], 
             UndirectedEdge[152, 216] -> 
             RGBColor[
              0.9281668181818181, 0.9415022727272726, 0.8022834090909089], 
             UndirectedEdge[244, 482] -> 
             RGBColor[
              0.9724789090909091, 0.9784929090909091, 0.9089678181818182], 
             UndirectedEdge[111, 463] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[58, 74] -> 
             RGBColor[
              0.6923454999999998, 0.7569099545454544, 0.964036409090909], 
             UndirectedEdge[66, 327] -> 
             RGBColor[0.8132755, 0.854133, 0.9383155], 
             UndirectedEdge[168, 346] -> 
             RGBColor[
              0.8913589545454546, 0.9129220909090909, 0.8399140909090911], 
             UndirectedEdge[53, 471] -> 
             RGBColor[
              0.9724789090909091, 0.9784929090909091, 0.9089678181818182], 
             UndirectedEdge[28, 125] -> 
             RGBColor[
              0.9821161363636364, 0.9846753636363637, 0.8476497272727272], 
             UndirectedEdge[405, 423] -> 
             RGBColor[0.9893075, 0.9754379090909091, 0.4262203181818179], 
             UndirectedEdge[314, 493] -> 
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181], 
             UndirectedEdge[43, 229] -> 
             RGBColor[
              0.9103723181818182, 0.9289587272727273, 0.8975446363636364], 
             UndirectedEdge[281, 397] -> 
             RGBColor[
              0.9693936818181818, 0.9741480909090909, 0.798332818181818], 
             UndirectedEdge[203, 324] -> 
             RGBColor[
              0.9690147272727272, 0.9733375454545454, 0.7570859545454547], 
             UndirectedEdge[403, 445] -> 
             RGBColor[
              0.5457742727272727, 0.6399536363636363, 0.9582862727272727], 
             UndirectedEdge[147, 303] -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909092], 
             UndirectedEdge[356, 457] -> 
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181], 
             UndirectedEdge[8, 85] -> 
             RGBColor[
              0.43486459090909085`, 0.5318865909090909, 0.9516586818181818], 
             UndirectedEdge[301, 336] -> 
             RGBColor[
              0.8859402727272727, 0.9108992727272727, 0.9455580454545454], 
             UndirectedEdge[24, 64] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[30, 488] -> 
             RGBColor[
              0.6529167727272727, 0.7227587727272726, 0.9615240454545455], 
             UndirectedEdge[191, 366] -> 
             RGBColor[
              0.8025037727272727, 0.4840972727272727, 0.5718455454545455], 
             UndirectedEdge[185, 481] -> 
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363], 
             UndirectedEdge[308, 389] -> 
             RGBColor[
              0.8417789090909091, 0.8726462727272728, 0.7113451363636362], 
             UndirectedEdge[96, 240] -> 
             RGBColor[0.9686357727272727, 0.972527, 0.7158390909090907], 
             UndirectedEdge[108, 113] -> 
             RGBColor[
              0.9755034545454545, 0.9797436363636364, 0.8588432727272728], 
             UndirectedEdge[85, 332] -> 
             RGBColor[
              0.7764321818181817, 0.8256140909090908, 0.9782609090909091], 
             UndirectedEdge[232, 280] -> 
             RGBColor[
              0.7367742272727272, 0.7794647272727272, 0.6761892727272727], 
             UndirectedEdge[310, 419] -> 
             RGBColor[
              0.9673784999999999, 0.9741865454545455, 0.8950990909090908], 
             UndirectedEdge[39, 378] -> 
             RGBColor[
              0.9419309545454545, 0.9541227272727273, 0.9005547272727272], 
             UndirectedEdge[53, 257] -> 
             RGBColor[
              0.9618348636363636, 0.9323674545454547, 0.6392780454545456], 
             UndirectedEdge[248, 339] -> 
             RGBColor[
              0.8661022272727272, 0.8961040909090909, 0.9791386818181818], 
             UndirectedEdge[327, 334] -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             UndirectedEdge[165, 358] -> 
             RGBColor[
              0.8663794545454546, 0.8923789090909091, 0.7550061818181819], 
             UndirectedEdge[69, 204] -> 
             RGBColor[
              0.9118845909090909, 0.9295840909090909, 0.8724823636363637], 
             UndirectedEdge[208, 293] -> 
             RGBColor[
              0.916514409090909, 0.9353582727272727, 0.9603677727272727], 
             UndirectedEdge[265, 320] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             UndirectedEdge[239, 453] -> 
             RGBColor[
              0.9942714545454545, 0.9901555454545454, 0.6178613636363632], 
             UndirectedEdge[108, 452] -> 
             RGBColor[
              0.8178123181818182, 0.8560090909090909, 0.8631286818181818], 
             UndirectedEdge[331, 418] -> 
             RGBColor[
              0.8421578636363636, 0.8734568181818182, 0.7525920000000001], 
             UndirectedEdge[28, 201] -> 
             RGBColor[0.982998, 0.9848220909090909, 0.8171925909090911], 
             UndirectedEdge[431, 486] -> 
             RGBColor[
              0.9480730454545454, 0.9605222727272728, 0.9633778636363636], 
             UndirectedEdge[269, 419] -> 
             RGBColor[
              0.9806038636363636, 0.9840500000000001, 0.8727119999999999], 
             UndirectedEdge[315, 378] -> 
             RGBColor[
              0.9256810454545454, 0.9430085454545454, 0.9730663636363637], 
             UndirectedEdge[57, 240] -> 
             RGBColor[
              0.7402223636363636, 0.7909401818181818, 0.7028428636363634], 
             UndirectedEdge[7, 176] -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             UndirectedEdge[6, 302] -> 
             RGBColor[
              0.9358782272727273, 0.7850346363636365, 0.5697681818181819], 
             UndirectedEdge[176, 455] -> 
             RGBColor[
              0.8178123181818182, 0.8560090909090909, 0.8631286818181818], 
             UndirectedEdge[161, 396] -> 
             RGBColor[
              0.8333480454545454, 0.844362909090909, 0.6653345909090909], 
             UndirectedEdge[36, 463] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[131, 373] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[54, 341] -> 
             RGBColor[
              0.9724789090909091, 0.9784929090909091, 0.9089678181818182], 
             UndirectedEdge[272, 453] -> 
             RGBColor[0.990744, 0.9895686363636363, 0.7396899090909089], 
             UndirectedEdge[169, 236] -> 
             RGBColor[0.9922562727272727, 0.990194, 0.7146276363636361], 
             UndirectedEdge[69, 101] -> 
             RGBColor[
              0.9887288181818181, 0.9896070909090909, 0.8364561818181819], 
             UndirectedEdge[286, 330] -> 
             RGBColor[
              0.8178123181818182, 0.8560090909090909, 0.8631286818181818], 
             UndirectedEdge[86, 254] -> 
             RGBColor[
              0.9917533636363636, 0.9908578181818182, 0.7863316363636363], 
             UndirectedEdge[68, 319] -> 
             RGBColor[
              0.43486459090909085`, 0.5318865909090909, 0.9516586818181818], 
             UndirectedEdge[37, 207] -> 
             RGBColor[
              0.9888527727272727, 0.9881327272727274, 0.7235053181818183], 
             UndirectedEdge[257, 317] -> 
             RGBColor[
              0.752587090909091, 0.7667769090909093, 0.6395047272727274], 
             UndirectedEdge[94, 158] -> 
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454], 
             UndirectedEdge[253, 336] -> 
             RGBColor[
              0.9857042727272727, 0.9883563636363637, 0.8865807272727273], 
             UndirectedEdge[67, 363] -> 
             RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 
             UndirectedEdge[61, 295] -> 
             RGBColor[
              0.916514409090909, 0.9353582727272727, 0.9603677727272727], 
             UndirectedEdge[16, 116] -> 
             RGBColor[
              0.6892454545454544, 0.7563732727272726, 0.9702011818181817], 
             UndirectedEdge[294, 439] -> 
             RGBColor[0.8662555, 0.8938532727272728, 0.8679570454545456], 
             UndirectedEdge[69, 346] -> 
             RGBColor[
              0.8904770909090909, 0.9127753636363636, 0.8703712272727273], 
             UndirectedEdge[327, 415] -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             UndirectedEdge[54, 61] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[244, 262] -> 
             RGBColor[
              0.9311420454545454, 0.7572872272727271, 0.5394920454545454], 
             UndirectedEdge[295, 397] -> 
             RGBColor[
              0.9281668181818181, 0.9415022727272726, 0.8022834090909089], 
             UndirectedEdge[61, 264] -> 
             RGBColor[
              0.8308844090909091, 0.8681233636363637, 0.9519232272727272], 
             UndirectedEdge[162, 226] -> 
             RGBColor[
              0.8147877727272728, 0.8547583636363636, 0.9132532272727273], 
             UndirectedEdge[237, 351] -> 
             RGBColor[
              0.9022677727272728, 0.5615543636363636, 0.5128682272727273], 
             UndirectedEdge[243, 273] -> 
             RGBColor[
              0.9690147272727272, 0.9733375454545454, 0.7570859545454547], 
             UndirectedEdge[53, 343] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[37, 445] -> 
             RGBColor[
              0.6971299545454546, 0.7550312727272728, 0.7410619090909092], 
             UndirectedEdge[144, 402] -> 
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454], 
             UndirectedEdge[235, 456] -> 
             RGBColor[
              0.993134590909091, 0.9877239090909091, 0.49412077272727273`], 
             UndirectedEdge[369, 456] -> 
             RGBColor[
              0.8663794545454546, 0.8923789090909091, 0.7550061818181819], 
             UndirectedEdge[7, 61] -> 
             RGBColor[
              0.9821161363636364, 0.9846753636363637, 0.8476497272727272], 
             UndirectedEdge[76, 175] -> 
             RGBColor[
              0.5457742727272727, 0.6399536363636363, 0.9582862727272727], 
             UndirectedEdge[259, 372] -> 
             RGBColor[
              0.9063581363636364, 0.6039933181818181, 0.5432955909090909], 
             UndirectedEdge[187, 224] -> 
             RGBColor[
              0.8429157727272727, 0.8750779090909091, 0.8350857272727275], 
             UndirectedEdge[142, 183] -> 
             RGBColor[
              0.5683341363636364, 0.6366990454545455, 0.9449590909090909], 
             UndirectedEdge[255, 299] -> 
             RGBColor[
              0.9659284545454545, 0.8967308181818181, 0.32213890909090903`], 
             UndirectedEdge[233, 444] -> 
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181], 
             UndirectedEdge[148, 280] -> 
             RGBColor[
              0.6376888181818181, 0.7145172727272726, 0.9661424545454544], 
             UndirectedEdge[7, 376] -> 
             RGBColor[
              0.842033909090909, 0.8749311818181817, 0.8655428636363637], 
             UndirectedEdge[73, 256] -> 
             RGBColor[
              0.9031987272727273, 0.8990158181818182, 0.6722740909090908], 
             UndirectedEdge[207, 403] -> 
             RGBColor[
              0.8374970909090909, 0.8730550909090908, 0.9407296818181818], 
             UndirectedEdge[233, 346] -> 
             RGBColor[
              0.8859402727272727, 0.9108992727272727, 0.9455580454545454], 
             UndirectedEdge[293, 403] -> 
             RGBColor[
              0.7764321818181817, 0.8256140909090908, 0.9782609090909091], 
             UndirectedEdge[321, 391] -> 
             RGBColor[
              0.9436389545454545, 0.8140327727272729, 0.5499197727272728], 
             UndirectedEdge[228, 298] -> 
             RGBColor[
              0.8508958636363635, 0.5996166363636362, 0.5861919090909091], 
             UndirectedEdge[54, 455] -> 
             RGBColor[
              0.8000501363636363, 0.8442695454545455, 0.9607025909090909], 
             UndirectedEdge[323, 419] -> 
             RGBColor[
              0.9419309545454545, 0.9541227272727273, 0.9005547272727272], 
             UndirectedEdge[65, 194] -> 
             RGBColor[
              0.9601044090909091, 0.9674768181818182, 0.8465403636363638], 
             UndirectedEdge[40, 273] -> 
             RGBColor[
              0.7921579545454545, 0.8336067272727272, 0.7481484545454546], 
             UndirectedEdge[209, 400] -> 
             RGBColor[
              0.9081814545454545, 0.9158237272727272, 0.6916310454545453], 
             UndirectedEdge[31, 488] -> 
             RGBColor[
              0.287824909090909, 0.4149919999999999, 0.9398805454545454], 
             UndirectedEdge[399, 407] -> 
             RGBColor[
              0.8904770909090909, 0.9127753636363636, 0.8703712272727273], 
             UndirectedEdge[292, 399] -> 
             RGBColor[
              0.9118845909090909, 0.9295840909090909, 0.8724823636363637], 
             UndirectedEdge[93, 218] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[198, 270] -> 
             RGBColor[
              0.8066628181818182, 0.8492012727272727, 0.9495090454545454], 
             UndirectedEdge[78, 192] -> 
             RGBColor[0.9922562727272727, 0.990194, 0.7146276363636361], 
             UndirectedEdge[286, 492] -> 
             RGBColor[0.8662555, 0.8938532727272728, 0.8679570454545456], 
             UndirectedEdge[317, 343] -> 
             RGBColor[0.7006539545454545, 0.7648360000000001, 0.971788], 
             UndirectedEdge[51, 203] -> 
             RGBColor[
              0.9348476818181818, 0.9506588181818182, 0.9857649545454545], 
             UndirectedEdge[212, 216] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[100, 257] -> 
             RGBColor[
              0.9800999545454545, 0.9434431818181819, 0.4700001363636363], 
             UndirectedEdge[189, 302] -> 
             RGBColor[
              0.8748133181818182, 0.7375936363636364, 0.6072994090909092], 
             UndirectedEdge[306, 382] -> 
             RGBColor[
              0.9658662272727272, 0.9735611818181817, 0.9201613636363637], 
             UndirectedEdge[20, 150] -> 
             RGBColor[
              0.8186941818181819, 0.8561558181818182, 0.8326715454545457], 
             UndirectedEdge[255, 446] -> 
             RGBColor[
              0.9505366818181819, 0.9367618181818183, 0.6767892272727272], 
             UndirectedEdge[182, 237] -> 
             RGBColor[
              0.8239112727272728, 0.5009060000000001, 0.5739566818181818], 
             UndirectedEdge[4, 366] -> 
             RGBColor[
              0.8904770909090909, 0.9127753636363636, 0.8703712272727273], 
             UndirectedEdge[231, 275] -> 
             RGBColor[
              0.9053480909090909, 0.642125909090909, 0.5598542272727273], 
             UndirectedEdge[97, 231] -> 
             RGBColor[
              0.6005235909090908, 0.3968805909090908, 0.5649610909090909], 
             UndirectedEdge[114, 128] -> 
             RGBColor[
              0.9887288181818181, 0.9896070909090909, 0.8364561818181819], 
             UndirectedEdge[207, 471] -> 
             RGBColor[
              0.9857042727272727, 0.9883563636363637, 0.8865807272727273], 
             UndirectedEdge[54, 391] -> 
             RGBColor[
              0.9289013181818182, 0.8035439545454547, 0.5973691363636364], 
             UndirectedEdge[299, 478] -> 
             RGBColor[
              0.9746143181818181, 0.9272990909090909, 0.5223471818181818], 
             UndirectedEdge[44, 365] -> 
             RGBColor[
              0.9746143181818181, 0.9272990909090909, 0.5223471818181818], 
             UndirectedEdge[6, 101] -> RGBColor[0.984192, 0.987731, 0.911643],
              UndirectedEdge[236, 308] -> 
             RGBColor[
              0.8405216363636363, 0.8743058181818182, 0.8906051363636363], 
             UndirectedEdge[47, 256] -> 
             RGBColor[
              0.8090960454545455, 0.8508762727272727, 0.9815842272727273], 
             UndirectedEdge[304, 427] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[54, 397] -> 
             RGBColor[
              0.9760063636363636, 0.9790798181818181, 0.7871392727272726], 
             UndirectedEdge[220, 254] -> 
             RGBColor[0.697006, 0.7565056363636364, 0.8540127727272728], 
             UndirectedEdge[377, 426] -> 
             RGBColor[
              0.8071564545454545, 0.6609080454545453, 0.5960551818181818], 
             UndirectedEdge[216, 292] -> 
             RGBColor[
              0.8462828636363636, 0.8802669999999999, 0.9852004090909091], 
             UndirectedEdge[42, 119] -> 
             RGBColor[0.7164332727272728, 0.777418, 0.9732930454545454], 
             UndirectedEdge[170, 491] -> 
             RGBColor[
              0.9423000909090908, 0.8365801818181817, 0.591697909090909], 
             UndirectedEdge[257, 326] -> 
             RGBColor[
              0.778365409090909, 0.7877049090909092, 0.641534090909091], 
             UndirectedEdge[98, 347] -> 
             RGBColor[
              0.8374970909090909, 0.8730550909090908, 0.9407296818181818], 
             UndirectedEdge[271, 311] -> 
             RGBColor[
              0.9511285909090909, 0.9630723636363636, 0.9676107272727272], 
             UndirectedEdge[156, 227] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[151, 160] -> 
             RGBColor[
              0.9808766363636363, 0.9471545454545454, 0.3802097727272725], 
             UndirectedEdge[93, 167] -> 
             RGBColor[
              0.8617186818181818, 0.8919771818181819, 0.9431438636363636], 
             UndirectedEdge[275, 348] -> 
             RGBColor[
              0.9818611363636364, 0.9823904545454546, 0.6934519999999997], 
             UndirectedEdge[34, 394] -> 
             RGBColor[0.732212590909091, 0.79, 0.9747980909090909], 
             UndirectedEdge[405, 488] -> 
             RGBColor[
              0.6770366363636363, 0.7371451363636363, 0.6985588636363634], 
             UndirectedEdge[338, 443] -> 
             RGBColor[
              0.9756274090909092, 0.9782692727272728, 0.7458924090909093], 
             UndirectedEdge[301, 316] -> 
             RGBColor[
              0.6376888181818181, 0.7145172727272726, 0.9661424545454544], 
             UndirectedEdge[103, 209] -> 
             RGBColor[
              0.9081814545454545, 0.9158237272727272, 0.6916310454545453], 
             UndirectedEdge[126, 414] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[154, 341] -> 
             RGBColor[
              0.6939814545454546, 0.7552549090909091, 0.9041373181818182], 
             UndirectedEdge[306, 347] -> 
             RGBColor[
              0.8390093636363636, 0.8736804545454545, 0.9156674090909092], 
             UndirectedEdge[20, 388] -> 
             RGBColor[
              0.5018383181818181, 0.6039559545454545, 0.954615909090909], 
             UndirectedEdge[286, 319] -> 
             RGBColor[
              0.842033909090909, 0.8749311818181817, 0.8655428636363637], 
             UndirectedEdge[62, 96] -> 
             RGBColor[
              0.8176590454545454, 0.8582599090909091, 0.9743103181818182], 
             UndirectedEdge[149, 242] -> 
             RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 
             UndirectedEdge[212, 319] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[289, 470] -> 
             RGBColor[
              0.9032890454545454, 0.9254948181818181, 0.9827548636363637], 
             UndirectedEdge[291, 353] -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             UndirectedEdge[21, 91] -> 
             RGBColor[
              0.6892454545454544, 0.7563732727272726, 0.9702011818181817], 
             UndirectedEdge[95, 224] -> 
             RGBColor[
              0.8390093636363636, 0.8736804545454545, 0.9156674090909092], 
             UndirectedEdge[218, 235] -> 
             RGBColor[
              0.9884738181818182, 0.9873221818181819, 0.6822584545454543], 
             UndirectedEdge[108, 315] -> 
             RGBColor[
              0.9755034545454545, 0.9797436363636364, 0.8588432727272728], 
             UndirectedEdge[61, 154] -> 
             RGBColor[0.6858565, 0.7496978181818181, 0.9403931363636363], 
             UndirectedEdge[297, 413] -> 
             RGBColor[0.6781735, 0.7395767727272726, 0.8222994545454547], 
             UndirectedEdge[294, 438] -> 
             RGBColor[
              0.9755034545454545, 0.9797436363636364, 0.8588432727272728], 
             UndirectedEdge[277, 386] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[125, 249] -> 
             RGBColor[
              0.9434432272727272, 0.9547480909090909, 0.8754924545454545], 
             UndirectedEdge[211, 308] -> 
             RGBColor[
              0.842033909090909, 0.8749311818181817, 0.8655428636363637], 
             UndirectedEdge[273, 477] -> 
             RGBColor[
              0.8421578636363636, 0.8734568181818182, 0.7525920000000001], 
             UndirectedEdge[154, 397] -> 
             RGBColor[
              0.697508909090909, 0.7558418181818182, 0.7823087727272725], 
             UndirectedEdge[105, 230] -> 
             RGBColor[
              0.9739911818181818, 0.9791182727272727, 0.8839055454545454], 
             UndirectedEdge[355, 404] -> 
             RGBColor[
              0.6894876363636364, 0.47160363636363634`, 0.5712744545454544], 
             UndirectedEdge[250, 263] -> 
             RGBColor[
              0.916514409090909, 0.9353582727272727, 0.9603677727272727], 
             UndirectedEdge[11, 259] -> 
             RGBColor[0.9073477727272727, 0.927708, 0.9476691818181818], 
             UndirectedEdge[339, 439] -> 
             RGBColor[0.8418806363636363, 0.8771819999999999, 0.9767245], 
             UndirectedEdge[303, 379] -> 
             RGBColor[
              0.9434432272727272, 0.9547480909090909, 0.8754924545454545], 
             UndirectedEdge[416, 468] -> 
             RGBColor[
              0.6590963181818181, 0.7313259999999999, 0.9682535909090909], 
             UndirectedEdge[77, 336] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[297, 412] -> 
             RGBColor[
              0.9697726363636363, 0.9749586363636363, 0.839579681818182], 
             UndirectedEdge[69, 418] -> 
             RGBColor[
              0.842033909090909, 0.8749311818181817, 0.8655428636363637], 
             UndirectedEdge[281, 322] -> 
             RGBColor[
              0.8176590454545454, 0.8582599090909091, 0.9743103181818182], 
             UndirectedEdge[51, 495] -> 
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363], 
             UndirectedEdge[227, 229] -> 
             RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454544], 
             UndirectedEdge[192, 497] -> 
             RGBColor[
              0.9780847727272728, 0.9434816363636365, 0.5667664090909091], 
             UndirectedEdge[143, 277] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[87, 161] -> 
             RGBColor[
              0.9808766363636363, 0.9471545454545454, 0.3802097727272725], 
             UndirectedEdge[114, 255] -> 
             RGBColor[
              0.9800429545454545, 0.9590388181818181, 0.636247909090909], 
             UndirectedEdge[341, 391] -> 
             RGBColor[
              0.9436389545454545, 0.8140327727272729, 0.5499197727272728], 
             UndirectedEdge[35, 347] -> 
             RGBColor[
              0.5457742727272727, 0.6399536363636363, 0.9582862727272727], 
             UndirectedEdge[99, 498] -> 
             RGBColor[
              0.8921227272727272, 0.6322624545454545, 0.5822413181818182], 
             UndirectedEdge[89, 448] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[130, 371] -> 
             RGBColor[
              0.8661022272727272, 0.8961040909090909, 0.9791386818181818], 
             UndirectedEdge[187, 481] -> 
             RGBColor[
              0.9601044090909091, 0.9674768181818182, 0.8465403636363638], 
             UndirectedEdge[427, 500] -> 
             RGBColor[
              0.6989581818181817, 0.7618416818181817, 0.9528428636363636], 
             UndirectedEdge[134, 247] -> 
             RGBColor[
              0.6735884999999999, 0.7256696818181817, 0.6719052727272725], 
             UndirectedEdge[79, 301] -> 
             RGBColor[
              0.8913589545454546, 0.9129220909090909, 0.8399140909090911], 
             UndirectedEdge[173, 323] -> 
             RGBColor[
              0.6274692272727271, 0.7026949545454545, 0.9669796818181817], 
             UndirectedEdge[84, 262] -> 
             RGBColor[
              0.9097917272727272, 0.7418666818181816, 0.5981349545454545], 
             UndirectedEdge[262, 391] -> 
             RGBColor[
              0.8875644545454545, 0.5823382727272728, 0.22789336363636364`], 
             UndirectedEdge[205, 382] -> 
             RGBColor[
              0.9348476818181818, 0.9506588181818182, 0.9857649545454545], 
             UndirectedEdge[50, 499] -> 
             RGBColor[
              0.7150237727272727, 0.7773012727272727, 0.9722305454545455], 
             UndirectedEdge[108, 380] -> 
             RGBColor[
              0.9821161363636364, 0.9846753636363637, 0.8476497272727272], 
             UndirectedEdge[300, 493] -> 
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363], 
             UndirectedEdge[331, 382] -> 
             RGBColor[
              0.9690147272727272, 0.9733375454545454, 0.7570859545454547], 
             UndirectedEdge[186, 495] -> 
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454], 
             UndirectedEdge[93, 235] -> 
             RGBColor[
              0.9884738181818182, 0.9873221818181819, 0.6822584545454543], 
             UndirectedEdge[18, 300] -> 
             RGBColor[
              0.9577102727272727, 0.9667047272727274, 0.9020597727272726], 
             UndirectedEdge[223, 246] -> 
             RGBColor[
              0.8909799999999999, 0.9121115454545454, 0.7986672272727271], 
             UndirectedEdge[233, 431] -> 
             RGBColor[
              0.9775793181818182, 0.9827992727272727, 0.9228365454545454], 
             UndirectedEdge[182, 351] -> 
             RGBColor[
              0.9088600454545455, 0.9283333636363637, 0.9226069090909091], 
             UndirectedEdge[163, 209] -> 
             RGBColor[0.9073477727272727, 0.927708, 0.9476691818181818], 
             UndirectedEdge[70, 182] -> 
             RGBColor[
              0.8875097272727273, 0.9129128181818182, 0.9812498181818182], 
             UndirectedEdge[59, 335] -> 
             RGBColor[
              0.9190683636363636, 0.9380768181818182, 0.9842599090909091], 
             UndirectedEdge[258, 453] -> 
             RGBColor[
              0.8667584090909091, 0.8931894545454545, 0.7962530454545452], 
             UndirectedEdge[161, 354] -> 
             RGBColor[
              0.960204909090909, 0.9442436363636364, 0.6698285454545454], 
             UndirectedEdge[213, 489] -> 
             RGBColor[
              0.9857042727272727, 0.9883563636363637, 0.8865807272727273], 
             UndirectedEdge[260, 407] -> 
             RGBColor[
              0.8564339999999999, 0.8886222727272728, 0.9860993636363635], 
             UndirectedEdge[95, 185] -> 
             RGBColor[0.956198, 0.9660793636363636, 0.9271220454545455], 
             UndirectedEdge[117, 479] -> 
             RGBColor[
              0.6156249545454546, 0.6946065454545455, 0.9652257727272727], 
             UndirectedEdge[164, 444] -> 
             RGBColor[
              0.7579909090909089, 0.8109279999999999, 0.9768274545454545], 
             UndirectedEdge[32, 334] -> 
             RGBColor[
              0.9724789090909091, 0.9784929090909091, 0.9089678181818182], 
             UndirectedEdge[46, 325] -> 
             RGBColor[
              0.8374970909090909, 0.8730550909090908, 0.9407296818181818], 
             UndirectedEdge[18, 201] -> 
             RGBColor[
              0.9926352272727272, 0.9910045454545455, 0.7558745000000001], 
             UndirectedEdge[328, 398] -> 
             RGBColor[
              0.9752484545454545, 0.9774587272727273, 0.7046455454545453], 
             UndirectedEdge[376, 448] -> 
             RGBColor[0.8079908181818182, 0.850778090909091, 0.981271], 
             UndirectedEdge[326, 355] -> 
             RGBColor[0.5650240454545454, 0.657751, 0.958899909090909], 
             UndirectedEdge[257, 281] -> 
             RGBColor[
              0.9552221818181819, 0.9274357272727274, 0.650471590909091], 
             UndirectedEdge[32, 89] -> 
             RGBColor[
              0.9088600454545455, 0.9283333636363637, 0.9226069090909091], 
             UndirectedEdge[341, 397] -> 
             RGBColor[0.990744, 0.9895686363636363, 0.7396899090909089], 
             UndirectedEdge[160, 274] -> 
             RGBColor[
              0.9555194090909092, 0.9535697272727273, 0.6961461818181818], 
             UndirectedEdge[151, 235] -> 
             RGBColor[
              0.9843247727272728, 0.9586300000000001, 0.40686336363636333`], 
             UndirectedEdge[11, 372] -> 
             RGBColor[
              0.8295139090909092, 0.5439703181818182, 0.5793217727272728], 
             UndirectedEdge[99, 295] -> 
             RGBColor[
              0.9032890454545454, 0.9254948181818181, 0.9827548636363637], 
             UndirectedEdge[154, 199] -> 
             RGBColor[
              0.662962909090909, 0.7323525454545454, 0.969740909090909], 
             UndirectedEdge[169, 308] -> 
             RGBColor[
              0.8425368181818181, 0.8742673636363636, 0.7938388636363634], 
             UndirectedEdge[158, 410] -> 
             RGBColor[0.8778414999999999, 0.9054309999999999, 0.9882105], 
             UndirectedEdge[311, 465] -> 
             RGBColor[
              0.9693936818181818, 0.9741480909090909, 0.798332818181818], 
             UndirectedEdge[139, 428] -> 
             RGBColor[
              0.9806038636363636, 0.9840500000000001, 0.8727119999999999], 
             UndirectedEdge[113, 364] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[89, 475] -> 
             RGBColor[
              0.900735090909091, 0.9227762727272728, 0.9588627272727273], 
             UndirectedEdge[375, 441] -> 
             RGBColor[
              0.9109507272727273, 0.6851902272727275, 0.5652193181818181], 
             UndirectedEdge[244, 295] -> 
             RGBColor[
              0.9246393636363636, 0.9409153636363636, 0.9241119545454546], 
             UndirectedEdge[187, 260] -> 
             RGBColor[
              0.9601044090909091, 0.9674768181818182, 0.8465403636363638], 
             UndirectedEdge[207, 322] -> 
             RGBColor[
              0.8374970909090909, 0.8730550909090908, 0.9407296818181818], 
             UndirectedEdge[100, 457] -> 
             RGBColor[
              0.9892317272727272, 0.9889432727272727, 0.7647521818181816], 
             UndirectedEdge[364, 416] -> 
             RGBColor[
              0.900735090909091, 0.9227762727272728, 0.9588627272727273], 
             UndirectedEdge[313, 386] -> 
             RGBColor[
              0.8374970909090909, 0.8730550909090908, 0.9407296818181818], 
             UndirectedEdge[31, 472] -> 
             RGBColor[
              0.6035439090909092, 0.6647602272727273, 0.6941955909090907], 
             UndirectedEdge[37, 49] -> 
             RGBColor[
              0.7663796363636364, 0.8126787272727274, 0.7461190909090911], 
             UndirectedEdge[201, 406] -> 
             RGBColor[
              0.9285457727272727, 0.9423128181818181, 0.8435302727272729], 
             UndirectedEdge[245, 376] -> 
             RGBColor[
              0.8425368181818181, 0.8742673636363636, 0.7938388636363634], 
             UndirectedEdge[58, 215] -> 
             RGBColor[
              0.5154887272727271, 0.6171791363636361, 0.955098909090909], 
             UndirectedEdge[84, 407] -> 
             RGBColor[
              0.8661022272727272, 0.8961040909090909, 0.9791386818181818], 
             UndirectedEdge[100, 324] -> 
             RGBColor[0.9938925000000001, 0.989345, 0.5766145], 
             UndirectedEdge[89, 176] -> 
             RGBColor[
              0.9118845909090909, 0.9295840909090909, 0.8724823636363637], 
             UndirectedEdge[75, 379] -> 
             RGBColor[
              0.9434432272727272, 0.9547480909090909, 0.8754924545454545], 
             UndirectedEdge[123, 422] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             UndirectedEdge[407, 455] -> 
             RGBColor[
              0.7150237727272727, 0.7773012727272728, 0.9722305454545455], 
             UndirectedEdge[333, 358] -> 
             RGBColor[
              0.8663794545454546, 0.8923789090909091, 0.7550061818181819], 
             UndirectedEdge[120, 124] -> 
             RGBColor[
              0.9088600454545455, 0.9283333636363637, 0.9226069090909091], 
             UndirectedEdge[88, 433] -> 
             RGBColor[
              0.9808766363636363, 0.9471545454545454, 0.3802097727272725], 
             UndirectedEdge[345, 456] -> 
             RGBColor[
              0.9690147272727272, 0.9733375454545454, 0.7570859545454547], 
             UndirectedEdge[392, 474] -> 
             RGBColor[
              0.8006537727272727, 0.8445361818181818, 0.9806750909090909], 
             UndirectedEdge[165, 333] -> 
             RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 
             UndirectedEdge[31, 133] -> 
             RGBColor[
              0.6039228636363636, 0.6655707727272728, 0.7354424545454548], 
             UndirectedEdge[171, 208] -> 
             RGBColor[
              0.9790915909090909, 0.9834246363636363, 0.8977742727272727], 
             UndirectedEdge[284, 472] -> 
             RGBColor[
              0.927408909090909, 0.9398811818181818, 0.7197896818181816], 
             UndirectedEdge[196, 427] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[179, 334] -> 
             RGBColor[0.6595294545454544, 0.7276904999999999, 0.9503305], 
             UndirectedEdge[97, 233] -> 
             RGBColor[
              0.6727548181818181, 0.7375539545454546, 0.9279434090909091], 
             UndirectedEdge[21, 409] -> 
             RGBColor[
              0.5942174545454545, 0.6777978181818182, 0.9631146363636363], 
             UndirectedEdge[63, 344] -> 
             RGBColor[
              0.8484933181818182, 0.8821137272727273, 0.9655309545454545], 
             UndirectedEdge[292, 398] -> 
             RGBColor[
              0.8941224090909091, 0.9178445454545454, 0.9700562727272728], 
             UndirectedEdge[71, 197] -> 
             RGBColor[
              0.7367742272727272, 0.7794647272727272, 0.6761892727272727], 
             UndirectedEdge[81, 121] -> 
             RGBColor[0.6781735, 0.7395767727272726, 0.8222994545454547], 
             UndirectedEdge[163, 317] -> 
             RGBColor[
              0.7617188636363637, 0.8122770000000001, 0.9342567727272727], 
             UndirectedEdge[167, 172] -> 
             RGBColor[
              0.8484933181818182, 0.8821137272727273, 0.9655309545454545], 
             UndirectedEdge[191, 488] -> 
             RGBColor[
              0.5893183181818181, 0.31075195454545446`, 0.5542309090909091], 
             UndirectedEdge[392, 490] -> 
             RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             UndirectedEdge[251, 272] -> 
             RGBColor[
              0.9903650454545454, 0.988758090909091, 0.6984430454545456], 
             UndirectedEdge[66, 255] -> 
             RGBColor[
              0.8091264545454546, 0.8254408181818182, 0.662920409090909], 
             UndirectedEdge[177, 194] -> 
             RGBColor[
              0.8564339999999999, 0.8886222727272728, 0.9860993636363635], 
             UndirectedEdge[36, 359] -> 
             RGBColor[
              0.7293278636363636, 0.7864172727272727, 0.9434209545454545], 
             UndirectedEdge[46, 377] -> 
             RGBColor[
              0.9296297727272727, 0.7566618636363636, 0.5645543181818181], 
             UndirectedEdge[6, 306] -> 
             RGBColor[
              0.9857042727272727, 0.9883563636363637, 0.8865807272727273], 
             UndirectedEdge[7, 455] -> 
             RGBColor[
              0.8178123181818182, 0.8560090909090909, 0.8631286818181818], 
             UndirectedEdge[84, 482] -> 
             RGBColor[
              0.9511285909090909, 0.9630723636363636, 0.9676107272727272], 
             UndirectedEdge[83, 97] -> 
             RGBColor[
              0.5959105909090909, 0.6775309545454545, 0.9639695909090908], 
             UndirectedEdge[125, 408] -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             UndirectedEdge[184, 473] -> 
             RGBColor[
              0.9592225454545454, 0.967330090909091, 0.8769975000000001], 
             UndirectedEdge[410, 422] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             UndirectedEdge[202, 283] -> 
             RGBColor[
              0.6978878636363637, 0.7566523636363636, 0.8235556363636365], 
             UndirectedEdge[320, 329] -> 
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273], 
             UndirectedEdge[146, 387] -> 
             RGBColor[
              0.6939814545454546, 0.7552549090909091, 0.9041373181818182], 
             UndirectedEdge[107, 170] -> 
             RGBColor[
              0.7808844999999999, 0.8282732727272726, 0.9474796818181818], 
             UndirectedEdge[273, 459] -> 
             RGBColor[
              0.9942714545454545, 0.9901555454545454, 0.617861363636364], 
             UndirectedEdge[5, 395] -> 
             RGBColor[
              0.5617214545454545, 0.6317673181818182, 0.9561526363636363], 
             UndirectedEdge[104, 242] -> 
             RGBColor[
              0.842033909090909, 0.8749311818181817, 0.8655428636363637], 
             UndirectedEdge[422, 437] -> 
             RGBColor[
              0.6314042727272726, 0.7071885454545455, 0.9667308181818182], 
             UndirectedEdge[29, 177] -> 
             RGBColor[
              0.8564339999999999, 0.8886222727272728, 0.9860993636363635], 
             UndirectedEdge[202, 285] -> 
             RGBColor[
              0.8913589545454546, 0.9129220909090909, 0.8399140909090911], 
             UndirectedEdge[182, 460] -> 
             RGBColor[
              0.9103723181818182, 0.9289587272727273, 0.8975446363636364], 
             UndirectedEdge[116, 333] -> 
             RGBColor[
              0.7634669545454544, 0.8151454545454545, 0.977058909090909], 
             UndirectedEdge[405, 472] -> 
             RGBColor[
              0.9927556363636364, 0.9869133636363637, 0.4528739090909087], 
             UndirectedEdge[51, 96] -> 
             RGBColor[
              0.9348476818181818, 0.9506588181818182, 0.9857649545454545], 
             UndirectedEdge[115, 402] -> 
             RGBColor[0.7522105909090908, 0.806692, 0.9758467272727273], 
             UndirectedEdge[67, 120] -> 
             RGBColor[
              0.8632309545454545, 0.8926025454545454, 0.9180815909090909], 
             UndirectedEdge[72, 222] -> 
             RGBColor[
              0.9933895909090908, 0.9900088181818183, 0.6483185000000002], 
             UndirectedEdge[84, 328] -> 
             RGBColor[0.9686357727272727, 0.972527, 0.7158390909090907], 
             UndirectedEdge[123, 401] -> 
             RGBColor[
              0.927663909090909, 0.9421660909090909, 0.8739874090909092], 
             UndirectedEdge[143, 178] -> 
             RGBColor[
              0.9850256818181817, 0.9758467272727273, 0.6556048636363635], 
             UndirectedEdge[2, 385] -> 
             RGBColor[
              0.8941224090909091, 0.9178445454545454, 0.9700562727272728], 
             UndirectedEdge[113, 487] -> 
             RGBColor[
              0.6792438181818181, 0.744766090909091, 0.9515866818181817], 
             UndirectedEdge[12, 430] -> 
             RGBColor[
              0.9739911818181818, 0.9791182727272727, 0.8839055454545454], 
             UndirectedEdge[72, 344] -> 
             RGBColor[
              0.9755034545454545, 0.9797436363636364, 0.8588432727272728], 
             UndirectedEdge[127, 221] -> 
             RGBColor[
              0.6529167727272727, 0.7227587727272726, 0.9615240454545455], 
             UndirectedEdge[466, 491] -> 
             RGBColor[
              0.9543314545454544, 0.8435347272727272, 0.47486040909090926`], 
             UndirectedEdge[236, 289] -> 
             RGBColor[
              0.9261516363636363, 0.9415407272727272, 0.8990496818181817], 
             UndirectedEdge[200, 298] -> 
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273], 
             UndirectedEdge[231, 431] -> 
             RGBColor[
              0.9053480909090909, 0.642125909090909, 0.5598542272727273], 
             UndirectedEdge[171, 238] -> 
             RGBColor[
              0.9911229545454545, 0.9903791818181817, 0.7809367727272729], 
             UndirectedEdge[276, 306] -> 
             RGBColor[0.6361795454545454, 0.7030075, 0.9005341363636363], 
             UndirectedEdge[294, 296] -> 
             RGBColor[
              0.927663909090909, 0.9421660909090909, 0.8739874090909092], 
             UndirectedEdge[1, 119] -> 
             RGBColor[
              0.7647434090909091, 0.8135277272727274, 0.8841322272727272], 
             UndirectedEdge[103, 444] -> 
             RGBColor[
              0.9555194090909092, 0.9535697272727273, 0.6961461818181818], 
             UndirectedEdge[331, 486] -> 
             RGBColor[
              0.9593465000000001, 0.9658557272727273, 0.7640466363636365], 
             UndirectedEdge[100, 281] -> 
             RGBColor[
              0.9693936818181818, 0.9741480909090909, 0.798332818181818], 
             UndirectedEdge[161, 477] -> 
             RGBColor[
              0.8333480454545454, 0.844362909090909, 0.6653345909090909], 
             UndirectedEdge[391, 475] -> 
             RGBColor[0.935514, 0.808475681818182, 0.5861755909090909], 
             UndirectedEdge[2, 312] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[264, 341] -> 
             RGBColor[
              0.8390093636363636, 0.8736804545454545, 0.9156674090909092], 
             UndirectedEdge[73, 434] -> 
             RGBColor[0.8575696363636364, 0.863285, 0.6677487727272726], 
             UndirectedEdge[241, 271] -> 
             RGBColor[0.6595294545454544, 0.7276904999999999, 0.9503305], 
             UndirectedEdge[49, 51] -> 
             RGBColor[0.732212590909091, 0.79, 0.9747980909090909], 
             UndirectedEdge[5, 275] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[18, 274] -> 
             RGBColor[
              0.9577102727272727, 0.9667047272727274, 0.9020597727272726], 
             UndirectedEdge[219, 445] -> 
             RGBColor[
              0.6792438181818181, 0.744766090909091, 0.9515866818181817], 
             UndirectedEdge[177, 297] -> 
             RGBColor[
              0.8913589545454546, 0.9129220909090909, 0.8399140909090911], 
             UndirectedEdge[250, 365] -> 
             RGBColor[
              0.9634648181818182, 0.9204912727272727, 0.6087275454545454], 
             UndirectedEdge[325, 474] -> 
             RGBColor[
              0.7764321818181817, 0.8256140909090908, 0.9782609090909091], 
             UndirectedEdge[266, 403] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[214, 470] -> 
             RGBColor[
              0.9658662272727272, 0.9735611818181817, 0.9201613636363637], 
             UndirectedEdge[152, 481] -> 
             RGBColor[
              0.9597254545454545, 0.9666662727272728, 0.8052934999999998], 
             UndirectedEdge[289, 466] -> 
             RGBColor[
              0.9285457727272727, 0.9423128181818181, 0.8435302727272729], 
             UndirectedEdge[126, 269] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[183, 396] -> 
             RGBColor[
              0.43486459090909085`, 0.5318865909090909, 0.9516586818181818], 
             UndirectedEdge[54, 99] -> 
             RGBColor[
              0.9511285909090909, 0.9630723636363636, 0.9676107272727272], 
             UndirectedEdge[129, 306] -> 
             RGBColor[
              0.6545527272727272, 0.7211037272727272, 0.9016249545454547], 
             UndirectedEdge[172, 236] -> 
             RGBColor[
              0.9739911818181818, 0.9791182727272727, 0.8839055454545454], 
             UndirectedEdge[162, 284] -> 
             RGBColor[0.7522105909090908, 0.806692, 0.9758467272727273], 
             UndirectedEdge[10, 189] -> 
             RGBColor[
              0.9281668181818181, 0.9415022727272726, 0.8022834090909089], 
             UndirectedEdge[213, 332] -> 
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273], 
             UndirectedEdge[199, 245] -> 
             RGBColor[
              0.9597254545454545, 0.9666662727272728, 0.8052934999999998], 
             UndirectedEdge[123, 139] -> 
             RGBColor[
              0.9261516363636363, 0.9415407272727272, 0.8990496818181817], 
             UndirectedEdge[391, 482] -> 
             RGBColor[
              0.9289013181818182, 0.8035439545454547, 0.5973691363636364], 
             UndirectedEdge[184, 354] -> 
             RGBColor[
              0.9348476818181818, 0.9506588181818182, 0.9857649545454545], 
             UndirectedEdge[25, 316] -> 
             RGBColor[
              0.6906549545454544, 0.7564899999999999, 0.9712636818181818], 
             UndirectedEdge[106, 479] -> 
             RGBColor[
              0.8462828636363636, 0.8802669999999999, 0.9852004090909091], 
             UndirectedEdge[118, 260] -> 
             RGBColor[0.956198, 0.9660793636363636, 0.9271220454545455], 
             UndirectedEdge[304, 469] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[93, 236] -> 
             RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454544], 
             UndirectedEdge[343, 445] -> 
             RGBColor[
              0.6314042727272726, 0.7071885454545455, 0.9667308181818182], 
             UndirectedEdge[204, 444] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[150, 412] -> 
             RGBColor[
              0.9697726363636363, 0.9749586363636363, 0.839579681818182], 
             UndirectedEdge[14, 239] -> 
             RGBColor[
              0.9693936818181818, 0.9741480909090909, 0.798332818181818], 
             UndirectedEdge[70, 442] -> 
             RGBColor[
              0.9160401818181818, 0.7702394545454547, 0.6033488181818183], 
             UndirectedEdge[93, 493] -> 
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181], 
             UndirectedEdge[228, 279] -> 
             RGBColor[
              0.6637093181818181, 0.4506756363636362, 0.5692450909090909], 
             UndirectedEdge[300, 456] -> 
             RGBColor[
              0.9593465000000001, 0.9658557272727273, 0.7640466363636365], 
             UndirectedEdge[168, 326] -> 
             RGBColor[
              0.7929158636363636, 0.835227818181818, 0.830642181818182], 
             UndirectedEdge[193, 437] -> 
             RGBColor[
              0.6156249545454546, 0.6946065454545455, 0.9652257727272727], 
             UndirectedEdge[224, 361] -> 
             RGBColor[
              0.8308844090909091, 0.8681233636363637, 0.9519232272727272], 
             UndirectedEdge[12, 477] -> 
             RGBColor[
              0.8405216363636363, 0.8743058181818182, 0.8906051363636363], 
             UndirectedEdge[212, 224] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[220, 490] -> 
             RGBColor[
              0.5215526818181818, 0.6210315454545454, 0.9558720909090909], 
             UndirectedEdge[175, 208] -> 
             RGBColor[0.6858565, 0.7496978181818181, 0.9403931363636363], 
             UndirectedEdge[242, 419] -> 
             RGBColor[
              0.8405216363636363, 0.8743058181818182, 0.8906051363636363], 
             UndirectedEdge[164, 205] -> 
             RGBColor[
              0.7579909090909089, 0.8109279999999999, 0.9768274545454545], 
             UndirectedEdge[257, 322] -> 
             RGBColor[0.8283653181818182, 0.827555, 0.6459776363636365], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.9755034545454545, 0.9797436363636364, 0.8588432727272728], 
             UndirectedEdge[26, 67] -> 
             RGBColor[
              0.8647432272727272, 0.8932279090909091, 0.893019318181818], 
             UndirectedEdge[366, 488] -> 
             RGBColor[
              0.5745030909090908, 0.6607222272727272, 0.9618584545454545], 
             UndirectedEdge[12, 243] -> 
             RGBColor[
              0.9673784999999999, 0.9741865454545455, 0.8950990909090908], 
             UndirectedEdge[271, 307] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[9, 352] -> 
             RGBColor[
              0.8405216363636363, 0.8743058181818182, 0.8906051363636363], 
             UndirectedEdge[404, 431] -> 
             RGBColor[
              0.9053480909090909, 0.642125909090909, 0.5598542272727273], 
             UndirectedEdge[256, 287] -> 
             RGBColor[
              0.9127664545454546, 0.9297308181818182, 0.8420252272727275], 
             UndirectedEdge[254, 412] -> 
             RGBColor[
              0.9688907727272726, 0.9748119090909091, 0.8700368181818183], 
             UndirectedEdge[42, 380] -> 
             RGBColor[
              0.9322937272727272, 0.9479402727272728, 0.9618728181818181], 
             UndirectedEdge[379, 404] -> 
             RGBColor[
              0.8666751818181817, 0.6121986363636363, 0.5876969545454545], 
             UndirectedEdge[134, 424] -> 
             RGBColor[
              0.9858593636363636, 0.9639624545454545, 0.3995667272727271], 
             UndirectedEdge[38, 253] -> 
             RGBColor[
              0.6742670909090909, 0.7381793181818181, 0.9028811363636364], 
             UndirectedEdge[103, 348] -> 
             RGBColor[0.9893075, 0.9754379090909091, 0.4262203181818179], 
             UndirectedEdge[42, 452] -> 
             RGBColor[
              0.767989909090909, 0.8192740000000001, 0.9773517727272727], 
             UndirectedEdge[164, 331] -> 
             RGBColor[
              0.7921579545454545, 0.8336067272727272, 0.7481484545454546], 
             UndirectedEdge[6, 181] -> 
             RGBColor[
              0.9887288181818181, 0.9896070909090909, 0.8364561818181819], 
             UndirectedEdge[172, 197] -> 
             RGBColor[
              0.7227151818181817, 0.7814855454545454, 0.9546144999999999], 
             UndirectedEdge[80, 258] -> 
             RGBColor[
              0.5699958636363636, 0.6588757272727273, 0.9607004545454545], 
             UndirectedEdge[223, 268] -> 
             RGBColor[0.8889648181818182, 0.91215, 0.8954334999999999], 
             UndirectedEdge[5, 69] -> 
             RGBColor[
              0.9688907727272726, 0.9748119090909091, 0.8700368181818183], 
             UndirectedEdge[306, 486] -> 
             RGBColor[0.956198, 0.9660793636363636, 0.9271220454545455], 
             UndirectedEdge[5, 348] -> 
             RGBColor[0.9686357727272727, 0.972527, 0.7158390909090907], 
             UndirectedEdge[279, 409] -> 
             RGBColor[0.44421772727272724`, 0.5582475454545455, 0.949784], 
             UndirectedEdge[463, 483] -> 
             RGBColor[0.8418806363636363, 0.8771819999999999, 0.9767245], 
             UndirectedEdge[351, 371] -> 
             RGBColor[
              0.8874525454545454, 0.9115246363636363, 0.9204957727272727], 
             UndirectedEdge[335, 421] -> 
             RGBColor[
              0.8406546818181817, 0.8760402727272727, 0.9845943181818182], 
             UndirectedEdge[259, 418] -> 
             RGBColor[
              0.8374970909090909, 0.8730550909090908, 0.9407296818181818], 
             UndirectedEdge[168, 302] -> 
             RGBColor[
              0.9412969090909091, 0.7870574545454547, 0.4641242272727275], 
             UndirectedEdge[87, 336] -> 
             RGBColor[
              0.9850256818181817, 0.9758467272727273, 0.6556048636363636], 
             UndirectedEdge[36, 266] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[161, 430] -> 
             RGBColor[
              0.9668175909090909, 0.9491753636363636, 0.6586349999999999], 
             UndirectedEdge[220, 412] -> 
             RGBColor[
              0.6726311363636364, 0.7398343636363636, 0.9627802272727273], 
             UndirectedEdge[372, 404] -> 
             RGBColor[
              0.834126909090909, 0.2633199545454544, 0.1803132727272727], 
             UndirectedEdge[38, 287] -> 
             RGBColor[0.6781735, 0.7395767727272726, 0.8222994545454547], 
             UndirectedEdge[171, 497] -> 
             RGBColor[
              0.9765725000000001, 0.9428562727272729, 0.5918286818181819], 
             UndirectedEdge[246, 411] -> 
             RGBColor[
              0.9850826818181818, 0.9602510909090909, 0.48935709090909063`], 
             UndirectedEdge[75, 303] -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             UndirectedEdge[23, 39] -> 
             RGBColor[
              0.9806038636363636, 0.9840500000000001, 0.8727119999999999], 
             UndirectedEdge[61, 391] -> 
             RGBColor[0.935514, 0.808475681818182, 0.5861755909090909], 
             UndirectedEdge[19, 200] -> 
             RGBColor[
              0.8859402727272727, 0.9108992727272727, 0.9455580454545454], 
             UndirectedEdge[208, 403] -> 
             RGBColor[
              0.8308844090909091, 0.8681233636363637, 0.9519232272727272], 
             UndirectedEdge[108, 378] -> 
             RGBColor[
              0.9434432272727272, 0.9547480909090909, 0.8754924545454545], 
             UndirectedEdge[10, 451] -> 
             RGBColor[
              0.7409802727272726, 0.7925612727272726, 0.7853365909090907], 
             UndirectedEdge[199, 262] -> 
             RGBColor[0.9001235, 0.7343848636363635, 0.6050956363636363], 
             UndirectedEdge[3, 401] -> 
             RGBColor[
              0.9845797727272727, 0.960914909090909, 0.561061090909091], 
             UndirectedEdge[241, 311] -> 
             RGBColor[
              0.6529167727272727, 0.7227587727272726, 0.9615240454545455], 
             UndirectedEdge[179, 255] -> 
             RGBColor[
              0.6686057727272727, 0.7088617727272727, 0.6525483181818181], 
             UndirectedEdge[276, 462] -> 
             RGBColor[
              0.41219413636363644`, 0.5269281363636364, 0.9482101818181818], 
             UndirectedEdge[167, 289] -> 
             RGBColor[
              0.8006537727272727, 0.8445361818181818, 0.9806750909090909], 
             UndirectedEdge[164, 348] -> 
             RGBColor[
              0.7917789999999999, 0.8327961818181817, 0.7069015909090907], 
             UndirectedEdge[18, 172] -> 
             RGBColor[
              0.9739911818181818, 0.9791182727272727, 0.8839055454545454], 
             UndirectedEdge[289, 300] -> 
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454], 
             UndirectedEdge[59, 188] -> 
             RGBColor[
              0.9697726363636363, 0.9749586363636363, 0.839579681818182], 
             UndirectedEdge[352, 357] -> 
             RGBColor[
              0.9419309545454545, 0.9541227272727273, 0.9005547272727272], 
             UndirectedEdge[161, 409] -> 
             RGBColor[
              0.6883201363636364, 0.7259373636363636, 0.6538044999999999], 
             UndirectedEdge[39, 157] -> 
             RGBColor[
              0.9739911818181818, 0.9791182727272727, 0.8839055454545454], 
             UndirectedEdge[216, 398] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[279, 396] -> 
             RGBColor[
              0.5892456363636362, 0.6766730909090908, 0.9613140909090909], 
             UndirectedEdge[103, 390] -> 
             RGBColor[
              0.9904443636363636, 0.9778695454545454, 0.5499609090909092], 
             UndirectedEdge[128, 296] -> 
             RGBColor[
              0.927663909090909, 0.9421660909090909, 0.8739874090909092], 
             UndirectedEdge[362, 369] -> 
             RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 
             UndirectedEdge[86, 412] -> 
             RGBColor[
              0.9673784999999999, 0.9741865454545455, 0.8950990909090908], 
             UndirectedEdge[261, 299] -> 
             RGBColor[
              0.9609457272727273, 0.8799229090909092, 0.30278195454545465`], 
             UndirectedEdge[208, 266] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[211, 236] -> 
             RGBColor[
              0.9917533636363636, 0.9908578181818182, 0.7863316363636363], 
             UndirectedEdge[19, 124] -> 
             RGBColor[
              0.8090960454545455, 0.8508762727272727, 0.9815842272727273], 
             UndirectedEdge[319, 330] -> 
             RGBColor[
              0.6665805909090909, 0.739457090909091, 0.9674021818181817], 
             UndirectedEdge[137, 267] -> 
             RGBColor[
              0.916404409090909, 0.746798409090909, 0.5869414090909091], 
             UndirectedEdge[23, 240] -> 
             RGBColor[
              0.9818611363636364, 0.9823904545454546, 0.6934519999999997], 
             UndirectedEdge[135, 369] -> 
             RGBColor[
              0.8551059999999999, 0.8870454545454545, 0.954337409090909], 
             UndirectedEdge[13, 335] -> 
             RGBColor[
              0.8843441818181818, 0.7218028636363635, 0.6035905909090908], 
             UndirectedEdge[176, 178] -> 
             RGBColor[
              0.9895624999999999, 0.9777228181818182, 0.5804180454545455], 
             UndirectedEdge[335, 459] -> 
             RGBColor[
              0.9443250909090909, 0.9548948181818182, 0.8450353181818184], 
             UndirectedEdge[83, 326] -> 
             RGBColor[
              0.7106529545454545, 0.7731819999999999, 0.9723123181818182], 
             UndirectedEdge[33, 76] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[13, 285] -> 
             RGBColor[
              0.8313780454545454, 0.6798301363636362, 0.5984693636363636], 
             UndirectedEdge[225, 309] -> 
             RGBColor[
              0.9511285909090909, 0.9630723636363636, 0.9676107272727272], 
             UndirectedEdge[242, 499] -> 
             RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             UndirectedEdge[13, 287] -> 
             RGBColor[
              0.9350484545454545, 0.7586846818181816, 0.45891036363636384`], 
             UndirectedEdge[265, 270] -> 
             RGBColor[0.7522105909090908, 0.806692, 0.9758467272727273], 
             UndirectedEdge[191, 311] -> 
             RGBColor[
              0.8809174545454546, 0.5461338181818182, 0.5715111363636364], 
             UndirectedEdge[47, 452] -> 
             RGBColor[
              0.7150237727272727, 0.7773012727272728, 0.9722305454545455], 
             UndirectedEdge[14, 80] -> 
             RGBColor[
              0.6726311363636364, 0.7398343636363636, 0.9627802272727273], 
             UndirectedEdge[152, 292] -> 
             RGBColor[0.9123875, 0.9289202727272727, 0.8007783636363635], 
             UndirectedEdge[133, 311] -> 
             RGBColor[
              0.9690147272727272, 0.9733375454545454, 0.7570859545454547], 
             UndirectedEdge[187, 398] -> 
             RGBColor[
              0.9763853181818182, 0.9798903636363636, 0.8283861363636366], 
             UndirectedEdge[130, 442] -> 
             RGBColor[
              0.9160401818181818, 0.7702394545454547, 0.6033488181818183], 
             UndirectedEdge[304, 433] -> 
             RGBColor[
              0.9668175909090909, 0.9491753636363636, 0.6586349999999999], 
             UndirectedEdge[354, 409] -> 
             RGBColor[
              0.6726311363636364, 0.7398343636363636, 0.9627802272727273], 
             UndirectedEdge[29, 412] -> 
             RGBColor[
              0.9348476818181818, 0.9506588181818182, 0.9857649545454545], 
             UndirectedEdge[295, 391] -> 
             RGBColor[
              0.8810617727272727, 0.7659664090909092, 0.6125132727272727], 
             UndirectedEdge[21, 298] -> 
             RGBColor[
              0.8248753636363635, 0.8634582727272726, 0.9830892727272726], 
             UndirectedEdge[383, 395] -> 
             RGBColor[
              0.5683341363636364, 0.6366990454545455, 0.9449590909090909], 
             UndirectedEdge[133, 241] -> 
             RGBColor[
              0.6774155909090909, 0.7379556818181818, 0.7398057272727274], 
             UndirectedEdge[142, 473] -> 
             RGBColor[
              0.9755034545454545, 0.9797436363636364, 0.8588432727272728], 
             UndirectedEdge[95, 330] -> 
             RGBColor[
              0.8147877727272728, 0.8547583636363636, 0.9132532272727273], 
             UndirectedEdge[275, 431] -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             UndirectedEdge[180, 474] -> 
             RGBColor[0.7522105909090908, 0.806692, 0.9758467272727273], 
             UndirectedEdge[82, 173] -> 
             RGBColor[
              0.36131763636363623`, 0.48737690909090897`, 0.9442438181818181],
              UndirectedEdge[205, 230] -> 
             RGBColor[
              0.9577102727272727, 0.9667047272727274, 0.9020597727272726], 
             UndirectedEdge[460, 463] -> 
             RGBColor[
              0.9673784999999999, 0.9741865454545455, 0.8950990909090908], 
             UndirectedEdge[121, 500] -> 
             RGBColor[
              0.40074636363636346`, 0.5215280909090907, 0.9467561818181818], 
             UndirectedEdge[88, 241] -> 
             RGBColor[
              0.6735884999999999, 0.7256696818181817, 0.6719052727272725], 
             UndirectedEdge[60, 73] -> 
             RGBColor[
              0.7575698181818182, 0.7835848181818182, 0.6588616818181817], 
             UndirectedEdge[75, 400] -> 
             RGBColor[
              0.9895624999999999, 0.9777228181818182, 0.5804180454545455], 
             UndirectedEdge[141, 274] -> 
             RGBColor[
              0.9589675454545454, 0.9650451818181819, 0.7227997727272726], 
             UndirectedEdge[299, 448] -> 
             RGBColor[0.9405712272727274, 0.903146, 0.6380753181818182], 
             UndirectedEdge[160, 389] -> 
             RGBColor[0.9893075, 0.9754379090909091, 0.4262203181818179], 
             UndirectedEdge[24, 268] -> 
             RGBColor[
              0.9739911818181818, 0.9791182727272727, 0.8839055454545454], 
             UndirectedEdge[386, 498] -> 
             RGBColor[
              0.9119607727272727, 0.6470576363636362, 0.5486606818181818], 
             UndirectedEdge[350, 476] -> 
             RGBColor[
              0.9887288181818181, 0.9896070909090909, 0.8364561818181819], 
             UndirectedEdge[180, 331] -> 
             RGBColor[
              0.8179362727272728, 0.8545347272727273, 0.7501778181818184], 
             UndirectedEdge[225, 252] -> 
             RGBColor[
              0.9511285909090909, 0.9630723636363636, 0.9676107272727272], 
             UndirectedEdge[100, 203] -> 
             RGBColor[
              0.9693936818181818, 0.9741480909090909, 0.798332818181818], 
             UndirectedEdge[445, 471] -> 
             RGBColor[
              0.6939814545454546, 0.7552549090909091, 0.9041373181818182], 
             UndirectedEdge[373, 498] -> 
             RGBColor[
              0.9119607727272727, 0.6470576363636362, 0.5486606818181818], 
             UndirectedEdge[102, 309] -> 
             RGBColor[
              0.8875097272727273, 0.9129128181818182, 0.9812498181818182], 
             UndirectedEdge[46, 86] -> 
             RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454544], 
             UndirectedEdge[294, 385] -> 
             RGBColor[
              0.9118845909090909, 0.9295840909090909, 0.8724823636363637], 
             UndirectedEdge[27, 29] -> 
             RGBColor[
              0.9348476818181818, 0.9506588181818182, 0.9857649545454545], 
             UndirectedEdge[274, 284] -> 
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454], 
             UndirectedEdge[284, 300] -> 
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454], 
             UndirectedEdge[159, 453] -> 
             RGBColor[
              0.9693936818181818, 0.9741480909090909, 0.798332818181818], 
             UndirectedEdge[229, 232] -> 
             RGBColor[
              0.9880502272727272, 0.9770974545454545, 0.605480318181818], 
             UndirectedEdge[259, 431] -> 
             RGBColor[
              0.9775793181818182, 0.9827992727272727, 0.9228365454545454], 
             UndirectedEdge[112, 483] -> 
             RGBColor[
              0.7150237727272727, 0.7773012727272727, 0.9722305454545455], 
             UndirectedEdge[78, 376] -> 
             RGBColor[
              0.8425368181818181, 0.8742673636363636, 0.7938388636363634], 
             UndirectedEdge[76, 351] -> 
             RGBColor[
              0.8390093636363636, 0.8736804545454545, 0.9156674090909092], 
             UndirectedEdge[178, 498] -> 
             RGBColor[
              0.9127944545454545, 0.6351733636363635, 0.29262254545454536`], 
             UndirectedEdge[400, 431] -> 
             RGBColor[0.978413, 0.970915, 0.6667984090909089], 
             UndirectedEdge[18, 432] -> 
             RGBColor[0.9830675, 0.9602895454545455, 0.5861233636363634], 
             UndirectedEdge[220, 325] -> 
             RGBColor[
              0.5457742727272727, 0.6399536363636363, 0.9582862727272727], 
             UndirectedEdge[353, 380] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[5, 355] -> 
             RGBColor[
              0.7418808181818182, 0.7974818181818182, 0.9678374090909091], 
             UndirectedEdge[367, 441] -> 
             RGBColor[
              0.9634648181818182, 0.9204912727272727, 0.6087275454545453], 
             UndirectedEdge[21, 287] -> 
             RGBColor[
              0.8913589545454546, 0.9129220909090909, 0.8399140909090911], 
             UndirectedEdge[175, 182] -> 
             RGBColor[
              0.6156249545454546, 0.6946065454545455, 0.9652257727272727], 
             UndirectedEdge[70, 371] -> 
             RGBColor[
              0.8661022272727272, 0.8961040909090909, 0.9791386818181818], 
             UndirectedEdge[217, 496] -> 
             RGBColor[
              0.6748756363636362, 0.7439079999999999, 0.9697586363636364], 
             UndirectedEdge[195, 292] -> 
             RGBColor[
              0.8941224090909091, 0.9178445454545454, 0.9700562727272728], 
             UndirectedEdge[161, 285] -> 
             RGBColor[
              0.8817912272727273, 0.8822070909090909, 0.6701629545454544], 
             UndirectedEdge[168, 370] -> 
             RGBColor[
              0.8671373636363636, 0.8939999999999999, 0.8374999090909092], 
             UndirectedEdge[50, 173] -> 
             RGBColor[
              0.5502814999999999, 0.6418001363636363, 0.9594442727272727], 
             UndirectedEdge[19, 188] -> 
             RGBColor[
              0.8913589545454546, 0.9129220909090909, 0.8399140909090911], 
             UndirectedEdge[147, 323] -> 
             RGBColor[0.9404186818181818, 0.9534973636363636, 0.925617], 
             UndirectedEdge[255, 260] -> 
             RGBColor[
              0.9505366818181819, 0.9367618181818183, 0.6767892272727272], 
             UndirectedEdge[29, 350] -> 
             RGBColor[
              0.9592225454545454, 0.967330090909091, 0.8769975000000001], 
             UndirectedEdge[348, 400] -> 
             RGBColor[0.9893075, 0.9754379090909091, 0.4262203181818179], 
             UndirectedEdge[26, 124] -> 
             RGBColor[
              0.9103723181818182, 0.9289587272727273, 0.8975446363636364], 
             UndirectedEdge[18, 93] -> 
             RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454544], 
             UndirectedEdge[64, 223] -> 
             RGBColor[
              0.8248753636363635, 0.8634582727272726, 0.9830892727272726], 
             UndirectedEdge[12, 335] -> 
             RGBColor[
              0.9419309545454545, 0.9541227272727273, 0.9005547272727272], 
             UndirectedEdge[143, 498] -> 
             RGBColor[
              0.9119607727272727, 0.6470576363636362, 0.5486606818181818], 
             UndirectedEdge[44, 92] -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909092], 
             UndirectedEdge[274, 389] -> 
             RGBColor[
              0.9589675454545454, 0.9650451818181819, 0.7227997727272725], 
             UndirectedEdge[247, 401] -> 
             RGBColor[
              0.6772916363636363, 0.7394300454545455, 0.852756590909091], 
             UndirectedEdge[111, 182] -> 
             RGBColor[0.9073477727272727, 0.927708, 0.9476691818181818], 
             UndirectedEdge[157, 190] -> 
             RGBColor[
              0.9752484545454545, 0.9774587272727273, 0.7046455454545453], 
             UndirectedEdge[100, 360] -> 
             RGBColor[
              0.8667584090909091, 0.8931894545454545, 0.7962530454545452], 
             UndirectedEdge[59, 468] -> 
             RGBColor[
              0.7161024999999999, 0.7765538181818181, 0.9658080454545455], 
             UndirectedEdge[101, 129] -> 
             RGBColor[
              0.6530404545454545, 0.7204783636363636, 0.9266872272727273], 
             UndirectedEdge[180, 382] -> 
             RGBColor[
              0.7934374545454546, 0.8393378181818182, 0.9718961363636364], 
             UndirectedEdge[145, 402] -> 
             RGBColor[
              0.927663909090909, 0.9421660909090909, 0.8739874090909092], 
             UndirectedEdge[90, 263] -> 
             RGBColor[0.8778414999999999, 0.9054309999999999, 0.9882105], 
             UndirectedEdge[98, 276] -> 
             RGBColor[
              0.6346672727272727, 0.7023821363636364, 0.925596409090909], 
             UndirectedEdge[224, 464] -> 
             RGBColor[
              0.6150239545454546, 0.697601090909091, 0.9633434545454544], 
             UndirectedEdge[261, 313] -> 
             RGBColor[0.8283653181818182, 0.827555, 0.6459776363636365], 
             UndirectedEdge[78, 219] -> 
             RGBColor[
              0.9760063636363636, 0.9790798181818181, 0.7871392727272726], 
             UndirectedEdge[393, 424] -> 
             RGBColor[
              0.9904443636363636, 0.9778695454545454, 0.5499609090909092], 
             UndirectedEdge[169, 211] -> 
             RGBColor[
              0.9937685454545454, 0.9908193636363636, 0.6895653636363634], 
             UndirectedEdge[176, 482] -> 
             RGBColor[
              0.9755034545454545, 0.9797436363636364, 0.8588432727272728], 
             UndirectedEdge[35, 94] -> 
             RGBColor[
              0.6471835909090908, 0.7197705454545454, 0.9682358636363636], 
             UndirectedEdge[114, 296] -> 
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273], 
             UndirectedEdge[130, 175] -> 
             RGBColor[
              0.6726311363636364, 0.7398343636363636, 0.9627802272727273], 
             UndirectedEdge[189, 383] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[139, 437] -> 
             RGBColor[
              0.6954937272727273, 0.7558802727272728, 0.8790750454545453], 
             UndirectedEdge[56, 324] -> 
             RGBColor[
              0.8663794545454546, 0.8923789090909091, 0.7550061818181819], 
             UndirectedEdge[398, 399] -> 
             RGBColor[
              0.9755034545454545, 0.9797436363636364, 0.8588432727272728], 
             UndirectedEdge[405, 429] -> 
             RGBColor[
              0.9818611363636364, 0.9823904545454546, 0.6934519999999997], 
             UndirectedEdge[12, 318] -> 
             RGBColor[
              0.7647434090909091, 0.8135277272727274, 0.8841322272727272], 
             UndirectedEdge[11, 205] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[226, 389] -> 
             RGBColor[
              0.989986090909091, 0.9879475454545454, 0.6571961818181816], 
             UndirectedEdge[294, 327] -> 
             RGBColor[
              0.9887288181818181, 0.9896070909090909, 0.8364561818181819], 
             UndirectedEdge[167, 218] -> 
             RGBColor[
              0.8617186818181818, 0.8919771818181819, 0.9431438636363636], 
             UndirectedEdge[217, 481] -> 
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454], 
             UndirectedEdge[247, 309] -> 
             RGBColor[
              0.6529167727272727, 0.7227587727272726, 0.9615240454545455], 
             UndirectedEdge[79, 234] -> 
             RGBColor[
              0.9754961818181818, 0.9274458181818181, 0.4918900454545456], 
             UndirectedEdge[331, 372] -> 
             RGBColor[
              0.9110189090909091, 0.6043950454545455, 0.3551579090909093], 
             UndirectedEdge[27, 484] -> 
             RGBColor[0.9686357727272727, 0.972527, 0.7158390909090907], 
             UndirectedEdge[103, 326] -> 
             RGBColor[0.7883308636363635, 0.8213207272727272, 0.680248], 
             UndirectedEdge[155, 394] -> 
             RGBColor[
              0.9480730454545454, 0.9605222727272728, 0.9633778636363636], 
             UndirectedEdge[433, 469] -> 
             RGBColor[
              0.9189780454545454, 0.9115978181818181, 0.6737791363636363], 
             UndirectedEdge[65, 412] -> 
             RGBColor[
              0.9697726363636363, 0.9749586363636363, 0.839579681818182], 
             UndirectedEdge[13, 161] -> 
             RGBColor[
              0.9254807272727272, 0.7279696818181817, 0.28915922727272714`], 
             UndirectedEdge[229, 480] -> 
             RGBColor[
              0.9739911818181818, 0.9791182727272727, 0.8839055454545454], 
             UndirectedEdge[32, 448] -> 
             RGBColor[0.956198, 0.9660793636363636, 0.9271220454545455], 
             UndirectedEdge[251, 453] -> 
             RGBColor[0.9938925000000001, 0.989345, 0.5766145], 
             UndirectedEdge[282, 310] -> 
             RGBColor[
              0.9190683636363636, 0.9380768181818182, 0.9842599090909091], 
             UndirectedEdge[392, 473] -> 
             RGBColor[0.8662555, 0.8938532727272728, 0.8679570454545456], 
             UndirectedEdge[222, 344] -> 
             RGBColor[
              0.9756274090909092, 0.9782692727272728, 0.7458924090909093], 
             UndirectedEdge[266, 440] -> 
             RGBColor[
              0.7227151818181817, 0.7814855454545454, 0.9546144999999999], 
             UndirectedEdge[16, 361] -> 
             RGBColor[
              0.7808844999999999, 0.8282732727272726, 0.9474796818181818], 
             UndirectedEdge[412, 426] -> 
             RGBColor[0.8418806363636363, 0.8771819999999999, 0.9767245], 
             UndirectedEdge[274, 460] -> 
             RGBColor[
              0.9577102727272727, 0.9667047272727274, 0.9020597727272726], 
             UndirectedEdge[180, 230] -> 
             RGBColor[
              0.8163000454545455, 0.8553837272727274, 0.8881909545454545], 
             UndirectedEdge[375, 450] -> 
             RGBColor[
              0.7208685909090908, 0.5355959545454547, 0.5786689090909092], 
             UndirectedEdge[6, 123] -> 
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273], 
             UndirectedEdge[170, 466] -> 
             RGBColor[0.982998, 0.9848220909090909, 0.8171925909090911], 
             UndirectedEdge[267, 280] -> 
             RGBColor[
              0.681378318181818, 0.5602798636363635, 0.5851387272727273], 
             UndirectedEdge[52, 214] -> 
             RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454546], 
             UndirectedEdge[358, 386] -> 
             RGBColor[
              0.9888527727272727, 0.9881327272727274, 0.7235053181818183], 
             UndirectedEdge[230, 413] -> 
             RGBColor[
              0.6757793636363636, 0.7388046818181818, 0.8778188636363635], 
             UndirectedEdge[53, 207] -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             UndirectedEdge[188, 256] -> 
             RGBColor[
              0.9127664545454546, 0.9297308181818182, 0.8420252272727275], 
             UndirectedEdge[38, 87] -> 
             RGBColor[
              0.6735884999999999, 0.7256696818181817, 0.6719052727272726], 
             UndirectedEdge[22, 52] -> 
             RGBColor[
              0.7374528181818181, 0.7919743636363636, 0.9071651363636364], 
             UndirectedEdge[160, 460] -> 
             RGBColor[
              0.9880502272727272, 0.9770974545454545, 0.605480318181818], 
             UndirectedEdge[63, 159] -> 
             RGBColor[0.8418806363636363, 0.8771819999999999, 0.9767245], 
             UndirectedEdge[285, 430] -> 
             RGBColor[
              0.872714909090909, 0.9010358181818181, 0.9679451363636363], 
             UndirectedEdge[132, 356] -> 
             RGBColor[
              0.9592225454545454, 0.967330090909091, 0.8769975000000001], 
             UndirectedEdge[99, 373] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[243, 396] -> 
             RGBColor[
              0.8176590454545454, 0.8582599090909091, 0.9743103181818182], 
             UndirectedEdge[118, 292] -> 
             RGBColor[
              0.9088600454545455, 0.9283333636363637, 0.9226069090909091], 
             UndirectedEdge[84, 176] -> 
             RGBColor[
              0.9688907727272726, 0.9748119090909091, 0.8700368181818183], 
             UndirectedEdge[334, 385] -> 
             RGBColor[
              0.8941224090909091, 0.9178445454545454, 0.9700562727272728], 
             UndirectedEdge[25, 325] -> 
             RGBColor[0.7922115, 0.8381960909090909, 0.9797659545454545], 
             UndirectedEdge[321, 397] -> 
             RGBColor[0.990744, 0.9895686363636363, 0.7396899090909089], 
             UndirectedEdge[201, 235] -> 
             RGBColor[0.9938925000000001, 0.989345, 0.5766145], 
             UndirectedEdge[321, 498] -> 
             RGBColor[
              0.9134730454545454, 0.6476829999999999, 0.5235984090909092], 
             UndirectedEdge[368, 492] -> 
             RGBColor[
              0.8484933181818182, 0.8821137272727273, 0.9655309545454545], 
             UndirectedEdge[239, 387] -> 
             RGBColor[
              0.697508909090909, 0.7558418181818182, 0.7823087727272725], 
             UndirectedEdge[196, 500] -> 
             RGBColor[
              0.5654886363636362, 0.6570292272727272, 0.9595424545454545], 
             UndirectedEdge[122, 185] -> 
             RGBColor[0.7837692272727272, 0.831856, 0.9788568181818181], 
             UndirectedEdge[350, 377] -> 
             RGBColor[
              0.9341665909090908, 0.7585379545454545, 0.48936750000000007`], 
             UndirectedEdge[315, 353] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[102, 480] -> 
             RGBColor[
              0.8941224090909091, 0.9178445454545454, 0.9700562727272728], 
             UndirectedEdge[127, 253] -> 
             RGBColor[
              0.6742670909090909, 0.7381793181818181, 0.9028811363636364], 
             UndirectedEdge[159, 192] -> 
             RGBColor[
              0.9673784999999999, 0.9741865454545455, 0.8950990909090908], 
             UndirectedEdge[201, 289] -> 
             RGBColor[
              0.9285457727272727, 0.9423128181818181, 0.8435302727272729], 
             UndirectedEdge[29, 194] -> 
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363], 
             UndirectedEdge[79, 388] -> 
             RGBColor[0.6781735, 0.7395767727272726, 0.8222994545454547], 
             UndirectedEdge[246, 402] -> 
             RGBColor[
              0.9281668181818181, 0.9415022727272726, 0.8022834090909089], 
             UndirectedEdge[185, 398] -> 
             RGBColor[
              0.9414603636363637, 0.9555905454545455, 0.974571409090909], 
             UndirectedEdge[133, 304] -> 
             RGBColor[
              0.9756274090909092, 0.9782692727272728, 0.7458924090909093], 
             UndirectedEdge[107, 314] -> 
             RGBColor[0.7874971818181817, 0.833205, 0.9362861363636363], 
             UndirectedEdge[13, 279] -> 
             RGBColor[
              0.681378318181818, 0.5602798636363635, 0.5851387272727273], 
             UndirectedEdge[180, 418] -> 
             RGBColor[
              0.6665805909090909, 0.739457090909091, 0.9674021818181817], 
             UndirectedEdge[112, 207] -> 
             RGBColor[
              0.8374970909090909, 0.8730550909090908, 0.9407296818181818], 
             UndirectedEdge[308, 369] -> 
             RGBColor[
              0.7150237727272727, 0.7773012727272727, 0.9722305454545455], 
             UndirectedEdge[45, 292] -> 
             RGBColor[
              0.9120085454545455, 0.9281097272727273, 0.7595315000000002], 
             UndirectedEdge[348, 418] -> 
             RGBColor[
              0.8417789090909091, 0.8726462727272728, 0.711345136363636], 
             UndirectedEdge[51, 264] -> 
             RGBColor[0.8079908181818182, 0.850778090909091, 0.981271], 
             UndirectedEdge[201, 218] -> 
             RGBColor[
              0.9896106818181818, 0.9897538181818182, 0.8059990454545456], 
             UndirectedEdge[262, 376] -> 
             RGBColor[
              0.7829348636363636, 0.6419859545454544, 0.5936409999999999], 
             UndirectedEdge[304, 307] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[8, 166] -> 
             RGBColor[
              0.4833077727272727, 0.5697307727272727, 0.9564870454545454], 
             UndirectedEdge[66, 312] -> 
             RGBColor[
              0.6665805909090909, 0.739457090909091, 0.9674021818181817], 
             UndirectedEdge[202, 430] -> 
             RGBColor[
              0.9763853181818182, 0.9798903636363636, 0.8283861363636366], 
             UndirectedEdge[348, 404] -> 
             RGBColor[
              0.9162425909090909, 0.6466488181818182, 0.31927613636363616`], 
             UndirectedEdge[1, 113] -> 
             RGBColor[
              0.9739911818181818, 0.9791182727272727, 0.8839055454545454], 
             UndirectedEdge[29, 377] -> 
             RGBColor[0.9001235, 0.7343848636363635, 0.6050956363636363], 
             UndirectedEdge[259, 404] -> 
             RGBColor[
              0.9119607727272727, 0.6470576363636362, 0.5486606818181818], 
             UndirectedEdge[131, 449] -> 
             RGBColor[
              0.9190683636363636, 0.9380768181818182, 0.9842599090909091], 
             UndirectedEdge[423, 465] -> 
             RGBColor[
              0.9900654090909091, 0.9770589999999999, 0.5087140454545451], 
             UndirectedEdge[177, 412] -> 
             RGBColor[
              0.8661022272727272, 0.8961040909090909, 0.9791386818181818], 
             UndirectedEdge[139, 158] -> 
             RGBColor[
              0.9419309545454545, 0.9541227272727273, 0.9005547272727272], 
             UndirectedEdge[454, 500] -> 
             RGBColor[
              0.5154887272727271, 0.6171791363636361, 0.955098909090909], 
             UndirectedEdge[430, 459] -> 
             RGBColor[
              0.9763853181818182, 0.9798903636363636, 0.8283861363636366], 
             UndirectedEdge[474, 490] -> 
             RGBColor[0.7522105909090908, 0.806692, 0.9758467272727273], 
             UndirectedEdge[443, 451] -> 
             RGBColor[
              0.7227151818181817, 0.7814855454545454, 0.9546144999999999], 
             UndirectedEdge[182, 483] -> 
             RGBColor[
              0.7848744545454546, 0.8319541818181818, 0.9791700454545454], 
             UndirectedEdge[92, 457] -> 
             RGBColor[
              0.9857042727272727, 0.9883563636363637, 0.8865807272727273], 
             UndirectedEdge[38, 184] -> 
             RGBColor[
              0.6432485454545454, 0.7152769545454545, 0.9684847272727273], 
             UndirectedEdge[51, 457] -> 
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181], 
             UndirectedEdge[321, 455] -> 
             RGBColor[
              0.8147877727272728, 0.8547583636363636, 0.9132532272727273], 
             UndirectedEdge[251, 435] -> 
             RGBColor[0.9822400909090909, 0.983201, 0.7346988636363638], 
             UndirectedEdge[16, 441] -> 
             RGBColor[
              0.7808844999999999, 0.8282732727272726, 0.9474796818181818], 
             UndirectedEdge[302, 390] -> 
             RGBColor[
              0.9412969090909091, 0.7870574545454547, 0.4641242272727275], 
             UndirectedEdge[186, 455] -> 
             RGBColor[0.7522105909090908, 0.806692, 0.9758467272727273], 
             UndirectedEdge[349, 353] -> 
             RGBColor[
              0.9755034545454545, 0.9797436363636364, 0.8588432727272728], 
             UndirectedEdge[125, 406] -> 
             RGBColor[
              0.927663909090909, 0.9421660909090909, 0.8739874090909092], 
             UndirectedEdge[307, 433] -> 
             RGBColor[
              0.9668175909090909, 0.9491753636363636, 0.6586349999999999], 
             UndirectedEdge[406, 419] -> 
             RGBColor[
              0.9261516363636363, 0.9415407272727272, 0.8990496818181817], 
             UndirectedEdge[237, 274] -> 
             RGBColor[0.8712492272727272, 0.538652, 0.5784718181818181], 
             UndirectedEdge[203, 264] -> 
             RGBColor[
              0.8176590454545454, 0.8582599090909091, 0.9743103181818182], 
             UndirectedEdge[69, 231] -> 
             RGBColor[
              0.9164975909090909, 0.6489337272727271, 0.4734738636363637], 
             UndirectedEdge[328, 399] -> 
             RGBColor[
              0.9930106363636364, 0.9891982727272728, 0.6070716363636363], 
             UndirectedEdge[78, 262] -> 
             RGBColor[
              0.9346694999999999, 0.7578741363636362, 0.41766349999999974`], 
             UndirectedEdge[27, 412] -> 
             RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 
             UndirectedEdge[147, 221] -> 
             RGBColor[
              0.9658662272727272, 0.9735611818181817, 0.9201613636363637], 
             UndirectedEdge[93, 289] -> 
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273], 
             UndirectedEdge[141, 235] -> 
             RGBColor[
              0.9927556363636364, 0.9869133636363637, 0.4528739090909087], 
             UndirectedEdge[185, 464] -> 
             RGBColor[0.732212590909091, 0.79, 0.9747980909090909], 
             UndirectedEdge[6, 189] -> 
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273], 
             UndirectedEdge[38, 316] -> 
             RGBColor[
              0.42450336363636354`, 0.5411719545454544, 0.9485278181818182], 
             UndirectedEdge[322, 343] -> 
             RGBColor[
              0.7764321818181817, 0.8256140909090908, 0.9782609090909091], 
             UndirectedEdge[93, 141] -> 
             RGBColor[
              0.9884738181818182, 0.9873221818181819, 0.6822584545454543], 
             UndirectedEdge[191, 237] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[145, 461] -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909092], 
             UndirectedEdge[420, 500] -> 
             RGBColor[0.713695818181818, 0.7723304999999998, 0.9053935], 
             UndirectedEdge[402, 458] -> 
             RGBColor[
              0.7764321818181817, 0.8256140909090908, 0.9782609090909091], 
             UndirectedEdge[148, 263] -> 
             RGBColor[
              0.8248753636363635, 0.8634582727272726, 0.9830892727272726], 
             UndirectedEdge[126, 499] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[133, 371] -> 
             RGBColor[0.8906010454545454, 0.911301, 0.7574203636363638], 
             UndirectedEdge[72, 245] -> 
             RGBColor[
              0.9937685454545454, 0.9908193636363636, 0.6895653636363634], 
             UndirectedEdge[57, 131] -> 
             RGBColor[
              0.7161024999999999, 0.7765538181818181, 0.9658080454545455], 
             UndirectedEdge[15, 173] -> 
             RGBColor[
              0.5502814999999999, 0.6418001363636363, 0.9594442727272727], 
             UndirectedEdge[138, 415] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[105, 109] -> 
             RGBColor[
              0.916404409090909, 0.746798409090909, 0.5869414090909091], 
             UndirectedEdge[235, 284] -> 
             RGBColor[
              0.927408909090909, 0.9398811818181818, 0.7197896818181817], 
             UndirectedEdge[150, 473] -> 
             RGBColor[0.9941475, 0.9916299090909091, 0.7308122272727275], 
             UndirectedEdge[74, 417] -> 
             RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 
             UndirectedEdge[20, 413] -> 
             RGBColor[
              0.5018383181818181, 0.6039559545454545, 0.954615909090909], 
             UndirectedEdge[34, 467] -> 
             RGBColor[
              0.7660006818181819, 0.8118681818181819, 0.704872227272727], 
             UndirectedEdge[62, 110] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[93, 389] -> 
             RGBColor[
              0.9884738181818182, 0.9873221818181819, 0.6822584545454543], 
             UndirectedEdge[28, 408] -> 
             RGBColor[
              0.9821161363636364, 0.9846753636363637, 0.8476497272727272], 
             UndirectedEdge[93, 284] -> 
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273], 
             UndirectedEdge[143, 313] -> 
             RGBColor[
              0.8374970909090909, 0.8730550909090908, 0.9407296818181818], 
             UndirectedEdge[361, 398] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[105, 382] -> 
             RGBColor[
              0.9511285909090909, 0.9630723636363636, 0.9676107272727272], 
             UndirectedEdge[240, 495] -> 
             RGBColor[
              0.9589675454545454, 0.9650451818181819, 0.7227997727272726], 
             UndirectedEdge[13, 21] -> 
             RGBColor[
              0.8313780454545454, 0.6798301363636362, 0.5984693636363636], 
             UndirectedEdge[32, 179] -> 
             RGBColor[
              0.6742670909090909, 0.7381793181818181, 0.9028811363636364], 
             UndirectedEdge[38, 79] -> 
             RGBColor[0.6781735, 0.7395767727272726, 0.8222994545454547], 
             UndirectedEdge[328, 407] -> 
             RGBColor[
              0.8902220909090909, 0.9104904545454546, 0.7161734999999998], 
             UndirectedEdge[357, 367] -> 
             RGBColor[
              0.9247919090909091, 0.8905639999999999, 0.6365702727272727], 
             UndirectedEdge[196, 213] -> 
             RGBColor[
              0.8374970909090909, 0.8730550909090908, 0.9407296818181818], 
             UndirectedEdge[233, 326] -> 
             RGBColor[0.7874971818181817, 0.833205, 0.9362861363636363], 
             UndirectedEdge[164, 372] -> 
             RGBColor[
              0.709663318181818, 0.44946731818181807`, 0.5679387272727272], 
             UndirectedEdge[3, 278] -> 
             RGBColor[
              0.9734302727272728, 0.954107090909091, 0.6474414545454544], 
             UndirectedEdge[195, 399] -> 
             RGBColor[
              0.9755034545454545, 0.9797436363636364, 0.8588432727272728], 
             UndirectedEdge[118, 187] -> 
             RGBColor[
              0.9911229545454545, 0.9903791818181817, 0.7809367727272729], 
             UndirectedEdge[61, 178] -> 
             RGBColor[0.978413, 0.970915, 0.6667984090909089], 
             UndirectedEdge[2, 496] -> 
             RGBColor[
              0.7227151818181817, 0.7814855454545454, 0.9546144999999999], 
             UndirectedEdge[103, 404] -> 
             RGBColor[
              0.9127944545454545, 0.6351733636363635, 0.29262254545454536`], 
             UndirectedEdge[37, 374] -> 
             RGBColor[
              0.9593465000000001, 0.9658557272727273, 0.7640466363636365], 
             UndirectedEdge[236, 466] -> 
             RGBColor[
              0.9926352272727272, 0.9910045454545455, 0.7558745000000001], 
             UndirectedEdge[150, 254] -> 
             RGBColor[0.9941475, 0.9916299090909091, 0.7308122272727275], 
             UndirectedEdge[148, 229] -> 
             RGBColor[0.8889648181818182, 0.91215, 0.8954334999999999], 
             UndirectedEdge[160, 432] -> 
             RGBColor[
              0.9808766363636363, 0.9471545454545454, 0.3802097727272725], 
             UndirectedEdge[48, 198] -> 
             RGBColor[
              0.7808844999999999, 0.8282732727272726, 0.9474796818181818], 
             UndirectedEdge[89, 178] -> 
             RGBColor[
              0.9081814545454545, 0.9158237272727272, 0.6916310454545453], 
             UndirectedEdge[63, 239] -> 
             RGBColor[
              0.8667584090909091, 0.8931894545454545, 0.7962530454545452], 
             UndirectedEdge[425, 462] -> 
             RGBColor[
              0.6150239545454546, 0.697601090909091, 0.9633434545454544], 
             UndirectedEdge[44, 457] -> 
             RGBColor[
              0.9887288181818181, 0.9896070909090909, 0.8364561818181819], 
             UndirectedEdge[46, 254] -> 
             RGBColor[
              0.9887288181818181, 0.9896070909090909, 0.8364561818181819], 
             UndirectedEdge[1, 452] -> 
             RGBColor[
              0.8163000454545455, 0.8553837272727274, 0.8881909545454545], 
             UndirectedEdge[260, 299] -> 
             RGBColor[0.9405712272727274, 0.903146, 0.6380753181818182], 
             UndirectedEdge[321, 341] -> 
             RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454546], 
             UndirectedEdge[249, 406] -> 
             RGBColor[0.8778414999999999, 0.9054309999999999, 0.9882105], 
             UndirectedEdge[398, 496] -> 
             RGBColor[
              0.7227151818181817, 0.7814855454545454, 0.9546144999999999], 
             UndirectedEdge[382, 462] -> 
             RGBColor[
              0.7418808181818182, 0.7974818181818182, 0.9678374090909091], 
             UndirectedEdge[63, 272] -> 
             RGBColor[
              0.8632309545454545, 0.8926025454545454, 0.9180815909090909], 
             UndirectedEdge[117, 270] -> 
             RGBColor[
              0.5215526818181818, 0.6210315454545454, 0.9558720909090909], 
             UndirectedEdge[164, 404] -> 
             RGBColor[
              0.7152659545454544, 0.49253163636363617`, 0.5733038181818182], 
             UndirectedEdge[133, 191] -> 
             RGBColor[
              0.9054162727272728, 0.5613307272727273, 0.34979281818181834`], 
             UndirectedEdge[307, 469] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[31, 237] -> 
             RGBColor[
              0.515825590909091, 0.23836704545454543`, 0.5498676363636363], 
             UndirectedEdge[1, 468] -> 
             RGBColor[
              0.7389650909090908, 0.7925997272727272, 0.8821028636363635], 
             UndirectedEdge[346, 395] -> 
             RGBColor[
              0.48330777272727266`, 0.5697307727272727, 0.9564870454545454], 
             UndirectedEdge[214, 223] -> 
             RGBColor[
              0.8874525454545454, 0.9115246363636363, 0.9204957727272727], 
             UndirectedEdge[264, 397] -> 
             RGBColor[
              0.8425368181818181, 0.8742673636363636, 0.7938388636363634], 
             UndirectedEdge[103, 204] -> 
             RGBColor[
              0.9081814545454545, 0.9158237272727272, 0.6916310454545453], 
             UndirectedEdge[110, 356] -> 
             RGBColor[
              0.9414603636363637, 0.9555905454545455, 0.974571409090909], 
             UndirectedEdge[184, 253] -> 
             RGBColor[0.956198, 0.9660793636363636, 0.9271220454545455], 
             UndirectedEdge[115, 417] -> 
             RGBColor[
              0.7934374545454546, 0.8393378181818182, 0.9718961363636364], 
             UndirectedEdge[243, 459] -> 
             RGBColor[
              0.9697726363636363, 0.9749586363636363, 0.839579681818182], 
             UndirectedEdge[190, 349] -> 
             RGBColor[
              0.9930106363636364, 0.9891982727272728, 0.6070716363636363], 
             UndirectedEdge[128, 222] -> 
             RGBColor[
              0.9933895909090908, 0.9900088181818183, 0.6483185000000002], 
             UndirectedEdge[204, 275] -> 
             RGBColor[
              0.900735090909091, 0.9227762727272728, 0.9588627272727273], 
             UndirectedEdge[178, 455] -> 
             RGBColor[
              0.8141091818181818, 0.8422487272727273, 0.6822773636363635], 
             UndirectedEdge[84, 391] -> 
             RGBColor[
              0.9222886363636363, 0.7986122272727274, 0.6085626818181818], 
             UndirectedEdge[54, 203] -> 
             RGBColor[
              0.9511285909090909, 0.9630723636363636, 0.9676107272727272], 
             UndirectedEdge[236, 314] -> 
             RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454544], 
             UndirectedEdge[277, 313] -> 
             RGBColor[
              0.8176590454545454, 0.8582599090909091, 0.9743103181818182], 
             UndirectedEdge[186, 397] -> 
             RGBColor[
              0.9281668181818181, 0.9415022727272726, 0.8022834090909089], 
             UndirectedEdge[29, 297] -> 
             RGBColor[
              0.9601044090909091, 0.9674768181818182, 0.8465403636363638], 
             UndirectedEdge[130, 208] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[145, 450] -> 
             RGBColor[
              0.7920339999999999, 0.8350810909090909, 0.8610993181818183], 
             UndirectedEdge[86, 350] -> 
             RGBColor[
              0.9917533636363636, 0.9908578181818182, 0.7863316363636363], 
             UndirectedEdge[37, 281] -> 
             RGBColor[
              0.9690147272727272, 0.9733375454545454, 0.7570859545454547], 
             UndirectedEdge[281, 445] -> 
             RGBColor[
              0.6726311363636364, 0.7398343636363636, 0.9627802272727273], 
             UndirectedEdge[116, 224] -> 
             RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 
             UndirectedEdge[112, 163] -> 
             RGBColor[
              0.8374970909090909, 0.8730550909090908, 0.9407296818181818], 
             UndirectedEdge[148, 480] -> 
             RGBColor[
              0.872714909090909, 0.9010358181818181, 0.9679451363636363], 
             UndirectedEdge[42, 487] -> 
             RGBColor[
              0.6471835909090908, 0.7197705454545454, 0.9682358636363636], 
             UndirectedEdge[122, 319] -> 
             RGBColor[
              0.6665805909090909, 0.739457090909091, 0.9674021818181817], 
             UndirectedEdge[129, 348] -> 
             RGBColor[
              0.6573222727272727, 0.7200695454545454, 0.6973026818181817], 
             UndirectedEdge[93, 201] -> 
             RGBColor[
              0.9896106818181818, 0.9897538181818182, 0.8059990454545456], 
             UndirectedEdge[121, 427] -> 
             RGBColor[0.6595294545454544, 0.7276904999999999, 0.9503305], 
             UndirectedEdge[269, 411] -> 
             RGBColor[
              0.9734302727272728, 0.954107090909091, 0.6474414545454544], 
             UndirectedEdge[76, 371] -> 
             RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 
             UndirectedEdge[61, 244] -> 
             RGBColor[
              0.9790915909090909, 0.9834246363636363, 0.8977742727272727], 
             UndirectedEdge[184, 436] -> 
             RGBColor[0.9405712272727274, 0.903146, 0.6380753181818182], 
             UndirectedEdge[80, 293] -> 
             RGBColor[
              0.6314042727272726, 0.7071885454545455, 0.9667308181818182], 
             UndirectedEdge[111, 460] -> 
             RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454544], 
             UndirectedEdge[286, 358] -> 
             RGBColor[
              0.9933895909090908, 0.9900088181818183, 0.6483185000000002], 
             UndirectedEdge[176, 244] -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909092], 
             UndirectedEdge[99, 321] -> 
             RGBColor[
              0.9658662272727272, 0.9735611818181817, 0.9201613636363637], 
             UndirectedEdge[187, 478] -> 
             RGBColor[0.9941475, 0.9916299090909091, 0.7308122272727275], 
             UndirectedEdge[116, 185] -> 
             RGBColor[
              0.8564339999999999, 0.8886222727272728, 0.9860993636363635], 
             UndirectedEdge[97, 257] -> 
             RGBColor[
              0.6636230454545454, 0.6920538636363637, 0.6331913636363637], 
             UndirectedEdge[16, 313] -> 
             RGBColor[
              0.6408022727272726, 0.7185290909090908, 0.9653728181818182], 
             UndirectedEdge[166, 344] -> 
             RGBColor[
              0.872714909090909, 0.9010358181818181, 0.9679451363636363], 
             UndirectedEdge[103, 443] -> 
             RGBColor[
              0.9718003181818182, 0.9659832727272727, 0.6779919545454545], 
             UndirectedEdge[74, 115] -> 
             RGBColor[
              0.7934374545454546, 0.8393378181818182, 0.9718961363636364], 
             UndirectedEdge[196, 332] -> 
             RGBColor[
              0.7764321818181817, 0.8256140909090908, 0.9782609090909091], 
             UndirectedEdge[49, 203] -> 
             RGBColor[
              0.7418808181818182, 0.7974818181818182, 0.9678374090909091], 
             UndirectedEdge[95, 122] -> 
             RGBColor[
              0.8147877727272728, 0.8547583636363636, 0.9132532272727273], 
             UndirectedEdge[97, 209] -> 
             RGBColor[
              0.5959105909090909, 0.6775309545454545, 0.9639695909090908], 
             UndirectedEdge[484, 490] -> 
             RGBColor[
              0.8175573181818182, 0.8537241818181819, 0.7089309545454543], 
             UndirectedEdge[128, 415] -> 
             RGBColor[
              0.9755034545454545, 0.9797436363636364, 0.8588432727272728], 
             UndirectedEdge[371, 442] -> 
             RGBColor[0.8376265, 0.7082029090909092, 0.6036832272727273], 
             UndirectedEdge[88, 311] -> 
             RGBColor[0.9651876363636362, 0.9610515454545454, 0.6891855], 
             UndirectedEdge[15, 149] -> 
             RGBColor[
              0.7634669545454544, 0.8151454545454545, 0.977058909090909], 
             UndirectedEdge[117, 140] -> 
             RGBColor[0.697006, 0.7565056363636364, 0.8540127727272728], 
             UndirectedEdge[199, 475] -> 
             RGBColor[
              0.9480730454545454, 0.9605222727272728, 0.9633778636363636], 
             UndirectedEdge[71, 169] -> 
             RGBColor[
              0.9900654090909091, 0.9770589999999999, 0.5087140454545451], 
             UndirectedEdge[23, 51] -> 
             RGBColor[
              0.9480730454545454, 0.9605222727272728, 0.9633778636363636], 
             UndirectedEdge[381, 416] -> 
             RGBColor[0.9123875, 0.9289202727272727, 0.8007783636363635], 
             UndirectedEdge[121, 447] -> 
             RGBColor[
              0.36131763636363623`, 0.48737690909090897`, 0.9442438181818181],
              UndirectedEdge[244, 407] -> 
             RGBColor[
              0.8874525454545454, 0.9115246363636363, 0.9204957727272727], 
             UndirectedEdge[255, 385] -> 
             RGBColor[
              0.9031987272727273, 0.8990158181818182, 0.6722740909090908], 
             UndirectedEdge[30, 469] -> 
             RGBColor[
              0.9032890454545454, 0.9254948181818181, 0.9827548636363637], 
             UndirectedEdge[80, 171] -> 
             RGBColor[
              0.6939814545454546, 0.7552549090909091, 0.9041373181818182], 
             UndirectedEdge[214, 466] -> 
             RGBColor[
              0.9911229545454545, 0.9903791818181817, 0.7809367727272729], 
             UndirectedEdge[199, 455] -> 
             RGBColor[0.7837692272727272, 0.831856, 0.9788568181818181], 
             UndirectedEdge[175, 483] -> 
             RGBColor[
              0.5699958636363636, 0.6588757272727273, 0.9607004545454545], 
             UndirectedEdge[124, 416] -> 
             RGBColor[0.8305035454545455, 0.867685, 0.9836953636363637], 
             UndirectedEdge[142, 396] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[185, 361] -> 
             RGBColor[
              0.9480730454545454, 0.9605222727272728, 0.9633778636363636], 
             UndirectedEdge[19, 26] -> 
             RGBColor[0.8889648181818182, 0.91215, 0.8954334999999999], 
             UndirectedEdge[341, 455] -> 
             RGBColor[
              0.8147877727272728, 0.8547583636363636, 0.9132532272727273], 
             UndirectedEdge[159, 239] -> 
             RGBColor[
              0.9693936818181818, 0.9741480909090909, 0.798332818181818], 
             UndirectedEdge[261, 482] -> 
             RGBColor[
              0.9618348636363636, 0.9323674545454547, 0.6392780454545456], 
             UndirectedEdge[5, 97] -> 
             RGBColor[
              0.6529167727272727, 0.7227587727272726, 0.9615240454545455], 
             UndirectedEdge[285, 396] -> 
             RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 
             UndirectedEdge[174, 424] -> 
             RGBColor[
              0.9850256818181817, 0.9758467272727273, 0.6556048636363635], 
             UndirectedEdge[99, 186] -> 
             RGBColor[
              0.9032890454545454, 0.9254948181818181, 0.9827548636363637], 
             UndirectedEdge[79, 127] -> 
             RGBColor[0.6781735, 0.7395767727272726, 0.8222994545454547], 
             UndirectedEdge[29, 86] -> 
             RGBColor[
              0.9577102727272727, 0.9667047272727274, 0.9020597727272726], 
             UndirectedEdge[127, 316] -> 
             RGBColor[
              0.42450336363636354`, 0.5411719545454544, 0.9485278181818182], 
             UndirectedEdge[197, 466] -> 
             RGBColor[
              0.7413592272727272, 0.7933718181818181, 0.8265834545454547], 
             UndirectedEdge[183, 206] -> 
             RGBColor[
              0.3848646818181817, 0.4920364999999999, 0.9472151363636363], 
             UndirectedEdge[25, 392] -> 
             RGBColor[
              0.8164330909090909, 0.8571181818181818, 0.9821801363636363], 
             UndirectedEdge[73, 91] -> 
             RGBColor[
              0.7833481363636363, 0.8045128181818181, 0.6608910454545454], 
             UndirectedEdge[187, 464] -> 
             RGBColor[
              0.7671375454545455, 0.8142998181818182, 0.8286128181818184], 
             UndirectedEdge[17, 99] -> 
             RGBColor[
              0.9348476818181818, 0.9506588181818182, 0.9857649545454545], 
             UndirectedEdge[110, 157] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[241, 429] -> 
             RGBColor[
              0.6661421363636363, 0.7326222272727272, 0.9391369545454544], 
             UndirectedEdge[27, 490] -> 
             RGBColor[
              0.7934374545454546, 0.8393378181818182, 0.9718961363636364], 
             UndirectedEdge[372, 418] -> 
             RGBColor[
              0.7596632272727273, 0.489317409090909, 0.5723822727272727], 
             UndirectedEdge[65, 350] -> 
             RGBColor[0.9941475, 0.9916299090909091, 0.7308122272727275], 
             UndirectedEdge[189, 390] -> 
             RGBColor[
              0.9285457727272727, 0.9423128181818181, 0.8435302727272729], 
             UndirectedEdge[263, 267] -> 
             RGBColor[
              0.8685648636363635, 0.7092208636363635, 0.6020855454545454], 
             UndirectedEdge[25, 490] -> 
             RGBColor[
              0.767989909090909, 0.8192740000000001, 0.9773517727272727], 
             UndirectedEdge[360, 494] -> 
             RGBColor[
              0.8164330909090909, 0.8571181818181818, 0.9821801363636363], 
             UndirectedEdge[61, 203] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[36, 104] -> 
             RGBColor[
              0.9821161363636364, 0.9846753636363637, 0.8476497272727272], 
             UndirectedEdge[33, 241] -> 
             RGBColor[0.6595294545454544, 0.7276904999999999, 0.9503305], 
             UndirectedEdge[82, 419] -> 
             RGBColor[
              0.6757793636363636, 0.7388046818181817, 0.8778188636363635], 
             UndirectedEdge[5, 404] -> 
             RGBColor[
              0.8921227272727272, 0.6322624545454545, 0.5822413181818182], 
             UndirectedEdge[40, 396] -> 
             RGBColor[
              0.6408022727272726, 0.7185290909090908, 0.9653728181818182], 
             UndirectedEdge[169, 369] -> 
             RGBColor[
              0.8667584090909091, 0.8931894545454545, 0.7962530454545452], 
             UndirectedEdge[268, 491] -> 
             RGBColor[
              0.951937318181818, 0.8427626363636362, 0.530379818181818], 
             UndirectedEdge[4, 151] -> 
             RGBColor[
              0.9845797727272727, 0.960914909090909, 0.561061090909091], 
             UndirectedEdge[6, 390] -> 
             RGBColor[
              0.9896106818181818, 0.9897538181818182, 0.8059990454545456], 
             UndirectedEdge[376, 482] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[158, 278] -> 
             RGBColor[
              0.9322937272727272, 0.9479402727272728, 0.9618728181818181], 
             UndirectedEdge[317, 445] -> 
             RGBColor[
              0.4699960454545455, 0.5791755454545455, 0.9518133636363636], 
             UndirectedEdge[133, 351] -> 
             RGBColor[
              0.9903650454545454, 0.988758090909091, 0.6984430454545456], 
             UndirectedEdge[239, 454] -> 
             RGBColor[
              0.7925369090909089, 0.8344172727272726, 0.789395318181818], 
             UndirectedEdge[140, 198] -> 
             RGBColor[
              0.9821161363636364, 0.9846753636363637, 0.8476497272727272], 
             UndirectedEdge[252, 309] -> 
             RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 
             UndirectedEdge[161, 243] -> 
             RGBColor[
              0.960204909090909, 0.9442436363636364, 0.6698285454545454], 
             UndirectedEdge[244, 455] -> 
             RGBColor[
              0.8147877727272728, 0.8547583636363636, 0.9132532272727273], 
             UndirectedEdge[401, 451] -> 
             RGBColor[
              0.7404773636363635, 0.7932250909090909, 0.857040590909091], 
             UndirectedEdge[210, 225] -> 
             RGBColor[0.7484935, 0.8024135454545456, 0.9566438636363637], 
             UndirectedEdge[107, 223] -> 
             RGBColor[
              0.6892454545454544, 0.7563732727272726, 0.9702011818181817], 
             UndirectedEdge[5, 204] -> 
             RGBColor[
              0.8875097272727273, 0.9129128181818182, 0.9812498181818182], 
             UndirectedEdge[59, 200] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[328, 481] -> 
             RGBColor[
              0.9589675454545454, 0.9650451818181819, 0.7227997727272726], 
             UndirectedEdge[55, 434] -> 
             RGBColor[
              0.8551059999999999, 0.8870454545454545, 0.954337409090909], 
             UndirectedEdge[269, 499] -> 
             RGBColor[
              0.8308844090909091, 0.8681233636363637, 0.9519232272727272], 
             UndirectedEdge[377, 476] -> 
             RGBColor[
              0.9296297727272727, 0.7566618636363636, 0.5645543181818182], 
             UndirectedEdge[260, 478] -> 
             RGBColor[
              0.9592225454545454, 0.967330090909091, 0.8769975000000001], 
             UndirectedEdge[163, 207] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[238, 258] -> 
             RGBColor[
              0.8671373636363636, 0.8939999999999999, 0.8374999090909092], 
             UndirectedEdge[10, 443] -> 
             RGBColor[
              0.9760063636363636, 0.9790798181818181, 0.7871392727272726], 
             UndirectedEdge[231, 326] -> 
             RGBColor[
              0.7152659545454544, 0.49253163636363617`, 0.5733038181818182], 
             UndirectedEdge[91, 287] -> 
             RGBColor[
              0.7929158636363636, 0.835227818181818, 0.830642181818182], 
             UndirectedEdge[242, 249] -> 
             RGBColor[0.7922115, 0.8381960909090909, 0.9797659545454545], 
             UndirectedEdge[83, 209] -> 
             RGBColor[0.8305035454545455, 0.867685, 0.9836953636363637], 
             UndirectedEdge[306, 431] -> 
             RGBColor[
              0.9790915909090909, 0.9834246363636363, 0.8977742727272727], 
             UndirectedEdge[176, 376] -> 
             RGBColor[
              0.842033909090909, 0.8749311818181817, 0.8655428636363637], 
             UndirectedEdge[30, 191] -> 
             RGBColor[
              0.8809174545454546, 0.5461338181818182, 0.5715111363636364], 
             UndirectedEdge[209, 444] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[169, 289] -> 
             RGBColor[
              0.9281668181818181, 0.9415022727272726, 0.8022834090909089], 
             UndirectedEdge[20, 46] -> 
             RGBColor[0.8132755, 0.854133, 0.9383155], 
             UndirectedEdge[49, 100] -> 
             RGBColor[
              0.7667585909090909, 0.8134892727272728, 0.7873659545454543], 
             UndirectedEdge[404, 486] -> 
             RGBColor[0.8824544999999999, 0.6247806363636363, 0.589202], 
             UndirectedEdge[103, 431] -> 
             RGBColor[0.978413, 0.970915, 0.6667984090909089], 
             UndirectedEdge[219, 238] -> 
             RGBColor[
              0.9763853181818182, 0.9798903636363636, 0.8283861363636366], 
             UndirectedEdge[249, 499] -> 
             RGBColor[0.7922115, 0.8381960909090909, 0.9797659545454545], 
             UndirectedEdge[254, 377] -> 
             RGBColor[
              0.9341665909090908, 0.7585379545454545, 0.48936750000000007`], 
             UndirectedEdge[57, 434] -> 
             RGBColor[
              0.6134672272727272, 0.6955951818181818, 0.9637282727272727], 
             UndirectedEdge[75, 104] -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             UndirectedEdge[132, 365] -> 
             RGBColor[
              0.9746143181818181, 0.9272990909090909, 0.5223471818181818], 
             UndirectedEdge[38, 77] -> 
             RGBColor[
              0.6727548181818181, 0.7375539545454546, 0.9279434090909091], 
             UndirectedEdge[172, 314] -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             UndirectedEdge[398, 481] -> 
             RGBColor[
              0.9414603636363637, 0.9555905454545455, 0.974571409090909], 
             UndirectedEdge[143, 165] -> 
             RGBColor[
              0.8617186818181818, 0.8919771818181819, 0.9431438636363636], 
             UndirectedEdge[261, 475] -> 
             RGBColor[
              0.9684475454545455, 0.937299181818182, 0.6280845000000002], 
             UndirectedEdge[288, 373] -> 
             RGBColor[0.9073477727272727, 0.927708, 0.9476691818181818], 
             UndirectedEdge[78, 171] -> 
             RGBColor[0.990744, 0.9895686363636363, 0.7396899090909089], 
             UndirectedEdge[6, 370] -> 
             RGBColor[
              0.8617186818181818, 0.8919771818181819, 0.9431438636363636], 
             UndirectedEdge[264, 295] -> 
             RGBColor[
              0.7764321818181817, 0.8256140909090908, 0.9782609090909091], 
             UndirectedEdge[45, 464] -> 
             RGBColor[
              0.7663796363636364, 0.8126787272727274, 0.7461190909090911], 
             UndirectedEdge[228, 318] -> 
             RGBColor[
              0.6894876363636364, 0.47160363636363634`, 0.5712744545454546], 
             UndirectedEdge[7, 295] -> 
             RGBColor[
              0.927663909090909, 0.9421660909090909, 0.8739874090909092], 
             UndirectedEdge[225, 320] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[137, 148] -> 
             RGBColor[
              0.872714909090909, 0.9010358181818181, 0.9679451363636363], 
             UndirectedEdge[61, 455] -> 
             RGBColor[
              0.8066628181818182, 0.8492012727272727, 0.9495090454545454], 
             UndirectedEdge[11, 331] -> 
             RGBColor[
              0.9120085454545455, 0.9281097272727273, 0.7595315000000002], 
             UndirectedEdge[20, 392] -> 
             RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             UndirectedEdge[348, 431] -> 
             RGBColor[
              0.9818611363636364, 0.9823904545454546, 0.6934519999999997], 
             UndirectedEdge[241, 351] -> 
             RGBColor[
              0.6742670909090909, 0.7381793181818181, 0.9028811363636364], 
             UndirectedEdge[343, 374] -> 
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454], 
             UndirectedEdge[162, 389] -> 
             RGBColor[
              0.8175573181818182, 0.8537241818181819, 0.7089309545454543], 
             UndirectedEdge[207, 266] -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             UndirectedEdge[98, 425] -> 
             RGBColor[
              0.8374970909090909, 0.8730550909090908, 0.9407296818181818], 
             UndirectedEdge[151, 284] -> 
             RGBColor[
              0.9189780454545454, 0.9115978181818181, 0.6737791363636363], 
             UndirectedEdge[41, 365] -> 
             RGBColor[
              0.8476041818181819, 0.8296691818181818, 0.6290348636363636], 
             UndirectedEdge[436, 473] -> 
             RGBColor[
              0.9746143181818181, 0.9272990909090909, 0.5223471818181818], 
             UndirectedEdge[311, 405] -> 
             RGBColor[0.9686357727272727, 0.972527, 0.7158390909090907], 
             UndirectedEdge[235, 432] -> 
             RGBColor[
              0.9843247727272728, 0.9586300000000001, 0.40686336363636333`], 
             UndirectedEdge[109, 474] -> 
             RGBColor[
              0.8685648636363635, 0.7092208636363635, 0.6020855454545455], 
             UndirectedEdge[364, 468] -> 
             RGBColor[
              0.7293278636363636, 0.7864172727272727, 0.9434209545454545], 
             UndirectedEdge[203, 374] -> 
             RGBColor[
              0.9348476818181818, 0.9506588181818182, 0.9857649545454545], 
             UndirectedEdge[36, 112] -> 
             RGBColor[
              0.8308844090909091, 0.8681233636363637, 0.9519232272727272], 
             UndirectedEdge[324, 342] -> 
             RGBColor[
              0.7663796363636364, 0.8126787272727274, 0.7461190909090911], 
             UndirectedEdge[374, 445] -> 
             RGBColor[
              0.662962909090909, 0.7323525454545454, 0.969740909090909], 
             UndirectedEdge[2, 327] -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             UndirectedEdge[128, 438] -> 
             RGBColor[
              0.9755034545454545, 0.9797436363636364, 0.8588432727272728], 
             UndirectedEdge[33, 460] -> 
             RGBColor[
              0.9739911818181818, 0.9791182727272727, 0.8839055454545454], 
             UndirectedEdge[298, 335] -> 
             RGBColor[0.8778414999999999, 0.9054309999999999, 0.9882105], 
             UndirectedEdge[112, 343] -> 
             RGBColor[
              0.7764321818181817, 0.8256140909090908, 0.9782609090909091], 
             UndirectedEdge[106, 265] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             UndirectedEdge[19, 468] -> 
             RGBColor[
              0.6376888181818181, 0.7145172727272726, 0.9661424545454544], 
             UndirectedEdge[161, 202] -> 
             RGBColor[
              0.9854616363636364, 0.9610616363636364, 0.5306039545454546], 
             UndirectedEdge[204, 390] -> 
             RGBColor[
              0.9127664545454546, 0.9297308181818182, 0.8420252272727275], 
             UndirectedEdge[211, 289] -> 
             RGBColor[
              0.927663909090909, 0.9421660909090909, 0.8739874090909092], 
             UndirectedEdge[48, 479] -> 
             RGBColor[
              0.7106529545454545, 0.7731819999999999, 0.9723123181818182], 
             UndirectedEdge[57, 495] -> 
             RGBColor[0.7064342727272727, 0.769072, 0.9727687272727272], 
             UndirectedEdge[10, 280] -> 
             RGBColor[
              0.7409802727272726, 0.7925612727272726, 0.7853365909090907], 
             UndirectedEdge[206, 476] -> 
             RGBColor[0.7874971818181817, 0.833205, 0.9362861363636363], 
             UndirectedEdge[13, 256] -> 
             RGBColor[0.8527855454545454, 0.6966388636363635, 0.6005805], 
             UndirectedEdge[184, 221] -> 
             RGBColor[
              0.9348476818181818, 0.9506588181818182, 0.9857649545454545], 
             UndirectedEdge[126, 282] -> 
             RGBColor[
              0.9256810454545454, 0.9430085454545454, 0.9730663636363637], 
             UndirectedEdge[53, 266] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[194, 220] -> 
             RGBColor[
              0.662962909090909, 0.7323525454545454, 0.969740909090909], 
             UndirectedEdge[375, 417] -> 
             RGBColor[
              0.8977253636363636, 0.6753267727272729, 0.5876064090909092], 
             UndirectedEdge[245, 448] -> 
             RGBColor[
              0.9597254545454545, 0.9666662727272728, 0.8052934999999998], 
             UndirectedEdge[79, 147] -> 
             RGBColor[
              0.9911229545454545, 0.9903791818181817, 0.7809367727272729], 
             UndirectedEdge[77, 253] -> 
             RGBColor[
              0.9857042727272727, 0.9883563636363637, 0.8865807272727273], 
             UndirectedEdge[180, 205] -> 
             RGBColor[0.7837692272727272, 0.831856, 0.9788568181818181], 
             UndirectedEdge[28, 432] -> 
             RGBColor[
              0.9734302727272728, 0.954107090909091, 0.6474414545454544], 
             UndirectedEdge[84, 245] -> 
             RGBColor[
              0.9693936818181818, 0.9741480909090909, 0.798332818181818], 
             UndirectedEdge[19, 459] -> 
             RGBColor[
              0.8913589545454546, 0.9129220909090909, 0.8399140909090911], 
             UndirectedEdge[153, 236] -> 
             RGBColor[
              0.9261516363636363, 0.9415407272727272, 0.8990496818181817], 
             UndirectedEdge[315, 349] -> 
             RGBColor[
              0.9755034545454545, 0.9797436363636364, 0.8588432727272728], 
             UndirectedEdge[18, 460] -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909089], 
             UndirectedEdge[126, 449] -> 
             RGBColor[
              0.9256810454545454, 0.9430085454545454, 0.9730663636363637], 
             UndirectedEdge[49, 324] -> 
             RGBColor[
              0.7663796363636364, 0.8126787272727274, 0.7461190909090911], 
             UndirectedEdge[334, 415] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[5, 444] -> 
             RGBColor[
              0.9348476818181818, 0.9506588181818182, 0.9857649545454545], 
             UndirectedEdge[147, 449] -> 
             RGBColor[0.9404186818181818, 0.9534973636363636, 0.925617], 
             UndirectedEdge[254, 426] -> 
             RGBColor[0.8662555, 0.8938532727272728, 0.8679570454545456], 
             UndirectedEdge[186, 321] -> 
             RGBColor[
              0.9246393636363636, 0.9409153636363636, 0.9241119545454546], 
             UndirectedEdge[260, 399] -> 
             RGBColor[
              0.9592225454545454, 0.967330090909091, 0.8769975000000001], 
             UndirectedEdge[184, 287] -> 
             RGBColor[
              0.9601044090909091, 0.9674768181818182, 0.8465403636363638], 
             UndirectedEdge[129, 431] -> 
             RGBColor[
              0.6464277727272727, 0.7155466363636362, 0.9378807727272727], 
             UndirectedEdge[300, 432] -> 
             RGBColor[
              0.9505366818181819, 0.9367618181818183, 0.6767892272727272], 
             UndirectedEdge[207, 293] -> 
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273], 
             UndirectedEdge[118, 399] -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909092], 
             UndirectedEdge[138, 179] -> 
             RGBColor[
              0.526059909090909, 0.6228780454545454, 0.9570300909090909], 
             UndirectedEdge[40, 161] -> 
             RGBColor[
              0.7833481363636363, 0.8045128181818181, 0.6608910454545454], 
             UndirectedEdge[243, 279] -> 
             RGBColor[
              0.7161024999999999, 0.7765538181818181, 0.9658080454545455], 
             UndirectedEdge[69, 233] -> 
             RGBColor[
              0.9887288181818181, 0.9896070909090909, 0.8364561818181819], 
             UndirectedEdge[237, 460] -> 
             RGBColor[
              0.9037800454545455, 0.5621797272727274, 0.4878059545454545], 
             UndirectedEdge[54, 295] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[102, 210] -> 
             RGBColor[
              0.6848746363636364, 0.7522540000000001, 0.9702829545454545], 
             UndirectedEdge[137, 156] -> 
             RGBColor[
              0.9511285909090909, 0.9630723636363636, 0.9676107272727272], 
             UndirectedEdge[231, 444] -> 
             RGBColor[0.8824544999999999, 0.6247806363636363, 0.589202], 
             UndirectedEdge[383, 393] -> 
             RGBColor[
              0.9763853181818182, 0.9798903636363636, 0.8283861363636366], 
             UndirectedEdge[43, 137] -> 
             RGBColor[
              0.8941224090909091, 0.9178445454545454, 0.9700562727272728], 
             UndirectedEdge[233, 348] -> 
             RGBColor[
              0.9884738181818182, 0.9873221818181819, 0.6822584545454543], 
             UndirectedEdge[193, 410] -> 
             RGBColor[
              0.8462828636363636, 0.8802669999999999, 0.9852004090909091], 
             UndirectedEdge[126, 384] -> 
             RGBColor[
              0.9511285909090909, 0.9630723636363636, 0.9676107272727272], 
             UndirectedEdge[162, 345] -> 
             RGBColor[
              0.7934374545454546, 0.8393378181818182, 0.9718961363636364], 
             UndirectedEdge[165, 178] -> 
             RGBColor[
              0.8625523636363637, 0.8800929090909091, 0.6871057272727271], 
             UndirectedEdge[154, 455] -> 
             RGBColor[
              0.5215526818181818, 0.6210315454545454, 0.9558720909090909], 
             UndirectedEdge[211, 470] -> 
             RGBColor[
              0.9688907727272726, 0.9748119090909091, 0.8700368181818183], 
             UndirectedEdge[201, 305] -> 
             RGBColor[
              0.9950293636363636, 0.9917766363636363, 0.7003550909090913], 
             UndirectedEdge[220, 474] -> 
             RGBColor[
              0.6314042727272726, 0.7071885454545455, 0.9667308181818182], 
             UndirectedEdge[125, 173] -> 
             RGBColor[
              0.6772916363636363, 0.7394300454545454, 0.852756590909091], 
             UndirectedEdge[189, 443] -> 
             RGBColor[
              0.9099017272727272, 0.9304265454545454, 0.9715613181818181], 
             UndirectedEdge[307, 500] -> 
             RGBColor[
              0.6989581818181817, 0.7618416818181817, 0.9528428636363636], 
             UndirectedEdge[102, 134] -> 
             RGBColor[
              0.9081814545454545, 0.9158237272727272, 0.6916310454545453], 
             UndirectedEdge[102, 174] -> 
             RGBColor[0.9073477727272727, 0.927708, 0.9476691818181818], 
             UndirectedEdge[203, 281] -> 
             RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 
             UndirectedEdge[279, 421] -> 
             RGBColor[
              0.6376888181818181, 0.7145172727272726, 0.9661424545454544], 
             UndirectedEdge[335, 430] -> 
             RGBColor[
              0.9256810454545454, 0.9430085454545454, 0.9730663636363637], 
             UndirectedEdge[69, 431] -> 
             RGBColor[
              0.9821161363636364, 0.9846753636363637, 0.8476497272727272], 
             UndirectedEdge[149, 249] -> 
             RGBColor[
              0.8406546818181817, 0.8760402727272727, 0.9845943181818182], 
             UndirectedEdge[141, 345] -> 
             RGBColor[0.9686357727272727, 0.972527, 0.7158390909090908], 
             UndirectedEdge[12, 283] -> 
             RGBColor[
              0.6954937272727273, 0.7558802727272728, 0.8790750454545453], 
             UndirectedEdge[119, 381] -> 
             RGBColor[
              0.7667585909090909, 0.8134892727272728, 0.7873659545454543], 
             UndirectedEdge[396, 430] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[49, 360] -> 
             RGBColor[
              0.6392455454545455, 0.7165231818181819, 0.9657576363636363], 
             UndirectedEdge[208, 497] -> 
             RGBColor[
              0.9684475454545455, 0.937299181818182, 0.6280845000000002], 
             UndirectedEdge[275, 444] -> 
             RGBColor[
              0.9480730454545454, 0.9605222727272728, 0.9633778636363636], 
             UndirectedEdge[269, 323] -> 
             RGBColor[
              0.9322937272727272, 0.9479402727272728, 0.9618728181818181], 
             UndirectedEdge[273, 279] -> 
             RGBColor[
              0.7406013181818182, 0.7917507272727273, 0.7440897272727274], 
             UndirectedEdge[107, 289] -> 
             RGBColor[
              0.7264322727272725, 0.7857639999999999, 0.9738173636363636], 
             UndirectedEdge[289, 314] -> 
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273], 
             UndirectedEdge[6, 428] -> 
             RGBColor[
              0.9775793181818182, 0.9827992727272727, 0.9228365454545454], 
             UndirectedEdge[7, 17] -> 
             RGBColor[
              0.9592225454545454, 0.967330090909091, 0.8769975000000001], 
             UndirectedEdge[309, 424] -> 
             RGBColor[
              0.9651876363636362, 0.9610515454545454, 0.6891854999999999], 
             UndirectedEdge[128, 385] -> 
             RGBColor[
              0.9118845909090909, 0.9295840909090909, 0.8724823636363637], 
             UndirectedEdge[71, 362] -> 
             RGBColor[
              0.8625523636363637, 0.8800929090909091, 0.6871057272727272], 
             UndirectedEdge[43, 156] -> 
             RGBColor[
              0.8875097272727273, 0.9129128181818182, 0.9812498181818182], 
             UndirectedEdge[59, 298] -> 
             RGBColor[
              0.9032890454545454, 0.9254948181818181, 0.9827548636363637], 
             UndirectedEdge[261, 455] -> 
             RGBColor[
              0.8041437272727273, 0.8086329090909092, 0.6435634545454547], 
             UndirectedEdge[17, 89] -> 
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105], 
             UndirectedEdge[9, 68] -> 
             RGBColor[
              0.4348645909090909, 0.5318865909090909, 0.9516586818181818], 
             UndirectedEdge[73, 298] -> 
             RGBColor[
              0.9189780454545454, 0.9115978181818181, 0.6737791363636363], 
             UndirectedEdge[16, 333] -> 
             RGBColor[0.6650238636363635, 0.7374511818181817, 0.967787], 
             UndirectedEdge[257, 445] -> 
             RGBColor[
              0.6833374090909091, 0.7091294545454547, 0.6344475454545455], 
             UndirectedEdge[428, 451] -> 
             RGBColor[
              0.7293278636363636, 0.7864172727272727, 0.9434209545454545], 
             UndirectedEdge[15, 419] -> 
             RGBColor[
              0.8647432272727272, 0.8932279090909091, 0.893019318181818], 
             UndirectedEdge[17, 313] -> 
             RGBColor[0.8079908181818182, 0.850778090909091, 0.981271], 
             UndirectedEdge[5, 326] -> 
             RGBColor[
              0.7676591363636363, 0.818409818181818, 0.9698667727272727], 
             UndirectedEdge[216, 217] -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             UndirectedEdge[138, 222] -> 
             RGBColor[
              0.8421578636363636, 0.8734568181818182, 0.7525920000000001], 
             UndirectedEdge[251, 447] -> 
             RGBColor[
              0.6774155909090909, 0.7379556818181818, 0.7398057272727274], 
             UndirectedEdge[58, 144] -> 
             RGBColor[
              0.6826772727272726, 0.7494281363636363, 0.9709970909090908], 
             UndirectedEdge[11, 404] -> 
             RGBColor[
              0.8351165454545455, 0.5870346363636363, 0.5846868636363636], 
             UndirectedEdge[270, 329] -> 
             RGBColor[0.8132755, 0.854133, 0.9383155], 
             UndirectedEdge[314, 406] -> 
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273], 
             UndirectedEdge[13, 409] -> 
             RGBColor[
              0.6379069545454545, 0.523560409090909, 0.5821109090909091], 
             UndirectedEdge[279, 335] -> 
             RGBColor[
              0.6906549545454544, 0.7564899999999999, 0.9712636818181818], 
             UndirectedEdge[195, 446] -> 
             RGBColor[
              0.9414603636363637, 0.9555905454545455, 0.974571409090909], 
             UndirectedEdge[22, 170] -> 
             RGBColor[
              0.7293278636363636, 0.7864172727272727, 0.9434209545454545], 
             UndirectedEdge[159, 166] -> 
             RGBColor[
              0.8661022272727272, 0.8961040909090909, 0.9791386818181818], 
             UndirectedEdge[59, 87] -> 
             RGBColor[
              0.9651876363636362, 0.9610515454545454, 0.6891854999999999], 
             UndirectedEdge[176, 407] -> 
             RGBColor[
              0.8904770909090909, 0.9127753636363636, 0.8703712272727273], 
             UndirectedEdge[169, 470] -> 
             RGBColor[
              0.9693936818181818, 0.9741480909090909, 0.798332818181818], 
             UndirectedEdge[13, 188] -> 
             RGBColor[
              0.9350484545454545, 0.7586846818181816, 0.45891036363636384`], 
             UndirectedEdge[273, 396] -> 
             RGBColor[
              0.8421578636363636, 0.8734568181818182, 0.7525920000000001], 
             UndirectedEdge[30, 405] -> 
             RGBColor[0.9686357727272727, 0.972527, 0.7158390909090907], 
             UndirectedEdge[258, 497] -> 
             RGBColor[
              0.8525869090909091, 0.8464770909090911, 0.6483918181818182], 
             UndirectedEdge[90, 485] -> 
             RGBColor[
              0.6471835909090908, 0.7197705454545454, 0.9682358636363636], 
             UndirectedEdge[89, 455] -> 
             RGBColor[
              0.7364312727272728, 0.7941100000000001, 0.9743416818181818], 
             UndirectedEdge[422, 451] -> 
             RGBColor[
              0.6748756363636362, 0.7439079999999999, 0.9697586363636364], 
             UndirectedEdge[99, 178] -> 
             RGBColor[
              0.9651876363636362, 0.9610515454545454, 0.6891854999999999], 
             UndirectedEdge[119, 416] -> 
             RGBColor[
              0.6848746363636364, 0.7522540000000001, 0.9702829545454545], 
             UndirectedEdge[129, 204] -> 
             RGBColor[
              0.5761962272727272, 0.6604553636363636, 0.9627134090909091], 
             UndirectedEdge[1, 381] -> 
             RGBColor[0.9922562727272727, 0.990194, 0.7146276363636361], 
             UndirectedEdge[287, 409] -> 
             RGBColor[
              0.6978878636363637, 0.7566523636363636, 0.8235556363636365], 
             UndirectedEdge[340, 384] -> 
             RGBColor[
              0.9190683636363636, 0.9380768181818182, 0.9842599090909091], 
             UndirectedEdge[233, 379] -> 
             RGBColor[
              0.938906409090909, 0.9528719999999999, 0.9506792727272727], 
             UndirectedEdge[1, 124] -> 
             RGBColor[
              0.9103723181818182, 0.9289587272727273, 0.8975446363636364], 
             UndirectedEdge[134, 309] -> 
             RGBColor[0.9651876363636362, 0.9610515454545454, 0.6891855], 
             UndirectedEdge[1, 380] -> 
             RGBColor[
              0.9806038636363636, 0.9840500000000001, 0.8727119999999999], 
             UndirectedEdge[112, 403] -> 
             RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             UndirectedEdge[214, 268] -> 
             RGBColor[
              0.9887288181818181, 0.9896070909090909, 0.8364561818181817], 
             UndirectedEdge[404, 444] -> 
             RGBColor[0.8824544999999999, 0.6247806363636363, 0.589202], 
             UndirectedEdge[252, 320] -> 
             RGBColor[
              0.9032890454545454, 0.9254948181818181, 0.9827548636363637], 
             UndirectedEdge[173, 419] -> 
             RGBColor[
              0.6757793636363636, 0.7388046818181817, 0.8778188636363635], 
             UndirectedEdge[407, 475] -> 
             RGBColor[
              0.8793275909090909, 0.9059675454545455, 0.9567515909090909], 
             UndirectedEdge[167, 305] -> 
             RGBColor[
              0.8671373636363636, 0.8939999999999999, 0.8374999090909092], 
             UndirectedEdge[407, 482] -> 
             RGBColor[
              0.872714909090909, 0.9010358181818181, 0.9679451363636363], 
             UndirectedEdge[197, 493] -> 
             RGBColor[0.7064342727272727, 0.769072, 0.9727687272727272], 
             UndirectedEdge[235, 300] -> 
             RGBColor[
              0.9589675454545454, 0.9650451818181819, 0.7227997727272726], 
             UndirectedEdge[312, 385] -> 
             RGBColor[
              0.7606528636363636, 0.8130320909090909, 0.9767558636363636], 
             UndirectedEdge[188, 318] -> 
             RGBColor[
              0.7671375454545455, 0.8142998181818182, 0.8286128181818184], 
             UndirectedEdge[71, 153] -> 
             RGBColor[
              0.9239607727272727, 0.9284057272727272, 0.6931360909090909], 
             UndirectedEdge[45, 481] -> 
             RGBColor[
              0.9593465000000001, 0.9658557272727273, 0.7640466363636365], 
             UndirectedEdge[53, 317] -> 
             RGBColor[0.7484935, 0.8024135454545456, 0.9566438636363637], 
             UndirectedEdge[253, 301] -> 
             RGBColor[
              0.8874525454545454, 0.9115246363636363, 0.9204957727272727], 
             UndirectedEdge[442, 447] -> 
             RGBColor[
              0.6244410454545455, 0.534857590909091, 0.5860685909090909], 
             UndirectedEdge[118, 464] -> 
             RGBColor[0.7632311363636364, 0.8129023636363637, 0.9091945], 
             UndirectedEdge[2, 118] -> 
             RGBColor[
              0.9724789090909091, 0.9784929090909091, 0.9089678181818182], 
             UndirectedEdge[332, 454] -> 
             RGBColor[
              0.7264322727272725, 0.7857639999999999, 0.9738173636363636], 
             UndirectedEdge[84, 455] -> 
             RGBColor[
              0.7934374545454546, 0.8393378181818182, 0.9718961363636364], 
             UndirectedEdge[423, 488] -> 
             RGBColor[
              0.6735884999999999, 0.7256696818181817, 0.6719052727272725], 
             UndirectedEdge[5, 231] -> 
             RGBColor[
              0.8921227272727272, 0.6322624545454545, 0.5822413181818182], 
             UndirectedEdge[121, 337] -> 
             RGBColor[
              0.6772916363636363, 0.7394300454545455, 0.852756590909091], 
             UndirectedEdge[23, 360] -> 
             RGBColor[
              0.8551059999999999, 0.8870454545454545, 0.954337409090909], 
             UndirectedEdge[79, 336] -> 
             RGBColor[
              0.9896106818181818, 0.9897538181818182, 0.8059990454545456], 
             UndirectedEdge[237, 371] -> 
             RGBColor[
              0.8025037727272727, 0.4840972727272727, 0.5718455454545455], 
             UndirectedEdge[9, 330] -> 
             RGBColor[
              0.6665805909090909, 0.739457090909091, 0.9674021818181817], 
             UndirectedEdge[76, 111] -> 
             RGBColor[
              0.8374970909090909, 0.8730550909090908, 0.9407296818181818], 
             UndirectedEdge[91, 256] -> 
             RGBColor[
              0.7106529545454545, 0.7731819999999999, 0.9723123181818182], 
             UndirectedEdge[35, 193] -> 
             RGBColor[
              0.6156249545454546, 0.6946065454545455, 0.9652257727272727], 
             UndirectedEdge[43, 267] -> 
             RGBColor[0.8527855454545454, 0.6966388636363635, 0.6005805], 
             UndirectedEdge[261, 448] -> 
             RGBColor[
              0.9455539545454545, 0.9199539090909092, 0.6574322727272728], 
             UndirectedEdge[322, 374] -> 
             RGBColor[0.8079908181818182, 0.850778090909091, 0.981271], 
             UndirectedEdge[76, 130] -> 
             RGBColor[
              0.8176590454545454, 0.8582599090909091, 0.9743103181818182], 
             UndirectedEdge[107, 153] -> 
             RGBColor[
              0.7264322727272725, 0.7857639999999999, 0.9738173636363636], 
             UndirectedEdge[410, 437] -> 
             RGBColor[
              0.6314042727272726, 0.7071885454545455, 0.9667308181818182], 
             UndirectedEdge[11, 164] -> 
             RGBColor[
              0.7106529545454545, 0.7731819999999999, 0.9723123181818182], 
             UndirectedEdge[213, 500] -> 
             RGBColor[
              0.7121835454545453, 0.7717051363636362, 0.9304557727272726], 
             UndirectedEdge[251, 454] -> 
             RGBColor[
              0.7921579545454545, 0.8336067272727272, 0.7481484545454546], 
             UndirectedEdge[111, 483] -> 
             RGBColor[
              0.8617186818181818, 0.8919771818181819, 0.9431438636363636], 
             UndirectedEdge[5, 233] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[69, 372] -> 
             RGBColor[
              0.9108949545454545, 0.605869409090909, 0.4681087727272728], 
             UndirectedEdge[454, 489] -> 
             RGBColor[
              0.7890094545454545, 0.8338303636363635, 0.9112238636363637], 
             UndirectedEdge[289, 493] -> 
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454], 
             UndirectedEdge[74, 268] -> 
             RGBColor[
              0.9673784999999999, 0.9741865454545455, 0.8950990909090908], 
             UndirectedEdge[192, 258] -> 
             RGBColor[
              0.8647432272727272, 0.8932279090909091, 0.893019318181818], 
             UndirectedEdge[68, 368] -> 
             RGBColor[
              0.5683341363636363, 0.6366990454545454, 0.9449590909090909], 
             UndirectedEdge[50, 414] -> 
             RGBColor[
              0.8551059999999999, 0.8870454545454545, 0.954337409090909], 
             UndirectedEdge[358, 441] -> 
             RGBColor[0.9822400909090909, 0.983201, 0.7346988636363638], 
             UndirectedEdge[71, 289] -> 
             RGBColor[
              0.9239607727272727, 0.9284057272727272, 0.6931360909090909], 
             UndirectedEdge[54, 321] -> 
             RGBColor[
              0.9724789090909091, 0.9784929090909091, 0.9089678181818182], 
             UndirectedEdge[75, 408] -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             UndirectedEdge[8, 239] -> 
             RGBColor[
              0.5865992272727272, 0.6477747727272727, 0.7756811818181817], 
             UndirectedEdge[389, 472] -> 
             RGBColor[
              0.9927556363636364, 0.9869133636363637, 0.4528739090909087], 
             UndirectedEdge[178, 475] -> 
             RGBColor[0.978413, 0.970915, 0.6667984090909089], 
             UndirectedEdge[332, 489] -> 
             RGBColor[
              0.9246393636363636, 0.9409153636363636, 0.9241119545454546], 
             UndirectedEdge[28, 406] -> 
             RGBColor[
              0.916514409090909, 0.9353582727272727, 0.9603677727272727], 
             UndirectedEdge[77, 87] -> 
             RGBColor[
              0.9850256818181817, 0.9758467272727273, 0.6556048636363635], 
             UndirectedEdge[274, 300] -> 
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363], 
             UndirectedEdge[330, 333] -> 
             RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             UndirectedEdge[325, 490] -> 
             RGBColor[
              0.6665805909090909, 0.739457090909091, 0.9674021818181817], 
             UndirectedEdge[420, 489] -> 
             RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454546], 
             UndirectedEdge[271, 304] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[166, 387] -> 
             RGBColor[
              0.5942174545454545, 0.6777978181818182, 0.9631146363636363], 
             UndirectedEdge[16, 165] -> 
             RGBColor[0.6650238636363635, 0.7374511818181817, 0.967787], 
             UndirectedEdge[44, 356] -> 
             RGBColor[
              0.9592225454545454, 0.967330090909091, 0.8769975000000001], 
             UndirectedEdge[86, 377] -> 
             RGBColor[
              0.9326543181818181, 0.7579125909090908, 0.5144297727272726], 
             UndirectedEdge[113, 353] -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             UndirectedEdge[63, 222] -> 
             RGBColor[
              0.8663794545454546, 0.8923789090909091, 0.7550061818181819], 
             UndirectedEdge[71, 493] -> 
             RGBColor[
              0.9555194090909092, 0.9535697272727273, 0.6961461818181818], 
             UndirectedEdge[106, 270] -> 
             RGBColor[0.7522105909090908, 0.806692, 0.9758467272727273], 
             UndirectedEdge[414, 498] -> 
             RGBColor[
              0.9053480909090909, 0.642125909090909, 0.5598542272727272], 
             UndirectedEdge[46, 220] -> 
             RGBColor[
              0.6924691818181818, 0.7546295454545455, 0.9291995909090909], 
             UndirectedEdge[302, 443] -> 
             RGBColor[
              0.9226528636363637, 0.7751711818181819, 0.5921552727272728], 
             UndirectedEdge[90, 267] -> 
             RGBColor[
              0.8843441818181818, 0.7218028636363635, 0.6035905909090908], 
             UndirectedEdge[116, 187] -> 
             RGBColor[
              0.8913589545454546, 0.9129220909090909, 0.8399140909090911], 
             UndirectedEdge[162, 472] -> 
             RGBColor[
              0.8175573181818182, 0.8537241818181819, 0.7089309545454543], 
             UndirectedEdge[271, 371] -> 
             RGBColor[
              0.872714909090909, 0.9010358181818181, 0.9679451363636363], 
             UndirectedEdge[84, 478] -> 
             RGBColor[
              0.9688907727272726, 0.9748119090909091, 0.8700368181818183], 
             UndirectedEdge[5, 163] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[188, 430] -> 
             RGBColor[
              0.9763853181818182, 0.9798903636363636, 0.8283861363636366], 
             UndirectedEdge[380, 487] -> 
             RGBColor[0.6858565, 0.7496978181818181, 0.9403931363636363], 
             UndirectedEdge[88, 304] -> 
             RGBColor[
              0.9718003181818182, 0.9659832727272727, 0.6779919545454545], 
             UndirectedEdge[41, 494] -> 
             RGBColor[
              0.8164330909090909, 0.8571181818181818, 0.9821801363636363], 
             UndirectedEdge[23, 136] -> 
             RGBColor[
              0.9167686363636363, 0.7233573636363635, 0.5705339999999999], 
             UndirectedEdge[7, 84] -> 
             RGBColor[
              0.9688907727272726, 0.9748119090909091, 0.8700368181818183], 
             UndirectedEdge[218, 493] -> 
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181], 
             UndirectedEdge[40, 183] -> 
             RGBColor[
              0.3848646818181817, 0.4920364999999999, 0.9472151363636363], 
             UndirectedEdge[192, 453] -> 
             RGBColor[0.9922562727272727, 0.990194, 0.7146276363636361], 
             UndirectedEdge[49, 397] -> 
             RGBColor[
              0.7667585909090909, 0.8134892727272728, 0.7873659545454543], 
             UndirectedEdge[291, 467] -> 
             RGBColor[
              0.9884738181818182, 0.9873221818181819, 0.6822584545454543], 
             UndirectedEdge[347, 462] -> 
             RGBColor[
              0.6150239545454546, 0.697601090909091, 0.9633434545454544], 
             UndirectedEdge[31, 226] -> 
             RGBColor[
              0.6007743636363636, 0.6657944090909091, 0.8985178636363637], 
             UndirectedEdge[120, 381] -> 
             RGBColor[0.990744, 0.9895686363636363, 0.7396899090909089], 
             UndirectedEdge[151, 274] -> 
             RGBColor[
              0.9505366818181819, 0.9367618181818183, 0.6767892272727272], 
             UndirectedEdge[316, 418] -> 
             RGBColor[
              0.5892456363636362, 0.6766730909090908, 0.9613140909090909], 
             UndirectedEdge[235, 389] -> 
             RGBColor[
              0.9927556363636364, 0.9869133636363637, 0.4528739090909087], 
             UndirectedEdge[218, 310] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[408, 463] -> 
             RGBColor[
              0.9688907727272726, 0.9748119090909091, 0.8700368181818183], 
             UndirectedEdge[12, 273] -> 
             RGBColor[
              0.9918773181818181, 0.9893834545454546, 0.6733807727272728], 
             UndirectedEdge[121, 454] -> 
             RGBColor[
              0.4760599999999998, 0.5830279545454544, 0.9525865454545455], 
             UndirectedEdge[47, 228] -> 
             RGBColor[
              0.8137090454545454, 0.570225909090909, 0.5825757272727272], 
             UndirectedEdge[438, 439] -> 
             RGBColor[
              0.8484933181818182, 0.8821137272727273, 0.9655309545454545], 
             UndirectedEdge[172, 201] -> 
             RGBColor[
              0.9763853181818182, 0.9798903636363636, 0.8283861363636366], 
             UndirectedEdge[58, 375] -> 
             RGBColor[
              0.6455549545454544, 0.474096090909091, 0.5728385454545455], 
             UndirectedEdge[168, 280] -> 
             RGBColor[
              0.7413592272727272, 0.7933718181818181, 0.8265834545454547], 
             UndirectedEdge[77, 301] -> 
             RGBColor[
              0.8859402727272727, 0.9108992727272727, 0.9455580454545454], 
             UndirectedEdge[283, 477] -> 
             RGBColor[
              0.5457742727272727, 0.6399536363636363, 0.9582862727272727], 
             UndirectedEdge[125, 149] -> 
             RGBColor[
              0.8904770909090909, 0.9127753636363636, 0.8703712272727273], 
             UndirectedEdge[7, 407] -> 
             RGBColor[
              0.8904770909090909, 0.9127753636363636, 0.8703712272727273], 
             UndirectedEdge[401, 437] -> 
             RGBColor[0.697006, 0.7565056363636364, 0.8540127727272728], 
             UndirectedEdge[138, 438] -> 
             RGBColor[
              0.8242717272727272, 0.8631916363636363, 0.9631167727272727], 
             UndirectedEdge[45, 399] -> 
             RGBColor[
              0.9933895909090908, 0.9900088181818183, 0.6483185000000002], 
             UndirectedEdge[97, 317] -> 
             RGBColor[
              0.4502816818181818, 0.5620999545454546, 0.9505571818181817], 
             UndirectedEdge[71, 201] -> 
             RGBColor[
              0.9904443636363636, 0.9778695454545454, 0.5499609090909092], 
             UndirectedEdge[107, 236] -> 
             RGBColor[
              0.7905217272727272, 0.8344557272727272, 0.8861615909090907], 
             UndirectedEdge[134, 225] -> 
             RGBColor[
              0.9718003181818182, 0.9659832727272727, 0.6779919545454545], 
             UndirectedEdge[59, 91] -> 
             RGBColor[
              0.7676591363636363, 0.818409818181818, 0.9698667727272727], 
             UndirectedEdge[161, 287] -> 
             RGBColor[
              0.9854616363636364, 0.9610616363636364, 0.5306039545454546], 
             UndirectedEdge[101, 486] -> 
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181], 
             UndirectedEdge[185, 330] -> 
             RGBColor[0.7837692272727272, 0.831856, 0.9788568181818181], 
             UndirectedEdge[237, 432] -> 
             RGBColor[
              0.8966064545454546, 0.5322368181818182, 0.262535409090909], 
             UndirectedEdge[99, 143] -> 
             RGBColor[
              0.9643539545454545, 0.9729358181818182, 0.9452236363636364], 
             UndirectedEdge[107, 411] -> 
             RGBColor[
              0.7833481363636363, 0.8045128181818181, 0.6608910454545454], 
             UndirectedEdge[187, 407] -> 
             RGBColor[
              0.8913589545454546, 0.9129220909090909, 0.8399140909090911], 
             UndirectedEdge[185, 357] -> 
             RGBColor[
              0.9094001363636364, 0.9305950000000001, 0.9912205909090909], 
             UndirectedEdge[80, 208] -> 
             RGBColor[0.6858565, 0.7496978181818181, 0.9403931363636363], 
             UndirectedEdge[60, 240] -> 
             RGBColor[
              0.7660006818181819, 0.8118681818181819, 0.704872227272727], 
             UndirectedEdge[262, 299] -> 
             RGBColor[
              0.9155152727272726, 0.6943538636363635, 0.25044531818181814`], 
             UndirectedEdge[82, 282] -> 
             RGBColor[
              0.6274692272727271, 0.7026949545454545, 0.9669796818181817], 
             UndirectedEdge[286, 368] -> 
             RGBColor[
              0.9755034545454545, 0.9797436363636364, 0.8588432727272728], 
             UndirectedEdge[81, 454] -> 
             RGBColor[
              0.7929158636363636, 0.835227818181818, 0.830642181818182], 
             UndirectedEdge[68, 352] -> 
             RGBColor[
              0.5845840454545455, 0.6478132272727273, 0.8724474545454545], 
             UndirectedEdge[196, 337] -> 
             RGBColor[
              0.842033909090909, 0.8749311818181817, 0.8655428636363637], 
             UndirectedEdge[261, 262] -> 
             RGBColor[0.920498, 0.7111617727272728, 0.26980227272727286`], 
             UndirectedEdge[122, 286] -> 
             RGBColor[
              0.8178123181818182, 0.8560090909090909, 0.8631286818181818]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             316 -> RGBColor[
              0.4876890909090908, 0.5949669999999999, 0.9528118181818181], 
             308 -> RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             160 -> RGBColor[
              0.9858593636363636, 0.9639624545454545, 0.3995667272727271], 
             245 -> RGBColor[
              0.9942714545454545, 0.9901555454545454, 0.6178613636363632], 
             155 -> RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             425 -> RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             213 -> RGBColor[0.984192, 0.987731, 0.911643], 352 -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909089], 27 -> 
             RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 485 -> 
             RGBColor[
              0.4007463636363636, 0.5215280909090909, 0.9467561818181818], 
             454 -> RGBColor[
              0.5908023636363634, 0.6786789999999998, 0.9609292727272727], 
             367 -> RGBColor[0.955963, 0.863115, 0.283425], 19 -> 
             RGBColor[
              0.7876885454545454, 0.8340675454545454, 0.9794730909090908], 
             164 -> RGBColor[
              0.5908023636363634, 0.6786789999999998, 0.9609292727272727], 
             190 -> 
             RGBColor[
              0.9927556363636364, 0.9869133636363637, 0.4528739090909087], 
             103 -> RGBColor[
              0.9858593636363636, 0.9639624545454545, 0.3995667272727271], 
             138 -> RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             416 -> RGBColor[
              0.8305035454545455, 0.867685, 0.9836953636363637], 476 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 291 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 28 -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             337 -> RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             195 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             114 -> RGBColor[0.984192, 0.987731, 0.911643], 479 -> 
             RGBColor[0.8305035454545455, 0.867685, 0.9836953636363637], 93 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 34 -> 
             RGBColor[
              0.5392457272727273, 0.6368230000000001, 0.9568705454545454], 
             161 -> RGBColor[
              0.9758939090909091, 0.9303466363636363, 0.360852818181818], 22 -> 
             RGBColor[
              0.4876890909090908, 0.5949669999999999, 0.9528118181818181], 
             124 -> RGBColor[
              0.8305035454545455, 0.867685, 0.9836953636363637], 84 -> 
             RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 46 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 241 -> 
             RGBColor[
              0.36131763636363623`, 0.48737690909090897`, 0.9442438181818181],
              185 -> RGBColor[
              0.9251794545454546, 0.943177, 0.9927256363636363], 426 -> 
             RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 
             390 -> RGBColor[
              0.9950293636363636, 0.9917766363636363, 0.7003550909090913], 
             121 -> RGBColor[
              0.36131763636363623`, 0.48737690909090897`, 0.9442438181818181],
              322 -> RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             488 -> RGBColor[
              0.36131763636363623`, 0.48737690909090897`, 0.9442438181818181],
              126 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             433 -> RGBColor[
              0.9758939090909091, 0.9303466363636363, 0.360852818181818], 236 -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909089], 78 -> 
             RGBColor[
              0.9942714545454545, 0.9901555454545454, 0.6178613636363632], 
             376 -> RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             458 -> RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             254 -> RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             290 -> RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 
             251 -> RGBColor[
              0.9935135454545455, 0.9885344545454546, 0.5353676363636367], 
             165 -> RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 
             460 -> RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909089], 
             100 -> RGBColor[
              0.9942714545454545, 0.9901555454545454, 0.6178613636363632], 
             235 -> RGBColor[
              0.9927556363636364, 0.9869133636363637, 0.4528739090909087], 70 -> 
             RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 234 -> 
             RGBColor[0.955963, 0.863115, 0.283425], 435 -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             257 -> RGBColor[
              0.9659284545454546, 0.8967308181818184, 0.32213890909090936`], 
             135 -> RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             265 -> RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             111 -> RGBColor[0.984192, 0.987731, 0.911643], 497 -> 
             RGBColor[
              0.9659284545454546, 0.8967308181818184, 0.32213890909090936`], 
             481 -> RGBColor[
              0.9251794545454546, 0.943177, 0.9927256363636363], 381 -> 
             RGBColor[
              0.9942714545454545, 0.9901555454545454, 0.6178613636363632], 
             182 -> RGBColor[
              0.8305035454545455, 0.867685, 0.9836953636363637], 188 -> 
             RGBColor[
              0.9950293636363636, 0.9917766363636363, 0.7003550909090913], 
             154 -> RGBColor[
              0.4007463636363636, 0.5215280909090909, 0.9467561818181818], 
             336 -> RGBColor[0.984192, 0.987731, 0.911643], 463 -> 
             RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 315 -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             368 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             269 -> RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             208 -> RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 86 -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909089], 
             119 -> RGBColor[
              0.5392457272727273, 0.6368230000000001, 0.9568705454545454], 
             436 -> RGBColor[0.955963, 0.863115, 0.283425], 377 -> 
             RGBColor[
              0.8750675454545453, 0.525592727272727, 0.2174656363636363], 140 -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 85 -> 
             RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             351 -> RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454546], 
             443 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             242 -> RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             117 -> RGBColor[
              0.4007463636363636, 0.5215280909090909, 0.9467561818181818], 47 -> 
             RGBColor[
              0.7876885454545454, 0.8340675454545454, 0.9794730909090908], 
             451 -> RGBColor[
              0.4876890909090908, 0.5949669999999999, 0.9528118181818181], 81 -> 
             RGBColor[
              0.9950293636363636, 0.9917766363636363, 0.7003550909090913], 
             275 -> RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 23 -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             328 -> RGBColor[
              0.9927556363636364, 0.9869133636363637, 0.4528739090909087], 
             418 -> RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             110 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 6 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 218 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 108 -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             297 -> RGBColor[
              0.9950293636363636, 0.9917766363636363, 0.7003550909090913], 
             487 -> 
             RGBColor[
              0.4007463636363636, 0.5215280909090909, 0.9467561818181818], 
             464 -> RGBColor[
              0.5392457272727273, 0.6368230000000001, 0.9568705454545454], 
             157 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             441 -> RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             354 -> RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 385 -> 
             RGBColor[0.8305035454545455, 0.867685, 0.9836953636363637], 270 -> 
             RGBColor[0.642359, 0.720535, 0.964988], 392 -> 
             RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 33 -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             252 -> RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 394 -> 
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363], 260 -> 
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363], 159 -> 
             RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 183 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 99 -> 
             RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 329 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 309 -> 
             RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 17 -> 
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363], 349 -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             495 -> RGBColor[
              0.9251794545454546, 0.943177, 0.9927256363636363], 347 -> 
             RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             340 -> RGBColor[
              0.8936208181818182, 0.918013, 0.9897155454545454], 404 -> 
             RGBColor[
              0.8397295454545454, 0.30638427272727253`, 0.1856783636363636], 
             277 -> RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 104 -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 79 -> 
             RGBColor[
              0.9950293636363636, 0.9917766363636363, 0.7003550909090913], 
             327 -> RGBColor[0.984192, 0.987731, 0.911643], 191 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 50 -> 
             RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 
             225 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             405 -> RGBColor[
              0.9927556363636364, 0.9869133636363637, 0.4528739090909087], 61 -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             196 -> RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 1 -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909089], 
             263 -> RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             201 -> RGBColor[
              0.9950293636363636, 0.9917766363636363, 0.7003550909090913], 
             371 -> RGBColor[
              0.7876885454545454, 0.8340675454545454, 0.9794730909090908], 
             293 -> RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             362 -> RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 
             184 -> RGBColor[
              0.9251794545454546, 0.943177, 0.9927256363636363], 106 -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             206 -> RGBColor[
              0.5908023636363634, 0.6786789999999998, 0.9609292727272727], 
             358 -> RGBColor[
              0.9935135454545455, 0.9885344545454546, 0.5353676363636367], 
             247 -> RGBColor[
              0.36131763636363623`, 0.48737690909090897`, 0.9442438181818181],
              220 -> RGBColor[
              0.4007463636363636, 0.5215280909090909, 0.9467561818181818], 
             407 -> RGBColor[
              0.7876885454545454, 0.8340675454545454, 0.9794730909090908], 
             107 -> RGBColor[
              0.5908023636363634, 0.6786789999999998, 0.9609292727272727], 
             375 -> RGBColor[
              0.8509348181818183, 0.3925129090909096, 0.1964085454545455], 
             131 -> RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 411 -> 
             RGBColor[
              0.9758939090909091, 0.9303466363636363, 0.360852818181818], 462 -> 
             RGBColor[
              0.5392457272727273, 0.6368230000000001, 0.9568705454545454], 
             127 -> RGBColor[
              0.36131763636363623`, 0.48737690909090897`, 0.9442438181818181],
              210 -> 
             RGBColor[
              0.5392457272727273, 0.6368230000000001, 0.9568705454545454], 
             357 -> RGBColor[
              0.8936208181818182, 0.918013, 0.9897155454545454], 181 -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             194 -> RGBColor[
              0.9251794545454546, 0.943177, 0.9927256363636363], 440 -> 
             RGBColor[
              0.4876890909090908, 0.5949669999999999, 0.9528118181818181], 
             490 -> RGBColor[0.642359, 0.720535, 0.964988], 118 -> 
             RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454546], 
             348 -> RGBColor[
              0.9927556363636364, 0.9869133636363637, 0.4528739090909087], 
             276 -> RGBColor[
              0.2851425454545455, 0.41703327272727275`, 0.9395498181818182], 
             305 -> RGBColor[
              0.9950293636363636, 0.9917766363636363, 0.7003550909090913], 
             343 -> RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             280 -> RGBColor[
              0.4876890909090908, 0.5949669999999999, 0.9528118181818181], 
             474 -> RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             189 -> RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             168 -> RGBColor[
              0.9950293636363636, 0.9917766363636363, 0.7003550909090913], 
             363 -> RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 41 -> 
             RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 14 -> 
             RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 77 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 51 -> 
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363], 438 -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             179 -> RGBColor[
              0.36131763636363623`, 0.48737690909090897`, 0.9442438181818181],
              467 -> RGBColor[
              0.9927556363636364, 0.9869133636363637, 0.4528739090909087], 
             223 -> RGBColor[
              0.7876885454545454, 0.8340675454545454, 0.9794730909090908], 
             456 -> RGBColor[
              0.9935135454545455, 0.9885344545454546, 0.5353676363636367], 
             323 -> RGBColor[
              0.8936208181818182, 0.918013, 0.9897155454545454], 500 -> 
             RGBColor[
              0.4401750909090907, 0.5556792727272725, 0.9492685454545454], 
             478 -> RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             292 -> RGBColor[
              0.8305035454545455, 0.867685, 0.9836953636363637], 491 -> 
             RGBColor[
              0.9136335454545453, 0.6952928181818179, 0.2493657272727272], 
             396 -> RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             321 -> RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454546], 
             143 -> RGBColor[0.984192, 0.987731, 0.911643], 112 -> 
             RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             197 -> RGBColor[
              0.4876890909090908, 0.5949669999999999, 0.9528118181818181], 
             421 -> RGBColor[
              0.7876885454545454, 0.8340675454545454, 0.9794730909090908], 54 -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 71 -> 
             RGBColor[
              0.9858593636363636, 0.9639624545454545, 0.3995667272727271], 
             177 -> RGBColor[
              0.7876885454545454, 0.8340675454545454, 0.9794730909090908], 
             158 -> RGBColor[
              0.8936208181818182, 0.918013, 0.9897155454545454], 226 -> 
             RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454546], 
             432 -> RGBColor[
              0.9758939090909091, 0.9303466363636363, 0.360852818181818], 350 -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             203 -> RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 475 -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             115 -> RGBColor[0.642359, 0.720535, 0.964988], 173 -> 
             RGBColor[
              0.36131763636363623`, 0.48737690909090897`, 0.9442438181818181],
              212 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             129 -> RGBColor[
              0.321888909090909, 0.45322572727272714`, 0.9417314545454546], 
             279 -> RGBColor[
              0.4876890909090908, 0.5949669999999999, 0.9528118181818181], 26 -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909089], 40 -> 
             RGBColor[
              0.5908023636363634, 0.6786789999999998, 0.9609292727272727], 
             146 -> RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454546], 
             386 -> RGBColor[0.984192, 0.987731, 0.911643], 192 -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909089], 
             300 -> RGBColor[
              0.9251794545454546, 0.943177, 0.9927256363636363], 221 -> 
             RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 62 -> 
             RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             286 -> RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             472 -> RGBColor[
              0.9927556363636364, 0.9869133636363637, 0.4528739090909087], 
             152 -> RGBColor[
              0.9942714545454545, 0.9901555454545454, 0.6178613636363632], 64 -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             307 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 37 -> 
             RGBColor[
              0.9935135454545455, 0.9885344545454546, 0.5353676363636367], 
             148 -> RGBColor[
              0.7876885454545454, 0.8340675454545454, 0.9794730909090908], 
             261 -> RGBColor[
              0.9659284545454546, 0.8967308181818184, 0.32213890909090936`], 
             387 -> RGBColor[
              0.4007463636363636, 0.5215280909090909, 0.9467561818181818], 15 -> 
             RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 
             136 -> RGBColor[
              0.8625706363636363, 0.4688471818181815, 0.20703790909090902`], 
             198 -> RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 63 -> 
             RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 
             444 -> RGBColor[
              0.9251794545454546, 0.943177, 0.9927256363636363], 310 -> 
             RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 171 -> 
             RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454546], 
             395 -> RGBColor[0.178927, 0.305394, 0.933501], 311 -> 
             RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 353 -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 59 -> 
             RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 397 -> 
             RGBColor[
              0.9942714545454545, 0.9901555454545454, 0.6178613636363632], 
             229 -> RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909089], 
             102 -> RGBColor[
              0.8305035454545455, 0.867685, 0.9836953636363637], 453 -> 
             RGBColor[
              0.9942714545454545, 0.9901555454545454, 0.6178613636363632], 
             299 -> RGBColor[0.955963, 0.863115, 0.283425], 128 -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 12 -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909089], 
             222 -> RGBColor[
              0.9935135454545455, 0.9885344545454546, 0.5353676363636367], 
             483 -> RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 92 -> 
             RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454546], 
             271 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             361 -> RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             344 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             132 -> RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 80 -> 
             RGBColor[
              0.4007463636363636, 0.5215280909090909, 0.9467561818181818], 
             324 -> RGBColor[
              0.9935135454545455, 0.9885344545454546, 0.5353676363636367], 
             244 -> RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454546], 
             150 -> RGBColor[
              0.9950293636363636, 0.9917766363636363, 0.7003550909090913], 
             125 -> RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             258 -> RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 
             133 -> RGBColor[
              0.9935135454545455, 0.9885344545454546, 0.5353676363636367], 
             469 -> RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             255 -> RGBColor[
              0.9758939090909091, 0.9303466363636363, 0.360852818181818], 408 -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             326 -> RGBColor[
              0.5908023636363634, 0.6786789999999998, 0.9609292727272727], 
             176 -> RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             230 -> RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909089], 
             274 -> RGBColor[
              0.9251794545454546, 0.943177, 0.9927256363636363], 87 -> 
             RGBColor[
              0.9858593636363636, 0.9639624545454545, 0.3995667272727271], 
             439 -> RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 
             130 -> RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 35 -> 
             RGBColor[
              0.4007463636363636, 0.5215280909090909, 0.9467561818181818], 
             379 -> RGBColor[
              0.8936208181818182, 0.918013, 0.9897155454545454], 31 -> 
             RGBColor[
              0.2143321818181818, 0.34260709090909086`, 0.9355172727272727], 
             18 -> RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909089], 24 -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             151 -> RGBColor[
              0.9758939090909091, 0.9303466363636363, 0.360852818181818], 137 -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             330 -> RGBColor[0.642359, 0.720535, 0.964988], 296 -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             266 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             302 -> RGBColor[
              0.8875644545454546, 0.582338272727273, 0.2278933636363637], 442 -> 
             RGBColor[
              0.8875644545454546, 0.582338272727273, 0.2278933636363637], 283 -> 
             RGBColor[
              0.4007463636363636, 0.5215280909090909, 0.9467561818181818], 
             388 -> RGBColor[
              0.36131763636363623`, 0.48737690909090897`, 0.9442438181818181],
              284 -> RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             417 -> RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 318 -> 
             RGBColor[
              0.5392457272727273, 0.6368230000000001, 0.9568705454545454], 
             413 -> 
             RGBColor[
              0.36131763636363623`, 0.48737690909090897`, 0.9442438181818181],
              238 -> RGBColor[
              0.9950293636363636, 0.9917766363636363, 0.7003550909090913], 72 -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             437 -> RGBColor[
              0.4007463636363636, 0.5215280909090909, 0.9467561818181818], 
             288 -> RGBColor[
              0.8305035454545455, 0.867685, 0.9836953636363637], 382 -> 
             RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 461 -> 
             RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454546], 
             389 -> RGBColor[
              0.9927556363636364, 0.9869133636363637, 0.4528739090909087], 
             172 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             447 -> RGBColor[
              0.36131763636363623`, 0.48737690909090897`, 0.9442438181818181],
              243 -> RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 410 -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 88 -> 
             RGBColor[
              0.9858593636363636, 0.9639624545454545, 0.3995667272727271], 
             273 -> RGBColor[
              0.9935135454545455, 0.9885344545454546, 0.5353676363636367], 
             477 -> RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             202 -> RGBColor[
              0.9950293636363636, 0.9917766363636363, 0.7003550909090913], 
             393 -> RGBColor[
              0.9950293636363636, 0.9917766363636363, 0.7003550909090913], 98 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 30 -> 
             RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 116 -> 
             RGBColor[
              0.7876885454545454, 0.8340675454545454, 0.9794730909090908], 
             373 -> RGBColor[0.984192, 0.987731, 0.911643], 434 -> 
             RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 
             401 -> RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             240 -> RGBColor[
              0.9927556363636364, 0.9869133636363637, 0.4528739090909087], 
             480 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             403 -> 
             RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             317 -> RGBColor[
              0.5392457272727273, 0.6368230000000001, 0.9568705454545454], 
             429 -> RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             391 -> RGBColor[
              0.9000613636363637, 0.6390838181818185, 0.23832109090909098`], 
             73 -> RGBColor[
              0.9758939090909091, 0.9303466363636363, 0.360852818181818], 303 -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             449 -> RGBColor[
              0.8936208181818182, 0.918013, 0.9897155454545454], 29 -> 
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363], 360 -> 
             RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 
             320 -> RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             482 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 75 -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             200 -> RGBColor[0.984192, 0.987731, 0.911643], 301 -> 
             RGBColor[
              0.7876885454545454, 0.8340675454545454, 0.9794730909090908], 
             156 -> RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 25 -> 
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454], 38 -> 
             RGBColor[
              0.36131763636363623`, 0.48737690909090897`, 0.9442438181818181],
              365 -> RGBColor[0.955963, 0.863115, 0.283425], 380 -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             370 -> RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 3 -> 
             RGBColor[
              0.9758939090909091, 0.9303466363636363, 0.360852818181818], 57 -> 
             RGBColor[
              0.4876890909090908, 0.5949669999999999, 0.9528118181818181], 
             227 -> RGBColor[0.984192, 0.987731, 0.911643], 494 -> 
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454], 39 -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909089], 
             424 -> RGBColor[
              0.9858593636363636, 0.9639624545454545, 0.3995667272727271], 
             109 -> 
             RGBColor[
              0.8750675454545453, 0.525592727272727, 0.2174656363636363], 465 -> 
             RGBColor[
              0.9942714545454545, 0.9901555454545454, 0.6178613636363632], 
             256 -> RGBColor[
              0.8305035454545455, 0.867685, 0.9836953636363637], 457 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 339 -> 
             RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 420 -> 
             RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454546], 
             287 -> RGBColor[
              0.9950293636363636, 0.9917766363636363, 0.7003550909090913], 
             239 -> RGBColor[
              0.9942714545454545, 0.9901555454545454, 0.6178613636363632], 
             427 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             285 -> RGBColor[
              0.7876885454545454, 0.8340675454545454, 0.9794730909090908], 
             345 -> RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 366 -> 
             RGBColor[
              0.7876885454545454, 0.8340675454545454, 0.9794730909090908], 
             216 -> RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 21 -> 
             RGBColor[
              0.7876885454545454, 0.8340675454545454, 0.9794730909090908], 
             355 -> RGBColor[
              0.5392457272727273, 0.6368230000000001, 0.9568705454545454], 
             175 -> RGBColor[
              0.4007463636363636, 0.5215280909090909, 0.9467561818181818], 7 -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 13 -> 
             RGBColor[
              0.8750675454545453, 0.525592727272727, 0.2174656363636363], 294 -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             412 -> RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 193 -> 
             RGBColor[0.8305035454545455, 0.867685, 0.9836953636363637], 60 -> 
             RGBColor[
              0.5392457272727273, 0.6368230000000001, 0.9568705454545454], 65 -> 
             RGBColor[
              0.9950293636363636, 0.9917766363636363, 0.7003550909090913], 
             448 -> RGBColor[
              0.9251794545454546, 0.943177, 0.9927256363636363], 69 -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             217 -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             214 -> RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454546], 
             170 -> RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             359 -> RGBColor[
              0.4876890909090908, 0.5949669999999999, 0.9528118181818181], 74 -> 
             RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 246 -> 
             RGBColor[
              0.9942714545454545, 0.9901555454545454, 0.6178613636363632], 
             264 -> RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             278 -> RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 45 -> 
             RGBColor[
              0.9935135454545455, 0.9885344545454546, 0.5353676363636367], 
             492 -> RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 
             306 -> RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454546], 
             237 -> RGBColor[0.817319, 0.134127, 0.164218], 228 -> 
             RGBColor[
              0.8397295454545454, 0.30638427272727253`, 0.1856783636363636], 
             180 -> RGBColor[0.642359, 0.720535, 0.964988], 383 -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 53 -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             304 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 48 -> 
             RGBColor[
              0.5908023636363634, 0.6786789999999998, 0.9609292727272727], 5 -> 
             RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 101 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 333 -> 
             RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 
             267 -> RGBColor[
              0.8750675454545453, 0.525592727272727, 0.2174656363636363], 120 -> 
             RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454546], 
             147 -> RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454546], 89 -> 
             RGBColor[0.8305035454545455, 0.867685, 0.9836953636363637], 43 -> 
             RGBColor[0.8305035454545455, 0.867685, 0.9836953636363637], 199 -> 
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363], 268 -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909089], 
             169 -> RGBColor[
              0.9942714545454545, 0.9901555454545454, 0.6178613636363632], 20 -> 
             RGBColor[0.642359, 0.720535, 0.964988], 4 -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             167 -> RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 
             431 -> RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             142 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 16 -> 
             RGBColor[
              0.5908023636363634, 0.6786789999999998, 0.9609292727272727], 
             414 -> RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             281 -> RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 289 -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             398 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             178 -> RGBColor[
              0.9858593636363636, 0.9639624545454545, 0.3995667272727271], 58 -> 
             RGBColor[
              0.4401750909090907, 0.5556792727272725, 0.9492685454545454], 
             186 -> RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             122 -> RGBColor[0.642359, 0.720535, 0.964988], 249 -> 
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454], 113 -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 52 -> 
             RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454546], 
             409 -> RGBColor[
              0.4007463636363636, 0.5215280909090909, 0.9467561818181818], 
             187 -> RGBColor[
              0.9950293636363636, 0.9917766363636363, 0.7003550909090913], 
             259 -> RGBColor[0.984192, 0.987731, 0.911643], 42 -> 
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454], 134 -> 
             RGBColor[
              0.9858593636363636, 0.9639624545454545, 0.3995667272727271], 
             470 -> RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 313 -> 
             RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             248 -> RGBColor[
              0.7876885454545454, 0.8340675454545454, 0.9794730909090908], 
             174 -> RGBColor[0.984192, 0.987731, 0.911643], 215 -> 
             RGBColor[
              0.5908023636363634, 0.6786789999999998, 0.9609292727272727], 
             399 -> RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             422 -> RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 83 -> 
             RGBColor[0.8305035454545455, 0.867685, 0.9836953636363637], 95 -> 
             RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454546], 
             166 -> RGBColor[
              0.7876885454545454, 0.8340675454545454, 0.9794730909090908], 
             384 -> RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 233 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 295 -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             499 -> RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             141 -> RGBColor[
              0.9927556363636364, 0.9869133636363637, 0.4528739090909087], 
             319 -> RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             205 -> RGBColor[
              0.9251794545454546, 0.943177, 0.9927256363636363], 468 -> 
             RGBColor[
              0.4876890909090908, 0.5949669999999999, 0.9528118181818181], 
             486 -> RGBColor[
              0.9251794545454546, 0.943177, 0.9927256363636363], 224 -> 
             RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             231 -> RGBColor[
              0.8397295454545454, 0.30638427272727253`, 0.1856783636363636], 
             332 -> RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 68 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 484 -> 
             RGBColor[
              0.9927556363636364, 0.9869133636363637, 0.4528739090909087], 10 -> 
             RGBColor[
              0.9942714545454545, 0.9901555454545454, 0.6178613636363632], 
             250 -> RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             282 -> RGBColor[
              0.8936208181818182, 0.918013, 0.9897155454545454], 374 -> 
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363], 232 -> 
             RGBColor[
              0.9858593636363636, 0.9639624545454545, 0.3995667272727271], 
             489 -> RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454546], 
             253 -> RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454546], 
             459 -> RGBColor[
              0.9950293636363636, 0.9917766363636363, 0.7003550909090913], 
             415 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 55 -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             446 -> RGBColor[
              0.9251794545454546, 0.943177, 0.9927256363636363], 325 -> 
             RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 91 -> 
             RGBColor[
              0.5908023636363634, 0.6786789999999998, 0.9609292727272727], 
             450 -> RGBColor[
              0.5908023636363634, 0.6786789999999998, 0.9609292727272727], 
             423 -> RGBColor[
              0.9858593636363636, 0.9639624545454545, 0.3995667272727271], 
             105 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 36 -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             123 -> RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 94 -> 
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454], 473 -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             312 -> RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 96 -> 
             RGBColor[
              0.944515909090909, 0.9581406363636363, 0.9788042727272728], 496 -> 
             RGBColor[
              0.4876890909090908, 0.5949669999999999, 0.9528118181818181], 2 -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             262 -> RGBColor[
              0.8750675454545453, 0.525592727272727, 0.2174656363636363], 272 -> 
             RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454546], 97 -> 
             RGBColor[
              0.36131763636363623`, 0.48737690909090897`, 0.9442438181818181],
              372 -> RGBColor[
              0.8285242727272727, 0.22025563636363626`, 0.1749481818181818], 
             356 -> 
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363], 402 -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             455 -> RGBColor[0.642359, 0.720535, 0.964988], 428 -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             346 -> RGBColor[
              0.7876885454545454, 0.8340675454545454, 0.9794730909090908], 
             341 -> RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454546], 
             209 -> RGBColor[
              0.8305035454545455, 0.867685, 0.9836953636363637], 498 -> 
             RGBColor[
              0.8397295454545454, 0.30638427272727253`, 0.1856783636363636], 
             378 -> RGBColor[
              0.8936208181818182, 0.918013, 0.9897155454545454], 419 -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909089], 66 -> 
             RGBColor[0.642359, 0.720535, 0.964988], 139 -> 
             RGBColor[
              0.9902410909090908, 0.9902324545454546, 0.8113939090909089], 56 -> 
             RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 
             335 -> RGBColor[
              0.8936208181818182, 0.918013, 0.9897155454545454], 314 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 144 -> 
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363], 298 -> 
             RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             204 -> RGBColor[
              0.8305035454545455, 0.867685, 0.9836953636363637], 452 -> 
             RGBColor[0.642359, 0.720535, 0.964988], 466 -> 
             RGBColor[
              0.9950293636363636, 0.9917766363636363, 0.7003550909090913], 
             207 -> RGBColor[0.984192, 0.987731, 0.911643], 334 -> 
             RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             149 -> RGBColor[
              0.7876885454545454, 0.8340675454545454, 0.9794730909090908], 
             219 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             400 -> RGBColor[
              0.9858593636363636, 0.9639624545454545, 0.3995667272727271], 9 -> 
             RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 11 -> 
             RGBColor[0.8305035454545455, 0.867685, 0.9836953636363637], 44 -> 
             RGBColor[
              0.9932656363636363, 0.9914831818181818, 0.7612693636363638], 
             153 -> RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 
             471 -> RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454546], 
             406 -> RGBColor[
              0.8620621818181817, 0.8928489999999999, 0.9867054545454546], 32 -> 
             RGBColor[
              0.9872165454545454, 0.9889817272727273, 0.8615184545454546], 
             162 -> RGBColor[0.642359, 0.720535, 0.964988], 493 -> 
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363], 90 -> 
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454], 331 -> 
             RGBColor[
              0.9935135454545455, 0.9885344545454546, 0.5353676363636367], 8 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 364 -> 
             RGBColor[
              0.9709666363636363, 0.9778675454545455, 0.9340300909090908], 
             342 -> RGBColor[
              0.5392457272727273, 0.6368230000000001, 0.9568705454545454], 
             163 -> RGBColor[0.984192, 0.987731, 0.911643], 49 -> 
             RGBColor[
              0.5392457272727273, 0.6368230000000001, 0.9568705454545454], 
             338 -> RGBColor[
              0.9935135454545455, 0.9885344545454546, 0.5353676363636367], 76 -> 
             RGBColor[
              0.6908021818181818, 0.7583791818181818, 0.9698163636363636], 
             369 -> RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 
             445 -> RGBColor[
              0.4007463636363636, 0.5215280909090909, 0.9467561818181818], 82 -> 
             RGBColor[
              0.36131763636363623`, 0.48737690909090897`, 0.9442438181818181],
              67 -> RGBColor[
              0.7392453636363636, 0.7962233636363636, 0.9746447272727272], 
             430 -> RGBColor[
              0.9577412727272727, 0.9680040909090909, 0.9564171818181818], 
             211 -> RGBColor[
              0.9932656363636363, 0.9914831818181818, 
               0.7612693636363638]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw1l3k4VA/cxYfs69jHPjOGGTNjV1rUPZUi6hcVbZKtXVmyRook2RJlqUih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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 42}], {
             RGBColor[
             0.9419309545454545, 0.9541227272727273, 0.9005547272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 108}], {
             RGBColor[
             0.9917533636363636, 0.9908578181818182, 0.7863316363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[
             0.9739911818181818, 0.9791182727272727, 0.8839055454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 119}], {
             RGBColor[
             0.7647434090909091, 0.8135277272727274, 0.8841322272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 120}], {
             RGBColor[
             0.9887288181818181, 0.9896070909090909, 0.8364561818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 124}], {
             RGBColor[
             0.9103723181818182, 0.9289587272727273, 0.8975446363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 315}], {
             RGBColor[
             0.9739911818181818, 0.9791182727272727, 0.8839055454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 363}], {
             RGBColor[
             0.8647432272727272, 0.8932279090909091, 0.893019318181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 364}], {
             RGBColor[
             0.9806038636363636, 0.9840500000000001, 0.8727119999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 378}], {
             RGBColor[
             0.9419309545454545, 0.9541227272727273, 0.9005547272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 380}], {
             RGBColor[
             0.9806038636363636, 0.9840500000000001, 0.8727119999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 381}], {
             RGBColor[0.9922562727272727, 0.990194, 0.7146276363636361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 416}], {
             RGBColor[
             0.9103723181818182, 0.9289587272727273, 0.8975446363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 452}], {
             RGBColor[
             0.8163000454545455, 0.8553837272727274, 0.8881909545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 468}], {
             RGBColor[
             0.7389650909090908, 0.7925997272727272, 0.8821028636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 487}], {
             RGBColor[
             0.6954937272727273, 0.7558802727272728, 0.8790750454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[
             0.8000501363636363, 0.8442695454545455, 0.9607025909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 114}], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 118}], {
             RGBColor[
             0.9724789090909091, 0.9784929090909091, 0.9089678181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 195}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 255}], {
             RGBColor[
             0.9668175909090909, 0.9491753636363636, 0.6586349999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 260}], {
             RGBColor[
             0.9414603636363637, 0.9555905454545455, 0.974571409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 312}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 327}], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 334}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 385}], {
             RGBColor[
             0.8941224090909091, 0.9178445454545454, 0.9700562727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 446}], {
             RGBColor[
             0.9414603636363637, 0.9555905454545455, 0.974571409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 496}], {
             RGBColor[
             0.7227151818181817, 0.7814855454545454, 0.9546144999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[
             0.9189780454545454, 0.9115978181818181, 0.6737791363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 139}], {
             RGBColor[0.9830675, 0.9602895454545455, 0.5861233636363634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 158}], {
             RGBColor[
             0.9347573636363636, 0.9241798181818182, 0.6752841818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 247}], {
             RGBColor[
             0.6686057727272727, 0.7088617727272727, 0.6525483181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 278}], {
             RGBColor[
             0.9734302727272728, 0.954107090909091, 0.6474414545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 401}], {
             RGBColor[
             0.9845797727272727, 0.960914909090909, 0.561061090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 428}], {
             RGBColor[
             0.9734302727272728, 0.954107090909091, 0.6474414545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 437}], {
             RGBColor[
             0.6883201363636364, 0.7259373636363636, 0.6538044999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 451}], {
             RGBColor[
             0.7317914999999999, 0.7626568181818181, 0.6568323181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 31}], {
             RGBColor[
             0.603798909090909, 0.6670451363636364, 0.8483933181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 151}], {
             RGBColor[
             0.9845797727272727, 0.960914909090909, 0.561061090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 162}], {
             RGBColor[
             0.8178123181818182, 0.8560090909090909, 0.8631286818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 191}], {
             RGBColor[
             0.9052923181818182, 0.5628050909090909, 0.4627436818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 345}], {
             RGBColor[
             0.9688907727272726, 0.9748119090909091, 0.8700368181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 366}], {
             RGBColor[
             0.8904770909090909, 0.9127753636363636, 0.8703712272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 389}], {
             RGBColor[
             0.9930106363636364, 0.9891982727272728, 0.6070716363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 405}], {
             RGBColor[
             0.9930106363636364, 0.9891982727272728, 0.6070716363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 429}], {
             RGBColor[
             0.9821161363636364, 0.9846753636363637, 0.8476497272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 472}], {
             RGBColor[
             0.9930106363636364, 0.9891982727272728, 0.6070716363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 488}], {
             RGBColor[
             0.6772916363636363, 0.7394300454545454, 0.852756590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 69}], {
             RGBColor[
             0.9688907727272726, 0.9748119090909091, 0.8700368181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[
             0.8875097272727273, 0.9129128181818182, 0.9812498181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 97}], {
             RGBColor[
             0.6529167727272727, 0.7227587727272726, 0.9615240454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 103}], {
             RGBColor[
             0.9651876363636362, 0.9610515454545454, 0.6891854999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 129}], {
             RGBColor[
             0.633202409090909, 0.7056831818181817, 0.9602678636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 163}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 204}], {
             RGBColor[
             0.8875097272727273, 0.9129128181818182, 0.9812498181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 209}], {
             RGBColor[
             0.8875097272727273, 0.9129128181818182, 0.9812498181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 231}], {
             RGBColor[
             0.8921227272727272, 0.6322624545454545, 0.5822413181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 233}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 259}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 275}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 326}], {
             RGBColor[
             0.7676591363636363, 0.818409818181818, 0.9698667727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 346}], {
             RGBColor[
             0.8661022272727272, 0.8961040909090909, 0.9791386818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 348}], {
             RGBColor[0.9686357727272727, 0.972527, 0.7158390909090907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 355}], {
             RGBColor[
             0.7418808181818182, 0.7974818181818182, 0.9678374090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 395}], {
             RGBColor[
             0.5617214545454545, 0.6317673181818182, 0.9561526363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 404}], {
             RGBColor[
             0.8921227272727272, 0.6322624545454545, 0.5822413181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 431}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 444}], {
             RGBColor[
             0.9348476818181818, 0.9506588181818182, 0.9857649545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 486}], {
             RGBColor[
             0.9348476818181818, 0.9506588181818182, 0.9857649545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 35}], {
             RGBColor[
             0.6924691818181818, 0.7546295454545455, 0.9291995909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 101}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 123}], {
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 158}], {
             RGBColor[
             0.938906409090909, 0.9528719999999999, 0.9506792727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 181}], {
             RGBColor[
             0.9887288181818181, 0.9896070909090909, 0.8364561818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 189}], {
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 302}], {
             RGBColor[
             0.9358782272727273, 0.7850346363636365, 0.5697681818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 306}], {
             RGBColor[
             0.9857042727272727, 0.9883563636363637, 0.8865807272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 347}], {
             RGBColor[
             0.8374970909090909, 0.8730550909090908, 0.9407296818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 370}], {
             RGBColor[
             0.8617186818181818, 0.8919771818181819, 0.9431438636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 390}], {
             RGBColor[
             0.9896106818181818, 0.9897538181818182, 0.8059990454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 422}], {
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 428}], {
             RGBColor[
             0.9775793181818182, 0.9827992727272727, 0.9228365454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 451}], {
             RGBColor[0.7359405454545453, 0.791349, 0.9322274090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 17}], {
             RGBColor[
             0.9592225454545454, 0.967330090909091, 0.8769975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.9755034545454545, 0.9797436363636364, 0.8588432727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.9821161363636364, 0.9846753636363637, 0.8476497272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.9688907727272726, 0.9748119090909091, 0.8700368181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 89}], {
             RGBColor[
             0.9118845909090909, 0.9295840909090909, 0.8724823636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 176}], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 178}], {
             RGBColor[
             0.9895624999999999, 0.9777228181818182, 0.5804180454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 244}], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 261}], {
             RGBColor[
             0.9795970454545455, 0.9441070000000001, 0.5417041363636366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 262}], {
             RGBColor[
             0.9341665909090908, 0.7585379545454545, 0.48936750000000007`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 288}], {
             RGBColor[
             0.9118845909090909, 0.9295840909090909, 0.8724823636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 295}], {
             RGBColor[
             0.927663909090909, 0.9421660909090909, 0.8739874090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 313}], {
             RGBColor[
             0.842033909090909, 0.8749311818181817, 0.8655428636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 321}], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 341}], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 376}], {
             RGBColor[
             0.842033909090909, 0.8749311818181817, 0.8655428636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 391}], {
             RGBColor[0.9466635, 0.8152835000000002, 0.4997952272727274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 407}], {
             RGBColor[
             0.8904770909090909, 0.9127753636363636, 0.8703712272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 448}], {
             RGBColor[
             0.9592225454545454, 0.967330090909091, 0.8769975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 455}], {
             RGBColor[
             0.8178123181818182, 0.8560090909090909, 0.8631286818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 475}], {
             RGBColor[
             0.9821161363636364, 0.9846753636363637, 0.8476497272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 478}], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 482}], {
             RGBColor[
             0.9755034545454545, 0.9797436363636364, 0.8588432727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 63}], {
             RGBColor[
             0.4590861818181818, 0.5508086818181818, 0.9540728636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 85}], {
             RGBColor[
             0.43486459090909085`, 0.5318865909090909, 0.9516586818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 146}], {
             RGBColor[
             0.5830717727272727, 0.6471878636363637, 0.8975097272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 159}], {
             RGBColor[
             0.5617214545454545, 0.6317673181818182, 0.9561526363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 166}], {
             RGBColor[
             0.4833077727272727, 0.5697307727272727, 0.9564870454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 239}], {
             RGBColor[
             0.5865992272727272, 0.6477747727272727, 0.7756811818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 344}], {
             RGBColor[
             0.5683341363636363, 0.6366990454545454, 0.9449590909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 387}], {
             RGBColor[
             0.2898366818181818, 0.41346104545454543`, 0.9401285909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 435}], {
             RGBColor[
             0.5749468181818183, 0.6416307727272728, 0.9337655454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 439}], {
             RGBColor[
             0.4590861818181818, 0.5508086818181818, 0.9540728636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 453}], {
             RGBColor[
             0.5865992272727272, 0.6477747727272727, 0.7756811818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 68}], {
             RGBColor[
             0.4348645909090909, 0.5318865909090909, 0.9516586818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 95}], {
             RGBColor[
             0.8390093636363636, 0.8736804545454545, 0.9156674090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 286}], {
             RGBColor[
             0.842033909090909, 0.8749311818181817, 0.8655428636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 319}], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 330}], {
             RGBColor[
             0.6665805909090909, 0.739457090909091, 0.9674021818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 333}], {
             RGBColor[
             0.7150237727272727, 0.7773012727272727, 0.9722305454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 352}], {
             RGBColor[
             0.8405216363636363, 0.8743058181818182, 0.8906051363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 357}], {
             RGBColor[0.7922115, 0.8381960909090909, 0.9797659545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 358}], {
             RGBColor[
             0.8421578636363636, 0.8734568181818182, 0.7525920000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 367}], {
             RGBColor[
             0.8233825909090908, 0.8107470909090908, 0.6266206818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 368}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 375}], {
             RGBColor[0.7708685, 0.5754460454545457, 0.5831124545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 441}], {
             RGBColor[
             0.8308844090909091, 0.8681233636363637, 0.9519232272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 450}], {
             RGBColor[
             0.6408022727272726, 0.7185290909090908, 0.9653728181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 492}], {
             RGBColor[
             0.7150237727272727, 0.7773012727272727, 0.9722305454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 102}], {
             RGBColor[0.9123875, 0.9289202727272727, 0.8007783636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 168}], {
             RGBColor[
             0.9946504090909091, 0.9909660909090909, 0.6591082272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 181}], {
             RGBColor[
             0.9937685454545454, 0.9908193636363636, 0.6895653636363634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.9281668181818181, 0.9415022727272726, 0.8022834090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 232}], {
             RGBColor[
             0.9900654090909091, 0.9770589999999999, 0.5087140454545451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 280}], {
             RGBColor[
             0.7409802727272726, 0.7925612727272726, 0.7853365909090907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 302}], {
             RGBColor[
             0.9409179545454546, 0.7862469090909092, 0.42287736363636347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 370}], {
             RGBColor[
             0.8667584090909091, 0.8931894545454545, 0.7962530454545452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 383}], {
             RGBColor[
             0.9760063636363636, 0.9790798181818181, 0.7871392727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 390}], {
             RGBColor[
             0.9946504090909091, 0.9909660909090909, 0.6591082272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 443}], {
             RGBColor[
             0.9760063636363636, 0.9790798181818181, 0.7871392727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 451}], {
             RGBColor[
             0.7409802727272726, 0.7925612727272726, 0.7853365909090907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 480}], {
             RGBColor[
             0.9760063636363636, 0.9790798181818181, 0.7871392727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 25}], {
             RGBColor[0.8620621818181818, 0.892849, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 164}], {
             RGBColor[
             0.7106529545454545, 0.7731819999999999, 0.9723123181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 180}], {
             RGBColor[
             0.7364312727272728, 0.7941100000000001, 0.9743416818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 205}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 259}], {
             RGBColor[0.9073477727272727, 0.927708, 0.9476691818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 316}], {
             RGBColor[
             0.6590963181818181, 0.7313259999999999, 0.9682535909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 331}], {
             RGBColor[
             0.9120085454545455, 0.9281097272727273, 0.7595315000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 348}], {
             RGBColor[
             0.911629590909091, 0.9272991818181819, 0.7182846363636362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 372}], {
             RGBColor[
             0.8295139090909092, 0.5439703181818182, 0.5793217727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 404}], {
             RGBColor[
             0.8351165454545455, 0.5870346363636363, 0.5846868636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 418}], {
             RGBColor[
             0.7606528636363636, 0.8130320909090909, 0.9767558636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 431}], {
             RGBColor[
             0.900735090909091, 0.9227762727272728, 0.9588627272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 444}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 40}], {
             RGBColor[
             0.7905217272727272, 0.8344557272727272, 0.8861615909090907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 161}], {
             RGBColor[0.9830675, 0.9602895454545455, 0.5861233636363634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 188}], {
             RGBColor[
             0.9926352272727272, 0.9910045454545455, 0.7558745000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 202}], {
             RGBColor[
             0.9926352272727272, 0.9910045454545455, 0.7558745000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 243}], {
             RGBColor[
             0.9673784999999999, 0.9741865454545455, 0.8950990909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 273}], {
             RGBColor[
             0.9918773181818181, 0.9893834545454546, 0.6733807727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 279}], {
             RGBColor[
             0.7389650909090908, 0.7925997272727272, 0.8821028636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 283}], {
             RGBColor[
             0.6954937272727273, 0.7558802727272728, 0.8790750454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 285}], {
             RGBColor[0.8889648181818182, 0.91215, 0.8954334999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 318}], {
             RGBColor[
             0.7647434090909091, 0.8135277272727274, 0.8841322272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 335}], {
             RGBColor[
             0.9419309545454545, 0.9541227272727273, 0.9005547272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 396}], {
             RGBColor[
             0.8405216363636363, 0.8743058181818182, 0.8906051363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 421}], {
             RGBColor[0.8889648181818182, 0.91215, 0.8954334999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 430}], {
             RGBColor[
             0.9739911818181818, 0.9791182727272727, 0.8839055454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 459}], {
             RGBColor[
             0.9926352272727272, 0.9910045454545455, 0.7558745000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 477}], {
             RGBColor[
             0.8405216363636363, 0.8743058181818182, 0.8906051363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 21}], {
             RGBColor[
             0.8313780454545454, 0.6798301363636362, 0.5984693636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 59}], {
             RGBColor[
             0.9097917272727272, 0.7418666818181816, 0.5981349545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 77}], {
             RGBColor[
             0.9296297727272727, 0.7566618636363636, 0.5645543181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 87}], {
             RGBColor[
             0.9304634545454544, 0.7447775909090908, 0.3085161818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 161}], {
             RGBColor[
             0.9254807272727272, 0.7279696818181817, 0.28915922727272714`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 188}], {
             RGBColor[
             0.9350484545454545, 0.7586846818181816, 0.45891036363636384`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 228}], {
             RGBColor[
             0.8573985454545454, 0.41598849999999976`, 0.20157199999999997`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 243}], {
             RGBColor[
             0.9097917272727272, 0.7418666818181816, 0.5981349545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 256}], {
             RGBColor[0.8527855454545454, 0.6966388636363635, 0.6005805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 279}], {
             RGBColor[
             0.681378318181818, 0.5602798636363635, 0.5851387272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 285}], {
             RGBColor[
             0.8313780454545454, 0.6798301363636362, 0.5984693636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 287}], {
             RGBColor[
             0.9350484545454545, 0.7586846818181816, 0.45891036363636384`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 298}], {
             RGBColor[
             0.8685648636363635, 0.7092208636363635, 0.6020855454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 335}], {
             RGBColor[
             0.8843441818181818, 0.7218028636363635, 0.6035905909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 354}], {
             RGBColor[
             0.9097917272727272, 0.7418666818181816, 0.5981349545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 409}], {
             RGBColor[
             0.6379069545454545, 0.523560409090909, 0.5821109090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 430}], {
             RGBColor[
             0.916404409090909, 0.746798409090909, 0.5869414090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 477}], {
             RGBColor[
             0.7829348636363636, 0.6419859545454544, 0.5936409999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 80}], {
             RGBColor[
             0.6726311363636364, 0.7398343636363636, 0.9627802272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 159}], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 166}], {
             RGBColor[
             0.8661022272727272, 0.8961040909090909, 0.9791386818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 192}], {
             RGBColor[
             0.9673784999999999, 0.9741865454545455, 0.8950990909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 239}], {
             RGBColor[
             0.9693936818181818, 0.9741480909090909, 0.798332818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 251}], {
             RGBColor[
             0.9690147272727272, 0.9733375454545454, 0.7570859545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 272}], {
             RGBColor[
             0.9658662272727272, 0.9735611818181817, 0.9201613636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 435}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 447}], {
             RGBColor[
             0.6529167727272727, 0.7227587727272726, 0.9615240454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 453}], {
             RGBColor[
             0.9693936818181818, 0.9741480909090909, 0.798332818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 454}], {
             RGBColor[
             0.7676591363636363, 0.818409818181818, 0.9698667727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 489}], {
             RGBColor[
             0.9658662272727272, 0.9735611818181817, 0.9201613636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 50}], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 82}], {
             RGBColor[
             0.5502814999999999, 0.6418001363636363, 0.9594442727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 126}], {
             RGBColor[
             0.8484933181818182, 0.8821137272727273, 0.9655309545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 149}], {
             RGBColor[
             0.7634669545454544, 0.8151454545454545, 0.977058909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 173}], {
             RGBColor[
             0.5502814999999999, 0.6418001363636363, 0.9594442727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 242}], {
             RGBColor[
             0.7150237727272727, 0.7773012727272727, 0.9722305454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 249}], {
             RGBColor[
             0.8164330909090909, 0.8571181818181818, 0.9821801363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 269}], {
             RGBColor[
             0.8551059999999999, 0.8870454545454545, 0.954337409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 282}], {
             RGBColor[
             0.8164330909090909, 0.8571181818181818, 0.9821801363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 323}], {
             RGBColor[
             0.8164330909090909, 0.8571181818181818, 0.9821801363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 414}], {
             RGBColor[
             0.8551059999999999, 0.8870454545454545, 0.954337409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 419}], {
             RGBColor[
             0.8647432272727272, 0.8932279090909091, 0.893019318181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 449}], {
             RGBColor[
             0.8164330909090909, 0.8571181818181818, 0.9821801363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 499}], {
             RGBColor[
             0.7150237727272727, 0.7773012727272727, 0.9722305454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 17}], {
             RGBColor[
             0.7579909090909089, 0.8109279999999999, 0.9768274545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 116}], {
             RGBColor[
             0.6892454545454544, 0.7563732727272726, 0.9702011818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 143}], {
             RGBColor[0.7874971818181817, 0.833205, 0.9362861363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 165}], {
             RGBColor[0.6650238636363635, 0.7374511818181817, 0.967787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 185}], {
             RGBColor[
             0.7579909090909089, 0.8109279999999999, 0.9768274545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.7929158636363636, 0.835227818181818, 0.830642181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 224}], {
             RGBColor[
             0.6408022727272726, 0.7185290909090908, 0.9653728181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 277}], {
             RGBColor[
             0.7676591363636363, 0.818409818181818, 0.9698667727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 313}], {
             RGBColor[
             0.6408022727272726, 0.7185290909090908, 0.9653728181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 333}], {
             RGBColor[0.6650238636363635, 0.7374511818181817, 0.967787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 358}], {
             RGBColor[
             0.7921579545454545, 0.8336067272727272, 0.7481484545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 361}], {
             RGBColor[
             0.7808844999999999, 0.8282732727272726, 0.9474796818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 386}], {
             RGBColor[0.7874971818181817, 0.833205, 0.9362861363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 441}], {
             RGBColor[
             0.7808844999999999, 0.8282732727272726, 0.9474796818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 89}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.9348476818181818, 0.9506588181818182, 0.9857649545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 116}], {
             RGBColor[
             0.8564339999999999, 0.8886222727272728, 0.9860993636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 143}], {
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 165}], {
             RGBColor[
             0.8322124090909091, 0.8697001818181818, 0.9836851818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 176}], {
             RGBColor[
             0.9592225454545454, 0.967330090909091, 0.8769975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 178}], {
             RGBColor[
             0.9555194090909092, 0.9535697272727273, 0.6961461818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 261}], {
             RGBColor[
             0.9455539545454545, 0.9199539090909092, 0.6574322727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 277}], {
             RGBColor[
             0.9348476818181818, 0.9506588181818182, 0.9857649545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 288}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 313}], {
             RGBColor[0.8079908181818182, 0.850778090909091, 0.981271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 321}], {
             RGBColor[0.956198, 0.9660793636363636, 0.9271220454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 328}], {
             RGBColor[
             0.9589675454545454, 0.9650451818181819, 0.7227997727272725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 386}], {
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 391}], {
             RGBColor[
             0.9126204090909091, 0.7911304090909093, 0.6155233636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 407}], {
             RGBColor[
             0.8564339999999999, 0.8886222727272728, 0.9860993636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 455}], {
             RGBColor[0.7837692272727272, 0.831856, 0.9788568181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 498}], {
             RGBColor[0.8824544999999999, 0.6247806363636363, 0.589202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 28}], {
             RGBColor[
             0.9806038636363636, 0.9840500000000001, 0.8727119999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 93}], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 160}], {
             RGBColor[
             0.9880502272727272, 0.9770974545454545, 0.605480318181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 167}], {
             RGBColor[
             0.8647432272727272, 0.8932279090909091, 0.893019318181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 172}], {
             RGBColor[
             0.9739911818181818, 0.9791182727272727, 0.8839055454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 201}], {
             RGBColor[
             0.9926352272727272, 0.9910045454545455, 0.7558745000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 218}], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 235}], {
             RGBColor[
             0.9914983636363637, 0.9885729090909092, 0.6321339090909088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 274}], {
             RGBColor[
             0.9577102727272727, 0.9667047272727274, 0.9020597727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 300}], {
             RGBColor[
             0.9577102727272727, 0.9667047272727274, 0.9020597727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 305}], {
             RGBColor[
             0.9926352272727272, 0.9910045454545455, 0.7558745000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 310}], {
             RGBColor[
             0.9673784999999999, 0.9741865454545455, 0.8950990909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 406}], {
             RGBColor[
             0.9261516363636363, 0.9415407272727272, 0.8990496818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 432}], {
             RGBColor[0.9830675, 0.9602895454545455, 0.5861233636363634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 460}], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 493}], {
             RGBColor[
             0.9577102727272727, 0.9667047272727274, 0.9020597727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 26}], {
             RGBColor[0.8889648181818182, 0.91215, 0.8954334999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 59}], {
             RGBColor[
             0.8661022272727272, 0.8961040909090909, 0.9791386818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 67}], {
             RGBColor[
             0.7634669545454544, 0.8151454545454545, 0.977058909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 124}], {
             RGBColor[
             0.8090960454545455, 0.8508762727272727, 0.9815842272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 188}], {
             RGBColor[
             0.8913589545454546, 0.9129220909090909, 0.8399140909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 200}], {
             RGBColor[
             0.8859402727272727, 0.9108992727272727, 0.9455580454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 228}], {
             RGBColor[
             0.8137090454545454, 0.570225909090909, 0.5825757272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 298}], {
             RGBColor[
             0.8248753636363635, 0.8634582727272726, 0.9830892727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 318}], {
             RGBColor[
             0.6634671363636364, 0.7354452727272728, 0.9681718181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 335}], {
             RGBColor[
             0.8406546818181817, 0.8760402727272727, 0.9845943181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 459}], {
             RGBColor[
             0.8913589545454546, 0.9129220909090909, 0.8399140909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 468}], {
             RGBColor[
             0.6376888181818181, 0.7145172727272726, 0.9661424545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 25}], {
             RGBColor[
             0.767989909090909, 0.8192740000000001, 0.9773517727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 46}], {
             RGBColor[0.8132755, 0.854133, 0.9383155]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{20, 150}], {
             RGBColor[
             0.8186941818181819, 0.8561558181818182, 0.8326715454545457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 220}], {
             RGBColor[
             0.5215526818181818, 0.6210315454545454, 0.9558720909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 325}], {
             RGBColor[
             0.6665805909090909, 0.739457090909091, 0.9674021818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 388}], {
             RGBColor[
             0.5018383181818181, 0.6039559545454545, 0.954615909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 392}], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 413}], {
             RGBColor[
             0.5018383181818181, 0.6039559545454545, 0.954615909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 473}], {
             RGBColor[
             0.8178123181818182, 0.8560090909090909, 0.8631286818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 474}], {
             RGBColor[0.7522105909090908, 0.806692, 0.9758467272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 490}], {
             RGBColor[0.642359, 0.720535, 0.964988]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 55}], {
             RGBColor[
             0.8793275909090909, 0.9059675454545455, 0.9567515909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 59}], {
             RGBColor[
             0.8661022272727272, 0.8961040909090909, 0.9791386818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 77}], {
             RGBColor[
             0.8859402727272727, 0.9108992727272727, 0.9455580454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[
             0.8867739545454545, 0.8990149999999999, 0.689519909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 91}], {
             RGBColor[
             0.6892454545454544, 0.7563732727272726, 0.9702011818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 188}], {
             RGBColor[
             0.8913589545454546, 0.9129220909090909, 0.8399140909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 200}], {
             RGBColor[
             0.8859402727272727, 0.9108992727272727, 0.9455580454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 228}], {
             RGBColor[
             0.8137090454545454, 0.570225909090909, 0.5825757272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 256}], {
             RGBColor[
             0.8090960454545455, 0.8508762727272727, 0.9815842272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 287}], {
             RGBColor[
             0.8913589545454546, 0.9129220909090909, 0.8399140909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 298}], {
             RGBColor[
             0.8248753636363635, 0.8634582727272726, 0.9830892727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 335}], {
             RGBColor[
             0.8406546818181817, 0.8760402727272727, 0.9845943181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 336}], {
             RGBColor[
             0.8859402727272727, 0.9108992727272727, 0.9455580454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 354}], {
             RGBColor[
             0.8661022272727272, 0.8961040909090909, 0.9791386818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 409}], {
             RGBColor[
             0.5942174545454545, 0.6777978181818182, 0.9631146363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 24}], {
             RGBColor[
             0.7227151818181817, 0.7814855454545454, 0.9546144999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 52}], {
             RGBColor[
             0.7374528181818181, 0.7919743636363636, 0.9071651363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 170}], {
             RGBColor[
             0.7293278636363636, 0.7864172727272727, 0.9434209545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 214}], {
             RGBColor[
             0.7374528181818181, 0.7919743636363636, 0.9071651363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 268}], {
             RGBColor[
             0.7389650909090908, 0.7925997272727272, 0.8821028636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 466}], {
             RGBColor[
             0.7413592272727272, 0.7933718181818181, 0.8265834545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 491}], {
             RGBColor[
             0.7006613181818181, 0.6451299090909088, 0.6010887727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 39}], {
             RGBColor[
             0.9806038636363636, 0.9840500000000001, 0.8727119999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 51}], {
             RGBColor[
             0.9480730454545454, 0.9605222727272728, 0.9633778636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 62}], {
             RGBColor[
             0.8308844090909091, 0.8681233636363637, 0.9519232272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 96}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 110}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 136}], {
             RGBColor[
             0.9167686363636363, 0.7233573636363635, 0.5705339999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 157}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 240}], {
             RGBColor[
             0.9818611363636364, 0.9823904545454546, 0.6934519999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 360}], {
             RGBColor[
             0.8551059999999999, 0.8870454545454545, 0.954337409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 52}], {
             RGBColor[
             0.9724789090909091, 0.9784929090909091, 0.9089678181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 64}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.9511285909090909, 0.9630723636363636, 0.9676107272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 115}], {
             RGBColor[
             0.8000501363636363, 0.8442695454545455, 0.9607025909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 170}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 223}], {
             RGBColor[
             0.872714909090909, 0.9010358181818181, 0.9679451363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 268}], {
             RGBColor[
             0.9739911818181818, 0.9791182727272727, 0.8839055454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 491}], {
             RGBColor[
             0.9356874090909091, 0.8316484545454543, 0.6028914545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 164}], {
             RGBColor[
             0.7422115909090907, 0.7983459999999999, 0.9753224090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.767989909090909, 0.8192740000000001, 0.9773517727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 220}], {
             RGBColor[
             0.6471835909090908, 0.7197705454545454, 0.9682358636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 316}], {
             RGBColor[
             0.6906549545454544, 0.7564899999999999, 0.9712636818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 325}], {
             RGBColor[0.7922115, 0.8381960909090909, 0.9797659545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 392}], {
             RGBColor[
             0.8164330909090909, 0.8571181818181818, 0.9821801363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 413}], {
             RGBColor[
             0.6274692272727271, 0.7026949545454545, 0.9669796818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 474}], {
             RGBColor[0.8778414999999999, 0.9054309999999999, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 490}], {
             RGBColor[
             0.767989909090909, 0.8192740000000001, 0.9773517727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 67}], {
             RGBColor[
             0.8647432272727272, 0.8932279090909091, 0.893019318181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 124}], {
             RGBColor[
             0.9103723181818182, 0.9289587272727273, 0.8975446363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 318}], {
             RGBColor[
             0.7647434090909091, 0.8135277272727274, 0.8841322272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 335}], {
             RGBColor[
             0.9419309545454545, 0.9541227272727273, 0.9005547272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 459}], {
             RGBColor[
             0.9926352272727272, 0.9910045454545455, 0.7558745000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 29}], {
             RGBColor[
             0.9348476818181818, 0.9506588181818182, 0.9857649545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 65}], {
             RGBColor[
             0.9697726363636363, 0.9749586363636363, 0.839579681818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 86}], {
             RGBColor[
             0.9673784999999999, 0.9741865454545455, 0.8950990909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 177}], {
             RGBColor[
             0.8661022272727272, 0.8961040909090909, 0.9791386818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[
             0.9348476818181818, 0.9506588181818182, 0.9857649545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 290}], {
             RGBColor[0.8418806363636363, 0.8771819999999999, 0.9767245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 297}], {
             RGBColor[
             0.9697726363636363, 0.9749586363636363, 0.839579681818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 350}], {
             RGBColor[
             0.9688907727272726, 0.9748119090909091, 0.8700368181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 412}], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 484}], {
             RGBColor[0.9686357727272727, 0.972527, 0.7158390909090907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 490}], {
             RGBColor[
             0.7934374545454546, 0.8393378181818182, 0.9718961363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 125}], {
             RGBColor[
             0.9821161363636364, 0.9846753636363637, 0.8476497272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 149}], {
             RGBColor[
             0.8793275909090909, 0.9059675454545455, 0.9567515909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 201}], {
             RGBColor[0.982998, 0.9848220909090909, 0.8171925909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 218}], {
             RGBColor[
             0.9775793181818182, 0.9827992727272727, 0.9228365454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 282}], {
             RGBColor[
             0.9322937272727272, 0.9479402727272728, 0.9618728181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 305}], {
             RGBColor[0.982998, 0.9848220909090909, 0.8171925909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 310}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 406}], {
             RGBColor[
             0.916514409090909, 0.9353582727272727, 0.9603677727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 408}], {
             RGBColor[
             0.9821161363636364, 0.9846753636363637, 0.8476497272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 419}], {
             RGBColor[
             0.9806038636363636, 0.9840500000000001, 0.8727119999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 432}], {
             RGBColor[
             0.9734302727272728, 0.954107090909091, 0.6474414545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 493}], {
             RGBColor[
             0.9480730454545454, 0.9605222727272728, 0.9633778636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 46}], {
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 65}], {
             RGBColor[
             0.9601044090909091, 0.9674768181818182, 0.8465403636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 86}], {
             RGBColor[
             0.9577102727272727, 0.9667047272727274, 0.9020597727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 177}], {
             RGBColor[
             0.8564339999999999, 0.8886222727272728, 0.9860993636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 194}], {
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 254}], {
             RGBColor[
             0.9592225454545454, 0.967330090909091, 0.8769975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 290}], {
             RGBColor[
             0.8322124090909091, 0.8697001818181818, 0.9836851818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 297}], {
             RGBColor[
             0.9601044090909091, 0.9674768181818182, 0.8465403636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 350}], {
             RGBColor[
             0.9592225454545454, 0.967330090909091, 0.8769975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 377}], {
             RGBColor[0.9001235, 0.7343848636363635, 0.6050956363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 412}], {
             RGBColor[
             0.9348476818181818, 0.9506588181818182, 0.9857649545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 426}], {
             RGBColor[
             0.8322124090909091, 0.8697001818181818, 0.9836851818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 476}], {
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 31}], {
             RGBColor[
             0.5794240454545454, 0.6503738636363636, 0.9571607727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 133}], {
             RGBColor[
             0.9690147272727272, 0.9733375454545454, 0.7570859545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 191}], {
             RGBColor[
             0.8809174545454546, 0.5461338181818182, 0.5715111363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 311}], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 366}], {
             RGBColor[
             0.8661022272727272, 0.8961040909090909, 0.9791386818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 405}], {
             RGBColor[0.9686357727272727, 0.972527, 0.7158390909090907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 423}], {
             RGBColor[
             0.9651876363636362, 0.9610515454545454, 0.6891854999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 429}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 465}], {
             RGBColor[
             0.9693936818181818, 0.9741480909090909, 0.798332818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 469}], {
             RGBColor[
             0.9032890454545454, 0.9254948181818181, 0.9827548636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 488}], {
             RGBColor[
             0.6529167727272727, 0.7227587727272726, 0.9615240454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 133}], {
             RGBColor[
             0.6039228636363636, 0.6655707727272728, 0.7354424545454548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 191}], {
             RGBColor[
             0.515825590909091, 0.23836704545454543`, 0.5498676363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 226}], {
             RGBColor[
             0.6007743636363636, 0.6657944090909091, 0.8985178636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 237}], {
             RGBColor[
             0.515825590909091, 0.23836704545454543`, 0.5498676363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 311}], {
             RGBColor[
             0.5794240454545454, 0.6503738636363636, 0.9571607727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 366}], {
             RGBColor[
             0.5010103636363636, 0.5883373181818181, 0.9574951818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 405}], {
             RGBColor[
             0.6035439090909092, 0.6647602272727273, 0.6941955909090907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 429}], {
             RGBColor[
             0.5926494090909091, 0.6602373181818182, 0.9347736818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 472}], {
             RGBColor[
             0.6035439090909092, 0.6647602272727273, 0.6941955909090907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 488}], {
             RGBColor[
             0.287824909090909, 0.4149919999999999, 0.9398805454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 66}], {
             RGBColor[
             0.8147877727272728, 0.8547583636363636, 0.9132532272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 84}], {
             RGBColor[
             0.9658662272727272, 0.9735611818181817, 0.9201613636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 89}], {
             RGBColor[
             0.9088600454545455, 0.9283333636363637, 0.9226069090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 176}], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 179}], {
             RGBColor[
             0.6742670909090909, 0.7381793181818181, 0.9028811363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 245}], {
             RGBColor[0.990744, 0.9895686363636363, 0.7396899090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 255}], {
             RGBColor[
             0.9815552272727273, 0.9596641818181818, 0.6111856363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 260}], {
             RGBColor[0.956198, 0.9660793636363636, 0.9271220454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 299}], {
             RGBColor[
             0.9715897727272726, 0.9260483636363637, 0.5724717272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 312}], {
             RGBColor[
             0.8390093636363636, 0.8736804545454545, 0.9156674090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 328}], {
             RGBColor[
             0.989986090909091, 0.9879475454545454, 0.6571961818181816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 334}], {
             RGBColor[
             0.9724789090909091, 0.9784929090909091, 0.9089678181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 407}], {
             RGBColor[
             0.8874525454545454, 0.9115246363636363, 0.9204957727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 448}], {
             RGBColor[0.956198, 0.9660793636363636, 0.9271220454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 475}], {
             RGBColor[
             0.9790915909090909, 0.9834246363636363, 0.8977742727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 478}], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 482}], {
             RGBColor[
             0.9724789090909091, 0.9784929090909091, 0.9089678181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 76}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 111}], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 160}], {
             RGBColor[
             0.9718003181818182, 0.9659832727272727, 0.6779919545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 175}], {
             RGBColor[
             0.6792438181818181, 0.744766090909091, 0.9515866818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 182}], {
             RGBColor[
             0.8941224090909091, 0.9178445454545454, 0.9700562727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 237}], {
             RGBColor[
             0.8875301363636363, 0.5510655454545454, 0.560317590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 241}], {
             RGBColor[0.6595294545454544, 0.7276904999999999, 0.9503305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 274}], {
             RGBColor[
             0.9414603636363637, 0.9555905454545455, 0.974571409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 351}], {
             RGBColor[
             0.9724789090909091, 0.9784929090909091, 0.9089678181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 371}], {
             RGBColor[
             0.872714909090909, 0.9010358181818181, 0.9679451363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 432}], {
             RGBColor[
             0.9668175909090909, 0.9491753636363636, 0.6586349999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 460}], {
             RGBColor[
             0.9739911818181818, 0.9791182727272727, 0.8839055454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 463}], {
             RGBColor[
             0.9511285909090909, 0.9630723636363636, 0.9676107272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 44}], {
             RGBColor[
             0.7662556818181818, 0.814153090909091, 0.8590699545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 62}], {
             RGBColor[
             0.6150239545454546, 0.697601090909091, 0.9633434545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 190}], {
             RGBColor[
             0.7660006818181819, 0.8118681818181819, 0.704872227272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 291}], {
             RGBColor[
             0.7617188636363637, 0.8122770000000001, 0.9342567727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 356}], {
             RGBColor[0.732212590909091, 0.79, 0.9747980909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 394}], {
             RGBColor[0.732212590909091, 0.79, 0.9747980909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 467}], {
             RGBColor[
             0.7660006818181819, 0.8118681818181819, 0.704872227272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.6471835909090908, 0.7197705454545454, 0.9682358636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 123}], {
             RGBColor[
             0.6314042727272726, 0.7071885454545455, 0.9667308181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 193}], {
             RGBColor[
             0.6156249545454546, 0.6946065454545455, 0.9652257727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 347}], {
             RGBColor[
             0.5457742727272727, 0.6399536363636363, 0.9582862727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 410}], {
             RGBColor[
             0.6314042727272726, 0.7071885454545455, 0.9667308181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 422}], {
             RGBColor[
             0.6314042727272726, 0.7071885454545455, 0.9667308181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 428}], {
             RGBColor[0.6858565, 0.7496978181818181, 0.9403931363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 437}], {
             RGBColor[
             0.4007463636363636, 0.5215280909090909, 0.9467561818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 75}], {
             RGBColor[
             0.9821161363636364, 0.9846753636363637, 0.8476497272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 76}], {
             RGBColor[
             0.8308844090909091, 0.8681233636363637, 0.9519232272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 104}], {
             RGBColor[
             0.9821161363636364, 0.9846753636363637, 0.8476497272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 112}], {
             RGBColor[
             0.8308844090909091, 0.8681233636363637, 0.9519232272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 266}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 359}], {
             RGBColor[
             0.7293278636363636, 0.7864172727272727, 0.9434209545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 379}], {
             RGBColor[
             0.9322937272727272, 0.9479402727272728, 0.9618728181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 408}], {
             RGBColor[
             0.9821161363636364, 0.9846753636363637, 0.8476497272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 440}], {
             RGBColor[
             0.7293278636363636, 0.7864172727272727, 0.9434209545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 463}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 49}], {
             RGBColor[
             0.7663796363636364, 0.8126787272727274, 0.7461190909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 53}], {
             RGBColor[
             0.9756274090909092, 0.9782692727272728, 0.7458924090909093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 97}], {
             RGBColor[
             0.6774155909090909, 0.7379556818181818, 0.7398057272727274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 100}], {
             RGBColor[0.9938925000000001, 0.989345, 0.5766145]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{37, 203}], {
             RGBColor[
             0.9690147272727272, 0.9733375454545454, 0.7570859545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 207}], {
             RGBColor[
             0.9888527727272727, 0.9881327272727274, 0.7235053181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 257}], {
             RGBColor[
             0.9797210000000001, 0.9426326363636366, 0.42875327272727304`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 264}], {
             RGBColor[
             0.8421578636363636, 0.8734568181818182, 0.7525920000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 281}], {
             RGBColor[
             0.9690147272727272, 0.9733375454545454, 0.7570859545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 317}], {
             RGBColor[
             0.7663796363636364, 0.8126787272727274, 0.7461190909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 322}], {
             RGBColor[
             0.8421578636363636, 0.8734568181818182, 0.7525920000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 324}], {
             RGBColor[
             0.9935135454545455, 0.9885344545454546, 0.5353676363636367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 343}], {
             RGBColor[
             0.9277878636363637, 0.9406917272727273, 0.7610365454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 374}], {
             RGBColor[
             0.9593465000000001, 0.9658557272727273, 0.7640466363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 397}], {
             RGBColor[0.9938925000000001, 0.989345, 0.5766145]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{37, 445}], {
             RGBColor[
             0.6971299545454546, 0.7550312727272728, 0.7410619090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 77}], {
             RGBColor[
             0.6727548181818181, 0.7375539545454546, 0.9279434090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 79}], {
             RGBColor[0.6781735, 0.7395767727272726, 0.8222994545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 87}], {
             RGBColor[
             0.6735884999999999, 0.7256696818181817, 0.6719052727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 127}], {
             RGBColor[
             0.36131763636363623`, 0.48737690909090897`, 0.9442438181818181]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 184}], {
             RGBColor[
             0.6432485454545454, 0.7152769545454545, 0.9684847272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 221}], {
             RGBColor[
             0.6529167727272727, 0.7227587727272726, 0.9615240454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 253}], {
             RGBColor[
             0.6742670909090909, 0.7381793181818181, 0.9028811363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 287}], {
             RGBColor[0.6781735, 0.7395767727272726, 0.8222994545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 301}], {
             RGBColor[
             0.5745030909090908, 0.6607222272727272, 0.9618584545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 316}], {
             RGBColor[
             0.42450336363636354`, 0.5411719545454544, 0.9485278181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 336}], {
             RGBColor[
             0.6727548181818181, 0.7375539545454546, 0.9279434090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 354}], {
             RGBColor[
             0.6529167727272727, 0.7227587727272726, 0.9615240454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 388}], {
             RGBColor[
             0.36131763636363623`, 0.48737690909090897`, 0.9442438181818181]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 436}], {
             RGBColor[
             0.6586403181818181, 0.6752459545454544, 0.613834409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 473}], {
             RGBColor[
             0.6772916363636363, 0.7394300454545455, 0.852756590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 62}], {
             RGBColor[
             0.8405216363636363, 0.8743058181818182, 0.8906051363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 96}], {
             RGBColor[
             0.9673784999999999, 0.9741865454545455, 0.8950990909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 108}], {
             RGBColor[
             0.9917533636363636, 0.9908578181818182, 0.7863316363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 113}], {
             RGBColor[
             0.9739911818181818, 0.9791182727272727, 0.8839055454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 157}], {
             RGBColor[
             0.9739911818181818, 0.9791182727272727, 0.8839055454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 190}], {
             RGBColor[
             0.9914983636363637, 0.9885729090909092, 0.6321339090909088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 378}], {
             RGBColor[
             0.9419309545454545, 0.9541227272727273, 0.9005547272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 161}], {
             RGBColor[
             0.7833481363636363, 0.8045128181818181, 0.6608910454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 183}], {
             RGBColor[
             0.3848646818181817, 0.4920364999999999, 0.9472151363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 202}], {
             RGBColor[
             0.7929158636363636, 0.835227818181818, 0.830642181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 206}], {
             RGBColor[
             0.5908023636363634, 0.6786789999999998, 0.9609292727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 243}], {
             RGBColor[
             0.7676591363636363, 0.818409818181818, 0.9698667727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 273}], {
             RGBColor[
             0.7921579545454545, 0.8336067272727272, 0.7481484545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 283}], {
             RGBColor[
             0.4957743636363635, 0.6001035454545454, 0.9538427272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 285}], {
             RGBColor[
             0.6892454545454544, 0.7563732727272726, 0.9702011818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 396}], {
             RGBColor[
             0.6408022727272726, 0.7185290909090908, 0.9653728181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 421}], {
             RGBColor[
             0.6892454545454544, 0.7563732727272726, 0.9702011818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 430}], {
             RGBColor[
             0.774271818181818, 0.8233415454545454, 0.9586732272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 477}], {
             RGBColor[
             0.6408022727272726, 0.7185290909090908, 0.9653728181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 44}], {
             RGBColor[0.8662555, 0.8938532727272728, 0.8679570454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 56}], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.8632309545454545, 0.8926025454545454, 0.9180815909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 132}], {
             RGBColor[0.8662555, 0.8938532727272728, 0.8679570454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.8551059999999999, 0.8870454545454545, 0.954337409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 356}], {
             RGBColor[
             0.8322124090909091, 0.8697001818181818, 0.9836851818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 365}], {
             RGBColor[
             0.8476041818181819, 0.8296691818181818, 0.6290348636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 457}], {
             RGBColor[
             0.8617186818181818, 0.8919771818181819, 0.9431438636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 485}], {
             RGBColor[
             0.5699958636363636, 0.6588757272727273, 0.9607004545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 494}], {
             RGBColor[
             0.8164330909090909, 0.8571181818181818, 0.9821801363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 108}], {
             RGBColor[
             0.9434432272727272, 0.9547480909090909, 0.8754924545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 113}], {
             RGBColor[
             0.9256810454545454, 0.9430085454545454, 0.9730663636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 119}], {
             RGBColor[0.7164332727272728, 0.777418, 0.9732930454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 315}], {
             RGBColor[
             0.9256810454545454, 0.9430085454545454, 0.9730663636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 364}], {
             RGBColor[
             0.9322937272727272, 0.9479402727272728, 0.9618728181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 378}], {
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 380}], {
             RGBColor[
             0.9322937272727272, 0.9479402727272728, 0.9618728181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 381}], {
             RGBColor[
             0.9439461363636363, 0.9540842727272727, 0.8037884545454543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 416}], {
             RGBColor[0.8620621818181818, 0.892849, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 452}], {
             RGBColor[
             0.767989909090909, 0.8192740000000001, 0.9773517727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 468}], {
             RGBColor[
             0.6906549545454544, 0.7564899999999999, 0.9712636818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 487}], {
             RGBColor[
             0.6471835909090908, 0.7197705454545454, 0.9682358636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[0.8620621818181818, 0.892849, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 137}], {
             RGBColor[
             0.8941224090909091, 0.9178445454545454, 0.9700562727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 148}], {
             RGBColor[
             0.8090960454545455, 0.8508762727272727, 0.9815842272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 156}], {
             RGBColor[
             0.8875097272727273, 0.9129128181818182, 0.9812498181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 227}], {
             RGBColor[0.9073477727272727, 0.927708, 0.9476691818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 229}], {
             RGBColor[
             0.9103723181818182, 0.9289587272727273, 0.8975446363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 250}], {
             RGBColor[
             0.900735090909091, 0.9227762727272728, 0.9588627272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 263}], {
             RGBColor[
             0.8462828636363636, 0.8802669999999999, 0.9852004090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 267}], {
             RGBColor[0.8527855454545454, 0.6966388636363635, 0.6005805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 393}], {
             RGBColor[
             0.9127664545454546, 0.9297308181818182, 0.8420252272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 485}], {
             RGBColor[
             0.6156249545454546, 0.6946065454545455, 0.9652257727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 56}], {
             RGBColor[0.8662555, 0.8938532727272728, 0.8679570454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 62}], {
             RGBColor[
             0.842033909090909, 0.8749311818181817, 0.8655428636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 92}], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 110}], {
             RGBColor[
             0.9755034545454545, 0.9797436363636364, 0.8588432727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 132}], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 157}], {
             RGBColor[
             0.9755034545454545, 0.9797436363636364, 0.8588432727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 356}], {
             RGBColor[
             0.9592225454545454, 0.967330090909091, 0.8769975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 360}], {
             RGBColor[0.8662555, 0.8938532727272728, 0.8679570454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 365}], {
             RGBColor[
             0.9746143181818181, 0.9272990909090909, 0.5223471818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 457}], {
             RGBColor[
             0.9887288181818181, 0.9896070909090909, 0.8364561818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 494}], {
             RGBColor[
             0.9434432272727272, 0.9547480909090909, 0.8754924545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 118}], {
             RGBColor[
             0.9903650454545454, 0.988758090909091, 0.6984430454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 152}], {
             RGBColor[0.9938925000000001, 0.989345, 0.5766145]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{45, 185}], {
             RGBColor[
             0.9593465000000001, 0.9658557272727273, 0.7640466363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 187}], {
             RGBColor[
             0.9942714545454545, 0.9901555454545454, 0.617861363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 195}], {
             RGBColor[
             0.9756274090909092, 0.9782692727272728, 0.7458924090909093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 216}], {
             RGBColor[
             0.9277878636363637, 0.9406917272727273, 0.7610365454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 217}], {
             RGBColor[
             0.9277878636363637, 0.9406917272727273, 0.7610365454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 224}], {
             RGBColor[
             0.8421578636363636, 0.8734568181818182, 0.7525920000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 292}], {
             RGBColor[
             0.9120085454545455, 0.9281097272727273, 0.7595315000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 328}], {
             RGBColor[
             0.993134590909091, 0.9877239090909091, 0.49412077272727273`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 398}], {
             RGBColor[
             0.9756274090909092, 0.9782692727272728, 0.7458924090909093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 399}], {
             RGBColor[
             0.9933895909090908, 0.9900088181818183, 0.6483185000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 464}], {
             RGBColor[
             0.7663796363636364, 0.8126787272727274, 0.7461190909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 481}], {
             RGBColor[
             0.9593465000000001, 0.9658557272727273, 0.7640466363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 496}], {
             RGBColor[
             0.7406013181818182, 0.7917507272727273, 0.7440897272727274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 86}], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 142}], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 150}], {
             RGBColor[
             0.9896106818181818, 0.9897538181818182, 0.8059990454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 194}], {
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 220}], {
             RGBColor[
             0.6924691818181818, 0.7546295454545455, 0.9291995909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 254}], {
             RGBColor[
             0.9887288181818181, 0.9896070909090909, 0.8364561818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 297}], {
             RGBColor[
             0.9896106818181818, 0.9897538181818182, 0.8059990454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 325}], {
             RGBColor[
             0.8374970909090909, 0.8730550909090908, 0.9407296818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 350}], {
             RGBColor[
             0.9887288181818181, 0.9896070909090909, 0.8364561818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 377}], {
             RGBColor[
             0.9296297727272727, 0.7566618636363636, 0.5645543181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 392}], {
             RGBColor[
             0.8617186818181818, 0.8919771818181819, 0.9431438636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 412}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 426}], {
             RGBColor[
             0.8617186818181818, 0.8919771818181819, 0.9431438636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 476}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 55}], {
             RGBColor[
             0.8793275909090909, 0.9059675454545455, 0.9567515909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 59}], {
             RGBColor[
             0.8661022272727272, 0.8961040909090909, 0.9791386818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 73}], {
             RGBColor[
             0.8817912272727273, 0.8822070909090909, 0.6701629545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 91}], {
             RGBColor[
             0.6892454545454544, 0.7563732727272726, 0.9702011818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 136}], {
             RGBColor[
             0.8251295909090908, 0.6514573636363634, 0.5932554999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 200}], {
             RGBColor[
             0.8859402727272727, 0.9108992727272727, 0.9455580454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 228}], {
             RGBColor[
             0.8137090454545454, 0.570225909090909, 0.5825757272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 256}], {
             RGBColor[
             0.8090960454545455, 0.8508762727272727, 0.9815842272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 298}], {
             RGBColor[
             0.8248753636363635, 0.8634582727272726, 0.9830892727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 416}], {
             RGBColor[
             0.8090960454545455, 0.8508762727272727, 0.9815842272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 452}], {
             RGBColor[
             0.7150237727272727, 0.7773012727272728, 0.9722305454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 468}], {
             RGBColor[
             0.6376888181818181, 0.7145172727272726, 0.9661424545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 117}], {
             RGBColor[
             0.4957743636363635, 0.6001035454545454, 0.9538427272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 140}], {
             RGBColor[
             0.7920339999999999, 0.8350810909090909, 0.8610993181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 155}], {
             RGBColor[
             0.7808844999999999, 0.8282732727272726, 0.9474796818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 156}], {
             RGBColor[
             0.7676591363636363, 0.818409818181818, 0.9698667727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 198}], {
             RGBColor[
             0.7808844999999999, 0.8282732727272726, 0.9474796818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 250}], {
             RGBColor[
             0.7808844999999999, 0.8282732727272726, 0.9474796818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 365}], {
             RGBColor[
             0.7733826818181817, 0.7708969999999999, 0.6221771363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 479}], {
             RGBColor[
             0.7106529545454545, 0.7731819999999999, 0.9723123181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 51}], {
             RGBColor[0.732212590909091, 0.79, 0.9747980909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 100}], {
             RGBColor[
             0.7667585909090909, 0.8134892727272728, 0.7873659545454543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 203}], {
             RGBColor[
             0.7418808181818182, 0.7974818181818182, 0.9678374090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 264}], {
             RGBColor[
             0.6150239545454546, 0.697601090909091, 0.9633434545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 324}], {
             RGBColor[
             0.7663796363636364, 0.8126787272727274, 0.7461190909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 360}], {
             RGBColor[
             0.6392455454545455, 0.7165231818181819, 0.9657576363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 397}], {
             RGBColor[
             0.7667585909090909, 0.8134892727272728, 0.7873659545454543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 457}], {
             RGBColor[
             0.7617188636363637, 0.8122770000000001, 0.9342567727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 82}], {
             RGBColor[
             0.5502814999999999, 0.6418001363636363, 0.9594442727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 126}], {
             RGBColor[
             0.8484933181818182, 0.8821137272727273, 0.9655309545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 131}], {
             RGBColor[0.8418806363636363, 0.8771819999999999, 0.9767245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 173}], {
             RGBColor[
             0.5502814999999999, 0.6418001363636363, 0.9594442727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 242}], {
             RGBColor[
             0.7150237727272727, 0.7773012727272727, 0.9722305454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 323}], {
             RGBColor[
             0.8164330909090909, 0.8571181818181818, 0.9821801363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 340}], {
             RGBColor[
             0.8164330909090909, 0.8571181818181818, 0.9821801363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 373}], {
             RGBColor[
             0.8617186818181818, 0.8919771818181819, 0.9431438636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 414}], {
             RGBColor[
             0.8551059999999999, 0.8870454545454545, 0.954337409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 449}], {
             RGBColor[
             0.8164330909090909, 0.8571181818181818, 0.9821801363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 499}], {
             RGBColor[
             0.7150237727272727, 0.7773012727272727, 0.9722305454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 60}], {
             RGBColor[0.732212590909091, 0.79, 0.9747980909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 96}], {
             RGBColor[
             0.9348476818181818, 0.9506588181818182, 0.9857649545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 100}], {
             RGBColor[
             0.9597254545454545, 0.9666662727272728, 0.8052934999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 110}], {
             RGBColor[
             0.9414603636363637, 0.9555905454545455, 0.974571409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 203}], {
             RGBColor[
             0.9348476818181818, 0.9506588181818182, 0.9857649545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 240}], {
             RGBColor[
             0.9589675454545454, 0.9650451818181819, 0.7227997727272725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 264}], {
             RGBColor[0.8079908181818182, 0.850778090909091, 0.981271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 324}], {
             RGBColor[
             0.9593465000000001, 0.9658557272727273, 0.7640466363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 360}], {
             RGBColor[
             0.8322124090909091, 0.8697001818181818, 0.9836851818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 397}], {
             RGBColor[
             0.9597254545454545, 0.9666662727272728, 0.8052934999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 457}], {
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 495}], {
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 170}], {
             RGBColor[
             0.9790915909090909, 0.9834246363636363, 0.8977742727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 214}], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 268}], {
             RGBColor[
             0.9887288181818181, 0.9896070909090909, 0.8364561818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 466}], {
             RGBColor[
             0.9911229545454545, 0.9903791818181817, 0.7809367727272729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 491}], {
             RGBColor[
             0.9504250454545453, 0.8421372727272726, 0.5554420909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 83}], {
             RGBColor[
             0.8941224090909091, 0.9178445454545454, 0.9700562727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 97}], {
             RGBColor[0.6595294545454544, 0.7276904999999999, 0.9503305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 112}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 163}], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 207}], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 257}], {
             RGBColor[
             0.9618348636363636, 0.9323674545454547, 0.6392780454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 266}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 281}], {
             RGBColor[
             0.9511285909090909, 0.9630723636363636, 0.9676107272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 317}], {
             RGBColor[0.7484935, 0.8024135454545456, 0.9566438636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 322}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 343}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 374}], {
             RGBColor[
             0.9414603636363637, 0.9555905454545455, 0.974571409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 440}], {
             RGBColor[
             0.7227151818181817, 0.7814855454545454, 0.9546144999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 445}], {
             RGBColor[
             0.6792438181818181, 0.744766090909091, 0.9515866818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 471}], {
             RGBColor[
             0.9724789090909091, 0.9784929090909091, 0.9089678181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 61}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 99}], {
             RGBColor[
             0.9511285909090909, 0.9630723636363636, 0.9676107272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 154}], {
             RGBColor[
             0.6792438181818181, 0.744766090909091, 0.9515866818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 186}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 203}], {
             RGBColor[
             0.9511285909090909, 0.9630723636363636, 0.9676107272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 244}], {
             RGBColor[
             0.9724789090909091, 0.9784929090909091, 0.9089678181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 264}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 295}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 321}], {
             RGBColor[
             0.9724789090909091, 0.9784929090909091, 0.9089678181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 341}], {
             RGBColor[
             0.9724789090909091, 0.9784929090909091, 0.9089678181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 374}], {
             RGBColor[
             0.9414603636363637, 0.9555905454545455, 0.974571409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 391}], {
             RGBColor[
             0.9289013181818182, 0.8035439545454547, 0.5973691363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 397}], {
             RGBColor[
             0.9760063636363636, 0.9790798181818181, 0.7871392727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 455}], {
             RGBColor[
             0.8000501363636363, 0.8442695454545455, 0.9607025909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 57}], {
             RGBColor[
             0.7293278636363636, 0.7864172727272727, 0.9434209545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 60}], {
             RGBColor[
             0.7551061818181819, 0.8073452727272727, 0.9454503181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 73}], {
             RGBColor[
             0.9734302727272728, 0.954107090909091, 0.6474414545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 91}], {
             RGBColor[
             0.7808844999999999, 0.8282732727272726, 0.9474796818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 136}], {
             RGBColor[
             0.9167686363636363, 0.7233573636363635, 0.5705339999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 200}], {
             RGBColor[
             0.9775793181818182, 0.9827992727272727, 0.9228365454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 256}], {
             RGBColor[
             0.900735090909091, 0.9227762727272728, 0.9588627272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 298}], {
             RGBColor[
             0.916514409090909, 0.9353582727272727, 0.9603677727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 434}], {
             RGBColor[
             0.8551059999999999, 0.8870454545454545, 0.954337409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 92}], {
             RGBColor[
             0.8632309545454545, 0.8926025454545454, 0.9180815909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 110}], {
             RGBColor[
             0.8484933181818182, 0.8821137272727273, 0.9655309545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 132}], {
             RGBColor[0.8662555, 0.8938532727272728, 0.8679570454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 324}], {
             RGBColor[
             0.8663794545454546, 0.8923789090909091, 0.7550061818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 342}], {
             RGBColor[
             0.6392455454545455, 0.7165231818181819, 0.9657576363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 360}], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 457}], {
             RGBColor[
             0.8617186818181818, 0.8919771818181819, 0.9431438636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 494}], {
             RGBColor[
             0.8164330909090909, 0.8571181818181818, 0.9821801363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 60}], {
             RGBColor[
             0.513467409090909, 0.6158950000000001, 0.9548411818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 73}], {
             RGBColor[
             0.7317914999999999, 0.7626568181818181, 0.6568323181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 91}], {
             RGBColor[
             0.5392457272727271, 0.6368229999999999, 0.9568705454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 131}], {
             RGBColor[
             0.7161024999999999, 0.7765538181818181, 0.9658080454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 136}], {
             RGBColor[
             0.6751298636363635, 0.5319070909090907, 0.5799248636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 234}], {
             RGBColor[
             0.7218260454545454, 0.7290409999999999, 0.6181184090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 240}], {
             RGBColor[
             0.7402223636363636, 0.7909401818181818, 0.7028428636363634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 434}], {
             RGBColor[
             0.6134672272727272, 0.6955951818181818, 0.9637282727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 495}], {
             RGBColor[0.7064342727272727, 0.769072, 0.9727687272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 74}], {
             RGBColor[
             0.6923454999999998, 0.7569099545454544, 0.964036409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 115}], {
             RGBColor[
             0.5412670454545454, 0.6381071363636363, 0.9571282727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 144}], {
             RGBColor[
             0.6826772727272726, 0.7494281363636363, 0.9709970909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 145}], {
             RGBColor[
             0.7167203636363635, 0.7735812272727272, 0.8552689545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 215}], {
             RGBColor[
             0.5154887272727271, 0.6171791363636361, 0.955098909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 375}], {
             RGBColor[
             0.6455549545454544, 0.474096090909091, 0.5728385454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 402}], {
             RGBColor[
             0.6511186363636362, 0.7242641363636362, 0.9679869999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 417}], {
             RGBColor[
             0.6923454999999998, 0.7569099545454544, 0.964036409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 87}], {
             RGBColor[
             0.9651876363636362, 0.9610515454545454, 0.6891854999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 91}], {
             RGBColor[
             0.7676591363636363, 0.818409818181818, 0.9698667727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 188}], {
             RGBColor[
             0.9697726363636363, 0.9749586363636363, 0.839579681818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 200}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 228}], {
             RGBColor[
             0.8921227272727272, 0.6322624545454545, 0.5822413181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 256}], {
             RGBColor[
             0.8875097272727273, 0.9129128181818182, 0.9812498181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 279}], {
             RGBColor[
             0.7161024999999999, 0.7765538181818181, 0.9658080454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 287}], {
             RGBColor[
             0.9697726363636363, 0.9749586363636363, 0.839579681818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 298}], {
             RGBColor[
             0.9032890454545454, 0.9254948181818181, 0.9827548636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 335}], {
             RGBColor[
             0.9190683636363636, 0.9380768181818182, 0.9842599090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 409}], {
             RGBColor[
             0.6726311363636364, 0.7398343636363636, 0.9627802272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 468}], {
             RGBColor[
             0.7161024999999999, 0.7765538181818181, 0.9658080454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 73}], {
             RGBColor[
             0.7575698181818182, 0.7835848181818182, 0.6588616818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 131}], {
             RGBColor[
             0.7418808181818182, 0.7974818181818182, 0.9678374090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.7009081818181818, 0.5528350909090909, 0.5819542272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 240}], {
             RGBColor[
             0.7660006818181819, 0.8118681818181819, 0.704872227272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 434}], {
             RGBColor[
             0.6392455454545455, 0.7165231818181819, 0.9657576363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 495}], {
             RGBColor[0.732212590909091, 0.79, 0.9747980909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 99}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 154}], {
             RGBColor[0.6858565, 0.7496978181818181, 0.9403931363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 178}], {
             RGBColor[0.978413, 0.970915, 0.6667984090909089]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{61, 186}], {
             RGBColor[
             0.916514409090909, 0.9353582727272727, 0.9603677727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 203}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 244}], {
             RGBColor[
             0.9790915909090909, 0.9834246363636363, 0.8977742727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 264}], {
             RGBColor[
             0.8308844090909091, 0.8681233636363637, 0.9519232272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 288}], {
             RGBColor[
             0.900735090909091, 0.9227762727272728, 0.9588627272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 295}], {
             RGBColor[
             0.916514409090909, 0.9353582727272727, 0.9603677727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 321}], {
             RGBColor[
             0.9790915909090909, 0.9834246363636363, 0.8977742727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 341}], {
             RGBColor[
             0.9790915909090909, 0.9834246363636363, 0.8977742727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 391}], {
             RGBColor[0.935514, 0.808475681818182, 0.5861755909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 397}], {
             RGBColor[
             0.9826190454545454, 0.9840115454545455, 0.775945727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 455}], {
             RGBColor[
             0.8066628181818182, 0.8492012727272727, 0.9495090454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 96}], {
             RGBColor[
             0.8176590454545454, 0.8582599090909091, 0.9743103181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 108}], {
             RGBColor[
             0.842033909090909, 0.8749311818181817, 0.8655428636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 110}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 157}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 190}], {
             RGBColor[
             0.8417789090909091, 0.8726462727272728, 0.7113451363636362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 356}], {
             RGBColor[0.8079908181818182, 0.850778090909091, 0.981271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 378}], {
             RGBColor[0.7922115, 0.8381960909090909, 0.9797659545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 72}], {
             RGBColor[0.8662555, 0.8938532727272728, 0.8679570454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 159}], {
             RGBColor[0.8418806363636363, 0.8771819999999999, 0.9767245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 166}], {
             RGBColor[
             0.7634669545454544, 0.8151454545454545, 0.977058909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 222}], {
             RGBColor[
             0.8663794545454546, 0.8923789090909091, 0.7550061818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 239}], {
             RGBColor[
             0.8667584090909091, 0.8931894545454545, 0.7962530454545452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 272}], {
             RGBColor[
             0.8632309545454545, 0.8926025454545454, 0.9180815909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 344}], {
             RGBColor[
             0.8484933181818182, 0.8821137272727273, 0.9655309545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 387}], {
             RGBColor[
             0.5699958636363636, 0.6588757272727273, 0.9607004545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 435}], {
             RGBColor[
             0.8551059999999999, 0.8870454545454545, 0.954337409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 439}], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 453}], {
             RGBColor[
             0.8667584090909091, 0.8931894545454545, 0.7962530454545452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 74}], {
             RGBColor[
             0.9032890454545454, 0.9254948181818181, 0.9827548636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 115}], {
             RGBColor[0.7522105909090908, 0.806692, 0.9758467272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 170}], {
             RGBColor[
             0.916514409090909, 0.9353582727272727, 0.9603677727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 215}], {
             RGBColor[
             0.7264322727272725, 0.7857639999999999, 0.9738173636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 223}], {
             RGBColor[
             0.8248753636363635, 0.8634582727272726, 0.9830892727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 268}], {
             RGBColor[
             0.9261516363636363, 0.9415407272727272, 0.8990496818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 86}], {
             RGBColor[
             0.9926352272727272, 0.9910045454545455, 0.7558745000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 177}], {
             RGBColor[
             0.8913589545454546, 0.9129220909090909, 0.8399140909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 194}], {
             RGBColor[
             0.9601044090909091, 0.9674768181818182, 0.8465403636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 290}], {
             RGBColor[
             0.8671373636363636, 0.8939999999999999, 0.8374999090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 297}], {
             RGBColor[
             0.9950293636363636, 0.9917766363636363, 0.7003550909090913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 350}], {
             RGBColor[0.9941475, 0.9916299090909091, 0.7308122272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 412}], {
             RGBColor[
             0.9697726363636363, 0.9749586363636363, 0.839579681818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 484}], {
             RGBColor[0.9938925000000001, 0.989345, 0.5766145]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{66, 114}], {
             RGBColor[0.8132755, 0.854133, 0.9383155]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{66, 128}], {
             RGBColor[
             0.8178123181818182, 0.8560090909090909, 0.8631286818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 179}], {
             RGBColor[
             0.5018383181818181, 0.6039559545454545, 0.954615909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 245}], {
             RGBColor[
             0.8183152272727272, 0.8553452727272728, 0.7914246818181816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 255}], {
             RGBColor[
             0.8091264545454546, 0.8254408181818182, 0.662920409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 260}], {
             RGBColor[0.7837692272727272, 0.831856, 0.9788568181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 294}], {
             RGBColor[
             0.8178123181818182, 0.8560090909090909, 0.8631286818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 299}], {
             RGBColor[0.799161, 0.791825, 0.6242065]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 312}], {
             RGBColor[
             0.6665805909090909, 0.739457090909091, 0.9674021818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 327}], {
             RGBColor[0.8132755, 0.854133, 0.9383155]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{66, 334}], {
             RGBColor[
             0.8000501363636363, 0.8442695454545455, 0.9607025909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 385}], {
             RGBColor[
             0.7364312727272728, 0.7941100000000001, 0.9743416818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 415}], {
             RGBColor[
             0.8000501363636363, 0.8442695454545455, 0.9607025909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 446}], {
             RGBColor[0.7837692272727272, 0.831856, 0.9788568181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 119}], {
             RGBColor[
             0.6392455454545455, 0.7165231818181819, 0.9657576363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 120}], {
             RGBColor[
             0.8632309545454545, 0.8926025454545454, 0.9180815909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 124}], {
             RGBColor[
             0.7848744545454546, 0.8319541818181818, 0.9791700454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 363}], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 381}], {
             RGBColor[
             0.8667584090909091, 0.8931894545454545, 0.7962530454545452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 95}], {
             RGBColor[
             0.5830717727272727, 0.6471878636363637, 0.8975097272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 286}], {
             RGBColor[
             0.5860963181818182, 0.6484385909090908, 0.8473851818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 319}], {
             RGBColor[
             0.43486459090909085`, 0.5318865909090909, 0.9516586818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 330}], {
             RGBColor[0.410643, 0.5129645, 0.9492445]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{68, 352}], {
             RGBColor[
             0.5845840454545455, 0.6478132272727273, 0.8724474545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 357}], {
             RGBColor[0.536273909090909, 0.6117035, 0.9616082727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 367}], {
             RGBColor[0.567445, 0.5842544999999999, 0.608463]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{68, 368}], {
             RGBColor[
             0.5683341363636363, 0.6366990454545454, 0.9449590909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 375}], {
             RGBColor[
             0.5149309090909091, 0.3489534545454548, 0.5649547727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 450}], {
             RGBColor[
             0.3848646818181817, 0.4920364999999999, 0.9472151363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 492}], {
             RGBColor[
             0.4590861818181818, 0.5508086818181818, 0.9540728636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 101}], {
             RGBColor[
             0.9887288181818181, 0.9896070909090909, 0.8364561818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 103}], {
             RGBColor[
             0.9895624999999999, 0.9777228181818182, 0.5804180454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 129}], {
             RGBColor[
             0.6575772727272726, 0.7223544545454545, 0.8515004090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 204}], {
             RGBColor[
             0.9118845909090909, 0.9295840909090909, 0.8724823636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 209}], {
             RGBColor[
             0.9118845909090909, 0.9295840909090909, 0.8724823636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 231}], {
             RGBColor[
             0.9164975909090909, 0.6489337272727271, 0.4734738636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 233}], {
             RGBColor[
             0.9887288181818181, 0.9896070909090909, 0.8364561818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 259}], {
             RGBColor[
             0.9887288181818181, 0.9896070909090909, 0.8364561818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 275}], {
             RGBColor[
             0.9821161363636364, 0.9846753636363637, 0.8476497272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 306}], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 331}], {
             RGBColor[
             0.9933895909090908, 0.9900088181818183, 0.6483185000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 346}], {
             RGBColor[
             0.8904770909090909, 0.9127753636363636, 0.8703712272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 348}], {
             RGBColor[
             0.9930106363636364, 0.9891982727272728, 0.6070716363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 355}], {
             RGBColor[
             0.7662556818181818, 0.814153090909091, 0.8590699545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 372}], {
             RGBColor[
             0.9108949545454545, 0.605869409090909, 0.4681087727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 404}], {
             RGBColor[
             0.9164975909090909, 0.6489337272727271, 0.4734738636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 418}], {
             RGBColor[
             0.842033909090909, 0.8749311818181817, 0.8655428636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 431}], {
             RGBColor[
             0.9821161363636364, 0.9846753636363637, 0.8476497272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 444}], {
             RGBColor[
             0.9592225454545454, 0.967330090909091, 0.8769975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 486}], {
             RGBColor[
             0.9592225454545454, 0.967330090909091, 0.8769975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 76}], {
             RGBColor[
             0.8176590454545454, 0.8582599090909091, 0.9743103181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 111}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 130}], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 175}], {
             RGBColor[
             0.6726311363636364, 0.7398343636363636, 0.9627802272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 182}], {
             RGBColor[
             0.8875097272727273, 0.9129128181818182, 0.9812498181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 208}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[
             0.9697726363636363, 0.9749586363636363, 0.839579681818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 351}], {
             RGBColor[
             0.9658662272727272, 0.9735611818181817, 0.9201613636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 359}], {
             RGBColor[
             0.7161024999999999, 0.7765538181818181, 0.9658080454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 371}], {
             RGBColor[
             0.8661022272727272, 0.8961040909090909, 0.9791386818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 403}], {
             RGBColor[
             0.8176590454545454, 0.8582599090909091, 0.9743103181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 442}], {
             RGBColor[
             0.9160401818181818, 0.7702394545454547, 0.6033488181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 463}], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 483}], {
             RGBColor[0.8418806363636363, 0.8771819999999999, 0.9767245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 135}], {
             RGBColor[0.978413, 0.970915, 0.6667984090909089]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{71, 153}], {
             RGBColor[
             0.9239607727272727, 0.9284057272727272, 0.6931360909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 169}], {
             RGBColor[
             0.9900654090909091, 0.9770589999999999, 0.5087140454545451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 172}], {
             RGBColor[
             0.9718003181818182, 0.9659832727272727, 0.6779919545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 197}], {
             RGBColor[
             0.7367742272727272, 0.7794647272727272, 0.6761892727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 201}], {
             RGBColor[
             0.9904443636363636, 0.9778695454545454, 0.5499609090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 211}], {
             RGBColor[
             0.9895624999999999, 0.9777228181818182, 0.5804180454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 236}], {
             RGBColor[
             0.9880502272727272, 0.9770974545454545, 0.605480318181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 289}], {
             RGBColor[
             0.9239607727272727, 0.9284057272727272, 0.6931360909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 308}], {
             RGBColor[
             0.8383307727272726, 0.8611708181818181, 0.6846915454545452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 362}], {
             RGBColor[
             0.8625523636363637, 0.8800929090909091, 0.6871057272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 369}], {
             RGBColor[
             0.8625523636363637, 0.8800929090909091, 0.6871057272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 466}], {
             RGBColor[
             0.9904443636363636, 0.9778695454545454, 0.5499609090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 470}], {
             RGBColor[0.9651876363636362, 0.9610515454545454, 0.6891855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 493}], {
             RGBColor[
             0.9555194090909092, 0.9535697272727273, 0.6961461818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 128}], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 159}], {
             RGBColor[
             0.9688907727272726, 0.9748119090909091, 0.8700368181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 179}], {
             RGBColor[
             0.6772916363636363, 0.7394300454545454, 0.852756590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 222}], {
             RGBColor[
             0.9933895909090908, 0.9900088181818183, 0.6483185000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 245}], {
             RGBColor[
             0.9937685454545454, 0.9908193636363636, 0.6895653636363634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 294}], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 344}], {
             RGBColor[
             0.9755034545454545, 0.9797436363636364, 0.8588432727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 438}], {
             RGBColor[
             0.9755034545454545, 0.9797436363636364, 0.8588432727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 439}], {
             RGBColor[0.8662555, 0.8938532727272728, 0.8679570454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 453}], {
             RGBColor[
             0.9937685454545454, 0.9908193636363636, 0.6895653636363634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 91}], {
             RGBColor[
             0.7833481363636363, 0.8045128181818181, 0.6608910454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 136}], {
             RGBColor[
             0.9192322727272727, 0.6995969090909089, 0.2839453636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 200}], {
             RGBColor[
             0.9800429545454545, 0.9590388181818181, 0.636247909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 240}], {
             RGBColor[
             0.9843247727272728, 0.9586300000000001, 0.40686336363636333`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 256}], {
             RGBColor[
             0.9031987272727273, 0.8990158181818182, 0.6722740909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 298}], {
             RGBColor[
             0.9189780454545454, 0.9115978181818181, 0.6737791363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 434}], {
             RGBColor[0.8575696363636364, 0.863285, 0.6677487727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 115}], {
             RGBColor[
             0.7934374545454546, 0.8393378181818182, 0.9718961363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 144}], {
             RGBColor[
             0.9348476818181818, 0.9506588181818182, 0.9857649545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 215}], {
             RGBColor[
             0.7676591363636363, 0.818409818181818, 0.9698667727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 268}], {
             RGBColor[
             0.9673784999999999, 0.9741865454545455, 0.8950990909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 402}], {
             RGBColor[
             0.9032890454545454, 0.9254948181818181, 0.9827548636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 417}], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 104}], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 125}], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 147}], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 303}], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 310}], {
             RGBColor[
             0.9688907727272726, 0.9748119090909091, 0.8700368181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 323}], {
             RGBColor[
             0.9434432272727272, 0.9547480909090909, 0.8754924545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 379}], {
             RGBColor[
             0.9434432272727272, 0.9547480909090909, 0.8754924545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 400}], {
             RGBColor[
             0.9895624999999999, 0.9777228181818182, 0.5804180454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 408}], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 111}], {
             RGBColor[
             0.8374970909090909, 0.8730550909090908, 0.9407296818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 130}], {
             RGBColor[
             0.8176590454545454, 0.8582599090909091, 0.9743103181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 175}], {
             RGBColor[
             0.5457742727272727, 0.6399536363636363, 0.9582862727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.7606528636363636, 0.8130320909090909, 0.9767558636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 351}], {
             RGBColor[
             0.8390093636363636, 0.8736804545454545, 0.9156674090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 359}], {
             RGBColor[
             0.5892456363636362, 0.6766730909090908, 0.9613140909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 371}], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 460}], {
             RGBColor[
             0.8405216363636363, 0.8743058181818182, 0.8906051363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 463}], {
             RGBColor[
             0.8176590454545454, 0.8582599090909091, 0.9743103181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 483}], {
             RGBColor[
             0.7150237727272727, 0.7773012727272727, 0.9722305454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 87}], {
             RGBColor[
             0.9850256818181817, 0.9758467272727273, 0.6556048636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 184}], {
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 253}], {
             RGBColor[
             0.9857042727272727, 0.9883563636363637, 0.8865807272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 287}], {
             RGBColor[
             0.9896106818181818, 0.9897538181818182, 0.8059990454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 301}], {
             RGBColor[
             0.8859402727272727, 0.9108992727272727, 0.9455580454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 336}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 354}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 388}], {
             RGBColor[
             0.6727548181818181, 0.7375539545454545, 0.9279434090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 409}], {
             RGBColor[
             0.6924691818181818, 0.7546295454545455, 0.9291995909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 436}], {
             RGBColor[0.9700774999999999, 0.925423, 0.597534]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{77, 473}], {
             RGBColor[
             0.9887288181818181, 0.9896070909090909, 0.8364561818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 154}], {
             RGBColor[
             0.697508909090909, 0.7558418181818182, 0.7823087727272725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 171}], {
             RGBColor[0.990744, 0.9895686363636363, 0.7396899090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 192}], {
             RGBColor[0.9922562727272727, 0.990194, 0.7146276363636361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.9597254545454545, 0.9666662727272728, 0.8052934999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 219}], {
             RGBColor[
             0.9760063636363636, 0.9790798181818181, 0.7871392727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 258}], {
             RGBColor[
             0.8667584090909091, 0.8931894545454545, 0.7962530454545452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 262}], {
             RGBColor[
             0.9346694999999999, 0.7578741363636362, 0.41766349999999974`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 376}], {
             RGBColor[
             0.8425368181818181, 0.8742673636363636, 0.7938388636363634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 497}], {
             RGBColor[
             0.9800999545454545, 0.9434431818181819, 0.4700001363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 127}], {
             RGBColor[0.6781735, 0.7395767727272726, 0.8222994545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 147}], {
             RGBColor[
             0.9911229545454545, 0.9903791818181817, 0.7809367727272729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 184}], {
             RGBColor[
             0.9601044090909091, 0.9674768181818182, 0.8465403636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 221}], {
             RGBColor[
             0.9697726363636363, 0.9749586363636363, 0.839579681818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 234}], {
             RGBColor[
             0.9754961818181818, 0.9274458181818181, 0.4918900454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 253}], {
             RGBColor[
             0.9911229545454545, 0.9903791818181817, 0.7809367727272729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 301}], {
             RGBColor[
             0.8913589545454546, 0.9129220909090909, 0.8399140909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 316}], {
             RGBColor[
             0.7413592272727272, 0.7933718181818181, 0.8265834545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 336}], {
             RGBColor[
             0.9896106818181818, 0.9897538181818182, 0.8059990454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 388}], {
             RGBColor[0.6781735, 0.7395767727272726, 0.8222994545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 436}], {
             RGBColor[
             0.9754961818181818, 0.9274458181818181, 0.4918900454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 81}], {
             RGBColor[
             0.6978878636363637, 0.7566523636363636, 0.8235556363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 171}], {
             RGBColor[
             0.6939814545454546, 0.7552549090909091, 0.9041373181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 192}], {
             RGBColor[
             0.6954937272727273, 0.7558802727272728, 0.8790750454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 208}], {
             RGBColor[0.6858565, 0.7496978181818181, 0.9403931363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 219}], {
             RGBColor[
             0.6792438181818181, 0.744766090909091, 0.9515866818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 238}], {
             RGBColor[
             0.6978878636363637, 0.7566523636363636, 0.8235556363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 251}], {
             RGBColor[
             0.6971299545454546, 0.7550312727272728, 0.7410619090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 258}], {
             RGBColor[
             0.5699958636363636, 0.6588757272727273, 0.9607004545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 272}], {
             RGBColor[
             0.6939814545454546, 0.7552549090909091, 0.9041373181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 293}], {
             RGBColor[
             0.6314042727272726, 0.7071885454545455, 0.9667308181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 403}], {
             RGBColor[
             0.5457742727272727, 0.6399536363636363, 0.9582862727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 447}], {
             RGBColor[0.3810319999999999, 0.5044525, 0.9455]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{80, 471}], {
             RGBColor[
             0.6939814545454546, 0.7552549090909091, 0.9041373181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 483}], {
             RGBColor[
             0.5699958636363636, 0.6588757272727273, 0.9607004545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 497}], {
             RGBColor[
             0.6833374090909091, 0.7091294545454547, 0.6344475454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 121}], {
             RGBColor[0.6781735, 0.7395767727272726, 0.8222994545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.9697726363636363, 0.9749586363636363, 0.839579681818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 208}], {
             RGBColor[0.982998, 0.9848220909090909, 0.8171925909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 213}], {
             RGBColor[
             0.9896106818181818, 0.9897538181818182, 0.8059990454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 251}], {
             RGBColor[
             0.9942714545454545, 0.9901555454545454, 0.617861363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 442}], {
             RGBColor[
             0.9412969090909091, 0.7870574545454547, 0.4641242272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 447}], {
             RGBColor[0.6781735, 0.7395767727272726, 0.8222994545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 454}], {
             RGBColor[
             0.7929158636363636, 0.835227818181818, 0.830642181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 500}], {
             RGBColor[
             0.7176022272727272, 0.7737279545454544, 0.8248118181818184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 126}], {
             RGBColor[0.6595294545454544, 0.7276904999999999, 0.9503305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 149}], {
             RGBColor[
             0.5745030909090908, 0.6607222272727272, 0.9618584545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 173}], {
             RGBColor[
             0.36131763636363623`, 0.48737690909090897`, 0.9442438181818181]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 242}], {
             RGBColor[
             0.526059909090909, 0.6228780454545454, 0.9570300909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 249}], {
             RGBColor[
             0.6274692272727271, 0.7026949545454545, 0.9669796818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 269}], {
             RGBColor[
             0.6661421363636363, 0.7326222272727272, 0.9391369545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 282}], {
             RGBColor[
             0.6274692272727271, 0.7026949545454545, 0.9669796818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 323}], {
             RGBColor[
             0.6274692272727271, 0.7026949545454545, 0.9669796818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 384}], {
             RGBColor[
             0.6529167727272727, 0.7227587727272726, 0.9615240454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 411}], {
             RGBColor[
             0.6686057727272727, 0.7088617727272727, 0.6525483181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 419}], {
             RGBColor[
             0.6757793636363636, 0.7388046818181817, 0.8778188636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 499}], {
             RGBColor[
             0.526059909090909, 0.6228780454545454, 0.9570300909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 97}], {
             RGBColor[
             0.5959105909090909, 0.6775309545454545, 0.9639695909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 163}], {
             RGBColor[0.9073477727272727, 0.927708, 0.9476691818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 207}], {
             RGBColor[0.9073477727272727, 0.927708, 0.9476691818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 209}], {
             RGBColor[0.8305035454545455, 0.867685, 0.9836953636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 231}], {
             RGBColor[
             0.8351165454545455, 0.5870346363636363, 0.5846868636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 233}], {
             RGBColor[0.9073477727272727, 0.927708, 0.9476691818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 257}], {
             RGBColor[
             0.8982160000000001, 0.8822079090909092, 0.6529171363636366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 317}], {
             RGBColor[
             0.6848746363636364, 0.7522540000000001, 0.9702829545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 326}], {
             RGBColor[
             0.7106529545454545, 0.7731819999999999, 0.9723123181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 343}], {
             RGBColor[
             0.8462828636363636, 0.8802669999999999, 0.9852004090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 346}], {
             RGBColor[
             0.8090960454545455, 0.8508762727272727, 0.9815842272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 355}], {
             RGBColor[
             0.6848746363636364, 0.7522540000000001, 0.9702829545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 395}], {
             RGBColor[0.5047152727272728, 0.5865395, 0.9585981818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 440}], {
             RGBColor[
             0.6590963181818181, 0.7313259999999999, 0.9682535909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 89}], {
             RGBColor[
             0.8875097272727273, 0.9129128181818182, 0.9812498181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 176}], {
             RGBColor[
             0.9688907727272726, 0.9748119090909091, 0.8700368181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 244}], {
             RGBColor[
             0.9658662272727272, 0.9735611818181817, 0.9201613636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 245}], {
             RGBColor[
             0.9693936818181818, 0.9741480909090909, 0.798332818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 260}], {
             RGBColor[
             0.9348476818181818, 0.9506588181818182, 0.9857649545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 261}], {
             RGBColor[
             0.9552221818181819, 0.9274357272727274, 0.650471590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 262}], {
             RGBColor[
             0.9097917272727272, 0.7418666818181816, 0.5981349545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 299}], {
             RGBColor[
             0.9502394545454544, 0.9106278181818181, 0.6311146363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 328}], {
             RGBColor[0.9686357727272727, 0.972527, 0.7158390909090907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 376}], {
             RGBColor[
             0.8176590454545454, 0.8582599090909091, 0.9743103181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 391}], {
             RGBColor[
             0.9222886363636363, 0.7986122272727274, 0.6085626818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 407}], {
             RGBColor[
             0.8661022272727272, 0.8961040909090909, 0.9791386818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 448}], {
             RGBColor[
             0.9348476818181818, 0.9506588181818182, 0.9857649545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 455}], {
             RGBColor[
             0.7934374545454546, 0.8393378181818182, 0.9718961363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 475}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 478}], {
             RGBColor[
             0.9688907727272726, 0.9748119090909091, 0.8700368181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 482}], {
             RGBColor[
             0.9511285909090909, 0.9630723636363636, 0.9676107272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 146}], {
             RGBColor[
             0.8390093636363636, 0.8736804545454545, 0.9156674090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 166}], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 239}], {
             RGBColor[
             0.8425368181818181, 0.8742673636363636, 0.7938388636363634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 332}], {
             RGBColor[
             0.7764321818181817, 0.8256140909090908, 0.9782609090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 387}], {
             RGBColor[
             0.5457742727272727, 0.6399536363636363, 0.9582862727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 489}], {
             RGBColor[
             0.8390093636363636, 0.8736804545454545, 0.9156674090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 177}], {
             RGBColor[0.8889648181818182, 0.91215, 0.8954334999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 194}], {
             RGBColor[
             0.9577102727272727, 0.9667047272727274, 0.9020597727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 220}], {
             RGBColor[
             0.6954937272727273, 0.7558802727272728, 0.8790750454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 254}], {
             RGBColor[
             0.9917533636363636, 0.9908578181818182, 0.7863316363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 290}], {
             RGBColor[
             0.8647432272727272, 0.8932279090909091, 0.893019318181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 297}], {
             RGBColor[
             0.9926352272727272, 0.9910045454545455, 0.7558745000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 350}], {
             RGBColor[
             0.9917533636363636, 0.9908578181818182, 0.7863316363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 377}], {
             RGBColor[
             0.9326543181818181, 0.7579125909090908, 0.5144297727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 412}], {
             RGBColor[
             0.9673784999999999, 0.9741865454545455, 0.8950990909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 426}], {
             RGBColor[
             0.8647432272727272, 0.8932279090909091, 0.893019318181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 476}], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 91}], {
             RGBColor[0.7883308636363635, 0.8213207272727272, 0.680248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 161}], {
             RGBColor[
             0.9808766363636363, 0.9471545454545454, 0.3802097727272725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 184}], {
             RGBColor[
             0.9555194090909092, 0.9535697272727273, 0.6961461818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 228}], {
             RGBColor[
             0.9127944545454545, 0.6351733636363635, 0.29262254545454536`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 253}], {
             RGBColor[
             0.9865379545454545, 0.9764720909090909, 0.6305425909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 256}], {
             RGBColor[
             0.9081814545454545, 0.9158237272727272, 0.6916310454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 285}], {
             RGBColor[
             0.8867739545454545, 0.8990149999999999, 0.689519909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 287}], {
             RGBColor[
             0.9904443636363636, 0.9778695454545454, 0.5499609090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 336}], {
             RGBColor[
             0.9850256818181817, 0.9758467272727273, 0.6556048636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 354}], {
             RGBColor[0.9651876363636362, 0.9610515454545454, 0.6891855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 388}], {
             RGBColor[
             0.6735884999999999, 0.7256696818181817, 0.6719052727272725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 409}], {
             RGBColor[
             0.6933028636363636, 0.7427452727272728, 0.6731614545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 436}], {
             RGBColor[
             0.9709111818181818, 0.9135387272727272, 0.34149586363636353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 473}], {
             RGBColor[
             0.9895624999999999, 0.9777228181818182, 0.5804180454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 133}], {
             RGBColor[
             0.9896864545454546, 0.9762484545454546, 0.4674671818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 241}], {
             RGBColor[
             0.6735884999999999, 0.7256696818181817, 0.6719052727272725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 271}], {
             RGBColor[
             0.9718003181818182, 0.9659832727272727, 0.6779919545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 304}], {
             RGBColor[
             0.9718003181818182, 0.9659832727272727, 0.6779919545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 307}], {
             RGBColor[
             0.9718003181818182, 0.9659832727272727, 0.6779919545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 311}], {
             RGBColor[0.9651876363636362, 0.9610515454545454, 0.6891855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 337}], {
             RGBColor[
             0.9895624999999999, 0.9777228181818182, 0.5804180454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 423}], {
             RGBColor[
             0.9858593636363636, 0.9639624545454545, 0.3995667272727271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 427}], {
             RGBColor[
             0.9718003181818182, 0.9659832727272727, 0.6779919545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 433}], {
             RGBColor[
             0.9808766363636363, 0.9471545454545454, 0.3802097727272725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 465}], {
             RGBColor[
             0.9900654090909091, 0.9770589999999999, 0.5087140454545451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 469}], {
             RGBColor[
             0.9239607727272727, 0.9284057272727272, 0.6931360909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 176}], {
             RGBColor[
             0.9118845909090909, 0.9295840909090909, 0.8724823636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 178}], {
             RGBColor[
             0.9081814545454545, 0.9158237272727272, 0.6916310454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 244}], {
             RGBColor[
             0.9088600454545455, 0.9283333636363637, 0.9226069090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 261}], {
             RGBColor[
             0.8982160000000001, 0.8822079090909092, 0.6529171363636366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 262}], {
             RGBColor[0.8527855454545454, 0.6966388636363635, 0.6005805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 299}], {
             RGBColor[0.8932332727272727, 0.8654, 0.6335601818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 328}], {
             RGBColor[
             0.911629590909091, 0.9272991818181819, 0.7182846363636362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 376}], {
             RGBColor[
             0.7606528636363636, 0.8130320909090909, 0.9767558636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 391}], {
             RGBColor[
             0.8652824545454546, 0.7533844090909092, 0.6110082272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 407}], {
             RGBColor[
             0.8090960454545455, 0.8508762727272727, 0.9815842272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 448}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 455}], {
             RGBColor[
             0.7364312727272728, 0.7941100000000001, 0.9743416818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 475}], {
             RGBColor[
             0.900735090909091, 0.9227762727272728, 0.9588627272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 478}], {
             RGBColor[
             0.9118845909090909, 0.9295840909090909, 0.8724823636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 482}], {
             RGBColor[
             0.8941224090909091, 0.9178445454545454, 0.9700562727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 137}], {
             RGBColor[
             0.9256810454545454, 0.9430085454545454, 0.9730663636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 148}], {
             RGBColor[
             0.8406546818181817, 0.8760402727272727, 0.9845943181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 229}], {
             RGBColor[
             0.9419309545454545, 0.9541227272727273, 0.9005547272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 232}], {
             RGBColor[
             0.9397400909090909, 0.9409877272727272, 0.6946411363636362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 263}], {
             RGBColor[0.8778414999999999, 0.9054309999999999, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 267}], {
             RGBColor[
             0.8843441818181818, 0.7218028636363635, 0.6035905909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 280}], {
             RGBColor[
             0.6906549545454544, 0.7564899999999999, 0.9712636818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 342}], {
             RGBColor[0.7164332727272728, 0.777418, 0.9732930454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 393}], {
             RGBColor[
             0.9443250909090909, 0.9548948181818182, 0.8450353181818184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 480}], {
             RGBColor[
             0.9256810454545454, 0.9430085454545454, 0.9730663636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 485}], {
             RGBColor[
             0.6471835909090908, 0.7197705454545454, 0.9682358636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 200}], {
             RGBColor[0.7874971818181817, 0.833205, 0.9362861363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 228}], {
             RGBColor[
             0.7152659545454544, 0.49253163636363617`, 0.5733038181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 256}], {
             RGBColor[
             0.7106529545454545, 0.7731819999999999, 0.9723123181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 287}], {
             RGBColor[
             0.7929158636363636, 0.835227818181818, 0.830642181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 298}], {
             RGBColor[
             0.7264322727272725, 0.7857639999999999, 0.9738173636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 336}], {
             RGBColor[0.7874971818181817, 0.833205, 0.9362861363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 132}], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 250}], {
             RGBColor[
             0.9790915909090909, 0.9834246363636363, 0.8977742727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 342}], {
             RGBColor[0.7632311363636364, 0.8129023636363637, 0.9091945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 356}], {
             RGBColor[0.956198, 0.9660793636363636, 0.9271220454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 365}], {
             RGBColor[
             0.9715897727272726, 0.9260483636363637, 0.5724717272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 457}], {
             RGBColor[
             0.9857042727272727, 0.9883563636363637, 0.8865807272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 485}], {
             RGBColor[
             0.6939814545454546, 0.7552549090909091, 0.9041373181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 494}], {
             RGBColor[0.9404186818181818, 0.9534973636363636, 0.925617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 141}], {
             RGBColor[
             0.9884738181818182, 0.9873221818181819, 0.6822584545454543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 151}], {
             RGBColor[
             0.9800429545454545, 0.9590388181818181, 0.636247909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 160}], {
             RGBColor[
             0.9850256818181817, 0.9758467272727273, 0.6556048636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 167}], {
             RGBColor[
             0.8617186818181818, 0.8919771818181819, 0.9431438636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 172}], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 201}], {
             RGBColor[
             0.9896106818181818, 0.9897538181818182, 0.8059990454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 218}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 235}], {
             RGBColor[
             0.9884738181818182, 0.9873221818181819, 0.6822584545454543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 236}], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 274}], {
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 284}], {
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 289}], {
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 300}], {
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 305}], {
             RGBColor[
             0.9896106818181818, 0.9897538181818182, 0.8059990454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 308}], {
             RGBColor[
             0.8374970909090909, 0.8730550909090908, 0.9407296818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 389}], {
             RGBColor[
             0.9884738181818182, 0.9873221818181819, 0.6822584545454543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 432}], {
             RGBColor[
             0.9800429545454545, 0.9590388181818181, 0.636247909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 456}], {
             RGBColor[
             0.9888527727272727, 0.9881327272727274, 0.7235053181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 493}], {
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 123}], {
             RGBColor[0.8778414999999999, 0.9054309999999999, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 139}], {
             RGBColor[
             0.9419309545454545, 0.9541227272727273, 0.9005547272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 158}], {
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 193}], {
             RGBColor[0.8620621818181818, 0.892849, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 401}], {
             RGBColor[
             0.9434432272727272, 0.9547480909090909, 0.8754924545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 410}], {
             RGBColor[0.8778414999999999, 0.9054309999999999, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 428}], {
             RGBColor[
             0.9322937272727272, 0.9479402727272728, 0.9618728181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 437}], {
             RGBColor[
             0.6471835909090908, 0.7197705454545454, 0.9682358636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 122}], {
             RGBColor[
             0.8147877727272728, 0.8547583636363636, 0.9132532272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 185}], {
             RGBColor[0.956198, 0.9660793636363636, 0.9271220454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 212}], {
             RGBColor[
             0.9724789090909091, 0.9784929090909091, 0.9089678181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 224}], {
             RGBColor[
             0.8390093636363636, 0.8736804545454545, 0.9156674090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 286}], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 319}], {
             RGBColor[
             0.8390093636363636, 0.8736804545454545, 0.9156674090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 330}], {
             RGBColor[
             0.8147877727272728, 0.8547583636363636, 0.9132532272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 357}], {
             RGBColor[0.9404186818181818, 0.9534973636363636, 0.925617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 367}], {
             RGBColor[
             0.9715897727272726, 0.9260483636363637, 0.5724717272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 368}], {
             RGBColor[
             0.9724789090909091, 0.9784929090909091, 0.9089678181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 492}], {
             RGBColor[
             0.8632309545454545, 0.8926025454545454, 0.9180815909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 110}], {
             RGBColor[
             0.9511285909090909, 0.9630723636363636, 0.9676107272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 136}], {
             RGBColor[
             0.9035432727272726, 0.7134939090909089, 0.592921090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.9511285909090909, 0.9630723636363636, 0.9676107272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 240}], {
             RGBColor[0.9686357727272727, 0.972527, 0.7158390909090907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 360}], {
             RGBColor[0.8418806363636363, 0.8771819999999999, 0.9767245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 457}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 163}], {
             RGBColor[
             0.6727548181818181, 0.7375539545454546, 0.9279434090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 207}], {
             RGBColor[
             0.6727548181818181, 0.7375539545454546, 0.9279434090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 209}], {
             RGBColor[
             0.5959105909090909, 0.6775309545454545, 0.9639695909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 231}], {
             RGBColor[
             0.6005235909090908, 0.3968805909090908, 0.5649610909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 233}], {
             RGBColor[
             0.6727548181818181, 0.7375539545454546, 0.9279434090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 257}], {
             RGBColor[
             0.6636230454545454, 0.6920538636363637, 0.6331913636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 281}], {
             RGBColor[
             0.6529167727272727, 0.7227587727272726, 0.9615240454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 317}], {
             RGBColor[
             0.4502816818181818, 0.5620999545454546, 0.9505571818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 322}], {
             RGBColor[
             0.526059909090909, 0.6228780454545454, 0.9570300909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 326}], {
             RGBColor[
             0.4760599999999998, 0.5830279545454544, 0.9525865454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 343}], {
             RGBColor[
             0.6116899090909089, 0.6901129545454544, 0.9654746363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 355}], {
             RGBColor[
             0.4502816818181818, 0.5620999545454546, 0.9505571818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 395}], {
             RGBColor[
             0.2701223181818181, 0.3963854545454545, 0.9388724090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 440}], {
             RGBColor[
             0.42450336363636354`, 0.5411719545454544, 0.9485278181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 105}], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 276}], {
             RGBColor[
             0.6346672727272727, 0.7023821363636364, 0.925596409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 347}], {
             RGBColor[
             0.8374970909090909, 0.8730550909090908, 0.9407296818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 382}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 425}], {
             RGBColor[
             0.8374970909090909, 0.8730550909090908, 0.9407296818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 462}], {
             RGBColor[
             0.7617188636363637, 0.8122770000000001, 0.9342567727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 131}], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 143}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 178}], {
             RGBColor[
             0.9651876363636362, 0.9610515454545454, 0.6891854999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 186}], {
             RGBColor[
             0.9032890454545454, 0.9254948181818181, 0.9827548636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 277}], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 288}], {
             RGBColor[
             0.8875097272727273, 0.9129128181818182, 0.9812498181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 295}], {
             RGBColor[
             0.9032890454545454, 0.9254948181818181, 0.9827548636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 313}], {
             RGBColor[
             0.8176590454545454, 0.8582599090909091, 0.9743103181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 321}], {
             RGBColor[
             0.9658662272727272, 0.9735611818181817, 0.9201613636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 341}], {
             RGBColor[
             0.9658662272727272, 0.9735611818181817, 0.9201613636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 373}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 498}], {
             RGBColor[
             0.8921227272727272, 0.6322624545454545, 0.5822413181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 203}], {
             RGBColor[
             0.9693936818181818, 0.9741480909090909, 0.798332818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 257}], {
             RGBColor[
             0.9800999545454545, 0.9434431818181819, 0.4700001363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 264}], {
             RGBColor[
             0.8425368181818181, 0.8742673636363636, 0.7938388636363634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 281}], {
             RGBColor[
             0.9693936818181818, 0.9741480909090909, 0.798332818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 324}], {
             RGBColor[0.9938925000000001, 0.989345, 0.5766145]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{100, 360}], {
             RGBColor[
             0.8667584090909091, 0.8931894545454545, 0.7962530454545452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 374}], {
             RGBColor[
             0.9597254545454545, 0.9666662727272728, 0.8052934999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 397}], {
             RGBColor[
             0.9942714545454545, 0.9901555454545454, 0.6178613636363632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 457}], {
             RGBColor[
             0.9892317272727272, 0.9889432727272727, 0.7647521818181816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 103}], {
             RGBColor[
             0.9850256818181817, 0.9758467272727273, 0.6556048636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 129}], {
             RGBColor[
             0.6530404545454545, 0.7204783636363636, 0.9266872272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[0.9073477727272727, 0.927708, 0.9476691818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 276}], {
             RGBColor[
             0.6346672727272727, 0.7023821363636364, 0.925596409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 306}], {
             RGBColor[
             0.9857042727272727, 0.9883563636363637, 0.8865807272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 331}], {
             RGBColor[
             0.9888527727272727, 0.9881327272727274, 0.7235053181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 347}], {
             RGBColor[
             0.8374970909090909, 0.8730550909090908, 0.9407296818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 390}], {
             RGBColor[
             0.9896106818181818, 0.9897538181818182, 0.8059990454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 431}], {
             RGBColor[
             0.9775793181818182, 0.9827992727272727, 0.9228365454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 486}], {
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 134}], {
             RGBColor[
             0.9081814545454545, 0.9158237272727272, 0.6916310454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 174}], {
             RGBColor[0.9073477727272727, 0.927708, 0.9476691818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 210}], {
             RGBColor[
             0.6848746363636364, 0.7522540000000001, 0.9702829545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 225}], {
             RGBColor[
             0.8941224090909091, 0.9178445454545454, 0.9700562727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 247}], {
             RGBColor[
             0.5959105909090909, 0.6775309545454545, 0.9639695909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 252}], {
             RGBColor[
             0.8875097272727273, 0.9129128181818182, 0.9812498181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 278}], {
             RGBColor[
             0.900735090909091, 0.9227762727272728, 0.9588627272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 309}], {
             RGBColor[
             0.8875097272727273, 0.9129128181818182, 0.9812498181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 383}], {
             RGBColor[
             0.8941224090909091, 0.9178445454545454, 0.9700562727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 393}], {
             RGBColor[
             0.9127664545454546, 0.9297308181818182, 0.8420252272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 451}], {
             RGBColor[
             0.6590963181818181, 0.7313259999999999, 0.9682535909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 480}], {
             RGBColor[
             0.8941224090909091, 0.9178445454545454, 0.9700562727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 129}], {
             RGBColor[
             0.6538741363636363, 0.7085940909090909, 0.6706490909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 204}], {
             RGBColor[
             0.9081814545454545, 0.9158237272727272, 0.6916310454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 209}], {
             RGBColor[
             0.9081814545454545, 0.9158237272727272, 0.6916310454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 231}], {
             RGBColor[
             0.9127944545454545, 0.6351733636363635, 0.29262254545454536`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 233}], {
             RGBColor[
             0.9850256818181817, 0.9758467272727273, 0.6556048636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 259}], {
             RGBColor[
             0.9850256818181817, 0.9758467272727273, 0.6556048636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 275}], {
             RGBColor[0.978413, 0.970915, 0.6667984090909089]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{103, 326}], {
             RGBColor[0.7883308636363635, 0.8213207272727272, 0.680248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 346}], {
             RGBColor[
             0.8867739545454545, 0.8990149999999999, 0.689519909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 348}], {
             RGBColor[0.9893075, 0.9754379090909091, 0.4262203181818179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 355}], {
             RGBColor[
             0.7625525454545454, 0.8003927272727274, 0.6782186363636362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 390}], {
             RGBColor[
             0.9904443636363636, 0.9778695454545454, 0.5499609090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 404}], {
             RGBColor[
             0.9127944545454545, 0.6351733636363635, 0.29262254545454536`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 431}], {
             RGBColor[0.978413, 0.970915, 0.6667984090909089]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{103, 443}], {
             RGBColor[
             0.9718003181818182, 0.9659832727272727, 0.6779919545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 444}], {
             RGBColor[
             0.9555194090909092, 0.9535697272727273, 0.6961461818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 486}], {
             RGBColor[
             0.9555194090909092, 0.9535697272727273, 0.6961461818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 125}], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 147}], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 242}], {
             RGBColor[
             0.842033909090909, 0.8749311818181817, 0.8655428636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 303}], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 310}], {
             RGBColor[
             0.9688907727272726, 0.9748119090909091, 0.8700368181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 323}], {
             RGBColor[
             0.9434432272727272, 0.9547480909090909, 0.8754924545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 379}], {
             RGBColor[
             0.9434432272727272, 0.9547480909090909, 0.8754924545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 408}], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 109}], {
             RGBColor[
             0.916404409090909, 0.746798409090909, 0.5869414090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 205}], {
             RGBColor[
             0.9414603636363637, 0.9555905454545455, 0.974571409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 230}], {
             RGBColor[
             0.9739911818181818, 0.9791182727272727, 0.8839055454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 382}], {
             RGBColor[
             0.9511285909090909, 0.9630723636363636, 0.9676107272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 425}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 462}], {
             RGBColor[0.7484935, 0.8024135454545456, 0.9566438636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 484}], {
             RGBColor[
             0.9752484545454545, 0.9774587272727273, 0.7046455454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 156}], {
             RGBColor[
             0.9032890454545454, 0.9254948181818181, 0.9827548636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 227}], {
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 265}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 270}], {
             RGBColor[0.7522105909090908, 0.806692, 0.9758467272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 329}], {
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 479}], {
             RGBColor[
             0.8462828636363636, 0.8802669999999999, 0.9852004090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 153}], {
             RGBColor[
             0.7264322727272725, 0.7857639999999999, 0.9738173636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 170}], {
             RGBColor[
             0.7808844999999999, 0.8282732727272726, 0.9474796818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 197}], {
             RGBColor[
             0.5392457272727271, 0.6368229999999999, 0.9568705454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 214}], {
             RGBColor[
             0.7890094545454545, 0.8338303636363635, 0.9112238636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 223}], {
             RGBColor[
             0.6892454545454544, 0.7563732727272726, 0.9702011818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 236}], {
             RGBColor[
             0.7905217272727272, 0.8344557272727272, 0.8861615909090907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 289}], {
             RGBColor[
             0.7264322727272725, 0.7857639999999999, 0.9738173636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 314}], {
             RGBColor[0.7874971818181817, 0.833205, 0.9362861363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 411}], {
             RGBColor[
             0.7833481363636363, 0.8045128181818181, 0.6608910454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 466}], {
             RGBColor[
             0.7929158636363636, 0.835227818181818, 0.830642181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 470}], {
             RGBColor[
             0.7676591363636363, 0.818409818181818, 0.9698667727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 113}], {
             RGBColor[
             0.9755034545454545, 0.9797436363636364, 0.8588432727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 190}], {
             RGBColor[
             0.9930106363636364, 0.9891982727272728, 0.6070716363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 315}], {
             RGBColor[
             0.9755034545454545, 0.9797436363636364, 0.8588432727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 349}], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 364}], {
             RGBColor[
             0.9821161363636364, 0.9846753636363637, 0.8476497272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 378}], {
             RGBColor[
             0.9434432272727272, 0.9547480909090909, 0.8754924545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 380}], {
             RGBColor[
             0.9821161363636364, 0.9846753636363637, 0.8476497272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 416}], {
             RGBColor[
             0.9118845909090909, 0.9295840909090909, 0.8724823636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 452}], {
             RGBColor[
             0.8178123181818182, 0.8560090909090909, 0.8631286818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 487}], {
             RGBColor[0.697006, 0.7565056363636364, 0.8540127727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 164}], {
             RGBColor[
             0.7329349545454544, 0.6021358636363634, 0.5891974545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 180}], {
             RGBColor[
             0.7587132727272727, 0.6230638636363635, 0.5912268181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 205}], {
             RGBColor[0.9001235, 0.7343848636363635, 0.6050956363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 230}], {
             RGBColor[
             0.9326543181818181, 0.7579125909090908, 0.5144297727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 382}], {
             RGBColor[
             0.9097917272727272, 0.7418666818181816, 0.5981349545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 413}], {
             RGBColor[
             0.6181925909090908, 0.506484818181818, 0.5808547272727271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 474}], {
             RGBColor[
             0.8685648636363635, 0.7092208636363635, 0.6020855454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 490}], {
             RGBColor[
             0.7587132727272727, 0.6230638636363635, 0.5912268181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 157}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 356}], {
             RGBColor[
             0.9414603636363637, 0.9555905454545455, 0.974571409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 360}], {
             RGBColor[
             0.8484933181818182, 0.8821137272727273, 0.9655309545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 457}], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 494}], {
             RGBColor[
             0.9256810454545454, 0.9430085454545454, 0.9730663636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 130}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 175}], {
             RGBColor[
             0.6924691818181818, 0.7546295454545455, 0.9291995909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 182}], {
             RGBColor[0.9073477727272727, 0.927708, 0.9476691818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 351}], {
             RGBColor[
             0.9857042727272727, 0.9883563636363637, 0.8865807272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 359}], {
             RGBColor[0.7359405454545453, 0.791349, 0.9322274090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 371}], {
             RGBColor[
             0.8859402727272727, 0.9108992727272727, 0.9455580454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 460}], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 463}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 483}], {
             RGBColor[
             0.8617186818181818, 0.8919771818181819, 0.9431438636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 163}], {
             RGBColor[
             0.8374970909090909, 0.8730550909090908, 0.9407296818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 175}], {
             RGBColor[
             0.5457742727272727, 0.6399536363636363, 0.9582862727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 207}], {
             RGBColor[
             0.8374970909090909, 0.8730550909090908, 0.9407296818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 238}], {
             RGBColor[
             0.8429157727272727, 0.8750779090909091, 0.8350857272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 266}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 293}], {
             RGBColor[
             0.7764321818181817, 0.8256140909090908, 0.9782609090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 317}], {
             RGBColor[
             0.6150239545454546, 0.697601090909091, 0.9633434545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 343}], {
             RGBColor[
             0.7764321818181817, 0.8256140909090908, 0.9782609090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 359}], {
             RGBColor[
             0.5892456363636362, 0.6766730909090908, 0.9613140909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 403}], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 440}], {
             RGBColor[
             0.5892456363636362, 0.6766730909090908, 0.9613140909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 445}], {
             RGBColor[
             0.5457742727272727, 0.6399536363636363, 0.9582862727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 463}], {
             RGBColor[
             0.8176590454545454, 0.8582599090909091, 0.9743103181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 471}], {
             RGBColor[
             0.8390093636363636, 0.8736804545454545, 0.9156674090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 483}], {
             RGBColor[
             0.7150237727272727, 0.7773012727272727, 0.9722305454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 190}], {
             RGBColor[
             0.9752484545454545, 0.9774587272727273, 0.7046455454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 315}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 349}], {
             RGBColor[
             0.9755034545454545, 0.9797436363636364, 0.8588432727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 353}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 364}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 378}], {
             RGBColor[
             0.9256810454545454, 0.9430085454545454, 0.9730663636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 380}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 487}], {
             RGBColor[
             0.6792438181818181, 0.744766090909091, 0.9515866818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 128}], {
             RGBColor[
             0.9887288181818181, 0.9896070909090909, 0.8364561818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 138}], {
             RGBColor[
             0.8374970909090909, 0.8730550909090908, 0.9407296818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 179}], {
             RGBColor[
             0.6727548181818181, 0.7375539545454545, 0.9279434090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 255}], {
             RGBColor[
             0.9800429545454545, 0.9590388181818181, 0.636247909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 294}], {
             RGBColor[
             0.9887288181818181, 0.9896070909090909, 0.8364561818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 296}], {
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 312}], {
             RGBColor[
             0.8374970909090909, 0.8730550909090908, 0.9407296818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 327}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 334}], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 385}], {
             RGBColor[0.9073477727272727, 0.927708, 0.9476691818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 415}], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 446}], {
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 144}], {
             RGBColor[0.7837692272727272, 0.831856, 0.9788568181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 215}], {
             RGBColor[
             0.6165806818181817, 0.6996069999999999, 0.9629586363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 223}], {
             RGBColor[
             0.7150237727272727, 0.7773012727272728, 0.9722305454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 268}], {
             RGBColor[
             0.8163000454545455, 0.8553837272727274, 0.8881909545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 402}], {
             RGBColor[0.7522105909090908, 0.806692, 0.9758467272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 417}], {
             RGBColor[
             0.7934374545454546, 0.8393378181818182, 0.9718961363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 143}], {
             RGBColor[
             0.8859402727272727, 0.9108992727272727, 0.9455580454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 165}], {
             RGBColor[
             0.7634669545454544, 0.8151454545454545, 0.977058909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 185}], {
             RGBColor[
             0.8564339999999999, 0.8886222727272728, 0.9860993636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 187}], {
             RGBColor[
             0.8913589545454546, 0.9129220909090909, 0.8399140909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 224}], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 277}], {
             RGBColor[
             0.8661022272727272, 0.8961040909090909, 0.9791386818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 313}], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 333}], {
             RGBColor[
             0.7634669545454544, 0.8151454545454545, 0.977058909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 358}], {
             RGBColor[0.8906010454545454, 0.911301, 0.7574203636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 361}], {
             RGBColor[
             0.8793275909090909, 0.9059675454545455, 0.9567515909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 386}], {
             RGBColor[
             0.8859402727272727, 0.9108992727272727, 0.9455580454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 441}], {
             RGBColor[
             0.8793275909090909, 0.9059675454545455, 0.9567515909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 140}], {
             RGBColor[0.697006, 0.7565056363636364, 0.8540127727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 155}], {
             RGBColor[0.6858565, 0.7496978181818181, 0.9403931363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 156}], {
             RGBColor[
             0.6726311363636364, 0.7398343636363636, 0.9627802272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 198}], {
             RGBColor[0.6858565, 0.7496978181818181, 0.9403931363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 270}], {
             RGBColor[
             0.5215526818181818, 0.6210315454545454, 0.9558720909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 479}], {
             RGBColor[
             0.6156249545454546, 0.6946065454545455, 0.9652257727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 152}], {
             RGBColor[0.990744, 0.9895686363636363, 0.7396899090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 187}], {
             RGBColor[
             0.9911229545454545, 0.9903791818181817, 0.7809367727272729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.9724789090909091, 0.9784929090909091, 0.9089678181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 255}], {
             RGBColor[
             0.9815552272727273, 0.9596641818181818, 0.6111856363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 260}], {
             RGBColor[0.956198, 0.9660793636363636, 0.9271220454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 292}], {
             RGBColor[
             0.9088600454545455, 0.9283333636363637, 0.9226069090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 399}], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 446}], {
             RGBColor[0.956198, 0.9660793636363636, 0.9271220454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 464}], {
             RGBColor[0.7632311363636364, 0.8129023636363637, 0.9091945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 481}], {
             RGBColor[0.956198, 0.9660793636363636, 0.9271220454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 496}], {
             RGBColor[
             0.7374528181818181, 0.7919743636363636, 0.9071651363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 120}], {
             RGBColor[0.7632311363636364, 0.8129023636363637, 0.9091945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 124}], {
             RGBColor[
             0.6848746363636364, 0.7522540000000001, 0.9702829545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 363}], {
             RGBColor[
             0.6392455454545455, 0.7165231818181819, 0.9657576363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 364}], {
             RGBColor[
             0.7551061818181819, 0.8073452727272727, 0.9454503181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 381}], {
             RGBColor[
             0.7667585909090909, 0.8134892727272728, 0.7873659545454543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 416}], {
             RGBColor[
             0.6848746363636364, 0.7522540000000001, 0.9702829545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 124}], {
             RGBColor[
             0.9088600454545455, 0.9283333636363637, 0.9226069090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 315}], {
             RGBColor[
             0.9724789090909091, 0.9784929090909091, 0.9089678181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 363}], {
             RGBColor[
             0.8632309545454545, 0.8926025454545454, 0.9180815909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 381}], {
             RGBColor[0.990744, 0.9895686363636363, 0.7396899090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 196}], {
             RGBColor[
             0.526059909090909, 0.6228780454545454, 0.9570300909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.6727548181818181, 0.7375539545454546, 0.9279434090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 307}], {
             RGBColor[0.6595294545454544, 0.7276904999999999, 0.9503305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 337}], {
             RGBColor[
             0.6772916363636363, 0.7394300454545455, 0.852756590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 420}], {
             RGBColor[
             0.6742670909090909, 0.7381793181818181, 0.9028811363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 427}], {
             RGBColor[0.6595294545454544, 0.7276904999999999, 0.9503305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 442}], {
             RGBColor[
             0.6244410454545455, 0.534857590909091, 0.5860685909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 447}], {
             RGBColor[
             0.36131763636363623`, 0.48737690909090897`, 0.9442438181818181]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 454}], {
             RGBColor[
             0.4760599999999998, 0.5830279545454544, 0.9525865454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 489}], {
             RGBColor[
             0.6742670909090909, 0.7381793181818181, 0.9028811363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 500}], {
             RGBColor[
             0.40074636363636346`, 0.5215280909090907, 0.9467561818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 185}], {
             RGBColor[0.7837692272727272, 0.831856, 0.9788568181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 212}], {
             RGBColor[
             0.8000501363636363, 0.8442695454545455, 0.9607025909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 216}], {
             RGBColor[0.7522105909090908, 0.806692, 0.9758467272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 217}], {
             RGBColor[0.7522105909090908, 0.806692, 0.9758467272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 224}], {
             RGBColor[
             0.6665805909090909, 0.739457090909091, 0.9674021818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 286}], {
             RGBColor[
             0.8178123181818182, 0.8560090909090909, 0.8631286818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 319}], {
             RGBColor[
             0.6665805909090909, 0.739457090909091, 0.9674021818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 330}], {
             RGBColor[0.642359, 0.720535, 0.964988]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 357}], {
             RGBColor[
             0.767989909090909, 0.8192740000000001, 0.9773517727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 492}], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 139}], {
             RGBColor[
             0.9261516363636363, 0.9415407272727272, 0.8990496818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 158}], {
             RGBColor[0.8778414999999999, 0.9054309999999999, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 193}], {
             RGBColor[
             0.8462828636363636, 0.8802669999999999, 0.9852004090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 401}], {
             RGBColor[
             0.927663909090909, 0.9421660909090909, 0.8739874090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 410}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 422}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 428}], {
             RGBColor[
             0.916514409090909, 0.9353582727272727, 0.9603677727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 437}], {
             RGBColor[
             0.6314042727272726, 0.7071885454545455, 0.9667308181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 363}], {
             RGBColor[
             0.7848744545454546, 0.8319541818181818, 0.9791700454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 381}], {
             RGBColor[0.9123875, 0.9289202727272727, 0.8007783636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 416}], {
             RGBColor[0.8305035454545455, 0.867685, 0.9836953636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.8904770909090909, 0.9127753636363636, 0.8703712272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 173}], {
             RGBColor[
             0.6772916363636363, 0.7394300454545454, 0.852756590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 242}], {
             RGBColor[
             0.842033909090909, 0.8749311818181817, 0.8655428636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 249}], {
             RGBColor[
             0.9434432272727272, 0.9547480909090909, 0.8754924545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 269}], {
             RGBColor[
             0.9821161363636364, 0.9846753636363637, 0.8476497272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 282}], {
             RGBColor[
             0.9434432272727272, 0.9547480909090909, 0.8754924545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 305}], {
             RGBColor[0.9941475, 0.9916299090909091, 0.7308122272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 310}], {
             RGBColor[
             0.9688907727272726, 0.9748119090909091, 0.8700368181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 323}], {
             RGBColor[
             0.9434432272727272, 0.9547480909090909, 0.8754924545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 406}], {
             RGBColor[
             0.927663909090909, 0.9421660909090909, 0.8739874090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 408}], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 419}], {
             RGBColor[
             0.9917533636363636, 0.9908578181818182, 0.7863316363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 173}], {
             RGBColor[0.6595294545454544, 0.7276904999999999, 0.9503305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 249}], {
             RGBColor[
             0.9256810454545454, 0.9430085454545454, 0.9730663636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 269}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 282}], {
             RGBColor[
             0.9256810454545454, 0.9430085454545454, 0.9730663636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 340}], {
             RGBColor[
             0.9256810454545454, 0.9430085454545454, 0.9730663636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 384}], {
             RGBColor[
             0.9511285909090909, 0.9630723636363636, 0.9676107272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 414}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 449}], {
             RGBColor[
             0.9256810454545454, 0.9430085454545454, 0.9730663636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 499}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 184}], {
             RGBColor[
             0.6432485454545454, 0.7152769545454545, 0.9684847272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 221}], {
             RGBColor[
             0.6529167727272727, 0.7227587727272726, 0.9615240454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 253}], {
             RGBColor[
             0.6742670909090909, 0.7381793181818181, 0.9028811363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 301}], {
             RGBColor[
             0.5745030909090908, 0.6607222272727272, 0.9618584545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 303}], {
             RGBColor[
             0.6772916363636363, 0.7394300454545455, 0.852756590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 316}], {
             RGBColor[
             0.42450336363636354`, 0.5411719545454544, 0.9485278181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 138}], {
             RGBColor[
             0.842033909090909, 0.8749311818181817, 0.8655428636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 179}], {
             RGBColor[
             0.6772916363636363, 0.7394300454545454, 0.852756590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 222}], {
             RGBColor[
             0.9933895909090908, 0.9900088181818183, 0.6483185000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 245}], {
             RGBColor[
             0.9937685454545454, 0.9908193636363636, 0.6895653636363634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 294}], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 296}], {
             RGBColor[
             0.927663909090909, 0.9421660909090909, 0.8739874090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 312}], {
             RGBColor[
             0.842033909090909, 0.8749311818181817, 0.8655428636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 385}], {
             RGBColor[
             0.9118845909090909, 0.9295840909090909, 0.8724823636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 415}], {
             RGBColor[
             0.9755034545454545, 0.9797436363636364, 0.8588432727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 438}], {
             RGBColor[
             0.9755034545454545, 0.9797436363636364, 0.8588432727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 439}], {
             RGBColor[0.8662555, 0.8938532727272728, 0.8679570454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 204}], {
             RGBColor[
             0.5761962272727272, 0.6604553636363636, 0.9627134090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 275}], {
             RGBColor[
             0.6464277727272727, 0.7155466363636362, 0.9378807727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 276}], {
             RGBColor[
             0.30351572727272724`, 0.43512949999999995`, 0.9406406363636364]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 306}], {
             RGBColor[
             0.6545527272727272, 0.7211037272727272, 0.9016249545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 331}], {
             RGBColor[
             0.6577012272727272, 0.7208800909090909, 0.7385495454545457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 346}], {
             RGBColor[
             0.5547887272727272, 0.6436466363636363, 0.9606022727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 348}], {
             RGBColor[
             0.6573222727272727, 0.7200695454545454, 0.6973026818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 355}], {
             RGBColor[0.43056731818181815`, 0.5450243636363636, 0.949301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 431}], {
             RGBColor[
             0.6464277727272727, 0.7155466363636362, 0.9378807727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 444}], {
             RGBColor[
             0.6235341818181819, 0.6982013636363635, 0.9672285454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 486}], {
             RGBColor[
             0.6235341818181819, 0.6982013636363635, 0.9672285454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 175}], {
             RGBColor[
             0.6726311363636364, 0.7398343636363636, 0.9627802272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 182}], {
             RGBColor[
             0.8875097272727273, 0.9129128181818182, 0.9812498181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 208}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 238}], {
             RGBColor[
             0.9697726363636363, 0.9749586363636363, 0.839579681818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 241}], {
             RGBColor[
             0.6529167727272727, 0.7227587727272726, 0.9615240454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 351}], {
             RGBColor[
             0.9658662272727272, 0.9735611818181817, 0.9201613636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 371}], {
             RGBColor[
             0.8661022272727272, 0.8961040909090909, 0.9791386818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 442}], {
             RGBColor[
             0.9160401818181818, 0.7702394545454547, 0.6033488181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 483}], {
             RGBColor[0.8418806363636363, 0.8771819999999999, 0.9767245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 186}], {
             RGBColor[
             0.9032890454545454, 0.9254948181818181, 0.9827548636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 234}], {
             RGBColor[
             0.9502394545454544, 0.9106278181818181, 0.6311146363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 373}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 434}], {
             RGBColor[0.8418806363636363, 0.8771819999999999, 0.9767245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 449}], {
             RGBColor[
             0.9190683636363636, 0.9380768181818182, 0.9842599090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 495}], {
             RGBColor[
             0.9348476818181818, 0.9506588181818182, 0.9857649545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 250}], {
             RGBColor[
             0.9821161363636364, 0.9846753636363637, 0.8476497272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 356}], {
             RGBColor[
             0.9592225454545454, 0.967330090909091, 0.8769975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 365}], {
             RGBColor[
             0.9746143181818181, 0.9272990909090909, 0.5223471818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 457}], {
             RGBColor[
             0.9887288181818181, 0.9896070909090909, 0.8364561818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 494}], {
             RGBColor[
             0.9434432272727272, 0.9547480909090909, 0.8754924545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 191}], {
             RGBColor[
             0.9054162727272728, 0.5613307272727273, 0.34979281818181834`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 237}], {
             RGBColor[
             0.9054162727272728, 0.5613307272727273, 0.34979281818181834`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 241}], {
             RGBColor[
             0.6774155909090909, 0.7379556818181818, 0.7398057272727274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 271}], {
             RGBColor[
             0.9756274090909092, 0.9782692727272728, 0.7458924090909093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 304}], {
             RGBColor[
             0.9756274090909092, 0.9782692727272728, 0.7458924090909093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 311}], {
             RGBColor[
             0.9690147272727272, 0.9733375454545454, 0.7570859545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 351}], {
             RGBColor[
             0.9903650454545454, 0.988758090909091, 0.6984430454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 366}], {
             RGBColor[0.8906010454545454, 0.911301, 0.7574203636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 371}], {
             RGBColor[0.8906010454545454, 0.911301, 0.7574203636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 405}], {
             RGBColor[
             0.993134590909091, 0.9877239090909091, 0.49412077272727273`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 423}], {
             RGBColor[
             0.9896864545454546, 0.9762484545454546, 0.4674671818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 429}], {
             RGBColor[0.9822400909090909, 0.983201, 0.7346988636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 469}], {
             RGBColor[
             0.9277878636363637, 0.9406917272727273, 0.7610365454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 488}], {
             RGBColor[
             0.6774155909090909, 0.7379556818181818, 0.7398057272727274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 174}], {
             RGBColor[
             0.9850256818181817, 0.9758467272727273, 0.6556048636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 210}], {
             RGBColor[
             0.7625525454545454, 0.8003927272727274, 0.6782186363636362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 225}], {
             RGBColor[
             0.9718003181818182, 0.9659832727272727, 0.6779919545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 247}], {
             RGBColor[
             0.6735884999999999, 0.7256696818181817, 0.6719052727272725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 252}], {
             RGBColor[0.9651876363636362, 0.9610515454545454, 0.6891855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 278}], {
             RGBColor[0.978413, 0.970915, 0.6667984090909089]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{134, 309}], {
             RGBColor[0.9651876363636362, 0.9610515454545454, 0.6891855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 424}], {
             RGBColor[
             0.9858593636363636, 0.9639624545454545, 0.3995667272727271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 169}], {
             RGBColor[
             0.9826190454545454, 0.9840115454545455, 0.775945727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 211}], {
             RGBColor[
             0.9821161363636364, 0.9846753636363637, 0.8476497272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 362}], {
             RGBColor[
             0.8551059999999999, 0.8870454545454545, 0.954337409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 369}], {
             RGBColor[
             0.8551059999999999, 0.8870454545454545, 0.954337409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 466}], {
             RGBColor[0.982998, 0.9848220909090909, 0.8171925909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 470}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 240}], {
             RGBColor[
             0.9276631363636363, 0.7278802727272726, 0.3299559090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 434}], {
             RGBColor[0.800908, 0.6325352727272726, 0.5908413181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 148}], {
             RGBColor[
             0.872714909090909, 0.9010358181818181, 0.9679451363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 156}], {
             RGBColor[
             0.9511285909090909, 0.9630723636363636, 0.9676107272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 227}], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 229}], {
             RGBColor[
             0.9739911818181818, 0.9791182727272727, 0.8839055454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 263}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 265}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 267}], {
             RGBColor[
             0.916404409090909, 0.746798409090909, 0.5869414090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 280}], {
             RGBColor[
             0.7227151818181817, 0.7814855454545454, 0.9546144999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 393}], {
             RGBColor[
             0.9763853181818182, 0.9798903636363636, 0.8283861363636366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 424}], {
             RGBColor[
             0.9718003181818182, 0.9659832727272727, 0.6779919545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 485}], {
             RGBColor[
             0.6792438181818181, 0.744766090909091, 0.9515866818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 179}], {
             RGBColor[
             0.526059909090909, 0.6228780454545454, 0.9570300909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 222}], {
             RGBColor[
             0.8421578636363636, 0.8734568181818182, 0.7525920000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 294}], {
             RGBColor[
             0.842033909090909, 0.8749311818181817, 0.8655428636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 296}], {
             RGBColor[
             0.7764321818181817, 0.8256140909090908, 0.9782609090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 339}], {
             RGBColor[
             0.8176590454545454, 0.8582599090909091, 0.9743103181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 385}], {
             RGBColor[
             0.7606528636363636, 0.8130320909090909, 0.9767558636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 415}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 438}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 158}], {
             RGBColor[
             0.9419309545454545, 0.9541227272727273, 0.9005547272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 247}], {
             RGBColor[
             0.6757793636363636, 0.7388046818181818, 0.8778188636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 278}], {
             RGBColor[
             0.9806038636363636, 0.9840500000000001, 0.8727119999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 401}], {
             RGBColor[
             0.9917533636363636, 0.9908578181818182, 0.7863316363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 410}], {
             RGBColor[
             0.9261516363636363, 0.9415407272727272, 0.8990496818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 428}], {
             RGBColor[
             0.9806038636363636, 0.9840500000000001, 0.8727119999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 437}], {
             RGBColor[
             0.6954937272727273, 0.7558802727272728, 0.8790750454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 451}], {
             RGBColor[
             0.7389650909090908, 0.7925997272727272, 0.8821028636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 198}], {
             RGBColor[
             0.9821161363636364, 0.9846753636363637, 0.8476497272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 270}], {
             RGBColor[
             0.8178123181818182, 0.8560090909090909, 0.8631286818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 479}], {
             RGBColor[
             0.9118845909090909, 0.9295840909090909, 0.8724823636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 151}], {
             RGBColor[
             0.9843247727272728, 0.9586300000000001, 0.40686336363636333`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 160}], {
             RGBColor[0.9893075, 0.9754379090909091, 0.4262203181818179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 162}], {
             RGBColor[
             0.8175573181818182, 0.8537241818181819, 0.7089309545454543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 167}], {
             RGBColor[0.8660005, 0.8915683636363636, 0.713759318181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 235}], {
             RGBColor[
             0.9927556363636364, 0.9869133636363637, 0.4528739090909087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 274}], {
             RGBColor[
             0.9589675454545454, 0.9650451818181819, 0.7227997727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 284}], {
             RGBColor[
             0.927408909090909, 0.9398811818181818, 0.7197896818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 300}], {
             RGBColor[
             0.9589675454545454, 0.9650451818181819, 0.7227997727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 345}], {
             RGBColor[0.9686357727272727, 0.972527, 0.7158390909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 389}], {
             RGBColor[
             0.9927556363636364, 0.9869133636363637, 0.4528739090909087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 432}], {
             RGBColor[
             0.9843247727272728, 0.9586300000000001, 0.40686336363636333`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 456}], {
             RGBColor[
             0.993134590909091, 0.9877239090909091, 0.49412077272727273`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 472}], {
             RGBColor[
             0.9927556363636364, 0.9869133636363637, 0.4528739090909087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[
             0.9763853181818182, 0.9798903636363636, 0.8283861363636366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 161}], {
             RGBColor[
             0.9668175909090909, 0.9491753636363636, 0.6586349999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 183}], {
             RGBColor[
             0.5683341363636364, 0.6366990454545455, 0.9449590909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 254}], {
             RGBColor[
             0.9755034545454545, 0.9797436363636364, 0.8588432727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 285}], {
             RGBColor[
             0.872714909090909, 0.9010358181818181, 0.9679451363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 388}], {
             RGBColor[0.6595294545454544, 0.7276904999999999, 0.9503305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 396}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 473}], {
             RGBColor[
             0.9755034545454545, 0.9797436363636364, 0.8588432727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 477}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 165}], {
             RGBColor[
             0.8617186818181818, 0.8919771818181819, 0.9431438636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 178}], {
             RGBColor[
             0.9850256818181817, 0.9758467272727273, 0.6556048636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 186}], {
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 277}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 288}], {
             RGBColor[0.9073477727272727, 0.927708, 0.9476691818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 313}], {
             RGBColor[
             0.8374970909090909, 0.8730550909090908, 0.9407296818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 321}], {
             RGBColor[
             0.9857042727272727, 0.9883563636363637, 0.8865807272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 373}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 386}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 414}], {
             RGBColor[
             0.9775793181818182, 0.9827992727272727, 0.9228365454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 498}], {
             RGBColor[
             0.9119607727272727, 0.6470576363636362, 0.5486606818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 145}], {
             RGBColor[
             0.9592225454545454, 0.967330090909091, 0.8769975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 215}], {
             RGBColor[
             0.7579909090909089, 0.8109279999999999, 0.9768274545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 246}], {
             RGBColor[
             0.9597254545454545, 0.9666662727272728, 0.8052934999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 375}], {
             RGBColor[
             0.8880571363636365, 0.6678449545454548, 0.5945670909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 402}], {
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 417}], {
             RGBColor[
             0.9348476818181818, 0.9506588181818182, 0.9857649545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 458}], {
             RGBColor[0.8079908181818182, 0.850778090909091, 0.981271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 367}], {
             RGBColor[
             0.9746143181818181, 0.9272990909090909, 0.5223471818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 375}], {
             RGBColor[
             0.9221002272727272, 0.6919980454545457, 0.47883895454545466`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 402}], {
             RGBColor[
             0.927663909090909, 0.9421660909090909, 0.8739874090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 417}], {
             RGBColor[
             0.9688907727272726, 0.9748119090909091, 0.8700368181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 450}], {
             RGBColor[
             0.7920339999999999, 0.8350810909090909, 0.8610993181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 458}], {
             RGBColor[
             0.842033909090909, 0.8749311818181817, 0.8655428636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 461}], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 166}], {
             RGBColor[
             0.8874525454545454, 0.9115246363636363, 0.9204957727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 239}], {
             RGBColor[0.990744, 0.9895686363636363, 0.7396899090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 248}], {
             RGBColor[
             0.8874525454545454, 0.9115246363636363, 0.9204957727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 387}], {
             RGBColor[
             0.6939814545454546, 0.7552549090909091, 0.9041373181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 221}], {
             RGBColor[
             0.9658662272727272, 0.9735611818181817, 0.9201613636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 234}], {
             RGBColor[
             0.9715897727272726, 0.9260483636363637, 0.5724717272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 242}], {
             RGBColor[
             0.8390093636363636, 0.8736804545454545, 0.9156674090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 303}], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 323}], {
             RGBColor[0.9404186818181818, 0.9534973636363636, 0.925617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 449}], {
             RGBColor[0.9404186818181818, 0.9534973636363636, 0.925617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 229}], {
             RGBColor[0.8889648181818182, 0.91215, 0.8954334999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 232}], {
             RGBColor[
             0.8867739545454545, 0.8990149999999999, 0.689519909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 263}], {
             RGBColor[
             0.8248753636363635, 0.8634582727272726, 0.9830892727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 267}], {
             RGBColor[
             0.8313780454545454, 0.6798301363636362, 0.5984693636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 280}], {
             RGBColor[
             0.6376888181818181, 0.7145172727272726, 0.9661424545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 342}], {
             RGBColor[
             0.6634671363636364, 0.7354452727272728, 0.9681718181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 393}], {
             RGBColor[
             0.8913589545454546, 0.9129220909090909, 0.8399140909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 480}], {
             RGBColor[
             0.872714909090909, 0.9010358181818181, 0.9679451363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 485}], {
             RGBColor[
             0.5942174545454545, 0.6777978181818182, 0.9631146363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 173}], {
             RGBColor[
             0.5745030909090908, 0.6607222272727272, 0.9618584545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 242}], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 249}], {
             RGBColor[
             0.8406546818181817, 0.8760402727272727, 0.9845943181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 269}], {
             RGBColor[
             0.8793275909090909, 0.9059675454545455, 0.9567515909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 282}], {
             RGBColor[
             0.8406546818181817, 0.8760402727272727, 0.9845943181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 310}], {
             RGBColor[
             0.8661022272727272, 0.8961040909090909, 0.9791386818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 314}], {
             RGBColor[
             0.8859402727272727, 0.9108992727272727, 0.9455580454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 323}], {
             RGBColor[
             0.8406546818181817, 0.8760402727272727, 0.9845943181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 406}], {
             RGBColor[
             0.8248753636363635, 0.8634582727272726, 0.9830892727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 411}], {
             RGBColor[
             0.8817912272727273, 0.8822070909090909, 0.6701629545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 419}], {
             RGBColor[0.8889648181818182, 0.91215, 0.8954334999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 220}], {
             RGBColor[
             0.6978878636363637, 0.7566523636363636, 0.8235556363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 254}], {
             RGBColor[0.9941475, 0.9916299090909091, 0.7308122272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 325}], {
             RGBColor[
             0.8429157727272727, 0.8750779090909091, 0.8350857272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 392}], {
             RGBColor[
             0.8671373636363636, 0.8939999999999999, 0.8374999090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 412}], {
             RGBColor[
             0.9697726363636363, 0.9749586363636363, 0.839579681818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 426}], {
             RGBColor[
             0.8671373636363636, 0.8939999999999999, 0.8374999090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 473}], {
             RGBColor[0.9941475, 0.9916299090909091, 0.7308122272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 160}], {
             RGBColor[
             0.9808766363636363, 0.9471545454545454, 0.3802097727272725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 162}], {
             RGBColor[
             0.8091264545454546, 0.8254408181818182, 0.662920409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 226}], {
             RGBColor[
             0.9815552272727273, 0.9596641818181818, 0.6111856363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 235}], {
             RGBColor[
             0.9843247727272728, 0.9586300000000001, 0.40686336363636333`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 237}], {
             RGBColor[
             0.8966064545454546, 0.5322368181818182, 0.262535409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 274}], {
             RGBColor[
             0.9505366818181819, 0.9367618181818183, 0.6767892272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 284}], {
             RGBColor[
             0.9189780454545454, 0.9115978181818181, 0.6737791363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 345}], {
             RGBColor[
             0.960204909090909, 0.9442436363636364, 0.6698285454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 389}], {
             RGBColor[
             0.9843247727272728, 0.9586300000000001, 0.40686336363636333`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 456}], {
             RGBColor[
             0.9847037272727273, 0.9594405454545455, 0.44811022727272737`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 472}], {
             RGBColor[
             0.9843247727272728, 0.9586300000000001, 0.40686336363636333`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 195}], {
             RGBColor[
             0.9760063636363636, 0.9790798181818181, 0.7871392727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 216}], {
             RGBColor[
             0.9281668181818181, 0.9415022727272726, 0.8022834090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 217}], {
             RGBColor[
             0.9281668181818181, 0.9415022727272726, 0.8022834090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 292}], {
             RGBColor[0.9123875, 0.9289202727272727, 0.8007783636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 398}], {
             RGBColor[
             0.9760063636363636, 0.9790798181818181, 0.7871392727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 399}], {
             RGBColor[
             0.9937685454545454, 0.9908193636363636, 0.6895653636363634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 464}], {
             RGBColor[
             0.7667585909090909, 0.8134892727272728, 0.7873659545454543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 481}], {
             RGBColor[
             0.9597254545454545, 0.9666662727272728, 0.8052934999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 496}], {
             RGBColor[
             0.7409802727272726, 0.7925612727272726, 0.7853365909090907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 172}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 197}], {
             RGBColor[
             0.6748756363636362, 0.7439079999999999, 0.9697586363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 201}], {
             RGBColor[
             0.9285457727272727, 0.9423128181818181, 0.8435302727272729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 223}], {
             RGBColor[
             0.8248753636363635, 0.8634582727272726, 0.9830892727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 236}], {
             RGBColor[
             0.9261516363636363, 0.9415407272727272, 0.8990496818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 289}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 314}], {
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 411}], {
             RGBColor[
             0.9189780454545454, 0.9115978181818181, 0.6737791363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 466}], {
             RGBColor[
             0.9285457727272727, 0.9423128181818181, 0.8435302727272729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 470}], {
             RGBColor[
             0.9032890454545454, 0.9254948181818181, 0.9827548636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 493}], {
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 199}], {
             RGBColor[
             0.662962909090909, 0.7323525454545454, 0.969740909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[
             0.6726311363636364, 0.7398343636363636, 0.9627802272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 219}], {
             RGBColor[
             0.6792438181818181, 0.744766090909091, 0.9515866818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 244}], {
             RGBColor[
             0.6939814545454546, 0.7552549090909091, 0.9041373181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 295}], {
             RGBColor[
             0.6314042727272726, 0.7071885454545455, 0.9667308181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 341}], {
             RGBColor[
             0.6939814545454546, 0.7552549090909091, 0.9041373181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 374}], {
             RGBColor[
             0.662962909090909, 0.7323525454545454, 0.969740909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 376}], {
             RGBColor[
             0.5457742727272727, 0.6399536363636363, 0.9582862727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 397}], {
             RGBColor[
             0.697508909090909, 0.7558418181818182, 0.7823087727272725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 455}], {
             RGBColor[
             0.5215526818181818, 0.6210315454545454, 0.9558720909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 198}], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 250}], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 365}], {
             RGBColor[
             0.9634648181818182, 0.9204912727272727, 0.6087275454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 394}], {
             RGBColor[
             0.9480730454545454, 0.9605222727272728, 0.9633778636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 467}], {
             RGBColor[
             0.9818611363636364, 0.9823904545454546, 0.6934519999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 479}], {
             RGBColor[
             0.900735090909091, 0.9227762727272728, 0.9588627272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 198}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 227}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 250}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 263}], {
             RGBColor[
             0.9032890454545454, 0.9254948181818181, 0.9827548636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 270}], {
             RGBColor[
             0.7934374545454546, 0.8393378181818182, 0.9718961363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 479}], {
             RGBColor[
             0.8875097272727273, 0.9129128181818182, 0.9812498181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 485}], {
             RGBColor[
             0.6726311363636364, 0.7398343636363636, 0.9627802272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 190}], {
             RGBColor[
             0.9752484545454545, 0.9774587272727273, 0.7046455454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 356}], {
             RGBColor[
             0.9414603636363637, 0.9555905454545455, 0.974571409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 360}], {
             RGBColor[
             0.8484933181818182, 0.8821137272727273, 0.9655309545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.9434432272727272, 0.9547480909090909, 0.8754924545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 193}], {
             RGBColor[0.8620621818181818, 0.892849, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 247}], {
             RGBColor[
             0.6274692272727271, 0.7026949545454545, 0.9669796818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 278}], {
             RGBColor[
             0.9322937272727272, 0.9479402727272728, 0.9618728181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 370}], {
             RGBColor[
             0.8164330909090909, 0.8571181818181818, 0.9821801363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 401}], {
             RGBColor[
             0.9434432272727272, 0.9547480909090909, 0.8754924545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 410}], {
             RGBColor[0.8778414999999999, 0.9054309999999999, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 422}], {
             RGBColor[0.8778414999999999, 0.9054309999999999, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 428}], {
             RGBColor[
             0.9322937272727272, 0.9479402727272728, 0.9618728181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 437}], {
             RGBColor[
             0.6471835909090908, 0.7197705454545454, 0.9682358636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 451}], {
             RGBColor[
             0.6906549545454544, 0.7564899999999999, 0.9712636818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 166}], {
             RGBColor[
             0.8661022272727272, 0.8961040909090909, 0.9791386818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 192}], {
             RGBColor[
             0.9673784999999999, 0.9741865454545455, 0.8950990909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 239}], {
             RGBColor[
             0.9693936818181818, 0.9741480909090909, 0.798332818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 251}], {
             RGBColor[
             0.9690147272727272, 0.9733375454545454, 0.7570859545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 272}], {
             RGBColor[
             0.9658662272727272, 0.9735611818181817, 0.9201613636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 344}], {
             RGBColor[
             0.9511285909090909, 0.9630723636363636, 0.9676107272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 435}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 439}], {
             RGBColor[0.8418806363636363, 0.8771819999999999, 0.9767245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 453}], {
             RGBColor[
             0.9693936818181818, 0.9741480909090909, 0.798332818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 167}], {
             RGBColor[
             0.8625523636363637, 0.8800929090909091, 0.6871057272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 235}], {
             RGBColor[0.9893075, 0.9754379090909091, 0.4262203181818179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 237}], {
             RGBColor[
             0.9015891818181818, 0.5490447272727272, 0.28189236363636355`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 274}], {
             RGBColor[
             0.9555194090909092, 0.9535697272727273, 0.6961461818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 284}], {
             RGBColor[
             0.9239607727272727, 0.9284057272727272, 0.6931360909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 300}], {
             RGBColor[
             0.9555194090909092, 0.9535697272727273, 0.6961461818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 305}], {
             RGBColor[
             0.9904443636363636, 0.9778695454545454, 0.5499609090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 389}], {
             RGBColor[0.9893075, 0.9754379090909091, 0.4262203181818179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 432}], {
             RGBColor[
             0.9808766363636363, 0.9471545454545454, 0.3802097727272725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 460}], {
             RGBColor[
             0.9880502272727272, 0.9770974545454545, 0.605480318181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 183}], {
             RGBColor[
             0.5774104545454546, 0.6178703181818181, 0.647176909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 188}], {
             RGBColor[
             0.9854616363636364, 0.9610616363636364, 0.5306039545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 202}], {
             RGBColor[
             0.9854616363636364, 0.9610616363636364, 0.5306039545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 243}], {
             RGBColor[
             0.960204909090909, 0.9442436363636364, 0.6698285454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 273}], {
             RGBColor[
             0.9847037272727273, 0.9594405454545455, 0.44811022727272737`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 279}], {
             RGBColor[
             0.7317914999999999, 0.7626568181818181, 0.6568323181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 285}], {
             RGBColor[
             0.8817912272727273, 0.8822070909090909, 0.6701629545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 287}], {
             RGBColor[
             0.9854616363636364, 0.9610616363636364, 0.5306039545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 335}], {
             RGBColor[
             0.9347573636363636, 0.9241798181818182, 0.6752841818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 354}], {
             RGBColor[
             0.960204909090909, 0.9442436363636364, 0.6698285454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 396}], {
             RGBColor[
             0.8333480454545454, 0.844362909090909, 0.6653345909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 409}], {
             RGBColor[
             0.6883201363636364, 0.7259373636363636, 0.6538044999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 430}], {
             RGBColor[
             0.9668175909090909, 0.9491753636363636, 0.6586349999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 459}], {
             RGBColor[
             0.9854616363636364, 0.9610616363636364, 0.5306039545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 477}], {
             RGBColor[
             0.8333480454545454, 0.844362909090909, 0.6653345909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 226}], {
             RGBColor[
             0.8147877727272728, 0.8547583636363636, 0.9132532272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 284}], {
             RGBColor[0.7522105909090908, 0.806692, 0.9758467272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 345}], {
             RGBColor[
             0.7934374545454546, 0.8393378181818182, 0.9718961363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 389}], {
             RGBColor[
             0.8175573181818182, 0.8537241818181819, 0.7089309545454543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 456}], {
             RGBColor[
             0.8179362727272728, 0.8545347272727273, 0.7501778181818184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 472}], {
             RGBColor[
             0.8175573181818182, 0.8537241818181819, 0.7089309545454543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 207}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 209}], {
             RGBColor[0.9073477727272727, 0.927708, 0.9476691818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 231}], {
             RGBColor[
             0.9119607727272727, 0.6470576363636362, 0.5486606818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 233}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 266}], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 317}], {
             RGBColor[
             0.7617188636363637, 0.8122770000000001, 0.9342567727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 326}], {
             RGBColor[0.7874971818181817, 0.833205, 0.9362861363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 343}], {
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 355}], {
             RGBColor[
             0.7617188636363637, 0.8122770000000001, 0.9342567727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 379}], {
             RGBColor[
             0.938906409090909, 0.9528719999999999, 0.9506792727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 440}], {
             RGBColor[0.7359405454545453, 0.791349, 0.9322274090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 180}], {
             RGBColor[
             0.6165806818181817, 0.6996069999999999, 0.9629586363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 205}], {
             RGBColor[
             0.7579909090909089, 0.8109279999999999, 0.9768274545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 259}], {
             RGBColor[0.7874971818181817, 0.833205, 0.9362861363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 316}], {
             RGBColor[
             0.5392457272727271, 0.6368229999999999, 0.9568705454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 331}], {
             RGBColor[
             0.7921579545454545, 0.8336067272727272, 0.7481484545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 348}], {
             RGBColor[
             0.7917789999999999, 0.8327961818181817, 0.7069015909090907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 372}], {
             RGBColor[
             0.709663318181818, 0.44946731818181807`, 0.5679387272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 404}], {
             RGBColor[
             0.7152659545454544, 0.49253163636363617`, 0.5733038181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 418}], {
             RGBColor[
             0.6408022727272726, 0.7185290909090908, 0.9653728181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 431}], {
             RGBColor[
             0.7808844999999999, 0.8282732727272726, 0.9474796818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 444}], {
             RGBColor[
             0.7579909090909089, 0.8109279999999999, 0.9768274545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 486}], {
             RGBColor[
             0.7579909090909089, 0.8109279999999999, 0.9768274545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 178}], {
             RGBColor[
             0.8625523636363637, 0.8800929090909091, 0.6871057272727271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 185}], {
             RGBColor[
             0.8322124090909091, 0.8697001818181818, 0.9836851818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 277}], {
             RGBColor[0.8418806363636363, 0.8771819999999999, 0.9767245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 288}], {
             RGBColor[
             0.7848744545454546, 0.8319541818181818, 0.9791700454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 313}], {
             RGBColor[
             0.7150237727272727, 0.7773012727272727, 0.9722305454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 333}], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 358}], {
             RGBColor[
             0.8663794545454546, 0.8923789090909091, 0.7550061818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 361}], {
             RGBColor[
             0.8551059999999999, 0.8870454545454545, 0.954337409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 386}], {
             RGBColor[
             0.8617186818181818, 0.8919771818181819, 0.9431438636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 498}], {
             RGBColor[
             0.7894874545454544, 0.5513038181818181, 0.5801615454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.8909799999999999, 0.9121115454545454, 0.7986672272727271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 344}], {
             RGBColor[
             0.872714909090909, 0.9010358181818181, 0.9679451363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 387}], {
             RGBColor[
             0.5942174545454545, 0.6777978181818182, 0.9631146363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 435}], {
             RGBColor[
             0.8793275909090909, 0.9059675454545455, 0.9567515909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 439}], {
             RGBColor[
             0.7634669545454544, 0.8151454545454545, 0.977058909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 453}], {
             RGBColor[
             0.8909799999999999, 0.9121115454545454, 0.7986672272727271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 172}], {
             RGBColor[
             0.8484933181818182, 0.8821137272727273, 0.9655309545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[
             0.8671373636363636, 0.8939999999999999, 0.8374999090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 218}], {
             RGBColor[
             0.8617186818181818, 0.8919771818181819, 0.9431438636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 235}], {
             RGBColor[0.8660005, 0.8915683636363636, 0.7137593181818179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 236}], {
             RGBColor[
             0.8647432272727272, 0.8932279090909091, 0.893019318181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 274}], {
             RGBColor[
             0.8322124090909091, 0.8697001818181818, 0.9836851818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 284}], {
             RGBColor[
             0.8006537727272727, 0.8445361818181818, 0.9806750909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 289}], {
             RGBColor[
             0.8006537727272727, 0.8445361818181818, 0.9806750909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 300}], {
             RGBColor[
             0.8322124090909091, 0.8697001818181818, 0.9836851818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 305}], {
             RGBColor[
             0.8671373636363636, 0.8939999999999999, 0.8374999090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 432}], {
             RGBColor[0.8575696363636364, 0.863285, 0.6677487727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 456}], {
             RGBColor[
             0.8663794545454546, 0.8923789090909091, 0.7550061818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 493}], {
             RGBColor[
             0.8322124090909091, 0.8697001818181818, 0.9836851818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 181}], {
             RGBColor[0.9941475, 0.9916299090909091, 0.7308122272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 189}], {
             RGBColor[
             0.9285457727272727, 0.9423128181818181, 0.8435302727272729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 232}], {
             RGBColor[
             0.9904443636363636, 0.9778695454545454, 0.5499609090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 280}], {
             RGBColor[
             0.7413592272727272, 0.7933718181818181, 0.8265834545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 302}], {
             RGBColor[
             0.9412969090909091, 0.7870574545454547, 0.4641242272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 326}], {
             RGBColor[
             0.7929158636363636, 0.835227818181818, 0.830642181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 338}], {
             RGBColor[
             0.9942714545454545, 0.9901555454545454, 0.617861363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 346}], {
             RGBColor[
             0.8913589545454546, 0.9129220909090909, 0.8399140909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 370}], {
             RGBColor[
             0.8671373636363636, 0.8939999999999999, 0.8374999090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 383}], {
             RGBColor[
             0.9763853181818182, 0.9798903636363636, 0.8283861363636366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 390}], {
             RGBColor[
             0.9950293636363636, 0.9917766363636363, 0.7003550909090913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 395}], {
             RGBColor[
             0.5869781818181818, 0.6485853181818182, 0.8169280454545457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 443}], {
             RGBColor[
             0.9763853181818182, 0.9798903636363636, 0.8283861363636366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 480}], {
             RGBColor[
             0.9763853181818182, 0.9798903636363636, 0.8283861363636366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 211}], {
             RGBColor[
             0.9937685454545454, 0.9908193636363636, 0.6895653636363634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 236}], {
             RGBColor[0.9922562727272727, 0.990194, 0.7146276363636361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 289}], {
             RGBColor[
             0.9281668181818181, 0.9415022727272726, 0.8022834090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 308}], {
             RGBColor[
             0.8425368181818181, 0.8742673636363636, 0.7938388636363634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 362}], {
             RGBColor[
             0.8667584090909091, 0.8931894545454545, 0.7962530454545452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 369}], {
             RGBColor[
             0.8667584090909091, 0.8931894545454545, 0.7962530454545452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 456}], {
             RGBColor[0.9938925000000001, 0.989345, 0.5766145]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{169, 470}], {
             RGBColor[
             0.9693936818181818, 0.9741480909090909, 0.798332818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 214}], {
             RGBColor[
             0.9790915909090909, 0.9834246363636363, 0.8977742727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 223}], {
             RGBColor[
             0.8793275909090909, 0.9059675454545455, 0.9567515909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 268}], {
             RGBColor[
             0.9806038636363636, 0.9840500000000001, 0.8727119999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 466}], {
             RGBColor[0.982998, 0.9848220909090909, 0.8171925909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 491}], {
             RGBColor[
             0.9423000909090908, 0.8365801818181817, 0.591697909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 192}], {
             RGBColor[
             0.9887288181818181, 0.9896070909090909, 0.8364561818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 208}], {
             RGBColor[
             0.9790915909090909, 0.9834246363636363, 0.8977742727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 219}], {
             RGBColor[
             0.9724789090909091, 0.9784929090909091, 0.9089678181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 238}], {
             RGBColor[
             0.9911229545454545, 0.9903791818181817, 0.7809367727272729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 258}], {
             RGBColor[
             0.8632309545454545, 0.8926025454545454, 0.9180815909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 272}], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 293}], {
             RGBColor[
             0.9246393636363636, 0.9409153636363636, 0.9241119545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 403}], {
             RGBColor[
             0.8390093636363636, 0.8736804545454545, 0.9156674090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 471}], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 497}], {
             RGBColor[
             0.9765725000000001, 0.9428562727272729, 0.5918286818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 197}], {
             RGBColor[
             0.7227151818181817, 0.7814855454545454, 0.9546144999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 201}], {
             RGBColor[
             0.9763853181818182, 0.9798903636363636, 0.8283861363636366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 211}], {
             RGBColor[
             0.9755034545454545, 0.9797436363636364, 0.8588432727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 218}], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 235}], {
             RGBColor[
             0.9752484545454545, 0.9774587272727273, 0.7046455454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 236}], {
             RGBColor[
             0.9739911818181818, 0.9791182727272727, 0.8839055454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 289}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 300}], {
             RGBColor[
             0.9414603636363637, 0.9555905454545455, 0.974571409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 308}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 314}], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 466}], {
             RGBColor[
             0.9763853181818182, 0.9798903636363636, 0.8283861363636366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 470}], {
             RGBColor[
             0.9511285909090909, 0.9630723636363636, 0.9676107272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 493}], {
             RGBColor[
             0.9414603636363637, 0.9555905454545455, 0.974571409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 242}], {
             RGBColor[
             0.526059909090909, 0.6228780454545454, 0.9570300909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 249}], {
             RGBColor[
             0.6274692272727271, 0.7026949545454545, 0.9669796818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 269}], {
             RGBColor[
             0.6661421363636363, 0.7326222272727272, 0.9391369545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 282}], {
             RGBColor[
             0.6274692272727271, 0.7026949545454545, 0.9669796818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 310}], {
             RGBColor[
             0.6529167727272727, 0.7227587727272726, 0.9615240454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 323}], {
             RGBColor[
             0.6274692272727271, 0.7026949545454545, 0.9669796818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 406}], {
             RGBColor[
             0.6116899090909089, 0.6901129545454544, 0.9654746363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 419}], {
             RGBColor[
             0.6757793636363636, 0.7388046818181817, 0.8778188636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 499}], {
             RGBColor[
             0.526059909090909, 0.6228780454545454, 0.9570300909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 210}], {
             RGBColor[
             0.7617188636363637, 0.8122770000000001, 0.9342567727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 225}], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 252}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 309}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 320}], {
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 393}], {
             RGBColor[
             0.9896106818181818, 0.9897538181818182, 0.8059990454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 424}], {
             RGBColor[
             0.9850256818181817, 0.9758467272727273, 0.6556048636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 182}], {
             RGBColor[
             0.6156249545454546, 0.6946065454545455, 0.9652257727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 208}], {
             RGBColor[0.6858565, 0.7496978181818181, 0.9403931363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 351}], {
             RGBColor[
             0.6939814545454546, 0.7552549090909091, 0.9041373181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 359}], {
             RGBColor[0.44421772727272724`, 0.5582475454545455, 0.949784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 371}], {
             RGBColor[
             0.5942174545454545, 0.6777978181818182, 0.9631146363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 463}], {
             RGBColor[
             0.6726311363636364, 0.7398343636363636, 0.9627802272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 483}], {
             RGBColor[
             0.5699958636363636, 0.6588757272727273, 0.9607004545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 178}], {
             RGBColor[
             0.9895624999999999, 0.9777228181818182, 0.5804180454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 244}], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 261}], {
             RGBColor[
             0.9795970454545455, 0.9441070000000001, 0.5417041363636366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 262}], {
             RGBColor[
             0.9341665909090908, 0.7585379545454545, 0.48936750000000007`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 299}], {
             RGBColor[
             0.9746143181818181, 0.9272990909090909, 0.5223471818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 313}], {
             RGBColor[
             0.842033909090909, 0.8749311818181817, 0.8655428636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 328}], {
             RGBColor[
             0.9930106363636364, 0.9891982727272728, 0.6070716363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 376}], {
             RGBColor[
             0.842033909090909, 0.8749311818181817, 0.8655428636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 391}], {
             RGBColor[0.9466635, 0.8152835000000002, 0.4997952272727274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 407}], {
             RGBColor[
             0.8904770909090909, 0.9127753636363636, 0.8703712272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 448}], {
             RGBColor[
             0.9592225454545454, 0.967330090909091, 0.8769975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 455}], {
             RGBColor[
             0.8178123181818182, 0.8560090909090909, 0.8631286818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 475}], {
             RGBColor[
             0.9821161363636364, 0.9846753636363637, 0.8476497272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 478}], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 482}], {
             RGBColor[
             0.9755034545454545, 0.9797436363636364, 0.8588432727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 194}], {
             RGBColor[
             0.8564339999999999, 0.8886222727272728, 0.9860993636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 290}], {
             RGBColor[
             0.7634669545454544, 0.8151454545454545, 0.977058909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 297}], {
             RGBColor[
             0.8913589545454546, 0.9129220909090909, 0.8399140909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 412}], {
             RGBColor[
             0.8661022272727272, 0.8961040909090909, 0.9791386818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 484}], {
             RGBColor[
             0.8902220909090909, 0.9104904545454546, 0.7161734999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 186}], {
             RGBColor[
             0.9239607727272727, 0.9284057272727272, 0.6931360909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 244}], {
             RGBColor[
             0.9865379545454545, 0.9764720909090909, 0.6305425909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 261}], {
             RGBColor[
             0.9758939090909091, 0.9303466363636365, 0.36085281818181825`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 288}], {
             RGBColor[
             0.9081814545454545, 0.9158237272727272, 0.6916310454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 313}], {
             RGBColor[
             0.8383307727272726, 0.8611708181818181, 0.6846915454545452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 321}], {
             RGBColor[
             0.9865379545454545, 0.9764720909090909, 0.6305425909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 391}], {
             RGBColor[
             0.9429603636363637, 0.8015231363636365, 0.31894390909090903`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 407}], {
             RGBColor[
             0.8867739545454545, 0.8990149999999999, 0.689519909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 455}], {
             RGBColor[
             0.8141091818181818, 0.8422487272727273, 0.6822773636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 475}], {
             RGBColor[0.978413, 0.970915, 0.6667984090909089]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{178, 498}], {
             RGBColor[
             0.9127944545454545, 0.6351733636363635, 0.29262254545454536`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 222}], {
             RGBColor[
             0.6774155909090909, 0.7379556818181818, 0.7398057272727274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 245}], {
             RGBColor[
             0.6777945454545453, 0.7387662272727271, 0.7810525909090906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 255}], {
             RGBColor[
             0.6686057727272727, 0.7088617727272727, 0.6525483181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 294}], {
             RGBColor[
             0.6772916363636363, 0.7394300454545455, 0.852756590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 296}], {
             RGBColor[
             0.6116899090909089, 0.6901129545454544, 0.9654746363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 312}], {
             RGBColor[
             0.526059909090909, 0.6228780454545454, 0.9570300909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 327}], {
             RGBColor[
             0.6727548181818181, 0.7375539545454546, 0.9279434090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 334}], {
             RGBColor[0.6595294545454544, 0.7276904999999999, 0.9503305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 385}], {
             RGBColor[
             0.5959105909090909, 0.6775309545454545, 0.9639695909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 415}], {
             RGBColor[0.6595294545454544, 0.7276904999999999, 0.9503305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 438}], {
             RGBColor[0.6595294545454544, 0.7276904999999999, 0.9503305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 205}], {
             RGBColor[0.7837692272727272, 0.831856, 0.9788568181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 230}], {
             RGBColor[
             0.8163000454545455, 0.8553837272727274, 0.8881909545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 331}], {
             RGBColor[
             0.8179362727272728, 0.8545347272727273, 0.7501778181818184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 382}], {
             RGBColor[
             0.7934374545454546, 0.8393378181818182, 0.9718961363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 413}], {
             RGBColor[
             0.5018383181818181, 0.6039559545454545, 0.954615909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 418}], {
             RGBColor[
             0.6665805909090909, 0.739457090909091, 0.9674021818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 474}], {
             RGBColor[0.7522105909090908, 0.806692, 0.9758467272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 490}], {
             RGBColor[0.642359, 0.720535, 0.964988]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 189}], {
             RGBColor[
             0.927663909090909, 0.9421660909090909, 0.8739874090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 302}], {
             RGBColor[
             0.9404150454545455, 0.7869107272727274, 0.49458136363636374`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 370}], {
             RGBColor[0.8662555, 0.8938532727272728, 0.8679570454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 390}], {
             RGBColor[0.9941475, 0.9916299090909091, 0.7308122272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 422}], {
             RGBColor[
             0.927663909090909, 0.9421660909090909, 0.8739874090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 443}], {
             RGBColor[
             0.9755034545454545, 0.9797436363636364, 0.8588432727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 451}], {
             RGBColor[
             0.7404773636363635, 0.7932250909090909, 0.857040590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 237}], {
             RGBColor[
             0.8239112727272728, 0.5009060000000001, 0.5739566818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 351}], {
             RGBColor[
             0.9088600454545455, 0.9283333636363637, 0.9226069090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 359}], {
             RGBColor[
             0.6590963181818181, 0.7313259999999999, 0.9682535909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 371}], {
             RGBColor[
             0.8090960454545455, 0.8508762727272727, 0.9815842272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 460}], {
             RGBColor[
             0.9103723181818182, 0.9289587272727273, 0.8975446363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 463}], {
             RGBColor[
             0.8875097272727273, 0.9129128181818182, 0.9812498181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 483}], {
             RGBColor[
             0.7848744545454546, 0.8319541818181818, 0.9791700454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 202}], {
             RGBColor[
             0.5869781818181818, 0.6485853181818182, 0.8169280454545457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 206}], {
             RGBColor[
             0.3848646818181817, 0.4920364999999999, 0.9472151363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 243}], {
             RGBColor[
             0.5617214545454545, 0.6317673181818182, 0.9561526363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 273}], {
             RGBColor[
             0.5862202727272727, 0.6469642272727274, 0.7344343181818184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 279}], {
             RGBColor[0.3333080454545454, 0.4501805, 0.943156409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 283}], {
             RGBColor[
             0.2898366818181818, 0.41346104545454543`, 0.9401285909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 285}], {
             RGBColor[
             0.4833077727272727, 0.5697307727272727, 0.9564870454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 396}], {
             RGBColor[
             0.43486459090909085`, 0.5318865909090909, 0.9516586818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 430}], {
             RGBColor[
             0.5683341363636363, 0.6366990454545454, 0.9449590909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 477}], {
             RGBColor[
             0.43486459090909085`, 0.5318865909090909, 0.9516586818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 221}], {
             RGBColor[
             0.9348476818181818, 0.9506588181818182, 0.9857649545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 253}], {
             RGBColor[0.956198, 0.9660793636363636, 0.9271220454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 287}], {
             RGBColor[
             0.9601044090909091, 0.9674768181818182, 0.8465403636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 301}], {
             RGBColor[
             0.8564339999999999, 0.8886222727272728, 0.9860993636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 316}], {
             RGBColor[0.7064342727272727, 0.769072, 0.9727687272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 336}], {
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 354}], {
             RGBColor[
             0.9348476818181818, 0.9506588181818182, 0.9857649545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 388}], {
             RGBColor[
             0.6432485454545454, 0.7152769545454545, 0.9684847272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 436}], {
             RGBColor[0.9405712272727274, 0.903146, 0.6380753181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 473}], {
             RGBColor[
             0.9592225454545454, 0.967330090909091, 0.8769975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 187}], {
             RGBColor[
             0.9601044090909091, 0.9674768181818182, 0.8465403636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 216}], {
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 224}], {
             RGBColor[0.8079908181818182, 0.850778090909091, 0.981271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 286}], {
             RGBColor[
             0.9592225454545454, 0.967330090909091, 0.8769975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 330}], {
             RGBColor[0.7837692272727272, 0.831856, 0.9788568181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 333}], {
             RGBColor[
             0.8322124090909091, 0.8697001818181818, 0.9836851818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 357}], {
             RGBColor[
             0.9094001363636364, 0.9305950000000001, 0.9912205909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 358}], {
             RGBColor[
             0.9593465000000001, 0.9658557272727273, 0.7640466363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 361}], {
             RGBColor[
             0.9480730454545454, 0.9605222727272728, 0.9633778636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 386}], {
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 398}], {
             RGBColor[
             0.9414603636363637, 0.9555905454545455, 0.974571409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 441}], {
             RGBColor[
             0.9480730454545454, 0.9605222727272728, 0.9633778636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 464}], {
             RGBColor[0.732212590909091, 0.79, 0.9747980909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 481}], {
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 288}], {
             RGBColor[
             0.8462828636363636, 0.8802669999999999, 0.9852004090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 295}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 321}], {
             RGBColor[
             0.9246393636363636, 0.9409153636363636, 0.9241119545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 341}], {
             RGBColor[
             0.9246393636363636, 0.9409153636363636, 0.9241119545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 373}], {
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 397}], {
             RGBColor[
             0.9281668181818181, 0.9415022727272726, 0.8022834090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 455}], {
             RGBColor[0.7522105909090908, 0.806692, 0.9758467272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 495}], {
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 498}], {
             RGBColor[
             0.8508958636363635, 0.5996166363636362, 0.5861919090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 216}], {
             RGBColor[
             0.9285457727272727, 0.9423128181818181, 0.8435302727272729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 224}], {
             RGBColor[
             0.8429157727272727, 0.8750779090909091, 0.8350857272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 260}], {
             RGBColor[
             0.9601044090909091, 0.9674768181818182, 0.8465403636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 328}], {
             RGBColor[0.9938925000000001, 0.989345, 0.5766145]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{187, 398}], {
             RGBColor[
             0.9763853181818182, 0.9798903636363636, 0.8283861363636366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 399}], {
             RGBColor[0.9941475, 0.9916299090909091, 0.7308122272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 407}], {
             RGBColor[
             0.8913589545454546, 0.9129220909090909, 0.8399140909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 464}], {
             RGBColor[
             0.7671375454545455, 0.8142998181818182, 0.8286128181818184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 478}], {
             RGBColor[0.9941475, 0.9916299090909091, 0.7308122272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 481}], {
             RGBColor[
             0.9601044090909091, 0.9674768181818182, 0.8465403636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 200}], {
             RGBColor[
             0.9896106818181818, 0.9897538181818182, 0.8059990454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 228}], {
             RGBColor[
             0.9173794545454546, 0.6490804545454545, 0.44301672727272745`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 256}], {
             RGBColor[
             0.9127664545454546, 0.9297308181818182, 0.8420252272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 279}], {
             RGBColor[
             0.7413592272727272, 0.7933718181818181, 0.8265834545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 298}], {
             RGBColor[
             0.9285457727272727, 0.9423128181818181, 0.8435302727272729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 318}], {
             RGBColor[
             0.7671375454545455, 0.8142998181818182, 0.8286128181818184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 335}], {
             RGBColor[
             0.9443250909090909, 0.9548948181818182, 0.8450353181818184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 409}], {
             RGBColor[
             0.6978878636363637, 0.7566523636363636, 0.8235556363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 430}], {
             RGBColor[
             0.9763853181818182, 0.9798903636363636, 0.8283861363636366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 459}], {
             RGBColor[
             0.9950293636363636, 0.9917766363636363, 0.7003550909090913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 302}], {
             RGBColor[
             0.8748133181818182, 0.7375936363636364, 0.6072994090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 346}], {
             RGBColor[
             0.8248753636363635, 0.8634582727272726, 0.9830892727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 370}], {
             RGBColor[
             0.8006537727272727, 0.8445361818181818, 0.9806750909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 383}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 390}], {
             RGBColor[
             0.9285457727272727, 0.9423128181818181, 0.8435302727272729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 422}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 443}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 451}], {
             RGBColor[
             0.6748756363636362, 0.7439079999999999, 0.9697586363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 349}], {
             RGBColor[
             0.9930106363636364, 0.9891982727272728, 0.6070716363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 378}], {
             RGBColor[
             0.9431882272727272, 0.9524631818181819, 0.721294727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 467}], {
             RGBColor[
             0.9927556363636364, 0.9869133636363637, 0.4528739090909087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 487}], {
             RGBColor[0.696751, 0.7542207272727273, 0.6998150454545452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 226}], {
             RGBColor[
             0.9022677727272728, 0.5615543636363636, 0.5128682272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 237}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 271}], {
             RGBColor[
             0.8875301363636363, 0.5510655454545454, 0.560317590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 311}], {
             RGBColor[
             0.8809174545454546, 0.5461338181818182, 0.5715111363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 366}], {
             RGBColor[
             0.8025037727272727, 0.4840972727272727, 0.5718455454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 405}], {
             RGBColor[
             0.9050373181818182, 0.5605201818181819, 0.3085459545454543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 423}], {
             RGBColor[
             0.9015891818181818, 0.5490447272727272, 0.28189236363636355`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 429}], {
             RGBColor[
             0.8941428181818182, 0.5559972727272727, 0.5491240454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 488}], {
             RGBColor[
             0.5893183181818181, 0.31075195454545446`, 0.5542309090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 219}], {
             RGBColor[
             0.9739911818181818, 0.9791182727272727, 0.8839055454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 251}], {
             RGBColor[
             0.9918773181818181, 0.9893834545454546, 0.6733807727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 258}], {
             RGBColor[
             0.8647432272727272, 0.8932279090909091, 0.893019318181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 272}], {
             RGBColor[
             0.9887288181818181, 0.9896070909090909, 0.8364561818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 435}], {
             RGBColor[
             0.9806038636363636, 0.9840500000000001, 0.8727119999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 453}], {
             RGBColor[0.9922562727272727, 0.990194, 0.7146276363636361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 497}], {
             RGBColor[
             0.9780847727272728, 0.9434816363636365, 0.5667664090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 410}], {
             RGBColor[
             0.8462828636363636, 0.8802669999999999, 0.9852004090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 428}], {
             RGBColor[
             0.900735090909091, 0.9227762727272728, 0.9588627272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 437}], {
             RGBColor[
             0.6156249545454546, 0.6946065454545455, 0.9652257727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 220}], {
             RGBColor[
             0.662962909090909, 0.7323525454545454, 0.969740909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 254}], {
             RGBColor[
             0.9592225454545454, 0.967330090909091, 0.8769975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 290}], {
             RGBColor[
             0.8322124090909091, 0.8697001818181818, 0.9836851818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 297}], {
             RGBColor[
             0.9601044090909091, 0.9674768181818182, 0.8465403636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 350}], {
             RGBColor[
             0.9592225454545454, 0.967330090909091, 0.8769975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 377}], {
             RGBColor[0.9001235, 0.7343848636363635, 0.6050956363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 412}], {
             RGBColor[
             0.9348476818181818, 0.9506588181818182, 0.9857649545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 426}], {
             RGBColor[
             0.8322124090909091, 0.8697001818181818, 0.9836851818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 476}], {
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.9668175909090909, 0.9491753636363636, 0.6586349999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 260}], {
             RGBColor[
             0.9414603636363637, 0.9555905454545455, 0.974571409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 292}], {
             RGBColor[
             0.8941224090909091, 0.9178445454545454, 0.9700562727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 399}], {
             RGBColor[
             0.9755034545454545, 0.9797436363636364, 0.8588432727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 446}], {
             RGBColor[
             0.9414603636363637, 0.9555905454545455, 0.974571409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 496}], {
             RGBColor[
             0.7227151818181817, 0.7814855454545454, 0.9546144999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 213}], {
             RGBColor[
             0.8374970909090909, 0.8730550909090908, 0.9407296818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 332}], {
             RGBColor[
             0.7764321818181817, 0.8256140909090908, 0.9782609090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 337}], {
             RGBColor[
             0.842033909090909, 0.8749311818181817, 0.8655428636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 420}], {
             RGBColor[
             0.8390093636363636, 0.8736804545454545, 0.9156674090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 427}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 447}], {
             RGBColor[
             0.526059909090909, 0.6228780454545454, 0.9570300909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 454}], {
             RGBColor[
             0.6408022727272726, 0.7185290909090908, 0.9653728181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 489}], {
             RGBColor[
             0.8390093636363636, 0.8736804545454545, 0.9156674090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 500}], {
             RGBColor[
             0.5654886363636362, 0.6570292272727272, 0.9595424545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 201}], {
             RGBColor[
             0.7413592272727272, 0.7933718181818181, 0.8265834545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 236}], {
             RGBColor[
             0.7389650909090908, 0.7925997272727272, 0.8821028636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 289}], {
             RGBColor[
             0.6748756363636362, 0.7439079999999999, 0.9697586363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 314}], {
             RGBColor[0.7359405454545453, 0.791349, 0.9322274090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 411}], {
             RGBColor[
             0.7317914999999999, 0.7626568181818181, 0.6568323181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 466}], {
             RGBColor[
             0.7413592272727272, 0.7933718181818181, 0.8265834545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 470}], {
             RGBColor[
             0.7161024999999999, 0.7765538181818181, 0.9658080454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 493}], {
             RGBColor[0.7064342727272727, 0.769072, 0.9727687272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 270}], {
             RGBColor[
             0.8066628181818182, 0.8492012727272727, 0.9495090454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 479}], {
             RGBColor[
             0.900735090909091, 0.9227762727272728, 0.9588627272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 244}], {
             RGBColor[0.956198, 0.9660793636363636, 0.9271220454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 245}], {
             RGBColor[
             0.9597254545454545, 0.9666662727272728, 0.8052934999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 262}], {
             RGBColor[0.9001235, 0.7343848636363635, 0.6050956363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 376}], {
             RGBColor[0.8079908181818182, 0.850778090909091, 0.981271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 448}], {
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 455}], {
             RGBColor[0.7837692272727272, 0.831856, 0.9788568181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 475}], {
             RGBColor[
             0.9480730454545454, 0.9605222727272728, 0.9633778636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 482}], {
             RGBColor[
             0.9414603636363637, 0.9555905454545455, 0.974571409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 228}], {
             RGBColor[
             0.9119607727272727, 0.6470576363636362, 0.5486606818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 256}], {
             RGBColor[0.9073477727272727, 0.927708, 0.9476691818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 298}], {
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 452}], {
             RGBColor[0.8132755, 0.854133, 0.9383155]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{200, 468}], {
             RGBColor[0.7359405454545453, 0.791349, 0.9322274090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 218}], {
             RGBColor[
             0.9896106818181818, 0.9897538181818182, 0.8059990454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 235}], {
             RGBColor[0.9938925000000001, 0.989345, 0.5766145]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{201, 236}], {
             RGBColor[
             0.9926352272727272, 0.9910045454545455, 0.7558745000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 289}], {
             RGBColor[
             0.9285457727272727, 0.9423128181818181, 0.8435302727272729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 300}], {
             RGBColor[
             0.9601044090909091, 0.9674768181818182, 0.8465403636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 305}], {
             RGBColor[
             0.9950293636363636, 0.9917766363636363, 0.7003550909090913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 314}], {
             RGBColor[
             0.9896106818181818, 0.9897538181818182, 0.8059990454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 406}], {
             RGBColor[
             0.9285457727272727, 0.9423128181818181, 0.8435302727272729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 493}], {
             RGBColor[
             0.9601044090909091, 0.9674768181818182, 0.8465403636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 243}], {
             RGBColor[
             0.9697726363636363, 0.9749586363636363, 0.839579681818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 273}], {
             RGBColor[
             0.9942714545454545, 0.9901555454545454, 0.617861363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 279}], {
             RGBColor[
             0.7413592272727272, 0.7933718181818181, 0.8265834545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 283}], {
             RGBColor[
             0.6978878636363637, 0.7566523636363636, 0.8235556363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 285}], {
             RGBColor[
             0.8913589545454546, 0.9129220909090909, 0.8399140909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 396}], {
             RGBColor[
             0.8429157727272727, 0.8750779090909091, 0.8350857272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 421}], {
             RGBColor[
             0.8913589545454546, 0.9129220909090909, 0.8399140909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 430}], {
             RGBColor[
             0.9763853181818182, 0.9798903636363636, 0.8283861363636366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 459}], {
             RGBColor[
             0.9950293636363636, 0.9917766363636363, 0.7003550909090913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 477}], {
             RGBColor[
             0.8429157727272727, 0.8750779090909091, 0.8350857272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 264}], {
             RGBColor[
             0.8176590454545454, 0.8582599090909091, 0.9743103181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 281}], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 295}], {
             RGBColor[
             0.9032890454545454, 0.9254948181818181, 0.9827548636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 324}], {
             RGBColor[
             0.9690147272727272, 0.9733375454545454, 0.7570859545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 341}], {
             RGBColor[
             0.9658662272727272, 0.9735611818181817, 0.9201613636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 374}], {
             RGBColor[
             0.9348476818181818, 0.9506588181818182, 0.9857649545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 397}], {
             RGBColor[
             0.9693936818181818, 0.9741480909090909, 0.798332818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 275}], {
             RGBColor[
             0.900735090909091, 0.9227762727272728, 0.9588627272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 306}], {
             RGBColor[
             0.9088600454545455, 0.9283333636363637, 0.9226069090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 331}], {
             RGBColor[
             0.9120085454545455, 0.9281097272727273, 0.7595315000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 346}], {
             RGBColor[
             0.8090960454545455, 0.8508762727272727, 0.9815842272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 348}], {
             RGBColor[
             0.911629590909091, 0.9272991818181819, 0.7182846363636362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 355}], {
             RGBColor[
             0.6848746363636364, 0.7522540000000001, 0.9702829545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 390}], {
             RGBColor[
             0.9127664545454546, 0.9297308181818182, 0.8420252272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 431}], {
             RGBColor[
             0.900735090909091, 0.9227762727272728, 0.9588627272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 444}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 486}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 230}], {
             RGBColor[
             0.9577102727272727, 0.9667047272727274, 0.9020597727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 331}], {
             RGBColor[
             0.9593465000000001, 0.9658557272727273, 0.7640466363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 382}], {
             RGBColor[
             0.9348476818181818, 0.9506588181818182, 0.9857649545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 413}], {
             RGBColor[
             0.6432485454545454, 0.7152769545454545, 0.9684847272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 474}], {
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 490}], {
             RGBColor[0.7837692272727272, 0.831856, 0.9788568181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 254}], {
             RGBColor[
             0.7920339999999999, 0.8350810909090909, 0.8610993181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 377}], {
             RGBColor[
             0.7329349545454544, 0.6021358636363634, 0.5891974545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 396}], {
             RGBColor[
             0.6408022727272726, 0.7185290909090908, 0.9653728181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 476}], {
             RGBColor[0.7874971818181817, 0.833205, 0.9362861363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 257}], {
             RGBColor[
             0.9750602272727273, 0.9422309090909092, 0.6168909545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 266}], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 281}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 293}], {
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 317}], {
             RGBColor[
             0.7617188636363637, 0.8122770000000001, 0.9342567727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 322}], {
             RGBColor[
             0.8374970909090909, 0.8730550909090908, 0.9407296818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 343}], {
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 374}], {
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 403}], {
             RGBColor[
             0.8374970909090909, 0.8730550909090908, 0.9407296818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 440}], {
             RGBColor[0.7359405454545453, 0.791349, 0.9322274090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 445}], {
             RGBColor[
             0.6924691818181818, 0.7546295454545455, 0.9291995909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 471}], {
             RGBColor[
             0.9857042727272727, 0.9883563636363637, 0.8865807272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 238}], {
             RGBColor[0.982998, 0.9848220909090909, 0.8171925909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[
             0.8551059999999999, 0.8870454545454545, 0.954337409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 266}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 293}], {
             RGBColor[
             0.916514409090909, 0.9353582727272727, 0.9603677727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 403}], {
             RGBColor[
             0.8308844090909091, 0.8681233636363637, 0.9519232272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 471}], {
             RGBColor[
             0.9790915909090909, 0.9834246363636363, 0.8977742727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 483}], {
             RGBColor[
             0.8551059999999999, 0.8870454545454545, 0.954337409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 497}], {
             RGBColor[
             0.9684475454545455, 0.937299181818182, 0.6280845000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 231}], {
             RGBColor[
             0.8351165454545455, 0.5870346363636363, 0.5846868636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 233}], {
             RGBColor[0.9073477727272727, 0.927708, 0.9476691818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 259}], {
             RGBColor[0.9073477727272727, 0.927708, 0.9476691818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 275}], {
             RGBColor[
             0.900735090909091, 0.9227762727272728, 0.9588627272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 348}], {
             RGBColor[
             0.911629590909091, 0.9272991818181819, 0.7182846363636362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 355}], {
             RGBColor[
             0.6848746363636364, 0.7522540000000001, 0.9702829545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 372}], {
             RGBColor[
             0.8295139090909092, 0.5439703181818182, 0.5793217727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 379}], {
             RGBColor[0.8620621818181818, 0.892849, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 400}], {
             RGBColor[
             0.9081814545454545, 0.9158237272727272, 0.6916310454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 404}], {
             RGBColor[
             0.8351165454545455, 0.5870346363636363, 0.5846868636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 431}], {
             RGBColor[
             0.900735090909091, 0.9227762727272728, 0.9588627272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 444}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 486}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 225}], {
             RGBColor[0.7484935, 0.8024135454545456, 0.9566438636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 252}], {
             RGBColor[
             0.7418808181818182, 0.7974818181818182, 0.9678374090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 280}], {
             RGBColor[
             0.513467409090909, 0.6158950000000001, 0.9548411818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 309}], {
             RGBColor[
             0.7418808181818182, 0.7974818181818182, 0.9678374090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 320}], {
             RGBColor[0.7006539545454545, 0.7648360000000001, 0.971788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 393}], {
             RGBColor[
             0.7671375454545455, 0.8142998181818182, 0.8286128181818184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 424}], {
             RGBColor[
             0.7625525454545454, 0.8003927272727274, 0.6782186363636362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 480}], {
             RGBColor[0.7484935, 0.8024135454545456, 0.9566438636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 236}], {
             RGBColor[
             0.9917533636363636, 0.9908578181818182, 0.7863316363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 289}], {
             RGBColor[
             0.927663909090909, 0.9421660909090909, 0.8739874090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 308}], {
             RGBColor[
             0.842033909090909, 0.8749311818181817, 0.8655428636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 362}], {
             RGBColor[0.8662555, 0.8938532727272728, 0.8679570454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 369}], {
             RGBColor[0.8662555, 0.8938532727272728, 0.8679570454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 466}], {
             RGBColor[0.9941475, 0.9916299090909091, 0.7308122272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 470}], {
             RGBColor[
             0.9688907727272726, 0.9748119090909091, 0.8700368181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 216}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 217}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 224}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 286}], {
             RGBColor[
             0.9755034545454545, 0.9797436363636364, 0.8588432727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 319}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 330}], {
             RGBColor[
             0.8000501363636363, 0.8442695454545455, 0.9607025909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 357}], {
             RGBColor[
             0.9256810454545454, 0.9430085454545454, 0.9730663636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 492}], {
             RGBColor[
             0.8484933181818182, 0.8821137272727273, 0.9655309545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 251}], {
             RGBColor[
             0.9888527727272727, 0.9881327272727274, 0.7235053181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 332}], {
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 337}], {
             RGBColor[
             0.9887288181818181, 0.9896070909090909, 0.8364561818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 420}], {
             RGBColor[
             0.9857042727272727, 0.9883563636363637, 0.8865807272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 447}], {
             RGBColor[
             0.6727548181818181, 0.7375539545454545, 0.9279434090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 454}], {
             RGBColor[0.7874971818181817, 0.833205, 0.9362861363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 489}], {
             RGBColor[
             0.9857042727272727, 0.9883563636363637, 0.8865807272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 500}], {
             RGBColor[
             0.7121835454545453, 0.7717051363636362, 0.9304557727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 223}], {
             RGBColor[
             0.8874525454545454, 0.9115246363636363, 0.9204957727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 268}], {
             RGBColor[
             0.9887288181818181, 0.9896070909090909, 0.8364561818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 466}], {
             RGBColor[
             0.9911229545454545, 0.9903791818181817, 0.7809367727272729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 470}], {
             RGBColor[
             0.9658662272727272, 0.9735611818181817, 0.9201613636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 491}], {
             RGBColor[
             0.9504250454545453, 0.8421372727272726, 0.5554420909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 402}], {
             RGBColor[
             0.7264322727272725, 0.7857639999999999, 0.9738173636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 417}], {
             RGBColor[
             0.7676591363636363, 0.818409818181818, 0.9698667727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 217}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 224}], {
             RGBColor[
             0.7764321818181817, 0.8256140909090908, 0.9782609090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 292}], {
             RGBColor[
             0.8462828636363636, 0.8802669999999999, 0.9852004090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 358}], {
             RGBColor[
             0.9277878636363637, 0.9406917272727273, 0.7610365454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 361}], {
             RGBColor[
             0.916514409090909, 0.9353582727272727, 0.9603677727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 398}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 399}], {
             RGBColor[
             0.927663909090909, 0.9421660909090909, 0.8739874090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 464}], {
             RGBColor[0.7006539545454545, 0.7648360000000001, 0.971788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 481}], {
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 292}], {
             RGBColor[
             0.8462828636363636, 0.8802669999999999, 0.9852004090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 398}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 464}], {
             RGBColor[0.7006539545454545, 0.7648360000000001, 0.971788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 481}], {
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 496}], {
             RGBColor[
             0.6748756363636362, 0.7439079999999999, 0.9697586363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 235}], {
             RGBColor[
             0.9884738181818182, 0.9873221818181819, 0.6822584545454543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 274}], {
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 305}], {
             RGBColor[
             0.9896106818181818, 0.9897538181818182, 0.8059990454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 310}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 314}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 406}], {
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 432}], {
             RGBColor[
             0.9800429545454545, 0.9590388181818181, 0.636247909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 493}], {
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 238}], {
             RGBColor[
             0.9763853181818182, 0.9798903636363636, 0.8283861363636366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 258}], {
             RGBColor[
             0.8484933181818182, 0.8821137272727273, 0.9655309545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 293}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 403}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 445}], {
             RGBColor[
             0.6792438181818181, 0.744766090909091, 0.9515866818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 471}], {
             RGBColor[
             0.9724789090909091, 0.9784929090909091, 0.9089678181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 497}], {
             RGBColor[
             0.9618348636363636, 0.9323674545454547, 0.6392780454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 254}], {
             RGBColor[0.697006, 0.7565056363636364, 0.8540127727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 297}], {
             RGBColor[
             0.6978878636363637, 0.7566523636363636, 0.8235556363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 325}], {
             RGBColor[
             0.5457742727272727, 0.6399536363636363, 0.9582862727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 392}], {
             RGBColor[
             0.5699958636363636, 0.6588757272727273, 0.9607004545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 412}], {
             RGBColor[
             0.6726311363636364, 0.7398343636363636, 0.9627802272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 413}], {
             RGBColor[0.3810319999999999, 0.5044525, 0.9455]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{220, 426}], {
             RGBColor[
             0.5699958636363636, 0.6588757272727273, 0.9607004545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 474}], {
             RGBColor[
             0.6314042727272726, 0.7071885454545455, 0.9667308181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 490}], {
             RGBColor[
             0.5215526818181818, 0.6210315454545454, 0.9558720909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 234}], {
             RGBColor[
             0.9502394545454544, 0.9106278181818181, 0.6311146363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 301}], {
             RGBColor[
             0.8661022272727272, 0.8961040909090909, 0.9791386818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 336}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 294}], {
             RGBColor[
             0.9933895909090908, 0.9900088181818183, 0.6483185000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 296}], {
             RGBColor[
             0.9277878636363637, 0.9406917272727273, 0.7610365454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 339}], {
             RGBColor[
             0.9690147272727272, 0.9733375454545454, 0.7570859545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 344}], {
             RGBColor[
             0.9756274090909092, 0.9782692727272728, 0.7458924090909093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 438}], {
             RGBColor[
             0.9756274090909092, 0.9782692727272728, 0.7458924090909093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 439}], {
             RGBColor[
             0.8663794545454546, 0.8923789090909091, 0.7550061818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 246}], {
             RGBColor[
             0.8909799999999999, 0.9121115454545454, 0.7986672272727271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 268}], {
             RGBColor[0.8889648181818182, 0.91215, 0.8954334999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 411}], {
             RGBColor[
             0.8817912272727273, 0.8822070909090909, 0.6701629545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 286}], {
             RGBColor[
             0.842033909090909, 0.8749311818181817, 0.8655428636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 330}], {
             RGBColor[
             0.6665805909090909, 0.739457090909091, 0.9674021818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 333}], {
             RGBColor[
             0.7150237727272727, 0.7773012727272727, 0.9722305454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 358}], {
             RGBColor[
             0.8421578636363636, 0.8734568181818182, 0.7525920000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 361}], {
             RGBColor[
             0.8308844090909091, 0.8681233636363637, 0.9519232272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 398}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 441}], {
             RGBColor[
             0.8308844090909091, 0.8681233636363637, 0.9519232272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 464}], {
             RGBColor[
             0.6150239545454546, 0.697601090909091, 0.9633434545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 481}], {
             RGBColor[0.8079908181818182, 0.850778090909091, 0.981271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 247}], {
             RGBColor[0.6595294545454544, 0.7276904999999999, 0.9503305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 252}], {
             RGBColor[
             0.9511285909090909, 0.9630723636363636, 0.9676107272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 309}], {
             RGBColor[
             0.9511285909090909, 0.9630723636363636, 0.9676107272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 320}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 424}], {
             RGBColor[
             0.9718003181818182, 0.9659832727272727, 0.6779919545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 284}], {
             RGBColor[
             0.9246393636363636, 0.9409153636363636, 0.9241119545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 345}], {
             RGBColor[
             0.9658662272727272, 0.9735611818181817, 0.9201613636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 366}], {
             RGBColor[
             0.8874525454545454, 0.9115246363636363, 0.9204957727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 389}], {
             RGBColor[
             0.989986090909091, 0.9879475454545454, 0.6571961818181816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 405}], {
             RGBColor[
             0.989986090909091, 0.9879475454545454, 0.6571961818181816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 429}], {
             RGBColor[
             0.9790915909090909, 0.9834246363636363, 0.8977742727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 472}], {
             RGBColor[
             0.989986090909091, 0.9879475454545454, 0.6571961818181816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 488}], {
             RGBColor[
             0.6742670909090909, 0.7381793181818181, 0.9028811363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 229}], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 263}], {
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 265}], {
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 267}], {
             RGBColor[
             0.9296297727272727, 0.7566618636363636, 0.5645543181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 270}], {
             RGBColor[0.8132755, 0.854133, 0.9383155]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{227, 329}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 424}], {
             RGBColor[
             0.9850256818181817, 0.9758467272727273, 0.6556048636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 256}], {
             RGBColor[
             0.8351165454545455, 0.5870346363636363, 0.5846868636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 279}], {
             RGBColor[
             0.6637093181818181, 0.4506756363636362, 0.5692450909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 287}], {
             RGBColor[
             0.9173794545454546, 0.6490804545454545, 0.44301672727272745`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 298}], {
             RGBColor[
             0.8508958636363635, 0.5996166363636362, 0.5861919090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 318}], {
             RGBColor[
             0.6894876363636364, 0.47160363636363634`, 0.5712744545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 335}], {
             RGBColor[
             0.8666751818181817, 0.6121986363636363, 0.5876969545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 409}], {
             RGBColor[
             0.6202379545454545, 0.4139561818181817, 0.5662172727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 468}], {
             RGBColor[
             0.6637093181818181, 0.4506756363636362, 0.5692450909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 232}], {
             RGBColor[
             0.9880502272727272, 0.9770974545454545, 0.605480318181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 263}], {
             RGBColor[
             0.9261516363636363, 0.9415407272727272, 0.8990496818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 267}], {
             RGBColor[
             0.9326543181818181, 0.7579125909090908, 0.5144297727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 280}], {
             RGBColor[
             0.7389650909090908, 0.7925997272727272, 0.8821028636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 393}], {
             RGBColor[
             0.9926352272727272, 0.9910045454545455, 0.7558745000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 480}], {
             RGBColor[
             0.9739911818181818, 0.9791182727272727, 0.8839055454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 485}], {
             RGBColor[
             0.6954937272727273, 0.7558802727272728, 0.8790750454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 382}], {
             RGBColor[
             0.9673784999999999, 0.9741865454545455, 0.8950990909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 413}], {
             RGBColor[
             0.6757793636363636, 0.7388046818181818, 0.8778188636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 474}], {
             RGBColor[
             0.9261516363636363, 0.9415407272727272, 0.8990496818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 484}], {
             RGBColor[
             0.9914983636363637, 0.9885729090909092, 0.6321339090909088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 490}], {
             RGBColor[
             0.8163000454545455, 0.8553837272727274, 0.8881909545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 233}], {
             RGBColor[
             0.9119607727272727, 0.6470576363636362, 0.5486606818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 275}], {
             RGBColor[
             0.9053480909090909, 0.642125909090909, 0.5598542272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 326}], {
             RGBColor[
             0.7152659545454544, 0.49253163636363617`, 0.5733038181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 346}], {
             RGBColor[
             0.8137090454545454, 0.570225909090909, 0.5825757272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 355}], {
             RGBColor[
             0.6894876363636364, 0.47160363636363634`, 0.5712744545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 395}], {
             RGBColor[
             0.5093282727272727, 0.30588913636363624`, 0.5595896818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 404}], {
             RGBColor[
             0.8397295454545454, 0.30638427272727253`, 0.1856783636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 431}], {
             RGBColor[
             0.9053480909090909, 0.642125909090909, 0.5598542272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 444}], {
             RGBColor[0.8824544999999999, 0.6247806363636363, 0.589202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 486}], {
             RGBColor[0.8824544999999999, 0.6247806363636363, 0.589202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 267}], {
             RGBColor[
             0.9304634545454544, 0.7447775909090908, 0.3085161818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 280}], {
             RGBColor[
             0.7367742272727272, 0.7794647272727272, 0.6761892727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 338}], {
             RGBColor[
             0.9896864545454546, 0.9762484545454546, 0.4674671818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 383}], {
             RGBColor[
             0.9718003181818182, 0.9659832727272727, 0.6779919545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 393}], {
             RGBColor[
             0.9904443636363636, 0.9778695454545454, 0.5499609090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 395}], {
             RGBColor[
             0.5823931818181818, 0.6346782272727273, 0.6665338636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 480}], {
             RGBColor[
             0.9718003181818182, 0.9659832727272727, 0.6779919545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 259}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 275}], {
             RGBColor[
             0.9775793181818182, 0.9827992727272727, 0.9228365454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 326}], {
             RGBColor[0.7874971818181817, 0.833205, 0.9362861363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 346}], {
             RGBColor[
             0.8859402727272727, 0.9108992727272727, 0.9455580454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 348}], {
             RGBColor[
             0.9884738181818182, 0.9873221818181819, 0.6822584545454543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 355}], {
             RGBColor[
             0.7617188636363637, 0.8122770000000001, 0.9342567727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 379}], {
             RGBColor[
             0.938906409090909, 0.9528719999999999, 0.9506792727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 400}], {
             RGBColor[
             0.9850256818181817, 0.9758467272727273, 0.6556048636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 404}], {
             RGBColor[
             0.9119607727272727, 0.6470576363636362, 0.5486606818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 431}], {
             RGBColor[
             0.9775793181818182, 0.9827992727272727, 0.9228365454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 444}], {
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 486}], {
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 336}], {
             RGBColor[0.9700774999999999, 0.925423, 0.597534]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{234, 449}], {
             RGBColor[
             0.9247919090909091, 0.8905639999999999, 0.6365702727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 274}], {
             RGBColor[
             0.9589675454545454, 0.9650451818181819, 0.7227997727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 284}], {
             RGBColor[
             0.927408909090909, 0.9398811818181818, 0.7197896818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 300}], {
             RGBColor[
             0.9589675454545454, 0.9650451818181819, 0.7227997727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 305}], {
             RGBColor[0.9938925000000001, 0.989345, 0.5766145]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{235, 308}], {
             RGBColor[
             0.8417789090909091, 0.8726462727272728, 0.711345136363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 345}], {
             RGBColor[0.9686357727272727, 0.972527, 0.7158390909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 389}], {
             RGBColor[
             0.9927556363636364, 0.9869133636363637, 0.4528739090909087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 432}], {
             RGBColor[
             0.9843247727272728, 0.9586300000000001, 0.40686336363636333`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 456}], {
             RGBColor[
             0.993134590909091, 0.9877239090909091, 0.49412077272727273`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 289}], {
             RGBColor[
             0.9261516363636363, 0.9415407272727272, 0.8990496818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 300}], {
             RGBColor[
             0.9577102727272727, 0.9667047272727274, 0.9020597727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 308}], {
             RGBColor[
             0.8405216363636363, 0.8743058181818182, 0.8906051363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 314}], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 466}], {
             RGBColor[
             0.9926352272727272, 0.9910045454545455, 0.7558745000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 470}], {
             RGBColor[
             0.9673784999999999, 0.9741865454545455, 0.8950990909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 493}], {
             RGBColor[
             0.9577102727272727, 0.9667047272727274, 0.9020597727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 241}], {
             RGBColor[
             0.5893183181818181, 0.31075195454545446`, 0.5542309090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 274}], {
             RGBColor[0.8712492272727272, 0.538652, 0.5784718181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 284}], {
             RGBColor[
             0.8396905909090908, 0.5134879999999999, 0.5754617272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 351}], {
             RGBColor[
             0.9022677727272728, 0.5615543636363636, 0.5128682272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 371}], {
             RGBColor[
             0.8025037727272727, 0.4840972727272727, 0.5718455454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 429}], {
             RGBColor[
             0.8941428181818182, 0.5559972727272727, 0.5491240454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 432}], {
             RGBColor[
             0.8966064545454546, 0.5322368181818182, 0.262535409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 460}], {
             RGBColor[
             0.9037800454545455, 0.5621797272727274, 0.4878059545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 258}], {
             RGBColor[
             0.8671373636363636, 0.8939999999999999, 0.8374999090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 266}], {
             RGBColor[
             0.9763853181818182, 0.9798903636363636, 0.8283861363636366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 293}], {
             RGBColor[
             0.9285457727272727, 0.9423128181818181, 0.8435302727272729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 403}], {
             RGBColor[
             0.8429157727272727, 0.8750779090909091, 0.8350857272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 445}], {
             RGBColor[
             0.6978878636363637, 0.7566523636363636, 0.8235556363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 471}], {
             RGBColor[
             0.9911229545454545, 0.9903791818181817, 0.7809367727272729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 483}], {
             RGBColor[
             0.8671373636363636, 0.8939999999999999, 0.8374999090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 497}], {
             RGBColor[
             0.9804789090909092, 0.9442537272727274, 0.5112470000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 251}], {
             RGBColor[0.9938925000000001, 0.989345, 0.5766145]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{239, 272}], {
             RGBColor[0.990744, 0.9895686363636363, 0.7396899090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 332}], {
             RGBColor[
             0.9281668181818181, 0.9415022727272726, 0.8022834090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 387}], {
             RGBColor[
             0.697508909090909, 0.7558418181818182, 0.7823087727272725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 435}], {
             RGBColor[
             0.9826190454545454, 0.9840115454545455, 0.775945727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 453}], {
             RGBColor[
             0.9942714545454545, 0.9901555454545454, 0.6178613636363632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 454}], {
             RGBColor[
             0.7925369090909089, 0.8344172727272726, 0.789395318181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 489}], {
             RGBColor[0.990744, 0.9895686363636363, 0.7396899090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 434}], {
             RGBColor[0.8660005, 0.8915683636363636, 0.713759318181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 495}], {
             RGBColor[
             0.9589675454545454, 0.9650451818181819, 0.7227997727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 271}], {
             RGBColor[0.6595294545454544, 0.7276904999999999, 0.9503305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 304}], {
             RGBColor[0.6595294545454544, 0.7276904999999999, 0.9503305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 311}], {
             RGBColor[
             0.6529167727272727, 0.7227587727272726, 0.9615240454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 351}], {
             RGBColor[
             0.6742670909090909, 0.7381793181818181, 0.9028811363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 371}], {
             RGBColor[
             0.5745030909090908, 0.6607222272727272, 0.9618584545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 429}], {
             RGBColor[
             0.6661421363636363, 0.7326222272727272, 0.9391369545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 442}], {
             RGBColor[
             0.6244410454545455, 0.534857590909091, 0.5860685909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 249}], {
             RGBColor[0.7922115, 0.8381960909090909, 0.9797659545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 269}], {
             RGBColor[
             0.8308844090909091, 0.8681233636363637, 0.9519232272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 282}], {
             RGBColor[0.7922115, 0.8381960909090909, 0.9797659545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 310}], {
             RGBColor[
             0.8176590454545454, 0.8582599090909091, 0.9743103181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 323}], {
             RGBColor[0.7922115, 0.8381960909090909, 0.9797659545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 419}], {
             RGBColor[
             0.8405216363636363, 0.8743058181818182, 0.8906051363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 449}], {
             RGBColor[0.7922115, 0.8381960909090909, 0.9797659545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 499}], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 273}], {
             RGBColor[
             0.9690147272727272, 0.9733375454545454, 0.7570859545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 279}], {
             RGBColor[
             0.7161024999999999, 0.7765538181818181, 0.9658080454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 283}], {
             RGBColor[
             0.6726311363636364, 0.7398343636363636, 0.9627802272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 285}], {
             RGBColor[
             0.8661022272727272, 0.8961040909090909, 0.9791386818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 318}], {
             RGBColor[
             0.7418808181818182, 0.7974818181818182, 0.9678374090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 335}], {
             RGBColor[
             0.9190683636363636, 0.9380768181818182, 0.9842599090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 396}], {
             RGBColor[
             0.8176590454545454, 0.8582599090909091, 0.9743103181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 421}], {
             RGBColor[
             0.8661022272727272, 0.8961040909090909, 0.9791386818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 430}], {
             RGBColor[
             0.9511285909090909, 0.9630723636363636, 0.9676107272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 459}], {
             RGBColor[
             0.9697726363636363, 0.9749586363636363, 0.839579681818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 477}], {
             RGBColor[
             0.8176590454545454, 0.8582599090909091, 0.9743103181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 261}], {
             RGBColor[
             0.9765725000000001, 0.9428562727272729, 0.5918286818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 262}], {
             RGBColor[
             0.9311420454545454, 0.7572872272727271, 0.5394920454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 295}], {
             RGBColor[
             0.9246393636363636, 0.9409153636363636, 0.9241119545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 341}], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 376}], {
             RGBColor[
             0.8390093636363636, 0.8736804545454545, 0.9156674090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 391}], {
             RGBColor[
             0.9436389545454545, 0.8140327727272729, 0.5499197727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 407}], {
             RGBColor[
             0.8874525454545454, 0.9115246363636363, 0.9204957727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 448}], {
             RGBColor[0.956198, 0.9660793636363636, 0.9271220454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 455}], {
             RGBColor[
             0.8147877727272728, 0.8547583636363636, 0.9132532272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 475}], {
             RGBColor[
             0.9790915909090909, 0.9834246363636363, 0.8977742727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 478}], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 482}], {
             RGBColor[
             0.9724789090909091, 0.9784929090909091, 0.9089678181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 262}], {
             RGBColor[
             0.9346694999999999, 0.7578741363636362, 0.41766349999999974`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 299}], {
             RGBColor[
             0.9751172272727273, 0.9266352727272726, 0.45064318181818164`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 376}], {
             RGBColor[
             0.8425368181818181, 0.8742673636363636, 0.7938388636363634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 438}], {
             RGBColor[
             0.9760063636363636, 0.9790798181818181, 0.7871392727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 448}], {
             RGBColor[
             0.9597254545454545, 0.9666662727272728, 0.8052934999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 475}], {
             RGBColor[
             0.9826190454545454, 0.9840115454545455, 0.775945727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 482}], {
             RGBColor[
             0.9760063636363636, 0.9790798181818181, 0.7871392727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 384}], {
             RGBColor[
             0.9693936818181818, 0.9741480909090909, 0.798332818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 402}], {
             RGBColor[
             0.9281668181818181, 0.9415022727272726, 0.8022834090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 411}], {
             RGBColor[
             0.9850826818181818, 0.9602510909090909, 0.48935709090909063`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 458}], {
             RGBColor[
             0.8425368181818181, 0.8742673636363636, 0.7938388636363634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 252}], {
             RGBColor[
             0.6529167727272727, 0.7227587727272726, 0.9615240454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 278}], {
             RGBColor[
             0.6661421363636363, 0.7326222272727272, 0.9391369545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 309}], {
             RGBColor[
             0.6529167727272727, 0.7227587727272726, 0.9615240454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 401}], {
             RGBColor[
             0.6772916363636363, 0.7394300454545455, 0.852756590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 451}], {
             RGBColor[
             0.42450336363636354`, 0.5411719545454544, 0.9485278181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 339}], {
             RGBColor[
             0.8661022272727272, 0.8961040909090909, 0.9791386818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 344}], {
             RGBColor[
             0.872714909090909, 0.9010358181818181, 0.9679451363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 387}], {
             RGBColor[
             0.5942174545454545, 0.6777978181818182, 0.9631146363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 439}], {
             RGBColor[
             0.7634669545454544, 0.8151454545454545, 0.977058909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 269}], {
             RGBColor[
             0.9322937272727272, 0.9479402727272728, 0.9618728181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 282}], {
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 310}], {
             RGBColor[
             0.9190683636363636, 0.9380768181818182, 0.9842599090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 323}], {
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 406}], {
             RGBColor[0.8778414999999999, 0.9054309999999999, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 419}], {
             RGBColor[
             0.9419309545454545, 0.9541227272727273, 0.9005547272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 499}], {
             RGBColor[0.7922115, 0.8381960909090909, 0.9797659545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 263}], {
             RGBColor[
             0.916514409090909, 0.9353582727272727, 0.9603677727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 365}], {
             RGBColor[
             0.9634648181818182, 0.9204912727272727, 0.6087275454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 485}], {
             RGBColor[0.6858565, 0.7496978181818181, 0.9403931363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 258}], {
             RGBColor[
             0.8663794545454546, 0.8923789090909091, 0.7550061818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 272}], {
             RGBColor[
             0.9903650454545454, 0.988758090909091, 0.6984430454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 435}], {
             RGBColor[0.9822400909090909, 0.983201, 0.7346988636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 447}], {
             RGBColor[
             0.6774155909090909, 0.7379556818181818, 0.7398057272727274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 453}], {
             RGBColor[0.9938925000000001, 0.989345, 0.5766145]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{251, 454}], {
             RGBColor[
             0.7921579545454545, 0.8336067272727272, 0.7481484545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 309}], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 320}], {
             RGBColor[
             0.9032890454545454, 0.9254948181818181, 0.9827548636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 424}], {
             RGBColor[
             0.9651876363636362, 0.9610515454545454, 0.6891854999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 287}], {
             RGBColor[
             0.9911229545454545, 0.9903791818181817, 0.7809367727272729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 301}], {
             RGBColor[
             0.8874525454545454, 0.9115246363636363, 0.9204957727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 336}], {
             RGBColor[
             0.9857042727272727, 0.9883563636363637, 0.8865807272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 354}], {
             RGBColor[
             0.9658662272727272, 0.9735611818181817, 0.9201613636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 388}], {
             RGBColor[
             0.6742670909090909, 0.7381793181818181, 0.9028811363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 436}], {
             RGBColor[
             0.9715897727272726, 0.9260483636363637, 0.5724717272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 473}], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 350}], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 377}], {
             RGBColor[
             0.9341665909090908, 0.7585379545454545, 0.48936750000000007`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 412}], {
             RGBColor[
             0.9688907727272726, 0.9748119090909091, 0.8700368181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 426}], {
             RGBColor[0.8662555, 0.8938532727272728, 0.8679570454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 476}], {
             RGBColor[
             0.9887288181818181, 0.9896070909090909, 0.8364561818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 260}], {
             RGBColor[
             0.9505366818181819, 0.9367618181818183, 0.6767892272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 299}], {
             RGBColor[
             0.9659284545454545, 0.8967308181818181, 0.32213890909090903`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 312}], {
             RGBColor[
             0.8333480454545454, 0.844362909090909, 0.6653345909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 327}], {
             RGBColor[
             0.9800429545454545, 0.9590388181818181, 0.636247909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 334}], {
             RGBColor[
             0.9668175909090909, 0.9491753636363636, 0.6586349999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 385}], {
             RGBColor[
             0.9031987272727273, 0.8990158181818182, 0.6722740909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 446}], {
             RGBColor[
             0.9505366818181819, 0.9367618181818183, 0.6767892272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 478}], {
             RGBColor[
             0.9845797727272727, 0.960914909090909, 0.561061090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 287}], {
             RGBColor[
             0.9127664545454546, 0.9297308181818182, 0.8420252272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 298}], {
             RGBColor[
             0.8462828636363636, 0.8802669999999999, 0.9852004090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 409}], {
             RGBColor[
             0.6156249545454546, 0.6946065454545455, 0.9652257727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 281}], {
             RGBColor[
             0.9552221818181819, 0.9274357272727274, 0.650471590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 317}], {
             RGBColor[
             0.752587090909091, 0.7667769090909093, 0.6395047272727274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 322}], {
             RGBColor[0.8283653181818182, 0.827555, 0.6459776363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 324}], {
             RGBColor[
             0.9797210000000001, 0.9426326363636366, 0.42875327272727304`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 326}], {
             RGBColor[
             0.778365409090909, 0.7877049090909092, 0.641534090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 343}], {
             RGBColor[
             0.9139953181818181, 0.8947899090909092, 0.6544221818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 374}], {
             RGBColor[
             0.9455539545454545, 0.9199539090909092, 0.6574322727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 445}], {
             RGBColor[
             0.6833374090909091, 0.7091294545454547, 0.6344475454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 272}], {
             RGBColor[
             0.8632309545454545, 0.8926025454545454, 0.9180815909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 293}], {
             RGBColor[
             0.8006537727272727, 0.8445361818181818, 0.9806750909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 403}], {
             RGBColor[
             0.7150237727272727, 0.7773012727272727, 0.9722305454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 435}], {
             RGBColor[
             0.8551059999999999, 0.8870454545454545, 0.954337409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 453}], {
             RGBColor[
             0.8667584090909091, 0.8931894545454545, 0.7962530454545452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 471}], {
             RGBColor[
             0.8632309545454545, 0.8926025454545454, 0.9180815909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 497}], {
             RGBColor[
             0.8525869090909091, 0.8464770909090911, 0.6483918181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 275}], {
             RGBColor[
             0.9775793181818182, 0.9827992727272727, 0.9228365454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 331}], {
             RGBColor[
             0.9888527727272727, 0.9881327272727274, 0.7235053181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 348}], {
             RGBColor[
             0.9884738181818182, 0.9873221818181819, 0.6822584545454543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 372}], {
             RGBColor[
             0.9063581363636364, 0.6039933181818181, 0.5432955909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 400}], {
             RGBColor[
             0.9850256818181817, 0.9758467272727273, 0.6556048636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 404}], {
             RGBColor[
             0.9119607727272727, 0.6470576363636362, 0.5486606818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 418}], {
             RGBColor[
             0.8374970909090909, 0.8730550909090908, 0.9407296818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 431}], {
             RGBColor[
             0.9775793181818182, 0.9827992727272727, 0.9228365454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 444}], {
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 486}], {
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 299}], {
             RGBColor[0.9405712272727274, 0.903146, 0.6380753181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 312}], {
             RGBColor[0.8079908181818182, 0.850778090909091, 0.981271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 328}], {
             RGBColor[
             0.9589675454545454, 0.9650451818181819, 0.7227997727272725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 334}], {
             RGBColor[
             0.9414603636363637, 0.9555905454545455, 0.974571409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 399}], {
             RGBColor[
             0.9592225454545454, 0.967330090909091, 0.8769975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 407}], {
             RGBColor[
             0.8564339999999999, 0.8886222727272728, 0.9860993636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 446}], {
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 478}], {
             RGBColor[
             0.9592225454545454, 0.967330090909091, 0.8769975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 262}], {
             RGBColor[0.920498, 0.7111617727272728, 0.26980227272727286`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 299}], {
             RGBColor[
             0.9609457272727273, 0.8799229090909092, 0.30278195454545465`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 313}], {
             RGBColor[0.8283653181818182, 0.827555, 0.6459776363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 328}], {
             RGBColor[
             0.9793420454545455, 0.9418220909090911, 0.38750640909090905`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 391}], {
             RGBColor[
             0.9329949090909091, 0.7679073181818185, 0.2802300000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 407}], {
             RGBColor[0.8768085, 0.8653991818181819, 0.6508060000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 448}], {
             RGBColor[
             0.9455539545454545, 0.9199539090909092, 0.6574322727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 455}], {
             RGBColor[
             0.8041437272727273, 0.8086329090909092, 0.6435634545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 475}], {
             RGBColor[
             0.9684475454545455, 0.937299181818182, 0.6280845000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 478}], {
             RGBColor[
             0.9795970454545455, 0.9441070000000001, 0.5417041363636366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 482}], {
             RGBColor[
             0.9618348636363636, 0.9323674545454547, 0.6392780454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 299}], {
             RGBColor[
             0.9155152727272726, 0.6943538636363635, 0.25044531818181814`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 376}], {
             RGBColor[
             0.7829348636363636, 0.6419859545454544, 0.5936409999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 391}], {
             RGBColor[
             0.8875644545454545, 0.5823382727272728, 0.22789336363636364`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 448}], {
             RGBColor[0.9001235, 0.7343848636363635, 0.6050956363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 455}], {
             RGBColor[
             0.7587132727272727, 0.6230638636363635, 0.5912268181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 475}], {
             RGBColor[
             0.9230170909090909, 0.7517301363636362, 0.5757478636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 478}], {
             RGBColor[0.9341665909090908, 0.7585379545454545, 0.4893675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 482}], {
             RGBColor[
             0.916404409090909, 0.746798409090909, 0.5869414090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 267}], {
             RGBColor[
             0.8685648636363635, 0.7092208636363635, 0.6020855454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 393}], {
             RGBColor[
             0.9285457727272727, 0.9423128181818181, 0.8435302727272729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 485}], {
             RGBColor[
             0.6314042727272726, 0.7071885454545455, 0.9667308181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 281}], {
             RGBColor[
             0.8176590454545454, 0.8582599090909091, 0.9743103181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 295}], {
             RGBColor[
             0.7764321818181817, 0.8256140909090908, 0.9782609090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 324}], {
             RGBColor[
             0.8421578636363636, 0.8734568181818182, 0.7525920000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 341}], {
             RGBColor[
             0.8390093636363636, 0.8736804545454545, 0.9156674090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 374}], {
             RGBColor[0.8079908181818182, 0.850778090909091, 0.981271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 397}], {
             RGBColor[
             0.8425368181818181, 0.8742673636363636, 0.7938388636363634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 270}], {
             RGBColor[0.7522105909090908, 0.806692, 0.9758467272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 320}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 329}], {
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 424}], {
             RGBColor[
             0.9239607727272727, 0.9284057272727272, 0.6931360909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 293}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 317}], {
             RGBColor[0.7484935, 0.8024135454545456, 0.9566438636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 322}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 343}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 359}], {
             RGBColor[
             0.7227151818181817, 0.7814855454545454, 0.9546144999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 403}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 440}], {
             RGBColor[
             0.7227151818181817, 0.7814855454545454, 0.9546144999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 445}], {
             RGBColor[
             0.6792438181818181, 0.744766090909091, 0.9515866818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 471}], {
             RGBColor[
             0.9724789090909091, 0.9784929090909091, 0.9089678181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 483}], {
             RGBColor[
             0.8484933181818182, 0.8821137272727273, 0.9655309545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 280}], {
             RGBColor[
             0.681378318181818, 0.5602798636363635, 0.5851387272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 393}], {
             RGBColor[
             0.9350484545454545, 0.7586846818181816, 0.45891036363636384`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 424}], {
             RGBColor[
             0.9304634545454544, 0.7447775909090908, 0.3085161818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 480}], {
             RGBColor[
             0.916404409090909, 0.746798409090909, 0.5869414090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 485}], {
             RGBColor[
             0.6379069545454545, 0.523560409090909, 0.5821109090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 491}], {
             RGBColor[
             0.951937318181818, 0.8427626363636362, 0.530379818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 282}], {
             RGBColor[
             0.9322937272727272, 0.9479402727272728, 0.9618728181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 310}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 323}], {
             RGBColor[
             0.9322937272727272, 0.9479402727272728, 0.9618728181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 406}], {
             RGBColor[
             0.916514409090909, 0.9353582727272727, 0.9603677727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 411}], {
             RGBColor[
             0.9734302727272728, 0.954107090909091, 0.6474414545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 419}], {
             RGBColor[
             0.9806038636363636, 0.9840500000000001, 0.8727119999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 499}], {
             RGBColor[
             0.8308844090909091, 0.8681233636363637, 0.9519232272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 329}], {
             RGBColor[0.8132755, 0.854133, 0.9383155]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{270, 479}], {
             RGBColor[
             0.7364312727272728, 0.7941100000000001, 0.9743416818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 304}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 307}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 311}], {
             RGBColor[
             0.9511285909090909, 0.9630723636363636, 0.9676107272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 351}], {
             RGBColor[
             0.9724789090909091, 0.9784929090909091, 0.9089678181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 371}], {
             RGBColor[
             0.872714909090909, 0.9010358181818181, 0.9679451363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 429}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 442}], {
             RGBColor[
             0.9226528636363637, 0.7751711818181819, 0.5921552727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 435}], {
             RGBColor[
             0.9790915909090909, 0.9834246363636363, 0.8977742727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 453}], {
             RGBColor[0.990744, 0.9895686363636363, 0.7396899090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 497}], {
             RGBColor[
             0.9765725000000001, 0.9428562727272729, 0.5918286818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 279}], {
             RGBColor[
             0.7406013181818182, 0.7917507272727273, 0.7440897272727274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 283}], {
             RGBColor[
             0.6971299545454546, 0.7550312727272728, 0.7410619090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 285}], {
             RGBColor[0.8906010454545454, 0.911301, 0.7574203636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 396}], {
             RGBColor[
             0.8421578636363636, 0.8734568181818182, 0.7525920000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 421}], {
             RGBColor[0.8906010454545454, 0.911301, 0.7574203636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 430}], {
             RGBColor[
             0.9756274090909092, 0.9782692727272728, 0.7458924090909093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 459}], {
             RGBColor[
             0.9942714545454545, 0.9901555454545454, 0.617861363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 477}], {
             RGBColor[
             0.8421578636363636, 0.8734568181818182, 0.7525920000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 284}], {
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 300}], {
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 305}], {
             RGBColor[
             0.9601044090909091, 0.9674768181818182, 0.8465403636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 389}], {
             RGBColor[
             0.9589675454545454, 0.9650451818181819, 0.7227997727272725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 432}], {
             RGBColor[
             0.9505366818181819, 0.9367618181818183, 0.6767892272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 460}], {
             RGBColor[
             0.9577102727272727, 0.9667047272727274, 0.9020597727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 331}], {
             RGBColor[0.9822400909090909, 0.983201, 0.7346988636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 346}], {
             RGBColor[
             0.8793275909090909, 0.9059675454545455, 0.9567515909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 348}], {
             RGBColor[
             0.9818611363636364, 0.9823904545454546, 0.6934519999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 355}], {
             RGBColor[
             0.7551061818181819, 0.8073452727272727, 0.9454503181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 372}], {
             RGBColor[
             0.8997454545454545, 0.5990615909090908, 0.5544891363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 404}], {
             RGBColor[
             0.9053480909090909, 0.642125909090909, 0.5598542272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 418}], {
             RGBColor[
             0.8308844090909091, 0.8681233636363637, 0.9519232272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 431}], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 444}], {
             RGBColor[
             0.9480730454545454, 0.9605222727272728, 0.9633778636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 486}], {
             RGBColor[
             0.9480730454545454, 0.9605222727272728, 0.9633778636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 306}], {
             RGBColor[0.6361795454545454, 0.7030075, 0.9005341363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 347}], {
             RGBColor[
             0.48797236363636365`, 0.5877062272727273, 0.9546830909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 382}], {
             RGBColor[
             0.6148292272727272, 0.6875869545454545, 0.9591770454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 462}], {
             RGBColor[
             0.41219413636363644`, 0.5269281363636364, 0.9482101818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 288}], {
             RGBColor[
             0.8875097272727273, 0.9129128181818182, 0.9812498181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 313}], {
             RGBColor[
             0.8176590454545454, 0.8582599090909091, 0.9743103181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 340}], {
             RGBColor[
             0.9190683636363636, 0.9380768181818182, 0.9842599090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 373}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 386}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 414}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 498}], {
             RGBColor[
             0.8921227272727272, 0.6322624545454545, 0.5822413181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 401}], {
             RGBColor[
             0.9821161363636364, 0.9846753636363637, 0.8476497272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 451}], {
             RGBColor[
             0.7293278636363636, 0.7864172727272727, 0.9434209545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.6376888181818181, 0.7145172727272726, 0.9661424545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 318}], {
             RGBColor[
             0.513467409090909, 0.6158950000000001, 0.9548411818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 335}], {
             RGBColor[
             0.6906549545454544, 0.7564899999999999, 0.9712636818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 396}], {
             RGBColor[
             0.5892456363636362, 0.6766730909090908, 0.9613140909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 409}], {
             RGBColor[0.44421772727272724`, 0.5582475454545455, 0.949784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 421}], {
             RGBColor[
             0.6376888181818181, 0.7145172727272726, 0.9661424545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 430}], {
             RGBColor[
             0.7227151818181817, 0.7814855454545454, 0.9546144999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 459}], {
             RGBColor[
             0.7413592272727272, 0.7933718181818181, 0.8265834545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 477}], {
             RGBColor[
             0.5892456363636362, 0.6766730909090908, 0.9613140909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 338}], {
             RGBColor[
             0.7406013181818181, 0.7917507272727273, 0.7440897272727274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 383}], {
             RGBColor[
             0.7227151818181817, 0.7814855454545454, 0.9546144999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 393}], {
             RGBColor[
             0.7413592272727272, 0.7933718181818181, 0.8265834545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 480}], {
             RGBColor[
             0.7227151818181817, 0.7814855454545454, 0.9546144999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 317}], {
             RGBColor[
             0.7418808181818182, 0.7974818181818182, 0.9678374090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 322}], {
             RGBColor[
             0.8176590454545454, 0.8582599090909091, 0.9743103181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 324}], {
             RGBColor[
             0.9690147272727272, 0.9733375454545454, 0.7570859545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 343}], {
             RGBColor[
             0.9032890454545454, 0.9254948181818181, 0.9827548636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 374}], {
             RGBColor[
             0.9348476818181818, 0.9506588181818182, 0.9857649545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 397}], {
             RGBColor[
             0.9693936818181818, 0.9741480909090909, 0.798332818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 445}], {
             RGBColor[
             0.6726311363636364, 0.7398343636363636, 0.9627802272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 310}], {
             RGBColor[
             0.9190683636363636, 0.9380768181818182, 0.9842599090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 323}], {
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 406}], {
             RGBColor[0.8778414999999999, 0.9054309999999999, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 419}], {
             RGBColor[
             0.9419309545454545, 0.9541227272727273, 0.9005547272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 499}], {
             RGBColor[0.7922115, 0.8381960909090909, 0.9797659545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 396}], {
             RGBColor[
             0.5457742727272727, 0.6399536363636363, 0.9582862727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 421}], {
             RGBColor[
             0.5942174545454545, 0.6777978181818182, 0.9631146363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 430}], {
             RGBColor[
             0.6792438181818181, 0.744766090909091, 0.9515866818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 459}], {
             RGBColor[
             0.6978878636363637, 0.7566523636363636, 0.8235556363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 477}], {
             RGBColor[
             0.5457742727272727, 0.6399536363636363, 0.9582862727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 300}], {
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 345}], {
             RGBColor[
             0.9032890454545454, 0.9254948181818181, 0.9827548636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 389}], {
             RGBColor[
             0.927408909090909, 0.9398811818181818, 0.7197896818181816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 432}], {
             RGBColor[
             0.9189780454545454, 0.9115978181818181, 0.6737791363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 456}], {
             RGBColor[
             0.9277878636363637, 0.9406917272727273, 0.7610365454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 472}], {
             RGBColor[
             0.927408909090909, 0.9398811818181818, 0.7197896818181816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 287}], {
             RGBColor[
             0.8913589545454546, 0.9129220909090909, 0.8399140909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 354}], {
             RGBColor[
             0.8661022272727272, 0.8961040909090909, 0.9791386818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 396}], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 409}], {
             RGBColor[
             0.5942174545454545, 0.6777978181818182, 0.9631146363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 430}], {
             RGBColor[
             0.872714909090909, 0.9010358181818181, 0.9679451363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 473}], {
             RGBColor[
             0.8904770909090909, 0.9127753636363636, 0.8703712272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 477}], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 319}], {
             RGBColor[
             0.842033909090909, 0.8749311818181817, 0.8655428636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 330}], {
             RGBColor[
             0.8178123181818182, 0.8560090909090909, 0.8631286818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 357}], {
             RGBColor[
             0.9434432272727272, 0.9547480909090909, 0.8754924545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 358}], {
             RGBColor[
             0.9933895909090908, 0.9900088181818183, 0.6483185000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 367}], {
             RGBColor[
             0.9746143181818181, 0.9272990909090909, 0.5223471818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 368}], {
             RGBColor[
             0.9755034545454545, 0.9797436363636364, 0.8588432727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 492}], {
             RGBColor[0.8662555, 0.8938532727272728, 0.8679570454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 336}], {
             RGBColor[
             0.9896106818181818, 0.9897538181818182, 0.8059990454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 354}], {
             RGBColor[
             0.9697726363636363, 0.9749586363636363, 0.839579681818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 388}], {
             RGBColor[0.6781735, 0.7395767727272726, 0.8222994545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 409}], {
             RGBColor[
             0.6978878636363637, 0.7566523636363636, 0.8235556363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 436}], {
             RGBColor[
             0.9754961818181818, 0.9274458181818181, 0.4918900454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 473}], {
             RGBColor[0.9941475, 0.9916299090909091, 0.7308122272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 313}], {
             RGBColor[
             0.7606528636363636, 0.8130320909090909, 0.9767558636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 321}], {
             RGBColor[
             0.9088600454545455, 0.9283333636363637, 0.9226069090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 373}], {
             RGBColor[0.9073477727272727, 0.927708, 0.9476691818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 386}], {
             RGBColor[0.9073477727272727, 0.927708, 0.9476691818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 391}], {
             RGBColor[
             0.8652824545454546, 0.7533844090909092, 0.6110082272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 455}], {
             RGBColor[
             0.7364312727272728, 0.7941100000000001, 0.9743416818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 498}], {
             RGBColor[
             0.8351165454545455, 0.5870346363636363, 0.5846868636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 300}], {
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 308}], {
             RGBColor[
             0.7764321818181817, 0.8256140909090908, 0.9782609090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 314}], {
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 466}], {
             RGBColor[
             0.9285457727272727, 0.9423128181818181, 0.8435302727272729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 470}], {
             RGBColor[
             0.9032890454545454, 0.9254948181818181, 0.9827548636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 493}], {
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 297}], {
             RGBColor[
             0.8671373636363636, 0.8939999999999999, 0.8374999090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 484}], {
             RGBColor[0.8660005, 0.8915683636363636, 0.7137593181818179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 349}], {
             RGBColor[
             0.9887288181818181, 0.9896070909090909, 0.8364561818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 353}], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 394}], {
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 467}], {
             RGBColor[
             0.9884738181818182, 0.9873221818181819, 0.6822584545454543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 398}], {
             RGBColor[
             0.8941224090909091, 0.9178445454545454, 0.9700562727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 399}], {
             RGBColor[
             0.9118845909090909, 0.9295840909090909, 0.8724823636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 464}], {
             RGBColor[
             0.6848746363636364, 0.7522540000000001, 0.9702829545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 481}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 496}], {
             RGBColor[
             0.6590963181818181, 0.7313259999999999, 0.9682535909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 343}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 403}], {
             RGBColor[
             0.7764321818181817, 0.8256140909090908, 0.9782609090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 440}], {
             RGBColor[
             0.6748756363636362, 0.7439079999999999, 0.9697586363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 445}], {
             RGBColor[
             0.6314042727272726, 0.7071885454545455, 0.9667308181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 471}], {
             RGBColor[
             0.9246393636363636, 0.9409153636363636, 0.9241119545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 483}], {
             RGBColor[
             0.8006537727272727, 0.8445361818181818, 0.9806750909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 497}], {
             RGBColor[
             0.9139953181818181, 0.8947899090909092, 0.6544221818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 296}], {
             RGBColor[
             0.927663909090909, 0.9421660909090909, 0.8739874090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 327}], {
             RGBColor[
             0.9887288181818181, 0.9896070909090909, 0.8364561818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 385}], {
             RGBColor[
             0.9118845909090909, 0.9295840909090909, 0.8724823636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 415}], {
             RGBColor[
             0.9755034545454545, 0.9797436363636364, 0.8588432727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 438}], {
             RGBColor[
             0.9755034545454545, 0.9797436363636364, 0.8588432727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 439}], {
             RGBColor[0.8662555, 0.8938532727272728, 0.8679570454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 321}], {
             RGBColor[
             0.9246393636363636, 0.9409153636363636, 0.9241119545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 341}], {
             RGBColor[
             0.9246393636363636, 0.9409153636363636, 0.9241119545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 391}], {
             RGBColor[
             0.8810617727272727, 0.7659664090909092, 0.6125132727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 397}], {
             RGBColor[
             0.9281668181818181, 0.9415022727272726, 0.8022834090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 455}], {
             RGBColor[0.7522105909090908, 0.806692, 0.9758467272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 327}], {
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 339}], {
             RGBColor[
             0.9032890454545454, 0.9254948181818181, 0.9827548636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 385}], {
             RGBColor[
             0.8462828636363636, 0.8802669999999999, 0.9852004090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 415}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 438}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 325}], {
             RGBColor[
             0.8429157727272727, 0.8750779090909091, 0.8350857272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 392}], {
             RGBColor[
             0.8671373636363636, 0.8939999999999999, 0.8374999090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 412}], {
             RGBColor[
             0.9697726363636363, 0.9749586363636363, 0.839579681818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 413}], {
             RGBColor[0.6781735, 0.7395767727272726, 0.8222994545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 474}], {
             RGBColor[
             0.9285457727272727, 0.9423128181818181, 0.8435302727272729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 484}], {
             RGBColor[0.9938925000000001, 0.989345, 0.5766145]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{297, 490}], {
             RGBColor[
             0.8186941818181819, 0.8561558181818182, 0.8326715454545457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 335}], {
             RGBColor[0.8778414999999999, 0.9054309999999999, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 409}], {
             RGBColor[
             0.6314042727272726, 0.7071885454545455, 0.9667308181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 468}], {
             RGBColor[
             0.6748756363636362, 0.7439079999999999, 0.9697586363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 312}], {
             RGBColor[
             0.8233825909090908, 0.8107470909090908, 0.6266206818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 328}], {
             RGBColor[
             0.9743593181818182, 0.9250141818181818, 0.36814945454545434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 399}], {
             RGBColor[
             0.9746143181818181, 0.9272990909090909, 0.5223471818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 407}], {
             RGBColor[
             0.8718257727272727, 0.8485912727272726, 0.6314490454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 448}], {
             RGBColor[0.9405712272727274, 0.903146, 0.6380753181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 475}], {
             RGBColor[
             0.9634648181818182, 0.9204912727272727, 0.6087275454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 478}], {
             RGBColor[
             0.9746143181818181, 0.9272990909090909, 0.5223471818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 482}], {
             RGBColor[
             0.9568521363636364, 0.9155595454545454, 0.6199210909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 305}], {
             RGBColor[
             0.9601044090909091, 0.9674768181818182, 0.8465403636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 308}], {
             RGBColor[0.8079908181818182, 0.850778090909091, 0.981271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 432}], {
             RGBColor[
             0.9505366818181819, 0.9367618181818183, 0.6767892272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 456}], {
             RGBColor[
             0.9593465000000001, 0.9658557272727273, 0.7640466363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 493}], {
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 316}], {
             RGBColor[
             0.6376888181818181, 0.7145172727272726, 0.9661424545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 336}], {
             RGBColor[
             0.8859402727272727, 0.9108992727272727, 0.9455580454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 388}], {
             RGBColor[
             0.5745030909090908, 0.6607222272727272, 0.9618584545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 436}], {
             RGBColor[
             0.8718257727272727, 0.8485912727272726, 0.6314490454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 346}], {
             RGBColor[0.8376265, 0.7082029090909092, 0.6036832272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 370}], {
             RGBColor[
             0.8134049090909091, 0.6892808181818183, 0.6012690454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 390}], {
             RGBColor[
             0.9412969090909091, 0.7870574545454547, 0.4641242272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 422}], {
             RGBColor[
             0.8748133181818182, 0.7375936363636364, 0.6072994090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 443}], {
             RGBColor[
             0.9226528636363637, 0.7751711818181819, 0.5921552727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 451}], {
             RGBColor[
             0.6876267727272727, 0.5886526363636364, 0.590352590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 379}], {
             RGBColor[
             0.9434432272727272, 0.9547480909090909, 0.8754924545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 400}], {
             RGBColor[
             0.9895624999999999, 0.9777228181818182, 0.5804180454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 307}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 311}], {
             RGBColor[
             0.9511285909090909, 0.9630723636363636, 0.9676107272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 337}], {
             RGBColor[
             0.9755034545454545, 0.9797436363636364, 0.8588432727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 423}], {
             RGBColor[
             0.9718003181818182, 0.9659832727272727, 0.6779919545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 427}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 433}], {
             RGBColor[
             0.9668175909090909, 0.9491753636363636, 0.6586349999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 465}], {
             RGBColor[
             0.9760063636363636, 0.9790798181818181, 0.7871392727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 469}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 310}], {
             RGBColor[
             0.9697726363636363, 0.9749586363636363, 0.839579681818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 406}], {
             RGBColor[
             0.9285457727272727, 0.9423128181818181, 0.8435302727272729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 432}], {
             RGBColor[
             0.9854616363636364, 0.9610616363636364, 0.5306039545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 460}], {
             RGBColor[
             0.9926352272727272, 0.9910045454545455, 0.7558745000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 493}], {
             RGBColor[
             0.9601044090909091, 0.9674768181818182, 0.8465403636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 331}], {
             RGBColor[
             0.9903650454545454, 0.988758090909091, 0.6984430454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 347}], {
             RGBColor[
             0.8390093636363636, 0.8736804545454545, 0.9156674090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 382}], {
             RGBColor[
             0.9658662272727272, 0.9735611818181817, 0.9201613636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 431}], {
             RGBColor[
             0.9790915909090909, 0.9834246363636363, 0.8977742727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 486}], {
             RGBColor[0.956198, 0.9660793636363636, 0.9271220454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 337}], {
             RGBColor[
             0.9755034545454545, 0.9797436363636364, 0.8588432727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 427}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 433}], {
             RGBColor[
             0.9668175909090909, 0.9491753636363636, 0.6586349999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 442}], {
             RGBColor[
             0.9226528636363637, 0.7751711818181819, 0.5921552727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 469}], {
             RGBColor[
             0.9099017272727272, 0.9304265454545454, 0.9715613181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 500}], {
             RGBColor[
             0.6989581818181817, 0.7618416818181817, 0.9528428636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 362}], {
             RGBColor[
             0.7150237727272727, 0.7773012727272727, 0.9722305454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 369}], {
             RGBColor[
             0.7150237727272727, 0.7773012727272727, 0.9722305454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 389}], {
             RGBColor[
             0.8417789090909091, 0.8726462727272728, 0.7113451363636362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 456}], {
             RGBColor[
             0.8421578636363636, 0.8734568181818182, 0.7525920000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 393}], {
             RGBColor[
             0.9697726363636363, 0.9749586363636363, 0.839579681818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 424}], {
             RGBColor[
             0.9651876363636362, 0.9610515454545454, 0.6891854999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 323}], {
             RGBColor[
             0.9190683636363636, 0.9380768181818182, 0.9842599090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 406}], {
             RGBColor[
             0.9032890454545454, 0.9254948181818181, 0.9827548636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 408}], {
             RGBColor[
             0.9688907727272726, 0.9748119090909091, 0.8700368181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 419}], {
             RGBColor[
             0.9673784999999999, 0.9741865454545455, 0.8950990909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 366}], {
             RGBColor[
             0.8661022272727272, 0.8961040909090909, 0.9791386818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 405}], {
             RGBColor[0.9686357727272727, 0.972527, 0.7158390909090907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 423}], {
             RGBColor[
             0.9651876363636362, 0.9610515454545454, 0.6891854999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 429}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 465}], {
             RGBColor[
             0.9693936818181818, 0.9741480909090909, 0.798332818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 469}], {
             RGBColor[
             0.9032890454545454, 0.9254948181818181, 0.9827548636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 488}], {
             RGBColor[
             0.6529167727272727, 0.7227587727272726, 0.9615240454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 327}], {
             RGBColor[
             0.8374970909090909, 0.8730550909090908, 0.9407296818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 334}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 385}], {
             RGBColor[
             0.7606528636363636, 0.8130320909090909, 0.9767558636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 415}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 446}], {
             RGBColor[0.8079908181818182, 0.850778090909091, 0.981271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 386}], {
             RGBColor[
             0.8374970909090909, 0.8730550909090908, 0.9407296818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 391}], {
             RGBColor[
             0.7954317727272727, 0.6987315000000001, 0.6040687272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 407}], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 498}], {
             RGBColor[
             0.7652658636363636, 0.5323817272727271, 0.5777473636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 406}], {
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 411}], {
             RGBColor[
             0.9800429545454545, 0.9590388181818181, 0.636247909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 493}], {
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 349}], {
             RGBColor[
             0.9755034545454545, 0.9797436363636364, 0.8588432727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 353}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 364}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 378}], {
             RGBColor[
             0.9256810454545454, 0.9430085454545454, 0.9730663636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 380}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 487}], {
             RGBColor[
             0.6792438181818181, 0.744766090909091, 0.9515866818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 372}], {
             RGBColor[
             0.6581066818181818, 0.40761131818181806`, 0.5638799999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 418}], {
             RGBColor[
             0.5892456363636362, 0.6766730909090908, 0.9613140909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 322}], {
             RGBColor[
             0.6150239545454546, 0.697601090909091, 0.9633434545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 343}], {
             RGBColor[0.7006539545454545, 0.7648360000000001, 0.971788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 374}], {
             RGBColor[0.732212590909091, 0.79, 0.9747980909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 440}], {
             RGBColor[
             0.513467409090909, 0.6158950000000001, 0.9548411818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 445}], {
             RGBColor[
             0.4699960454545455, 0.5791755454545455, 0.9518133636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 471}], {
             RGBColor[0.7632311363636364, 0.8129023636363637, 0.9091945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 335}], {
             RGBColor[0.7164332727272728, 0.777418, 0.9732930454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 421}], {
             RGBColor[
             0.6634671363636364, 0.7354452727272728, 0.9681718181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 430}], {
             RGBColor[0.7484935, 0.8024135454545456, 0.9566438636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 459}], {
             RGBColor[
             0.7671375454545455, 0.8142998181818182, 0.8286128181818184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 330}], {
             RGBColor[
             0.6665805909090909, 0.739457090909091, 0.9674021818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 357}], {
             RGBColor[0.7922115, 0.8381960909090909, 0.9797659545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 368}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 492}], {
             RGBColor[
             0.7150237727272727, 0.7773012727272727, 0.9722305454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 329}], {
             RGBColor[0.9231270909090908, 0.94029, 0.9491742272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 424}], {
             RGBColor[
             0.9239607727272727, 0.9284057272727272, 0.6931360909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 341}], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 373}], {
             RGBColor[
             0.9857042727272727, 0.9883563636363637, 0.8865807272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 391}], {
             RGBColor[
             0.9436389545454545, 0.8140327727272729, 0.5499197727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 397}], {
             RGBColor[0.990744, 0.9895686363636363, 0.7396899090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 455}], {
             RGBColor[
             0.8147877727272728, 0.8547583636363636, 0.9132532272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 498}], {
             RGBColor[
             0.9134730454545454, 0.6476829999999999, 0.5235984090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 343}], {
             RGBColor[
             0.7764321818181817, 0.8256140909090908, 0.9782609090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 374}], {
             RGBColor[0.8079908181818182, 0.850778090909091, 0.981271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 440}], {
             RGBColor[
             0.5892456363636362, 0.6766730909090908, 0.9613140909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 445}], {
             RGBColor[
             0.5457742727272727, 0.6399536363636363, 0.9582862727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 471}], {
             RGBColor[
             0.8390093636363636, 0.8736804545454545, 0.9156674090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 419}], {
             RGBColor[
             0.9419309545454545, 0.9541227272727273, 0.9005547272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 449}], {
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 499}], {
             RGBColor[0.7922115, 0.8381960909090909, 0.9797659545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 342}], {
             RGBColor[
             0.7663796363636364, 0.8126787272727274, 0.7461190909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 360}], {
             RGBColor[
             0.8663794545454546, 0.8923789090909091, 0.7550061818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 457}], {
             RGBColor[
             0.9888527727272727, 0.9881327272727274, 0.7235053181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 392}], {
             RGBColor[
             0.7150237727272727, 0.7773012727272727, 0.9722305454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 413}], {
             RGBColor[
             0.526059909090909, 0.6228780454545454, 0.9570300909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 474}], {
             RGBColor[
             0.7764321818181817, 0.8256140909090908, 0.9782609090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 490}], {
             RGBColor[
             0.6665805909090909, 0.739457090909091, 0.9674021818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 338}], {
             RGBColor[
             0.7921579545454545, 0.8336067272727272, 0.7481484545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 346}], {
             RGBColor[
             0.6892454545454544, 0.7563732727272726, 0.9702011818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 355}], {
             RGBColor[0.5650240454545454, 0.657751, 0.958899909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 395}], {
             RGBColor[
             0.3848646818181817, 0.4920364999999999, 0.9472151363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 443}], {
             RGBColor[
             0.774271818181818, 0.8233415454545454, 0.9586732272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 334}], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 385}], {
             RGBColor[0.9073477727272727, 0.927708, 0.9476691818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 415}], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 446}], {
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 398}], {
             RGBColor[
             0.9752484545454545, 0.9774587272727273, 0.7046455454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 399}], {
             RGBColor[
             0.9930106363636364, 0.9891982727272728, 0.6070716363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 407}], {
             RGBColor[
             0.8902220909090909, 0.9104904545454546, 0.7161734999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 464}], {
             RGBColor[
             0.7660006818181819, 0.8118681818181819, 0.704872227272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 475}], {
             RGBColor[
             0.9818611363636364, 0.9823904545454546, 0.6934519999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 478}], {
             RGBColor[
             0.9930106363636364, 0.9891982727272728, 0.6070716363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 481}], {
             RGBColor[
             0.9589675454545454, 0.9650451818181819, 0.7227997727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 333}], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 352}], {
             RGBColor[
             0.8163000454545455, 0.8553837272727274, 0.8881909545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 357}], {
             RGBColor[
             0.767989909090909, 0.8192740000000001, 0.9773517727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 358}], {
             RGBColor[
             0.8179362727272728, 0.8545347272727273, 0.7501778181818184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 367}], {
             RGBColor[0.799161, 0.791825, 0.6242065]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 368}], {
             RGBColor[
             0.8000501363636363, 0.8442695454545455, 0.9607025909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 441}], {
             RGBColor[
             0.8066628181818182, 0.8492012727272727, 0.9495090454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 492}], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 348}], {
             RGBColor[
             0.993134590909091, 0.9877239090909091, 0.49412077272727273`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 372}], {
             RGBColor[
             0.9110189090909091, 0.6043950454545455, 0.3551579090909093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 382}], {
             RGBColor[
             0.9690147272727272, 0.9733375454545454, 0.7570859545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 404}], {
             RGBColor[
             0.9166215454545454, 0.6474593636363636, 0.36052300000000015`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 418}], {
             RGBColor[
             0.8421578636363636, 0.8734568181818182, 0.7525920000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 431}], {
             RGBColor[0.9822400909090909, 0.983201, 0.7346988636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 444}], {
             RGBColor[
             0.9593465000000001, 0.9658557272727273, 0.7640466363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 486}], {
             RGBColor[
             0.9593465000000001, 0.9658557272727273, 0.7640466363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 420}], {
             RGBColor[
             0.9246393636363636, 0.9409153636363636, 0.9241119545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 454}], {
             RGBColor[
             0.7264322727272725, 0.7857639999999999, 0.9738173636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 489}], {
             RGBColor[
             0.9246393636363636, 0.9409153636363636, 0.9241119545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 358}], {
             RGBColor[
             0.8663794545454546, 0.8923789090909091, 0.7550061818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 361}], {
             RGBColor[
             0.8551059999999999, 0.8870454545454545, 0.954337409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 367}], {
             RGBColor[
             0.8476041818181819, 0.8296691818181818, 0.6290348636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 386}], {
             RGBColor[
             0.8617186818181818, 0.8919771818181819, 0.9431438636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 441}], {
             RGBColor[
             0.8551059999999999, 0.8870454545454545, 0.954337409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 450}], {
             RGBColor[0.6650238636363635, 0.7374511818181817, 0.967787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 461}], {
             RGBColor[
             0.8632309545454545, 0.8926025454545454, 0.9180815909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 385}], {
             RGBColor[
             0.8941224090909091, 0.9178445454545454, 0.9700562727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 415}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 446}], {
             RGBColor[
             0.9414603636363637, 0.9555905454545455, 0.974571409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 409}], {
             RGBColor[
             0.6471835909090908, 0.7197705454545454, 0.9682358636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 421}], {
             RGBColor[
             0.8406546818181817, 0.8760402727272727, 0.9845943181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 430}], {
             RGBColor[
             0.9256810454545454, 0.9430085454545454, 0.9730663636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 459}], {
             RGBColor[
             0.9443250909090909, 0.9548948181818182, 0.8450353181818184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 354}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 388}], {
             RGBColor[
             0.6727548181818181, 0.7375539545454545, 0.9279434090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 436}], {
             RGBColor[0.9700774999999999, 0.925423, 0.597534]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{337, 420}], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 427}], {
             RGBColor[
             0.9755034545454545, 0.9797436363636364, 0.8588432727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 433}], {
             RGBColor[
             0.9845797727272727, 0.960914909090909, 0.561061090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 500}], {
             RGBColor[
             0.7167203636363635, 0.7735812272727272, 0.8552689545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 383}], {
             RGBColor[
             0.9756274090909092, 0.9782692727272728, 0.7458924090909093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 395}], {
             RGBColor[
             0.5862202727272727, 0.6469642272727273, 0.7344343181818184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 443}], {
             RGBColor[
             0.9756274090909092, 0.9782692727272728, 0.7458924090909093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 480}], {
             RGBColor[
             0.9756274090909092, 0.9782692727272728, 0.7458924090909093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 344}], {
             RGBColor[
             0.9511285909090909, 0.9630723636363636, 0.9676107272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 387}], {
             RGBColor[
             0.6726311363636364, 0.7398343636363636, 0.9627802272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 439}], {
             RGBColor[0.8418806363636363, 0.8771819999999999, 0.9767245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 384}], {
             RGBColor[
             0.9190683636363636, 0.9380768181818182, 0.9842599090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 414}], {
             RGBColor[
             0.9322937272727272, 0.9479402727272728, 0.9618728181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 461}], {
             RGBColor[0.9404186818181818, 0.9534973636363636, 0.925617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 499}], {
             RGBColor[0.7922115, 0.8381960909090909, 0.9797659545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 374}], {
             RGBColor[0.956198, 0.9660793636363636, 0.9271220454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 391}], {
             RGBColor[
             0.9436389545454545, 0.8140327727272729, 0.5499197727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 397}], {
             RGBColor[0.990744, 0.9895686363636363, 0.7396899090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 455}], {
             RGBColor[
             0.8147877727272728, 0.8547583636363636, 0.9132532272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 485}], {
             RGBColor[
             0.4699960454545455, 0.5791755454545455, 0.9518133636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 374}], {
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 403}], {
             RGBColor[
             0.7764321818181817, 0.8256140909090908, 0.9782609090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 440}], {
             RGBColor[
             0.6748756363636362, 0.7439079999999999, 0.9697586363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 445}], {
             RGBColor[
             0.6314042727272726, 0.7071885454545455, 0.9667308181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 471}], {
             RGBColor[
             0.9246393636363636, 0.9409153636363636, 0.9241119545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 387}], {
             RGBColor[
             0.6792438181818181, 0.744766090909091, 0.9515866818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 438}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 439}], {
             RGBColor[
             0.8484933181818182, 0.8821137272727273, 0.9655309545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 389}], {
             RGBColor[0.9686357727272727, 0.972527, 0.7158390909090907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 456}], {
             RGBColor[
             0.9690147272727272, 0.9733375454545454, 0.7570859545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 472}], {
             RGBColor[0.9686357727272727, 0.972527, 0.7158390909090907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 355}], {
             RGBColor[
             0.6634671363636364, 0.7354452727272728, 0.9681718181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 390}], {
             RGBColor[
             0.8913589545454546, 0.9129220909090909, 0.8399140909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 395}], {
             RGBColor[
             0.48330777272727266`, 0.5697307727272727, 0.9564870454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 431}], {
             RGBColor[
             0.8793275909090909, 0.9059675454545455, 0.9567515909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 443}], {
             RGBColor[
             0.872714909090909, 0.9010358181818181, 0.9679451363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 486}], {
             RGBColor[
             0.8564339999999999, 0.8886222727272728, 0.9860993636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 382}], {
             RGBColor[
             0.8176590454545454, 0.8582599090909091, 0.9743103181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 462}], {
             RGBColor[
             0.6150239545454546, 0.697601090909091, 0.9633434545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 355}], {
             RGBColor[
             0.7660006818181819, 0.8118681818181819, 0.704872227272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 372}], {
             RGBColor[0.9106399545454545, 0.6035845, 0.31391104545454523`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 400}], {
             RGBColor[0.9893075, 0.9754379090909091, 0.4262203181818179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 404}], {
             RGBColor[
             0.9162425909090909, 0.6466488181818182, 0.31927613636363616`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 418}], {
             RGBColor[
             0.8417789090909091, 0.8726462727272728, 0.711345136363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 431}], {
             RGBColor[
             0.9818611363636364, 0.9823904545454546, 0.6934519999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 444}], {
             RGBColor[
             0.9589675454545454, 0.9650451818181819, 0.7227997727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 486}], {
             RGBColor[
             0.9589675454545454, 0.9650451818181819, 0.7227997727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 353}], {
             RGBColor[
             0.9755034545454545, 0.9797436363636364, 0.8588432727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 378}], {
             RGBColor[
             0.9434432272727272, 0.9547480909090909, 0.8754924545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 380}], {
             RGBColor[
             0.9821161363636364, 0.9846753636363637, 0.8476497272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 487}], {
             RGBColor[0.697006, 0.7565056363636364, 0.8540127727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 377}], {
             RGBColor[
             0.9341665909090908, 0.7585379545454545, 0.48936750000000007`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 412}], {
             RGBColor[
             0.9688907727272726, 0.9748119090909091, 0.8700368181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 426}], {
             RGBColor[0.8662555, 0.8938532727272728, 0.8679570454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 476}], {
             RGBColor[
             0.9887288181818181, 0.9896070909090909, 0.8364561818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 371}], {
             RGBColor[
             0.8874525454545454, 0.9115246363636363, 0.9204957727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 442}], {
             RGBColor[0.9373905, 0.7856600000000001, 0.5447059090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 460}], {
             RGBColor[
             0.9887288181818181, 0.9896070909090909, 0.8364561818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 357}], {
             RGBColor[
             0.9419309545454545, 0.9541227272727273, 0.9005547272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 367}], {
             RGBColor[
             0.9731020454545454, 0.9266737272727272, 0.5474094545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 368}], {
             RGBColor[
             0.9739911818181818, 0.9791182727272727, 0.8839055454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 375}], {
             RGBColor[
             0.9205879545454545, 0.6913726818181821, 0.5039012272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 380}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 487}], {
             RGBColor[
             0.6792438181818181, 0.744766090909091, 0.9515866818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 388}], {
             RGBColor[
             0.6529167727272727, 0.7227587727272726, 0.9615240454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 409}], {
             RGBColor[
             0.6726311363636364, 0.7398343636363636, 0.9627802272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 436}], {
             RGBColor[
             0.9502394545454544, 0.9106278181818181, 0.6311146363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 473}], {
             RGBColor[
             0.9688907727272726, 0.9748119090909091, 0.8700368181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 395}], {
             RGBColor[
             0.3590863636363637, 0.47110850000000004`, 0.9451857727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 404}], {
             RGBColor[
             0.6894876363636364, 0.47160363636363634`, 0.5712744545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 431}], {
             RGBColor[
             0.7551061818181819, 0.8073452727272727, 0.9454503181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 443}], {
             RGBColor[0.7484935, 0.8024135454545456, 0.9566438636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 444}], {
             RGBColor[0.732212590909091, 0.79, 0.9747980909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 486}], {
             RGBColor[0.732212590909091, 0.79, 0.9747980909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 365}], {
             RGBColor[0.9405712272727274, 0.903146, 0.6380753181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 457}], {
             RGBColor[0.9546857272727273, 0.965454, 0.9521843181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 494}], {
             RGBColor[
             0.9094001363636364, 0.9305950000000001, 0.9912205909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 367}], {
             RGBColor[
             0.9247919090909091, 0.8905639999999999, 0.6365702727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 368}], {
             RGBColor[
             0.9256810454545454, 0.9430085454545454, 0.9730663636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 441}], {
             RGBColor[
             0.9322937272727272, 0.9479402727272728, 0.9618728181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 492}], {
             RGBColor[
             0.8164330909090909, 0.8571181818181818, 0.9821801363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 361}], {
             RGBColor[0.9822400909090909, 0.983201, 0.7346988636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 386}], {
             RGBColor[
             0.9888527727272727, 0.9881327272727274, 0.7235053181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 398}], {
             RGBColor[
             0.9756274090909092, 0.9782692727272728, 0.7458924090909093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 441}], {
             RGBColor[0.9822400909090909, 0.983201, 0.7346988636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 408}], {
             RGBColor[
             0.7404773636363635, 0.7932250909090909, 0.857040590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 440}], {
             RGBColor[
             0.4876890909090908, 0.5949669999999999, 0.9528118181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 463}], {
             RGBColor[
             0.7161024999999999, 0.7765538181818181, 0.9658080454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 483}], {
             RGBColor[
             0.6134672272727272, 0.6955951818181818, 0.9637282727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 457}], {
             RGBColor[
             0.8617186818181818, 0.8919771818181819, 0.9431438636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 494}], {
             RGBColor[
             0.8164330909090909, 0.8571181818181818, 0.9821801363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 386}], {
             RGBColor[
             0.9775793181818182, 0.9827992727272727, 0.9228365454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 398}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 441}], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 481}], {
             RGBColor[
             0.9480730454545454, 0.9605222727272728, 0.9633778636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 369}], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 470}], {
             RGBColor[0.8418806363636363, 0.8771819999999999, 0.9767245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 381}], {
             RGBColor[
             0.8667584090909091, 0.8931894545454545, 0.7962530454545452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 378}], {
             RGBColor[
             0.9322937272727272, 0.9479402727272728, 0.9618728181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 380}], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 381}], {
             RGBColor[
             0.9826190454545454, 0.9840115454545455, 0.775945727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 416}], {
             RGBColor[
             0.900735090909091, 0.9227762727272728, 0.9588627272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 452}], {
             RGBColor[
             0.8066628181818182, 0.8492012727272727, 0.9495090454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 468}], {
             RGBColor[
             0.7293278636363636, 0.7864172727272727, 0.9434209545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 487}], {
             RGBColor[0.6858565, 0.7496978181818181, 0.9403931363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 405}], {
             RGBColor[
             0.8902220909090909, 0.9104904545454546, 0.7161734999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 423}], {
             RGBColor[
             0.8867739545454545, 0.8990149999999999, 0.689519909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 429}], {
             RGBColor[
             0.8793275909090909, 0.9059675454545455, 0.9567515909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 465}], {
             RGBColor[
             0.8909799999999999, 0.9121115454545454, 0.7986672272727271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 469}], {
             RGBColor[
             0.8248753636363635, 0.8634582727272726, 0.9830892727272726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 488}], {
             RGBColor[
             0.5745030909090908, 0.6607222272727272, 0.9618584545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 368}], {
             RGBColor[
             0.9568521363636364, 0.9155595454545454, 0.6199210909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 375}], {
             RGBColor[
             0.9034489090909091, 0.6278139545454547, 0.23991677272727274`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 441}], {
             RGBColor[
             0.9634648181818182, 0.9204912727272727, 0.6087275454545453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 450}], {
             RGBColor[
             0.7733826818181817, 0.7708969999999999, 0.6221771363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 492}], {
             RGBColor[
             0.8484933181818182, 0.8821137272727273, 0.9655309545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 456}], {
             RGBColor[
             0.8663794545454546, 0.8923789090909091, 0.7550061818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 390}], {
             RGBColor[
             0.8671373636363636, 0.8939999999999999, 0.8374999090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 422}], {
             RGBColor[
             0.8006537727272727, 0.8445361818181818, 0.9806750909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 443}], {
             RGBColor[
             0.8484933181818182, 0.8821137272727273, 0.9655309545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 451}], {
             RGBColor[
             0.6134672272727272, 0.6955951818181818, 0.9637282727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 442}], {
             RGBColor[0.8376265, 0.7082029090909092, 0.6036832272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 460}], {
             RGBColor[0.8889648181818182, 0.91215, 0.8954334999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 400}], {
             RGBColor[
             0.9071918181818182, 0.5921090454545455, 0.2872574545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 404}], {
             RGBColor[
             0.834126909090909, 0.2633199545454544, 0.1803132727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 418}], {
             RGBColor[
             0.7596632272727273, 0.489317409090909, 0.5723822727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 431}], {
             RGBColor[
             0.8997454545454545, 0.5990615909090908, 0.5544891363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 444}], {
             RGBColor[
             0.8768518636363636, 0.5817163181818181, 0.583836909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 486}], {
             RGBColor[
             0.8768518636363636, 0.5817163181818181, 0.583836909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 449}], {
             RGBColor[
             0.938906409090909, 0.9528719999999999, 0.9506792727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 498}], {
             RGBColor[
             0.9119607727272727, 0.6470576363636362, 0.5486606818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 397}], {
             RGBColor[
             0.9597254545454545, 0.9666662727272728, 0.8052934999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 445}], {
             RGBColor[
             0.662962909090909, 0.7323525454545454, 0.969740909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 402}], {
             RGBColor[0.8564985, 0.6426809545454548, 0.5915570000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 417}], {
             RGBColor[
             0.8977253636363636, 0.6753267727272729, 0.5876064090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 441}], {
             RGBColor[
             0.9109507272727273, 0.6851902272727275, 0.5652193181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 450}], {
             RGBColor[
             0.7208685909090908, 0.5355959545454547, 0.5786689090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 461}], {
             RGBColor[
             0.9190756818181818, 0.6907473181818184, 0.5289635000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 391}], {
             RGBColor[
             0.7954317727272727, 0.6987315000000001, 0.6040687272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 448}], {
             RGBColor[0.8079908181818182, 0.850778090909091, 0.981271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 455}], {
             RGBColor[
             0.6665805909090909, 0.739457090909091, 0.9674021818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 475}], {
             RGBColor[
             0.8308844090909091, 0.8681233636363637, 0.9519232272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 482}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 412}], {
             RGBColor[
             0.9097917272727272, 0.7418666818181816, 0.5981349545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 426}], {
             RGBColor[
             0.8071564545454545, 0.6609080454545453, 0.5960551818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 476}], {
             RGBColor[
             0.9296297727272727, 0.7566618636363636, 0.5645543181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 380}], {
             RGBColor[
             0.9322937272727272, 0.9479402727272728, 0.9618728181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 416}], {
             RGBColor[0.8620621818181818, 0.892849, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 452}], {
             RGBColor[
             0.767989909090909, 0.8192740000000001, 0.9773517727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 487}], {
             RGBColor[
             0.6471835909090908, 0.7197705454545454, 0.9682358636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 400}], {
             RGBColor[
             0.9397400909090909, 0.9409877272727272, 0.6946411363636362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 404}], {
             RGBColor[
             0.8666751818181817, 0.6121986363636363, 0.5876969545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 440}], {
             RGBColor[
             0.6906549545454544, 0.7564899999999999, 0.9712636818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 487}], {
             RGBColor[0.6858565, 0.7496978181818181, 0.9403931363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 416}], {
             RGBColor[0.9123875, 0.9289202727272727, 0.8007783636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 468}], {
             RGBColor[
             0.7409802727272726, 0.7925612727272726, 0.7853365909090907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 425}], {
             RGBColor[
             0.8176590454545454, 0.8582599090909091, 0.9743103181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 462}], {
             RGBColor[
             0.7418808181818182, 0.7974818181818182, 0.9678374090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 393}], {
             RGBColor[
             0.9763853181818182, 0.9798903636363636, 0.8283861363636366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 395}], {
             RGBColor[
             0.5683341363636364, 0.6366990454545455, 0.9449590909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 443}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 480}], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 402}], {
             RGBColor[
             0.9032890454545454, 0.9254948181818181, 0.9827548636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 411}], {
             RGBColor[
             0.960204909090909, 0.9442436363636364, 0.6698285454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 458}], {
             RGBColor[
             0.8176590454545454, 0.8582599090909091, 0.9743103181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 461}], {
             RGBColor[
             0.9658662272727272, 0.9735611818181817, 0.9201613636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 499}], {
             RGBColor[
             0.8176590454545454, 0.8582599090909091, 0.9743103181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 415}], {
             RGBColor[
             0.8941224090909091, 0.9178445454545454, 0.9700562727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 446}], {
             RGBColor[0.8778415, 0.9054310000000001, 0.9882105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 441}], {
             RGBColor[
             0.9775793181818182, 0.9827992727272727, 0.9228365454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 498}], {
             RGBColor[
             0.9119607727272727, 0.6470576363636362, 0.5486606818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 439}], {
             RGBColor[
             0.5699958636363636, 0.6588757272727273, 0.9607004545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 436}], {
             RGBColor[
             0.6586403181818181, 0.6752459545454544, 0.613834409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 473}], {
             RGBColor[
             0.6772916363636363, 0.7394300454545455, 0.852756590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 456}], {
             RGBColor[
             0.993134590909091, 0.9877239090909091, 0.49412077272727273`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 472}], {
             RGBColor[
             0.9927556363636364, 0.9869133636363637, 0.4528739090909087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 422}], {
             RGBColor[
             0.9285457727272727, 0.9423128181818181, 0.8435302727272729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 443}], {
             RGBColor[
             0.9763853181818182, 0.9798903636363636, 0.8283861363636366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 451}], {
             RGBColor[
             0.7413592272727272, 0.7933718181818181, 0.8265834545454547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 407}], {
             RGBColor[
             0.8438749545454545, 0.7365756818181819, 0.6088970909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 448}], {
             RGBColor[
             0.9126204090909091, 0.7911304090909093, 0.6155233636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 455}], {
             RGBColor[
             0.7712101818181818, 0.6798094090909093, 0.6016545454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 475}], {
             RGBColor[0.935514, 0.808475681818182, 0.5861755909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 478}], {
             RGBColor[0.9466635, 0.8152835000000002, 0.49979522727272735`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 482}], {
             RGBColor[
             0.9289013181818182, 0.8035439545454547, 0.5973691363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 413}], {
             RGBColor[
             0.5502814999999999, 0.6418001363636363, 0.9594442727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 473}], {
             RGBColor[0.8662555, 0.8938532727272728, 0.8679570454545456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 474}], {
             RGBColor[
             0.8006537727272727, 0.8445361818181818, 0.9806750909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 490}], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 424}], {
             RGBColor[
             0.9904443636363636, 0.9778695454545454, 0.5499609090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 480}], {
             RGBColor[
             0.9763853181818182, 0.9798903636363636, 0.8283861363636366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 467}], {
             RGBColor[
             0.9589675454545454, 0.9650451818181819, 0.7227997727272725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 443}], {
             RGBColor[
             0.5683341363636363, 0.6366990454545454, 0.9449590909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 430}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 477}], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 495}], {
             RGBColor[
             0.9597254545454545, 0.9666662727272728, 0.8052934999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 399}], {
             RGBColor[
             0.9755034545454545, 0.9797436363636364, 0.8588432727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 464}], {
             RGBColor[0.7484935, 0.8024135454545456, 0.9566438636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 481}], {
             RGBColor[
             0.9414603636363637, 0.9555905454545455, 0.974571409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 496}], {
             RGBColor[
             0.7227151818181817, 0.7814855454545454, 0.9546144999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 407}], {
             RGBColor[
             0.8904770909090909, 0.9127753636363636, 0.8703712272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 464}], {
             RGBColor[
             0.7662556818181818, 0.814153090909091, 0.8590699545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 478}], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 481}], {
             RGBColor[
             0.9592225454545454, 0.967330090909091, 0.8769975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 496}], {
             RGBColor[
             0.7404773636363635, 0.7932250909090909, 0.857040590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 404}], {
             RGBColor[
             0.9127944545454545, 0.6351733636363635, 0.29262254545454536`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 418}], {
             RGBColor[
             0.8383307727272726, 0.8611708181818181, 0.6846915454545452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 431}], {
             RGBColor[0.978413, 0.970915, 0.6667984090909089]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{400, 444}], {
             RGBColor[
             0.9555194090909092, 0.9535697272727273, 0.6961461818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 428}], {
             RGBColor[
             0.9821161363636364, 0.9846753636363637, 0.8476497272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 437}], {
             RGBColor[0.697006, 0.7565056363636364, 0.8540127727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 451}], {
             RGBColor[
             0.7404773636363635, 0.7932250909090909, 0.857040590909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 417}], {
             RGBColor[
             0.9032890454545454, 0.9254948181818181, 0.9827548636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 458}], {
             RGBColor[
             0.7764321818181817, 0.8256140909090908, 0.9782609090909091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 461}], {
             RGBColor[
             0.9246393636363636, 0.9409153636363636, 0.9241119545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 440}], {
             RGBColor[
             0.5892456363636362, 0.6766730909090908, 0.9613140909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 445}], {
             RGBColor[
             0.5457742727272727, 0.6399536363636363, 0.9582862727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 471}], {
             RGBColor[
             0.8390093636363636, 0.8736804545454545, 0.9156674090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 483}], {
             RGBColor[
             0.7150237727272727, 0.7773012727272727, 0.9722305454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 497}], {
             RGBColor[0.8283653181818182, 0.827555, 0.6459776363636365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 418}], {
             RGBColor[
             0.7652658636363636, 0.5323817272727271, 0.5777473636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 431}], {
             RGBColor[
             0.9053480909090909, 0.642125909090909, 0.5598542272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 444}], {
             RGBColor[0.8824544999999999, 0.6247806363636363, 0.589202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 486}], {
             RGBColor[0.8824544999999999, 0.6247806363636363, 0.589202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 423}], {
             RGBColor[0.9893075, 0.9754379090909091, 0.4262203181818179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 429}], {
             RGBColor[
             0.9818611363636364, 0.9823904545454546, 0.6934519999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 472}], {
             RGBColor[
             0.9927556363636364, 0.9869133636363637, 0.4528739090909087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 488}], {
             RGBColor[
             0.6770366363636363, 0.7371451363636363, 0.6985588636363634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 419}], {
             RGBColor[
             0.9261516363636363, 0.9415407272727272, 0.8990496818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 493}], {
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 448}], {
             RGBColor[
             0.8564339999999999, 0.8886222727272728, 0.9860993636363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 455}], {
             RGBColor[
             0.7150237727272727, 0.7773012727272728, 0.9722305454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 475}], {
             RGBColor[
             0.8793275909090909, 0.9059675454545455, 0.9567515909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 478}], {
             RGBColor[
             0.8904770909090909, 0.9127753636363636, 0.8703712272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 482}], {
             RGBColor[
             0.872714909090909, 0.9010358181818181, 0.9679451363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{408, 463}], {
             RGBColor[
             0.9688907727272726, 0.9748119090909091, 0.8700368181818183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 430}], {
             RGBColor[
             0.6792438181818181, 0.744766090909091, 0.9515866818181817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 422}], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 428}], {
             RGBColor[
             0.916514409090909, 0.9353582727272727, 0.9603677727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 437}], {
             RGBColor[
             0.6314042727272726, 0.7071885454545455, 0.9667308181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{412, 426}], {
             RGBColor[0.8418806363636363, 0.8771819999999999, 0.9767245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{412, 476}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 474}], {
             RGBColor[
             0.6116899090909089, 0.6901129545454544, 0.9654746363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 490}], {
             RGBColor[
             0.5018383181818181, 0.6039559545454545, 0.954615909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 461}], {
             RGBColor[
             0.9790915909090909, 0.9834246363636363, 0.8977742727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 498}], {
             RGBColor[
             0.9053480909090909, 0.642125909090909, 0.5598542272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 499}], {
             RGBColor[
             0.8308844090909091, 0.8681233636363637, 0.9519232272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 452}], {
             RGBColor[
             0.7364312727272728, 0.7941100000000001, 0.9743416818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 468}], {
             RGBColor[
             0.6590963181818181, 0.7313259999999999, 0.9682535909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{417, 458}], {
             RGBColor[
             0.8176590454545454, 0.8582599090909091, 0.9743103181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 431}], {
             RGBColor[
             0.8308844090909091, 0.8681233636363637, 0.9519232272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 444}], {
             RGBColor[0.8079908181818182, 0.850778090909091, 0.981271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 486}], {
             RGBColor[0.8079908181818182, 0.850778090909091, 0.981271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 427}], {
             RGBColor[
             0.9724789090909091, 0.9784929090909091, 0.9089678181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 454}], {
             RGBColor[
             0.7890094545454545, 0.8338303636363635, 0.9112238636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 489}], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 500}], {
             RGBColor[0.713695818181818, 0.7723304999999998, 0.9053935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 430}], {
             RGBColor[
             0.872714909090909, 0.9010358181818181, 0.9679451363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 459}], {
             RGBColor[
             0.8913589545454546, 0.9129220909090909, 0.8399140909090911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 477}], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 428}], {
             RGBColor[
             0.916514409090909, 0.9353582727272727, 0.9603677727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 437}], {
             RGBColor[
             0.6314042727272726, 0.7071885454545455, 0.9667308181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 451}], {
             RGBColor[
             0.6748756363636362, 0.7439079999999999, 0.9697586363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 429}], {
             RGBColor[0.978413, 0.970915, 0.6667984090909089]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{423, 465}], {
             RGBColor[
             0.9900654090909091, 0.9770589999999999, 0.5087140454545451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 469}], {
             RGBColor[
             0.9239607727272727, 0.9284057272727272, 0.6931360909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 488}], {
             RGBColor[
             0.6735884999999999, 0.7256696818181817, 0.6719052727272725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{425, 462}], {
             RGBColor[
             0.6150239545454546, 0.697601090909091, 0.9633434545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 476}], {
             RGBColor[
             0.8617186818181818, 0.8919771818181819, 0.9431438636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 433}], {
             RGBColor[
             0.9668175909090909, 0.9491753636363636, 0.6586349999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 500}], {
             RGBColor[
             0.6989581818181817, 0.7618416818181817, 0.9528428636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 437}], {
             RGBColor[0.6858565, 0.7496978181818181, 0.9403931363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 451}], {
             RGBColor[
             0.7293278636363636, 0.7864172727272727, 0.9434209545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{429, 488}], {
             RGBColor[
             0.6661421363636363, 0.7326222272727272, 0.9391369545454544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{430, 459}], {
             RGBColor[
             0.9763853181818182, 0.9798903636363636, 0.8283861363636366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{430, 477}], {
             RGBColor[
             0.8242717272727272, 0.8631916363636363, 0.9631167727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 444}], {
             RGBColor[
             0.9480730454545454, 0.9605222727272728, 0.9633778636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 486}], {
             RGBColor[
             0.9480730454545454, 0.9605222727272728, 0.9633778636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{432, 460}], {
             RGBColor[0.9830675, 0.9602895454545455, 0.5861233636363634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 465}], {
             RGBColor[
             0.9850826818181818, 0.9602510909090909, 0.48935709090909063`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 469}], {
             RGBColor[
             0.9189780454545454, 0.9115978181818181, 0.6737791363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 495}], {
             RGBColor[
             0.8322124090909091, 0.8697001818181818, 0.9836851818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{435, 439}], {
             RGBColor[
             0.8551059999999999, 0.8870454545454545, 0.954337409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{435, 453}], {
             RGBColor[
             0.9826190454545454, 0.9840115454545455, 0.775945727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 473}], {
             RGBColor[
             0.9746143181818181, 0.9272990909090909, 0.5223471818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 439}], {
             RGBColor[
             0.8484933181818182, 0.8821137272727273, 0.9655309545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{439, 453}], {
             RGBColor[
             0.8667584090909091, 0.8931894545454545, 0.7962530454545452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 445}], {
             RGBColor[0.44421772727272724`, 0.5582475454545455, 0.949784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 471}], {
             RGBColor[
             0.7374528181818181, 0.7919743636363636, 0.9071651363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 450}], {
             RGBColor[
             0.7808844999999999, 0.8282732727272726, 0.9474796818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 461}], {
             RGBColor[
             0.9790915909090909, 0.9834246363636363, 0.8977742727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 447}], {
             RGBColor[
             0.6244410454545455, 0.534857590909091, 0.5860685909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 500}], {
             RGBColor[
             0.6638697727272727, 0.5690087727272728, 0.5885809545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{443, 451}], {
             RGBColor[
             0.7227151818181817, 0.7814855454545454, 0.9546144999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{444, 486}], {
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{445, 471}], {
             RGBColor[
             0.6939814545454546, 0.7552549090909091, 0.9041373181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 454}], {
             RGBColor[
             0.4760599999999998, 0.5830279545454544, 0.9525865454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 500}], {
             RGBColor[
             0.40074636363636346`, 0.5215280909090907, 0.9467561818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 455}], {
             RGBColor[0.7837692272727272, 0.831856, 0.9788568181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 475}], {
             RGBColor[
             0.9480730454545454, 0.9605222727272728, 0.9633778636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 478}], {
             RGBColor[
             0.9592225454545454, 0.967330090909091, 0.8769975000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 482}], {
             RGBColor[
             0.9414603636363637, 0.9555905454545455, 0.974571409090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{449, 499}], {
             RGBColor[0.7922115, 0.8381960909090909, 0.9797659545454545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 461}], {
             RGBColor[
             0.7890094545454545, 0.8338303636363635, 0.9112238636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{452, 468}], {
             RGBColor[0.5650240454545454, 0.657751, 0.958899909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 489}], {
             RGBColor[
             0.7890094545454545, 0.8338303636363635, 0.9112238636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 500}], {
             RGBColor[
             0.5154887272727271, 0.6171791363636361, 0.955098909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{455, 475}], {
             RGBColor[
             0.8066628181818182, 0.8492012727272727, 0.9495090454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{455, 482}], {
             RGBColor[
             0.8000501363636363, 0.8442695454545455, 0.9607025909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{457, 494}], {
             RGBColor[
             0.938906409090909, 0.9528719999999999, 0.9506792727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{458, 461}], {
             RGBColor[
             0.8390093636363636, 0.8736804545454545, 0.9156674090909092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{459, 477}], {
             RGBColor[
             0.8429157727272727, 0.8750779090909091, 0.8350857272727275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{460, 463}], {
             RGBColor[
             0.9673784999999999, 0.9741865454545455, 0.8950990909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{463, 483}], {
             RGBColor[0.8418806363636363, 0.8771819999999999, 0.9767245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 481}], {
             RGBColor[0.732212590909091, 0.79, 0.9747980909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 496}], {
             RGBColor[
             0.513467409090909, 0.6158950000000001, 0.9548411818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{465, 469}], {
             RGBColor[
             0.9281668181818181, 0.9415022727272726, 0.8022834090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 470}], {
             RGBColor[
             0.9697726363636363, 0.9749586363636363, 0.839579681818182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 491}], {
             RGBColor[
             0.9543314545454544, 0.8435347272727272, 0.47486040909090926`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 483}], {
             RGBColor[
             0.8632309545454545, 0.8926025454545454, 0.9180815909090909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 497}], {
             RGBColor[
             0.9765725000000001, 0.9428562727272729, 0.5918286818181819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{472, 488}], {
             RGBColor[
             0.6770366363636363, 0.7371451363636363, 0.6985588636363634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{474, 490}], {
             RGBColor[0.7522105909090908, 0.806692, 0.9758467272727273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{475, 478}], {
             RGBColor[
             0.9821161363636364, 0.9846753636363637, 0.8476497272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{475, 482}], {
             RGBColor[
             0.9643539545454545, 0.9729358181818182, 0.9452236363636364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{478, 482}], {
             RGBColor[
             0.9755034545454545, 0.9797436363636364, 0.8588432727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{481, 496}], {
             RGBColor[0.7064342727272727, 0.769072, 0.9727687272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{484, 490}], {
             RGBColor[
             0.8175573181818182, 0.8537241818181819, 0.7089309545454543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{489, 500}], {
             RGBColor[0.713695818181818, 0.7723304999999998, 0.9053935]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.028685633809430733`], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.028685633809430733`], {
             RGBColor[
             0.9758939090909091, 0.9303466363636363, 0.360852818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.028685633809430733`], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.028685633809430733`], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.028685633809430733`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.028685633809430733`], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.028685633809430733`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.028685633809430733`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.028685633809430733`], {
             RGBColor[
             0.9942714545454545, 0.9901555454545454, 0.6178613636363632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.028685633809430733`], {
             RGBColor[0.8305035454545455, 0.867685, 0.9836953636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.028685633809430733`], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.028685633809430733`], {
             RGBColor[
             0.8750675454545453, 0.525592727272727, 0.2174656363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.028685633809430733`], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.028685633809430733`], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.028685633809430733`], {
             RGBColor[
             0.5908023636363634, 0.6786789999999998, 0.9609292727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.028685633809430733`], {
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.028685633809430733`], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.028685633809430733`], {
             RGBColor[
             0.7876885454545454, 0.8340675454545454, 0.9794730909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.028685633809430733`], {
             RGBColor[0.642359, 0.720535, 0.964988]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.028685633809430733`], {
             RGBColor[
             0.7876885454545454, 0.8340675454545454, 0.9794730909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.028685633809430733`], {
             RGBColor[
             0.4876890909090908, 0.5949669999999999, 0.9528118181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.028685633809430733`], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.028685633809430733`], {
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.028685633809430733`], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.028685633809430733`], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.028685633809430733`], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.028685633809430733`], {
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.028685633809430733`], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.028685633809430733`], {
             RGBColor[
             0.2143321818181818, 0.34260709090909086`, 0.9355172727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.028685633809430733`], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.028685633809430733`], {
             RGBColor[
             0.5392457272727273, 0.6368230000000001, 0.9568705454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.028685633809430733`], {
             RGBColor[
             0.4007463636363636, 0.5215280909090909, 0.9467561818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.028685633809430733`], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.028685633809430733`], {
             RGBColor[
             0.9935135454545455, 0.9885344545454546, 0.5353676363636367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.028685633809430733`], {
             RGBColor[
             0.36131763636363623`, 0.48737690909090897`, 0.9442438181818181]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.028685633809430733`], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.028685633809430733`], {
             RGBColor[
             0.5908023636363634, 0.6786789999999998, 0.9609292727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.028685633809430733`], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.028685633809430733`], {
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.028685633809430733`], {
             RGBColor[0.8305035454545455, 0.867685, 0.9836953636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.028685633809430733`], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.028685633809430733`], {
             RGBColor[
             0.9935135454545455, 0.9885344545454546, 0.5353676363636367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.028685633809430733`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.028685633809430733`], {
             RGBColor[
             0.7876885454545454, 0.8340675454545454, 0.9794730909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.028685633809430733`], {
             RGBColor[
             0.5908023636363634, 0.6786789999999998, 0.9609292727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.028685633809430733`], {
             RGBColor[
             0.5392457272727273, 0.6368230000000001, 0.9568705454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.028685633809430733`], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.028685633809430733`], {
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.028685633809430733`], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.028685633809430733`], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.028685633809430733`], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.028685633809430733`], {
             RGBColor[
             0.4876890909090908, 0.5949669999999999, 0.9528118181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.028685633809430733`], {
             RGBColor[
             0.4401750909090907, 0.5556792727272725, 0.9492685454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.028685633809430733`], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.028685633809430733`], {
             RGBColor[
             0.5392457272727273, 0.6368230000000001, 0.9568705454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.028685633809430733`], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.028685633809430733`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.028685633809430733`], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.028685633809430733`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.028685633809430733`], {
             RGBColor[
             0.9950293636363636, 0.9917766363636363, 0.7003550909090913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.028685633809430733`], {
             RGBColor[0.642359, 0.720535, 0.964988]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.028685633809430733`], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.028685633809430733`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.028685633809430733`], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.028685633809430733`], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.028685633809430733`], {
             RGBColor[
             0.9858593636363636, 0.9639624545454545, 0.3995667272727271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.028685633809430733`], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.028685633809430733`], {
             RGBColor[
             0.9758939090909091, 0.9303466363636363, 0.360852818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.028685633809430733`], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.028685633809430733`], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.028685633809430733`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.028685633809430733`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.028685633809430733`], {
             RGBColor[
             0.9942714545454545, 0.9901555454545454, 0.6178613636363632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.028685633809430733`], {
             RGBColor[
             0.9950293636363636, 0.9917766363636363, 0.7003550909090913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.028685633809430733`], {
             RGBColor[
             0.4007463636363636, 0.5215280909090909, 0.9467561818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.028685633809430733`], {
             RGBColor[
             0.9950293636363636, 0.9917766363636363, 0.7003550909090913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.028685633809430733`], {
             RGBColor[
             0.36131763636363623`, 0.48737690909090897`, 0.9442438181818181]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.028685633809430733`], {
             RGBColor[0.8305035454545455, 0.867685, 0.9836953636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.028685633809430733`], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.028685633809430733`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.028685633809430733`], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.028685633809430733`], {
             RGBColor[
             0.9858593636363636, 0.9639624545454545, 0.3995667272727271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.028685633809430733`], {
             RGBColor[
             0.9858593636363636, 0.9639624545454545, 0.3995667272727271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.028685633809430733`], {
             RGBColor[0.8305035454545455, 0.867685, 0.9836953636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.028685633809430733`], {
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.028685633809430733`], {
             RGBColor[
             0.5908023636363634, 0.6786789999999998, 0.9609292727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.028685633809430733`], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.028685633809430733`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.028685633809430733`], {
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.028685633809430733`], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.028685633809430733`], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.028685633809430733`], {
             RGBColor[
             0.36131763636363623`, 0.48737690909090897`, 0.9442438181818181]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.028685633809430733`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.028685633809430733`], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.028685633809430733`], {
             RGBColor[
             0.9942714545454545, 0.9901555454545454, 0.6178613636363632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.028685633809430733`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.028685633809430733`], {
             RGBColor[0.8305035454545455, 0.867685, 0.9836953636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.028685633809430733`], {
             RGBColor[
             0.9858593636363636, 0.9639624545454545, 0.3995667272727271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.028685633809430733`], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.028685633809430733`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.028685633809430733`], {
             RGBColor[
             0.5908023636363634, 0.6786789999999998, 0.9609292727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.028685633809430733`], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.028685633809430733`], {
             RGBColor[
             0.8750675454545453, 0.525592727272727, 0.2174656363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.028685633809430733`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.028685633809430733`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.028685633809430733`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.028685633809430733`], {
             RGBColor[0.642359, 0.720535, 0.964988]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.028685633809430733`], {
             RGBColor[
             0.7876885454545454, 0.8340675454545454, 0.9794730909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.028685633809430733`], {
             RGBColor[
             0.4007463636363636, 0.5215280909090909, 0.9467561818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.028685633809430733`], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.028685633809430733`], {
             RGBColor[
             0.5392457272727273, 0.6368230000000001, 0.9568705454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.028685633809430733`], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.028685633809430733`], {
             RGBColor[
             0.36131763636363623`, 0.48737690909090897`, 0.9442438181818181]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.028685633809430733`], {
             RGBColor[0.642359, 0.720535, 0.964988]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.028685633809430733`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.028685633809430733`], {
             RGBColor[0.8305035454545455, 0.867685, 0.9836953636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.028685633809430733`], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.028685633809430733`], {
             RGBColor[
             0.36131763636363623`, 0.48737690909090897`, 0.9442438181818181]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.028685633809430733`], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.028685633809430733`], {
             RGBColor[
             0.321888909090909, 0.45322572727272714`, 0.9417314545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.028685633809430733`], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.028685633809430733`], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.028685633809430733`], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.028685633809430733`], {
             RGBColor[
             0.9935135454545455, 0.9885344545454546, 0.5353676363636367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.028685633809430733`], {
             RGBColor[
             0.9858593636363636, 0.9639624545454545, 0.3995667272727271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.028685633809430733`], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.028685633809430733`], {
             RGBColor[
             0.8625706363636363, 0.4688471818181815, 0.20703790909090902`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.028685633809430733`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.028685633809430733`], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.028685633809430733`], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.028685633809430733`], {
             RGBColor[
             0.9927556363636364, 0.9869133636363637, 0.4528739090909087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.028685633809430733`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.028685633809430733`], {
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.028685633809430733`], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.028685633809430733`], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.028685633809430733`], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.028685633809430733`], {
             RGBColor[
             0.7876885454545454, 0.8340675454545454, 0.9794730909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.028685633809430733`], {
             RGBColor[
             0.7876885454545454, 0.8340675454545454, 0.9794730909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.028685633809430733`], {
             RGBColor[
             0.9950293636363636, 0.9917766363636363, 0.7003550909090913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.028685633809430733`], {
             RGBColor[
             0.9758939090909091, 0.9303466363636363, 0.360852818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.028685633809430733`], {
             RGBColor[
             0.9942714545454545, 0.9901555454545454, 0.6178613636363632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.028685633809430733`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.028685633809430733`], {
             RGBColor[
             0.4007463636363636, 0.5215280909090909, 0.9467561818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.028685633809430733`], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.028685633809430733`], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.028685633809430733`], {
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.028685633809430733`], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.028685633809430733`], {
             RGBColor[
             0.9858593636363636, 0.9639624545454545, 0.3995667272727271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.028685633809430733`], {
             RGBColor[
             0.9758939090909091, 0.9303466363636363, 0.360852818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.028685633809430733`], {
             RGBColor[0.642359, 0.720535, 0.964988]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.028685633809430733`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.028685633809430733`], {
             RGBColor[
             0.5908023636363634, 0.6786789999999998, 0.9609292727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.028685633809430733`], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.028685633809430733`], {
             RGBColor[
             0.7876885454545454, 0.8340675454545454, 0.9794730909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.028685633809430733`], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.028685633809430733`], {
             RGBColor[
             0.9950293636363636, 0.9917766363636363, 0.7003550909090913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.028685633809430733`], {
             RGBColor[
             0.9942714545454545, 0.9901555454545454, 0.6178613636363632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.028685633809430733`], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.028685633809430733`], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.028685633809430733`], {
             RGBColor[
             0.36131763636363623`, 0.48737690909090897`, 0.9442438181818181]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.028685633809430733`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.028685633809430733`], {
             RGBColor[
             0.4007463636363636, 0.5215280909090909, 0.9467561818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.028685633809430733`], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.028685633809430733`], {
             RGBColor[
             0.7876885454545454, 0.8340675454545454, 0.9794730909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.028685633809430733`], {
             RGBColor[
             0.9858593636363636, 0.9639624545454545, 0.3995667272727271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.028685633809430733`], {
             RGBColor[
             0.36131763636363623`, 0.48737690909090897`, 0.9442438181818181]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.028685633809430733`], {
             RGBColor[0.642359, 0.720535, 0.964988]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.028685633809430733`], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.028685633809430733`], {
             RGBColor[0.8305035454545455, 0.867685, 0.9836953636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.028685633809430733`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.028685633809430733`], {
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.028685633809430733`], {
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.028685633809430733`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.028685633809430733`], {
             RGBColor[
             0.9950293636363636, 0.9917766363636363, 0.7003550909090913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.028685633809430733`], {
             RGBColor[
             0.9950293636363636, 0.9917766363636363, 0.7003550909090913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.028685633809430733`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.028685633809430733`], {
             RGBColor[
             0.9927556363636364, 0.9869133636363637, 0.4528739090909087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.028685633809430733`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.028685633809430733`], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.028685633809430733`], {
             RGBColor[0.8305035454545455, 0.867685, 0.9836953636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.028685633809430733`], {
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.028685633809430733`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.028685633809430733`], {
             RGBColor[
             0.4876890909090908, 0.5949669999999999, 0.9528118181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.028685633809430733`], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.028685633809430733`], {
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.028685633809430733`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.028685633809430733`], {
             RGBColor[
             0.9950293636363636, 0.9917766363636363, 0.7003550909090913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.028685633809430733`], {
             RGBColor[
             0.9950293636363636, 0.9917766363636363, 0.7003550909090913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.028685633809430733`], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.028685633809430733`], {
             RGBColor[0.8305035454545455, 0.867685, 0.9836953636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.028685633809430733`], {
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.028685633809430733`], {
             RGBColor[
             0.5908023636363634, 0.6786789999999998, 0.9609292727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.028685633809430733`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.028685633809430733`], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.028685633809430733`], {
             RGBColor[0.8305035454545455, 0.867685, 0.9836953636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.028685633809430733`], {
             RGBColor[
             0.5392457272727273, 0.6368230000000001, 0.9568705454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.028685633809430733`], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.028685633809430733`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.028685633809430733`], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.028685633809430733`], {
             RGBColor[
             0.5908023636363634, 0.6786789999999998, 0.9609292727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.028685633809430733`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.028685633809430733`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.028685633809430733`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.028685633809430733`], {
             RGBColor[
             0.4007463636363636, 0.5215280909090909, 0.9467561818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.028685633809430733`], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.028685633809430733`], {
             RGBColor[
             0.9935135454545455, 0.9885344545454546, 0.5353676363636367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.028685633809430733`], {
             RGBColor[
             0.7876885454545454, 0.8340675454545454, 0.9794730909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.028685633809430733`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.028685633809430733`], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.028685633809430733`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.028685633809430733`], {
             RGBColor[
             0.8397295454545454, 0.30638427272727253`, 0.1856783636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.028685633809430733`], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.028685633809430733`], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.028685633809430733`], {
             RGBColor[
             0.8397295454545454, 0.30638427272727253`, 0.1856783636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.028685633809430733`], {
             RGBColor[
             0.9858593636363636, 0.9639624545454545, 0.3995667272727271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.028685633809430733`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.028685633809430733`], {
             RGBColor[0.955963, 0.863115, 0.283425]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.028685633809430733`], {
             RGBColor[
             0.9927556363636364, 0.9869133636363637, 0.4528739090909087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.028685633809430733`], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.028685633809430733`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.028685633809430733`], {
             RGBColor[
             0.9950293636363636, 0.9917766363636363, 0.7003550909090913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.028685633809430733`], {
             RGBColor[
             0.9942714545454545, 0.9901555454545454, 0.6178613636363632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.028685633809430733`], {
             RGBColor[
             0.9927556363636364, 0.9869133636363637, 0.4528739090909087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.028685633809430733`], {
             RGBColor[
             0.36131763636363623`, 0.48737690909090897`, 0.9442438181818181]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.028685633809430733`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.028685633809430733`], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.028685633809430733`], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.028685633809430733`], {
             RGBColor[
             0.9942714545454545, 0.9901555454545454, 0.6178613636363632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.028685633809430733`], {
             RGBColor[
             0.9942714545454545, 0.9901555454545454, 0.6178613636363632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.028685633809430733`], {
             RGBColor[
             0.36131763636363623`, 0.48737690909090897`, 0.9442438181818181]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.028685633809430733`], {
             RGBColor[
             0.7876885454545454, 0.8340675454545454, 0.9794730909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.028685633809430733`], {
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.028685633809430733`], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.028685633809430733`], {
             RGBColor[
             0.9935135454545455, 0.9885344545454546, 0.5353676363636367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.028685633809430733`], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.028685633809430733`], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.028685633809430733`], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.028685633809430733`], {
             RGBColor[
             0.9758939090909091, 0.9303466363636363, 0.360852818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.028685633809430733`], {
             RGBColor[0.8305035454545455, 0.867685, 0.9836953636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.028685633809430733`], {
             RGBColor[
             0.9659284545454546, 0.8967308181818184, 0.32213890909090936`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.028685633809430733`], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.028685633809430733`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.028685633809430733`], {
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.028685633809430733`], {
             RGBColor[
             0.9659284545454546, 0.8967308181818184, 0.32213890909090936`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.028685633809430733`], {
             RGBColor[
             0.8750675454545453, 0.525592727272727, 0.2174656363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.028685633809430733`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.028685633809430733`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.028685633809430733`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.028685633809430733`], {
             RGBColor[
             0.8750675454545453, 0.525592727272727, 0.2174656363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.028685633809430733`], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.028685633809430733`], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.028685633809430733`], {
             RGBColor[0.642359, 0.720535, 0.964988]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.028685633809430733`], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.028685633809430733`], {
             RGBColor[
             0.9935135454545455, 0.9885344545454546, 0.5353676363636367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.028685633809430733`], {
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.028685633809430733`], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.028685633809430733`], {
             RGBColor[
             0.2851425454545455, 0.41703327272727275`, 0.9395498181818182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.028685633809430733`], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.028685633809430733`], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.028685633809430733`], {
             RGBColor[
             0.4876890909090908, 0.5949669999999999, 0.9528118181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.028685633809430733`], {
             RGBColor[
             0.4876890909090908, 0.5949669999999999, 0.9528118181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.028685633809430733`], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.028685633809430733`], {
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.028685633809430733`], {
             RGBColor[
             0.4007463636363636, 0.5215280909090909, 0.9467561818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.028685633809430733`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.028685633809430733`], {
             RGBColor[
             0.7876885454545454, 0.8340675454545454, 0.9794730909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.028685633809430733`], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.028685633809430733`], {
             RGBColor[
             0.9950293636363636, 0.9917766363636363, 0.7003550909090913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.028685633809430733`], {
             RGBColor[0.8305035454545455, 0.867685, 0.9836953636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.028685633809430733`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.028685633809430733`], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.028685633809430733`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.028685633809430733`], {
             RGBColor[0.8305035454545455, 0.867685, 0.9836953636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.028685633809430733`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.028685633809430733`], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.028685633809430733`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.028685633809430733`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.028685633809430733`], {
             RGBColor[
             0.9950293636363636, 0.9917766363636363, 0.7003550909090913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.028685633809430733`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.028685633809430733`], {
             RGBColor[0.955963, 0.863115, 0.283425]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.028685633809430733`], {
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.028685633809430733`], {
             RGBColor[
             0.7876885454545454, 0.8340675454545454, 0.9794730909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.028685633809430733`], {
             RGBColor[
             0.8875644545454546, 0.582338272727273, 0.2278933636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.028685633809430733`], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.028685633809430733`], {
             RGBColor[
             0.9950293636363636, 0.9917766363636363, 0.7003550909090913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.028685633809430733`], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.028685633809430733`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.028685633809430733`], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.028685633809430733`], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.028685633809430733`], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.028685633809430733`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.028685633809430733`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.028685633809430733`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.028685633809430733`], {
             RGBColor[
             0.4876890909090908, 0.5949669999999999, 0.9528118181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.028685633809430733`], {
             RGBColor[
             0.5392457272727273, 0.6368230000000001, 0.9568705454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.028685633809430733`], {
             RGBColor[
             0.5392457272727273, 0.6368230000000001, 0.9568705454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.028685633809430733`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.028685633809430733`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.028685633809430733`], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.028685633809430733`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.028685633809430733`], {
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.028685633809430733`], {
             RGBColor[
             0.9935135454545455, 0.9885344545454546, 0.5353676363636367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.028685633809430733`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.028685633809430733`], {
             RGBColor[
             0.5908023636363634, 0.6786789999999998, 0.9609292727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.028685633809430733`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.028685633809430733`], {
             RGBColor[
             0.9927556363636364, 0.9869133636363637, 0.4528739090909087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.028685633809430733`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.028685633809430733`], {
             RGBColor[0.642359, 0.720535, 0.964988]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.028685633809430733`], {
             RGBColor[
             0.9935135454545455, 0.9885344545454546, 0.5353676363636367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.028685633809430733`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.028685633809430733`], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.028685633809430733`], {
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.028685633809430733`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.028685633809430733`], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.028685633809430733`], {
             RGBColor[
             0.9935135454545455, 0.9885344545454546, 0.5353676363636367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.028685633809430733`], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.028685633809430733`], {
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.028685633809430733`], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.028685633809430733`], {
             RGBColor[
             0.5392457272727273, 0.6368230000000001, 0.9568705454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.028685633809430733`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.028685633809430733`], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.028685633809430733`], {
             RGBColor[
             0.7876885454545454, 0.8340675454545454, 0.9794730909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.028685633809430733`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.028685633809430733`], {
             RGBColor[
             0.9927556363636364, 0.9869133636363637, 0.4528739090909087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.028685633809430733`], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.028685633809430733`], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.028685633809430733`], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.028685633809430733`], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.028685633809430733`], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.028685633809430733`], {
             RGBColor[
             0.5392457272727273, 0.6368230000000001, 0.9568705454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.028685633809430733`], {
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.028685633809430733`], {
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.028685633809430733`], {
             RGBColor[
             0.9935135454545455, 0.9885344545454546, 0.5353676363636367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.028685633809430733`], {
             RGBColor[
             0.4876890909090908, 0.5949669999999999, 0.9528118181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.028685633809430733`], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.028685633809430733`], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.028685633809430733`], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.028685633809430733`], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.028685633809430733`], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.028685633809430733`], {
             RGBColor[0.955963, 0.863115, 0.283425]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.028685633809430733`], {
             RGBColor[
             0.7876885454545454, 0.8340675454545454, 0.9794730909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.028685633809430733`], {
             RGBColor[0.955963, 0.863115, 0.283425]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.028685633809430733`], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.028685633809430733`], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.028685633809430733`], {
             RGBColor[
             0.7876885454545454, 0.8340675454545454, 0.9794730909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.028685633809430733`], {
             RGBColor[
             0.8285242727272727, 0.22025563636363626`, 0.1749481818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.028685633809430733`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.028685633809430733`], {
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.028685633809430733`], {
             RGBColor[
             0.8509348181818183, 0.3925129090909096, 0.1964085454545455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.028685633809430733`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.028685633809430733`], {
             RGBColor[
             0.8750675454545453, 0.525592727272727, 0.2174656363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.028685633809430733`], {
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.028685633809430733`], {
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.028685633809430733`], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.028685633809430733`], {
             RGBColor[
             0.9942714545454545, 0.9901555454545454, 0.6178613636363632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.028685633809430733`], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.028685633809430733`], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.028685633809430733`], {
             RGBColor[0.8305035454545455, 0.867685, 0.9836953636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.028685633809430733`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.028685633809430733`], {
             RGBColor[
             0.4007463636363636, 0.5215280909090909, 0.9467561818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.028685633809430733`], {
             RGBColor[
             0.36131763636363623`, 0.48737690909090897`, 0.9442438181818181]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.028685633809430733`], {
             RGBColor[
             0.9927556363636364, 0.9869133636363637, 0.4528739090909087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.028685633809430733`], {
             RGBColor[
             0.9950293636363636, 0.9917766363636363, 0.7003550909090913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.028685633809430733`], {
             RGBColor[
             0.9000613636363637, 0.6390838181818185, 0.23832109090909098`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.028685633809430733`], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.028685633809430733`], {
             RGBColor[
             0.9950293636363636, 0.9917766363636363, 0.7003550909090913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.028685633809430733`], {
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.028685633809430733`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.028685633809430733`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.028685633809430733`], {
             RGBColor[
             0.9942714545454545, 0.9901555454545454, 0.6178613636363632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.028685633809430733`], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.028685633809430733`], {
             RGBColor[
             0.9858593636363636, 0.9639624545454545, 0.3995667272727271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[401, 0.028685633809430733`], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[402, 0.028685633809430733`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[403, 0.028685633809430733`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[404, 0.028685633809430733`], {
             RGBColor[
             0.8397295454545454, 0.30638427272727253`, 0.1856783636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[405, 0.028685633809430733`], {
             RGBColor[
             0.9927556363636364, 0.9869133636363637, 0.4528739090909087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[406, 0.028685633809430733`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[407, 0.028685633809430733`], {
             RGBColor[
             0.7876885454545454, 0.8340675454545454, 0.9794730909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[408, 0.028685633809430733`], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[409, 0.028685633809430733`], {
             RGBColor[
             0.4007463636363636, 0.5215280909090909, 0.9467561818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[410, 0.028685633809430733`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[411, 0.028685633809430733`], {
             RGBColor[
             0.9758939090909091, 0.9303466363636363, 0.360852818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[412, 0.028685633809430733`], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[413, 0.028685633809430733`], {
             RGBColor[
             0.36131763636363623`, 0.48737690909090897`, 0.9442438181818181]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[414, 0.028685633809430733`], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[415, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[416, 0.028685633809430733`], {
             RGBColor[0.8305035454545455, 0.867685, 0.9836953636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[417, 0.028685633809430733`], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[418, 0.028685633809430733`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[419, 0.028685633809430733`], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[420, 0.028685633809430733`], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[421, 0.028685633809430733`], {
             RGBColor[
             0.7876885454545454, 0.8340675454545454, 0.9794730909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[422, 0.028685633809430733`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[423, 0.028685633809430733`], {
             RGBColor[
             0.9858593636363636, 0.9639624545454545, 0.3995667272727271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[424, 0.028685633809430733`], {
             RGBColor[
             0.9858593636363636, 0.9639624545454545, 0.3995667272727271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[425, 0.028685633809430733`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[426, 0.028685633809430733`], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[427, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[428, 0.028685633809430733`], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[429, 0.028685633809430733`], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[430, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[431, 0.028685633809430733`], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[432, 0.028685633809430733`], {
             RGBColor[
             0.9758939090909091, 0.9303466363636363, 0.360852818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[433, 0.028685633809430733`], {
             RGBColor[
             0.9758939090909091, 0.9303466363636363, 0.360852818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[434, 0.028685633809430733`], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[435, 0.028685633809430733`], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[436, 0.028685633809430733`], {
             RGBColor[0.955963, 0.863115, 0.283425]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[437, 0.028685633809430733`], {
             RGBColor[
             0.4007463636363636, 0.5215280909090909, 0.9467561818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[438, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[439, 0.028685633809430733`], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[440, 0.028685633809430733`], {
             RGBColor[
             0.4876890909090908, 0.5949669999999999, 0.9528118181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[441, 0.028685633809430733`], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[442, 0.028685633809430733`], {
             RGBColor[
             0.8875644545454546, 0.582338272727273, 0.2278933636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[443, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[444, 0.028685633809430733`], {
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[445, 0.028685633809430733`], {
             RGBColor[
             0.4007463636363636, 0.5215280909090909, 0.9467561818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[446, 0.028685633809430733`], {
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[447, 0.028685633809430733`], {
             RGBColor[
             0.36131763636363623`, 0.48737690909090897`, 0.9442438181818181]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[448, 0.028685633809430733`], {
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[449, 0.028685633809430733`], {
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[450, 0.028685633809430733`], {
             RGBColor[
             0.5908023636363634, 0.6786789999999998, 0.9609292727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[451, 0.028685633809430733`], {
             RGBColor[
             0.4876890909090908, 0.5949669999999999, 0.9528118181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[452, 0.028685633809430733`], {
             RGBColor[0.642359, 0.720535, 0.964988]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[453, 0.028685633809430733`], {
             RGBColor[
             0.9942714545454545, 0.9901555454545454, 0.6178613636363632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[454, 0.028685633809430733`], {
             RGBColor[
             0.5908023636363634, 0.6786789999999998, 0.9609292727272727]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[455, 0.028685633809430733`], {
             RGBColor[0.642359, 0.720535, 0.964988]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[456, 0.028685633809430733`], {
             RGBColor[
             0.9935135454545455, 0.9885344545454546, 0.5353676363636367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[457, 0.028685633809430733`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[458, 0.028685633809430733`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[459, 0.028685633809430733`], {
             RGBColor[
             0.9950293636363636, 0.9917766363636363, 0.7003550909090913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[460, 0.028685633809430733`], {
             RGBColor[
             0.9902410909090908, 0.9902324545454546, 0.8113939090909089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[461, 0.028685633809430733`], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[462, 0.028685633809430733`], {
             RGBColor[
             0.5392457272727273, 0.6368230000000001, 0.9568705454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[463, 0.028685633809430733`], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[464, 0.028685633809430733`], {
             RGBColor[
             0.5392457272727273, 0.6368230000000001, 0.9568705454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[465, 0.028685633809430733`], {
             RGBColor[
             0.9942714545454545, 0.9901555454545454, 0.6178613636363632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[466, 0.028685633809430733`], {
             RGBColor[
             0.9950293636363636, 0.9917766363636363, 0.7003550909090913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[467, 0.028685633809430733`], {
             RGBColor[
             0.9927556363636364, 0.9869133636363637, 0.4528739090909087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[468, 0.028685633809430733`], {
             RGBColor[
             0.4876890909090908, 0.5949669999999999, 0.9528118181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[469, 0.028685633809430733`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[470, 0.028685633809430733`], {
             RGBColor[
             0.944515909090909, 0.9581406363636363, 0.9788042727272728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[471, 0.028685633809430733`], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[472, 0.028685633809430733`], {
             RGBColor[
             0.9927556363636364, 0.9869133636363637, 0.4528739090909087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[473, 0.028685633809430733`], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[474, 0.028685633809430733`], {
             RGBColor[
             0.8620621818181817, 0.8928489999999999, 0.9867054545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[475, 0.028685633809430733`], {
             RGBColor[
             0.9709666363636363, 0.9778675454545455, 0.9340300909090908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[476, 0.028685633809430733`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[477, 0.028685633809430733`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[478, 0.028685633809430733`], {
             RGBColor[
             0.9932656363636363, 0.9914831818181818, 0.7612693636363638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[479, 0.028685633809430733`], {
             RGBColor[0.8305035454545455, 0.867685, 0.9836953636363637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[480, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[481, 0.028685633809430733`], {
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[482, 0.028685633809430733`], {
             RGBColor[
             0.9577412727272727, 0.9680040909090909, 0.9564171818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[483, 0.028685633809430733`], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[484, 0.028685633809430733`], {
             RGBColor[
             0.9927556363636364, 0.9869133636363637, 0.4528739090909087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[485, 0.028685633809430733`], {
             RGBColor[
             0.4007463636363636, 0.5215280909090909, 0.9467561818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[486, 0.028685633809430733`], {
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[487, 0.028685633809430733`], {
             RGBColor[
             0.4007463636363636, 0.5215280909090909, 0.9467561818181818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[488, 0.028685633809430733`], {
             RGBColor[
             0.36131763636363623`, 0.48737690909090897`, 0.9442438181818181]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[489, 0.028685633809430733`], {
             RGBColor[
             0.9872165454545454, 0.9889817272727273, 0.8615184545454546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[490, 0.028685633809430733`], {
             RGBColor[0.642359, 0.720535, 0.964988]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[491, 0.028685633809430733`], {
             RGBColor[
             0.9136335454545453, 0.6952928181818179, 0.2493657272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[492, 0.028685633809430733`], {
             RGBColor[
             0.7392453636363636, 0.7962233636363636, 0.9746447272727272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[493, 0.028685633809430733`], {
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[494, 0.028685633809430733`], {
             RGBColor[0.8936208181818182, 0.918013, 0.9897155454545454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[495, 0.028685633809430733`], {
             RGBColor[0.9251794545454546, 0.943177, 0.9927256363636363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[496, 0.028685633809430733`], {
             RGBColor[
             0.4876890909090908, 0.5949669999999999, 0.9528118181818181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[497, 0.028685633809430733`], {
             RGBColor[
             0.9659284545454546, 0.8967308181818184, 0.32213890909090936`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[498, 0.028685633809430733`], {
             RGBColor[
             0.8397295454545454, 0.30638427272727253`, 0.1856783636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[499, 0.028685633809430733`], {
             RGBColor[
             0.6908021818181818, 0.7583791818181818, 0.9698163636363636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[500, 0.028685633809430733`], {
             RGBColor[
             0.4401750909090907, 0.5556792727272725, 0.9492685454545454]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1dOWGAgQBNBMbNu2bds2J+bEtm3btm3btu01sjdnH271F1R1ssCg6p0C
ggUL9l38vMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEIS
kZgkJCUZyUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpR
mCIUpRjFKUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGY
JjSlGYE0pwUtaUVr2tCWdrSnAx3pRBCd6UJXutGdHvSkF73pQ1/60Z8BDGQQ
gxnCUIYxnBGMZBSjGcNYxjGeCUxkEpOZwlSmMZ0ZzGQWs5nDXOYxnwUsZBGL
WcJSlrGcFaxkFatZw1rWsZ4NbGQTm9nCVraxnR3sZBe72cNe9rGfAxzkEIc5
wlGOcZwTnOQUpznDWc5xngtc5BKXucJVrnGdG9zkFre5w13ucZ8HPOQRj3nC
U57xnBe85BWvecNb3vGeD3zkE5/5wle+8Z1f+JXf+J0/+JO/+Jt/+Jcf/Cx/
AMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEISkZgkJCUZ
yUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpRmCIUpRjF
KUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGYJjSlGYE0
pwUtaUVr2tCWdrSnAx35Od5BdKYLXelGd3rQk170pg996Ud/BjCQQQxmCEMZ
xnBGMJJRjGYMYxnHeCYwkUlMZgpTmcZ0ZjCTWcxmDnOZx3wWsJBFLGYJS1nG
clawklWsZg1rWcd6NrCRTWxmC1vZxnZ2sJNd7GYPe9nHfg5wkEMc5ghHOcZx
TnCSU5zmDGc5x3kucJFLXOYKV7nGdW5wk1vc5g53ucd9HvCQRzzmCU95xnNe
8JJXvOYNb3nHez7wkU985gtf+Rbw/z//Dz189+A=
          "], {Null, CompressedData["
1:eJxF3Al0ldW5gOF/21YsVqt2QFCqdkClVEWUGRVRJmWoghGKIgREKWUqk4DM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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[13, 59] -> 
             RGBColor[
              0.2579706137078198, 0.3884738496614871, 0.938002416866113], 
             UndirectedEdge[210, 309] -> 
             RGBColor[
              0.1918597924354573, 0.31898718483606625`, 0.9342375033968474], 
             UndirectedEdge[88, 427] -> 
             RGBColor[
              0.18803656473244668`, 0.3149687301135649, 0.9340197762351194], 
             UndirectedEdge[293, 483] -> 
             RGBColor[
              0.630894839609411, 0.7086289993280623, 0.9658482385387919], 
             UndirectedEdge[46, 150] -> 
             RGBColor[
              0.2095354252082916, 0.3375653955801614, 0.935244104534505], 
             UndirectedEdge[400, 444] -> 
             RGBColor[
              0.7778662305017423, 0.8242556583288213, 0.8882685536457314], 
             UndirectedEdge[98, 105] -> 
             RGBColor[
              0.18986356428247403`, 0.31688902247910566`, 0.93412382115669], 
             UndirectedEdge[128, 439] -> 
             RGBColor[
              0.1967431917255388, 0.32411994711534, 0.9345156057620757], 
             UndirectedEdge[23, 62] -> 
             RGBColor[
              0.34157168432943963`, 0.4649528057928196, 0.943180457023785], 
             UndirectedEdge[201, 236] -> 
             RGBColor[
              0.2329055510975478, 0.36212887964133295`, 0.9365749986308951], 
             UndirectedEdge[40, 477] -> 
             RGBColor[
              0.19140125749096676`, 0.31850523553661203`, 0.9342113905101004],
              UndirectedEdge[455, 482] -> 
             RGBColor[
              0.47270830175216416`, 0.5795209528723455, 0.952539845619061], 
             UndirectedEdge[60, 131] -> 
             RGBColor[
              0.9096110781982166, 0.6242662481872688, 0.5350082437658015], 
             UndirectedEdge[179, 222] -> 
             RGBColor[
              0.19860716321184355`, 0.3260790993300644, 0.9346217561807222], 
             UndirectedEdge[111, 175] -> 
             RGBColor[
              0.38213445941917534`, 0.5054073949376681, 0.9455702477393233], 
             UndirectedEdge[51, 110] -> 
             RGBColor[
              0.7061642122935256, 0.763962913869964, 0.8362189440457062], 
             UndirectedEdge[84, 261] -> 
             RGBColor[
              0.30240410894972447`, 0.4332765821863486, 0.9406023955782863], 
             UndirectedEdge[156, 479] -> 
             RGBColor[
              0.19085648891639362`, 0.317932649224413, 0.9341803667456914], 
             UndirectedEdge[158, 437] -> 
             RGBColor[
              0.1868134400454955, 0.31368314851699497`, 0.9339501210936485], 
             UndirectedEdge[103, 355] -> 
             RGBColor[
              0.48475696898891374`, 0.5914050668107322, 0.9529074440237885], 
             UndirectedEdge[13, 228] -> 
             RGBColor[
              0.2555809934244899, 0.38596220723303065`, 0.9378663315261038], 
             UndirectedEdge[59, 409] -> 
             RGBColor[
              0.2581147666270732, 0.38862536351944543`, 0.9380106261616092], 
             UndirectedEdge[243, 430] -> 
             RGBColor[
              0.19906776015361727`, 0.3265632159194014, 0.934647986495164], 
             UndirectedEdge[333, 441] -> 
             RGBColor[
              0.2266279051671714, 0.35553067574276653`, 0.936217495982105], 
             UndirectedEdge[179, 385] -> 
             RGBColor[
              0.19083377116116018`, 0.3179087714232738, 0.9341790730031387], 
             UndirectedEdge[81, 447] -> 
             RGBColor[
              0.23604325092602435`, 0.36542680110272124`, 0.936753685994316], 
             UndirectedEdge[69, 404] -> 
             RGBColor[
              0.6398415718326245, 0.7153643102811339, 0.9668689392230831], 
             UndirectedEdge[113, 380] -> 
             RGBColor[
              0.19209288530033616`, 0.3192321802159951, 0.9342507776906723], 
             UndirectedEdge[85, 489] -> 
             RGBColor[
              0.18944536571522486`, 0.31644946926960615`, 0.9341000053669545],
              UndirectedEdge[277, 498] -> 
             RGBColor[
              0.6089064489917588, 0.6910771522369943, 0.9638150835884631], 
             UndirectedEdge[18, 160] -> 
             RGBColor[
              0.26388110219154026`, 0.3946861478044915, 0.9383390104414766], 
             UndirectedEdge[355, 431] -> 
             RGBColor[
              0.49048091648110803`, 0.596362862434505, 0.9532721688965031], 
             UndirectedEdge[357, 492] -> 
             RGBColor[
              0.1855765306994534, 0.3123830783697226, 0.9338796809362347], 
             UndirectedEdge[165, 386] -> 
             RGBColor[
              0.3057645176630249, 0.43870827302694076`, 0.9407242089916171], 
             UndirectedEdge[218, 274] -> 
             RGBColor[
              0.26498050169023135`, 0.3958416863835701, 0.9384016196165113], 
             UndirectedEdge[116, 441] -> 
             RGBColor[
              0.24897326082313725`, 0.37901706131456436`, 0.9374900309297209],
              UndirectedEdge[258, 435] -> 
             RGBColor[
              0.32678964542360633`, 0.4509663941385996, 0.942281872262574], 
             UndirectedEdge[112, 445] -> 
             RGBColor[
              0.9782801480279448, 0.9394045757914982, 0.5347896078268422], 
             UndirectedEdge[114, 179] -> 
             RGBColor[
              0.19077318734493098`, 0.3178450939911811, 0.9341756228444302], 
             UndirectedEdge[155, 467] -> 
             RGBColor[
              0.19253479608250443`, 0.31969665646681583`, 0.9342759438559683],
              UndirectedEdge[243, 421] -> 
             RGBColor[
              0.1904580230623436, 0.31751383634761216`, 0.9341576747047806], 
             UndirectedEdge[172, 289] -> 
             RGBColor[
              0.2167825321958998, 0.3451825645172597, 0.9356568165563153], 
             UndirectedEdge[381, 468] -> 
             RGBColor[
              0.20490029607601296`, 0.33269358097797563`, 0.9349801407874807],
              UndirectedEdge[17, 277] -> 
             RGBColor[
              0.4093350243660927, 0.5289671571545423, 0.9473034436852257], 
             UndirectedEdge[279, 477] -> 
             RGBColor[
              0.2028882707819582, 0.3305788148241523, 0.9348655589235091], 
             UndirectedEdge[4, 405] -> 
             RGBColor[
              0.18158563263707392`, 0.3081883914686098, 0.9336524051955868], 
             UndirectedEdge[36, 379] -> 
             RGBColor[
              0.9107780137599082, 0.6018218600251894, 0.4604073756146171], 
             UndirectedEdge[278, 401] -> 
             RGBColor[
              0.18259570595575553`, 0.30925004256889155`, 0.9337099273768162],
              UndirectedEdge[152, 399] -> 
             RGBColor[
              0.19605719925809356`, 0.3233989255376204, 0.9344765395058896], 
             UndirectedEdge[173, 406] -> 
             RGBColor[
              0.5685496786155626, 0.658415121806283, 0.9602730898835382], 
             UndirectedEdge[239, 332] -> 
             RGBColor[
              0.1916360269785587, 0.31875199315331637`, 0.9342247602851084], 
             UndirectedEdge[116, 361] -> 
             RGBColor[
              0.25328984688463263`, 0.3835540669525598, 0.9377358541201064], 
             UndirectedEdge[288, 498] -> 
             RGBColor[
              0.7429048622719281, 0.7990821917836863, 0.9750094718967612], 
             UndirectedEdge[16, 386] -> 
             RGBColor[
              0.2878595743491687, 0.4198890423651035, 0.9397045489578829], 
             UndirectedEdge[216, 464] -> 
             RGBColor[
              0.20118455785762748`, 0.32878810451904233`, 0.9347685349928858],
              UndirectedEdge[379, 400] -> 
             RGBColor[
              0.9086464403656656, 0.6009403996477325, 0.49573306309233295`], 
             UndirectedEdge[22, 24] -> 
             RGBColor[
              0.18354454614871424`, 0.31024733377163405`, 0.9337639624221219],
              UndirectedEdge[231, 355] -> 
             RGBColor[
              0.6616838941423232, 0.7343656744943371, 0.9677797504415411], 
             UndirectedEdge[434, 495] -> 
             RGBColor[
              0.9105859845179732, 0.6779864914594717, 0.24664336835265455`], 
             UndirectedEdge[75, 323] -> 
             RGBColor[
              0.9290142282590157, 0.73628865839294, 0.4899032009526938], 
             UndirectedEdge[165, 288] -> 
             RGBColor[
              0.508574991950541, 0.6066055037109249, 0.956292599133973], 
             UndirectedEdge[90, 229] -> 
             RGBColor[
              0.24859585520259658`, 0.3786203840784777, 0.9374685382379528], 
             UndirectedEdge[267, 424] -> 
             RGBColor[
              0.21136439475697272`, 0.3394877585391924, 0.9353482616445844], 
             UndirectedEdge[258, 403] -> 
             RGBColor[
              0.5792948267817268, 0.6667531924094637, 0.9613678188204143], 
             UndirectedEdge[274, 305] -> 
             RGBColor[
              0.2773195143815185, 0.4086435488273039, 0.9391104309604698], 
             UndirectedEdge[399, 478] -> 
             RGBColor[
              0.22859634417905478`, 0.3575996299504977, 0.9363295956717873], 
             UndirectedEdge[359, 463] -> 
             RGBColor[
              0.7323426131107887, 0.7902188270608363, 0.9746779559842911], 
             UndirectedEdge[302, 422] -> 
             RGBColor[
              0.22565049031831835`, 0.3545033507649412, 0.9361618336524187], 
             UndirectedEdge[21, 335] -> 
             RGBColor[
              0.2551889465783416, 0.385550141140523, 0.9378440050381969], 
             UndirectedEdge[266, 445] -> 
             RGBColor[
              0.9783510953842744, 0.9379685313127405, 0.42709594933440853`], 
             UndirectedEdge[200, 452] -> 
             RGBColor[
              0.24489188267224044`, 0.3747272741036509, 0.9372576024818854], 
             UndirectedEdge[112, 471] -> 
             RGBColor[
              0.9751390722082593, 0.9794426669377387, 0.8581518289048162], 
             UndirectedEdge[481, 496] -> 
             RGBColor[
              0.19554201050297132`, 0.3228574294911333, 0.934447200268439], 
             UndirectedEdge[6, 422] -> 
             RGBColor[
              0.21046728026605566`, 0.33854483432889454`, 0.9352971723014887],
              UndirectedEdge[137, 424] -> 
             RGBColor[
              0.20256381379959026`, 0.3302377899639228, 0.9348470815783543], 
             UndirectedEdge[89, 482] -> 
             RGBColor[
              0.3210267437424298, 0.45247896298156487`, 0.9416765181318323], 
             UndirectedEdge[142, 254] -> 
             RGBColor[
              0.20407108545370353`, 0.33182202803893834`, 0.9349329184692474],
              UndirectedEdge[178, 321] -> 
             RGBColor[
              0.7273722693999012, 0.7841453015250835, 0.9212028178095601], 
             UndirectedEdge[151, 456] -> 
             RGBColor[
              0.19966233325078292`, 0.32718814994263423`, 0.9346818465534554],
              UndirectedEdge[346, 431] -> 
             RGBColor[
              0.43133365387154704`, 0.5480212643488988, 0.948705176904689], 
             UndirectedEdge[65, 297] -> 
             RGBColor[
              0.18922089119532, 0.3162135323166796, 0.9340872218751262], 
             UndirectedEdge[79, 253] -> 
             RGBColor[
              0.6318697246341356, 0.7067600197693191, 0.967143342848597], 
             UndirectedEdge[376, 475] -> 
             RGBColor[
              0.3538187512223421, 0.4808817516864462, 0.9437659958516187], 
             UndirectedEdge[209, 259] -> 
             RGBColor[
              0.8388746662508497, 0.8722406233791922, 0.8551373469793608], 
             UndirectedEdge[464, 496] -> 
             RGBColor[
              0.1941346337620407, 0.32137818730357604`, 0.9343670522450702], 
             UndirectedEdge[101, 103] -> 
             RGBColor[
              0.32745764009317235`, 0.4521656087003331, 0.9423017119454735], 
             UndirectedEdge[69, 348] -> 
             RGBColor[
              0.4524683198594424, 0.5660891289103882, 0.9501175973747447], 
             UndirectedEdge[116, 277] -> 
             RGBColor[
              0.35985275808300965`, 0.4831247951827711, 0.9442597110251651], 
             UndirectedEdge[171, 471] -> 
             RGBColor[
              0.7137657491152036, 0.7742498659419835, 0.9547112060503897], 
             UndirectedEdge[133, 429] -> 
             RGBColor[
              0.19496484613925177`, 0.3222507931505298, 0.9344143316117632], 
             UndirectedEdge[37, 203] -> 
             RGBColor[
              0.8534629031399862, 0.4065189709815528, 0.1986169775584265], 
             UndirectedEdge[299, 399] -> 
             RGBColor[
              0.22397618806162217`, 0.3527435529362591, 0.936066484615808], 
             UndirectedEdge[311, 429] -> 
             RGBColor[
              0.19096685764878327`, 0.3180486537599364, 0.934186652081725], 
             UndirectedEdge[327, 446] -> 
             RGBColor[
              0.18359313787334597`, 0.31029840675511533`, 0.9337667296489547],
              UndirectedEdge[15, 249] -> 
             RGBColor[
              0.6896781375343781, 0.7575010698806214, 0.9697043294069452], 
             UndirectedEdge[50, 242] -> 
             RGBColor[
              0.9267381119467066, 0.943455029677774, 0.9594240314227456], 
             UndirectedEdge[163, 355] -> 
             RGBColor[
              0.7295091887885554, 0.6445510453124249, 0.5980872339837272], 
             UndirectedEdge[192, 435] -> 
             RGBColor[
              0.2756938897780267, 0.40670981874574946`, 0.9390260958950403], 
             UndirectedEdge[31, 191] -> 
             RGBColor[
              0.1912888055455656, 0.31838704141213026`, 0.9342049865381675], 
             UndirectedEdge[385, 415] -> 
             RGBColor[
              0.18097729894859016`, 0.30754899419142984`, 0.9336177614919767],
              UndirectedEdge[207, 257] -> 
             RGBColor[
              0.9190198138450048, 0.7061284902521469, 0.2641826298296307], 
             UndirectedEdge[359, 408] -> 
             RGBColor[
              0.923405109023163, 0.9417213092494618, 0.9911392082523272], 
             UndirectedEdge[183, 202] -> 
             RGBColor[
              0.19186250689715728`, 0.31899003790741964`, 0.9342376579814256],
              UndirectedEdge[170, 223] -> 
             RGBColor[
              0.19795986022643686`, 0.3253987428510222, 0.9345848932333021], 
             UndirectedEdge[40, 430] -> 
             RGBColor[
              0.1932824749084014, 0.32048251431840913`, 0.9343185230590114], 
             UndirectedEdge[69, 444] -> 
             RGBColor[
              0.5043601503383525, 0.6082172545934901, 0.9542027123560828], 
             UndirectedEdge[215, 417] -> 
             RGBColor[
              0.1910469226092748, 0.31813280710982467`, 0.9341912116627795], 
             UndirectedEdge[423, 429] -> 
             RGBColor[
              0.18557451474248365`, 0.3123809594711283, 0.9338795661304677], 
             UndirectedEdge[5, 83] -> 
             RGBColor[
              0.8424015657306109, 0.8748578438487853, 0.849230453036272], 
             UndirectedEdge[311, 366] -> 
             RGBColor[
              0.18627071422588198`, 0.31311270926977675`, 0.9339192136611123],
              UndirectedEdge[133, 366] -> 
             RGBColor[
              0.1902687027163505, 0.3173148486603702, 0.9341468931911505], 
             UndirectedEdge[76, 359] -> 
             RGBColor[
              0.6599771175433797, 0.7303046973046542, 0.9693028506052312], 
             UndirectedEdge[172, 218] -> 
             RGBColor[
              0.25468436170219366`, 0.3850197904431626, 0.9378152696759667], 
             UndirectedEdge[177, 484] -> 
             RGBColor[
              0.18459712642978363`, 0.31135366238448237`, 0.9338239053119759],
              UndirectedEdge[45, 328] -> 
             RGBColor[
              0.22208190708084125`, 0.3507525435211073, 0.9359586081162901], 
             UndirectedEdge[115, 144] -> 
             RGBColor[
              0.1939326542641488, 0.3211658940450518, 0.9343555498114672], 
             UndirectedEdge[63, 72] -> 
             RGBColor[
              0.20896361604647165`, 0.3369643878962938, 0.9352115408486552], 
             UndirectedEdge[248, 387] -> 
             RGBColor[
              0.18458186461527748`, 0.3113376212497815, 0.9338230361742175], 
             UndirectedEdge[34, 44] -> 
             RGBColor[
              0.24396970740458573`, 0.37375800942805687`, 0.9372050859646285],
              UndirectedEdge[279, 285] -> 
             RGBColor[
              0.2111852622032374, 0.3392994788675566, 0.935338060310652], 
             UndirectedEdge[13, 77] -> 
             RGBColor[
              0.293706622672794, 0.4236564919439787, 0.9401246061243856], 
             UndirectedEdge[53, 445] -> 
             RGBColor[
              0.897896740106011, 0.5697053012801583, 0.24507330073286251`], 
             UndirectedEdge[91, 298] -> 
             RGBColor[
              0.368006349252357, 0.4899237097604318, 0.9448344889260978], 
             UndirectedEdge[6, 451] -> 
             RGBColor[
              0.20974058048916117`, 0.3377810267879514, 0.9352557878242505], 
             UndirectedEdge[87, 256] -> 
             RGBColor[
              0.30998490234108894`, 0.4428842197606874, 0.9409740715208748], 
             UndirectedEdge[153, 172] -> 
             RGBColor[
              0.22556462734887084`, 0.3544131033400252, 0.9361569438833315], 
             UndirectedEdge[72, 438] -> 
             RGBColor[
              0.20687895912531873`, 0.33477328129727923`, 0.9350928227209692],
              UndirectedEdge[207, 440] -> 
             RGBColor[
              0.8833097581290331, 0.5630186900098979, 0.22434314065434907`], 
             UndirectedEdge[19, 228] -> 
             RGBColor[
              0.2307172081494932, 0.3598287924539709, 0.9364503757373667], 
             UndirectedEdge[8, 63] -> 
             RGBColor[
              0.20214886588846875`, 0.32980165340011697`, 0.9348234509086764],
              UndirectedEdge[72, 128] -> 
             RGBColor[
              0.20268608388741163`, 0.33036630357859437`, 0.9348540446789733],
              UndirectedEdge[229, 485] -> 
             RGBColor[
              0.2450928096239232, 0.3749384610693741, 0.9372690449745389], 
             UndirectedEdge[32, 407] -> 
             RGBColor[
              0.24840100008144717`, 0.3784155789916214, 0.9374574415270658], 
             UndirectedEdge[475, 478] -> 
             RGBColor[
              0.2929211568634166, 0.42264039555989485`, 0.9400868509528724], 
             UndirectedEdge[194, 412] -> 
             RGBColor[
              0.18818134565428368`, 0.3151209040420562, 0.934028021294434], 
             UndirectedEdge[370, 390] -> 
             RGBColor[
              0.24233683264276484`, 0.3720417545231436, 0.9371120961625645], 
             UndirectedEdge[231, 233] -> 
             RGBColor[
              0.8631076739966228, 0.8934453053740385, 0.9626713381948079], 
             UndirectedEdge[114, 385] -> 
             RGBColor[
              0.18149489941754873`, 0.3080930251020705, 0.9336472380729627], 
             UndirectedEdge[271, 442] -> 
             RGBColor[
              0.22300003138538366`, 0.3517175503776244, 0.9360108939371906], 
             UndirectedEdge[206, 254] -> 
             RGBColor[
              0.18642186112422848`, 0.31327157424320573`, 0.9339278212533714],
              UndirectedEdge[262, 455] -> 
             RGBColor[
              0.47810598768171675`, 0.5841961571289409, 0.9528837813935058], 
             UndirectedEdge[7, 341] -> 
             RGBColor[
              0.7333256796265153, 0.7863640981896829, 0.7861411597228827], 
             UndirectedEdge[187, 328] -> 
             RGBColor[
              0.2321163718921772, 0.36129940225963686`, 0.9365300560426353], 
             UndirectedEdge[44, 56] -> 
             RGBColor[
              0.342928946455201, 0.46870029922168843`, 0.9431727706647948], 
             UndirectedEdge[142, 388] -> 
             RGBColor[
              0.27220031221012625`, 0.4015863957278337, 0.9388802865699359], 
             UndirectedEdge[282, 419] -> 
             RGBColor[
              0.6729998707802133, 0.7444718811327458, 0.9680419956441542], 
             UndirectedEdge[7, 244] -> 
             RGBColor[
              0.45953784870192455`, 0.5719334474988196, 0.9506451367617185], 
             UndirectedEdge[107, 470] -> 
             RGBColor[
              0.20295018288856098`, 0.3306438883736461, 0.9348690847263893], 
             UndirectedEdge[10, 383] -> 
             RGBColor[
              0.24728065527257528`, 0.3772380255635335, 0.9373936395476021], 
             UndirectedEdge[249, 419] -> 
             RGBColor[
              0.6881180325530365, 0.7562823040119602, 0.9695488327224149], 
             UndirectedEdge[191, 271] -> 
             RGBColor[
              0.19934619168565726`, 0.3268558651131542, 0.9346638427590112], 
             UndirectedEdge[297, 490] -> 
             RGBColor[
              0.20561521715269282`, 0.3334450083581805, 0.9350208544851668], 
             UndirectedEdge[32, 176] -> 
             RGBColor[
              0.26830294791528575`, 0.39857679935889445`, 0.938618545077043], 
             UndirectedEdge[353, 487] -> 
             RGBColor[
              0.18672390467583372`, 0.3135890411666101, 0.933945022186802], 
             UndirectedEdge[281, 324] -> 
             RGBColor[
              0.8790783466018638, 0.5485966593380001, 0.5760884806324713], 
             UndirectedEdge[19, 59] -> 
             RGBColor[
              0.2331068284328231, 0.3623404348824274, 0.936586461077376], 
             UndirectedEdge[197, 411] -> 
             RGBColor[
              0.25605149674669436`, 0.3864567360563011, 0.937893125994256], 
             UndirectedEdge[163, 343] -> 
             RGBColor[
              0.8727695735845509, 0.4960098594094768, 0.21479835234035222`], 
             UndirectedEdge[12, 396] -> 
             RGBColor[
              0.19573690002635402`, 0.32306227073691796`, 0.9344582989384823],
              UndirectedEdge[51, 397] -> 
             RGBColor[
              0.9086311282442023, 0.5812180792787432, 0.4466755411222336], 
             UndirectedEdge[448, 482] -> 
             RGBColor[
              0.3164780231838319, 0.4477844619968153, 0.9414143083027866], 
             UndirectedEdge[183, 285] -> 
             RGBColor[
              0.20567627769071223`, 0.33350918685510056`, 0.935024331792476], 
             UndirectedEdge[155, 365] -> 
             RGBColor[
              0.200483284293693, 0.3280510215400352, 0.934728598500861], 
             UndirectedEdge[122, 217] -> 
             RGBColor[
              0.1834604918576584, 0.31015898738238445`, 0.9337591756545935], 
             UndirectedEdge[249, 269] -> 
             RGBColor[
              0.6644117978227214, 0.7371426324130581, 0.9676100378285277], 
             UndirectedEdge[101, 331] -> 
             RGBColor[
              0.2732729587475753, 0.4045575845229832, 0.9388738627783362], 
             UndirectedEdge[246, 458] -> 
             RGBColor[
              0.2394606076875042, 0.3690186597319697, 0.9369482994063559], 
             UndirectedEdge[35, 437] -> 
             RGBColor[
              0.18478436843582058`, 0.31155046560465605`, 0.9338345684672199],
              UndirectedEdge[354, 473] -> 
             RGBColor[
              0.28709080979716467`, 0.41891074115277027`, 0.9396670037727628],
              UndirectedEdge[230, 484] -> 
             RGBColor[
              0.19535510076833423`, 0.3226609755092681, 0.9344365560355595], 
             UndirectedEdge[108, 190] -> 
             RGBColor[
              0.21307880253974895`, 0.34128970981862183`, 0.9354458946315745],
              UndirectedEdge[55, 136] -> 
             RGBColor[
              0.5509076978824959, 0.6462907131067992, 0.9577886185001523], 
             UndirectedEdge[59, 279] -> 
             RGBColor[
              0.23548934775412372`, 0.36484461374956423`, 0.9367221420281024],
              UndirectedEdge[24, 170] -> 
             RGBColor[
              0.18651291707157386`, 0.3133672798171463, 0.9339330067548675], 
             UndirectedEdge[184, 388] -> 
             RGBColor[
              0.43476172806913593`, 0.5486141843644792, 0.9495801910661066], 
             UndirectedEdge[173, 242] -> 
             RGBColor[
              0.8468550508642396, 0.8805617516174773, 0.9515915409041512], 
             UndirectedEdge[4, 345] -> 
             RGBColor[
              0.18617654721563465`, 0.31301373377147346`, 0.9339138509891864],
              UndirectedEdge[59, 256] -> 
             RGBColor[
              0.28727672509446966`, 0.4190164856928953, 0.9396808744204175], 
             UndirectedEdge[232, 480] -> 
             RGBColor[
              0.2609103808391443, 0.3915637313085108, 0.9381698322552461], 
             UndirectedEdge[3, 437] -> 
             RGBColor[
              0.18278910615931465`, 0.30945331844511326`, 0.9337209412322989],
              UndirectedEdge[199, 448] -> 
             RGBColor[
              0.3433591771132972, 0.47106756644443715`, 0.943127151661101], 
             UndirectedEdge[151, 226] -> 
             RGBColor[
              0.19534643528489967`, 0.3226518675367549, 0.9344360625490973], 
             UndirectedEdge[241, 442] -> 
             RGBColor[
              0.22676711964941848`, 0.35567699899031613`, 0.9362254240409197],
              UndirectedEdge[303, 400] -> 
             RGBColor[
              0.9153331914929417, 0.6523376989650047, 0.5021363035234178], 
             UndirectedEdge[42, 378] -> 
             RGBColor[
              0.20375715237687997`, 0.3314920644706901, 0.9349150404449447], 
             UndirectedEdge[15, 499] -> 
             RGBColor[
              0.6404896932769727, 0.7188634972449458, 0.9649460740899308], 
             UndirectedEdge[341, 374] -> 
             RGBColor[
              0.9208708140731814, 0.677947066838142, 0.406871876564454], 
             UndirectedEdge[312, 334] -> 
             RGBColor[
              0.19091202731972692`, 0.3179910236076545, 0.9341835295755994], 
             UndirectedEdge[7, 482] -> 
             RGBColor[
              0.4023630118874444, 0.5224114775409715, 0.9470020067176228], 
             UndirectedEdge[219, 403] -> 
             RGBColor[
              0.7064676273124759, 0.7706171469001197, 0.9713777488413233], 
             UndirectedEdge[50, 449] -> 
             RGBColor[
              0.9319849870644814, 0.931902676711367, 0.6896331946772748], 
             UndirectedEdge[318, 430] -> 
             RGBColor[
              0.1997685243379237, 0.32729976350812295`, 0.9346878939787725], 
             UndirectedEdge[242, 449] -> 
             RGBColor[
              0.9783597736506789, 0.9679158712997968, 0.6606061921458748], 
             UndirectedEdge[356, 365] -> 
             RGBColor[
              0.2261799618783253, 0.3550598589449443, 0.9361919862744781], 
             UndirectedEdge[154, 219] -> 
             RGBColor[
              0.8264967277029731, 0.8644743578312362, 0.9402829367923042], 
             UndirectedEdge[69, 275] -> 
             RGBColor[
              0.46608428308489896`, 0.5771431812489669, 0.9511894958767693], 
             UndirectedEdge[173, 310] -> 
             RGBColor[
              0.682704924474264, 0.7520535428396782, 0.9690093046974939], 
             UndirectedEdge[351, 460] -> 
             RGBColor[
              0.2704319943298352, 0.4015715507923906, 0.9387120740575761], 
             UndirectedEdge[97, 207] -> 
             RGBColor[
              0.9317219029437263, 0.7489756193744845, 0.31352784738991035`], 
             UndirectedEdge[122, 212] -> 
             RGBColor[
              0.18381215152445518`, 0.3105286039886985, 0.9337792021523836], 
             UndirectedEdge[45, 224] -> 
             RGBColor[
              0.20355580866569664`, 0.3312804394643078, 0.9349035742184542], 
             UndirectedEdge[144, 215] -> 
             RGBColor[
              0.19092068807717077`, 0.3180001266128517, 0.9341840227929235], 
             UndirectedEdge[22, 214] -> 
             RGBColor[
              0.1846717285967103, 0.31143207399197287`, 0.9338281537950183], 
             UndirectedEdge[142, 150] -> 
             RGBColor[
              0.2155365862389103, 0.34387299631892737`, 0.9355858617772765], 
             UndirectedEdge[149, 419] -> 
             RGBColor[
              0.6052079656077549, 0.6902679989364768, 0.962135887741037], 
             UndirectedEdge[11, 418] -> 
             RGBColor[
              0.4260394736081712, 0.5428061221897597, 0.9485417938214956], 
             UndirectedEdge[189, 346] -> 
             RGBColor[
              0.346693677388048, 0.46946123011413, 0.9435041892031641], 
             UndirectedEdge[185, 224] -> 
             RGBColor[
              0.2087376164930067, 0.33672684803640285`, 0.9351986705084218], 
             UndirectedEdge[17, 386] -> 
             RGBColor[
              0.34052296335874593`, 0.4690749660172503, 0.9429294418511679], 
             UndirectedEdge[194, 476] -> 
             RGBColor[
              0.18476853282621936`, 0.3115338213749295, 0.9338336666526799], 
             UndirectedEdge[258, 471] -> 
             RGBColor[
              0.686008715672987, 0.7506799404061069, 0.9528121866762553], 
             UndirectedEdge[203, 397] -> 
             RGBColor[
              0.8335404053549352, 0.2588118298231834, 0.1797516360873429], 
             UndirectedEdge[126, 173] -> 
             RGBColor[
              0.6045267350947843, 0.6886225535376819, 0.9628291330052186], 
             UndirectedEdge[30, 366] -> 
             RGBColor[
              0.1807454038963133, 0.3073052577884914, 0.9336045554118075], 
             UndirectedEdge[95, 368] -> 
             RGBColor[
              0.1819562792912616, 0.3085779646025163, 0.9336735129742202], 
             UndirectedEdge[15, 242] -> 
             RGBColor[
              0.8127597142986478, 0.8539262155582815, 0.9481932363943286], 
             UndirectedEdge[150, 392] -> 
             RGBColor[
              0.22610554162039614`, 0.3549816385353439, 0.9361877481508839], 
             UndirectedEdge[179, 296] -> 
             RGBColor[
              0.19117065430032437`, 0.31826285696216006`, 0.9341982579995401],
              UndirectedEdge[3, 123] -> 
             RGBColor[
              0.1847525458331286, 0.3115170180315573, 0.933832756217074], 
             UndirectedEdge[37, 257] -> 
             RGBColor[
              0.9124536887252621, 0.6763132496408797, 0.2587036940792628], 
             UndirectedEdge[17, 178] -> 
             RGBColor[
              0.4223764301651894, 0.5398287637649369, 0.9482544022825725], 
             UndirectedEdge[68, 367] -> 
             RGBColor[
              0.19128856344294365`, 0.31838678694692435`, 0.9342049727507814],
              UndirectedEdge[1, 363] -> 
             RGBColor[
              0.19094550353876433`, 0.3180262092363777, 0.93418543599675], 
             UndirectedEdge[227, 329] -> 
             RGBColor[
              0.18736891797604732`, 0.31426699104133987`, 0.9339817547400375],
              UndirectedEdge[121, 420] -> 
             RGBColor[
              0.1965885249531354, 0.3239573825311042, 0.9345067977181964], 
             UndirectedEdge[82, 149] -> 
             RGBColor[
              0.540625880408879, 0.6379434704911183, 0.9569791961650909], 
             UndirectedEdge[129, 355] -> 
             RGBColor[
              0.4245428223807357, 0.5374596923522321, 0.9491362257297418], 
             UndirectedEdge[87, 388] -> 
             RGBColor[
              0.3185501109900676, 0.45030297299252864`, 0.941519839042071], 
             UndirectedEdge[91, 228] -> 
             RGBColor[
              0.35927043823642757`, 0.48074171339394056`, 0.9443369917173629],
              UndirectedEdge[12, 161] -> 
             RGBColor[
              0.20394297282787943`, 0.33168737354638755`, 0.9349256226447324],
              UndirectedEdge[64, 115] -> 
             RGBColor[
              0.18789626990443398`, 0.31482127135411775`, 0.9340117866522119],
              UndirectedEdge[56, 342] -> 
             RGBColor[
              0.4415801835206408, 0.5562719260910596, 0.9495305912404275], 
             UndirectedEdge[378, 416] -> 
             RGBColor[
              0.2080965578112694, 0.3360530547164289, 0.9351621631648581], 
             UndirectedEdge[119, 363] -> 
             RGBColor[
              0.18346622269800678`, 0.3101650108589469, 0.9337595020174734], 
             UndirectedEdge[391, 455] -> 
             RGBColor[
              0.5430796704315681, 0.6399355677735181, 0.9571723675042059], 
             UndirectedEdge[249, 282] -> 
             RGBColor[
              0.7118315832315418, 0.7748075100316689, 0.9719123778383179], 
             UndirectedEdge[226, 429] -> 
             RGBColor[
              0.18946440368264025`, 0.31646947938043657`, 0.9341010895510347],
              UndirectedEdge[181, 189] -> 
             RGBColor[
              0.238744748764803, 0.3682662466161335, 0.9369075322997265], 
             UndirectedEdge[160, 167] -> 
             RGBColor[
              0.2396559862242012, 0.36922401496175294`, 0.9369594259249842], 
             UndirectedEdge[16, 277] -> 
             RGBColor[
              0.35667163535651547`, 0.47978123350239554`, 0.9440785507919407],
              UndirectedEdge[295, 341] -> 
             RGBColor[
              0.9895466198460419, 0.9890958111978665, 0.7611561924651287], 
             UndirectedEdge[69, 129] -> 
             RGBColor[
              0.36611599979539755`, 0.48974210320523914`, 0.944615139539211], 
             UndirectedEdge[352, 368] -> 
             RGBColor[
              0.1813119634696479, 0.3079007478220177, 0.9336368201413592], 
             UndirectedEdge[194, 297] -> 
             RGBColor[
              0.1906847748105455, 0.3177521668118635, 0.9341705878813915], 
             UndirectedEdge[188, 228] -> 
             RGBColor[
              0.24109668028529843`, 0.37073827576524543`, 0.9370414713204478],
              UndirectedEdge[273, 430] -> 
             RGBColor[
              0.19435747882303328`, 0.32161241159187215`, 0.9343797429416241],
              UndirectedEdge[200, 468] -> 
             RGBColor[
              0.2422384711696754, 0.37193837037844896`, 0.9371064946221849], 
             UndirectedEdge[93, 172] -> 
             RGBColor[
              0.22306123798292227`, 0.35178188239235997`, 0.9360143795623734],
              UndirectedEdge[61, 341] -> 
             RGBColor[
              0.992278182050985, 0.9902253823675571, 0.7158871376728388], 
             UndirectedEdge[121, 442] -> 
             RGBColor[
              0.22151836933651753`, 0.35016022962146637`, 0.9359265154754303],
              UndirectedEdge[287, 336] -> 
             RGBColor[
              0.46475221828321023`, 0.5718710801553506, 0.9521407597407114], 
             UndirectedEdge[403, 497] -> 
             RGBColor[
              0.6107955480026974, 0.6933624123353453, 0.9635615550100725], 
             UndirectedEdge[17, 407] -> 
             RGBColor[
              0.3262865305599572, 0.4541115725037497, 0.9421186980641918], 
             UndirectedEdge[135, 470] -> 
             RGBColor[
              0.18730486737300778`, 0.31419966979650255`, 0.9339781071529487],
              UndirectedEdge[322, 471] -> 
             RGBColor[
              0.8888094561578547, 0.5640382311059557, 0.5627414261917315], 
             UndirectedEdge[24, 52] -> 
             RGBColor[
              0.18264284256949226`, 0.3092995861385628, 0.9337126117372361], 
             UndirectedEdge[163, 440] -> 
             RGBColor[
              0.8954705204165625, 0.6182378713393768, 0.2344903787946242], 
             UndirectedEdge[274, 432] -> 
             RGBColor[
              0.26765870816883486`, 0.3986566512006808, 0.9385541395134164], 
             UndirectedEdge[89, 261] -> 
             RGBColor[
              0.31948712585052597`, 0.45114542334704305`, 0.9415784150411908],
              UndirectedEdge[255, 312] -> 
             RGBColor[
              0.19606964847691927`, 0.3234120104559323, 0.9344772484704849], 
             UndirectedEdge[370, 422] -> 
             RGBColor[
              0.21765000410983476`, 0.3460943324997014, 0.9357062177985042], 
             UndirectedEdge[43, 90] -> 
             RGBColor[
              0.24535980769453214`, 0.3752190929702395, 0.9372842501196719], 
             UndirectedEdge[373, 449] -> 
             RGBColor[
              0.9873031183402635, 0.9734548154410307, 0.5948195031122866], 
             UndirectedEdge[49, 457] -> 
             RGBColor[
              0.7315880631738731, 0.7847063242900234, 0.765752210507527], 
             UndirectedEdge[234, 449] -> 
             RGBColor[
              0.9549924747052941, 0.851092521948047, 0.32521790592745947`], 
             UndirectedEdge[245, 299] -> 
             RGBColor[
              0.24199930981785328`, 0.3716869966339784, 0.9370928747370061], 
             UndirectedEdge[398, 464] -> 
             RGBColor[
              0.20435657897174597`, 0.33212209982773555`, 0.9349491769027501],
              UndirectedEdge[245, 262] -> 
             RGBColor[
              0.2935462908702744, 0.4226836514910424, 0.9401449256179049], 
             UndirectedEdge[288, 321] -> 
             RGBColor[
              0.8483292768809738, 0.881288734461381, 0.9314462475205114], 
             UndirectedEdge[433, 465] -> 
             RGBColor[
              0.17986137360753812`, 0.306376085904231, 0.9335542111946675], 
             UndirectedEdge[330, 367] -> 
             RGBColor[
              0.19336515666501655`, 0.3205694180869378, 0.9343232316627341], 
             UndirectedEdge[106, 156] -> 
             RGBColor[
              0.1895211212928381, 0.31652909318485867`, 0.9341043195350291], 
             UndirectedEdge[85, 239] -> 
             RGBColor[
              0.19195700771123925`, 0.31908936425471746`, 0.9342430396629862],
              UndirectedEdge[336, 388] -> 
             RGBColor[
              0.4770192723969674, 0.5829207625304905, 0.9529068597500787], 
             UndirectedEdge[69, 355] -> 
             RGBColor[
              0.5012830197903266, 0.6057191013914514, 0.9539604693674415], 
             UndirectedEdge[102, 383] -> 
             RGBColor[
              0.23360844690792137`, 0.362867667704204, 0.9366150275074547], 
             UndirectedEdge[296, 327] -> 
             RGBColor[
              0.1830042105599709, 0.3096794068086097, 0.9337331911096979], 
             UndirectedEdge[61, 288] -> 
             RGBColor[
              0.8507412174209339, 0.8822861338586991, 0.8914741508713435], 
             UndirectedEdge[141, 472] -> 
             RGBColor[
              0.19522243291560842`, 0.32252153318442556`, 0.9344290007976113],
              UndirectedEdge[43, 485] -> 
             RGBColor[
              0.24185676211585877`, 0.3715371699611359, 0.9370847568562579], 
             UndirectedEdge[9, 358] -> 
             RGBColor[
              0.2093374978833109, 0.33735736141228945`, 0.9352328328661546], 
             UndirectedEdge[70, 359] -> 
             RGBColor[
              0.6396346219366711, 0.7126850500536813, 0.9680066447733342], 
             UndirectedEdge[466, 470] -> 
             RGBColor[
              0.19475005924981162`, 0.3220250385114528, 0.9344020998161584], 
             UndirectedEdge[41, 356] -> 
             RGBColor[
              0.25420192746199044`, 0.3845127214686115, 0.9377877957596846], 
             UndirectedEdge[79, 436] -> 
             RGBColor[
              0.620883921888038, 0.6972446695931502, 0.9664433372119796], 
             UndirectedEdge[33, 175] -> 
             RGBColor[
              0.326974395016177, 0.4527788821025087, 0.9422331394259775], 
             UndirectedEdge[176, 448] -> 
             RGBColor[
              0.3087587670403855, 0.44109843030645696`, 0.9409224441271964], 
             UndirectedEdge[118, 481] -> 
             RGBColor[
              0.1987399075504107, 0.32621862204637564`, 0.9346293157744259], 
             UndirectedEdge[326, 346] -> 
             RGBColor[
              0.5833986733777301, 0.6710733580441507, 0.9613052656352206], 
             UndirectedEdge[63, 435] -> 
             RGBColor[
              0.22260483335872017`, 0.351302172194599, 0.9359883879942152], 
             UndirectedEdge[194, 350] -> 
             RGBColor[
              0.18381567245253283`, 0.31053230470734794`, 0.9337794026640289],
              UndirectedEdge[275, 486] -> 
             RGBColor[
              0.45132348377934284`, 0.564358118789839, 0.9502489507974816], 
             UndirectedEdge[407, 478] -> 
             RGBColor[
              0.2632216514132959, 0.39399302322496244`, 0.9383014556952256], 
             UndirectedEdge[62, 356] -> 
             RGBColor[
              0.24825469827183463`, 0.37826180651364816`, 0.9374491098554425],
              UndirectedEdge[150, 426] -> 
             RGBColor[
              0.20135872025195078`, 0.3289711602380097, 0.9347784532835923], 
             UndirectedEdge[372, 444] -> 
             RGBColor[
              0.5900676498939734, 0.6780825262854508, 0.9608714333701266], 
             UndirectedEdge[106, 329] -> 
             RGBColor[
              0.18061317161541351`, 0.30716627327725476`, 0.9335970249790304],
              UndirectedEdge[128, 294] -> 
             RGBColor[
              0.1908740507973531, 0.317951107874789, 0.9341813668688315], 
             UndirectedEdge[379, 440] -> 
             RGBColor[
              0.8595285144156211, 0.406306411086346, 0.20259145280411195`], 
             UndirectedEdge[227, 267] -> 
             RGBColor[
              0.2112079223469873, 0.3393232961153739, 0.935339350772316], 
             UndirectedEdge[151, 345] -> 
             RGBColor[
              0.19727711657984534`, 0.32468113599000714`, 0.9345460119926574],
              UndirectedEdge[275, 418] -> 
             RGBColor[
              0.48290882987898437`, 0.5910861687474542, 0.9524354985228551], 
             UndirectedEdge[10, 232] -> 
             RGBColor[
              0.2526232272726644, 0.38285340747425656`, 0.9376978911193801], 
             UndirectedEdge[5, 431] -> 
             RGBColor[
              0.5554141285415004, 0.6483552608910543, 0.9588784790444786], 
             UndirectedEdge[42, 416] -> 
             RGBColor[
              0.20488956233917005`, 0.3326822991399955, 0.9349795295170467], 
             UndirectedEdge[37, 97] -> 
             RGBColor[
              0.9251557778239836, 0.7191603787632175, 0.30804891163954246`], 
             UndirectedEdge[441, 450] -> 
             RGBColor[
              0.21849705952285933`, 0.34698464144520536`, 0.9357544563511697],
              UndirectedEdge[5, 259] -> 
             RGBColor[
              0.686424746410886, 0.7549594960082611, 0.969380061784424], 
             UndirectedEdge[279, 318] -> 
             RGBColor[
              0.20298181137445004`, 0.33067713191767734`, 0.9348708859218705],
              UndirectedEdge[275, 355] -> 
             RGBColor[
              0.5245111056702372, 0.6248607703959599, 0.9557105820673001], 
             UndirectedEdge[344, 387] -> 
             RGBColor[
              0.1895833056665427, 0.31659445290433924`, 0.9341078608431181], 
             UndirectedEdge[239, 489] -> 
             RGBColor[
              0.1941327088524955, 0.32137616410159764`, 0.9343669426243193], 
             UndirectedEdge[21, 336] -> 
             RGBColor[
              0.4626767064166898, 0.5696895855885848, 0.9520225624103578], 
             UndirectedEdge[32, 312] -> 
             RGBColor[
              0.20732064752653726`, 0.335237523811622, 0.935117976221999], 
             UndirectedEdge[77, 436] -> 
             RGBColor[
              0.3449944123676427, 0.4732385528946725, 0.9432037167828538], 
             UndirectedEdge[66, 294] -> 
             RGBColor[
              0.19268716813915449`, 0.3198568091593014, 0.9342846212191803], 
             UndirectedEdge[197, 201] -> 
             RGBColor[
              0.2441727010346539, 0.373971368603798, 0.9372166461515588], 
             UndirectedEdge[228, 256] -> 
             RGBColor[
              0.28488710481113977`, 0.4165048432644388, 0.9395447890804083], 
             UndirectedEdge[292, 481] -> 
             RGBColor[
              0.1951943467181843, 0.32249201281016504`, 0.9344274013302178], 
             UndirectedEdge[444, 486] -> 
             RGBColor[
              0.4895993510327964, 0.5954321921343623, 0.953262167276795], 
             UndirectedEdge[154, 244] -> 
             RGBColor[
              0.7150943787471429, 0.7742699758488314, 0.9312778860004862], 
             UndirectedEdge[288, 386] -> 
             RGBColor[
              0.5084129263265404, 0.6064351624645463, 0.9562833697364408], 
             UndirectedEdge[273, 285] -> 
             RGBColor[
              0.20077325282687788`, 0.3283557968534793, 0.934745111779856], 
             UndirectedEdge[190, 487] -> 
             RGBColor[
              0.2046420322637051, 0.3324221293363686, 0.9349654330454369], 
             UndirectedEdge[83, 343] -> 
             RGBColor[
              0.920728738466214, 0.6743242594892878, 0.4603352612449215], 
             UndirectedEdge[1, 315] -> 
             RGBColor[
              0.19134373832478055`, 0.31844477924602455`, 0.934208114878678], 
             UndirectedEdge[4, 429] -> 
             RGBColor[
              0.18673058009120463`, 0.3135960574514107, 0.9339454023418319], 
             UndirectedEdge[189, 451] -> 
             RGBColor[
              0.22852938408198586`, 0.3575292506429629, 0.9363257823933178], 
             UndirectedEdge[10, 102] -> 
             RGBColor[
              0.21311463700569694`, 0.34132737411436953`, 0.9354479353513978],
              UndirectedEdge[357, 368] -> 
             RGBColor[
              0.18388810829963448`, 0.3106084393753497, 0.9337835277783622], 
             UndirectedEdge[128, 138] -> 
             RGBColor[
              0.18851306554638397`, 0.31546956268090953`, 0.9340469122515535],
              UndirectedEdge[336, 436] -> 
             RGBColor[
              0.49043574205618756`, 0.5945414342179349, 0.953761745333046], 
             UndirectedEdge[196, 454] -> 
             RGBColor[
              0.20169424196759916`, 0.3293238148344616, 0.9347975607489386], 
             UndirectedEdge[25, 164] -> 
             RGBColor[
              0.3024600979339018, 0.4345620939070181, 0.9405606698993174], 
             UndirectedEdge[125, 282] -> 
             RGBColor[
              0.7373315894354715, 0.794728308685404, 0.9744539801456191], 
             UndirectedEdge[9, 286] -> 
             RGBColor[
              0.19059390233229334`, 0.3176566540755726, 0.9341654128281889], 
             UndirectedEdge[421, 477] -> 
             RGBColor[
              0.1910652466541582, 0.31815206684280867`, 0.9341922551900277], 
             UndirectedEdge[105, 484] -> 
             RGBColor[
              0.1881185665568436, 0.315054919230222, 0.9340244461177081], 
             UndirectedEdge[299, 475] -> 
             RGBColor[
              0.28830100074598397`, 0.41778431854565623`, 0.939823739896893], 
             UndirectedEdge[247, 252] -> 
             RGBColor[
              0.18329308738435063`, 0.3099830346668814, 0.9337496422174913], 
             UndirectedEdge[261, 478] -> 
             RGBColor[
              0.2893032374986769, 0.41950673564807195`, 0.9398563203301515], 
             UndirectedEdge[104, 303] -> 
             RGBColor[
              0.8824648742106225, 0.5257558359619144, 0.2222571743069387], 
             UndirectedEdge[32, 66] -> 
             RGBColor[
              0.20877736241614875`, 0.33676862352166215`, 0.9352009339799459],
              UndirectedEdge[213, 454] -> 
             RGBColor[
              0.20680491942710666`, 0.3346954608800703, 0.9350886062696878], 
             UndirectedEdge[129, 331] -> 
             RGBColor[
              0.2954052676483876, 0.42782004444717026`, 0.9401342650284206], 
             UndirectedEdge[245, 475] -> 
             RGBColor[
              0.2902269064135576, 0.4198085675117481, 0.9399334173755393], 
             UndirectedEdge[90, 148] -> 
             RGBColor[
              0.26849318417245727`, 0.3995337383893224, 0.9386016616873261], 
             UndirectedEdge[195, 496] -> 
             RGBColor[
              0.18695506079229124`, 0.31383200090115126`, 0.9339581861856694],
              UndirectedEdge[241, 371] -> 
             RGBColor[
              0.2348560709776379, 0.3641789997054109, 0.9366860778525307], 
             UndirectedEdge[13, 243] -> 
             RGBColor[
              0.2247623131438397, 0.3535698202408788, 0.9361112532762724], 
             UndirectedEdge[246, 384] -> 
             RGBColor[
              0.2539870125967417, 0.38428683231884564`, 0.9377755566760467], 
             UndirectedEdge[22, 268] -> 
             RGBColor[
              0.1840499075552901, 0.3107785006517091, 0.9337927420066112], 
             UndirectedEdge[69, 306] -> 
             RGBColor[
              0.3418131212888621, 0.4641982370033755, 0.9432311265611506], 
             UndirectedEdge[66, 128] -> 
             RGBColor[
              0.19606919376904863`, 0.32341153252913013`, 0.9344772225755442],
              UndirectedEdge[220, 413] -> 
             RGBColor[
              0.2236716605546839, 0.35242347521830786`, 0.9360491422247958], 
             UndirectedEdge[319, 492] -> 
             RGBColor[
              0.18173579190696668`, 0.3083462183819148, 0.9336609565438665], 
             UndirectedEdge[61, 186] -> 
             RGBColor[
              0.9917911303595999, 0.9891836280481643, 0.6628745668001933], 
             UndirectedEdge[94, 401] -> 
             RGBColor[
              0.17982716171712376`, 0.30634012703824637`, 0.9335522628781203],
              UndirectedEdge[429, 488] -> 
             RGBColor[
              0.1872389149746237, 0.3141303496441773, 0.9339743512614285], 
             UndirectedEdge[11, 431] -> 
             RGBColor[
              0.3984128235048672, 0.519506895734326, 0.9466074907044714], 
             UndirectedEdge[349, 487] -> 
             RGBColor[
              0.1889676303182698, 0.3159473390772327, 0.9340727990428441], 
             UndirectedEdge[156, 198] -> 
             RGBColor[
              0.19090321227565094`, 0.31798175843742454`, 0.93418302757188], 
             UndirectedEdge[12, 188] -> 
             RGBColor[
              0.20900601855676193`, 0.3370089556230833, 0.9352139556088873], 
             UndirectedEdge[70, 111] -> 
             RGBColor[
              0.36816732392345053`, 0.4933097641799131, 0.9446802742161886], 
             UndirectedEdge[212, 286] -> 
             RGBColor[
              0.18467080520712215`, 0.3114311034509694, 0.9338281012093472], 
             UndirectedEdge[242, 282] -> 
             RGBColor[
              0.8349131599958114, 0.8712326557093291, 0.9504012848257013], 
             UndirectedEdge[70, 175] -> 
             RGBColor[
              0.3837102779939304, 0.5067722897841764, 0.945670657505465], 
             UndirectedEdge[188, 298] -> 
             RGBColor[
              0.24983259130122784`, 0.37992027213173674`, 0.9375389685291828],
              UndirectedEdge[286, 367] -> 
             RGBColor[
              0.1922727390163294, 0.3194212178748882, 0.9342610200937285], 
             UndirectedEdge[9, 492] -> 
             RGBColor[
              0.18820033017206594`, 0.3151408579739333, 0.9340291024346365], 
             UndirectedEdge[37, 343] -> 
             RGBColor[
              0.8540426861772787, 0.4109754374687308, 0.1991721784497092], 
             UndirectedEdge[376, 391] -> 
             RGBColor[
              0.4221118184289103, 0.5394962463103177, 0.9482660902046844], 
             UndirectedEdge[230, 490] -> 
             RGBColor[
              0.21093312852044277`, 0.33903447038074064`, 0.9353237016704152],
              UndirectedEdge[346, 355] -> 
             RGBColor[
              0.5005625797661037, 0.605095092452838, 0.9539145635661582], 
             UndirectedEdge[30, 465] -> 
             RGBColor[
              0.17899164586466354`, 0.3054619469025459, 0.9335046814863577], 
             UndirectedEdge[119, 124] -> 
             RGBColor[
              0.18484388120986256`, 0.311613017303502, 0.9338379576316604], 
             UndirectedEdge[301, 436] -> 
             RGBColor[
              0.5059845229884368, 0.6069488070899312, 0.9551333650755793], 
             UndirectedEdge[39, 108] -> 
             RGBColor[
              0.22860230621824829`, 0.3576058964317052, 0.9363299352010993], 
             UndirectedEdge[98, 382] -> 
             RGBColor[
              0.20018581629901203`, 0.3277383638170652, 0.9347116581386283], 
             UndirectedEdge[81, 208] -> 
             RGBColor[
              0.3324858109628042, 0.4558962797557328, 0.942644967739437], 
             UndirectedEdge[154, 203] -> 
             RGBColor[
              0.9142690676811895, 0.6673158743356673, 0.5518317374650853], 
             UndirectedEdge[145, 367] -> 
             RGBColor[
              0.2030970423728074, 0.33079824700301824`, 0.9348774481567581], 
             UndirectedEdge[44, 132] -> 
             RGBColor[
              0.27566251602704606`, 0.4070691607303891, 0.9390099445303688], 
             UndirectedEdge[319, 357] -> 
             RGBColor[
              0.18470360051772483`, 0.3114655734017556, 0.9338299688537698], 
             UndirectedEdge[364, 378] -> 
             RGBColor[
              0.20567802361676119`, 0.3335110219340761, 0.9350244312203816], 
             UndirectedEdge[213, 251] -> 
             RGBColor[
              0.22057376513923174`, 0.3491673907187537, 0.9358727216638114], 
             UndirectedEdge[73, 136] -> 
             RGBColor[
              0.5525602908951197, 0.647632362562914, 0.9579187166757537], 
             UndirectedEdge[441, 461] -> 
             RGBColor[
              0.2373696075780963, 0.3668208860399178, 0.9368292200434826], 
             UndirectedEdge[90, 480] -> 
             RGBColor[
              0.2528560578238772, 0.3830981271458908, 0.9377111504748298], 
             UndirectedEdge[118, 446] -> 
             RGBColor[
              0.18780907665371493`, 0.3147296257192406, 0.9340068211255742], 
             UndirectedEdge[210, 480] -> 
             RGBColor[
              0.21944240212988145`, 0.3479782564633687, 0.9358082922141305], 
             UndirectedEdge[95, 492] -> 
             RGBColor[
              0.18364470169108055`, 0.3103526035968892, 0.9337696661320929], 
             UndirectedEdge[261, 328] -> 
             RGBColor[
              0.28613962453427205`, 0.41618157783783527`, 0.9396761572519747],
              UndirectedEdge[152, 496] -> 
             RGBColor[
              0.1850253408084585, 0.31180374284682943`, 0.9338482914873549], 
             UndirectedEdge[86, 177] -> 
             RGBColor[
              0.1848471163861694, 0.31161641767892256`, 0.933838141870165], 
             UndirectedEdge[45, 217] -> 
             RGBColor[
              0.19120987418842403`, 0.31830407955123735`, 0.9342004915141469],
              UndirectedEdge[306, 331] -> 
             RGBColor[
              0.2711023891418522, 0.40227617824530654`, 0.9387502520503602], 
             UndirectedEdge[103, 129] -> 
             RGBColor[
              0.3495899489939847, 0.47542806862452014`, 0.9435621141955579], 
             UndirectedEdge[50, 126] -> 
             RGBColor[
              0.6844097961772514, 0.7515158315979785, 0.9706616235238129], 
             UndirectedEdge[172, 308] -> 
             RGBColor[
              0.207198246316672, 0.3351088723793687, 0.9351110056541736], 
             UndirectedEdge[112, 266] -> 
             RGBColor[
              0.9935124253020141, 0.9901198523525236, 0.6506615550659651], 
             UndirectedEdge[129, 275] -> 
             RGBColor[
              0.3893440856753081, 0.5088837722097477, 0.9463652522390695], 
             UndirectedEdge[297, 325] -> 
             RGBColor[
              0.21444902327045198`, 0.3427298986836028, 0.9355239266751281], 
             UndirectedEdge[202, 396] -> 
             RGBColor[
              0.1920993256937792, 0.31923894947784826`, 0.9342511444615511], 
             UndirectedEdge[167, 236] -> 
             RGBColor[
              0.22411127044535895`, 0.3528855330862843, 0.9360741773577252], 
             UndirectedEdge[184, 301] -> 
             RGBColor[
              0.5986418341837841, 0.6848276074011173, 0.9616939873161781], 
             UndirectedEdge[78, 258] -> 
             RGBColor[
              0.44262074177976496`, 0.5573429685234437, 0.9495499886233556], 
             UndirectedEdge[172, 470] -> 
             RGBColor[
              0.2090529849214024, 0.33705832025015997`, 0.9352166302738731], 
             UndirectedEdge[72, 159] -> 
             RGBColor[
              0.22161615608300847`, 0.35026300969206614`, 0.9359320842859804],
              UndirectedEdge[304, 337] -> 
             RGBColor[
              0.1898974932161501, 0.3169246839396178, 0.9341257533592695], 
             UndirectedEdge[88, 271] -> 
             RGBColor[
              0.19882737388287028`, 0.32631055470747644`, 0.9346342968526646],
              UndirectedEdge[392, 413] -> 
             RGBColor[
              0.23358028524334118`, 0.3628380680091775, 0.9366134237423184], 
             UndirectedEdge[187, 216] -> 
             RGBColor[
              0.21058067829644372`, 0.3386640228486828, 0.9353036301515618], 
             UndirectedEdge[33, 432] -> 
             RGBColor[
              0.27375220804932543`, 0.40506130592528333`, 0.9389011553170851],
              UndirectedEdge[36, 75] -> 
             RGBColor[
              0.929724921483118, 0.7365825483050892, 0.4781251750142107], 
             UndirectedEdge[243, 335] -> 
             RGBColor[
              0.2034771985235191, 0.3311978152207083, 0.9348990974871504], 
             UndirectedEdge[323, 499] -> 
             RGBColor[
              0.8106414871808013, 0.8502981241426343, 0.8671892234801464], 
             UndirectedEdge[168, 480] -> 
             RGBColor[
              0.26803681984078476`, 0.3990540705415648, 0.9385756724137677], 
             UndirectedEdge[301, 388] -> 
             RGBColor[
              0.4925680533292166, 0.5953281354024867, 0.9542784794926122], 
             UndirectedEdge[111, 371] -> 
             RGBColor[
              0.3103368514001098, 0.4381658734848475, 0.9411804208813801], 
             UndirectedEdge[103, 231] -> 
             RGBColor[
              0.5867310207555722, 0.6723340507666251, 0.9622056389073572], 
             UndirectedEdge[99, 131] -> 
             RGBColor[
              0.9067135965497277, 0.6223214351513566, 0.549591400192696], 
             UndirectedEdge[193, 428] -> 
             RGBColor[
              0.18434895637471288`, 0.31109281992171267`, 0.9338097723944743],
              UndirectedEdge[189, 370] -> 
             RGBColor[
              0.24036595787050763`, 0.36997024017682334`, 0.9369998577599323],
              UndirectedEdge[45, 187] -> 
             RGBColor[
              0.21121178851668337`, 0.3393273597048538, 0.9353395709449606], 
             UndirectedEdge[346, 443] -> 
             RGBColor[
              0.3646259972920919, 0.4883092353080305, 0.9445254082932095], 
             UndirectedEdge[19, 318] -> 
             RGBColor[
              0.20059929205314941`, 0.3281729530505406, 0.9347352049711439], 
             UndirectedEdge[5, 129] -> 
             RGBColor[
              0.4894760344411281, 0.5894520908087815, 0.9547425358777173], 
             UndirectedEdge[29, 46] -> 
             RGBColor[
              0.19406985648437775`, 0.32131010227763557`, 0.9343633632749366],
              UndirectedEdge[227, 263] -> 
             RGBColor[
              0.2087485483203887, 0.3367383380800992, 0.935199293059819], 
             UndirectedEdge[272, 435] -> 
             RGBColor[
              0.24781268178209245`, 0.377797219157465, 0.9374239376702564], 
             UndirectedEdge[208, 483] -> 
             RGBColor[
              0.4393277460874472, 0.554945345231554, 0.949214553391788], 
             UndirectedEdge[244, 475] -> 
             RGBColor[
              0.39162513268333266`, 0.5136277391039731, 0.9461749850474426], 
             UndirectedEdge[350, 412] -> 
             RGBColor[
              0.18588998404715956`, 0.3127125377122519, 0.9338975316406739], 
             UndirectedEdge[217, 398] -> 
             RGBColor[
              0.1937507850823029, 0.3209747380037596, 0.9343451926306123], 
             UndirectedEdge[370, 451] -> 
             RGBColor[
              0.21692330433294027`, 0.34533052495875827`, 0.935664833321266], 
             UndirectedEdge[265, 424] -> 
             RGBColor[
              0.18889724072199854`, 0.3158733551485935, 0.9340687904594684], 
             UndirectedEdge[28, 419] -> 
             RGBColor[
              0.5625638978028586, 0.6556476235991, 0.9587787905130681], 
             UndirectedEdge[67, 381] -> 
             RGBColor[
              0.18458590754106158`, 0.31134187062111685`, 0.93382326641286], 
             UndirectedEdge[239, 435] -> 
             RGBColor[
              0.21752143841029148`, 0.3459592017979452, 0.9356988961721111], 
             UndirectedEdge[302, 370] -> 
             RGBColor[
              0.23676036432994563`, 0.36618053275785845`, 0.936794524541795], 
             UndirectedEdge[2, 66] -> 
             RGBColor[
              0.19103840083759993`, 0.31812385018748285`, 0.9341907263604894],
              UndirectedEdge[36, 408] -> 
             RGBColor[
              0.9657078104957213, 0.9722942089440085, 0.8689827508705463], 
             UndirectedEdge[76, 483] -> 
             RGBColor[
              0.43123446241891855`, 0.5479353496981393, 0.948698856513039], 
             UndirectedEdge[9, 367] -> 
             RGBColor[
              0.19547077493947268`, 0.3227825563973006, 0.9344431435084812], 
             UndirectedEdge[133, 469] -> 
             RGBColor[
              0.18966655655355485`, 0.31668195486500017`, 0.9341126018579748],
              UndirectedEdge[46, 297] -> 
             RGBColor[
              0.19948643535294036`, 0.32700327009943075`, 0.934671829428391], 
             UndirectedEdge[159, 435] -> 
             RGBColor[
              0.23525737339525699`, 0.3646007939903714, 0.9367089314315404], 
             UndirectedEdge[126, 340] -> 
             RGBColor[
              0.4261246264730337, 0.5425553802981693, 0.948636879181104], 
             UndirectedEdge[27, 290] -> 
             RGBColor[
              0.18336907213961767`, 0.31006289946237875`, 0.9337539694368944],
              UndirectedEdge[326, 338] -> 
             RGBColor[
              0.5748571876552486, 0.6636751524188924, 0.9607610097179233], 
             UndirectedEdge[179, 438] -> 
             RGBColor[
              0.20137694299580192`, 0.3289903134971859, 0.9347794910418965], 
             UndirectedEdge[138, 339] -> 
             RGBColor[
              0.1814781394477339, 0.3080754093111516, 0.9336462836174759], 
             UndirectedEdge[475, 482] -> 
             RGBColor[
              0.3344502958688525, 0.46410576914612495`, 0.942531855003347], 
             UndirectedEdge[94, 428] -> 
             RGBColor[
              0.18335052254202558`, 0.31004340265919705`, 0.9337529130647533],
              UndirectedEdge[186, 295] -> 
             RGBColor[
              0.9890595681546568, 0.9880540568784736, 0.7081436215924831], 
             UndirectedEdge[348, 372] -> 
             RGBColor[
              0.5381758194150634, 0.6359544006023488, 0.9567863183887886], 
             UndirectedEdge[293, 343] -> 
             RGBColor[
              0.8279897500301316, 0.6038277857603807, 0.5867878259844261], 
             UndirectedEdge[385, 446] -> 
             RGBColor[
              0.18248129368631721`, 0.30912978801955504`, 0.9337034117673295],
              UndirectedEdge[7, 288] -> 
             RGBColor[
              0.5917887149964642, 0.6784248496808247, 0.9617281729213873], 
             UndirectedEdge[242, 323] -> 
             RGBColor[
              0.9829115082024764, 0.98536084245597, 0.8504363857845441], 
             UndirectedEdge[464, 481] -> 
             RGBColor[
              0.2038613891913174, 0.3316016239716596, 0.9349209765773223], 
             UndirectedEdge[42, 108] -> 
             RGBColor[
              0.2050818952093152, 0.3328844531811263, 0.9349904825894705], 
             UndirectedEdge[101, 276] -> 
             RGBColor[
              0.22935486634297414`, 0.3583968848378599, 0.9363727923868895], 
             UndirectedEdge[86, 426] -> 
             RGBColor[
              0.1863343941921356, 0.31317964095185236`, 0.9339228401409845], 
             UndirectedEdge[37, 324] -> 
             RGBColor[
              0.9007937640631225, 0.7100849667901136, 0.5966707240103046], 
             UndirectedEdge[290, 297] -> 
             RGBColor[
              0.18839455558370108`, 0.3153450011961642, 0.9340401632844985], 
             UndirectedEdge[315, 380] -> 
             RGBColor[
              0.18543946082278231`, 0.31223900923860914`, 0.9338718750095351],
              UndirectedEdge[181, 390] -> 
             RGBColor[
              0.24071562353706022`, 0.37033776096245374`, 0.9370197707023586],
              UndirectedEdge[283, 421] -> 
             RGBColor[
              0.18332707368146411`, 0.3100187564200033, 0.9337515776868337], 
             UndirectedEdge[97, 355] -> 
             RGBColor[
              0.7740833188183651, 0.8130804459299827, 0.6840694071044306], 
             UndirectedEdge[192, 219] -> 
             RGBColor[
              0.49125780976030897`, 0.5936378228658237, 0.9544300827546521], 
             UndirectedEdge[171, 192] -> 
             RGBColor[
              0.3918420426717766, 0.5133437939110442, 0.9463191721078775], 
             UndirectedEdge[122, 216] -> 
             RGBColor[
              0.19279683115434215`, 0.3199720719413004, 0.9342908663656634], 
             UndirectedEdge[18, 28] -> 
             RGBColor[
              0.38207742266917044`, 0.5028572911387341, 0.9458047612186589], 
             UndirectedEdge[178, 288] -> 
             RGBColor[
              0.5902663931329839, 0.677188960212233, 0.9616083301678455], 
             UndirectedEdge[165, 185] -> 
             RGBColor[
              0.2587337613234965, 0.38927596619191684`, 0.93804587699385], 
             UndirectedEdge[264, 281] -> 
             RGBColor[
              0.8419839123581961, 0.3124840077358858, 0.18739747519941907`], 
             UndirectedEdge[80, 192] -> 
             RGBColor[
              0.3302026401393104, 0.46042666324658016`, 0.9422611981363149], 
             UndirectedEdge[74, 402] -> 
             RGBColor[
              0.20341804022375085`, 0.331135636096799, 0.9348957285094954], 
             UndirectedEdge[3, 158] -> 
             RGBColor[
              0.187682952058607, 0.31459706077302096`, 0.9339996385164674], 
             UndirectedEdge[426, 476] -> 
             RGBColor[
              0.1853934884122734, 0.3121906893203451, 0.9338692569487667], 
             UndirectedEdge[27, 177] -> 
             RGBColor[
              0.18479696914654997`, 0.31156370975056386`, 0.9338352860590549],
              UndirectedEdge[355, 443] -> 
             RGBColor[
              0.4237732599016528, 0.5366508333936366, 0.9490924002850236], 
             UndirectedEdge[21, 256] -> 
             RGBColor[
              0.3057801725853121, 0.43846478219210167`, 0.9407346183816234], 
             UndirectedEdge[331, 404] -> 
             RGBColor[
              0.5691308396856145, 0.6534422515230649, 0.9623880647122928], 
             UndirectedEdge[142, 285] -> 
             RGBColor[
              0.2150502131881199, 0.3433617874047141, 0.9355581635515585], 
             UndirectedEdge[232, 267] -> 
             RGBColor[
              0.25385827815003914`, 0.3841515242531258, 0.9377682254397526], 
             UndirectedEdge[133, 488] -> 
             RGBColor[
              0.19025464326071956`, 0.31730007128108106`, 0.9341460925259515],
              UndirectedEdge[148, 393] -> 
             RGBColor[
              0.24797563185424576`, 0.37796849001492944`, 0.9374332174358024],
              UndirectedEdge[84, 89] -> 
             RGBColor[
              0.2925984761880414, 0.42478343593361145`, 0.9399775893294924], 
             UndirectedEdge[27, 350] -> 
             RGBColor[
              0.18336792975933797`, 0.3100616987482737, 0.9337539043800275], 
             UndirectedEdge[8, 435] -> 
             RGBColor[
              0.21794255850182165`, 0.34640182571469935`, 0.9357228783383325],
              UndirectedEdge[20, 220] -> 
             RGBColor[
              0.2293954500117661, 0.35843954084691343`, 0.9363751035667891], 
             UndirectedEdge[35, 422] -> 
             RGBColor[
              0.19709463641182273`, 0.32448933776350447`, 0.9345356200170438],
              UndirectedEdge[65, 177] -> 
             RGBColor[
              0.18378082822451933`, 0.3104956812144541, 0.9337774183367911], 
             UndirectedEdge[93, 160] -> 
             RGBColor[
              0.23103960685447572`, 0.36016765393416605`, 0.9364687358666692],
              UndirectedEdge[277, 373] -> 
             RGBColor[
              0.7171130809828956, 0.774434213301909, 0.8741433170431847], 
             UndirectedEdge[15, 126] -> 
             RGBColor[
              0.5704313985291926, 0.6619870174784861, 0.9594308284953961], 
             UndirectedEdge[95, 367] -> 
             RGBColor[
              0.19091514645848728`, 0.31799430202025647`, 0.9341837072059376],
              UndirectedEdge[304, 465] -> 
             RGBColor[
              0.18487917380697239`, 0.31165011206074433`, 0.933839967492855], 
             UndirectedEdge[218, 305] -> 
             RGBColor[
              0.29821563929003225`, 0.43060670099699316`, 0.9403004343609631],
              UndirectedEdge[137, 265] -> 
             RGBColor[
              0.19798921213274367`, 0.325429593565569, 0.934586564780944], 
             UndirectedEdge[325, 392] -> 
             RGBColor[
              0.23524305947406288`, 0.3645857491516413, 0.9367081162749039], 
             UndirectedEdge[263, 393] -> 
             RGBColor[
              0.22282702878996197`, 0.35153571368083814`, 0.9360010416953157],
              UndirectedEdge[228, 335] -> 
             RGBColor[
              0.2342958788041693, 0.36359020221286015`, 0.9366541757369817], 
             UndirectedEdge[104, 408] -> 
             RGBColor[
              0.9307079198191593, 0.8448308855634613, 0.624429309131783], 
             UndirectedEdge[145, 375] -> 
             RGBColor[
              0.20589359976284474`, 0.33373760613192704`, 0.9350367079629848],
              UndirectedEdge[181, 451] -> 
             RGBColor[
              0.21530209522723562`, 0.3436265313980684, 0.93557250786106], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.20367497522683542`, 0.331405691075661, 0.93491036057782], 
             UndirectedEdge[387, 439] -> 
             RGBColor[
              0.1940605439508961, 0.3213003142144977, 0.9343628329399316], 
             UndirectedEdge[163, 231] -> 
             RGBColor[
              0.8314832405552138, 0.7254800292683178, 0.607385428867296], 
             UndirectedEdge[143, 288] -> 
             RGBColor[
              0.6459376056374727, 0.7223853584829198, 0.9659909719465696], 
             UndirectedEdge[128, 312] -> 
             RGBColor[
              0.19461247887943717`, 0.32188043281908996`, 0.9343942648175974],
              UndirectedEdge[270, 479] -> 
             RGBColor[
              0.18121603188329788`, 0.30779991764234993`, 0.9336313569794346],
              UndirectedEdge[119, 120] -> 
             RGBColor[
              0.18211134871711507`, 0.30874095240105776`, 0.9336823439486179],
              UndirectedEdge[105, 462] -> 
             RGBColor[
              0.19074614489061564`, 0.31781667065710506`, 0.9341740828166627],
              UndirectedEdge[14, 159] -> 
             RGBColor[
              0.2315482163827265, 0.3607022347960642, 0.9364977004268829], 
             UndirectedEdge[58, 417] -> 
             RGBColor[
              0.19514933346569613`, 0.3224447010277949, 0.9344248378920796], 
             UndirectedEdge[66, 299] -> 
             RGBColor[
              0.21897785763056482`, 0.34748999074076453`, 0.9357818370921265],
              UndirectedEdge[11, 348] -> 
             RGBColor[
              0.41882704946853977`, 0.5369507513572022, 0.9479740053732437], 
             UndirectedEdge[4, 31] -> 
             RGBColor[
              0.18674651901237604`, 0.3136128102681478, 0.9339463100398131], 
             UndirectedEdge[259, 400] -> 
             RGBColor[
              0.8365707919285453, 0.8712879121400499, 0.8933185067355665], 
             UndirectedEdge[247, 451] -> 
             RGBColor[
              0.19468301666075716`, 0.32195457249961096`, 0.9343982818398924],
              UndirectedEdge[17, 261] -> 
             RGBColor[
              0.3523681166453383, 0.4796252849268593, 0.9436735626991177], 
             UndirectedEdge[361, 386] -> 
             RGBColor[
              0.26785160184799417`, 0.39885939468764287`, 0.9385651245230838],
              UndirectedEdge[212, 492] -> 
             RGBColor[
              0.18227723304689475`, 0.30891530734933015`, 0.933691790815795], 
             UndirectedEdge[287, 388] -> 
             RGBColor[
              0.31642089310081123`, 0.44806502999070874`, 0.9413985832331735],
              UndirectedEdge[383, 480] -> 
             RGBColor[
              0.2555678088390552, 0.3859483493977877, 0.937865580683468], 
             UndirectedEdge[403, 440] -> 
             RGBColor[
              0.8175206971599966, 0.7001431418216288, 0.6031737768596591], 
             UndirectedEdge[13, 354] -> 
             RGBColor[
              0.28176652075351294`, 0.4133145757884693, 0.9393637933883066], 
             UndirectedEdge[1, 42] -> 
             RGBColor[
              0.19991385155278849`, 0.32745251162522343`, 0.9346961701486667],
              UndirectedEdge[161, 188] -> 
             RGBColor[
              0.2189136351360459, 0.34742248882708376`, 0.9357781797160722], 
             UndirectedEdge[194, 426] -> 
             RGBColor[
              0.18673198964571103`, 0.31359753898256787`, 0.9339454826138758],
              UndirectedEdge[257, 324] -> 
             RGBColor[
              0.9513926924014826, 0.9208016602260798, 0.6489338534613713], 
             UndirectedEdge[198, 479] -> 
             RGBColor[
              0.18236486345397498`, 0.30900741246326024`, 0.9336967812378407],
              UndirectedEdge[372, 431] -> 
             RGBColor[
              0.5177615934513908, 0.6185105449794727, 0.9554198037200161], 
             UndirectedEdge[107, 466] -> 
             RGBColor[
              0.20308636910120992`, 0.33078702871784477`, 0.9348768403297303],
              UndirectedEdge[122, 330] -> 
             RGBColor[
              0.18762963037517022`, 0.3145410163029389, 0.9339966019254781], 
             UndirectedEdge[4, 472] -> 
             RGBColor[
              0.18232394464799978`, 0.30896440420377813`, 0.9336944509723744],
              UndirectedEdge[145, 458] -> 
             RGBColor[
              0.2240333301287531, 0.35280361287183004`, 0.936069738771997], 
             UndirectedEdge[3, 451] -> 
             RGBColor[
              0.19437267435842231`, 0.32162838306301855`, 0.9343806083048847],
              UndirectedEdge[146, 239] -> 
             RGBColor[
              0.18835872742063176`, 0.3153073435251416, 0.9340381229236147], 
             UndirectedEdge[15, 282] -> 
             RGBColor[
              0.674559975761555, 0.7456906470014069, 0.9681974923286845], 
             UndirectedEdge[82, 126] -> 
             RGBColor[
              0.504289208348975, 0.6084437231644664, 0.9541186402349197], 
             UndirectedEdge[413, 474] -> 
             RGBColor[
              0.2299117533537109, 0.35898220839482003`, 0.9364045062783105], 
             UndirectedEdge[160, 235] -> 
             RGBColor[
              0.22828336996259535`, 0.35727067420528746`, 0.9363117722531638],
              UndirectedEdge[161, 183] -> 
             RGBColor[
              0.2054076978090161, 0.33322689237048986`, 0.9350090365655417], 
             UndirectedEdge[366, 429] -> 
             RGBColor[
              0.18725297443025463`, 0.3141451270234664, 0.9339751519266276], 
             UndirectedEdge[7, 313] -> 
             RGBColor[
              0.4167872287841039, 0.534905009234637, 0.9479211050634437], 
             UndirectedEdge[129, 444] -> 
             RGBColor[
              0.42761995292876165`, 0.539957845554271, 0.9493784687183828], 
             UndirectedEdge[18, 493] -> 
             RGBColor[
              0.274609024515375, 0.4059618743564031, 0.9389499497472802], 
             UndirectedEdge[149, 411] -> 
             RGBColor[
              0.4211694508709569, 0.5337442476409241, 0.9489595750460023], 
             UndirectedEdge[221, 301] -> 
             RGBColor[
              0.8093616863432395, 0.8079745679423065, 0.6371695161143949], 
             UndirectedEdge[45, 496] -> 
             RGBColor[
              0.19349628938952101`, 0.32070724689468694`, 0.9343306994774011],
              UndirectedEdge[478, 482] -> 
             RGBColor[
              0.2908428553905808, 0.4208402752825938, 0.939954423420793], 
             UndirectedEdge[69, 331] -> 
             RGBColor[
              0.37214546505797846`, 0.49607945348638943`, 0.9449585086661204],
              UndirectedEdge[16, 143] -> 
             RGBColor[
              0.42538425366010096`, 0.535839238383477, 0.9494121511680118], 
             UndirectedEdge[210, 280] -> 
             RGBColor[
              0.22449871038575198`, 0.3532927570287484, 0.9360962414891647], 
             UndirectedEdge[101, 390] -> 
             RGBColor[
              0.25051248587412484`, 0.3806348844356572, 0.9375776875192954], 
             UndirectedEdge[400, 418] -> 
             RGBColor[
              0.7331868241624636, 0.7879829034782768, 0.8847512271126452], 
             UndirectedEdge[84, 299] -> 
             RGBColor[
              0.2577944317187598, 0.3882886712204018, 0.9379923835624739], 
             UndirectedEdge[333, 386] -> 
             RGBColor[
              0.268695341419697, 0.3997462184736812, 0.9386131742434916], 
             UndirectedEdge[244, 341] -> 
             RGBColor[
              0.7205094989495678, 0.7757802394753833, 0.7851817105206231], 
             UndirectedEdge[143, 373] -> 
             RGBColor[
              0.7858256992864812, 0.8304922181829903, 0.8794769174192558], 
             UndirectedEdge[160, 284] -> 
             RGBColor[
              0.22313950665110643`, 0.35186414772514174`, 0.9360188368472383],
              UndirectedEdge[281, 343] -> 
             RGBColor[
              0.8323272687160201, 0.24948713001661726`, 0.17858993507187598`],
              UndirectedEdge[207, 445] -> 
             RGBColor[
              0.9190529143682962, 0.7062401460895815, 0.26431121911210875`], 
             UndirectedEdge[260, 334] -> 
             RGBColor[
              0.19830298963418935`, 0.3257593936142311, 0.9346044339454591], 
             UndirectedEdge[66, 114] -> 
             RGBColor[
              0.1896583133560848, 0.31667329074181017`, 0.9341121324200736], 
             UndirectedEdge[364, 381] -> 
             RGBColor[
              0.19634549402636683`, 0.3237019416180197, 0.9344929574664489], 
             UndirectedEdge[204, 306] -> 
             RGBColor[
              0.2783366060930942, 0.40921806996322074`, 0.9391864591429547], 
             UndirectedEdge[358, 361] -> 
             RGBColor[
              0.2274919045840746, 0.3564387939106588, 0.9362666994707252], 
             UndirectedEdge[294, 415] -> 
             RGBColor[
              0.18394556991543065`, 0.3106688351768284, 0.9337868001323749], 
             UndirectedEdge[2, 255] -> 
             RGBColor[
              0.19068245309328063`, 0.3177497265398128, 0.9341704556630279], 
             UndirectedEdge[326, 443] -> 
             RGBColor[
              0.5066093535132791, 0.6026290989849493, 0.956483102354086], 
             UndirectedEdge[58, 145] -> 
             RGBColor[
              0.20110599109187893`, 0.32870552586681995`, 0.9347640607318055],
              UndirectedEdge[103, 346] -> 
             RGBColor[
              0.4256097063793528, 0.5430634687251261, 0.9483404520319744], 
             UndirectedEdge[62, 108] -> 
             RGBColor[
              0.2304034031645468, 0.35949896351840704`, 0.9364325050077069], 
             UndirectedEdge[91, 336] -> 
             RGBColor[
              0.5428373971732765, 0.639738879428151, 0.957153294865837], 
             UndirectedEdge[338, 395] -> 
             RGBColor[
              0.4642366864681818, 0.5751402530845398, 0.9511830173068838], 
             UndirectedEdge[19, 335] -> 
             RGBColor[
              0.20679640724799403`, 0.3346865140401196, 0.9350881215136799], 
             UndirectedEdge[2, 195] -> 
             RGBColor[
              0.18614467853761885`, 0.312980237770288, 0.933912036115119], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.2086123729274203, 0.33659520910807084`, 0.9351915380726428], 
             UndirectedEdge[150, 325] -> 
             RGBColor[
              0.2244980131258032, 0.35329202416433336`, 0.9360962017812421], 
             UndirectedEdge[208, 238] -> 
             RGBColor[
              0.4566518822195865, 0.5690445386024363, 0.9505687908779773], 
             UndirectedEdge[318, 335] -> 
             RGBColor[
              0.2041779627078255, 0.33193436280942984`, 0.9349390049707589], 
             UndirectedEdge[12, 421] -> 
             RGBColor[
              0.18918604161445732`, 0.31617690319760183`, 0.9340852372430514],
              UndirectedEdge[102, 278] -> 
             RGBColor[
              0.19195325855915324`, 0.31908542365816517`, 0.9342428261543212],
              UndirectedEdge[5, 209] -> 
             RGBColor[
              0.8420261863364131, 0.8747026148224741, 0.8554514610488602], 
             UndirectedEdge[76, 463] -> 
             RGBColor[
              0.4827936292790318, 0.5898280832845495, 0.9527482010251842], 
             UndirectedEdge[293, 445] -> 
             RGBColor[
              0.8864338531014064, 0.8692772537699642, 0.6464479308964578], 
             UndirectedEdge[48, 250] -> 
             RGBColor[
              0.20476233546869063`, 0.33254857563247214`, 0.9349722841349881],
              UndirectedEdge[459, 477] -> 
             RGBColor[
              0.19613686914455325`, 0.32348266363965217`, 0.9344810765880625],
              UndirectedEdge[400, 404] -> 
             RGBColor[
              0.9133476519960143, 0.9314027140164651, 0.9009347805127319], 
             UndirectedEdge[144, 246] -> 
             RGBColor[
              0.21838885852257034`, 0.34687091533356196`, 0.9357482944642723],
              UndirectedEdge[90, 393] -> 
             RGBColor[
              0.24183341082623228`, 0.3715126262751811, 0.9370834270348589], 
             UndirectedEdge[157, 360] -> 
             RGBColor[
              0.44762961538947754`, 0.5573651742459853, 0.9508478770838158], 
             UndirectedEdge[156, 250] -> 
             RGBColor[
              0.20951821380303975`, 0.3375473053019756, 0.9352431243704379], 
             UndirectedEdge[25, 220] -> 
             RGBColor[
              0.25296409856661417`, 0.38321168481668605`, 0.9377173032352967],
              UndirectedEdge[261, 407] -> 
             RGBColor[
              0.30321117252682794`, 0.43412485717667065`, 0.9406483566550587],
              UndirectedEdge[42, 364] -> 
             RGBColor[
              0.2024710281446618, 0.33014026635764265`, 0.9348417975725702], 
             UndirectedEdge[83, 257] -> 
             RGBColor[
              0.9791397410141973, 0.9396620716614368, 0.5198667768744751], 
             UndirectedEdge[137, 263] -> 
             RGBColor[
              0.21799699214111928`, 0.34645903892089325`, 0.935725978253563], 
             UndirectedEdge[27, 65] -> 
             RGBColor[
              0.1841954077512366, 0.31093143058289413`, 0.9338010280275222], 
             UndirectedEdge[318, 421] -> 
             RGBColor[
              0.19115878724665003`, 0.3182503839363337, 0.9341975821883891], 
             UndirectedEdge[203, 341] -> 
             RGBColor[
              0.9196841878836145, 0.6688261379622193, 0.4057355619852222], 
             UndirectedEdge[80, 483] -> 
             RGBColor[
              0.3997284089104274, 0.520646389689377, 0.9466913186431871], 
             UndirectedEdge[95, 319] -> 
             RGBColor[
              0.18277177150935192`, 0.30943509862892227`, 0.9337199540496279],
              UndirectedEdge[84, 376] -> 
             RGBColor[
              0.3233121821951179, 0.4513861043611917, 0.9419346395171995], 
             UndirectedEdge[260, 446] -> 
             RGBColor[
              0.19657895504970424`, 0.32394732395583115`, 0.9345062527263533],
              UndirectedEdge[174, 393] -> 
             RGBColor[
              0.20439651484045512`, 0.33216407495782907`, 0.9349514511913933],
              UndirectedEdge[185, 216] -> 
             RGBColor[
              0.20572802131241785`, 0.3335635726822483, 0.9350272785151843], 
             UndirectedEdge[143, 321] -> 
             RGBColor[
              0.78304348190439, 0.8293416997957703, 0.9255854595882844], 
             UndirectedEdge[296, 415] -> 
             RGBColor[
              0.18131418208775438`, 0.30790307973031616`, 0.9336369464883782],
              UndirectedEdge[42, 113] -> 
             RGBColor[
              0.1986334681543265, 0.3261067474924436, 0.9346232542082819], 
             UndirectedEdge[54, 264] -> 
             RGBColor[
              0.9275346951808384, 0.7361423049047013, 0.5163860611032753], 
             UndirectedEdge[9, 95] -> 
             RGBColor[
              0.18923630977445122`, 0.3162297382209408, 0.934088099940398], 
             UndirectedEdge[47, 55] -> 
             RGBColor[
              0.42760134170853215`, 0.539013813149998, 0.94946155992206], 
             UndirectedEdge[212, 330] -> 
             RGBColor[
              0.18576322285580926`, 0.312579303663019, 0.9338903127783529], 
             UndirectedEdge[89, 244] -> 
             RGBColor[
              0.37820158055690994`, 0.5020009329394131, 0.945319648175928], 
             UndirectedEdge[3, 247] -> 
             RGBColor[
              0.18396896047476097`, 0.31069342013773166`, 0.9337881321901256],
              UndirectedEdge[26, 318] -> 
             RGBColor[
              0.1914380372433468, 0.3185438933883344, 0.9342134850625876], 
             UndirectedEdge[46, 426] -> 
             RGBColor[
              0.19553365018810587`, 0.3228486422701351, 0.9344467241608754], 
             UndirectedEdge[102, 247] -> 
             RGBColor[
              0.19186086570906943`, 0.31898831291468205`, 0.934237564518192], 
             UndirectedEdge[285, 287] -> 
             RGBColor[
              0.2592707940788048, 0.38984042166758914`, 0.938076460214796], 
             UndirectedEdge[346, 390] -> 
             RGBColor[
              0.34866455216030523`, 0.47153274446045024`, 0.9436164276057963],
              UndirectedEdge[388, 473] -> 
             RGBColor[
              0.2961409162225916, 0.4267494884669002, 0.9402436685514961], 
             UndirectedEdge[377, 412] -> 
             RGBColor[
              0.18552364470094684`, 0.3123274918321262, 0.9338766691568576], 
             UndirectedEdge[7, 321] -> 
             RGBColor[
              0.7288945912633815, 0.7853811909936754, 0.9213226605631021], 
             UndirectedEdge[209, 275] -> 
             RGBColor[
              0.7418942375705933, 0.7941342962234403, 0.8470741774102124], 
             UndirectedEdge[204, 346] -> 
             RGBColor[
              0.3786592419849977, 0.5023973362656904, 0.9453488099574316], 
             UndirectedEdge[220, 297] -> 
             RGBColor[
              0.20614792707638763`, 0.3340049202637436, 0.9350511915272475], 
             UndirectedEdge[16, 185] -> 
             RGBColor[
              0.2408288180096403, 0.3704567355300795, 0.9370262169601158], 
             UndirectedEdge[323, 449] -> 
             RGBColor[
              0.9881583833202512, 0.9738084894895631, 0.5806455490390734], 
             UndirectedEdge[224, 481] -> 
             RGBColor[
              0.20560152977914695`, 0.33343062206075413`, 0.9350200750094919],
              UndirectedEdge[86, 476] -> 
             RGBColor[
              0.18437093737264393`, 0.311115923344214, 0.9338110241797885], 
             UndirectedEdge[66, 385] -> 
             RGBColor[
              0.189718897172314, 0.31673696817390284`, 0.9341155825787821], 
             UndirectedEdge[184, 316] -> 
             RGBColor[
              0.4897742836055883, 0.5962632949587165, 0.9530855424591965], 
             UndirectedEdge[308, 362] -> 
             RGBColor[
              0.18507064546441102`, 0.3118513609127166, 0.9338508715204893], 
             UndirectedEdge[216, 361] -> 
             RGBColor[
              0.21500792746091607`, 0.34331734242435297`, 0.9355557554419504],
              UndirectedEdge[123, 410] -> 
             RGBColor[
              0.18404732868398718`, 0.3107757900944599, 0.9337925951437056], 
             UndirectedEdge[174, 225] -> 
             RGBColor[
              0.18572114805288265`, 0.3125350803774465, 0.9338879166805704], 
             UndirectedEdge[3, 139] -> 
             RGBColor[
              0.18312900664284068`, 0.3098105754042345, 0.933740298061998], 
             UndirectedEdge[226, 472] -> 
             RGBColor[
              0.18505776823943543`, 0.311837826132804, 0.933850138181577], 
             UndirectedEdge[9, 441] -> 
             RGBColor[
              0.2076297588947049, 0.33556241945835885`, 0.9351355796571268], 
             UndirectedEdge[253, 354] -> 
             RGBColor[
              0.34404011319445926`, 0.47241198691533204`, 0.9431429096833921],
              UndirectedEdge[47, 73] -> 
             RGBColor[
              0.42925393472115597`, 0.5403554626061129, 0.9495916580976614], 
             UndirectedEdge[305, 432] -> 
             RGBColor[
              0.30089384576863576`, 0.43342166581410385`, 0.9404529542578681],
              UndirectedEdge[4, 226] -> 
             RGBColor[
              0.18424586592068898`, 0.3109844653182212, 0.9338039015456263], 
             UndirectedEdge[112, 359] -> 
             RGBColor[
              0.9514837896604106, 0.9611256689561112, 0.8747939095613684], 
             UndirectedEdge[101, 204] -> 
             RGBColor[
              0.2805071756988172, 0.41149947624089733`, 0.9393100698709307], 
             UndirectedEdge[256, 409] -> 
             RGBColor[
              0.2823955714492146, 0.41388608372871627`, 0.93940289994134], 
             UndirectedEdge[64, 268] -> 
             RGBColor[
              0.18555371944787077`, 0.31235910229799235`, 0.9338783818692034],
              UndirectedEdge[97, 395] -> 
             RGBColor[
              0.7462989112429244, 0.7905238121869427, 0.6818821167624534], 
             UndirectedEdge[117, 156] -> 
             RGBColor[
              0.19147940284680726`, 0.31858737126030207`, 0.9342158407725099],
              UndirectedEdge[48, 117] -> 
             RGBColor[
              0.18672352451245816`, 0.31358864159079863`, 0.9339450005370601],
              UndirectedEdge[5, 103] -> 
             RGBColor[
              0.5496901810493061, 0.6433974652672816, 0.958513754171764], 
             UndirectedEdge[344, 438] -> 
             RGBColor[
              0.19645882867909248`, 0.32382106352386636`, 0.934499411707258], 
             UndirectedEdge[42, 381] -> 
             RGBColor[
              0.19442462278648562`, 0.3216829841546337, 0.9343835666910121], 
             UndirectedEdge[224, 398] -> 
             RGBColor[
              0.2060967195595755, 0.33395109791683003`, 0.9350482753349197], 
             UndirectedEdge[226, 405] -> 
             RGBColor[
              0.18431945622850954`, 0.3110618133976357, 0.9338080924047896], 
             UndirectedEdge[231, 346] -> 
             RGBColor[
              0.6025366315327623, 0.6860240764087309, 0.963212758449727], 
             UndirectedEdge[168, 181] -> 
             RGBColor[
              0.25911497354415575`, 0.3896766444060805, 0.9380675864658636], 
             UndirectedEdge[178, 391] -> 
             RGBColor[
              0.47121205870336796`, 0.5815902029735522, 0.9515146858492259], 
             UndirectedEdge[30, 133] -> 
             RGBColor[
              0.18845727560531045`, 0.31541092391555475`, 0.934043735096943], 
             UndirectedEdge[120, 363] -> 
             RGBColor[
              0.18125858689584057`, 0.307844645658676, 0.9336337804244444], 
             UndirectedEdge[452, 468] -> 
             RGBColor[
              0.22415491498640028`, 0.35293140626614244`, 0.9360766628497713],
              UndirectedEdge[159, 344] -> 
             RGBColor[
              0.2111960256367822, 0.3393107919186533, 0.9353386732722694], 
             UndirectedEdge[68, 330] -> 
             RGBColor[
              0.18750410848445143`, 0.3144090848372459, 0.9339894536394946], 
             UndirectedEdge[359, 440] -> 
             RGBColor[
              0.9005793035034079, 0.7657528918366445, 0.6112602253720522], 
             UndirectedEdge[180, 413] -> 
             RGBColor[
              0.24672751485063993`, 0.37665663990895104`, 0.9373621390188708],
              UndirectedEdge[81, 442] -> 
             RGBColor[
              0.2381306078360068, 0.36762074556118485`, 0.9368725578823716], 
             UndirectedEdge[165, 277] -> 
             RGBColor[
              0.37457657867037175`, 0.49860046416423287`, 0.9450982108256749],
              UndirectedEdge[28, 310] -> 
             RGBColor[
              0.5603270606284811, 0.6539001893978842, 0.958555843487958], 
             UndirectedEdge[71, 470] -> 
             RGBColor[
              0.19617627269900267`, 0.32352407927370813`, 0.9344833205621961],
              UndirectedEdge[129, 276] -> 
             RGBColor[
              0.2514871752437865, 0.381659344762047, 0.9376331946369739], 
             UndirectedEdge[192, 251] -> 
             RGBColor[
              0.2759596386433615, 0.40698913765266753`, 0.9390412298997809], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.4280975104696688, 0.5447636755214684, 0.9486245811666656], 
             UndirectedEdge[15, 323] -> 
             RGBColor[
              0.82255832396822, 0.8598188337480478, 0.8682325932875272], 
             UndirectedEdge[20, 473] -> 
             RGBColor[
              0.25267572333140287`, 0.38290858416043305`, 0.9377008806922643],
              UndirectedEdge[336, 354] -> 
             RGBColor[
              0.4679691659715405, 0.5750820152163606, 0.9523301949713454], 
             UndirectedEdge[36, 440] -> 
             RGBColor[
              0.9428820049759663, 0.7963257915311912, 0.48910376799027133`], 
             UndirectedEdge[31, 311] -> 
             RGBColor[
              0.1909827965699547, 0.3180654065766735, 0.9341875597797062], 
             UndirectedEdge[366, 405] -> 
             RGBColor[
              0.18210802697612394`, 0.3087374610406655, 0.9336821547803826], 
             UndirectedEdge[257, 374] -> 
             RGBColor[
              0.9052484576679132, 0.6263565932934416, 0.25201642158872506`], 
             UndirectedEdge[194, 254] -> 
             RGBColor[
              0.18926826388068996`, 0.3162633240126051, 0.9340899196794763], 
             UndirectedEdge[284, 456] -> 
             RGBColor[
              0.2012208320986775, 0.3288262310463056, 0.9347706007572507], 
             UndirectedEdge[30, 429] -> 
             RGBColor[
              0.18544154731921458`, 0.312241202278651, 0.9338719938324201], 
             UndirectedEdge[182, 463] -> 
             RGBColor[
              0.4500781331882001, 0.5614915648993155, 0.9506635985434537], 
             UndirectedEdge[130, 238] -> 
             RGBColor[
              0.39480407867420486`, 0.5149363424561325, 0.9466476293366854], 
             UndirectedEdge[19, 67] -> 
             RGBColor[
              0.1920452315036252, 0.3191820930542266, 0.9342480638774471], 
             UndirectedEdge[114, 446] -> 
             RGBColor[
              0.18242070987008802`, 0.30906611058746236`, 0.933699961608621], 
             UndirectedEdge[164, 418] -> 
             RGBColor[
              0.3962653140595378, 0.5170172416815048, 0.9466446107033122], 
             UndirectedEdge[96, 457] -> 
             RGBColor[
              0.47001276809964954`, 0.5806165648340276, 0.951420273299755], 
             UndirectedEdge[285, 354] -> 
             RGBColor[
              0.2624877417671351, 0.39305135672859914`, 0.93826589544543], 
             UndirectedEdge[432, 460] -> 
             RGBColor[
              0.2959533208946317, 0.4283960831575556, 0.9401654758500221], 
             UndirectedEdge[82, 249] -> 
             RGBColor[
              0.6235359473541606, 0.7039577755666018, 0.9643921411464688], 
             UndirectedEdge[176, 262] -> 
             RGBColor[
              0.33005042418212294`, 0.46029482143506084`, 0.9422514990701223],
              UndirectedEdge[216, 358] -> 
             RGBColor[
              0.21239908038802668`, 0.34057527874028815`, 0.9354071854605928],
              UndirectedEdge[54, 374] -> 
             RGBColor[
              0.9184848946909366, 0.6778098895741775, 0.5081596346636814], 
             UndirectedEdge[214, 491] -> 
             RGBColor[
              0.1845859949601158, 0.3113419625040855, 0.9338232713912458], 
             UndirectedEdge[68, 357] -> 
             RGBColor[
              0.18698592728629504`, 0.313864443543398, 0.93395994398684], 
             UndirectedEdge[260, 328] -> 
             RGBColor[
              0.2263686482084435, 0.35525818024130285`, 0.9362027316818419], 
             UndirectedEdge[224, 286] -> 
             RGBColor[
              0.19666508001759797`, 0.3240378467577258, 0.9345111574158644], 
             UndirectedEdge[219, 293] -> 
             RGBColor[
              0.7396376270146225, 0.7965298027687717, 0.9746838244203624], 
             UndirectedEdge[209, 404] -> 
             RGBColor[
              0.9156515263183187, 0.9323554252556073, 0.8627536207565263], 
             UndirectedEdge[197, 289] -> 
             RGBColor[
              0.22048333522571711`, 0.34907234314606217`, 0.9358675718140159],
              UndirectedEdge[227, 424] -> 
             RGBColor[
              0.19331536997885967`, 0.3205170891231287, 0.9343203963846103], 
             UndirectedEdge[458, 461] -> 
             RGBColor[
              0.24614691137880979`, 0.3760463888476713, 0.937329074510076], 
             UndirectedEdge[292, 464] -> 
             RGBColor[
              0.19378696997725373`, 0.3210127706226078, 0.9343472533068491], 
             UndirectedEdge[386, 441] -> 
             RGBColor[
              0.26353501578649874`, 0.39432238904964745`, 0.9383193013326985],
              UndirectedEdge[257, 343] -> 
             RGBColor[
              0.9046416145156388, 0.621692130904697, 0.25143530790077595`], 
             UndirectedEdge[132, 457] -> 
             RGBColor[
              0.37078286929344473`, 0.4917742570671961, 0.9450898009992874], 
             UndirectedEdge[69, 259] -> 
             RGBColor[
              0.5630647117651555, 0.6552495084047187, 0.9592526654459177], 
             UndirectedEdge[68, 95] -> 
             RGBColor[
              0.18505409827792216`, 0.3118339687705646, 0.933849929182698], 
             UndirectedEdge[247, 278] -> 
             RGBColor[
              0.18437169562717964`, 0.3111167203178072, 0.9338110673612625], 
             UndirectedEdge[293, 440] -> 
             RGBColor[
              0.8506906968621433, 0.7260557976902806, 0.6064798524386981], 
             UndirectedEdge[307, 442] -> 
             RGBColor[
              0.21483864965875055`, 0.34313942072144443`, 0.9355461153215412],
              UndirectedEdge[406, 493] -> 
             RGBColor[
              0.33870341661598447`, 0.4633663515821581, 0.9429648172026237], 
             UndirectedEdge[155, 479] -> 
             RGBColor[
              0.18812050432693928`, 0.3150569559494543, 0.9340245564708484], 
             UndirectedEdge[311, 488] -> 
             RGBColor[
              0.18625665477025105`, 0.3130979318904876, 0.9339184129959133], 
             UndirectedEdge[226, 345] -> 
             RGBColor[
              0.18891037080707027`, 0.3158871557004993, 0.9340695381983891], 
             UndirectedEdge[183, 273] -> 
             RGBColor[
              0.19206178134703447`, 0.31919948798897047`, 0.934249006366546], 
             UndirectedEdge[384, 499] -> 
             RGBColor[
              0.4483239267217146, 0.554218492373762, 0.9512402754132152], 
             UndirectedEdge[20, 325] -> 
             RGBColor[
              0.23769654620583044`, 0.3671645192667726, 0.9368478387146697], 
             UndirectedEdge[252, 424] -> 
             RGBColor[
              0.1878893571902253, 0.31481400565319295`, 0.934011392983364], 
             UndirectedEdge[285, 473] -> 
             RGBColor[
              0.2389908172005852, 0.3685248801437806, 0.9369215455331186], 
             UndirectedEdge[71, 236] -> 
             RGBColor[
              0.20304903767595361`, 0.3307477910229513, 0.9348747143602888], 
             UndirectedEdge[2, 446] -> 
             RGBColor[
              0.18380079735160318`, 0.310516670033135, 0.9337785555490368], 
             UndirectedEdge[33, 351] -> 
             RGBColor[
              0.24823088148452888`, 0.3782367735601183, 0.937447753524639], 
             UndirectedEdge[172, 466] -> 
             RGBColor[
              0.20918917113405136`, 0.3372014605943586, 0.935224385877214], 
             UndirectedEdge[12, 279] -> 
             RGBColor[
              0.2010090657422573, 0.3286036511789455, 0.9347585409765328], 
             UndirectedEdge[171, 219] -> 
             RGBColor[
              0.5701105988481052, 0.6614643237945504, 0.9595848784963202], 
             UndirectedEdge[153, 223] -> 
             RGBColor[
              0.21791092009915627`, 0.34636857174750746`, 0.9357210765781054],
              UndirectedEdge[121, 489] -> 
             RGBColor[
              0.1983767553672155, 0.32583692607665915`, 0.9346086347948284], 
             UndirectedEdge[362, 470] -> 
             RGBColor[
              0.1869253840691414, 0.31380080878350786`, 0.9339564961401887], 
             UndirectedEdge[168, 232] -> 
             RGBColor[
              0.28558604817661837`, 0.417499422207868, 0.9395750750057368], 
             UndirectedEdge[285, 409] -> 
             RGBColor[
              0.23381068107618688`, 0.3630802286374379, 0.9366265444441588], 
             UndirectedEdge[159, 439] -> 
             RGBColor[
              0.21567326392113564`, 0.34401665322881175`, 0.9355936453690827],
              UndirectedEdge[156, 263] -> 
             RGBColor[
              0.21186651840498638`, 0.34001552232973276`, 0.9353768568435135],
              UndirectedEdge[149, 314] -> 
             RGBColor[
              0.41196878637874557`, 0.5240737659037882, 0.9484356108143341], 
             UndirectedEdge[110, 457] -> 
             RGBColor[
              0.44316356556908426`, 0.5578351155851111, 0.9495785036311474], 
             UndirectedEdge[43, 263] -> 
             RGBColor[
              0.2263534256582619, 0.35524218037589655`, 0.9362018647801287], 
             UndirectedEdge[141, 160] -> 
             RGBColor[
              0.2233789267066098, 0.352115793383584, 0.936032471465209], 
             UndirectedEdge[345, 389] -> 
             RGBColor[
              0.1928812337006961, 0.3200607843689489, 0.9342956729658158], 
             UndirectedEdge[225, 247] -> 
             RGBColor[
              0.18412221385498584`, 0.31085449915717356`, 0.9337968597434113],
              UndirectedEdge[171, 293] -> 
             RGBColor[
              0.6402218599260903, 0.7162357738139922, 0.9665729137735878], 
             UndirectedEdge[179, 415] -> 
             RGBColor[
              0.19025558687597238`, 0.31730106308054046`, 0.9341461462634442],
              UndirectedEdge[143, 414] -> 
             RGBColor[
              0.5016592032391687, 0.6054763090493759, 0.9541415518219014], 
             UndirectedEdge[77, 388] -> 
             RGBColor[
              0.33157794270842256`, 0.4616178812072281, 0.9423488311998864], 
             UndirectedEdge[305, 406] -> 
             RGBColor[
              0.3635284030084348, 0.4892917640422711, 0.9443846862775205], 
             UndirectedEdge[55, 256] -> 
             RGBColor[
              0.4425753647760989, 0.554492515651166, 0.9503238262490175], 
             UndirectedEdge[367, 450] -> 
             RGBColor[
              0.20633807556762712`, 0.3342047783841471, 0.9350620202025242], 
             UndirectedEdge[171, 258] -> 
             RGBColor[
              0.44293779831735625`, 0.5576003693038944, 0.9495749484754112], 
             UndirectedEdge[366, 423] -> 
             RGBColor[
              0.18087837131958237`, 0.30744501498096866`, 0.933612127709855], 
             UndirectedEdge[309, 393] -> 
             RGBColor[
              0.20475589581124165`, 0.33254180714419534`, 0.9349719174060231],
              UndirectedEdge[324, 360] -> 
             RGBColor[
              0.7679481729777577, 0.8188024264455834, 0.9741261052850922], 
             UndirectedEdge[125, 310] -> 
             RGBColor[
              0.7113812015825887, 0.7744556684644794, 0.9718674880046061], 
             UndirectedEdge[33, 463] -> 
             RGBColor[
              0.4057152506945697, 0.5182150283519088, 0.9480144771137997], 
             UndirectedEdge[137, 280] -> 
             RGBColor[
              0.2325647771126936, 0.3617707045769326, 0.9365555920565876], 
             UndirectedEdge[72, 179] -> 
             RGBColor[
              0.20561407521805922`, 0.3334438081124777, 0.9350207894536787], 
             UndirectedEdge[17, 165] -> 
             RGBColor[
              0.3406850289827465, 0.4692453072636289, 0.9429386712487001], 
             UndirectedEdge[402, 417] -> 
             RGBColor[
              0.20763019049226705`, 0.33556287309476157`, 0.9351356042359695],
              UndirectedEdge[102, 225] -> 
             RGBColor[
              0.19170377678695943`, 0.3188232024975315, 0.9342286185364699], 
             UndirectedEdge[83, 231] -> 
             RGBColor[
              0.879442405436877, 0.9037944293481288, 0.8529223377718652], 
             UndirectedEdge[194, 377] -> 
             RGBColor[
              0.1834493331063201, 0.31014725882722227`, 0.9337585401802126], 
             UndirectedEdge[131, 495] -> 
             RGBColor[
              0.8599106722287021, 0.41795803680078086`, 0.20329863351297417`],
              UndirectedEdge[213, 447] -> 
             RGBColor[
              0.2179735437754206, 0.34643439320183167`, 0.9357246429038253], 
             UndirectedEdge[146, 166] -> 
             RGBColor[
              0.18787743892822623`, 0.31480147880417053`, 0.9340107142559747],
              UndirectedEdge[422, 428] -> 
             RGBColor[
              0.19715708759112932`, 0.32455497791258914`, 0.9345391765193171],
              UndirectedEdge[232, 338] -> 
             RGBColor[
              0.351395977443279, 0.47598308304576464`, 0.9437141472934822], 
             UndirectedEdge[366, 469] -> 
             RGBColor[
              0.1819546848445577, 0.30857628873793674`, 0.9336734221728392], 
             UndirectedEdge[245, 482] -> 
             RGBColor[
              0.2881486049407218, 0.4180084472344471, 0.93980098984346], 
             UndirectedEdge[40, 243] -> 
             RGBColor[
              0.19079403389915217`, 0.3178670050414155, 0.9341768100248533], 
             UndirectedEdge[174, 320] -> 
             RGBColor[
              0.1843078028000945, 0.31104956490550145`, 0.933807428759281], 
             UndirectedEdge[30, 31] -> 
             RGBColor[
              0.185457486240386, 0.3122579550953881, 0.9338729015304014], 
             UndirectedEdge[77, 354] -> 
             RGBColor[
              0.32252783628299564`, 0.4537791338930982, 0.9417721664211531], 
             UndirectedEdge[24, 223] -> 
             RGBColor[
              0.19673773915135, 0.32411421611415436`, 0.934515295246042], 
             UndirectedEdge[261, 391] -> 
             RGBColor[
              0.40120374518351687`, 0.5213867241354746, 0.9469338462657712], 
             UndirectedEdge[125, 323] -> 
             RGBColor[
              0.8853299376421364, 0.9088564954320449, 0.8744890811044619], 
             UndirectedEdge[1, 364] -> 
             RGBColor[
              0.2018347227926697, 0.32947146908860947`, 0.9348055609241036], 
             UndirectedEdge[88, 133] -> 
             RGBColor[
              0.19376977710770305`, 0.3209946998266191, 0.9343462741983627], 
             UndirectedEdge[178, 407] -> 
             RGBColor[
              0.3732194860466791, 0.4943283360147483, 0.9452291962385135], 
             UndirectedEdge[103, 486] -> 
             RGBColor[
              0.41156934709801946`, 0.5309024152046116, 0.94744581275397], 
             UndirectedEdge[204, 486] -> 
             RGBColor[
              0.3646188827036643, 0.4902362827451757, 0.9444541706794272], 
             UndirectedEdge[89, 407] -> 
             RGBColor[
              0.2934055397651449, 0.4256317109239335, 0.9400235504062648], 
             UndirectedEdge[38, 301] -> 
             RGBColor[
              0.5876340036038425, 0.6758909546392042, 0.9608274105699129], 
             UndirectedEdge[92, 132] -> 
             RGBColor[
              0.27212682678288186`, 0.40335292715912663`, 0.9388085922584972],
              UndirectedEdge[8, 146] -> 
             RGBColor[
              0.18877984751216192`, 0.31574996744189576`, 0.934062105089836], 
             UndirectedEdge[44, 110] -> 
             RGBColor[
              0.34804321230268565`, 0.4731300192483041, 0.9434986471622288], 
             UndirectedEdge[102, 252] -> 
             RGBColor[
              0.19087465031632422`, 0.3179517380072394, 0.93418140101055], 
             UndirectedEdge[273, 283] -> 
             RGBColor[
              0.18473808843290457`, 0.31150182238726964`, 0.933831932889519], 
             UndirectedEdge[158, 428] -> 
             RGBColor[
              0.1897406655144195, 0.31675984808164837`, 0.9341168222536617], 
             UndirectedEdge[176, 328] -> 
             RGBColor[
              0.27995998628272956`, 0.4108290857819987, 0.939282396167026], 
             UndirectedEdge[45, 398] -> 
             RGBColor[
              0.20371823459922628`, 0.33145115941884645`, 0.934912824135081], 
             UndirectedEdge[233, 275] -> 
             RGBColor[
              0.7259348855245369, 0.7839404012756612, 0.9506021698205669], 
             UndirectedEdge[250, 485] -> 
             RGBColor[
              0.23749323092755345`, 0.3669508220183703, 0.9368362602103498], 
             UndirectedEdge[29, 65] -> 
             RGBColor[
              0.1838043123267574, 0.3105203644948844, 0.9337787557216719], 
             UndirectedEdge[166, 453] -> 
             RGBColor[
              0.2178060906512075, 0.3462583893511425, 0.935715106696126], 
             UndirectedEdge[222, 294] -> 
             RGBColor[
              0.19229714625130181`, 0.3194468714263523, 0.9342624100496528], 
             UndirectedEdge[150, 220] -> 
             RGBColor[
              0.21619691693173887`, 0.3445670457444743, 0.9356234666333614], 
             UndirectedEdge[311, 423] -> 
             RGBColor[
              0.184592254538111, 0.31134854171743864`, 0.9338236278649524], 
             UndirectedEdge[210, 424] -> 
             RGBColor[
              0.19449774707264864`, 0.3217598424157385, 0.9343877310109313], 
             UndirectedEdge[179, 312] -> 
             RGBColor[
              0.19754047021008475`, 0.3249579373529733, 0.9345610095923028], 
             UndirectedEdge[310, 323] -> 
             RGBColor[
              0.8187613818125008, 0.8568526336781708, 0.8678541495778869], 
             UndirectedEdge[108, 349] -> 
             RGBColor[
              0.19740440059431363`, 0.32481491955948594`, 0.9345532606289816],
              UndirectedEdge[355, 395] -> 
             RGBColor[
              0.5319254348002241, 0.6308800567954042, 0.9562942652159951], 
             UndirectedEdge[47, 200] -> 
             RGBColor[
              0.2722924613184966, 0.40352701955789383`, 0.9388180249002662], 
             UndirectedEdge[152, 217] -> 
             RGBColor[
              0.18273892560736155`, 0.30940057550337985`, 0.9337180835241007],
              UndirectedEdge[174, 210] -> 
             RGBColor[
              0.19150041146467078`, 0.3186094526497, 0.9342170371822176], 
             UndirectedEdge[135, 211] -> 
             RGBColor[
              0.18373947818140363`, 0.31045221969739534`, 0.9337750635130075],
              UndirectedEdge[52, 491] -> 
             RGBColor[
              0.18081085908512495`, 0.30737405534203105`, 0.9336082829879782],
              UndirectedEdge[41, 250] -> 
             RGBColor[
              0.2413646105317827, 0.37101988744205927`, 0.9370567295516178], 
             UndirectedEdge[220, 392] -> 
             RGBColor[
              0.22694196327999852`, 0.35586077073178224`, 0.9362353811270232],
              UndirectedEdge[182, 359] -> 
             RGBColor[
              0.6272616214525479, 0.7019681789194203, 0.9672182481235007], 
             UndirectedEdge[89, 391] -> 
             RGBColor[
              0.39139811242183375`, 0.5128935778827375, 0.9463090400169774], 
             UndirectedEdge[62, 190] -> 
             RGBColor[
              0.233868572190446, 0.3631410758690329, 0.9366298412574736], 
             UndirectedEdge[21, 87] -> 
             RGBColor[
              0.30420754500978997`, 0.43707179605062296`, 0.94063554170235], 
             UndirectedEdge[185, 286] -> 
             RGBColor[
              0.1994684028845588, 0.32698431683183726`, 0.9346708025059933], 
             UndirectedEdge[114, 294] -> 
             RGBColor[
              0.18446317038438925`, 0.311212866087469, 0.9338162767133609], 
             UndirectedEdge[48, 156] -> 
             RGBColor[
              0.19463895940372045`, 0.3219082655290739, 0.9343957728442809], 
             UndirectedEdge[68, 450] -> 
             RGBColor[
              0.20047702738706202`, 0.3280444451344552, 0.9347282421792846], 
             UndirectedEdge[149, 406] -> 
             RGBColor[
              0.48881588257467606`, 0.5948821437018659, 0.9531767259019711], 
             UndirectedEdge[123, 158] -> 
             RGBColor[
              0.1887768797193095, 0.31574684810343895`, 0.9340619360784235], 
             UndirectedEdge[55, 91] -> 
             RGBColor[
              0.5169586982013866, 0.6187293857806677, 0.955116028885972], 
             UndirectedEdge[135, 169] -> 
             RGBColor[
              0.1819041358977289, 0.3085231585898313, 0.9336705434850978], 
             UndirectedEdge[141, 456] -> 
             RGBColor[
              0.20146025215418084`, 0.3290778767047479, 0.9347842353752214], 
             UndirectedEdge[287, 354] -> 
             RGBColor[
              0.3073707866753843, 0.44022628267657893`, 0.9408219184544402], 
             UndirectedEdge[223, 411] -> 
             RGBColor[
              0.24469698646716248`, 0.3745224258349809, 0.9372465034313293], 
             UndirectedEdge[127, 301] -> 
             RGBColor[
              0.7442995113076243, 0.8002700424356418, 0.9751223810067287], 
             UndirectedEdge[167, 201] -> 
             RGBColor[
              0.2486574185518422, 0.37868509106187664`, 0.9374720441796176], 
             UndirectedEdge[28, 218] -> 
             RGBColor[
              0.38085905105137724`, 0.5015767053192113, 0.9457353767574448], 
             UndirectedEdge[112, 317] -> 
             RGBColor[
              0.9053802389728423, 0.5628414484156407, 0.4612866067791993], 
             UndirectedEdge[275, 372] -> 
             RGBColor[
              0.55179178264052, 0.6470084529409276, 0.9578582168908132], 
             UndirectedEdge[85, 146] -> 
             RGBColor[
              0.1836713842833611, 0.3103806486931501, 0.9337711856662498], 
             UndirectedEdge[7, 262] -> 
             RGBColor[
              0.407760697816997, 0.5270866817975668, 0.9473459424920676], 
             UndirectedEdge[448, 455] -> 
             RGBColor[
              0.45681433053997933`, 0.564999766000337, 0.9515547264505798], 
             UndirectedEdge[9, 368] -> 
             RGBColor[
              0.18651190777224702`, 0.3133662189795604, 0.933932949276764], 
             UndirectedEdge[216, 399] -> 
             RGBColor[
              0.20389703761891642`, 0.33163909272930703`, 0.934923006702537], 
             UndirectedEdge[205, 474] -> 
             RGBColor[
              0.23349741976768085`, 0.3627509711402839, 0.936608704676068], 
             UndirectedEdge[125, 242] -> 
             RGBColor[
              0.8755313279725643, 0.9029638772422787, 0.9544497242112633], 
             UndirectedEdge[280, 338] -> 
             RGBColor[
              0.33890305736331594`, 0.4628522319448411, 0.9430026939765475], 
             UndirectedEdge[232, 393] -> 
             RGBColor[
              0.24988773384149937`, 0.3799782304378011, 0.9375421088152751], 
             UndirectedEdge[403, 483] -> 
             RGBColor[
              0.5977248399072642, 0.6827163434594106, 0.9625421629597528], 
             UndirectedEdge[427, 433] -> 
             RGBColor[
              0.18359379097292866`, 0.3102990932041856, 0.9337667668420098], 
             UndirectedEdge[269, 310] -> 
             RGBColor[
              0.6233432481970155, 0.705059569312919, 0.963516708609254], 
             UndirectedEdge[212, 357] -> 
             RGBColor[
              0.18524504165765288`, 0.3120346623691711, 0.9338608031256983], 
             UndirectedEdge[88, 307] -> 
             RGBColor[
              0.1906659921562372, 0.31773242505129645`, 0.9341695182370151], 
             UndirectedEdge[212, 217] -> 
             RGBColor[
              0.18159408433829743`, 0.30819727474246456`, 0.9336528865074684],
              UndirectedEdge[67, 124] -> 
             RGBColor[
              0.18312075215718818`, 0.30980189941644914`, 0.9337398279812515],
              UndirectedEdge[364, 380] -> 
             RGBColor[
              0.19593044529067147`, 0.3232656990811941, 0.9344693210549606], 
             UndirectedEdge[82, 384] -> 
             RGBColor[
              0.39409857332891574`, 0.5101959076651558, 0.9469714569601196], 
             UndirectedEdge[222, 439] -> 
             RGBColor[
              0.19816628717948753`, 0.32561571066690326`, 0.9345966489428971],
              UndirectedEdge[337, 420] -> 
             RGBColor[
              0.18856527989536503`, 0.3155244432722696, 0.9340498857814837], 
             UndirectedEdge[61, 99] -> 
             RGBColor[
              0.9849784772768306, 0.9873095986531333, 0.8651734232542627], 
             UndirectedEdge[63, 439] -> 
             RGBColor[
              0.20302072388459882`, 0.33071803143303935`, 0.9348731019317575],
              UndirectedEdge[37, 53] -> 
             RGBColor[
              0.8472647112443593, 0.3588769520067575, 0.19268158199931773`], 
             UndirectedEdge[39, 62] -> 
             RGBColor[
              0.2493920758689453, 0.37945726248211625`, 0.9375138818269986], 
             UndirectedEdge[130, 182] -> 
             RGBColor[
              0.323958117743938, 0.4544792345302443, 0.9418830285018508], 
             UndirectedEdge[152, 398] -> 
             RGBColor[
              0.19524728601816377`, 0.32254765537098895`, 0.934430416145035], 
             UndirectedEdge[23, 110] -> 
             RGBColor[
              0.42451306437954106`, 0.5421136125437187, 0.9482705749734688], 
             UndirectedEdge[322, 440] -> 
             RGBColor[
              0.8562073757382771, 0.38077868388003167`, 0.19941112665599764`],
              UndirectedEdge[141, 432] -> 
             RGBColor[
              0.24927102921021138`, 0.3793300347689854, 0.937506988398856], 
             UndirectedEdge[161, 459] -> 
             RGBColor[
              0.20416528068413636`, 0.3319210331984458, 0.9349382827482713], 
             UndirectedEdge[185, 333] -> 
             RGBColor[
              0.22166458508016862`, 0.3503139116386572, 0.9359348422457243], 
             UndirectedEdge[297, 474] -> 
             RGBColor[
              0.21238801987541464`, 0.34056365344025585`, 0.935406555580762], 
             UndirectedEdge[265, 329] -> 
             RGBColor[
              0.18295078871918613`, 0.3096232570668046, 0.9337301488148957], 
             UndirectedEdge[90, 280] -> 
             RGBColor[
              0.25791236607974777`, 0.3884126277112705, 0.937999099749864], 
             UndirectedEdge[183, 430] -> 
             RGBColor[
              0.19926050368686765`, 0.32676580159349333`, 0.9346589629542441],
              UndirectedEdge[86, 194] -> 
             RGBColor[
              0.18570943860608155`, 0.31252277300643677`, 0.9338872498448976],
              UndirectedEdge[143, 186] -> 
             RGBColor[
              0.7869875185761387, 0.829282852672385, 0.7373913878754195], 
             UndirectedEdge[1, 416] -> 
             RGBColor[
              0.20425325698717794`, 0.33201350187096224`, 0.9349432928685801],
              UndirectedEdge[27, 86] -> 
             RGBColor[
              0.18526169591288671`, 0.3120521670473626, 0.9338617515608961], 
             UndirectedEdge[66, 415] -> 
             RGBColor[
              0.1891407128871262, 0.3161292598311696, 0.9340826558390877], 
             UndirectedEdge[413, 490] -> 
             RGBColor[
              0.2231389506309891, 0.3518635633127446, 0.9360188051827152], 
             UndirectedEdge[226, 284] -> 
             RGBColor[
              0.19690493413279425`, 0.3242899486404264, 0.9345248167528926], 
             UndirectedEdge[245, 438] -> 
             RGBColor[
              0.22328352119424416`, 0.3520155161410289, 0.9360270382624196], 
             UndirectedEdge[53, 163] -> 
             RGBColor[
              0.8659915986516313, 0.4439113739475036, 0.20830775588996076`], 
             UndirectedEdge[367, 368] -> 
             RGBColor[
              0.1881907444562831, 0.3151307827788761, 0.9340285565423035], 
             UndirectedEdge[112, 175] -> 
             RGBColor[
              0.6955594457176699, 0.7552129086866064, 0.8524579222934991], 
             UndirectedEdge[277, 288] -> 
             RGBColor[
              0.5772249873338873, 0.6663273536018384, 0.9606573715704986], 
             UndirectedEdge[249, 323] -> 
             RGBColor[
              0.8598299314382067, 0.8889356967783099, 0.8719474787971606], 
             UndirectedEdge[416, 452] -> 
             RGBColor[
              0.2180186471312624, 0.3464817996885393, 0.935727211473216], 
             UndirectedEdge[13, 87] -> 
             RGBColor[
              0.28067879095443904`, 0.41234158372927926`, 0.9392956139665702],
              UndirectedEdge[471, 497] -> 
             RGBColor[
              0.7175094368939575, 0.7772891603319885, 0.9550059228659136], 
             UndirectedEdge[17, 321] -> 
             RGBColor[
              0.6804393139131792, 0.743928538014085, 0.9180923196352385], 
             UndirectedEdge[106, 227] -> 
             RGBColor[
              0.18640315120824044`, 0.31325190893522514`, 0.9339267557513348],
              UndirectedEdge[37, 100] -> 
             RGBColor[
              0.9275408237580072, 0.7267589387889348, 0.3553036056592853], 
             UndirectedEdge[9, 375] -> 
             RGBColor[
              0.19826733232951002`, 0.32572191552620944`, 0.934602403314708], 
             UndirectedEdge[10, 302] -> 
             RGBColor[
              0.23577384795439005`, 0.3651436414983986, 0.9367383438936274], 
             UndirectedEdge[14, 272] -> 
             RGBColor[
              0.24410352476956199`, 0.37389865996315785`, 0.9372127066655989],
              UndirectedEdge[63, 387] -> 
             RGBColor[
              0.1978509608116646, 0.3252842826614749, 0.9345786915727331], 
             UndirectedEdge[471, 483] -> 
             RGBColor[
              0.7044387287985243, 0.7666430914560537, 0.9539865308155939], 
             UndirectedEdge[46, 392] -> 
             RGBColor[
              0.22028047155655125`, 0.34885912056746937`, 0.9358560190281668],
              UndirectedEdge[122, 357] -> 
             RGBColor[
              0.18711144917701383`, 0.313996375009091, 0.9339670922728234], 
             UndirectedEdge[75, 125] -> 
             RGBColor[
              0.8216340480291034, 0.6538916931792487, 0.593916539379413], 
             UndirectedEdge[244, 261] -> 
             RGBColor[
              0.388007213318593, 0.5104940791921502, 0.9459444544247217], 
             UndirectedEdge[7, 178] -> 
             RGBColor[
              0.47083170751539166`, 0.5812814167445273, 0.9514847432104361], 
             UndirectedEdge[108, 487] -> 
             RGBColor[
              0.20117686323780593`, 0.3287800169857428, 0.9347680967956702], 
             UndirectedEdge[338, 480] -> 
             RGBColor[
              0.3338467491074454, 0.4575377313794614, 0.9427147447015134], 
             UndirectedEdge[237, 284] -> 
             RGBColor[
              0.21986017242091369`, 0.34841735952740993`, 0.9358320836141691],
              UndirectedEdge[162, 456] -> 
             RGBColor[
              0.18946877260235598`, 0.3164740713920633, 0.9341013383545491], 
             UndirectedEdge[104, 310] -> 
             RGBColor[
              0.7844721843600413, 0.7296832002097726, 0.6115226819006405], 
             UndirectedEdge[168, 390] -> 
             RGBColor[
              0.27431313717116323`, 0.40565087799729527`, 0.9389330994007534],
              UndirectedEdge[164, 431] -> 
             RGBColor[
              0.36863866395623385`, 0.49371801522607117`, 0.9447103075862879],
              UndirectedEdge[57, 60] -> 
             RGBColor[
              0.9740668501566808, 0.9799635557919238, 0.9191037618424754], 
             UndirectedEdge[158, 247] -> 
             RGBColor[
              0.18799329436094186`, 0.3149232502096133, 0.9340173120514751], 
             UndirectedEdge[32, 475] -> 
             RGBColor[
              0.27810050553156784`, 0.4070629513265539, 0.9392428367847124], 
             UndirectedEdge[53, 293] -> 
             RGBColor[
              0.8212117750972121, 0.5517293002984074, 0.5802972295340347], 
             UndirectedEdge[72, 294] -> 
             RGBColor[
              0.19930405825751749`, 0.32681158020876566`, 0.9346614433226095],
              UndirectedEdge[87, 287] -> 
             RGBColor[
              0.3062830568763104, 0.4392532906173888, 0.9407537390327037], 
             UndirectedEdge[154, 374] -> 
             RGBColor[
              0.9154556938707563, 0.6764368032115899, 0.5529680520443171], 
             UndirectedEdge[119, 364] -> 
             RGBColor[
              0.19435544195191212`, 0.32161027071117865`, 0.934379626944827], 
             UndirectedEdge[90, 342] -> 
             RGBColor[
              0.36933196448262395`, 0.489404611907154, 0.9450840596145658], 
             UndirectedEdge[401, 428] -> 
             RGBColor[
              0.18425068425914937`, 0.3109895296974434, 0.9338041759428735], 
             UndirectedEdge[183, 477] -> 
             RGBColor[
              0.19737928626943302`, 0.32478852281169623`, 0.934551830405333], 
             UndirectedEdge[82, 269] -> 
             RGBColor[
              0.5609980001725171, 0.6544824750687763, 0.958582964058418], 
             UndirectedEdge[202, 273] -> 
             RGBColor[
              0.18695948203332297`, 0.31383664790579846`, 0.9339584379688055],
              UndirectedEdge[147, 242] -> 
             RGBColor[
              0.8960966123696098, 0.5635667746530044, 0.5481508384278233], 
             UndirectedEdge[117, 198] -> 
             RGBColor[
              0.18298777738438862`, 0.30966213449914926`, 0.9337322552646592],
              UndirectedEdge[240, 434] -> 
             RGBColor[
              0.9649429424873008, 0.8858096572696792, 0.4713319778660402], 
             UndirectedEdge[249, 310] -> 
             RGBColor[
              0.685881195378659, 0.7545348698107444, 0.9693258856973048], 
             UndirectedEdge[448, 478] -> 
             RGBColor[
              0.2749488841783959, 0.4063190884105853, 0.938969304252312], 
             UndirectedEdge[121, 196] -> 
             RGBColor[
              0.19856429776732792`, 0.3260340450300523, 0.9346193150570707], 
             UndirectedEdge[200, 256] -> 
             RGBColor[
              0.28726648438606334`, 0.4190057220590618, 0.9396802912272235], 
             UndirectedEdge[79, 184] -> 
             RGBColor[
              0.7135412330833855, 0.7751234699043363, 0.9730039594525782], 
             UndirectedEdge[51, 240] -> 
             RGBColor[
              0.995029239647029, 0.991776371162987, 0.7003415954352006], 
             UndirectedEdge[339, 387] -> 
             RGBColor[
              0.1845385025539545, 0.3112920449740175, 0.9338205667689736], 
             UndirectedEdge[46, 142] -> 
             RGBColor[
              0.2097115161750654, 0.33775047835105276`, 0.9352541326545596], 
             UndirectedEdge[233, 259] -> 
             RGBColor[
              0.8229153142047934, 0.8620467284314131, 0.9586653393897153], 
             UndirectedEdge[266, 471] -> 
             RGBColor[
              0.975210019564589, 0.978006622458981, 0.7504581704123827], 
             UndirectedEdge[167, 456] -> 
             RGBColor[
              0.21773731167177224`, 0.3461860982829168, 0.9357111898349966], 
             UndirectedEdge[10, 181] -> 
             RGBColor[
              0.22615215264020183`, 0.355030629672469, 0.9361904025795069], 
             UndirectedEdge[31, 429] -> 
             RGBColor[
              0.19196505677432735`, 0.31909782433036316`, 0.9342434980452214],
              UndirectedEdge[317, 322] -> 
             RGBColor[
              0.8190506229224375, 0.1474370125838577, 0.16587620406611453`], 
             UndirectedEdge[52, 466] -> 
             RGBColor[
              0.18744056730247904`, 0.3143422990262493, 0.933985835063182], 
             UndirectedEdge[207, 281] -> 
             RGBColor[
              0.8467054680453859, 0.3339234893640672, 0.19133725700073073`], 
             UndirectedEdge[358, 398] -> 
             RGBColor[
              0.21557110150214517`, 0.3439092740489813, 0.935587827370457], 
             UndirectedEdge[155, 250] -> 
             RGBColor[
              0.2067822292135854, 0.3346716120270169, 0.9350873140955949], 
             UndirectedEdge[243, 285] -> 
             RGBColor[
              0.20548353415746184`, 0.3333066011810086, 0.9350133553333959], 
             UndirectedEdge[378, 452] -> 
             RGBColor[
              0.21688623716897232`, 0.34529156501923397`, 0.935662722401114], 
             UndirectedEdge[100, 264] -> 
             RGBColor[
              0.92938539319056, 0.7351346977720205, 0.3568427596083415], 
             UndirectedEdge[81, 130] -> 
             RGBColor[
              0.27063800741742255`, 0.4017880836094291, 0.9387238061981451], 
             UndirectedEdge[1, 120] -> 
             RGBColor[
              0.18959062955787265`, 0.3166021507784885, 0.9341082779278946], 
             UndirectedEdge[390, 422] -> 
             RGBColor[
              0.23122695863113757`, 0.36036457253022636`, 0.9364794052731881],
              UndirectedEdge[118, 255] -> 
             RGBColor[
              0.19469073239539242`, 0.3219626822259184, 0.9343987212395655], 
             UndirectedEdge[137, 229] -> 
             RGBColor[
              0.2232482662355424, 0.35197846094413987`, 0.9360250305446766], 
             UndirectedEdge[367, 375] -> 
             RGBColor[
              0.19994616901354612`, 0.3274864793255251, 0.9346980105802476], 
             UndirectedEdge[230, 382] -> 
             RGBColor[
              0.20898405610198123`, 0.3369858716906088, 0.9352127048795782], 
             UndirectedEdge[114, 334] -> 
             RGBColor[
              0.18414474445457316`, 0.31087818024586233`, 0.9337981428277268],
              UndirectedEdge[52, 170] -> 
             RGBColor[
              0.1838649636445791, 0.31058411287543064`, 0.9337822097244962], 
             UndirectedEdge[4, 389] -> 
             RGBColor[
              0.18821672881431478`, 0.31515809398667083`, 0.934030036313053], 
             UndirectedEdge[190, 378] -> 
             RGBColor[
              0.21175405970731373`, 0.3398973211081856, 0.9353704524870488], 
             UndirectedEdge[89, 328] -> 
             RGBColor[
              0.27633399177258894`, 0.4076884315850981, 0.9390513510031808], 
             UndirectedEdge[93, 300] -> 
             RGBColor[
              0.2272468293636924, 0.3561812043153706, 0.9362527427994807], 
             UndirectedEdge[104, 125] -> 
             RGBColor[
              0.8510407401896769, 0.7816870619636468, 0.6181576134272155], 
             UndirectedEdge[59, 228] -> 
             RGBColor[
              0.26060629998899837`, 0.391244123055168, 0.9381525153006776], 
             UndirectedEdge[96, 136] -> 
             RGBColor[
              0.4994982670529912, 0.6045542211909409, 0.9537414797863035], 
             UndirectedEdge[332, 420] -> 
             RGBColor[
              0.1873361545684642, 0.31423255462265, 0.9339798889124447], 
             UndirectedEdge[40, 283] -> 
             RGBColor[
              0.18366308451827268`, 0.3103719251138067, 0.9337707130069065], 
             UndirectedEdge[17, 288] -> 
             RGBColor[
              0.543333437646262, 0.6369721967012344, 0.9584978319935238], 
             UndirectedEdge[325, 413] -> 
             RGBColor[
              0.23197275674874823`, 0.36114845363816694`, 0.9365218773726766],
              UndirectedEdge[421, 459] -> 
             RGBColor[
              0.18940834947071425`, 0.31641056284966007`, 0.9340978973465902],
              UndirectedEdge[148, 342] -> 
             RGBColor[
              0.3754741855106375, 0.4958604756469023, 0.9454338500155093], 
             UndirectedEdge[262, 478] -> 
             RGBColor[
              0.29624054132013333`, 0.4255154795391891, 0.9402983591952379], 
             UndirectedEdge[133, 405] -> 
             RGBColor[
              0.18981989868512106`, 0.3168431271677289, 0.9341213344655181], 
             UndirectedEdge[374, 397] -> 
             RGBColor[
              0.8347270315445021, 0.26793275869910615`, 0.18088795066657473`],
              UndirectedEdge[151, 389] -> 
             RGBColor[
              0.1993172981785255, 0.3268254962052045, 0.9346621973165241], 
             UndirectedEdge[235, 305] -> 
             RGBColor[
              0.2638362786788805, 0.394471813217312, 0.9383425806338642], 
             UndirectedEdge[204, 348] -> 
             RGBColor[
              0.38899180466367445`, 0.5111089618702334, 0.9460729299565488], 
             UndirectedEdge[191, 429] -> 
             RGBColor[
              0.1912728666243942, 0.31837028859539307`, 0.9342040788401863], 
             UndirectedEdge[15, 414] -> 
             RGBColor[0.53753656294092, 0.634449250565901, 0.957071181763386],
              UndirectedEdge[277, 414] -> 
             RGBColor[
              0.43294658493558325`, 0.5494183041682945, 0.9488079514458304], 
             UndirectedEdge[317, 440] -> 
             RGBColor[
              0.8544757528158395, 0.36746867129617394`, 0.19775292258988314`],
              UndirectedEdge[76, 182] -> 
             RGBColor[
              0.3777126376207911, 0.5015774351431334, 0.9452884931643937], 
             UndirectedEdge[199, 376] -> 
             RGBColor[
              0.3786216036789717, 0.5023647358567669, 0.9453464116778538], 
             UndirectedEdge[375, 402] -> 
             RGBColor[
              0.21043597475918854`, 0.33851193025629345`, 0.9352953894991849],
              UndirectedEdge[45, 195] -> 
             RGBColor[
              0.19463609510811763`, 0.32190525497278855`, 0.9343956097268837],
              UndirectedEdge[149, 269] -> 
             RGBColor[
              0.5815017308774398, 0.6711283273375747, 0.9601970928471498], 
             UndirectedEdge[45, 152] -> 
             RGBColor[
              0.1927063751242849, 0.3198769969184667, 0.9342857150285693], 
             UndirectedEdge[356, 494] -> 
             RGBColor[
              0.30030937836549265`, 0.4286701061729542, 0.9405711545959381], 
             UndirectedEdge[44, 360] -> 
             RGBColor[
              0.4375870349530485, 0.5468097854709225, 0.9502759669846275], 
             UndirectedEdge[284, 432] -> 
             RGBColor[
              0.249031609154708, 0.37907838911054315`, 0.9374933537808854], 
             UndirectedEdge[151, 237] -> 
             RGBColor[
              0.2183016735730191, 0.3467792784237385, 0.9357433294103739], 
             UndirectedEdge[207, 343] -> 
             RGBColor[
              0.8606088112970214, 0.4407906780799979, 0.2046511142000771], 
             UndirectedEdge[33, 371] -> 
             RGBColor[
              0.2551767869971113, 0.385537360649688, 0.9378433125680343], 
             UndirectedEdge[280, 480] -> 
             RGBColor[
              0.24841746075918128`, 0.37843288020758725`, 0.9374583789383113],
              UndirectedEdge[420, 454] -> 
             RGBColor[
              0.19971846915340663`, 0.3272471523355135, 0.9346850434100643], 
             UndirectedEdge[267, 393] -> 
             RGBColor[
              0.22528640281656057`, 0.35412067171611283`, 0.9361410994078128],
              UndirectedEdge[337, 427] -> 
             RGBColor[
              0.18780005171862202`, 0.314720139940244, 0.9340063071688718], 
             UndirectedEdge[267, 480] -> 
             RGBColor[
              0.23630904981420553`, 0.3657061725868226, 0.9367688228477836], 
             UndirectedEdge[234, 336] -> 
             RGBColor[
              0.7758644491107505, 0.7262741691289183, 0.6116347463560659], 
             UndirectedEdge[122, 492] -> 
             RGBColor[
              0.1841436405662557, 0.3108770199892501, 0.9337980799629202], 
             UndirectedEdge[80, 272] -> 
             RGBColor[
              0.30232143214337615`, 0.4315140636582957, 0.9406590399115311], 
             UndirectedEdge[331, 444] -> 
             RGBColor[
              0.43364941819134256`, 0.5462951958354212, 0.9497218378452923], 
             UndirectedEdge[77, 184] -> 
             RGBColor[
              0.4376517235629901, 0.5511173532058586, 0.9497643390234523], 
             UndirectedEdge[266, 359] -> 
             RGBColor[
              0.9515547370167402, 0.9596896244773535, 0.7671002510689349], 
             UndirectedEdge[32, 478] -> 
             RGBColor[
              0.23449306505329615`, 0.3637974574630227, 0.9366654052021586], 
             UndirectedEdge[14, 447] -> 
             RGBColor[
              0.2323548964610662, 0.3615501067048703, 0.936543639663968], 
             UndirectedEdge[16, 358] -> 
             RGBColor[
              0.24749987708524912`, 0.37746844158811943`, 0.9374061239055242],
              UndirectedEdge[50, 323] -> 
             RGBColor[
              0.9365367216162789, 0.9493476478675402, 0.8794633883159441], 
             UndirectedEdge[92, 365] -> 
             RGBColor[
              0.23949140661491064`, 0.36905103135743866`, 0.9369500533597088],
              UndirectedEdge[296, 438] -> 
             RGBColor[
              0.1924355382075839, 0.3195923301469616, 0.9342702912668306], 
             UndirectedEdge[181, 422] -> 
             RGBColor[
              0.2160287950041301, 0.3443903389390116, 0.9356138923382982], 
             UndirectedEdge[35, 428] -> 
             RGBColor[
              0.18771159390474457`, 0.31462716516930944`, 0.9340012696272331],
              UndirectedEdge[19, 298] -> 
             RGBColor[
              0.2394531191654226, 0.3690107888204622, 0.9369478729461016], 
             UndirectedEdge[209, 348] -> 
             RGBColor[
              0.7282782743451366, 0.7830802438848616, 0.8460022789081878], 
             UndirectedEdge[27, 194] -> 
             RGBColor[
              0.1856592913664621, 0.31247006507807806`, 0.9338843940337875], 
             UndirectedEdge[253, 287] -> 
             RGBColor[
              0.340823165506129, 0.46920105185432204`, 0.9429534744527581], 
             UndirectedEdge[412, 476] -> 
             RGBColor[
              0.18684284442084606`, 0.31371405437983346`, 0.9339517956293248],
              UndirectedEdge[221, 336] -> 
             RGBColor[
              0.7938129054109903, 0.7955671950703103, 0.6357978963718616], 
             UndirectedEdge[146, 248] -> 
             RGBColor[
              0.18017302617267333`, 0.306703652510102, 0.9335719593472032], 
             UndirectedEdge[17, 455] -> 
             RGBColor[
              0.49424404189338955`, 0.5981741285649027, 0.9539120839375526], 
             UndirectedEdge[102, 393] -> 
             RGBColor[
              0.2103791435745319, 0.3384521970779141, 0.9352921530472929], 
             UndirectedEdge[80, 497] -> 
             RGBColor[
              0.4127991170058606, 0.5312924585653119, 0.9477107106935068], 
             UndirectedEdge[108, 416] -> 
             RGBColor[
              0.20942130064370462`, 0.3374454434268651, 0.9352376053093838], 
             UndirectedEdge[8, 453] -> 
             RGBColor[
              0.21870849923514318`, 0.34720687798886773`, 0.9357664975299873],
              UndirectedEdge[58, 402] -> 
             RGBColor[
              0.20564836608822273`, 0.3334798499911863, 0.9350227422680057], 
             UndirectedEdge[95, 357] -> 
             RGBColor[
              0.18661251030183867`, 0.3134719586167301, 0.9339386784419961], 
             UndirectedEdge[183, 283] -> 
             RGBColor[
              0.18964111329673894`, 0.31665521238889094`, 0.9341111529021391],
              UndirectedEdge[179, 294] -> 
             RGBColor[
              0.19380204212800067`, 0.3210286124086723, 0.9343481116435368], 
             UndirectedEdge[136, 240] -> 
             RGBColor[
              0.7615140918759296, 0.8095862292350475, 0.8160223615071904], 
             UndirectedEdge[153, 289] -> 
             RGBColor[
              0.21885506273912853`, 0.34736092552421916`, 0.935774844104718], 
             UndirectedEdge[73, 200] -> 
             RGBColor[
              0.4199369122581749, 0.5305626812641765, 0.9490610674516942], 
             UndirectedEdge[196, 447] -> 
             RGBColor[
              0.2128628663159131, 0.341062747156223, 0.9354335973830761], 
             UndirectedEdge[68, 492] -> 
             RGBColor[
              0.1840181186755369, 0.3107450885235571, 0.9337909316769367], 
             UndirectedEdge[25, 413] -> 
             RGBColor[
              0.25960242052995686`, 0.39018898209408137`, 0.9380953458505918],
              UndirectedEdge[220, 426] -> 
             RGBColor[
              0.20219514191155313`, 0.32985029243444797`, 0.9348260862597317],
              UndirectedEdge[21, 354] -> 
             RGBColor[
              0.30529527480886387`, 0.43804478810981307`, 0.9407037211240865],
              UndirectedEdge[125, 269] -> 
             RGBColor[
              0.6899118040266511, 0.7570634310667932, 0.970151640135829], 
             UndirectedEdge[241, 304] -> 
             RGBColor[
              0.20316948858682138`, 0.3308743925673022, 0.9348815738614715], 
             UndirectedEdge[93, 456] -> 
             RGBColor[
              0.20912093230204676`, 0.3371297372553299, 0.9352204997766816], 
             UndirectedEdge[295, 455] -> 
             RGBColor[
              0.7989202594631184, 0.8423584945526768, 0.9321574576076621], 
             UndirectedEdge[185, 386] -> 
             RGBColor[
              0.25857169569949595`, 0.38910562494553824`, 0.9380366475963178],
              UndirectedEdge[233, 400] -> 
             RGBColor[
              0.9762128798080161, 0.9808371360064839, 0.8829178984103572], 
             UndirectedEdge[83, 317] -> 
             RGBColor[
              0.9062729324823862, 0.5632106001230137, 0.44649236510931034`], 
             UndirectedEdge[88, 465] -> 
             RGBColor[
              0.18430414736705614`, 0.3110457228136103, 0.9338072205877772], 
             UndirectedEdge[418, 431] -> 
             RGBColor[
              0.4488786406898552, 0.5625882607859993, 0.9499970853520581], 
             UndirectedEdge[121, 307] -> 
             RGBColor[
              0.1984527242001829, 0.32591677413681014`, 0.93461296110748], 
             UndirectedEdge[64, 74] -> 
             RGBColor[
              0.1867563887094054, 0.3136231839455006, 0.933946872104458], 
             UndirectedEdge[185, 358] -> 
             RGBColor[
              0.21821199843557637`, 0.3466850241685541, 0.935738222543959], 
             UndirectedEdge[113, 315] -> 
             RGBColor[
              0.19006335492631857`, 0.31709901511324473`, 0.9341351989382931],
              UndirectedEdge[47, 91] -> 
             RGBColor[
              0.37096684027433213`, 0.4930353735304999, 0.9450030845101454], 
             UndirectedEdge[158, 401] -> 
             RGBColor[
              0.1862173046895177, 0.3130565724606977, 0.9339161720670288], 
             UndirectedEdge[90, 232] -> 
             RGBColor[
              0.2704052861597108, 0.40154347881219404`, 0.9387105530667987], 
             UndirectedEdge[58, 115] -> 
             RGBColor[
              0.19207706439220854`, 0.3192155514384495, 0.9342498767133594], 
             UndirectedEdge[132, 494] -> 
             RGBColor[
              0.3138085366833637, 0.4428585774611083, 0.9413399116919258], 
             UndirectedEdge[167, 300] -> 
             RGBColor[
              0.23586320873341787`, 0.3652375653429575, 0.9367434328577955], 
             UndirectedEdge[284, 389] -> 
             RGBColor[
              0.20087579702642006`, 0.328463577308876, 0.9347509515203193], 
             UndirectedEdge[103, 233] -> 
             RGBColor[
              0.6861807488432135, 0.7504846976904338, 0.9477990317770553], 
             UndirectedEdge[172, 300] -> 
             RGBColor[
              0.22767768818641226`, 0.35663406425607636`, 0.936277279572036], 
             UndirectedEdge[70, 76] -> 
             RGBColor[
              0.3900856381049142, 0.5122943062773944, 0.9460768898142273], 
             UndirectedEdge[57, 73] -> 
             RGBColor[
              0.769769601175684, 0.81952464354351, 0.9539791162715971], 
             UndirectedEdge[287, 473] -> 
             RGBColor[
              0.28387386210883436`, 0.4156998060917603, 0.9394775685421287], 
             UndirectedEdge[395, 443] -> 
             RGBColor[
              0.39598885232621217`, 0.5140941996505966, 0.9469051099430464], 
             UndirectedEdge[100, 397] -> 
             RGBColor[
              0.9076183259729562, 0.5790517976305654, 0.33643826418820166`], 
             UndirectedEdge[57, 234] -> 
             RGBColor[
              0.9445095586663342, 0.8587398441686642, 0.6038719941743098], 
             UndirectedEdge[343, 403] -> 
             RGBColor[
              0.7948197503279848, 0.5779151298917289, 0.5834817504053871], 
             UndirectedEdge[105, 425] -> 
             RGBColor[
              0.18905198757822078`, 0.3160360039060004, 0.9340776030640029], 
             UndirectedEdge[133, 423] -> 
             RGBColor[
              0.18859024302857952`, 0.3155506811080321, 0.9340513073949906], 
             UndirectedEdge[92, 494] -> 
             RGBColor[
              0.31362082310207806`, 0.44266127858544857`, 0.9413292216811688],
              UndirectedEdge[51, 100] -> 
             RGBColor[
              0.9942396894003585, 0.9900876030211339, 0.6144039236244064], 
             UndirectedEdge[6, 347] -> 
             RGBColor[
              0.20873556607912272`, 0.336724692921407, 0.9351985537403844], 
             UndirectedEdge[333, 461] -> 
             RGBColor[
              0.24252993321129454`, 0.3722447154639515, 0.9371230929542755], 
             UndirectedEdge[291, 394] -> 
             RGBColor[
              0.18326692398746902`, 0.30995553527790365`, 0.9337481522507443],
              UndirectedEdge[143, 386] -> 
             RGBColor[
              0.4431271313499566, 0.5544881277989356, 0.9504225818042138], 
             UndirectedEdge[123, 437] -> 
             RGBColor[
              0.18388303382001714`, 0.3106031057755313, 0.9337832387942551], 
             UndirectedEdge[72, 453] -> 
             RGBColor[
              0.2255232493931461, 0.35436961248504456`, 0.9361545874699662], 
             UndirectedEdge[391, 478] -> 
             RGBColor[
              0.36121422406998477`, 0.4812548901837663, 0.9445869453059381], 
             UndirectedEdge[328, 464] -> 
             RGBColor[
              0.22272025145336094`, 0.35142348392999634`, 0.9359949608839593],
              UndirectedEdge[149, 173] -> 
             RGBColor[
              0.6408634071546884, 0.7181223008643338, 0.9656896889353898], 
             UndirectedEdge[54, 186] -> 
             RGBColor[
              0.9914243588005289, 0.9890319585828893, 0.6689529207083693], 
             UndirectedEdge[355, 444] -> 
             RGBColor[
              0.5627869729236907, 0.655934843740483, 0.9587237985466135], 
             UndirectedEdge[7, 448] -> 
             RGBColor[
              0.38646904067525956`, 0.507890290668963, 0.9460168875491417], 
             UndirectedEdge[47, 416] -> 
             RGBColor[
              0.24541922577751857`, 0.3752815451427822, 0.9372876338915967], 
             UndirectedEdge[48, 155] -> 
             RGBColor[
              0.1919029748142661, 0.3190325722541152, 0.934239962569438], 
             UndirectedEdge[346, 486] -> 
             RGBColor[
              0.4273749578752095, 0.5445924408467173, 0.9484529322963398], 
             UndirectedEdge[24, 491] -> 
             RGBColor[
              0.1834588125121197, 0.3101572222837467, 0.9337590800183494], 
             UndirectedEdge[321, 373] -> 
             RGBColor[
              0.9882173705299822, 0.9893955941614516, 0.8449321929931977], 
             UndirectedEdge[209, 231] -> 
             RGBColor[
              0.8790670260426792, 0.9036392003218177, 0.8591433457844534], 
             UndirectedEdge[210, 393] -> 
             RGBColor[
              0.20841975513223648`, 0.336392755592659, 0.9351805687741597], 
             UndirectedEdge[188, 409] -> 
             RGBColor[
              0.23860514692337326`, 0.3681195162295229, 0.9368995821813795], 
             UndirectedEdge[307, 427] -> 
             RGBColor[
              0.1891435770986254, 0.31613227029905666`, 0.9340828189516954], 
             UndirectedEdge[178, 186] -> 
             RGBColor[
              0.7313163060716499, 0.7840864544016981, 0.7330087460966953], 
             UndirectedEdge[328, 475] -> 
             RGBColor[
              0.28975754389901165`, 0.4193152377496582, 0.9399066878746956], 
             UndirectedEdge[213, 337] -> 
             RGBColor[
              0.19565173016906506`, 0.3229727518168264, 0.9344534486411072], 
             UndirectedEdge[384, 458] -> 
             RGBColor[
              0.25354859204463764`, 0.3838260245211157, 0.9377505892741895], 
             UndirectedEdge[87, 473] -> 
             RGBColor[
              0.28600307999809077`, 0.4179377490935802, 0.9395988243510263], 
             UndirectedEdge[112, 440] -> 
             RGBColor[
              0.9425369917886818, 0.7961831197118145, 0.4948215293690824], 
             UndirectedEdge[237, 429] -> 
             RGBColor[
              0.2124196419707597, 0.3405968902674201, 0.9354083564123112], 
             UndirectedEdge[109, 230] -> 
             RGBColor[
              0.20976714477549485`, 0.3378089475371612, 0.9352573006210588], 
             UndirectedEdge[89, 262] -> 
             RGBColor[
              0.3264244296719824, 0.4571541672381602, 0.9420204539062771], 
             UndirectedEdge[280, 383] -> 
             RGBColor[
              0.2606241170949257, 0.3912628499631674, 0.9381535299585022], 
             UndirectedEdge[196, 489] -> 
             RGBColor[
              0.19180860925659354`, 0.31893338806987936`, 0.9342345885905299],
              UndirectedEdge[279, 459] -> 
             RGBColor[
              0.20123137359851423`, 0.3288373108310037, 0.9347712010800716], 
             UndirectedEdge[191, 423] -> 
             RGBColor[
              0.1848982635137219, 0.3116701765528954, 0.9338410546234137], 
             UndirectedEdge[116, 165] -> 
             RGBColor[
              0.2912027626996634, 0.4234029452918576, 0.9398949385886397], 
             UndirectedEdge[176, 313] -> 
             RGBColor[
              0.3390769551492299, 0.46811314887213096`, 0.9428266616414984], 
             UndirectedEdge[180, 490] -> 
             RGBColor[
              0.23955648296360244`, 0.3691194307259925, 0.9369537593614949], 
             UndirectedEdge[17, 498] -> 
             RGBColor[
              0.5750148993041335, 0.6617219953363903, 0.9616555440114883], 
             UndirectedEdge[108, 364] -> 
             RGBColor[
              0.2070027664491964, 0.33490341064451234`, 0.9350998733649074], 
             UndirectedEdge[29, 254] -> 
             RGBColor[
              0.18842942576301586`, 0.31538165196552115`, 0.9340421490896246],
              UndirectedEdge[7, 261] -> 
             RGBColor[
              0.40082339399554057`, 0.5210779379064496, 0.9469039036269813], 
             UndirectedEdge[122, 224] -> 
             RGBColor[
              0.195806426334931, 0.3231353472954549, 0.9344622583589008], 
             UndirectedEdge[116, 386] -> 
             RGBColor[
              0.2910406970756628, 0.423232604045479, 0.9398857091911075], 
             UndirectedEdge[8, 439] -> 
             RGBColor[
              0.1983584490277003, 0.3258176849531398, 0.9346075922758748], 
             UndirectedEdge[226, 488] -> 
             RGBColor[
              0.18475420080410804`, 0.31151875751098784`, 0.9338328504652229],
              UndirectedEdge[64, 170] -> 
             RGBColor[
              0.18627047911638173`, 0.31311246215478516`, 0.9339192002719742],
              UndirectedEdge[178, 313] -> 
             RGBColor[
              0.4152649069206235, 0.5336691197660451, 0.9478012623099019], 
             UndirectedEdge[81, 251] -> 
             RGBColor[
              0.23864347228983546`, 0.36815979861964326`, 0.9369017647543021],
              UndirectedEdge[186, 288] -> 
             RGBColor[
              0.8522733135527225, 0.8812298873379956, 0.7432521758076465], 
             UndirectedEdge[45, 118] -> 
             RGBColor[
              0.1966941864369604, 0.3240684394499293, 0.9345128149833881], 
             UndirectedEdge[224, 330] -> 
             RGBColor[
              0.1977574976662851, 0.3251860469697754, 0.9345733689848701], 
             UndirectedEdge[35, 410] -> 
             RGBColor[
              0.18494866329979062`, 0.31172314992358463`, 0.9338439248166706],
              UndirectedEdge[163, 379] -> 
             RGBColor[
              0.8633665292005046, 0.42373393983337493`, 0.2057939864189699], 
             UndirectedEdge[181, 443] -> 
             RGBColor[
              0.2566770686688468, 0.387114251810034, 0.9379287513897718], 
             UndirectedEdge[167, 235] -> 
             RGBColor[
              0.22849052163804753`, 0.3574884037503625, 0.9363235692346273], 
             UndirectedEdge[202, 279] -> 
             RGBColor[
              0.19737149140968246`, 0.32478032991987577`, 0.9345513864996016],
              UndirectedEdge[242, 310] -> 
             RGBColor[
              0.8089627721429287, 0.8509600154884045, 0.9478147926846883], 
             UndirectedEdge[299, 482] -> 
             RGBColor[
              0.2862226992731482, 0.4159841982683552, 0.9396913123648138], 
             UndirectedEdge[56, 110] -> 
             RGBColor[
              0.41196166706796206`, 0.5312422230440008, 0.9474708110355399], 
             UndirectedEdge[125, 419] -> 
             RGBColor[
              0.7136180387569662, 0.7762031026656953, 0.9720904350297161], 
             UndirectedEdge[262, 448] -> 
             RGBColor[
              0.3218757091133844, 0.45245966625341066`, 0.9417582440772314], 
             UndirectedEdge[95, 212] -> 
             RGBColor[
              0.18331321264928, 0.31000418759633763`, 0.9337507883215563], 
             UndirectedEdge[32, 260] -> 
             RGBColor[
              0.21471160984099968`, 0.34300589381819857`, 0.9355388805918587],
              UndirectedEdge[421, 430] -> 
             RGBColor[
              0.19294646407159283`, 0.3201293456246058, 0.9342993877389387], 
             UndirectedEdge[129, 346] -> 
             RGBColor[
              0.36539555977117477`, 0.4891180942666259, 0.9445692337379277], 
             UndirectedEdge[16, 17] -> 
             RGBColor[
              0.32278008566889027`, 0.45042607660179157`, 0.9419190112149659],
              UndirectedEdge[153, 466] -> 
             RGBColor[
              0.2112617016772801, 0.3393798216013181, 0.9353424134256167], 
             UndirectedEdge[244, 391] -> 
             RGBColor[
              0.45991819988990085`, 0.5722422337278446, 0.9506750794005083], 
             UndirectedEdge[218, 406] -> 
             RGBColor[
              0.35118939031714774`, 0.4764899015985373, 0.9436758749335621], 
             UndirectedEdge[99, 288] -> 
             RGBColor[
              0.8454606604699532, 0.8793558579429647, 0.9455510322617159], 
             UndirectedEdge[399, 481] -> 
             RGBColor[
              0.20657386895260635`, 0.3344526121819243, 0.9350754482869736], 
             UndirectedEdge[278, 451] -> 
             RGBColor[
              0.194775409510841, 0.3220516832430941, 0.9344035434760216], 
             UndirectedEdge[179, 327] -> 
             RGBColor[
              0.1919456153481889, 0.3190773901588341, 0.9342423908847639], 
             UndirectedEdge[38, 473] -> 
             RGBColor[
              0.39120686649721753`, 0.5073123077036177, 0.9467925996287968], 
             UndirectedEdge[17, 176] -> 
             RGBColor[
              0.3461884783937958, 0.47427279287102275`, 0.943279801614169], 
             UndirectedEdge[186, 373] -> 
             RGBColor[
              0.9921614072017308, 0.9893367470380662, 0.6567381212803327], 
             UndirectedEdge[399, 496] -> 
             RGBColor[
              0.19684711352332962`, 0.3242291755138407, 0.9345215239547214], 
             UndirectedEdge[116, 358] -> 
             RGBColor[
              0.2506809998117433, 0.38081200326849496`, 0.9375872841387487], 
             UndirectedEdge[71, 135] -> 
             RGBColor[
              0.18886726703484777`, 0.31584185090295647`, 0.9340670835023274],
              UndirectedEdge[53, 374] -> 
             RGBColor[
              0.8400594801870103, 0.30892029565931944`, 0.18599430950878], 
             UndirectedEdge[228, 409] -> 
             RGBColor[
              0.2557251463437433, 0.3861137210909889, 0.9378745408216], 
             UndirectedEdge[440, 471] -> 
             RGBColor[
              0.9242345860512566, 0.784069889818272, 0.5946181447155001], 
             UndirectedEdge[403, 471] -> 
             RGBColor[
              0.8501227775795742, 0.8834026890475528, 0.9665040763953929], 
             UndirectedEdge[63, 166] -> 
             RGBColor[
              0.20124645730453306`, 0.3288531647623917, 0.9347720600748151], 
             UndirectedEdge[159, 272] -> 
             RGBColor[
              0.24467152920527638`, 0.37449566863865497`, 0.9372450536779255],
              UndirectedEdge[130, 351] -> 
             RGBColor[
              0.2715547401921379, 0.40275162787986996`, 0.9387760127734806], 
             UndirectedEdge[113, 378] -> 
             RGBColor[
              0.20184046362642588`, 0.32947750306887713`, 0.9348058878560932],
              UndirectedEdge[145, 417] -> 
             RGBColor[
              0.20308781549592325`, 0.3307885489703952, 0.9348769226997694], 
             UndirectedEdge[38, 354] -> 
             RGBColor[
              0.4147037910637674, 0.5318387842884362, 0.9481369495411083], 
             UndirectedEdge[334, 446] -> 
             RGBColor[
              0.18513113872334164`, 0.31191494316334684`, 0.9338543165220936],
              UndirectedEdge[305, 310] -> 
             RGBColor[
              0.4776836488671362, 0.5829301850756662, 0.9531209010914763], 
             UndirectedEdge[338, 383] -> 
             RGBColor[
              0.34605340544318985`, 0.47036770113504156`, 0.9434098957217043],
              UndirectedEdge[243, 477] -> 
             RGBColor[
              0.19718654273618264`, 0.32458593713760425`, 0.9345408539462529],
              UndirectedEdge[38, 221] -> 
             RGBColor[
              0.7405475305032172, 0.7523239641423858, 0.6316046509416242], 
             UndirectedEdge[330, 357] -> 
             RGBColor[
              0.18906252050836794`, 0.3160470746834114, 0.9340782028987926], 
             UndirectedEdge[48, 365] -> 
             RGBColor[
              0.19846339054879825`, 0.32592798514549043`, 0.9346135685402542],
              UndirectedEdge[384, 411] -> 
             RGBColor[
              0.2746421437909936, 0.40599668481496154`, 0.9389518358410311], 
             UndirectedEdge[38, 436] -> 
             RGBColor[
              0.4371703671484145, 0.5512982032900106, 0.9495684999028087], 
             UndirectedEdge[117, 155] -> 
             RGBColor[
              0.1887434182573529, 0.3157116779853434, 0.9340600304976668], 
             UndirectedEdge[68, 286] -> 
             RGBColor[
              0.1864116908357643, 0.3132608846251963, 0.9339272420704889], 
             UndirectedEdge[378, 380] -> 
             RGBColor[
              0.19721656952288963`, 0.32461749719424154`, 0.9345425639273353],
              UndirectedEdge[12, 285] -> 
             RGBColor[
              0.20421155270957553`, 0.33196966803099826`, 0.9349409178716667],
              UndirectedEdge[93, 432] -> 
             RGBColor[
              0.2569317093580773, 0.38738189531956746`, 0.9379432528003164], 
             UndirectedEdge[340, 499] -> 
             RGBColor[
              0.4961829212208138, 0.5994318600646289, 0.9541521247756388], 
             UndirectedEdge[389, 456] -> 
             RGBColor[
              0.1952664503716337, 0.322567798321576, 0.9344315075266139], 
             UndirectedEdge[390, 451] -> 
             RGBColor[
              0.23050025885424308`, 0.3596007649892832, 0.93643802079595], 
             UndirectedEdge[92, 485] -> 
             RGBColor[
              0.26364199259434656`, 0.39443482845741684`, 0.9383253935036474],
              UndirectedEdge[293, 471] -> 
             RGBColor[
              0.883292777281721, 0.9093153449162048, 0.969810151974432], 
             UndirectedEdge[111, 359] -> 
             RGBColor[
              0.6380588033619161, 0.711320155207173, 0.9679062350071925], 
             UndirectedEdge[357, 441] -> 
             RGBColor[
              0.20500595942209238`, 0.33280463985414815`, 0.9349861581587251],
              UndirectedEdge[52, 268] -> 
             RGBColor[
              0.18314820397606815`, 0.30983075301863783`, 0.9337413913217254],
              UndirectedEdge[30, 311] -> 
             RGBColor[
              0.18445928711484194`, 0.31120878452496137`, 0.9338160555669048],
              UndirectedEdge[164, 486] -> 
             RGBColor[
              0.3646799679598963, 0.49028919172388963`, 0.9444580629779388], 
             UndirectedEdge[194, 290] -> 
             RGBColor[
              0.18381681483281254`, 0.31053350542145297`, 0.9337794677208959],
              UndirectedEdge[238, 445] -> 
             RGBColor[
              0.7249039407503491, 0.7407041936806955, 0.6319785472238091], 
             UndirectedEdge[269, 406] -> 
             RGBColor[
              0.5091880023383142, 0.611421148279524, 0.9547804937952983], 
             UndirectedEdge[99, 341] -> 
             RGBColor[
              0.9869976251000042, 0.9872951064518227, 0.7699640190632113], 
             UndirectedEdge[41, 457] -> 
             RGBColor[
              0.36616941470913866`, 0.48692522378917524`, 0.9448270715857057],
              UndirectedEdge[217, 292] -> 
             RGBColor[
              0.18318117608781065`, 0.30986540879863184`, 0.9337432690347114],
              UndirectedEdge[176, 299] -> 
             RGBColor[
              0.2785034431297019, 0.4092981665779968, 0.9391994481892236], 
             UndirectedEdge[218, 314] -> 
             RGBColor[
              0.27434229412121725`, 0.4056815238004595, 0.9389347598459252], 
             UndirectedEdge[355, 486] -> 
             RGBColor[
              0.48652222048477045`, 0.5929340389323234, 0.9530199242881539], 
             UndirectedEdge[213, 420] -> 
             RGBColor[
              0.19513105630202093`, 0.32242549056993314`, 0.9344237970346471],
              UndirectedEdge[299, 407] -> 
             RGBColor[
              0.2586014952958633, 0.3891369462107238, 0.9380383446392464], 
             UndirectedEdge[201, 314] -> 
             RGBColor[
              0.2601298304238602, 0.39074332333229245`, 0.9381253810638166], 
             UndirectedEdge[160, 300] -> 
             RGBColor[
              0.2356560570579657, 0.36501983579788244`, 0.936731635876332], 
             UndirectedEdge[21, 200] -> 
             RGBColor[
              0.28148912705476437`, 0.4131932983489973, 0.9393417614086988], 
             UndirectedEdge[25, 180] -> 
             RGBColor[
              0.2760199528625702, 0.4074448495073293, 0.9390303000293716], 
             UndirectedEdge[45, 185] -> 
             RGBColor[
              0.2063591315326575, 0.33422690953841927`, 0.935063219308583], 
             UndirectedEdge[191, 226] -> 
             RGBColor[
              0.18878815245387853`, 0.31575869646220367`, 0.9340625780439806],
              UndirectedEdge[50, 82] -> 
             RGBColor[
              0.7002427375322327, 0.764369726655832, 0.9719080506652522], 
             UndirectedEdge[22, 491] -> 
             RGBColor[
              0.1817125626643469, 0.3083218029751023, 0.9336596336728639], 
             UndirectedEdge[99, 277] -> 
             RGBColor[
              0.7114622471897839, 0.7713508183962726, 0.9343566439534178], 
             UndirectedEdge[17, 391] -> 
             RGBColor[
              0.4242791032166461, 0.5413734394625537, 0.9484041876749043], 
             UndirectedEdge[211, 362] -> 
             RGBColor[
              0.1833599948775373, 0.31005335868440065`, 0.9337534525002475], 
             UndirectedEdge[4, 162] -> 
             RGBColor[
              0.18241905104503708`, 0.3090643670571582, 0.9336998671409883], 
             UndirectedEdge[259, 444] -> 
             RGBColor[
              0.6245686648985196, 0.7054652507537504, 0.9640159946250897], 
             UndirectedEdge[347, 382] -> 
             RGBColor[
              0.2075732378156851, 0.3355030122206657, 0.9351323608652922], 
             UndirectedEdge[66, 179] -> 
             RGBColor[
              0.19899718509969622`, 0.32648903706301347`, 0.9346439673502496],
              UndirectedEdge[343, 471] -> 
             RGBColor[
              0.901533639219245, 0.661841877888372, 0.5749261182612281], 
             UndirectedEdge[97, 322] -> 
             RGBColor[
              0.9046195205529701, 0.5667356132446183, 0.288595833391559], 
             UndirectedEdge[363, 381] -> 
             RGBColor[
              0.18545627477246146`, 0.3122566817657879, 0.9338728325390953], 
             UndirectedEdge[238, 471] -> 
             RGBColor[
              0.7217628649306637, 0.780742284826936, 0.9553407683017833], 
             UndirectedEdge[40, 285] -> 
             RGBColor[
              0.19969824891224597`, 0.32722589958001636`, 0.9346838918972433],
              UndirectedEdge[70, 208] -> 
             RGBColor[
              0.39817892177344283`, 0.519304301810809, 0.9465925866929762], 
             UndirectedEdge[84, 448] -> 
             RGBColor[
              0.28804975562944346`, 0.4200889349488619, 0.9397153795004467], 
             UndirectedEdge[152, 195] -> 
             RGBColor[
              0.18616514652705513`, 0.313001750924931, 0.9339132017368377], 
             UndirectedEdge[93, 308] -> 
             RGBColor[
              0.20676738749395213`, 0.33465601243866294`, 0.9350864688816183],
              UndirectedEdge[255, 478] -> 
             RGBColor[
              0.22324206600367816`, 0.3519719441073331, 0.9360246774506443], 
             UndirectedEdge[112, 293] -> 
             RGBColor[
              0.901595183019146, 0.9214285748097474, 0.8700135366280143], 
             UndirectedEdge[87, 184] -> 
             RGBColor[
              0.4246238918446351, 0.5398024449911591, 0.9489353468656369], 
             UndirectedEdge[149, 323] -> 
             RGBColor[
              0.7769198644929252, 0.8229213917028264, 0.8645345338157826], 
             UndirectedEdge[272, 497] -> 
             RGBColor[
              0.3677045224545963, 0.48747048871276477`, 0.9450117306986173], 
             UndirectedEdge[80, 471] -> 
             RGBColor[
              0.6521263465827374, 0.7213327352775194, 0.9506532320788272], 
             UndirectedEdge[339, 344] -> 
             RGBColor[
              0.1852310273425353, 0.3120199324354236, 0.9338600050311847], 
             UndirectedEdge[137, 393] -> 
             RGBColor[
              0.21648582185917808`, 0.3448707031408432, 0.9356399193415825], 
             UndirectedEdge[11, 316] -> 
             RGBColor[
              0.4071433573553281, 0.5270688453462049, 0.9471637926013148], 
             UndirectedEdge[88, 423] -> 
             RGBColor[
              0.18437944571093495`, 0.3111248661472177, 0.9338115087170672], 
             UndirectedEdge[70, 351] -> 
             RGBColor[
              0.3049667644622824, 0.4322301812417861, 0.9408852716041266], 
             UndirectedEdge[55, 298] -> 
             RGBColor[
              0.424640850686557, 0.5359021493799299, 0.9492929643380126], 
             UndirectedEdge[428, 437] -> 
             RGBColor[
              0.18484681961512717`, 0.31161610575374077`, 0.9338381249694931],
              UndirectedEdge[90, 137] -> 
             RGBColor[
              0.23700337417738956`, 0.3664359515152362, 0.9368083635931062], 
             UndirectedEdge[344, 439] -> 
             RGBColor[
              0.19475306873947695`, 0.32202820167590374`, 0.9344022712021427],
              UndirectedEdge[93, 274] -> 
             RGBColor[
              0.23335737797095998`, 0.3626037783327675, 0.936600729502918], 
             UndirectedEdge[60, 434] -> 
             RGBColor[
              0.9602863904874878, 0.8842947028459596, 0.5783529786054818], 
             UndirectedEdge[54, 244] -> 
             RGBColor[
              0.7181235795673231, 0.775643062211419, 0.8864694686198505], 
             UndirectedEdge[243, 318] -> 
             RGBColor[
              0.19728008332867447`, 0.3246842542311293, 0.9345461809446143], 
             UndirectedEdge[384, 402] -> 
             RGBColor[
              0.24310211003433443`, 0.3728461095830723, 0.937155677577888], 
             UndirectedEdge[83, 233] -> 
             RGBColor[
              0.9788921335245182, 0.9819450762719373, 0.8385157306415634], 
             UndirectedEdge[153, 201] -> 
             RGBColor[
              0.2425444285480653, 0.37225995098195497`, 0.9371239184422607], 
             UndirectedEdge[275, 331] -> 
             RGBColor[
              0.39537355093788906`, 0.515221122490898, 0.946708621365979], 
             UndirectedEdge[312, 327] -> 
             RGBColor[
              0.18937402646973123`, 0.31637448719942296`, 0.9340959427024605],
              UndirectedEdge[181, 370] -> 
             RGBColor[
              0.2271386690157574, 0.35606752093192884`, 0.9362465832276747], 
             UndirectedEdge[32, 245] -> 
             RGBColor[
              0.23179881460343715`, 0.36096562941487603`, 0.9365119716248255],
              UndirectedEdge[176, 391] -> 
             RGBColor[
              0.3950241069319744, 0.5160342320796381, 0.9465400851808224], 
             UndirectedEdge[148, 232] -> 
             RGBColor[
              0.27654750718772436`, 0.40799934255194237`, 0.9390603434677424],
              UndirectedEdge[430, 477] -> 
             RGBColor[
              0.19967498374543186`, 0.3272014464145979, 0.9346825669804111], 
             UndirectedEdge[7, 475] -> 
             RGBColor[
              0.40444131336028016`, 0.5242115978182725, 0.9471344342497021], 
             UndirectedEdge[15, 50] -> 
             RGBColor[
              0.7663849277124503, 0.8179130209698517, 0.9772202389257285], 
             UndirectedEdge[168, 395] -> 
             RGBColor[
              0.3984267572015211, 0.5166565922466431, 0.9470439450191381], 
             UndirectedEdge[97, 440] -> 
             RGBColor[
              0.9400446504463722, 0.7867672719569345, 0.32047255191532753`], 
             UndirectedEdge[71, 308] -> 
             RGBColor[
              0.19432153409427227`, 0.32157463140291687`, 0.9343776959424965],
              UndirectedEdge[253, 436] -> 
             RGBColor[
              0.36650668927910635`, 0.49187140591690626`, 0.9445744600450926],
              UndirectedEdge[13, 430] -> 
             RGBColor[
              0.22725075415308893`, 0.3561853295178724, 0.9362529663104306], 
             UndirectedEdge[209, 233] -> 
             RGBColor[
              0.9785167541303205, 0.9817898472456261, 0.8447367386541516], 
             UndirectedEdge[254, 350] -> 
             RGBColor[
              0.18697690227356584`, 0.31385495768280075`, 0.9339594300257164],
              UndirectedEdge[115, 268] -> 
             RGBColor[
              0.18864406926620203`, 0.3156072558965539, 0.9340543727195945], 
             UndirectedEdge[42, 468] -> 
             RGBColor[
              0.21102583019430793`, 0.33913190571759855`, 0.9353289808936021],
              UndirectedEdge[51, 60] -> 
             RGBColor[
              0.9903726876472161, 0.9902614167392676, 0.8073625961746422], 
             UndirectedEdge[331, 348] -> 
             RGBColor[
              0.3817575877124325, 0.5041670701523192, 0.9456367228639543], 
             UndirectedEdge[310, 406] -> 
             RGBColor[
              0.5306573998942516, 0.6288133856772102, 0.9564963416640753], 
             UndirectedEdge[70, 130] -> 
             RGBColor[
              0.33633111822806117`, 0.4651961056645053, 0.9426714251516843], 
             UndirectedEdge[83, 440] -> 
             RGBColor[
              0.9434296852982257, 0.7965522714191877, 0.48002728769919345`], 
             UndirectedEdge[100, 374] -> 
             RGBColor[
              0.9203355927006582, 0.6768022824414968, 0.3486163331687475], 
             UndirectedEdge[207, 374] -> 
             RGBColor[
              0.8612156544492956, 0.4454551404687426, 0.20523222788802623`], 
             UndirectedEdge[51, 324] -> 
             RGBColor[
              0.9674926297054737, 0.9734136310223126, 0.8557710419754258], 
             UndirectedEdge[164, 180] -> 
             RGBColor[
              0.28958519225458484`, 0.42102975172188783`, 0.9398274630675963],
              UndirectedEdge[56, 132] -> 
             RGBColor[
              0.3395809707923225, 0.46518136452608577`, 0.94298210840368], 
             UndirectedEdge[30, 423] -> 
             RGBColor[
              0.17906694420854233`, 0.3055410902361533, 0.9335089696156476], 
             UndirectedEdge[104, 379] -> 
             RGBColor[
              0.8757781230833462, 0.4743585366446421, 0.21585393387585383`], 
             UndirectedEdge[324, 457] -> 
             RGBColor[
              0.7044919829810323, 0.7672858327374596, 0.9691306015608669], 
             UndirectedEdge[283, 459] -> 
             RGBColor[
              0.18839869617185917`, 0.3153493532168468, 0.9340403990848687], 
             UndirectedEdge[128, 245] -> 
             RGBColor[
              0.21909064595633707`, 0.347608538422344, 0.9357882602204238], 
             UndirectedEdge[34, 62] -> 
             RGBColor[
              0.23006104796724536`, 0.35913912649947, 0.9364130083856896], 
             UndirectedEdge[320, 424] -> 
             RGBColor[
              0.18730513840807234`, 0.31419995467154005`, 0.9339781225879946],
              UndirectedEdge[111, 351] -> 
             RGBColor[
              0.3033909458875273, 0.43086528639527777`, 0.9407848618379848], 
             UndirectedEdge[79, 316] -> 
             RGBColor[
              0.6624800077652702, 0.7332731084999433, 0.9690938030221024], 
             UndirectedEdge[43, 250] -> 
             RGBColor[
              0.22400512105631526`, 0.3527739633481394, 0.9360681323070532], 
             UndirectedEdge[116, 313] -> 
             RGBColor[
              0.3188496851508186, 0.44760999428327536`, 0.9416470314755198], 
             UndirectedEdge[87, 436] -> 
             RGBColor[
              0.33196658064928775`, 0.46192364467997304`, 0.9423747246250382],
              UndirectedEdge[280, 393] -> 
             RGBColor[
              0.23739481376153632`, 0.3668473793368775, 0.9368306554983403], 
             UndirectedEdge[295, 321] -> 
             RGBColor[
              0.9851155314829081, 0.988112904001859, 0.896337693305348], 
             UndirectedEdge[131, 186] -> 
             RGBColor[
              0.913526249632497, 0.6241954645463874, 0.3472925437386266], 
             UndirectedEdge[165, 313] -> 
             RGBColor[
              0.3335735057381806, 0.4630856632647371, 0.9424855312760294], 
             UndirectedEdge[140, 270] -> 
             RGBColor[
              0.1795641494336302, 0.30606368445235266`, 0.9335372847176671], 
             UndirectedEdge[322, 445] -> 
             RGBColor[
              0.89195053197754, 0.5240001399597152, 0.23937920511375732`], 
             UndirectedEdge[112, 463] -> 
             RGBColor[
              0.7743003013960627, 0.8206490549360065, 0.8582392599813213], 
             UndirectedEdge[115, 223] -> 
             RGBColor[
              0.1995856510144891, 0.3271075520503548, 0.9346774796135398], 
             UndirectedEdge[102, 451] -> 
             RGBColor[
              0.20226457959273075`, 0.32992327583996894`, 0.9348300406329509],
              UndirectedEdge[148, 267] -> 
             RGBColor[
              0.25194617616278553`, 0.3821417838302541, 0.9376593340602799], 
             UndirectedEdge[447, 500] -> 
             RGBColor[
              0.21735914083056895`, 0.34578861675139594`, 0.9356896535650436],
              UndirectedEdge[238, 293] -> 
             RGBColor[
              0.6482189757415503, 0.7227281926989446, 0.9672024760249813], 
             UndirectedEdge[56, 457] -> 
             RGBColor[
              0.4380492997215996, 0.5534053955584954, 0.9492526271337134], 
             UndirectedEdge[204, 331] -> 
             RGBColor[
              0.3086689498622105, 0.44109928644623464`, 0.9409138412479245], 
             UndirectedEdge[66, 260] -> 
             RGBColor[
              0.203816558535701, 0.331554504110179, 0.9349184235378061], 
             UndirectedEdge[225, 424] -> 
             RGBColor[
              0.18871848366086047`, 0.31568547014348514`, 0.9340586105092841],
              UndirectedEdge[178, 244] -> 
             RGBColor[
              0.45801552683844415`, 0.5706975580302278, 0.9505252940081765], 
             UndirectedEdge[139, 247] -> 
             RGBColor[
              0.18343934894517555`, 0.310136764840827, 0.9337579715970057], 
             UndirectedEdge[244, 448] -> 
             RGBColor[
              0.373652859998312, 0.49730643195466345`, 0.9450574383468822], 
             UndirectedEdge[259, 275] -> 
             RGBColor[
              0.586292797645066, 0.6743911774092273, 0.9610027781457763], 
             UndirectedEdge[282, 406] -> 
             RGBColor[
              0.5566077877471345, 0.6490860258981348, 0.9590828338050883], 
             UndirectedEdge[286, 357] -> 
             RGBColor[
              0.1879701028596808, 0.3148988744713619, 0.934015991329787], 
             UndirectedEdge[206, 396] -> 
             RGBColor[
              0.18892633617542332`, 0.3159039363149012, 0.9340704474024981], 
             UndirectedEdge[154, 295] -> 
             RGBColor[
              0.9841314996436169, 0.9875855475713144, 0.9072523679449918], 
             UndirectedEdge[410, 428] -> 
             RGBColor[
              0.18501111447909718`, 0.3117887900726693, 0.9338474813189439], 
             UndirectedEdge[104, 147] -> 
             RGBColor[
              0.8716060245867224, 0.4422899593743725, 0.21185872764377553`], 
             UndirectedEdge[32, 255] -> 
             RGBColor[
              0.20842141467182945`, 0.3363944998739921, 0.9351806632824844], 
             UndirectedEdge[165, 498] -> 
             RGBColor[
              0.5402564536084126, 0.6313553023460808, 0.9594503111519376], 
             UndirectedEdge[248, 439] -> 
             RGBColor[
              0.18975162768821172`, 0.3167713700213459, 0.934117446533242], 
             UndirectedEdge[141, 389] -> 
             RGBColor[
              0.20111521708192343`, 0.32871522296731825`, 0.9347645861382899],
              UndirectedEdge[328, 478] -> 
             RGBColor[
              0.24615010342073995`, 0.376049743886127, 0.9373292562921416], 
             UndirectedEdge[178, 261] -> 
             RGBColor[
              0.3993010721320601, 0.5198420484378579, 0.9467840608734395], 
             UndirectedEdge[120, 315] -> 
             RGBColor[
              0.18165682168185682`, 0.3082632156683228, 0.9336564593063725], 
             UndirectedEdge[47, 136] -> 
             RGBColor[
              0.40491583995544145`, 0.5205967008566313, 0.9476756741243257], 
             UndirectedEdge[74, 144] -> 
             RGBColor[
              0.1927927730691202, 0.31996780663643465`, 0.9342906352637134], 
             UndirectedEdge[165, 361] -> 
             RGBColor[
              0.26801366747199473`, 0.39902973593402147`, 0.9385743539206161],
              UndirectedEdge[32, 482] -> 
             RGBColor[
              0.27602220405873207`, 0.40526283104925287`, 0.9391104092526332],
              UndirectedEdge[67, 119] -> 
             RGBColor[
              0.18259585546660687`, 0.3092501997142758, 0.933709935891238], 
             UndirectedEdge[97, 326] -> 
             RGBColor[
              0.8569194124299913, 0.8790587115212953, 0.6914601091734929], 
             UndirectedEdge[409, 430] -> 
             RGBColor[
              0.22739490707234228`, 0.3563368433758307, 0.9362611756059269], 
             UndirectedEdge[113, 190] -> 
             RGBColor[
              0.20663037548476026`, 0.33451200412993914`, 0.9350786662503858],
              UndirectedEdge[292, 496] -> 
             RGBColor[
              0.1854675912889076, 0.3122685761420814, 0.9338734769979656], 
             UndirectedEdge[15, 82] -> 
             RGBColor[
              0.5862643398841738, 0.6748409125363397, 0.9606772556368353], 
             UndirectedEdge[340, 414] -> 
             RGBColor[
              0.3932297908847611, 0.5150176133855842, 0.946277232449094], 
             UndirectedEdge[149, 282] -> 
             RGBColor[
              0.6289215162862603, 0.7087932049561856, 0.9644994328569398], 
             UndirectedEdge[330, 368] -> 
             RGBColor[
              0.18440628949779087`, 0.3111530806691976, 0.9338130374310167], 
             UndirectedEdge[331, 431] -> 
             RGBColor[
              0.3613433617487599, 0.48672321452944306`, 0.9442702081951819], 
             UndirectedEdge[4, 488] -> 
             RGBColor[
              0.1820203772126724, 0.30864533558196194`, 0.9336771632560201], 
             UndirectedEdge[87, 409] -> 
             RGBColor[
              0.28082294387369244`, 0.4124930975872375, 0.9393038232620665], 
             UndirectedEdge[440, 445] -> 
             RGBColor[
              0.9273756618709421, 0.7440317986720315, 0.27125592363752593`], 
             UndirectedEdge[55, 200] -> 
             RGBColor[
              0.4182843192455511, 0.5292210318080617, 0.9489309692760928], 
             UndirectedEdge[64, 215] -> 
             RGBColor[
              0.18488430371745596`, 0.31165550392191765`, 0.9338402596336681],
              UndirectedEdge[167, 493] -> 
             RGBColor[
              0.25038390854803594`, 0.3804997415136645, 0.9375703652307877], 
             UndirectedEdge[153, 470] -> 
             RGBColor[
              0.2111255154646311, 0.3392366812571194, 0.9353346578222758], 
             UndirectedEdge[185, 187] -> 
             RGBColor[
              0.21639359634399347`, 0.34477376827694883`, 0.9356346672349283],
              UndirectedEdge[18, 310] -> 
             RGBColor[
              0.46656300779364224`, 0.5714089084514553, 0.952481474208732], 
             UndirectedEdge[226, 366] -> 
             RGBColor[
              0.18476826025973897`, 0.3115335348902769, 0.9338336511304219], 
             UndirectedEdge[333, 361] -> 
             RGBColor[
              0.2309444912286668, 0.3600676813807619, 0.9364633191724905], 
             UndirectedEdge[236, 300] -> 
             RGBColor[
              0.22011134127912346`, 0.34868135392241384`, 0.9358463873090731],
              UndirectedEdge[161, 335] -> 
             RGBColor[
              0.21211283365491676`, 0.3402744152746985, 0.9353908841326062], 
             UndirectedEdge[61, 397] -> 
             RGBColor[
              0.9061343995223057, 0.5802110742285213, 0.48990321177495955`], 
             UndirectedEdge[393, 480] -> 
             RGBColor[
              0.23233850550566576`, 0.36153287877149787`, 0.9365427062233063],
              UndirectedEdge[349, 378] -> 
             RGBColor[
              0.1960796577618784, 0.3234225308490497, 0.9344778184844558], 
             UndirectedEdge[97, 163] -> 
             RGBColor[
              0.9438826652312557, 0.8041948007039634, 0.3236750855301855], 
             UndirectedEdge[229, 267] -> 
             RGBColor[
              0.23204884719292487`, 0.3612284295194095, 0.9365262106109067], 
             UndirectedEdge[77, 287] -> 
             RGBColor[
              0.31931088859466533`, 0.4505681988320882, 0.9415827311905192], 
             UndirectedEdge[41, 485] -> 
             RGBColor[
              0.2592162515913262, 0.38978309405505573`, 0.9380733541008225], 
             UndirectedEdge[7, 89] -> 
             RGBColor[
              0.39101776123385745`, 0.5125847916537125, 0.9462790973781875], 
             UndirectedEdge[41, 44] -> 
             RGBColor[
              0.27104906144274005`, 0.40222012745236824`, 0.938747215116787], 
             UndirectedEdge[147, 234] -> 
             RGBColor[
              0.872729313424225, 0.4467434253012546, 0.2127625522094079], 
             UndirectedEdge[259, 331] -> 
             RGBColor[
              0.4923539796181456, 0.5933274496466499, 0.9547717909351274], 
             UndirectedEdge[77, 409] -> 
             RGBColor[
              0.2938507755920474, 0.42380800580193695`, 0.940132815419882], 
             UndirectedEdge[2, 334] -> 
             RGBColor[
              0.18552483193608832`, 0.31232873969153496`, 0.9338767367681426],
              UndirectedEdge[315, 487] -> 
             RGBColor[
              0.1880750117052634, 0.3150091403196742, 0.9340219657333442], 
             UndirectedEdge[251, 258] -> 
             RGBColor[
              0.3270553942889411, 0.45124571304551764`, 0.9422970062673146], 
             UndirectedEdge[39, 96] -> 
             RGBColor[
              0.359182658449612, 0.4793995184819319, 0.94444576944529], 
             UndirectedEdge[219, 497] -> 
             RGBColor[
              0.5738542866268592, 0.6645036181845554, 0.959879595311844], 
             UndirectedEdge[447, 454] -> 
             RGBColor[
              0.2225609566268063, 0.3512560549674121, 0.9359858892792425], 
             UndirectedEdge[417, 458] -> 
             RGBColor[
              0.21807667250257026`, 0.34654278803280497`, 0.9357305159322711],
              UndirectedEdge[189, 422] -> 
             RGBColor[
              0.22925608385888036`, 0.3582930581839061, 0.936367166870556], 
             UndirectedEdge[431, 444] -> 
             RGBColor[
              0.4935580470291339, 0.5988610156365437, 0.9535144118851442], 
             UndirectedEdge[161, 273] -> 
             RGBColor[
              0.20050467294518176`, 0.3280735023688687, 0.9347298165529216], 
             UndirectedEdge[109, 413] -> 
             RGBColor[
              0.22197296688604118`, 0.35063804046916514`, 0.9359524041333588],
              UndirectedEdge[236, 470] -> 
             RGBColor[
              0.2014866380141136, 0.3291056099164974, 0.9347857380109101], 
             UndirectedEdge[287, 436] -> 
             RGBColor[
              0.3298373627600314, 0.45968570167815315`, 0.9422534688161406], 
             UndirectedEdge[253, 473] -> 
             RGBColor[
              0.32054318862790937`, 0.44788551033051344`, 0.9417985597710807],
              UndirectedEdge[166, 435] -> 
             RGBColor[
              0.21704014991788595`, 0.3454533370769741, 0.9356714875044712], 
             UndirectedEdge[114, 312] -> 
             RGBColor[
              0.1882015984664733, 0.31514219103177, 0.9340291746621268], 
             UndirectedEdge[222, 296] -> 
             RGBColor[
              0.18966575842362554`, 0.31668111597984006`, 0.934112556405656], 
             UndirectedEdge[5, 346] -> 
             RGBColor[
              0.5654957918264961, 0.6570874909093873, 0.9595208737141337], 
             UndirectedEdge[86, 220] -> 
             RGBColor[
              0.20117259087192368`, 0.32877552645831687`, 0.9347678534907535],
              UndirectedEdge[195, 255] -> 
             RGBColor[
              0.19263264106654965`, 0.3197994977487777, 0.9342815159830611], 
             UndirectedEdge[313, 407] -> 
             RGBColor[
              0.31917500731539133`, 0.44795192850485793`, 0.9416655580915212],
              UndirectedEdge[224, 441] -> 
             RGBColor[
              0.21370093658000952`, 0.34194361214051205`, 0.9354813242448025],
              UndirectedEdge[172, 211] -> 
             RGBColor[
              0.20548759572979827`, 0.33331087015105276`, 0.9350135866339319],
              UndirectedEdge[204, 355] -> 
             RGBColor[
              0.4378065045945586, 0.5507389343512965, 0.9499158019492457], 
             UndirectedEdge[109, 180] -> 
             RGBColor[
              0.23839049921865452`, 0.36789390788241305`, 0.9368873583121385],
              UndirectedEdge[96, 157] -> 
             RGBColor[
              0.3849349952696799, 0.5064668572722832, 0.9459123269300246], 
             UndirectedEdge[316, 372] -> 
             RGBColor[
              0.5264921273018517, 0.6260724945913516, 0.9559761056168596], 
             UndirectedEdge[53, 112] -> 
             RGBColor[
              0.9130580700237505, 0.6218566223199413, 0.468638906464419], 
             UndirectedEdge[28, 305] -> 
             RGBColor[
              0.3931980637426643, 0.5143785677629451, 0.9464441881014032], 
             UndirectedEdge[186, 341] -> 
             RGBColor[
              0.9938102781827736, 0.9891691358468536, 0.5676651626091419], 
             UndirectedEdge[65, 86] -> 
             RGBColor[
              0.18424555499085607`, 0.31098413851125284`, 0.9338038838386322],
              UndirectedEdge[10, 390] -> 
             RGBColor[
              0.24135031626720926`, 0.37100486326368376`, 0.9370559155143968],
              UndirectedEdge[48, 140] -> 
             RGBColor[
              0.1844487281323768, 0.3111976863649123, 0.9338154542484741], 
             UndirectedEdge[231, 404] -> 
             RGBColor[
              0.8002424461846211, 0.8440108833840196, 0.9806882202971826], 
             UndirectedEdge[87, 354] -> 
             RGBColor[
              0.30950000456464066`, 0.4424642256783988, 0.9409431742633377], 
             UndirectedEdge[136, 434] -> 
             RGBColor[
              0.7316510467407765, 0.7040970288480641, 0.6113123490612679], 
             UndirectedEdge[205, 413] -> 
             RGBColor[
              0.2338956489319965, 0.363169535241167, 0.9366313832378486], 
             UndirectedEdge[20, 490] -> 
             RGBColor[
              0.22886274008807128`, 0.3578796289413503, 0.9363447665247084], 
             UndirectedEdge[390, 443] -> 
             RGBColor[
              0.2718752322958543, 0.4030884854012488, 0.9387942643246616], 
             UndirectedEdge[296, 385] -> 
             RGBColor[
              0.18189236637294215`, 0.30851078807304944`, 0.9336698732280726],
              UndirectedEdge[86, 290] -> 
             RGBColor[
              0.18341921937923714`, 0.31011560739073746`, 0.9337568252480046],
              UndirectedEdge[24, 74] -> 
             RGBColor[
              0.18699882666459755`, 0.3138780016078617, 0.9339606785873513], 
             UndirectedEdge[38, 336] -> 
             RGBColor[
              0.5720852226715933, 0.663483581767208, 0.9594557908273795], 
             UndirectedEdge[383, 443] -> 
             RGBColor[
              0.2778055713012203, 0.40932164770109847`, 0.9391319883578669], 
             UndirectedEdge[14, 435] -> 
             RGBColor[
              0.23468936895954257`, 0.3640037853148743, 0.9366765844192138], 
             UndirectedEdge[282, 323] -> 
             RGBColor[
              0.8447117696653836, 0.8771252738990953, 0.8704406417188999], 
             UndirectedEdge[307, 337] -> 
             RGBColor[
              0.19042947914241254`, 0.31748383487797555`, 0.9341560491707674],
              UndirectedEdge[157, 356] -> 
             RGBColor[
              0.272205938145604, 0.40343607821729777`, 0.9388130975335695], 
             UndirectedEdge[166, 439] -> 
             RGBColor[
              0.19745604044376464`, 0.3248691963154145, 0.9345562014420135], 
             UndirectedEdge[266, 293] -> 
             RGBColor[
              0.9016661303754756, 0.9199925303309897, 0.7623198781355807], 
             UndirectedEdge[2, 260] -> 
             RGBColor[
              0.1969726482624509, 0.32436112048401927`, 0.9345286729724024], 
             UndirectedEdge[135, 466] -> 
             RGBColor[
              0.18744105358565671`, 0.3143428101407012, 0.9339858627562896], 
             UndirectedEdge[60, 495] -> 
             RGBColor[
              0.9357924776533132, 0.7819607374227355, 0.5583743815380187], 
             UndirectedEdge[217, 464] -> 
             RGBColor[
              0.19184821856094375`, 0.31897501996012645`, 0.9342368442818159],
              UndirectedEdge[435, 453] -> 
             RGBColor[
              0.2391644667053946, 0.36870739678334974`, 0.9369314346155262], 
             UndirectedEdge[82, 411] -> 
             RGBColor[
              0.4006657201660342, 0.5170983953721258, 0.9473454462572704], 
             UndirectedEdge[94, 193] -> 
             RGBColor[
              0.17992543383268728`, 0.3064434172625156, 0.9335578593297211], 
             UndirectedEdge[88, 469] -> 
             RGBColor[
              0.1854557592359103, 0.3122561399041857, 0.9338728031800514], 
             UndirectedEdge[36, 76] -> 
             RGBColor[
              0.7022798190159381, 0.7608775969992009, 0.8471463932234504], 
             UndirectedEdge[163, 326] -> 
             RGBColor[
              0.8123452824001817, 0.7105293109037376, 0.6054779360527895], 
             UndirectedEdge[151, 472] -> 
             RGBColor[
              0.1934245140122105, 0.3206318064223118, 0.9343266119758453], 
             UndirectedEdge[114, 138] -> 
             RGBColor[
              0.18210218513342014`, 0.30873132089358957`, 0.9336818220960829],
              UndirectedEdge[448, 475] -> 
             RGBColor[
              0.3185563246566676, 0.44958458227411635`, 0.9415467358348658], 
             UndirectedEdge[169, 362] -> 
             RGBColor[
              0.18152465259386255`, 0.3081242975768366, 0.9336489324723378], 
             UndirectedEdge[20, 25] -> 
             RGBColor[
              0.26532620998703904`, 0.39620504772268694`, 0.9384213071925849],
              UndirectedEdge[113, 349] -> 
             RGBColor[
              0.19095597353932497`, 0.3180372138708033, 0.934186032247793], 
             UndirectedEdge[457, 494] -> 
             RGBColor[
              0.4122768656126409, 0.531082608493518, 0.9476104304219592], 
             UndirectedEdge[364, 452] -> 
             RGBColor[
              0.21560011293675418`, 0.34393976690618655`, 0.9355894795287394],
              UndirectedEdge[351, 442] -> 
             RGBColor[
              0.23904734061072216`, 0.3685842898316257, 0.936924764457707], 
             UndirectedEdge[71, 466] -> 
             RGBColor[
              0.1963124589116516, 0.3236672196179068, 0.934491076165537], 
             UndirectedEdge[87, 285] -> 
             RGBColor[
              0.2614000119680612, 0.39207836466940904`, 0.9381977160236936], 
             UndirectedEdge[211, 369] -> 
             RGBColor[
              0.1847549864301014, 0.3115195832537184, 0.933832895205461], 
             UndirectedEdge[164, 316] -> 
             RGBColor[
              0.37736919780669476`, 0.5012799648379501, 0.9452666094831315], 
             UndirectedEdge[27, 297] -> 
             RGBColor[
              0.19023703211735066`, 0.31728156085278936`, 0.93414508959739], 
             UndirectedEdge[238, 483] -> 
             RGBColor[
              0.46936492725835366`, 0.5800559392387936, 0.9513788548661433], 
             UndirectedEdge[109, 164] -> 
             RGBColor[
              0.2648306442899861, 0.3950111522821019, 0.9384177281820844], 
             UndirectedEdge[83, 355] -> 
             RGBColor[
              0.7774683536702185, 0.8228654453922359, 0.8436241428882965], 
             UndirectedEdge[85, 166] -> 
             RGBColor[
              0.19147571921883372`, 0.31858349953374643`, 0.9342156309953462],
              UndirectedEdge[34, 190] -> 
             RGBColor[
              0.2127364473424475, 0.3409298727996848, 0.9354263980095573], 
             UndirectedEdge[232, 383] -> 
             RGBColor[
              0.2731170371748888, 0.40439370106409095`, 0.938864983275437], 
             UndirectedEdge[185, 441] -> 
             RGBColor[
              0.21650425944697038`, 0.34489008221462353`, 0.9356409693349313],
              UndirectedEdge[83, 207] -> 
             RGBColor[
              0.9351069377955797, 0.7587606188367377, 0.47308258317377627`], 
             UndirectedEdge[138, 385] -> 
             RGBColor[
              0.18216276894964933`, 0.30879499832568225`, 0.9336852722547914],
              UndirectedEdge[131, 234] -> 
             RGBColor[
              0.88005378670787, 0.5030425365640092, 0.21977647609763581`], 
             UndirectedEdge[80, 81] -> 
             RGBColor[
              0.2928864737857844, 0.4215973242135559, 0.9401217329908362], 
             UndirectedEdge[5, 486] -> 
             RGBColor[
              0.5514554325451628, 0.6449264373888728, 0.9586262344361294], 
             UndirectedEdge[94, 139] -> 
             RGBColor[
              0.18076319755662762`, 0.3073239600536649, 0.9336055687344391], 
             UndirectedEdge[126, 249] -> 
             RGBColor[
              0.6077030059991793, 0.6911038805087482, 0.9631457140050295], 
             UndirectedEdge[359, 483] -> 
             RGBColor[
              0.6807834462506754, 0.7483260934744262, 0.970628611472146], 
             UndirectedEdge[275, 404] -> 
             RGBColor[
              0.663069657712535, 0.7345059792856424, 0.9686190519229416], 
             UndirectedEdge[313, 391] -> 
             RGBColor[
              0.4171675799720802, 0.5352137954636619, 0.9479510477022336], 
             UndirectedEdge[1, 487] -> 
             RGBColor[
              0.19600881958127922`, 0.3233480754298399, 0.9344737843548664], 
             UndirectedEdge[71, 172] -> 
             RGBColor[
              0.21061538458324242`, 0.3387005013566139, 0.9353056066232517], 
             UndirectedEdge[44, 494] -> 
             RGBColor[
              0.31715651234624226`, 0.44637751215671095`, 0.9415305739530406],
              UndirectedEdge[85, 387] -> 
             RGBColor[
              0.18808022272596522`, 0.31501461743282955`, 0.9340222624932641],
              UndirectedEdge[414, 499] -> 
             RGBColor[
              0.5256197261535013, 0.6249285409604874, 0.9560278119560052], 
             UndirectedEdge[89, 376] -> 
             RGBColor[
              0.3403951990959194, 0.4692549455218861, 0.9429106589801041], 
             UndirectedEdge[171, 403] -> 
             RGBColor[
              0.6070518602239434, 0.6903231179453404, 0.9632668381945488], 
             UndirectedEdge[161, 279] -> 
             RGBColor[
              0.21091668232154126`, 0.339017184382946, 0.9353227650837177], 
             UndirectedEdge[149, 310] -> 
             RGBColor[
              0.6029711284333774, 0.688520564735261, 0.9619129407159268], 
             UndirectedEdge[333, 367] -> 
             RGBColor[
              0.21446892121193922`, 0.34275081268170826`, 0.9355250598334595],
              UndirectedEdge[43, 227] -> 
             RGBColor[
              0.21076377490674741`, 0.3388564689951076, 0.9353140572326515], 
             UndirectedEdge[71, 369] -> 
             RGBColor[
              0.18988277528354555`, 0.3169092144592796, 0.9341249151947808], 
             UndirectedEdge[134, 174] -> 
             RGBColor[
              0.18580423451035571`, 0.31262240951223635`, 0.9338926483314081],
              UndirectedEdge[158, 370] -> 
             RGBColor[
              0.21023358203312498`, 0.3382992026687606, 0.9352838635328488], 
             UndirectedEdge[7, 391] -> 
             RGBColor[
              0.47273438056684836`, 0.582826092442144, 0.9516345286027679], 
             UndirectedEdge[200, 228] -> 
             RGBColor[
              0.26059605928059204`, 0.3912333594213344, 0.9381519321074836], 
             UndirectedEdge[201, 300] -> 
             RGBColor[
              0.24465748938560672`, 0.37448091189800614`, 0.9372442541309653],
              UndirectedEdge[210, 320] -> 
             RGBColor[
              0.18833104309187587`, 0.31527824554033135`, 0.9340365463420472],
              UndirectedEdge[69, 103] -> 
             RGBColor[
              0.4263301464035756, 0.5436874776637394, 0.9483863578332576], 
             UndirectedEdge[97, 281] -> 
             RGBColor[
              0.903440360362725, 0.5576720713111039, 0.28746666826170925`], 
             UndirectedEdge[192, 272] -> 
             RGBColor[
              0.28510804558804614`, 0.41660469339403305`, 0.9395622181414255],
              UndirectedEdge[70, 463] -> 
             RGBColor[
              0.4624511336723232, 0.5722084360335765, 0.9514519951932873], 
             UndirectedEdge[285, 477] -> 
             RGBColor[
              0.20609075774927643`, 0.3339448316762051, 0.935047935818643], 
             UndirectedEdge[10, 168] -> 
             RGBColor[
              0.25974966627430485`, 0.39034374670731053`, 0.9381037312779018],
              UndirectedEdge[298, 468] -> 
             RGBColor[
              0.24859500261068126`, 0.37861948795031725`, 0.9374684896841046],
              UndirectedEdge[37, 264] -> 
             RGBColor[
              0.8636993298194549, 0.4739723151879993, 0.20797971857725228`], 
             UndirectedEdge[191, 405] -> 
             RGBColor[
              0.18612791917026347`, 0.3129626226125922, 0.9339110816939413], 
             UndirectedEdge[349, 380] -> 
             RGBColor[
              0.18633207943578872`, 0.3131772079961678, 0.9339227083190349], 
             UndirectedEdge[94, 410] -> 
             RGBColor[
              0.18058759193707163`, 0.30713938741347224`, 0.9335955682541907],
              UndirectedEdge[335, 409] -> 
             RGBColor[
              0.23180434544224413`, 0.3609714426771376, 0.9365122865979134], 
             UndirectedEdge[168, 189] -> 
             RGBColor[
              0.272342262398906, 0.403579363650975, 0.9388208609981212], 
             UndirectedEdge[187, 399] -> 
             RGBColor[
              0.214562612650492, 0.3428492883240075, 0.9355303954222809], 
             UndirectedEdge[153, 314] -> 
             RGBColor[
              0.24522255976789442`, 0.3750748366973221, 0.93727643405329], 
             UndirectedEdge[233, 355] -> 
             RGBColor[
              0.7611336222299645, 0.8125163214181457, 0.9533731433112391], 
             UndirectedEdge[233, 486] -> 
             RGBColor[
              0.6879460003390702, 0.7520136698120249, 0.9479115120414208], 
             UndirectedEdge[49, 264] -> 
             RGBColor[
              0.9297344136885161, 0.7358812173257631, 0.3948314869060207], 
             UndirectedEdge[205, 331] -> 
             RGBColor[
              0.26945802412846753`, 0.40054784635747565`, 0.938656607895468], 
             UndirectedEdge[308, 456] -> 
             RGBColor[
              0.1932579406357965, 0.32045672724233865`, 0.9343171258684819], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.2456814749936662, 0.3755571856965141, 0.9373025685964933], 
             UndirectedEdge[175, 371] -> 
             RGBColor[
              0.32587980547058965`, 0.4516283990891108, 0.9421708041706565], 
             UndirectedEdge[21, 188] -> 
             RGBColor[
              0.26198974805947073`, 0.39269821469290833`, 0.9382313006216629],
              UndirectedEdge[79, 221] -> 
             RGBColor[
              0.9242610852428408, 0.8982704304455256, 0.6484794882507952], 
             UndirectedEdge[158, 193] -> 
             RGBColor[
              0.1863155768050812, 0.3131598626849669, 0.9339217685186295], 
             UndirectedEdge[266, 483] -> 
             RGBColor[
              0.722812081892279, 0.7773202768708386, 0.7464962569767426], 
             UndirectedEdge[290, 484] -> 
             RGBColor[
              0.18316922942285135`, 0.3098528520962973, 0.9337425886898154], 
             UndirectedEdge[153, 411] -> 
             RGBColor[
              0.2544232242601058, 0.38474531843445803`, 0.937800398284958], 
             UndirectedEdge[176, 475] -> 
             RGBColor[
              0.3267310397254062, 0.4574197374557666, 0.9420399908277568], 
             UndirectedEdge[20, 474] -> 
             RGBColor[
              0.2356355428107931, 0.36499827402342566`, 0.9367304676203037], 
             UndirectedEdge[70, 483] -> 
             RGBColor[
              0.41089196681220996`, 0.5303157024471664, 0.9474026506811422], 
             UndirectedEdge[163, 266] -> 
             RGBColor[
              0.9464459539298948, 0.8121746039800857, 0.3903304044915068], 
             UndirectedEdge[69, 486] -> 
             RGBColor[
              0.4280953978994323, 0.5452164497853305, 0.9484988380976231], 
             UndirectedEdge[262, 475] -> 
             RGBColor[
              0.33984798179840503`, 0.4687809734027203, 0.9428757907777918], 
             UndirectedEdge[18, 167] -> 
             RGBColor[
              0.2640882538669924, 0.39490387734956656`, 0.9383508074229403], 
             UndirectedEdge[281, 374] -> 
             RGBColor[
              0.8329341118682944, 0.254151592405362, 0.1791710487598251], 
             UndirectedEdge[138, 294] -> 
             RGBColor[
              0.18513103991648983`, 0.3119148393110808, 0.9338543108951896], 
             UndirectedEdge[291, 349] -> 
             RGBColor[
              0.1841373062547167, 0.310870362226204, 0.9337977192332487], 
             UndirectedEdge[288, 455] -> 
             RGBColor[
              0.6621340048611841, 0.7355343250121988, 0.9672660118228255], 
             UndirectedEdge[12, 459] -> 
             RGBColor[
              0.19425766410485237`, 0.3215074999944453, 0.9343740586410862], 
             UndirectedEdge[93, 305] -> 
             RGBColor[
              0.26659251557076086`, 0.3973687929461906, 0.9384995442473698], 
             UndirectedEdge[127, 184] -> 
             RGBColor[
              0.6864931860475436, 0.7535560913976342, 0.970424092580223], 
             UndirectedEdge[204, 431] -> 
             RGBColor[
              0.36857757870000185`, 0.49366510624735727`, 0.9447064152877764],
              UndirectedEdge[397, 495] -> 
             RGBColor[
              0.8540509182502993, 0.3729173999622112, 0.19768732648561016`], 
             UndirectedEdge[28, 493] -> 
             RGBColor[
              0.36837307735021396`, 0.48845315530283206`, 0.9450243190265064],
              UndirectedEdge[267, 485] -> 
             RGBColor[
              0.24230090955609868`, 0.3720039970814022, 0.9371100503959223], 
             UndirectedEdge[110, 494] -> 
             RGBColor[
              0.3861892329590033, 0.5089194359790232, 0.9458286143237857], 
             UndirectedEdge[337, 500] -> 
             RGBColor[
              0.1950373272242134, 0.32232697536639066`, 0.9344184593023257], 
             UndirectedEdge[43, 393] -> 
             RGBColor[
              0.2248422553763207, 0.3536538445958466, 0.9361158058681482], 
             UndirectedEdge[167, 432] -> 
             RGBColor[
              0.2655480887278028, 0.39643825634715435`, 0.9384339428586312], 
             UndirectedEdge[230, 474] -> 
             RGBColor[
              0.21770593124316456`, 0.3461531154628161, 0.9357094027660106], 
             UndirectedEdge[40, 421] -> 
             RGBColor[
              0.18467273781712776`, 0.31143313474661993`, 0.933828211268628], 
             UndirectedEdge[254, 476] -> 
             RGBColor[
              0.18792976264725234`, 0.31485647435038233`, 0.9340136940143672],
              UndirectedEdge[107, 197] -> 
             RGBColor[
              0.221090097802618, 0.3497100890853544, 0.9359021260451457], 
             UndirectedEdge[231, 395] -> 
             RGBColor[
              0.6338994865668826, 0.711809040751297, 0.9655924600995638], 
             UndirectedEdge[420, 427] -> 
             RGBColor[
              0.1872793778515779, 0.31417287869335075`, 0.9339766555624116], 
             UndirectedEdge[317, 374] -> 
             RGBColor[
              0.832381649136102, 0.24990512175501872`, 0.1786420098235603], 
             UndirectedEdge[188, 200] -> 
             RGBColor[
              0.24347605986022197`, 0.37323915455986845`, 0.937176973467263], 
             UndirectedEdge[84, 260] -> 
             RGBColor[
              0.24263313262389596`, 0.37235318458981626`, 0.9371289700081534],
              UndirectedEdge[33, 160] -> 
             RGBColor[
              0.24786010554572385`, 0.3778470645398819, 0.937426638383438], 
             UndirectedEdge[135, 362] -> 
             RGBColor[
              0.1796163784049865, 0.3061185804127562, 0.9335402590803201], 
             UndirectedEdge[123, 193] -> 
             RGBColor[
              0.18338517057960285`, 0.31007981994350325`, 0.9337548862192361],
              UndirectedEdge[439, 453] -> 
             RGBColor[
              0.21958035723127328`, 0.3481232560217902, 0.9358161485530685], 
             UndirectedEdge[269, 282] -> 
             RGBColor[
              0.6492936360498982, 0.7253322095338435, 0.966103200750267], 
             UndirectedEdge[202, 459] -> 
             RGBColor[
              0.19062008977227754`, 0.3176841787353756, 0.9341669041641552], 
             UndirectedEdge[25, 474] -> 
             RGBColor[
              0.2592041913656412, 0.3897704179931982, 0.9380726672888113], 
             UndirectedEdge[103, 259] -> 
             RGBColor[
              0.5465386609637427, 0.6409354738239997, 0.9581996401022647], 
             UndirectedEdge[352, 375] -> 
             RGBColor[
              0.19306738802691092`, 0.32025644436866674`, 0.9343062741793031],
              UndirectedEdge[300, 308] -> 
             RGBColor[
              0.21138383769744212`, 0.33950819430237933`, 0.9353493688912808],
              UndirectedEdge[32, 328] -> 
             RGBColor[
              0.23132945208889125`, 0.36047229965278604`, 0.9364852421239818],
              UndirectedEdge[209, 486] -> 
             RGBColor[
              0.7039053523851265, 0.7622075647598039, 0.8443835196310663], 
             UndirectedEdge[118, 496] -> 
             RGBColor[
              0.18901315212113398`, 0.315995185378292, 0.9340753914421738], 
             UndirectedEdge[31, 405] -> 
             RGBColor[
              0.18682010932019663`, 0.3136901583475623, 0.9339505008989764], 
             UndirectedEdge[21, 228] -> 
             RGBColor[
              0.2791097474798408, 0.4106924195543743, 0.9392062592618835], 
             UndirectedEdge[92, 250] -> 
             RGBColor[
              0.24579035153480303`, 0.3756716218444204, 0.9373087689544427], 
             UndirectedEdge[177, 290] -> 
             RGBColor[
              0.1829544926129004, 0.3096271500939387, 0.9337303597461633], 
             UndirectedEdge[9, 333] -> 
             RGBColor[
              0.21279008452790313`, 0.3409862488823926, 0.9354294525679199], 
             UndirectedEdge[11, 444] -> 
             RGBColor[
              0.4707188799474499, 0.5790788770403041, 0.9520591203545818], 
             UndirectedEdge[11, 25] -> 
             RGBColor[
              0.3322342574825351, 0.46035097441527295`, 0.9424578530175007], 
             UndirectedEdge[168, 338] -> 
             RGBColor[
              0.35852241644491945`, 0.4834734222788186, 0.944119987452004], 
             UndirectedEdge[283, 430] -> 
             RGBColor[
              0.19193681077273775`, 0.31906813599179257`, 0.9342418894772171],
              UndirectedEdge[139, 410] -> 
             RGBColor[
              0.18242378949369925`, 0.3090693474671371, 0.9337001369886297], 
             UndirectedEdge[195, 260] -> 
             RGBColor[
              0.1989228362357199, 0.32641089169298415`, 0.9346397332924354], 
             UndirectedEdge[391, 407] -> 
             RGBColor[
              0.3751221590981358, 0.49587301171236503`, 0.9453789816308452], 
             UndirectedEdge[33, 111] -> 
             RGBColor[
              0.3114314409456971, 0.4393163564982453, 0.9412427561367012], 
             UndirectedEdge[2, 114] -> 
             RGBColor[
              0.1828144030828347, 0.30947990711565043`, 0.93372238185467], 
             UndirectedEdge[101, 306] -> 
             RGBColor[
              0.24294061497845892`, 0.37267636803996923`, 0.9371464806733664],
              UndirectedEdge[264, 374] -> 
             RGBColor[
              0.8564940987621058, 0.42401565884056125`, 0.20129244608671454`],
              UndirectedEdge[172, 235] -> 
             RGBColor[
              0.22030500109104192`, 0.3488849026634814, 0.9358574159488678], 
             UndirectedEdge[84, 475] -> 
             RGBColor[
              0.3060220283144641, 0.4364102420981715, 0.9408329262010071], 
             UndirectedEdge[37, 397] -> 
             RGBColor[
              0.8419322626018511, 0.3178894150465442, 0.18757522315711248`], 
             UndirectedEdge[228, 287] -> 
             RGBColor[
              0.28118525934636124`, 0.41287391412114016`, 0.9393244565922372],
              UndirectedEdge[68, 375] -> 
             RGBColor[
              0.19408512083298096`, 0.3213261460758332, 0.9343642325570081], 
             UndirectedEdge[197, 236] -> 
             RGBColor[
              0.21962655292817068`, 0.3481718106282057, 0.9358187793296664], 
             UndirectedEdge[107, 214] -> 
             RGBColor[
              0.19941582681621922`, 0.32692905605049705`, 0.9346678083766806],
              UndirectedEdge[207, 317] -> 
             RGBColor[
              0.8461530053131936, 0.3296770187137239, 0.19080821806446593`], 
             UndirectedEdge[98, 462] -> 
             RGBColor[
              0.18918443929913709`, 0.3161752190626076, 0.9340851459935643], 
             UndirectedEdge[21, 59] -> 
             RGBColor[
              0.2814993677631707, 0.4132040619828309, 0.9393423446018928], 
             UndirectedEdge[46, 350] -> 
             RGBColor[
              0.1926173329949277, 0.3197834079949152, 0.9342806442110285], 
             UndirectedEdge[271, 429] -> 
             RGBColor[
              0.200022442914419, 0.32756664803138713`, 0.9347023542660651], 
             UndirectedEdge[304, 423] -> 
             RGBColor[
              0.1849544721508512, 0.3117292553943517, 0.9338442556221451], 
             UndirectedEdge[299, 328] -> 
             RGBColor[
              0.24152994730330735`, 0.3711936668718884, 0.9370661452361624], 
             UndirectedEdge[55, 73] -> 
             RGBColor[
              0.5752457926482104, 0.6660494748562806, 0.9597046024734881], 
             UndirectedEdge[53, 440] -> 
             RGBColor[
              0.8621535838667478, 0.42648384520047466`, 0.20510522227510283`],
              UndirectedEdge[206, 377] -> 
             RGBColor[
              0.18060293034985866`, 0.30715550905782296`, 0.9335964417541076],
              UndirectedEdge[39, 113] -> 
             RGBColor[
              0.2221538791632596, 0.3508281907430225, 0.9359627068199107], 
             UndirectedEdge[9, 450] -> 
             RGBColor[
              0.20465923888359105`, 0.3324402145848314, 0.9349664129369846], 
             UndirectedEdge[61, 321] -> 
             RGBColor[
              0.9878470936878512, 0.9892424751715496, 0.8510686385130581], 
             UndirectedEdge[76, 460] -> 
             RGBColor[
              0.35555086797246704`, 0.4816356758279989, 0.9439036922676769], 
             UndirectedEdge[141, 167] -> 
             RGBColor[
              0.22358607838206196`, 0.35233352292865905`, 0.9360442684466725],
              UndirectedEdge[29, 476] -> 
             RGBColor[
              0.18392969470854525`, 0.3106521493278456, 0.933785896062828], 
             UndirectedEdge[39, 190] -> 
             RGBColor[
              0.23206747524414745`, 0.361248008782331, 0.9365272714508661], 
             UndirectedEdge[115, 215] -> 
             RGBColor[
              0.18797465353578718`, 0.3149036575204792, 0.9340162504840592], 
             UndirectedEdge[208, 471] -> 
             RGBColor[
              0.6917256837597572, 0.7556316908196963, 0.953176466827428], 
             UndirectedEdge[139, 401] -> 
             RGBColor[
              0.18166335927375138`, 0.3082700870919113, 0.9336568316125594], 
             UndirectedEdge[34, 356] -> 
             RGBColor[
              0.22712257342383618`, 0.3560506034443001, 0.9362456666075261], 
             UndirectedEdge[288, 313] -> 
             RGBColor[
              0.5362219144016962, 0.6308125527023426, 0.9580446920208532], 
             UndirectedEdge[66, 334] -> 
             RGBColor[
              0.19236874220933842`, 0.3195221233176947, 0.9342664873335462], 
             UndirectedEdge[17, 328] -> 
             RGBColor[
              0.30921498256740126`, 0.43616829316491434`, 0.9411464986611078],
              UndirectedEdge[318, 459] -> 
             RGBColor[
              0.1962304097370451, 0.3235809807331772, 0.934486403586424], 
             UndirectedEdge[163, 233] -> 
             RGBColor[
              0.9309329686428551, 0.8036306761921264, 0.5929788217369941], 
             UndirectedEdge[141, 300] -> 
             RGBColor[
              0.21958614921582648`, 0.3481293437647886, 0.9358164783980203], 
             UndirectedEdge[354, 436] -> 
             RGBColor[
              0.33305431044836165`, 0.46289663673916315`, 0.9424429040467747],
              UndirectedEdge[29, 290] -> 
             RGBColor[
              0.18297797671513846`, 0.309651833374369, 0.9337316971310441], 
             UndirectedEdge[110, 360] -> 
             RGBColor[
              0.5066197555658096, 0.6093517092932348, 0.9545740073553726], 
             UndirectedEdge[289, 308] -> 
             RGBColor[
              0.20048868170692968`, 0.3280566945635627, 0.9347289058755601], 
             UndirectedEdge[264, 324] -> 
             RGBColor[
              0.9026383334956752, 0.7184607257731993, 0.5982098779593608], 
             UndirectedEdge[109, 382] -> 
             RGBColor[
              0.2128528625805422, 0.3410522325960747, 0.9354330276851459], 
             UndirectedEdge[293, 497] -> 
             RGBColor[
              0.6439655477048442, 0.7192750682039972, 0.9668676305891115], 
             UndirectedEdge[160, 237] -> 
             RGBColor[
              0.23616950031855627`, 0.3655594972189461, 0.9367608757104513], 
             UndirectedEdge[35, 123] -> 
             RGBColor[
              0.18674780810963457`, 0.3136141651911, 0.933946383451995], 
             UndirectedEdge[218, 432] -> 
             RGBColor[
              0.28855483307734864`, 0.4206198033703701, 0.9397441429139097], 
             UndirectedEdge[46, 476] -> 
             RGBColor[
              0.1935701933686142, 0.32078492466249675`, 0.9343349081996792], 
             UndirectedEdge[288, 391] -> 
             RGBColor[
              0.5921690661844405, 0.6787336359098497, 0.9617581155601771], 
             UndirectedEdge[259, 486] -> 
             RGBColor[
              0.5483039124595994, 0.6424644459455908, 0.95831212036663], 
             UndirectedEdge[138, 296] -> 
             RGBColor[
              0.18249965208881352`, 0.3091490838645686, 0.9337044572511928], 
             UndirectedEdge[56, 494] -> 
             RGBColor[
              0.38107496711151867`, 0.5044897159524077, 0.9455027378263516], 
             UndirectedEdge[91, 200] -> 
             RGBColor[
              0.3616498178113511, 0.4832425921885635, 0.9444724938641782], 
             UndirectedEdge[172, 493] -> 
             RGBColor[
              0.24219838800103033`, 0.3718962404267834, 0.9371042119450282], 
             UndirectedEdge[340, 461] -> 
             RGBColor[
              0.30853231078714655`, 0.43652792912541416`, 0.9410681811421904],
              UndirectedEdge[33, 274] -> 
             RGBColor[
              0.25017787666220814`, 0.38028318893848334`, 0.9375586320196867],
              UndirectedEdge[235, 345] -> 
             RGBColor[
              0.20397947873922884`, 0.3317257435738243, 0.934927701602378], 
             UndirectedEdge[205, 490] -> 
             RGBColor[
              0.22672461704495903`, 0.3556323260582085, 0.9362230035804727], 
             UndirectedEdge[141, 284] -> 
             RGBColor[
              0.20706959880896725`, 0.33497365569204784`, 0.9351036793689267],
              UndirectedEdge[489, 500] -> 
             RGBColor[
              0.19630488377124938`, 0.3236592576650523, 0.9344906447724974], 
             UndirectedEdge[155, 198] -> 
             RGBColor[
              0.1881672276861966, 0.31510606516246586`, 0.934027217297037], 
             UndirectedEdge[23, 157] -> 
             RGBColor[
              0.36552292420320903`, 0.49012707749646917`, 0.944544444701912], 
             UndirectedEdge[248, 344] -> 
             RGBColor[
              0.18527438940385826`, 0.31206550871118754`, 0.9338624744364286],
              UndirectedEdge[50, 131] -> 
             RGBColor[
              0.8570462990670573, 0.5838526913273292, 0.5841917648474512], 
             UndirectedEdge[442, 500] -> 
             RGBColor[
              0.21944649774055142`, 0.34798256120985954`, 0.9358085254530993],
              UndirectedEdge[18, 305] -> 
             RGBColor[
              0.2994340109078254, 0.43188728681651606`, 0.9403698188221772], 
             UndirectedEdge[134, 278] -> 
             RGBColor[
              0.18429769316254274`, 0.3110389390354465, 0.9338068530303782], 
             UndirectedEdge[158, 422] -> 
             RGBColor[
              0.19912370802149765`, 0.3266220206758434, 0.9346511726434723], 
             UndirectedEdge[229, 393] -> 
             RGBColor[
              0.2280783028843851, 0.35705513570408476`, 0.9363000939864292], 
             UndirectedEdge[17, 143] -> 
             RGBColor[
              0.4780476426696782, 0.5850251620356237, 0.9526370440612968], 
             UndirectedEdge[53, 83] -> 
             RGBColor[
              0.9139507635332944, 0.6222257740273145, 0.45384466479453006`], 
             UndirectedEdge[166, 239] -> 
             RGBColor[
              0.19616306235610437`, 0.3235101943657379, 0.9344825682527109], 
             UndirectedEdge[46, 194] -> 
             RGBColor[
              0.19490869460205182`, 0.32219177432471957`, 0.9344111338647885],
              UndirectedEdge[319, 368] -> 
             RGBColor[
              0.18004736950714773`, 0.30657157938754187`, 0.9335648033859939],
              UndirectedEdge[51, 360] -> 
             RGBColor[
              0.7957080349438885, 0.8376426800925825, 0.8429962638681049], 
             UndirectedEdge[132, 250] -> 
             RGBColor[
              0.24597806511608875`, 0.3758689207200801, 0.9373194589651996], 
             UndirectedEdge[80, 447] -> 
             RGBColor[
              0.2905728038348803, 0.41916551040000816`, 0.9399899729099002], 
             UndirectedEdge[128, 179] -> 
             RGBColor[
              0.19718406775789482`, 0.32458333577850107`, 0.9345407129999008],
              UndirectedEdge[218, 300] -> 
             RGBColor[
              0.25886995308296373`, 0.3894191123661732, 0.938053632913074], 
             UndirectedEdge[130, 241] -> 
             RGBColor[
              0.2592745192308342, 0.38984433703856036`, 0.9380766723566932], 
             UndirectedEdge[134, 252] -> 
             RGBColor[
              0.18321908491971373`, 0.3099052533845207, 0.9337454278866071], 
             UndirectedEdge[266, 317] -> 
             RGBColor[
              0.9054511863291719, 0.561405403936883, 0.35359294828676574`], 
             UndirectedEdge[156, 485] -> 
             RGBColor[
              0.22736985486258326`, 0.3563105119149721, 0.9362597489196426], 
             UndirectedEdge[96, 110] -> 
             RGBColor[
              0.443925135446012, 0.558453392319533, 0.9496384572015815], 
             UndirectedEdge[50, 373] -> 
             RGBColor[
              0.9356814566362912, 0.9489939738190079, 0.8936373423891573], 
             UndirectedEdge[37, 322] -> 
             RGBColor[
              0.8413185031158885, 0.3131717906863145, 0.18698748638021256`], 
             UndirectedEdge[65, 290] -> 
             RGBColor[
              0.18235293121758706`, 0.308994870926269, 0.9336961017146306], 
             UndirectedEdge[333, 450] -> 
             RGBColor[
              0.22365738515605757`, 0.35240847086923904`, 0.9360483292619628],
              UndirectedEdge[238, 266] -> 
             RGBColor[
              0.7401362180244184, 0.7914194702417209, 0.7478504944629321], 
             UndirectedEdge[312, 446] -> 
             RGBColor[
              0.18918799273524178`, 0.31617895394925455`, 0.9340853483564936],
              UndirectedEdge[407, 448] -> 
             RGBColor[
              0.28885681920654693`, 0.42093720993918393`, 0.9397613405772192],
              UndirectedEdge[14, 454] -> 
             RGBColor[
              0.2211862721127522, 0.34981117438310894`, 0.9359076030298306], 
             UndirectedEdge[77, 473] -> 
             RGBColor[
              0.2990309117164457, 0.42925265730827966`, 0.9404278165088418], 
             UndirectedEdge[57, 136] -> 
             RGBColor[
              0.7454315064099696, 0.7997658817940283, 0.9520631322982614], 
             UndirectedEdge[364, 487] -> 
             RGBColor[
              0.19856599617315254`, 0.3260358301622591, 0.9346194117787698], 
             UndirectedEdge[80, 403] -> 
             RGBColor[
              0.5454124576914773, 0.6374059872808763, 0.9592088642229862], 
             UndirectedEdge[330, 352] -> 
             RGBColor[
              0.1864863756783814, 0.3133393831300794, 0.9339314952617896], 
             UndirectedEdge[239, 272] -> 
             RGBColor[
              0.22693559422031087`, 0.3558540764462288, 0.9362350184184962], 
             UndirectedEdge[53, 97] -> 
             RGBColor[
              0.910565728681441, 0.6124407745650613, 0.29428992901066414`], 
             UndirectedEdge[304, 311] -> 
             RGBColor[
              0.19034681505715081`, 0.3173969496831598, 0.9341513415734024], 
             UndirectedEdge[237, 241] -> 
             RGBColor[
              0.2242600552960576, 0.35304191539787294`, 0.9360826504348652], 
             UndirectedEdge[361, 441] -> 
             RGBColor[
              0.22578416559546857`, 0.3546438519567282, 0.9361694462616974], 
             UndirectedEdge[276, 347] -> 
             RGBColor[
              0.20833762491305394`, 0.33630643152494155`, 0.935175891579678], 
             UndirectedEdge[11, 180] -> 
             RGBColor[
              0.31935935180321817`, 0.4468186322301426, 0.9417246461857798], 
             UndirectedEdge[56, 360] -> 
             RGBColor[
              0.501505489718325, 0.6049219892666192, 0.9542481308579387], 
             UndirectedEdge[15, 269] -> 
             RGBColor[
              0.6271401903527347, 0.708025769382796, 0.9638951523188943], 
             UndirectedEdge[8, 387] -> 
             RGBColor[
              0.19318868595476607`, 0.32038393618157524`, 0.9343131819168503],
              UndirectedEdge[139, 278] -> 
             RGBColor[
              0.18353174179525936`, 0.31023387558431004`, 0.933763233233135], 
             UndirectedEdge[15, 449] -> 
             RGBColor[
              0.8180065894164226, 0.8423738625918746, 0.678402399648858], 
             UndirectedEdge[348, 355] -> 
             RGBColor[
              0.5108951424447806, 0.6138067180573811, 0.9546386835652754], 
             UndirectedEdge[173, 499] -> 
             RGBColor[
              0.6745850298425644, 0.7454990333041416, 0.9683443785997534], 
             UndirectedEdge[130, 483] -> 
             RGBColor[
              0.3774799425420655, 0.5008371490852502, 0.9452933918504961], 
             UndirectedEdge[173, 282] -> 
             RGBColor[
              0.7086553123271468, 0.7723261830606026, 0.9715957968385069], 
             UndirectedEdge[84, 244] -> 
             RGBColor[
              0.3611185636561085, 0.4841320917787186, 0.9443436287130234], 
             UndirectedEdge[183, 279] -> 
             RGBColor[
              0.202473790723394, 0.3301431700030478, 0.9348419548973421], 
             UndirectedEdge[124, 381] -> 
             RGBColor[
              0.18683393328431724`, 0.31370468821034303`, 0.9339512881532823],
              UndirectedEdge[81, 213] -> 
             RGBColor[
              0.2202872137263247, 0.3488662070153795, 0.9358564029847612], 
             UndirectedEdge[134, 210] -> 
             RGBColor[
              0.18982747480213708`, 0.31685109014706625`, 0.9341217659141743],
              UndirectedEdge[103, 275] -> 
             RGBColor[
              0.4495582322834861, 0.5628291466682479, 0.9501364705331162], 
             UndirectedEdge[256, 298] -> 
             RGBColor[
              0.2936230158270692, 0.42568683963093007`, 0.9400422862891433], 
             UndirectedEdge[18, 235] -> 
             RGBColor[
              0.2527156376053866, 0.3829505365931011, 0.9377031537511198], 
             UndirectedEdge[255, 334] -> 
             RGBColor[
              0.19201279446501912`, 0.3191479996700246, 0.9342462166360848], 
             UndirectedEdge[209, 372] -> 
             RGBColor[
              0.8043736512463036, 0.8448578989108925, 0.8519927857243978], 
             UndirectedEdge[112, 238] -> 
             RGBColor[
              0.7400652706680888, 0.7928555147204785, 0.8555441529553656], 
             UndirectedEdge[360, 457] -> 
             RGBColor[
              0.5327073882194472, 0.6315148818077295, 0.9563558234535461], 
             UndirectedEdge[233, 404] -> 
             RGBColor[
              0.8996921742722623, 0.9221615303078283, 0.9662816131668808], 
             UndirectedEdge[259, 348] -> 
             RGBColor[
              0.5726768344196096, 0.6633371250706486, 0.9599308796437516], 
             UndirectedEdge[244, 376] -> 
             RGBColor[
              0.40891528656398646`, 0.5286036013669932, 0.947276698363635], 
             UndirectedEdge[182, 371] -> 
             RGBColor[
              0.29953966949074173`, 0.42881389719709484`, 0.9404924339976882],
              UndirectedEdge[21, 77] -> 
             RGBColor[
              0.3172353767281449, 0.44838670426532234`, 0.9414645338601655], 
             UndirectedEdge[153, 493] -> 
             RGBColor[
              0.24427091854425903`, 0.3740746014337428, 0.9372222394934309], 
             UndirectedEdge[276, 382] -> 
             RGBColor[
              0.21283416100439742`, 0.3410325760537981, 0.935431962658051], 
             UndirectedEdge[80, 219] -> 
             RGBColor[
              0.508471196315639, 0.6085471931300863, 0.9555269045247576], 
             UndirectedEdge[60, 136] -> 
             RGBColor[
              0.7568575398761165, 0.8080712748113279, 0.923043362246632], 
             UndirectedEdge[23, 96] -> 
             RGBColor[
              0.4513622669101063, 0.5648950617926353, 0.9501123446420765], 
             UndirectedEdge[53, 281] -> 
             RGBColor[
              0.8255492937831006, 0.19738864455464403`, 0.17209933862148452`],
              UndirectedEdge[141, 162] -> 
             RGBColor[
              0.19531753931264573`, 0.32262149603780554`, 0.9344344169662252],
              UndirectedEdge[28, 149] -> 
             RGBColor[
              0.5184855433089055, 0.6199689474225398, 0.9552362277258538], 
             UndirectedEdge[37, 317] -> 
             RGBColor[
              0.839586880193451, 0.2998617781024568, 0.18532928231409804`], 
             UndirectedEdge[372, 486] -> 
             RGBColor[
              0.5138028974550533, 0.6150817214772912, 0.955167559111667], 
             UndirectedEdge[63, 453] -> 
             RGBColor[
              0.2233707740920417, 0.35210722446876735`, 0.9360320071858701], 
             UndirectedEdge[82, 242] -> 
             RGBColor[
              0.7466175241184303, 0.8003829212442619, 0.9428810481338523], 
             UndirectedEdge[4, 191] -> 
             RGBColor[
              0.18605432886244289`, 0.31288527453317777`, 0.933906890834778], 
             UndirectedEdge[70, 403] -> 
             RGBColor[
              0.5565760155932599, 0.6470753000386655, 0.9599201962609412], 
             UndirectedEdge[144, 458] -> 
             RGBColor[
              0.21795043797046626`, 0.346410107535832, 0.935723327062415], 
             UndirectedEdge[16, 224] -> 
             RGBColor[
              0.23802549514267946`, 0.3675102654559681, 0.9368665718699869], 
             UndirectedEdge[40, 206] -> 
             RGBColor[
              0.18271148860033518`, 0.3093717374693884, 0.9337165210271399], 
             UndirectedEdge[148, 485] -> 
             RGBColor[
              0.26499013859378384`, 0.39585181538021874`, 0.9384021684239121],
              UndirectedEdge[34, 291] -> 
             RGBColor[
              0.19600418397695138`, 0.323343203115777, 0.9344735203640577], 
             UndirectedEdge[222, 339] -> 
             RGBColor[
              0.1886442457825459, 0.3156074414264231, 0.9340543827719392], 
             UndirectedEdge[197, 314] -> 
             RGBColor[
              0.24685083225448304`, 0.3767862543191651, 0.9373691617625879], 
             UndirectedEdge[330, 358] -> 
             RGBColor[
              0.20723187960885475`, 0.33514422310192665`, 0.9351129210204074],
              UndirectedEdge[312, 415] -> 
             RGBColor[
              0.18768399799751473`, 0.31459816012112934`, 0.9339996980811409],
              UndirectedEdge[370, 443] -> 
             RGBColor[
              0.2582982777745515, 0.38881824537072385`, 0.9380210768499777], 
             UndirectedEdge[160, 305] -> 
             RGBColor[
              0.2750017432650342, 0.40620742442870245`, 0.938978437324221], 
             UndirectedEdge[266, 343] -> 
             RGBColor[
              0.9199069923129997, 0.6725190633031569, 0.3674358444223769], 
             UndirectedEdge[47, 468] -> 
             RGBColor[
              0.25155549363265645`, 0.38173115172038535`, 0.9376370852681521],
              UndirectedEdge[388, 436] -> 
             RGBColor[
              0.34210441687378856`, 0.470735384053293, 0.943019568825508], 
             UndirectedEdge[69, 209] -> 
             RGBColor[
              0.7186661516906826, 0.7749926272189318, 0.8453240647103539], 
             UndirectedEdge[197, 470] -> 
             RGBColor[
              0.2127537879512197, 0.3409480988789625, 0.9354273855315738], 
             UndirectedEdge[13, 298] -> 
             RGBColor[
              0.26431690444041933`, 0.3951442035995219, 0.9383638287348387], 
             UndirectedEdge[168, 383] -> 
             RGBColor[
              0.2802434761765292, 0.4118840402971449, 0.9392708234339586], 
             UndirectedEdge[123, 428] -> 
             RGBColor[
              0.18681025928894113`, 0.3136798053401847, 0.9339499399542682], 
             UndirectedEdge[137, 485] -> 
             RGBColor[
              0.2335003285987162, 0.3627540285061326, 0.9366088703296922], 
             UndirectedEdge[394, 467] -> 
             RGBColor[
              0.18730056337306505`, 0.3141951460196734, 0.9339778620465191], 
             UndirectedEdge[232, 395] -> 
             RGBColor[
              0.3913003181998807, 0.5091662530135891, 0.9466381048606165], 
             UndirectedEdge[414, 461] -> 
             RGBColor[
              0.337969115719834, 0.4620246100212727, 0.9429438683225567], 
             UndirectedEdge[224, 333] -> 
             RGBColor[
              0.21886126221320776`, 0.3473674415645458, 0.9357751971555954], 
             UndirectedEdge[33, 182] -> 
             RGBColor[
              0.300634259036329, 0.42996438021049266`, 0.9405547692530093], 
             UndirectedEdge[158, 451] -> 
             RGBColor[
              0.19839700824460316`, 0.32585821313490027`, 0.9346097881662341],
              UndirectedEdge[235, 274] -> 
             RGBColor[
              0.23060114107907964`, 0.35970679860388893`, 0.9364437658894125],
              UndirectedEdge[284, 345] -> 
             RGBColor[
              0.19883561542773992`, 0.32631921709367856`, 0.9346347661964527],
              UndirectedEdge[70, 238] -> 
             RGBColor[
              0.4282161029443493, 0.5444148958180487, 0.9487568881673315], 
             UndirectedEdge[21, 55] -> 
             RGBColor[
              0.4367980074447999, 0.5486800919411015, 0.9499852964304927], 
             UndirectedEdge[55, 60] -> 
             RGBColor[
              0.7795430416292072, 0.8264883871046946, 0.9248292480443663], 
             UndirectedEdge[219, 258] -> 
             RGBColor[
              0.5423535654058886, 0.6378943982586738, 0.9576858591221857], 
             UndirectedEdge[175, 463] -> 
             RGBColor[
              0.476418269168048, 0.5843060667913316, 0.9523419687164218], 
             UndirectedEdge[101, 431] -> 
             RGBColor[
              0.33318158758536665`, 0.45712340432410575`, 0.9426664368181881],
              UndirectedEdge[14, 213] -> 
             RGBColor[
              0.21659885926136652`, 0.3449895126175285, 0.9356463566544133], 
             UndirectedEdge[378, 487] -> 
             RGBColor[
              0.1998521204053707, 0.32738762827530654`, 0.9346926546511444], 
             UndirectedEdge[8, 159] -> 
             RGBColor[
              0.21480140592500557`, 0.34310027519588937`, 0.9355439943460016],
              UndirectedEdge[311, 469] -> 
             RGBColor[
              0.18566856806308635`, 0.31247981547440673`, 0.9338849223279366],
              UndirectedEdge[343, 440] -> 
             RGBColor[
              0.8689315587996673, 0.47858233066244793`, 0.21159581872549427`],
              UndirectedEdge[371, 460] -> 
             RGBColor[
              0.2773778998424177, 0.4088721378819603, 0.9391076331009713], 
             UndirectedEdge[224, 358] -> 
             RGBColor[
              0.21540867556861554`, 0.34373855409444265`, 0.9355785774538301],
              UndirectedEdge[455, 475] -> 
             RGBColor[
              0.47478660322499994`, 0.5813210731496465, 0.9526722731511402], 
             UndirectedEdge[310, 408] -> 
             RGBColor[
              0.7910483812120712, 0.837599492064294, 0.9781391837091735], 
             UndirectedEdge[154, 376] -> 
             RGBColor[
              0.6772879972861523, 0.7415239884313045, 0.9288688968046623], 
             UndirectedEdge[282, 499] -> 
             RGBColor[
              0.6626431389741363, 0.7361699373959933, 0.9671541225213036], 
             UndirectedEdge[14, 192] -> 
             RGBColor[
              0.27198473276549623`, 0.40281125955144237`, 0.9388148648903828],
              UndirectedEdge[75, 147] -> 
             RGBColor[
              0.842199332426149, 0.3144945905899744, 0.187617653595973], 
             UndirectedEdge[175, 351] -> 
             RGBColor[
              0.3189338999580072, 0.4443278119995411, 0.9417752451272612], 
             UndirectedEdge[109, 205] -> 
             RGBColor[
              0.22555863330001114`, 0.354406803214629, 0.9361566025311163], 
             UndirectedEdge[43, 148] -> 
             RGBColor[
              0.2515020287225457, 0.38167495670998786`, 0.9376340405206155], 
             UndirectedEdge[56, 92] -> 
             RGBColor[
              0.33939325721103675`, 0.46498406565042605`, 0.9429714183929231],
              UndirectedEdge[46, 412] -> 
             RGBColor[
              0.19698300619667852`, 0.32437200732962346`, 0.9345292628414335],
              UndirectedEdge[170, 214] -> 
             RGBColor[
              0.18764009951956995`, 0.31455202003748506`, 0.9339971981277639],
              UndirectedEdge[94, 437] -> 
             RGBColor[
              0.18042329707310156`, 0.30696670309454366`, 0.93358621190474], 
             UndirectedEdge[173, 249] -> 
             RGBColor[
              0.72377347409997, 0.7841366059398172, 0.9731026339167677], 
             UndirectedEdge[181, 302] -> 
             RGBColor[
              0.235139155224241, 0.3644765391971686, 0.9367021990815891], 
             UndirectedEdge[188, 279] -> 
             RGBColor[
              0.21597972805042376`, 0.3443387664596417, 0.9356110980478727], 
             UndirectedEdge[317, 471] -> 
             RGBColor[
              0.8870778332354172, 0.5507282185220981, 0.561083222125617], 
             UndirectedEdge[8, 344] -> 
             RGBColor[
              0.19388121074334685`, 0.3211118236429813, 0.9343526201790614], 
             UndirectedEdge[236, 493] -> 
             RGBColor[
              0.23463204109374153`, 0.36394353009312075`, 0.9366733196820654],
              UndirectedEdge[31, 366] -> 
             RGBColor[
              0.18726891335142604`, 0.3141618798402035, 0.9339760596246088], 
             UndirectedEdge[176, 261] -> 
             RGBColor[
              0.32311312036066653`, 0.4542860775439437, 0.941809460205036], 
             UndirectedEdge[144, 145] -> 
             RGBColor[
              0.20296158096381922`, 0.33065586847342227`, 0.9348697338299133],
              UndirectedEdge[144, 375] -> 
             RGBColor[
              0.1998107076045579, 0.3273441007959291, 0.9346902962534028], 
             UndirectedEdge[258, 293] -> 
             RGBColor[
              0.6124648264838737, 0.6926658482781156, 0.9646738943994533], 
             UndirectedEdge[242, 269] -> 
             RGBColor[
              0.787493374586991, 0.8335677780907182, 0.9460989448159113], 
             UndirectedEdge[45, 216] -> 
             RGBColor[
              0.20054621348510776`, 0.32811716411015324`, 0.9347321822252167],
              UndirectedEdge[82, 323] -> 
             RGBColor[
              0.7564161337880024, 0.8062755394340282, 0.8629204050270508], 
             UndirectedEdge[258, 272] -> 
             RGBColor[
              0.33620380123362575`, 0.46086126878688316`, 0.9428179945089592],
              UndirectedEdge[92, 356] -> 
             RGBColor[
              0.2586276684650108, 0.3891644558709726, 0.9380398351625095], 
             UndirectedEdge[114, 327] -> 
             RGBColor[
              0.18260674360457746`, 0.3092616438376308, 0.933710555954588], 
             UndirectedEdge[188, 459] -> 
             RGBColor[
              0.20922832641301886`, 0.3372426152751415, 0.9352266157124262], 
             UndirectedEdge[465, 469] -> 
             RGBColor[
              0.18020092681290795`, 0.30673297785199133`, 0.9335735482473893],
              UndirectedEdge[44, 62] -> 
             RGBColor[
              0.2651018322525842, 0.3959692124974049, 0.9384085292125448], 
             UndirectedEdge[88, 337] -> 
             RGBColor[
              0.18932246677623382`, 0.3163202946924838, 0.9340930064541916], 
             UndirectedEdge[253, 388] -> 
             RGBColor[
              0.3530902196198862, 0.48025073422946185`, 0.9437195744621254], 
             UndirectedEdge[80, 238] -> 
             RGBColor[
              0.4170525450425667, 0.5347455830602593, 0.9480455561293766], 
             UndirectedEdge[171, 272] -> 
             RGBColor[
              0.36396083467584234`, 0.48443119432275983`, 0.9447170138830936],
              UndirectedEdge[297, 392] -> 
             RGBColor[
              0.21605655176504493`, 0.3444195130546133, 0.9356154730447699], 
             UndirectedEdge[82, 499] -> 
             RGBColor[
              0.5743475030967551, 0.6653202029309262, 0.9596338858294544], 
             UndirectedEdge[297, 484] -> 
             RGBColor[
              0.1900371894005843, 0.3170715134867078, 0.934133708850311], 
             UndirectedEdge[73, 240] -> 
             RGBColor[
              0.785852186641644, 0.829344990984529, 0.8179383454805261], 
             UndirectedEdge[229, 263] -> 
             RGBColor[
              0.22958947316632627`, 0.3586434714841348, 0.9363861528984097], 
             UndirectedEdge[87, 91] -> 
             RGBColor[
              0.3843682357663767, 0.5071210898901892, 0.9457662741578293], 
             UndirectedEdge[296, 339] -> 
             RGBColor[
              0.18120773687102673`, 0.3077911990585188, 0.9336308845907572], 
             UndirectedEdge[62, 157] -> 
             RGBColor[
              0.27514441268901324`, 0.40652460127246764`, 0.9389804393117331],
              UndirectedEdge[227, 265] -> 
             RGBColor[
              0.18874076831201309`, 0.315708892724775, 0.9340598795871999], 
             UndirectedEdge[38, 127] -> 
             RGBColor[
              0.6754853554676021, 0.7446194386357212, 0.969557515833958], 
             UndirectedEdge[302, 451] -> 
             RGBColor[
              0.22492379054142386`, 0.35373954322399803`, 0.9361204491751804],
              UndirectedEdge[141, 151] -> 
             RGBColor[
              0.20551109996107267`, 0.3333355745883765, 0.9350149251651315], 
             UndirectedEdge[72, 439] -> 
             RGBColor[
              0.2051731991857032, 0.33298041944931656`, 0.9349956822158536], 
             UndirectedEdge[277, 340] -> 
             RGBColor[
              0.40350978000289583`, 0.523921623272436, 0.9469322642654641], 
             UndirectedEdge[53, 322] -> 
             RGBColor[
              0.8267284539733458, 0.20645218648815844`, 0.17322850375133425`],
              UndirectedEdge[450, 461] -> 
             RGBColor[
              0.23439908756698247`, 0.3636986811663903, 0.9366600533233402], 
             UndirectedEdge[352, 367] -> 
             RGBColor[
              0.1902708306368736, 0.3173170852397579, 0.9341470143730765], 
             UndirectedEdge[239, 251] -> 
             RGBColor[
              0.2177871872756262, 0.3462385207048633, 0.9357140301768516], 
             UndirectedEdge[83, 163] -> 
             RGBColor[
              0.9472677000831091, 0.8139798001662166, 0.4832298213140514], 
             UndirectedEdge[179, 245] -> 
             RGBColor[
              0.22201863728698465`, 0.35068604295622735`, 0.9359550049951293],
              UndirectedEdge[133, 237] -> 
             RGBColor[
              0.21543537025685555`, 0.3437666119043239, 0.9355800976768341], 
             UndirectedEdge[199, 244] -> 
             RGBColor[
              0.4164279851399622, 0.5351107232742938, 0.9477554008736777], 
             UndirectedEdge[173, 269] -> 
             RGBColor[
              0.6612355269183264, 0.7346613054419917, 0.9672934568287169], 
             UndirectedEdge[209, 379] -> 
             RGBColor[
              0.9109503146879699, 0.6018931108868748, 0.4575519033361274], 
             UndirectedEdge[139, 451] -> 
             RGBColor[
              0.19384306282883684`, 0.3210717277661138, 0.9343504477117648], 
             UndirectedEdge[18, 218] -> 
             RGBColor[
              0.2870949982165383, 0.4190854243727823, 0.9396610074782187], 
             UndirectedEdge[59, 287] -> 
             RGBColor[
              0.28357487962969113`, 0.41538555654959675`, 0.9394605419322465],
              UndirectedEdge[167, 274] -> 
             RGBColor[
              0.24197375734068546`, 0.3716601393603544, 0.9370914195612329], 
             UndirectedEdge[402, 461] -> 
             RGBColor[
              0.23570042936850655`, 0.3650664739096279, 0.9367341628137743], 
             UndirectedEdge[472, 488] -> 
             RGBColor[
              0.18283227953141887`, 0.3094986963965447, 0.933723399891971], 
             UndirectedEdge[227, 270] -> 
             RGBColor[
              0.18663641062037617`, 0.3134970793668807, 0.9339400395297794], 
             UndirectedEdge[124, 363] -> 
             RGBColor[
              0.1839911193885881, 0.3107167105611202, 0.9337893941074868], 
             UndirectedEdge[118, 195] -> 
             RGBColor[
              0.19015295783973063`, 0.31719319345639363`, 0.9341403016916563],
              UndirectedEdge[54, 154] -> 
             RGBColor[
              0.9864962902894889, 0.9885634492757301, 0.8680616670608778], 
             UndirectedEdge[313, 498] -> 
             RGBColor[
              0.5679033760595678, 0.6555623513374985, 0.9612024040388176], 
             UndirectedEdge[243, 283] -> 
             RGBColor[
              0.18944836976348856`, 0.3164526267147989, 0.934100176443059], 
             UndirectedEdge[302, 346] -> 
             RGBColor[
              0.343088083847486, 0.46567152269516504`, 0.9432988559850268], 
             UndirectedEdge[13, 477] -> 
             RGBColor[
              0.2253695367356543, 0.3542080507360753, 0.9361458337615195], 
             UndirectedEdge[140, 479] -> 
             RGBColor[
              0.18066625764504995`, 0.3072220700602514, 0.9336000481498845], 
             UndirectedEdge[174, 309] -> 
             RGBColor[
              0.18783655214367595`, 0.3147585042012363, 0.9340083858140811], 
             UndirectedEdge[299, 312] -> 
             RGBColor[
              0.21752114274095335`, 0.3459588910307243, 0.9356988793341796], 
             UndirectedEdge[215, 402] -> 
             RGBColor[
              0.2015459552318014, 0.3291679560732161, 0.9347891160387054], 
             UndirectedEdge[372, 400] -> 
             RGBColor[
              0.8020697769239993, 0.8439051876717503, 0.8901739454806034], 
             UndirectedEdge[29, 426] -> 
             RGBColor[
              0.18589315152803693`, 0.3127158669354839, 0.933897712024024], 
             UndirectedEdge[361, 481] -> 
             RGBColor[
              0.217684758794606, 0.34613086187697023`, 0.935708197026387], 
             UndirectedEdge[188, 335] -> 
             RGBColor[
              0.21717587938379926`, 0.3455959973513941, 0.9356792170967612], 
             UndirectedEdge[168, 443] -> 
             RGBColor[
              0.29027458230294984`, 0.42242736884487553`, 0.9398420800881666],
              UndirectedEdge[81, 500] -> 
             RGBColor[
              0.21967281078147302`, 0.34822043056494373`, 0.9358214136459797],
              UndirectedEdge[75, 310] -> 
             RGBColor[
              0.7550654921994678, 0.6018878314253746, 0.587281607852838], 
             UndirectedEdge[348, 444] -> 
             RGBColor[
              0.5139722729928065, 0.6163048712594199, 0.9548809265539167], 
             UndirectedEdge[262, 482] -> 
             RGBColor[
              0.3377696803255693, 0.46698085312541926`, 0.9427433632457125], 
             UndirectedEdge[83, 395] -> 
             RGBColor[
              0.749683946094778, 0.8003088116491959, 0.8414368525463194], 
             UndirectedEdge[26, 459] -> 
             RGBColor[
              0.18968759946741098`, 0.31670407230166076`, 0.9341138002207887],
              UndirectedEdge[186, 498] -> 
             RGBColor[
              0.8839547752105941, 0.9059796859731515, 0.7464098878256111], 
             UndirectedEdge[167, 284] -> 
             RGBColor[
              0.22334665832655862`, 0.3520818772702168, 0.9360306338287019], 
             UndirectedEdge[175, 359] -> 
             RGBColor[
              0.653601757432396, 0.7247826808114364, 0.9688966182964689], 
             UndirectedEdge[65, 484] -> 
             RGBColor[
              0.1839955650344703, 0.31072138321681264`, 0.9337896472804431], 
             UndirectedEdge[266, 322] -> 
             RGBColor[
              0.9071828092516094, 0.5747154165207407, 0.3552511523528803], 
             UndirectedEdge[210, 252] -> 
             RGBColor[
              0.1889152618740288, 0.3158922965219843, 0.9340698167374166], 
             UndirectedEdge[133, 271] -> 
             RGBColor[
              0.20303817120051487`, 0.3307363696682909, 0.9348740955305881], 
             UndirectedEdge[190, 467] -> 
             RGBColor[
              0.20384534758574807`, 0.33158476322710967`, 0.9349200630316166],
              UndirectedEdge[216, 481] -> 
             RGBColor[
              0.20259193459855807`, 0.33026734670659963`, 0.9348486830162546],
              UndirectedEdge[18, 406] -> 
             RGBColor[
              0.35240776193494094`, 0.47777048741806016`, 0.9437452593947762],
              UndirectedEdge[315, 364] -> 
             RGBColor[
              0.19390091491665387`, 0.32113253397844377`, 0.9343537423025814],
              UndirectedEdge[152, 464] -> 
             RGBColor[
              0.19334471949680462`, 0.32054793732735576`, 0.9343220677962385],
              UndirectedEdge[229, 280] -> 
             RGBColor[
              0.24415725813790062`, 0.37395513714017414`, 0.9372157667014342],
              UndirectedEdge[164, 259] -> 
             RGBColor[
              0.4996492818256195, 0.6003222503432779, 0.9552118903262334], 
             UndirectedEdge[238, 497] -> 
             RGBColor[
              0.4824356353537869, 0.5907020081147285, 0.9523982469164629], 
             UndirectedEdge[7, 478] -> 
             RGBColor[
              0.36083387288200847`, 0.48094610395474147`, 0.9445570026671483],
              UndirectedEdge[137, 227] -> 
             RGBColor[
              0.2024073413896048, 0.33007332754010427`, 0.9348381707060858], 
             UndirectedEdge[44, 157] -> 
             RGBColor[
              0.2890530721263536, 0.4211434842010545, 0.9397725168906719], 
             UndirectedEdge[105, 205] -> 
             RGBColor[
              0.21445329260995954`, 0.34273438603011697`, 0.9355241698076971],
              UndirectedEdge[305, 460] -> 
             RGBColor[
              0.3056141271073153, 0.43838298078417876`, 0.9407217672970755], 
             UndirectedEdge[330, 492] -> 
             RGBColor[
              0.1860947118976098, 0.3129277196635705, 0.9339091905888894], 
             UndirectedEdge[94, 123] -> 
             RGBColor[
              0.18238673674691558`, 0.30903040268098764`, 0.933698026889515], 
             UndirectedEdge[418, 444] -> 
             RGBColor[
              0.5211846971324379, 0.6221602420919774, 0.9554487150021684], 
             UndirectedEdge[203, 295] -> 
             RGBColor[
              0.9149334778554977, 0.6677110589938393, 0.5462140209685634], 
             UndirectedEdge[342, 485] -> 
             RGBColor[
              0.36582891890395064`, 0.48572268889805037`, 0.9448845663511518],
              UndirectedEdge[279, 430] -> 
             RGBColor[
              0.2047694881993928, 0.33255609360594945`, 0.9349726914724201], 
             UndirectedEdge[391, 448] -> 
             RGBColor[
              0.38684939186323586`, 0.5081990768979878, 0.9460468301879315], 
             UndirectedEdge[174, 252] -> 
             RGBColor[
              0.18489202158224743`, 0.3116636158871544, 0.9338406991546504], 
             UndirectedEdge[14, 489] -> 
             RGBColor[
              0.2113006394017466, 0.3394207476185267, 0.935344630871422], 
             UndirectedEdge[6, 158] -> 
             RGBColor[
              0.20305085818934585`, 0.33074970449795377`, 0.9348748180358333],
              UndirectedEdge[201, 493] -> 
             RGBColor[
              0.2591781892002248, 0.38974308806871316`, 0.9380711865039575], 
             UndirectedEdge[66, 446] -> 
             RGBColor[
              0.19064470762485328`, 0.3177100536592947, 0.9341683061144403], 
             UndirectedEdge[449, 499] -> 
             RGBColor[
              0.8060897526290038, 0.8328531529864611, 0.6773590298414771], 
             UndirectedEdge[202, 477] -> 
             RGBColor[
              0.19227698695572149`, 0.31942568272852423`, 0.9342612620075925],
              UndirectedEdge[89, 299] -> 
             RGBColor[
              0.27487744861956126`, 0.4061575123810962, 0.9389684030253784], 
             UndirectedEdge[57, 91] -> 
             RGBColor[
              0.7114825067288603, 0.7722045544678969, 0.9493905426840812], 
             UndirectedEdge[222, 438] -> 
             RGBColor[
              0.19987204711910306`, 0.3274085725148659, 0.9346937894480125], 
             UndirectedEdge[83, 346] -> 
             RGBColor[
              0.7183210910606576, 0.7745238473066297, 0.8390571508964824], 
             UndirectedEdge[38, 388] -> 
             RGBColor[
              0.42375389748919434`, 0.5396775316025662, 0.9487136143198416], 
             UndirectedEdge[345, 472] -> 
             RGBColor[
              0.1869884495343811, 0.3138670945860562, 0.9339600876251372], 
             UndirectedEdge[231, 486] -> 
             RGBColor[
              0.5884962722514289, 0.6738630228882163, 0.9623181191717225], 
             UndirectedEdge[14, 251] -> 
             RGBColor[
              0.23495511782487732`, 0.36428310422179233`, 0.9366917184239543],
              UndirectedEdge[404, 418] -> 
             RGBColor[
              0.6566661186267099, 0.7293072977796211, 0.9681149418691689], 
             UndirectedEdge[10, 370] -> 
             RGBColor[
              0.22777336174590646`, 0.35673462323315885`, 0.9362827280397129],
              UndirectedEdge[216, 224] -> 
             RGBColor[
              0.20292469844545702`, 0.3306171026081368, 0.9348676334250554], 
             UndirectedEdge[116, 143] -> 
             RGBColor[
              0.4285653763865951, 0.5391828000638526, 0.9495933114012363], 
             UndirectedEdge[142, 477] -> 
             RGBColor[
              0.2067532217668407, 0.3346411233613098, 0.9350856621644155], 
             UndirectedEdge[1, 378] -> 
             RGBColor[
              0.20312084702488786`, 0.3308232672016569, 0.9348788037964781], 
             UndirectedEdge[47, 298] -> 
             RGBColor[
              0.2786489927595025, 0.4102081371297621, 0.9391800199621858], 
             UndirectedEdge[50, 340] -> 
             RGBColor[
              0.6220781556562913, 0.698481383789535, 0.9664262896114366], 
             UndirectedEdge[144, 417] -> 
             RGBColor[
              0.19700492333763642`, 0.3243950436343972, 0.9345305109901875], 
             UndirectedEdge[326, 395] -> 
             RGBColor[
              0.6147615284118504, 0.6968583223867169, 0.9636849672850575], 
             UndirectedEdge[14, 166] -> 
             RGBColor[
              0.21333099290535548`, 0.34155477788266697`, 0.9354602564998136],
              UndirectedEdge[41, 132] -> 
             RGBColor[
              0.2677010857798615, 0.3987011927567655, 0.9385565528556723], 
             UndirectedEdge[6, 35] -> 
             RGBColor[
              0.2010217865796709, 0.32861702158561484`, 0.9347592654094047], 
             UndirectedEdge[95, 286] -> 
             RGBColor[
              0.18603827385130794`, 0.3128683996985284, 0.9339059765256451], 
             UndirectedEdge[435, 439] -> 
             RGBColor[
              0.21881441649795172`, 0.3473182037476218, 0.9357725293614136], 
             UndirectedEdge[354, 388] -> 
             RGBColor[
              0.3196378407891415, 0.45127596505171874`, 0.9415880184638075], 
             UndirectedEdge[47, 59] -> 
             RGBColor[
              0.272302702026903, 0.4035377831917274, 0.9388186080934602], 
             UndirectedEdge[305, 493] -> 
             RGBColor[
              0.2857296655888689, 0.41748315098061395`, 0.9395893766300246], 
             UndirectedEdge[26, 335] -> 
             RGBColor[
              0.1976351524381914, 0.3250574543779134, 0.9345664016051236], 
             UndirectedEdge[24, 115] -> 
             RGBColor[
              0.18813870785962614`, 0.3150760890164789, 0.9340255931351051], 
             UndirectedEdge[271, 351] -> 
             RGBColor[
              0.2241430772010206, 0.3529189640031495, 0.9360759887054064], 
             UndirectedEdge[12, 40] -> 
             RGBColor[
              0.18952205245126588`, 0.31653007189140514`, 0.9341043725631242],
              UndirectedEdge[228, 468] -> 
             RGBColor[
              0.23985909159475186`, 0.369437491583826, 0.9369709924753695], 
             UndirectedEdge[1, 108] -> 
             RGBColor[
              0.20444558985732308`, 0.3322156559120931, 0.9349542459410038], 
             UndirectedEdge[97, 343] -> 
             RGBColor[
              0.9173437036143605, 0.6645392600270346, 0.3007805254610556], 
             UndirectedEdge[314, 411] -> 
             RGBColor[
              0.27200862613590066`, 0.4032286907847955, 0.9388018609065139], 
             UndirectedEdge[211, 466] -> 
             RGBColor[
              0.1911846700582075, 0.3182775884123456, 0.9341990561762171], 
             UndirectedEdge[12, 202] -> 
             RGBColor[
              0.1903977819160206, 0.31745051908331734`, 0.9341542440606163], 
             UndirectedEdge[96, 360] -> 
             RGBColor[
              0.5334689580963748, 0.6321331585421514, 0.9564157770239803], 
             UndirectedEdge[199, 482] -> 
             RGBColor[
              0.35925314832548205`, 0.4855887533164457, 0.9441122708295822], 
             UndirectedEdge[9, 357] -> 
             RGBColor[
              0.19116813878282407`, 0.31826021299377427`, 0.9341981147445398],
              UndirectedEdge[330, 441] -> 
             RGBColor[
              0.20552414062024876`, 0.33334928114799606`, 0.9350156678113797],
              UndirectedEdge[375, 461] -> 
             RGBColor[
              0.22800718101290143`, 0.35698038210776833`, 0.9362960437010637],
              UndirectedEdge[170, 268] -> 
             RGBColor[
              0.18701827847814975`, 0.31389844669722133`, 0.9339617863393568],
              UndirectedEdge[66, 245] -> 
             RGBColor[
              0.22090376329813846`, 0.34951423970685647`, 0.9358915145707727],
              UndirectedEdge[235, 308] -> 
             RGBColor[
              0.2040111506020718, 0.33175903270978435`, 0.9349295052681127], 
             UndirectedEdge[42, 315] -> 
             RGBColor[
              0.19198004367677265`, 0.3191135765150577, 0.9342443515271446], 
             UndirectedEdge[238, 403] -> 
             RGBColor[
              0.6150489760394036, 0.6968155368302928, 0.9638964004459423], 
             UndirectedEdge[382, 425] -> 
             RGBColor[
              0.19937423959475875`, 0.32688534524395996`, 0.9346654400459413],
              UndirectedEdge[74, 215] -> 
             RGBColor[
              0.1868347723407586, 0.3137055701118621, 0.9339513359363054], 
             UndirectedEdge[350, 426] -> 
             RGBColor[
              0.1844406280385869, 0.3111891726527635, 0.9338149929601158], 
             UndirectedEdge[78, 497] -> 
             RGBColor[
              0.47412146300073554`, 0.5839521884493253, 0.9517437248130138], 
             UndirectedEdge[109, 490] -> 
             RGBColor[
              0.21480193499900369`, 0.3431008312862066, 0.935544024475983], 
             UndirectedEdge[281, 317] -> 
             RGBColor[
              0.8178714627321924, 0.13837347065034328`, 0.1647470389362648], 
             UndirectedEdge[219, 471] -> 
             RGBColor[
              0.8131815162037359, 0.854543894896763, 0.9628221166971644], 
             UndirectedEdge[183, 243] -> 
             RGBColor[
              0.19677206267761843`, 0.3241502923164997, 0.9345172499200859], 
             UndirectedEdge[93, 151] -> 
             RGBColor[
              0.21317178010893856`, 0.3413874351389585, 0.9354511895665918], 
             UndirectedEdge[176, 478] -> 
             RGBColor[
              0.2831235992471345, 0.4141542435922354, 0.9394625592452028], 
             UndirectedEdge[28, 282] -> 
             RGBColor[
              0.586277448481364, 0.6741728296188088, 0.961142335628971], 
             UndirectedEdge[125, 305] -> 
             RGBColor[
              0.5442522046967718, 0.6349340468295404, 0.9597558326180513], 
             UndirectedEdge[22, 466] -> 
             RGBColor[
              0.188342270881701, 0.3152900466593206, 0.9340371857480678], 
             UndirectedEdge[78, 154] -> 
             RGBColor[
              0.7267639040768494, 0.783922928096006, 0.9321470662934741], 
             UndirectedEdge[273, 421] -> 
             RGBColor[
              0.18574774173175967`, 0.3125630320200829, 0.9338894311512407], 
             UndirectedEdge[221, 234] -> 
             RGBColor[
              0.9443267569423743, 0.8151145515040961, 0.2837836064703105], 
             UndirectedEdge[384, 461] -> 
             RGBColor[
              0.26067331628804735`, 0.3913145614345472, 0.9381563317797668], 
             UndirectedEdge[3, 428] -> 
             RGBColor[
              0.18571633162823864`, 0.3125300180097667, 0.9338876423923121], 
             UndirectedEdge[209, 431] -> 
             RGBColor[
              0.707864048381464, 0.7656363882619854, 0.8446357642394154], 
             UndirectedEdge[33, 237] -> 
             RGBColor[
              0.24458077131553108`, 0.3744002763421501, 0.9372398851503687], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.26751337219857585`, 0.3985038938811058, 0.9385458628449154], 
             UndirectedEdge[202, 243] -> 
             RGBColor[
              0.1916697633639069, 0.3187874522333277, 0.9342266815223454], 
             UndirectedEdge[169, 456] -> 
             RGBColor[
              0.18971194776524802`, 0.31672966390645874`, 0.9341151868203305],
              UndirectedEdge[86, 297] -> 
             RGBColor[
              0.1902871793569701, 0.317334268781148, 0.9341479454085002], 
             UndirectedEdge[40, 202] -> 
             RGBColor[
              0.18588447811869105`, 0.31270675063233544`, 0.933897218086193], 
             UndirectedEdge[396, 477] -> 
             RGBColor[
              0.19761610506605493`, 0.32503743438212485`, 0.9345653168854586],
              UndirectedEdge[209, 355] -> 
             RGBColor[
              0.7770929742760209, 0.8227102163659248, 0.8498451509008846], 
             UndirectedEdge[131, 434] -> 
             RGBColor[
              0.8844045850628767, 0.520292002224005, 0.22327723058043727`], 
             UndirectedEdge[87, 228] -> 
             RGBColor[
              0.28331447723561765`, 0.41511185712296006`, 0.9394457124011348],
              UndirectedEdge[17, 116] -> 
             RGBColor[
              0.32596120839538445`, 0.45376963828216715`, 0.9421001714481905],
              UndirectedEdge[104, 323] -> 
             RGBColor[
              0.958420920419589, 0.8640840271773381, 0.5141442750004963], 
             UndirectedEdge[101, 347] -> 
             RGBColor[
              0.22409394315426182`, 0.3528673210047275, 0.9360731905941307], 
             UndirectedEdge[92, 342] -> 
             RGBColor[
              0.37412603951120016`, 0.4944434887241004, 0.9453570750952447], 
             UndirectedEdge[399, 464] -> 
             RGBColor[
              0.20516649221167577`, 0.332973369994367, 0.9349953002636049], 
             UndirectedEdge[423, 469] -> 
             RGBColor[
              0.18027622515678673`, 0.30681212118559864`, 0.9335778363766793],
              UndirectedEdge[114, 415] -> 
             RGBColor[
              0.18091671513236096`, 0.30748531675933716`, 0.9336143113332682],
              UndirectedEdge[244, 478] -> 
             RGBColor[
              0.34801769220506096`, 0.4703622452404419, 0.9435975534648887], 
             UndirectedEdge[129, 486] -> 
             RGBColor[
              0.3513552004898414, 0.47695704074611134`, 0.9436745944599232], 
             UndirectedEdge[202, 421] -> 
             RGBColor[
              0.18554846728188248`, 0.31235358193853213`, 0.9338780827661202],
              UndirectedEdge[62, 378] -> 
             RGBColor[
              0.22907866033211158`, 0.3581065748079708, 0.9363570628631811], 
             UndirectedEdge[263, 485] -> 
             RGBColor[
              0.23984153552950008`, 0.3694190390461275, 0.9369699926834254], 
             UndirectedEdge[275, 346] -> 
             RGBColor[
              0.4653638430606762, 0.5765191723103537, 0.951143590075486], 
             UndirectedEdge[127, 303] -> 
             RGBColor[
              0.8364744443127496, 0.5917978023235237, 0.5852770137807005], 
             UndirectedEdge[260, 312] -> 
             RGBColor[
              0.2023598436460895, 0.3300234044001388, 0.9348354657798592], 
             UndirectedEdge[32, 299] -> 
             RGBColor[
              0.22987290893586354`, 0.3589413804487841, 0.9364022941461793], 
             UndirectedEdge[283, 396] -> 
             RGBColor[
              0.18987793209336085`, 0.3169041239593195, 0.9341246393822646], 
             UndirectedEdge[87, 253] -> 
             RGBColor[
              0.34295238339538536`, 0.47143899485614194`, 0.9430747302616557],
              UndirectedEdge[298, 409] -> 
             RGBColor[
              0.26446105735967274`, 0.39529571745748016`, 0.9383720380303351],
              UndirectedEdge[208, 258] -> 
             RGBColor[
              0.42089773296190985`, 0.5389821941816072, 0.9480402092524494], 
             UndirectedEdge[142, 161] -> 
             RGBColor[
              0.21478163330642375`, 0.3430794929201034, 0.9355428683246243], 
             UndirectedEdge[71, 211] -> 
             RGBColor[
              0.19261088350739852`, 0.3197766291746009, 0.9342802769222549], 
             UndirectedEdge[14, 453] -> 
             RGBColor[
              0.23545530969286413`, 0.36480883758904264`, 0.9367202036108686],
              UndirectedEdge[89, 478] -> 
             RGBColor[
              0.27949760473699387`, 0.41101358939533483`, 0.9392315140813577],
              UndirectedEdge[159, 251] -> 
             RGBColor[
              0.23552312226059172`, 0.3648801128972894, 0.936724065436281], 
             UndirectedEdge[300, 305] -> 
             RGBColor[
              0.27120896577425085`, 0.40222097480990704`, 0.9387624442570324],
              UndirectedEdge[327, 385] -> 
             RGBColor[
              0.18266732742080666`, 0.30932532126972345`, 0.9337140061132965],
              UndirectedEdge[156, 270] -> 
             RGBColor[
              0.18975438070497386`, 0.3167742636165143, 0.9341176033134739], 
             UndirectedEdge[418, 486] -> 
             RGBColor[
              0.4449199446935177, 0.5591594372838178, 0.9497448407437088], 
             UndirectedEdge[366, 465] -> 
             RGBColor[
              0.18080307297570358`, 0.30736587164736134`, 0.9336078395805651],
              UndirectedEdge[337, 433] -> 
             RGBColor[
              0.1848796930167158, 0.31165065778310447`, 0.9338399970610818], 
             UndirectedEdge[118, 152] -> 
             RGBColor[
              0.1882232378558979, 0.3151649354020718, 0.9340304069933419], 
             UndirectedEdge[151, 162] -> 
             RGBColor[
              0.1935196204092478, 0.32073176927569186`, 0.9343320281444594], 
             UndirectedEdge[80, 251] -> 
             RGBColor[
              0.2931730251986915, 0.4218985079169302, 0.9401380516698865], 
             UndirectedEdge[348, 486] -> 
             RGBColor[
              0.4377075205538863, 0.5533040664512603, 0.949177052295457], 
             UndirectedEdge[376, 455] -> 
             RGBColor[
              0.4920767571056538, 0.5962969354126668, 0.9537739864673327], 
             UndirectedEdge[153, 197] -> 
             RGBColor[
              0.22926543037868818`, 0.35830288196882765`, 0.9363676991410321],
              UndirectedEdge[9, 319] -> 
             RGBColor[
              0.18732739999033735`, 0.3142233530059664, 0.9339793903521716], 
             UndirectedEdge[184, 336] -> 
             RGBColor[
              0.5830930532515349, 0.672420234529121, 0.9603223675736445], 
             UndirectedEdge[41, 56] -> 
             RGBColor[
              0.33496751620801646`, 0.46033233124806494`, 0.9427193789900982],
              UndirectedEdge[99, 313] -> 
             RGBColor[
              0.6704591742575927, 0.7358360174967769, 0.9317439644037724], 
             UndirectedEdge[111, 130] -> 
             RGBColor[
              0.3347552996533061, 0.46383121081799694`, 0.9425710153855427], 
             UndirectedEdge[255, 327] -> 
             RGBColor[
              0.19047479361502342`, 0.3175314632617931, 0.9341586297629458], 
             UndirectedEdge[32, 84] -> 
             RGBColor[
              0.2475939365043437, 0.3775673040012994, 0.9374114804502933], 
             UndirectedEdge[196, 420] -> 
             RGBColor[
              0.19002037884251344`, 0.3170538445243244, 0.9341327515138979], 
             UndirectedEdge[55, 57] -> 
             RGBColor[
              0.7681170081630603, 0.818182994087395, 0.9538490180959958], 
             UndirectedEdge[10, 480] -> 
             RGBColor[
              0.2350739989368308, 0.3644080558079533, 0.9366984885274112], 
             UndirectedEdge[152, 216] -> 
             RGBColor[
              0.19207526490404528`, 0.31921366006229573`, 0.9342497742351705],
              UndirectedEdge[244, 482] -> 
             RGBColor[
              0.3895468312104969, 0.511827618826672, 0.9460425575153633], 
             UndirectedEdge[111, 463] -> 
             RGBColor[
              0.4608753150975682, 0.5708435411870683, 0.9513515854271455], 
             UndirectedEdge[58, 74] -> 
             RGBColor[
              0.19093718319717995`, 0.31801746402983233`, 0.9341849621656055],
              UndirectedEdge[66, 327] -> 
             RGBColor[
              0.19083074135934272`, 0.31790558690946313`, 0.9341789004604073],
              UndirectedEdge[168, 346] -> 
             RGBColor[
              0.3670639021674008, 0.4908716279040769, 0.9446642433693013], 
             UndirectedEdge[53, 471] -> 
             RGBColor[
              0.8947556642863255, 0.6097433924263989, 0.5684355218108367], 
             UndirectedEdge[28, 125] -> 
             RGBColor[
              0.6268956164581168, 0.7059040511517584, 0.965190775014533], 
             UndirectedEdge[405, 423] -> 
             RGBColor[
              0.18042956728835297`, 0.30697329348832747`, 0.9335865689842227],
              UndirectedEdge[314, 493] -> 
             RGBColor[
              0.2618563204200539, 0.3925579737840803, 0.9382237021149867], 
             UndirectedEdge[43, 229] -> 
             RGBColor[
              0.231604699752685, 0.3607616023991431, 0.9365009170712423], 
             UndirectedEdge[281, 397] -> 
             RGBColor[
              0.8202168451405925, 0.15640110759443068`, 0.16699297977927924`],
              UndirectedEdge[203, 324] -> 
             RGBColor[
              0.8924019068162066, 0.6510073815667528, 0.588847136940535], 
             UndirectedEdge[403, 445] -> 
             RGBColor[
              0.8532638533992596, 0.8433645979013125, 0.6431418553174187], 
             UndirectedEdge[147, 303] -> 
             RGBColor[
              0.8299391758302155, 0.23113120162734693`, 0.17630309462746424`],
              UndirectedEdge[356, 457] -> 
             RGBColor[
              0.35728371097557365`, 0.477585785779042, 0.9443210439032999], 
             UndirectedEdge[8, 85] -> 
             RGBColor[
              0.19237812780276942`, 0.31953198817147166`, 0.9342670218292075],
              UndirectedEdge[301, 336] -> 
             RGBColor[
              0.6408993785116156, 0.7191341855671287, 0.9650206560001502], 
             UndirectedEdge[24, 64] -> 
             RGBColor[
              0.18504835804129488`, 0.3118279354179173, 0.933849602284714], 
             UndirectedEdge[30, 488] -> 
             RGBColor[
              0.18073134444068237`, 0.30729048040920226`, 0.9336037547466085],
              UndirectedEdge[191, 366] -> 
             RGBColor[
              0.18657672320149288`, 0.31343434410523346`, 0.9339366404195737],
              UndirectedEdge[185, 481] -> 
             RGBColor[
              0.2084048526461078, 0.33637709213486555`, 0.9351797200996208], 
             UndirectedEdge[308, 389] -> 
             RGBColor[
              0.19291290556353907`, 0.320094073504909, 0.9342974766315505], 
             UndirectedEdge[96, 240] -> 
             RGBColor[
              0.7327901627995155, 0.786266849612556, 0.8137611085910759], 
             UndirectedEdge[108, 113] -> 
             RGBColor[
              0.2031652064588611, 0.33086989177931336`, 0.934881330000619], 
             UndirectedEdge[85, 332] -> 
             RGBColor[
              0.18694868384128802`, 0.31382529832132483`, 0.9339578230277437],
              UndirectedEdge[232, 280] -> 
             RGBColor[
              0.26596668909501486`, 0.3968782318738905, 0.9384577815302801], 
             UndirectedEdge[310, 419] -> 
             RGBColor[
              0.6470494829273306, 0.7241992409118212, 0.9654555035031411], 
             UndirectedEdge[39, 378] -> 
             RGBColor[
              0.22727756338581306`, 0.356213507721269, 0.9362544930565735], 
             UndirectedEdge[53, 257] -> 
             RGBColor[
              0.8978636395827194, 0.5695936454427237, 0.2449447114503845], 
             UndirectedEdge[248, 339] -> 
             RGBColor[
              0.18022958629127006`, 0.30676310078086577`, 0.933575180362284], 
             UndirectedEdge[327, 334] -> 
             RGBColor[
              0.18531717245783108`, 0.3121104764135153, 0.9338649108680606], 
             UndirectedEdge[165, 358] -> 
             RGBColor[
              0.26540482039910535`, 0.39628767224995665`, 0.9384257839392585],
              UndirectedEdge[69, 204] -> 
             RGBColor[
              0.37937968200922045`, 0.5030213452043036, 0.9453947157587149], 
             UndirectedEdge[208, 293] -> 
             RGBColor[
              0.6181817945706438, 0.697617598691705, 0.965038174550626], 
             UndirectedEdge[265, 320] -> 
             RGBColor[
              0.18273053674122575`, 0.3093917582731863, 0.9337176057905845], 
             UndirectedEdge[239, 453] -> 
             RGBColor[
              0.21828737914361301`, 0.34676425407211353`, 0.935742515363766], 
             UndirectedEdge[108, 452] -> 
             RGBColor[
              0.21821098000140754`, 0.3466839537296702, 0.9357381645456397], 
             UndirectedEdge[331, 418] -> 
             RGBColor[
              0.38897001185206387`, 0.5100224409848767, 0.9462045113122062], 
             UndirectedEdge[28, 201] -> 
             RGBColor[
              0.3666465873540202, 0.4866385048510442, 0.9449259979753362], 
             UndirectedEdge[431, 486] -> 
             RGBColor[
              0.4172932945902137, 0.5358602108283841, 0.9478105376266845], 
             UndirectedEdge[269, 419] -> 
             RGBColor[
              0.6255800853713929, 0.7068070035141348, 0.9637396556343641], 
             UndirectedEdge[315, 378] -> 
             RGBColor[
              0.19518703914887203`, 0.3224843320914912, 0.934426985174956], 
             UndirectedEdge[57, 240] -> 
             RGBColor[
              0.9787234021564939, 0.9814785102156434, 0.8120827611030339], 
             UndirectedEdge[7, 176] -> 
             RGBColor[
              0.39464375574399807`, 0.5157254458506131, 0.9465101425420326], 
             UndirectedEdge[6, 302] -> 
             RGBColor[
              0.22957764048616652`, 0.3586310345870516, 0.9363854790447795], 
             UndirectedEdge[176, 455] -> 
             RGBColor[
              0.46498904560871784`, 0.5728349211819872, 0.9520479814434708], 
             UndirectedEdge[161, 396] -> 
             RGBColor[
              0.205644516605638, 0.33347580394091847`, 0.9350225230456672], 
             UndirectedEdge[36, 463] -> 
             RGBColor[
              0.7746453145833472, 0.820791726755383, 0.8525214986025103], 
             UndirectedEdge[131, 373] -> 
             RGBColor[
              0.9123644303428394, 0.625404830056993, 0.48937807328246297`], 
             UndirectedEdge[54, 341] -> 
             RGBColor[
              0.991911410491914, 0.9900737129022821, 0.7219654915810148], 
             UndirectedEdge[272, 453] -> 
             RGBColor[
              0.24857862251541402`, 0.3786022714316334, 0.9374675568619113], 
             UndirectedEdge[169, 236] -> 
             RGBColor[
              0.19608590653883476`, 0.32342909870982617`, 0.9344781743430592],
              UndirectedEdge[69, 101] -> 
             RGBColor[
              0.3439836908945852, 0.4664796432810521, 0.9433547372891266], 
             UndirectedEdge[286, 330] -> 
             RGBColor[
              0.18848828405783719`, 0.3154435157652098, 0.9340455009824417], 
             UndirectedEdge[86, 254] -> 
             RGBColor[
              0.18887066842711453`, 0.3158454259818896, 0.934067277206585], 
             UndirectedEdge[68, 319] -> 
             RGBColor[
              0.1831451884938083, 0.30982758355559015`, 0.9337412195944718], 
             UndirectedEdge[37, 207] -> 
             RGBColor[
              0.8684208855066446, 0.4954117968161807, 0.21191950037856397`], 
             UndirectedEdge[257, 317] -> 
             RGBColor[
              0.8901858085318111, 0.510578471538423, 0.23759241176516477`], 
             UndirectedEdge[94, 158] -> 
             RGBColor[
              0.18531714297239393`, 0.3121104454224513, 0.9338649091889084], 
             UndirectedEdge[253, 336] -> 
             RGBColor[
              0.5014215448022852, 0.6040567843941038, 0.9544617509696633], 
             UndirectedEdge[67, 363] -> 
             RGBColor[
              0.18174309364533237`, 0.30835389297189403`, 0.9336613723670645],
              UndirectedEdge[61, 295] -> 
             RGBColor[
              0.9875274720228682, 0.989110303399177, 0.8563655966561801], 
             UndirectedEdge[16, 116] -> 
             RGBColor[
              0.2732978193858072, 0.4045837146300204, 0.9388752785549055], 
             UndirectedEdge[294, 439] -> 
             RGBColor[
              0.19336116609564466`, 0.3205652237455112, 0.9343230044057118], 
             UndirectedEdge[69, 346] -> 
             RGBColor[
              0.4421357571807656, 0.5573775033058451, 0.9493934773756274], 
             UndirectedEdge[327, 415] -> 
             RGBColor[
              0.1820891431356189, 0.3087176129269901, 0.9336810793736019], 
             UndirectedEdge[54, 61] -> 
             RGBColor[
              0.9898922626687403, 0.9900882051035927, 0.8171748957720661], 
             UndirectedEdge[244, 262] -> 
             RGBColor[
              0.3949445171400494, 0.5165028230832673, 0.9463864932898081], 
             UndirectedEdge[295, 397] -> 
             RGBColor[
              0.9034028373173626, 0.5790815030588307, 0.5351722665672494], 
             UndirectedEdge[61, 264] -> 
             RGBColor[
              0.9279014667399095, 0.7362939743699763, 0.5103077071950994], 
             UndirectedEdge[162, 226] -> 
             RGBColor[
              0.18515287463647273`, 0.3119377889861841, 0.933855554350191], 
             UndirectedEdge[237, 351] -> 
             RGBColor[
              0.2365402762573613, 0.3659492062391825, 0.9367819908516525], 
             UndirectedEdge[243, 273] -> 
             RGBColor[
              0.1918690378137841, 0.3189969023148785, 0.9342380299074659], 
             UndirectedEdge[53, 343] -> 
             RGBColor[
              0.8394526370347362, 0.3042558332705747, 0.18541319582083088`], 
             UndirectedEdge[37, 445] -> 
             RGBColor[
              0.9124867892485535, 0.6764249054783144, 0.25883228336174086`], 
             UndirectedEdge[144, 402] -> 
             RGBColor[
              0.20750395596016302`, 0.3354301925977886, 0.9351284153661135], 
             UndirectedEdge[235, 456] -> 
             RGBColor[
              0.20636469541016642`, 0.3342327575264513, 0.9350635361631761], 
             UndirectedEdge[369, 456] -> 
             RGBColor[
              0.1888191818250698, 0.31579131029870144`, 0.9340643451207662], 
             UndirectedEdge[7, 61] -> 
             RGBColor[
              0.7313065318033417, 0.7863785903909934, 0.8813505639139341], 
             UndirectedEdge[76, 175] -> 
             RGBColor[
              0.404052773600639, 0.5243919370351493, 0.946966863337362], 
             UndirectedEdge[259, 372] -> 
             RGBColor[
              0.6487722113207766, 0.7251147800966794, 0.9659213864599616], 
             UndirectedEdge[187, 224] -> 
             RGBColor[
              0.2135902734770326, 0.34182729820283736`, 0.9354750221447994], 
             UndirectedEdge[142, 183] -> 
             RGBColor[
              0.20633874170827649`, 0.3342054785402052, 0.9350620581382485], 
             UndirectedEdge[255, 299] -> 
             RGBColor[
              0.21862190988624552`, 0.3471158670930945, 0.935761566394665], 
             UndirectedEdge[233, 444] -> 
             RGBColor[
              0.7642107527779903, 0.8150144746201845, 0.9536153862998804], 
             UndirectedEdge[148, 280] -> 
             RGBColor[
              0.2640545871077613, 0.39486849145101877`, 0.9383488901508075], 
             UndirectedEdge[7, 376] -> 
             RGBColor[
              0.421731467240934, 0.5391874600812927, 0.9482361475658946], 
             UndirectedEdge[73, 256] -> 
             RGBColor[
              0.4442279577887227, 0.5558341651072809, 0.9504539244246188], 
             UndirectedEdge[207, 403] -> 
             RGBColor[
              0.8091979496573507, 0.6623514892391787, 0.5962290723342419], 
             UndirectedEdge[233, 346] -> 
             RGBColor[
              0.7019863596204035, 0.7641747233325396, 0.948806151319425], 
             UndirectedEdge[293, 403] -> 
             RGBColor[
              0.7765788883904609, 0.8253885969195616, 0.9783657841185909], 
             UndirectedEdge[321, 391] -> 
             RGBColor[
              0.7292749424513578, 0.7856899772227003, 0.9213526032018919], 
             UndirectedEdge[228, 298] -> 
             RGBColor[
              0.2669525907215979, 0.3979144769932027, 0.9385139271694034], 
             UndirectedEdge[54, 455] -> 
             RGBColor[
              0.8012850501089904, 0.8433363962570924, 0.8929667567235482], 
             UndirectedEdge[323, 419] -> 
             RGBColor[
              0.8209982189868783, 0.8586000678793866, 0.8680770966029969], 
             UndirectedEdge[65, 194] -> 
             RGBColor[
              0.18464315044443147`, 0.3114020365419683, 0.9338265263115236], 
             UndirectedEdge[40, 273] -> 
             RGBColor[
              0.18608375256856824`, 0.31291620071388626`, 0.9339085664713134],
              UndirectedEdge[209, 400] -> 
             RGBColor[
              0.9921722318540724, 0.9910310309542629, 0.7793899060000027], 
             UndirectedEdge[31, 488] -> 
             RGBColor[
              0.1872548538957951, 0.31414710246091443`, 0.9339752589594097], 
             UndirectedEdge[399, 407] -> 
             RGBColor[
              0.2425042792072058, 0.3722177514790964, 0.9371216319966944], 
             UndirectedEdge[292, 399] -> 
             RGBColor[
              0.19649944973854266`, 0.32386375883287244`, 0.9345017250165003],
              UndirectedEdge[93, 218] -> 
             RGBColor[
              0.2542535028794738, 0.3845669305024568, 0.9377907329034113], 
             UndirectedEdge[198, 270] -> 
             RGBColor[
              0.1812627552425552, 0.3078490268553615, 0.9336340178056233], 
             UndirectedEdge[78, 192] -> 
             RGBColor[
              0.39152498613418535`, 0.5130863931305935, 0.946294212255822], 
             UndirectedEdge[286, 492] -> 
             RGBColor[
              0.18500229424892267`, 0.31177951945152094`, 0.9338469790198838],
              UndirectedEdge[317, 343] -> 
             RGBColor[
              0.8317748059838278, 0.24524065936627398`, 0.17806089613561116`],
              UndirectedEdge[51, 203] -> 
             RGBColor[
              0.9201617687823374, 0.6698476352137519, 0.4577172955235477], 
             UndirectedEdge[212, 216] -> 
             RGBColor[
              0.19093042363498117`, 0.31801035930138044`, 0.9341845772185382],
              UndirectedEdge[100, 257] -> 
             RGBColor[
              0.9781397520963673, 0.9374756322249009, 0.407566735110352], 
             UndirectedEdge[189, 302] -> 
             RGBColor[
              0.24836644407899122`, 0.3783792584420631, 0.9374554736138468], 
             UndirectedEdge[306, 382] -> 
             RGBColor[
              0.2264199096398822, 0.3553120592559075, 0.9362056509445278], 
             UndirectedEdge[20, 150] -> 
             RGBColor[
              0.22855902835216374`, 0.35756040865047517`, 0.9363274705906497],
              UndirectedEdge[255, 446] -> 
             RGBColor[
              0.19028875988053398`, 0.31733593001162463`, 0.9341480354169789],
              UndirectedEdge[182, 237] -> 
             RGBColor[
              0.2889436538091614, 0.4176768128895569, 0.9398890065800227], 
             UndirectedEdge[4, 366] -> 
             RGBColor[
              0.18203443666830332`, 0.30866011296125107`, 0.9336779639212193],
              UndirectedEdge[231, 275] -> 
             RGBColor[
              0.6264851574368956, 0.7057897543518528, 0.9650087769508688], 
             UndirectedEdge[97, 231] -> 
             RGBColor[
              0.8760573705850234, 0.8940094298858756, 0.6933676019879993], 
             UndirectedEdge[114, 128] -> 
             RGBColor[
              0.1878451960142834, 0.31476758945729777`, 0.9340088780697248], 
             UndirectedEdge[207, 471] -> 
             RGBColor[
              0.9159118385486107, 0.7462782372358219, 0.5876734401900829], 
             UndirectedEdge[54, 391] -> 
             RGBColor[0.731320111432247, 0.7865357071547434, 0.8874588604609],
              UndirectedEdge[299, 478] -> 
             RGBColor[
              0.24469356026771227`, 0.3745188246821251, 0.9372463083143392], 
             UndirectedEdge[44, 365] -> 
             RGBColor[
              0.24302709585907487`, 0.37276726492870105`, 0.9371514056315804],
              UndirectedEdge[6, 101] -> 
             RGBColor[
              0.22975280750904292`, 0.3588151462343254, 0.9363954545475959], 
             UndirectedEdge[236, 308] -> 
             RGBColor[
              0.19963189940938322`, 0.3271561620457061, 0.9346801133912106], 
             UndirectedEdge[47, 256] -> 
             RGBColor[
              0.2965835068490444, 0.4287985034009982, 0.9402108818731908], 
             UndirectedEdge[304, 427] -> 
             RGBColor[
              0.18861159117236292`, 0.315573119360699, 0.9340525231401974], 
             UndirectedEdge[54, 397] -> 
             RGBColor[
              0.9057676279632347, 0.5800594047632462, 0.4959815656831355], 
             UndirectedEdge[220, 254] -> 
             RGBColor[
              0.20473141614653206`, 0.3325160774644852, 0.9349705233253323], 
             UndirectedEdge[377, 426] -> 
             RGBColor[
              0.1840742886923742, 0.31080412677263786`, 0.9337941304762996], 
             UndirectedEdge[216, 292] -> 
             RGBColor[
              0.19251751538449438`, 0.3196784933575477, 0.9342749597457812], 
             UndirectedEdge[42, 119] -> 
             RGBColor[
              0.1924345707120309, 0.31959131324779266`, 0.9342702361693901], 
             UndirectedEdge[170, 491] -> 
             RGBColor[
              0.18468093358720655`, 0.3114417490206145, 0.9338286780056095], 
             UndirectedEdge[257, 326] -> 
             RGBColor[
              0.8442173233312698, 0.8362115823989578, 0.6421148916132133], 
             UndirectedEdge[98, 347] -> 
             RGBColor[
              0.19568928020766854`, 0.32301221928820867`, 0.9344555870602553],
              UndirectedEdge[271, 311] -> 
             RGBColor[
              0.19904018271004636`, 0.32653423027769746`, 0.9346464160005499],
              UndirectedEdge[156, 227] -> 
             RGBColor[
              0.1962768676534719, 0.3236298109489438, 0.9344890492960363], 
             UndirectedEdge[151, 160] -> 
             RGBColor[
              0.22158100780321188`, 0.3502260666214703, 0.9359300826434431], 
             UndirectedEdge[93, 167] -> 
             RGBColor[
              0.23124675852992788`, 0.3603853834792411, 0.9364805328481329], 
             UndirectedEdge[275, 348] -> 
             RGBColor[
              0.475696405739353, 0.5852307979148967, 0.9518677100746031], 
             UndirectedEdge[34, 394] -> 
             RGBColor[
              0.19619166312976455`, 0.3235402555922485, 0.9344841970244598], 
             UndirectedEdge[405, 488] -> 
             RGBColor[
              0.182093967520493, 0.30872268366137645`, 0.9336813541151835], 
             UndirectedEdge[338, 443] -> 
             RGBColor[
              0.3560845115696105, 0.4809110296827722, 0.9439811523759123], 
             UndirectedEdge[301, 316] -> 
             RGBColor[
              0.547580608865669, 0.6429772459967242, 0.9577838308857021], 
             UndirectedEdge[103, 209] -> 
             RGBColor[
              0.7021401008892698, 0.7606785926382128, 0.8442710393667008], 
             UndirectedEdge[126, 414] -> 
             RGBColor[
              0.45556143140572114`, 0.5680520611940277, 0.9505125663614704], 
             UndirectedEdge[154, 341] -> 
             RGBColor[
              0.9888822096717337, 0.9887006265396945, 0.7667739089616505], 
             UndirectedEdge[306, 347] -> 
             RGBColor[
              0.22192337354853872`, 0.3505859147270508, 0.9359495798661548], 
             UndirectedEdge[20, 388] -> 
             RGBColor[
              0.2852227543233797, 0.4152738080593815, 0.9396218953833091], 
             UndirectedEdge[286, 319] -> 
             RGBColor[
              0.18412936406719407`, 0.310862014483554, 0.9337972669374188], 
             UndirectedEdge[62, 96] -> 
             RGBColor[
              0.36098375539591054`, 0.48129258556863375`, 0.9445483392518976],
              UndirectedEdge[149, 242] -> 
             RGBColor[
              0.767121254823353, 0.8170287735130601, 0.9444951769225841], 
             UndirectedEdge[212, 319] -> 
             RGBColor[
              0.18140430286516612`, 0.3079978023813632, 0.93364207873333], 
             UndirectedEdge[289, 470] -> 
             RGBColor[
              0.20234342031166005`, 0.33000614243435394`, 0.9348345304952597],
              UndirectedEdge[291, 353] -> 
             RGBColor[
              0.18189358061228061`, 0.3085120643155814, 0.9336699423772067], 
             UndirectedEdge[21, 91] -> 
             RGBColor[
              0.3801635060105999, 0.5027016523216035, 0.9455268210185781], 
             UndirectedEdge[95, 224] -> 
             RGBColor[
              0.19530748745975585`, 0.322610930903094, 0.9344338445280735], 
             UndirectedEdge[218, 235] -> 
             RGBColor[
              0.2514972659875934, 0.38166995077357824`, 0.9376337692899057], 
             UndirectedEdge[108, 315] -> 
             RGBColor[
              0.19651178198130725`, 0.3238767208019274, 0.9345024273194817], 
             UndirectedEdge[61, 154] -> 
             RGBColor[
              0.9868630618485601, 0.9887151187410052, 0.8619833131527019], 
             UndirectedEdge[297, 413] -> 
             RGBColor[
              0.2127862490397303, 0.34098221754113894`, 0.9354292341425425], 
             UndirectedEdge[294, 438] -> 
             RGBColor[
              0.19506692603526019`, 0.32235808559347384`, 0.9344201449108273],
              UndirectedEdge[277, 386] -> 
             RGBColor[
              0.3744145130463712, 0.49843012291785427`, 0.9450889814281427], 
             UndirectedEdge[125, 249] -> 
             RGBColor[
              0.7524497512082946, 0.8065387315646185, 0.9759608172238798], 
             UndirectedEdge[211, 308] -> 
             RGBColor[
              0.18919374524082816`, 0.3161850001973557, 0.9340856759531767], 
             UndirectedEdge[273, 477] -> 
             RGBColor[
              0.19247626140559868`, 0.319635132810075, 0.9342726103927129], 
             UndirectedEdge[154, 397] -> 
             RGBColor[
              0.9027384271430544, 0.5786863184006587, 0.5407899830637712], 
             UndirectedEdge[105, 230] -> 
             RGBColor[
              0.19866180408544326`, 0.32613653035264917`, 0.9346248678976397],
              UndirectedEdge[355, 404] -> 
             RGBColor[
              0.6982683944179626, 0.7630818994281268, 0.9713900254136139], 
             UndirectedEdge[250, 263] -> 
             RGBColor[
              0.22198989446995654`, 0.350655832433131, 0.9359533681342207], 
             UndirectedEdge[11, 259] -> 
             RGBColor[
              0.5294234413742529, 0.6261111308515327, 0.9571090734444168], 
             UndirectedEdge[339, 439] -> 
             RGBColor[
              0.18970826562688875`, 0.316725793745582, 0.9341149771279982], 
             UndirectedEdge[303, 379] -> 
             RGBColor[
              0.8341112743268393, 0.26319977889761653`, 0.18029830085954252`],
              UndirectedEdge[416, 468] -> 
             RGBColor[
              0.21536523562869736`, 0.3436928959633374, 0.9355761036135155], 
             UndirectedEdge[77, 336] -> 
             RGBColor[
              0.47990926789082156`, 0.58542393137187, 0.9530910077074245], 
             UndirectedEdge[297, 412] -> 
             RGBColor[
              0.1927590864051722, 0.31993239981676747`, 0.9342887168580365], 
             UndirectedEdge[69, 418] -> 
             RGBColor[
              0.45968074399907377`, 0.5719444997429457, 0.9506853858229966], 
             UndirectedEdge[281, 322] -> 
             RGBColor[
              0.8196030856546299, 0.15168348323420097`, 0.16640524300237935`],
              UndirectedEdge[51, 495] -> 
             RGBColor[
              0.9406722816777016, 0.7839532053527796, 0.47565298592181493`], 
             UndirectedEdge[227, 229] -> 
             RGBColor[
              0.21399982241481183`, 0.34225776010334574`, 0.9354983453509325],
              UndirectedEdge[192, 497] -> 
             RGBColor[
              0.3955857304505306, 0.5163830883010493, 0.9466138889234013], 
             UndirectedEdge[143, 277] -> 
             RGBColor[
              0.5119391923573035, 0.6143803189362278, 0.9547965836382715], 
             UndirectedEdge[87, 161] -> 
             RGBColor[
              0.2611314320863651, 0.3917960701847984, 0.9381824207967593], 
             UndirectedEdge[114, 255] -> 
             RGBColor[
              0.1893023656117655, 0.31629916709414013`, 0.9340918617226122], 
             UndirectedEdge[341, 391] -> 
             RGBColor[
              0.7337060308144916, 0.7866728844187078, 0.7861711023616725], 
             UndirectedEdge[35, 347] -> 
             RGBColor[
              0.19536292222488982`, 0.32266919635601693`, 0.9344370014559396],
              UndirectedEdge[99, 498] -> 
             RGBColor[
              0.8771421221278247, 0.9041056565781206, 0.9487087442796804], 
             UndirectedEdge[89, 448] -> 
             RGBColor[
              0.30513277253024496`, 0.43795777610955633`, 0.9406913989633512],
              UndirectedEdge[130, 371] -> 
             RGBColor[
              0.27850064570472033`, 0.41005221496943967`, 0.9391715718168758],
              UndirectedEdge[187, 481] -> 
             RGBColor[
              0.21325750963013368`, 0.3414775423013001, 0.9354560717359984], 
             UndirectedEdge[427, 500] -> 
             RGBColor[
              0.19375142518042626`, 0.32097541078747177`, 0.9343452290832536],
              UndirectedEdge[134, 247] -> 
             RGBColor[
              0.1842053003124589, 0.3109418282919634, 0.933801591394249], 
             UndirectedEdge[79, 301] -> 
             RGBColor[
              0.7713475583434661, 0.821837420942344, 0.9777022478790838], 
             UndirectedEdge[173, 323] -> 
             RGBColor[
              0.8566536605338118, 0.8864543698072436, 0.8716308977973497], 
             UndirectedEdge[84, 262] -> 
             RGBColor[
              0.3093414127711809, 0.4392853260774658, 0.9410444344433726], 
             UndirectedEdge[262, 391] -> 
             RGBColor[
              0.4081410490049733, 0.5273954680265918, 0.9473758851308575], 
             UndirectedEdge[205, 382] -> 
             RGBColor[
              0.22477554462649751`, 0.3535837273680766, 0.9361120067896356], 
             UndirectedEdge[50, 499] -> 
             RGBColor[
              0.7544680909250315, 0.8083923113644382, 0.9761768691183477], 
             UndirectedEdge[108, 380] -> 
             RGBColor[
              0.19854131235532485`, 0.3260098859046778, 0.934618006071861], 
             UndirectedEdge[300, 493] -> 
             RGBColor[
              0.24638397938180046`, 0.376295562349794, 0.9373425751821356], 
             UndirectedEdge[331, 382] -> 
             RGBColor[
              0.25675225340899854`, 0.38719327573892137`, 0.9379330330494976],
              UndirectedEdge[186, 495] -> 
             RGBColor[
              0.9397076490875935, 0.7818899537818541, 0.3706586815108439], 
             UndirectedEdge[93, 235] -> 
             RGBColor[
              0.21987414226832205`, 0.3484320427227756, 0.9358328791763124], 
             UndirectedEdge[18, 300] -> 
             RGBColor[
              0.26008832470075693`, 0.39069969818569605`, 0.938123017374288], 
             UndirectedEdge[223, 246] -> 
             RGBColor[
              0.22404185527291065`, 0.35281257333886495`, 0.9360702242663449],
              UndirectedEdge[233, 431] -> 
             RGBColor[
              0.6919046963354076, 0.7554424933142063, 0.9481637566497699], 
             UndirectedEdge[182, 351] -> 
             RGBColor[
              0.2925937639781592, 0.42151331010752513`, 0.9400968749542931], 
             UndirectedEdge[163, 209] -> 
             RGBColor[
              0.9468923206889115, 0.8138245711399055, 0.48945082932663964`], 
             UndirectedEdge[70, 182] -> 
             RGBColor[
              0.35737014201408246`, 0.4839577878921605, 0.9439922873324968], 
             UndirectedEdge[59, 335] -> 
             RGBColor[
              0.2366854990874992, 0.3661018446413167, 0.9367902610769909], 
             UndirectedEdge[258, 453] -> 
             RGBColor[
              0.3275555861569279, 0.45177144641276795`, 0.942325491454229], 
             UndirectedEdge[161, 354] -> 
             RGBColor[
              0.262219161885439, 0.39276906224398844`, 0.9382506002184958], 
             UndirectedEdge[213, 489] -> 
             RGBColor[
              0.19691928671610104`, 0.3243050341154881, 0.9345256341112791], 
             UndirectedEdge[260, 407] -> 
             RGBColor[
              0.24344019620099944`, 0.3732014595801383, 0.9371749310849259], 
             UndirectedEdge[95, 185] -> 
             RGBColor[
              0.19811081032671668`, 0.3255574009772055, 0.9345934896182024], 
             UndirectedEdge[117, 479] -> 
             RGBColor[
              0.1829410540251313, 0.30961302528613777`, 0.9337295944384705], 
             UndirectedEdge[164, 444] -> 
             RGBColor[
              0.4409447203988165, 0.5532899965320492, 0.9501619372363984], 
             UndirectedEdge[32, 334] -> 
             RGBColor[
              0.2032637935146371, 0.3309735130257143, 0.934886944387599], 
             UndirectedEdge[46, 325] -> 
             RGBColor[
              0.2186729430619583, 0.3471695061964588, 0.935764472658525], 
             UndirectedEdge[18, 201] -> 
             RGBColor[
              0.27288253451918126`, 0.4041472239046152, 0.93885162869611], 
             UndirectedEdge[328, 398] -> 
             RGBColor[
              0.2246228179747201, 0.35342320197362953`, 0.9361033092327558], 
             UndirectedEdge[376, 448] -> 
             RGBColor[
              0.33584647853732147`, 0.4645604445371366, 0.9426484491510583], 
             UndirectedEdge[326, 355] -> 
             RGBColor[
              0.642545935987291, 0.7194149561297569, 0.9658722576270347], 
             UndirectedEdge[257, 281] -> 
             RGBColor[
              0.8907382712640035, 0.5148249421887663, 0.2381214507014296], 
             UndirectedEdge[32, 89] -> 
             RGBColor[
              0.26467695340514513`, 0.3954361451619938, 0.9383874999131978], 
             UndirectedEdge[341, 397] -> 
             RGBColor[
              0.9081535473454794, 0.5801965820272107, 0.39469380758390815`], 
             UndirectedEdge[160, 274] -> 
             RGBColor[
              0.24176660566523328`, 0.3714424098152794, 0.9370796225797693], 
             UndirectedEdge[151, 235] -> 
             RGBColor[
              0.21041554321705824`, 0.3384904554100799, 0.9352942259530863], 
             UndirectedEdge[11, 372] -> 
             RGBColor[
              0.49492242636970674`, 0.598728406383233, 0.9539645121894538], 
             UndirectedEdge[99, 295] -> 
             RGBColor[
              0.9822469150718874, 0.9861800274834427, 0.9104424780465525], 
             UndirectedEdge[154, 199] -> 
             RGBColor[
              0.684800695862128, 0.748031110338605, 0.9293475993147051], 
             UndirectedEdge[169, 308] -> 
             RGBColor[
              0.18735840295715342`, 0.31425593908979166`, 0.9339811559252671],
              UndirectedEdge[158, 410] -> 
             RGBColor[
              0.18697773490946556`, 0.31385583283592355`, 0.933959477443099], 
             UndirectedEdge[311, 465] -> 
             RGBColor[
              0.1845169561942322, 0.31126939838383133`, 0.9338193397356624], 
             UndirectedEdge[139, 428] -> 
             RGBColor[
              0.1851867200986532, 0.311973362712862, 0.9338574817991923], 
             UndirectedEdge[113, 364] -> 
             RGBColor[
              0.20055433939420772`, 0.3281257049558297, 0.9347326449837188], 
             UndirectedEdge[89, 475] -> 
             RGBColor[
              0.32310504521526556`, 0.4542790832588659, 0.9418089456639116], 
             UndirectedEdge[375, 441] -> 
             RGBColor[
              0.2121051529687783, 0.3402663423865834, 0.9353904467288932], 
             UndirectedEdge[244, 295] -> 
             RGBColor[
              0.7157587889214511, 0.7746651605070033, 0.9256601695039643], 
             UndirectedEdge[187, 260] -> 
             RGBColor[
              0.21549852964428565`, 0.3438329964250494, 0.9355836945105124], 
             UndirectedEdge[207, 322] -> 
             RGBColor[
              0.8478846282356312, 0.34298703129758157`, 0.19246642213058046`],
              UndirectedEdge[100, 457] -> 
             RGBColor[
              0.7312390426759171, 0.7839598047362808, 0.7277634832098476], 
             UndirectedEdge[364, 416] -> 
             RGBColor[
              0.20681043357905127`, 0.33470125660338146`, 0.9350889202924836],
              UndirectedEdge[313, 386] -> 
             RGBColor[
              0.33341144011418006`, 0.4629153220183585, 0.9424763018784972], 
             UndirectedEdge[31, 472] -> 
             RGBColor[
              0.1875584213311225, 0.31446617108273056`, 0.9339925466757639], 
             UndirectedEdge[37, 49] -> 
             RGBColor[
              0.9278898442559633, 0.7275054583426774, 0.39329233295696453`], 
             UndirectedEdge[201, 406] -> 
             RGBColor[
              0.33697692661979073`, 0.46155170113037025`, 0.9428664961514535],
              UndirectedEdge[245, 376] -> 
             RGBColor[
              0.30751706029421144`, 0.43478442977476833`, 0.9410351306917317],
              UndirectedEdge[58, 215] -> 
             RGBColor[
              0.1890650982052305, 0.3160497840062494, 0.9340783496948156], 
             UndirectedEdge[84, 407] -> 
             RGBColor[
              0.27632252286434345`, 0.40776286976323906`, 0.9390475309433604],
              UndirectedEdge[100, 324] -> 
             RGBColor[
              0.9664798274342277, 0.9712473493741347, 0.7455337650413938], 
             UndirectedEdge[89, 176] -> 
             RGBColor[
              0.31330748759898347`, 0.4457929312912065, 0.9411846539562421], 
             UndirectedEdge[75, 379] -> 
             RGBColor[
              0.8463714309227728, 0.346563167860244, 0.1916128598280513], 
             UndirectedEdge[123, 422] -> 
             RGBColor[
              0.1961933017960193, 0.3235419779343797, 0.9344842903440789], 
             UndirectedEdge[407, 455] -> 
             RGBColor[
              0.44508709777487926`, 0.5526737008147141, 0.9508868778934936], 
             UndirectedEdge[333, 358] -> 
             RGBColor[
              0.22833564415577742`, 0.35732561769669713`, 0.9363147491911328],
              UndirectedEdge[120, 124] -> 
             RGBColor[
              0.18263624540769638`, 0.3092926521032311, 0.9337122360386315], 
             UndirectedEdge[88, 433] -> 
             RGBColor[
              0.18511620603054046`, 0.3118992479564254, 0.9338534661273294], 
             UndirectedEdge[345, 456] -> 
             RGBColor[
              0.1932262687729535, 0.32042343810637863`, 0.9343153222027473], 
             UndirectedEdge[392, 474] -> 
             RGBColor[
              0.23318205607902553`, 0.3624195039082944, 0.9365907451805379], 
             UndirectedEdge[165, 333] -> 
             RGBColor[
              0.26885740704369754`, 0.3999165597200598, 0.9386224036410238], 
             UndirectedEdge[31, 133] -> 
             RGBColor[
              0.1949807850604232, 0.3222675459672669, 0.9344152393097445], 
             UndirectedEdge[171, 208] -> 
             RGBColor[
              0.44865476640412644`, 0.5625521197174839, 0.9499392286265838], 
             UndirectedEdge[284, 472] -> 
             RGBColor[
              0.19498301286010505`, 0.32226988752598323`, 0.9344153661796406],
              UndirectedEdge[196, 427] -> 
             RGBColor[
              0.18925515066577042`, 0.3162495411922988, 0.9340891729012859], 
             UndirectedEdge[179, 334] -> 
             RGBColor[
              0.1934836161981846, 0.32069392656706563`, 0.9343299777579028], 
             UndirectedEdge[97, 233] -> 
             RGBColor[
              0.9755070986726647, 0.9721600768096842, 0.6789609948576975], 
             UndirectedEdge[21, 409] -> 
             RGBColor[
              0.27661821411791565`, 0.40807366001865175`, 0.9390643701228152],
              UndirectedEdge[63, 344] -> 
             RGBColor[
              0.19854348560024537`, 0.326012170122881, 0.9346181298349442], 
             UndirectedEdge[292, 398] -> 
             RGBColor[
              0.19568953649861287`, 0.32301248866624094`, 0.9344556016556456],
              UndirectedEdge[71, 197] -> 
             RGBColor[
              0.2143161876130597, 0.34259027998541636`, 0.9355163618809523], 
             UndirectedEdge[81, 121] -> 
             RGBColor[
              0.22174468237743916`, 0.35039809897655055`, 0.9359394036683106],
              UndirectedEdge[163, 317] -> 
             RGBColor[
              0.8583137676007231, 0.3848962000432028, 0.20095545620474106`], 
             UndirectedEdge[167, 172] -> 
             RGBColor[
              0.23167761735264775`, 0.36083824341994686`, 0.9365050696206882],
              UndirectedEdge[191, 488] -> 
             RGBColor[
              0.18656266374586195`, 0.3134195667259444, 0.9339358397543747], 
             UndirectedEdge[392, 490] -> 
             RGBColor[
              0.2264092533563037, 0.355300858826219, 0.9362050440849425], 
             UndirectedEdge[251, 272] -> 
             RGBColor[
              0.24807843064742718`, 0.378076538064383, 0.937439071674997], 
             UndirectedEdge[66, 255] -> 
             RGBColor[
              0.19752636336653073`, 0.32494311016597255`, 0.9345602062284316],
              UndirectedEdge[177, 194] -> 
             RGBColor[
              0.1852447118397448, 0.312034315709638, 0.9338607843430564], 
             UndirectedEdge[36, 359] -> 
             RGBColor[
              0.9518288028476951, 0.9612683407754878, 0.8690761481825573], 
             UndirectedEdge[46, 377] -> 
             RGBColor[
              0.192250993648715, 0.31939836211478956`, 0.9342597817272121], 
             UndirectedEdge[6, 306] -> 
             RGBColor[
              0.22758223790331983`, 0.3565337399566487, 0.93627184381962], 
             UndirectedEdge[7, 455] -> 
             RGBColor[
              0.5426993192435918, 0.6396267815444932, 0.9571424248654161], 
             UndirectedEdge[84, 482] -> 
             RGBColor[
              0.30394372684162835`, 0.43461012182087044`, 0.9407004986689278],
              UndirectedEdge[83, 97] -> 
             RGBColor[
              0.9918418301129188, 0.9825092007837744, 0.5692119944347548], 
             UndirectedEdge[125, 408] -> 
             RGBColor[
              0.8576169370417068, 0.8896033538181681, 0.9847741152357485], 
             UndirectedEdge[184, 473] -> 
             RGBColor[
              0.4022146970771591, 0.5162489604655307, 0.9476591763750619], 
             UndirectedEdge[410, 422] -> 
             RGBColor[
              0.19439415698617535`, 0.3216509626668643, 0.9343818317087544], 
             UndirectedEdge[202, 283] -> 
             RGBColor[
              0.1845388139830274, 0.3112923723057189, 0.9338205845043986], 
             UndirectedEdge[320, 329] -> 
             RGBColor[
              0.18135868640525998`, 0.3079498565897512, 0.9336394809434219], 
             UndirectedEdge[146, 387] -> 
             RGBColor[
              0.18448194243535776`, 0.3112325967032537, 0.9338173457538927], 
             UndirectedEdge[107, 170] -> 
             RGBColor[
              0.19951076544330998`, 0.3270288425670261, 0.9346732149910444], 
             UndirectedEdge[273, 459] -> 
             RGBColor[
              0.19081936422215473`, 0.3178936288169264, 0.9341782525492754], 
             UndirectedEdge[5, 395] -> 
             RGBColor[
              0.5968586468606165, 0.6828724552519535, 0.9619005753639707], 
             UndirectedEdge[104, 242] -> 
             RGBColor[
              0.9486223107500168, 0.8581914089875718, 0.5941049181072977], 
             UndirectedEdge[422, 437] -> 
             RGBColor[
              0.1942298621222053, 0.32147827834793574`, 0.9343724753593039], 
             UndirectedEdge[29, 177] -> 
             RGBColor[
              0.18440587372207073`, 0.31115264366255413`, 0.9338130137532046],
              UndirectedEdge[202, 285] -> 
             RGBColor[
              0.2005739783770007, 0.32814634677192855`, 0.9347337633947355], 
             UndirectedEdge[182, 460] -> 
             RGBColor[
              0.32283537188163536`, 0.453299157442765, 0.9418190897859463], 
             UndirectedEdge[116, 333] -> 
             RGBColor[
              0.2541335864563355, 0.3844408907385981, 0.937783903840514], 
             UndirectedEdge[405, 472] -> 
             RGBColor[
              0.1823975349558204, 0.3090417522831926, 0.9336986418315376], 
             UndirectedEdge[51, 96] -> 
             RGBColor[
              0.7330134148240908, 0.7867443631188805, 0.8380607137143137], 
             UndirectedEdge[115, 402] -> 
             RGBColor[
              0.20455792141877943`, 0.3323337235054161, 0.9349606430572492], 
             UndirectedEdge[67, 120] -> 
             RGBColor[
              0.18038821966444069`, 0.3069298345140049, 0.9335842142982091], 
             UndirectedEdge[72, 222] -> 
             RGBColor[
              0.20410917934136036`, 0.33186206713015765`, 0.9349350878597946],
              UndirectedEdge[84, 328] -> 
             RGBColor[
              0.2592509748717875, 0.3898195904244037, 0.9380753315402763], 
             UndirectedEdge[123, 401] -> 
             RGBColor[
              0.18328689846403934`, 0.309976529719234, 0.9337492897676354], 
             UndirectedEdge[143, 178] -> 
             RGBColor[
              0.5249805981564001, 0.6252419255466224, 0.9557475422356184], 
             UndirectedEdge[2, 385] -> 
             RGBColor[
              0.1828749868990639, 0.3095435845477431, 0.9337258320133786], 
             UndirectedEdge[113, 487] -> 
             RGBColor[
              0.19472843618281724`, 0.32200231129706014`, 0.9344008684144816],
              UndirectedEdge[12, 430] -> 
             RGBColor[
              0.19779577870573095`, 0.32522628276939103`, 0.9345755490334348],
              UndirectedEdge[72, 344] -> 
             RGBColor[
              0.20069596090134978`, 0.3282745581391582, 0.9347407101190403], 
             UndirectedEdge[127, 221] -> 
             RGBColor[
              0.8972130382069989, 0.8767030519388234, 0.6458996213784399], 
             UndirectedEdge[466, 491] -> 
             RGBColor[
              0.1882565372451065, 0.3151999351714332, 0.9340323033442953], 
             UndirectedEdge[236, 289] -> 
             RGBColor[
              0.20921618528861102`, 0.33722985418359713`, 0.9352259242933523],
              UndirectedEdge[200, 298] -> 
             RGBColor[
              0.26933197029652145`, 0.4004153557878257, 0.9386494293162186], 
             UndirectedEdge[231, 431] -> 
             RGBColor[
              0.5924549682477664, 0.6772918463903979, 0.9625703637800718], 
             UndirectedEdge[171, 238] -> 
             RGBColor[
              0.47869194757503297`, 0.5876627137247235, 0.9521035301009391], 
             UndirectedEdge[276, 306] -> 
             RGBColor[
              0.22718429673725105`, 0.3561154785601833, 0.9362491816589136], 
             UndirectedEdge[294, 296] -> 
             RGBColor[
              0.18486063733978264`, 0.311630629058448, 0.9338389118684709], 
             UndirectedEdge[1, 119] -> 
             RGBColor[
              0.1917982653600388, 0.3189225159787594, 0.9342339995209235], 
             UndirectedEdge[103, 444] -> 
             RGBColor[
              0.4878340995369397, 0.5939032200127712, 0.9531496870124296], 
             UndirectedEdge[331, 486] -> 
             RGBColor[
              0.35738466575242234`, 0.48329439102726157`, 0.9440179635868327],
              UndirectedEdge[100, 281] -> 
             RGBColor[
              0.9058254062967486, 0.5652706313368212, 0.33472136228145205`], 
             UndirectedEdge[161, 477] -> 
             RGBColor[
              0.2058221778675803, 0.33366253719159444`, 0.9350326405917087], 
             UndirectedEdge[391, 475] -> 
             RGBColor[
              0.40482166454825647`, 0.5245203840472975, 0.9471643768884919], 
             UndirectedEdge[2, 312] -> 
             RGBColor[
              0.18958168594798847`, 0.3165927504774426, 0.9341077686025426], 
             UndirectedEdge[264, 341] -> 
             RGBColor[
              0.9299206145630832, 0.7362794821686658, 0.415098303004048], 
             UndirectedEdge[73, 434] -> 
             RGBColor[
              0.755989141506491, 0.7238557905975457, 0.6132283330346036], 
             UndirectedEdge[241, 271] -> 
             RGBColor[
              0.2118628562397169, 0.3400116731618399, 0.935376648288619], 
             UndirectedEdge[49, 51] -> 
             RGBColor[
              0.9945887098983145, 0.9908341225748765, 0.6523926509220856], 
             UndirectedEdge[5, 275] -> 
             RGBColor[
              0.5894443177306294, 0.6768531688525092, 0.9613168922152756], 
             UndirectedEdge[18, 274] -> 
             RGBColor[
              0.2661988733080245, 0.397122272203093, 0.9384710040777253], 
             UndirectedEdge[219, 445] -> 
             RGBColor[
              0.8163225920234214, 0.8145058037505225, 0.6394598956191903], 
             UndirectedEdge[177, 297] -> 
             RGBColor[
              0.18982245259063335`, 0.3168458114843493, 0.9341214799066588], 
             UndirectedEdge[250, 365] -> 
             RGBColor[
              0.21334264494811753`, 0.3415670249183921, 0.9354609200664112], 
             UndirectedEdge[325, 474] -> 
             RGBColor[
              0.2315745275844326, 0.3607298895372839, 0.936499198810896], 
             UndirectedEdge[266, 403] -> 
             RGBColor[
              0.868496130673329, 0.8940798744623377, 0.7590138025565417], 
             UndirectedEdge[214, 470] -> 
             RGBColor[
              0.19107951696482092`, 0.31816706584410515`, 0.9341930678631087],
              UndirectedEdge[152, 481] -> 
             RGBColor[
              0.1947520962377352, 0.322027179514913, 0.9344022158196071], 
             UndirectedEdge[289, 466] -> 
             RGBColor[
              0.20247960652430902`, 0.3301492827785526, 0.9348422860986005], 
             UndirectedEdge[126, 269] -> 
             RGBColor[
              0.5451650588175359, 0.6416285800109227, 0.9573365369169786], 
             UndirectedEdge[183, 396] -> 
             RGBColor[
              0.19720162500749072`, 0.32460178956102026`, 0.9345417128592917],
              UndirectedEdge[54, 99] -> 
             RGBColor[
              0.9846117057177595, 0.9871579291878583, 0.8712517771624386], 
             UndirectedEdge[129, 306] -> 
             RGBColor[
              0.2650729238792713, 0.39593882796415625`, 0.9384068829234508], 
             UndirectedEdge[172, 236] -> 
             RGBColor[
              0.21592574989835334`, 0.34428203199940316`, 0.9356080240719657],
              UndirectedEdge[162, 284] -> 
             RGBColor[
              0.19507811925714236`, 0.3223698503793633, 0.9344207823482545], 
             UndirectedEdge[10, 189] -> 
             RGBColor[
              0.23937944149495205`, 0.3689333489173635, 0.9369436771117647], 
             UndirectedEdge[213, 332] -> 
             RGBColor[
              0.19442260484216423`, 0.3216808631672068, 0.9343834517720682], 
             UndirectedEdge[199, 245] -> 
             RGBColor[
              0.31502975887018714`, 0.4412915516820689, 0.9415138332017744], 
             UndirectedEdge[123, 139] -> 
             RGBColor[
              0.1842229343035432, 0.31096036273465255`, 0.9338025956239542], 
             UndirectedEdge[391, 482] -> 
             RGBColor[
              0.4027433630754207, 0.5227202637699965, 0.9470319493564127], 
             UndirectedEdge[184, 354] -> 
             RGBColor[
              0.425711621643709, 0.5407754370503493, 0.9490035262873733], 
             UndirectedEdge[25, 316] -> 
             RGBColor[
              0.36380395841468005`, 0.4876950626233916, 0.9444694464449066], 
             UndirectedEdge[106, 479] -> 
             RGBColor[
              0.18098277247116215`, 0.30755474721069437`, 0.9336180732009899],
              UndirectedEdge[118, 260] -> 
             RGBColor[
              0.20098092756456265`, 0.3285740761701249, 0.9347569385489398], 
             UndirectedEdge[304, 469] -> 
             RGBColor[
              0.18603078567582654`, 0.3128605291513198, 0.9339055500851292], 
             UndirectedEdge[93, 236] -> 
             RGBColor[
              0.21549489107563347`, 0.3438291720586974, 0.9355834872994104], 
             UndirectedEdge[343, 445] -> 
             RGBColor[
              0.9046747150389304, 0.6218037867421315, 0.25156389718325395`], 
             UndirectedEdge[204, 444] -> 
             RGBColor[
              0.44088363514258455`, 0.5532370875533353, 0.9501580449378868], 
             UndirectedEdge[150, 412] -> 
             RGBColor[
              0.20280807626052344`, 0.33049452529749807`, 0.9348609919641505],
              UndirectedEdge[14, 239] -> 
             RGBColor[
              0.21381228139776098`, 0.3420606426036381, 0.9354876651674535], 
             UndirectedEdge[70, 442] -> 
             RGBColor[
              0.3038237186466454, 0.4310287676162611, 0.9408201768359108], 
             UndirectedEdge[93, 493] -> 
             RGBColor[
              0.24176752917831046`, 0.3714433804860776, 0.9370796751724728], 
             UndirectedEdge[228, 279] -> 
             RGBColor[
              0.23309972747079383`, 0.36233297132110764`, 0.9365860566880932],
              UndirectedEdge[300, 456] -> 
             RGBColor[
              0.21373738250553675`, 0.34198191911904635`, 0.9354833997863443],
              UndirectedEdge[168, 326] -> 
             RGBColor[
              0.509047258388588, 0.6051914915809957, 0.9566219374301776], 
             UndirectedEdge[193, 437] -> 
             RGBColor[
              0.18142173090578886`, 0.3080161203570593, 0.933643071234461], 
             UndirectedEdge[224, 361] -> 
             RGBColor[
              0.21801752264150492`, 0.34648061777850747`, 0.9357271474351878],
              UndirectedEdge[12, 477] -> 
             RGBColor[
              0.19591456128829632`, 0.32324900398759393`, 0.9344684164845236],
              UndirectedEdge[212, 224] -> 
             RGBColor[
              0.19394001881557005`, 0.321173634655535, 0.9343559692117758], 
             UndirectedEdge[220, 490] -> 
             RGBColor[
              0.2165006286676464, 0.34488626603534933`, 0.9356407625674201], 
             UndirectedEdge[175, 208] -> 
             RGBColor[
              0.41214605726916764`, 0.531401932568564, 0.9474825602161108], 
             UndirectedEdge[242, 419] -> 
             RGBColor[
              0.8111996093173061, 0.8527074496896203, 0.9480377397097984], 
             UndirectedEdge[164, 205] -> 
             RGBColor[
              0.2767533263359414, 0.40754264705410376`, 0.9390967072865741], 
             UndirectedEdge[257, 322] -> 
             RGBColor[
              0.8919174314542486, 0.5238884841222806, 0.23925061583127932`], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.7309397602442707, 0.7862269209257184, 0.8874289178221101], 
             UndirectedEdge[26, 67] -> 
             RGBColor[
              0.1828839766938226, 0.30955303339202045`, 0.9337263439688908], 
             UndirectedEdge[366, 488] -> 
             RGBColor[
              0.1825427715517224, 0.30919440515401764`, 0.933706912840816], 
             UndirectedEdge[12, 243] -> 
             RGBColor[
              0.19530733769648173`, 0.3226107734923974, 0.9344338359992765], 
             UndirectedEdge[271, 307] -> 
             RGBColor[
              0.199934386249049, 0.3274740948929682, 0.9346973395692404], 
             UndirectedEdge[9, 352] -> 
             RGBColor[
              0.18859199395283752`, 0.3155525214404422, 0.9340514071075369], 
             UndirectedEdge[404, 431] -> 
             RGBColor[
              0.629039468523406, 0.7060080713241875, 0.9661806387521447], 
             UndirectedEdge[256, 287] -> 
             RGBColor[
              0.30785568445183253`, 0.44064627675886753`, 0.9408528157119771],
              UndirectedEdge[254, 412] -> 
             RGBColor[
              0.19134257547531666`, 0.31844355701750904`, 0.9342080486561213],
              UndirectedEdge[42, 380] -> 
             RGBColor[
              0.19400957405079025`, 0.3212467416178081, 0.9343599302795238], 
             UndirectedEdge[379, 404] -> 
             RGBColor[
              0.8321257348299118, 0.5422647939490768, 0.5790967778488565], 
             UndirectedEdge[134, 424] -> 
             RGBColor[
              0.18880157011833354`, 0.31577279927827495`, 0.9340633421601217],
              UndirectedEdge[38, 253] -> 
             RGBColor[
              0.4481561698945121, 0.5608135534661793, 0.9502685055394262], 
             UndirectedEdge[103, 348] -> 
             RGBColor[
              0.4359422690580296, 0.5517750943296691, 0.9490645720310915], 
             UndirectedEdge[42, 452] -> 
             RGBColor[
              0.21367924169687297`, 0.3419208094428005, 0.9354800887533026], 
             UndirectedEdge[164, 331] -> 
             RGBColor[
              0.3087300351184425, 0.44115219542494855`, 0.940917733546436], 
             UndirectedEdge[6, 181] -> 
             RGBColor[
              0.2199559451719783, 0.348518022761122, 0.9358375377306591], 
             UndirectedEdge[172, 197] -> 
             RGBColor[
              0.22719289983545946`, 0.3561245209618682, 0.9362496715926294], 
             UndirectedEdge[80, 258] -> 
             RGBColor[
              0.38129839578489, 0.5046832386394303, 0.9455169745038486], 
             UndirectedEdge[223, 268] -> 
             RGBColor[
              0.19724310055792588`, 0.32464538299422946`, 0.9345440748305314],
              UndirectedEdge[5, 69] -> 
             RGBColor[
              0.5662162318507189, 0.6577114998480007, 0.959566779515417], 
             UndirectedEdge[306, 486] -> 
             RGBColor[
              0.327052321983306, 0.4514131745442476, 0.942290581481863], 
             UndirectedEdge[5, 348] -> 
             RGBColor[
              0.575828354505173, 0.6657991165139304, 0.9602449937132509], 
             UndirectedEdge[279, 409] -> 
             RGBColor[
              0.23060819410886862`, 0.3597142117853851, 0.9364441675490249], 
             UndirectedEdge[463, 483] -> 
             RGBColor[
              0.5035999579863275, 0.6078494794543214, 0.954073961892099], 
             UndirectedEdge[351, 371] -> 
             RGBColor[
              0.2471362919389416, 0.37708629054672044`, 0.937385418269318], 
             UndirectedEdge[335, 421] -> 
             RGBColor[
              0.19735590244149465`, 0.3247639449259127, 0.9345504987309252], 
             UndirectedEdge[259, 418] -> 
             RGBColor[
              0.5798892585592409, 0.6691924959032061, 0.9604986680920036], 
             UndirectedEdge[168, 302] -> 
             RGBColor[
              0.268736668858344, 0.3997896562320101, 0.9386155277799839], 
             UndirectedEdge[87, 336] -> 
             RGBColor[
              0.4668814361724666, 0.5741090231571706, 0.9522620155496091], 
             UndirectedEdge[36, 266] -> 
             RGBColor[
              0.9938574384892986, 0.9902625241719002, 0.644943793687154], 
             UndirectedEdge[161, 430] -> 
             RGBColor[
              0.2077033952850149, 0.33563981597339154`, 0.9351397731406197], 
             UndirectedEdge[220, 412] -> 
             RGBColor[
              0.2036444979201258, 0.3313736574939363, 0.9349086249402898], 
             UndirectedEdge[372, 404] -> 
             RGBColor[
              0.7255490713882455, 0.7852295819730946, 0.9735376602371271], 
             UndirectedEdge[38, 287] -> 
             RGBColor[
              0.4114868433754372, 0.5286278492274263, 0.9479475143104742], 
             UndirectedEdge[171, 497] -> 
             RGBColor[
              0.47443851953832683`, 0.5842095892297761, 0.9517686846650694], 
             UndirectedEdge[246, 411] -> 
             RGBColor[
              0.2605541594338602, 0.3911893200258155, 0.9381495459731974], 
             UndirectedEdge[75, 303] -> 
             RGBColor[
              0.853058182050049, 0.3979604671775163, 0.19801610025913619`], 
             UndirectedEdge[23, 39] -> 
             RGBColor[
              0.3397705873831411, 0.4630597387061178, 0.9430778872171774], 
             UndirectedEdge[61, 391] -> 
             RGBColor[
              0.731686882991318, 0.7866873766200184, 0.8813805065527239], 
             UndirectedEdge[19, 200] -> 
             RGBColor[
              0.23309658772441674`, 0.3623296712485939, 0.936585877884182], 
             UndirectedEdge[208, 403] -> 
             RGBColor[
              0.5850117948684971, 0.6717049428230532, 0.961732098971587], 
             UndirectedEdge[108, 378] -> 
             RGBColor[
              0.20828889068141454`, 0.33625520875755976`, 0.9351731162372818],
              UndirectedEdge[10, 451] -> 
             RGBColor[
              0.2159367879573847, 0.34429363369929844`, 0.9356086526730982], 
             UndirectedEdge[199, 262] -> 
             RGBColor[
              0.36465083425503464`, 0.49026395757304103`, 0.944456206604027], 
             UndirectedEdge[3, 401] -> 
             RGBColor[
              0.18219297080333685`, 0.308826742388816, 0.9336869922056792], 
             UndirectedEdge[241, 311] -> 
             RGBColor[
              0.2028072709740812, 0.33049367889038916`, 0.934860946104279], 
             UndirectedEdge[179, 255] -> 
             RGBColor[
              0.19864123735537692`, 0.32611491341534343`, 0.9346236966527881],
              UndirectedEdge[276, 462] -> 
             RGBColor[
              0.20183278400452248`, 0.3294694312993405, 0.9348054505129868], 
             UndirectedEdge[167, 289] -> 
             RGBColor[
              0.2249680527429054, 0.35378606560414083`, 0.9361229698420748], 
             UndirectedEdge[164, 348] -> 
             RGBColor[
              0.38905288991990644`, 0.5111618708489473, 0.9460768222550604], 
             UndirectedEdge[18, 172] -> 
             RGBColor[
              0.2559027333199868, 0.38630037626268543`, 0.9378846541371808], 
             UndirectedEdge[289, 300] -> 
             RGBColor[
              0.2209681235766699, 0.34958188644027033`, 0.9358951797934225], 
             UndirectedEdge[59, 188] -> 
             RGBColor[
              0.24348630056862833`, 0.373249918193702, 0.937177556660457], 
             UndirectedEdge[352, 357] -> 
             RGBColor[
              0.185968194480225, 0.3127947418362315, 0.9339019856091351], 
             UndirectedEdge[161, 409] -> 
             RGBColor[
              0.23354210119449076`, 0.36279793415282724`, 0.9366112492172245],
              UndirectedEdge[39, 157] -> 
             RGBColor[
              0.2733433157427147, 0.4046315341857658, 0.9388778695051255], 
             UndirectedEdge[216, 398] -> 
             RGBColor[
              0.20308712437898663`, 0.33078782256267547`, 0.9348768833416823],
              UndirectedEdge[279, 396] -> 
             RGBColor[
              0.2027106095200159, 0.3303920815734764, 0.9348554413774677], 
             UndirectedEdge[103, 390] -> 
             RGBColor[
              0.3328589413831152, 0.4578427188183445, 0.9426093080634266], 
             UndirectedEdge[128, 296] -> 
             RGBColor[
              0.1882426629696768, 0.3151853524282767, 0.9340315132248347], 
             UndirectedEdge[362, 369] -> 
             RGBColor[
              0.1806318866536843, 0.30718594396907933`, 0.9335980907727736], 
             UndirectedEdge[86, 412] -> 
             RGBColor[
              0.18778375020070825`, 0.3147030060113407, 0.9340053788215426], 
             UndirectedEdge[261, 299] -> 
             RGBColor[
              0.2846830813812443, 0.4146506586338333, 0.9395932092741723], 
             UndirectedEdge[208, 266] -> 
             RGBColor[
              0.7100990368535118, 0.7663088762344812, 0.7456861929885767], 
             UndirectedEdge[211, 236] -> 
             RGBColor[
              0.1979212488225095, 0.32535815981739014`, 0.934582694370969], 
             UndirectedEdge[19, 124] -> 
             RGBColor[
              0.1942932572468809, 0.3215449106434528, 0.9343760856178694], 
             UndirectedEdge[319, 330] -> 
             RGBColor[
              0.18522178171588122`, 0.3120102146956035, 0.9338594785064245], 
             UndirectedEdge[137, 267] -> 
             RGBColor[
              0.22045636616771785`, 0.34904399695616795`, 0.93586603596606], 
             UndirectedEdge[23, 240] -> 
             RGBColor[
              0.7133780917330446, 0.7699270698367418, 0.8123932263629633], 
             UndirectedEdge[135, 369] -> 
             RGBColor[
              0.18101136995755066`, 0.307584804982074, 0.9336197017855334], 
             UndirectedEdge[13, 335] -> 
             RGBColor[
              0.23166019252299075`, 0.36081992881917935`, 0.936504077302417], 
             UndirectedEdge[176, 178] -> 
             RGBColor[
              0.3931214338805177, 0.5144895563820213, 0.9463902997884908], 
             UndirectedEdge[335, 459] -> 
             RGBColor[
              0.2024275249318897, 0.3300945417227562, 0.93483932012896], 
             UndirectedEdge[83, 326] -> 
             RGBColor[
              0.8603044472818449, 0.8888437109835485, 0.8510148449573589], 
             UndirectedEdge[33, 76] -> 
             RGBColor[
              0.3333497551271607, 0.45830089859572654`, 0.9426393717347399], 
             UndirectedEdge[13, 285] -> 
             RGBColor[
              0.2336665281569335, 0.36292871477947963`, 0.9366183351486626], 
             UndirectedEdge[225, 309] -> 
             RGBColor[
              0.18608052902366917`, 0.31291281256381276`, 0.9339083828952002],
              UndirectedEdge[242, 499] -> 
             RGBColor[
              0.8008428775112291, 0.844405505952868, 0.9471498665869478], 
             UndirectedEdge[13, 287] -> 
             RGBColor[
              0.2785495730651827, 0.41010364072745936`, 0.9391743581576726], 
             UndirectedEdge[265, 270] -> 
             RGBColor[
              0.18221828136351503`, 0.30885334539234544`, 0.9336884336046377],
              UndirectedEdge[191, 311] -> 
             RGBColor[
              0.19029060642002155`, 0.31733787084170345`, 0.934148140574671], 
             UndirectedEdge[47, 452] -> 
             RGBColor[
              0.2542089051352215, 0.3845200554455873, 0.9377881931278527], 
             UndirectedEdge[14, 80] -> 
             RGBColor[
              0.28919811932082623`, 0.417720629815705, 0.9399116866604884], 
             UndirectedEdge[152, 292] -> 
             RGBColor[
              0.18467767702367152`, 0.3114383261658612, 0.9338284925491338], 
             UndirectedEdge[133, 311] -> 
             RGBColor[
              0.19398258593487913`, 0.3212183753968402, 0.9343583933462479], 
             UndirectedEdge[187, 398] -> 
             RGBColor[
              0.21375269941056224`, 0.341998018157376, 0.9354842720614263], 
             UndirectedEdge[130, 442] -> 
             RGBColor[
              0.2704116943765009, 0.4015502142543449, 0.9387109180052648], 
             UndirectedEdge[304, 433] -> 
             RGBColor[
              0.1856912324704567, 0.31250363720355945`, 0.9338862130324074], 
             UndirectedEdge[354, 409] -> 
             RGBColor[
              0.28191067367276634`, 0.4134660896464276, 0.9393720026838029], 
             UndirectedEdge[29, 412] -> 
             RGBColor[
              0.18734250753660958`, 0.3142392319949723, 0.9339802507045822], 
             UndirectedEdge[295, 391] -> 
             RGBColor[
              0.7289553207863748, 0.7855578054503277, 0.9266495613450138], 
             UndirectedEdge[21, 298] -> 
             RGBColor[
              0.2878456584957702, 0.4198744159208656, 0.9397037564706185], 
             UndirectedEdge[383, 395] -> 
             RGBColor[
              0.3859577461997916, 0.503550871102866, 0.9463338532888385], 
             UndirectedEdge[133, 241] -> 
             RGBColor[
              0.2068052594645497, 0.3346958182809826, 0.9350886256343172], 
             UndirectedEdge[142, 473] -> 
             RGBColor[
              0.23965328121814944`, 0.36922117182888525`, 0.9369592718788913],
              UndirectedEdge[95, 330] -> 
             RGBColor[
              0.18713069149999506`, 0.314016599910578, 0.9339681880946508], 
             UndirectedEdge[275, 431] -> 
             RGBColor[
              0.4552821797756804, 0.5677869422920205, 0.9505011954058309], 
             UndirectedEdge[180, 474] -> 
             RGBColor[
              0.24632928568632426`, 0.37623807580806795`, 0.9373394604570903],
              UndirectedEdge[82, 173] -> 
             RGBColor[
              0.6203596764497656, 0.7014764485955354, 0.964075560146658], 
             UndirectedEdge[205, 230] -> 
             RGBColor[
              0.22168982682145016`, 0.35034044230916306`, 0.9359362797255486],
              UndirectedEdge[460, 463] -> 
             RGBColor[
              0.42791636353987605`, 0.5415498055841811, 0.9492787976467367], 
             UndirectedEdge[121, 500] -> 
             RGBColor[
              0.20306057228198376`, 0.33075991462522525`, 0.9348753712390383],
              UndirectedEdge[88, 241] -> 
             RGBColor[
              0.2025944621469051, 0.33027000332016815`, 0.9348488269563937], 
             UndirectedEdge[60, 73] -> 
             RGBColor[
              0.781195634641831, 0.8278300365608096, 0.9249593462199677], 
             UndirectedEdge[75, 400] -> 
             RGBColor[
              0.9275933480888754, 0.7357010879276322, 0.5134508624919265], 
             UndirectedEdge[141, 274] -> 
             RGBColor[
              0.2256966978230941, 0.35455191778218553`, 0.9361644651014577], 
             UndirectedEdge[299, 448] -> 
             RGBColor[
              0.2703287280609633, 0.40146301139634666`, 0.9387061931963326], 
             UndirectedEdge[160, 389] -> 
             RGBColor[
              0.21718512492406264`, 0.34560571500041215`, 0.9356797436166016],
              UndirectedEdge[24, 268] -> 
             RGBColor[
              0.18579615740306293`, 0.3126139199603535, 0.9338921883520968], 
             UndirectedEdge[386, 498] -> 
             RGBColor[
              0.540094387984412, 0.6311849610997022, 0.9594410817544053], 
             UndirectedEdge[350, 476] -> 
             RGBColor[
              0.18247717121909524`, 0.3091254550451252, 0.9337031769989198], 
             UndirectedEdge[180, 331] -> 
             RGBColor[
              0.2822898900471109, 0.4140349510252597, 0.9393873636764902], 
             UndirectedEdge[225, 252] -> 
             RGBColor[
              0.18313599846224066`, 0.30981792424973087`, 0.9337406962357694],
              UndirectedEdge[100, 203] -> 
             RGBColor[
              0.9191489665110915, 0.667681353565574, 0.3474800185895157], 
             UndirectedEdge[445, 471] -> 
             RGBColor[
              0.9599777422905198, 0.9272913458979556, 0.6345862231732597], 
             UndirectedEdge[373, 498] -> 
             RGBColor[
              0.8827929559209364, 0.907189051483757, 0.8884954173694475], 
             UndirectedEdge[102, 309] -> 
             RGBColor[
              0.19381918087775277`, 0.3210466263213213, 0.9343490876699807], 
             UndirectedEdge[46, 86] -> 
             RGBColor[
              0.19451109914847642`, 0.321773876294004, 0.9343884913918972], 
             UndirectedEdge[294, 385] -> 
             RGBColor[
              0.18452375420061845`, 0.3112765435195617, 0.9338197268720694], 
             UndirectedEdge[27, 29] -> 
             RGBColor[
              0.18482045324878804`, 0.31158839303099417`, 0.9338366234439357],
              UndirectedEdge[274, 284] -> 
             RGBColor[
              0.22545727776759072`, 0.3543002721237432, 0.936150830483487], 
             UndirectedEdge[284, 300] -> 
             RGBColor[
              0.2193467291603231, 0.3478776981063463, 0.9358028437800496], 
             UndirectedEdge[159, 453] -> 
             RGBColor[
              0.23602331412857852`, 0.36540584626453976`, 0.9367525506231953],
              UndirectedEdge[229, 232] -> 
             RGBColor[
              0.2566501782178637, 0.3870859882410977, 0.9379272200183691], 
             UndirectedEdge[259, 431] -> 
             RGBColor[
              0.552262608455937, 0.6458932694477724, 0.9585643649749793], 
             UndirectedEdge[112, 483] -> 
             RGBColor[
              0.7227411345359493, 0.7787563213495963, 0.8541899154691762], 
             UndirectedEdge[78, 376] -> 
             RGBColor[
              0.4205848118936931, 0.5382565536141679, 0.9481458786566228], 
             UndirectedEdge[76, 351] -> 
             RGBColor[
              0.32530926006899097`, 0.449849828492759, 0.9421814774360235], 
             UndirectedEdge[178, 498] -> 
             RGBColor[
              0.6219478547908555, 0.7019387588473889, 0.96476604218581], 
             UndirectedEdge[400, 431] -> 
             RGBColor[
              0.7055601740591597, 0.7646836770228431, 0.882816923995621], 
             UndirectedEdge[18, 432] -> 
             RGBColor[
              0.2897732046951418, 0.4219003891898929, 0.9398135273751238], 
             UndirectedEdge[220, 325] -> 
             RGBColor[
              0.22533443478540557`, 0.3541711563607717, 0.9361438347573814], 
             UndirectedEdge[353, 380] -> 
             RGBColor[
              0.18408835379335264`, 0.31081891008554513`, 0.9337949314629927],
              UndirectedEdge[5, 355] -> 
             RGBColor[
              0.624643054436057, 0.7054290889949936, 0.9640878657059478], 
             UndirectedEdge[367, 441] -> 
             RGBColor[
              0.20930859557874099`, 0.3373269832576745, 0.9352311869226664], 
             UndirectedEdge[21, 287] -> 
             RGBColor[
              0.30207832712053356`, 0.43483385304880307`, 0.9405142858934524],
              UndirectedEdge[175, 182] -> 
             RGBColor[
              0.3713372775098073, 0.4960554186499155, 0.9448822608556314], 
             UndirectedEdge[70, 371] -> 
             RGBColor[
              0.31191266997486483`, 0.4395307683313558, 0.9412808306475218], 
             UndirectedEdge[217, 496] -> 
             RGBColor[
              0.1835288398725976, 0.31023082547960007`, 0.9337630679729325], 
             UndirectedEdge[195, 292] -> 
             RGBColor[
              0.18660739700750423`, 0.31346658422018303`, 0.9339383872474483],
              UndirectedEdge[161, 285] -> 
             RGBColor[
              0.21411916928885952`, 0.34238320123499877`, 0.9355051419788516],
              UndirectedEdge[168, 370] -> 
             RGBColor[
              0.2607361826498604, 0.3913806379667703, 0.9381599119260695], 
             UndirectedEdge[50, 173] -> 
             RGBColor[
              0.800480264278042, 0.8445485570290475, 0.9806185434355512], 
             UndirectedEdge[19, 188] -> 
             RGBColor[
              0.21359720872912316`, 0.3418345875925049, 0.9354754170971461], 
             UndirectedEdge[147, 323] -> 
             RGBColor[
              0.905895222039182, 0.5694593928427707, 0.46819019532102185`], 
             UndirectedEdge[255, 260] -> 
             RGBColor[
              0.2034606107913817, 0.33118038046250897`, 0.9348981528403446], 
             UndirectedEdge[29, 350] -> 
             RGBColor[
              0.18297683433485876`, 0.309650632660264, 0.9337316320741772], 
             UndirectedEdge[348, 400] -> 
             RGBColor[
              0.7259744000228323, 0.7821275326457193, 0.8841834386643934], 
             UndirectedEdge[26, 124] -> 
             RGBColor[
              0.18513200243707828`, 0.31191585098124663`, 0.9338543657093131],
              UndirectedEdge[18, 93] -> 
             RGBColor[
              0.25547187449726694`, 0.38584751632197967`, 0.9378601173646254],
              UndirectedEdge[64, 223] -> 
             RGBColor[
              0.19649530119615788`, 0.32385939845179323`, 0.9345014887631486],
              UndirectedEdge[12, 335] -> 
             RGBColor[
              0.20220521707563277`, 0.32986088207069797`, 0.9348266600254211],
              UndirectedEdge[143, 498] -> 
             RGBColor[
              0.6776190672953443, 0.7471351571180758, 0.9691486839645342], 
             UndirectedEdge[44, 92] -> 
             RGBColor[
              0.2754748024457604, 0.40687186185472934`, 0.938999254519612], 
             UndirectedEdge[274, 389] -> 
             RGBColor[
              0.2195028960405469, 0.34804183939901356`, 0.9358117372528503], 
             UndirectedEdge[247, 401] -> 
             RGBColor[
              0.1825033131056717, 0.3091529318254084, 0.9337046657406869], 
             UndirectedEdge[111, 182] -> 
             RGBColor[
              0.35579432343932743`, 0.4825928930456521, 0.9438918775663551], 
             UndirectedEdge[157, 190] -> 
             RGBColor[
              0.2578198120642154, 0.3883153475726824, 0.9379938289356007], 
             UndirectedEdge[100, 360] -> 
             RGBColor[
              0.7946952326726424, 0.8354763984444047, 0.7327589869340729], 
             UndirectedEdge[59, 468] -> 
             RGBColor[
              0.24224871187808175`, 0.37194913401228247`, 0.9371070778153788],
              UndirectedEdge[101, 129] -> 
             RGBColor[
              0.2672434934849943, 0.39822023424183295`, 0.9385304936514267], 
             UndirectedEdge[180, 382] -> 
             RGBColor[
              0.23760741054514092`, 0.36707083203586066`, 0.9368427625706579],
              UndirectedEdge[145, 402] -> 
             RGBColor[
              0.21358684811844986`, 0.34182369793378664`, 0.9354748270756954],
              UndirectedEdge[90, 263] -> 
             RGBColor[
              0.24334458110817345`, 0.37310096205523113`, 0.9371694859468394],
              UndirectedEdge[98, 276] -> 
             RGBColor[
              0.20095020339638087`, 0.3285417831213411, 0.9347551888530141], 
             UndirectedEdge[224, 464] -> 
             RGBColor[
              0.20419415303821636`, 0.3319513798731969, 0.9349399269861233], 
             UndirectedEdge[261, 313] -> 
             RGBColor[
              0.3452565934007724, 0.4734656409279675, 0.9432204227264471], 
             UndirectedEdge[78, 219] -> 
             RGBColor[
              0.5697935423105139, 0.6612069230140997, 0.9595599186442647], 
             UndirectedEdge[393, 424] -> 
             RGBColor[
              0.20739385044843295`, 0.3353144647238677, 0.935122145020107], 
             UndirectedEdge[169, 211] -> 
             RGBColor[
              0.1856477523702797, 0.3124579368614757, 0.9338837369050252], 
             UndirectedEdge[176, 482] -> 
             RGBColor[
              0.3246527382525704, 0.45561961717846555`, 0.9419075632956775], 
             UndirectedEdge[35, 94] -> 
             RGBColor[
              0.18328807136271902`, 0.3099777625101124, 0.9337493565624799], 
             UndirectedEdge[114, 296] -> 
             RGBColor[
              0.18183178255671295`, 0.30844711064095676`, 0.9336664230693641],
              UndirectedEdge[130, 175] -> 
             RGBColor[
              0.350298253723786, 0.4772937364222603, 0.943561398674819], 
             UndirectedEdge[189, 383] -> 
             RGBColor[
              0.25987325139717643`, 0.39047364250719796`, 0.9381107692678216],
              UndirectedEdge[139, 437] -> 
             RGBColor[
              0.18225949462972918`, 0.3088966631482086, 0.9336907806391791], 
             UndirectedEdge[56, 324] -> 
             RGBColor[
              0.6732900844799101, 0.7406929401963493, 0.9670229089652596], 
             UndirectedEdge[398, 399] -> 
             RGBColor[
              0.2070690587330349, 0.3349730880380002, 0.9351036486124014], 
             UndirectedEdge[405, 429] -> 
             RGBColor[
              0.1868041703990252, 0.3136734055308251, 0.9339495932009951], 
             UndirectedEdge[12, 318] -> 
             RGBColor[
              0.19600810188078815`, 0.32334732108111897`, 0.9344737434828851],
              UndirectedEdge[11, 205] -> 
             RGBColor[
              0.3065274858845748, 0.4333315275623586, 0.9409938904047574], 
             UndirectedEdge[226, 389] -> 
             RGBColor[
              0.19095055240575043`, 0.3180315159156967, 0.9341857235222557], 
             UndirectedEdge[294, 327] -> 
             RGBColor[
              0.18563559838764718`, 0.312445162255122, 0.9338830447536945], 
             UndirectedEdge[167, 218] -> 
             RGBColor[
              0.26286988224919927`, 0.3936232915300437, 0.9382814229617262], 
             UndirectedEdge[217, 481] -> 
             RGBColor[
              0.19325559530187433`, 0.3204542621476837, 0.9343169923051846], 
             UndirectedEdge[247, 309] -> 
             RGBColor[
              0.18623761794577917`, 0.3130779229809633, 0.933917328876922], 
             UndirectedEdge[79, 234] -> 
             RGBColor[
              0.9063126289426009, 0.8289774045041336, 0.6243163382349994], 
             UndirectedEdge[331, 372] -> 
             RGBColor[
              0.4578529646135995, 0.56594472517835, 0.9516272296801642], 
             UndirectedEdge[27, 484] -> 
             RGBColor[
              0.1850117059565009, 0.3117894117529224, 0.933847515002707], 
             UndirectedEdge[103, 326] -> 
             RGBColor[
              0.56759306260054, 0.6573833324020449, 0.9602981460928508], 
             UndirectedEdge[155, 394] -> 
             RGBColor[
              0.1886886358497215, 0.3156540982015175, 0.9340569107205956], 
             UndirectedEdge[433, 469] -> 
             RGBColor[
              0.18101298547639227`, 0.3075865029948064, 0.9336197937869416], 
             UndirectedEdge[65, 412] -> 
             RGBColor[
              0.1867174620390582, 0.3135822695468723, 0.9339446552881686], 
             UndirectedEdge[13, 161] -> 
             RGBColor[
              0.23339794827523738`, 0.36264642029486893`, 0.9366030399217282],
              UndirectedEdge[229, 480] -> 
             RGBColor[
              0.23910094988203007`, 0.36864063657479446`, 0.9369278174264002],
              UndirectedEdge[32, 448] -> 
             RGBColor[
              0.26012823284654724`, 0.3907416441772443, 0.938125290084152], 
             UndirectedEdge[251, 453] -> 
             RGBColor[
              0.23943021557072935`, 0.3689867156902678, 0.9369465686202667], 
             UndirectedEdge[282, 310] -> 
             RGBColor[
              0.6707630336058359, 0.74272444693153, 0.9678190486190441], 
             UndirectedEdge[392, 473] -> 
             RGBColor[
              0.2502222365996353, 0.3803298140453018, 0.9375611582524985], 
             UndirectedEdge[222, 344] -> 
             RGBColor[
              0.1936890488951341, 0.3209098493567448, 0.9343416768460837], 
             UndirectedEdge[266, 440] -> 
             RGBColor[
              0.9426079391450114, 0.7947470752330569, 0.3871278708766489], 
             UndirectedEdge[16, 361] -> 
             RGBColor[
              0.2501087241581385, 0.3802105052721842, 0.9375546938868818], 
             UndirectedEdge[412, 426] -> 
             RGBColor[
              0.18880630124033773`, 0.3157777719874718, 0.9340636115905208], 
             UndirectedEdge[274, 460] -> 
             RGBColor[
              0.27237898950751444`, 0.4036179661707557, 0.9388229525526237], 
             UndirectedEdge[180, 230] -> 
             RGBColor[
              0.2345216927400936, 0.3638275469769471, 0.9366670355065708], 
             UndirectedEdge[375, 450] -> 
             RGBColor[
              0.20913463295766446`, 0.3371441375130559, 0.9352212800087508], 
             UndirectedEdge[6, 123] -> 
             RGBColor[
              0.20012045196386746`, 0.3276696617564901, 0.9347079357364398], 
             UndirectedEdge[170, 466] -> 
             RGBColor[
              0.19131064180456064`, 0.3184099927048328, 0.9342062300808134], 
             UndirectedEdge[267, 280] -> 
             RGBColor[
              0.24136535807007609`, 0.3710206731522022, 0.9370567721228178], 
             UndirectedEdge[52, 214] -> 
             RGBColor[
              0.18377002501748835`, 0.3104843263589016, 0.9337768031101326], 
             UndirectedEdge[358, 386] -> 
             RGBColor[
              0.2652427547751048, 0.39611733100357804`, 0.9384165545417262], 
             UndirectedEdge[230, 413] -> 
             RGBColor[
              0.21810416040748024`, 0.34657167956369916`, 0.9357320813277911],
              UndirectedEdge[53, 207] -> 
             RGBColor[
              0.8538308363641018, 0.3886921926180247, 0.19816051774968563`], 
             UndirectedEdge[188, 256] -> 
             RGBColor[
              0.26776710539076976`, 0.3985106384029728, 0.9385698304401877], 
             UndirectedEdge[38, 87] -> 
             RGBColor[
              0.4136160612646935, 0.5308657922292461, 0.9480687701193717], 
             UndirectedEdge[22, 52] -> 
             RGBColor[
              0.18089659272171946`, 0.3074641668299184, 0.9336131653917505], 
             UndirectedEdge[160, 460] -> 
             RGBColor[
              0.27006121839103014`, 0.4011818417721542, 0.938690958916375], 
             UndirectedEdge[63, 159] -> 
             RGBColor[
              0.2194636807819041, 0.34800062167578893`, 0.9358095040018843], 
             UndirectedEdge[285, 430] -> 
             RGBColor[
              0.20797197516671106`, 0.33592211045800224`, 0.935155068367554], 
             UndirectedEdge[132, 356] -> 
             RGBColor[
              0.2588153820462965, 0.38936175474663237`, 0.9380505251732665], 
             UndirectedEdge[99, 373] -> 
             RGBColor[
              0.9853487541189616, 0.9874627176430353, 0.859036977734402], 
             UndirectedEdge[243, 396] -> 
             RGBColor[
              0.19700888147424034`, 0.32439920388692833`, 0.9345307364002116],
              UndirectedEdge[118, 292] -> 
             RGBColor[
              0.188665488336347, 0.3156297686973238, 0.9340555925039526], 
             UndirectedEdge[84, 176] -> 
             RGBColor[
              0.29622447069818203`, 0.4279240901305121, 0.9402086344933376], 
             UndirectedEdge[334, 385] -> 
             RGBColor[
              0.18420532827080235`, 0.310941857677955, 0.9338015929864353], 
             UndirectedEdge[25, 325] -> 
             RGBColor[
              0.26126519476067855`, 0.3919366632365452, 0.9381900383831774], 
             UndirectedEdge[321, 397] -> 
             RGBColor[
              0.9037224589823456, 0.5792136748312032, 0.5298753084241274], 
             UndirectedEdge[201, 235] -> 
             RGBColor[
              0.23728480229023638`, 0.36673175030541116`, 0.9368243905077971],
              UndirectedEdge[321, 498] -> 
             RGBColor[
              0.8800107385388454, 0.9060385330965369, 0.934603959538476], 
             UndirectedEdge[368, 492] -> 
             RGBColor[
              0.18092029968887635`, 0.3074890843555088, 0.9336145154684589], 
             UndirectedEdge[239, 387] -> 
             RGBColor[
              0.1927675658632359, 0.3199413122648211, 0.934289199750629], 
             UndirectedEdge[196, 500] -> 
             RGBColor[
              0.1964924261713618, 0.32385637661844546`, 0.9345013250347398], 
             UndirectedEdge[122, 185] -> 
             RGBColor[
              0.19860974920189184`, 0.3260818173695664, 0.9346219034490297], 
             UndirectedEdge[350, 377] -> 
             RGBColor[
              0.181157971499196, 0.3077388924974179, 0.9336280505264527], 
             UndirectedEdge[315, 353] -> 
             RGBColor[
              0.18205882341933505`, 0.3086857449827948, 0.9336793527106135], 
             UndirectedEdge[102, 480] -> 
             RGBColor[
              0.2214017905721769, 0.3500376979486238, 0.9359198764872638], 
             UndirectedEdge[127, 253] -> 
             RGBColor[
              0.604821677598294, 0.6851926412626169, 0.9645634759762418], 
             UndirectedEdge[159, 192] -> 
             RGBColor[
              0.27255273720121065`, 0.4034082682269394, 0.9388472119027095], 
             UndirectedEdge[201, 289] -> 
             RGBColor[
              0.23376233339509425`, 0.3630294121591895, 0.9366237911152446], 
             UndirectedEdge[29, 194] -> 
             RGBColor[
              0.18526819594198288`, 0.31205899899006834`, 0.9338621217279373],
              UndirectedEdge[79, 388] -> 
             RGBColor[
              0.6074674522288179, 0.6856239979057058, 0.9655884516290124], 
             UndirectedEdge[246, 402] -> 
             RGBColor[
              0.22901412567720097`, 0.3580387447939263, 0.9363533877100543], 
             UndirectedEdge[185, 398] -> 
             RGBColor[
              0.20890004242653637`, 0.3368975679909415, 0.9352079204250486], 
             UndirectedEdge[133, 304] -> 
             RGBColor[
              0.19434480354761932`, 0.3215990890737532, 0.9343790211034406], 
             UndirectedEdge[107, 314] -> 
             RGBColor[
              0.2370472271918243, 0.36648204381384886`, 0.9368108609574035], 
             UndirectedEdge[13, 279] -> 
             RGBColor[
              0.23046404118961528`, 0.35956269792742684`, 0.9364359582535287],
              UndirectedEdge[180, 418] -> 
             RGBColor[
              0.3698251689882062, 0.48989999728181594`, 0.9451142408333664], 
             UndirectedEdge[112, 207] -> 
             RGBColor[
              0.9342142442860358, 0.7583914671293646, 0.48787682484366524`], 
             UndirectedEdge[308, 369] -> 
             RGBColor[
              0.18646563701697516`, 0.31331758548203437`, 0.9339303142257027],
              UndirectedEdge[45, 292] -> 
             RGBColor[
              0.193148625604734, 0.3203418302137187, 0.93431090053918], 
             UndirectedEdge[348, 418] -> 
             RGBColor[
              0.4692928666535278, 0.5800321164088754, 0.9513636000208304], 
             UndirectedEdge[51, 264] -> 
             RGBColor[
              0.930398195461806, 0.7373009794201983, 0.46708003654237346`], 
             UndirectedEdge[201, 218] -> 
             RGBColor[
              0.27166416290138806`, 0.4028666380850924, 0.938782244234896], 
             UndirectedEdge[262, 376] -> 
             RGBColor[
              0.3571381356790589, 0.48375683566574046`, 0.9439775040939842], 
             UndirectedEdge[304, 307] -> 
             RGBColor[
              0.19124101859615344`, 0.3183368142984305, 0.9342022651420929], 
             UndirectedEdge[8, 166] -> 
             RGBColor[
              0.19658418244763454`, 0.3239528182824921, 0.9345065504189323], 
             UndirectedEdge[66, 312] -> 
             RGBColor[
              0.19642559622123856`, 0.32378613410360235`, 0.9344975191679463],
              UndirectedEdge[202, 430] -> 
             RGBColor[
              0.19415820437315612`, 0.32140296151032133`, 0.9343683945565036],
              UndirectedEdge[348, 404] -> 
             RGBColor[
              0.6494536944870786, 0.7234519269470636, 0.967547153420917], 
             UndirectedEdge[1, 113] -> 
             RGBColor[
              0.1979971628023344, 0.3254379502234105, 0.9345870175598152], 
             UndirectedEdge[29, 377] -> 
             RGBColor[
              0.18261049498864607`, 0.3092655867801383, 0.9337107695903608], 
             UndirectedEdge[259, 404] -> 
             RGBColor[
              0.7600500863927916, 0.8126123064413943, 0.97668222149209], 
             UndirectedEdge[131, 449] -> 
             RGBColor[
              0.9086679607710296, 0.6083135329493521, 0.2853739255705805], 
             UndirectedEdge[423, 465] -> 
             RGBColor[
              0.1791246132879326, 0.3056017040950233, 0.9335122537844052], 
             UndirectedEdge[177, 412] -> 
             RGBColor[
              0.1873190234343715, 0.314214548714542, 0.9339789133197014], 
             UndirectedEdge[139, 158] -> 
             RGBColor[
              0.18715334052902155`, 0.3140404054761162, 0.9339694779233476], 
             UndirectedEdge[454, 500] -> 
             RGBColor[
              0.206190516482255, 0.33404968442963456`, 0.9350536169309063], 
             UndirectedEdge[430, 459] -> 
             RGBColor[
              0.19801808656198788`, 0.32545994242144927`, 0.9345882091369736],
              UndirectedEdge[474, 490] -> 
             RGBColor[
              0.22274072146667342`, 0.35144499921186156`, 0.9359961266209347],
              UndirectedEdge[443, 451] -> 
             RGBColor[
              0.24646170398602968`, 0.37637725583686343`, 0.9373470014833631],
              UndirectedEdge[182, 483] -> 
             RGBColor[
              0.3985189663280868, 0.5195988313129054, 0.9466142540313085], 
             UndirectedEdge[92, 457] -> 
             RGBColor[
              0.37059515571215895`, 0.49157695819153635`, 0.9450791109885306],
              UndirectedEdge[38, 184] -> 
             RGBColor[
              0.5298276783437619, 0.6291770036011967, 0.9561291221434074], 
             UndirectedEdge[51, 457] -> 
             RGBColor[
              0.7322518449471631, 0.7861260863844587, 0.8380007601438797], 
             UndirectedEdge[321, 455] -> 
             RGBColor[
              0.7992398811281014, 0.8424906663250493, 0.9268604994645402], 
             UndirectedEdge[251, 435] -> 
             RGBColor[
              0.2386642748374078, 0.3681816634160995, 0.9369029494286119], 
             UndirectedEdge[16, 441] -> 
             RGBColor[
              0.2457921380966431, 0.37567349963418883`, 0.9373088706964965], 
             UndirectedEdge[302, 390] -> 
             RGBColor[
              0.25033731885124844`, 0.38045077278838335`, 0.9375677120164789],
              UndirectedEdge[186, 455] -> 
             RGBColor[
              0.8031839177998501, 0.842431819201664, 0.7386664277516752], 
             UndirectedEdge[349, 353] -> 
             RGBColor[
              0.18295144203234145`, 0.3096239437403533, 0.9337301860201135], 
             UndirectedEdge[125, 406] -> 
             RGBColor[
              0.5972259557238873, 0.6808172474310844, 0.9631312731906503], 
             UndirectedEdge[307, 433] -> 
             RGBColor[
              0.18622321839671918`, 0.3130627881419171, 0.9339165088439054], 
             UndirectedEdge[406, 419] -> 
             RGBColor[
              0.5328942370686292, 0.630560819878426, 0.9567192886891854], 
             UndirectedEdge[237, 274] -> 
             RGBColor[
              0.23848727143504053`, 0.36799562161754756`, 0.9368928693467], 
             UndirectedEdge[203, 264] -> 
             RGBColor[
              0.8553074725725389, 0.4148947299646385, 0.20015613150748274`], 
             UndirectedEdge[69, 231] -> 
             RGBColor[
              0.6032570715569849, 0.6866480853473442, 0.9632586642510103], 
             UndirectedEdge[328, 399] -> 
             RGBColor[
              0.22543273121464985`, 0.354274472140261, 0.9361494325936104], 
             UndirectedEdge[78, 262] -> 
             RGBColor[
              0.4066140424697561, 0.526155775330442, 0.9472556735827959], 
             UndirectedEdge[27, 412] -> 
             RGBColor[
              0.18773360296108882`, 0.31465029808298206`, 0.9340025230104325],
              UndirectedEdge[147, 221] -> 
             RGBColor[
              0.8906777697244648, 0.5160364512426465, 0.23692570222520362`], 
             UndirectedEdge[93, 289] -> 
             RGBColor[
              0.21635167337317993`, 0.34472970457655394`, 0.93563227978376], 
             UndirectedEdge[141, 235] -> 
             RGBColor[
              0.21221346212045616`, 0.34038018217219357`, 0.9353966147748521],
              UndirectedEdge[185, 464] -> 
             RGBColor[
              0.2069974759051772, 0.3348978499473083, 0.9350995720762522], 
             UndirectedEdge[6, 189] -> 
             RGBColor[
              0.23318323402672853`, 0.3624207420060165, 0.9365908122629168], 
             UndirectedEdge[38, 316] -> 
             RGBColor[
              0.4787664530256467, 0.5873266421968035, 0.9522189657129314], 
             UndirectedEdge[322, 343] -> 
             RGBColor[
              0.8335064289062653, 0.2585506719501317, 0.17971910020172568`], 
             UndirectedEdge[93, 141] -> 
             RGBColor[
              0.21496969901233648`, 0.34327716190107216`, 0.9355535783883577],
              UndirectedEdge[191, 237] -> 
             RGBColor[
              0.21174339074199797`, 0.3398861073491872, 0.9353698449052572], 
             UndirectedEdge[145, 461] -> 
             RGBColor[
              0.23115805437216275`, 0.3602921497852615, 0.9364754812775742], 
             UndirectedEdge[420, 500] -> 
             RGBColor[
              0.19451665335716928`, 0.32177971411949735`, 0.9343888076958655],
              UndirectedEdge[402, 458] -> 
             RGBColor[
              0.2285757051250969, 0.3575779369961964, 0.9363284203081972], 
             UndirectedEdge[148, 263] -> 
             RGBColor[
              0.24948680213618696`, 0.3795568257949794, 0.9375192763477829], 
             UndirectedEdge[126, 499] -> 
             RGBColor[
              0.5585145617417738, 0.6524663078730726, 0.9583874586880152], 
             UndirectedEdge[133, 371] -> 
             RGBColor[
              0.22603138593843586`, 0.35490369621186185`, 0.9361835250944996],
              UndirectedEdge[72, 245] -> 
             RGBColor[
              0.22752065341650146`, 0.35646901075632065`, 0.9362683366742017],
              UndirectedEdge[57, 131] -> 
             RGBColor[
              0.8981850447320697, 0.6159608551699692, 0.564028013817431], 
             UndirectedEdge[15, 173] -> 
             RGBColor[
              0.6865018666299831, 0.7550197429095551, 0.9693877484071343], 
             UndirectedEdge[138, 415] -> 
             RGBColor[
              0.18158458466446153`, 0.308187289982949, 0.9336523455150969], 
             UndirectedEdge[105, 109] -> 
             RGBColor[
              0.2025306105640042, 0.3302028912581151, 0.9348451907032074], 
             UndirectedEdge[235, 284] -> 
             RGBColor[
              0.2119740420649528, 0.3401285365137513, 0.9353829801568815], 
             UndirectedEdge[150, 473] -> 
             RGBColor[
              0.23947719025137565`, 0.36903608905799384`, 0.9369492437588367],
              UndirectedEdge[74, 417] -> 
             RGBColor[
              0.1929190076012242, 0.3201004871334076, 0.9342978241335694], 
             UndirectedEdge[20, 413] -> 
             RGBColor[
              0.23603377197510877`, 0.36541683812430875`, 0.9367531461820842],
              UndirectedEdge[34, 467] -> 
             RGBColor[
              0.20003782336254744`, 0.32758281385754684`, 0.9347032301598326],
              UndirectedEdge[62, 110] -> 
             RGBColor[
              0.33413455286534527`, 0.45851113631971724`, 0.9427065695832899],
              UndirectedEdge[93, 389] -> 
             RGBColor[
              0.20877589722978934`, 0.3367670835179003, 0.9352008505397502], 
             UndirectedEdge[28, 408] -> 
             RGBColor[
              0.7065627960875993, 0.7690478747515729, 0.9714624707191005], 
             UndirectedEdge[93, 284] -> 
             RGBColor[
              0.21473027895683314`, 0.3430255162426299, 0.9355399437703871], 
             UndirectedEdge[143, 313] -> 
             RGBColor[
              0.4709361194251123, 0.5788655180367319, 0.9521839040886261], 
             UndirectedEdge[361, 398] -> 
             RGBColor[
              0.21817994857503456`, 0.3466513377330461, 0.9357363973518147], 
             UndirectedEdge[105, 382] -> 
             RGBColor[
              0.2017475218904906, 0.3293798154115627, 0.9348005949617267], 
             UndirectedEdge[240, 495] -> 
             RGBColor[
              0.9404490296531263, 0.7834756918464549, 0.4513533807985771], 
             UndirectedEdge[13, 21] -> 
             RGBColor[
              0.27647406119866225`, 0.4079221461606935, 0.9390561608273189], 
             UndirectedEdge[32, 179] -> 
             RGBColor[
              0.20989223640499494`, 0.3379404267710331, 0.9352644244043025], 
             UndirectedEdge[38, 79] -> 
             RGBColor[
              0.7025334025034438, 0.7661868171424233, 0.9721373827063131], 
             UndirectedEdge[328, 407] -> 
             RGBColor[
              0.26005803844889097`, 0.3906678654147257, 0.9381212926170488], 
             UndirectedEdge[357, 367] -> 
             RGBColor[
              0.19284697546686017`, 0.3200247767930899, 0.9342937220100794], 
             UndirectedEdge[196, 213] -> 
             RGBColor[
              0.19710682911621347`, 0.3245021530688812, 0.9345363143735214], 
             UndirectedEdge[233, 326] -> 
             RGBColor[
              0.8439697158415906, 0.8784945870094583, 0.9607638453803016], 
             UndirectedEdge[164, 372] -> 
             RGBColor[
              0.4651482668210734, 0.5729395258749782, 0.9520673290712703], 
             UndirectedEdge[3, 278] -> 
             RGBColor[
              0.1840613533248448, 0.3107905308812148, 0.9337933938262548], 
             UndirectedEdge[195, 399] -> 
             RGBColor[
              0.19798691924192627`, 0.3254271835919423, 0.9345864342042041], 
             UndirectedEdge[118, 187] -> 
             RGBColor[
              0.20672865124829637`, 0.33461529818845887`, 0.9350842629097332],
              UndirectedEdge[61, 178] -> 
             RGBColor[
              0.7297842099398613, 0.7851427009224017, 0.8812307211603922], 
             UndirectedEdge[2, 496] -> 
             RGBColor[
              0.18500487281902223`, 0.3117822296921864, 0.9338471258656362], 
             UndirectedEdge[103, 404] -> 
             RGBColor[
              0.6233155210312117, 0.7010502757004149, 0.96581591387943], 
             UndirectedEdge[37, 374] -> 
             RGBColor[
              0.8546495293295531, 0.4156398998574755, 0.19975329213765833`], 
             UndirectedEdge[236, 466] -> 
             RGBColor[
              0.2016228242267626, 0.329248750260696, 0.934793493614251], 
             UndirectedEdge[150, 254] -> 
             RGBColor[
              0.20389499448692971`, 0.33163694526804693`, 0.9349228903491928],
              UndirectedEdge[148, 229] -> 
             RGBColor[
              0.25473807623061007`, 0.385076247818226, 0.9378183286388965], 
             UndirectedEdge[160, 432] -> 
             RGBColor[
              0.26534093705235057`, 0.3962205268020793, 0.9384221458771677], 
             UndirectedEdge[48, 198] -> 
             RGBColor[
              0.18614733394130184`, 0.3129830287679211, 0.9339121873364302], 
             UndirectedEdge[89, 178] -> 
             RGBColor[
              0.38949543937037706`, 0.5113489021851207, 0.9461592546246456], 
             UndirectedEdge[63, 239] -> 
             RGBColor[
              0.20172774579693858`, 0.3293590294833628, 0.934799468742455], 
             UndirectedEdge[425, 462] -> 
             RGBColor[
              0.1883728625948838, 0.3153222004895023, 0.9340389279008772], 
             UndirectedEdge[44, 457] -> 
             RGBColor[
              0.3741308449563232, 0.49529319176279873`, 0.9452804632604023], 
             UndirectedEdge[46, 254] -> 
             RGBColor[
              0.1980699244230848, 0.3255144273001723, 0.9345911612264759], 
             UndirectedEdge[1, 452] -> 
             RGBColor[
              0.21304293634488086`, 0.3412520121737673, 0.935443852104836], 
             UndirectedEdge[260, 299] -> 
             RGBColor[
              0.2249121050554158, 0.35372726103730096`, 0.9361197837040394], 
             UndirectedEdge[321, 341] -> 
             RGBColor[
              0.9898662415110249, 0.9892279829702391, 0.7558592343220067], 
             UndirectedEdge[249, 406] -> 
             RGBColor[
              0.5717259495199576, 0.6608964487773493, 0.960589670883349], 
             UndirectedEdge[398, 496] -> 
             RGBColor[
              0.19603720028339988`, 0.32337790534720917`, 0.9344754005938667],
              UndirectedEdge[382, 462] -> 
             RGBColor[
              0.20106839690715364`, 0.3286660119950647, 0.934761919798601], 
             UndirectedEdge[63, 272] -> 
             RGBColor[
              0.23201898916873956`, 0.36119704684288256`, 0.9365245102406003],
              UndirectedEdge[117, 270] -> 
             RGBColor[
              0.18183894581371152`, 0.308454639678239, 0.933666831006253], 
             UndirectedEdge[164, 404] -> 
             RGBColor[
              0.5764261418930885, 0.6604370522196931, 0.9628281641033989], 
             UndirectedEdge[133, 191] -> 
             RGBColor[
              0.19428859491049005`, 0.32154001023229684`, 0.9343758201047092],
              UndirectedEdge[307, 469] -> 
             RGBColor[
              0.186562771602089, 0.31341968008967747`, 0.9339358458966271], 
             UndirectedEdge[31, 237] -> 
             RGBColor[
              0.21243558089193113`, 0.3406136430841573, 0.9354092641102925], 
             UndirectedEdge[1, 468] -> 
             RGBColor[
              0.21038952484231582`, 0.33846310844856536`, 0.9352927442451355],
              UndirectedEdge[346, 395] -> 
             RGBColor[
              0.47277817219066315`, 0.5825384587097979, 0.951727273224181], 
             UndirectedEdge[214, 223] -> 
             RGBColor[
              0.1978649215993461, 0.32529895633449324`, 0.9345794866189384], 
             UndirectedEdge[264, 397] -> 
             RGBColor[
              0.8437768320344039, 0.3262651740296299, 0.18911437710616869`], 
             UndirectedEdge[103, 204] -> 
             RGBColor[
              0.3628536312078076, 0.48870731062358463`, 0.9443416904150619], 
             UndirectedEdge[110, 356] -> 
             RGBColor[
              0.3311960783219361, 0.45542261326454736`, 0.9425392278051263], 
             UndirectedEdge[184, 253] -> 
             RGBColor[
              0.4591640004744537, 0.5697502062280924, 0.9511350822856912], 
             UndirectedEdge[115, 417] -> 
             RGBColor[
              0.19405888879625283`, 0.3212985745420247, 0.9343627386813232], 
             UndirectedEdge[243, 459] -> 
             RGBColor[
              0.19552964555273866`, 0.32284443314445566`, 0.9344464961028154],
              UndirectedEdge[190, 349] -> 
             RGBColor[
              0.20086956962021285`, 0.3284570319101118, 0.9347505968787484], 
             UndirectedEdge[128, 222] -> 
             RGBColor[
              0.19567917188119596`, 0.32300159479618107`, 0.9344550114060167],
              UndirectedEdge[204, 275] -> 
             RGBColor[
              0.402607767889131, 0.5221630142088122, 0.9471448284585735], 
             UndirectedEdge[178, 455] -> 
             RGBColor[
              0.5411769973801115, 0.6383908920759014, 0.9570225821118743], 
             UndirectedEdge[84, 391] -> 
             RGBColor[
              0.3743150955210323, 0.495024736722043, 0.9453330205540728], 
             UndirectedEdge[54, 203] -> 
             RGBColor[
              0.9172982685013698, 0.6686889606982549, 0.5070233200844496], 
             UndirectedEdge[236, 314] -> 
             RGBColor[
              0.23558368231737692`, 0.3649437653567001, 0.9367275142419242], 
             UndirectedEdge[277, 313] -> 
             RGBColor[
              0.4022235011215268, 0.5228075131556505, 0.9468503037125551], 
             UndirectedEdge[186, 397] -> 
             RGBColor[
              0.9076664956540943, 0.5791548277078178, 0.3416812367112626], 
             UndirectedEdge[29, 297] -> 
             RGBColor[
              0.18984593669287142`, 0.3168704947647796, 0.9341228172915397], 
             UndirectedEdge[130, 208] -> 
             RGBColor[
              0.3647668975032984, 0.4898257484488929, 0.9444833278623301], 
             UndirectedEdge[145, 450] -> 
             RGBColor[
              0.21228550631692578`, 0.340455905190549, 0.9354007175852613], 
             UndirectedEdge[86, 350] -> 
             RGBColor[
              0.18341807699895743`, 0.3101144066766324, 0.9337567601911376], 
             UndirectedEdge[37, 281] -> 
             RGBColor[
              0.8401393429256434, 0.30410824875280007`, 0.18585832125036283`],
              UndirectedEdge[281, 445] -> 
             RGBColor[
              0.8907713717872949, 0.5149365980262008, 0.23825003998390762`], 
             UndirectedEdge[116, 224] -> 
             RGBColor[
              0.2412066178691736, 0.37085382713634363`, 0.9370477321032114], 
             UndirectedEdge[112, 163] -> 
             RGBColor[
              0.9463750065735652, 0.8136106484588435, 0.49802406298394036`], 
             UndirectedEdge[148, 480] -> 
             RGBColor[
              0.25899827885189075`, 0.38955399088563913`, 0.9380609408757734],
              UndirectedEdge[42, 487] -> 
             RGBColor[
              0.19664512493327133`, 0.3240168726988731, 0.934510021003333], 
             UndirectedEdge[122, 319] -> 
             RGBColor[
              0.1832707103845271, 0.30995951502128316`, 0.9337483678804552], 
             UndirectedEdge[129, 348] -> 
             RGBColor[
              0.37572812244985154`, 0.497829719871169, 0.9452933537370448], 
             UndirectedEdge[93, 201] -> 
             RGBColor[
              0.24004103918211672`, 0.36962873003428975`, 0.9369813541213027],
              UndirectedEdge[121, 427] -> 
             RGBColor[
              0.19582329677639237`, 0.3231530791990786, 0.9344632191055845], 
             UndirectedEdge[269, 411] -> 
             RGBColor[
              0.441541570634595, 0.5502832522185821, 0.9505633429393294], 
             UndirectedEdge[76, 371] -> 
             RGBColor[
              0.3322551655815734, 0.4571504155823287, 0.9425770364794188], 
             UndirectedEdge[61, 244] -> 
             RGBColor[
              0.7184903511263943, 0.775794731676694, 0.8803911147116745], 
             UndirectedEdge[184, 436] -> 
             RGBColor[
              0.4481781977283561, 0.5602348560519236, 0.9504350766490738], 
             UndirectedEdge[80, 293] -> 
             RGBColor[
              0.578582457393624, 0.6633186431495282, 0.9625149398020252], 
             UndirectedEdge[111, 460] -> 
             RGBColor[
              0.33363255379100343`, 0.46265113373051764`, 0.9425070766696382],
              UndirectedEdge[286, 358] -> 
             RGBColor[
              0.20613946196016764`, 0.33399602288987706`, 0.9350507094514018],
              UndirectedEdge[176, 244] -> 
             RGBColor[
              0.38182757506705056`, 0.5051415871363136, 0.945550693339773], 
             UndirectedEdge[99, 321] -> 
             RGBColor[
              0.9825665367368704, 0.9863121992558153, 0.9051455199034306], 
             UndirectedEdge[187, 478] -> 
             RGBColor[
              0.2352799848565821, 0.36462456006987354`, 0.9367102191208121], 
             UndirectedEdge[116, 185] -> 
             RGBColor[
              0.24400994073613447`, 0.3738002972104551, 0.9372073771933402], 
             UndirectedEdge[97, 257] -> 
             RGBColor[
              0.9757547061623437, 0.9298770721991836, 0.3603120410906092], 
             UndirectedEdge[16, 313] -> 
             RGBColor[
              0.3156685624243244, 0.4442664326028998, 0.9414658712422952], 
             UndirectedEdge[166, 344] -> 
             RGBColor[
              0.19297880215941118`, 0.32016333500525607`, 0.9343012293452001],
              UndirectedEdge[103, 443] -> 
             RGBColor[
              0.3488203865149018, 0.47461920966592475`, 0.9435182887508398], 
             UndirectedEdge[74, 115] -> 
             RGBColor[
              0.18984673852773665`, 0.31687133754406216`, 0.9341228629548491],
              UndirectedEdge[196, 332] -> 
             RGBColor[
              0.18931192738265673`, 0.3163092171215981, 0.934092406251319], 
             UndirectedEdge[49, 203] -> 
             RGBColor[
              0.9194979870090474, 0.6684278731193166, 0.38546874588719493`], 
             UndirectedEdge[95, 122] -> 
             RGBColor[
              0.18517962016864098`, 0.3119659002362576, 0.9338570774686815], 
             UndirectedEdge[97, 209] -> 
             RGBColor[
              0.9914664507187211, 0.9823539717574632, 0.575433002447343], 
             UndirectedEdge[484, 490] -> 
             RGBColor[
              0.2003898909918431, 0.3279528592583135, 0.9347232798904836], 
             UndirectedEdge[128, 415] -> 
             RGBColor[
              0.1873275955453248, 0.3142235585466571, 0.9339794014887388], 
             UndirectedEdge[371, 442] -> 
             RGBColor[
              0.24599324612330464`, 0.37588487692119543`, 0.9373203235011023],
              UndirectedEdge[88, 311] -> 
             RGBColor[
              0.18977178861723454`, 0.3167925604360257, 0.9341185946683245], 
             UndirectedEdge[15, 149] -> 
             RGBColor[
              0.6067680705890965, 0.6914867648051379, 0.9622913844255672], 
             UndirectedEdge[117, 140] -> 
             RGBColor[
              0.1812891715754636, 0.30787679209614044`, 0.933635522176703], 
             UndirectedEdge[199, 475] -> 
             RGBColor[
              0.3613314497983178, 0.4873888735937467, 0.9442446983616614], 
             UndirectedEdge[71, 169] -> 
             RGBColor[
              0.1907755412237238, 0.3178475680670369, 0.9341757568943452], 
             UndirectedEdge[23, 51] -> 
             RGBColor[
              0.7136013437576199, 0.7704045833430664, 0.8366928314862011], 
             UndirectedEdge[381, 416] -> 
             RGBColor[
              0.19876402822087508`, 0.3262439744003725, 0.9346306894109254], 
             UndirectedEdge[121, 447] -> 
             RGBColor[
              0.21943101242653507`, 0.34796628516300276`, 0.9358076435873746],
              UndirectedEdge[244, 407] -> 
             RGBColor[
              0.361925627233212, 0.4849803667690406, 0.9443895897897958], 
             UndirectedEdge[255, 385] -> 
             RGBColor[
              0.1893629494279947, 0.3163628445262328, 0.9340953118813207], 
             UndirectedEdge[30, 469] -> 
             RGBColor[
              0.18014325773351766`, 0.30667236399312137`, 0.9335702640786318],
              UndirectedEdge[80, 171] -> 
             RGBColor[
              0.4090554292271066, 0.5282531641753069, 0.9474159938779831], 
             UndirectedEdge[214, 466] -> 
             RGBColor[
              0.1912157031774699, 0.31831020618830375`, 0.9342008234664497], 
             UndirectedEdge[199, 455] -> 
             RGBColor[
              0.4995894556816295, 0.6028040573199673, 0.9542526889773754], 
             UndirectedEdge[175, 483] -> 
             RGBColor[
              0.4248591023079348, 0.5424133332049215, 0.9482926242042767], 
             UndirectedEdge[124, 416] -> 
             RGBColor[
              0.19729887283700168`, 0.3247040031957048, 0.934547250979317], 
             UndirectedEdge[142, 396] -> 
             RGBColor[
              0.2065755605048984, 0.3344543901106338, 0.9350755446183742], 
             UndirectedEdge[185, 361] -> 
             RGBColor[
              0.22082084550846576`, 0.3494270878526189, 0.9358867925253167], 
             UndirectedEdge[19, 26] -> 
             RGBColor[
              0.1940564817835153, 0.32129604461902417`, 0.9343626016055087], 
             UndirectedEdge[341, 455] -> 
             RGBColor[
              0.8036709694912352, 0.8434735735210568, 0.7916789986243209], 
             UndirectedEdge[159, 239] -> 
             RGBColor[
              0.2143802858334754, 0.34265765127913517`, 0.9355200121797802], 
             UndirectedEdge[261, 482] -> 
             RGBColor[
              0.3308323765041129, 0.4609721092343021, 0.9423013243806262], 
             UndirectedEdge[5, 97] -> 
             RGBColor[
              0.8390165308787574, 0.8650728443865321, 0.6896757172524062], 
             UndirectedEdge[285, 396] -> 
             RGBColor[
              0.20591309648733414`, 0.33375809842552917`, 0.9350378182726016],
              UndirectedEdge[174, 424] -> 
             RGBColor[
              0.19047450678086728`, 0.3175311617809086, 0.934158613428165], 
             UndirectedEdge[99, 186] -> 
             RGBColor[
              0.9865105734086191, 0.9862533521324298, 0.7169514481905657], 
             UndirectedEdge[79, 127] -> 
             RGBColor[
              0.8591989102072256, 0.8905659049388609, 0.9864323531431288], 
             UndirectedEdge[29, 86] -> 
             RGBColor[
              0.18487060048840748`, 0.3116411009593528, 0.9338394792550458], 
             UndirectedEdge[127, 316] -> 
             RGBColor[
              0.6354319607294284, 0.7117057299932411, 0.9665139361497471], 
             UndirectedEdge[197, 466] -> 
             RGBColor[
              0.21288997416386868`, 0.3410912392231611, 0.9354351411349147], 
             UndirectedEdge[183, 206] -> 
             RGBColor[
              0.1886895173788014, 0.31565502474447266`, 0.9340569609223726], 
             UndirectedEdge[25, 392] -> 
             RGBColor[
              0.26287272325527145`, 0.39362627760755575`, 0.9382815847528192],
              UndirectedEdge[73, 91] -> 
             RGBColor[
              0.5186112912140105, 0.6200710352367826, 0.9552461270615734], 
             UndirectedEdge[187, 464] -> 
             RGBColor[
              0.21185013288920307`, 0.3399983001137429, 0.9353759237126298], 
             UndirectedEdge[17, 99] -> 
             RGBColor[
              0.6775706975021587, 0.7419956614956686, 0.932197104376443], 
             UndirectedEdge[110, 157] -> 
             RGBColor[
              0.35808579273911467`, 0.4836854080233668, 0.944070557261417], 
             UndirectedEdge[241, 429] -> 
             RGBColor[
              0.20378953117845383`, 0.33152609664407884`, 0.9349168843697941],
              UndirectedEdge[27, 490] -> 
             RGBColor[
              0.20058973370860944`, 0.328162906624395, 0.9347346606375627], 
             UndirectedEdge[372, 418] -> 
             RGBColor[
              0.5453882435546948, 0.6418097714349063, 0.9573541068370404], 
             UndirectedEdge[65, 350] -> 
             RGBColor[
              0.18235178883730735`, 0.30899367021216395`, 0.9336960366577636],
              UndirectedEdge[189, 390] -> 
             RGBColor[
              0.25394291239181044`, 0.3842404802073483, 0.9377730452346162], 
             UndirectedEdge[263, 267] -> 
             RGBColor[
              0.22679757309850174`, 0.35570900749616285`, 0.9362271583197932],
              UndirectedEdge[25, 490] -> 
             RGBColor[
              0.25243138864291936`, 0.38265177291112284`, 0.937686966193216], 
             UndirectedEdge[360, 494] -> 
             RGBColor[
              0.4757330556093662, 0.5825992022016417, 0.9526059341461844], 
             UndirectedEdge[61, 203] -> 
             RGBColor[
              0.9176650400604409, 0.6688406301635299, 0.5009449661762736], 
             UndirectedEdge[36, 104] -> 
             RGBColor[
              0.9591316136436914, 0.8643779170894872, 0.5023662490620132], 
             UndirectedEdge[33, 241] -> 
             RGBColor[
              0.2359506605232252, 0.3653294827188087, 0.9367484131078517], 
             UndirectedEdge[82, 419] -> 
             RGBColor[
              0.5847042349028322, 0.6736221466676785, 0.9605217589523052], 
             UndirectedEdge[5, 404] -> 
             RGBColor[
              0.763201606478355, 0.8150742978846761, 0.9769963355615894], 
             UndirectedEdge[40, 396] -> 
             RGBColor[
              0.19122359622902446`, 0.31831850228593606`, 0.934201272964059], 
             UndirectedEdge[169, 369] -> 
             RGBColor[
              0.1829196441464267, 0.30959052214615446`, 0.9337283751775514], 
             UndirectedEdge[268, 491] -> 
             RGBColor[
              0.1839641739186956, 0.3106883891638218, 0.9337878596028387], 
             UndirectedEdge[4, 151] -> 
             RGBColor[
              0.19261261169346405`, 0.31977844560772906`, 0.9342803753398946],
              UndirectedEdge[6, 390] -> 
             RGBColor[
              0.23515410879898574`, 0.36449225635233673`, 0.9367030506655489],
              UndirectedEdge[376, 482] -> 
             RGBColor[
              0.35174044974950636`, 0.47908163140914517`, 0.9436335683195394],
              UndirectedEdge[158, 278] -> 
             RGBColor[
              0.18808568721102567`, 0.3150203609530965, 0.9340225736876044], 
             UndirectedEdge[317, 445] -> 
             RGBColor[
              0.8902189090551026, 0.5106901273758575, 0.23772100104764282`], 
             UndirectedEdge[133, 351] -> 
             RGBColor[
              0.21908548042585338`, 0.34760310912229214`, 0.9357879660511045],
              UndirectedEdge[239, 454] -> 
             RGBColor[
              0.20401834156350113`, 0.3317665908661798, 0.9349299147827279], 
             UndirectedEdge[140, 198] -> 
             RGBColor[
              0.18071298100430727`, 0.3072711792732629, 0.9336027089760732], 
             UndirectedEdge[252, 309] -> 
             RGBColor[
              0.18525140255303396`, 0.3120413480735207, 0.9338611653692801], 
             UndirectedEdge[161, 243] -> 
             RGBColor[
              0.20521495427576572`, 0.33302430669639793`, 0.9349980601064616],
              UndirectedEdge[244, 455] -> 
             RGBColor[
              0.5298831385666443, 0.6290429228301937, 0.9561829756631566], 
             UndirectedEdge[401, 451] -> 
             RGBColor[
              0.192907026989333, 0.3200878947506953, 0.934297141855446], 
             UndirectedEdge[210, 225] -> 
             RGBColor[
              0.189744388344664, 0.31676376101227643`, 0.9341170342633367], 
             UndirectedEdge[107, 223] -> 
             RGBColor[
              0.20973558752308613`, 0.3377757788640342, 0.935255503482219], 
             UndirectedEdge[5, 204] -> 
             RGBColor[
              0.502739716654951, 0.6027313328078459, 0.9555221120972213], 
             UndirectedEdge[59, 200] -> 
             RGBColor[
              0.26298567956392194`, 0.393745001849791, 0.9382880174474929], 
             UndirectedEdge[328, 481] -> 
             RGBColor[
              0.22412762819429155`, 0.3529027261175536, 0.9360751089073279], 
             UndirectedEdge[55, 434] -> 
             RGBColor[
              0.7543365484938672, 0.7225141411414309, 0.6130982348590022], 
             UndirectedEdge[269, 499] -> 
             RGBColor[
              0.615223353565316, 0.6985050597773825, 0.9628517825115135], 
             UndirectedEdge[377, 476] -> 
             RGBColor[
              0.18211083187288252`, 0.3087404091649995, 0.9336823145151034], 
             UndirectedEdge[260, 478] -> 
             RGBColor[
              0.22953226117284842`, 0.3585833380515396, 0.9363828947600188], 
             UndirectedEdge[163, 207] -> 
             RGBColor[
              0.8871477729139166, 0.5804462187569267, 0.227545674269207], 
             UndirectedEdge[238, 258] -> 
             RGBColor[
              0.4509349141328164, 0.5640927881888469, 0.9502045107268047], 
             UndirectedEdge[10, 443] -> 
             RGBColor[
              0.2573117613989959, 0.387781354111264, 0.9379648962018101], 
             UndirectedEdge[231, 326] -> 
             RGBColor[
              0.7445199877539495, 0.8003439400856498, 0.9751704525106033], 
             UndirectedEdge[91, 287] -> 
             RGBColor[
              0.38223901787712034`, 0.5048831468883692, 0.9456450183489318], 
             UndirectedEdge[242, 249] -> 
             RGBColor[
              0.8500313217686346, 0.8830430785885436, 0.951908121903962], 
             UndirectedEdge[83, 209] -> 
             RGBColor[
              0.9948514855705746, 0.9921389712197164, 0.7349877382312089], 
             UndirectedEdge[306, 431] -> 
             RGBColor[
              0.33101101797964355`, 0.4548419980464291, 0.9425428260902121], 
             UndirectedEdge[176, 376] -> 
             RGBColor[
              0.34402119360606, 0.47239559971878675`, 0.9431417041439492], 
             UndirectedEdge[30, 191] -> 
             RGBColor[
              0.18476529609045284`, 0.31153041936041803`, 0.9338334823253662],
              UndirectedEdge[209, 444] -> 
             RGBColor[
              0.7801701048240467, 0.8252083695679635, 0.8500873938895259], 
             UndirectedEdge[169, 289] -> 
             RGBColor[
              0.19694268883638122`, 0.3243296312276827, 0.9345269668274088], 
             UndirectedEdge[20, 46] -> 
             RGBColor[
              0.22273395828831882`, 0.35143789068260056`, 0.9359957414679326],
              UndirectedEdge[49, 100] -> 
             RGBColor[
              0.9935759076270685, 0.9886678409266986, 0.5421553739880537], 
             UndirectedEdge[404, 486] -> 
             RGBColor[
              0.6250807725270684, 0.7025792478220061, 0.9659283941437955], 
             UndirectedEdge[103, 431] -> 
             RGBColor[
              0.415528043094357, 0.534331238706793, 0.9476980573623193], 
             UndirectedEdge[219, 238] -> 
             RGBColor[
              0.5781077146635654, 0.6679567426795029, 0.9602144407477138], 
             UndirectedEdge[249, 499] -> 
             RGBColor[
              0.6777613007469594, 0.7479803602752079, 0.9686609595995643], 
             UndirectedEdge[254, 377] -> 
             RGBColor[
              0.18661056292735312`, 0.3134699118026751, 0.9339385675419001], 
             UndirectedEdge[57, 434] -> 
             RGBColor[
              0.9488603570213409, 0.87598930982866, 0.6073727486571113], 
             UndirectedEdge[75, 104] -> 
             RGBColor[
              0.894725030806556, 0.6091192249245418, 0.23357173327544747`], 
             UndirectedEdge[132, 365] -> 
             RGBColor[
              0.23967912019619636`, 0.3692483302330984, 0.9369607433704656], 
             UndirectedEdge[38, 77] -> 
             RGBColor[
              0.4266438929830485, 0.5421807004439456, 0.9488977622771873], 
             UndirectedEdge[172, 314] -> 
             RGBColor[
              0.24315002922466572`, 0.37289647569036266`, 0.9371584065048872],
              UndirectedEdge[398, 481] -> 
             RGBColor[
              0.20576395571267658`, 0.3336013420152928, 0.9350293249261188], 
             UndirectedEdge[143, 165] -> 
             RGBColor[
              0.4432891969739572, 0.5546584690453142, 0.950431811201746], 
             UndirectedEdge[261, 475] -> 
             RGBColor[
              0.3329106779769486, 0.46277222951160313`, 0.9424337519127055], 
             UndirectedEdge[288, 373] -> 
             RGBColor[
              0.8511114942630649, 0.882439252848601, 0.8853377053514828], 
             UndirectedEdge[78, 171] -> 
             RGBColor[
              0.47037777522198154`, 0.5809128940593202, 0.9514490079974901], 
             UndirectedEdge[6, 370] -> 
             RGBColor[
              0.22157715427768293`, 0.35022201632181177`, 0.935929863190865], 
             UndirectedEdge[264, 295] -> 
             RGBColor[
              0.9251699045349664, 0.7351644032002858, 0.5555767619873893], 
             UndirectedEdge[45, 464] -> 
             RGBColor[
              0.2018156680778671, 0.3294514413752133, 0.9348044757862846], 
             UndirectedEdge[228, 318] -> 
             RGBColor[
              0.22809876360932468`, 0.35707664122328114`, 0.9363012591944456],
              UndirectedEdge[7, 295] -> 
             RGBColor[
              0.7285749695983985, 0.7852490192213029, 0.9266196187062239], 
             UndirectedEdge[225, 320] -> 
             RGBColor[
              0.1825517796800877, 0.30920387326807797`, 0.9337074258404], 
             UndirectedEdge[137, 148] -> 
             RGBColor[
              0.24314559520540308`, 0.3728918152549845, 0.9371581539940498], 
             UndirectedEdge[61, 455] -> 
             RGBColor[
              0.8016518216680615, 0.8434880657223675, 0.8868884028153723], 
             UndirectedEdge[11, 331] -> 
             RGBColor[
              0.3385041946670758, 0.46694107593320344`, 0.9428149166646195], 
             UndirectedEdge[20, 392] -> 
             RGBColor[
              0.2393040747004234, 0.36885413363778313`, 0.9369393850843115], 
             UndirectedEdge[348, 431] -> 
             RGBColor[
              0.44166621655022387`, 0.5567328899534418, 0.9494292969038062], 
             UndirectedEdge[241, 351] -> 
             RGBColor[
              0.22791016546505544`, 0.3568784126158412, 0.9362905188091355], 
             UndirectedEdge[343, 374] -> 
             RGBColor[
              0.8468374551199298, 0.3610187811212927, 0.19248490595917145`], 
             UndirectedEdge[162, 389] -> 
             RGBColor[
              0.18912373753009853`, 0.3161114176546337, 0.9340816891176178], 
             UndirectedEdge[207, 266] -> 
             RGBColor[
              0.9342851916423655, 0.7569554226506068, 0.3801831663512317], 
             UndirectedEdge[98, 425] -> 
             RGBColor[
              0.1874902819867422, 0.31439455231150293`, 0.9339886662409045], 
             UndirectedEdge[151, 284] -> 
             RGBColor[
              0.20527167990556933`, 0.33308392892993416`, 0.9350012905471609],
              UndirectedEdge[41, 365] -> 
             RGBColor[
              0.23506566561189032`, 0.36439929695507756`, 0.9366980139568839],
              UndirectedEdge[436, 473] -> 
             RGBColor[
              0.30955738588181175`, 0.4383701601543446, 0.9410985541344632], 
             UndirectedEdge[311, 405] -> 
             RGBColor[
              0.18582191019465255`, 0.3126409877771355, 0.9338936549354799], 
             UndirectedEdge[235, 432] -> 
             RGBColor[
              0.25417547246619693`, 0.38448491559068887`, 0.9377862891868108],
              UndirectedEdge[109, 474] -> 
             RGBColor[
              0.22157473772172553`, 0.350219476368282, 0.9359297255715783], 
             UndirectedEdge[364, 468] -> 
             RGBColor[
              0.21294670143418915`, 0.3411508631809846, 0.9354383716690389], 
             UndirectedEdge[203, 374] -> 
             RGBColor[
              0.8462576720826371, 0.35656231463411475`, 0.19192970506788876`],
              UndirectedEdge[36, 112] -> 
             RGBColor[
              0.993786491132969, 0.9916985686506579, 0.7526374521795876], 
             UndirectedEdge[324, 342] -> 
             RGBColor[
              0.7080228667800735, 0.7701523632700238, 0.969408565667581], 
             UndirectedEdge[374, 445] -> 
             RGBColor[
              0.9052815581912046, 0.6264682491308763, 0.2521450108712031], 
             UndirectedEdge[2, 327] -> 
             RGBColor[
              0.18398683108609262`, 0.3107122032833034, 0.9337891498950037], 
             UndirectedEdge[128, 438] -> 
             RGBColor[
              0.19844895166515433`, 0.32591280896330255`, 0.9346127462671912],
              UndirectedEdge[33, 460] -> 
             RGBColor[
              0.27847248938800495`, 0.41002262089535824`, 0.9391699683562924],
              UndirectedEdge[298, 335] -> 
             RGBColor[
              0.2430317898200987, 0.3727721985793514, 0.9371516729457167], 
             UndirectedEdge[112, 343] -> 
             RGBColor[
              0.91983604495667, 0.6739551077819146, 0.4751295029148105], 
             UndirectedEdge[106, 265] -> 
             RGBColor[
              0.18198502195137928`, 0.3086081749606899, 0.933675149826193], 
             UndirectedEdge[19, 468] -> 
             RGBColor[
              0.21235962003857659`, 0.3405338034110854, 0.9354049382520679], 
             UndirectedEdge[161, 202] -> 
             RGBColor[
              0.2003053984953046, 0.32786405228731785`, 0.9347184681678012], 
             UndirectedEdge[204, 390] -> 
             RGBColor[
              0.2859084769887601, 0.4171765863589087, 0.9396176659888837], 
             UndirectedEdge[211, 289] -> 
             RGBColor[
              0.19877803112005593`, 0.32625869233524674`, 0.9346314868553184],
              UndirectedEdge[48, 479] -> 
             RGBColor[
              0.18610061058204452`, 0.31293391955490957`, 0.9339095265102416],
              UndirectedEdge[57, 495] -> 
             RGBColor[
              0.9243664441871663, 0.7736553444054359, 0.5873941515896481], 
             UndirectedEdge[10, 280] -> 
             RGBColor[
              0.24013030719270134`, 0.36972255637333296`, 0.9369864378024453],
              UndirectedEdge[206, 476] -> 
             RGBColor[
              0.18192213006975788`, 0.30854207160553015`, 0.9336715682265748],
              UndirectedEdge[13, 256] -> 
             RGBColor[
              0.2822514185299613, 0.41373456987075796`, 0.9393946906458437], 
             UndirectedEdge[184, 221] -> 
             RGBColor[
              0.7515553610831588, 0.7612606169042988, 0.6324712276878893], 
             UndirectedEdge[126, 282] -> 
             RGBColor[
              0.5925848442263562, 0.6792934576295336, 0.9616388769267687], 
             UndirectedEdge[53, 266] -> 
             RGBColor[
              0.9131290173800801, 0.6204205778411838, 0.36094524797198546`], 
             UndirectedEdge[194, 220] -> 
             RGBColor[
              0.20157018632549908`, 0.32919342448903244`, 0.9347904959636448],
              UndirectedEdge[375, 417] -> 
             RGBColor[
              0.1999369421366619, 0.32747678129290203`, 0.9346974851232589], 
             UndirectedEdge[245, 448] -> 
             RGBColor[
              0.272254633728537, 0.40348726036243854`, 0.9388158706749788], 
             UndirectedEdge[79, 147] -> 
             RGBColor[
              0.8526636417246913, 0.529899304242684, 0.5774584339898925], 
             UndirectedEdge[77, 253] -> 
             RGBColor[
              0.35598021511374034`, 0.4827539030708413, 0.9439037224194711], 
             UndirectedEdge[180, 205] -> 
             RGBColor[
              0.2503131812646099, 0.38042540265441493`, 0.9375663374166283], 
             UndirectedEdge[28, 432] -> 
             RGBColor[
              0.38353725752998075`, 0.5043916701363219, 0.9458878966543498], 
             UndirectedEdge[84, 245] -> 
             RGBColor[
              0.25972033738633343`, 0.39031292018649366`, 0.9381020610411201],
              UndirectedEdge[19, 459] -> 
             RGBColor[
              0.1988488542772136, 0.32633313196386693`, 0.934635520129345], 
             UndirectedEdge[153, 236] -> 
             RGBColor[
              0.21799828044158207`, 0.3464603930063626, 0.9357260516203685], 
             UndirectedEdge[315, 349] -> 
             RGBColor[
              0.18430254906177113`, 0.31104404289341736`, 0.9338071295666557],
              UndirectedEdge[18, 460] -> 
             RGBColor[
              0.2944934860338214, 0.4268617041599678, 0.940082340414331], 
             UndirectedEdge[126, 449] -> 
             RGBColor[
              0.7360314578812237, 0.7759766732200013, 0.6718437842469422], 
             UndirectedEdge[49, 324] -> 
             RGBColor[
              0.9668288479321837, 0.9719938689278773, 0.783522492339073], 
             UndirectedEdge[334, 415] -> 
             RGBColor[
              0.18362714398561458`, 0.31033414933522163`, 0.9337686662467408],
              UndirectedEdge[5, 444] -> 
             RGBColor[
              0.627720184984083, 0.7079272421970324, 0.964330108694589], 
             UndirectedEdge[147, 449] -> 
             RGBColor[
              0.9013434874873846, 0.5520144216865974, 0.2783600016823526], 
             UndirectedEdge[254, 426] -> 
             RGBColor[
              0.189893219466744, 0.3169201919580207, 0.9341255099755632], 
             UndirectedEdge[186, 321] -> 
             RGBColor[
              0.9893791898196398, 0.9881862286508462, 0.7028466634493613], 
             UndirectedEdge[260, 399] -> 
             RGBColor[
              0.20881488896675832`, 0.33680806630567356`, 0.9352030710614876],
              UndirectedEdge[184, 287] -> 
             RGBColor[
              0.42249467395537876`, 0.5375645019893394, 0.9488140910567393], 
             UndirectedEdge[129, 431] -> 
             RGBColor[
              0.35531389648617895`, 0.48038586424829277`, 0.9439268390682725],
              UndirectedEdge[300, 432] -> 
             RGBColor[
              0.26154815956156724`, 0.39223407718328385`, 0.938206152809979], 
             UndirectedEdge[207, 293] -> 
             RGBColor[
              0.8423679493594973, 0.6882641451078306, 0.5995351479132809], 
             UndirectedEdge[118, 399] -> 
             RGBColor[
              0.200045010570769, 0.32759036806908304`, 0.9347036394607084], 
             UndirectedEdge[138, 179] -> 
             RGBColor[
              0.19144105687703156`, 0.31854706721479287`, 0.9342136570262589],
              UndirectedEdge[40, 161] -> 
             RGBColor[
              0.19942966903054987`, 0.32694360509540565`, 0.9346685966703091],
              UndirectedEdge[243, 279] -> 
             RGBColor[
              0.20228104719014361`, 0.3299405843289558, 0.934830978438262], 
             UndirectedEdge[69, 233] -> 
             RGBColor[
              0.7027067996446262, 0.7647987322711527, 0.9488520571207084], 
             UndirectedEdge[237, 460] -> 
             RGBColor[
              0.26678188416083737`, 0.3977350535744224, 0.9385042056833057], 
             UndirectedEdge[54, 295] -> 
             RGBColor[
              0.9871607004637972, 0.988958633933902, 0.862443950564356], 
             UndirectedEdge[102, 210] -> 
             RGBColor[
              0.19748304019874757`, 0.324897574769785, 0.9345577390381172], 
             UndirectedEdge[137, 156] -> 
             RGBColor[
              0.2055253114742025, 0.33335051178973785`, 0.9350157344897803], 
             UndirectedEdge[231, 444] -> 
             RGBColor[
              0.664761024690349, 0.7368638276963759, 0.9680219934301821], 
             UndirectedEdge[383, 393] -> 
             RGBColor[
              0.24454516184141023`, 0.374362848527078, 0.9372378572434972], 
             UndirectedEdge[43, 137] -> 
             RGBColor[
              0.220012218727478, 0.34857716983590165`, 0.9358407424263956], 
             UndirectedEdge[233, 348] -> 
             RGBColor[
              0.7123189222990802, 0.7728863489370825, 0.9495302713185423], 
             UndirectedEdge[193, 410] -> 
             RGBColor[
              0.1815860257697589, 0.30818880467598786`, 0.9336524275839118], 
             UndirectedEdge[126, 384] -> 
             RGBColor[
              0.3782656319739345, 0.49734201260730226`, 0.9457250298186803], 
             UndirectedEdge[162, 345] -> 
             RGBColor[
              0.1870835559314184, 0.31396705743943626`, 0.9339655037937511], 
             UndirectedEdge[165, 178] -> 
             RGBColor[
              0.3876179844694684, 0.5094620707746275, 0.9460491694230218], 
             UndirectedEdge[154, 455] -> 
             RGBColor[
              0.7982558492888101, 0.8419633098945049, 0.937775174104184], 
             UndirectedEdge[211, 470] -> 
             RGBColor[
              0.19104848384555853`, 0.31813444806814695`, 0.9341913005728761],
              UndirectedEdge[201, 305] -> 
             RGBColor[
              0.2840031755926752, 0.41566850052882615`, 0.9394910555788545], 
             UndirectedEdge[220, 474] -> 
             RGBColor[
              0.22327343139036823`, 0.3520049111174247, 0.9360264636630153], 
             UndirectedEdge[125, 173] -> 
             RGBColor[
              0.7492734803038996, 0.8040574045935522, 0.9756442362240689], 
             UndirectedEdge[189, 443] -> 
             RGBColor[
              0.2699043575235971, 0.40101697105492856`, 0.9386820259220295], 
             UndirectedEdge[307, 500] -> 
             RGBColor[
              0.19638085260421678`, 0.3237391057252033, 0.9344949710851491], 
             UndirectedEdge[102, 134] -> 
             RGBColor[
              0.1917868632444325, 0.31891053163232136`, 0.9342333501873077], 
             UndirectedEdge[102, 174] -> 
             RGBColor[
              0.1934597999069662, 0.32066889413495503`, 0.934328621455351], 
             UndirectedEdge[203, 281] -> 
             RGBColor[
              0.8317474856787275, 0.2450306635294393, 0.1780347341805933], 
             UndirectedEdge[279, 421] -> 
             RGBColor[
              0.19615975110811917`, 0.3235067140341602, 0.9344823796820367], 
             UndirectedEdge[335, 430] -> 
             RGBColor[
              0.2059656395327683, 0.33381332449770196`, 0.9350408105213086], 
             UndirectedEdge[69, 431] -> 
             RGBColor[
              0.4320540938957698, 0.548645273287512, 0.9487510827059723], 
             UndirectedEdge[149, 249] -> 
             RGBColor[
              0.6440396780590834, 0.7206036278354, 0.9660062699352006], 
             UndirectedEdge[141, 345] -> 
             RGBColor[
              0.19907503548324326`, 0.3265708627521209, 0.9346484008144234], 
             UndirectedEdge[12, 283] -> 
             RGBColor[
              0.18817638831560224`, 0.31511569356478863`, 0.9340277389813298],
              UndirectedEdge[119, 381] -> 
             RGBColor[
              0.18630903659373593`, 0.3131529885081697, 0.9339213960632688], 
             UndirectedEdge[396, 430] -> 
             RGBColor[
              0.19949732248348956`, 0.32701471316392194`, 0.9346724494343697],
              UndirectedEdge[49, 360] -> 
             RGBColor[
              0.7950442531705986, 0.8362229179981473, 0.7707477142317521], 
             UndirectedEdge[208, 497] -> 
             RGBColor[
              0.4523984541828804, 0.5655914141074888, 0.9502339454421076], 
             UndirectedEdge[275, 444] -> 
             RGBColor[
              0.5275882362182631, 0.6273589235979986, 0.9559528250559413], 
             UndirectedEdge[269, 323] -> 
             RGBColor[
              0.7972919842565633, 0.8394603962804845, 0.8661383017091098], 
             UndirectedEdge[273, 279] -> 
             RGBColor[
              0.19757076585955963`, 0.32498978000142653`, 0.9345627348847221],
              UndirectedEdge[107, 289] -> 
             RGBColor[
              0.21067973016305835`, 0.3387681326407459, 0.9353092710088315], 
             UndirectedEdge[289, 314] -> 
             RGBColor[
              0.23644046461492338`, 0.36584429787455663`, 0.9367763067262738],
              UndirectedEdge[6, 428] -> 
             RGBColor[
              0.2010842377589775, 0.3286826617346995, 0.9347628219116779], 
             UndirectedEdge[7, 17] -> 
             RGBColor[
              0.4238987520286698, 0.5410646532335288, 0.9483742450361144], 
             UndirectedEdge[309, 424] -> 
             RGBColor[
              0.19083388775165383`, 0.3179088939672749, 0.9341790796427948], 
             UndirectedEdge[128, 385] -> 
             RGBColor[
              0.1879057798305126, 0.31483126688939045`, 0.9340123282284333], 
             UndirectedEdge[71, 362] -> 
             RGBColor[
              0.1884877837309814, 0.3154429898899618, 0.9340454724895675], 
             UndirectedEdge[43, 156] -> 
             RGBColor[
              0.21388174499134507`, 0.34213365324474115`, 0.935491621016346], 
             UndirectedEdge[59, 298] -> 
             RGBColor[
              0.2693422110049278, 0.4004261194216593, 0.9386500125094126], 
             UndirectedEdge[261, 455] -> 
             RGBColor[
              0.47116868386026034`, 0.5781874132378237, 0.9524417425284195], 
             UndirectedEdge[17, 89] -> 
             RGBColor[
              0.3425624838836552, 0.4711321386741221, 0.9430487564503239], 
             UndirectedEdge[9, 68] -> 
             RGBColor[
              0.18960972675890758`, 0.3166222231476087, 0.9341093654852418], 
             UndirectedEdge[73, 298] -> 
             RGBColor[
              0.42629344369918076`, 0.5372437988360448, 0.949423062513614], 
             UndirectedEdge[16, 333] -> 
             RGBColor[
              0.25095246372984137`, 0.3810973290582225, 0.9376027436072896], 
             UndirectedEdge[257, 445] -> 
             RGBColor[
              0.9630857175869136, 0.8871415989142806, 0.3110954128128076], 
             UndirectedEdge[428, 451] -> 
             RGBColor[
              0.19643038781423483`, 0.323791170371646, 0.934497792042079], 
             UndirectedEdge[15, 419] -> 
             RGBColor[
              0.6508464250830497, 0.7271654409816981, 0.9658339472127815], 
             UndirectedEdge[17, 313] -> 
             RGBColor[
              0.3683319514339016, 0.4934523562550466, 0.9446907641355802], 
             UndirectedEdge[5, 326] -> 
             RGBColor[
              0.7074791480476834, 0.7714073545863063, 0.9714785677750102], 
             UndirectedEdge[216, 217] -> 
             RGBColor[
              0.1905787639681844, 0.31764074269506637`, 0.9341645507207481], 
             UndirectedEdge[138, 222] -> 
             RGBColor[
              0.1899361610003327, 0.31696532623247287`, 0.9341279554323748], 
             UndirectedEdge[251, 447] -> 
             RGBColor[
              0.23632980233893142`, 0.3657279848060955, 0.9367700046733661], 
             UndirectedEdge[58, 144] -> 
             RGBColor[
              0.1950230989335921, 0.322312020530822, 0.9344176490222236], 
             UndirectedEdge[11, 404] -> 
             RGBColor[
              0.6062003014417219, 0.6862259327279479, 0.9647253472215822], 
             UndirectedEdge[270, 329] -> 
             RGBColor[
              0.18084643102754924`, 0.3074114437089104, 0.9336103087574752], 
             UndirectedEdge[314, 406] -> 
             RGBColor[
              0.3396550578396198, 0.4643665868457374, 0.9430190117624826], 
             UndirectedEdge[13, 409] -> 
             RGBColor[
              0.2530894600625647, 0.3833434476973081, 0.9377244423870355], 
             UndirectedEdge[279, 335] -> 
             RGBColor[
              0.20917892656929465`, 0.33719069290725634`, 0.9352238024644066],
              UndirectedEdge[195, 446] -> 
             RGBColor[
              0.1857509853248722, 0.31256644124209987`, 0.9338896158690699], 
             UndirectedEdge[22, 170] -> 
             RGBColor[
              0.18476666722380106`, 0.3115318605085019, 0.9338335604093819], 
             UndirectedEdge[159, 166] -> 
             RGBColor[
              0.21389899734106987`, 0.3421517865581641, 0.9354926035121403], 
             UndirectedEdge[59, 87] -> 
             RGBColor[
              0.28570409751894754`, 0.41762349955141664`, 0.939581797741144], 
             UndirectedEdge[176, 407] -> 
             RGBColor[
              0.2970315342752855, 0.4287723651208341, 0.94025459557011], 
             UndirectedEdge[169, 470] -> 
             RGBColor[
              0.1892131415618838, 0.316205386960583, 0.9340867805449665], 
             UndirectedEdge[13, 188] -> 
             RGBColor[
              0.23846099400411988`, 0.36796800237156463`, 0.9368913728858832],
              UndirectedEdge[273, 396] -> 
             RGBColor[
              0.19229860014365638`, 0.3194483995593991, 0.9342624928466716], 
             UndirectedEdge[30, 405] -> 
             RGBColor[
              0.1802965998650839, 0.3068335362958501, 0.9335789966861752], 
             UndirectedEdge[258, 497] -> 
             RGBColor[
              0.44668148609611025`, 0.5606396636938994, 0.9498696652909349], 
             UndirectedEdge[90, 485] -> 
             RGBColor[
              0.25884791756577036`, 0.3893959516404705, 0.9380523780229685], 
             UndirectedEdge[89, 455] -> 
             RGBColor[
              0.4613630510985772, 0.5696942669850865, 0.9518169362796256], 
             UndirectedEdge[422, 451] -> 
             RGBColor[
              0.20581343032131297`, 0.33365334296584104`, 0.9350321424318895],
              UndirectedEdge[99, 178] -> 
             RGBColor[
              0.7245036529888805, 0.7822124250066672, 0.9353076025507647], 
             UndirectedEdge[119, 416] -> 
             RGBColor[
              0.19677397614642037`, 0.32415230349353147`, 0.9345173588893034],
              UndirectedEdge[129, 204] -> 
             RGBColor[
              0.3026394845996296, 0.4347619361650844, 0.9405704721210151], 
             UndirectedEdge[1, 381] -> 
             RGBColor[
              0.1937883174344935, 0.32101418688560046`, 0.9343473300425454], 
             UndirectedEdge[287, 409] -> 
             RGBColor[
              0.2786937259844361, 0.4102551545854176, 0.9391825674531689], 
             UndirectedEdge[340, 384] -> 
             RGBColor[
              0.3159339914529744, 0.4443075647988586, 0.9414896959063039], 
             UndirectedEdge[233, 379] -> 
             RGBColor[
              0.8949909626419136, 0.5916992159390957, 0.5610798957464819], 
             UndirectedEdge[1, 124] -> 
             RGBColor[
              0.1923231620506201, 0.3194742156809328, 0.934263891610937], 
             UndirectedEdge[134, 309] -> 
             RGBColor[
              0.18616361548114224`, 0.31300014169860263`, 0.9339131145460378],
              UndirectedEdge[1, 380] -> 
             RGBColor[
              0.19337326869879815`, 0.3205779443487749, 0.9343236936310573], 
             UndirectedEdge[112, 403] -> 
             RGBColor[
              0.8684251833169994, 0.8955159189410955, 0.8667074610489753], 
             UndirectedEdge[214, 268] -> 
             RGBColor[
              0.186923339851059, 0.31379866018069236`, 0.9339563797249931], 
             UndirectedEdge[404, 444] -> 
             RGBColor[
              0.7013455249659886, 0.7655800526301657, 0.9716322684022551], 
             UndirectedEdge[252, 320] -> 
             RGBColor[
              0.18172265320945252`, 0.3083324087777858, 0.93366020831448], 
             UndirectedEdge[173, 419] -> 
             RGBColor[
              0.6849417616486415, 0.753800977040894, 0.9692322517226041], 
             UndirectedEdge[407, 475] -> 
             RGBColor[
              0.3068290918915676, 0.4372585170884935, 0.9408788872777796], 
             UndirectedEdge[167, 305] -> 
             RGBColor[
              0.27520889494048634`, 0.4064251539737775, 0.9389902343056846], 
             UndirectedEdge[407, 482] -> 
             RGBColor[
              0.3047507904187318, 0.43545839681119247`, 0.9407464597457003], 
             UndirectedEdge[197, 493] -> 
             RGBColor[
              0.24589919103084765`, 0.37578601905558584`, 0.9373149672027289],
              UndirectedEdge[235, 300] -> 
             RGBColor[
              0.22449059247181202`, 0.353284224586492, 0.9360957791859752], 
             UndirectedEdge[312, 385] -> 
             RGBColor[
              0.1882621822827025, 0.31520586846386267`, 0.9340326248208353], 
             UndirectedEdge[188, 318] -> 
             RGBColor[
              0.21097876418895464`, 0.3390824363618151, 0.935326300554225], 
             UndirectedEdge[71, 153] -> 
             RGBColor[
              0.21268791512647112`, 0.34087886236357334`, 0.9354236341716544],
              UndirectedEdge[45, 481] -> 
             RGBColor[
              0.20322304481879772`, 0.33093068356277056`, 0.9348846238096533],
              UndirectedEdge[53, 317] -> 
             RGBColor[
              0.8249968310509084, 0.19314217390430075`, 0.1715702996852197], 
             UndirectedEdge[253, 301] -> 
             RGBColor[
              0.5169703257345344, 0.6164641572661, 0.9558333707121969], 
             UndirectedEdge[442, 447] -> 
             RGBColor[
              0.23581693788510275`, 0.36518893174763706`, 0.9367407978014356],
              UndirectedEdge[118, 464] -> 
             RGBColor[
              0.1973325308094801, 0.3247393798588184, 0.9345491677510571], 
             UndirectedEdge[2, 118] -> 
             RGBColor[
              0.18820276986646162`, 0.31514342224742875`, 0.9340292413716232],
              UndirectedEdge[332, 454] -> 
             RGBColor[
              0.19901001769354992`, 0.3265025249327872, 0.9346446981474854], 
             UndirectedEdge[84, 455] -> 
             RGBColor[
              0.4442800341977758, 0.5518254258243921, 0.9508409168167211], 
             UndirectedEdge[423, 488] -> 
             RGBColor[
              0.18086431186395144`, 0.3074302376016796, 0.933611327044656], 
             UndirectedEdge[5, 231] -> 
             RGBColor[
              0.7266171062027156, 0.7863580729508864, 0.9733860605895166], 
             UndirectedEdge[121, 337] -> 
             RGBColor[
              0.19710919882017952`, 0.3245046437779975, 0.9345364493246566], 
             UndirectedEdge[23, 360] -> 
             RGBColor[
              0.5140568870299039, 0.6157933787663372, 0.9550478947958676], 
             UndirectedEdge[79, 336] -> 
             RGBColor[
              0.7557987774112169, 0.8094300480703478, 0.9763306281365505], 
             UndirectedEdge[237, 371] -> 
             RGBColor[
              0.24348618176994377`, 0.3732497933287522, 0.9371775498950476], 
             UndirectedEdge[9, 330] -> 
             RGBColor[
              0.19168631998098046`, 0.3188048542876222, 0.9342276243971945], 
             UndirectedEdge[76, 111] -> 
             RGBColor[
              0.3885098195301592, 0.510929411430886, 0.9459764800480857], 
             UndirectedEdge[91, 256] -> 
             RGBColor[
              0.3859408633418989, 0.5085140760316679, 0.9458653508371028], 
             UndirectedEdge[35, 193] -> 
             RGBColor[
              0.1842865051954063, 0.311027179772628, 0.9338062158922009], 
             UndirectedEdge[43, 267] -> 
             RGBColor[
              0.22881279968486046`, 0.35782713841117125`, 0.9363419224926257],
              UndirectedEdge[261, 448] -> 
             RGBColor[
              0.314938405291928, 0.4464509223622935, 0.9413162052121451], 
             UndirectedEdge[322, 374] -> 
             RGBColor[
              0.8341132720585396, 0.26321513433887644`, 0.18030021388967482`],
              UndirectedEdge[76, 130] -> 
             RGBColor[
              0.3566736138347697, 0.4828157529154782, 0.9439676309835814], 
             UndirectedEdge[107, 153] -> 
             RGBColor[
              0.21946182531602942`, 0.3479986714635114, 0.9358093983358476], 
             UndirectedEdge[410, 437] -> 
             RGBColor[
              0.1820838890101732, 0.30871209050801585`, 0.9336807801589306], 
             UndirectedEdge[11, 164] -> 
             RGBColor[
              0.3457994968745498, 0.4739358766298315, 0.9432550160557256], 
             UndirectedEdge[213, 500] -> 
             RGBColor[
              0.2016031036308693, 0.32922802266405415`, 0.934792370555489], 
             UndirectedEdge[251, 454] -> 
             RGBColor[
              0.22516117799061744`, 0.3539890524843341, 0.9361339680392287], 
             UndirectedEdge[111, 483] -> 
             RGBColor[
              0.4093161482374549, 0.528950807600658, 0.9473022409150004], 
             UndirectedEdge[5, 233] -> 
             RGBColor[
              0.8260668342903568, 0.864508719874695, 0.9589794534592146], 
             UndirectedEdge[69, 372] -> 
             RGBColor[
              0.5285636967606093, 0.627866783936419, 0.9561081041909547], 
             UndirectedEdge[454, 489] -> 
             RGBColor[
              0.20150669956748674`, 0.32912669588106847`, 0.9347868804866963],
              UndirectedEdge[289, 493] -> 
             RGBColor[
              0.235488823391288, 0.36484406261097735`, 0.9367221121664148], 
             UndirectedEdge[74, 268] -> 
             RGBColor[
              0.18750418807117342`, 0.3144091684879368, 0.9339894581718406], 
             UndirectedEdge[192, 258] -> 
             RGBColor[
              0.36408500922956, 0.4897738683751677, 0.944420152733743], 
             UndirectedEdge[68, 368] -> 
             RGBColor[
              0.18232969627571796`, 0.3089704495291842, 0.9336947785190641], 
             UndirectedEdge[50, 414] -> 
             RGBColor[
              0.6515149605889788, 0.7239780646853934, 0.9683019767918029], 
             UndirectedEdge[358, 441] -> 
             RGBColor[
              0.22317531852257919`, 0.3519017882726634, 0.9360208762803397], 
             UndirectedEdge[71, 289] -> 
             RGBColor[
              0.20390581997350005`, 0.33164832354080787`, 0.9349235068446382],
              UndirectedEdge[54, 321] -> 
             RGBColor[
              0.9874803221287802, 0.9890908057062746, 0.8571469924212342], 
             UndirectedEdge[75, 408] -> 
             RGBColor[
              0.9013012276585859, 0.7170355167790632, 0.6001882350839804], 
             UndirectedEdge[8, 239] -> 
             RGBColor[
              0.19706547094004007`, 0.32445868300346314`, 0.9345339590865722],
              UndirectedEdge[389, 472] -> 
             RGBColor[
              0.18902863113306126`, 0.3160114548012536, 0.9340762729490037], 
             UndirectedEdge[178, 475] -> 
             RGBColor[
              0.40291899149679977`, 0.5229757083496808, 0.9470145914961603], 
             UndirectedEdge[332, 489] -> 
             RGBColor[
              0.1891243849825443, 0.31611209816820496`, 0.9340817259890768], 
             UndirectedEdge[28, 406] -> 
             RGBColor[
              0.44617181476977985`, 0.5602617683644892, 0.9498196286740023], 
             UndirectedEdge[77, 87] -> 
             RGBColor[
              0.32144010648392174`, 0.4528061418339081, 0.9417039869994168], 
             UndirectedEdge[274, 300] -> 
             RGBColor[
              0.23797382817444995`, 0.36745596019648397`, 0.9368636295125807],
              UndirectedEdge[330, 333] -> 
             RGBColor[
              0.210684466253447, 0.33877311057202975`, 0.9353095407221728], 
             UndirectedEdge[325, 490] -> 
             RGBColor[
              0.22480172486171077`, 0.3536112444552085, 0.9361134977153007], 
             UndirectedEdge[420, 489] -> 
             RGBColor[
              0.189832836442401, 0.3168567255709313, 0.9341220712516556], 
             UndirectedEdge[271, 304] -> 
             RGBColor[
              0.19940240032278655`, 0.3269149439546105, 0.9346670437577425], 
             UndirectedEdge[166, 387] -> 
             RGBColor[
              0.19228627737083037`, 0.31943544754385, 0.934261791082989], 
             UndirectedEdge[16, 165] -> 
             RGBColor[
              0.28802163997316926`, 0.4200593836114821, 0.9397137783554151], 
             UndirectedEdge[44, 356] -> 
             RGBColor[
              0.262163357709175, 0.39288068944223503`, 0.9382411874343812], 
             UndirectedEdge[86, 377] -> 
             RGBColor[
              0.18305173765274474`, 0.30972936079650676`, 0.9337358977073213],
              UndirectedEdge[113, 353] -> 
             RGBColor[
              0.1887122478968889, 0.3156789159601807, 0.9340582553917509], 
             UndirectedEdge[63, 222] -> 
             RGBColor[
              0.20195670404025598`, 0.32959967911388044`, 0.9348125075756986],
              UndirectedEdge[71, 493] -> 
             RGBColor[
              0.2293216757786306, 0.35836199945033154`, 0.9363709022333513], 
             UndirectedEdge[106, 270] -> 
             RGBColor[
              0.17988066425974236`, 0.3063963616027956, 0.9335553097687725], 
             UndirectedEdge[414, 498] -> 
             RGBColor[
              0.5986264598736242, 0.6821731423501425, 0.9631600517720931], 
             UndirectedEdge[46, 220] -> 
             RGBColor[
              0.21037184686789395`, 0.33844452777659967`, 0.9352917375106444],
              UndirectedEdge[302, 443] -> 
             RGBColor[
              0.2662987639830351, 0.3972272636359636, 0.9384766927038922], 
             UndirectedEdge[90, 267] -> 
             RGBColor[
              0.24580395513477205`, 0.37568592009050583`, 0.9373095436593363],
              UndirectedEdge[116, 187] -> 
             RGBColor[
              0.24886259772016034`, 0.3789007473768896, 0.9374837288297179], 
             UndirectedEdge[162, 472] -> 
             RGBColor[
              0.18323095336378353`, 0.30991772787174093`, 0.933746103776939], 
             UndirectedEdge[271, 371] -> 
             RGBColor[
              0.23108898271360306`, 0.3602195510927192, 0.9364715477488016], 
             UndirectedEdge[84, 478] -> 
             RGBColor[
              0.2624145878361924, 0.3931447482346404, 0.9382554946184531], 
             UndirectedEdge[5, 163] -> 
             RGBColor[
              0.7944424008489477, 0.6965434437689743, 0.6036935441317027], 
             UndirectedEdge[188, 430] -> 
             RGBColor[
              0.2127664410138974, 0.34096139805008724`, 0.9354281061047747], 
             UndirectedEdge[380, 487] -> 
             RGBColor[
              0.19010454207928099`, 0.31714230542242455`, 0.9341375444857234],
              UndirectedEdge[88, 304] -> 
             RGBColor[
              0.19013400622997473`, 0.3171732741129387, 0.9341392224255172], 
             UndirectedEdge[41, 494] -> 
             RGBColor[
              0.3091950820990577, 0.43800954418308746`, 0.9410771822783439], 
             UndirectedEdge[23, 136] -> 
             RGBColor[
              0.48008619598652036`, 0.5882144414151268, 0.9523735975581908], 
             UndirectedEdge[7, 84] -> 
             RGBColor[
              0.373934744333056, 0.4947159504930181, 0.9453030779152829], 
             UndirectedEdge[218, 493] -> 
             RGBColor[
              0.2733906528975818, 0.4046812885368802, 0.9388805652860661], 
             UndirectedEdge[40, 183] -> 
             RGBColor[
              0.19098677743240255`, 0.31806959071550744`, 0.9341877864839334],
              UndirectedEdge[192, 453] -> 
             RGBColor[
              0.27645983051134826`, 0.4075148710199178, 0.9390697150866952], 
             UndirectedEdge[49, 397] -> 
             RGBColor[
              0.9079673464709124, 0.579798317184308, 0.3744269914858809], 
             UndirectedEdge[291, 467] -> 
             RGBColor[
              0.1871130842202519, 0.31399809354320196`, 0.933967185386117], 
             UndirectedEdge[347, 462] -> 
             RGBColor[
              0.19657186081581016`, 0.32393986746620806`, 0.934505848720228], 
             UndirectedEdge[31, 226] -> 
             RGBColor[
              0.1894803426038117, 0.3164862321971737, 0.9341019972490159], 
             UndirectedEdge[120, 381] -> 
             RGBColor[
              0.18410140079156978`, 0.3108326233078988, 0.9337956744702399], 
             UndirectedEdge[151, 274] -> 
             RGBColor[
              0.22389877891969617`, 0.3526621910200718, 0.9360620762796918], 
             UndirectedEdge[316, 418] -> 
             RGBColor[
              0.45760917454031613`, 0.5701502103978782, 0.9505533872489015], 
             UndirectedEdge[235, 389] -> 
             RGBColor[
              0.20601966033790897`, 0.3338701037890217, 0.9350438869262447], 
             UndirectedEdge[218, 310] -> 
             RGBColor[
              0.4653446361758491, 0.5701283226319324, 0.9524120897475179], 
             UndirectedEdge[408, 463] -> 
             RGBColor[
              0.746221620758815, 0.8012446952293572, 0.9745845586722801], 
             UndirectedEdge[12, 273] -> 
             RGBColor[
              0.1905970563658978, 0.31765996916486816`, 0.9341655924457366], 
             UndirectedEdge[121, 454] -> 
             RGBColor[
              0.20826238807822112`, 0.3362273528412414, 0.9351716069532372], 
             UndirectedEdge[47, 228] -> 
             RGBColor[
              0.2699130817435731, 0.4010261407632708, 0.9386825227534509], 
             UndirectedEdge[438, 439] -> 
             RGBColor[
              0.2009360669634459, 0.3285269248340248, 0.9347543838040715], 
             UndirectedEdge[172, 201] -> 
             RGBColor[
              0.2404718980048366, 0.3700815899749955, 0.9370058908938581], 
             UndirectedEdge[58, 375] -> 
             RGBColor[
              0.19795511773261765`, 0.3253937581893268, 0.934584623155295], 
             UndirectedEdge[168, 280] -> 
             RGBColor[
              0.2730931280966553, 0.40436857110694446`, 0.9388636216888019], 
             UndirectedEdge[77, 301] -> 
             RGBColor[
              0.49545804882307076`, 0.5978313042438662, 0.9544626274499579], 
             UndirectedEdge[283, 477] -> 
             RGBColor[
              0.19005559335530314`, 0.3170908572099954, 0.934134756928306], 
             UndirectedEdge[125, 149] -> 
             RGBColor[
              0.669539684263013, 0.7405244264891351, 0.9685478722425018], 
             UndirectedEdge[7, 407] -> 
             RGBColor[
              0.3747418079101595, 0.4955642254833401, 0.9453490389920554], 
             UndirectedEdge[401, 437] -> 
             RGBColor[
              0.18132345879022535`, 0.30791283013279, 0.9336374747828603], 
             UndirectedEdge[138, 438] -> 
             RGBColor[
              0.19270594078429107`, 0.3198765403995944, 0.9342856902935492], 
             UndirectedEdge[45, 399] -> 
             RGBColor[
              0.20452814783915604`, 0.33230242958547795`, 0.9349589474959358],
              UndirectedEdge[97, 317] -> 
             RGBColor[
              0.9028878976305327, 0.5534256006607606, 0.2869376293254444], 
             UndirectedEdge[71, 201] -> 
             RGBColor[
              0.22759518578243687`, 0.3565473489985437, 0.936272581182181], 
             UndirectedEdge[107, 236] -> 
             RGBColor[
              0.20982294786551192`, 0.3378676001228893, 0.935260478524482], 
             UndirectedEdge[134, 225] -> 
             RGBColor[
              0.1840482113903489, 0.31077671787481287`, 0.933792645412527], 
             UndirectedEdge[59, 91] -> 
             RGBColor[
              0.36166005851975747`, 0.48325335582239703`, 0.9444730770573722],
              UndirectedEdge[161, 287] -> 
             RGBColor[
              0.25900221419710867`, 0.3895581271829785, 0.9380611649878617], 
             UndirectedEdge[101, 486] -> 
             RGBColor[
              0.32922289158902907`, 0.45369458082192426`, 0.9424141922098388],
              UndirectedEdge[185, 330] -> 
             RGBColor[
              0.20056082053324595`, 0.3281325170438868, 0.934733014074999], 
             UndirectedEdge[237, 432] -> 
             RGBColor[
              0.26206160282215785`, 0.3927737386043475, 0.9382353926440985], 
             UndirectedEdge[99, 143] -> 
             RGBColor[
              0.7801748654933693, 0.827408823277354, 0.9396902443294888], 
             UndirectedEdge[107, 411] -> 
             RGBColor[
              0.24624789168403566`, 0.3761525255509848, 0.9373348251890715], 
             UndirectedEdge[187, 407] -> 
             RGBColor[
              0.24918791988473313`, 0.3792426815984722, 0.9375022554457193], 
             UndirectedEdge[185, 357] -> 
             RGBColor[
              0.20004263933508956`, 0.3275878757500389, 0.9347035044223444], 
             UndirectedEdge[80, 208] -> 
             RGBColor[
              0.38701536387166025`, 0.5096349890530197, 0.9458812546550213], 
             UndirectedEdge[60, 240] -> 
             RGBColor[
              0.9901494356226408, 0.989783903232943, 0.7830629910514044], 
             UndirectedEdge[262, 299] -> 
             RGBColor[
              0.2916203852027007, 0.4206594025249505, 0.9400352481392587], 
             UndirectedEdge[82, 282] -> 
             RGBColor[
              0.6084177855813375, 0.6921473526873871, 0.962885304068208], 
             UndirectedEdge[286, 368] -> 
             RGBColor[
              0.18331387184910375`, 0.310004880457148, 0.9337508258620111], 
             UndirectedEdge[81, 454] -> 
             RGBColor[
              0.2248746265777104, 0.3536878687809598, 0.9361176493601785], 
             UndirectedEdge[68, 352] -> 
             RGBColor[
              0.18440978245630846`, 0.311156751990066, 0.933813236349837], 
             UndirectedEdge[196, 337] -> 
             RGBColor[
              0.19054105270955757`, 0.3176011057712177, 0.934162403120358], 
             UndirectedEdge[261, 262] -> 
             RGBColor[
              0.33623006243366543`, 0.4656473134908974, 0.942645260155071], 
             UndirectedEdge[122, 286] -> 
             RGBColor[
              0.1865372127264831, 0.3133928160908893, 0.9339343903564724]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.20904447312210606`, 0.33704937380942024`, 0.9352161455394953],
              316 -> RGBColor[
              0.43871305828747303`, 0.5544129335543235, 0.9491753860287206], 
             308 -> RGBColor[
              0.19090439582770188`, 0.3179830024256716, 0.9341830949734184], 
             160 -> RGBColor[
              0.23944883454874902`, 0.3690062854166779, 0.9369476289435206], 
             245 -> RGBColor[
              0.2439252154854269, 0.3737112456000703, 0.9372025522156523], 
             155 -> RGBColor[
              0.19392286855916088`, 0.32115560864865994`, 0.9343549925300447],
              425 -> RGBColor[
              0.18667870528248892`, 0.31354153373839766`, 0.9339424481482175],
              213 -> RGBColor[
              0.20221750657572096`, 0.32987379911448994`, 0.9348273598942706],
              352 -> RGBColor[
              0.18339204965023842`, 0.3100870502828995, 0.9337552779721321], 
             27 -> RGBColor[
              0.18521154867326725`, 0.3119994591190039, 0.933858895749786], 
             485 -> RGBColor[
              0.255344871987097, 0.38571402863136683`, 0.9378528847595545], 
             454 -> 
             RGBColor[
              0.21139233227849236`, 0.33951712264565065`, 0.9353498526451051],
              367 -> RGBColor[
              0.19714961162350877`, 0.32454712019661625`, 0.9345387507740208],
              19 -> RGBColor[
              0.20321773659331793`, 0.33092510428123034`, 0.934884321514065], 
             164 -> RGBColor[
              0.3160253373259164, 0.44814699612157666`, 0.9413578329375422], 
             190 -> RGBColor[
              0.21654397156564814`, 0.3449318221692476, 0.9356432308813413], 
             103 -> RGBColor[
              0.40980409560216274`, 0.5293734430830204, 0.9473333324896046], 
             138 -> RGBColor[
              0.1827700546655207, 0.3094332941172014, 0.9337198562779115], 
             416 -> RGBColor[
              0.20922896777355948`, 0.3372432893857343, 0.9352266522369601], 
             476 -> RGBColor[
              0.18343003159278173`, 0.31012697171270676`, 0.9337574409875706],
              291 -> RGBColor[
              0.18307944483465585`, 0.30975848280143214`, 0.933737475590342], 
             28 -> RGBColor[
              0.47584147550400935`, 0.5853485720851631, 0.951879130497885], 
             337 -> RGBColor[
              0.1890859537624092, 0.3160717045191629, 0.9340795373879439], 
             195 -> RGBColor[
              0.18809486651088786`, 0.3150300089792529, 0.934023096435152], 
             114 -> RGBColor[
              0.18143431560131953`, 0.3080293476699778, 0.9336437879142542], 
             479 -> RGBColor[
              0.18231814009471767`, 0.3089583032502487, 0.933694120411652], 
             93 -> RGBColor[
              0.2226303791602024, 0.3513290224516542, 0.935989842789818], 34 -> 
             RGBColor[
              0.2089289231192469, 0.33692792343012196`, 0.9352095651377733], 
             161 -> RGBColor[
              0.2138505894071634, 0.34210090675038807`, 0.9354898467519174], 
             22 -> RGBColor[
              0.1817982963009414, 0.30841191446298966`, 0.9336645160766364], 
             124 -> RGBColor[
              0.18536877790044387`, 0.31216471700567533`, 0.9338678497216739],
              84 -> RGBColor[
              0.27551545928723997`, 0.406914594772917, 0.9390015698665879], 
             46 -> RGBColor[
              0.2037103551444467, 0.3314428776122868, 0.934912375411788], 241 -> 
             RGBColor[
              0.21562994450375172`, 0.3439711217745316, 0.9355911783923481], 
             185 -> RGBColor[
              0.21154093935996757`, 0.33967331811051427`, 0.9353583155985506],
              426 -> 
             RGBColor[
              0.18735694523176508`, 0.31425440692798345`, 0.9339810729099627],
              390 -> RGBColor[
              0.25591378716406765`, 0.38631199455366855`, 0.9378852836372484],
              121 -> RGBColor[
              0.20513244387794988`, 0.3329375830368321, 0.9349933612613692], 
             322 -> RGBColor[
              0.820782245844875, 0.16074702516771538`, 0.16753440813222906`], 
             488 -> RGBColor[
              0.18252871209609148`, 0.30917962777472857`, 0.9337061121756168],
              126 -> RGBColor[
              0.4884562669939937, 0.5955898281066129, 0.9528722130934804], 
             433 -> RGBColor[
              0.18067343227102245`, 0.30722961104704605`, 0.9336004567342198],
              236 -> RGBColor[
              0.20835940299106456`, 0.3363293216657406, 0.9351771318090029], 
             78 -> RGBColor[
              0.4700607186843903, 0.5806554932788695, 0.9514240481454346], 
             376 -> RGBColor[
              0.37110890510299593`, 0.49585761394946637`, 0.9448677091678112],
              458 -> RGBColor[
              0.2390221871354001, 0.3685578519342398, 0.9369233320044987], 
             254 -> RGBColor[
              0.19242949370172294`, 0.3195859769880579, 0.9342699470411637], 
             290 -> RGBColor[
              0.18152659560596812`, 0.30812633980575366`, 0.9336490431240029],
              251 -> RGBColor[
              0.23893002370274252`, 0.3684609823230175, 0.9369180834333524], 
             165 -> RGBColor[
              0.3059265832870255, 0.43887861427331937`, 0.9407334383891494], 
             460 -> RGBColor[
              0.3006736022333113, 0.4333573981276305, 0.9404342888892294], 
             100 -> RGBColor[
              0.9932268871291124, 0.987921321372956, 0.5041666466903745], 235 -> 
             RGBColor[
              0.2171179053764417, 0.345535062993897, 0.9356759155628069], 70 -> 
             RGBColor[
              0.3697431424982056, 0.49467465902642144`, 0.9447806839823304], 
             234 -> RGBColor[
              0.9263783006421346, 0.7458215255627042, 0.25962045645451476`], 
             435 -> RGBColor[
              0.23839852597207306`, 0.3679023445091814, 0.9368878154238712], 
             257 -> RGBColor[
              0.9630526170636222, 0.8870299430768459, 0.31096682353032956`], 
             135 -> RGBColor[
              0.17999586170885287`, 0.3065174414257509, 0.93356187009308], 
             265 -> RGBColor[
              0.18432263905515192`, 0.3110651587502397, 0.9338082736620582], 
             111 -> 
             RGBColor[
              0.3665915053486955, 0.49194486933340476`, 0.9445798644500469], 
             497 -> RGBColor[
              0.4781822073170808, 0.587248883619781, 0.9520634014805931], 481 -> 
             RGBColor[
              0.20526876593224802`, 0.3330808661592169, 0.9350011246006911], 
             381 -> RGBColor[
              0.18829908866819065`, 0.31524465941501073`, 0.9340347265848907],
              182 -> RGBColor[
              0.34499714152995936`, 0.4732409167578995, 0.9432038906826632], 
             188 -> RGBColor[
              0.2239766808649284, 0.35274407090377946`, 0.9360665126802272], 
             154 -> RGBColor[
              0.9834670894693087, 0.9871903629131425, 0.9128700844415136], 
             336 -> RGBColor[
              0.6253505975793664, 0.7067268126951324, 0.9636490362576168], 
             463 -> RGBColor[
              0.5551591248464408, 0.6497422130407317, 0.9581233064042441], 
             315 -> RGBColor[
              0.18340993044876472`, 0.3101058441358588, 0.9337562962571558], 
             368 -> RGBColor[
              0.1792318772890574, 0.3057144453611359, 0.9335183623105863], 
             269 -> RGBColor[
              0.6018738506410779, 0.6876673319152327, 0.961800860740477], 208 -> 
             RGBColor[
              0.42661470104868005`, 0.5439339445951966, 0.948404489403622], 
             86 -> RGBColor[
              0.18531184315250615`, 0.31210487497572126`, 0.9338646073720063],
              119 -> RGBColor[
              0.18431898451928125`, 0.31106131760132866`, 0.9338080655416469],
              436 -> RGBColor[
              0.35552088653300873`, 0.4823560557407374, 0.9438744544084752], 
             377 -> RGBColor[
              0.1807916321529833, 0.30735384661729226`, 0.9336071880426363], 
             140 -> RGBColor[
              0.17901437519538227`, 0.3054858368702541, 0.933505975888117], 
             85 -> RGBColor[
              0.18726966457396857`, 0.31416266942272597`, 0.9339761024056213],
              351 -> RGBColor[
              0.24019038642635912`, 0.3697857034571507, 0.9369898592259228], 
             443 -> RGBColor[
              0.2878366774276409, 0.41986497624882907`, 0.9397032450120749], 
             242 -> RGBColor[
              0.9731128985329042, 0.9794682242662037, 0.9303970288913456], 
             117 -> RGBColor[
              0.18356396795554494`, 0.3102677473220268, 0.933765068465289], 
             47 -> RGBColor[
              0.28160948378147765`, 0.4133198008998302, 0.9393486155462334], 
             451 -> 
             RGBColor[
              0.20508673054441848`, 0.33288953542489785`, 0.9349907579546514],
              81 -> RGBColor[
              0.23835692087692842`, 0.36785861491626903`, 0.9368854460752519],
              275 -> RGBColor[
              0.48931236896480956`, 0.5962848502534754, 0.9529396085766279], 
             23 -> RGBColor[
              0.4319501958436354, 0.5485552820168211, 0.9487444624139638], 
             328 -> RGBColor[
              0.24298649045633505`, 0.3727245860758903, 0.9371490932139648], 
             418 -> RGBColor[
              0.4765052907931592, 0.5858874872414329, 0.9519313884690823], 
             110 -> RGBColor[
              0.4170759329154467, 0.5356719430706164, 0.9477966875329739], 6 -> 
             RGBColor[
              0.21439443043390383`, 0.3426725181510049, 0.9355208176938495], 
             218 -> RGBColor[
              0.28587662659874513`, 0.4178048385532594, 0.9395916230170046], 
             108 -> RGBColor[
              0.20961363351384976`, 0.337647597467996, 0.9352485583818076], 
             297 -> RGBColor[
              0.19526251556143404`, 0.32256366258657476`, 0.934431283444994], 
             487 -> RGBColor[
              0.19274009296176206`, 0.31991243650348955`, 0.9342876352095326],
              464 -> RGBColor[
              0.20245401245038683`, 0.33012238178410236`, 0.9348408285539537],
              157 -> RGBColor[
              0.29909565256278264`, 0.4316988729761172, 0.9403444269898601], 
             441 -> RGBColor[
              0.22146757953397317`, 0.3501068463187328, 0.935923623071312], 
             354 -> RGBColor[
              0.31058773436371456`, 0.4434372177375889, 0.9410113536850742], 
             385 -> RGBColor[
              0.18155548323377793`, 0.30815670253416316`, 0.9336506882316712],
              270 -> RGBColor[
              0.18011392367187812`, 0.3066415320344512, 0.9335685935472172], 
             392 -> RGBColor[
              0.23685058796865582`, 0.3662753635226519, 0.9367996626445457], 
             33 -> RGBColor[
              0.25627137654269866`, 0.3866878436630859, 0.9379056478233554], 
             252 -> RGBColor[
              0.18230687199160545`, 0.30894645975943874`, 0.9336934787098494],
              394 -> RGBColor[
              0.18345440314028216`, 0.3101525877543751, 0.9337588289111464], 
             260 -> RGBColor[
              0.20975080596055196`, 0.33779177440671543`, 0.935256370149719], 
             159 -> RGBColor[
              0.2321162208184409, 0.36129924347156134`, 0.9365300474392095], 
             183 -> 
             RGBColor[
              0.19696480621086881`, 0.3243528779905917, 0.934528226379166], 
             99 -> RGBColor[
              0.9796979203258498, 0.9843793227373989, 0.9192503046446351], 
             329 -> RGBColor[
              0.18157893838322037`, 0.30818135538336955`, 0.9336520239677332],
              309 -> RGBColor[
              0.1881959331144625, 0.3151362363876026, 0.9340288520287109], 17 -> 
             RGBColor[
              0.3754434746784675, 0.49961200025393837`, 0.9451439041082509], 
             349 -> RGBColor[
              0.18519516767477753`, 0.31198224165097593`, 0.9338579628761555],
              495 -> RGBColor[
              0.8860920716837987, 0.5756525260362475, 0.22666477128519144`], 
             347 -> RGBColor[
              0.2030767017243416, 0.3307768676918091, 0.9348762897869192], 
             340 -> RGBColor[
              0.36379298595207366`, 0.4895209324897256, 0.9444015452687277], 
             404 -> RGBColor[
              0.8368269464602606, 0.8727271083178094, 0.9842984952692555], 
             277 -> RGBColor[
              0.44322657405371796`, 0.5583223140551463, 0.9494629832622005], 
             104 -> RGBColor[
              0.9241317229671294, 0.73691459370894, 0.25781280732325], 79 -> 
             RGBColor[
              0.8862469572430673, 0.9121332834455631, 0.9890122200154841], 
             327 -> RGBColor[
              0.1837791716078354, 0.31049394000528374`, 0.9337773239949216], 
             191 -> RGBColor[
              0.19059661539563244`, 0.31765950567716017`, 0.9341655673331324],
              50 -> RGBColor[
              0.8803633253605091, 0.9074418350893442, 0.9884510339541455], 
             225 -> RGBColor[
              0.18396512493287584`, 0.310689388740023, 0.9337879137616893], 
             405 -> RGBColor[
              0.1816592229448945, 0.3082657395480243, 0.9336565960547502], 61 -> 
             RGBColor[
              0.9902590342278114, 0.9902398745688678, 0.8110965418638902], 
             196 -> RGBColor[
              0.19199615165670597`, 0.3191305070232725, 0.9342452688527721], 
             1 -> RGBColor[
              0.19927754620079638`, 0.32678371435619025`, 0.9346599335002002],
              263 -> RGBColor[
              0.22433819907190317`, 0.35312404946088816`, 0.9360871006072962],
              201 -> RGBColor[
              0.25745169920403105`, 0.3879284376169253, 0.9379728654527874], 
             371 -> RGBColor[
              0.25408219745152405`, 0.38438687763629015`, 0.9377809773127133],
              293 -> 
             RGBColor[
              0.8097488880926076, 0.8513012527882134, 0.9816718596976299], 
             362 -> RGBColor[
              0.17923689510112015`, 0.3057197193997615, 0.9335186480675601], 
             184 -> RGBColor[
              0.5408355089237035, 0.6381136563631097, 0.9569956988896724], 
             106 -> RGBColor[
              0.17964740484760663`, 0.30615119117114004`, 0.9335420259903278],
              206 -> RGBColor[
              0.18041422854673403`, 0.3069571714983536, 0.933585695465579], 
             358 -> RGBColor[
              0.2248830575111852, 0.353696730226594, 0.9361181294893675], 247 -> 
             RGBColor[
              0.18427930277709584`, 0.31101960957432406`, 0.9338058057251333],
              220 -> RGBColor[
              0.21703333859134122`, 0.34544617794091254`, 0.9356710996095008],
              407 -> RGBColor[
              0.2771295864414469, 0.4086111447535611, 0.9390934920201328], 
             107 -> RGBColor[
              0.21128649273995928`, 0.33940587858003807`, 0.9353438252399612],
              375 -> RGBColor[
              0.20274272640358343`, 0.3304258384544339, 0.9348572703864743], 
             131 -> RGBColor[
              0.8337292727736055, 0.2602635475653142, 0.17993249574075687`], 
             411 -> RGBColor[
              0.281209290628112, 0.4128991725219315, 0.9393258251381819], 462 -> 
             RGBColor[
              0.1900670199072787, 0.31710286724060704`, 0.934135407653537], 
             127 -> RGBColor[
              0.8321508631713839, 0.8689985264321587, 0.9838524862707736], 
             210 -> RGBColor[
              0.19552365175645214`, 0.32283813328452987`, 0.9344461547649839],
              357 -> RGBColor[
              0.18854433931021156`, 0.3155024333895635, 0.934048693246138], 
             181 -> RGBColor[
              0.22551745991005276`, 0.354363527371239, 0.9361542577674687], 
             194 -> RGBColor[
              0.18610703405965695`, 0.3129406710371523, 0.933909892317789], 
             440 -> RGBColor[
              0.8916325056316791, 0.6008103425923479, 0.23128784517976625`], 
             490 -> RGBColor[
              0.2159679187439516, 0.3443263541297861, 0.9356104255253395], 
             118 -> RGBColor[
              0.19221104916857337`, 0.3193563779335344, 0.9342575069481607], 
             348 -> RGBColor[
              0.46208044251389646`, 0.5741767455763179, 0.9507958115725785], 
             276 -> RGBColor[
              0.21359854810176626`, 0.34183599535807396`, 0.9354754933724367],
              305 -> 
             RGBColor[
              0.3105546519813193, 0.443408563440727, 0.9410092457049215], 343 -> 
             RGBColor[
              0.8462306119676556, 0.35635431873254797`, 0.1919037922712223], 
             280 -> RGBColor[
              0.2534737690150518, 0.3837473807729669, 0.9377463282133454], 
             474 -> RGBColor[
              0.22951352418939525`, 0.35856364429393695`, 0.93638182771653], 
             189 -> RGBColor[
              0.2519720376195532, 0.38216896586102805`, 0.9376608068319842], 
             168 -> RGBColor[
              0.29271248717825876`, 0.424989761440922, 0.9399809151642584], 
             363 -> RGBColor[
              0.18261346087673228`, 0.3092687041165651, 0.9337109384932998], 
             41 -> RGBColor[
              0.2630876311955555, 0.3938521594787447, 0.9382938234420904], 14 -> 
             RGBColor[
              0.2309802119470121, 0.36010522612056717`, 0.9364653534145562], 
             77 -> RGBColor[
              0.33446793820227666`, 0.46412105004860754`, 0.9425329791572322],
              51 -> RGBColor[
              0.9952524916716045, 0.9922538846693116, 0.7246412005584384], 
             438 -> RGBColor[
              0.20264182690306143`, 0.3303197866819874, 0.9348515243091869], 
             179 -> RGBColor[
              0.2001120590885424, 0.3276608403123844, 0.9347074577746062], 
             467 -> RGBColor[
              0.19114672360584797`, 0.3182377042849717, 0.934196895181892], 
             223 -> RGBColor[
              0.20818468230621298`, 0.33614567914803034`, 0.9351671817244767],
              456 -> RGBColor[
              0.19561148544389112`, 0.32293045205900567`, 0.9344511567635453],
              323 -> RGBColor[
              0.9927101178720487, 0.9912534606457363, 0.7704757426777427], 
             500 -> RGBColor[
              0.20098870068601762`, 0.3285822462136184, 0.9347573812167074], 
             478 -> RGBColor[
              0.24931371638514488`, 0.37937490169636373`, 0.9375094193703185],
              292 -> RGBColor[
              0.18511992750412062`, 0.3119031594611132, 0.9338536780597445], 
             491 -> RGBColor[
              0.1816268290277524, 0.30823169148721496`, 0.9336547512690914], 
             396 -> RGBColor[
              0.19743844380411263`, 0.32485070113144887`, 0.9345551993394172],
              321 -> RGBColor[
              0.9854351531478911, 0.9882450757742316, 0.8910407351622261], 
             143 -> RGBColor[
              0.5806518106608889, 0.6704383238173092, 0.9601301840143426], 
             112 -> 
             RGBColor[
              0.9934414779456845, 0.9915558968312813, 0.7583552135583986], 
             197 -> RGBColor[
              0.23089370286527677`, 0.3600142995906707, 0.93646042685033], 
             421 -> RGBColor[
              0.1843367269803192, 0.31107996605281657`, 0.9338090759485553], 
             54 -> RGBColor[
              0.9895254911096693, 0.9899365356383177, 0.8232532496802422], 71 -> 
             RGBColor[
              0.19773867236084267`, 0.32516626038016205`, 0.9345722969115747],
              177 -> RGBColor[
              0.18438238961983267`, 0.3111279603821238, 0.9338116763683237], 
             158 -> RGBColor[
              0.19170728594478786`, 0.3188268908449026, 0.9342288183778169], 
             226 -> RGBColor[
              0.1869796895121246, 0.3138578872472471, 0.933959588754829], 432 -> 
             RGBColor[
              0.29123303955595214`, 0.4234347681874807, 0.9398966628108147], 
             350 -> RGBColor[
              0.1815243108454087, 0.3081239383775436, 0.933648913010269], 203 -> 
             RGBColor[
              0.8450710458930704, 0.34744138575819206`, 0.19079339048865696`],
              475 -> RGBColor[
              0.3365285973416883, 0.465905889423426, 0.9426642825354262], 115 -> 
             RGBColor[
              0.19098661972276523`, 0.31806942495267926`, 0.934187777502603], 
             173 -> RGBColor[
              0.720597203195575, 0.7816552789687509, 0.9727860529169569], 212 -> 
             RGBColor[
              0.1819457440050942, 0.3085668913487786, 0.9336729130052586], 
             129 -> RGBColor[
              0.2893758023858067, 0.42148269416601997`, 0.9397908959015111], 
             279 -> RGBColor[
              0.20798277523591915`, 0.3359334620155039, 0.9351556834155181], 
             26 -> RGBColor[
              0.1848952269737127, 0.31166698495681794`, 0.9338408816969523], 
             40 -> RGBColor[
              0.18500874865393632`, 0.31178630344042324`, 0.9338473465887008],
              146 -> RGBColor[
              0.1800731039927536, 0.30659862796357423`, 0.9335662689268784], 
             386 -> RGBColor[
              0.30560245203902436`, 0.43853793178056216`, 0.9407149795940849],
              192 -> RGBColor[
              0.3129892535839804, 0.4455172929823175, 0.9411643763662094], 
             300 -> RGBColor[
              0.23186327956718236`, 0.36103338617908703`, 0.9365156428091433],
              221 -> RGBColor[
              0.9622752132426141, 0.884407577445488, 0.3079467564861062], 62 -> 
             RGBColor[
              0.25119317281524384`, 0.3813503295688181, 0.9376164516336061], 
             286 -> RGBColor[
              0.18739586640915007`, 0.3142953155531602, 0.933983289413436], 
             472 -> RGBColor[
              0.18313584696674626`, 0.3098177650183609, 0.9337406876083251], 
             152 -> RGBColor[
              0.18423542654322242`, 0.31097349287060916`, 0.9338033070385232],
              64 -> RGBColor[
              0.18480592008610275`, 0.3115731177555562, 0.9338357958018207], 
             307 -> RGBColor[
              0.1917730045224159, 0.3188959652367882, 0.934232560953591], 37 -> 
             RGBColor[
              0.861854760386902, 0.4655965562049136, 0.20644056462819607`], 
             148 -> RGBColor[
              0.27463540520047075`, 0.4059896021290707, 0.9389514520882697], 
             261 -> RGBColor[
              0.329292758612209, 0.4596385695997802, 0.9422032212899847], 387 -> 
             RGBColor[
              0.18889078087796188`, 0.3158665654429332, 0.934068422580907], 
             15 -> RGBColor[
              0.6524065300643914, 0.7283842068503593, 0.9659894438973117], 
             136 -> RGBColor[
              0.5282221961294052, 0.6278736008134325, 0.956002732702418], 198 -> 
             RGBColor[
              0.1824115868132323, 0.30905652167627173`, 0.9336994420640293], 
             63 -> RGBColor[
              0.20681114074536727`, 0.3347019998800166, 0.9350889605645591], 
             444 -> RGBColor[
              0.5658641034717166, 0.6584329969425219, 0.9589660415352547], 
             310 -> RGBColor[
              0.644812645752953, 0.7224518067106054, 0.9652325564780311], 171 -> 
             RGBColor[
              0.47069483175957283`, 0.581170294839771, 0.9514739678495456], 
             395 -> RGBColor[
              0.5041410272247835, 0.6083234230523641, 0.954106974874018], 311 -> 
             RGBColor[
              0.18998459744441062`, 0.31701623600624673`, 0.9341307138162097],
              353 -> RGBColor[
              0.18070771638990538`, 0.3072656458297307, 0.9336024091640713], 
             59 -> RGBColor[
              0.26299592027232827`, 0.3937557654836245, 0.9382886006406869], 
             397 -> RGBColor[
              0.8220097648168001, 0.1701822738881748, 0.16870988168602888`], 
             229 -> RGBColor[
              0.2348407472607494, 0.36416289350738135`, 0.9366852051895233], 
             102 -> RGBColor[
              0.19944242864104303`, 0.32695701625504003`, 0.9346693233112505],
              453 -> 
             RGBColor[
              0.23993040743871616`, 0.3695124490575181, 0.936975053807181], 
             299 -> RGBColor[
              0.24007340415027964`, 0.3696627476678865, 0.9369831972583599], 
             128 -> RGBColor[
              0.19425607642724724`, 0.32150583124461773`, 0.9343739682251954],
              12 -> RGBColor[
              0.19403535624859544`, 0.3212738403423871, 0.9343613985375474], 
             222 -> RGBColor[
              0.1971022673351447, 0.32449735834774435`, 0.9345360545868381], 
             483 -> RGBColor[
              0.4520407911262143, 0.5659567458679113, 0.9500246173799538], 92 -> 
             RGBColor[
              0.27193911320159614`, 0.4031556282834669, 0.9387979022477403], 
             271 -> RGBColor[
              0.20809576797568208`, 0.3360522245491482, 0.9351621181848899], 
             361 -> RGBColor[
              0.23010075165696398`, 0.35918085759472357`, 0.9364152694520828],
              344 -> RGBColor[
              0.1902758304551235, 0.3173223403657453, 0.9341472991053292], 
             132 -> RGBColor[
              0.2723145403641676, 0.4035502260347864, 0.938819282269254], 80 -> 
             RGBColor[
              0.3474160266946404, 0.4753360335108428, 0.9433580199064205], 
             324 -> RGBColor[
              0.9397327677393429, 0.9545733773753136, 0.9869008833924131], 
             244 -> RGBColor[
              0.44672166802497704`, 0.5613495887845201, 0.9496856875594589], 
             150 -> RGBColor[
              0.2153604952721365, 0.34368791354803596`, 0.9355758336572221], 
             125 -> RGBColor[
              0.7779497574122243, 0.8264595302183536, 0.978502419531181], 258 -> 
             RGBColor[
              0.41518076487513966`, 0.5340304437680178, 0.9476759291012767], 
             133 -> RGBColor[
              0.19798057442534764`, 0.32542051478743356`, 0.9345860728762861],
              469 -> RGBColor[
              0.18135253868176207`, 0.30794339494256673`, 0.9336391308396634],
              255 -> RGBColor[
              0.19717041562221144`, 0.32456898651830246`, 0.9345399355309701],
              408 -> RGBColor[
              0.9372841166711893, 0.9527471774179826, 0.9910458109403161], 
             326 -> RGBColor[
              0.7253820295989173, 0.7853932217210695, 0.973262959696097], 176 -> 
             RGBColor[
              0.3169334821091241, 0.44893358548810713`, 0.9414156991200873], 
             230 -> RGBColor[
              0.2058983382969339, 0.3337425866316952, 0.9350369778154911], 
             274 -> 
             RGBColor[
              0.24408437678171757`, 0.37387853421388084`, 0.937211616216018], 
             87 -> RGBColor[
              0.30841227476556676`, 0.4414912336192087, 0.9408749948416013], 
             439 -> RGBColor[
              0.19923030702383038`, 0.32673406298606217`, 0.934657243298956], 
             130 -> RGBColor[
              0.30291909395791666`, 0.43571755230258913`, 0.9405621663210384],
              35 -> RGBColor[
              0.187649142725438, 0.3145615250202248, 0.9339977131249598], 379 -> 
             RGBColor[
              0.8274245231995631, 0.21180247958034423`, 0.17389506042845765`],
              31 -> RGBColor[
              0.19198099569549876`, 0.3191145771471003, 0.9342444057432027], 
             18 -> RGBColor[
              0.2883133698343315, 0.42036601019230513`, 0.9397303919394328], 
             24 -> RGBColor[
              0.18529079599648704`, 0.31208275308027844`, 0.9338634087676074],
              151 -> RGBColor[
              0.20371318105767475`, 0.33144584782626274`, 0.9349125363433657],
              137 -> RGBColor[
              0.2116557852103354, 0.33979402838089834`, 0.9353648558998299], 
             330 -> RGBColor[
              0.18958070170652433`, 0.3165917159772593, 0.9341077125514473], 
             296 -> RGBColor[
              0.18222924951210637`, 0.30886487361193576`, 0.9336890582244741],
              266 -> RGBColor[
              0.9935833726583437, 0.9886838078737659, 0.5429678965735315], 
             302 -> RGBColor[
              0.24476085053842922`, 0.3745895510230982, 0.9372501403957095], 
             442 -> RGBColor[
              0.2379042947950852, 0.36738287620610066`, 0.9368596696894913], 
             283 -> RGBColor[
              0.18231742038260904`, 0.3089575467871901, 0.9336940794251122], 
             388 -> RGBColor[
              0.3286879472145684, 0.4591147123658486, 0.9421646832425408], 
             284 -> RGBColor[
              0.20683017875346388`, 0.3347220100336056, 0.935090044750956], 
             417 -> RGBColor[
              0.19713115786974042`, 0.32452772413137015`, 0.9345376998600435],
              318 -> RGBColor[
              0.1979808475129809, 0.32542080181985084`, 0.9345860884282229], 
             413 -> RGBColor[
              0.23030998251802656`, 0.3594007724957031, 0.936427184840091], 
             238 -> RGBColor[
              0.48668906339049306`, 0.5941551326096759, 0.9527330923523326], 
             72 -> RGBColor[
              0.21111609134757603`, 0.339226775912571, 0.9353341211327513], 
             437 -> 
             RGBColor[
              0.18191959414620315`, 0.3085394061890873, 0.93367142380948], 
             288 -> RGBColor[
              0.7112234006140565, 0.7743323931485304, 0.9718517598787967], 
             382 -> RGBColor[
              0.21206977390702858`, 0.3402291567495223, 0.9353884319436652], 
             461 -> RGBColor[
              0.25327163562221944`, 0.38353492576110276`, 0.9377348170156531],
              389 -> RGBColor[
              0.19492141529937626`, 0.32220514458414634`, 0.9344118582896825],
              172 -> RGBColor[
              0.22349209680564214`, 0.35223474233306573`, 0.9360389163349288],
              447 -> RGBColor[
              0.23372958097512028`, 0.36299498728917345`, 0.9366219259133799],
              243 -> RGBColor[
              0.19657931914436805`, 0.32394770664240774`, 0.9345062734610058],
              410 -> RGBColor[
              0.18224818387414324`, 0.30888477482694443`, 0.9336901365083813],
              88 -> RGBColor[
              0.18955897979005848`, 0.3165688848658047, 0.9341064755204392], 
             273 -> RGBColor[
              0.18715875648320013`, 0.3140460979873492, 0.9339697863539259], 
             477 -> RGBColor[
              0.19779376632799722`, 0.32522416763280076`, 0.9345754344314999],
              202 -> RGBColor[
              0.18676020758344578`, 0.31362719782424764`, 0.9339470895836851],
              393 -> RGBColor[
              0.2213158585080208, 0.34994737790078817`, 0.9359149827833353], 
             98 -> RGBColor[
              0.18830185869099547`, 0.3152475708846082, 0.9340348843335916], 
             30 -> RGBColor[
              0.17893397678527326`, 0.30540133304367595`, 0.9335013973176001],
              116 -> RGBColor[
              0.27647894211230134`, 0.40792727631039594`, 0.9390564387881299],
              373 -> RGBColor[
              0.9909995879120733, 0.9905461125486716, 0.7988236508241691], 
             434 -> RGBColor[
              0.9350798973521478, 0.7803204568826958, 0.2666219654201177], 
             401 -> RGBColor[
              0.18072732343424755`, 0.30728625407649274`, 0.9336035257562406],
              240 -> RGBColor[
              0.9948059876224538, 0.9912988576566625, 0.6760419903119628], 
             480 -> RGBColor[
              0.24336115250331075`, 0.37311837964220756`, 0.9371704296632771],
              403 -> RGBColor[
              0.7434088886883141, 0.7994759410509097, 0.9750597085395519], 
             317 -> RGBColor[0.817319, 0.134127, 0.164218], 429 -> 
             RGBColor[
              0.1919491178531559, 0.319081071513626, 0.9342425903472402], 391 -> 
             RGBColor[
              0.47311473175482466`, 0.583134878671169, 0.9516644712415576], 
             73 -> RGBColor[
              0.5768983856608343, 0.6673911243123956, 0.9598347006490895], 
             303 -> RGBColor[
              0.8407980254541154, 0.31459707821488886`, 0.1867015412906274], 
             449 -> RGBColor[
              0.9836066487684537, 0.9563635183333898, 0.39081535540040413`], 
             29 -> RGBColor[
              0.1844293578243088, 0.3111773269429844, 0.9338143511380854], 
             360 -> RGBColor[
              0.5961635782161725, 0.6830314755158533, 0.9613513271777714], 
             320 -> RGBColor[
              0.18113843442729957`, 0.3077183577961329, 0.9336269379191107], 
             482 -> RGBColor[
              0.3323719943960167, 0.4623056488688239, 0.9423994274712677], 75 -> 
             RGBColor[
              0.8653183386459826, 0.4813238561401438, 0.20933065922764493`], 
             200 -> RGBColor[
              0.26297543885551555`, 0.39373423821595743`, 0.938287434254299], 
             301 -> RGBColor[
              0.6564481594438648, 0.7315415584391249, 0.9663922757426836], 
             156 -> RGBColor[
              0.19939483773806957`, 0.32690699519857735`, 0.9346666130797306],
              25 -> RGBColor[
              0.2888948585418871, 0.42097719169245956`, 0.9397635068610926], 
             38 -> RGBColor[
              0.5188198477638203, 0.6202403508392836, 0.9552625453971423], 
             365 -> RGBColor[
              0.20704370002822514`, 0.33494643443141037`, 0.9351022044716772],
              380 -> RGBColor[
              0.1874689911967999, 0.31437217434135956`, 0.9339874537619143], 
             370 -> RGBColor[
              0.22875987812146206`, 0.3577715144926186, 0.9363389086878806], 
             3 -> RGBColor[
              0.18365861817242612`, 0.31036723070113925`, 0.9337704586551179],
              57 -> RGBColor[
              0.9626408166905339, 0.9716581627746242, 0.9481235318941049], 
             227 -> RGBColor[
              0.19315889756887425`, 0.3203526266993102, 0.9343114855123418], 
             494 -> RGBColor[
              0.35530253300255993`, 0.4821669288874302, 0.9438605411145975], 
             39 -> RGBColor[
              0.24759097892264678`, 0.3775641953954144, 0.937411312020391], 
             424 -> RGBColor[
              0.19347184238884513`, 0.3206815515469472, 0.9343293072568787], 
             109 -> 
             RGBColor[
              0.2136359512540558, 0.3418753084426271, 0.9354776234266265], 
             465 -> RGBColor[
              0.1790493149440538, 0.30552256076141593`, 0.9335079656551152], 
             256 -> RGBColor[
              0.3115575299166111, 0.44427720590216613`, 0.9410731482001482], 
             457 -> RGBColor[
              0.4692511982227218, 0.5799982880996057, 0.9513603197293209], 
             339 -> RGBColor[
              0.1801862242299471, 0.30671752450510187`, 0.9335727109570402], 
             420 -> RGBColor[
              0.1880446060283209, 0.31497718202537633`, 0.9340202341750236], 
             287 -> RGBColor[
              0.304153838987054, 0.4370153476155689, 0.9406324832238061], 239 -> 
             RGBColor[
              0.1966443508485099, 0.324016059086709, 0.9345099769203509], 427 -> 
             RGBColor[
              0.18651414967483487`, 0.3133685753613251, 0.9339330769497998], 
             285 -> RGBColor[
              0.21438774917055564`, 0.3426654957196094, 0.9355204372057859], 
             345 -> RGBColor[
              0.19084105210201593`, 0.31791642415375154`, 0.9341794876419492],
              366 -> RGBColor[
              0.18255683100735334`, 0.30920918253330676`, 0.933707713506015], 
             216 -> RGBColor[
              0.19991510326486814`, 0.3274538272539823, 0.934696241431818], 
             21 -> RGBColor[
              0.3000028152540131, 0.4326523584820372, 0.9403960885630988], 
             355 -> RGBColor[
              0.5597098423756648, 0.6534366905384442, 0.9584815555579723], 
             175 -> RGBColor[
              0.39767741348965524`, 0.5188699205419315, 0.9465606310285997], 
             7 -> RGBColor[
              0.47235402937887205`, 0.5825173062131191, 0.951604585963978], 
             13 -> RGBColor[
              0.25294530714331137`, 0.3831919338393498, 0.9377162330915391], 
             294 -> RGBColor[
              0.18749202516745894`, 0.31439638450496027`, 0.9339887655124676],
              412 -> RGBColor[
              0.1902556572489104, 0.31730113704696017`, 0.934146150271079], 
             193 -> RGBColor[
              0.18092386766537458`, 0.30749283452503123`, 0.9336147186594421],
              60 -> RGBColor[
              0.9854928836228277, 0.9882689488092234, 0.890083991790846], 65 -> 
             RGBColor[
              0.183179266829206, 0.30986340204678436`, 0.9337431603052583], 
             448 -> RGBColor[
              0.300584051971647, 0.4332632751248068, 0.9404291891343054], 69 -> 
             RGBColor[
              0.44285619720498837`, 0.5580015122444584, 0.9494393831769108], 
             217 -> RGBColor[
              0.18124242467150065`, 0.3078276581361505, 0.9336328600096782], 
             214 -> RGBColor[
              0.1875451608924792, 0.3144522335209561, 0.9339917915134002], 
             170 -> RGBColor[
              0.1877350381466607, 0.3146518065540141, 0.9340026047421276], 
             359 -> RGBColor[
              0.9095261013751367, 0.9306954410809412, 0.9912326055643381], 74 -> 
             RGBColor[
              0.18870685733270803`, 0.31567325013544506`, 0.9340579484070953],
              246 -> RGBColor[
              0.2398990282396083, 0.3694794675296996, 0.9369732668082131], 
             264 -> RGBColor[
              0.8655438992520076, 0.482348074171085, 0.20951887252630852`], 
             278 -> RGBColor[
              0.18446408847726348`, 0.3112138310612903, 0.9338163289973919], 
             45 -> RGBColor[
              0.2011773237053474, 0.3287805009663242, 0.9347681230186154], 
             492 -> RGBColor[
              0.18260872208869527`, 0.3092637233498817, 0.9337106686263315], 
             306 -> RGBColor[
              0.24077004537273583`, 0.3703949617622926, 0.9370228699453904], 
             237 -> RGBColor[
              0.2328901660883635, 0.3621127090212143, 0.9365741224773821], 
             228 -> RGBColor[
              0.2582166797056685, 0.38873248062671145`, 0.9380164299606684], 
             180 -> RGBColor[
              0.26314504718325327`, 0.39391250732219896`, 0.9382970931976505],
              383 -> RGBColor[
              0.2677744651747997, 0.39877831915336787`, 0.938560731703659], 
             53 -> RGBColor[
              0.8326746621018166, 0.2521573478086015, 0.17892259937043942`], 
             304 -> RGBColor[
              0.190709032669891, 0.3177776633600728, 0.934171969330595], 48 -> 
             RGBColor[
              0.18988308106937135`, 0.3169095358595705, 0.9341249326088312], 
             5 -> RGBColor[
              0.6895762664964494, 0.7574214874515429, 0.9696941758539234], 
             101 -> RGBColor[
              0.24511118458418202`, 0.3749577743176459, 0.9372700914013423], 
             333 -> RGBColor[
              0.23178823080036964`, 0.3609545051668002, 0.9365113688928981], 
             267 -> RGBColor[
              0.22925694712510034`, 0.35829396553143755`, 0.9363672160322901],
              120 -> RGBColor[
              0.1799037129149489, 0.30642058720078685`, 0.9335566223555891], 
             147 -> 
             RGBColor[
              0.8190803262063154, 0.147665325039805, 0.16590464796430104`], 
             89 -> RGBColor[
              0.30968149308884285`, 0.4426522770943059, 0.940953608792397], 
             43 -> RGBColor[
              0.22836865224462058`, 0.35736031129090495`, 0.9363166289529613],
              199 -> RGBColor[
              0.3861343022549474, 0.5088718577640675, 0.9458251141878965], 
             268 -> RGBColor[
              0.1863015188096388, 0.3131450868404286, 0.9339209679365861], 
             169 -> RGBColor[
              0.18381241008660495`, 0.31052887575391175`, 0.9337792168771156],
              20 -> RGBColor[
              0.24175756143219096`, 0.3714329037529144, 0.9370791075240773], 
             4 -> RGBColor[
              0.18151204232925333`, 0.30811104338919537`, 0.9336482143364235],
              167 -> RGBColor[
              0.23986313789965336`, 0.369441744506828, 0.9369712229064477], 
             431 -> RGBColor[
              0.4212519905865513, 0.5392890343305656, 0.9480627822350338], 
             142 -> RGBColor[
              0.21571267720568413`, 0.3440580790898188, 0.9355958898973311], 
             16 -> RGBColor[
              0.27011669665931304`, 0.4012401529496448, 0.9386941183216809], 
             414 -> RGBColor[
              0.4226665958174486, 0.5405142942814426, 0.9481529196294604], 
             281 -> RGBColor[
              0.8184239254643847, 0.14261994130068656`, 0.16527607787252963`],
              289 -> RGBColor[
              0.21007296758615746`, 0.3381303867014537, 0.9352747167777018], 
             398 -> RGBColor[
              0.20625914549310514`, 0.3341218178713687, 0.9350575252515466], 
             178 -> RGBColor[
              0.46930938565191127`, 0.5800455272759355, 0.9513649004568943], 
             58 -> RGBColor[
              0.19316750906165184`, 0.32036167792421966`, 0.9343119759241159],
              186 -> RGBColor[
              0.9933232264913885, 0.9881273815274607, 0.5146525917364964], 
             122 -> RGBColor[
              0.18567855904381614`, 0.3124903166286185, 0.9338854912995088], 
             249 -> RGBColor[
              0.7269497450043649, 0.7866179329108834, 0.9734192149165786], 
             113 -> RGBColor[
              0.19671677940387242`, 0.3240921860906307, 0.9345141016194304], 
             52 -> RGBColor[
              0.1799948891424975, 0.30651641919684713`, 0.9335618147068648], 
             409 -> RGBColor[
              0.2532336129818181, 0.38349496155526636`, 0.9377326516825317], 
             187 -> 
             RGBColor[
              0.22124625332801934`, 0.34987421844338334`, 0.9359110188713058],
              259 -> RGBColor[
              0.6832732263253226, 0.7524975045649791, 0.9690659477149247], 42 -> 
             RGBColor[
              0.2005501569047806, 0.3281213088942566, 0.9347324067971333], 
             134 -> RGBColor[
              0.18413129784782198`, 0.3108640470096027, 0.9337973770633647], 
             470 -> RGBColor[
              0.19461387303716265`, 0.3218818981672542, 0.9343943442128174], 
             313 -> RGBColor[
              0.36122042818933575`, 0.4872927122561548, 0.9442376241629096], 
             248 -> RGBColor[
              0.18027294835259305`, 0.30680867705662973`, 0.933577649767528], 
             174 -> RGBColor[
              0.18747717117288942`, 0.31438077201487, 0.9339879195994514], 
             215 -> RGBColor[
              0.18496268734880916`, 0.3117378900882792, 0.9338447234655154], 
             399 -> RGBColor[
              0.20787897197296468`, 0.3358243582046317, 0.9351497719732561], 
             422 -> RGBColor[
              0.20654013009820746`, 0.33441715050678417`, 0.9350735269091277],
              83 -> RGBColor[
              0.9952268649647723, 0.9922942002460275, 0.7287667302186207], 95 -> 
             RGBColor[
              0.1846806812934658, 0.3114414838438967, 0.9338286636378542], 
             166 -> RGBColor[
              0.19568177386369887`, 0.32300432964476683`, 0.934455159585071], 
             384 -> RGBColor[
              0.2680749969538752, 0.3990941971079916, 0.9385778465438803], 
             233 -> RGBColor[
              0.9625574020842641, 0.9715959522978471, 0.948264731064506], 295 -> 
             RGBColor[
              0.9847959098179251, 0.9879807322294865, 0.9016346514484699], 
             499 -> RGBColor[
              0.628572856489554, 0.7093427876395323, 0.96390270428255], 141 -> 
             RGBColor[
              0.2073090188644706, 0.33522530135049017`, 0.9351173139868973], 
             319 -> RGBColor[
              0.18086286172523808`, 0.3074287134139478, 0.9336112444614015], 
             205 -> RGBColor[
              0.23748131534596645`, 0.36693829798663086`, 0.936835581635606], 
             468 -> RGBColor[
              0.22150150348383524`, 0.3501425025409405, 0.9359255549900708], 
             486 -> RGBColor[
              0.41333459859387617`, 0.5324313873262027, 0.9475582930183354], 
             224 -> RGBColor[
              0.20593429362604587`, 0.3337803779622914, 0.9350390254182929], 
             231 -> 
             RGBColor[
              0.7636579459089816, 0.81529465845023, 0.9770779453251097], 332 -> 
             RGBColor[
              0.18662770310860746`, 0.3134879272199237, 0.9339395436498659], 
             68 -> RGBColor[
              0.18542751526237852`, 0.31222645369723245`, 0.933871194727542], 
             484 -> RGBColor[
              0.1848118632397346, 0.3115793643868409, 0.933836134255628], 10 -> 
             RGBColor[
              0.22678684537035088`, 0.355697731973699, 0.9362265473915452], 
             250 -> RGBColor[
              0.2196415898680099, 0.3481876154053738, 0.9358196356611451], 
             282 -> RGBColor[
              0.6967134214587186, 0.7629970871524544, 0.9704055407600571], 
             374 -> RGBColor[
              0.847444298272204, 0.36568324351003745`, 0.19306601964712058`], 
             232 -> RGBColor[
              0.2784596091749779, 0.41000908297481403`, 0.939169234847215], 
             489 -> RGBColor[
              0.19162106685648111`, 0.3187362691164863, 0.9342239083282876], 
             253 -> RGBColor[
              0.37749249202520396`, 0.5013867560930751, 0.94527446568171], 
             459 -> RGBColor[
              0.1944799719611093, 0.3217411596465035, 0.9343867187446251], 
             415 -> RGBColor[
              0.1803991146634024, 0.3069412858486965, 0.9335848347522823], 55 -> 
             RGBColor[
              0.5735931996355866, 0.6647078254001658, 0.9595745042978867], 
             446 -> RGBColor[
              0.18340710413885652`, 0.31010287350494686`, 0.9337561353029877],
              325 -> RGBColor[
              0.23363553097946993`, 0.3628961347806308, 0.9366165699052621], 
             91 -> RGBColor[
              0.46032419676718667`, 0.5727509461611696, 0.9506575534740573], 
             450 -> RGBColor[
              0.2155265395117455, 0.34386243657167787`, 0.9355852896310274], 
             423 -> RGBColor[
              0.1791999116318114, 0.3056808474286306, 0.9335165419136952], 
             105 -> RGBColor[
              0.1914252698739526, 0.31853047407360313`, 0.9342127579797883], 
             36 -> RGBColor[
              0.9941315043202534, 0.9918412404700345, 0.7469196908007765], 
             123 -> RGBColor[
              0.18584647349383113`, 0.3126668053619753, 0.93389505377903], 94 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 473 -> 
             RGBColor[
              0.2635938852306148, 0.3943842645679517, 0.9383226538604513], 
             312 -> RGBColor[
              0.19496888133162707`, 0.3222550343935622, 0.9344145614099995], 
             96 -> RGBColor[
              0.4707743379765772, 0.5812348415684494, 0.9514802268701891], 
             496 -> RGBColor[
              0.1858152550736946, 0.31263399282304966`, 0.9338932759361868], 
             2 -> RGBColor[
              0.18419449056434983`, 0.3109304665613231, 0.9338009757950858], 
             262 -> RGBColor[
              0.34316736625512184`, 0.47165605738201455`, 0.9430872990201573],
              272 -> RGBColor[
              0.25722683759211185`, 0.3876920938057486, 0.9379600599166416], 
             97 -> RGBColor[
              0.9884567952610653, 0.9727242013215213, 0.40965725865088887`], 
             372 -> RGBColor[
              0.6142711963162304, 0.6977320556283797, 0.9627768252049985], 
             356 -> RGBColor[
              0.24531622372842543`, 0.3751732834584783, 0.9372817680772788], 
             402 -> RGBColor[
              0.21812922311479366`, 0.346598022058153, 0.9357335086118955], 
             455 -> RGBColor[
              0.6130446091083116, 0.6967362568758672, 0.9626802637668542], 
             428 -> RGBColor[
              0.18777404508405116`, 0.31469280531839416`, 0.9340048261295064],
              346 -> RGBColor[
              0.4414153171565428, 0.5567534943672319, 0.9493475715743441], 
             341 -> RGBColor[
              0.9942973298741586, 0.9902108901662465, 0.6206777334817875], 
             209 -> RGBColor[
              0.9944761061763768, 0.9919837421934052, 0.7412087462437971], 
             498 -> RGBColor[
              0.7745863239297996, 0.8238319904188423, 0.9781671839147258], 
             378 -> RGBColor[
              0.20696414784897932`, 0.33486282004712353`, 0.9350976740927561],
              419 -> RGBColor[
              0.649286320101708, 0.725946675113037, 0.9656784505282513], 66 -> 
             RGBColor[
              0.19788231111085003`, 0.3253172338136426, 0.9345804769258931], 
             139 -> RGBColor[
              0.18259939511325524`, 0.3092539201073298, 0.9337101374688782], 
             56 -> RGBColor[
              0.4068474012204774, 0.5268125030173851, 0.9471449345381059], 
             335 -> RGBColor[
              0.21037507790267013`, 0.33844792379900884`, 0.935291921513295], 
             314 -> RGBColor[
              0.2628079616436893, 0.3935582090476596, 0.9382778966748457], 
             144 -> RGBColor[
              0.1968786888055324, 0.3242623631374243, 0.9345233221203314], 
             298 -> 
             RGBColor[
              0.2756885017375273, 0.407096473359694, 0.9390114243781383], 204 -> 
             RGBColor[
              0.3159031668134525, 0.44804117816414885`, 0.941350048340519], 
             452 -> RGBColor[
              0.22680832648896532`, 0.3557203099913444, 0.9362277707094718], 
             466 -> RGBColor[
              0.19488624546246058`, 0.32216817885565147`, 0.9344098554194993],
              207 -> RGBColor[
              0.8749870106263872, 0.5252270374274478, 0.21739843612893187`], 
             334 -> RGBColor[
              0.18685517330782678`, 0.3137270128217468, 0.9339524977411994], 
             149 -> RGBColor[
              0.5611296111138018, 0.6545893227599167, 0.9585933249538227], 
             219 -> RGBColor[
              0.6695263659366376, 0.7417583527493299, 0.9676957891430948], 
             400 -> RGBColor[
              0.989868357531768, 0.9900783197151207, 0.8175710657562082], 9 -> 
             RGBColor[
              0.1937919382554366, 0.32101799259798497`, 0.9343475362429416], 
             11 -> RGBColor[
              0.37557365642318313`, 0.49972475713808634`, 0.9451521991739089],
              44 -> RGBColor[
              0.2790104916899246, 0.4105880954259918, 0.9392006067914836], 
             153 -> RGBColor[
              0.22763715789209957`, 0.35659146434698463`, 0.9362749714317341],
              471 -> RGBColor[
              0.9568366664708343, 0.967329437044196, 0.9579484442512339], 406 -> 
             RGBColor[
              0.41650215403555035`, 0.5351749646438152, 0.9477601268501196], 
             32 -> RGBColor[
              0.21967241372144744`, 0.34822001322968177`, 0.9358213910339986],
              162 -> RGBColor[
              0.18332605976082084`, 0.310017690725121, 0.933751519945553], 
             493 -> RGBColor[
              0.2609046791964185, 0.39155773852050096`, 0.9381695075551277], 
             90 -> RGBColor[
              0.2623509631444437, 0.39307787464957405`, 0.9382518712863824], 
             331 -> RGBColor[
              0.30143473291096856`, 0.4341573947283205, 0.94047763415533], 8 -> 
             RGBColor[
              0.19748659103157024`, 0.32490130692021735`, 0.9345579412527936],
              364 -> RGBColor[
              0.20439189938454302`, 0.3321592238210287, 0.9349511883480071], 
             342 -> RGBColor[
              0.47631296582080423`, 0.5857313491647339, 0.951916247942749], 
             163 -> RGBColor[
              0.899308535201446, 0.6356654000864056, 0.23769291240948212`], 
             49 -> 
             RGBColor[
              0.9939249281250245, 0.9894143604804412, 0.5801441012857329], 
             338 -> RGBColor[
              0.4243323457115801, 0.5419570831167153, 0.9482590597397496], 76 -> 
             RGBColor[
              0.4104281337116228, 0.5299139535283672, 0.9473730956461243], 
             369 -> RGBColor[
              0.18202687820624844`, 0.30865216853839716`, 0.933677533477987], 
             445 -> RGBColor[
              0.9631188181102052, 0.8872532547517151, 0.3112240020952856], 82 -> 
             RGBColor[
              0.5201221497039563, 0.62129761822232, 0.955365067376359], 67 -> 
             RGBColor[
              0.18087272641393248`, 0.30743908182722296`, 0.9336118062408292],
              430 -> RGBColor[
              0.20155620116286646`, 0.329178725196395, 0.9347896995293221], 
             211 -> RGBColor[
              0.1874830946539544, 0.31438699796903974`, 
               0.933988256932935]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw1l3k4VA/cxYfs69jHPjOGGTNjV1rUPZUi6hcVbZKtXVmyRook2RJlqUih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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 42}], {
             RGBColor[
             0.19991385155278849`, 0.32745251162522343`, 0.9346961701486667]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 108}], {
             RGBColor[
             0.20444558985732308`, 0.3322156559120931, 0.9349542459410038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[
             0.1979971628023344, 0.3254379502234105, 0.9345870175598152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 119}], {
             RGBColor[
             0.1917982653600388, 0.3189225159787594, 0.9342339995209235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 120}], {
             RGBColor[
             0.18959062955787265`, 0.3166021507784885, 0.9341082779278946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 124}], {
             RGBColor[
             0.1923231620506201, 0.3194742156809328, 0.934263891610937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 315}], {
             RGBColor[
             0.19134373832478055`, 0.31844477924602455`, 0.934208114878678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 363}], {
             RGBColor[
             0.19094550353876433`, 0.3180262092363777, 0.93418543599675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 364}], {
             RGBColor[
             0.2018347227926697, 0.32947146908860947`, 0.9348055609241036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 378}], {
             RGBColor[
             0.20312084702488786`, 0.3308232672016569, 0.9348788037964781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 380}], {
             RGBColor[
             0.19337326869879815`, 0.3205779443487749, 0.9343236936310573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 381}], {
             RGBColor[
             0.1937883174344935, 0.32101418688560046`, 0.9343473300425454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 416}], {
             RGBColor[
             0.20425325698717794`, 0.33201350187096224`, 0.9349432928685801]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 452}], {
             RGBColor[
             0.21304293634488086`, 0.3412520121737673, 0.935443852104836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 468}], {
             RGBColor[
             0.21038952484231582`, 0.33846310844856536`, 0.9352927442451355]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 487}], {
             RGBColor[
             0.19600881958127922`, 0.3233480754298399, 0.9344737843548664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[
             0.19103840083759993`, 0.31812385018748285`, 0.9341907263604894]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 114}], {
             RGBColor[
             0.1828144030828347, 0.30947990711565043`, 0.93372238185467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 118}], {
             RGBColor[
             0.18820276986646162`, 0.31514342224742875`, 0.9340292413716232]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 195}], {
             RGBColor[
             0.18614467853761885`, 0.312980237770288, 0.933912036115119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 255}], {
             RGBColor[
             0.19068245309328063`, 0.3177497265398128, 0.9341704556630279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 260}], {
             RGBColor[
             0.1969726482624509, 0.32436112048401927`, 0.9345286729724024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 312}], {
             RGBColor[
             0.18958168594798847`, 0.3165927504774426, 0.9341077686025426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 327}], {
             RGBColor[
             0.18398683108609262`, 0.3107122032833034, 0.9337891498950037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 334}], {
             RGBColor[
             0.18552483193608832`, 0.31232873969153496`, 0.9338767367681426]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 385}], {
             RGBColor[
             0.1828749868990639, 0.3095435845477431, 0.9337258320133786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 446}], {
             RGBColor[
             0.18380079735160318`, 0.310516670033135, 0.9337785555490368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 496}], {
             RGBColor[
             0.18500487281902223`, 0.3117822296921864, 0.9338471258656362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[
             0.1847525458331286, 0.3115170180315573, 0.933832756217074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 139}], {
             RGBColor[
             0.18312900664284068`, 0.3098105754042345, 0.933740298061998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 158}], {
             RGBColor[
             0.187682952058607, 0.31459706077302096`, 0.9339996385164674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 247}], {
             RGBColor[
             0.18396896047476097`, 0.31069342013773166`, 0.9337881321901256]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 278}], {
             RGBColor[
             0.1840613533248448, 0.3107905308812148, 0.9337933938262548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 401}], {
             RGBColor[
             0.18219297080333685`, 0.308826742388816, 0.9336869922056792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 428}], {
             RGBColor[
             0.18571633162823864`, 0.3125300180097667, 0.9338876423923121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 437}], {
             RGBColor[
             0.18278910615931465`, 0.30945331844511326`, 0.9337209412322989]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 451}], {
             RGBColor[
             0.19437267435842231`, 0.32162838306301855`, 0.9343806083048847]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 31}], {
             RGBColor[
             0.18674651901237604`, 0.3136128102681478, 0.9339463100398131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 151}], {
             RGBColor[
             0.19261261169346405`, 0.31977844560772906`, 0.9342803753398946]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 162}], {
             RGBColor[
             0.18241905104503708`, 0.3090643670571582, 0.9336998671409883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 191}], {
             RGBColor[
             0.18605432886244289`, 0.31288527453317777`, 0.933906890834778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.18424586592068898`, 0.3109844653182212, 0.9338039015456263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 345}], {
             RGBColor[
             0.18617654721563465`, 0.31301373377147346`, 0.9339138509891864]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 366}], {
             RGBColor[
             0.18203443666830332`, 0.30866011296125107`, 0.9336779639212193]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 389}], {
             RGBColor[
             0.18821672881431478`, 0.31515809398667083`, 0.934030036313053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 405}], {
             RGBColor[
             0.18158563263707392`, 0.3081883914686098, 0.9336524051955868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 429}], {
             RGBColor[
             0.18673058009120463`, 0.3135960574514107, 0.9339454023418319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 472}], {
             RGBColor[
             0.18232394464799978`, 0.30896440420377813`, 0.9336944509723744]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 488}], {
             RGBColor[
             0.1820203772126724, 0.30864533558196194`, 0.9336771632560201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 69}], {
             RGBColor[
             0.5662162318507189, 0.6577114998480007, 0.959566779515417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[
             0.8424015657306109, 0.8748578438487853, 0.849230453036272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 97}], {
             RGBColor[
             0.8390165308787574, 0.8650728443865321, 0.6896757172524062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 103}], {
             RGBColor[
             0.5496901810493061, 0.6433974652672816, 0.958513754171764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 129}], {
             RGBColor[
             0.4894760344411281, 0.5894520908087815, 0.9547425358777173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 163}], {
             RGBColor[
             0.7944424008489477, 0.6965434437689743, 0.6036935441317027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 204}], {
             RGBColor[
             0.502739716654951, 0.6027313328078459, 0.9555221120972213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 209}], {
             RGBColor[
             0.8420261863364131, 0.8747026148224741, 0.8554514610488602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 231}], {
             RGBColor[
             0.7266171062027156, 0.7863580729508864, 0.9733860605895166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 233}], {
             RGBColor[
             0.8260668342903568, 0.864508719874695, 0.9589794534592146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 259}], {
             RGBColor[
             0.686424746410886, 0.7549594960082611, 0.969380061784424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 275}], {
             RGBColor[
             0.5894443177306294, 0.6768531688525092, 0.9613168922152756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 326}], {
             RGBColor[
             0.7074791480476834, 0.7714073545863063, 0.9714785677750102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 346}], {
             RGBColor[
             0.5654957918264961, 0.6570874909093873, 0.9595208737141337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 348}], {
             RGBColor[
             0.575828354505173, 0.6657991165139304, 0.9602449937132509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 355}], {
             RGBColor[
             0.624643054436057, 0.7054290889949936, 0.9640878657059478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 395}], {
             RGBColor[
             0.5968586468606165, 0.6828724552519535, 0.9619005753639707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 404}], {
             RGBColor[
             0.763201606478355, 0.8150742978846761, 0.9769963355615894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 431}], {
             RGBColor[
             0.5554141285415004, 0.6483552608910543, 0.9588784790444786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 444}], {
             RGBColor[
             0.627720184984083, 0.7079272421970324, 0.964330108694589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 486}], {
             RGBColor[
             0.5514554325451628, 0.6449264373888728, 0.9586262344361294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 35}], {
             RGBColor[
             0.2010217865796709, 0.32861702158561484`, 0.9347592654094047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 101}], {
             RGBColor[
             0.22975280750904292`, 0.3588151462343254, 0.9363954545475959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 123}], {
             RGBColor[
             0.20012045196386746`, 0.3276696617564901, 0.9347079357364398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 158}], {
             RGBColor[
             0.20305085818934585`, 0.33074970449795377`, 0.9348748180358333]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 181}], {
             RGBColor[
             0.2199559451719783, 0.348518022761122, 0.9358375377306591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 189}], {
             RGBColor[
             0.23318323402672853`, 0.3624207420060165, 0.9365908122629168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 302}], {
             RGBColor[
             0.22957764048616652`, 0.3586310345870516, 0.9363854790447795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 306}], {
             RGBColor[
             0.22758223790331983`, 0.3565337399566487, 0.93627184381962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 347}], {
             RGBColor[
             0.20873556607912272`, 0.336724692921407, 0.9351985537403844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 370}], {
             RGBColor[
             0.22157715427768293`, 0.35022201632181177`, 0.935929863190865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 390}], {
             RGBColor[
             0.23515410879898574`, 0.36449225635233673`, 0.9367030506655489]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 422}], {
             RGBColor[
             0.21046728026605566`, 0.33854483432889454`, 0.9352971723014887]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 428}], {
             RGBColor[
             0.2010842377589775, 0.3286826617346995, 0.9347628219116779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 451}], {
             RGBColor[
             0.20974058048916117`, 0.3377810267879514, 0.9352557878242505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 17}], {
             RGBColor[
             0.4238987520286698, 0.5410646532335288, 0.9483742450361144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.7309397602442707, 0.7862269209257184, 0.8874289178221101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.7313065318033417, 0.7863785903909934, 0.8813505639139341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.373934744333056, 0.4947159504930181, 0.9453030779152829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 89}], {
             RGBColor[
             0.39101776123385745`, 0.5125847916537125, 0.9462790973781875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 176}], {
             RGBColor[
             0.39464375574399807`, 0.5157254458506131, 0.9465101425420326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 178}], {
             RGBColor[
             0.47083170751539166`, 0.5812814167445273, 0.9514847432104361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 244}], {
             RGBColor[
             0.45953784870192455`, 0.5719334474988196, 0.9506451367617185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 261}], {
             RGBColor[
             0.40082339399554057`, 0.5210779379064496, 0.9469039036269813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 262}], {
             RGBColor[
             0.407760697816997, 0.5270866817975668, 0.9473459424920676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 288}], {
             RGBColor[
             0.5917887149964642, 0.6784248496808247, 0.9617281729213873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 295}], {
             RGBColor[
             0.7285749695983985, 0.7852490192213029, 0.9266196187062239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 313}], {
             RGBColor[
             0.4167872287841039, 0.534905009234637, 0.9479211050634437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 321}], {
             RGBColor[
             0.7288945912633815, 0.7853811909936754, 0.9213226605631021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 341}], {
             RGBColor[
             0.7333256796265153, 0.7863640981896829, 0.7861411597228827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 376}], {
             RGBColor[
             0.421731467240934, 0.5391874600812927, 0.9482361475658946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 391}], {
             RGBColor[
             0.47273438056684836`, 0.582826092442144, 0.9516345286027679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 407}], {
             RGBColor[
             0.3747418079101595, 0.4955642254833401, 0.9453490389920554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 448}], {
             RGBColor[
             0.38646904067525956`, 0.507890290668963, 0.9460168875491417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 455}], {
             RGBColor[
             0.5426993192435918, 0.6396267815444932, 0.9571424248654161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 475}], {
             RGBColor[
             0.40444131336028016`, 0.5242115978182725, 0.9471344342497021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 478}], {
             RGBColor[
             0.36083387288200847`, 0.48094610395474147`, 0.9445570026671483]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 482}], {
             RGBColor[
             0.4023630118874444, 0.5224114775409715, 0.9470020067176228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 63}], {
             RGBColor[
             0.20214886588846875`, 0.32980165340011697`, 0.9348234509086764]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 85}], {
             RGBColor[
             0.19237812780276942`, 0.31953198817147166`, 0.9342670218292075]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 146}], {
             RGBColor[
             0.18877984751216192`, 0.31574996744189576`, 0.934062105089836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 159}], {
             RGBColor[
             0.21480140592500557`, 0.34310027519588937`, 0.9355439943460016]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 166}], {
             RGBColor[
             0.19658418244763454`, 0.3239528182824921, 0.9345065504189323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 239}], {
             RGBColor[
             0.19706547094004007`, 0.32445868300346314`, 0.9345339590865722]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 344}], {
             RGBColor[
             0.19388121074334685`, 0.3211118236429813, 0.9343526201790614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 387}], {
             RGBColor[
             0.19318868595476607`, 0.32038393618157524`, 0.9343131819168503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 435}], {
             RGBColor[
             0.21794255850182165`, 0.34640182571469935`, 0.9357228783383325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 439}], {
             RGBColor[
             0.1983584490277003, 0.3258176849531398, 0.9346075922758748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 453}], {
             RGBColor[
             0.21870849923514318`, 0.34720687798886773`, 0.9357664975299873]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 68}], {
             RGBColor[
             0.18960972675890758`, 0.3166222231476087, 0.9341093654852418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 95}], {
             RGBColor[
             0.18923630977445122`, 0.3162297382209408, 0.934088099940398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 286}], {
             RGBColor[
             0.19059390233229334`, 0.3176566540755726, 0.9341654128281889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 319}], {
             RGBColor[
             0.18732739999033735`, 0.3142233530059664, 0.9339793903521716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 330}], {
             RGBColor[
             0.19168631998098046`, 0.3188048542876222, 0.9342276243971945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 333}], {
             RGBColor[
             0.21279008452790313`, 0.3409862488823926, 0.9354294525679199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 352}], {
             RGBColor[
             0.18859199395283752`, 0.3155525214404422, 0.9340514071075369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 357}], {
             RGBColor[
             0.19116813878282407`, 0.31826021299377427`, 0.9341981147445398]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 358}], {
             RGBColor[
             0.2093374978833109, 0.33735736141228945`, 0.9352328328661546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 367}], {
             RGBColor[
             0.19547077493947268`, 0.3227825563973006, 0.9344431435084812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 368}], {
             RGBColor[
             0.18651190777224702`, 0.3133662189795604, 0.933932949276764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 375}], {
             RGBColor[
             0.19826733232951002`, 0.32572191552620944`, 0.934602403314708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 441}], {
             RGBColor[
             0.2076297588947049, 0.33556241945835885`, 0.9351355796571268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 450}], {
             RGBColor[
             0.20465923888359105`, 0.3324402145848314, 0.9349664129369846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 492}], {
             RGBColor[
             0.18820033017206594`, 0.3151408579739333, 0.9340291024346365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 102}], {
             RGBColor[
             0.21311463700569694`, 0.34132737411436953`, 0.9354479353513978]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 168}], {
             RGBColor[
             0.25974966627430485`, 0.39034374670731053`, 0.9381037312779018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 181}], {
             RGBColor[
             0.22615215264020183`, 0.355030629672469, 0.9361904025795069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.23937944149495205`, 0.3689333489173635, 0.9369436771117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 232}], {
             RGBColor[
             0.2526232272726644, 0.38285340747425656`, 0.9376978911193801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 280}], {
             RGBColor[
             0.24013030719270134`, 0.36972255637333296`, 0.9369864378024453]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 302}], {
             RGBColor[
             0.23577384795439005`, 0.3651436414983986, 0.9367383438936274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 370}], {
             RGBColor[
             0.22777336174590646`, 0.35673462323315885`, 0.9362827280397129]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 383}], {
             RGBColor[
             0.24728065527257528`, 0.3772380255635335, 0.9373936395476021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 390}], {
             RGBColor[
             0.24135031626720926`, 0.37100486326368376`, 0.9370559155143968]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 443}], {
             RGBColor[
             0.2573117613989959, 0.387781354111264, 0.9379648962018101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 451}], {
             RGBColor[
             0.2159367879573847, 0.34429363369929844`, 0.9356086526730982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 480}], {
             RGBColor[
             0.2350739989368308, 0.3644080558079533, 0.9366984885274112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 25}], {
             RGBColor[
             0.3322342574825351, 0.46035097441527295`, 0.9424578530175007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 164}], {
             RGBColor[
             0.3457994968745498, 0.4739358766298315, 0.9432550160557256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 180}], {
             RGBColor[
             0.31935935180321817`, 0.4468186322301426, 0.9417246461857798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 205}], {
             RGBColor[
             0.3065274858845748, 0.4333315275623586, 0.9409938904047574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 259}], {
             RGBColor[
             0.5294234413742529, 0.6261111308515327, 0.9571090734444168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 316}], {
             RGBColor[
             0.4071433573553281, 0.5270688453462049, 0.9471637926013148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 331}], {
             RGBColor[
             0.3385041946670758, 0.46694107593320344`, 0.9428149166646195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 348}], {
             RGBColor[
             0.41882704946853977`, 0.5369507513572022, 0.9479740053732437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 372}], {
             RGBColor[
             0.49492242636970674`, 0.598728406383233, 0.9539645121894538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 404}], {
             RGBColor[
             0.6062003014417219, 0.6862259327279479, 0.9647253472215822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 418}], {
             RGBColor[
             0.4260394736081712, 0.5428061221897597, 0.9485417938214956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 431}], {
             RGBColor[
             0.3984128235048672, 0.519506895734326, 0.9466074907044714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 444}], {
             RGBColor[
             0.4707188799474499, 0.5790788770403041, 0.9520591203545818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 40}], {
             RGBColor[
             0.18952205245126588`, 0.31653007189140514`, 0.9341043725631242]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 161}], {
             RGBColor[
             0.20394297282787943`, 0.33168737354638755`, 0.9349256226447324]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 188}], {
             RGBColor[
             0.20900601855676193`, 0.3370089556230833, 0.9352139556088873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 202}], {
             RGBColor[
             0.1903977819160206, 0.31745051908331734`, 0.9341542440606163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 243}], {
             RGBColor[
             0.19530733769648173`, 0.3226107734923974, 0.9344338359992765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 273}], {
             RGBColor[
             0.1905970563658978, 0.31765996916486816`, 0.9341655924457366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 279}], {
             RGBColor[
             0.2010090657422573, 0.3286036511789455, 0.9347585409765328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 283}], {
             RGBColor[
             0.18817638831560224`, 0.31511569356478863`, 0.9340277389813298]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 285}], {
             RGBColor[
             0.20421155270957553`, 0.33196966803099826`, 0.9349409178716667]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 318}], {
             RGBColor[
             0.19600810188078815`, 0.32334732108111897`, 0.9344737434828851]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 335}], {
             RGBColor[
             0.20220521707563277`, 0.32986088207069797`, 0.9348266600254211]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 396}], {
             RGBColor[
             0.19573690002635402`, 0.32306227073691796`, 0.9344582989384823]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 421}], {
             RGBColor[
             0.18918604161445732`, 0.31617690319760183`, 0.9340852372430514]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 430}], {
             RGBColor[
             0.19779577870573095`, 0.32522628276939103`, 0.9345755490334348]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 459}], {
             RGBColor[
             0.19425766410485237`, 0.3215074999944453, 0.9343740586410862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 477}], {
             RGBColor[
             0.19591456128829632`, 0.32324900398759393`, 0.9344684164845236]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 21}], {
             RGBColor[
             0.27647406119866225`, 0.4079221461606935, 0.9390561608273189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 59}], {
             RGBColor[
             0.2579706137078198, 0.3884738496614871, 0.938002416866113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 77}], {
             RGBColor[
             0.293706622672794, 0.4236564919439787, 0.9401246061243856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 87}], {
             RGBColor[
             0.28067879095443904`, 0.41234158372927926`, 0.9392956139665702]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 161}], {
             RGBColor[
             0.23339794827523738`, 0.36264642029486893`, 0.9366030399217282]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 188}], {
             RGBColor[
             0.23846099400411988`, 0.36796800237156463`, 0.9368913728858832]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 228}], {
             RGBColor[
             0.2555809934244899, 0.38596220723303065`, 0.9378663315261038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 243}], {
             RGBColor[
             0.2247623131438397, 0.3535698202408788, 0.9361112532762724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 256}], {
             RGBColor[
             0.2822514185299613, 0.41373456987075796`, 0.9393946906458437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 279}], {
             RGBColor[
             0.23046404118961528`, 0.35956269792742684`, 0.9364359582535287]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 285}], {
             RGBColor[
             0.2336665281569335, 0.36292871477947963`, 0.9366183351486626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 287}], {
             RGBColor[
             0.2785495730651827, 0.41010364072745936`, 0.9391743581576726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 298}], {
             RGBColor[
             0.26431690444041933`, 0.3951442035995219, 0.9383638287348387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 335}], {
             RGBColor[
             0.23166019252299075`, 0.36081992881917935`, 0.936504077302417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 354}], {
             RGBColor[
             0.28176652075351294`, 0.4133145757884693, 0.9393637933883066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 409}], {
             RGBColor[
             0.2530894600625647, 0.3833434476973081, 0.9377244423870355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 430}], {
             RGBColor[
             0.22725075415308893`, 0.3561853295178724, 0.9362529663104306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 477}], {
             RGBColor[
             0.2253695367356543, 0.3542080507360753, 0.9361458337615195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 80}], {
             RGBColor[
             0.28919811932082623`, 0.417720629815705, 0.9399116866604884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 159}], {
             RGBColor[
             0.2315482163827265, 0.3607022347960642, 0.9364977004268829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 166}], {
             RGBColor[
             0.21333099290535548`, 0.34155477788266697`, 0.9354602564998136]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 192}], {
             RGBColor[
             0.27198473276549623`, 0.40281125955144237`, 0.9388148648903828]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.21659885926136652`, 0.3449895126175285, 0.9356463566544133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 239}], {
             RGBColor[
             0.21381228139776098`, 0.3420606426036381, 0.9354876651674535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 251}], {
             RGBColor[
             0.23495511782487732`, 0.36428310422179233`, 0.9366917184239543]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 272}], {
             RGBColor[
             0.24410352476956199`, 0.37389865996315785`, 0.9372127066655989]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 435}], {
             RGBColor[
             0.23468936895954257`, 0.3640037853148743, 0.9366765844192138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 447}], {
             RGBColor[
             0.2323548964610662, 0.3615501067048703, 0.936543639663968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 453}], {
             RGBColor[
             0.23545530969286413`, 0.36480883758904264`, 0.9367202036108686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 454}], {
             RGBColor[
             0.2211862721127522, 0.34981117438310894`, 0.9359076030298306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 489}], {
             RGBColor[
             0.2113006394017466, 0.3394207476185267, 0.935344630871422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 50}], {
             RGBColor[
             0.7663849277124503, 0.8179130209698517, 0.9772202389257285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 82}], {
             RGBColor[
             0.5862643398841738, 0.6748409125363397, 0.9606772556368353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 126}], {
             RGBColor[
             0.5704313985291926, 0.6619870174784861, 0.9594308284953961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 149}], {
             RGBColor[
             0.6067680705890965, 0.6914867648051379, 0.9622913844255672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 173}], {
             RGBColor[
             0.6865018666299831, 0.7550197429095551, 0.9693877484071343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 242}], {
             RGBColor[
             0.8127597142986478, 0.8539262155582815, 0.9481932363943286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 249}], {
             RGBColor[
             0.6896781375343781, 0.7575010698806214, 0.9697043294069452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 269}], {
             RGBColor[
             0.6271401903527347, 0.708025769382796, 0.9638951523188943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 282}], {
             RGBColor[
             0.674559975761555, 0.7456906470014069, 0.9681974923286845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 323}], {
             RGBColor[
             0.82255832396822, 0.8598188337480478, 0.8682325932875272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 414}], {
             RGBColor[
             0.53753656294092, 0.634449250565901, 0.957071181763386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 419}], {
             RGBColor[
             0.6508464250830497, 0.7271654409816981, 0.9658339472127815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 449}], {
             RGBColor[
             0.8180065894164226, 0.8423738625918746, 0.678402399648858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 499}], {
             RGBColor[
             0.6404896932769727, 0.7188634972449458, 0.9649460740899308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 17}], {
             RGBColor[
             0.32278008566889027`, 0.45042607660179157`, 0.9419190112149659]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 116}], {
             RGBColor[
             0.2732978193858072, 0.4045837146300204, 0.9388752785549055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 143}], {
             RGBColor[
             0.42538425366010096`, 0.535839238383477, 0.9494121511680118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 165}], {
             RGBColor[
             0.28802163997316926`, 0.4200593836114821, 0.9397137783554151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 185}], {
             RGBColor[
             0.2408288180096403, 0.3704567355300795, 0.9370262169601158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.2456814749936662, 0.3755571856965141, 0.9373025685964933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 224}], {
             RGBColor[
             0.23802549514267946`, 0.3675102654559681, 0.9368665718699869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 277}], {
             RGBColor[
             0.35667163535651547`, 0.47978123350239554`, 0.9440785507919407]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 313}], {
             RGBColor[
             0.3156685624243244, 0.4442664326028998, 0.9414658712422952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 333}], {
             RGBColor[
             0.25095246372984137`, 0.3810973290582225, 0.9376027436072896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 358}], {
             RGBColor[
             0.24749987708524912`, 0.37746844158811943`, 0.9374061239055242]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 361}], {
             RGBColor[
             0.2501087241581385, 0.3802105052721842, 0.9375546938868818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 386}], {
             RGBColor[
             0.2878595743491687, 0.4198890423651035, 0.9397045489578829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 441}], {
             RGBColor[
             0.2457921380966431, 0.37567349963418883`, 0.9373088706964965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 89}], {
             RGBColor[
             0.3425624838836552, 0.4711321386741221, 0.9430487564503239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.6775706975021587, 0.7419956614956686, 0.932197104376443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 116}], {
             RGBColor[
             0.32596120839538445`, 0.45376963828216715`, 0.9421001714481905]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 143}], {
             RGBColor[
             0.4780476426696782, 0.5850251620356237, 0.9526370440612968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 165}], {
             RGBColor[
             0.3406850289827465, 0.4692453072636289, 0.9429386712487001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 176}], {
             RGBColor[
             0.3461884783937958, 0.47427279287102275`, 0.943279801614169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 178}], {
             RGBColor[
             0.4223764301651894, 0.5398287637649369, 0.9482544022825725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 261}], {
             RGBColor[
             0.3523681166453383, 0.4796252849268593, 0.9436735626991177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 277}], {
             RGBColor[
             0.4093350243660927, 0.5289671571545423, 0.9473034436852257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 288}], {
             RGBColor[
             0.543333437646262, 0.6369721967012344, 0.9584978319935238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 313}], {
             RGBColor[
             0.3683319514339016, 0.4934523562550466, 0.9446907641355802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 321}], {
             RGBColor[
             0.6804393139131792, 0.743928538014085, 0.9180923196352385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 328}], {
             RGBColor[
             0.30921498256740126`, 0.43616829316491434`, 0.9411464986611078]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 386}], {
             RGBColor[
             0.34052296335874593`, 0.4690749660172503, 0.9429294418511679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 391}], {
             RGBColor[
             0.4242791032166461, 0.5413734394625537, 0.9484041876749043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 407}], {
             RGBColor[
             0.3262865305599572, 0.4541115725037497, 0.9421186980641918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 455}], {
             RGBColor[
             0.49424404189338955`, 0.5981741285649027, 0.9539120839375526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 498}], {
             RGBColor[
             0.5750148993041335, 0.6617219953363903, 0.9616555440114883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 28}], {
             RGBColor[
             0.38207742266917044`, 0.5028572911387341, 0.9458047612186589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 93}], {
             RGBColor[
             0.25547187449726694`, 0.38584751632197967`, 0.9378601173646254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 160}], {
             RGBColor[
             0.26388110219154026`, 0.3946861478044915, 0.9383390104414766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 167}], {
             RGBColor[
             0.2640882538669924, 0.39490387734956656`, 0.9383508074229403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 172}], {
             RGBColor[
             0.2559027333199868, 0.38630037626268543`, 0.9378846541371808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 201}], {
             RGBColor[
             0.27288253451918126`, 0.4041472239046152, 0.93885162869611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 218}], {
             RGBColor[
             0.2870949982165383, 0.4190854243727823, 0.9396610074782187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 235}], {
             RGBColor[
             0.2527156376053866, 0.3829505365931011, 0.9377031537511198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 274}], {
             RGBColor[
             0.2661988733080245, 0.397122272203093, 0.9384710040777253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 300}], {
             RGBColor[
             0.26008832470075693`, 0.39069969818569605`, 0.938123017374288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 305}], {
             RGBColor[
             0.2994340109078254, 0.43188728681651606`, 0.9403698188221772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 310}], {
             RGBColor[
             0.46656300779364224`, 0.5714089084514553, 0.952481474208732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 406}], {
             RGBColor[
             0.35240776193494094`, 0.47777048741806016`, 0.9437452593947762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 432}], {
             RGBColor[
             0.2897732046951418, 0.4219003891898929, 0.9398135273751238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 460}], {
             RGBColor[
             0.2944934860338214, 0.4268617041599678, 0.940082340414331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 493}], {
             RGBColor[
             0.274609024515375, 0.4059618743564031, 0.9389499497472802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 26}], {
             RGBColor[
             0.1940564817835153, 0.32129604461902417`, 0.9343626016055087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 59}], {
             RGBColor[
             0.2331068284328231, 0.3623404348824274, 0.936586461077376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 67}], {
             RGBColor[
             0.1920452315036252, 0.3191820930542266, 0.9342480638774471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 124}], {
             RGBColor[
             0.1942932572468809, 0.3215449106434528, 0.9343760856178694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 188}], {
             RGBColor[
             0.21359720872912316`, 0.3418345875925049, 0.9354754170971461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 200}], {
             RGBColor[
             0.23309658772441674`, 0.3623296712485939, 0.936585877884182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 228}], {
             RGBColor[
             0.2307172081494932, 0.3598287924539709, 0.9364503757373667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 298}], {
             RGBColor[
             0.2394531191654226, 0.3690107888204622, 0.9369478729461016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 318}], {
             RGBColor[
             0.20059929205314941`, 0.3281729530505406, 0.9347352049711439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 335}], {
             RGBColor[
             0.20679640724799403`, 0.3346865140401196, 0.9350881215136799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 459}], {
             RGBColor[
             0.1988488542772136, 0.32633313196386693`, 0.934635520129345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 468}], {
             RGBColor[
             0.21235962003857659`, 0.3405338034110854, 0.9354049382520679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 25}], {
             RGBColor[
             0.26532620998703904`, 0.39620504772268694`, 0.9384213071925849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 46}], {
             RGBColor[
             0.22273395828831882`, 0.35143789068260056`, 0.9359957414679326]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 150}], {
             RGBColor[
             0.22855902835216374`, 0.35756040865047517`, 0.9363274705906497]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 220}], {
             RGBColor[
             0.2293954500117661, 0.35843954084691343`, 0.9363751035667891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 325}], {
             RGBColor[
             0.23769654620583044`, 0.3671645192667726, 0.9368478387146697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 388}], {
             RGBColor[
             0.2852227543233797, 0.4152738080593815, 0.9396218953833091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 392}], {
             RGBColor[
             0.2393040747004234, 0.36885413363778313`, 0.9369393850843115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 413}], {
             RGBColor[
             0.23603377197510877`, 0.36541683812430875`, 0.9367531461820842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 473}], {
             RGBColor[
             0.25267572333140287`, 0.38290858416043305`, 0.9377008806922643]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 474}], {
             RGBColor[
             0.2356355428107931, 0.36499827402342566`, 0.9367304676203037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 490}], {
             RGBColor[
             0.22886274008807128`, 0.3578796289413503, 0.9363447665247084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 55}], {
             RGBColor[
             0.4367980074447999, 0.5486800919411015, 0.9499852964304927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 59}], {
             RGBColor[
             0.2814993677631707, 0.4132040619828309, 0.9393423446018928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 77}], {
             RGBColor[
             0.3172353767281449, 0.44838670426532234`, 0.9414645338601655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[
             0.30420754500978997`, 0.43707179605062296`, 0.94063554170235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 91}], {
             RGBColor[
             0.3801635060105999, 0.5027016523216035, 0.9455268210185781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 188}], {
             RGBColor[
             0.26198974805947073`, 0.39269821469290833`, 0.9382313006216629]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 200}], {
             RGBColor[
             0.28148912705476437`, 0.4131932983489973, 0.9393417614086988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 228}], {
             RGBColor[
             0.2791097474798408, 0.4106924195543743, 0.9392062592618835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 256}], {
             RGBColor[
             0.3057801725853121, 0.43846478219210167`, 0.9407346183816234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 287}], {
             RGBColor[
             0.30207832712053356`, 0.43483385304880307`, 0.9405142858934524]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 298}], {
             RGBColor[
             0.2878456584957702, 0.4198744159208656, 0.9397037564706185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 335}], {
             RGBColor[
             0.2551889465783416, 0.385550141140523, 0.9378440050381969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 336}], {
             RGBColor[
             0.4626767064166898, 0.5696895855885848, 0.9520225624103578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 354}], {
             RGBColor[
             0.30529527480886387`, 0.43804478810981307`, 0.9407037211240865]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 409}], {
             RGBColor[
             0.27661821411791565`, 0.40807366001865175`, 0.9390643701228152]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 24}], {
             RGBColor[
             0.18354454614871424`, 0.31024733377163405`, 0.9337639624221219]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 52}], {
             RGBColor[
             0.18089659272171946`, 0.3074641668299184, 0.9336131653917505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 170}], {
             RGBColor[
             0.18476666722380106`, 0.3115318605085019, 0.9338335604093819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 214}], {
             RGBColor[
             0.1846717285967103, 0.31143207399197287`, 0.9338281537950183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 268}], {
             RGBColor[
             0.1840499075552901, 0.3107785006517091, 0.9337927420066112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 466}], {
             RGBColor[
             0.188342270881701, 0.3152900466593206, 0.9340371857480678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 491}], {
             RGBColor[
             0.1817125626643469, 0.3083218029751023, 0.9336596336728639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 39}], {
             RGBColor[
             0.3397705873831411, 0.4630597387061178, 0.9430778872171774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 51}], {
             RGBColor[
             0.7136013437576199, 0.7704045833430664, 0.8366928314862011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 62}], {
             RGBColor[
             0.34157168432943963`, 0.4649528057928196, 0.943180457023785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 96}], {
             RGBColor[
             0.4513622669101063, 0.5648950617926353, 0.9501123446420765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 110}], {
             RGBColor[
             0.42451306437954106`, 0.5421136125437187, 0.9482705749734688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 136}], {
             RGBColor[
             0.48008619598652036`, 0.5882144414151268, 0.9523735975581908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 157}], {
             RGBColor[
             0.36552292420320903`, 0.49012707749646917`, 0.944544444701912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 240}], {
             RGBColor[
             0.7133780917330446, 0.7699270698367418, 0.8123932263629633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 360}], {
             RGBColor[
             0.5140568870299039, 0.6157933787663372, 0.9550478947958676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 52}], {
             RGBColor[
             0.18264284256949226`, 0.3092995861385628, 0.9337126117372361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 64}], {
             RGBColor[
             0.18504835804129488`, 0.3118279354179173, 0.933849602284714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.18699882666459755`, 0.3138780016078617, 0.9339606785873513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 115}], {
             RGBColor[
             0.18813870785962614`, 0.3150760890164789, 0.9340255931351051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 170}], {
             RGBColor[
             0.18651291707157386`, 0.3133672798171463, 0.9339330067548675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 223}], {
             RGBColor[
             0.19673773915135, 0.32411421611415436`, 0.934515295246042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 268}], {
             RGBColor[
             0.18579615740306293`, 0.3126139199603535, 0.9338921883520968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 491}], {
             RGBColor[
             0.1834588125121197, 0.3101572222837467, 0.9337590800183494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 164}], {
             RGBColor[
             0.3024600979339018, 0.4345620939070181, 0.9405606698993174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.2760199528625702, 0.4074448495073293, 0.9390303000293716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 220}], {
             RGBColor[
             0.25296409856661417`, 0.38321168481668605`, 0.9377173032352967]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 316}], {
             RGBColor[
             0.36380395841468005`, 0.4876950626233916, 0.9444694464449066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 325}], {
             RGBColor[
             0.26126519476067855`, 0.3919366632365452, 0.9381900383831774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 392}], {
             RGBColor[
             0.26287272325527145`, 0.39362627760755575`, 0.9382815847528192]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 413}], {
             RGBColor[
             0.25960242052995686`, 0.39018898209408137`, 0.9380953458505918]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 474}], {
             RGBColor[
             0.2592041913656412, 0.3897704179931982, 0.9380726672888113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 490}], {
             RGBColor[
             0.25243138864291936`, 0.38265177291112284`, 0.937686966193216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 67}], {
             RGBColor[
             0.1828839766938226, 0.30955303339202045`, 0.9337263439688908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 124}], {
             RGBColor[
             0.18513200243707828`, 0.31191585098124663`, 0.9338543657093131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 318}], {
             RGBColor[
             0.1914380372433468, 0.3185438933883344, 0.9342134850625876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 335}], {
             RGBColor[
             0.1976351524381914, 0.3250574543779134, 0.9345664016051236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 459}], {
             RGBColor[
             0.18968759946741098`, 0.31670407230166076`, 0.9341138002207887]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 29}], {
             RGBColor[
             0.18482045324878804`, 0.31158839303099417`, 0.9338366234439357]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 65}], {
             RGBColor[
             0.1841954077512366, 0.31093143058289413`, 0.9338010280275222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 86}], {
             RGBColor[
             0.18526169591288671`, 0.3120521670473626, 0.9338617515608961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 177}], {
             RGBColor[
             0.18479696914654997`, 0.31156370975056386`, 0.9338352860590549]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[
             0.1856592913664621, 0.31247006507807806`, 0.9338843940337875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 290}], {
             RGBColor[
             0.18336907213961767`, 0.31006289946237875`, 0.9337539694368944]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 297}], {
             RGBColor[
             0.19023703211735066`, 0.31728156085278936`, 0.93414508959739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 350}], {
             RGBColor[
             0.18336792975933797`, 0.3100616987482737, 0.9337539043800275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 412}], {
             RGBColor[
             0.18773360296108882`, 0.31465029808298206`, 0.9340025230104325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 484}], {
             RGBColor[
             0.1850117059565009, 0.3117894117529224, 0.933847515002707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 490}], {
             RGBColor[
             0.20058973370860944`, 0.328162906624395, 0.9347346606375627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 125}], {
             RGBColor[
             0.6268956164581168, 0.7059040511517584, 0.965190775014533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 149}], {
             RGBColor[
             0.5184855433089055, 0.6199689474225398, 0.9552362277258538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 201}], {
             RGBColor[
             0.3666465873540202, 0.4866385048510442, 0.9449259979753362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 218}], {
             RGBColor[
             0.38085905105137724`, 0.5015767053192113, 0.9457353767574448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 282}], {
             RGBColor[
             0.586277448481364, 0.6741728296188088, 0.961142335628971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 305}], {
             RGBColor[
             0.3931980637426643, 0.5143785677629451, 0.9464441881014032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 310}], {
             RGBColor[
             0.5603270606284811, 0.6539001893978842, 0.958555843487958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 406}], {
             RGBColor[
             0.44617181476977985`, 0.5602617683644892, 0.9498196286740023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 408}], {
             RGBColor[
             0.7065627960875993, 0.7690478747515729, 0.9714624707191005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 419}], {
             RGBColor[
             0.5625638978028586, 0.6556476235991, 0.9587787905130681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 432}], {
             RGBColor[
             0.38353725752998075`, 0.5043916701363219, 0.9458878966543498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 493}], {
             RGBColor[
             0.36837307735021396`, 0.48845315530283206`, 0.9450243190265064]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 46}], {
             RGBColor[
             0.19406985648437775`, 0.32131010227763557`, 0.9343633632749366]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 65}], {
             RGBColor[
             0.1838043123267574, 0.3105203644948844, 0.9337787557216719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 86}], {
             RGBColor[
             0.18487060048840748`, 0.3116411009593528, 0.9338394792550458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 177}], {
             RGBColor[
             0.18440587372207073`, 0.31115264366255413`, 0.9338130137532046]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 194}], {
             RGBColor[
             0.18526819594198288`, 0.31205899899006834`, 0.9338621217279373]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 254}], {
             RGBColor[
             0.18842942576301586`, 0.31538165196552115`, 0.9340421490896246]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 290}], {
             RGBColor[
             0.18297797671513846`, 0.309651833374369, 0.9337316971310441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 297}], {
             RGBColor[
             0.18984593669287142`, 0.3168704947647796, 0.9341228172915397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 350}], {
             RGBColor[
             0.18297683433485876`, 0.309650632660264, 0.9337316320741772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 377}], {
             RGBColor[
             0.18261049498864607`, 0.3092655867801383, 0.9337107695903608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 412}], {
             RGBColor[
             0.18734250753660958`, 0.3142392319949723, 0.9339802507045822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 426}], {
             RGBColor[
             0.18589315152803693`, 0.3127158669354839, 0.933897712024024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 476}], {
             RGBColor[
             0.18392969470854525`, 0.3106521493278456, 0.933785896062828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 31}], {
             RGBColor[
             0.185457486240386, 0.3122579550953881, 0.9338729015304014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 133}], {
             RGBColor[
             0.18845727560531045`, 0.31541092391555475`, 0.934043735096943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 191}], {
             RGBColor[
             0.18476529609045284`, 0.31153041936041803`, 0.9338334823253662]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 311}], {
             RGBColor[
             0.18445928711484194`, 0.31120878452496137`, 0.9338160555669048]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 366}], {
             RGBColor[
             0.1807454038963133, 0.3073052577884914, 0.9336045554118075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 405}], {
             RGBColor[
             0.1802965998650839, 0.3068335362958501, 0.9335789966861752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 423}], {
             RGBColor[
             0.17906694420854233`, 0.3055410902361533, 0.9335089696156476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 429}], {
             RGBColor[
             0.18544154731921458`, 0.312241202278651, 0.9338719938324201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 465}], {
             RGBColor[
             0.17899164586466354`, 0.3054619469025459, 0.9335046814863577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 469}], {
             RGBColor[
             0.18014325773351766`, 0.30667236399312137`, 0.9335702640786318]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 488}], {
             RGBColor[
             0.18073134444068237`, 0.30729048040920226`, 0.9336037547466085]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 133}], {
             RGBColor[
             0.1949807850604232, 0.3222675459672669, 0.9344152393097445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 191}], {
             RGBColor[
             0.1912888055455656, 0.31838704141213026`, 0.9342049865381675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 226}], {
             RGBColor[
             0.1894803426038117, 0.3164862321971737, 0.9341019972490159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 237}], {
             RGBColor[
             0.21243558089193113`, 0.3406136430841573, 0.9354092641102925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 311}], {
             RGBColor[
             0.1909827965699547, 0.3180654065766735, 0.9341875597797062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 366}], {
             RGBColor[
             0.18726891335142604`, 0.3141618798402035, 0.9339760596246088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 405}], {
             RGBColor[
             0.18682010932019663`, 0.3136901583475623, 0.9339505008989764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 429}], {
             RGBColor[
             0.19196505677432735`, 0.31909782433036316`, 0.9342434980452214]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 472}], {
             RGBColor[
             0.1875584213311225, 0.31446617108273056`, 0.9339925466757639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 488}], {
             RGBColor[
             0.1872548538957951, 0.31414710246091443`, 0.9339752589594097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 66}], {
             RGBColor[
             0.20877736241614875`, 0.33676862352166215`, 0.9352009339799459]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 84}], {
             RGBColor[
             0.2475939365043437, 0.3775673040012994, 0.9374114804502933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 89}], {
             RGBColor[
             0.26467695340514513`, 0.3954361451619938, 0.9383874999131978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 176}], {
             RGBColor[
             0.26830294791528575`, 0.39857679935889445`, 0.938618545077043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 179}], {
             RGBColor[
             0.20989223640499494`, 0.3379404267710331, 0.9352644244043025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 245}], {
             RGBColor[
             0.23179881460343715`, 0.36096562941487603`, 0.9365119716248255]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 255}], {
             RGBColor[
             0.20842141467182945`, 0.3363944998739921, 0.9351806632824844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 260}], {
             RGBColor[
             0.21471160984099968`, 0.34300589381819857`, 0.9355388805918587]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 299}], {
             RGBColor[
             0.22987290893586354`, 0.3589413804487841, 0.9364022941461793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 312}], {
             RGBColor[
             0.20732064752653726`, 0.335237523811622, 0.935117976221999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 328}], {
             RGBColor[
             0.23132945208889125`, 0.36047229965278604`, 0.9364852421239818]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 334}], {
             RGBColor[
             0.2032637935146371, 0.3309735130257143, 0.934886944387599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 407}], {
             RGBColor[
             0.24840100008144717`, 0.3784155789916214, 0.9374574415270658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 448}], {
             RGBColor[
             0.26012823284654724`, 0.3907416441772443, 0.938125290084152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 475}], {
             RGBColor[
             0.27810050553156784`, 0.4070629513265539, 0.9392428367847124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 478}], {
             RGBColor[
             0.23449306505329615`, 0.3637974574630227, 0.9366654052021586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 482}], {
             RGBColor[
             0.27602220405873207`, 0.40526283104925287`, 0.9391104092526332]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 76}], {
             RGBColor[
             0.3333497551271607, 0.45830089859572654`, 0.9426393717347399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 111}], {
             RGBColor[
             0.3114314409456971, 0.4393163564982453, 0.9412427561367012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 160}], {
             RGBColor[
             0.24786010554572385`, 0.3778470645398819, 0.937426638383438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 175}], {
             RGBColor[
             0.326974395016177, 0.4527788821025087, 0.9422331394259775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 182}], {
             RGBColor[
             0.300634259036329, 0.42996438021049266`, 0.9405547692530093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 237}], {
             RGBColor[
             0.24458077131553108`, 0.3744002763421501, 0.9372398851503687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 241}], {
             RGBColor[
             0.2359506605232252, 0.3653294827188087, 0.9367484131078517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 274}], {
             RGBColor[
             0.25017787666220814`, 0.38028318893848334`, 0.9375586320196867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 351}], {
             RGBColor[
             0.24823088148452888`, 0.3782367735601183, 0.937447753524639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 371}], {
             RGBColor[
             0.2551767869971113, 0.385537360649688, 0.9378433125680343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 432}], {
             RGBColor[
             0.27375220804932543`, 0.40506130592528333`, 0.9389011553170851]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 460}], {
             RGBColor[
             0.27847248938800495`, 0.41002262089535824`, 0.9391699683562924]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 463}], {
             RGBColor[
             0.4057152506945697, 0.5182150283519088, 0.9480144771137997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 44}], {
             RGBColor[
             0.24396970740458573`, 0.37375800942805687`, 0.9372050859646285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 62}], {
             RGBColor[
             0.23006104796724536`, 0.35913912649947, 0.9364130083856896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 190}], {
             RGBColor[
             0.2127364473424475, 0.3409298727996848, 0.9354263980095573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 291}], {
             RGBColor[
             0.19600418397695138`, 0.323343203115777, 0.9344735203640577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 356}], {
             RGBColor[
             0.22712257342383618`, 0.3560506034443001, 0.9362456666075261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 394}], {
             RGBColor[
             0.19619166312976455`, 0.3235402555922485, 0.9344841970244598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 467}], {
             RGBColor[
             0.20003782336254744`, 0.32758281385754684`, 0.9347032301598326]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.18328807136271902`, 0.3099777625101124, 0.9337493565624799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 123}], {
             RGBColor[
             0.18674780810963457`, 0.3136141651911, 0.933946383451995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 193}], {
             RGBColor[
             0.1842865051954063, 0.311027179772628, 0.9338062158922009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 347}], {
             RGBColor[
             0.19536292222488982`, 0.32266919635601693`, 0.9344370014559396]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 410}], {
             RGBColor[
             0.18494866329979062`, 0.31172314992358463`, 0.9338439248166706]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 422}], {
             RGBColor[
             0.19709463641182273`, 0.32448933776350447`, 0.9345356200170438]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 428}], {
             RGBColor[
             0.18771159390474457`, 0.31462716516930944`, 0.9340012696272331]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 437}], {
             RGBColor[
             0.18478436843582058`, 0.31155046560465605`, 0.9338345684672199]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 75}], {
             RGBColor[
             0.929724921483118, 0.7365825483050892, 0.4781251750142107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 76}], {
             RGBColor[
             0.7022798190159381, 0.7608775969992009, 0.8471463932234504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 104}], {
             RGBColor[
             0.9591316136436914, 0.8643779170894872, 0.5023662490620132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 112}], {
             RGBColor[
             0.993786491132969, 0.9916985686506579, 0.7526374521795876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 266}], {
             RGBColor[
             0.9938574384892986, 0.9902625241719002, 0.644943793687154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 359}], {
             RGBColor[
             0.9518288028476951, 0.9612683407754878, 0.8690761481825573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 379}], {
             RGBColor[
             0.9107780137599082, 0.6018218600251894, 0.4604073756146171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 408}], {
             RGBColor[
             0.9657078104957213, 0.9722942089440085, 0.8689827508705463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 440}], {
             RGBColor[
             0.9428820049759663, 0.7963257915311912, 0.48910376799027133`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 463}], {
             RGBColor[
             0.7746453145833472, 0.820791726755383, 0.8525214986025103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 49}], {
             RGBColor[
             0.9278898442559633, 0.7275054583426774, 0.39329233295696453`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 53}], {
             RGBColor[
             0.8472647112443593, 0.3588769520067575, 0.19268158199931773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 97}], {
             RGBColor[
             0.9251557778239836, 0.7191603787632175, 0.30804891163954246`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 100}], {
             RGBColor[
             0.9275408237580072, 0.7267589387889348, 0.3553036056592853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 203}], {
             RGBColor[
             0.8534629031399862, 0.4065189709815528, 0.1986169775584265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 207}], {
             RGBColor[
             0.8684208855066446, 0.4954117968161807, 0.21191950037856397`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 257}], {
             RGBColor[
             0.9124536887252621, 0.6763132496408797, 0.2587036940792628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 264}], {
             RGBColor[
             0.8636993298194549, 0.4739723151879993, 0.20797971857725228`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 281}], {
             RGBColor[
             0.8401393429256434, 0.30410824875280007`, 0.18585832125036283`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 317}], {
             RGBColor[
             0.839586880193451, 0.2998617781024568, 0.18532928231409804`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 322}], {
             RGBColor[
             0.8413185031158885, 0.3131717906863145, 0.18698748638021256`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 324}], {
             RGBColor[
             0.9007937640631225, 0.7100849667901136, 0.5966707240103046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 343}], {
             RGBColor[
             0.8540426861772787, 0.4109754374687308, 0.1991721784497092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 374}], {
             RGBColor[
             0.8546495293295531, 0.4156398998574755, 0.19975329213765833`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 397}], {
             RGBColor[
             0.8419322626018511, 0.3178894150465442, 0.18757522315711248`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 445}], {
             RGBColor[
             0.9124867892485535, 0.6764249054783144, 0.25883228336174086`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 77}], {
             RGBColor[
             0.4266438929830485, 0.5421807004439456, 0.9488977622771873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 79}], {
             RGBColor[
             0.7025334025034438, 0.7661868171424233, 0.9721373827063131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 87}], {
             RGBColor[
             0.4136160612646935, 0.5308657922292461, 0.9480687701193717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 127}], {
             RGBColor[
             0.6754853554676021, 0.7446194386357212, 0.969557515833958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 184}], {
             RGBColor[
             0.5298276783437619, 0.6291770036011967, 0.9561291221434074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 221}], {
             RGBColor[
             0.7405475305032172, 0.7523239641423858, 0.6316046509416242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 253}], {
             RGBColor[
             0.4481561698945121, 0.5608135534661793, 0.9502685055394262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 287}], {
             RGBColor[
             0.4114868433754372, 0.5286278492274263, 0.9479475143104742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 301}], {
             RGBColor[
             0.5876340036038425, 0.6758909546392042, 0.9608274105699129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 316}], {
             RGBColor[
             0.4787664530256467, 0.5873266421968035, 0.9522189657129314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 336}], {
             RGBColor[
             0.5720852226715933, 0.663483581767208, 0.9594557908273795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 354}], {
             RGBColor[
             0.4147037910637674, 0.5318387842884362, 0.9481369495411083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 388}], {
             RGBColor[
             0.42375389748919434`, 0.5396775316025662, 0.9487136143198416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 436}], {
             RGBColor[
             0.4371703671484145, 0.5512982032900106, 0.9495684999028087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 473}], {
             RGBColor[
             0.39120686649721753`, 0.5073123077036177, 0.9467925996287968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 62}], {
             RGBColor[
             0.2493920758689453, 0.37945726248211625`, 0.9375138818269986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 96}], {
             RGBColor[
             0.359182658449612, 0.4793995184819319, 0.94444576944529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 108}], {
             RGBColor[
             0.22860230621824829`, 0.3576058964317052, 0.9363299352010993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 113}], {
             RGBColor[
             0.2221538791632596, 0.3508281907430225, 0.9359627068199107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 157}], {
             RGBColor[
             0.2733433157427147, 0.4046315341857658, 0.9388778695051255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 190}], {
             RGBColor[
             0.23206747524414745`, 0.361248008782331, 0.9365272714508661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 378}], {
             RGBColor[
             0.22727756338581306`, 0.356213507721269, 0.9362544930565735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 161}], {
             RGBColor[
             0.19942966903054987`, 0.32694360509540565`, 0.9346685966703091]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 183}], {
             RGBColor[
             0.19098677743240255`, 0.31806959071550744`, 0.9341877864839334]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 202}], {
             RGBColor[
             0.18588447811869105`, 0.31270675063233544`, 0.933897218086193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 206}], {
             RGBColor[
             0.18271148860033518`, 0.3093717374693884, 0.9337165210271399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 243}], {
             RGBColor[
             0.19079403389915217`, 0.3178670050414155, 0.9341768100248533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 273}], {
             RGBColor[
             0.18608375256856824`, 0.31291620071388626`, 0.9339085664713134]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 283}], {
             RGBColor[
             0.18366308451827268`, 0.3103719251138067, 0.9337707130069065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 285}], {
             RGBColor[
             0.19969824891224597`, 0.32722589958001636`, 0.9346838918972433]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 396}], {
             RGBColor[
             0.19122359622902446`, 0.31831850228593606`, 0.934201272964059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 421}], {
             RGBColor[
             0.18467273781712776`, 0.31143313474661993`, 0.933828211268628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 430}], {
             RGBColor[
             0.1932824749084014, 0.32048251431840913`, 0.9343185230590114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 477}], {
             RGBColor[
             0.19140125749096676`, 0.31850523553661203`, 0.9342113905101004]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 44}], {
             RGBColor[
             0.27104906144274005`, 0.40222012745236824`, 0.938747215116787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 56}], {
             RGBColor[
             0.33496751620801646`, 0.46033233124806494`, 0.9427193789900982]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.26751337219857585`, 0.3985038938811058, 0.9385458628449154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 132}], {
             RGBColor[
             0.2677010857798615, 0.3987011927567655, 0.9385565528556723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 250}], {
             RGBColor[
             0.2413646105317827, 0.37101988744205927`, 0.9370567295516178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 356}], {
             RGBColor[
             0.25420192746199044`, 0.3845127214686115, 0.9377877957596846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 365}], {
             RGBColor[
             0.23506566561189032`, 0.36439929695507756`, 0.9366980139568839]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 457}], {
             RGBColor[
             0.36616941470913866`, 0.48692522378917524`, 0.9448270715857057]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 485}], {
             RGBColor[
             0.2592162515913262, 0.38978309405505573`, 0.9380733541008225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 494}], {
             RGBColor[
             0.3091950820990577, 0.43800954418308746`, 0.9410771822783439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 108}], {
             RGBColor[
             0.2050818952093152, 0.3328844531811263, 0.9349904825894705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 113}], {
             RGBColor[
             0.1986334681543265, 0.3261067474924436, 0.9346232542082819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 119}], {
             RGBColor[
             0.1924345707120309, 0.31959131324779266`, 0.9342702361693901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 315}], {
             RGBColor[
             0.19198004367677265`, 0.3191135765150577, 0.9342443515271446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 364}], {
             RGBColor[
             0.2024710281446618, 0.33014026635764265`, 0.9348417975725702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 378}], {
             RGBColor[
             0.20375715237687997`, 0.3314920644706901, 0.9349150404449447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 380}], {
             RGBColor[
             0.19400957405079025`, 0.3212467416178081, 0.9343599302795238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 381}], {
             RGBColor[
             0.19442462278648562`, 0.3216829841546337, 0.9343835666910121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 416}], {
             RGBColor[
             0.20488956233917005`, 0.3326822991399955, 0.9349795295170467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 452}], {
             RGBColor[
             0.21367924169687297`, 0.3419208094428005, 0.9354800887533026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 468}], {
             RGBColor[
             0.21102583019430793`, 0.33913190571759855`, 0.9353289808936021]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 487}], {
             RGBColor[
             0.19664512493327133`, 0.3240168726988731, 0.934510021003333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 90}], {
             RGBColor[
             0.24535980769453214`, 0.3752190929702395, 0.9372842501196719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 137}], {
             RGBColor[
             0.220012218727478, 0.34857716983590165`, 0.9358407424263956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 148}], {
             RGBColor[
             0.2515020287225457, 0.38167495670998786`, 0.9376340405206155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 156}], {
             RGBColor[
             0.21388174499134507`, 0.34213365324474115`, 0.935491621016346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 227}], {
             RGBColor[
             0.21076377490674741`, 0.3388564689951076, 0.9353140572326515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 229}], {
             RGBColor[
             0.231604699752685, 0.3607616023991431, 0.9365009170712423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 250}], {
             RGBColor[
             0.22400512105631526`, 0.3527739633481394, 0.9360681323070532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 263}], {
             RGBColor[
             0.2263534256582619, 0.35524218037589655`, 0.9362018647801287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 267}], {
             RGBColor[
             0.22881279968486046`, 0.35782713841117125`, 0.9363419224926257]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 393}], {
             RGBColor[
             0.2248422553763207, 0.3536538445958466, 0.9361158058681482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 485}], {
             RGBColor[
             0.24185676211585877`, 0.3715371699611359, 0.9370847568562579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 56}], {
             RGBColor[
             0.342928946455201, 0.46870029922168843`, 0.9431727706647948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 62}], {
             RGBColor[
             0.2651018322525842, 0.3959692124974049, 0.9384085292125448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 92}], {
             RGBColor[
             0.2754748024457604, 0.40687186185472934`, 0.938999254519612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 110}], {
             RGBColor[
             0.34804321230268565`, 0.4731300192483041, 0.9434986471622288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 132}], {
             RGBColor[
             0.27566251602704606`, 0.4070691607303891, 0.9390099445303688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 157}], {
             RGBColor[
             0.2890530721263536, 0.4211434842010545, 0.9397725168906719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 356}], {
             RGBColor[
             0.262163357709175, 0.39288068944223503`, 0.9382411874343812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 360}], {
             RGBColor[
             0.4375870349530485, 0.5468097854709225, 0.9502759669846275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 365}], {
             RGBColor[
             0.24302709585907487`, 0.37276726492870105`, 0.9371514056315804]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 457}], {
             RGBColor[
             0.3741308449563232, 0.49529319176279873`, 0.9452804632604023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 494}], {
             RGBColor[
             0.31715651234624226`, 0.44637751215671095`, 0.9415305739530406]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 118}], {
             RGBColor[
             0.1966941864369604, 0.3240684394499293, 0.9345128149833881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 152}], {
             RGBColor[
             0.1927063751242849, 0.3198769969184667, 0.9342857150285693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 185}], {
             RGBColor[
             0.2063591315326575, 0.33422690953841927`, 0.935063219308583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 187}], {
             RGBColor[
             0.21121178851668337`, 0.3393273597048538, 0.9353395709449606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 195}], {
             RGBColor[
             0.19463609510811763`, 0.32190525497278855`, 0.9343956097268837]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 216}], {
             RGBColor[
             0.20054621348510776`, 0.32811716411015324`, 0.9347321822252167]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 217}], {
             RGBColor[
             0.19120987418842403`, 0.31830407955123735`, 0.9342004915141469]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 224}], {
             RGBColor[
             0.20355580866569664`, 0.3312804394643078, 0.9349035742184542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 292}], {
             RGBColor[
             0.193148625604734, 0.3203418302137187, 0.93431090053918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 328}], {
             RGBColor[
             0.22208190708084125`, 0.3507525435211073, 0.9359586081162901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 398}], {
             RGBColor[
             0.20371823459922628`, 0.33145115941884645`, 0.934912824135081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 399}], {
             RGBColor[
             0.20452814783915604`, 0.33230242958547795`, 0.9349589474959358]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 464}], {
             RGBColor[
             0.2018156680778671, 0.3294514413752133, 0.9348044757862846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 481}], {
             RGBColor[
             0.20322304481879772`, 0.33093068356277056`, 0.9348846238096533]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 496}], {
             RGBColor[
             0.19349628938952101`, 0.32070724689468694`, 0.9343306994774011]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 86}], {
             RGBColor[
             0.19451109914847642`, 0.321773876294004, 0.9343884913918972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 142}], {
             RGBColor[
             0.2097115161750654, 0.33775047835105276`, 0.9352541326545596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 150}], {
             RGBColor[
             0.2095354252082916, 0.3375653955801614, 0.935244104534505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 194}], {
             RGBColor[
             0.19490869460205182`, 0.32219177432471957`, 0.9344111338647885]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 220}], {
             RGBColor[
             0.21037184686789395`, 0.33844452777659967`, 0.9352917375106444]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 254}], {
             RGBColor[
             0.1980699244230848, 0.3255144273001723, 0.9345911612264759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 297}], {
             RGBColor[
             0.19948643535294036`, 0.32700327009943075`, 0.934671829428391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 325}], {
             RGBColor[
             0.2186729430619583, 0.3471695061964588, 0.935764472658525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 350}], {
             RGBColor[
             0.1926173329949277, 0.3197834079949152, 0.9342806442110285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 377}], {
             RGBColor[
             0.192250993648715, 0.31939836211478956`, 0.9342597817272121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 392}], {
             RGBColor[
             0.22028047155655125`, 0.34885912056746937`, 0.9358560190281668]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 412}], {
             RGBColor[
             0.19698300619667852`, 0.32437200732962346`, 0.9345292628414335]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 426}], {
             RGBColor[
             0.19553365018810587`, 0.3228486422701351, 0.9344467241608754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 476}], {
             RGBColor[
             0.1935701933686142, 0.32078492466249675`, 0.9343349081996792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 55}], {
             RGBColor[
             0.42760134170853215`, 0.539013813149998, 0.94946155992206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 59}], {
             RGBColor[
             0.272302702026903, 0.4035377831917274, 0.9388186080934602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 73}], {
             RGBColor[
             0.42925393472115597`, 0.5403554626061129, 0.9495916580976614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 91}], {
             RGBColor[
             0.37096684027433213`, 0.4930353735304999, 0.9450030845101454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 136}], {
             RGBColor[
             0.40491583995544145`, 0.5205967008566313, 0.9476756741243257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 200}], {
             RGBColor[
             0.2722924613184966, 0.40352701955789383`, 0.9388180249002662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 228}], {
             RGBColor[
             0.2699130817435731, 0.4010261407632708, 0.9386825227534509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 256}], {
             RGBColor[
             0.2965835068490444, 0.4287985034009982, 0.9402108818731908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 298}], {
             RGBColor[
             0.2786489927595025, 0.4102081371297621, 0.9391800199621858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 416}], {
             RGBColor[
             0.24541922577751857`, 0.3752815451427822, 0.9372876338915967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 452}], {
             RGBColor[
             0.2542089051352215, 0.3845200554455873, 0.9377881931278527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 468}], {
             RGBColor[
             0.25155549363265645`, 0.38173115172038535`, 0.9376370852681521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 117}], {
             RGBColor[
             0.18672352451245816`, 0.31358864159079863`, 0.9339450005370601]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 140}], {
             RGBColor[
             0.1844487281323768, 0.3111976863649123, 0.9338154542484741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 155}], {
             RGBColor[
             0.1919029748142661, 0.3190325722541152, 0.934239962569438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 156}], {
             RGBColor[
             0.19463895940372045`, 0.3219082655290739, 0.9343957728442809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 198}], {
             RGBColor[
             0.18614733394130184`, 0.3129830287679211, 0.9339121873364302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 250}], {
             RGBColor[
             0.20476233546869063`, 0.33254857563247214`, 0.9349722841349881]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 365}], {
             RGBColor[
             0.19846339054879825`, 0.32592798514549043`, 0.9346135685402542]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 479}], {
             RGBColor[
             0.18610061058204452`, 0.31293391955490957`, 0.9339095265102416]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 51}], {
             RGBColor[
             0.9945887098983145, 0.9908341225748765, 0.6523926509220856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 100}], {
             RGBColor[
             0.9935759076270685, 0.9886678409266986, 0.5421553739880537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 203}], {
             RGBColor[
             0.9194979870090474, 0.6684278731193166, 0.38546874588719493`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 264}], {
             RGBColor[
             0.9297344136885161, 0.7358812173257631, 0.3948314869060207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 324}], {
             RGBColor[
             0.9668288479321837, 0.9719938689278773, 0.783522492339073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 360}], {
             RGBColor[
             0.7950442531705986, 0.8362229179981473, 0.7707477142317521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 397}], {
             RGBColor[
             0.9079673464709124, 0.579798317184308, 0.3744269914858809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 457}], {
             RGBColor[
             0.7315880631738731, 0.7847063242900234, 0.765752210507527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 82}], {
             RGBColor[
             0.7002427375322327, 0.764369726655832, 0.9719080506652522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 126}], {
             RGBColor[
             0.6844097961772514, 0.7515158315979785, 0.9706616235238129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 131}], {
             RGBColor[
             0.8570462990670573, 0.5838526913273292, 0.5841917648474512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 173}], {
             RGBColor[
             0.800480264278042, 0.8445485570290475, 0.9806185434355512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 242}], {
             RGBColor[
             0.9267381119467066, 0.943455029677774, 0.9594240314227456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 323}], {
             RGBColor[
             0.9365367216162789, 0.9493476478675402, 0.8794633883159441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 340}], {
             RGBColor[
             0.6220781556562913, 0.698481383789535, 0.9664262896114366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 373}], {
             RGBColor[
             0.9356814566362912, 0.9489939738190079, 0.8936373423891573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 414}], {
             RGBColor[
             0.6515149605889788, 0.7239780646853934, 0.9683019767918029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 449}], {
             RGBColor[
             0.9319849870644814, 0.931902676711367, 0.6896331946772748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 499}], {
             RGBColor[
             0.7544680909250315, 0.8083923113644382, 0.9761768691183477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 60}], {
             RGBColor[
             0.9903726876472161, 0.9902614167392676, 0.8073625961746422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 96}], {
             RGBColor[
             0.7330134148240908, 0.7867443631188805, 0.8380607137143137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 100}], {
             RGBColor[
             0.9942396894003585, 0.9900876030211339, 0.6144039236244064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 110}], {
             RGBColor[
             0.7061642122935256, 0.763962913869964, 0.8362189440457062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 203}], {
             RGBColor[
             0.9201617687823374, 0.6698476352137519, 0.4577172955235477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 240}], {
             RGBColor[
             0.995029239647029, 0.991776371162987, 0.7003415954352006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 264}], {
             RGBColor[
             0.930398195461806, 0.7373009794201983, 0.46708003654237346`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 324}], {
             RGBColor[
             0.9674926297054737, 0.9734136310223126, 0.8557710419754258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 360}], {
             RGBColor[
             0.7957080349438885, 0.8376426800925825, 0.8429962638681049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 397}], {
             RGBColor[
             0.9086311282442023, 0.5812180792787432, 0.4466755411222336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 457}], {
             RGBColor[
             0.7322518449471631, 0.7861260863844587, 0.8380007601438797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 495}], {
             RGBColor[
             0.9406722816777016, 0.7839532053527796, 0.47565298592181493`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 170}], {
             RGBColor[
             0.1838649636445791, 0.31058411287543064`, 0.9337822097244962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 214}], {
             RGBColor[
             0.18377002501748835`, 0.3104843263589016, 0.9337768031101326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 268}], {
             RGBColor[
             0.18314820397606815`, 0.30983075301863783`, 0.9337413913217254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 466}], {
             RGBColor[
             0.18744056730247904`, 0.3143422990262493, 0.933985835063182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 491}], {
             RGBColor[
             0.18081085908512495`, 0.30737405534203105`, 0.9336082829879782]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 83}], {
             RGBColor[
             0.9139507635332944, 0.6222257740273145, 0.45384466479453006`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 97}], {
             RGBColor[
             0.910565728681441, 0.6124407745650613, 0.29428992901066414`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 112}], {
             RGBColor[
             0.9130580700237505, 0.6218566223199413, 0.468638906464419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 163}], {
             RGBColor[
             0.8659915986516313, 0.4439113739475036, 0.20830775588996076`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 207}], {
             RGBColor[
             0.8538308363641018, 0.3886921926180247, 0.19816051774968563`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 257}], {
             RGBColor[
             0.8978636395827194, 0.5695936454427237, 0.2449447114503845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 266}], {
             RGBColor[
             0.9131290173800801, 0.6204205778411838, 0.36094524797198546`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 281}], {
             RGBColor[
             0.8255492937831006, 0.19738864455464403`, 0.17209933862148452`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[
             0.8212117750972121, 0.5517293002984074, 0.5802972295340347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 317}], {
             RGBColor[
             0.8249968310509084, 0.19314217390430075`, 0.1715702996852197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 322}], {
             RGBColor[
             0.8267284539733458, 0.20645218648815844`, 0.17322850375133425`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 343}], {
             RGBColor[
             0.8394526370347362, 0.3042558332705747, 0.18541319582083088`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 374}], {
             RGBColor[
             0.8400594801870103, 0.30892029565931944`, 0.18599430950878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 440}], {
             RGBColor[
             0.8621535838667478, 0.42648384520047466`, 0.20510522227510283`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 445}], {
             RGBColor[
             0.897896740106011, 0.5697053012801583, 0.24507330073286251`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 471}], {
             RGBColor[
             0.8947556642863255, 0.6097433924263989, 0.5684355218108367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 61}], {
             RGBColor[
             0.9898922626687403, 0.9900882051035927, 0.8171748957720661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 99}], {
             RGBColor[
             0.9846117057177595, 0.9871579291878583, 0.8712517771624386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 154}], {
             RGBColor[
             0.9864962902894889, 0.9885634492757301, 0.8680616670608778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 186}], {
             RGBColor[
             0.9914243588005289, 0.9890319585828893, 0.6689529207083693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 203}], {
             RGBColor[
             0.9172982685013698, 0.6686889606982549, 0.5070233200844496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 244}], {
             RGBColor[
             0.7181235795673231, 0.775643062211419, 0.8864694686198505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 264}], {
             RGBColor[
             0.9275346951808384, 0.7361423049047013, 0.5163860611032753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 295}], {
             RGBColor[
             0.9871607004637972, 0.988958633933902, 0.862443950564356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 321}], {
             RGBColor[
             0.9874803221287802, 0.9890908057062746, 0.8571469924212342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 341}], {
             RGBColor[
             0.991911410491914, 0.9900737129022821, 0.7219654915810148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 374}], {
             RGBColor[
             0.9184848946909366, 0.6778098895741775, 0.5081596346636814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 391}], {
             RGBColor[
             0.731320111432247, 0.7865357071547434, 0.8874588604609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 397}], {
             RGBColor[
             0.9057676279632347, 0.5800594047632462, 0.4959815656831355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 455}], {
             RGBColor[
             0.8012850501089904, 0.8433363962570924, 0.8929667567235482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 57}], {
             RGBColor[
             0.7681170081630603, 0.818182994087395, 0.9538490180959958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 60}], {
             RGBColor[
             0.7795430416292072, 0.8264883871046946, 0.9248292480443663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 73}], {
             RGBColor[
             0.5752457926482104, 0.6660494748562806, 0.9597046024734881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 91}], {
             RGBColor[
             0.5169586982013866, 0.6187293857806677, 0.955116028885972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 136}], {
             RGBColor[
             0.5509076978824959, 0.6462907131067992, 0.9577886185001523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 200}], {
             RGBColor[
             0.4182843192455511, 0.5292210318080617, 0.9489309692760928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 256}], {
             RGBColor[
             0.4425753647760989, 0.554492515651166, 0.9503238262490175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 298}], {
             RGBColor[
             0.424640850686557, 0.5359021493799299, 0.9492929643380126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 434}], {
             RGBColor[
             0.7543365484938672, 0.7225141411414309, 0.6130982348590022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 92}], {
             RGBColor[
             0.33939325721103675`, 0.46498406565042605`, 0.9429714183929231]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 110}], {
             RGBColor[
             0.41196166706796206`, 0.5312422230440008, 0.9474708110355399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 132}], {
             RGBColor[
             0.3395809707923225, 0.46518136452608577`, 0.94298210840368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 324}], {
             RGBColor[
             0.6732900844799101, 0.7406929401963493, 0.9670229089652596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 342}], {
             RGBColor[
             0.4415801835206408, 0.5562719260910596, 0.9495305912404275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 360}], {
             RGBColor[
             0.501505489718325, 0.6049219892666192, 0.9542481308579387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 457}], {
             RGBColor[
             0.4380492997215996, 0.5534053955584954, 0.9492526271337134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 494}], {
             RGBColor[
             0.38107496711151867`, 0.5044897159524077, 0.9455027378263516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 60}], {
             RGBColor[
             0.9740668501566808, 0.9799635557919238, 0.9191037618424754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 73}], {
             RGBColor[
             0.769769601175684, 0.81952464354351, 0.9539791162715971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 91}], {
             RGBColor[
             0.7114825067288603, 0.7722045544678969, 0.9493905426840812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 131}], {
             RGBColor[
             0.8981850447320697, 0.6159608551699692, 0.564028013817431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 136}], {
             RGBColor[
             0.7454315064099696, 0.7997658817940283, 0.9520631322982614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 234}], {
             RGBColor[
             0.9445095586663342, 0.8587398441686642, 0.6038719941743098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 240}], {
             RGBColor[
             0.9787234021564939, 0.9814785102156434, 0.8120827611030339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 434}], {
             RGBColor[
             0.9488603570213409, 0.87598930982866, 0.6073727486571113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 495}], {
             RGBColor[
             0.9243664441871663, 0.7736553444054359, 0.5873941515896481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 74}], {
             RGBColor[
             0.19093718319717995`, 0.31801746402983233`, 0.9341849621656055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 115}], {
             RGBColor[
             0.19207706439220854`, 0.3192155514384495, 0.9342498767133594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 144}], {
             RGBColor[
             0.1950230989335921, 0.322312020530822, 0.9344176490222236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 145}], {
             RGBColor[
             0.20110599109187893`, 0.32870552586681995`, 0.9347640607318055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 215}], {
             RGBColor[
             0.1890650982052305, 0.3160497840062494, 0.9340783496948156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 375}], {
             RGBColor[
             0.19795511773261765`, 0.3253937581893268, 0.934584623155295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 402}], {
             RGBColor[
             0.20564836608822273`, 0.3334798499911863, 0.9350227422680057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 417}], {
             RGBColor[
             0.19514933346569613`, 0.3224447010277949, 0.9344248378920796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 87}], {
             RGBColor[
             0.28570409751894754`, 0.41762349955141664`, 0.939581797741144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 91}], {
             RGBColor[
             0.36166005851975747`, 0.48325335582239703`, 0.9444730770573722]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 188}], {
             RGBColor[
             0.24348630056862833`, 0.373249918193702, 0.937177556660457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 200}], {
             RGBColor[
             0.26298567956392194`, 0.393745001849791, 0.9382880174474929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 228}], {
             RGBColor[
             0.26060629998899837`, 0.391244123055168, 0.9381525153006776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 256}], {
             RGBColor[
             0.28727672509446966`, 0.4190164856928953, 0.9396808744204175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 279}], {
             RGBColor[
             0.23548934775412372`, 0.36484461374956423`, 0.9367221420281024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 287}], {
             RGBColor[
             0.28357487962969113`, 0.41538555654959675`, 0.9394605419322465]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 298}], {
             RGBColor[
             0.2693422110049278, 0.4004261194216593, 0.9386500125094126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 335}], {
             RGBColor[
             0.2366854990874992, 0.3661018446413167, 0.9367902610769909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 409}], {
             RGBColor[
             0.2581147666270732, 0.38862536351944543`, 0.9380106261616092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 468}], {
             RGBColor[
             0.24224871187808175`, 0.37194913401228247`, 0.9371070778153788]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 73}], {
             RGBColor[
             0.781195634641831, 0.8278300365608096, 0.9249593462199677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 131}], {
             RGBColor[
             0.9096110781982166, 0.6242662481872688, 0.5350082437658015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.7568575398761165, 0.8080712748113279, 0.923043362246632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 240}], {
             RGBColor[
             0.9901494356226408, 0.989783903232943, 0.7830629910514044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 434}], {
             RGBColor[
             0.9602863904874878, 0.8842947028459596, 0.5783529786054818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 495}], {
             RGBColor[
             0.9357924776533132, 0.7819607374227355, 0.5583743815380187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 99}], {
             RGBColor[
             0.9849784772768306, 0.9873095986531333, 0.8651734232542627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 154}], {
             RGBColor[
             0.9868630618485601, 0.9887151187410052, 0.8619833131527019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 178}], {
             RGBColor[
             0.7297842099398613, 0.7851427009224017, 0.8812307211603922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 186}], {
             RGBColor[
             0.9917911303595999, 0.9891836280481643, 0.6628745668001933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 203}], {
             RGBColor[
             0.9176650400604409, 0.6688406301635299, 0.5009449661762736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 244}], {
             RGBColor[
             0.7184903511263943, 0.775794731676694, 0.8803911147116745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 264}], {
             RGBColor[
             0.9279014667399095, 0.7362939743699763, 0.5103077071950994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 288}], {
             RGBColor[
             0.8507412174209339, 0.8822861338586991, 0.8914741508713435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 295}], {
             RGBColor[
             0.9875274720228682, 0.989110303399177, 0.8563655966561801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 321}], {
             RGBColor[
             0.9878470936878512, 0.9892424751715496, 0.8510686385130581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 341}], {
             RGBColor[
             0.992278182050985, 0.9902253823675571, 0.7158871376728388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 391}], {
             RGBColor[
             0.731686882991318, 0.7866873766200184, 0.8813805065527239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 397}], {
             RGBColor[
             0.9061343995223057, 0.5802110742285213, 0.48990321177495955`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 455}], {
             RGBColor[
             0.8016518216680615, 0.8434880657223675, 0.8868884028153723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 96}], {
             RGBColor[
             0.36098375539591054`, 0.48129258556863375`, 0.9445483392518976]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 108}], {
             RGBColor[
             0.2304034031645468, 0.35949896351840704`, 0.9364325050077069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 110}], {
             RGBColor[
             0.33413455286534527`, 0.45851113631971724`, 0.9427065695832899]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 157}], {
             RGBColor[
             0.27514441268901324`, 0.40652460127246764`, 0.9389804393117331]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 190}], {
             RGBColor[
             0.233868572190446, 0.3631410758690329, 0.9366298412574736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 356}], {
             RGBColor[
             0.24825469827183463`, 0.37826180651364816`, 0.9374491098554425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 378}], {
             RGBColor[
             0.22907866033211158`, 0.3581065748079708, 0.9363570628631811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 72}], {
             RGBColor[
             0.20896361604647165`, 0.3369643878962938, 0.9352115408486552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 159}], {
             RGBColor[
             0.2194636807819041, 0.34800062167578893`, 0.9358095040018843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 166}], {
             RGBColor[
             0.20124645730453306`, 0.3288531647623917, 0.9347720600748151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 222}], {
             RGBColor[
             0.20195670404025598`, 0.32959967911388044`, 0.9348125075756986]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 239}], {
             RGBColor[
             0.20172774579693858`, 0.3293590294833628, 0.934799468742455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 272}], {
             RGBColor[
             0.23201898916873956`, 0.36119704684288256`, 0.9365245102406003]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 344}], {
             RGBColor[
             0.19854348560024537`, 0.326012170122881, 0.9346181298349442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 387}], {
             RGBColor[
             0.1978509608116646, 0.3252842826614749, 0.9345786915727331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 435}], {
             RGBColor[
             0.22260483335872017`, 0.351302172194599, 0.9359883879942152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 439}], {
             RGBColor[
             0.20302072388459882`, 0.33071803143303935`, 0.9348731019317575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 453}], {
             RGBColor[
             0.2233707740920417, 0.35210722446876735`, 0.9360320071858701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 74}], {
             RGBColor[
             0.1867563887094054, 0.3136231839455006, 0.933946872104458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 115}], {
             RGBColor[
             0.18789626990443398`, 0.31482127135411775`, 0.9340117866522119]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 170}], {
             RGBColor[
             0.18627047911638173`, 0.31311246215478516`, 0.9339192002719742]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 215}], {
             RGBColor[
             0.18488430371745596`, 0.31165550392191765`, 0.9338402596336681]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 223}], {
             RGBColor[
             0.19649530119615788`, 0.32385939845179323`, 0.9345014887631486]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 268}], {
             RGBColor[
             0.18555371944787077`, 0.31235910229799235`, 0.9338783818692034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 86}], {
             RGBColor[
             0.18424555499085607`, 0.31098413851125284`, 0.9338038838386322]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 177}], {
             RGBColor[
             0.18378082822451933`, 0.3104956812144541, 0.9337774183367911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 194}], {
             RGBColor[
             0.18464315044443147`, 0.3114020365419683, 0.9338265263115236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 290}], {
             RGBColor[
             0.18235293121758706`, 0.308994870926269, 0.9336961017146306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 297}], {
             RGBColor[
             0.18922089119532, 0.3162135323166796, 0.9340872218751262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 350}], {
             RGBColor[
             0.18235178883730735`, 0.30899367021216395`, 0.9336960366577636]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 412}], {
             RGBColor[
             0.1867174620390582, 0.3135822695468723, 0.9339446552881686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 484}], {
             RGBColor[
             0.1839955650344703, 0.31072138321681264`, 0.9337896472804431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 114}], {
             RGBColor[
             0.1896583133560848, 0.31667329074181017`, 0.9341121324200736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 128}], {
             RGBColor[
             0.19606919376904863`, 0.32341153252913013`, 0.9344772225755442]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 179}], {
             RGBColor[
             0.19899718509969622`, 0.32648903706301347`, 0.9346439673502496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 245}], {
             RGBColor[
             0.22090376329813846`, 0.34951423970685647`, 0.9358915145707727]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 255}], {
             RGBColor[
             0.19752636336653073`, 0.32494311016597255`, 0.9345602062284316]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 260}], {
             RGBColor[
             0.203816558535701, 0.331554504110179, 0.9349184235378061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 294}], {
             RGBColor[
             0.19268716813915449`, 0.3198568091593014, 0.9342846212191803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 299}], {
             RGBColor[
             0.21897785763056482`, 0.34748999074076453`, 0.9357818370921265]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 312}], {
             RGBColor[
             0.19642559622123856`, 0.32378613410360235`, 0.9344975191679463]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 327}], {
             RGBColor[
             0.19083074135934272`, 0.31790558690946313`, 0.9341789004604073]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 334}], {
             RGBColor[
             0.19236874220933842`, 0.3195221233176947, 0.9342664873335462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 385}], {
             RGBColor[
             0.189718897172314, 0.31673696817390284`, 0.9341155825787821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 415}], {
             RGBColor[
             0.1891407128871262, 0.3161292598311696, 0.9340826558390877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 446}], {
             RGBColor[
             0.19064470762485328`, 0.3177100536592947, 0.9341683061144403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 119}], {
             RGBColor[
             0.18259585546660687`, 0.3092501997142758, 0.933709935891238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 120}], {
             RGBColor[
             0.18038821966444069`, 0.3069298345140049, 0.9335842142982091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 124}], {
             RGBColor[
             0.18312075215718818`, 0.30980189941644914`, 0.9337398279812515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 363}], {
             RGBColor[
             0.18174309364533237`, 0.30835389297189403`, 0.9336613723670645]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 381}], {
             RGBColor[
             0.18458590754106158`, 0.31134187062111685`, 0.93382326641286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 95}], {
             RGBColor[
             0.18505409827792216`, 0.3118339687705646, 0.933849929182698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 286}], {
             RGBColor[
             0.1864116908357643, 0.3132608846251963, 0.9339272420704889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 319}], {
             RGBColor[
             0.1831451884938083, 0.30982758355559015`, 0.9337412195944718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 330}], {
             RGBColor[
             0.18750410848445143`, 0.3144090848372459, 0.9339894536394946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 352}], {
             RGBColor[
             0.18440978245630846`, 0.311156751990066, 0.933813236349837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 357}], {
             RGBColor[
             0.18698592728629504`, 0.313864443543398, 0.93395994398684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 367}], {
             RGBColor[
             0.19128856344294365`, 0.31838678694692435`, 0.9342049727507814]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 368}], {
             RGBColor[
             0.18232969627571796`, 0.3089704495291842, 0.9336947785190641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 375}], {
             RGBColor[
             0.19408512083298096`, 0.3213261460758332, 0.9343642325570081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 450}], {
             RGBColor[
             0.20047702738706202`, 0.3280444451344552, 0.9347282421792846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 492}], {
             RGBColor[
             0.1840181186755369, 0.3107450885235571, 0.9337909316769367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 101}], {
             RGBColor[
             0.3439836908945852, 0.4664796432810521, 0.9433547372891266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 103}], {
             RGBColor[
             0.4263301464035756, 0.5436874776637394, 0.9483863578332576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 129}], {
             RGBColor[
             0.36611599979539755`, 0.48974210320523914`, 0.944615139539211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 204}], {
             RGBColor[
             0.37937968200922045`, 0.5030213452043036, 0.9453947157587149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 209}], {
             RGBColor[
             0.7186661516906826, 0.7749926272189318, 0.8453240647103539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 231}], {
             RGBColor[
             0.6032570715569849, 0.6866480853473442, 0.9632586642510103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 233}], {
             RGBColor[
             0.7027067996446262, 0.7647987322711527, 0.9488520571207084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 259}], {
             RGBColor[
             0.5630647117651555, 0.6552495084047187, 0.9592526654459177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 275}], {
             RGBColor[
             0.46608428308489896`, 0.5771431812489669, 0.9511894958767693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 306}], {
             RGBColor[
             0.3418131212888621, 0.4641982370033755, 0.9432311265611506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 331}], {
             RGBColor[
             0.37214546505797846`, 0.49607945348638943`, 0.9449585086661204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 346}], {
             RGBColor[
             0.4421357571807656, 0.5573775033058451, 0.9493934773756274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 348}], {
             RGBColor[
             0.4524683198594424, 0.5660891289103882, 0.9501175973747447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 355}], {
             RGBColor[
             0.5012830197903266, 0.6057191013914514, 0.9539604693674415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 372}], {
             RGBColor[
             0.5285636967606093, 0.627866783936419, 0.9561081041909547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 404}], {
             RGBColor[
             0.6398415718326245, 0.7153643102811339, 0.9668689392230831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 418}], {
             RGBColor[
             0.45968074399907377`, 0.5719444997429457, 0.9506853858229966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 431}], {
             RGBColor[
             0.4320540938957698, 0.548645273287512, 0.9487510827059723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 444}], {
             RGBColor[
             0.5043601503383525, 0.6082172545934901, 0.9542027123560828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 486}], {
             RGBColor[
             0.4280953978994323, 0.5452164497853305, 0.9484988380976231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 76}], {
             RGBColor[
             0.3900856381049142, 0.5122943062773944, 0.9460768898142273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 111}], {
             RGBColor[
             0.36816732392345053`, 0.4933097641799131, 0.9446802742161886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 130}], {
             RGBColor[
             0.33633111822806117`, 0.4651961056645053, 0.9426714251516843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 175}], {
             RGBColor[
             0.3837102779939304, 0.5067722897841764, 0.945670657505465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 182}], {
             RGBColor[
             0.35737014201408246`, 0.4839577878921605, 0.9439922873324968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 208}], {
             RGBColor[
             0.39817892177344283`, 0.519304301810809, 0.9465925866929762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[
             0.4282161029443493, 0.5444148958180487, 0.9487568881673315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 351}], {
             RGBColor[
             0.3049667644622824, 0.4322301812417861, 0.9408852716041266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 359}], {
             RGBColor[
             0.6396346219366711, 0.7126850500536813, 0.9680066447733342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 371}], {
             RGBColor[
             0.31191266997486483`, 0.4395307683313558, 0.9412808306475218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 403}], {
             RGBColor[
             0.5565760155932599, 0.6470753000386655, 0.9599201962609412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 442}], {
             RGBColor[
             0.3038237186466454, 0.4310287676162611, 0.9408201768359108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 463}], {
             RGBColor[
             0.4624511336723232, 0.5722084360335765, 0.9514519951932873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 483}], {
             RGBColor[
             0.41089196681220996`, 0.5303157024471664, 0.9474026506811422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 135}], {
             RGBColor[
             0.18886726703484777`, 0.31584185090295647`, 0.9340670835023274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 153}], {
             RGBColor[
             0.21268791512647112`, 0.34087886236357334`, 0.9354236341716544]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 169}], {
             RGBColor[
             0.1907755412237238, 0.3178475680670369, 0.9341757568943452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 172}], {
             RGBColor[
             0.21061538458324242`, 0.3387005013566139, 0.9353056066232517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 197}], {
             RGBColor[
             0.2143161876130597, 0.34259027998541636`, 0.9355163618809523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 201}], {
             RGBColor[
             0.22759518578243687`, 0.3565473489985437, 0.936272581182181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 211}], {
             RGBColor[
             0.19261088350739852`, 0.3197766291746009, 0.9342802769222549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 236}], {
             RGBColor[
             0.20304903767595361`, 0.3307477910229513, 0.9348747143602888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 289}], {
             RGBColor[
             0.20390581997350005`, 0.33164832354080787`, 0.9349235068446382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 308}], {
             RGBColor[
             0.19432153409427227`, 0.32157463140291687`, 0.9343776959424965]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 362}], {
             RGBColor[
             0.1884877837309814, 0.3154429898899618, 0.9340454724895675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 369}], {
             RGBColor[
             0.18988277528354555`, 0.3169092144592796, 0.9341249151947808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 466}], {
             RGBColor[
             0.1963124589116516, 0.3236672196179068, 0.934491076165537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 470}], {
             RGBColor[
             0.19617627269900267`, 0.32352407927370813`, 0.9344833205621961]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 493}], {
             RGBColor[
             0.2293216757786306, 0.35836199945033154`, 0.9363709022333513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 128}], {
             RGBColor[
             0.20268608388741163`, 0.33036630357859437`, 0.9348540446789733]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 159}], {
             RGBColor[
             0.22161615608300847`, 0.35026300969206614`, 0.9359320842859804]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 179}], {
             RGBColor[
             0.20561407521805922`, 0.3334438081124777, 0.9350207894536787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 222}], {
             RGBColor[
             0.20410917934136036`, 0.33186206713015765`, 0.9349350878597946]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 245}], {
             RGBColor[
             0.22752065341650146`, 0.35646901075632065`, 0.9362683366742017]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 294}], {
             RGBColor[
             0.19930405825751749`, 0.32681158020876566`, 0.9346614433226095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 344}], {
             RGBColor[
             0.20069596090134978`, 0.3282745581391582, 0.9347407101190403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 438}], {
             RGBColor[
             0.20687895912531873`, 0.33477328129727923`, 0.9350928227209692]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 439}], {
             RGBColor[
             0.2051731991857032, 0.33298041944931656`, 0.9349956822158536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 453}], {
             RGBColor[
             0.2255232493931461, 0.35436961248504456`, 0.9361545874699662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 91}], {
             RGBColor[
             0.5186112912140105, 0.6200710352367826, 0.9552461270615734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 136}], {
             RGBColor[
             0.5525602908951197, 0.647632362562914, 0.9579187166757537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 200}], {
             RGBColor[
             0.4199369122581749, 0.5305626812641765, 0.9490610674516942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 240}], {
             RGBColor[
             0.785852186641644, 0.829344990984529, 0.8179383454805261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 256}], {
             RGBColor[
             0.4442279577887227, 0.5558341651072809, 0.9504539244246188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 298}], {
             RGBColor[
             0.42629344369918076`, 0.5372437988360448, 0.949423062513614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 434}], {
             RGBColor[
             0.755989141506491, 0.7238557905975457, 0.6132283330346036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 115}], {
             RGBColor[
             0.18984673852773665`, 0.31687133754406216`, 0.9341228629548491]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 144}], {
             RGBColor[
             0.1927927730691202, 0.31996780663643465`, 0.9342906352637134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 215}], {
             RGBColor[
             0.1868347723407586, 0.3137055701118621, 0.9339513359363054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 268}], {
             RGBColor[
             0.18750418807117342`, 0.3144091684879368, 0.9339894581718406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 402}], {
             RGBColor[
             0.20341804022375085`, 0.331135636096799, 0.9348957285094954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 417}], {
             RGBColor[
             0.1929190076012242, 0.3201004871334076, 0.9342978241335694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 104}], {
             RGBColor[
             0.894725030806556, 0.6091192249245418, 0.23357173327544747`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 125}], {
             RGBColor[
             0.8216340480291034, 0.6538916931792487, 0.593916539379413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 147}], {
             RGBColor[
             0.842199332426149, 0.3144945905899744, 0.187617653595973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 303}], {
             RGBColor[
             0.853058182050049, 0.3979604671775163, 0.19801610025913619`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 310}], {
             RGBColor[
             0.7550654921994678, 0.6018878314253746, 0.587281607852838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 323}], {
             RGBColor[
             0.9290142282590157, 0.73628865839294, 0.4899032009526938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 379}], {
             RGBColor[
             0.8463714309227728, 0.346563167860244, 0.1916128598280513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 400}], {
             RGBColor[
             0.9275933480888754, 0.7357010879276322, 0.5134508624919265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 408}], {
             RGBColor[
             0.9013012276585859, 0.7170355167790632, 0.6001882350839804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 111}], {
             RGBColor[
             0.3885098195301592, 0.510929411430886, 0.9459764800480857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 130}], {
             RGBColor[
             0.3566736138347697, 0.4828157529154782, 0.9439676309835814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 175}], {
             RGBColor[
             0.404052773600639, 0.5243919370351493, 0.946966863337362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.3777126376207911, 0.5015774351431334, 0.9452884931643937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 351}], {
             RGBColor[
             0.32530926006899097`, 0.449849828492759, 0.9421814774360235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 359}], {
             RGBColor[
             0.6599771175433797, 0.7303046973046542, 0.9693028506052312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 371}], {
             RGBColor[
             0.3322551655815734, 0.4571504155823287, 0.9425770364794188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 460}], {
             RGBColor[
             0.35555086797246704`, 0.4816356758279989, 0.9439036922676769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 463}], {
             RGBColor[
             0.4827936292790318, 0.5898280832845495, 0.9527482010251842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 483}], {
             RGBColor[
             0.43123446241891855`, 0.5479353496981393, 0.948698856513039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 87}], {
             RGBColor[
             0.32144010648392174`, 0.4528061418339081, 0.9417039869994168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 184}], {
             RGBColor[
             0.4376517235629901, 0.5511173532058586, 0.9497643390234523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 253}], {
             RGBColor[
             0.35598021511374034`, 0.4827539030708413, 0.9439037224194711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 287}], {
             RGBColor[
             0.31931088859466533`, 0.4505681988320882, 0.9415827311905192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 301}], {
             RGBColor[
             0.49545804882307076`, 0.5978313042438662, 0.9544626274499579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 336}], {
             RGBColor[
             0.47990926789082156`, 0.58542393137187, 0.9530910077074245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 354}], {
             RGBColor[
             0.32252783628299564`, 0.4537791338930982, 0.9417721664211531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 388}], {
             RGBColor[
             0.33157794270842256`, 0.4616178812072281, 0.9423488311998864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 409}], {
             RGBColor[
             0.2938507755920474, 0.42380800580193695`, 0.940132815419882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 436}], {
             RGBColor[
             0.3449944123676427, 0.4732385528946725, 0.9432037167828538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 473}], {
             RGBColor[
             0.2990309117164457, 0.42925265730827966`, 0.9404278165088418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 154}], {
             RGBColor[
             0.7267639040768494, 0.783922928096006, 0.9321470662934741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 171}], {
             RGBColor[
             0.47037777522198154`, 0.5809128940593202, 0.9514490079974901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 192}], {
             RGBColor[
             0.39152498613418535`, 0.5130863931305935, 0.946294212255822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.4280975104696688, 0.5447636755214684, 0.9486245811666656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 219}], {
             RGBColor[
             0.5697935423105139, 0.6612069230140997, 0.9595599186442647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 258}], {
             RGBColor[
             0.44262074177976496`, 0.5573429685234437, 0.9495499886233556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 262}], {
             RGBColor[
             0.4066140424697561, 0.526155775330442, 0.9472556735827959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 376}], {
             RGBColor[
             0.4205848118936931, 0.5382565536141679, 0.9481458786566228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 497}], {
             RGBColor[
             0.47412146300073554`, 0.5839521884493253, 0.9517437248130138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 127}], {
             RGBColor[
             0.8591989102072256, 0.8905659049388609, 0.9864323531431288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 147}], {
             RGBColor[
             0.8526636417246913, 0.529899304242684, 0.5774584339898925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 184}], {
             RGBColor[
             0.7135412330833855, 0.7751234699043363, 0.9730039594525782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 221}], {
             RGBColor[
             0.9242610852428408, 0.8982704304455256, 0.6484794882507952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 234}], {
             RGBColor[
             0.9063126289426009, 0.8289774045041336, 0.6243163382349994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 253}], {
             RGBColor[
             0.6318697246341356, 0.7067600197693191, 0.967143342848597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 301}], {
             RGBColor[
             0.7713475583434661, 0.821837420942344, 0.9777022478790838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 316}], {
             RGBColor[
             0.6624800077652702, 0.7332731084999433, 0.9690938030221024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 336}], {
             RGBColor[
             0.7557987774112169, 0.8094300480703478, 0.9763306281365505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 388}], {
             RGBColor[
             0.6074674522288179, 0.6856239979057058, 0.9655884516290124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 436}], {
             RGBColor[
             0.620883921888038, 0.6972446695931502, 0.9664433372119796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 81}], {
             RGBColor[
             0.2928864737857844, 0.4215973242135559, 0.9401217329908362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 171}], {
             RGBColor[
             0.4090554292271066, 0.5282531641753069, 0.9474159938779831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 192}], {
             RGBColor[
             0.3302026401393104, 0.46042666324658016`, 0.9422611981363149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 208}], {
             RGBColor[
             0.38701536387166025`, 0.5096349890530197, 0.9458812546550213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 219}], {
             RGBColor[
             0.508471196315639, 0.6085471931300863, 0.9555269045247576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 238}], {
             RGBColor[
             0.4170525450425667, 0.5347455830602593, 0.9480455561293766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 251}], {
             RGBColor[
             0.2931730251986915, 0.4218985079169302, 0.9401380516698865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 258}], {
             RGBColor[
             0.38129839578489, 0.5046832386394303, 0.9455169745038486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 272}], {
             RGBColor[
             0.30232143214337615`, 0.4315140636582957, 0.9406590399115311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 293}], {
             RGBColor[
             0.578582457393624, 0.6633186431495282, 0.9625149398020252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 403}], {
             RGBColor[
             0.5454124576914773, 0.6374059872808763, 0.9592088642229862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 447}], {
             RGBColor[
             0.2905728038348803, 0.41916551040000816`, 0.9399899729099002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 471}], {
             RGBColor[
             0.6521263465827374, 0.7213327352775194, 0.9506532320788272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 483}], {
             RGBColor[
             0.3997284089104274, 0.520646389689377, 0.9466913186431871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 497}], {
             RGBColor[
             0.4127991170058606, 0.5312924585653119, 0.9477107106935068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 121}], {
             RGBColor[
             0.22174468237743916`, 0.35039809897655055`, 0.9359394036683106]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 130}], {
             RGBColor[
             0.27063800741742255`, 0.4017880836094291, 0.9387238061981451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 208}], {
             RGBColor[
             0.3324858109628042, 0.4558962797557328, 0.942644967739437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 213}], {
             RGBColor[
             0.2202872137263247, 0.3488662070153795, 0.9358564029847612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 251}], {
             RGBColor[
             0.23864347228983546`, 0.36815979861964326`, 0.9369017647543021]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 442}], {
             RGBColor[
             0.2381306078360068, 0.36762074556118485`, 0.9368725578823716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 447}], {
             RGBColor[
             0.23604325092602435`, 0.36542680110272124`, 0.936753685994316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 454}], {
             RGBColor[
             0.2248746265777104, 0.3536878687809598, 0.9361176493601785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 500}], {
             RGBColor[
             0.21967281078147302`, 0.34822043056494373`, 0.9358214136459797]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 126}], {
             RGBColor[
             0.504289208348975, 0.6084437231644664, 0.9541186402349197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 149}], {
             RGBColor[
             0.540625880408879, 0.6379434704911183, 0.9569791961650909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 173}], {
             RGBColor[
             0.6203596764497656, 0.7014764485955354, 0.964075560146658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 242}], {
             RGBColor[
             0.7466175241184303, 0.8003829212442619, 0.9428810481338523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 249}], {
             RGBColor[
             0.6235359473541606, 0.7039577755666018, 0.9643921411464688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 269}], {
             RGBColor[
             0.5609980001725171, 0.6544824750687763, 0.958582964058418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 282}], {
             RGBColor[
             0.6084177855813375, 0.6921473526873871, 0.962885304068208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 323}], {
             RGBColor[
             0.7564161337880024, 0.8062755394340282, 0.8629204050270508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 384}], {
             RGBColor[
             0.39409857332891574`, 0.5101959076651558, 0.9469714569601196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 411}], {
             RGBColor[
             0.4006657201660342, 0.5170983953721258, 0.9473454462572704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 419}], {
             RGBColor[
             0.5847042349028322, 0.6736221466676785, 0.9605217589523052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 499}], {
             RGBColor[
             0.5743475030967551, 0.6653202029309262, 0.9596338858294544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 97}], {
             RGBColor[
             0.9918418301129188, 0.9825092007837744, 0.5692119944347548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 163}], {
             RGBColor[
             0.9472677000831091, 0.8139798001662166, 0.4832298213140514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 207}], {
             RGBColor[
             0.9351069377955797, 0.7587606188367377, 0.47308258317377627`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 209}], {
             RGBColor[
             0.9948514855705746, 0.9921389712197164, 0.7349877382312089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 231}], {
             RGBColor[
             0.879442405436877, 0.9037944293481288, 0.8529223377718652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 233}], {
             RGBColor[
             0.9788921335245182, 0.9819450762719373, 0.8385157306415634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 257}], {
             RGBColor[
             0.9791397410141973, 0.9396620716614368, 0.5198667768744751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 317}], {
             RGBColor[
             0.9062729324823862, 0.5632106001230137, 0.44649236510931034`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 326}], {
             RGBColor[
             0.8603044472818449, 0.8888437109835485, 0.8510148449573589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 343}], {
             RGBColor[
             0.920728738466214, 0.6743242594892878, 0.4603352612449215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 346}], {
             RGBColor[
             0.7183210910606576, 0.7745238473066297, 0.8390571508964824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 355}], {
             RGBColor[
             0.7774683536702185, 0.8228654453922359, 0.8436241428882965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 395}], {
             RGBColor[
             0.749683946094778, 0.8003088116491959, 0.8414368525463194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 440}], {
             RGBColor[
             0.9434296852982257, 0.7965522714191877, 0.48002728769919345`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 89}], {
             RGBColor[
             0.2925984761880414, 0.42478343593361145`, 0.9399775893294924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 176}], {
             RGBColor[
             0.29622447069818203`, 0.4279240901305121, 0.9402086344933376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 244}], {
             RGBColor[
             0.3611185636561085, 0.4841320917787186, 0.9443436287130234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 245}], {
             RGBColor[
             0.25972033738633343`, 0.39031292018649366`, 0.9381020610411201]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 260}], {
             RGBColor[
             0.24263313262389596`, 0.37235318458981626`, 0.9371289700081534]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 261}], {
             RGBColor[
             0.30240410894972447`, 0.4332765821863486, 0.9406023955782863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 262}], {
             RGBColor[
             0.3093414127711809, 0.4392853260774658, 0.9410444344433726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 299}], {
             RGBColor[
             0.2577944317187598, 0.3882886712204018, 0.9379923835624739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 328}], {
             RGBColor[
             0.2592509748717875, 0.3898195904244037, 0.9380753315402763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 376}], {
             RGBColor[
             0.3233121821951179, 0.4513861043611917, 0.9419346395171995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 391}], {
             RGBColor[
             0.3743150955210323, 0.495024736722043, 0.9453330205540728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 407}], {
             RGBColor[
             0.27632252286434345`, 0.40776286976323906`, 0.9390475309433604]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 448}], {
             RGBColor[
             0.28804975562944346`, 0.4200889349488619, 0.9397153795004467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 455}], {
             RGBColor[
             0.4442800341977758, 0.5518254258243921, 0.9508409168167211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 475}], {
             RGBColor[
             0.3060220283144641, 0.4364102420981715, 0.9408329262010071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 478}], {
             RGBColor[
             0.2624145878361924, 0.3931447482346404, 0.9382554946184531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 482}], {
             RGBColor[
             0.30394372684162835`, 0.43461012182087044`, 0.9407004986689278]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 146}], {
             RGBColor[
             0.1836713842833611, 0.3103806486931501, 0.9337711856662498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 166}], {
             RGBColor[
             0.19147571921883372`, 0.31858349953374643`, 0.9342156309953462]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 239}], {
             RGBColor[
             0.19195700771123925`, 0.31908936425471746`, 0.9342430396629862]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 332}], {
             RGBColor[
             0.18694868384128802`, 0.31382529832132483`, 0.9339578230277437]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 387}], {
             RGBColor[
             0.18808022272596522`, 0.31501461743282955`, 0.9340222624932641]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 489}], {
             RGBColor[
             0.18944536571522486`, 0.31644946926960615`, 0.9341000053669545]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 177}], {
             RGBColor[
             0.1848471163861694, 0.31161641767892256`, 0.933838141870165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 194}], {
             RGBColor[
             0.18570943860608155`, 0.31252277300643677`, 0.9338872498448976]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 220}], {
             RGBColor[
             0.20117259087192368`, 0.32877552645831687`, 0.9347678534907535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 254}], {
             RGBColor[
             0.18887066842711453`, 0.3158454259818896, 0.934067277206585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 290}], {
             RGBColor[
             0.18341921937923714`, 0.31011560739073746`, 0.9337568252480046]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 297}], {
             RGBColor[
             0.1902871793569701, 0.317334268781148, 0.9341479454085002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 350}], {
             RGBColor[
             0.18341807699895743`, 0.3101144066766324, 0.9337567601911376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 377}], {
             RGBColor[
             0.18305173765274474`, 0.30972936079650676`, 0.9337358977073213]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 412}], {
             RGBColor[
             0.18778375020070825`, 0.3147030060113407, 0.9340053788215426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 426}], {
             RGBColor[
             0.1863343941921356, 0.31317964095185236`, 0.9339228401409845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 476}], {
             RGBColor[
             0.18437093737264393`, 0.311115923344214, 0.9338110241797885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 91}], {
             RGBColor[
             0.3843682357663767, 0.5071210898901892, 0.9457662741578293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 161}], {
             RGBColor[
             0.2611314320863651, 0.3917960701847984, 0.9381824207967593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 184}], {
             RGBColor[
             0.4246238918446351, 0.5398024449911591, 0.9489353468656369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 228}], {
             RGBColor[
             0.28331447723561765`, 0.41511185712296006`, 0.9394457124011348]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 253}], {
             RGBColor[
             0.34295238339538536`, 0.47143899485614194`, 0.9430747302616557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 256}], {
             RGBColor[
             0.30998490234108894`, 0.4428842197606874, 0.9409740715208748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 285}], {
             RGBColor[
             0.2614000119680612, 0.39207836466940904`, 0.9381977160236936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 287}], {
             RGBColor[
             0.3062830568763104, 0.4392532906173888, 0.9407537390327037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 336}], {
             RGBColor[
             0.4668814361724666, 0.5741090231571706, 0.9522620155496091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 354}], {
             RGBColor[
             0.30950000456464066`, 0.4424642256783988, 0.9409431742633377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 388}], {
             RGBColor[
             0.3185501109900676, 0.45030297299252864`, 0.941519839042071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 409}], {
             RGBColor[
             0.28082294387369244`, 0.4124930975872375, 0.9393038232620665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 436}], {
             RGBColor[
             0.33196658064928775`, 0.46192364467997304`, 0.9423747246250382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 473}], {
             RGBColor[
             0.28600307999809077`, 0.4179377490935802, 0.9395988243510263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 133}], {
             RGBColor[
             0.19376977710770305`, 0.3209946998266191, 0.9343462741983627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 241}], {
             RGBColor[
             0.2025944621469051, 0.33027000332016815`, 0.9348488269563937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 271}], {
             RGBColor[
             0.19882737388287028`, 0.32631055470747644`, 0.9346342968526646]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 304}], {
             RGBColor[
             0.19013400622997473`, 0.3171732741129387, 0.9341392224255172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 307}], {
             RGBColor[
             0.1906659921562372, 0.31773242505129645`, 0.9341695182370151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 311}], {
             RGBColor[
             0.18977178861723454`, 0.3167925604360257, 0.9341185946683245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 337}], {
             RGBColor[
             0.18932246677623382`, 0.3163202946924838, 0.9340930064541916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 423}], {
             RGBColor[
             0.18437944571093495`, 0.3111248661472177, 0.9338115087170672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 427}], {
             RGBColor[
             0.18803656473244668`, 0.3149687301135649, 0.9340197762351194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 433}], {
             RGBColor[
             0.18511620603054046`, 0.3118992479564254, 0.9338534661273294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 465}], {
             RGBColor[
             0.18430414736705614`, 0.3110457228136103, 0.9338072205877772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 469}], {
             RGBColor[
             0.1854557592359103, 0.3122561399041857, 0.9338728031800514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 176}], {
             RGBColor[
             0.31330748759898347`, 0.4457929312912065, 0.9411846539562421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 178}], {
             RGBColor[
             0.38949543937037706`, 0.5113489021851207, 0.9461592546246456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 244}], {
             RGBColor[
             0.37820158055690994`, 0.5020009329394131, 0.945319648175928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 261}], {
             RGBColor[
             0.31948712585052597`, 0.45114542334704305`, 0.9415784150411908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 262}], {
             RGBColor[
             0.3264244296719824, 0.4571541672381602, 0.9420204539062771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 299}], {
             RGBColor[
             0.27487744861956126`, 0.4061575123810962, 0.9389684030253784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 328}], {
             RGBColor[
             0.27633399177258894`, 0.4076884315850981, 0.9390513510031808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 376}], {
             RGBColor[
             0.3403951990959194, 0.4692549455218861, 0.9429106589801041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 391}], {
             RGBColor[
             0.39139811242183375`, 0.5128935778827375, 0.9463090400169774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 407}], {
             RGBColor[
             0.2934055397651449, 0.4256317109239335, 0.9400235504062648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 448}], {
             RGBColor[
             0.30513277253024496`, 0.43795777610955633`, 0.9406913989633512]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 455}], {
             RGBColor[
             0.4613630510985772, 0.5696942669850865, 0.9518169362796256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 475}], {
             RGBColor[
             0.32310504521526556`, 0.4542790832588659, 0.9418089456639116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 478}], {
             RGBColor[
             0.27949760473699387`, 0.41101358939533483`, 0.9392315140813577]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 482}], {
             RGBColor[
             0.3210267437424298, 0.45247896298156487`, 0.9416765181318323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 137}], {
             RGBColor[
             0.23700337417738956`, 0.3664359515152362, 0.9368083635931062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 148}], {
             RGBColor[
             0.26849318417245727`, 0.3995337383893224, 0.9386016616873261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 229}], {
             RGBColor[
             0.24859585520259658`, 0.3786203840784777, 0.9374685382379528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 232}], {
             RGBColor[
             0.2704052861597108, 0.40154347881219404`, 0.9387105530667987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 263}], {
             RGBColor[
             0.24334458110817345`, 0.37310096205523113`, 0.9371694859468394]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 267}], {
             RGBColor[
             0.24580395513477205`, 0.37568592009050583`, 0.9373095436593363]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 280}], {
             RGBColor[
             0.25791236607974777`, 0.3884126277112705, 0.937999099749864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 342}], {
             RGBColor[
             0.36933196448262395`, 0.489404611907154, 0.9450840596145658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 393}], {
             RGBColor[
             0.24183341082623228`, 0.3715126262751811, 0.9370834270348589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 480}], {
             RGBColor[
             0.2528560578238772, 0.3830981271458908, 0.9377111504748298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 485}], {
             RGBColor[
             0.25884791756577036`, 0.3893959516404705, 0.9380523780229685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 200}], {
             RGBColor[
             0.3616498178113511, 0.4832425921885635, 0.9444724938641782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 228}], {
             RGBColor[
             0.35927043823642757`, 0.48074171339394056`, 0.9443369917173629]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 256}], {
             RGBColor[
             0.3859408633418989, 0.5085140760316679, 0.9458653508371028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 287}], {
             RGBColor[
             0.38223901787712034`, 0.5048831468883692, 0.9456450183489318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 298}], {
             RGBColor[
             0.368006349252357, 0.4899237097604318, 0.9448344889260978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 336}], {
             RGBColor[
             0.5428373971732765, 0.639738879428151, 0.957153294865837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 132}], {
             RGBColor[
             0.27212682678288186`, 0.40335292715912663`, 0.9388085922584972]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 250}], {
             RGBColor[
             0.24579035153480303`, 0.3756716218444204, 0.9373087689544427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 342}], {
             RGBColor[
             0.37412603951120016`, 0.4944434887241004, 0.9453570750952447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 356}], {
             RGBColor[
             0.2586276684650108, 0.3891644558709726, 0.9380398351625095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 365}], {
             RGBColor[
             0.23949140661491064`, 0.36905103135743866`, 0.9369500533597088]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 457}], {
             RGBColor[
             0.37059515571215895`, 0.49157695819153635`, 0.9450791109885306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 485}], {
             RGBColor[
             0.26364199259434656`, 0.39443482845741684`, 0.9383253935036474]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 494}], {
             RGBColor[
             0.31362082310207806`, 0.44266127858544857`, 0.9413292216811688]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 141}], {
             RGBColor[
             0.21496969901233648`, 0.34327716190107216`, 0.9355535783883577]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 151}], {
             RGBColor[
             0.21317178010893856`, 0.3413874351389585, 0.9354511895665918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 160}], {
             RGBColor[
             0.23103960685447572`, 0.36016765393416605`, 0.9364687358666692]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 167}], {
             RGBColor[
             0.23124675852992788`, 0.3603853834792411, 0.9364805328481329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 172}], {
             RGBColor[
             0.22306123798292227`, 0.35178188239235997`, 0.9360143795623734]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 201}], {
             RGBColor[
             0.24004103918211672`, 0.36962873003428975`, 0.9369813541213027]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 218}], {
             RGBColor[
             0.2542535028794738, 0.3845669305024568, 0.9377907329034113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 235}], {
             RGBColor[
             0.21987414226832205`, 0.3484320427227756, 0.9358328791763124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 236}], {
             RGBColor[
             0.21549489107563347`, 0.3438291720586974, 0.9355834872994104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 274}], {
             RGBColor[
             0.23335737797095998`, 0.3626037783327675, 0.936600729502918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 284}], {
             RGBColor[
             0.21473027895683314`, 0.3430255162426299, 0.9355399437703871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 289}], {
             RGBColor[
             0.21635167337317993`, 0.34472970457655394`, 0.93563227978376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 300}], {
             RGBColor[
             0.2272468293636924, 0.3561812043153706, 0.9362527427994807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 305}], {
             RGBColor[
             0.26659251557076086`, 0.3973687929461906, 0.9384995442473698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 308}], {
             RGBColor[
             0.20676738749395213`, 0.33465601243866294`, 0.9350864688816183]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 389}], {
             RGBColor[
             0.20877589722978934`, 0.3367670835179003, 0.9352008505397502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 432}], {
             RGBColor[
             0.2569317093580773, 0.38738189531956746`, 0.9379432528003164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 456}], {
             RGBColor[
             0.20912093230204676`, 0.3371297372553299, 0.9352204997766816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 493}], {
             RGBColor[
             0.24176752917831046`, 0.3714433804860776, 0.9370796751724728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 123}], {
             RGBColor[
             0.18238673674691558`, 0.30903040268098764`, 0.933698026889515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 139}], {
             RGBColor[
             0.18076319755662762`, 0.3073239600536649, 0.9336055687344391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 158}], {
             RGBColor[
             0.18531714297239393`, 0.3121104454224513, 0.9338649091889084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 193}], {
             RGBColor[
             0.17992543383268728`, 0.3064434172625156, 0.9335578593297211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 401}], {
             RGBColor[
             0.17982716171712376`, 0.30634012703824637`, 0.9335522628781203]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 410}], {
             RGBColor[
             0.18058759193707163`, 0.30713938741347224`, 0.9335955682541907]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 428}], {
             RGBColor[
             0.18335052254202558`, 0.31004340265919705`, 0.9337529130647533]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 437}], {
             RGBColor[
             0.18042329707310156`, 0.30696670309454366`, 0.93358621190474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 122}], {
             RGBColor[
             0.18517962016864098`, 0.3119659002362576, 0.9338570774686815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 185}], {
             RGBColor[
             0.19811081032671668`, 0.3255574009772055, 0.9345934896182024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 212}], {
             RGBColor[
             0.18331321264928, 0.31000418759633763`, 0.9337507883215563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 224}], {
             RGBColor[
             0.19530748745975585`, 0.322610930903094, 0.9344338445280735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 286}], {
             RGBColor[
             0.18603827385130794`, 0.3128683996985284, 0.9339059765256451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 319}], {
             RGBColor[
             0.18277177150935192`, 0.30943509862892227`, 0.9337199540496279]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 330}], {
             RGBColor[
             0.18713069149999506`, 0.314016599910578, 0.9339681880946508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 357}], {
             RGBColor[
             0.18661251030183867`, 0.3134719586167301, 0.9339386784419961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 367}], {
             RGBColor[
             0.19091514645848728`, 0.31799430202025647`, 0.9341837072059376]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 368}], {
             RGBColor[
             0.1819562792912616, 0.3085779646025163, 0.9336735129742202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 492}], {
             RGBColor[
             0.18364470169108055`, 0.3103526035968892, 0.9337696661320929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 110}], {
             RGBColor[
             0.443925135446012, 0.558453392319533, 0.9496384572015815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 136}], {
             RGBColor[
             0.4994982670529912, 0.6045542211909409, 0.9537414797863035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.3849349952696799, 0.5064668572722832, 0.9459123269300246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 240}], {
             RGBColor[
             0.7327901627995155, 0.786266849612556, 0.8137611085910759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 360}], {
             RGBColor[
             0.5334689580963748, 0.6321331585421514, 0.9564157770239803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 457}], {
             RGBColor[
             0.47001276809964954`, 0.5806165648340276, 0.951420273299755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 163}], {
             RGBColor[
             0.9438826652312557, 0.8041948007039634, 0.3236750855301855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 207}], {
             RGBColor[
             0.9317219029437263, 0.7489756193744845, 0.31352784738991035`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 209}], {
             RGBColor[
             0.9914664507187211, 0.9823539717574632, 0.575433002447343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 231}], {
             RGBColor[
             0.8760573705850234, 0.8940094298858756, 0.6933676019879993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 233}], {
             RGBColor[
             0.9755070986726647, 0.9721600768096842, 0.6789609948576975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 257}], {
             RGBColor[
             0.9757547061623437, 0.9298770721991836, 0.3603120410906092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 281}], {
             RGBColor[
             0.903440360362725, 0.5576720713111039, 0.28746666826170925`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 317}], {
             RGBColor[
             0.9028878976305327, 0.5534256006607606, 0.2869376293254444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 322}], {
             RGBColor[
             0.9046195205529701, 0.5667356132446183, 0.288595833391559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 326}], {
             RGBColor[
             0.8569194124299913, 0.8790587115212953, 0.6914601091734929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 343}], {
             RGBColor[
             0.9173437036143605, 0.6645392600270346, 0.3007805254610556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 355}], {
             RGBColor[
             0.7740833188183651, 0.8130804459299827, 0.6840694071044306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 395}], {
             RGBColor[
             0.7462989112429244, 0.7905238121869427, 0.6818821167624534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 440}], {
             RGBColor[
             0.9400446504463722, 0.7867672719569345, 0.32047255191532753`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 105}], {
             RGBColor[
             0.18986356428247403`, 0.31688902247910566`, 0.93412382115669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 276}], {
             RGBColor[
             0.20095020339638087`, 0.3285417831213411, 0.9347551888530141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 347}], {
             RGBColor[
             0.19568928020766854`, 0.32301221928820867`, 0.9344555870602553]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 382}], {
             RGBColor[
             0.20018581629901203`, 0.3277383638170652, 0.9347116581386283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 425}], {
             RGBColor[
             0.1874902819867422, 0.31439455231150293`, 0.9339886662409045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 462}], {
             RGBColor[
             0.18918443929913709`, 0.3161752190626076, 0.9340851459935643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 131}], {
             RGBColor[
             0.9067135965497277, 0.6223214351513566, 0.549591400192696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 143}], {
             RGBColor[
             0.7801748654933693, 0.827408823277354, 0.9396902443294888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 178}], {
             RGBColor[
             0.7245036529888805, 0.7822124250066672, 0.9353076025507647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 186}], {
             RGBColor[
             0.9865105734086191, 0.9862533521324298, 0.7169514481905657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 277}], {
             RGBColor[
             0.7114622471897839, 0.7713508183962726, 0.9343566439534178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 288}], {
             RGBColor[
             0.8454606604699532, 0.8793558579429647, 0.9455510322617159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 295}], {
             RGBColor[
             0.9822469150718874, 0.9861800274834427, 0.9104424780465525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 313}], {
             RGBColor[
             0.6704591742575927, 0.7358360174967769, 0.9317439644037724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 321}], {
             RGBColor[
             0.9825665367368704, 0.9863121992558153, 0.9051455199034306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 341}], {
             RGBColor[
             0.9869976251000042, 0.9872951064518227, 0.7699640190632113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 373}], {
             RGBColor[
             0.9853487541189616, 0.9874627176430353, 0.859036977734402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 498}], {
             RGBColor[
             0.8771421221278247, 0.9041056565781206, 0.9487087442796804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 203}], {
             RGBColor[
             0.9191489665110915, 0.667681353565574, 0.3474800185895157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 257}], {
             RGBColor[
             0.9781397520963673, 0.9374756322249009, 0.407566735110352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 264}], {
             RGBColor[
             0.92938539319056, 0.7351346977720205, 0.3568427596083415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 281}], {
             RGBColor[
             0.9058254062967486, 0.5652706313368212, 0.33472136228145205`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 324}], {
             RGBColor[
             0.9664798274342277, 0.9712473493741347, 0.7455337650413938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 360}], {
             RGBColor[
             0.7946952326726424, 0.8354763984444047, 0.7327589869340729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 374}], {
             RGBColor[
             0.9203355927006582, 0.6768022824414968, 0.3486163331687475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 397}], {
             RGBColor[
             0.9076183259729562, 0.5790517976305654, 0.33643826418820166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 457}], {
             RGBColor[
             0.7312390426759171, 0.7839598047362808, 0.7277634832098476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 103}], {
             RGBColor[
             0.32745764009317235`, 0.4521656087003331, 0.9423017119454735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 129}], {
             RGBColor[
             0.2672434934849943, 0.39822023424183295`, 0.9385304936514267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[
             0.2805071756988172, 0.41149947624089733`, 0.9393100698709307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 276}], {
             RGBColor[
             0.22935486634297414`, 0.3583968848378599, 0.9363727923868895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 306}], {
             RGBColor[
             0.24294061497845892`, 0.37267636803996923`, 0.9371464806733664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 331}], {
             RGBColor[
             0.2732729587475753, 0.4045575845229832, 0.9388738627783362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 347}], {
             RGBColor[
             0.22409394315426182`, 0.3528673210047275, 0.9360731905941307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 390}], {
             RGBColor[
             0.25051248587412484`, 0.3806348844356572, 0.9375776875192954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 431}], {
             RGBColor[
             0.33318158758536665`, 0.45712340432410575`, 0.9426664368181881]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 486}], {
             RGBColor[
             0.32922289158902907`, 0.45369458082192426`, 0.9424141922098388]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 134}], {
             RGBColor[
             0.1917868632444325, 0.31891053163232136`, 0.9342333501873077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 174}], {
             RGBColor[
             0.1934597999069662, 0.32066889413495503`, 0.934328621455351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 210}], {
             RGBColor[
             0.19748304019874757`, 0.324897574769785, 0.9345577390381172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 225}], {
             RGBColor[
             0.19170377678695943`, 0.3188232024975315, 0.9342286185364699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 247}], {
             RGBColor[
             0.19186086570906943`, 0.31898831291468205`, 0.934237564518192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 252}], {
             RGBColor[
             0.19087465031632422`, 0.3179517380072394, 0.93418140101055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 278}], {
             RGBColor[
             0.19195325855915324`, 0.31908542365816517`, 0.9342428261543212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 309}], {
             RGBColor[
             0.19381918087775277`, 0.3210466263213213, 0.9343490876699807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 383}], {
             RGBColor[
             0.23360844690792137`, 0.362867667704204, 0.9366150275074547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 393}], {
             RGBColor[
             0.2103791435745319, 0.3384521970779141, 0.9352921530472929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 451}], {
             RGBColor[
             0.20226457959273075`, 0.32992327583996894`, 0.9348300406329509]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 480}], {
             RGBColor[
             0.2214017905721769, 0.3500376979486238, 0.9359198764872638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 129}], {
             RGBColor[
             0.3495899489939847, 0.47542806862452014`, 0.9435621141955579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 204}], {
             RGBColor[
             0.3628536312078076, 0.48870731062358463`, 0.9443416904150619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 209}], {
             RGBColor[
             0.7021401008892698, 0.7606785926382128, 0.8442710393667008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 231}], {
             RGBColor[
             0.5867310207555722, 0.6723340507666251, 0.9622056389073572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 233}], {
             RGBColor[
             0.6861807488432135, 0.7504846976904338, 0.9477990317770553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 259}], {
             RGBColor[
             0.5465386609637427, 0.6409354738239997, 0.9581996401022647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 275}], {
             RGBColor[
             0.4495582322834861, 0.5628291466682479, 0.9501364705331162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 326}], {
             RGBColor[
             0.56759306260054, 0.6573833324020449, 0.9602981460928508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 346}], {
             RGBColor[
             0.4256097063793528, 0.5430634687251261, 0.9483404520319744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 348}], {
             RGBColor[
             0.4359422690580296, 0.5517750943296691, 0.9490645720310915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 355}], {
             RGBColor[
             0.48475696898891374`, 0.5914050668107322, 0.9529074440237885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 390}], {
             RGBColor[
             0.3328589413831152, 0.4578427188183445, 0.9426093080634266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 404}], {
             RGBColor[
             0.6233155210312117, 0.7010502757004149, 0.96581591387943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 431}], {
             RGBColor[
             0.415528043094357, 0.534331238706793, 0.9476980573623193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 443}], {
             RGBColor[
             0.3488203865149018, 0.47461920966592475`, 0.9435182887508398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 444}], {
             RGBColor[
             0.4878340995369397, 0.5939032200127712, 0.9531496870124296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 486}], {
             RGBColor[
             0.41156934709801946`, 0.5309024152046116, 0.94744581275397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 125}], {
             RGBColor[
             0.8510407401896769, 0.7816870619636468, 0.6181576134272155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 147}], {
             RGBColor[
             0.8716060245867224, 0.4422899593743725, 0.21185872764377553`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 242}], {
             RGBColor[
             0.9486223107500168, 0.8581914089875718, 0.5941049181072977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 303}], {
             RGBColor[
             0.8824648742106225, 0.5257558359619144, 0.2222571743069387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 310}], {
             RGBColor[
             0.7844721843600413, 0.7296832002097726, 0.6115226819006405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 323}], {
             RGBColor[
             0.958420920419589, 0.8640840271773381, 0.5141442750004963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 379}], {
             RGBColor[
             0.8757781230833462, 0.4743585366446421, 0.21585393387585383`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 408}], {
             RGBColor[
             0.9307079198191593, 0.8448308855634613, 0.624429309131783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 109}], {
             RGBColor[
             0.2025306105640042, 0.3302028912581151, 0.9348451907032074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 205}], {
             RGBColor[
             0.21445329260995954`, 0.34273438603011697`, 0.9355241698076971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 230}], {
             RGBColor[
             0.19866180408544326`, 0.32613653035264917`, 0.9346248678976397]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 382}], {
             RGBColor[
             0.2017475218904906, 0.3293798154115627, 0.9348005949617267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 425}], {
             RGBColor[
             0.18905198757822078`, 0.3160360039060004, 0.9340776030640029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 462}], {
             RGBColor[
             0.19074614489061564`, 0.31781667065710506`, 0.9341740828166627]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 484}], {
             RGBColor[
             0.1881185665568436, 0.315054919230222, 0.9340244461177081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 156}], {
             RGBColor[
             0.1895211212928381, 0.31652909318485867`, 0.9341043195350291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 227}], {
             RGBColor[
             0.18640315120824044`, 0.31325190893522514`, 0.9339267557513348]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 265}], {
             RGBColor[
             0.18198502195137928`, 0.3086081749606899, 0.933675149826193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 270}], {
             RGBColor[
             0.17988066425974236`, 0.3063963616027956, 0.9335553097687725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 329}], {
             RGBColor[
             0.18061317161541351`, 0.30716627327725476`, 0.9335970249790304]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 479}], {
             RGBColor[
             0.18098277247116215`, 0.30755474721069437`, 0.9336180732009899]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 153}], {
             RGBColor[
             0.21946182531602942`, 0.3479986714635114, 0.9358093983358476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 170}], {
             RGBColor[
             0.19951076544330998`, 0.3270288425670261, 0.9346732149910444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 197}], {
             RGBColor[
             0.221090097802618, 0.3497100890853544, 0.9359021260451457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 214}], {
             RGBColor[
             0.19941582681621922`, 0.32692905605049705`, 0.9346678083766806]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 223}], {
             RGBColor[
             0.20973558752308613`, 0.3377757788640342, 0.935255503482219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 236}], {
             RGBColor[
             0.20982294786551192`, 0.3378676001228893, 0.935260478524482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 289}], {
             RGBColor[
             0.21067973016305835`, 0.3387681326407459, 0.9353092710088315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 314}], {
             RGBColor[
             0.2370472271918243, 0.36648204381384886`, 0.9368108609574035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 411}], {
             RGBColor[
             0.24624789168403566`, 0.3761525255509848, 0.9373348251890715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 466}], {
             RGBColor[
             0.20308636910120992`, 0.33078702871784477`, 0.9348768403297303]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 470}], {
             RGBColor[
             0.20295018288856098`, 0.3306438883736461, 0.9348690847263893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 113}], {
             RGBColor[
             0.2031652064588611, 0.33086989177931336`, 0.934881330000619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 190}], {
             RGBColor[
             0.21307880253974895`, 0.34128970981862183`, 0.9354458946315745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 315}], {
             RGBColor[
             0.19651178198130725`, 0.3238767208019274, 0.9345024273194817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 349}], {
             RGBColor[
             0.19740440059431363`, 0.32481491955948594`, 0.9345532606289816]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 364}], {
             RGBColor[
             0.2070027664491964, 0.33490341064451234`, 0.9350998733649074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 378}], {
             RGBColor[
             0.20828889068141454`, 0.33625520875755976`, 0.9351731162372818]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 380}], {
             RGBColor[
             0.19854131235532485`, 0.3260098859046778, 0.934618006071861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 416}], {
             RGBColor[
             0.20942130064370462`, 0.3374454434268651, 0.9352376053093838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 452}], {
             RGBColor[
             0.21821098000140754`, 0.3466839537296702, 0.9357381645456397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 487}], {
             RGBColor[
             0.20117686323780593`, 0.3287800169857428, 0.9347680967956702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 164}], {
             RGBColor[
             0.2648306442899861, 0.3950111522821019, 0.9384177281820844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 180}], {
             RGBColor[
             0.23839049921865452`, 0.36789390788241305`, 0.9368873583121385]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 205}], {
             RGBColor[
             0.22555863330001114`, 0.354406803214629, 0.9361566025311163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 230}], {
             RGBColor[
             0.20976714477549485`, 0.3378089475371612, 0.9352573006210588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 382}], {
             RGBColor[
             0.2128528625805422, 0.3410522325960747, 0.9354330276851459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 413}], {
             RGBColor[
             0.22197296688604118`, 0.35063804046916514`, 0.9359524041333588]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 474}], {
             RGBColor[
             0.22157473772172553`, 0.350219476368282, 0.9359297255715783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 490}], {
             RGBColor[
             0.21480193499900369`, 0.3431008312862066, 0.935544024475983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 157}], {
             RGBColor[
             0.35808579273911467`, 0.4836854080233668, 0.944070557261417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 356}], {
             RGBColor[
             0.3311960783219361, 0.45542261326454736`, 0.9425392278051263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 360}], {
             RGBColor[
             0.5066197555658096, 0.6093517092932348, 0.9545740073553726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 457}], {
             RGBColor[
             0.44316356556908426`, 0.5578351155851111, 0.9495785036311474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 494}], {
             RGBColor[
             0.3861892329590033, 0.5089194359790232, 0.9458286143237857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 130}], {
             RGBColor[
             0.3347552996533061, 0.46383121081799694`, 0.9425710153855427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 175}], {
             RGBColor[
             0.38213445941917534`, 0.5054073949376681, 0.9455702477393233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 182}], {
             RGBColor[
             0.35579432343932743`, 0.4825928930456521, 0.9438918775663551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 351}], {
             RGBColor[
             0.3033909458875273, 0.43086528639527777`, 0.9407848618379848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 359}], {
             RGBColor[
             0.6380588033619161, 0.711320155207173, 0.9679062350071925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 371}], {
             RGBColor[
             0.3103368514001098, 0.4381658734848475, 0.9411804208813801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 460}], {
             RGBColor[
             0.33363255379100343`, 0.46265113373051764`, 0.9425070766696382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 463}], {
             RGBColor[
             0.4608753150975682, 0.5708435411870683, 0.9513515854271455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 483}], {
             RGBColor[
             0.4093161482374549, 0.528950807600658, 0.9473022409150004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 163}], {
             RGBColor[
             0.9463750065735652, 0.8136106484588435, 0.49802406298394036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 175}], {
             RGBColor[
             0.6955594457176699, 0.7552129086866064, 0.8524579222934991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 207}], {
             RGBColor[
             0.9342142442860358, 0.7583914671293646, 0.48787682484366524`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 238}], {
             RGBColor[
             0.7400652706680888, 0.7928555147204785, 0.8555441529553656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 266}], {
             RGBColor[
             0.9935124253020141, 0.9901198523525236, 0.6506615550659651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 293}], {
             RGBColor[
             0.901595183019146, 0.9214285748097474, 0.8700135366280143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 317}], {
             RGBColor[
             0.9053802389728423, 0.5628414484156407, 0.4612866067791993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 343}], {
             RGBColor[
             0.91983604495667, 0.6739551077819146, 0.4751295029148105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 359}], {
             RGBColor[
             0.9514837896604106, 0.9611256689561112, 0.8747939095613684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 403}], {
             RGBColor[
             0.8684251833169994, 0.8955159189410955, 0.8667074610489753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 440}], {
             RGBColor[
             0.9425369917886818, 0.7961831197118145, 0.4948215293690824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 445}], {
             RGBColor[
             0.9782801480279448, 0.9394045757914982, 0.5347896078268422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 463}], {
             RGBColor[
             0.7743003013960627, 0.8206490549360065, 0.8582392599813213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 471}], {
             RGBColor[
             0.9751390722082593, 0.9794426669377387, 0.8581518289048162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 483}], {
             RGBColor[
             0.7227411345359493, 0.7787563213495963, 0.8541899154691762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 190}], {
             RGBColor[
             0.20663037548476026`, 0.33451200412993914`, 0.9350786662503858]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 315}], {
             RGBColor[
             0.19006335492631857`, 0.31709901511324473`, 0.9341351989382931]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 349}], {
             RGBColor[
             0.19095597353932497`, 0.3180372138708033, 0.934186032247793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 353}], {
             RGBColor[
             0.1887122478968889, 0.3156789159601807, 0.9340582553917509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 364}], {
             RGBColor[
             0.20055433939420772`, 0.3281257049558297, 0.9347326449837188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 378}], {
             RGBColor[
             0.20184046362642588`, 0.32947750306887713`, 0.9348058878560932]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 380}], {
             RGBColor[
             0.19209288530033616`, 0.3192321802159951, 0.9342507776906723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 487}], {
             RGBColor[
             0.19472843618281724`, 0.32200231129706014`, 0.9344008684144816]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 128}], {
             RGBColor[
             0.1878451960142834, 0.31476758945729777`, 0.9340088780697248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 138}], {
             RGBColor[
             0.18210218513342014`, 0.30873132089358957`, 0.9336818220960829]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 179}], {
             RGBColor[
             0.19077318734493098`, 0.3178450939911811, 0.9341756228444302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 255}], {
             RGBColor[
             0.1893023656117655, 0.31629916709414013`, 0.9340918617226122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 294}], {
             RGBColor[
             0.18446317038438925`, 0.311212866087469, 0.9338162767133609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 296}], {
             RGBColor[
             0.18183178255671295`, 0.30844711064095676`, 0.9336664230693641]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 312}], {
             RGBColor[
             0.1882015984664733, 0.31514219103177, 0.9340291746621268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 327}], {
             RGBColor[
             0.18260674360457746`, 0.3092616438376308, 0.933710555954588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 334}], {
             RGBColor[
             0.18414474445457316`, 0.31087818024586233`, 0.9337981428277268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 385}], {
             RGBColor[
             0.18149489941754873`, 0.3080930251020705, 0.9336472380729627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 415}], {
             RGBColor[
             0.18091671513236096`, 0.30748531675933716`, 0.9336143113332682]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 446}], {
             RGBColor[
             0.18242070987008802`, 0.30906611058746236`, 0.933699961608621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 144}], {
             RGBColor[
             0.1939326542641488, 0.3211658940450518, 0.9343555498114672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 215}], {
             RGBColor[
             0.18797465353578718`, 0.3149036575204792, 0.9340162504840592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 223}], {
             RGBColor[
             0.1995856510144891, 0.3271075520503548, 0.9346774796135398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 268}], {
             RGBColor[
             0.18864406926620203`, 0.3156072558965539, 0.9340543727195945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 402}], {
             RGBColor[
             0.20455792141877943`, 0.3323337235054161, 0.9349606430572492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 417}], {
             RGBColor[
             0.19405888879625283`, 0.3212985745420247, 0.9343627386813232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 143}], {
             RGBColor[
             0.4285653763865951, 0.5391828000638526, 0.9495933114012363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 165}], {
             RGBColor[
             0.2912027626996634, 0.4234029452918576, 0.9398949385886397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 185}], {
             RGBColor[
             0.24400994073613447`, 0.3738002972104551, 0.9372073771933402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 187}], {
             RGBColor[
             0.24886259772016034`, 0.3789007473768896, 0.9374837288297179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 224}], {
             RGBColor[
             0.2412066178691736, 0.37085382713634363`, 0.9370477321032114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 277}], {
             RGBColor[
             0.35985275808300965`, 0.4831247951827711, 0.9442597110251651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 313}], {
             RGBColor[
             0.3188496851508186, 0.44760999428327536`, 0.9416470314755198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 333}], {
             RGBColor[
             0.2541335864563355, 0.3844408907385981, 0.937783903840514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 358}], {
             RGBColor[
             0.2506809998117433, 0.38081200326849496`, 0.9375872841387487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 361}], {
             RGBColor[
             0.25328984688463263`, 0.3835540669525598, 0.9377358541201064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 386}], {
             RGBColor[
             0.2910406970756628, 0.423232604045479, 0.9398857091911075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 441}], {
             RGBColor[
             0.24897326082313725`, 0.37901706131456436`, 0.9374900309297209]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 140}], {
             RGBColor[
             0.1812891715754636, 0.30787679209614044`, 0.933635522176703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 155}], {
             RGBColor[
             0.1887434182573529, 0.3157116779853434, 0.9340600304976668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 156}], {
             RGBColor[
             0.19147940284680726`, 0.31858737126030207`, 0.9342158407725099]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 198}], {
             RGBColor[
             0.18298777738438862`, 0.30966213449914926`, 0.9337322552646592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 270}], {
             RGBColor[
             0.18183894581371152`, 0.308454639678239, 0.933666831006253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 479}], {
             RGBColor[
             0.1829410540251313, 0.30961302528613777`, 0.9337295944384705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 152}], {
             RGBColor[
             0.1882232378558979, 0.3151649354020718, 0.9340304069933419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 187}], {
             RGBColor[
             0.20672865124829637`, 0.33461529818845887`, 0.9350842629097332]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.19015295783973063`, 0.31719319345639363`, 0.9341403016916563]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 255}], {
             RGBColor[
             0.19469073239539242`, 0.3219626822259184, 0.9343987212395655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 260}], {
             RGBColor[
             0.20098092756456265`, 0.3285740761701249, 0.9347569385489398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 292}], {
             RGBColor[
             0.188665488336347, 0.3156297686973238, 0.9340555925039526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 399}], {
             RGBColor[
             0.200045010570769, 0.32759036806908304`, 0.9347036394607084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 446}], {
             RGBColor[
             0.18780907665371493`, 0.3147296257192406, 0.9340068211255742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 464}], {
             RGBColor[
             0.1973325308094801, 0.3247393798588184, 0.9345491677510571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 481}], {
             RGBColor[
             0.1987399075504107, 0.32621862204637564`, 0.9346293157744259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 496}], {
             RGBColor[
             0.18901315212113398`, 0.315995185378292, 0.9340753914421738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 120}], {
             RGBColor[
             0.18211134871711507`, 0.30874095240105776`, 0.9336823439486179]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 124}], {
             RGBColor[
             0.18484388120986256`, 0.311613017303502, 0.9338379576316604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 363}], {
             RGBColor[
             0.18346622269800678`, 0.3101650108589469, 0.9337595020174734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 364}], {
             RGBColor[
             0.19435544195191212`, 0.32161027071117865`, 0.934379626944827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 381}], {
             RGBColor[
             0.18630903659373593`, 0.3131529885081697, 0.9339213960632688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 416}], {
             RGBColor[
             0.19677397614642037`, 0.32415230349353147`, 0.9345173588893034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 124}], {
             RGBColor[
             0.18263624540769638`, 0.3092926521032311, 0.9337122360386315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 315}], {
             RGBColor[
             0.18165682168185682`, 0.3082632156683228, 0.9336564593063725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 363}], {
             RGBColor[
             0.18125858689584057`, 0.307844645658676, 0.9336337804244444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 381}], {
             RGBColor[
             0.18410140079156978`, 0.3108326233078988, 0.9337956744702399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 196}], {
             RGBColor[
             0.19856429776732792`, 0.3260340450300523, 0.9346193150570707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.20367497522683542`, 0.331405691075661, 0.93491036057782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 307}], {
             RGBColor[
             0.1984527242001829, 0.32591677413681014`, 0.93461296110748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 337}], {
             RGBColor[
             0.19710919882017952`, 0.3245046437779975, 0.9345364493246566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 420}], {
             RGBColor[
             0.1965885249531354, 0.3239573825311042, 0.9345067977181964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 427}], {
             RGBColor[
             0.19582329677639237`, 0.3231530791990786, 0.9344632191055845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 442}], {
             RGBColor[
             0.22151836933651753`, 0.35016022962146637`, 0.9359265154754303]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 447}], {
             RGBColor[
             0.21943101242653507`, 0.34796628516300276`, 0.9358076435873746]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 454}], {
             RGBColor[
             0.20826238807822112`, 0.3362273528412414, 0.9351716069532372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 489}], {
             RGBColor[
             0.1983767553672155, 0.32583692607665915`, 0.9346086347948284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 500}], {
             RGBColor[
             0.20306057228198376`, 0.33075991462522525`, 0.9348753712390383]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 185}], {
             RGBColor[
             0.19860974920189184`, 0.3260818173695664, 0.9346219034490297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 212}], {
             RGBColor[
             0.18381215152445518`, 0.3105286039886985, 0.9337792021523836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 216}], {
             RGBColor[
             0.19279683115434215`, 0.3199720719413004, 0.9342908663656634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 217}], {
             RGBColor[
             0.1834604918576584, 0.31015898738238445`, 0.9337591756545935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 224}], {
             RGBColor[
             0.195806426334931, 0.3231353472954549, 0.9344622583589008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 286}], {
             RGBColor[
             0.1865372127264831, 0.3133928160908893, 0.9339343903564724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 319}], {
             RGBColor[
             0.1832707103845271, 0.30995951502128316`, 0.9337483678804552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 330}], {
             RGBColor[
             0.18762963037517022`, 0.3145410163029389, 0.9339966019254781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 357}], {
             RGBColor[
             0.18711144917701383`, 0.313996375009091, 0.9339670922728234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 492}], {
             RGBColor[
             0.1841436405662557, 0.3108770199892501, 0.9337980799629202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 139}], {
             RGBColor[
             0.1842229343035432, 0.31096036273465255`, 0.9338025956239542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 158}], {
             RGBColor[
             0.1887768797193095, 0.31574684810343895`, 0.9340619360784235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 193}], {
             RGBColor[
             0.18338517057960285`, 0.31007981994350325`, 0.9337548862192361]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 401}], {
             RGBColor[
             0.18328689846403934`, 0.309976529719234, 0.9337492897676354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 410}], {
             RGBColor[
             0.18404732868398718`, 0.3107757900944599, 0.9337925951437056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 422}], {
             RGBColor[
             0.1961933017960193, 0.3235419779343797, 0.9344842903440789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 428}], {
             RGBColor[
             0.18681025928894113`, 0.3136798053401847, 0.9339499399542682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 437}], {
             RGBColor[
             0.18388303382001714`, 0.3106031057755313, 0.9337832387942551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 363}], {
             RGBColor[
             0.1839911193885881, 0.3107167105611202, 0.9337893941074868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 381}], {
             RGBColor[
             0.18683393328431724`, 0.31370468821034303`, 0.9339512881532823]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 416}], {
             RGBColor[
             0.19729887283700168`, 0.3247040031957048, 0.934547250979317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.669539684263013, 0.7405244264891351, 0.9685478722425018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 173}], {
             RGBColor[
             0.7492734803038996, 0.8040574045935522, 0.9756442362240689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 242}], {
             RGBColor[
             0.8755313279725643, 0.9029638772422787, 0.9544497242112633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 249}], {
             RGBColor[
             0.7524497512082946, 0.8065387315646185, 0.9759608172238798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 269}], {
             RGBColor[
             0.6899118040266511, 0.7570634310667932, 0.970151640135829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 282}], {
             RGBColor[
             0.7373315894354715, 0.794728308685404, 0.9744539801456191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 305}], {
             RGBColor[
             0.5442522046967718, 0.6349340468295404, 0.9597558326180513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 310}], {
             RGBColor[
             0.7113812015825887, 0.7744556684644794, 0.9718674880046061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 323}], {
             RGBColor[
             0.8853299376421364, 0.9088564954320449, 0.8744890811044619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 406}], {
             RGBColor[
             0.5972259557238873, 0.6808172474310844, 0.9631312731906503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 408}], {
             RGBColor[
             0.8576169370417068, 0.8896033538181681, 0.9847741152357485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 419}], {
             RGBColor[
             0.7136180387569662, 0.7762031026656953, 0.9720904350297161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 173}], {
             RGBColor[
             0.6045267350947843, 0.6886225535376819, 0.9628291330052186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 249}], {
             RGBColor[
             0.6077030059991793, 0.6911038805087482, 0.9631457140050295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 269}], {
             RGBColor[
             0.5451650588175359, 0.6416285800109227, 0.9573365369169786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 282}], {
             RGBColor[
             0.5925848442263562, 0.6792934576295336, 0.9616388769267687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 340}], {
             RGBColor[
             0.4261246264730337, 0.5425553802981693, 0.948636879181104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 384}], {
             RGBColor[
             0.3782656319739345, 0.49734201260730226`, 0.9457250298186803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 414}], {
             RGBColor[
             0.45556143140572114`, 0.5680520611940277, 0.9505125663614704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 449}], {
             RGBColor[
             0.7360314578812237, 0.7759766732200013, 0.6718437842469422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 499}], {
             RGBColor[
             0.5585145617417738, 0.6524663078730726, 0.9583874586880152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 184}], {
             RGBColor[
             0.6864931860475436, 0.7535560913976342, 0.970424092580223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 221}], {
             RGBColor[
             0.8972130382069989, 0.8767030519388234, 0.6458996213784399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 253}], {
             RGBColor[
             0.604821677598294, 0.6851926412626169, 0.9645634759762418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 301}], {
             RGBColor[
             0.7442995113076243, 0.8002700424356418, 0.9751223810067287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 303}], {
             RGBColor[
             0.8364744443127496, 0.5917978023235237, 0.5852770137807005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 316}], {
             RGBColor[
             0.6354319607294284, 0.7117057299932411, 0.9665139361497471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 138}], {
             RGBColor[
             0.18851306554638397`, 0.31546956268090953`, 0.9340469122515535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 179}], {
             RGBColor[
             0.19718406775789482`, 0.32458333577850107`, 0.9345407129999008]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 222}], {
             RGBColor[
             0.19567917188119596`, 0.32300159479618107`, 0.9344550114060167]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 245}], {
             RGBColor[
             0.21909064595633707`, 0.347608538422344, 0.9357882602204238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 294}], {
             RGBColor[
             0.1908740507973531, 0.317951107874789, 0.9341813668688315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 296}], {
             RGBColor[
             0.1882426629696768, 0.3151853524282767, 0.9340315132248347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 312}], {
             RGBColor[
             0.19461247887943717`, 0.32188043281908996`, 0.9343942648175974]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 385}], {
             RGBColor[
             0.1879057798305126, 0.31483126688939045`, 0.9340123282284333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 415}], {
             RGBColor[
             0.1873275955453248, 0.3142235585466571, 0.9339794014887388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 438}], {
             RGBColor[
             0.19844895166515433`, 0.32591280896330255`, 0.9346127462671912]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 439}], {
             RGBColor[
             0.1967431917255388, 0.32411994711534, 0.9345156057620757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 204}], {
             RGBColor[
             0.3026394845996296, 0.4347619361650844, 0.9405704721210151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 275}], {
             RGBColor[
             0.3893440856753081, 0.5088837722097477, 0.9463652522390695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 276}], {
             RGBColor[
             0.2514871752437865, 0.381659344762047, 0.9376331946369739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 306}], {
             RGBColor[
             0.2650729238792713, 0.39593882796415625`, 0.9384068829234508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 331}], {
             RGBColor[
             0.2954052676483876, 0.42782004444717026`, 0.9401342650284206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 346}], {
             RGBColor[
             0.36539555977117477`, 0.4891180942666259, 0.9445692337379277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 348}], {
             RGBColor[
             0.37572812244985154`, 0.497829719871169, 0.9452933537370448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 355}], {
             RGBColor[
             0.4245428223807357, 0.5374596923522321, 0.9491362257297418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 431}], {
             RGBColor[
             0.35531389648617895`, 0.48038586424829277`, 0.9439268390682725]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 444}], {
             RGBColor[
             0.42761995292876165`, 0.539957845554271, 0.9493784687183828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 486}], {
             RGBColor[
             0.3513552004898414, 0.47695704074611134`, 0.9436745944599232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 175}], {
             RGBColor[
             0.350298253723786, 0.4772937364222603, 0.943561398674819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 182}], {
             RGBColor[
             0.323958117743938, 0.4544792345302443, 0.9418830285018508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 208}], {
             RGBColor[
             0.3647668975032984, 0.4898257484488929, 0.9444833278623301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 238}], {
             RGBColor[
             0.39480407867420486`, 0.5149363424561325, 0.9466476293366854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 241}], {
             RGBColor[
             0.2592745192308342, 0.38984433703856036`, 0.9380766723566932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 351}], {
             RGBColor[
             0.2715547401921379, 0.40275162787986996`, 0.9387760127734806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 371}], {
             RGBColor[
             0.27850064570472033`, 0.41005221496943967`, 0.9391715718168758]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 442}], {
             RGBColor[
             0.2704116943765009, 0.4015502142543449, 0.9387109180052648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 483}], {
             RGBColor[
             0.3774799425420655, 0.5008371490852502, 0.9452933918504961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 186}], {
             RGBColor[
             0.913526249632497, 0.6241954645463874, 0.3472925437386266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 234}], {
             RGBColor[
             0.88005378670787, 0.5030425365640092, 0.21977647609763581`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 373}], {
             RGBColor[
             0.9123644303428394, 0.625404830056993, 0.48937807328246297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 434}], {
             RGBColor[
             0.8844045850628767, 0.520292002224005, 0.22327723058043727`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 449}], {
             RGBColor[
             0.9086679607710296, 0.6083135329493521, 0.2853739255705805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 495}], {
             RGBColor[
             0.8599106722287021, 0.41795803680078086`, 0.20329863351297417`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 250}], {
             RGBColor[
             0.24597806511608875`, 0.3758689207200801, 0.9373194589651996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 356}], {
             RGBColor[
             0.2588153820462965, 0.38936175474663237`, 0.9380505251732665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 365}], {
             RGBColor[
             0.23967912019619636`, 0.3692483302330984, 0.9369607433704656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 457}], {
             RGBColor[
             0.37078286929344473`, 0.4917742570671961, 0.9450898009992874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 494}], {
             RGBColor[
             0.3138085366833637, 0.4428585774611083, 0.9413399116919258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 191}], {
             RGBColor[
             0.19428859491049005`, 0.32154001023229684`, 0.9343758201047092]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 237}], {
             RGBColor[
             0.21543537025685555`, 0.3437666119043239, 0.9355800976768341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 241}], {
             RGBColor[
             0.2068052594645497, 0.3346958182809826, 0.9350886256343172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 271}], {
             RGBColor[
             0.20303817120051487`, 0.3307363696682909, 0.9348740955305881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 304}], {
             RGBColor[
             0.19434480354761932`, 0.3215990890737532, 0.9343790211034406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 311}], {
             RGBColor[
             0.19398258593487913`, 0.3212183753968402, 0.9343583933462479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 351}], {
             RGBColor[
             0.21908548042585338`, 0.34760310912229214`, 0.9357879660511045]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 366}], {
             RGBColor[
             0.1902687027163505, 0.3173148486603702, 0.9341468931911505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 371}], {
             RGBColor[
             0.22603138593843586`, 0.35490369621186185`, 0.9361835250944996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 405}], {
             RGBColor[
             0.18981989868512106`, 0.3168431271677289, 0.9341213344655181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 423}], {
             RGBColor[
             0.18859024302857952`, 0.3155506811080321, 0.9340513073949906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 429}], {
             RGBColor[
             0.19496484613925177`, 0.3222507931505298, 0.9344143316117632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 469}], {
             RGBColor[
             0.18966655655355485`, 0.31668195486500017`, 0.9341126018579748]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 488}], {
             RGBColor[
             0.19025464326071956`, 0.31730007128108106`, 0.9341460925259515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 174}], {
             RGBColor[
             0.18580423451035571`, 0.31262240951223635`, 0.9338926483314081]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 210}], {
             RGBColor[
             0.18982747480213708`, 0.31685109014706625`, 0.9341217659141743]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 225}], {
             RGBColor[
             0.1840482113903489, 0.31077671787481287`, 0.933792645412527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 247}], {
             RGBColor[
             0.1842053003124589, 0.3109418282919634, 0.933801591394249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 252}], {
             RGBColor[
             0.18321908491971373`, 0.3099052533845207, 0.9337454278866071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 278}], {
             RGBColor[
             0.18429769316254274`, 0.3110389390354465, 0.9338068530303782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 309}], {
             RGBColor[
             0.18616361548114224`, 0.31300014169860263`, 0.9339131145460378]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 424}], {
             RGBColor[
             0.18880157011833354`, 0.31577279927827495`, 0.9340633421601217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 169}], {
             RGBColor[
             0.1819041358977289, 0.3085231585898313, 0.9336705434850978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 211}], {
             RGBColor[
             0.18373947818140363`, 0.31045221969739534`, 0.9337750635130075]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 362}], {
             RGBColor[
             0.1796163784049865, 0.3061185804127562, 0.9335402590803201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 369}], {
             RGBColor[
             0.18101136995755066`, 0.307584804982074, 0.9336197017855334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 466}], {
             RGBColor[
             0.18744105358565671`, 0.3143428101407012, 0.9339858627562896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 470}], {
             RGBColor[
             0.18730486737300778`, 0.31419966979650255`, 0.9339781071529487]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 240}], {
             RGBColor[
             0.7615140918759296, 0.8095862292350475, 0.8160223615071904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 434}], {
             RGBColor[
             0.7316510467407765, 0.7040970288480641, 0.6113123490612679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 148}], {
             RGBColor[
             0.24314559520540308`, 0.3728918152549845, 0.9371581539940498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 156}], {
             RGBColor[
             0.2055253114742025, 0.33335051178973785`, 0.9350157344897803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 227}], {
             RGBColor[
             0.2024073413896048, 0.33007332754010427`, 0.9348381707060858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 229}], {
             RGBColor[
             0.2232482662355424, 0.35197846094413987`, 0.9360250305446766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 263}], {
             RGBColor[
             0.21799699214111928`, 0.34645903892089325`, 0.935725978253563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 265}], {
             RGBColor[
             0.19798921213274367`, 0.325429593565569, 0.934586564780944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 267}], {
             RGBColor[
             0.22045636616771785`, 0.34904399695616795`, 0.93586603596606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 280}], {
             RGBColor[
             0.2325647771126936, 0.3617707045769326, 0.9365555920565876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 393}], {
             RGBColor[
             0.21648582185917808`, 0.3448707031408432, 0.9356399193415825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 424}], {
             RGBColor[
             0.20256381379959026`, 0.3302377899639228, 0.9348470815783543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 485}], {
             RGBColor[
             0.2335003285987162, 0.3627540285061326, 0.9366088703296922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 179}], {
             RGBColor[
             0.19144105687703156`, 0.31854706721479287`, 0.9342136570262589]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 222}], {
             RGBColor[
             0.1899361610003327, 0.31696532623247287`, 0.9341279554323748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 294}], {
             RGBColor[
             0.18513103991648983`, 0.3119148393110808, 0.9338543108951896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 296}], {
             RGBColor[
             0.18249965208881352`, 0.3091490838645686, 0.9337044572511928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 339}], {
             RGBColor[
             0.1814781394477339, 0.3080754093111516, 0.9336462836174759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 385}], {
             RGBColor[
             0.18216276894964933`, 0.30879499832568225`, 0.9336852722547914]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 415}], {
             RGBColor[
             0.18158458466446153`, 0.308187289982949, 0.9336523455150969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 438}], {
             RGBColor[
             0.19270594078429107`, 0.3198765403995944, 0.9342856902935492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 158}], {
             RGBColor[
             0.18715334052902155`, 0.3140404054761162, 0.9339694779233476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 247}], {
             RGBColor[
             0.18343934894517555`, 0.310136764840827, 0.9337579715970057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 278}], {
             RGBColor[
             0.18353174179525936`, 0.31023387558431004`, 0.933763233233135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 401}], {
             RGBColor[
             0.18166335927375138`, 0.3082700870919113, 0.9336568316125594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 410}], {
             RGBColor[
             0.18242378949369925`, 0.3090693474671371, 0.9337001369886297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 428}], {
             RGBColor[
             0.1851867200986532, 0.311973362712862, 0.9338574817991923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 437}], {
             RGBColor[
             0.18225949462972918`, 0.3088966631482086, 0.9336907806391791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 451}], {
             RGBColor[
             0.19384306282883684`, 0.3210717277661138, 0.9343504477117648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 198}], {
             RGBColor[
             0.18071298100430727`, 0.3072711792732629, 0.9336027089760732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 270}], {
             RGBColor[
             0.1795641494336302, 0.30606368445235266`, 0.9335372847176671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 479}], {
             RGBColor[
             0.18066625764504995`, 0.3072220700602514, 0.9336000481498845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 151}], {
             RGBColor[
             0.20551109996107267`, 0.3333355745883765, 0.9350149251651315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 160}], {
             RGBColor[
             0.2233789267066098, 0.352115793383584, 0.936032471465209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 162}], {
             RGBColor[
             0.19531753931264573`, 0.32262149603780554`, 0.9344344169662252]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 167}], {
             RGBColor[
             0.22358607838206196`, 0.35233352292865905`, 0.9360442684466725]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 235}], {
             RGBColor[
             0.21221346212045616`, 0.34038018217219357`, 0.9353966147748521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 274}], {
             RGBColor[
             0.2256966978230941, 0.35455191778218553`, 0.9361644651014577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 284}], {
             RGBColor[
             0.20706959880896725`, 0.33497365569204784`, 0.9351036793689267]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 300}], {
             RGBColor[
             0.21958614921582648`, 0.3481293437647886, 0.9358164783980203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 345}], {
             RGBColor[
             0.19907503548324326`, 0.3265708627521209, 0.9346484008144234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 389}], {
             RGBColor[
             0.20111521708192343`, 0.32871522296731825`, 0.9347645861382899]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 432}], {
             RGBColor[
             0.24927102921021138`, 0.3793300347689854, 0.937506988398856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 456}], {
             RGBColor[
             0.20146025215418084`, 0.3290778767047479, 0.9347842353752214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 472}], {
             RGBColor[
             0.19522243291560842`, 0.32252153318442556`, 0.9344290007976113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[
             0.2155365862389103, 0.34387299631892737`, 0.9355858617772765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 161}], {
             RGBColor[
             0.21478163330642375`, 0.3430794929201034, 0.9355428683246243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 183}], {
             RGBColor[
             0.20633874170827649`, 0.3342054785402052, 0.9350620581382485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 254}], {
             RGBColor[
             0.20407108545370353`, 0.33182202803893834`, 0.9349329184692474]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 285}], {
             RGBColor[
             0.2150502131881199, 0.3433617874047141, 0.9355581635515585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 388}], {
             RGBColor[
             0.27220031221012625`, 0.4015863957278337, 0.9388802865699359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 396}], {
             RGBColor[
             0.2065755605048984, 0.3344543901106338, 0.9350755446183742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 473}], {
             RGBColor[
             0.23965328121814944`, 0.36922117182888525`, 0.9369592718788913]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 477}], {
             RGBColor[
             0.2067532217668407, 0.3346411233613098, 0.9350856621644155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 165}], {
             RGBColor[
             0.4432891969739572, 0.5546584690453142, 0.950431811201746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 178}], {
             RGBColor[
             0.5249805981564001, 0.6252419255466224, 0.9557475422356184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 186}], {
             RGBColor[
             0.7869875185761387, 0.829282852672385, 0.7373913878754195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 277}], {
             RGBColor[
             0.5119391923573035, 0.6143803189362278, 0.9547965836382715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 288}], {
             RGBColor[
             0.6459376056374727, 0.7223853584829198, 0.9659909719465696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 313}], {
             RGBColor[
             0.4709361194251123, 0.5788655180367319, 0.9521839040886261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 321}], {
             RGBColor[
             0.78304348190439, 0.8293416997957703, 0.9255854595882844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 373}], {
             RGBColor[
             0.7858256992864812, 0.8304922181829903, 0.8794769174192558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 386}], {
             RGBColor[
             0.4431271313499566, 0.5544881277989356, 0.9504225818042138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 414}], {
             RGBColor[
             0.5016592032391687, 0.6054763090493759, 0.9541415518219014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 498}], {
             RGBColor[
             0.6776190672953443, 0.7471351571180758, 0.9691486839645342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 145}], {
             RGBColor[
             0.20296158096381922`, 0.33065586847342227`, 0.9348697338299133]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 215}], {
             RGBColor[
             0.19092068807717077`, 0.3180001266128517, 0.9341840227929235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 246}], {
             RGBColor[
             0.21838885852257034`, 0.34687091533356196`, 0.9357482944642723]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 375}], {
             RGBColor[
             0.1998107076045579, 0.3273441007959291, 0.9346902962534028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 402}], {
             RGBColor[
             0.20750395596016302`, 0.3354301925977886, 0.9351284153661135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 417}], {
             RGBColor[
             0.19700492333763642`, 0.3243950436343972, 0.9345305109901875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 458}], {
             RGBColor[
             0.21795043797046626`, 0.346410107535832, 0.935723327062415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 367}], {
             RGBColor[
             0.2030970423728074, 0.33079824700301824`, 0.9348774481567581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 375}], {
             RGBColor[
             0.20589359976284474`, 0.33373760613192704`, 0.9350367079629848]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 402}], {
             RGBColor[
             0.21358684811844986`, 0.34182369793378664`, 0.9354748270756954]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 417}], {
             RGBColor[
             0.20308781549592325`, 0.3307885489703952, 0.9348769226997694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 450}], {
             RGBColor[
             0.21228550631692578`, 0.340455905190549, 0.9354007175852613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 458}], {
             RGBColor[
             0.2240333301287531, 0.35280361287183004`, 0.936069738771997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 461}], {
             RGBColor[
             0.23115805437216275`, 0.3602921497852615, 0.9364754812775742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 166}], {
             RGBColor[
             0.18787743892822623`, 0.31480147880417053`, 0.9340107142559747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 239}], {
             RGBColor[
             0.18835872742063176`, 0.3153073435251416, 0.9340381229236147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 248}], {
             RGBColor[
             0.18017302617267333`, 0.306703652510102, 0.9335719593472032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 387}], {
             RGBColor[
             0.18448194243535776`, 0.3112325967032537, 0.9338173457538927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 221}], {
             RGBColor[
             0.8906777697244648, 0.5160364512426465, 0.23692570222520362`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 234}], {
             RGBColor[
             0.872729313424225, 0.4467434253012546, 0.2127625522094079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 242}], {
             RGBColor[
             0.8960966123696098, 0.5635667746530044, 0.5481508384278233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 303}], {
             RGBColor[
             0.8299391758302155, 0.23113120162734693`, 0.17630309462746424`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 323}], {
             RGBColor[
             0.905895222039182, 0.5694593928427707, 0.46819019532102185`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 449}], {
             RGBColor[
             0.9013434874873846, 0.5520144216865974, 0.2783600016823526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 229}], {
             RGBColor[
             0.25473807623061007`, 0.385076247818226, 0.9378183286388965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 232}], {
             RGBColor[
             0.27654750718772436`, 0.40799934255194237`, 0.9390603434677424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 263}], {
             RGBColor[
             0.24948680213618696`, 0.3795568257949794, 0.9375192763477829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 267}], {
             RGBColor[
             0.25194617616278553`, 0.3821417838302541, 0.9376593340602799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 280}], {
             RGBColor[
             0.2640545871077613, 0.39486849145101877`, 0.9383488901508075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 342}], {
             RGBColor[
             0.3754741855106375, 0.4958604756469023, 0.9454338500155093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 393}], {
             RGBColor[
             0.24797563185424576`, 0.37796849001492944`, 0.9374332174358024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 480}], {
             RGBColor[
             0.25899827885189075`, 0.38955399088563913`, 0.9380609408757734]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 485}], {
             RGBColor[
             0.26499013859378384`, 0.39585181538021874`, 0.9384021684239121]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 173}], {
             RGBColor[
             0.6408634071546884, 0.7181223008643338, 0.9656896889353898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 242}], {
             RGBColor[
             0.767121254823353, 0.8170287735130601, 0.9444951769225841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 249}], {
             RGBColor[
             0.6440396780590834, 0.7206036278354, 0.9660062699352006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 269}], {
             RGBColor[
             0.5815017308774398, 0.6711283273375747, 0.9601970928471498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 282}], {
             RGBColor[
             0.6289215162862603, 0.7087932049561856, 0.9644994328569398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 310}], {
             RGBColor[
             0.6029711284333774, 0.688520564735261, 0.9619129407159268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 314}], {
             RGBColor[
             0.41196878637874557`, 0.5240737659037882, 0.9484356108143341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 323}], {
             RGBColor[
             0.7769198644929252, 0.8229213917028264, 0.8645345338157826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 406}], {
             RGBColor[
             0.48881588257467606`, 0.5948821437018659, 0.9531767259019711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 411}], {
             RGBColor[
             0.4211694508709569, 0.5337442476409241, 0.9489595750460023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 419}], {
             RGBColor[
             0.6052079656077549, 0.6902679989364768, 0.962135887741037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 220}], {
             RGBColor[
             0.21619691693173887`, 0.3445670457444743, 0.9356234666333614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 254}], {
             RGBColor[
             0.20389499448692971`, 0.33163694526804693`, 0.9349228903491928]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 325}], {
             RGBColor[
             0.2244980131258032, 0.35329202416433336`, 0.9360962017812421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 392}], {
             RGBColor[
             0.22610554162039614`, 0.3549816385353439, 0.9361877481508839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 412}], {
             RGBColor[
             0.20280807626052344`, 0.33049452529749807`, 0.9348609919641505]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 426}], {
             RGBColor[
             0.20135872025195078`, 0.3289711602380097, 0.9347784532835923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 473}], {
             RGBColor[
             0.23947719025137565`, 0.36903608905799384`, 0.9369492437588367]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 160}], {
             RGBColor[
             0.22158100780321188`, 0.3502260666214703, 0.9359300826434431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 162}], {
             RGBColor[
             0.1935196204092478, 0.32073176927569186`, 0.9343320281444594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 226}], {
             RGBColor[
             0.19534643528489967`, 0.3226518675367549, 0.9344360625490973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 235}], {
             RGBColor[
             0.21041554321705824`, 0.3384904554100799, 0.9352942259530863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 237}], {
             RGBColor[
             0.2183016735730191, 0.3467792784237385, 0.9357433294103739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 274}], {
             RGBColor[
             0.22389877891969617`, 0.3526621910200718, 0.9360620762796918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 284}], {
             RGBColor[
             0.20527167990556933`, 0.33308392892993416`, 0.9350012905471609]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 345}], {
             RGBColor[
             0.19727711657984534`, 0.32468113599000714`, 0.9345460119926574]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 389}], {
             RGBColor[
             0.1993172981785255, 0.3268254962052045, 0.9346621973165241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 456}], {
             RGBColor[
             0.19966233325078292`, 0.32718814994263423`, 0.9346818465534554]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 472}], {
             RGBColor[
             0.1934245140122105, 0.3206318064223118, 0.9343266119758453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 195}], {
             RGBColor[
             0.18616514652705513`, 0.313001750924931, 0.9339132017368377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 216}], {
             RGBColor[
             0.19207526490404528`, 0.31921366006229573`, 0.9342497742351705]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 217}], {
             RGBColor[
             0.18273892560736155`, 0.30940057550337985`, 0.9337180835241007]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 292}], {
             RGBColor[
             0.18467767702367152`, 0.3114383261658612, 0.9338284925491338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 398}], {
             RGBColor[
             0.19524728601816377`, 0.32254765537098895`, 0.934430416145035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 399}], {
             RGBColor[
             0.19605719925809356`, 0.3233989255376204, 0.9344765395058896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 464}], {
             RGBColor[
             0.19334471949680462`, 0.32054793732735576`, 0.9343220677962385]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 481}], {
             RGBColor[
             0.1947520962377352, 0.322027179514913, 0.9344022158196071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 496}], {
             RGBColor[
             0.1850253408084585, 0.31180374284682943`, 0.9338482914873549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 172}], {
             RGBColor[
             0.22556462734887084`, 0.3544131033400252, 0.9361569438833315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 197}], {
             RGBColor[
             0.22926543037868818`, 0.35830288196882765`, 0.9363676991410321]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 201}], {
             RGBColor[
             0.2425444285480653, 0.37225995098195497`, 0.9371239184422607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 223}], {
             RGBColor[
             0.21791092009915627`, 0.34636857174750746`, 0.9357210765781054]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 236}], {
             RGBColor[
             0.21799828044158207`, 0.3464603930063626, 0.9357260516203685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 289}], {
             RGBColor[
             0.21885506273912853`, 0.34736092552421916`, 0.935774844104718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 314}], {
             RGBColor[
             0.24522255976789442`, 0.3750748366973221, 0.93727643405329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 411}], {
             RGBColor[
             0.2544232242601058, 0.38474531843445803`, 0.937800398284958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 466}], {
             RGBColor[
             0.2112617016772801, 0.3393798216013181, 0.9353424134256167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 470}], {
             RGBColor[
             0.2111255154646311, 0.3392366812571194, 0.9353346578222758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 493}], {
             RGBColor[
             0.24427091854425903`, 0.3740746014337428, 0.9372222394934309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 199}], {
             RGBColor[
             0.684800695862128, 0.748031110338605, 0.9293475993147051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[
             0.9142690676811895, 0.6673158743356673, 0.5518317374650853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 219}], {
             RGBColor[
             0.8264967277029731, 0.8644743578312362, 0.9402829367923042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 244}], {
             RGBColor[
             0.7150943787471429, 0.7742699758488314, 0.9312778860004862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 295}], {
             RGBColor[
             0.9841314996436169, 0.9875855475713144, 0.9072523679449918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 341}], {
             RGBColor[
             0.9888822096717337, 0.9887006265396945, 0.7667739089616505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 374}], {
             RGBColor[
             0.9154556938707563, 0.6764368032115899, 0.5529680520443171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 376}], {
             RGBColor[
             0.6772879972861523, 0.7415239884313045, 0.9288688968046623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 397}], {
             RGBColor[
             0.9027384271430544, 0.5786863184006587, 0.5407899830637712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 455}], {
             RGBColor[
             0.7982558492888101, 0.8419633098945049, 0.937775174104184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 198}], {
             RGBColor[
             0.1881672276861966, 0.31510606516246586`, 0.934027217297037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 250}], {
             RGBColor[
             0.2067822292135854, 0.3346716120270169, 0.9350873140955949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 365}], {
             RGBColor[
             0.200483284293693, 0.3280510215400352, 0.934728598500861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 394}], {
             RGBColor[
             0.1886886358497215, 0.3156540982015175, 0.9340569107205956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 467}], {
             RGBColor[
             0.19253479608250443`, 0.31969665646681583`, 0.9342759438559683]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 479}], {
             RGBColor[
             0.18812050432693928`, 0.3150569559494543, 0.9340245564708484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 198}], {
             RGBColor[
             0.19090321227565094`, 0.31798175843742454`, 0.93418302757188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 227}], {
             RGBColor[
             0.1962768676534719, 0.3236298109489438, 0.9344890492960363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 250}], {
             RGBColor[
             0.20951821380303975`, 0.3375473053019756, 0.9352431243704379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 263}], {
             RGBColor[
             0.21186651840498638`, 0.34001552232973276`, 0.9353768568435135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 270}], {
             RGBColor[
             0.18975438070497386`, 0.3167742636165143, 0.9341176033134739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 479}], {
             RGBColor[
             0.19085648891639362`, 0.317932649224413, 0.9341803667456914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 485}], {
             RGBColor[
             0.22736985486258326`, 0.3563105119149721, 0.9362597489196426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 190}], {
             RGBColor[
             0.2578198120642154, 0.3883153475726824, 0.9379938289356007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 356}], {
             RGBColor[
             0.272205938145604, 0.40343607821729777`, 0.9388130975335695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 360}], {
             RGBColor[
             0.44762961538947754`, 0.5573651742459853, 0.9508478770838158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.2086123729274203, 0.33659520910807084`, 0.9351915380726428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 193}], {
             RGBColor[
             0.1863155768050812, 0.3131598626849669, 0.9339217685186295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 247}], {
             RGBColor[
             0.18799329436094186`, 0.3149232502096133, 0.9340173120514751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 278}], {
             RGBColor[
             0.18808568721102567`, 0.3150203609530965, 0.9340225736876044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 370}], {
             RGBColor[
             0.21023358203312498`, 0.3382992026687606, 0.9352838635328488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 401}], {
             RGBColor[
             0.1862173046895177, 0.3130565724606977, 0.9339161720670288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 410}], {
             RGBColor[
             0.18697773490946556`, 0.31385583283592355`, 0.933959477443099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 422}], {
             RGBColor[
             0.19912370802149765`, 0.3266220206758434, 0.9346511726434723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 428}], {
             RGBColor[
             0.1897406655144195, 0.31675984808164837`, 0.9341168222536617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 437}], {
             RGBColor[
             0.1868134400454955, 0.31368314851699497`, 0.9339501210936485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 451}], {
             RGBColor[
             0.19839700824460316`, 0.32585821313490027`, 0.9346097881662341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 166}], {
             RGBColor[
             0.21389899734106987`, 0.3421517865581641, 0.9354926035121403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 192}], {
             RGBColor[
             0.27255273720121065`, 0.4034082682269394, 0.9388472119027095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 239}], {
             RGBColor[
             0.2143802858334754, 0.34265765127913517`, 0.9355200121797802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 251}], {
             RGBColor[
             0.23552312226059172`, 0.3648801128972894, 0.936724065436281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 272}], {
             RGBColor[
             0.24467152920527638`, 0.37449566863865497`, 0.9372450536779255]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 344}], {
             RGBColor[
             0.2111960256367822, 0.3393107919186533, 0.9353386732722694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 435}], {
             RGBColor[
             0.23525737339525699`, 0.3646007939903714, 0.9367089314315404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 439}], {
             RGBColor[
             0.21567326392113564`, 0.34401665322881175`, 0.9355936453690827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 453}], {
             RGBColor[
             0.23602331412857852`, 0.36540584626453976`, 0.9367525506231953]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 167}], {
             RGBColor[
             0.2396559862242012, 0.36922401496175294`, 0.9369594259249842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 235}], {
             RGBColor[
             0.22828336996259535`, 0.35727067420528746`, 0.9363117722531638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 237}], {
             RGBColor[
             0.23616950031855627`, 0.3655594972189461, 0.9367608757104513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 274}], {
             RGBColor[
             0.24176660566523328`, 0.3714424098152794, 0.9370796225797693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 284}], {
             RGBColor[
             0.22313950665110643`, 0.35186414772514174`, 0.9360188368472383]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 300}], {
             RGBColor[
             0.2356560570579657, 0.36501983579788244`, 0.936731635876332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 305}], {
             RGBColor[
             0.2750017432650342, 0.40620742442870245`, 0.938978437324221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 389}], {
             RGBColor[
             0.21718512492406264`, 0.34560571500041215`, 0.9356797436166016]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 432}], {
             RGBColor[
             0.26534093705235057`, 0.3962205268020793, 0.9384221458771677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 460}], {
             RGBColor[
             0.27006121839103014`, 0.4011818417721542, 0.938690958916375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 183}], {
             RGBColor[
             0.2054076978090161, 0.33322689237048986`, 0.9350090365655417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 188}], {
             RGBColor[
             0.2189136351360459, 0.34742248882708376`, 0.9357781797160722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 202}], {
             RGBColor[
             0.2003053984953046, 0.32786405228731785`, 0.9347184681678012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 243}], {
             RGBColor[
             0.20521495427576572`, 0.33302430669639793`, 0.9349980601064616]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 273}], {
             RGBColor[
             0.20050467294518176`, 0.3280735023688687, 0.9347298165529216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 279}], {
             RGBColor[
             0.21091668232154126`, 0.339017184382946, 0.9353227650837177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 285}], {
             RGBColor[
             0.21411916928885952`, 0.34238320123499877`, 0.9355051419788516]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 287}], {
             RGBColor[
             0.25900221419710867`, 0.3895581271829785, 0.9380611649878617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 335}], {
             RGBColor[
             0.21211283365491676`, 0.3402744152746985, 0.9353908841326062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 354}], {
             RGBColor[
             0.262219161885439, 0.39276906224398844`, 0.9382506002184958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 396}], {
             RGBColor[
             0.205644516605638, 0.33347580394091847`, 0.9350225230456672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 409}], {
             RGBColor[
             0.23354210119449076`, 0.36279793415282724`, 0.9366112492172245]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 430}], {
             RGBColor[
             0.2077033952850149, 0.33563981597339154`, 0.9351397731406197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 459}], {
             RGBColor[
             0.20416528068413636`, 0.3319210331984458, 0.9349382827482713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 477}], {
             RGBColor[
             0.2058221778675803, 0.33366253719159444`, 0.9350326405917087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 226}], {
             RGBColor[
             0.18515287463647273`, 0.3119377889861841, 0.933855554350191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 284}], {
             RGBColor[
             0.19507811925714236`, 0.3223698503793633, 0.9344207823482545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 345}], {
             RGBColor[
             0.1870835559314184, 0.31396705743943626`, 0.9339655037937511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 389}], {
             RGBColor[
             0.18912373753009853`, 0.3161114176546337, 0.9340816891176178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 456}], {
             RGBColor[
             0.18946877260235598`, 0.3164740713920633, 0.9341013383545491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 472}], {
             RGBColor[
             0.18323095336378353`, 0.30991772787174093`, 0.933746103776939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 207}], {
             RGBColor[
             0.8871477729139166, 0.5804462187569267, 0.227545674269207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 209}], {
             RGBColor[
             0.9468923206889115, 0.8138245711399055, 0.48945082932663964`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 231}], {
             RGBColor[
             0.8314832405552138, 0.7254800292683178, 0.607385428867296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 233}], {
             RGBColor[
             0.9309329686428551, 0.8036306761921264, 0.5929788217369941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 266}], {
             RGBColor[
             0.9464459539298948, 0.8121746039800857, 0.3903304044915068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 317}], {
             RGBColor[
             0.8583137676007231, 0.3848962000432028, 0.20095545620474106`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 326}], {
             RGBColor[
             0.8123452824001817, 0.7105293109037376, 0.6054779360527895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 343}], {
             RGBColor[
             0.8727695735845509, 0.4960098594094768, 0.21479835234035222`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 355}], {
             RGBColor[
             0.7295091887885554, 0.6445510453124249, 0.5980872339837272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 379}], {
             RGBColor[
             0.8633665292005046, 0.42373393983337493`, 0.2057939864189699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 440}], {
             RGBColor[
             0.8954705204165625, 0.6182378713393768, 0.2344903787946242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 180}], {
             RGBColor[
             0.28958519225458484`, 0.42102975172188783`, 0.9398274630675963]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 205}], {
             RGBColor[
             0.2767533263359414, 0.40754264705410376`, 0.9390967072865741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 259}], {
             RGBColor[
             0.4996492818256195, 0.6003222503432779, 0.9552118903262334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 316}], {
             RGBColor[
             0.37736919780669476`, 0.5012799648379501, 0.9452666094831315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 331}], {
             RGBColor[
             0.3087300351184425, 0.44115219542494855`, 0.940917733546436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 348}], {
             RGBColor[
             0.38905288991990644`, 0.5111618708489473, 0.9460768222550604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 372}], {
             RGBColor[
             0.4651482668210734, 0.5729395258749782, 0.9520673290712703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 404}], {
             RGBColor[
             0.5764261418930885, 0.6604370522196931, 0.9628281641033989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 418}], {
             RGBColor[
             0.3962653140595378, 0.5170172416815048, 0.9466446107033122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 431}], {
             RGBColor[
             0.36863866395623385`, 0.49371801522607117`, 0.9447103075862879]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 444}], {
             RGBColor[
             0.4409447203988165, 0.5532899965320492, 0.9501619372363984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 486}], {
             RGBColor[
             0.3646799679598963, 0.49028919172388963`, 0.9444580629779388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 178}], {
             RGBColor[
             0.3876179844694684, 0.5094620707746275, 0.9460491694230218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 185}], {
             RGBColor[
             0.2587337613234965, 0.38927596619191684`, 0.93804587699385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 277}], {
             RGBColor[
             0.37457657867037175`, 0.49860046416423287`, 0.9450982108256749]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 288}], {
             RGBColor[
             0.508574991950541, 0.6066055037109249, 0.956292599133973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 313}], {
             RGBColor[
             0.3335735057381806, 0.4630856632647371, 0.9424855312760294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 333}], {
             RGBColor[
             0.26885740704369754`, 0.3999165597200598, 0.9386224036410238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 358}], {
             RGBColor[
             0.26540482039910535`, 0.39628767224995665`, 0.9384257839392585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 361}], {
             RGBColor[
             0.26801366747199473`, 0.39902973593402147`, 0.9385743539206161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 386}], {
             RGBColor[
             0.3057645176630249, 0.43870827302694076`, 0.9407242089916171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 498}], {
             RGBColor[
             0.5402564536084126, 0.6313553023460808, 0.9594503111519376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 239}], {
             RGBColor[
             0.19616306235610437`, 0.3235101943657379, 0.9344825682527109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 344}], {
             RGBColor[
             0.19297880215941118`, 0.32016333500525607`, 0.9343012293452001]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 387}], {
             RGBColor[
             0.19228627737083037`, 0.31943544754385, 0.934261791082989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 435}], {
             RGBColor[
             0.21704014991788595`, 0.3454533370769741, 0.9356714875044712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 439}], {
             RGBColor[
             0.19745604044376464`, 0.3248691963154145, 0.9345562014420135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 453}], {
             RGBColor[
             0.2178060906512075, 0.3462583893511425, 0.935715106696126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 172}], {
             RGBColor[
             0.23167761735264775`, 0.36083824341994686`, 0.9365050696206882]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[
             0.2486574185518422, 0.37868509106187664`, 0.9374720441796176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 218}], {
             RGBColor[
             0.26286988224919927`, 0.3936232915300437, 0.9382814229617262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 235}], {
             RGBColor[
             0.22849052163804753`, 0.3574884037503625, 0.9363235692346273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 236}], {
             RGBColor[
             0.22411127044535895`, 0.3528855330862843, 0.9360741773577252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 274}], {
             RGBColor[
             0.24197375734068546`, 0.3716601393603544, 0.9370914195612329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 284}], {
             RGBColor[
             0.22334665832655862`, 0.3520818772702168, 0.9360306338287019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 289}], {
             RGBColor[
             0.2249680527429054, 0.35378606560414083`, 0.9361229698420748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 300}], {
             RGBColor[
             0.23586320873341787`, 0.3652375653429575, 0.9367434328577955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 305}], {
             RGBColor[
             0.27520889494048634`, 0.4064251539737775, 0.9389902343056846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 432}], {
             RGBColor[
             0.2655480887278028, 0.39643825634715435`, 0.9384339428586312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 456}], {
             RGBColor[
             0.21773731167177224`, 0.3461860982829168, 0.9357111898349966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 493}], {
             RGBColor[
             0.25038390854803594`, 0.3804997415136645, 0.9375703652307877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 181}], {
             RGBColor[
             0.25911497354415575`, 0.3896766444060805, 0.9380675864658636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 189}], {
             RGBColor[
             0.272342262398906, 0.403579363650975, 0.9388208609981212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 232}], {
             RGBColor[
             0.28558604817661837`, 0.417499422207868, 0.9395750750057368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 280}], {
             RGBColor[
             0.2730931280966553, 0.40436857110694446`, 0.9388636216888019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 302}], {
             RGBColor[
             0.268736668858344, 0.3997896562320101, 0.9386155277799839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 326}], {
             RGBColor[
             0.509047258388588, 0.6051914915809957, 0.9566219374301776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 338}], {
             RGBColor[
             0.35852241644491945`, 0.4834734222788186, 0.944119987452004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 346}], {
             RGBColor[
             0.3670639021674008, 0.4908716279040769, 0.9446642433693013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 370}], {
             RGBColor[
             0.2607361826498604, 0.3913806379667703, 0.9381599119260695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 383}], {
             RGBColor[
             0.2802434761765292, 0.4118840402971449, 0.9392708234339586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 390}], {
             RGBColor[
             0.27431313717116323`, 0.40565087799729527`, 0.9389330994007534]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 395}], {
             RGBColor[
             0.3984267572015211, 0.5166565922466431, 0.9470439450191381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 443}], {
             RGBColor[
             0.29027458230294984`, 0.42242736884487553`, 0.9398420800881666]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 480}], {
             RGBColor[
             0.26803681984078476`, 0.3990540705415648, 0.9385756724137677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 211}], {
             RGBColor[
             0.1856477523702797, 0.3124579368614757, 0.9338837369050252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 236}], {
             RGBColor[
             0.19608590653883476`, 0.32342909870982617`, 0.9344781743430592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 289}], {
             RGBColor[
             0.19694268883638122`, 0.3243296312276827, 0.9345269668274088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 308}], {
             RGBColor[
             0.18735840295715342`, 0.31425593908979166`, 0.9339811559252671]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 362}], {
             RGBColor[
             0.18152465259386255`, 0.3081242975768366, 0.9336489324723378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 369}], {
             RGBColor[
             0.1829196441464267, 0.30959052214615446`, 0.9337283751775514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 456}], {
             RGBColor[
             0.18971194776524802`, 0.31672966390645874`, 0.9341151868203305]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 470}], {
             RGBColor[
             0.1892131415618838, 0.316205386960583, 0.9340867805449665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 214}], {
             RGBColor[
             0.18764009951956995`, 0.31455202003748506`, 0.9339971981277639]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 223}], {
             RGBColor[
             0.19795986022643686`, 0.3253987428510222, 0.9345848932333021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 268}], {
             RGBColor[
             0.18701827847814975`, 0.31389844669722133`, 0.9339617863393568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 466}], {
             RGBColor[
             0.19131064180456064`, 0.3184099927048328, 0.9342062300808134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 491}], {
             RGBColor[
             0.18468093358720655`, 0.3114417490206145, 0.9338286780056095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 192}], {
             RGBColor[
             0.3918420426717766, 0.5133437939110442, 0.9463191721078775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 208}], {
             RGBColor[
             0.44865476640412644`, 0.5625521197174839, 0.9499392286265838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 219}], {
             RGBColor[
             0.5701105988481052, 0.6614643237945504, 0.9595848784963202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 238}], {
             RGBColor[
             0.47869194757503297`, 0.5876627137247235, 0.9521035301009391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 258}], {
             RGBColor[
             0.44293779831735625`, 0.5576003693038944, 0.9495749484754112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 272}], {
             RGBColor[
             0.36396083467584234`, 0.48443119432275983`, 0.9447170138830936]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 293}], {
             RGBColor[
             0.6402218599260903, 0.7162357738139922, 0.9665729137735878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 403}], {
             RGBColor[
             0.6070518602239434, 0.6903231179453404, 0.9632668381945488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 471}], {
             RGBColor[
             0.7137657491152036, 0.7742498659419835, 0.9547112060503897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 497}], {
             RGBColor[
             0.47443851953832683`, 0.5842095892297761, 0.9517686846650694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 197}], {
             RGBColor[
             0.22719289983545946`, 0.3561245209618682, 0.9362496715926294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 201}], {
             RGBColor[
             0.2404718980048366, 0.3700815899749955, 0.9370058908938581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 211}], {
             RGBColor[
             0.20548759572979827`, 0.33331087015105276`, 0.9350135866339319]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 218}], {
             RGBColor[
             0.25468436170219366`, 0.3850197904431626, 0.9378152696759667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 235}], {
             RGBColor[
             0.22030500109104192`, 0.3488849026634814, 0.9358574159488678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 236}], {
             RGBColor[
             0.21592574989835334`, 0.34428203199940316`, 0.9356080240719657]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 289}], {
             RGBColor[
             0.2167825321958998, 0.3451825645172597, 0.9356568165563153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 300}], {
             RGBColor[
             0.22767768818641226`, 0.35663406425607636`, 0.936277279572036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 308}], {
             RGBColor[
             0.207198246316672, 0.3351088723793687, 0.9351110056541736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 314}], {
             RGBColor[
             0.24315002922466572`, 0.37289647569036266`, 0.9371584065048872]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 466}], {
             RGBColor[
             0.20918917113405136`, 0.3372014605943586, 0.935224385877214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 470}], {
             RGBColor[
             0.2090529849214024, 0.33705832025015997`, 0.9352166302738731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 493}], {
             RGBColor[
             0.24219838800103033`, 0.3718962404267834, 0.9371042119450282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 242}], {
             RGBColor[
             0.8468550508642396, 0.8805617516174773, 0.9515915409041512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 249}], {
             RGBColor[
             0.72377347409997, 0.7841366059398172, 0.9731026339167677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 269}], {
             RGBColor[
             0.6612355269183264, 0.7346613054419917, 0.9672934568287169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 282}], {
             RGBColor[
             0.7086553123271468, 0.7723261830606026, 0.9715957968385069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 310}], {
             RGBColor[
             0.682704924474264, 0.7520535428396782, 0.9690093046974939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 323}], {
             RGBColor[
             0.8566536605338118, 0.8864543698072436, 0.8716308977973497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 406}], {
             RGBColor[
             0.5685496786155626, 0.658415121806283, 0.9602730898835382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 419}], {
             RGBColor[
             0.6849417616486415, 0.753800977040894, 0.9692322517226041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 499}], {
             RGBColor[
             0.6745850298425644, 0.7454990333041416, 0.9683443785997534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 210}], {
             RGBColor[
             0.19150041146467078`, 0.3186094526497, 0.9342170371822176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 225}], {
             RGBColor[
             0.18572114805288265`, 0.3125350803774465, 0.9338879166805704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 252}], {
             RGBColor[
             0.18489202158224743`, 0.3116636158871544, 0.9338406991546504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 309}], {
             RGBColor[
             0.18783655214367595`, 0.3147585042012363, 0.9340083858140811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 320}], {
             RGBColor[
             0.1843078028000945, 0.31104956490550145`, 0.933807428759281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 393}], {
             RGBColor[
             0.20439651484045512`, 0.33216407495782907`, 0.9349514511913933]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 424}], {
             RGBColor[
             0.19047450678086728`, 0.3175311617809086, 0.934158613428165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 182}], {
             RGBColor[
             0.3713372775098073, 0.4960554186499155, 0.9448822608556314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 208}], {
             RGBColor[
             0.41214605726916764`, 0.531401932568564, 0.9474825602161108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 351}], {
             RGBColor[
             0.3189338999580072, 0.4443278119995411, 0.9417752451272612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 359}], {
             RGBColor[
             0.653601757432396, 0.7247826808114364, 0.9688966182964689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 371}], {
             RGBColor[
             0.32587980547058965`, 0.4516283990891108, 0.9421708041706565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 463}], {
             RGBColor[
             0.476418269168048, 0.5843060667913316, 0.9523419687164218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 483}], {
             RGBColor[
             0.4248591023079348, 0.5424133332049215, 0.9482926242042767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 178}], {
             RGBColor[
             0.3931214338805177, 0.5144895563820213, 0.9463902997884908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 244}], {
             RGBColor[
             0.38182757506705056`, 0.5051415871363136, 0.945550693339773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 261}], {
             RGBColor[
             0.32311312036066653`, 0.4542860775439437, 0.941809460205036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 262}], {
             RGBColor[
             0.33005042418212294`, 0.46029482143506084`, 0.9422514990701223]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 299}], {
             RGBColor[
             0.2785034431297019, 0.4092981665779968, 0.9391994481892236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 313}], {
             RGBColor[
             0.3390769551492299, 0.46811314887213096`, 0.9428266616414984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 328}], {
             RGBColor[
             0.27995998628272956`, 0.4108290857819987, 0.939282396167026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 376}], {
             RGBColor[
             0.34402119360606, 0.47239559971878675`, 0.9431417041439492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 391}], {
             RGBColor[
             0.3950241069319744, 0.5160342320796381, 0.9465400851808224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 407}], {
             RGBColor[
             0.2970315342752855, 0.4287723651208341, 0.94025459557011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 448}], {
             RGBColor[
             0.3087587670403855, 0.44109843030645696`, 0.9409224441271964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 455}], {
             RGBColor[
             0.46498904560871784`, 0.5728349211819872, 0.9520479814434708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 475}], {
             RGBColor[
             0.3267310397254062, 0.4574197374557666, 0.9420399908277568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 478}], {
             RGBColor[
             0.2831235992471345, 0.4141542435922354, 0.9394625592452028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 482}], {
             RGBColor[
             0.3246527382525704, 0.45561961717846555`, 0.9419075632956775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 194}], {
             RGBColor[
             0.1852447118397448, 0.312034315709638, 0.9338607843430564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 290}], {
             RGBColor[
             0.1829544926129004, 0.3096271500939387, 0.9337303597461633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 297}], {
             RGBColor[
             0.18982245259063335`, 0.3168458114843493, 0.9341214799066588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 412}], {
             RGBColor[
             0.1873190234343715, 0.314214548714542, 0.9339789133197014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 484}], {
             RGBColor[
             0.18459712642978363`, 0.31135366238448237`, 0.9338239053119759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 186}], {
             RGBColor[
             0.7313163060716499, 0.7840864544016981, 0.7330087460966953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 244}], {
             RGBColor[
             0.45801552683844415`, 0.5706975580302278, 0.9505252940081765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 261}], {
             RGBColor[
             0.3993010721320601, 0.5198420484378579, 0.9467840608734395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 288}], {
             RGBColor[
             0.5902663931329839, 0.677188960212233, 0.9616083301678455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 313}], {
             RGBColor[
             0.4152649069206235, 0.5336691197660451, 0.9478012623099019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 321}], {
             RGBColor[
             0.7273722693999012, 0.7841453015250835, 0.9212028178095601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 391}], {
             RGBColor[
             0.47121205870336796`, 0.5815902029735522, 0.9515146858492259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 407}], {
             RGBColor[
             0.3732194860466791, 0.4943283360147483, 0.9452291962385135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 455}], {
             RGBColor[
             0.5411769973801115, 0.6383908920759014, 0.9570225821118743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 475}], {
             RGBColor[
             0.40291899149679977`, 0.5229757083496808, 0.9470145914961603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 498}], {
             RGBColor[
             0.6219478547908555, 0.7019387588473889, 0.96476604218581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 222}], {
             RGBColor[
             0.19860716321184355`, 0.3260790993300644, 0.9346217561807222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 245}], {
             RGBColor[
             0.22201863728698465`, 0.35068604295622735`, 0.9359550049951293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 255}], {
             RGBColor[
             0.19864123735537692`, 0.32611491341534343`, 0.9346236966527881]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 294}], {
             RGBColor[
             0.19380204212800067`, 0.3210286124086723, 0.9343481116435368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 296}], {
             RGBColor[
             0.19117065430032437`, 0.31826285696216006`, 0.9341982579995401]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 312}], {
             RGBColor[
             0.19754047021008475`, 0.3249579373529733, 0.9345610095923028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 327}], {
             RGBColor[
             0.1919456153481889, 0.3190773901588341, 0.9342423908847639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 334}], {
             RGBColor[
             0.1934836161981846, 0.32069392656706563`, 0.9343299777579028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 385}], {
             RGBColor[
             0.19083377116116018`, 0.3179087714232738, 0.9341790730031387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 415}], {
             RGBColor[
             0.19025558687597238`, 0.31730106308054046`, 0.9341461462634442]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 438}], {
             RGBColor[
             0.20137694299580192`, 0.3289903134971859, 0.9347794910418965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 205}], {
             RGBColor[
             0.2503131812646099, 0.38042540265441493`, 0.9375663374166283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 230}], {
             RGBColor[
             0.2345216927400936, 0.3638275469769471, 0.9366670355065708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 331}], {
             RGBColor[
             0.2822898900471109, 0.4140349510252597, 0.9393873636764902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 382}], {
             RGBColor[
             0.23760741054514092`, 0.36707083203586066`, 0.9368427625706579]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 413}], {
             RGBColor[
             0.24672751485063993`, 0.37665663990895104`, 0.9373621390188708]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 418}], {
             RGBColor[
             0.3698251689882062, 0.48989999728181594`, 0.9451142408333664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 474}], {
             RGBColor[
             0.24632928568632426`, 0.37623807580806795`, 0.9373394604570903]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 490}], {
             RGBColor[
             0.23955648296360244`, 0.3691194307259925, 0.9369537593614949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 189}], {
             RGBColor[
             0.238744748764803, 0.3682662466161335, 0.9369075322997265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 302}], {
             RGBColor[
             0.235139155224241, 0.3644765391971686, 0.9367021990815891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 370}], {
             RGBColor[
             0.2271386690157574, 0.35606752093192884`, 0.9362465832276747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 390}], {
             RGBColor[
             0.24071562353706022`, 0.37033776096245374`, 0.9370197707023586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 422}], {
             RGBColor[
             0.2160287950041301, 0.3443903389390116, 0.9356138923382982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 443}], {
             RGBColor[
             0.2566770686688468, 0.387114251810034, 0.9379287513897718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 451}], {
             RGBColor[
             0.21530209522723562`, 0.3436265313980684, 0.93557250786106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 237}], {
             RGBColor[
             0.2889436538091614, 0.4176768128895569, 0.9398890065800227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 351}], {
             RGBColor[
             0.2925937639781592, 0.42151331010752513`, 0.9400968749542931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 359}], {
             RGBColor[
             0.6272616214525479, 0.7019681789194203, 0.9672182481235007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 371}], {
             RGBColor[
             0.29953966949074173`, 0.42881389719709484`, 0.9404924339976882]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 460}], {
             RGBColor[
             0.32283537188163536`, 0.453299157442765, 0.9418190897859463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 463}], {
             RGBColor[
             0.4500781331882001, 0.5614915648993155, 0.9506635985434537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 483}], {
             RGBColor[
             0.3985189663280868, 0.5195988313129054, 0.9466142540313085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 202}], {
             RGBColor[
             0.19186250689715728`, 0.31899003790741964`, 0.9342376579814256]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 206}], {
             RGBColor[
             0.1886895173788014, 0.31565502474447266`, 0.9340569609223726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 243}], {
             RGBColor[
             0.19677206267761843`, 0.3241502923164997, 0.9345172499200859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 273}], {
             RGBColor[
             0.19206178134703447`, 0.31919948798897047`, 0.934249006366546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 279}], {
             RGBColor[
             0.202473790723394, 0.3301431700030478, 0.9348419548973421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 283}], {
             RGBColor[
             0.18964111329673894`, 0.31665521238889094`, 0.9341111529021391]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 285}], {
             RGBColor[
             0.20567627769071223`, 0.33350918685510056`, 0.935024331792476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 396}], {
             RGBColor[
             0.19720162500749072`, 0.32460178956102026`, 0.9345417128592917]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 430}], {
             RGBColor[
             0.19926050368686765`, 0.32676580159349333`, 0.9346589629542441]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 477}], {
             RGBColor[
             0.19737928626943302`, 0.32478852281169623`, 0.934551830405333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 221}], {
             RGBColor[
             0.7515553610831588, 0.7612606169042988, 0.6324712276878893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 253}], {
             RGBColor[
             0.4591640004744537, 0.5697502062280924, 0.9511350822856912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 287}], {
             RGBColor[
             0.42249467395537876`, 0.5375645019893394, 0.9488140910567393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 301}], {
             RGBColor[
             0.5986418341837841, 0.6848276074011173, 0.9616939873161781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 316}], {
             RGBColor[
             0.4897742836055883, 0.5962632949587165, 0.9530855424591965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 336}], {
             RGBColor[
             0.5830930532515349, 0.672420234529121, 0.9603223675736445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 354}], {
             RGBColor[
             0.425711621643709, 0.5407754370503493, 0.9490035262873733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 388}], {
             RGBColor[
             0.43476172806913593`, 0.5486141843644792, 0.9495801910661066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 436}], {
             RGBColor[
             0.4481781977283561, 0.5602348560519236, 0.9504350766490738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 473}], {
             RGBColor[
             0.4022146970771591, 0.5162489604655307, 0.9476591763750619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 187}], {
             RGBColor[
             0.21639359634399347`, 0.34477376827694883`, 0.9356346672349283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 216}], {
             RGBColor[
             0.20572802131241785`, 0.3335635726822483, 0.9350272785151843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 224}], {
             RGBColor[
             0.2087376164930067, 0.33672684803640285`, 0.9351986705084218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 286}], {
             RGBColor[
             0.1994684028845588, 0.32698431683183726`, 0.9346708025059933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 330}], {
             RGBColor[
             0.20056082053324595`, 0.3281325170438868, 0.934733014074999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 333}], {
             RGBColor[
             0.22166458508016862`, 0.3503139116386572, 0.9359348422457243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 357}], {
             RGBColor[
             0.20004263933508956`, 0.3275878757500389, 0.9347035044223444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 358}], {
             RGBColor[
             0.21821199843557637`, 0.3466850241685541, 0.935738222543959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 361}], {
             RGBColor[
             0.22082084550846576`, 0.3494270878526189, 0.9358867925253167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 386}], {
             RGBColor[
             0.25857169569949595`, 0.38910562494553824`, 0.9380366475963178]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 398}], {
             RGBColor[
             0.20890004242653637`, 0.3368975679909415, 0.9352079204250486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 441}], {
             RGBColor[
             0.21650425944697038`, 0.34489008221462353`, 0.9356409693349313]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 464}], {
             RGBColor[
             0.2069974759051772, 0.3348978499473083, 0.9350995720762522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 481}], {
             RGBColor[
             0.2084048526461078, 0.33637709213486555`, 0.9351797200996208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 288}], {
             RGBColor[
             0.8522733135527225, 0.8812298873379956, 0.7432521758076465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 295}], {
             RGBColor[
             0.9890595681546568, 0.9880540568784736, 0.7081436215924831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 321}], {
             RGBColor[
             0.9893791898196398, 0.9881862286508462, 0.7028466634493613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 341}], {
             RGBColor[
             0.9938102781827736, 0.9891691358468536, 0.5676651626091419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 373}], {
             RGBColor[
             0.9921614072017308, 0.9893367470380662, 0.6567381212803327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 397}], {
             RGBColor[
             0.9076664956540943, 0.5791548277078178, 0.3416812367112626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 455}], {
             RGBColor[
             0.8031839177998501, 0.842431819201664, 0.7386664277516752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 495}], {
             RGBColor[
             0.9397076490875935, 0.7818899537818541, 0.3706586815108439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 498}], {
             RGBColor[
             0.8839547752105941, 0.9059796859731515, 0.7464098878256111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 216}], {
             RGBColor[
             0.21058067829644372`, 0.3386640228486828, 0.9353036301515618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 224}], {
             RGBColor[
             0.2135902734770326, 0.34182729820283736`, 0.9354750221447994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 260}], {
             RGBColor[
             0.21549852964428565`, 0.3438329964250494, 0.9355836945105124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 328}], {
             RGBColor[
             0.2321163718921772, 0.36129940225963686`, 0.9365300560426353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 398}], {
             RGBColor[
             0.21375269941056224`, 0.341998018157376, 0.9354842720614263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 399}], {
             RGBColor[
             0.214562612650492, 0.3428492883240075, 0.9355303954222809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 407}], {
             RGBColor[
             0.24918791988473313`, 0.3792426815984722, 0.9375022554457193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 464}], {
             RGBColor[
             0.21185013288920307`, 0.3399983001137429, 0.9353759237126298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 478}], {
             RGBColor[
             0.2352799848565821, 0.36462456006987354`, 0.9367102191208121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 481}], {
             RGBColor[
             0.21325750963013368`, 0.3414775423013001, 0.9354560717359984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 200}], {
             RGBColor[
             0.24347605986022197`, 0.37323915455986845`, 0.937176973467263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 228}], {
             RGBColor[
             0.24109668028529843`, 0.37073827576524543`, 0.9370414713204478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 256}], {
             RGBColor[
             0.26776710539076976`, 0.3985106384029728, 0.9385698304401877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 279}], {
             RGBColor[
             0.21597972805042376`, 0.3443387664596417, 0.9356110980478727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 298}], {
             RGBColor[
             0.24983259130122784`, 0.37992027213173674`, 0.9375389685291828]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 318}], {
             RGBColor[
             0.21097876418895464`, 0.3390824363618151, 0.935326300554225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 335}], {
             RGBColor[
             0.21717587938379926`, 0.3455959973513941, 0.9356792170967612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 409}], {
             RGBColor[
             0.23860514692337326`, 0.3681195162295229, 0.9368995821813795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 430}], {
             RGBColor[
             0.2127664410138974, 0.34096139805008724`, 0.9354281061047747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 459}], {
             RGBColor[
             0.20922832641301886`, 0.3372426152751415, 0.9352266157124262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 302}], {
             RGBColor[
             0.24836644407899122`, 0.3783792584420631, 0.9374554736138468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 346}], {
             RGBColor[
             0.346693677388048, 0.46946123011413, 0.9435041892031641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 370}], {
             RGBColor[
             0.24036595787050763`, 0.36997024017682334`, 0.9369998577599323]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 383}], {
             RGBColor[
             0.25987325139717643`, 0.39047364250719796`, 0.9381107692678216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 390}], {
             RGBColor[
             0.25394291239181044`, 0.3842404802073483, 0.9377730452346162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 422}], {
             RGBColor[
             0.22925608385888036`, 0.3582930581839061, 0.936367166870556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 443}], {
             RGBColor[
             0.2699043575235971, 0.40101697105492856`, 0.9386820259220295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 451}], {
             RGBColor[
             0.22852938408198586`, 0.3575292506429629, 0.9363257823933178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 349}], {
             RGBColor[
             0.20086956962021285`, 0.3284570319101118, 0.9347505968787484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 378}], {
             RGBColor[
             0.21175405970731373`, 0.3398973211081856, 0.9353704524870488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 467}], {
             RGBColor[
             0.20384534758574807`, 0.33158476322710967`, 0.9349200630316166]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 487}], {
             RGBColor[
             0.2046420322637051, 0.3324221293363686, 0.9349654330454369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 226}], {
             RGBColor[
             0.18878815245387853`, 0.31575869646220367`, 0.9340625780439806]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 237}], {
             RGBColor[
             0.21174339074199797`, 0.3398861073491872, 0.9353698449052572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 271}], {
             RGBColor[
             0.19934619168565726`, 0.3268558651131542, 0.9346638427590112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 311}], {
             RGBColor[
             0.19029060642002155`, 0.31733787084170345`, 0.934148140574671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 366}], {
             RGBColor[
             0.18657672320149288`, 0.31343434410523346`, 0.9339366404195737]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 405}], {
             RGBColor[
             0.18612791917026347`, 0.3129626226125922, 0.9339110816939413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 423}], {
             RGBColor[
             0.1848982635137219, 0.3116701765528954, 0.9338410546234137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 429}], {
             RGBColor[
             0.1912728666243942, 0.31837028859539307`, 0.9342040788401863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 488}], {
             RGBColor[
             0.18656266374586195`, 0.3134195667259444, 0.9339358397543747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 219}], {
             RGBColor[
             0.49125780976030897`, 0.5936378228658237, 0.9544300827546521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 251}], {
             RGBColor[
             0.2759596386433615, 0.40698913765266753`, 0.9390412298997809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 258}], {
             RGBColor[
             0.36408500922956, 0.4897738683751677, 0.944420152733743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 272}], {
             RGBColor[
             0.28510804558804614`, 0.41660469339403305`, 0.9395622181414255]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 435}], {
             RGBColor[
             0.2756938897780267, 0.40670981874574946`, 0.9390260958950403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 453}], {
             RGBColor[
             0.27645983051134826`, 0.4075148710199178, 0.9390697150866952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 497}], {
             RGBColor[
             0.3955857304505306, 0.5163830883010493, 0.9466138889234013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 410}], {
             RGBColor[
             0.1815860257697589, 0.30818880467598786`, 0.9336524275839118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 428}], {
             RGBColor[
             0.18434895637471288`, 0.31109281992171267`, 0.9338097723944743]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 437}], {
             RGBColor[
             0.18142173090578886`, 0.3080161203570593, 0.933643071234461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 220}], {
             RGBColor[
             0.20157018632549908`, 0.32919342448903244`, 0.9347904959636448]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 254}], {
             RGBColor[
             0.18926826388068996`, 0.3162633240126051, 0.9340899196794763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 290}], {
             RGBColor[
             0.18381681483281254`, 0.31053350542145297`, 0.9337794677208959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 297}], {
             RGBColor[
             0.1906847748105455, 0.3177521668118635, 0.9341705878813915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 350}], {
             RGBColor[
             0.18381567245253283`, 0.31053230470734794`, 0.9337794026640289]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 377}], {
             RGBColor[
             0.1834493331063201, 0.31014725882722227`, 0.9337585401802126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 412}], {
             RGBColor[
             0.18818134565428368`, 0.3151209040420562, 0.934028021294434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 426}], {
             RGBColor[
             0.18673198964571103`, 0.31359753898256787`, 0.9339454826138758]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 476}], {
             RGBColor[
             0.18476853282621936`, 0.3115338213749295, 0.9338336666526799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.19263264106654965`, 0.3197994977487777, 0.9342815159830611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 260}], {
             RGBColor[
             0.1989228362357199, 0.32641089169298415`, 0.9346397332924354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 292}], {
             RGBColor[
             0.18660739700750423`, 0.31346658422018303`, 0.9339383872474483]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 399}], {
             RGBColor[
             0.19798691924192627`, 0.3254271835919423, 0.9345864342042041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 446}], {
             RGBColor[
             0.1857509853248722, 0.31256644124209987`, 0.9338896158690699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 496}], {
             RGBColor[
             0.18695506079229124`, 0.31383200090115126`, 0.9339581861856694]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 213}], {
             RGBColor[
             0.19710682911621347`, 0.3245021530688812, 0.9345363143735214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 332}], {
             RGBColor[
             0.18931192738265673`, 0.3163092171215981, 0.934092406251319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 337}], {
             RGBColor[
             0.19054105270955757`, 0.3176011057712177, 0.934162403120358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 420}], {
             RGBColor[
             0.19002037884251344`, 0.3170538445243244, 0.9341327515138979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 427}], {
             RGBColor[
             0.18925515066577042`, 0.3162495411922988, 0.9340891729012859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 447}], {
             RGBColor[
             0.2128628663159131, 0.341062747156223, 0.9354335973830761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 454}], {
             RGBColor[
             0.20169424196759916`, 0.3293238148344616, 0.9347975607489386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 489}], {
             RGBColor[
             0.19180860925659354`, 0.31893338806987936`, 0.9342345885905299]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 500}], {
             RGBColor[
             0.1964924261713618, 0.32385637661844546`, 0.9345013250347398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 201}], {
             RGBColor[
             0.2441727010346539, 0.373971368603798, 0.9372166461515588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 236}], {
             RGBColor[
             0.21962655292817068`, 0.3481718106282057, 0.9358187793296664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 289}], {
             RGBColor[
             0.22048333522571711`, 0.34907234314606217`, 0.9358675718140159]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 314}], {
             RGBColor[
             0.24685083225448304`, 0.3767862543191651, 0.9373691617625879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 411}], {
             RGBColor[
             0.25605149674669436`, 0.3864567360563011, 0.937893125994256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 466}], {
             RGBColor[
             0.21288997416386868`, 0.3410912392231611, 0.9354351411349147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 470}], {
             RGBColor[
             0.2127537879512197, 0.3409480988789625, 0.9354273855315738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 493}], {
             RGBColor[
             0.24589919103084765`, 0.37578601905558584`, 0.9373149672027289]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 270}], {
             RGBColor[
             0.1812627552425552, 0.3078490268553615, 0.9336340178056233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 479}], {
             RGBColor[
             0.18236486345397498`, 0.30900741246326024`, 0.9336967812378407]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 244}], {
             RGBColor[
             0.4164279851399622, 0.5351107232742938, 0.9477554008736777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 245}], {
             RGBColor[
             0.31502975887018714`, 0.4412915516820689, 0.9415138332017744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 262}], {
             RGBColor[
             0.36465083425503464`, 0.49026395757304103`, 0.944456206604027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 376}], {
             RGBColor[
             0.3786216036789717, 0.5023647358567669, 0.9453464116778538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 448}], {
             RGBColor[
             0.3433591771132972, 0.47106756644443715`, 0.943127151661101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 455}], {
             RGBColor[
             0.4995894556816295, 0.6028040573199673, 0.9542526889773754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 475}], {
             RGBColor[
             0.3613314497983178, 0.4873888735937467, 0.9442446983616614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 482}], {
             RGBColor[
             0.35925314832548205`, 0.4855887533164457, 0.9441122708295822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 228}], {
             RGBColor[
             0.26059605928059204`, 0.3912333594213344, 0.9381519321074836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 256}], {
             RGBColor[
             0.28726648438606334`, 0.4190057220590618, 0.9396802912272235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 298}], {
             RGBColor[
             0.26933197029652145`, 0.4004153557878257, 0.9386494293162186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 452}], {
             RGBColor[
             0.24489188267224044`, 0.3747272741036509, 0.9372576024818854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 468}], {
             RGBColor[
             0.2422384711696754, 0.37193837037844896`, 0.9371064946221849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 218}], {
             RGBColor[
             0.27166416290138806`, 0.4028666380850924, 0.938782244234896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 235}], {
             RGBColor[
             0.23728480229023638`, 0.36673175030541116`, 0.9368243905077971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 236}], {
             RGBColor[
             0.2329055510975478, 0.36212887964133295`, 0.9365749986308951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 289}], {
             RGBColor[
             0.23376233339509425`, 0.3630294121591895, 0.9366237911152446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 300}], {
             RGBColor[
             0.24465748938560672`, 0.37448091189800614`, 0.9372442541309653]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 305}], {
             RGBColor[
             0.2840031755926752, 0.41566850052882615`, 0.9394910555788545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 314}], {
             RGBColor[
             0.2601298304238602, 0.39074332333229245`, 0.9381253810638166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 406}], {
             RGBColor[
             0.33697692661979073`, 0.46155170113037025`, 0.9428664961514535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 493}], {
             RGBColor[
             0.2591781892002248, 0.38974308806871316`, 0.9380711865039575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 243}], {
             RGBColor[
             0.1916697633639069, 0.3187874522333277, 0.9342266815223454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 273}], {
             RGBColor[
             0.18695948203332297`, 0.31383664790579846`, 0.9339584379688055]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 279}], {
             RGBColor[
             0.19737149140968246`, 0.32478032991987577`, 0.9345513864996016]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 283}], {
             RGBColor[
             0.1845388139830274, 0.3112923723057189, 0.9338205845043986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 285}], {
             RGBColor[
             0.2005739783770007, 0.32814634677192855`, 0.9347337633947355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 396}], {
             RGBColor[
             0.1920993256937792, 0.31923894947784826`, 0.9342511444615511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 421}], {
             RGBColor[
             0.18554846728188248`, 0.31235358193853213`, 0.9338780827661202]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 430}], {
             RGBColor[
             0.19415820437315612`, 0.32140296151032133`, 0.9343683945565036]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 459}], {
             RGBColor[
             0.19062008977227754`, 0.3176841787353756, 0.9341669041641552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 477}], {
             RGBColor[
             0.19227698695572149`, 0.31942568272852423`, 0.9342612620075925]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 264}], {
             RGBColor[
             0.8553074725725389, 0.4148947299646385, 0.20015613150748274`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 281}], {
             RGBColor[
             0.8317474856787275, 0.2450306635294393, 0.1780347341805933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 295}], {
             RGBColor[
             0.9149334778554977, 0.6677110589938393, 0.5462140209685634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 324}], {
             RGBColor[
             0.8924019068162066, 0.6510073815667528, 0.588847136940535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 341}], {
             RGBColor[
             0.9196841878836145, 0.6688261379622193, 0.4057355619852222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 374}], {
             RGBColor[
             0.8462576720826371, 0.35656231463411475`, 0.19192970506788876`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 397}], {
             RGBColor[
             0.8335404053549352, 0.2588118298231834, 0.1797516360873429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 275}], {
             RGBColor[
             0.402607767889131, 0.5221630142088122, 0.9471448284585735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 306}], {
             RGBColor[
             0.2783366060930942, 0.40921806996322074`, 0.9391864591429547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 331}], {
             RGBColor[
             0.3086689498622105, 0.44109928644623464`, 0.9409138412479245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 346}], {
             RGBColor[
             0.3786592419849977, 0.5023973362656904, 0.9453488099574316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 348}], {
             RGBColor[
             0.38899180466367445`, 0.5111089618702334, 0.9460729299565488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 355}], {
             RGBColor[
             0.4378065045945586, 0.5507389343512965, 0.9499158019492457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 390}], {
             RGBColor[
             0.2859084769887601, 0.4171765863589087, 0.9396176659888837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 431}], {
             RGBColor[
             0.36857757870000185`, 0.49366510624735727`, 0.9447064152877764]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 444}], {
             RGBColor[
             0.44088363514258455`, 0.5532370875533353, 0.9501580449378868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 486}], {
             RGBColor[
             0.3646188827036643, 0.4902362827451757, 0.9444541706794272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 230}], {
             RGBColor[
             0.22168982682145016`, 0.35034044230916306`, 0.9359362797255486]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 331}], {
             RGBColor[
             0.26945802412846753`, 0.40054784635747565`, 0.938656607895468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 382}], {
             RGBColor[
             0.22477554462649751`, 0.3535837273680766, 0.9361120067896356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 413}], {
             RGBColor[
             0.2338956489319965, 0.363169535241167, 0.9366313832378486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 474}], {
             RGBColor[
             0.23349741976768085`, 0.3627509711402839, 0.936608704676068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 490}], {
             RGBColor[
             0.22672461704495903`, 0.3556323260582085, 0.9362230035804727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 254}], {
             RGBColor[
             0.18642186112422848`, 0.31327157424320573`, 0.9339278212533714]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 377}], {
             RGBColor[
             0.18060293034985866`, 0.30715550905782296`, 0.9335964417541076]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 396}], {
             RGBColor[
             0.18892633617542332`, 0.3159039363149012, 0.9340704474024981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 476}], {
             RGBColor[
             0.18192213006975788`, 0.30854207160553015`, 0.9336715682265748]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 257}], {
             RGBColor[
             0.9190198138450048, 0.7061284902521469, 0.2641826298296307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 266}], {
             RGBColor[
             0.9342851916423655, 0.7569554226506068, 0.3801831663512317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 281}], {
             RGBColor[
             0.8467054680453859, 0.3339234893640672, 0.19133725700073073`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 293}], {
             RGBColor[
             0.8423679493594973, 0.6882641451078306, 0.5995351479132809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 317}], {
             RGBColor[
             0.8461530053131936, 0.3296770187137239, 0.19080821806446593`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 322}], {
             RGBColor[
             0.8478846282356312, 0.34298703129758157`, 0.19246642213058046`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 343}], {
             RGBColor[
             0.8606088112970214, 0.4407906780799979, 0.2046511142000771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 374}], {
             RGBColor[
             0.8612156544492956, 0.4454551404687426, 0.20523222788802623`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 403}], {
             RGBColor[
             0.8091979496573507, 0.6623514892391787, 0.5962290723342419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 440}], {
             RGBColor[
             0.8833097581290331, 0.5630186900098979, 0.22434314065434907`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 445}], {
             RGBColor[
             0.9190529143682962, 0.7062401460895815, 0.26431121911210875`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 471}], {
             RGBColor[
             0.9159118385486107, 0.7462782372358219, 0.5876734401900829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 238}], {
             RGBColor[
             0.4566518822195865, 0.5690445386024363, 0.9505687908779773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[
             0.42089773296190985`, 0.5389821941816072, 0.9480402092524494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 266}], {
             RGBColor[
             0.7100990368535118, 0.7663088762344812, 0.7456861929885767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 293}], {
             RGBColor[
             0.6181817945706438, 0.697617598691705, 0.965038174550626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 403}], {
             RGBColor[
             0.5850117948684971, 0.6717049428230532, 0.961732098971587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 471}], {
             RGBColor[
             0.6917256837597572, 0.7556316908196963, 0.953176466827428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 483}], {
             RGBColor[
             0.4393277460874472, 0.554945345231554, 0.949214553391788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 497}], {
             RGBColor[
             0.4523984541828804, 0.5655914141074888, 0.9502339454421076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 231}], {
             RGBColor[
             0.8790670260426792, 0.9036392003218177, 0.8591433457844534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 233}], {
             RGBColor[
             0.9785167541303205, 0.9817898472456261, 0.8447367386541516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 259}], {
             RGBColor[
             0.8388746662508497, 0.8722406233791922, 0.8551373469793608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 275}], {
             RGBColor[
             0.7418942375705933, 0.7941342962234403, 0.8470741774102124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 348}], {
             RGBColor[
             0.7282782743451366, 0.7830802438848616, 0.8460022789081878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 355}], {
             RGBColor[
             0.7770929742760209, 0.8227102163659248, 0.8498451509008846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 372}], {
             RGBColor[
             0.8043736512463036, 0.8448578989108925, 0.8519927857243978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 379}], {
             RGBColor[
             0.9109503146879699, 0.6018931108868748, 0.4575519033361274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 400}], {
             RGBColor[
             0.9921722318540724, 0.9910310309542629, 0.7793899060000027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 404}], {
             RGBColor[
             0.9156515263183187, 0.9323554252556073, 0.8627536207565263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 431}], {
             RGBColor[
             0.707864048381464, 0.7656363882619854, 0.8446357642394154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 444}], {
             RGBColor[
             0.7801701048240467, 0.8252083695679635, 0.8500873938895259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 486}], {
             RGBColor[
             0.7039053523851265, 0.7622075647598039, 0.8443835196310663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 225}], {
             RGBColor[
             0.189744388344664, 0.31676376101227643`, 0.9341170342633367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 252}], {
             RGBColor[
             0.1889152618740288, 0.3158922965219843, 0.9340698167374166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 280}], {
             RGBColor[
             0.22449871038575198`, 0.3532927570287484, 0.9360962414891647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 309}], {
             RGBColor[
             0.1918597924354573, 0.31898718483606625`, 0.9342375033968474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 320}], {
             RGBColor[
             0.18833104309187587`, 0.31527824554033135`, 0.9340365463420472]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 393}], {
             RGBColor[
             0.20841975513223648`, 0.336392755592659, 0.9351805687741597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 424}], {
             RGBColor[
             0.19449774707264864`, 0.3217598424157385, 0.9343877310109313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 480}], {
             RGBColor[
             0.21944240212988145`, 0.3479782564633687, 0.9358082922141305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 236}], {
             RGBColor[
             0.1979212488225095, 0.32535815981739014`, 0.934582694370969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 289}], {
             RGBColor[
             0.19877803112005593`, 0.32625869233524674`, 0.9346314868553184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 308}], {
             RGBColor[
             0.18919374524082816`, 0.3161850001973557, 0.9340856759531767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 362}], {
             RGBColor[
             0.1833599948775373, 0.31005335868440065`, 0.9337534525002475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 369}], {
             RGBColor[
             0.1847549864301014, 0.3115195832537184, 0.933832895205461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 466}], {
             RGBColor[
             0.1911846700582075, 0.3182775884123456, 0.9341990561762171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 470}], {
             RGBColor[
             0.19104848384555853`, 0.31813444806814695`, 0.9341913005728761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 216}], {
             RGBColor[
             0.19093042363498117`, 0.31801035930138044`, 0.9341845772185382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 217}], {
             RGBColor[
             0.18159408433829743`, 0.30819727474246456`, 0.9336528865074684]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 224}], {
             RGBColor[
             0.19394001881557005`, 0.321173634655535, 0.9343559692117758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 286}], {
             RGBColor[
             0.18467080520712215`, 0.3114311034509694, 0.9338281012093472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 319}], {
             RGBColor[
             0.18140430286516612`, 0.3079978023813632, 0.93364207873333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 330}], {
             RGBColor[
             0.18576322285580926`, 0.312579303663019, 0.9338903127783529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 357}], {
             RGBColor[
             0.18524504165765288`, 0.3120346623691711, 0.9338608031256983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 492}], {
             RGBColor[
             0.18227723304689475`, 0.30891530734933015`, 0.933691790815795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 251}], {
             RGBColor[
             0.22057376513923174`, 0.3491673907187537, 0.9358727216638114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 332}], {
             RGBColor[
             0.19442260484216423`, 0.3216808631672068, 0.9343834517720682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 337}], {
             RGBColor[
             0.19565173016906506`, 0.3229727518168264, 0.9344534486411072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 420}], {
             RGBColor[
             0.19513105630202093`, 0.32242549056993314`, 0.9344237970346471]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 447}], {
             RGBColor[
             0.2179735437754206, 0.34643439320183167`, 0.9357246429038253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 454}], {
             RGBColor[
             0.20680491942710666`, 0.3346954608800703, 0.9350886062696878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 489}], {
             RGBColor[
             0.19691928671610104`, 0.3243050341154881, 0.9345256341112791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 500}], {
             RGBColor[
             0.2016031036308693, 0.32922802266405415`, 0.934792370555489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 223}], {
             RGBColor[
             0.1978649215993461, 0.32529895633449324`, 0.9345794866189384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 268}], {
             RGBColor[
             0.186923339851059, 0.31379866018069236`, 0.9339563797249931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 466}], {
             RGBColor[
             0.1912157031774699, 0.31831020618830375`, 0.9342008234664497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 470}], {
             RGBColor[
             0.19107951696482092`, 0.31816706584410515`, 0.9341930678631087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 491}], {
             RGBColor[
             0.1845859949601158, 0.3113419625040855, 0.9338232713912458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 402}], {
             RGBColor[
             0.2015459552318014, 0.3291679560732161, 0.9347891160387054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 417}], {
             RGBColor[
             0.1910469226092748, 0.31813280710982467`, 0.9341912116627795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 217}], {
             RGBColor[
             0.1905787639681844, 0.31764074269506637`, 0.9341645507207481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 224}], {
             RGBColor[
             0.20292469844545702`, 0.3306171026081368, 0.9348676334250554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 292}], {
             RGBColor[
             0.19251751538449438`, 0.3196784933575477, 0.9342749597457812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 358}], {
             RGBColor[
             0.21239908038802668`, 0.34057527874028815`, 0.9354071854605928]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 361}], {
             RGBColor[
             0.21500792746091607`, 0.34331734242435297`, 0.9355557554419504]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 398}], {
             RGBColor[
             0.20308712437898663`, 0.33078782256267547`, 0.9348768833416823]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 399}], {
             RGBColor[
             0.20389703761891642`, 0.33163909272930703`, 0.934923006702537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 464}], {
             RGBColor[
             0.20118455785762748`, 0.32878810451904233`, 0.9347685349928858]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 481}], {
             RGBColor[
             0.20259193459855807`, 0.33026734670659963`, 0.9348486830162546]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 292}], {
             RGBColor[
             0.18318117608781065`, 0.30986540879863184`, 0.9337432690347114]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 398}], {
             RGBColor[
             0.1937507850823029, 0.3209747380037596, 0.9343451926306123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 464}], {
             RGBColor[
             0.19184821856094375`, 0.31897501996012645`, 0.9342368442818159]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 481}], {
             RGBColor[
             0.19325559530187433`, 0.3204542621476837, 0.9343169923051846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 496}], {
             RGBColor[
             0.1835288398725976, 0.31023082547960007`, 0.9337630679729325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 235}], {
             RGBColor[
             0.2514972659875934, 0.38166995077357824`, 0.9376337692899057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 274}], {
             RGBColor[
             0.26498050169023135`, 0.3958416863835701, 0.9384016196165113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.25886995308296373`, 0.3894191123661732, 0.938053632913074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 305}], {
             RGBColor[
             0.29821563929003225`, 0.43060670099699316`, 0.9403004343609631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 310}], {
             RGBColor[
             0.4653446361758491, 0.5701283226319324, 0.9524120897475179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 314}], {
             RGBColor[
             0.27434229412121725`, 0.4056815238004595, 0.9389347598459252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 406}], {
             RGBColor[
             0.35118939031714774`, 0.4764899015985373, 0.9436758749335621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 432}], {
             RGBColor[
             0.28855483307734864`, 0.4206198033703701, 0.9397441429139097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 493}], {
             RGBColor[
             0.2733906528975818, 0.4046812885368802, 0.9388805652860661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 238}], {
             RGBColor[
             0.5781077146635654, 0.6679567426795029, 0.9602144407477138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 258}], {
             RGBColor[
             0.5423535654058886, 0.6378943982586738, 0.9576858591221857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 293}], {
             RGBColor[
             0.7396376270146225, 0.7965298027687717, 0.9746838244203624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 403}], {
             RGBColor[
             0.7064676273124759, 0.7706171469001197, 0.9713777488413233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 445}], {
             RGBColor[
             0.8163225920234214, 0.8145058037505225, 0.6394598956191903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 471}], {
             RGBColor[
             0.8131815162037359, 0.854543894896763, 0.9628221166971644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 497}], {
             RGBColor[
             0.5738542866268592, 0.6645036181845554, 0.959879595311844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 254}], {
             RGBColor[
             0.20473141614653206`, 0.3325160774644852, 0.9349705233253323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 297}], {
             RGBColor[
             0.20614792707638763`, 0.3340049202637436, 0.9350511915272475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 325}], {
             RGBColor[
             0.22533443478540557`, 0.3541711563607717, 0.9361438347573814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 392}], {
             RGBColor[
             0.22694196327999852`, 0.35586077073178224`, 0.9362353811270232]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 412}], {
             RGBColor[
             0.2036444979201258, 0.3313736574939363, 0.9349086249402898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 413}], {
             RGBColor[
             0.2236716605546839, 0.35242347521830786`, 0.9360491422247958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 426}], {
             RGBColor[
             0.20219514191155313`, 0.32985029243444797`, 0.9348260862597317]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 474}], {
             RGBColor[
             0.22327343139036823`, 0.3520049111174247, 0.9360264636630153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 490}], {
             RGBColor[
             0.2165006286676464, 0.34488626603534933`, 0.9356407625674201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 234}], {
             RGBColor[
             0.9443267569423743, 0.8151145515040961, 0.2837836064703105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 301}], {
             RGBColor[
             0.8093616863432395, 0.8079745679423065, 0.6371695161143949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 336}], {
             RGBColor[
             0.7938129054109903, 0.7955671950703103, 0.6357978963718616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 294}], {
             RGBColor[
             0.19229714625130181`, 0.3194468714263523, 0.9342624100496528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 296}], {
             RGBColor[
             0.18966575842362554`, 0.31668111597984006`, 0.934112556405656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 339}], {
             RGBColor[
             0.1886442457825459, 0.3156074414264231, 0.9340543827719392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 344}], {
             RGBColor[
             0.1936890488951341, 0.3209098493567448, 0.9343416768460837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 438}], {
             RGBColor[
             0.19987204711910306`, 0.3274085725148659, 0.9346937894480125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 439}], {
             RGBColor[
             0.19816628717948753`, 0.32561571066690326`, 0.9345966489428971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 246}], {
             RGBColor[
             0.22404185527291065`, 0.35281257333886495`, 0.9360702242663449]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 268}], {
             RGBColor[
             0.19724310055792588`, 0.32464538299422946`, 0.9345440748305314]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 411}], {
             RGBColor[
             0.24469698646716248`, 0.3745224258349809, 0.9372465034313293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 286}], {
             RGBColor[
             0.19666508001759797`, 0.3240378467577258, 0.9345111574158644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 330}], {
             RGBColor[
             0.1977574976662851, 0.3251860469697754, 0.9345733689848701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 333}], {
             RGBColor[
             0.21886126221320776`, 0.3473674415645458, 0.9357751971555954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 358}], {
             RGBColor[
             0.21540867556861554`, 0.34373855409444265`, 0.9355785774538301]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 361}], {
             RGBColor[
             0.21801752264150492`, 0.34648061777850747`, 0.9357271474351878]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 398}], {
             RGBColor[
             0.2060967195595755, 0.33395109791683003`, 0.9350482753349197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 441}], {
             RGBColor[
             0.21370093658000952`, 0.34194361214051205`, 0.9354813242448025]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 464}], {
             RGBColor[
             0.20419415303821636`, 0.3319513798731969, 0.9349399269861233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 481}], {
             RGBColor[
             0.20560152977914695`, 0.33343062206075413`, 0.9350200750094919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 247}], {
             RGBColor[
             0.18412221385498584`, 0.31085449915717356`, 0.9337968597434113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 252}], {
             RGBColor[
             0.18313599846224066`, 0.30981792424973087`, 0.9337406962357694]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 309}], {
             RGBColor[
             0.18608052902366917`, 0.31291281256381276`, 0.9339083828952002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 320}], {
             RGBColor[
             0.1825517796800877, 0.30920387326807797`, 0.9337074258404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 424}], {
             RGBColor[
             0.18871848366086047`, 0.31568547014348514`, 0.9340586105092841]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 284}], {
             RGBColor[
             0.19690493413279425`, 0.3242899486404264, 0.9345248167528926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 345}], {
             RGBColor[
             0.18891037080707027`, 0.3158871557004993, 0.9340695381983891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 366}], {
             RGBColor[
             0.18476826025973897`, 0.3115335348902769, 0.9338336511304219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 389}], {
             RGBColor[
             0.19095055240575043`, 0.3180315159156967, 0.9341857235222557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 405}], {
             RGBColor[
             0.18431945622850954`, 0.3110618133976357, 0.9338080924047896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 429}], {
             RGBColor[
             0.18946440368264025`, 0.31646947938043657`, 0.9341010895510347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 472}], {
             RGBColor[
             0.18505776823943543`, 0.311837826132804, 0.933850138181577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 488}], {
             RGBColor[
             0.18475420080410804`, 0.31151875751098784`, 0.9338328504652229]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 229}], {
             RGBColor[
             0.21399982241481183`, 0.34225776010334574`, 0.9354983453509325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 263}], {
             RGBColor[
             0.2087485483203887, 0.3367383380800992, 0.935199293059819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 265}], {
             RGBColor[
             0.18874076831201309`, 0.315708892724775, 0.9340598795871999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 267}], {
             RGBColor[
             0.2112079223469873, 0.3393232961153739, 0.935339350772316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 270}], {
             RGBColor[
             0.18663641062037617`, 0.3134970793668807, 0.9339400395297794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 329}], {
             RGBColor[
             0.18736891797604732`, 0.31426699104133987`, 0.9339817547400375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 424}], {
             RGBColor[
             0.19331536997885967`, 0.3205170891231287, 0.9343203963846103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 256}], {
             RGBColor[
             0.28488710481113977`, 0.4165048432644388, 0.9395447890804083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 279}], {
             RGBColor[
             0.23309972747079383`, 0.36233297132110764`, 0.9365860566880932]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 287}], {
             RGBColor[
             0.28118525934636124`, 0.41287391412114016`, 0.9393244565922372]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 298}], {
             RGBColor[
             0.2669525907215979, 0.3979144769932027, 0.9385139271694034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 318}], {
             RGBColor[
             0.22809876360932468`, 0.35707664122328114`, 0.9363012591944456]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 335}], {
             RGBColor[
             0.2342958788041693, 0.36359020221286015`, 0.9366541757369817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 409}], {
             RGBColor[
             0.2557251463437433, 0.3861137210909889, 0.9378745408216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 468}], {
             RGBColor[
             0.23985909159475186`, 0.369437491583826, 0.9369709924753695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 232}], {
             RGBColor[
             0.2566501782178637, 0.3870859882410977, 0.9379272200183691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 263}], {
             RGBColor[
             0.22958947316632627`, 0.3586434714841348, 0.9363861528984097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 267}], {
             RGBColor[
             0.23204884719292487`, 0.3612284295194095, 0.9365262106109067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 280}], {
             RGBColor[
             0.24415725813790062`, 0.37395513714017414`, 0.9372157667014342]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 393}], {
             RGBColor[
             0.2280783028843851, 0.35705513570408476`, 0.9363000939864292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 480}], {
             RGBColor[
             0.23910094988203007`, 0.36864063657479446`, 0.9369278174264002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 485}], {
             RGBColor[
             0.2450928096239232, 0.3749384610693741, 0.9372690449745389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 382}], {
             RGBColor[
             0.20898405610198123`, 0.3369858716906088, 0.9352127048795782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 413}], {
             RGBColor[
             0.21810416040748024`, 0.34657167956369916`, 0.9357320813277911]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 474}], {
             RGBColor[
             0.21770593124316456`, 0.3461531154628161, 0.9357094027660106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 484}], {
             RGBColor[
             0.19535510076833423`, 0.3226609755092681, 0.9344365560355595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 490}], {
             RGBColor[
             0.21093312852044277`, 0.33903447038074064`, 0.9353237016704152]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 233}], {
             RGBColor[
             0.8631076739966228, 0.8934453053740385, 0.9626713381948079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 275}], {
             RGBColor[
             0.6264851574368956, 0.7057897543518528, 0.9650087769508688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 326}], {
             RGBColor[
             0.7445199877539495, 0.8003439400856498, 0.9751704525106033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 346}], {
             RGBColor[
             0.6025366315327623, 0.6860240764087309, 0.963212758449727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 355}], {
             RGBColor[
             0.6616838941423232, 0.7343656744943371, 0.9677797504415411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 395}], {
             RGBColor[
             0.6338994865668826, 0.711809040751297, 0.9655924600995638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 404}], {
             RGBColor[
             0.8002424461846211, 0.8440108833840196, 0.9806882202971826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 431}], {
             RGBColor[
             0.5924549682477664, 0.6772918463903979, 0.9625703637800718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 444}], {
             RGBColor[
             0.664761024690349, 0.7368638276963759, 0.9680219934301821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 486}], {
             RGBColor[
             0.5884962722514289, 0.6738630228882163, 0.9623181191717225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 267}], {
             RGBColor[
             0.25385827815003914`, 0.3841515242531258, 0.9377682254397526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 280}], {
             RGBColor[
             0.26596668909501486`, 0.3968782318738905, 0.9384577815302801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 338}], {
             RGBColor[
             0.351395977443279, 0.47598308304576464`, 0.9437141472934822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 383}], {
             RGBColor[
             0.2731170371748888, 0.40439370106409095`, 0.938864983275437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 393}], {
             RGBColor[
             0.24988773384149937`, 0.3799782304378011, 0.9375421088152751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 395}], {
             RGBColor[
             0.3913003181998807, 0.5091662530135891, 0.9466381048606165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 480}], {
             RGBColor[
             0.2609103808391443, 0.3915637313085108, 0.9381698322552461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 259}], {
             RGBColor[
             0.8229153142047934, 0.8620467284314131, 0.9586653393897153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 275}], {
             RGBColor[
             0.7259348855245369, 0.7839404012756612, 0.9506021698205669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 326}], {
             RGBColor[
             0.8439697158415906, 0.8784945870094583, 0.9607638453803016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 346}], {
             RGBColor[
             0.7019863596204035, 0.7641747233325396, 0.948806151319425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 348}], {
             RGBColor[
             0.7123189222990802, 0.7728863489370825, 0.9495302713185423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 355}], {
             RGBColor[
             0.7611336222299645, 0.8125163214181457, 0.9533731433112391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 379}], {
             RGBColor[
             0.8949909626419136, 0.5916992159390957, 0.5610798957464819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 400}], {
             RGBColor[
             0.9762128798080161, 0.9808371360064839, 0.8829178984103572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 404}], {
             RGBColor[
             0.8996921742722623, 0.9221615303078283, 0.9662816131668808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 431}], {
             RGBColor[
             0.6919046963354076, 0.7554424933142063, 0.9481637566497699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 444}], {
             RGBColor[
             0.7642107527779903, 0.8150144746201845, 0.9536153862998804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 486}], {
             RGBColor[
             0.6879460003390702, 0.7520136698120249, 0.9479115120414208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 336}], {
             RGBColor[
             0.7758644491107505, 0.7262741691289183, 0.6116347463560659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 449}], {
             RGBColor[
             0.9549924747052941, 0.851092521948047, 0.32521790592745947`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 274}], {
             RGBColor[
             0.23060114107907964`, 0.35970679860388893`, 0.9364437658894125]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 284}], {
             RGBColor[
             0.2119740420649528, 0.3401285365137513, 0.9353829801568815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 300}], {
             RGBColor[
             0.22449059247181202`, 0.353284224586492, 0.9360957791859752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 305}], {
             RGBColor[
             0.2638362786788805, 0.394471813217312, 0.9383425806338642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 308}], {
             RGBColor[
             0.2040111506020718, 0.33175903270978435`, 0.9349295052681127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 345}], {
             RGBColor[
             0.20397947873922884`, 0.3317257435738243, 0.934927701602378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 389}], {
             RGBColor[
             0.20601966033790897`, 0.3338701037890217, 0.9350438869262447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 432}], {
             RGBColor[
             0.25417547246619693`, 0.38448491559068887`, 0.9377862891868108]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 456}], {
             RGBColor[
             0.20636469541016642`, 0.3342327575264513, 0.9350635361631761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 289}], {
             RGBColor[
             0.20921618528861102`, 0.33722985418359713`, 0.9352259242933523]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 300}], {
             RGBColor[
             0.22011134127912346`, 0.34868135392241384`, 0.9358463873090731]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 308}], {
             RGBColor[
             0.19963189940938322`, 0.3271561620457061, 0.9346801133912106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 314}], {
             RGBColor[
             0.23558368231737692`, 0.3649437653567001, 0.9367275142419242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 466}], {
             RGBColor[
             0.2016228242267626, 0.329248750260696, 0.934793493614251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 470}], {
             RGBColor[
             0.2014866380141136, 0.3291056099164974, 0.9347857380109101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 493}], {
             RGBColor[
             0.23463204109374153`, 0.36394353009312075`, 0.9366733196820654]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 241}], {
             RGBColor[
             0.2242600552960576, 0.35304191539787294`, 0.9360826504348652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 274}], {
             RGBColor[
             0.23848727143504053`, 0.36799562161754756`, 0.9368928693467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 284}], {
             RGBColor[
             0.21986017242091369`, 0.34841735952740993`, 0.9358320836141691]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 351}], {
             RGBColor[
             0.2365402762573613, 0.3659492062391825, 0.9367819908516525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 371}], {
             RGBColor[
             0.24348618176994377`, 0.3732497933287522, 0.9371775498950476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 429}], {
             RGBColor[
             0.2124196419707597, 0.3405968902674201, 0.9354083564123112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 432}], {
             RGBColor[
             0.26206160282215785`, 0.3927737386043475, 0.9382353926440985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 460}], {
             RGBColor[
             0.26678188416083737`, 0.3977350535744224, 0.9385042056833057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 258}], {
             RGBColor[
             0.4509349141328164, 0.5640927881888469, 0.9502045107268047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 266}], {
             RGBColor[
             0.7401362180244184, 0.7914194702417209, 0.7478504944629321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 293}], {
             RGBColor[
             0.6482189757415503, 0.7227281926989446, 0.9672024760249813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 403}], {
             RGBColor[
             0.6150489760394036, 0.6968155368302928, 0.9638964004459423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 445}], {
             RGBColor[
             0.7249039407503491, 0.7407041936806955, 0.6319785472238091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 471}], {
             RGBColor[
             0.7217628649306637, 0.780742284826936, 0.9553407683017833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 483}], {
             RGBColor[
             0.46936492725835366`, 0.5800559392387936, 0.9513788548661433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 497}], {
             RGBColor[
             0.4824356353537869, 0.5907020081147285, 0.9523982469164629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 251}], {
             RGBColor[
             0.2177871872756262, 0.3462385207048633, 0.9357140301768516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 272}], {
             RGBColor[
             0.22693559422031087`, 0.3558540764462288, 0.9362350184184962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 332}], {
             RGBColor[
             0.1916360269785587, 0.31875199315331637`, 0.9342247602851084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 387}], {
             RGBColor[
             0.1927675658632359, 0.3199413122648211, 0.934289199750629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 435}], {
             RGBColor[
             0.21752143841029148`, 0.3459592017979452, 0.9356988961721111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 453}], {
             RGBColor[
             0.21828737914361301`, 0.34676425407211353`, 0.935742515363766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 454}], {
             RGBColor[
             0.20401834156350113`, 0.3317665908661798, 0.9349299147827279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 489}], {
             RGBColor[
             0.1941327088524955, 0.32137616410159764`, 0.9343669426243193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 434}], {
             RGBColor[
             0.9649429424873008, 0.8858096572696792, 0.4713319778660402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 495}], {
             RGBColor[
             0.9404490296531263, 0.7834756918464549, 0.4513533807985771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 271}], {
             RGBColor[
             0.2118628562397169, 0.3400116731618399, 0.935376648288619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 304}], {
             RGBColor[
             0.20316948858682138`, 0.3308743925673022, 0.9348815738614715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 311}], {
             RGBColor[
             0.2028072709740812, 0.33049367889038916`, 0.934860946104279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 351}], {
             RGBColor[
             0.22791016546505544`, 0.3568784126158412, 0.9362905188091355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 371}], {
             RGBColor[
             0.2348560709776379, 0.3641789997054109, 0.9366860778525307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 429}], {
             RGBColor[
             0.20378953117845383`, 0.33152609664407884`, 0.9349168843697941]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 442}], {
             RGBColor[
             0.22676711964941848`, 0.35567699899031613`, 0.9362254240409197]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 249}], {
             RGBColor[
             0.8500313217686346, 0.8830430785885436, 0.951908121903962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 269}], {
             RGBColor[
             0.787493374586991, 0.8335677780907182, 0.9460989448159113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 282}], {
             RGBColor[
             0.8349131599958114, 0.8712326557093291, 0.9504012848257013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 310}], {
             RGBColor[
             0.8089627721429287, 0.8509600154884045, 0.9478147926846883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 323}], {
             RGBColor[
             0.9829115082024764, 0.98536084245597, 0.8504363857845441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 419}], {
             RGBColor[
             0.8111996093173061, 0.8527074496896203, 0.9480377397097984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 449}], {
             RGBColor[
             0.9783597736506789, 0.9679158712997968, 0.6606061921458748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 499}], {
             RGBColor[
             0.8008428775112291, 0.844405505952868, 0.9471498665869478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 273}], {
             RGBColor[
             0.1918690378137841, 0.3189969023148785, 0.9342380299074659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 279}], {
             RGBColor[
             0.20228104719014361`, 0.3299405843289558, 0.934830978438262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 283}], {
             RGBColor[
             0.18944836976348856`, 0.3164526267147989, 0.934100176443059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 285}], {
             RGBColor[
             0.20548353415746184`, 0.3333066011810086, 0.9350133553333959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 318}], {
             RGBColor[
             0.19728008332867447`, 0.3246842542311293, 0.9345461809446143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 335}], {
             RGBColor[
             0.2034771985235191, 0.3311978152207083, 0.9348990974871504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 396}], {
             RGBColor[
             0.19700888147424034`, 0.32439920388692833`, 0.9345307364002116]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 421}], {
             RGBColor[
             0.1904580230623436, 0.31751383634761216`, 0.9341576747047806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 430}], {
             RGBColor[
             0.19906776015361727`, 0.3265632159194014, 0.934647986495164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 459}], {
             RGBColor[
             0.19552964555273866`, 0.32284443314445566`, 0.9344464961028154]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 477}], {
             RGBColor[
             0.19718654273618264`, 0.32458593713760425`, 0.9345408539462529]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 261}], {
             RGBColor[
             0.388007213318593, 0.5104940791921502, 0.9459444544247217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 262}], {
             RGBColor[
             0.3949445171400494, 0.5165028230832673, 0.9463864932898081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 295}], {
             RGBColor[
             0.7157587889214511, 0.7746651605070033, 0.9256601695039643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 341}], {
             RGBColor[
             0.7205094989495678, 0.7757802394753833, 0.7851817105206231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 376}], {
             RGBColor[
             0.40891528656398646`, 0.5286036013669932, 0.947276698363635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 391}], {
             RGBColor[
             0.45991819988990085`, 0.5722422337278446, 0.9506750794005083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 407}], {
             RGBColor[
             0.361925627233212, 0.4849803667690406, 0.9443895897897958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 448}], {
             RGBColor[
             0.373652859998312, 0.49730643195466345`, 0.9450574383468822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 455}], {
             RGBColor[
             0.5298831385666443, 0.6290429228301937, 0.9561829756631566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 475}], {
             RGBColor[
             0.39162513268333266`, 0.5136277391039731, 0.9461749850474426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 478}], {
             RGBColor[
             0.34801769220506096`, 0.4703622452404419, 0.9435975534648887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 482}], {
             RGBColor[
             0.3895468312104969, 0.511827618826672, 0.9460425575153633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 262}], {
             RGBColor[
             0.2935462908702744, 0.4226836514910424, 0.9401449256179049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 299}], {
             RGBColor[
             0.24199930981785328`, 0.3716869966339784, 0.9370928747370061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 376}], {
             RGBColor[
             0.30751706029421144`, 0.43478442977476833`, 0.9410351306917317]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 438}], {
             RGBColor[
             0.22328352119424416`, 0.3520155161410289, 0.9360270382624196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 448}], {
             RGBColor[
             0.272254633728537, 0.40348726036243854`, 0.9388158706749788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 475}], {
             RGBColor[
             0.2902269064135576, 0.4198085675117481, 0.9399334173755393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 482}], {
             RGBColor[
             0.2881486049407218, 0.4180084472344471, 0.93980098984346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 384}], {
             RGBColor[
             0.2539870125967417, 0.38428683231884564`, 0.9377755566760467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 402}], {
             RGBColor[
             0.22901412567720097`, 0.3580387447939263, 0.9363533877100543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 411}], {
             RGBColor[
             0.2605541594338602, 0.3911893200258155, 0.9381495459731974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 458}], {
             RGBColor[
             0.2394606076875042, 0.3690186597319697, 0.9369482994063559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 252}], {
             RGBColor[
             0.18329308738435063`, 0.3099830346668814, 0.9337496422174913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 278}], {
             RGBColor[
             0.18437169562717964`, 0.3111167203178072, 0.9338110673612625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 309}], {
             RGBColor[
             0.18623761794577917`, 0.3130779229809633, 0.933917328876922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 401}], {
             RGBColor[
             0.1825033131056717, 0.3091529318254084, 0.9337046657406869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 451}], {
             RGBColor[
             0.19468301666075716`, 0.32195457249961096`, 0.9343982818398924]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 339}], {
             RGBColor[
             0.18022958629127006`, 0.30676310078086577`, 0.933575180362284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 344}], {
             RGBColor[
             0.18527438940385826`, 0.31206550871118754`, 0.9338624744364286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 387}], {
             RGBColor[
             0.18458186461527748`, 0.3113376212497815, 0.9338230361742175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 439}], {
             RGBColor[
             0.18975162768821172`, 0.3167713700213459, 0.934117446533242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 269}], {
             RGBColor[
             0.6644117978227214, 0.7371426324130581, 0.9676100378285277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 282}], {
             RGBColor[
             0.7118315832315418, 0.7748075100316689, 0.9719123778383179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 310}], {
             RGBColor[
             0.685881195378659, 0.7545348698107444, 0.9693258856973048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 323}], {
             RGBColor[
             0.8598299314382067, 0.8889356967783099, 0.8719474787971606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 406}], {
             RGBColor[
             0.5717259495199576, 0.6608964487773493, 0.960589670883349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 419}], {
             RGBColor[
             0.6881180325530365, 0.7562823040119602, 0.9695488327224149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 499}], {
             RGBColor[
             0.6777613007469594, 0.7479803602752079, 0.9686609595995643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 263}], {
             RGBColor[
             0.22198989446995654`, 0.350655832433131, 0.9359533681342207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 365}], {
             RGBColor[
             0.21334264494811753`, 0.3415670249183921, 0.9354609200664112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 485}], {
             RGBColor[
             0.23749323092755345`, 0.3669508220183703, 0.9368362602103498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 258}], {
             RGBColor[
             0.3270553942889411, 0.45124571304551764`, 0.9422970062673146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 272}], {
             RGBColor[
             0.24807843064742718`, 0.378076538064383, 0.937439071674997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 435}], {
             RGBColor[
             0.2386642748374078, 0.3681816634160995, 0.9369029494286119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 447}], {
             RGBColor[
             0.23632980233893142`, 0.3657279848060955, 0.9367700046733661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 453}], {
             RGBColor[
             0.23943021557072935`, 0.3689867156902678, 0.9369465686202667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 454}], {
             RGBColor[
             0.22516117799061744`, 0.3539890524843341, 0.9361339680392287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 309}], {
             RGBColor[
             0.18525140255303396`, 0.3120413480735207, 0.9338611653692801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 320}], {
             RGBColor[
             0.18172265320945252`, 0.3083324087777858, 0.93366020831448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 424}], {
             RGBColor[
             0.1878893571902253, 0.31481400565319295`, 0.934011392983364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 287}], {
             RGBColor[
             0.340823165506129, 0.46920105185432204`, 0.9429534744527581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 301}], {
             RGBColor[
             0.5169703257345344, 0.6164641572661, 0.9558333707121969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 336}], {
             RGBColor[
             0.5014215448022852, 0.6040567843941038, 0.9544617509696633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 354}], {
             RGBColor[
             0.34404011319445926`, 0.47241198691533204`, 0.9431429096833921]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 388}], {
             RGBColor[
             0.3530902196198862, 0.48025073422946185`, 0.9437195744621254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 436}], {
             RGBColor[
             0.36650668927910635`, 0.49187140591690626`, 0.9445744600450926]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 473}], {
             RGBColor[
             0.32054318862790937`, 0.44788551033051344`, 0.9417985597710807]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 350}], {
             RGBColor[
             0.18697690227356584`, 0.31385495768280075`, 0.9339594300257164]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 377}], {
             RGBColor[
             0.18661056292735312`, 0.3134699118026751, 0.9339385675419001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 412}], {
             RGBColor[
             0.19134257547531666`, 0.31844355701750904`, 0.9342080486561213]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 426}], {
             RGBColor[
             0.189893219466744, 0.3169201919580207, 0.9341255099755632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 476}], {
             RGBColor[
             0.18792976264725234`, 0.31485647435038233`, 0.9340136940143672]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 260}], {
             RGBColor[
             0.2034606107913817, 0.33118038046250897`, 0.9348981528403446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 299}], {
             RGBColor[
             0.21862190988624552`, 0.3471158670930945, 0.935761566394665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 312}], {
             RGBColor[
             0.19606964847691927`, 0.3234120104559323, 0.9344772484704849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 327}], {
             RGBColor[
             0.19047479361502342`, 0.3175314632617931, 0.9341586297629458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 334}], {
             RGBColor[
             0.19201279446501912`, 0.3191479996700246, 0.9342462166360848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 385}], {
             RGBColor[
             0.1893629494279947, 0.3163628445262328, 0.9340953118813207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 446}], {
             RGBColor[
             0.19028875988053398`, 0.31733593001162463`, 0.9341480354169789]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 478}], {
             RGBColor[
             0.22324206600367816`, 0.3519719441073331, 0.9360246774506443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 287}], {
             RGBColor[
             0.30785568445183253`, 0.44064627675886753`, 0.9408528157119771]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 298}], {
             RGBColor[
             0.2936230158270692, 0.42568683963093007`, 0.9400422862891433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 409}], {
             RGBColor[
             0.2823955714492146, 0.41388608372871627`, 0.93940289994134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 281}], {
             RGBColor[
             0.8907382712640035, 0.5148249421887663, 0.2381214507014296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 317}], {
             RGBColor[
             0.8901858085318111, 0.510578471538423, 0.23759241176516477`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 322}], {
             RGBColor[
             0.8919174314542486, 0.5238884841222806, 0.23925061583127932`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 324}], {
             RGBColor[
             0.9513926924014826, 0.9208016602260798, 0.6489338534613713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 326}], {
             RGBColor[
             0.8442173233312698, 0.8362115823989578, 0.6421148916132133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 343}], {
             RGBColor[
             0.9046416145156388, 0.621692130904697, 0.25143530790077595`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 374}], {
             RGBColor[
             0.9052484576679132, 0.6263565932934416, 0.25201642158872506`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 445}], {
             RGBColor[
             0.9630857175869136, 0.8871415989142806, 0.3110954128128076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 272}], {
             RGBColor[
             0.33620380123362575`, 0.46086126878688316`, 0.9428179945089592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 293}], {
             RGBColor[
             0.6124648264838737, 0.6926658482781156, 0.9646738943994533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 403}], {
             RGBColor[
             0.5792948267817268, 0.6667531924094637, 0.9613678188204143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 435}], {
             RGBColor[
             0.32678964542360633`, 0.4509663941385996, 0.942281872262574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 453}], {
             RGBColor[
             0.3275555861569279, 0.45177144641276795`, 0.942325491454229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 471}], {
             RGBColor[
             0.686008715672987, 0.7506799404061069, 0.9528121866762553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 497}], {
             RGBColor[
             0.44668148609611025`, 0.5606396636938994, 0.9498696652909349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 275}], {
             RGBColor[
             0.586292797645066, 0.6743911774092273, 0.9610027781457763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 331}], {
             RGBColor[
             0.4923539796181456, 0.5933274496466499, 0.9547717909351274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 348}], {
             RGBColor[
             0.5726768344196096, 0.6633371250706486, 0.9599308796437516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 372}], {
             RGBColor[
             0.6487722113207766, 0.7251147800966794, 0.9659213864599616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 400}], {
             RGBColor[
             0.8365707919285453, 0.8712879121400499, 0.8933185067355665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 404}], {
             RGBColor[
             0.7600500863927916, 0.8126123064413943, 0.97668222149209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 418}], {
             RGBColor[
             0.5798892585592409, 0.6691924959032061, 0.9604986680920036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 431}], {
             RGBColor[
             0.552262608455937, 0.6458932694477724, 0.9585643649749793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 444}], {
             RGBColor[
             0.6245686648985196, 0.7054652507537504, 0.9640159946250897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 486}], {
             RGBColor[
             0.5483039124595994, 0.6424644459455908, 0.95831212036663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 299}], {
             RGBColor[
             0.2249121050554158, 0.35372726103730096`, 0.9361197837040394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 312}], {
             RGBColor[
             0.2023598436460895, 0.3300234044001388, 0.9348354657798592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 328}], {
             RGBColor[
             0.2263686482084435, 0.35525818024130285`, 0.9362027316818419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 334}], {
             RGBColor[
             0.19830298963418935`, 0.3257593936142311, 0.9346044339454591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 399}], {
             RGBColor[
             0.20881488896675832`, 0.33680806630567356`, 0.9352030710614876]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 407}], {
             RGBColor[
             0.24344019620099944`, 0.3732014595801383, 0.9371749310849259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 446}], {
             RGBColor[
             0.19657895504970424`, 0.32394732395583115`, 0.9345062527263533]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 478}], {
             RGBColor[
             0.22953226117284842`, 0.3585833380515396, 0.9363828947600188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 262}], {
             RGBColor[
             0.33623006243366543`, 0.4656473134908974, 0.942645260155071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 299}], {
             RGBColor[
             0.2846830813812443, 0.4146506586338333, 0.9395932092741723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 313}], {
             RGBColor[
             0.3452565934007724, 0.4734656409279675, 0.9432204227264471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 328}], {
             RGBColor[
             0.28613962453427205`, 0.41618157783783527`, 0.9396761572519747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 391}], {
             RGBColor[
             0.40120374518351687`, 0.5213867241354746, 0.9469338462657712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 407}], {
             RGBColor[
             0.30321117252682794`, 0.43412485717667065`, 0.9406483566550587]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 448}], {
             RGBColor[
             0.314938405291928, 0.4464509223622935, 0.9413162052121451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 455}], {
             RGBColor[
             0.47116868386026034`, 0.5781874132378237, 0.9524417425284195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 475}], {
             RGBColor[
             0.3329106779769486, 0.46277222951160313`, 0.9424337519127055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 478}], {
             RGBColor[
             0.2893032374986769, 0.41950673564807195`, 0.9398563203301515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 482}], {
             RGBColor[
             0.3308323765041129, 0.4609721092343021, 0.9423013243806262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 299}], {
             RGBColor[
             0.2916203852027007, 0.4206594025249505, 0.9400352481392587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 376}], {
             RGBColor[
             0.3571381356790589, 0.48375683566574046`, 0.9439775040939842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 391}], {
             RGBColor[
             0.4081410490049733, 0.5273954680265918, 0.9473758851308575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 448}], {
             RGBColor[
             0.3218757091133844, 0.45245966625341066`, 0.9417582440772314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 455}], {
             RGBColor[
             0.47810598768171675`, 0.5841961571289409, 0.9528837813935058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 475}], {
             RGBColor[
             0.33984798179840503`, 0.4687809734027203, 0.9428757907777918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 478}], {
             RGBColor[
             0.29624054132013333`, 0.4255154795391891, 0.9402983591952379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 482}], {
             RGBColor[
             0.3377696803255693, 0.46698085312541926`, 0.9427433632457125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 267}], {
             RGBColor[
             0.22679757309850174`, 0.35570900749616285`, 0.9362271583197932]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 393}], {
             RGBColor[
             0.22282702878996197`, 0.35153571368083814`, 0.9360010416953157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 485}], {
             RGBColor[
             0.23984153552950008`, 0.3694190390461275, 0.9369699926834254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 281}], {
             RGBColor[
             0.8419839123581961, 0.3124840077358858, 0.18739747519941907`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 295}], {
             RGBColor[
             0.9251699045349664, 0.7351644032002858, 0.5555767619873893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 324}], {
             RGBColor[
             0.9026383334956752, 0.7184607257731993, 0.5982098779593608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 341}], {
             RGBColor[
             0.9299206145630832, 0.7362794821686658, 0.415098303004048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 374}], {
             RGBColor[
             0.8564940987621058, 0.42401565884056125`, 0.20129244608671454`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 397}], {
             RGBColor[
             0.8437768320344039, 0.3262651740296299, 0.18911437710616869`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 270}], {
             RGBColor[
             0.18221828136351503`, 0.30885334539234544`, 0.9336884336046377]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 320}], {
             RGBColor[
             0.18273053674122575`, 0.3093917582731863, 0.9337176057905845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 329}], {
             RGBColor[
             0.18295078871918613`, 0.3096232570668046, 0.9337301488148957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 424}], {
             RGBColor[
             0.18889724072199854`, 0.3158733551485935, 0.9340687904594684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 293}], {
             RGBColor[
             0.9016661303754756, 0.9199925303309897, 0.7623198781355807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 317}], {
             RGBColor[
             0.9054511863291719, 0.561405403936883, 0.35359294828676574`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 322}], {
             RGBColor[
             0.9071828092516094, 0.5747154165207407, 0.3552511523528803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 343}], {
             RGBColor[
             0.9199069923129997, 0.6725190633031569, 0.3674358444223769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 359}], {
             RGBColor[
             0.9515547370167402, 0.9596896244773535, 0.7671002510689349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 403}], {
             RGBColor[
             0.868496130673329, 0.8940798744623377, 0.7590138025565417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 440}], {
             RGBColor[
             0.9426079391450114, 0.7947470752330569, 0.3871278708766489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 445}], {
             RGBColor[
             0.9783510953842744, 0.9379685313127405, 0.42709594933440853`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 471}], {
             RGBColor[
             0.975210019564589, 0.978006622458981, 0.7504581704123827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 483}], {
             RGBColor[
             0.722812081892279, 0.7773202768708386, 0.7464962569767426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 280}], {
             RGBColor[
             0.24136535807007609`, 0.3710206731522022, 0.9370567721228178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 393}], {
             RGBColor[
             0.22528640281656057`, 0.35412067171611283`, 0.9361410994078128]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 424}], {
             RGBColor[
             0.21136439475697272`, 0.3394877585391924, 0.9353482616445844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 480}], {
             RGBColor[
             0.23630904981420553`, 0.3657061725868226, 0.9367688228477836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 485}], {
             RGBColor[
             0.24230090955609868`, 0.3720039970814022, 0.9371100503959223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 491}], {
             RGBColor[
             0.1839641739186956, 0.3106883891638218, 0.9337878596028387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 282}], {
             RGBColor[
             0.6492936360498982, 0.7253322095338435, 0.966103200750267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 310}], {
             RGBColor[
             0.6233432481970155, 0.705059569312919, 0.963516708609254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 323}], {
             RGBColor[
             0.7972919842565633, 0.8394603962804845, 0.8661383017091098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 406}], {
             RGBColor[
             0.5091880023383142, 0.611421148279524, 0.9547804937952983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 411}], {
             RGBColor[
             0.441541570634595, 0.5502832522185821, 0.9505633429393294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 419}], {
             RGBColor[
             0.6255800853713929, 0.7068070035141348, 0.9637396556343641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 499}], {
             RGBColor[
             0.615223353565316, 0.6985050597773825, 0.9628517825115135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 329}], {
             RGBColor[
             0.18084643102754924`, 0.3074114437089104, 0.9336103087574752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 479}], {
             RGBColor[
             0.18121603188329788`, 0.30779991764234993`, 0.9336313569794346]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 304}], {
             RGBColor[
             0.19940240032278655`, 0.3269149439546105, 0.9346670437577425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 307}], {
             RGBColor[
             0.199934386249049, 0.3274740948929682, 0.9346973395692404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 311}], {
             RGBColor[
             0.19904018271004636`, 0.32653423027769746`, 0.9346464160005499]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 351}], {
             RGBColor[
             0.2241430772010206, 0.3529189640031495, 0.9360759887054064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 371}], {
             RGBColor[
             0.23108898271360306`, 0.3602195510927192, 0.9364715477488016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 429}], {
             RGBColor[
             0.200022442914419, 0.32756664803138713`, 0.9347023542660651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 442}], {
             RGBColor[
             0.22300003138538366`, 0.3517175503776244, 0.9360108939371906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 435}], {
             RGBColor[
             0.24781268178209245`, 0.377797219157465, 0.9374239376702564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 453}], {
             RGBColor[
             0.24857862251541402`, 0.3786022714316334, 0.9374675568619113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 497}], {
             RGBColor[
             0.3677045224545963, 0.48747048871276477`, 0.9450117306986173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 279}], {
             RGBColor[
             0.19757076585955963`, 0.32498978000142653`, 0.9345627348847221]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 283}], {
             RGBColor[
             0.18473808843290457`, 0.31150182238726964`, 0.933831932889519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 285}], {
             RGBColor[
             0.20077325282687788`, 0.3283557968534793, 0.934745111779856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 396}], {
             RGBColor[
             0.19229860014365638`, 0.3194483995593991, 0.9342624928466716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 421}], {
             RGBColor[
             0.18574774173175967`, 0.3125630320200829, 0.9338894311512407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 430}], {
             RGBColor[
             0.19435747882303328`, 0.32161241159187215`, 0.9343797429416241]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 459}], {
             RGBColor[
             0.19081936422215473`, 0.3178936288169264, 0.9341782525492754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 477}], {
             RGBColor[
             0.19247626140559868`, 0.319635132810075, 0.9342726103927129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 284}], {
             RGBColor[
             0.22545727776759072`, 0.3543002721237432, 0.936150830483487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 300}], {
             RGBColor[
             0.23797382817444995`, 0.36745596019648397`, 0.9368636295125807]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 305}], {
             RGBColor[
             0.2773195143815185, 0.4086435488273039, 0.9391104309604698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 389}], {
             RGBColor[
             0.2195028960405469, 0.34804183939901356`, 0.9358117372528503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 432}], {
             RGBColor[
             0.26765870816883486`, 0.3986566512006808, 0.9385541395134164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 460}], {
             RGBColor[
             0.27237898950751444`, 0.4036179661707557, 0.9388229525526237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 331}], {
             RGBColor[
             0.39537355093788906`, 0.515221122490898, 0.946708621365979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 346}], {
             RGBColor[
             0.4653638430606762, 0.5765191723103537, 0.951143590075486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 348}], {
             RGBColor[
             0.475696405739353, 0.5852307979148967, 0.9518677100746031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 355}], {
             RGBColor[
             0.5245111056702372, 0.6248607703959599, 0.9557105820673001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 372}], {
             RGBColor[
             0.55179178264052, 0.6470084529409276, 0.9578582168908132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 404}], {
             RGBColor[
             0.663069657712535, 0.7345059792856424, 0.9686190519229416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 418}], {
             RGBColor[
             0.48290882987898437`, 0.5910861687474542, 0.9524354985228551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 431}], {
             RGBColor[
             0.4552821797756804, 0.5677869422920205, 0.9505011954058309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 444}], {
             RGBColor[
             0.5275882362182631, 0.6273589235979986, 0.9559528250559413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 486}], {
             RGBColor[
             0.45132348377934284`, 0.564358118789839, 0.9502489507974816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 306}], {
             RGBColor[
             0.22718429673725105`, 0.3561154785601833, 0.9362491816589136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 347}], {
             RGBColor[
             0.20833762491305394`, 0.33630643152494155`, 0.935175891579678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 382}], {
             RGBColor[
             0.21283416100439742`, 0.3410325760537981, 0.935431962658051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 462}], {
             RGBColor[
             0.20183278400452248`, 0.3294694312993405, 0.9348054505129868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 288}], {
             RGBColor[
             0.5772249873338873, 0.6663273536018384, 0.9606573715704986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 313}], {
             RGBColor[
             0.4022235011215268, 0.5228075131556505, 0.9468503037125551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 340}], {
             RGBColor[
             0.40350978000289583`, 0.523921623272436, 0.9469322642654641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 373}], {
             RGBColor[
             0.7171130809828956, 0.774434213301909, 0.8741433170431847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 386}], {
             RGBColor[
             0.3744145130463712, 0.49843012291785427`, 0.9450889814281427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 414}], {
             RGBColor[
             0.43294658493558325`, 0.5494183041682945, 0.9488079514458304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 498}], {
             RGBColor[
             0.6089064489917588, 0.6910771522369943, 0.9638150835884631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 401}], {
             RGBColor[
             0.18259570595575553`, 0.30925004256889155`, 0.9337099273768162]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 451}], {
             RGBColor[
             0.194775409510841, 0.3220516832430941, 0.9344035434760216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.2111852622032374, 0.3392994788675566, 0.935338060310652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 318}], {
             RGBColor[
             0.20298181137445004`, 0.33067713191767734`, 0.9348708859218705]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 335}], {
             RGBColor[
             0.20917892656929465`, 0.33719069290725634`, 0.9352238024644066]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 396}], {
             RGBColor[
             0.2027106095200159, 0.3303920815734764, 0.9348554413774677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 409}], {
             RGBColor[
             0.23060819410886862`, 0.3597142117853851, 0.9364441675490249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 421}], {
             RGBColor[
             0.19615975110811917`, 0.3235067140341602, 0.9344823796820367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 430}], {
             RGBColor[
             0.2047694881993928, 0.33255609360594945`, 0.9349726914724201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 459}], {
             RGBColor[
             0.20123137359851423`, 0.3288373108310037, 0.9347712010800716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 477}], {
             RGBColor[
             0.2028882707819582, 0.3305788148241523, 0.9348655589235091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 338}], {
             RGBColor[
             0.33890305736331594`, 0.4628522319448411, 0.9430026939765475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 383}], {
             RGBColor[
             0.2606241170949257, 0.3912628499631674, 0.9381535299585022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 393}], {
             RGBColor[
             0.23739481376153632`, 0.3668473793368775, 0.9368306554983403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 480}], {
             RGBColor[
             0.24841746075918128`, 0.37843288020758725`, 0.9374583789383113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 317}], {
             RGBColor[
             0.8178714627321924, 0.13837347065034328`, 0.1647470389362648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 322}], {
             RGBColor[
             0.8196030856546299, 0.15168348323420097`, 0.16640524300237935`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 324}], {
             RGBColor[
             0.8790783466018638, 0.5485966593380001, 0.5760884806324713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 343}], {
             RGBColor[
             0.8323272687160201, 0.24948713001661726`, 0.17858993507187598`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 374}], {
             RGBColor[
             0.8329341118682944, 0.254151592405362, 0.1791710487598251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 397}], {
             RGBColor[
             0.8202168451405925, 0.15640110759443068`, 0.16699297977927924`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 445}], {
             RGBColor[
             0.8907713717872949, 0.5149365980262008, 0.23825003998390762`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 310}], {
             RGBColor[
             0.6707630336058359, 0.74272444693153, 0.9678190486190441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 323}], {
             RGBColor[
             0.8447117696653836, 0.8771252738990953, 0.8704406417188999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 406}], {
             RGBColor[
             0.5566077877471345, 0.6490860258981348, 0.9590828338050883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 419}], {
             RGBColor[
             0.6729998707802133, 0.7444718811327458, 0.9680419956441542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 499}], {
             RGBColor[
             0.6626431389741363, 0.7361699373959933, 0.9671541225213036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 396}], {
             RGBColor[
             0.18987793209336085`, 0.3169041239593195, 0.9341246393822646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 421}], {
             RGBColor[
             0.18332707368146411`, 0.3100187564200033, 0.9337515776868337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 430}], {
             RGBColor[
             0.19193681077273775`, 0.31906813599179257`, 0.9342418894772171]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 459}], {
             RGBColor[
             0.18839869617185917`, 0.3153493532168468, 0.9340403990848687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 477}], {
             RGBColor[
             0.19005559335530314`, 0.3170908572099954, 0.934134756928306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 300}], {
             RGBColor[
             0.2193467291603231, 0.3478776981063463, 0.9358028437800496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 345}], {
             RGBColor[
             0.19883561542773992`, 0.32631921709367856`, 0.9346347661964527]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 389}], {
             RGBColor[
             0.20087579702642006`, 0.328463577308876, 0.9347509515203193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 432}], {
             RGBColor[
             0.249031609154708, 0.37907838911054315`, 0.9374933537808854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 456}], {
             RGBColor[
             0.2012208320986775, 0.3288262310463056, 0.9347706007572507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 472}], {
             RGBColor[
             0.19498301286010505`, 0.32226988752598323`, 0.9344153661796406]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 287}], {
             RGBColor[
             0.2592707940788048, 0.38984042166758914`, 0.938076460214796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 354}], {
             RGBColor[
             0.2624877417671351, 0.39305135672859914`, 0.93826589544543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 396}], {
             RGBColor[
             0.20591309648733414`, 0.33375809842552917`, 0.9350378182726016]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 409}], {
             RGBColor[
             0.23381068107618688`, 0.3630802286374379, 0.9366265444441588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 430}], {
             RGBColor[
             0.20797197516671106`, 0.33592211045800224`, 0.935155068367554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 473}], {
             RGBColor[
             0.2389908172005852, 0.3685248801437806, 0.9369215455331186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 477}], {
             RGBColor[
             0.20609075774927643`, 0.3339448316762051, 0.935047935818643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 319}], {
             RGBColor[
             0.18412936406719407`, 0.310862014483554, 0.9337972669374188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 330}], {
             RGBColor[
             0.18848828405783719`, 0.3154435157652098, 0.9340455009824417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 357}], {
             RGBColor[
             0.1879701028596808, 0.3148988744713619, 0.934015991329787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 358}], {
             RGBColor[
             0.20613946196016764`, 0.33399602288987706`, 0.9350507094514018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 367}], {
             RGBColor[
             0.1922727390163294, 0.3194212178748882, 0.9342610200937285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 368}], {
             RGBColor[
             0.18331387184910375`, 0.310004880457148, 0.9337508258620111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 492}], {
             RGBColor[
             0.18500229424892267`, 0.31177951945152094`, 0.9338469790198838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 336}], {
             RGBColor[
             0.46475221828321023`, 0.5718710801553506, 0.9521407597407114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 354}], {
             RGBColor[
             0.3073707866753843, 0.44022628267657893`, 0.9408219184544402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 388}], {
             RGBColor[
             0.31642089310081123`, 0.44806502999070874`, 0.9413985832331735]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 409}], {
             RGBColor[
             0.2786937259844361, 0.4102551545854176, 0.9391825674531689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 436}], {
             RGBColor[
             0.3298373627600314, 0.45968570167815315`, 0.9422534688161406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 473}], {
             RGBColor[
             0.28387386210883436`, 0.4156998060917603, 0.9394775685421287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 313}], {
             RGBColor[
             0.5362219144016962, 0.6308125527023426, 0.9580446920208532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 321}], {
             RGBColor[
             0.8483292768809738, 0.881288734461381, 0.9314462475205114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 373}], {
             RGBColor[
             0.8511114942630649, 0.882439252848601, 0.8853377053514828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 386}], {
             RGBColor[
             0.5084129263265404, 0.6064351624645463, 0.9562833697364408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 391}], {
             RGBColor[
             0.5921690661844405, 0.6787336359098497, 0.9617581155601771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 455}], {
             RGBColor[
             0.6621340048611841, 0.7355343250121988, 0.9672660118228255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 498}], {
             RGBColor[
             0.7429048622719281, 0.7990821917836863, 0.9750094718967612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 300}], {
             RGBColor[
             0.2209681235766699, 0.34958188644027033`, 0.9358951797934225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 308}], {
             RGBColor[
             0.20048868170692968`, 0.3280566945635627, 0.9347289058755601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 314}], {
             RGBColor[
             0.23644046461492338`, 0.36584429787455663`, 0.9367763067262738]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 466}], {
             RGBColor[
             0.20247960652430902`, 0.3301492827785526, 0.9348422860986005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 470}], {
             RGBColor[
             0.20234342031166005`, 0.33000614243435394`, 0.9348345304952597]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 493}], {
             RGBColor[
             0.235488823391288, 0.36484406261097735`, 0.9367221121664148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 297}], {
             RGBColor[
             0.18839455558370108`, 0.3153450011961642, 0.9340401632844985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 484}], {
             RGBColor[
             0.18316922942285135`, 0.3098528520962973, 0.9337425886898154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 349}], {
             RGBColor[
             0.1841373062547167, 0.310870362226204, 0.9337977192332487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 353}], {
             RGBColor[
             0.18189358061228061`, 0.3085120643155814, 0.9336699423772067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 394}], {
             RGBColor[
             0.18326692398746902`, 0.30995553527790365`, 0.9337481522507443]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 467}], {
             RGBColor[
             0.1871130842202519, 0.31399809354320196`, 0.933967185386117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 398}], {
             RGBColor[
             0.19568953649861287`, 0.32301248866624094`, 0.9344556016556456]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 399}], {
             RGBColor[
             0.19649944973854266`, 0.32386375883287244`, 0.9345017250165003]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 464}], {
             RGBColor[
             0.19378696997725373`, 0.3210127706226078, 0.9343472533068491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 481}], {
             RGBColor[
             0.1951943467181843, 0.32249201281016504`, 0.9344274013302178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 496}], {
             RGBColor[
             0.1854675912889076, 0.3122685761420814, 0.9338734769979656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 343}], {
             RGBColor[
             0.8279897500301316, 0.6038277857603807, 0.5867878259844261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 403}], {
             RGBColor[
             0.7765788883904609, 0.8253885969195616, 0.9783657841185909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 440}], {
             RGBColor[
             0.8506906968621433, 0.7260557976902806, 0.6064798524386981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 445}], {
             RGBColor[
             0.8864338531014064, 0.8692772537699642, 0.6464479308964578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 471}], {
             RGBColor[
             0.883292777281721, 0.9093153449162048, 0.969810151974432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 483}], {
             RGBColor[
             0.630894839609411, 0.7086289993280623, 0.9658482385387919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 497}], {
             RGBColor[
             0.6439655477048442, 0.7192750682039972, 0.9668676305891115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 296}], {
             RGBColor[
             0.18486063733978264`, 0.311630629058448, 0.9338389118684709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 327}], {
             RGBColor[
             0.18563559838764718`, 0.312445162255122, 0.9338830447536945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 385}], {
             RGBColor[
             0.18452375420061845`, 0.3112765435195617, 0.9338197268720694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 415}], {
             RGBColor[
             0.18394556991543065`, 0.3106688351768284, 0.9337868001323749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 438}], {
             RGBColor[
             0.19506692603526019`, 0.32235808559347384`, 0.9344201449108273]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 439}], {
             RGBColor[
             0.19336116609564466`, 0.3205652237455112, 0.9343230044057118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 321}], {
             RGBColor[
             0.9851155314829081, 0.988112904001859, 0.896337693305348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 341}], {
             RGBColor[
             0.9895466198460419, 0.9890958111978665, 0.7611561924651287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 391}], {
             RGBColor[
             0.7289553207863748, 0.7855578054503277, 0.9266495613450138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 397}], {
             RGBColor[
             0.9034028373173626, 0.5790815030588307, 0.5351722665672494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 455}], {
             RGBColor[
             0.7989202594631184, 0.8423584945526768, 0.9321574576076621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 327}], {
             RGBColor[
             0.1830042105599709, 0.3096794068086097, 0.9337331911096979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 339}], {
             RGBColor[
             0.18120773687102673`, 0.3077911990585188, 0.9336308845907572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 385}], {
             RGBColor[
             0.18189236637294215`, 0.30851078807304944`, 0.9336698732280726]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 415}], {
             RGBColor[
             0.18131418208775438`, 0.30790307973031616`, 0.9336369464883782]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 438}], {
             RGBColor[
             0.1924355382075839, 0.3195923301469616, 0.9342702912668306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 325}], {
             RGBColor[
             0.21444902327045198`, 0.3427298986836028, 0.9355239266751281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 392}], {
             RGBColor[
             0.21605655176504493`, 0.3444195130546133, 0.9356154730447699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 412}], {
             RGBColor[
             0.1927590864051722, 0.31993239981676747`, 0.9342887168580365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 413}], {
             RGBColor[
             0.2127862490397303, 0.34098221754113894`, 0.9354292341425425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 474}], {
             RGBColor[
             0.21238801987541464`, 0.34056365344025585`, 0.935406555580762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 484}], {
             RGBColor[
             0.1900371894005843, 0.3170715134867078, 0.934133708850311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 490}], {
             RGBColor[
             0.20561521715269282`, 0.3334450083581805, 0.9350208544851668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 335}], {
             RGBColor[
             0.2430317898200987, 0.3727721985793514, 0.9371516729457167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 409}], {
             RGBColor[
             0.26446105735967274`, 0.39529571745748016`, 0.9383720380303351]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 468}], {
             RGBColor[
             0.24859500261068126`, 0.37861948795031725`, 0.9374684896841046]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 312}], {
             RGBColor[
             0.21752114274095335`, 0.3459588910307243, 0.9356988793341796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 328}], {
             RGBColor[
             0.24152994730330735`, 0.3711936668718884, 0.9370661452361624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 399}], {
             RGBColor[
             0.22397618806162217`, 0.3527435529362591, 0.936066484615808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 407}], {
             RGBColor[
             0.2586014952958633, 0.3891369462107238, 0.9380383446392464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 448}], {
             RGBColor[
             0.2703287280609633, 0.40146301139634666`, 0.9387061931963326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 475}], {
             RGBColor[
             0.28830100074598397`, 0.41778431854565623`, 0.939823739896893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 478}], {
             RGBColor[
             0.24469356026771227`, 0.3745188246821251, 0.9372463083143392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 482}], {
             RGBColor[
             0.2862226992731482, 0.4159841982683552, 0.9396913123648138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 305}], {
             RGBColor[
             0.27120896577425085`, 0.40222097480990704`, 0.9387624442570324]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 308}], {
             RGBColor[
             0.21138383769744212`, 0.33950819430237933`, 0.9353493688912808]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 432}], {
             RGBColor[
             0.26154815956156724`, 0.39223407718328385`, 0.938206152809979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 456}], {
             RGBColor[
             0.21373738250553675`, 0.34198191911904635`, 0.9354833997863443]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 493}], {
             RGBColor[
             0.24638397938180046`, 0.376295562349794, 0.9373425751821356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 316}], {
             RGBColor[
             0.547580608865669, 0.6429772459967242, 0.9577838308857021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 336}], {
             RGBColor[
             0.6408993785116156, 0.7191341855671287, 0.9650206560001502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 388}], {
             RGBColor[
             0.4925680533292166, 0.5953281354024867, 0.9542784794926122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 436}], {
             RGBColor[
             0.5059845229884368, 0.6069488070899312, 0.9551333650755793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 346}], {
             RGBColor[
             0.343088083847486, 0.46567152269516504`, 0.9432988559850268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 370}], {
             RGBColor[
             0.23676036432994563`, 0.36618053275785845`, 0.936794524541795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 390}], {
             RGBColor[
             0.25033731885124844`, 0.38045077278838335`, 0.9375677120164789]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 422}], {
             RGBColor[
             0.22565049031831835`, 0.3545033507649412, 0.9361618336524187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 443}], {
             RGBColor[
             0.2662987639830351, 0.3972272636359636, 0.9384766927038922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 451}], {
             RGBColor[
             0.22492379054142386`, 0.35373954322399803`, 0.9361204491751804]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 379}], {
             RGBColor[
             0.8341112743268393, 0.26319977889761653`, 0.18029830085954252`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 400}], {
             RGBColor[
             0.9153331914929417, 0.6523376989650047, 0.5021363035234178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 307}], {
             RGBColor[
             0.19124101859615344`, 0.3183368142984305, 0.9342022651420929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 311}], {
             RGBColor[
             0.19034681505715081`, 0.3173969496831598, 0.9341513415734024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 337}], {
             RGBColor[
             0.1898974932161501, 0.3169246839396178, 0.9341257533592695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 423}], {
             RGBColor[
             0.1849544721508512, 0.3117292553943517, 0.9338442556221451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 427}], {
             RGBColor[
             0.18861159117236292`, 0.315573119360699, 0.9340525231401974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 433}], {
             RGBColor[
             0.1856912324704567, 0.31250363720355945`, 0.9338862130324074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 465}], {
             RGBColor[
             0.18487917380697239`, 0.31165011206074433`, 0.933839967492855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 469}], {
             RGBColor[
             0.18603078567582654`, 0.3128605291513198, 0.9339055500851292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 310}], {
             RGBColor[
             0.4776836488671362, 0.5829301850756662, 0.9531209010914763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 406}], {
             RGBColor[
             0.3635284030084348, 0.4892917640422711, 0.9443846862775205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 432}], {
             RGBColor[
             0.30089384576863576`, 0.43342166581410385`, 0.9404529542578681]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 460}], {
             RGBColor[
             0.3056141271073153, 0.43838298078417876`, 0.9407217672970755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 493}], {
             RGBColor[
             0.2857296655888689, 0.41748315098061395`, 0.9395893766300246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 331}], {
             RGBColor[
             0.2711023891418522, 0.40227617824530654`, 0.9387502520503602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 347}], {
             RGBColor[
             0.22192337354853872`, 0.3505859147270508, 0.9359495798661548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 382}], {
             RGBColor[
             0.2264199096398822, 0.3553120592559075, 0.9362056509445278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 431}], {
             RGBColor[
             0.33101101797964355`, 0.4548419980464291, 0.9425428260902121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 486}], {
             RGBColor[
             0.327052321983306, 0.4514131745442476, 0.942290581481863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 337}], {
             RGBColor[
             0.19042947914241254`, 0.31748383487797555`, 0.9341560491707674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 427}], {
             RGBColor[
             0.1891435770986254, 0.31613227029905666`, 0.9340828189516954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 433}], {
             RGBColor[
             0.18622321839671918`, 0.3130627881419171, 0.9339165088439054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 442}], {
             RGBColor[
             0.21483864965875055`, 0.34313942072144443`, 0.9355461153215412]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 469}], {
             RGBColor[
             0.186562771602089, 0.31341968008967747`, 0.9339358458966271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 500}], {
             RGBColor[
             0.19638085260421678`, 0.3237391057252033, 0.9344949710851491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 362}], {
             RGBColor[
             0.18507064546441102`, 0.3118513609127166, 0.9338508715204893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 369}], {
             RGBColor[
             0.18646563701697516`, 0.31331758548203437`, 0.9339303142257027]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 389}], {
             RGBColor[
             0.19291290556353907`, 0.320094073504909, 0.9342974766315505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 456}], {
             RGBColor[
             0.1932579406357965, 0.32045672724233865`, 0.9343171258684819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 393}], {
             RGBColor[
             0.20475589581124165`, 0.33254180714419534`, 0.9349719174060231]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 424}], {
             RGBColor[
             0.19083388775165383`, 0.3179088939672749, 0.9341790796427948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 323}], {
             RGBColor[
             0.8187613818125008, 0.8568526336781708, 0.8678541495778869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 406}], {
             RGBColor[
             0.5306573998942516, 0.6288133856772102, 0.9564963416640753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 408}], {
             RGBColor[
             0.7910483812120712, 0.837599492064294, 0.9781391837091735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 419}], {
             RGBColor[
             0.6470494829273306, 0.7241992409118212, 0.9654555035031411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 366}], {
             RGBColor[
             0.18627071422588198`, 0.31311270926977675`, 0.9339192136611123]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 405}], {
             RGBColor[
             0.18582191019465255`, 0.3126409877771355, 0.9338936549354799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 423}], {
             RGBColor[
             0.184592254538111, 0.31134854171743864`, 0.9338236278649524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 429}], {
             RGBColor[
             0.19096685764878327`, 0.3180486537599364, 0.934186652081725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 465}], {
             RGBColor[
             0.1845169561942322, 0.31126939838383133`, 0.9338193397356624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 469}], {
             RGBColor[
             0.18566856806308635`, 0.31247981547440673`, 0.9338849223279366]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 488}], {
             RGBColor[
             0.18625665477025105`, 0.3130979318904876, 0.9339184129959133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 327}], {
             RGBColor[
             0.18937402646973123`, 0.31637448719942296`, 0.9340959427024605]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 334}], {
             RGBColor[
             0.19091202731972692`, 0.3179910236076545, 0.9341835295755994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 385}], {
             RGBColor[
             0.1882621822827025, 0.31520586846386267`, 0.9340326248208353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 415}], {
             RGBColor[
             0.18768399799751473`, 0.31459816012112934`, 0.9339996980811409]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 446}], {
             RGBColor[
             0.18918799273524178`, 0.31617895394925455`, 0.9340853483564936]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 386}], {
             RGBColor[
             0.33341144011418006`, 0.4629153220183585, 0.9424763018784972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 391}], {
             RGBColor[
             0.4171675799720802, 0.5352137954636619, 0.9479510477022336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 407}], {
             RGBColor[
             0.31917500731539133`, 0.44795192850485793`, 0.9416655580915212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 498}], {
             RGBColor[
             0.5679033760595678, 0.6555623513374985, 0.9612024040388176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 406}], {
             RGBColor[
             0.3396550578396198, 0.4643665868457374, 0.9430190117624826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 411}], {
             RGBColor[
             0.27200862613590066`, 0.4032286907847955, 0.9388018609065139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 493}], {
             RGBColor[
             0.2618563204200539, 0.3925579737840803, 0.9382237021149867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 349}], {
             RGBColor[
             0.18430254906177113`, 0.31104404289341736`, 0.9338071295666557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 353}], {
             RGBColor[
             0.18205882341933505`, 0.3086857449827948, 0.9336793527106135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 364}], {
             RGBColor[
             0.19390091491665387`, 0.32113253397844377`, 0.9343537423025814]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 378}], {
             RGBColor[
             0.19518703914887203`, 0.3224843320914912, 0.934426985174956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 380}], {
             RGBColor[
             0.18543946082278231`, 0.31223900923860914`, 0.9338718750095351]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 487}], {
             RGBColor[
             0.1880750117052634, 0.3150091403196742, 0.9340219657333442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 372}], {
             RGBColor[
             0.5264921273018517, 0.6260724945913516, 0.9559761056168596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 418}], {
             RGBColor[
             0.45760917454031613`, 0.5701502103978782, 0.9505533872489015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 322}], {
             RGBColor[
             0.8190506229224375, 0.1474370125838577, 0.16587620406611453`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 343}], {
             RGBColor[
             0.8317748059838278, 0.24524065936627398`, 0.17806089613561116`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 374}], {
             RGBColor[
             0.832381649136102, 0.24990512175501872`, 0.1786420098235603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 440}], {
             RGBColor[
             0.8544757528158395, 0.36746867129617394`, 0.19775292258988314`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 445}], {
             RGBColor[
             0.8902189090551026, 0.5106901273758575, 0.23772100104764282`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 471}], {
             RGBColor[
             0.8870778332354172, 0.5507282185220981, 0.561083222125617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 335}], {
             RGBColor[
             0.2041779627078255, 0.33193436280942984`, 0.9349390049707589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 421}], {
             RGBColor[
             0.19115878724665003`, 0.3182503839363337, 0.9341975821883891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 430}], {
             RGBColor[
             0.1997685243379237, 0.32729976350812295`, 0.9346878939787725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 459}], {
             RGBColor[
             0.1962304097370451, 0.3235809807331772, 0.934486403586424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 330}], {
             RGBColor[
             0.18522178171588122`, 0.3120102146956035, 0.9338594785064245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 357}], {
             RGBColor[
             0.18470360051772483`, 0.3114655734017556, 0.9338299688537698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 368}], {
             RGBColor[
             0.18004736950714773`, 0.30657157938754187`, 0.9335648033859939]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 492}], {
             RGBColor[
             0.18173579190696668`, 0.3083462183819148, 0.9336609565438665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 329}], {
             RGBColor[
             0.18135868640525998`, 0.3079498565897512, 0.9336394809434219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 424}], {
             RGBColor[
             0.18730513840807234`, 0.31419995467154005`, 0.9339781225879946]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 341}], {
             RGBColor[
             0.9898662415110249, 0.9892279829702391, 0.7558592343220067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 373}], {
             RGBColor[
             0.9882173705299822, 0.9893955941614516, 0.8449321929931977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 391}], {
             RGBColor[
             0.7292749424513578, 0.7856899772227003, 0.9213526032018919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 397}], {
             RGBColor[
             0.9037224589823456, 0.5792136748312032, 0.5298753084241274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 455}], {
             RGBColor[
             0.7992398811281014, 0.8424906663250493, 0.9268604994645402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 498}], {
             RGBColor[
             0.8800107385388454, 0.9060385330965369, 0.934603959538476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 343}], {
             RGBColor[
             0.8335064289062653, 0.2585506719501317, 0.17971910020172568`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 374}], {
             RGBColor[
             0.8341132720585396, 0.26321513433887644`, 0.18030021388967482`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 440}], {
             RGBColor[
             0.8562073757382771, 0.38077868388003167`, 0.19941112665599764`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 445}], {
             RGBColor[
             0.89195053197754, 0.5240001399597152, 0.23937920511375732`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 471}], {
             RGBColor[
             0.8888094561578547, 0.5640382311059557, 0.5627414261917315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 419}], {
             RGBColor[
             0.8209982189868783, 0.8586000678793866, 0.8680770966029969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 449}], {
             RGBColor[
             0.9881583833202512, 0.9738084894895631, 0.5806455490390734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 499}], {
             RGBColor[
             0.8106414871808013, 0.8502981241426343, 0.8671892234801464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 342}], {
             RGBColor[
             0.7080228667800735, 0.7701523632700238, 0.969408565667581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 360}], {
             RGBColor[
             0.7679481729777577, 0.8188024264455834, 0.9741261052850922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 457}], {
             RGBColor[
             0.7044919829810323, 0.7672858327374596, 0.9691306015608669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 392}], {
             RGBColor[
             0.23524305947406288`, 0.3645857491516413, 0.9367081162749039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 413}], {
             RGBColor[
             0.23197275674874823`, 0.36114845363816694`, 0.9365218773726766]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 474}], {
             RGBColor[
             0.2315745275844326, 0.3607298895372839, 0.936499198810896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 490}], {
             RGBColor[
             0.22480172486171077`, 0.3536112444552085, 0.9361134977153007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 338}], {
             RGBColor[
             0.5748571876552486, 0.6636751524188924, 0.9607610097179233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 346}], {
             RGBColor[
             0.5833986733777301, 0.6710733580441507, 0.9613052656352206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 355}], {
             RGBColor[
             0.642545935987291, 0.7194149561297569, 0.9658722576270347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 395}], {
             RGBColor[
             0.6147615284118504, 0.6968583223867169, 0.9636849672850575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 443}], {
             RGBColor[
             0.5066093535132791, 0.6026290989849493, 0.956483102354086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 334}], {
             RGBColor[
             0.18531717245783108`, 0.3121104764135153, 0.9338649108680606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 385}], {
             RGBColor[
             0.18266732742080666`, 0.30932532126972345`, 0.9337140061132965]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 415}], {
             RGBColor[
             0.1820891431356189, 0.3087176129269901, 0.9336810793736019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 446}], {
             RGBColor[
             0.18359313787334597`, 0.31029840675511533`, 0.9337667296489547]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 398}], {
             RGBColor[
             0.2246228179747201, 0.35342320197362953`, 0.9361033092327558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 399}], {
             RGBColor[
             0.22543273121464985`, 0.354274472140261, 0.9361494325936104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 407}], {
             RGBColor[
             0.26005803844889097`, 0.3906678654147257, 0.9381212926170488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 464}], {
             RGBColor[
             0.22272025145336094`, 0.35142348392999634`, 0.9359949608839593]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 475}], {
             RGBColor[
             0.28975754389901165`, 0.4193152377496582, 0.9399066878746956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 478}], {
             RGBColor[
             0.24615010342073995`, 0.376049743886127, 0.9373292562921416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 481}], {
             RGBColor[
             0.22412762819429155`, 0.3529027261175536, 0.9360751089073279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 333}], {
             RGBColor[
             0.210684466253447, 0.33877311057202975`, 0.9353095407221728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 352}], {
             RGBColor[
             0.1864863756783814, 0.3133393831300794, 0.9339314952617896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 357}], {
             RGBColor[
             0.18906252050836794`, 0.3160470746834114, 0.9340782028987926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 358}], {
             RGBColor[
             0.20723187960885475`, 0.33514422310192665`, 0.9351129210204074]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 367}], {
             RGBColor[
             0.19336515666501655`, 0.3205694180869378, 0.9343232316627341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 368}], {
             RGBColor[
             0.18440628949779087`, 0.3111530806691976, 0.9338130374310167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 441}], {
             RGBColor[
             0.20552414062024876`, 0.33334928114799606`, 0.9350156678113797]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 492}], {
             RGBColor[
             0.1860947118976098, 0.3129277196635705, 0.9339091905888894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 348}], {
             RGBColor[
             0.3817575877124325, 0.5041670701523192, 0.9456367228639543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 372}], {
             RGBColor[
             0.4578529646135995, 0.56594472517835, 0.9516272296801642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 382}], {
             RGBColor[
             0.25675225340899854`, 0.38719327573892137`, 0.9379330330494976]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 404}], {
             RGBColor[
             0.5691308396856145, 0.6534422515230649, 0.9623880647122928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 418}], {
             RGBColor[
             0.38897001185206387`, 0.5100224409848767, 0.9462045113122062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 431}], {
             RGBColor[
             0.3613433617487599, 0.48672321452944306`, 0.9442702081951819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 444}], {
             RGBColor[
             0.43364941819134256`, 0.5462951958354212, 0.9497218378452923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 486}], {
             RGBColor[
             0.35738466575242234`, 0.48329439102726157`, 0.9440179635868327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 420}], {
             RGBColor[
             0.1873361545684642, 0.31423255462265, 0.9339798889124447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 454}], {
             RGBColor[
             0.19901001769354992`, 0.3265025249327872, 0.9346446981474854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 489}], {
             RGBColor[
             0.1891243849825443, 0.31611209816820496`, 0.9340817259890768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 358}], {
             RGBColor[
             0.22833564415577742`, 0.35732561769669713`, 0.9363147491911328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 361}], {
             RGBColor[
             0.2309444912286668, 0.3600676813807619, 0.9364633191724905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 367}], {
             RGBColor[
             0.21446892121193922`, 0.34275081268170826`, 0.9355250598334595]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 386}], {
             RGBColor[
             0.268695341419697, 0.3997462184736812, 0.9386131742434916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 441}], {
             RGBColor[
             0.2266279051671714, 0.35553067574276653`, 0.936217495982105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 450}], {
             RGBColor[
             0.22365738515605757`, 0.35240847086923904`, 0.9360483292619628]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 461}], {
             RGBColor[
             0.24252993321129454`, 0.3722447154639515, 0.9371230929542755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 385}], {
             RGBColor[
             0.18420532827080235`, 0.310941857677955, 0.9338015929864353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 415}], {
             RGBColor[
             0.18362714398561458`, 0.31033414933522163`, 0.9337686662467408]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 446}], {
             RGBColor[
             0.18513113872334164`, 0.31191494316334684`, 0.9338543165220936]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 409}], {
             RGBColor[
             0.23180434544224413`, 0.3609714426771376, 0.9365122865979134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 421}], {
             RGBColor[
             0.19735590244149465`, 0.3247639449259127, 0.9345504987309252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 430}], {
             RGBColor[
             0.2059656395327683, 0.33381332449770196`, 0.9350408105213086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 459}], {
             RGBColor[
             0.2024275249318897, 0.3300945417227562, 0.93483932012896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 354}], {
             RGBColor[
             0.4679691659715405, 0.5750820152163606, 0.9523301949713454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 388}], {
             RGBColor[
             0.4770192723969674, 0.5829207625304905, 0.9529068597500787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 436}], {
             RGBColor[
             0.49043574205618756`, 0.5945414342179349, 0.953761745333046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 420}], {
             RGBColor[
             0.18856527989536503`, 0.3155244432722696, 0.9340498857814837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 427}], {
             RGBColor[
             0.18780005171862202`, 0.314720139940244, 0.9340063071688718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 433}], {
             RGBColor[
             0.1848796930167158, 0.31165065778310447`, 0.9338399970610818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 500}], {
             RGBColor[
             0.1950373272242134, 0.32232697536639066`, 0.9344184593023257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 383}], {
             RGBColor[
             0.34605340544318985`, 0.47036770113504156`, 0.9434098957217043]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 395}], {
             RGBColor[
             0.4642366864681818, 0.5751402530845398, 0.9511830173068838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 443}], {
             RGBColor[
             0.3560845115696105, 0.4809110296827722, 0.9439811523759123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 480}], {
             RGBColor[
             0.3338467491074454, 0.4575377313794614, 0.9427147447015134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 344}], {
             RGBColor[
             0.1852310273425353, 0.3120199324354236, 0.9338600050311847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 387}], {
             RGBColor[
             0.1845385025539545, 0.3112920449740175, 0.9338205667689736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 439}], {
             RGBColor[
             0.18970826562688875`, 0.316725793745582, 0.9341149771279982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 384}], {
             RGBColor[
             0.3159339914529744, 0.4443075647988586, 0.9414896959063039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 414}], {
             RGBColor[
             0.3932297908847611, 0.5150176133855842, 0.946277232449094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 461}], {
             RGBColor[
             0.30853231078714655`, 0.43652792912541416`, 0.9410681811421904]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 499}], {
             RGBColor[
             0.4961829212208138, 0.5994318600646289, 0.9541521247756388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 374}], {
             RGBColor[
             0.9208708140731814, 0.677947066838142, 0.406871876564454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 391}], {
             RGBColor[
             0.7337060308144916, 0.7866728844187078, 0.7861711023616725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 397}], {
             RGBColor[
             0.9081535473454794, 0.5801965820272107, 0.39469380758390815`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 455}], {
             RGBColor[
             0.8036709694912352, 0.8434735735210568, 0.7916789986243209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 485}], {
             RGBColor[
             0.36582891890395064`, 0.48572268889805037`, 0.9448845663511518]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 374}], {
             RGBColor[
             0.8468374551199298, 0.3610187811212927, 0.19248490595917145`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 403}], {
             RGBColor[
             0.7948197503279848, 0.5779151298917289, 0.5834817504053871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 440}], {
             RGBColor[
             0.8689315587996673, 0.47858233066244793`, 0.21159581872549427`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 445}], {
             RGBColor[
             0.9046747150389304, 0.6218037867421315, 0.25156389718325395`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 471}], {
             RGBColor[
             0.901533639219245, 0.661841877888372, 0.5749261182612281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 387}], {
             RGBColor[
             0.1895833056665427, 0.31659445290433924`, 0.9341078608431181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 438}], {
             RGBColor[
             0.19645882867909248`, 0.32382106352386636`, 0.934499411707258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 439}], {
             RGBColor[
             0.19475306873947695`, 0.32202820167590374`, 0.9344022712021427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 389}], {
             RGBColor[
             0.1928812337006961, 0.3200607843689489, 0.9342956729658158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 456}], {
             RGBColor[
             0.1932262687729535, 0.32042343810637863`, 0.9343153222027473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 472}], {
             RGBColor[
             0.1869884495343811, 0.3138670945860562, 0.9339600876251372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 355}], {
             RGBColor[
             0.5005625797661037, 0.605095092452838, 0.9539145635661582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 390}], {
             RGBColor[
             0.34866455216030523`, 0.47153274446045024`, 0.9436164276057963]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 395}], {
             RGBColor[
             0.47277817219066315`, 0.5825384587097979, 0.951727273224181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 431}], {
             RGBColor[
             0.43133365387154704`, 0.5480212643488988, 0.948705176904689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 443}], {
             RGBColor[
             0.3646259972920919, 0.4883092353080305, 0.9445254082932095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 486}], {
             RGBColor[
             0.4273749578752095, 0.5445924408467173, 0.9484529322963398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 382}], {
             RGBColor[
             0.2075732378156851, 0.3355030122206657, 0.9351323608652922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 462}], {
             RGBColor[
             0.19657186081581016`, 0.32393986746620806`, 0.934505848720228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 355}], {
             RGBColor[
             0.5108951424447806, 0.6138067180573811, 0.9546386835652754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 372}], {
             RGBColor[
             0.5381758194150634, 0.6359544006023488, 0.9567863183887886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 400}], {
             RGBColor[
             0.7259744000228323, 0.7821275326457193, 0.8841834386643934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 404}], {
             RGBColor[
             0.6494536944870786, 0.7234519269470636, 0.967547153420917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 418}], {
             RGBColor[
             0.4692928666535278, 0.5800321164088754, 0.9513636000208304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 431}], {
             RGBColor[
             0.44166621655022387`, 0.5567328899534418, 0.9494292969038062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 444}], {
             RGBColor[
             0.5139722729928065, 0.6163048712594199, 0.9548809265539167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 486}], {
             RGBColor[
             0.4377075205538863, 0.5533040664512603, 0.949177052295457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 353}], {
             RGBColor[
             0.18295144203234145`, 0.3096239437403533, 0.9337301860201135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 378}], {
             RGBColor[
             0.1960796577618784, 0.3234225308490497, 0.9344778184844558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 380}], {
             RGBColor[
             0.18633207943578872`, 0.3131772079961678, 0.9339227083190349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 487}], {
             RGBColor[
             0.1889676303182698, 0.3159473390772327, 0.9340727990428441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 377}], {
             RGBColor[
             0.181157971499196, 0.3077388924974179, 0.9336280505264527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 412}], {
             RGBColor[
             0.18588998404715956`, 0.3127125377122519, 0.9338975316406739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 426}], {
             RGBColor[
             0.1844406280385869, 0.3111891726527635, 0.9338149929601158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 476}], {
             RGBColor[
             0.18247717121909524`, 0.3091254550451252, 0.9337031769989198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 371}], {
             RGBColor[
             0.2471362919389416, 0.37708629054672044`, 0.937385418269318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 442}], {
             RGBColor[
             0.23904734061072216`, 0.3685842898316257, 0.936924764457707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 460}], {
             RGBColor[
             0.2704319943298352, 0.4015715507923906, 0.9387120740575761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 357}], {
             RGBColor[
             0.185968194480225, 0.3127947418362315, 0.9339019856091351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 367}], {
             RGBColor[
             0.1902708306368736, 0.3173170852397579, 0.9341470143730765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 368}], {
             RGBColor[
             0.1813119634696479, 0.3079007478220177, 0.9336368201413592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 375}], {
             RGBColor[
             0.19306738802691092`, 0.32025644436866674`, 0.9343062741793031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 380}], {
             RGBColor[
             0.18408835379335264`, 0.31081891008554513`, 0.9337949314629927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 487}], {
             RGBColor[
             0.18672390467583372`, 0.3135890411666101, 0.933945022186802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 388}], {
             RGBColor[
             0.3196378407891415, 0.45127596505171874`, 0.9415880184638075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 409}], {
             RGBColor[
             0.28191067367276634`, 0.4134660896464276, 0.9393720026838029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 436}], {
             RGBColor[
             0.33305431044836165`, 0.46289663673916315`, 0.9424429040467747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 473}], {
             RGBColor[
             0.28709080979716467`, 0.41891074115277027`, 0.9396670037727628]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 395}], {
             RGBColor[
             0.5319254348002241, 0.6308800567954042, 0.9562942652159951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 404}], {
             RGBColor[
             0.6982683944179626, 0.7630818994281268, 0.9713900254136139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 431}], {
             RGBColor[
             0.49048091648110803`, 0.596362862434505, 0.9532721688965031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 443}], {
             RGBColor[
             0.4237732599016528, 0.5366508333936366, 0.9490924002850236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 444}], {
             RGBColor[
             0.5627869729236907, 0.655934843740483, 0.9587237985466135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 486}], {
             RGBColor[
             0.48652222048477045`, 0.5929340389323234, 0.9530199242881539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 365}], {
             RGBColor[
             0.2261799618783253, 0.3550598589449443, 0.9361919862744781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 457}], {
             RGBColor[
             0.35728371097557365`, 0.477585785779042, 0.9443210439032999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 494}], {
             RGBColor[
             0.30030937836549265`, 0.4286701061729542, 0.9405711545959381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 367}], {
             RGBColor[
             0.19284697546686017`, 0.3200247767930899, 0.9342937220100794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 368}], {
             RGBColor[
             0.18388810829963448`, 0.3106084393753497, 0.9337835277783622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 441}], {
             RGBColor[
             0.20500595942209238`, 0.33280463985414815`, 0.9349861581587251]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 492}], {
             RGBColor[
             0.1855765306994534, 0.3123830783697226, 0.9338796809362347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 361}], {
             RGBColor[
             0.2274919045840746, 0.3564387939106588, 0.9362666994707252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 386}], {
             RGBColor[
             0.2652427547751048, 0.39611733100357804`, 0.9384165545417262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 398}], {
             RGBColor[
             0.21557110150214517`, 0.3439092740489813, 0.935587827370457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 441}], {
             RGBColor[
             0.22317531852257919`, 0.3519017882726634, 0.9360208762803397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 408}], {
             RGBColor[
             0.923405109023163, 0.9417213092494618, 0.9911392082523272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 440}], {
             RGBColor[
             0.9005793035034079, 0.7657528918366445, 0.6112602253720522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 463}], {
             RGBColor[
             0.7323426131107887, 0.7902188270608363, 0.9746779559842911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 483}], {
             RGBColor[
             0.6807834462506754, 0.7483260934744262, 0.970628611472146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 457}], {
             RGBColor[
             0.5327073882194472, 0.6315148818077295, 0.9563558234535461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 494}], {
             RGBColor[
             0.4757330556093662, 0.5825992022016417, 0.9526059341461844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 386}], {
             RGBColor[
             0.26785160184799417`, 0.39885939468764287`, 0.9385651245230838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 398}], {
             RGBColor[
             0.21817994857503456`, 0.3466513377330461, 0.9357363973518147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 441}], {
             RGBColor[
             0.22578416559546857`, 0.3546438519567282, 0.9361694462616974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 481}], {
             RGBColor[
             0.217684758794606, 0.34613086187697023`, 0.935708197026387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 369}], {
             RGBColor[
             0.1806318866536843, 0.30718594396907933`, 0.9335980907727736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 470}], {
             RGBColor[
             0.1869253840691414, 0.31380080878350786`, 0.9339564961401887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 381}], {
             RGBColor[
             0.18545627477246146`, 0.3122566817657879, 0.9338728325390953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 378}], {
             RGBColor[
             0.20567802361676119`, 0.3335110219340761, 0.9350244312203816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 380}], {
             RGBColor[
             0.19593044529067147`, 0.3232656990811941, 0.9344693210549606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 381}], {
             RGBColor[
             0.19634549402636683`, 0.3237019416180197, 0.9344929574664489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 416}], {
             RGBColor[
             0.20681043357905127`, 0.33470125660338146`, 0.9350889202924836]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 452}], {
             RGBColor[
             0.21560011293675418`, 0.34393976690618655`, 0.9355894795287394]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 468}], {
             RGBColor[
             0.21294670143418915`, 0.3411508631809846, 0.9354383716690389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 487}], {
             RGBColor[
             0.19856599617315254`, 0.3260358301622591, 0.9346194117787698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 405}], {
             RGBColor[
             0.18210802697612394`, 0.3087374610406655, 0.9336821547803826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 423}], {
             RGBColor[
             0.18087837131958237`, 0.30744501498096866`, 0.933612127709855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 429}], {
             RGBColor[
             0.18725297443025463`, 0.3141451270234664, 0.9339751519266276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 465}], {
             RGBColor[
             0.18080307297570358`, 0.30736587164736134`, 0.9336078395805651]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 469}], {
             RGBColor[
             0.1819546848445577, 0.30857628873793674`, 0.9336734221728392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 488}], {
             RGBColor[
             0.1825427715517224, 0.30919440515401764`, 0.933706912840816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 368}], {
             RGBColor[
             0.1881907444562831, 0.3151307827788761, 0.9340285565423035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 375}], {
             RGBColor[
             0.19994616901354612`, 0.3274864793255251, 0.9346980105802476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 441}], {
             RGBColor[
             0.20930859557874099`, 0.3373269832576745, 0.9352311869226664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 450}], {
             RGBColor[
             0.20633807556762712`, 0.3342047783841471, 0.9350620202025242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 492}], {
             RGBColor[
             0.18092029968887635`, 0.3074890843555088, 0.9336145154684589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 456}], {
             RGBColor[
             0.1888191818250698, 0.31579131029870144`, 0.9340643451207662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 390}], {
             RGBColor[
             0.24233683264276484`, 0.3720417545231436, 0.9371120961625645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 422}], {
             RGBColor[
             0.21765000410983476`, 0.3460943324997014, 0.9357062177985042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 443}], {
             RGBColor[
             0.2582982777745515, 0.38881824537072385`, 0.9380210768499777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 451}], {
             RGBColor[
             0.21692330433294027`, 0.34533052495875827`, 0.935664833321266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 442}], {
             RGBColor[
             0.24599324612330464`, 0.37588487692119543`, 0.9373203235011023]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 460}], {
             RGBColor[
             0.2773778998424177, 0.4088721378819603, 0.9391076331009713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 400}], {
             RGBColor[
             0.8020697769239993, 0.8439051876717503, 0.8901739454806034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 404}], {
             RGBColor[
             0.7255490713882455, 0.7852295819730946, 0.9735376602371271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 418}], {
             RGBColor[
             0.5453882435546948, 0.6418097714349063, 0.9573541068370404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 431}], {
             RGBColor[
             0.5177615934513908, 0.6185105449794727, 0.9554198037200161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 444}], {
             RGBColor[
             0.5900676498939734, 0.6780825262854508, 0.9608714333701266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 486}], {
             RGBColor[
             0.5138028974550533, 0.6150817214772912, 0.955167559111667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 449}], {
             RGBColor[
             0.9873031183402635, 0.9734548154410307, 0.5948195031122866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 498}], {
             RGBColor[
             0.8827929559209364, 0.907189051483757, 0.8884954173694475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 397}], {
             RGBColor[
             0.8347270315445021, 0.26793275869910615`, 0.18088795066657473`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 445}], {
             RGBColor[
             0.9052815581912046, 0.6264682491308763, 0.2521450108712031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 402}], {
             RGBColor[
             0.21043597475918854`, 0.33851193025629345`, 0.9352953894991849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 417}], {
             RGBColor[
             0.1999369421366619, 0.32747678129290203`, 0.9346974851232589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 441}], {
             RGBColor[
             0.2121051529687783, 0.3402663423865834, 0.9353904467288932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 450}], {
             RGBColor[
             0.20913463295766446`, 0.3371441375130559, 0.9352212800087508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 461}], {
             RGBColor[
             0.22800718101290143`, 0.35698038210776833`, 0.9362960437010637]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 391}], {
             RGBColor[
             0.4221118184289103, 0.5394962463103177, 0.9482660902046844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 448}], {
             RGBColor[
             0.33584647853732147`, 0.4645604445371366, 0.9426484491510583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 455}], {
             RGBColor[
             0.4920767571056538, 0.5962969354126668, 0.9537739864673327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 475}], {
             RGBColor[
             0.3538187512223421, 0.4808817516864462, 0.9437659958516187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 482}], {
             RGBColor[
             0.35174044974950636`, 0.47908163140914517`, 0.9436335683195394]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 412}], {
             RGBColor[
             0.18552364470094684`, 0.3123274918321262, 0.9338766691568576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 426}], {
             RGBColor[
             0.1840742886923742, 0.31080412677263786`, 0.9337941304762996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 476}], {
             RGBColor[
             0.18211083187288252`, 0.3087404091649995, 0.9336823145151034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 380}], {
             RGBColor[
             0.19721656952288963`, 0.32461749719424154`, 0.9345425639273353]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 416}], {
             RGBColor[
             0.2080965578112694, 0.3360530547164289, 0.9351621631648581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 452}], {
             RGBColor[
             0.21688623716897232`, 0.34529156501923397`, 0.935662722401114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 487}], {
             RGBColor[
             0.1998521204053707, 0.32738762827530654`, 0.9346926546511444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 400}], {
             RGBColor[
             0.9086464403656656, 0.6009403996477325, 0.49573306309233295`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 404}], {
             RGBColor[
             0.8321257348299118, 0.5422647939490768, 0.5790967778488565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 440}], {
             RGBColor[
             0.8595285144156211, 0.406306411086346, 0.20259145280411195`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 487}], {
             RGBColor[
             0.19010454207928099`, 0.31714230542242455`, 0.9341375444857234]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 416}], {
             RGBColor[
             0.19876402822087508`, 0.3262439744003725, 0.9346306894109254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 468}], {
             RGBColor[
             0.20490029607601296`, 0.33269358097797563`, 0.9349801407874807]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 425}], {
             RGBColor[
             0.19937423959475875`, 0.32688534524395996`, 0.9346654400459413]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 462}], {
             RGBColor[
             0.20106839690715364`, 0.3286660119950647, 0.934761919798601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 393}], {
             RGBColor[
             0.24454516184141023`, 0.374362848527078, 0.9372378572434972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 395}], {
             RGBColor[
             0.3859577461997916, 0.503550871102866, 0.9463338532888385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 443}], {
             RGBColor[
             0.2778055713012203, 0.40932164770109847`, 0.9391319883578669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 480}], {
             RGBColor[
             0.2555678088390552, 0.3859483493977877, 0.937865580683468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 402}], {
             RGBColor[
             0.24310211003433443`, 0.3728461095830723, 0.937155677577888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 411}], {
             RGBColor[
             0.2746421437909936, 0.40599668481496154`, 0.9389518358410311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 458}], {
             RGBColor[
             0.25354859204463764`, 0.3838260245211157, 0.9377505892741895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 461}], {
             RGBColor[
             0.26067331628804735`, 0.3913145614345472, 0.9381563317797668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 499}], {
             RGBColor[
             0.4483239267217146, 0.554218492373762, 0.9512402754132152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 415}], {
             RGBColor[
             0.18097729894859016`, 0.30754899419142984`, 0.9336177614919767]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 446}], {
             RGBColor[
             0.18248129368631721`, 0.30912978801955504`, 0.9337034117673295]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 441}], {
             RGBColor[
             0.26353501578649874`, 0.39432238904964745`, 0.9383193013326985]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 498}], {
             RGBColor[
             0.540094387984412, 0.6311849610997022, 0.9594410817544053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 439}], {
             RGBColor[
             0.1940605439508961, 0.3213003142144977, 0.9343628329399316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 436}], {
             RGBColor[
             0.34210441687378856`, 0.470735384053293, 0.943019568825508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 473}], {
             RGBColor[
             0.2961409162225916, 0.4267494884669002, 0.9402436685514961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 456}], {
             RGBColor[
             0.1952664503716337, 0.322567798321576, 0.9344315075266139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 472}], {
             RGBColor[
             0.18902863113306126`, 0.3160114548012536, 0.9340762729490037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 422}], {
             RGBColor[
             0.23122695863113757`, 0.36036457253022636`, 0.9364794052731881]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 443}], {
             RGBColor[
             0.2718752322958543, 0.4030884854012488, 0.9387942643246616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 451}], {
             RGBColor[
             0.23050025885424308`, 0.3596007649892832, 0.93643802079595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 407}], {
             RGBColor[
             0.3751221590981358, 0.49587301171236503`, 0.9453789816308452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 448}], {
             RGBColor[
             0.38684939186323586`, 0.5081990768979878, 0.9460468301879315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 455}], {
             RGBColor[
             0.5430796704315681, 0.6399355677735181, 0.9571723675042059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 475}], {
             RGBColor[
             0.40482166454825647`, 0.5245203840472975, 0.9471643768884919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 478}], {
             RGBColor[
             0.36121422406998477`, 0.4812548901837663, 0.9445869453059381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{391, 482}], {
             RGBColor[
             0.4027433630754207, 0.5227202637699965, 0.9470319493564127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 413}], {
             RGBColor[
             0.23358028524334118`, 0.3628380680091775, 0.9366134237423184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 473}], {
             RGBColor[
             0.2502222365996353, 0.3803298140453018, 0.9375611582524985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 474}], {
             RGBColor[
             0.23318205607902553`, 0.3624195039082944, 0.9365907451805379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 490}], {
             RGBColor[
             0.2264092533563037, 0.355300858826219, 0.9362050440849425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 424}], {
             RGBColor[
             0.20739385044843295`, 0.3353144647238677, 0.935122145020107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 480}], {
             RGBColor[
             0.23233850550566576`, 0.36153287877149787`, 0.9365427062233063]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 467}], {
             RGBColor[
             0.18730056337306505`, 0.3141951460196734, 0.9339778620465191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 443}], {
             RGBColor[
             0.39598885232621217`, 0.5140941996505966, 0.9469051099430464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 430}], {
             RGBColor[
             0.19949732248348956`, 0.32701471316392194`, 0.9346724494343697]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 477}], {
             RGBColor[
             0.19761610506605493`, 0.32503743438212485`, 0.9345653168854586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 495}], {
             RGBColor[
             0.8540509182502993, 0.3729173999622112, 0.19768732648561016`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 399}], {
             RGBColor[
             0.2070690587330349, 0.3349730880380002, 0.9351036486124014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 464}], {
             RGBColor[
             0.20435657897174597`, 0.33212209982773555`, 0.9349491769027501]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 481}], {
             RGBColor[
             0.20576395571267658`, 0.3336013420152928, 0.9350293249261188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 496}], {
             RGBColor[
             0.19603720028339988`, 0.32337790534720917`, 0.9344754005938667]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 407}], {
             RGBColor[
             0.2425042792072058, 0.3722177514790964, 0.9371216319966944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 464}], {
             RGBColor[
             0.20516649221167577`, 0.332973369994367, 0.9349953002636049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 478}], {
             RGBColor[
             0.22859634417905478`, 0.3575996299504977, 0.9363295956717873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 481}], {
             RGBColor[
             0.20657386895260635`, 0.3344526121819243, 0.9350754482869736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 496}], {
             RGBColor[
             0.19684711352332962`, 0.3242291755138407, 0.9345215239547214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 404}], {
             RGBColor[
             0.9133476519960143, 0.9314027140164651, 0.9009347805127319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 418}], {
             RGBColor[
             0.7331868241624636, 0.7879829034782768, 0.8847512271126452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 431}], {
             RGBColor[
             0.7055601740591597, 0.7646836770228431, 0.882816923995621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 444}], {
             RGBColor[
             0.7778662305017423, 0.8242556583288213, 0.8882685536457314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 428}], {
             RGBColor[
             0.18425068425914937`, 0.3109895296974434, 0.9338041759428735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 437}], {
             RGBColor[
             0.18132345879022535`, 0.30791283013279, 0.9336374747828603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 451}], {
             RGBColor[
             0.192907026989333, 0.3200878947506953, 0.934297141855446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 417}], {
             RGBColor[
             0.20763019049226705`, 0.33556287309476157`, 0.9351356042359695]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 458}], {
             RGBColor[
             0.2285757051250969, 0.3575779369961964, 0.9363284203081972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 461}], {
             RGBColor[
             0.23570042936850655`, 0.3650664739096279, 0.9367341628137743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 440}], {
             RGBColor[
             0.8175206971599966, 0.7001431418216288, 0.6031737768596591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 445}], {
             RGBColor[
             0.8532638533992596, 0.8433645979013125, 0.6431418553174187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 471}], {
             RGBColor[
             0.8501227775795742, 0.8834026890475528, 0.9665040763953929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 483}], {
             RGBColor[
             0.5977248399072642, 0.6827163434594106, 0.9625421629597528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 497}], {
             RGBColor[
             0.6107955480026974, 0.6933624123353453, 0.9635615550100725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 418}], {
             RGBColor[
             0.6566661186267099, 0.7293072977796211, 0.9681149418691689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 431}], {
             RGBColor[
             0.629039468523406, 0.7060080713241875, 0.9661806387521447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 444}], {
             RGBColor[
             0.7013455249659886, 0.7655800526301657, 0.9716322684022551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 486}], {
             RGBColor[
             0.6250807725270684, 0.7025792478220061, 0.9659283941437955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 423}], {
             RGBColor[
             0.18042956728835297`, 0.30697329348832747`, 0.9335865689842227]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 429}], {
             RGBColor[
             0.1868041703990252, 0.3136734055308251, 0.9339495932009951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 472}], {
             RGBColor[
             0.1823975349558204, 0.3090417522831926, 0.9336986418315376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 488}], {
             RGBColor[
             0.182093967520493, 0.30872268366137645`, 0.9336813541151835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 419}], {
             RGBColor[
             0.5328942370686292, 0.630560819878426, 0.9567192886891854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 493}], {
             RGBColor[
             0.33870341661598447`, 0.4633663515821581, 0.9429648172026237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 448}], {
             RGBColor[
             0.28885681920654693`, 0.42093720993918393`, 0.9397613405772192]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 455}], {
             RGBColor[
             0.44508709777487926`, 0.5526737008147141, 0.9508868778934936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 475}], {
             RGBColor[
             0.3068290918915676, 0.4372585170884935, 0.9408788872777796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 478}], {
             RGBColor[
             0.2632216514132959, 0.39399302322496244`, 0.9383014556952256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 482}], {
             RGBColor[
             0.3047507904187318, 0.43545839681119247`, 0.9407464597457003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{408, 463}], {
             RGBColor[
             0.746221620758815, 0.8012446952293572, 0.9745845586722801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 430}], {
             RGBColor[
             0.22739490707234228`, 0.3563368433758307, 0.9362611756059269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 422}], {
             RGBColor[
             0.19439415698617535`, 0.3216509626668643, 0.9343818317087544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 428}], {
             RGBColor[
             0.18501111447909718`, 0.3117887900726693, 0.9338474813189439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{410, 437}], {
             RGBColor[
             0.1820838890101732, 0.30871209050801585`, 0.9336807801589306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{412, 426}], {
             RGBColor[
             0.18880630124033773`, 0.3157777719874718, 0.9340636115905208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{412, 476}], {
             RGBColor[
             0.18684284442084606`, 0.31371405437983346`, 0.9339517956293248]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 474}], {
             RGBColor[
             0.2299117533537109, 0.35898220839482003`, 0.9364045062783105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 490}], {
             RGBColor[
             0.2231389506309891, 0.3518635633127446, 0.9360188051827152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 461}], {
             RGBColor[
             0.337969115719834, 0.4620246100212727, 0.9429438683225567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 498}], {
             RGBColor[
             0.5986264598736242, 0.6821731423501425, 0.9631600517720931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 499}], {
             RGBColor[
             0.5256197261535013, 0.6249285409604874, 0.9560278119560052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 452}], {
             RGBColor[
             0.2180186471312624, 0.3464817996885393, 0.935727211473216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 468}], {
             RGBColor[
             0.21536523562869736`, 0.3436928959633374, 0.9355761036135155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{417, 458}], {
             RGBColor[
             0.21807667250257026`, 0.34654278803280497`, 0.9357305159322711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 431}], {
             RGBColor[
             0.4488786406898552, 0.5625882607859993, 0.9499970853520581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 444}], {
             RGBColor[
             0.5211846971324379, 0.6221602420919774, 0.9554487150021684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 486}], {
             RGBColor[
             0.4449199446935177, 0.5591594372838178, 0.9497448407437088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 427}], {
             RGBColor[
             0.1872793778515779, 0.31417287869335075`, 0.9339766555624116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 454}], {
             RGBColor[
             0.19971846915340663`, 0.3272471523355135, 0.9346850434100643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 489}], {
             RGBColor[
             0.189832836442401, 0.3168567255709313, 0.9341220712516556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 500}], {
             RGBColor[
             0.19451665335716928`, 0.32177971411949735`, 0.9343888076958655]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 430}], {
             RGBColor[
             0.19294646407159283`, 0.3201293456246058, 0.9342993877389387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 459}], {
             RGBColor[
             0.18940834947071425`, 0.31641056284966007`, 0.9340978973465902]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 477}], {
             RGBColor[
             0.1910652466541582, 0.31815206684280867`, 0.9341922551900277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 428}], {
             RGBColor[
             0.19715708759112932`, 0.32455497791258914`, 0.9345391765193171]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 437}], {
             RGBColor[
             0.1942298621222053, 0.32147827834793574`, 0.9343724753593039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 451}], {
             RGBColor[
             0.20581343032131297`, 0.33365334296584104`, 0.9350321424318895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 429}], {
             RGBColor[
             0.18557451474248365`, 0.3123809594711283, 0.9338795661304677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 465}], {
             RGBColor[
             0.1791246132879326, 0.3056017040950233, 0.9335122537844052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 469}], {
             RGBColor[
             0.18027622515678673`, 0.30681212118559864`, 0.9335778363766793]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 488}], {
             RGBColor[
             0.18086431186395144`, 0.3074302376016796, 0.933611327044656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{425, 462}], {
             RGBColor[
             0.1883728625948838, 0.3153222004895023, 0.9340389279008772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 476}], {
             RGBColor[
             0.1853934884122734, 0.3121906893203451, 0.9338692569487667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 433}], {
             RGBColor[
             0.18359379097292866`, 0.3102990932041856, 0.9337667668420098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 500}], {
             RGBColor[
             0.19375142518042626`, 0.32097541078747177`, 0.9343452290832536]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 437}], {
             RGBColor[
             0.18484681961512717`, 0.31161610575374077`, 0.9338381249694931]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 451}], {
             RGBColor[
             0.19643038781423483`, 0.323791170371646, 0.934497792042079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{429, 488}], {
             RGBColor[
             0.1872389149746237, 0.3141303496441773, 0.9339743512614285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{430, 459}], {
             RGBColor[
             0.19801808656198788`, 0.32545994242144927`, 0.9345882091369736]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{430, 477}], {
             RGBColor[
             0.19967498374543186`, 0.3272014464145979, 0.9346825669804111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 444}], {
             RGBColor[
             0.4935580470291339, 0.5988610156365437, 0.9535144118851442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 486}], {
             RGBColor[
             0.4172932945902137, 0.5358602108283841, 0.9478105376266845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{432, 460}], {
             RGBColor[
             0.2959533208946317, 0.4283960831575556, 0.9401654758500221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 465}], {
             RGBColor[
             0.17986137360753812`, 0.306376085904231, 0.9335542111946675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 469}], {
             RGBColor[
             0.18101298547639227`, 0.3075865029948064, 0.9336197937869416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 495}], {
             RGBColor[
             0.9105859845179732, 0.6779864914594717, 0.24664336835265455`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{435, 439}], {
             RGBColor[
             0.21881441649795172`, 0.3473182037476218, 0.9357725293614136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{435, 453}], {
             RGBColor[
             0.2391644667053946, 0.36870739678334974`, 0.9369314346155262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 473}], {
             RGBColor[
             0.30955738588181175`, 0.4383701601543446, 0.9410985541344632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 439}], {
             RGBColor[
             0.2009360669634459, 0.3285269248340248, 0.9347543838040715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{439, 453}], {
             RGBColor[
             0.21958035723127328`, 0.3481232560217902, 0.9358161485530685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 445}], {
             RGBColor[
             0.9273756618709421, 0.7440317986720315, 0.27125592363752593`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 471}], {
             RGBColor[
             0.9242345860512566, 0.784069889818272, 0.5946181447155001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 450}], {
             RGBColor[
             0.21849705952285933`, 0.34698464144520536`, 0.9357544563511697]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 461}], {
             RGBColor[
             0.2373696075780963, 0.3668208860399178, 0.9368292200434826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 447}], {
             RGBColor[
             0.23581693788510275`, 0.36518893174763706`, 0.9367407978014356]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 500}], {
             RGBColor[
             0.21944649774055142`, 0.34798256120985954`, 0.9358085254530993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{443, 451}], {
             RGBColor[
             0.24646170398602968`, 0.37637725583686343`, 0.9373470014833631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{444, 486}], {
             RGBColor[
             0.4895993510327964, 0.5954321921343623, 0.953262167276795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{445, 471}], {
             RGBColor[
             0.9599777422905198, 0.9272913458979556, 0.6345862231732597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 454}], {
             RGBColor[
             0.2225609566268063, 0.3512560549674121, 0.9359858892792425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 500}], {
             RGBColor[
             0.21735914083056895`, 0.34578861675139594`, 0.9356896535650436]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 455}], {
             RGBColor[
             0.45681433053997933`, 0.564999766000337, 0.9515547264505798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 475}], {
             RGBColor[
             0.3185563246566676, 0.44958458227411635`, 0.9415467358348658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 478}], {
             RGBColor[
             0.2749488841783959, 0.4063190884105853, 0.938969304252312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{448, 482}], {
             RGBColor[
             0.3164780231838319, 0.4477844619968153, 0.9414143083027866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{449, 499}], {
             RGBColor[
             0.8060897526290038, 0.8328531529864611, 0.6773590298414771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 461}], {
             RGBColor[
             0.23439908756698247`, 0.3636986811663903, 0.9366600533233402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{452, 468}], {
             RGBColor[
             0.22415491498640028`, 0.35293140626614244`, 0.9360766628497713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 489}], {
             RGBColor[
             0.20150669956748674`, 0.32912669588106847`, 0.9347868804866963]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 500}], {
             RGBColor[
             0.206190516482255, 0.33404968442963456`, 0.9350536169309063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{455, 475}], {
             RGBColor[
             0.47478660322499994`, 0.5813210731496465, 0.9526722731511402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{455, 482}], {
             RGBColor[
             0.47270830175216416`, 0.5795209528723455, 0.952539845619061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{457, 494}], {
             RGBColor[
             0.4122768656126409, 0.531082608493518, 0.9476104304219592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{458, 461}], {
             RGBColor[
             0.24614691137880979`, 0.3760463888476713, 0.937329074510076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{459, 477}], {
             RGBColor[
             0.19613686914455325`, 0.32348266363965217`, 0.9344810765880625]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{460, 463}], {
             RGBColor[
             0.42791636353987605`, 0.5415498055841811, 0.9492787976467367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{463, 483}], {
             RGBColor[
             0.5035999579863275, 0.6078494794543214, 0.954073961892099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 481}], {
             RGBColor[
             0.2038613891913174, 0.3316016239716596, 0.9349209765773223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 496}], {
             RGBColor[
             0.1941346337620407, 0.32137818730357604`, 0.9343670522450702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{465, 469}], {
             RGBColor[
             0.18020092681290795`, 0.30673297785199133`, 0.9335735482473893]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 470}], {
             RGBColor[
             0.19475005924981162`, 0.3220250385114528, 0.9344020998161584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 491}], {
             RGBColor[
             0.1882565372451065, 0.3151999351714332, 0.9340323033442953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 483}], {
             RGBColor[
             0.7044387287985243, 0.7666430914560537, 0.9539865308155939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 497}], {
             RGBColor[
             0.7175094368939575, 0.7772891603319885, 0.9550059228659136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{472, 488}], {
             RGBColor[
             0.18283227953141887`, 0.3094986963965447, 0.933723399891971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{474, 490}], {
             RGBColor[
             0.22274072146667342`, 0.35144499921186156`, 0.9359961266209347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{475, 478}], {
             RGBColor[
             0.2929211568634166, 0.42264039555989485`, 0.9400868509528724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{475, 482}], {
             RGBColor[
             0.3344502958688525, 0.46410576914612495`, 0.942531855003347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{478, 482}], {
             RGBColor[
             0.2908428553905808, 0.4208402752825938, 0.939954423420793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{481, 496}], {
             RGBColor[
             0.19554201050297132`, 0.3228574294911333, 0.934447200268439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{484, 490}], {
             RGBColor[
             0.2003898909918431, 0.3279528592583135, 0.9347232798904836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{489, 500}], {
             RGBColor[
             0.19630488377124938`, 0.3236592576650523, 0.9344906447724974]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.028685633809430733`], {
             RGBColor[
             0.19927754620079638`, 0.32678371435619025`, 0.9346599335002002]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.028685633809430733`], {
             RGBColor[
             0.18419449056434983`, 0.3109304665613231, 0.9338009757950858]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.028685633809430733`], {
             RGBColor[
             0.18365861817242612`, 0.31036723070113925`, 0.9337704586551179]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.028685633809430733`], {
             RGBColor[
             0.18151204232925333`, 0.30811104338919537`, 0.9336482143364235]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.028685633809430733`], {
             RGBColor[
             0.6895762664964494, 0.7574214874515429, 0.9696941758539234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.028685633809430733`], {
             RGBColor[
             0.21439443043390383`, 0.3426725181510049, 0.9355208176938495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.028685633809430733`], {
             RGBColor[
             0.47235402937887205`, 0.5825173062131191, 0.951604585963978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.028685633809430733`], {
             RGBColor[
             0.19748659103157024`, 0.32490130692021735`, 0.9345579412527936]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.028685633809430733`], {
             RGBColor[
             0.1937919382554366, 0.32101799259798497`, 0.9343475362429416]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.028685633809430733`], {
             RGBColor[
             0.22678684537035088`, 0.355697731973699, 0.9362265473915452]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.028685633809430733`], {
             RGBColor[
             0.37557365642318313`, 0.49972475713808634`, 0.9451521991739089]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.028685633809430733`], {
             RGBColor[
             0.19403535624859544`, 0.3212738403423871, 0.9343613985375474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.028685633809430733`], {
             RGBColor[
             0.25294530714331137`, 0.3831919338393498, 0.9377162330915391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.028685633809430733`], {
             RGBColor[
             0.2309802119470121, 0.36010522612056717`, 0.9364653534145562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.028685633809430733`], {
             RGBColor[
             0.6524065300643914, 0.7283842068503593, 0.9659894438973117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.028685633809430733`], {
             RGBColor[
             0.27011669665931304`, 0.4012401529496448, 0.9386941183216809]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.028685633809430733`], {
             RGBColor[
             0.3754434746784675, 0.49961200025393837`, 0.9451439041082509]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.028685633809430733`], {
             RGBColor[
             0.2883133698343315, 0.42036601019230513`, 0.9397303919394328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.028685633809430733`], {
             RGBColor[
             0.20321773659331793`, 0.33092510428123034`, 0.934884321514065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.028685633809430733`], {
             RGBColor[
             0.24175756143219096`, 0.3714329037529144, 0.9370791075240773]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.028685633809430733`], {
             RGBColor[
             0.3000028152540131, 0.4326523584820372, 0.9403960885630988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.028685633809430733`], {
             RGBColor[
             0.1817982963009414, 0.30841191446298966`, 0.9336645160766364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.028685633809430733`], {
             RGBColor[
             0.4319501958436354, 0.5485552820168211, 0.9487444624139638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.028685633809430733`], {
             RGBColor[
             0.18529079599648704`, 0.31208275308027844`, 0.9338634087676074]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.028685633809430733`], {
             RGBColor[
             0.2888948585418871, 0.42097719169245956`, 0.9397635068610926]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.028685633809430733`], {
             RGBColor[
             0.1848952269737127, 0.31166698495681794`, 0.9338408816969523]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.028685633809430733`], {
             RGBColor[
             0.18521154867326725`, 0.3119994591190039, 0.933858895749786]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.028685633809430733`], {
             RGBColor[
             0.47584147550400935`, 0.5853485720851631, 0.951879130497885]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.028685633809430733`], {
             RGBColor[
             0.1844293578243088, 0.3111773269429844, 0.9338143511380854]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.028685633809430733`], {
             RGBColor[
             0.17893397678527326`, 0.30540133304367595`, 0.9335013973176001]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.028685633809430733`], {
             RGBColor[
             0.19198099569549876`, 0.3191145771471003, 0.9342444057432027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.028685633809430733`], {
             RGBColor[
             0.21967241372144744`, 0.34822001322968177`, 0.9358213910339986]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.028685633809430733`], {
             RGBColor[
             0.25627137654269866`, 0.3866878436630859, 0.9379056478233554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.028685633809430733`], {
             RGBColor[
             0.2089289231192469, 0.33692792343012196`, 0.9352095651377733]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.028685633809430733`], {
             RGBColor[
             0.187649142725438, 0.3145615250202248, 0.9339977131249598]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.028685633809430733`], {
             RGBColor[
             0.9941315043202534, 0.9918412404700345, 0.7469196908007765]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.028685633809430733`], {
             RGBColor[
             0.861854760386902, 0.4655965562049136, 0.20644056462819607`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.028685633809430733`], {
             RGBColor[
             0.5188198477638203, 0.6202403508392836, 0.9552625453971423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.028685633809430733`], {
             RGBColor[
             0.24759097892264678`, 0.3775641953954144, 0.937411312020391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.028685633809430733`], {
             RGBColor[
             0.18500874865393632`, 0.31178630344042324`, 0.9338473465887008]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.028685633809430733`], {
             RGBColor[
             0.2630876311955555, 0.3938521594787447, 0.9382938234420904]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.028685633809430733`], {
             RGBColor[
             0.2005501569047806, 0.3281213088942566, 0.9347324067971333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.028685633809430733`], {
             RGBColor[
             0.22836865224462058`, 0.35736031129090495`, 0.9363166289529613]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.028685633809430733`], {
             RGBColor[
             0.2790104916899246, 0.4105880954259918, 0.9392006067914836]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.028685633809430733`], {
             RGBColor[
             0.2011773237053474, 0.3287805009663242, 0.9347681230186154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.028685633809430733`], {
             RGBColor[
             0.2037103551444467, 0.3314428776122868, 0.934912375411788]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.028685633809430733`], {
             RGBColor[
             0.28160948378147765`, 0.4133198008998302, 0.9393486155462334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.028685633809430733`], {
             RGBColor[
             0.18988308106937135`, 0.3169095358595705, 0.9341249326088312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.028685633809430733`], {
             RGBColor[
             0.9939249281250245, 0.9894143604804412, 0.5801441012857329]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.028685633809430733`], {
             RGBColor[
             0.8803633253605091, 0.9074418350893442, 0.9884510339541455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.028685633809430733`], {
             RGBColor[
             0.9952524916716045, 0.9922538846693116, 0.7246412005584384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.028685633809430733`], {
             RGBColor[
             0.1799948891424975, 0.30651641919684713`, 0.9335618147068648]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.028685633809430733`], {
             RGBColor[
             0.8326746621018166, 0.2521573478086015, 0.17892259937043942`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.028685633809430733`], {
             RGBColor[
             0.9895254911096693, 0.9899365356383177, 0.8232532496802422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.028685633809430733`], {
             RGBColor[
             0.5735931996355866, 0.6647078254001658, 0.9595745042978867]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.028685633809430733`], {
             RGBColor[
             0.4068474012204774, 0.5268125030173851, 0.9471449345381059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.028685633809430733`], {
             RGBColor[
             0.9626408166905339, 0.9716581627746242, 0.9481235318941049]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.028685633809430733`], {
             RGBColor[
             0.19316750906165184`, 0.32036167792421966`, 0.9343119759241159]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.028685633809430733`], {
             RGBColor[
             0.26299592027232827`, 0.3937557654836245, 0.9382886006406869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.028685633809430733`], {
             RGBColor[
             0.9854928836228277, 0.9882689488092234, 0.890083991790846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.028685633809430733`], {
             RGBColor[
             0.9902590342278114, 0.9902398745688678, 0.8110965418638902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.028685633809430733`], {
             RGBColor[
             0.25119317281524384`, 0.3813503295688181, 0.9376164516336061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.028685633809430733`], {
             RGBColor[
             0.20681114074536727`, 0.3347019998800166, 0.9350889605645591]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.028685633809430733`], {
             RGBColor[
             0.18480592008610275`, 0.3115731177555562, 0.9338357958018207]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.028685633809430733`], {
             RGBColor[
             0.183179266829206, 0.30986340204678436`, 0.9337431603052583]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.028685633809430733`], {
             RGBColor[
             0.19788231111085003`, 0.3253172338136426, 0.9345804769258931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.028685633809430733`], {
             RGBColor[
             0.18087272641393248`, 0.30743908182722296`, 0.9336118062408292]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.028685633809430733`], {
             RGBColor[
             0.18542751526237852`, 0.31222645369723245`, 0.933871194727542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.028685633809430733`], {
             RGBColor[
             0.44285619720498837`, 0.5580015122444584, 0.9494393831769108]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.028685633809430733`], {
             RGBColor[
             0.3697431424982056, 0.49467465902642144`, 0.9447806839823304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.028685633809430733`], {
             RGBColor[
             0.19773867236084267`, 0.32516626038016205`, 0.9345722969115747]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.028685633809430733`], {
             RGBColor[
             0.21111609134757603`, 0.339226775912571, 0.9353341211327513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.028685633809430733`], {
             RGBColor[
             0.5768983856608343, 0.6673911243123956, 0.9598347006490895]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.028685633809430733`], {
             RGBColor[
             0.18870685733270803`, 0.31567325013544506`, 0.9340579484070953]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.028685633809430733`], {
             RGBColor[
             0.8653183386459826, 0.4813238561401438, 0.20933065922764493`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.028685633809430733`], {
             RGBColor[
             0.4104281337116228, 0.5299139535283672, 0.9473730956461243]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.028685633809430733`], {
             RGBColor[
             0.33446793820227666`, 0.46412105004860754`, 0.9425329791572322]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.028685633809430733`], {
             RGBColor[
             0.4700607186843903, 0.5806554932788695, 0.9514240481454346]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.028685633809430733`], {
             RGBColor[
             0.8862469572430673, 0.9121332834455631, 0.9890122200154841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.028685633809430733`], {
             RGBColor[
             0.3474160266946404, 0.4753360335108428, 0.9433580199064205]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.028685633809430733`], {
             RGBColor[
             0.23835692087692842`, 0.36785861491626903`, 0.9368854460752519]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.028685633809430733`], {
             RGBColor[
             0.5201221497039563, 0.62129761822232, 0.955365067376359]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.028685633809430733`], {
             RGBColor[
             0.9952268649647723, 0.9922942002460275, 0.7287667302186207]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.028685633809430733`], {
             RGBColor[
             0.27551545928723997`, 0.406914594772917, 0.9390015698665879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.028685633809430733`], {
             RGBColor[
             0.18726966457396857`, 0.31416266942272597`, 0.9339761024056213]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.028685633809430733`], {
             RGBColor[
             0.18531184315250615`, 0.31210487497572126`, 0.9338646073720063]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.028685633809430733`], {
             RGBColor[
             0.30841227476556676`, 0.4414912336192087, 0.9408749948416013]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.028685633809430733`], {
             RGBColor[
             0.18955897979005848`, 0.3165688848658047, 0.9341064755204392]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.028685633809430733`], {
             RGBColor[
             0.30968149308884285`, 0.4426522770943059, 0.940953608792397]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.028685633809430733`], {
             RGBColor[
             0.2623509631444437, 0.39307787464957405`, 0.9382518712863824]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.028685633809430733`], {
             RGBColor[
             0.46032419676718667`, 0.5727509461611696, 0.9506575534740573]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.028685633809430733`], {
             RGBColor[
             0.27193911320159614`, 0.4031556282834669, 0.9387979022477403]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.028685633809430733`], {
             RGBColor[
             0.2226303791602024, 0.3513290224516542, 0.935989842789818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.028685633809430733`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.028685633809430733`], {
             RGBColor[
             0.1846806812934658, 0.3114414838438967, 0.9338286636378542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.028685633809430733`], {
             RGBColor[
             0.4707743379765772, 0.5812348415684494, 0.9514802268701891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.028685633809430733`], {
             RGBColor[
             0.9884567952610653, 0.9727242013215213, 0.40965725865088887`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.028685633809430733`], {
             RGBColor[
             0.18830185869099547`, 0.3152475708846082, 0.9340348843335916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.028685633809430733`], {
             RGBColor[
             0.9796979203258498, 0.9843793227373989, 0.9192503046446351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.028685633809430733`], {
             RGBColor[
             0.9932268871291124, 0.987921321372956, 0.5041666466903745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.028685633809430733`], {
             RGBColor[
             0.24511118458418202`, 0.3749577743176459, 0.9372700914013423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.028685633809430733`], {
             RGBColor[
             0.19944242864104303`, 0.32695701625504003`, 0.9346693233112505]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.028685633809430733`], {
             RGBColor[
             0.40980409560216274`, 0.5293734430830204, 0.9473333324896046]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.028685633809430733`], {
             RGBColor[
             0.9241317229671294, 0.73691459370894, 0.25781280732325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.028685633809430733`], {
             RGBColor[
             0.1914252698739526, 0.31853047407360313`, 0.9342127579797883]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.028685633809430733`], {
             RGBColor[
             0.17964740484760663`, 0.30615119117114004`, 0.9335420259903278]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.028685633809430733`], {
             RGBColor[
             0.21128649273995928`, 0.33940587858003807`, 0.9353438252399612]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.028685633809430733`], {
             RGBColor[
             0.20961363351384976`, 0.337647597467996, 0.9352485583818076]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.028685633809430733`], {
             RGBColor[
             0.2136359512540558, 0.3418753084426271, 0.9354776234266265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.028685633809430733`], {
             RGBColor[
             0.4170759329154467, 0.5356719430706164, 0.9477966875329739]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.028685633809430733`], {
             RGBColor[
             0.3665915053486955, 0.49194486933340476`, 0.9445798644500469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.028685633809430733`], {
             RGBColor[
             0.9934414779456845, 0.9915558968312813, 0.7583552135583986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.028685633809430733`], {
             RGBColor[
             0.19671677940387242`, 0.3240921860906307, 0.9345141016194304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.028685633809430733`], {
             RGBColor[
             0.18143431560131953`, 0.3080293476699778, 0.9336437879142542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.028685633809430733`], {
             RGBColor[
             0.19098661972276523`, 0.31806942495267926`, 0.934187777502603]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.028685633809430733`], {
             RGBColor[
             0.27647894211230134`, 0.40792727631039594`, 0.9390564387881299]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.028685633809430733`], {
             RGBColor[
             0.18356396795554494`, 0.3102677473220268, 0.933765068465289]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.028685633809430733`], {
             RGBColor[
             0.19221104916857337`, 0.3193563779335344, 0.9342575069481607]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.028685633809430733`], {
             RGBColor[
             0.18431898451928125`, 0.31106131760132866`, 0.9338080655416469]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.028685633809430733`], {
             RGBColor[
             0.1799037129149489, 0.30642058720078685`, 0.9335566223555891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.028685633809430733`], {
             RGBColor[
             0.20513244387794988`, 0.3329375830368321, 0.9349933612613692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.028685633809430733`], {
             RGBColor[
             0.18567855904381614`, 0.3124903166286185, 0.9338854912995088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.028685633809430733`], {
             RGBColor[
             0.18584647349383113`, 0.3126668053619753, 0.93389505377903]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.028685633809430733`], {
             RGBColor[
             0.18536877790044387`, 0.31216471700567533`, 0.9338678497216739]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.028685633809430733`], {
             RGBColor[
             0.7779497574122243, 0.8264595302183536, 0.978502419531181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.028685633809430733`], {
             RGBColor[
             0.4884562669939937, 0.5955898281066129, 0.9528722130934804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.028685633809430733`], {
             RGBColor[
             0.8321508631713839, 0.8689985264321587, 0.9838524862707736]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.028685633809430733`], {
             RGBColor[
             0.19425607642724724`, 0.32150583124461773`, 0.9343739682251954]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.028685633809430733`], {
             RGBColor[
             0.2893758023858067, 0.42148269416601997`, 0.9397908959015111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.028685633809430733`], {
             RGBColor[
             0.30291909395791666`, 0.43571755230258913`, 0.9405621663210384]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.028685633809430733`], {
             RGBColor[
             0.8337292727736055, 0.2602635475653142, 0.17993249574075687`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.028685633809430733`], {
             RGBColor[
             0.2723145403641676, 0.4035502260347864, 0.938819282269254]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.028685633809430733`], {
             RGBColor[
             0.19798057442534764`, 0.32542051478743356`, 0.9345860728762861]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.028685633809430733`], {
             RGBColor[
             0.18413129784782198`, 0.3108640470096027, 0.9337973770633647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.028685633809430733`], {
             RGBColor[
             0.17999586170885287`, 0.3065174414257509, 0.93356187009308]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.028685633809430733`], {
             RGBColor[
             0.5282221961294052, 0.6278736008134325, 0.956002732702418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.028685633809430733`], {
             RGBColor[
             0.2116557852103354, 0.33979402838089834`, 0.9353648558998299]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.028685633809430733`], {
             RGBColor[
             0.1827700546655207, 0.3094332941172014, 0.9337198562779115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.028685633809430733`], {
             RGBColor[
             0.18259939511325524`, 0.3092539201073298, 0.9337101374688782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.028685633809430733`], {
             RGBColor[
             0.17901437519538227`, 0.3054858368702541, 0.933505975888117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.028685633809430733`], {
             RGBColor[
             0.2073090188644706, 0.33522530135049017`, 0.9351173139868973]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.028685633809430733`], {
             RGBColor[
             0.21571267720568413`, 0.3440580790898188, 0.9355958898973311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.028685633809430733`], {
             RGBColor[
             0.5806518106608889, 0.6704383238173092, 0.9601301840143426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.028685633809430733`], {
             RGBColor[
             0.1968786888055324, 0.3242623631374243, 0.9345233221203314]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.028685633809430733`], {
             RGBColor[
             0.20904447312210606`, 0.33704937380942024`, 0.9352161455394953]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.028685633809430733`], {
             RGBColor[
             0.1800731039927536, 0.30659862796357423`, 0.9335662689268784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.028685633809430733`], {
             RGBColor[
             0.8190803262063154, 0.147665325039805, 0.16590464796430104`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.028685633809430733`], {
             RGBColor[
             0.27463540520047075`, 0.4059896021290707, 0.9389514520882697]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.028685633809430733`], {
             RGBColor[
             0.5611296111138018, 0.6545893227599167, 0.9585933249538227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.028685633809430733`], {
             RGBColor[
             0.2153604952721365, 0.34368791354803596`, 0.9355758336572221]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.028685633809430733`], {
             RGBColor[
             0.20371318105767475`, 0.33144584782626274`, 0.9349125363433657]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.028685633809430733`], {
             RGBColor[
             0.18423542654322242`, 0.31097349287060916`, 0.9338033070385232]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.028685633809430733`], {
             RGBColor[
             0.22763715789209957`, 0.35659146434698463`, 0.9362749714317341]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.028685633809430733`], {
             RGBColor[
             0.9834670894693087, 0.9871903629131425, 0.9128700844415136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.028685633809430733`], {
             RGBColor[
             0.19392286855916088`, 0.32115560864865994`, 0.9343549925300447]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.028685633809430733`], {
             RGBColor[
             0.19939483773806957`, 0.32690699519857735`, 0.9346666130797306]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.028685633809430733`], {
             RGBColor[
             0.29909565256278264`, 0.4316988729761172, 0.9403444269898601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.028685633809430733`], {
             RGBColor[
             0.19170728594478786`, 0.3188268908449026, 0.9342288183778169]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.028685633809430733`], {
             RGBColor[
             0.2321162208184409, 0.36129924347156134`, 0.9365300474392095]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.028685633809430733`], {
             RGBColor[
             0.23944883454874902`, 0.3690062854166779, 0.9369476289435206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.028685633809430733`], {
             RGBColor[
             0.2138505894071634, 0.34210090675038807`, 0.9354898467519174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.028685633809430733`], {
             RGBColor[
             0.18332605976082084`, 0.310017690725121, 0.933751519945553]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.028685633809430733`], {
             RGBColor[
             0.899308535201446, 0.6356654000864056, 0.23769291240948212`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.028685633809430733`], {
             RGBColor[
             0.3160253373259164, 0.44814699612157666`, 0.9413578329375422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.028685633809430733`], {
             RGBColor[
             0.3059265832870255, 0.43887861427331937`, 0.9407334383891494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.028685633809430733`], {
             RGBColor[
             0.19568177386369887`, 0.32300432964476683`, 0.934455159585071]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.028685633809430733`], {
             RGBColor[
             0.23986313789965336`, 0.369441744506828, 0.9369712229064477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.028685633809430733`], {
             RGBColor[
             0.29271248717825876`, 0.424989761440922, 0.9399809151642584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.028685633809430733`], {
             RGBColor[
             0.18381241008660495`, 0.31052887575391175`, 0.9337792168771156]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.028685633809430733`], {
             RGBColor[
             0.1877350381466607, 0.3146518065540141, 0.9340026047421276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.028685633809430733`], {
             RGBColor[
             0.47069483175957283`, 0.581170294839771, 0.9514739678495456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.028685633809430733`], {
             RGBColor[
             0.22349209680564214`, 0.35223474233306573`, 0.9360389163349288]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.028685633809430733`], {
             RGBColor[
             0.720597203195575, 0.7816552789687509, 0.9727860529169569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.028685633809430733`], {
             RGBColor[
             0.18747717117288942`, 0.31438077201487, 0.9339879195994514]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.028685633809430733`], {
             RGBColor[
             0.39767741348965524`, 0.5188699205419315, 0.9465606310285997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.028685633809430733`], {
             RGBColor[
             0.3169334821091241, 0.44893358548810713`, 0.9414156991200873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.028685633809430733`], {
             RGBColor[
             0.18438238961983267`, 0.3111279603821238, 0.9338116763683237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.028685633809430733`], {
             RGBColor[
             0.46930938565191127`, 0.5800455272759355, 0.9513649004568943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.028685633809430733`], {
             RGBColor[
             0.2001120590885424, 0.3276608403123844, 0.9347074577746062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.028685633809430733`], {
             RGBColor[
             0.26314504718325327`, 0.39391250732219896`, 0.9382970931976505]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.028685633809430733`], {
             RGBColor[
             0.22551745991005276`, 0.354363527371239, 0.9361542577674687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.028685633809430733`], {
             RGBColor[
             0.34499714152995936`, 0.4732409167578995, 0.9432038906826632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.028685633809430733`], {
             RGBColor[
             0.19696480621086881`, 0.3243528779905917, 0.934528226379166]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.028685633809430733`], {
             RGBColor[
             0.5408355089237035, 0.6381136563631097, 0.9569956988896724]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.028685633809430733`], {
             RGBColor[
             0.21154093935996757`, 0.33967331811051427`, 0.9353583155985506]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.028685633809430733`], {
             RGBColor[
             0.9933232264913885, 0.9881273815274607, 0.5146525917364964]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.028685633809430733`], {
             RGBColor[
             0.22124625332801934`, 0.34987421844338334`, 0.9359110188713058]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.028685633809430733`], {
             RGBColor[
             0.2239766808649284, 0.35274407090377946`, 0.9360665126802272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.028685633809430733`], {
             RGBColor[
             0.2519720376195532, 0.38216896586102805`, 0.9376608068319842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.028685633809430733`], {
             RGBColor[
             0.21654397156564814`, 0.3449318221692476, 0.9356432308813413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.028685633809430733`], {
             RGBColor[
             0.19059661539563244`, 0.31765950567716017`, 0.9341655673331324]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.028685633809430733`], {
             RGBColor[
             0.3129892535839804, 0.4455172929823175, 0.9411643763662094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.028685633809430733`], {
             RGBColor[
             0.18092386766537458`, 0.30749283452503123`, 0.9336147186594421]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.028685633809430733`], {
             RGBColor[
             0.18610703405965695`, 0.3129406710371523, 0.933909892317789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.028685633809430733`], {
             RGBColor[
             0.18809486651088786`, 0.3150300089792529, 0.934023096435152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.028685633809430733`], {
             RGBColor[
             0.19199615165670597`, 0.3191305070232725, 0.9342452688527721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.028685633809430733`], {
             RGBColor[
             0.23089370286527677`, 0.3600142995906707, 0.93646042685033]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.028685633809430733`], {
             RGBColor[
             0.1824115868132323, 0.30905652167627173`, 0.9336994420640293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.028685633809430733`], {
             RGBColor[
             0.3861343022549474, 0.5088718577640675, 0.9458251141878965]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.028685633809430733`], {
             RGBColor[
             0.26297543885551555`, 0.39373423821595743`, 0.938287434254299]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.028685633809430733`], {
             RGBColor[
             0.25745169920403105`, 0.3879284376169253, 0.9379728654527874]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.028685633809430733`], {
             RGBColor[
             0.18676020758344578`, 0.31362719782424764`, 0.9339470895836851]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.028685633809430733`], {
             RGBColor[
             0.8450710458930704, 0.34744138575819206`, 0.19079339048865696`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.028685633809430733`], {
             RGBColor[
             0.3159031668134525, 0.44804117816414885`, 0.941350048340519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.028685633809430733`], {
             RGBColor[
             0.23748131534596645`, 0.36693829798663086`, 0.936835581635606]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.028685633809430733`], {
             RGBColor[
             0.18041422854673403`, 0.3069571714983536, 0.933585695465579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.028685633809430733`], {
             RGBColor[
             0.8749870106263872, 0.5252270374274478, 0.21739843612893187`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.028685633809430733`], {
             RGBColor[
             0.42661470104868005`, 0.5439339445951966, 0.948404489403622]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.028685633809430733`], {
             RGBColor[
             0.9944761061763768, 0.9919837421934052, 0.7412087462437971]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.028685633809430733`], {
             RGBColor[
             0.19552365175645214`, 0.32283813328452987`, 0.9344461547649839]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.028685633809430733`], {
             RGBColor[
             0.1874830946539544, 0.31438699796903974`, 0.933988256932935]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.028685633809430733`], {
             RGBColor[
             0.1819457440050942, 0.3085668913487786, 0.9336729130052586]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.028685633809430733`], {
             RGBColor[
             0.20221750657572096`, 0.32987379911448994`, 0.9348273598942706]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.028685633809430733`], {
             RGBColor[
             0.1875451608924792, 0.3144522335209561, 0.9339917915134002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.028685633809430733`], {
             RGBColor[
             0.18496268734880916`, 0.3117378900882792, 0.9338447234655154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.028685633809430733`], {
             RGBColor[
             0.19991510326486814`, 0.3274538272539823, 0.934696241431818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.028685633809430733`], {
             RGBColor[
             0.18124242467150065`, 0.3078276581361505, 0.9336328600096782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.028685633809430733`], {
             RGBColor[
             0.28587662659874513`, 0.4178048385532594, 0.9395916230170046]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.028685633809430733`], {
             RGBColor[
             0.6695263659366376, 0.7417583527493299, 0.9676957891430948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.028685633809430733`], {
             RGBColor[
             0.21703333859134122`, 0.34544617794091254`, 0.9356710996095008]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.028685633809430733`], {
             RGBColor[
             0.9622752132426141, 0.884407577445488, 0.3079467564861062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.028685633809430733`], {
             RGBColor[
             0.1971022673351447, 0.32449735834774435`, 0.9345360545868381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.028685633809430733`], {
             RGBColor[
             0.20818468230621298`, 0.33614567914803034`, 0.9351671817244767]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.028685633809430733`], {
             RGBColor[
             0.20593429362604587`, 0.3337803779622914, 0.9350390254182929]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.028685633809430733`], {
             RGBColor[
             0.18396512493287584`, 0.310689388740023, 0.9337879137616893]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.028685633809430733`], {
             RGBColor[
             0.1869796895121246, 0.3138578872472471, 0.933959588754829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.028685633809430733`], {
             RGBColor[
             0.19315889756887425`, 0.3203526266993102, 0.9343114855123418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.028685633809430733`], {
             RGBColor[
             0.2582166797056685, 0.38873248062671145`, 0.9380164299606684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.028685633809430733`], {
             RGBColor[
             0.2348407472607494, 0.36416289350738135`, 0.9366852051895233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.028685633809430733`], {
             RGBColor[
             0.2058983382969339, 0.3337425866316952, 0.9350369778154911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.028685633809430733`], {
             RGBColor[
             0.7636579459089816, 0.81529465845023, 0.9770779453251097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.028685633809430733`], {
             RGBColor[
             0.2784596091749779, 0.41000908297481403`, 0.939169234847215]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.028685633809430733`], {
             RGBColor[
             0.9625574020842641, 0.9715959522978471, 0.948264731064506]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.028685633809430733`], {
             RGBColor[
             0.9263783006421346, 0.7458215255627042, 0.25962045645451476`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.028685633809430733`], {
             RGBColor[
             0.2171179053764417, 0.345535062993897, 0.9356759155628069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.028685633809430733`], {
             RGBColor[
             0.20835940299106456`, 0.3363293216657406, 0.9351771318090029]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.028685633809430733`], {
             RGBColor[
             0.2328901660883635, 0.3621127090212143, 0.9365741224773821]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.028685633809430733`], {
             RGBColor[
             0.48668906339049306`, 0.5941551326096759, 0.9527330923523326]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.028685633809430733`], {
             RGBColor[
             0.1966443508485099, 0.324016059086709, 0.9345099769203509]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.028685633809430733`], {
             RGBColor[
             0.9948059876224538, 0.9912988576566625, 0.6760419903119628]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.028685633809430733`], {
             RGBColor[
             0.21562994450375172`, 0.3439711217745316, 0.9355911783923481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.028685633809430733`], {
             RGBColor[
             0.9731128985329042, 0.9794682242662037, 0.9303970288913456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.028685633809430733`], {
             RGBColor[
             0.19657931914436805`, 0.32394770664240774`, 0.9345062734610058]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.028685633809430733`], {
             RGBColor[
             0.44672166802497704`, 0.5613495887845201, 0.9496856875594589]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.028685633809430733`], {
             RGBColor[
             0.2439252154854269, 0.3737112456000703, 0.9372025522156523]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.028685633809430733`], {
             RGBColor[
             0.2398990282396083, 0.3694794675296996, 0.9369732668082131]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.028685633809430733`], {
             RGBColor[
             0.18427930277709584`, 0.31101960957432406`, 0.9338058057251333]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.028685633809430733`], {
             RGBColor[
             0.18027294835259305`, 0.30680867705662973`, 0.933577649767528]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.028685633809430733`], {
             RGBColor[
             0.7269497450043649, 0.7866179329108834, 0.9734192149165786]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.028685633809430733`], {
             RGBColor[
             0.2196415898680099, 0.3481876154053738, 0.9358196356611451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.028685633809430733`], {
             RGBColor[
             0.23893002370274252`, 0.3684609823230175, 0.9369180834333524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.028685633809430733`], {
             RGBColor[
             0.18230687199160545`, 0.30894645975943874`, 0.9336934787098494]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.028685633809430733`], {
             RGBColor[
             0.37749249202520396`, 0.5013867560930751, 0.94527446568171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.028685633809430733`], {
             RGBColor[
             0.19242949370172294`, 0.3195859769880579, 0.9342699470411637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.028685633809430733`], {
             RGBColor[
             0.19717041562221144`, 0.32456898651830246`, 0.9345399355309701]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.028685633809430733`], {
             RGBColor[
             0.3115575299166111, 0.44427720590216613`, 0.9410731482001482]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.028685633809430733`], {
             RGBColor[
             0.9630526170636222, 0.8870299430768459, 0.31096682353032956`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.028685633809430733`], {
             RGBColor[
             0.41518076487513966`, 0.5340304437680178, 0.9476759291012767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.028685633809430733`], {
             RGBColor[
             0.6832732263253226, 0.7524975045649791, 0.9690659477149247]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.028685633809430733`], {
             RGBColor[
             0.20975080596055196`, 0.33779177440671543`, 0.935256370149719]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.028685633809430733`], {
             RGBColor[
             0.329292758612209, 0.4596385695997802, 0.9422032212899847]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.028685633809430733`], {
             RGBColor[
             0.34316736625512184`, 0.47165605738201455`, 0.9430872990201573]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.028685633809430733`], {
             RGBColor[
             0.22433819907190317`, 0.35312404946088816`, 0.9360871006072962]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.028685633809430733`], {
             RGBColor[
             0.8655438992520076, 0.482348074171085, 0.20951887252630852`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.028685633809430733`], {
             RGBColor[
             0.18432263905515192`, 0.3110651587502397, 0.9338082736620582]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.028685633809430733`], {
             RGBColor[
             0.9935833726583437, 0.9886838078737659, 0.5429678965735315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.028685633809430733`], {
             RGBColor[
             0.22925694712510034`, 0.35829396553143755`, 0.9363672160322901]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.028685633809430733`], {
             RGBColor[
             0.1863015188096388, 0.3131450868404286, 0.9339209679365861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.028685633809430733`], {
             RGBColor[
             0.6018738506410779, 0.6876673319152327, 0.961800860740477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.028685633809430733`], {
             RGBColor[
             0.18011392367187812`, 0.3066415320344512, 0.9335685935472172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.028685633809430733`], {
             RGBColor[
             0.20809576797568208`, 0.3360522245491482, 0.9351621181848899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.028685633809430733`], {
             RGBColor[
             0.25722683759211185`, 0.3876920938057486, 0.9379600599166416]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.028685633809430733`], {
             RGBColor[
             0.18715875648320013`, 0.3140460979873492, 0.9339697863539259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.028685633809430733`], {
             RGBColor[
             0.24408437678171757`, 0.37387853421388084`, 0.937211616216018]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.028685633809430733`], {
             RGBColor[
             0.48931236896480956`, 0.5962848502534754, 0.9529396085766279]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.028685633809430733`], {
             RGBColor[
             0.21359854810176626`, 0.34183599535807396`, 0.9354754933724367]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.028685633809430733`], {
             RGBColor[
             0.44322657405371796`, 0.5583223140551463, 0.9494629832622005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.028685633809430733`], {
             RGBColor[
             0.18446408847726348`, 0.3112138310612903, 0.9338163289973919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.028685633809430733`], {
             RGBColor[
             0.20798277523591915`, 0.3359334620155039, 0.9351556834155181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.028685633809430733`], {
             RGBColor[
             0.2534737690150518, 0.3837473807729669, 0.9377463282133454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.028685633809430733`], {
             RGBColor[
             0.8184239254643847, 0.14261994130068656`, 0.16527607787252963`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.028685633809430733`], {
             RGBColor[
             0.6967134214587186, 0.7629970871524544, 0.9704055407600571]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.028685633809430733`], {
             RGBColor[
             0.18231742038260904`, 0.3089575467871901, 0.9336940794251122]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.028685633809430733`], {
             RGBColor[
             0.20683017875346388`, 0.3347220100336056, 0.935090044750956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.028685633809430733`], {
             RGBColor[
             0.21438774917055564`, 0.3426654957196094, 0.9355204372057859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.028685633809430733`], {
             RGBColor[
             0.18739586640915007`, 0.3142953155531602, 0.933983289413436]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.028685633809430733`], {
             RGBColor[
             0.304153838987054, 0.4370153476155689, 0.9406324832238061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.028685633809430733`], {
             RGBColor[
             0.7112234006140565, 0.7743323931485304, 0.9718517598787967]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.028685633809430733`], {
             RGBColor[
             0.21007296758615746`, 0.3381303867014537, 0.9352747167777018]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.028685633809430733`], {
             RGBColor[
             0.18152659560596812`, 0.30812633980575366`, 0.9336490431240029]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.028685633809430733`], {
             RGBColor[
             0.18307944483465585`, 0.30975848280143214`, 0.933737475590342]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.028685633809430733`], {
             RGBColor[
             0.18511992750412062`, 0.3119031594611132, 0.9338536780597445]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.028685633809430733`], {
             RGBColor[
             0.8097488880926076, 0.8513012527882134, 0.9816718596976299]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.028685633809430733`], {
             RGBColor[
             0.18749202516745894`, 0.31439638450496027`, 0.9339887655124676]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.028685633809430733`], {
             RGBColor[
             0.9847959098179251, 0.9879807322294865, 0.9016346514484699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.028685633809430733`], {
             RGBColor[
             0.18222924951210637`, 0.30886487361193576`, 0.9336890582244741]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.028685633809430733`], {
             RGBColor[
             0.19526251556143404`, 0.32256366258657476`, 0.934431283444994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.028685633809430733`], {
             RGBColor[
             0.2756885017375273, 0.407096473359694, 0.9390114243781383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.028685633809430733`], {
             RGBColor[
             0.24007340415027964`, 0.3696627476678865, 0.9369831972583599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.028685633809430733`], {
             RGBColor[
             0.23186327956718236`, 0.36103338617908703`, 0.9365156428091433]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.028685633809430733`], {
             RGBColor[
             0.6564481594438648, 0.7315415584391249, 0.9663922757426836]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.028685633809430733`], {
             RGBColor[
             0.24476085053842922`, 0.3745895510230982, 0.9372501403957095]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.028685633809430733`], {
             RGBColor[
             0.8407980254541154, 0.31459707821488886`, 0.1867015412906274]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.028685633809430733`], {
             RGBColor[
             0.190709032669891, 0.3177776633600728, 0.934171969330595]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.028685633809430733`], {
             RGBColor[
             0.3105546519813193, 0.443408563440727, 0.9410092457049215]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.028685633809430733`], {
             RGBColor[
             0.24077004537273583`, 0.3703949617622926, 0.9370228699453904]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.028685633809430733`], {
             RGBColor[
             0.1917730045224159, 0.3188959652367882, 0.934232560953591]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.028685633809430733`], {
             RGBColor[
             0.19090439582770188`, 0.3179830024256716, 0.9341830949734184]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.028685633809430733`], {
             RGBColor[
             0.1881959331144625, 0.3151362363876026, 0.9340288520287109]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.028685633809430733`], {
             RGBColor[
             0.644812645752953, 0.7224518067106054, 0.9652325564780311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.028685633809430733`], {
             RGBColor[
             0.18998459744441062`, 0.31701623600624673`, 0.9341307138162097]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.028685633809430733`], {
             RGBColor[
             0.19496888133162707`, 0.3222550343935622, 0.9344145614099995]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.028685633809430733`], {
             RGBColor[
             0.36122042818933575`, 0.4872927122561548, 0.9442376241629096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.028685633809430733`], {
             RGBColor[
             0.2628079616436893, 0.3935582090476596, 0.9382778966748457]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.028685633809430733`], {
             RGBColor[
             0.18340993044876472`, 0.3101058441358588, 0.9337562962571558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.028685633809430733`], {
             RGBColor[
             0.43871305828747303`, 0.5544129335543235, 0.9491753860287206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.028685633809430733`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.028685633809430733`], {
             RGBColor[
             0.1979808475129809, 0.32542080181985084`, 0.9345860884282229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.028685633809430733`], {
             RGBColor[
             0.18086286172523808`, 0.3074287134139478, 0.9336112444614015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.028685633809430733`], {
             RGBColor[
             0.18113843442729957`, 0.3077183577961329, 0.9336269379191107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.028685633809430733`], {
             RGBColor[
             0.9854351531478911, 0.9882450757742316, 0.8910407351622261]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.028685633809430733`], {
             RGBColor[
             0.820782245844875, 0.16074702516771538`, 0.16753440813222906`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.028685633809430733`], {
             RGBColor[
             0.9927101178720487, 0.9912534606457363, 0.7704757426777427]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.028685633809430733`], {
             RGBColor[
             0.9397327677393429, 0.9545733773753136, 0.9869008833924131]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.028685633809430733`], {
             RGBColor[
             0.23363553097946993`, 0.3628961347806308, 0.9366165699052621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.028685633809430733`], {
             RGBColor[
             0.7253820295989173, 0.7853932217210695, 0.973262959696097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.028685633809430733`], {
             RGBColor[
             0.1837791716078354, 0.31049394000528374`, 0.9337773239949216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.028685633809430733`], {
             RGBColor[
             0.24298649045633505`, 0.3727245860758903, 0.9371490932139648]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.028685633809430733`], {
             RGBColor[
             0.18157893838322037`, 0.30818135538336955`, 0.9336520239677332]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.028685633809430733`], {
             RGBColor[
             0.18958070170652433`, 0.3165917159772593, 0.9341077125514473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.028685633809430733`], {
             RGBColor[
             0.30143473291096856`, 0.4341573947283205, 0.94047763415533]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.028685633809430733`], {
             RGBColor[
             0.18662770310860746`, 0.3134879272199237, 0.9339395436498659]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.028685633809430733`], {
             RGBColor[
             0.23178823080036964`, 0.3609545051668002, 0.9365113688928981]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.028685633809430733`], {
             RGBColor[
             0.18685517330782678`, 0.3137270128217468, 0.9339524977411994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.028685633809430733`], {
             RGBColor[
             0.21037507790267013`, 0.33844792379900884`, 0.935291921513295]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.028685633809430733`], {
             RGBColor[
             0.6253505975793664, 0.7067268126951324, 0.9636490362576168]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.028685633809430733`], {
             RGBColor[
             0.1890859537624092, 0.3160717045191629, 0.9340795373879439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.028685633809430733`], {
             RGBColor[
             0.4243323457115801, 0.5419570831167153, 0.9482590597397496]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.028685633809430733`], {
             RGBColor[
             0.1801862242299471, 0.30671752450510187`, 0.9335727109570402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.028685633809430733`], {
             RGBColor[
             0.36379298595207366`, 0.4895209324897256, 0.9444015452687277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.028685633809430733`], {
             RGBColor[
             0.9942973298741586, 0.9902108901662465, 0.6206777334817875]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.028685633809430733`], {
             RGBColor[
             0.47631296582080423`, 0.5857313491647339, 0.951916247942749]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.028685633809430733`], {
             RGBColor[
             0.8462306119676556, 0.35635431873254797`, 0.1919037922712223]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.028685633809430733`], {
             RGBColor[
             0.1902758304551235, 0.3173223403657453, 0.9341472991053292]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.028685633809430733`], {
             RGBColor[
             0.19084105210201593`, 0.31791642415375154`, 0.9341794876419492]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.028685633809430733`], {
             RGBColor[
             0.4414153171565428, 0.5567534943672319, 0.9493475715743441]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.028685633809430733`], {
             RGBColor[
             0.2030767017243416, 0.3307768676918091, 0.9348762897869192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.028685633809430733`], {
             RGBColor[
             0.46208044251389646`, 0.5741767455763179, 0.9507958115725785]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.028685633809430733`], {
             RGBColor[
             0.18519516767477753`, 0.31198224165097593`, 0.9338579628761555]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.028685633809430733`], {
             RGBColor[
             0.1815243108454087, 0.3081239383775436, 0.933648913010269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.028685633809430733`], {
             RGBColor[
             0.24019038642635912`, 0.3697857034571507, 0.9369898592259228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.028685633809430733`], {
             RGBColor[
             0.18339204965023842`, 0.3100870502828995, 0.9337552779721321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.028685633809430733`], {
             RGBColor[
             0.18070771638990538`, 0.3072656458297307, 0.9336024091640713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.028685633809430733`], {
             RGBColor[
             0.31058773436371456`, 0.4434372177375889, 0.9410113536850742]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.028685633809430733`], {
             RGBColor[
             0.5597098423756648, 0.6534366905384442, 0.9584815555579723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.028685633809430733`], {
             RGBColor[
             0.24531622372842543`, 0.3751732834584783, 0.9372817680772788]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.028685633809430733`], {
             RGBColor[
             0.18854433931021156`, 0.3155024333895635, 0.934048693246138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.028685633809430733`], {
             RGBColor[
             0.2248830575111852, 0.353696730226594, 0.9361181294893675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.028685633809430733`], {
             RGBColor[
             0.9095261013751367, 0.9306954410809412, 0.9912326055643381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.028685633809430733`], {
             RGBColor[
             0.5961635782161725, 0.6830314755158533, 0.9613513271777714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.028685633809430733`], {
             RGBColor[
             0.23010075165696398`, 0.35918085759472357`, 0.9364152694520828]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.028685633809430733`], {
             RGBColor[
             0.17923689510112015`, 0.3057197193997615, 0.9335186480675601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.028685633809430733`], {
             RGBColor[
             0.18261346087673228`, 0.3092687041165651, 0.9337109384932998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.028685633809430733`], {
             RGBColor[
             0.20439189938454302`, 0.3321592238210287, 0.9349511883480071]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.028685633809430733`], {
             RGBColor[
             0.20704370002822514`, 0.33494643443141037`, 0.9351022044716772]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.028685633809430733`], {
             RGBColor[
             0.18255683100735334`, 0.30920918253330676`, 0.933707713506015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.028685633809430733`], {
             RGBColor[
             0.19714961162350877`, 0.32454712019661625`, 0.9345387507740208]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.028685633809430733`], {
             RGBColor[
             0.1792318772890574, 0.3057144453611359, 0.9335183623105863]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.028685633809430733`], {
             RGBColor[
             0.18202687820624844`, 0.30865216853839716`, 0.933677533477987]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.028685633809430733`], {
             RGBColor[
             0.22875987812146206`, 0.3577715144926186, 0.9363389086878806]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.028685633809430733`], {
             RGBColor[
             0.25408219745152405`, 0.38438687763629015`, 0.9377809773127133]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.028685633809430733`], {
             RGBColor[
             0.6142711963162304, 0.6977320556283797, 0.9627768252049985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.028685633809430733`], {
             RGBColor[
             0.9909995879120733, 0.9905461125486716, 0.7988236508241691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.028685633809430733`], {
             RGBColor[
             0.847444298272204, 0.36568324351003745`, 0.19306601964712058`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.028685633809430733`], {
             RGBColor[
             0.20274272640358343`, 0.3304258384544339, 0.9348572703864743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.028685633809430733`], {
             RGBColor[
             0.37110890510299593`, 0.49585761394946637`, 0.9448677091678112]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.028685633809430733`], {
             RGBColor[
             0.1807916321529833, 0.30735384661729226`, 0.9336071880426363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.028685633809430733`], {
             RGBColor[
             0.20696414784897932`, 0.33486282004712353`, 0.9350976740927561]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.028685633809430733`], {
             RGBColor[
             0.8274245231995631, 0.21180247958034423`, 0.17389506042845765`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.028685633809430733`], {
             RGBColor[
             0.1874689911967999, 0.31437217434135956`, 0.9339874537619143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.028685633809430733`], {
             RGBColor[
             0.18829908866819065`, 0.31524465941501073`, 0.9340347265848907]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.028685633809430733`], {
             RGBColor[
             0.21206977390702858`, 0.3402291567495223, 0.9353884319436652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.028685633809430733`], {
             RGBColor[
             0.2677744651747997, 0.39877831915336787`, 0.938560731703659]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.028685633809430733`], {
             RGBColor[
             0.2680749969538752, 0.3990941971079916, 0.9385778465438803]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.028685633809430733`], {
             RGBColor[
             0.18155548323377793`, 0.30815670253416316`, 0.9336506882316712]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.028685633809430733`], {
             RGBColor[
             0.30560245203902436`, 0.43853793178056216`, 0.9407149795940849]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.028685633809430733`], {
             RGBColor[
             0.18889078087796188`, 0.3158665654429332, 0.934068422580907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.028685633809430733`], {
             RGBColor[
             0.3286879472145684, 0.4591147123658486, 0.9421646832425408]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.028685633809430733`], {
             RGBColor[
             0.19492141529937626`, 0.32220514458414634`, 0.9344118582896825]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.028685633809430733`], {
             RGBColor[
             0.25591378716406765`, 0.38631199455366855`, 0.9378852836372484]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.028685633809430733`], {
             RGBColor[
             0.47311473175482466`, 0.583134878671169, 0.9516644712415576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.028685633809430733`], {
             RGBColor[
             0.23685058796865582`, 0.3662753635226519, 0.9367996626445457]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.028685633809430733`], {
             RGBColor[
             0.2213158585080208, 0.34994737790078817`, 0.9359149827833353]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.028685633809430733`], {
             RGBColor[
             0.18345440314028216`, 0.3101525877543751, 0.9337588289111464]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.028685633809430733`], {
             RGBColor[
             0.5041410272247835, 0.6083234230523641, 0.954106974874018]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.028685633809430733`], {
             RGBColor[
             0.19743844380411263`, 0.32485070113144887`, 0.9345551993394172]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.028685633809430733`], {
             RGBColor[
             0.8220097648168001, 0.1701822738881748, 0.16870988168602888`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.028685633809430733`], {
             RGBColor[
             0.20625914549310514`, 0.3341218178713687, 0.9350575252515466]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.028685633809430733`], {
             RGBColor[
             0.20787897197296468`, 0.3358243582046317, 0.9351497719732561]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.028685633809430733`], {
             RGBColor[
             0.989868357531768, 0.9900783197151207, 0.8175710657562082]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[401, 0.028685633809430733`], {
             RGBColor[
             0.18072732343424755`, 0.30728625407649274`, 0.9336035257562406]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[402, 0.028685633809430733`], {
             RGBColor[
             0.21812922311479366`, 0.346598022058153, 0.9357335086118955]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[403, 0.028685633809430733`], {
             RGBColor[
             0.7434088886883141, 0.7994759410509097, 0.9750597085395519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[404, 0.028685633809430733`], {
             RGBColor[
             0.8368269464602606, 0.8727271083178094, 0.9842984952692555]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[405, 0.028685633809430733`], {
             RGBColor[
             0.1816592229448945, 0.3082657395480243, 0.9336565960547502]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[406, 0.028685633809430733`], {
             RGBColor[
             0.41650215403555035`, 0.5351749646438152, 0.9477601268501196]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[407, 0.028685633809430733`], {
             RGBColor[
             0.2771295864414469, 0.4086111447535611, 0.9390934920201328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[408, 0.028685633809430733`], {
             RGBColor[
             0.9372841166711893, 0.9527471774179826, 0.9910458109403161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[409, 0.028685633809430733`], {
             RGBColor[
             0.2532336129818181, 0.38349496155526636`, 0.9377326516825317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[410, 0.028685633809430733`], {
             RGBColor[
             0.18224818387414324`, 0.30888477482694443`, 0.9336901365083813]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[411, 0.028685633809430733`], {
             RGBColor[
             0.281209290628112, 0.4128991725219315, 0.9393258251381819]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[412, 0.028685633809430733`], {
             RGBColor[
             0.1902556572489104, 0.31730113704696017`, 0.934146150271079]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[413, 0.028685633809430733`], {
             RGBColor[
             0.23030998251802656`, 0.3594007724957031, 0.936427184840091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[414, 0.028685633809430733`], {
             RGBColor[
             0.4226665958174486, 0.5405142942814426, 0.9481529196294604]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[415, 0.028685633809430733`], {
             RGBColor[
             0.1803991146634024, 0.3069412858486965, 0.9335848347522823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[416, 0.028685633809430733`], {
             RGBColor[
             0.20922896777355948`, 0.3372432893857343, 0.9352266522369601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[417, 0.028685633809430733`], {
             RGBColor[
             0.19713115786974042`, 0.32452772413137015`, 0.9345376998600435]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[418, 0.028685633809430733`], {
             RGBColor[
             0.4765052907931592, 0.5858874872414329, 0.9519313884690823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[419, 0.028685633809430733`], {
             RGBColor[
             0.649286320101708, 0.725946675113037, 0.9656784505282513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[420, 0.028685633809430733`], {
             RGBColor[
             0.1880446060283209, 0.31497718202537633`, 0.9340202341750236]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[421, 0.028685633809430733`], {
             RGBColor[
             0.1843367269803192, 0.31107996605281657`, 0.9338090759485553]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[422, 0.028685633809430733`], {
             RGBColor[
             0.20654013009820746`, 0.33441715050678417`, 0.9350735269091277]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[423, 0.028685633809430733`], {
             RGBColor[
             0.1791999116318114, 0.3056808474286306, 0.9335165419136952]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[424, 0.028685633809430733`], {
             RGBColor[
             0.19347184238884513`, 0.3206815515469472, 0.9343293072568787]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[425, 0.028685633809430733`], {
             RGBColor[
             0.18667870528248892`, 0.31354153373839766`, 0.9339424481482175]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[426, 0.028685633809430733`], {
             RGBColor[
             0.18735694523176508`, 0.31425440692798345`, 0.9339810729099627]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[427, 0.028685633809430733`], {
             RGBColor[
             0.18651414967483487`, 0.3133685753613251, 0.9339330769497998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[428, 0.028685633809430733`], {
             RGBColor[
             0.18777404508405116`, 0.31469280531839416`, 0.9340048261295064]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[429, 0.028685633809430733`], {
             RGBColor[
             0.1919491178531559, 0.319081071513626, 0.9342425903472402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[430, 0.028685633809430733`], {
             RGBColor[
             0.20155620116286646`, 0.329178725196395, 0.9347896995293221]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[431, 0.028685633809430733`], {
             RGBColor[
             0.4212519905865513, 0.5392890343305656, 0.9480627822350338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[432, 0.028685633809430733`], {
             RGBColor[
             0.29123303955595214`, 0.4234347681874807, 0.9398966628108147]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[433, 0.028685633809430733`], {
             RGBColor[
             0.18067343227102245`, 0.30722961104704605`, 0.9336004567342198]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[434, 0.028685633809430733`], {
             RGBColor[
             0.9350798973521478, 0.7803204568826958, 0.2666219654201177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[435, 0.028685633809430733`], {
             RGBColor[
             0.23839852597207306`, 0.3679023445091814, 0.9368878154238712]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[436, 0.028685633809430733`], {
             RGBColor[
             0.35552088653300873`, 0.4823560557407374, 0.9438744544084752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[437, 0.028685633809430733`], {
             RGBColor[
             0.18191959414620315`, 0.3085394061890873, 0.93367142380948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[438, 0.028685633809430733`], {
             RGBColor[
             0.20264182690306143`, 0.3303197866819874, 0.9348515243091869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[439, 0.028685633809430733`], {
             RGBColor[
             0.19923030702383038`, 0.32673406298606217`, 0.934657243298956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[440, 0.028685633809430733`], {
             RGBColor[
             0.8916325056316791, 0.6008103425923479, 0.23128784517976625`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[441, 0.028685633809430733`], {
             RGBColor[
             0.22146757953397317`, 0.3501068463187328, 0.935923623071312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[442, 0.028685633809430733`], {
             RGBColor[
             0.2379042947950852, 0.36738287620610066`, 0.9368596696894913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[443, 0.028685633809430733`], {
             RGBColor[
             0.2878366774276409, 0.41986497624882907`, 0.9397032450120749]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[444, 0.028685633809430733`], {
             RGBColor[
             0.5658641034717166, 0.6584329969425219, 0.9589660415352547]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[445, 0.028685633809430733`], {
             RGBColor[
             0.9631188181102052, 0.8872532547517151, 0.3112240020952856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[446, 0.028685633809430733`], {
             RGBColor[
             0.18340710413885652`, 0.31010287350494686`, 0.9337561353029877]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[447, 0.028685633809430733`], {
             RGBColor[
             0.23372958097512028`, 0.36299498728917345`, 0.9366219259133799]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[448, 0.028685633809430733`], {
             RGBColor[
             0.300584051971647, 0.4332632751248068, 0.9404291891343054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[449, 0.028685633809430733`], {
             RGBColor[
             0.9836066487684537, 0.9563635183333898, 0.39081535540040413`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[450, 0.028685633809430733`], {
             RGBColor[
             0.2155265395117455, 0.34386243657167787`, 0.9355852896310274]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[451, 0.028685633809430733`], {
             RGBColor[
             0.20508673054441848`, 0.33288953542489785`, 0.9349907579546514]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[452, 0.028685633809430733`], {
             RGBColor[
             0.22680832648896532`, 0.3557203099913444, 0.9362277707094718]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[453, 0.028685633809430733`], {
             RGBColor[
             0.23993040743871616`, 0.3695124490575181, 0.936975053807181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[454, 0.028685633809430733`], {
             RGBColor[
             0.21139233227849236`, 0.33951712264565065`, 0.9353498526451051]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[455, 0.028685633809430733`], {
             RGBColor[
             0.6130446091083116, 0.6967362568758672, 0.9626802637668542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[456, 0.028685633809430733`], {
             RGBColor[
             0.19561148544389112`, 0.32293045205900567`, 0.9344511567635453]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[457, 0.028685633809430733`], {
             RGBColor[
             0.4692511982227218, 0.5799982880996057, 0.9513603197293209]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[458, 0.028685633809430733`], {
             RGBColor[
             0.2390221871354001, 0.3685578519342398, 0.9369233320044987]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[459, 0.028685633809430733`], {
             RGBColor[
             0.1944799719611093, 0.3217411596465035, 0.9343867187446251]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[460, 0.028685633809430733`], {
             RGBColor[
             0.3006736022333113, 0.4333573981276305, 0.9404342888892294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[461, 0.028685633809430733`], {
             RGBColor[
             0.25327163562221944`, 0.38353492576110276`, 0.9377348170156531]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[462, 0.028685633809430733`], {
             RGBColor[
             0.1900670199072787, 0.31710286724060704`, 0.934135407653537]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[463, 0.028685633809430733`], {
             RGBColor[
             0.5551591248464408, 0.6497422130407317, 0.9581233064042441]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[464, 0.028685633809430733`], {
             RGBColor[
             0.20245401245038683`, 0.33012238178410236`, 0.9348408285539537]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[465, 0.028685633809430733`], {
             RGBColor[
             0.1790493149440538, 0.30552256076141593`, 0.9335079656551152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[466, 0.028685633809430733`], {
             RGBColor[
             0.19488624546246058`, 0.32216817885565147`, 0.9344098554194993]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[467, 0.028685633809430733`], {
             RGBColor[
             0.19114672360584797`, 0.3182377042849717, 0.934196895181892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[468, 0.028685633809430733`], {
             RGBColor[
             0.22150150348383524`, 0.3501425025409405, 0.9359255549900708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[469, 0.028685633809430733`], {
             RGBColor[
             0.18135253868176207`, 0.30794339494256673`, 0.9336391308396634]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[470, 0.028685633809430733`], {
             RGBColor[
             0.19461387303716265`, 0.3218818981672542, 0.9343943442128174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[471, 0.028685633809430733`], {
             RGBColor[
             0.9568366664708343, 0.967329437044196, 0.9579484442512339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[472, 0.028685633809430733`], {
             RGBColor[
             0.18313584696674626`, 0.3098177650183609, 0.9337406876083251]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[473, 0.028685633809430733`], {
             RGBColor[
             0.2635938852306148, 0.3943842645679517, 0.9383226538604513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[474, 0.028685633809430733`], {
             RGBColor[
             0.22951352418939525`, 0.35856364429393695`, 0.93638182771653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[475, 0.028685633809430733`], {
             RGBColor[
             0.3365285973416883, 0.465905889423426, 0.9426642825354262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[476, 0.028685633809430733`], {
             RGBColor[
             0.18343003159278173`, 0.31012697171270676`, 0.9337574409875706]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[477, 0.028685633809430733`], {
             RGBColor[
             0.19779376632799722`, 0.32522416763280076`, 0.9345754344314999]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[478, 0.028685633809430733`], {
             RGBColor[
             0.24931371638514488`, 0.37937490169636373`, 0.9375094193703185]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[479, 0.028685633809430733`], {
             RGBColor[
             0.18231814009471767`, 0.3089583032502487, 0.933694120411652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[480, 0.028685633809430733`], {
             RGBColor[
             0.24336115250331075`, 0.37311837964220756`, 0.9371704296632771]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[481, 0.028685633809430733`], {
             RGBColor[
             0.20526876593224802`, 0.3330808661592169, 0.9350011246006911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[482, 0.028685633809430733`], {
             RGBColor[
             0.3323719943960167, 0.4623056488688239, 0.9423994274712677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[483, 0.028685633809430733`], {
             RGBColor[
             0.4520407911262143, 0.5659567458679113, 0.9500246173799538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[484, 0.028685633809430733`], {
             RGBColor[
             0.1848118632397346, 0.3115793643868409, 0.933836134255628]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[485, 0.028685633809430733`], {
             RGBColor[
             0.255344871987097, 0.38571402863136683`, 0.9378528847595545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[486, 0.028685633809430733`], {
             RGBColor[
             0.41333459859387617`, 0.5324313873262027, 0.9475582930183354]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[487, 0.028685633809430733`], {
             RGBColor[
             0.19274009296176206`, 0.31991243650348955`, 0.9342876352095326]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[488, 0.028685633809430733`], {
             RGBColor[
             0.18252871209609148`, 0.30917962777472857`, 0.9337061121756168]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[489, 0.028685633809430733`], {
             RGBColor[
             0.19162106685648111`, 0.3187362691164863, 0.9342239083282876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[490, 0.028685633809430733`], {
             RGBColor[
             0.2159679187439516, 0.3443263541297861, 0.9356104255253395]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[491, 0.028685633809430733`], {
             RGBColor[
             0.1816268290277524, 0.30823169148721496`, 0.9336547512690914]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[492, 0.028685633809430733`], {
             RGBColor[
             0.18260872208869527`, 0.3092637233498817, 0.9337106686263315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[493, 0.028685633809430733`], {
             RGBColor[
             0.2609046791964185, 0.39155773852050096`, 0.9381695075551277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[494, 0.028685633809430733`], {
             RGBColor[
             0.35530253300255993`, 0.4821669288874302, 0.9438605411145975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[495, 0.028685633809430733`], {
             RGBColor[
             0.8860920716837987, 0.5756525260362475, 0.22666477128519144`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[496, 0.028685633809430733`], {
             RGBColor[
             0.1858152550736946, 0.31263399282304966`, 0.9338932759361868]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[497, 0.028685633809430733`], {
             RGBColor[
             0.4781822073170808, 0.587248883619781, 0.9520634014805931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[498, 0.028685633809430733`], {
             RGBColor[
             0.7745863239297996, 0.8238319904188423, 0.9781671839147258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[499, 0.028685633809430733`], {
             RGBColor[
             0.628572856489554, 0.7093427876395323, 0.96390270428255]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[500, 0.028685633809430733`], {
             RGBColor[
             0.20098870068601762`, 0.3285822462136184, 0.9347573812167074]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{{3.8349502435193233`*^9, 3.8349502581408367`*^9}, 
   3.834950528174912*^9, 3.8349578088972807`*^9, 3.835018923470682*^9, 
   3.835019026079196*^9, 3.8350205603927774`*^9},
 CellLabel->"Out[78]=",ExpressionUUID->"84bcbe1e-77dd-4cfb-bdce-d9a4686a683c"]
}, Open  ]],

Cell["r = 3 :", "Text",
 CellChangeTimes->{{3.834793779215767*^9, 3.8347938725231647`*^9}, {
  3.8347953347101345`*^9, 3.8347953431477337`*^9}, {3.8348851911359825`*^9, 
  3.83488519180678*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"638a35ff-4482-4ed9-b8b1-69050ad62567"],

Cell["Cubic Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.834795179278664*^9}},ExpressionUUID->"48231263-48a9-471a-b390-\
3a0c26317c60"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c\[Rho]3i5", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"CMDi3500", ",", "kri5"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.834947911760502*^9, 
   3.834947914304406*^9}, {3.834947957535968*^9, 3.8349479704802837`*^9}, {
   3.8349480487781425`*^9, 3.834948105065866*^9}, {3.8349497992119355`*^9, 
   3.83494980454772*^9}, {3.8349578354451995`*^9, 3.83495784069214*^9}, {
   3.835018838991932*^9, 3.8350188405169106`*^9}},
 CellLabel->"In[79]:=",ExpressionUUID->"93946396-6b3f-4d32-97c6-87ad9909fbe2"],

Cell[BoxData[
 RowBox[{"-", "0.03940704720660954`"}]], "Output",
 CellChangeTimes->{
  3.834948013482303*^9, {3.834948049945756*^9, 3.834948058990469*^9}, 
   3.8349481059508953`*^9, 3.8349499476386404`*^9, 3.834957841643118*^9, 
   3.8350189236386824`*^9, 3.8350190270322647`*^9, 3.8350204164650445`*^9, 
   3.8350205609787445`*^9},
 CellLabel->"Out[79]=",ExpressionUUID->"0fc48968-ef79-4a4d-87a2-64f14a13e14d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CP3i5", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"CMDi3500", ",", "kri5"}], "}"}], "]"}], ",", "c\[Rho]3i5"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8349481210775223`*^9, 3.834948150679065*^9}, {
  3.8349481924167476`*^9, 3.8349481986802473`*^9}, {3.834949807949147*^9, 
  3.834949815491851*^9}, {3.8349578438231587`*^9, 3.8349578533989754`*^9}, {
  3.835018846742407*^9, 3.835018849961266*^9}},
 CellLabel->"In[80]:=",ExpressionUUID->"ed0ebc90-a2c0-46dc-848d-b32570bcd90d"],

Cell[BoxData["0.8703932362566628`"], "Output",
 CellChangeTimes->{3.8349481513130674`*^9, 3.8349482002632475`*^9, 
  3.8349499490044084`*^9, 3.8349578559445095`*^9, 3.83501892389968*^9, 
  3.8350190272812295`*^9, 3.8350205613687525`*^9},
 CellLabel->"Out[80]=",ExpressionUUID->"b4ad57ac-a982-446a-a6e2-47b0e0e0f3fa"]
}, Open  ]],

Cell["Absolute Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.8347951985065947`*^9}},ExpressionUUID->"40da51d5-f6fd-4e64-a058-\
863561978934"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a\[Rho]3i5", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"AMDi3500", ",", "kri5"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.8348873709111376`*^9, 
   3.8348873755217657`*^9}, {3.8349481641806583`*^9, 
   3.8349481824982553`*^9}, {3.834949818653184*^9, 3.8349498238056817`*^9}, {
   3.834957866337153*^9, 3.834957872254816*^9}, {3.8350188531986103`*^9, 
   3.8350188546829796`*^9}},
 CellLabel->"In[81]:=",ExpressionUUID->"2ae75f92-9d35-477a-9e58-164aa6c0282f"],

Cell[BoxData[
 RowBox[{"-", "0.02227124493841914`"}]], "Output",
 CellChangeTimes->{3.834948182946122*^9, 3.83494995054953*^9, 
  3.834957874365346*^9, 3.835018924320698*^9, 3.8350190275072393`*^9, 
  3.8350205614078007`*^9},
 CellLabel->"Out[81]=",ExpressionUUID->"f4988226-8727-4be1-bc40-bbc0df9c2fa5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"aP3i5", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"AMDi3500", ",", "kri5"}], "}"}], "]"}], ",", "a\[Rho]3i5"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8349482041094093`*^9, 
  3.8349482202691827`*^9}, {3.8349498269490285`*^9, 3.8349498405604887`*^9}, {
  3.8349578796796703`*^9, 3.834957886620027*^9}, {3.8350188593392305`*^9, 
  3.835018861313801*^9}},
 CellLabel->"In[82]:=",ExpressionUUID->"bcd2af4f-6b58-4348-a3f1-e6a885d5e91c"],

Cell[BoxData["0.8208773622420424`"], "Output",
 CellChangeTimes->{3.834887440036944*^9, 3.8349482220989213`*^9, 
  3.8349499520491343`*^9, 3.8349578874036503`*^9, 3.83501892439668*^9, 
  3.8350190277232385`*^9, 3.8350205614517555`*^9},
 CellLabel->"Out[82]=",ExpressionUUID->"6863ccdc-5b18-4088-8031-5e6403ca71f3"]
}, Open  ]],

Cell["Max-min Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 3.8347951985065947`*^9}, {
  3.8348543263190746`*^9, 
  3.834854330052075*^9}},ExpressionUUID->"3e400ad9-1a1e-4df0-89fb-\
101c924ad045"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mM\[Rho]3i5", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"mMDi3500", ",", "kri5"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8348874651734295`*^9, 3.8348874872060013`*^9}, {
  3.8349482319487157`*^9, 3.834948245258479*^9}, {3.834949844516972*^9, 
  3.8349498489188633`*^9}, {3.834957895209076*^9, 3.834957899999796*^9}, {
  3.83501886583329*^9, 3.835018866821826*^9}},
 CellLabel->"In[83]:=",ExpressionUUID->"9277847a-786b-4251-8c9f-5d1162ef2887"],

Cell[BoxData[
 RowBox[{"-", "0.024394524158218554`"}]], "Output",
 CellChangeTimes->{3.834948246413353*^9, 3.834949953689977*^9, 
  3.834957900696502*^9, 3.835018924463678*^9, 3.835019027994238*^9, 
  3.835020561490786*^9},
 CellLabel->"Out[83]=",ExpressionUUID->"7a97aae0-d41b-4bab-b0e7-c08e808323d6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mMP3i5", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"mMDi3500", ",", "kri5"}], "}"}], "]"}], ",", "mM\[Rho]3i5"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8348875260806427`*^9, 
  3.8348875488478312`*^9}, {3.8349482525846663`*^9, 3.8349482707073736`*^9}, {
  3.8349498532537427`*^9, 3.834949860995207*^9}, {3.834957902898573*^9, 
  3.8349579090270967`*^9}, {3.8350188699780455`*^9, 3.835018871634328*^9}},
 CellLabel->"In[84]:=",ExpressionUUID->"bbe3d2fe-e8a8-41ff-88cf-5ef22cd9fe0d"],

Cell[BoxData["0.9134167020484705`"], "Output",
 CellChangeTimes->{3.834887440036944*^9, 3.8348875533996215`*^9, 
  3.834948277702903*^9, 3.834949955989804*^9, 3.834957909480212*^9, 
  3.835018924542716*^9, 3.835019028341303*^9, 3.8350205615287514`*^9},
 CellLabel->"Out[84]=",ExpressionUUID->"0ab68908-fa00-42f3-a558-b759b266df57"]
}, Open  ]],

Cell["r = 6 :", "Text",
 CellChangeTimes->{{3.834793779215767*^9, 3.8347938725231647`*^9}, {
  3.8347953347101345`*^9, 3.8347953431477337`*^9}, {3.8348851911359825`*^9, 
  3.83488519180678*^9}, {3.834948305866973*^9, 3.8349483068980722`*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"50abafbe-995b-4cec-80a2-19c5ba216cdb"],

Cell["Cubic Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.834795179278664*^9}},ExpressionUUID->"1d4b39de-1768-4ef2-9ce7-\
87f74e2081e2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c\[Rho]6i5", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"CMDi6500", ",", "kri5"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.834947911760502*^9, 
   3.834947914304406*^9}, {3.834947957535968*^9, 3.8349479704802837`*^9}, {
   3.8349480487781425`*^9, 3.834948105065866*^9}, {3.8349483158342133`*^9, 
   3.8349483193845987`*^9}, {3.834949864783629*^9, 3.834949869574106*^9}, {
   3.834957963470776*^9, 3.834957967378231*^9}, {3.835018875109179*^9, 
   3.8350188762029247`*^9}},
 CellLabel->"In[85]:=",ExpressionUUID->"d82c8da4-13f5-42f5-b3bd-de40e6f5668d"],

Cell[BoxData[
 RowBox[{"-", "0.0014136729272135964`"}]], "Output",
 CellChangeTimes->{
  3.834948013482303*^9, {3.834948049945756*^9, 3.834948058990469*^9}, 
   3.8349481059508953`*^9, 3.834948360850016*^9, 3.8349499580565577`*^9, 
   3.834957967763415*^9, 3.835018924610717*^9, 3.835019028526283*^9, 
   3.8350205615657897`*^9},
 CellLabel->"Out[85]=",ExpressionUUID->"b4ac1afc-d7ca-4738-adca-a662f6d249b2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CP6i5", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"CMDi6500", ",", "kri5"}], "}"}], "]"}], ",", "c\[Rho]6i5"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8349481210775223`*^9, 3.834948150679065*^9}, {
  3.8349481924167476`*^9, 3.8349481986802473`*^9}, {3.8349483230197706`*^9, 
  3.834948338654296*^9}, {3.8349498724373255`*^9, 3.8349498802583637`*^9}, {
  3.8349579696959915`*^9, 3.834957975592292*^9}, {3.8350188769841766`*^9, 
  3.835018878671647*^9}},
 CellLabel->"In[86]:=",ExpressionUUID->"3114e925-d32a-43eb-b0d3-6630a3016a3f"],

Cell[BoxData["0.7959246709538622`"], "Output",
 CellChangeTimes->{3.8349481513130674`*^9, 3.8349482002632475`*^9, 
  3.834948361143017*^9, 3.8349499593900194`*^9, 3.8349579759739666`*^9, 
  3.835018924686731*^9, 3.835019028733289*^9, 3.835020561606792*^9},
 CellLabel->"Out[86]=",ExpressionUUID->"fac5929c-5fae-4d5b-8401-8c0aa2423978"]
}, Open  ]],

Cell["Absolute Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.8347951985065947`*^9}},ExpressionUUID->"c308b8b7-c67a-48bb-b8e6-\
af30af8a754b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a\[Rho]6i5", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"AMDi6500", ",", "kri5"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.8348873709111376`*^9, 
   3.8348873755217657`*^9}, {3.8349481641806583`*^9, 
   3.8349481824982553`*^9}, {3.834948329127375*^9, 3.834948332212267*^9}, {
   3.834949883458797*^9, 3.8349498875077024`*^9}, {3.834957978394422*^9, 
   3.8349579827581863`*^9}, {3.8350188795779624`*^9, 3.83501888042175*^9}},
 CellLabel->"In[87]:=",ExpressionUUID->"56058984-88b4-43d4-8d12-ad11c26865e1"],

Cell[BoxData["0.008103786754398016`"], "Output",
 CellChangeTimes->{3.834948182946122*^9, 3.8349483612910123`*^9, 
  3.8349499607430162`*^9, 3.834957983223776*^9, 3.8350189247546825`*^9, 
  3.8350190289627576`*^9, 3.835020561645753*^9},
 CellLabel->"Out[87]=",ExpressionUUID->"b5cb5c05-70cb-4907-9511-f22c1a977aed"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"aP6i5", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"AMDi6500", ",", "kri5"}], "}"}], "]"}], ",", "a\[Rho]6i5"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8349482041094093`*^9, 
  3.8349482202691827`*^9}, {3.834948340881687*^9, 3.834948354997751*^9}, {
  3.8349498907390194`*^9, 3.8349498979971194`*^9}, {3.8349579853563895`*^9, 
  3.8349579919125147`*^9}, {3.8350188832810483`*^9, 3.83501888448921*^9}},
 CellLabel->"In[88]:=",ExpressionUUID->"2ebefb86-03a4-4cef-921b-6cbf3f9b5e69"],

Cell[BoxData["0.8935107227771192`"], "Output",
 CellChangeTimes->{3.834887440036944*^9, 3.8349482220989213`*^9, 
  3.834948361458013*^9, 3.834949962307019*^9, 3.834957992381853*^9, 
  3.8350189248306823`*^9, 3.8350190293037586`*^9, 3.8350205616797533`*^9},
 CellLabel->"Out[88]=",ExpressionUUID->"8eaada18-139f-451a-96a3-47b49458cf62"]
}, Open  ]],

Cell["Max-min Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 3.8347951985065947`*^9}, {
  3.8348543263190746`*^9, 
  3.834854330052075*^9}},ExpressionUUID->"e6661573-6b9b-4cb8-9392-\
2d88f04eebc0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mM\[Rho]6i5", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"mMDi6500", ",", "kri5"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8348874651734295`*^9, 3.8348874872060013`*^9}, {
   3.8349482319487157`*^9, 3.834948245258479*^9}, 3.8349483527075925`*^9, {
   3.8349499042423377`*^9, 3.8349499090679235`*^9}, {3.834949978751977*^9, 
   3.8349499794842105`*^9}, {3.834957994342047*^9, 3.834957998175455*^9}, {
   3.835018886286111*^9, 3.8350188870361056`*^9}},
 CellLabel->"In[89]:=",ExpressionUUID->"c8475b9d-43c6-4091-966c-6405725ccb76"],

Cell[BoxData[
 RowBox[{"-", "0.006865584962829076`"}]], "Output",
 CellChangeTimes->{
  3.834948246413353*^9, 3.8349483615970154`*^9, {3.834949963955017*^9, 
   3.8349499810066743`*^9}, 3.834957999014784*^9, 3.835018924901681*^9, 
   3.8350190294867744`*^9, 3.835020561717774*^9},
 CellLabel->"Out[89]=",ExpressionUUID->"fb33b385-89f5-4de2-881c-13b84c25c6b2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mMP6i5", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"mMDi6500", ",", "kri5"}], "}"}], "]"}], ",", "mM\[Rho]6i5"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8348875260806427`*^9, 
  3.8348875488478312`*^9}, {3.8349482525846663`*^9, 3.8349482707073736`*^9}, {
  3.83494834565068*^9, 3.8349483504716325`*^9}, {3.8349499122654495`*^9, 
  3.83494991854418*^9}, {3.834958000997678*^9, 3.8349580074869604`*^9}, {
  3.8350188877705455`*^9, 3.8350189082569094`*^9}},
 CellLabel->"In[90]:=",ExpressionUUID->"55f6699a-799e-40cf-9f2d-0d7d3bd4c7d6"],

Cell[BoxData["0.6831732045946488`"], "Output",
 CellChangeTimes->{
  3.834887440036944*^9, 3.8348875533996215`*^9, 3.834948277702903*^9, 
   3.8349483617580156`*^9, {3.834949965578516*^9, 3.8349499927811513`*^9}, 
   3.834958007945059*^9, 3.8350189249776793`*^9, 3.835019029685795*^9, 
   3.835020561757756*^9},
 CellLabel->"Out[90]=",ExpressionUUID->"7653738a-070c-42b4-9f07-2bb5f9eca8d7"]
}, Open  ]],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{
  3.83502225388186*^9},ExpressionUUID->"b692d413-09f4-4a8d-bae4-b2b85cd0ae4b"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Flamm\[CloseCurlyQuote]s paraboloid", "Section",
 CellChangeTimes->{{3.835043929346464*^9, 3.835043930545144*^9}, {
  3.835044129428104*^9, 3.8350441316820936`*^9}, {3.835201889579811*^9, 
  3.8352018901823483`*^9}},ExpressionUUID->"844d71d4-3117-4358-86c0-\
10612141069d"],

Cell[CellGroupData[{

Cell["1st imported file", "Subsubsection",
 CellChangeTimes->{{3.834947473073307*^9, 3.8349474798089457`*^9}, {
   3.8349497159535103`*^9, 3.8349497173354855`*^9}, {3.834956622993673*^9, 
   3.834956623710862*^9}, {3.8350187834860272`*^9, 3.835018783813758*^9}, {
   3.835044179773861*^9, 3.8350441837622757`*^9}, 3.835201683515482*^9},
 Background->RGBColor[
  1, 1, 0],ExpressionUUID->"95fc5c11-b753-421b-8dd0-8b6b3e63b267"],

Cell["Dividing stuff", "Text",
 CellChangeTimes->{{3.83494752022309*^9, 
  3.834947523245259*^9}},ExpressionUUID->"ff7b6e36-136a-4579-af01-\
a5f30bffdac6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dataf1", "=", 
   RowBox[{"StringSplit", "[", 
    RowBox[{
     RowBox[{"Import", "[", "\"\<ariadnaComputationf1.txt\>\"", "]"}], ",", 
     "\"\<]\n{\>\""}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8349434033501863`*^9, 3.834943479535334*^9}, {
   3.834943567297134*^9, 3.8349435736474867`*^9}, {3.8349441109152327`*^9, 
   3.8349441401892223`*^9}, 3.834944204627252*^9, {3.834949720382628*^9, 
   3.8349497230261507`*^9}, {3.834956627593688*^9, 3.834956631231691*^9}, {
   3.8350187858989725`*^9, 3.8350187908769827`*^9}, {3.835044188339929*^9, 
   3.835044192375786*^9}},
 CellLabel->
  "In[221]:=",ExpressionUUID->"f093f5d7-5c0d-44ad-9318-65c23377cf95"],

Cell[BoxData[
 RowBox[{
  RowBox[{"graphif1", "=", 
   RowBox[{"ToExpression", "@", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
      "dataf1", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "<>", 
      "\"\<]\>\""}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834944474381714*^9, 3.83494454689666*^9}, 
   3.8349475108233376`*^9, {3.834949726505718*^9, 3.8349497324197383`*^9}, {
   3.8349566345564103`*^9, 3.834956636582815*^9}, {3.8350188037132354`*^9, 
   3.8350188065525265`*^9}, {3.835044199446479*^9, 3.8350442063533845`*^9}},
 CellLabel->
  "In[222]:=",ExpressionUUID->"c90fec42-8245-42e0-9fda-5e5ae569ddc4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"otherif1", "=", 
   RowBox[{"ToExpression", "@", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "<>", "\"\<}}\>\""}], "&"}], ",", 
      RowBox[{"StringSplit", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\"\<{\>\"", "<>", 
          RowBox[{
          "dataf1", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
         ")"}], ",", "\"\<}}\>\""}], "]"}]}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834944518155362*^9, 3.8349445533517303`*^9}, 
   3.8349446259294133`*^9, {3.8349447635371876`*^9, 3.8349447780382657`*^9}, {
   3.834944820013957*^9, 3.8349448816359477`*^9}, {3.834944915595456*^9, 
   3.834944918286141*^9}, {3.8349449615053425`*^9, 3.834944967406804*^9}, {
   3.834945029266304*^9, 3.834945031628281*^9}, {3.834945108799203*^9, 
   3.8349451822852197`*^9}, 3.834945584171259*^9, {3.834949734758335*^9, 
   3.8349497379503355`*^9}, {3.834956638769047*^9, 3.8349566423540664`*^9}, {
   3.8350188094708586`*^9, 3.8350188125204616`*^9}, {3.8350442096862793`*^9, 
   3.835044210497281*^9}, 3.8350442469097853`*^9},
 CellLabel->
  "In[225]:=",ExpressionUUID->"0253f06a-20dd-496e-b270-2ddbb1932ef4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "CMDi3f100", "}"}], ",", 
     RowBox[{"{", "AMDi3f100", "}"}], ",", 
     RowBox[{"{", "mMDi3f100", "}"}], ",", 
     RowBox[{"{", "CMDi6f100", "}"}], ",", 
     RowBox[{"{", "AMDi6f100", "}"}], ",", 
     RowBox[{"{", "mMDi6f100", "}"}]}], "}"}], "=", "otherif1"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.834945694541313*^9, 3.834945753140644*^9}, {
  3.8349459487260857`*^9, 3.8349459670133495`*^9}, {3.8349471029719105`*^9, 
  3.8349471182020655`*^9}, {3.83494974203613*^9, 3.8349497544188104`*^9}, {
  3.834956647753375*^9, 3.8349566844693546`*^9}, {3.8350188134722548`*^9, 
  3.835018816812196*^9}, {3.835044228572632*^9, 3.835044233700058*^9}},
 CellLabel->
  "In[226]:=",ExpressionUUID->"31358cde-60e7-4a8d-8fdd-30a18878a2c0"],

Cell["\[OpenCurlyDoubleQuote]Cleaning\[CloseCurlyDoubleQuote] the graph:", \
"Text",
 CellChangeTimes->{{3.8349477786156034`*^9, 
  3.8349478283202667`*^9}},ExpressionUUID->"f1292779-791b-4f72-b83d-\
47dd2ccb5534"],

Cell[BoxData[
 RowBox[{
  RowBox[{"graphinf1", "=", 
   RowBox[{"IndexGraph", "@", "graphif1"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834946654863307*^9, 3.834946693639777*^9}, {
  3.834949757637121*^9, 3.834949759707878*^9}, {3.8349566892836237`*^9, 
  3.834956691608691*^9}, {3.83501881773997*^9, 3.8350188182388163`*^9}, {
  3.8350442520120163`*^9, 3.8350442531771507`*^9}},
 CellLabel->
  "In[228]:=",ExpressionUUID->"29322f71-0e95-4acf-8250-539d78feb7ff"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pointsif1", "=", 
   RowBox[{"VertexList", "@", "graphinf1"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834784420352569*^9, 3.8347844264642625`*^9}, {
  3.8348756828269844`*^9, 3.8348756865131674`*^9}, {3.834878831782991*^9, 
  3.8348788488376627`*^9}, {3.8349467020325813`*^9, 3.834946739879963*^9}, {
  3.8349497621629615`*^9, 3.8349497641865125`*^9}, {3.834956695197647*^9, 
  3.834956697830969*^9}, {3.835018818796376*^9, 3.8350188192932053`*^9}, {
  3.835044292816033*^9, 3.8350442934580317`*^9}},
 CellLabel->
  "In[229]:=",ExpressionUUID->"50e1f70c-2232-468d-a2c5-510d749a939b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"coordpointsif1", "=", 
   RowBox[{"VertexList", "@", "graphif1"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834879134322084*^9, 3.834879146224797*^9}, {
  3.834946724882841*^9, 3.834946736706849*^9}, {3.834949767417904*^9, 
  3.8349497706963253`*^9}, {3.8349567000470257`*^9, 3.8349567019660654`*^9}, {
  3.835018819834511*^9, 3.835018820572505*^9}, {3.835044294376539*^9, 
  3.8350442977248926`*^9}},
 CellLabel->
  "In[230]:=",ExpressionUUID->"0524bfb2-9c7d-45a5-a0b3-1a72f18f7273"],

Cell["Kretchmann \[OpenCurlyDoubleQuote]real\[CloseCurlyDoubleQuote] \
values:", "Text",
 CellChangeTimes->{
  3.8347933561184683`*^9, {3.8347935444076195`*^9, 
   3.834793546974228*^9}},ExpressionUUID->"8475ad76-9d27-45b9-8839-\
7b2a713aba33"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rvalif1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1"}], "+", "r"}]]}], "\[Equal]", "#"}], ",", 
       RowBox[{"{", "r", "}"}]}], "]"}], "&"}], "/@", 
    RowBox[{"coordpointsif1", "\[LeftDoubleBracket]", 
     RowBox[{";;", ",", "3"}], "\[RightDoubleBracket]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834105426841242*^9, 3.8341054487325706`*^9}, {
   3.8341407674337025`*^9, 3.834140799285215*^9}, {3.8341408938375945`*^9, 
   3.834140946496229*^9}, {3.8341410168099756`*^9, 3.8341410671886864`*^9}, {
   3.8341411610986195`*^9, 3.834141210381962*^9}, {3.834141332672348*^9, 
   3.834141336755044*^9}, {3.834141461053176*^9, 3.834141468978607*^9}, {
   3.834141967115094*^9, 3.8341420256686225`*^9}, {3.8341640069512*^9, 
   3.834164012603241*^9}, {3.834164792400744*^9, 3.8341647947633886`*^9}, {
   3.83466546628111*^9, 3.834665483801684*^9}, {3.8347933895124626`*^9, 
   3.834793417249506*^9}, 3.8347960586942053`*^9, 3.834879156483405*^9, {
   3.8348862453609915`*^9, 3.8348862641404076`*^9}, 3.834886374221485*^9, {
   3.834946768449996*^9, 3.8349467823353415`*^9}, {3.8349468446168528`*^9, 
   3.834946857637892*^9}, 3.8349474594107084`*^9, {3.834949773350379*^9, 
   3.8349497766098785`*^9}, {3.8349567056279964`*^9, 
   3.8349567091770997`*^9}, {3.8350188215027976`*^9, 3.835018822410869*^9}, {
   3.835044298874358*^9, 3.8350443004592457`*^9}, 3.8350444868602533`*^9},
 CellLabel->
  "In[235]:=",ExpressionUUID->"7f92a9aa-eef6-4d2c-a466-04b2ffca5f2b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"KHFlamm", "=", 
   FractionBox[
    RowBox[{"4", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "r"}], ")"}], "2"]}], 
    SuperscriptBox["r", "6"]]}], ";"}]], "Input",
 CellChangeTimes->{{3.8350445081379066`*^9, 3.8350445206494045`*^9}},
 CellLabel->
  "In[232]:=",ExpressionUUID->"be41232b-70b5-4cc1-954d-434e72b32d4c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"krif1", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"KHFlamm", "/.", "rvalif1"}], ")"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834792366597866*^9, 3.834792376019791*^9}, {
   3.834793346399704*^9, 3.8347933590872536`*^9}, {3.834793445378667*^9, 
   3.8347934527754736`*^9}, {3.834793487784485*^9, 3.834793489659489*^9}, 
   3.8348550102643666`*^9, {3.8348863808528233`*^9, 3.83488645374378*^9}, {
   3.834886485165092*^9, 3.834886521271514*^9}, 3.8348865820814276`*^9, {
   3.83494679091998*^9, 3.8349467979310513`*^9}, {3.8349468742957215`*^9, 
   3.834946904080855*^9}, 3.8349474644429636`*^9, {3.834949779141443*^9, 
   3.834949781745859*^9}, {3.8349567110647635`*^9, 3.8349567138998594`*^9}, {
   3.8350188233356256`*^9, 3.8350188239955263`*^9}, {3.8350443047283278`*^9, 
   3.8350443056932993`*^9}, {3.835044525959175*^9, 3.835044526610751*^9}},
 CellLabel->
  "In[233]:=",ExpressionUUID->"37e30422-2a8c-43b7-975f-5fc6c11200bd"],

Cell["Estimated with cubic Mean Deviation v Calculated: (r=3)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 
  3.8349503319477153`*^9}},ExpressionUUID->"26396b60-2395-4ffe-b7cc-\
57f2e65f3a73"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraphb", "[", 
     RowBox[{"graphinf1", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsif1", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}],
      "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"CMDi3f100", ",", "krif1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349567344957485`*^9, 3.834956749729442*^9}, {
   3.8349587420893497`*^9, 3.834958755264699*^9}, {3.835018825281867*^9, 
   3.835018828052806*^9}, {3.835044306768691*^9, 3.8350443152608557`*^9}, {
   3.8350445713666224`*^9, 3.835044576386869*^9}, 3.835051925385333*^9},
 Background->RGBColor[1, 1, 0.85],
 CellLabel->
  "In[408]:=",ExpressionUUID->"576e1263-28b7-4db2-bc42-074e9b99a7ca"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100}, {
          Null, CompressedData["
1:eJwVxVmbqQwAAOCxVtbppLIkW4w1a5YJk8gSaaRCIqr783/Pr/me7715C/Zf
xfZ+fHz883x8/D9363DUk1oFBOGSrgbkKTe9Ubr+DJzlM67jGn44aCN55AiO
7OTWuWMuH0qHqrVObVrjcvv1PnbAe71DT+vplLkyddN8hkqxEiiAOngBnQA/
4nmBl/kz71Cz2Wqmz8zZE8QwHhOwC+aAKIqhFLpCL6gZpsKz8Cpshp+ghVm8
JViWU9t1dtxud0NGCI/IiIU4oXgsHi/Fq3gmo3kQT8YzygyrQz/up/w9/8Gv
+58BCZQwiZcESbpIluT8+c395n89MAjDCIzBI5iHBViCZdiCncDPzznXz/f7
6/6+Nu6Mx9x4N755Y96s9xj4/v75PnvrsXq2Xj/6SZBESYzESZIie6ROmuQz
5MbdtFt1h+5nNkDABEIQI4InZOJMOOEtuqW2s+1quzU9NEwjNEHTI1qmLdpp
99vr9t5fxsuZcrlXPpS19qvz4l7r1/6Fqxm1rPbUoXpQVc1b+CxkC4V67dF5
jB/TB/fYPW6PXCvfah1r1/a1cx1fuevuen2l0qlqaphy0SJWLE6LQlEqXjzR
aCY6jKpRLfeV//pqff3WxLbYEcfiVOTEnShexZenEW0gjUyjQTeG3maumW9+
NevNZqt5DC+p5Wy5XC23S31pLp/+ZCyJJ5P1ZC95AKJACsgAZaAKDAEV0AAX
7KJdrFvsdoWu1L3U7p37+M7dd3fxfr3f7vfH/RV4f79/3vxbeEvv8xswQkbc
SBslo2qohmYYbhAIhoLxYCqYDpaC1aARdIub7ma6ETYbaXMJsDCLsARLsyOW
5VmBlViZPbMW+2Yd7zw2j88/59l5YV6a1+eBRIJIfCfYxE+CT8iJc+IdXACL
0CK1SC+qi4WxcEEFVTCFVIoKpXSVlbJVFF25KCZsIzZh0/bIZm3eFmzJlm3L
th1vJVaJV7KVUqVSr8zDg9ZgsBysBtvBEThFT/gpcyqfeqfD6aSetCADMCEm
xsSZNFNiqgyzYFRGYwzGbU86k/5kwk3WE3Gyn1wnL6/P9+nL+gq+iq/um0dq
kUFkGuEiYuQaefkhKAyhEAlR0AxaQitoCymQDpnQ8z9pR8GG
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[69, 98] -> 
             RGBColor[
              0.9921145268466341, 0.9907223688043016, 0.7596442995111387], 
             UndirectedEdge[29, 33] -> 
             RGBColor[
              0.5653787603799021, 0.657365301033789, 0.9593529309466425], 
             UndirectedEdge[55, 59] -> 
             RGBColor[
              0.9385148407961577, 0.9507949628281045, 0.8740077273184854], 
             UndirectedEdge[47, 74] -> 
             RGBColor[
              0.33344529597857986`, 0.4502919261584768, 0.9431672139549263], 
             UndirectedEdge[19, 43] -> 
             RGBColor[
              0.7563862082444284, 0.8009424018268199, 0.6859887974175987], 
             UndirectedEdge[57, 75] -> 
             RGBColor[
              0.5041420684734272, 0.6047718016309358, 0.9552619416362569], 
             UndirectedEdge[19, 46] -> 
             RGBColor[
              0.9333218938419502, 0.941457206965906, 0.7022484303253222], 
             UndirectedEdge[36, 67] -> 
             RGBColor[
              0.5431889677397497, 0.6342933842237418, 0.959569464866326], 
             UndirectedEdge[79, 99] -> 
             RGBColor[
              0.34376483479123254`, 0.4628057589961921, 0.9436031244708405], 
             UndirectedEdge[52, 68] -> 
             RGBColor[
              0.692050788846582, 0.7585028971607255, 0.9705231291310037], 
             UndirectedEdge[81, 85] -> 
             RGBColor[
              0.9658404553265398, 0.968224516085025, 0.7022737712485565], 
             UndirectedEdge[12, 88] -> 
             RGBColor[
              0.2926486157081791, 0.42475022656974454`, 0.9399835902568532], 
             UndirectedEdge[72, 82] -> 
             RGBColor[
              0.5442576605455558, 0.6407252519689914, 0.9573111522001883], 
             UndirectedEdge[31, 44] -> 
             RGBColor[
              0.7022189379809489, 0.7610652667181741, 0.8559785411847425], 
             UndirectedEdge[17, 79] -> 
             RGBColor[
              0.47581297297629377`, 0.5853254324491394, 0.951876886674495], 
             UndirectedEdge[91, 96] -> 
             RGBColor[
              0.4234775951219629, 0.5412167411170028, 0.9482045957880054], 
             UndirectedEdge[55, 99] -> 
             RGBColor[
              0.6034466951550465, 0.6666361274324131, 0.847360946343275], 
             UndirectedEdge[77, 99] -> 
             RGBColor[
              0.47666517813662457`, 0.5692071999426849, 0.9550863292632896], 
             UndirectedEdge[29, 38] -> 
             RGBColor[
              0.4829112029710235, 0.5910009672767478, 0.9524597590821973], 
             UndirectedEdge[26, 90] -> 
             RGBColor[
              0.3195138308614136, 0.44036050432832197`, 0.9419758522996886], 
             UndirectedEdge[13, 27] -> 
             RGBColor[
              0.8609697230994028, 0.36695781813934386`, 0.20189065748895554`],
              UndirectedEdge[22, 99] -> 
             RGBColor[
              0.5807074175269119, 0.6512048989855446, 0.9542655829181864], 
             UndirectedEdge[73, 74] -> 
             RGBColor[
              0.5851831440651697, 0.6480609699443524, 0.8625188401499069], 
             UndirectedEdge[8, 77] -> 
             RGBColor[
              0.8394743030482452, 0.8753976113077471, 0.9813166861382819], 
             UndirectedEdge[36, 94] -> 
             RGBColor[
              0.6317754484141815, 0.6404518320823172, 0.6093667645289956], 
             UndirectedEdge[21, 87] -> 
             RGBColor[
              0.5904932836793886, 0.6726657017783227, 0.963704070926601], 
             UndirectedEdge[59, 83] -> 
             RGBColor[
              0.935711846921652, 0.9402511618161581, 0.6978986255134836], 
             UndirectedEdge[24, 42] -> 
             RGBColor[
              0.39799772456716404`, 0.5191473578979667, 0.9465810409672186], 
             UndirectedEdge[33, 42] -> 
             RGBColor[
              0.5506559028914049, 0.6446131018695862, 0.9584148034863872], 
             UndirectedEdge[14, 42] -> 
             RGBColor[
              0.6108649335195498, 0.691648854201874, 0.9644158769740194], 
             UndirectedEdge[45, 78] -> 
             RGBColor[
              0.5988624198310237, 0.6643773193308076, 0.9138633471839822], 
             UndirectedEdge[15, 38] -> 
             RGBColor[
              0.6212594686255792, 0.7021118345953499, 0.9642114194538602], 
             UndirectedEdge[84, 85] -> 
             RGBColor[
              0.5765495294307721, 0.6479300973614693, 0.9603073153779905], 
             UndirectedEdge[55, 98] -> 
             RGBColor[
              0.9913322850060433, 0.9906836913469534, 0.7933099989846082], 
             UndirectedEdge[86, 92] -> 
             RGBColor[
              0.8571996584315286, 0.8870953786986908, 0.8814103518826011], 
             UndirectedEdge[72, 92] -> 
             RGBColor[
              0.5850179029583706, 0.6725831444983545, 0.9613630308014073], 
             UndirectedEdge[19, 99] -> 
             RGBColor[
              0.6018517352962531, 0.6601673088153396, 0.6759448285712335], 
             UndirectedEdge[4, 76] -> 
             RGBColor[
              0.8825145761493729, 0.9089690449626002, 0.9821333210692682], 
             UndirectedEdge[23, 76] -> 
             RGBColor[
              0.7061559360516309, 0.7685289809250071, 0.9663722918016218], 
             UndirectedEdge[9, 72] -> 
             RGBColor[
              0.7072605757774133, 0.731621382119956, 0.6386709421288772], 
             UndirectedEdge[2, 44] -> 
             RGBColor[
              0.6032876255619037, 0.6665703480677464, 0.8499971411605618], 
             UndirectedEdge[74, 88] -> 
             RGBColor[
              0.24476883729548096`, 0.3744255437047106, 0.9372569077080346], 
             UndirectedEdge[21, 49] -> 
             RGBColor[
              0.263151029988302, 0.39052519484246706`, 0.9384216902583299], 
             UndirectedEdge[21, 34] -> 
             RGBColor[
              0.3964187246065888, 0.517779707494962, 0.9464804284859856], 
             UndirectedEdge[59, 66] -> 
             RGBColor[
              0.9385148407961577, 0.9507949628281045, 0.8740077273184854], 
             UndirectedEdge[17, 99] -> 
             RGBColor[
              0.3455541432445607, 0.4642584002060311, 0.9437439853867393], 
             UndirectedEdge[26, 53] -> 
             RGBColor[
              0.7204543470362704, 0.7767106191908485, 0.8516550477007867], 
             UndirectedEdge[23, 50] -> 
             RGBColor[
              0.37412633342625, 0.4952805731422975, 0.9452809233231523], 
             UndirectedEdge[41, 74] -> 
             RGBColor[
              0.5727535547756668, 0.60216150176626, 0.6290857328670137], 
             UndirectedEdge[59, 79] -> 
             RGBColor[
              0.6788329804323436, 0.7469645943918837, 0.9702499054460508], 
             UndirectedEdge[56, 93] -> 
             RGBColor[
              0.6804708797159784, 0.7495807062910111, 0.9692840890149028], 
             UndirectedEdge[19, 98] -> 
             RGBColor[
              0.9897373251472499, 0.9842148727298801, 0.6218938812125666], 
             UndirectedEdge[2, 38] -> 
             RGBColor[
              0.3646096351596373, 0.4797285069828183, 0.9452441035128609], 
             UndirectedEdge[19, 59] -> 
             RGBColor[
              0.9369198809373642, 0.9443261442110311, 0.7025916095464437], 
             UndirectedEdge[24, 76] -> 
             RGBColor[
              0.6591634217651596, 0.7282608387345567, 0.9632579410781892], 
             UndirectedEdge[5, 20] -> 
             RGBColor[
              0.5474830127752259, 0.6246641572802797, 0.9620679771555973], 
             UndirectedEdge[37, 84] -> 
             RGBColor[
              0.27739928824581095`, 0.40578015294244585`, 0.9392228869777224],
              UndirectedEdge[9, 82] -> 
             RGBColor[
              0.8043382420761045, 0.810600066167174, 0.6462672026280298], 
             UndirectedEdge[47, 75] -> 
             RGBColor[
              0.4130579041926235, 0.5312510194937752, 0.947800583008877], 
             UndirectedEdge[51, 75] -> 
             RGBColor[
              0.6140198817239373, 0.6911741887914697, 0.9660636004131409], 
             UndirectedEdge[58, 63] -> 
             RGBColor[
              0.7490335420489297, 0.8033603818984699, 0.9703225241362353], 
             UndirectedEdge[7, 25] -> 
             RGBColor[
              0.6687890791959652, 0.7401802893172376, 0.9683074373050622], 
             UndirectedEdge[1, 55] -> 
             RGBColor[
              0.5861571926252966, 0.648463764055871, 0.8463763347517326], 
             UndirectedEdge[82, 86] -> 
             RGBColor[
              0.8164394160187136, 0.8552374861693277, 0.877358473281382], 
             UndirectedEdge[34, 71] -> 
             RGBColor[
              0.6093688304927611, 0.6916150550437818, 0.963786387200393], 
             UndirectedEdge[41, 73] -> 
             RGBColor[
              0.9790096988408366, 0.9448284717106123, 0.5581035730169206], 
             UndirectedEdge[92, 94] -> 
             RGBColor[
              0.8356898450186131, 0.8085205413709036, 0.6252252390087605], 
             UndirectedEdge[3, 62] -> 
             RGBColor[
              0.6064188803221255, 0.6859566391265896, 0.96495040084543], 
             UndirectedEdge[70, 75] -> 
             RGBColor[
              0.25853960821404365`, 0.3863530933352983, 0.9381343690539508], 
             UndirectedEdge[57, 96] -> 
             RGBColor[
              0.557252529400863, 0.6507734134768979, 0.9586460932428165], 
             UndirectedEdge[68, 72] -> 
             RGBColor[
              0.5169699909666087, 0.6185718925092967, 0.9551629668929063], 
             UndirectedEdge[13, 54] -> 
             RGBColor[
              0.6356682823820846, 0.6434320975284521, 0.6095211958419067], 
             UndirectedEdge[48, 96] -> 
             RGBColor[
              0.5936655451125863, 0.6792195381000654, 0.9622754023499824], 
             UndirectedEdge[30, 50] -> 
             RGBColor[
              0.43020045905815174`, 0.5408040744408478, 0.9496952838991859], 
             UndirectedEdge[11, 92] -> 
             RGBColor[
              0.5572345711345984, 0.6485186189034635, 0.9595927014654322], 
             UndirectedEdge[41, 56] -> 
             RGBColor[
              0.866329619245986, 0.8580575542843764, 0.6509948659782454], 
             UndirectedEdge[73, 91] -> 
             RGBColor[
              0.6970106700456533, 0.7569230058800948, 0.869204915277402], 
             UndirectedEdge[32, 39] -> 
             RGBColor[
              0.6626471655490727, 0.6515649764110816, 0.6075973675091835], 
             UndirectedEdge[32, 80] -> 
             RGBColor[
              0.606562035571413, 0.5998378275102894, 0.6041389739707101], 
             UndirectedEdge[20, 66] -> 
             RGBColor[
              0.6020143946302694, 0.6651306887677739, 0.8472793789472877], 
             UndirectedEdge[47, 88] -> 
             RGBColor[
              0.39928713327406085`, 0.5193234698631873, 0.9469231216629608], 
             UndirectedEdge[14, 53] -> 
             RGBColor[
              0.8973975705797492, 0.9180965649255672, 0.8672008391236652], 
             UndirectedEdge[51, 57] -> 
             RGBColor[
              0.7800097337692773, 0.8286338037518088, 0.9785578039414964], 
             UndirectedEdge[30, 94] -> 
             RGBColor[
              0.7649945908165731, 0.7523600577141345, 0.6188167666239323], 
             UndirectedEdge[22, 69] -> 
             RGBColor[
              0.9714303494630497, 0.9761409771222218, 0.8324906066049071], 
             UndirectedEdge[4, 94] -> 
             RGBColor[
              0.8852791052824134, 0.8472766204531774, 0.6301634353155452], 
             UndirectedEdge[4, 86] -> 
             RGBColor[
              0.9067889186953288, 0.9258514577809647, 0.8863485481893858], 
             UndirectedEdge[9, 94] -> 
             RGBColor[
              0.9579325178376558, 0.867558778992505, 0.3025331503362304], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.4418836340588162, 0.5406340814555366, 0.9518415099033601], 
             UndirectedEdge[12, 60] -> 
             RGBColor[
              0.4535549997971217, 0.5592561163890327, 0.9515801008186278], 
             UndirectedEdge[25, 40] -> 
             RGBColor[
              0.8770611197089742, 0.9007055534447748, 0.7546328339930948], 
             UndirectedEdge[22, 95] -> 
             RGBColor[
              0.7344578429980808, 0.7913434669342548, 0.9642478286751011], 
             UndirectedEdge[3, 33] -> 
             RGBColor[
              0.7654058288311612, 0.8169040457390397, 0.977187427004462], 
             UndirectedEdge[48, 93] -> 
             RGBColor[
              0.6689102912167663, 0.7405494866917, 0.9681318375931431], 
             UndirectedEdge[15, 90] -> 
             RGBColor[
              0.459326669733673, 0.5527399113565087, 0.9538208339817125], 
             UndirectedEdge[77, 97] -> 
             RGBColor[
              0.46934809185639326`, 0.5615164783320963, 0.9546696320242896], 
             UndirectedEdge[44, 78] -> 
             RGBColor[
              0.9892135634249515, 0.989807545524511, 0.8284226986589875], 
             UndirectedEdge[30, 92] -> 
             RGBColor[
              0.6521605574678366, 0.7272592374181666, 0.9666026975169508], 
             UndirectedEdge[37, 76] -> 
             RGBColor[
              0.6427132188582191, 0.7140124997878035, 0.9622097486953023], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.6794772439536411, 0.707556856525065, 0.6369006127929022], 
             UndirectedEdge[75, 96] -> 
             RGBColor[
              0.3912626773555229, 0.5133137985165588, 0.9461518897144612], 
             UndirectedEdge[31, 80] -> 
             RGBColor[
              0.3430275933614931, 0.46838596489200357`, 0.9431936941645416], 
             UndirectedEdge[85, 90] -> 
             RGBColor[
              0.5662898837305272, 0.6371465592314035, 0.9597230437331472], 
             UndirectedEdge[91, 93] -> 
             RGBColor[
              0.4987223412261429, 0.6025466897086372, 0.9540610310311661], 
             UndirectedEdge[22, 49] -> 
             RGBColor[
              0.5643800923623934, 0.6340438450254292, 0.9533357659041801], 
             UndirectedEdge[69, 87] -> 
             RGBColor[
              0.9152438655222055, 0.9316542578655014, 0.8380478105240703], 
             UndirectedEdge[47, 70] -> 
             RGBColor[
              0.33344529597857986`, 0.4502919261584768, 0.9431672139549263], 
             UndirectedEdge[42, 78] -> 
             RGBColor[
              0.7030106532454361, 0.7634961853395752, 0.9201733087905914], 
             UndirectedEdge[1, 43] -> 
             RGBColor[
              0.350750975477925, 0.46434145638802227`, 0.9445295804379076], 
             UndirectedEdge[10, 35] -> 
             RGBColor[
              0.2883499086037265, 0.41571946958314787`, 0.9399040115608313], 
             UndirectedEdge[67, 94] -> 
             RGBColor[
              0.8599373976929178, 0.8274629138082963, 0.6276420084530723], 
             UndirectedEdge[73, 93] -> 
             RGBColor[
              0.7931509593108289, 0.8363516237172473, 0.876392796053578], 
             UndirectedEdge[68, 82] -> 
             RGBColor[
              0.6140476572652998, 0.6975505765565146, 0.9627592273920589], 
             UndirectedEdge[11, 52] -> 
             RGBColor[
              0.5944774603030657, 0.6776130469783113, 0.9633047246031581], 
             UndirectedEdge[15, 53] -> 
             RGBColor[
              0.8602671859085298, 0.8890900262190352, 0.8635000293828107], 
             UndirectedEdge[53, 100] -> 
             RGBColor[
              0.7875970015457364, 0.8313867121106605, 0.8568947144163302], 
             UndirectedEdge[58, 83] -> 
             RGBColor[
              0.7717512801915096, 0.8103222134624579, 0.682600508995317], 
             UndirectedEdge[74, 96] -> 
             RGBColor[
              0.3116500691414793, 0.4323547051812604, 0.9415185206605103], 
             UndirectedEdge[8, 87] -> 
             RGBColor[
              0.8873300584976883, 0.9129085910938861, 0.9860531437123419], 
             UndirectedEdge[43, 46] -> 
             RGBColor[
              0.6995106365533719, 0.7638037179151305, 0.9718177937835387], 
             UndirectedEdge[73, 89] -> 
             RGBColor[
              0.9487472332883892, 0.9593278806209977, 0.8912191130683416], 
             UndirectedEdge[11, 67] -> 
             RGBColor[
              0.5814821238089031, 0.6674609913408561, 0.962009470909744], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.5431116875638049, 0.636118332200447, 0.9587638055908481], 
             UndirectedEdge[98, 99] -> 
             RGBColor[
              0.6013915949104963, 0.6657862906676243, 0.8814192758244179], 
             UndirectedEdge[4, 9] -> 
             RGBColor[
              0.8946877447527195, 0.8812140377788109, 0.6552572775360337], 
             UndirectedEdge[34, 49] -> 
             RGBColor[
              0.31411904934874935`, 0.434671131485348, 0.9416693273827277], 
             UndirectedEdge[6, 7] -> 
             RGBColor[
              0.7136940630227813, 0.7755066097768555, 0.9727178109818482], 
             UndirectedEdge[7, 40] -> 
             RGBColor[
              0.7852150576103256, 0.8279526222506923, 0.7461636108872924], 
             UndirectedEdge[23, 85] -> 
             RGBColor[
              0.7050245759935425, 0.7676852144461168, 0.9682873892740043], 
             UndirectedEdge[82, 92] -> 
             RGBColor[
              0.6820955692570618, 0.7515618285455725, 0.9689592913005598], 
             UndirectedEdge[34, 69] -> 
             RGBColor[
              0.7211693064494057, 0.7767682635821407, 0.8208241680834547], 
             UndirectedEdge[13, 85] -> 
             RGBColor[
              0.94450163464165, 0.8939690660729841, 0.6312226235174098], 
             UndirectedEdge[95, 98] -> 
             RGBColor[
              0.7551420203816652, 0.8059248586163346, 0.8914015215813327], 
             UndirectedEdge[34, 87] -> 
             RGBColor[
              0.641461303039836, 0.7168116384212037, 0.9669517080509988], 
             UndirectedEdge[61, 94] -> 
             RGBColor[
              0.8424641368159296, 0.8138126696094917, 0.6259004371057608], 
             UndirectedEdge[61, 72] -> 
             RGBColor[
              0.591792194755687, 0.6778752727369426, 0.9620382288984077], 
             UndirectedEdge[50, 86] -> 
             RGBColor[
              0.6352395600218437, 0.700640215721372, 0.8645029382648362], 
             UndirectedEdge[66, 97] -> 
             RGBColor[
              0.5961296088748151, 0.6589454058218245, 0.8469442491042749], 
             UndirectedEdge[9, 21] -> 
             RGBColor[
              0.6563959312770518, 0.6875649835851098, 0.6354298919591532], 
             UndirectedEdge[34, 60] -> 
             RGBColor[
              0.5399050933679417, 0.6371972555929203, 0.9569669510750007], 
             UndirectedEdge[53, 84] -> 
             RGBColor[
              0.6030478293510643, 0.6661080937274628, 0.844500279944283], 
             UndirectedEdge[21, 22] -> 
             RGBColor[
              0.6466797676202328, 0.7171524210350433, 0.9581468670074378], 
             UndirectedEdge[14, 62] -> 
             RGBColor[
              0.5818704621966417, 0.6665353004464728, 0.962568374900128], 
             UndirectedEdge[22, 30] -> 
             RGBColor[
              0.7646870666300605, 0.8158849124897014, 0.9666275838927053], 
             UndirectedEdge[67, 72] -> 
             RGBColor[
              0.6092654556326753, 0.6915255169357472, 0.9637798002457192], 
             UndirectedEdge[61, 86] -> 
             RGBColor[
              0.863973950228845, 0.8923875069372789, 0.8820855499796014], 
             UndirectedEdge[5, 83] -> 
             RGBColor[
              0.9360530095210444, 0.9405231956123015, 0.6979311659067731], 
             UndirectedEdge[46, 99] -> 
             RGBColor[
              0.5449761636051966, 0.6230286249036501, 0.9617738249371736], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.5081936084215491, 0.5895571257687087, 0.9588929698233433], 
             UndirectedEdge[7, 37] -> 
             RGBColor[
              0.4596873173562431, 0.5692230735065225, 0.9514393159833381], 
             UndirectedEdge[7, 53] -> 
             RGBColor[
              0.7853358584614964, 0.8295510142915394, 0.8567167089498988], 
             UndirectedEdge[12, 52] -> 
             RGBColor[
              0.5360140734161039, 0.6238259714773495, 0.9596947906374339], 
             UndirectedEdge[50, 85] -> 
             RGBColor[
              0.6098338574177994, 0.6829140364241173, 0.9622028086171011], 
             UndirectedEdge[14, 15] -> 
             RGBColor[
              0.7639360566626028, 0.8155119206846788, 0.977105664805938], 
             UndirectedEdge[14, 35] -> 
             RGBColor[
              0.5091742777025244, 0.5951130580673798, 0.9582458707759212], 
             UndirectedEdge[8, 95] -> 
             RGBColor[
              0.7300655554422891, 0.7880677060668562, 0.9716828258149917], 
             UndirectedEdge[7, 84] -> 
             RGBColor[
              0.3946549879868845, 0.5039844375590786, 0.9476217851936439], 
             UndirectedEdge[14, 76] -> 
             RGBColor[
              0.8720306307175454, 0.900762335038464, 0.9810927770849902], 
             UndirectedEdge[60, 89] -> 
             RGBColor[
              0.7692393106076431, 0.8201983442006442, 0.9775536911882439], 
             UndirectedEdge[37, 85] -> 
             RGBColor[
              0.6415818588001307, 0.7131687333089132, 0.9641248461676848], 
             UndirectedEdge[39, 80] -> 
             RGBColor[
              0.33077168680305613`, 0.45777051463086005`, 0.9424127586361106],
              UndirectedEdge[23, 24] -> 
             RGBColor[
              0.42232453771552186`, 0.5397836089738466, 0.948251153256623], 
             UndirectedEdge[11, 68] -> 
             RGBColor[
              0.48918665914283643`, 0.5945073669144056, 0.9533926375569312], 
             UndirectedEdge[27, 81] -> 
             RGBColor[
              0.8751956035559959, 0.41646145148070446`, 0.24925808930972007`],
              UndirectedEdge[36, 61] -> 
             RGBColor[
              0.5257157068627615, 0.6206431400249373, 0.9578278935190145], 
             UndirectedEdge[28, 59] -> 
             RGBColor[
              0.5800654504719879, 0.6589969148722201, 0.963910387093072], 
             UndirectedEdge[8, 30] -> 
             RGBColor[
              0.7602947790742687, 0.8126091516223027, 0.974062581032596], 
             UndirectedEdge[34, 82] -> 
             RGBColor[
              0.5443610354056415, 0.6408147900770262, 0.9573177391548621], 
             UndirectedEdge[50, 84] -> 
             RGBColor[
              0.24565128686347962`, 0.37552545605765, 0.9373008494271386], 
             UndirectedEdge[57, 88] -> 
             RGBColor[
              0.49037129755486464`, 0.5928442520003481, 0.9543844802903407], 
             UndirectedEdge[6, 53] -> 
             RGBColor[
              0.9220869043869611, 0.9376302659452396, 0.8695963057324874], 
             UndirectedEdge[8, 69] -> 
             RGBColor[
              0.967038061907258, 0.9728652162548233, 0.8399256037447977], 
             UndirectedEdge[69, 99] -> 
             RGBColor[
              0.6042289369956374, 0.666674804889761, 0.8136952468698055], 
             UndirectedEdge[81, 84] -> 
             RGBColor[
              0.60165788477222, 0.6608359357185577, 0.6773718120585941], 
             UndirectedEdge[11, 94] -> 
             RGBColor[
              0.6700686044833348, 0.6736194391994315, 0.6118067705724137], 
             UndirectedEdge[10, 65] -> 
             RGBColor[
              0.6440092853409874, 0.7158182121386999, 0.9685873649532741], 
             UndirectedEdge[79, 98] -> 
             RGBColor[
              0.7316504246422293, 0.7868533229107326, 0.8895521771121737], 
             UndirectedEdge[33, 62] -> 
             RGBColor[
              0.5216614315684968, 0.6194995481141848, 0.9565673014124958], 
             UndirectedEdge[31, 70] -> 
             RGBColor[
              0.29514781494879494`, 0.41806128202696957`, 0.940467011615723], 
             UndirectedEdge[31, 32] -> 
             RGBColor[
              0.6749030721075097, 0.6621804266722251, 0.6083783030376144], 
             UndirectedEdge[15, 100] -> 
             RGBColor[
              0.65413548762859, 0.7288020678697722, 0.966799540098603], 
             UndirectedEdge[7, 65] -> 
             RGBColor[
              0.7527719423215327, 0.8066662499889039, 0.9764450939945978], 
             UndirectedEdge[59, 95] -> 
             RGBColor[
              0.7023245761717796, 0.7660361300974856, 0.9720992499152098], 
             UndirectedEdge[2, 3] -> 
             RGBColor[
              0.5318346413221446, 0.6125499317522641, 0.9605203748102407], 
             UndirectedEdge[48, 88] -> 
             RGBColor[
              0.5267843132665879, 0.6212903766235156, 0.9580137893975066], 
             UndirectedEdge[14, 38] -> 
             RGBColor[
              0.6583898532967987, 0.7311183733018818, 0.9679122291947148], 
             UndirectedEdge[44, 45] -> 
             RGBColor[
              0.6027181024703802, 0.6659717431887056, 0.8499647076630334], 
             UndirectedEdge[24, 50] -> 
             RGBColor[
              0.3271338191397788, 0.45501243095184707`, 0.9421665725997199], 
             UndirectedEdge[38, 62] -> 
             RGBColor[
              0.4391938741596181, 0.5531352143571437, 0.9496741295480504], 
             UndirectedEdge[4, 50] -> 
             RGBColor[
              0.5504849735239921, 0.6357206371798907, 0.9610419525907988], 
             UndirectedEdge[48, 74] -> 
             RGBColor[
              0.46094247597110705`, 0.5522588329188051, 0.954257881689472], 
             UndirectedEdge[40, 100] -> 
             RGBColor[
              0.7874762006945655, 0.8297883200698135, 0.7463416163537238], 
             UndirectedEdge[19, 95] -> 
             RGBColor[
              0.755602160767422, 0.8003058767640499, 0.685927074328148], 
             UndirectedEdge[19, 79] -> 
             RGBColor[
              0.7321105650279862, 0.7812343410584479, 0.6840777298589891], 
             UndirectedEdge[51, 70] -> 
             RGBColor[
              0.5344072735098936, 0.6102150954561714, 0.9614302313591903], 
             UndirectedEdge[17, 22] -> 
             RGBColor[
              0.7127555557119731, 0.7737245724384918, 0.9625393451218409], 
             UndirectedEdge[59, 99] -> 
             RGBColor[
              0.5485741507006107, 0.6258975621487753, 0.9621170041582952], 
             UndirectedEdge[20, 63] -> 
             RGBColor[
              0.5764936626131839, 0.6476250561918395, 0.9588922922832043], 
             UndirectedEdge[56, 89] -> 
             RGBColor[
              0.8360671536935387, 0.8725569631947617, 0.9841104060296664], 
             UndirectedEdge[12, 74] -> 
             RGBColor[
              0.22680677841269817`, 0.35571868286503394`, 0.9362276825488186],
              UndirectedEdge[8, 17] -> 
             RGBColor[
              0.7083632681561813, 0.7704488115710932, 0.9699743422617315], 
             UndirectedEdge[53, 90] -> 
             RGBColor[
              0.5927881836508194, 0.655324555597397, 0.8439160082994397], 
             UndirectedEdge[21, 72] -> 
             RGBColor[
              0.396315349746503, 0.5176901693869274, 0.9464738415313116], 
             UndirectedEdge[48, 73] -> 
             RGBColor[
              0.8671986200362767, 0.8949258028631575, 0.883275721839379], 
             UndirectedEdge[8, 49] -> 
             RGBColor[
              0.5599878048066017, 0.6307680841580305, 0.9607707630440707], 
             UndirectedEdge[17, 69] -> 
             RGBColor[
              0.7362770751806986, 0.7891944783427084, 0.8219690090734599], 
             UndirectedEdge[21, 82] -> 
             RGBColor[
              0.49339301604519414`, 0.5966688534341453, 0.9540701020304643], 
             UndirectedEdge[36, 68] -> 
             RGBColor[
              0.45089350307368303`, 0.5613397597972913, 0.9509526315135131], 
             UndirectedEdge[21, 30] -> 
             RGBColor[
              0.463458004255969, 0.5723662623067394, 0.9517135082468551], 
             UndirectedEdge[56, 64] -> 
             RGBColor[
              0.627021360448899, 0.7061879786765931, 0.965076347066158], 
             UndirectedEdge[48, 64] -> 
             RGBColor[
              0.615460771949687, 0.6971567590772818, 0.9639240956443984], 
             UndirectedEdge[46, 59] -> 
             RGBColor[
              0.8800443092463077, 0.9071874602993417, 0.9884206059123839], 
             UndirectedEdge[46, 79] -> 
             RGBColor[
              0.6752349933369297, 0.7440956571467584, 0.9699067262249292], 
             UndirectedEdge[9, 86] -> 
             RGBColor[
              0.9794423312505712, 0.9461336163202922, 0.558718263210071], 
             UndirectedEdge[64, 91] -> 
             RGBColor[
              0.44527282195906354`, 0.5591539620942192, 0.9498532890824214], 
             UndirectedEdge[1, 19] -> 
             RGBColor[
              0.5845622327665034, 0.6419949454387976, 0.6749602169796911], 
             UndirectedEdge[5, 69] -> 
             RGBColor[
              0.9396382452361409, 0.9511056740815961, 0.8403745682383053], 
             UndirectedEdge[36, 92] -> 
             RGBColor[
              0.518941415065445, 0.6153510117863492, 0.9571526954220141], 
             UndirectedEdge[17, 95] -> 
             RGBColor[
              0.49930456871572965`, 0.6043969681547414, 0.953726231143654], 
             UndirectedEdge[7, 13] -> 
             RGBColor[
              0.7626070931977624, 0.7500234062705934, 0.6185370933330632], 
             UndirectedEdge[11, 61] -> 
             RGBColor[
              0.5640088629319149, 0.6538107471420516, 0.9602678995624325], 
             UndirectedEdge[66, 83] -> 
             RGBColor[
              0.9905843913760879, 0.9809897270997958, 0.5831425676984634], 
             UndirectedEdge[27, 37] -> 
             RGBColor[
              0.6590232058717231, 0.24642426296329656`, 0.42382547258913883`],
              UndirectedEdge[22, 34] -> 
             RGBColor[
              0.6976477869806802, 0.7612983576779242, 0.9613945041318357], 
             UndirectedEdge[6, 90] -> 
             RGBColor[
              0.5211463882121044, 0.601280151082713, 0.959917110331389], 
             UndirectedEdge[71, 77] -> 
             RGBColor[
              0.7555876341161178, 0.8089900695410035, 0.9762735720669486], 
             UndirectedEdge[9, 68] -> 
             RGBColor[
              0.7770505724971574, 0.7884467067074792, 0.6441190173207478], 
             UndirectedEdge[23, 86] -> 
             RGBColor[
              0.7304302785975867, 0.7854113937433715, 0.8705875189217394], 
             UndirectedEdge[54, 84] -> 
             RGBColor[
              0.26771617717120666`, 0.39739312881693734`, 0.9386058877024874],
              UndirectedEdge[3, 16] -> 
             RGBColor[
              0.526641082812445, 0.6070911724679413, 0.9602246093362945], 
             UndirectedEdge[66, 98] -> 
             RGBColor[
              0.9913322850060433, 0.9906836913469534, 0.7933099989846082], 
             UndirectedEdge[64, 93] -> 
             RGBColor[
              0.5414131112242391, 0.6385825799313716, 0.9570411698585974], 
             UndirectedEdge[2, 29] -> 
             RGBColor[
              0.3318075728708858, 0.4530111870470133, 0.942685878752421], 
             UndirectedEdge[50, 81] -> 
             RGBColor[
              0.6349422127592472, 0.6958198747812057, 0.6792673052977047], 
             UndirectedEdge[8, 99] -> 
             RGBColor[
              0.5763151299711202, 0.6479291381181459, 0.9617005800580771], 
             UndirectedEdge[66, 69] -> 
             RGBColor[
              0.9941696270911844, 0.9915722055690903, 0.7255859700299957], 
             UndirectedEdge[9, 30] -> 
             RGBColor[
              0.7744032302868793, 0.786297475039768, 0.6439106088444206], 
             UndirectedEdge[11, 36] -> 
             RGBColor[
              0.3533201745301668, 0.4804499096148771, 0.9437342269856673], 
             UndirectedEdge[16, 62] -> 
             RGBColor[
              0.28289668554978065`, 0.40968667484308646`, 0.9396044837443281],
              UndirectedEdge[50, 76] -> 
             RGBColor[
              0.6109652174758877, 0.6837578029030076, 0.9602877111447186], 
             UndirectedEdge[36, 86] -> 
             RGBColor[
              0.653285261827097, 0.7190266694101044, 0.8655518774028361], 
             UndirectedEdge[60, 71] -> 
             RGBColor[
              0.7018871798936666, 0.7668866664988592, 0.9710252726650104], 
             UndirectedEdge[43, 54] -> 
             RGBColor[
              0.42282017321090554`, 0.5387668267074586, 0.9486822900463809], 
             UndirectedEdge[29, 42] -> 
             RGBColor[
              0.4353862831937747, 0.55153144817674, 0.9489634068615019], 
             UndirectedEdge[76, 84] -> 
             RGBColor[
              0.5776808894888605, 0.6487738638403596, 0.958392217905608], 
             UndirectedEdge[65, 90] -> 
             RGBColor[
              0.5602242675108555, 0.6324397912947615, 0.9636443933441387], 
             UndirectedEdge[52, 78] -> 
             RGBColor[
              0.8913497353962031, 0.9149108494456222, 0.9363782771785835], 
             UndirectedEdge[25, 65] -> 
             RGBColor[
              0.8446180044201812, 0.8794191811829862, 0.9849143171004002], 
             UndirectedEdge[45, 52] -> 
             RGBColor[
              0.5048542744416318, 0.5910750471098166, 0.9579202861826294], 
             UndirectedEdge[57, 74] -> 
             RGBColor[
              0.42452946025938365`, 0.5238127082956374, 0.9506285725823062], 
             UndirectedEdge[17, 66] -> 
             RGBColor[
              0.7354948333401077, 0.7891558008853603, 0.8556347085469296], 
             UndirectedEdge[59, 98] -> 
             RGBColor[
              0.9364597405516074, 0.9499451260633158, 0.9080660567996284], 
             UndirectedEdge[22, 77] -> 
             RGBColor[
              0.8438665906040369, 0.8786733721751456, 0.9738816889983912], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.7902297908634939, 0.8369117427497088, 0.976419174816205], 
             UndirectedEdge[30, 36] -> 
             RGBColor[
              0.44824616086340496`, 0.5591905281295801, 0.9507442230371859], 
             UndirectedEdge[60, 64] -> 
             RGBColor[
              0.5601935173630035, 0.6538293596824756, 0.9585196322247354], 
             UndirectedEdge[28, 99] -> 
             RGBColor[
              0.24499730483087676`, 0.37483807947652864`, 0.9372636061178616],
              UndirectedEdge[59, 69] -> 
             RGBColor[
              0.9392970826367485, 0.9508336402854527, 0.8403420278450158], 
             UndirectedEdge[66, 79] -> 
             RGBColor[
              0.7337055248867795, 0.7877031596755213, 0.8554938476310308], 
             UndirectedEdge[7, 81] -> 
             RGBColor[
              0.7839459138826521, 0.8242788562826343, 0.68958824106421], 
             UndirectedEdge[26, 100] -> 
             RGBColor[
              0.5143226487563306, 0.6164226608415855, 0.9549545584165791], 
             UndirectedEdge[5, 97] -> 
             RGBColor[
              0.5415982270197717, 0.6184788743343301, 0.9617328473125846], 
             UndirectedEdge[20, 83] -> 
             RGBColor[
              0.5992114007557638, 0.6545868877558274, 0.6711702771422859], 
             UndirectedEdge[21, 92] -> 
             RGBColor[
              0.5341532584580091, 0.6285267459635083, 0.9581219806316833], 
             UndirectedEdge[77, 98] -> 
             RGBColor[
              0.8645507679876213, 0.8932547638572255, 0.9010353819046228], 
             UndirectedEdge[13, 84] -> 
             RGBColor[
              0.5803190640873302, 0.5865804857065168, 0.6063206643274474], 
             UndirectedEdge[83, 97] -> 
             RGBColor[
              0.5933266150003096, 0.648401604809878, 0.6708351472992731], 
             UndirectedEdge[4, 24] -> 
             RGBColor[
              0.5986831778132639, 0.6802236730114397, 0.9640121825242696], 
             UndirectedEdge[7, 85] -> 
             RGBColor[
              0.7588375585412043, 0.811373017925546, 0.9725237443836063], 
             UndirectedEdge[10, 40] -> 
             RGBColor[
              0.6764524006297804, 0.7371045844004884, 0.7383058818459688], 
             UndirectedEdge[26, 40] -> 
             RGBColor[
              0.7203335461850995, 0.7751122271500015, 0.7411019496381803], 
             UndirectedEdge[56, 74] -> 
             RGBColor[
              0.4725030644703191, 0.5612900525181164, 0.9554101331112317], 
             UndirectedEdge[42, 62] -> 
             RGBColor[
              0.3916689543823693, 0.513665695257136, 0.9461777773273552], 
             UndirectedEdge[4, 36] -> 
             RGBColor[
              0.5685306753292453, 0.6541070908686231, 0.9620908917287989], 
             UndirectedEdge[2, 33] -> 
             RGBColor[
              0.44707719256851586`, 0.5460928407398594, 0.9521372753773063], 
             UndirectedEdge[36, 82] -> 
             RGBColor[
              0.47818117265263016`, 0.5834931192569861, 0.9531008168207951], 
             UndirectedEdge[76, 81] -> 
             RGBColor[
              0.9669718153846282, 0.9690682825639153, 0.7003586737761741], 
             UndirectedEdge[27, 43] -> 
             RGBColor[
              0.71907098365195, 0.2971809709253481, 0.42799805362527166`], 
             UndirectedEdge[61, 67] -> 
             RGBColor[
              0.7538776561414977, 0.8076542217509164, 0.9761031374430912], 
             UndirectedEdge[10, 26] -> 
             RGBColor[
              0.4032988486915455, 0.5237389251722603, 0.9469188239088241], 
             UndirectedEdge[63, 83] -> 
             RGBColor[
              0.9650636593590023, 0.9634840945238613, 0.69475548103438], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.45000420628163884`, 0.560836049381014, 0.9508223167081034], 
             UndirectedEdge[20, 97] -> 
             RGBColor[
              0.20475661825449115`, 0.3325425664778562, 0.9349719585480974], 
             UndirectedEdge[28, 98] -> 
             RGBColor[
              0.6328828946818735, 0.6988856433910691, 0.8832126587591949], 
             UndirectedEdge[4, 23] -> 
             RGBColor[
              0.6456756920997351, 0.7204918152018902, 0.9671265332477019], 
             UndirectedEdge[30, 86] -> 
             RGBColor[
              0.7865044042294885, 0.8309348950419218, 0.8750018794977729], 
             UndirectedEdge[27, 54] -> 
             RGBColor[
              0.6525677984886538, 0.24083291354629088`, 0.42341413973898223`],
              UndirectedEdge[1, 13] -> 
             RGBColor[
              0.5635990846491041, 0.5690067272090158, 0.6053684862334333], 
             UndirectedEdge[15, 35] -> 
             RGBColor[
              0.472043893031305, 0.5661065193608478, 0.9545450610350668], 
             UndirectedEdge[56, 73] -> 
             RGBColor[
              0.8787592085354887, 0.9039570224624687, 0.8844279732611386], 
             UndirectedEdge[16, 29] -> 
             RGBColor[
              0.3266140143611861, 0.44755242776269055`, 0.9423901132784749], 
             UndirectedEdge[53, 65] -> 
             RGBColor[
              0.9611647836857125, 0.968789906157288, 0.8733235887452369], 
             UndirectedEdge[6, 25] -> 
             RGBColor[
              0.8055401251214298, 0.8482595409709378, 0.9811870340876507], 
             UndirectedEdge[68, 92] -> 
             RGBColor[
              0.6548078996781147, 0.7294084690858778, 0.9668111059932779], 
             UndirectedEdge[69, 97] -> 
             RGBColor[
              0.5969118507154061, 0.6589840832791725, 0.8132785496308055], 
             UndirectedEdge[17, 77] -> 
             RGBColor[
              0.6087133163216858, 0.6917268733956322, 0.9633600914669442], 
             UndirectedEdge[46, 98] -> 
             RGBColor[
              0.9328617534561934, 0.9470761888181907, 0.9077228775785067], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.4063918118708666, 0.5264178944213388, 0.9471159047876105], 
             UndirectedEdge[17, 55] -> 
             RGBColor[
              0.7354948333401077, 0.7891558008853603, 0.8556347085469296], 
             UndirectedEdge[2, 78] -> 
             RGBColor[
              0.5994319429225472, 0.6649759242098484, 0.9138957806815106], 
             UndirectedEdge[6, 35] -> 
             RGBColor[
              0.5338636115097364, 0.6146467590870521, 0.9606413373847433], 
             UndirectedEdge[95, 99] -> 
             RGBColor[
              0.3672564305306685, 0.4818772947017941, 0.9454524689399995], 
             UndirectedEdge[66, 99] -> 
             RGBColor[
              0.6034466951550465, 0.6666361274324131, 0.847360946343275], 
             UndirectedEdge[31, 39] -> 
             RGBColor[
              0.3991127233391528, 0.5201131137927957, 0.9466520877030149], 
             UndirectedEdge[69, 71] -> 
             RGBColor[
              0.8831513929751307, 0.9064576744880797, 0.8348824896734643], 
             UndirectedEdge[64, 89] -> 
             RGBColor[
              0.6970093852017993, 0.7615588368351222, 0.971867486873361], 
             UndirectedEdge[40, 53] -> 
             RGBColor[
              0.9936078989745054, 0.9900762784190765, 0.6430421056379314], 
             UndirectedEdge[1, 27] -> 
             RGBColor[0.6045216666666666, 0.191216, 0.4206456666666667], 
             UndirectedEdge[41, 48] -> 
             RGBColor[
              0.8547690307467739, 0.849026334685065, 0.6498426145564857], 
             UndirectedEdge[57, 70] -> 
             RGBColor[
              0.42452946025938365`, 0.5238127082956374, 0.9506285725823062], 
             UndirectedEdge[39, 44] -> 
             RGBColor[
              0.6899630314225118, 0.7504498164570306, 0.8551976056563114], 
             UndirectedEdge[6, 15] -> 
             RGBColor[
              0.7886253904698146, 0.8350456217043514, 0.9795011314147601], 
             UndirectedEdge[6, 40] -> 
             RGBColor[
              0.9219661035357902, 0.9360318739043927, 0.7590432076698809], 
             UndirectedEdge[17, 59] -> 
             RGBColor[
              0.6806222888856719, 0.7484172356017227, 0.9703907663619497], 
             UndirectedEdge[56, 91] -> 
             RGBColor[
              0.5843305904508027, 0.6701520884538588, 0.9620962082387268], 
             UndirectedEdge[5, 59] -> 
             RGBColor[
              0.8839834589411142, 0.9103284313406104, 0.988796325526795], 
             UndirectedEdge[20, 58] -> 
             RGBColor[
              0.38318128344569113`, 0.49446317513043614`, 0.9467373202441413],
              UndirectedEdge[17, 19] -> 
             RGBColor[
              0.7338998734813142, 0.7826869822682869, 0.684218590774888], 
             UndirectedEdge[3, 38] -> 
             RGBColor[
              0.6829382714222825, 0.7505397119819986, 0.9702942551400168], 
             UndirectedEdge[1, 17] -> 
             RGBColor[
              0.328264640714811, 0.4460860368294892, 0.9427593737951969], 
             UndirectedEdge[2, 42] -> 
             RGBColor[
              0.31708471538238847`, 0.44025898788281054`, 0.9417477512921657],
              UndirectedEdge[12, 64] -> 
             RGBColor[
              0.38132507439127805`, 0.5006166090235107, 0.9458938965037449], 
             UndirectedEdge[48, 56] -> 
             RGBColor[
              0.7545185404414261, 0.8081548854369214, 0.9761670148007038], 
             UndirectedEdge[86, 94] -> 
             RGBColor[
              0.970033691780265, 0.9121961989946588, 0.5336244209895825], 
             UndirectedEdge[23, 30] -> 
             RGBColor[
              0.5253911776338949, 0.6255752524628473, 0.9557798645560891], 
             UndirectedEdge[30, 82] -> 
             RGBColor[
              0.6114003150550218, 0.6954013448888035, 0.9625508189157317], 
             UndirectedEdge[60, 74] -> 
             RGBColor[
              0.4056752213844236, 0.5089314335239988, 0.9488534182698092], 
             UndirectedEdge[10, 90] -> 
             RGBColor[
              0.27563268530609447`, 0.4023528615788088, 0.939179784507477], 
             UndirectedEdge[49, 69] -> 
             RGBColor[
              0.5879016118311189, 0.6495137509296458, 0.8127654298557991], 
             UndirectedEdge[25, 100] -> 
             RGBColor[
              0.6710502222802052, 0.7420159871363587, 0.9684854427714936], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.9610439828345415, 0.9671915141164411, 0.7627704906826305], 
             UndirectedEdge[31, 51] -> 
             RGBColor[
              0.6506280884586886, 0.722882377483141, 0.9683962429749131], 
             UndirectedEdge[37, 50] -> 
             RGBColor[
              0.3106836162328382, 0.4407640920050938, 0.9411183802168328], 
             UndirectedEdge[6, 10] -> 
             RGBColor[
              0.6049314060422362, 0.6846585719266515, 0.9648600819405246], 
             UndirectedEdge[69, 77] -> 
             RGBColor[
              0.8673881100727624, 0.8941432780793622, 0.8333113529500104], 
             UndirectedEdge[12, 96] -> 
             RGBColor[
              0.35952984755417744`, 0.4826793880462943, 0.9442452032093289], 
             UndirectedEdge[12, 41] -> 
             RGBColor[
              0.620633333188365, 0.6524861846312939, 0.6318124154158323], 
             UndirectedEdge[89, 93] -> 
             RGBColor[
              0.7504589044688788, 0.8049515644495402, 0.9760752288221058], 
             UndirectedEdge[37, 81] -> 
             RGBColor[
              0.6666902141415786, 0.7260745716660015, 0.6811893428482884], 
             UndirectedEdge[14, 24] -> 
             RGBColor[
              0.5881992323814365, 0.6720169630873035, 0.9629716385399915], 
             UndirectedEdge[52, 67] -> 
             RGBColor[
              0.7843462535126486, 0.8314565215871761, 0.9791399624838166], 
             UndirectedEdge[23, 27] -> 
             RGBColor[
              0.7013183506673311, 0.2827685837214324, 0.42660050132668514`], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.24356500430609968`, 0.37333264081188955`, 0.9371820387218743],
              UndirectedEdge[23, 81] -> 
             RGBColor[
              0.7301329313349905, 0.7805910528032052, 0.6853518859546078], 
             UndirectedEdge[88, 96] -> 
             RGBColor[
              0.37749190643696023`, 0.5013862488859709, 0.9452744283685449], 
             UndirectedEdge[77, 95] -> 
             RGBColor[
              0.6304156036077935, 0.7093457678913953, 0.9650685750202044], 
             UndirectedEdge[74, 91] -> 
             RGBColor[
              0.2907545259804837, 0.41425603593574234`, 0.940187075127495], 
             UndirectedEdge[7, 100] -> 
             RGBColor[
              0.5792041601815566, 0.6692630559422763, 0.9600162196656912], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.6385953920711478, 0.6711930454709706, 0.6328416405750483], 
             UndirectedEdge[6, 100] -> 
             RGBColor[
              0.7159552061070213, 0.7773423075959767, 0.9728958164482797], 
             UndirectedEdge[19, 55] -> 
             RGBColor[
              0.9917924253918, 0.9850647094946687, 0.5878355517314237], 
             UndirectedEdge[17, 28] -> 
             RGBColor[
              0.37704544301593795`, 0.4973577529294759, 0.9455373683215161], 
             UndirectedEdge[64, 96] -> 
             RGBColor[
              0.46616836512005916`, 0.5772526313397371, 0.9511847346154367], 
             UndirectedEdge[67, 68] -> 
             RGBColor[
              0.6790554523524194, 0.7483508415232704, 0.9692278754375898], 
             UndirectedEdge[22, 87] -> 
             RGBColor[
              0.89172234605348, 0.9161843519612849, 0.9786181465724513], 
             UndirectedEdge[42, 44] -> 
             RGBColor[
              0.7068663358847926, 0.7650906091974732, 0.8562746692696428], 
             UndirectedEdge[70, 96] -> 
             RGBColor[
              0.3116500691414793, 0.4323547051812604, 0.9415185206605103], 
             UndirectedEdge[64, 88] -> 
             RGBColor[
              0.39928713327406085`, 0.5193234698631873, 0.9469231216629608], 
             UndirectedEdge[26, 65] -> 
             RGBColor[
              0.6878904308963065, 0.7538258548882131, 0.9713834327454858], 
             UndirectedEdge[2, 14] -> 
             RGBColor[
              0.5072862231966608, 0.5931285930721473, 0.9581383488649386], 
             UndirectedEdge[11, 72] -> 
             RGBColor[
              0.41939666242309237`, 0.5376820423268824, 0.9479445623650605], 
             UndirectedEdge[67, 86] -> 
             RGBColor[
              0.8814472111058332, 0.9060377511360834, 0.8838271213269129], 
             UndirectedEdge[40, 90] -> 
             RGBColor[
              0.5926673827996485, 0.65372616355655, 0.7333629102368333], 
             UndirectedEdge[27, 84] -> 
             RGBColor[
              0.6156683196254842, 0.202931838998334, 0.42128045206267606`], 
             UndirectedEdge[13, 43] -> 
             RGBColor[
              0.7354230601270291, 0.727954183597038, 0.6163970666713409], 
             UndirectedEdge[52, 72] -> 
             RGBColor[
              0.6222607921268379, 0.7016775725732023, 0.9650750539391331], 
             UndirectedEdge[10, 53] -> 
             RGBColor[
              0.6765732014809513, 0.7387029764413353, 0.8488589799085753], 
             UndirectedEdge[15, 40] -> 
             RGBColor[
              0.860146385057359, 0.8874916341781882, 0.7529469313202042], 
             UndirectedEdge[21, 68] -> 
             RGBColor[
              0.4661053464662471, 0.5745154939744506, 0.9519219167231823], 
             UndirectedEdge[28, 83] -> 
             RGBColor[
              0.6321350010519181, 0.6891916791439114, 0.6730452274730501], 
             UndirectedEdge[54, 100] -> 
             RGBColor[
              0.4522653493658788, 0.562671747200135, 0.9510003221745347], 
             UndirectedEdge[47, 96] -> 
             RGBColor[
              0.46616836512005916`, 0.5772526313397371, 0.9511847346154367], 
             UndirectedEdge[47, 51] -> 
             RGBColor[
              0.6889255694884735, 0.7551130216146481, 0.9710964453141164], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.5447400775254223, 0.6375287617399408, 0.9588675651592735], 
             UndirectedEdge[39, 45] -> 
             RGBColor[
              0.2996118878285841, 0.4250195902633271, 0.9406382541813061], 
             UndirectedEdge[58, 97] -> 
             RGBColor[
              0.37729649769023693`, 0.4882778921844866, 0.9464021904011285], 
             UndirectedEdge[31, 45] -> 
             RGBColor[
              0.31186779438702106`, 0.4356350405244706, 0.941419189709737], 
             UndirectedEdge[6, 26] -> 
             RGBColor[
              0.6488125515975554, 0.7226662146761647, 0.9676561497327362], 
             UndirectedEdge[41, 91] -> 
             RGBColor[
              0.6845810807561505, 0.7110235377020024, 0.6357718079945087], 
             UndirectedEdge[8, 22] -> 
             RGBColor[
              0.9435165424385326, 0.9573953103506067, 0.9804959397931787], 
             UndirectedEdge[46, 95] -> 
             RGBColor[
              0.6987265890763655, 0.7631671928523605, 0.9717560706940882], 
             UndirectedEdge[66, 95] -> 
             RGBColor[
              0.7571971206262154, 0.8067746953811232, 0.8573431921001897], 
             UndirectedEdge[23, 37] -> 
             RGBColor[
              0.40587433480858126`, 0.5255352700270934, 0.947202960873736], 
             UndirectedEdge[10, 100] -> 
             RGBColor[
              0.47044150320101147`, 0.5784150180920723, 0.9521584906243676], 
             UndirectedEdge[5, 79] -> 
             RGBColor[
              0.6791741430317361, 0.747236628188027, 0.9702824458393403], 
             UndirectedEdge[38, 42] -> 
             RGBColor[
              0.4681883454825262, 0.578248768112545, 0.9515216316219419], 
             UndirectedEdge[40, 54] -> 
             RGBColor[
              0.6582762467946477, 0.721361313508551, 0.7371477133961359], 
             UndirectedEdge[32, 45] -> 
             RGBColor[
              0.5754022365969409, 0.5670869031427564, 0.6023644695159056], 
             UndirectedEdge[41, 60] -> 
             RGBColor[
              0.7995017761600904, 0.8056989352902588, 0.6444381511368229], 
             UndirectedEdge[88, 91] -> 
             RGBColor[
              0.3565963632759646, 0.483287579640453, 0.9439429828355296], 
             UndirectedEdge[47, 57] -> 
             RGBColor[
              0.5790477562379636, 0.6687106344541143, 0.9602947865372324], 
             UndirectedEdge[27, 85] -> 
             RGBColor[
              0.8584566999950306, 0.40785755924264555`, 0.4378817581893176], 
             UndirectedEdge[69, 95] -> 
             RGBColor[
              0.7579793624668063, 0.8068133728384714, 0.8236774926267201], 
             UndirectedEdge[36, 72] -> 
             RGBColor[
              0.38110350635393897`, 0.5045144352097681, 0.9455045563216424], 
             UndirectedEdge[6, 65] -> 
             RGBColor[
              0.8895229882469973, 0.9147455016426042, 0.9893246907771862], 
             UndirectedEdge[49, 77] -> 
             RGBColor[
              0.46033785297210605`, 0.5520461459825695, 0.9541565122492833], 
             UndirectedEdge[2, 62] -> 
             RGBColor[
              0.28809024405948036`, 0.41514543412740923`, 0.9399002492182742],
              UndirectedEdge[22, 66] -> 
             RGBColor[
              0.9706481076224589, 0.9761022996648738, 0.8661563060783766], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.20210731317620745`, 0.3297579788649362, 0.9348210845431848], 
             UndirectedEdge[73, 88] -> 
             RGBColor[
              0.6510249813606506, 0.717092513649063, 0.8662747478579415], 
             UndirectedEdge[8, 21] -> 
             RGBColor[
              0.6422874800644411, 0.7138766601676445, 0.9655818641473285], 
             UndirectedEdge[31, 75] -> 
             RGBColor[
              0.37476042316283853`, 0.49902037536226795`, 0.9451003806696737],
              UndirectedEdge[4, 30] -> 
             RGBColor[
              0.7017498177316368, 0.7660153165004404, 0.9715408938237355], 
             UndirectedEdge[48, 91] -> 
             RGBColor[
              0.5727700019515907, 0.6611208688545473, 0.9609439568169671], 
             UndirectedEdge[19, 28] -> 
             RGBColor[
              0.6333430350676303, 0.6932666615387844, 0.6777382115060102], 
             UndirectedEdge[28, 66] -> 
             RGBColor[
              0.6349379949264238, 0.6997354801558578, 0.8491543292780519], 
             UndirectedEdge[3, 29] -> 
             RGBColor[
              0.650136209133531, 0.7238223920461937, 0.9677360303795768], 
             UndirectedEdge[22, 82] -> 
             RGBColor[
              0.7946220784192856, 0.8401875036171074, 0.9689841776763144], 
             UndirectedEdge[49, 82] -> 
             RGBColor[
              0.4110933407873547, 0.5135602774245313, 0.9492590009272064], 
             UndirectedEdge[23, 84] -> 
             RGBColor[
              0.3408420054392227, 0.46029663407964955`, 0.9433854300840419], 
             UndirectedEdge[65, 100] -> 
             RGBColor[
              0.7550330854057725, 0.8085019478080251, 0.9766230994610292], 
             UndirectedEdge[53, 85] -> 
             RGBColor[
              0.9672303999053841, 0.9734966740939301, 0.8694022391342454], 
             UndirectedEdge[59, 97] -> 
             RGBColor[
              0.5412570644203794, 0.6182068405381868, 0.9617003069192951], 
             UndirectedEdge[17, 98] -> 
             RGBColor[
              0.7334397330955575, 0.7883059641205716, 0.8896930380280725], 
             UndirectedEdge[61, 68] -> 
             RGBColor[
              0.6615821914754312, 0.7347005973244658, 0.9674863040902784], 
             UndirectedEdge[28, 55] -> 
             RGBColor[
              0.6349379949264238, 0.6997354801558578, 0.8491543292780519], 
             UndirectedEdge[9, 36] -> 
             RGBColor[
              0.6411840878844877, 0.6743892494079506, 0.634460606749484], 
             UndirectedEdge[20, 59] -> 
             RGBColor[
              0.5471418501758336, 0.6243921234841363, 0.9620354367623078], 
             UndirectedEdge[48, 57] -> 
             RGBColor[
              0.7065449362304907, 0.7706775412144424, 0.9713854542717781], 
             UndirectedEdge[1, 46] -> 
             RGBColor[
              0.5276866610754469, 0.6048562615271083, 0.9607892133456312], 
             UndirectedEdge[5, 66] -> 
             RGBColor[
              0.93885600339555, 0.951066996624248, 0.8740402677117749], 
             UndirectedEdge[64, 74] -> 
             RGBColor[
              0.33344529597857986`, 0.4502919261584768, 0.9431672139549263], 
             UndirectedEdge[55, 79] -> 
             RGBColor[
              0.7337055248867795, 0.7877031596755213, 0.8554938476310308], 
             UndirectedEdge[32, 51] -> 
             RGBColor[
              0.9141625306686083, 0.8543342401014268, 0.6293415227810817], 
             UndirectedEdge[64, 73] -> 
             RGBColor[
              0.7397014400437496, 0.7929588961028291, 0.8721850541048333], 
             UndirectedEdge[35, 38] -> 
             RGBColor[
              0.36649768966550084`, 0.48171297197805074`, 0.9453516254238435],
              UndirectedEdge[71, 87] -> 
             RGBColor[
              0.8034433895655608, 0.8465010493271425, 0.9810100296410085], 
             UndirectedEdge[82, 87] -> 
             RGBColor[
              0.7384355944784413, 0.7957007843603869, 0.9745413815954775], 
             UndirectedEdge[5, 77] -> 
             RGBColor[
              0.8120744863771281, 0.8536380691345199, 0.9817656506317896], 
             UndirectedEdge[57, 64] -> 
             RGBColor[
              0.5790477562379636, 0.6687106344541143, 0.9602947865372324], 
             UndirectedEdge[63, 97] -> 
             RGBColor[
              0.5706088768577298, 0.64143977324589, 0.9585571624401915], 
             UndirectedEdge[41, 93] -> 
             RGBColor[
              0.780721370021326, 0.7904521555391548, 0.6429596887706849], 
             UndirectedEdge[9, 61] -> 
             RGBColor[
              0.8518727762862357, 0.8477500869351251, 0.6509942793262493], 
             UndirectedEdge[17, 46] -> 
             RGBColor[
              0.6770243017902577, 0.7455482983565974, 0.9700475871408281], 
             UndirectedEdge[25, 54] -> 
             RGBColor[
              0.5418502683802874, 0.6335889805750963, 0.9592915398139057], 
             UndirectedEdge[59, 77] -> 
             RGBColor[
              0.8117333237777357, 0.8533660353383765, 0.9817331102385001], 
             UndirectedEdge[66, 77] -> 
             RGBColor[
              0.8666058682321716, 0.8941046006220141, 0.8669770524234799], 
             UndirectedEdge[7, 27] -> 
             RGBColor[
              0.7371936723657722, 0.3118937860410518, 0.4294247380664199], 
             UndirectedEdge[61, 92] -> 
             RGBColor[
              0.729630103467193, 0.7887118493135237, 0.9736863679987793], 
             UndirectedEdge[77, 87] -> 
             RGBColor[
              0.7876801066631927, 0.8341866529184252, 0.9794388929175545], 
             UndirectedEdge[28, 79] -> 
             RGBColor[
              0.3752561345626098, 0.4959051117196369, 0.9453965074056173], 
             UndirectedEdge[5, 28] -> 
             RGBColor[
              0.5804066130713803, 0.6592689486683636, 0.9639429274863615], 
             UndirectedEdge[56, 88] -> 
             RGBColor[
              0.5383449017658001, 0.6303215962228269, 0.9591660408192662], 
             UndirectedEdge[25, 26] -> 
             RGBColor[
              0.6039075677707392, 0.6873398942165467, 0.9632457760559501], 
             UndirectedEdge[9, 67] -> 
             RGBColor[
              0.869346037163224, 0.8614003311339296, 0.6527358506735608], 
             UndirectedEdge[32, 44] -> 
             RGBColor[
              0.9657533801908686, 0.89251712933646, 0.5169238209909109], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.3302388618535774, 0.46045803667492197`, 0.9422635061519185], 
             UndirectedEdge[79, 83] -> 
             RGBColor[
              0.7309025310122739, 0.7771593586635748, 0.6793847458260289], 
             UndirectedEdge[60, 93] -> 
             RGBColor[
              0.6136430366300828, 0.6972220872968937, 0.9627273741734803], 
             UndirectedEdge[5, 63] -> 
             RGBColor[
              0.9133352713784645, 0.9335613640483136, 0.9856531810476914], 
             UndirectedEdge[19, 66] -> 
             RGBColor[
              0.9917924253918, 0.9850647094946687, 0.5878355517314237], 
             UndirectedEdge[8, 86] -> 
             RGBColor[
              0.9653338800379607, 0.972445292902827, 0.8888702353982463], 
             UndirectedEdge[4, 37] -> 
             RGBColor[
              0.5822329749063233, 0.6659753340646866, 0.9629639901413825], 
             UndirectedEdge[9, 92] -> 
             RGBColor[
              0.8450984844889193, 0.842457958696537, 0.650319081229249], 
             UndirectedEdge[3, 42] -> 
             RGBColor[
              0.6354133516450337, 0.7110701928819909, 0.9667979029193214], 
             UndirectedEdge[7, 90] -> 
             RGBColor[
              0.38439534228663963`, 0.4932008994290128, 0.9470375135488006], 
             UndirectedEdge[35, 62] -> 
             RGBColor[
              0.28997829856534396`, 0.41712989912264165`, 0.9400077711292568],
              UndirectedEdge[20, 79] -> 
             RGBColor[
              0.3423325342664555, 0.461300320331553, 0.9435215570748532], 
             UndirectedEdge[31, 78] -> 
             RGBColor[
              0.6983632553415924, 0.7594708428602761, 0.9198771807056911], 
             UndirectedEdge[13, 81] -> 
             RGBColor[
              0.9696099899830979, 0.9068749044300725, 0.34828712019801344`], 
             UndirectedEdge[18, 80] -> 
             RGBColor[
              0.523354033045176, 0.6139358517197104, 0.9584329561280636], 
             UndirectedEdge[90, 100] -> 
             RGBColor[
              0.3866564853708796, 0.495036597248134, 0.947215519015232], 
             UndirectedEdge[67, 92] -> 
             RGBColor[
              0.7471033643441813, 0.8023620935123281, 0.9754279393460907], 
             UndirectedEdge[55, 66] -> 
             RGBColor[
              0.9933873852505934, 0.9915335281117422, 0.7592516695034652], 
             UndirectedEdge[89, 91] -> 
             RGBColor[
              0.6543186152037032, 0.7255229466123878, 0.9688873480459297], 
             UndirectedEdge[46, 55] -> 
             RGBColor[
              0.9349168537007435, 0.9479260255829793, 0.8736645480973637], 
             UndirectedEdge[41, 64] -> 
             RGBColor[
              0.7272718507542467, 0.7470594279247368, 0.63875194682194], 
             UndirectedEdge[28, 46] -> 
             RGBColor[
              0.5764674633765738, 0.656127977627095, 0.9635672078719504], 
             UndirectedEdge[35, 53] -> 
             RGBColor[
              0.6055054069484515, 0.6686911636017361, 0.844640235352794], 
             UndirectedEdge[35, 90] -> 
             RGBColor[
              0.20456489077359463`, 0.33234104873920955`, 0.9349610399516957],
              UndirectedEdge[5, 58] -> 
             RGBColor[
              0.7200228922109717, 0.7803994829869101, 0.9734982090086284], 
             UndirectedEdge[76, 85] -> 
             RGBColor[
              0.9418634600431803, 0.956162444206827, 0.9832941770955704], 
             UndirectedEdge[34, 77] -> 
             RGBColor[
              0.5936055475903929, 0.6793006586350645, 0.962215250476939], 
             UndirectedEdge[49, 71] -> 
             RGBColor[
              0.4761011358744742, 0.564360542391287, 0.9557276489727373]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 25 -> 
             RGBColor[
              0.7606351412946137, 0.8129332205113199, 0.9767766604108646], 55 -> 
             RGBColor[
              0.9933873852505934, 0.9915335281117422, 0.7592516695034652], 90 -> 
             RGBColor[
              0.19184766747596257`, 0.3189744407348704, 0.9342368128983415], 
             27 -> RGBColor[0.817319, 0.134127, 0.164218], 15 -> 
             RGBColor[
              0.7268056719913834, 0.7865053819781469, 0.9734048550650835], 98 -> 
             RGBColor[
              0.9892771847614931, 0.9898338545821648, 0.8273683284657511], 38 -> 
             RGBColor[
              0.515713265259775, 0.6177182872125528, 0.9550179838426371], 99 -> 
             RGBColor[
              0.21350600505949952`, 0.3417387267530838, 0.9354702231830848], 
             71 -> RGBColor[
              0.771350917018486, 0.8213044659497208, 0.9778447087904026], 41 -> 
             RGBColor[
              0.9665801095513337, 0.89892900353252, 0.32467046573402747`], 75 -> 
             RGBColor[
              0.33815221642808724`, 0.4673121866705967, 0.9427677381079015], 
             64 -> RGBColor[
              0.48796359195715977`, 0.5951898523169535, 0.9528334279098526], 
             63 -> RGBColor[
              0.9423459212164225, 0.9565222629598733, 0.9824774961752983], 85 -> 
             RGBColor[
              0.9407320999850919, 0.9553186777279367, 0.9852092745679529], 3 -> 
             RGBColor[
              0.8501632775847899, 0.8833611367514445, 0.9855705264373964], 86 -> 
             RGBColor[
              0.9915435051931805, 0.990771036322446, 0.7898095338634231], 94 -> 
             RGBColor[
              0.9485238783673495, 0.8336213616668716, 0.27743930811574197`], 
             61 -> 
             RGBColor[
              0.7364043952645095, 0.7940039775521118, 0.9743615660957797], 84 -> 
             RGBColor[
              0.21236695887645235`, 0.340541516995002, 0.9354053561880281], 
             76 -> RGBColor[
              0.9429948201012687, 0.9570062106857172, 0.9813790796231879], 21 -> 
             RGBColor[
              0.3454507052461414, 0.47363377085208114`, 0.9432327913615877], 
             87 -> RGBColor[
              0.8355358621126358, 0.8716976327045644, 0.9841753504916144], 95 -> 
             RGBColor[
              0.5210068560018374, 0.6220158626505043, 0.9554347146969141], 72 -> 
             RGBColor[
              0.4471799942468646, 0.5617465679217735, 0.9497148917010356], 42 -> 
             RGBColor[
              0.4206634257052774, 0.5387792490125373, 0.9480252794012466], 66 -> 
             RGBColor[
              0.9933873852505934, 0.9915335281117422, 0.7592516695034652], 1 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 24 -> 
             RGBColor[
              0.37533202342905064`, 0.49951546678339614`, 0.9451368025331905],
              54 -> RGBColor[
              0.323065395465961, 0.45424474063887266`, 0.9418064192169469], 4 -> 
             RGBColor[
              0.8220343321974771, 0.8609318792394833, 0.9828875625153485], 7 -> 
             RGBColor[
              0.5769430170973167, 0.6674273581231552, 0.9598382141992597], 
             100 -> RGBColor[
              0.5814653032657966, 0.6710987537613975, 0.9601942251321226], 12 -> 
             RGBColor[
              0.27468655682539633`, 0.4060433657300679, 0.9389543650976372], 
             65 -> RGBColor[
              0.9286008675457486, 0.9459051418546526, 0.9930519737899358], 8 -> 
             RGBColor[
              0.9391242548827409, 0.954119549483208, 0.9879309369330693], 57 -> 
             RGBColor[
              0.6701319205187674, 0.7422314165912749, 0.9677561451646123], 74 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 37 -> 
             RGBColor[
              0.3424316176151695, 0.47101878888988974`, 0.9430404177674165], 
             43 -> RGBColor[
              0.52257495095585, 0.6232889127760445, 0.9555581608758151], 39 -> 
             RGBColor[
              0.3868568167807159, 0.5094976635316522, 0.945871152174584], 58 -> 
             RGBColor[
              0.5557211628814369, 0.6501985008370665, 0.9581675520971723], 11 -> 
             RGBColor[
              0.3916133305993202, 0.5136175167319914, 0.9461742330290854], 51 -> 
             RGBColor[
              0.8898875470197872, 0.9150361909123427, 0.9893594627183804], 48 -> 
             RGBColor[
              0.742957951942214, 0.7991236658376101, 0.9750147633789441], 20 -> 
             RGBColor[
              0.21064140400994538`, 0.3387278494238057, 0.9353070883911102], 
             33 -> RGBColor[
              0.6806483800775323, 0.750446954726635, 0.9688043275715278], 45 -> 
             RGBColor[
              0.21236695887645235`, 0.340541516995002, 0.9354053561880281], 
             23 -> RGBColor[
              0.4693170520019931, 0.5800517511642971, 0.9513655039800555], 22 -> 
             RGBColor[
              0.9479088299943242, 0.9606710712180053, 0.973060942653288], 2 -> 
             RGBColor[
              0.21350600505949952`, 0.3417387267530838, 0.9354702231830848], 
             60 -> RGBColor[
              0.6324234427688471, 0.7124688670479976, 0.9642058365396182], 16 -> 
             RGBColor[
              0.20311888804010014`, 0.3308212081844382, 0.9348786922351926], 
             79 -> RGBColor[
              0.4740236645229656, 0.5838727912393004, 0.9517360257585962], 89 -> 
             RGBColor[
              0.906055178446439, 0.9279278213532908, 0.9909015458368694], 36 -> 
             RGBColor[
              0.3150270184610134, 0.4472823024977628, 0.9412942209422492], 52 -> 
             RGBColor[
              0.7973415900068113, 0.8416085772246312, 0.9804352161772306], 32 -> 
             RGBColor[
              0.9384375143174295, 0.7936322892905109, 0.26932358284378294`], 
             31 -> RGBColor[
              0.4113686298975898, 0.5307285640539392, 0.947433023231446], 68 -> 
             RGBColor[
              0.5867599876863527, 0.6753972170968199, 0.9606110420847769], 73 -> 
             RGBColor[
              0.9914392881303393, 0.9907279398887048, 0.7915366802998138], 82 -> 
             RGBColor[
              0.6413353268442469, 0.7197039360162095, 0.9649074126993408], 35 -> 
             RGBColor[
              0.21728211407122666`, 0.34570765674354864`, 0.93568526700505], 
             88 -> RGBColor[
              0.3106106745909619, 0.4434570874094212, 0.9410128154160691], 50 -> 
             RGBColor[
              0.2789356148505069, 0.41050939512029794`, 0.9391963426662492], 
             19 -> RGBColor[
              0.9901974655330067, 0.9785958908775954, 0.41641943395938213`], 
             17 -> RGBColor[
              0.4776022814296219, 0.5867780736589784, 0.9520177475903938], 96 -> 
             RGBColor[
              0.44437313828295855`, 0.5593154103625207, 0.9495360413210208], 
             14 -> 
             RGBColor[
              0.8010664413338222, 0.8445184593912108, 0.9808064745467924], 5 -> 
             RGBColor[
              0.8843246215405065, 0.9106004651367537, 0.9888288659200845], 34 -> 
             RGBColor[
              0.44738674396703615`, 0.561925644137843, 0.9497280656103834], 
             97 -> RGBColor[
              0.19887183249903692`, 0.32635728353190663`, 0.9346368287050847],
              93 -> RGBColor[
              0.5948626304913185, 0.6819753075457897, 0.9612489118073423], 81 -> 
             RGBColor[
              0.9909488106679877, 0.9811303544421134, 0.41933826792916024`], 
             69 -> RGBColor[
              0.9949518689317752, 0.9916108830264384, 0.6919202705565262], 9 -> 
             RGBColor[
              0.967341157307962, 0.9014961963181384, 0.32762699255671884`], 
             13 -> RGBColor[
              0.9482711692982082, 0.8326194544180315, 0.2772359724668666], 30 -> 
             RGBColor[
              0.5814653032657966, 0.6710987537613975, 0.9601942251321226], 59 -> 
             RGBColor[
              0.8836422963417218, 0.9100563975444669, 0.9887637851335055], 28 -> 
             RGBColor[
              0.276488604602254, 0.40793743219997347`, 0.9390569890526385], 
             80 -> RGBColor[
              0.27468655682539633`, 0.4060433657300679, 0.9389543650976372], 
             47 -> RGBColor[
              0.48796359195715977`, 0.5951898523169535, 0.9528334279098526], 
             62 -> RGBColor[
              0.3626744830594612, 0.4885521415017347, 0.9443302752534637], 77 -> 
             RGBColor[
              0.7398243512137496, 0.796675673132286, 0.9747024353434945], 78 -> 
             RGBColor[
              0.9853578807855949, 0.988213121666613, 0.8923213381799363], 40 -> 
             RGBColor[
              0.9934870981233345, 0.9884778863782295, 0.532489007575325], 67 -> 
             RGBColor[
              0.771350917018486, 0.8213044659497208, 0.9778447087904026], 56 -> 
             RGBColor[
              0.7660791289406382, 0.8171861050362327, 0.9773192662224633], 10 -> 
             RGBColor[
              0.35941770313622634`, 0.48573128242274716`, 0.9441227561166126],
              53 -> RGBColor[
              0.9937286998256762, 0.9916746704599235, 0.7535952037005379], 26 -> 
             RGBColor[
              0.4471799942468646, 0.5617465679217735, 0.9497148917010356], 18 -> 
             RGBColor[
              0.7720215092649558, 0.8218283377093529, 0.9779115471584899], 29 -> 
             RGBColor[
              0.45010914068227204`, 0.5642836473409428, 0.9499015343217573], 
             92 -> RGBColor[
              0.7228558116698767, 0.7834197210749355, 0.9730111699017789], 46 -> 
             RGBColor[
              0.8764463221508937, 0.9043185230542164, 0.9880774266912623], 49 -> 
             RGBColor[
              0.18085135473046252`, 0.30741661883285304`, 0.9336105891550721],
              83 -> RGBColor[
              0.9877813975015822, 0.9704459260878493, 0.4070334658934616], 70 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 44 -> 
             RGBColor[
              0.9930692460643079, 0.991401969382409, 0.7645240591380389], 91 -> 
             RGBColor[
              0.4025820519609673, 0.5231180718714847, 0.9468731502549901], 6 -> 
             RGBColor[
              0.850445108948246, 0.8835858614305557, 0.9855974077644367]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9lHs01Akbx4dhXCZmRjNjDGZ+vxEpY003Oez6fWm7uFSIpJWyrGvrtqF9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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 13}], {
             RGBColor[
             0.5635990846491041, 0.5690067272090158, 0.6053684862334333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 17}], {
             RGBColor[
             0.328264640714811, 0.4460860368294892, 0.9427593737951969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 19}], {
             RGBColor[
             0.5845622327665034, 0.6419949454387976, 0.6749602169796911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 27}], {
             RGBColor[0.6045216666666666, 0.191216, 0.4206456666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 43}], {
             RGBColor[
             0.350750975477925, 0.46434145638802227`, 0.9445295804379076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 46}], {
             RGBColor[
             0.5276866610754469, 0.6048562615271083, 0.9607892133456312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 55}], {
             RGBColor[
             0.5861571926252966, 0.648463764055871, 0.8463763347517326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 3}], {
             RGBColor[
             0.5318346413221446, 0.6125499317522641, 0.9605203748102407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 14}], {
             RGBColor[
             0.5072862231966608, 0.5931285930721473, 0.9581383488649386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 29}], {
             RGBColor[
             0.3318075728708858, 0.4530111870470133, 0.942685878752421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 33}], {
             RGBColor[
             0.44707719256851586`, 0.5460928407398594, 0.9521372753773063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 38}], {
             RGBColor[
             0.3646096351596373, 0.4797285069828183, 0.9452441035128609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 42}], {
             RGBColor[
             0.31708471538238847`, 0.44025898788281054`, 0.9417477512921657]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 44}], {
             RGBColor[
             0.6032876255619037, 0.6665703480677464, 0.8499971411605618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 62}], {
             RGBColor[
             0.28809024405948036`, 0.41514543412740923`, 0.9399002492182742]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 78}], {
             RGBColor[
             0.5994319429225472, 0.6649759242098484, 0.9138957806815106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 16}], {
             RGBColor[
             0.526641082812445, 0.6070911724679413, 0.9602246093362945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 29}], {
             RGBColor[
             0.650136209133531, 0.7238223920461937, 0.9677360303795768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 33}], {
             RGBColor[
             0.7654058288311612, 0.8169040457390397, 0.977187427004462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 38}], {
             RGBColor[
             0.6829382714222825, 0.7505397119819986, 0.9702942551400168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 42}], {
             RGBColor[
             0.6354133516450337, 0.7110701928819909, 0.9667979029193214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 62}], {
             RGBColor[
             0.6064188803221255, 0.6859566391265896, 0.96495040084543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 9}], {
             RGBColor[
             0.8946877447527195, 0.8812140377788109, 0.6552572775360337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 23}], {
             RGBColor[
             0.6456756920997351, 0.7204918152018902, 0.9671265332477019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 24}], {
             RGBColor[
             0.5986831778132639, 0.6802236730114397, 0.9640121825242696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 30}], {
             RGBColor[
             0.7017498177316368, 0.7660153165004404, 0.9715408938237355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 36}], {
             RGBColor[
             0.5685306753292453, 0.6541070908686231, 0.9620908917287989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 37}], {
             RGBColor[
             0.5822329749063233, 0.6659753340646866, 0.9629639901413825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 50}], {
             RGBColor[
             0.5504849735239921, 0.6357206371798907, 0.9610419525907988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 76}], {
             RGBColor[
             0.8825145761493729, 0.9089690449626002, 0.9821333210692682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 86}], {
             RGBColor[
             0.9067889186953288, 0.9258514577809647, 0.8863485481893858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 94}], {
             RGBColor[
             0.8852791052824134, 0.8472766204531774, 0.6301634353155452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 20}], {
             RGBColor[
             0.5474830127752259, 0.6246641572802797, 0.9620679771555973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 28}], {
             RGBColor[
             0.5804066130713803, 0.6592689486683636, 0.9639429274863615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 58}], {
             RGBColor[
             0.7200228922109717, 0.7803994829869101, 0.9734982090086284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.8839834589411142, 0.9103284313406104, 0.988796325526795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 63}], {
             RGBColor[
             0.9133352713784645, 0.9335613640483136, 0.9856531810476914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 66}], {
             RGBColor[
             0.93885600339555, 0.951066996624248, 0.8740402677117749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 69}], {
             RGBColor[
             0.9396382452361409, 0.9511056740815961, 0.8403745682383053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[
             0.8120744863771281, 0.8536380691345199, 0.9817656506317896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 79}], {
             RGBColor[
             0.6791741430317361, 0.747236628188027, 0.9702824458393403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[
             0.9360530095210444, 0.9405231956123015, 0.6979311659067731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 97}], {
             RGBColor[
             0.5415982270197717, 0.6184788743343301, 0.9617328473125846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 7}], {
             RGBColor[
             0.7136940630227813, 0.7755066097768555, 0.9727178109818482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 10}], {
             RGBColor[
             0.6049314060422362, 0.6846585719266515, 0.9648600819405246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 15}], {
             RGBColor[
             0.7886253904698146, 0.8350456217043514, 0.9795011314147601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 25}], {
             RGBColor[
             0.8055401251214298, 0.8482595409709378, 0.9811870340876507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 26}], {
             RGBColor[
             0.6488125515975554, 0.7226662146761647, 0.9676561497327362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 35}], {
             RGBColor[
             0.5338636115097364, 0.6146467590870521, 0.9606413373847433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 40}], {
             RGBColor[
             0.9219661035357902, 0.9360318739043927, 0.7590432076698809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.9220869043869611, 0.9376302659452396, 0.8695963057324874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 65}], {
             RGBColor[
             0.8895229882469973, 0.9147455016426042, 0.9893246907771862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 90}], {
             RGBColor[
             0.5211463882121044, 0.601280151082713, 0.959917110331389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 100}], {
             RGBColor[
             0.7159552061070213, 0.7773423075959767, 0.9728958164482797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 13}], {
             RGBColor[
             0.7626070931977624, 0.7500234062705934, 0.6185370933330632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 25}], {
             RGBColor[
             0.6687890791959652, 0.7401802893172376, 0.9683074373050622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 27}], {
             RGBColor[
             0.7371936723657722, 0.3118937860410518, 0.4294247380664199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 37}], {
             RGBColor[
             0.4596873173562431, 0.5692230735065225, 0.9514393159833381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 40}], {
             RGBColor[
             0.7852150576103256, 0.8279526222506923, 0.7461636108872924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 53}], {
             RGBColor[
             0.7853358584614964, 0.8295510142915394, 0.8567167089498988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.45000420628163884`, 0.560836049381014, 0.9508223167081034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 65}], {
             RGBColor[
             0.7527719423215327, 0.8066662499889039, 0.9764450939945978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 81}], {
             RGBColor[
             0.7839459138826521, 0.8242788562826343, 0.68958824106421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.3946549879868845, 0.5039844375590786, 0.9476217851936439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 85}], {
             RGBColor[
             0.7588375585412043, 0.811373017925546, 0.9725237443836063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 90}], {
             RGBColor[
             0.38439534228663963`, 0.4932008994290128, 0.9470375135488006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 100}], {
             RGBColor[
             0.5792041601815566, 0.6692630559422763, 0.9600162196656912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 17}], {
             RGBColor[
             0.7083632681561813, 0.7704488115710932, 0.9699743422617315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.6422874800644411, 0.7138766601676445, 0.9655818641473285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 22}], {
             RGBColor[
             0.9435165424385326, 0.9573953103506067, 0.9804959397931787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 30}], {
             RGBColor[
             0.7602947790742687, 0.8126091516223027, 0.974062581032596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 49}], {
             RGBColor[
             0.5599878048066017, 0.6307680841580305, 0.9607707630440707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 69}], {
             RGBColor[
             0.967038061907258, 0.9728652162548233, 0.8399256037447977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 77}], {
             RGBColor[
             0.8394743030482452, 0.8753976113077471, 0.9813166861382819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.7902297908634939, 0.8369117427497088, 0.976419174816205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 86}], {
             RGBColor[
             0.9653338800379607, 0.972445292902827, 0.8888702353982463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 87}], {
             RGBColor[
             0.8873300584976883, 0.9129085910938861, 0.9860531437123419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 95}], {
             RGBColor[
             0.7300655554422891, 0.7880677060668562, 0.9716828258149917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 99}], {
             RGBColor[
             0.5763151299711202, 0.6479291381181459, 0.9617005800580771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.6794772439536411, 0.707556856525065, 0.6369006127929022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 21}], {
             RGBColor[
             0.6563959312770518, 0.6875649835851098, 0.6354298919591532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 30}], {
             RGBColor[
             0.7744032302868793, 0.786297475039768, 0.6439106088444206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 36}], {
             RGBColor[
             0.6411840878844877, 0.6743892494079506, 0.634460606749484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 61}], {
             RGBColor[
             0.8518727762862357, 0.8477500869351251, 0.6509942793262493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 67}], {
             RGBColor[
             0.869346037163224, 0.8614003311339296, 0.6527358506735608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 68}], {
             RGBColor[
             0.7770505724971574, 0.7884467067074792, 0.6441190173207478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 72}], {
             RGBColor[
             0.7072605757774133, 0.731621382119956, 0.6386709421288772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 82}], {
             RGBColor[
             0.8043382420761045, 0.810600066167174, 0.6462672026280298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 86}], {
             RGBColor[
             0.9794423312505712, 0.9461336163202922, 0.558718263210071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 92}], {
             RGBColor[
             0.8450984844889193, 0.842457958696537, 0.650319081229249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 94}], {
             RGBColor[
             0.9579325178376558, 0.867558778992505, 0.3025331503362304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.5431116875638049, 0.636118332200447, 0.9587638055908481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 26}], {
             RGBColor[
             0.4032988486915455, 0.5237389251722603, 0.9469188239088241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 35}], {
             RGBColor[
             0.2883499086037265, 0.41571946958314787`, 0.9399040115608313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 40}], {
             RGBColor[
             0.6764524006297804, 0.7371045844004884, 0.7383058818459688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 53}], {
             RGBColor[
             0.6765732014809513, 0.7387029764413353, 0.8488589799085753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 65}], {
             RGBColor[
             0.6440092853409874, 0.7158182121386999, 0.9685873649532741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 90}], {
             RGBColor[
             0.27563268530609447`, 0.4023528615788088, 0.939179784507477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 100}], {
             RGBColor[
             0.47044150320101147`, 0.5784150180920723, 0.9521584906243676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 36}], {
             RGBColor[
             0.3533201745301668, 0.4804499096148771, 0.9437342269856673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 52}], {
             RGBColor[
             0.5944774603030657, 0.6776130469783113, 0.9633047246031581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 61}], {
             RGBColor[
             0.5640088629319149, 0.6538107471420516, 0.9602678995624325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 67}], {
             RGBColor[
             0.5814821238089031, 0.6674609913408561, 0.962009470909744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 68}], {
             RGBColor[
             0.48918665914283643`, 0.5945073669144056, 0.9533926375569312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 72}], {
             RGBColor[
             0.41939666242309237`, 0.5376820423268824, 0.9479445623650605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 92}], {
             RGBColor[
             0.5572345711345984, 0.6485186189034635, 0.9595927014654322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 94}], {
             RGBColor[
             0.6700686044833348, 0.6736194391994315, 0.6118067705724137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 41}], {
             RGBColor[
             0.620633333188365, 0.6524861846312939, 0.6318124154158323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 52}], {
             RGBColor[
             0.5360140734161039, 0.6238259714773495, 0.9596947906374339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 60}], {
             RGBColor[
             0.4535549997971217, 0.5592561163890327, 0.9515801008186278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.38132507439127805`, 0.5006166090235107, 0.9458938965037449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 74}], {
             RGBColor[
             0.22680677841269817`, 0.35571868286503394`, 0.9362276825488186]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 88}], {
             RGBColor[
             0.2926486157081791, 0.42475022656974454`, 0.9399835902568532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 96}], {
             RGBColor[
             0.35952984755417744`, 0.4826793880462943, 0.9442452032093289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 27}], {
             RGBColor[
             0.8609697230994028, 0.36695781813934386`, 0.20189065748895554`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 43}], {
             RGBColor[
             0.7354230601270291, 0.727954183597038, 0.6163970666713409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 54}], {
             RGBColor[
             0.6356682823820846, 0.6434320975284521, 0.6095211958419067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 81}], {
             RGBColor[
             0.9696099899830979, 0.9068749044300725, 0.34828712019801344`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 84}], {
             RGBColor[
             0.5803190640873302, 0.5865804857065168, 0.6063206643274474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 85}], {
             RGBColor[
             0.94450163464165, 0.8939690660729841, 0.6312226235174098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 15}], {
             RGBColor[
             0.7639360566626028, 0.8155119206846788, 0.977105664805938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 24}], {
             RGBColor[
             0.5881992323814365, 0.6720169630873035, 0.9629716385399915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 35}], {
             RGBColor[
             0.5091742777025244, 0.5951130580673798, 0.9582458707759212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 38}], {
             RGBColor[
             0.6583898532967987, 0.7311183733018818, 0.9679122291947148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 42}], {
             RGBColor[
             0.6108649335195498, 0.691648854201874, 0.9644158769740194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 53}], {
             RGBColor[
             0.8973975705797492, 0.9180965649255672, 0.8672008391236652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 62}], {
             RGBColor[
             0.5818704621966417, 0.6665353004464728, 0.962568374900128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 76}], {
             RGBColor[
             0.8720306307175454, 0.900762335038464, 0.9810927770849902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 35}], {
             RGBColor[
             0.472043893031305, 0.5661065193608478, 0.9545450610350668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 38}], {
             RGBColor[
             0.6212594686255792, 0.7021118345953499, 0.9642114194538602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 40}], {
             RGBColor[
             0.860146385057359, 0.8874916341781882, 0.7529469313202042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 53}], {
             RGBColor[
             0.8602671859085298, 0.8890900262190352, 0.8635000293828107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.5447400775254223, 0.6375287617399408, 0.9588675651592735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 90}], {
             RGBColor[
             0.459326669733673, 0.5527399113565087, 0.9538208339817125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 100}], {
             RGBColor[
             0.65413548762859, 0.7288020678697722, 0.966799540098603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 29}], {
             RGBColor[
             0.3266140143611861, 0.44755242776269055`, 0.9423901132784749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.4418836340588162, 0.5406340814555366, 0.9518415099033601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 62}], {
             RGBColor[
             0.28289668554978065`, 0.40968667484308646`, 0.9396044837443281]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 19}], {
             RGBColor[
             0.7338998734813142, 0.7826869822682869, 0.684218590774888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 22}], {
             RGBColor[
             0.7127555557119731, 0.7737245724384918, 0.9625393451218409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 28}], {
             RGBColor[
             0.37704544301593795`, 0.4973577529294759, 0.9455373683215161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 46}], {
             RGBColor[
             0.6770243017902577, 0.7455482983565974, 0.9700475871408281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 55}], {
             RGBColor[
             0.7354948333401077, 0.7891558008853603, 0.8556347085469296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 59}], {
             RGBColor[
             0.6806222888856719, 0.7484172356017227, 0.9703907663619497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 66}], {
             RGBColor[
             0.7354948333401077, 0.7891558008853603, 0.8556347085469296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 69}], {
             RGBColor[
             0.7362770751806986, 0.7891944783427084, 0.8219690090734599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 77}], {
             RGBColor[
             0.6087133163216858, 0.6917268733956322, 0.9633600914669442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 79}], {
             RGBColor[
             0.47581297297629377`, 0.5853254324491394, 0.951876886674495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 95}], {
             RGBColor[
             0.49930456871572965`, 0.6043969681547414, 0.953726231143654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 98}], {
             RGBColor[
             0.7334397330955575, 0.7883059641205716, 0.8896930380280725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.3455541432445607, 0.4642584002060311, 0.9437439853867393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 80}], {
             RGBColor[
             0.523354033045176, 0.6139358517197104, 0.9584329561280636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 28}], {
             RGBColor[
             0.6333430350676303, 0.6932666615387844, 0.6777382115060102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 43}], {
             RGBColor[
             0.7563862082444284, 0.8009424018268199, 0.6859887974175987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 46}], {
             RGBColor[
             0.9333218938419502, 0.941457206965906, 0.7022484303253222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 55}], {
             RGBColor[
             0.9917924253918, 0.9850647094946687, 0.5878355517314237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 59}], {
             RGBColor[
             0.9369198809373642, 0.9443261442110311, 0.7025916095464437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 66}], {
             RGBColor[
             0.9917924253918, 0.9850647094946687, 0.5878355517314237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 79}], {
             RGBColor[
             0.7321105650279862, 0.7812343410584479, 0.6840777298589891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 95}], {
             RGBColor[
             0.755602160767422, 0.8003058767640499, 0.685927074328148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 98}], {
             RGBColor[
             0.9897373251472499, 0.9842148727298801, 0.6218938812125666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 99}], {
             RGBColor[
             0.6018517352962531, 0.6601673088153396, 0.6759448285712335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.24356500430609968`, 0.37333264081188955`, 0.9371820387218743]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 58}], {
             RGBColor[
             0.38318128344569113`, 0.49446317513043614`, 0.9467373202441413]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 59}], {
             RGBColor[
             0.5471418501758336, 0.6243921234841363, 0.9620354367623078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 63}], {
             RGBColor[
             0.5764936626131839, 0.6476250561918395, 0.9588922922832043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 66}], {
             RGBColor[
             0.6020143946302694, 0.6651306887677739, 0.8472793789472877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 79}], {
             RGBColor[
             0.3423325342664555, 0.461300320331553, 0.9435215570748532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 83}], {
             RGBColor[
             0.5992114007557638, 0.6545868877558274, 0.6711702771422859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 97}], {
             RGBColor[
             0.20475661825449115`, 0.3325425664778562, 0.9349719585480974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 22}], {
             RGBColor[
             0.6466797676202328, 0.7171524210350433, 0.9581468670074378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 30}], {
             RGBColor[
             0.463458004255969, 0.5723662623067394, 0.9517135082468551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 34}], {
             RGBColor[
             0.3964187246065888, 0.517779707494962, 0.9464804284859856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.3302388618535774, 0.46045803667492197`, 0.9422635061519185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 49}], {
             RGBColor[
             0.263151029988302, 0.39052519484246706`, 0.9384216902583299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 68}], {
             RGBColor[
             0.4661053464662471, 0.5745154939744506, 0.9519219167231823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 72}], {
             RGBColor[
             0.396315349746503, 0.5176901693869274, 0.9464738415313116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 82}], {
             RGBColor[
             0.49339301604519414`, 0.5966688534341453, 0.9540701020304643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[
             0.5904932836793886, 0.6726657017783227, 0.963704070926601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 92}], {
             RGBColor[
             0.5341532584580091, 0.6285267459635083, 0.9581219806316833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 30}], {
             RGBColor[
             0.7646870666300605, 0.8158849124897014, 0.9666275838927053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 34}], {
             RGBColor[
             0.6976477869806802, 0.7612983576779242, 0.9613945041318357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 49}], {
             RGBColor[
             0.5643800923623934, 0.6340438450254292, 0.9533357659041801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 66}], {
             RGBColor[
             0.9706481076224589, 0.9761022996648738, 0.8661563060783766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 69}], {
             RGBColor[
             0.9714303494630497, 0.9761409771222218, 0.8324906066049071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 77}], {
             RGBColor[
             0.8438665906040369, 0.8786733721751456, 0.9738816889983912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 82}], {
             RGBColor[
             0.7946220784192856, 0.8401875036171074, 0.9689841776763144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 87}], {
             RGBColor[
             0.89172234605348, 0.9161843519612849, 0.9786181465724513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 95}], {
             RGBColor[
             0.7344578429980808, 0.7913434669342548, 0.9642478286751011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 99}], {
             RGBColor[
             0.5807074175269119, 0.6512048989855446, 0.9542655829181864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 24}], {
             RGBColor[
             0.42232453771552186`, 0.5397836089738466, 0.948251153256623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 27}], {
             RGBColor[
             0.7013183506673311, 0.2827685837214324, 0.42660050132668514`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 30}], {
             RGBColor[
             0.5253911776338949, 0.6255752524628473, 0.9557798645560891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 37}], {
             RGBColor[
             0.40587433480858126`, 0.5255352700270934, 0.947202960873736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 50}], {
             RGBColor[
             0.37412633342625, 0.4952805731422975, 0.9452809233231523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 76}], {
             RGBColor[
             0.7061559360516309, 0.7685289809250071, 0.9663722918016218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[
             0.7301329313349905, 0.7805910528032052, 0.6853518859546078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 84}], {
             RGBColor[
             0.3408420054392227, 0.46029663407964955`, 0.9433854300840419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 85}], {
             RGBColor[
             0.7050245759935425, 0.7676852144461168, 0.9682873892740043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 86}], {
             RGBColor[
             0.7304302785975867, 0.7854113937433715, 0.8705875189217394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 42}], {
             RGBColor[
             0.39799772456716404`, 0.5191473578979667, 0.9465810409672186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 50}], {
             RGBColor[
             0.3271338191397788, 0.45501243095184707`, 0.9421665725997199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 76}], {
             RGBColor[
             0.6591634217651596, 0.7282608387345567, 0.9632579410781892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 26}], {
             RGBColor[
             0.6039075677707392, 0.6873398942165467, 0.9632457760559501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 40}], {
             RGBColor[
             0.8770611197089742, 0.9007055534447748, 0.7546328339930948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 54}], {
             RGBColor[
             0.5418502683802874, 0.6335889805750963, 0.9592915398139057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 65}], {
             RGBColor[
             0.8446180044201812, 0.8794191811829862, 0.9849143171004002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 100}], {
             RGBColor[
             0.6710502222802052, 0.7420159871363587, 0.9684854427714936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 40}], {
             RGBColor[
             0.7203335461850995, 0.7751122271500015, 0.7411019496381803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 53}], {
             RGBColor[
             0.7204543470362704, 0.7767106191908485, 0.8516550477007867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 65}], {
             RGBColor[
             0.6878904308963065, 0.7538258548882131, 0.9713834327454858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 90}], {
             RGBColor[
             0.3195138308614136, 0.44036050432832197`, 0.9419758522996886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[
             0.5143226487563306, 0.6164226608415855, 0.9549545584165791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 37}], {
             RGBColor[
             0.6590232058717231, 0.24642426296329656`, 0.42382547258913883`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 43}], {
             RGBColor[
             0.71907098365195, 0.2971809709253481, 0.42799805362527166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 54}], {
             RGBColor[
             0.6525677984886538, 0.24083291354629088`, 0.42341413973898223`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 81}], {
             RGBColor[
             0.8751956035559959, 0.41646145148070446`, 0.24925808930972007`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 84}], {
             RGBColor[
             0.6156683196254842, 0.202931838998334, 0.42128045206267606`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 85}], {
             RGBColor[
             0.8584566999950306, 0.40785755924264555`, 0.4378817581893176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 46}], {
             RGBColor[
             0.5764674633765738, 0.656127977627095, 0.9635672078719504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 55}], {
             RGBColor[
             0.6349379949264238, 0.6997354801558578, 0.8491543292780519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 59}], {
             RGBColor[
             0.5800654504719879, 0.6589969148722201, 0.963910387093072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 66}], {
             RGBColor[
             0.6349379949264238, 0.6997354801558578, 0.8491543292780519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 79}], {
             RGBColor[
             0.3752561345626098, 0.4959051117196369, 0.9453965074056173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 83}], {
             RGBColor[
             0.6321350010519181, 0.6891916791439114, 0.6730452274730501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 98}], {
             RGBColor[
             0.6328828946818735, 0.6988856433910691, 0.8832126587591949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 99}], {
             RGBColor[
             0.24499730483087676`, 0.37483807947652864`, 0.9372636061178616]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 33}], {
             RGBColor[
             0.5653787603799021, 0.657365301033789, 0.9593529309466425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 38}], {
             RGBColor[
             0.4829112029710235, 0.5910009672767478, 0.9524597590821973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 42}], {
             RGBColor[
             0.4353862831937747, 0.55153144817674, 0.9489634068615019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.4063918118708666, 0.5264178944213388, 0.9471159047876105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 36}], {
             RGBColor[
             0.44824616086340496`, 0.5591905281295801, 0.9507442230371859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 50}], {
             RGBColor[
             0.43020045905815174`, 0.5408040744408478, 0.9496952838991859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 82}], {
             RGBColor[
             0.6114003150550218, 0.6954013448888035, 0.9625508189157317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 86}], {
             RGBColor[
             0.7865044042294885, 0.8309348950419218, 0.8750018794977729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 92}], {
             RGBColor[
             0.6521605574678366, 0.7272592374181666, 0.9666026975169508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 94}], {
             RGBColor[
             0.7649945908165731, 0.7523600577141345, 0.6188167666239323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 32}], {
             RGBColor[
             0.6749030721075097, 0.6621804266722251, 0.6083783030376144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 39}], {
             RGBColor[
             0.3991127233391528, 0.5201131137927957, 0.9466520877030149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 44}], {
             RGBColor[
             0.7022189379809489, 0.7610652667181741, 0.8559785411847425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 45}], {
             RGBColor[
             0.31186779438702106`, 0.4356350405244706, 0.941419189709737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 51}], {
             RGBColor[
             0.6506280884586886, 0.722882377483141, 0.9683962429749131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 70}], {
             RGBColor[
             0.29514781494879494`, 0.41806128202696957`, 0.940467011615723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 75}], {
             RGBColor[
             0.37476042316283853`, 0.49902037536226795`, 0.9451003806696737]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 78}], {
             RGBColor[
             0.6983632553415924, 0.7594708428602761, 0.9198771807056911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 80}], {
             RGBColor[
             0.3430275933614931, 0.46838596489200357`, 0.9431936941645416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 39}], {
             RGBColor[
             0.6626471655490727, 0.6515649764110816, 0.6075973675091835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 44}], {
             RGBColor[
             0.9657533801908686, 0.89251712933646, 0.5169238209909109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 45}], {
             RGBColor[
             0.5754022365969409, 0.5670869031427564, 0.6023644695159056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 51}], {
             RGBColor[
             0.9141625306686083, 0.8543342401014268, 0.6293415227810817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 80}], {
             RGBColor[
             0.606562035571413, 0.5998378275102894, 0.6041389739707101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 42}], {
             RGBColor[
             0.5506559028914049, 0.6446131018695862, 0.9584148034863872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 62}], {
             RGBColor[
             0.5216614315684968, 0.6194995481141848, 0.9565673014124958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 49}], {
             RGBColor[
             0.31411904934874935`, 0.434671131485348, 0.9416693273827277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 60}], {
             RGBColor[
             0.5399050933679417, 0.6371972555929203, 0.9569669510750007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 69}], {
             RGBColor[
             0.7211693064494057, 0.7767682635821407, 0.8208241680834547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 71}], {
             RGBColor[
             0.6093688304927611, 0.6916150550437818, 0.963786387200393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 77}], {
             RGBColor[
             0.5936055475903929, 0.6793006586350645, 0.962215250476939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 82}], {
             RGBColor[
             0.5443610354056415, 0.6408147900770262, 0.9573177391548621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 87}], {
             RGBColor[
             0.641461303039836, 0.7168116384212037, 0.9669517080509988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 38}], {
             RGBColor[
             0.36649768966550084`, 0.48171297197805074`, 0.9453516254238435]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 53}], {
             RGBColor[
             0.6055054069484515, 0.6686911636017361, 0.844640235352794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 62}], {
             RGBColor[
             0.28997829856534396`, 0.41712989912264165`, 0.9400077711292568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 90}], {
             RGBColor[
             0.20456489077359463`, 0.33234104873920955`, 0.9349610399516957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 61}], {
             RGBColor[
             0.5257157068627615, 0.6206431400249373, 0.9578278935190145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 67}], {
             RGBColor[
             0.5431889677397497, 0.6342933842237418, 0.959569464866326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 68}], {
             RGBColor[
             0.45089350307368303`, 0.5613397597972913, 0.9509526315135131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 72}], {
             RGBColor[
             0.38110350635393897`, 0.5045144352097681, 0.9455045563216424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 82}], {
             RGBColor[
             0.47818117265263016`, 0.5834931192569861, 0.9531008168207951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 86}], {
             RGBColor[
             0.653285261827097, 0.7190266694101044, 0.8655518774028361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 92}], {
             RGBColor[
             0.518941415065445, 0.6153510117863492, 0.9571526954220141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 94}], {
             RGBColor[
             0.6317754484141815, 0.6404518320823172, 0.6093667645289956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 50}], {
             RGBColor[
             0.3106836162328382, 0.4407640920050938, 0.9411183802168328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 76}], {
             RGBColor[
             0.6427132188582191, 0.7140124997878035, 0.9622097486953023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 81}], {
             RGBColor[
             0.6666902141415786, 0.7260745716660015, 0.6811893428482884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 84}], {
             RGBColor[
             0.27739928824581095`, 0.40578015294244585`, 0.9392228869777224]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 85}], {
             RGBColor[
             0.6415818588001307, 0.7131687333089132, 0.9641248461676848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 42}], {
             RGBColor[
             0.4681883454825262, 0.578248768112545, 0.9515216316219419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 62}], {
             RGBColor[
             0.4391938741596181, 0.5531352143571437, 0.9496741295480504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 44}], {
             RGBColor[
             0.6899630314225118, 0.7504498164570306, 0.8551976056563114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 45}], {
             RGBColor[
             0.2996118878285841, 0.4250195902633271, 0.9406382541813061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 80}], {
             RGBColor[
             0.33077168680305613`, 0.45777051463086005`, 0.9424127586361106]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 53}], {
             RGBColor[
             0.9936078989745054, 0.9900762784190765, 0.6430421056379314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 54}], {
             RGBColor[
             0.6582762467946477, 0.721361313508551, 0.7371477133961359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.9610439828345415, 0.9671915141164411, 0.7627704906826305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 90}], {
             RGBColor[
             0.5926673827996485, 0.65372616355655, 0.7333629102368333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 100}], {
             RGBColor[
             0.7874762006945655, 0.8297883200698135, 0.7463416163537238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 48}], {
             RGBColor[
             0.8547690307467739, 0.849026334685065, 0.6498426145564857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 56}], {
             RGBColor[
             0.866329619245986, 0.8580575542843764, 0.6509948659782454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 60}], {
             RGBColor[
             0.7995017761600904, 0.8056989352902588, 0.6444381511368229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 64}], {
             RGBColor[
             0.7272718507542467, 0.7470594279247368, 0.63875194682194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 73}], {
             RGBColor[
             0.9790096988408366, 0.9448284717106123, 0.5581035730169206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 74}], {
             RGBColor[
             0.5727535547756668, 0.60216150176626, 0.6290857328670137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.6385953920711478, 0.6711930454709706, 0.6328416405750483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 91}], {
             RGBColor[
             0.6845810807561505, 0.7110235377020024, 0.6357718079945087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 93}], {
             RGBColor[
             0.780721370021326, 0.7904521555391548, 0.6429596887706849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 44}], {
             RGBColor[
             0.7068663358847926, 0.7650906091974732, 0.8562746692696428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 62}], {
             RGBColor[
             0.3916689543823693, 0.513665695257136, 0.9461777773273552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 78}], {
             RGBColor[
             0.7030106532454361, 0.7634961853395752, 0.9201733087905914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 46}], {
             RGBColor[
             0.6995106365533719, 0.7638037179151305, 0.9718177937835387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 54}], {
             RGBColor[
             0.42282017321090554`, 0.5387668267074586, 0.9486822900463809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 45}], {
             RGBColor[
             0.6027181024703802, 0.6659717431887056, 0.8499647076630334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 78}], {
             RGBColor[
             0.9892135634249515, 0.989807545524511, 0.8284226986589875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 52}], {
             RGBColor[
             0.5048542744416318, 0.5910750471098166, 0.9579202861826294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 78}], {
             RGBColor[
             0.5988624198310237, 0.6643773193308076, 0.9138633471839822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 55}], {
             RGBColor[
             0.9349168537007435, 0.9479260255829793, 0.8736645480973637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 59}], {
             RGBColor[
             0.8800443092463077, 0.9071874602993417, 0.9884206059123839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 79}], {
             RGBColor[
             0.6752349933369297, 0.7440956571467584, 0.9699067262249292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 95}], {
             RGBColor[
             0.6987265890763655, 0.7631671928523605, 0.9717560706940882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 98}], {
             RGBColor[
             0.9328617534561934, 0.9470761888181907, 0.9077228775785067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 99}], {
             RGBColor[
             0.5449761636051966, 0.6230286249036501, 0.9617738249371736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 51}], {
             RGBColor[
             0.6889255694884735, 0.7551130216146481, 0.9710964453141164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 57}], {
             RGBColor[
             0.5790477562379636, 0.6687106344541143, 0.9602947865372324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 70}], {
             RGBColor[
             0.33344529597857986`, 0.4502919261584768, 0.9431672139549263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 74}], {
             RGBColor[
             0.33344529597857986`, 0.4502919261584768, 0.9431672139549263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 75}], {
             RGBColor[
             0.4130579041926235, 0.5312510194937752, 0.947800583008877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 88}], {
             RGBColor[
             0.39928713327406085`, 0.5193234698631873, 0.9469231216629608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.46616836512005916`, 0.5772526313397371, 0.9511847346154367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 56}], {
             RGBColor[
             0.7545185404414261, 0.8081548854369214, 0.9761670148007038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 57}], {
             RGBColor[
             0.7065449362304907, 0.7706775412144424, 0.9713854542717781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 64}], {
             RGBColor[
             0.615460771949687, 0.6971567590772818, 0.9639240956443984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 73}], {
             RGBColor[
             0.8671986200362767, 0.8949258028631575, 0.883275721839379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 74}], {
             RGBColor[
             0.46094247597110705`, 0.5522588329188051, 0.954257881689472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 88}], {
             RGBColor[
             0.5267843132665879, 0.6212903766235156, 0.9580137893975066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 91}], {
             RGBColor[
             0.5727700019515907, 0.6611208688545473, 0.9609439568169671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 93}], {
             RGBColor[
             0.6689102912167663, 0.7405494866917, 0.9681318375931431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 96}], {
             RGBColor[
             0.5936655451125863, 0.6792195381000654, 0.9622754023499824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 69}], {
             RGBColor[
             0.5879016118311189, 0.6495137509296458, 0.8127654298557991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 71}], {
             RGBColor[
             0.4761011358744742, 0.564360542391287, 0.9557276489727373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 77}], {
             RGBColor[
             0.46033785297210605`, 0.5520461459825695, 0.9541565122492833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 82}], {
             RGBColor[
             0.4110933407873547, 0.5135602774245313, 0.9492590009272064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.5081936084215491, 0.5895571257687087, 0.9588929698233433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 76}], {
             RGBColor[
             0.6109652174758877, 0.6837578029030076, 0.9602877111447186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 81}], {
             RGBColor[
             0.6349422127592472, 0.6958198747812057, 0.6792673052977047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 84}], {
             RGBColor[
             0.24565128686347962`, 0.37552545605765, 0.9373008494271386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 85}], {
             RGBColor[
             0.6098338574177994, 0.6829140364241173, 0.9622028086171011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 86}], {
             RGBColor[
             0.6352395600218437, 0.700640215721372, 0.8645029382648362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 57}], {
             RGBColor[
             0.7800097337692773, 0.8286338037518088, 0.9785578039414964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 70}], {
             RGBColor[
             0.5344072735098936, 0.6102150954561714, 0.9614302313591903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 75}], {
             RGBColor[
             0.6140198817239373, 0.6911741887914697, 0.9660636004131409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 67}], {
             RGBColor[
             0.7843462535126486, 0.8314565215871761, 0.9791399624838166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 68}], {
             RGBColor[
             0.692050788846582, 0.7585028971607255, 0.9705231291310037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 72}], {
             RGBColor[
             0.6222607921268379, 0.7016775725732023, 0.9650750539391331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 78}], {
             RGBColor[
             0.8913497353962031, 0.9149108494456222, 0.9363782771785835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 65}], {
             RGBColor[
             0.9611647836857125, 0.968789906157288, 0.8733235887452369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 84}], {
             RGBColor[
             0.6030478293510643, 0.6661080937274628, 0.844500279944283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 85}], {
             RGBColor[
             0.9672303999053841, 0.9734966740939301, 0.8694022391342454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 90}], {
             RGBColor[
             0.5927881836508194, 0.655324555597397, 0.8439160082994397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 100}], {
             RGBColor[
             0.7875970015457364, 0.8313867121106605, 0.8568947144163302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 84}], {
             RGBColor[
             0.26771617717120666`, 0.39739312881693734`, 0.9386058877024874]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 100}], {
             RGBColor[
             0.4522653493658788, 0.562671747200135, 0.9510003221745347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 59}], {
             RGBColor[
             0.9385148407961577, 0.9507949628281045, 0.8740077273184854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 66}], {
             RGBColor[
             0.9933873852505934, 0.9915335281117422, 0.7592516695034652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 79}], {
             RGBColor[
             0.7337055248867795, 0.7877031596755213, 0.8554938476310308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 98}], {
             RGBColor[
             0.9913322850060433, 0.9906836913469534, 0.7933099989846082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 99}], {
             RGBColor[
             0.6034466951550465, 0.6666361274324131, 0.847360946343275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 64}], {
             RGBColor[
             0.627021360448899, 0.7061879786765931, 0.965076347066158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 73}], {
             RGBColor[
             0.8787592085354887, 0.9039570224624687, 0.8844279732611386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 74}], {
             RGBColor[
             0.4725030644703191, 0.5612900525181164, 0.9554101331112317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 88}], {
             RGBColor[
             0.5383449017658001, 0.6303215962228269, 0.9591660408192662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 89}], {
             RGBColor[
             0.8360671536935387, 0.8725569631947617, 0.9841104060296664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 91}], {
             RGBColor[
             0.5843305904508027, 0.6701520884538588, 0.9620962082387268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 93}], {
             RGBColor[
             0.6804708797159784, 0.7495807062910111, 0.9692840890149028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 64}], {
             RGBColor[
             0.5790477562379636, 0.6687106344541143, 0.9602947865372324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 70}], {
             RGBColor[
             0.42452946025938365`, 0.5238127082956374, 0.9506285725823062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 74}], {
             RGBColor[
             0.42452946025938365`, 0.5238127082956374, 0.9506285725823062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 75}], {
             RGBColor[
             0.5041420684734272, 0.6047718016309358, 0.9552619416362569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 88}], {
             RGBColor[
             0.49037129755486464`, 0.5928442520003481, 0.9543844802903407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 96}], {
             RGBColor[
             0.557252529400863, 0.6507734134768979, 0.9586460932428165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 63}], {
             RGBColor[
             0.7490335420489297, 0.8033603818984699, 0.9703225241362353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 83}], {
             RGBColor[
             0.7717512801915096, 0.8103222134624579, 0.682600508995317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 97}], {
             RGBColor[
             0.37729649769023693`, 0.4882778921844866, 0.9464021904011285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 66}], {
             RGBColor[
             0.9385148407961577, 0.9507949628281045, 0.8740077273184854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 69}], {
             RGBColor[
             0.9392970826367485, 0.9508336402854527, 0.8403420278450158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 77}], {
             RGBColor[
             0.8117333237777357, 0.8533660353383765, 0.9817331102385001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 79}], {
             RGBColor[
             0.6788329804323436, 0.7469645943918837, 0.9702499054460508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 83}], {
             RGBColor[
             0.935711846921652, 0.9402511618161581, 0.6978986255134836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 95}], {
             RGBColor[
             0.7023245761717796, 0.7660361300974856, 0.9720992499152098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 97}], {
             RGBColor[
             0.5412570644203794, 0.6182068405381868, 0.9617003069192951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 98}], {
             RGBColor[
             0.9364597405516074, 0.9499451260633158, 0.9080660567996284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 99}], {
             RGBColor[
             0.5485741507006107, 0.6258975621487753, 0.9621170041582952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 64}], {
             RGBColor[
             0.5601935173630035, 0.6538293596824756, 0.9585196322247354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 71}], {
             RGBColor[
             0.7018871798936666, 0.7668866664988592, 0.9710252726650104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 74}], {
             RGBColor[
             0.4056752213844236, 0.5089314335239988, 0.9488534182698092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 89}], {
             RGBColor[
             0.7692393106076431, 0.8201983442006442, 0.9775536911882439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 93}], {
             RGBColor[
             0.6136430366300828, 0.6972220872968937, 0.9627273741734803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 67}], {
             RGBColor[
             0.7538776561414977, 0.8076542217509164, 0.9761031374430912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 68}], {
             RGBColor[
             0.6615821914754312, 0.7347005973244658, 0.9674863040902784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 72}], {
             RGBColor[
             0.591792194755687, 0.6778752727369426, 0.9620382288984077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 86}], {
             RGBColor[
             0.863973950228845, 0.8923875069372789, 0.8820855499796014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 92}], {
             RGBColor[
             0.729630103467193, 0.7887118493135237, 0.9736863679987793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 94}], {
             RGBColor[
             0.8424641368159296, 0.8138126696094917, 0.6259004371057608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 83}], {
             RGBColor[
             0.9650636593590023, 0.9634840945238613, 0.69475548103438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 97}], {
             RGBColor[
             0.5706088768577298, 0.64143977324589, 0.9585571624401915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 73}], {
             RGBColor[
             0.7397014400437496, 0.7929588961028291, 0.8721850541048333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 74}], {
             RGBColor[
             0.33344529597857986`, 0.4502919261584768, 0.9431672139549263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 88}], {
             RGBColor[
             0.39928713327406085`, 0.5193234698631873, 0.9469231216629608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 89}], {
             RGBColor[
             0.6970093852017993, 0.7615588368351222, 0.971867486873361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 91}], {
             RGBColor[
             0.44527282195906354`, 0.5591539620942192, 0.9498532890824214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 93}], {
             RGBColor[
             0.5414131112242391, 0.6385825799313716, 0.9570411698585974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 96}], {
             RGBColor[
             0.46616836512005916`, 0.5772526313397371, 0.9511847346154367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 90}], {
             RGBColor[
             0.5602242675108555, 0.6324397912947615, 0.9636443933441387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 100}], {
             RGBColor[
             0.7550330854057725, 0.8085019478080251, 0.9766230994610292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 69}], {
             RGBColor[
             0.9941696270911844, 0.9915722055690903, 0.7255859700299957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 77}], {
             RGBColor[
             0.8666058682321716, 0.8941046006220141, 0.8669770524234799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 79}], {
             RGBColor[
             0.7337055248867795, 0.7877031596755213, 0.8554938476310308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 83}], {
             RGBColor[
             0.9905843913760879, 0.9809897270997958, 0.5831425676984634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 95}], {
             RGBColor[
             0.7571971206262154, 0.8067746953811232, 0.8573431921001897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 97}], {
             RGBColor[
             0.5961296088748151, 0.6589454058218245, 0.8469442491042749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[
             0.9913322850060433, 0.9906836913469534, 0.7933099989846082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 99}], {
             RGBColor[
             0.6034466951550465, 0.6666361274324131, 0.847360946343275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 68}], {
             RGBColor[
             0.6790554523524194, 0.7483508415232704, 0.9692278754375898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 72}], {
             RGBColor[
             0.6092654556326753, 0.6915255169357472, 0.9637798002457192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 86}], {
             RGBColor[
             0.8814472111058332, 0.9060377511360834, 0.8838271213269129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 92}], {
             RGBColor[
             0.7471033643441813, 0.8023620935123281, 0.9754279393460907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 94}], {
             RGBColor[
             0.8599373976929178, 0.8274629138082963, 0.6276420084530723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 72}], {
             RGBColor[
             0.5169699909666087, 0.6185718925092967, 0.9551629668929063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 82}], {
             RGBColor[
             0.6140476572652998, 0.6975505765565146, 0.9627592273920589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 92}], {
             RGBColor[
             0.6548078996781147, 0.7294084690858778, 0.9668111059932779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 71}], {
             RGBColor[
             0.8831513929751307, 0.9064576744880797, 0.8348824896734643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 77}], {
             RGBColor[
             0.8673881100727624, 0.8941432780793622, 0.8333113529500104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 87}], {
             RGBColor[
             0.9152438655222055, 0.9316542578655014, 0.8380478105240703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 95}], {
             RGBColor[
             0.7579793624668063, 0.8068133728384714, 0.8236774926267201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 97}], {
             RGBColor[
             0.5969118507154061, 0.6589840832791725, 0.8132785496308055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 98}], {
             RGBColor[
             0.9921145268466341, 0.9907223688043016, 0.7596442995111387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 99}], {
             RGBColor[
             0.6042289369956374, 0.666674804889761, 0.8136952468698055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 75}], {
             RGBColor[
             0.25853960821404365`, 0.3863530933352983, 0.9381343690539508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 96}], {
             RGBColor[
             0.3116500691414793, 0.4323547051812604, 0.9415185206605103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 77}], {
             RGBColor[
             0.7555876341161178, 0.8089900695410035, 0.9762735720669486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 87}], {
             RGBColor[
             0.8034433895655608, 0.8465010493271425, 0.9810100296410085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 82}], {
             RGBColor[
             0.5442576605455558, 0.6407252519689914, 0.9573111522001883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 92}], {
             RGBColor[
             0.5850179029583706, 0.6725831444983545, 0.9613630308014073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 74}], {
             RGBColor[
             0.5851831440651697, 0.6480609699443524, 0.8625188401499069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 88}], {
             RGBColor[
             0.6510249813606506, 0.717092513649063, 0.8662747478579415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.9487472332883892, 0.9593278806209977, 0.8912191130683416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 91}], {
             RGBColor[
             0.6970106700456533, 0.7569230058800948, 0.869204915277402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 93}], {
             RGBColor[
             0.7931509593108289, 0.8363516237172473, 0.876392796053578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 88}], {
             RGBColor[
             0.24476883729548096`, 0.3744255437047106, 0.9372569077080346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 91}], {
             RGBColor[
             0.2907545259804837, 0.41425603593574234`, 0.940187075127495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 96}], {
             RGBColor[
             0.3116500691414793, 0.4323547051812604, 0.9415185206605103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 96}], {
             RGBColor[
             0.3912626773555229, 0.5133137985165588, 0.9461518897144612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 81}], {
             RGBColor[
             0.9669718153846282, 0.9690682825639153, 0.7003586737761741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 84}], {
             RGBColor[
             0.5776808894888605, 0.6487738638403596, 0.958392217905608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 85}], {
             RGBColor[
             0.9418634600431803, 0.956162444206827, 0.9832941770955704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 87}], {
             RGBColor[
             0.7876801066631927, 0.8341866529184252, 0.9794388929175545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 95}], {
             RGBColor[
             0.6304156036077935, 0.7093457678913953, 0.9650685750202044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 97}], {
             RGBColor[
             0.46934809185639326`, 0.5615164783320963, 0.9546696320242896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 98}], {
             RGBColor[
             0.8645507679876213, 0.8932547638572255, 0.9010353819046228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 99}], {
             RGBColor[
             0.47666517813662457`, 0.5692071999426849, 0.9550863292632896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 83}], {
             RGBColor[
             0.7309025310122739, 0.7771593586635748, 0.6793847458260289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 98}], {
             RGBColor[
             0.7316504246422293, 0.7868533229107326, 0.8895521771121737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 99}], {
             RGBColor[
             0.34376483479123254`, 0.4628057589961921, 0.9436031244708405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 84}], {
             RGBColor[
             0.60165788477222, 0.6608359357185577, 0.6773718120585941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 85}], {
             RGBColor[
             0.9658404553265398, 0.968224516085025, 0.7022737712485565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 86}], {
             RGBColor[
             0.8164394160187136, 0.8552374861693277, 0.877358473281382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 87}], {
             RGBColor[
             0.7384355944784413, 0.7957007843603869, 0.9745413815954775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 92}], {
             RGBColor[
             0.6820955692570618, 0.7515618285455725, 0.9689592913005598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 97}], {
             RGBColor[
             0.5933266150003096, 0.648401604809878, 0.6708351472992731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 85}], {
             RGBColor[
             0.5765495294307721, 0.6479300973614693, 0.9603073153779905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.20210731317620745`, 0.3297579788649362, 0.9348210845431848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 90}], {
             RGBColor[
             0.5662898837305272, 0.6371465592314035, 0.9597230437331472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 92}], {
             RGBColor[
             0.8571996584315286, 0.8870953786986908, 0.8814103518826011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[
             0.970033691780265, 0.9121961989946588, 0.5336244209895825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 91}], {
             RGBColor[
             0.3565963632759646, 0.483287579640453, 0.9439429828355296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 96}], {
             RGBColor[
             0.37749190643696023`, 0.5013862488859709, 0.9452744283685449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 91}], {
             RGBColor[
             0.6543186152037032, 0.7255229466123878, 0.9688873480459297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 93}], {
             RGBColor[
             0.7504589044688788, 0.8049515644495402, 0.9760752288221058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 100}], {
             RGBColor[
             0.3866564853708796, 0.495036597248134, 0.947215519015232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 93}], {
             RGBColor[
             0.4987223412261429, 0.6025466897086372, 0.9540610310311661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 96}], {
             RGBColor[
             0.4234775951219629, 0.5412167411170028, 0.9482045957880054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 94}], {
             RGBColor[
             0.8356898450186131, 0.8085205413709036, 0.6252252390087605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 98}], {
             RGBColor[
             0.7551420203816652, 0.8059248586163346, 0.8914015215813327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 99}], {
             RGBColor[
             0.3672564305306685, 0.4818772947017941, 0.9454524689399995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 99}], {
             RGBColor[
             0.6013915949104963, 0.6657862906676243, 0.8814192758244179]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.058168352269944726`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.058168352269944726`], {
             RGBColor[
             0.21350600505949952`, 0.3417387267530838, 0.9354702231830848]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.058168352269944726`], {
             RGBColor[
             0.8501632775847899, 0.8833611367514445, 0.9855705264373964]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.058168352269944726`], {
             RGBColor[
             0.8220343321974771, 0.8609318792394833, 0.9828875625153485]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.058168352269944726`], {
             RGBColor[
             0.8843246215405065, 0.9106004651367537, 0.9888288659200845]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.058168352269944726`], {
             RGBColor[
             0.850445108948246, 0.8835858614305557, 0.9855974077644367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.058168352269944726`], {
             RGBColor[
             0.5769430170973167, 0.6674273581231552, 0.9598382141992597]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.058168352269944726`], {
             RGBColor[
             0.9391242548827409, 0.954119549483208, 0.9879309369330693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.058168352269944726`], {
             RGBColor[
             0.967341157307962, 0.9014961963181384, 0.32762699255671884`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.058168352269944726`], {
             RGBColor[
             0.35941770313622634`, 0.48573128242274716`, 0.9441227561166126]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.058168352269944726`], {
             RGBColor[
             0.3916133305993202, 0.5136175167319914, 0.9461742330290854]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.058168352269944726`], {
             RGBColor[
             0.27468655682539633`, 0.4060433657300679, 0.9389543650976372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.058168352269944726`], {
             RGBColor[
             0.9482711692982082, 0.8326194544180315, 0.2772359724668666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.058168352269944726`], {
             RGBColor[
             0.8010664413338222, 0.8445184593912108, 0.9808064745467924]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.058168352269944726`], {
             RGBColor[
             0.7268056719913834, 0.7865053819781469, 0.9734048550650835]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.058168352269944726`], {
             RGBColor[
             0.20311888804010014`, 0.3308212081844382, 0.9348786922351926]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.058168352269944726`], {
             RGBColor[
             0.4776022814296219, 0.5867780736589784, 0.9520177475903938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.058168352269944726`], {
             RGBColor[
             0.7720215092649558, 0.8218283377093529, 0.9779115471584899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.058168352269944726`], {
             RGBColor[
             0.9901974655330067, 0.9785958908775954, 0.41641943395938213`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.058168352269944726`], {
             RGBColor[
             0.21064140400994538`, 0.3387278494238057, 0.9353070883911102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.058168352269944726`], {
             RGBColor[
             0.3454507052461414, 0.47363377085208114`, 0.9432327913615877]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.058168352269944726`], {
             RGBColor[
             0.9479088299943242, 0.9606710712180053, 0.973060942653288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.058168352269944726`], {
             RGBColor[
             0.4693170520019931, 0.5800517511642971, 0.9513655039800555]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.058168352269944726`], {
             RGBColor[
             0.37533202342905064`, 0.49951546678339614`, 0.9451368025331905]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.058168352269944726`], {
             RGBColor[
             0.7606351412946137, 0.8129332205113199, 0.9767766604108646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.058168352269944726`], {
             RGBColor[
             0.4471799942468646, 0.5617465679217735, 0.9497148917010356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.058168352269944726`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.058168352269944726`], {
             RGBColor[
             0.276488604602254, 0.40793743219997347`, 0.9390569890526385]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.058168352269944726`], {
             RGBColor[
             0.45010914068227204`, 0.5642836473409428, 0.9499015343217573]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.058168352269944726`], {
             RGBColor[
             0.5814653032657966, 0.6710987537613975, 0.9601942251321226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.058168352269944726`], {
             RGBColor[
             0.4113686298975898, 0.5307285640539392, 0.947433023231446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.058168352269944726`], {
             RGBColor[
             0.9384375143174295, 0.7936322892905109, 0.26932358284378294`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.058168352269944726`], {
             RGBColor[
             0.6806483800775323, 0.750446954726635, 0.9688043275715278]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.058168352269944726`], {
             RGBColor[
             0.44738674396703615`, 0.561925644137843, 0.9497280656103834]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.058168352269944726`], {
             RGBColor[
             0.21728211407122666`, 0.34570765674354864`, 0.93568526700505]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.058168352269944726`], {
             RGBColor[
             0.3150270184610134, 0.4472823024977628, 0.9412942209422492]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.058168352269944726`], {
             RGBColor[
             0.3424316176151695, 0.47101878888988974`, 0.9430404177674165]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.058168352269944726`], {
             RGBColor[
             0.515713265259775, 0.6177182872125528, 0.9550179838426371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.058168352269944726`], {
             RGBColor[
             0.3868568167807159, 0.5094976635316522, 0.945871152174584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.058168352269944726`], {
             RGBColor[
             0.9934870981233345, 0.9884778863782295, 0.532489007575325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.058168352269944726`], {
             RGBColor[
             0.9665801095513337, 0.89892900353252, 0.32467046573402747`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.058168352269944726`], {
             RGBColor[
             0.4206634257052774, 0.5387792490125373, 0.9480252794012466]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.058168352269944726`], {
             RGBColor[
             0.52257495095585, 0.6232889127760445, 0.9555581608758151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.058168352269944726`], {
             RGBColor[
             0.9930692460643079, 0.991401969382409, 0.7645240591380389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.058168352269944726`], {
             RGBColor[
             0.21236695887645235`, 0.340541516995002, 0.9354053561880281]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.058168352269944726`], {
             RGBColor[
             0.8764463221508937, 0.9043185230542164, 0.9880774266912623]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.058168352269944726`], {
             RGBColor[
             0.48796359195715977`, 0.5951898523169535, 0.9528334279098526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.058168352269944726`], {
             RGBColor[
             0.742957951942214, 0.7991236658376101, 0.9750147633789441]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.058168352269944726`], {
             RGBColor[
             0.18085135473046252`, 0.30741661883285304`, 0.9336105891550721]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.058168352269944726`], {
             RGBColor[
             0.2789356148505069, 0.41050939512029794`, 0.9391963426662492]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.058168352269944726`], {
             RGBColor[
             0.8898875470197872, 0.9150361909123427, 0.9893594627183804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.058168352269944726`], {
             RGBColor[
             0.7973415900068113, 0.8416085772246312, 0.9804352161772306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.058168352269944726`], {
             RGBColor[
             0.9937286998256762, 0.9916746704599235, 0.7535952037005379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.058168352269944726`], {
             RGBColor[
             0.323065395465961, 0.45424474063887266`, 0.9418064192169469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.058168352269944726`], {
             RGBColor[
             0.9933873852505934, 0.9915335281117422, 0.7592516695034652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.058168352269944726`], {
             RGBColor[
             0.7660791289406382, 0.8171861050362327, 0.9773192662224633]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.058168352269944726`], {
             RGBColor[
             0.6701319205187674, 0.7422314165912749, 0.9677561451646123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.058168352269944726`], {
             RGBColor[
             0.5557211628814369, 0.6501985008370665, 0.9581675520971723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.058168352269944726`], {
             RGBColor[
             0.8836422963417218, 0.9100563975444669, 0.9887637851335055]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.058168352269944726`], {
             RGBColor[
             0.6324234427688471, 0.7124688670479976, 0.9642058365396182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.058168352269944726`], {
             RGBColor[
             0.7364043952645095, 0.7940039775521118, 0.9743615660957797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.058168352269944726`], {
             RGBColor[
             0.3626744830594612, 0.4885521415017347, 0.9443302752534637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.058168352269944726`], {
             RGBColor[
             0.9423459212164225, 0.9565222629598733, 0.9824774961752983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.058168352269944726`], {
             RGBColor[
             0.48796359195715977`, 0.5951898523169535, 0.9528334279098526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.058168352269944726`], {
             RGBColor[
             0.9286008675457486, 0.9459051418546526, 0.9930519737899358]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.058168352269944726`], {
             RGBColor[
             0.9933873852505934, 0.9915335281117422, 0.7592516695034652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.058168352269944726`], {
             RGBColor[
             0.771350917018486, 0.8213044659497208, 0.9778447087904026]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.058168352269944726`], {
             RGBColor[
             0.5867599876863527, 0.6753972170968199, 0.9606110420847769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.058168352269944726`], {
             RGBColor[
             0.9949518689317752, 0.9916108830264384, 0.6919202705565262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.058168352269944726`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.058168352269944726`], {
             RGBColor[
             0.771350917018486, 0.8213044659497208, 0.9778447087904026]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.058168352269944726`], {
             RGBColor[
             0.4471799942468646, 0.5617465679217735, 0.9497148917010356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.058168352269944726`], {
             RGBColor[
             0.9914392881303393, 0.9907279398887048, 0.7915366802998138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.058168352269944726`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.058168352269944726`], {
             RGBColor[
             0.33815221642808724`, 0.4673121866705967, 0.9427677381079015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.058168352269944726`], {
             RGBColor[
             0.9429948201012687, 0.9570062106857172, 0.9813790796231879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.058168352269944726`], {
             RGBColor[
             0.7398243512137496, 0.796675673132286, 0.9747024353434945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.058168352269944726`], {
             RGBColor[
             0.9853578807855949, 0.988213121666613, 0.8923213381799363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.058168352269944726`], {
             RGBColor[
             0.4740236645229656, 0.5838727912393004, 0.9517360257585962]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.058168352269944726`], {
             RGBColor[
             0.27468655682539633`, 0.4060433657300679, 0.9389543650976372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.058168352269944726`], {
             RGBColor[
             0.9909488106679877, 0.9811303544421134, 0.41933826792916024`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.058168352269944726`], {
             RGBColor[
             0.6413353268442469, 0.7197039360162095, 0.9649074126993408]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.058168352269944726`], {
             RGBColor[
             0.9877813975015822, 0.9704459260878493, 0.4070334658934616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.058168352269944726`], {
             RGBColor[
             0.21236695887645235`, 0.340541516995002, 0.9354053561880281]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.058168352269944726`], {
             RGBColor[
             0.9407320999850919, 0.9553186777279367, 0.9852092745679529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.058168352269944726`], {
             RGBColor[
             0.9915435051931805, 0.990771036322446, 0.7898095338634231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.058168352269944726`], {
             RGBColor[
             0.8355358621126358, 0.8716976327045644, 0.9841753504916144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.058168352269944726`], {
             RGBColor[
             0.3106106745909619, 0.4434570874094212, 0.9410128154160691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.058168352269944726`], {
             RGBColor[
             0.906055178446439, 0.9279278213532908, 0.9909015458368694]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.058168352269944726`], {
             RGBColor[
             0.19184766747596257`, 0.3189744407348704, 0.9342368128983415]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.058168352269944726`], {
             RGBColor[
             0.4025820519609673, 0.5231180718714847, 0.9468731502549901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.058168352269944726`], {
             RGBColor[
             0.7228558116698767, 0.7834197210749355, 0.9730111699017789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.058168352269944726`], {
             RGBColor[
             0.5948626304913185, 0.6819753075457897, 0.9612489118073423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.058168352269944726`], {
             RGBColor[
             0.9485238783673495, 0.8336213616668716, 0.27743930811574197`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.058168352269944726`], {
             RGBColor[
             0.5210068560018374, 0.6220158626505043, 0.9554347146969141]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.058168352269944726`], {
             RGBColor[
             0.44437313828295855`, 0.5593154103625207, 0.9495360413210208]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.058168352269944726`], {
             RGBColor[
             0.19887183249903692`, 0.32635728353190663`, 0.9346368287050847]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.058168352269944726`], {
             RGBColor[
             0.9892771847614931, 0.9898338545821648, 0.8273683284657511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.058168352269944726`], {
             RGBColor[
             0.21350600505949952`, 0.3417387267530838, 0.9354702231830848]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.058168352269944726`], {
             RGBColor[
             0.5814653032657966, 0.6710987537613975, 0.9601942251321226]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100}, {
          Null, CompressedData["
1:eJwVxVmbqQwAAOCxVtbppLIkW4w1a5YJk8gSaaRCIqr783/Pr/me7715C/Zf
xfZ+fHz883x8/D9363DUk1oFBOGSrgbkKTe9Ubr+DJzlM67jGn44aCN55AiO
7OTWuWMuH0qHqrVObVrjcvv1PnbAe71DT+vplLkyddN8hkqxEiiAOngBnQA/
4nmBl/kz71Cz2Wqmz8zZE8QwHhOwC+aAKIqhFLpCL6gZpsKz8Cpshp+ghVm8
JViWU9t1dtxud0NGCI/IiIU4oXgsHi/Fq3gmo3kQT8YzygyrQz/up/w9/8Gv
+58BCZQwiZcESbpIluT8+c395n89MAjDCIzBI5iHBViCZdiCncDPzznXz/f7
6/6+Nu6Mx9x4N755Y96s9xj4/v75PnvrsXq2Xj/6SZBESYzESZIie6ROmuQz
5MbdtFt1h+5nNkDABEIQI4InZOJMOOEtuqW2s+1quzU9NEwjNEHTI1qmLdpp
99vr9t5fxsuZcrlXPpS19qvz4l7r1/6Fqxm1rPbUoXpQVc1b+CxkC4V67dF5
jB/TB/fYPW6PXCvfah1r1/a1cx1fuevuen2l0qlqaphy0SJWLE6LQlEqXjzR
aCY6jKpRLfeV//pqff3WxLbYEcfiVOTEnShexZenEW0gjUyjQTeG3maumW9+
NevNZqt5DC+p5Wy5XC23S31pLp/+ZCyJJ5P1ZC95AKJACsgAZaAKDAEV0AAX
7KJdrFvsdoWu1L3U7p37+M7dd3fxfr3f7vfH/RV4f79/3vxbeEvv8xswQkbc
SBslo2qohmYYbhAIhoLxYCqYDpaC1aARdIub7ma6ETYbaXMJsDCLsARLsyOW
5VmBlViZPbMW+2Yd7zw2j88/59l5YV6a1+eBRIJIfCfYxE+CT8iJc+IdXACL
0CK1SC+qi4WxcEEFVTCFVIoKpXSVlbJVFF25KCZsIzZh0/bIZm3eFmzJlm3L
th1vJVaJV7KVUqVSr8zDg9ZgsBysBtvBEThFT/gpcyqfeqfD6aSetCADMCEm
xsSZNFNiqgyzYFRGYwzGbU86k/5kwk3WE3Gyn1wnL6/P9+nL+gq+iq/um0dq
kUFkGuEiYuQaefkhKAyhEAlR0AxaQitoCymQDpnQ8z9pR8GG
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[69, 98] -> 
             RGBColor[
              0.35934722090825977`, 0.48438990088158124`, 0.9441651443282024],
              UndirectedEdge[29, 33] -> 
             RGBColor[
              0.29422509162390786`, 0.4255184180648389, 0.9401059109878009], 
             UndirectedEdge[55, 59] -> 
             RGBColor[
              0.26182384182735224`, 0.39252383672388913`, 0.9382218525071802],
              UndirectedEdge[47, 74] -> 
             RGBColor[
              0.31904494583740095`, 0.4476628644149205, 0.9416637299737558], 
             UndirectedEdge[19, 43] -> 
             RGBColor[
              0.25864725898215624`, 0.389185046746603, 0.9380409508134795], 
             UndirectedEdge[57, 75] -> 
             RGBColor[
              0.25952031121468844`, 0.390102679997703, 0.9380906698465571], 
             UndirectedEdge[19, 46] -> 
             RGBColor[
              0.2688995810964162, 0.39996088732345647`, 0.9386248053909352], 
             UndirectedEdge[36, 67] -> 
             RGBColor[
              0.18042977836149893`, 0.3069735153395867, 0.9335865810045261], 
             UndirectedEdge[79, 99] -> 
             RGBColor[
              0.3231374521934327, 0.4482183313765927, 0.9420339521780562], 
             UndirectedEdge[52, 68] -> 
             RGBColor[
              0.857792466353585, 0.3543610539002231, 0.19933416213146946`], 
             UndirectedEdge[81, 85] -> 
             RGBColor[
              0.5777440554332705, 0.6680776771306483, 0.9599012748713662], 
             UndirectedEdge[12, 88] -> 
             RGBColor[
              0.44729833605503005`, 0.5559100353701449, 0.9509297720791202], 
             UndirectedEdge[72, 82] -> 
             RGBColor[
              0.8334563513078143, 0.2581657535842936, 0.17967114583689445`], 
             UndirectedEdge[31, 44] -> 
             RGBColor[
              0.5893518598321712, 0.6739738751825308, 0.9626393731710036], 
             UndirectedEdge[17, 79] -> 
             RGBColor[
              0.3156295526433677, 0.44171536614432994`, 0.9415555554577009], 
             UndirectedEdge[91, 96] -> 
             RGBColor[
              0.269451185257078, 0.40054065827003577`, 0.9386562184318596], 
             UndirectedEdge[55, 99] -> 
             RGBColor[
              0.32604506358539376`, 0.45127441530275375`, 0.9421995363454028],
              UndirectedEdge[77, 99] -> 
             RGBColor[
              0.4105884153235183, 0.5300527814046032, 0.9473833086487027], 
             UndirectedEdge[29, 38] -> 
             RGBColor[
              0.3762188058276783, 0.5002835531261081, 0.9451933075234802], 
             UndirectedEdge[26, 90] -> 
             RGBColor[
              0.2640863311664119, 0.39490185646935017`, 0.9383506979279865], 
             UndirectedEdge[13, 27] -> 
             RGBColor[
              0.30786109230723857`, 0.43780476345745334`, 0.9409573735218479],
              UndirectedEdge[22, 99] -> 
             RGBColor[
              0.6824515754881706, 0.7473171966554524, 0.9484738769221548], 
             UndirectedEdge[73, 74] -> 
             RGBColor[
              0.3072565676292452, 0.4352725314918011, 0.940992399274144], 
             UndirectedEdge[8, 77] -> 
             RGBColor[
              0.6903471893885933, 0.7540727058376107, 0.9477616322002713], 
             UndirectedEdge[36, 94] -> 
             RGBColor[
              0.1800640484055534, 0.3065891099672694, 0.9335657532245839], 
             UndirectedEdge[21, 87] -> 
             RGBColor[
              0.8461475149580568, 0.7442097533956613, 0.6102686063858478], 
             UndirectedEdge[59, 83] -> 
             RGBColor[
              0.24944682557751796`, 0.3795148078971581, 0.9375169997419068], 
             UndirectedEdge[24, 42] -> 
             RGBColor[
              0.7818518898687528, 0.7011631313519644, 0.6053992543639326], 
             UndirectedEdge[33, 42] -> 
             RGBColor[
              0.46221511877127164`, 0.5653020306816455, 0.952477193383617], 
             UndirectedEdge[14, 42] -> 
             RGBColor[
              0.6875842561639678, 0.755865313839969, 0.9694956308803766], 
             UndirectedEdge[45, 78] -> 
             RGBColor[
              0.8888960529642432, 0.9113695171236152, 0.8624721274568261], 
             UndirectedEdge[15, 38] -> 
             RGBColor[
              0.3740760297515814, 0.49842758818805, 0.9450567717266938], 
             UndirectedEdge[84, 85] -> 
             RGBColor[
              0.5258992134513589, 0.6255397259320082, 0.9559436352420423], 
             UndirectedEdge[55, 98] -> 
             RGBColor[
              0.2718017456530969, 0.4030112462803886, 0.9387900793690704], 
             UndirectedEdge[86, 92] -> 
             RGBColor[
              0.5898473968790202, 0.652327074257428, 0.8461866592841044], 
             UndirectedEdge[72, 92] -> 
             RGBColor[
              0.6163830767877724, 0.26617042741573227`, 0.42980287471151735`],
              UndirectedEdge[19, 99] -> 
             RGBColor[
              0.33504481922143936`, 0.46073372909370225`, 0.9427120591149303],
              UndirectedEdge[4, 76] -> 
             RGBColor[
              0.8906548722841052, 0.5296457315437284, 0.33185422782530094`], 
             UndirectedEdge[23, 76] -> 
             RGBColor[
              0.9905483291850934, 0.9895519766020239, 0.7476033518841813], 
             UndirectedEdge[9, 72] -> 
             RGBColor[
              0.871424018845867, 0.4434546654256925, 0.21174306614349048`], 
             UndirectedEdge[2, 44] -> 
             RGBColor[
              0.6476158835940419, 0.7227173201002071, 0.9668276779841867], 
             UndirectedEdge[74, 88] -> 
             RGBColor[
              0.3260233854984479, 0.4549976469573106, 0.9420611417887761], 
             UndirectedEdge[21, 49] -> 
             RGBColor[
              0.8381155029968219, 0.7379350846059927, 0.6094680504969712], 
             UndirectedEdge[21, 34] -> 
             RGBColor[
              0.7440489383777218, 0.6635696741320418, 0.6006939636333543], 
             UndirectedEdge[59, 66] -> 
             RGBColor[
              0.2986049435975745, 0.4299329425040255, 0.9403622564770246], 
             UndirectedEdge[17, 99] -> 
             RGBColor[
              0.3958768319210234, 0.5173103472870436, 0.9464458995632381], 
             UndirectedEdge[26, 53] -> 
             RGBColor[
              0.27181647740875625`, 0.40165680145894234`, 0.9388410781260154],
              UndirectedEdge[23, 50] -> 
             RGBColor[
              0.9890507904475296, 0.9897402347152724, 0.831120268137828], 
             UndirectedEdge[41, 74] -> 
             RGBColor[
              0.39624144168094344`, 0.517626153935267, 0.9464691321747285], 
             UndirectedEdge[59, 79] -> 
             RGBColor[
              0.2589162304353912, 0.38946775279772805`, 0.9380562683398335], 
             UndirectedEdge[56, 93] -> 
             RGBColor[
              0.251058389952088, 0.3812086642339142, 0.9376087759489427], 
             UndirectedEdge[19, 98] -> 
             RGBColor[
              0.2808015012891425, 0.4124705600713371, 0.9393026021385978], 
             UndirectedEdge[2, 38] -> 
             RGBColor[
              0.4744745540542128, 0.5836658197325597, 0.9519298496562583], 
             UndirectedEdge[19, 59] -> 
             RGBColor[
              0.2708235974633978, 0.40198315051483763`, 0.9387343752767077], 
             UndirectedEdge[24, 76] -> 
             RGBColor[
              0.9509230096039614, 0.8306452679372385, 0.4351994673534736], 
             UndirectedEdge[5, 20] -> 
             RGBColor[
              0.23580229552736498`, 0.3651735417012756, 0.9367399639408238], 
             UndirectedEdge[37, 84] -> 
             RGBColor[
              0.5813861978869495, 0.66930600772412, 0.9611872941941962], 
             UndirectedEdge[9, 82] -> 
             RGBColor[
              0.8754468132212324, 0.47437562579448644`, 0.2155952985804368], 
             UndirectedEdge[47, 75] -> 
             RGBColor[
              0.2704352603663721, 0.40157498360386956`, 0.9387122600535251], 
             UndirectedEdge[51, 75] -> 
             RGBColor[
              0.2631874052799758, 0.3939570283675128, 0.9382995054285956], 
             UndirectedEdge[58, 63] -> 
             RGBColor[
              0.22145736040975994`, 0.3500961053712548, 0.9359230411073061], 
             UndirectedEdge[7, 25] -> 
             RGBColor[
              0.2646919276847649, 0.3951010487472052, 0.9384011984763869], 
             UndirectedEdge[1, 55] -> 
             RGBColor[
              0.25340680094735984`, 0.3836769930878019, 0.9377425144809607], 
             UndirectedEdge[82, 86] -> 
             RGBColor[
              0.8894645876671153, 0.5232422803245426, 0.375167170072727], 
             UndirectedEdge[34, 71] -> 
             RGBColor[
              0.46781157980336074`, 0.5760433128989255, 0.9520168308232597], 
             UndirectedEdge[41, 73] -> 
             RGBColor[
              0.34062966364440406`, 0.46417862987955394`, 0.9431189034415599],
              UndirectedEdge[92, 94] -> 
             RGBColor[
              0.18353386454932197`, 0.3102361067334203, 0.9337633541208386], 
             UndirectedEdge[3, 62] -> 
             RGBColor[
              0.3326644235069168, 0.4616841238673607, 0.9424500919629462], 
             UndirectedEdge[70, 75] -> 
             RGBColor[
              0.2709835768789808, 0.4021512990238961, 0.9387434858677567], 
             UndirectedEdge[57, 96] -> 
             RGBColor[
              0.26925290833864535`, 0.40033225665728034`, 0.9386449268546793],
              UndirectedEdge[68, 72] -> 
             RGBColor[
              0.8220276513733772, 0.17031975779996553`, 0.1687270098728071], 
             UndirectedEdge[13, 54] -> 
             RGBColor[
              0.26215076948672145`, 0.392867458422297, 0.938240470553735], 
             UndirectedEdge[48, 96] -> 
             RGBColor[
              0.2710430288508906, 0.402213786815846, 0.9387468715696057], 
             UndirectedEdge[30, 50] -> 
             RGBColor[
              0.8760283796853721, 0.425019431443821, 0.37448185602113726`], 
             UndirectedEdge[11, 92] -> 
             RGBColor[
              0.21022995471211395`, 0.3382953901243926, 0.9352836569622833], 
             UndirectedEdge[41, 56] -> 
             RGBColor[
              0.3357366265014662, 0.459035737605853, 0.9428402522148693], 
             UndirectedEdge[73, 91] -> 
             RGBColor[
              0.25271649556761044`, 0.3829514383657963, 0.9377032026107992], 
             UndirectedEdge[32, 39] -> 
             RGBColor[
              0.2935264779562271, 0.4258453173585629, 0.9400272707348724], 
             UndirectedEdge[32, 80] -> 
             RGBColor[
              0.2808572092204622, 0.41252911263924097`, 0.939305774622874], 
             UndirectedEdge[20, 66] -> 
             RGBColor[
              0.271765998365242, 0.4017235093774315, 0.9388338182507047], 
             UndirectedEdge[47, 88] -> 
             RGBColor[
              0.28219998567006427`, 0.41394045582471695`, 0.9393822437552191],
              UndirectedEdge[14, 53] -> 
             RGBColor[
              0.5212638853795565, 0.6175278736453831, 0.9572307375115887], 
             UndirectedEdge[51, 57] -> 
             RGBColor[
              0.25705874177093724`, 0.3875154144398035, 0.9379504871083011], 
             UndirectedEdge[30, 94] -> 
             RGBColor[
              0.6058475621171975, 0.19724613329962365`, 0.4213505142806121], 
             UndirectedEdge[22, 69] -> 
             RGBColor[
              0.6926573828576388, 0.7561569540400923, 0.9491241819430962], 
             UndirectedEdge[4, 94] -> 
             RGBColor[
              0.6194756955575549, 0.30199793880836345`, 0.4344008302538737], 
             UndirectedEdge[4, 86] -> 
             RGBColor[
              0.8903513837773537, 0.5300585838243685, 0.3760163670293843], 
             UndirectedEdge[9, 94] -> 
             RGBColor[
              0.566095277636464, 0.5761624637483606, 0.6066736412687983], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.25232882209907226`, 0.38254396897044507`, 0.9376811251802775],
              UndirectedEdge[12, 60] -> 
             RGBColor[
              0.5377449711891708, 0.6356046186030777, 0.9567524004381972], 
             UndirectedEdge[25, 40] -> 
             RGBColor[
              0.22979823437354924`, 0.35886289274915106`, 0.9363980415403266],
              UndirectedEdge[22, 95] -> 
             RGBColor[
              0.7735850344334367, 0.822659249453164, 0.9552736235962966], 
             UndirectedEdge[3, 33] -> 
             RGBColor[
              0.283755346452618, 0.41557523862275036`, 0.9394708192508354], 
             UndirectedEdge[48, 93] -> 
             RGBColor[
              0.2586149766637431, 0.3891511159831336, 0.9380391123832033], 
             UndirectedEdge[15, 90] -> 
             RGBColor[
              0.3120203774346074, 0.44461862031594124`, 0.9411048183197483], 
             UndirectedEdge[77, 97] -> 
             RGBColor[
              0.3343295626774611, 0.4586498895325537, 0.9427200995394867], 
             UndirectedEdge[44, 78] -> 
             RGBColor[
              0.88634546706693, 0.9093769800354632, 0.8622179088911622], 
             UndirectedEdge[30, 92] -> 
             RGBColor[
              0.6076645338330189, 0.19915588577561247`, 0.4214539881318594], 
             UndirectedEdge[37, 76] -> 
             RGBColor[
              0.8601494153237335, 0.8880770205793902, 0.7996440970661025], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.5927913677992559, 0.604221747139333, 0.6081939441102431], 
             UndirectedEdge[75, 96] -> 
             RGBColor[
              0.27538157184768386`, 0.40677387058498965`, 0.9389939451749738],
              UndirectedEdge[31, 80] -> 
             RGBColor[
              0.33469414166217204`, 0.4606589391956579, 0.9426813312926726], 
             UndirectedEdge[85, 90] -> 
             RGBColor[
              0.4615407941261787, 0.5697362170178263, 0.951844951557591], 
             UndirectedEdge[91, 93] -> 
             RGBColor[
              0.2570231330699305, 0.38747798743732337`, 0.9379484592454572], 
             UndirectedEdge[22, 49] -> 
             RGBColor[
              0.8672856751894109, 0.8967275864503471, 0.9640189035929849], 
             UndirectedEdge[69, 87] -> 
             RGBColor[
              0.6064566505030319, 0.6883381284885098, 0.9639201838642415], 
             UndirectedEdge[47, 70] -> 
             RGBColor[
              0.27576986252162594`, 0.40718198870235345`, 0.9390160577544302],
              UndirectedEdge[42, 78] -> 
             RGBColor[
              0.8251990022368825, 0.8616088969798854, 0.8561234007231051], 
             UndirectedEdge[1, 43] -> 
             RGBColor[
              0.25434890859377146`, 0.3846672079572553, 0.9377961661177004], 
             UndirectedEdge[10, 35] -> 
             RGBColor[
              0.2769526708149095, 0.4084251952129716, 0.9390834169369247], 
             UndirectedEdge[67, 94] -> 
             RGBColor[
              0.18117413693153547`, 0.3077558833917543, 0.9336289711239099], 
             UndirectedEdge[73, 93] -> 
             RGBColor[
              0.2559514270950259, 0.38635155650761516`, 0.9378874271756332], 
             UndirectedEdge[68, 82] -> 
             RGBColor[
              0.8240390485610599, 0.18578023798436252`, 0.17065312609128025`],
              UndirectedEdge[11, 52] -> 
             RGBColor[
              0.5864699931809645, 0.5791596032510256, 0.6031076177106328], 
             UndirectedEdge[15, 53] -> 
             RGBColor[
              0.3197505236769518, 0.4513735653055334, 0.9415951985177772], 
             UndirectedEdge[53, 100] -> 
             RGBColor[
              0.2844126072753804, 0.4148961325895252, 0.9395584090876155], 
             UndirectedEdge[58, 83] -> 
             RGBColor[
              0.22400482828107066`, 0.3527736556227943, 0.9360681156339361], 
             UndirectedEdge[74, 96] -> 
             RGBColor[
              0.3239912573187127, 0.45286175139604057`, 0.9419454150952044], 
             UndirectedEdge[8, 87] -> 
             RGBColor[
              0.8760096171986388, 0.9035182955368775, 0.9636482023948687], 
             UndirectedEdge[43, 46] -> 
             RGBColor[
              0.2608419331067822, 0.3914917884019613, 0.9381659342581474], 
             UndirectedEdge[73, 89] -> 
             RGBColor[
              0.24808487338589558`, 0.37808330979100657`, 0.9374394385794216],
              UndirectedEdge[11, 67] -> 
             RGBColor[
              0.20787022709432745`, 0.3358151667827266, 0.9351492739653546], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.28368193490479854`, 0.4148331204560798, 0.9394909859406446], 
             UndirectedEdge[98, 99] -> 
             RGBColor[
              0.3491414135387916, 0.47555014349694125`, 0.943514839307261], 
             UndirectedEdge[4, 9] -> 
             RGBColor[
              0.8763336093314709, 0.4811919292943124, 0.21644449553709408`], 
             UndirectedEdge[34, 49] -> 
             RGBColor[
              0.678986366254469, 0.7482686816351451, 0.9692402627616367], 
             UndirectedEdge[6, 7] -> 
             RGBColor[
              0.2850997356690481, 0.41655094886844685`, 0.9395633929504454], 
             UndirectedEdge[7, 40] -> 
             RGBColor[
              0.2785823850167328, 0.4097008001089655, 0.9391922394723524], 
             UndirectedEdge[23, 85] -> 
             RGBColor[
              0.8008648229179952, 0.8435478591637703, 0.9160354539398804], 
             UndirectedEdge[82, 92] -> 
             RGBColor[
              0.6204058711631378, 0.29709138778452626`, 0.4336551071484636], 
             UndirectedEdge[34, 69] -> 
             RGBColor[
              0.5043580739226968, 0.6076980492248905, 0.954345541111748], 
             UndirectedEdge[13, 85] -> 
             RGBColor[
              0.44417434838099124`, 0.5514829814433777, 0.9508559581637567], 
             UndirectedEdge[95, 98] -> 
             RGBColor[
              0.44027487248405767`, 0.5508921962946529, 0.9503145859814027], 
             UndirectedEdge[34, 87] -> 
             RGBColor[
              0.687018378215704, 0.7545433504248138, 0.9700408186505132], 
             UndirectedEdge[61, 94] -> 
             RGBColor[
              0.17986770348779496`, 0.3063827390097185, 0.9335545716719839], 
             UndirectedEdge[61, 72] -> 
             RGBColor[
              0.613938969413421, 0.26360151559993106`, 0.4296636864122809], 
             UndirectedEdge[50, 86] -> 
             RGBColor[
              0.9923931656575502, 0.9911223927597408, 0.7757284611180213], 
             UndirectedEdge[66, 97] -> 
             RGBColor[
              0.2865673127095588, 0.41728062921084064`, 0.9396767312060312], 
             UndirectedEdge[9, 21] -> 
             RGBColor[
              0.9272801117087064, 0.7490947632900866, 0.26033044528115884`], 
             UndirectedEdge[34, 60] -> 
             RGBColor[
              0.5274957486173808, 0.6272838379970835, 0.9559455440932065], 
             UndirectedEdge[53, 84] -> 
             RGBColor[
              0.3801912291988372, 0.5037242665904019, 0.9454464268280143], 
             UndirectedEdge[21, 22] -> 
             RGBColor[
              0.9323482473126639, 0.8120285789472437, 0.5954726044647025], 
             UndirectedEdge[14, 62] -> 
             RGBColor[
              0.5425047543047143, 0.6359256467112409, 0.9585841868969369], 
             UndirectedEdge[22, 30] -> 
             RGBColor[
              0.8660842329604185, 0.4183960008903441, 0.42682228568619507`], 
             UndirectedEdge[67, 72] -> 
             RGBColor[
              0.6148099250425814, 0.26451694518795493`, 0.4297132860468982], 
             UndirectedEdge[61, 86] -> 
             RGBColor[
              0.5861812358174932, 0.6484737065337263, 0.8459778768352497], 
             UndirectedEdge[5, 83] -> 
             RGBColor[
              0.23714577838221002`, 0.3665856273634506, 0.9368164733019025], 
             UndirectedEdge[46, 99] -> 
             RGBColor[
              0.3372394933460653, 0.46304047074906063`, 0.9428370425595982], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.781084942834804, 0.8289087608987646, 0.9788149055141302], 
             UndirectedEdge[7, 37] -> 
             RGBColor[
              0.5197144859100872, 0.615889070520134, 0.9572576272411842], 
             UndirectedEdge[7, 53] -> 
             RGBColor[
              0.3185195172219749, 0.4503073293864159, 0.9415167598750023], 
             UndirectedEdge[12, 52] -> 
             RGBColor[
              0.7720788229198519, 0.7426869970369261, 0.6158231874912047], 
             UndirectedEdge[50, 85] -> 
             RGBColor[
              0.8031648921505794, 0.844498996900527, 0.8779173543675954], 
             UndirectedEdge[14, 15] -> 
             RGBColor[
              0.517451452940507, 0.6142257362851044, 0.9569878126877741], 
             UndirectedEdge[14, 35] -> 
             RGBColor[
              0.5107221888506179, 0.6078178110419963, 0.9565802436840543], 
             UndirectedEdge[8, 95] -> 
             RGBColor[
              0.7742769644814296, 0.8231752897500257, 0.9541023665093038], 
             UndirectedEdge[7, 84] -> 
             RGBColor[
              0.3751477903048108, 0.49935589331100566`, 0.9451250633614249], 
             UndirectedEdge[14, 76] -> 
             RGBColor[
              0.8566553758991764, 0.885347450425243, 0.7992958438699176], 
             UndirectedEdge[60, 89] -> 
             RGBColor[
              0.357298326389239, 0.4775030084894488, 0.9443308094531306], 
             UndirectedEdge[37, 85] -> 
             RGBColor[
              0.6704659090566354, 0.7420729031411366, 0.9680761991218017], 
             UndirectedEdge[39, 80] -> 
             RGBColor[
              0.28185045974068534`, 0.4135730819117158, 0.9393623387706183], 
             UndirectedEdge[23, 24] -> 
             RGBColor[
              0.9471254016338135, 0.8298823883137303, 0.5568344831794053], 
             UndirectedEdge[11, 68] -> 
             RGBColor[
              0.6229461957670579, 0.21058134826712724`, 0.42169491634228573`],
              UndirectedEdge[27, 81] -> 
             RGBColor[
              0.4414307993595177, 0.5543994591447239, 0.9500026902294574], 
             UndirectedEdge[36, 61] -> 
             RGBColor[
              0.17912334491775841`, 0.3056003709575509, 0.9335121815526001], 
             UndirectedEdge[28, 59] -> 
             RGBColor[
              0.2655146286535537, 0.39640308768762733`, 0.9384320373569025], 
             UndirectedEdge[8, 30] -> 
             RGBColor[
              0.8665455196590803, 0.4187400277549185, 0.42604144762819984`], 
             UndirectedEdge[34, 82] -> 
             RGBColor[
              0.7532926976672427, 0.4173588996891232, 0.4425043108152338], 
             UndirectedEdge[50, 84] -> 
             RGBColor[
              0.7140851809808935, 0.7717321014835103, 0.87102844943999], 
             UndirectedEdge[57, 88] -> 
             RGBColor[
              0.27128503651838054`, 0.40246815221855037`, 0.9387606535482509],
              UndirectedEdge[6, 53] -> 
             RGBColor[
              0.2901431745630745, 0.4209193221478431, 0.939884756417035], 
             UndirectedEdge[8, 69] -> 
             RGBColor[
              0.6933493129056316, 0.7566729943369539, 0.9479529248561034], 
             UndirectedEdge[69, 99] -> 
             RGBColor[
              0.41359053884055663`, 0.5326530699039465, 0.9475746013045347], 
             UndirectedEdge[81, 84] -> 
             RGBColor[
              0.4886643442635845, 0.5953107817136317, 0.9530123699437607], 
             UndirectedEdge[11, 94] -> 
             RGBColor[
              0.20750449713838193`, 0.3354307614104094, 0.9351284461854125], 
             UndirectedEdge[10, 65] -> 
             RGBColor[
              0.23682752030936433`, 0.3662511179501625, 0.9367983489754745], 
             UndirectedEdge[79, 98] -> 
             RGBColor[
              0.26889413426113584`, 0.39995516235422757`, 0.9386244952017238],
              UndirectedEdge[33, 62] -> 
             RGBColor[
              0.3171356169120182, 0.44536236355291736`, 0.9415657494001773], 
             UndirectedEdge[31, 70] -> 
             RGBColor[
              0.3382626356768291, 0.464409652660651, 0.9428845517476936], 
             UndirectedEdge[31, 32] -> 
             RGBColor[
              0.3463701598777138, 0.472931174642505, 0.9433462632569267], 
             UndirectedEdge[15, 100] -> 
             RGBColor[
              0.28060017483633093`, 0.41159399522924645`, 0.9393154842638007],
              UndirectedEdge[7, 65] -> 
             RGBColor[
              0.26785267018749115`, 0.3984231895202199, 0.9385811980860177], 
             UndirectedEdge[59, 95] -> 
             RGBColor[
              0.430296968658313, 0.5404047867381535, 0.9497463591195126], 
             UndirectedEdge[2, 3] -> 
             RGBColor[
              0.4080096464453409, 0.5252224449857339, 0.947726795683348], 
             UndirectedEdge[48, 88] -> 
             RGBColor[
              0.2730751570306258, 0.404349682377116, 0.9388625982631773], 
             UndirectedEdge[14, 38] -> 
             RGBColor[
              0.5755893914541861, 0.6645818965278997, 0.9606923107205052], 
             UndirectedEdge[44, 45] -> 
             RGBColor[
              0.7810472132422319, 0.8288792862542917, 0.9788111449809456], 
             UndirectedEdge[24, 50] -> 
             RGBColor[
              0.9494254708663976, 0.830833526050487, 0.5187163836071205], 
             UndirectedEdge[38, 62] -> 
             RGBColor[
              0.39912933111578863`, 0.5201274986141865, 0.9466531459358565], 
             UndirectedEdge[4, 50] -> 
             RGBColor[
              0.8896565131257295, 0.5297712369525608, 0.3875321719943988], 
             UndirectedEdge[48, 74] -> 
             RGBColor[
              0.3099201171979624, 0.4380720909673196, 0.941144084481714], 
             UndirectedEdge[40, 100] -> 
             RGBColor[
              0.24447547507013836`, 0.3742896033120748, 0.9372338886849655], 
             UndirectedEdge[19, 95] -> 
             RGBColor[
              0.4261782781667054, 0.536075781891414, 0.949511805789072], 
             UndirectedEdge[19, 79] -> 
             RGBColor[
              0.2547975399437836, 0.38513874795098857`, 0.937821715009393], 
             UndirectedEdge[51, 70] -> 
             RGBColor[
              0.2685220074352297, 0.3995640334659966, 0.9386033031295007], 
             UndirectedEdge[17, 22] -> 
             RGBColor[
              0.6749436759381056, 0.7408142314231896, 0.9479954802017996], 
             UndirectedEdge[59, 99] -> 
             RGBColor[
              0.33916350971304693`, 0.46506273394044173`, 0.9429466124453707],
              UndirectedEdge[20, 63] -> 
             RGBColor[
              0.22006041247387476`, 0.34862782451902463`, 0.9358434869889567],
              UndirectedEdge[56, 89] -> 
             RGBColor[
              0.2431918362429577, 0.37294041751730556`, 0.937160787352731], 
             UndirectedEdge[12, 74] -> 
             RGBColor[
              0.48414329622236674`, 0.5896324439603484, 0.9532112582976568], 
             UndirectedEdge[8, 17] -> 
             RGBColor[
              0.6756356059860984, 0.7413302717200512, 0.9468242231148067], 
             UndirectedEdge[53, 90] -> 
             RGBColor[
              0.3158328098736569, 0.44792075767621997`, 0.941347743143563], 
             UndirectedEdge[21, 72] -> 
             RGBColor[
              0.8553559944534459, 0.3795488746342275, 0.19880393686851044`], 
             UndirectedEdge[48, 73] -> 
             RGBColor[
              0.25430833916142304`, 0.38462456691160657`, 0.9377938557485452],
              UndirectedEdge[8, 49] -> 
             RGBColor[
              0.8679776052374037, 0.8972436267472088, 0.9628476465059921], 
             UndirectedEdge[17, 69] -> 
             RGBColor[
              0.40608263929049154`, 0.5261501046716837, 0.9470962045841795], 
             UndirectedEdge[21, 82] -> 
             RGBColor[
              0.8593787888288114, 0.4104698350030215, 0.20265616930545677`], 
             UndirectedEdge[36, 68] -> 
             RGBColor[
              0.6046525632785056, 0.19135358063836727`, 0.4206531210350667], 
             UndirectedEdge[21, 30] -> 
             RGBColor[
              0.8466374514986924, 0.3125343329941077, 0.1904550502888525], 
             UndirectedEdge[56, 64] -> 
             RGBColor[
              0.2634347031054928, 0.3942169540617188, 0.9383135886739146], 
             UndirectedEdge[48, 64] -> 
             RGBColor[
              0.27099128981714793`, 0.40215940581093823`, 0.9387439251081751],
              UndirectedEdge[46, 59] -> 
             RGBColor[
              0.27301827158802383`, 0.40428989217019595`, 0.9388593587213756],
              UndirectedEdge[46, 79] -> 
             RGBColor[
              0.25699221406840955`, 0.38744548960634695`, 0.937946698454061], 
             UndirectedEdge[9, 86] -> 
             RGBColor[
              0.9724088099661622, 0.9182534312723682, 0.5190969464320642], 
             UndirectedEdge[64, 91] -> 
             RGBColor[
              0.26939944622333534`, 0.400486277265128, 0.938653271970429], 
             UndirectedEdge[1, 19] -> 
             RGBColor[
              0.2624065565834054, 0.39313630687875045`, 0.9382550372504881], 
             UndirectedEdge[5, 69] -> 
             RGBColor[
              0.3370682698872072, 0.4609733107913742, 0.942896391026308], 
             UndirectedEdge[36, 92] -> 
             RGBColor[
              0.18278950597928542`, 0.3094537386812527, 0.9337209640014548], 
             UndirectedEdge[17, 95] -> 
             RGBColor[
              0.48701029086628944`, 0.5926524000847553, 0.95324564623738], 
             UndirectedEdge[7, 13] -> 
             RGBColor[
              0.293422925234443, 0.42529914882237513`, 0.9400373862831393], 
             UndirectedEdge[11, 61] -> 
             RGBColor[
              0.20656379365058694`, 0.3344420224006909, 0.9350748745134286], 
             UndirectedEdge[66, 83] -> 
             RGBColor[
              0.27310948122008705`, 0.4031355950396065, 0.9389103276117834], 
             UndirectedEdge[27, 37] -> 
             RGBColor[
              0.5341526529828826, 0.6283946851552121, 0.9581776144798929], 
             UndirectedEdge[22, 34] -> 
             RGBColor[
              0.7732191105703109, 0.8223621759763964, 0.955244816729368], 
             UndirectedEdge[6, 90] -> 
             RGBColor[
              0.2824130283207301, 0.41416437715825094`, 0.9393943762190061], 
             UndirectedEdge[71, 77] -> 
             RGBColor[
              0.3842477285736503, 0.5072378024632783, 0.9457049033811559], 
             UndirectedEdge[9, 68] -> 
             RGBColor[
              0.8620067160991126, 0.3710691498257614, 0.2027250463978763], 
             UndirectedEdge[23, 86] -> 
             RGBColor[
              0.990093096424966, 0.9901712550229842, 0.8138465606903063], 
             UndirectedEdge[54, 84] -> 
             RGBColor[
              0.3438756345570892, 0.4669242029109275, 0.9433281476320208], 
             UndirectedEdge[3, 16] -> 
             RGBColor[
              0.26785762869397084`, 0.3988657292848884, 0.9385654677430463], 
             UndirectedEdge[66, 98] -> 
             RGBColor[
              0.3085828474233191, 0.440420352060525, 0.9409304833389149], 
             UndirectedEdge[64, 93] -> 
             RGBColor[
              0.2726343777507507, 0.4038863954069468, 0.938837496535263], 
             UndirectedEdge[2, 29] -> 
             RGBColor[
              0.41847939161663067`, 0.5351656244278226, 0.9483618874203135], 
             UndirectedEdge[50, 81] -> 
             RGBColor[
              0.7659300229628049, 0.8142700526821505, 0.8749860890693137], 
             UndirectedEdge[8, 99] -> 
             RGBColor[
              0.6831435055361634, 0.747833236952314, 0.947302619835162], 
             UndirectedEdge[66, 69] -> 
             RGBColor[
              0.37303197272508415`, 0.4975232784675301, 0.9449902453361887], 
             UndirectedEdge[9, 30] -> 
             RGBColor[
              0.8627054758911135, 0.37644012378557273`, 0.20339417956383254`],
              UndirectedEdge[11, 36] -> 
             RGBColor[
              0.20676013856834535`, 0.33464839335824176`, 0.9350860560660287],
              UndirectedEdge[16, 62] -> 
             RGBColor[
              0.30123789915337096`, 0.4286528542150554, 0.9406603978923882], 
             UndirectedEdge[50, 76] -> 
             RGBColor[
              0.9928483984176775, 0.9905031143387806, 0.7094852523118963], 
             UndirectedEdge[36, 86] -> 
             RGBColor[
              0.5863775807352516, 0.6486800774912771, 0.8459890583878498], 
             UndirectedEdge[60, 71] -> 
             RGBColor[
              0.41038752678537255`, 0.5294238797348146, 0.9474961990184465], 
             UndirectedEdge[43, 54] -> 
             RGBColor[
              0.2507606889125138, 0.3808957615659856, 0.9375918223151481], 
             UndirectedEdge[29, 42] -> 
             RGBColor[
              0.48821367053746006`, 0.5915669704381774, 0.9539966276833514], 
             UndirectedEdge[76, 84] -> 
             RGBColor[
              0.7155827197184571, 0.7715438433702618, 0.7875115331863431], 
             UndirectedEdge[65, 90] -> 
             RGBColor[
              0.26516596283917315`, 0.39603661781002397`, 0.9384121813545784],
              UndirectedEdge[52, 78] -> 
             RGBColor[
              0.9664668529248481, 0.8933481863027279, 0.5077226888807255], 
             UndirectedEdge[25, 65] -> 
             RGBColor[
              0.21906851954430756`, 0.34758528216040546`, 0.9357870001539919],
              UndirectedEdge[45, 52] -> 
             RGBColor[
              0.8611685991001501, 0.8128504925215565, 0.6243159249705089], 
             UndirectedEdge[57, 74] -> 
             RGBColor[
              0.3081299966857172, 0.43619056080875396`, 0.9410421397667876], 
             UndirectedEdge[17, 66] -> 
             RGBColor[
              0.3553182658055509, 0.48218055585062736`, 0.943861543594892], 
             UndirectedEdge[59, 98] -> 
             RGBColor[
              0.28492019178075007`, 0.41679956491807657`, 0.9395371554690384],
              UndirectedEdge[22, 77] -> 
             RGBColor[
              0.6896552593406005, 0.7535566655407491, 0.9489328892872642], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.8792868569891993, 0.5166755297638322, 0.4382425666448041], 
             UndirectedEdge[30, 36] -> 
             RGBColor[
              0.6053513230705064, 0.19672455459817856`, 0.421322254201023], 
             UndirectedEdge[60, 64] -> 
             RGBColor[
              0.37754119325177404`, 0.49877954503386207`, 0.9454836107743141],
              UndirectedEdge[28, 99] -> 
             RGBColor[
              0.3297358504115952, 0.455153666266492, 0.9424097211951252], 
             UndirectedEdge[59, 69] -> 
             RGBColor[
              0.34936931708251506`, 0.4739024913250818, 0.9435969174663121], 
             UndirectedEdge[66, 79] -> 
             RGBColor[
              0.2825788860779602, 0.4130885399401764, 0.93944959620971], 
             UndirectedEdge[7, 81] -> 
             RGBColor[
              0.42699263228672224`, 0.5418938445096457, 0.9490827029907487], 
             UndirectedEdge[26, 100] -> 
             RGBColor[
              0.2326661285681354, 0.3618772313826554, 0.9365613638720389], 
             UndirectedEdge[5, 97] -> 
             RGBColor[
              0.2506036098716818, 0.3807306615346847, 0.9375828768961504], 
             UndirectedEdge[20, 83] -> 
             RGBColor[
              0.22260788034518547`, 0.3513053747705641, 0.9359885615155867], 
             UndirectedEdge[21, 92] -> 
             RGBColor[
              0.5447186986215644, 0.48316840627514634`, 0.5874201581331991], 
             UndirectedEdge[77, 98] -> 
             RGBColor[
              0.35634509739122144`, 0.481789612382238, 0.9439738516723704], 
             UndirectedEdge[13, 84] -> 
             RGBColor[
              0.35509463721130535`, 0.4787160860263612, 0.9439670532361513], 
             UndirectedEdge[83, 97] -> 
             RGBColor[
              0.23740919468950228`, 0.36686249460397324`, 0.9368314744709133],
              UndirectedEdge[4, 24] -> 
             RGBColor[
              0.8617062539165854, 0.4231993393515327, 0.20467498202211704`], 
             UndirectedEdge[7, 85] -> 
             RGBColor[
              0.46422750147449665`, 0.5721227887280222, 0.9520139682890303], 
             UndirectedEdge[10, 40] -> 
             RGBColor[
              0.247557235138606, 0.37752872853890806`, 0.9374093903618093], 
             UndirectedEdge[26, 40] -> 
             RGBColor[
              0.23187934520351416`, 0.3610502721814919, 0.9365165577233654], 
             UndirectedEdge[56, 74] -> 
             RGBColor[
              0.3023635304863073, 0.4301296392181001, 0.9407137480474534], 
             UndirectedEdge[42, 62] -> 
             RGBColor[
              0.5111241958255703, 0.6114109159262558, 0.9554564660957278], 
             UndirectedEdge[4, 36] -> 
             RGBColor[
              0.6189794565108638, 0.30147636010691836`, 0.43437257017428454`],
              UndirectedEdge[2, 33] -> 
             RGBColor[
              0.39248083985044224`, 0.5089006846712906, 0.946842453120579], 
             UndirectedEdge[36, 82] -> 
             RGBColor[
              0.6180926604006254, 0.2946600566070923, 0.4335233732176272], 
             UndirectedEdge[76, 81] -> 
             RGBColor[
              0.7674275617003685, 0.8140817945689018, 0.7914691728156671], 
             UndirectedEdge[27, 43] -> 
             RGBColor[
              0.29647101173303086`, 0.4258330666011419, 0.9403087252832609], 
             UndirectedEdge[61, 67] -> 
             RGBColor[
              0.1802334334437405, 0.3067671443820358, 0.933575399451926], 
             UndirectedEdge[10, 26] -> 
             RGBColor[
              0.235747888636603, 0.36511635660948866`, 0.9367368655488828], 
             UndirectedEdge[63, 83] -> 
             RGBColor[
              0.2214038953287198, 0.3500399101811996, 0.9359199963500353], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.28220392258022686`, 0.41350726570694146`, 0.9393984806790088],
              UndirectedEdge[20, 97] -> 
             RGBColor[
              0.23606571183465724`, 0.3654504089417983, 0.9367549651098346], 
             UndirectedEdge[28, 98] -> 
             RGBColor[
              0.27549253247929834`, 0.40689049724412685`, 0.9390002642187927],
              UndirectedEdge[4, 23] -> 
             RGBColor[
              0.8881231336373401, 0.5291371451280563, 0.4129442383759221], 
             UndirectedEdge[30, 86] -> 
             RGBColor[
              0.8767232503369963, 0.4253067783156288, 0.3629660510561227], 
             UndirectedEdge[27, 54] -> 
             RGBColor[
              0.2966420896530224, 0.4260128803420197, 0.9403184679177174], 
             UndirectedEdge[1, 13] -> 
             RGBColor[
              0.2657389891679791, 0.3966389048135667, 0.9384448143562873], 
             UndirectedEdge[15, 35] -> 
             RGBColor[
              0.3092088271480132, 0.4416635027021466, 0.9409447046902427], 
             UndirectedEdge[56, 73] -> 
             RGBColor[
              0.24675175244976794`, 0.37668211516238714`, 0.9373635193142849],
              UndirectedEdge[16, 29] -> 
             RGBColor[
              0.27832737386526063`, 0.40880890872697706`, 0.9392005594800119],
              UndirectedEdge[53, 65] -> 
             RGBColor[
              0.2728961090815175, 0.40279156279961614`, 0.9389025615526072], 
             UndirectedEdge[6, 25] -> 
             RGBColor[
              0.2363155850258645, 0.36571304150863243`, 0.9367691950184196], 
             UndirectedEdge[68, 92] -> 
             RGBColor[
              0.606965774041018, 0.19378491181580115`, 0.4207848549659031], 
             UndirectedEdge[69, 97] -> 
             RGBColor[
              0.3373316861944994, 0.46125017803189694`, 0.9429113921953187], 
             UndirectedEdge[17, 77] -> 
             RGBColor[
              0.4030805157734533, 0.5235498161723404, 0.9469049119283475], 
             UndirectedEdge[46, 98] -> 
             RGBColor[
              0.2829961754137684, 0.41477730172669547`, 0.9394275855832659], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.34313416867820656`, 0.4716273033094493, 0.9430851836999117], 
             UndirectedEdge[17, 55] -> 
             RGBColor[
              0.3185371640353287, 0.44477145007049096`, 0.9417211396250476], 
             UndirectedEdge[2, 78] -> 
             RGBColor[
              0.7554647233160532, 0.8052075509695305, 0.8504886604600671], 
             UndirectedEdge[6, 35] -> 
             RGBColor[
              0.2796014780341359, 0.41120925954445625`, 0.9392342625895005], 
             UndirectedEdge[95, 99] -> 
             RGBColor[
              0.49451819041635453`, 0.5991553653170181, 0.9537240429577352], 
             UndirectedEdge[66, 99] -> 
             RGBColor[
              0.36282616535561596`, 0.48868352108289015`, 0.9443399403152473],
              UndirectedEdge[31, 39] -> 
             RGBColor[
              0.34736341039793694`, 0.47397514391497986`, 0.943402827404671], 
             UndirectedEdge[69, 71] -> 
             RGBColor[
              0.38724985209068863`, 0.5098380909626216, 0.9458961960369879], 
             UndirectedEdge[64, 89] -> 
             RGBColor[
              0.2647678240416204, 0.39561814869033823`, 0.9383895079390514], 
             UndirectedEdge[40, 53] -> 
             RGBColor[
              0.2836258239107592, 0.41406917338836174`, 0.9395136029389419], 
             UndirectedEdge[1, 27] -> 
             RGBColor[
              0.3002303093342801, 0.42978432673328937`, 0.9405228117202697], 
             UndirectedEdge[41, 48] -> 
             RGBColor[
              0.34329321321312134`, 0.4669781893550724, 0.9432705886491298], 
             UndirectedEdge[57, 70] -> 
             RGBColor[
              0.26485491336994227`, 0.39570968509618687`, 0.9383944675474621],
              UndirectedEdge[39, 44] -> 
             RGBColor[
              0.5365081779106845, 0.6268880178985887, 0.9593203806489492], 
             UndirectedEdge[6, 15] -> 
             RGBColor[
              0.286330742124025, 0.4176171847875644, 0.9396418315932203], 
             UndirectedEdge[6, 40] -> 
             RGBColor[
              0.2502060423578324, 0.3803127928703927, 0.9375602360143851], 
             UndirectedEdge[17, 59] -> 
             RGBColor[
              0.33165561016298184`, 0.45855976870817894`, 0.9424682157250155],
              UndirectedEdge[56, 91] -> 
             RGBColor[
              0.2478234584246726, 0.37780854609209535`, 0.9374245513841087], 
             UndirectedEdge[5, 59] -> 
             RGBColor[
              0.26264124075969747`, 0.39338297482786955`, 0.9382684021671439],
              UndirectedEdge[20, 58] -> 
             RGBColor[
              0.22266134542622565`, 0.3513615699606193, 0.9359916062728575], 
             UndirectedEdge[17, 19] -> 
             RGBColor[
              0.32753691967137427`, 0.45423076386143946`, 0.9422336623945751],
              UndirectedEdge[3, 38] -> 
             RGBColor[
              0.36574906065638857`, 0.4903403736840195, 0.9445582157865146], 
             UndirectedEdge[1, 17] -> 
             RGBColor[
              0.32323856928298944`, 0.4497129250720918, 0.941988877698796], 
             UndirectedEdge[2, 42] -> 
             RGBColor[
              0.5864694187639945, 0.6749492370446291, 0.9607331698161294], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.44521446884155214`, 0.5537197588039671, 0.950811098924118], 
             UndirectedEdge[48, 56] -> 
             RGBColor[
              0.2494153020184852, 0.3794816746379056, 0.9375152045218548], 
             UndirectedEdge[86, 94] -> 
             RGBColor[
              0.5871219393052882, 0.6494624455434448, 0.8460314485072336], 
             UndirectedEdge[23, 30] -> 
             RGBColor[
              0.8744950001969827, 0.4243853396193167, 0.39989392240266064`], 
             UndirectedEdge[30, 82] -> 
             RGBColor[
              0.8247378083530608, 0.19115121194417384`, 0.17132225925723651`],
              UndirectedEdge[60, 74] -> 
             RGBColor[
              0.4164700206325886, 0.5346922301902434, 0.9478837701478531], 
             UndirectedEdge[10, 90] -> 
             RGBColor[
              0.2797642211015037, 0.41138031282676635`, 0.9392435305664304], 
             UndirectedEdge[49, 69] -> 
             RGBColor[
              0.5984246385417968, 0.6820634596988412, 0.9631196279753649], 
             UndirectedEdge[25, 100] -> 
             RGBColor[
              0.23058501773817044`, 0.3596898519503145, 0.9364428476890001], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.23295897687627548`, 0.36218503352216574`, 0.9365780411499574],
              UndirectedEdge[31, 51] -> 
             RGBColor[
              0.33046646407782415`, 0.4562153820042676, 0.9424405713085325], 
             UndirectedEdge[37, 50] -> 
             RGBColor[
              0.8586518765861698, 0.8882652786926387, 0.8831610133197494], 
             UndirectedEdge[6, 10] -> 
             RGBColor[
              0.25407458579092124`, 0.3843788772983895, 0.9377805438399023], 
             UndirectedEdge[69, 77] -> 
             RGBColor[
              0.4207942226929865, 0.5388925387892431, 0.9480336136696441], 
             UndirectedEdge[12, 96] -> 
             RGBColor[
              0.4452662078752948, 0.5537741398088749, 0.9508140453855485], 
             UndirectedEdge[12, 41] -> 
             RGBColor[
              0.5175163922375255, 0.6185385423481014, 0.9553377624650727], 
             UndirectedEdge[89, 93] -> 
             RGBColor[
              0.25239151088821565`, 0.3826098588625336, 0.9376846952140795], 
             UndirectedEdge[37, 81] -> 
             RGBColor[
              0.6332310398688609, 0.7118439589227601, 0.9651449338235201], 
             UndirectedEdge[14, 24] -> 
             RGBColor[
              0.8132324483478965, 0.7256778621369495, 0.6085269751651416], 
             UndirectedEdge[52, 67] -> 
             RGBColor[
              0.560139632974118, 0.5514847252323705, 0.6016081426491302], 
             UndirectedEdge[23, 27] -> 
             RGBColor[
              0.6645515668442425, 0.7298696411778459, 0.9061368692979717], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.2386756834212212, 0.36819365456103337`, 0.9369035991305825], 
             UndirectedEdge[23, 81] -> 
             RGBColor[
              0.7636299537302207, 0.8133189149453938, 0.9131041886415987], 
             UndirectedEdge[88, 96] -> 
             RGBColor[
              0.2871462971513761, 0.419139342805837, 0.9396639288766677], 
             UndirectedEdge[77, 95] -> 
             RGBColor[
              0.5017218742687843, 0.6053948342023149, 0.9541830553228445], 
             UndirectedEdge[74, 91] -> 
             RGBColor[
              0.3083282736041498, 0.43639896242150933`, 0.941053431343968], 
             UndirectedEdge[7, 100] -> 
             RGBColor[
              0.27936916838135406`, 0.4105277593101289, 0.939237045621026], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.3593964815136068, 0.4839037453450634, 0.9441876459561919], 
             UndirectedEdge[6, 100] -> 
             RGBColor[
              0.2509928257224536, 0.38113975207155615`, 0.9376050421630586], 
             UndirectedEdge[19, 55] -> 
             RGBColor[
              0.2577051513357447, 0.38819483187714965`, 0.9379872991767397], 
             UndirectedEdge[17, 28] -> 
             RGBColor[
              0.3222279508615301, 0.4486507010342292, 0.9419313244747699], 
             UndirectedEdge[64, 96] -> 
             RGBColor[
              0.28506242993789815`, 0.4169490662396592, 0.9395452557216655], 
             UndirectedEdge[67, 68] -> 
             RGBColor[
              0.605392622295827, 0.19213142958802387`, 0.42069526630128395`], 
             UndirectedEdge[22, 87] -> 
             RGBColor[
              0.875317687150646, 0.9030022552400158, 0.9648194594818615], 
             UndirectedEdge[42, 44] -> 
             RGBColor[
              0.7173501625148713, 0.7791186661105619, 0.9724624182472246], 
             UndirectedEdge[70, 96] -> 
             RGBColor[
              0.28071617400293775`, 0.4123808756834735, 0.9392977428758789], 
             UndirectedEdge[64, 88] -> 
             RGBColor[
              0.2870945581176334, 0.41908496180092925`, 0.9396609824152371], 
             UndirectedEdge[26, 65] -> 
             RGBColor[
              0.2211496303742725, 0.34977266159274634`, 0.9359055163370308], 
             UndirectedEdge[2, 14] -> 
             RGBColor[
              0.6178499772431384, 0.6994639678296142, 0.9638608906173386], 
             UndirectedEdge[11, 72] -> 
             RGBColor[
              0.6323634985138122, 0.2829668638670583, 0.43071293608789996`], 
             UndirectedEdge[67, 86] -> 
             RGBColor[
              0.5874876692612337, 0.649846850915762, 0.8460522762871756], 
             UndirectedEdge[40, 90] -> 
             RGBColor[
              0.27589567766841483`, 0.4073142283987696, 0.939023222740913], 
             UndirectedEdge[27, 84] -> 
             RGBColor[
              0.38958595737760626`, 0.5118615079460839, 0.9460450506001336], 
             UndirectedEdge[13, 43] -> 
             RGBColor[
              0.26197969156672996`, 0.39268764468141926`, 0.9382307279192786],
              UndirectedEdge[52, 72] -> 
             RGBColor[
              0.8672097691003393, 0.4267465695001542, 0.20835218187708365`], 
             UndirectedEdge[10, 53] -> 
             RGBColor[
              0.28749436734384803`, 0.4181352578163585, 0.9397339107644591], 
             UndirectedEdge[15, 40] -> 
             RGBColor[
              0.2798133914717097, 0.41076703602808307`, 0.9392706781151272], 
             UndirectedEdge[21, 68] -> 
             RGBColor[
              0.8459386917066916, 0.3071633590342964, 0.18978591712289627`], 
             UndirectedEdge[28, 83] -> 
             RGBColor[
              0.24001916627606623`, 0.36960574022320836`, 0.9369801084916611],
              UndirectedEdge[54, 100] -> 
             RGBColor[
              0.24809701263363243`, 0.37809606891005076`, 0.9374401298916217],
              UndirectedEdge[47, 96] -> 
             RGBColor[
              0.280167857490329, 0.4118045602634469, 0.9392665170616474], 
             UndirectedEdge[47, 51] -> 
             RGBColor[
              0.26797369092262097`, 0.39898771804597, 0.9385720773152693], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.3409913926021096, 0.4697713383713912, 0.9429486479031253], 
             UndirectedEdge[39, 45] -> 
             RGBColor[
              0.5390587638079978, 0.6288805549867408, 0.959574599214613], 
             UndirectedEdge[58, 97] -> 
             RGBColor[
              0.23746265977054243`, 0.3669186897940284, 0.936834519228184], 
             UndirectedEdge[31, 45] -> 
             RGBColor[
              0.5919024457294845, 0.6759664122706829, 0.9628935917366674], 
             UndirectedEdge[6, 26] -> 
             RGBColor[
              0.23839669585582945`, 0.3679004209409733, 0.9368877112014585], 
             UndirectedEdge[41, 91] -> 
             RGBColor[
              0.34170136961930875`, 0.46530506080926215`, 0.9431799355113838],
              UndirectedEdge[8, 22] -> 
             RGBColor[
              0.9622103495532457, 0.9713371210884598, 0.9488522004737234], 
             UndirectedEdge[46, 95] -> 
             RGBColor[
              0.42837295229133143`, 0.5383825235467723, 0.9496367892337401], 
             UndirectedEdge[66, 95] -> 
             RGBColor[
              0.4539596243008821, 0.5640255738806018, 0.9511396869893891], 
             UndirectedEdge[23, 37] -> 
             RGBColor[
              0.8563518073535856, 0.887314140955882, 0.9212791128920343], 
             UndirectedEdge[10, 100] -> 
             RGBColor[
              0.2483440185032272, 0.37835568774007156`, 0.9374541965104828], 
             UndirectedEdge[5, 79] -> 
             RGBColor[
              0.24661518324008325`, 0.37653857226402054`, 0.9373557418998293],
              UndirectedEdge[38, 42] -> 
             RGBColor[
              0.5442088329750422, 0.6400671657429147, 0.9575645899192962], 
             UndirectedEdge[40, 54] -> 
             RGBColor[
              0.24731022926901122`, 0.37726910970888733`, 0.9373953237429482],
              UndirectedEdge[32, 45] -> 
             RGBColor[
              0.5380655132877746, 0.6278365857142659, 0.9595180350668688], 
             UndirectedEdge[41, 60] -> 
             RGBColor[
              0.44984311664774745`, 0.5635983285779962, 0.9500102743152689], 
             UndirectedEdge[88, 91] -> 
             RGBColor[
              0.2714833134368132, 0.40267655383130574`, 0.9387719451254313], 
             UndirectedEdge[47, 57] -> 
             RGBColor[
              0.2643065968573336, 0.3951333696761603, 0.9383632417332306], 
             UndirectedEdge[27, 85] -> 
             RGBColor[
              0.4786656685472922, 0.5846284033631004, 0.952933955527739], 
             UndirectedEdge[69, 95] -> 
             RGBColor[
              0.5047239977858227, 0.6079951227016581, 0.9543743479786766], 
             UndirectedEdge[36, 72] -> 
             RGBColor[
              0.6140698660252599, 0.26373909623829833`, 0.4296711407806809], 
             UndirectedEdge[6, 65] -> 
             RGBColor[
              0.23947632752859074`, 0.3690351822816471, 0.9369491946280504], 
             UndirectedEdge[49, 77] -> 
             RGBColor[
              0.5954225150247585, 0.679463171199498, 0.9629283353195328], 
             UndirectedEdge[2, 62] -> 
             RGBColor[
              0.441389916904741, 0.555009569915901, 0.9498217258326898], 
             UndirectedEdge[22, 66] -> 
             RGBColor[
              0.6418930093726982, 0.712187405219036, 0.9458895209538087], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.37246108295649283`, 0.49696932160080975`, 0.9449560466299856],
              UndirectedEdge[73, 88] -> 
             RGBColor[
              0.2704116074619085, 0.40155012290159753`, 0.9387109130556073], 
             UndirectedEdge[8, 21] -> 
             RGBColor[
              0.9330401773606567, 0.8125446192441054, 0.5943013473777097], 
             UndirectedEdge[31, 75] -> 
             RGBColor[
              0.3329280335215753, 0.45880264756216715`, 0.9425807540467885], 
             UndirectedEdge[4, 30] -> 
             RGBColor[
              0.8319952731283586, 0.24693526644845676`, 0.17827201572219592`],
              UndirectedEdge[48, 91] -> 
             RGBColor[
              0.2553800451363277, 0.3857509978413148, 0.9378548878183692], 
             UndirectedEdge[19, 28] -> 
             RGBColor[
              0.26139593816194606`, 0.39207408284088785`, 0.938197484026462], 
             UndirectedEdge[28, 66] -> 
             RGBColor[
              0.28917728429612277`, 0.42002387483007575`, 0.9398253652267791],
              UndirectedEdge[3, 29] -> 
             RGBColor[
              0.30975389821880644`, 0.4418401783792823, 0.9409902535505699], 
             UndirectedEdge[22, 82] -> 
             RGBColor[
              0.8788255702905374, 0.5163315028992579, 0.4390234047027993], 
             UndirectedEdge[49, 82] -> 
             RGBColor[
              0.8160037407466428, 0.4669358400050904, 0.44835370205764513`], 
             UndirectedEdge[23, 84] -> 
             RGBColor[
              0.7117851117483094, 0.7707809637467538, 0.909146549012275], 
             UndirectedEdge[65, 100] -> 
             RGBColor[
              0.2337457602408967, 0.3630119927233292, 0.9366228472986309], 
             UndirectedEdge[53, 85] -> 
             RGBColor[
              0.46927094036852307`, 0.5764911620074185, 0.9523353317556198], 
             UndirectedEdge[59, 97] -> 
             RGBColor[
              0.26290465706698973`, 0.3936598420683923, 0.9382834033361547], 
             UndirectedEdge[17, 98] -> 
             RGBColor[
              0.34163351398872654`, 0.46904717826467845`, 0.9430364425869058],
              UndirectedEdge[61, 68] -> 
             RGBColor[0.6045216666666666, 0.191216, 0.4206456666666667], 
             UndirectedEdge[28, 55] -> 
             RGBColor[
              0.2523961825259005, 0.38261476904993935`, 0.9376849612569346], 
             UndirectedEdge[9, 36] -> 
             RGBColor[
              0.5653509190664274, 0.575380095696193, 0.6066312511494145], 
             UndirectedEdge[20, 59] -> 
             RGBColor[
              0.24810334272267293`, 0.37810272223498315`, 0.9374404903808281],
              UndirectedEdge[48, 57] -> 
             RGBColor[
              0.25518176821789507`, 0.38554259622855935`, 0.9378435962411888],
              UndirectedEdge[1, 46] -> 
             RGBColor[
              0.26460123070803143`, 0.39544304853410883`, 0.9383800206951561],
              UndirectedEdge[5, 66] -> 
             RGBColor[
              0.2863038964022665, 0.41700376197031797`, 0.9396617300370205], 
             UndirectedEdge[64, 74] -> 
             RGBColor[
              0.32393951828497003`, 0.45280737039113284`, 0.9419424686337738],
              UndirectedEdge[55, 79] -> 
             RGBColor[
              0.24579778430773802`, 0.37567943416004, 0.9373091922398655], 
             UndirectedEdge[32, 51] -> 
             RGBColor[
              0.27662953163611426`, 0.40808555544785063`, 0.9390650146387339],
              UndirectedEdge[64, 73] -> 
             RGBColor[
              0.26832774024843065`, 0.39935984633541977`, 0.938592239900605], 
             UndirectedEdge[35, 38] -> 
             RGBColor[
              0.3673467656616922, 0.49201966294494187`, 0.9446492027229738], 
             UndirectedEdge[71, 87] -> 
             RGBColor[
              0.5699101563836958, 0.656683392162545, 0.9615914735757531], 
             UndirectedEdge[82, 87] -> 
             RGBColor[
              0.8213584153874661, 0.47111895253153613`, 0.44888740598356275`],
              UndirectedEdge[5, 77] -> 
             RGBColor[
              0.33406614637016885`, 0.458373022292031, 0.9427050983704759], 
             UndirectedEdge[57, 64] -> 
             RGBColor[
              0.2692011693049027, 0.4002778756523726, 0.9386419803932486], 
             UndirectedEdge[63, 97] -> 
             RGBColor[
              0.23486172681819156`, 0.36418494435243376`, 0.9366863999442832],
              UndirectedEdge[41, 93] -> 
             RGBColor[
              0.34493630114672413`, 0.468705178951081, 0.9433641600762177], 
             UndirectedEdge[9, 61] -> 
             RGBColor[
              0.565154574148669, 0.575173724738642, 0.6066200695968145], 
             UndirectedEdge[17, 46] -> 
             RGBColor[
              0.32973159379600026`, 0.45653750551679784`, 0.942358645839243], 
             UndirectedEdge[25, 54] -> 
             RGBColor[
              0.2334197719370433, 0.36266935834712705`, 0.9366042827469828], 
             UndirectedEdge[59, 77] -> 
             RGBColor[
              0.3463671935654768, 0.47130220282573854`, 0.9434056248104801], 
             UndirectedEdge[66, 77] -> 
             RGBColor[
              0.3700298492080458, 0.49492298996818684`, 0.9447989526803566], 
             UndirectedEdge[7, 27] -> 
             RGBColor[
              0.327914245400744, 0.45844457074209777`, 0.9421153836471216], 
             UndirectedEdge[61, 92] -> 
             RGBColor[
              0.182593161061527, 0.30924736772370176`, 0.9337097824488547], 
             UndirectedEdge[77, 87] -> 
             RGBColor[
              0.6034545269859937, 0.6857378399891666, 0.9637288912084094], 
             UndirectedEdge[28, 79] -> 
             RGBColor[
              0.24948857113393946`, 0.3795586851237783, 0.937519377089588], 
             UndirectedEdge[5, 28] -> 
             RGBColor[
              0.25321358145824574`, 0.3834739071539198, 0.9377315109168982], 
             UndirectedEdge[56, 88] -> 
             RGBColor[
              0.26551857031897064`, 0.39640723062789657`, 0.9384322618289168],
              UndirectedEdge[25, 26] -> 
             RGBColor[
              0.21798888787154624`, 0.3464505208197316, 0.9357255167274], 
             UndirectedEdge[9, 67] -> 
             RGBColor[
              0.5664610075924095, 0.5765468691206779, 0.6066944690487404], 
             UndirectedEdge[32, 44] -> 
             RGBColor[
              0.5355149273904612, 0.6258440486261139, 0.959263816501205], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.5412488824777958, 0.4795214095089955, 0.5872225572369445], 
             UndirectedEdge[79, 83] -> 
             RGBColor[
              0.23342076805790374`, 0.3626704053333091, 0.9366043394745922], 
             UndirectedEdge[60, 93] -> 
             RGBColor[
              0.3651648800983693, 0.48577125520605746`, 0.9447787980493423], 
             UndirectedEdge[5, 63] -> 
             RGBColor[
              0.2345983105108993, 0.3639080771119111, 0.9366713987752724], 
             UndirectedEdge[19, 66] -> 
             RGBColor[
              0.2944862531059669, 0.425603937657286, 0.9401277031465842], 
             UndirectedEdge[8, 86] -> 
             RGBColor[
              0.9781688756181125, 0.981703287226387, 0.853067848528615], 
             UndirectedEdge[4, 37] -> 
             RGBColor[
              0.8011905243964335, 0.4614871744463005, 0.447638068497203], 
             UndirectedEdge[9, 92] -> 
             RGBColor[
              0.5688207352101959, 0.5790270924623439, 0.606828852045669], 
             UndirectedEdge[3, 42] -> 
             RGBColor[
              0.4777439253661703, 0.5816237909960889, 0.9533615359463858], 
             UndirectedEdge[7, 90] -> 
             RGBColor[
              0.31078937097963055`, 0.4435523843968237, 0.9410263796769736], 
             UndirectedEdge[35, 62] -> 
             RGBColor[
              0.3342621285122205, 0.46336341312828305`, 0.9425410788994055], 
             UndirectedEdge[20, 79] -> 
             RGBColor[
              0.2320772852030587, 0.3612583196711341, 0.9365278301135136], 
             UndirectedEdge[31, 78] -> 
             RGBColor[
              0.6972006995541824, 0.7564641060518543, 0.846300355646884], 
             UndirectedEdge[13, 81] -> 
             RGBColor[
              0.40693947919321677`, 0.5212540372250012, 0.947924692865475], 
             UndirectedEdge[18, 80] -> 
             RGBColor[
              0.2419836729170215, 0.3716705612597674, 0.9370919842386365], 
             UndirectedEdge[90, 100] -> 
             RGBColor[
              0.27668246103303606`, 0.408141187599933, 0.9390680288895865], 
             UndirectedEdge[67, 92] -> 
             RGBColor[
              0.1838995945052675, 0.31062051210573755`, 0.9337841819007806], 
             UndirectedEdge[55, 66] -> 
             RGBColor[
              0.28548649746992133`, 0.41614462386633744`, 0.9396151803770567],
              UndirectedEdge[89, 91] -> 
             RGBColor[
              0.24915657936080024`, 0.3792097407207148, 0.9375004706492456], 
             UndirectedEdge[46, 55] -> 
             RGBColor[
              0.25989982546037066`, 0.390501573532508, 0.9381122826214077], 
             UndirectedEdge[41, 64] -> 
             RGBColor[
              0.3573126143001289, 0.48171346877888566`, 0.9440689728011896], 
             UndirectedEdge[28, 46] -> 
             RGBColor[
              0.2635906122865721, 0.39438082449624623`, 0.93832246747113], 
             UndirectedEdge[35, 53] -> 
             RGBColor[
              0.3130212595870627, 0.4449656400624253, 0.9411876295140573], 
             UndirectedEdge[35, 90] -> 
             RGBColor[
              0.3052911133447183, 0.4382106950728331, 0.9406972493160285], 
             UndirectedEdge[5, 58] -> 
             RGBColor[
              0.23719924346325016`, 0.36664182255350575`, 0.9368195180591732],
              UndirectedEdge[76, 85] -> 
             RGBColor[
              0.8046624308881429, 0.8443107387872784, 0.7944004381139487], 
             UndirectedEdge[34, 77] -> 
             RGBColor[
              0.5013559504056586, 0.6050977607255472, 0.9541542484559159], 
             UndirectedEdge[49, 71] -> 
             RGBColor[
              0.5618781444224608, 0.6504087233728764, 0.9607909176868766]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 25 -> 
             RGBColor[
              0.21590777704158132`, 0.3442631413873908, 0.9356070005443611], 
             55 -> RGBColor[
              0.2487053956996991, 0.3787355180862011, 0.9374747764072122], 90 -> 
             RGBColor[
              0.30810266363131256`, 0.4411658126866278, 0.9408573629455341], 
             27 -> RGBColor[
              0.3423524124735395, 0.470950185377176, 0.9430353708858302], 15 -> 
             RGBColor[
              0.3159380912379023, 0.44807142794525473`, 0.9413522736939626], 
             98 -> RGBColor[
              0.2948980956064947, 0.4272869744745761, 0.9401053823309286], 38 -> 
             RGBColor[
              0.43221396826526043`, 0.5487837484308453, 0.9487612697594249], 
             99 -> RGBColor[
              0.40338473147108844`, 0.5238133125193064, 0.9469242962835934], 
             71 -> RGBColor[
              0.3507033579713525, 0.4781833546366567, 0.9435674857484997], 41 -> 
             RGBColor[
              0.4296145376961023, 0.5465322523230198, 0.9485956363421444], 75 -> 
             RGBColor[
              0.26564897472372695`, 0.3965442939254123, 0.9384396881668516], 
             64 -> RGBColor[
              0.2850106909041555, 0.4168946852347515, 0.9395423092602349], 63 -> 
             RGBColor[
              0.21885642745740908`, 0.34736235992966014`, 0.9357749218234052],
              85 -> RGBColor[
              0.6149789246210449, 0.6983066213490248, 0.9628325401696478], 3 -> 
             RGBColor[
              0.29928415304751665`, 0.4318969989371937, 0.9403551618136042], 
             86 -> RGBColor[
              0.9934354716349865, 0.9915534130674525, 0.7584547536704994], 94 -> 
             RGBColor[
              0.18080840697558995`, 0.30737147801943704`, 0.9336081433439677],
              61 -> RGBColor[0.178927, 0.305394, 0.933501], 84 -> 
             RGBColor[
              0.4368195022816731, 0.5527728305149917, 0.9490547303144369], 76 -> 
             RGBColor[
              0.9943459371552411, 0.990314856225532, 0.6259683360582495], 21 -> 
             RGBColor[
              0.9031780751200748, 0.6532360771028892, 0.2409217513686888], 87 -> 
             RGBColor[
              0.789116954796039, 0.8351834296884333, 0.9796154614030067], 95 -> 
             RGBColor[
              0.5856516493616206, 0.6744974181147299, 0.9605237896318769], 72 -> 
             RGBColor[
              0.8314449541201315, 0.24270527339989661`, 0.17774502961842129`],
              42 -> RGBColor[
              0.6562036976848239, 0.731350583054984, 0.9663679100791674], 66 -> 
             RGBColor[
              0.32226759924014353`, 0.45355372964647384`, 0.9417555843469012],
              1 -> RGBColor[
              0.2581082061950206, 0.38861846808940276`, 0.9380102525547092], 
             24 -> RGBColor[
              0.9075000820526815, 0.6709756796489449, 0.2444305986486977], 54 -> 
             RGBColor[
              0.2509317668325053, 0.3810755753068633, 0.9376015649496046], 4 -> 
             RGBColor[
              0.8388093398485373, 0.29931116920282663`, 0.1847971737088267], 
             7 -> RGBColor[
              0.3134760783279485, 0.4459389561070196, 0.9411953964084129], 
             100 -> RGBColor[
              0.24526225843475957`, 0.3751165625132382, 0.937278694833639], 
             12 -> RGBColor[
              0.6054182467789488, 0.6905448323731828, 0.9620798885880011], 65 -> 
             RGBColor[
              0.2222292620470338, 0.35090742293342014`, 0.9359669997636226], 
             8 -> RGBColor[
              0.9629022796012385, 0.9718531613853215, 0.9476809433867306], 57 -> 
             RGBColor[
              0.25339164770564987`, 0.38366106606999373`, 0.9377416515262625],
              74 -> RGBColor[
              0.3628683456657846, 0.48872005554751413`, 0.9443426280073127], 
             37 -> RGBColor[
              0.7259528934922258, 0.7858391849332483, 0.9733198580739556], 43 -> 
             RGBColor[
              0.25058961099252225`, 0.3807159478251078, 0.9375820796806917], 
             39 -> RGBColor[
              0.2945197284764503, 0.42688928663103776`, 0.9400838348826166], 
             58 -> RGBColor[
              0.22405829336211083`, 0.3528298508128494, 0.9360711603912069], 
             11 -> RGBColor[
              0.23420058730117388`, 0.3634900448013817, 0.9366487490268572], 
             51 -> RGBColor[
              0.26072583583622466`, 0.3913697628096132, 0.9381593226903397], 
             48 -> RGBColor[
              0.2569718887301403, 0.38742412638712503`, 0.9379455409561153], 
             20 -> RGBColor[
              0.22126439749034046`, 0.3498932891083892, 0.9359120521545081], 
             33 -> RGBColor[
              0.26822653985771944`, 0.399253478308307, 0.9385864766880666], 
             45 -> RGBColor[
              0.7835977991395453, 0.8308718233424438, 0.9790653635466094], 23 -> 
             RGBColor[
              0.9867507212149456, 0.9887890969785158, 0.869238367710113], 22 -> 
             RGBColor[
              0.9615184195052529, 0.9708210807915982, 0.9500234575607163], 2 -> 
             RGBColor[
              0.5167351398431651, 0.6185478910342742, 0.9550984295530915], 60 -> 
             RGBColor[
              0.4700716955993926, 0.5806644048329727, 0.9514249122883933], 16 -> 
             RGBColor[
              0.23643110434042502`, 0.36583445963258315`, 0.9367757736724883],
              79 -> RGBColor[
              0.24289017291577697`, 0.372623350233879, 0.937143608072519], 89 -> 
             RGBColor[
              0.24452495717908534`, 0.374341612145925, 0.9372367066178678], 
             36 -> RGBColor[
              0.17931968983551683`, 0.3058067419151018, 0.9335233631052001], 
             52 -> RGBColor[
              0.938739399060755, 0.7948291617006693, 0.26956648639440833`], 
             32 -> RGBColor[
              0.2925332274360039, 0.424801348086088, 0.9399707065871281], 31 -> 
             RGBColor[
              0.40020709231942364`, 0.521061001198922, 0.9467218199267253], 
             68 -> RGBColor[0.817319, 0.134127, 0.164218], 73 -> 
             RGBColor[
              0.2516447895927058, 0.3818250074360881, 0.9376421705409753], 82 -> 
             RGBColor[
              0.8374791456831797, 0.2890867139530876, 0.18352337827384074`], 
             35 -> RGBColor[
              0.30247956305812407`, 0.4352555774590384, 0.9405371356865229], 
             88 -> RGBColor[
              0.28917842533111127`, 0.421275238367107, 0.9397796555702393], 
             50 -> RGBColor[
              0.9913508596801138, 0.9906913724520291, 0.7930021685655431], 19 -> 
             RGBColor[
              0.2667049069717902, 0.39765414566809815`, 0.9384998219462671], 
             17 -> RGBColor[
              0.3883689323709583, 0.5108073820547808, 0.9459675028428829], 96 -> 
             RGBColor[
              0.2851141689716408, 0.417003447244567, 0.939548202183096], 14 -> 
             RGBColor[
              0.7189648146431117, 0.780380044624954, 0.9726233516815856], 5 -> 
             RGBColor[
              0.2503401935643895, 0.38045379429416204`, 0.9375678757271396], 
             34 -> 
             RGBColor[
              0.5849198016353689, 0.6739032711611944, 0.9604661758980197], 97 -> 
             RGBColor[
              0.25086702617897405`, 0.38100752877520744`, 0.9375978780651611],
              93 -> RGBColor[
              0.26025806459734596`, 0.3908781055791422, 0.9381326838102911], 
             81 -> RGBColor[
              0.5405091862454959, 0.6378487329122717, 0.9569700095730845], 69 -> 
             RGBColor[
              0.42379634621002477`, 0.5414928272885864, 0.9482249063254762], 
             9 -> RGBColor[
              0.9513821482973379, 0.8449534494772841, 0.27973913919362886`], 
             13 -> RGBColor[
              0.2733697721409376, 0.40465934153773064`, 0.9388793761578655], 
             30 -> RGBColor[
              0.8183671396880012, 0.14218346093971695`, 0.1652216997489344], 
             59 -> RGBColor[
              0.2749422879550054, 0.4063121553615771, 0.9389689286071481], 28 -> 
             RGBColor[
              0.25608696935210196`, 0.3864940200136776, 0.9378951461066569], 
             80 -> RGBColor[
              0.26918119100492044`, 0.4002568771923939, 0.9386408426586199], 
             47 -> RGBColor[
              0.27522154600901727`, 0.40660567328232683`, 0.9389848319401988],
              62 -> RGBColor[
              0.3660446939663169, 0.4914712487975277, 0.9445450221122881], 77 -> 
             RGBColor[
              0.4177920991759482, 0.5362922502898999, 0.947842321013812], 78 -> 
             RGBColor[
              0.9941943067889412, 0.9918672109047867, 0.7458788913670427], 40 -> 
             RGBColor[
              0.24368869170551716`, 0.37346264411091135`, 0.937189082536292], 
             67 -> RGBColor[
              0.181539866887481, 0.30814028876407157`, 0.9336497989038519], 
             56 -> RGBColor[
              0.24185871530683006`, 0.3715392228886861, 0.9370848680875943], 
             10 -> RGBColor[
              0.25142577857169485`, 0.38159481296690484`, 0.9376296981873266],
              53 -> RGBColor[
              0.3235629561160013, 0.45467570266581214`, 0.9418381233415918], 
             26 -> RGBColor[
              0.2200699987015112, 0.3486379002520725, 0.9358440329104389], 18 -> 
             RGBColor[
              0.21478615482912253`, 0.34308424532714094`, 0.935543125818653], 
             29 -> RGBColor[
              0.32022364339009624`, 0.4517833578213709, 0.9416253452875354], 
             92 -> RGBColor[
              0.18625932212305402`, 0.3131007354474035, 0.9339185648977094], 
             46 -> 
             RGBColor[
              0.2710942552210422, 0.40226762897881485`, 0.9387497888356031], 
             49 -> RGBColor[
              0.773052930873569, 0.822634092109096, 0.9780143496252536], 83 -> 
             RGBColor[
              0.2239513632000305, 0.3527174604327391, 0.9360650708766655], 70 -> 
             RGBColor[
              0.27631817903423467`, 0.40775830412238, 0.9390472835686617], 44 -> 
             RGBColor[
              0.7784966273449186, 0.8268867491661398, 0.9785569264152818], 91 -> 
             RGBColor[
              0.25378820154251513`, 0.3840778692955045, 0.9377642346806232], 
             6 -> RGBColor[
              0.2567233930101477, 0.3871629416298741, 
               0.9379313894924781]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9lHs01Akbx4dhXCZmRjNjDGZ+vxEpY003Oez6fWm7uFSIpJWyrGvrtqF9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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 13}], {
             RGBColor[
             0.2657389891679791, 0.3966389048135667, 0.9384448143562873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 17}], {
             RGBColor[
             0.32323856928298944`, 0.4497129250720918, 0.941988877698796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 19}], {
             RGBColor[
             0.2624065565834054, 0.39313630687875045`, 0.9382550372504881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 27}], {
             RGBColor[
             0.3002303093342801, 0.42978432673328937`, 0.9405228117202697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 43}], {
             RGBColor[
             0.25434890859377146`, 0.3846672079572553, 0.9377961661177004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 46}], {
             RGBColor[
             0.26460123070803143`, 0.39544304853410883`, 0.9383800206951561]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 55}], {
             RGBColor[
             0.25340680094735984`, 0.3836769930878019, 0.9377425144809607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 3}], {
             RGBColor[
             0.4080096464453409, 0.5252224449857339, 0.947726795683348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 14}], {
             RGBColor[
             0.6178499772431384, 0.6994639678296142, 0.9638608906173386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 29}], {
             RGBColor[
             0.41847939161663067`, 0.5351656244278226, 0.9483618874203135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 33}], {
             RGBColor[
             0.39248083985044224`, 0.5089006846712906, 0.946842453120579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 38}], {
             RGBColor[
             0.4744745540542128, 0.5836658197325597, 0.9519298496562583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 42}], {
             RGBColor[
             0.5864694187639945, 0.6749492370446291, 0.9607331698161294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 44}], {
             RGBColor[
             0.6476158835940419, 0.7227173201002071, 0.9668276779841867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 62}], {
             RGBColor[
             0.441389916904741, 0.555009569915901, 0.9498217258326898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 78}], {
             RGBColor[
             0.7554647233160532, 0.8052075509695305, 0.8504886604600671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 16}], {
             RGBColor[
             0.26785762869397084`, 0.3988657292848884, 0.9385654677430463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 29}], {
             RGBColor[
             0.30975389821880644`, 0.4418401783792823, 0.9409902535505699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 33}], {
             RGBColor[
             0.283755346452618, 0.41557523862275036`, 0.9394708192508354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 38}], {
             RGBColor[
             0.36574906065638857`, 0.4903403736840195, 0.9445582157865146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 42}], {
             RGBColor[
             0.4777439253661703, 0.5816237909960889, 0.9533615359463858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 62}], {
             RGBColor[
             0.3326644235069168, 0.4616841238673607, 0.9424500919629462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 9}], {
             RGBColor[
             0.8763336093314709, 0.4811919292943124, 0.21644449553709408`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 23}], {
             RGBColor[
             0.8881231336373401, 0.5291371451280563, 0.4129442383759221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 24}], {
             RGBColor[
             0.8617062539165854, 0.4231993393515327, 0.20467498202211704`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 30}], {
             RGBColor[
             0.8319952731283586, 0.24693526644845676`, 0.17827201572219592`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 36}], {
             RGBColor[
             0.6189794565108638, 0.30147636010691836`, 0.43437257017428454`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 37}], {
             RGBColor[
             0.8011905243964335, 0.4614871744463005, 0.447638068497203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 50}], {
             RGBColor[
             0.8896565131257295, 0.5297712369525608, 0.3875321719943988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 76}], {
             RGBColor[
             0.8906548722841052, 0.5296457315437284, 0.33185422782530094`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 86}], {
             RGBColor[
             0.8903513837773537, 0.5300585838243685, 0.3760163670293843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 94}], {
             RGBColor[
             0.6194756955575549, 0.30199793880836345`, 0.4344008302538737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 20}], {
             RGBColor[
             0.23580229552736498`, 0.3651735417012756, 0.9367399639408238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 28}], {
             RGBColor[
             0.25321358145824574`, 0.3834739071539198, 0.9377315109168982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 58}], {
             RGBColor[
             0.23719924346325016`, 0.36664182255350575`, 0.9368195180591732]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.26264124075969747`, 0.39338297482786955`, 0.9382684021671439]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 63}], {
             RGBColor[
             0.2345983105108993, 0.3639080771119111, 0.9366713987752724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 66}], {
             RGBColor[
             0.2863038964022665, 0.41700376197031797`, 0.9396617300370205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 69}], {
             RGBColor[
             0.3370682698872072, 0.4609733107913742, 0.942896391026308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[
             0.33406614637016885`, 0.458373022292031, 0.9427050983704759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 79}], {
             RGBColor[
             0.24661518324008325`, 0.37653857226402054`, 0.9373557418998293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[
             0.23714577838221002`, 0.3665856273634506, 0.9368164733019025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 97}], {
             RGBColor[
             0.2506036098716818, 0.3807306615346847, 0.9375828768961504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 7}], {
             RGBColor[
             0.2850997356690481, 0.41655094886844685`, 0.9395633929504454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 10}], {
             RGBColor[
             0.25407458579092124`, 0.3843788772983895, 0.9377805438399023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 15}], {
             RGBColor[
             0.286330742124025, 0.4176171847875644, 0.9396418315932203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 25}], {
             RGBColor[
             0.2363155850258645, 0.36571304150863243`, 0.9367691950184196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 26}], {
             RGBColor[
             0.23839669585582945`, 0.3679004209409733, 0.9368877112014585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 35}], {
             RGBColor[
             0.2796014780341359, 0.41120925954445625`, 0.9392342625895005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 40}], {
             RGBColor[
             0.2502060423578324, 0.3803127928703927, 0.9375602360143851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.2901431745630745, 0.4209193221478431, 0.939884756417035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 65}], {
             RGBColor[
             0.23947632752859074`, 0.3690351822816471, 0.9369491946280504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 90}], {
             RGBColor[
             0.2824130283207301, 0.41416437715825094`, 0.9393943762190061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 100}], {
             RGBColor[
             0.2509928257224536, 0.38113975207155615`, 0.9376050421630586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 13}], {
             RGBColor[
             0.293422925234443, 0.42529914882237513`, 0.9400373862831393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 25}], {
             RGBColor[
             0.2646919276847649, 0.3951010487472052, 0.9384011984763869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 27}], {
             RGBColor[
             0.327914245400744, 0.45844457074209777`, 0.9421153836471216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 37}], {
             RGBColor[
             0.5197144859100872, 0.615889070520134, 0.9572576272411842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 40}], {
             RGBColor[
             0.2785823850167328, 0.4097008001089655, 0.9391922394723524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 53}], {
             RGBColor[
             0.3185195172219749, 0.4503073293864159, 0.9415167598750023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.28220392258022686`, 0.41350726570694146`, 0.9393984806790088]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 65}], {
             RGBColor[
             0.26785267018749115`, 0.3984231895202199, 0.9385811980860177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 81}], {
             RGBColor[
             0.42699263228672224`, 0.5418938445096457, 0.9490827029907487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.3751477903048108, 0.49935589331100566`, 0.9451250633614249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 85}], {
             RGBColor[
             0.46422750147449665`, 0.5721227887280222, 0.9520139682890303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 90}], {
             RGBColor[
             0.31078937097963055`, 0.4435523843968237, 0.9410263796769736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 100}], {
             RGBColor[
             0.27936916838135406`, 0.4105277593101289, 0.939237045621026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 17}], {
             RGBColor[
             0.6756356059860984, 0.7413302717200512, 0.9468242231148067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.9330401773606567, 0.8125446192441054, 0.5943013473777097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 22}], {
             RGBColor[
             0.9622103495532457, 0.9713371210884598, 0.9488522004737234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 30}], {
             RGBColor[
             0.8665455196590803, 0.4187400277549185, 0.42604144762819984`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 49}], {
             RGBColor[
             0.8679776052374037, 0.8972436267472088, 0.9628476465059921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 69}], {
             RGBColor[
             0.6933493129056316, 0.7566729943369539, 0.9479529248561034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 77}], {
             RGBColor[
             0.6903471893885933, 0.7540727058376107, 0.9477616322002713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.8792868569891993, 0.5166755297638322, 0.4382425666448041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 86}], {
             RGBColor[
             0.9781688756181125, 0.981703287226387, 0.853067848528615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 87}], {
             RGBColor[
             0.8760096171986388, 0.9035182955368775, 0.9636482023948687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 95}], {
             RGBColor[
             0.7742769644814296, 0.8231752897500257, 0.9541023665093038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 99}], {
             RGBColor[
             0.6831435055361634, 0.747833236952314, 0.947302619835162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.5927913677992559, 0.604221747139333, 0.6081939441102431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 21}], {
             RGBColor[
             0.9272801117087064, 0.7490947632900866, 0.26033044528115884`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 30}], {
             RGBColor[
             0.8627054758911135, 0.37644012378557273`, 0.20339417956383254`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 36}], {
             RGBColor[
             0.5653509190664274, 0.575380095696193, 0.6066312511494145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 61}], {
             RGBColor[
             0.565154574148669, 0.575173724738642, 0.6066200695968145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 67}], {
             RGBColor[
             0.5664610075924095, 0.5765468691206779, 0.6066944690487404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 68}], {
             RGBColor[
             0.8620067160991126, 0.3710691498257614, 0.2027250463978763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 72}], {
             RGBColor[
             0.871424018845867, 0.4434546654256925, 0.21174306614349048`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 82}], {
             RGBColor[
             0.8754468132212324, 0.47437562579448644`, 0.2155952985804368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 86}], {
             RGBColor[
             0.9724088099661622, 0.9182534312723682, 0.5190969464320642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 92}], {
             RGBColor[
             0.5688207352101959, 0.5790270924623439, 0.606828852045669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 94}], {
             RGBColor[
             0.566095277636464, 0.5761624637483606, 0.6066736412687983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.28368193490479854`, 0.4148331204560798, 0.9394909859406446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 26}], {
             RGBColor[
             0.235747888636603, 0.36511635660948866`, 0.9367368655488828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 35}], {
             RGBColor[
             0.2769526708149095, 0.4084251952129716, 0.9390834169369247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 40}], {
             RGBColor[
             0.247557235138606, 0.37752872853890806`, 0.9374093903618093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 53}], {
             RGBColor[
             0.28749436734384803`, 0.4181352578163585, 0.9397339107644591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 65}], {
             RGBColor[
             0.23682752030936433`, 0.3662511179501625, 0.9367983489754745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 90}], {
             RGBColor[
             0.2797642211015037, 0.41138031282676635`, 0.9392435305664304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 100}], {
             RGBColor[
             0.2483440185032272, 0.37835568774007156`, 0.9374541965104828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 36}], {
             RGBColor[
             0.20676013856834535`, 0.33464839335824176`, 0.9350860560660287]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 52}], {
             RGBColor[
             0.5864699931809645, 0.5791596032510256, 0.6031076177106328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 61}], {
             RGBColor[
             0.20656379365058694`, 0.3344420224006909, 0.9350748745134286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 67}], {
             RGBColor[
             0.20787022709432745`, 0.3358151667827266, 0.9351492739653546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 68}], {
             RGBColor[
             0.6229461957670579, 0.21058134826712724`, 0.42169491634228573`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 72}], {
             RGBColor[
             0.6323634985138122, 0.2829668638670583, 0.43071293608789996`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 92}], {
             RGBColor[
             0.21022995471211395`, 0.3382953901243926, 0.9352836569622833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 94}], {
             RGBColor[
             0.20750449713838193`, 0.3354307614104094, 0.9351284461854125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 41}], {
             RGBColor[
             0.5175163922375255, 0.6185385423481014, 0.9553377624650727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 52}], {
             RGBColor[
             0.7720788229198519, 0.7426869970369261, 0.6158231874912047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 60}], {
             RGBColor[
             0.5377449711891708, 0.6356046186030777, 0.9567524004381972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.44521446884155214`, 0.5537197588039671, 0.950811098924118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 74}], {
             RGBColor[
             0.48414329622236674`, 0.5896324439603484, 0.9532112582976568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 88}], {
             RGBColor[
             0.44729833605503005`, 0.5559100353701449, 0.9509297720791202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 96}], {
             RGBColor[
             0.4452662078752948, 0.5537741398088749, 0.9508140453855485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 27}], {
             RGBColor[
             0.30786109230723857`, 0.43780476345745334`, 0.9409573735218479]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 43}], {
             RGBColor[
             0.26197969156672996`, 0.39268764468141926`, 0.9382307279192786]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 54}], {
             RGBColor[
             0.26215076948672145`, 0.392867458422297, 0.938240470553735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 81}], {
             RGBColor[
             0.40693947919321677`, 0.5212540372250012, 0.947924692865475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 84}], {
             RGBColor[
             0.35509463721130535`, 0.4787160860263612, 0.9439670532361513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 85}], {
             RGBColor[
             0.44417434838099124`, 0.5514829814433777, 0.9508559581637567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 15}], {
             RGBColor[
             0.517451452940507, 0.6142257362851044, 0.9569878126877741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 24}], {
             RGBColor[
             0.8132324483478965, 0.7256778621369495, 0.6085269751651416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 35}], {
             RGBColor[
             0.5107221888506179, 0.6078178110419963, 0.9565802436840543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 38}], {
             RGBColor[
             0.5755893914541861, 0.6645818965278997, 0.9606923107205052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 42}], {
             RGBColor[
             0.6875842561639678, 0.755865313839969, 0.9694956308803766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 53}], {
             RGBColor[
             0.5212638853795565, 0.6175278736453831, 0.9572307375115887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 62}], {
             RGBColor[
             0.5425047543047143, 0.6359256467112409, 0.9585841868969369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 76}], {
             RGBColor[
             0.8566553758991764, 0.885347450425243, 0.7992958438699176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 35}], {
             RGBColor[
             0.3092088271480132, 0.4416635027021466, 0.9409447046902427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 38}], {
             RGBColor[
             0.3740760297515814, 0.49842758818805, 0.9450567717266938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 40}], {
             RGBColor[
             0.2798133914717097, 0.41076703602808307`, 0.9392706781151272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 53}], {
             RGBColor[
             0.3197505236769518, 0.4513735653055334, 0.9415951985177772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.3409913926021096, 0.4697713383713912, 0.9429486479031253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 90}], {
             RGBColor[
             0.3120203774346074, 0.44461862031594124`, 0.9411048183197483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 100}], {
             RGBColor[
             0.28060017483633093`, 0.41159399522924645`, 0.9393154842638007]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 29}], {
             RGBColor[
             0.27832737386526063`, 0.40880890872697706`, 0.9392005594800119]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.25232882209907226`, 0.38254396897044507`, 0.9376811251802775]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 62}], {
             RGBColor[
             0.30123789915337096`, 0.4286528542150554, 0.9406603978923882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 19}], {
             RGBColor[
             0.32753691967137427`, 0.45423076386143946`, 0.9422336623945751]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 22}], {
             RGBColor[
             0.6749436759381056, 0.7408142314231896, 0.9479954802017996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 28}], {
             RGBColor[
             0.3222279508615301, 0.4486507010342292, 0.9419313244747699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 46}], {
             RGBColor[
             0.32973159379600026`, 0.45653750551679784`, 0.942358645839243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 55}], {
             RGBColor[
             0.3185371640353287, 0.44477145007049096`, 0.9417211396250476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 59}], {
             RGBColor[
             0.33165561016298184`, 0.45855976870817894`, 0.9424682157250155]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 66}], {
             RGBColor[
             0.3553182658055509, 0.48218055585062736`, 0.943861543594892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 69}], {
             RGBColor[
             0.40608263929049154`, 0.5261501046716837, 0.9470962045841795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 77}], {
             RGBColor[
             0.4030805157734533, 0.5235498161723404, 0.9469049119283475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 79}], {
             RGBColor[
             0.3156295526433677, 0.44171536614432994`, 0.9415555554577009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 95}], {
             RGBColor[
             0.48701029086628944`, 0.5926524000847553, 0.95324564623738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 98}], {
             RGBColor[
             0.34163351398872654`, 0.46904717826467845`, 0.9430364425869058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.3958768319210234, 0.5173103472870436, 0.9464458995632381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 80}], {
             RGBColor[
             0.2419836729170215, 0.3716705612597674, 0.9370919842386365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 28}], {
             RGBColor[
             0.26139593816194606`, 0.39207408284088785`, 0.938197484026462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 43}], {
             RGBColor[
             0.25864725898215624`, 0.389185046746603, 0.9380409508134795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 46}], {
             RGBColor[
             0.2688995810964162, 0.39996088732345647`, 0.9386248053909352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 55}], {
             RGBColor[
             0.2577051513357447, 0.38819483187714965`, 0.9379872991767397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 59}], {
             RGBColor[
             0.2708235974633978, 0.40198315051483763`, 0.9387343752767077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 66}], {
             RGBColor[
             0.2944862531059669, 0.425603937657286, 0.9401277031465842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 79}], {
             RGBColor[
             0.2547975399437836, 0.38513874795098857`, 0.937821715009393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 95}], {
             RGBColor[
             0.4261782781667054, 0.536075781891414, 0.949511805789072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 98}], {
             RGBColor[
             0.2808015012891425, 0.4124705600713371, 0.9393026021385978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 99}], {
             RGBColor[
             0.33504481922143936`, 0.46073372909370225`, 0.9427120591149303]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.2386756834212212, 0.36819365456103337`, 0.9369035991305825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 58}], {
             RGBColor[
             0.22266134542622565`, 0.3513615699606193, 0.9359916062728575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 59}], {
             RGBColor[
             0.24810334272267293`, 0.37810272223498315`, 0.9374404903808281]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 63}], {
             RGBColor[
             0.22006041247387476`, 0.34862782451902463`, 0.9358434869889567]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 66}], {
             RGBColor[
             0.271765998365242, 0.4017235093774315, 0.9388338182507047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 79}], {
             RGBColor[
             0.2320772852030587, 0.3612583196711341, 0.9365278301135136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 83}], {
             RGBColor[
             0.22260788034518547`, 0.3513053747705641, 0.9359885615155867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 97}], {
             RGBColor[
             0.23606571183465724`, 0.3654504089417983, 0.9367549651098346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 22}], {
             RGBColor[
             0.9323482473126639, 0.8120285789472437, 0.5954726044647025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 30}], {
             RGBColor[
             0.8466374514986924, 0.3125343329941077, 0.1904550502888525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 34}], {
             RGBColor[
             0.7440489383777218, 0.6635696741320418, 0.6006939636333543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.5412488824777958, 0.4795214095089955, 0.5872225572369445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 49}], {
             RGBColor[
             0.8381155029968219, 0.7379350846059927, 0.6094680504969712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 68}], {
             RGBColor[
             0.8459386917066916, 0.3071633590342964, 0.18978591712289627`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 72}], {
             RGBColor[
             0.8553559944534459, 0.3795488746342275, 0.19880393686851044`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 82}], {
             RGBColor[
             0.8593787888288114, 0.4104698350030215, 0.20265616930545677`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[
             0.8461475149580568, 0.7442097533956613, 0.6102686063858478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 92}], {
             RGBColor[
             0.5447186986215644, 0.48316840627514634`, 0.5874201581331991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 30}], {
             RGBColor[
             0.8660842329604185, 0.4183960008903441, 0.42682228568619507`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 34}], {
             RGBColor[
             0.7732191105703109, 0.8223621759763964, 0.955244816729368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 49}], {
             RGBColor[
             0.8672856751894109, 0.8967275864503471, 0.9640189035929849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 66}], {
             RGBColor[
             0.6418930093726982, 0.712187405219036, 0.9458895209538087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 69}], {
             RGBColor[
             0.6926573828576388, 0.7561569540400923, 0.9491241819430962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 77}], {
             RGBColor[
             0.6896552593406005, 0.7535566655407491, 0.9489328892872642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 82}], {
             RGBColor[
             0.8788255702905374, 0.5163315028992579, 0.4390234047027993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 87}], {
             RGBColor[
             0.875317687150646, 0.9030022552400158, 0.9648194594818615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 95}], {
             RGBColor[
             0.7735850344334367, 0.822659249453164, 0.9552736235962966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 99}], {
             RGBColor[
             0.6824515754881706, 0.7473171966554524, 0.9484738769221548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 24}], {
             RGBColor[
             0.9471254016338135, 0.8298823883137303, 0.5568344831794053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 27}], {
             RGBColor[
             0.6645515668442425, 0.7298696411778459, 0.9061368692979717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 30}], {
             RGBColor[
             0.8744950001969827, 0.4243853396193167, 0.39989392240266064`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 37}], {
             RGBColor[
             0.8563518073535856, 0.887314140955882, 0.9212791128920343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 50}], {
             RGBColor[
             0.9890507904475296, 0.9897402347152724, 0.831120268137828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 76}], {
             RGBColor[
             0.9905483291850934, 0.9895519766020239, 0.7476033518841813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[
             0.7636299537302207, 0.8133189149453938, 0.9131041886415987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 84}], {
             RGBColor[
             0.7117851117483094, 0.7707809637467538, 0.909146549012275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 85}], {
             RGBColor[
             0.8008648229179952, 0.8435478591637703, 0.9160354539398804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 86}], {
             RGBColor[
             0.990093096424966, 0.9901712550229842, 0.8138465606903063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 42}], {
             RGBColor[
             0.7818518898687528, 0.7011631313519644, 0.6053992543639326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 50}], {
             RGBColor[
             0.9494254708663976, 0.830833526050487, 0.5187163836071205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 76}], {
             RGBColor[
             0.9509230096039614, 0.8306452679372385, 0.4351994673534736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 26}], {
             RGBColor[
             0.21798888787154624`, 0.3464505208197316, 0.9357255167274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 40}], {
             RGBColor[
             0.22979823437354924`, 0.35886289274915106`, 0.9363980415403266]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 54}], {
             RGBColor[
             0.2334197719370433, 0.36266935834712705`, 0.9366042827469828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 65}], {
             RGBColor[
             0.21906851954430756`, 0.34758528216040546`, 0.9357870001539919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 100}], {
             RGBColor[
             0.23058501773817044`, 0.3596898519503145, 0.9364428476890001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 40}], {
             RGBColor[
             0.23187934520351416`, 0.3610502721814919, 0.9365165577233654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 53}], {
             RGBColor[
             0.27181647740875625`, 0.40165680145894234`, 0.9388410781260154]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 65}], {
             RGBColor[
             0.2211496303742725, 0.34977266159274634`, 0.9359055163370308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 90}], {
             RGBColor[
             0.2640863311664119, 0.39490185646935017`, 0.9383506979279865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[
             0.2326661285681354, 0.3618772313826554, 0.9365613638720389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 37}], {
             RGBColor[
             0.5341526529828826, 0.6283946851552121, 0.9581776144798929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 43}], {
             RGBColor[
             0.29647101173303086`, 0.4258330666011419, 0.9403087252832609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 54}], {
             RGBColor[
             0.2966420896530224, 0.4260128803420197, 0.9403184679177174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 81}], {
             RGBColor[
             0.4414307993595177, 0.5543994591447239, 0.9500026902294574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 84}], {
             RGBColor[
             0.38958595737760626`, 0.5118615079460839, 0.9460450506001336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 85}], {
             RGBColor[
             0.4786656685472922, 0.5846284033631004, 0.952933955527739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 46}], {
             RGBColor[
             0.2635906122865721, 0.39438082449624623`, 0.93832246747113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 55}], {
             RGBColor[
             0.2523961825259005, 0.38261476904993935`, 0.9376849612569346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 59}], {
             RGBColor[
             0.2655146286535537, 0.39640308768762733`, 0.9384320373569025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 66}], {
             RGBColor[
             0.28917728429612277`, 0.42002387483007575`, 0.9398253652267791]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 79}], {
             RGBColor[
             0.24948857113393946`, 0.3795586851237783, 0.937519377089588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 83}], {
             RGBColor[
             0.24001916627606623`, 0.36960574022320836`, 0.9369801084916611]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 98}], {
             RGBColor[
             0.27549253247929834`, 0.40689049724412685`, 0.9390002642187927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 99}], {
             RGBColor[
             0.3297358504115952, 0.455153666266492, 0.9424097211951252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 33}], {
             RGBColor[
             0.29422509162390786`, 0.4255184180648389, 0.9401059109878009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 38}], {
             RGBColor[
             0.3762188058276783, 0.5002835531261081, 0.9451933075234802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 42}], {
             RGBColor[
             0.48821367053746006`, 0.5915669704381774, 0.9539966276833514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.34313416867820656`, 0.4716273033094493, 0.9430851836999117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 36}], {
             RGBColor[
             0.6053513230705064, 0.19672455459817856`, 0.421322254201023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 50}], {
             RGBColor[
             0.8760283796853721, 0.425019431443821, 0.37448185602113726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 82}], {
             RGBColor[
             0.8247378083530608, 0.19115121194417384`, 0.17132225925723651`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 86}], {
             RGBColor[
             0.8767232503369963, 0.4253067783156288, 0.3629660510561227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 92}], {
             RGBColor[
             0.6076645338330189, 0.19915588577561247`, 0.4214539881318594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 94}], {
             RGBColor[
             0.6058475621171975, 0.19724613329962365`, 0.4213505142806121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 32}], {
             RGBColor[
             0.3463701598777138, 0.472931174642505, 0.9433462632569267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 39}], {
             RGBColor[
             0.34736341039793694`, 0.47397514391497986`, 0.943402827404671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 44}], {
             RGBColor[
             0.5893518598321712, 0.6739738751825308, 0.9626393731710036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 45}], {
             RGBColor[
             0.5919024457294845, 0.6759664122706829, 0.9628935917366674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 51}], {
             RGBColor[
             0.33046646407782415`, 0.4562153820042676, 0.9424405713085325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 70}], {
             RGBColor[
             0.3382626356768291, 0.464409652660651, 0.9428845517476936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 75}], {
             RGBColor[
             0.3329280335215753, 0.45880264756216715`, 0.9425807540467885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 78}], {
             RGBColor[
             0.6972006995541824, 0.7564641060518543, 0.846300355646884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 80}], {
             RGBColor[
             0.33469414166217204`, 0.4606589391956579, 0.9426813312926726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 39}], {
             RGBColor[
             0.2935264779562271, 0.4258453173585629, 0.9400272707348724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 44}], {
             RGBColor[
             0.5355149273904612, 0.6258440486261139, 0.959263816501205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 45}], {
             RGBColor[
             0.5380655132877746, 0.6278365857142659, 0.9595180350668688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 51}], {
             RGBColor[
             0.27662953163611426`, 0.40808555544785063`, 0.9390650146387339]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 80}], {
             RGBColor[
             0.2808572092204622, 0.41252911263924097`, 0.939305774622874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 42}], {
             RGBColor[
             0.46221511877127164`, 0.5653020306816455, 0.952477193383617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 62}], {
             RGBColor[
             0.3171356169120182, 0.44536236355291736`, 0.9415657494001773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 49}], {
             RGBColor[
             0.678986366254469, 0.7482686816351451, 0.9692402627616367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 60}], {
             RGBColor[
             0.5274957486173808, 0.6272838379970835, 0.9559455440932065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 69}], {
             RGBColor[
             0.5043580739226968, 0.6076980492248905, 0.954345541111748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 71}], {
             RGBColor[
             0.46781157980336074`, 0.5760433128989255, 0.9520168308232597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 77}], {
             RGBColor[
             0.5013559504056586, 0.6050977607255472, 0.9541542484559159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 82}], {
             RGBColor[
             0.7532926976672427, 0.4173588996891232, 0.4425043108152338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 87}], {
             RGBColor[
             0.687018378215704, 0.7545433504248138, 0.9700408186505132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 38}], {
             RGBColor[
             0.3673467656616922, 0.49201966294494187`, 0.9446492027229738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 53}], {
             RGBColor[
             0.3130212595870627, 0.4449656400624253, 0.9411876295140573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 62}], {
             RGBColor[
             0.3342621285122205, 0.46336341312828305`, 0.9425410788994055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 90}], {
             RGBColor[
             0.3052911133447183, 0.4382106950728331, 0.9406972493160285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 61}], {
             RGBColor[
             0.17912334491775841`, 0.3056003709575509, 0.9335121815526001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 67}], {
             RGBColor[
             0.18042977836149893`, 0.3069735153395867, 0.9335865810045261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 68}], {
             RGBColor[
             0.6046525632785056, 0.19135358063836727`, 0.4206531210350667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 72}], {
             RGBColor[
             0.6140698660252599, 0.26373909623829833`, 0.4296711407806809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 82}], {
             RGBColor[
             0.6180926604006254, 0.2946600566070923, 0.4335233732176272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 86}], {
             RGBColor[
             0.5863775807352516, 0.6486800774912771, 0.8459890583878498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 92}], {
             RGBColor[
             0.18278950597928542`, 0.3094537386812527, 0.9337209640014548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 94}], {
             RGBColor[
             0.1800640484055534, 0.3065891099672694, 0.9335657532245839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 50}], {
             RGBColor[
             0.8586518765861698, 0.8882652786926387, 0.8831610133197494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 76}], {
             RGBColor[
             0.8601494153237335, 0.8880770205793902, 0.7996440970661025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 81}], {
             RGBColor[
             0.6332310398688609, 0.7118439589227601, 0.9651449338235201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 84}], {
             RGBColor[
             0.5813861978869495, 0.66930600772412, 0.9611872941941962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 85}], {
             RGBColor[
             0.6704659090566354, 0.7420729031411366, 0.9680761991218017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 42}], {
             RGBColor[
             0.5442088329750422, 0.6400671657429147, 0.9575645899192962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 62}], {
             RGBColor[
             0.39912933111578863`, 0.5201274986141865, 0.9466531459358565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 44}], {
             RGBColor[
             0.5365081779106845, 0.6268880178985887, 0.9593203806489492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 45}], {
             RGBColor[
             0.5390587638079978, 0.6288805549867408, 0.959574599214613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 80}], {
             RGBColor[
             0.28185045974068534`, 0.4135730819117158, 0.9393623387706183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 53}], {
             RGBColor[
             0.2836258239107592, 0.41406917338836174`, 0.9395136029389419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 54}], {
             RGBColor[
             0.24731022926901122`, 0.37726910970888733`, 0.9373953237429482]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.23295897687627548`, 0.36218503352216574`, 0.9365780411499574]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 90}], {
             RGBColor[
             0.27589567766841483`, 0.4073142283987696, 0.939023222740913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 100}], {
             RGBColor[
             0.24447547507013836`, 0.3742896033120748, 0.9372338886849655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 48}], {
             RGBColor[
             0.34329321321312134`, 0.4669781893550724, 0.9432705886491298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 56}], {
             RGBColor[
             0.3357366265014662, 0.459035737605853, 0.9428402522148693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 60}], {
             RGBColor[
             0.44984311664774745`, 0.5635983285779962, 0.9500102743152689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 64}], {
             RGBColor[
             0.3573126143001289, 0.48171346877888566`, 0.9440689728011896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 73}], {
             RGBColor[
             0.34062966364440406`, 0.46417862987955394`, 0.9431189034415599]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 74}], {
             RGBColor[
             0.39624144168094344`, 0.517626153935267, 0.9464691321747285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.3593964815136068, 0.4839037453450634, 0.9441876459561919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 91}], {
             RGBColor[
             0.34170136961930875`, 0.46530506080926215`, 0.9431799355113838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 93}], {
             RGBColor[
             0.34493630114672413`, 0.468705178951081, 0.9433641600762177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 44}], {
             RGBColor[
             0.7173501625148713, 0.7791186661105619, 0.9724624182472246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 62}], {
             RGBColor[
             0.5111241958255703, 0.6114109159262558, 0.9554564660957278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 78}], {
             RGBColor[
             0.8251990022368825, 0.8616088969798854, 0.8561234007231051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 46}], {
             RGBColor[
             0.2608419331067822, 0.3914917884019613, 0.9381659342581474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 54}], {
             RGBColor[
             0.2507606889125138, 0.3808957615659856, 0.9375918223151481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 45}], {
             RGBColor[
             0.7810472132422319, 0.8288792862542917, 0.9788111449809456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 78}], {
             RGBColor[
             0.88634546706693, 0.9093769800354632, 0.8622179088911622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 52}], {
             RGBColor[
             0.8611685991001501, 0.8128504925215565, 0.6243159249705089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 78}], {
             RGBColor[
             0.8888960529642432, 0.9113695171236152, 0.8624721274568261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 55}], {
             RGBColor[
             0.25989982546037066`, 0.390501573532508, 0.9381122826214077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 59}], {
             RGBColor[
             0.27301827158802383`, 0.40428989217019595`, 0.9388593587213756]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 79}], {
             RGBColor[
             0.25699221406840955`, 0.38744548960634695`, 0.937946698454061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 95}], {
             RGBColor[
             0.42837295229133143`, 0.5383825235467723, 0.9496367892337401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 98}], {
             RGBColor[
             0.2829961754137684, 0.41477730172669547`, 0.9394275855832659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 99}], {
             RGBColor[
             0.3372394933460653, 0.46304047074906063`, 0.9428370425595982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 51}], {
             RGBColor[
             0.26797369092262097`, 0.39898771804597, 0.9385720773152693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 57}], {
             RGBColor[
             0.2643065968573336, 0.3951333696761603, 0.9383632417332306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 70}], {
             RGBColor[
             0.27576986252162594`, 0.40718198870235345`, 0.9390160577544302]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 74}], {
             RGBColor[
             0.31904494583740095`, 0.4476628644149205, 0.9416637299737558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 75}], {
             RGBColor[
             0.2704352603663721, 0.40157498360386956`, 0.9387122600535251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 88}], {
             RGBColor[
             0.28219998567006427`, 0.41394045582471695`, 0.9393822437552191]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.280167857490329, 0.4118045602634469, 0.9392665170616474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 56}], {
             RGBColor[
             0.2494153020184852, 0.3794816746379056, 0.9375152045218548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 57}], {
             RGBColor[
             0.25518176821789507`, 0.38554259622855935`, 0.9378435962411888]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 64}], {
             RGBColor[
             0.27099128981714793`, 0.40215940581093823`, 0.9387439251081751]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 73}], {
             RGBColor[
             0.25430833916142304`, 0.38462456691160657`, 0.9377938557485452]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 74}], {
             RGBColor[
             0.3099201171979624, 0.4380720909673196, 0.941144084481714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 88}], {
             RGBColor[
             0.2730751570306258, 0.404349682377116, 0.9388625982631773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 91}], {
             RGBColor[
             0.2553800451363277, 0.3857509978413148, 0.9378548878183692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 93}], {
             RGBColor[
             0.2586149766637431, 0.3891511159831336, 0.9380391123832033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 96}], {
             RGBColor[
             0.2710430288508906, 0.402213786815846, 0.9387468715696057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 69}], {
             RGBColor[
             0.5984246385417968, 0.6820634596988412, 0.9631196279753649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 71}], {
             RGBColor[
             0.5618781444224608, 0.6504087233728764, 0.9607909176868766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 77}], {
             RGBColor[
             0.5954225150247585, 0.679463171199498, 0.9629283353195328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 82}], {
             RGBColor[
             0.8160037407466428, 0.4669358400050904, 0.44835370205764513`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.781084942834804, 0.8289087608987646, 0.9788149055141302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 76}], {
             RGBColor[
             0.9928483984176775, 0.9905031143387806, 0.7094852523118963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 81}], {
             RGBColor[
             0.7659300229628049, 0.8142700526821505, 0.8749860890693137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 84}], {
             RGBColor[
             0.7140851809808935, 0.7717321014835103, 0.87102844943999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 85}], {
             RGBColor[
             0.8031648921505794, 0.844498996900527, 0.8779173543675954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 86}], {
             RGBColor[
             0.9923931656575502, 0.9911223927597408, 0.7757284611180213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 57}], {
             RGBColor[
             0.25705874177093724`, 0.3875154144398035, 0.9379504871083011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 70}], {
             RGBColor[
             0.2685220074352297, 0.3995640334659966, 0.9386033031295007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 75}], {
             RGBColor[
             0.2631874052799758, 0.3939570283675128, 0.9382995054285956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 67}], {
             RGBColor[
             0.560139632974118, 0.5514847252323705, 0.6016081426491302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 68}], {
             RGBColor[
             0.857792466353585, 0.3543610539002231, 0.19933416213146946`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 72}], {
             RGBColor[
             0.8672097691003393, 0.4267465695001542, 0.20835218187708365`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 78}], {
             RGBColor[
             0.9664668529248481, 0.8933481863027279, 0.5077226888807255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 65}], {
             RGBColor[
             0.2728961090815175, 0.40279156279961614`, 0.9389025615526072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 84}], {
             RGBColor[
             0.3801912291988372, 0.5037242665904019, 0.9454464268280143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 85}], {
             RGBColor[
             0.46927094036852307`, 0.5764911620074185, 0.9523353317556198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 90}], {
             RGBColor[
             0.3158328098736569, 0.44792075767621997`, 0.941347743143563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 100}], {
             RGBColor[
             0.2844126072753804, 0.4148961325895252, 0.9395584090876155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 84}], {
             RGBColor[
             0.3438756345570892, 0.4669242029109275, 0.9433281476320208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 100}], {
             RGBColor[
             0.24809701263363243`, 0.37809606891005076`, 0.9374401298916217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 59}], {
             RGBColor[
             0.26182384182735224`, 0.39252383672388913`, 0.9382218525071802]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 66}], {
             RGBColor[
             0.28548649746992133`, 0.41614462386633744`, 0.9396151803770567]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 79}], {
             RGBColor[
             0.24579778430773802`, 0.37567943416004, 0.9373091922398655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 98}], {
             RGBColor[
             0.2718017456530969, 0.4030112462803886, 0.9387900793690704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 99}], {
             RGBColor[
             0.32604506358539376`, 0.45127441530275375`, 0.9421995363454028]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 64}], {
             RGBColor[
             0.2634347031054928, 0.3942169540617188, 0.9383135886739146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 73}], {
             RGBColor[
             0.24675175244976794`, 0.37668211516238714`, 0.9373635193142849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 74}], {
             RGBColor[
             0.3023635304863073, 0.4301296392181001, 0.9407137480474534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 88}], {
             RGBColor[
             0.26551857031897064`, 0.39640723062789657`, 0.9384322618289168]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 89}], {
             RGBColor[
             0.2431918362429577, 0.37294041751730556`, 0.937160787352731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 91}], {
             RGBColor[
             0.2478234584246726, 0.37780854609209535`, 0.9374245513841087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 93}], {
             RGBColor[
             0.251058389952088, 0.3812086642339142, 0.9376087759489427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 64}], {
             RGBColor[
             0.2692011693049027, 0.4002778756523726, 0.9386419803932486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 70}], {
             RGBColor[
             0.26485491336994227`, 0.39570968509618687`, 0.9383944675474621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 74}], {
             RGBColor[
             0.3081299966857172, 0.43619056080875396`, 0.9410421397667876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 75}], {
             RGBColor[
             0.25952031121468844`, 0.390102679997703, 0.9380906698465571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 88}], {
             RGBColor[
             0.27128503651838054`, 0.40246815221855037`, 0.9387606535482509]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 96}], {
             RGBColor[
             0.26925290833864535`, 0.40033225665728034`, 0.9386449268546793]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 63}], {
             RGBColor[
             0.22145736040975994`, 0.3500961053712548, 0.9359230411073061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 83}], {
             RGBColor[
             0.22400482828107066`, 0.3527736556227943, 0.9360681156339361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 97}], {
             RGBColor[
             0.23746265977054243`, 0.3669186897940284, 0.936834519228184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 66}], {
             RGBColor[
             0.2986049435975745, 0.4299329425040255, 0.9403622564770246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 69}], {
             RGBColor[
             0.34936931708251506`, 0.4739024913250818, 0.9435969174663121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 77}], {
             RGBColor[
             0.3463671935654768, 0.47130220282573854`, 0.9434056248104801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 79}], {
             RGBColor[
             0.2589162304353912, 0.38946775279772805`, 0.9380562683398335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 83}], {
             RGBColor[
             0.24944682557751796`, 0.3795148078971581, 0.9375169997419068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 95}], {
             RGBColor[
             0.430296968658313, 0.5404047867381535, 0.9497463591195126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 97}], {
             RGBColor[
             0.26290465706698973`, 0.3936598420683923, 0.9382834033361547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 98}], {
             RGBColor[
             0.28492019178075007`, 0.41679956491807657`, 0.9395371554690384]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 99}], {
             RGBColor[
             0.33916350971304693`, 0.46506273394044173`, 0.9429466124453707]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 64}], {
             RGBColor[
             0.37754119325177404`, 0.49877954503386207`, 0.9454836107743141]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 71}], {
             RGBColor[
             0.41038752678537255`, 0.5294238797348146, 0.9474961990184465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 74}], {
             RGBColor[
             0.4164700206325886, 0.5346922301902434, 0.9478837701478531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 89}], {
             RGBColor[
             0.357298326389239, 0.4775030084894488, 0.9443308094531306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 93}], {
             RGBColor[
             0.3651648800983693, 0.48577125520605746`, 0.9447787980493423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 67}], {
             RGBColor[
             0.1802334334437405, 0.3067671443820358, 0.933575399451926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 68}], {
             RGBColor[0.6045216666666666, 0.191216, 0.4206456666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 72}], {
             RGBColor[
             0.613938969413421, 0.26360151559993106`, 0.4296636864122809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 86}], {
             RGBColor[
             0.5861812358174932, 0.6484737065337263, 0.8459778768352497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 92}], {
             RGBColor[
             0.182593161061527, 0.30924736772370176`, 0.9337097824488547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 94}], {
             RGBColor[
             0.17986770348779496`, 0.3063827390097185, 0.9335545716719839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 83}], {
             RGBColor[
             0.2214038953287198, 0.3500399101811996, 0.9359199963500353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 97}], {
             RGBColor[
             0.23486172681819156`, 0.36418494435243376`, 0.9366863999442832]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 73}], {
             RGBColor[
             0.26832774024843065`, 0.39935984633541977`, 0.938592239900605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 74}], {
             RGBColor[
             0.32393951828497003`, 0.45280737039113284`, 0.9419424686337738]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 88}], {
             RGBColor[
             0.2870945581176334, 0.41908496180092925`, 0.9396609824152371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 89}], {
             RGBColor[
             0.2647678240416204, 0.39561814869033823`, 0.9383895079390514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 91}], {
             RGBColor[
             0.26939944622333534`, 0.400486277265128, 0.938653271970429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 93}], {
             RGBColor[
             0.2726343777507507, 0.4038863954069468, 0.938837496535263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 96}], {
             RGBColor[
             0.28506242993789815`, 0.4169490662396592, 0.9395452557216655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 90}], {
             RGBColor[
             0.26516596283917315`, 0.39603661781002397`, 0.9384121813545784]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 100}], {
             RGBColor[
             0.2337457602408967, 0.3630119927233292, 0.9366228472986309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 69}], {
             RGBColor[
             0.37303197272508415`, 0.4975232784675301, 0.9449902453361887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 77}], {
             RGBColor[
             0.3700298492080458, 0.49492298996818684`, 0.9447989526803566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 79}], {
             RGBColor[
             0.2825788860779602, 0.4130885399401764, 0.93944959620971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 83}], {
             RGBColor[
             0.27310948122008705`, 0.4031355950396065, 0.9389103276117834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 95}], {
             RGBColor[
             0.4539596243008821, 0.5640255738806018, 0.9511396869893891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 97}], {
             RGBColor[
             0.2865673127095588, 0.41728062921084064`, 0.9396767312060312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[
             0.3085828474233191, 0.440420352060525, 0.9409304833389149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 99}], {
             RGBColor[
             0.36282616535561596`, 0.48868352108289015`, 0.9443399403152473]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 68}], {
             RGBColor[
             0.605392622295827, 0.19213142958802387`, 0.42069526630128395`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 72}], {
             RGBColor[
             0.6148099250425814, 0.26451694518795493`, 0.4297132860468982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 86}], {
             RGBColor[
             0.5874876692612337, 0.649846850915762, 0.8460522762871756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 92}], {
             RGBColor[
             0.1838995945052675, 0.31062051210573755`, 0.9337841819007806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 94}], {
             RGBColor[
             0.18117413693153547`, 0.3077558833917543, 0.9336289711239099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 72}], {
             RGBColor[
             0.8220276513733772, 0.17031975779996553`, 0.1687270098728071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 82}], {
             RGBColor[
             0.8240390485610599, 0.18578023798436252`, 0.17065312609128025`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 92}], {
             RGBColor[
             0.606965774041018, 0.19378491181580115`, 0.4207848549659031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 71}], {
             RGBColor[
             0.38724985209068863`, 0.5098380909626216, 0.9458961960369879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 77}], {
             RGBColor[
             0.4207942226929865, 0.5388925387892431, 0.9480336136696441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 87}], {
             RGBColor[
             0.6064566505030319, 0.6883381284885098, 0.9639201838642415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 95}], {
             RGBColor[
             0.5047239977858227, 0.6079951227016581, 0.9543743479786766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 97}], {
             RGBColor[
             0.3373316861944994, 0.46125017803189694`, 0.9429113921953187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 98}], {
             RGBColor[
             0.35934722090825977`, 0.48438990088158124`, 0.9441651443282024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 99}], {
             RGBColor[
             0.41359053884055663`, 0.5326530699039465, 0.9475746013045347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 75}], {
             RGBColor[
             0.2709835768789808, 0.4021512990238961, 0.9387434858677567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 96}], {
             RGBColor[
             0.28071617400293775`, 0.4123808756834735, 0.9392977428758789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 77}], {
             RGBColor[
             0.3842477285736503, 0.5072378024632783, 0.9457049033811559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 87}], {
             RGBColor[
             0.5699101563836958, 0.656683392162545, 0.9615914735757531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 82}], {
             RGBColor[
             0.8334563513078143, 0.2581657535842936, 0.17967114583689445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 92}], {
             RGBColor[
             0.6163830767877724, 0.26617042741573227`, 0.42980287471151735`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 74}], {
             RGBColor[
             0.3072565676292452, 0.4352725314918011, 0.940992399274144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 88}], {
             RGBColor[
             0.2704116074619085, 0.40155012290159753`, 0.9387109130556073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.24808487338589558`, 0.37808330979100657`, 0.9374394385794216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 91}], {
             RGBColor[
             0.25271649556761044`, 0.3829514383657963, 0.9377032026107992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 93}], {
             RGBColor[
             0.2559514270950259, 0.38635155650761516`, 0.9378874271756332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 88}], {
             RGBColor[
             0.3260233854984479, 0.4549976469573106, 0.9420611417887761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 91}], {
             RGBColor[
             0.3083282736041498, 0.43639896242150933`, 0.941053431343968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 96}], {
             RGBColor[
             0.3239912573187127, 0.45286175139604057`, 0.9419454150952044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 96}], {
             RGBColor[
             0.27538157184768386`, 0.40677387058498965`, 0.9389939451749738]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 81}], {
             RGBColor[
             0.7674275617003685, 0.8140817945689018, 0.7914691728156671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 84}], {
             RGBColor[
             0.7155827197184571, 0.7715438433702618, 0.7875115331863431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 85}], {
             RGBColor[
             0.8046624308881429, 0.8443107387872784, 0.7944004381139487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 87}], {
             RGBColor[
             0.6034545269859937, 0.6857378399891666, 0.9637288912084094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 95}], {
             RGBColor[
             0.5017218742687843, 0.6053948342023149, 0.9541830553228445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 97}], {
             RGBColor[
             0.3343295626774611, 0.4586498895325537, 0.9427200995394867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 98}], {
             RGBColor[
             0.35634509739122144`, 0.481789612382238, 0.9439738516723704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 99}], {
             RGBColor[
             0.4105884153235183, 0.5300527814046032, 0.9473833086487027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 83}], {
             RGBColor[
             0.23342076805790374`, 0.3626704053333091, 0.9366043394745922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 98}], {
             RGBColor[
             0.26889413426113584`, 0.39995516235422757`, 0.9386244952017238]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 99}], {
             RGBColor[
             0.3231374521934327, 0.4482183313765927, 0.9420339521780562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 84}], {
             RGBColor[
             0.4886643442635845, 0.5953107817136317, 0.9530123699437607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 85}], {
             RGBColor[
             0.5777440554332705, 0.6680776771306483, 0.9599012748713662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 86}], {
             RGBColor[
             0.8894645876671153, 0.5232422803245426, 0.375167170072727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 87}], {
             RGBColor[
             0.8213584153874661, 0.47111895253153613`, 0.44888740598356275`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 92}], {
             RGBColor[
             0.6204058711631378, 0.29709138778452626`, 0.4336551071484636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 97}], {
             RGBColor[
             0.23740919468950228`, 0.36686249460397324`, 0.9368314744709133]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 85}], {
             RGBColor[
             0.5258992134513589, 0.6255397259320082, 0.9559436352420423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.37246108295649283`, 0.49696932160080975`, 0.9449560466299856]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 90}], {
             RGBColor[
             0.4615407941261787, 0.5697362170178263, 0.951844951557591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 92}], {
             RGBColor[
             0.5898473968790202, 0.652327074257428, 0.8461866592841044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[
             0.5871219393052882, 0.6494624455434448, 0.8460314485072336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 91}], {
             RGBColor[
             0.2714833134368132, 0.40267655383130574`, 0.9387719451254313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 96}], {
             RGBColor[
             0.2871462971513761, 0.419139342805837, 0.9396639288766677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 91}], {
             RGBColor[
             0.24915657936080024`, 0.3792097407207148, 0.9375004706492456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 93}], {
             RGBColor[
             0.25239151088821565`, 0.3826098588625336, 0.9376846952140795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 100}], {
             RGBColor[
             0.27668246103303606`, 0.408141187599933, 0.9390680288895865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 93}], {
             RGBColor[
             0.2570231330699305, 0.38747798743732337`, 0.9379484592454572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 96}], {
             RGBColor[
             0.269451185257078, 0.40054065827003577`, 0.9386562184318596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 94}], {
             RGBColor[
             0.18353386454932197`, 0.3102361067334203, 0.9337633541208386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 98}], {
             RGBColor[
             0.44027487248405767`, 0.5508921962946529, 0.9503145859814027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 99}], {
             RGBColor[
             0.49451819041635453`, 0.5991553653170181, 0.9537240429577352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 99}], {
             RGBColor[
             0.3491414135387916, 0.47555014349694125`, 0.943514839307261]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.058168352269944726`], {
             RGBColor[
             0.2581082061950206, 0.38861846808940276`, 0.9380102525547092]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.058168352269944726`], {
             RGBColor[
             0.5167351398431651, 0.6185478910342742, 0.9550984295530915]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.058168352269944726`], {
             RGBColor[
             0.29928415304751665`, 0.4318969989371937, 0.9403551618136042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.058168352269944726`], {
             RGBColor[
             0.8388093398485373, 0.29931116920282663`, 0.1847971737088267]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.058168352269944726`], {
             RGBColor[
             0.2503401935643895, 0.38045379429416204`, 0.9375678757271396]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.058168352269944726`], {
             RGBColor[
             0.2567233930101477, 0.3871629416298741, 0.9379313894924781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.058168352269944726`], {
             RGBColor[
             0.3134760783279485, 0.4459389561070196, 0.9411953964084129]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.058168352269944726`], {
             RGBColor[
             0.9629022796012385, 0.9718531613853215, 0.9476809433867306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.058168352269944726`], {
             RGBColor[
             0.9513821482973379, 0.8449534494772841, 0.27973913919362886`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.058168352269944726`], {
             RGBColor[
             0.25142577857169485`, 0.38159481296690484`, 0.9376296981873266]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.058168352269944726`], {
             RGBColor[
             0.23420058730117388`, 0.3634900448013817, 0.9366487490268572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.058168352269944726`], {
             RGBColor[
             0.6054182467789488, 0.6905448323731828, 0.9620798885880011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.058168352269944726`], {
             RGBColor[
             0.2733697721409376, 0.40465934153773064`, 0.9388793761578655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.058168352269944726`], {
             RGBColor[
             0.7189648146431117, 0.780380044624954, 0.9726233516815856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.058168352269944726`], {
             RGBColor[
             0.3159380912379023, 0.44807142794525473`, 0.9413522736939626]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.058168352269944726`], {
             RGBColor[
             0.23643110434042502`, 0.36583445963258315`, 0.9367757736724883]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.058168352269944726`], {
             RGBColor[
             0.3883689323709583, 0.5108073820547808, 0.9459675028428829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.058168352269944726`], {
             RGBColor[
             0.21478615482912253`, 0.34308424532714094`, 0.935543125818653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.058168352269944726`], {
             RGBColor[
             0.2667049069717902, 0.39765414566809815`, 0.9384998219462671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.058168352269944726`], {
             RGBColor[
             0.22126439749034046`, 0.3498932891083892, 0.9359120521545081]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.058168352269944726`], {
             RGBColor[
             0.9031780751200748, 0.6532360771028892, 0.2409217513686888]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.058168352269944726`], {
             RGBColor[
             0.9615184195052529, 0.9708210807915982, 0.9500234575607163]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.058168352269944726`], {
             RGBColor[
             0.9867507212149456, 0.9887890969785158, 0.869238367710113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.058168352269944726`], {
             RGBColor[
             0.9075000820526815, 0.6709756796489449, 0.2444305986486977]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.058168352269944726`], {
             RGBColor[
             0.21590777704158132`, 0.3442631413873908, 0.9356070005443611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.058168352269944726`], {
             RGBColor[
             0.2200699987015112, 0.3486379002520725, 0.9358440329104389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.058168352269944726`], {
             RGBColor[
             0.3423524124735395, 0.470950185377176, 0.9430353708858302]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.058168352269944726`], {
             RGBColor[
             0.25608696935210196`, 0.3864940200136776, 0.9378951461066569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.058168352269944726`], {
             RGBColor[
             0.32022364339009624`, 0.4517833578213709, 0.9416253452875354]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.058168352269944726`], {
             RGBColor[
             0.8183671396880012, 0.14218346093971695`, 0.1652216997489344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.058168352269944726`], {
             RGBColor[
             0.40020709231942364`, 0.521061001198922, 0.9467218199267253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.058168352269944726`], {
             RGBColor[
             0.2925332274360039, 0.424801348086088, 0.9399707065871281]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.058168352269944726`], {
             RGBColor[
             0.26822653985771944`, 0.399253478308307, 0.9385864766880666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.058168352269944726`], {
             RGBColor[
             0.5849198016353689, 0.6739032711611944, 0.9604661758980197]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.058168352269944726`], {
             RGBColor[
             0.30247956305812407`, 0.4352555774590384, 0.9405371356865229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.058168352269944726`], {
             RGBColor[
             0.17931968983551683`, 0.3058067419151018, 0.9335233631052001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.058168352269944726`], {
             RGBColor[
             0.7259528934922258, 0.7858391849332483, 0.9733198580739556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.058168352269944726`], {
             RGBColor[
             0.43221396826526043`, 0.5487837484308453, 0.9487612697594249]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.058168352269944726`], {
             RGBColor[
             0.2945197284764503, 0.42688928663103776`, 0.9400838348826166]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.058168352269944726`], {
             RGBColor[
             0.24368869170551716`, 0.37346264411091135`, 0.937189082536292]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.058168352269944726`], {
             RGBColor[
             0.4296145376961023, 0.5465322523230198, 0.9485956363421444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.058168352269944726`], {
             RGBColor[
             0.6562036976848239, 0.731350583054984, 0.9663679100791674]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.058168352269944726`], {
             RGBColor[
             0.25058961099252225`, 0.3807159478251078, 0.9375820796806917]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.058168352269944726`], {
             RGBColor[
             0.7784966273449186, 0.8268867491661398, 0.9785569264152818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.058168352269944726`], {
             RGBColor[
             0.7835977991395453, 0.8308718233424438, 0.9790653635466094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.058168352269944726`], {
             RGBColor[
             0.2710942552210422, 0.40226762897881485`, 0.9387497888356031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.058168352269944726`], {
             RGBColor[
             0.27522154600901727`, 0.40660567328232683`, 0.9389848319401988]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.058168352269944726`], {
             RGBColor[
             0.2569718887301403, 0.38742412638712503`, 0.9379455409561153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.058168352269944726`], {
             RGBColor[
             0.773052930873569, 0.822634092109096, 0.9780143496252536]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.058168352269944726`], {
             RGBColor[
             0.9913508596801138, 0.9906913724520291, 0.7930021685655431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.058168352269944726`], {
             RGBColor[
             0.26072583583622466`, 0.3913697628096132, 0.9381593226903397]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.058168352269944726`], {
             RGBColor[
             0.938739399060755, 0.7948291617006693, 0.26956648639440833`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.058168352269944726`], {
             RGBColor[
             0.3235629561160013, 0.45467570266581214`, 0.9418381233415918]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.058168352269944726`], {
             RGBColor[
             0.2509317668325053, 0.3810755753068633, 0.9376015649496046]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.058168352269944726`], {
             RGBColor[
             0.2487053956996991, 0.3787355180862011, 0.9374747764072122]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.058168352269944726`], {
             RGBColor[
             0.24185871530683006`, 0.3715392228886861, 0.9370848680875943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.058168352269944726`], {
             RGBColor[
             0.25339164770564987`, 0.38366106606999373`, 0.9377416515262625]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.058168352269944726`], {
             RGBColor[
             0.22405829336211083`, 0.3528298508128494, 0.9360711603912069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.058168352269944726`], {
             RGBColor[
             0.2749422879550054, 0.4063121553615771, 0.9389689286071481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.058168352269944726`], {
             RGBColor[
             0.4700716955993926, 0.5806644048329727, 0.9514249122883933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.058168352269944726`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.058168352269944726`], {
             RGBColor[
             0.3660446939663169, 0.4914712487975277, 0.9445450221122881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.058168352269944726`], {
             RGBColor[
             0.21885642745740908`, 0.34736235992966014`, 0.9357749218234052]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.058168352269944726`], {
             RGBColor[
             0.2850106909041555, 0.4168946852347515, 0.9395423092602349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.058168352269944726`], {
             RGBColor[
             0.2222292620470338, 0.35090742293342014`, 0.9359669997636226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.058168352269944726`], {
             RGBColor[
             0.32226759924014353`, 0.45355372964647384`, 0.9417555843469012]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.058168352269944726`], {
             RGBColor[
             0.181539866887481, 0.30814028876407157`, 0.9336497989038519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.058168352269944726`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.058168352269944726`], {
             RGBColor[
             0.42379634621002477`, 0.5414928272885864, 0.9482249063254762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.058168352269944726`], {
             RGBColor[
             0.27631817903423467`, 0.40775830412238, 0.9390472835686617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.058168352269944726`], {
             RGBColor[
             0.3507033579713525, 0.4781833546366567, 0.9435674857484997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.058168352269944726`], {
             RGBColor[
             0.8314449541201315, 0.24270527339989661`, 0.17774502961842129`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.058168352269944726`], {
             RGBColor[
             0.2516447895927058, 0.3818250074360881, 0.9376421705409753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.058168352269944726`], {
             RGBColor[
             0.3628683456657846, 0.48872005554751413`, 0.9443426280073127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.058168352269944726`], {
             RGBColor[
             0.26564897472372695`, 0.3965442939254123, 0.9384396881668516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.058168352269944726`], {
             RGBColor[
             0.9943459371552411, 0.990314856225532, 0.6259683360582495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.058168352269944726`], {
             RGBColor[
             0.4177920991759482, 0.5362922502898999, 0.947842321013812]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.058168352269944726`], {
             RGBColor[
             0.9941943067889412, 0.9918672109047867, 0.7458788913670427]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.058168352269944726`], {
             RGBColor[
             0.24289017291577697`, 0.372623350233879, 0.937143608072519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.058168352269944726`], {
             RGBColor[
             0.26918119100492044`, 0.4002568771923939, 0.9386408426586199]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.058168352269944726`], {
             RGBColor[
             0.5405091862454959, 0.6378487329122717, 0.9569700095730845]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.058168352269944726`], {
             RGBColor[
             0.8374791456831797, 0.2890867139530876, 0.18352337827384074`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.058168352269944726`], {
             RGBColor[
             0.2239513632000305, 0.3527174604327391, 0.9360650708766655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.058168352269944726`], {
             RGBColor[
             0.4368195022816731, 0.5527728305149917, 0.9490547303144369]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.058168352269944726`], {
             RGBColor[
             0.6149789246210449, 0.6983066213490248, 0.9628325401696478]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.058168352269944726`], {
             RGBColor[
             0.9934354716349865, 0.9915534130674525, 0.7584547536704994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.058168352269944726`], {
             RGBColor[
             0.789116954796039, 0.8351834296884333, 0.9796154614030067]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.058168352269944726`], {
             RGBColor[
             0.28917842533111127`, 0.421275238367107, 0.9397796555702393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.058168352269944726`], {
             RGBColor[
             0.24452495717908534`, 0.374341612145925, 0.9372367066178678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.058168352269944726`], {
             RGBColor[
             0.30810266363131256`, 0.4411658126866278, 0.9408573629455341]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.058168352269944726`], {
             RGBColor[
             0.25378820154251513`, 0.3840778692955045, 0.9377642346806232]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.058168352269944726`], {
             RGBColor[
             0.18625932212305402`, 0.3131007354474035, 0.9339185648977094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.058168352269944726`], {
             RGBColor[
             0.26025806459734596`, 0.3908781055791422, 0.9381326838102911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.058168352269944726`], {
             RGBColor[
             0.18080840697558995`, 0.30737147801943704`, 0.9336081433439677]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.058168352269944726`], {
             RGBColor[
             0.5856516493616206, 0.6744974181147299, 0.9605237896318769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.058168352269944726`], {
             RGBColor[
             0.2851141689716408, 0.417003447244567, 0.939548202183096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.058168352269944726`], {
             RGBColor[
             0.25086702617897405`, 0.38100752877520744`, 0.9375978780651611]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.058168352269944726`], {
             RGBColor[
             0.2948980956064947, 0.4272869744745761, 0.9401053823309286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.058168352269944726`], {
             RGBColor[
             0.40338473147108844`, 0.5238133125193064, 0.9469242962835934]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.058168352269944726`], {
             RGBColor[
             0.24526225843475957`, 0.3751165625132382, 0.937278694833639]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{{3.834946926643799*^9, 3.8349469478612347`*^9}, 
   3.834947050298876*^9, {3.8349471234738255`*^9, 3.8349471300172663`*^9}, {
   3.8349471617829676`*^9, 3.834947218900016*^9}, {3.8349472753220577`*^9, 
   3.834947307624898*^9}, 3.83494993428115*^9, 3.8349573375769677`*^9, {
   3.8349587473655295`*^9, 3.83495875945916*^9}, 3.835018920680505*^9, 
   3.835019004300144*^9, 3.8350204747493663`*^9, 3.8350205388580465`*^9, {
   3.8350445644807453`*^9, 3.8350445774530525`*^9}, 3.835051926588645*^9},
 Background->RGBColor[1, 1, 0.85],
 CellLabel->
  "Out[408]=",ExpressionUUID->"3bc5702a-abd1-4f3f-98a4-d583fb27b4d0"]
}, Open  ]],

Cell["Estimated with cubic Mean Deviation v Calculated: (r=6)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 
  3.834950339812094*^9}},ExpressionUUID->"cd961d7b-2ff0-4721-980b-\
03002c03709e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphinf1", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsif1", ",", "#"}], "}"}], "]"}], ",", "500", ",", 
      "1.2"}], "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"CMDi6f100", ",", "krif1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.834950273560528*^9, 3.834950273964845*^9}, {
   3.834957360267254*^9, 3.8349573712318316`*^9}, {3.8349587856645794`*^9, 
   3.83495878977224*^9}, {3.8350188291975336`*^9, 3.8350188308736053`*^9}, {
   3.8350443206807604`*^9, 3.835044327012074*^9}, {3.8350446304641314`*^9, 
   3.835044631224497*^9}, {3.8350450366633215`*^9, 3.8350450403134584`*^9}},
 CellLabel->
  "In[287]:=",ExpressionUUID->"bfef1a34-8b4d-41b8-baa9-4320ade88177"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100}, {
          Null, CompressedData["
1:eJwVxVmbqQwAAOCxVtbppLIkW4w1a5YJk8gSaaRCIqr783/Pr/me7715C/Zf
xfZ+fHz883x8/D9363DUk1oFBOGSrgbkKTe9Ubr+DJzlM67jGn44aCN55AiO
7OTWuWMuH0qHqrVObVrjcvv1PnbAe71DT+vplLkyddN8hkqxEiiAOngBnQA/
4nmBl/kz71Cz2Wqmz8zZE8QwHhOwC+aAKIqhFLpCL6gZpsKz8Cpshp+ghVm8
JViWU9t1dtxud0NGCI/IiIU4oXgsHi/Fq3gmo3kQT8YzygyrQz/up/w9/8Gv
+58BCZQwiZcESbpIluT8+c395n89MAjDCIzBI5iHBViCZdiCncDPzznXz/f7
6/6+Nu6Mx9x4N755Y96s9xj4/v75PnvrsXq2Xj/6SZBESYzESZIie6ROmuQz
5MbdtFt1h+5nNkDABEIQI4InZOJMOOEtuqW2s+1quzU9NEwjNEHTI1qmLdpp
99vr9t5fxsuZcrlXPpS19qvz4l7r1/6Fqxm1rPbUoXpQVc1b+CxkC4V67dF5
jB/TB/fYPW6PXCvfah1r1/a1cx1fuevuen2l0qlqaphy0SJWLE6LQlEqXjzR
aCY6jKpRLfeV//pqff3WxLbYEcfiVOTEnShexZenEW0gjUyjQTeG3maumW9+
NevNZqt5DC+p5Wy5XC23S31pLp/+ZCyJJ5P1ZC95AKJACsgAZaAKDAEV0AAX
7KJdrFvsdoWu1L3U7p37+M7dd3fxfr3f7vfH/RV4f79/3vxbeEvv8xswQkbc
SBslo2qohmYYbhAIhoLxYCqYDpaC1aARdIub7ma6ETYbaXMJsDCLsARLsyOW
5VmBlViZPbMW+2Yd7zw2j88/59l5YV6a1+eBRIJIfCfYxE+CT8iJc+IdXACL
0CK1SC+qi4WxcEEFVTCFVIoKpXSVlbJVFF25KCZsIzZh0/bIZm3eFmzJlm3L
th1vJVaJV7KVUqVSr8zDg9ZgsBysBtvBEThFT/gpcyqfeqfD6aSetCADMCEm
xsSZNFNiqgyzYFRGYwzGbU86k/5kwk3WE3Gyn1wnL6/P9+nL+gq+iq/um0dq
kUFkGuEiYuQaefkhKAyhEAlR0AxaQitoCymQDpnQ8z9pR8GG
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[69, 98] -> 
             RGBColor[
              0.6666559635976383, 0.7337065185771219, 0.9484990305659624], 
             UndirectedEdge[29, 33] -> 
             RGBColor[
              0.7739537682486328, 0.8218267489519613, 0.9192049586750441], 
             UndirectedEdge[55, 59] -> 
             RGBColor[
              0.34351240304929953`, 0.4719549109110778, 0.9431092844595783], 
             UndirectedEdge[47, 74] -> 
             RGBColor[
              0.6054869157593615, 0.6858670832810115, 0.9645606362600541], 
             UndirectedEdge[19, 43] -> 
             RGBColor[
              0.40056381863826873`, 0.5047817665086007, 0.9484510299219466], 
             UndirectedEdge[57, 75] -> 
             RGBColor[
              0.6270260344029265, 0.577490763532325, 0.5949928017523054], 
             UndirectedEdge[19, 46] -> 
             RGBColor[
              0.2611549487411393, 0.38861836984903164`, 0.9383010162396825], 
             UndirectedEdge[36, 67] -> 
             RGBColor[
              0.4979041889514232, 0.6006921658343561, 0.954325509563033], 
             UndirectedEdge[79, 99] -> 
             RGBColor[
              0.46415359140785273`, 0.5754948579886403, 0.9510598578822176], 
             UndirectedEdge[52, 68] -> 
             RGBColor[
              0.6665357664170201, 0.730952678503006, 0.8829025271198943], 
             UndirectedEdge[81, 85] -> 
             RGBColor[
              0.5952833327275304, 0.6819430734762885, 0.9615375858386634], 
             UndirectedEdge[12, 88] -> 
             RGBColor[
              0.5630608124827576, 0.6556370201598889, 0.9590869741863753], 
             UndirectedEdge[72, 82] -> 
             RGBColor[
              0.6933497844368266, 0.7155837947844386, 0.6317052216207808], 
             UndirectedEdge[31, 44] -> 
             RGBColor[
              0.714596373282997, 0.7759010053685093, 0.9731780376946879], 
             UndirectedEdge[17, 79] -> 
             RGBColor[
              0.6954379427382176, 0.6994280009387697, 0.61434027136379], 
             UndirectedEdge[91, 96] -> 
             RGBColor[
              0.6466545621836362, 0.6553113353637008, 0.610786375945428], 
             UndirectedEdge[55, 99] -> 
             RGBColor[
              0.41597145113819545`, 0.5337619097918473, 0.9479897345100288], 
             UndirectedEdge[77, 99] -> 
             RGBColor[
              0.6136119079890978, 0.6957195649232661, 0.9637349280121512], 
             UndirectedEdge[29, 38] -> 
             RGBColor[
              0.4751117392627783, 0.5829943190826724, 0.9523084791716263], 
             UndirectedEdge[26, 90] -> 
             RGBColor[
              0.701181649072504, 0.7223673622909002, 0.6322042611099201], 
             UndirectedEdge[13, 27] -> 
             RGBColor[
              0.43310763993542034`, 0.5493617232236389, 0.9488723908544494], 
             UndirectedEdge[22, 99] -> 
             RGBColor[
              0.4674307280191196, 0.5783333490076443, 0.9512686741292294], 
             UndirectedEdge[73, 74] -> 
             RGBColor[
              0.31570389453431214`, 0.4424119489621132, 0.941537144825604], 
             UndirectedEdge[8, 77] -> 
             RGBColor[
              0.5497578977714029, 0.6413658173447521, 0.9594027833657173], 
             UndirectedEdge[36, 94] -> 
             RGBColor[
              0.44439134754236553`, 0.55724803045245, 0.950112782663315], 
             UndirectedEdge[21, 87] -> 
             RGBColor[
              0.6555532414361969, 0.7304605187369896, 0.9665642014879448], 
             UndirectedEdge[59, 83] -> 
             RGBColor[
              0.6660211459922516, 0.7307398697322226, 0.8914311193532741], 
             UndirectedEdge[24, 42] -> 
             RGBColor[
              0.6398709003737642, 0.711949947236397, 0.9678564941908168], 
             UndirectedEdge[33, 42] -> 
             RGBColor[
              0.6647492342728158, 0.7301845928831406, 0.9114327409586338], 
             UndirectedEdge[14, 42] -> 
             RGBColor[
              0.6433615760579257, 0.7145532874461878, 0.9619476907715585], 
             UndirectedEdge[45, 78] -> 
             RGBColor[
              0.6020043211702005, 0.6873237095901026, 0.9621184876683498], 
             UndirectedEdge[15, 38] -> 
             RGBColor[
              0.6697153574897324, 0.6771483904512579, 0.6127012509773455], 
             UndirectedEdge[84, 85] -> 
             RGBColor[
              0.5977562892885417, 0.6838749659369165, 0.9617840670375721], 
             UndirectedEdge[55, 98] -> 
             RGBColor[
              0.6519280724937404, 0.720949959548256, 0.9475605823681849], 
             UndirectedEdge[86, 92] -> 
             RGBColor[
              0.6964899032561532, 0.7588394950681209, 0.9400718080386092], 
             UndirectedEdge[72, 92] -> 
             RGBColor[
              0.6925174795322071, 0.714862894108918, 0.6316521878882368], 
             UndirectedEdge[19, 99] -> 
             RGBColor[
              0.3336787496135457, 0.4504814543363085, 0.9431855922802397], 
             UndirectedEdge[4, 76] -> 
             RGBColor[
              0.4694355667616086, 0.5790822321849334, 0.9516692995414732], 
             UndirectedEdge[23, 76] -> 
             RGBColor[
              0.6724294505905137, 0.7422260400256662, 0.9692162068589585], 
             UndirectedEdge[9, 72] -> 
             RGBColor[
              0.8814051747100815, 0.8666971194939361, 0.6479156543279192], 
             UndirectedEdge[2, 44] -> 
             RGBColor[
              0.5102242260406127, 0.6132620378960381, 0.9545858665682916], 
             UndirectedEdge[74, 88] -> 
             RGBColor[
              0.5278747457242696, 0.6251606176368234, 0.9568449491263417], 
             UndirectedEdge[21, 49] -> 
             RGBColor[
              0.5185958290846993, 0.616290842129642, 0.9566062039374492], 
             UndirectedEdge[21, 34] -> 
             RGBColor[
              0.5296088897177638, 0.6258298017174805, 0.9573079464225209], 
             UndirectedEdge[59, 66] -> 
             RGBColor[
              0.34351240304929953`, 0.4719549109110778, 0.9431092844595783], 
             UndirectedEdge[17, 99] -> 
             RGBColor[
              0.7197148505574562, 0.7195020516227463, 0.6161505980420516], 
             UndirectedEdge[26, 53] -> 
             RGBColor[
              0.6769300680740886, 0.7013618617499754, 0.6306589718135323], 
             UndirectedEdge[23, 50] -> 
             RGBColor[
              0.8953054617643066, 0.885846237716369, 0.661406161981744], 
             UndirectedEdge[41, 74] -> 
             RGBColor[
              0.3551063372101424, 0.48199699395312534`, 0.9438480396921938], 
             UndirectedEdge[59, 79] -> 
             RGBColor[
              0.39169454331895676`, 0.5136878591078706, 0.9461794078317671], 
             UndirectedEdge[56, 93] -> 
             RGBColor[
              0.37415868992563706`, 0.49849918427619594`, 0.9450620387598911],
              UndirectedEdge[19, 98] -> 
             RGBColor[
              0.5696353709690907, 0.6376695040927172, 0.9427564401383957], 
             UndirectedEdge[2, 38] -> 
             RGBColor[
              0.4384310061593676, 0.5532152475011285, 0.9494208374957731], 
             UndirectedEdge[19, 59] -> 
             RGBColor[
              0.2612197015246498, 0.3886744554555389, 0.9383051422297892], 
             UndirectedEdge[24, 76] -> 
             RGBColor[
              0.7305811118963581, 0.7885775791779595, 0.974172771096774], 
             UndirectedEdge[5, 20] -> 
             RGBColor[
              0.5268738026764624, 0.6267789142639006, 0.9558965822304744], 
             UndirectedEdge[37, 84] -> 
             RGBColor[
              0.5669920847146128, 0.6588991987521787, 0.9593621961605179], 
             UndirectedEdge[9, 82] -> 
             RGBColor[
              0.6105957912309722, 0.691518315346179, 0.9643553113117262], 
             UndirectedEdge[47, 75] -> 
             RGBColor[
              0.5864031566354251, 0.6693376903054807, 0.9633446360037824], 
             UndirectedEdge[51, 75] -> 
             RGBColor[
              0.5013668864989553, 0.6028314612368455, 0.9548889839541247], 
             UndirectedEdge[58, 63] -> 
             RGBColor[
              0.6514579760244663, 0.6145167107472813, 0.6003429707766408], 
             UndirectedEdge[7, 25] -> 
             RGBColor[
              0.6434614246736143, 0.42049014071974455`, 0.5659170902397461], 
             UndirectedEdge[1, 55] -> 
             RGBColor[
              0.3625961621732359, 0.4884843038866086, 0.9443252847158499], 
             UndirectedEdge[82, 86] -> 
             RGBColor[
              0.6973222081607728, 0.7595603957436414, 0.9401248417711533], 
             UndirectedEdge[34, 71] -> 
             RGBColor[
              0.5013015452102499, 0.6036347850696613, 0.9545419860996813], 
             UndirectedEdge[41, 73] -> 
             RGBColor[
              0.2891303104472822, 0.4193952460530992, 0.9398438995456763], 
             UndirectedEdge[92, 94] -> 
             RGBColor[
              0.475457337217717, 0.584155829287198, 0.9520922800548524], 
             UndirectedEdge[3, 62] -> 
             RGBColor[
              0.6882926152563622, 0.7547384900351055, 0.9708862515072076], 
             UndirectedEdge[70, 75] -> 
             RGBColor[
              0.3625961621732359, 0.4884843038866086, 0.9443252847158499], 
             UndirectedEdge[57, 96] -> 
             RGBColor[
              0.9301681935372632, 0.760847187984948, 0.2626698932381551], 
             UndirectedEdge[68, 72] -> 
             RGBColor[
              0.6538357854826178, 0.6813587549216367, 0.629187424548276], 
             UndirectedEdge[13, 54] -> 
             RGBColor[
              0.456193206139892, 0.5681036258613348, 0.9506897711912808], 
             UndirectedEdge[48, 96] -> 
             RGBColor[
              0.8482857331989091, 0.820386566730877, 0.6269293265401106], 
             UndirectedEdge[30, 50] -> 
             RGBColor[
              0.977843258223327, 0.9502288856850554, 0.6180959799760569], 
             UndirectedEdge[11, 92] -> 
             RGBColor[
              0.6792057841909991, 0.7459490273694764, 0.9693293131956884], 
             UndirectedEdge[41, 56] -> 
             RGBColor[
              0.336022578086206, 0.46546760097759454`, 0.9426320394359221], 
             UndirectedEdge[73, 91] -> 
             RGBColor[
              0.29662013541037574`, 0.4258825559865824, 0.9403211445693325], 
             UndirectedEdge[32, 39] -> 
             RGBColor[
              0.6600031432442972, 0.5021126588856858, 0.5759139197358353], 
             UndirectedEdge[32, 80] -> 
             RGBColor[
              0.4582445310922102, 0.5710282064985155, 0.9505033320413214], 
             UndirectedEdge[20, 66] -> 
             RGBColor[
              0.469480594875806, 0.5772030432374944, 0.9522021703155055], 
             UndirectedEdge[47, 88] -> 
             RGBColor[
              0.7516817401864588, 0.8060140040556956, 0.9758643004142742], 
             UndirectedEdge[14, 53] -> 
             RGBColor[
              0.6665206114329072, 0.7346124798810338, 0.9634233640269214], 
             UndirectedEdge[51, 57] -> 
             RGBColor[
              0.7848805178525823, 0.7083673138580927, 0.6067725012468519], 
             UndirectedEdge[30, 94] -> 
             RGBColor[
              0.7575850284292789, 0.8087339208481366, 0.9261121061927341], 
             UndirectedEdge[22, 69] -> 
             RGBColor[
              0.4096995710341216, 0.5292829091557406, 0.9473266722765565], 
             UndirectedEdge[4, 94] -> 
             RGBColor[
              0.47205334814135325`, 0.5812074650387173, 0.9518753808809358], 
             UndirectedEdge[4, 86] -> 
             RGBColor[
              0.6930859141797895, 0.7558911308196401, 0.9398549088646928], 
             UndirectedEdge[9, 94] -> 
             RGBColor[
              0.6643450323955915, 0.7359900546722162, 0.9683557464945347], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.7437963477463096, 0.797343596411864, 0.91683085606283], 
             UndirectedEdge[12, 60] -> 
             RGBColor[
              0.5676305864320215, 0.6592069623006221, 0.9595424465466724], 
             UndirectedEdge[25, 40] -> 
             RGBColor[
              0.684434119437049, 0.45381178462557537`, 0.5691265398353487], 
             UndirectedEdge[22, 95] -> 
             RGBColor[
              0.6451885474286111, 0.4499463202255459, 0.5696916705809758], 
             UndirectedEdge[3, 33] -> 
             RGBColor[
              0.7460339984027584, 0.7991602220197824, 0.91700701211929], 
             UndirectedEdge[48, 93] -> 
             RGBColor[
              0.57578986094091, 0.663574415643372, 0.9612049893545737], 
             UndirectedEdge[15, 90] -> 
             RGBColor[
              0.6946016660584466, 0.6987036601112402, 0.6142869845532454], 
             UndirectedEdge[77, 97] -> 
             RGBColor[
              0.7874433538894662, 0.5371527088022043, 0.5783980247573565], 
             UndirectedEdge[44, 78] -> 
             RGBColor[
              0.532160768674642, 0.6310711114363269, 0.9563127915606457], 
             UndirectedEdge[30, 92] -> 
             RGBColor[
              0.7030034823600401, 0.7635412808465789, 0.9220586372773817], 
             UndirectedEdge[37, 76] -> 
             RGBColor[
              0.4935412160557206, 0.5997180188292675, 0.9532725189104017], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.8680934793688736, 0.8977832527544947, 0.9855927796353707], 
             UndirectedEdge[75, 96] -> 
             RGBColor[
              0.6466545621836362, 0.6553113353637008, 0.610786375945428], 
             UndirectedEdge[31, 80] -> 
             RGBColor[
              0.6746134242630042, 0.7434066727629149, 0.9700399309527306], 
             UndirectedEdge[85, 90] -> 
             RGBColor[
              0.48100582548045234`, 0.5891308470482136, 0.9523990754332494], 
             UndirectedEdge[91, 93] -> 
             RGBColor[
              0.37415868992563706`, 0.49849918427619594`, 0.9450620387598911],
              UndirectedEdge[22, 49] -> 
             RGBColor[
              0.39497167993022364`, 0.5165263501268748, 0.9463882240787789], 
             UndirectedEdge[69, 87] -> 
             RGBColor[
              0.49519770650469513`, 0.5988811465472912, 0.9540057302078515], 
             UndirectedEdge[47, 70] -> 
             RGBColor[
              0.6054869157593615, 0.6858670832810115, 0.9645606362600541], 
             UndirectedEdge[42, 78] -> 
             RGBColor[
              0.4378432409887143, 0.551514897725629, 0.9497125335122762], 
             UndirectedEdge[1, 43] -> 
             RGBColor[
              0.5019402792868549, 0.6045916149396704, 0.9544711724080074], 
             UndirectedEdge[10, 35] -> 
             RGBColor[
              0.8535271847446179, 0.524520924340115, 0.5767814739448329], 
             UndirectedEdge[67, 94] -> 
             RGBColor[
              0.5835517246960136, 0.6727926046706618, 0.9603584758699228], 
             UndirectedEdge[73, 93] -> 
             RGBColor[
              0.32726642228671327`, 0.45242682935170053`, 0.9422738988696453],
              UndirectedEdge[68, 82] -> 
             RGBColor[
              0.38302640200350835`, 0.5061799507738796, 0.9456270815320831], 
             UndirectedEdge[11, 52] -> 
             RGBColor[
              0.9635474535091303, 0.9714426557741234, 0.9066577925160435], 
             UndirectedEdge[15, 53] -> 
             RGBColor[
              0.6703500850600312, 0.6776981595703153, 0.6127416952568574], 
             UndirectedEdge[53, 100] -> 
             RGBColor[
              0.6874160709019217, 0.7500402484876363, 0.9210654212026771], 
             UndirectedEdge[58, 83] -> 
             RGBColor[
              0.9546547193076778, 0.8565745861124845, 0.5474342621289487], 
             UndirectedEdge[74, 96] -> 
             RGBColor[
              0.6657383213075726, 0.6718407283392316, 0.6120023762016995], 
             UndirectedEdge[8, 87] -> 
             RGBColor[
              0.4890748532719983, 0.5935778388206807, 0.9536155874140906], 
             UndirectedEdge[43, 46] -> 
             RGBColor[
              0.48279176737940804`, 0.5880061363576323, 0.953251046161629], 
             UndirectedEdge[73, 89] -> 
             RGBColor[
              0.3269085496351144, 0.4521168580480881, 0.9422510955407397], 
             UndirectedEdge[11, 67] -> 
             RGBColor[
              0.7873001716692956, 0.8345858027529403, 0.9775955090107589], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.9203672856885283, 0.8791750216265528, 0.634387979706645], 
             UndirectedEdge[98, 99] -> 
             RGBColor[
              0.7243871205826363, 0.7827569584290257, 0.9524410324186354], 
             UndirectedEdge[4, 9] -> 
             RGBColor[
              0.6063594972499889, 0.6878490504221777, 0.9640853784052658], 
             UndirectedEdge[34, 49] -> 
             RGBColor[
              0.3545254636823641, 0.4814938704989162, 0.94381102694465], 
             UndirectedEdge[6, 7] -> 
             RGBColor[
              0.6979681759040541, 0.7617653150459365, 0.9641798692392154], 
             UndirectedEdge[7, 40] -> 
             RGBColor[
              0.49214854096325883`, 0.5985292179518991, 0.9531789534496875], 
             UndirectedEdge[23, 85] -> 
             RGBColor[
              0.6719315506926968, 0.7418218224584836, 0.9691770103551349], 
             UndirectedEdge[82, 92] -> 
             RGBColor[
              0.4217080960530977, 0.5396840899611609, 0.9480918448720439], 
             UndirectedEdge[34, 69] -> 
             RGBColor[
              0.369253354786262, 0.49425042952778203`, 0.9447494751424277], 
             UndirectedEdge[13, 85] -> 
             RGBColor[
              0.4647416864923106, 0.5750436673160795, 0.9513627388787385], 
             UndirectedEdge[95, 98] -> 
             RGBColor[
              0.9021449399921279, 0.6543699296469272, 0.5708640288703817], 
             UndirectedEdge[34, 87] -> 
             RGBColor[
              0.4914828760338618, 0.5956635471062637, 0.9537690244951457], 
             UndirectedEdge[61, 94] -> 
             RGBColor[
              0.7620617381295739, 0.8095521683663478, 0.776834191766445], 
             UndirectedEdge[61, 72] -> 
             RGBColor[
              0.979121880444064, 0.9402592331880678, 0.45639409959982946`], 
             UndirectedEdge[50, 86] -> 
             RGBColor[
              0.9713296791194401, 0.9455270999065974, 0.6361091507372845], 
             UndirectedEdge[66, 97] -> 
             RGBColor[
              0.5898028970385638, 0.3751950536707855, 0.5626528312552341], 
             UndirectedEdge[9, 21] -> 
             RGBColor[
              0.746165218312163, 0.8016292067019415, 0.9753344337170924], 
             UndirectedEdge[34, 60] -> 
             RGBColor[
              0.5243738211826616, 0.6217401263898643, 0.9567861637154389], 
             UndirectedEdge[53, 84] -> 
             RGBColor[
              0.5307030130387462, 0.6277107439973828, 0.9569826598908013], 
             UndirectedEdge[21, 22] -> 
             RGBColor[
              0.5700551059656234, 0.660862281345439, 0.9598851435566498], 
             UndirectedEdge[14, 62] -> 
             RGBColor[
              0.9069865297020667, 0.9284734086465884, 0.9841586386387451], 
             UndirectedEdge[22, 30] -> 
             RGBColor[
              0.715781065191375, 0.7746085808750945, 0.9228728135566215], 
             UndirectedEdge[67, 72] -> 
             RGBColor[
              0.8006118670105036, 0.8034996694923818, 0.6399183837033072], 
             UndirectedEdge[61, 86] -> 
             RGBColor[
              0.9830943041680101, 0.9842358341472707, 0.764813719750202], 
             UndirectedEdge[5, 83] -> 
             RGBColor[
              0.7234143537929081, 0.7803157407586288, 0.895125531268243], 
             UndirectedEdge[46, 99] -> 
             RGBColor[
              0.41590669835468497`, 0.5337058241853401, 0.9479856085199221], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.48046981540079725`, 0.5861245875184253, 0.953067282010074], 
             UndirectedEdge[7, 37] -> 
             RGBColor[
              0.45672747889189946`, 0.5697728040617076, 0.9503904776918044], 
             UndirectedEdge[7, 53] -> 
             RGBColor[
              0.4204384072160328, 0.5385843493069117, 0.9480109414220879], 
             UndirectedEdge[12, 52] -> 
             RGBColor[
              0.7208055922994445, 0.7779584740016023, 0.8863605524361995], 
             UndirectedEdge[50, 85] -> 
             RGBColor[
              0.7471814318034422, 0.768313983704708, 0.6478843449102414], 
             UndirectedEdge[14, 15] -> 
             RGBColor[
              0.947169728260697, 0.900349514883594, 0.630112680293688], 
             UndirectedEdge[14, 35] -> 
             RGBColor[
              0.8803296273167864, 0.5456954175971562, 0.572506174531876], 
             UndirectedEdge[8, 95] -> 
             RGBColor[
              0.602334308418888, 0.4128281323120043, 0.5669610363657919], 
             UndirectedEdge[7, 84] -> 
             RGBColor[
              0.5614404520225376, 0.6543339687365393, 0.9589412223227985], 
             UndirectedEdge[14, 76] -> 
             RGBColor[
              0.7340717875805196, 0.7911809193877501, 0.9682639676775158], 
             UndirectedEdge[60, 89] -> 
             RGBColor[
              0.5436491747743358, 0.6384354688635316, 0.9580143722017744], 
             UndirectedEdge[37, 85] -> 
             RGBColor[
              0.4930433161579036, 0.5993138012620849, 0.9532333224065781], 
             UndirectedEdge[39, 80] -> 
             RGBColor[
              0.6538106669662354, 0.49705095429544066`, 0.5754359227867027], 
             UndirectedEdge[23, 24] -> 
             RGBColor[
              0.8782072419594054, 0.9057056156224377, 0.987655391664453], 
             UndirectedEdge[11, 68] -> 
             RGBColor[
              0.6405240901414098, 0.7124448881821952, 0.9668645498557276], 
             UndirectedEdge[27, 81] -> 
             RGBColor[
              0.56364928617064, 0.6562611293838478, 0.9590472378143744], 
             UndirectedEdge[36, 61] -> 
             RGBColor[
              0.6764142023849835, 0.737451729530042, 0.7708012254595553], 
             UndirectedEdge[28, 59] -> 
             RGBColor[
              0.357336611506684, 0.4839287454519442, 0.9439901507982152], 
             UndirectedEdge[8, 30] -> 
             RGBColor[
              0.6729268261816518, 0.7374903929615529, 0.9201421793414375], 
             UndirectedEdge[34, 82] -> 
             RGBColor[
              0.39403946263657297`, 0.515718910361718, 0.9463288240171548], 
             UndirectedEdge[50, 84] -> 
             RGBColor[
              0.8211302003601515, 0.8278993811948019, 0.6540132186641812], 
             UndirectedEdge[57, 88] -> 
             RGBColor[
              0.7923046179539602, 0.7141670772825397, 0.6075124661627972], 
             UndirectedEdge[6, 53] -> 
             RGBColor[
              0.6672307369202628, 0.7351420903067798, 0.9622213068072182], 
             UndirectedEdge[8, 69] -> 
             RGBColor[
              0.36684533202439845`, 0.492164721242199, 0.9445960380613726], 
             UndirectedEdge[69, 99] -> 
             RGBColor[
              0.4306993422420934, 0.5465184688207132, 0.9489281827078064], 
             UndirectedEdge[81, 84] -> 
             RGBColor[
              0.6692321012842397, 0.7415284709663823, 0.9676664595926034], 
             UndirectedEdge[11, 94] -> 
             RGBColor[
              0.7337873302602379, 0.7911416673710342, 0.9733827821110408], 
             UndirectedEdge[10, 65] -> 
             RGBColor[
              0.7678795947330346, 0.8191564169498979, 0.9773491114476334], 
             UndirectedEdge[79, 98] -> 
             RGBColor[
              0.7001102127633976, 0.762682907745049, 0.9506307057403737], 
             UndirectedEdge[33, 62] -> 
             RGBColor[
              0.9283741879169568, 0.9441047140835411, 0.9336436888258202], 
             UndirectedEdge[31, 70] -> 
             RGBColor[
              0.6394273575045162, 0.7129302702398495, 0.9677979058926969], 
             UndirectedEdge[31, 32] -> 
             RGBColor[0.680805900541066, 0.74846837735316, 0.970517927901863],
              UndirectedEdge[15, 100] -> 
             RGBColor[
              0.9680651877297115, 0.9157772834901965, 0.5877547374694437], 
             UndirectedEdge[7, 65] -> 
             RGBColor[
              0.5485998330883288, 0.6443027796328171, 0.9576613894298429], 
             UndirectedEdge[59, 95] -> 
             RGBColor[
              0.593729270547687, 0.40537488100974894`, 0.5664127309617751], 
             UndirectedEdge[2, 3] -> 
             RGBColor[
              0.49719146248462764`, 0.6026814533219819, 0.9535598796805784], 
             UndirectedEdge[48, 88] -> 
             RGBColor[
              0.7104221576156062, 0.7737064560284688, 0.9717718994647526], 
             UndirectedEdge[14, 38] -> 
             RGBColor[
              0.6658858838626083, 0.7340627107619763, 0.9633829197474095], 
             UndirectedEdge[44, 45] -> 
             RGBColor[
              0.6018615053496925, 0.6872077652732347, 0.9621072446838079], 
             UndirectedEdge[24, 50] -> 
             RGBColor[
              0.953457123070151, 0.9321977768686622, 0.6663627262195595], 
             UndirectedEdge[38, 62] -> 
             RGBColor[
              0.6295321589311023, 0.7052722842142523, 0.9667472093224024], 
             UndirectedEdge[4, 50] -> 
             RGBColor[
              0.6923115779354014, 0.7227024298756362, 0.6438592546642586], 
             UndirectedEdge[48, 74] -> 
             RGBColor[
              0.5642273331885088, 0.6535595352537846, 0.9604682353105325], 
             UndirectedEdge[40, 100] -> 
             RGBColor[
              0.7591262046491477, 0.8099851171326236, 0.9262334332302766], 
             UndirectedEdge[19, 95] -> 
             RGBColor[
              0.5114365690230371, 0.3220944255542101, 0.561608588731986], 
             UndirectedEdge[19, 79] -> 
             RGBColor[
              0.30940184179430696`, 0.43040740365233177`, 0.941375265601978], 
             UndirectedEdge[51, 70] -> 
             RGBColor[
              0.5204506456228917, 0.6193608542123763, 0.9561049842103964], 
             UndirectedEdge[17, 22] -> 
             RGBColor[
              0.6987150793494844, 0.7022664919577737, 0.6145490876108017], 
             UndirectedEdge[59, 99] -> 
             RGBColor[
              0.41597145113819545`, 0.5337619097918473, 0.9479897345100288], 
             UndirectedEdge[20, 63] -> 
             RGBColor[
              0.4887925945355468, 0.593930126693436, 0.9534327138568934], 
             UndirectedEdge[56, 89] -> 
             RGBColor[
              0.37380081727403824`, 0.4981892129725835, 0.9450392354309856], 
             UndirectedEdge[12, 74] -> 
             RGBColor[
              0.41686598805566033`, 0.5354900993852049, 0.9477833100321552], 
             UndirectedEdge[8, 17] -> 
             RGBColor[
              0.6558608403397613, 0.6651483040442321, 0.6118184533956179], 
             UndirectedEdge[53, 90] -> 
             RGBColor[
              0.41395254923065683`, 0.5329666251086799, 0.9475976682864787], 
             UndirectedEdge[21, 72] -> 
             RGBColor[
              0.8289192115180174, 0.825694686140201, 0.6426843440261468], 
             UndirectedEdge[48, 73] -> 
             RGBColor[
              0.49825130642564863`, 0.5909577873537585, 0.9564640951640151], 
             UndirectedEdge[8, 49] -> 
             RGBColor[
              0.35211744092050057`, 0.47940816221333316`, 0.943657589863595], 
             UndirectedEdge[17, 69] -> 
             RGBColor[
              0.6619836935724581, 0.6704516117708426, 0.6122085961893788], 
             UndirectedEdge[21, 82] -> 
             RGBColor[
              0.5581098280389081, 0.6505158819924439, 0.959124001009954], 
             UndirectedEdge[36, 68] -> 
             RGBColor[
              0.3511281074235374, 0.478551251263611, 0.9435945504080018], 
             UndirectedEdge[21, 30] -> 
             RGBColor[
              0.8394052143458504, 0.8743730728778618, 0.9330907934152917], 
             UndirectedEdge[56, 64] -> 
             RGBColor[
              0.5864031566354251, 0.6693376903054807, 0.9633446360037824], 
             UndirectedEdge[48, 64] -> 
             RGBColor[
              0.788034327650698, 0.8344129216726568, 0.9794875865984649], 
             UndirectedEdge[46, 59] -> 
             RGBColor[
              0.34344765026578905`, 0.4718988253045705, 0.9431051584694716], 
             UndirectedEdge[46, 79] -> 
             RGBColor[
              0.3916297905354463, 0.5136317735013635, 0.9461752818416604], 
             UndirectedEdge[9, 86] -> 
             RGBColor[
              0.8853775984340277, 0.910673720453139, 0.9563352744782916], 
             UndirectedEdge[64, 91] -> 
             RGBColor[
              0.5864031566354251, 0.6693376903054807, 0.9633446360037824], 
             UndirectedEdge[1, 19] -> 
             RGBColor[
              0.28030346064858613`, 0.4052038484310697, 0.9395211424860608], 
             UndirectedEdge[5, 69] -> 
             RGBColor[
              0.41563350195385385`, 0.5342873409663498, 0.9477421445723249], 
             UndirectedEdge[36, 92] -> 
             RGBColor[
              0.3898098014731267, 0.5120553904508923, 0.9460593137479626], 
             UndirectedEdge[17, 95] -> 
             RGBColor[
              0.8974726699669477, 0.5911150228406479, 0.23457359449379803`], 
             UndirectedEdge[7, 13] -> 
             RGBColor[
              0.42842584922630655`, 0.5455026701157024, 0.948519894163965], 
             UndirectedEdge[11, 61] -> 
             RGBColor[
              0.965810185102856, 0.9713453664486262, 0.7940712249072811], 
             UndirectedEdge[66, 83] -> 
             RGBColor[
              0.6660211459922516, 0.7307398697322226, 0.8914311193532741], 
             UndirectedEdge[27, 37] -> 
             RGBColor[
              0.46140926960101325`, 0.5736318571696442, 0.9507429743822889], 
             UndirectedEdge[22, 34] -> 
             RGBColor[
              0.40598474056328826`, 0.5260653097147132, 0.9470899665638506], 
             UndirectedEdge[6, 90] -> 
             RGBColor[
              0.6914823179186781, 0.7561475908477047, 0.9637665961036062], 
             UndirectedEdge[71, 77] -> 
             RGBColor[
              0.6879289414280878, 0.7560534806132417, 0.9695854371167318], 
             UndirectedEdge[9, 68] -> 
             RGBColor[
              0.5710817922767634, 0.6572932754833771, 0.9618375142392215], 
             UndirectedEdge[23, 86] -> 
             RGBColor[
              0.8960797980086948, 0.9190349386603729, 0.957401816182178], 
             UndirectedEdge[54, 84] -> 
             RGBColor[
              0.5892078089361231, 0.6769349244821719, 0.9611110993501144], 
             UndirectedEdge[3, 16] -> 
             RGBColor[
              0.5037147750857152, 0.6079773723634284, 0.9540734187442175], 
             UndirectedEdge[66, 98] -> 
             RGBColor[
              0.6519280724937404, 0.720949959548256, 0.9475605823681849], 
             UndirectedEdge[64, 93] -> 
             RGBColor[
              0.6170494435117626, 0.6958819636705988, 0.9652973903040951], 
             UndirectedEdge[2, 29] -> 
             RGBColor[
              0.525111232330502, 0.6253479802541608, 0.9557578262363324], 
             UndirectedEdge[50, 81] -> 
             RGBColor[
              0.8186572437991402, 0.8259674887341739, 0.6537667374652726], 
             UndirectedEdge[8, 99] -> 
             RGBColor[
              0.4245764890093965, 0.5412151610941027, 0.9485380399140455], 
             UndirectedEdge[66, 69] -> 
             RGBColor[
              0.3582402941531974, 0.48471146993994363`, 0.944047732657356], 
             UndirectedEdge[9, 30] -> 
             RGBColor[
              0.8918911775379146, 0.9153755062315969, 0.938322103717064], 
             UndirectedEdge[11, 36] -> 
             RGBColor[
              0.6481397945156476, 0.7190412285347284, 0.9673498158041511], 
             UndirectedEdge[16, 62] -> 
             RGBColor[
              0.6860549645999134, 0.7529218644271871, 0.9707100954507476], 
             UndirectedEdge[50, 76] -> 
             RGBColor[
              0.7476793317012593, 0.7687182012718907, 0.6479235414140649], 
             UndirectedEdge[36, 86] -> 
             RGBColor[
              0.6654239135808018, 0.7319316962333728, 0.938092310647072], 
             UndirectedEdge[60, 71] -> 
             RGBColor[
              0.6601368420774829, 0.734342081372771, 0.9668153803853984], 
             UndirectedEdge[43, 54] -> 
             RGBColor[
              0.5644555986517663, 0.6572895092772673, 0.958855158876305], 
             UndirectedEdge[29, 42] -> 
             RGBColor[
              0.45258743145809566`, 0.563484895766884, 0.9508732501957753], 
             UndirectedEdge[76, 84] -> 
             RGBColor[
              0.5982541891863588, 0.6842791835040991, 0.9618232635413957], 
             UndirectedEdge[65, 90] -> 
             RGBColor[
              0.5421139751029529, 0.6386850554345853, 0.9572481162942338], 
             UndirectedEdge[52, 78] -> 
             RGBColor[
              0.7609313571399453, 0.8105687509240644, 0.8895099021626989], 
             UndirectedEdge[25, 65] -> 
             RGBColor[
              0.7408854115621191, 0.49958534630649337`, 0.5736089758155041], 
             UndirectedEdge[45, 52] -> 
             RGBColor[
              0.8306320938149958, 0.8667054047609724, 0.895304355285861], 
             UndirectedEdge[57, 74] -> 
             RGBColor[
              0.6461097935268629, 0.5940201565078558, 0.5962088020085771], 
             UndirectedEdge[17, 66] -> 
             RGBColor[
              0.6472558024685603, 0.6576950527419767, 0.6112701479916012], 
             UndirectedEdge[59, 98] -> 
             RGBColor[
              0.6519280724937404, 0.720949959548256, 0.9475605823681849], 
             UndirectedEdge[22, 77] -> 
             RGBColor[
              0.592612136781126, 0.6784840052582937, 0.9621334175809013], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.3916314398747094, 0.5136332020761349, 0.9461753869360998], 
             UndirectedEdge[30, 36] -> 
             RGBColor[
              0.6719374926846886, 0.7366334820118308, 0.9200791398858443], 
             UndirectedEdge[60, 64] -> 
             RGBColor[
              0.7562515141357227, 0.8095839461964288, 0.9763197727745712], 
             UndirectedEdge[28, 99] -> 
             RGBColor[
              0.42979565959557997`, 0.5457357443327138, 0.9488706008486658], 
             UndirectedEdge[59, 69] -> 
             RGBColor[
              0.3582402941531974, 0.48471146993994363`, 0.944047732657356], 
             UndirectedEdge[66, 79] -> 
             RGBColor[
              0.39169454331895676`, 0.5136878591078706, 0.9461794078317671], 
             UndirectedEdge[7, 81] -> 
             RGBColor[
              0.5589674954615262, 0.6524020762759113, 0.95869474112389], 
             UndirectedEdge[26, 100] -> 
             RGBColor[
              0.9746451707437689, 0.9394409856698565, 0.6056720140261185], 
             UndirectedEdge[5, 97] -> 
             RGBColor[
              0.6471961048392202, 0.4247709246971917, 0.566347243170203], 
             UndirectedEdge[20, 83] -> 
             RGBColor[
              0.7919893378187581, 0.8359880020586392, 0.9005240052092014], 
             UndirectedEdge[21, 92] -> 
             RGBColor[
              0.5572775231342886, 0.6497949813169234, 0.95907096727741], 
             UndirectedEdge[77, 98] -> 
             RGBColor[
              0.8495685293446428, 0.8829076146796749, 0.9633057758703072], 
             UndirectedEdge[13, 84] -> 
             RGBColor[
              0.5386904550490199, 0.6346290648061734, 0.9574916126326785], 
             UndirectedEdge[83, 97] -> 
             RGBColor[
              0.9123116399815159, 0.6339800124919304, 0.51097466614893], 
             UndirectedEdge[4, 24] -> 
             RGBColor[
              0.6752133581305002, 0.7425618077817049, 0.9701084843469677], 
             UndirectedEdge[7, 85] -> 
             RGBColor[
              0.48749168346582833`, 0.5947485712464454, 0.9528123485688587], 
             UndirectedEdge[10, 40] -> 
             RGBColor[
              0.7114283026079646, 0.7733828552689799, 0.972866675467478], 
             UndirectedEdge[26, 40] -> 
             RGBColor[
              0.7486402018213147, 0.7613067303949628, 0.6358269838411318], 
             UndirectedEdge[56, 74] -> 
             RGBColor[
              0.3625961621732359, 0.4884843038866086, 0.9443252847158499], 
             UndirectedEdge[42, 62] -> 
             RGBColor[
              0.6070078511264196, 0.6857628608984638, 0.9653119803465514], 
             UndirectedEdge[4, 36] -> 
             RGBColor[
              0.38640581239676297`, 0.5091070262024116, 0.945842414574046], 
             UndirectedEdge[2, 33] -> 
             RGBColor[
              0.7372730351452222, 0.7920476773704175, 0.916317316999191], 
             UndirectedEdge[36, 82] -> 
             RGBColor[
              0.3906421063777462, 0.5127762911264129, 0.9461123474805067], 
             UndirectedEdge[76, 81] -> 
             RGBColor[
              0.5957812326253473, 0.6823472910434711, 0.9615767823424871], 
             UndirectedEdge[27, 43] -> 
             RGBColor[
              0.5413700324472946, 0.6385476066395713, 0.9570377785394737], 
             UndirectedEdge[61, 67] -> 
             RGBColor[
              0.8155745795386315, 0.852996303748254, 0.781046918666163], 
             UndirectedEdge[10, 26] -> 
             RGBColor[
              0.9269472687025858, 0.9028387238062128, 0.6523052562633198], 
             UndirectedEdge[63, 83] -> 
             RGBColor[
              0.6853331456519924, 0.7474669531881643, 0.892661662894662], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.4789432031134097, 0.5878085297917007, 0.9521393808814009], 
             UndirectedEdge[20, 97] -> 
             RGBColor[
              0.7157710888650703, 0.4804431859972021, 0.5717457171111614], 
             UndirectedEdge[28, 98] -> 
             RGBColor[
              0.6657522809511249, 0.7329237940891224, 0.9484414487068218], 
             UndirectedEdge[4, 23] -> 
             RGBColor[
              0.6170616968246558, 0.6962102686294117, 0.9651519201091522], 
             UndirectedEdge[30, 86] -> 
             RGBColor[
              0.9786175944677151, 0.9834175866290593, 0.9140916341764911], 
             UndirectedEdge[27, 54] -> 
             RGBColor[
              0.4836249938225235, 0.5916675828996372, 0.9524918775718855], 
             UndirectedEdge[1, 13] -> 
             RGBColor[
              0.3936778867749806, 0.5154057315237379, 0.9463057847229832], 
             UndirectedEdge[15, 35] -> 
             RGBColor[
              0.8841591009439105, 0.4887810972864378, 0.221824505761812], 
             UndirectedEdge[56, 73] -> 
             RGBColor[
              0.29662013541037574`, 0.4258825559865824, 0.9403211445693325], 
             UndirectedEdge[16, 29] -> 
             RGBColor[
              0.5316345449315896, 0.6306438992956074, 0.9562713652999715], 
             UndirectedEdge[53, 65] -> 
             RGBColor[
              0.5178623941045375, 0.6176795548936604, 0.9557028269978458], 
             UndirectedEdge[6, 25] -> 
             RGBColor[
              0.8902537543778444, 0.6170478817196128, 0.5801274556248764], 
             UndirectedEdge[68, 92] -> 
             RGBColor[
              0.38219409709888885`, 0.5054590500983591, 0.9455740477995391], 
             UndirectedEdge[69, 97] -> 
             RGBColor[
              0.6045307881424618, 0.38795161269965134`, 0.5635912794530118], 
             UndirectedEdge[17, 77] -> 
             RGBColor[
              0.8448962593194627, 0.8196527078733955, 0.6270153414937235], 
             UndirectedEdge[46, 98] -> 
             RGBColor[
              0.6518633197102299, 0.7208938739417489, 0.9475564563780782], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.7162123851022366, 0.7774050169672846, 0.9730841980629618], 
             UndirectedEdge[17, 55] -> 
             RGBColor[
              0.6472558024685603, 0.6576950527419767, 0.6112701479916012], 
             UndirectedEdge[2, 78] -> 
             RGBColor[
              0.5103670418611207, 0.6133779822129057, 0.9545971095528335], 
             UndirectedEdge[6, 35] -> 
             RGBColor[
              0.881039752804142, 0.5462250280229023, 0.5713041173121728], 
             UndirectedEdge[95, 99] -> 
             RGBColor[
              0.6661883186365829, 0.4671818798905185, 0.5712931810122257], 
             UndirectedEdge[66, 99] -> 
             RGBColor[
              0.41597145113819545`, 0.5337619097918473, 0.9479897345100288], 
             UndirectedEdge[31, 39] -> 
             RGBColor[
              0.8763720364150911, 0.6744911251500851, 0.5954505186472445], 
             UndirectedEdge[69, 71] -> 
             RGBColor[
              0.5050163756810833, 0.6068523845106888, 0.9547786918123872], 
             UndirectedEdge[64, 89] -> 
             RGBColor[
              0.6166915708601638, 0.6955719923669865, 0.9652745869751896], 
             UndirectedEdge[40, 53] -> 
             RGBColor[
              0.46141110197946744`, 0.5719059932127425, 0.9512203910176904], 
             UndirectedEdge[1, 27] -> 
             RGBColor[
              0.42110967445761205`, 0.5389696885620403, 0.9481078911035878], 
             UndirectedEdge[41, 48] -> 
             RGBColor[
              0.5376537491014789, 0.6305428323447707, 0.9587749900306046], 
             UndirectedEdge[57, 70] -> 
             RGBColor[
              0.6461097935268629, 0.5940201565078558, 0.5962088020085771], 
             UndirectedEdge[39, 44] -> 
             RGBColor[
              0.6937936159862281, 0.5295452869010351, 0.5785740295286602], 
             UndirectedEdge[6, 15] -> 
             RGBColor[
              0.9478798537480526, 0.9008791253093401, 0.6289106230739848], 
             UndirectedEdge[6, 40] -> 
             RGBColor[
              0.7389408706674887, 0.7950869589517673, 0.9673893188348177], 
             UndirectedEdge[17, 59] -> 
             RGBColor[
              0.6472558024685603, 0.6576950527419767, 0.6112701479916012], 
             UndirectedEdge[56, 91] -> 
             RGBColor[
              0.34351240304929953`, 0.4719549109110778, 0.9431092844595783], 
             UndirectedEdge[5, 59] -> 
             RGBColor[
              0.4009056108499559, 0.5215307819374839, 0.9468036963745472], 
             UndirectedEdge[20, 58] -> 
             RGBColor[
              0.758114168191232, 0.7030377596177562, 0.6082053130911802], 
             UndirectedEdge[17, 19] -> 
             RGBColor[
              0.5649631009439106, 0.5744145972864378, 0.6064660057618121], 
             UndirectedEdge[3, 38] -> 
             RGBColor[
              0.4471919694169038, 0.5603277921504934, 0.9501105326158723], 
             UndirectedEdge[1, 17] -> 
             RGBColor[
              0.6663395615924967, 0.6742244457175075, 0.6124861482478727], 
             UndirectedEdge[2, 42] -> 
             RGBColor[
              0.41590669835468497`, 0.5337058241853401, 0.9479856085199221], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.6406729825178495, 0.716343485804077, 0.9668026613200877], 
             UndirectedEdge[48, 56] -> 
             RGBColor[
              0.5451435740645725, 0.6370301422782538, 0.9592522350542609], 
             UndirectedEdge[86, 94] -> 
             RGBColor[
              0.751071449325392, 0.8040321350696786, 0.9441252769539616], 
             UndirectedEdge[23, 30] -> 
             RGBColor[
              0.9025933771125816, 0.9237367244388309, 0.9393886454209505], 
             UndirectedEdge[30, 82] -> 
             RGBColor[
              0.7038357872646596, 0.7642621815220993, 0.9221116710099257], 
             UndirectedEdge[60, 74] -> 
             RGBColor[
              0.5324445196735335, 0.6287305597775567, 0.9573004214866387], 
             UndirectedEdge[10, 90] -> 
             RGBColor[
              0.6639697498591539, 0.7344434871649173, 0.9692439527362664], 
             UndirectedEdge[49, 69] -> 
             RGBColor[
              0.3582402941531974, 0.48471146993994363`, 0.944047732657356], 
             UndirectedEdge[25, 100] -> 
             RGBColor[
              0.9104390883595033, 0.631946039900469, 0.5389715700203354], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.5895725278517635, 0.6776244235386479, 0.9608708390254455], 
             UndirectedEdge[31, 51] -> 
             RGBColor[
              0.7781980818302355, 0.8272774275900864, 0.9783616051309716], 
             UndirectedEdge[37, 50] -> 
             RGBColor[
              0.7164172272295134, 0.7433382165199702, 0.6454624740331871], 
             UndirectedEdge[6, 10] -> 
             RGBColor[
              0.9172479375487599, 0.9366189523630173, 0.9838675912570058], 
             UndirectedEdge[69, 77] -> 
             RGBColor[
              0.5558807510040997, 0.6466691250713625, 0.9597929261594782], 
             UndirectedEdge[12, 96] -> 
             RGBColor[
              0.7009243880660606, 0.7023171308622971, 0.6142444012617332], 
             UndirectedEdge[12, 41] -> 
             RGBColor[
              0.3902924039686304, 0.5124733964761908, 0.9460900647522275], 
             UndirectedEdge[89, 93] -> 
             RGBColor[
              0.40444710415037577`, 0.5247334863377017, 0.9469919897312984], 
             UndirectedEdge[37, 81] -> 
             RGBColor[
              0.5645191281536015, 0.6569673062915506, 0.9591157149616093], 
             UndirectedEdge[14, 24] -> 
             RGBColor[
              0.9398495789494112, 0.9546604949845217, 0.9867031524830103], 
             UndirectedEdge[52, 67] -> 
             RGBColor[
              0.813311847944906, 0.8530935930737511, 0.8936334862749256], 
             UndirectedEdge[23, 27] -> 
             RGBColor[
              0.6402975041358064, 0.7161398783660429, 0.9666866623308458], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.4833048033331905, 0.5891768777783608, 0.9530830366541425], 
             UndirectedEdge[23, 81] -> 
             RGBColor[
              0.7434073626883947, 0.7994753274879494, 0.9750594029101661], 
             UndirectedEdge[88, 96] -> 
             RGBColor[
              0.8119331457346699, 0.7919876491139157, 0.6233060403559196], 
             UndirectedEdge[77, 95] -> 
             RGBColor[
              0.7913697273985894, 0.5673325361411679, 0.5821579244638975], 
             UndirectedEdge[74, 91] -> 
             RGBColor[
              0.3625961621732359, 0.4884843038866086, 0.9443252847158499], 
             UndirectedEdge[7, 100] -> 
             RGBColor[
              0.718153509885713, 0.7766634732267927, 0.9230239836346743], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.5013011616372398, 0.6021439147278094, 0.9551517038464139], 
             UndirectedEdge[6, 100] -> 
             RGBColor[
              0.9649458395899431, 0.973221214226661, 0.9372343490198045], 
             UndirectedEdge[19, 55] -> 
             RGBColor[
              0.2612197015246498, 0.3886744554555389, 0.9383051422297892], 
             UndirectedEdge[17, 28] -> 
             RGBColor[
              0.6610800109259447, 0.6696688872828431, 0.6121510143302381], 
             UndirectedEdge[64, 96] -> 
             RGBColor[
              0.8895453157697618, 0.8526941147581037, 0.631021727489632], 
             UndirectedEdge[67, 68] -> 
             RGBColor[
              0.4902884845771854, 0.5940958254818229, 0.9538402436146096], 
             UndirectedEdge[22, 87] -> 
             RGBColor[
              0.5319290922817214, 0.6306960267342223, 0.9563462216292746], 
             UndirectedEdge[42, 44] -> 
             RGBColor[
              0.4377004251682063, 0.5513989534087612, 0.9497012905277343], 
             UndirectedEdge[70, 96] -> 
             RGBColor[
              0.6657383213075726, 0.6718407283392316, 0.6120023762016995], 
             UndirectedEdge[64, 88] -> 
             RGBColor[
              0.7516817401864588, 0.8060140040556956, 0.9758643004142742], 
             UndirectedEdge[26, 65] -> 
             RGBColor[
              0.8050914939463847, 0.8070802920758808, 0.6403094198212873], 
             UndirectedEdge[2, 14] -> 
             RGBColor[
              0.7158853769303322, 0.7764163719334647, 0.9668322668121158], 
             UndirectedEdge[11, 72] -> 
             RGBColor[
              0.950847472574728, 0.9218487321927542, 0.6529426899444253], 
             UndirectedEdge[67, 86] -> 
             RGBColor[
              0.8045842907344498, 0.8474762704515847, 0.9483380038536797], 
             UndirectedEdge[40, 90] -> 
             RGBColor[
              0.48566268297788284`, 0.5929114937536673, 0.9527656803140783], 
             UndirectedEdge[27, 84] -> 
             RGBColor[
              0.5661222427316515, 0.6581930218444758, 0.9592937190132831], 
             UndirectedEdge[13, 43] -> 
             RGBColor[
              0.5139382447646632, 0.614983649601269, 0.9552356721588691], 
             UndirectedEdge[52, 72] -> 
             RGBColor[
              0.9768591488503382, 0.9403565225135649, 0.568980667208592], 
             UndirectedEdge[10, 53] -> 
             RGBColor[
              0.6397181688607385, 0.7134379866239925, 0.9676986634398783], 
             UndirectedEdge[15, 40] -> 
             RGBColor[
              0.7420602188072573, 0.7376430282153028, 0.617909707284457], 
             UndirectedEdge[21, 68] -> 
             RGBColor[
              0.5185958290846993, 0.616290842129642, 0.9566062039374492], 
             UndirectedEdge[28, 83] -> 
             RGBColor[
              0.6798453544496361, 0.742713704273089, 0.8923119856919111], 
             UndirectedEdge[54, 100] -> 
             RGBColor[
              0.7459208667992986, 0.7992644289724253, 0.9251938606619902], 
             UndirectedEdge[47, 96] -> 
             RGBColor[
              0.8895453157697618, 0.8526941147581037, 0.631021727489632], 
             UndirectedEdge[47, 51] -> 
             RGBColor[
              0.7442576400850809, 0.8002142406312485, 0.9751243354983288], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.9108160033291908, 0.8715590883358699, 0.633476969868681], 
             UndirectedEdge[39, 45] -> 
             RGBColor[
              0.7636371684817866, 0.5857978850548107, 0.5843797256363643], 
             UndirectedEdge[58, 97] -> 
             RGBColor[
              0.8784364703539899, 0.5010297700510473, 0.2186559740309088], 
             UndirectedEdge[31, 45] -> 
             RGBColor[
              0.7844399257785555, 0.832153603522285, 0.9789837338023921], 
             UndirectedEdge[6, 26] -> 
             RGBColor[
              0.95445983676211, 0.9245428274890002, 0.6468278996306596], 
             UndirectedEdge[41, 91] -> 
             RGBColor[
              0.336022578086206, 0.46546760097759454`, 0.9426320394359221], 
             UndirectedEdge[8, 22] -> 
             RGBColor[
              0.4035767178014247, 0.5239796014291301, 0.9469365294827956], 
             UndirectedEdge[46, 95] -> 
             RGBColor[
              0.5936645177641765, 0.40531879540324167`, 0.5664086049716685], 
             UndirectedEdge[66, 95] -> 
             RGBColor[
              0.593729270547687, 0.40537488100974894`, 0.5664127309617751], 
             UndirectedEdge[23, 37] -> 
             RGBColor[
              0.6411673461187679, 0.7168460552737458, 0.9667551394780807], 
             UndirectedEdge[10, 100] -> 
             RGBColor[
              0.9374332715304188, 0.9515171105438736, 0.9427117056524648], 
             UndirectedEdge[5, 79] -> 
             RGBColor[
              0.4490877511196132, 0.5632637301342769, 0.949873819746736], 
             UndirectedEdge[38, 42] -> 
             RGBColor[
              0.3659072052869612, 0.49135216301385165`, 0.944536261455216], 
             UndirectedEdge[40, 54] -> 
             RGBColor[
              0.5199158978768443, 0.6211301736975315, 0.9553488304770035], 
             UndirectedEdge[32, 45] -> 
             RGBColor[
              0.5680710326077616, 0.6597751372578855, 0.959447134890983], 
             UndirectedEdge[41, 60] -> 
             RGBColor[
              0.5058709355865036, 0.6057138568685426, 0.9556071762067109], 
             UndirectedEdge[88, 91] -> 
             RGBColor[
              0.5087909866003333, 0.6086312246612926, 0.95562894887007], 
             UndirectedEdge[47, 57] -> 
             RGBColor[
              0.8699167879890521, 0.7748735429267279, 0.6152281532965096], 
             UndirectedEdge[27, 85] -> 
             RGBColor[
              0.4921734741749421, 0.5986076243543819, 0.9531648452593431], 
             UndirectedEdge[69, 95] -> 
             RGBColor[
              0.6084571616515848, 0.4181314400386148, 0.5673511791595528], 
             UndirectedEdge[36, 72] -> 
             RGBColor[
              0.6614514898568555, 0.68795509527417, 0.6296726904966994], 
             UndirectedEdge[6, 65] -> 
             RGBColor[
              0.7953921627925589, 0.8408605206326852, 0.9718717548149732], 
             UndirectedEdge[49, 77] -> 
             RGBColor[
              0.5411528599002019, 0.6339125660424967, 0.9588544779617006], 
             UndirectedEdge[2, 62] -> 
             RGBColor[
              0.679531651998826, 0.7476259453857406, 0.9701965563871087], 
             UndirectedEdge[22, 66] -> 
             RGBColor[
              0.39497167993022364`, 0.5165263501268748, 0.9463882240787789], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.5549545940371616, 0.6487162445383075, 0.9585279491871894], 
             UndirectedEdge[73, 88] -> 
             RGBColor[
              0.4618987189614095, 0.5625588697367973, 0.9528408089798241], 
             UndirectedEdge[8, 21] -> 
             RGBColor[
              0.5272008669559003, 0.6237440934318974, 0.9571545093414658], 
             UndirectedEdge[31, 75] -> 
             RGBColor[
              0.6203435983805797, 0.6964008772643187, 0.9665819056364253], 
             UndirectedEdge[4, 30] -> 
             RGBColor[
              0.6995994932836763, 0.7605929165980981, 0.9218417381034651], 
             UndirectedEdge[48, 91] -> 
             RGBColor[
              0.5451435740645725, 0.6370301422782538, 0.9592522350542609], 
             UndirectedEdge[19, 28] -> 
             RGBColor[
              0.2750439099820342, 0.40064828999640534`, 0.939186008568426], 
             UndirectedEdge[28, 66] -> 
             RGBColor[
              0.357336611506684, 0.4839287454519442, 0.9439901507982152], 
             UndirectedEdge[3, 29] -> 
             RGBColor[
              0.5338721955880383, 0.6324605249035258, 0.9564475213564316], 
             UndirectedEdge[22, 82] -> 
             RGBColor[
              0.4344856788844325, 0.5507513899896765, 0.9489060211512838], 
             UndirectedEdge[49, 82] -> 
             RGBColor[
              0.38302640200350835`, 0.5061799507738796, 0.9456270815320831], 
             UndirectedEdge[23, 84] -> 
             RGBColor[
              0.7458803192494061, 0.8014072199485774, 0.9753058841090747], 
             UndirectedEdge[65, 100] -> 
             RGBColor[
              0.8155774967742178, 0.8557586788135416, 0.9307158692104321], 
             UndirectedEdge[53, 85] -> 
             RGBColor[
              0.45675424448203694`, 0.5681253465072889, 0.9508537861368616], 
             UndirectedEdge[59, 97] -> 
             RGBColor[
              0.5898028970385638, 0.3751950536707855, 0.5626528312552341], 
             UndirectedEdge[17, 98] -> 
             RGBColor[
              0.9556714719130012, 0.9066901013791551, 0.6157214459002077], 
             UndirectedEdge[61, 68] -> 
             RGBColor[
              0.6687984980107458, 0.7308553891775089, 0.7703159595111317], 
             UndirectedEdge[28, 55] -> 
             RGBColor[
              0.357336611506684, 0.4839287454519442, 0.9439901507982152], 
             UndirectedEdge[9, 36] -> 
             RGBColor[
              0.5786974966510012, 0.6638896158359104, 0.9623227801876449], 
             UndirectedEdge[20, 59] -> 
             RGBColor[
              0.469480594875806, 0.5772030432374944, 0.9522021703155055], 
             UndirectedEdge[48, 57] -> 
             RGBColor[
              0.8286572054181993, 0.742565994899501, 0.611135752346988], 
             UndirectedEdge[1, 46] -> 
             RGBColor[
              0.36253140938972545`, 0.4884282182801013, 0.9443211587257432], 
             UndirectedEdge[5, 66] -> 
             RGBColor[
              0.4009056108499559, 0.5215307819374839, 0.9468036963745472], 
             UndirectedEdge[64, 74] -> 
             RGBColor[
              0.6054869157593615, 0.6858670832810115, 0.9645606362600541], 
             UndirectedEdge[55, 79] -> 
             RGBColor[
              0.39169454331895676`, 0.5136878591078706, 0.9461794078317671], 
             UndirectedEdge[32, 51] -> 
             RGBColor[
              0.5618291886594416, 0.654898961325687, 0.9588250062195625], 
             UndirectedEdge[64, 73] -> 
             RGBColor[
              0.5395108889965013, 0.6232653353809854, 0.9605564961135366], 
             UndirectedEdge[35, 38] -> 
             RGBColor[
              0.602875256545822, 0.32249429316482003`, 0.5550947452155335], 
             UndirectedEdge[71, 87] -> 
             RGBColor[
              0.6272458969286832, 0.7082655020891704, 0.9637982411651052], 
             UndirectedEdge[82, 87] -> 
             RGBColor[
              0.5199838143550061, 0.6203496273812271, 0.9555850790825788], 
             UndirectedEdge[5, 77] -> 
             RGBColor[
              0.5985460677008583, 0.6834884370689028, 0.9625488898766695], 
             UndirectedEdge[57, 64] -> 
             RGBColor[
              0.8699167879890521, 0.7748735429267279, 0.6152281532965095], 
             UndirectedEdge[63, 97] -> 
             RGBColor[
              0.6091148966983045, 0.39192213712672713`, 0.563883374796622], 
             UndirectedEdge[41, 93] -> 
             RGBColor[
              0.36666886496254353`, 0.49201187434271276`, 0.9445847937362348],
              UndirectedEdge[9, 61] -> 
             RGBColor[
              0.8963678872382096, 0.9161937537498083, 0.7890441892907749], 
             UndirectedEdge[17, 46] -> 
             RGBColor[
              0.6471910496850498, 0.6576389671354694, 0.6112660220014945], 
             UndirectedEdge[25, 54] -> 
             RGBColor[
              0.6712287815871999, 0.44309109646537703`, 0.5680869672670621], 
             UndirectedEdge[59, 77] -> 
             RGBColor[
              0.5411528599002019, 0.6339125660424967, 0.9588544779617006], 
             UndirectedEdge[66, 77] -> 
             RGBColor[
              0.5411528599002019, 0.6339125660424967, 0.9588544779617006], 
             UndirectedEdge[7, 27] -> 
             RGBColor[
              0.455857636908938, 0.5690666271540048, 0.9503220005445696], 
             UndirectedEdge[61, 92] -> 
             RGBColor[
              0.7074801920603351, 0.7643595283647902, 0.7727807228510926], 
             UndirectedEdge[77, 87] -> 
             RGBColor[
              0.6781102722516996, 0.7480822426498441, 0.9688124755121963], 
             UndirectedEdge[28, 79] -> 
             RGBColor[
              0.4055187517763412, 0.525661693648737, 0.9470602741704041], 
             UndirectedEdge[5, 28] -> 
             RGBColor[
              0.41472981930734043`, 0.5335046164783503, 0.9476845627131841], 
             UndirectedEdge[56, 88] -> 
             RGBColor[
              0.5087909866003333, 0.6086312246612926, 0.95562894887007], 
             UndirectedEdge[25, 26] -> 
             RGBColor[
              0.8999530855316702, 0.5832676531628083, 0.24856512063119046`], 
             UndirectedEdge[9, 67] -> 
             RGBColor[
              0.7178578738046493, 0.7794341900541223, 0.9725684733942528], 
             UndirectedEdge[32, 44] -> 
             RGBColor[
              0.4982274801122031, 0.6035225391041099, 0.9536414387832788], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.526211533458937, 0.6228871824821753, 0.9570914698858726], 
             UndirectedEdge[79, 83] -> 
             RGBColor[
              0.7142032862619089, 0.7724728179290155, 0.8945012427254629], 
             UndirectedEdge[60, 93] -> 
             RGBColor[
              0.5440070474259346, 0.638745440167144, 0.9580371755306799], 
             UndirectedEdge[5, 63] -> 
             RGBColor[
              0.4202176105096967, 0.5382578653934256, 0.948034239915935], 
             UndirectedEdge[19, 66] -> 
             RGBColor[
              0.2612197015246498, 0.3886744554555389, 0.9383051422297892], 
             UndirectedEdge[8, 86] -> 
             RGBColor[
              0.666413247077765, 0.7327886071830949, 0.9381553501026652], 
             UndirectedEdge[4, 37] -> 
             RGBColor[
              0.4381734622898627, 0.553702247433013, 0.9492082321605954], 
             UndirectedEdge[9, 92] -> 
             RGBColor[
              0.6097634863263527, 0.6907974146706585, 0.9643022775791823], 
             UndirectedEdge[3, 42] -> 
             RGBColor[
              0.4246676616122212, 0.540818368834705, 0.9486753036400213], 
             UndirectedEdge[7, 90] -> 
             RGBColor[
              0.44468998821444816`, 0.5595898498478364, 0.949556230718476], 
             UndirectedEdge[35, 62] -> 
             RGBColor[
              0.8439759023852803, 0.5169049910494321, 0.5758704641068689], 
             UndirectedEdge[20, 79] -> 
             RGBColor[
              0.5176627351454632, 0.6189359914342873, 0.9552722936876943], 
             UndirectedEdge[31, 78] -> 
             RGBColor[
              0.714739189103505, 0.776016949685377, 0.9731892806792299], 
             UndirectedEdge[13, 81] -> 
             RGBColor[
              0.5362174984880086, 0.6326971723455455, 0.9572451314337698], 
             UndirectedEdge[18, 80] -> 
             RGBColor[
              0.39778222893172394`, 0.5189607064096741, 0.9465673097758835], 
             UndirectedEdge[90, 100] -> 
             RGBColor[
              0.7116676519003371, 0.7710457490285609, 0.9226107104990651], 
             UndirectedEdge[67, 92] -> 
             RGBColor[
              0.5289701786267748, 0.6275999646691042, 0.9563050069545704], 
             UndirectedEdge[55, 66] -> 
             RGBColor[
              0.34351240304929953`, 0.4719549109110778, 0.9431092844595783], 
             UndirectedEdge[89, 91] -> 
             RGBColor[
              0.37380081727403824`, 0.4981892129725835, 0.9450392354309856], 
             UndirectedEdge[46, 55] -> 
             RGBColor[
              0.34344765026578905`, 0.4718988253045705, 0.9431051584694716], 
             UndirectedEdge[41, 64] -> 
             RGBColor[
              0.5789133316723316, 0.6628503803719975, 0.9628673909801262], 
             UndirectedEdge[28, 46] -> 
             RGBColor[
              0.3572718587231735, 0.4838726598454369, 0.9439860248081086], 
             UndirectedEdge[35, 53] -> 
             RGBColor[
              0.6035099841161207, 0.32304406228387755`, 0.5551351894950454], 
             UndirectedEdge[35, 90] -> 
             RGBColor[
              0.6277615651145361, 0.3440495628248023, 0.5566804787914333], 
             UndirectedEdge[5, 58] -> 
             RGBColor[
              0.689539184165382, 0.6473654983177458, 0.6028068391502218], 
             UndirectedEdge[76, 85] -> 
             RGBColor[
              0.5243054206296495, 0.6246937860140053, 0.9556943897874559], 
             UndirectedEdge[34, 77] -> 
             RGBColor[
              0.5521659205332665, 0.643451525630335, 0.9595562204467724], 
             UndirectedEdge[49, 71] -> 
             RGBColor[
              0.4902884845771854, 0.5940958254818229, 0.9538402436146096]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1.2}, VertexStyle -> {
             EdgeForm[None], 25 -> 
             RGBColor[
              0.8357470031474046, 0.27577270739342086`, 0.18186467662540728`],
              55 -> RGBColor[
              0.34351240304929953`, 0.4719549109110778, 0.9431092844595783], 
             90 -> RGBColor[
              0.4382041302290722, 0.5539721256496046, 0.9491429575828667], 27 -> 
             RGBColor[
              0.4605394276180518, 0.5729256802619412, 0.950674497235054], 15 -> 
             RGBColor[
              0.950999201887821, 0.8434351945728756, 0.27943101152362404`], 
             98 -> RGBColor[
              0.9603437419381813, 0.9699450081854344, 0.9520118802767914], 38 -> 
             RGBColor[
              0.3884315130916438, 0.5108615863296401, 0.945971490431067], 99 -> 
             RGBColor[
              0.4884304992270914, 0.5955689086726169, 0.9528701845604793], 71 -> 
             RGBColor[
              0.6370645661050712, 0.716236740052568, 0.9645712027696408], 41 -> 
             RGBColor[
              0.3285327531231125, 0.45898029104411137`, 0.9421547944122659], 
             75 -> RGBColor[
              0.34351240304929953`, 0.4719549109110778, 0.9431092844595783], 
             64 -> RGBColor[
              0.8292939102215507, 0.8667204696998837, 0.9835799875479865], 63 -> 
             RGBColor[
              0.38213640236878105`, 0.5054090778229611, 0.945570371542354], 
             85 -> RGBColor[
              0.5238075207318325, 0.6242895684468226, 0.9556551932836322], 3 -> 
             RGBColor[
              0.5059524257421638, 0.6097939979713468, 0.9542495748006775], 86 -> 
             RGBColor[
              0.9721040153638283, 0.9787158008506014, 0.9321048049377186], 94 -> 
             RGBColor[
              0.5300388832869558, 0.6293484692887558, 0.9561457489702048], 61 -> 
             RGBColor[
              0.994084592972192, 0.98975586744394, 0.5975226345626853], 84 -> 
             RGBColor[
              0.671705057845251, 0.7434603634270104, 0.967912940791512], 76 -> 
             RGBColor[
              0.5248033205274665, 0.6250980035811879, 0.9557335862912795], 21 -> 
             RGBColor[
              0.6936792551200989, 0.7606267733482064, 0.97010312341532], 87 -> 
             RGBColor[
              0.617427227752295, 0.7002942641257728, 0.9630252795605696], 95 -> 
             RGBColor[
              0.8439461380460744, 0.3387948511084201, 0.189716177463972], 72 -> 
             RGBColor[
              0.9641591679159359, 0.8907625989321957, 0.31526556463697364`], 
             42 -> RGBColor[
              0.34338289748227857`, 0.4718427396980633, 0.9431010324793649], 
             66 -> RGBColor[
              0.34351240304929953`, 0.4719549109110778, 0.9431092844595783], 
             1 -> RGBColor[
              0.3816799212971723, 0.5050136968621394, 0.9455412849721215], 24 -> 
             RGBColor[
              0.9363589032652497, 0.9520571547747309, 0.9926119559022686], 54 -> 
             RGBColor[
              0.5067105600269952, 0.6104094855373332, 0.9543092579087169], 4 -> 
             RGBColor[
              0.4140678129957507, 0.5330664607886789, 0.9476050127916669], 7 -> 
             RGBColor[
              0.4511758461998242, 0.5652075740460683, 0.9499695038540851], 
             100 -> RGBColor[
              0.985131173571602, 0.9881193724075173, 0.8960784634152634], 12 -> 
             RGBColor[
              0.45205205481414834`, 0.5659665019082704, 0.9500253350921889], 
             65 -> RGBColor[
              0.6460238199768336, 0.7233979852195659, 0.9653532750056009], 8 -> 
             RGBColor[
              0.3607224787917016, 0.48686141351558854`, 0.9442058952676117], 
             57 -> RGBColor[
              0.9105396657565534, 0.6830266161535721, 0.24687631904503257`], 
             74 -> RGBColor[
              0.3816799212971723, 0.5050136968621394, 0.9455412849721215], 37 -> 
             RGBColor[
              0.4622791115839747, 0.5743380340773471, 0.9508114515295238], 43 -> 
             RGBColor[
              0.6222006372765375, 0.7041695330172014, 0.9634010598438932], 39 -> 
             RGBColor[
              0.8555692791183223, 0.42813540668261096`, 0.2008465104812167], 
             58 -> RGBColor[
              0.9207795496801516, 0.7236243436716014, 0.2551155700109276], 11 -> 
             RGBColor[
              0.93753577723352, 0.9529348654533126, 0.9906198152518769], 51 -> 
             RGBColor[
              0.6592213699486111, 0.7337080115626133, 0.9666686834486711], 48 -> 
             RGBColor[
              0.7467747450798453, 0.80210537364543, 0.9753951856489435], 20 -> 
             RGBColor[
              0.5954487867023125, 0.682451175563911, 0.9612950561714327], 33 -> 
             RGBColor[
              0.986115571063353, 0.9885264460682179, 0.8797644494379026], 45 -> 
             RGBColor[
              0.671705057845251, 0.7434603634270104, 0.967912940791512], 23 -> 
             RGBColor[
              0.8200555806535611, 0.8593540764701445, 0.9826988274266375], 22 -> 
             RGBColor[
              0.4464309568111478, 0.5610977893426717, 0.9496671636979795], 2 -> 
             RGBColor[
              0.4884304992270914, 0.5955689086726169, 0.9528701845604793], 60 -> 
             RGBColor[
              0.6832091180498947, 0.7524474226929739, 0.969059558001156], 16 -> 
             RGBColor[
              0.5014771244292664, 0.60616074675551, 0.9538972626877573], 79 -> 
             RGBColor[
              0.439876683588614, 0.5554208073046636, 0.9492495312039559], 89 -> 
             RGBColor[
              0.4040892314987769, 0.5244235150340892, 0.9469691864023928], 36 -> 
             RGBColor[
              0.3587438117977752, 0.48514759161614424`, 0.9440798163564252], 
             52 -> RGBColor[
              0.9895591297847406, 0.9899504460949342, 0.8226957697802102], 32 -> 
             RGBColor[
              0.4644370073702721, 0.5760899110887606, 0.9509813289904538], 31 -> 
             RGBColor[
              0.8971747937118599, 0.9208468436175594, 0.9900545268132722], 68 -> 
             RGBColor[
              0.34351240304929953`, 0.4719549109110778, 0.9431092844595783], 
             73 -> RGBColor[
              0.24972786777145195`, 0.379810201062087, 0.9375330046790866], 
             82 -> RGBColor[
              0.4225404009577172, 0.5404049906366815, 0.948144878604588], 35 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 88 -> 
             RGBColor[
              0.674069570151367, 0.7453075384115074, 0.9681486132805618], 50 -> 
             RGBColor[
              0.9705553428750521, 0.9123383989625935, 0.3401134965368504], 19 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 17 -> 
             RGBColor[
              0.950999201887821, 0.8434351945728756, 0.27943101152362404`], 
             96 -> RGBColor[
              0.9497967213179729, 0.8386677598163239, 0.2784634674312776], 14 -> 
             RGBColor[
              0.9433402546335729, 0.9572638351943125, 0.9807943490637522], 5 -> 
             RGBColor[
              0.45829881865061234`, 0.5711066529638902, 0.9504981082895161], 
             34 -> RGBColor[
              0.36553852431542866`, 0.4910328300867546, 0.9445127694297217], 
             97 -> RGBColor[
              0.8360933910278281, 0.2784351964304932, 0.18219637805089], 93 -> 
             RGBColor[
              0.4048049768019746, 0.5250434576413141, 0.9470147930602039], 81 -> 
             RGBColor[
              0.6667591447232283, 0.7395965785057543, 0.9674199783936948], 69 -> 
             RGBColor[
              0.3729681852570953, 0.4974680289688095, 0.9449861808551335], 9 -> 
             RGBColor[
              0.7986511815042272, 0.8426316400556766, 0.9805657440188646], 13 -> 
             RGBColor[
              0.40567585225278885`, 0.5257977661853365, 0.9470702844738448], 
             30 -> RGBColor[
              0.985131173571602, 0.9881193724075173, 0.8960784634152634], 59 -> 
             RGBColor[
              0.34351240304929953`, 0.4719549109110778, 0.9431092844595783], 
             28 -> RGBColor[
              0.37116081996406847`, 0.4959025799928106, 0.9448710171368522], 
             80 -> RGBColor[
              0.45205205481414834`, 0.5659665019082704, 0.9500253350921889], 
             47 -> RGBColor[
              0.8292939102215507, 0.8667204696998837, 0.9835799875479865], 62 -> 
             RGBColor[
              0.8706328047705606, 0.8996829820988643, 0.9875229282137379], 77 -> 
             RGBColor[
              0.7387933167511043, 0.7958702211739155, 0.974599671463823], 78 -> 
             RGBColor[
              0.53230358449515, 0.6311870557531947, 0.9563240345451877], 40 -> 
             RGBColor[
              0.5331212357266935, 0.6318508618577299, 0.9563884030452899], 67 -> 
             RGBColor[
              0.6370645661050712, 0.716236740052568, 0.9645712027696408], 56 -> 
             RGBColor[
              0.34351240304929953`, 0.4719549109110778, 0.9431092844595783], 
             10 -> RGBColor[
              0.8897353694892357, 0.9149148486802299, 0.989344947889666], 53 -> 
             RGBColor[
              0.38970096823224143`, 0.5119611245677551, 0.9460523789900908], 
             26 -> RGBColor[
              0.9641591679159359, 0.8907625989321957, 0.31526556463697364`], 
             18 -> RGBColor[
              0.34351240304929953`, 0.4719549109110778, 0.9431092844595783], 
             29 -> RGBColor[
              0.5617919654339127, 0.6551270518357047, 0.9586454679121856], 92 -> 
             RGBColor[
              0.42087579114847823`, 0.5389631892856404, 0.9480388111395], 46 -> 
             RGBColor[
              0.34338289748227857`, 0.4718427396980633, 0.9431010324793649], 
             49 -> RGBColor[
              0.34351240304929953`, 0.4719549109110778, 0.9431092844595783], 
             83 -> RGBColor[
              0.9885298889352038, 0.9895248285533674, 0.8397529542469699], 70 -> 
             RGBColor[
              0.3816799212971723, 0.5050136968621394, 0.9455412849721215], 44 -> 
             RGBColor[
              0.532017952854134, 0.6309551671194591, 0.9563015485761037], 91 -> 
             RGBColor[
              0.34351240304929953`, 0.4719549109110778, 0.9431092844595783], 
             6 -> RGBColor[
              0.9447605056082841, 0.9583230560458046, 
               0.9783902346243456]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9lHs01Akbx4dhXCZmRjNjDGZ+vxEpY003Oez6fWm7uFSIpJWyrGvrtqF9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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 13}], {
             RGBColor[
             0.3936778867749806, 0.5154057315237379, 0.9463057847229832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 17}], {
             RGBColor[
             0.6663395615924967, 0.6742244457175075, 0.6124861482478727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 19}], {
             RGBColor[
             0.28030346064858613`, 0.4052038484310697, 0.9395211424860608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 27}], {
             RGBColor[
             0.42110967445761205`, 0.5389696885620403, 0.9481078911035878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 43}], {
             RGBColor[
             0.5019402792868549, 0.6045916149396704, 0.9544711724080074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 46}], {
             RGBColor[
             0.36253140938972545`, 0.4884282182801013, 0.9443211587257432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 55}], {
             RGBColor[
             0.3625961621732359, 0.4884843038866086, 0.9443252847158499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 3}], {
             RGBColor[
             0.49719146248462764`, 0.6026814533219819, 0.9535598796805784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 14}], {
             RGBColor[
             0.7158853769303322, 0.7764163719334647, 0.9668322668121158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 29}], {
             RGBColor[
             0.525111232330502, 0.6253479802541608, 0.9557578262363324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 33}], {
             RGBColor[
             0.7372730351452222, 0.7920476773704175, 0.916317316999191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 38}], {
             RGBColor[
             0.4384310061593676, 0.5532152475011285, 0.9494208374957731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 42}], {
             RGBColor[
             0.41590669835468497`, 0.5337058241853401, 0.9479856085199221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 44}], {
             RGBColor[
             0.5102242260406127, 0.6132620378960381, 0.9545858665682916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 62}], {
             RGBColor[
             0.679531651998826, 0.7476259453857406, 0.9701965563871087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 78}], {
             RGBColor[
             0.5103670418611207, 0.6133779822129057, 0.9545971095528335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 16}], {
             RGBColor[
             0.5037147750857152, 0.6079773723634284, 0.9540734187442175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 29}], {
             RGBColor[
             0.5338721955880383, 0.6324605249035258, 0.9564475213564316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 33}], {
             RGBColor[
             0.7460339984027584, 0.7991602220197824, 0.91700701211929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 38}], {
             RGBColor[
             0.4471919694169038, 0.5603277921504934, 0.9501105326158723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 42}], {
             RGBColor[
             0.4246676616122212, 0.540818368834705, 0.9486753036400213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 62}], {
             RGBColor[
             0.6882926152563622, 0.7547384900351055, 0.9708862515072076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 9}], {
             RGBColor[
             0.6063594972499889, 0.6878490504221777, 0.9640853784052658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 23}], {
             RGBColor[
             0.6170616968246558, 0.6962102686294117, 0.9651519201091522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 24}], {
             RGBColor[
             0.6752133581305002, 0.7425618077817049, 0.9701084843469677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 30}], {
             RGBColor[
             0.6995994932836763, 0.7605929165980981, 0.9218417381034651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 36}], {
             RGBColor[
             0.38640581239676297`, 0.5091070262024116, 0.945842414574046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 37}], {
             RGBColor[
             0.4381734622898627, 0.553702247433013, 0.9492082321605954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 50}], {
             RGBColor[
             0.6923115779354014, 0.7227024298756362, 0.6438592546642586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 76}], {
             RGBColor[
             0.4694355667616086, 0.5790822321849334, 0.9516692995414732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 86}], {
             RGBColor[
             0.6930859141797895, 0.7558911308196401, 0.9398549088646928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 94}], {
             RGBColor[
             0.47205334814135325`, 0.5812074650387173, 0.9518753808809358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 20}], {
             RGBColor[
             0.5268738026764624, 0.6267789142639006, 0.9558965822304744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 28}], {
             RGBColor[
             0.41472981930734043`, 0.5335046164783503, 0.9476845627131841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 58}], {
             RGBColor[
             0.689539184165382, 0.6473654983177458, 0.6028068391502218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.4009056108499559, 0.5215307819374839, 0.9468036963745472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 63}], {
             RGBColor[
             0.4202176105096967, 0.5382578653934256, 0.948034239915935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 66}], {
             RGBColor[
             0.4009056108499559, 0.5215307819374839, 0.9468036963745472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 69}], {
             RGBColor[
             0.41563350195385385`, 0.5342873409663498, 0.9477421445723249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[
             0.5985460677008583, 0.6834884370689028, 0.9625488898766695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 79}], {
             RGBColor[
             0.4490877511196132, 0.5632637301342769, 0.949873819746736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[
             0.7234143537929081, 0.7803157407586288, 0.895125531268243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 97}], {
             RGBColor[
             0.6471961048392202, 0.4247709246971917, 0.566347243170203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 7}], {
             RGBColor[
             0.6979681759040541, 0.7617653150459365, 0.9641798692392154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 10}], {
             RGBColor[
             0.9172479375487599, 0.9366189523630173, 0.9838675912570058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 15}], {
             RGBColor[
             0.9478798537480526, 0.9008791253093401, 0.6289106230739848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 25}], {
             RGBColor[
             0.8902537543778444, 0.6170478817196128, 0.5801274556248764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 26}], {
             RGBColor[
             0.95445983676211, 0.9245428274890002, 0.6468278996306596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 35}], {
             RGBColor[
             0.881039752804142, 0.5462250280229023, 0.5713041173121728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 40}], {
             RGBColor[
             0.7389408706674887, 0.7950869589517673, 0.9673893188348177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.6672307369202628, 0.7351420903067798, 0.9622213068072182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 65}], {
             RGBColor[
             0.7953921627925589, 0.8408605206326852, 0.9718717548149732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 90}], {
             RGBColor[
             0.6914823179186781, 0.7561475908477047, 0.9637665961036062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 100}], {
             RGBColor[
             0.9649458395899431, 0.973221214226661, 0.9372343490198045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 13}], {
             RGBColor[
             0.42842584922630655`, 0.5455026701157024, 0.948519894163965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 25}], {
             RGBColor[
             0.6434614246736143, 0.42049014071974455`, 0.5659170902397461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 27}], {
             RGBColor[
             0.455857636908938, 0.5690666271540048, 0.9503220005445696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 37}], {
             RGBColor[
             0.45672747889189946`, 0.5697728040617076, 0.9503904776918044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 40}], {
             RGBColor[
             0.49214854096325883`, 0.5985292179518991, 0.9531789534496875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 53}], {
             RGBColor[
             0.4204384072160328, 0.5385843493069117, 0.9480109414220879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.4789432031134097, 0.5878085297917007, 0.9521393808814009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 65}], {
             RGBColor[
             0.5485998330883288, 0.6443027796328171, 0.9576613894298429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 81}], {
             RGBColor[
             0.5589674954615262, 0.6524020762759113, 0.95869474112389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.5614404520225376, 0.6543339687365393, 0.9589412223227985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 85}], {
             RGBColor[
             0.48749168346582833`, 0.5947485712464454, 0.9528123485688587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 90}], {
             RGBColor[
             0.44468998821444816`, 0.5595898498478364, 0.949556230718476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 100}], {
             RGBColor[
             0.718153509885713, 0.7766634732267927, 0.9230239836346743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 17}], {
             RGBColor[
             0.6558608403397613, 0.6651483040442321, 0.6118184533956179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.5272008669559003, 0.6237440934318974, 0.9571545093414658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 22}], {
             RGBColor[
             0.4035767178014247, 0.5239796014291301, 0.9469365294827956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 30}], {
             RGBColor[
             0.6729268261816518, 0.7374903929615529, 0.9201421793414375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 49}], {
             RGBColor[
             0.35211744092050057`, 0.47940816221333316`, 0.943657589863595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 69}], {
             RGBColor[
             0.36684533202439845`, 0.492164721242199, 0.9445960380613726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 77}], {
             RGBColor[
             0.5497578977714029, 0.6413658173447521, 0.9594027833657173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.3916314398747094, 0.5136332020761349, 0.9461753869360998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 86}], {
             RGBColor[
             0.666413247077765, 0.7327886071830949, 0.9381553501026652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 87}], {
             RGBColor[
             0.4890748532719983, 0.5935778388206807, 0.9536155874140906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 95}], {
             RGBColor[
             0.602334308418888, 0.4128281323120043, 0.5669610363657919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 99}], {
             RGBColor[
             0.4245764890093965, 0.5412151610941027, 0.9485380399140455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.8680934793688736, 0.8977832527544947, 0.9855927796353707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 21}], {
             RGBColor[
             0.746165218312163, 0.8016292067019415, 0.9753344337170924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 30}], {
             RGBColor[
             0.8918911775379146, 0.9153755062315969, 0.938322103717064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 36}], {
             RGBColor[
             0.5786974966510012, 0.6638896158359104, 0.9623227801876449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 61}], {
             RGBColor[
             0.8963678872382096, 0.9161937537498083, 0.7890441892907749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 67}], {
             RGBColor[
             0.7178578738046493, 0.7794341900541223, 0.9725684733942528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 68}], {
             RGBColor[
             0.5710817922767634, 0.6572932754833771, 0.9618375142392215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 72}], {
             RGBColor[
             0.8814051747100815, 0.8666971194939361, 0.6479156543279192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 82}], {
             RGBColor[
             0.6105957912309722, 0.691518315346179, 0.9643553113117262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 86}], {
             RGBColor[
             0.8853775984340277, 0.910673720453139, 0.9563352744782916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 92}], {
             RGBColor[
             0.6097634863263527, 0.6907974146706585, 0.9643022775791823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 94}], {
             RGBColor[
             0.6643450323955915, 0.7359900546722162, 0.9683557464945347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.9203672856885283, 0.8791750216265528, 0.634387979706645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 26}], {
             RGBColor[
             0.9269472687025858, 0.9028387238062128, 0.6523052562633198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 35}], {
             RGBColor[
             0.8535271847446179, 0.524520924340115, 0.5767814739448329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 40}], {
             RGBColor[
             0.7114283026079646, 0.7733828552689799, 0.972866675467478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 53}], {
             RGBColor[
             0.6397181688607385, 0.7134379866239925, 0.9676986634398783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 65}], {
             RGBColor[
             0.7678795947330346, 0.8191564169498979, 0.9773491114476334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 90}], {
             RGBColor[
             0.6639697498591539, 0.7344434871649173, 0.9692439527362664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 100}], {
             RGBColor[
             0.9374332715304188, 0.9515171105438736, 0.9427117056524648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 36}], {
             RGBColor[
             0.6481397945156476, 0.7190412285347284, 0.9673498158041511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 52}], {
             RGBColor[
             0.9635474535091303, 0.9714426557741234, 0.9066577925160435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 61}], {
             RGBColor[
             0.965810185102856, 0.9713453664486262, 0.7940712249072811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 67}], {
             RGBColor[
             0.7873001716692956, 0.8345858027529403, 0.9775955090107589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 68}], {
             RGBColor[
             0.6405240901414098, 0.7124448881821952, 0.9668645498557276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 72}], {
             RGBColor[
             0.950847472574728, 0.9218487321927542, 0.6529426899444253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 92}], {
             RGBColor[
             0.6792057841909991, 0.7459490273694764, 0.9693293131956884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 94}], {
             RGBColor[
             0.7337873302602379, 0.7911416673710342, 0.9733827821110408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 41}], {
             RGBColor[
             0.3902924039686304, 0.5124733964761908, 0.9460900647522275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 52}], {
             RGBColor[
             0.7208055922994445, 0.7779584740016023, 0.8863605524361995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 60}], {
             RGBColor[
             0.5676305864320215, 0.6592069623006221, 0.9595424465466724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.6406729825178495, 0.716343485804077, 0.9668026613200877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 74}], {
             RGBColor[
             0.41686598805566033`, 0.5354900993852049, 0.9477833100321552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 88}], {
             RGBColor[
             0.5630608124827576, 0.6556370201598889, 0.9590869741863753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 96}], {
             RGBColor[
             0.7009243880660606, 0.7023171308622971, 0.6142444012617332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 27}], {
             RGBColor[
             0.43310763993542034`, 0.5493617232236389, 0.9488723908544494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 43}], {
             RGBColor[
             0.5139382447646632, 0.614983649601269, 0.9552356721588691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 54}], {
             RGBColor[
             0.456193206139892, 0.5681036258613348, 0.9506897711912808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 81}], {
             RGBColor[
             0.5362174984880086, 0.6326971723455455, 0.9572451314337698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 84}], {
             RGBColor[
             0.5386904550490199, 0.6346290648061734, 0.9574916126326785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 85}], {
             RGBColor[
             0.4647416864923106, 0.5750436673160795, 0.9513627388787385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 15}], {
             RGBColor[
             0.947169728260697, 0.900349514883594, 0.630112680293688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 24}], {
             RGBColor[
             0.9398495789494112, 0.9546604949845217, 0.9867031524830103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 35}], {
             RGBColor[
             0.8803296273167864, 0.5456954175971562, 0.572506174531876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 38}], {
             RGBColor[
             0.6658858838626083, 0.7340627107619763, 0.9633829197474095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 42}], {
             RGBColor[
             0.6433615760579257, 0.7145532874461878, 0.9619476907715585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 53}], {
             RGBColor[
             0.6665206114329072, 0.7346124798810338, 0.9634233640269214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 62}], {
             RGBColor[
             0.9069865297020667, 0.9284734086465884, 0.9841586386387451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 76}], {
             RGBColor[
             0.7340717875805196, 0.7911809193877501, 0.9682639676775158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 35}], {
             RGBColor[
             0.8841591009439105, 0.4887810972864378, 0.221824505761812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 38}], {
             RGBColor[
             0.6697153574897324, 0.6771483904512579, 0.6127012509773455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 40}], {
             RGBColor[
             0.7420602188072573, 0.7376430282153028, 0.617909707284457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 53}], {
             RGBColor[
             0.6703500850600312, 0.6776981595703153, 0.6127416952568574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.9108160033291908, 0.8715590883358699, 0.633476969868681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 90}], {
             RGBColor[
             0.6946016660584466, 0.6987036601112402, 0.6142869845532454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 100}], {
             RGBColor[
             0.9680651877297115, 0.9157772834901965, 0.5877547374694437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 29}], {
             RGBColor[
             0.5316345449315896, 0.6306438992956074, 0.9562713652999715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.7437963477463096, 0.797343596411864, 0.91683085606283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 62}], {
             RGBColor[
             0.6860549645999134, 0.7529218644271871, 0.9707100954507476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 19}], {
             RGBColor[
             0.5649631009439106, 0.5744145972864378, 0.6064660057618121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 22}], {
             RGBColor[
             0.6987150793494844, 0.7022664919577737, 0.6145490876108017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 28}], {
             RGBColor[
             0.6610800109259447, 0.6696688872828431, 0.6121510143302381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 46}], {
             RGBColor[
             0.6471910496850498, 0.6576389671354694, 0.6112660220014945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 55}], {
             RGBColor[
             0.6472558024685603, 0.6576950527419767, 0.6112701479916012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 59}], {
             RGBColor[
             0.6472558024685603, 0.6576950527419767, 0.6112701479916012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 66}], {
             RGBColor[
             0.6472558024685603, 0.6576950527419767, 0.6112701479916012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 69}], {
             RGBColor[
             0.6619836935724581, 0.6704516117708426, 0.6122085961893788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 77}], {
             RGBColor[
             0.8448962593194627, 0.8196527078733955, 0.6270153414937235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 79}], {
             RGBColor[
             0.6954379427382176, 0.6994280009387697, 0.61434027136379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 95}], {
             RGBColor[
             0.8974726699669477, 0.5911150228406479, 0.23457359449379803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 98}], {
             RGBColor[
             0.9556714719130012, 0.9066901013791551, 0.6157214459002077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.7197148505574562, 0.7195020516227463, 0.6161505980420516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 80}], {
             RGBColor[
             0.39778222893172394`, 0.5189607064096741, 0.9465673097758835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 28}], {
             RGBColor[
             0.2750439099820342, 0.40064828999640534`, 0.939186008568426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 43}], {
             RGBColor[
             0.40056381863826873`, 0.5047817665086007, 0.9484510299219466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 46}], {
             RGBColor[
             0.2611549487411393, 0.38861836984903164`, 0.9383010162396825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 55}], {
             RGBColor[
             0.2612197015246498, 0.3886744554555389, 0.9383051422297892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 59}], {
             RGBColor[
             0.2612197015246498, 0.3886744554555389, 0.9383051422297892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 66}], {
             RGBColor[
             0.2612197015246498, 0.3886744554555389, 0.9383051422297892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 79}], {
             RGBColor[
             0.30940184179430696`, 0.43040740365233177`, 0.941375265601978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 95}], {
             RGBColor[
             0.5114365690230371, 0.3220944255542101, 0.561608588731986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 98}], {
             RGBColor[
             0.5696353709690907, 0.6376695040927172, 0.9427564401383957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 99}], {
             RGBColor[
             0.3336787496135457, 0.4504814543363085, 0.9431855922802397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.4833048033331905, 0.5891768777783608, 0.9530830366541425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 58}], {
             RGBColor[
             0.758114168191232, 0.7030377596177562, 0.6082053130911802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 59}], {
             RGBColor[
             0.469480594875806, 0.5772030432374944, 0.9522021703155055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 63}], {
             RGBColor[
             0.4887925945355468, 0.593930126693436, 0.9534327138568934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 66}], {
             RGBColor[
             0.469480594875806, 0.5772030432374944, 0.9522021703155055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 79}], {
             RGBColor[
             0.5176627351454632, 0.6189359914342873, 0.9552722936876943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 83}], {
             RGBColor[
             0.7919893378187581, 0.8359880020586392, 0.9005240052092014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 97}], {
             RGBColor[
             0.7157710888650703, 0.4804431859972021, 0.5717457171111614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 22}], {
             RGBColor[
             0.5700551059656234, 0.660862281345439, 0.9598851435566498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 30}], {
             RGBColor[
             0.8394052143458504, 0.8743730728778618, 0.9330907934152917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 34}], {
             RGBColor[
             0.5296088897177638, 0.6258298017174805, 0.9573079464225209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.526211533458937, 0.6228871824821753, 0.9570914698858726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 49}], {
             RGBColor[
             0.5185958290846993, 0.616290842129642, 0.9566062039374492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 68}], {
             RGBColor[
             0.5185958290846993, 0.616290842129642, 0.9566062039374492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 72}], {
             RGBColor[
             0.8289192115180174, 0.825694686140201, 0.6426843440261468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 82}], {
             RGBColor[
             0.5581098280389081, 0.6505158819924439, 0.959124001009954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[
             0.6555532414361969, 0.7304605187369896, 0.9665642014879448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 92}], {
             RGBColor[
             0.5572775231342886, 0.6497949813169234, 0.95907096727741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 30}], {
             RGBColor[
             0.715781065191375, 0.7746085808750945, 0.9228728135566215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 34}], {
             RGBColor[
             0.40598474056328826`, 0.5260653097147132, 0.9470899665638506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 49}], {
             RGBColor[
             0.39497167993022364`, 0.5165263501268748, 0.9463882240787789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 66}], {
             RGBColor[
             0.39497167993022364`, 0.5165263501268748, 0.9463882240787789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 69}], {
             RGBColor[
             0.4096995710341216, 0.5292829091557406, 0.9473266722765565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 77}], {
             RGBColor[
             0.592612136781126, 0.6784840052582937, 0.9621334175809013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 82}], {
             RGBColor[
             0.4344856788844325, 0.5507513899896765, 0.9489060211512838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 87}], {
             RGBColor[
             0.5319290922817214, 0.6306960267342223, 0.9563462216292746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 95}], {
             RGBColor[
             0.6451885474286111, 0.4499463202255459, 0.5696916705809758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 99}], {
             RGBColor[
             0.4674307280191196, 0.5783333490076443, 0.9512686741292294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 24}], {
             RGBColor[
             0.8782072419594054, 0.9057056156224377, 0.987655391664453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 27}], {
             RGBColor[
             0.6402975041358064, 0.7161398783660429, 0.9666866623308458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 30}], {
             RGBColor[
             0.9025933771125816, 0.9237367244388309, 0.9393886454209505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 37}], {
             RGBColor[
             0.6411673461187679, 0.7168460552737458, 0.9667551394780807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 50}], {
             RGBColor[
             0.8953054617643066, 0.885846237716369, 0.661406161981744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 76}], {
             RGBColor[
             0.6724294505905137, 0.7422260400256662, 0.9692162068589585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[
             0.7434073626883947, 0.7994753274879494, 0.9750594029101661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 84}], {
             RGBColor[
             0.7458803192494061, 0.8014072199485774, 0.9753058841090747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 85}], {
             RGBColor[
             0.6719315506926968, 0.7418218224584836, 0.9691770103551349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 86}], {
             RGBColor[
             0.8960797980086948, 0.9190349386603729, 0.957401816182178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 42}], {
             RGBColor[
             0.6398709003737642, 0.711949947236397, 0.9678564941908168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 50}], {
             RGBColor[
             0.953457123070151, 0.9321977768686622, 0.6663627262195595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 76}], {
             RGBColor[
             0.7305811118963581, 0.7885775791779595, 0.974172771096774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 26}], {
             RGBColor[
             0.8999530855316702, 0.5832676531628083, 0.24856512063119046`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 40}], {
             RGBColor[
             0.684434119437049, 0.45381178462557537`, 0.5691265398353487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 54}], {
             RGBColor[
             0.6712287815871999, 0.44309109646537703`, 0.5680869672670621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 65}], {
             RGBColor[
             0.7408854115621191, 0.49958534630649337`, 0.5736089758155041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 100}], {
             RGBColor[
             0.9104390883595033, 0.631946039900469, 0.5389715700203354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 40}], {
             RGBColor[
             0.7486402018213147, 0.7613067303949628, 0.6358269838411318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 53}], {
             RGBColor[
             0.6769300680740886, 0.7013618617499754, 0.6306589718135323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 65}], {
             RGBColor[
             0.8050914939463847, 0.8070802920758808, 0.6403094198212873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 90}], {
             RGBColor[
             0.701181649072504, 0.7223673622909002, 0.6322042611099201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[
             0.9746451707437689, 0.9394409856698565, 0.6056720140261185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 37}], {
             RGBColor[
             0.46140926960101325`, 0.5736318571696442, 0.9507429743822889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 43}], {
             RGBColor[
             0.5413700324472946, 0.6385476066395713, 0.9570377785394737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 54}], {
             RGBColor[
             0.4836249938225235, 0.5916675828996372, 0.9524918775718855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 81}], {
             RGBColor[
             0.56364928617064, 0.6562611293838478, 0.9590472378143744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 84}], {
             RGBColor[
             0.5661222427316515, 0.6581930218444758, 0.9592937190132831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 85}], {
             RGBColor[
             0.4921734741749421, 0.5986076243543819, 0.9531648452593431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 46}], {
             RGBColor[
             0.3572718587231735, 0.4838726598454369, 0.9439860248081086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 55}], {
             RGBColor[
             0.357336611506684, 0.4839287454519442, 0.9439901507982152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 59}], {
             RGBColor[
             0.357336611506684, 0.4839287454519442, 0.9439901507982152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 66}], {
             RGBColor[
             0.357336611506684, 0.4839287454519442, 0.9439901507982152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 79}], {
             RGBColor[
             0.4055187517763412, 0.525661693648737, 0.9470602741704041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 83}], {
             RGBColor[
             0.6798453544496361, 0.742713704273089, 0.8923119856919111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 98}], {
             RGBColor[
             0.6657522809511249, 0.7329237940891224, 0.9484414487068218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 99}], {
             RGBColor[
             0.42979565959557997`, 0.5457357443327138, 0.9488706008486658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 33}], {
             RGBColor[
             0.7739537682486328, 0.8218267489519613, 0.9192049586750441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 38}], {
             RGBColor[
             0.4751117392627783, 0.5829943190826724, 0.9523084791716263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 42}], {
             RGBColor[
             0.45258743145809566`, 0.563484895766884, 0.9508732501957753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.7162123851022366, 0.7774050169672846, 0.9730841980629618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 36}], {
             RGBColor[
             0.6719374926846886, 0.7366334820118308, 0.9200791398858443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 50}], {
             RGBColor[
             0.977843258223327, 0.9502288856850554, 0.6180959799760569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 82}], {
             RGBColor[
             0.7038357872646596, 0.7642621815220993, 0.9221116710099257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 86}], {
             RGBColor[
             0.9786175944677151, 0.9834175866290593, 0.9140916341764911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 92}], {
             RGBColor[
             0.7030034823600401, 0.7635412808465789, 0.9220586372773817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 94}], {
             RGBColor[
             0.7575850284292789, 0.8087339208481366, 0.9261121061927341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 32}], {
             RGBColor[
             0.680805900541066, 0.74846837735316, 0.970517927901863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 39}], {
             RGBColor[
             0.8763720364150911, 0.6744911251500851, 0.5954505186472445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 44}], {
             RGBColor[
             0.714596373282997, 0.7759010053685093, 0.9731780376946879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 45}], {
             RGBColor[
             0.7844399257785555, 0.832153603522285, 0.9789837338023921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 51}], {
             RGBColor[
             0.7781980818302355, 0.8272774275900864, 0.9783616051309716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 70}], {
             RGBColor[
             0.6394273575045162, 0.7129302702398495, 0.9677979058926969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 75}], {
             RGBColor[
             0.6203435983805797, 0.6964008772643187, 0.9665819056364253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 78}], {
             RGBColor[
             0.714739189103505, 0.776016949685377, 0.9731892806792299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 80}], {
             RGBColor[
             0.6746134242630042, 0.7434066727629149, 0.9700399309527306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 39}], {
             RGBColor[
             0.6600031432442972, 0.5021126588856858, 0.5759139197358353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 44}], {
             RGBColor[
             0.4982274801122031, 0.6035225391041099, 0.9536414387832788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 45}], {
             RGBColor[
             0.5680710326077616, 0.6597751372578855, 0.959447134890983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 51}], {
             RGBColor[
             0.5618291886594416, 0.654898961325687, 0.9588250062195625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 80}], {
             RGBColor[
             0.4582445310922102, 0.5710282064985155, 0.9505033320413214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 42}], {
             RGBColor[
             0.6647492342728158, 0.7301845928831406, 0.9114327409586338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 62}], {
             RGBColor[
             0.9283741879169568, 0.9441047140835411, 0.9336436888258202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 49}], {
             RGBColor[
             0.3545254636823641, 0.4814938704989162, 0.94381102694465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 60}], {
             RGBColor[
             0.5243738211826616, 0.6217401263898643, 0.9567861637154389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 69}], {
             RGBColor[
             0.369253354786262, 0.49425042952778203`, 0.9447494751424277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 71}], {
             RGBColor[
             0.5013015452102499, 0.6036347850696613, 0.9545419860996813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 77}], {
             RGBColor[
             0.5521659205332665, 0.643451525630335, 0.9595562204467724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 82}], {
             RGBColor[
             0.39403946263657297`, 0.515718910361718, 0.9463288240171548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 87}], {
             RGBColor[
             0.4914828760338618, 0.5956635471062637, 0.9537690244951457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 38}], {
             RGBColor[
             0.602875256545822, 0.32249429316482003`, 0.5550947452155335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 53}], {
             RGBColor[
             0.6035099841161207, 0.32304406228387755`, 0.5551351894950454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 62}], {
             RGBColor[
             0.8439759023852803, 0.5169049910494321, 0.5758704641068689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 90}], {
             RGBColor[
             0.6277615651145361, 0.3440495628248023, 0.5566804787914333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 61}], {
             RGBColor[
             0.6764142023849835, 0.737451729530042, 0.7708012254595553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 67}], {
             RGBColor[
             0.4979041889514232, 0.6006921658343561, 0.954325509563033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 68}], {
             RGBColor[
             0.3511281074235374, 0.478551251263611, 0.9435945504080018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 72}], {
             RGBColor[
             0.6614514898568555, 0.68795509527417, 0.6296726904966994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 82}], {
             RGBColor[
             0.3906421063777462, 0.5127762911264129, 0.9461123474805067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 86}], {
             RGBColor[
             0.6654239135808018, 0.7319316962333728, 0.938092310647072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 92}], {
             RGBColor[
             0.3898098014731267, 0.5120553904508923, 0.9460593137479626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 94}], {
             RGBColor[
             0.44439134754236553`, 0.55724803045245, 0.950112782663315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 50}], {
             RGBColor[
             0.7164172272295134, 0.7433382165199702, 0.6454624740331871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 76}], {
             RGBColor[
             0.4935412160557206, 0.5997180188292675, 0.9532725189104017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 81}], {
             RGBColor[
             0.5645191281536015, 0.6569673062915506, 0.9591157149616093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 84}], {
             RGBColor[
             0.5669920847146128, 0.6588991987521787, 0.9593621961605179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 85}], {
             RGBColor[
             0.4930433161579036, 0.5993138012620849, 0.9532333224065781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 42}], {
             RGBColor[
             0.3659072052869612, 0.49135216301385165`, 0.944536261455216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 62}], {
             RGBColor[
             0.6295321589311023, 0.7052722842142523, 0.9667472093224024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 44}], {
             RGBColor[
             0.6937936159862281, 0.5295452869010351, 0.5785740295286602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 45}], {
             RGBColor[
             0.7636371684817866, 0.5857978850548107, 0.5843797256363643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 80}], {
             RGBColor[
             0.6538106669662354, 0.49705095429544066`, 0.5754359227867027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 53}], {
             RGBColor[
             0.46141110197946744`, 0.5719059932127425, 0.9512203910176904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 54}], {
             RGBColor[
             0.5199158978768443, 0.6211301736975315, 0.9553488304770035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.5895725278517635, 0.6776244235386479, 0.9608708390254455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 90}], {
             RGBColor[
             0.48566268297788284`, 0.5929114937536673, 0.9527656803140783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 100}], {
             RGBColor[
             0.7591262046491477, 0.8099851171326236, 0.9262334332302766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 48}], {
             RGBColor[
             0.5376537491014789, 0.6305428323447707, 0.9587749900306046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 56}], {
             RGBColor[
             0.336022578086206, 0.46546760097759454`, 0.9426320394359221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 60}], {
             RGBColor[
             0.5058709355865036, 0.6057138568685426, 0.9556071762067109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 64}], {
             RGBColor[
             0.5789133316723316, 0.6628503803719975, 0.9628673909801262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 73}], {
             RGBColor[
             0.2891303104472822, 0.4193952460530992, 0.9398438995456763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 74}], {
             RGBColor[
             0.3551063372101424, 0.48199699395312534`, 0.9438480396921938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.5013011616372398, 0.6021439147278094, 0.9551517038464139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 91}], {
             RGBColor[
             0.336022578086206, 0.46546760097759454`, 0.9426320394359221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 93}], {
             RGBColor[
             0.36666886496254353`, 0.49201187434271276`, 0.9445847937362348]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 44}], {
             RGBColor[
             0.4377004251682063, 0.5513989534087612, 0.9497012905277343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 62}], {
             RGBColor[
             0.6070078511264196, 0.6857628608984638, 0.9653119803465514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 78}], {
             RGBColor[
             0.4378432409887143, 0.551514897725629, 0.9497125335122762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 46}], {
             RGBColor[
             0.48279176737940804`, 0.5880061363576323, 0.953251046161629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 54}], {
             RGBColor[
             0.5644555986517663, 0.6572895092772673, 0.958855158876305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 45}], {
             RGBColor[
             0.6018615053496925, 0.6872077652732347, 0.9621072446838079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 78}], {
             RGBColor[
             0.532160768674642, 0.6310711114363269, 0.9563127915606457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 52}], {
             RGBColor[
             0.8306320938149958, 0.8667054047609724, 0.895304355285861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 78}], {
             RGBColor[
             0.6020043211702005, 0.6873237095901026, 0.9621184876683498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 55}], {
             RGBColor[
             0.34344765026578905`, 0.4718988253045705, 0.9431051584694716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 59}], {
             RGBColor[
             0.34344765026578905`, 0.4718988253045705, 0.9431051584694716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 79}], {
             RGBColor[
             0.3916297905354463, 0.5136317735013635, 0.9461752818416604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 95}], {
             RGBColor[
             0.5936645177641765, 0.40531879540324167`, 0.5664086049716685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 98}], {
             RGBColor[
             0.6518633197102299, 0.7208938739417489, 0.9475564563780782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 99}], {
             RGBColor[
             0.41590669835468497`, 0.5337058241853401, 0.9479856085199221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 51}], {
             RGBColor[
             0.7442576400850809, 0.8002142406312485, 0.9751243354983288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 57}], {
             RGBColor[
             0.8699167879890521, 0.7748735429267279, 0.6152281532965096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 70}], {
             RGBColor[
             0.6054869157593615, 0.6858670832810115, 0.9645606362600541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 74}], {
             RGBColor[
             0.6054869157593615, 0.6858670832810115, 0.9645606362600541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 75}], {
             RGBColor[
             0.5864031566354251, 0.6693376903054807, 0.9633446360037824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 88}], {
             RGBColor[
             0.7516817401864588, 0.8060140040556956, 0.9758643004142742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.8895453157697618, 0.8526941147581037, 0.631021727489632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 56}], {
             RGBColor[
             0.5451435740645725, 0.6370301422782538, 0.9592522350542609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 57}], {
             RGBColor[
             0.8286572054181993, 0.742565994899501, 0.611135752346988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 64}], {
             RGBColor[
             0.788034327650698, 0.8344129216726568, 0.9794875865984649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 73}], {
             RGBColor[
             0.49825130642564863`, 0.5909577873537585, 0.9564640951640151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 74}], {
             RGBColor[
             0.5642273331885088, 0.6535595352537846, 0.9604682353105325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 88}], {
             RGBColor[
             0.7104221576156062, 0.7737064560284688, 0.9717718994647526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 91}], {
             RGBColor[
             0.5451435740645725, 0.6370301422782538, 0.9592522350542609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 93}], {
             RGBColor[
             0.57578986094091, 0.663574415643372, 0.9612049893545737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 96}], {
             RGBColor[
             0.8482857331989091, 0.820386566730877, 0.6269293265401106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 69}], {
             RGBColor[
             0.3582402941531974, 0.48471146993994363`, 0.944047732657356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 71}], {
             RGBColor[
             0.4902884845771854, 0.5940958254818229, 0.9538402436146096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 77}], {
             RGBColor[
             0.5411528599002019, 0.6339125660424967, 0.9588544779617006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 82}], {
             RGBColor[
             0.38302640200350835`, 0.5061799507738796, 0.9456270815320831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.48046981540079725`, 0.5861245875184253, 0.953067282010074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 76}], {
             RGBColor[
             0.7476793317012593, 0.7687182012718907, 0.6479235414140649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 81}], {
             RGBColor[
             0.8186572437991402, 0.8259674887341739, 0.6537667374652726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 84}], {
             RGBColor[
             0.8211302003601515, 0.8278993811948019, 0.6540132186641812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 85}], {
             RGBColor[
             0.7471814318034422, 0.768313983704708, 0.6478843449102414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 86}], {
             RGBColor[
             0.9713296791194401, 0.9455270999065974, 0.6361091507372845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 57}], {
             RGBColor[
             0.7848805178525823, 0.7083673138580927, 0.6067725012468519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 70}], {
             RGBColor[
             0.5204506456228917, 0.6193608542123763, 0.9561049842103964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 75}], {
             RGBColor[
             0.5013668864989553, 0.6028314612368455, 0.9548889839541247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 67}], {
             RGBColor[
             0.813311847944906, 0.8530935930737511, 0.8936334862749256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 68}], {
             RGBColor[
             0.6665357664170201, 0.730952678503006, 0.8829025271198943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 72}], {
             RGBColor[
             0.9768591488503382, 0.9403565225135649, 0.568980667208592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 78}], {
             RGBColor[
             0.7609313571399453, 0.8105687509240644, 0.8895099021626989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 65}], {
             RGBColor[
             0.5178623941045375, 0.6176795548936604, 0.9557028269978458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 84}], {
             RGBColor[
             0.5307030130387462, 0.6277107439973828, 0.9569826598908013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 85}], {
             RGBColor[
             0.45675424448203694`, 0.5681253465072889, 0.9508537861368616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 90}], {
             RGBColor[
             0.41395254923065683`, 0.5329666251086799, 0.9475976682864787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 100}], {
             RGBColor[
             0.6874160709019217, 0.7500402484876363, 0.9210654212026771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 84}], {
             RGBColor[
             0.5892078089361231, 0.6769349244821719, 0.9611110993501144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 100}], {
             RGBColor[
             0.7459208667992986, 0.7992644289724253, 0.9251938606619902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 59}], {
             RGBColor[
             0.34351240304929953`, 0.4719549109110778, 0.9431092844595783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 66}], {
             RGBColor[
             0.34351240304929953`, 0.4719549109110778, 0.9431092844595783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 79}], {
             RGBColor[
             0.39169454331895676`, 0.5136878591078706, 0.9461794078317671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 98}], {
             RGBColor[
             0.6519280724937404, 0.720949959548256, 0.9475605823681849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 99}], {
             RGBColor[
             0.41597145113819545`, 0.5337619097918473, 0.9479897345100288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 64}], {
             RGBColor[
             0.5864031566354251, 0.6693376903054807, 0.9633446360037824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 73}], {
             RGBColor[
             0.29662013541037574`, 0.4258825559865824, 0.9403211445693325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 74}], {
             RGBColor[
             0.3625961621732359, 0.4884843038866086, 0.9443252847158499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 88}], {
             RGBColor[
             0.5087909866003333, 0.6086312246612926, 0.95562894887007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 89}], {
             RGBColor[
             0.37380081727403824`, 0.4981892129725835, 0.9450392354309856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 91}], {
             RGBColor[
             0.34351240304929953`, 0.4719549109110778, 0.9431092844595783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 93}], {
             RGBColor[
             0.37415868992563706`, 0.49849918427619594`, 0.9450620387598911]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 64}], {
             RGBColor[
             0.8699167879890521, 0.7748735429267279, 0.6152281532965095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 70}], {
             RGBColor[
             0.6461097935268629, 0.5940201565078558, 0.5962088020085771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 74}], {
             RGBColor[
             0.6461097935268629, 0.5940201565078558, 0.5962088020085771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 75}], {
             RGBColor[
             0.6270260344029265, 0.577490763532325, 0.5949928017523054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 88}], {
             RGBColor[
             0.7923046179539602, 0.7141670772825397, 0.6075124661627972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 96}], {
             RGBColor[
             0.9301681935372632, 0.760847187984948, 0.2626698932381551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 63}], {
             RGBColor[
             0.6514579760244663, 0.6145167107472813, 0.6003429707766408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 83}], {
             RGBColor[
             0.9546547193076778, 0.8565745861124845, 0.5474342621289487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 97}], {
             RGBColor[
             0.8784364703539899, 0.5010297700510473, 0.2186559740309088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 66}], {
             RGBColor[
             0.34351240304929953`, 0.4719549109110778, 0.9431092844595783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 69}], {
             RGBColor[
             0.3582402941531974, 0.48471146993994363`, 0.944047732657356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 77}], {
             RGBColor[
             0.5411528599002019, 0.6339125660424967, 0.9588544779617006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 79}], {
             RGBColor[
             0.39169454331895676`, 0.5136878591078706, 0.9461794078317671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 83}], {
             RGBColor[
             0.6660211459922516, 0.7307398697322226, 0.8914311193532741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 95}], {
             RGBColor[
             0.593729270547687, 0.40537488100974894`, 0.5664127309617751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 97}], {
             RGBColor[
             0.5898028970385638, 0.3751950536707855, 0.5626528312552341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 98}], {
             RGBColor[
             0.6519280724937404, 0.720949959548256, 0.9475605823681849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 99}], {
             RGBColor[
             0.41597145113819545`, 0.5337619097918473, 0.9479897345100288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 64}], {
             RGBColor[
             0.7562515141357227, 0.8095839461964288, 0.9763197727745712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 71}], {
             RGBColor[
             0.6601368420774829, 0.734342081372771, 0.9668153803853984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 74}], {
             RGBColor[
             0.5324445196735335, 0.6287305597775567, 0.9573004214866387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 89}], {
             RGBColor[
             0.5436491747743358, 0.6384354688635316, 0.9580143722017744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 93}], {
             RGBColor[
             0.5440070474259346, 0.638745440167144, 0.9580371755306799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 67}], {
             RGBColor[
             0.8155745795386315, 0.852996303748254, 0.781046918666163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 68}], {
             RGBColor[
             0.6687984980107458, 0.7308553891775089, 0.7703159595111317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 72}], {
             RGBColor[
             0.979121880444064, 0.9402592331880678, 0.45639409959982946`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 86}], {
             RGBColor[
             0.9830943041680101, 0.9842358341472707, 0.764813719750202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 92}], {
             RGBColor[
             0.7074801920603351, 0.7643595283647902, 0.7727807228510926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 94}], {
             RGBColor[
             0.7620617381295739, 0.8095521683663478, 0.776834191766445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 83}], {
             RGBColor[
             0.6853331456519924, 0.7474669531881643, 0.892661662894662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 97}], {
             RGBColor[
             0.6091148966983045, 0.39192213712672713`, 0.563883374796622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 73}], {
             RGBColor[
             0.5395108889965013, 0.6232653353809854, 0.9605564961135366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 74}], {
             RGBColor[
             0.6054869157593615, 0.6858670832810115, 0.9645606362600541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 88}], {
             RGBColor[
             0.7516817401864588, 0.8060140040556956, 0.9758643004142742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 89}], {
             RGBColor[
             0.6166915708601638, 0.6955719923669865, 0.9652745869751896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 91}], {
             RGBColor[
             0.5864031566354251, 0.6693376903054807, 0.9633446360037824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 93}], {
             RGBColor[
             0.6170494435117626, 0.6958819636705988, 0.9652973903040951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 96}], {
             RGBColor[
             0.8895453157697618, 0.8526941147581037, 0.631021727489632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 90}], {
             RGBColor[
             0.5421139751029529, 0.6386850554345853, 0.9572481162942338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 100}], {
             RGBColor[
             0.8155774967742178, 0.8557586788135416, 0.9307158692104321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 69}], {
             RGBColor[
             0.3582402941531974, 0.48471146993994363`, 0.944047732657356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 77}], {
             RGBColor[
             0.5411528599002019, 0.6339125660424967, 0.9588544779617006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 79}], {
             RGBColor[
             0.39169454331895676`, 0.5136878591078706, 0.9461794078317671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 83}], {
             RGBColor[
             0.6660211459922516, 0.7307398697322226, 0.8914311193532741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 95}], {
             RGBColor[
             0.593729270547687, 0.40537488100974894`, 0.5664127309617751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 97}], {
             RGBColor[
             0.5898028970385638, 0.3751950536707855, 0.5626528312552341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[
             0.6519280724937404, 0.720949959548256, 0.9475605823681849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 99}], {
             RGBColor[
             0.41597145113819545`, 0.5337619097918473, 0.9479897345100288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 68}], {
             RGBColor[
             0.4902884845771854, 0.5940958254818229, 0.9538402436146096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 72}], {
             RGBColor[
             0.8006118670105036, 0.8034996694923818, 0.6399183837033072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 86}], {
             RGBColor[
             0.8045842907344498, 0.8474762704515847, 0.9483380038536797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 92}], {
             RGBColor[
             0.5289701786267748, 0.6275999646691042, 0.9563050069545704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 94}], {
             RGBColor[
             0.5835517246960136, 0.6727926046706618, 0.9603584758699228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 72}], {
             RGBColor[
             0.6538357854826178, 0.6813587549216367, 0.629187424548276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 82}], {
             RGBColor[
             0.38302640200350835`, 0.5061799507738796, 0.9456270815320831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 92}], {
             RGBColor[
             0.38219409709888885`, 0.5054590500983591, 0.9455740477995391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 71}], {
             RGBColor[
             0.5050163756810833, 0.6068523845106888, 0.9547786918123872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 77}], {
             RGBColor[
             0.5558807510040997, 0.6466691250713625, 0.9597929261594782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 87}], {
             RGBColor[
             0.49519770650469513`, 0.5988811465472912, 0.9540057302078515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 95}], {
             RGBColor[
             0.6084571616515848, 0.4181314400386148, 0.5673511791595528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 97}], {
             RGBColor[
             0.6045307881424618, 0.38795161269965134`, 0.5635912794530118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 98}], {
             RGBColor[
             0.6666559635976383, 0.7337065185771219, 0.9484990305659624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 99}], {
             RGBColor[
             0.4306993422420934, 0.5465184688207132, 0.9489281827078064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 75}], {
             RGBColor[
             0.3625961621732359, 0.4884843038866086, 0.9443252847158499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 96}], {
             RGBColor[
             0.6657383213075726, 0.6718407283392316, 0.6120023762016995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 77}], {
             RGBColor[
             0.6879289414280878, 0.7560534806132417, 0.9695854371167318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 87}], {
             RGBColor[
             0.6272458969286832, 0.7082655020891704, 0.9637982411651052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 82}], {
             RGBColor[
             0.6933497844368266, 0.7155837947844386, 0.6317052216207808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 92}], {
             RGBColor[
             0.6925174795322071, 0.714862894108918, 0.6316521878882368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 74}], {
             RGBColor[
             0.31570389453431214`, 0.4424119489621132, 0.941537144825604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 88}], {
             RGBColor[
             0.4618987189614095, 0.5625588697367973, 0.9528408089798241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.3269085496351144, 0.4521168580480881, 0.9422510955407397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 91}], {
             RGBColor[
             0.29662013541037574`, 0.4258825559865824, 0.9403211445693325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 93}], {
             RGBColor[
             0.32726642228671327`, 0.45242682935170053`, 0.9422738988696453]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 88}], {
             RGBColor[
             0.5278747457242696, 0.6251606176368234, 0.9568449491263417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 91}], {
             RGBColor[
             0.3625961621732359, 0.4884843038866086, 0.9443252847158499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 96}], {
             RGBColor[
             0.6657383213075726, 0.6718407283392316, 0.6120023762016995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 96}], {
             RGBColor[
             0.6466545621836362, 0.6553113353637008, 0.610786375945428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 81}], {
             RGBColor[
             0.5957812326253473, 0.6823472910434711, 0.9615767823424871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 84}], {
             RGBColor[
             0.5982541891863588, 0.6842791835040991, 0.9618232635413957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 85}], {
             RGBColor[
             0.5243054206296495, 0.6246937860140053, 0.9556943897874559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 87}], {
             RGBColor[
             0.6781102722516996, 0.7480822426498441, 0.9688124755121963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 95}], {
             RGBColor[
             0.7913697273985894, 0.5673325361411679, 0.5821579244638975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 97}], {
             RGBColor[
             0.7874433538894662, 0.5371527088022043, 0.5783980247573565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 98}], {
             RGBColor[
             0.8495685293446428, 0.8829076146796749, 0.9633057758703072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 99}], {
             RGBColor[
             0.6136119079890978, 0.6957195649232661, 0.9637349280121512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 83}], {
             RGBColor[
             0.7142032862619089, 0.7724728179290155, 0.8945012427254629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 98}], {
             RGBColor[
             0.7001102127633976, 0.762682907745049, 0.9506307057403737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 99}], {
             RGBColor[
             0.46415359140785273`, 0.5754948579886403, 0.9510598578822176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 84}], {
             RGBColor[
             0.6692321012842397, 0.7415284709663823, 0.9676664595926034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 85}], {
             RGBColor[
             0.5952833327275304, 0.6819430734762885, 0.9615375858386634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 86}], {
             RGBColor[
             0.6973222081607728, 0.7595603957436414, 0.9401248417711533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 87}], {
             RGBColor[
             0.5199838143550061, 0.6203496273812271, 0.9555850790825788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 92}], {
             RGBColor[
             0.4217080960530977, 0.5396840899611609, 0.9480918448720439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 97}], {
             RGBColor[
             0.9123116399815159, 0.6339800124919304, 0.51097466614893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 85}], {
             RGBColor[
             0.5977562892885417, 0.6838749659369165, 0.9617840670375721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.5549545940371616, 0.6487162445383075, 0.9585279491871894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 90}], {
             RGBColor[
             0.48100582548045234`, 0.5891308470482136, 0.9523990754332494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 92}], {
             RGBColor[
             0.6964899032561532, 0.7588394950681209, 0.9400718080386092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[
             0.751071449325392, 0.8040321350696786, 0.9441252769539616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 91}], {
             RGBColor[
             0.5087909866003333, 0.6086312246612926, 0.95562894887007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 96}], {
             RGBColor[
             0.8119331457346699, 0.7919876491139157, 0.6233060403559196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 91}], {
             RGBColor[
             0.37380081727403824`, 0.4981892129725835, 0.9450392354309856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 93}], {
             RGBColor[
             0.40444710415037577`, 0.5247334863377017, 0.9469919897312984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 100}], {
             RGBColor[
             0.7116676519003371, 0.7710457490285609, 0.9226107104990651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 93}], {
             RGBColor[
             0.37415868992563706`, 0.49849918427619594`, 0.9450620387598911]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 96}], {
             RGBColor[
             0.6466545621836362, 0.6553113353637008, 0.610786375945428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 94}], {
             RGBColor[
             0.475457337217717, 0.584155829287198, 0.9520922800548524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 98}], {
             RGBColor[
             0.9021449399921279, 0.6543699296469272, 0.5708640288703817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 99}], {
             RGBColor[
             0.6661883186365829, 0.4671818798905185, 0.5712931810122257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 99}], {
             RGBColor[
             0.7243871205826363, 0.7827569584290257, 0.9524410324186354]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.06980202272393367], {
             RGBColor[
             0.3816799212971723, 0.5050136968621394, 0.9455412849721215]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.06980202272393367], {
             RGBColor[
             0.4884304992270914, 0.5955689086726169, 0.9528701845604793]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.06980202272393367], {
             RGBColor[
             0.5059524257421638, 0.6097939979713468, 0.9542495748006775]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.06980202272393367], {
             RGBColor[
             0.4140678129957507, 0.5330664607886789, 0.9476050127916669]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.06980202272393367], {
             RGBColor[
             0.45829881865061234`, 0.5711066529638902, 0.9504981082895161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.06980202272393367], {
             RGBColor[
             0.9447605056082841, 0.9583230560458046, 0.9783902346243456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.06980202272393367], {
             RGBColor[
             0.4511758461998242, 0.5652075740460683, 0.9499695038540851]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.06980202272393367], {
             RGBColor[
             0.3607224787917016, 0.48686141351558854`, 0.9442058952676117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.06980202272393367], {
             RGBColor[
             0.7986511815042272, 0.8426316400556766, 0.9805657440188646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.06980202272393367], {
             RGBColor[
             0.8897353694892357, 0.9149148486802299, 0.989344947889666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.06980202272393367], {
             RGBColor[
             0.93753577723352, 0.9529348654533126, 0.9906198152518769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.06980202272393367], {
             RGBColor[
             0.45205205481414834`, 0.5659665019082704, 0.9500253350921889]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.06980202272393367], {
             RGBColor[
             0.40567585225278885`, 0.5257977661853365, 0.9470702844738448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.06980202272393367], {
             RGBColor[
             0.9433402546335729, 0.9572638351943125, 0.9807943490637522]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.06980202272393367], {
             RGBColor[
             0.950999201887821, 0.8434351945728756, 0.27943101152362404`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.06980202272393367], {
             RGBColor[
             0.5014771244292664, 0.60616074675551, 0.9538972626877573]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.06980202272393367], {
             RGBColor[
             0.950999201887821, 0.8434351945728756, 0.27943101152362404`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.06980202272393367], {
             RGBColor[
             0.34351240304929953`, 0.4719549109110778, 0.9431092844595783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.06980202272393367], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.06980202272393367], {
             RGBColor[
             0.5954487867023125, 0.682451175563911, 0.9612950561714327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.06980202272393367], {
             RGBColor[
             0.6936792551200989, 0.7606267733482064, 0.97010312341532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.06980202272393367], {
             RGBColor[
             0.4464309568111478, 0.5610977893426717, 0.9496671636979795]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.06980202272393367], {
             RGBColor[
             0.8200555806535611, 0.8593540764701445, 0.9826988274266375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.06980202272393367], {
             RGBColor[
             0.9363589032652497, 0.9520571547747309, 0.9926119559022686]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.06980202272393367], {
             RGBColor[
             0.8357470031474046, 0.27577270739342086`, 0.18186467662540728`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.06980202272393367], {
             RGBColor[
             0.9641591679159359, 0.8907625989321957, 0.31526556463697364`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.06980202272393367], {
             RGBColor[
             0.4605394276180518, 0.5729256802619412, 0.950674497235054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.06980202272393367], {
             RGBColor[
             0.37116081996406847`, 0.4959025799928106, 0.9448710171368522]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.06980202272393367], {
             RGBColor[
             0.5617919654339127, 0.6551270518357047, 0.9586454679121856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.06980202272393367], {
             RGBColor[
             0.985131173571602, 0.9881193724075173, 0.8960784634152634]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.06980202272393367], {
             RGBColor[
             0.8971747937118599, 0.9208468436175594, 0.9900545268132722]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.06980202272393367], {
             RGBColor[
             0.4644370073702721, 0.5760899110887606, 0.9509813289904538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.06980202272393367], {
             RGBColor[
             0.986115571063353, 0.9885264460682179, 0.8797644494379026]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.06980202272393367], {
             RGBColor[
             0.36553852431542866`, 0.4910328300867546, 0.9445127694297217]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.06980202272393367], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.06980202272393367], {
             RGBColor[
             0.3587438117977752, 0.48514759161614424`, 0.9440798163564252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.06980202272393367], {
             RGBColor[
             0.4622791115839747, 0.5743380340773471, 0.9508114515295238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.06980202272393367], {
             RGBColor[
             0.3884315130916438, 0.5108615863296401, 0.945971490431067]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.06980202272393367], {
             RGBColor[
             0.8555692791183223, 0.42813540668261096`, 0.2008465104812167]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.06980202272393367], {
             RGBColor[
             0.5331212357266935, 0.6318508618577299, 0.9563884030452899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.06980202272393367], {
             RGBColor[
             0.3285327531231125, 0.45898029104411137`, 0.9421547944122659]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.06980202272393367], {
             RGBColor[
             0.34338289748227857`, 0.4718427396980633, 0.9431010324793649]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.06980202272393367], {
             RGBColor[
             0.6222006372765375, 0.7041695330172014, 0.9634010598438932]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.06980202272393367], {
             RGBColor[
             0.532017952854134, 0.6309551671194591, 0.9563015485761037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.06980202272393367], {
             RGBColor[
             0.671705057845251, 0.7434603634270104, 0.967912940791512]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.06980202272393367], {
             RGBColor[
             0.34338289748227857`, 0.4718427396980633, 0.9431010324793649]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.06980202272393367], {
             RGBColor[
             0.8292939102215507, 0.8667204696998837, 0.9835799875479865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.06980202272393367], {
             RGBColor[
             0.7467747450798453, 0.80210537364543, 0.9753951856489435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.06980202272393367], {
             RGBColor[
             0.34351240304929953`, 0.4719549109110778, 0.9431092844595783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.06980202272393367], {
             RGBColor[
             0.9705553428750521, 0.9123383989625935, 0.3401134965368504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.06980202272393367], {
             RGBColor[
             0.6592213699486111, 0.7337080115626133, 0.9666686834486711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.06980202272393367], {
             RGBColor[
             0.9895591297847406, 0.9899504460949342, 0.8226957697802102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.06980202272393367], {
             RGBColor[
             0.38970096823224143`, 0.5119611245677551, 0.9460523789900908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.06980202272393367], {
             RGBColor[
             0.5067105600269952, 0.6104094855373332, 0.9543092579087169]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.06980202272393367], {
             RGBColor[
             0.34351240304929953`, 0.4719549109110778, 0.9431092844595783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.06980202272393367], {
             RGBColor[
             0.34351240304929953`, 0.4719549109110778, 0.9431092844595783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.06980202272393367], {
             RGBColor[
             0.9105396657565534, 0.6830266161535721, 0.24687631904503257`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.06980202272393367], {
             RGBColor[
             0.9207795496801516, 0.7236243436716014, 0.2551155700109276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.06980202272393367], {
             RGBColor[
             0.34351240304929953`, 0.4719549109110778, 0.9431092844595783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.06980202272393367], {
             RGBColor[
             0.6832091180498947, 0.7524474226929739, 0.969059558001156]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.06980202272393367], {
             RGBColor[
             0.994084592972192, 0.98975586744394, 0.5975226345626853]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.06980202272393367], {
             RGBColor[
             0.8706328047705606, 0.8996829820988643, 0.9875229282137379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.06980202272393367], {
             RGBColor[
             0.38213640236878105`, 0.5054090778229611, 0.945570371542354]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.06980202272393367], {
             RGBColor[
             0.8292939102215507, 0.8667204696998837, 0.9835799875479865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.06980202272393367], {
             RGBColor[
             0.6460238199768336, 0.7233979852195659, 0.9653532750056009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.06980202272393367], {
             RGBColor[
             0.34351240304929953`, 0.4719549109110778, 0.9431092844595783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.06980202272393367], {
             RGBColor[
             0.6370645661050712, 0.716236740052568, 0.9645712027696408]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.06980202272393367], {
             RGBColor[
             0.34351240304929953`, 0.4719549109110778, 0.9431092844595783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.06980202272393367], {
             RGBColor[
             0.3729681852570953, 0.4974680289688095, 0.9449861808551335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.06980202272393367], {
             RGBColor[
             0.3816799212971723, 0.5050136968621394, 0.9455412849721215]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.06980202272393367], {
             RGBColor[
             0.6370645661050712, 0.716236740052568, 0.9645712027696408]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.06980202272393367], {
             RGBColor[
             0.9641591679159359, 0.8907625989321957, 0.31526556463697364`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.06980202272393367], {
             RGBColor[
             0.24972786777145195`, 0.379810201062087, 0.9375330046790866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.06980202272393367], {
             RGBColor[
             0.3816799212971723, 0.5050136968621394, 0.9455412849721215]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.06980202272393367], {
             RGBColor[
             0.34351240304929953`, 0.4719549109110778, 0.9431092844595783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.06980202272393367], {
             RGBColor[
             0.5248033205274665, 0.6250980035811879, 0.9557335862912795]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.06980202272393367], {
             RGBColor[
             0.7387933167511043, 0.7958702211739155, 0.974599671463823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.06980202272393367], {
             RGBColor[
             0.53230358449515, 0.6311870557531947, 0.9563240345451877]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.06980202272393367], {
             RGBColor[
             0.439876683588614, 0.5554208073046636, 0.9492495312039559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.06980202272393367], {
             RGBColor[
             0.45205205481414834`, 0.5659665019082704, 0.9500253350921889]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.06980202272393367], {
             RGBColor[
             0.6667591447232283, 0.7395965785057543, 0.9674199783936948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.06980202272393367], {
             RGBColor[
             0.4225404009577172, 0.5404049906366815, 0.948144878604588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.06980202272393367], {
             RGBColor[
             0.9885298889352038, 0.9895248285533674, 0.8397529542469699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.06980202272393367], {
             RGBColor[
             0.671705057845251, 0.7434603634270104, 0.967912940791512]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.06980202272393367], {
             RGBColor[
             0.5238075207318325, 0.6242895684468226, 0.9556551932836322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.06980202272393367], {
             RGBColor[
             0.9721040153638283, 0.9787158008506014, 0.9321048049377186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.06980202272393367], {
             RGBColor[
             0.617427227752295, 0.7002942641257728, 0.9630252795605696]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.06980202272393367], {
             RGBColor[
             0.674069570151367, 0.7453075384115074, 0.9681486132805618]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.06980202272393367], {
             RGBColor[
             0.4040892314987769, 0.5244235150340892, 0.9469691864023928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.06980202272393367], {
             RGBColor[
             0.4382041302290722, 0.5539721256496046, 0.9491429575828667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.06980202272393367], {
             RGBColor[
             0.34351240304929953`, 0.4719549109110778, 0.9431092844595783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.06980202272393367], {
             RGBColor[
             0.42087579114847823`, 0.5389631892856404, 0.9480388111395]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.06980202272393367], {
             RGBColor[
             0.4048049768019746, 0.5250434576413141, 0.9470147930602039]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.06980202272393367], {
             RGBColor[
             0.5300388832869558, 0.6293484692887558, 0.9561457489702048]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.06980202272393367], {
             RGBColor[
             0.8439461380460744, 0.3387948511084201, 0.189716177463972]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.06980202272393367], {
             RGBColor[
             0.9497967213179729, 0.8386677598163239, 0.2784634674312776]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.06980202272393367], {
             RGBColor[
             0.8360933910278281, 0.2784351964304932, 0.18219637805089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.06980202272393367], {
             RGBColor[
             0.9603437419381813, 0.9699450081854344, 0.9520118802767914]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.06980202272393367], {
             RGBColor[
             0.4884304992270914, 0.5955689086726169, 0.9528701845604793]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.06980202272393367], {
             RGBColor[
             0.985131173571602, 0.9881193724075173, 0.8960784634152634]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100}, {
          Null, CompressedData["
1:eJwVxVmbqQwAAOCxVtbppLIkW4w1a5YJk8gSaaRCIqr783/Pr/me7715C/Zf
xfZ+fHz883x8/D9363DUk1oFBOGSrgbkKTe9Ubr+DJzlM67jGn44aCN55AiO
7OTWuWMuH0qHqrVObVrjcvv1PnbAe71DT+vplLkyddN8hkqxEiiAOngBnQA/
4nmBl/kz71Cz2Wqmz8zZE8QwHhOwC+aAKIqhFLpCL6gZpsKz8Cpshp+ghVm8
JViWU9t1dtxud0NGCI/IiIU4oXgsHi/Fq3gmo3kQT8YzygyrQz/up/w9/8Gv
+58BCZQwiZcESbpIluT8+c395n89MAjDCIzBI5iHBViCZdiCncDPzznXz/f7
6/6+Nu6Mx9x4N755Y96s9xj4/v75PnvrsXq2Xj/6SZBESYzESZIie6ROmuQz
5MbdtFt1h+5nNkDABEIQI4InZOJMOOEtuqW2s+1quzU9NEwjNEHTI1qmLdpp
99vr9t5fxsuZcrlXPpS19qvz4l7r1/6Fqxm1rPbUoXpQVc1b+CxkC4V67dF5
jB/TB/fYPW6PXCvfah1r1/a1cx1fuevuen2l0qlqaphy0SJWLE6LQlEqXjzR
aCY6jKpRLfeV//pqff3WxLbYEcfiVOTEnShexZenEW0gjUyjQTeG3maumW9+
NevNZqt5DC+p5Wy5XC23S31pLp/+ZCyJJ5P1ZC95AKJACsgAZaAKDAEV0AAX
7KJdrFvsdoWu1L3U7p37+M7dd3fxfr3f7vfH/RV4f79/3vxbeEvv8xswQkbc
SBslo2qohmYYbhAIhoLxYCqYDpaC1aARdIub7ma6ETYbaXMJsDCLsARLsyOW
5VmBlViZPbMW+2Yd7zw2j88/59l5YV6a1+eBRIJIfCfYxE+CT8iJc+IdXACL
0CK1SC+qi4WxcEEFVTCFVIoKpXSVlbJVFF25KCZsIzZh0/bIZm3eFmzJlm3L
th1vJVaJV7KVUqVSr8zDg9ZgsBysBtvBEThFT/gpcyqfeqfD6aSetCADMCEm
xsSZNFNiqgyzYFRGYwzGbU86k/5kwk3WE3Gyn1wnL6/P9+nL+gq+iq/um0dq
kUFkGuEiYuQaefkhKAyhEAlR0AxaQitoCymQDpnQ8z9pR8GG
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[69, 98] -> 
             RGBColor[
              0.35934722090825977`, 0.48438990088158124`, 0.9441651443282024],
              UndirectedEdge[29, 33] -> 
             RGBColor[
              0.29422509162390786`, 0.4255184180648389, 0.9401059109878009], 
             UndirectedEdge[55, 59] -> 
             RGBColor[
              0.26182384182735224`, 0.39252383672388913`, 0.9382218525071802],
              UndirectedEdge[47, 74] -> 
             RGBColor[
              0.31904494583740095`, 0.4476628644149205, 0.9416637299737558], 
             UndirectedEdge[19, 43] -> 
             RGBColor[
              0.25864725898215624`, 0.389185046746603, 0.9380409508134795], 
             UndirectedEdge[57, 75] -> 
             RGBColor[
              0.25952031121468844`, 0.390102679997703, 0.9380906698465571], 
             UndirectedEdge[19, 46] -> 
             RGBColor[
              0.2688995810964162, 0.39996088732345647`, 0.9386248053909352], 
             UndirectedEdge[36, 67] -> 
             RGBColor[
              0.18042977836149893`, 0.3069735153395867, 0.9335865810045261], 
             UndirectedEdge[79, 99] -> 
             RGBColor[
              0.3231374521934327, 0.4482183313765927, 0.9420339521780562], 
             UndirectedEdge[52, 68] -> 
             RGBColor[
              0.8780291995303775, 0.46447808085033465`, 0.21689224319720418`],
              UndirectedEdge[81, 85] -> 
             RGBColor[
              0.5777440554332705, 0.6680776771306483, 0.9599012748713662], 
             UndirectedEdge[12, 88] -> 
             RGBColor[
              0.44729833605503005`, 0.5559100353701449, 0.9509297720791202], 
             UndirectedEdge[72, 82] -> 
             RGBColor[
              0.8344620499016556, 0.2658959936764921, 0.180634203946131], 
             UndirectedEdge[31, 44] -> 
             RGBColor[
              0.5893518598321712, 0.6739738751825308, 0.9626393731710036], 
             UndirectedEdge[17, 79] -> 
             RGBColor[
              0.3156295526433677, 0.44171536614432994`, 0.9415555554577009], 
             UndirectedEdge[91, 96] -> 
             RGBColor[
              0.269451185257078, 0.40054065827003577`, 0.9386562184318596], 
             UndirectedEdge[55, 99] -> 
             RGBColor[
              0.32604506358539376`, 0.45127441530275375`, 0.9421995363454028],
              UndirectedEdge[77, 99] -> 
             RGBColor[
              0.4105884153235183, 0.5300527814046032, 0.9473833086487027], 
             UndirectedEdge[29, 38] -> 
             RGBColor[
              0.3762188058276783, 0.5002835531261081, 0.9451933075234802], 
             UndirectedEdge[26, 90] -> 
             RGBColor[
              0.2640863311664119, 0.39490185646935017`, 0.9383506979279865], 
             UndirectedEdge[13, 27] -> 
             RGBColor[
              0.30786109230723857`, 0.43780476345745334`, 0.9409573735218479],
              UndirectedEdge[22, 99] -> 
             RGBColor[
              0.6824515754881706, 0.7473171966554524, 0.9484738769221548], 
             UndirectedEdge[73, 74] -> 
             RGBColor[
              0.3072565676292452, 0.4352725314918011, 0.940992399274144], 
             UndirectedEdge[8, 77] -> 
             RGBColor[
              0.6903471893885933, 0.7540727058376107, 0.9477616322002713], 
             UndirectedEdge[36, 94] -> 
             RGBColor[
              0.1800640484055534, 0.3065891099672694, 0.9335657532245839], 
             UndirectedEdge[21, 87] -> 
             RGBColor[
              0.8461475149580568, 0.7442097533956613, 0.6102686063858478], 
             UndirectedEdge[59, 83] -> 
             RGBColor[
              0.24944682557751796`, 0.3795148078971581, 0.9375169997419068], 
             UndirectedEdge[24, 42] -> 
             RGBColor[
              0.7818518898687528, 0.7011631313519644, 0.6053992543639326], 
             UndirectedEdge[33, 42] -> 
             RGBColor[
              0.46221511877127164`, 0.5653020306816455, 0.952477193383617], 
             UndirectedEdge[14, 42] -> 
             RGBColor[
              0.6875842561639678, 0.755865313839969, 0.9694956308803766], 
             UndirectedEdge[45, 78] -> 
             RGBColor[
              0.8888960529642432, 0.9113695171236152, 0.8624721274568261], 
             UndirectedEdge[15, 38] -> 
             RGBColor[
              0.3740760297515814, 0.49842758818805, 0.9450567717266938], 
             UndirectedEdge[84, 85] -> 
             RGBColor[
              0.5258992134513589, 0.6255397259320082, 0.9559436352420423], 
             UndirectedEdge[55, 98] -> 
             RGBColor[
              0.2718017456530969, 0.4030112462803886, 0.9387900793690704], 
             UndirectedEdge[86, 92] -> 
             RGBColor[
              0.5898473968790202, 0.652327074257428, 0.8461866592841044], 
             UndirectedEdge[72, 92] -> 
             RGBColor[
              0.5088521381215928, 0.27790300442365007`, 0.5558317972580653], 
             UndirectedEdge[19, 99] -> 
             RGBColor[
              0.33504481922143936`, 0.46073372909370225`, 0.9427120591149303],
              UndirectedEdge[4, 76] -> 
             RGBColor[
              0.9165776385018892, 0.6448130127141793, 0.40538275488353814`], 
             UndirectedEdge[23, 76] -> 
             RGBColor[
              0.9905483291850934, 0.9895519766020239, 0.7476033518841813], 
             UndirectedEdge[9, 72] -> 
             RGBColor[
              0.8914135512087347, 0.5438293614385904, 0.22874208440602506`], 
             UndirectedEdge[2, 44] -> 
             RGBColor[
              0.6476158835940419, 0.7227173201002071, 0.9668276779841867], 
             UndirectedEdge[74, 88] -> 
             RGBColor[
              0.3260233854984479, 0.4549976469573106, 0.9420611417887761], 
             UndirectedEdge[21, 49] -> 
             RGBColor[
              0.8381155029968219, 0.7379350846059927, 0.6094680504969712], 
             UndirectedEdge[21, 34] -> 
             RGBColor[
              0.7440489383777218, 0.6635696741320418, 0.6006939636333543], 
             UndirectedEdge[59, 66] -> 
             RGBColor[
              0.2986049435975745, 0.4299329425040255, 0.9403622564770246], 
             UndirectedEdge[17, 99] -> 
             RGBColor[
              0.3958768319210234, 0.5173103472870436, 0.9464458995632381], 
             UndirectedEdge[26, 53] -> 
             RGBColor[
              0.27181647740875625`, 0.40165680145894234`, 0.9388410781260154],
              UndirectedEdge[23, 50] -> 
             RGBColor[
              0.9890507904475296, 0.9897402347152724, 0.831120268137828], 
             UndirectedEdge[41, 74] -> 
             RGBColor[
              0.39624144168094344`, 0.517626153935267, 0.9464691321747285], 
             UndirectedEdge[59, 79] -> 
             RGBColor[
              0.2589162304353912, 0.38946775279772805`, 0.9380562683398335], 
             UndirectedEdge[56, 93] -> 
             RGBColor[
              0.251058389952088, 0.3812086642339142, 0.9376087759489427], 
             UndirectedEdge[19, 98] -> 
             RGBColor[
              0.2808015012891425, 0.4124705600713371, 0.9393026021385978], 
             UndirectedEdge[2, 38] -> 
             RGBColor[
              0.4744745540542128, 0.5836658197325597, 0.9519298496562583], 
             UndirectedEdge[19, 59] -> 
             RGBColor[
              0.2708235974633978, 0.40198315051483763`, 0.9387343752767077], 
             UndirectedEdge[24, 76] -> 
             RGBColor[
              0.9509230096039614, 0.8306452679372385, 0.4351994673534736], 
             UndirectedEdge[5, 20] -> 
             RGBColor[
              0.23580229552736498`, 0.3651735417012756, 0.9367399639408238], 
             UndirectedEdge[37, 84] -> 
             RGBColor[
              0.5813861978869495, 0.66930600772412, 0.9611872941941962], 
             UndirectedEdge[9, 82] -> 
             RGBColor[
              0.8944306469902588, 0.5670200817151858, 0.2316312587337348], 
             UndirectedEdge[47, 75] -> 
             RGBColor[
              0.2704352603663721, 0.40157498360386956`, 0.9387122600535251], 
             UndirectedEdge[51, 75] -> 
             RGBColor[
              0.2631874052799758, 0.3939570283675128, 0.9382995054285956], 
             UndirectedEdge[58, 63] -> 
             RGBColor[
              0.22145736040975994`, 0.3500961053712548, 0.9359230411073061], 
             UndirectedEdge[7, 25] -> 
             RGBColor[
              0.2646919276847649, 0.3951010487472052, 0.9384011984763869], 
             UndirectedEdge[1, 55] -> 
             RGBColor[
              0.25340680094735984`, 0.3836769930878019, 0.9377425144809607], 
             UndirectedEdge[82, 86] -> 
             RGBColor[
              0.9154573086590831, 0.64032006351027, 0.4709890659721701], 
             UndirectedEdge[34, 71] -> 
             RGBColor[
              0.46781157980336074`, 0.5760433128989255, 0.9520168308232597], 
             UndirectedEdge[41, 73] -> 
             RGBColor[
              0.34062966364440406`, 0.46417862987955394`, 0.9431189034415599],
              UndirectedEdge[92, 94] -> 
             RGBColor[
              0.18353386454932197`, 0.3102361067334203, 0.9337633541208386], 
             UndirectedEdge[3, 62] -> 
             RGBColor[
              0.3326644235069168, 0.4616841238673607, 0.9424500919629462], 
             UndirectedEdge[70, 75] -> 
             RGBColor[
              0.2709835768789808, 0.4021512990238961, 0.9387434858677567], 
             UndirectedEdge[57, 96] -> 
             RGBColor[
              0.26925290833864535`, 0.40033225665728034`, 0.9386449268546793],
              UndirectedEdge[68, 72] -> 
             RGBColor[
              0.8243819770600658, 0.1884161366999483, 0.17098151480921064`], 
             UndirectedEdge[13, 54] -> 
             RGBColor[
              0.26215076948672145`, 0.392867458422297, 0.938240470553735], 
             UndirectedEdge[48, 96] -> 
             RGBColor[
              0.2710430288508906, 0.402213786815846, 0.9387468715696057], 
             UndirectedEdge[30, 50] -> 
             RGBColor[
              0.9048589996840575, 0.566437416695873, 0.47911193415723874`], 
             UndirectedEdge[11, 92] -> 
             RGBColor[
              0.21022995471211395`, 0.3382953901243926, 0.9352836569622833], 
             UndirectedEdge[41, 56] -> 
             RGBColor[
              0.3357366265014662, 0.459035737605853, 0.9428402522148693], 
             UndirectedEdge[73, 91] -> 
             RGBColor[
              0.25271649556761044`, 0.3829514383657963, 0.9377032026107992], 
             UndirectedEdge[32, 39] -> 
             RGBColor[
              0.2935264779562271, 0.4258453173585629, 0.9400272707348724], 
             UndirectedEdge[32, 80] -> 
             RGBColor[
              0.2808572092204622, 0.41252911263924097`, 0.939305774622874], 
             UndirectedEdge[20, 66] -> 
             RGBColor[
              0.271765998365242, 0.4017235093774315, 0.9388338182507047], 
             UndirectedEdge[47, 88] -> 
             RGBColor[
              0.28219998567006427`, 0.41394045582471695`, 0.9393822437552191],
              UndirectedEdge[14, 53] -> 
             RGBColor[
              0.5212638853795565, 0.6175278736453831, 0.9572307375115887], 
             UndirectedEdge[51, 57] -> 
             RGBColor[
              0.25705874177093724`, 0.3875154144398035, 0.9379504871083011], 
             UndirectedEdge[30, 94] -> 
             RGBColor[
              0.4995877733317956, 0.224777469479577, 0.549414921546451], 
             UndirectedEdge[22, 69] -> 
             RGBColor[
              0.6926573828576388, 0.7561569540400923, 0.9491241819430962], 
             UndirectedEdge[4, 94] -> 
             RGBColor[
              0.5098088734120636, 0.30334132361113186`, 0.5592026585263972], 
             UndirectedEdge[4, 86] -> 
             RGBColor[
              0.9161224057417618, 0.6454322911351396, 0.4716259636896631], 
             UndirectedEdge[9, 94] -> 
             RGBColor[
              0.566095277636464, 0.5761624637483606, 0.6066736412687983], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.25232882209907226`, 0.38254396897044507`, 0.9376811251802775],
              UndirectedEdge[12, 60] -> 
             RGBColor[
              0.5377449711891708, 0.6356046186030777, 0.9567524004381972], 
             UndirectedEdge[25, 40] -> 
             RGBColor[
              0.22979823437354924`, 0.35886289274915106`, 0.9363980415403266],
              UndirectedEdge[22, 95] -> 
             RGBColor[
              0.7735850344334367, 0.822659249453164, 0.9552736235962966], 
             UndirectedEdge[3, 33] -> 
             RGBColor[
              0.283755346452618, 0.41557523862275036`, 0.9394708192508354], 
             UndirectedEdge[48, 93] -> 
             RGBColor[
              0.2586149766637431, 0.3891511159831336, 0.9380391123832033], 
             UndirectedEdge[15, 90] -> 
             RGBColor[
              0.3120203774346074, 0.44461862031594124`, 0.9411048183197483], 
             UndirectedEdge[77, 97] -> 
             RGBColor[
              0.3343295626774611, 0.4586498895325537, 0.9427200995394867], 
             UndirectedEdge[44, 78] -> 
             RGBColor[
              0.88634546706693, 0.9093769800354632, 0.8622179088911622], 
             UndirectedEdge[30, 92] -> 
             RGBColor[
              0.5023132309055276, 0.22764209819356024`, 0.5495701323233219], 
             UndirectedEdge[37, 76] -> 
             RGBColor[
              0.8601494153237335, 0.8880770205793902, 0.7996440970661025], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.5927913677992559, 0.604221747139333, 0.6081939441102431], 
             UndirectedEdge[75, 96] -> 
             RGBColor[
              0.27538157184768386`, 0.40677387058498965`, 0.9389939451749738],
              UndirectedEdge[31, 80] -> 
             RGBColor[
              0.33469414166217204`, 0.4606589391956579, 0.9426813312926726], 
             UndirectedEdge[85, 90] -> 
             RGBColor[
              0.4615407941261787, 0.5697362170178263, 0.951844951557591], 
             UndirectedEdge[91, 93] -> 
             RGBColor[
              0.2570231330699305, 0.38747798743732337`, 0.9379484592454572], 
             UndirectedEdge[22, 49] -> 
             RGBColor[
              0.8672856751894109, 0.8967275864503471, 0.9640189035929849], 
             UndirectedEdge[69, 87] -> 
             RGBColor[
              0.6064566505030319, 0.6883381284885098, 0.9639201838642415], 
             UndirectedEdge[47, 70] -> 
             RGBColor[
              0.27576986252162594`, 0.40718198870235345`, 0.9390160577544302],
              UndirectedEdge[42, 78] -> 
             RGBColor[
              0.8251990022368825, 0.8616088969798854, 0.8561234007231051], 
             UndirectedEdge[1, 43] -> 
             RGBColor[
              0.25434890859377146`, 0.3846672079572553, 0.9377961661177004], 
             UndirectedEdge[10, 35] -> 
             RGBColor[
              0.2769526708149095, 0.4084251952129716, 0.9390834169369247], 
             UndirectedEdge[67, 94] -> 
             RGBColor[
              0.18117413693153547`, 0.3077558833917543, 0.9336289711239099], 
             UndirectedEdge[73, 93] -> 
             RGBColor[
              0.2559514270950259, 0.38635155650761516`, 0.9378874271756332], 
             UndirectedEdge[68, 82] -> 
             RGBColor[
              0.8273990728415899, 0.2116068569765438, 0.1738706891369204], 
             UndirectedEdge[11, 52] -> 
             RGBColor[
              0.5864699931809645, 0.5791596032510256, 0.6031076177106328], 
             UndirectedEdge[15, 53] -> 
             RGBColor[
              0.3197505236769518, 0.4513735653055334, 0.9415951985177772], 
             UndirectedEdge[53, 100] -> 
             RGBColor[
              0.2844126072753804, 0.4148961325895252, 0.9395584090876155], 
             UndirectedEdge[58, 83] -> 
             RGBColor[
              0.22400482828107066`, 0.3527736556227943, 0.9360681156339361], 
             UndirectedEdge[74, 96] -> 
             RGBColor[
              0.3239912573187127, 0.45286175139604057`, 0.9419454150952044], 
             UndirectedEdge[8, 87] -> 
             RGBColor[
              0.8760096171986388, 0.9035182955368775, 0.9636482023948687], 
             UndirectedEdge[43, 46] -> 
             RGBColor[
              0.2608419331067822, 0.3914917884019613, 0.9381659342581474], 
             UndirectedEdge[73, 89] -> 
             RGBColor[
              0.24808487338589558`, 0.37808330979100657`, 0.9374394385794216],
              UndirectedEdge[11, 67] -> 
             RGBColor[
              0.20787022709432745`, 0.3358151667827266, 0.9351492739653546], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.28368193490479854`, 0.4148331204560798, 0.9394909859406446], 
             UndirectedEdge[98, 99] -> 
             RGBColor[
              0.3491414135387916, 0.47555014349694125`, 0.943514839307261], 
             UndirectedEdge[4, 9] -> 
             RGBColor[
              0.8950957440729377, 0.5721323093400554, 0.23226815645122778`], 
             UndirectedEdge[34, 49] -> 
             RGBColor[
              0.678986366254469, 0.7482686816351451, 0.9692402627616367], 
             UndirectedEdge[6, 7] -> 
             RGBColor[
              0.2850997356690481, 0.41655094886844685`, 0.9395633929504454], 
             UndirectedEdge[7, 40] -> 
             RGBColor[
              0.2785823850167328, 0.4097008001089655, 0.9391922394723524], 
             UndirectedEdge[23, 85] -> 
             RGBColor[
              0.8008648229179952, 0.8435478591637703, 0.9160354539398804], 
             UndirectedEdge[82, 92] -> 
             RGBColor[
              0.5118692339031169, 0.30109372470024554`, 0.558720971585775], 
             UndirectedEdge[34, 69] -> 
             RGBColor[
              0.5043580739226968, 0.6076980492248905, 0.954345541111748], 
             UndirectedEdge[13, 85] -> 
             RGBColor[
              0.44417434838099124`, 0.5514829814433777, 0.9508559581637567], 
             UndirectedEdge[95, 98] -> 
             RGBColor[
              0.44027487248405767`, 0.5508921962946529, 0.9503145859814027], 
             UndirectedEdge[34, 87] -> 
             RGBColor[
              0.687018378215704, 0.7545433504248138, 0.9700408186505132], 
             UndirectedEdge[61, 94] -> 
             RGBColor[
              0.17986770348779496`, 0.3063827390097185, 0.9335545716719839], 
             UndirectedEdge[61, 72] -> 
             RGBColor[
              0.5051859770600657, 0.2740496366999483, 0.5556230148092107], 
             UndirectedEdge[50, 86] -> 
             RGBColor[
              0.9923931656575502, 0.9911223927597408, 0.7757284611180213], 
             UndirectedEdge[66, 97] -> 
             RGBColor[
              0.2865673127095588, 0.41728062921084064`, 0.9396767312060312], 
             UndirectedEdge[9, 21] -> 
             RGBColor[
              0.9272801117087064, 0.7490947632900866, 0.26033044528115884`], 
             UndirectedEdge[34, 60] -> 
             RGBColor[
              0.5274957486173808, 0.6272838379970835, 0.9559455440932065], 
             UndirectedEdge[53, 84] -> 
             RGBColor[
              0.3801912291988372, 0.5037242665904019, 0.9454464268280143], 
             UndirectedEdge[21, 22] -> 
             RGBColor[
              0.9323482473126639, 0.8120285789472437, 0.5954726044647025], 
             UndirectedEdge[14, 62] -> 
             RGBColor[
              0.5425047543047143, 0.6359256467112409, 0.9585841868969369], 
             UndirectedEdge[22, 30] -> 
             RGBColor[
              0.889942779596627, 0.5565022708656576, 0.5576225786548253], 
             UndirectedEdge[67, 72] -> 
             RGBColor[
              0.5064924105038062, 0.2754227810819841, 0.5556974142611366], 
             UndirectedEdge[61, 86] -> 
             RGBColor[
              0.5861812358174932, 0.6484737065337263, 0.8459778768352497], 
             UndirectedEdge[5, 83] -> 
             RGBColor[
              0.23714577838221002`, 0.3665856273634506, 0.9368164733019025], 
             UndirectedEdge[46, 99] -> 
             RGBColor[
              0.3372394933460653, 0.46304047074906063`, 0.9428370425595982], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.781084942834804, 0.8289087608987646, 0.9788149055141302], 
             UndirectedEdge[7, 37] -> 
             RGBColor[
              0.5197144859100872, 0.615889070520134, 0.9572576272411842], 
             UndirectedEdge[7, 53] -> 
             RGBColor[
              0.3185195172219749, 0.4503073293864159, 0.9415167598750023], 
             UndirectedEdge[12, 52] -> 
             RGBColor[
              0.7720788229198519, 0.7426869970369261, 0.6158231874912047], 
             UndirectedEdge[50, 85] -> 
             RGBColor[
              0.8031648921505794, 0.844498996900527, 0.8779173543675954], 
             UndirectedEdge[14, 15] -> 
             RGBColor[
              0.517451452940507, 0.6142257362851044, 0.9569878126877741], 
             UndirectedEdge[14, 35] -> 
             RGBColor[
              0.5107221888506179, 0.6078178110419963, 0.9565802436840543], 
             UndirectedEdge[8, 95] -> 
             RGBColor[
              0.7742769644814296, 0.8231752897500257, 0.9541023665093038], 
             UndirectedEdge[7, 84] -> 
             RGBColor[
              0.3751477903048108, 0.49935589331100566`, 0.9451250633614249], 
             UndirectedEdge[14, 76] -> 
             RGBColor[
              0.8566553758991764, 0.885347450425243, 0.7992958438699176], 
             UndirectedEdge[60, 89] -> 
             RGBColor[
              0.357298326389239, 0.4775030084894488, 0.9443308094531306], 
             UndirectedEdge[37, 85] -> 
             RGBColor[
              0.6704659090566354, 0.7420729031411366, 0.9680761991218017], 
             UndirectedEdge[39, 80] -> 
             RGBColor[
              0.28185045974068534`, 0.4135730819117158, 0.9393623387706183], 
             UndirectedEdge[23, 24] -> 
             RGBColor[
              0.9471254016338135, 0.8298823883137303, 0.5568344831794053], 
             UndirectedEdge[11, 68] -> 
             RGBColor[
              0.5257597936505869, 0.24880852240069085`, 0.5504333745134287], 
             UndirectedEdge[27, 81] -> 
             RGBColor[
              0.4414307993595177, 0.5543994591447239, 0.9500026902294574], 
             UndirectedEdge[36, 61] -> 
             RGBColor[
              0.17912334491775841`, 0.3056003709575509, 0.9335121815526001], 
             UndirectedEdge[28, 59] -> 
             RGBColor[
              0.2655146286535537, 0.39640308768762733`, 0.9384320373569025], 
             UndirectedEdge[8, 30] -> 
             RGBColor[
              0.8906347096446199, 0.5570183111625192, 0.5564513215678325], 
             UndirectedEdge[34, 82] -> 
             RGBColor[
              0.7111994736592744, 0.481494992557141, 0.5719947770859303], 
             UndirectedEdge[50, 84] -> 
             RGBColor[
              0.7140851809808935, 0.7717321014835103, 0.87102844943999], 
             UndirectedEdge[57, 88] -> 
             RGBColor[
              0.27128503651838054`, 0.40246815221855037`, 0.9387606535482509],
              UndirectedEdge[6, 53] -> 
             RGBColor[
              0.2901431745630745, 0.4209193221478431, 0.939884756417035], 
             UndirectedEdge[8, 69] -> 
             RGBColor[
              0.6933493129056316, 0.7566729943369539, 0.9479529248561034], 
             UndirectedEdge[69, 99] -> 
             RGBColor[
              0.41359053884055663`, 0.5326530699039465, 0.9475746013045347], 
             UndirectedEdge[81, 84] -> 
             RGBColor[
              0.4886643442635845, 0.5953107817136317, 0.9530123699437607], 
             UndirectedEdge[11, 94] -> 
             RGBColor[
              0.20750449713838193`, 0.3354307614104094, 0.9351284461854125], 
             UndirectedEdge[10, 65] -> 
             RGBColor[
              0.23682752030936433`, 0.3662511179501625, 0.9367983489754745], 
             UndirectedEdge[79, 98] -> 
             RGBColor[
              0.26889413426113584`, 0.39995516235422757`, 0.9386244952017238],
              UndirectedEdge[33, 62] -> 
             RGBColor[
              0.3171356169120182, 0.44536236355291736`, 0.9415657494001773], 
             UndirectedEdge[31, 70] -> 
             RGBColor[
              0.3382626356768291, 0.464409652660651, 0.9428845517476936], 
             UndirectedEdge[31, 32] -> 
             RGBColor[
              0.3463701598777138, 0.472931174642505, 0.9433462632569267], 
             UndirectedEdge[15, 100] -> 
             RGBColor[
              0.28060017483633093`, 0.41159399522924645`, 0.9393154842638007],
              UndirectedEdge[7, 65] -> 
             RGBColor[
              0.26785267018749115`, 0.3984231895202199, 0.9385811980860177], 
             UndirectedEdge[59, 95] -> 
             RGBColor[
              0.430296968658313, 0.5404047867381535, 0.9497463591195126], 
             UndirectedEdge[2, 3] -> 
             RGBColor[
              0.4080096464453409, 0.5252224449857339, 0.947726795683348], 
             UndirectedEdge[48, 88] -> 
             RGBColor[
              0.2730751570306258, 0.404349682377116, 0.9388625982631773], 
             UndirectedEdge[14, 38] -> 
             RGBColor[
              0.5755893914541861, 0.6645818965278997, 0.9606923107205052], 
             UndirectedEdge[44, 45] -> 
             RGBColor[
              0.7810472132422319, 0.8288792862542917, 0.9788111449809456], 
             UndirectedEdge[24, 50] -> 
             RGBColor[
              0.9494254708663976, 0.830833526050487, 0.5187163836071205], 
             UndirectedEdge[38, 62] -> 
             RGBColor[
              0.39912933111578863`, 0.5201274986141865, 0.9466531459358565], 
             UndirectedEdge[4, 50] -> 
             RGBColor[
              0.9150800997643256, 0.6450012708274279, 0.48889967113718485`], 
             UndirectedEdge[48, 74] -> 
             RGBColor[
              0.3099201171979624, 0.4380720909673196, 0.941144084481714], 
             UndirectedEdge[40, 100] -> 
             RGBColor[
              0.24447547507013836`, 0.3742896033120748, 0.9372338886849655], 
             UndirectedEdge[19, 95] -> 
             RGBColor[
              0.4261782781667054, 0.536075781891414, 0.949511805789072], 
             UndirectedEdge[19, 79] -> 
             RGBColor[
              0.2547975399437836, 0.38513874795098857`, 0.937821715009393], 
             UndirectedEdge[51, 70] -> 
             RGBColor[
              0.2685220074352297, 0.3995640334659966, 0.9386033031295007], 
             UndirectedEdge[17, 22] -> 
             RGBColor[
              0.6749436759381056, 0.7408142314231896, 0.9479954802017996], 
             UndirectedEdge[59, 99] -> 
             RGBColor[
              0.33916350971304693`, 0.46506273394044173`, 0.9429466124453707],
              UndirectedEdge[20, 63] -> 
             RGBColor[
              0.22006041247387476`, 0.34862782451902463`, 0.9358434869889567],
              UndirectedEdge[56, 89] -> 
             RGBColor[
              0.2431918362429577, 0.37294041751730556`, 0.937160787352731], 
             UndirectedEdge[12, 74] -> 
             RGBColor[
              0.48414329622236674`, 0.5896324439603484, 0.9532112582976568], 
             UndirectedEdge[8, 17] -> 
             RGBColor[
              0.6756356059860984, 0.7413302717200512, 0.9468242231148067], 
             UndirectedEdge[53, 90] -> 
             RGBColor[
              0.3158328098736569, 0.44792075767621997`, 0.941347743143563], 
             UndirectedEdge[21, 72] -> 
             RGBColor[
              0.8673115146201031, 0.4479706752513929, 0.20933339049355504`], 
             UndirectedEdge[48, 73] -> 
             RGBColor[
              0.25430833916142304`, 0.38462456691160657`, 0.9377938557485452],
              UndirectedEdge[8, 49] -> 
             RGBColor[
              0.8679776052374037, 0.8972436267472088, 0.9628476465059921], 
             UndirectedEdge[17, 69] -> 
             RGBColor[
              0.40608263929049154`, 0.5261501046716837, 0.9470962045841795], 
             UndirectedEdge[21, 82] -> 
             RGBColor[
              0.8703286104016272, 0.4711613955279884, 0.21222256482126478`], 
             UndirectedEdge[36, 68] -> 
             RGBColor[
              0.4983193449177584, 0.2199668709575509, 0.5488706815526001], 
             UndirectedEdge[21, 30] -> 
             RGBColor[
              0.860772607404038, 0.39770976902130306`, 0.2030717255588116], 
             UndirectedEdge[56, 64] -> 
             RGBColor[
              0.2634347031054928, 0.3942169540617188, 0.9383135886739146], 
             UndirectedEdge[48, 64] -> 
             RGBColor[
              0.27099128981714793`, 0.40215940581093823`, 0.9387439251081751],
              UndirectedEdge[46, 59] -> 
             RGBColor[
              0.27301827158802383`, 0.40428989217019595`, 0.9388593587213756],
              UndirectedEdge[46, 79] -> 
             RGBColor[
              0.25699221406840955`, 0.38744548960634695`, 0.937946698454061], 
             UndirectedEdge[9, 86] -> 
             RGBColor[
              0.9724088099661622, 0.9182534312723682, 0.5190969464320642], 
             UndirectedEdge[64, 91] -> 
             RGBColor[
              0.26939944622333534`, 0.400486277265128, 0.938653271970429], 
             UndirectedEdge[1, 19] -> 
             RGBColor[
              0.2624065565834054, 0.39313630687875045`, 0.9382550372504881], 
             UndirectedEdge[5, 69] -> 
             RGBColor[
              0.3370682698872072, 0.4609733107913742, 0.942896391026308], 
             UndirectedEdge[36, 92] -> 
             RGBColor[
              0.18278950597928542`, 0.3094537386812527, 0.9337209640014548], 
             UndirectedEdge[17, 95] -> 
             RGBColor[
              0.48701029086628944`, 0.5926524000847553, 0.95324564623738], 
             UndirectedEdge[7, 13] -> 
             RGBColor[
              0.293422925234443, 0.42529914882237513`, 0.9400373862831393], 
             UndirectedEdge[11, 61] -> 
             RGBColor[
              0.20656379365058694`, 0.3344420224006909, 0.9350748745134286], 
             UndirectedEdge[66, 83] -> 
             RGBColor[
              0.27310948122008705`, 0.4031355950396065, 0.9389103276117834], 
             UndirectedEdge[27, 37] -> 
             RGBColor[
              0.5341526529828826, 0.6283946851552121, 0.9581776144798929], 
             UndirectedEdge[22, 34] -> 
             RGBColor[
              0.7732191105703109, 0.8223621759763964, 0.955244816729368], 
             UndirectedEdge[6, 90] -> 
             RGBColor[
              0.2824130283207301, 0.41416437715825094`, 0.9393943762190061], 
             UndirectedEdge[71, 77] -> 
             RGBColor[
              0.3842477285736503, 0.5072378024632783, 0.9457049033811559], 
             UndirectedEdge[9, 68] -> 
             RGBColor[
              0.884350574148669, 0.48954022473864206`, 0.22197856959681445`], 
             UndirectedEdge[23, 86] -> 
             RGBColor[
              0.990093096424966, 0.9901712550229842, 0.8138465606903063], 
             UndirectedEdge[54, 84] -> 
             RGBColor[
              0.3438756345570892, 0.4669242029109275, 0.9433281476320208], 
             UndirectedEdge[3, 16] -> 
             RGBColor[
              0.26785762869397084`, 0.3988657292848884, 0.9385654677430463], 
             UndirectedEdge[66, 98] -> 
             RGBColor[
              0.3085828474233191, 0.440420352060525, 0.9409304833389149], 
             UndirectedEdge[64, 93] -> 
             RGBColor[
              0.2726343777507507, 0.4038863954069468, 0.938837496535263], 
             UndirectedEdge[2, 29] -> 
             RGBColor[
              0.41847939161663067`, 0.5351656244278226, 0.9483618874203135], 
             UndirectedEdge[50, 81] -> 
             RGBColor[
              0.7659300229628049, 0.8142700526821505, 0.8749860890693137], 
             UndirectedEdge[8, 99] -> 
             RGBColor[
              0.6831435055361634, 0.747833236952314, 0.947302619835162], 
             UndirectedEdge[66, 69] -> 
             RGBColor[
              0.37303197272508415`, 0.4975232784675301, 0.9449902453361887], 
             UndirectedEdge[9, 30] -> 
             RGBColor[
              0.8848746439926696, 0.49356845520850057`, 0.2224804194712816], 
             UndirectedEdge[11, 36] -> 
             RGBColor[
              0.20676013856834535`, 0.33464839335824176`, 0.9350860560660287],
              UndirectedEdge[16, 62] -> 
             RGBColor[
              0.30123789915337096`, 0.4286528542150554, 0.9406603978923882], 
             UndirectedEdge[50, 76] -> 
             RGBColor[
              0.9928483984176775, 0.9905031143387806, 0.7094852523118963], 
             UndirectedEdge[36, 86] -> 
             RGBColor[
              0.5863775807352516, 0.6486800774912771, 0.8459890583878498], 
             UndirectedEdge[60, 71] -> 
             RGBColor[
              0.41038752678537255`, 0.5294238797348146, 0.9474961990184465], 
             UndirectedEdge[43, 54] -> 
             RGBColor[
              0.2507606889125138, 0.3808957615659856, 0.9375918223151481], 
             UndirectedEdge[29, 42] -> 
             RGBColor[
              0.48821367053746006`, 0.5915669704381774, 0.9539966276833514], 
             UndirectedEdge[76, 84] -> 
             RGBColor[
              0.7155827197184571, 0.7715438433702618, 0.7875115331863431], 
             UndirectedEdge[65, 90] -> 
             RGBColor[
              0.26516596283917315`, 0.39603661781002397`, 0.9384121813545784],
              UndirectedEdge[52, 78] -> 
             RGBColor[
              0.9664668529248481, 0.8933481863027279, 0.5077226888807255], 
             UndirectedEdge[25, 65] -> 
             RGBColor[
              0.21906851954430756`, 0.34758528216040546`, 0.9357870001539919],
              UndirectedEdge[45, 52] -> 
             RGBColor[
              0.8611685991001501, 0.8128504925215565, 0.6243159249705089], 
             UndirectedEdge[57, 74] -> 
             RGBColor[
              0.3081299966857172, 0.43619056080875396`, 0.9410421397667876], 
             UndirectedEdge[17, 66] -> 
             RGBColor[
              0.3553182658055509, 0.48218055585062736`, 0.943861543594892], 
             UndirectedEdge[59, 98] -> 
             RGBColor[
              0.28492019178075007`, 0.41679956491807657`, 0.9395371554690384],
              UndirectedEdge[22, 77] -> 
             RGBColor[
              0.6896552593406005, 0.7535566655407491, 0.9489328892872642], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.9001907126422091, 0.6304699376692046, 0.5656021608302857], 
             UndirectedEdge[30, 36] -> 
             RGBColor[
              0.49884341476175903`, 0.2239951014274094, 0.5493725314270672], 
             UndirectedEdge[60, 64] -> 
             RGBColor[
              0.37754119325177404`, 0.49877954503386207`, 0.9454836107743141],
              UndirectedEdge[28, 99] -> 
             RGBColor[
              0.3297358504115952, 0.455153666266492, 0.9424097211951252], 
             UndirectedEdge[59, 69] -> 
             RGBColor[
              0.34936931708251506`, 0.4739024913250818, 0.9435969174663121], 
             UndirectedEdge[66, 79] -> 
             RGBColor[
              0.2825788860779602, 0.4130885399401764, 0.93944959620971], 
             UndirectedEdge[7, 81] -> 
             RGBColor[
              0.42699263228672224`, 0.5418938445096457, 0.9490827029907487], 
             UndirectedEdge[26, 100] -> 
             RGBColor[
              0.2326661285681354, 0.3618772313826554, 0.9365613638720389], 
             UndirectedEdge[5, 97] -> 
             RGBColor[
              0.2506036098716818, 0.3807306615346847, 0.9375828768961504], 
             UndirectedEdge[20, 83] -> 
             RGBColor[
              0.22260788034518547`, 0.3513053747705641, 0.9359885615155867], 
             UndirectedEdge[21, 92] -> 
             RGBColor[
              0.5447186986215644, 0.48316840627514634`, 0.5874201581331991], 
             UndirectedEdge[77, 98] -> 
             RGBColor[
              0.35634509739122144`, 0.481789612382238, 0.9439738516723704], 
             UndirectedEdge[13, 84] -> 
             RGBColor[
              0.35509463721130535`, 0.4787160860263612, 0.9439670532361513], 
             UndirectedEdge[83, 97] -> 
             RGBColor[
              0.23740919468950228`, 0.36686249460397324`, 0.9368314744709133],
              UndirectedEdge[4, 24] -> 
             RGBColor[
              0.8731547109506095, 0.48514342442588576`, 0.2146138861787622], 
             UndirectedEdge[7, 85] -> 
             RGBColor[
              0.46422750147449665`, 0.5721227887280222, 0.9520139682890303], 
             UndirectedEdge[10, 40] -> 
             RGBColor[
              0.247557235138606, 0.37752872853890806`, 0.9374093903618093], 
             UndirectedEdge[26, 40] -> 
             RGBColor[
              0.23187934520351416`, 0.3610502721814919, 0.9365165577233654], 
             UndirectedEdge[56, 74] -> 
             RGBColor[
              0.3023635304863073, 0.4301296392181001, 0.9407137480474534], 
             UndirectedEdge[42, 62] -> 
             RGBColor[
              0.5111241958255703, 0.6114109159262558, 0.9554564660957278], 
             UndirectedEdge[4, 36] -> 
             RGBColor[
              0.5090645148420271, 0.3025589555589642, 0.5591602684070134], 
             UndirectedEdge[2, 33] -> 
             RGBColor[
              0.39248083985044224`, 0.5089006846712906, 0.946842453120579], 
             UndirectedEdge[36, 82] -> 
             RGBColor[
              0.5083994177593483, 0.2974467279340947, 0.5585233706895204], 
             UndirectedEdge[76, 81] -> 
             RGBColor[
              0.7674275617003685, 0.8140817945689018, 0.7914691728156671], 
             UndirectedEdge[27, 43] -> 
             RGBColor[
              0.29647101173303086`, 0.4258330666011419, 0.9403087252832609], 
             UndirectedEdge[61, 67] -> 
             RGBColor[
              0.1802334334437405, 0.3067671443820358, 0.933575399451926], 
             UndirectedEdge[10, 26] -> 
             RGBColor[
              0.235747888636603, 0.36511635660948866`, 0.9367368655488828], 
             UndirectedEdge[63, 83] -> 
             RGBColor[
              0.2214038953287198, 0.3500399101811996, 0.9359199963500353], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.28220392258022686`, 0.41350726570694146`, 0.9393984806790088],
              UndirectedEdge[20, 97] -> 
             RGBColor[
              0.23606571183465724`, 0.3654504089417983, 0.9367549651098346], 
             UndirectedEdge[28, 98] -> 
             RGBColor[
              0.27549253247929834`, 0.40689049724412685`, 0.9390002642187927],
              UndirectedEdge[4, 23] -> 
             RGBColor[
              0.9127800305317415, 0.6440501330906712, 0.5270177707094699], 
             UndirectedEdge[30, 86] -> 
             RGBColor[
              0.9059013056614938, 0.5668684370035848, 0.46183822670971686`], 
             UndirectedEdge[27, 54] -> 
             RGBColor[
              0.2966420896530224, 0.4260128803420197, 0.9403184679177174], 
             UndirectedEdge[1, 13] -> 
             RGBColor[
              0.2657389891679791, 0.3966389048135667, 0.9384448143562873], 
             UndirectedEdge[15, 35] -> 
             RGBColor[
              0.3092088271480132, 0.4416635027021466, 0.9409447046902427], 
             UndirectedEdge[56, 73] -> 
             RGBColor[
              0.24675175244976794`, 0.37668211516238714`, 0.9373635193142849],
              UndirectedEdge[16, 29] -> 
             RGBColor[
              0.27832737386526063`, 0.40880890872697706`, 0.9392005594800119],
              UndirectedEdge[53, 65] -> 
             RGBColor[
              0.2728961090815175, 0.40279156279961614`, 0.9389025615526072], 
             UndirectedEdge[6, 25] -> 
             RGBColor[
              0.2363155850258645, 0.36571304150863243`, 0.9367691950184196], 
             UndirectedEdge[68, 92] -> 
             RGBColor[
              0.501789161061527, 0.22361386772370176`, 0.5490682824488547], 
             UndirectedEdge[69, 97] -> 
             RGBColor[
              0.3373316861944994, 0.46125017803189694`, 0.9429113921953187], 
             UndirectedEdge[17, 77] -> 
             RGBColor[
              0.4030805157734533, 0.5235498161723404, 0.9469049119283475], 
             UndirectedEdge[46, 98] -> 
             RGBColor[
              0.2829961754137684, 0.41477730172669547`, 0.9394275855832659], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.34313416867820656`, 0.4716273033094493, 0.9430851836999117], 
             UndirectedEdge[17, 55] -> 
             RGBColor[
              0.3185371640353287, 0.44477145007049096`, 0.9417211396250476], 
             UndirectedEdge[2, 78] -> 
             RGBColor[
              0.7554647233160532, 0.8052075509695305, 0.8504886604600671], 
             UndirectedEdge[6, 35] -> 
             RGBColor[
              0.2796014780341359, 0.41120925954445625`, 0.9392342625895005], 
             UndirectedEdge[95, 99] -> 
             RGBColor[
              0.49451819041635453`, 0.5991553653170181, 0.9537240429577352], 
             UndirectedEdge[66, 99] -> 
             RGBColor[
              0.36282616535561596`, 0.48868352108289015`, 0.9443399403152473],
              UndirectedEdge[31, 39] -> 
             RGBColor[
              0.34736341039793694`, 0.47397514391497986`, 0.943402827404671], 
             UndirectedEdge[69, 71] -> 
             RGBColor[
              0.38724985209068863`, 0.5098380909626216, 0.9458961960369879], 
             UndirectedEdge[64, 89] -> 
             RGBColor[
              0.2647678240416204, 0.39561814869033823`, 0.9383895079390514], 
             UndirectedEdge[40, 53] -> 
             RGBColor[
              0.2836258239107592, 0.41406917338836174`, 0.9395136029389419], 
             UndirectedEdge[1, 27] -> 
             RGBColor[
              0.3002303093342801, 0.42978432673328937`, 0.9405228117202697], 
             UndirectedEdge[41, 48] -> 
             RGBColor[
              0.34329321321312134`, 0.4669781893550724, 0.9432705886491298], 
             UndirectedEdge[57, 70] -> 
             RGBColor[
              0.26485491336994227`, 0.39570968509618687`, 0.9383944675474621],
              UndirectedEdge[39, 44] -> 
             RGBColor[
              0.5365081779106845, 0.6268880178985887, 0.9593203806489492], 
             UndirectedEdge[6, 15] -> 
             RGBColor[
              0.286330742124025, 0.4176171847875644, 0.9396418315932203], 
             UndirectedEdge[6, 40] -> 
             RGBColor[
              0.2502060423578324, 0.3803127928703927, 0.9375602360143851], 
             UndirectedEdge[17, 59] -> 
             RGBColor[
              0.33165561016298184`, 0.45855976870817894`, 0.9424682157250155],
              UndirectedEdge[56, 91] -> 
             RGBColor[
              0.2478234584246726, 0.37780854609209535`, 0.9374245513841087], 
             UndirectedEdge[5, 59] -> 
             RGBColor[
              0.26264124075969747`, 0.39338297482786955`, 0.9382684021671439],
              UndirectedEdge[20, 58] -> 
             RGBColor[
              0.22266134542622565`, 0.3513615699606193, 0.9359916062728575], 
             UndirectedEdge[17, 19] -> 
             RGBColor[
              0.32753691967137427`, 0.45423076386143946`, 0.9422336623945751],
              UndirectedEdge[3, 38] -> 
             RGBColor[
              0.36574906065638857`, 0.4903403736840195, 0.9445582157865146], 
             UndirectedEdge[1, 17] -> 
             RGBColor[
              0.32323856928298944`, 0.4497129250720918, 0.941988877698796], 
             UndirectedEdge[2, 42] -> 
             RGBColor[
              0.5864694187639945, 0.6749492370446291, 0.9607331698161294], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.44521446884155214`, 0.5537197588039671, 0.950811098924118], 
             UndirectedEdge[48, 56] -> 
             RGBColor[
              0.2494153020184852, 0.3794816746379056, 0.9375152045218548], 
             UndirectedEdge[86, 94] -> 
             RGBColor[
              0.5871219393052882, 0.6494624455434448, 0.8460314485072336], 
             UndirectedEdge[23, 30] -> 
             RGBColor[
              0.9025589304514734, 0.5654862789591164, 0.5172300337295237], 
             UndirectedEdge[30, 82] -> 
             RGBColor[
              0.8279231426855904, 0.21563508744640228`, 0.17437253901138755`],
              UndirectedEdge[60, 74] -> 
             RGBColor[
              0.4164700206325886, 0.5346922301902434, 0.9478837701478531], 
             UndirectedEdge[10, 90] -> 
             RGBColor[
              0.2797642211015037, 0.41138031282676635`, 0.9392435305664304], 
             UndirectedEdge[49, 69] -> 
             RGBColor[
              0.5984246385417968, 0.6820634596988412, 0.9631196279753649], 
             UndirectedEdge[25, 100] -> 
             RGBColor[
              0.23058501773817044`, 0.3596898519503145, 0.9364428476890001], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.23295897687627548`, 0.36218503352216574`, 0.9365780411499574],
              UndirectedEdge[31, 51] -> 
             RGBColor[
              0.33046646407782415`, 0.4562153820042676, 0.9424405713085325], 
             UndirectedEdge[37, 50] -> 
             RGBColor[
              0.8586518765861698, 0.8882652786926387, 0.8831610133197494], 
             UndirectedEdge[6, 10] -> 
             RGBColor[
              0.25407458579092124`, 0.3843788772983895, 0.9377805438399023], 
             UndirectedEdge[69, 77] -> 
             RGBColor[
              0.4207942226929865, 0.5388925387892431, 0.9480336136696441], 
             UndirectedEdge[12, 96] -> 
             RGBColor[
              0.4452662078752948, 0.5537741398088749, 0.9508140453855485], 
             UndirectedEdge[12, 41] -> 
             RGBColor[
              0.5175163922375255, 0.6185385423481014, 0.9553377624650727], 
             UndirectedEdge[89, 93] -> 
             RGBColor[
              0.25239151088821565`, 0.3826098588625336, 0.9376846952140795], 
             UndirectedEdge[37, 81] -> 
             RGBColor[
              0.6332310398688609, 0.7118439589227601, 0.9651449338235201], 
             UndirectedEdge[14, 24] -> 
             RGBColor[
              0.8132324483478965, 0.7256778621369495, 0.6085269751651416], 
             UndirectedEdge[52, 67] -> 
             RGBColor[
              0.560139632974118, 0.5514847252323705, 0.6016081426491302], 
             UndirectedEdge[23, 27] -> 
             RGBColor[
              0.6645515668442425, 0.7298696411778459, 0.9061368692979717], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.2386756834212212, 0.36819365456103337`, 0.9369035991305825], 
             UndirectedEdge[23, 81] -> 
             RGBColor[
              0.7636299537302207, 0.8133189149453938, 0.9131041886415987], 
             UndirectedEdge[88, 96] -> 
             RGBColor[
              0.2871462971513761, 0.419139342805837, 0.9396639288766677], 
             UndirectedEdge[77, 95] -> 
             RGBColor[
              0.5017218742687843, 0.6053948342023149, 0.9541830553228445], 
             UndirectedEdge[74, 91] -> 
             RGBColor[
              0.3083282736041498, 0.43639896242150933`, 0.941053431343968], 
             UndirectedEdge[7, 100] -> 
             RGBColor[
              0.27936916838135406`, 0.4105277593101289, 0.939237045621026], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.3593964815136068, 0.4839037453450634, 0.9441876459561919], 
             UndirectedEdge[6, 100] -> 
             RGBColor[
              0.2509928257224536, 0.38113975207155615`, 0.9376050421630586], 
             UndirectedEdge[19, 55] -> 
             RGBColor[
              0.2577051513357447, 0.38819483187714965`, 0.9379872991767397], 
             UndirectedEdge[17, 28] -> 
             RGBColor[
              0.3222279508615301, 0.4486507010342292, 0.9419313244747699], 
             UndirectedEdge[64, 96] -> 
             RGBColor[
              0.28506242993789815`, 0.4169490662396592, 0.9395452557216655], 
             UndirectedEdge[67, 68] -> 
             RGBColor[
              0.49942943344374047`, 0.22113364438203578`, 0.5489338994519259],
              UndirectedEdge[22, 87] -> 
             RGBColor[
              0.875317687150646, 0.9030022552400158, 0.9648194594818615], 
             UndirectedEdge[42, 44] -> 
             RGBColor[
              0.7173501625148713, 0.7791186661105619, 0.9724624182472246], 
             UndirectedEdge[70, 96] -> 
             RGBColor[
              0.28071617400293775`, 0.4123808756834735, 0.9392977428758789], 
             UndirectedEdge[64, 88] -> 
             RGBColor[
              0.2870945581176334, 0.41908496180092925`, 0.9396609824152371], 
             UndirectedEdge[26, 65] -> 
             RGBColor[
              0.2211496303742725, 0.34977266159274634`, 0.9359055163370308], 
             UndirectedEdge[2, 14] -> 
             RGBColor[
              0.6178499772431384, 0.6994639678296142, 0.9638608906173386], 
             UndirectedEdge[11, 72] -> 
             RGBColor[
              0.5328227707106528, 0.3030976591006391, 0.5571968893226393], 
             UndirectedEdge[67, 86] -> 
             RGBColor[
              0.5874876692612337, 0.649846850915762, 0.8460522762871756], 
             UndirectedEdge[40, 90] -> 
             RGBColor[
              0.27589567766841483`, 0.4073142283987696, 0.939023222740913], 
             UndirectedEdge[27, 84] -> 
             RGBColor[
              0.38958595737760626`, 0.5118615079460839, 0.9460450506001336], 
             UndirectedEdge[13, 43] -> 
             RGBColor[
              0.26197969156672996`, 0.39268764468141926`, 0.9382307279192786],
              UndirectedEdge[52, 72] -> 
             RGBColor[
              0.8850921765904433, 0.518767217550283, 0.2236557580064148], 
             UndirectedEdge[10, 53] -> 
             RGBColor[
              0.28749436734384803`, 0.4181352578163585, 0.9397339107644591], 
             UndirectedEdge[15, 40] -> 
             RGBColor[
              0.2798133914717097, 0.41076703602808307`, 0.9392706781151272], 
             UndirectedEdge[21, 68] -> 
             RGBColor[
              0.8602485375600374, 0.3936815385514446, 0.2025698756843444], 
             UndirectedEdge[28, 83] -> 
             RGBColor[
              0.24001916627606623`, 0.36960574022320836`, 0.9369801084916611],
              UndirectedEdge[54, 100] -> 
             RGBColor[
              0.24809701263363243`, 0.37809606891005076`, 0.9374401298916217],
              UndirectedEdge[47, 96] -> 
             RGBColor[
              0.280167857490329, 0.4118045602634469, 0.9392665170616474], 
             UndirectedEdge[47, 51] -> 
             RGBColor[
              0.26797369092262097`, 0.39898771804597, 0.9385720773152693], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.3409913926021096, 0.4697713383713912, 0.9429486479031253], 
             UndirectedEdge[39, 45] -> 
             RGBColor[
              0.5390587638079978, 0.6288805549867408, 0.959574599214613], 
             UndirectedEdge[58, 97] -> 
             RGBColor[
              0.23746265977054243`, 0.3669186897940284, 0.936834519228184], 
             UndirectedEdge[31, 45] -> 
             RGBColor[
              0.5919024457294845, 0.6759664122706829, 0.9628935917366674], 
             UndirectedEdge[6, 26] -> 
             RGBColor[
              0.23839669585582945`, 0.3679004209409733, 0.9368877112014585], 
             UndirectedEdge[41, 91] -> 
             RGBColor[
              0.34170136961930875`, 0.46530506080926215`, 0.9431799355113838],
              UndirectedEdge[8, 22] -> 
             RGBColor[
              0.9622103495532457, 0.9713371210884598, 0.9488522004737234], 
             UndirectedEdge[46, 95] -> 
             RGBColor[
              0.42837295229133143`, 0.5383825235467723, 0.9496367892337401], 
             UndirectedEdge[66, 95] -> 
             RGBColor[
              0.4539596243008821, 0.5640255738806018, 0.9511396869893891], 
             UndirectedEdge[23, 37] -> 
             RGBColor[
              0.8563518073535856, 0.887314140955882, 0.9212791128920343], 
             UndirectedEdge[10, 100] -> 
             RGBColor[
              0.2483440185032272, 0.37835568774007156`, 0.9374541965104828], 
             UndirectedEdge[5, 79] -> 
             RGBColor[
              0.24661518324008325`, 0.37653857226402054`, 0.9373557418998293],
              UndirectedEdge[38, 42] -> 
             RGBColor[
              0.5442088329750422, 0.6400671657429147, 0.9575645899192962], 
             UndirectedEdge[40, 54] -> 
             RGBColor[
              0.24731022926901122`, 0.37726910970888733`, 0.9373953237429482],
              UndirectedEdge[32, 45] -> 
             RGBColor[
              0.5380655132877746, 0.6278365857142659, 0.9595180350668688], 
             UndirectedEdge[41, 60] -> 
             RGBColor[
              0.44984311664774745`, 0.5635983285779962, 0.9500102743152689], 
             UndirectedEdge[88, 91] -> 
             RGBColor[
              0.2714833134368132, 0.40267655383130574`, 0.9387719451254313], 
             UndirectedEdge[47, 57] -> 
             RGBColor[
              0.2643065968573336, 0.3951333696761603, 0.9383632417332306], 
             UndirectedEdge[27, 85] -> 
             RGBColor[
              0.4786656685472922, 0.5846284033631004, 0.952933955527739], 
             UndirectedEdge[69, 95] -> 
             RGBColor[
              0.5047239977858227, 0.6079951227016581, 0.9543743479786766], 
             UndirectedEdge[36, 72] -> 
             RGBColor[
              0.5053823219778242, 0.27425600765749925`, 0.5556341963618108], 
             UndirectedEdge[6, 65] -> 
             RGBColor[
              0.23947632752859074`, 0.3690351822816471, 0.9369491946280504], 
             UndirectedEdge[49, 77] -> 
             RGBColor[
              0.5954225150247585, 0.679463171199498, 0.9629283353195328], 
             UndirectedEdge[2, 62] -> 
             RGBColor[
              0.441389916904741, 0.555009569915901, 0.9498217258326898], 
             UndirectedEdge[22, 66] -> 
             RGBColor[
              0.6418930093726982, 0.712187405219036, 0.9458895209538087], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.37246108295649283`, 0.49696932160080975`, 0.9449560466299856],
              UndirectedEdge[73, 88] -> 
             RGBColor[
              0.2704116074619085, 0.40155012290159753`, 0.9387109130556073], 
             UndirectedEdge[8, 21] -> 
             RGBColor[
              0.9330401773606567, 0.8125446192441054, 0.5943013473777097], 
             UndirectedEdge[31, 75] -> 
             RGBColor[
              0.3329280335215753, 0.45880264756216715`, 0.9425807540467885], 
             UndirectedEdge[4, 30] -> 
             RGBColor[
              0.8285882397682693, 0.2207473150712718, 0.17500943672888053`], 
             UndirectedEdge[48, 91] -> 
             RGBColor[
              0.2553800451363277, 0.3857509978413148, 0.9378548878183692], 
             UndirectedEdge[19, 28] -> 
             RGBColor[
              0.26139593816194606`, 0.39207408284088785`, 0.938197484026462], 
             UndirectedEdge[28, 66] -> 
             RGBColor[
              0.28917728429612277`, 0.42002387483007575`, 0.9398253652267791],
              UndirectedEdge[3, 29] -> 
             RGBColor[
              0.30975389821880644`, 0.4418401783792823, 0.9409902535505699], 
             UndirectedEdge[22, 82] -> 
             RGBColor[
              0.8994987825942162, 0.6299538973723429, 0.5667734179172785], 
             UndirectedEdge[49, 82] -> 
             RGBColor[
              0.8052660382783743, 0.5558604030310919, 0.5807688639495472], 
             UndirectedEdge[23, 84] -> 
             RGBColor[
              0.7117851117483094, 0.7707809637467538, 0.909146549012275], 
             UndirectedEdge[65, 100] -> 
             RGBColor[
              0.2337457602408967, 0.3630119927233292, 0.9366228472986309], 
             UndirectedEdge[53, 85] -> 
             RGBColor[
              0.46927094036852307`, 0.5764911620074185, 0.9523353317556198], 
             UndirectedEdge[59, 97] -> 
             RGBColor[
              0.26290465706698973`, 0.3936598420683923, 0.9382834033361547], 
             UndirectedEdge[17, 98] -> 
             RGBColor[
              0.34163351398872654`, 0.46904717826467845`, 0.9430364425869058],
              UndirectedEdge[61, 68] -> 
             RGBColor[0.49812300000000004`, 0.2197605, 0.5488595000000001], 
             UndirectedEdge[28, 55] -> 
             RGBColor[
              0.2523961825259005, 0.38261476904993935`, 0.9376849612569346], 
             UndirectedEdge[9, 36] -> 
             RGBColor[
              0.5653509190664274, 0.575380095696193, 0.6066312511494145], 
             UndirectedEdge[20, 59] -> 
             RGBColor[
              0.24810334272267293`, 0.37810272223498315`, 0.9374404903808281],
              UndirectedEdge[48, 57] -> 
             RGBColor[
              0.25518176821789507`, 0.38554259622855935`, 0.9378435962411888],
              UndirectedEdge[1, 46] -> 
             RGBColor[
              0.26460123070803143`, 0.39544304853410883`, 0.9383800206951561],
              UndirectedEdge[5, 66] -> 
             RGBColor[
              0.2863038964022665, 0.41700376197031797`, 0.9396617300370205], 
             UndirectedEdge[64, 74] -> 
             RGBColor[
              0.32393951828497003`, 0.45280737039113284`, 0.9419424686337738],
              UndirectedEdge[55, 79] -> 
             RGBColor[
              0.24579778430773802`, 0.37567943416004, 0.9373091922398655], 
             UndirectedEdge[32, 51] -> 
             RGBColor[
              0.27662953163611426`, 0.40808555544785063`, 0.9390650146387339],
              UndirectedEdge[64, 73] -> 
             RGBColor[
              0.26832774024843065`, 0.39935984633541977`, 0.938592239900605], 
             UndirectedEdge[35, 38] -> 
             RGBColor[
              0.3673467656616922, 0.49201966294494187`, 0.9446492027229738], 
             UndirectedEdge[71, 87] -> 
             RGBColor[
              0.5699101563836958, 0.656683392162545, 0.9615914735757531], 
             UndirectedEdge[82, 87] -> 
             RGBColor[
              0.8132980502396094, 0.5621350718207605, 0.5815694198384238], 
             UndirectedEdge[5, 77] -> 
             RGBColor[
              0.33406614637016885`, 0.458373022292031, 0.9427050983704759], 
             UndirectedEdge[57, 64] -> 
             RGBColor[
              0.2692011693049027, 0.4002778756523726, 0.9386419803932486], 
             UndirectedEdge[63, 97] -> 
             RGBColor[
              0.23486172681819156`, 0.36418494435243376`, 0.9366863999442832],
              UndirectedEdge[41, 93] -> 
             RGBColor[
              0.34493630114672413`, 0.468705178951081, 0.9433641600762177], 
             UndirectedEdge[9, 61] -> 
             RGBColor[
              0.565154574148669, 0.575173724738642, 0.6066200695968145], 
             UndirectedEdge[17, 46] -> 
             RGBColor[
              0.32973159379600026`, 0.45653750551679784`, 0.942358645839243], 
             UndirectedEdge[25, 54] -> 
             RGBColor[
              0.2334197719370433, 0.36266935834712705`, 0.9366042827469828], 
             UndirectedEdge[59, 77] -> 
             RGBColor[
              0.3463671935654768, 0.47130220282573854`, 0.9434056248104801], 
             UndirectedEdge[66, 77] -> 
             RGBColor[
              0.3700298492080458, 0.49492298996818684`, 0.9447989526803566], 
             UndirectedEdge[7, 27] -> 
             RGBColor[
              0.327914245400744, 0.45844457074209777`, 0.9421153836471216], 
             UndirectedEdge[61, 92] -> 
             RGBColor[
              0.182593161061527, 0.30924736772370176`, 0.9337097824488547], 
             UndirectedEdge[77, 87] -> 
             RGBColor[
              0.6034545269859937, 0.6857378399891666, 0.9637288912084094], 
             UndirectedEdge[28, 79] -> 
             RGBColor[
              0.24948857113393946`, 0.3795586851237783, 0.937519377089588], 
             UndirectedEdge[5, 28] -> 
             RGBColor[
              0.25321358145824574`, 0.3834739071539198, 0.9377315109168982], 
             UndirectedEdge[56, 88] -> 
             RGBColor[
              0.26551857031897064`, 0.39640723062789657`, 0.9384322618289168],
              UndirectedEdge[25, 26] -> 
             RGBColor[
              0.21798888787154624`, 0.3464505208197316, 0.9357255167274], 
             UndirectedEdge[9, 67] -> 
             RGBColor[
              0.5664610075924095, 0.5765468691206779, 0.6066944690487404], 
             UndirectedEdge[32, 44] -> 
             RGBColor[
              0.5355149273904612, 0.6258440486261139, 0.959263816501205], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.5412488824777958, 0.4795214095089955, 0.5872225572369445], 
             UndirectedEdge[79, 83] -> 
             RGBColor[
              0.23342076805790374`, 0.3626704053333091, 0.9366043394745922], 
             UndirectedEdge[60, 93] -> 
             RGBColor[
              0.3651648800983693, 0.48577125520605746`, 0.9447787980493423], 
             UndirectedEdge[5, 63] -> 
             RGBColor[
              0.2345983105108993, 0.3639080771119111, 0.9366713987752724], 
             UndirectedEdge[19, 66] -> 
             RGBColor[
              0.2944862531059669, 0.425603937657286, 0.9401277031465842], 
             UndirectedEdge[8, 86] -> 
             RGBColor[
              0.9781688756181125, 0.981703287226387, 0.853067848528615], 
             UndirectedEdge[4, 37] -> 
             RGBColor[
              0.7823811166703816, 0.5425751770680375, 0.5790585158913912], 
             UndirectedEdge[9, 92] -> 
             RGBColor[
              0.5688207352101959, 0.5790270924623439, 0.606828852045669], 
             UndirectedEdge[3, 42] -> 
             RGBColor[
              0.4777439253661703, 0.5816237909960889, 0.9533615359463858], 
             UndirectedEdge[7, 90] -> 
             RGBColor[
              0.31078937097963055`, 0.4435523843968237, 0.9410263796769736], 
             UndirectedEdge[35, 62] -> 
             RGBColor[
              0.3342621285122205, 0.46336341312828305`, 0.9425410788994055], 
             UndirectedEdge[20, 79] -> 
             RGBColor[
              0.2320772852030587, 0.3612583196711341, 0.9365278301135136], 
             UndirectedEdge[31, 78] -> 
             RGBColor[
              0.6972006995541824, 0.7564641060518543, 0.846300355646884], 
             UndirectedEdge[13, 81] -> 
             RGBColor[
              0.40693947919321677`, 0.5212540372250012, 0.947924692865475], 
             UndirectedEdge[18, 80] -> 
             RGBColor[
              0.2419836729170215, 0.3716705612597674, 0.9370919842386365], 
             UndirectedEdge[90, 100] -> 
             RGBColor[
              0.27668246103303606`, 0.408141187599933, 0.9390680288895865], 
             UndirectedEdge[67, 92] -> 
             RGBColor[
              0.1838995945052675, 0.31062051210573755`, 0.9337841819007806], 
             UndirectedEdge[55, 66] -> 
             RGBColor[
              0.28548649746992133`, 0.41614462386633744`, 0.9396151803770567],
              UndirectedEdge[89, 91] -> 
             RGBColor[
              0.24915657936080024`, 0.3792097407207148, 0.9375004706492456], 
             UndirectedEdge[46, 55] -> 
             RGBColor[
              0.25989982546037066`, 0.390501573532508, 0.9381122826214077], 
             UndirectedEdge[41, 64] -> 
             RGBColor[
              0.3573126143001289, 0.48171346877888566`, 0.9440689728011896], 
             UndirectedEdge[28, 46] -> 
             RGBColor[
              0.2635906122865721, 0.39438082449624623`, 0.93832246747113], 
             UndirectedEdge[35, 53] -> 
             RGBColor[
              0.3130212595870627, 0.4449656400624253, 0.9411876295140573], 
             UndirectedEdge[35, 90] -> 
             RGBColor[
              0.3052911133447183, 0.4382106950728331, 0.9406972493160285], 
             UndirectedEdge[5, 58] -> 
             RGBColor[
              0.23719924346325016`, 0.36664182255350575`, 0.9368195180591732],
              UndirectedEdge[76, 85] -> 
             RGBColor[
              0.8046624308881429, 0.8443107387872784, 0.7944004381139487], 
             UndirectedEdge[34, 77] -> 
             RGBColor[
              0.5013559504056586, 0.6050977607255472, 0.9541542484559159], 
             UndirectedEdge[49, 71] -> 
             RGBColor[
              0.5618781444224608, 0.6504087233728764, 0.9607909176868766]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1.2}, VertexStyle -> {
             EdgeForm[None], 25 -> 
             RGBColor[
              0.21590777704158132`, 0.3442631413873908, 0.9356070005443611], 
             55 -> RGBColor[
              0.2487053956996991, 0.3787355180862011, 0.9374747764072122], 90 -> 
             RGBColor[
              0.30810266363131256`, 0.4411658126866278, 0.9408573629455341], 
             27 -> RGBColor[
              0.3423524124735395, 0.470950185377176, 0.9430353708858302], 15 -> 
             RGBColor[
              0.3159380912379023, 0.44807142794525473`, 0.9413522736939626], 
             98 -> RGBColor[
              0.2948980956064947, 0.4272869744745761, 0.9401053823309286], 38 -> 
             RGBColor[
              0.43221396826526043`, 0.5487837484308453, 0.9487612697594249], 
             99 -> RGBColor[
              0.40338473147108844`, 0.5238133125193064, 0.9469242962835934], 
             71 -> RGBColor[
              0.3507033579713525, 0.4781833546366567, 0.9435674857484997], 41 -> 
             RGBColor[
              0.4296145376961023, 0.5465322523230198, 0.9485956363421444], 75 -> 
             RGBColor[
              0.26564897472372695`, 0.3965442939254123, 0.9384396881668516], 
             64 -> RGBColor[
              0.2850106909041555, 0.4168946852347515, 0.9395423092602349], 63 -> 
             RGBColor[
              0.21885642745740908`, 0.34736235992966014`, 0.9357749218234052],
              85 -> RGBColor[
              0.6149789246210449, 0.6983066213490248, 0.9628325401696478], 3 -> 
             RGBColor[
              0.29928415304751665`, 0.4318969989371937, 0.9403551618136042], 
             86 -> RGBColor[
              0.9934354716349865, 0.9915534130674525, 0.7584547536704994], 94 -> 
             RGBColor[
              0.18080840697558995`, 0.30737147801943704`, 0.9336081433439677],
              61 -> RGBColor[0.178927, 0.305394, 0.933501], 84 -> 
             RGBColor[
              0.4368195022816731, 0.5527728305149917, 0.9490547303144369], 76 -> 
             RGBColor[
              0.9943459371552411, 0.990314856225532, 0.6259683360582495], 21 -> 
             RGBColor[
              0.9031780751200748, 0.6532360771028892, 0.2409217513686888], 87 -> 
             RGBColor[
              0.789116954796039, 0.8351834296884333, 0.9796154614030067], 95 -> 
             RGBColor[
              0.5856516493616206, 0.6744974181147299, 0.9605237896318769], 72 -> 
             RGBColor[
              0.8314449541201315, 0.24270527339989661`, 0.17774502961842129`],
              42 -> 
             RGBColor[
              0.6562036976848239, 0.731350583054984, 0.9663679100791674], 66 -> 
             RGBColor[
              0.32226759924014353`, 0.45355372964647384`, 0.9417555843469012],
              1 -> RGBColor[
              0.2581082061950206, 0.38861846808940276`, 0.9380102525547092], 
             24 -> RGBColor[
              0.9075000820526815, 0.6709756796489449, 0.2444305986486977], 54 -> 
             RGBColor[
              0.2509317668325053, 0.3810755753068633, 0.9376015649496046], 4 -> 
             RGBColor[
              0.8388093398485373, 0.29931116920282663`, 0.1847971737088267], 
             7 -> RGBColor[
              0.3134760783279485, 0.4459389561070196, 0.9411953964084129], 
             100 -> RGBColor[
              0.24526225843475957`, 0.3751165625132382, 0.937278694833639], 
             12 -> RGBColor[
              0.6054182467789488, 0.6905448323731828, 0.9620798885880011], 65 -> 
             RGBColor[
              0.2222292620470338, 0.35090742293342014`, 0.9359669997636226], 
             8 -> RGBColor[
              0.9629022796012385, 0.9718531613853215, 0.9476809433867306], 57 -> 
             RGBColor[
              0.25339164770564987`, 0.38366106606999373`, 0.9377416515262625],
              74 -> RGBColor[
              0.3628683456657846, 0.48872005554751413`, 0.9443426280073127], 
             37 -> RGBColor[
              0.7259528934922258, 0.7858391849332483, 0.9733198580739556], 43 -> 
             RGBColor[
              0.25058961099252225`, 0.3807159478251078, 0.9375820796806917], 
             39 -> RGBColor[
              0.2945197284764503, 0.42688928663103776`, 0.9400838348826166], 
             58 -> RGBColor[
              0.22405829336211083`, 0.3528298508128494, 0.9360711603912069], 
             11 -> RGBColor[
              0.23420058730117388`, 0.3634900448013817, 0.9366487490268572], 
             51 -> RGBColor[
              0.26072583583622466`, 0.3913697628096132, 0.9381593226903397], 
             48 -> RGBColor[
              0.2569718887301403, 0.38742412638712503`, 0.9379455409561153], 
             20 -> RGBColor[
              0.22126439749034046`, 0.3498932891083892, 0.9359120521545081], 
             33 -> RGBColor[
              0.26822653985771944`, 0.399253478308307, 0.9385864766880666], 
             45 -> RGBColor[
              0.7835977991395453, 0.8308718233424438, 0.9790653635466094], 23 -> 
             RGBColor[
              0.9867507212149456, 0.9887890969785158, 0.869238367710113], 22 -> 
             RGBColor[
              0.9615184195052529, 0.9708210807915982, 0.9500234575607163], 2 -> 
             RGBColor[
              0.5167351398431651, 0.6185478910342742, 0.9550984295530915], 60 -> 
             RGBColor[
              0.4700716955993926, 0.5806644048329727, 0.9514249122883933], 16 -> 
             RGBColor[
              0.23643110434042502`, 0.36583445963258315`, 0.9367757736724883],
              79 -> RGBColor[
              0.24289017291577697`, 0.372623350233879, 0.937143608072519], 89 -> 
             RGBColor[
              0.24452495717908534`, 0.374341612145925, 0.9372367066178678], 
             36 -> RGBColor[
              0.17931968983551683`, 0.3058067419151018, 0.9335233631052001], 
             52 -> RGBColor[
              0.938739399060755, 0.7948291617006693, 0.26956648639440833`], 
             32 -> RGBColor[
              0.2925332274360039, 0.424801348086088, 0.9399707065871281], 31 -> 
             RGBColor[
              0.40020709231942364`, 0.521061001198922, 0.9467218199267253], 
             68 -> RGBColor[0.817319, 0.134127, 0.164218], 73 -> 
             RGBColor[
              0.2516447895927058, 0.3818250074360881, 0.9376421705409753], 82 -> 
             RGBColor[
              0.8374791456831797, 0.2890867139530876, 0.18352337827384074`], 
             35 -> RGBColor[
              0.30247956305812407`, 0.4352555774590384, 0.9405371356865229], 
             88 -> RGBColor[
              0.28917842533111127`, 0.421275238367107, 0.9397796555702393], 
             50 -> RGBColor[
              0.9913508596801138, 0.9906913724520291, 0.7930021685655431], 19 -> 
             RGBColor[
              0.2667049069717902, 0.39765414566809815`, 0.9384998219462671], 
             17 -> RGBColor[
              0.3883689323709583, 0.5108073820547808, 0.9459675028428829], 96 -> 
             RGBColor[
              0.2851141689716408, 0.417003447244567, 0.939548202183096], 14 -> 
             RGBColor[
              0.7189648146431117, 0.780380044624954, 0.9726233516815856], 5 -> 
             RGBColor[
              0.2503401935643895, 0.38045379429416204`, 0.9375678757271396], 
             34 -> RGBColor[
              0.5849198016353689, 0.6739032711611944, 0.9604661758980197], 97 -> 
             RGBColor[
              0.25086702617897405`, 0.38100752877520744`, 0.9375978780651611],
              93 -> RGBColor[
              0.26025806459734596`, 0.3908781055791422, 0.9381326838102911], 
             81 -> RGBColor[
              0.5405091862454959, 0.6378487329122717, 0.9569700095730845], 69 -> 
             RGBColor[
              0.42379634621002477`, 0.5414928272885864, 0.9482249063254762], 
             9 -> RGBColor[
              0.9513821482973379, 0.8449534494772841, 0.27973913919362886`], 
             13 -> RGBColor[
              0.2733697721409376, 0.40465934153773064`, 0.9388793761578655], 
             30 -> RGBColor[
              0.8183671396880012, 0.14218346093971695`, 0.1652216997489344], 
             59 -> RGBColor[
              0.2749422879550054, 0.4063121553615771, 0.9389689286071481], 28 -> 
             RGBColor[
              0.25608696935210196`, 0.3864940200136776, 0.9378951461066569], 
             80 -> RGBColor[
              0.26918119100492044`, 0.4002568771923939, 0.9386408426586199], 
             47 -> RGBColor[
              0.27522154600901727`, 0.40660567328232683`, 0.9389848319401988],
              62 -> RGBColor[
              0.3660446939663169, 0.4914712487975277, 0.9445450221122881], 77 -> 
             RGBColor[
              0.4177920991759482, 0.5362922502898999, 0.947842321013812], 78 -> 
             RGBColor[
              0.9941943067889412, 0.9918672109047867, 0.7458788913670427], 40 -> 
             RGBColor[
              0.24368869170551716`, 0.37346264411091135`, 0.937189082536292], 
             67 -> RGBColor[
              0.181539866887481, 0.30814028876407157`, 0.9336497989038519], 
             56 -> RGBColor[
              0.24185871530683006`, 0.3715392228886861, 0.9370848680875943], 
             10 -> RGBColor[
              0.25142577857169485`, 0.38159481296690484`, 0.9376296981873266],
              53 -> RGBColor[
              0.3235629561160013, 0.45467570266581214`, 0.9418381233415918], 
             26 -> RGBColor[
              0.2200699987015112, 0.3486379002520725, 0.9358440329104389], 18 -> 
             RGBColor[
              0.21478615482912253`, 0.34308424532714094`, 0.935543125818653], 
             29 -> RGBColor[
              0.32022364339009624`, 0.4517833578213709, 0.9416253452875354], 
             92 -> RGBColor[
              0.18625932212305402`, 0.3131007354474035, 0.9339185648977094], 
             46 -> RGBColor[
              0.2710942552210422, 0.40226762897881485`, 0.9387497888356031], 
             49 -> RGBColor[
              0.773052930873569, 0.822634092109096, 0.9780143496252536], 83 -> 
             RGBColor[
              0.2239513632000305, 0.3527174604327391, 0.9360650708766655], 70 -> 
             RGBColor[
              0.27631817903423467`, 0.40775830412238, 0.9390472835686617], 44 -> 
             RGBColor[
              0.7784966273449186, 0.8268867491661398, 0.9785569264152818], 91 -> 
             RGBColor[
              0.25378820154251513`, 0.3840778692955045, 0.9377642346806232], 
             6 -> RGBColor[
              0.2567233930101477, 0.3871629416298741, 
               0.9379313894924781]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9lHs01Akbx4dhXCZmRjNjDGZ+vxEpY003Oez6fWm7uFSIpJWyrGvrtqF9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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 13}], {
             RGBColor[
             0.2657389891679791, 0.3966389048135667, 0.9384448143562873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 17}], {
             RGBColor[
             0.32323856928298944`, 0.4497129250720918, 0.941988877698796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 19}], {
             RGBColor[
             0.2624065565834054, 0.39313630687875045`, 0.9382550372504881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 27}], {
             RGBColor[
             0.3002303093342801, 0.42978432673328937`, 0.9405228117202697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 43}], {
             RGBColor[
             0.25434890859377146`, 0.3846672079572553, 0.9377961661177004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 46}], {
             RGBColor[
             0.26460123070803143`, 0.39544304853410883`, 0.9383800206951561]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 55}], {
             RGBColor[
             0.25340680094735984`, 0.3836769930878019, 0.9377425144809607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 3}], {
             RGBColor[
             0.4080096464453409, 0.5252224449857339, 0.947726795683348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 14}], {
             RGBColor[
             0.6178499772431384, 0.6994639678296142, 0.9638608906173386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 29}], {
             RGBColor[
             0.41847939161663067`, 0.5351656244278226, 0.9483618874203135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 33}], {
             RGBColor[
             0.39248083985044224`, 0.5089006846712906, 0.946842453120579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 38}], {
             RGBColor[
             0.4744745540542128, 0.5836658197325597, 0.9519298496562583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 42}], {
             RGBColor[
             0.5864694187639945, 0.6749492370446291, 0.9607331698161294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 44}], {
             RGBColor[
             0.6476158835940419, 0.7227173201002071, 0.9668276779841867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 62}], {
             RGBColor[
             0.441389916904741, 0.555009569915901, 0.9498217258326898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 78}], {
             RGBColor[
             0.7554647233160532, 0.8052075509695305, 0.8504886604600671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 16}], {
             RGBColor[
             0.26785762869397084`, 0.3988657292848884, 0.9385654677430463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 29}], {
             RGBColor[
             0.30975389821880644`, 0.4418401783792823, 0.9409902535505699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 33}], {
             RGBColor[
             0.283755346452618, 0.41557523862275036`, 0.9394708192508354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 38}], {
             RGBColor[
             0.36574906065638857`, 0.4903403736840195, 0.9445582157865146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 42}], {
             RGBColor[
             0.4777439253661703, 0.5816237909960889, 0.9533615359463858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 62}], {
             RGBColor[
             0.3326644235069168, 0.4616841238673607, 0.9424500919629462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 9}], {
             RGBColor[
             0.8950957440729377, 0.5721323093400554, 0.23226815645122778`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 23}], {
             RGBColor[
             0.9127800305317415, 0.6440501330906712, 0.5270177707094699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 24}], {
             RGBColor[
             0.8731547109506095, 0.48514342442588576`, 0.2146138861787622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 30}], {
             RGBColor[
             0.8285882397682693, 0.2207473150712718, 0.17500943672888053`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 36}], {
             RGBColor[
             0.5090645148420271, 0.3025589555589642, 0.5591602684070134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 37}], {
             RGBColor[
             0.7823811166703816, 0.5425751770680375, 0.5790585158913912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 50}], {
             RGBColor[
             0.9150800997643256, 0.6450012708274279, 0.48889967113718485`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 76}], {
             RGBColor[
             0.9165776385018892, 0.6448130127141793, 0.40538275488353814`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 86}], {
             RGBColor[
             0.9161224057417618, 0.6454322911351396, 0.4716259636896631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 94}], {
             RGBColor[
             0.5098088734120636, 0.30334132361113186`, 0.5592026585263972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 20}], {
             RGBColor[
             0.23580229552736498`, 0.3651735417012756, 0.9367399639408238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 28}], {
             RGBColor[
             0.25321358145824574`, 0.3834739071539198, 0.9377315109168982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 58}], {
             RGBColor[
             0.23719924346325016`, 0.36664182255350575`, 0.9368195180591732]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.26264124075969747`, 0.39338297482786955`, 0.9382684021671439]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 63}], {
             RGBColor[
             0.2345983105108993, 0.3639080771119111, 0.9366713987752724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 66}], {
             RGBColor[
             0.2863038964022665, 0.41700376197031797`, 0.9396617300370205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 69}], {
             RGBColor[
             0.3370682698872072, 0.4609733107913742, 0.942896391026308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[
             0.33406614637016885`, 0.458373022292031, 0.9427050983704759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 79}], {
             RGBColor[
             0.24661518324008325`, 0.37653857226402054`, 0.9373557418998293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[
             0.23714577838221002`, 0.3665856273634506, 0.9368164733019025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 97}], {
             RGBColor[
             0.2506036098716818, 0.3807306615346847, 0.9375828768961504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 7}], {
             RGBColor[
             0.2850997356690481, 0.41655094886844685`, 0.9395633929504454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 10}], {
             RGBColor[
             0.25407458579092124`, 0.3843788772983895, 0.9377805438399023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 15}], {
             RGBColor[
             0.286330742124025, 0.4176171847875644, 0.9396418315932203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 25}], {
             RGBColor[
             0.2363155850258645, 0.36571304150863243`, 0.9367691950184196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 26}], {
             RGBColor[
             0.23839669585582945`, 0.3679004209409733, 0.9368877112014585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 35}], {
             RGBColor[
             0.2796014780341359, 0.41120925954445625`, 0.9392342625895005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 40}], {
             RGBColor[
             0.2502060423578324, 0.3803127928703927, 0.9375602360143851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.2901431745630745, 0.4209193221478431, 0.939884756417035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 65}], {
             RGBColor[
             0.23947632752859074`, 0.3690351822816471, 0.9369491946280504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 90}], {
             RGBColor[
             0.2824130283207301, 0.41416437715825094`, 0.9393943762190061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 100}], {
             RGBColor[
             0.2509928257224536, 0.38113975207155615`, 0.9376050421630586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 13}], {
             RGBColor[
             0.293422925234443, 0.42529914882237513`, 0.9400373862831393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 25}], {
             RGBColor[
             0.2646919276847649, 0.3951010487472052, 0.9384011984763869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 27}], {
             RGBColor[
             0.327914245400744, 0.45844457074209777`, 0.9421153836471216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 37}], {
             RGBColor[
             0.5197144859100872, 0.615889070520134, 0.9572576272411842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 40}], {
             RGBColor[
             0.2785823850167328, 0.4097008001089655, 0.9391922394723524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 53}], {
             RGBColor[
             0.3185195172219749, 0.4503073293864159, 0.9415167598750023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.28220392258022686`, 0.41350726570694146`, 0.9393984806790088]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 65}], {
             RGBColor[
             0.26785267018749115`, 0.3984231895202199, 0.9385811980860177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 81}], {
             RGBColor[
             0.42699263228672224`, 0.5418938445096457, 0.9490827029907487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.3751477903048108, 0.49935589331100566`, 0.9451250633614249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 85}], {
             RGBColor[
             0.46422750147449665`, 0.5721227887280222, 0.9520139682890303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 90}], {
             RGBColor[
             0.31078937097963055`, 0.4435523843968237, 0.9410263796769736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 100}], {
             RGBColor[
             0.27936916838135406`, 0.4105277593101289, 0.939237045621026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 17}], {
             RGBColor[
             0.6756356059860984, 0.7413302717200512, 0.9468242231148067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.9330401773606567, 0.8125446192441054, 0.5943013473777097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 22}], {
             RGBColor[
             0.9622103495532457, 0.9713371210884598, 0.9488522004737234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 30}], {
             RGBColor[
             0.8906347096446199, 0.5570183111625192, 0.5564513215678325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 49}], {
             RGBColor[
             0.8679776052374037, 0.8972436267472088, 0.9628476465059921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 69}], {
             RGBColor[
             0.6933493129056316, 0.7566729943369539, 0.9479529248561034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 77}], {
             RGBColor[
             0.6903471893885933, 0.7540727058376107, 0.9477616322002713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.9001907126422091, 0.6304699376692046, 0.5656021608302857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 86}], {
             RGBColor[
             0.9781688756181125, 0.981703287226387, 0.853067848528615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 87}], {
             RGBColor[
             0.8760096171986388, 0.9035182955368775, 0.9636482023948687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 95}], {
             RGBColor[
             0.7742769644814296, 0.8231752897500257, 0.9541023665093038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 99}], {
             RGBColor[
             0.6831435055361634, 0.747833236952314, 0.947302619835162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.5927913677992559, 0.604221747139333, 0.6081939441102431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 21}], {
             RGBColor[
             0.9272801117087064, 0.7490947632900866, 0.26033044528115884`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 30}], {
             RGBColor[
             0.8848746439926696, 0.49356845520850057`, 0.2224804194712816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 36}], {
             RGBColor[
             0.5653509190664274, 0.575380095696193, 0.6066312511494145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 61}], {
             RGBColor[
             0.565154574148669, 0.575173724738642, 0.6066200695968145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 67}], {
             RGBColor[
             0.5664610075924095, 0.5765468691206779, 0.6066944690487404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 68}], {
             RGBColor[
             0.884350574148669, 0.48954022473864206`, 0.22197856959681445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 72}], {
             RGBColor[
             0.8914135512087347, 0.5438293614385904, 0.22874208440602506`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 82}], {
             RGBColor[
             0.8944306469902588, 0.5670200817151858, 0.2316312587337348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 86}], {
             RGBColor[
             0.9724088099661622, 0.9182534312723682, 0.5190969464320642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 92}], {
             RGBColor[
             0.5688207352101959, 0.5790270924623439, 0.606828852045669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 94}], {
             RGBColor[
             0.566095277636464, 0.5761624637483606, 0.6066736412687983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.28368193490479854`, 0.4148331204560798, 0.9394909859406446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 26}], {
             RGBColor[
             0.235747888636603, 0.36511635660948866`, 0.9367368655488828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 35}], {
             RGBColor[
             0.2769526708149095, 0.4084251952129716, 0.9390834169369247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 40}], {
             RGBColor[
             0.247557235138606, 0.37752872853890806`, 0.9374093903618093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 53}], {
             RGBColor[
             0.28749436734384803`, 0.4181352578163585, 0.9397339107644591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 65}], {
             RGBColor[
             0.23682752030936433`, 0.3662511179501625, 0.9367983489754745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 90}], {
             RGBColor[
             0.2797642211015037, 0.41138031282676635`, 0.9392435305664304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 100}], {
             RGBColor[
             0.2483440185032272, 0.37835568774007156`, 0.9374541965104828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 36}], {
             RGBColor[
             0.20676013856834535`, 0.33464839335824176`, 0.9350860560660287]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 52}], {
             RGBColor[
             0.5864699931809645, 0.5791596032510256, 0.6031076177106328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 61}], {
             RGBColor[
             0.20656379365058694`, 0.3344420224006909, 0.9350748745134286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 67}], {
             RGBColor[
             0.20787022709432745`, 0.3358151667827266, 0.9351492739653546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 68}], {
             RGBColor[
             0.5257597936505869, 0.24880852240069085`, 0.5504333745134287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 72}], {
             RGBColor[
             0.5328227707106528, 0.3030976591006391, 0.5571968893226393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 92}], {
             RGBColor[
             0.21022995471211395`, 0.3382953901243926, 0.9352836569622833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 94}], {
             RGBColor[
             0.20750449713838193`, 0.3354307614104094, 0.9351284461854125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 41}], {
             RGBColor[
             0.5175163922375255, 0.6185385423481014, 0.9553377624650727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 52}], {
             RGBColor[
             0.7720788229198519, 0.7426869970369261, 0.6158231874912047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 60}], {
             RGBColor[
             0.5377449711891708, 0.6356046186030777, 0.9567524004381972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.44521446884155214`, 0.5537197588039671, 0.950811098924118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 74}], {
             RGBColor[
             0.48414329622236674`, 0.5896324439603484, 0.9532112582976568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 88}], {
             RGBColor[
             0.44729833605503005`, 0.5559100353701449, 0.9509297720791202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 96}], {
             RGBColor[
             0.4452662078752948, 0.5537741398088749, 0.9508140453855485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 27}], {
             RGBColor[
             0.30786109230723857`, 0.43780476345745334`, 0.9409573735218479]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 43}], {
             RGBColor[
             0.26197969156672996`, 0.39268764468141926`, 0.9382307279192786]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 54}], {
             RGBColor[
             0.26215076948672145`, 0.392867458422297, 0.938240470553735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 81}], {
             RGBColor[
             0.40693947919321677`, 0.5212540372250012, 0.947924692865475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 84}], {
             RGBColor[
             0.35509463721130535`, 0.4787160860263612, 0.9439670532361513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 85}], {
             RGBColor[
             0.44417434838099124`, 0.5514829814433777, 0.9508559581637567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 15}], {
             RGBColor[
             0.517451452940507, 0.6142257362851044, 0.9569878126877741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 24}], {
             RGBColor[
             0.8132324483478965, 0.7256778621369495, 0.6085269751651416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 35}], {
             RGBColor[
             0.5107221888506179, 0.6078178110419963, 0.9565802436840543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 38}], {
             RGBColor[
             0.5755893914541861, 0.6645818965278997, 0.9606923107205052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 42}], {
             RGBColor[
             0.6875842561639678, 0.755865313839969, 0.9694956308803766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 53}], {
             RGBColor[
             0.5212638853795565, 0.6175278736453831, 0.9572307375115887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 62}], {
             RGBColor[
             0.5425047543047143, 0.6359256467112409, 0.9585841868969369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 76}], {
             RGBColor[
             0.8566553758991764, 0.885347450425243, 0.7992958438699176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 35}], {
             RGBColor[
             0.3092088271480132, 0.4416635027021466, 0.9409447046902427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 38}], {
             RGBColor[
             0.3740760297515814, 0.49842758818805, 0.9450567717266938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 40}], {
             RGBColor[
             0.2798133914717097, 0.41076703602808307`, 0.9392706781151272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 53}], {
             RGBColor[
             0.3197505236769518, 0.4513735653055334, 0.9415951985177772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.3409913926021096, 0.4697713383713912, 0.9429486479031253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 90}], {
             RGBColor[
             0.3120203774346074, 0.44461862031594124`, 0.9411048183197483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 100}], {
             RGBColor[
             0.28060017483633093`, 0.41159399522924645`, 0.9393154842638007]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 29}], {
             RGBColor[
             0.27832737386526063`, 0.40880890872697706`, 0.9392005594800119]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.25232882209907226`, 0.38254396897044507`, 0.9376811251802775]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 62}], {
             RGBColor[
             0.30123789915337096`, 0.4286528542150554, 0.9406603978923882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 19}], {
             RGBColor[
             0.32753691967137427`, 0.45423076386143946`, 0.9422336623945751]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 22}], {
             RGBColor[
             0.6749436759381056, 0.7408142314231896, 0.9479954802017996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 28}], {
             RGBColor[
             0.3222279508615301, 0.4486507010342292, 0.9419313244747699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 46}], {
             RGBColor[
             0.32973159379600026`, 0.45653750551679784`, 0.942358645839243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 55}], {
             RGBColor[
             0.3185371640353287, 0.44477145007049096`, 0.9417211396250476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 59}], {
             RGBColor[
             0.33165561016298184`, 0.45855976870817894`, 0.9424682157250155]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 66}], {
             RGBColor[
             0.3553182658055509, 0.48218055585062736`, 0.943861543594892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 69}], {
             RGBColor[
             0.40608263929049154`, 0.5261501046716837, 0.9470962045841795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 77}], {
             RGBColor[
             0.4030805157734533, 0.5235498161723404, 0.9469049119283475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 79}], {
             RGBColor[
             0.3156295526433677, 0.44171536614432994`, 0.9415555554577009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 95}], {
             RGBColor[
             0.48701029086628944`, 0.5926524000847553, 0.95324564623738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 98}], {
             RGBColor[
             0.34163351398872654`, 0.46904717826467845`, 0.9430364425869058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.3958768319210234, 0.5173103472870436, 0.9464458995632381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 80}], {
             RGBColor[
             0.2419836729170215, 0.3716705612597674, 0.9370919842386365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 28}], {
             RGBColor[
             0.26139593816194606`, 0.39207408284088785`, 0.938197484026462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 43}], {
             RGBColor[
             0.25864725898215624`, 0.389185046746603, 0.9380409508134795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 46}], {
             RGBColor[
             0.2688995810964162, 0.39996088732345647`, 0.9386248053909352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 55}], {
             RGBColor[
             0.2577051513357447, 0.38819483187714965`, 0.9379872991767397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 59}], {
             RGBColor[
             0.2708235974633978, 0.40198315051483763`, 0.9387343752767077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 66}], {
             RGBColor[
             0.2944862531059669, 0.425603937657286, 0.9401277031465842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 79}], {
             RGBColor[
             0.2547975399437836, 0.38513874795098857`, 0.937821715009393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 95}], {
             RGBColor[
             0.4261782781667054, 0.536075781891414, 0.949511805789072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 98}], {
             RGBColor[
             0.2808015012891425, 0.4124705600713371, 0.9393026021385978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 99}], {
             RGBColor[
             0.33504481922143936`, 0.46073372909370225`, 0.9427120591149303]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.2386756834212212, 0.36819365456103337`, 0.9369035991305825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 58}], {
             RGBColor[
             0.22266134542622565`, 0.3513615699606193, 0.9359916062728575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 59}], {
             RGBColor[
             0.24810334272267293`, 0.37810272223498315`, 0.9374404903808281]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 63}], {
             RGBColor[
             0.22006041247387476`, 0.34862782451902463`, 0.9358434869889567]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 66}], {
             RGBColor[
             0.271765998365242, 0.4017235093774315, 0.9388338182507047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 79}], {
             RGBColor[
             0.2320772852030587, 0.3612583196711341, 0.9365278301135136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 83}], {
             RGBColor[
             0.22260788034518547`, 0.3513053747705641, 0.9359885615155867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 97}], {
             RGBColor[
             0.23606571183465724`, 0.3654504089417983, 0.9367549651098346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 22}], {
             RGBColor[
             0.9323482473126639, 0.8120285789472437, 0.5954726044647025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 30}], {
             RGBColor[
             0.860772607404038, 0.39770976902130306`, 0.2030717255588116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 34}], {
             RGBColor[
             0.7440489383777218, 0.6635696741320418, 0.6006939636333543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.5412488824777958, 0.4795214095089955, 0.5872225572369445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 49}], {
             RGBColor[
             0.8381155029968219, 0.7379350846059927, 0.6094680504969712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 68}], {
             RGBColor[
             0.8602485375600374, 0.3936815385514446, 0.2025698756843444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 72}], {
             RGBColor[
             0.8673115146201031, 0.4479706752513929, 0.20933339049355504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 82}], {
             RGBColor[
             0.8703286104016272, 0.4711613955279884, 0.21222256482126478`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[
             0.8461475149580568, 0.7442097533956613, 0.6102686063858478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 92}], {
             RGBColor[
             0.5447186986215644, 0.48316840627514634`, 0.5874201581331991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 30}], {
             RGBColor[
             0.889942779596627, 0.5565022708656576, 0.5576225786548253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 34}], {
             RGBColor[
             0.7732191105703109, 0.8223621759763964, 0.955244816729368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 49}], {
             RGBColor[
             0.8672856751894109, 0.8967275864503471, 0.9640189035929849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 66}], {
             RGBColor[
             0.6418930093726982, 0.712187405219036, 0.9458895209538087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 69}], {
             RGBColor[
             0.6926573828576388, 0.7561569540400923, 0.9491241819430962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 77}], {
             RGBColor[
             0.6896552593406005, 0.7535566655407491, 0.9489328892872642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 82}], {
             RGBColor[
             0.8994987825942162, 0.6299538973723429, 0.5667734179172785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 87}], {
             RGBColor[
             0.875317687150646, 0.9030022552400158, 0.9648194594818615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 95}], {
             RGBColor[
             0.7735850344334367, 0.822659249453164, 0.9552736235962966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 99}], {
             RGBColor[
             0.6824515754881706, 0.7473171966554524, 0.9484738769221548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 24}], {
             RGBColor[
             0.9471254016338135, 0.8298823883137303, 0.5568344831794053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 27}], {
             RGBColor[
             0.6645515668442425, 0.7298696411778459, 0.9061368692979717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 30}], {
             RGBColor[
             0.9025589304514734, 0.5654862789591164, 0.5172300337295237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 37}], {
             RGBColor[
             0.8563518073535856, 0.887314140955882, 0.9212791128920343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 50}], {
             RGBColor[
             0.9890507904475296, 0.9897402347152724, 0.831120268137828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 76}], {
             RGBColor[
             0.9905483291850934, 0.9895519766020239, 0.7476033518841813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[
             0.7636299537302207, 0.8133189149453938, 0.9131041886415987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 84}], {
             RGBColor[
             0.7117851117483094, 0.7707809637467538, 0.909146549012275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 85}], {
             RGBColor[
             0.8008648229179952, 0.8435478591637703, 0.9160354539398804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 86}], {
             RGBColor[
             0.990093096424966, 0.9901712550229842, 0.8138465606903063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 42}], {
             RGBColor[
             0.7818518898687528, 0.7011631313519644, 0.6053992543639326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 50}], {
             RGBColor[
             0.9494254708663976, 0.830833526050487, 0.5187163836071205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 76}], {
             RGBColor[
             0.9509230096039614, 0.8306452679372385, 0.4351994673534736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 26}], {
             RGBColor[
             0.21798888787154624`, 0.3464505208197316, 0.9357255167274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 40}], {
             RGBColor[
             0.22979823437354924`, 0.35886289274915106`, 0.9363980415403266]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 54}], {
             RGBColor[
             0.2334197719370433, 0.36266935834712705`, 0.9366042827469828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 65}], {
             RGBColor[
             0.21906851954430756`, 0.34758528216040546`, 0.9357870001539919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 100}], {
             RGBColor[
             0.23058501773817044`, 0.3596898519503145, 0.9364428476890001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 40}], {
             RGBColor[
             0.23187934520351416`, 0.3610502721814919, 0.9365165577233654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 53}], {
             RGBColor[
             0.27181647740875625`, 0.40165680145894234`, 0.9388410781260154]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 65}], {
             RGBColor[
             0.2211496303742725, 0.34977266159274634`, 0.9359055163370308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 90}], {
             RGBColor[
             0.2640863311664119, 0.39490185646935017`, 0.9383506979279865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[
             0.2326661285681354, 0.3618772313826554, 0.9365613638720389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 37}], {
             RGBColor[
             0.5341526529828826, 0.6283946851552121, 0.9581776144798929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 43}], {
             RGBColor[
             0.29647101173303086`, 0.4258330666011419, 0.9403087252832609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 54}], {
             RGBColor[
             0.2966420896530224, 0.4260128803420197, 0.9403184679177174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 81}], {
             RGBColor[
             0.4414307993595177, 0.5543994591447239, 0.9500026902294574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 84}], {
             RGBColor[
             0.38958595737760626`, 0.5118615079460839, 0.9460450506001336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 85}], {
             RGBColor[
             0.4786656685472922, 0.5846284033631004, 0.952933955527739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 46}], {
             RGBColor[
             0.2635906122865721, 0.39438082449624623`, 0.93832246747113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 55}], {
             RGBColor[
             0.2523961825259005, 0.38261476904993935`, 0.9376849612569346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 59}], {
             RGBColor[
             0.2655146286535537, 0.39640308768762733`, 0.9384320373569025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 66}], {
             RGBColor[
             0.28917728429612277`, 0.42002387483007575`, 0.9398253652267791]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 79}], {
             RGBColor[
             0.24948857113393946`, 0.3795586851237783, 0.937519377089588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 83}], {
             RGBColor[
             0.24001916627606623`, 0.36960574022320836`, 0.9369801084916611]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 98}], {
             RGBColor[
             0.27549253247929834`, 0.40689049724412685`, 0.9390002642187927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 99}], {
             RGBColor[
             0.3297358504115952, 0.455153666266492, 0.9424097211951252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 33}], {
             RGBColor[
             0.29422509162390786`, 0.4255184180648389, 0.9401059109878009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 38}], {
             RGBColor[
             0.3762188058276783, 0.5002835531261081, 0.9451933075234802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 42}], {
             RGBColor[
             0.48821367053746006`, 0.5915669704381774, 0.9539966276833514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.34313416867820656`, 0.4716273033094493, 0.9430851836999117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 36}], {
             RGBColor[
             0.49884341476175903`, 0.2239951014274094, 0.5493725314270672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 50}], {
             RGBColor[
             0.9048589996840575, 0.566437416695873, 0.47911193415723874`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 82}], {
             RGBColor[
             0.8279231426855904, 0.21563508744640228`, 0.17437253901138755`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 86}], {
             RGBColor[
             0.9059013056614938, 0.5668684370035848, 0.46183822670971686`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 92}], {
             RGBColor[
             0.5023132309055276, 0.22764209819356024`, 0.5495701323233219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 94}], {
             RGBColor[
             0.4995877733317956, 0.224777469479577, 0.549414921546451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 32}], {
             RGBColor[
             0.3463701598777138, 0.472931174642505, 0.9433462632569267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 39}], {
             RGBColor[
             0.34736341039793694`, 0.47397514391497986`, 0.943402827404671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 44}], {
             RGBColor[
             0.5893518598321712, 0.6739738751825308, 0.9626393731710036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 45}], {
             RGBColor[
             0.5919024457294845, 0.6759664122706829, 0.9628935917366674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 51}], {
             RGBColor[
             0.33046646407782415`, 0.4562153820042676, 0.9424405713085325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 70}], {
             RGBColor[
             0.3382626356768291, 0.464409652660651, 0.9428845517476936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 75}], {
             RGBColor[
             0.3329280335215753, 0.45880264756216715`, 0.9425807540467885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 78}], {
             RGBColor[
             0.6972006995541824, 0.7564641060518543, 0.846300355646884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 80}], {
             RGBColor[
             0.33469414166217204`, 0.4606589391956579, 0.9426813312926726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 39}], {
             RGBColor[
             0.2935264779562271, 0.4258453173585629, 0.9400272707348724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 44}], {
             RGBColor[
             0.5355149273904612, 0.6258440486261139, 0.959263816501205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 45}], {
             RGBColor[
             0.5380655132877746, 0.6278365857142659, 0.9595180350668688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 51}], {
             RGBColor[
             0.27662953163611426`, 0.40808555544785063`, 0.9390650146387339]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 80}], {
             RGBColor[
             0.2808572092204622, 0.41252911263924097`, 0.939305774622874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 42}], {
             RGBColor[
             0.46221511877127164`, 0.5653020306816455, 0.952477193383617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 62}], {
             RGBColor[
             0.3171356169120182, 0.44536236355291736`, 0.9415657494001773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 49}], {
             RGBColor[
             0.678986366254469, 0.7482686816351451, 0.9692402627616367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 60}], {
             RGBColor[
             0.5274957486173808, 0.6272838379970835, 0.9559455440932065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 69}], {
             RGBColor[
             0.5043580739226968, 0.6076980492248905, 0.954345541111748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 71}], {
             RGBColor[
             0.46781157980336074`, 0.5760433128989255, 0.9520168308232597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 77}], {
             RGBColor[
             0.5013559504056586, 0.6050977607255472, 0.9541542484559159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 82}], {
             RGBColor[
             0.7111994736592744, 0.481494992557141, 0.5719947770859303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 87}], {
             RGBColor[
             0.687018378215704, 0.7545433504248138, 0.9700408186505132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 38}], {
             RGBColor[
             0.3673467656616922, 0.49201966294494187`, 0.9446492027229738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 53}], {
             RGBColor[
             0.3130212595870627, 0.4449656400624253, 0.9411876295140573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 62}], {
             RGBColor[
             0.3342621285122205, 0.46336341312828305`, 0.9425410788994055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 90}], {
             RGBColor[
             0.3052911133447183, 0.4382106950728331, 0.9406972493160285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 61}], {
             RGBColor[
             0.17912334491775841`, 0.3056003709575509, 0.9335121815526001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 67}], {
             RGBColor[
             0.18042977836149893`, 0.3069735153395867, 0.9335865810045261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 68}], {
             RGBColor[
             0.4983193449177584, 0.2199668709575509, 0.5488706815526001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 72}], {
             RGBColor[
             0.5053823219778242, 0.27425600765749925`, 0.5556341963618108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 82}], {
             RGBColor[
             0.5083994177593483, 0.2974467279340947, 0.5585233706895204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 86}], {
             RGBColor[
             0.5863775807352516, 0.6486800774912771, 0.8459890583878498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 92}], {
             RGBColor[
             0.18278950597928542`, 0.3094537386812527, 0.9337209640014548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 94}], {
             RGBColor[
             0.1800640484055534, 0.3065891099672694, 0.9335657532245839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 50}], {
             RGBColor[
             0.8586518765861698, 0.8882652786926387, 0.8831610133197494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 76}], {
             RGBColor[
             0.8601494153237335, 0.8880770205793902, 0.7996440970661025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 81}], {
             RGBColor[
             0.6332310398688609, 0.7118439589227601, 0.9651449338235201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 84}], {
             RGBColor[
             0.5813861978869495, 0.66930600772412, 0.9611872941941962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 85}], {
             RGBColor[
             0.6704659090566354, 0.7420729031411366, 0.9680761991218017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 42}], {
             RGBColor[
             0.5442088329750422, 0.6400671657429147, 0.9575645899192962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 62}], {
             RGBColor[
             0.39912933111578863`, 0.5201274986141865, 0.9466531459358565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 44}], {
             RGBColor[
             0.5365081779106845, 0.6268880178985887, 0.9593203806489492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 45}], {
             RGBColor[
             0.5390587638079978, 0.6288805549867408, 0.959574599214613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 80}], {
             RGBColor[
             0.28185045974068534`, 0.4135730819117158, 0.9393623387706183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 53}], {
             RGBColor[
             0.2836258239107592, 0.41406917338836174`, 0.9395136029389419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 54}], {
             RGBColor[
             0.24731022926901122`, 0.37726910970888733`, 0.9373953237429482]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.23295897687627548`, 0.36218503352216574`, 0.9365780411499574]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 90}], {
             RGBColor[
             0.27589567766841483`, 0.4073142283987696, 0.939023222740913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 100}], {
             RGBColor[
             0.24447547507013836`, 0.3742896033120748, 0.9372338886849655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 48}], {
             RGBColor[
             0.34329321321312134`, 0.4669781893550724, 0.9432705886491298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 56}], {
             RGBColor[
             0.3357366265014662, 0.459035737605853, 0.9428402522148693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 60}], {
             RGBColor[
             0.44984311664774745`, 0.5635983285779962, 0.9500102743152689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 64}], {
             RGBColor[
             0.3573126143001289, 0.48171346877888566`, 0.9440689728011896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 73}], {
             RGBColor[
             0.34062966364440406`, 0.46417862987955394`, 0.9431189034415599]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 74}], {
             RGBColor[
             0.39624144168094344`, 0.517626153935267, 0.9464691321747285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.3593964815136068, 0.4839037453450634, 0.9441876459561919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 91}], {
             RGBColor[
             0.34170136961930875`, 0.46530506080926215`, 0.9431799355113838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 93}], {
             RGBColor[
             0.34493630114672413`, 0.468705178951081, 0.9433641600762177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 44}], {
             RGBColor[
             0.7173501625148713, 0.7791186661105619, 0.9724624182472246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 62}], {
             RGBColor[
             0.5111241958255703, 0.6114109159262558, 0.9554564660957278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 78}], {
             RGBColor[
             0.8251990022368825, 0.8616088969798854, 0.8561234007231051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 46}], {
             RGBColor[
             0.2608419331067822, 0.3914917884019613, 0.9381659342581474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 54}], {
             RGBColor[
             0.2507606889125138, 0.3808957615659856, 0.9375918223151481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 45}], {
             RGBColor[
             0.7810472132422319, 0.8288792862542917, 0.9788111449809456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 78}], {
             RGBColor[
             0.88634546706693, 0.9093769800354632, 0.8622179088911622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 52}], {
             RGBColor[
             0.8611685991001501, 0.8128504925215565, 0.6243159249705089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 78}], {
             RGBColor[
             0.8888960529642432, 0.9113695171236152, 0.8624721274568261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 55}], {
             RGBColor[
             0.25989982546037066`, 0.390501573532508, 0.9381122826214077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 59}], {
             RGBColor[
             0.27301827158802383`, 0.40428989217019595`, 0.9388593587213756]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 79}], {
             RGBColor[
             0.25699221406840955`, 0.38744548960634695`, 0.937946698454061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 95}], {
             RGBColor[
             0.42837295229133143`, 0.5383825235467723, 0.9496367892337401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 98}], {
             RGBColor[
             0.2829961754137684, 0.41477730172669547`, 0.9394275855832659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 99}], {
             RGBColor[
             0.3372394933460653, 0.46304047074906063`, 0.9428370425595982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 51}], {
             RGBColor[
             0.26797369092262097`, 0.39898771804597, 0.9385720773152693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 57}], {
             RGBColor[
             0.2643065968573336, 0.3951333696761603, 0.9383632417332306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 70}], {
             RGBColor[
             0.27576986252162594`, 0.40718198870235345`, 0.9390160577544302]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 74}], {
             RGBColor[
             0.31904494583740095`, 0.4476628644149205, 0.9416637299737558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 75}], {
             RGBColor[
             0.2704352603663721, 0.40157498360386956`, 0.9387122600535251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 88}], {
             RGBColor[
             0.28219998567006427`, 0.41394045582471695`, 0.9393822437552191]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.280167857490329, 0.4118045602634469, 0.9392665170616474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 56}], {
             RGBColor[
             0.2494153020184852, 0.3794816746379056, 0.9375152045218548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 57}], {
             RGBColor[
             0.25518176821789507`, 0.38554259622855935`, 0.9378435962411888]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 64}], {
             RGBColor[
             0.27099128981714793`, 0.40215940581093823`, 0.9387439251081751]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 73}], {
             RGBColor[
             0.25430833916142304`, 0.38462456691160657`, 0.9377938557485452]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 74}], {
             RGBColor[
             0.3099201171979624, 0.4380720909673196, 0.941144084481714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 88}], {
             RGBColor[
             0.2730751570306258, 0.404349682377116, 0.9388625982631773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 91}], {
             RGBColor[
             0.2553800451363277, 0.3857509978413148, 0.9378548878183692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 93}], {
             RGBColor[
             0.2586149766637431, 0.3891511159831336, 0.9380391123832033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 96}], {
             RGBColor[
             0.2710430288508906, 0.402213786815846, 0.9387468715696057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 69}], {
             RGBColor[
             0.5984246385417968, 0.6820634596988412, 0.9631196279753649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 71}], {
             RGBColor[
             0.5618781444224608, 0.6504087233728764, 0.9607909176868766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 77}], {
             RGBColor[
             0.5954225150247585, 0.679463171199498, 0.9629283353195328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 82}], {
             RGBColor[
             0.8052660382783743, 0.5558604030310919, 0.5807688639495472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.781084942834804, 0.8289087608987646, 0.9788149055141302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 76}], {
             RGBColor[
             0.9928483984176775, 0.9905031143387806, 0.7094852523118963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 81}], {
             RGBColor[
             0.7659300229628049, 0.8142700526821505, 0.8749860890693137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 84}], {
             RGBColor[
             0.7140851809808935, 0.7717321014835103, 0.87102844943999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 85}], {
             RGBColor[
             0.8031648921505794, 0.844498996900527, 0.8779173543675954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 86}], {
             RGBColor[
             0.9923931656575502, 0.9911223927597408, 0.7757284611180213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 57}], {
             RGBColor[
             0.25705874177093724`, 0.3875154144398035, 0.9379504871083011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 70}], {
             RGBColor[
             0.2685220074352297, 0.3995640334659966, 0.9386033031295007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 75}], {
             RGBColor[
             0.2631874052799758, 0.3939570283675128, 0.9382995054285956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 67}], {
             RGBColor[
             0.560139632974118, 0.5514847252323705, 0.6016081426491302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 68}], {
             RGBColor[
             0.8780291995303775, 0.46447808085033465`, 0.21689224319720418`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 72}], {
             RGBColor[
             0.8850921765904433, 0.518767217550283, 0.2236557580064148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 78}], {
             RGBColor[
             0.9664668529248481, 0.8933481863027279, 0.5077226888807255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 65}], {
             RGBColor[
             0.2728961090815175, 0.40279156279961614`, 0.9389025615526072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 84}], {
             RGBColor[
             0.3801912291988372, 0.5037242665904019, 0.9454464268280143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 85}], {
             RGBColor[
             0.46927094036852307`, 0.5764911620074185, 0.9523353317556198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 90}], {
             RGBColor[
             0.3158328098736569, 0.44792075767621997`, 0.941347743143563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 100}], {
             RGBColor[
             0.2844126072753804, 0.4148961325895252, 0.9395584090876155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 84}], {
             RGBColor[
             0.3438756345570892, 0.4669242029109275, 0.9433281476320208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 100}], {
             RGBColor[
             0.24809701263363243`, 0.37809606891005076`, 0.9374401298916217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 59}], {
             RGBColor[
             0.26182384182735224`, 0.39252383672388913`, 0.9382218525071802]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 66}], {
             RGBColor[
             0.28548649746992133`, 0.41614462386633744`, 0.9396151803770567]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 79}], {
             RGBColor[
             0.24579778430773802`, 0.37567943416004, 0.9373091922398655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 98}], {
             RGBColor[
             0.2718017456530969, 0.4030112462803886, 0.9387900793690704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 99}], {
             RGBColor[
             0.32604506358539376`, 0.45127441530275375`, 0.9421995363454028]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 64}], {
             RGBColor[
             0.2634347031054928, 0.3942169540617188, 0.9383135886739146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 73}], {
             RGBColor[
             0.24675175244976794`, 0.37668211516238714`, 0.9373635193142849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 74}], {
             RGBColor[
             0.3023635304863073, 0.4301296392181001, 0.9407137480474534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 88}], {
             RGBColor[
             0.26551857031897064`, 0.39640723062789657`, 0.9384322618289168]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 89}], {
             RGBColor[
             0.2431918362429577, 0.37294041751730556`, 0.937160787352731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 91}], {
             RGBColor[
             0.2478234584246726, 0.37780854609209535`, 0.9374245513841087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 93}], {
             RGBColor[
             0.251058389952088, 0.3812086642339142, 0.9376087759489427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 64}], {
             RGBColor[
             0.2692011693049027, 0.4002778756523726, 0.9386419803932486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 70}], {
             RGBColor[
             0.26485491336994227`, 0.39570968509618687`, 0.9383944675474621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 74}], {
             RGBColor[
             0.3081299966857172, 0.43619056080875396`, 0.9410421397667876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 75}], {
             RGBColor[
             0.25952031121468844`, 0.390102679997703, 0.9380906698465571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 88}], {
             RGBColor[
             0.27128503651838054`, 0.40246815221855037`, 0.9387606535482509]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 96}], {
             RGBColor[
             0.26925290833864535`, 0.40033225665728034`, 0.9386449268546793]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 63}], {
             RGBColor[
             0.22145736040975994`, 0.3500961053712548, 0.9359230411073061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 83}], {
             RGBColor[
             0.22400482828107066`, 0.3527736556227943, 0.9360681156339361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 97}], {
             RGBColor[
             0.23746265977054243`, 0.3669186897940284, 0.936834519228184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 66}], {
             RGBColor[
             0.2986049435975745, 0.4299329425040255, 0.9403622564770246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 69}], {
             RGBColor[
             0.34936931708251506`, 0.4739024913250818, 0.9435969174663121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 77}], {
             RGBColor[
             0.3463671935654768, 0.47130220282573854`, 0.9434056248104801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 79}], {
             RGBColor[
             0.2589162304353912, 0.38946775279772805`, 0.9380562683398335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 83}], {
             RGBColor[
             0.24944682557751796`, 0.3795148078971581, 0.9375169997419068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 95}], {
             RGBColor[
             0.430296968658313, 0.5404047867381535, 0.9497463591195126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 97}], {
             RGBColor[
             0.26290465706698973`, 0.3936598420683923, 0.9382834033361547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 98}], {
             RGBColor[
             0.28492019178075007`, 0.41679956491807657`, 0.9395371554690384]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 99}], {
             RGBColor[
             0.33916350971304693`, 0.46506273394044173`, 0.9429466124453707]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 64}], {
             RGBColor[
             0.37754119325177404`, 0.49877954503386207`, 0.9454836107743141]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 71}], {
             RGBColor[
             0.41038752678537255`, 0.5294238797348146, 0.9474961990184465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 74}], {
             RGBColor[
             0.4164700206325886, 0.5346922301902434, 0.9478837701478531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 89}], {
             RGBColor[
             0.357298326389239, 0.4775030084894488, 0.9443308094531306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 93}], {
             RGBColor[
             0.3651648800983693, 0.48577125520605746`, 0.9447787980493423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 67}], {
             RGBColor[
             0.1802334334437405, 0.3067671443820358, 0.933575399451926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 68}], {
             RGBColor[0.49812300000000004`, 0.2197605, 0.5488595000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 72}], {
             RGBColor[
             0.5051859770600657, 0.2740496366999483, 0.5556230148092107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 86}], {
             RGBColor[
             0.5861812358174932, 0.6484737065337263, 0.8459778768352497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 92}], {
             RGBColor[
             0.182593161061527, 0.30924736772370176`, 0.9337097824488547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 94}], {
             RGBColor[
             0.17986770348779496`, 0.3063827390097185, 0.9335545716719839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 83}], {
             RGBColor[
             0.2214038953287198, 0.3500399101811996, 0.9359199963500353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 97}], {
             RGBColor[
             0.23486172681819156`, 0.36418494435243376`, 0.9366863999442832]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 73}], {
             RGBColor[
             0.26832774024843065`, 0.39935984633541977`, 0.938592239900605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 74}], {
             RGBColor[
             0.32393951828497003`, 0.45280737039113284`, 0.9419424686337738]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 88}], {
             RGBColor[
             0.2870945581176334, 0.41908496180092925`, 0.9396609824152371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 89}], {
             RGBColor[
             0.2647678240416204, 0.39561814869033823`, 0.9383895079390514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 91}], {
             RGBColor[
             0.26939944622333534`, 0.400486277265128, 0.938653271970429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 93}], {
             RGBColor[
             0.2726343777507507, 0.4038863954069468, 0.938837496535263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 96}], {
             RGBColor[
             0.28506242993789815`, 0.4169490662396592, 0.9395452557216655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 90}], {
             RGBColor[
             0.26516596283917315`, 0.39603661781002397`, 0.9384121813545784]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 100}], {
             RGBColor[
             0.2337457602408967, 0.3630119927233292, 0.9366228472986309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 69}], {
             RGBColor[
             0.37303197272508415`, 0.4975232784675301, 0.9449902453361887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 77}], {
             RGBColor[
             0.3700298492080458, 0.49492298996818684`, 0.9447989526803566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 79}], {
             RGBColor[
             0.2825788860779602, 0.4130885399401764, 0.93944959620971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 83}], {
             RGBColor[
             0.27310948122008705`, 0.4031355950396065, 0.9389103276117834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 95}], {
             RGBColor[
             0.4539596243008821, 0.5640255738806018, 0.9511396869893891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 97}], {
             RGBColor[
             0.2865673127095588, 0.41728062921084064`, 0.9396767312060312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[
             0.3085828474233191, 0.440420352060525, 0.9409304833389149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 99}], {
             RGBColor[
             0.36282616535561596`, 0.48868352108289015`, 0.9443399403152473]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 68}], {
             RGBColor[
             0.49942943344374047`, 0.22113364438203578`, 0.5489338994519259]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 72}], {
             RGBColor[
             0.5064924105038062, 0.2754227810819841, 0.5556974142611366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 86}], {
             RGBColor[
             0.5874876692612337, 0.649846850915762, 0.8460522762871756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 92}], {
             RGBColor[
             0.1838995945052675, 0.31062051210573755`, 0.9337841819007806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 94}], {
             RGBColor[
             0.18117413693153547`, 0.3077558833917543, 0.9336289711239099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 72}], {
             RGBColor[
             0.8243819770600658, 0.1884161366999483, 0.17098151480921064`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 82}], {
             RGBColor[
             0.8273990728415899, 0.2116068569765438, 0.1738706891369204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 92}], {
             RGBColor[
             0.501789161061527, 0.22361386772370176`, 0.5490682824488547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 71}], {
             RGBColor[
             0.38724985209068863`, 0.5098380909626216, 0.9458961960369879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 77}], {
             RGBColor[
             0.4207942226929865, 0.5388925387892431, 0.9480336136696441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 87}], {
             RGBColor[
             0.6064566505030319, 0.6883381284885098, 0.9639201838642415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 95}], {
             RGBColor[
             0.5047239977858227, 0.6079951227016581, 0.9543743479786766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 97}], {
             RGBColor[
             0.3373316861944994, 0.46125017803189694`, 0.9429113921953187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 98}], {
             RGBColor[
             0.35934722090825977`, 0.48438990088158124`, 0.9441651443282024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 99}], {
             RGBColor[
             0.41359053884055663`, 0.5326530699039465, 0.9475746013045347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 75}], {
             RGBColor[
             0.2709835768789808, 0.4021512990238961, 0.9387434858677567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 96}], {
             RGBColor[
             0.28071617400293775`, 0.4123808756834735, 0.9392977428758789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 77}], {
             RGBColor[
             0.3842477285736503, 0.5072378024632783, 0.9457049033811559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 87}], {
             RGBColor[
             0.5699101563836958, 0.656683392162545, 0.9615914735757531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 82}], {
             RGBColor[
             0.8344620499016556, 0.2658959936764921, 0.180634203946131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 92}], {
             RGBColor[
             0.5088521381215928, 0.27790300442365007`, 0.5558317972580653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 74}], {
             RGBColor[
             0.3072565676292452, 0.4352725314918011, 0.940992399274144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 88}], {
             RGBColor[
             0.2704116074619085, 0.40155012290159753`, 0.9387109130556073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.24808487338589558`, 0.37808330979100657`, 0.9374394385794216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 91}], {
             RGBColor[
             0.25271649556761044`, 0.3829514383657963, 0.9377032026107992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 93}], {
             RGBColor[
             0.2559514270950259, 0.38635155650761516`, 0.9378874271756332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 88}], {
             RGBColor[
             0.3260233854984479, 0.4549976469573106, 0.9420611417887761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 91}], {
             RGBColor[
             0.3083282736041498, 0.43639896242150933`, 0.941053431343968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 96}], {
             RGBColor[
             0.3239912573187127, 0.45286175139604057`, 0.9419454150952044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 96}], {
             RGBColor[
             0.27538157184768386`, 0.40677387058498965`, 0.9389939451749738]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 81}], {
             RGBColor[
             0.7674275617003685, 0.8140817945689018, 0.7914691728156671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 84}], {
             RGBColor[
             0.7155827197184571, 0.7715438433702618, 0.7875115331863431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 85}], {
             RGBColor[
             0.8046624308881429, 0.8443107387872784, 0.7944004381139487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 87}], {
             RGBColor[
             0.6034545269859937, 0.6857378399891666, 0.9637288912084094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 95}], {
             RGBColor[
             0.5017218742687843, 0.6053948342023149, 0.9541830553228445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 97}], {
             RGBColor[
             0.3343295626774611, 0.4586498895325537, 0.9427200995394867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 98}], {
             RGBColor[
             0.35634509739122144`, 0.481789612382238, 0.9439738516723704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 99}], {
             RGBColor[
             0.4105884153235183, 0.5300527814046032, 0.9473833086487027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 83}], {
             RGBColor[
             0.23342076805790374`, 0.3626704053333091, 0.9366043394745922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 98}], {
             RGBColor[
             0.26889413426113584`, 0.39995516235422757`, 0.9386244952017238]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 99}], {
             RGBColor[
             0.3231374521934327, 0.4482183313765927, 0.9420339521780562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 84}], {
             RGBColor[
             0.4886643442635845, 0.5953107817136317, 0.9530123699437607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 85}], {
             RGBColor[
             0.5777440554332705, 0.6680776771306483, 0.9599012748713662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 86}], {
             RGBColor[
             0.9154573086590831, 0.64032006351027, 0.4709890659721701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 87}], {
             RGBColor[
             0.8132980502396094, 0.5621350718207605, 0.5815694198384238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 92}], {
             RGBColor[
             0.5118692339031169, 0.30109372470024554`, 0.558720971585775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 97}], {
             RGBColor[
             0.23740919468950228`, 0.36686249460397324`, 0.9368314744709133]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 85}], {
             RGBColor[
             0.5258992134513589, 0.6255397259320082, 0.9559436352420423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.37246108295649283`, 0.49696932160080975`, 0.9449560466299856]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 90}], {
             RGBColor[
             0.4615407941261787, 0.5697362170178263, 0.951844951557591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 92}], {
             RGBColor[
             0.5898473968790202, 0.652327074257428, 0.8461866592841044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[
             0.5871219393052882, 0.6494624455434448, 0.8460314485072336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 91}], {
             RGBColor[
             0.2714833134368132, 0.40267655383130574`, 0.9387719451254313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 96}], {
             RGBColor[
             0.2871462971513761, 0.419139342805837, 0.9396639288766677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 91}], {
             RGBColor[
             0.24915657936080024`, 0.3792097407207148, 0.9375004706492456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 93}], {
             RGBColor[
             0.25239151088821565`, 0.3826098588625336, 0.9376846952140795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 100}], {
             RGBColor[
             0.27668246103303606`, 0.408141187599933, 0.9390680288895865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 93}], {
             RGBColor[
             0.2570231330699305, 0.38747798743732337`, 0.9379484592454572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 96}], {
             RGBColor[
             0.269451185257078, 0.40054065827003577`, 0.9386562184318596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 94}], {
             RGBColor[
             0.18353386454932197`, 0.3102361067334203, 0.9337633541208386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 98}], {
             RGBColor[
             0.44027487248405767`, 0.5508921962946529, 0.9503145859814027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 99}], {
             RGBColor[
             0.49451819041635453`, 0.5991553653170181, 0.9537240429577352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 99}], {
             RGBColor[
             0.3491414135387916, 0.47555014349694125`, 0.943514839307261]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.06980202272393367], {
             RGBColor[
             0.2581082061950206, 0.38861846808940276`, 0.9380102525547092]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.06980202272393367], {
             RGBColor[
             0.5167351398431651, 0.6185478910342742, 0.9550984295530915]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.06980202272393367], {
             RGBColor[
             0.29928415304751665`, 0.4318969989371937, 0.9403551618136042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.06980202272393367], {
             RGBColor[
             0.8388093398485373, 0.29931116920282663`, 0.1847971737088267]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.06980202272393367], {
             RGBColor[
             0.2503401935643895, 0.38045379429416204`, 0.9375678757271396]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.06980202272393367], {
             RGBColor[
             0.2567233930101477, 0.3871629416298741, 0.9379313894924781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.06980202272393367], {
             RGBColor[
             0.3134760783279485, 0.4459389561070196, 0.9411953964084129]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.06980202272393367], {
             RGBColor[
             0.9629022796012385, 0.9718531613853215, 0.9476809433867306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.06980202272393367], {
             RGBColor[
             0.9513821482973379, 0.8449534494772841, 0.27973913919362886`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.06980202272393367], {
             RGBColor[
             0.25142577857169485`, 0.38159481296690484`, 0.9376296981873266]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.06980202272393367], {
             RGBColor[
             0.23420058730117388`, 0.3634900448013817, 0.9366487490268572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.06980202272393367], {
             RGBColor[
             0.6054182467789488, 0.6905448323731828, 0.9620798885880011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.06980202272393367], {
             RGBColor[
             0.2733697721409376, 0.40465934153773064`, 0.9388793761578655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.06980202272393367], {
             RGBColor[
             0.7189648146431117, 0.780380044624954, 0.9726233516815856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.06980202272393367], {
             RGBColor[
             0.3159380912379023, 0.44807142794525473`, 0.9413522736939626]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.06980202272393367], {
             RGBColor[
             0.23643110434042502`, 0.36583445963258315`, 0.9367757736724883]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.06980202272393367], {
             RGBColor[
             0.3883689323709583, 0.5108073820547808, 0.9459675028428829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.06980202272393367], {
             RGBColor[
             0.21478615482912253`, 0.34308424532714094`, 0.935543125818653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.06980202272393367], {
             RGBColor[
             0.2667049069717902, 0.39765414566809815`, 0.9384998219462671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.06980202272393367], {
             RGBColor[
             0.22126439749034046`, 0.3498932891083892, 0.9359120521545081]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.06980202272393367], {
             RGBColor[
             0.9031780751200748, 0.6532360771028892, 0.2409217513686888]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.06980202272393367], {
             RGBColor[
             0.9615184195052529, 0.9708210807915982, 0.9500234575607163]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.06980202272393367], {
             RGBColor[
             0.9867507212149456, 0.9887890969785158, 0.869238367710113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.06980202272393367], {
             RGBColor[
             0.9075000820526815, 0.6709756796489449, 0.2444305986486977]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.06980202272393367], {
             RGBColor[
             0.21590777704158132`, 0.3442631413873908, 0.9356070005443611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.06980202272393367], {
             RGBColor[
             0.2200699987015112, 0.3486379002520725, 0.9358440329104389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.06980202272393367], {
             RGBColor[
             0.3423524124735395, 0.470950185377176, 0.9430353708858302]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.06980202272393367], {
             RGBColor[
             0.25608696935210196`, 0.3864940200136776, 0.9378951461066569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.06980202272393367], {
             RGBColor[
             0.32022364339009624`, 0.4517833578213709, 0.9416253452875354]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.06980202272393367], {
             RGBColor[
             0.8183671396880012, 0.14218346093971695`, 0.1652216997489344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.06980202272393367], {
             RGBColor[
             0.40020709231942364`, 0.521061001198922, 0.9467218199267253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.06980202272393367], {
             RGBColor[
             0.2925332274360039, 0.424801348086088, 0.9399707065871281]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.06980202272393367], {
             RGBColor[
             0.26822653985771944`, 0.399253478308307, 0.9385864766880666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.06980202272393367], {
             RGBColor[
             0.5849198016353689, 0.6739032711611944, 0.9604661758980197]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.06980202272393367], {
             RGBColor[
             0.30247956305812407`, 0.4352555774590384, 0.9405371356865229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.06980202272393367], {
             RGBColor[
             0.17931968983551683`, 0.3058067419151018, 0.9335233631052001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.06980202272393367], {
             RGBColor[
             0.7259528934922258, 0.7858391849332483, 0.9733198580739556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.06980202272393367], {
             RGBColor[
             0.43221396826526043`, 0.5487837484308453, 0.9487612697594249]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.06980202272393367], {
             RGBColor[
             0.2945197284764503, 0.42688928663103776`, 0.9400838348826166]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.06980202272393367], {
             RGBColor[
             0.24368869170551716`, 0.37346264411091135`, 0.937189082536292]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.06980202272393367], {
             RGBColor[
             0.4296145376961023, 0.5465322523230198, 0.9485956363421444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.06980202272393367], {
             RGBColor[
             0.6562036976848239, 0.731350583054984, 0.9663679100791674]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.06980202272393367], {
             RGBColor[
             0.25058961099252225`, 0.3807159478251078, 0.9375820796806917]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.06980202272393367], {
             RGBColor[
             0.7784966273449186, 0.8268867491661398, 0.9785569264152818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.06980202272393367], {
             RGBColor[
             0.7835977991395453, 0.8308718233424438, 0.9790653635466094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.06980202272393367], {
             RGBColor[
             0.2710942552210422, 0.40226762897881485`, 0.9387497888356031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.06980202272393367], {
             RGBColor[
             0.27522154600901727`, 0.40660567328232683`, 0.9389848319401988]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.06980202272393367], {
             RGBColor[
             0.2569718887301403, 0.38742412638712503`, 0.9379455409561153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.06980202272393367], {
             RGBColor[
             0.773052930873569, 0.822634092109096, 0.9780143496252536]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.06980202272393367], {
             RGBColor[
             0.9913508596801138, 0.9906913724520291, 0.7930021685655431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.06980202272393367], {
             RGBColor[
             0.26072583583622466`, 0.3913697628096132, 0.9381593226903397]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.06980202272393367], {
             RGBColor[
             0.938739399060755, 0.7948291617006693, 0.26956648639440833`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.06980202272393367], {
             RGBColor[
             0.3235629561160013, 0.45467570266581214`, 0.9418381233415918]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.06980202272393367], {
             RGBColor[
             0.2509317668325053, 0.3810755753068633, 0.9376015649496046]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.06980202272393367], {
             RGBColor[
             0.2487053956996991, 0.3787355180862011, 0.9374747764072122]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.06980202272393367], {
             RGBColor[
             0.24185871530683006`, 0.3715392228886861, 0.9370848680875943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.06980202272393367], {
             RGBColor[
             0.25339164770564987`, 0.38366106606999373`, 0.9377416515262625]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.06980202272393367], {
             RGBColor[
             0.22405829336211083`, 0.3528298508128494, 0.9360711603912069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.06980202272393367], {
             RGBColor[
             0.2749422879550054, 0.4063121553615771, 0.9389689286071481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.06980202272393367], {
             RGBColor[
             0.4700716955993926, 0.5806644048329727, 0.9514249122883933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.06980202272393367], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.06980202272393367], {
             RGBColor[
             0.3660446939663169, 0.4914712487975277, 0.9445450221122881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.06980202272393367], {
             RGBColor[
             0.21885642745740908`, 0.34736235992966014`, 0.9357749218234052]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.06980202272393367], {
             RGBColor[
             0.2850106909041555, 0.4168946852347515, 0.9395423092602349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.06980202272393367], {
             RGBColor[
             0.2222292620470338, 0.35090742293342014`, 0.9359669997636226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.06980202272393367], {
             RGBColor[
             0.32226759924014353`, 0.45355372964647384`, 0.9417555843469012]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.06980202272393367], {
             RGBColor[
             0.181539866887481, 0.30814028876407157`, 0.9336497989038519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.06980202272393367], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.06980202272393367], {
             RGBColor[
             0.42379634621002477`, 0.5414928272885864, 0.9482249063254762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.06980202272393367], {
             RGBColor[
             0.27631817903423467`, 0.40775830412238, 0.9390472835686617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.06980202272393367], {
             RGBColor[
             0.3507033579713525, 0.4781833546366567, 0.9435674857484997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.06980202272393367], {
             RGBColor[
             0.8314449541201315, 0.24270527339989661`, 0.17774502961842129`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.06980202272393367], {
             RGBColor[
             0.2516447895927058, 0.3818250074360881, 0.9376421705409753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.06980202272393367], {
             RGBColor[
             0.3628683456657846, 0.48872005554751413`, 0.9443426280073127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.06980202272393367], {
             RGBColor[
             0.26564897472372695`, 0.3965442939254123, 0.9384396881668516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.06980202272393367], {
             RGBColor[
             0.9943459371552411, 0.990314856225532, 0.6259683360582495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.06980202272393367], {
             RGBColor[
             0.4177920991759482, 0.5362922502898999, 0.947842321013812]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.06980202272393367], {
             RGBColor[
             0.9941943067889412, 0.9918672109047867, 0.7458788913670427]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.06980202272393367], {
             RGBColor[
             0.24289017291577697`, 0.372623350233879, 0.937143608072519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.06980202272393367], {
             RGBColor[
             0.26918119100492044`, 0.4002568771923939, 0.9386408426586199]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.06980202272393367], {
             RGBColor[
             0.5405091862454959, 0.6378487329122717, 0.9569700095730845]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.06980202272393367], {
             RGBColor[
             0.8374791456831797, 0.2890867139530876, 0.18352337827384074`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.06980202272393367], {
             RGBColor[
             0.2239513632000305, 0.3527174604327391, 0.9360650708766655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.06980202272393367], {
             RGBColor[
             0.4368195022816731, 0.5527728305149917, 0.9490547303144369]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.06980202272393367], {
             RGBColor[
             0.6149789246210449, 0.6983066213490248, 0.9628325401696478]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.06980202272393367], {
             RGBColor[
             0.9934354716349865, 0.9915534130674525, 0.7584547536704994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.06980202272393367], {
             RGBColor[
             0.789116954796039, 0.8351834296884333, 0.9796154614030067]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.06980202272393367], {
             RGBColor[
             0.28917842533111127`, 0.421275238367107, 0.9397796555702393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.06980202272393367], {
             RGBColor[
             0.24452495717908534`, 0.374341612145925, 0.9372367066178678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.06980202272393367], {
             RGBColor[
             0.30810266363131256`, 0.4411658126866278, 0.9408573629455341]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.06980202272393367], {
             RGBColor[
             0.25378820154251513`, 0.3840778692955045, 0.9377642346806232]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.06980202272393367], {
             RGBColor[
             0.18625932212305402`, 0.3131007354474035, 0.9339185648977094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.06980202272393367], {
             RGBColor[
             0.26025806459734596`, 0.3908781055791422, 0.9381326838102911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.06980202272393367], {
             RGBColor[
             0.18080840697558995`, 0.30737147801943704`, 0.9336081433439677]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.06980202272393367], {
             RGBColor[
             0.5856516493616206, 0.6744974181147299, 0.9605237896318769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.06980202272393367], {
             RGBColor[
             0.2851141689716408, 0.417003447244567, 0.939548202183096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.06980202272393367], {
             RGBColor[
             0.25086702617897405`, 0.38100752877520744`, 0.9375978780651611]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.06980202272393367], {
             RGBColor[
             0.2948980956064947, 0.4272869744745761, 0.9401053823309286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.06980202272393367], {
             RGBColor[
             0.40338473147108844`, 0.5238133125193064, 0.9469242962835934]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.06980202272393367], {
             RGBColor[
             0.24526225843475957`, 0.3751165625132382, 0.937278694833639]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{
  3.834950276960332*^9, {3.8349573666066523`*^9, 3.83495737580899*^9}, 
   3.8349587938370156`*^9, 3.8350189212906833`*^9, 3.835019008666805*^9, 
   3.8350204886401753`*^9, 3.83502054312705*^9, {3.8350446267813253`*^9, 
   3.8350446323653708`*^9}, 3.835045041794944*^9},
 CellLabel->
  "Out[287]=",ExpressionUUID->"0733d715-4b86-4203-8c75-c92d3a000163"]
}, Open  ]],

Cell["Estimated with absolute Mean Deviation v Calculated: (r=3)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 
  3.8349503756793146`*^9}},ExpressionUUID->"0ac48e38-7d57-4247-8371-\
fb51c9afad5b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphinf1", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsif1", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}],
      "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"AMDi3f100", ",", "krif1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502409842243`*^9}, {3.834957391671958*^9, 3.8349574025038147`*^9}, {
   3.8350188314314775`*^9, 3.835018832832349*^9}, {3.8350443332621727`*^9, 
   3.835044338598092*^9}},
 CellLabel->
  "In[243]:=",ExpressionUUID->"06f7307a-b318-46bd-b063-b28ed6b0917b"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100}, {
          Null, CompressedData["
1:eJwVxVmbqQwAAOCxVtbppLIkW4w1a5YJk8gSaaRCIqr783/Pr/me7715C/Zf
xfZ+fHz883x8/D9363DUk1oFBOGSrgbkKTe9Ubr+DJzlM67jGn44aCN55AiO
7OTWuWMuH0qHqrVObVrjcvv1PnbAe71DT+vplLkyddN8hkqxEiiAOngBnQA/
4nmBl/kz71Cz2Wqmz8zZE8QwHhOwC+aAKIqhFLpCL6gZpsKz8Cpshp+ghVm8
JViWU9t1dtxud0NGCI/IiIU4oXgsHi/Fq3gmo3kQT8YzygyrQz/up/w9/8Gv
+58BCZQwiZcESbpIluT8+c395n89MAjDCIzBI5iHBViCZdiCncDPzznXz/f7
6/6+Nu6Mx9x4N755Y96s9xj4/v75PnvrsXq2Xj/6SZBESYzESZIie6ROmuQz
5MbdtFt1h+5nNkDABEIQI4InZOJMOOEtuqW2s+1quzU9NEwjNEHTI1qmLdpp
99vr9t5fxsuZcrlXPpS19qvz4l7r1/6Fqxm1rPbUoXpQVc1b+CxkC4V67dF5
jB/TB/fYPW6PXCvfah1r1/a1cx1fuevuen2l0qlqaphy0SJWLE6LQlEqXjzR
aCY6jKpRLfeV//pqff3WxLbYEcfiVOTEnShexZenEW0gjUyjQTeG3maumW9+
NevNZqt5DC+p5Wy5XC23S31pLp/+ZCyJJ5P1ZC95AKJACsgAZaAKDAEV0AAX
7KJdrFvsdoWu1L3U7p37+M7dd3fxfr3f7vfH/RV4f79/3vxbeEvv8xswQkbc
SBslo2qohmYYbhAIhoLxYCqYDpaC1aARdIub7ma6ETYbaXMJsDCLsARLsyOW
5VmBlViZPbMW+2Yd7zw2j88/59l5YV6a1+eBRIJIfCfYxE+CT8iJc+IdXACL
0CK1SC+qi4WxcEEFVTCFVIoKpXSVlbJVFF25KCZsIzZh0/bIZm3eFmzJlm3L
th1vJVaJV7KVUqVSr8zDg9ZgsBysBtvBEThFT/gpcyqfeqfD6aSetCADMCEm
xsSZNFNiqgyzYFRGYwzGbU86k/5kwk3WE3Gyn1wnL6/P9+nL+gq+iq/um0dq
kUFkGuEiYuQaefkhKAyhEAlR0AxaQitoCymQDpnQ8z9pR8GG
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[69, 98] -> 
             RGBColor[
              0.9888110884267548, 0.973049303966259, 0.4850131098422645], 
             UndirectedEdge[29, 33] -> 
             RGBColor[
              0.9932588685619793, 0.9873325561322804, 0.5635286463312299], 
             UndirectedEdge[55, 59] -> 
             RGBColor[
              0.9862913881727573, 0.9652286172187896, 0.417499717737032], 
             UndirectedEdge[47, 74] -> 
             RGBColor[
              0.6349916197756902, 0.6892171656441717, 0.6683006254313648], 
             UndirectedEdge[19, 43] -> 
             RGBColor[
              0.9929986825154649, 0.9892084612214183, 0.6083696586918081], 
             UndirectedEdge[57, 75] -> 
             RGBColor[
              0.9657339612611228, 0.9053086792775249, 0.5798793163795126], 
             UndirectedEdge[19, 46] -> 
             RGBColor[
              0.9938526345108809, 0.9892597317497935, 0.5722753875306688], 
             UndirectedEdge[36, 67] -> 
             RGBColor[
              0.959874267107126, 0.9689373029731005, 0.924284703397829], 
             UndirectedEdge[79, 99] -> 
             RGBColor[
              0.9193244810708026, 0.9361665874843496, 0.9014228810269813], 
             UndirectedEdge[52, 68] -> 
             RGBColor[
              0.9436857783283932, 0.810443608318399, 0.2943592518308228], 
             UndirectedEdge[81, 85] -> 
             RGBColor[
              0.9186555979288933, 0.7058587175650297, 0.26026264782202957`], 
             UndirectedEdge[12, 88] -> 
             RGBColor[
              0.9704728720858895, 0.9774908193251534, 0.9344862634969325], 
             UndirectedEdge[72, 82] -> 
             RGBColor[
              0.9943698627782784, 0.990366030713957, 0.628572492474022], 
             UndirectedEdge[31, 44] -> 
             RGBColor[
              0.9566031244798661, 0.9176008691838038, 0.6250701798414979], 
             UndirectedEdge[17, 79] -> 
             RGBColor[
              0.9917876162563838, 0.9895046577224069, 0.6863739032036825], 
             UndirectedEdge[91, 96] -> 
             RGBColor[
              0.9825247420808815, 0.9530629172136866, 0.5467194328551754], 
             UndirectedEdge[55, 99] -> 
             RGBColor[
              0.9207917509028185, 0.9346431380776853, 0.7222631384425535], 
             UndirectedEdge[77, 99] -> 
             RGBColor[
              0.9127383316717791, 0.9076682215107361, 0.6747224687691717], 
             UndirectedEdge[29, 38] -> 
             RGBColor[
              0.994599222493539, 0.9908566079530752, 0.6535368820360583], 
             UndirectedEdge[26, 90] -> 
             RGBColor[
              0.809911129949003, 0.8484438114846626, 0.7843180517507669], 
             UndirectedEdge[13, 27] -> 
             RGBColor[
              0.8823876851884311, 0.5588317721422311, 0.2235737403906348], 
             UndirectedEdge[22, 99] -> 
             RGBColor[
              0.8998960534494331, 0.8628868732848425, 0.6324432654126233], 
             UndirectedEdge[73, 74] -> 
             RGBColor[
              0.6346440793591153, 0.6880448302126942, 0.6669504965404722], 
             UndirectedEdge[8, 77] -> 
             RGBColor[
              0.984316098529677, 0.96200749399041, 0.5737364139986493], 
             UndirectedEdge[36, 94] -> 
             RGBColor[
              0.9624075628889067, 0.9677278093199011, 0.718235797210449], 
             UndirectedEdge[21, 87] -> 
             RGBColor[
              0.9933689637972367, 0.9882252089999191, 0.519630815220137], 
             UndirectedEdge[59, 83] -> 
             RGBColor[
              0.9233745490797546, 0.7161432641104293, 0.29331363404907973`], 
             UndirectedEdge[24, 42] -> 
             RGBColor[
              0.9901365751678708, 0.9891008416737217, 0.7340113292820114], 
             UndirectedEdge[33, 42] -> 
             RGBColor[
              0.9927292760736196, 0.9861998113496933, 0.5058857722392636], 
             UndirectedEdge[14, 42] -> 
             RGBColor[
              0.9935283955904908, 0.9885662174846626, 0.5369839820168708], 
             UndirectedEdge[45, 78] -> 
             RGBColor[
              0.9454478586716744, 0.8943907478281082, 0.6294005631273724], 
             UndirectedEdge[15, 38] -> 
             RGBColor[
              0.993744308905187, 0.989028034232613, 0.560484813859027], 
             UndirectedEdge[84, 85] -> 
             RGBColor[
              0.951741368731566, 0.9179470161406873, 0.6417317457941415], 
             UndirectedEdge[55, 98] -> 
             RGBColor[
              0.9882611134577467, 0.9718729631185496, 0.4251517285178077], 
             UndirectedEdge[86, 92] -> 
             RGBColor[
              0.9312480915826569, 0.7426694381710208, 0.3999185568554861], 
             UndirectedEdge[72, 92] -> 
             RGBColor[
              0.9940743394434904, 0.9897339361828381, 0.5964066012409709], 
             UndirectedEdge[19, 99] -> 
             RGBColor[
              0.9207719724971325, 0.9346008340678262, 0.7201103810417919], 
             UndirectedEdge[4, 76] -> 
             RGBColor[
              0.9579886448298555, 0.8582549914874646, 0.4647418353217144], 
             UndirectedEdge[23, 76] -> 
             RGBColor[
              0.9345956468748453, 0.7784005651070967, 0.2662323261192604], 
             UndirectedEdge[9, 72] -> 
             RGBColor[
              0.9599588578124452, 0.8666455774794039, 0.43204438740753714`], 
             UndirectedEdge[2, 44] -> 
             RGBColor[
              0.903214492290449, 0.8755420749736811, 0.63772415119886], 
             UndirectedEdge[74, 88] -> 
             RGBColor[
              0.6207342694689417, 0.6919334251533742, 0.948851775431365], 
             UndirectedEdge[21, 49] -> 
             RGBColor[
              0.5862792201577564, 0.6470903098660323, 0.740850382208589], 
             UndirectedEdge[21, 34] -> 
             RGBColor[
              0.9942549054592411, 0.9901201486325042, 0.6160600977311502], 
             UndirectedEdge[59, 66] -> 
             RGBColor[
              0.9862913881727573, 0.9652286172187896, 0.417499717737032], 
             UndirectedEdge[17, 99] -> 
             RGBColor[
              0.9212339035904892, 0.9355888579681186, 0.7703887298454128], 
             UndirectedEdge[26, 53] -> 
             RGBColor[
              0.9687367912646498, 0.901447158544473, 0.43910731870776093`], 
             UndirectedEdge[23, 50] -> 
             RGBColor[
              0.9526413550866195, 0.8996057712665104, 0.6171075698339537], 
             UndirectedEdge[41, 74] -> 
             RGBColor[
              0.6202929964628068, 0.6395930208588955, 0.6114192202166411], 
             UndirectedEdge[59, 79] -> 
             RGBColor[
              0.9848241183407412, 0.9667520666254539, 0.5966594603214599], 
             UndirectedEdge[56, 93] -> 
             RGBColor[
              0.9688928769284688, 0.9044681582037308, 0.3454375018681649], 
             UndirectedEdge[19, 98] -> 
             RGBColor[
              0.9882413350520607, 0.9718306591086907, 0.4229989711170461], 
             UndirectedEdge[2, 38] -> 
             RGBColor[
              0.9214448301585536, 0.936040008569261, 0.7933467850913314], 
             UndirectedEdge[19, 59] -> 
             RGBColor[
              0.9862716097670712, 0.9651863132089306, 0.41534696033627044`], 
             UndirectedEdge[24, 76] -> 
             RGBColor[
              0.9537212476050883, 0.856916845431125, 0.5664680511067934], 
             UndirectedEdge[5, 20] -> 
             RGBColor[
              0.9121295668167836, 0.8900622595455703, 0.6494778339557805], 
             UndirectedEdge[37, 84] -> 
             RGBColor[
              0.9648369970210044, 0.9728506623031866, 0.9244596837550557], 
             UndirectedEdge[9, 82] -> 
             RGBColor[
              0.9601757788483922, 0.8671095496412136, 0.45565490348892124`], 
             UndirectedEdge[47, 75] -> 
             RGBColor[
              0.9855195556940184, 0.9751009694210122, 0.640853817963957], 
             UndirectedEdge[51, 75] -> 
             RGBColor[
              0.9895893402507542, 0.9883022553815659, 0.7014809435248506], 
             UndirectedEdge[58, 63] -> 
             RGBColor[
              0.9941780799424065, 0.9914339683235258, 0.7151434121071742], 
             UndirectedEdge[7, 25] -> 
             RGBColor[
              0.9944842586084823, 0.991972422920187, 0.7400057941026192], 
             UndirectedEdge[1, 55] -> 
             RGBColor[
              0.6387892778870977, 0.7018364006543725, 0.6993084667880289], 
             UndirectedEdge[82, 86] -> 
             RGBColor[
              0.9315436149174448, 0.7433015327021397, 0.43208444808853724`], 
             UndirectedEdge[34, 71] -> 
             RGBColor[
              0.991238722347261, 0.9902967951138055, 0.7695496980614946], 
             UndirectedEdge[41, 73] -> 
             RGBColor[
              0.9701712534484558, 0.9110005381881542, 0.33884135239745067`], 
             UndirectedEdge[92, 94] -> 
             RGBColor[
              0.9933307013998818, 0.9881433696008988, 0.5154661893962051], 
             UndirectedEdge[3, 62] -> 
             RGBColor[
              0.9465188011712213, 0.8772030145008365, 0.6136329369771332], 
             UndirectedEdge[70, 75] -> 
             RGBColor[
              0.6352937582917945, 0.7025211166602761, 0.9120815568922547], 
             UndirectedEdge[57, 96] -> 
             RGBColor[
              0.9697667368554479, 0.9069763356233838, 0.5130457882928561], 
             UndirectedEdge[68, 72] -> 
             RGBColor[
              0.956023760779767, 0.851044229038187, 0.42887811596644543`], 
             UndirectedEdge[13, 54] -> 
             RGBColor[
              0.9102150304388863, 0.7281681349693252, 0.5880859778197263], 
             UndirectedEdge[48, 96] -> 
             RGBColor[
              0.9932404837179187, 0.9914727805527841, 0.7616862080688647], 
             UndirectedEdge[30, 50] -> 
             RGBColor[
              0.9757655112507624, 0.9788851722402881, 0.7863553091997235], 
             UndirectedEdge[11, 92] -> 
             RGBColor[
              0.9903692095539198, 0.9782539542441877, 0.4954247391305414], 
             UndirectedEdge[41, 56] -> 
             RGBColor[
              0.9726466744248465, 0.9193507143980059, 0.3484578954467023], 
             UndirectedEdge[73, 91] -> 
             RGBColor[
              0.9778422875538771, 0.9369189744202459, 0.3684219005900494], 
             UndirectedEdge[32, 39] -> 
             RGBColor[
              0.8563949406952965, 0.5268075950920246, 0.5770550030674847], 
             UndirectedEdge[32, 80] -> 
             RGBColor[
              0.9007810138036809, 0.5609395506134969, 0.5375076702453988], 
             UndirectedEdge[20, 66] -> 
             RGBColor[
              0.9268295182341069, 0.9394574898568264, 0.7228390260805904], 
             UndirectedEdge[47, 88] -> 
             RGBColor[
              0.9709600668711657, 0.9645132779141103, 0.6776240365030672], 
             UndirectedEdge[14, 53] -> 
             RGBColor[
              0.9681785319348952, 0.9002530982868043, 0.37834423584119636`], 
             UndirectedEdge[51, 57] -> 
             RGBColor[
              0.9695016073017543, 0.9052060142219742, 0.3967255104795163], 
             UndirectedEdge[30, 94] -> 
             RGBColor[
              0.9934577793802482, 0.9884151765513476, 0.529297843324685], 
             UndirectedEdge[22, 69] -> 
             RGBColor[
              0.9724670109163519, 0.9164555644801757, 0.429130077510922], 
             UndirectedEdge[4, 94] -> 
             RGBColor[
              0.9937266211711153, 0.988990201957938, 0.5585596131613693], 
             UndirectedEdge[4, 86] -> 
             RGBColor[
              0.9316440113538903, 0.74351627052806, 0.44301198062065017`], 
             UndirectedEdge[9, 94] -> 
             RGBColor[
              0.9592152197688366, 0.8650550108974644, 0.3511039755627714], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.9890963633531441, 0.9857859015049846, 0.6452072138132667], 
             UndirectedEdge[12, 60] -> 
             RGBColor[
              0.9791253560473269, 0.9558680295480155, 0.6321612661355953], 
             UndirectedEdge[25, 40] -> 
             RGBColor[
              0.985562752035301, 0.9612573138241559, 0.5433613392854162], 
             UndirectedEdge[22, 95] -> 
             RGBColor[
              0.9695356951365497, 0.9074375594443517, 0.34376298009360484`], 
             UndirectedEdge[3, 33] -> 
             RGBColor[
              0.9641786288343557, 0.8851966518404906, 0.34467060046012254`], 
             UndirectedEdge[48, 93] -> 
             RGBColor[
              0.9704531487982282, 0.9119944722112696, 0.5248370059013701], 
             UndirectedEdge[15, 90] -> 
             RGBColor[
              0.8095195220269248, 0.8476062017369717, 0.7416939461564993], 
             UndirectedEdge[77, 97] -> 
             RGBColor[
              0.9207070486963189, 0.9140222601610428, 0.67548253211273], 
             UndirectedEdge[44, 78] -> 
             RGBColor[
              0.9528764596870802, 0.8503765936762622, 0.2835522892147963], 
             UndirectedEdge[30, 92] -> 
             RGBColor[
              0.9941228151250159, 0.9898376207639779, 0.6016828800177837], 
             UndirectedEdge[37, 76] -> 
             RGBColor[
              0.9540313464347124, 0.8570450792663511, 0.561328910989874], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.9562537279228747, 0.8551655955407534, 0.33106252529710767`], 
             UndirectedEdge[75, 96] -> 
             RGBColor[
              0.9898544698044478, 0.9900725767829754, 0.8178012213381904], 
             UndirectedEdge[31, 80] -> 
             RGBColor[
              0.9698955301955521, 0.9770602386886502, 0.9354635527223927], 
             UndirectedEdge[85, 90] -> 
             RGBColor[
              0.7931755207368143, 0.7930089630887797, 0.6327152380715092], 
             UndirectedEdge[91, 93] -> 
             RGBColor[
              0.9597374071611908, 0.8735846088721722, 0.30987023068768094`], 
             UndirectedEdge[22, 49] -> 
             RGBColor[
              0.5649741692469792, 0.5744584794198119, 0.6064749115782675], 
             UndirectedEdge[69, 87] -> 
             RGBColor[
              0.993509585308853, 0.9885259841942506, 0.5349365989442025], 
             UndirectedEdge[47, 70] -> 
             RGBColor[
              0.6349916197756902, 0.6892171656441717, 0.6683006254313648], 
             UndirectedEdge[42, 78] -> 
             RGBColor[
              0.971057535648165, 0.9107691610338693, 0.43381306853740864`], 
             UndirectedEdge[1, 43] -> 
             RGBColor[
              0.6389950054075194, 0.7040516774603405, 0.8507423136642034], 
             UndirectedEdge[10, 35] -> 
             RGBColor[
              0.9662827284314088, 0.9713769917515755, 0.7678174832730186], 
             UndirectedEdge[67, 94] -> 
             RGBColor[
              0.9901323698733333, 0.9879304190414679, 0.6491300588904866], 
             UndirectedEdge[73, 93] -> 
             RGBColor[
              0.9664174559520781, 0.8961179819938792, 0.3358209588189133], 
             UndirectedEdge[68, 82] -> 
             RGBColor[
              0.9562406818157142, 0.8515082011999967, 0.4524886320478295], 
             UndirectedEdge[11, 52] -> 
             RGBColor[
              0.9781098294013868, 0.937821455893709, 0.3694612501465858], 
             UndirectedEdge[15, 53] -> 
             RGBColor[
              0.9683451833425716, 0.900609548796782, 0.39648321311349344`], 
             UndirectedEdge[53, 100] -> 
             RGBColor[
              0.9687852669461753, 0.9015508431256127, 0.44438359748457373`], 
             UndirectedEdge[58, 83] -> 
             RGBColor[
              0.9302738192062101, 0.7402366201640165, 0.48348257621760365`], 
             UndirectedEdge[74, 96] -> 
             RGBColor[
              0.6393265338861196, 0.7041887730061349, 0.8452480288055982], 
             UndirectedEdge[8, 87] -> 
             RGBColor[
              0.9925163946998323, 0.9892965654785912, 0.6372637320753815], 
             UndirectedEdge[43, 46] -> 
             RGBColor[
              0.9940781404369887, 0.9915173125656207, 0.7258619918076048], 
             UndirectedEdge[73, 89] -> 
             RGBColor[
              0.9250868776361763, 0.7211443217239959, 0.3019906091502217], 
             UndirectedEdge[11, 67] -> 
             RGBColor[
              0.9871708780273714, 0.9780410036847569, 0.6290886086248229], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.9934968840654327, 0.9884988175188671, 0.5335541469808855], 
             UndirectedEdge[98, 99] -> 
             RGBColor[
              0.916240130959836, 0.9194806127709256, 0.6883262977439658], 
             UndirectedEdge[4, 9] -> 
             RGBColor[
              0.9602761752848379, 0.8673242874671339, 0.46658243602103416`], 
             UndirectedEdge[34, 49] -> 
             RGBColor[
              0.5869026853014847, 0.6484238387664718, 0.8087107155225612], 
             UndirectedEdge[6, 7] -> 
             RGBColor[
              0.9205039397898406, 0.6781358410838657, 0.473472028386203], 
             UndirectedEdge[7, 40] -> 
             RGBColor[
              0.9847820394390885, 0.9609491596156254, 0.5573676126674595], 
             UndirectedEdge[23, 85] -> 
             RGBColor[
              0.954341652047525, 0.8552914937636262, 0.28938770212442333`], 
             UndirectedEdge[82, 92] -> 
             RGBColor[
              0.9942912604794376, 0.9901979083446479, 0.620017117322355], 
             UndirectedEdge[34, 69] -> 
             RGBColor[
              0.9943955269708574, 0.9904209238268358, 0.6313658814552157], 
             UndirectedEdge[13, 85] -> 
             RGBColor[
              0.9141817849718603, 0.685544177812706, 0.2565295886274908], 
             UndirectedEdge[95, 98] -> 
             RGBColor[
              0.9858797726469526, 0.9640312989304349, 0.39964601242494735`], 
             UndirectedEdge[34, 87] -> 
             RGBColor[
              0.9939924289409651, 0.9895587379003585, 0.5874911485341092], 
             UndirectedEdge[61, 94] -> 
             RGBColor[
              0.9821889099225386, 0.9514807602741353, 0.3938443213764499], 
             UndirectedEdge[61, 72] -> 
             RGBColor[
              0.9829325479661473, 0.9530713268560747, 0.47478473322121567`], 
             UndirectedEdge[50, 86] -> 
             RGBColor[
              0.9128907877084034, 0.7317169896473311, 0.5845909860374259], 
             UndirectedEdge[66, 97] -> 
             RGBColor[
              0.9287604679273584, 0.9409971767279921, 0.7230232017861118], 
             UndirectedEdge[9, 21] -> 
             RGBColor[
              0.9596981070990359, 0.8660878580693625, 0.4036632814198072], 
             UndirectedEdge[34, 60] -> 
             RGBColor[
              0.9844430275451306, 0.9577188177009903, 0.5187228114127577], 
             UndirectedEdge[53, 84] -> 
             RGBColor[
              0.9430608274660733, 0.884926964528896, 0.6274799017885221], 
             UndirectedEdge[21, 22] -> 
             RGBColor[
              0.9723263894047356, 0.9161547892858442, 0.41382429378685653`], 
             UndirectedEdge[14, 62] -> 
             RGBColor[
              0.9745774759028165, 0.9771538945621863, 0.7212999373989122], 
             UndirectedEdge[22, 30] -> 
             RGBColor[
              0.9726356157996703, 0.9168161932770251, 0.4474816785513993], 
             UndirectedEdge[67, 72] -> 
             RGBColor[
              0.9908760079169419, 0.9895209856234073, 0.7300704707352523], 
             UndirectedEdge[61, 86] -> 
             RGBColor[
              0.9201063001053136, 0.7060068288442573, 0.2782966888357309], 
             UndirectedEdge[5, 83] -> 
             RGBColor[
              0.9151959428904032, 0.6885549050056929, 0.26154129340363325`], 
             UndirectedEdge[46, 99] -> 
             RGBColor[
              0.9218514304186565, 0.9369096854120286, 0.8376027141575886], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.5860167436394803, 0.6465288991338867, 0.712281433011548], 
             UndirectedEdge[7, 37] -> 
             RGBColor[
              0.9902882629545502, 0.9902519613985183, 0.8106121462203069], 
             UndirectedEdge[7, 53] -> 
             RGBColor[
              0.9685120933996192, 0.9023282636242276, 0.5136323642537732], 
             UndirectedEdge[12, 52] -> 
             RGBColor[
              0.9768600022234726, 0.9482264591697827, 0.6233607943060953], 
             UndirectedEdge[50, 85] -> 
             RGBColor[
              0.9589814263570482, 0.9233466392632655, 0.6294762167436531], 
             UndirectedEdge[14, 15] -> 
             RGBColor[
              0.9932030744904985, 0.9878703885467877, 0.5015747879318059], 
             UndirectedEdge[14, 35] -> 
             RGBColor[
              0.9659889188564746, 0.9707485627794961, 0.7358381242239389], 
             UndirectedEdge[8, 95] -> 
             RGBColor[
              0.9899881769499225, 0.9811407463692444, 0.5957713675791707], 
             UndirectedEdge[7, 84] -> 
             RGBColor[
              0.9682522800787241, 0.9742629696163247, 0.8678596050194114], 
             UndirectedEdge[14, 76] -> 
             RGBColor[
              0.9571130680277082, 0.856382221242066, 0.36944070384165284`], 
             UndirectedEdge[60, 89] -> 
             RGBColor[
              0.91982955170744, 0.7034101268875379, 0.28156689067977725`], 
             UndirectedEdge[37, 85] -> 
             RGBColor[
              0.9737773516073922, 0.9339360079228807, 0.584484286995037], 
             UndirectedEdge[39, 80] -> 
             RGBColor[
              0.9398569544989774, 0.9536201457055214, 0.9503446733128835], 
             UndirectedEdge[23, 24] -> 
             RGBColor[
              0.9671271815073392, 0.9100669060908997, 0.577254780202257], 
             UndirectedEdge[11, 68] -> 
             RGBColor[
              0.9523186308901965, 0.8395642470995366, 0.3278962538560159], 
             UndirectedEdge[27, 81] -> 
             RGBColor[
              0.8868614981454641, 0.5791463118945548, 0.22730679958517352`], 
             UndirectedEdge[36, 61] -> 
             RGBColor[
              0.9519308071563313, 0.9324876442057679, 0.6689989658837924], 
             UndirectedEdge[28, 59] -> 
             RGBColor[
              0.9809805705521473, 0.9475051398773006, 0.38061353742331283`], 
             UndirectedEdge[8, 30] -> 
             RGBColor[
              0.993088097613043, 0.9905193802019179, 0.6994900660369652], 
             UndirectedEdge[34, 82] -> 
             RGBColor[
              0.9947325772085975, 0.9911418402043553, 0.6680517198002642], 
             UndirectedEdge[50, 84] -> 
             RGBColor[
              0.9500410717706604, 0.9622612936435715, 0.9694516135036718], 
             UndirectedEdge[57, 88] -> 
             RGBColor[0.95117447243827, 0.894720987770623, 0.616649534918623],
              UndirectedEdge[6, 53] -> 
             RGBColor[
              0.8953124871771898, 0.5887998359964368, 0.23309232515531367`], 
             UndirectedEdge[8, 69] -> 
             RGBColor[
              0.9929194927297247, 0.9901587514050685, 0.6811384649964879], 
             UndirectedEdge[69, 99] -> 
             RGBColor[
              0.9213417258718266, 0.9358194789253946, 0.7821245197670104], 
             UndirectedEdge[81, 84] -> 
             RGBColor[
              0.9097152433425055, 0.7447733719453355, 0.6002380445820483], 
             UndirectedEdge[11, 94] -> 
             RGBColor[
              0.9897041738091521, 0.9768315100315574, 0.4230397024374427], 
             UndirectedEdge[10, 65] -> 
             RGBColor[
              0.9799557625712094, 0.9433563505696756, 0.4354640976234815], 
             UndirectedEdge[79, 98] -> 
             RGBColor[
              0.9867938436257306, 0.9733964125252139, 0.6043114711022355], 
             UndirectedEdge[33, 62] -> 
             RGBColor[
              0.9737783563859452, 0.974787488427217, 0.6902017276213049], 
             UndirectedEdge[31, 70] -> 
             RGBColor[
              0.6201569275786043, 0.6915028445168712, 0.9498290646568252], 
             UndirectedEdge[31, 32] -> 
             RGBColor[
              0.8864335163918711, 0.5502476880751533, 0.5621738824769938], 
             UndirectedEdge[15, 100] -> 
             RGBColor[
              0.9938098095017784, 0.989168133385596, 0.5676141495751832], 
             UndirectedEdge[7, 65] -> 
             RGBColor[
              0.9799955144609991, 0.9448030869350192, 0.5387728669869787], 
             UndirectedEdge[59, 95] -> 
             RGBColor[
              0.9839100473619632, 0.9573869530306748, 0.39199400164417164`], 
             UndirectedEdge[2, 3] -> 
             RGBColor[
              0.8928449210122699, 0.8349314828220857, 0.6267697587423312], 
             UndirectedEdge[48, 88] -> 
             RGBColor[
              0.9746482193007409, 0.9792174327000234, 0.8652899546946313], 
             UndirectedEdge[14, 38] -> 
             RGBColor[
              0.9935776574975106, 0.9886715837226352, 0.54234583658673], 
             UndirectedEdge[44, 45] -> 
             RGBColor[
              0.9502296151605841, 0.9128475163691471, 0.6358588686415843], 
             UndirectedEdge[24, 50] -> 
             RGBColor[
              0.9717669558168625, 0.9781220515905389, 0.9173432948214867], 
             UndirectedEdge[38, 62] -> 
             RGBColor[
              0.975118710317505, 0.9783115402480117, 0.7802099633261333], 
             UndirectedEdge[4, 50] -> 
             RGBColor[
              0.9760343530416297, 0.9794601976468786, 0.8156170790364077], 
             UndirectedEdge[48, 74] -> 
             RGBColor[
              0.6386797722052654, 0.7039213204300847, 0.8559665436229289], 
             UndirectedEdge[40, 100] -> 
             RGBColor[
              0.9850552129856447, 0.9601717391170104, 0.48811884589826005`], 
             UndirectedEdge[19, 95] -> 
             RGBColor[
              0.9904116141842491, 0.9791515202273354, 0.43143009572277347`], 
             UndirectedEdge[19, 79] -> 
             RGBColor[
              0.9913256851630271, 0.9885166338221145, 0.6360955544000616], 
             UndirectedEdge[51, 70] -> 
             RGBColor[
              0.639061404332426, 0.7024184516047255, 0.7289277509922585], 
             UndirectedEdge[17, 22] -> 
             RGBColor[
              0.9723591886350145, 0.9162249435228997, 0.41739428758932456`], 
             UndirectedEdge[59, 99] -> 
             RGBColor[
              0.9142704056748466, 0.9128362668711656, 0.6806742869631901], 
             UndirectedEdge[20, 63] -> 
             RGBColor[
              0.9278169398773006, 0.9415694849079754, 0.8303137782822086], 
             UndirectedEdge[56, 89] -> 
             RGBColor[
              0.9275622986125671, 0.7294944979338476, 0.3116071521994733], 
             UndirectedEdge[12, 74] -> 
             RGBColor[
              0.6345044249904142, 0.7021947070552147, 0.9251628524252301], 
             UndirectedEdge[8, 17] -> 
             RGBColor[
              0.9928116704483871, 0.9899281304477925, 0.6694026750748905], 
             UndirectedEdge[53, 90] -> 
             RGBColor[
              0.7844949794713216, 0.7599889114769884, 0.6184633940658898], 
             UndirectedEdge[21, 72] -> 
             RGBColor[
              0.993892191028922, 0.989344339142106, 0.576580870404908], 
             UndirectedEdge[48, 73] -> 
             RGBColor[
              0.9885580291909144, 0.9753288377593434, 0.5833886758037385], 
             UndirectedEdge[8, 49] -> 
             RGBColor[
              0.585426651060352, 0.6481616663447046, 0.8584832990638334], 
             UndirectedEdge[17, 69] -> 
             RGBColor[
              0.993804861057408, 0.9891575491634519, 0.5670755419437115], 
             UndirectedEdge[21, 82] -> 
             RGBColor[
              0.9941091120648691, 0.9898083113039158, 0.600191386486292], 
             UndirectedEdge[36, 68] -> 
             RGBColor[
              0.9250220199699511, 0.8304605463878802, 0.6230923486290221], 
             UndirectedEdge[21, 30] -> 
             RGBColor[
              0.9939406667104475, 0.9894480237232456, 0.5818571491817208], 
             UndirectedEdge[56, 64] -> 
             RGBColor[
              0.98734529773773, 0.9689748591832821, 0.40533930066142615`], 
             UndirectedEdge[48, 64] -> 
             RGBColor[
              0.9889055696074893, 0.9765011731908209, 0.5847388046946312], 
             UndirectedEdge[46, 59] -> 
             RGBColor[
              0.987351067688595, 0.9674951645531329, 0.532839293452067], 
             UndirectedEdge[46, 79] -> 
             RGBColor[
              0.9924051430845511, 0.9908254851663169, 0.7535878875158581], 
             UndirectedEdge[9, 86] -> 
             RGBColor[
              0.8971326099516115, 0.6195810794675864, 0.23555634302205236`], 
             UndirectedEdge[64, 91] -> 
             RGBColor[
              0.978189827970452, 0.9380913098517233, 0.3697720294809421], 
             UndirectedEdge[1, 19] -> 
             RGBColor[
              0.6387694994814117, 0.7017940966445133, 0.6971557093872673], 
             UndirectedEdge[5, 69] -> 
             RGBColor[
              0.978662756952414, 0.9388165989617625, 0.44558875841604234`], 
             UndirectedEdge[36, 92] -> 
             RGBColor[
              0.9630725986336746, 0.9691502535325314, 0.7906208339035476], 
             UndirectedEdge[17, 95] -> 
             RGBColor[
              0.9908735452776057, 0.9801395441276277, 0.4817084445263944], 
             UndirectedEdge[7, 13] -> 
             RGBColor[
              0.9306926963190184, 0.7418601312883436, 0.4826574478527607], 
             UndirectedEdge[11, 61] -> 
             RGBColor[
              0.9792274180765767, 0.9415913449174242, 0.37380287111078614`], 
             UndirectedEdge[66, 83] -> 
             RGBColor[
              0.9298958943077265, 0.7379501353169491, 0.33490248552844304`], 
             UndirectedEdge[27, 37] -> 
             RGBColor[
              0.941983251823963, 0.8072236022524059, 0.5515284387581809], 
             UndirectedEdge[22, 34] -> 
             RGBColor[
              0.9729498545484639, 0.9174883181862836, 0.48168462710082877`], 
             UndirectedEdge[6, 90] -> 
             RGBColor[
              0.736486825861543, 0.5357964889366265, 0.5783030581983195], 
             UndirectedEdge[71, 77] -> 
             RGBColor[
              0.9821524845151014, 0.9611127839930391, 0.6095930974737492], 
             UndirectedEdge[9, 68] -> 
             RGBColor[
              0.921829676849881, 0.7277877479654435, 0.25596052698134464`], 
             UndirectedEdge[23, 86] -> 
             RGBColor[
              0.9082510133988801, 0.6636618441476918, 0.24450247141819614`], 
             UndirectedEdge[54, 84] -> 
             RGBColor[
              0.9477746141985919, 0.9605709732973065, 0.9732881349863769], 
             UndirectedEdge[3, 16] -> 
             RGBColor[
              0.9618368081384201, 0.8882014275786041, 0.5686384231690951], 
             UndirectedEdge[66, 98] -> 
             RGBColor[
              0.9882611134577467, 0.9718729631185496, 0.4251517285178077], 
             UndirectedEdge[64, 93] -> 
             RGBColor[
              0.9667649963686529, 0.8972903174253566, 0.33717108770980597`], 
             UndirectedEdge[2, 29] -> 
             RGBColor[
              0.9219251607398935, 0.9370673871138755, 0.8456278046134387], 
             UndirectedEdge[50, 81] -> 
             RGBColor[
              0.9169553009679878, 0.7501729950679139, 0.5879825155315599], 
             UndirectedEdge[8, 99] -> 
             RGBColor[
              0.9203485352628059, 0.9365900602097352, 0.8844516528981892], 
             UndirectedEdge[66, 69] -> 
             RGBColor[
              0.9933627083697373, 0.9882118292730186, 0.5189499505408521], 
             UndirectedEdge[9, 30] -> 
             RGBColor[
              0.9600073334939706, 0.8667492620605435, 0.43732066618434995`], 
             UndirectedEdge[11, 36] -> 
             RGBColor[
              0.9594460710429448, 0.9578383939631901, 0.6981943469447851], 
             UndirectedEdge[16, 62] -> 
             RGBColor[
              0.9714365356900097, 0.9777922641653305, 0.9141695503302774], 
             UndirectedEdge[50, 76] -> 
             RGBColor[
              0.9392354211843685, 0.8464557106067359, 0.6063208407384901], 
             UndirectedEdge[36, 86] -> 
             RGBColor[
              0.9003249530716817, 0.7222538778900232, 0.6026881646697299], 
             UndirectedEdge[60, 71] -> 
             RGBColor[
              0.9808033792894222, 0.9565619352818522, 0.6043520784291299], 
             UndirectedEdge[43, 54] -> 
             RGBColor[
              0.9729862013467891, 0.9778731590554326, 0.8634126951936689], 
             UndirectedEdge[29, 42] -> 
             RGBColor[
              0.9945499605865192, 0.9907512417151025, 0.6481750274661993], 
             UndirectedEdge[76, 84] -> 
             RGBColor[
              0.9319953635588862, 0.8410560874841575, 0.6185763697889786], 
             UndirectedEdge[65, 90] -> 
             RGBColor[
              0.7959784005327015, 0.8024637347877801, 0.6436038967990951], 
             UndirectedEdge[52, 78] -> 
             RGBColor[
              0.9587858400188769, 0.8703103211238974, 0.3065091159109886], 
             UndirectedEdge[25, 65] -> 
             RGBColor[
              0.9807762270572116, 0.9451112411435498, 0.5247665936049353], 
             UndirectedEdge[45, 52] -> 
             RGBColor[
              0.9561389954923808, 0.9327812438167823, 0.6588156953377765], 
             UndirectedEdge[57, 74] -> 
             RGBColor[
              0.6152060253427946, 0.6194248755006844, 0.6073261238469205], 
             UndirectedEdge[17, 66] -> 
             RGBColor[
              0.9932548860883998, 0.9879812083157427, 0.5072141606192547], 
             UndirectedEdge[59, 98] -> 
             RGBColor[
              0.9817397682297748, 0.9500660919120301, 0.3835628770384443], 
             UndirectedEdge[22, 77] -> 
             RGBColor[
              0.9638636167163044, 0.8883043070655172, 0.3217280265130834], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.9932565429674647, 0.990879667782588, 0.7178243033415365], 
             UndirectedEdge[30, 36] -> 
             RGBColor[
              0.9631996766140407, 0.9694220604829802, 0.8044524878320274], 
             UndirectedEdge[60, 64] -> 
             RGBColor[
              0.979612550832603, 0.9428904881369724, 0.3752990391417301], 
             UndirectedEdge[28, 99] -> 
             RGBColor[
              0.9154809332822086, 0.9169196607361962, 0.6853769581288343], 
             UndirectedEdge[59, 69] -> 
             RGBColor[
              0.9868413631417654, 0.9664049580664988, 0.4773610990614888], 
             UndirectedEdge[66, 79] -> 
             RGBColor[
              0.9913454635687131, 0.9885589378319736, 0.6382483118008232], 
             UndirectedEdge[7, 81] -> 
             RGBColor[
              0.9351665092760514, 0.7621746710406672, 0.48639050704729947`], 
             UndirectedEdge[26, 100] -> 
             RGBColor[
              0.9942014174238567, 0.9900057431332869, 0.6102382551694507], 
             UndirectedEdge[5, 97] -> 
             RGBColor[
              0.9140605165100351, 0.891601946416736, 0.6496620096613019], 
             UndirectedEdge[20, 83] -> 
             RGBColor[
              0.8639126791411043, 0.6903721367484661, 0.5986529423926381], 
             UndirectedEdge[21, 92] -> 
             RGBColor[
              0.9938135887300812, 0.9891762167727969, 0.5680254952532409], 
             UndirectedEdge[77, 98] -> 
             RGBColor[
              0.9802076942267073, 0.9448980465516005, 0.3776110588444258], 
             UndirectedEdge[13, 84] -> 
             RGBColor[
              0.9052414303854726, 0.7244588321930119, 0.5965049853875096], 
             UndirectedEdge[83, 97] -> 
             RGBColor[
              0.8658436288343558, 0.6919118236196318, 0.5988371180981594], 
             UndirectedEdge[4, 24] -> 
             RGBColor[
              0.9905201794623494, 0.9899213324712677, 0.775764289404711], 
             UndirectedEdge[7, 85] -> 
             RGBColor[
              0.9771926346651119, 0.9353483152360189, 0.5278842082593926], 
             UndirectedEdge[10, 40] -> 
             RGBColor[
              0.9847422875492988, 0.9595024232502817, 0.4540588433039624], 
             UndirectedEdge[26, 40] -> 
             RGBColor[
              0.9850067373041191, 0.9600680545358709, 0.48284256712144724`], 
             UndirectedEdge[56, 74] -> 
             RGBColor[
              0.6371195003355061, 0.6963950064225459, 0.6765670395897239], 
             UndirectedEdge[42, 62] -> 
             RGBColor[
              0.9750694484104852, 0.9782061740100391, 0.7748481087562742], 
             UndirectedEdge[4, 36] -> 
             RGBColor[
              0.963468518404908, 0.9699970858895706, 0.8337142576687117], 
             UndirectedEdge[2, 33] -> 
             RGBColor[
              0.9201044762269939, 0.9325159567484662, 0.703338549386503], 
             UndirectedEdge[36, 82] -> 
             RGBColor[
              0.9633681219684624, 0.9697823480636503, 0.8227867251365988], 
             UndirectedEdge[76, 81] -> 
             RGBColor[
              0.8989095927562136, 0.6289677889084999, 0.23710727181686664`], 
             UndirectedEdge[27, 43] -> 
             RGBColor[
              0.945158856096334, 0.8085367962283385, 0.4989004577645775], 
             UndirectedEdge[61, 67] -> 
             RGBColor[
              0.9796556141407579, 0.9526902539273346, 0.59989322756383], 
             UndirectedEdge[10, 26] -> 
             RGBColor[
              0.993888491987511, 0.9893364272665581, 0.5761782525751531], 
             UndirectedEdge[63, 83] -> 
             RGBColor[
              0.9308833159509202, 0.7400621303680981, 0.4423772377300614], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.9732258801321378, 0.9779722723926381, 0.8594405974516282], 
             UndirectedEdge[20, 97] -> 
             RGBColor[
              0.8627772527607362, 0.8934191781595092, 0.9867736586503068], 
             UndirectedEdge[28, 98] -> 
             RGBColor[
              0.9829502958371368, 0.9541494857770607, 0.3882655482040885], 
             UndirectedEdge[4, 23] -> 
             RGBColor[
              0.9713945787321063, 0.9114050521472393, 0.47552856441717795`], 
             UndirectedEdge[30, 86] -> 
             RGBColor[
              0.931375169563023, 0.7429412451214695, 0.41375021078396595`], 
             UndirectedEdge[27, 54] -> 
             RGBColor[
              0.9249208690015506, 0.7949439132465257, 0.6003568899895022], 
             UndirectedEdge[1, 13] -> 
             RGBColor[
              0.5762238344996166, 0.4543466533742332, 0.5754155962902607], 
             UndirectedEdge[15, 35] -> 
             RGBColor[
              0.9661555702641509, 0.9711050132894737, 0.753977101496236], 
             UndirectedEdge[56, 73] -> 
             RGBColor[
              0.9869977573211552, 0.9678025237518046, 0.40398917177053345`], 
             UndirectedEdge[16, 29] -> 
             RGBColor[
              0.9909170478660437, 0.9903373318703941, 0.7874964690402024], 
             UndirectedEdge[53, 65] -> 
             RGBColor[
              0.9548040618483483, 0.8554670818475905, 0.2983931637560893], 
             UndirectedEdge[6, 25] -> 
             RGBColor[
              0.921284652386053, 0.6784439952923962, 0.4594657550041596], 
             UndirectedEdge[68, 92] -> 
             RGBColor[
              0.9559451584809262, 0.8508761066688778, 0.4203227408147784], 
             UndirectedEdge[69, 97] -> 
             RGBColor[
              0.9293104428963666, 0.9421735175757013, 0.7828845831105686], 
             UndirectedEdge[17, 77] -> 
             RGBColor[
              0.9852014668573603, 0.9610062917487934, 0.45967349094587284`], 
             UndirectedEdge[46, 98] -> 
             RGBColor[
              0.9893207929735846, 0.9741395104528929, 0.5404913042328428], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.9755990408988449, 0.9793389187926262, 0.8324909828482406], 
             UndirectedEdge[17, 55] -> 
             RGBColor[
              0.9932548860883998, 0.9879812083157427, 0.5072141606192547], 
             UndirectedEdge[2, 78] -> 
             RGBColor[
              0.8984327358015392, 0.8570853064326422, 0.631265845684648], 
             UndirectedEdge[6, 35] -> 
             RGBColor[
              0.8931228740987691, 0.6592953004891285, 0.5905862135380562], 
             UndirectedEdge[95, 99] -> 
             RGBColor[
              0.9184104100920245, 0.9268014738895705, 0.6967574223496931], 
             UndirectedEdge[66, 99] -> 
             RGBColor[
              0.9207917509028185, 0.9346431380776853, 0.7222631384425535], 
             UndirectedEdge[31, 39] -> 
             RGBColor[
              0.9255094570871676, 0.9429282831671779, 0.9750108855444786], 
             UndirectedEdge[69, 71] -> 
             RGBColor[
              0.9907558787151489, 0.9892640414076976, 0.7169951484715879], 
             UndirectedEdge[64, 89] -> 
             RGBColor[
              0.9254344180527512, 0.7223166571554733, 0.3033407380411144], 
             UndirectedEdge[40, 53] -> 
             RGBColor[
              0.9595905868264378, 0.8716131545281965, 0.3169879094365702], 
             UndirectedEdge[1, 27] -> 
             RGBColor[
              0.5909296730622808, 0.5211224316514336, 0.5876865084600367], 
             UndirectedEdge[41, 48] -> 
             RGBColor[
              0.9742069462946059, 0.9268770284055445, 0.5278573994799074], 
             UndirectedEdge[57, 70] -> 
             RGBColor[
              0.6152060253427946, 0.6194248755006844, 0.6073261238469205], 
             UndirectedEdge[39, 44] -> 
             RGBColor[
              0.9265645487832915, 0.894160776200675, 0.6399513004319888], 
             UndirectedEdge[6, 15] -> 
             RGBColor[
              0.920337029732793, 0.6764171262564201, 0.35632287724592315`], 
             UndirectedEdge[6, 40] -> 
             RGBColor[
              0.9115824332166591, 0.6474207319878347, 0.27682757356899995`], 
             UndirectedEdge[17, 59] -> 
             RGBColor[
              0.9867335408604279, 0.9661743371092228, 0.46562530913989136`], 
             UndirectedEdge[56, 91] -> 
             RGBColor[
              0.9803177085302679, 0.9452691506300975, 0.37803844363930106`], 
             UndirectedEdge[5, 59] -> 
             RGBColor[
              0.9715914367554339, 0.9158333869075335, 0.3441385256122222], 
             UndirectedEdge[20, 58] -> 
             RGBColor[
              0.9272074431325905, 0.9417439747038938, 0.8714191167697509], 
             UndirectedEdge[17, 19] -> 
             RGBColor[
              0.9932351076827137, 0.9879389043058835, 0.5050614032184931], 
             UndirectedEdge[3, 38] -> 
             RGBColor[
              0.9655189827659154, 0.8887207036612854, 0.43467883616495095`], 
             UndirectedEdge[1, 17] -> 
             RGBColor[
              0.6392314305747684, 0.7027821205448057, 0.7474340581908883], 
             UndirectedEdge[2, 42] -> 
             RGBColor[
              0.9213955682515338, 0.9359346423312883, 0.7879849305214722], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.984730222392638, 0.9747745598159508, 0.6539351134969325], 
             UndirectedEdge[48, 56] -> 
             RGBColor[
              0.9910334501673053, 0.9836790139691951, 0.5930052188529902], 
             UndirectedEdge[86, 94] -> 
             RGBColor[
              0.930583055837889, 0.7412469939583906, 0.3275335201623874], 
             UndirectedEdge[23, 30] -> 
             RGBColor[
              0.9711257369412392, 0.9108300267406488, 0.44626679458049373`], 
             UndirectedEdge[30, 82] -> 
             RGBColor[
              0.9944183384598038, 0.9904697152950968, 0.6338487712508348], 
             UndirectedEdge[60, 74] -> 
             RGBColor[
              0.629386753430379, 0.6703106353762364, 0.6465267780700277], 
             UndirectedEdge[10, 90] -> 
             RGBColor[
              0.8096466801941827, 0.8478781801990736, 0.755534327933282], 
             UndirectedEdge[49, 69] -> 
             RGBColor[
              0.5864198416693727, 0.6473910850603639, 0.7561561659326546], 
             UndirectedEdge[25, 100] -> 
             RGBColor[
              0.9947574321550385, 0.9911950024215721, 0.6707570273334197], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.9710740078878177, 0.9140879778389882, 0.34212841216977563`], 
             UndirectedEdge[31, 51] -> 
             RGBColor[
              0.974452509537564, 0.977283983238161, 0.7392284512894209], 
             UndirectedEdge[37, 50] -> 
             RGBColor[
              0.9720770546464866, 0.9782502854257649, 0.9122041547045673], 
             UndirectedEdge[6, 10] -> 
             RGBColor[
              0.9204641879000509, 0.676689104718522, 0.37016325902270586`], 
             UndirectedEdge[69, 77] -> 
             RGBColor[
              0.9853092891386979, 0.9612369127060694, 0.47140928086747036`], 
             UndirectedEdge[12, 96] -> 
             RGBColor[
              0.9890651365030675, 0.9897461671779142, 0.8308825168711658], 
             UndirectedEdge[12, 41] -> 
             RGBColor[
              0.9700315990797546, 0.9251504150306746, 0.5970537082822086], 
             UndirectedEdge[89, 93] -> 
             RGBColor[
              0.90698199724349, 0.6578099561759221, 0.24343893924785312`], 
             UndirectedEdge[37, 81] -> 
             RGBColor[
              0.9317512262183316, 0.760762363727529, 0.5429905857829438], 
             UndirectedEdge[14, 24] -> 
             RGBColor[
              0.9896446026602022, 0.988048562225869, 0.6804631579246494], 
             UndirectedEdge[52, 67] -> 
             RGBColor[
              0.978538025465568, 0.9489203649036193, 0.5955516065996298], 
             UndirectedEdge[23, 27] -> 
             RGBColor[
              0.9225475522640958, 0.7285790880931514, 0.2564318538875673], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.9215187006134969, 0.9217340125153374, 0.6859528457668711], 
             UndirectedEdge[23, 81] -> 
             RGBColor[
              0.9123155266584645, 0.6821178495682746, 0.24789400091233016`], 
             UndirectedEdge[88, 96] -> 
             RGBColor[
              0.9752949809815952, 0.9794848852760736, 0.8545714398773007], 
             UndirectedEdge[77, 95] -> 
             RGBColor[
              0.9823779733588957, 0.9522189076702452, 0.3860421834501532], 
             UndirectedEdge[74, 91] -> 
             RGBColor[
              0.6279640305682281, 0.6655114570909871, 0.6409997684092399], 
             UndirectedEdge[7, 100] -> 
             RGBColor[
              0.993976719558826, 0.9908868482130415, 0.684763300715463], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.9562614435582821, 0.9148891331288341, 0.6207426312883435], 
             UndirectedEdge[6, 100] -> 
             RGBColor[
              0.9207771133363967, 0.6773584205852508, 0.4042232616170035], 
             UndirectedEdge[19, 55] -> 
             RGBColor[
              0.9927929549950432, 0.9869931844154503, 0.4569358118156338], 
             UndirectedEdge[17, 28] -> 
             RGBColor[
              0.9879440684677898, 0.9702577309742535, 0.4703279803055355], 
             UndirectedEdge[64, 96] -> 
             RGBColor[
              0.9895523312883436, 0.9767686257668711, 0.5740202898773006], 
             UndirectedEdge[67, 68] -> 
             RGBColor[
              0.9527468269543777, 0.8506631561094469, 0.5539866103090598], 
             UndirectedEdge[22, 87] -> 
             RGBColor[
              0.9720639128864595, 0.9155933785536985, 0.3852553445898156], 
             UndirectedEdge[42, 44] -> 
             RGBColor[
              0.9758392921370748, 0.9292259295749081, 0.44027137405162053`], 
             UndirectedEdge[70, 96] -> 
             RGBColor[
              0.6393265338861196, 0.7041887730061349, 0.8452480288055982], 
             UndirectedEdge[64, 88] -> 
             RGBColor[
              0.9709600668711657, 0.9645132779141103, 0.6776240365030672], 
             UndirectedEdge[26, 65] -> 
             RGBColor[
              0.9802202123260297, 0.9439219818552647, 0.4642478214409663], 
             UndirectedEdge[2, 14] -> 
             RGBColor[
              0.920903595743865, 0.9348823628834355, 0.7344367591641102], 
             UndirectedEdge[11, 72] -> 
             RGBColor[
              0.9904478118527607, 0.9784220766134969, 0.5039801142822085], 
             UndirectedEdge[67, 86] -> 
             RGBColor[
              0.9280497600561083, 0.7424564876115899, 0.5335824263497675], 
             UndirectedEdge[40, 90] -> 
             RGBColor[
              0.8007649255107909, 0.8186098074683861, 0.662198642479576], 
             UndirectedEdge[27, 84] -> 
             RGBColor[
              0.9199472689481369, 0.7912346104702124, 0.6087758975572855], 
             UndirectedEdge[13, 43] -> 
             RGBColor[
              0.9304530175336697, 0.741761017951138, 0.48662954559480154`], 
             UndirectedEdge[52, 72] -> 
             RGBColor[
              0.9818149592909573, 0.9493014378323594, 0.47044311225701535`], 
             UndirectedEdge[10, 53] -> 
             RGBColor[
              0.9684723415098295, 0.9008815272588839, 0.4103235948902761], 
             UndirectedEdge[15, 40] -> 
             RGBColor[
              0.9846151293820409, 0.9592304447881799, 0.4402184615271797], 
             UndirectedEdge[21, 68] -> 
             RGBColor[
              0.9557630100663579, 0.8504865096281455, 0.4004970099787154], 
             UndirectedEdge[28, 83] -> 
             RGBColor[
              0.9245850766871165, 0.7202266579754599, 0.2980163052147239], 
             UndirectedEdge[54, 100] -> 
             RGBColor[
              0.9734990536786938, 0.9771948518940231, 0.7901918306824286], 
             UndirectedEdge[47, 96] -> 
             RGBColor[
              0.9895523312883436, 0.9767686257668711, 0.5740202898773006], 
             UndirectedEdge[47, 51] -> 
             RGBColor[
              0.9892872017346499, 0.9749983043654615, 0.4577000120639607], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.9747441273104929, 0.977510345072164, 0.7394389146712093], 
             UndirectedEdge[39, 45] -> 
             RGBColor[
              0.9191359477678857, 0.9381749303525211, 0.9857995743445648], 
             UndirectedEdge[58, 97] -> 
             RGBColor[
              0.929138392825842, 0.9432836615750595, 0.8716032924752724], 
             UndirectedEdge[31, 45] -> 
             RGBColor[
              0.9491745234644602, 0.96161502333565, 0.970918453754074], 
             UndirectedEdge[6, 26] -> 
             RGBColor[
              0.9207286376548712, 0.6772547360041111, 0.3989469828401907], 
             UndirectedEdge[41, 91] -> 
             RGBColor[
              0.9634912046575685, 0.8884671650664471, 0.3128906242662183], 
             UndirectedEdge[8, 22] -> 
             RGBColor[
              0.9714738203073312, 0.9172261457645164, 0.5314572106421009], 
             UndirectedEdge[46, 95] -> 
             RGBColor[
              0.991491072105773, 0.9814603715715378, 0.54892242883857], 
             UndirectedEdge[66, 95] -> 
             RGBColor[
              0.9904313925899351, 0.9791938242371945, 0.433582853123535], 
             UndirectedEdge[23, 37] -> 
             RGBColor[
              0.9674372803369633, 0.9101951399261257, 0.5721156400853376], 
             UndirectedEdge[10, 100] -> 
             RGBColor[
              0.9939369676690364, 0.9894401118476979, 0.5814545313519659], 
             UndirectedEdge[5, 79] -> 
             RGBColor[
              0.9766455121513898, 0.9391637075207174, 0.5648871196760133], 
             UndirectedEdge[38, 42] -> 
             RGBColor[
              0.9940696300051793, 0.989723863170488, 0.595894007944092], 
             UndirectedEdge[40, 54] -> 
             RGBColor[
              0.9643043735589564, 0.9472571632966069, 0.6627961426344251], 
             UndirectedEdge[32, 45] -> 
             RGBColor[
              0.8800600070725891, 0.5454943352604966, 0.5729625712770802], 
             UndirectedEdge[41, 60] -> 
             RGBColor[
              0.9649139275197195, 0.8932663433516963, 0.3184176339270062], 
             UndirectedEdge[88, 91] -> 
             RGBColor[
              0.9639324776637035, 0.9408075693609258, 0.6503231794809423], 
             UndirectedEdge[47, 57] -> 
             RGBColor[
              0.9654318227450185, 0.8920047282614205, 0.33609838491862276`], 
             UndirectedEdge[27, 85] -> 
             RGBColor[
              0.9288876235345247, 0.7523199560899065, 0.2688005007972667], 
             UndirectedEdge[69, 95] -> 
             RGBColor[
              0.9909813675589432, 0.9803701650849037, 0.4934442344479918], 
             UndirectedEdge[36, 72] -> 
             RGBColor[
              0.9631512009325154, 0.9693183759018406, 0.7991762090552146], 
             UndirectedEdge[6, 65] -> 
             RGBColor[
              0.9067959082385697, 0.6312746593072285, 0.2582328278885191], 
             UndirectedEdge[49, 77] -> 
             RGBColor[
              0.577816447469325, 0.6192398276457054, 0.6487541149348158], 
             UndirectedEdge[2, 62] -> 
             RGBColor[
              0.9024446485638594, 0.924522319408812, 0.9723008859035136], 
             UndirectedEdge[22, 66] -> 
             RGBColor[
              0.9719170359473438, 0.9152792236324665, 0.3692686961864652], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.7842351661504265, 0.8319236174690856, 0.972690634831528], 
             UndirectedEdge[73, 88] -> 
             RGBColor[
              0.9706125264545908, 0.9633409424826329, 0.6762739076121747], 
             UndirectedEdge[8, 21] -> 
             RGBColor[
              0.9927788712181083, 0.9898579762107369, 0.6658326812724225], 
             UndirectedEdge[31, 75] -> 
             RGBColor[
              0.9706848634969325, 0.9773866482937117, 0.9223822571894174], 
             UndirectedEdge[4, 30] -> 
             RGBColor[
              0.9945187348962494, 0.990684453121017, 0.6447763037829477], 
             UndirectedEdge[48, 91] -> 
             RGBColor[
              0.9818779804000273, 0.9527954646376362, 0.5574379476725062], 
             UndirectedEdge[19, 28] -> 
             RGBColor[
              0.9874821373744331, 0.9692697070739612, 0.4200496315019146], 
             UndirectedEdge[28, 66] -> 
             RGBColor[
              0.9875019157801193, 0.9693120110838203, 0.42220238890267614`], 
             UndirectedEdge[3, 29] -> 
             RGBColor[
              0.9659993133472553, 0.8897480822059, 0.48695985568705824`], 
             UndirectedEdge[22, 82] -> 
             RGBColor[
              0.972804061154092, 0.9171764808576952, 0.4658159158559706], 
             UndirectedEdge[49, 82] -> 
             RGBColor[
              0.5867568919071127, 0.6481120014378834, 0.7928420042777031], 
             UndirectedEdge[23, 84] -> 
             RGBColor[
              0.9454012974611372, 0.8942061481439322, 0.6293630988844421], 
             UndirectedEdge[65, 100] -> 
             RGBColor[
              0.9802686880075552, 0.9440256664364044, 0.46952410021777913`], 
             UndirectedEdge[53, 85] -> 
             RGBColor[
              0.9520011820524611, 0.8460123101485901, 0.28750450502850333`], 
             UndirectedEdge[59, 97] -> 
             RGBColor[
              0.9222391226993865, 0.9191903055214724, 0.6814343503067484], 
             UndirectedEdge[17, 98] -> 
             RGBColor[
              0.9887032661454174, 0.972818683008983, 0.473277319920667], 
             UndirectedEdge[61, 68] -> 
             RGBColor[
              0.944803367003583, 0.8142134973421142, 0.2987008727950231], 
             UndirectedEdge[28, 55] -> 
             RGBColor[
              0.9875019157801193, 0.9693120110838203, 0.42220238890267614`], 
             UndirectedEdge[9, 36] -> 
             RGBColor[
              0.9289571170026292, 0.8460618948290971, 0.6262586200701139], 
             UndirectedEdge[20, 59] -> 
             RGBColor[
              0.920308173006135, 0.9176506186503067, 0.6812501746012269], 
             UndirectedEdge[48, 57] -> 
             RGBColor[
              0.9691199751745937, 0.9067088830473335, 0.5237643031101868], 
             UndirectedEdge[1, 46] -> 
             RGBColor[
              0.6398489574029356, 0.7041029479887158, 0.814648042503064], 
             UndirectedEdge[5, 66] -> 
             RGBColor[
              0.9781127819834059, 0.9376402581140532, 0.38572737709158555`], 
             UndirectedEdge[64, 74] -> 
             RGBColor[
              0.6349916197756902, 0.6892171656441717, 0.6683006254313648], 
             UndirectedEdge[55, 79] -> 
             RGBColor[
              0.9913454635687131, 0.9885589378319736, 0.6382483118008232], 
             UndirectedEdge[32, 51] -> 
             RGBColor[
              0.9053379931456929, 0.5611632951630077, 0.3412725688124272], 
             UndirectedEdge[64, 73] -> 
             RGBColor[
              0.9848698767613393, 0.9606246829734304, 0.3957227576121745], 
             UndirectedEdge[35, 38] -> 
             RGBColor[
              0.9665301532711632, 0.9719062084653214, 0.79474815015116], 
             UndirectedEdge[71, 87] -> 
             RGBColor[
              0.9903527806852566, 0.9884018554812204, 0.6731204155504814], 
             UndirectedEdge[82, 87] -> 
             RGBColor[
              0.9938466355465931, 0.9892469005717701, 0.5716224372892511], 
             UndirectedEdge[5, 77] -> 
             RGBColor[
              0.9700593627523664, 0.910665341547104, 0.33818670741820367`], 
             UndirectedEdge[57, 64] -> 
             RGBColor[
              0.9654318227450185, 0.8920047282614205, 0.33609838491862276`], 
             UndirectedEdge[63, 97] -> 
             RGBColor[
              0.9297478895705522, 0.9431091717791411, 0.8304979539877301], 
             UndirectedEdge[41, 93] -> 
             RGBColor[
              0.9520663730557695, 0.8476661726400805, 0.2802896824950821], 
             UndirectedEdge[9, 61] -> 
             RGBColor[
              0.948738464036261, 0.8298148457833312, 0.3018671442361149], 
             UndirectedEdge[17, 46] -> 
             RGBColor[
              0.9943145656042376, 0.9902477556500859, 0.6225537363342897], 
             UndirectedEdge[25, 54] -> 
             RGBColor[
              0.9740065927283502, 0.9782804266011687, 0.8454343240695847], 
             UndirectedEdge[59, 77] -> 
             RGBColor[
              0.9782379689417178, 0.9382537006518403, 0.3699590480636502], 
             UndirectedEdge[66, 77] -> 
             RGBColor[
              0.9847593141696898, 0.9600605718583601, 0.4115478995430135], 
             UndirectedEdge[7, 27] -> 
             RGBColor[
              0.9453985348816827, 0.808635909565544, 0.4949283600225366], 
             UndirectedEdge[61, 92] -> 
             RGBColor[
              0.9828539456673064, 0.9529032044867656, 0.4662293580695486], 
             UndirectedEdge[77, 87] -> 
             RGBColor[
              0.9849061911088055, 0.9603747267795921, 0.42753454794636386`], 
             UndirectedEdge[28, 79] -> 
             RGBColor[
              0.9860346459481032, 0.9708354604904845, 0.601362131487104], 
             UndirectedEdge[5, 28] -> 
             RGBColor[
              0.9728019643627959, 0.9199167807725641, 0.34884119677786635`], 
             UndirectedEdge[56, 88] -> 
             RGBColor[
              0.9730879474309816, 0.9716911186924846, 0.6858904506614263], 
             UndirectedEdge[25, 26] -> 
             RGBColor[
              0.994708956473513, 0.9910913178404324, 0.6654807485566069], 
             UndirectedEdge[9, 67] -> 
             RGBColor[
              0.9566819239870559, 0.8662645045506638, 0.5571528817501515], 
             UndirectedEdge[32, 44] -> 
             RGBColor[
              0.887488608087995, 0.5014801811086504, 0.22711429736450411`], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.962890450219106, 0.9687606564917992, 0.7707951030674847], 
             UndirectedEdge[79, 83] -> 
             RGBColor[
              0.9284286244757105, 0.7394735847236134, 0.5140622281128708], 
             UndirectedEdge[60, 93] -> 
             RGBColor[
              0.9611601300233418, 0.8783837871574213, 0.31539724034846883`], 
             UndirectedEdge[5, 63] -> 
             RGBColor[
              0.9791002036265996, 0.9397522531652023, 0.49320212929320384`], 
             UndirectedEdge[19, 66] -> 
             RGBColor[
              0.9927929549950432, 0.9869931844154503, 0.4569358118156338], 
             UndirectedEdge[8, 86] -> 
             RGBColor[
              0.9302133740706839, 0.7433511976089608, 0.4977257428746676], 
             UndirectedEdge[4, 37] -> 
             RGBColor[
              0.9908302782919736, 0.9900495663064938, 0.7706251492877916], 
             UndirectedEdge[9, 92] -> 
             RGBColor[
              0.9598802555136043, 0.8664774551100947, 0.4234890122558701], 
             UndirectedEdge[3, 42] -> 
             RGBColor[
              0.9654697208588956, 0.8886153374233128, 0.4293169815950918], 
             UndirectedEdge[7, 90] -> 
             RGBColor[
              0.8096864320839724, 0.8493249165644172, 0.8588430972967791], 
             UndirectedEdge[35, 62] -> 
             RGBColor[
              0.947529971676469, 0.9603885193048725, 0.9737022509633423], 
             UndirectedEdge[20, 79] -> 
             RGBColor[
              0.9253622484020909, 0.9409809392634907, 0.9019987686650182], 
             UndirectedEdge[31, 78] -> 
             RGBColor[
              0.9518213679909563, 0.899144100642765, 0.618611874327286], 
             UndirectedEdge[13, 81] -> 
             RGBColor[
              0.8721556595827998, 0.5123705336173543, 0.21503588741539764`], 
             UndirectedEdge[18, 80] -> 
             RGBColor[
              0.9889605025477868, 0.9883191296329159, 0.7320311944810631], 
             UndirectedEdge[90, 100] -> 
             RGBColor[
              0.8099596056305285, 0.8485474960658023, 0.7895943305275797], 
             UndirectedEdge[67, 92] -> 
             RGBColor[
              0.990797405618101, 0.9893528632540982, 0.7215150955835853], 
             UndirectedEdge[55, 66] -> 
             RGBColor[
              0.9928127334007292, 0.9870354884253093, 0.45908856921639535`], 
             UndirectedEdge[89, 91] -> 
             RGBColor[
              0.9184068288452891, 0.6986109486022888, 0.2760398810189893], 
             UndirectedEdge[46, 55] -> 
             RGBColor[
              0.993872412916567, 0.9893020357596526, 0.5744281449314304], 
             UndirectedEdge[41, 64] -> 
             RGBColor[
              0.9705187938650306, 0.9121728736196316, 0.34019148128834337`], 
             UndirectedEdge[28, 46] -> 
             RGBColor[
              0.988561595295957, 0.9715785584181635, 0.5375419646177112], 
             UndirectedEdge[35, 53] -> 
             RGBColor[
              0.9411310277085478, 0.8834877230294904, 0.6307465494056264], 
             UndirectedEdge[35, 90] -> 
             RGBColor[
              0.7823053663929009, 0.83048437596968, 0.9759572824486322], 
             UndirectedEdge[5, 58] -> 
             RGBColor[
              0.9784907068818893, 0.9399267429611206, 0.5343074677807461], 
             UndirectedEdge[76, 85] -> 
             RGBColor[
              0.940935718145274, 0.8021414331038517, 0.2786009730289598], 
             UndirectedEdge[34, 77] -> 
             RGBColor[
              0.9857921327708099, 0.9622696664121773, 0.523963830457377], 
             UndirectedEdge[49, 71] -> 
             RGBColor[
              0.5832630370457763, 0.6472669563473337, 0.8943399825389333]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 25 -> 
             RGBColor[
              0.9952649712046948, 0.9922805771287175, 0.7259995207205758], 55 -> 
             RGBColor[
              0.9928127334007292, 0.9870354884253093, 0.45908856921639535`], 
             90 -> RGBColor[
              0.6256693181556748, 0.706985564417178, 0.9636741271088957], 27 -> 
             RGBColor[
              0.8970935237510955, 0.6256075504194316, 0.23584465256041068`], 
             15 -> RGBColor[
              0.9933697258981747, 0.9882268390567653, 0.519713765204103], 98 -> 
             RGBColor[
              0.9837094935147642, 0.9567104378117901, 0.39121488781922], 38 -> 
             RGBColor[
              0.9941188919121992, 0.9898292294084606, 0.601255862513951], 99 -> 
             RGBColor[
              0.848770768404908, 0.8822507877300613, 0.9854377076687116], 71 -> 
             RGBColor[
              0.9875990740915526, 0.9891399126946673, 0.8551789650778667], 41 -> 
             RGBColor[
              0.9558201705521472, 0.8625487288343554, 0.2833100760736195], 75 -> 
             RGBColor[
              0.9858216942101227, 0.9884049204371166, 0.8846347494248469], 64 -> 
             RGBColor[
              0.9852174171779141, 0.9617970184049078, 0.3970728865030672], 63 -> 
             RGBColor[
              0.9947875766871166, 0.9912594785276074, 0.674038073619632], 85 -> 
             RGBColor[
              0.9606817233179538, 0.8790323617603814, 0.30175634903412274`], 
             3 -> RGBColor[
              0.9369190736196318, 0.7876121779141101, 0.26810180981595083`], 
             86 -> RGBColor[
              0.868500446020664, 0.4957730625285125, 0.21198588762166837`], 
             94 -> RGBColor[
              0.992665665655114, 0.9867209253882685, 0.44308115270310644`], 
             61 -> 
             RGBColor[
              0.9717121541899632, 0.916240595160002, 0.3446074900497934], 84 -> 
             RGBColor[
              0.9428010141451783, 0.9568616705209931, 0.9817071425541603], 76 -> 
             RGBColor[
              0.9211897129725943, 0.725250504447322, 0.2554455970237969], 21 -> 
             RGBColor[
              0.9936314403155128, 0.9887866197320646, 0.548199764417178], 87 -> 
             RGBColor[
              0.9931064872789607, 0.9876637982677734, 0.49106186602309604`], 
             95 -> RGBColor[
              0.9880500517791411, 0.9713521600490796, 0.40807713703067466`], 
             72 -> RGBColor[
              0.9941529417423313, 0.9899020585521473, 0.6049619763926379], 42 -> 
             RGBColor[
              0.9940203680981595, 0.9896184969325154, 0.5905321533742328], 66 -> 
             RGBColor[
              0.9928127334007292, 0.9870354884253093, 0.45908856921639535`], 
             1 -> RGBColor[
              0.28476582237346626`, 0.4166373128834356, 0.9395283643596626], 
             24 -> RGBColor[
              0.9862527822375822, 0.988583186414928, 0.87749050518979], 54 -> 
             RGBColor[
              0.9527482142520056, 0.9642802760736197, 0.9648691274185937], 4 -> 
             RGBColor[
              0.9947875766871166, 0.9912594785276074, 0.674038073619632], 7 -> 
             RGBColor[
              0.99370354601227, 0.9916642687116565, 0.7540120674846625], 100 -> 
             RGBColor[
              0.9942498931053821, 0.9901094277144266, 0.6155145339462635], 12 -> 
             RGBColor[
              0.9842430276073619, 0.9877521012269939, 0.9107973404907976], 65 -> 
             RGBColor[
              0.9662874829097282, 0.8979419051583821, 0.3235336664892947], 8 -> 
             RGBColor[
              0.9919263021207039, 0.9909293326894092, 0.7834655981276668], 57 -> 
             RGBColor[
              0.9456462283121229, 0.8222124381179332, 0.2751238833341783], 74 -> 
             RGBColor[
              0.28476582237346626`, 0.4166373128834356, 0.9395283643596626], 
             37 -> RGBColor[
              0.9868729798968305, 0.9888396540853801, 0.8672122249559512], 43 -> 
             RGBColor[
              0.9932241884415726, 0.9914660420372454, 0.7619562629687442], 39 -> 
             RGBColor[
              0.895470881390593, 0.919488190184049, 0.9898920061349693], 58 -> 
             RGBColor[
              0.9935685831976963, 0.9916084581194441, 0.7562487505947165], 11 -> 
             RGBColor[
              0.9867426819631901, 0.9669420946748465, 0.4029982521717789], 51 -> 
             RGBColor[
              0.9933569862913857, 0.9881995903260153, 0.5183271376248543], 48 -> 
             RGBColor[
              0.9925937220370645, 0.9912053279767338, 0.7724047228861953], 20 -> 
             RGBColor[
              0.8608463030674847, 0.8918794912883435, 0.9865894829447853], 33 -> 
             RGBColor[
              0.9914381840490797, 0.982781125766871, 0.4212393911042942], 45 -> 
             RGBColor[
              0.9428010141451783, 0.9568616705209931, 0.9817071425541603], 23 -> 
             RGBColor[
              0.9480015807770962, 0.8315506257668712, 0.2770190552147239], 22 -> 
             RGBColor[
              0.9510213384939584, 0.8435229588396237, 0.2794488231565351], 2 -> 
             RGBColor[
              0.848770768404908, 0.8822507877300613, 0.9854377076687116], 60 -> 
             RGBColor[
              0.9740076844872918, 0.9239839578690371, 0.35352519178039293`], 
             16 -> RGBColor[
              0.9867545426572085, 0.9887906772430982, 0.8691750365222392], 79 -> 
             RGBColor[
              0.9898781937366972, 0.9900823872386378, 0.817408054385251], 89 -> 
             RGBColor[
              0.8656514189275882, 0.4828362959060388, 0.2096085895791615], 36 -> 
             RGBColor[
              0.9321494601226994, 0.9487346932515338, 0.9933904417177913], 52 -> 
             RGBColor[
              0.9694769768395833, 0.9087008171125714, 0.33592424812139277`], 
             32 -> RGBColor[0.817319, 0.134127, 0.164218], 31 -> 
             RGBColor[
              0.9555480327837422, 0.9663683761503067, 0.9601297649539877], 68 -> 
             RGBColor[
              0.9178945798172029, 0.7121863995242266, 0.25279425554025287`], 
             73 -> RGBColor[
              0.9845223363447644, 0.959452347541953, 0.3943726287212818], 82 -> 
             RGBColor[
              0.9945867838142255, 0.9908300028757668, 0.6521830085554061], 35 -> 
             RGBColor[
              0.9389414146301271, 0.9539831875221821, 0.9882404377883689], 88 -> 
             RGBColor[
              0.9567027165644172, 0.9672295374233129, 0.9581751865030674], 50 -> 
             RGBColor[
              0.9572811293961427, 0.9676609167661497, 0.9571960844531834], 19 -> 
             RGBColor[
              0.992773176589357, 0.9869508804055912, 0.4547830544148722], 17 -> 
             RGBColor[
              0.9936970387760704, 0.9889269282061759, 0.555339752022114], 96 -> 
             RGBColor[
              0.993887245398773, 0.9917402331288344, 0.7509676932515339], 14 -> 
             RGBColor[
              0.9930364230828221, 0.9875139380368099, 0.4834358106595088], 5 -> 
             RGBColor[
              0.9634128305660825, 0.888245027802797, 0.3123661849667757], 34 -> 
             RGBColor[
              0.9948783706029695, 0.9914536775329437, 0.6839204310451225], 97 -> 
             RGBColor[
              0.8647082024539877, 0.8949588650306749, 0.9869578343558282], 93 -> 
             RGBColor[
              0.9483125755593917, 0.8327836164458055, 0.27726928891654473`], 
             81 -> RGBColor[
              0.8766294725398328, 0.532685073369678, 0.2187689466099364], 69 -> 
             RGBColor[
              0.9939126833387454, 0.9893881701207279, 0.578811331865309], 9 -> 
             RGBColor[
              0.9257647738825591, 0.7433890964066604, 0.25912679842243636`], 
             13 -> RGBColor[
              0.8676818466257669, 0.49205599386503074`, 0.2113028282208589], 
             30 -> RGBColor[
              0.9942498931053821, 0.9901094277144266, 0.6155145339462635], 59 -> 
             RGBColor[
              0.9797700429447853, 0.9434217460122699, 0.3759108662576687], 28 -> 
             RGBColor[
              0.9821910981595092, 0.9515885337423312, 0.385316208588957], 80 -> 
             RGBColor[
              0.9842430276073619, 0.9877521012269939, 0.9107973404907976], 47 -> 
             RGBColor[
              0.9852174171779141, 0.9617970184049078, 0.3970728865030672], 62 -> 
             RGBColor[
              0.9561185287228109, 0.9667938510875628, 0.9591640641383157], 77 -> 
             RGBColor[
              0.9767058949386502, 0.9330856552914109, 0.3640072298696317], 78 -> 
             RGBColor[
              0.9480947031981704, 0.8319198251352233, 0.2770939837005844], 40 -> 
             RGBColor[
              0.9758605328659071, 0.9302340505195943, 0.3607231578502565], 67 -> 
             RGBColor[
              0.9875990740915526, 0.9891399126946673, 0.8551789650778667], 56 -> 
             RGBColor[
              0.989473178297546, 0.9761526999616563, 0.4136057148197851], 10 -> 
             RGBColor[
              0.9936240422326906, 0.9887707959809691, 0.5473945287576683], 53 -> 
             RGBColor[
              0.9433206407869684, 0.8129922585367988, 0.2732526610228839], 26 -> 
             RGBColor[
              0.9941529417423313, 0.9899020585521473, 0.6049619763926379], 18 -> 
             RGBColor[
              0.9936779774882117, 0.988886158038838, 0.5532650484713285], 29 -> 
             RGBColor[
              0.9950795530748789, 0.9918839864976898, 0.7058179015581656], 92 -> 
             RGBColor[
              0.9939957371446496, 0.989565813813529, 0.5878512260893038], 46 -> 
             RGBColor[
              0.9949320924324049, 0.9915685830939959, 0.6897677206464654], 49 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 83 -> 
             RGBColor[
              0.8669790552147238, 0.48886478220858876`, 0.21071640184049076`],
              70 -> RGBColor[
              0.28476582237346626`, 0.4166373128834356, 0.9395283643596626], 
             44 -> RGBColor[
              0.95765821617599, 0.868833362217301, 0.2900105947290082], 91 -> 
             RGBColor[
              0.9711622387629899, 0.9143856012985387, 0.3424711724588171], 6 -> 
             RGBColor[
              0.8473043335674112, 0.36460741345607495`, 
               0.1929319892877434]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9lHs01Akbx4dhXCZmRjNjDGZ+vxEpY003Oez6fWm7uFSIpJWyrGvrtqF9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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 13}], {
             RGBColor[
             0.5762238344996166, 0.4543466533742332, 0.5754155962902607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 17}], {
             RGBColor[
             0.6392314305747684, 0.7027821205448057, 0.7474340581908883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 19}], {
             RGBColor[
             0.6387694994814117, 0.7017940966445133, 0.6971557093872673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 27}], {
             RGBColor[
             0.5909296730622808, 0.5211224316514336, 0.5876865084600367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 43}], {
             RGBColor[
             0.6389950054075194, 0.7040516774603405, 0.8507423136642034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 46}], {
             RGBColor[
             0.6398489574029356, 0.7041029479887158, 0.814648042503064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 55}], {
             RGBColor[
             0.6387892778870977, 0.7018364006543725, 0.6993084667880289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 3}], {
             RGBColor[
             0.8928449210122699, 0.8349314828220857, 0.6267697587423312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 14}], {
             RGBColor[
             0.920903595743865, 0.9348823628834355, 0.7344367591641102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 29}], {
             RGBColor[
             0.9219251607398935, 0.9370673871138755, 0.8456278046134387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 33}], {
             RGBColor[
             0.9201044762269939, 0.9325159567484662, 0.703338549386503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 38}], {
             RGBColor[
             0.9214448301585536, 0.936040008569261, 0.7933467850913314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 42}], {
             RGBColor[
             0.9213955682515338, 0.9359346423312883, 0.7879849305214722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 44}], {
             RGBColor[
             0.903214492290449, 0.8755420749736811, 0.63772415119886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 62}], {
             RGBColor[
             0.9024446485638594, 0.924522319408812, 0.9723008859035136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 78}], {
             RGBColor[
             0.8984327358015392, 0.8570853064326422, 0.631265845684648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 16}], {
             RGBColor[
             0.9618368081384201, 0.8882014275786041, 0.5686384231690951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 29}], {
             RGBColor[
             0.9659993133472553, 0.8897480822059, 0.48695985568705824`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 33}], {
             RGBColor[
             0.9641786288343557, 0.8851966518404906, 0.34467060046012254`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 38}], {
             RGBColor[
             0.9655189827659154, 0.8887207036612854, 0.43467883616495095`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 42}], {
             RGBColor[
             0.9654697208588956, 0.8886153374233128, 0.4293169815950918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 62}], {
             RGBColor[
             0.9465188011712213, 0.8772030145008365, 0.6136329369771332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 9}], {
             RGBColor[
             0.9602761752848379, 0.8673242874671339, 0.46658243602103416`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 23}], {
             RGBColor[
             0.9713945787321063, 0.9114050521472393, 0.47552856441717795`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 24}], {
             RGBColor[
             0.9905201794623494, 0.9899213324712677, 0.775764289404711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 30}], {
             RGBColor[
             0.9945187348962494, 0.990684453121017, 0.6447763037829477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 36}], {
             RGBColor[
             0.963468518404908, 0.9699970858895706, 0.8337142576687117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 37}], {
             RGBColor[
             0.9908302782919736, 0.9900495663064938, 0.7706251492877916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 50}], {
             RGBColor[
             0.9760343530416297, 0.9794601976468786, 0.8156170790364077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 76}], {
             RGBColor[
             0.9579886448298555, 0.8582549914874646, 0.4647418353217144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 86}], {
             RGBColor[
             0.9316440113538903, 0.74351627052806, 0.44301198062065017`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 94}], {
             RGBColor[
             0.9937266211711153, 0.988990201957938, 0.5585596131613693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 20}], {
             RGBColor[
             0.9121295668167836, 0.8900622595455703, 0.6494778339557805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 28}], {
             RGBColor[
             0.9728019643627959, 0.9199167807725641, 0.34884119677786635`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 58}], {
             RGBColor[
             0.9784907068818893, 0.9399267429611206, 0.5343074677807461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.9715914367554339, 0.9158333869075335, 0.3441385256122222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 63}], {
             RGBColor[
             0.9791002036265996, 0.9397522531652023, 0.49320212929320384`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 66}], {
             RGBColor[
             0.9781127819834059, 0.9376402581140532, 0.38572737709158555`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 69}], {
             RGBColor[
             0.978662756952414, 0.9388165989617625, 0.44558875841604234`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[
             0.9700593627523664, 0.910665341547104, 0.33818670741820367`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 79}], {
             RGBColor[
             0.9766455121513898, 0.9391637075207174, 0.5648871196760133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[
             0.9151959428904032, 0.6885549050056929, 0.26154129340363325`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 97}], {
             RGBColor[
             0.9140605165100351, 0.891601946416736, 0.6496620096613019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 7}], {
             RGBColor[
             0.9205039397898406, 0.6781358410838657, 0.473472028386203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 10}], {
             RGBColor[
             0.9204641879000509, 0.676689104718522, 0.37016325902270586`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 15}], {
             RGBColor[
             0.920337029732793, 0.6764171262564201, 0.35632287724592315`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 25}], {
             RGBColor[
             0.921284652386053, 0.6784439952923962, 0.4594657550041596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 26}], {
             RGBColor[
             0.9207286376548712, 0.6772547360041111, 0.3989469828401907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 35}], {
             RGBColor[
             0.8931228740987691, 0.6592953004891285, 0.5905862135380562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 40}], {
             RGBColor[
             0.9115824332166591, 0.6474207319878347, 0.27682757356899995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.8953124871771898, 0.5887998359964368, 0.23309232515531367`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 65}], {
             RGBColor[
             0.9067959082385697, 0.6312746593072285, 0.2582328278885191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 90}], {
             RGBColor[
             0.736486825861543, 0.5357964889366265, 0.5783030581983195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 100}], {
             RGBColor[
             0.9207771133363967, 0.6773584205852508, 0.4042232616170035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 13}], {
             RGBColor[
             0.9306926963190184, 0.7418601312883436, 0.4826574478527607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 25}], {
             RGBColor[
             0.9944842586084823, 0.991972422920187, 0.7400057941026192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 27}], {
             RGBColor[
             0.9453985348816827, 0.808635909565544, 0.4949283600225366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 37}], {
             RGBColor[
             0.9902882629545502, 0.9902519613985183, 0.8106121462203069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 40}], {
             RGBColor[
             0.9847820394390885, 0.9609491596156254, 0.5573676126674595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 53}], {
             RGBColor[
             0.9685120933996192, 0.9023282636242276, 0.5136323642537732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.9732258801321378, 0.9779722723926381, 0.8594405974516282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 65}], {
             RGBColor[
             0.9799955144609991, 0.9448030869350192, 0.5387728669869787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 81}], {
             RGBColor[
             0.9351665092760514, 0.7621746710406672, 0.48639050704729947`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.9682522800787241, 0.9742629696163247, 0.8678596050194114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 85}], {
             RGBColor[
             0.9771926346651119, 0.9353483152360189, 0.5278842082593926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 90}], {
             RGBColor[
             0.8096864320839724, 0.8493249165644172, 0.8588430972967791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 100}], {
             RGBColor[
             0.993976719558826, 0.9908868482130415, 0.684763300715463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 17}], {
             RGBColor[
             0.9928116704483871, 0.9899281304477925, 0.6694026750748905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.9927788712181083, 0.9898579762107369, 0.6658326812724225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 22}], {
             RGBColor[
             0.9714738203073312, 0.9172261457645164, 0.5314572106421009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 30}], {
             RGBColor[
             0.993088097613043, 0.9905193802019179, 0.6994900660369652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 49}], {
             RGBColor[
             0.585426651060352, 0.6481616663447046, 0.8584832990638334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 69}], {
             RGBColor[
             0.9929194927297247, 0.9901587514050685, 0.6811384649964879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 77}], {
             RGBColor[
             0.984316098529677, 0.96200749399041, 0.5737364139986493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.9932565429674647, 0.990879667782588, 0.7178243033415365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 86}], {
             RGBColor[
             0.9302133740706839, 0.7433511976089608, 0.4977257428746676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 87}], {
             RGBColor[
             0.9925163946998323, 0.9892965654785912, 0.6372637320753815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 95}], {
             RGBColor[
             0.9899881769499225, 0.9811407463692444, 0.5957713675791707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 99}], {
             RGBColor[
             0.9203485352628059, 0.9365900602097352, 0.8844516528981892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.9562537279228747, 0.8551655955407534, 0.33106252529710767`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 21}], {
             RGBColor[
             0.9596981070990359, 0.8660878580693625, 0.4036632814198072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 30}], {
             RGBColor[
             0.9600073334939706, 0.8667492620605435, 0.43732066618434995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 36}], {
             RGBColor[
             0.9289571170026292, 0.8460618948290971, 0.6262586200701139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 61}], {
             RGBColor[
             0.948738464036261, 0.8298148457833312, 0.3018671442361149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 67}], {
             RGBColor[
             0.9566819239870559, 0.8662645045506638, 0.5571528817501515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 68}], {
             RGBColor[
             0.921829676849881, 0.7277877479654435, 0.25596052698134464`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 72}], {
             RGBColor[
             0.9599588578124452, 0.8666455774794039, 0.43204438740753714`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 82}], {
             RGBColor[
             0.9601757788483922, 0.8671095496412136, 0.45565490348892124`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 86}], {
             RGBColor[
             0.8971326099516115, 0.6195810794675864, 0.23555634302205236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 92}], {
             RGBColor[
             0.9598802555136043, 0.8664774551100947, 0.4234890122558701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 94}], {
             RGBColor[
             0.9592152197688366, 0.8650550108974644, 0.3511039755627714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.9934968840654327, 0.9884988175188671, 0.5335541469808855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 26}], {
             RGBColor[
             0.993888491987511, 0.9893364272665581, 0.5761782525751531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 35}], {
             RGBColor[
             0.9662827284314088, 0.9713769917515755, 0.7678174832730186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 40}], {
             RGBColor[
             0.9847422875492988, 0.9595024232502817, 0.4540588433039624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 53}], {
             RGBColor[
             0.9684723415098295, 0.9008815272588839, 0.4103235948902761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 65}], {
             RGBColor[
             0.9799557625712094, 0.9433563505696756, 0.4354640976234815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 90}], {
             RGBColor[
             0.8096466801941827, 0.8478781801990736, 0.755534327933282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 100}], {
             RGBColor[
             0.9939369676690364, 0.9894401118476979, 0.5814545313519659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 36}], {
             RGBColor[
             0.9594460710429448, 0.9578383939631901, 0.6981943469447851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 52}], {
             RGBColor[
             0.9781098294013868, 0.937821455893709, 0.3694612501465858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 61}], {
             RGBColor[
             0.9792274180765767, 0.9415913449174242, 0.37380287111078614`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 67}], {
             RGBColor[
             0.9871708780273714, 0.9780410036847569, 0.6290886086248229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 68}], {
             RGBColor[
             0.9523186308901965, 0.8395642470995366, 0.3278962538560159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 72}], {
             RGBColor[
             0.9904478118527607, 0.9784220766134969, 0.5039801142822085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 92}], {
             RGBColor[
             0.9903692095539198, 0.9782539542441877, 0.4954247391305414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 94}], {
             RGBColor[
             0.9897041738091521, 0.9768315100315574, 0.4230397024374427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 41}], {
             RGBColor[
             0.9700315990797546, 0.9251504150306746, 0.5970537082822086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 52}], {
             RGBColor[
             0.9768600022234726, 0.9482264591697827, 0.6233607943060953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 60}], {
             RGBColor[
             0.9791253560473269, 0.9558680295480155, 0.6321612661355953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.984730222392638, 0.9747745598159508, 0.6539351134969325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 74}], {
             RGBColor[
             0.6345044249904142, 0.7021947070552147, 0.9251628524252301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 88}], {
             RGBColor[
             0.9704728720858895, 0.9774908193251534, 0.9344862634969325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 96}], {
             RGBColor[
             0.9890651365030675, 0.9897461671779142, 0.8308825168711658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 27}], {
             RGBColor[
             0.8823876851884311, 0.5588317721422311, 0.2235737403906348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 43}], {
             RGBColor[
             0.9304530175336697, 0.741761017951138, 0.48662954559480154`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 54}], {
             RGBColor[
             0.9102150304388863, 0.7281681349693252, 0.5880859778197263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 81}], {
             RGBColor[
             0.8721556595827998, 0.5123705336173543, 0.21503588741539764`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 84}], {
             RGBColor[
             0.9052414303854726, 0.7244588321930119, 0.5965049853875096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 85}], {
             RGBColor[
             0.9141817849718603, 0.685544177812706, 0.2565295886274908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 15}], {
             RGBColor[
             0.9932030744904985, 0.9878703885467877, 0.5015747879318059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 24}], {
             RGBColor[
             0.9896446026602022, 0.988048562225869, 0.6804631579246494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 35}], {
             RGBColor[
             0.9659889188564746, 0.9707485627794961, 0.7358381242239389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 38}], {
             RGBColor[
             0.9935776574975106, 0.9886715837226352, 0.54234583658673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 42}], {
             RGBColor[
             0.9935283955904908, 0.9885662174846626, 0.5369839820168708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 53}], {
             RGBColor[
             0.9681785319348952, 0.9002530982868043, 0.37834423584119636`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 62}], {
             RGBColor[
             0.9745774759028165, 0.9771538945621863, 0.7212999373989122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 76}], {
             RGBColor[
             0.9571130680277082, 0.856382221242066, 0.36944070384165284`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 35}], {
             RGBColor[
             0.9661555702641509, 0.9711050132894737, 0.753977101496236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 38}], {
             RGBColor[
             0.993744308905187, 0.989028034232613, 0.560484813859027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 40}], {
             RGBColor[
             0.9846151293820409, 0.9592304447881799, 0.4402184615271797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 53}], {
             RGBColor[
             0.9683451833425716, 0.900609548796782, 0.39648321311349344`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.9747441273104929, 0.977510345072164, 0.7394389146712093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 90}], {
             RGBColor[
             0.8095195220269248, 0.8476062017369717, 0.7416939461564993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 100}], {
             RGBColor[
             0.9938098095017784, 0.989168133385596, 0.5676141495751832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 29}], {
             RGBColor[
             0.9909170478660437, 0.9903373318703941, 0.7874964690402024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.9890963633531441, 0.9857859015049846, 0.6452072138132667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 62}], {
             RGBColor[
             0.9714365356900097, 0.9777922641653305, 0.9141695503302774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 19}], {
             RGBColor[
             0.9932351076827137, 0.9879389043058835, 0.5050614032184931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 22}], {
             RGBColor[
             0.9723591886350145, 0.9162249435228997, 0.41739428758932456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 28}], {
             RGBColor[
             0.9879440684677898, 0.9702577309742535, 0.4703279803055355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 46}], {
             RGBColor[
             0.9943145656042376, 0.9902477556500859, 0.6225537363342897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 55}], {
             RGBColor[
             0.9932548860883998, 0.9879812083157427, 0.5072141606192547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 59}], {
             RGBColor[
             0.9867335408604279, 0.9661743371092228, 0.46562530913989136`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 66}], {
             RGBColor[
             0.9932548860883998, 0.9879812083157427, 0.5072141606192547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 69}], {
             RGBColor[
             0.993804861057408, 0.9891575491634519, 0.5670755419437115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 77}], {
             RGBColor[
             0.9852014668573603, 0.9610062917487934, 0.45967349094587284`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 79}], {
             RGBColor[
             0.9917876162563838, 0.9895046577224069, 0.6863739032036825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 95}], {
             RGBColor[
             0.9908735452776057, 0.9801395441276277, 0.4817084445263944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 98}], {
             RGBColor[
             0.9887032661454174, 0.972818683008983, 0.473277319920667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.9212339035904892, 0.9355888579681186, 0.7703887298454128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 80}], {
             RGBColor[
             0.9889605025477868, 0.9883191296329159, 0.7320311944810631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 28}], {
             RGBColor[
             0.9874821373744331, 0.9692697070739612, 0.4200496315019146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 43}], {
             RGBColor[
             0.9929986825154649, 0.9892084612214183, 0.6083696586918081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 46}], {
             RGBColor[
             0.9938526345108809, 0.9892597317497935, 0.5722753875306688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 55}], {
             RGBColor[
             0.9927929549950432, 0.9869931844154503, 0.4569358118156338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 59}], {
             RGBColor[
             0.9862716097670712, 0.9651863132089306, 0.41534696033627044`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 66}], {
             RGBColor[
             0.9927929549950432, 0.9869931844154503, 0.4569358118156338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 79}], {
             RGBColor[
             0.9913256851630271, 0.9885166338221145, 0.6360955544000616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 95}], {
             RGBColor[
             0.9904116141842491, 0.9791515202273354, 0.43143009572277347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 98}], {
             RGBColor[
             0.9882413350520607, 0.9718306591086907, 0.4229989711170461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 99}], {
             RGBColor[
             0.9207719724971325, 0.9346008340678262, 0.7201103810417919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.9215187006134969, 0.9217340125153374, 0.6859528457668711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 58}], {
             RGBColor[
             0.9272074431325905, 0.9417439747038938, 0.8714191167697509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 59}], {
             RGBColor[
             0.920308173006135, 0.9176506186503067, 0.6812501746012269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 63}], {
             RGBColor[
             0.9278169398773006, 0.9415694849079754, 0.8303137782822086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 66}], {
             RGBColor[
             0.9268295182341069, 0.9394574898568264, 0.7228390260805904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 79}], {
             RGBColor[
             0.9253622484020909, 0.9409809392634907, 0.9019987686650182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 83}], {
             RGBColor[
             0.8639126791411043, 0.6903721367484661, 0.5986529423926381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 97}], {
             RGBColor[
             0.8627772527607362, 0.8934191781595092, 0.9867736586503068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 22}], {
             RGBColor[
             0.9723263894047356, 0.9161547892858442, 0.41382429378685653`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 30}], {
             RGBColor[
             0.9939406667104475, 0.9894480237232456, 0.5818571491817208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 34}], {
             RGBColor[
             0.9942549054592411, 0.9901201486325042, 0.6160600977311502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.962890450219106, 0.9687606564917992, 0.7707951030674847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 49}], {
             RGBColor[
             0.5862792201577564, 0.6470903098660323, 0.740850382208589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 68}], {
             RGBColor[
             0.9557630100663579, 0.8504865096281455, 0.4004970099787154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 72}], {
             RGBColor[
             0.993892191028922, 0.989344339142106, 0.576580870404908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 82}], {
             RGBColor[
             0.9941091120648691, 0.9898083113039158, 0.600191386486292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[
             0.9933689637972367, 0.9882252089999191, 0.519630815220137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 92}], {
             RGBColor[
             0.9938135887300812, 0.9891762167727969, 0.5680254952532409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 30}], {
             RGBColor[
             0.9726356157996703, 0.9168161932770251, 0.4474816785513993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 34}], {
             RGBColor[
             0.9729498545484639, 0.9174883181862836, 0.48168462710082877`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 49}], {
             RGBColor[
             0.5649741692469792, 0.5744584794198119, 0.6064749115782675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 66}], {
             RGBColor[
             0.9719170359473438, 0.9152792236324665, 0.3692686961864652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 69}], {
             RGBColor[
             0.9724670109163519, 0.9164555644801757, 0.429130077510922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 77}], {
             RGBColor[
             0.9638636167163044, 0.8883043070655172, 0.3217280265130834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 82}], {
             RGBColor[
             0.972804061154092, 0.9171764808576952, 0.4658159158559706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 87}], {
             RGBColor[
             0.9720639128864595, 0.9155933785536985, 0.3852553445898156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 95}], {
             RGBColor[
             0.9695356951365497, 0.9074375594443517, 0.34376298009360484`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 99}], {
             RGBColor[
             0.8998960534494331, 0.8628868732848425, 0.6324432654126233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 24}], {
             RGBColor[
             0.9671271815073392, 0.9100669060908997, 0.577254780202257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 27}], {
             RGBColor[
             0.9225475522640958, 0.7285790880931514, 0.2564318538875673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 30}], {
             RGBColor[
             0.9711257369412392, 0.9108300267406488, 0.44626679458049373`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 37}], {
             RGBColor[
             0.9674372803369633, 0.9101951399261257, 0.5721156400853376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 50}], {
             RGBColor[
             0.9526413550866195, 0.8996057712665104, 0.6171075698339537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 76}], {
             RGBColor[
             0.9345956468748453, 0.7784005651070967, 0.2662323261192604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[
             0.9123155266584645, 0.6821178495682746, 0.24789400091233016`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 84}], {
             RGBColor[
             0.9454012974611372, 0.8942061481439322, 0.6293630988844421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 85}], {
             RGBColor[
             0.954341652047525, 0.8552914937636262, 0.28938770212442333`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 86}], {
             RGBColor[
             0.9082510133988801, 0.6636618441476918, 0.24450247141819614`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 42}], {
             RGBColor[
             0.9901365751678708, 0.9891008416737217, 0.7340113292820114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 50}], {
             RGBColor[
             0.9717669558168625, 0.9781220515905389, 0.9173432948214867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 76}], {
             RGBColor[
             0.9537212476050883, 0.856916845431125, 0.5664680511067934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 26}], {
             RGBColor[
             0.994708956473513, 0.9910913178404324, 0.6654807485566069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 40}], {
             RGBColor[
             0.985562752035301, 0.9612573138241559, 0.5433613392854162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 54}], {
             RGBColor[
             0.9740065927283502, 0.9782804266011687, 0.8454343240695847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 65}], {
             RGBColor[
             0.9807762270572116, 0.9451112411435498, 0.5247665936049353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 100}], {
             RGBColor[
             0.9947574321550385, 0.9911950024215721, 0.6707570273334197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 40}], {
             RGBColor[
             0.9850067373041191, 0.9600680545358709, 0.48284256712144724`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 53}], {
             RGBColor[
             0.9687367912646498, 0.901447158544473, 0.43910731870776093`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 65}], {
             RGBColor[
             0.9802202123260297, 0.9439219818552647, 0.4642478214409663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 90}], {
             RGBColor[
             0.809911129949003, 0.8484438114846626, 0.7843180517507669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[
             0.9942014174238567, 0.9900057431332869, 0.6102382551694507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 37}], {
             RGBColor[
             0.941983251823963, 0.8072236022524059, 0.5515284387581809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 43}], {
             RGBColor[
             0.945158856096334, 0.8085367962283385, 0.4989004577645775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 54}], {
             RGBColor[
             0.9249208690015506, 0.7949439132465257, 0.6003568899895022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 81}], {
             RGBColor[
             0.8868614981454641, 0.5791463118945548, 0.22730679958517352`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 84}], {
             RGBColor[
             0.9199472689481369, 0.7912346104702124, 0.6087758975572855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 85}], {
             RGBColor[
             0.9288876235345247, 0.7523199560899065, 0.2688005007972667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 46}], {
             RGBColor[
             0.988561595295957, 0.9715785584181635, 0.5375419646177112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 55}], {
             RGBColor[
             0.9875019157801193, 0.9693120110838203, 0.42220238890267614`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 59}], {
             RGBColor[
             0.9809805705521473, 0.9475051398773006, 0.38061353742331283`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 66}], {
             RGBColor[
             0.9875019157801193, 0.9693120110838203, 0.42220238890267614`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 79}], {
             RGBColor[
             0.9860346459481032, 0.9708354604904845, 0.601362131487104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 83}], {
             RGBColor[
             0.9245850766871165, 0.7202266579754599, 0.2980163052147239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 98}], {
             RGBColor[
             0.9829502958371368, 0.9541494857770607, 0.3882655482040885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 99}], {
             RGBColor[
             0.9154809332822086, 0.9169196607361962, 0.6853769581288343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 33}], {
             RGBColor[
             0.9932588685619793, 0.9873325561322804, 0.5635286463312299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 38}], {
             RGBColor[
             0.994599222493539, 0.9908566079530752, 0.6535368820360583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 42}], {
             RGBColor[
             0.9945499605865192, 0.9907512417151025, 0.6481750274661993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.9755990408988449, 0.9793389187926262, 0.8324909828482406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 36}], {
             RGBColor[
             0.9631996766140407, 0.9694220604829802, 0.8044524878320274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 50}], {
             RGBColor[
             0.9757655112507624, 0.9788851722402881, 0.7863553091997235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 82}], {
             RGBColor[
             0.9944183384598038, 0.9904697152950968, 0.6338487712508348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 86}], {
             RGBColor[
             0.931375169563023, 0.7429412451214695, 0.41375021078396595`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 92}], {
             RGBColor[
             0.9941228151250159, 0.9898376207639779, 0.6016828800177837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 94}], {
             RGBColor[
             0.9934577793802482, 0.9884151765513476, 0.529297843324685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 32}], {
             RGBColor[
             0.8864335163918711, 0.5502476880751533, 0.5621738824769938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 39}], {
             RGBColor[
             0.9255094570871676, 0.9429282831671779, 0.9750108855444786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 44}], {
             RGBColor[
             0.9566031244798661, 0.9176008691838038, 0.6250701798414979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 45}], {
             RGBColor[
             0.9491745234644602, 0.96161502333565, 0.970918453754074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 51}], {
             RGBColor[
             0.974452509537564, 0.977283983238161, 0.7392284512894209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 70}], {
             RGBColor[
             0.6201569275786043, 0.6915028445168712, 0.9498290646568252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 75}], {
             RGBColor[
             0.9706848634969325, 0.9773866482937117, 0.9223822571894174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 78}], {
             RGBColor[
             0.9518213679909563, 0.899144100642765, 0.618611874327286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 80}], {
             RGBColor[
             0.9698955301955521, 0.9770602386886502, 0.9354635527223927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 39}], {
             RGBColor[
             0.8563949406952965, 0.5268075950920246, 0.5770550030674847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 44}], {
             RGBColor[
             0.887488608087995, 0.5014801811086504, 0.22711429736450411`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 45}], {
             RGBColor[
             0.8800600070725891, 0.5454943352604966, 0.5729625712770802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 51}], {
             RGBColor[
             0.9053379931456929, 0.5611632951630077, 0.3412725688124272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 80}], {
             RGBColor[
             0.9007810138036809, 0.5609395506134969, 0.5375076702453988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 42}], {
             RGBColor[
             0.9927292760736196, 0.9861998113496933, 0.5058857722392636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 62}], {
             RGBColor[
             0.9737783563859452, 0.974787488427217, 0.6902017276213049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 49}], {
             RGBColor[
             0.5869026853014847, 0.6484238387664718, 0.8087107155225612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 60}], {
             RGBColor[
             0.9844430275451306, 0.9577188177009903, 0.5187228114127577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 69}], {
             RGBColor[
             0.9943955269708574, 0.9904209238268358, 0.6313658814552157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 71}], {
             RGBColor[
             0.991238722347261, 0.9902967951138055, 0.7695496980614946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 77}], {
             RGBColor[
             0.9857921327708099, 0.9622696664121773, 0.523963830457377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 82}], {
             RGBColor[
             0.9947325772085975, 0.9911418402043553, 0.6680517198002642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 87}], {
             RGBColor[
             0.9939924289409651, 0.9895587379003585, 0.5874911485341092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 38}], {
             RGBColor[
             0.9665301532711632, 0.9719062084653214, 0.79474815015116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 53}], {
             RGBColor[
             0.9411310277085478, 0.8834877230294904, 0.6307465494056264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 62}], {
             RGBColor[
             0.947529971676469, 0.9603885193048725, 0.9737022509633423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 90}], {
             RGBColor[
             0.7823053663929009, 0.83048437596968, 0.9759572824486322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 61}], {
             RGBColor[
             0.9519308071563313, 0.9324876442057679, 0.6689989658837924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 67}], {
             RGBColor[
             0.959874267107126, 0.9689373029731005, 0.924284703397829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 68}], {
             RGBColor[
             0.9250220199699511, 0.8304605463878802, 0.6230923486290221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 72}], {
             RGBColor[
             0.9631512009325154, 0.9693183759018406, 0.7991762090552146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 82}], {
             RGBColor[
             0.9633681219684624, 0.9697823480636503, 0.8227867251365988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 86}], {
             RGBColor[
             0.9003249530716817, 0.7222538778900232, 0.6026881646697299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 92}], {
             RGBColor[
             0.9630725986336746, 0.9691502535325314, 0.7906208339035476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 94}], {
             RGBColor[
             0.9624075628889067, 0.9677278093199011, 0.718235797210449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 50}], {
             RGBColor[
             0.9720770546464866, 0.9782502854257649, 0.9122041547045673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 76}], {
             RGBColor[
             0.9540313464347124, 0.8570450792663511, 0.561328910989874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 81}], {
             RGBColor[
             0.9317512262183316, 0.760762363727529, 0.5429905857829438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 84}], {
             RGBColor[
             0.9648369970210044, 0.9728506623031866, 0.9244596837550557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 85}], {
             RGBColor[
             0.9737773516073922, 0.9339360079228807, 0.584484286995037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 42}], {
             RGBColor[
             0.9940696300051793, 0.989723863170488, 0.595894007944092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 62}], {
             RGBColor[
             0.975118710317505, 0.9783115402480117, 0.7802099633261333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 44}], {
             RGBColor[
             0.9265645487832915, 0.894160776200675, 0.6399513004319888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 45}], {
             RGBColor[
             0.9191359477678857, 0.9381749303525211, 0.9857995743445648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 80}], {
             RGBColor[
             0.9398569544989774, 0.9536201457055214, 0.9503446733128835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 53}], {
             RGBColor[
             0.9595905868264378, 0.8716131545281965, 0.3169879094365702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 54}], {
             RGBColor[
             0.9643043735589564, 0.9472571632966069, 0.6627961426344251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.9710740078878177, 0.9140879778389882, 0.34212841216977563`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 90}], {
             RGBColor[
             0.8007649255107909, 0.8186098074683861, 0.662198642479576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 100}], {
             RGBColor[
             0.9850552129856447, 0.9601717391170104, 0.48811884589826005`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 48}], {
             RGBColor[
             0.9742069462946059, 0.9268770284055445, 0.5278573994799074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 56}], {
             RGBColor[
             0.9726466744248465, 0.9193507143980059, 0.3484578954467023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 60}], {
             RGBColor[
             0.9649139275197195, 0.8932663433516963, 0.3184176339270062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 64}], {
             RGBColor[
             0.9705187938650306, 0.9121728736196316, 0.34019148128834337`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 73}], {
             RGBColor[
             0.9701712534484558, 0.9110005381881542, 0.33884135239745067`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 74}], {
             RGBColor[
             0.6202929964628068, 0.6395930208588955, 0.6114192202166411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.9562614435582821, 0.9148891331288341, 0.6207426312883435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 91}], {
             RGBColor[
             0.9634912046575685, 0.8884671650664471, 0.3128906242662183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 93}], {
             RGBColor[
             0.9520663730557695, 0.8476661726400805, 0.2802896824950821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 44}], {
             RGBColor[
             0.9758392921370748, 0.9292259295749081, 0.44027137405162053`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 62}], {
             RGBColor[
             0.9750694484104852, 0.9782061740100391, 0.7748481087562742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 78}], {
             RGBColor[
             0.971057535648165, 0.9107691610338693, 0.43381306853740864`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 46}], {
             RGBColor[
             0.9940781404369887, 0.9915173125656207, 0.7258619918076048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 54}], {
             RGBColor[
             0.9729862013467891, 0.9778731590554326, 0.8634126951936689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 45}], {
             RGBColor[
             0.9502296151605841, 0.9128475163691471, 0.6358588686415843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 78}], {
             RGBColor[
             0.9528764596870802, 0.8503765936762622, 0.2835522892147963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 52}], {
             RGBColor[
             0.9561389954923808, 0.9327812438167823, 0.6588156953377765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 78}], {
             RGBColor[
             0.9454478586716744, 0.8943907478281082, 0.6294005631273724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 55}], {
             RGBColor[
             0.993872412916567, 0.9893020357596526, 0.5744281449314304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 59}], {
             RGBColor[
             0.987351067688595, 0.9674951645531329, 0.532839293452067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 79}], {
             RGBColor[
             0.9924051430845511, 0.9908254851663169, 0.7535878875158581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 95}], {
             RGBColor[
             0.991491072105773, 0.9814603715715378, 0.54892242883857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 98}], {
             RGBColor[
             0.9893207929735846, 0.9741395104528929, 0.5404913042328428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 99}], {
             RGBColor[
             0.9218514304186565, 0.9369096854120286, 0.8376027141575886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 51}], {
             RGBColor[
             0.9892872017346499, 0.9749983043654615, 0.4577000120639607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 57}], {
             RGBColor[
             0.9654318227450185, 0.8920047282614205, 0.33609838491862276`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 70}], {
             RGBColor[
             0.6349916197756902, 0.6892171656441717, 0.6683006254313648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 74}], {
             RGBColor[
             0.6349916197756902, 0.6892171656441717, 0.6683006254313648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 75}], {
             RGBColor[
             0.9855195556940184, 0.9751009694210122, 0.640853817963957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 88}], {
             RGBColor[
             0.9709600668711657, 0.9645132779141103, 0.6776240365030672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.9895523312883436, 0.9767686257668711, 0.5740202898773006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 56}], {
             RGBColor[
             0.9910334501673053, 0.9836790139691951, 0.5930052188529902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 57}], {
             RGBColor[
             0.9691199751745937, 0.9067088830473335, 0.5237643031101868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 64}], {
             RGBColor[
             0.9889055696074893, 0.9765011731908209, 0.5847388046946312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 73}], {
             RGBColor[
             0.9885580291909144, 0.9753288377593434, 0.5833886758037385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 74}], {
             RGBColor[
             0.6386797722052654, 0.7039213204300847, 0.8559665436229289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 88}], {
             RGBColor[
             0.9746482193007409, 0.9792174327000234, 0.8652899546946313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 91}], {
             RGBColor[
             0.9818779804000273, 0.9527954646376362, 0.5574379476725062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 93}], {
             RGBColor[
             0.9704531487982282, 0.9119944722112696, 0.5248370059013701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 96}], {
             RGBColor[
             0.9932404837179187, 0.9914727805527841, 0.7616862080688647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 69}], {
             RGBColor[
             0.5864198416693727, 0.6473910850603639, 0.7561561659326546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 71}], {
             RGBColor[
             0.5832630370457763, 0.6472669563473337, 0.8943399825389333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 77}], {
             RGBColor[
             0.577816447469325, 0.6192398276457054, 0.6487541149348158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 82}], {
             RGBColor[
             0.5867568919071127, 0.6481120014378834, 0.7928420042777031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.5860167436394803, 0.6465288991338867, 0.712281433011548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 76}], {
             RGBColor[
             0.9392354211843685, 0.8464557106067359, 0.6063208407384901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 81}], {
             RGBColor[
             0.9169553009679878, 0.7501729950679139, 0.5879825155315599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 84}], {
             RGBColor[
             0.9500410717706604, 0.9622612936435715, 0.9694516135036718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 85}], {
             RGBColor[
             0.9589814263570482, 0.9233466392632655, 0.6294762167436531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 86}], {
             RGBColor[
             0.9128907877084034, 0.7317169896473311, 0.5845909860374259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 57}], {
             RGBColor[
             0.9695016073017543, 0.9052060142219742, 0.3967255104795163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 70}], {
             RGBColor[
             0.639061404332426, 0.7024184516047255, 0.7289277509922585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 75}], {
             RGBColor[
             0.9895893402507542, 0.9883022553815659, 0.7014809435248506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 67}], {
             RGBColor[
             0.978538025465568, 0.9489203649036193, 0.5955516065996298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 68}], {
             RGBColor[
             0.9436857783283932, 0.810443608318399, 0.2943592518308228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 72}], {
             RGBColor[
             0.9818149592909573, 0.9493014378323594, 0.47044311225701535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 78}], {
             RGBColor[
             0.9587858400188769, 0.8703103211238974, 0.3065091159109886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 65}], {
             RGBColor[
             0.9548040618483483, 0.8554670818475905, 0.2983931637560893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 84}], {
             RGBColor[
             0.9430608274660733, 0.884926964528896, 0.6274799017885221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 85}], {
             RGBColor[
             0.9520011820524611, 0.8460123101485901, 0.28750450502850333`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 90}], {
             RGBColor[
             0.7844949794713216, 0.7599889114769884, 0.6184633940658898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 100}], {
             RGBColor[
             0.9687852669461753, 0.9015508431256127, 0.44438359748457373`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 84}], {
             RGBColor[
             0.9477746141985919, 0.9605709732973065, 0.9732881349863769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 100}], {
             RGBColor[
             0.9734990536786938, 0.9771948518940231, 0.7901918306824286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 59}], {
             RGBColor[
             0.9862913881727573, 0.9652286172187896, 0.417499717737032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 66}], {
             RGBColor[
             0.9928127334007292, 0.9870354884253093, 0.45908856921639535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 79}], {
             RGBColor[
             0.9913454635687131, 0.9885589378319736, 0.6382483118008232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 98}], {
             RGBColor[
             0.9882611134577467, 0.9718729631185496, 0.4251517285178077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 99}], {
             RGBColor[
             0.9207917509028185, 0.9346431380776853, 0.7222631384425535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 64}], {
             RGBColor[
             0.98734529773773, 0.9689748591832821, 0.40533930066142615`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 73}], {
             RGBColor[
             0.9869977573211552, 0.9678025237518046, 0.40398917177053345`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 74}], {
             RGBColor[
             0.6371195003355061, 0.6963950064225459, 0.6765670395897239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 88}], {
             RGBColor[
             0.9730879474309816, 0.9716911186924846, 0.6858904506614263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 89}], {
             RGBColor[
             0.9275622986125671, 0.7294944979338476, 0.3116071521994733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 91}], {
             RGBColor[
             0.9803177085302679, 0.9452691506300975, 0.37803844363930106`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 93}], {
             RGBColor[
             0.9688928769284688, 0.9044681582037308, 0.3454375018681649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 64}], {
             RGBColor[
             0.9654318227450185, 0.8920047282614205, 0.33609838491862276`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 70}], {
             RGBColor[
             0.6152060253427946, 0.6194248755006844, 0.6073261238469205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 74}], {
             RGBColor[
             0.6152060253427946, 0.6194248755006844, 0.6073261238469205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 75}], {
             RGBColor[
             0.9657339612611228, 0.9053086792775249, 0.5798793163795126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 88}], {
             RGBColor[
             0.95117447243827, 0.894720987770623, 0.616649534918623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 96}], {
             RGBColor[
             0.9697667368554479, 0.9069763356233838, 0.5130457882928561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 63}], {
             RGBColor[
             0.9941780799424065, 0.9914339683235258, 0.7151434121071742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 83}], {
             RGBColor[
             0.9302738192062101, 0.7402366201640165, 0.48348257621760365`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 97}], {
             RGBColor[
             0.929138392825842, 0.9432836615750595, 0.8716032924752724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 66}], {
             RGBColor[
             0.9862913881727573, 0.9652286172187896, 0.417499717737032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 69}], {
             RGBColor[
             0.9868413631417654, 0.9664049580664988, 0.4773610990614888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 77}], {
             RGBColor[
             0.9782379689417178, 0.9382537006518403, 0.3699590480636502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 79}], {
             RGBColor[
             0.9848241183407412, 0.9667520666254539, 0.5966594603214599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 83}], {
             RGBColor[
             0.9233745490797546, 0.7161432641104293, 0.29331363404907973`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 95}], {
             RGBColor[
             0.9839100473619632, 0.9573869530306748, 0.39199400164417164`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 97}], {
             RGBColor[
             0.9222391226993865, 0.9191903055214724, 0.6814343503067484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 98}], {
             RGBColor[
             0.9817397682297748, 0.9500660919120301, 0.3835628770384443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 99}], {
             RGBColor[
             0.9142704056748466, 0.9128362668711656, 0.6806742869631901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 64}], {
             RGBColor[
             0.979612550832603, 0.9428904881369724, 0.3752990391417301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 71}], {
             RGBColor[
             0.9808033792894222, 0.9565619352818522, 0.6043520784291299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 74}], {
             RGBColor[
             0.629386753430379, 0.6703106353762364, 0.6465267780700277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 89}], {
             RGBColor[
             0.91982955170744, 0.7034101268875379, 0.28156689067977725`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 93}], {
             RGBColor[
             0.9611601300233418, 0.8783837871574213, 0.31539724034846883`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 67}], {
             RGBColor[
             0.9796556141407579, 0.9526902539273346, 0.59989322756383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 68}], {
             RGBColor[
             0.944803367003583, 0.8142134973421142, 0.2987008727950231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 72}], {
             RGBColor[
             0.9829325479661473, 0.9530713268560747, 0.47478473322121567`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 86}], {
             RGBColor[
             0.9201063001053136, 0.7060068288442573, 0.2782966888357309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 92}], {
             RGBColor[
             0.9828539456673064, 0.9529032044867656, 0.4662293580695486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 94}], {
             RGBColor[
             0.9821889099225386, 0.9514807602741353, 0.3938443213764499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 83}], {
             RGBColor[
             0.9308833159509202, 0.7400621303680981, 0.4423772377300614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 97}], {
             RGBColor[
             0.9297478895705522, 0.9431091717791411, 0.8304979539877301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 73}], {
             RGBColor[
             0.9848698767613393, 0.9606246829734304, 0.3957227576121745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 74}], {
             RGBColor[
             0.6349916197756902, 0.6892171656441717, 0.6683006254313648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 88}], {
             RGBColor[
             0.9709600668711657, 0.9645132779141103, 0.6776240365030672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 89}], {
             RGBColor[
             0.9254344180527512, 0.7223166571554733, 0.3033407380411144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 91}], {
             RGBColor[
             0.978189827970452, 0.9380913098517233, 0.3697720294809421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 93}], {
             RGBColor[
             0.9667649963686529, 0.8972903174253566, 0.33717108770980597`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 96}], {
             RGBColor[
             0.9895523312883436, 0.9767686257668711, 0.5740202898773006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 90}], {
             RGBColor[
             0.7959784005327015, 0.8024637347877801, 0.6436038967990951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 100}], {
             RGBColor[
             0.9802686880075552, 0.9440256664364044, 0.46952410021777913`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 69}], {
             RGBColor[
             0.9933627083697373, 0.9882118292730186, 0.5189499505408521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 77}], {
             RGBColor[
             0.9847593141696898, 0.9600605718583601, 0.4115478995430135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 79}], {
             RGBColor[
             0.9913454635687131, 0.9885589378319736, 0.6382483118008232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 83}], {
             RGBColor[
             0.9298958943077265, 0.7379501353169491, 0.33490248552844304`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 95}], {
             RGBColor[
             0.9904313925899351, 0.9791938242371945, 0.433582853123535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 97}], {
             RGBColor[
             0.9287604679273584, 0.9409971767279921, 0.7230232017861118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[
             0.9882611134577467, 0.9718729631185496, 0.4251517285178077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 99}], {
             RGBColor[
             0.9207917509028185, 0.9346431380776853, 0.7222631384425535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 68}], {
             RGBColor[
             0.9527468269543777, 0.8506631561094469, 0.5539866103090598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 72}], {
             RGBColor[
             0.9908760079169419, 0.9895209856234073, 0.7300704707352523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 86}], {
             RGBColor[
             0.9280497600561083, 0.7424564876115899, 0.5335824263497675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 92}], {
             RGBColor[
             0.990797405618101, 0.9893528632540982, 0.7215150955835853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 94}], {
             RGBColor[
             0.9901323698733333, 0.9879304190414679, 0.6491300588904866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 72}], {
             RGBColor[
             0.956023760779767, 0.851044229038187, 0.42887811596644543`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 82}], {
             RGBColor[
             0.9562406818157142, 0.8515082011999967, 0.4524886320478295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 92}], {
             RGBColor[
             0.9559451584809262, 0.8508761066688778, 0.4203227408147784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 71}], {
             RGBColor[
             0.9907558787151489, 0.9892640414076976, 0.7169951484715879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 77}], {
             RGBColor[
             0.9853092891386979, 0.9612369127060694, 0.47140928086747036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 87}], {
             RGBColor[
             0.993509585308853, 0.9885259841942506, 0.5349365989442025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 95}], {
             RGBColor[
             0.9909813675589432, 0.9803701650849037, 0.4934442344479918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 97}], {
             RGBColor[
             0.9293104428963666, 0.9421735175757013, 0.7828845831105686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 98}], {
             RGBColor[
             0.9888110884267548, 0.973049303966259, 0.4850131098422645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 99}], {
             RGBColor[
             0.9213417258718266, 0.9358194789253946, 0.7821245197670104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 75}], {
             RGBColor[
             0.6352937582917945, 0.7025211166602761, 0.9120815568922547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 96}], {
             RGBColor[
             0.6393265338861196, 0.7041887730061349, 0.8452480288055982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 77}], {
             RGBColor[
             0.9821524845151014, 0.9611127839930391, 0.6095930974737492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 87}], {
             RGBColor[
             0.9903527806852566, 0.9884018554812204, 0.6731204155504814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 82}], {
             RGBColor[
             0.9943698627782784, 0.990366030713957, 0.628572492474022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 92}], {
             RGBColor[
             0.9940743394434904, 0.9897339361828381, 0.5964066012409709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 74}], {
             RGBColor[
             0.6346440793591153, 0.6880448302126942, 0.6669504965404722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 88}], {
             RGBColor[
             0.9706125264545908, 0.9633409424826329, 0.6762739076121747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.9250868776361763, 0.7211443217239959, 0.3019906091502217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 91}], {
             RGBColor[
             0.9778422875538771, 0.9369189744202459, 0.3684219005900494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 93}], {
             RGBColor[
             0.9664174559520781, 0.8961179819938792, 0.3358209588189133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 88}], {
             RGBColor[
             0.6207342694689417, 0.6919334251533742, 0.948851775431365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 91}], {
             RGBColor[
             0.6279640305682281, 0.6655114570909871, 0.6409997684092399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 96}], {
             RGBColor[
             0.6393265338861196, 0.7041887730061349, 0.8452480288055982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 96}], {
             RGBColor[
             0.9898544698044478, 0.9900725767829754, 0.8178012213381904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 81}], {
             RGBColor[
             0.8989095927562136, 0.6289677889084999, 0.23710727181686664`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 84}], {
             RGBColor[
             0.9319953635588862, 0.8410560874841575, 0.6185763697889786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 85}], {
             RGBColor[
             0.940935718145274, 0.8021414331038517, 0.2786009730289598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 87}], {
             RGBColor[
             0.9849061911088055, 0.9603747267795921, 0.42753454794636386`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 95}], {
             RGBColor[
             0.9823779733588957, 0.9522189076702452, 0.3860421834501532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 97}], {
             RGBColor[
             0.9207070486963189, 0.9140222601610428, 0.67548253211273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 98}], {
             RGBColor[
             0.9802076942267073, 0.9448980465516005, 0.3776110588444258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 99}], {
             RGBColor[
             0.9127383316717791, 0.9076682215107361, 0.6747224687691717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 83}], {
             RGBColor[
             0.9284286244757105, 0.7394735847236134, 0.5140622281128708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 98}], {
             RGBColor[
             0.9867938436257306, 0.9733964125252139, 0.6043114711022355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 99}], {
             RGBColor[
             0.9193244810708026, 0.9361665874843496, 0.9014228810269813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 84}], {
             RGBColor[
             0.9097152433425055, 0.7447733719453355, 0.6002380445820483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 85}], {
             RGBColor[
             0.9186555979288933, 0.7058587175650297, 0.26026264782202957`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 86}], {
             RGBColor[
             0.9315436149174448, 0.7433015327021397, 0.43208444808853724`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 87}], {
             RGBColor[
             0.9938466355465931, 0.9892469005717701, 0.5716224372892511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 92}], {
             RGBColor[
             0.9942912604794376, 0.9901979083446479, 0.620017117322355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 97}], {
             RGBColor[
             0.8658436288343558, 0.6919118236196318, 0.5988371180981594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 85}], {
             RGBColor[
             0.951741368731566, 0.9179470161406873, 0.6417317457941415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.7842351661504265, 0.8319236174690856, 0.972690634831528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 90}], {
             RGBColor[
             0.7931755207368143, 0.7930089630887797, 0.6327152380715092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 92}], {
             RGBColor[
             0.9312480915826569, 0.7426694381710208, 0.3999185568554861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[
             0.930583055837889, 0.7412469939583906, 0.3275335201623874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 91}], {
             RGBColor[
             0.9639324776637035, 0.9408075693609258, 0.6503231794809423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 96}], {
             RGBColor[
             0.9752949809815952, 0.9794848852760736, 0.8545714398773007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 91}], {
             RGBColor[
             0.9184068288452891, 0.6986109486022888, 0.2760398810189893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 93}], {
             RGBColor[
             0.90698199724349, 0.6578099561759221, 0.24343893924785312`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 100}], {
             RGBColor[
             0.8099596056305285, 0.8485474960658023, 0.7895943305275797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 93}], {
             RGBColor[
             0.9597374071611908, 0.8735846088721722, 0.30987023068768094`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 96}], {
             RGBColor[
             0.9825247420808815, 0.9530629172136866, 0.5467194328551754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 94}], {
             RGBColor[
             0.9933307013998818, 0.9881433696008988, 0.5154661893962051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 98}], {
             RGBColor[
             0.9858797726469526, 0.9640312989304349, 0.39964601242494735`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 99}], {
             RGBColor[
             0.9184104100920245, 0.9268014738895705, 0.6967574223496931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 99}], {
             RGBColor[
             0.916240130959836, 0.9194806127709256, 0.6883262977439658]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.058168352269944726`], {
             RGBColor[
             0.28476582237346626`, 0.4166373128834356, 0.9395283643596626]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.058168352269944726`], {
             RGBColor[
             0.848770768404908, 0.8822507877300613, 0.9854377076687116]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.058168352269944726`], {
             RGBColor[
             0.9369190736196318, 0.7876121779141101, 0.26810180981595083`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.058168352269944726`], {
             RGBColor[
             0.9947875766871166, 0.9912594785276074, 0.674038073619632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.058168352269944726`], {
             RGBColor[
             0.9634128305660825, 0.888245027802797, 0.3123661849667757]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.058168352269944726`], {
             RGBColor[
             0.8473043335674112, 0.36460741345607495`, 0.1929319892877434]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.058168352269944726`], {
             RGBColor[
             0.99370354601227, 0.9916642687116565, 0.7540120674846625]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.058168352269944726`], {
             RGBColor[
             0.9919263021207039, 0.9909293326894092, 0.7834655981276668]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.058168352269944726`], {
             RGBColor[
             0.9257647738825591, 0.7433890964066604, 0.25912679842243636`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.058168352269944726`], {
             RGBColor[
             0.9936240422326906, 0.9887707959809691, 0.5473945287576683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.058168352269944726`], {
             RGBColor[
             0.9867426819631901, 0.9669420946748465, 0.4029982521717789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.058168352269944726`], {
             RGBColor[
             0.9842430276073619, 0.9877521012269939, 0.9107973404907976]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.058168352269944726`], {
             RGBColor[
             0.8676818466257669, 0.49205599386503074`, 0.2113028282208589]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.058168352269944726`], {
             RGBColor[
             0.9930364230828221, 0.9875139380368099, 0.4834358106595088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.058168352269944726`], {
             RGBColor[
             0.9933697258981747, 0.9882268390567653, 0.519713765204103]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.058168352269944726`], {
             RGBColor[
             0.9867545426572085, 0.9887906772430982, 0.8691750365222392]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.058168352269944726`], {
             RGBColor[
             0.9936970387760704, 0.9889269282061759, 0.555339752022114]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.058168352269944726`], {
             RGBColor[
             0.9936779774882117, 0.988886158038838, 0.5532650484713285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.058168352269944726`], {
             RGBColor[
             0.992773176589357, 0.9869508804055912, 0.4547830544148722]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.058168352269944726`], {
             RGBColor[
             0.8608463030674847, 0.8918794912883435, 0.9865894829447853]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.058168352269944726`], {
             RGBColor[
             0.9936314403155128, 0.9887866197320646, 0.548199764417178]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.058168352269944726`], {
             RGBColor[
             0.9510213384939584, 0.8435229588396237, 0.2794488231565351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.058168352269944726`], {
             RGBColor[
             0.9480015807770962, 0.8315506257668712, 0.2770190552147239]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.058168352269944726`], {
             RGBColor[
             0.9862527822375822, 0.988583186414928, 0.87749050518979]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.058168352269944726`], {
             RGBColor[
             0.9952649712046948, 0.9922805771287175, 0.7259995207205758]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.058168352269944726`], {
             RGBColor[
             0.9941529417423313, 0.9899020585521473, 0.6049619763926379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.058168352269944726`], {
             RGBColor[
             0.8970935237510955, 0.6256075504194316, 0.23584465256041068`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.058168352269944726`], {
             RGBColor[
             0.9821910981595092, 0.9515885337423312, 0.385316208588957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.058168352269944726`], {
             RGBColor[
             0.9950795530748789, 0.9918839864976898, 0.7058179015581656]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.058168352269944726`], {
             RGBColor[
             0.9942498931053821, 0.9901094277144266, 0.6155145339462635]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.058168352269944726`], {
             RGBColor[
             0.9555480327837422, 0.9663683761503067, 0.9601297649539877]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.058168352269944726`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.058168352269944726`], {
             RGBColor[
             0.9914381840490797, 0.982781125766871, 0.4212393911042942]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.058168352269944726`], {
             RGBColor[
             0.9948783706029695, 0.9914536775329437, 0.6839204310451225]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.058168352269944726`], {
             RGBColor[
             0.9389414146301271, 0.9539831875221821, 0.9882404377883689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.058168352269944726`], {
             RGBColor[
             0.9321494601226994, 0.9487346932515338, 0.9933904417177913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.058168352269944726`], {
             RGBColor[
             0.9868729798968305, 0.9888396540853801, 0.8672122249559512]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.058168352269944726`], {
             RGBColor[
             0.9941188919121992, 0.9898292294084606, 0.601255862513951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.058168352269944726`], {
             RGBColor[
             0.895470881390593, 0.919488190184049, 0.9898920061349693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.058168352269944726`], {
             RGBColor[
             0.9758605328659071, 0.9302340505195943, 0.3607231578502565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.058168352269944726`], {
             RGBColor[
             0.9558201705521472, 0.8625487288343554, 0.2833100760736195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.058168352269944726`], {
             RGBColor[
             0.9940203680981595, 0.9896184969325154, 0.5905321533742328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.058168352269944726`], {
             RGBColor[
             0.9932241884415726, 0.9914660420372454, 0.7619562629687442]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.058168352269944726`], {
             RGBColor[
             0.95765821617599, 0.868833362217301, 0.2900105947290082]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.058168352269944726`], {
             RGBColor[
             0.9428010141451783, 0.9568616705209931, 0.9817071425541603]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.058168352269944726`], {
             RGBColor[
             0.9949320924324049, 0.9915685830939959, 0.6897677206464654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.058168352269944726`], {
             RGBColor[
             0.9852174171779141, 0.9617970184049078, 0.3970728865030672]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.058168352269944726`], {
             RGBColor[
             0.9925937220370645, 0.9912053279767338, 0.7724047228861953]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.058168352269944726`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.058168352269944726`], {
             RGBColor[
             0.9572811293961427, 0.9676609167661497, 0.9571960844531834]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.058168352269944726`], {
             RGBColor[
             0.9933569862913857, 0.9881995903260153, 0.5183271376248543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.058168352269944726`], {
             RGBColor[
             0.9694769768395833, 0.9087008171125714, 0.33592424812139277`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.058168352269944726`], {
             RGBColor[
             0.9433206407869684, 0.8129922585367988, 0.2732526610228839]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.058168352269944726`], {
             RGBColor[
             0.9527482142520056, 0.9642802760736197, 0.9648691274185937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.058168352269944726`], {
             RGBColor[
             0.9928127334007292, 0.9870354884253093, 0.45908856921639535`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.058168352269944726`], {
             RGBColor[
             0.989473178297546, 0.9761526999616563, 0.4136057148197851]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.058168352269944726`], {
             RGBColor[
             0.9456462283121229, 0.8222124381179332, 0.2751238833341783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.058168352269944726`], {
             RGBColor[
             0.9935685831976963, 0.9916084581194441, 0.7562487505947165]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.058168352269944726`], {
             RGBColor[
             0.9797700429447853, 0.9434217460122699, 0.3759108662576687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.058168352269944726`], {
             RGBColor[
             0.9740076844872918, 0.9239839578690371, 0.35352519178039293`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.058168352269944726`], {
             RGBColor[
             0.9717121541899632, 0.916240595160002, 0.3446074900497934]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.058168352269944726`], {
             RGBColor[
             0.9561185287228109, 0.9667938510875628, 0.9591640641383157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.058168352269944726`], {
             RGBColor[
             0.9947875766871166, 0.9912594785276074, 0.674038073619632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.058168352269944726`], {
             RGBColor[
             0.9852174171779141, 0.9617970184049078, 0.3970728865030672]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.058168352269944726`], {
             RGBColor[
             0.9662874829097282, 0.8979419051583821, 0.3235336664892947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.058168352269944726`], {
             RGBColor[
             0.9928127334007292, 0.9870354884253093, 0.45908856921639535`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.058168352269944726`], {
             RGBColor[
             0.9875990740915526, 0.9891399126946673, 0.8551789650778667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.058168352269944726`], {
             RGBColor[
             0.9178945798172029, 0.7121863995242266, 0.25279425554025287`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.058168352269944726`], {
             RGBColor[
             0.9939126833387454, 0.9893881701207279, 0.578811331865309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.058168352269944726`], {
             RGBColor[
             0.28476582237346626`, 0.4166373128834356, 0.9395283643596626]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.058168352269944726`], {
             RGBColor[
             0.9875990740915526, 0.9891399126946673, 0.8551789650778667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.058168352269944726`], {
             RGBColor[
             0.9941529417423313, 0.9899020585521473, 0.6049619763926379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.058168352269944726`], {
             RGBColor[
             0.9845223363447644, 0.959452347541953, 0.3943726287212818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.058168352269944726`], {
             RGBColor[
             0.28476582237346626`, 0.4166373128834356, 0.9395283643596626]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.058168352269944726`], {
             RGBColor[
             0.9858216942101227, 0.9884049204371166, 0.8846347494248469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.058168352269944726`], {
             RGBColor[
             0.9211897129725943, 0.725250504447322, 0.2554455970237969]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.058168352269944726`], {
             RGBColor[
             0.9767058949386502, 0.9330856552914109, 0.3640072298696317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.058168352269944726`], {
             RGBColor[
             0.9480947031981704, 0.8319198251352233, 0.2770939837005844]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.058168352269944726`], {
             RGBColor[
             0.9898781937366972, 0.9900823872386378, 0.817408054385251]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.058168352269944726`], {
             RGBColor[
             0.9842430276073619, 0.9877521012269939, 0.9107973404907976]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.058168352269944726`], {
             RGBColor[
             0.8766294725398328, 0.532685073369678, 0.2187689466099364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.058168352269944726`], {
             RGBColor[
             0.9945867838142255, 0.9908300028757668, 0.6521830085554061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.058168352269944726`], {
             RGBColor[
             0.8669790552147238, 0.48886478220858876`, 0.21071640184049076`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.058168352269944726`], {
             RGBColor[
             0.9428010141451783, 0.9568616705209931, 0.9817071425541603]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.058168352269944726`], {
             RGBColor[
             0.9606817233179538, 0.8790323617603814, 0.30175634903412274`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.058168352269944726`], {
             RGBColor[
             0.868500446020664, 0.4957730625285125, 0.21198588762166837`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.058168352269944726`], {
             RGBColor[
             0.9931064872789607, 0.9876637982677734, 0.49106186602309604`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.058168352269944726`], {
             RGBColor[
             0.9567027165644172, 0.9672295374233129, 0.9581751865030674]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.058168352269944726`], {
             RGBColor[
             0.8656514189275882, 0.4828362959060388, 0.2096085895791615]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.058168352269944726`], {
             RGBColor[
             0.6256693181556748, 0.706985564417178, 0.9636741271088957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.058168352269944726`], {
             RGBColor[
             0.9711622387629899, 0.9143856012985387, 0.3424711724588171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.058168352269944726`], {
             RGBColor[
             0.9939957371446496, 0.989565813813529, 0.5878512260893038]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.058168352269944726`], {
             RGBColor[
             0.9483125755593917, 0.8327836164458055, 0.27726928891654473`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.058168352269944726`], {
             RGBColor[
             0.992665665655114, 0.9867209253882685, 0.44308115270310644`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.058168352269944726`], {
             RGBColor[
             0.9880500517791411, 0.9713521600490796, 0.40807713703067466`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.058168352269944726`], {
             RGBColor[
             0.993887245398773, 0.9917402331288344, 0.7509676932515339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.058168352269944726`], {
             RGBColor[
             0.8647082024539877, 0.8949588650306749, 0.9869578343558282]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.058168352269944726`], {
             RGBColor[
             0.9837094935147642, 0.9567104378117901, 0.39121488781922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.058168352269944726`], {
             RGBColor[
             0.848770768404908, 0.8822507877300613, 0.9854377076687116]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.058168352269944726`], {
             RGBColor[
             0.9942498931053821, 0.9901094277144266, 0.6155145339462635]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100}, {
          Null, CompressedData["
1:eJwVxVmbqQwAAOCxVtbppLIkW4w1a5YJk8gSaaRCIqr783/Pr/me7715C/Zf
xfZ+fHz883x8/D9363DUk1oFBOGSrgbkKTe9Ubr+DJzlM67jGn44aCN55AiO
7OTWuWMuH0qHqrVObVrjcvv1PnbAe71DT+vplLkyddN8hkqxEiiAOngBnQA/
4nmBl/kz71Cz2Wqmz8zZE8QwHhOwC+aAKIqhFLpCL6gZpsKz8Cpshp+ghVm8
JViWU9t1dtxud0NGCI/IiIU4oXgsHi/Fq3gmo3kQT8YzygyrQz/up/w9/8Gv
+58BCZQwiZcESbpIluT8+c395n89MAjDCIzBI5iHBViCZdiCncDPzznXz/f7
6/6+Nu6Mx9x4N755Y96s9xj4/v75PnvrsXq2Xj/6SZBESYzESZIie6ROmuQz
5MbdtFt1h+5nNkDABEIQI4InZOJMOOEtuqW2s+1quzU9NEwjNEHTI1qmLdpp
99vr9t5fxsuZcrlXPpS19qvz4l7r1/6Fqxm1rPbUoXpQVc1b+CxkC4V67dF5
jB/TB/fYPW6PXCvfah1r1/a1cx1fuevuen2l0qlqaphy0SJWLE6LQlEqXjzR
aCY6jKpRLfeV//pqff3WxLbYEcfiVOTEnShexZenEW0gjUyjQTeG3maumW9+
NevNZqt5DC+p5Wy5XC23S31pLp/+ZCyJJ5P1ZC95AKJACsgAZaAKDAEV0AAX
7KJdrFvsdoWu1L3U7p37+M7dd3fxfr3f7vfH/RV4f79/3vxbeEvv8xswQkbc
SBslo2qohmYYbhAIhoLxYCqYDpaC1aARdIub7ma6ETYbaXMJsDCLsARLsyOW
5VmBlViZPbMW+2Yd7zw2j88/59l5YV6a1+eBRIJIfCfYxE+CT8iJc+IdXACL
0CK1SC+qi4WxcEEFVTCFVIoKpXSVlbJVFF25KCZsIzZh0/bIZm3eFmzJlm3L
th1vJVaJV7KVUqVSr8zDg9ZgsBysBtvBEThFT/gpcyqfeqfD6aSetCADMCEm
xsSZNFNiqgyzYFRGYwzGbU86k/5kwk3WE3Gyn1wnL6/P9+nL+gq+iq/um0dq
kUFkGuEiYuQaefkhKAyhEAlR0AxaQitoCymQDpnQ8z9pR8GG
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[69, 98] -> 
             RGBColor[
              0.35934722090825977`, 0.48438990088158124`, 0.9441651443282024],
              UndirectedEdge[29, 33] -> 
             RGBColor[
              0.29422509162390786`, 0.4255184180648389, 0.9401059109878009], 
             UndirectedEdge[55, 59] -> 
             RGBColor[
              0.26182384182735224`, 0.39252383672388913`, 0.9382218525071802],
              UndirectedEdge[47, 74] -> 
             RGBColor[
              0.31904494583740095`, 0.4476628644149205, 0.9416637299737558], 
             UndirectedEdge[19, 43] -> 
             RGBColor[
              0.25864725898215624`, 0.389185046746603, 0.9380409508134795], 
             UndirectedEdge[57, 75] -> 
             RGBColor[
              0.25952031121468844`, 0.390102679997703, 0.9380906698465571], 
             UndirectedEdge[19, 46] -> 
             RGBColor[
              0.2688995810964162, 0.39996088732345647`, 0.9386248053909352], 
             UndirectedEdge[36, 67] -> 
             RGBColor[
              0.18042977836149893`, 0.3069735153395867, 0.9335865810045261], 
             UndirectedEdge[79, 99] -> 
             RGBColor[
              0.3231374521934327, 0.4482183313765927, 0.9420339521780562], 
             UndirectedEdge[52, 68] -> 
             RGBColor[
              0.8780291995303775, 0.46447808085033465`, 0.21689224319720418`],
              UndirectedEdge[81, 85] -> 
             RGBColor[
              0.5777440554332705, 0.6680776771306483, 0.9599012748713662], 
             UndirectedEdge[12, 88] -> 
             RGBColor[
              0.44729833605503005`, 0.5559100353701449, 0.9509297720791202], 
             UndirectedEdge[72, 82] -> 
             RGBColor[
              0.8344620499016556, 0.2658959936764921, 0.180634203946131], 
             UndirectedEdge[31, 44] -> 
             RGBColor[
              0.5893518598321712, 0.6739738751825308, 0.9626393731710036], 
             UndirectedEdge[17, 79] -> 
             RGBColor[
              0.3156295526433677, 0.44171536614432994`, 0.9415555554577009], 
             UndirectedEdge[91, 96] -> 
             RGBColor[
              0.269451185257078, 0.40054065827003577`, 0.9386562184318596], 
             UndirectedEdge[55, 99] -> 
             RGBColor[
              0.32604506358539376`, 0.45127441530275375`, 0.9421995363454028],
              UndirectedEdge[77, 99] -> 
             RGBColor[
              0.4105884153235183, 0.5300527814046032, 0.9473833086487027], 
             UndirectedEdge[29, 38] -> 
             RGBColor[
              0.3762188058276783, 0.5002835531261081, 0.9451933075234802], 
             UndirectedEdge[26, 90] -> 
             RGBColor[
              0.2640863311664119, 0.39490185646935017`, 0.9383506979279865], 
             UndirectedEdge[13, 27] -> 
             RGBColor[
              0.30786109230723857`, 0.43780476345745334`, 0.9409573735218479],
              UndirectedEdge[22, 99] -> 
             RGBColor[
              0.6824515754881706, 0.7473171966554524, 0.9484738769221548], 
             UndirectedEdge[73, 74] -> 
             RGBColor[
              0.3072565676292452, 0.4352725314918011, 0.940992399274144], 
             UndirectedEdge[8, 77] -> 
             RGBColor[
              0.6903471893885933, 0.7540727058376107, 0.9477616322002713], 
             UndirectedEdge[36, 94] -> 
             RGBColor[
              0.1800640484055534, 0.3065891099672694, 0.9335657532245839], 
             UndirectedEdge[21, 87] -> 
             RGBColor[
              0.8461475149580568, 0.7442097533956613, 0.6102686063858478], 
             UndirectedEdge[59, 83] -> 
             RGBColor[
              0.24944682557751796`, 0.3795148078971581, 0.9375169997419068], 
             UndirectedEdge[24, 42] -> 
             RGBColor[
              0.7818518898687528, 0.7011631313519644, 0.6053992543639326], 
             UndirectedEdge[33, 42] -> 
             RGBColor[
              0.46221511877127164`, 0.5653020306816455, 0.952477193383617], 
             UndirectedEdge[14, 42] -> 
             RGBColor[
              0.6875842561639678, 0.755865313839969, 0.9694956308803766], 
             UndirectedEdge[45, 78] -> 
             RGBColor[
              0.8888960529642432, 0.9113695171236152, 0.8624721274568261], 
             UndirectedEdge[15, 38] -> 
             RGBColor[
              0.3740760297515814, 0.49842758818805, 0.9450567717266938], 
             UndirectedEdge[84, 85] -> 
             RGBColor[
              0.5258992134513589, 0.6255397259320082, 0.9559436352420423], 
             UndirectedEdge[55, 98] -> 
             RGBColor[
              0.2718017456530969, 0.4030112462803886, 0.9387900793690704], 
             UndirectedEdge[86, 92] -> 
             RGBColor[
              0.5898473968790202, 0.652327074257428, 0.8461866592841044], 
             UndirectedEdge[72, 92] -> 
             RGBColor[
              0.5088521381215928, 0.27790300442365007`, 0.5558317972580653], 
             UndirectedEdge[19, 99] -> 
             RGBColor[
              0.33504481922143936`, 0.46073372909370225`, 0.9427120591149303],
              UndirectedEdge[4, 76] -> 
             RGBColor[
              0.9165776385018892, 0.6448130127141793, 0.40538275488353814`], 
             UndirectedEdge[23, 76] -> 
             RGBColor[
              0.9905483291850934, 0.9895519766020239, 0.7476033518841813], 
             UndirectedEdge[9, 72] -> 
             RGBColor[
              0.8914135512087347, 0.5438293614385904, 0.22874208440602506`], 
             UndirectedEdge[2, 44] -> 
             RGBColor[
              0.6476158835940419, 0.7227173201002071, 0.9668276779841867], 
             UndirectedEdge[74, 88] -> 
             RGBColor[
              0.3260233854984479, 0.4549976469573106, 0.9420611417887761], 
             UndirectedEdge[21, 49] -> 
             RGBColor[
              0.8381155029968219, 0.7379350846059927, 0.6094680504969712], 
             UndirectedEdge[21, 34] -> 
             RGBColor[
              0.7440489383777218, 0.6635696741320418, 0.6006939636333543], 
             UndirectedEdge[59, 66] -> 
             RGBColor[
              0.2986049435975745, 0.4299329425040255, 0.9403622564770246], 
             UndirectedEdge[17, 99] -> 
             RGBColor[
              0.3958768319210234, 0.5173103472870436, 0.9464458995632381], 
             UndirectedEdge[26, 53] -> 
             RGBColor[
              0.27181647740875625`, 0.40165680145894234`, 0.9388410781260154],
              UndirectedEdge[23, 50] -> 
             RGBColor[
              0.9890507904475296, 0.9897402347152724, 0.831120268137828], 
             UndirectedEdge[41, 74] -> 
             RGBColor[
              0.39624144168094344`, 0.517626153935267, 0.9464691321747285], 
             UndirectedEdge[59, 79] -> 
             RGBColor[
              0.2589162304353912, 0.38946775279772805`, 0.9380562683398335], 
             UndirectedEdge[56, 93] -> 
             RGBColor[
              0.251058389952088, 0.3812086642339142, 0.9376087759489427], 
             UndirectedEdge[19, 98] -> 
             RGBColor[
              0.2808015012891425, 0.4124705600713371, 0.9393026021385978], 
             UndirectedEdge[2, 38] -> 
             RGBColor[
              0.4744745540542128, 0.5836658197325597, 0.9519298496562583], 
             UndirectedEdge[19, 59] -> 
             RGBColor[
              0.2708235974633978, 0.40198315051483763`, 0.9387343752767077], 
             UndirectedEdge[24, 76] -> 
             RGBColor[
              0.9509230096039614, 0.8306452679372385, 0.4351994673534736], 
             UndirectedEdge[5, 20] -> 
             RGBColor[
              0.23580229552736498`, 0.3651735417012756, 0.9367399639408238], 
             UndirectedEdge[37, 84] -> 
             RGBColor[
              0.5813861978869495, 0.66930600772412, 0.9611872941941962], 
             UndirectedEdge[9, 82] -> 
             RGBColor[
              0.8944306469902588, 0.5670200817151858, 0.2316312587337348], 
             UndirectedEdge[47, 75] -> 
             RGBColor[
              0.2704352603663721, 0.40157498360386956`, 0.9387122600535251], 
             UndirectedEdge[51, 75] -> 
             RGBColor[
              0.2631874052799758, 0.3939570283675128, 0.9382995054285956], 
             UndirectedEdge[58, 63] -> 
             RGBColor[
              0.22145736040975994`, 0.3500961053712548, 0.9359230411073061], 
             UndirectedEdge[7, 25] -> 
             RGBColor[
              0.2646919276847649, 0.3951010487472052, 0.9384011984763869], 
             UndirectedEdge[1, 55] -> 
             RGBColor[
              0.25340680094735984`, 0.3836769930878019, 0.9377425144809607], 
             UndirectedEdge[82, 86] -> 
             RGBColor[
              0.9154573086590831, 0.64032006351027, 0.4709890659721701], 
             UndirectedEdge[34, 71] -> 
             RGBColor[
              0.46781157980336074`, 0.5760433128989255, 0.9520168308232597], 
             UndirectedEdge[41, 73] -> 
             RGBColor[
              0.34062966364440406`, 0.46417862987955394`, 0.9431189034415599],
              UndirectedEdge[92, 94] -> 
             RGBColor[
              0.18353386454932197`, 0.3102361067334203, 0.9337633541208386], 
             UndirectedEdge[3, 62] -> 
             RGBColor[
              0.3326644235069168, 0.4616841238673607, 0.9424500919629462], 
             UndirectedEdge[70, 75] -> 
             RGBColor[
              0.2709835768789808, 0.4021512990238961, 0.9387434858677567], 
             UndirectedEdge[57, 96] -> 
             RGBColor[
              0.26925290833864535`, 0.40033225665728034`, 0.9386449268546793],
              UndirectedEdge[68, 72] -> 
             RGBColor[
              0.8243819770600658, 0.1884161366999483, 0.17098151480921064`], 
             UndirectedEdge[13, 54] -> 
             RGBColor[
              0.26215076948672145`, 0.392867458422297, 0.938240470553735], 
             UndirectedEdge[48, 96] -> 
             RGBColor[
              0.2710430288508906, 0.402213786815846, 0.9387468715696057], 
             UndirectedEdge[30, 50] -> 
             RGBColor[
              0.9048589996840575, 0.566437416695873, 0.47911193415723874`], 
             UndirectedEdge[11, 92] -> 
             RGBColor[
              0.21022995471211395`, 0.3382953901243926, 0.9352836569622833], 
             UndirectedEdge[41, 56] -> 
             RGBColor[
              0.3357366265014662, 0.459035737605853, 0.9428402522148693], 
             UndirectedEdge[73, 91] -> 
             RGBColor[
              0.25271649556761044`, 0.3829514383657963, 0.9377032026107992], 
             UndirectedEdge[32, 39] -> 
             RGBColor[
              0.2935264779562271, 0.4258453173585629, 0.9400272707348724], 
             UndirectedEdge[32, 80] -> 
             RGBColor[
              0.2808572092204622, 0.41252911263924097`, 0.939305774622874], 
             UndirectedEdge[20, 66] -> 
             RGBColor[
              0.271765998365242, 0.4017235093774315, 0.9388338182507047], 
             UndirectedEdge[47, 88] -> 
             RGBColor[
              0.28219998567006427`, 0.41394045582471695`, 0.9393822437552191],
              UndirectedEdge[14, 53] -> 
             RGBColor[
              0.5212638853795565, 0.6175278736453831, 0.9572307375115887], 
             UndirectedEdge[51, 57] -> 
             RGBColor[
              0.25705874177093724`, 0.3875154144398035, 0.9379504871083011], 
             UndirectedEdge[30, 94] -> 
             RGBColor[
              0.4995877733317956, 0.224777469479577, 0.549414921546451], 
             UndirectedEdge[22, 69] -> 
             RGBColor[
              0.6926573828576388, 0.7561569540400923, 0.9491241819430962], 
             UndirectedEdge[4, 94] -> 
             RGBColor[
              0.5098088734120636, 0.30334132361113186`, 0.5592026585263972], 
             UndirectedEdge[4, 86] -> 
             RGBColor[
              0.9161224057417618, 0.6454322911351396, 0.4716259636896631], 
             UndirectedEdge[9, 94] -> 
             RGBColor[
              0.566095277636464, 0.5761624637483606, 0.6066736412687983], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.25232882209907226`, 0.38254396897044507`, 0.9376811251802775],
              UndirectedEdge[12, 60] -> 
             RGBColor[
              0.5377449711891708, 0.6356046186030777, 0.9567524004381972], 
             UndirectedEdge[25, 40] -> 
             RGBColor[
              0.22979823437354924`, 0.35886289274915106`, 0.9363980415403266],
              UndirectedEdge[22, 95] -> 
             RGBColor[
              0.7735850344334367, 0.822659249453164, 0.9552736235962966], 
             UndirectedEdge[3, 33] -> 
             RGBColor[
              0.283755346452618, 0.41557523862275036`, 0.9394708192508354], 
             UndirectedEdge[48, 93] -> 
             RGBColor[
              0.2586149766637431, 0.3891511159831336, 0.9380391123832033], 
             UndirectedEdge[15, 90] -> 
             RGBColor[
              0.3120203774346074, 0.44461862031594124`, 0.9411048183197483], 
             UndirectedEdge[77, 97] -> 
             RGBColor[
              0.3343295626774611, 0.4586498895325537, 0.9427200995394867], 
             UndirectedEdge[44, 78] -> 
             RGBColor[
              0.88634546706693, 0.9093769800354632, 0.8622179088911622], 
             UndirectedEdge[30, 92] -> 
             RGBColor[
              0.5023132309055276, 0.22764209819356024`, 0.5495701323233219], 
             UndirectedEdge[37, 76] -> 
             RGBColor[
              0.8601494153237335, 0.8880770205793902, 0.7996440970661025], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.5927913677992559, 0.604221747139333, 0.6081939441102431], 
             UndirectedEdge[75, 96] -> 
             RGBColor[
              0.27538157184768386`, 0.40677387058498965`, 0.9389939451749738],
              UndirectedEdge[31, 80] -> 
             RGBColor[
              0.33469414166217204`, 0.4606589391956579, 0.9426813312926726], 
             UndirectedEdge[85, 90] -> 
             RGBColor[
              0.4615407941261787, 0.5697362170178263, 0.951844951557591], 
             UndirectedEdge[91, 93] -> 
             RGBColor[
              0.2570231330699305, 0.38747798743732337`, 0.9379484592454572], 
             UndirectedEdge[22, 49] -> 
             RGBColor[
              0.8672856751894109, 0.8967275864503471, 0.9640189035929849], 
             UndirectedEdge[69, 87] -> 
             RGBColor[
              0.6064566505030319, 0.6883381284885098, 0.9639201838642415], 
             UndirectedEdge[47, 70] -> 
             RGBColor[
              0.27576986252162594`, 0.40718198870235345`, 0.9390160577544302],
              UndirectedEdge[42, 78] -> 
             RGBColor[
              0.8251990022368825, 0.8616088969798854, 0.8561234007231051], 
             UndirectedEdge[1, 43] -> 
             RGBColor[
              0.25434890859377146`, 0.3846672079572553, 0.9377961661177004], 
             UndirectedEdge[10, 35] -> 
             RGBColor[
              0.2769526708149095, 0.4084251952129716, 0.9390834169369247], 
             UndirectedEdge[67, 94] -> 
             RGBColor[
              0.18117413693153547`, 0.3077558833917543, 0.9336289711239099], 
             UndirectedEdge[73, 93] -> 
             RGBColor[
              0.2559514270950259, 0.38635155650761516`, 0.9378874271756332], 
             UndirectedEdge[68, 82] -> 
             RGBColor[
              0.8273990728415899, 0.2116068569765438, 0.1738706891369204], 
             UndirectedEdge[11, 52] -> 
             RGBColor[
              0.5864699931809645, 0.5791596032510256, 0.6031076177106328], 
             UndirectedEdge[15, 53] -> 
             RGBColor[
              0.3197505236769518, 0.4513735653055334, 0.9415951985177772], 
             UndirectedEdge[53, 100] -> 
             RGBColor[
              0.2844126072753804, 0.4148961325895252, 0.9395584090876155], 
             UndirectedEdge[58, 83] -> 
             RGBColor[
              0.22400482828107066`, 0.3527736556227943, 0.9360681156339361], 
             UndirectedEdge[74, 96] -> 
             RGBColor[
              0.3239912573187127, 0.45286175139604057`, 0.9419454150952044], 
             UndirectedEdge[8, 87] -> 
             RGBColor[
              0.8760096171986388, 0.9035182955368775, 0.9636482023948687], 
             UndirectedEdge[43, 46] -> 
             RGBColor[
              0.2608419331067822, 0.3914917884019613, 0.9381659342581474], 
             UndirectedEdge[73, 89] -> 
             RGBColor[
              0.24808487338589558`, 0.37808330979100657`, 0.9374394385794216],
              UndirectedEdge[11, 67] -> 
             RGBColor[
              0.20787022709432745`, 0.3358151667827266, 0.9351492739653546], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.28368193490479854`, 0.4148331204560798, 0.9394909859406446], 
             UndirectedEdge[98, 99] -> 
             RGBColor[
              0.3491414135387916, 0.47555014349694125`, 0.943514839307261], 
             UndirectedEdge[4, 9] -> 
             RGBColor[
              0.8950957440729377, 0.5721323093400554, 0.23226815645122778`], 
             UndirectedEdge[34, 49] -> 
             RGBColor[
              0.678986366254469, 0.7482686816351451, 0.9692402627616367], 
             UndirectedEdge[6, 7] -> 
             RGBColor[
              0.2850997356690481, 0.41655094886844685`, 0.9395633929504454], 
             UndirectedEdge[7, 40] -> 
             RGBColor[
              0.2785823850167328, 0.4097008001089655, 0.9391922394723524], 
             UndirectedEdge[23, 85] -> 
             RGBColor[
              0.8008648229179952, 0.8435478591637703, 0.9160354539398804], 
             UndirectedEdge[82, 92] -> 
             RGBColor[
              0.5118692339031169, 0.30109372470024554`, 0.558720971585775], 
             UndirectedEdge[34, 69] -> 
             RGBColor[
              0.5043580739226968, 0.6076980492248905, 0.954345541111748], 
             UndirectedEdge[13, 85] -> 
             RGBColor[
              0.44417434838099124`, 0.5514829814433777, 0.9508559581637567], 
             UndirectedEdge[95, 98] -> 
             RGBColor[
              0.44027487248405767`, 0.5508921962946529, 0.9503145859814027], 
             UndirectedEdge[34, 87] -> 
             RGBColor[
              0.687018378215704, 0.7545433504248138, 0.9700408186505132], 
             UndirectedEdge[61, 94] -> 
             RGBColor[
              0.17986770348779496`, 0.3063827390097185, 0.9335545716719839], 
             UndirectedEdge[61, 72] -> 
             RGBColor[
              0.5051859770600657, 0.2740496366999483, 0.5556230148092107], 
             UndirectedEdge[50, 86] -> 
             RGBColor[
              0.9923931656575502, 0.9911223927597408, 0.7757284611180213], 
             UndirectedEdge[66, 97] -> 
             RGBColor[
              0.2865673127095588, 0.41728062921084064`, 0.9396767312060312], 
             UndirectedEdge[9, 21] -> 
             RGBColor[
              0.9272801117087064, 0.7490947632900866, 0.26033044528115884`], 
             UndirectedEdge[34, 60] -> 
             RGBColor[
              0.5274957486173808, 0.6272838379970835, 0.9559455440932065], 
             UndirectedEdge[53, 84] -> 
             RGBColor[
              0.3801912291988372, 0.5037242665904019, 0.9454464268280143], 
             UndirectedEdge[21, 22] -> 
             RGBColor[
              0.9323482473126639, 0.8120285789472437, 0.5954726044647025], 
             UndirectedEdge[14, 62] -> 
             RGBColor[
              0.5425047543047143, 0.6359256467112409, 0.9585841868969369], 
             UndirectedEdge[22, 30] -> 
             RGBColor[
              0.889942779596627, 0.5565022708656576, 0.5576225786548253], 
             UndirectedEdge[67, 72] -> 
             RGBColor[
              0.5064924105038062, 0.2754227810819841, 0.5556974142611366], 
             UndirectedEdge[61, 86] -> 
             RGBColor[
              0.5861812358174932, 0.6484737065337263, 0.8459778768352497], 
             UndirectedEdge[5, 83] -> 
             RGBColor[
              0.23714577838221002`, 0.3665856273634506, 0.9368164733019025], 
             UndirectedEdge[46, 99] -> 
             RGBColor[
              0.3372394933460653, 0.46304047074906063`, 0.9428370425595982], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.781084942834804, 0.8289087608987646, 0.9788149055141302], 
             UndirectedEdge[7, 37] -> 
             RGBColor[
              0.5197144859100872, 0.615889070520134, 0.9572576272411842], 
             UndirectedEdge[7, 53] -> 
             RGBColor[
              0.3185195172219749, 0.4503073293864159, 0.9415167598750023], 
             UndirectedEdge[12, 52] -> 
             RGBColor[
              0.7720788229198519, 0.7426869970369261, 0.6158231874912047], 
             UndirectedEdge[50, 85] -> 
             RGBColor[
              0.8031648921505794, 0.844498996900527, 0.8779173543675954], 
             UndirectedEdge[14, 15] -> 
             RGBColor[
              0.517451452940507, 0.6142257362851044, 0.9569878126877741], 
             UndirectedEdge[14, 35] -> 
             RGBColor[
              0.5107221888506179, 0.6078178110419963, 0.9565802436840543], 
             UndirectedEdge[8, 95] -> 
             RGBColor[
              0.7742769644814296, 0.8231752897500257, 0.9541023665093038], 
             UndirectedEdge[7, 84] -> 
             RGBColor[
              0.3751477903048108, 0.49935589331100566`, 0.9451250633614249], 
             UndirectedEdge[14, 76] -> 
             RGBColor[
              0.8566553758991764, 0.885347450425243, 0.7992958438699176], 
             UndirectedEdge[60, 89] -> 
             RGBColor[
              0.357298326389239, 0.4775030084894488, 0.9443308094531306], 
             UndirectedEdge[37, 85] -> 
             RGBColor[
              0.6704659090566354, 0.7420729031411366, 0.9680761991218017], 
             UndirectedEdge[39, 80] -> 
             RGBColor[
              0.28185045974068534`, 0.4135730819117158, 0.9393623387706183], 
             UndirectedEdge[23, 24] -> 
             RGBColor[
              0.9471254016338135, 0.8298823883137303, 0.5568344831794053], 
             UndirectedEdge[11, 68] -> 
             RGBColor[
              0.5257597936505869, 0.24880852240069085`, 0.5504333745134287], 
             UndirectedEdge[27, 81] -> 
             RGBColor[
              0.4414307993595177, 0.5543994591447239, 0.9500026902294574], 
             UndirectedEdge[36, 61] -> 
             RGBColor[
              0.17912334491775841`, 0.3056003709575509, 0.9335121815526001], 
             UndirectedEdge[28, 59] -> 
             RGBColor[
              0.2655146286535537, 0.39640308768762733`, 0.9384320373569025], 
             UndirectedEdge[8, 30] -> 
             RGBColor[
              0.8906347096446199, 0.5570183111625192, 0.5564513215678325], 
             UndirectedEdge[34, 82] -> 
             RGBColor[
              0.7111994736592744, 0.481494992557141, 0.5719947770859303], 
             UndirectedEdge[50, 84] -> 
             RGBColor[
              0.7140851809808935, 0.7717321014835103, 0.87102844943999], 
             UndirectedEdge[57, 88] -> 
             RGBColor[
              0.27128503651838054`, 0.40246815221855037`, 0.9387606535482509],
              UndirectedEdge[6, 53] -> 
             RGBColor[
              0.2901431745630745, 0.4209193221478431, 0.939884756417035], 
             UndirectedEdge[8, 69] -> 
             RGBColor[
              0.6933493129056316, 0.7566729943369539, 0.9479529248561034], 
             UndirectedEdge[69, 99] -> 
             RGBColor[
              0.41359053884055663`, 0.5326530699039465, 0.9475746013045347], 
             UndirectedEdge[81, 84] -> 
             RGBColor[
              0.4886643442635845, 0.5953107817136317, 0.9530123699437607], 
             UndirectedEdge[11, 94] -> 
             RGBColor[
              0.20750449713838193`, 0.3354307614104094, 0.9351284461854125], 
             UndirectedEdge[10, 65] -> 
             RGBColor[
              0.23682752030936433`, 0.3662511179501625, 0.9367983489754745], 
             UndirectedEdge[79, 98] -> 
             RGBColor[
              0.26889413426113584`, 0.39995516235422757`, 0.9386244952017238],
              UndirectedEdge[33, 62] -> 
             RGBColor[
              0.3171356169120182, 0.44536236355291736`, 0.9415657494001773], 
             UndirectedEdge[31, 70] -> 
             RGBColor[
              0.3382626356768291, 0.464409652660651, 0.9428845517476936], 
             UndirectedEdge[31, 32] -> 
             RGBColor[
              0.3463701598777138, 0.472931174642505, 0.9433462632569267], 
             UndirectedEdge[15, 100] -> 
             RGBColor[
              0.28060017483633093`, 0.41159399522924645`, 0.9393154842638007],
              UndirectedEdge[7, 65] -> 
             RGBColor[
              0.26785267018749115`, 0.3984231895202199, 0.9385811980860177], 
             UndirectedEdge[59, 95] -> 
             RGBColor[
              0.430296968658313, 0.5404047867381535, 0.9497463591195126], 
             UndirectedEdge[2, 3] -> 
             RGBColor[
              0.4080096464453409, 0.5252224449857339, 0.947726795683348], 
             UndirectedEdge[48, 88] -> 
             RGBColor[
              0.2730751570306258, 0.404349682377116, 0.9388625982631773], 
             UndirectedEdge[14, 38] -> 
             RGBColor[
              0.5755893914541861, 0.6645818965278997, 0.9606923107205052], 
             UndirectedEdge[44, 45] -> 
             RGBColor[
              0.7810472132422319, 0.8288792862542917, 0.9788111449809456], 
             UndirectedEdge[24, 50] -> 
             RGBColor[
              0.9494254708663976, 0.830833526050487, 0.5187163836071205], 
             UndirectedEdge[38, 62] -> 
             RGBColor[
              0.39912933111578863`, 0.5201274986141865, 0.9466531459358565], 
             UndirectedEdge[4, 50] -> 
             RGBColor[
              0.9150800997643256, 0.6450012708274279, 0.48889967113718485`], 
             UndirectedEdge[48, 74] -> 
             RGBColor[
              0.3099201171979624, 0.4380720909673196, 0.941144084481714], 
             UndirectedEdge[40, 100] -> 
             RGBColor[
              0.24447547507013836`, 0.3742896033120748, 0.9372338886849655], 
             UndirectedEdge[19, 95] -> 
             RGBColor[
              0.4261782781667054, 0.536075781891414, 0.949511805789072], 
             UndirectedEdge[19, 79] -> 
             RGBColor[
              0.2547975399437836, 0.38513874795098857`, 0.937821715009393], 
             UndirectedEdge[51, 70] -> 
             RGBColor[
              0.2685220074352297, 0.3995640334659966, 0.9386033031295007], 
             UndirectedEdge[17, 22] -> 
             RGBColor[
              0.6749436759381056, 0.7408142314231896, 0.9479954802017996], 
             UndirectedEdge[59, 99] -> 
             RGBColor[
              0.33916350971304693`, 0.46506273394044173`, 0.9429466124453707],
              UndirectedEdge[20, 63] -> 
             RGBColor[
              0.22006041247387476`, 0.34862782451902463`, 0.9358434869889567],
              UndirectedEdge[56, 89] -> 
             RGBColor[
              0.2431918362429577, 0.37294041751730556`, 0.937160787352731], 
             UndirectedEdge[12, 74] -> 
             RGBColor[
              0.48414329622236674`, 0.5896324439603484, 0.9532112582976568], 
             UndirectedEdge[8, 17] -> 
             RGBColor[
              0.6756356059860984, 0.7413302717200512, 0.9468242231148067], 
             UndirectedEdge[53, 90] -> 
             RGBColor[
              0.3158328098736569, 0.44792075767621997`, 0.941347743143563], 
             UndirectedEdge[21, 72] -> 
             RGBColor[
              0.8673115146201031, 0.4479706752513929, 0.20933339049355504`], 
             UndirectedEdge[48, 73] -> 
             RGBColor[
              0.25430833916142304`, 0.38462456691160657`, 0.9377938557485452],
              UndirectedEdge[8, 49] -> 
             RGBColor[
              0.8679776052374037, 0.8972436267472088, 0.9628476465059921], 
             UndirectedEdge[17, 69] -> 
             RGBColor[
              0.40608263929049154`, 0.5261501046716837, 0.9470962045841795], 
             UndirectedEdge[21, 82] -> 
             RGBColor[
              0.8703286104016272, 0.4711613955279884, 0.21222256482126478`], 
             UndirectedEdge[36, 68] -> 
             RGBColor[
              0.4983193449177584, 0.2199668709575509, 0.5488706815526001], 
             UndirectedEdge[21, 30] -> 
             RGBColor[
              0.860772607404038, 0.39770976902130306`, 0.2030717255588116], 
             UndirectedEdge[56, 64] -> 
             RGBColor[
              0.2634347031054928, 0.3942169540617188, 0.9383135886739146], 
             UndirectedEdge[48, 64] -> 
             RGBColor[
              0.27099128981714793`, 0.40215940581093823`, 0.9387439251081751],
              UndirectedEdge[46, 59] -> 
             RGBColor[
              0.27301827158802383`, 0.40428989217019595`, 0.9388593587213756],
              UndirectedEdge[46, 79] -> 
             RGBColor[
              0.25699221406840955`, 0.38744548960634695`, 0.937946698454061], 
             UndirectedEdge[9, 86] -> 
             RGBColor[
              0.9724088099661622, 0.9182534312723682, 0.5190969464320642], 
             UndirectedEdge[64, 91] -> 
             RGBColor[
              0.26939944622333534`, 0.400486277265128, 0.938653271970429], 
             UndirectedEdge[1, 19] -> 
             RGBColor[
              0.2624065565834054, 0.39313630687875045`, 0.9382550372504881], 
             UndirectedEdge[5, 69] -> 
             RGBColor[
              0.3370682698872072, 0.4609733107913742, 0.942896391026308], 
             UndirectedEdge[36, 92] -> 
             RGBColor[
              0.18278950597928542`, 0.3094537386812527, 0.9337209640014548], 
             UndirectedEdge[17, 95] -> 
             RGBColor[
              0.48701029086628944`, 0.5926524000847553, 0.95324564623738], 
             UndirectedEdge[7, 13] -> 
             RGBColor[
              0.293422925234443, 0.42529914882237513`, 0.9400373862831393], 
             UndirectedEdge[11, 61] -> 
             RGBColor[
              0.20656379365058694`, 0.3344420224006909, 0.9350748745134286], 
             UndirectedEdge[66, 83] -> 
             RGBColor[
              0.27310948122008705`, 0.4031355950396065, 0.9389103276117834], 
             UndirectedEdge[27, 37] -> 
             RGBColor[
              0.5341526529828826, 0.6283946851552121, 0.9581776144798929], 
             UndirectedEdge[22, 34] -> 
             RGBColor[
              0.7732191105703109, 0.8223621759763964, 0.955244816729368], 
             UndirectedEdge[6, 90] -> 
             RGBColor[
              0.2824130283207301, 0.41416437715825094`, 0.9393943762190061], 
             UndirectedEdge[71, 77] -> 
             RGBColor[
              0.3842477285736503, 0.5072378024632783, 0.9457049033811559], 
             UndirectedEdge[9, 68] -> 
             RGBColor[
              0.884350574148669, 0.48954022473864206`, 0.22197856959681445`], 
             UndirectedEdge[23, 86] -> 
             RGBColor[
              0.990093096424966, 0.9901712550229842, 0.8138465606903063], 
             UndirectedEdge[54, 84] -> 
             RGBColor[
              0.3438756345570892, 0.4669242029109275, 0.9433281476320208], 
             UndirectedEdge[3, 16] -> 
             RGBColor[
              0.26785762869397084`, 0.3988657292848884, 0.9385654677430463], 
             UndirectedEdge[66, 98] -> 
             RGBColor[
              0.3085828474233191, 0.440420352060525, 0.9409304833389149], 
             UndirectedEdge[64, 93] -> 
             RGBColor[
              0.2726343777507507, 0.4038863954069468, 0.938837496535263], 
             UndirectedEdge[2, 29] -> 
             RGBColor[
              0.41847939161663067`, 0.5351656244278226, 0.9483618874203135], 
             UndirectedEdge[50, 81] -> 
             RGBColor[
              0.7659300229628049, 0.8142700526821505, 0.8749860890693137], 
             UndirectedEdge[8, 99] -> 
             RGBColor[
              0.6831435055361634, 0.747833236952314, 0.947302619835162], 
             UndirectedEdge[66, 69] -> 
             RGBColor[
              0.37303197272508415`, 0.4975232784675301, 0.9449902453361887], 
             UndirectedEdge[9, 30] -> 
             RGBColor[
              0.8848746439926696, 0.49356845520850057`, 0.2224804194712816], 
             UndirectedEdge[11, 36] -> 
             RGBColor[
              0.20676013856834535`, 0.33464839335824176`, 0.9350860560660287],
              UndirectedEdge[16, 62] -> 
             RGBColor[
              0.30123789915337096`, 0.4286528542150554, 0.9406603978923882], 
             UndirectedEdge[50, 76] -> 
             RGBColor[
              0.9928483984176775, 0.9905031143387806, 0.7094852523118963], 
             UndirectedEdge[36, 86] -> 
             RGBColor[
              0.5863775807352516, 0.6486800774912771, 0.8459890583878498], 
             UndirectedEdge[60, 71] -> 
             RGBColor[
              0.41038752678537255`, 0.5294238797348146, 0.9474961990184465], 
             UndirectedEdge[43, 54] -> 
             RGBColor[
              0.2507606889125138, 0.3808957615659856, 0.9375918223151481], 
             UndirectedEdge[29, 42] -> 
             RGBColor[
              0.48821367053746006`, 0.5915669704381774, 0.9539966276833514], 
             UndirectedEdge[76, 84] -> 
             RGBColor[
              0.7155827197184571, 0.7715438433702618, 0.7875115331863431], 
             UndirectedEdge[65, 90] -> 
             RGBColor[
              0.26516596283917315`, 0.39603661781002397`, 0.9384121813545784],
              UndirectedEdge[52, 78] -> 
             RGBColor[
              0.9664668529248481, 0.8933481863027279, 0.5077226888807255], 
             UndirectedEdge[25, 65] -> 
             RGBColor[
              0.21906851954430756`, 0.34758528216040546`, 0.9357870001539919],
              UndirectedEdge[45, 52] -> 
             RGBColor[
              0.8611685991001501, 0.8128504925215565, 0.6243159249705089], 
             UndirectedEdge[57, 74] -> 
             RGBColor[
              0.3081299966857172, 0.43619056080875396`, 0.9410421397667876], 
             UndirectedEdge[17, 66] -> 
             RGBColor[
              0.3553182658055509, 0.48218055585062736`, 0.943861543594892], 
             UndirectedEdge[59, 98] -> 
             RGBColor[
              0.28492019178075007`, 0.41679956491807657`, 0.9395371554690384],
              UndirectedEdge[22, 77] -> 
             RGBColor[
              0.6896552593406005, 0.7535566655407491, 0.9489328892872642], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.9001907126422091, 0.6304699376692046, 0.5656021608302857], 
             UndirectedEdge[30, 36] -> 
             RGBColor[
              0.49884341476175903`, 0.2239951014274094, 0.5493725314270672], 
             UndirectedEdge[60, 64] -> 
             RGBColor[
              0.37754119325177404`, 0.49877954503386207`, 0.9454836107743141],
              UndirectedEdge[28, 99] -> 
             RGBColor[
              0.3297358504115952, 0.455153666266492, 0.9424097211951252], 
             UndirectedEdge[59, 69] -> 
             RGBColor[
              0.34936931708251506`, 0.4739024913250818, 0.9435969174663121], 
             UndirectedEdge[66, 79] -> 
             RGBColor[
              0.2825788860779602, 0.4130885399401764, 0.93944959620971], 
             UndirectedEdge[7, 81] -> 
             RGBColor[
              0.42699263228672224`, 0.5418938445096457, 0.9490827029907487], 
             UndirectedEdge[26, 100] -> 
             RGBColor[
              0.2326661285681354, 0.3618772313826554, 0.9365613638720389], 
             UndirectedEdge[5, 97] -> 
             RGBColor[
              0.2506036098716818, 0.3807306615346847, 0.9375828768961504], 
             UndirectedEdge[20, 83] -> 
             RGBColor[
              0.22260788034518547`, 0.3513053747705641, 0.9359885615155867], 
             UndirectedEdge[21, 92] -> 
             RGBColor[
              0.5447186986215644, 0.48316840627514634`, 0.5874201581331991], 
             UndirectedEdge[77, 98] -> 
             RGBColor[
              0.35634509739122144`, 0.481789612382238, 0.9439738516723704], 
             UndirectedEdge[13, 84] -> 
             RGBColor[
              0.35509463721130535`, 0.4787160860263612, 0.9439670532361513], 
             UndirectedEdge[83, 97] -> 
             RGBColor[
              0.23740919468950228`, 0.36686249460397324`, 0.9368314744709133],
              UndirectedEdge[4, 24] -> 
             RGBColor[
              0.8731547109506095, 0.48514342442588576`, 0.2146138861787622], 
             UndirectedEdge[7, 85] -> 
             RGBColor[
              0.46422750147449665`, 0.5721227887280222, 0.9520139682890303], 
             UndirectedEdge[10, 40] -> 
             RGBColor[
              0.247557235138606, 0.37752872853890806`, 0.9374093903618093], 
             UndirectedEdge[26, 40] -> 
             RGBColor[
              0.23187934520351416`, 0.3610502721814919, 0.9365165577233654], 
             UndirectedEdge[56, 74] -> 
             RGBColor[
              0.3023635304863073, 0.4301296392181001, 0.9407137480474534], 
             UndirectedEdge[42, 62] -> 
             RGBColor[
              0.5111241958255703, 0.6114109159262558, 0.9554564660957278], 
             UndirectedEdge[4, 36] -> 
             RGBColor[
              0.5090645148420271, 0.3025589555589642, 0.5591602684070134], 
             UndirectedEdge[2, 33] -> 
             RGBColor[
              0.39248083985044224`, 0.5089006846712906, 0.946842453120579], 
             UndirectedEdge[36, 82] -> 
             RGBColor[
              0.5083994177593483, 0.2974467279340947, 0.5585233706895204], 
             UndirectedEdge[76, 81] -> 
             RGBColor[
              0.7674275617003685, 0.8140817945689018, 0.7914691728156671], 
             UndirectedEdge[27, 43] -> 
             RGBColor[
              0.29647101173303086`, 0.4258330666011419, 0.9403087252832609], 
             UndirectedEdge[61, 67] -> 
             RGBColor[
              0.1802334334437405, 0.3067671443820358, 0.933575399451926], 
             UndirectedEdge[10, 26] -> 
             RGBColor[
              0.235747888636603, 0.36511635660948866`, 0.9367368655488828], 
             UndirectedEdge[63, 83] -> 
             RGBColor[
              0.2214038953287198, 0.3500399101811996, 0.9359199963500353], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.28220392258022686`, 0.41350726570694146`, 0.9393984806790088],
              UndirectedEdge[20, 97] -> 
             RGBColor[
              0.23606571183465724`, 0.3654504089417983, 0.9367549651098346], 
             UndirectedEdge[28, 98] -> 
             RGBColor[
              0.27549253247929834`, 0.40689049724412685`, 0.9390002642187927],
              UndirectedEdge[4, 23] -> 
             RGBColor[
              0.9127800305317415, 0.6440501330906712, 0.5270177707094699], 
             UndirectedEdge[30, 86] -> 
             RGBColor[
              0.9059013056614938, 0.5668684370035848, 0.46183822670971686`], 
             UndirectedEdge[27, 54] -> 
             RGBColor[
              0.2966420896530224, 0.4260128803420197, 0.9403184679177174], 
             UndirectedEdge[1, 13] -> 
             RGBColor[
              0.2657389891679791, 0.3966389048135667, 0.9384448143562873], 
             UndirectedEdge[15, 35] -> 
             RGBColor[
              0.3092088271480132, 0.4416635027021466, 0.9409447046902427], 
             UndirectedEdge[56, 73] -> 
             RGBColor[
              0.24675175244976794`, 0.37668211516238714`, 0.9373635193142849],
              UndirectedEdge[16, 29] -> 
             RGBColor[
              0.27832737386526063`, 0.40880890872697706`, 0.9392005594800119],
              UndirectedEdge[53, 65] -> 
             RGBColor[
              0.2728961090815175, 0.40279156279961614`, 0.9389025615526072], 
             UndirectedEdge[6, 25] -> 
             RGBColor[
              0.2363155850258645, 0.36571304150863243`, 0.9367691950184196], 
             UndirectedEdge[68, 92] -> 
             RGBColor[
              0.501789161061527, 0.22361386772370176`, 0.5490682824488547], 
             UndirectedEdge[69, 97] -> 
             RGBColor[
              0.3373316861944994, 0.46125017803189694`, 0.9429113921953187], 
             UndirectedEdge[17, 77] -> 
             RGBColor[
              0.4030805157734533, 0.5235498161723404, 0.9469049119283475], 
             UndirectedEdge[46, 98] -> 
             RGBColor[
              0.2829961754137684, 0.41477730172669547`, 0.9394275855832659], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.34313416867820656`, 0.4716273033094493, 0.9430851836999117], 
             UndirectedEdge[17, 55] -> 
             RGBColor[
              0.3185371640353287, 0.44477145007049096`, 0.9417211396250476], 
             UndirectedEdge[2, 78] -> 
             RGBColor[
              0.7554647233160532, 0.8052075509695305, 0.8504886604600671], 
             UndirectedEdge[6, 35] -> 
             RGBColor[
              0.2796014780341359, 0.41120925954445625`, 0.9392342625895005], 
             UndirectedEdge[95, 99] -> 
             RGBColor[
              0.49451819041635453`, 0.5991553653170181, 0.9537240429577352], 
             UndirectedEdge[66, 99] -> 
             RGBColor[
              0.36282616535561596`, 0.48868352108289015`, 0.9443399403152473],
              UndirectedEdge[31, 39] -> 
             RGBColor[
              0.34736341039793694`, 0.47397514391497986`, 0.943402827404671], 
             UndirectedEdge[69, 71] -> 
             RGBColor[
              0.38724985209068863`, 0.5098380909626216, 0.9458961960369879], 
             UndirectedEdge[64, 89] -> 
             RGBColor[
              0.2647678240416204, 0.39561814869033823`, 0.9383895079390514], 
             UndirectedEdge[40, 53] -> 
             RGBColor[
              0.2836258239107592, 0.41406917338836174`, 0.9395136029389419], 
             UndirectedEdge[1, 27] -> 
             RGBColor[
              0.3002303093342801, 0.42978432673328937`, 0.9405228117202697], 
             UndirectedEdge[41, 48] -> 
             RGBColor[
              0.34329321321312134`, 0.4669781893550724, 0.9432705886491298], 
             UndirectedEdge[57, 70] -> 
             RGBColor[
              0.26485491336994227`, 0.39570968509618687`, 0.9383944675474621],
              UndirectedEdge[39, 44] -> 
             RGBColor[
              0.5365081779106845, 0.6268880178985887, 0.9593203806489492], 
             UndirectedEdge[6, 15] -> 
             RGBColor[
              0.286330742124025, 0.4176171847875644, 0.9396418315932203], 
             UndirectedEdge[6, 40] -> 
             RGBColor[
              0.2502060423578324, 0.3803127928703927, 0.9375602360143851], 
             UndirectedEdge[17, 59] -> 
             RGBColor[
              0.33165561016298184`, 0.45855976870817894`, 0.9424682157250155],
              UndirectedEdge[56, 91] -> 
             RGBColor[
              0.2478234584246726, 0.37780854609209535`, 0.9374245513841087], 
             UndirectedEdge[5, 59] -> 
             RGBColor[
              0.26264124075969747`, 0.39338297482786955`, 0.9382684021671439],
              UndirectedEdge[20, 58] -> 
             RGBColor[
              0.22266134542622565`, 0.3513615699606193, 0.9359916062728575], 
             UndirectedEdge[17, 19] -> 
             RGBColor[
              0.32753691967137427`, 0.45423076386143946`, 0.9422336623945751],
              UndirectedEdge[3, 38] -> 
             RGBColor[
              0.36574906065638857`, 0.4903403736840195, 0.9445582157865146], 
             UndirectedEdge[1, 17] -> 
             RGBColor[
              0.32323856928298944`, 0.4497129250720918, 0.941988877698796], 
             UndirectedEdge[2, 42] -> 
             RGBColor[
              0.5864694187639945, 0.6749492370446291, 0.9607331698161294], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.44521446884155214`, 0.5537197588039671, 0.950811098924118], 
             UndirectedEdge[48, 56] -> 
             RGBColor[
              0.2494153020184852, 0.3794816746379056, 0.9375152045218548], 
             UndirectedEdge[86, 94] -> 
             RGBColor[
              0.5871219393052882, 0.6494624455434448, 0.8460314485072336], 
             UndirectedEdge[23, 30] -> 
             RGBColor[
              0.9025589304514734, 0.5654862789591164, 0.5172300337295237], 
             UndirectedEdge[30, 82] -> 
             RGBColor[
              0.8279231426855904, 0.21563508744640228`, 0.17437253901138755`],
              UndirectedEdge[60, 74] -> 
             RGBColor[
              0.4164700206325886, 0.5346922301902434, 0.9478837701478531], 
             UndirectedEdge[10, 90] -> 
             RGBColor[
              0.2797642211015037, 0.41138031282676635`, 0.9392435305664304], 
             UndirectedEdge[49, 69] -> 
             RGBColor[
              0.5984246385417968, 0.6820634596988412, 0.9631196279753649], 
             UndirectedEdge[25, 100] -> 
             RGBColor[
              0.23058501773817044`, 0.3596898519503145, 0.9364428476890001], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.23295897687627548`, 0.36218503352216574`, 0.9365780411499574],
              UndirectedEdge[31, 51] -> 
             RGBColor[
              0.33046646407782415`, 0.4562153820042676, 0.9424405713085325], 
             UndirectedEdge[37, 50] -> 
             RGBColor[
              0.8586518765861698, 0.8882652786926387, 0.8831610133197494], 
             UndirectedEdge[6, 10] -> 
             RGBColor[
              0.25407458579092124`, 0.3843788772983895, 0.9377805438399023], 
             UndirectedEdge[69, 77] -> 
             RGBColor[
              0.4207942226929865, 0.5388925387892431, 0.9480336136696441], 
             UndirectedEdge[12, 96] -> 
             RGBColor[
              0.4452662078752948, 0.5537741398088749, 0.9508140453855485], 
             UndirectedEdge[12, 41] -> 
             RGBColor[
              0.5175163922375255, 0.6185385423481014, 0.9553377624650727], 
             UndirectedEdge[89, 93] -> 
             RGBColor[
              0.25239151088821565`, 0.3826098588625336, 0.9376846952140795], 
             UndirectedEdge[37, 81] -> 
             RGBColor[
              0.6332310398688609, 0.7118439589227601, 0.9651449338235201], 
             UndirectedEdge[14, 24] -> 
             RGBColor[
              0.8132324483478965, 0.7256778621369495, 0.6085269751651416], 
             UndirectedEdge[52, 67] -> 
             RGBColor[
              0.560139632974118, 0.5514847252323705, 0.6016081426491302], 
             UndirectedEdge[23, 27] -> 
             RGBColor[
              0.6645515668442425, 0.7298696411778459, 0.9061368692979717], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.2386756834212212, 0.36819365456103337`, 0.9369035991305825], 
             UndirectedEdge[23, 81] -> 
             RGBColor[
              0.7636299537302207, 0.8133189149453938, 0.9131041886415987], 
             UndirectedEdge[88, 96] -> 
             RGBColor[
              0.2871462971513761, 0.419139342805837, 0.9396639288766677], 
             UndirectedEdge[77, 95] -> 
             RGBColor[
              0.5017218742687843, 0.6053948342023149, 0.9541830553228445], 
             UndirectedEdge[74, 91] -> 
             RGBColor[
              0.3083282736041498, 0.43639896242150933`, 0.941053431343968], 
             UndirectedEdge[7, 100] -> 
             RGBColor[
              0.27936916838135406`, 0.4105277593101289, 0.939237045621026], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.3593964815136068, 0.4839037453450634, 0.9441876459561919], 
             UndirectedEdge[6, 100] -> 
             RGBColor[
              0.2509928257224536, 0.38113975207155615`, 0.9376050421630586], 
             UndirectedEdge[19, 55] -> 
             RGBColor[
              0.2577051513357447, 0.38819483187714965`, 0.9379872991767397], 
             UndirectedEdge[17, 28] -> 
             RGBColor[
              0.3222279508615301, 0.4486507010342292, 0.9419313244747699], 
             UndirectedEdge[64, 96] -> 
             RGBColor[
              0.28506242993789815`, 0.4169490662396592, 0.9395452557216655], 
             UndirectedEdge[67, 68] -> 
             RGBColor[
              0.49942943344374047`, 0.22113364438203578`, 0.5489338994519259],
              UndirectedEdge[22, 87] -> 
             RGBColor[
              0.875317687150646, 0.9030022552400158, 0.9648194594818615], 
             UndirectedEdge[42, 44] -> 
             RGBColor[
              0.7173501625148713, 0.7791186661105619, 0.9724624182472246], 
             UndirectedEdge[70, 96] -> 
             RGBColor[
              0.28071617400293775`, 0.4123808756834735, 0.9392977428758789], 
             UndirectedEdge[64, 88] -> 
             RGBColor[
              0.2870945581176334, 0.41908496180092925`, 0.9396609824152371], 
             UndirectedEdge[26, 65] -> 
             RGBColor[
              0.2211496303742725, 0.34977266159274634`, 0.9359055163370308], 
             UndirectedEdge[2, 14] -> 
             RGBColor[
              0.6178499772431384, 0.6994639678296142, 0.9638608906173386], 
             UndirectedEdge[11, 72] -> 
             RGBColor[
              0.5328227707106528, 0.3030976591006391, 0.5571968893226393], 
             UndirectedEdge[67, 86] -> 
             RGBColor[
              0.5874876692612337, 0.649846850915762, 0.8460522762871756], 
             UndirectedEdge[40, 90] -> 
             RGBColor[
              0.27589567766841483`, 0.4073142283987696, 0.939023222740913], 
             UndirectedEdge[27, 84] -> 
             RGBColor[
              0.38958595737760626`, 0.5118615079460839, 0.9460450506001336], 
             UndirectedEdge[13, 43] -> 
             RGBColor[
              0.26197969156672996`, 0.39268764468141926`, 0.9382307279192786],
              UndirectedEdge[52, 72] -> 
             RGBColor[
              0.8850921765904433, 0.518767217550283, 0.2236557580064148], 
             UndirectedEdge[10, 53] -> 
             RGBColor[
              0.28749436734384803`, 0.4181352578163585, 0.9397339107644591], 
             UndirectedEdge[15, 40] -> 
             RGBColor[
              0.2798133914717097, 0.41076703602808307`, 0.9392706781151272], 
             UndirectedEdge[21, 68] -> 
             RGBColor[
              0.8602485375600374, 0.3936815385514446, 0.2025698756843444], 
             UndirectedEdge[28, 83] -> 
             RGBColor[
              0.24001916627606623`, 0.36960574022320836`, 0.9369801084916611],
              UndirectedEdge[54, 100] -> 
             RGBColor[
              0.24809701263363243`, 0.37809606891005076`, 0.9374401298916217],
              UndirectedEdge[47, 96] -> 
             RGBColor[
              0.280167857490329, 0.4118045602634469, 0.9392665170616474], 
             UndirectedEdge[47, 51] -> 
             RGBColor[
              0.26797369092262097`, 0.39898771804597, 0.9385720773152693], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.3409913926021096, 0.4697713383713912, 0.9429486479031253], 
             UndirectedEdge[39, 45] -> 
             RGBColor[
              0.5390587638079978, 0.6288805549867408, 0.959574599214613], 
             UndirectedEdge[58, 97] -> 
             RGBColor[
              0.23746265977054243`, 0.3669186897940284, 0.936834519228184], 
             UndirectedEdge[31, 45] -> 
             RGBColor[
              0.5919024457294845, 0.6759664122706829, 0.9628935917366674], 
             UndirectedEdge[6, 26] -> 
             RGBColor[
              0.23839669585582945`, 0.3679004209409733, 0.9368877112014585], 
             UndirectedEdge[41, 91] -> 
             RGBColor[
              0.34170136961930875`, 0.46530506080926215`, 0.9431799355113838],
              UndirectedEdge[8, 22] -> 
             RGBColor[
              0.9622103495532457, 0.9713371210884598, 0.9488522004737234], 
             UndirectedEdge[46, 95] -> 
             RGBColor[
              0.42837295229133143`, 0.5383825235467723, 0.9496367892337401], 
             UndirectedEdge[66, 95] -> 
             RGBColor[
              0.4539596243008821, 0.5640255738806018, 0.9511396869893891], 
             UndirectedEdge[23, 37] -> 
             RGBColor[
              0.8563518073535856, 0.887314140955882, 0.9212791128920343], 
             UndirectedEdge[10, 100] -> 
             RGBColor[
              0.2483440185032272, 0.37835568774007156`, 0.9374541965104828], 
             UndirectedEdge[5, 79] -> 
             RGBColor[
              0.24661518324008325`, 0.37653857226402054`, 0.9373557418998293],
              UndirectedEdge[38, 42] -> 
             RGBColor[
              0.5442088329750422, 0.6400671657429147, 0.9575645899192962], 
             UndirectedEdge[40, 54] -> 
             RGBColor[
              0.24731022926901122`, 0.37726910970888733`, 0.9373953237429482],
              UndirectedEdge[32, 45] -> 
             RGBColor[
              0.5380655132877746, 0.6278365857142659, 0.9595180350668688], 
             UndirectedEdge[41, 60] -> 
             RGBColor[
              0.44984311664774745`, 0.5635983285779962, 0.9500102743152689], 
             UndirectedEdge[88, 91] -> 
             RGBColor[
              0.2714833134368132, 0.40267655383130574`, 0.9387719451254313], 
             UndirectedEdge[47, 57] -> 
             RGBColor[
              0.2643065968573336, 0.3951333696761603, 0.9383632417332306], 
             UndirectedEdge[27, 85] -> 
             RGBColor[
              0.4786656685472922, 0.5846284033631004, 0.952933955527739], 
             UndirectedEdge[69, 95] -> 
             RGBColor[
              0.5047239977858227, 0.6079951227016581, 0.9543743479786766], 
             UndirectedEdge[36, 72] -> 
             RGBColor[
              0.5053823219778242, 0.27425600765749925`, 0.5556341963618108], 
             UndirectedEdge[6, 65] -> 
             RGBColor[
              0.23947632752859074`, 0.3690351822816471, 0.9369491946280504], 
             UndirectedEdge[49, 77] -> 
             RGBColor[
              0.5954225150247585, 0.679463171199498, 0.9629283353195328], 
             UndirectedEdge[2, 62] -> 
             RGBColor[
              0.441389916904741, 0.555009569915901, 0.9498217258326898], 
             UndirectedEdge[22, 66] -> 
             RGBColor[
              0.6418930093726982, 0.712187405219036, 0.9458895209538087], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.37246108295649283`, 0.49696932160080975`, 0.9449560466299856],
              UndirectedEdge[73, 88] -> 
             RGBColor[
              0.2704116074619085, 0.40155012290159753`, 0.9387109130556073], 
             UndirectedEdge[8, 21] -> 
             RGBColor[
              0.9330401773606567, 0.8125446192441054, 0.5943013473777097], 
             UndirectedEdge[31, 75] -> 
             RGBColor[
              0.3329280335215753, 0.45880264756216715`, 0.9425807540467885], 
             UndirectedEdge[4, 30] -> 
             RGBColor[
              0.8285882397682693, 0.2207473150712718, 0.17500943672888053`], 
             UndirectedEdge[48, 91] -> 
             RGBColor[
              0.2553800451363277, 0.3857509978413148, 0.9378548878183692], 
             UndirectedEdge[19, 28] -> 
             RGBColor[
              0.26139593816194606`, 0.39207408284088785`, 0.938197484026462], 
             UndirectedEdge[28, 66] -> 
             RGBColor[
              0.28917728429612277`, 0.42002387483007575`, 0.9398253652267791],
              UndirectedEdge[3, 29] -> 
             RGBColor[
              0.30975389821880644`, 0.4418401783792823, 0.9409902535505699], 
             UndirectedEdge[22, 82] -> 
             RGBColor[
              0.8994987825942162, 0.6299538973723429, 0.5667734179172785], 
             UndirectedEdge[49, 82] -> 
             RGBColor[
              0.8052660382783743, 0.5558604030310919, 0.5807688639495472], 
             UndirectedEdge[23, 84] -> 
             RGBColor[
              0.7117851117483094, 0.7707809637467538, 0.909146549012275], 
             UndirectedEdge[65, 100] -> 
             RGBColor[
              0.2337457602408967, 0.3630119927233292, 0.9366228472986309], 
             UndirectedEdge[53, 85] -> 
             RGBColor[
              0.46927094036852307`, 0.5764911620074185, 0.9523353317556198], 
             UndirectedEdge[59, 97] -> 
             RGBColor[
              0.26290465706698973`, 0.3936598420683923, 0.9382834033361547], 
             UndirectedEdge[17, 98] -> 
             RGBColor[
              0.34163351398872654`, 0.46904717826467845`, 0.9430364425869058],
              UndirectedEdge[61, 68] -> 
             RGBColor[0.49812300000000004`, 0.2197605, 0.5488595000000001], 
             UndirectedEdge[28, 55] -> 
             RGBColor[
              0.2523961825259005, 0.38261476904993935`, 0.9376849612569346], 
             UndirectedEdge[9, 36] -> 
             RGBColor[
              0.5653509190664274, 0.575380095696193, 0.6066312511494145], 
             UndirectedEdge[20, 59] -> 
             RGBColor[
              0.24810334272267293`, 0.37810272223498315`, 0.9374404903808281],
              UndirectedEdge[48, 57] -> 
             RGBColor[
              0.25518176821789507`, 0.38554259622855935`, 0.9378435962411888],
              UndirectedEdge[1, 46] -> 
             RGBColor[
              0.26460123070803143`, 0.39544304853410883`, 0.9383800206951561],
              UndirectedEdge[5, 66] -> 
             RGBColor[
              0.2863038964022665, 0.41700376197031797`, 0.9396617300370205], 
             UndirectedEdge[64, 74] -> 
             RGBColor[
              0.32393951828497003`, 0.45280737039113284`, 0.9419424686337738],
              UndirectedEdge[55, 79] -> 
             RGBColor[
              0.24579778430773802`, 0.37567943416004, 0.9373091922398655], 
             UndirectedEdge[32, 51] -> 
             RGBColor[
              0.27662953163611426`, 0.40808555544785063`, 0.9390650146387339],
              UndirectedEdge[64, 73] -> 
             RGBColor[
              0.26832774024843065`, 0.39935984633541977`, 0.938592239900605], 
             UndirectedEdge[35, 38] -> 
             RGBColor[
              0.3673467656616922, 0.49201966294494187`, 0.9446492027229738], 
             UndirectedEdge[71, 87] -> 
             RGBColor[
              0.5699101563836958, 0.656683392162545, 0.9615914735757531], 
             UndirectedEdge[82, 87] -> 
             RGBColor[
              0.8132980502396094, 0.5621350718207605, 0.5815694198384238], 
             UndirectedEdge[5, 77] -> 
             RGBColor[
              0.33406614637016885`, 0.458373022292031, 0.9427050983704759], 
             UndirectedEdge[57, 64] -> 
             RGBColor[
              0.2692011693049027, 0.4002778756523726, 0.9386419803932486], 
             UndirectedEdge[63, 97] -> 
             RGBColor[
              0.23486172681819156`, 0.36418494435243376`, 0.9366863999442832],
              UndirectedEdge[41, 93] -> 
             RGBColor[
              0.34493630114672413`, 0.468705178951081, 0.9433641600762177], 
             UndirectedEdge[9, 61] -> 
             RGBColor[
              0.565154574148669, 0.575173724738642, 0.6066200695968145], 
             UndirectedEdge[17, 46] -> 
             RGBColor[
              0.32973159379600026`, 0.45653750551679784`, 0.942358645839243], 
             UndirectedEdge[25, 54] -> 
             RGBColor[
              0.2334197719370433, 0.36266935834712705`, 0.9366042827469828], 
             UndirectedEdge[59, 77] -> 
             RGBColor[
              0.3463671935654768, 0.47130220282573854`, 0.9434056248104801], 
             UndirectedEdge[66, 77] -> 
             RGBColor[
              0.3700298492080458, 0.49492298996818684`, 0.9447989526803566], 
             UndirectedEdge[7, 27] -> 
             RGBColor[
              0.327914245400744, 0.45844457074209777`, 0.9421153836471216], 
             UndirectedEdge[61, 92] -> 
             RGBColor[
              0.182593161061527, 0.30924736772370176`, 0.9337097824488547], 
             UndirectedEdge[77, 87] -> 
             RGBColor[
              0.6034545269859937, 0.6857378399891666, 0.9637288912084094], 
             UndirectedEdge[28, 79] -> 
             RGBColor[
              0.24948857113393946`, 0.3795586851237783, 0.937519377089588], 
             UndirectedEdge[5, 28] -> 
             RGBColor[
              0.25321358145824574`, 0.3834739071539198, 0.9377315109168982], 
             UndirectedEdge[56, 88] -> 
             RGBColor[
              0.26551857031897064`, 0.39640723062789657`, 0.9384322618289168],
              UndirectedEdge[25, 26] -> 
             RGBColor[
              0.21798888787154624`, 0.3464505208197316, 0.9357255167274], 
             UndirectedEdge[9, 67] -> 
             RGBColor[
              0.5664610075924095, 0.5765468691206779, 0.6066944690487404], 
             UndirectedEdge[32, 44] -> 
             RGBColor[
              0.5355149273904612, 0.6258440486261139, 0.959263816501205], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.5412488824777958, 0.4795214095089955, 0.5872225572369445], 
             UndirectedEdge[79, 83] -> 
             RGBColor[
              0.23342076805790374`, 0.3626704053333091, 0.9366043394745922], 
             UndirectedEdge[60, 93] -> 
             RGBColor[
              0.3651648800983693, 0.48577125520605746`, 0.9447787980493423], 
             UndirectedEdge[5, 63] -> 
             RGBColor[
              0.2345983105108993, 0.3639080771119111, 0.9366713987752724], 
             UndirectedEdge[19, 66] -> 
             RGBColor[
              0.2944862531059669, 0.425603937657286, 0.9401277031465842], 
             UndirectedEdge[8, 86] -> 
             RGBColor[
              0.9781688756181125, 0.981703287226387, 0.853067848528615], 
             UndirectedEdge[4, 37] -> 
             RGBColor[
              0.7823811166703816, 0.5425751770680375, 0.5790585158913912], 
             UndirectedEdge[9, 92] -> 
             RGBColor[
              0.5688207352101959, 0.5790270924623439, 0.606828852045669], 
             UndirectedEdge[3, 42] -> 
             RGBColor[
              0.4777439253661703, 0.5816237909960889, 0.9533615359463858], 
             UndirectedEdge[7, 90] -> 
             RGBColor[
              0.31078937097963055`, 0.4435523843968237, 0.9410263796769736], 
             UndirectedEdge[35, 62] -> 
             RGBColor[
              0.3342621285122205, 0.46336341312828305`, 0.9425410788994055], 
             UndirectedEdge[20, 79] -> 
             RGBColor[
              0.2320772852030587, 0.3612583196711341, 0.9365278301135136], 
             UndirectedEdge[31, 78] -> 
             RGBColor[
              0.6972006995541824, 0.7564641060518543, 0.846300355646884], 
             UndirectedEdge[13, 81] -> 
             RGBColor[
              0.40693947919321677`, 0.5212540372250012, 0.947924692865475], 
             UndirectedEdge[18, 80] -> 
             RGBColor[
              0.2419836729170215, 0.3716705612597674, 0.9370919842386365], 
             UndirectedEdge[90, 100] -> 
             RGBColor[
              0.27668246103303606`, 0.408141187599933, 0.9390680288895865], 
             UndirectedEdge[67, 92] -> 
             RGBColor[
              0.1838995945052675, 0.31062051210573755`, 0.9337841819007806], 
             UndirectedEdge[55, 66] -> 
             RGBColor[
              0.28548649746992133`, 0.41614462386633744`, 0.9396151803770567],
              UndirectedEdge[89, 91] -> 
             RGBColor[
              0.24915657936080024`, 0.3792097407207148, 0.9375004706492456], 
             UndirectedEdge[46, 55] -> 
             RGBColor[
              0.25989982546037066`, 0.390501573532508, 0.9381122826214077], 
             UndirectedEdge[41, 64] -> 
             RGBColor[
              0.3573126143001289, 0.48171346877888566`, 0.9440689728011896], 
             UndirectedEdge[28, 46] -> 
             RGBColor[
              0.2635906122865721, 0.39438082449624623`, 0.93832246747113], 
             UndirectedEdge[35, 53] -> 
             RGBColor[
              0.3130212595870627, 0.4449656400624253, 0.9411876295140573], 
             UndirectedEdge[35, 90] -> 
             RGBColor[
              0.3052911133447183, 0.4382106950728331, 0.9406972493160285], 
             UndirectedEdge[5, 58] -> 
             RGBColor[
              0.23719924346325016`, 0.36664182255350575`, 0.9368195180591732],
              UndirectedEdge[76, 85] -> 
             RGBColor[
              0.8046624308881429, 0.8443107387872784, 0.7944004381139487], 
             UndirectedEdge[34, 77] -> 
             RGBColor[
              0.5013559504056586, 0.6050977607255472, 0.9541542484559159], 
             UndirectedEdge[49, 71] -> 
             RGBColor[
              0.5618781444224608, 0.6504087233728764, 0.9607909176868766]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 25 -> 
             RGBColor[
              0.21590777704158132`, 0.3442631413873908, 0.9356070005443611], 
             55 -> RGBColor[
              0.2487053956996991, 0.3787355180862011, 0.9374747764072122], 90 -> 
             RGBColor[
              0.30810266363131256`, 0.4411658126866278, 0.9408573629455341], 
             27 -> RGBColor[
              0.3423524124735395, 0.470950185377176, 0.9430353708858302], 15 -> 
             RGBColor[
              0.3159380912379023, 0.44807142794525473`, 0.9413522736939626], 
             98 -> RGBColor[
              0.2948980956064947, 0.4272869744745761, 0.9401053823309286], 38 -> 
             RGBColor[
              0.43221396826526043`, 0.5487837484308453, 0.9487612697594249], 
             99 -> RGBColor[
              0.40338473147108844`, 0.5238133125193064, 0.9469242962835934], 
             71 -> RGBColor[
              0.3507033579713525, 0.4781833546366567, 0.9435674857484997], 41 -> 
             RGBColor[
              0.4296145376961023, 0.5465322523230198, 0.9485956363421444], 75 -> 
             RGBColor[
              0.26564897472372695`, 0.3965442939254123, 0.9384396881668516], 
             64 -> RGBColor[
              0.2850106909041555, 0.4168946852347515, 0.9395423092602349], 63 -> 
             RGBColor[
              0.21885642745740908`, 0.34736235992966014`, 0.9357749218234052],
              85 -> RGBColor[
              0.6149789246210449, 0.6983066213490248, 0.9628325401696478], 3 -> 
             RGBColor[
              0.29928415304751665`, 0.4318969989371937, 0.9403551618136042], 
             86 -> RGBColor[
              0.9934354716349865, 0.9915534130674525, 0.7584547536704994], 94 -> 
             RGBColor[
              0.18080840697558995`, 0.30737147801943704`, 0.9336081433439677],
              61 -> RGBColor[0.178927, 0.305394, 0.933501], 84 -> 
             RGBColor[
              0.4368195022816731, 0.5527728305149917, 0.9490547303144369], 76 -> 
             RGBColor[
              0.9943459371552411, 0.990314856225532, 0.6259683360582495], 21 -> 
             RGBColor[
              0.9031780751200748, 0.6532360771028892, 0.2409217513686888], 87 -> 
             RGBColor[
              0.789116954796039, 0.8351834296884333, 0.9796154614030067], 95 -> 
             RGBColor[
              0.5856516493616206, 0.6744974181147299, 0.9605237896318769], 72 -> 
             RGBColor[
              0.8314449541201315, 0.24270527339989661`, 0.17774502961842129`],
              42 -> RGBColor[
              0.6562036976848239, 0.731350583054984, 0.9663679100791674], 66 -> 
             RGBColor[
              0.32226759924014353`, 0.45355372964647384`, 0.9417555843469012],
              1 -> RGBColor[
              0.2581082061950206, 0.38861846808940276`, 0.9380102525547092], 
             24 -> RGBColor[
              0.9075000820526815, 0.6709756796489449, 0.2444305986486977], 54 -> 
             RGBColor[
              0.2509317668325053, 0.3810755753068633, 0.9376015649496046], 4 -> 
             RGBColor[
              0.8388093398485373, 0.29931116920282663`, 0.1847971737088267], 
             7 -> RGBColor[
              0.3134760783279485, 0.4459389561070196, 0.9411953964084129], 
             100 -> RGBColor[
              0.24526225843475957`, 0.3751165625132382, 0.937278694833639], 
             12 -> RGBColor[
              0.6054182467789488, 0.6905448323731828, 0.9620798885880011], 65 -> 
             RGBColor[
              0.2222292620470338, 0.35090742293342014`, 0.9359669997636226], 
             8 -> RGBColor[
              0.9629022796012385, 0.9718531613853215, 0.9476809433867306], 57 -> 
             RGBColor[
              0.25339164770564987`, 0.38366106606999373`, 0.9377416515262625],
              74 -> RGBColor[
              0.3628683456657846, 0.48872005554751413`, 0.9443426280073127], 
             37 -> RGBColor[
              0.7259528934922258, 0.7858391849332483, 0.9733198580739556], 43 -> 
             RGBColor[
              0.25058961099252225`, 0.3807159478251078, 0.9375820796806917], 
             39 -> RGBColor[
              0.2945197284764503, 0.42688928663103776`, 0.9400838348826166], 
             58 -> RGBColor[
              0.22405829336211083`, 0.3528298508128494, 0.9360711603912069], 
             11 -> RGBColor[
              0.23420058730117388`, 0.3634900448013817, 0.9366487490268572], 
             51 -> RGBColor[
              0.26072583583622466`, 0.3913697628096132, 0.9381593226903397], 
             48 -> RGBColor[
              0.2569718887301403, 0.38742412638712503`, 0.9379455409561153], 
             20 -> RGBColor[
              0.22126439749034046`, 0.3498932891083892, 0.9359120521545081], 
             33 -> RGBColor[
              0.26822653985771944`, 0.399253478308307, 0.9385864766880666], 
             45 -> RGBColor[
              0.7835977991395453, 0.8308718233424438, 0.9790653635466094], 23 -> 
             RGBColor[
              0.9867507212149456, 0.9887890969785158, 0.869238367710113], 22 -> 
             RGBColor[
              0.9615184195052529, 0.9708210807915982, 0.9500234575607163], 2 -> 
             RGBColor[
              0.5167351398431651, 0.6185478910342742, 0.9550984295530915], 60 -> 
             RGBColor[
              0.4700716955993926, 0.5806644048329727, 0.9514249122883933], 16 -> 
             RGBColor[
              0.23643110434042502`, 0.36583445963258315`, 0.9367757736724883],
              79 -> RGBColor[
              0.24289017291577697`, 0.372623350233879, 0.937143608072519], 89 -> 
             RGBColor[
              0.24452495717908534`, 0.374341612145925, 0.9372367066178678], 
             36 -> RGBColor[
              0.17931968983551683`, 0.3058067419151018, 0.9335233631052001], 
             52 -> RGBColor[
              0.938739399060755, 0.7948291617006693, 0.26956648639440833`], 
             32 -> RGBColor[
              0.2925332274360039, 0.424801348086088, 0.9399707065871281], 31 -> 
             RGBColor[
              0.40020709231942364`, 0.521061001198922, 0.9467218199267253], 
             68 -> RGBColor[0.817319, 0.134127, 0.164218], 73 -> 
             RGBColor[
              0.2516447895927058, 0.3818250074360881, 0.9376421705409753], 82 -> 
             RGBColor[
              0.8374791456831797, 0.2890867139530876, 0.18352337827384074`], 
             35 -> RGBColor[
              0.30247956305812407`, 0.4352555774590384, 0.9405371356865229], 
             88 -> RGBColor[
              0.28917842533111127`, 0.421275238367107, 0.9397796555702393], 
             50 -> RGBColor[
              0.9913508596801138, 0.9906913724520291, 0.7930021685655431], 19 -> 
             RGBColor[
              0.2667049069717902, 0.39765414566809815`, 0.9384998219462671], 
             17 -> RGBColor[
              0.3883689323709583, 0.5108073820547808, 0.9459675028428829], 96 -> 
             RGBColor[
              0.2851141689716408, 0.417003447244567, 0.939548202183096], 14 -> 
             RGBColor[
              0.7189648146431117, 0.780380044624954, 0.9726233516815856], 5 -> 
             RGBColor[
              0.2503401935643895, 0.38045379429416204`, 0.9375678757271396], 
             34 -> RGBColor[
              0.5849198016353689, 0.6739032711611944, 0.9604661758980197], 97 -> 
             RGBColor[
              0.25086702617897405`, 0.38100752877520744`, 0.9375978780651611],
              93 -> RGBColor[
              0.26025806459734596`, 0.3908781055791422, 0.9381326838102911], 
             81 -> RGBColor[
              0.5405091862454959, 0.6378487329122717, 0.9569700095730845], 69 -> 
             RGBColor[
              0.42379634621002477`, 0.5414928272885864, 0.9482249063254762], 
             9 -> RGBColor[
              0.9513821482973379, 0.8449534494772841, 0.27973913919362886`], 
             13 -> RGBColor[
              0.2733697721409376, 0.40465934153773064`, 0.9388793761578655], 
             30 -> RGBColor[
              0.8183671396880012, 0.14218346093971695`, 0.1652216997489344], 
             59 -> RGBColor[
              0.2749422879550054, 0.4063121553615771, 0.9389689286071481], 28 -> 
             RGBColor[
              0.25608696935210196`, 0.3864940200136776, 0.9378951461066569], 
             80 -> RGBColor[
              0.26918119100492044`, 0.4002568771923939, 0.9386408426586199], 
             47 -> RGBColor[
              0.27522154600901727`, 0.40660567328232683`, 0.9389848319401988],
              62 -> RGBColor[
              0.3660446939663169, 0.4914712487975277, 0.9445450221122881], 77 -> 
             RGBColor[
              0.4177920991759482, 0.5362922502898999, 0.947842321013812], 78 -> 
             RGBColor[
              0.9941943067889412, 0.9918672109047867, 0.7458788913670427], 40 -> 
             RGBColor[
              0.24368869170551716`, 0.37346264411091135`, 0.937189082536292], 
             67 -> RGBColor[
              0.181539866887481, 0.30814028876407157`, 0.9336497989038519], 
             56 -> RGBColor[
              0.24185871530683006`, 0.3715392228886861, 0.9370848680875943], 
             10 -> RGBColor[
              0.25142577857169485`, 0.38159481296690484`, 0.9376296981873266],
              53 -> RGBColor[
              0.3235629561160013, 0.45467570266581214`, 0.9418381233415918], 
             26 -> RGBColor[
              0.2200699987015112, 0.3486379002520725, 0.9358440329104389], 18 -> 
             RGBColor[
              0.21478615482912253`, 0.34308424532714094`, 0.935543125818653], 
             29 -> RGBColor[
              0.32022364339009624`, 0.4517833578213709, 0.9416253452875354], 
             92 -> 
             RGBColor[
              0.18625932212305402`, 0.3131007354474035, 0.9339185648977094], 
             46 -> RGBColor[
              0.2710942552210422, 0.40226762897881485`, 0.9387497888356031], 
             49 -> RGBColor[
              0.773052930873569, 0.822634092109096, 0.9780143496252536], 83 -> 
             RGBColor[
              0.2239513632000305, 0.3527174604327391, 0.9360650708766655], 70 -> 
             RGBColor[
              0.27631817903423467`, 0.40775830412238, 0.9390472835686617], 44 -> 
             RGBColor[
              0.7784966273449186, 0.8268867491661398, 0.9785569264152818], 91 -> 
             RGBColor[
              0.25378820154251513`, 0.3840778692955045, 0.9377642346806232], 
             6 -> RGBColor[
              0.2567233930101477, 0.3871629416298741, 
               0.9379313894924781]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9lHs01Akbx4dhXCZmRjNjDGZ+vxEpY003Oez6fWm7uFSIpJWyrGvrtqF9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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 13}], {
             RGBColor[
             0.2657389891679791, 0.3966389048135667, 0.9384448143562873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 17}], {
             RGBColor[
             0.32323856928298944`, 0.4497129250720918, 0.941988877698796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 19}], {
             RGBColor[
             0.2624065565834054, 0.39313630687875045`, 0.9382550372504881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 27}], {
             RGBColor[
             0.3002303093342801, 0.42978432673328937`, 0.9405228117202697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 43}], {
             RGBColor[
             0.25434890859377146`, 0.3846672079572553, 0.9377961661177004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 46}], {
             RGBColor[
             0.26460123070803143`, 0.39544304853410883`, 0.9383800206951561]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 55}], {
             RGBColor[
             0.25340680094735984`, 0.3836769930878019, 0.9377425144809607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 3}], {
             RGBColor[
             0.4080096464453409, 0.5252224449857339, 0.947726795683348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 14}], {
             RGBColor[
             0.6178499772431384, 0.6994639678296142, 0.9638608906173386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 29}], {
             RGBColor[
             0.41847939161663067`, 0.5351656244278226, 0.9483618874203135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 33}], {
             RGBColor[
             0.39248083985044224`, 0.5089006846712906, 0.946842453120579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 38}], {
             RGBColor[
             0.4744745540542128, 0.5836658197325597, 0.9519298496562583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 42}], {
             RGBColor[
             0.5864694187639945, 0.6749492370446291, 0.9607331698161294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 44}], {
             RGBColor[
             0.6476158835940419, 0.7227173201002071, 0.9668276779841867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 62}], {
             RGBColor[
             0.441389916904741, 0.555009569915901, 0.9498217258326898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 78}], {
             RGBColor[
             0.7554647233160532, 0.8052075509695305, 0.8504886604600671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 16}], {
             RGBColor[
             0.26785762869397084`, 0.3988657292848884, 0.9385654677430463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 29}], {
             RGBColor[
             0.30975389821880644`, 0.4418401783792823, 0.9409902535505699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 33}], {
             RGBColor[
             0.283755346452618, 0.41557523862275036`, 0.9394708192508354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 38}], {
             RGBColor[
             0.36574906065638857`, 0.4903403736840195, 0.9445582157865146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 42}], {
             RGBColor[
             0.4777439253661703, 0.5816237909960889, 0.9533615359463858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 62}], {
             RGBColor[
             0.3326644235069168, 0.4616841238673607, 0.9424500919629462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 9}], {
             RGBColor[
             0.8950957440729377, 0.5721323093400554, 0.23226815645122778`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 23}], {
             RGBColor[
             0.9127800305317415, 0.6440501330906712, 0.5270177707094699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 24}], {
             RGBColor[
             0.8731547109506095, 0.48514342442588576`, 0.2146138861787622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 30}], {
             RGBColor[
             0.8285882397682693, 0.2207473150712718, 0.17500943672888053`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 36}], {
             RGBColor[
             0.5090645148420271, 0.3025589555589642, 0.5591602684070134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 37}], {
             RGBColor[
             0.7823811166703816, 0.5425751770680375, 0.5790585158913912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 50}], {
             RGBColor[
             0.9150800997643256, 0.6450012708274279, 0.48889967113718485`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 76}], {
             RGBColor[
             0.9165776385018892, 0.6448130127141793, 0.40538275488353814`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 86}], {
             RGBColor[
             0.9161224057417618, 0.6454322911351396, 0.4716259636896631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 94}], {
             RGBColor[
             0.5098088734120636, 0.30334132361113186`, 0.5592026585263972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 20}], {
             RGBColor[
             0.23580229552736498`, 0.3651735417012756, 0.9367399639408238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 28}], {
             RGBColor[
             0.25321358145824574`, 0.3834739071539198, 0.9377315109168982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 58}], {
             RGBColor[
             0.23719924346325016`, 0.36664182255350575`, 0.9368195180591732]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.26264124075969747`, 0.39338297482786955`, 0.9382684021671439]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 63}], {
             RGBColor[
             0.2345983105108993, 0.3639080771119111, 0.9366713987752724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 66}], {
             RGBColor[
             0.2863038964022665, 0.41700376197031797`, 0.9396617300370205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 69}], {
             RGBColor[
             0.3370682698872072, 0.4609733107913742, 0.942896391026308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[
             0.33406614637016885`, 0.458373022292031, 0.9427050983704759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 79}], {
             RGBColor[
             0.24661518324008325`, 0.37653857226402054`, 0.9373557418998293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[
             0.23714577838221002`, 0.3665856273634506, 0.9368164733019025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 97}], {
             RGBColor[
             0.2506036098716818, 0.3807306615346847, 0.9375828768961504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 7}], {
             RGBColor[
             0.2850997356690481, 0.41655094886844685`, 0.9395633929504454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 10}], {
             RGBColor[
             0.25407458579092124`, 0.3843788772983895, 0.9377805438399023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 15}], {
             RGBColor[
             0.286330742124025, 0.4176171847875644, 0.9396418315932203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 25}], {
             RGBColor[
             0.2363155850258645, 0.36571304150863243`, 0.9367691950184196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 26}], {
             RGBColor[
             0.23839669585582945`, 0.3679004209409733, 0.9368877112014585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 35}], {
             RGBColor[
             0.2796014780341359, 0.41120925954445625`, 0.9392342625895005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 40}], {
             RGBColor[
             0.2502060423578324, 0.3803127928703927, 0.9375602360143851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.2901431745630745, 0.4209193221478431, 0.939884756417035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 65}], {
             RGBColor[
             0.23947632752859074`, 0.3690351822816471, 0.9369491946280504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 90}], {
             RGBColor[
             0.2824130283207301, 0.41416437715825094`, 0.9393943762190061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 100}], {
             RGBColor[
             0.2509928257224536, 0.38113975207155615`, 0.9376050421630586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 13}], {
             RGBColor[
             0.293422925234443, 0.42529914882237513`, 0.9400373862831393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 25}], {
             RGBColor[
             0.2646919276847649, 0.3951010487472052, 0.9384011984763869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 27}], {
             RGBColor[
             0.327914245400744, 0.45844457074209777`, 0.9421153836471216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 37}], {
             RGBColor[
             0.5197144859100872, 0.615889070520134, 0.9572576272411842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 40}], {
             RGBColor[
             0.2785823850167328, 0.4097008001089655, 0.9391922394723524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 53}], {
             RGBColor[
             0.3185195172219749, 0.4503073293864159, 0.9415167598750023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.28220392258022686`, 0.41350726570694146`, 0.9393984806790088]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 65}], {
             RGBColor[
             0.26785267018749115`, 0.3984231895202199, 0.9385811980860177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 81}], {
             RGBColor[
             0.42699263228672224`, 0.5418938445096457, 0.9490827029907487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.3751477903048108, 0.49935589331100566`, 0.9451250633614249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 85}], {
             RGBColor[
             0.46422750147449665`, 0.5721227887280222, 0.9520139682890303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 90}], {
             RGBColor[
             0.31078937097963055`, 0.4435523843968237, 0.9410263796769736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 100}], {
             RGBColor[
             0.27936916838135406`, 0.4105277593101289, 0.939237045621026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 17}], {
             RGBColor[
             0.6756356059860984, 0.7413302717200512, 0.9468242231148067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.9330401773606567, 0.8125446192441054, 0.5943013473777097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 22}], {
             RGBColor[
             0.9622103495532457, 0.9713371210884598, 0.9488522004737234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 30}], {
             RGBColor[
             0.8906347096446199, 0.5570183111625192, 0.5564513215678325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 49}], {
             RGBColor[
             0.8679776052374037, 0.8972436267472088, 0.9628476465059921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 69}], {
             RGBColor[
             0.6933493129056316, 0.7566729943369539, 0.9479529248561034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 77}], {
             RGBColor[
             0.6903471893885933, 0.7540727058376107, 0.9477616322002713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.9001907126422091, 0.6304699376692046, 0.5656021608302857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 86}], {
             RGBColor[
             0.9781688756181125, 0.981703287226387, 0.853067848528615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 87}], {
             RGBColor[
             0.8760096171986388, 0.9035182955368775, 0.9636482023948687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 95}], {
             RGBColor[
             0.7742769644814296, 0.8231752897500257, 0.9541023665093038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 99}], {
             RGBColor[
             0.6831435055361634, 0.747833236952314, 0.947302619835162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.5927913677992559, 0.604221747139333, 0.6081939441102431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 21}], {
             RGBColor[
             0.9272801117087064, 0.7490947632900866, 0.26033044528115884`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 30}], {
             RGBColor[
             0.8848746439926696, 0.49356845520850057`, 0.2224804194712816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 36}], {
             RGBColor[
             0.5653509190664274, 0.575380095696193, 0.6066312511494145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 61}], {
             RGBColor[
             0.565154574148669, 0.575173724738642, 0.6066200695968145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 67}], {
             RGBColor[
             0.5664610075924095, 0.5765468691206779, 0.6066944690487404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 68}], {
             RGBColor[
             0.884350574148669, 0.48954022473864206`, 0.22197856959681445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 72}], {
             RGBColor[
             0.8914135512087347, 0.5438293614385904, 0.22874208440602506`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 82}], {
             RGBColor[
             0.8944306469902588, 0.5670200817151858, 0.2316312587337348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 86}], {
             RGBColor[
             0.9724088099661622, 0.9182534312723682, 0.5190969464320642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 92}], {
             RGBColor[
             0.5688207352101959, 0.5790270924623439, 0.606828852045669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 94}], {
             RGBColor[
             0.566095277636464, 0.5761624637483606, 0.6066736412687983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.28368193490479854`, 0.4148331204560798, 0.9394909859406446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 26}], {
             RGBColor[
             0.235747888636603, 0.36511635660948866`, 0.9367368655488828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 35}], {
             RGBColor[
             0.2769526708149095, 0.4084251952129716, 0.9390834169369247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 40}], {
             RGBColor[
             0.247557235138606, 0.37752872853890806`, 0.9374093903618093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 53}], {
             RGBColor[
             0.28749436734384803`, 0.4181352578163585, 0.9397339107644591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 65}], {
             RGBColor[
             0.23682752030936433`, 0.3662511179501625, 0.9367983489754745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 90}], {
             RGBColor[
             0.2797642211015037, 0.41138031282676635`, 0.9392435305664304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 100}], {
             RGBColor[
             0.2483440185032272, 0.37835568774007156`, 0.9374541965104828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 36}], {
             RGBColor[
             0.20676013856834535`, 0.33464839335824176`, 0.9350860560660287]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 52}], {
             RGBColor[
             0.5864699931809645, 0.5791596032510256, 0.6031076177106328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 61}], {
             RGBColor[
             0.20656379365058694`, 0.3344420224006909, 0.9350748745134286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 67}], {
             RGBColor[
             0.20787022709432745`, 0.3358151667827266, 0.9351492739653546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 68}], {
             RGBColor[
             0.5257597936505869, 0.24880852240069085`, 0.5504333745134287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 72}], {
             RGBColor[
             0.5328227707106528, 0.3030976591006391, 0.5571968893226393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 92}], {
             RGBColor[
             0.21022995471211395`, 0.3382953901243926, 0.9352836569622833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 94}], {
             RGBColor[
             0.20750449713838193`, 0.3354307614104094, 0.9351284461854125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 41}], {
             RGBColor[
             0.5175163922375255, 0.6185385423481014, 0.9553377624650727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 52}], {
             RGBColor[
             0.7720788229198519, 0.7426869970369261, 0.6158231874912047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 60}], {
             RGBColor[
             0.5377449711891708, 0.6356046186030777, 0.9567524004381972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.44521446884155214`, 0.5537197588039671, 0.950811098924118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 74}], {
             RGBColor[
             0.48414329622236674`, 0.5896324439603484, 0.9532112582976568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 88}], {
             RGBColor[
             0.44729833605503005`, 0.5559100353701449, 0.9509297720791202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 96}], {
             RGBColor[
             0.4452662078752948, 0.5537741398088749, 0.9508140453855485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 27}], {
             RGBColor[
             0.30786109230723857`, 0.43780476345745334`, 0.9409573735218479]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 43}], {
             RGBColor[
             0.26197969156672996`, 0.39268764468141926`, 0.9382307279192786]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 54}], {
             RGBColor[
             0.26215076948672145`, 0.392867458422297, 0.938240470553735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 81}], {
             RGBColor[
             0.40693947919321677`, 0.5212540372250012, 0.947924692865475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 84}], {
             RGBColor[
             0.35509463721130535`, 0.4787160860263612, 0.9439670532361513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 85}], {
             RGBColor[
             0.44417434838099124`, 0.5514829814433777, 0.9508559581637567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 15}], {
             RGBColor[
             0.517451452940507, 0.6142257362851044, 0.9569878126877741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 24}], {
             RGBColor[
             0.8132324483478965, 0.7256778621369495, 0.6085269751651416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 35}], {
             RGBColor[
             0.5107221888506179, 0.6078178110419963, 0.9565802436840543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 38}], {
             RGBColor[
             0.5755893914541861, 0.6645818965278997, 0.9606923107205052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 42}], {
             RGBColor[
             0.6875842561639678, 0.755865313839969, 0.9694956308803766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 53}], {
             RGBColor[
             0.5212638853795565, 0.6175278736453831, 0.9572307375115887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 62}], {
             RGBColor[
             0.5425047543047143, 0.6359256467112409, 0.9585841868969369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 76}], {
             RGBColor[
             0.8566553758991764, 0.885347450425243, 0.7992958438699176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 35}], {
             RGBColor[
             0.3092088271480132, 0.4416635027021466, 0.9409447046902427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 38}], {
             RGBColor[
             0.3740760297515814, 0.49842758818805, 0.9450567717266938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 40}], {
             RGBColor[
             0.2798133914717097, 0.41076703602808307`, 0.9392706781151272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 53}], {
             RGBColor[
             0.3197505236769518, 0.4513735653055334, 0.9415951985177772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.3409913926021096, 0.4697713383713912, 0.9429486479031253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 90}], {
             RGBColor[
             0.3120203774346074, 0.44461862031594124`, 0.9411048183197483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 100}], {
             RGBColor[
             0.28060017483633093`, 0.41159399522924645`, 0.9393154842638007]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 29}], {
             RGBColor[
             0.27832737386526063`, 0.40880890872697706`, 0.9392005594800119]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.25232882209907226`, 0.38254396897044507`, 0.9376811251802775]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 62}], {
             RGBColor[
             0.30123789915337096`, 0.4286528542150554, 0.9406603978923882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 19}], {
             RGBColor[
             0.32753691967137427`, 0.45423076386143946`, 0.9422336623945751]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 22}], {
             RGBColor[
             0.6749436759381056, 0.7408142314231896, 0.9479954802017996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 28}], {
             RGBColor[
             0.3222279508615301, 0.4486507010342292, 0.9419313244747699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 46}], {
             RGBColor[
             0.32973159379600026`, 0.45653750551679784`, 0.942358645839243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 55}], {
             RGBColor[
             0.3185371640353287, 0.44477145007049096`, 0.9417211396250476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 59}], {
             RGBColor[
             0.33165561016298184`, 0.45855976870817894`, 0.9424682157250155]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 66}], {
             RGBColor[
             0.3553182658055509, 0.48218055585062736`, 0.943861543594892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 69}], {
             RGBColor[
             0.40608263929049154`, 0.5261501046716837, 0.9470962045841795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 77}], {
             RGBColor[
             0.4030805157734533, 0.5235498161723404, 0.9469049119283475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 79}], {
             RGBColor[
             0.3156295526433677, 0.44171536614432994`, 0.9415555554577009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 95}], {
             RGBColor[
             0.48701029086628944`, 0.5926524000847553, 0.95324564623738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 98}], {
             RGBColor[
             0.34163351398872654`, 0.46904717826467845`, 0.9430364425869058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.3958768319210234, 0.5173103472870436, 0.9464458995632381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 80}], {
             RGBColor[
             0.2419836729170215, 0.3716705612597674, 0.9370919842386365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 28}], {
             RGBColor[
             0.26139593816194606`, 0.39207408284088785`, 0.938197484026462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 43}], {
             RGBColor[
             0.25864725898215624`, 0.389185046746603, 0.9380409508134795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 46}], {
             RGBColor[
             0.2688995810964162, 0.39996088732345647`, 0.9386248053909352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 55}], {
             RGBColor[
             0.2577051513357447, 0.38819483187714965`, 0.9379872991767397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 59}], {
             RGBColor[
             0.2708235974633978, 0.40198315051483763`, 0.9387343752767077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 66}], {
             RGBColor[
             0.2944862531059669, 0.425603937657286, 0.9401277031465842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 79}], {
             RGBColor[
             0.2547975399437836, 0.38513874795098857`, 0.937821715009393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 95}], {
             RGBColor[
             0.4261782781667054, 0.536075781891414, 0.949511805789072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 98}], {
             RGBColor[
             0.2808015012891425, 0.4124705600713371, 0.9393026021385978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 99}], {
             RGBColor[
             0.33504481922143936`, 0.46073372909370225`, 0.9427120591149303]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.2386756834212212, 0.36819365456103337`, 0.9369035991305825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 58}], {
             RGBColor[
             0.22266134542622565`, 0.3513615699606193, 0.9359916062728575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 59}], {
             RGBColor[
             0.24810334272267293`, 0.37810272223498315`, 0.9374404903808281]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 63}], {
             RGBColor[
             0.22006041247387476`, 0.34862782451902463`, 0.9358434869889567]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 66}], {
             RGBColor[
             0.271765998365242, 0.4017235093774315, 0.9388338182507047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 79}], {
             RGBColor[
             0.2320772852030587, 0.3612583196711341, 0.9365278301135136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 83}], {
             RGBColor[
             0.22260788034518547`, 0.3513053747705641, 0.9359885615155867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 97}], {
             RGBColor[
             0.23606571183465724`, 0.3654504089417983, 0.9367549651098346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 22}], {
             RGBColor[
             0.9323482473126639, 0.8120285789472437, 0.5954726044647025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 30}], {
             RGBColor[
             0.860772607404038, 0.39770976902130306`, 0.2030717255588116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 34}], {
             RGBColor[
             0.7440489383777218, 0.6635696741320418, 0.6006939636333543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.5412488824777958, 0.4795214095089955, 0.5872225572369445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 49}], {
             RGBColor[
             0.8381155029968219, 0.7379350846059927, 0.6094680504969712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 68}], {
             RGBColor[
             0.8602485375600374, 0.3936815385514446, 0.2025698756843444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 72}], {
             RGBColor[
             0.8673115146201031, 0.4479706752513929, 0.20933339049355504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 82}], {
             RGBColor[
             0.8703286104016272, 0.4711613955279884, 0.21222256482126478`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[
             0.8461475149580568, 0.7442097533956613, 0.6102686063858478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 92}], {
             RGBColor[
             0.5447186986215644, 0.48316840627514634`, 0.5874201581331991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 30}], {
             RGBColor[
             0.889942779596627, 0.5565022708656576, 0.5576225786548253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 34}], {
             RGBColor[
             0.7732191105703109, 0.8223621759763964, 0.955244816729368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 49}], {
             RGBColor[
             0.8672856751894109, 0.8967275864503471, 0.9640189035929849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 66}], {
             RGBColor[
             0.6418930093726982, 0.712187405219036, 0.9458895209538087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 69}], {
             RGBColor[
             0.6926573828576388, 0.7561569540400923, 0.9491241819430962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 77}], {
             RGBColor[
             0.6896552593406005, 0.7535566655407491, 0.9489328892872642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 82}], {
             RGBColor[
             0.8994987825942162, 0.6299538973723429, 0.5667734179172785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 87}], {
             RGBColor[
             0.875317687150646, 0.9030022552400158, 0.9648194594818615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 95}], {
             RGBColor[
             0.7735850344334367, 0.822659249453164, 0.9552736235962966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 99}], {
             RGBColor[
             0.6824515754881706, 0.7473171966554524, 0.9484738769221548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 24}], {
             RGBColor[
             0.9471254016338135, 0.8298823883137303, 0.5568344831794053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 27}], {
             RGBColor[
             0.6645515668442425, 0.7298696411778459, 0.9061368692979717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 30}], {
             RGBColor[
             0.9025589304514734, 0.5654862789591164, 0.5172300337295237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 37}], {
             RGBColor[
             0.8563518073535856, 0.887314140955882, 0.9212791128920343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 50}], {
             RGBColor[
             0.9890507904475296, 0.9897402347152724, 0.831120268137828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 76}], {
             RGBColor[
             0.9905483291850934, 0.9895519766020239, 0.7476033518841813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[
             0.7636299537302207, 0.8133189149453938, 0.9131041886415987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 84}], {
             RGBColor[
             0.7117851117483094, 0.7707809637467538, 0.909146549012275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 85}], {
             RGBColor[
             0.8008648229179952, 0.8435478591637703, 0.9160354539398804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 86}], {
             RGBColor[
             0.990093096424966, 0.9901712550229842, 0.8138465606903063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 42}], {
             RGBColor[
             0.7818518898687528, 0.7011631313519644, 0.6053992543639326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 50}], {
             RGBColor[
             0.9494254708663976, 0.830833526050487, 0.5187163836071205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 76}], {
             RGBColor[
             0.9509230096039614, 0.8306452679372385, 0.4351994673534736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 26}], {
             RGBColor[
             0.21798888787154624`, 0.3464505208197316, 0.9357255167274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 40}], {
             RGBColor[
             0.22979823437354924`, 0.35886289274915106`, 0.9363980415403266]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 54}], {
             RGBColor[
             0.2334197719370433, 0.36266935834712705`, 0.9366042827469828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 65}], {
             RGBColor[
             0.21906851954430756`, 0.34758528216040546`, 0.9357870001539919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 100}], {
             RGBColor[
             0.23058501773817044`, 0.3596898519503145, 0.9364428476890001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 40}], {
             RGBColor[
             0.23187934520351416`, 0.3610502721814919, 0.9365165577233654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 53}], {
             RGBColor[
             0.27181647740875625`, 0.40165680145894234`, 0.9388410781260154]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 65}], {
             RGBColor[
             0.2211496303742725, 0.34977266159274634`, 0.9359055163370308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 90}], {
             RGBColor[
             0.2640863311664119, 0.39490185646935017`, 0.9383506979279865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[
             0.2326661285681354, 0.3618772313826554, 0.9365613638720389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 37}], {
             RGBColor[
             0.5341526529828826, 0.6283946851552121, 0.9581776144798929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 43}], {
             RGBColor[
             0.29647101173303086`, 0.4258330666011419, 0.9403087252832609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 54}], {
             RGBColor[
             0.2966420896530224, 0.4260128803420197, 0.9403184679177174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 81}], {
             RGBColor[
             0.4414307993595177, 0.5543994591447239, 0.9500026902294574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 84}], {
             RGBColor[
             0.38958595737760626`, 0.5118615079460839, 0.9460450506001336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 85}], {
             RGBColor[
             0.4786656685472922, 0.5846284033631004, 0.952933955527739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 46}], {
             RGBColor[
             0.2635906122865721, 0.39438082449624623`, 0.93832246747113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 55}], {
             RGBColor[
             0.2523961825259005, 0.38261476904993935`, 0.9376849612569346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 59}], {
             RGBColor[
             0.2655146286535537, 0.39640308768762733`, 0.9384320373569025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 66}], {
             RGBColor[
             0.28917728429612277`, 0.42002387483007575`, 0.9398253652267791]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 79}], {
             RGBColor[
             0.24948857113393946`, 0.3795586851237783, 0.937519377089588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 83}], {
             RGBColor[
             0.24001916627606623`, 0.36960574022320836`, 0.9369801084916611]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 98}], {
             RGBColor[
             0.27549253247929834`, 0.40689049724412685`, 0.9390002642187927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 99}], {
             RGBColor[
             0.3297358504115952, 0.455153666266492, 0.9424097211951252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 33}], {
             RGBColor[
             0.29422509162390786`, 0.4255184180648389, 0.9401059109878009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 38}], {
             RGBColor[
             0.3762188058276783, 0.5002835531261081, 0.9451933075234802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 42}], {
             RGBColor[
             0.48821367053746006`, 0.5915669704381774, 0.9539966276833514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.34313416867820656`, 0.4716273033094493, 0.9430851836999117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 36}], {
             RGBColor[
             0.49884341476175903`, 0.2239951014274094, 0.5493725314270672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 50}], {
             RGBColor[
             0.9048589996840575, 0.566437416695873, 0.47911193415723874`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 82}], {
             RGBColor[
             0.8279231426855904, 0.21563508744640228`, 0.17437253901138755`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 86}], {
             RGBColor[
             0.9059013056614938, 0.5668684370035848, 0.46183822670971686`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 92}], {
             RGBColor[
             0.5023132309055276, 0.22764209819356024`, 0.5495701323233219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 94}], {
             RGBColor[
             0.4995877733317956, 0.224777469479577, 0.549414921546451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 32}], {
             RGBColor[
             0.3463701598777138, 0.472931174642505, 0.9433462632569267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 39}], {
             RGBColor[
             0.34736341039793694`, 0.47397514391497986`, 0.943402827404671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 44}], {
             RGBColor[
             0.5893518598321712, 0.6739738751825308, 0.9626393731710036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 45}], {
             RGBColor[
             0.5919024457294845, 0.6759664122706829, 0.9628935917366674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 51}], {
             RGBColor[
             0.33046646407782415`, 0.4562153820042676, 0.9424405713085325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 70}], {
             RGBColor[
             0.3382626356768291, 0.464409652660651, 0.9428845517476936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 75}], {
             RGBColor[
             0.3329280335215753, 0.45880264756216715`, 0.9425807540467885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 78}], {
             RGBColor[
             0.6972006995541824, 0.7564641060518543, 0.846300355646884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 80}], {
             RGBColor[
             0.33469414166217204`, 0.4606589391956579, 0.9426813312926726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 39}], {
             RGBColor[
             0.2935264779562271, 0.4258453173585629, 0.9400272707348724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 44}], {
             RGBColor[
             0.5355149273904612, 0.6258440486261139, 0.959263816501205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 45}], {
             RGBColor[
             0.5380655132877746, 0.6278365857142659, 0.9595180350668688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 51}], {
             RGBColor[
             0.27662953163611426`, 0.40808555544785063`, 0.9390650146387339]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 80}], {
             RGBColor[
             0.2808572092204622, 0.41252911263924097`, 0.939305774622874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 42}], {
             RGBColor[
             0.46221511877127164`, 0.5653020306816455, 0.952477193383617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 62}], {
             RGBColor[
             0.3171356169120182, 0.44536236355291736`, 0.9415657494001773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 49}], {
             RGBColor[
             0.678986366254469, 0.7482686816351451, 0.9692402627616367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 60}], {
             RGBColor[
             0.5274957486173808, 0.6272838379970835, 0.9559455440932065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 69}], {
             RGBColor[
             0.5043580739226968, 0.6076980492248905, 0.954345541111748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 71}], {
             RGBColor[
             0.46781157980336074`, 0.5760433128989255, 0.9520168308232597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 77}], {
             RGBColor[
             0.5013559504056586, 0.6050977607255472, 0.9541542484559159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 82}], {
             RGBColor[
             0.7111994736592744, 0.481494992557141, 0.5719947770859303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 87}], {
             RGBColor[
             0.687018378215704, 0.7545433504248138, 0.9700408186505132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 38}], {
             RGBColor[
             0.3673467656616922, 0.49201966294494187`, 0.9446492027229738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 53}], {
             RGBColor[
             0.3130212595870627, 0.4449656400624253, 0.9411876295140573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 62}], {
             RGBColor[
             0.3342621285122205, 0.46336341312828305`, 0.9425410788994055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 90}], {
             RGBColor[
             0.3052911133447183, 0.4382106950728331, 0.9406972493160285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 61}], {
             RGBColor[
             0.17912334491775841`, 0.3056003709575509, 0.9335121815526001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 67}], {
             RGBColor[
             0.18042977836149893`, 0.3069735153395867, 0.9335865810045261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 68}], {
             RGBColor[
             0.4983193449177584, 0.2199668709575509, 0.5488706815526001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 72}], {
             RGBColor[
             0.5053823219778242, 0.27425600765749925`, 0.5556341963618108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 82}], {
             RGBColor[
             0.5083994177593483, 0.2974467279340947, 0.5585233706895204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 86}], {
             RGBColor[
             0.5863775807352516, 0.6486800774912771, 0.8459890583878498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 92}], {
             RGBColor[
             0.18278950597928542`, 0.3094537386812527, 0.9337209640014548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 94}], {
             RGBColor[
             0.1800640484055534, 0.3065891099672694, 0.9335657532245839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 50}], {
             RGBColor[
             0.8586518765861698, 0.8882652786926387, 0.8831610133197494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 76}], {
             RGBColor[
             0.8601494153237335, 0.8880770205793902, 0.7996440970661025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 81}], {
             RGBColor[
             0.6332310398688609, 0.7118439589227601, 0.9651449338235201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 84}], {
             RGBColor[
             0.5813861978869495, 0.66930600772412, 0.9611872941941962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 85}], {
             RGBColor[
             0.6704659090566354, 0.7420729031411366, 0.9680761991218017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 42}], {
             RGBColor[
             0.5442088329750422, 0.6400671657429147, 0.9575645899192962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 62}], {
             RGBColor[
             0.39912933111578863`, 0.5201274986141865, 0.9466531459358565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 44}], {
             RGBColor[
             0.5365081779106845, 0.6268880178985887, 0.9593203806489492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 45}], {
             RGBColor[
             0.5390587638079978, 0.6288805549867408, 0.959574599214613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 80}], {
             RGBColor[
             0.28185045974068534`, 0.4135730819117158, 0.9393623387706183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 53}], {
             RGBColor[
             0.2836258239107592, 0.41406917338836174`, 0.9395136029389419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 54}], {
             RGBColor[
             0.24731022926901122`, 0.37726910970888733`, 0.9373953237429482]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.23295897687627548`, 0.36218503352216574`, 0.9365780411499574]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 90}], {
             RGBColor[
             0.27589567766841483`, 0.4073142283987696, 0.939023222740913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 100}], {
             RGBColor[
             0.24447547507013836`, 0.3742896033120748, 0.9372338886849655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 48}], {
             RGBColor[
             0.34329321321312134`, 0.4669781893550724, 0.9432705886491298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 56}], {
             RGBColor[
             0.3357366265014662, 0.459035737605853, 0.9428402522148693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 60}], {
             RGBColor[
             0.44984311664774745`, 0.5635983285779962, 0.9500102743152689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 64}], {
             RGBColor[
             0.3573126143001289, 0.48171346877888566`, 0.9440689728011896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 73}], {
             RGBColor[
             0.34062966364440406`, 0.46417862987955394`, 0.9431189034415599]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 74}], {
             RGBColor[
             0.39624144168094344`, 0.517626153935267, 0.9464691321747285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.3593964815136068, 0.4839037453450634, 0.9441876459561919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 91}], {
             RGBColor[
             0.34170136961930875`, 0.46530506080926215`, 0.9431799355113838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 93}], {
             RGBColor[
             0.34493630114672413`, 0.468705178951081, 0.9433641600762177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 44}], {
             RGBColor[
             0.7173501625148713, 0.7791186661105619, 0.9724624182472246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 62}], {
             RGBColor[
             0.5111241958255703, 0.6114109159262558, 0.9554564660957278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 78}], {
             RGBColor[
             0.8251990022368825, 0.8616088969798854, 0.8561234007231051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 46}], {
             RGBColor[
             0.2608419331067822, 0.3914917884019613, 0.9381659342581474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 54}], {
             RGBColor[
             0.2507606889125138, 0.3808957615659856, 0.9375918223151481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 45}], {
             RGBColor[
             0.7810472132422319, 0.8288792862542917, 0.9788111449809456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 78}], {
             RGBColor[
             0.88634546706693, 0.9093769800354632, 0.8622179088911622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 52}], {
             RGBColor[
             0.8611685991001501, 0.8128504925215565, 0.6243159249705089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 78}], {
             RGBColor[
             0.8888960529642432, 0.9113695171236152, 0.8624721274568261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 55}], {
             RGBColor[
             0.25989982546037066`, 0.390501573532508, 0.9381122826214077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 59}], {
             RGBColor[
             0.27301827158802383`, 0.40428989217019595`, 0.9388593587213756]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 79}], {
             RGBColor[
             0.25699221406840955`, 0.38744548960634695`, 0.937946698454061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 95}], {
             RGBColor[
             0.42837295229133143`, 0.5383825235467723, 0.9496367892337401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 98}], {
             RGBColor[
             0.2829961754137684, 0.41477730172669547`, 0.9394275855832659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 99}], {
             RGBColor[
             0.3372394933460653, 0.46304047074906063`, 0.9428370425595982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 51}], {
             RGBColor[
             0.26797369092262097`, 0.39898771804597, 0.9385720773152693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 57}], {
             RGBColor[
             0.2643065968573336, 0.3951333696761603, 0.9383632417332306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 70}], {
             RGBColor[
             0.27576986252162594`, 0.40718198870235345`, 0.9390160577544302]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 74}], {
             RGBColor[
             0.31904494583740095`, 0.4476628644149205, 0.9416637299737558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 75}], {
             RGBColor[
             0.2704352603663721, 0.40157498360386956`, 0.9387122600535251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 88}], {
             RGBColor[
             0.28219998567006427`, 0.41394045582471695`, 0.9393822437552191]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.280167857490329, 0.4118045602634469, 0.9392665170616474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 56}], {
             RGBColor[
             0.2494153020184852, 0.3794816746379056, 0.9375152045218548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 57}], {
             RGBColor[
             0.25518176821789507`, 0.38554259622855935`, 0.9378435962411888]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 64}], {
             RGBColor[
             0.27099128981714793`, 0.40215940581093823`, 0.9387439251081751]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 73}], {
             RGBColor[
             0.25430833916142304`, 0.38462456691160657`, 0.9377938557485452]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 74}], {
             RGBColor[
             0.3099201171979624, 0.4380720909673196, 0.941144084481714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 88}], {
             RGBColor[
             0.2730751570306258, 0.404349682377116, 0.9388625982631773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 91}], {
             RGBColor[
             0.2553800451363277, 0.3857509978413148, 0.9378548878183692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 93}], {
             RGBColor[
             0.2586149766637431, 0.3891511159831336, 0.9380391123832033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 96}], {
             RGBColor[
             0.2710430288508906, 0.402213786815846, 0.9387468715696057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 69}], {
             RGBColor[
             0.5984246385417968, 0.6820634596988412, 0.9631196279753649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 71}], {
             RGBColor[
             0.5618781444224608, 0.6504087233728764, 0.9607909176868766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 77}], {
             RGBColor[
             0.5954225150247585, 0.679463171199498, 0.9629283353195328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 82}], {
             RGBColor[
             0.8052660382783743, 0.5558604030310919, 0.5807688639495472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.781084942834804, 0.8289087608987646, 0.9788149055141302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 76}], {
             RGBColor[
             0.9928483984176775, 0.9905031143387806, 0.7094852523118963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 81}], {
             RGBColor[
             0.7659300229628049, 0.8142700526821505, 0.8749860890693137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 84}], {
             RGBColor[
             0.7140851809808935, 0.7717321014835103, 0.87102844943999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 85}], {
             RGBColor[
             0.8031648921505794, 0.844498996900527, 0.8779173543675954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 86}], {
             RGBColor[
             0.9923931656575502, 0.9911223927597408, 0.7757284611180213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 57}], {
             RGBColor[
             0.25705874177093724`, 0.3875154144398035, 0.9379504871083011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 70}], {
             RGBColor[
             0.2685220074352297, 0.3995640334659966, 0.9386033031295007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 75}], {
             RGBColor[
             0.2631874052799758, 0.3939570283675128, 0.9382995054285956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 67}], {
             RGBColor[
             0.560139632974118, 0.5514847252323705, 0.6016081426491302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 68}], {
             RGBColor[
             0.8780291995303775, 0.46447808085033465`, 0.21689224319720418`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 72}], {
             RGBColor[
             0.8850921765904433, 0.518767217550283, 0.2236557580064148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 78}], {
             RGBColor[
             0.9664668529248481, 0.8933481863027279, 0.5077226888807255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 65}], {
             RGBColor[
             0.2728961090815175, 0.40279156279961614`, 0.9389025615526072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 84}], {
             RGBColor[
             0.3801912291988372, 0.5037242665904019, 0.9454464268280143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 85}], {
             RGBColor[
             0.46927094036852307`, 0.5764911620074185, 0.9523353317556198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 90}], {
             RGBColor[
             0.3158328098736569, 0.44792075767621997`, 0.941347743143563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 100}], {
             RGBColor[
             0.2844126072753804, 0.4148961325895252, 0.9395584090876155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 84}], {
             RGBColor[
             0.3438756345570892, 0.4669242029109275, 0.9433281476320208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 100}], {
             RGBColor[
             0.24809701263363243`, 0.37809606891005076`, 0.9374401298916217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 59}], {
             RGBColor[
             0.26182384182735224`, 0.39252383672388913`, 0.9382218525071802]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 66}], {
             RGBColor[
             0.28548649746992133`, 0.41614462386633744`, 0.9396151803770567]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 79}], {
             RGBColor[
             0.24579778430773802`, 0.37567943416004, 0.9373091922398655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 98}], {
             RGBColor[
             0.2718017456530969, 0.4030112462803886, 0.9387900793690704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 99}], {
             RGBColor[
             0.32604506358539376`, 0.45127441530275375`, 0.9421995363454028]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 64}], {
             RGBColor[
             0.2634347031054928, 0.3942169540617188, 0.9383135886739146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 73}], {
             RGBColor[
             0.24675175244976794`, 0.37668211516238714`, 0.9373635193142849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 74}], {
             RGBColor[
             0.3023635304863073, 0.4301296392181001, 0.9407137480474534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 88}], {
             RGBColor[
             0.26551857031897064`, 0.39640723062789657`, 0.9384322618289168]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 89}], {
             RGBColor[
             0.2431918362429577, 0.37294041751730556`, 0.937160787352731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 91}], {
             RGBColor[
             0.2478234584246726, 0.37780854609209535`, 0.9374245513841087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 93}], {
             RGBColor[
             0.251058389952088, 0.3812086642339142, 0.9376087759489427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 64}], {
             RGBColor[
             0.2692011693049027, 0.4002778756523726, 0.9386419803932486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 70}], {
             RGBColor[
             0.26485491336994227`, 0.39570968509618687`, 0.9383944675474621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 74}], {
             RGBColor[
             0.3081299966857172, 0.43619056080875396`, 0.9410421397667876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 75}], {
             RGBColor[
             0.25952031121468844`, 0.390102679997703, 0.9380906698465571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 88}], {
             RGBColor[
             0.27128503651838054`, 0.40246815221855037`, 0.9387606535482509]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 96}], {
             RGBColor[
             0.26925290833864535`, 0.40033225665728034`, 0.9386449268546793]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 63}], {
             RGBColor[
             0.22145736040975994`, 0.3500961053712548, 0.9359230411073061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 83}], {
             RGBColor[
             0.22400482828107066`, 0.3527736556227943, 0.9360681156339361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 97}], {
             RGBColor[
             0.23746265977054243`, 0.3669186897940284, 0.936834519228184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 66}], {
             RGBColor[
             0.2986049435975745, 0.4299329425040255, 0.9403622564770246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 69}], {
             RGBColor[
             0.34936931708251506`, 0.4739024913250818, 0.9435969174663121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 77}], {
             RGBColor[
             0.3463671935654768, 0.47130220282573854`, 0.9434056248104801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 79}], {
             RGBColor[
             0.2589162304353912, 0.38946775279772805`, 0.9380562683398335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 83}], {
             RGBColor[
             0.24944682557751796`, 0.3795148078971581, 0.9375169997419068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 95}], {
             RGBColor[
             0.430296968658313, 0.5404047867381535, 0.9497463591195126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 97}], {
             RGBColor[
             0.26290465706698973`, 0.3936598420683923, 0.9382834033361547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 98}], {
             RGBColor[
             0.28492019178075007`, 0.41679956491807657`, 0.9395371554690384]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 99}], {
             RGBColor[
             0.33916350971304693`, 0.46506273394044173`, 0.9429466124453707]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 64}], {
             RGBColor[
             0.37754119325177404`, 0.49877954503386207`, 0.9454836107743141]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 71}], {
             RGBColor[
             0.41038752678537255`, 0.5294238797348146, 0.9474961990184465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 74}], {
             RGBColor[
             0.4164700206325886, 0.5346922301902434, 0.9478837701478531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 89}], {
             RGBColor[
             0.357298326389239, 0.4775030084894488, 0.9443308094531306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 93}], {
             RGBColor[
             0.3651648800983693, 0.48577125520605746`, 0.9447787980493423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 67}], {
             RGBColor[
             0.1802334334437405, 0.3067671443820358, 0.933575399451926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 68}], {
             RGBColor[0.49812300000000004`, 0.2197605, 0.5488595000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 72}], {
             RGBColor[
             0.5051859770600657, 0.2740496366999483, 0.5556230148092107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 86}], {
             RGBColor[
             0.5861812358174932, 0.6484737065337263, 0.8459778768352497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 92}], {
             RGBColor[
             0.182593161061527, 0.30924736772370176`, 0.9337097824488547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 94}], {
             RGBColor[
             0.17986770348779496`, 0.3063827390097185, 0.9335545716719839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 83}], {
             RGBColor[
             0.2214038953287198, 0.3500399101811996, 0.9359199963500353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 97}], {
             RGBColor[
             0.23486172681819156`, 0.36418494435243376`, 0.9366863999442832]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 73}], {
             RGBColor[
             0.26832774024843065`, 0.39935984633541977`, 0.938592239900605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 74}], {
             RGBColor[
             0.32393951828497003`, 0.45280737039113284`, 0.9419424686337738]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 88}], {
             RGBColor[
             0.2870945581176334, 0.41908496180092925`, 0.9396609824152371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 89}], {
             RGBColor[
             0.2647678240416204, 0.39561814869033823`, 0.9383895079390514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 91}], {
             RGBColor[
             0.26939944622333534`, 0.400486277265128, 0.938653271970429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 93}], {
             RGBColor[
             0.2726343777507507, 0.4038863954069468, 0.938837496535263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 96}], {
             RGBColor[
             0.28506242993789815`, 0.4169490662396592, 0.9395452557216655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 90}], {
             RGBColor[
             0.26516596283917315`, 0.39603661781002397`, 0.9384121813545784]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 100}], {
             RGBColor[
             0.2337457602408967, 0.3630119927233292, 0.9366228472986309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 69}], {
             RGBColor[
             0.37303197272508415`, 0.4975232784675301, 0.9449902453361887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 77}], {
             RGBColor[
             0.3700298492080458, 0.49492298996818684`, 0.9447989526803566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 79}], {
             RGBColor[
             0.2825788860779602, 0.4130885399401764, 0.93944959620971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 83}], {
             RGBColor[
             0.27310948122008705`, 0.4031355950396065, 0.9389103276117834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 95}], {
             RGBColor[
             0.4539596243008821, 0.5640255738806018, 0.9511396869893891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 97}], {
             RGBColor[
             0.2865673127095588, 0.41728062921084064`, 0.9396767312060312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[
             0.3085828474233191, 0.440420352060525, 0.9409304833389149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 99}], {
             RGBColor[
             0.36282616535561596`, 0.48868352108289015`, 0.9443399403152473]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 68}], {
             RGBColor[
             0.49942943344374047`, 0.22113364438203578`, 0.5489338994519259]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 72}], {
             RGBColor[
             0.5064924105038062, 0.2754227810819841, 0.5556974142611366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 86}], {
             RGBColor[
             0.5874876692612337, 0.649846850915762, 0.8460522762871756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 92}], {
             RGBColor[
             0.1838995945052675, 0.31062051210573755`, 0.9337841819007806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 94}], {
             RGBColor[
             0.18117413693153547`, 0.3077558833917543, 0.9336289711239099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 72}], {
             RGBColor[
             0.8243819770600658, 0.1884161366999483, 0.17098151480921064`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 82}], {
             RGBColor[
             0.8273990728415899, 0.2116068569765438, 0.1738706891369204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 92}], {
             RGBColor[
             0.501789161061527, 0.22361386772370176`, 0.5490682824488547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 71}], {
             RGBColor[
             0.38724985209068863`, 0.5098380909626216, 0.9458961960369879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 77}], {
             RGBColor[
             0.4207942226929865, 0.5388925387892431, 0.9480336136696441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 87}], {
             RGBColor[
             0.6064566505030319, 0.6883381284885098, 0.9639201838642415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 95}], {
             RGBColor[
             0.5047239977858227, 0.6079951227016581, 0.9543743479786766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 97}], {
             RGBColor[
             0.3373316861944994, 0.46125017803189694`, 0.9429113921953187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 98}], {
             RGBColor[
             0.35934722090825977`, 0.48438990088158124`, 0.9441651443282024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 99}], {
             RGBColor[
             0.41359053884055663`, 0.5326530699039465, 0.9475746013045347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 75}], {
             RGBColor[
             0.2709835768789808, 0.4021512990238961, 0.9387434858677567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 96}], {
             RGBColor[
             0.28071617400293775`, 0.4123808756834735, 0.9392977428758789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 77}], {
             RGBColor[
             0.3842477285736503, 0.5072378024632783, 0.9457049033811559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 87}], {
             RGBColor[
             0.5699101563836958, 0.656683392162545, 0.9615914735757531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 82}], {
             RGBColor[
             0.8344620499016556, 0.2658959936764921, 0.180634203946131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 92}], {
             RGBColor[
             0.5088521381215928, 0.27790300442365007`, 0.5558317972580653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 74}], {
             RGBColor[
             0.3072565676292452, 0.4352725314918011, 0.940992399274144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 88}], {
             RGBColor[
             0.2704116074619085, 0.40155012290159753`, 0.9387109130556073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.24808487338589558`, 0.37808330979100657`, 0.9374394385794216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 91}], {
             RGBColor[
             0.25271649556761044`, 0.3829514383657963, 0.9377032026107992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 93}], {
             RGBColor[
             0.2559514270950259, 0.38635155650761516`, 0.9378874271756332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 88}], {
             RGBColor[
             0.3260233854984479, 0.4549976469573106, 0.9420611417887761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 91}], {
             RGBColor[
             0.3083282736041498, 0.43639896242150933`, 0.941053431343968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 96}], {
             RGBColor[
             0.3239912573187127, 0.45286175139604057`, 0.9419454150952044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 96}], {
             RGBColor[
             0.27538157184768386`, 0.40677387058498965`, 0.9389939451749738]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 81}], {
             RGBColor[
             0.7674275617003685, 0.8140817945689018, 0.7914691728156671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 84}], {
             RGBColor[
             0.7155827197184571, 0.7715438433702618, 0.7875115331863431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 85}], {
             RGBColor[
             0.8046624308881429, 0.8443107387872784, 0.7944004381139487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 87}], {
             RGBColor[
             0.6034545269859937, 0.6857378399891666, 0.9637288912084094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 95}], {
             RGBColor[
             0.5017218742687843, 0.6053948342023149, 0.9541830553228445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 97}], {
             RGBColor[
             0.3343295626774611, 0.4586498895325537, 0.9427200995394867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 98}], {
             RGBColor[
             0.35634509739122144`, 0.481789612382238, 0.9439738516723704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 99}], {
             RGBColor[
             0.4105884153235183, 0.5300527814046032, 0.9473833086487027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 83}], {
             RGBColor[
             0.23342076805790374`, 0.3626704053333091, 0.9366043394745922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 98}], {
             RGBColor[
             0.26889413426113584`, 0.39995516235422757`, 0.9386244952017238]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 99}], {
             RGBColor[
             0.3231374521934327, 0.4482183313765927, 0.9420339521780562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 84}], {
             RGBColor[
             0.4886643442635845, 0.5953107817136317, 0.9530123699437607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 85}], {
             RGBColor[
             0.5777440554332705, 0.6680776771306483, 0.9599012748713662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 86}], {
             RGBColor[
             0.9154573086590831, 0.64032006351027, 0.4709890659721701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 87}], {
             RGBColor[
             0.8132980502396094, 0.5621350718207605, 0.5815694198384238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 92}], {
             RGBColor[
             0.5118692339031169, 0.30109372470024554`, 0.558720971585775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 97}], {
             RGBColor[
             0.23740919468950228`, 0.36686249460397324`, 0.9368314744709133]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 85}], {
             RGBColor[
             0.5258992134513589, 0.6255397259320082, 0.9559436352420423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.37246108295649283`, 0.49696932160080975`, 0.9449560466299856]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 90}], {
             RGBColor[
             0.4615407941261787, 0.5697362170178263, 0.951844951557591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 92}], {
             RGBColor[
             0.5898473968790202, 0.652327074257428, 0.8461866592841044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[
             0.5871219393052882, 0.6494624455434448, 0.8460314485072336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 91}], {
             RGBColor[
             0.2714833134368132, 0.40267655383130574`, 0.9387719451254313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 96}], {
             RGBColor[
             0.2871462971513761, 0.419139342805837, 0.9396639288766677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 91}], {
             RGBColor[
             0.24915657936080024`, 0.3792097407207148, 0.9375004706492456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 93}], {
             RGBColor[
             0.25239151088821565`, 0.3826098588625336, 0.9376846952140795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 100}], {
             RGBColor[
             0.27668246103303606`, 0.408141187599933, 0.9390680288895865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 93}], {
             RGBColor[
             0.2570231330699305, 0.38747798743732337`, 0.9379484592454572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 96}], {
             RGBColor[
             0.269451185257078, 0.40054065827003577`, 0.9386562184318596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 94}], {
             RGBColor[
             0.18353386454932197`, 0.3102361067334203, 0.9337633541208386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 98}], {
             RGBColor[
             0.44027487248405767`, 0.5508921962946529, 0.9503145859814027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 99}], {
             RGBColor[
             0.49451819041635453`, 0.5991553653170181, 0.9537240429577352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 99}], {
             RGBColor[
             0.3491414135387916, 0.47555014349694125`, 0.943514839307261]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.058168352269944726`], {
             RGBColor[
             0.2581082061950206, 0.38861846808940276`, 0.9380102525547092]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.058168352269944726`], {
             RGBColor[
             0.5167351398431651, 0.6185478910342742, 0.9550984295530915]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.058168352269944726`], {
             RGBColor[
             0.29928415304751665`, 0.4318969989371937, 0.9403551618136042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.058168352269944726`], {
             RGBColor[
             0.8388093398485373, 0.29931116920282663`, 0.1847971737088267]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.058168352269944726`], {
             RGBColor[
             0.2503401935643895, 0.38045379429416204`, 0.9375678757271396]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.058168352269944726`], {
             RGBColor[
             0.2567233930101477, 0.3871629416298741, 0.9379313894924781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.058168352269944726`], {
             RGBColor[
             0.3134760783279485, 0.4459389561070196, 0.9411953964084129]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.058168352269944726`], {
             RGBColor[
             0.9629022796012385, 0.9718531613853215, 0.9476809433867306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.058168352269944726`], {
             RGBColor[
             0.9513821482973379, 0.8449534494772841, 0.27973913919362886`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.058168352269944726`], {
             RGBColor[
             0.25142577857169485`, 0.38159481296690484`, 0.9376296981873266]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.058168352269944726`], {
             RGBColor[
             0.23420058730117388`, 0.3634900448013817, 0.9366487490268572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.058168352269944726`], {
             RGBColor[
             0.6054182467789488, 0.6905448323731828, 0.9620798885880011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.058168352269944726`], {
             RGBColor[
             0.2733697721409376, 0.40465934153773064`, 0.9388793761578655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.058168352269944726`], {
             RGBColor[
             0.7189648146431117, 0.780380044624954, 0.9726233516815856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.058168352269944726`], {
             RGBColor[
             0.3159380912379023, 0.44807142794525473`, 0.9413522736939626]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.058168352269944726`], {
             RGBColor[
             0.23643110434042502`, 0.36583445963258315`, 0.9367757736724883]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.058168352269944726`], {
             RGBColor[
             0.3883689323709583, 0.5108073820547808, 0.9459675028428829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.058168352269944726`], {
             RGBColor[
             0.21478615482912253`, 0.34308424532714094`, 0.935543125818653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.058168352269944726`], {
             RGBColor[
             0.2667049069717902, 0.39765414566809815`, 0.9384998219462671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.058168352269944726`], {
             RGBColor[
             0.22126439749034046`, 0.3498932891083892, 0.9359120521545081]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.058168352269944726`], {
             RGBColor[
             0.9031780751200748, 0.6532360771028892, 0.2409217513686888]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.058168352269944726`], {
             RGBColor[
             0.9615184195052529, 0.9708210807915982, 0.9500234575607163]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.058168352269944726`], {
             RGBColor[
             0.9867507212149456, 0.9887890969785158, 0.869238367710113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.058168352269944726`], {
             RGBColor[
             0.9075000820526815, 0.6709756796489449, 0.2444305986486977]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.058168352269944726`], {
             RGBColor[
             0.21590777704158132`, 0.3442631413873908, 0.9356070005443611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.058168352269944726`], {
             RGBColor[
             0.2200699987015112, 0.3486379002520725, 0.9358440329104389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.058168352269944726`], {
             RGBColor[
             0.3423524124735395, 0.470950185377176, 0.9430353708858302]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.058168352269944726`], {
             RGBColor[
             0.25608696935210196`, 0.3864940200136776, 0.9378951461066569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.058168352269944726`], {
             RGBColor[
             0.32022364339009624`, 0.4517833578213709, 0.9416253452875354]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.058168352269944726`], {
             RGBColor[
             0.8183671396880012, 0.14218346093971695`, 0.1652216997489344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.058168352269944726`], {
             RGBColor[
             0.40020709231942364`, 0.521061001198922, 0.9467218199267253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.058168352269944726`], {
             RGBColor[
             0.2925332274360039, 0.424801348086088, 0.9399707065871281]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.058168352269944726`], {
             RGBColor[
             0.26822653985771944`, 0.399253478308307, 0.9385864766880666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.058168352269944726`], {
             RGBColor[
             0.5849198016353689, 0.6739032711611944, 0.9604661758980197]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.058168352269944726`], {
             RGBColor[
             0.30247956305812407`, 0.4352555774590384, 0.9405371356865229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.058168352269944726`], {
             RGBColor[
             0.17931968983551683`, 0.3058067419151018, 0.9335233631052001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.058168352269944726`], {
             RGBColor[
             0.7259528934922258, 0.7858391849332483, 0.9733198580739556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.058168352269944726`], {
             RGBColor[
             0.43221396826526043`, 0.5487837484308453, 0.9487612697594249]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.058168352269944726`], {
             RGBColor[
             0.2945197284764503, 0.42688928663103776`, 0.9400838348826166]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.058168352269944726`], {
             RGBColor[
             0.24368869170551716`, 0.37346264411091135`, 0.937189082536292]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.058168352269944726`], {
             RGBColor[
             0.4296145376961023, 0.5465322523230198, 0.9485956363421444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.058168352269944726`], {
             RGBColor[
             0.6562036976848239, 0.731350583054984, 0.9663679100791674]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.058168352269944726`], {
             RGBColor[
             0.25058961099252225`, 0.3807159478251078, 0.9375820796806917]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.058168352269944726`], {
             RGBColor[
             0.7784966273449186, 0.8268867491661398, 0.9785569264152818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.058168352269944726`], {
             RGBColor[
             0.7835977991395453, 0.8308718233424438, 0.9790653635466094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.058168352269944726`], {
             RGBColor[
             0.2710942552210422, 0.40226762897881485`, 0.9387497888356031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.058168352269944726`], {
             RGBColor[
             0.27522154600901727`, 0.40660567328232683`, 0.9389848319401988]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.058168352269944726`], {
             RGBColor[
             0.2569718887301403, 0.38742412638712503`, 0.9379455409561153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.058168352269944726`], {
             RGBColor[
             0.773052930873569, 0.822634092109096, 0.9780143496252536]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.058168352269944726`], {
             RGBColor[
             0.9913508596801138, 0.9906913724520291, 0.7930021685655431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.058168352269944726`], {
             RGBColor[
             0.26072583583622466`, 0.3913697628096132, 0.9381593226903397]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.058168352269944726`], {
             RGBColor[
             0.938739399060755, 0.7948291617006693, 0.26956648639440833`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.058168352269944726`], {
             RGBColor[
             0.3235629561160013, 0.45467570266581214`, 0.9418381233415918]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.058168352269944726`], {
             RGBColor[
             0.2509317668325053, 0.3810755753068633, 0.9376015649496046]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.058168352269944726`], {
             RGBColor[
             0.2487053956996991, 0.3787355180862011, 0.9374747764072122]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.058168352269944726`], {
             RGBColor[
             0.24185871530683006`, 0.3715392228886861, 0.9370848680875943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.058168352269944726`], {
             RGBColor[
             0.25339164770564987`, 0.38366106606999373`, 0.9377416515262625]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.058168352269944726`], {
             RGBColor[
             0.22405829336211083`, 0.3528298508128494, 0.9360711603912069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.058168352269944726`], {
             RGBColor[
             0.2749422879550054, 0.4063121553615771, 0.9389689286071481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.058168352269944726`], {
             RGBColor[
             0.4700716955993926, 0.5806644048329727, 0.9514249122883933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.058168352269944726`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.058168352269944726`], {
             RGBColor[
             0.3660446939663169, 0.4914712487975277, 0.9445450221122881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.058168352269944726`], {
             RGBColor[
             0.21885642745740908`, 0.34736235992966014`, 0.9357749218234052]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.058168352269944726`], {
             RGBColor[
             0.2850106909041555, 0.4168946852347515, 0.9395423092602349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.058168352269944726`], {
             RGBColor[
             0.2222292620470338, 0.35090742293342014`, 0.9359669997636226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.058168352269944726`], {
             RGBColor[
             0.32226759924014353`, 0.45355372964647384`, 0.9417555843469012]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.058168352269944726`], {
             RGBColor[
             0.181539866887481, 0.30814028876407157`, 0.9336497989038519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.058168352269944726`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.058168352269944726`], {
             RGBColor[
             0.42379634621002477`, 0.5414928272885864, 0.9482249063254762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.058168352269944726`], {
             RGBColor[
             0.27631817903423467`, 0.40775830412238, 0.9390472835686617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.058168352269944726`], {
             RGBColor[
             0.3507033579713525, 0.4781833546366567, 0.9435674857484997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.058168352269944726`], {
             RGBColor[
             0.8314449541201315, 0.24270527339989661`, 0.17774502961842129`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.058168352269944726`], {
             RGBColor[
             0.2516447895927058, 0.3818250074360881, 0.9376421705409753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.058168352269944726`], {
             RGBColor[
             0.3628683456657846, 0.48872005554751413`, 0.9443426280073127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.058168352269944726`], {
             RGBColor[
             0.26564897472372695`, 0.3965442939254123, 0.9384396881668516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.058168352269944726`], {
             RGBColor[
             0.9943459371552411, 0.990314856225532, 0.6259683360582495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.058168352269944726`], {
             RGBColor[
             0.4177920991759482, 0.5362922502898999, 0.947842321013812]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.058168352269944726`], {
             RGBColor[
             0.9941943067889412, 0.9918672109047867, 0.7458788913670427]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.058168352269944726`], {
             RGBColor[
             0.24289017291577697`, 0.372623350233879, 0.937143608072519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.058168352269944726`], {
             RGBColor[
             0.26918119100492044`, 0.4002568771923939, 0.9386408426586199]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.058168352269944726`], {
             RGBColor[
             0.5405091862454959, 0.6378487329122717, 0.9569700095730845]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.058168352269944726`], {
             RGBColor[
             0.8374791456831797, 0.2890867139530876, 0.18352337827384074`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.058168352269944726`], {
             RGBColor[
             0.2239513632000305, 0.3527174604327391, 0.9360650708766655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.058168352269944726`], {
             RGBColor[
             0.4368195022816731, 0.5527728305149917, 0.9490547303144369]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.058168352269944726`], {
             RGBColor[
             0.6149789246210449, 0.6983066213490248, 0.9628325401696478]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.058168352269944726`], {
             RGBColor[
             0.9934354716349865, 0.9915534130674525, 0.7584547536704994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.058168352269944726`], {
             RGBColor[
             0.789116954796039, 0.8351834296884333, 0.9796154614030067]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.058168352269944726`], {
             RGBColor[
             0.28917842533111127`, 0.421275238367107, 0.9397796555702393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.058168352269944726`], {
             RGBColor[
             0.24452495717908534`, 0.374341612145925, 0.9372367066178678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.058168352269944726`], {
             RGBColor[
             0.30810266363131256`, 0.4411658126866278, 0.9408573629455341]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.058168352269944726`], {
             RGBColor[
             0.25378820154251513`, 0.3840778692955045, 0.9377642346806232]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.058168352269944726`], {
             RGBColor[
             0.18625932212305402`, 0.3131007354474035, 0.9339185648977094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.058168352269944726`], {
             RGBColor[
             0.26025806459734596`, 0.3908781055791422, 0.9381326838102911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.058168352269944726`], {
             RGBColor[
             0.18080840697558995`, 0.30737147801943704`, 0.9336081433439677]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.058168352269944726`], {
             RGBColor[
             0.5856516493616206, 0.6744974181147299, 0.9605237896318769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.058168352269944726`], {
             RGBColor[
             0.2851141689716408, 0.417003447244567, 0.939548202183096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.058168352269944726`], {
             RGBColor[
             0.25086702617897405`, 0.38100752877520744`, 0.9375978780651611]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.058168352269944726`], {
             RGBColor[
             0.2948980956064947, 0.4272869744745761, 0.9401053823309286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.058168352269944726`], {
             RGBColor[
             0.40338473147108844`, 0.5238133125193064, 0.9469242962835934]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.058168352269944726`], {
             RGBColor[
             0.24526225843475957`, 0.3751165625132382, 0.937278694833639]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{3.8349502435193233`*^9, 3.834957407142641*^9, 
  3.835018921852682*^9, 3.8350190129675236`*^9, 3.8350205474078445`*^9, 
  3.8350446401426015`*^9},
 CellLabel->
  "Out[243]=",ExpressionUUID->"0131a3d7-8a0a-44c2-bf70-93c5cc2bd52a"]
}, Open  ]],

Cell["Estimated with absolute Mean Deviation v Calculated: (r=6)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 
  3.8349503922098827`*^9}},ExpressionUUID->"9f6991ad-2f06-4a9d-8e16-\
b0c62d13e051"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphinf1", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsif1", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}],
      "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"AMDi6f100", ",", "krif1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502409842243`*^9}, {3.8349504019691753`*^9, 3.834950402221115*^9}, {
   3.8349577477528667`*^9, 3.8349577551942053`*^9}, {3.835018833417392*^9, 
   3.8350188346728773`*^9}, {3.8350443403897114`*^9, 3.8350443452390656`*^9}},
 CellLabel->
  "In[244]:=",ExpressionUUID->"46a48aca-393d-46b3-a2d7-eac365105fd5"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100}, {
          Null, CompressedData["
1:eJwVxVmbqQwAAOCxVtbppLIkW4w1a5YJk8gSaaRCIqr783/Pr/me7715C/Zf
xfZ+fHz883x8/D9363DUk1oFBOGSrgbkKTe9Ubr+DJzlM67jGn44aCN55AiO
7OTWuWMuH0qHqrVObVrjcvv1PnbAe71DT+vplLkyddN8hkqxEiiAOngBnQA/
4nmBl/kz71Cz2Wqmz8zZE8QwHhOwC+aAKIqhFLpCL6gZpsKz8Cpshp+ghVm8
JViWU9t1dtxud0NGCI/IiIU4oXgsHi/Fq3gmo3kQT8YzygyrQz/up/w9/8Gv
+58BCZQwiZcESbpIluT8+c395n89MAjDCIzBI5iHBViCZdiCncDPzznXz/f7
6/6+Nu6Mx9x4N755Y96s9xj4/v75PnvrsXq2Xj/6SZBESYzESZIie6ROmuQz
5MbdtFt1h+5nNkDABEIQI4InZOJMOOEtuqW2s+1quzU9NEwjNEHTI1qmLdpp
99vr9t5fxsuZcrlXPpS19qvz4l7r1/6Fqxm1rPbUoXpQVc1b+CxkC4V67dF5
jB/TB/fYPW6PXCvfah1r1/a1cx1fuevuen2l0qlqaphy0SJWLE6LQlEqXjzR
aCY6jKpRLfeV//pqff3WxLbYEcfiVOTEnShexZenEW0gjUyjQTeG3maumW9+
NevNZqt5DC+p5Wy5XC23S31pLp/+ZCyJJ5P1ZC95AKJACsgAZaAKDAEV0AAX
7KJdrFvsdoWu1L3U7p37+M7dd3fxfr3f7vfH/RV4f79/3vxbeEvv8xswQkbc
SBslo2qohmYYbhAIhoLxYCqYDpaC1aARdIub7ma6ETYbaXMJsDCLsARLsyOW
5VmBlViZPbMW+2Yd7zw2j88/59l5YV6a1+eBRIJIfCfYxE+CT8iJc+IdXACL
0CK1SC+qi4WxcEEFVTCFVIoKpXSVlbJVFF25KCZsIzZh0/bIZm3eFmzJlm3L
th1vJVaJV7KVUqVSr8zDg9ZgsBysBtvBEThFT/gpcyqfeqfD6aSetCADMCEm
xsSZNFNiqgyzYFRGYwzGbU86k/5kwk3WE3Gyn1wnL6/P9+nL+gq+iq/um0dq
kUFkGuEiYuQaefkhKAyhEAlR0AxaQitoCymQDpnQ8z9pR8GG
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[69, 98] -> 
             RGBColor[
              0.8334530332929782, 0.8690331798305084, 0.9012098258837771], 
             UndirectedEdge[29, 33] -> 
             RGBColor[
              0.946042526899693, 0.843864456928933, 0.5888489740023626], 
             UndirectedEdge[55, 59] -> RGBColor[0.178927, 0.305394, 0.933501],
              UndirectedEdge[47, 74] -> 
             RGBColor[
              0.7876349473835056, 0.8334331688194891, 0.9394169653061224], 
             UndirectedEdge[19, 43] -> 
             RGBColor[
              0.9479968084449275, 0.8904769145130204, 0.6205744091515539], 
             UndirectedEdge[57, 75] -> 
             RGBColor[
              0.5863961363196126, 0.6485625734140436, 0.84241641937046], 
             UndirectedEdge[19, 46] -> 
             RGBColor[
              0.5956521927657261, 0.5971761206947667, 0.6057772304689429], 
             UndirectedEdge[36, 67] -> 
             RGBColor[
              0.7931001064762564, 0.8385765246291447, 0.9587963271245739], 
             UndirectedEdge[79, 99] -> 
             RGBColor[
              0.875901183298843, 0.9037402514138257, 0.9791607401618674], 
             UndirectedEdge[52, 68] -> 
             RGBColor[
              0.5863526355932204, 0.6485445847457627, 0.8431373389830508], 
             UndirectedEdge[81, 85] -> 
             RGBColor[
              0.9405130750605326, 0.9551553292978208, 0.9855800266343825], 
             UndirectedEdge[12, 88] -> 
             RGBColor[
              0.9651772460217716, 0.9731168792909399, 0.9244417080439806], 
             UndirectedEdge[72, 82] -> 
             RGBColor[
              0.9868348744423361, 0.9876951343575366, 0.8116109351012649], 
             UndirectedEdge[31, 44] -> 
             RGBColor[
              0.9739704762945194, 0.9781016915550724, 0.8334508211885896], 
             UndirectedEdge[17, 79] -> 
             RGBColor[
              0.9562127239255451, 0.9293777259763655, 0.6513491420622961], 
             UndirectedEdge[91, 96] -> 
             RGBColor[
              0.5555762685981465, 0.5371989350119337, 0.5989131401191364], 
             UndirectedEdge[55, 99] -> 
             RGBColor[
              0.4925741440677966, 0.5769697324455205, 0.9574106307506054], 
             UndirectedEdge[77, 99] -> 
             RGBColor[
              0.8952799508474576, 0.9181685466828087, 0.9452667476997577], 
             UndirectedEdge[29, 38] -> 
             RGBColor[
              0.8766004115343047, 0.789523676466399, 0.6179528204839264], 
             UndirectedEdge[26, 90] -> 
             RGBColor[
              0.9225764668410288, 0.9399945342432168, 0.9540999572162673], 
             UndirectedEdge[13, 27] -> 
             RGBColor[
              0.9152167334743293, 0.9351284753589959, 0.9881515644048031], 
             UndirectedEdge[22, 99] -> 
             RGBColor[
              0.8576042506053269, 0.7627085617433411, 0.6134737203389831], 
             UndirectedEdge[73, 74] -> 
             RGBColor[
              0.7295537960517864, 0.5797015441221524, 0.5849410476305776], 
             UndirectedEdge[8, 77] -> 
             RGBColor[
              0.9558335941585956, 0.966341139297821, 0.9510719276331717], 
             UndirectedEdge[36, 94] -> 
             RGBColor[
              0.7372660422127788, 0.7946639367455651, 0.9745498511646984], 
             UndirectedEdge[21, 87] -> 
             RGBColor[
              0.990302797540672, 0.9902061119004263, 0.8066016015748501], 
             UndirectedEdge[59, 83] -> 
             RGBColor[
              0.586859661497549, 0.6483318152002271, 0.8040278399762903], 
             UndirectedEdge[24, 42] -> 
             RGBColor[
              0.6032432957207097, 0.6730973237386965, 0.9452650821762119], 
             UndirectedEdge[33, 42] -> 
             RGBColor[
              0.6112411941081518, 0.6790621432606941, 0.9317267263922517], 
             UndirectedEdge[14, 42] -> 
             RGBColor[
              0.5987950488297014, 0.6697798284907184, 0.9527948038740919], 
             UndirectedEdge[45, 78] -> 
             RGBColor[
              0.9735449653721238, 0.9796150106310533, 0.921808715676578], 
             UndirectedEdge[15, 38] -> 
             RGBColor[
              0.9018099377714025, 0.8862532526149371, 0.6549953270744865], 
             UndirectedEdge[84, 85] -> 
             RGBColor[
              0.9642392390770926, 0.9726748151969475, 0.9375608829719386], 
             UndirectedEdge[55, 98] -> 
             RGBColor[
              0.5839057197336561, 0.6475327221549636, 0.8836890671912832], 
             UndirectedEdge[86, 92] -> 
             RGBColor[
              0.8754475263317192, 0.9019617766343826, 0.9109355895883775], 
             UndirectedEdge[72, 92] -> 
             RGBColor[
              0.8706495351733784, 0.8990526140843227, 0.9490241995851243], 
             UndirectedEdge[19, 99] -> 
             RGBColor[
              0.8753515111676631, 0.8330705359490039, 0.6277535827691851], 
             UndirectedEdge[4, 76] -> 
             RGBColor[
              0.9818537281316401, 0.9852472847694816, 0.8824697211938528], 
             UndirectedEdge[23, 76] -> 
             RGBColor[
              0.9818827286159015, 0.9852592772150022, 0.8819891081187923], 
             UndirectedEdge[9, 72] -> 
             RGBColor[
              0.9756784871240133, 0.9813816360366872, 0.9260541566192696], 
             UndirectedEdge[2, 44] -> 
             RGBColor[
              0.8795575999541527, 0.9064672009685231, 0.9729713805106236], 
             UndirectedEdge[74, 88] -> 
             RGBColor[
              0.7906991854633885, 0.835285524236337, 0.9148416989191105], 
             UndirectedEdge[21, 49] -> 
             RGBColor[
              0.5870744427791007, 0.6487912106437477, 0.8274054569967781], 
             UndirectedEdge[21, 34] -> 
             RGBColor[
              0.98372967277399, 0.9855018724608176, 0.8265944159937368], 
             UndirectedEdge[59, 66] -> RGBColor[0.178927, 0.305394, 0.933501],
              UndirectedEdge[17, 99] -> 
             RGBColor[
              0.8865328287622953, 0.8741829394535808, 0.6535086634016395], 
             UndirectedEdge[26, 53] -> 
             RGBColor[
              0.9743101060571555, 0.9803610996775429, 0.9283704688345189], 
             UndirectedEdge[23, 50] -> 
             RGBColor[
              0.9808930084745762, 0.9552303498789345, 0.5934066374092009], 
             UndirectedEdge[41, 74] -> 
             RGBColor[
              0.7933193154222464, 0.8363690153085932, 0.8714193648218609], 
             UndirectedEdge[59, 79] -> 
             RGBColor[
              0.5622540392310464, 0.6321645189683052, 0.955251109411262], 
             UndirectedEdge[56, 93] -> 
             RGBColor[
              0.48118702495422333`, 0.5680740284486865, 0.9562756691360426], 
             UndirectedEdge[19, 98] -> 
             RGBColor[
              0.9666830868335227, 0.9036335256584471, 0.5540320192098629], 
             UndirectedEdge[2, 38] -> 
             RGBColor[
              0.8214983971447004, 0.8606157780523974, 0.9828069251740577], 
             UndirectedEdge[19, 59] -> 
             RGBColor[
              0.5617043670998665, 0.5614948035034834, 0.6038439520185798], 
             UndirectedEdge[24, 76] -> 
             RGBColor[
              0.9673631054504126, 0.9751800379997035, 0.9401299287937934], 
             UndirectedEdge[5, 20] -> 
             RGBColor[
              0.9622305066708317, 0.8814745609055284, 0.5283997910074767], 
             UndirectedEdge[37, 84] -> 
             RGBColor[
              0.9196930937121671, 0.9373491428344431, 0.9400455801528449], 
             UndirectedEdge[9, 82] -> 
             RGBColor[
              0.9838894988467115, 0.9854984780609296, 0.8165966877076709], 
             UndirectedEdge[47, 75] -> 
             RGBColor[
              0.5797982530266343, 0.6452489648910412, 0.9255533317191282], 
             UndirectedEdge[51, 75] -> 
             RGBColor[
              0.5804534369007264, 0.6457375999515739, 0.9244442763196126], 
             UndirectedEdge[58, 63] -> 
             RGBColor[
              0.8174165259564166, 0.8554297281355933, 0.852310405181598], 
             UndirectedEdge[7, 25] -> 
             RGBColor[
              0.9382445127789336, 0.9245176268948312, 0.6720231850079161], 
             UndirectedEdge[1, 55] -> 
             RGBColor[
              0.3867636943568712, 0.493578203928448, 0.9473646335869941], 
             UndirectedEdge[82, 86] -> 
             RGBColor[
              0.991632865600677, 0.9906042969075965, 0.7735223251045181], 
             UndirectedEdge[34, 71] -> 
             RGBColor[
              0.9657566034445113, 0.973981911434108, 0.9428493176469561], 
             UndirectedEdge[41, 73] -> 
             RGBColor[
              0.9282727227602905, 0.7343081515738497, 0.4951321452784503], 
             UndirectedEdge[92, 94] -> 
             RGBColor[
              0.8051414129997037, 0.8479251296511341, 0.9811533802688146], 
             UndirectedEdge[3, 62] -> 
             RGBColor[
              0.8870952684745763, 0.5507412216949152, 0.5610537088135593], 
             UndirectedEdge[70, 75] -> 
             RGBColor[
              0.3867636943568712, 0.493578203928448, 0.9473646335869941], 
             UndirectedEdge[57, 96] -> 
             RGBColor[
              0.963045404917759, 0.8803675084259773, 0.5078285594895963], 
             UndirectedEdge[68, 72] -> 
             RGBColor[
              0.578775431359819, 0.6444861461666471, 0.9272847020064319], 
             UndirectedEdge[13, 54] -> 
             RGBColor[
              0.9536190579669022, 0.9282861640357792, 0.6575286254165248], 
             UndirectedEdge[48, 96] -> 
             RGBColor[
              0.9501070325206646, 0.8723251735107231, 0.6016982660271266], 
             UndirectedEdge[30, 50] -> 
             RGBColor[
              0.9827467097885212, 0.9559969030102016, 0.5626860094119105], 
             UndirectedEdge[11, 92] -> 
             RGBColor[
              0.8542391382777914, 0.8868137669491526, 0.9768027210123644], 
             UndirectedEdge[41, 56] -> 
             RGBColor[
              0.5854826210653753, 0.6481848113801453, 0.8575557312348667], 
             UndirectedEdge[73, 91] -> 
             RGBColor[
              0.5217171016949153, 0.39151734019370443`, 0.5710774140435835], 
             UndirectedEdge[32, 39] -> 
             RGBColor[
              0.9906217511150758, 0.9800271057729066, 0.41806770332611165`], 
             UndirectedEdge[32, 80] -> 
             RGBColor[
              0.9669700206554298, 0.968324326487226, 0.6987852752264692], 
             UndirectedEdge[20, 66] -> 
             RGBColor[
              0.585174598680517, 0.6480574362081921, 0.8626604592883484], 
             UndirectedEdge[47, 88] -> 
             RGBColor[
              0.9837337441331517, 0.9869562851989302, 0.8930303970512447], 
             UndirectedEdge[14, 53] -> 
             RGBColor[
              0.9603818978611783, 0.9699734648103309, 0.951947292251816], 
             UndirectedEdge[51, 57] -> 
             RGBColor[
              0.9879225732203389, 0.9889061733656175, 0.8333596956900724], 
             UndirectedEdge[30, 94] -> 
             RGBColor[
              0.9200091037204283, 0.9362264606274375, 0.8803832377436791], 
             UndirectedEdge[22, 69] -> 
             RGBColor[
              0.7935044200968523, 0.7126332869733654, 0.6070848482808716], 
             UndirectedEdge[4, 94] -> 
             RGBColor[
              0.9181264019222217, 0.9354479150506498, 0.9115844788160301], 
             UndirectedEdge[4, 86] -> 
             RGBColor[
              0.9884325152542373, 0.9894845620338983, 0.841366688135593], 
             UndirectedEdge[9, 94] -> 
             RGBColor[
              0.9101703649503385, 0.9302541516034986, 0.9581833373029598], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.9756061784970902, 0.9813277083811224, 0.92617655626354], 
             UndirectedEdge[12, 60] -> 
             RGBColor[
              0.9639844041468597, 0.9726236085210258, 0.9442101848870879], 
             UndirectedEdge[25, 40] -> 
             RGBColor[
              0.9722006075928882, 0.95069835002573, 0.6442336371376783], 
             UndirectedEdge[22, 95] -> 
             RGBColor[
              0.9477994926410678, 0.8328016482942879, 0.5585841457678943], 
             UndirectedEdge[3, 33] -> 
             RGBColor[
              0.8964893684422922, 0.5577473260694108, 0.5451519479418886], 
             UndirectedEdge[48, 93] -> 
             RGBColor[
              0.8757177888767415, 0.9032002669474759, 0.9590607950440329], 
             UndirectedEdge[15, 90] -> 
             RGBColor[
              0.9166867201757085, 0.89811559508463, 0.6564142878608696], 
             UndirectedEdge[77, 97] -> 
             RGBColor[
              0.9868846332503873, 0.9819004402123508, 0.6613268728699535], 
             UndirectedEdge[44, 78] -> 
             RGBColor[
              0.9573678959482499, 0.9677256271186441, 0.9570492113128071], 
             UndirectedEdge[30, 92] -> 
             RGBColor[
              0.8775428983478434, 0.9028282668116545, 0.8762098526322496], 
             UndirectedEdge[37, 76] -> 
             RGBColor[
              0.9146002037974996, 0.9337263222513219, 0.9565234510970004], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.9592680902284263, 0.9691427889015171, 0.9538326780465097], 
             UndirectedEdge[75, 96] -> 
             RGBColor[
              0.5555762685981465, 0.5371989350119337, 0.5989131401191364], 
             UndirectedEdge[31, 80] -> 
             RGBColor[
              0.9693017753234175, 0.9746197820151208, 0.8413537141404357], 
             UndirectedEdge[85, 90] -> 
             RGBColor[
              0.9048797492480725, 0.9267963512381054, 0.9840558840579848], 
             UndirectedEdge[91, 93] -> 
             RGBColor[
              0.48118702495422333`, 0.5680740284486865, 0.9562756691360426], 
             UndirectedEdge[22, 49] -> 
             RGBColor[
              0.5439571065375303, 0.49113282929782065`, 0.5895640895883777], 
             UndirectedEdge[69, 87] -> 
             RGBColor[
              0.8317026683208932, 0.8683093589322235, 0.930217903270566], 
             UndirectedEdge[47, 70] -> 
             RGBColor[
              0.7876349473835056, 0.8334331688194891, 0.9394169653061224], 
             UndirectedEdge[42, 78] -> 
             RGBColor[
              0.6043322657277533, 0.6739094757869251, 0.9434217400031519], 
             UndirectedEdge[1, 43] -> 
             RGBColor[
              0.7730561357019321, 0.822560314937985, 0.9640950907199684], 
             UndirectedEdge[10, 35] -> 
             RGBColor[
              0.9879498023446398, 0.9788156108882593, 0.6193074937242291], 
             UndirectedEdge[67, 94] -> 
             RGBColor[
              0.9034416826357663, 0.9252359113504967, 0.9695732413401196], 
             UndirectedEdge[73, 93] -> 
             RGBColor[
              0.8239771266491385, 0.6541973686423909, 0.5938520831796261], 
             UndirectedEdge[68, 82] -> 
             RGBColor[
              0.5869864430825171, 0.6486029881908895, 0.8178272330948331], 
             UndirectedEdge[11, 52] -> 
             RGBColor[
              0.9697906700574523, 0.9753978837772397, 0.8646995624167227], 
             UndirectedEdge[15, 53] -> 
             RGBColor[
              0.9684203593918352, 0.9384821605189562, 0.6306847994791214], 
             UndirectedEdge[53, 100] -> 
             RGBColor[
              0.9812034692316205, 0.9841367524048747, 0.8555561218816443], 
             UndirectedEdge[58, 83] -> 
             RGBColor[
              0.9946768036282996, 0.9916442979605176, 0.7071759024460238], 
             UndirectedEdge[74, 96] -> 
             RGBColor[
              0.7634129629550176, 0.7253831389403818, 0.6127767737061305], 
             UndirectedEdge[8, 87] -> 
             RGBColor[
              0.9563561421405058, 0.9665572263172113, 0.9424119552620913], 
             UndirectedEdge[43, 46] -> 
             RGBColor[
              0.5991672670109206, 0.6700574282008203, 0.9521647355833374], 
             UndirectedEdge[73, 89] -> 
             RGBColor[
              0.8443007841649173, 0.670107586908842, 0.5958689391822554], 
             UndirectedEdge[11, 67] -> 
             RGBColor[
              0.9525394079138538, 0.964124548648515, 0.9652225820836695], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.9778477587420353, 0.944739045744039, 0.5800629619389719], 
             UndirectedEdge[98, 99] -> 
             RGBColor[
              0.8975528638014527, 0.9191084546004842, 0.9075986979418885], 
             UndirectedEdge[4, 9] -> 
             RGBColor[
              0.9806891485002718, 0.9843787431872313, 0.8844410507387458], 
             UndirectedEdge[34, 49] -> 
             RGBColor[
              0.5755822299948893, 0.6421046618170698, 0.9326899589969586], 
             UndirectedEdge[6, 7] -> 
             RGBColor[
              0.9481732569968375, 0.9571753548905471, 0.7815337285533921], 
             UndirectedEdge[7, 40] -> 
             RGBColor[
              0.9364478574516975, 0.9512671734446805, 0.9627721161856995], 
             UndirectedEdge[23, 85] -> 
             RGBColor[
              0.9659668069872016, 0.9733892089242477, 0.9089306118989968], 
             UndirectedEdge[82, 92] -> 
             RGBColor[
              0.8788605468960766, 0.9031694561085651, 0.8395667306735256], 
             UndirectedEdge[34, 69] -> 
             RGBColor[
              0.8251295435542114, 0.8636051194926146, 0.9502107176894525], 
             UndirectedEdge[13, 85] -> 
             RGBColor[
              0.941491321950882, 0.9558849042269111, 0.9839241098166723], 
             UndirectedEdge[95, 98] -> 
             RGBColor[
              0.9877481058371936, 0.989201541151431, 0.8527091233707997], 
             UndirectedEdge[34, 87] -> 
             RGBColor[
              0.9788105847564605, 0.9835195630737485, 0.9118861035750306], 
             UndirectedEdge[61, 94] -> 
             RGBColor[
              0.9210200528302122, 0.9359116508375748, 0.8103577746392745], 
             UndirectedEdge[61, 72] -> 
             RGBColor[
              0.9865281750038868, 0.9870391352707633, 0.7782285939555842], 
             UndirectedEdge[50, 86] -> 
             RGBColor[
              0.9806513377723971, 0.9551304128329297, 0.5974117463680384], 
             UndirectedEdge[66, 97] -> 
             RGBColor[
              0.5841788264707264, 0.6407016259750626, 0.6734707559208011], 
             UndirectedEdge[9, 21] -> 
             RGBColor[
              0.983977498543295, 0.9856867005137877, 0.826174911609616], 
             UndirectedEdge[34, 60] -> 
             RGBColor[
              0.9783248792264947, 0.9833187113550448, 0.9199355011721821], 
             UndirectedEdge[53, 84] -> 
             RGBColor[
              0.9776222000075665, 0.9826558055463075, 0.9149070209518764], 
             UndirectedEdge[21, 22] -> 
             RGBColor[
              0.9521045493166309, 0.8345300399415683, 0.4834685465851558], 
             UndirectedEdge[14, 62] -> 
             RGBColor[
              0.9538194916384182, 0.9650792329943503, 0.9630557342372881], 
             UndirectedEdge[22, 30] -> 
             RGBColor[
              0.9506989010718142, 0.8340006281917995, 0.5105334446419348], 
             UndirectedEdge[67, 72] -> 
             RGBColor[
              0.9689498048094409, 0.9763633957836851, 0.9374440606564294], 
             UndirectedEdge[61, 86] -> 
             RGBColor[
              0.9913261661622277, 0.9899482978208233, 0.7401399839588374], 
             UndirectedEdge[5, 83] -> 
             RGBColor[
              0.9639155694878636, 0.8817489398975633, 0.4697671716954186], 
             UndirectedEdge[46, 99] -> 
             RGBColor[
              0.5265219697336562, 0.6126510496368038, 0.9593439092009686], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.5821553547615712, 0.6468089012566787, 0.912697144578072], 
             UndirectedEdge[7, 37] -> 
             RGBColor[
              0.8783149497208085, 0.9058085159559224, 0.9882556580570243], 
             UndirectedEdge[7, 53] -> 
             RGBColor[
              0.936244056016208, 0.9511151786677867, 0.9631170988560558], 
             UndirectedEdge[12, 52] -> 
             RGBColor[
              0.9686673905084746, 0.9745601437288136, 0.8666009816949152], 
             UndirectedEdge[50, 85] -> 
             RGBColor[
              0.9581566290210999, 0.9390230672777584, 0.6654562832065027], 
             UndirectedEdge[14, 15] -> 
             RGBColor[
              0.9588059078583405, 0.9313117183074953, 0.6469595580747629], 
             UndirectedEdge[14, 35] -> 
             RGBColor[
              0.9689079514609449, 0.9653882834517158, 0.68620408986002], 
             UndirectedEdge[8, 95] -> 
             RGBColor[
              0.956970173482472, 0.9668111440570001, 0.9322358668635359], 
             UndirectedEdge[7, 84] -> 
             RGBColor[
              0.9438699066291014, 0.9566270771923024, 0.9423515861517577], 
             UndirectedEdge[14, 76] -> 
             RGBColor[
              0.9629148585594044, 0.9718625427517253, 0.9476596504916736], 
             UndirectedEdge[60, 89] -> 
             RGBColor[
              0.9042533317016075, 0.9251982962531126, 0.9455380673138953], 
             UndirectedEdge[37, 85] -> 
             RGBColor[
              0.8986842821687997, 0.9218562539605673, 0.983464954877205], 
             UndirectedEdge[39, 80] -> 
             RGBColor[
              0.9672082402901545, 0.9691278972517825, 0.6997107135233711], 
             UndirectedEdge[23, 24] -> 
             RGBColor[
              0.974183563275189, 0.979517252310125, 0.8950217867766961], 
             UndirectedEdge[11, 68] -> 
             RGBColor[
              0.5623650344642319, 0.632247299031477, 0.955063223433672], 
             UndirectedEdge[27, 81] -> 
             RGBColor[
              0.9142384865839799, 0.9343989004299056, 0.9898074812225133], 
             UndirectedEdge[36, 61] -> 
             RGBColor[
              0.8106784766707023, 0.8492522641162228, 0.7995808604237287], 
             UndirectedEdge[28, 59] -> 
             RGBColor[
              0.5664011314209674, 0.635257413533308, 0.948231164068597], 
             UndirectedEdge[8, 30] -> 
             RGBColor[
              0.9598695819132186, 0.9680101239545116, 0.8841851657375764], 
             UndirectedEdge[34, 82] -> 
             RGBColor[
              0.9836416730774065, 0.9853136500079593, 0.8170161920917918], 
             UndirectedEdge[50, 84] -> 
             RGBColor[
              0.9791654405644673, 0.9545159561516343, 0.6220369084821427], 
             UndirectedEdge[57, 88] -> 
             RGBColor[
              0.99033162742613, 0.9902698937219325, 0.8098934847025763], 
             UndirectedEdge[6, 53] -> 
             RGBColor[
              0.9819255503753026, 0.9832040832445521, 0.7540891633535107], 
             UndirectedEdge[8, 69] -> 
             RGBColor[
              0.8026751009382567, 0.8466427827360775, 0.9807365693765133], 
             UndirectedEdge[69, 99] -> 
             RGBColor[
              0.7421214576271187, 0.7984701901210653, 0.9749313894430993], 
             UndirectedEdge[81, 84] -> 
             RGBColor[
              0.9615218866039, 0.9706482181716967, 0.9421606519100223], 
             UndirectedEdge[11, 94] -> 
             RGBColor[
              0.8967053436503762, 0.9202119607649355, 0.980976106123794], 
             UndirectedEdge[10, 65] -> 
             RGBColor[
              0.9785677827158176, 0.9827624141839206, 0.8864996233315212], 
             UndirectedEdge[79, 98] -> 
             RGBColor[
              0.9672327589647025, 0.9743032411232688, 0.9054391766025451], 
             UndirectedEdge[33, 62] -> 
             RGBColor[
              0.9662656369168685, 0.9743615477643262, 0.9419876567554478], 
             UndirectedEdge[31, 70] -> 
             RGBColor[
              0.7948237147650344, 0.8367884269605179, 0.8317537050155654], 
             UndirectedEdge[31, 32] -> 
             RGBColor[
              0.9927152861483388, 0.9855189905362451, 0.5597107039431761], 
             UndirectedEdge[15, 100] -> 
             RGBColor[
              0.9796274792287827, 0.9454750059020391, 0.5505683877045913], 
             UndirectedEdge[7, 65] -> 
             RGBColor[
              0.9353880899871523, 0.9504768006048327, 0.9645660260715521], 
             UndirectedEdge[59, 95] -> 
             RGBColor[
              0.5827693861035375, 0.6470628189964673, 0.9025210561795165], 
             UndirectedEdge[2, 3] -> 
             RGBColor[
              0.8117701440677967, 0.49133623244552055`, 0.5727691307506053], 
             UndirectedEdge[48, 88] -> 
             RGBColor[
              0.9773932550290355, 0.9822275588066784, 0.9037631912401066], 
             UndirectedEdge[14, 38] -> 
             RGBColor[
              0.8937714762407456, 0.9177445569063118, 0.9762578198471811], 
             UndirectedEdge[44, 45] -> 
             RGBColor[
              0.9690709811965862, 0.9762783205584141, 0.9293820038838074], 
             UndirectedEdge[24, 50] -> 
             RGBColor[
              0.9663733853090872, 0.9451511106636359, 0.651547458084202], 
             UndirectedEdge[38, 62] -> 
             RGBColor[
              0.8968235215514802, 0.9200207673017922, 0.9710915032370115], 
             UndirectedEdge[4, 50] -> 
             RGBColor[
              0.9808640079903148, 0.9552183574334139, 0.5938872504842614], 
             UndirectedEdge[48, 74] -> 
             RGBColor[
              0.7812944582793893, 0.8287044424272374, 0.9501497594949844], 
             UndirectedEdge[40, 100] -> 
             RGBColor[
              0.98140727066711, 0.9842887471817686, 0.855211139211288], 
             UndirectedEdge[19, 95] -> 
             RGBColor[
              0.965546753203404, 0.9031636224999507, 0.5728640081980962], 
             UndirectedEdge[19, 79] -> 
             RGBColor[
              0.9450314063309129, 0.8882653224717886, 0.6255940614298418], 
             UndirectedEdge[51, 70] -> 
             RGBColor[
              0.7882901312575976, 0.8339218038800218, 0.9383079099066066], 
             UndirectedEdge[17, 22] -> 
             RGBColor[
              0.937915791232029, 0.788346036305881, 0.28566212223941184`], 
             UndirectedEdge[59, 99] -> 
             RGBColor[
              0.4925741440677966, 0.5769697324455205, 0.9574106307506054], 
             UndirectedEdge[20, 63] -> 
             RGBColor[
              0.8158469825061829, 0.8547806815834949, 0.8783218020002128], 
             UndirectedEdge[56, 89] -> 
             RGBColor[
              0.501510682470002, 0.5839842467151375, 0.9582925251386718], 
             UndirectedEdge[12, 74] -> 
             RGBColor[
              0.7690784492721254, 0.8195937629114989, 0.9708282762988585], 
             UndirectedEdge[8, 17] -> 
             RGBColor[
              0.9470864720734333, 0.922355532068593, 0.6593138433350535], 
             UndirectedEdge[53, 90] -> 
             RGBColor[
              0.9182627101785463, 0.9367773415874656, 0.9614020220379227], 
             UndirectedEdge[21, 72] -> 
             RGBColor[
              0.9869228741389198, 0.9878833568103946, 0.8211891590032099], 
             UndirectedEdge[48, 73] -> 
             RGBColor[
              0.9162478656174333, 0.7266435786924939, 0.5738625399515738], 
             UndirectedEdge[8, 49] -> 
             RGBColor[
              0.5531277873789346, 0.6251423250605327, 0.9632158106840194], 
             UndirectedEdge[17, 69] -> 
             RGBColor[
              0.8224329982538208, 0.8241076646836051, 0.647119791343528], 
             UndirectedEdge[21, 82] -> 
             RGBColor[
              0.9951338858616179, 0.9920001988346372, 0.7117316900916113], 
             UndirectedEdge[36, 68] -> 
             RGBColor[
              0.4029257330266345, 0.5066992750121065, 0.9486369684745763], 
             UndirectedEdge[21, 30] -> 
             RGBColor[
              0.9938162373133848, 0.9916590095377266, 0.7483748120503353], 
             UndirectedEdge[56, 64] -> 
             RGBColor[
              0.5797982530266343, 0.6452489648910411, 0.9255533317191282], 
             UndirectedEdge[48, 64] -> 
             RGBColor[
              0.9743290169491525, 0.9803752033898305, 0.9283384576271185], 
             UndirectedEdge[46, 59] -> 
             RGBColor[
              0.21287482566585958`, 0.3410753171912833, 0.9354342784503632], 
             UndirectedEdge[46, 79] -> 
             RGBColor[
              0.596201864896906, 0.6678458361595885, 0.9571843878616252], 
             UndirectedEdge[9, 86] -> 
             RGBColor[
              0.9804764782823541, 0.9842907985867471, 0.8879655466225228], 
             UndirectedEdge[64, 91] -> 
             RGBColor[
              0.5797982530266343, 0.6452489648910412, 0.9255533317191282], 
             UndirectedEdge[1, 19] -> 
             RGBColor[
              0.7695410614567377, 0.7496790074319313, 0.6177075856055738], 
             UndirectedEdge[5, 69] -> 
             RGBColor[
              0.8055302215496367, 0.7603115823728811, 0.6167610904116223], 
             UndirectedEdge[36, 92] -> 
             RGBColor[
              0.6947998368401939, 0.7612657429297822, 0.9703764660532688], 
             UndirectedEdge[17, 95] -> 
             RGBColor[
              0.9767280707980361, 0.9442760260045276, 0.5986190888305507], 
             UndirectedEdge[7, 13] -> 
             RGBColor[
              0.9211219895028908, 0.9398371662222662, 0.9887148129964916], 
             UndirectedEdge[11, 61] -> 
             RGBColor[
              0.9701177781082997, 0.9748002881355933, 0.8060071153828243], 
             UndirectedEdge[66, 83] -> 
             RGBColor[
              0.586859661497549, 0.6483318152002271, 0.8040278399762903], 
             UndirectedEdge[27, 37] -> 
             RGBColor[
              0.872409693692247, 0.9010998250926521, 0.9876924094653358], 
             UndirectedEdge[22, 34] -> 
             RGBColor[
              0.9406123365324195, 0.8278434911148904, 0.5887530485853364], 
             UndirectedEdge[6, 90] -> 
             RGBColor[
              0.9301919111591759, 0.9428375178102258, 0.779818651735259], 
             UndirectedEdge[71, 77] -> 
             RGBColor[
              0.9718071802292829, 0.9784700638543262, 0.9315164755991499], 
             UndirectedEdge[9, 68] -> 
             RGBColor[
              0.5758300557641943, 0.6422894898700401, 0.9322704546128378], 
             UndirectedEdge[23, 86] -> 
             RGBColor[
              0.9884615157384988, 0.989496554479419, 0.8408860750605325], 
             UndirectedEdge[54, 84] -> 
             RGBColor[
              0.9763669750931128, 0.9450760750058156, 0.6111653985717911], 
             UndirectedEdge[3, 16] -> 
             RGBColor[
              0.896435810054798, 0.5577073823117116, 0.5452426083216515], 
             UndirectedEdge[66, 98] -> 
             RGBColor[
              0.5839057197336561, 0.6475327221549636, 0.8836890671912832], 
             UndirectedEdge[64, 93] -> 
             RGBColor[
              0.8820582779808577, 0.9079289933397277, 0.9483280008551709], 
             UndirectedEdge[2, 29] -> 
             RGBColor[
              0.8613233025251975, 0.7774533633050427, 0.6164661568110793], 
             UndirectedEdge[50, 81] -> 
             RGBColor[
              0.9554392765479073, 0.9369964702525077, 0.6700560521445865], 
             UndirectedEdge[8, 99] -> 
             RGBColor[
              0.8667749314467312, 0.8967180575060533, 0.9871254414346247], 
             UndirectedEdge[66, 69] -> 
             RGBColor[
              0.4284743135593221, 0.5268944576755448, 0.951021758692494], 
             UndirectedEdge[9, 30] -> 
             RGBColor[
              0.9825718502984783, 0.985157288764019, 0.8532398096663949], 
             UndirectedEdge[11, 36] -> 
             RGBColor[
              0.7863637674908663, 0.8335525740435836, 0.9701991919082482], 
             UndirectedEdge[16, 62] -> 
             RGBColor[
              0.9662120785293744, 0.9743216040066268, 0.9420783171352107], 
             UndirectedEdge[50, 76] -> 
             RGBColor[
              0.9740725506497998, 0.9508931355685131, 0.6385147794262982], 
             UndirectedEdge[36, 86] -> 
             RGBColor[
              0.8075721555447943, 0.8487005837288136, 0.9043320604842613], 
             UndirectedEdge[60, 71] -> 
             RGBColor[
              0.9718440226812274, 0.978485299155013, 0.930905900825221], 
             UndirectedEdge[43, 54] -> 
             RGBColor[
              0.9594988911279437, 0.9326713339799408, 0.647575601580976], 
             UndirectedEdge[29, 42] -> 
             RGBColor[
              0.5816239841232604, 0.5415589480508054, 0.5944898045108371], 
             UndirectedEdge[76, 84] -> 
             RGBColor[
              0.9801551607057926, 0.984544883487702, 0.9106193791917341], 
             UndirectedEdge[65, 90] -> 
             RGBColor[
              0.9174067441494906, 0.9361389635245116, 0.962850949253419], 
             UndirectedEdge[52, 78] -> 
             RGBColor[
              0.9778100756551141, 0.9813787433414044, 0.8511248005358396], 
             UndirectedEdge[25, 65] -> 
             RGBColor[
              0.971140840128343, 0.9499079771858823, 0.6460275470235309], 
             UndirectedEdge[45, 52] -> 
             RGBColor[
              0.9895131609034504, 0.9899314367811745, 0.82345759310684], 
             UndirectedEdge[57, 74] -> 
             RGBColor[
              0.7942328306764838, 0.8367467773424915, 0.856280052957454], 
             UndirectedEdge[17, 66] -> 
             RGBColor[
              0.5728856846944987, 0.6026072070080603, 0.6295990326510341], 
             UndirectedEdge[59, 98] -> 
             RGBColor[
              0.5839057197336561, 0.6475327221549636, 0.8836890671912832], 
             UndirectedEdge[22, 77] -> 
             RGBColor[
              0.9466629133171912, 0.8323316435351088, 0.5774202065375301], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.9611872304614517, 0.9683513132514223, 0.8475420437788524], 
             UndirectedEdge[30, 36] -> 
             RGBColor[
              0.8096675275609184, 0.8495670739060854, 0.8696063235281334], 
             UndirectedEdge[60, 64] -> 
             RGBColor[
              0.9825409022582399, 0.9864630144290162, 0.9127988738943518], 
             UndirectedEdge[28, 99] -> 
             RGBColor[
              0.880048275488764, 0.9068331459788286, 0.9721407948192022], 
             UndirectedEdge[59, 69] -> 
             RGBColor[
              0.4284743135593221, 0.5268944576755448, 0.951021758692494], 
             UndirectedEdge[66, 79] -> 
             RGBColor[
              0.5622540392310464, 0.6321645189683052, 0.955251109411262], 
             UndirectedEdge[7, 81] -> 
             RGBColor[
              0.9201437426125414, 0.9391075912931759, 0.9903707298142017], 
             UndirectedEdge[26, 100] -> 
             RGBColor[
              0.985517225894103, 0.9873539450606259, 0.8482540570599889], 
             UndirectedEdge[5, 97] -> 
             RGBColor[
              0.961234734461041, 0.8741187506723989, 0.3392100876399293], 
             UndirectedEdge[20, 83] -> 
             RGBColor[
              0.9931072601780659, 0.9909952514084192, 0.7331872992646387], 
             UndirectedEdge[21, 92] -> 
             RGBColor[
              0.8789485465926601, 0.9033576785614232, 0.8491449545754706], 
             UndirectedEdge[77, 98] -> 
             RGBColor[
              0.9866115265133171, 0.9887315363922519, 0.8715451841404356], 
             UndirectedEdge[13, 84] -> 
             RGBColor[
              0.9625001334942493, 0.971377793100787, 0.9405047350923121], 
             UndirectedEdge[83, 97] -> 
             RGBColor[
              0.9921114879682753, 0.9836394411752896, 0.5439975958970914], 
             UndirectedEdge[4, 24] -> 
             RGBColor[
              0.9741545627909275, 0.9795052598646045, 0.8955023998517566], 
             UndirectedEdge[7, 85] -> 
             RGBColor[
              0.9228610950857341, 0.9411341883184267, 0.9857709608761179], 
             UndirectedEdge[10, 40] -> 
             RGBColor[
              0.9796275501803626, 0.9835527870237684, 0.8847057134456686], 
             UndirectedEdge[26, 40] -> 
             RGBColor[
              0.974513907492645, 0.9805130944544367, 0.9280254861641626], 
             UndirectedEdge[56, 74] -> 
             RGBColor[
              0.3867636943568712, 0.493578203928448, 0.9473646335869941], 
             UndirectedEdge[42, 62] -> 
             RGBColor[
              0.6018470941404359, 0.6720560388861987, 0.9476284872639225], 
             UndirectedEdge[4, 36] -> 
             RGBColor[
              0.8077848257627119, 0.8487885283292979, 0.9008075646004843], 
             UndirectedEdge[2, 33] -> 
             RGBColor[
              0.8909405125100889, 0.9149565585149314, 0.9537030786924938], 
             UndirectedEdge[36, 82] -> 
             RGBColor[
              0.8109851761091516, 0.8499082632029962, 0.8329632015694094], 
             UndirectedEdge[76, 81] -> 
             RGBColor[
              0.9564289966892325, 0.9670253975885754, 0.9586385228541779], 
             UndirectedEdge[27, 43] -> 
             RGBColor[
              0.9210965666353709, 0.9395136453031576, 0.9781985405692544], 
             UndirectedEdge[61, 67] -> 
             RGBColor[
              0.9768541170936897, 0.9798242387211543, 0.79460425059915], 
             UndirectedEdge[10, 26] -> 
             RGBColor[
              0.9837375054073556, 0.9866179849026258, 0.8777486312943696], 
             UndirectedEdge[63, 83] -> 
             RGBColor[
              0.8175320453232149, 0.8550550605755297, 0.8196891826881547], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.9349888311017541, 0.9135354481272948, 0.6593754764759704], 
             UndirectedEdge[20, 97] -> 
             RGBColor[
              0.9904264251512434, 0.9833650621832547, 0.6026302152091494], 
             UndirectedEdge[28, 98] -> 
             RGBColor[
              0.9713798511546234, 0.9773961356882717, 0.8984192312598802], 
             UndirectedEdge[4, 23] -> 
             RGBColor[
              0.9886741859564164, 0.9895844990799032, 0.8373615791767555], 
             UndirectedEdge[30, 86] -> 
             RGBColor[
              0.9903152170524439, 0.990263107610686, 0.8101654470632421], 
             UndirectedEdge[27, 54] -> 
             RGBColor[
              0.9290835750731926, 0.9088267572640245, 0.6588122278842818], 
             UndirectedEdge[1, 13] -> 
             RGBColor[
              0.7671763025408905, 0.8181751449938233, 0.9740481145555171], 
             UndirectedEdge[15, 35] -> 
             RGBColor[
              0.9769464129916019, 0.933896979160341, 0.36494159708732543`], 
             UndirectedEdge[56, 73] -> 
             RGBColor[
              0.5217171016949151, 0.39151734019370443`, 0.5710774140435835], 
             UndirectedEdge[16, 29] -> 
             RGBColor[
              0.9459889685121989, 0.8438245131712336, 0.5889396343821255], 
             UndirectedEdge[53, 65] -> 
             RGBColor[
              0.9691403833656174, 0.9765055289588378, 0.9371214608716706], 
             UndirectedEdge[6, 25] -> 
             RGBColor[
              0.9839260071380282, 0.9566065314715966, 0.462995249505371], 
             UndirectedEdge[68, 92] -> 
             RGBColor[
              0.4708011038135594, 0.5599604679176755, 0.9552404975786926], 
             UndirectedEdge[69, 97] -> 
             RGBColor[
              0.8337261400300484, 0.8622020836506074, 0.690991514613295], 
             UndirectedEdge[17, 77] -> 
             RGBColor[
              0.9755914914741597, 0.9438060212453485, 0.6174551496001865], 
             UndirectedEdge[46, 98] -> 
             RGBColor[
              0.6178535453995158, 0.6832140393462469, 0.8856223456416463], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.9366484269319773, 0.8368583525544374, 0.6047507348740333], 
             UndirectedEdge[17, 55] -> 
             RGBColor[
              0.5728856846944987, 0.6026072070080603, 0.6295990326510341], 
             UndirectedEdge[2, 78] -> 
             RGBColor[
              0.8840315841296904, 0.9098038910411622, 0.965398092303394], 
             UndirectedEdge[6, 35] -> 
             RGBColor[
              0.9904516039750693, 0.9786189018859368, 0.4883459609617148], 
             UndirectedEdge[95, 99] -> 
             RGBColor[
              0.896416530171334, 0.9186385514419879, 0.9264306869301219], 
             UndirectedEdge[66, 99] -> 
             RGBColor[
              0.4925741440677966, 0.5769697324455205, 0.9574106307506054], 
             UndirectedEdge[31, 39] -> 
             RGBColor[
              0.9929535057830635, 0.9863225613008015, 0.5606361422400783], 
             UndirectedEdge[69, 71] -> 
             RGBColor[
              0.818648687008944, 0.8587717072925829, 0.9611811173424915], 
             UndirectedEdge[64, 89] -> 
             RGBColor[
              0.9023819354966365, 0.9238392116061788, 0.9503448568578001], 
             UndirectedEdge[40, 53] -> 
             RGBColor[
              0.9702001508301625, 0.9772959017986855, 0.935327550985818], 
             UndirectedEdge[1, 27] -> 
             RGBColor[
              0.742640819647181, 0.7987157382220686, 0.9753317170232743], 
             UndirectedEdge[41, 48] -> 
             RGBColor[
              0.9800133849878935, 0.9833110498789347, 0.860340857142857], 
             UndirectedEdge[57, 70] -> 
             RGBColor[
              0.7942328306764838, 0.8367467773424915, 0.856280052957454], 
             UndirectedEdge[39, 44] -> 
             RGBColor[
              0.9718769412612565, 0.972609806791734, 0.6918078205715251], 
             UndirectedEdge[6, 15] -> 
             RGBColor[
              0.9803495603724648, 0.9445423367417165, 0.4491014291764577], 
             UndirectedEdge[6, 40] -> 
             RGBColor[
              0.9821293518107921, 0.9833560780214459, 0.7537441806831544], 
             UndirectedEdge[17, 59] -> 
             RGBColor[
              0.5728856846944987, 0.6026072070080603, 0.6295990326510341], 
             UndirectedEdge[56, 91] -> RGBColor[0.178927, 0.305394, 0.933501],
              UndirectedEdge[5, 59] -> 
             RGBColor[
              0.5559829079903147, 0.5388111246973363, 0.5992403317191284], 
             UndirectedEdge[20, 58] -> 
             RGBColor[
              0.9929917408112676, 0.9913699189684827, 0.7658085217580819], 
             UndirectedEdge[17, 19] -> 
             RGBColor[
              0.9556630517943652, 0.8587080105115437, 0.2999419846696139], 
             UndirectedEdge[3, 38] -> 
             RGBColor[
              0.8270472530769037, 0.5034065456068768, 0.5742557944234523], 
             UndirectedEdge[1, 17] -> 
             RGBColor[
              0.7807223790513699, 0.7907914109365082, 0.6434626662380283], 
             UndirectedEdge[2, 42] -> 
             RGBColor[
              0.5265219697336563, 0.6126510496368038, 0.9593439092009686], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.9621130079418887, 0.971264523874092, 0.9490169744309926], 
             UndirectedEdge[48, 56] -> 
             RGBColor[
              0.5734577639225181, 0.6405202384987894, 0.9362861259079902], 
             UndirectedEdge[86, 94] -> 
             RGBColor[
              0.9179137317043041, 0.9353599704501656, 0.9151089746998071], 
             UndirectedEdge[23, 30] -> 
             RGBColor[
              0.9905568877546229, 0.9903630446566908, 0.8061603381044046], 
             UndirectedEdge[30, 82] -> 
             RGBColor[
              0.9937282376168011, 0.9914707870848685, 0.7387965881483902], 
             UndirectedEdge[60, 74] -> 
             RGBColor[
              0.7895063435884766, 0.8347922534664229, 0.9346101757622176], 
             UndirectedEdge[10, 90] -> 
             RGBColor[
              0.9276901095287464, 0.9430342268125483, 0.9107801844977732], 
             UndirectedEdge[49, 69] -> 
             RGBColor[
              0.4284743135593221, 0.5268944576755448, 0.951021758692494], 
             UndirectedEdge[25, 100] -> 
             RGBColor[
              0.9832039259943461, 0.9575392006319192, 0.5644622080335047], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.9693441848011068, 0.9766575237357316, 0.9367764782013143], 
             UndirectedEdge[31, 51] -> 
             RGBColor[
              0.9885134573088896, 0.9889478229836439, 0.8088333477481839], 
             UndirectedEdge[37, 50] -> 
             RGBColor[
              0.9136104836561744, 0.9036973949152541, 0.667940980387409], 
             UndirectedEdge[6, 10] -> 
             RGBColor[
              0.9913529497255028, 0.9894609684696348, 0.7034673258133612], 
             UndirectedEdge[69, 77] -> 
             RGBColor[
              0.831180120338983, 0.8680932719128329, 0.9388778756416463], 
             UndirectedEdge[12, 96] -> 
             RGBColor[
              0.9378910235134007, 0.8632144939949846, 0.6223767828310007], 
             UndirectedEdge[12, 41] -> 
             RGBColor[
              0.9677973759806295, 0.9742003703631962, 0.8810193739467311], 
             UndirectedEdge[89, 93] -> 
             RGBColor[
              0.8037707074242253, 0.846664275163824, 0.9810671942747144], 
             UndirectedEdge[37, 81] -> 
             RGBColor[
              0.8959669296956071, 0.9198296569353165, 0.9880647238152889], 
             UndirectedEdge[14, 24] -> 
             RGBColor[
              0.9552156932186918, 0.9661205178468482, 0.9606923291495775], 
             UndirectedEdge[52, 67] -> 
             RGBColor[
              0.9765270090428423, 0.9804218343628008, 0.8532966976330483], 
             UndirectedEdge[23, 27] -> 
             RGBColor[
              0.9396922185106489, 0.9526327800563326, 0.9131580664871275], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.9726487301014843, 0.9779208497415002, 0.8773906233569453], 
             UndirectedEdge[23, 81] -> 
             RGBColor[
              0.9632494545140089, 0.9713626118989969, 0.9135303808370806], 
             UndirectedEdge[88, 96] -> 
             RGBColor[
              0.9595117597046638, 0.8789062553198228, 0.5663902054512527], 
             UndirectedEdge[77, 95] -> 
             RGBColor[
              0.9854751928831984, 0.9882616332337555, 0.8903771731286689], 
             UndirectedEdge[74, 91] -> 
             RGBColor[
              0.3867636943568712, 0.493578203928448, 0.9473646335869941], 
             UndirectedEdge[7, 100] -> 
             RGBColor[
              0.9474511758531554, 0.9581080240508697, 0.8830006870815257], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.9894181121718927, 0.9898921316880342, 0.8250327965669831], 
             UndirectedEdge[6, 100] -> 
             RGBColor[
              0.99313267021225, 0.9901969286276351, 0.6739727515789806], 
             UndirectedEdge[19, 55] -> 
             RGBColor[
              0.5617043670998665, 0.5614948035034834, 0.6038439520185798], 
             UndirectedEdge[17, 28] -> 
             RGBColor[
              0.9603598161154661, 0.9324706205413683, 0.6443291967196312], 
             UndirectedEdge[64, 96] -> 
             RGBColor[
              0.9564475216247807, 0.8770538999029749, 0.5909654718382646], 
             UndirectedEdge[67, 68] -> 
             RGBColor[
              0.569101373449622, 0.6372712496170381, 0.9436603586499975], 
             UndirectedEdge[22, 87] -> 
             RGBColor[
              0.9471854612991015, 0.8325477305544993, 0.5687602341664497], 
             UndirectedEdge[42, 44] -> 
             RGBColor[
              0.5998582815522158, 0.6705727857142858, 0.9509950282103814], 
             UndirectedEdge[70, 96] -> 
             RGBColor[
              0.7634129629550176, 0.7253831389403818, 0.6127767737061305], 
             UndirectedEdge[64, 88] -> 
             RGBColor[
              0.9837337441331517, 0.9869562851989302, 0.8930303970512447], 
             UndirectedEdge[26, 65] -> 
             RGBColor[
              0.9734541400280998, 0.979722721614589, 0.9298193960500152], 
             UndirectedEdge[2, 14] -> 
             RGBColor[
              0.8784943672316384, 0.9056742437449556, 0.9747711561743341], 
             UndirectedEdge[11, 72] -> 
             RGBColor[
              0.9622134658240509, 0.9713394451981241, 0.9488469254401037], 
             UndirectedEdge[67, 86] -> 
             RGBColor[
              0.9737477959677818, 0.9792725583337452, 0.8993554506596826], 
             UndirectedEdge[40, 90] -> 
             RGBColor[
              0.9184665116140358, 0.9369293363643594, 0.9610570393675664], 
             UndirectedEdge[27, 84] -> 
             RGBColor[
              0.9379646506005399, 0.9519183863290324, 0.9417883375600693], 
             UndirectedEdge[13, 43] -> 
             RGBColor[
              0.9456320495290804, 0.9589730520749122, 0.9769149381014972], 
             UndirectedEdge[52, 72] -> 
             RGBColor[
              0.9862010669530393, 0.9876367309124098, 0.8369210409894826], 
             UndirectedEdge[10, 53] -> 
             RGBColor[
              0.9794237487448731, 0.9834007922468746, 0.8850506961160249], 
             UndirectedEdge[15, 40] -> 
             RGBColor[
              0.9686241608273247, 0.9386341552958499, 0.630339816808765], 
             UndirectedEdge[21, 68] -> 
             RGBColor[
              0.5870744427791007, 0.6487912106437477, 0.8274054569967781], 
             UndirectedEdge[28, 83] -> 
             RGBColor[
              0.9743337929185163, 0.978195228733535, 0.8187580040448873], 
             UndirectedEdge[54, 100] -> 
             RGBColor[
              0.9799482443171668, 0.9465570218643828, 0.5518144995015589], 
             UndirectedEdge[47, 96] -> 
             RGBColor[
              0.9564475216247807, 0.8770538999029749, 0.5909654718382646], 
             UndirectedEdge[47, 51] -> 
             RGBColor[
              0.9813246899273608, 0.9855925648426151, 0.9164966080387408], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.961857953169075, 0.9335879287029756, 0.6417932414645935], 
             UndirectedEdge[39, 45] -> 
             RGBColor[
              0.9880540106851303, 0.9844991903041432, 0.6565673249352961], 
             UndirectedEdge[58, 97] -> 
             RGBColor[
              0.991995968601477, 0.9840141087353531, 0.5766188183905345], 
             UndirectedEdge[31, 45] -> 
             RGBColor[
              0.9901475457183933, 0.9899910750674816, 0.7982103255523606], 
             UndirectedEdge[6, 26] -> 
             RGBColor[
              0.9862393070377851, 0.9864212759003033, 0.7467870985318553], 
             UndirectedEdge[41, 91] -> 
             RGBColor[
              0.5854826210653753, 0.6481848113801453, 0.8575557312348667], 
             UndirectedEdge[8, 22] -> 
             RGBColor[
              0.9181578939164649, 0.8108811543583534, 0.6192789002723971], 
             UndirectedEdge[46, 95] -> 
             RGBColor[
              0.6167172117693971, 0.6827441361877506, 0.9044543346298797], 
             UndirectedEdge[66, 95] -> 
             RGBColor[
              0.5827693861035375, 0.6470628189964673, 0.9025210561795165], 
             UndirectedEdge[23, 37] -> 
             RGBColor[
              0.921420661622276, 0.9380635365617433, 0.9114153090799031], 
             UndirectedEdge[10, 100] -> 
             RGBColor[
              0.9906308685818206, 0.9903936376299576, 0.8049342843414948], 
             UndirectedEdge[5, 79] -> 
             RGBColor[
              0.9393099472213611, 0.8655816436656415, 0.6209904411303904], 
             UndirectedEdge[38, 42] -> 
             RGBColor[
              0.5417990787427633, 0.6247213627981602, 0.9608305728738156], 
             UndirectedEdge[40, 54] -> 
             RGBColor[
              0.9689449259157088, 0.9397161712581936, 0.6315859286057326], 
             UndirectedEdge[32, 45] -> 
             RGBColor[
              0.9878157910504055, 0.9836956195395867, 0.655641886638394], 
             UndirectedEdge[41, 60] -> 
             RGBColor[
              0.9882252702969807, 0.9893988609181203, 0.8448012734100903], 
             UndirectedEdge[88, 91] -> 
             RGBColor[
              0.5828624911065173, 0.647101320307889, 0.9009780653321164], 
             UndirectedEdge[47, 57] -> 
             RGBColor[
              0.9872673893462469, 0.9884175383050848, 0.8344687510895882], 
             UndirectedEdge[27, 85] -> 
             RGBColor[
              0.9169558390571726, 0.9364254974551565, 0.9852077122844294], 
             UndirectedEdge[69, 95] -> 
             RGBColor[
              0.8323166996628595, 0.8685632766720122, 0.9200418148720104], 
             UndirectedEdge[36, 72] -> 
             RGBColor[
              0.8027741643864534, 0.8457914211787536, 0.9424206704810081], 
             UndirectedEdge[6, 65] -> 
             RGBColor[
              0.981069584346247, 0.9825657051815981, 0.755538090569007], 
             UndirectedEdge[49, 77] -> 
             RGBColor[
              0.581632806779661, 0.6465928142372881, 0.9213571169491523], 
             UndirectedEdge[2, 62] -> 
             RGBColor[
              0.8815464125423729, 0.9079504541404358, 0.9696048395641645], 
             UndirectedEdge[22, 66] -> 
             RGBColor[
              0.5439571065375303, 0.49113282929782065`, 0.5895640895883777], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.9258885607914398, 0.9422892401119813, 0.9406365093336246], 
             UndirectedEdge[73, 88] -> 
             RGBColor[
              0.9256525928014325, 0.7332246605015934, 0.5385544793756998], 
             UndirectedEdge[8, 21] -> 
             RGBColor[
              0.9612752301580354, 0.9685395357042803, 0.8571202676807974], 
             UndirectedEdge[31, 75] -> 
             RGBColor[
              0.5869870204081633, 0.64860422303207, 0.8178900714285714], 
             UndirectedEdge[4, 30] -> 
             RGBColor[
              0.9905278872703615, 0.9903510522111703, 0.8066409511794651], 
             UndirectedEdge[48, 91] -> 
             RGBColor[
              0.5734577639225181, 0.6405202384987894, 0.9362861259079902], 
             UndirectedEdge[19, 28] -> 
             RGBColor[
              0.9491784985208338, 0.8913582170367914, 0.6185741160871767], 
             UndirectedEdge[28, 66] -> 
             RGBColor[
              0.5664011314209674, 0.635257413533308, 0.948231164068597], 
             UndirectedEdge[3, 29] -> 
             RGBColor[
              0.8668721584574008, 0.4202441308595221, 0.20791502606047402`], 
             UndirectedEdge[22, 82] -> 
             RGBColor[
              0.9520165496200474, 0.8343418174887102, 0.47389032268321085`], 
             UndirectedEdge[49, 82] -> 
             RGBColor[
              0.5869864430825171, 0.6486029881908895, 0.8178272330948331], 
             UndirectedEdge[23, 84] -> 
             RGBColor[
              0.9869756185305689, 0.9888820977981235, 0.8655112371746367], 
             UndirectedEdge[65, 100] -> 
             RGBColor[
              0.9803475032025648, 0.9834983743419208, 0.8570050490971406], 
             UndirectedEdge[53, 85] -> 
             RGBColor[
              0.9566133884641992, 0.9671629166724317, 0.9583263956762365], 
             UndirectedEdge[59, 97] -> 
             RGBColor[
              0.5841788264707264, 0.6407016259750626, 0.6734707559208011], 
             UndirectedEdge[17, 98] -> 
             RGBColor[
              0.9778644044281548, 0.944745929163024, 0.5797870998423174], 
             UndirectedEdge[61, 68] -> 
             RGBColor[
              0.5866797436440678, 0.6479469891041162, 0.7844448919491525], 
             UndirectedEdge[28, 55] -> 
             RGBColor[
              0.5664011314209674, 0.635257413533308, 0.948231164068597], 
             UndirectedEdge[9, 36] -> 
             RGBColor[
              0.7998287887908287, 0.8435947648821467, 0.9474064230874141], 
             UndirectedEdge[20, 59] -> 
             RGBColor[
              0.585174598680517, 0.6480574362081921, 0.8626604592883484], 
             UndirectedEdge[48, 57] -> 
             RGBColor[
              0.9809269002421308, 0.983688811912833, 0.8452015452784502], 
             UndirectedEdge[1, 46] -> 
             RGBColor[
              0.42071152002273077`, 0.5292595211197313, 0.9492979120373572], 
             UndirectedEdge[5, 66] -> 
             RGBColor[
              0.5559829079903147, 0.5388111246973363, 0.5992403317191284], 
             UndirectedEdge[64, 74] -> 
             RGBColor[
              0.7876349473835056, 0.8334331688194891, 0.9394169653061224], 
             UndirectedEdge[55, 79] -> 
             RGBColor[
              0.5622540392310464, 0.6321645189683052, 0.955251109411262], 
             UndirectedEdge[32, 51] -> 
             RGBColor[
              0.9861817026409019, 0.982652367455749, 0.6662649088342173], 
             UndirectedEdge[64, 73] -> 
             RGBColor[
              0.9225883547215497, 0.7313723050847456, 0.5631297457627118], 
             UndirectedEdge[35, 38] -> 
             RGBColor[
              0.9119119813740069, 0.9203298177591576, 0.6942398588597436], 
             UndirectedEdge[71, 87] -> 
             RGBColor[
              0.9723297282111931, 0.9786861508737168, 0.9228565032280696], 
             UndirectedEdge[82, 87] -> 
             RGBColor[
              0.9902147978440884, 0.9900178894475682, 0.7970233776729051], 
             UndirectedEdge[5, 77] -> 
             RGBColor[
              0.9586887147699756, 0.8800099389346245, 0.5870964486682806], 
             UndirectedEdge[57, 64] -> 
             RGBColor[
              0.9872673893462469, 0.9884175383050848, 0.8344687510895882], 
             UndirectedEdge[63, 97] -> 
             RGBColor[
              0.8148512102963923, 0.8474248713503653, 0.6891320986326654], 
             UndirectedEdge[41, 93] -> 
             RGBColor[
              0.8877426460195986, 0.9108648398288317, 0.8803304003709094], 
             UndirectedEdge[9, 61] -> 
             RGBColor[
              0.9835827994082621, 0.9848424789741563, 0.7832143465619903], 
             UndirectedEdge[17, 46] -> 
             RGBColor[
              0.6068335103603584, 0.6382885241993436, 0.6315323111013973], 
             UndirectedEdge[25, 54] -> 
             RGBColor[
              0.970741581242945, 0.9129666247083443, 0.34083699742794926`], 
             UndirectedEdge[59, 77] -> 
             RGBColor[
              0.581632806779661, 0.6465928142372881, 0.9213571169491523], 
             UndirectedEdge[66, 77] -> 
             RGBColor[
              0.581632806779661, 0.6465928142372881, 0.9213571169491523], 
             UndirectedEdge[7, 27] -> 
             RGBColor[
              0.8965865066091813, 0.9203777594505115, 0.9899984154642487], 
             UndirectedEdge[61, 92] -> 
             RGBColor[
              0.8785538474576272, 0.9025134570217919, 0.8061843895278449], 
             UndirectedEdge[77, 87] -> 
             RGBColor[
              0.9848611615412322, 0.9880077154939668, 0.9005532615272244], 
             UndirectedEdge[28, 79] -> 
             RGBColor[
              0.9497281706520138, 0.9620279325016132, 0.969981273479859], 
             UndirectedEdge[5, 28] -> 
             RGBColor[
              0.943457039411282, 0.8686745382306443, 0.6139704957877252], 
             UndirectedEdge[56, 88] -> 
             RGBColor[
              0.5828624911065174, 0.647101320307889, 0.9009780653321164], 
             UndirectedEdge[25, 26] -> 
             RGBColor[
              0.9763105628198812, 0.9537635479045874, 0.6372765549863793], 
             UndirectedEdge[9, 67] -> 
             RGBColor[
              0.9660044292138162, 0.9741667394870781, 0.9424298132628353], 
             UndirectedEdge[32, 44] -> 
             RGBColor[
              0.9716387216265316, 0.9718062360271775, 0.6908823822746231], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.8110731758057352, 0.8500964856558542, 0.8425414254713544], 
             UndirectedEdge[79, 83] -> 
             RGBColor[
              0.9701867007285954, 0.9751023341685322, 0.8257779493875523], 
             UndirectedEdge[60, 93] -> 
             RGBColor[
              0.8839296741858287, 0.9092880779866614, 0.9435212113112661], 
             UndirectedEdge[5, 63] -> 
             RGBColor[
              0.7866552918159806, 0.745534370072639, 0.6149016744309928], 
             UndirectedEdge[19, 66] -> 
             RGBColor[
              0.5617043670998665, 0.5614948035034834, 0.6038439520185798], 
             UndirectedEdge[8, 86] -> 
             RGBColor[
              0.9577742098970945, 0.9671436337772398, 0.9189109026937043], 
             UndirectedEdge[4, 37] -> 
             RGBColor[
              0.9213916611380146, 0.9380515441162227, 0.9118959221549636], 
             UndirectedEdge[9, 92] -> 
             RGBColor[
              0.8677041595777537, 0.8968559577877157, 0.9540099521915303], 
             UndirectedEdge[3, 42] -> 
             RGBColor[
              0.5320708256658596, 0.25544181719128334`, 0.5507927784503632], 
             UndirectedEdge[7, 90] -> 
             RGBColor[
              0.8845104168000811, 0.9107486132334606, 0.988846587237804], 
             UndirectedEdge[35, 62] -> 
             RGBColor[
              0.9719599967716794, 0.967664493847196, 0.6810377732498505], 
             UndirectedEdge[20, 79] -> 
             RGBColor[
              0.9685016379115634, 0.9748279551764973, 0.8844105686996104], 
             UndirectedEdge[31, 78] -> 
             RGBColor[
              0.9784444604700571, 0.9814383816277117, 0.8258775329813601], 
             UndirectedEdge[13, 81] -> 
             RGBColor[
              0.9387739694776893, 0.9538583072016603, 0.9885238787547561], 
             UndirectedEdge[18, 80] -> 
             RGBColor[
              0.5612417549152542, 0.6314095589830508, 0.9569646427118643], 
             UndirectedEdge[90, 100] -> 
             RGBColor[
              0.9294698300154938, 0.9437701869705486, 0.8812856102633926], 
             UndirectedEdge[67, 92] -> 
             RGBColor[
              0.8609754772631814, 0.8918377175347136, 0.9653998562286901], 
             UndirectedEdge[55, 66] -> RGBColor[0.178927, 0.305394, 0.933501],
              UndirectedEdge[89, 91] -> 
             RGBColor[
              0.5015106824700021, 0.5839842467151376, 0.9582925251386718], 
             UndirectedEdge[46, 55] -> 
             RGBColor[
              0.21287482566585958`, 0.3410753171912833, 0.9354342784503632], 
             UndirectedEdge[41, 64] -> 
             RGBColor[
              0.9863538740920097, 0.9880397762711866, 0.849608062953995], 
             UndirectedEdge[28, 46] -> 
             RGBColor[
              0.600348957086827, 0.6709387307245913, 0.9501644425189602], 
             UndirectedEdge[35, 53] -> 
             RGBColor[
              0.9785224029944397, 0.9725587256631766, 0.6699293312643784], 
             UndirectedEdge[35, 90] -> 
             RGBColor[
              0.9267887637783129, 0.9321921602288503, 0.6956588196461269], 
             UndirectedEdge[5, 58] -> 
             RGBColor[
              0.9638000501210653, 0.8821236074576269, 0.5023883941888618], 
             UndirectedEdge[76, 85] -> 
             RGBColor[
              0.9591463491624252, 0.9690519946138262, 0.9540387539160942], 
             UndirectedEdge[34, 77] -> 
             RGBColor[
              0.9782880367745503, 0.983303476054358, 0.920546075946111], 
             UndirectedEdge[49, 71] -> 
             RGBColor[
              0.569101373449622, 0.6372712496170381, 0.9436603586499975]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 25 -> 
             RGBColor[
              0.9739972629201243, 0.9239488034758807, 0.353484705959895], 55 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 90 -> 
             RGBColor[
              0.8665290709624195, 0.8964107761531394, 0.987131510419671], 27 -> 
             RGBColor[
              0.8906812505806198, 0.9156690685872413, 0.9894351668725602], 15 -> 
             RGBColor[
              0.9668443693889974, 0.8998204140161206, 0.3256970653020683], 98 -> 
             RGBColor[
              0.9888844394673123, 0.9896714443099274, 0.8338771343825664], 38 -> 
             RGBColor[
              0.8367755061538076, 0.8726860912137537, 0.9842935888469047], 99 -> 
             RGBColor[
              0.8062212881355932, 0.8485454648910411, 0.9813202615012107], 71 -> 
             RGBColor[
              0.9592757468992439, 0.9691484992340762, 0.953819717299995], 41 -> 
             RGBColor[
              0.9920382421307506, 0.9909756227602906, 0.7816104624697335], 75 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 64 -> 
             RGBColor[
              0.9806695060532687, 0.9851039297820824, 0.9176056634382566], 63 -> 
             RGBColor[
              0.6402717676513319, 0.7188404907506054, 0.9648236854237288], 85 -> 
             RGBColor[
              0.9432304275337253, 0.9571819263230716, 0.9809802576962987], 3 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 86 -> 
             RGBColor[
              0.9882198450363197, 0.9893966174334141, 0.84489118401937], 94 -> 
             RGBColor[
              0.8476076183722886, 0.8813233234669171, 0.9853267653802441], 61 -> 
             RGBColor[
              0.9944324872881356, 0.9904999782082324, 0.6353887838983049], 84 -> 
             RGBColor[
              0.9852480506204601, 0.9881677040708233, 0.8941415082475784], 76 -> 
             RGBColor[
              0.9750622707911252, 0.9809220629045807, 0.9270972501358896], 21 -> 
             RGBColor[
              0.9952218855582015, 0.9921884212874953, 0.7213099139935563], 87 -> 
             RGBColor[
              0.9853837095231425, 0.9882238025133573, 0.891893289156144], 95 -> 
             RGBColor[
              0.986611772207075, 0.9887316379929347, 0.8715411123590331], 72 -> 
             RGBColor[
              0.978623862719638, 0.9835782923332941, 0.9210684040128636], 42 -> 
             RGBColor[
              0.24682265133171918`, 0.3767566343825666, 0.9373675569007264], 
             66 -> RGBColor[0.178927, 0.305394, 0.933501], 1 -> 
             RGBColor[
              0.5946003887137423, 0.6817624078568959, 0.9612282671739882], 24 -> 
             RGBColor[
              0.9596639401097, 0.9694380130948264, 0.9531626074516973], 54 -> 
             RGBColor[
              0.9674858995657655, 0.9019844459408078, 0.3281892888960036], 4 -> 
             RGBColor[
              0.988645185472155, 0.9895725066343826, 0.837842192251816], 7 -> 
             RGBColor[
              0.9024917626377428, 0.9250864503137817, 0.9905616640559372], 
             100 -> RGBColor[
              0.9924105890685679, 0.9911295977879578, 0.7754397101071142], 12 -> 
             RGBColor[
              0.9435565098305085, 0.9574251179661017, 0.9804282854237286], 65 -> 
             RGBColor[
              0.9682844173365618, 0.9758671508958838, 0.9385703880871669], 8 -> 
             RGBColor[
              0.9273285747578692, 0.9448906501210654, 0.9929306213680387], 57 -> 
             RGBColor[
              0.9938652726392252, 0.9917311468280872, 0.7513318387409198], 74 -> 
             RGBColor[
              0.5946003887137423, 0.6817624078568959, 0.9612282671739882], 37 -> 
             RGBColor[
              0.8541381368038742, 0.886530581598063, 0.9859496520581114], 43 -> 
             RGBColor[
              0.951511882690122, 0.963358222019074, 0.9669619142659485], 39 -> 
             RGBColor[
              0.9908599707498005, 0.9808306765374631, 0.4189931416230137], 58 -> 
             RGBColor[
              0.9945612842615013, 0.9920189655205811, 0.739797124939467], 11 -> 
             RGBColor[
              0.9458030689284639, 0.959100598062954, 0.9766254468673439], 51 -> 
             RGBColor[
              0.9819798738014528, 0.9860811999031478, 0.915387552639225], 48 -> 
             RGBColor[
              0.9679885278450363, 0.9756464769975788, 0.9390712518159805], 20 -> 
             RGBColor[
              0.991422197361034, 0.9907208724163843, 0.7918199185766968], 33 -> 
             RGBColor[
              0.9756597368845844, 0.9813676521388217, 0.9260858958837771], 45 -> 
             RGBColor[
              0.9852480506204601, 0.9881677040708233, 0.8941415082475784], 23 -> 
             RGBColor[
              0.9887031864406779, 0.9895964915254237, 0.8368809661016949], 22 -> 
             RGBColor[
              0.9089872130750605, 0.6768716585956412, 0.2456271791767554], 2 -> 
             RGBColor[
              0.8062212881355932, 0.8485454648910411, 0.9813202615012107], 60 -> 
             RGBColor[
              0.9844122984632109, 0.98782209907595, 0.907992084350447], 16 -> 
             RGBColor[
              0.9755526201095961, 0.981287764623423, 0.926267216643303], 79 -> 
             RGBColor[
              0.9455810784620927, 0.9589350379366104, 0.977001218822524], 89 -> 
             RGBColor[
              0.8240943649400041, 0.8625744934302751, 0.9830840502773437], 36 -> 
             RGBColor[
              0.6269244660532689, 0.7080045500242131, 0.9637729369491526], 52 -> 
             RGBColor[
              0.9937782711864407, 0.9916951694915255, 0.7527736779661016], 32 -> 
             RGBColor[
              0.9903835314803511, 0.9792235350083502, 0.41714226502920954`], 
             31 -> RGBColor[
              0.9950470408163266, 0.9918144460641399, 0.7022791428571428], 68 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 73 -> 
             RGBColor[
              0.8645072033898304, 0.4776406803874088, 0.20865382808716698`], 
             82 -> RGBColor[
              0.9950458861650343, 0.9918119763817791, 0.7021534661896662], 35 -> 
             RGBColor[
              0.9870484565942063, 0.9679735443045614, 0.4041861288725826], 88 -> 
             RGBColor[
              0.9867979822130347, 0.988808640615778, 0.8684551306642327], 50 -> 
             RGBColor[
              0.9730828305084745, 0.9208642082324453, 0.3499323087167068], 19 -> 
             RGBColor[
              0.944481734199733, 0.8175956070069668, 0.2741869040371595], 17 -> 
             RGBColor[
              0.9668443693889974, 0.8998204140161206, 0.3256970653020683], 96 -> 
             RGBColor[
              0.9322255371962929, 0.7690038700238675, 0.2643252802382728], 14 -> 
             RGBColor[
              0.9507674463276836, 0.9628030225988701, 0.9682220508474575], 5 -> 
             RGBColor[
              0.9330388159806294, 0.7722282493946726, 0.2649796634382566], 34 -> 
             RGBColor[
              0.9722374599897786, 0.9788153236341397, 0.9318789179939173], 97 -> 
             RGBColor[
              0.9894306529414527, 0.9760092519501251, 0.41344051184160213`], 
             93 -> RGBColor[
              0.7834470499084466, 0.8307540568973729, 0.9790503382720852], 81 -> 
             RGBColor[0.93779572258734, 0.95312873227257, 0.9901797955724663],
              69 -> RGBColor[
              0.6780216271186441, 0.7483949153510896, 0.9685425173849879], 9 -> 
             RGBColor[
              0.9727331115283886, 0.9791849797400801, 0.9310399092256756], 13 -> 
             RGBColor[
              0.9397522163680387, 0.9545878821307506, 0.986867961937046], 30 -> 
             RGBColor[
              0.9924105890685679, 0.9911295977879578, 0.7754397101071142], 59 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 28 -> 
             RGBColor[
              0.9538752628419347, 0.9651208270666161, 0.9629613281371939], 80 -> 
             RGBColor[
              0.9435565098305085, 0.9574251179661017, 0.9804282854237286], 47 -> 
             RGBColor[
              0.9806695060532687, 0.9851039297820824, 0.9176056634382566], 62 -> 
             RGBColor[
              0.9568715369491526, 0.9673554433898306, 0.9578894176271185], 77 -> 
             RGBColor[
              0.984338613559322, 0.9877916284745764, 0.9092132338983048], 78 -> 
             RGBColor[
              0.9618418801237876, 0.9710623171912833, 0.9494759231055775], 40 -> 
             RGBColor[
              0.970403952265652, 0.9774478965755794, 0.9349825683154617], 67 -> 
             RGBColor[
              0.9592757468992439, 0.9691484992340762, 0.953819717299995], 56 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 10 -> 
             RGBColor[
              0.9888511480950734, 0.9896576774719573, 0.8344288585758756], 53 -> 
             RGBColor[
              0.969996349394673, 0.9771439070217918, 0.9356725336561743], 26 -> 
             RGBColor[
              0.978623862719638, 0.9835782923332941, 0.9210684040128636], 18 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 29 -> 
             RGBColor[
              0.9164253169148018, 0.7063612617190442, 0.251612052120948], 92 -> 
             RGBColor[
              0.7626752076271188, 0.8145269358353512, 0.976979995157385], 46 -> 
             RGBColor[
              0.24682265133171918`, 0.3767566343825666, 0.9373675569007264], 
             49 -> RGBColor[0.178927, 0.305394, 0.933501], 83 -> 
             RGBColor[
              0.9947923229950979, 0.991269630400454, 0.6745546799525807], 70 -> 
             RGBColor[
              0.5946003887137423, 0.6817624078568959, 0.9612282671739882], 44 -> 
             RGBColor[
              0.9528939117727123, 0.9643889370460049, 0.9646224995200365], 91 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 6 -> 
             RGBColor[
              0.9938547513559323, 0.9892642594673123, 0.572505793050847]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9lHs01Akbx4dhXCZmRjNjDGZ+vxEpY003Oez6fWm7uFSIpJWyrGvrtqF9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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 13}], {
             RGBColor[
             0.7671763025408905, 0.8181751449938233, 0.9740481145555171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 17}], {
             RGBColor[
             0.7807223790513699, 0.7907914109365082, 0.6434626662380283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 19}], {
             RGBColor[
             0.7695410614567377, 0.7496790074319313, 0.6177075856055738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 27}], {
             RGBColor[
             0.742640819647181, 0.7987157382220686, 0.9753317170232743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 43}], {
             RGBColor[
             0.7730561357019321, 0.822560314937985, 0.9640950907199684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 46}], {
             RGBColor[
             0.42071152002273077`, 0.5292595211197313, 0.9492979120373572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 55}], {
             RGBColor[
             0.3867636943568712, 0.493578203928448, 0.9473646335869941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 3}], {
             RGBColor[
             0.8117701440677967, 0.49133623244552055`, 0.5727691307506053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 14}], {
             RGBColor[
             0.8784943672316384, 0.9056742437449556, 0.9747711561743341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 29}], {
             RGBColor[
             0.8613233025251975, 0.7774533633050427, 0.6164661568110793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 33}], {
             RGBColor[
             0.8909405125100889, 0.9149565585149314, 0.9537030786924938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 38}], {
             RGBColor[
             0.8214983971447004, 0.8606157780523974, 0.9828069251740577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 42}], {
             RGBColor[
             0.5265219697336563, 0.6126510496368038, 0.9593439092009686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 44}], {
             RGBColor[
             0.8795575999541527, 0.9064672009685231, 0.9729713805106236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 62}], {
             RGBColor[
             0.8815464125423729, 0.9079504541404358, 0.9696048395641645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 78}], {
             RGBColor[
             0.8840315841296904, 0.9098038910411622, 0.965398092303394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 16}], {
             RGBColor[
             0.896435810054798, 0.5577073823117116, 0.5452426083216515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 29}], {
             RGBColor[
             0.8668721584574008, 0.4202441308595221, 0.20791502606047402`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 33}], {
             RGBColor[
             0.8964893684422922, 0.5577473260694108, 0.5451519479418886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 38}], {
             RGBColor[
             0.8270472530769037, 0.5034065456068768, 0.5742557944234523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 42}], {
             RGBColor[
             0.5320708256658596, 0.25544181719128334`, 0.5507927784503632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 62}], {
             RGBColor[
             0.8870952684745763, 0.5507412216949152, 0.5610537088135593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 9}], {
             RGBColor[
             0.9806891485002718, 0.9843787431872313, 0.8844410507387458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 23}], {
             RGBColor[
             0.9886741859564164, 0.9895844990799032, 0.8373615791767555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 24}], {
             RGBColor[
             0.9741545627909275, 0.9795052598646045, 0.8955023998517566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 30}], {
             RGBColor[
             0.9905278872703615, 0.9903510522111703, 0.8066409511794651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 36}], {
             RGBColor[
             0.8077848257627119, 0.8487885283292979, 0.9008075646004843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 37}], {
             RGBColor[
             0.9213916611380146, 0.9380515441162227, 0.9118959221549636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 50}], {
             RGBColor[
             0.9808640079903148, 0.9552183574334139, 0.5938872504842614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 76}], {
             RGBColor[
             0.9818537281316401, 0.9852472847694816, 0.8824697211938528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 86}], {
             RGBColor[
             0.9884325152542373, 0.9894845620338983, 0.841366688135593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 94}], {
             RGBColor[
             0.9181264019222217, 0.9354479150506498, 0.9115844788160301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 20}], {
             RGBColor[
             0.9622305066708317, 0.8814745609055284, 0.5283997910074767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 28}], {
             RGBColor[
             0.943457039411282, 0.8686745382306443, 0.6139704957877252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 58}], {
             RGBColor[
             0.9638000501210653, 0.8821236074576269, 0.5023883941888618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.5559829079903147, 0.5388111246973363, 0.5992403317191284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 63}], {
             RGBColor[
             0.7866552918159806, 0.745534370072639, 0.6149016744309928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 66}], {
             RGBColor[
             0.5559829079903147, 0.5388111246973363, 0.5992403317191284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 69}], {
             RGBColor[
             0.8055302215496367, 0.7603115823728811, 0.6167610904116223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[
             0.9586887147699756, 0.8800099389346245, 0.5870964486682806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 79}], {
             RGBColor[
             0.9393099472213611, 0.8655816436656415, 0.6209904411303904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[
             0.9639155694878636, 0.8817489398975633, 0.4697671716954186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 97}], {
             RGBColor[
             0.961234734461041, 0.8741187506723989, 0.3392100876399293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 7}], {
             RGBColor[
             0.9481732569968375, 0.9571753548905471, 0.7815337285533921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 10}], {
             RGBColor[
             0.9913529497255028, 0.9894609684696348, 0.7034673258133612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 15}], {
             RGBColor[
             0.9803495603724648, 0.9445423367417165, 0.4491014291764577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 25}], {
             RGBColor[
             0.9839260071380282, 0.9566065314715966, 0.462995249505371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 26}], {
             RGBColor[
             0.9862393070377851, 0.9864212759003033, 0.7467870985318553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 35}], {
             RGBColor[
             0.9904516039750693, 0.9786189018859368, 0.4883459609617148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 40}], {
             RGBColor[
             0.9821293518107921, 0.9833560780214459, 0.7537441806831544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.9819255503753026, 0.9832040832445521, 0.7540891633535107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 65}], {
             RGBColor[
             0.981069584346247, 0.9825657051815981, 0.755538090569007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 90}], {
             RGBColor[
             0.9301919111591759, 0.9428375178102258, 0.779818651735259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 100}], {
             RGBColor[
             0.99313267021225, 0.9901969286276351, 0.6739727515789806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 13}], {
             RGBColor[
             0.9211219895028908, 0.9398371662222662, 0.9887148129964916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 25}], {
             RGBColor[
             0.9382445127789336, 0.9245176268948312, 0.6720231850079161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 27}], {
             RGBColor[
             0.8965865066091813, 0.9203777594505115, 0.9899984154642487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 37}], {
             RGBColor[
             0.8783149497208085, 0.9058085159559224, 0.9882556580570243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 40}], {
             RGBColor[
             0.9364478574516975, 0.9512671734446805, 0.9627721161856995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 53}], {
             RGBColor[
             0.936244056016208, 0.9511151786677867, 0.9631170988560558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.9349888311017541, 0.9135354481272948, 0.6593754764759704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 65}], {
             RGBColor[
             0.9353880899871523, 0.9504768006048327, 0.9645660260715521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 81}], {
             RGBColor[
             0.9201437426125414, 0.9391075912931759, 0.9903707298142017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.9438699066291014, 0.9566270771923024, 0.9423515861517577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 85}], {
             RGBColor[
             0.9228610950857341, 0.9411341883184267, 0.9857709608761179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 90}], {
             RGBColor[
             0.8845104168000811, 0.9107486132334606, 0.988846587237804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 100}], {
             RGBColor[
             0.9474511758531554, 0.9581080240508697, 0.8830006870815257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 17}], {
             RGBColor[
             0.9470864720734333, 0.922355532068593, 0.6593138433350535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.9612752301580354, 0.9685395357042803, 0.8571202676807974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 22}], {
             RGBColor[
             0.9181578939164649, 0.8108811543583534, 0.6192789002723971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 30}], {
             RGBColor[
             0.9598695819132186, 0.9680101239545116, 0.8841851657375764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 49}], {
             RGBColor[
             0.5531277873789346, 0.6251423250605327, 0.9632158106840194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 69}], {
             RGBColor[
             0.8026751009382567, 0.8466427827360775, 0.9807365693765133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 77}], {
             RGBColor[
             0.9558335941585956, 0.966341139297821, 0.9510719276331717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.9611872304614517, 0.9683513132514223, 0.8475420437788524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 86}], {
             RGBColor[
             0.9577742098970945, 0.9671436337772398, 0.9189109026937043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 87}], {
             RGBColor[
             0.9563561421405058, 0.9665572263172113, 0.9424119552620913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 95}], {
             RGBColor[
             0.956970173482472, 0.9668111440570001, 0.9322358668635359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 99}], {
             RGBColor[
             0.8667749314467312, 0.8967180575060533, 0.9871254414346247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.9592680902284263, 0.9691427889015171, 0.9538326780465097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 21}], {
             RGBColor[
             0.983977498543295, 0.9856867005137877, 0.826174911609616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 30}], {
             RGBColor[
             0.9825718502984783, 0.985157288764019, 0.8532398096663949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 36}], {
             RGBColor[
             0.7998287887908287, 0.8435947648821467, 0.9474064230874141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 61}], {
             RGBColor[
             0.9835827994082621, 0.9848424789741563, 0.7832143465619903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 67}], {
             RGBColor[
             0.9660044292138162, 0.9741667394870781, 0.9424298132628353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 68}], {
             RGBColor[
             0.5758300557641943, 0.6422894898700401, 0.9322704546128378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 72}], {
             RGBColor[
             0.9756784871240133, 0.9813816360366872, 0.9260541566192696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 82}], {
             RGBColor[
             0.9838894988467115, 0.9854984780609296, 0.8165966877076709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 86}], {
             RGBColor[
             0.9804764782823541, 0.9842907985867471, 0.8879655466225228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 92}], {
             RGBColor[
             0.8677041595777537, 0.8968559577877157, 0.9540099521915303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 94}], {
             RGBColor[
             0.9101703649503385, 0.9302541516034986, 0.9581833373029598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.9778477587420353, 0.944739045744039, 0.5800629619389719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 26}], {
             RGBColor[
             0.9837375054073556, 0.9866179849026258, 0.8777486312943696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 35}], {
             RGBColor[
             0.9879498023446398, 0.9788156108882593, 0.6193074937242291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 40}], {
             RGBColor[
             0.9796275501803626, 0.9835527870237684, 0.8847057134456686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 53}], {
             RGBColor[
             0.9794237487448731, 0.9834007922468746, 0.8850506961160249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 65}], {
             RGBColor[
             0.9785677827158176, 0.9827624141839206, 0.8864996233315212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 90}], {
             RGBColor[
             0.9276901095287464, 0.9430342268125483, 0.9107801844977732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 100}], {
             RGBColor[
             0.9906308685818206, 0.9903936376299576, 0.8049342843414948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 36}], {
             RGBColor[
             0.7863637674908663, 0.8335525740435836, 0.9701991919082482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 52}], {
             RGBColor[
             0.9697906700574523, 0.9753978837772397, 0.8646995624167227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 61}], {
             RGBColor[
             0.9701177781082997, 0.9748002881355933, 0.8060071153828243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 67}], {
             RGBColor[
             0.9525394079138538, 0.964124548648515, 0.9652225820836695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 68}], {
             RGBColor[
             0.5623650344642319, 0.632247299031477, 0.955063223433672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 72}], {
             RGBColor[
             0.9622134658240509, 0.9713394451981241, 0.9488469254401037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 92}], {
             RGBColor[
             0.8542391382777914, 0.8868137669491526, 0.9768027210123644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 94}], {
             RGBColor[
             0.8967053436503762, 0.9202119607649355, 0.980976106123794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 41}], {
             RGBColor[
             0.9677973759806295, 0.9742003703631962, 0.8810193739467311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 52}], {
             RGBColor[
             0.9686673905084746, 0.9745601437288136, 0.8666009816949152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 60}], {
             RGBColor[
             0.9639844041468597, 0.9726236085210258, 0.9442101848870879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.9621130079418887, 0.971264523874092, 0.9490169744309926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 74}], {
             RGBColor[
             0.7690784492721254, 0.8195937629114989, 0.9708282762988585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 88}], {
             RGBColor[
             0.9651772460217716, 0.9731168792909399, 0.9244417080439806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 96}], {
             RGBColor[
             0.9378910235134007, 0.8632144939949846, 0.6223767828310007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 27}], {
             RGBColor[
             0.9152167334743293, 0.9351284753589959, 0.9881515644048031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 43}], {
             RGBColor[
             0.9456320495290804, 0.9589730520749122, 0.9769149381014972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 54}], {
             RGBColor[
             0.9536190579669022, 0.9282861640357792, 0.6575286254165248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 81}], {
             RGBColor[
             0.9387739694776893, 0.9538583072016603, 0.9885238787547561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 84}], {
             RGBColor[
             0.9625001334942493, 0.971377793100787, 0.9405047350923121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 85}], {
             RGBColor[
             0.941491321950882, 0.9558849042269111, 0.9839241098166723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 15}], {
             RGBColor[
             0.9588059078583405, 0.9313117183074953, 0.6469595580747629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 24}], {
             RGBColor[
             0.9552156932186918, 0.9661205178468482, 0.9606923291495775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 35}], {
             RGBColor[
             0.9689079514609449, 0.9653882834517158, 0.68620408986002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 38}], {
             RGBColor[
             0.8937714762407456, 0.9177445569063118, 0.9762578198471811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 42}], {
             RGBColor[
             0.5987950488297014, 0.6697798284907184, 0.9527948038740919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 53}], {
             RGBColor[
             0.9603818978611783, 0.9699734648103309, 0.951947292251816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 62}], {
             RGBColor[
             0.9538194916384182, 0.9650792329943503, 0.9630557342372881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 76}], {
             RGBColor[
             0.9629148585594044, 0.9718625427517253, 0.9476596504916736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 35}], {
             RGBColor[
             0.9769464129916019, 0.933896979160341, 0.36494159708732543`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 38}], {
             RGBColor[
             0.9018099377714025, 0.8862532526149371, 0.6549953270744865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 40}], {
             RGBColor[
             0.9686241608273247, 0.9386341552958499, 0.630339816808765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 53}], {
             RGBColor[
             0.9684203593918352, 0.9384821605189562, 0.6306847994791214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.961857953169075, 0.9335879287029756, 0.6417932414645935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 90}], {
             RGBColor[
             0.9166867201757085, 0.89811559508463, 0.6564142878608696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 100}], {
             RGBColor[
             0.9796274792287827, 0.9454750059020391, 0.5505683877045913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 29}], {
             RGBColor[
             0.9459889685121989, 0.8438245131712336, 0.5889396343821255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.9756061784970902, 0.9813277083811224, 0.92617655626354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 62}], {
             RGBColor[
             0.9662120785293744, 0.9743216040066268, 0.9420783171352107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 19}], {
             RGBColor[
             0.9556630517943652, 0.8587080105115437, 0.2999419846696139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 22}], {
             RGBColor[
             0.937915791232029, 0.788346036305881, 0.28566212223941184`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 28}], {
             RGBColor[
             0.9603598161154661, 0.9324706205413683, 0.6443291967196312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 46}], {
             RGBColor[
             0.6068335103603584, 0.6382885241993436, 0.6315323111013973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 55}], {
             RGBColor[
             0.5728856846944987, 0.6026072070080603, 0.6295990326510341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 59}], {
             RGBColor[
             0.5728856846944987, 0.6026072070080603, 0.6295990326510341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 66}], {
             RGBColor[
             0.5728856846944987, 0.6026072070080603, 0.6295990326510341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 69}], {
             RGBColor[
             0.8224329982538208, 0.8241076646836051, 0.647119791343528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 77}], {
             RGBColor[
             0.9755914914741597, 0.9438060212453485, 0.6174551496001865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 79}], {
             RGBColor[
             0.9562127239255451, 0.9293777259763655, 0.6513491420622961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 95}], {
             RGBColor[
             0.9767280707980361, 0.9442760260045276, 0.5986190888305507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 98}], {
             RGBColor[
             0.9778644044281548, 0.944745929163024, 0.5797870998423174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.8865328287622953, 0.8741829394535808, 0.6535086634016395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 80}], {
             RGBColor[
             0.5612417549152542, 0.6314095589830508, 0.9569646427118643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 28}], {
             RGBColor[
             0.9491784985208338, 0.8913582170367914, 0.6185741160871767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 43}], {
             RGBColor[
             0.9479968084449275, 0.8904769145130204, 0.6205744091515539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 46}], {
             RGBColor[
             0.5956521927657261, 0.5971761206947667, 0.6057772304689429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 55}], {
             RGBColor[
             0.5617043670998665, 0.5614948035034834, 0.6038439520185798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 59}], {
             RGBColor[
             0.5617043670998665, 0.5614948035034834, 0.6038439520185798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 66}], {
             RGBColor[
             0.5617043670998665, 0.5614948035034834, 0.6038439520185798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 79}], {
             RGBColor[
             0.9450314063309129, 0.8882653224717886, 0.6255940614298418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 95}], {
             RGBColor[
             0.965546753203404, 0.9031636224999507, 0.5728640081980962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 98}], {
             RGBColor[
             0.9666830868335227, 0.9036335256584471, 0.5540320192098629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 99}], {
             RGBColor[
             0.8753515111676631, 0.8330705359490039, 0.6277535827691851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.9726487301014843, 0.9779208497415002, 0.8773906233569453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 58}], {
             RGBColor[
             0.9929917408112676, 0.9913699189684827, 0.7658085217580819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 59}], {
             RGBColor[
             0.585174598680517, 0.6480574362081921, 0.8626604592883484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 63}], {
             RGBColor[
             0.8158469825061829, 0.8547806815834949, 0.8783218020002128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 66}], {
             RGBColor[
             0.585174598680517, 0.6480574362081921, 0.8626604592883484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 79}], {
             RGBColor[
             0.9685016379115634, 0.9748279551764973, 0.8844105686996104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 83}], {
             RGBColor[
             0.9931072601780659, 0.9909952514084192, 0.7331872992646387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 97}], {
             RGBColor[
             0.9904264251512434, 0.9833650621832547, 0.6026302152091494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 22}], {
             RGBColor[
             0.9521045493166309, 0.8345300399415683, 0.4834685465851558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 30}], {
             RGBColor[
             0.9938162373133848, 0.9916590095377266, 0.7483748120503353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 34}], {
             RGBColor[
             0.98372967277399, 0.9855018724608176, 0.8265944159937368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.8110731758057352, 0.8500964856558542, 0.8425414254713544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 49}], {
             RGBColor[
             0.5870744427791007, 0.6487912106437477, 0.8274054569967781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 68}], {
             RGBColor[
             0.5870744427791007, 0.6487912106437477, 0.8274054569967781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 72}], {
             RGBColor[
             0.9869228741389198, 0.9878833568103946, 0.8211891590032099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 82}], {
             RGBColor[
             0.9951338858616179, 0.9920001988346372, 0.7117316900916113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[
             0.990302797540672, 0.9902061119004263, 0.8066016015748501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 92}], {
             RGBColor[
             0.8789485465926601, 0.9033576785614232, 0.8491449545754706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 30}], {
             RGBColor[
             0.9506989010718142, 0.8340006281917995, 0.5105334446419348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 34}], {
             RGBColor[
             0.9406123365324195, 0.8278434911148904, 0.5887530485853364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 49}], {
             RGBColor[
             0.5439571065375303, 0.49113282929782065`, 0.5895640895883777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 66}], {
             RGBColor[
             0.5439571065375303, 0.49113282929782065`, 0.5895640895883777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 69}], {
             RGBColor[
             0.7935044200968523, 0.7126332869733654, 0.6070848482808716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 77}], {
             RGBColor[
             0.9466629133171912, 0.8323316435351088, 0.5774202065375301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 82}], {
             RGBColor[
             0.9520165496200474, 0.8343418174887102, 0.47389032268321085`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 87}], {
             RGBColor[
             0.9471854612991015, 0.8325477305544993, 0.5687602341664497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 95}], {
             RGBColor[
             0.9477994926410678, 0.8328016482942879, 0.5585841457678943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 99}], {
             RGBColor[
             0.8576042506053269, 0.7627085617433411, 0.6134737203389831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 24}], {
             RGBColor[
             0.974183563275189, 0.979517252310125, 0.8950217867766961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 27}], {
             RGBColor[
             0.9396922185106489, 0.9526327800563326, 0.9131580664871275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 30}], {
             RGBColor[
             0.9905568877546229, 0.9903630446566908, 0.8061603381044046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 37}], {
             RGBColor[
             0.921420661622276, 0.9380635365617433, 0.9114153090799031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 50}], {
             RGBColor[
             0.9808930084745762, 0.9552303498789345, 0.5934066374092009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 76}], {
             RGBColor[
             0.9818827286159015, 0.9852592772150022, 0.8819891081187923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[
             0.9632494545140089, 0.9713626118989969, 0.9135303808370806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 84}], {
             RGBColor[
             0.9869756185305689, 0.9888820977981235, 0.8655112371746367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 85}], {
             RGBColor[
             0.9659668069872016, 0.9733892089242477, 0.9089306118989968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 86}], {
             RGBColor[
             0.9884615157384988, 0.989496554479419, 0.8408860750605325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 42}], {
             RGBColor[
             0.6032432957207097, 0.6730973237386965, 0.9452650821762119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 50}], {
             RGBColor[
             0.9663733853090872, 0.9451511106636359, 0.651547458084202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 76}], {
             RGBColor[
             0.9673631054504126, 0.9751800379997035, 0.9401299287937934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 26}], {
             RGBColor[
             0.9763105628198812, 0.9537635479045874, 0.6372765549863793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 40}], {
             RGBColor[
             0.9722006075928882, 0.95069835002573, 0.6442336371376783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 54}], {
             RGBColor[
             0.970741581242945, 0.9129666247083443, 0.34083699742794926`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 65}], {
             RGBColor[
             0.971140840128343, 0.9499079771858823, 0.6460275470235309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 100}], {
             RGBColor[
             0.9832039259943461, 0.9575392006319192, 0.5644622080335047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 40}], {
             RGBColor[
             0.974513907492645, 0.9805130944544367, 0.9280254861641626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 53}], {
             RGBColor[
             0.9743101060571555, 0.9803610996775429, 0.9283704688345189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 65}], {
             RGBColor[
             0.9734541400280998, 0.979722721614589, 0.9298193960500152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 90}], {
             RGBColor[
             0.9225764668410288, 0.9399945342432168, 0.9540999572162673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[
             0.985517225894103, 0.9873539450606259, 0.8482540570599889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 37}], {
             RGBColor[
             0.872409693692247, 0.9010998250926521, 0.9876924094653358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 43}], {
             RGBColor[
             0.9210965666353709, 0.9395136453031576, 0.9781985405692544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 54}], {
             RGBColor[
             0.9290835750731926, 0.9088267572640245, 0.6588122278842818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 81}], {
             RGBColor[
             0.9142384865839799, 0.9343989004299056, 0.9898074812225133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 84}], {
             RGBColor[
             0.9379646506005399, 0.9519183863290324, 0.9417883375600693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 85}], {
             RGBColor[
             0.9169558390571726, 0.9364254974551565, 0.9852077122844294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 46}], {
             RGBColor[
             0.600348957086827, 0.6709387307245913, 0.9501644425189602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 55}], {
             RGBColor[
             0.5664011314209674, 0.635257413533308, 0.948231164068597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 59}], {
             RGBColor[
             0.5664011314209674, 0.635257413533308, 0.948231164068597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 66}], {
             RGBColor[
             0.5664011314209674, 0.635257413533308, 0.948231164068597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 79}], {
             RGBColor[
             0.9497281706520138, 0.9620279325016132, 0.969981273479859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 83}], {
             RGBColor[
             0.9743337929185163, 0.978195228733535, 0.8187580040448873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 98}], {
             RGBColor[
             0.9713798511546234, 0.9773961356882717, 0.8984192312598802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 99}], {
             RGBColor[
             0.880048275488764, 0.9068331459788286, 0.9721407948192022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 33}], {
             RGBColor[
             0.946042526899693, 0.843864456928933, 0.5888489740023626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 38}], {
             RGBColor[
             0.8766004115343047, 0.789523676466399, 0.6179528204839264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 42}], {
             RGBColor[
             0.5816239841232604, 0.5415589480508054, 0.5944898045108371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.9366484269319773, 0.8368583525544374, 0.6047507348740333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 36}], {
             RGBColor[
             0.8096675275609184, 0.8495670739060854, 0.8696063235281334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 50}], {
             RGBColor[
             0.9827467097885212, 0.9559969030102016, 0.5626860094119105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 82}], {
             RGBColor[
             0.9937282376168011, 0.9914707870848685, 0.7387965881483902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 86}], {
             RGBColor[
             0.9903152170524439, 0.990263107610686, 0.8101654470632421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 92}], {
             RGBColor[
             0.8775428983478434, 0.9028282668116545, 0.8762098526322496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 94}], {
             RGBColor[
             0.9200091037204283, 0.9362264606274375, 0.8803832377436791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 32}], {
             RGBColor[
             0.9927152861483388, 0.9855189905362451, 0.5597107039431761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 39}], {
             RGBColor[
             0.9929535057830635, 0.9863225613008015, 0.5606361422400783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 44}], {
             RGBColor[
             0.9739704762945194, 0.9781016915550724, 0.8334508211885896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 45}], {
             RGBColor[
             0.9901475457183933, 0.9899910750674816, 0.7982103255523606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 51}], {
             RGBColor[
             0.9885134573088896, 0.9889478229836439, 0.8088333477481839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 70}], {
             RGBColor[
             0.7948237147650344, 0.8367884269605179, 0.8317537050155654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 75}], {
             RGBColor[
             0.5869870204081633, 0.64860422303207, 0.8178900714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 78}], {
             RGBColor[
             0.9784444604700571, 0.9814383816277117, 0.8258775329813601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 80}], {
             RGBColor[
             0.9693017753234175, 0.9746197820151208, 0.8413537141404357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 39}], {
             RGBColor[
             0.9906217511150758, 0.9800271057729066, 0.41806770332611165`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 44}], {
             RGBColor[
             0.9716387216265316, 0.9718062360271775, 0.6908823822746231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 45}], {
             RGBColor[
             0.9878157910504055, 0.9836956195395867, 0.655641886638394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 51}], {
             RGBColor[
             0.9861817026409019, 0.982652367455749, 0.6662649088342173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 80}], {
             RGBColor[
             0.9669700206554298, 0.968324326487226, 0.6987852752264692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 42}], {
             RGBColor[
             0.6112411941081518, 0.6790621432606941, 0.9317267263922517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 62}], {
             RGBColor[
             0.9662656369168685, 0.9743615477643262, 0.9419876567554478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 49}], {
             RGBColor[
             0.5755822299948893, 0.6421046618170698, 0.9326899589969586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 60}], {
             RGBColor[
             0.9783248792264947, 0.9833187113550448, 0.9199355011721821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 69}], {
             RGBColor[
             0.8251295435542114, 0.8636051194926146, 0.9502107176894525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 71}], {
             RGBColor[
             0.9657566034445113, 0.973981911434108, 0.9428493176469561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 77}], {
             RGBColor[
             0.9782880367745503, 0.983303476054358, 0.920546075946111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 82}], {
             RGBColor[
             0.9836416730774065, 0.9853136500079593, 0.8170161920917918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 87}], {
             RGBColor[
             0.9788105847564605, 0.9835195630737485, 0.9118861035750306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 38}], {
             RGBColor[
             0.9119119813740069, 0.9203298177591576, 0.6942398588597436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 53}], {
             RGBColor[
             0.9785224029944397, 0.9725587256631766, 0.6699293312643784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 62}], {
             RGBColor[
             0.9719599967716794, 0.967664493847196, 0.6810377732498505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 90}], {
             RGBColor[
             0.9267887637783129, 0.9321921602288503, 0.6956588196461269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 61}], {
             RGBColor[
             0.8106784766707023, 0.8492522641162228, 0.7995808604237287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 67}], {
             RGBColor[
             0.7931001064762564, 0.8385765246291447, 0.9587963271245739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 68}], {
             RGBColor[
             0.4029257330266345, 0.5066992750121065, 0.9486369684745763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 72}], {
             RGBColor[
             0.8027741643864534, 0.8457914211787536, 0.9424206704810081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 82}], {
             RGBColor[
             0.8109851761091516, 0.8499082632029962, 0.8329632015694094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 86}], {
             RGBColor[
             0.8075721555447943, 0.8487005837288136, 0.9043320604842613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 92}], {
             RGBColor[
             0.6947998368401939, 0.7612657429297822, 0.9703764660532688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 94}], {
             RGBColor[
             0.7372660422127788, 0.7946639367455651, 0.9745498511646984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 50}], {
             RGBColor[
             0.9136104836561744, 0.9036973949152541, 0.667940980387409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 76}], {
             RGBColor[
             0.9146002037974996, 0.9337263222513219, 0.9565234510970004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 81}], {
             RGBColor[
             0.8959669296956071, 0.9198296569353165, 0.9880647238152889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 84}], {
             RGBColor[
             0.9196930937121671, 0.9373491428344431, 0.9400455801528449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 85}], {
             RGBColor[
             0.8986842821687997, 0.9218562539605673, 0.983464954877205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 42}], {
             RGBColor[
             0.5417990787427633, 0.6247213627981602, 0.9608305728738156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 62}], {
             RGBColor[
             0.8968235215514802, 0.9200207673017922, 0.9710915032370115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 44}], {
             RGBColor[
             0.9718769412612565, 0.972609806791734, 0.6918078205715251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 45}], {
             RGBColor[
             0.9880540106851303, 0.9844991903041432, 0.6565673249352961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 80}], {
             RGBColor[
             0.9672082402901545, 0.9691278972517825, 0.6997107135233711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 53}], {
             RGBColor[
             0.9702001508301625, 0.9772959017986855, 0.935327550985818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 54}], {
             RGBColor[
             0.9689449259157088, 0.9397161712581936, 0.6315859286057326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.9693441848011068, 0.9766575237357316, 0.9367764782013143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 90}], {
             RGBColor[
             0.9184665116140358, 0.9369293363643594, 0.9610570393675664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 100}], {
             RGBColor[
             0.98140727066711, 0.9842887471817686, 0.855211139211288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 48}], {
             RGBColor[
             0.9800133849878935, 0.9833110498789347, 0.860340857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 56}], {
             RGBColor[
             0.5854826210653753, 0.6481848113801453, 0.8575557312348667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 60}], {
             RGBColor[
             0.9882252702969807, 0.9893988609181203, 0.8448012734100903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 64}], {
             RGBColor[
             0.9863538740920097, 0.9880397762711866, 0.849608062953995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 73}], {
             RGBColor[
             0.9282727227602905, 0.7343081515738497, 0.4951321452784503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 74}], {
             RGBColor[
             0.7933193154222464, 0.8363690153085932, 0.8714193648218609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.9894181121718927, 0.9898921316880342, 0.8250327965669831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 91}], {
             RGBColor[
             0.5854826210653753, 0.6481848113801453, 0.8575557312348667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 93}], {
             RGBColor[
             0.8877426460195986, 0.9108648398288317, 0.8803304003709094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 44}], {
             RGBColor[
             0.5998582815522158, 0.6705727857142858, 0.9509950282103814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 62}], {
             RGBColor[
             0.6018470941404359, 0.6720560388861987, 0.9476284872639225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 78}], {
             RGBColor[
             0.6043322657277533, 0.6739094757869251, 0.9434217400031519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 46}], {
             RGBColor[
             0.5991672670109206, 0.6700574282008203, 0.9521647355833374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 54}], {
             RGBColor[
             0.9594988911279437, 0.9326713339799408, 0.647575601580976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 45}], {
             RGBColor[
             0.9690709811965862, 0.9762783205584141, 0.9293820038838074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 78}], {
             RGBColor[
             0.9573678959482499, 0.9677256271186441, 0.9570492113128071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 52}], {
             RGBColor[
             0.9895131609034504, 0.9899314367811745, 0.82345759310684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 78}], {
             RGBColor[
             0.9735449653721238, 0.9796150106310533, 0.921808715676578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 55}], {
             RGBColor[
             0.21287482566585958`, 0.3410753171912833, 0.9354342784503632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 59}], {
             RGBColor[
             0.21287482566585958`, 0.3410753171912833, 0.9354342784503632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 79}], {
             RGBColor[
             0.596201864896906, 0.6678458361595885, 0.9571843878616252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 95}], {
             RGBColor[
             0.6167172117693971, 0.6827441361877506, 0.9044543346298797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 98}], {
             RGBColor[
             0.6178535453995158, 0.6832140393462469, 0.8856223456416463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 99}], {
             RGBColor[
             0.5265219697336562, 0.6126510496368038, 0.9593439092009686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 51}], {
             RGBColor[
             0.9813246899273608, 0.9855925648426151, 0.9164966080387408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 57}], {
             RGBColor[
             0.9872673893462469, 0.9884175383050848, 0.8344687510895882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 70}], {
             RGBColor[
             0.7876349473835056, 0.8334331688194891, 0.9394169653061224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 74}], {
             RGBColor[
             0.7876349473835056, 0.8334331688194891, 0.9394169653061224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 75}], {
             RGBColor[
             0.5797982530266343, 0.6452489648910412, 0.9255533317191282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 88}], {
             RGBColor[
             0.9837337441331517, 0.9869562851989302, 0.8930303970512447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.9564475216247807, 0.8770538999029749, 0.5909654718382646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 56}], {
             RGBColor[
             0.5734577639225181, 0.6405202384987894, 0.9362861259079902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 57}], {
             RGBColor[
             0.9809269002421308, 0.983688811912833, 0.8452015452784502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 64}], {
             RGBColor[
             0.9743290169491525, 0.9803752033898305, 0.9283384576271185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 73}], {
             RGBColor[
             0.9162478656174333, 0.7266435786924939, 0.5738625399515738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 74}], {
             RGBColor[
             0.7812944582793893, 0.8287044424272374, 0.9501497594949844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 88}], {
             RGBColor[
             0.9773932550290355, 0.9822275588066784, 0.9037631912401066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 91}], {
             RGBColor[
             0.5734577639225181, 0.6405202384987894, 0.9362861259079902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 93}], {
             RGBColor[
             0.8757177888767415, 0.9032002669474759, 0.9590607950440329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 96}], {
             RGBColor[
             0.9501070325206646, 0.8723251735107231, 0.6016982660271266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 69}], {
             RGBColor[
             0.4284743135593221, 0.5268944576755448, 0.951021758692494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 71}], {
             RGBColor[
             0.569101373449622, 0.6372712496170381, 0.9436603586499975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 77}], {
             RGBColor[
             0.581632806779661, 0.6465928142372881, 0.9213571169491523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 82}], {
             RGBColor[
             0.5869864430825171, 0.6486029881908895, 0.8178272330948331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.5821553547615712, 0.6468089012566787, 0.912697144578072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 76}], {
             RGBColor[
             0.9740725506497998, 0.9508931355685131, 0.6385147794262982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 81}], {
             RGBColor[
             0.9554392765479073, 0.9369964702525077, 0.6700560521445865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 84}], {
             RGBColor[
             0.9791654405644673, 0.9545159561516343, 0.6220369084821427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 85}], {
             RGBColor[
             0.9581566290210999, 0.9390230672777584, 0.6654562832065027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 86}], {
             RGBColor[
             0.9806513377723971, 0.9551304128329297, 0.5974117463680384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 57}], {
             RGBColor[
             0.9879225732203389, 0.9889061733656175, 0.8333596956900724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 70}], {
             RGBColor[
             0.7882901312575976, 0.8339218038800218, 0.9383079099066066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 75}], {
             RGBColor[
             0.5804534369007264, 0.6457375999515739, 0.9244442763196126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 67}], {
             RGBColor[
             0.9765270090428423, 0.9804218343628008, 0.8532966976330483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 68}], {
             RGBColor[
             0.5863526355932204, 0.6485445847457627, 0.8431373389830508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 72}], {
             RGBColor[
             0.9862010669530393, 0.9876367309124098, 0.8369210409894826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 78}], {
             RGBColor[
             0.9778100756551141, 0.9813787433414044, 0.8511248005358396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 65}], {
             RGBColor[
             0.9691403833656174, 0.9765055289588378, 0.9371214608716706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 84}], {
             RGBColor[
             0.9776222000075665, 0.9826558055463075, 0.9149070209518764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 85}], {
             RGBColor[
             0.9566133884641992, 0.9671629166724317, 0.9583263956762365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 90}], {
             RGBColor[
             0.9182627101785463, 0.9367773415874656, 0.9614020220379227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 100}], {
             RGBColor[
             0.9812034692316205, 0.9841367524048747, 0.8555561218816443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 84}], {
             RGBColor[
             0.9763669750931128, 0.9450760750058156, 0.6111653985717911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 100}], {
             RGBColor[
             0.9799482443171668, 0.9465570218643828, 0.5518144995015589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 59}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 66}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 79}], {
             RGBColor[
             0.5622540392310464, 0.6321645189683052, 0.955251109411262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 98}], {
             RGBColor[
             0.5839057197336561, 0.6475327221549636, 0.8836890671912832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 99}], {
             RGBColor[
             0.4925741440677966, 0.5769697324455205, 0.9574106307506054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 64}], {
             RGBColor[
             0.5797982530266343, 0.6452489648910411, 0.9255533317191282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 73}], {
             RGBColor[
             0.5217171016949151, 0.39151734019370443`, 0.5710774140435835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 74}], {
             RGBColor[
             0.3867636943568712, 0.493578203928448, 0.9473646335869941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 88}], {
             RGBColor[
             0.5828624911065174, 0.647101320307889, 0.9009780653321164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 89}], {
             RGBColor[
             0.501510682470002, 0.5839842467151375, 0.9582925251386718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 91}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 93}], {
             RGBColor[
             0.48118702495422333`, 0.5680740284486865, 0.9562756691360426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 64}], {
             RGBColor[
             0.9872673893462469, 0.9884175383050848, 0.8344687510895882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 70}], {
             RGBColor[
             0.7942328306764838, 0.8367467773424915, 0.856280052957454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 74}], {
             RGBColor[
             0.7942328306764838, 0.8367467773424915, 0.856280052957454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 75}], {
             RGBColor[
             0.5863961363196126, 0.6485625734140436, 0.84241641937046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 88}], {
             RGBColor[
             0.99033162742613, 0.9902698937219325, 0.8098934847025763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 96}], {
             RGBColor[
             0.963045404917759, 0.8803675084259773, 0.5078285594895963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 63}], {
             RGBColor[
             0.8174165259564166, 0.8554297281355933, 0.852310405181598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 83}], {
             RGBColor[
             0.9946768036282996, 0.9916442979605176, 0.7071759024460238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 97}], {
             RGBColor[
             0.991995968601477, 0.9840141087353531, 0.5766188183905345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 66}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 69}], {
             RGBColor[
             0.4284743135593221, 0.5268944576755448, 0.951021758692494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 77}], {
             RGBColor[
             0.581632806779661, 0.6465928142372881, 0.9213571169491523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 79}], {
             RGBColor[
             0.5622540392310464, 0.6321645189683052, 0.955251109411262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 83}], {
             RGBColor[
             0.586859661497549, 0.6483318152002271, 0.8040278399762903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 95}], {
             RGBColor[
             0.5827693861035375, 0.6470628189964673, 0.9025210561795165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 97}], {
             RGBColor[
             0.5841788264707264, 0.6407016259750626, 0.6734707559208011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 98}], {
             RGBColor[
             0.5839057197336561, 0.6475327221549636, 0.8836890671912832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 99}], {
             RGBColor[
             0.4925741440677966, 0.5769697324455205, 0.9574106307506054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 64}], {
             RGBColor[
             0.9825409022582399, 0.9864630144290162, 0.9127988738943518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 71}], {
             RGBColor[
             0.9718440226812274, 0.978485299155013, 0.930905900825221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 74}], {
             RGBColor[
             0.7895063435884766, 0.8347922534664229, 0.9346101757622176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 89}], {
             RGBColor[
             0.9042533317016075, 0.9251982962531126, 0.9455380673138953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 93}], {
             RGBColor[
             0.8839296741858287, 0.9092880779866614, 0.9435212113112661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 67}], {
             RGBColor[
             0.9768541170936897, 0.9798242387211543, 0.79460425059915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 68}], {
             RGBColor[
             0.5866797436440678, 0.6479469891041162, 0.7844448919491525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 72}], {
             RGBColor[
             0.9865281750038868, 0.9870391352707633, 0.7782285939555842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 86}], {
             RGBColor[
             0.9913261661622277, 0.9899482978208233, 0.7401399839588374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 92}], {
             RGBColor[
             0.8785538474576272, 0.9025134570217919, 0.8061843895278449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 94}], {
             RGBColor[
             0.9210200528302122, 0.9359116508375748, 0.8103577746392745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 83}], {
             RGBColor[
             0.8175320453232149, 0.8550550605755297, 0.8196891826881547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 97}], {
             RGBColor[
             0.8148512102963923, 0.8474248713503653, 0.6891320986326654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 73}], {
             RGBColor[
             0.9225883547215497, 0.7313723050847456, 0.5631297457627118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 74}], {
             RGBColor[
             0.7876349473835056, 0.8334331688194891, 0.9394169653061224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 88}], {
             RGBColor[
             0.9837337441331517, 0.9869562851989302, 0.8930303970512447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 89}], {
             RGBColor[
             0.9023819354966365, 0.9238392116061788, 0.9503448568578001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 91}], {
             RGBColor[
             0.5797982530266343, 0.6452489648910412, 0.9255533317191282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 93}], {
             RGBColor[
             0.8820582779808577, 0.9079289933397277, 0.9483280008551709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 96}], {
             RGBColor[
             0.9564475216247807, 0.8770538999029749, 0.5909654718382646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 90}], {
             RGBColor[
             0.9174067441494906, 0.9361389635245116, 0.962850949253419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 100}], {
             RGBColor[
             0.9803475032025648, 0.9834983743419208, 0.8570050490971406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 69}], {
             RGBColor[
             0.4284743135593221, 0.5268944576755448, 0.951021758692494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 77}], {
             RGBColor[
             0.581632806779661, 0.6465928142372881, 0.9213571169491523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 79}], {
             RGBColor[
             0.5622540392310464, 0.6321645189683052, 0.955251109411262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 83}], {
             RGBColor[
             0.586859661497549, 0.6483318152002271, 0.8040278399762903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 95}], {
             RGBColor[
             0.5827693861035375, 0.6470628189964673, 0.9025210561795165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 97}], {
             RGBColor[
             0.5841788264707264, 0.6407016259750626, 0.6734707559208011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[
             0.5839057197336561, 0.6475327221549636, 0.8836890671912832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 99}], {
             RGBColor[
             0.4925741440677966, 0.5769697324455205, 0.9574106307506054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 68}], {
             RGBColor[
             0.569101373449622, 0.6372712496170381, 0.9436603586499975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 72}], {
             RGBColor[
             0.9689498048094409, 0.9763633957836851, 0.9374440606564294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 86}], {
             RGBColor[
             0.9737477959677818, 0.9792725583337452, 0.8993554506596826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 92}], {
             RGBColor[
             0.8609754772631814, 0.8918377175347136, 0.9653998562286901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 94}], {
             RGBColor[
             0.9034416826357663, 0.9252359113504967, 0.9695732413401196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 72}], {
             RGBColor[
             0.578775431359819, 0.6444861461666471, 0.9272847020064319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 82}], {
             RGBColor[
             0.5869864430825171, 0.6486029881908895, 0.8178272330948331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 92}], {
             RGBColor[
             0.4708011038135594, 0.5599604679176755, 0.9552404975786926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 71}], {
             RGBColor[
             0.818648687008944, 0.8587717072925829, 0.9611811173424915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 77}], {
             RGBColor[
             0.831180120338983, 0.8680932719128329, 0.9388778756416463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 87}], {
             RGBColor[
             0.8317026683208932, 0.8683093589322235, 0.930217903270566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 95}], {
             RGBColor[
             0.8323166996628595, 0.8685632766720122, 0.9200418148720104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 97}], {
             RGBColor[
             0.8337261400300484, 0.8622020836506074, 0.690991514613295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 98}], {
             RGBColor[
             0.8334530332929782, 0.8690331798305084, 0.9012098258837771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 99}], {
             RGBColor[
             0.7421214576271187, 0.7984701901210653, 0.9749313894430993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 75}], {
             RGBColor[
             0.3867636943568712, 0.493578203928448, 0.9473646335869941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 96}], {
             RGBColor[
             0.7634129629550176, 0.7253831389403818, 0.6127767737061305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 77}], {
             RGBColor[
             0.9718071802292829, 0.9784700638543262, 0.9315164755991499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 87}], {
             RGBColor[
             0.9723297282111931, 0.9786861508737168, 0.9228565032280696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 82}], {
             RGBColor[
             0.9868348744423361, 0.9876951343575366, 0.8116109351012649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 92}], {
             RGBColor[
             0.8706495351733784, 0.8990526140843227, 0.9490241995851243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 74}], {
             RGBColor[
             0.7295537960517864, 0.5797015441221524, 0.5849410476305776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 88}], {
             RGBColor[
             0.9256525928014325, 0.7332246605015934, 0.5385544793756998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.8443007841649173, 0.670107586908842, 0.5958689391822554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 91}], {
             RGBColor[
             0.5217171016949153, 0.39151734019370443`, 0.5710774140435835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 93}], {
             RGBColor[
             0.8239771266491385, 0.6541973686423909, 0.5938520831796261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 88}], {
             RGBColor[
             0.7906991854633885, 0.835285524236337, 0.9148416989191105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 91}], {
             RGBColor[
             0.3867636943568712, 0.493578203928448, 0.9473646335869941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 96}], {
             RGBColor[
             0.7634129629550176, 0.7253831389403818, 0.6127767737061305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 96}], {
             RGBColor[
             0.5555762685981465, 0.5371989350119337, 0.5989131401191364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 81}], {
             RGBColor[
             0.9564289966892325, 0.9670253975885754, 0.9586385228541779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 84}], {
             RGBColor[
             0.9801551607057926, 0.984544883487702, 0.9106193791917341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 85}], {
             RGBColor[
             0.9591463491624252, 0.9690519946138262, 0.9540387539160942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 87}], {
             RGBColor[
             0.9848611615412322, 0.9880077154939668, 0.9005532615272244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 95}], {
             RGBColor[
             0.9854751928831984, 0.9882616332337555, 0.8903771731286689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 97}], {
             RGBColor[
             0.9868846332503873, 0.9819004402123508, 0.6613268728699535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 98}], {
             RGBColor[
             0.9866115265133171, 0.9887315363922519, 0.8715451841404356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 99}], {
             RGBColor[
             0.8952799508474576, 0.9181685466828087, 0.9452667476997577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 83}], {
             RGBColor[
             0.9701867007285954, 0.9751023341685322, 0.8257779493875523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 98}], {
             RGBColor[
             0.9672327589647025, 0.9743032411232688, 0.9054391766025451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 99}], {
             RGBColor[
             0.875901183298843, 0.9037402514138257, 0.9791607401618674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 84}], {
             RGBColor[
             0.9615218866039, 0.9706482181716967, 0.9421606519100223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 85}], {
             RGBColor[
             0.9405130750605326, 0.9551553292978208, 0.9855800266343825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 86}], {
             RGBColor[
             0.991632865600677, 0.9906042969075965, 0.7735223251045181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 87}], {
             RGBColor[
             0.9902147978440884, 0.9900178894475682, 0.7970233776729051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 92}], {
             RGBColor[
             0.8788605468960766, 0.9031694561085651, 0.8395667306735256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 97}], {
             RGBColor[
             0.9921114879682753, 0.9836394411752896, 0.5439975958970914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 85}], {
             RGBColor[
             0.9642392390770926, 0.9726748151969475, 0.9375608829719386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.9258885607914398, 0.9422892401119813, 0.9406365093336246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 90}], {
             RGBColor[
             0.9048797492480725, 0.9267963512381054, 0.9840558840579848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 92}], {
             RGBColor[
             0.8754475263317192, 0.9019617766343826, 0.9109355895883775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[
             0.9179137317043041, 0.9353599704501656, 0.9151089746998071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 91}], {
             RGBColor[
             0.5828624911065173, 0.647101320307889, 0.9009780653321164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 96}], {
             RGBColor[
             0.9595117597046638, 0.8789062553198228, 0.5663902054512527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 91}], {
             RGBColor[
             0.5015106824700021, 0.5839842467151376, 0.9582925251386718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 93}], {
             RGBColor[
             0.8037707074242253, 0.846664275163824, 0.9810671942747144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 100}], {
             RGBColor[
             0.9294698300154938, 0.9437701869705486, 0.8812856102633926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 93}], {
             RGBColor[
             0.48118702495422333`, 0.5680740284486865, 0.9562756691360426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 96}], {
             RGBColor[
             0.5555762685981465, 0.5371989350119337, 0.5989131401191364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 94}], {
             RGBColor[
             0.8051414129997037, 0.8479251296511341, 0.9811533802688146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 98}], {
             RGBColor[
             0.9877481058371936, 0.989201541151431, 0.8527091233707997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 99}], {
             RGBColor[
             0.896416530171334, 0.9186385514419879, 0.9264306869301219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 99}], {
             RGBColor[
             0.8975528638014527, 0.9191084546004842, 0.9075986979418885]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.058168352269944726`], {
             RGBColor[
             0.5946003887137423, 0.6817624078568959, 0.9612282671739882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.058168352269944726`], {
             RGBColor[
             0.8062212881355932, 0.8485454648910411, 0.9813202615012107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.058168352269944726`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.058168352269944726`], {
             RGBColor[
             0.988645185472155, 0.9895725066343826, 0.837842192251816]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.058168352269944726`], {
             RGBColor[
             0.9330388159806294, 0.7722282493946726, 0.2649796634382566]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.058168352269944726`], {
             RGBColor[
             0.9938547513559323, 0.9892642594673123, 0.572505793050847]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.058168352269944726`], {
             RGBColor[
             0.9024917626377428, 0.9250864503137817, 0.9905616640559372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.058168352269944726`], {
             RGBColor[
             0.9273285747578692, 0.9448906501210654, 0.9929306213680387]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.058168352269944726`], {
             RGBColor[
             0.9727331115283886, 0.9791849797400801, 0.9310399092256756]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.058168352269944726`], {
             RGBColor[
             0.9888511480950734, 0.9896576774719573, 0.8344288585758756]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.058168352269944726`], {
             RGBColor[
             0.9458030689284639, 0.959100598062954, 0.9766254468673439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.058168352269944726`], {
             RGBColor[
             0.9435565098305085, 0.9574251179661017, 0.9804282854237286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.058168352269944726`], {
             RGBColor[
             0.9397522163680387, 0.9545878821307506, 0.986867961937046]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.058168352269944726`], {
             RGBColor[
             0.9507674463276836, 0.9628030225988701, 0.9682220508474575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.058168352269944726`], {
             RGBColor[
             0.9668443693889974, 0.8998204140161206, 0.3256970653020683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.058168352269944726`], {
             RGBColor[
             0.9755526201095961, 0.981287764623423, 0.926267216643303]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.058168352269944726`], {
             RGBColor[
             0.9668443693889974, 0.8998204140161206, 0.3256970653020683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.058168352269944726`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.058168352269944726`], {
             RGBColor[
             0.944481734199733, 0.8175956070069668, 0.2741869040371595]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.058168352269944726`], {
             RGBColor[
             0.991422197361034, 0.9907208724163843, 0.7918199185766968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.058168352269944726`], {
             RGBColor[
             0.9952218855582015, 0.9921884212874953, 0.7213099139935563]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.058168352269944726`], {
             RGBColor[
             0.9089872130750605, 0.6768716585956412, 0.2456271791767554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.058168352269944726`], {
             RGBColor[
             0.9887031864406779, 0.9895964915254237, 0.8368809661016949]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.058168352269944726`], {
             RGBColor[
             0.9596639401097, 0.9694380130948264, 0.9531626074516973]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.058168352269944726`], {
             RGBColor[
             0.9739972629201243, 0.9239488034758807, 0.353484705959895]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.058168352269944726`], {
             RGBColor[
             0.978623862719638, 0.9835782923332941, 0.9210684040128636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.058168352269944726`], {
             RGBColor[
             0.8906812505806198, 0.9156690685872413, 0.9894351668725602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.058168352269944726`], {
             RGBColor[
             0.9538752628419347, 0.9651208270666161, 0.9629613281371939]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.058168352269944726`], {
             RGBColor[
             0.9164253169148018, 0.7063612617190442, 0.251612052120948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.058168352269944726`], {
             RGBColor[
             0.9924105890685679, 0.9911295977879578, 0.7754397101071142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.058168352269944726`], {
             RGBColor[
             0.9950470408163266, 0.9918144460641399, 0.7022791428571428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.058168352269944726`], {
             RGBColor[
             0.9903835314803511, 0.9792235350083502, 0.41714226502920954`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.058168352269944726`], {
             RGBColor[
             0.9756597368845844, 0.9813676521388217, 0.9260858958837771]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.058168352269944726`], {
             RGBColor[
             0.9722374599897786, 0.9788153236341397, 0.9318789179939173]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.058168352269944726`], {
             RGBColor[
             0.9870484565942063, 0.9679735443045614, 0.4041861288725826]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.058168352269944726`], {
             RGBColor[
             0.6269244660532689, 0.7080045500242131, 0.9637729369491526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.058168352269944726`], {
             RGBColor[
             0.8541381368038742, 0.886530581598063, 0.9859496520581114]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.058168352269944726`], {
             RGBColor[
             0.8367755061538076, 0.8726860912137537, 0.9842935888469047]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.058168352269944726`], {
             RGBColor[
             0.9908599707498005, 0.9808306765374631, 0.4189931416230137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.058168352269944726`], {
             RGBColor[
             0.970403952265652, 0.9774478965755794, 0.9349825683154617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.058168352269944726`], {
             RGBColor[
             0.9920382421307506, 0.9909756227602906, 0.7816104624697335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.058168352269944726`], {
             RGBColor[
             0.24682265133171918`, 0.3767566343825666, 0.9373675569007264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.058168352269944726`], {
             RGBColor[
             0.951511882690122, 0.963358222019074, 0.9669619142659485]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.058168352269944726`], {
             RGBColor[
             0.9528939117727123, 0.9643889370460049, 0.9646224995200365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.058168352269944726`], {
             RGBColor[
             0.9852480506204601, 0.9881677040708233, 0.8941415082475784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.058168352269944726`], {
             RGBColor[
             0.24682265133171918`, 0.3767566343825666, 0.9373675569007264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.058168352269944726`], {
             RGBColor[
             0.9806695060532687, 0.9851039297820824, 0.9176056634382566]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.058168352269944726`], {
             RGBColor[
             0.9679885278450363, 0.9756464769975788, 0.9390712518159805]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.058168352269944726`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.058168352269944726`], {
             RGBColor[
             0.9730828305084745, 0.9208642082324453, 0.3499323087167068]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.058168352269944726`], {
             RGBColor[
             0.9819798738014528, 0.9860811999031478, 0.915387552639225]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.058168352269944726`], {
             RGBColor[
             0.9937782711864407, 0.9916951694915255, 0.7527736779661016]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.058168352269944726`], {
             RGBColor[
             0.969996349394673, 0.9771439070217918, 0.9356725336561743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.058168352269944726`], {
             RGBColor[
             0.9674858995657655, 0.9019844459408078, 0.3281892888960036]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.058168352269944726`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.058168352269944726`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.058168352269944726`], {
             RGBColor[
             0.9938652726392252, 0.9917311468280872, 0.7513318387409198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.058168352269944726`], {
             RGBColor[
             0.9945612842615013, 0.9920189655205811, 0.739797124939467]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.058168352269944726`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.058168352269944726`], {
             RGBColor[
             0.9844122984632109, 0.98782209907595, 0.907992084350447]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.058168352269944726`], {
             RGBColor[
             0.9944324872881356, 0.9904999782082324, 0.6353887838983049]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.058168352269944726`], {
             RGBColor[
             0.9568715369491526, 0.9673554433898306, 0.9578894176271185]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.058168352269944726`], {
             RGBColor[
             0.6402717676513319, 0.7188404907506054, 0.9648236854237288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.058168352269944726`], {
             RGBColor[
             0.9806695060532687, 0.9851039297820824, 0.9176056634382566]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.058168352269944726`], {
             RGBColor[
             0.9682844173365618, 0.9758671508958838, 0.9385703880871669]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.058168352269944726`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.058168352269944726`], {
             RGBColor[
             0.9592757468992439, 0.9691484992340762, 0.953819717299995]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.058168352269944726`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.058168352269944726`], {
             RGBColor[
             0.6780216271186441, 0.7483949153510896, 0.9685425173849879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.058168352269944726`], {
             RGBColor[
             0.5946003887137423, 0.6817624078568959, 0.9612282671739882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.058168352269944726`], {
             RGBColor[
             0.9592757468992439, 0.9691484992340762, 0.953819717299995]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.058168352269944726`], {
             RGBColor[
             0.978623862719638, 0.9835782923332941, 0.9210684040128636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.058168352269944726`], {
             RGBColor[
             0.8645072033898304, 0.4776406803874088, 0.20865382808716698`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.058168352269944726`], {
             RGBColor[
             0.5946003887137423, 0.6817624078568959, 0.9612282671739882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.058168352269944726`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.058168352269944726`], {
             RGBColor[
             0.9750622707911252, 0.9809220629045807, 0.9270972501358896]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.058168352269944726`], {
             RGBColor[
             0.984338613559322, 0.9877916284745764, 0.9092132338983048]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.058168352269944726`], {
             RGBColor[
             0.9618418801237876, 0.9710623171912833, 0.9494759231055775]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.058168352269944726`], {
             RGBColor[
             0.9455810784620927, 0.9589350379366104, 0.977001218822524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.058168352269944726`], {
             RGBColor[
             0.9435565098305085, 0.9574251179661017, 0.9804282854237286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.058168352269944726`], {
             RGBColor[
             0.93779572258734, 0.95312873227257, 0.9901797955724663]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.058168352269944726`], {
             RGBColor[
             0.9950458861650343, 0.9918119763817791, 0.7021534661896662]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.058168352269944726`], {
             RGBColor[
             0.9947923229950979, 0.991269630400454, 0.6745546799525807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.058168352269944726`], {
             RGBColor[
             0.9852480506204601, 0.9881677040708233, 0.8941415082475784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.058168352269944726`], {
             RGBColor[
             0.9432304275337253, 0.9571819263230716, 0.9809802576962987]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.058168352269944726`], {
             RGBColor[
             0.9882198450363197, 0.9893966174334141, 0.84489118401937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.058168352269944726`], {
             RGBColor[
             0.9853837095231425, 0.9882238025133573, 0.891893289156144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.058168352269944726`], {
             RGBColor[
             0.9867979822130347, 0.988808640615778, 0.8684551306642327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.058168352269944726`], {
             RGBColor[
             0.8240943649400041, 0.8625744934302751, 0.9830840502773437]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.058168352269944726`], {
             RGBColor[
             0.8665290709624195, 0.8964107761531394, 0.987131510419671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.058168352269944726`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.058168352269944726`], {
             RGBColor[
             0.7626752076271188, 0.8145269358353512, 0.976979995157385]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.058168352269944726`], {
             RGBColor[
             0.7834470499084466, 0.8307540568973729, 0.9790503382720852]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.058168352269944726`], {
             RGBColor[
             0.8476076183722886, 0.8813233234669171, 0.9853267653802441]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.058168352269944726`], {
             RGBColor[
             0.986611772207075, 0.9887316379929347, 0.8715411123590331]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.058168352269944726`], {
             RGBColor[
             0.9322255371962929, 0.7690038700238675, 0.2643252802382728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.058168352269944726`], {
             RGBColor[
             0.9894306529414527, 0.9760092519501251, 0.41344051184160213`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.058168352269944726`], {
             RGBColor[
             0.9888844394673123, 0.9896714443099274, 0.8338771343825664]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.058168352269944726`], {
             RGBColor[
             0.8062212881355932, 0.8485454648910411, 0.9813202615012107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.058168352269944726`], {
             RGBColor[
             0.9924105890685679, 0.9911295977879578, 0.7754397101071142]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100}, {
          Null, CompressedData["
1:eJwVxVmbqQwAAOCxVtbppLIkW4w1a5YJk8gSaaRCIqr783/Pr/me7715C/Zf
xfZ+fHz883x8/D9363DUk1oFBOGSrgbkKTe9Ubr+DJzlM67jGn44aCN55AiO
7OTWuWMuH0qHqrVObVrjcvv1PnbAe71DT+vplLkyddN8hkqxEiiAOngBnQA/
4nmBl/kz71Cz2Wqmz8zZE8QwHhOwC+aAKIqhFLpCL6gZpsKz8Cpshp+ghVm8
JViWU9t1dtxud0NGCI/IiIU4oXgsHi/Fq3gmo3kQT8YzygyrQz/up/w9/8Gv
+58BCZQwiZcESbpIluT8+c395n89MAjDCIzBI5iHBViCZdiCncDPzznXz/f7
6/6+Nu6Mx9x4N755Y96s9xj4/v75PnvrsXq2Xj/6SZBESYzESZIie6ROmuQz
5MbdtFt1h+5nNkDABEIQI4InZOJMOOEtuqW2s+1quzU9NEwjNEHTI1qmLdpp
99vr9t5fxsuZcrlXPpS19qvz4l7r1/6Fqxm1rPbUoXpQVc1b+CxkC4V67dF5
jB/TB/fYPW6PXCvfah1r1/a1cx1fuevuen2l0qlqaphy0SJWLE6LQlEqXjzR
aCY6jKpRLfeV//pqff3WxLbYEcfiVOTEnShexZenEW0gjUyjQTeG3maumW9+
NevNZqt5DC+p5Wy5XC23S31pLp/+ZCyJJ5P1ZC95AKJACsgAZaAKDAEV0AAX
7KJdrFvsdoWu1L3U7p37+M7dd3fxfr3f7vfH/RV4f79/3vxbeEvv8xswQkbc
SBslo2qohmYYbhAIhoLxYCqYDpaC1aARdIub7ma6ETYbaXMJsDCLsARLsyOW
5VmBlViZPbMW+2Yd7zw2j88/59l5YV6a1+eBRIJIfCfYxE+CT8iJc+IdXACL
0CK1SC+qi4WxcEEFVTCFVIoKpXSVlbJVFF25KCZsIzZh0/bIZm3eFmzJlm3L
th1vJVaJV7KVUqVSr8zDg9ZgsBysBtvBEThFT/gpcyqfeqfD6aSetCADMCEm
xsSZNFNiqgyzYFRGYwzGbU86k/5kwk3WE3Gyn1wnL6/P9+nL+gq+iq/um0dq
kUFkGuEiYuQaefkhKAyhEAlR0AxaQitoCymQDpnQ8z9pR8GG
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[69, 98] -> 
             RGBColor[
              0.35934722090825977`, 0.48438990088158124`, 0.9441651443282024],
              UndirectedEdge[29, 33] -> 
             RGBColor[
              0.29422509162390786`, 0.4255184180648389, 0.9401059109878009], 
             UndirectedEdge[55, 59] -> 
             RGBColor[
              0.26182384182735224`, 0.39252383672388913`, 0.9382218525071802],
              UndirectedEdge[47, 74] -> 
             RGBColor[
              0.31904494583740095`, 0.4476628644149205, 0.9416637299737558], 
             UndirectedEdge[19, 43] -> 
             RGBColor[
              0.25864725898215624`, 0.389185046746603, 0.9380409508134795], 
             UndirectedEdge[57, 75] -> 
             RGBColor[
              0.25952031121468844`, 0.390102679997703, 0.9380906698465571], 
             UndirectedEdge[19, 46] -> 
             RGBColor[
              0.2688995810964162, 0.39996088732345647`, 0.9386248053909352], 
             UndirectedEdge[36, 67] -> 
             RGBColor[
              0.18042977836149893`, 0.3069735153395867, 0.9335865810045261], 
             UndirectedEdge[79, 99] -> 
             RGBColor[
              0.3231374521934327, 0.4482183313765927, 0.9420339521780562], 
             UndirectedEdge[52, 68] -> 
             RGBColor[
              0.8780291995303775, 0.46447808085033465`, 0.21689224319720418`],
              UndirectedEdge[81, 85] -> 
             RGBColor[
              0.5777440554332705, 0.6680776771306483, 0.9599012748713662], 
             UndirectedEdge[12, 88] -> 
             RGBColor[
              0.44729833605503005`, 0.5559100353701449, 0.9509297720791202], 
             UndirectedEdge[72, 82] -> 
             RGBColor[
              0.8344620499016556, 0.2658959936764921, 0.180634203946131], 
             UndirectedEdge[31, 44] -> 
             RGBColor[
              0.5893518598321712, 0.6739738751825308, 0.9626393731710036], 
             UndirectedEdge[17, 79] -> 
             RGBColor[
              0.3156295526433677, 0.44171536614432994`, 0.9415555554577009], 
             UndirectedEdge[91, 96] -> 
             RGBColor[
              0.269451185257078, 0.40054065827003577`, 0.9386562184318596], 
             UndirectedEdge[55, 99] -> 
             RGBColor[
              0.32604506358539376`, 0.45127441530275375`, 0.9421995363454028],
              UndirectedEdge[77, 99] -> 
             RGBColor[
              0.4105884153235183, 0.5300527814046032, 0.9473833086487027], 
             UndirectedEdge[29, 38] -> 
             RGBColor[
              0.3762188058276783, 0.5002835531261081, 0.9451933075234802], 
             UndirectedEdge[26, 90] -> 
             RGBColor[
              0.2640863311664119, 0.39490185646935017`, 0.9383506979279865], 
             UndirectedEdge[13, 27] -> 
             RGBColor[
              0.30786109230723857`, 0.43780476345745334`, 0.9409573735218479],
              UndirectedEdge[22, 99] -> 
             RGBColor[
              0.6824515754881706, 0.7473171966554524, 0.9484738769221548], 
             UndirectedEdge[73, 74] -> 
             RGBColor[
              0.3072565676292452, 0.4352725314918011, 0.940992399274144], 
             UndirectedEdge[8, 77] -> 
             RGBColor[
              0.6903471893885933, 0.7540727058376107, 0.9477616322002713], 
             UndirectedEdge[36, 94] -> 
             RGBColor[
              0.1800640484055534, 0.3065891099672694, 0.9335657532245839], 
             UndirectedEdge[21, 87] -> 
             RGBColor[
              0.8461475149580568, 0.7442097533956613, 0.6102686063858478], 
             UndirectedEdge[59, 83] -> 
             RGBColor[
              0.24944682557751796`, 0.3795148078971581, 0.9375169997419068], 
             UndirectedEdge[24, 42] -> 
             RGBColor[
              0.7818518898687528, 0.7011631313519644, 0.6053992543639326], 
             UndirectedEdge[33, 42] -> 
             RGBColor[
              0.46221511877127164`, 0.5653020306816455, 0.952477193383617], 
             UndirectedEdge[14, 42] -> 
             RGBColor[
              0.6875842561639678, 0.755865313839969, 0.9694956308803766], 
             UndirectedEdge[45, 78] -> 
             RGBColor[
              0.8888960529642432, 0.9113695171236152, 0.8624721274568261], 
             UndirectedEdge[15, 38] -> 
             RGBColor[
              0.3740760297515814, 0.49842758818805, 0.9450567717266938], 
             UndirectedEdge[84, 85] -> 
             RGBColor[
              0.5258992134513589, 0.6255397259320082, 0.9559436352420423], 
             UndirectedEdge[55, 98] -> 
             RGBColor[
              0.2718017456530969, 0.4030112462803886, 0.9387900793690704], 
             UndirectedEdge[86, 92] -> 
             RGBColor[
              0.5898473968790202, 0.652327074257428, 0.8461866592841044], 
             UndirectedEdge[72, 92] -> 
             RGBColor[
              0.5088521381215928, 0.27790300442365007`, 0.5558317972580653], 
             UndirectedEdge[19, 99] -> 
             RGBColor[
              0.33504481922143936`, 0.46073372909370225`, 0.9427120591149303],
              UndirectedEdge[4, 76] -> 
             RGBColor[
              0.9165776385018892, 0.6448130127141793, 0.40538275488353814`], 
             UndirectedEdge[23, 76] -> 
             RGBColor[
              0.9905483291850934, 0.9895519766020239, 0.7476033518841813], 
             UndirectedEdge[9, 72] -> 
             RGBColor[
              0.8914135512087347, 0.5438293614385904, 0.22874208440602506`], 
             UndirectedEdge[2, 44] -> 
             RGBColor[
              0.6476158835940419, 0.7227173201002071, 0.9668276779841867], 
             UndirectedEdge[74, 88] -> 
             RGBColor[
              0.3260233854984479, 0.4549976469573106, 0.9420611417887761], 
             UndirectedEdge[21, 49] -> 
             RGBColor[
              0.8381155029968219, 0.7379350846059927, 0.6094680504969712], 
             UndirectedEdge[21, 34] -> 
             RGBColor[
              0.7440489383777218, 0.6635696741320418, 0.6006939636333543], 
             UndirectedEdge[59, 66] -> 
             RGBColor[
              0.2986049435975745, 0.4299329425040255, 0.9403622564770246], 
             UndirectedEdge[17, 99] -> 
             RGBColor[
              0.3958768319210234, 0.5173103472870436, 0.9464458995632381], 
             UndirectedEdge[26, 53] -> 
             RGBColor[
              0.27181647740875625`, 0.40165680145894234`, 0.9388410781260154],
              UndirectedEdge[23, 50] -> 
             RGBColor[
              0.9890507904475296, 0.9897402347152724, 0.831120268137828], 
             UndirectedEdge[41, 74] -> 
             RGBColor[
              0.39624144168094344`, 0.517626153935267, 0.9464691321747285], 
             UndirectedEdge[59, 79] -> 
             RGBColor[
              0.2589162304353912, 0.38946775279772805`, 0.9380562683398335], 
             UndirectedEdge[56, 93] -> 
             RGBColor[
              0.251058389952088, 0.3812086642339142, 0.9376087759489427], 
             UndirectedEdge[19, 98] -> 
             RGBColor[
              0.2808015012891425, 0.4124705600713371, 0.9393026021385978], 
             UndirectedEdge[2, 38] -> 
             RGBColor[
              0.4744745540542128, 0.5836658197325597, 0.9519298496562583], 
             UndirectedEdge[19, 59] -> 
             RGBColor[
              0.2708235974633978, 0.40198315051483763`, 0.9387343752767077], 
             UndirectedEdge[24, 76] -> 
             RGBColor[
              0.9509230096039614, 0.8306452679372385, 0.4351994673534736], 
             UndirectedEdge[5, 20] -> 
             RGBColor[
              0.23580229552736498`, 0.3651735417012756, 0.9367399639408238], 
             UndirectedEdge[37, 84] -> 
             RGBColor[
              0.5813861978869495, 0.66930600772412, 0.9611872941941962], 
             UndirectedEdge[9, 82] -> 
             RGBColor[
              0.8944306469902588, 0.5670200817151858, 0.2316312587337348], 
             UndirectedEdge[47, 75] -> 
             RGBColor[
              0.2704352603663721, 0.40157498360386956`, 0.9387122600535251], 
             UndirectedEdge[51, 75] -> 
             RGBColor[
              0.2631874052799758, 0.3939570283675128, 0.9382995054285956], 
             UndirectedEdge[58, 63] -> 
             RGBColor[
              0.22145736040975994`, 0.3500961053712548, 0.9359230411073061], 
             UndirectedEdge[7, 25] -> 
             RGBColor[
              0.2646919276847649, 0.3951010487472052, 0.9384011984763869], 
             UndirectedEdge[1, 55] -> 
             RGBColor[
              0.25340680094735984`, 0.3836769930878019, 0.9377425144809607], 
             UndirectedEdge[82, 86] -> 
             RGBColor[
              0.9154573086590831, 0.64032006351027, 0.4709890659721701], 
             UndirectedEdge[34, 71] -> 
             RGBColor[
              0.46781157980336074`, 0.5760433128989255, 0.9520168308232597], 
             UndirectedEdge[41, 73] -> 
             RGBColor[
              0.34062966364440406`, 0.46417862987955394`, 0.9431189034415599],
              UndirectedEdge[92, 94] -> 
             RGBColor[
              0.18353386454932197`, 0.3102361067334203, 0.9337633541208386], 
             UndirectedEdge[3, 62] -> 
             RGBColor[
              0.3326644235069168, 0.4616841238673607, 0.9424500919629462], 
             UndirectedEdge[70, 75] -> 
             RGBColor[
              0.2709835768789808, 0.4021512990238961, 0.9387434858677567], 
             UndirectedEdge[57, 96] -> 
             RGBColor[
              0.26925290833864535`, 0.40033225665728034`, 0.9386449268546793],
              UndirectedEdge[68, 72] -> 
             RGBColor[
              0.8243819770600658, 0.1884161366999483, 0.17098151480921064`], 
             UndirectedEdge[13, 54] -> 
             RGBColor[
              0.26215076948672145`, 0.392867458422297, 0.938240470553735], 
             UndirectedEdge[48, 96] -> 
             RGBColor[
              0.2710430288508906, 0.402213786815846, 0.9387468715696057], 
             UndirectedEdge[30, 50] -> 
             RGBColor[
              0.9048589996840575, 0.566437416695873, 0.47911193415723874`], 
             UndirectedEdge[11, 92] -> 
             RGBColor[
              0.21022995471211395`, 0.3382953901243926, 0.9352836569622833], 
             UndirectedEdge[41, 56] -> 
             RGBColor[
              0.3357366265014662, 0.459035737605853, 0.9428402522148693], 
             UndirectedEdge[73, 91] -> 
             RGBColor[
              0.25271649556761044`, 0.3829514383657963, 0.9377032026107992], 
             UndirectedEdge[32, 39] -> 
             RGBColor[
              0.2935264779562271, 0.4258453173585629, 0.9400272707348724], 
             UndirectedEdge[32, 80] -> 
             RGBColor[
              0.2808572092204622, 0.41252911263924097`, 0.939305774622874], 
             UndirectedEdge[20, 66] -> 
             RGBColor[
              0.271765998365242, 0.4017235093774315, 0.9388338182507047], 
             UndirectedEdge[47, 88] -> 
             RGBColor[
              0.28219998567006427`, 0.41394045582471695`, 0.9393822437552191],
              UndirectedEdge[14, 53] -> 
             RGBColor[
              0.5212638853795565, 0.6175278736453831, 0.9572307375115887], 
             UndirectedEdge[51, 57] -> 
             RGBColor[
              0.25705874177093724`, 0.3875154144398035, 0.9379504871083011], 
             UndirectedEdge[30, 94] -> 
             RGBColor[
              0.4995877733317956, 0.224777469479577, 0.549414921546451], 
             UndirectedEdge[22, 69] -> 
             RGBColor[
              0.6926573828576388, 0.7561569540400923, 0.9491241819430962], 
             UndirectedEdge[4, 94] -> 
             RGBColor[
              0.5098088734120636, 0.30334132361113186`, 0.5592026585263972], 
             UndirectedEdge[4, 86] -> 
             RGBColor[
              0.9161224057417618, 0.6454322911351396, 0.4716259636896631], 
             UndirectedEdge[9, 94] -> 
             RGBColor[
              0.566095277636464, 0.5761624637483606, 0.6066736412687983], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.25232882209907226`, 0.38254396897044507`, 0.9376811251802775],
              UndirectedEdge[12, 60] -> 
             RGBColor[
              0.5377449711891708, 0.6356046186030777, 0.9567524004381972], 
             UndirectedEdge[25, 40] -> 
             RGBColor[
              0.22979823437354924`, 0.35886289274915106`, 0.9363980415403266],
              UndirectedEdge[22, 95] -> 
             RGBColor[
              0.7735850344334367, 0.822659249453164, 0.9552736235962966], 
             UndirectedEdge[3, 33] -> 
             RGBColor[
              0.283755346452618, 0.41557523862275036`, 0.9394708192508354], 
             UndirectedEdge[48, 93] -> 
             RGBColor[
              0.2586149766637431, 0.3891511159831336, 0.9380391123832033], 
             UndirectedEdge[15, 90] -> 
             RGBColor[
              0.3120203774346074, 0.44461862031594124`, 0.9411048183197483], 
             UndirectedEdge[77, 97] -> 
             RGBColor[
              0.3343295626774611, 0.4586498895325537, 0.9427200995394867], 
             UndirectedEdge[44, 78] -> 
             RGBColor[
              0.88634546706693, 0.9093769800354632, 0.8622179088911622], 
             UndirectedEdge[30, 92] -> 
             RGBColor[
              0.5023132309055276, 0.22764209819356024`, 0.5495701323233219], 
             UndirectedEdge[37, 76] -> 
             RGBColor[
              0.8601494153237335, 0.8880770205793902, 0.7996440970661025], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.5927913677992559, 0.604221747139333, 0.6081939441102431], 
             UndirectedEdge[75, 96] -> 
             RGBColor[
              0.27538157184768386`, 0.40677387058498965`, 0.9389939451749738],
              UndirectedEdge[31, 80] -> 
             RGBColor[
              0.33469414166217204`, 0.4606589391956579, 0.9426813312926726], 
             UndirectedEdge[85, 90] -> 
             RGBColor[
              0.4615407941261787, 0.5697362170178263, 0.951844951557591], 
             UndirectedEdge[91, 93] -> 
             RGBColor[
              0.2570231330699305, 0.38747798743732337`, 0.9379484592454572], 
             UndirectedEdge[22, 49] -> 
             RGBColor[
              0.8672856751894109, 0.8967275864503471, 0.9640189035929849], 
             UndirectedEdge[69, 87] -> 
             RGBColor[
              0.6064566505030319, 0.6883381284885098, 0.9639201838642415], 
             UndirectedEdge[47, 70] -> 
             RGBColor[
              0.27576986252162594`, 0.40718198870235345`, 0.9390160577544302],
              UndirectedEdge[42, 78] -> 
             RGBColor[
              0.8251990022368825, 0.8616088969798854, 0.8561234007231051], 
             UndirectedEdge[1, 43] -> 
             RGBColor[
              0.25434890859377146`, 0.3846672079572553, 0.9377961661177004], 
             UndirectedEdge[10, 35] -> 
             RGBColor[
              0.2769526708149095, 0.4084251952129716, 0.9390834169369247], 
             UndirectedEdge[67, 94] -> 
             RGBColor[
              0.18117413693153547`, 0.3077558833917543, 0.9336289711239099], 
             UndirectedEdge[73, 93] -> 
             RGBColor[
              0.2559514270950259, 0.38635155650761516`, 0.9378874271756332], 
             UndirectedEdge[68, 82] -> 
             RGBColor[
              0.8273990728415899, 0.2116068569765438, 0.1738706891369204], 
             UndirectedEdge[11, 52] -> 
             RGBColor[
              0.5864699931809645, 0.5791596032510256, 0.6031076177106328], 
             UndirectedEdge[15, 53] -> 
             RGBColor[
              0.3197505236769518, 0.4513735653055334, 0.9415951985177772], 
             UndirectedEdge[53, 100] -> 
             RGBColor[
              0.2844126072753804, 0.4148961325895252, 0.9395584090876155], 
             UndirectedEdge[58, 83] -> 
             RGBColor[
              0.22400482828107066`, 0.3527736556227943, 0.9360681156339361], 
             UndirectedEdge[74, 96] -> 
             RGBColor[
              0.3239912573187127, 0.45286175139604057`, 0.9419454150952044], 
             UndirectedEdge[8, 87] -> 
             RGBColor[
              0.8760096171986388, 0.9035182955368775, 0.9636482023948687], 
             UndirectedEdge[43, 46] -> 
             RGBColor[
              0.2608419331067822, 0.3914917884019613, 0.9381659342581474], 
             UndirectedEdge[73, 89] -> 
             RGBColor[
              0.24808487338589558`, 0.37808330979100657`, 0.9374394385794216],
              UndirectedEdge[11, 67] -> 
             RGBColor[
              0.20787022709432745`, 0.3358151667827266, 0.9351492739653546], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.28368193490479854`, 0.4148331204560798, 0.9394909859406446], 
             UndirectedEdge[98, 99] -> 
             RGBColor[
              0.3491414135387916, 0.47555014349694125`, 0.943514839307261], 
             UndirectedEdge[4, 9] -> 
             RGBColor[
              0.8950957440729377, 0.5721323093400554, 0.23226815645122778`], 
             UndirectedEdge[34, 49] -> 
             RGBColor[
              0.678986366254469, 0.7482686816351451, 0.9692402627616367], 
             UndirectedEdge[6, 7] -> 
             RGBColor[
              0.2850997356690481, 0.41655094886844685`, 0.9395633929504454], 
             UndirectedEdge[7, 40] -> 
             RGBColor[
              0.2785823850167328, 0.4097008001089655, 0.9391922394723524], 
             UndirectedEdge[23, 85] -> 
             RGBColor[
              0.8008648229179952, 0.8435478591637703, 0.9160354539398804], 
             UndirectedEdge[82, 92] -> 
             RGBColor[
              0.5118692339031169, 0.30109372470024554`, 0.558720971585775], 
             UndirectedEdge[34, 69] -> 
             RGBColor[
              0.5043580739226968, 0.6076980492248905, 0.954345541111748], 
             UndirectedEdge[13, 85] -> 
             RGBColor[
              0.44417434838099124`, 0.5514829814433777, 0.9508559581637567], 
             UndirectedEdge[95, 98] -> 
             RGBColor[
              0.44027487248405767`, 0.5508921962946529, 0.9503145859814027], 
             UndirectedEdge[34, 87] -> 
             RGBColor[
              0.687018378215704, 0.7545433504248138, 0.9700408186505132], 
             UndirectedEdge[61, 94] -> 
             RGBColor[
              0.17986770348779496`, 0.3063827390097185, 0.9335545716719839], 
             UndirectedEdge[61, 72] -> 
             RGBColor[
              0.5051859770600657, 0.2740496366999483, 0.5556230148092107], 
             UndirectedEdge[50, 86] -> 
             RGBColor[
              0.9923931656575502, 0.9911223927597408, 0.7757284611180213], 
             UndirectedEdge[66, 97] -> 
             RGBColor[
              0.2865673127095588, 0.41728062921084064`, 0.9396767312060312], 
             UndirectedEdge[9, 21] -> 
             RGBColor[
              0.9272801117087064, 0.7490947632900866, 0.26033044528115884`], 
             UndirectedEdge[34, 60] -> 
             RGBColor[
              0.5274957486173808, 0.6272838379970835, 0.9559455440932065], 
             UndirectedEdge[53, 84] -> 
             RGBColor[
              0.3801912291988372, 0.5037242665904019, 0.9454464268280143], 
             UndirectedEdge[21, 22] -> 
             RGBColor[
              0.9323482473126639, 0.8120285789472437, 0.5954726044647025], 
             UndirectedEdge[14, 62] -> 
             RGBColor[
              0.5425047543047143, 0.6359256467112409, 0.9585841868969369], 
             UndirectedEdge[22, 30] -> 
             RGBColor[
              0.889942779596627, 0.5565022708656576, 0.5576225786548253], 
             UndirectedEdge[67, 72] -> 
             RGBColor[
              0.5064924105038062, 0.2754227810819841, 0.5556974142611366], 
             UndirectedEdge[61, 86] -> 
             RGBColor[
              0.5861812358174932, 0.6484737065337263, 0.8459778768352497], 
             UndirectedEdge[5, 83] -> 
             RGBColor[
              0.23714577838221002`, 0.3665856273634506, 0.9368164733019025], 
             UndirectedEdge[46, 99] -> 
             RGBColor[
              0.3372394933460653, 0.46304047074906063`, 0.9428370425595982], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.781084942834804, 0.8289087608987646, 0.9788149055141302], 
             UndirectedEdge[7, 37] -> 
             RGBColor[
              0.5197144859100872, 0.615889070520134, 0.9572576272411842], 
             UndirectedEdge[7, 53] -> 
             RGBColor[
              0.3185195172219749, 0.4503073293864159, 0.9415167598750023], 
             UndirectedEdge[12, 52] -> 
             RGBColor[
              0.7720788229198519, 0.7426869970369261, 0.6158231874912047], 
             UndirectedEdge[50, 85] -> 
             RGBColor[
              0.8031648921505794, 0.844498996900527, 0.8779173543675954], 
             UndirectedEdge[14, 15] -> 
             RGBColor[
              0.517451452940507, 0.6142257362851044, 0.9569878126877741], 
             UndirectedEdge[14, 35] -> 
             RGBColor[
              0.5107221888506179, 0.6078178110419963, 0.9565802436840543], 
             UndirectedEdge[8, 95] -> 
             RGBColor[
              0.7742769644814296, 0.8231752897500257, 0.9541023665093038], 
             UndirectedEdge[7, 84] -> 
             RGBColor[
              0.3751477903048108, 0.49935589331100566`, 0.9451250633614249], 
             UndirectedEdge[14, 76] -> 
             RGBColor[
              0.8566553758991764, 0.885347450425243, 0.7992958438699176], 
             UndirectedEdge[60, 89] -> 
             RGBColor[
              0.357298326389239, 0.4775030084894488, 0.9443308094531306], 
             UndirectedEdge[37, 85] -> 
             RGBColor[
              0.6704659090566354, 0.7420729031411366, 0.9680761991218017], 
             UndirectedEdge[39, 80] -> 
             RGBColor[
              0.28185045974068534`, 0.4135730819117158, 0.9393623387706183], 
             UndirectedEdge[23, 24] -> 
             RGBColor[
              0.9471254016338135, 0.8298823883137303, 0.5568344831794053], 
             UndirectedEdge[11, 68] -> 
             RGBColor[
              0.5257597936505869, 0.24880852240069085`, 0.5504333745134287], 
             UndirectedEdge[27, 81] -> 
             RGBColor[
              0.4414307993595177, 0.5543994591447239, 0.9500026902294574], 
             UndirectedEdge[36, 61] -> 
             RGBColor[
              0.17912334491775841`, 0.3056003709575509, 0.9335121815526001], 
             UndirectedEdge[28, 59] -> 
             RGBColor[
              0.2655146286535537, 0.39640308768762733`, 0.9384320373569025], 
             UndirectedEdge[8, 30] -> 
             RGBColor[
              0.8906347096446199, 0.5570183111625192, 0.5564513215678325], 
             UndirectedEdge[34, 82] -> 
             RGBColor[
              0.7111994736592744, 0.481494992557141, 0.5719947770859303], 
             UndirectedEdge[50, 84] -> 
             RGBColor[
              0.7140851809808935, 0.7717321014835103, 0.87102844943999], 
             UndirectedEdge[57, 88] -> 
             RGBColor[
              0.27128503651838054`, 0.40246815221855037`, 0.9387606535482509],
              UndirectedEdge[6, 53] -> 
             RGBColor[
              0.2901431745630745, 0.4209193221478431, 0.939884756417035], 
             UndirectedEdge[8, 69] -> 
             RGBColor[
              0.6933493129056316, 0.7566729943369539, 0.9479529248561034], 
             UndirectedEdge[69, 99] -> 
             RGBColor[
              0.41359053884055663`, 0.5326530699039465, 0.9475746013045347], 
             UndirectedEdge[81, 84] -> 
             RGBColor[
              0.4886643442635845, 0.5953107817136317, 0.9530123699437607], 
             UndirectedEdge[11, 94] -> 
             RGBColor[
              0.20750449713838193`, 0.3354307614104094, 0.9351284461854125], 
             UndirectedEdge[10, 65] -> 
             RGBColor[
              0.23682752030936433`, 0.3662511179501625, 0.9367983489754745], 
             UndirectedEdge[79, 98] -> 
             RGBColor[
              0.26889413426113584`, 0.39995516235422757`, 0.9386244952017238],
              UndirectedEdge[33, 62] -> 
             RGBColor[
              0.3171356169120182, 0.44536236355291736`, 0.9415657494001773], 
             UndirectedEdge[31, 70] -> 
             RGBColor[
              0.3382626356768291, 0.464409652660651, 0.9428845517476936], 
             UndirectedEdge[31, 32] -> 
             RGBColor[
              0.3463701598777138, 0.472931174642505, 0.9433462632569267], 
             UndirectedEdge[15, 100] -> 
             RGBColor[
              0.28060017483633093`, 0.41159399522924645`, 0.9393154842638007],
              UndirectedEdge[7, 65] -> 
             RGBColor[
              0.26785267018749115`, 0.3984231895202199, 0.9385811980860177], 
             UndirectedEdge[59, 95] -> 
             RGBColor[
              0.430296968658313, 0.5404047867381535, 0.9497463591195126], 
             UndirectedEdge[2, 3] -> 
             RGBColor[
              0.4080096464453409, 0.5252224449857339, 0.947726795683348], 
             UndirectedEdge[48, 88] -> 
             RGBColor[
              0.2730751570306258, 0.404349682377116, 0.9388625982631773], 
             UndirectedEdge[14, 38] -> 
             RGBColor[
              0.5755893914541861, 0.6645818965278997, 0.9606923107205052], 
             UndirectedEdge[44, 45] -> 
             RGBColor[
              0.7810472132422319, 0.8288792862542917, 0.9788111449809456], 
             UndirectedEdge[24, 50] -> 
             RGBColor[
              0.9494254708663976, 0.830833526050487, 0.5187163836071205], 
             UndirectedEdge[38, 62] -> 
             RGBColor[
              0.39912933111578863`, 0.5201274986141865, 0.9466531459358565], 
             UndirectedEdge[4, 50] -> 
             RGBColor[
              0.9150800997643256, 0.6450012708274279, 0.48889967113718485`], 
             UndirectedEdge[48, 74] -> 
             RGBColor[
              0.3099201171979624, 0.4380720909673196, 0.941144084481714], 
             UndirectedEdge[40, 100] -> 
             RGBColor[
              0.24447547507013836`, 0.3742896033120748, 0.9372338886849655], 
             UndirectedEdge[19, 95] -> 
             RGBColor[
              0.4261782781667054, 0.536075781891414, 0.949511805789072], 
             UndirectedEdge[19, 79] -> 
             RGBColor[
              0.2547975399437836, 0.38513874795098857`, 0.937821715009393], 
             UndirectedEdge[51, 70] -> 
             RGBColor[
              0.2685220074352297, 0.3995640334659966, 0.9386033031295007], 
             UndirectedEdge[17, 22] -> 
             RGBColor[
              0.6749436759381056, 0.7408142314231896, 0.9479954802017996], 
             UndirectedEdge[59, 99] -> 
             RGBColor[
              0.33916350971304693`, 0.46506273394044173`, 0.9429466124453707],
              UndirectedEdge[20, 63] -> 
             RGBColor[
              0.22006041247387476`, 0.34862782451902463`, 0.9358434869889567],
              UndirectedEdge[56, 89] -> 
             RGBColor[
              0.2431918362429577, 0.37294041751730556`, 0.937160787352731], 
             UndirectedEdge[12, 74] -> 
             RGBColor[
              0.48414329622236674`, 0.5896324439603484, 0.9532112582976568], 
             UndirectedEdge[8, 17] -> 
             RGBColor[
              0.6756356059860984, 0.7413302717200512, 0.9468242231148067], 
             UndirectedEdge[53, 90] -> 
             RGBColor[
              0.3158328098736569, 0.44792075767621997`, 0.941347743143563], 
             UndirectedEdge[21, 72] -> 
             RGBColor[
              0.8673115146201031, 0.4479706752513929, 0.20933339049355504`], 
             UndirectedEdge[48, 73] -> 
             RGBColor[
              0.25430833916142304`, 0.38462456691160657`, 0.9377938557485452],
              UndirectedEdge[8, 49] -> 
             RGBColor[
              0.8679776052374037, 0.8972436267472088, 0.9628476465059921], 
             UndirectedEdge[17, 69] -> 
             RGBColor[
              0.40608263929049154`, 0.5261501046716837, 0.9470962045841795], 
             UndirectedEdge[21, 82] -> 
             RGBColor[
              0.8703286104016272, 0.4711613955279884, 0.21222256482126478`], 
             UndirectedEdge[36, 68] -> 
             RGBColor[
              0.4983193449177584, 0.2199668709575509, 0.5488706815526001], 
             UndirectedEdge[21, 30] -> 
             RGBColor[
              0.860772607404038, 0.39770976902130306`, 0.2030717255588116], 
             UndirectedEdge[56, 64] -> 
             RGBColor[
              0.2634347031054928, 0.3942169540617188, 0.9383135886739146], 
             UndirectedEdge[48, 64] -> 
             RGBColor[
              0.27099128981714793`, 0.40215940581093823`, 0.9387439251081751],
              UndirectedEdge[46, 59] -> 
             RGBColor[
              0.27301827158802383`, 0.40428989217019595`, 0.9388593587213756],
              UndirectedEdge[46, 79] -> 
             RGBColor[
              0.25699221406840955`, 0.38744548960634695`, 0.937946698454061], 
             UndirectedEdge[9, 86] -> 
             RGBColor[
              0.9724088099661622, 0.9182534312723682, 0.5190969464320642], 
             UndirectedEdge[64, 91] -> 
             RGBColor[
              0.26939944622333534`, 0.400486277265128, 0.938653271970429], 
             UndirectedEdge[1, 19] -> 
             RGBColor[
              0.2624065565834054, 0.39313630687875045`, 0.9382550372504881], 
             UndirectedEdge[5, 69] -> 
             RGBColor[
              0.3370682698872072, 0.4609733107913742, 0.942896391026308], 
             UndirectedEdge[36, 92] -> 
             RGBColor[
              0.18278950597928542`, 0.3094537386812527, 0.9337209640014548], 
             UndirectedEdge[17, 95] -> 
             RGBColor[
              0.48701029086628944`, 0.5926524000847553, 0.95324564623738], 
             UndirectedEdge[7, 13] -> 
             RGBColor[
              0.293422925234443, 0.42529914882237513`, 0.9400373862831393], 
             UndirectedEdge[11, 61] -> 
             RGBColor[
              0.20656379365058694`, 0.3344420224006909, 0.9350748745134286], 
             UndirectedEdge[66, 83] -> 
             RGBColor[
              0.27310948122008705`, 0.4031355950396065, 0.9389103276117834], 
             UndirectedEdge[27, 37] -> 
             RGBColor[
              0.5341526529828826, 0.6283946851552121, 0.9581776144798929], 
             UndirectedEdge[22, 34] -> 
             RGBColor[
              0.7732191105703109, 0.8223621759763964, 0.955244816729368], 
             UndirectedEdge[6, 90] -> 
             RGBColor[
              0.2824130283207301, 0.41416437715825094`, 0.9393943762190061], 
             UndirectedEdge[71, 77] -> 
             RGBColor[
              0.3842477285736503, 0.5072378024632783, 0.9457049033811559], 
             UndirectedEdge[9, 68] -> 
             RGBColor[
              0.884350574148669, 0.48954022473864206`, 0.22197856959681445`], 
             UndirectedEdge[23, 86] -> 
             RGBColor[
              0.990093096424966, 0.9901712550229842, 0.8138465606903063], 
             UndirectedEdge[54, 84] -> 
             RGBColor[
              0.3438756345570892, 0.4669242029109275, 0.9433281476320208], 
             UndirectedEdge[3, 16] -> 
             RGBColor[
              0.26785762869397084`, 0.3988657292848884, 0.9385654677430463], 
             UndirectedEdge[66, 98] -> 
             RGBColor[
              0.3085828474233191, 0.440420352060525, 0.9409304833389149], 
             UndirectedEdge[64, 93] -> 
             RGBColor[
              0.2726343777507507, 0.4038863954069468, 0.938837496535263], 
             UndirectedEdge[2, 29] -> 
             RGBColor[
              0.41847939161663067`, 0.5351656244278226, 0.9483618874203135], 
             UndirectedEdge[50, 81] -> 
             RGBColor[
              0.7659300229628049, 0.8142700526821505, 0.8749860890693137], 
             UndirectedEdge[8, 99] -> 
             RGBColor[
              0.6831435055361634, 0.747833236952314, 0.947302619835162], 
             UndirectedEdge[66, 69] -> 
             RGBColor[
              0.37303197272508415`, 0.4975232784675301, 0.9449902453361887], 
             UndirectedEdge[9, 30] -> 
             RGBColor[
              0.8848746439926696, 0.49356845520850057`, 0.2224804194712816], 
             UndirectedEdge[11, 36] -> 
             RGBColor[
              0.20676013856834535`, 0.33464839335824176`, 0.9350860560660287],
              UndirectedEdge[16, 62] -> 
             RGBColor[
              0.30123789915337096`, 0.4286528542150554, 0.9406603978923882], 
             UndirectedEdge[50, 76] -> 
             RGBColor[
              0.9928483984176775, 0.9905031143387806, 0.7094852523118963], 
             UndirectedEdge[36, 86] -> 
             RGBColor[
              0.5863775807352516, 0.6486800774912771, 0.8459890583878498], 
             UndirectedEdge[60, 71] -> 
             RGBColor[
              0.41038752678537255`, 0.5294238797348146, 0.9474961990184465], 
             UndirectedEdge[43, 54] -> 
             RGBColor[
              0.2507606889125138, 0.3808957615659856, 0.9375918223151481], 
             UndirectedEdge[29, 42] -> 
             RGBColor[
              0.48821367053746006`, 0.5915669704381774, 0.9539966276833514], 
             UndirectedEdge[76, 84] -> 
             RGBColor[
              0.7155827197184571, 0.7715438433702618, 0.7875115331863431], 
             UndirectedEdge[65, 90] -> 
             RGBColor[
              0.26516596283917315`, 0.39603661781002397`, 0.9384121813545784],
              UndirectedEdge[52, 78] -> 
             RGBColor[
              0.9664668529248481, 0.8933481863027279, 0.5077226888807255], 
             UndirectedEdge[25, 65] -> 
             RGBColor[
              0.21906851954430756`, 0.34758528216040546`, 0.9357870001539919],
              UndirectedEdge[45, 52] -> 
             RGBColor[
              0.8611685991001501, 0.8128504925215565, 0.6243159249705089], 
             UndirectedEdge[57, 74] -> 
             RGBColor[
              0.3081299966857172, 0.43619056080875396`, 0.9410421397667876], 
             UndirectedEdge[17, 66] -> 
             RGBColor[
              0.3553182658055509, 0.48218055585062736`, 0.943861543594892], 
             UndirectedEdge[59, 98] -> 
             RGBColor[
              0.28492019178075007`, 0.41679956491807657`, 0.9395371554690384],
              UndirectedEdge[22, 77] -> 
             RGBColor[
              0.6896552593406005, 0.7535566655407491, 0.9489328892872642], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.9001907126422091, 0.6304699376692046, 0.5656021608302857], 
             UndirectedEdge[30, 36] -> 
             RGBColor[
              0.49884341476175903`, 0.2239951014274094, 0.5493725314270672], 
             UndirectedEdge[60, 64] -> 
             RGBColor[
              0.37754119325177404`, 0.49877954503386207`, 0.9454836107743141],
              UndirectedEdge[28, 99] -> 
             RGBColor[
              0.3297358504115952, 0.455153666266492, 0.9424097211951252], 
             UndirectedEdge[59, 69] -> 
             RGBColor[
              0.34936931708251506`, 0.4739024913250818, 0.9435969174663121], 
             UndirectedEdge[66, 79] -> 
             RGBColor[
              0.2825788860779602, 0.4130885399401764, 0.93944959620971], 
             UndirectedEdge[7, 81] -> 
             RGBColor[
              0.42699263228672224`, 0.5418938445096457, 0.9490827029907487], 
             UndirectedEdge[26, 100] -> 
             RGBColor[
              0.2326661285681354, 0.3618772313826554, 0.9365613638720389], 
             UndirectedEdge[5, 97] -> 
             RGBColor[
              0.2506036098716818, 0.3807306615346847, 0.9375828768961504], 
             UndirectedEdge[20, 83] -> 
             RGBColor[
              0.22260788034518547`, 0.3513053747705641, 0.9359885615155867], 
             UndirectedEdge[21, 92] -> 
             RGBColor[
              0.5447186986215644, 0.48316840627514634`, 0.5874201581331991], 
             UndirectedEdge[77, 98] -> 
             RGBColor[
              0.35634509739122144`, 0.481789612382238, 0.9439738516723704], 
             UndirectedEdge[13, 84] -> 
             RGBColor[
              0.35509463721130535`, 0.4787160860263612, 0.9439670532361513], 
             UndirectedEdge[83, 97] -> 
             RGBColor[
              0.23740919468950228`, 0.36686249460397324`, 0.9368314744709133],
              UndirectedEdge[4, 24] -> 
             RGBColor[
              0.8731547109506095, 0.48514342442588576`, 0.2146138861787622], 
             UndirectedEdge[7, 85] -> 
             RGBColor[
              0.46422750147449665`, 0.5721227887280222, 0.9520139682890303], 
             UndirectedEdge[10, 40] -> 
             RGBColor[
              0.247557235138606, 0.37752872853890806`, 0.9374093903618093], 
             UndirectedEdge[26, 40] -> 
             RGBColor[
              0.23187934520351416`, 0.3610502721814919, 0.9365165577233654], 
             UndirectedEdge[56, 74] -> 
             RGBColor[
              0.3023635304863073, 0.4301296392181001, 0.9407137480474534], 
             UndirectedEdge[42, 62] -> 
             RGBColor[
              0.5111241958255703, 0.6114109159262558, 0.9554564660957278], 
             UndirectedEdge[4, 36] -> 
             RGBColor[
              0.5090645148420271, 0.3025589555589642, 0.5591602684070134], 
             UndirectedEdge[2, 33] -> 
             RGBColor[
              0.39248083985044224`, 0.5089006846712906, 0.946842453120579], 
             UndirectedEdge[36, 82] -> 
             RGBColor[
              0.5083994177593483, 0.2974467279340947, 0.5585233706895204], 
             UndirectedEdge[76, 81] -> 
             RGBColor[
              0.7674275617003685, 0.8140817945689018, 0.7914691728156671], 
             UndirectedEdge[27, 43] -> 
             RGBColor[
              0.29647101173303086`, 0.4258330666011419, 0.9403087252832609], 
             UndirectedEdge[61, 67] -> 
             RGBColor[
              0.1802334334437405, 0.3067671443820358, 0.933575399451926], 
             UndirectedEdge[10, 26] -> 
             RGBColor[
              0.235747888636603, 0.36511635660948866`, 0.9367368655488828], 
             UndirectedEdge[63, 83] -> 
             RGBColor[
              0.2214038953287198, 0.3500399101811996, 0.9359199963500353], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.28220392258022686`, 0.41350726570694146`, 0.9393984806790088],
              UndirectedEdge[20, 97] -> 
             RGBColor[
              0.23606571183465724`, 0.3654504089417983, 0.9367549651098346], 
             UndirectedEdge[28, 98] -> 
             RGBColor[
              0.27549253247929834`, 0.40689049724412685`, 0.9390002642187927],
              UndirectedEdge[4, 23] -> 
             RGBColor[
              0.9127800305317415, 0.6440501330906712, 0.5270177707094699], 
             UndirectedEdge[30, 86] -> 
             RGBColor[
              0.9059013056614938, 0.5668684370035848, 0.46183822670971686`], 
             UndirectedEdge[27, 54] -> 
             RGBColor[
              0.2966420896530224, 0.4260128803420197, 0.9403184679177174], 
             UndirectedEdge[1, 13] -> 
             RGBColor[
              0.2657389891679791, 0.3966389048135667, 0.9384448143562873], 
             UndirectedEdge[15, 35] -> 
             RGBColor[
              0.3092088271480132, 0.4416635027021466, 0.9409447046902427], 
             UndirectedEdge[56, 73] -> 
             RGBColor[
              0.24675175244976794`, 0.37668211516238714`, 0.9373635193142849],
              UndirectedEdge[16, 29] -> 
             RGBColor[
              0.27832737386526063`, 0.40880890872697706`, 0.9392005594800119],
              UndirectedEdge[53, 65] -> 
             RGBColor[
              0.2728961090815175, 0.40279156279961614`, 0.9389025615526072], 
             UndirectedEdge[6, 25] -> 
             RGBColor[
              0.2363155850258645, 0.36571304150863243`, 0.9367691950184196], 
             UndirectedEdge[68, 92] -> 
             RGBColor[
              0.501789161061527, 0.22361386772370176`, 0.5490682824488547], 
             UndirectedEdge[69, 97] -> 
             RGBColor[
              0.3373316861944994, 0.46125017803189694`, 0.9429113921953187], 
             UndirectedEdge[17, 77] -> 
             RGBColor[
              0.4030805157734533, 0.5235498161723404, 0.9469049119283475], 
             UndirectedEdge[46, 98] -> 
             RGBColor[
              0.2829961754137684, 0.41477730172669547`, 0.9394275855832659], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.34313416867820656`, 0.4716273033094493, 0.9430851836999117], 
             UndirectedEdge[17, 55] -> 
             RGBColor[
              0.3185371640353287, 0.44477145007049096`, 0.9417211396250476], 
             UndirectedEdge[2, 78] -> 
             RGBColor[
              0.7554647233160532, 0.8052075509695305, 0.8504886604600671], 
             UndirectedEdge[6, 35] -> 
             RGBColor[
              0.2796014780341359, 0.41120925954445625`, 0.9392342625895005], 
             UndirectedEdge[95, 99] -> 
             RGBColor[
              0.49451819041635453`, 0.5991553653170181, 0.9537240429577352], 
             UndirectedEdge[66, 99] -> 
             RGBColor[
              0.36282616535561596`, 0.48868352108289015`, 0.9443399403152473],
              UndirectedEdge[31, 39] -> 
             RGBColor[
              0.34736341039793694`, 0.47397514391497986`, 0.943402827404671], 
             UndirectedEdge[69, 71] -> 
             RGBColor[
              0.38724985209068863`, 0.5098380909626216, 0.9458961960369879], 
             UndirectedEdge[64, 89] -> 
             RGBColor[
              0.2647678240416204, 0.39561814869033823`, 0.9383895079390514], 
             UndirectedEdge[40, 53] -> 
             RGBColor[
              0.2836258239107592, 0.41406917338836174`, 0.9395136029389419], 
             UndirectedEdge[1, 27] -> 
             RGBColor[
              0.3002303093342801, 0.42978432673328937`, 0.9405228117202697], 
             UndirectedEdge[41, 48] -> 
             RGBColor[
              0.34329321321312134`, 0.4669781893550724, 0.9432705886491298], 
             UndirectedEdge[57, 70] -> 
             RGBColor[
              0.26485491336994227`, 0.39570968509618687`, 0.9383944675474621],
              UndirectedEdge[39, 44] -> 
             RGBColor[
              0.5365081779106845, 0.6268880178985887, 0.9593203806489492], 
             UndirectedEdge[6, 15] -> 
             RGBColor[
              0.286330742124025, 0.4176171847875644, 0.9396418315932203], 
             UndirectedEdge[6, 40] -> 
             RGBColor[
              0.2502060423578324, 0.3803127928703927, 0.9375602360143851], 
             UndirectedEdge[17, 59] -> 
             RGBColor[
              0.33165561016298184`, 0.45855976870817894`, 0.9424682157250155],
              UndirectedEdge[56, 91] -> 
             RGBColor[
              0.2478234584246726, 0.37780854609209535`, 0.9374245513841087], 
             UndirectedEdge[5, 59] -> 
             RGBColor[
              0.26264124075969747`, 0.39338297482786955`, 0.9382684021671439],
              UndirectedEdge[20, 58] -> 
             RGBColor[
              0.22266134542622565`, 0.3513615699606193, 0.9359916062728575], 
             UndirectedEdge[17, 19] -> 
             RGBColor[
              0.32753691967137427`, 0.45423076386143946`, 0.9422336623945751],
              UndirectedEdge[3, 38] -> 
             RGBColor[
              0.36574906065638857`, 0.4903403736840195, 0.9445582157865146], 
             UndirectedEdge[1, 17] -> 
             RGBColor[
              0.32323856928298944`, 0.4497129250720918, 0.941988877698796], 
             UndirectedEdge[2, 42] -> 
             RGBColor[
              0.5864694187639945, 0.6749492370446291, 0.9607331698161294], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.44521446884155214`, 0.5537197588039671, 0.950811098924118], 
             UndirectedEdge[48, 56] -> 
             RGBColor[
              0.2494153020184852, 0.3794816746379056, 0.9375152045218548], 
             UndirectedEdge[86, 94] -> 
             RGBColor[
              0.5871219393052882, 0.6494624455434448, 0.8460314485072336], 
             UndirectedEdge[23, 30] -> 
             RGBColor[
              0.9025589304514734, 0.5654862789591164, 0.5172300337295237], 
             UndirectedEdge[30, 82] -> 
             RGBColor[
              0.8279231426855904, 0.21563508744640228`, 0.17437253901138755`],
              UndirectedEdge[60, 74] -> 
             RGBColor[
              0.4164700206325886, 0.5346922301902434, 0.9478837701478531], 
             UndirectedEdge[10, 90] -> 
             RGBColor[
              0.2797642211015037, 0.41138031282676635`, 0.9392435305664304], 
             UndirectedEdge[49, 69] -> 
             RGBColor[
              0.5984246385417968, 0.6820634596988412, 0.9631196279753649], 
             UndirectedEdge[25, 100] -> 
             RGBColor[
              0.23058501773817044`, 0.3596898519503145, 0.9364428476890001], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.23295897687627548`, 0.36218503352216574`, 0.9365780411499574],
              UndirectedEdge[31, 51] -> 
             RGBColor[
              0.33046646407782415`, 0.4562153820042676, 0.9424405713085325], 
             UndirectedEdge[37, 50] -> 
             RGBColor[
              0.8586518765861698, 0.8882652786926387, 0.8831610133197494], 
             UndirectedEdge[6, 10] -> 
             RGBColor[
              0.25407458579092124`, 0.3843788772983895, 0.9377805438399023], 
             UndirectedEdge[69, 77] -> 
             RGBColor[
              0.4207942226929865, 0.5388925387892431, 0.9480336136696441], 
             UndirectedEdge[12, 96] -> 
             RGBColor[
              0.4452662078752948, 0.5537741398088749, 0.9508140453855485], 
             UndirectedEdge[12, 41] -> 
             RGBColor[
              0.5175163922375255, 0.6185385423481014, 0.9553377624650727], 
             UndirectedEdge[89, 93] -> 
             RGBColor[
              0.25239151088821565`, 0.3826098588625336, 0.9376846952140795], 
             UndirectedEdge[37, 81] -> 
             RGBColor[
              0.6332310398688609, 0.7118439589227601, 0.9651449338235201], 
             UndirectedEdge[14, 24] -> 
             RGBColor[
              0.8132324483478965, 0.7256778621369495, 0.6085269751651416], 
             UndirectedEdge[52, 67] -> 
             RGBColor[
              0.560139632974118, 0.5514847252323705, 0.6016081426491302], 
             UndirectedEdge[23, 27] -> 
             RGBColor[
              0.6645515668442425, 0.7298696411778459, 0.9061368692979717], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.2386756834212212, 0.36819365456103337`, 0.9369035991305825], 
             UndirectedEdge[23, 81] -> 
             RGBColor[
              0.7636299537302207, 0.8133189149453938, 0.9131041886415987], 
             UndirectedEdge[88, 96] -> 
             RGBColor[
              0.2871462971513761, 0.419139342805837, 0.9396639288766677], 
             UndirectedEdge[77, 95] -> 
             RGBColor[
              0.5017218742687843, 0.6053948342023149, 0.9541830553228445], 
             UndirectedEdge[74, 91] -> 
             RGBColor[
              0.3083282736041498, 0.43639896242150933`, 0.941053431343968], 
             UndirectedEdge[7, 100] -> 
             RGBColor[
              0.27936916838135406`, 0.4105277593101289, 0.939237045621026], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.3593964815136068, 0.4839037453450634, 0.9441876459561919], 
             UndirectedEdge[6, 100] -> 
             RGBColor[
              0.2509928257224536, 0.38113975207155615`, 0.9376050421630586], 
             UndirectedEdge[19, 55] -> 
             RGBColor[
              0.2577051513357447, 0.38819483187714965`, 0.9379872991767397], 
             UndirectedEdge[17, 28] -> 
             RGBColor[
              0.3222279508615301, 0.4486507010342292, 0.9419313244747699], 
             UndirectedEdge[64, 96] -> 
             RGBColor[
              0.28506242993789815`, 0.4169490662396592, 0.9395452557216655], 
             UndirectedEdge[67, 68] -> 
             RGBColor[
              0.49942943344374047`, 0.22113364438203578`, 0.5489338994519259],
              UndirectedEdge[22, 87] -> 
             RGBColor[
              0.875317687150646, 0.9030022552400158, 0.9648194594818615], 
             UndirectedEdge[42, 44] -> 
             RGBColor[
              0.7173501625148713, 0.7791186661105619, 0.9724624182472246], 
             UndirectedEdge[70, 96] -> 
             RGBColor[
              0.28071617400293775`, 0.4123808756834735, 0.9392977428758789], 
             UndirectedEdge[64, 88] -> 
             RGBColor[
              0.2870945581176334, 0.41908496180092925`, 0.9396609824152371], 
             UndirectedEdge[26, 65] -> 
             RGBColor[
              0.2211496303742725, 0.34977266159274634`, 0.9359055163370308], 
             UndirectedEdge[2, 14] -> 
             RGBColor[
              0.6178499772431384, 0.6994639678296142, 0.9638608906173386], 
             UndirectedEdge[11, 72] -> 
             RGBColor[
              0.5328227707106528, 0.3030976591006391, 0.5571968893226393], 
             UndirectedEdge[67, 86] -> 
             RGBColor[
              0.5874876692612337, 0.649846850915762, 0.8460522762871756], 
             UndirectedEdge[40, 90] -> 
             RGBColor[
              0.27589567766841483`, 0.4073142283987696, 0.939023222740913], 
             UndirectedEdge[27, 84] -> 
             RGBColor[
              0.38958595737760626`, 0.5118615079460839, 0.9460450506001336], 
             UndirectedEdge[13, 43] -> 
             RGBColor[
              0.26197969156672996`, 0.39268764468141926`, 0.9382307279192786],
              UndirectedEdge[52, 72] -> 
             RGBColor[
              0.8850921765904433, 0.518767217550283, 0.2236557580064148], 
             UndirectedEdge[10, 53] -> 
             RGBColor[
              0.28749436734384803`, 0.4181352578163585, 0.9397339107644591], 
             UndirectedEdge[15, 40] -> 
             RGBColor[
              0.2798133914717097, 0.41076703602808307`, 0.9392706781151272], 
             UndirectedEdge[21, 68] -> 
             RGBColor[
              0.8602485375600374, 0.3936815385514446, 0.2025698756843444], 
             UndirectedEdge[28, 83] -> 
             RGBColor[
              0.24001916627606623`, 0.36960574022320836`, 0.9369801084916611],
              UndirectedEdge[54, 100] -> 
             RGBColor[
              0.24809701263363243`, 0.37809606891005076`, 0.9374401298916217],
              UndirectedEdge[47, 96] -> 
             RGBColor[
              0.280167857490329, 0.4118045602634469, 0.9392665170616474], 
             UndirectedEdge[47, 51] -> 
             RGBColor[
              0.26797369092262097`, 0.39898771804597, 0.9385720773152693], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.3409913926021096, 0.4697713383713912, 0.9429486479031253], 
             UndirectedEdge[39, 45] -> 
             RGBColor[
              0.5390587638079978, 0.6288805549867408, 0.959574599214613], 
             UndirectedEdge[58, 97] -> 
             RGBColor[
              0.23746265977054243`, 0.3669186897940284, 0.936834519228184], 
             UndirectedEdge[31, 45] -> 
             RGBColor[
              0.5919024457294845, 0.6759664122706829, 0.9628935917366674], 
             UndirectedEdge[6, 26] -> 
             RGBColor[
              0.23839669585582945`, 0.3679004209409733, 0.9368877112014585], 
             UndirectedEdge[41, 91] -> 
             RGBColor[
              0.34170136961930875`, 0.46530506080926215`, 0.9431799355113838],
              UndirectedEdge[8, 22] -> 
             RGBColor[
              0.9622103495532457, 0.9713371210884598, 0.9488522004737234], 
             UndirectedEdge[46, 95] -> 
             RGBColor[
              0.42837295229133143`, 0.5383825235467723, 0.9496367892337401], 
             UndirectedEdge[66, 95] -> 
             RGBColor[
              0.4539596243008821, 0.5640255738806018, 0.9511396869893891], 
             UndirectedEdge[23, 37] -> 
             RGBColor[
              0.8563518073535856, 0.887314140955882, 0.9212791128920343], 
             UndirectedEdge[10, 100] -> 
             RGBColor[
              0.2483440185032272, 0.37835568774007156`, 0.9374541965104828], 
             UndirectedEdge[5, 79] -> 
             RGBColor[
              0.24661518324008325`, 0.37653857226402054`, 0.9373557418998293],
              UndirectedEdge[38, 42] -> 
             RGBColor[
              0.5442088329750422, 0.6400671657429147, 0.9575645899192962], 
             UndirectedEdge[40, 54] -> 
             RGBColor[
              0.24731022926901122`, 0.37726910970888733`, 0.9373953237429482],
              UndirectedEdge[32, 45] -> 
             RGBColor[
              0.5380655132877746, 0.6278365857142659, 0.9595180350668688], 
             UndirectedEdge[41, 60] -> 
             RGBColor[
              0.44984311664774745`, 0.5635983285779962, 0.9500102743152689], 
             UndirectedEdge[88, 91] -> 
             RGBColor[
              0.2714833134368132, 0.40267655383130574`, 0.9387719451254313], 
             UndirectedEdge[47, 57] -> 
             RGBColor[
              0.2643065968573336, 0.3951333696761603, 0.9383632417332306], 
             UndirectedEdge[27, 85] -> 
             RGBColor[
              0.4786656685472922, 0.5846284033631004, 0.952933955527739], 
             UndirectedEdge[69, 95] -> 
             RGBColor[
              0.5047239977858227, 0.6079951227016581, 0.9543743479786766], 
             UndirectedEdge[36, 72] -> 
             RGBColor[
              0.5053823219778242, 0.27425600765749925`, 0.5556341963618108], 
             UndirectedEdge[6, 65] -> 
             RGBColor[
              0.23947632752859074`, 0.3690351822816471, 0.9369491946280504], 
             UndirectedEdge[49, 77] -> 
             RGBColor[
              0.5954225150247585, 0.679463171199498, 0.9629283353195328], 
             UndirectedEdge[2, 62] -> 
             RGBColor[
              0.441389916904741, 0.555009569915901, 0.9498217258326898], 
             UndirectedEdge[22, 66] -> 
             RGBColor[
              0.6418930093726982, 0.712187405219036, 0.9458895209538087], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.37246108295649283`, 0.49696932160080975`, 0.9449560466299856],
              UndirectedEdge[73, 88] -> 
             RGBColor[
              0.2704116074619085, 0.40155012290159753`, 0.9387109130556073], 
             UndirectedEdge[8, 21] -> 
             RGBColor[
              0.9330401773606567, 0.8125446192441054, 0.5943013473777097], 
             UndirectedEdge[31, 75] -> 
             RGBColor[
              0.3329280335215753, 0.45880264756216715`, 0.9425807540467885], 
             UndirectedEdge[4, 30] -> 
             RGBColor[
              0.8285882397682693, 0.2207473150712718, 0.17500943672888053`], 
             UndirectedEdge[48, 91] -> 
             RGBColor[
              0.2553800451363277, 0.3857509978413148, 0.9378548878183692], 
             UndirectedEdge[19, 28] -> 
             RGBColor[
              0.26139593816194606`, 0.39207408284088785`, 0.938197484026462], 
             UndirectedEdge[28, 66] -> 
             RGBColor[
              0.28917728429612277`, 0.42002387483007575`, 0.9398253652267791],
              UndirectedEdge[3, 29] -> 
             RGBColor[
              0.30975389821880644`, 0.4418401783792823, 0.9409902535505699], 
             UndirectedEdge[22, 82] -> 
             RGBColor[
              0.8994987825942162, 0.6299538973723429, 0.5667734179172785], 
             UndirectedEdge[49, 82] -> 
             RGBColor[
              0.8052660382783743, 0.5558604030310919, 0.5807688639495472], 
             UndirectedEdge[23, 84] -> 
             RGBColor[
              0.7117851117483094, 0.7707809637467538, 0.909146549012275], 
             UndirectedEdge[65, 100] -> 
             RGBColor[
              0.2337457602408967, 0.3630119927233292, 0.9366228472986309], 
             UndirectedEdge[53, 85] -> 
             RGBColor[
              0.46927094036852307`, 0.5764911620074185, 0.9523353317556198], 
             UndirectedEdge[59, 97] -> 
             RGBColor[
              0.26290465706698973`, 0.3936598420683923, 0.9382834033361547], 
             UndirectedEdge[17, 98] -> 
             RGBColor[
              0.34163351398872654`, 0.46904717826467845`, 0.9430364425869058],
              UndirectedEdge[61, 68] -> 
             RGBColor[0.49812300000000004`, 0.2197605, 0.5488595000000001], 
             UndirectedEdge[28, 55] -> 
             RGBColor[
              0.2523961825259005, 0.38261476904993935`, 0.9376849612569346], 
             UndirectedEdge[9, 36] -> 
             RGBColor[
              0.5653509190664274, 0.575380095696193, 0.6066312511494145], 
             UndirectedEdge[20, 59] -> 
             RGBColor[
              0.24810334272267293`, 0.37810272223498315`, 0.9374404903808281],
              UndirectedEdge[48, 57] -> 
             RGBColor[
              0.25518176821789507`, 0.38554259622855935`, 0.9378435962411888],
              UndirectedEdge[1, 46] -> 
             RGBColor[
              0.26460123070803143`, 0.39544304853410883`, 0.9383800206951561],
              UndirectedEdge[5, 66] -> 
             RGBColor[
              0.2863038964022665, 0.41700376197031797`, 0.9396617300370205], 
             UndirectedEdge[64, 74] -> 
             RGBColor[
              0.32393951828497003`, 0.45280737039113284`, 0.9419424686337738],
              UndirectedEdge[55, 79] -> 
             RGBColor[
              0.24579778430773802`, 0.37567943416004, 0.9373091922398655], 
             UndirectedEdge[32, 51] -> 
             RGBColor[
              0.27662953163611426`, 0.40808555544785063`, 0.9390650146387339],
              UndirectedEdge[64, 73] -> 
             RGBColor[
              0.26832774024843065`, 0.39935984633541977`, 0.938592239900605], 
             UndirectedEdge[35, 38] -> 
             RGBColor[
              0.3673467656616922, 0.49201966294494187`, 0.9446492027229738], 
             UndirectedEdge[71, 87] -> 
             RGBColor[
              0.5699101563836958, 0.656683392162545, 0.9615914735757531], 
             UndirectedEdge[82, 87] -> 
             RGBColor[
              0.8132980502396094, 0.5621350718207605, 0.5815694198384238], 
             UndirectedEdge[5, 77] -> 
             RGBColor[
              0.33406614637016885`, 0.458373022292031, 0.9427050983704759], 
             UndirectedEdge[57, 64] -> 
             RGBColor[
              0.2692011693049027, 0.4002778756523726, 0.9386419803932486], 
             UndirectedEdge[63, 97] -> 
             RGBColor[
              0.23486172681819156`, 0.36418494435243376`, 0.9366863999442832],
              UndirectedEdge[41, 93] -> 
             RGBColor[
              0.34493630114672413`, 0.468705178951081, 0.9433641600762177], 
             UndirectedEdge[9, 61] -> 
             RGBColor[
              0.565154574148669, 0.575173724738642, 0.6066200695968145], 
             UndirectedEdge[17, 46] -> 
             RGBColor[
              0.32973159379600026`, 0.45653750551679784`, 0.942358645839243], 
             UndirectedEdge[25, 54] -> 
             RGBColor[
              0.2334197719370433, 0.36266935834712705`, 0.9366042827469828], 
             UndirectedEdge[59, 77] -> 
             RGBColor[
              0.3463671935654768, 0.47130220282573854`, 0.9434056248104801], 
             UndirectedEdge[66, 77] -> 
             RGBColor[
              0.3700298492080458, 0.49492298996818684`, 0.9447989526803566], 
             UndirectedEdge[7, 27] -> 
             RGBColor[
              0.327914245400744, 0.45844457074209777`, 0.9421153836471216], 
             UndirectedEdge[61, 92] -> 
             RGBColor[
              0.182593161061527, 0.30924736772370176`, 0.9337097824488547], 
             UndirectedEdge[77, 87] -> 
             RGBColor[
              0.6034545269859937, 0.6857378399891666, 0.9637288912084094], 
             UndirectedEdge[28, 79] -> 
             RGBColor[
              0.24948857113393946`, 0.3795586851237783, 0.937519377089588], 
             UndirectedEdge[5, 28] -> 
             RGBColor[
              0.25321358145824574`, 0.3834739071539198, 0.9377315109168982], 
             UndirectedEdge[56, 88] -> 
             RGBColor[
              0.26551857031897064`, 0.39640723062789657`, 0.9384322618289168],
              UndirectedEdge[25, 26] -> 
             RGBColor[
              0.21798888787154624`, 0.3464505208197316, 0.9357255167274], 
             UndirectedEdge[9, 67] -> 
             RGBColor[
              0.5664610075924095, 0.5765468691206779, 0.6066944690487404], 
             UndirectedEdge[32, 44] -> 
             RGBColor[
              0.5355149273904612, 0.6258440486261139, 0.959263816501205], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.5412488824777958, 0.4795214095089955, 0.5872225572369445], 
             UndirectedEdge[79, 83] -> 
             RGBColor[
              0.23342076805790374`, 0.3626704053333091, 0.9366043394745922], 
             UndirectedEdge[60, 93] -> 
             RGBColor[
              0.3651648800983693, 0.48577125520605746`, 0.9447787980493423], 
             UndirectedEdge[5, 63] -> 
             RGBColor[
              0.2345983105108993, 0.3639080771119111, 0.9366713987752724], 
             UndirectedEdge[19, 66] -> 
             RGBColor[
              0.2944862531059669, 0.425603937657286, 0.9401277031465842], 
             UndirectedEdge[8, 86] -> 
             RGBColor[
              0.9781688756181125, 0.981703287226387, 0.853067848528615], 
             UndirectedEdge[4, 37] -> 
             RGBColor[
              0.7823811166703816, 0.5425751770680375, 0.5790585158913912], 
             UndirectedEdge[9, 92] -> 
             RGBColor[
              0.5688207352101959, 0.5790270924623439, 0.606828852045669], 
             UndirectedEdge[3, 42] -> 
             RGBColor[
              0.4777439253661703, 0.5816237909960889, 0.9533615359463858], 
             UndirectedEdge[7, 90] -> 
             RGBColor[
              0.31078937097963055`, 0.4435523843968237, 0.9410263796769736], 
             UndirectedEdge[35, 62] -> 
             RGBColor[
              0.3342621285122205, 0.46336341312828305`, 0.9425410788994055], 
             UndirectedEdge[20, 79] -> 
             RGBColor[
              0.2320772852030587, 0.3612583196711341, 0.9365278301135136], 
             UndirectedEdge[31, 78] -> 
             RGBColor[
              0.6972006995541824, 0.7564641060518543, 0.846300355646884], 
             UndirectedEdge[13, 81] -> 
             RGBColor[
              0.40693947919321677`, 0.5212540372250012, 0.947924692865475], 
             UndirectedEdge[18, 80] -> 
             RGBColor[
              0.2419836729170215, 0.3716705612597674, 0.9370919842386365], 
             UndirectedEdge[90, 100] -> 
             RGBColor[
              0.27668246103303606`, 0.408141187599933, 0.9390680288895865], 
             UndirectedEdge[67, 92] -> 
             RGBColor[
              0.1838995945052675, 0.31062051210573755`, 0.9337841819007806], 
             UndirectedEdge[55, 66] -> 
             RGBColor[
              0.28548649746992133`, 0.41614462386633744`, 0.9396151803770567],
              UndirectedEdge[89, 91] -> 
             RGBColor[
              0.24915657936080024`, 0.3792097407207148, 0.9375004706492456], 
             UndirectedEdge[46, 55] -> 
             RGBColor[
              0.25989982546037066`, 0.390501573532508, 0.9381122826214077], 
             UndirectedEdge[41, 64] -> 
             RGBColor[
              0.3573126143001289, 0.48171346877888566`, 0.9440689728011896], 
             UndirectedEdge[28, 46] -> 
             RGBColor[
              0.2635906122865721, 0.39438082449624623`, 0.93832246747113], 
             UndirectedEdge[35, 53] -> 
             RGBColor[
              0.3130212595870627, 0.4449656400624253, 0.9411876295140573], 
             UndirectedEdge[35, 90] -> 
             RGBColor[
              0.3052911133447183, 0.4382106950728331, 0.9406972493160285], 
             UndirectedEdge[5, 58] -> 
             RGBColor[
              0.23719924346325016`, 0.36664182255350575`, 0.9368195180591732],
              UndirectedEdge[76, 85] -> 
             RGBColor[
              0.8046624308881429, 0.8443107387872784, 0.7944004381139487], 
             UndirectedEdge[34, 77] -> 
             RGBColor[
              0.5013559504056586, 0.6050977607255472, 0.9541542484559159], 
             UndirectedEdge[49, 71] -> 
             RGBColor[
              0.5618781444224608, 0.6504087233728764, 0.9607909176868766]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 25 -> 
             RGBColor[
              0.21590777704158132`, 0.3442631413873908, 0.9356070005443611], 
             55 -> RGBColor[
              0.2487053956996991, 0.3787355180862011, 0.9374747764072122], 90 -> 
             RGBColor[
              0.30810266363131256`, 0.4411658126866278, 0.9408573629455341], 
             27 -> RGBColor[
              0.3423524124735395, 0.470950185377176, 0.9430353708858302], 15 -> 
             RGBColor[
              0.3159380912379023, 0.44807142794525473`, 0.9413522736939626], 
             98 -> RGBColor[
              0.2948980956064947, 0.4272869744745761, 0.9401053823309286], 38 -> 
             RGBColor[
              0.43221396826526043`, 0.5487837484308453, 0.9487612697594249], 
             99 -> RGBColor[
              0.40338473147108844`, 0.5238133125193064, 0.9469242962835934], 
             71 -> RGBColor[
              0.3507033579713525, 0.4781833546366567, 0.9435674857484997], 41 -> 
             RGBColor[
              0.4296145376961023, 0.5465322523230198, 0.9485956363421444], 75 -> 
             RGBColor[
              0.26564897472372695`, 0.3965442939254123, 0.9384396881668516], 
             64 -> RGBColor[
              0.2850106909041555, 0.4168946852347515, 0.9395423092602349], 63 -> 
             RGBColor[
              0.21885642745740908`, 0.34736235992966014`, 0.9357749218234052],
              85 -> RGBColor[
              0.6149789246210449, 0.6983066213490248, 0.9628325401696478], 3 -> 
             RGBColor[
              0.29928415304751665`, 0.4318969989371937, 0.9403551618136042], 
             86 -> RGBColor[
              0.9934354716349865, 0.9915534130674525, 0.7584547536704994], 94 -> 
             RGBColor[
              0.18080840697558995`, 0.30737147801943704`, 0.9336081433439677],
              61 -> RGBColor[0.178927, 0.305394, 0.933501], 84 -> 
             RGBColor[
              0.4368195022816731, 0.5527728305149917, 0.9490547303144369], 76 -> 
             RGBColor[
              0.9943459371552411, 0.990314856225532, 0.6259683360582495], 21 -> 
             RGBColor[
              0.9031780751200748, 0.6532360771028892, 0.2409217513686888], 87 -> 
             RGBColor[
              0.789116954796039, 0.8351834296884333, 0.9796154614030067], 95 -> 
             RGBColor[
              0.5856516493616206, 0.6744974181147299, 0.9605237896318769], 72 -> 
             RGBColor[
              0.8314449541201315, 0.24270527339989661`, 0.17774502961842129`],
              42 -> RGBColor[
              0.6562036976848239, 0.731350583054984, 0.9663679100791674], 66 -> 
             RGBColor[
              0.32226759924014353`, 0.45355372964647384`, 0.9417555843469012],
              1 -> RGBColor[
              0.2581082061950206, 0.38861846808940276`, 0.9380102525547092], 
             24 -> RGBColor[
              0.9075000820526815, 0.6709756796489449, 0.2444305986486977], 54 -> 
             RGBColor[
              0.2509317668325053, 0.3810755753068633, 0.9376015649496046], 4 -> 
             RGBColor[
              0.8388093398485373, 0.29931116920282663`, 0.1847971737088267], 
             7 -> RGBColor[
              0.3134760783279485, 0.4459389561070196, 0.9411953964084129], 
             100 -> RGBColor[
              0.24526225843475957`, 0.3751165625132382, 0.937278694833639], 
             12 -> RGBColor[
              0.6054182467789488, 0.6905448323731828, 0.9620798885880011], 65 -> 
             RGBColor[
              0.2222292620470338, 0.35090742293342014`, 0.9359669997636226], 
             8 -> RGBColor[
              0.9629022796012385, 0.9718531613853215, 0.9476809433867306], 57 -> 
             RGBColor[
              0.25339164770564987`, 0.38366106606999373`, 0.9377416515262625],
              74 -> 
             RGBColor[
              0.3628683456657846, 0.48872005554751413`, 0.9443426280073127], 
             37 -> RGBColor[
              0.7259528934922258, 0.7858391849332483, 0.9733198580739556], 43 -> 
             RGBColor[
              0.25058961099252225`, 0.3807159478251078, 0.9375820796806917], 
             39 -> RGBColor[
              0.2945197284764503, 0.42688928663103776`, 0.9400838348826166], 
             58 -> RGBColor[
              0.22405829336211083`, 0.3528298508128494, 0.9360711603912069], 
             11 -> RGBColor[
              0.23420058730117388`, 0.3634900448013817, 0.9366487490268572], 
             51 -> RGBColor[
              0.26072583583622466`, 0.3913697628096132, 0.9381593226903397], 
             48 -> RGBColor[
              0.2569718887301403, 0.38742412638712503`, 0.9379455409561153], 
             20 -> RGBColor[
              0.22126439749034046`, 0.3498932891083892, 0.9359120521545081], 
             33 -> RGBColor[
              0.26822653985771944`, 0.399253478308307, 0.9385864766880666], 
             45 -> RGBColor[
              0.7835977991395453, 0.8308718233424438, 0.9790653635466094], 23 -> 
             RGBColor[
              0.9867507212149456, 0.9887890969785158, 0.869238367710113], 22 -> 
             RGBColor[
              0.9615184195052529, 0.9708210807915982, 0.9500234575607163], 2 -> 
             RGBColor[
              0.5167351398431651, 0.6185478910342742, 0.9550984295530915], 60 -> 
             RGBColor[
              0.4700716955993926, 0.5806644048329727, 0.9514249122883933], 16 -> 
             RGBColor[
              0.23643110434042502`, 0.36583445963258315`, 0.9367757736724883],
              79 -> RGBColor[
              0.24289017291577697`, 0.372623350233879, 0.937143608072519], 89 -> 
             RGBColor[
              0.24452495717908534`, 0.374341612145925, 0.9372367066178678], 
             36 -> RGBColor[
              0.17931968983551683`, 0.3058067419151018, 0.9335233631052001], 
             52 -> RGBColor[
              0.938739399060755, 0.7948291617006693, 0.26956648639440833`], 
             32 -> RGBColor[
              0.2925332274360039, 0.424801348086088, 0.9399707065871281], 31 -> 
             RGBColor[
              0.40020709231942364`, 0.521061001198922, 0.9467218199267253], 
             68 -> RGBColor[0.817319, 0.134127, 0.164218], 73 -> 
             RGBColor[
              0.2516447895927058, 0.3818250074360881, 0.9376421705409753], 82 -> 
             RGBColor[
              0.8374791456831797, 0.2890867139530876, 0.18352337827384074`], 
             35 -> 
             RGBColor[
              0.30247956305812407`, 0.4352555774590384, 0.9405371356865229], 
             88 -> RGBColor[
              0.28917842533111127`, 0.421275238367107, 0.9397796555702393], 
             50 -> RGBColor[
              0.9913508596801138, 0.9906913724520291, 0.7930021685655431], 19 -> 
             RGBColor[
              0.2667049069717902, 0.39765414566809815`, 0.9384998219462671], 
             17 -> RGBColor[
              0.3883689323709583, 0.5108073820547808, 0.9459675028428829], 96 -> 
             RGBColor[
              0.2851141689716408, 0.417003447244567, 0.939548202183096], 14 -> 
             RGBColor[
              0.7189648146431117, 0.780380044624954, 0.9726233516815856], 5 -> 
             RGBColor[
              0.2503401935643895, 0.38045379429416204`, 0.9375678757271396], 
             34 -> RGBColor[
              0.5849198016353689, 0.6739032711611944, 0.9604661758980197], 97 -> 
             RGBColor[
              0.25086702617897405`, 0.38100752877520744`, 0.9375978780651611],
              93 -> RGBColor[
              0.26025806459734596`, 0.3908781055791422, 0.9381326838102911], 
             81 -> RGBColor[
              0.5405091862454959, 0.6378487329122717, 0.9569700095730845], 69 -> 
             RGBColor[
              0.42379634621002477`, 0.5414928272885864, 0.9482249063254762], 
             9 -> RGBColor[
              0.9513821482973379, 0.8449534494772841, 0.27973913919362886`], 
             13 -> RGBColor[
              0.2733697721409376, 0.40465934153773064`, 0.9388793761578655], 
             30 -> RGBColor[
              0.8183671396880012, 0.14218346093971695`, 0.1652216997489344], 
             59 -> RGBColor[
              0.2749422879550054, 0.4063121553615771, 0.9389689286071481], 28 -> 
             RGBColor[
              0.25608696935210196`, 0.3864940200136776, 0.9378951461066569], 
             80 -> RGBColor[
              0.26918119100492044`, 0.4002568771923939, 0.9386408426586199], 
             47 -> RGBColor[
              0.27522154600901727`, 0.40660567328232683`, 0.9389848319401988],
              62 -> RGBColor[
              0.3660446939663169, 0.4914712487975277, 0.9445450221122881], 77 -> 
             RGBColor[
              0.4177920991759482, 0.5362922502898999, 0.947842321013812], 78 -> 
             RGBColor[
              0.9941943067889412, 0.9918672109047867, 0.7458788913670427], 40 -> 
             RGBColor[
              0.24368869170551716`, 0.37346264411091135`, 0.937189082536292], 
             67 -> 
             RGBColor[
              0.181539866887481, 0.30814028876407157`, 0.9336497989038519], 
             56 -> RGBColor[
              0.24185871530683006`, 0.3715392228886861, 0.9370848680875943], 
             10 -> RGBColor[
              0.25142577857169485`, 0.38159481296690484`, 0.9376296981873266],
              53 -> RGBColor[
              0.3235629561160013, 0.45467570266581214`, 0.9418381233415918], 
             26 -> RGBColor[
              0.2200699987015112, 0.3486379002520725, 0.9358440329104389], 18 -> 
             RGBColor[
              0.21478615482912253`, 0.34308424532714094`, 0.935543125818653], 
             29 -> RGBColor[
              0.32022364339009624`, 0.4517833578213709, 0.9416253452875354], 
             92 -> RGBColor[
              0.18625932212305402`, 0.3131007354474035, 0.9339185648977094], 
             46 -> RGBColor[
              0.2710942552210422, 0.40226762897881485`, 0.9387497888356031], 
             49 -> RGBColor[
              0.773052930873569, 0.822634092109096, 0.9780143496252536], 83 -> 
             RGBColor[
              0.2239513632000305, 0.3527174604327391, 0.9360650708766655], 70 -> 
             RGBColor[
              0.27631817903423467`, 0.40775830412238, 0.9390472835686617], 44 -> 
             RGBColor[
              0.7784966273449186, 0.8268867491661398, 0.9785569264152818], 91 -> 
             RGBColor[
              0.25378820154251513`, 0.3840778692955045, 0.9377642346806232], 
             6 -> RGBColor[
              0.2567233930101477, 0.3871629416298741, 
               0.9379313894924781]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9lHs01Akbx4dhXCZmRjNjDGZ+vxEpY003Oez6fWm7uFSIpJWyrGvrtqF9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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 13}], {
             RGBColor[
             0.2657389891679791, 0.3966389048135667, 0.9384448143562873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 17}], {
             RGBColor[
             0.32323856928298944`, 0.4497129250720918, 0.941988877698796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 19}], {
             RGBColor[
             0.2624065565834054, 0.39313630687875045`, 0.9382550372504881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 27}], {
             RGBColor[
             0.3002303093342801, 0.42978432673328937`, 0.9405228117202697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 43}], {
             RGBColor[
             0.25434890859377146`, 0.3846672079572553, 0.9377961661177004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 46}], {
             RGBColor[
             0.26460123070803143`, 0.39544304853410883`, 0.9383800206951561]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 55}], {
             RGBColor[
             0.25340680094735984`, 0.3836769930878019, 0.9377425144809607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 3}], {
             RGBColor[
             0.4080096464453409, 0.5252224449857339, 0.947726795683348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 14}], {
             RGBColor[
             0.6178499772431384, 0.6994639678296142, 0.9638608906173386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 29}], {
             RGBColor[
             0.41847939161663067`, 0.5351656244278226, 0.9483618874203135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 33}], {
             RGBColor[
             0.39248083985044224`, 0.5089006846712906, 0.946842453120579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 38}], {
             RGBColor[
             0.4744745540542128, 0.5836658197325597, 0.9519298496562583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 42}], {
             RGBColor[
             0.5864694187639945, 0.6749492370446291, 0.9607331698161294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 44}], {
             RGBColor[
             0.6476158835940419, 0.7227173201002071, 0.9668276779841867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 62}], {
             RGBColor[
             0.441389916904741, 0.555009569915901, 0.9498217258326898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 78}], {
             RGBColor[
             0.7554647233160532, 0.8052075509695305, 0.8504886604600671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 16}], {
             RGBColor[
             0.26785762869397084`, 0.3988657292848884, 0.9385654677430463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 29}], {
             RGBColor[
             0.30975389821880644`, 0.4418401783792823, 0.9409902535505699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 33}], {
             RGBColor[
             0.283755346452618, 0.41557523862275036`, 0.9394708192508354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 38}], {
             RGBColor[
             0.36574906065638857`, 0.4903403736840195, 0.9445582157865146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 42}], {
             RGBColor[
             0.4777439253661703, 0.5816237909960889, 0.9533615359463858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 62}], {
             RGBColor[
             0.3326644235069168, 0.4616841238673607, 0.9424500919629462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 9}], {
             RGBColor[
             0.8950957440729377, 0.5721323093400554, 0.23226815645122778`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 23}], {
             RGBColor[
             0.9127800305317415, 0.6440501330906712, 0.5270177707094699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 24}], {
             RGBColor[
             0.8731547109506095, 0.48514342442588576`, 0.2146138861787622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 30}], {
             RGBColor[
             0.8285882397682693, 0.2207473150712718, 0.17500943672888053`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 36}], {
             RGBColor[
             0.5090645148420271, 0.3025589555589642, 0.5591602684070134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 37}], {
             RGBColor[
             0.7823811166703816, 0.5425751770680375, 0.5790585158913912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 50}], {
             RGBColor[
             0.9150800997643256, 0.6450012708274279, 0.48889967113718485`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 76}], {
             RGBColor[
             0.9165776385018892, 0.6448130127141793, 0.40538275488353814`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 86}], {
             RGBColor[
             0.9161224057417618, 0.6454322911351396, 0.4716259636896631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 94}], {
             RGBColor[
             0.5098088734120636, 0.30334132361113186`, 0.5592026585263972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 20}], {
             RGBColor[
             0.23580229552736498`, 0.3651735417012756, 0.9367399639408238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 28}], {
             RGBColor[
             0.25321358145824574`, 0.3834739071539198, 0.9377315109168982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 58}], {
             RGBColor[
             0.23719924346325016`, 0.36664182255350575`, 0.9368195180591732]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.26264124075969747`, 0.39338297482786955`, 0.9382684021671439]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 63}], {
             RGBColor[
             0.2345983105108993, 0.3639080771119111, 0.9366713987752724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 66}], {
             RGBColor[
             0.2863038964022665, 0.41700376197031797`, 0.9396617300370205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 69}], {
             RGBColor[
             0.3370682698872072, 0.4609733107913742, 0.942896391026308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[
             0.33406614637016885`, 0.458373022292031, 0.9427050983704759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 79}], {
             RGBColor[
             0.24661518324008325`, 0.37653857226402054`, 0.9373557418998293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[
             0.23714577838221002`, 0.3665856273634506, 0.9368164733019025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 97}], {
             RGBColor[
             0.2506036098716818, 0.3807306615346847, 0.9375828768961504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 7}], {
             RGBColor[
             0.2850997356690481, 0.41655094886844685`, 0.9395633929504454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 10}], {
             RGBColor[
             0.25407458579092124`, 0.3843788772983895, 0.9377805438399023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 15}], {
             RGBColor[
             0.286330742124025, 0.4176171847875644, 0.9396418315932203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 25}], {
             RGBColor[
             0.2363155850258645, 0.36571304150863243`, 0.9367691950184196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 26}], {
             RGBColor[
             0.23839669585582945`, 0.3679004209409733, 0.9368877112014585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 35}], {
             RGBColor[
             0.2796014780341359, 0.41120925954445625`, 0.9392342625895005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 40}], {
             RGBColor[
             0.2502060423578324, 0.3803127928703927, 0.9375602360143851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.2901431745630745, 0.4209193221478431, 0.939884756417035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 65}], {
             RGBColor[
             0.23947632752859074`, 0.3690351822816471, 0.9369491946280504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 90}], {
             RGBColor[
             0.2824130283207301, 0.41416437715825094`, 0.9393943762190061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 100}], {
             RGBColor[
             0.2509928257224536, 0.38113975207155615`, 0.9376050421630586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 13}], {
             RGBColor[
             0.293422925234443, 0.42529914882237513`, 0.9400373862831393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 25}], {
             RGBColor[
             0.2646919276847649, 0.3951010487472052, 0.9384011984763869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 27}], {
             RGBColor[
             0.327914245400744, 0.45844457074209777`, 0.9421153836471216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 37}], {
             RGBColor[
             0.5197144859100872, 0.615889070520134, 0.9572576272411842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 40}], {
             RGBColor[
             0.2785823850167328, 0.4097008001089655, 0.9391922394723524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 53}], {
             RGBColor[
             0.3185195172219749, 0.4503073293864159, 0.9415167598750023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.28220392258022686`, 0.41350726570694146`, 0.9393984806790088]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 65}], {
             RGBColor[
             0.26785267018749115`, 0.3984231895202199, 0.9385811980860177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 81}], {
             RGBColor[
             0.42699263228672224`, 0.5418938445096457, 0.9490827029907487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.3751477903048108, 0.49935589331100566`, 0.9451250633614249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 85}], {
             RGBColor[
             0.46422750147449665`, 0.5721227887280222, 0.9520139682890303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 90}], {
             RGBColor[
             0.31078937097963055`, 0.4435523843968237, 0.9410263796769736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 100}], {
             RGBColor[
             0.27936916838135406`, 0.4105277593101289, 0.939237045621026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 17}], {
             RGBColor[
             0.6756356059860984, 0.7413302717200512, 0.9468242231148067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.9330401773606567, 0.8125446192441054, 0.5943013473777097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 22}], {
             RGBColor[
             0.9622103495532457, 0.9713371210884598, 0.9488522004737234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 30}], {
             RGBColor[
             0.8906347096446199, 0.5570183111625192, 0.5564513215678325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 49}], {
             RGBColor[
             0.8679776052374037, 0.8972436267472088, 0.9628476465059921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 69}], {
             RGBColor[
             0.6933493129056316, 0.7566729943369539, 0.9479529248561034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 77}], {
             RGBColor[
             0.6903471893885933, 0.7540727058376107, 0.9477616322002713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.9001907126422091, 0.6304699376692046, 0.5656021608302857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 86}], {
             RGBColor[
             0.9781688756181125, 0.981703287226387, 0.853067848528615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 87}], {
             RGBColor[
             0.8760096171986388, 0.9035182955368775, 0.9636482023948687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 95}], {
             RGBColor[
             0.7742769644814296, 0.8231752897500257, 0.9541023665093038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 99}], {
             RGBColor[
             0.6831435055361634, 0.747833236952314, 0.947302619835162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.5927913677992559, 0.604221747139333, 0.6081939441102431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 21}], {
             RGBColor[
             0.9272801117087064, 0.7490947632900866, 0.26033044528115884`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 30}], {
             RGBColor[
             0.8848746439926696, 0.49356845520850057`, 0.2224804194712816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 36}], {
             RGBColor[
             0.5653509190664274, 0.575380095696193, 0.6066312511494145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 61}], {
             RGBColor[
             0.565154574148669, 0.575173724738642, 0.6066200695968145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 67}], {
             RGBColor[
             0.5664610075924095, 0.5765468691206779, 0.6066944690487404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 68}], {
             RGBColor[
             0.884350574148669, 0.48954022473864206`, 0.22197856959681445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 72}], {
             RGBColor[
             0.8914135512087347, 0.5438293614385904, 0.22874208440602506`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 82}], {
             RGBColor[
             0.8944306469902588, 0.5670200817151858, 0.2316312587337348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 86}], {
             RGBColor[
             0.9724088099661622, 0.9182534312723682, 0.5190969464320642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 92}], {
             RGBColor[
             0.5688207352101959, 0.5790270924623439, 0.606828852045669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 94}], {
             RGBColor[
             0.566095277636464, 0.5761624637483606, 0.6066736412687983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.28368193490479854`, 0.4148331204560798, 0.9394909859406446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 26}], {
             RGBColor[
             0.235747888636603, 0.36511635660948866`, 0.9367368655488828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 35}], {
             RGBColor[
             0.2769526708149095, 0.4084251952129716, 0.9390834169369247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 40}], {
             RGBColor[
             0.247557235138606, 0.37752872853890806`, 0.9374093903618093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 53}], {
             RGBColor[
             0.28749436734384803`, 0.4181352578163585, 0.9397339107644591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 65}], {
             RGBColor[
             0.23682752030936433`, 0.3662511179501625, 0.9367983489754745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 90}], {
             RGBColor[
             0.2797642211015037, 0.41138031282676635`, 0.9392435305664304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 100}], {
             RGBColor[
             0.2483440185032272, 0.37835568774007156`, 0.9374541965104828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 36}], {
             RGBColor[
             0.20676013856834535`, 0.33464839335824176`, 0.9350860560660287]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 52}], {
             RGBColor[
             0.5864699931809645, 0.5791596032510256, 0.6031076177106328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 61}], {
             RGBColor[
             0.20656379365058694`, 0.3344420224006909, 0.9350748745134286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 67}], {
             RGBColor[
             0.20787022709432745`, 0.3358151667827266, 0.9351492739653546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 68}], {
             RGBColor[
             0.5257597936505869, 0.24880852240069085`, 0.5504333745134287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 72}], {
             RGBColor[
             0.5328227707106528, 0.3030976591006391, 0.5571968893226393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 92}], {
             RGBColor[
             0.21022995471211395`, 0.3382953901243926, 0.9352836569622833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 94}], {
             RGBColor[
             0.20750449713838193`, 0.3354307614104094, 0.9351284461854125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 41}], {
             RGBColor[
             0.5175163922375255, 0.6185385423481014, 0.9553377624650727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 52}], {
             RGBColor[
             0.7720788229198519, 0.7426869970369261, 0.6158231874912047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 60}], {
             RGBColor[
             0.5377449711891708, 0.6356046186030777, 0.9567524004381972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.44521446884155214`, 0.5537197588039671, 0.950811098924118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 74}], {
             RGBColor[
             0.48414329622236674`, 0.5896324439603484, 0.9532112582976568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 88}], {
             RGBColor[
             0.44729833605503005`, 0.5559100353701449, 0.9509297720791202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 96}], {
             RGBColor[
             0.4452662078752948, 0.5537741398088749, 0.9508140453855485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 27}], {
             RGBColor[
             0.30786109230723857`, 0.43780476345745334`, 0.9409573735218479]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 43}], {
             RGBColor[
             0.26197969156672996`, 0.39268764468141926`, 0.9382307279192786]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 54}], {
             RGBColor[
             0.26215076948672145`, 0.392867458422297, 0.938240470553735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 81}], {
             RGBColor[
             0.40693947919321677`, 0.5212540372250012, 0.947924692865475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 84}], {
             RGBColor[
             0.35509463721130535`, 0.4787160860263612, 0.9439670532361513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 85}], {
             RGBColor[
             0.44417434838099124`, 0.5514829814433777, 0.9508559581637567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 15}], {
             RGBColor[
             0.517451452940507, 0.6142257362851044, 0.9569878126877741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 24}], {
             RGBColor[
             0.8132324483478965, 0.7256778621369495, 0.6085269751651416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 35}], {
             RGBColor[
             0.5107221888506179, 0.6078178110419963, 0.9565802436840543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 38}], {
             RGBColor[
             0.5755893914541861, 0.6645818965278997, 0.9606923107205052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 42}], {
             RGBColor[
             0.6875842561639678, 0.755865313839969, 0.9694956308803766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 53}], {
             RGBColor[
             0.5212638853795565, 0.6175278736453831, 0.9572307375115887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 62}], {
             RGBColor[
             0.5425047543047143, 0.6359256467112409, 0.9585841868969369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 76}], {
             RGBColor[
             0.8566553758991764, 0.885347450425243, 0.7992958438699176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 35}], {
             RGBColor[
             0.3092088271480132, 0.4416635027021466, 0.9409447046902427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 38}], {
             RGBColor[
             0.3740760297515814, 0.49842758818805, 0.9450567717266938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 40}], {
             RGBColor[
             0.2798133914717097, 0.41076703602808307`, 0.9392706781151272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 53}], {
             RGBColor[
             0.3197505236769518, 0.4513735653055334, 0.9415951985177772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.3409913926021096, 0.4697713383713912, 0.9429486479031253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 90}], {
             RGBColor[
             0.3120203774346074, 0.44461862031594124`, 0.9411048183197483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 100}], {
             RGBColor[
             0.28060017483633093`, 0.41159399522924645`, 0.9393154842638007]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 29}], {
             RGBColor[
             0.27832737386526063`, 0.40880890872697706`, 0.9392005594800119]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.25232882209907226`, 0.38254396897044507`, 0.9376811251802775]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 62}], {
             RGBColor[
             0.30123789915337096`, 0.4286528542150554, 0.9406603978923882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 19}], {
             RGBColor[
             0.32753691967137427`, 0.45423076386143946`, 0.9422336623945751]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 22}], {
             RGBColor[
             0.6749436759381056, 0.7408142314231896, 0.9479954802017996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 28}], {
             RGBColor[
             0.3222279508615301, 0.4486507010342292, 0.9419313244747699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 46}], {
             RGBColor[
             0.32973159379600026`, 0.45653750551679784`, 0.942358645839243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 55}], {
             RGBColor[
             0.3185371640353287, 0.44477145007049096`, 0.9417211396250476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 59}], {
             RGBColor[
             0.33165561016298184`, 0.45855976870817894`, 0.9424682157250155]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 66}], {
             RGBColor[
             0.3553182658055509, 0.48218055585062736`, 0.943861543594892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 69}], {
             RGBColor[
             0.40608263929049154`, 0.5261501046716837, 0.9470962045841795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 77}], {
             RGBColor[
             0.4030805157734533, 0.5235498161723404, 0.9469049119283475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 79}], {
             RGBColor[
             0.3156295526433677, 0.44171536614432994`, 0.9415555554577009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 95}], {
             RGBColor[
             0.48701029086628944`, 0.5926524000847553, 0.95324564623738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 98}], {
             RGBColor[
             0.34163351398872654`, 0.46904717826467845`, 0.9430364425869058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.3958768319210234, 0.5173103472870436, 0.9464458995632381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 80}], {
             RGBColor[
             0.2419836729170215, 0.3716705612597674, 0.9370919842386365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 28}], {
             RGBColor[
             0.26139593816194606`, 0.39207408284088785`, 0.938197484026462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 43}], {
             RGBColor[
             0.25864725898215624`, 0.389185046746603, 0.9380409508134795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 46}], {
             RGBColor[
             0.2688995810964162, 0.39996088732345647`, 0.9386248053909352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 55}], {
             RGBColor[
             0.2577051513357447, 0.38819483187714965`, 0.9379872991767397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 59}], {
             RGBColor[
             0.2708235974633978, 0.40198315051483763`, 0.9387343752767077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 66}], {
             RGBColor[
             0.2944862531059669, 0.425603937657286, 0.9401277031465842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 79}], {
             RGBColor[
             0.2547975399437836, 0.38513874795098857`, 0.937821715009393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 95}], {
             RGBColor[
             0.4261782781667054, 0.536075781891414, 0.949511805789072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 98}], {
             RGBColor[
             0.2808015012891425, 0.4124705600713371, 0.9393026021385978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 99}], {
             RGBColor[
             0.33504481922143936`, 0.46073372909370225`, 0.9427120591149303]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.2386756834212212, 0.36819365456103337`, 0.9369035991305825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 58}], {
             RGBColor[
             0.22266134542622565`, 0.3513615699606193, 0.9359916062728575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 59}], {
             RGBColor[
             0.24810334272267293`, 0.37810272223498315`, 0.9374404903808281]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 63}], {
             RGBColor[
             0.22006041247387476`, 0.34862782451902463`, 0.9358434869889567]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 66}], {
             RGBColor[
             0.271765998365242, 0.4017235093774315, 0.9388338182507047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 79}], {
             RGBColor[
             0.2320772852030587, 0.3612583196711341, 0.9365278301135136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 83}], {
             RGBColor[
             0.22260788034518547`, 0.3513053747705641, 0.9359885615155867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 97}], {
             RGBColor[
             0.23606571183465724`, 0.3654504089417983, 0.9367549651098346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 22}], {
             RGBColor[
             0.9323482473126639, 0.8120285789472437, 0.5954726044647025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 30}], {
             RGBColor[
             0.860772607404038, 0.39770976902130306`, 0.2030717255588116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 34}], {
             RGBColor[
             0.7440489383777218, 0.6635696741320418, 0.6006939636333543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.5412488824777958, 0.4795214095089955, 0.5872225572369445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 49}], {
             RGBColor[
             0.8381155029968219, 0.7379350846059927, 0.6094680504969712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 68}], {
             RGBColor[
             0.8602485375600374, 0.3936815385514446, 0.2025698756843444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 72}], {
             RGBColor[
             0.8673115146201031, 0.4479706752513929, 0.20933339049355504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 82}], {
             RGBColor[
             0.8703286104016272, 0.4711613955279884, 0.21222256482126478`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[
             0.8461475149580568, 0.7442097533956613, 0.6102686063858478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 92}], {
             RGBColor[
             0.5447186986215644, 0.48316840627514634`, 0.5874201581331991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 30}], {
             RGBColor[
             0.889942779596627, 0.5565022708656576, 0.5576225786548253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 34}], {
             RGBColor[
             0.7732191105703109, 0.8223621759763964, 0.955244816729368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 49}], {
             RGBColor[
             0.8672856751894109, 0.8967275864503471, 0.9640189035929849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 66}], {
             RGBColor[
             0.6418930093726982, 0.712187405219036, 0.9458895209538087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 69}], {
             RGBColor[
             0.6926573828576388, 0.7561569540400923, 0.9491241819430962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 77}], {
             RGBColor[
             0.6896552593406005, 0.7535566655407491, 0.9489328892872642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 82}], {
             RGBColor[
             0.8994987825942162, 0.6299538973723429, 0.5667734179172785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 87}], {
             RGBColor[
             0.875317687150646, 0.9030022552400158, 0.9648194594818615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 95}], {
             RGBColor[
             0.7735850344334367, 0.822659249453164, 0.9552736235962966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 99}], {
             RGBColor[
             0.6824515754881706, 0.7473171966554524, 0.9484738769221548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 24}], {
             RGBColor[
             0.9471254016338135, 0.8298823883137303, 0.5568344831794053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 27}], {
             RGBColor[
             0.6645515668442425, 0.7298696411778459, 0.9061368692979717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 30}], {
             RGBColor[
             0.9025589304514734, 0.5654862789591164, 0.5172300337295237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 37}], {
             RGBColor[
             0.8563518073535856, 0.887314140955882, 0.9212791128920343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 50}], {
             RGBColor[
             0.9890507904475296, 0.9897402347152724, 0.831120268137828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 76}], {
             RGBColor[
             0.9905483291850934, 0.9895519766020239, 0.7476033518841813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[
             0.7636299537302207, 0.8133189149453938, 0.9131041886415987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 84}], {
             RGBColor[
             0.7117851117483094, 0.7707809637467538, 0.909146549012275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 85}], {
             RGBColor[
             0.8008648229179952, 0.8435478591637703, 0.9160354539398804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 86}], {
             RGBColor[
             0.990093096424966, 0.9901712550229842, 0.8138465606903063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 42}], {
             RGBColor[
             0.7818518898687528, 0.7011631313519644, 0.6053992543639326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 50}], {
             RGBColor[
             0.9494254708663976, 0.830833526050487, 0.5187163836071205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 76}], {
             RGBColor[
             0.9509230096039614, 0.8306452679372385, 0.4351994673534736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 26}], {
             RGBColor[
             0.21798888787154624`, 0.3464505208197316, 0.9357255167274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 40}], {
             RGBColor[
             0.22979823437354924`, 0.35886289274915106`, 0.9363980415403266]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 54}], {
             RGBColor[
             0.2334197719370433, 0.36266935834712705`, 0.9366042827469828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 65}], {
             RGBColor[
             0.21906851954430756`, 0.34758528216040546`, 0.9357870001539919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 100}], {
             RGBColor[
             0.23058501773817044`, 0.3596898519503145, 0.9364428476890001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 40}], {
             RGBColor[
             0.23187934520351416`, 0.3610502721814919, 0.9365165577233654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 53}], {
             RGBColor[
             0.27181647740875625`, 0.40165680145894234`, 0.9388410781260154]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 65}], {
             RGBColor[
             0.2211496303742725, 0.34977266159274634`, 0.9359055163370308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 90}], {
             RGBColor[
             0.2640863311664119, 0.39490185646935017`, 0.9383506979279865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[
             0.2326661285681354, 0.3618772313826554, 0.9365613638720389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 37}], {
             RGBColor[
             0.5341526529828826, 0.6283946851552121, 0.9581776144798929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 43}], {
             RGBColor[
             0.29647101173303086`, 0.4258330666011419, 0.9403087252832609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 54}], {
             RGBColor[
             0.2966420896530224, 0.4260128803420197, 0.9403184679177174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 81}], {
             RGBColor[
             0.4414307993595177, 0.5543994591447239, 0.9500026902294574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 84}], {
             RGBColor[
             0.38958595737760626`, 0.5118615079460839, 0.9460450506001336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 85}], {
             RGBColor[
             0.4786656685472922, 0.5846284033631004, 0.952933955527739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 46}], {
             RGBColor[
             0.2635906122865721, 0.39438082449624623`, 0.93832246747113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 55}], {
             RGBColor[
             0.2523961825259005, 0.38261476904993935`, 0.9376849612569346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 59}], {
             RGBColor[
             0.2655146286535537, 0.39640308768762733`, 0.9384320373569025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 66}], {
             RGBColor[
             0.28917728429612277`, 0.42002387483007575`, 0.9398253652267791]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 79}], {
             RGBColor[
             0.24948857113393946`, 0.3795586851237783, 0.937519377089588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 83}], {
             RGBColor[
             0.24001916627606623`, 0.36960574022320836`, 0.9369801084916611]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 98}], {
             RGBColor[
             0.27549253247929834`, 0.40689049724412685`, 0.9390002642187927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 99}], {
             RGBColor[
             0.3297358504115952, 0.455153666266492, 0.9424097211951252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 33}], {
             RGBColor[
             0.29422509162390786`, 0.4255184180648389, 0.9401059109878009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 38}], {
             RGBColor[
             0.3762188058276783, 0.5002835531261081, 0.9451933075234802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 42}], {
             RGBColor[
             0.48821367053746006`, 0.5915669704381774, 0.9539966276833514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.34313416867820656`, 0.4716273033094493, 0.9430851836999117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 36}], {
             RGBColor[
             0.49884341476175903`, 0.2239951014274094, 0.5493725314270672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 50}], {
             RGBColor[
             0.9048589996840575, 0.566437416695873, 0.47911193415723874`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 82}], {
             RGBColor[
             0.8279231426855904, 0.21563508744640228`, 0.17437253901138755`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 86}], {
             RGBColor[
             0.9059013056614938, 0.5668684370035848, 0.46183822670971686`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 92}], {
             RGBColor[
             0.5023132309055276, 0.22764209819356024`, 0.5495701323233219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 94}], {
             RGBColor[
             0.4995877733317956, 0.224777469479577, 0.549414921546451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 32}], {
             RGBColor[
             0.3463701598777138, 0.472931174642505, 0.9433462632569267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 39}], {
             RGBColor[
             0.34736341039793694`, 0.47397514391497986`, 0.943402827404671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 44}], {
             RGBColor[
             0.5893518598321712, 0.6739738751825308, 0.9626393731710036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 45}], {
             RGBColor[
             0.5919024457294845, 0.6759664122706829, 0.9628935917366674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 51}], {
             RGBColor[
             0.33046646407782415`, 0.4562153820042676, 0.9424405713085325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 70}], {
             RGBColor[
             0.3382626356768291, 0.464409652660651, 0.9428845517476936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 75}], {
             RGBColor[
             0.3329280335215753, 0.45880264756216715`, 0.9425807540467885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 78}], {
             RGBColor[
             0.6972006995541824, 0.7564641060518543, 0.846300355646884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 80}], {
             RGBColor[
             0.33469414166217204`, 0.4606589391956579, 0.9426813312926726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 39}], {
             RGBColor[
             0.2935264779562271, 0.4258453173585629, 0.9400272707348724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 44}], {
             RGBColor[
             0.5355149273904612, 0.6258440486261139, 0.959263816501205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 45}], {
             RGBColor[
             0.5380655132877746, 0.6278365857142659, 0.9595180350668688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 51}], {
             RGBColor[
             0.27662953163611426`, 0.40808555544785063`, 0.9390650146387339]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 80}], {
             RGBColor[
             0.2808572092204622, 0.41252911263924097`, 0.939305774622874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 42}], {
             RGBColor[
             0.46221511877127164`, 0.5653020306816455, 0.952477193383617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 62}], {
             RGBColor[
             0.3171356169120182, 0.44536236355291736`, 0.9415657494001773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 49}], {
             RGBColor[
             0.678986366254469, 0.7482686816351451, 0.9692402627616367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 60}], {
             RGBColor[
             0.5274957486173808, 0.6272838379970835, 0.9559455440932065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 69}], {
             RGBColor[
             0.5043580739226968, 0.6076980492248905, 0.954345541111748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 71}], {
             RGBColor[
             0.46781157980336074`, 0.5760433128989255, 0.9520168308232597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 77}], {
             RGBColor[
             0.5013559504056586, 0.6050977607255472, 0.9541542484559159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 82}], {
             RGBColor[
             0.7111994736592744, 0.481494992557141, 0.5719947770859303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 87}], {
             RGBColor[
             0.687018378215704, 0.7545433504248138, 0.9700408186505132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 38}], {
             RGBColor[
             0.3673467656616922, 0.49201966294494187`, 0.9446492027229738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 53}], {
             RGBColor[
             0.3130212595870627, 0.4449656400624253, 0.9411876295140573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 62}], {
             RGBColor[
             0.3342621285122205, 0.46336341312828305`, 0.9425410788994055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 90}], {
             RGBColor[
             0.3052911133447183, 0.4382106950728331, 0.9406972493160285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 61}], {
             RGBColor[
             0.17912334491775841`, 0.3056003709575509, 0.9335121815526001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 67}], {
             RGBColor[
             0.18042977836149893`, 0.3069735153395867, 0.9335865810045261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 68}], {
             RGBColor[
             0.4983193449177584, 0.2199668709575509, 0.5488706815526001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 72}], {
             RGBColor[
             0.5053823219778242, 0.27425600765749925`, 0.5556341963618108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 82}], {
             RGBColor[
             0.5083994177593483, 0.2974467279340947, 0.5585233706895204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 86}], {
             RGBColor[
             0.5863775807352516, 0.6486800774912771, 0.8459890583878498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 92}], {
             RGBColor[
             0.18278950597928542`, 0.3094537386812527, 0.9337209640014548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 94}], {
             RGBColor[
             0.1800640484055534, 0.3065891099672694, 0.9335657532245839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 50}], {
             RGBColor[
             0.8586518765861698, 0.8882652786926387, 0.8831610133197494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 76}], {
             RGBColor[
             0.8601494153237335, 0.8880770205793902, 0.7996440970661025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 81}], {
             RGBColor[
             0.6332310398688609, 0.7118439589227601, 0.9651449338235201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 84}], {
             RGBColor[
             0.5813861978869495, 0.66930600772412, 0.9611872941941962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 85}], {
             RGBColor[
             0.6704659090566354, 0.7420729031411366, 0.9680761991218017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 42}], {
             RGBColor[
             0.5442088329750422, 0.6400671657429147, 0.9575645899192962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 62}], {
             RGBColor[
             0.39912933111578863`, 0.5201274986141865, 0.9466531459358565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 44}], {
             RGBColor[
             0.5365081779106845, 0.6268880178985887, 0.9593203806489492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 45}], {
             RGBColor[
             0.5390587638079978, 0.6288805549867408, 0.959574599214613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 80}], {
             RGBColor[
             0.28185045974068534`, 0.4135730819117158, 0.9393623387706183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 53}], {
             RGBColor[
             0.2836258239107592, 0.41406917338836174`, 0.9395136029389419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 54}], {
             RGBColor[
             0.24731022926901122`, 0.37726910970888733`, 0.9373953237429482]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.23295897687627548`, 0.36218503352216574`, 0.9365780411499574]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 90}], {
             RGBColor[
             0.27589567766841483`, 0.4073142283987696, 0.939023222740913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 100}], {
             RGBColor[
             0.24447547507013836`, 0.3742896033120748, 0.9372338886849655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 48}], {
             RGBColor[
             0.34329321321312134`, 0.4669781893550724, 0.9432705886491298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 56}], {
             RGBColor[
             0.3357366265014662, 0.459035737605853, 0.9428402522148693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 60}], {
             RGBColor[
             0.44984311664774745`, 0.5635983285779962, 0.9500102743152689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 64}], {
             RGBColor[
             0.3573126143001289, 0.48171346877888566`, 0.9440689728011896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 73}], {
             RGBColor[
             0.34062966364440406`, 0.46417862987955394`, 0.9431189034415599]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 74}], {
             RGBColor[
             0.39624144168094344`, 0.517626153935267, 0.9464691321747285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.3593964815136068, 0.4839037453450634, 0.9441876459561919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 91}], {
             RGBColor[
             0.34170136961930875`, 0.46530506080926215`, 0.9431799355113838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 93}], {
             RGBColor[
             0.34493630114672413`, 0.468705178951081, 0.9433641600762177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 44}], {
             RGBColor[
             0.7173501625148713, 0.7791186661105619, 0.9724624182472246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 62}], {
             RGBColor[
             0.5111241958255703, 0.6114109159262558, 0.9554564660957278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 78}], {
             RGBColor[
             0.8251990022368825, 0.8616088969798854, 0.8561234007231051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 46}], {
             RGBColor[
             0.2608419331067822, 0.3914917884019613, 0.9381659342581474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 54}], {
             RGBColor[
             0.2507606889125138, 0.3808957615659856, 0.9375918223151481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 45}], {
             RGBColor[
             0.7810472132422319, 0.8288792862542917, 0.9788111449809456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 78}], {
             RGBColor[
             0.88634546706693, 0.9093769800354632, 0.8622179088911622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 52}], {
             RGBColor[
             0.8611685991001501, 0.8128504925215565, 0.6243159249705089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 78}], {
             RGBColor[
             0.8888960529642432, 0.9113695171236152, 0.8624721274568261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 55}], {
             RGBColor[
             0.25989982546037066`, 0.390501573532508, 0.9381122826214077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 59}], {
             RGBColor[
             0.27301827158802383`, 0.40428989217019595`, 0.9388593587213756]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 79}], {
             RGBColor[
             0.25699221406840955`, 0.38744548960634695`, 0.937946698454061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 95}], {
             RGBColor[
             0.42837295229133143`, 0.5383825235467723, 0.9496367892337401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 98}], {
             RGBColor[
             0.2829961754137684, 0.41477730172669547`, 0.9394275855832659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 99}], {
             RGBColor[
             0.3372394933460653, 0.46304047074906063`, 0.9428370425595982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 51}], {
             RGBColor[
             0.26797369092262097`, 0.39898771804597, 0.9385720773152693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 57}], {
             RGBColor[
             0.2643065968573336, 0.3951333696761603, 0.9383632417332306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 70}], {
             RGBColor[
             0.27576986252162594`, 0.40718198870235345`, 0.9390160577544302]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 74}], {
             RGBColor[
             0.31904494583740095`, 0.4476628644149205, 0.9416637299737558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 75}], {
             RGBColor[
             0.2704352603663721, 0.40157498360386956`, 0.9387122600535251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 88}], {
             RGBColor[
             0.28219998567006427`, 0.41394045582471695`, 0.9393822437552191]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.280167857490329, 0.4118045602634469, 0.9392665170616474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 56}], {
             RGBColor[
             0.2494153020184852, 0.3794816746379056, 0.9375152045218548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 57}], {
             RGBColor[
             0.25518176821789507`, 0.38554259622855935`, 0.9378435962411888]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 64}], {
             RGBColor[
             0.27099128981714793`, 0.40215940581093823`, 0.9387439251081751]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 73}], {
             RGBColor[
             0.25430833916142304`, 0.38462456691160657`, 0.9377938557485452]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 74}], {
             RGBColor[
             0.3099201171979624, 0.4380720909673196, 0.941144084481714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 88}], {
             RGBColor[
             0.2730751570306258, 0.404349682377116, 0.9388625982631773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 91}], {
             RGBColor[
             0.2553800451363277, 0.3857509978413148, 0.9378548878183692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 93}], {
             RGBColor[
             0.2586149766637431, 0.3891511159831336, 0.9380391123832033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 96}], {
             RGBColor[
             0.2710430288508906, 0.402213786815846, 0.9387468715696057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 69}], {
             RGBColor[
             0.5984246385417968, 0.6820634596988412, 0.9631196279753649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 71}], {
             RGBColor[
             0.5618781444224608, 0.6504087233728764, 0.9607909176868766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 77}], {
             RGBColor[
             0.5954225150247585, 0.679463171199498, 0.9629283353195328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 82}], {
             RGBColor[
             0.8052660382783743, 0.5558604030310919, 0.5807688639495472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.781084942834804, 0.8289087608987646, 0.9788149055141302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 76}], {
             RGBColor[
             0.9928483984176775, 0.9905031143387806, 0.7094852523118963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 81}], {
             RGBColor[
             0.7659300229628049, 0.8142700526821505, 0.8749860890693137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 84}], {
             RGBColor[
             0.7140851809808935, 0.7717321014835103, 0.87102844943999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 85}], {
             RGBColor[
             0.8031648921505794, 0.844498996900527, 0.8779173543675954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 86}], {
             RGBColor[
             0.9923931656575502, 0.9911223927597408, 0.7757284611180213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 57}], {
             RGBColor[
             0.25705874177093724`, 0.3875154144398035, 0.9379504871083011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 70}], {
             RGBColor[
             0.2685220074352297, 0.3995640334659966, 0.9386033031295007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 75}], {
             RGBColor[
             0.2631874052799758, 0.3939570283675128, 0.9382995054285956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 67}], {
             RGBColor[
             0.560139632974118, 0.5514847252323705, 0.6016081426491302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 68}], {
             RGBColor[
             0.8780291995303775, 0.46447808085033465`, 0.21689224319720418`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 72}], {
             RGBColor[
             0.8850921765904433, 0.518767217550283, 0.2236557580064148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 78}], {
             RGBColor[
             0.9664668529248481, 0.8933481863027279, 0.5077226888807255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 65}], {
             RGBColor[
             0.2728961090815175, 0.40279156279961614`, 0.9389025615526072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 84}], {
             RGBColor[
             0.3801912291988372, 0.5037242665904019, 0.9454464268280143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 85}], {
             RGBColor[
             0.46927094036852307`, 0.5764911620074185, 0.9523353317556198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 90}], {
             RGBColor[
             0.3158328098736569, 0.44792075767621997`, 0.941347743143563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 100}], {
             RGBColor[
             0.2844126072753804, 0.4148961325895252, 0.9395584090876155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 84}], {
             RGBColor[
             0.3438756345570892, 0.4669242029109275, 0.9433281476320208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 100}], {
             RGBColor[
             0.24809701263363243`, 0.37809606891005076`, 0.9374401298916217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 59}], {
             RGBColor[
             0.26182384182735224`, 0.39252383672388913`, 0.9382218525071802]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 66}], {
             RGBColor[
             0.28548649746992133`, 0.41614462386633744`, 0.9396151803770567]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 79}], {
             RGBColor[
             0.24579778430773802`, 0.37567943416004, 0.9373091922398655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 98}], {
             RGBColor[
             0.2718017456530969, 0.4030112462803886, 0.9387900793690704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 99}], {
             RGBColor[
             0.32604506358539376`, 0.45127441530275375`, 0.9421995363454028]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 64}], {
             RGBColor[
             0.2634347031054928, 0.3942169540617188, 0.9383135886739146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 73}], {
             RGBColor[
             0.24675175244976794`, 0.37668211516238714`, 0.9373635193142849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 74}], {
             RGBColor[
             0.3023635304863073, 0.4301296392181001, 0.9407137480474534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 88}], {
             RGBColor[
             0.26551857031897064`, 0.39640723062789657`, 0.9384322618289168]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 89}], {
             RGBColor[
             0.2431918362429577, 0.37294041751730556`, 0.937160787352731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 91}], {
             RGBColor[
             0.2478234584246726, 0.37780854609209535`, 0.9374245513841087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 93}], {
             RGBColor[
             0.251058389952088, 0.3812086642339142, 0.9376087759489427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 64}], {
             RGBColor[
             0.2692011693049027, 0.4002778756523726, 0.9386419803932486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 70}], {
             RGBColor[
             0.26485491336994227`, 0.39570968509618687`, 0.9383944675474621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 74}], {
             RGBColor[
             0.3081299966857172, 0.43619056080875396`, 0.9410421397667876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 75}], {
             RGBColor[
             0.25952031121468844`, 0.390102679997703, 0.9380906698465571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 88}], {
             RGBColor[
             0.27128503651838054`, 0.40246815221855037`, 0.9387606535482509]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 96}], {
             RGBColor[
             0.26925290833864535`, 0.40033225665728034`, 0.9386449268546793]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 63}], {
             RGBColor[
             0.22145736040975994`, 0.3500961053712548, 0.9359230411073061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 83}], {
             RGBColor[
             0.22400482828107066`, 0.3527736556227943, 0.9360681156339361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 97}], {
             RGBColor[
             0.23746265977054243`, 0.3669186897940284, 0.936834519228184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 66}], {
             RGBColor[
             0.2986049435975745, 0.4299329425040255, 0.9403622564770246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 69}], {
             RGBColor[
             0.34936931708251506`, 0.4739024913250818, 0.9435969174663121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 77}], {
             RGBColor[
             0.3463671935654768, 0.47130220282573854`, 0.9434056248104801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 79}], {
             RGBColor[
             0.2589162304353912, 0.38946775279772805`, 0.9380562683398335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 83}], {
             RGBColor[
             0.24944682557751796`, 0.3795148078971581, 0.9375169997419068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 95}], {
             RGBColor[
             0.430296968658313, 0.5404047867381535, 0.9497463591195126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 97}], {
             RGBColor[
             0.26290465706698973`, 0.3936598420683923, 0.9382834033361547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 98}], {
             RGBColor[
             0.28492019178075007`, 0.41679956491807657`, 0.9395371554690384]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 99}], {
             RGBColor[
             0.33916350971304693`, 0.46506273394044173`, 0.9429466124453707]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 64}], {
             RGBColor[
             0.37754119325177404`, 0.49877954503386207`, 0.9454836107743141]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 71}], {
             RGBColor[
             0.41038752678537255`, 0.5294238797348146, 0.9474961990184465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 74}], {
             RGBColor[
             0.4164700206325886, 0.5346922301902434, 0.9478837701478531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 89}], {
             RGBColor[
             0.357298326389239, 0.4775030084894488, 0.9443308094531306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 93}], {
             RGBColor[
             0.3651648800983693, 0.48577125520605746`, 0.9447787980493423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 67}], {
             RGBColor[
             0.1802334334437405, 0.3067671443820358, 0.933575399451926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 68}], {
             RGBColor[0.49812300000000004`, 0.2197605, 0.5488595000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 72}], {
             RGBColor[
             0.5051859770600657, 0.2740496366999483, 0.5556230148092107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 86}], {
             RGBColor[
             0.5861812358174932, 0.6484737065337263, 0.8459778768352497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 92}], {
             RGBColor[
             0.182593161061527, 0.30924736772370176`, 0.9337097824488547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 94}], {
             RGBColor[
             0.17986770348779496`, 0.3063827390097185, 0.9335545716719839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 83}], {
             RGBColor[
             0.2214038953287198, 0.3500399101811996, 0.9359199963500353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 97}], {
             RGBColor[
             0.23486172681819156`, 0.36418494435243376`, 0.9366863999442832]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 73}], {
             RGBColor[
             0.26832774024843065`, 0.39935984633541977`, 0.938592239900605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 74}], {
             RGBColor[
             0.32393951828497003`, 0.45280737039113284`, 0.9419424686337738]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 88}], {
             RGBColor[
             0.2870945581176334, 0.41908496180092925`, 0.9396609824152371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 89}], {
             RGBColor[
             0.2647678240416204, 0.39561814869033823`, 0.9383895079390514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 91}], {
             RGBColor[
             0.26939944622333534`, 0.400486277265128, 0.938653271970429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 93}], {
             RGBColor[
             0.2726343777507507, 0.4038863954069468, 0.938837496535263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 96}], {
             RGBColor[
             0.28506242993789815`, 0.4169490662396592, 0.9395452557216655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 90}], {
             RGBColor[
             0.26516596283917315`, 0.39603661781002397`, 0.9384121813545784]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 100}], {
             RGBColor[
             0.2337457602408967, 0.3630119927233292, 0.9366228472986309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 69}], {
             RGBColor[
             0.37303197272508415`, 0.4975232784675301, 0.9449902453361887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 77}], {
             RGBColor[
             0.3700298492080458, 0.49492298996818684`, 0.9447989526803566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 79}], {
             RGBColor[
             0.2825788860779602, 0.4130885399401764, 0.93944959620971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 83}], {
             RGBColor[
             0.27310948122008705`, 0.4031355950396065, 0.9389103276117834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 95}], {
             RGBColor[
             0.4539596243008821, 0.5640255738806018, 0.9511396869893891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 97}], {
             RGBColor[
             0.2865673127095588, 0.41728062921084064`, 0.9396767312060312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[
             0.3085828474233191, 0.440420352060525, 0.9409304833389149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 99}], {
             RGBColor[
             0.36282616535561596`, 0.48868352108289015`, 0.9443399403152473]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 68}], {
             RGBColor[
             0.49942943344374047`, 0.22113364438203578`, 0.5489338994519259]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 72}], {
             RGBColor[
             0.5064924105038062, 0.2754227810819841, 0.5556974142611366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 86}], {
             RGBColor[
             0.5874876692612337, 0.649846850915762, 0.8460522762871756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 92}], {
             RGBColor[
             0.1838995945052675, 0.31062051210573755`, 0.9337841819007806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 94}], {
             RGBColor[
             0.18117413693153547`, 0.3077558833917543, 0.9336289711239099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 72}], {
             RGBColor[
             0.8243819770600658, 0.1884161366999483, 0.17098151480921064`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 82}], {
             RGBColor[
             0.8273990728415899, 0.2116068569765438, 0.1738706891369204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 92}], {
             RGBColor[
             0.501789161061527, 0.22361386772370176`, 0.5490682824488547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 71}], {
             RGBColor[
             0.38724985209068863`, 0.5098380909626216, 0.9458961960369879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 77}], {
             RGBColor[
             0.4207942226929865, 0.5388925387892431, 0.9480336136696441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 87}], {
             RGBColor[
             0.6064566505030319, 0.6883381284885098, 0.9639201838642415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 95}], {
             RGBColor[
             0.5047239977858227, 0.6079951227016581, 0.9543743479786766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 97}], {
             RGBColor[
             0.3373316861944994, 0.46125017803189694`, 0.9429113921953187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 98}], {
             RGBColor[
             0.35934722090825977`, 0.48438990088158124`, 0.9441651443282024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 99}], {
             RGBColor[
             0.41359053884055663`, 0.5326530699039465, 0.9475746013045347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 75}], {
             RGBColor[
             0.2709835768789808, 0.4021512990238961, 0.9387434858677567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 96}], {
             RGBColor[
             0.28071617400293775`, 0.4123808756834735, 0.9392977428758789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 77}], {
             RGBColor[
             0.3842477285736503, 0.5072378024632783, 0.9457049033811559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 87}], {
             RGBColor[
             0.5699101563836958, 0.656683392162545, 0.9615914735757531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 82}], {
             RGBColor[
             0.8344620499016556, 0.2658959936764921, 0.180634203946131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 92}], {
             RGBColor[
             0.5088521381215928, 0.27790300442365007`, 0.5558317972580653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 74}], {
             RGBColor[
             0.3072565676292452, 0.4352725314918011, 0.940992399274144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 88}], {
             RGBColor[
             0.2704116074619085, 0.40155012290159753`, 0.9387109130556073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.24808487338589558`, 0.37808330979100657`, 0.9374394385794216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 91}], {
             RGBColor[
             0.25271649556761044`, 0.3829514383657963, 0.9377032026107992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 93}], {
             RGBColor[
             0.2559514270950259, 0.38635155650761516`, 0.9378874271756332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 88}], {
             RGBColor[
             0.3260233854984479, 0.4549976469573106, 0.9420611417887761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 91}], {
             RGBColor[
             0.3083282736041498, 0.43639896242150933`, 0.941053431343968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 96}], {
             RGBColor[
             0.3239912573187127, 0.45286175139604057`, 0.9419454150952044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 96}], {
             RGBColor[
             0.27538157184768386`, 0.40677387058498965`, 0.9389939451749738]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 81}], {
             RGBColor[
             0.7674275617003685, 0.8140817945689018, 0.7914691728156671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 84}], {
             RGBColor[
             0.7155827197184571, 0.7715438433702618, 0.7875115331863431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 85}], {
             RGBColor[
             0.8046624308881429, 0.8443107387872784, 0.7944004381139487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 87}], {
             RGBColor[
             0.6034545269859937, 0.6857378399891666, 0.9637288912084094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 95}], {
             RGBColor[
             0.5017218742687843, 0.6053948342023149, 0.9541830553228445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 97}], {
             RGBColor[
             0.3343295626774611, 0.4586498895325537, 0.9427200995394867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 98}], {
             RGBColor[
             0.35634509739122144`, 0.481789612382238, 0.9439738516723704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 99}], {
             RGBColor[
             0.4105884153235183, 0.5300527814046032, 0.9473833086487027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 83}], {
             RGBColor[
             0.23342076805790374`, 0.3626704053333091, 0.9366043394745922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 98}], {
             RGBColor[
             0.26889413426113584`, 0.39995516235422757`, 0.9386244952017238]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 99}], {
             RGBColor[
             0.3231374521934327, 0.4482183313765927, 0.9420339521780562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 84}], {
             RGBColor[
             0.4886643442635845, 0.5953107817136317, 0.9530123699437607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 85}], {
             RGBColor[
             0.5777440554332705, 0.6680776771306483, 0.9599012748713662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 86}], {
             RGBColor[
             0.9154573086590831, 0.64032006351027, 0.4709890659721701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 87}], {
             RGBColor[
             0.8132980502396094, 0.5621350718207605, 0.5815694198384238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 92}], {
             RGBColor[
             0.5118692339031169, 0.30109372470024554`, 0.558720971585775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 97}], {
             RGBColor[
             0.23740919468950228`, 0.36686249460397324`, 0.9368314744709133]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 85}], {
             RGBColor[
             0.5258992134513589, 0.6255397259320082, 0.9559436352420423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.37246108295649283`, 0.49696932160080975`, 0.9449560466299856]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 90}], {
             RGBColor[
             0.4615407941261787, 0.5697362170178263, 0.951844951557591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 92}], {
             RGBColor[
             0.5898473968790202, 0.652327074257428, 0.8461866592841044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[
             0.5871219393052882, 0.6494624455434448, 0.8460314485072336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 91}], {
             RGBColor[
             0.2714833134368132, 0.40267655383130574`, 0.9387719451254313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 96}], {
             RGBColor[
             0.2871462971513761, 0.419139342805837, 0.9396639288766677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 91}], {
             RGBColor[
             0.24915657936080024`, 0.3792097407207148, 0.9375004706492456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 93}], {
             RGBColor[
             0.25239151088821565`, 0.3826098588625336, 0.9376846952140795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 100}], {
             RGBColor[
             0.27668246103303606`, 0.408141187599933, 0.9390680288895865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 93}], {
             RGBColor[
             0.2570231330699305, 0.38747798743732337`, 0.9379484592454572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 96}], {
             RGBColor[
             0.269451185257078, 0.40054065827003577`, 0.9386562184318596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 94}], {
             RGBColor[
             0.18353386454932197`, 0.3102361067334203, 0.9337633541208386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 98}], {
             RGBColor[
             0.44027487248405767`, 0.5508921962946529, 0.9503145859814027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 99}], {
             RGBColor[
             0.49451819041635453`, 0.5991553653170181, 0.9537240429577352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 99}], {
             RGBColor[
             0.3491414135387916, 0.47555014349694125`, 0.943514839307261]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.058168352269944726`], {
             RGBColor[
             0.2581082061950206, 0.38861846808940276`, 0.9380102525547092]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.058168352269944726`], {
             RGBColor[
             0.5167351398431651, 0.6185478910342742, 0.9550984295530915]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.058168352269944726`], {
             RGBColor[
             0.29928415304751665`, 0.4318969989371937, 0.9403551618136042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.058168352269944726`], {
             RGBColor[
             0.8388093398485373, 0.29931116920282663`, 0.1847971737088267]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.058168352269944726`], {
             RGBColor[
             0.2503401935643895, 0.38045379429416204`, 0.9375678757271396]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.058168352269944726`], {
             RGBColor[
             0.2567233930101477, 0.3871629416298741, 0.9379313894924781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.058168352269944726`], {
             RGBColor[
             0.3134760783279485, 0.4459389561070196, 0.9411953964084129]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.058168352269944726`], {
             RGBColor[
             0.9629022796012385, 0.9718531613853215, 0.9476809433867306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.058168352269944726`], {
             RGBColor[
             0.9513821482973379, 0.8449534494772841, 0.27973913919362886`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.058168352269944726`], {
             RGBColor[
             0.25142577857169485`, 0.38159481296690484`, 0.9376296981873266]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.058168352269944726`], {
             RGBColor[
             0.23420058730117388`, 0.3634900448013817, 0.9366487490268572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.058168352269944726`], {
             RGBColor[
             0.6054182467789488, 0.6905448323731828, 0.9620798885880011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.058168352269944726`], {
             RGBColor[
             0.2733697721409376, 0.40465934153773064`, 0.9388793761578655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.058168352269944726`], {
             RGBColor[
             0.7189648146431117, 0.780380044624954, 0.9726233516815856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.058168352269944726`], {
             RGBColor[
             0.3159380912379023, 0.44807142794525473`, 0.9413522736939626]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.058168352269944726`], {
             RGBColor[
             0.23643110434042502`, 0.36583445963258315`, 0.9367757736724883]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.058168352269944726`], {
             RGBColor[
             0.3883689323709583, 0.5108073820547808, 0.9459675028428829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.058168352269944726`], {
             RGBColor[
             0.21478615482912253`, 0.34308424532714094`, 0.935543125818653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.058168352269944726`], {
             RGBColor[
             0.2667049069717902, 0.39765414566809815`, 0.9384998219462671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.058168352269944726`], {
             RGBColor[
             0.22126439749034046`, 0.3498932891083892, 0.9359120521545081]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.058168352269944726`], {
             RGBColor[
             0.9031780751200748, 0.6532360771028892, 0.2409217513686888]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.058168352269944726`], {
             RGBColor[
             0.9615184195052529, 0.9708210807915982, 0.9500234575607163]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.058168352269944726`], {
             RGBColor[
             0.9867507212149456, 0.9887890969785158, 0.869238367710113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.058168352269944726`], {
             RGBColor[
             0.9075000820526815, 0.6709756796489449, 0.2444305986486977]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.058168352269944726`], {
             RGBColor[
             0.21590777704158132`, 0.3442631413873908, 0.9356070005443611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.058168352269944726`], {
             RGBColor[
             0.2200699987015112, 0.3486379002520725, 0.9358440329104389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.058168352269944726`], {
             RGBColor[
             0.3423524124735395, 0.470950185377176, 0.9430353708858302]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.058168352269944726`], {
             RGBColor[
             0.25608696935210196`, 0.3864940200136776, 0.9378951461066569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.058168352269944726`], {
             RGBColor[
             0.32022364339009624`, 0.4517833578213709, 0.9416253452875354]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.058168352269944726`], {
             RGBColor[
             0.8183671396880012, 0.14218346093971695`, 0.1652216997489344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.058168352269944726`], {
             RGBColor[
             0.40020709231942364`, 0.521061001198922, 0.9467218199267253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.058168352269944726`], {
             RGBColor[
             0.2925332274360039, 0.424801348086088, 0.9399707065871281]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.058168352269944726`], {
             RGBColor[
             0.26822653985771944`, 0.399253478308307, 0.9385864766880666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.058168352269944726`], {
             RGBColor[
             0.5849198016353689, 0.6739032711611944, 0.9604661758980197]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.058168352269944726`], {
             RGBColor[
             0.30247956305812407`, 0.4352555774590384, 0.9405371356865229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.058168352269944726`], {
             RGBColor[
             0.17931968983551683`, 0.3058067419151018, 0.9335233631052001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.058168352269944726`], {
             RGBColor[
             0.7259528934922258, 0.7858391849332483, 0.9733198580739556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.058168352269944726`], {
             RGBColor[
             0.43221396826526043`, 0.5487837484308453, 0.9487612697594249]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.058168352269944726`], {
             RGBColor[
             0.2945197284764503, 0.42688928663103776`, 0.9400838348826166]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.058168352269944726`], {
             RGBColor[
             0.24368869170551716`, 0.37346264411091135`, 0.937189082536292]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.058168352269944726`], {
             RGBColor[
             0.4296145376961023, 0.5465322523230198, 0.9485956363421444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.058168352269944726`], {
             RGBColor[
             0.6562036976848239, 0.731350583054984, 0.9663679100791674]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.058168352269944726`], {
             RGBColor[
             0.25058961099252225`, 0.3807159478251078, 0.9375820796806917]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.058168352269944726`], {
             RGBColor[
             0.7784966273449186, 0.8268867491661398, 0.9785569264152818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.058168352269944726`], {
             RGBColor[
             0.7835977991395453, 0.8308718233424438, 0.9790653635466094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.058168352269944726`], {
             RGBColor[
             0.2710942552210422, 0.40226762897881485`, 0.9387497888356031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.058168352269944726`], {
             RGBColor[
             0.27522154600901727`, 0.40660567328232683`, 0.9389848319401988]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.058168352269944726`], {
             RGBColor[
             0.2569718887301403, 0.38742412638712503`, 0.9379455409561153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.058168352269944726`], {
             RGBColor[
             0.773052930873569, 0.822634092109096, 0.9780143496252536]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.058168352269944726`], {
             RGBColor[
             0.9913508596801138, 0.9906913724520291, 0.7930021685655431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.058168352269944726`], {
             RGBColor[
             0.26072583583622466`, 0.3913697628096132, 0.9381593226903397]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.058168352269944726`], {
             RGBColor[
             0.938739399060755, 0.7948291617006693, 0.26956648639440833`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.058168352269944726`], {
             RGBColor[
             0.3235629561160013, 0.45467570266581214`, 0.9418381233415918]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.058168352269944726`], {
             RGBColor[
             0.2509317668325053, 0.3810755753068633, 0.9376015649496046]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.058168352269944726`], {
             RGBColor[
             0.2487053956996991, 0.3787355180862011, 0.9374747764072122]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.058168352269944726`], {
             RGBColor[
             0.24185871530683006`, 0.3715392228886861, 0.9370848680875943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.058168352269944726`], {
             RGBColor[
             0.25339164770564987`, 0.38366106606999373`, 0.9377416515262625]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.058168352269944726`], {
             RGBColor[
             0.22405829336211083`, 0.3528298508128494, 0.9360711603912069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.058168352269944726`], {
             RGBColor[
             0.2749422879550054, 0.4063121553615771, 0.9389689286071481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.058168352269944726`], {
             RGBColor[
             0.4700716955993926, 0.5806644048329727, 0.9514249122883933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.058168352269944726`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.058168352269944726`], {
             RGBColor[
             0.3660446939663169, 0.4914712487975277, 0.9445450221122881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.058168352269944726`], {
             RGBColor[
             0.21885642745740908`, 0.34736235992966014`, 0.9357749218234052]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.058168352269944726`], {
             RGBColor[
             0.2850106909041555, 0.4168946852347515, 0.9395423092602349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.058168352269944726`], {
             RGBColor[
             0.2222292620470338, 0.35090742293342014`, 0.9359669997636226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.058168352269944726`], {
             RGBColor[
             0.32226759924014353`, 0.45355372964647384`, 0.9417555843469012]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.058168352269944726`], {
             RGBColor[
             0.181539866887481, 0.30814028876407157`, 0.9336497989038519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.058168352269944726`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.058168352269944726`], {
             RGBColor[
             0.42379634621002477`, 0.5414928272885864, 0.9482249063254762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.058168352269944726`], {
             RGBColor[
             0.27631817903423467`, 0.40775830412238, 0.9390472835686617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.058168352269944726`], {
             RGBColor[
             0.3507033579713525, 0.4781833546366567, 0.9435674857484997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.058168352269944726`], {
             RGBColor[
             0.8314449541201315, 0.24270527339989661`, 0.17774502961842129`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.058168352269944726`], {
             RGBColor[
             0.2516447895927058, 0.3818250074360881, 0.9376421705409753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.058168352269944726`], {
             RGBColor[
             0.3628683456657846, 0.48872005554751413`, 0.9443426280073127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.058168352269944726`], {
             RGBColor[
             0.26564897472372695`, 0.3965442939254123, 0.9384396881668516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.058168352269944726`], {
             RGBColor[
             0.9943459371552411, 0.990314856225532, 0.6259683360582495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.058168352269944726`], {
             RGBColor[
             0.4177920991759482, 0.5362922502898999, 0.947842321013812]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.058168352269944726`], {
             RGBColor[
             0.9941943067889412, 0.9918672109047867, 0.7458788913670427]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.058168352269944726`], {
             RGBColor[
             0.24289017291577697`, 0.372623350233879, 0.937143608072519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.058168352269944726`], {
             RGBColor[
             0.26918119100492044`, 0.4002568771923939, 0.9386408426586199]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.058168352269944726`], {
             RGBColor[
             0.5405091862454959, 0.6378487329122717, 0.9569700095730845]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.058168352269944726`], {
             RGBColor[
             0.8374791456831797, 0.2890867139530876, 0.18352337827384074`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.058168352269944726`], {
             RGBColor[
             0.2239513632000305, 0.3527174604327391, 0.9360650708766655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.058168352269944726`], {
             RGBColor[
             0.4368195022816731, 0.5527728305149917, 0.9490547303144369]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.058168352269944726`], {
             RGBColor[
             0.6149789246210449, 0.6983066213490248, 0.9628325401696478]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.058168352269944726`], {
             RGBColor[
             0.9934354716349865, 0.9915534130674525, 0.7584547536704994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.058168352269944726`], {
             RGBColor[
             0.789116954796039, 0.8351834296884333, 0.9796154614030067]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.058168352269944726`], {
             RGBColor[
             0.28917842533111127`, 0.421275238367107, 0.9397796555702393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.058168352269944726`], {
             RGBColor[
             0.24452495717908534`, 0.374341612145925, 0.9372367066178678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.058168352269944726`], {
             RGBColor[
             0.30810266363131256`, 0.4411658126866278, 0.9408573629455341]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.058168352269944726`], {
             RGBColor[
             0.25378820154251513`, 0.3840778692955045, 0.9377642346806232]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.058168352269944726`], {
             RGBColor[
             0.18625932212305402`, 0.3131007354474035, 0.9339185648977094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.058168352269944726`], {
             RGBColor[
             0.26025806459734596`, 0.3908781055791422, 0.9381326838102911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.058168352269944726`], {
             RGBColor[
             0.18080840697558995`, 0.30737147801943704`, 0.9336081433439677]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.058168352269944726`], {
             RGBColor[
             0.5856516493616206, 0.6744974181147299, 0.9605237896318769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.058168352269944726`], {
             RGBColor[
             0.2851141689716408, 0.417003447244567, 0.939548202183096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.058168352269944726`], {
             RGBColor[
             0.25086702617897405`, 0.38100752877520744`, 0.9375978780651611]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.058168352269944726`], {
             RGBColor[
             0.2948980956064947, 0.4272869744745761, 0.9401053823309286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.058168352269944726`], {
             RGBColor[
             0.40338473147108844`, 0.5238133125193064, 0.9469242962835934]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.058168352269944726`], {
             RGBColor[
             0.24526225843475957`, 0.3751165625132382, 0.937278694833639]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{3.8349504055390835`*^9, 3.834957759852075*^9, 
  3.835018922383715*^9, 3.835019017360054*^9, 3.835020551743785*^9, 
  3.835044643191966*^9},
 CellLabel->
  "Out[244]=",ExpressionUUID->"4fac06e6-6057-4cd4-926f-7ca4957a103a"]
}, Open  ]],

Cell["Estimated with Max-Min Deviation v Calculated: (r = 3)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 3.8349503922098827`*^9}, {3.8349504781120467`*^9, 
  3.8349504928656063`*^9}},ExpressionUUID->"49a7d9c9-303d-4b18-838a-\
c11ca7776de3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphinf1", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsif1", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}],
      "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"mMDi3f100", ",", "krif1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502554527807`*^9}, {3.8349577716948586`*^9, 
   3.8349577796673746`*^9}, {3.835018835203446*^9, 3.8350188366714215`*^9}, {
   3.8350443464072504`*^9, 3.835044352231003*^9}},
 CellLabel->
  "In[245]:=",ExpressionUUID->"2c281a42-d563-49eb-a011-dfad985ea8c6"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100}, {
          Null, CompressedData["
1:eJwVxVmbqQwAAOCxVtbppLIkW4w1a5YJk8gSaaRCIqr783/Pr/me7715C/Zf
xfZ+fHz883x8/D9363DUk1oFBOGSrgbkKTe9Ubr+DJzlM67jGn44aCN55AiO
7OTWuWMuH0qHqrVObVrjcvv1PnbAe71DT+vplLkyddN8hkqxEiiAOngBnQA/
4nmBl/kz71Cz2Wqmz8zZE8QwHhOwC+aAKIqhFLpCL6gZpsKz8Cpshp+ghVm8
JViWU9t1dtxud0NGCI/IiIU4oXgsHi/Fq3gmo3kQT8YzygyrQz/up/w9/8Gv
+58BCZQwiZcESbpIluT8+c395n89MAjDCIzBI5iHBViCZdiCncDPzznXz/f7
6/6+Nu6Mx9x4N755Y96s9xj4/v75PnvrsXq2Xj/6SZBESYzESZIie6ROmuQz
5MbdtFt1h+5nNkDABEIQI4InZOJMOOEtuqW2s+1quzU9NEwjNEHTI1qmLdpp
99vr9t5fxsuZcrlXPpS19qvz4l7r1/6Fqxm1rPbUoXpQVc1b+CxkC4V67dF5
jB/TB/fYPW6PXCvfah1r1/a1cx1fuevuen2l0qlqaphy0SJWLE6LQlEqXjzR
aCY6jKpRLfeV//pqff3WxLbYEcfiVOTEnShexZenEW0gjUyjQTeG3maumW9+
NevNZqt5DC+p5Wy5XC23S31pLp/+ZCyJJ5P1ZC95AKJACsgAZaAKDAEV0AAX
7KJdrFvsdoWu1L3U7p37+M7dd3fxfr3f7vfH/RV4f79/3vxbeEvv8xswQkbc
SBslo2qohmYYbhAIhoLxYCqYDpaC1aARdIub7ma6ETYbaXMJsDCLsARLsyOW
5VmBlViZPbMW+2Yd7zw2j88/59l5YV6a1+eBRIJIfCfYxE+CT8iJc+IdXACL
0CK1SC+qi4WxcEEFVTCFVIoKpXSVlbJVFF25KCZsIzZh0/bIZm3eFmzJlm3L
th1vJVaJV7KVUqVSr8zDg9ZgsBysBtvBEThFT/gpcyqfeqfD6aSetCADMCEm
xsSZNFNiqgyzYFRGYwzGbU86k/5kwk3WE3Gyn1wnL6/P9+nL+gq+iq/um0dq
kUFkGuEiYuQaefkhKAyhEAlR0AxaQitoCymQDpnQ8z9pR8GG
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[69, 98] -> 
             RGBColor[
              0.8931629999999999, 0.5900125714285713, 0.23176292857142858`], 
             UndirectedEdge[29, 33] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.632953357142857], 
             UndirectedEdge[55, 59] -> 
             RGBColor[
              0.8718352857142857, 0.5016841428571427, 0.2144070714285714], 
             UndirectedEdge[47, 74] -> 
             RGBColor[
              0.6417487142857143, 0.7052103571428572, 0.7258179285714285], 
             UndirectedEdge[19, 43] -> 
             RGBColor[0.905308, 0.5610991428571428, 0.33800799999999986`], 
             UndirectedEdge[57, 75] -> 
             RGBColor[
              0.9589912142857142, 0.8814695714285714, 0.5886137142857143], 
             UndirectedEdge[19, 46] -> 
             RGBColor[
              0.8755547142857143, 0.45466757142857145`, 0.2149012142857143], 
             UndirectedEdge[36, 67] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857142], 
             UndirectedEdge[79, 99] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999999], 
             UndirectedEdge[52, 68] -> 
             RGBColor[
              0.9124627142857142, 0.6868797142857143, 0.24822857142857144`], 
             UndirectedEdge[81, 85] -> 
             RGBColor[0.891135, 0.5985512857142856, 0.23087271428571426`], 
             UndirectedEdge[12, 88] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[72, 82] -> 
             RGBColor[0.98246, 0.9520055714285713, 0.42802957142857123`], 
             UndirectedEdge[31, 44] -> 
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715], 
             UndirectedEdge[17, 79] -> 
             RGBColor[0.98246, 0.9520055714285713, 0.42802957142857123`], 
             UndirectedEdge[91, 96] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[55, 99] -> 
             RGBColor[0.7069385, 0.5297891428571427, 0.5782757142857142], 
             UndirectedEdge[77, 99] -> 
             RGBColor[
              0.7664822142857144, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[29, 38] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.632953357142857], 
             UndirectedEdge[26, 90] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857141], 
             UndirectedEdge[13, 27] -> 
             RGBColor[
              0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`],
              UndirectedEdge[22, 99] -> 
             RGBColor[
              0.7475659285714287, 0.7149847142857143, 0.6120972142857143], 
             UndirectedEdge[73, 74] -> 
             RGBColor[0.571368, 0.41358321428571415`, 0.5688896428571428], 
             UndirectedEdge[8, 77] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`], 
             UndirectedEdge[36, 94] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714286, 0.6064375714285714], 
             UndirectedEdge[21, 87] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[59, 83] -> 
             RGBColor[
              0.8718352857142857, 0.5016841428571427, 0.2144070714285714], 
             UndirectedEdge[24, 42] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999999], 
             UndirectedEdge[33, 42] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 
             UndirectedEdge[14, 42] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 
             UndirectedEdge[45, 78] -> 
             RGBColor[
              0.8934179285714285, 0.8304337142857143, 0.6257149285714285], 
             UndirectedEdge[15, 38] -> 
             RGBColor[0.98246, 0.9520055714285713, 0.42802957142857123`], 
             UndirectedEdge[84, 85] -> 
             RGBColor[
              0.8720902142857143, 0.7421052857142857, 0.6083590714285714], 
             UndirectedEdge[55, 98] -> 
             RGBColor[
              0.8931629999999999, 0.5900125714285713, 0.23176292857142858`], 
             UndirectedEdge[86, 92] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.3548697142857141], 
             UndirectedEdge[72, 92] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 
             UndirectedEdge[19, 99] -> 
             RGBColor[0.6893302142857143, 0.39444414285714285`, 0.561414], 
             UndirectedEdge[4, 76] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`], 
             UndirectedEdge[23, 76] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[9, 72] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[2, 44] -> 
             RGBColor[
              0.7475659285714287, 0.7149847142857143, 0.6120972142857143], 
             UndirectedEdge[74, 88] -> 
             RGBColor[
              0.6419490714285714, 0.7070056428571428, 0.8469732857142858], 
             UndirectedEdge[21, 49] -> 
             RGBColor[0.586112, 0.6467326428571428, 0.7226495], 
             UndirectedEdge[21, 34] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.632953357142857], 
             UndirectedEdge[59, 66] -> 
             RGBColor[
              0.8718352857142857, 0.5016841428571427, 0.2144070714285714], 
             UndirectedEdge[17, 99] -> 
             RGBColor[
              0.7664822142857144, 0.7853505714285713, 0.6514355714285713], 
             UndirectedEdge[26, 53] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[23, 50] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999999], 
             UndirectedEdge[41, 74] -> 
             RGBColor[0.571368, 0.41358321428571415`, 0.5688896428571428], 
             UndirectedEdge[59, 79] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.37133535714285704`], 
             UndirectedEdge[56, 93] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[19, 98] -> 
             RGBColor[
              0.8755547142857143, 0.45466757142857145`, 0.2149012142857143], 
             UndirectedEdge[2, 38] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999999], 
             UndirectedEdge[19, 59] -> 
             RGBColor[
              0.8542270000000001, 0.3663391428571428, 0.19754535714285715`], 
             UndirectedEdge[24, 76] -> 
             RGBColor[
              0.9589912142857142, 0.8814695714285714, 0.5886137142857143], 
             UndirectedEdge[5, 20] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[37, 84] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[9, 82] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`], 
             UndirectedEdge[47, 75] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999999], 
             UndirectedEdge[51, 75] -> 
             RGBColor[0.9376635, 0.7931411428571429, 0.571257857142857], 
             UndirectedEdge[58, 63] -> 
             RGBColor[
              0.9120792857142856, 0.6603784285714285, 0.27110128571428566`], 
             UndirectedEdge[7, 25] -> 
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715], 
             UndirectedEdge[1, 55] -> 
             RGBColor[0.571368, 0.41358321428571415`, 0.5688896428571428], 
             UndirectedEdge[82, 86] -> 
             RGBColor[
              0.9120792857142856, 0.6603784285714285, 0.27110128571428566`], 
             UndirectedEdge[34, 71] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.632953357142857], 
             UndirectedEdge[41, 73] -> 
             RGBColor[
              0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`],
              UndirectedEdge[92, 94] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.37133535714285704`], 
             UndirectedEdge[3, 62] -> 
             RGBColor[
              0.9589912142857142, 0.8814695714285714, 0.5886137142857143], 
             UndirectedEdge[70, 75] -> 
             RGBColor[
              0.6371962142857143, 0.7050402142857143, 0.9257404285714286], 
             UndirectedEdge[57, 96] -> 
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715], 
             UndirectedEdge[68, 72] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[13, 54] -> 
             RGBColor[
              0.9183637857142857, 0.6962739999999998, 0.5547922142857142], 
             UndirectedEdge[48, 96] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.632953357142857], 
             UndirectedEdge[30, 50] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[11, 92] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 
             UndirectedEdge[41, 56] -> 
             RGBColor[
              0.8931629999999999, 0.5900125714285713, 0.23176292857142858`], 
             UndirectedEdge[73, 91] -> 
             RGBColor[
              0.9120792857142856, 0.6603784285714285, 0.27110128571428566`], 
             UndirectedEdge[32, 39] -> 
             RGBColor[
              0.9055083571428572, 0.5628944285714286, 0.45916335714285716`], 
             UndirectedEdge[32, 80] -> 
             RGBColor[
              0.8799727857142857, 0.5454292857142857, 0.5731102142857143], 
             UndirectedEdge[20, 66] -> 
             RGBColor[
              0.8975810714285715, 0.6807742857142856, 0.5899719285714285], 
             UndirectedEdge[47, 88] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.632953357142857], 
             UndirectedEdge[14, 53] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[51, 57] -> 
             RGBColor[
              0.9124627142857142, 0.6868797142857143, 0.24822857142857144`], 
             UndirectedEdge[30, 94] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.49249071428571434`], 
             UndirectedEdge[22, 69] -> 
             RGBColor[
              0.8931629999999999, 0.5900125714285713, 0.23176292857142858`], 
             UndirectedEdge[4, 94] -> 
             RGBColor[0.931379, 0.7572455714285713, 0.2875669285714285], 
             UndirectedEdge[4, 86] -> 
             RGBColor[
              0.9120792857142856, 0.6603784285714285, 0.27110128571428566`], 
             UndirectedEdge[9, 94] -> 
             RGBColor[
              0.9124627142857142, 0.6868797142857143, 0.24822857142857144`], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142857, 0.7488217142857141], 
             UndirectedEdge[12, 60] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714286, 0.6064375714285714], 
             UndirectedEdge[25, 40] -> 
             RGBColor[
              0.9124627142857142, 0.6868797142857143, 0.24822857142857144`], 
             UndirectedEdge[22, 95] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[3, 33] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[48, 93] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 
             UndirectedEdge[15, 90] -> 
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142857], 
             UndirectedEdge[77, 97] -> 
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142857], 
             UndirectedEdge[44, 78] -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 
             UndirectedEdge[30, 92] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.632953357142857], 
             UndirectedEdge[37, 76] -> 
             RGBColor[
              0.9589912142857142, 0.8814695714285714, 0.5886137142857143], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[75, 96] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[31, 80] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[85, 90] -> 
             RGBColor[0.8048095, 0.689277857142857, 0.6017240714285714], 
             UndirectedEdge[91, 93] -> 
             RGBColor[0.98246, 0.9520055714285713, 0.42802957142857123`], 
             UndirectedEdge[22, 49] -> 
             RGBColor[
              0.5563587142857143, 0.5403010714285714, 0.5995427142857144], 
             UndirectedEdge[69, 87] -> 
             RGBColor[
              0.8931629999999999, 0.5900125714285713, 0.23176292857142858`], 
             UndirectedEdge[47, 70] -> 
             RGBColor[
              0.6417487142857143, 0.7052103571428572, 0.7258179285714285], 
             UndirectedEdge[42, 78] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[1, 43] -> 
             RGBColor[
              0.6417487142857143, 0.7052103571428572, 0.7258179285714285], 
             UndirectedEdge[10, 35] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[67, 94] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.37133535714285704`], 
             UndirectedEdge[73, 93] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.3548697142857141], 
             UndirectedEdge[68, 82] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`], 
             UndirectedEdge[11, 52] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.37133535714285704`], 
             UndirectedEdge[15, 53] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`], 
             UndirectedEdge[53, 100] -> 
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715], 
             UndirectedEdge[58, 83] -> 
             RGBColor[
              0.9120792857142856, 0.6603784285714285, 0.27110128571428566`], 
             UndirectedEdge[74, 96] -> 
             RGBColor[
              0.6419490714285714, 0.7070056428571428, 0.8469732857142858], 
             UndirectedEdge[8, 87] -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 
             UndirectedEdge[43, 46] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[73, 89] -> 
             RGBColor[
              0.8931629999999999, 0.5900125714285713, 0.23176292857142858`], 
             UndirectedEdge[11, 67] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[98, 99] -> 
             RGBColor[
              0.7475659285714287, 0.7149847142857143, 0.6120972142857143], 
             UndirectedEdge[4, 9] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`], 
             UndirectedEdge[34, 49] -> 
             RGBColor[
              0.5863123571428571, 0.6485279285714286, 0.8438048571428571], 
             UndirectedEdge[6, 7] -> 
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715], 
             UndirectedEdge[7, 40] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.49249071428571434`], 
             UndirectedEdge[23, 85] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.37133535714285704`], 
             UndirectedEdge[82, 92] -> 
             RGBColor[0.98246, 0.9520055714285713, 0.42802957142857123`], 
             UndirectedEdge[34, 69] -> 
             RGBColor[
              0.9231166428571429, 0.6982394285714284, 0.4760250714285714], 
             UndirectedEdge[13, 85] -> 
             RGBColor[
              0.8718352857142857, 0.5016841428571427, 0.2144070714285714], 
             UndirectedEdge[95, 98] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[34, 87] -> 
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715], 
             UndirectedEdge[61, 94] -> 
             RGBColor[
              0.8718352857142857, 0.5016841428571427, 0.2144070714285714], 
             UndirectedEdge[61, 72] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.3548697142857141], 
             UndirectedEdge[50, 86] -> 
             RGBColor[
              0.9183637857142857, 0.6962739999999998, 0.5547922142857142], 
             UndirectedEdge[66, 97] -> 
             RGBColor[
              0.7855097857142856, 0.5924107142857142, 0.5852584285714286], 
             UndirectedEdge[9, 21] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[34, 60] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.49249071428571434`], 
             UndirectedEdge[53, 84] -> 
             RGBColor[
              0.8934179285714285, 0.8304337142857143, 0.6257149285714285], 
             UndirectedEdge[21, 22] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[14, 62] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999999], 
             UndirectedEdge[22, 30] -> 
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715], 
             UndirectedEdge[67, 72] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 
             UndirectedEdge[61, 86] -> 
             RGBColor[
              0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`],
              UndirectedEdge[5, 83] -> 
             RGBColor[
              0.9120792857142856, 0.6603784285714285, 0.27110128571428566`], 
             UndirectedEdge[46, 99] -> 
             RGBColor[
              0.7475659285714287, 0.7149847142857143, 0.6120972142857143], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.5563587142857143, 0.5403010714285714, 0.5995427142857144], 
             UndirectedEdge[7, 37] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[7, 53] -> 
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715], 
             UndirectedEdge[12, 52] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714286, 0.6064375714285714], 
             UndirectedEdge[50, 85] -> 
             RGBColor[0.9376635, 0.7931411428571429, 0.5712578571428572], 
             UndirectedEdge[14, 15] -> 
             RGBColor[0.98246, 0.9520055714285713, 0.42802957142857123`], 
             UndirectedEdge[14, 35] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857142], 
             UndirectedEdge[8, 95] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[7, 84] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[14, 76] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[60, 89] -> 
             RGBColor[
              0.9124627142857142, 0.6868797142857143, 0.24822857142857144`], 
             UndirectedEdge[37, 85] -> 
             RGBColor[0.9376635, 0.7931411428571429, 0.5712578571428572], 
             UndirectedEdge[39, 80] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[23, 24] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999999], 
             UndirectedEdge[11, 68] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[27, 81] -> 
             RGBColor[
              0.8718352857142857, 0.5016841428571427, 0.2144070714285714], 
             UndirectedEdge[36, 61] -> 
             RGBColor[
              0.8975810714285715, 0.6807742857142856, 0.5899719285714285], 
             UndirectedEdge[28, 59] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.37133535714285704`], 
             UndirectedEdge[8, 30] -> 
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715], 
             UndirectedEdge[34, 82] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[50, 84] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[57, 88] -> 
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715], 
             UndirectedEdge[6, 53] -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 
             UndirectedEdge[8, 69] -> 
             RGBColor[
              0.8931629999999999, 0.5900125714285713, 0.23176292857142858`], 
             UndirectedEdge[69, 99] -> 
             RGBColor[0.7069385, 0.5297891428571427, 0.5782757142857142], 
             UndirectedEdge[81, 84] -> 
             RGBColor[
              0.8720902142857143, 0.7421052857142857, 0.6083590714285714], 
             UndirectedEdge[11, 94] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.37133535714285704`], 
             UndirectedEdge[10, 65] -> 
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715], 
             UndirectedEdge[79, 98] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[33, 62] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999999], 
             UndirectedEdge[31, 70] -> 
             RGBColor[
              0.6419490714285714, 0.7070056428571428, 0.8469732857142858], 
             UndirectedEdge[31, 32] -> 
             RGBColor[
              0.9055083571428572, 0.5628944285714286, 0.45916335714285716`], 
             UndirectedEdge[15, 100] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[7, 65] -> 
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715], 
             UndirectedEdge[59, 95] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.37133535714285704`], 
             UndirectedEdge[2, 3] -> 
             RGBColor[
              0.7475659285714287, 0.7149847142857143, 0.6120972142857143], 
             UndirectedEdge[48, 88] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.632953357142857], 
             UndirectedEdge[14, 38] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 
             UndirectedEdge[44, 45] -> 
             RGBColor[
              0.8934179285714285, 0.8304337142857143, 0.6257149285714285], 
             UndirectedEdge[24, 50] -> RGBColor[0.984192, 0.987731, 0.911643],
              UndirectedEdge[38, 62] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999999], 
             UndirectedEdge[4, 50] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[48, 74] -> 
             RGBColor[
              0.6417487142857143, 0.7052103571428572, 0.7258179285714285], 
             UndirectedEdge[40, 100] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.4924907142857143], 
             UndirectedEdge[19, 95] -> 
             RGBColor[0.905308, 0.5610991428571428, 0.33800799999999986`], 
             UndirectedEdge[19, 79] -> 
             RGBColor[0.905308, 0.5610991428571428, 0.33800799999999986`], 
             UndirectedEdge[51, 70] -> 
             RGBColor[
              0.5906677142857143, 0.5104503571428571, 0.5853552857142856], 
             UndirectedEdge[17, 22] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`], 
             UndirectedEdge[59, 99] -> 
             RGBColor[
              0.7262382142857143, 0.6266562857142857, 0.594741357142857], 
             UndirectedEdge[20, 63] -> 
             RGBColor[
              0.8975810714285715, 0.6807742857142856, 0.5899719285714285], 
             UndirectedEdge[56, 89] -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 
             UndirectedEdge[12, 74] -> 
             RGBColor[0.6164135, 0.6895405, 0.9609201428571428], 
             UndirectedEdge[8, 17] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`], 
             UndirectedEdge[53, 90] -> 
             RGBColor[
              0.8261372142857143, 0.7776062857142858, 0.6190799285714286], 
             UndirectedEdge[21, 72] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 
             UndirectedEdge[48, 73] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.3548697142857141], 
             UndirectedEdge[8, 49] -> 
             RGBColor[
              0.5563587142857143, 0.5403010714285714, 0.5995427142857144], 
             UndirectedEdge[17, 69] -> 
             RGBColor[
              0.9120792857142856, 0.6603784285714285, 0.27110128571428566`], 
             UndirectedEdge[21, 82] -> 
             RGBColor[0.98246, 0.9520055714285713, 0.42802957142857123`], 
             UndirectedEdge[36, 68] -> 
             RGBColor[0.9382085, 0.8659698571428571, 0.6237934285714286], 
             UndirectedEdge[21, 30] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.632953357142857], 
             UndirectedEdge[56, 64] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[48, 64] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 
             UndirectedEdge[46, 59] -> 
             RGBColor[
              0.9124627142857142, 0.6868797142857143, 0.24822857142857144`], 
             UndirectedEdge[46, 79] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[9, 86] -> 
             RGBColor[
              0.8931629999999999, 0.5900125714285713, 0.23176292857142858`], 
             UndirectedEdge[64, 91] -> 
             RGBColor[0.98246, 0.9520055714285713, 0.42802957142857123`], 
             UndirectedEdge[1, 19] -> 
             RGBColor[
              0.5537597142857142, 0.27823821428571427`, 0.5520279285714286], 
             UndirectedEdge[5, 69] -> 
             RGBColor[
              0.9120792857142856, 0.6603784285714285, 0.27110128571428566`], 
             UndirectedEdge[36, 92] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857142], 
             UndirectedEdge[17, 95] -> 
             RGBColor[0.98246, 0.9520055714285713, 0.42802957142857123`], 
             UndirectedEdge[7, 13] -> 
             RGBColor[
              0.9231166428571429, 0.6982394285714284, 0.4760250714285714], 
             UndirectedEdge[11, 61] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.3548697142857141], 
             UndirectedEdge[66, 83] -> 
             RGBColor[
              0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`],
              UndirectedEdge[27, 37] -> 
             RGBColor[
              0.9183637857142857, 0.6962739999999998, 0.5547922142857142], 
             UndirectedEdge[22, 34] -> 
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715], 
             UndirectedEdge[6, 90] -> 
             RGBColor[
              0.8261372142857143, 0.7776062857142858, 0.6190799285714286], 
             UndirectedEdge[71, 77] -> 
             RGBColor[0.98246, 0.9520055714285713, 0.42802957142857123`], 
             UndirectedEdge[9, 68] -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 
             UndirectedEdge[23, 86] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.3548697142857141], 
             UndirectedEdge[54, 84] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[3, 16] -> 
             RGBColor[
              0.8934179285714285, 0.8304337142857143, 0.6257149285714285], 
             UndirectedEdge[66, 98] -> 
             RGBColor[
              0.8931629999999999, 0.5900125714285713, 0.23176292857142858`], 
             UndirectedEdge[64, 93] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 
             UndirectedEdge[2, 29] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[50, 81] -> 
             RGBColor[0.9376635, 0.7931411428571429, 0.5712578571428572], 
             UndirectedEdge[8, 99] -> 
             RGBColor[
              0.7475659285714287, 0.7149847142857143, 0.6120972142857143], 
             UndirectedEdge[66, 69] -> 
             RGBColor[
              0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`],
              UndirectedEdge[9, 30] -> 
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715], 
             UndirectedEdge[11, 36] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857142], 
             UndirectedEdge[16, 62] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[50, 76] -> 
             RGBColor[
              0.9589912142857142, 0.8814695714285714, 0.5886137142857143], 
             UndirectedEdge[36, 86] -> 
             RGBColor[
              0.8975810714285715, 0.6807742857142856, 0.5899719285714285], 
             UndirectedEdge[60, 71] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.37133535714285704`], 
             UndirectedEdge[43, 54] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999999], 
             UndirectedEdge[29, 42] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.632953357142857], 
             UndirectedEdge[76, 84] -> 
             RGBColor[
              0.8934179285714285, 0.8304337142857143, 0.6257149285714285], 
             UndirectedEdge[65, 90] -> 
             RGBColor[
              0.8261372142857143, 0.7776062857142858, 0.6190799285714286], 
             UndirectedEdge[52, 78] -> 
             RGBColor[
              0.9124627142857142, 0.6868797142857143, 0.24822857142857144`], 
             UndirectedEdge[25, 65] -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 
             UndirectedEdge[45, 52] -> 
             RGBColor[
              0.8720902142857143, 0.7421052857142857, 0.6083590714285714], 
             UndirectedEdge[57, 74] -> 
             RGBColor[
              0.6119954285714286, 0.5987787857142857, 0.6027111428571429], 
             UndirectedEdge[17, 66] -> 
             RGBColor[
              0.9120792857142856, 0.6603784285714285, 0.27110128571428566`], 
             UndirectedEdge[59, 98] -> 
             RGBColor[
              0.9124627142857142, 0.6868797142857143, 0.24822857142857144`], 
             UndirectedEdge[22, 77] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`], 
             UndirectedEdge[8, 82] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`], 
             UndirectedEdge[30, 36] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[60, 64] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.37133535714285704`], 
             UndirectedEdge[28, 99] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999999], 
             UndirectedEdge[59, 69] -> 
             RGBColor[
              0.8718352857142857, 0.5016841428571427, 0.2144070714285714], 
             UndirectedEdge[66, 79] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.3548697142857141], 
             UndirectedEdge[7, 81] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.49249071428571434`], 
             UndirectedEdge[26, 100] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.632953357142857], 
             UndirectedEdge[5, 97] -> 
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142857], 
             UndirectedEdge[20, 83] -> 
             RGBColor[
              0.8975810714285715, 0.6807742857142856, 0.5899719285714285], 
             UndirectedEdge[21, 92] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 
             UndirectedEdge[77, 98] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`], 
             UndirectedEdge[13, 84] -> 
             RGBColor[0.8527905, 0.6452381428571428, 0.5918934285714286], 
             UndirectedEdge[83, 97] -> 
             RGBColor[
              0.7855097857142856, 0.5924107142857142, 0.5852584285714286], 
             UndirectedEdge[4, 24] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[7, 85] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.49249071428571434`], 
             UndirectedEdge[10, 40] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.49249071428571434`], 
             UndirectedEdge[26, 40] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.37133535714285704`], 
             UndirectedEdge[56, 74] -> 
             RGBColor[
              0.6119954285714286, 0.5987787857142857, 0.6027111428571429], 
             UndirectedEdge[42, 62] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999999], 
             UndirectedEdge[4, 36] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[2, 33] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999999], 
             UndirectedEdge[36, 82] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142857], 
             UndirectedEdge[76, 81] -> 
             RGBColor[
              0.9124627142857142, 0.6868797142857143, 0.24822857142857144`], 
             UndirectedEdge[27, 43] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.3548697142857141], 
             UndirectedEdge[61, 67] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.3548697142857141], 
             UndirectedEdge[10, 26] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.632953357142857], 
             UndirectedEdge[63, 83] -> 
             RGBColor[
              0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`],
              UndirectedEdge[7, 54] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[20, 97] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[28, 98] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[4, 23] -> 
             RGBColor[0.98246, 0.9520055714285713, 0.42802957142857123`], 
             UndirectedEdge[30, 86] -> 
             RGBColor[
              0.9231166428571429, 0.6982394285714284, 0.4760250714285714], 
             UndirectedEdge[27, 54] -> 
             RGBColor[
              0.9183637857142857, 0.6962739999999998, 0.5547922142857142], 
             UndirectedEdge[1, 13] -> 
             RGBColor[0.571368, 0.41358321428571415`, 0.5688896428571428], 
             UndirectedEdge[15, 35] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142855], 
             UndirectedEdge[56, 73] -> 
             RGBColor[
              0.8931629999999999, 0.5900125714285713, 0.23176292857142858`], 
             UndirectedEdge[16, 29] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[53, 65] -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 
             UndirectedEdge[6, 25] -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 
             UndirectedEdge[68, 92] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[69, 97] -> 
             RGBColor[
              0.7855097857142856, 0.5924107142857142, 0.5852584285714286], 
             UndirectedEdge[17, 77] -> 
             RGBColor[0.971623, 0.9159398571428571, 0.34426114285714277`], 
             UndirectedEdge[46, 98] -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[17, 55] -> 
             RGBColor[
              0.9120792857142856, 0.6603784285714285, 0.27110128571428566`], 
             UndirectedEdge[2, 78] -> 
             RGBColor[
              0.7475659285714287, 0.7149847142857143, 0.6120972142857143], 
             UndirectedEdge[6, 35] -> 
             RGBColor[0.9382085, 0.8659698571428571, 0.6237934285714286], 
             UndirectedEdge[95, 99] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999999], 
             UndirectedEdge[66, 99] -> 
             RGBColor[0.7069385, 0.5297891428571427, 0.5782757142857142], 
             UndirectedEdge[31, 39] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[69, 71] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.3548697142857141], 
             UndirectedEdge[64, 89] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[40, 53] -> 
             RGBColor[
              0.9124627142857142, 0.6868797142857143, 0.24822857142857144`], 
             UndirectedEdge[1, 27] -> 
             RGBColor[0.571368, 0.41358321428571415`, 0.5688896428571428], 
             UndirectedEdge[41, 48] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.3548697142857141], 
             UndirectedEdge[57, 70] -> 
             RGBColor[
              0.6119954285714286, 0.5987787857142857, 0.6027111428571429], 
             UndirectedEdge[39, 44] -> 
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715], 
             UndirectedEdge[6, 15] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`], 
             UndirectedEdge[6, 40] -> 
             RGBColor[
              0.9124627142857142, 0.6868797142857143, 0.24822857142857144`], 
             UndirectedEdge[17, 59] -> 
             RGBColor[0.931379, 0.7572455714285713, 0.2875669285714285], 
             UndirectedEdge[56, 91] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`], 
             UndirectedEdge[5, 59] -> 
             RGBColor[0.931379, 0.7572455714285713, 0.2875669285714285], 
             UndirectedEdge[20, 58] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857143, 0.6631317857142857], 
             UndirectedEdge[17, 19] -> 
             RGBColor[0.894471, 0.5250334285714285, 0.2542395714285714], 
             UndirectedEdge[3, 38] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[1, 17] -> 
             RGBColor[
              0.6309117142857144, 0.6691446428571428, 0.6420494999999999], 
             UndirectedEdge[2, 42] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999999], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857142], 
             UndirectedEdge[48, 56] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[86, 94] -> 
             RGBColor[
              0.8718352857142857, 0.5016841428571427, 0.2144070714285714], 
             UndirectedEdge[23, 30] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.632953357142857], 
             UndirectedEdge[30, 82] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[60, 74] -> 
             RGBColor[
              0.5906677142857143, 0.5104503571428571, 0.5853552857142856], 
             UndirectedEdge[10, 90] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[49, 69] -> 
             RGBColor[
              0.5157312857142857, 0.35510549999999985`, 0.5657212142857143], 
             UndirectedEdge[25, 100] -> 
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.9124627142857142, 0.6868797142857143, 0.24822857142857144`], 
             UndirectedEdge[31, 51] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.49249071428571434`], 
             UndirectedEdge[37, 50] -> RGBColor[0.984192, 0.987731, 0.911643],
              UndirectedEdge[6, 10] -> 
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715], 
             UndirectedEdge[69, 77] -> 
             RGBColor[
              0.9120792857142856, 0.6603784285714285, 0.27110128571428566`], 
             UndirectedEdge[12, 96] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[12, 41] -> 
             RGBColor[
              0.8975810714285715, 0.6807742857142856, 0.5899719285714285], 
             UndirectedEdge[89, 93] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[37, 81] -> 
             RGBColor[0.9376635, 0.7931411428571429, 0.5712578571428572], 
             UndirectedEdge[14, 24] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999999], 
             UndirectedEdge[52, 67] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.37133535714285704`], 
             UndirectedEdge[23, 27] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.3548697142857141], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857142], 
             UndirectedEdge[23, 81] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.37133535714285704`], 
             UndirectedEdge[88, 96] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[77, 95] -> 
             RGBColor[0.98246, 0.9520055714285713, 0.42802957142857123`], 
             UndirectedEdge[74, 91] -> 
             RGBColor[
              0.6309117142857144, 0.6691446428571428, 0.6420494999999999], 
             UndirectedEdge[7, 100] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.9231166428571429, 0.6982394285714284, 0.4760250714285715], 
             UndirectedEdge[6, 100] -> 
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715], 
             UndirectedEdge[19, 55] -> 
             RGBColor[
              0.8349272857142858, 0.2694719999999999, 0.1810797142857143], 
             UndirectedEdge[17, 28] -> 
             RGBColor[0.98246, 0.9520055714285713, 0.42802957142857123`], 
             UndirectedEdge[64, 96] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.632953357142857], 
             UndirectedEdge[67, 68] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[22, 87] -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 
             UndirectedEdge[42, 44] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[70, 96] -> 
             RGBColor[
              0.6419490714285714, 0.7070056428571428, 0.8469732857142858], 
             UndirectedEdge[64, 88] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.632953357142857], 
             UndirectedEdge[26, 65] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[2, 14] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999999], 
             UndirectedEdge[11, 72] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 
             UndirectedEdge[67, 86] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.3548697142857141], 
             UndirectedEdge[40, 90] -> 
             RGBColor[0.8048095, 0.689277857142857, 0.6017240714285714], 
             UndirectedEdge[27, 84] -> 
             RGBColor[0.8527905, 0.6452381428571428, 0.5918934285714286], 
             UndirectedEdge[13, 43] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.3548697142857141], 
             UndirectedEdge[52, 72] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.37133535714285704`], 
             UndirectedEdge[10, 53] -> 
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715], 
             UndirectedEdge[15, 40] -> 
             RGBColor[0.931379, 0.7572455714285713, 0.2875669285714285], 
             UndirectedEdge[21, 68] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[28, 83] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.3548697142857141], 
             UndirectedEdge[54, 100] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[47, 96] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.632953357142857], 
             UndirectedEdge[47, 51] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.37133535714285704`], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[39, 45] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[58, 97] -> 
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142857], 
             UndirectedEdge[31, 45] -> 
             RGBColor[
              0.9233715714285715, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[6, 26] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[41, 91] -> 
             RGBColor[
              0.9120792857142856, 0.6603784285714285, 0.27110128571428566`], 
             UndirectedEdge[8, 22] -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 
             UndirectedEdge[46, 95] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[66, 95] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.3548697142857141], 
             UndirectedEdge[23, 37] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999999], 
             UndirectedEdge[10, 100] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[5, 79] -> 
             RGBColor[0.98246, 0.9520055714285713, 0.42802957142857123`], 
             UndirectedEdge[38, 42] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 
             UndirectedEdge[40, 54] -> 
             RGBColor[0.9376635, 0.7931411428571429, 0.571257857142857], 
             UndirectedEdge[32, 45] -> 
             RGBColor[
              0.8351822142857144, 0.5098931428571429, 0.5750317142857143], 
             UndirectedEdge[41, 60] -> 
             RGBColor[
              0.8718352857142857, 0.5016841428571427, 0.2144070714285714], 
             UndirectedEdge[88, 91] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[47, 57] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[27, 85] -> 
             RGBColor[
              0.8718352857142857, 0.5016841428571427, 0.2144070714285714], 
             UndirectedEdge[69, 95] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.3548697142857141], 
             UndirectedEdge[36, 72] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857142], 
             UndirectedEdge[6, 65] -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 
             UndirectedEdge[49, 77] -> 
             RGBColor[0.575275, 0.6106669285714286, 0.6388810714285714], 
             UndirectedEdge[2, 62] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[22, 66] -> 
             RGBColor[
              0.8931629999999999, 0.5900125714285713, 0.23176292857142858`], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.7857647142857143, 0.8328318571428572, 0.9792104285714285], 
             UndirectedEdge[73, 88] -> 
             RGBColor[
              0.9231166428571429, 0.6982394285714284, 0.4760250714285715], 
             UndirectedEdge[8, 21] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[31, 75] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[4, 30] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[48, 91] -> 
             RGBColor[0.98246, 0.9520055714285713, 0.42802957142857123`], 
             UndirectedEdge[19, 28] -> 
             RGBColor[0.905308, 0.5610991428571428, 0.33800799999999986`], 
             UndirectedEdge[28, 66] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.3548697142857141], 
             UndirectedEdge[3, 29] -> 
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715], 
             UndirectedEdge[22, 82] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`], 
             UndirectedEdge[49, 82] -> 
             RGBColor[0.575275, 0.6106669285714286, 0.6388810714285714], 
             UndirectedEdge[23, 84] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142857, 0.7488217142857141], 
             UndirectedEdge[65, 100] -> 
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715], 
             UndirectedEdge[53, 85] -> 
             RGBColor[
              0.9124627142857142, 0.6868797142857143, 0.24822857142857144`], 
             UndirectedEdge[59, 97] -> 
             RGBColor[0.8048095, 0.689277857142857, 0.6017240714285714], 
             UndirectedEdge[17, 98] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`], 
             UndirectedEdge[61, 68] -> 
             RGBColor[
              0.8931629999999999, 0.5900125714285713, 0.23176292857142858`], 
             UndirectedEdge[28, 55] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.3548697142857141], 
             UndirectedEdge[9, 36] -> 
             RGBColor[0.9382085, 0.8659698571428571, 0.6237934285714286], 
             UndirectedEdge[20, 59] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714286, 0.6064375714285714], 
             UndirectedEdge[48, 57] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[1, 46] -> 
             RGBColor[
              0.6119954285714286, 0.5987787857142857, 0.6027111428571429], 
             UndirectedEdge[5, 66] -> 
             RGBColor[
              0.9120792857142856, 0.6603784285714285, 0.27110128571428566`], 
             UndirectedEdge[64, 74] -> 
             RGBColor[
              0.6417487142857143, 0.7052103571428572, 0.7258179285714285], 
             UndirectedEdge[55, 79] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.3548697142857141], 
             UndirectedEdge[32, 51] -> 
             RGBColor[
              0.8542270000000001, 0.3663391428571428, 0.19754535714285715`], 
             UndirectedEdge[64, 73] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.3548697142857141], 
             UndirectedEdge[35, 38] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857142], 
             UndirectedEdge[71, 87] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[82, 87] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`], 
             UndirectedEdge[5, 77] -> 
             RGBColor[0.971623, 0.9159398571428571, 0.34426114285714277`], 
             UndirectedEdge[57, 64] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[63, 97] -> 
             RGBColor[
              0.7855097857142856, 0.5924107142857142, 0.5852584285714286], 
             UndirectedEdge[41, 93] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.3548697142857141], 
             UndirectedEdge[9, 61] -> 
             RGBColor[
              0.8931629999999999, 0.5900125714285713, 0.23176292857142858`], 
             UndirectedEdge[17, 46] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`], 
             UndirectedEdge[25, 54] -> 
             RGBColor[
              0.9589912142857142, 0.8814695714285714, 0.5886137142857143], 
             UndirectedEdge[59, 77] -> 
             RGBColor[0.931379, 0.7572455714285713, 0.2875669285714285], 
             UndirectedEdge[66, 77] -> 
             RGBColor[
              0.9120792857142856, 0.6603784285714285, 0.27110128571428566`], 
             UndirectedEdge[7, 27] -> 
             RGBColor[
              0.9231166428571429, 0.6982394285714284, 0.4760250714285714], 
             UndirectedEdge[61, 92] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.3548697142857141], 
             UndirectedEdge[77, 87] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`], 
             UndirectedEdge[28, 79] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 
             UndirectedEdge[5, 28] -> 
             RGBColor[0.98246, 0.9520055714285713, 0.42802957142857123`], 
             UndirectedEdge[56, 88] -> 
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715], 
             UndirectedEdge[25, 26] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[9, 67] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[32, 44] -> 
             RGBColor[
              0.8755547142857143, 0.45466757142857145`, 0.2149012142857143], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857142], 
             UndirectedEdge[79, 83] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.3548697142857141], 
             UndirectedEdge[60, 93] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.37133535714285704`], 
             UndirectedEdge[5, 63] -> 
             RGBColor[
              0.9120792857142856, 0.6603784285714285, 0.27110128571428566`], 
             UndirectedEdge[19, 66] -> 
             RGBColor[
              0.8349272857142858, 0.2694719999999999, 0.1810797142857143], 
             UndirectedEdge[8, 86] -> 
             RGBColor[
              0.8931629999999999, 0.5900125714285713, 0.23176292857142858`], 
             UndirectedEdge[4, 37] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714286, 0.6279520714285713], 
             UndirectedEdge[9, 92] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[3, 42] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[7, 90] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[35, 62] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[20, 79] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.7469002142857142], 
             UndirectedEdge[31, 78] -> 
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715], 
             UndirectedEdge[13, 81] -> 
             RGBColor[
              0.8718352857142857, 0.5016841428571427, 0.2144070714285714], 
             UndirectedEdge[18, 80] -> 
             RGBColor[0.9382085, 0.8659698571428571, 0.6237934285714286], 
             UndirectedEdge[90, 100] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[67, 92] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 
             UndirectedEdge[55, 66] -> 
             RGBColor[
              0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`],
              UndirectedEdge[89, 91] -> 
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`], 
             UndirectedEdge[46, 55] -> 
             RGBColor[
              0.8931629999999999, 0.5900125714285713, 0.23176292857142858`], 
             UndirectedEdge[41, 64] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.3548697142857141], 
             UndirectedEdge[28, 46] -> 
             RGBColor[
              0.9635437142857143, 0.8816397142857143, 0.3886912142857142], 
             UndirectedEdge[35, 53] -> 
             RGBColor[0.9382085, 0.8659698571428571, 0.6237934285714286], 
             UndirectedEdge[35, 90] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[5, 58] -> 
             RGBColor[0.971623, 0.9159398571428571, 0.34426114285714277`], 
             UndirectedEdge[76, 85] -> 
             RGBColor[
              0.9124627142857142, 0.6868797142857143, 0.24822857142857144`], 
             UndirectedEdge[34, 77] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428571, 0.5491849285714285], 
             UndirectedEdge[49, 71] -> 
             RGBColor[0.586112, 0.6467326428571429, 0.7226495]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 25 -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 55 -> 
             RGBColor[
              0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`],
              90 -> RGBColor[
              0.718484, 0.7800044285714286, 0.9725754285714285], 27 -> 
             RGBColor[
              0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`],
              15 -> RGBColor[
              0.971623, 0.9159398571428571, 0.34426114285714277`], 98 -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 38 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 99 -> 
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861], 71 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 41 -> 
             RGBColor[
              0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`],
              75 -> RGBColor[0.984192, 0.987731, 0.911643], 64 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 63 -> 
             RGBColor[
              0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`],
              85 -> RGBColor[
              0.891135, 0.5985512857142856, 0.23087271428571426`], 3 -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 86 -> 
             RGBColor[
              0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`],
              94 -> RGBColor[
              0.891135, 0.5985512857142856, 0.23087271428571426`], 61 -> 
             RGBColor[
              0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`],
              84 -> RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714285], 76 -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 21 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 87 -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 95 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 72 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 42 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 66 -> 
             RGBColor[
              0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`],
              1 -> RGBColor[
              0.2902004285714286, 0.42234942857142854`, 0.9398378571428572], 
             24 -> RGBColor[0.984192, 0.987731, 0.911643], 54 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 4 -> 
             RGBColor[0.971623, 0.9159398571428571, 0.34426114285714277`], 7 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             100 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 12 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 65 -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 8 -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 57 -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 74 -> 
             RGBColor[
              0.2902004285714286, 0.42234942857142854`, 0.9398378571428572], 
             37 -> RGBColor[0.984192, 0.987731, 0.911643], 43 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 39 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 58 -> 
             RGBColor[0.971623, 0.9159398571428571, 0.34426114285714277`], 11 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 51 -> 
             RGBColor[0.891135, 0.5985512857142856, 0.23087271428571426`], 48 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 20 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 33 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 45 -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714285], 23 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 22 -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 2 -> 
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861], 60 -> 
             RGBColor[0.891135, 0.5985512857142856, 0.23087271428571426`], 16 -> 
             RGBColor[
              0.8530454285714286, 0.8856592857142858, 0.9858454285714285], 79 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 89 -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 36 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 52 -> 
             RGBColor[0.891135, 0.5985512857142856, 0.23087271428571426`], 32 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 31 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 68 -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 73 -> 
             RGBColor[
              0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`],
              82 -> RGBColor[
              0.971623, 0.9159398571428571, 0.34426114285714277`], 35 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 88 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 50 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 19 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 17 -> 
             RGBColor[0.971623, 0.9159398571428571, 0.34426114285714277`], 96 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 14 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 5 -> 
             RGBColor[0.971623, 0.9159398571428571, 0.34426114285714277`], 34 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 97 -> 
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285], 93 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 81 -> 
             RGBColor[0.891135, 0.5985512857142856, 0.23087271428571426`], 69 -> 
             RGBColor[
              0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`],
              9 -> RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 13 -> 
             RGBColor[
              0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`],
              30 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 59 -> 
             RGBColor[0.891135, 0.5985512857142856, 0.23087271428571426`], 28 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 80 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 47 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 62 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 77 -> 
             RGBColor[0.971623, 0.9159398571428571, 0.34426114285714277`], 78 -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 40 -> 
             RGBColor[0.891135, 0.5985512857142856, 0.23087271428571426`], 67 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 56 -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 10 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 53 -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 26 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 18 -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 29 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 92 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998], 46 -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 49 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 83 -> 
             RGBColor[
              0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`],
              70 -> RGBColor[
              0.2902004285714286, 0.42234942857142854`, 0.9398378571428572], 
             44 -> RGBColor[
              0.9337904285714286, 0.7752081428571429, 0.2655844285714286], 91 -> 
             RGBColor[0.971623, 0.9159398571428571, 0.34426114285714277`], 6 -> 
             RGBColor[
              0.9337904285714286, 0.7752081428571429, 
               0.2655844285714286]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9lHs01Akbx4dhXCZmRjNjDGZ+vxEpY003Oez6fWm7uFSIpJWyrGvrtqF9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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 13}], {
             RGBColor[0.571368, 0.41358321428571415`, 0.5688896428571428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 17}], {
             RGBColor[
             0.6309117142857144, 0.6691446428571428, 0.6420494999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 19}], {
             RGBColor[
             0.5537597142857142, 0.27823821428571427`, 0.5520279285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 27}], {
             RGBColor[0.571368, 0.41358321428571415`, 0.5688896428571428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 43}], {
             RGBColor[
             0.6417487142857143, 0.7052103571428572, 0.7258179285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 46}], {
             RGBColor[
             0.6119954285714286, 0.5987787857142857, 0.6027111428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 55}], {
             RGBColor[0.571368, 0.41358321428571415`, 0.5688896428571428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 3}], {
             RGBColor[
             0.7475659285714287, 0.7149847142857143, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 14}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 29}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 33}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 38}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 42}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 44}], {
             RGBColor[
             0.7475659285714287, 0.7149847142857143, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 62}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 78}], {
             RGBColor[
             0.7475659285714287, 0.7149847142857143, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 16}], {
             RGBColor[
             0.8934179285714285, 0.8304337142857143, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 29}], {
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 33}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 38}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 42}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 62}], {
             RGBColor[
             0.9589912142857142, 0.8814695714285714, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 9}], {
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 23}], {
             RGBColor[0.98246, 0.9520055714285713, 0.42802957142857123`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 24}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 30}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 36}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 37}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 50}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 76}], {
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 86}], {
             RGBColor[
             0.9120792857142856, 0.6603784285714285, 0.27110128571428566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 94}], {
             RGBColor[0.931379, 0.7572455714285713, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 20}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 28}], {
             RGBColor[0.98246, 0.9520055714285713, 0.42802957142857123`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 58}], {
             RGBColor[0.971623, 0.9159398571428571, 0.34426114285714277`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[0.931379, 0.7572455714285713, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 63}], {
             RGBColor[
             0.9120792857142856, 0.6603784285714285, 0.27110128571428566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 66}], {
             RGBColor[
             0.9120792857142856, 0.6603784285714285, 0.27110128571428566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 69}], {
             RGBColor[
             0.9120792857142856, 0.6603784285714285, 0.27110128571428566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[0.971623, 0.9159398571428571, 0.34426114285714277`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 79}], {
             RGBColor[0.98246, 0.9520055714285713, 0.42802957142857123`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[
             0.9120792857142856, 0.6603784285714285, 0.27110128571428566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 97}], {
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 7}], {
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 10}], {
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 15}], {
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 25}], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 26}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 35}], {
             RGBColor[0.9382085, 0.8659698571428571, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 40}], {
             RGBColor[
             0.9124627142857142, 0.6868797142857143, 0.24822857142857144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 65}], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 90}], {
             RGBColor[
             0.8261372142857143, 0.7776062857142858, 0.6190799285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 100}], {
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 13}], {
             RGBColor[
             0.9231166428571429, 0.6982394285714284, 0.4760250714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 25}], {
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 27}], {
             RGBColor[
             0.9231166428571429, 0.6982394285714284, 0.4760250714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 37}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 40}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 53}], {
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 65}], {
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 81}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 85}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 90}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 100}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 17}], {
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 22}], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 30}], {
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 49}], {
             RGBColor[
             0.5563587142857143, 0.5403010714285714, 0.5995427142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 69}], {
             RGBColor[
             0.8931629999999999, 0.5900125714285713, 0.23176292857142858`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 77}], {
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 86}], {
             RGBColor[
             0.8931629999999999, 0.5900125714285713, 0.23176292857142858`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 87}], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 95}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 99}], {
             RGBColor[
             0.7475659285714287, 0.7149847142857143, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 21}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 30}], {
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 36}], {
             RGBColor[0.9382085, 0.8659698571428571, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 61}], {
             RGBColor[
             0.8931629999999999, 0.5900125714285713, 0.23176292857142858`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 67}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 68}], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 72}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 82}], {
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 86}], {
             RGBColor[
             0.8931629999999999, 0.5900125714285713, 0.23176292857142858`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 92}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 94}], {
             RGBColor[
             0.9124627142857142, 0.6868797142857143, 0.24822857142857144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 26}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.632953357142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 35}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 40}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 53}], {
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 65}], {
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 90}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 100}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 36}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 52}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.37133535714285704`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 61}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.3548697142857141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 67}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 68}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 72}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 92}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 94}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.37133535714285704`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 41}], {
             RGBColor[
             0.8975810714285715, 0.6807742857142856, 0.5899719285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 52}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714286, 0.6064375714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 60}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714286, 0.6064375714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 74}], {
             RGBColor[0.6164135, 0.6895405, 0.9609201428571428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 88}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 96}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 27}], {
             RGBColor[
             0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 43}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.3548697142857141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 54}], {
             RGBColor[
             0.9183637857142857, 0.6962739999999998, 0.5547922142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 81}], {
             RGBColor[
             0.8718352857142857, 0.5016841428571427, 0.2144070714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 84}], {
             RGBColor[0.8527905, 0.6452381428571428, 0.5918934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 85}], {
             RGBColor[
             0.8718352857142857, 0.5016841428571427, 0.2144070714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 15}], {
             RGBColor[0.98246, 0.9520055714285713, 0.42802957142857123`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 24}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 35}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 38}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 42}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 53}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 62}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 76}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 35}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 38}], {
             RGBColor[0.98246, 0.9520055714285713, 0.42802957142857123`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 40}], {
             RGBColor[0.931379, 0.7572455714285713, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 53}], {
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714286, 0.6279520714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 90}], {
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 100}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 29}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142857, 0.7488217142857141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 62}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 19}], {
             RGBColor[0.894471, 0.5250334285714285, 0.2542395714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 22}], {
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 28}], {
             RGBColor[0.98246, 0.9520055714285713, 0.42802957142857123`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 46}], {
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 55}], {
             RGBColor[
             0.9120792857142856, 0.6603784285714285, 0.27110128571428566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 59}], {
             RGBColor[0.931379, 0.7572455714285713, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 66}], {
             RGBColor[
             0.9120792857142856, 0.6603784285714285, 0.27110128571428566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 69}], {
             RGBColor[
             0.9120792857142856, 0.6603784285714285, 0.27110128571428566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 77}], {
             RGBColor[0.971623, 0.9159398571428571, 0.34426114285714277`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 79}], {
             RGBColor[0.98246, 0.9520055714285713, 0.42802957142857123`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 95}], {
             RGBColor[0.98246, 0.9520055714285713, 0.42802957142857123`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 98}], {
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.7664822142857144, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 80}], {
             RGBColor[0.9382085, 0.8659698571428571, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 28}], {
             RGBColor[0.905308, 0.5610991428571428, 0.33800799999999986`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 43}], {
             RGBColor[0.905308, 0.5610991428571428, 0.33800799999999986`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 46}], {
             RGBColor[
             0.8755547142857143, 0.45466757142857145`, 0.2149012142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 55}], {
             RGBColor[
             0.8349272857142858, 0.2694719999999999, 0.1810797142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 59}], {
             RGBColor[
             0.8542270000000001, 0.3663391428571428, 0.19754535714285715`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 66}], {
             RGBColor[
             0.8349272857142858, 0.2694719999999999, 0.1810797142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 79}], {
             RGBColor[0.905308, 0.5610991428571428, 0.33800799999999986`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 95}], {
             RGBColor[0.905308, 0.5610991428571428, 0.33800799999999986`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 98}], {
             RGBColor[
             0.8755547142857143, 0.45466757142857145`, 0.2149012142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 99}], {
             RGBColor[0.6893302142857143, 0.39444414285714285`, 0.561414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 58}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 59}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714286, 0.6064375714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 63}], {
             RGBColor[
             0.8975810714285715, 0.6807742857142856, 0.5899719285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 66}], {
             RGBColor[
             0.8975810714285715, 0.6807742857142856, 0.5899719285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 79}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 83}], {
             RGBColor[
             0.8975810714285715, 0.6807742857142856, 0.5899719285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 97}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 22}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 30}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.632953357142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 34}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.632953357142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 49}], {
             RGBColor[0.586112, 0.6467326428571428, 0.7226495]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{21, 68}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 72}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 82}], {
             RGBColor[0.98246, 0.9520055714285713, 0.42802957142857123`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 92}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 30}], {
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 34}], {
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 49}], {
             RGBColor[
             0.5563587142857143, 0.5403010714285714, 0.5995427142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 66}], {
             RGBColor[
             0.8931629999999999, 0.5900125714285713, 0.23176292857142858`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 69}], {
             RGBColor[
             0.8931629999999999, 0.5900125714285713, 0.23176292857142858`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 77}], {
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 82}], {
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 87}], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 95}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 99}], {
             RGBColor[
             0.7475659285714287, 0.7149847142857143, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 24}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 27}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.3548697142857141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 30}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.632953357142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 37}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 50}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 76}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.37133535714285704`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 84}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142857, 0.7488217142857141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 85}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.37133535714285704`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 86}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.3548697142857141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 42}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 50}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 76}], {
             RGBColor[
             0.9589912142857142, 0.8814695714285714, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 26}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 40}], {
             RGBColor[
             0.9124627142857142, 0.6868797142857143, 0.24822857142857144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 54}], {
             RGBColor[
             0.9589912142857142, 0.8814695714285714, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 65}], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 100}], {
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 40}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.37133535714285704`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 53}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 65}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 90}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.632953357142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 37}], {
             RGBColor[
             0.9183637857142857, 0.6962739999999998, 0.5547922142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 43}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.3548697142857141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 54}], {
             RGBColor[
             0.9183637857142857, 0.6962739999999998, 0.5547922142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 81}], {
             RGBColor[
             0.8718352857142857, 0.5016841428571427, 0.2144070714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 84}], {
             RGBColor[0.8527905, 0.6452381428571428, 0.5918934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 85}], {
             RGBColor[
             0.8718352857142857, 0.5016841428571427, 0.2144070714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 46}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 55}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.3548697142857141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 59}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.37133535714285704`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 66}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.3548697142857141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 79}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 83}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.3548697142857141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 98}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 99}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 33}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.632953357142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 38}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.632953357142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 42}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.632953357142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 36}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 50}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 82}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 86}], {
             RGBColor[
             0.9231166428571429, 0.6982394285714284, 0.4760250714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 92}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.632953357142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 94}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 32}], {
             RGBColor[
             0.9055083571428572, 0.5628944285714286, 0.45916335714285716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 39}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 44}], {
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 45}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 51}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 70}], {
             RGBColor[
             0.6419490714285714, 0.7070056428571428, 0.8469732857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 75}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 78}], {
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 80}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 39}], {
             RGBColor[
             0.9055083571428572, 0.5628944285714286, 0.45916335714285716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 44}], {
             RGBColor[
             0.8755547142857143, 0.45466757142857145`, 0.2149012142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 45}], {
             RGBColor[
             0.8351822142857144, 0.5098931428571429, 0.5750317142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 51}], {
             RGBColor[
             0.8542270000000001, 0.3663391428571428, 0.19754535714285715`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 80}], {
             RGBColor[
             0.8799727857142857, 0.5454292857142857, 0.5731102142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 42}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 62}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 49}], {
             RGBColor[
             0.5863123571428571, 0.6485279285714286, 0.8438048571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 60}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 69}], {
             RGBColor[
             0.9231166428571429, 0.6982394285714284, 0.4760250714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 71}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.632953357142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 77}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 82}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 87}], {
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 38}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 53}], {
             RGBColor[0.9382085, 0.8659698571428571, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 62}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 90}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 61}], {
             RGBColor[
             0.8975810714285715, 0.6807742857142856, 0.5899719285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 67}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 68}], {
             RGBColor[0.9382085, 0.8659698571428571, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 72}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 82}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857143, 0.6631317857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 86}], {
             RGBColor[
             0.8975810714285715, 0.6807742857142856, 0.5899719285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 92}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.7469002142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 94}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714286, 0.6064375714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 50}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 76}], {
             RGBColor[
             0.9589912142857142, 0.8814695714285714, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 81}], {
             RGBColor[0.9376635, 0.7931411428571429, 0.5712578571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 84}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 85}], {
             RGBColor[0.9376635, 0.7931411428571429, 0.5712578571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 42}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 62}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 44}], {
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 45}], {
             RGBColor[
             0.9233715714285715, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 80}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 53}], {
             RGBColor[
             0.9124627142857142, 0.6868797142857143, 0.24822857142857144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 54}], {
             RGBColor[0.9376635, 0.7931411428571429, 0.571257857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.9124627142857142, 0.6868797142857143, 0.24822857142857144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 90}], {
             RGBColor[0.8048095, 0.689277857142857, 0.6017240714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 100}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.4924907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 48}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.3548697142857141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 56}], {
             RGBColor[
             0.8931629999999999, 0.5900125714285713, 0.23176292857142858`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 60}], {
             RGBColor[
             0.8718352857142857, 0.5016841428571427, 0.2144070714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 64}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.3548697142857141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 73}], {
             RGBColor[
             0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 74}], {
             RGBColor[0.571368, 0.41358321428571415`, 0.5688896428571428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.9231166428571429, 0.6982394285714284, 0.4760250714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 91}], {
             RGBColor[
             0.9120792857142856, 0.6603784285714285, 0.27110128571428566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 93}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.3548697142857141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 44}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 62}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 78}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 46}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 54}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 45}], {
             RGBColor[
             0.8934179285714285, 0.8304337142857143, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 78}], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 52}], {
             RGBColor[
             0.8720902142857143, 0.7421052857142857, 0.6083590714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 78}], {
             RGBColor[
             0.8934179285714285, 0.8304337142857143, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 55}], {
             RGBColor[
             0.8931629999999999, 0.5900125714285713, 0.23176292857142858`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 59}], {
             RGBColor[
             0.9124627142857142, 0.6868797142857143, 0.24822857142857144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 79}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 95}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 98}], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 99}], {
             RGBColor[
             0.7475659285714287, 0.7149847142857143, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 51}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.37133535714285704`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 57}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 70}], {
             RGBColor[
             0.6417487142857143, 0.7052103571428572, 0.7258179285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 74}], {
             RGBColor[
             0.6417487142857143, 0.7052103571428572, 0.7258179285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 75}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 88}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.632953357142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.632953357142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 56}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 57}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 64}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 73}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.3548697142857141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 74}], {
             RGBColor[
             0.6417487142857143, 0.7052103571428572, 0.7258179285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 88}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.632953357142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 91}], {
             RGBColor[0.98246, 0.9520055714285713, 0.42802957142857123`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 93}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 96}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.632953357142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 69}], {
             RGBColor[
             0.5157312857142857, 0.35510549999999985`, 0.5657212142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 71}], {
             RGBColor[0.586112, 0.6467326428571429, 0.7226495]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{49, 77}], {
             RGBColor[0.575275, 0.6106669285714286, 0.6388810714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 82}], {
             RGBColor[0.575275, 0.6106669285714286, 0.6388810714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.5563587142857143, 0.5403010714285714, 0.5995427142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 76}], {
             RGBColor[
             0.9589912142857142, 0.8814695714285714, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 81}], {
             RGBColor[0.9376635, 0.7931411428571429, 0.5712578571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 84}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 85}], {
             RGBColor[0.9376635, 0.7931411428571429, 0.5712578571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 86}], {
             RGBColor[
             0.9183637857142857, 0.6962739999999998, 0.5547922142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 57}], {
             RGBColor[
             0.9124627142857142, 0.6868797142857143, 0.24822857142857144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 70}], {
             RGBColor[
             0.5906677142857143, 0.5104503571428571, 0.5853552857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 75}], {
             RGBColor[0.9376635, 0.7931411428571429, 0.571257857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 67}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.37133535714285704`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 68}], {
             RGBColor[
             0.9124627142857142, 0.6868797142857143, 0.24822857142857144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 72}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.37133535714285704`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 78}], {
             RGBColor[
             0.9124627142857142, 0.6868797142857143, 0.24822857142857144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 65}], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 84}], {
             RGBColor[
             0.8934179285714285, 0.8304337142857143, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 85}], {
             RGBColor[
             0.9124627142857142, 0.6868797142857143, 0.24822857142857144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 90}], {
             RGBColor[
             0.8261372142857143, 0.7776062857142858, 0.6190799285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 100}], {
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 84}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 100}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 59}], {
             RGBColor[
             0.8718352857142857, 0.5016841428571427, 0.2144070714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 66}], {
             RGBColor[
             0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 79}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.3548697142857141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 98}], {
             RGBColor[
             0.8931629999999999, 0.5900125714285713, 0.23176292857142858`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 99}], {
             RGBColor[0.7069385, 0.5297891428571427, 0.5782757142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 64}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 73}], {
             RGBColor[
             0.8931629999999999, 0.5900125714285713, 0.23176292857142858`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 74}], {
             RGBColor[
             0.6119954285714286, 0.5987787857142857, 0.6027111428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 88}], {
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 89}], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 91}], {
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 93}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 64}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 70}], {
             RGBColor[
             0.6119954285714286, 0.5987787857142857, 0.6027111428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 74}], {
             RGBColor[
             0.6119954285714286, 0.5987787857142857, 0.6027111428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 75}], {
             RGBColor[
             0.9589912142857142, 0.8814695714285714, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 88}], {
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 96}], {
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 63}], {
             RGBColor[
             0.9120792857142856, 0.6603784285714285, 0.27110128571428566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 83}], {
             RGBColor[
             0.9120792857142856, 0.6603784285714285, 0.27110128571428566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 97}], {
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 66}], {
             RGBColor[
             0.8718352857142857, 0.5016841428571427, 0.2144070714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 69}], {
             RGBColor[
             0.8718352857142857, 0.5016841428571427, 0.2144070714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 77}], {
             RGBColor[0.931379, 0.7572455714285713, 0.2875669285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 79}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.37133535714285704`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 83}], {
             RGBColor[
             0.8718352857142857, 0.5016841428571427, 0.2144070714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 95}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.37133535714285704`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 97}], {
             RGBColor[0.8048095, 0.689277857142857, 0.6017240714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 98}], {
             RGBColor[
             0.9124627142857142, 0.6868797142857143, 0.24822857142857144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 99}], {
             RGBColor[
             0.7262382142857143, 0.6266562857142857, 0.594741357142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 64}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.37133535714285704`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 71}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.37133535714285704`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 74}], {
             RGBColor[
             0.5906677142857143, 0.5104503571428571, 0.5853552857142856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 89}], {
             RGBColor[
             0.9124627142857142, 0.6868797142857143, 0.24822857142857144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 93}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.37133535714285704`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 67}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.3548697142857141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 68}], {
             RGBColor[
             0.8931629999999999, 0.5900125714285713, 0.23176292857142858`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 72}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.3548697142857141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 86}], {
             RGBColor[
             0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 92}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.3548697142857141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 94}], {
             RGBColor[
             0.8718352857142857, 0.5016841428571427, 0.2144070714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 83}], {
             RGBColor[
             0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 97}], {
             RGBColor[
             0.7855097857142856, 0.5924107142857142, 0.5852584285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 73}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.3548697142857141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 74}], {
             RGBColor[
             0.6417487142857143, 0.7052103571428572, 0.7258179285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 88}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.632953357142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 89}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 91}], {
             RGBColor[0.98246, 0.9520055714285713, 0.42802957142857123`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 93}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 96}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.632953357142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 90}], {
             RGBColor[
             0.8261372142857143, 0.7776062857142858, 0.6190799285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 100}], {
             RGBColor[0.9637440714285714, 0.883435, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 69}], {
             RGBColor[
             0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 77}], {
             RGBColor[
             0.9120792857142856, 0.6603784285714285, 0.27110128571428566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 79}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.3548697142857141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 83}], {
             RGBColor[
             0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 95}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.3548697142857141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 97}], {
             RGBColor[
             0.7855097857142856, 0.5924107142857142, 0.5852584285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[
             0.8931629999999999, 0.5900125714285713, 0.23176292857142858`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 99}], {
             RGBColor[0.7069385, 0.5297891428571427, 0.5782757142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 68}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 72}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 86}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.3548697142857141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 92}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 94}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.37133535714285704`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 72}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 82}], {
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 92}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 71}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.3548697142857141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 77}], {
             RGBColor[
             0.9120792857142856, 0.6603784285714285, 0.27110128571428566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 87}], {
             RGBColor[
             0.8931629999999999, 0.5900125714285713, 0.23176292857142858`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 95}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.3548697142857141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 97}], {
             RGBColor[
             0.7855097857142856, 0.5924107142857142, 0.5852584285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 98}], {
             RGBColor[
             0.8931629999999999, 0.5900125714285713, 0.23176292857142858`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 99}], {
             RGBColor[0.7069385, 0.5297891428571427, 0.5782757142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 75}], {
             RGBColor[
             0.6371962142857143, 0.7050402142857143, 0.9257404285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 96}], {
             RGBColor[
             0.6419490714285714, 0.7070056428571428, 0.8469732857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 77}], {
             RGBColor[0.98246, 0.9520055714285713, 0.42802957142857123`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 87}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 82}], {
             RGBColor[0.98246, 0.9520055714285713, 0.42802957142857123`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 92}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 74}], {
             RGBColor[0.571368, 0.41358321428571415`, 0.5688896428571428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 88}], {
             RGBColor[
             0.9231166428571429, 0.6982394285714284, 0.4760250714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.8931629999999999, 0.5900125714285713, 0.23176292857142858`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 91}], {
             RGBColor[
             0.9120792857142856, 0.6603784285714285, 0.27110128571428566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 93}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.3548697142857141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 88}], {
             RGBColor[
             0.6419490714285714, 0.7070056428571428, 0.8469732857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 91}], {
             RGBColor[
             0.6309117142857144, 0.6691446428571428, 0.6420494999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 96}], {
             RGBColor[
             0.6419490714285714, 0.7070056428571428, 0.8469732857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 96}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 81}], {
             RGBColor[
             0.9124627142857142, 0.6868797142857143, 0.24822857142857144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 84}], {
             RGBColor[
             0.8934179285714285, 0.8304337142857143, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 85}], {
             RGBColor[
             0.9124627142857142, 0.6868797142857143, 0.24822857142857144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 87}], {
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 95}], {
             RGBColor[0.98246, 0.9520055714285713, 0.42802957142857123`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 97}], {
             RGBColor[0.8450535, 0.8479721428571428, 0.6584182857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 98}], {
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 99}], {
             RGBColor[
             0.7664822142857144, 0.7853505714285713, 0.6514355714285713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 83}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.3548697142857141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 98}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 99}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 84}], {
             RGBColor[
             0.8720902142857143, 0.7421052857142857, 0.6083590714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 85}], {
             RGBColor[0.891135, 0.5985512857142856, 0.23087271428571426`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 86}], {
             RGBColor[
             0.9120792857142856, 0.6603784285714285, 0.27110128571428566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 87}], {
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 92}], {
             RGBColor[0.98246, 0.9520055714285713, 0.42802957142857123`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 97}], {
             RGBColor[
             0.7855097857142856, 0.5924107142857142, 0.5852584285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 85}], {
             RGBColor[
             0.8720902142857143, 0.7421052857142857, 0.6083590714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.7857647142857143, 0.8328318571428572, 0.9792104285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 90}], {
             RGBColor[0.8048095, 0.689277857142857, 0.6017240714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 92}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.3548697142857141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[
             0.8718352857142857, 0.5016841428571427, 0.2144070714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 91}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 96}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 91}], {
             RGBColor[0.9527067142857143, 0.845574, 0.30492278571428566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 93}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 100}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 93}], {
             RGBColor[0.98246, 0.9520055714285713, 0.42802957142857123`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 96}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428571, 0.5491849285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 94}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.37133535714285704`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 98}], {
             RGBColor[
             0.9635437142857143, 0.8816397142857143, 0.3886912142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 99}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 99}], {
             RGBColor[
             0.7475659285714287, 0.7149847142857143, 0.6120972142857143]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.058168352269944726`], {
             RGBColor[
             0.2902004285714286, 0.42234942857142854`, 0.9398378571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.058168352269944726`], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.058168352269944726`], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.058168352269944726`], {
             RGBColor[0.971623, 0.9159398571428571, 0.34426114285714277`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.058168352269944726`], {
             RGBColor[0.971623, 0.9159398571428571, 0.34426114285714277`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.058168352269944726`], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.058168352269944726`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.058168352269944726`], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.058168352269944726`], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.058168352269944726`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.058168352269944726`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.058168352269944726`], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.058168352269944726`], {
             RGBColor[
             0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.058168352269944726`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.058168352269944726`], {
             RGBColor[0.971623, 0.9159398571428571, 0.34426114285714277`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.058168352269944726`], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.058168352269944726`], {
             RGBColor[0.971623, 0.9159398571428571, 0.34426114285714277`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.058168352269944726`], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.058168352269944726`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.058168352269944726`], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.058168352269944726`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.058168352269944726`], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.058168352269944726`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.058168352269944726`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.058168352269944726`], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.058168352269944726`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.058168352269944726`], {
             RGBColor[
             0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.058168352269944726`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.058168352269944726`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.058168352269944726`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.058168352269944726`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.058168352269944726`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.058168352269944726`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.058168352269944726`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.058168352269944726`], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.058168352269944726`], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.058168352269944726`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.058168352269944726`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.058168352269944726`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.058168352269944726`], {
             RGBColor[0.891135, 0.5985512857142856, 0.23087271428571426`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.058168352269944726`], {
             RGBColor[
             0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.058168352269944726`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.058168352269944726`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.058168352269944726`], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.058168352269944726`], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.058168352269944726`], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.058168352269944726`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.058168352269944726`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.058168352269944726`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.058168352269944726`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.058168352269944726`], {
             RGBColor[0.891135, 0.5985512857142856, 0.23087271428571426`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.058168352269944726`], {
             RGBColor[0.891135, 0.5985512857142856, 0.23087271428571426`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.058168352269944726`], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.058168352269944726`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.058168352269944726`], {
             RGBColor[
             0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.058168352269944726`], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.058168352269944726`], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.058168352269944726`], {
             RGBColor[0.971623, 0.9159398571428571, 0.34426114285714277`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.058168352269944726`], {
             RGBColor[0.891135, 0.5985512857142856, 0.23087271428571426`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.058168352269944726`], {
             RGBColor[0.891135, 0.5985512857142856, 0.23087271428571426`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.058168352269944726`], {
             RGBColor[
             0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.058168352269944726`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.058168352269944726`], {
             RGBColor[
             0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.058168352269944726`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.058168352269944726`], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.058168352269944726`], {
             RGBColor[
             0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.058168352269944726`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.058168352269944726`], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.058168352269944726`], {
             RGBColor[
             0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.058168352269944726`], {
             RGBColor[
             0.2902004285714286, 0.42234942857142854`, 0.9398378571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.058168352269944726`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.058168352269944726`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.058168352269944726`], {
             RGBColor[
             0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.058168352269944726`], {
             RGBColor[
             0.2902004285714286, 0.42234942857142854`, 0.9398378571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.058168352269944726`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.058168352269944726`], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.058168352269944726`], {
             RGBColor[0.971623, 0.9159398571428571, 0.34426114285714277`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.058168352269944726`], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.058168352269944726`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.058168352269944726`], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.058168352269944726`], {
             RGBColor[0.891135, 0.5985512857142856, 0.23087271428571426`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.058168352269944726`], {
             RGBColor[0.971623, 0.9159398571428571, 0.34426114285714277`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.058168352269944726`], {
             RGBColor[
             0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.058168352269944726`], {
             RGBColor[
             0.8530454285714286, 0.8856592857142858, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.058168352269944726`], {
             RGBColor[0.891135, 0.5985512857142856, 0.23087271428571426`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.058168352269944726`], {
             RGBColor[
             0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.058168352269944726`], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.058168352269944726`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.058168352269944726`], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.058168352269944726`], {
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.058168352269944726`], {
             RGBColor[0.971623, 0.9159398571428571, 0.34426114285714277`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.058168352269944726`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.058168352269944726`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.058168352269944726`], {
             RGBColor[0.891135, 0.5985512857142856, 0.23087271428571426`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.058168352269944726`], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.058168352269944726`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.058168352269944726`], {
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.058168352269944726`], {
             RGBColor[
             0.9337904285714286, 0.7752081428571429, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.058168352269944726`], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.058168352269944726`], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100}, {
          Null, CompressedData["
1:eJwVxVmbqQwAAOCxVtbppLIkW4w1a5YJk8gSaaRCIqr783/Pr/me7715C/Zf
xfZ+fHz883x8/D9363DUk1oFBOGSrgbkKTe9Ubr+DJzlM67jGn44aCN55AiO
7OTWuWMuH0qHqrVObVrjcvv1PnbAe71DT+vplLkyddN8hkqxEiiAOngBnQA/
4nmBl/kz71Cz2Wqmz8zZE8QwHhOwC+aAKIqhFLpCL6gZpsKz8Cpshp+ghVm8
JViWU9t1dtxud0NGCI/IiIU4oXgsHi/Fq3gmo3kQT8YzygyrQz/up/w9/8Gv
+58BCZQwiZcESbpIluT8+c395n89MAjDCIzBI5iHBViCZdiCncDPzznXz/f7
6/6+Nu6Mx9x4N755Y96s9xj4/v75PnvrsXq2Xj/6SZBESYzESZIie6ROmuQz
5MbdtFt1h+5nNkDABEIQI4InZOJMOOEtuqW2s+1quzU9NEwjNEHTI1qmLdpp
99vr9t5fxsuZcrlXPpS19qvz4l7r1/6Fqxm1rPbUoXpQVc1b+CxkC4V67dF5
jB/TB/fYPW6PXCvfah1r1/a1cx1fuevuen2l0qlqaphy0SJWLE6LQlEqXjzR
aCY6jKpRLfeV//pqff3WxLbYEcfiVOTEnShexZenEW0gjUyjQTeG3maumW9+
NevNZqt5DC+p5Wy5XC23S31pLp/+ZCyJJ5P1ZC95AKJACsgAZaAKDAEV0AAX
7KJdrFvsdoWu1L3U7p37+M7dd3fxfr3f7vfH/RV4f79/3vxbeEvv8xswQkbc
SBslo2qohmYYbhAIhoLxYCqYDpaC1aARdIub7ma6ETYbaXMJsDCLsARLsyOW
5VmBlViZPbMW+2Yd7zw2j88/59l5YV6a1+eBRIJIfCfYxE+CT8iJc+IdXACL
0CK1SC+qi4WxcEEFVTCFVIoKpXSVlbJVFF25KCZsIzZh0/bIZm3eFmzJlm3L
th1vJVaJV7KVUqVSr8zDg9ZgsBysBtvBEThFT/gpcyqfeqfD6aSetCADMCEm
xsSZNFNiqgyzYFRGYwzGbU86k/5kwk3WE3Gyn1wnL6/P9+nL+gq+iq/um0dq
kUFkGuEiYuQaefkhKAyhEAlR0AxaQitoCymQDpnQ8z9pR8GG
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[69, 98] -> 
             RGBColor[
              0.35934722090825977`, 0.48438990088158124`, 0.9441651443282024],
              UndirectedEdge[29, 33] -> 
             RGBColor[
              0.29422509162390786`, 0.4255184180648389, 0.9401059109878009], 
             UndirectedEdge[55, 59] -> 
             RGBColor[
              0.26182384182735224`, 0.39252383672388913`, 0.9382218525071802],
              UndirectedEdge[47, 74] -> 
             RGBColor[
              0.31904494583740095`, 0.4476628644149205, 0.9416637299737558], 
             UndirectedEdge[19, 43] -> 
             RGBColor[
              0.25864725898215624`, 0.389185046746603, 0.9380409508134795], 
             UndirectedEdge[57, 75] -> 
             RGBColor[
              0.25952031121468844`, 0.390102679997703, 0.9380906698465571], 
             UndirectedEdge[19, 46] -> 
             RGBColor[
              0.2688995810964162, 0.39996088732345647`, 0.9386248053909352], 
             UndirectedEdge[36, 67] -> 
             RGBColor[
              0.18042977836149893`, 0.3069735153395867, 0.9335865810045261], 
             UndirectedEdge[79, 99] -> 
             RGBColor[
              0.3231374521934327, 0.4482183313765927, 0.9420339521780562], 
             UndirectedEdge[52, 68] -> 
             RGBColor[
              0.8780291995303775, 0.46447808085033465`, 0.21689224319720418`],
              UndirectedEdge[81, 85] -> 
             RGBColor[
              0.5777440554332705, 0.6680776771306483, 0.9599012748713662], 
             UndirectedEdge[12, 88] -> 
             RGBColor[
              0.44729833605503005`, 0.5559100353701449, 0.9509297720791202], 
             UndirectedEdge[72, 82] -> 
             RGBColor[
              0.8344620499016556, 0.2658959936764921, 0.180634203946131], 
             UndirectedEdge[31, 44] -> 
             RGBColor[
              0.5893518598321712, 0.6739738751825308, 0.9626393731710036], 
             UndirectedEdge[17, 79] -> 
             RGBColor[
              0.3156295526433677, 0.44171536614432994`, 0.9415555554577009], 
             UndirectedEdge[91, 96] -> 
             RGBColor[
              0.269451185257078, 0.40054065827003577`, 0.9386562184318596], 
             UndirectedEdge[55, 99] -> 
             RGBColor[
              0.32604506358539376`, 0.45127441530275375`, 0.9421995363454028],
              UndirectedEdge[77, 99] -> 
             RGBColor[
              0.4105884153235183, 0.5300527814046032, 0.9473833086487027], 
             UndirectedEdge[29, 38] -> 
             RGBColor[
              0.3762188058276783, 0.5002835531261081, 0.9451933075234802], 
             UndirectedEdge[26, 90] -> 
             RGBColor[
              0.2640863311664119, 0.39490185646935017`, 0.9383506979279865], 
             UndirectedEdge[13, 27] -> 
             RGBColor[
              0.30786109230723857`, 0.43780476345745334`, 0.9409573735218479],
              UndirectedEdge[22, 99] -> 
             RGBColor[
              0.6824515754881706, 0.7473171966554524, 0.9484738769221548], 
             UndirectedEdge[73, 74] -> 
             RGBColor[
              0.3072565676292452, 0.4352725314918011, 0.940992399274144], 
             UndirectedEdge[8, 77] -> 
             RGBColor[
              0.6903471893885933, 0.7540727058376107, 0.9477616322002713], 
             UndirectedEdge[36, 94] -> 
             RGBColor[
              0.1800640484055534, 0.3065891099672694, 0.9335657532245839], 
             UndirectedEdge[21, 87] -> 
             RGBColor[
              0.8461475149580568, 0.7442097533956613, 0.6102686063858478], 
             UndirectedEdge[59, 83] -> 
             RGBColor[
              0.24944682557751796`, 0.3795148078971581, 0.9375169997419068], 
             UndirectedEdge[24, 42] -> 
             RGBColor[
              0.7818518898687528, 0.7011631313519644, 0.6053992543639326], 
             UndirectedEdge[33, 42] -> 
             RGBColor[
              0.46221511877127164`, 0.5653020306816455, 0.952477193383617], 
             UndirectedEdge[14, 42] -> 
             RGBColor[
              0.6875842561639678, 0.755865313839969, 0.9694956308803766], 
             UndirectedEdge[45, 78] -> 
             RGBColor[
              0.8888960529642432, 0.9113695171236152, 0.8624721274568261], 
             UndirectedEdge[15, 38] -> 
             RGBColor[
              0.3740760297515814, 0.49842758818805, 0.9450567717266938], 
             UndirectedEdge[84, 85] -> 
             RGBColor[
              0.5258992134513589, 0.6255397259320082, 0.9559436352420423], 
             UndirectedEdge[55, 98] -> 
             RGBColor[
              0.2718017456530969, 0.4030112462803886, 0.9387900793690704], 
             UndirectedEdge[86, 92] -> 
             RGBColor[
              0.5898473968790202, 0.652327074257428, 0.8461866592841044], 
             UndirectedEdge[72, 92] -> 
             RGBColor[
              0.5088521381215928, 0.27790300442365007`, 0.5558317972580653], 
             UndirectedEdge[19, 99] -> 
             RGBColor[
              0.33504481922143936`, 0.46073372909370225`, 0.9427120591149303],
              UndirectedEdge[4, 76] -> 
             RGBColor[
              0.9165776385018892, 0.6448130127141793, 0.40538275488353814`], 
             UndirectedEdge[23, 76] -> 
             RGBColor[
              0.9905483291850934, 0.9895519766020239, 0.7476033518841813], 
             UndirectedEdge[9, 72] -> 
             RGBColor[
              0.8914135512087347, 0.5438293614385904, 0.22874208440602506`], 
             UndirectedEdge[2, 44] -> 
             RGBColor[
              0.6476158835940419, 0.7227173201002071, 0.9668276779841867], 
             UndirectedEdge[74, 88] -> 
             RGBColor[
              0.3260233854984479, 0.4549976469573106, 0.9420611417887761], 
             UndirectedEdge[21, 49] -> 
             RGBColor[
              0.8381155029968219, 0.7379350846059927, 0.6094680504969712], 
             UndirectedEdge[21, 34] -> 
             RGBColor[
              0.7440489383777218, 0.6635696741320418, 0.6006939636333543], 
             UndirectedEdge[59, 66] -> 
             RGBColor[
              0.2986049435975745, 0.4299329425040255, 0.9403622564770246], 
             UndirectedEdge[17, 99] -> 
             RGBColor[
              0.3958768319210234, 0.5173103472870436, 0.9464458995632381], 
             UndirectedEdge[26, 53] -> 
             RGBColor[
              0.27181647740875625`, 0.40165680145894234`, 0.9388410781260154],
              UndirectedEdge[23, 50] -> 
             RGBColor[
              0.9890507904475296, 0.9897402347152724, 0.831120268137828], 
             UndirectedEdge[41, 74] -> 
             RGBColor[
              0.39624144168094344`, 0.517626153935267, 0.9464691321747285], 
             UndirectedEdge[59, 79] -> 
             RGBColor[
              0.2589162304353912, 0.38946775279772805`, 0.9380562683398335], 
             UndirectedEdge[56, 93] -> 
             RGBColor[
              0.251058389952088, 0.3812086642339142, 0.9376087759489427], 
             UndirectedEdge[19, 98] -> 
             RGBColor[
              0.2808015012891425, 0.4124705600713371, 0.9393026021385978], 
             UndirectedEdge[2, 38] -> 
             RGBColor[
              0.4744745540542128, 0.5836658197325597, 0.9519298496562583], 
             UndirectedEdge[19, 59] -> 
             RGBColor[
              0.2708235974633978, 0.40198315051483763`, 0.9387343752767077], 
             UndirectedEdge[24, 76] -> 
             RGBColor[
              0.9509230096039614, 0.8306452679372385, 0.4351994673534736], 
             UndirectedEdge[5, 20] -> 
             RGBColor[
              0.23580229552736498`, 0.3651735417012756, 0.9367399639408238], 
             UndirectedEdge[37, 84] -> 
             RGBColor[
              0.5813861978869495, 0.66930600772412, 0.9611872941941962], 
             UndirectedEdge[9, 82] -> 
             RGBColor[
              0.8944306469902588, 0.5670200817151858, 0.2316312587337348], 
             UndirectedEdge[47, 75] -> 
             RGBColor[
              0.2704352603663721, 0.40157498360386956`, 0.9387122600535251], 
             UndirectedEdge[51, 75] -> 
             RGBColor[
              0.2631874052799758, 0.3939570283675128, 0.9382995054285956], 
             UndirectedEdge[58, 63] -> 
             RGBColor[
              0.22145736040975994`, 0.3500961053712548, 0.9359230411073061], 
             UndirectedEdge[7, 25] -> 
             RGBColor[
              0.2646919276847649, 0.3951010487472052, 0.9384011984763869], 
             UndirectedEdge[1, 55] -> 
             RGBColor[
              0.25340680094735984`, 0.3836769930878019, 0.9377425144809607], 
             UndirectedEdge[82, 86] -> 
             RGBColor[
              0.9154573086590831, 0.64032006351027, 0.4709890659721701], 
             UndirectedEdge[34, 71] -> 
             RGBColor[
              0.46781157980336074`, 0.5760433128989255, 0.9520168308232597], 
             UndirectedEdge[41, 73] -> 
             RGBColor[
              0.34062966364440406`, 0.46417862987955394`, 0.9431189034415599],
              UndirectedEdge[92, 94] -> 
             RGBColor[
              0.18353386454932197`, 0.3102361067334203, 0.9337633541208386], 
             UndirectedEdge[3, 62] -> 
             RGBColor[
              0.3326644235069168, 0.4616841238673607, 0.9424500919629462], 
             UndirectedEdge[70, 75] -> 
             RGBColor[
              0.2709835768789808, 0.4021512990238961, 0.9387434858677567], 
             UndirectedEdge[57, 96] -> 
             RGBColor[
              0.26925290833864535`, 0.40033225665728034`, 0.9386449268546793],
              UndirectedEdge[68, 72] -> 
             RGBColor[
              0.8243819770600658, 0.1884161366999483, 0.17098151480921064`], 
             UndirectedEdge[13, 54] -> 
             RGBColor[
              0.26215076948672145`, 0.392867458422297, 0.938240470553735], 
             UndirectedEdge[48, 96] -> 
             RGBColor[
              0.2710430288508906, 0.402213786815846, 0.9387468715696057], 
             UndirectedEdge[30, 50] -> 
             RGBColor[
              0.9048589996840575, 0.566437416695873, 0.47911193415723874`], 
             UndirectedEdge[11, 92] -> 
             RGBColor[
              0.21022995471211395`, 0.3382953901243926, 0.9352836569622833], 
             UndirectedEdge[41, 56] -> 
             RGBColor[
              0.3357366265014662, 0.459035737605853, 0.9428402522148693], 
             UndirectedEdge[73, 91] -> 
             RGBColor[
              0.25271649556761044`, 0.3829514383657963, 0.9377032026107992], 
             UndirectedEdge[32, 39] -> 
             RGBColor[
              0.2935264779562271, 0.4258453173585629, 0.9400272707348724], 
             UndirectedEdge[32, 80] -> 
             RGBColor[
              0.2808572092204622, 0.41252911263924097`, 0.939305774622874], 
             UndirectedEdge[20, 66] -> 
             RGBColor[
              0.271765998365242, 0.4017235093774315, 0.9388338182507047], 
             UndirectedEdge[47, 88] -> 
             RGBColor[
              0.28219998567006427`, 0.41394045582471695`, 0.9393822437552191],
              UndirectedEdge[14, 53] -> 
             RGBColor[
              0.5212638853795565, 0.6175278736453831, 0.9572307375115887], 
             UndirectedEdge[51, 57] -> 
             RGBColor[
              0.25705874177093724`, 0.3875154144398035, 0.9379504871083011], 
             UndirectedEdge[30, 94] -> 
             RGBColor[
              0.4995877733317956, 0.224777469479577, 0.549414921546451], 
             UndirectedEdge[22, 69] -> 
             RGBColor[
              0.6926573828576388, 0.7561569540400923, 0.9491241819430962], 
             UndirectedEdge[4, 94] -> 
             RGBColor[
              0.5098088734120636, 0.30334132361113186`, 0.5592026585263972], 
             UndirectedEdge[4, 86] -> 
             RGBColor[
              0.9161224057417618, 0.6454322911351396, 0.4716259636896631], 
             UndirectedEdge[9, 94] -> 
             RGBColor[
              0.566095277636464, 0.5761624637483606, 0.6066736412687983], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.25232882209907226`, 0.38254396897044507`, 0.9376811251802775],
              UndirectedEdge[12, 60] -> 
             RGBColor[
              0.5377449711891708, 0.6356046186030777, 0.9567524004381972], 
             UndirectedEdge[25, 40] -> 
             RGBColor[
              0.22979823437354924`, 0.35886289274915106`, 0.9363980415403266],
              UndirectedEdge[22, 95] -> 
             RGBColor[
              0.7735850344334367, 0.822659249453164, 0.9552736235962966], 
             UndirectedEdge[3, 33] -> 
             RGBColor[
              0.283755346452618, 0.41557523862275036`, 0.9394708192508354], 
             UndirectedEdge[48, 93] -> 
             RGBColor[
              0.2586149766637431, 0.3891511159831336, 0.9380391123832033], 
             UndirectedEdge[15, 90] -> 
             RGBColor[
              0.3120203774346074, 0.44461862031594124`, 0.9411048183197483], 
             UndirectedEdge[77, 97] -> 
             RGBColor[
              0.3343295626774611, 0.4586498895325537, 0.9427200995394867], 
             UndirectedEdge[44, 78] -> 
             RGBColor[
              0.88634546706693, 0.9093769800354632, 0.8622179088911622], 
             UndirectedEdge[30, 92] -> 
             RGBColor[
              0.5023132309055276, 0.22764209819356024`, 0.5495701323233219], 
             UndirectedEdge[37, 76] -> 
             RGBColor[
              0.8601494153237335, 0.8880770205793902, 0.7996440970661025], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.5927913677992559, 0.604221747139333, 0.6081939441102431], 
             UndirectedEdge[75, 96] -> 
             RGBColor[
              0.27538157184768386`, 0.40677387058498965`, 0.9389939451749738],
              UndirectedEdge[31, 80] -> 
             RGBColor[
              0.33469414166217204`, 0.4606589391956579, 0.9426813312926726], 
             UndirectedEdge[85, 90] -> 
             RGBColor[
              0.4615407941261787, 0.5697362170178263, 0.951844951557591], 
             UndirectedEdge[91, 93] -> 
             RGBColor[
              0.2570231330699305, 0.38747798743732337`, 0.9379484592454572], 
             UndirectedEdge[22, 49] -> 
             RGBColor[
              0.8672856751894109, 0.8967275864503471, 0.9640189035929849], 
             UndirectedEdge[69, 87] -> 
             RGBColor[
              0.6064566505030319, 0.6883381284885098, 0.9639201838642415], 
             UndirectedEdge[47, 70] -> 
             RGBColor[
              0.27576986252162594`, 0.40718198870235345`, 0.9390160577544302],
              UndirectedEdge[42, 78] -> 
             RGBColor[
              0.8251990022368825, 0.8616088969798854, 0.8561234007231051], 
             UndirectedEdge[1, 43] -> 
             RGBColor[
              0.25434890859377146`, 0.3846672079572553, 0.9377961661177004], 
             UndirectedEdge[10, 35] -> 
             RGBColor[
              0.2769526708149095, 0.4084251952129716, 0.9390834169369247], 
             UndirectedEdge[67, 94] -> 
             RGBColor[
              0.18117413693153547`, 0.3077558833917543, 0.9336289711239099], 
             UndirectedEdge[73, 93] -> 
             RGBColor[
              0.2559514270950259, 0.38635155650761516`, 0.9378874271756332], 
             UndirectedEdge[68, 82] -> 
             RGBColor[
              0.8273990728415899, 0.2116068569765438, 0.1738706891369204], 
             UndirectedEdge[11, 52] -> 
             RGBColor[
              0.5864699931809645, 0.5791596032510256, 0.6031076177106328], 
             UndirectedEdge[15, 53] -> 
             RGBColor[
              0.3197505236769518, 0.4513735653055334, 0.9415951985177772], 
             UndirectedEdge[53, 100] -> 
             RGBColor[
              0.2844126072753804, 0.4148961325895252, 0.9395584090876155], 
             UndirectedEdge[58, 83] -> 
             RGBColor[
              0.22400482828107066`, 0.3527736556227943, 0.9360681156339361], 
             UndirectedEdge[74, 96] -> 
             RGBColor[
              0.3239912573187127, 0.45286175139604057`, 0.9419454150952044], 
             UndirectedEdge[8, 87] -> 
             RGBColor[
              0.8760096171986388, 0.9035182955368775, 0.9636482023948687], 
             UndirectedEdge[43, 46] -> 
             RGBColor[
              0.2608419331067822, 0.3914917884019613, 0.9381659342581474], 
             UndirectedEdge[73, 89] -> 
             RGBColor[
              0.24808487338589558`, 0.37808330979100657`, 0.9374394385794216],
              UndirectedEdge[11, 67] -> 
             RGBColor[
              0.20787022709432745`, 0.3358151667827266, 0.9351492739653546], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.28368193490479854`, 0.4148331204560798, 0.9394909859406446], 
             UndirectedEdge[98, 99] -> 
             RGBColor[
              0.3491414135387916, 0.47555014349694125`, 0.943514839307261], 
             UndirectedEdge[4, 9] -> 
             RGBColor[
              0.8950957440729377, 0.5721323093400554, 0.23226815645122778`], 
             UndirectedEdge[34, 49] -> 
             RGBColor[
              0.678986366254469, 0.7482686816351451, 0.9692402627616367], 
             UndirectedEdge[6, 7] -> 
             RGBColor[
              0.2850997356690481, 0.41655094886844685`, 0.9395633929504454], 
             UndirectedEdge[7, 40] -> 
             RGBColor[
              0.2785823850167328, 0.4097008001089655, 0.9391922394723524], 
             UndirectedEdge[23, 85] -> 
             RGBColor[
              0.8008648229179952, 0.8435478591637703, 0.9160354539398804], 
             UndirectedEdge[82, 92] -> 
             RGBColor[
              0.5118692339031169, 0.30109372470024554`, 0.558720971585775], 
             UndirectedEdge[34, 69] -> 
             RGBColor[
              0.5043580739226968, 0.6076980492248905, 0.954345541111748], 
             UndirectedEdge[13, 85] -> 
             RGBColor[
              0.44417434838099124`, 0.5514829814433777, 0.9508559581637567], 
             UndirectedEdge[95, 98] -> 
             RGBColor[
              0.44027487248405767`, 0.5508921962946529, 0.9503145859814027], 
             UndirectedEdge[34, 87] -> 
             RGBColor[
              0.687018378215704, 0.7545433504248138, 0.9700408186505132], 
             UndirectedEdge[61, 94] -> 
             RGBColor[
              0.17986770348779496`, 0.3063827390097185, 0.9335545716719839], 
             UndirectedEdge[61, 72] -> 
             RGBColor[
              0.5051859770600657, 0.2740496366999483, 0.5556230148092107], 
             UndirectedEdge[50, 86] -> 
             RGBColor[
              0.9923931656575502, 0.9911223927597408, 0.7757284611180213], 
             UndirectedEdge[66, 97] -> 
             RGBColor[
              0.2865673127095588, 0.41728062921084064`, 0.9396767312060312], 
             UndirectedEdge[9, 21] -> 
             RGBColor[
              0.9272801117087064, 0.7490947632900866, 0.26033044528115884`], 
             UndirectedEdge[34, 60] -> 
             RGBColor[
              0.5274957486173808, 0.6272838379970835, 0.9559455440932065], 
             UndirectedEdge[53, 84] -> 
             RGBColor[
              0.3801912291988372, 0.5037242665904019, 0.9454464268280143], 
             UndirectedEdge[21, 22] -> 
             RGBColor[
              0.9323482473126639, 0.8120285789472437, 0.5954726044647025], 
             UndirectedEdge[14, 62] -> 
             RGBColor[
              0.5425047543047143, 0.6359256467112409, 0.9585841868969369], 
             UndirectedEdge[22, 30] -> 
             RGBColor[
              0.889942779596627, 0.5565022708656576, 0.5576225786548253], 
             UndirectedEdge[67, 72] -> 
             RGBColor[
              0.5064924105038062, 0.2754227810819841, 0.5556974142611366], 
             UndirectedEdge[61, 86] -> 
             RGBColor[
              0.5861812358174932, 0.6484737065337263, 0.8459778768352497], 
             UndirectedEdge[5, 83] -> 
             RGBColor[
              0.23714577838221002`, 0.3665856273634506, 0.9368164733019025], 
             UndirectedEdge[46, 99] -> 
             RGBColor[
              0.3372394933460653, 0.46304047074906063`, 0.9428370425595982], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.781084942834804, 0.8289087608987646, 0.9788149055141302], 
             UndirectedEdge[7, 37] -> 
             RGBColor[
              0.5197144859100872, 0.615889070520134, 0.9572576272411842], 
             UndirectedEdge[7, 53] -> 
             RGBColor[
              0.3185195172219749, 0.4503073293864159, 0.9415167598750023], 
             UndirectedEdge[12, 52] -> 
             RGBColor[
              0.7720788229198519, 0.7426869970369261, 0.6158231874912047], 
             UndirectedEdge[50, 85] -> 
             RGBColor[
              0.8031648921505794, 0.844498996900527, 0.8779173543675954], 
             UndirectedEdge[14, 15] -> 
             RGBColor[
              0.517451452940507, 0.6142257362851044, 0.9569878126877741], 
             UndirectedEdge[14, 35] -> 
             RGBColor[
              0.5107221888506179, 0.6078178110419963, 0.9565802436840543], 
             UndirectedEdge[8, 95] -> 
             RGBColor[
              0.7742769644814296, 0.8231752897500257, 0.9541023665093038], 
             UndirectedEdge[7, 84] -> 
             RGBColor[
              0.3751477903048108, 0.49935589331100566`, 0.9451250633614249], 
             UndirectedEdge[14, 76] -> 
             RGBColor[
              0.8566553758991764, 0.885347450425243, 0.7992958438699176], 
             UndirectedEdge[60, 89] -> 
             RGBColor[
              0.357298326389239, 0.4775030084894488, 0.9443308094531306], 
             UndirectedEdge[37, 85] -> 
             RGBColor[
              0.6704659090566354, 0.7420729031411366, 0.9680761991218017], 
             UndirectedEdge[39, 80] -> 
             RGBColor[
              0.28185045974068534`, 0.4135730819117158, 0.9393623387706183], 
             UndirectedEdge[23, 24] -> 
             RGBColor[
              0.9471254016338135, 0.8298823883137303, 0.5568344831794053], 
             UndirectedEdge[11, 68] -> 
             RGBColor[
              0.5257597936505869, 0.24880852240069085`, 0.5504333745134287], 
             UndirectedEdge[27, 81] -> 
             RGBColor[
              0.4414307993595177, 0.5543994591447239, 0.9500026902294574], 
             UndirectedEdge[36, 61] -> 
             RGBColor[
              0.17912334491775841`, 0.3056003709575509, 0.9335121815526001], 
             UndirectedEdge[28, 59] -> 
             RGBColor[
              0.2655146286535537, 0.39640308768762733`, 0.9384320373569025], 
             UndirectedEdge[8, 30] -> 
             RGBColor[
              0.8906347096446199, 0.5570183111625192, 0.5564513215678325], 
             UndirectedEdge[34, 82] -> 
             RGBColor[
              0.7111994736592744, 0.481494992557141, 0.5719947770859303], 
             UndirectedEdge[50, 84] -> 
             RGBColor[
              0.7140851809808935, 0.7717321014835103, 0.87102844943999], 
             UndirectedEdge[57, 88] -> 
             RGBColor[
              0.27128503651838054`, 0.40246815221855037`, 0.9387606535482509],
              UndirectedEdge[6, 53] -> 
             RGBColor[
              0.2901431745630745, 0.4209193221478431, 0.939884756417035], 
             UndirectedEdge[8, 69] -> 
             RGBColor[
              0.6933493129056316, 0.7566729943369539, 0.9479529248561034], 
             UndirectedEdge[69, 99] -> 
             RGBColor[
              0.41359053884055663`, 0.5326530699039465, 0.9475746013045347], 
             UndirectedEdge[81, 84] -> 
             RGBColor[
              0.4886643442635845, 0.5953107817136317, 0.9530123699437607], 
             UndirectedEdge[11, 94] -> 
             RGBColor[
              0.20750449713838193`, 0.3354307614104094, 0.9351284461854125], 
             UndirectedEdge[10, 65] -> 
             RGBColor[
              0.23682752030936433`, 0.3662511179501625, 0.9367983489754745], 
             UndirectedEdge[79, 98] -> 
             RGBColor[
              0.26889413426113584`, 0.39995516235422757`, 0.9386244952017238],
              UndirectedEdge[33, 62] -> 
             RGBColor[
              0.3171356169120182, 0.44536236355291736`, 0.9415657494001773], 
             UndirectedEdge[31, 70] -> 
             RGBColor[
              0.3382626356768291, 0.464409652660651, 0.9428845517476936], 
             UndirectedEdge[31, 32] -> 
             RGBColor[
              0.3463701598777138, 0.472931174642505, 0.9433462632569267], 
             UndirectedEdge[15, 100] -> 
             RGBColor[
              0.28060017483633093`, 0.41159399522924645`, 0.9393154842638007],
              UndirectedEdge[7, 65] -> 
             RGBColor[
              0.26785267018749115`, 0.3984231895202199, 0.9385811980860177], 
             UndirectedEdge[59, 95] -> 
             RGBColor[
              0.430296968658313, 0.5404047867381535, 0.9497463591195126], 
             UndirectedEdge[2, 3] -> 
             RGBColor[
              0.4080096464453409, 0.5252224449857339, 0.947726795683348], 
             UndirectedEdge[48, 88] -> 
             RGBColor[
              0.2730751570306258, 0.404349682377116, 0.9388625982631773], 
             UndirectedEdge[14, 38] -> 
             RGBColor[
              0.5755893914541861, 0.6645818965278997, 0.9606923107205052], 
             UndirectedEdge[44, 45] -> 
             RGBColor[
              0.7810472132422319, 0.8288792862542917, 0.9788111449809456], 
             UndirectedEdge[24, 50] -> 
             RGBColor[
              0.9494254708663976, 0.830833526050487, 0.5187163836071205], 
             UndirectedEdge[38, 62] -> 
             RGBColor[
              0.39912933111578863`, 0.5201274986141865, 0.9466531459358565], 
             UndirectedEdge[4, 50] -> 
             RGBColor[
              0.9150800997643256, 0.6450012708274279, 0.48889967113718485`], 
             UndirectedEdge[48, 74] -> 
             RGBColor[
              0.3099201171979624, 0.4380720909673196, 0.941144084481714], 
             UndirectedEdge[40, 100] -> 
             RGBColor[
              0.24447547507013836`, 0.3742896033120748, 0.9372338886849655], 
             UndirectedEdge[19, 95] -> 
             RGBColor[
              0.4261782781667054, 0.536075781891414, 0.949511805789072], 
             UndirectedEdge[19, 79] -> 
             RGBColor[
              0.2547975399437836, 0.38513874795098857`, 0.937821715009393], 
             UndirectedEdge[51, 70] -> 
             RGBColor[
              0.2685220074352297, 0.3995640334659966, 0.9386033031295007], 
             UndirectedEdge[17, 22] -> 
             RGBColor[
              0.6749436759381056, 0.7408142314231896, 0.9479954802017996], 
             UndirectedEdge[59, 99] -> 
             RGBColor[
              0.33916350971304693`, 0.46506273394044173`, 0.9429466124453707],
              UndirectedEdge[20, 63] -> 
             RGBColor[
              0.22006041247387476`, 0.34862782451902463`, 0.9358434869889567],
              UndirectedEdge[56, 89] -> 
             RGBColor[
              0.2431918362429577, 0.37294041751730556`, 0.937160787352731], 
             UndirectedEdge[12, 74] -> 
             RGBColor[
              0.48414329622236674`, 0.5896324439603484, 0.9532112582976568], 
             UndirectedEdge[8, 17] -> 
             RGBColor[
              0.6756356059860984, 0.7413302717200512, 0.9468242231148067], 
             UndirectedEdge[53, 90] -> 
             RGBColor[
              0.3158328098736569, 0.44792075767621997`, 0.941347743143563], 
             UndirectedEdge[21, 72] -> 
             RGBColor[
              0.8673115146201031, 0.4479706752513929, 0.20933339049355504`], 
             UndirectedEdge[48, 73] -> 
             RGBColor[
              0.25430833916142304`, 0.38462456691160657`, 0.9377938557485452],
              UndirectedEdge[8, 49] -> 
             RGBColor[
              0.8679776052374037, 0.8972436267472088, 0.9628476465059921], 
             UndirectedEdge[17, 69] -> 
             RGBColor[
              0.40608263929049154`, 0.5261501046716837, 0.9470962045841795], 
             UndirectedEdge[21, 82] -> 
             RGBColor[
              0.8703286104016272, 0.4711613955279884, 0.21222256482126478`], 
             UndirectedEdge[36, 68] -> 
             RGBColor[
              0.4983193449177584, 0.2199668709575509, 0.5488706815526001], 
             UndirectedEdge[21, 30] -> 
             RGBColor[
              0.860772607404038, 0.39770976902130306`, 0.2030717255588116], 
             UndirectedEdge[56, 64] -> 
             RGBColor[
              0.2634347031054928, 0.3942169540617188, 0.9383135886739146], 
             UndirectedEdge[48, 64] -> 
             RGBColor[
              0.27099128981714793`, 0.40215940581093823`, 0.9387439251081751],
              UndirectedEdge[46, 59] -> 
             RGBColor[
              0.27301827158802383`, 0.40428989217019595`, 0.9388593587213756],
              UndirectedEdge[46, 79] -> 
             RGBColor[
              0.25699221406840955`, 0.38744548960634695`, 0.937946698454061], 
             UndirectedEdge[9, 86] -> 
             RGBColor[
              0.9724088099661622, 0.9182534312723682, 0.5190969464320642], 
             UndirectedEdge[64, 91] -> 
             RGBColor[
              0.26939944622333534`, 0.400486277265128, 0.938653271970429], 
             UndirectedEdge[1, 19] -> 
             RGBColor[
              0.2624065565834054, 0.39313630687875045`, 0.9382550372504881], 
             UndirectedEdge[5, 69] -> 
             RGBColor[
              0.3370682698872072, 0.4609733107913742, 0.942896391026308], 
             UndirectedEdge[36, 92] -> 
             RGBColor[
              0.18278950597928542`, 0.3094537386812527, 0.9337209640014548], 
             UndirectedEdge[17, 95] -> 
             RGBColor[
              0.48701029086628944`, 0.5926524000847553, 0.95324564623738], 
             UndirectedEdge[7, 13] -> 
             RGBColor[
              0.293422925234443, 0.42529914882237513`, 0.9400373862831393], 
             UndirectedEdge[11, 61] -> 
             RGBColor[
              0.20656379365058694`, 0.3344420224006909, 0.9350748745134286], 
             UndirectedEdge[66, 83] -> 
             RGBColor[
              0.27310948122008705`, 0.4031355950396065, 0.9389103276117834], 
             UndirectedEdge[27, 37] -> 
             RGBColor[
              0.5341526529828826, 0.6283946851552121, 0.9581776144798929], 
             UndirectedEdge[22, 34] -> 
             RGBColor[
              0.7732191105703109, 0.8223621759763964, 0.955244816729368], 
             UndirectedEdge[6, 90] -> 
             RGBColor[
              0.2824130283207301, 0.41416437715825094`, 0.9393943762190061], 
             UndirectedEdge[71, 77] -> 
             RGBColor[
              0.3842477285736503, 0.5072378024632783, 0.9457049033811559], 
             UndirectedEdge[9, 68] -> 
             RGBColor[
              0.884350574148669, 0.48954022473864206`, 0.22197856959681445`], 
             UndirectedEdge[23, 86] -> 
             RGBColor[
              0.990093096424966, 0.9901712550229842, 0.8138465606903063], 
             UndirectedEdge[54, 84] -> 
             RGBColor[
              0.3438756345570892, 0.4669242029109275, 0.9433281476320208], 
             UndirectedEdge[3, 16] -> 
             RGBColor[
              0.26785762869397084`, 0.3988657292848884, 0.9385654677430463], 
             UndirectedEdge[66, 98] -> 
             RGBColor[
              0.3085828474233191, 0.440420352060525, 0.9409304833389149], 
             UndirectedEdge[64, 93] -> 
             RGBColor[
              0.2726343777507507, 0.4038863954069468, 0.938837496535263], 
             UndirectedEdge[2, 29] -> 
             RGBColor[
              0.41847939161663067`, 0.5351656244278226, 0.9483618874203135], 
             UndirectedEdge[50, 81] -> 
             RGBColor[
              0.7659300229628049, 0.8142700526821505, 0.8749860890693137], 
             UndirectedEdge[8, 99] -> 
             RGBColor[
              0.6831435055361634, 0.747833236952314, 0.947302619835162], 
             UndirectedEdge[66, 69] -> 
             RGBColor[
              0.37303197272508415`, 0.4975232784675301, 0.9449902453361887], 
             UndirectedEdge[9, 30] -> 
             RGBColor[
              0.8848746439926696, 0.49356845520850057`, 0.2224804194712816], 
             UndirectedEdge[11, 36] -> 
             RGBColor[
              0.20676013856834535`, 0.33464839335824176`, 0.9350860560660287],
              UndirectedEdge[16, 62] -> 
             RGBColor[
              0.30123789915337096`, 0.4286528542150554, 0.9406603978923882], 
             UndirectedEdge[50, 76] -> 
             RGBColor[
              0.9928483984176775, 0.9905031143387806, 0.7094852523118963], 
             UndirectedEdge[36, 86] -> 
             RGBColor[
              0.5863775807352516, 0.6486800774912771, 0.8459890583878498], 
             UndirectedEdge[60, 71] -> 
             RGBColor[
              0.41038752678537255`, 0.5294238797348146, 0.9474961990184465], 
             UndirectedEdge[43, 54] -> 
             RGBColor[
              0.2507606889125138, 0.3808957615659856, 0.9375918223151481], 
             UndirectedEdge[29, 42] -> 
             RGBColor[
              0.48821367053746006`, 0.5915669704381774, 0.9539966276833514], 
             UndirectedEdge[76, 84] -> 
             RGBColor[
              0.7155827197184571, 0.7715438433702618, 0.7875115331863431], 
             UndirectedEdge[65, 90] -> 
             RGBColor[
              0.26516596283917315`, 0.39603661781002397`, 0.9384121813545784],
              UndirectedEdge[52, 78] -> 
             RGBColor[
              0.9664668529248481, 0.8933481863027279, 0.5077226888807255], 
             UndirectedEdge[25, 65] -> 
             RGBColor[
              0.21906851954430756`, 0.34758528216040546`, 0.9357870001539919],
              UndirectedEdge[45, 52] -> 
             RGBColor[
              0.8611685991001501, 0.8128504925215565, 0.6243159249705089], 
             UndirectedEdge[57, 74] -> 
             RGBColor[
              0.3081299966857172, 0.43619056080875396`, 0.9410421397667876], 
             UndirectedEdge[17, 66] -> 
             RGBColor[
              0.3553182658055509, 0.48218055585062736`, 0.943861543594892], 
             UndirectedEdge[59, 98] -> 
             RGBColor[
              0.28492019178075007`, 0.41679956491807657`, 0.9395371554690384],
              UndirectedEdge[22, 77] -> 
             RGBColor[
              0.6896552593406005, 0.7535566655407491, 0.9489328892872642], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.9001907126422091, 0.6304699376692046, 0.5656021608302857], 
             UndirectedEdge[30, 36] -> 
             RGBColor[
              0.49884341476175903`, 0.2239951014274094, 0.5493725314270672], 
             UndirectedEdge[60, 64] -> 
             RGBColor[
              0.37754119325177404`, 0.49877954503386207`, 0.9454836107743141],
              UndirectedEdge[28, 99] -> 
             RGBColor[
              0.3297358504115952, 0.455153666266492, 0.9424097211951252], 
             UndirectedEdge[59, 69] -> 
             RGBColor[
              0.34936931708251506`, 0.4739024913250818, 0.9435969174663121], 
             UndirectedEdge[66, 79] -> 
             RGBColor[
              0.2825788860779602, 0.4130885399401764, 0.93944959620971], 
             UndirectedEdge[7, 81] -> 
             RGBColor[
              0.42699263228672224`, 0.5418938445096457, 0.9490827029907487], 
             UndirectedEdge[26, 100] -> 
             RGBColor[
              0.2326661285681354, 0.3618772313826554, 0.9365613638720389], 
             UndirectedEdge[5, 97] -> 
             RGBColor[
              0.2506036098716818, 0.3807306615346847, 0.9375828768961504], 
             UndirectedEdge[20, 83] -> 
             RGBColor[
              0.22260788034518547`, 0.3513053747705641, 0.9359885615155867], 
             UndirectedEdge[21, 92] -> 
             RGBColor[
              0.5447186986215644, 0.48316840627514634`, 0.5874201581331991], 
             UndirectedEdge[77, 98] -> 
             RGBColor[
              0.35634509739122144`, 0.481789612382238, 0.9439738516723704], 
             UndirectedEdge[13, 84] -> 
             RGBColor[
              0.35509463721130535`, 0.4787160860263612, 0.9439670532361513], 
             UndirectedEdge[83, 97] -> 
             RGBColor[
              0.23740919468950228`, 0.36686249460397324`, 0.9368314744709133],
              UndirectedEdge[4, 24] -> 
             RGBColor[
              0.8731547109506095, 0.48514342442588576`, 0.2146138861787622], 
             UndirectedEdge[7, 85] -> 
             RGBColor[
              0.46422750147449665`, 0.5721227887280222, 0.9520139682890303], 
             UndirectedEdge[10, 40] -> 
             RGBColor[
              0.247557235138606, 0.37752872853890806`, 0.9374093903618093], 
             UndirectedEdge[26, 40] -> 
             RGBColor[
              0.23187934520351416`, 0.3610502721814919, 0.9365165577233654], 
             UndirectedEdge[56, 74] -> 
             RGBColor[
              0.3023635304863073, 0.4301296392181001, 0.9407137480474534], 
             UndirectedEdge[42, 62] -> 
             RGBColor[
              0.5111241958255703, 0.6114109159262558, 0.9554564660957278], 
             UndirectedEdge[4, 36] -> 
             RGBColor[
              0.5090645148420271, 0.3025589555589642, 0.5591602684070134], 
             UndirectedEdge[2, 33] -> 
             RGBColor[
              0.39248083985044224`, 0.5089006846712906, 0.946842453120579], 
             UndirectedEdge[36, 82] -> 
             RGBColor[
              0.5083994177593483, 0.2974467279340947, 0.5585233706895204], 
             UndirectedEdge[76, 81] -> 
             RGBColor[
              0.7674275617003685, 0.8140817945689018, 0.7914691728156671], 
             UndirectedEdge[27, 43] -> 
             RGBColor[
              0.29647101173303086`, 0.4258330666011419, 0.9403087252832609], 
             UndirectedEdge[61, 67] -> 
             RGBColor[
              0.1802334334437405, 0.3067671443820358, 0.933575399451926], 
             UndirectedEdge[10, 26] -> 
             RGBColor[
              0.235747888636603, 0.36511635660948866`, 0.9367368655488828], 
             UndirectedEdge[63, 83] -> 
             RGBColor[
              0.2214038953287198, 0.3500399101811996, 0.9359199963500353], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.28220392258022686`, 0.41350726570694146`, 0.9393984806790088],
              UndirectedEdge[20, 97] -> 
             RGBColor[
              0.23606571183465724`, 0.3654504089417983, 0.9367549651098346], 
             UndirectedEdge[28, 98] -> 
             RGBColor[
              0.27549253247929834`, 0.40689049724412685`, 0.9390002642187927],
              UndirectedEdge[4, 23] -> 
             RGBColor[
              0.9127800305317415, 0.6440501330906712, 0.5270177707094699], 
             UndirectedEdge[30, 86] -> 
             RGBColor[
              0.9059013056614938, 0.5668684370035848, 0.46183822670971686`], 
             UndirectedEdge[27, 54] -> 
             RGBColor[
              0.2966420896530224, 0.4260128803420197, 0.9403184679177174], 
             UndirectedEdge[1, 13] -> 
             RGBColor[
              0.2657389891679791, 0.3966389048135667, 0.9384448143562873], 
             UndirectedEdge[15, 35] -> 
             RGBColor[
              0.3092088271480132, 0.4416635027021466, 0.9409447046902427], 
             UndirectedEdge[56, 73] -> 
             RGBColor[
              0.24675175244976794`, 0.37668211516238714`, 0.9373635193142849],
              UndirectedEdge[16, 29] -> 
             RGBColor[
              0.27832737386526063`, 0.40880890872697706`, 0.9392005594800119],
              UndirectedEdge[53, 65] -> 
             RGBColor[
              0.2728961090815175, 0.40279156279961614`, 0.9389025615526072], 
             UndirectedEdge[6, 25] -> 
             RGBColor[
              0.2363155850258645, 0.36571304150863243`, 0.9367691950184196], 
             UndirectedEdge[68, 92] -> 
             RGBColor[
              0.501789161061527, 0.22361386772370176`, 0.5490682824488547], 
             UndirectedEdge[69, 97] -> 
             RGBColor[
              0.3373316861944994, 0.46125017803189694`, 0.9429113921953187], 
             UndirectedEdge[17, 77] -> 
             RGBColor[
              0.4030805157734533, 0.5235498161723404, 0.9469049119283475], 
             UndirectedEdge[46, 98] -> 
             RGBColor[
              0.2829961754137684, 0.41477730172669547`, 0.9394275855832659], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.34313416867820656`, 0.4716273033094493, 0.9430851836999117], 
             UndirectedEdge[17, 55] -> 
             RGBColor[
              0.3185371640353287, 0.44477145007049096`, 0.9417211396250476], 
             UndirectedEdge[2, 78] -> 
             RGBColor[
              0.7554647233160532, 0.8052075509695305, 0.8504886604600671], 
             UndirectedEdge[6, 35] -> 
             RGBColor[
              0.2796014780341359, 0.41120925954445625`, 0.9392342625895005], 
             UndirectedEdge[95, 99] -> 
             RGBColor[
              0.49451819041635453`, 0.5991553653170181, 0.9537240429577352], 
             UndirectedEdge[66, 99] -> 
             RGBColor[
              0.36282616535561596`, 0.48868352108289015`, 0.9443399403152473],
              UndirectedEdge[31, 39] -> 
             RGBColor[
              0.34736341039793694`, 0.47397514391497986`, 0.943402827404671], 
             UndirectedEdge[69, 71] -> 
             RGBColor[
              0.38724985209068863`, 0.5098380909626216, 0.9458961960369879], 
             UndirectedEdge[64, 89] -> 
             RGBColor[
              0.2647678240416204, 0.39561814869033823`, 0.9383895079390514], 
             UndirectedEdge[40, 53] -> 
             RGBColor[
              0.2836258239107592, 0.41406917338836174`, 0.9395136029389419], 
             UndirectedEdge[1, 27] -> 
             RGBColor[
              0.3002303093342801, 0.42978432673328937`, 0.9405228117202697], 
             UndirectedEdge[41, 48] -> 
             RGBColor[
              0.34329321321312134`, 0.4669781893550724, 0.9432705886491298], 
             UndirectedEdge[57, 70] -> 
             RGBColor[
              0.26485491336994227`, 0.39570968509618687`, 0.9383944675474621],
              UndirectedEdge[39, 44] -> 
             RGBColor[
              0.5365081779106845, 0.6268880178985887, 0.9593203806489492], 
             UndirectedEdge[6, 15] -> 
             RGBColor[
              0.286330742124025, 0.4176171847875644, 0.9396418315932203], 
             UndirectedEdge[6, 40] -> 
             RGBColor[
              0.2502060423578324, 0.3803127928703927, 0.9375602360143851], 
             UndirectedEdge[17, 59] -> 
             RGBColor[
              0.33165561016298184`, 0.45855976870817894`, 0.9424682157250155],
              UndirectedEdge[56, 91] -> 
             RGBColor[
              0.2478234584246726, 0.37780854609209535`, 0.9374245513841087], 
             UndirectedEdge[5, 59] -> 
             RGBColor[
              0.26264124075969747`, 0.39338297482786955`, 0.9382684021671439],
              UndirectedEdge[20, 58] -> 
             RGBColor[
              0.22266134542622565`, 0.3513615699606193, 0.9359916062728575], 
             UndirectedEdge[17, 19] -> 
             RGBColor[
              0.32753691967137427`, 0.45423076386143946`, 0.9422336623945751],
              UndirectedEdge[3, 38] -> 
             RGBColor[
              0.36574906065638857`, 0.4903403736840195, 0.9445582157865146], 
             UndirectedEdge[1, 17] -> 
             RGBColor[
              0.32323856928298944`, 0.4497129250720918, 0.941988877698796], 
             UndirectedEdge[2, 42] -> 
             RGBColor[
              0.5864694187639945, 0.6749492370446291, 0.9607331698161294], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.44521446884155214`, 0.5537197588039671, 0.950811098924118], 
             UndirectedEdge[48, 56] -> 
             RGBColor[
              0.2494153020184852, 0.3794816746379056, 0.9375152045218548], 
             UndirectedEdge[86, 94] -> 
             RGBColor[
              0.5871219393052882, 0.6494624455434448, 0.8460314485072336], 
             UndirectedEdge[23, 30] -> 
             RGBColor[
              0.9025589304514734, 0.5654862789591164, 0.5172300337295237], 
             UndirectedEdge[30, 82] -> 
             RGBColor[
              0.8279231426855904, 0.21563508744640228`, 0.17437253901138755`],
              UndirectedEdge[60, 74] -> 
             RGBColor[
              0.4164700206325886, 0.5346922301902434, 0.9478837701478531], 
             UndirectedEdge[10, 90] -> 
             RGBColor[
              0.2797642211015037, 0.41138031282676635`, 0.9392435305664304], 
             UndirectedEdge[49, 69] -> 
             RGBColor[
              0.5984246385417968, 0.6820634596988412, 0.9631196279753649], 
             UndirectedEdge[25, 100] -> 
             RGBColor[
              0.23058501773817044`, 0.3596898519503145, 0.9364428476890001], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.23295897687627548`, 0.36218503352216574`, 0.9365780411499574],
              UndirectedEdge[31, 51] -> 
             RGBColor[
              0.33046646407782415`, 0.4562153820042676, 0.9424405713085325], 
             UndirectedEdge[37, 50] -> 
             RGBColor[
              0.8586518765861698, 0.8882652786926387, 0.8831610133197494], 
             UndirectedEdge[6, 10] -> 
             RGBColor[
              0.25407458579092124`, 0.3843788772983895, 0.9377805438399023], 
             UndirectedEdge[69, 77] -> 
             RGBColor[
              0.4207942226929865, 0.5388925387892431, 0.9480336136696441], 
             UndirectedEdge[12, 96] -> 
             RGBColor[
              0.4452662078752948, 0.5537741398088749, 0.9508140453855485], 
             UndirectedEdge[12, 41] -> 
             RGBColor[
              0.5175163922375255, 0.6185385423481014, 0.9553377624650727], 
             UndirectedEdge[89, 93] -> 
             RGBColor[
              0.25239151088821565`, 0.3826098588625336, 0.9376846952140795], 
             UndirectedEdge[37, 81] -> 
             RGBColor[
              0.6332310398688609, 0.7118439589227601, 0.9651449338235201], 
             UndirectedEdge[14, 24] -> 
             RGBColor[
              0.8132324483478965, 0.7256778621369495, 0.6085269751651416], 
             UndirectedEdge[52, 67] -> 
             RGBColor[
              0.560139632974118, 0.5514847252323705, 0.6016081426491302], 
             UndirectedEdge[23, 27] -> 
             RGBColor[
              0.6645515668442425, 0.7298696411778459, 0.9061368692979717], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.2386756834212212, 0.36819365456103337`, 0.9369035991305825], 
             UndirectedEdge[23, 81] -> 
             RGBColor[
              0.7636299537302207, 0.8133189149453938, 0.9131041886415987], 
             UndirectedEdge[88, 96] -> 
             RGBColor[
              0.2871462971513761, 0.419139342805837, 0.9396639288766677], 
             UndirectedEdge[77, 95] -> 
             RGBColor[
              0.5017218742687843, 0.6053948342023149, 0.9541830553228445], 
             UndirectedEdge[74, 91] -> 
             RGBColor[
              0.3083282736041498, 0.43639896242150933`, 0.941053431343968], 
             UndirectedEdge[7, 100] -> 
             RGBColor[
              0.27936916838135406`, 0.4105277593101289, 0.939237045621026], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.3593964815136068, 0.4839037453450634, 0.9441876459561919], 
             UndirectedEdge[6, 100] -> 
             RGBColor[
              0.2509928257224536, 0.38113975207155615`, 0.9376050421630586], 
             UndirectedEdge[19, 55] -> 
             RGBColor[
              0.2577051513357447, 0.38819483187714965`, 0.9379872991767397], 
             UndirectedEdge[17, 28] -> 
             RGBColor[
              0.3222279508615301, 0.4486507010342292, 0.9419313244747699], 
             UndirectedEdge[64, 96] -> 
             RGBColor[
              0.28506242993789815`, 0.4169490662396592, 0.9395452557216655], 
             UndirectedEdge[67, 68] -> 
             RGBColor[
              0.49942943344374047`, 0.22113364438203578`, 0.5489338994519259],
              UndirectedEdge[22, 87] -> 
             RGBColor[
              0.875317687150646, 0.9030022552400158, 0.9648194594818615], 
             UndirectedEdge[42, 44] -> 
             RGBColor[
              0.7173501625148713, 0.7791186661105619, 0.9724624182472246], 
             UndirectedEdge[70, 96] -> 
             RGBColor[
              0.28071617400293775`, 0.4123808756834735, 0.9392977428758789], 
             UndirectedEdge[64, 88] -> 
             RGBColor[
              0.2870945581176334, 0.41908496180092925`, 0.9396609824152371], 
             UndirectedEdge[26, 65] -> 
             RGBColor[
              0.2211496303742725, 0.34977266159274634`, 0.9359055163370308], 
             UndirectedEdge[2, 14] -> 
             RGBColor[
              0.6178499772431384, 0.6994639678296142, 0.9638608906173386], 
             UndirectedEdge[11, 72] -> 
             RGBColor[
              0.5328227707106528, 0.3030976591006391, 0.5571968893226393], 
             UndirectedEdge[67, 86] -> 
             RGBColor[
              0.5874876692612337, 0.649846850915762, 0.8460522762871756], 
             UndirectedEdge[40, 90] -> 
             RGBColor[
              0.27589567766841483`, 0.4073142283987696, 0.939023222740913], 
             UndirectedEdge[27, 84] -> 
             RGBColor[
              0.38958595737760626`, 0.5118615079460839, 0.9460450506001336], 
             UndirectedEdge[13, 43] -> 
             RGBColor[
              0.26197969156672996`, 0.39268764468141926`, 0.9382307279192786],
              UndirectedEdge[52, 72] -> 
             RGBColor[
              0.8850921765904433, 0.518767217550283, 0.2236557580064148], 
             UndirectedEdge[10, 53] -> 
             RGBColor[
              0.28749436734384803`, 0.4181352578163585, 0.9397339107644591], 
             UndirectedEdge[15, 40] -> 
             RGBColor[
              0.2798133914717097, 0.41076703602808307`, 0.9392706781151272], 
             UndirectedEdge[21, 68] -> 
             RGBColor[
              0.8602485375600374, 0.3936815385514446, 0.2025698756843444], 
             UndirectedEdge[28, 83] -> 
             RGBColor[
              0.24001916627606623`, 0.36960574022320836`, 0.9369801084916611],
              UndirectedEdge[54, 100] -> 
             RGBColor[
              0.24809701263363243`, 0.37809606891005076`, 0.9374401298916217],
              UndirectedEdge[47, 96] -> 
             RGBColor[
              0.280167857490329, 0.4118045602634469, 0.9392665170616474], 
             UndirectedEdge[47, 51] -> 
             RGBColor[
              0.26797369092262097`, 0.39898771804597, 0.9385720773152693], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.3409913926021096, 0.4697713383713912, 0.9429486479031253], 
             UndirectedEdge[39, 45] -> 
             RGBColor[
              0.5390587638079978, 0.6288805549867408, 0.959574599214613], 
             UndirectedEdge[58, 97] -> 
             RGBColor[
              0.23746265977054243`, 0.3669186897940284, 0.936834519228184], 
             UndirectedEdge[31, 45] -> 
             RGBColor[
              0.5919024457294845, 0.6759664122706829, 0.9628935917366674], 
             UndirectedEdge[6, 26] -> 
             RGBColor[
              0.23839669585582945`, 0.3679004209409733, 0.9368877112014585], 
             UndirectedEdge[41, 91] -> 
             RGBColor[
              0.34170136961930875`, 0.46530506080926215`, 0.9431799355113838],
              UndirectedEdge[8, 22] -> 
             RGBColor[
              0.9622103495532457, 0.9713371210884598, 0.9488522004737234], 
             UndirectedEdge[46, 95] -> 
             RGBColor[
              0.42837295229133143`, 0.5383825235467723, 0.9496367892337401], 
             UndirectedEdge[66, 95] -> 
             RGBColor[
              0.4539596243008821, 0.5640255738806018, 0.9511396869893891], 
             UndirectedEdge[23, 37] -> 
             RGBColor[
              0.8563518073535856, 0.887314140955882, 0.9212791128920343], 
             UndirectedEdge[10, 100] -> 
             RGBColor[
              0.2483440185032272, 0.37835568774007156`, 0.9374541965104828], 
             UndirectedEdge[5, 79] -> 
             RGBColor[
              0.24661518324008325`, 0.37653857226402054`, 0.9373557418998293],
              UndirectedEdge[38, 42] -> 
             RGBColor[
              0.5442088329750422, 0.6400671657429147, 0.9575645899192962], 
             UndirectedEdge[40, 54] -> 
             RGBColor[
              0.24731022926901122`, 0.37726910970888733`, 0.9373953237429482],
              UndirectedEdge[32, 45] -> 
             RGBColor[
              0.5380655132877746, 0.6278365857142659, 0.9595180350668688], 
             UndirectedEdge[41, 60] -> 
             RGBColor[
              0.44984311664774745`, 0.5635983285779962, 0.9500102743152689], 
             UndirectedEdge[88, 91] -> 
             RGBColor[
              0.2714833134368132, 0.40267655383130574`, 0.9387719451254313], 
             UndirectedEdge[47, 57] -> 
             RGBColor[
              0.2643065968573336, 0.3951333696761603, 0.9383632417332306], 
             UndirectedEdge[27, 85] -> 
             RGBColor[
              0.4786656685472922, 0.5846284033631004, 0.952933955527739], 
             UndirectedEdge[69, 95] -> 
             RGBColor[
              0.5047239977858227, 0.6079951227016581, 0.9543743479786766], 
             UndirectedEdge[36, 72] -> 
             RGBColor[
              0.5053823219778242, 0.27425600765749925`, 0.5556341963618108], 
             UndirectedEdge[6, 65] -> 
             RGBColor[
              0.23947632752859074`, 0.3690351822816471, 0.9369491946280504], 
             UndirectedEdge[49, 77] -> 
             RGBColor[
              0.5954225150247585, 0.679463171199498, 0.9629283353195328], 
             UndirectedEdge[2, 62] -> 
             RGBColor[
              0.441389916904741, 0.555009569915901, 0.9498217258326898], 
             UndirectedEdge[22, 66] -> 
             RGBColor[
              0.6418930093726982, 0.712187405219036, 0.9458895209538087], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.37246108295649283`, 0.49696932160080975`, 0.9449560466299856],
              UndirectedEdge[73, 88] -> 
             RGBColor[
              0.2704116074619085, 0.40155012290159753`, 0.9387109130556073], 
             UndirectedEdge[8, 21] -> 
             RGBColor[
              0.9330401773606567, 0.8125446192441054, 0.5943013473777097], 
             UndirectedEdge[31, 75] -> 
             RGBColor[
              0.3329280335215753, 0.45880264756216715`, 0.9425807540467885], 
             UndirectedEdge[4, 30] -> 
             RGBColor[
              0.8285882397682693, 0.2207473150712718, 0.17500943672888053`], 
             UndirectedEdge[48, 91] -> 
             RGBColor[
              0.2553800451363277, 0.3857509978413148, 0.9378548878183692], 
             UndirectedEdge[19, 28] -> 
             RGBColor[
              0.26139593816194606`, 0.39207408284088785`, 0.938197484026462], 
             UndirectedEdge[28, 66] -> 
             RGBColor[
              0.28917728429612277`, 0.42002387483007575`, 0.9398253652267791],
              UndirectedEdge[3, 29] -> 
             RGBColor[
              0.30975389821880644`, 0.4418401783792823, 0.9409902535505699], 
             UndirectedEdge[22, 82] -> 
             RGBColor[
              0.8994987825942162, 0.6299538973723429, 0.5667734179172785], 
             UndirectedEdge[49, 82] -> 
             RGBColor[
              0.8052660382783743, 0.5558604030310919, 0.5807688639495472], 
             UndirectedEdge[23, 84] -> 
             RGBColor[
              0.7117851117483094, 0.7707809637467538, 0.909146549012275], 
             UndirectedEdge[65, 100] -> 
             RGBColor[
              0.2337457602408967, 0.3630119927233292, 0.9366228472986309], 
             UndirectedEdge[53, 85] -> 
             RGBColor[
              0.46927094036852307`, 0.5764911620074185, 0.9523353317556198], 
             UndirectedEdge[59, 97] -> 
             RGBColor[
              0.26290465706698973`, 0.3936598420683923, 0.9382834033361547], 
             UndirectedEdge[17, 98] -> 
             RGBColor[
              0.34163351398872654`, 0.46904717826467845`, 0.9430364425869058],
              UndirectedEdge[61, 68] -> 
             RGBColor[0.49812300000000004`, 0.2197605, 0.5488595000000001], 
             UndirectedEdge[28, 55] -> 
             RGBColor[
              0.2523961825259005, 0.38261476904993935`, 0.9376849612569346], 
             UndirectedEdge[9, 36] -> 
             RGBColor[
              0.5653509190664274, 0.575380095696193, 0.6066312511494145], 
             UndirectedEdge[20, 59] -> 
             RGBColor[
              0.24810334272267293`, 0.37810272223498315`, 0.9374404903808281],
              UndirectedEdge[48, 57] -> 
             RGBColor[
              0.25518176821789507`, 0.38554259622855935`, 0.9378435962411888],
              UndirectedEdge[1, 46] -> 
             RGBColor[
              0.26460123070803143`, 0.39544304853410883`, 0.9383800206951561],
              UndirectedEdge[5, 66] -> 
             RGBColor[
              0.2863038964022665, 0.41700376197031797`, 0.9396617300370205], 
             UndirectedEdge[64, 74] -> 
             RGBColor[
              0.32393951828497003`, 0.45280737039113284`, 0.9419424686337738],
              UndirectedEdge[55, 79] -> 
             RGBColor[
              0.24579778430773802`, 0.37567943416004, 0.9373091922398655], 
             UndirectedEdge[32, 51] -> 
             RGBColor[
              0.27662953163611426`, 0.40808555544785063`, 0.9390650146387339],
              UndirectedEdge[64, 73] -> 
             RGBColor[
              0.26832774024843065`, 0.39935984633541977`, 0.938592239900605], 
             UndirectedEdge[35, 38] -> 
             RGBColor[
              0.3673467656616922, 0.49201966294494187`, 0.9446492027229738], 
             UndirectedEdge[71, 87] -> 
             RGBColor[
              0.5699101563836958, 0.656683392162545, 0.9615914735757531], 
             UndirectedEdge[82, 87] -> 
             RGBColor[
              0.8132980502396094, 0.5621350718207605, 0.5815694198384238], 
             UndirectedEdge[5, 77] -> 
             RGBColor[
              0.33406614637016885`, 0.458373022292031, 0.9427050983704759], 
             UndirectedEdge[57, 64] -> 
             RGBColor[
              0.2692011693049027, 0.4002778756523726, 0.9386419803932486], 
             UndirectedEdge[63, 97] -> 
             RGBColor[
              0.23486172681819156`, 0.36418494435243376`, 0.9366863999442832],
              UndirectedEdge[41, 93] -> 
             RGBColor[
              0.34493630114672413`, 0.468705178951081, 0.9433641600762177], 
             UndirectedEdge[9, 61] -> 
             RGBColor[
              0.565154574148669, 0.575173724738642, 0.6066200695968145], 
             UndirectedEdge[17, 46] -> 
             RGBColor[
              0.32973159379600026`, 0.45653750551679784`, 0.942358645839243], 
             UndirectedEdge[25, 54] -> 
             RGBColor[
              0.2334197719370433, 0.36266935834712705`, 0.9366042827469828], 
             UndirectedEdge[59, 77] -> 
             RGBColor[
              0.3463671935654768, 0.47130220282573854`, 0.9434056248104801], 
             UndirectedEdge[66, 77] -> 
             RGBColor[
              0.3700298492080458, 0.49492298996818684`, 0.9447989526803566], 
             UndirectedEdge[7, 27] -> 
             RGBColor[
              0.327914245400744, 0.45844457074209777`, 0.9421153836471216], 
             UndirectedEdge[61, 92] -> 
             RGBColor[
              0.182593161061527, 0.30924736772370176`, 0.9337097824488547], 
             UndirectedEdge[77, 87] -> 
             RGBColor[
              0.6034545269859937, 0.6857378399891666, 0.9637288912084094], 
             UndirectedEdge[28, 79] -> 
             RGBColor[
              0.24948857113393946`, 0.3795586851237783, 0.937519377089588], 
             UndirectedEdge[5, 28] -> 
             RGBColor[
              0.25321358145824574`, 0.3834739071539198, 0.9377315109168982], 
             UndirectedEdge[56, 88] -> 
             RGBColor[
              0.26551857031897064`, 0.39640723062789657`, 0.9384322618289168],
              UndirectedEdge[25, 26] -> 
             RGBColor[
              0.21798888787154624`, 0.3464505208197316, 0.9357255167274], 
             UndirectedEdge[9, 67] -> 
             RGBColor[
              0.5664610075924095, 0.5765468691206779, 0.6066944690487404], 
             UndirectedEdge[32, 44] -> 
             RGBColor[
              0.5355149273904612, 0.6258440486261139, 0.959263816501205], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.5412488824777958, 0.4795214095089955, 0.5872225572369445], 
             UndirectedEdge[79, 83] -> 
             RGBColor[
              0.23342076805790374`, 0.3626704053333091, 0.9366043394745922], 
             UndirectedEdge[60, 93] -> 
             RGBColor[
              0.3651648800983693, 0.48577125520605746`, 0.9447787980493423], 
             UndirectedEdge[5, 63] -> 
             RGBColor[
              0.2345983105108993, 0.3639080771119111, 0.9366713987752724], 
             UndirectedEdge[19, 66] -> 
             RGBColor[
              0.2944862531059669, 0.425603937657286, 0.9401277031465842], 
             UndirectedEdge[8, 86] -> 
             RGBColor[
              0.9781688756181125, 0.981703287226387, 0.853067848528615], 
             UndirectedEdge[4, 37] -> 
             RGBColor[
              0.7823811166703816, 0.5425751770680375, 0.5790585158913912], 
             UndirectedEdge[9, 92] -> 
             RGBColor[
              0.5688207352101959, 0.5790270924623439, 0.606828852045669], 
             UndirectedEdge[3, 42] -> 
             RGBColor[
              0.4777439253661703, 0.5816237909960889, 0.9533615359463858], 
             UndirectedEdge[7, 90] -> 
             RGBColor[
              0.31078937097963055`, 0.4435523843968237, 0.9410263796769736], 
             UndirectedEdge[35, 62] -> 
             RGBColor[
              0.3342621285122205, 0.46336341312828305`, 0.9425410788994055], 
             UndirectedEdge[20, 79] -> 
             RGBColor[
              0.2320772852030587, 0.3612583196711341, 0.9365278301135136], 
             UndirectedEdge[31, 78] -> 
             RGBColor[
              0.6972006995541824, 0.7564641060518543, 0.846300355646884], 
             UndirectedEdge[13, 81] -> 
             RGBColor[
              0.40693947919321677`, 0.5212540372250012, 0.947924692865475], 
             UndirectedEdge[18, 80] -> 
             RGBColor[
              0.2419836729170215, 0.3716705612597674, 0.9370919842386365], 
             UndirectedEdge[90, 100] -> 
             RGBColor[
              0.27668246103303606`, 0.408141187599933, 0.9390680288895865], 
             UndirectedEdge[67, 92] -> 
             RGBColor[
              0.1838995945052675, 0.31062051210573755`, 0.9337841819007806], 
             UndirectedEdge[55, 66] -> 
             RGBColor[
              0.28548649746992133`, 0.41614462386633744`, 0.9396151803770567],
              UndirectedEdge[89, 91] -> 
             RGBColor[
              0.24915657936080024`, 0.3792097407207148, 0.9375004706492456], 
             UndirectedEdge[46, 55] -> 
             RGBColor[
              0.25989982546037066`, 0.390501573532508, 0.9381122826214077], 
             UndirectedEdge[41, 64] -> 
             RGBColor[
              0.3573126143001289, 0.48171346877888566`, 0.9440689728011896], 
             UndirectedEdge[28, 46] -> 
             RGBColor[
              0.2635906122865721, 0.39438082449624623`, 0.93832246747113], 
             UndirectedEdge[35, 53] -> 
             RGBColor[
              0.3130212595870627, 0.4449656400624253, 0.9411876295140573], 
             UndirectedEdge[35, 90] -> 
             RGBColor[
              0.3052911133447183, 0.4382106950728331, 0.9406972493160285], 
             UndirectedEdge[5, 58] -> 
             RGBColor[
              0.23719924346325016`, 0.36664182255350575`, 0.9368195180591732],
              UndirectedEdge[76, 85] -> 
             RGBColor[
              0.8046624308881429, 0.8443107387872784, 0.7944004381139487], 
             UndirectedEdge[34, 77] -> 
             RGBColor[
              0.5013559504056586, 0.6050977607255472, 0.9541542484559159], 
             UndirectedEdge[49, 71] -> 
             RGBColor[
              0.5618781444224608, 0.6504087233728764, 0.9607909176868766]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 25 -> 
             RGBColor[
              0.21590777704158132`, 0.3442631413873908, 0.9356070005443611], 
             55 -> RGBColor[
              0.2487053956996991, 0.3787355180862011, 0.9374747764072122], 90 -> 
             RGBColor[
              0.30810266363131256`, 0.4411658126866278, 0.9408573629455341], 
             27 -> RGBColor[
              0.3423524124735395, 0.470950185377176, 0.9430353708858302], 15 -> 
             RGBColor[
              0.3159380912379023, 0.44807142794525473`, 0.9413522736939626], 
             98 -> RGBColor[
              0.2948980956064947, 0.4272869744745761, 0.9401053823309286], 38 -> 
             RGBColor[
              0.43221396826526043`, 0.5487837484308453, 0.9487612697594249], 
             99 -> RGBColor[
              0.40338473147108844`, 0.5238133125193064, 0.9469242962835934], 
             71 -> RGBColor[
              0.3507033579713525, 0.4781833546366567, 0.9435674857484997], 41 -> 
             RGBColor[
              0.4296145376961023, 0.5465322523230198, 0.9485956363421444], 75 -> 
             RGBColor[
              0.26564897472372695`, 0.3965442939254123, 0.9384396881668516], 
             64 -> RGBColor[
              0.2850106909041555, 0.4168946852347515, 0.9395423092602349], 63 -> 
             RGBColor[
              0.21885642745740908`, 0.34736235992966014`, 0.9357749218234052],
              85 -> RGBColor[
              0.6149789246210449, 0.6983066213490248, 0.9628325401696478], 3 -> 
             RGBColor[
              0.29928415304751665`, 0.4318969989371937, 0.9403551618136042], 
             86 -> RGBColor[
              0.9934354716349865, 0.9915534130674525, 0.7584547536704994], 94 -> 
             RGBColor[
              0.18080840697558995`, 0.30737147801943704`, 0.9336081433439677],
              61 -> RGBColor[0.178927, 0.305394, 0.933501], 84 -> 
             RGBColor[
              0.4368195022816731, 0.5527728305149917, 0.9490547303144369], 76 -> 
             RGBColor[
              0.9943459371552411, 0.990314856225532, 0.6259683360582495], 21 -> 
             RGBColor[
              0.9031780751200748, 0.6532360771028892, 0.2409217513686888], 87 -> 
             RGBColor[
              0.789116954796039, 0.8351834296884333, 0.9796154614030067], 95 -> 
             RGBColor[
              0.5856516493616206, 0.6744974181147299, 0.9605237896318769], 72 -> 
             RGBColor[
              0.8314449541201315, 0.24270527339989661`, 0.17774502961842129`],
              42 -> RGBColor[
              0.6562036976848239, 0.731350583054984, 0.9663679100791674], 66 -> 
             RGBColor[
              0.32226759924014353`, 0.45355372964647384`, 0.9417555843469012],
              1 -> RGBColor[
              0.2581082061950206, 0.38861846808940276`, 0.9380102525547092], 
             24 -> RGBColor[
              0.9075000820526815, 0.6709756796489449, 0.2444305986486977], 54 -> 
             RGBColor[
              0.2509317668325053, 0.3810755753068633, 0.9376015649496046], 4 -> 
             RGBColor[
              0.8388093398485373, 0.29931116920282663`, 0.1847971737088267], 
             7 -> RGBColor[
              0.3134760783279485, 0.4459389561070196, 0.9411953964084129], 
             100 -> RGBColor[
              0.24526225843475957`, 0.3751165625132382, 0.937278694833639], 
             12 -> RGBColor[
              0.6054182467789488, 0.6905448323731828, 0.9620798885880011], 65 -> 
             RGBColor[
              0.2222292620470338, 0.35090742293342014`, 0.9359669997636226], 
             8 -> RGBColor[
              0.9629022796012385, 0.9718531613853215, 0.9476809433867306], 57 -> 
             RGBColor[
              0.25339164770564987`, 0.38366106606999373`, 0.9377416515262625],
              74 -> RGBColor[
              0.3628683456657846, 0.48872005554751413`, 0.9443426280073127], 
             37 -> RGBColor[
              0.7259528934922258, 0.7858391849332483, 0.9733198580739556], 43 -> 
             RGBColor[
              0.25058961099252225`, 0.3807159478251078, 0.9375820796806917], 
             39 -> RGBColor[
              0.2945197284764503, 0.42688928663103776`, 0.9400838348826166], 
             58 -> RGBColor[
              0.22405829336211083`, 0.3528298508128494, 0.9360711603912069], 
             11 -> RGBColor[
              0.23420058730117388`, 0.3634900448013817, 0.9366487490268572], 
             51 -> RGBColor[
              0.26072583583622466`, 0.3913697628096132, 0.9381593226903397], 
             48 -> RGBColor[
              0.2569718887301403, 0.38742412638712503`, 0.9379455409561153], 
             20 -> RGBColor[
              0.22126439749034046`, 0.3498932891083892, 0.9359120521545081], 
             33 -> RGBColor[
              0.26822653985771944`, 0.399253478308307, 0.9385864766880666], 
             45 -> RGBColor[
              0.7835977991395453, 0.8308718233424438, 0.9790653635466094], 23 -> 
             RGBColor[
              0.9867507212149456, 0.9887890969785158, 0.869238367710113], 22 -> 
             RGBColor[
              0.9615184195052529, 0.9708210807915982, 0.9500234575607163], 2 -> 
             RGBColor[
              0.5167351398431651, 0.6185478910342742, 0.9550984295530915], 60 -> 
             RGBColor[
              0.4700716955993926, 0.5806644048329727, 0.9514249122883933], 16 -> 
             RGBColor[
              0.23643110434042502`, 0.36583445963258315`, 0.9367757736724883],
              79 -> RGBColor[
              0.24289017291577697`, 0.372623350233879, 0.937143608072519], 89 -> 
             RGBColor[
              0.24452495717908534`, 0.374341612145925, 0.9372367066178678], 
             36 -> RGBColor[
              0.17931968983551683`, 0.3058067419151018, 0.9335233631052001], 
             52 -> RGBColor[
              0.938739399060755, 0.7948291617006693, 0.26956648639440833`], 
             32 -> RGBColor[
              0.2925332274360039, 0.424801348086088, 0.9399707065871281], 31 -> 
             RGBColor[
              0.40020709231942364`, 0.521061001198922, 0.9467218199267253], 
             68 -> RGBColor[0.817319, 0.134127, 0.164218], 73 -> 
             RGBColor[
              0.2516447895927058, 0.3818250074360881, 0.9376421705409753], 82 -> 
             RGBColor[
              0.8374791456831797, 0.2890867139530876, 0.18352337827384074`], 
             35 -> RGBColor[
              0.30247956305812407`, 0.4352555774590384, 0.9405371356865229], 
             88 -> RGBColor[
              0.28917842533111127`, 0.421275238367107, 0.9397796555702393], 
             50 -> RGBColor[
              0.9913508596801138, 0.9906913724520291, 0.7930021685655431], 19 -> 
             RGBColor[
              0.2667049069717902, 0.39765414566809815`, 0.9384998219462671], 
             17 -> RGBColor[
              0.3883689323709583, 0.5108073820547808, 0.9459675028428829], 96 -> 
             RGBColor[
              0.2851141689716408, 0.417003447244567, 0.939548202183096], 14 -> 
             RGBColor[
              0.7189648146431117, 0.780380044624954, 0.9726233516815856], 5 -> 
             RGBColor[
              0.2503401935643895, 0.38045379429416204`, 0.9375678757271396], 
             34 -> RGBColor[
              0.5849198016353689, 0.6739032711611944, 0.9604661758980197], 97 -> 
             RGBColor[
              0.25086702617897405`, 0.38100752877520744`, 0.9375978780651611],
              93 -> RGBColor[
              0.26025806459734596`, 0.3908781055791422, 0.9381326838102911], 
             81 -> RGBColor[
              0.5405091862454959, 0.6378487329122717, 0.9569700095730845], 69 -> 
             RGBColor[
              0.42379634621002477`, 0.5414928272885864, 0.9482249063254762], 
             9 -> RGBColor[
              0.9513821482973379, 0.8449534494772841, 0.27973913919362886`], 
             13 -> RGBColor[
              0.2733697721409376, 0.40465934153773064`, 0.9388793761578655], 
             30 -> RGBColor[
              0.8183671396880012, 0.14218346093971695`, 0.1652216997489344], 
             59 -> RGBColor[
              0.2749422879550054, 0.4063121553615771, 0.9389689286071481], 28 -> 
             RGBColor[
              0.25608696935210196`, 0.3864940200136776, 0.9378951461066569], 
             80 -> RGBColor[
              0.26918119100492044`, 0.4002568771923939, 0.9386408426586199], 
             47 -> RGBColor[
              0.27522154600901727`, 0.40660567328232683`, 0.9389848319401988],
              62 -> RGBColor[
              0.3660446939663169, 0.4914712487975277, 0.9445450221122881], 77 -> 
             RGBColor[
              0.4177920991759482, 0.5362922502898999, 0.947842321013812], 78 -> 
             RGBColor[
              0.9941943067889412, 0.9918672109047867, 0.7458788913670427], 40 -> 
             RGBColor[
              0.24368869170551716`, 0.37346264411091135`, 0.937189082536292], 
             67 -> RGBColor[
              0.181539866887481, 0.30814028876407157`, 0.9336497989038519], 
             56 -> RGBColor[
              0.24185871530683006`, 0.3715392228886861, 0.9370848680875943], 
             10 -> RGBColor[
              0.25142577857169485`, 0.38159481296690484`, 0.9376296981873266],
              53 -> RGBColor[
              0.3235629561160013, 0.45467570266581214`, 0.9418381233415918], 
             26 -> RGBColor[
              0.2200699987015112, 0.3486379002520725, 0.9358440329104389], 18 -> 
             RGBColor[
              0.21478615482912253`, 0.34308424532714094`, 0.935543125818653], 
             29 -> RGBColor[
              0.32022364339009624`, 0.4517833578213709, 0.9416253452875354], 
             92 -> RGBColor[
              0.18625932212305402`, 0.3131007354474035, 0.9339185648977094], 
             46 -> RGBColor[
              0.2710942552210422, 0.40226762897881485`, 0.9387497888356031], 
             49 -> RGBColor[
              0.773052930873569, 0.822634092109096, 0.9780143496252536], 83 -> 
             RGBColor[
              0.2239513632000305, 0.3527174604327391, 0.9360650708766655], 70 -> 
             RGBColor[
              0.27631817903423467`, 0.40775830412238, 0.9390472835686617], 44 -> 
             RGBColor[
              0.7784966273449186, 0.8268867491661398, 0.9785569264152818], 91 -> 
             RGBColor[
              0.25378820154251513`, 0.3840778692955045, 0.9377642346806232], 
             6 -> RGBColor[
              0.2567233930101477, 0.3871629416298741, 
               0.9379313894924781]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9lHs01Akbx4dhXCZmRjNjDGZ+vxEpY003Oez6fWm7uFSIpJWyrGvrtqF9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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 13}], {
             RGBColor[
             0.2657389891679791, 0.3966389048135667, 0.9384448143562873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 17}], {
             RGBColor[
             0.32323856928298944`, 0.4497129250720918, 0.941988877698796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 19}], {
             RGBColor[
             0.2624065565834054, 0.39313630687875045`, 0.9382550372504881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 27}], {
             RGBColor[
             0.3002303093342801, 0.42978432673328937`, 0.9405228117202697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 43}], {
             RGBColor[
             0.25434890859377146`, 0.3846672079572553, 0.9377961661177004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 46}], {
             RGBColor[
             0.26460123070803143`, 0.39544304853410883`, 0.9383800206951561]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 55}], {
             RGBColor[
             0.25340680094735984`, 0.3836769930878019, 0.9377425144809607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 3}], {
             RGBColor[
             0.4080096464453409, 0.5252224449857339, 0.947726795683348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 14}], {
             RGBColor[
             0.6178499772431384, 0.6994639678296142, 0.9638608906173386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 29}], {
             RGBColor[
             0.41847939161663067`, 0.5351656244278226, 0.9483618874203135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 33}], {
             RGBColor[
             0.39248083985044224`, 0.5089006846712906, 0.946842453120579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 38}], {
             RGBColor[
             0.4744745540542128, 0.5836658197325597, 0.9519298496562583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 42}], {
             RGBColor[
             0.5864694187639945, 0.6749492370446291, 0.9607331698161294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 44}], {
             RGBColor[
             0.6476158835940419, 0.7227173201002071, 0.9668276779841867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 62}], {
             RGBColor[
             0.441389916904741, 0.555009569915901, 0.9498217258326898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 78}], {
             RGBColor[
             0.7554647233160532, 0.8052075509695305, 0.8504886604600671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 16}], {
             RGBColor[
             0.26785762869397084`, 0.3988657292848884, 0.9385654677430463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 29}], {
             RGBColor[
             0.30975389821880644`, 0.4418401783792823, 0.9409902535505699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 33}], {
             RGBColor[
             0.283755346452618, 0.41557523862275036`, 0.9394708192508354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 38}], {
             RGBColor[
             0.36574906065638857`, 0.4903403736840195, 0.9445582157865146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 42}], {
             RGBColor[
             0.4777439253661703, 0.5816237909960889, 0.9533615359463858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 62}], {
             RGBColor[
             0.3326644235069168, 0.4616841238673607, 0.9424500919629462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 9}], {
             RGBColor[
             0.8950957440729377, 0.5721323093400554, 0.23226815645122778`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 23}], {
             RGBColor[
             0.9127800305317415, 0.6440501330906712, 0.5270177707094699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 24}], {
             RGBColor[
             0.8731547109506095, 0.48514342442588576`, 0.2146138861787622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 30}], {
             RGBColor[
             0.8285882397682693, 0.2207473150712718, 0.17500943672888053`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 36}], {
             RGBColor[
             0.5090645148420271, 0.3025589555589642, 0.5591602684070134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 37}], {
             RGBColor[
             0.7823811166703816, 0.5425751770680375, 0.5790585158913912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 50}], {
             RGBColor[
             0.9150800997643256, 0.6450012708274279, 0.48889967113718485`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 76}], {
             RGBColor[
             0.9165776385018892, 0.6448130127141793, 0.40538275488353814`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 86}], {
             RGBColor[
             0.9161224057417618, 0.6454322911351396, 0.4716259636896631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 94}], {
             RGBColor[
             0.5098088734120636, 0.30334132361113186`, 0.5592026585263972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 20}], {
             RGBColor[
             0.23580229552736498`, 0.3651735417012756, 0.9367399639408238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 28}], {
             RGBColor[
             0.25321358145824574`, 0.3834739071539198, 0.9377315109168982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 58}], {
             RGBColor[
             0.23719924346325016`, 0.36664182255350575`, 0.9368195180591732]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.26264124075969747`, 0.39338297482786955`, 0.9382684021671439]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 63}], {
             RGBColor[
             0.2345983105108993, 0.3639080771119111, 0.9366713987752724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 66}], {
             RGBColor[
             0.2863038964022665, 0.41700376197031797`, 0.9396617300370205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 69}], {
             RGBColor[
             0.3370682698872072, 0.4609733107913742, 0.942896391026308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[
             0.33406614637016885`, 0.458373022292031, 0.9427050983704759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 79}], {
             RGBColor[
             0.24661518324008325`, 0.37653857226402054`, 0.9373557418998293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[
             0.23714577838221002`, 0.3665856273634506, 0.9368164733019025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 97}], {
             RGBColor[
             0.2506036098716818, 0.3807306615346847, 0.9375828768961504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 7}], {
             RGBColor[
             0.2850997356690481, 0.41655094886844685`, 0.9395633929504454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 10}], {
             RGBColor[
             0.25407458579092124`, 0.3843788772983895, 0.9377805438399023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 15}], {
             RGBColor[
             0.286330742124025, 0.4176171847875644, 0.9396418315932203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 25}], {
             RGBColor[
             0.2363155850258645, 0.36571304150863243`, 0.9367691950184196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 26}], {
             RGBColor[
             0.23839669585582945`, 0.3679004209409733, 0.9368877112014585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 35}], {
             RGBColor[
             0.2796014780341359, 0.41120925954445625`, 0.9392342625895005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 40}], {
             RGBColor[
             0.2502060423578324, 0.3803127928703927, 0.9375602360143851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.2901431745630745, 0.4209193221478431, 0.939884756417035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 65}], {
             RGBColor[
             0.23947632752859074`, 0.3690351822816471, 0.9369491946280504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 90}], {
             RGBColor[
             0.2824130283207301, 0.41416437715825094`, 0.9393943762190061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 100}], {
             RGBColor[
             0.2509928257224536, 0.38113975207155615`, 0.9376050421630586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 13}], {
             RGBColor[
             0.293422925234443, 0.42529914882237513`, 0.9400373862831393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 25}], {
             RGBColor[
             0.2646919276847649, 0.3951010487472052, 0.9384011984763869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 27}], {
             RGBColor[
             0.327914245400744, 0.45844457074209777`, 0.9421153836471216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 37}], {
             RGBColor[
             0.5197144859100872, 0.615889070520134, 0.9572576272411842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 40}], {
             RGBColor[
             0.2785823850167328, 0.4097008001089655, 0.9391922394723524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 53}], {
             RGBColor[
             0.3185195172219749, 0.4503073293864159, 0.9415167598750023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.28220392258022686`, 0.41350726570694146`, 0.9393984806790088]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 65}], {
             RGBColor[
             0.26785267018749115`, 0.3984231895202199, 0.9385811980860177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 81}], {
             RGBColor[
             0.42699263228672224`, 0.5418938445096457, 0.9490827029907487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.3751477903048108, 0.49935589331100566`, 0.9451250633614249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 85}], {
             RGBColor[
             0.46422750147449665`, 0.5721227887280222, 0.9520139682890303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 90}], {
             RGBColor[
             0.31078937097963055`, 0.4435523843968237, 0.9410263796769736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 100}], {
             RGBColor[
             0.27936916838135406`, 0.4105277593101289, 0.939237045621026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 17}], {
             RGBColor[
             0.6756356059860984, 0.7413302717200512, 0.9468242231148067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.9330401773606567, 0.8125446192441054, 0.5943013473777097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 22}], {
             RGBColor[
             0.9622103495532457, 0.9713371210884598, 0.9488522004737234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 30}], {
             RGBColor[
             0.8906347096446199, 0.5570183111625192, 0.5564513215678325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 49}], {
             RGBColor[
             0.8679776052374037, 0.8972436267472088, 0.9628476465059921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 69}], {
             RGBColor[
             0.6933493129056316, 0.7566729943369539, 0.9479529248561034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 77}], {
             RGBColor[
             0.6903471893885933, 0.7540727058376107, 0.9477616322002713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.9001907126422091, 0.6304699376692046, 0.5656021608302857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 86}], {
             RGBColor[
             0.9781688756181125, 0.981703287226387, 0.853067848528615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 87}], {
             RGBColor[
             0.8760096171986388, 0.9035182955368775, 0.9636482023948687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 95}], {
             RGBColor[
             0.7742769644814296, 0.8231752897500257, 0.9541023665093038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 99}], {
             RGBColor[
             0.6831435055361634, 0.747833236952314, 0.947302619835162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.5927913677992559, 0.604221747139333, 0.6081939441102431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 21}], {
             RGBColor[
             0.9272801117087064, 0.7490947632900866, 0.26033044528115884`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 30}], {
             RGBColor[
             0.8848746439926696, 0.49356845520850057`, 0.2224804194712816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 36}], {
             RGBColor[
             0.5653509190664274, 0.575380095696193, 0.6066312511494145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 61}], {
             RGBColor[
             0.565154574148669, 0.575173724738642, 0.6066200695968145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 67}], {
             RGBColor[
             0.5664610075924095, 0.5765468691206779, 0.6066944690487404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 68}], {
             RGBColor[
             0.884350574148669, 0.48954022473864206`, 0.22197856959681445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 72}], {
             RGBColor[
             0.8914135512087347, 0.5438293614385904, 0.22874208440602506`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 82}], {
             RGBColor[
             0.8944306469902588, 0.5670200817151858, 0.2316312587337348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 86}], {
             RGBColor[
             0.9724088099661622, 0.9182534312723682, 0.5190969464320642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 92}], {
             RGBColor[
             0.5688207352101959, 0.5790270924623439, 0.606828852045669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 94}], {
             RGBColor[
             0.566095277636464, 0.5761624637483606, 0.6066736412687983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.28368193490479854`, 0.4148331204560798, 0.9394909859406446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 26}], {
             RGBColor[
             0.235747888636603, 0.36511635660948866`, 0.9367368655488828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 35}], {
             RGBColor[
             0.2769526708149095, 0.4084251952129716, 0.9390834169369247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 40}], {
             RGBColor[
             0.247557235138606, 0.37752872853890806`, 0.9374093903618093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 53}], {
             RGBColor[
             0.28749436734384803`, 0.4181352578163585, 0.9397339107644591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 65}], {
             RGBColor[
             0.23682752030936433`, 0.3662511179501625, 0.9367983489754745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 90}], {
             RGBColor[
             0.2797642211015037, 0.41138031282676635`, 0.9392435305664304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 100}], {
             RGBColor[
             0.2483440185032272, 0.37835568774007156`, 0.9374541965104828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 36}], {
             RGBColor[
             0.20676013856834535`, 0.33464839335824176`, 0.9350860560660287]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 52}], {
             RGBColor[
             0.5864699931809645, 0.5791596032510256, 0.6031076177106328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 61}], {
             RGBColor[
             0.20656379365058694`, 0.3344420224006909, 0.9350748745134286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 67}], {
             RGBColor[
             0.20787022709432745`, 0.3358151667827266, 0.9351492739653546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 68}], {
             RGBColor[
             0.5257597936505869, 0.24880852240069085`, 0.5504333745134287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 72}], {
             RGBColor[
             0.5328227707106528, 0.3030976591006391, 0.5571968893226393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 92}], {
             RGBColor[
             0.21022995471211395`, 0.3382953901243926, 0.9352836569622833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 94}], {
             RGBColor[
             0.20750449713838193`, 0.3354307614104094, 0.9351284461854125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 41}], {
             RGBColor[
             0.5175163922375255, 0.6185385423481014, 0.9553377624650727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 52}], {
             RGBColor[
             0.7720788229198519, 0.7426869970369261, 0.6158231874912047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 60}], {
             RGBColor[
             0.5377449711891708, 0.6356046186030777, 0.9567524004381972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.44521446884155214`, 0.5537197588039671, 0.950811098924118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 74}], {
             RGBColor[
             0.48414329622236674`, 0.5896324439603484, 0.9532112582976568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 88}], {
             RGBColor[
             0.44729833605503005`, 0.5559100353701449, 0.9509297720791202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 96}], {
             RGBColor[
             0.4452662078752948, 0.5537741398088749, 0.9508140453855485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 27}], {
             RGBColor[
             0.30786109230723857`, 0.43780476345745334`, 0.9409573735218479]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 43}], {
             RGBColor[
             0.26197969156672996`, 0.39268764468141926`, 0.9382307279192786]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 54}], {
             RGBColor[
             0.26215076948672145`, 0.392867458422297, 0.938240470553735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 81}], {
             RGBColor[
             0.40693947919321677`, 0.5212540372250012, 0.947924692865475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 84}], {
             RGBColor[
             0.35509463721130535`, 0.4787160860263612, 0.9439670532361513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 85}], {
             RGBColor[
             0.44417434838099124`, 0.5514829814433777, 0.9508559581637567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 15}], {
             RGBColor[
             0.517451452940507, 0.6142257362851044, 0.9569878126877741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 24}], {
             RGBColor[
             0.8132324483478965, 0.7256778621369495, 0.6085269751651416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 35}], {
             RGBColor[
             0.5107221888506179, 0.6078178110419963, 0.9565802436840543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 38}], {
             RGBColor[
             0.5755893914541861, 0.6645818965278997, 0.9606923107205052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 42}], {
             RGBColor[
             0.6875842561639678, 0.755865313839969, 0.9694956308803766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 53}], {
             RGBColor[
             0.5212638853795565, 0.6175278736453831, 0.9572307375115887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 62}], {
             RGBColor[
             0.5425047543047143, 0.6359256467112409, 0.9585841868969369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 76}], {
             RGBColor[
             0.8566553758991764, 0.885347450425243, 0.7992958438699176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 35}], {
             RGBColor[
             0.3092088271480132, 0.4416635027021466, 0.9409447046902427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 38}], {
             RGBColor[
             0.3740760297515814, 0.49842758818805, 0.9450567717266938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 40}], {
             RGBColor[
             0.2798133914717097, 0.41076703602808307`, 0.9392706781151272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 53}], {
             RGBColor[
             0.3197505236769518, 0.4513735653055334, 0.9415951985177772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.3409913926021096, 0.4697713383713912, 0.9429486479031253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 90}], {
             RGBColor[
             0.3120203774346074, 0.44461862031594124`, 0.9411048183197483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 100}], {
             RGBColor[
             0.28060017483633093`, 0.41159399522924645`, 0.9393154842638007]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 29}], {
             RGBColor[
             0.27832737386526063`, 0.40880890872697706`, 0.9392005594800119]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.25232882209907226`, 0.38254396897044507`, 0.9376811251802775]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 62}], {
             RGBColor[
             0.30123789915337096`, 0.4286528542150554, 0.9406603978923882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 19}], {
             RGBColor[
             0.32753691967137427`, 0.45423076386143946`, 0.9422336623945751]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 22}], {
             RGBColor[
             0.6749436759381056, 0.7408142314231896, 0.9479954802017996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 28}], {
             RGBColor[
             0.3222279508615301, 0.4486507010342292, 0.9419313244747699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 46}], {
             RGBColor[
             0.32973159379600026`, 0.45653750551679784`, 0.942358645839243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 55}], {
             RGBColor[
             0.3185371640353287, 0.44477145007049096`, 0.9417211396250476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 59}], {
             RGBColor[
             0.33165561016298184`, 0.45855976870817894`, 0.9424682157250155]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 66}], {
             RGBColor[
             0.3553182658055509, 0.48218055585062736`, 0.943861543594892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 69}], {
             RGBColor[
             0.40608263929049154`, 0.5261501046716837, 0.9470962045841795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 77}], {
             RGBColor[
             0.4030805157734533, 0.5235498161723404, 0.9469049119283475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 79}], {
             RGBColor[
             0.3156295526433677, 0.44171536614432994`, 0.9415555554577009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 95}], {
             RGBColor[
             0.48701029086628944`, 0.5926524000847553, 0.95324564623738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 98}], {
             RGBColor[
             0.34163351398872654`, 0.46904717826467845`, 0.9430364425869058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.3958768319210234, 0.5173103472870436, 0.9464458995632381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 80}], {
             RGBColor[
             0.2419836729170215, 0.3716705612597674, 0.9370919842386365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 28}], {
             RGBColor[
             0.26139593816194606`, 0.39207408284088785`, 0.938197484026462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 43}], {
             RGBColor[
             0.25864725898215624`, 0.389185046746603, 0.9380409508134795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 46}], {
             RGBColor[
             0.2688995810964162, 0.39996088732345647`, 0.9386248053909352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 55}], {
             RGBColor[
             0.2577051513357447, 0.38819483187714965`, 0.9379872991767397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 59}], {
             RGBColor[
             0.2708235974633978, 0.40198315051483763`, 0.9387343752767077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 66}], {
             RGBColor[
             0.2944862531059669, 0.425603937657286, 0.9401277031465842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 79}], {
             RGBColor[
             0.2547975399437836, 0.38513874795098857`, 0.937821715009393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 95}], {
             RGBColor[
             0.4261782781667054, 0.536075781891414, 0.949511805789072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 98}], {
             RGBColor[
             0.2808015012891425, 0.4124705600713371, 0.9393026021385978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 99}], {
             RGBColor[
             0.33504481922143936`, 0.46073372909370225`, 0.9427120591149303]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.2386756834212212, 0.36819365456103337`, 0.9369035991305825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 58}], {
             RGBColor[
             0.22266134542622565`, 0.3513615699606193, 0.9359916062728575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 59}], {
             RGBColor[
             0.24810334272267293`, 0.37810272223498315`, 0.9374404903808281]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 63}], {
             RGBColor[
             0.22006041247387476`, 0.34862782451902463`, 0.9358434869889567]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 66}], {
             RGBColor[
             0.271765998365242, 0.4017235093774315, 0.9388338182507047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 79}], {
             RGBColor[
             0.2320772852030587, 0.3612583196711341, 0.9365278301135136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 83}], {
             RGBColor[
             0.22260788034518547`, 0.3513053747705641, 0.9359885615155867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 97}], {
             RGBColor[
             0.23606571183465724`, 0.3654504089417983, 0.9367549651098346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 22}], {
             RGBColor[
             0.9323482473126639, 0.8120285789472437, 0.5954726044647025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 30}], {
             RGBColor[
             0.860772607404038, 0.39770976902130306`, 0.2030717255588116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 34}], {
             RGBColor[
             0.7440489383777218, 0.6635696741320418, 0.6006939636333543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.5412488824777958, 0.4795214095089955, 0.5872225572369445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 49}], {
             RGBColor[
             0.8381155029968219, 0.7379350846059927, 0.6094680504969712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 68}], {
             RGBColor[
             0.8602485375600374, 0.3936815385514446, 0.2025698756843444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 72}], {
             RGBColor[
             0.8673115146201031, 0.4479706752513929, 0.20933339049355504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 82}], {
             RGBColor[
             0.8703286104016272, 0.4711613955279884, 0.21222256482126478`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[
             0.8461475149580568, 0.7442097533956613, 0.6102686063858478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 92}], {
             RGBColor[
             0.5447186986215644, 0.48316840627514634`, 0.5874201581331991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 30}], {
             RGBColor[
             0.889942779596627, 0.5565022708656576, 0.5576225786548253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 34}], {
             RGBColor[
             0.7732191105703109, 0.8223621759763964, 0.955244816729368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 49}], {
             RGBColor[
             0.8672856751894109, 0.8967275864503471, 0.9640189035929849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 66}], {
             RGBColor[
             0.6418930093726982, 0.712187405219036, 0.9458895209538087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 69}], {
             RGBColor[
             0.6926573828576388, 0.7561569540400923, 0.9491241819430962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 77}], {
             RGBColor[
             0.6896552593406005, 0.7535566655407491, 0.9489328892872642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 82}], {
             RGBColor[
             0.8994987825942162, 0.6299538973723429, 0.5667734179172785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 87}], {
             RGBColor[
             0.875317687150646, 0.9030022552400158, 0.9648194594818615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 95}], {
             RGBColor[
             0.7735850344334367, 0.822659249453164, 0.9552736235962966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 99}], {
             RGBColor[
             0.6824515754881706, 0.7473171966554524, 0.9484738769221548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 24}], {
             RGBColor[
             0.9471254016338135, 0.8298823883137303, 0.5568344831794053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 27}], {
             RGBColor[
             0.6645515668442425, 0.7298696411778459, 0.9061368692979717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 30}], {
             RGBColor[
             0.9025589304514734, 0.5654862789591164, 0.5172300337295237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 37}], {
             RGBColor[
             0.8563518073535856, 0.887314140955882, 0.9212791128920343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 50}], {
             RGBColor[
             0.9890507904475296, 0.9897402347152724, 0.831120268137828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 76}], {
             RGBColor[
             0.9905483291850934, 0.9895519766020239, 0.7476033518841813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[
             0.7636299537302207, 0.8133189149453938, 0.9131041886415987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 84}], {
             RGBColor[
             0.7117851117483094, 0.7707809637467538, 0.909146549012275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 85}], {
             RGBColor[
             0.8008648229179952, 0.8435478591637703, 0.9160354539398804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 86}], {
             RGBColor[
             0.990093096424966, 0.9901712550229842, 0.8138465606903063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 42}], {
             RGBColor[
             0.7818518898687528, 0.7011631313519644, 0.6053992543639326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 50}], {
             RGBColor[
             0.9494254708663976, 0.830833526050487, 0.5187163836071205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 76}], {
             RGBColor[
             0.9509230096039614, 0.8306452679372385, 0.4351994673534736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 26}], {
             RGBColor[
             0.21798888787154624`, 0.3464505208197316, 0.9357255167274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 40}], {
             RGBColor[
             0.22979823437354924`, 0.35886289274915106`, 0.9363980415403266]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 54}], {
             RGBColor[
             0.2334197719370433, 0.36266935834712705`, 0.9366042827469828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 65}], {
             RGBColor[
             0.21906851954430756`, 0.34758528216040546`, 0.9357870001539919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 100}], {
             RGBColor[
             0.23058501773817044`, 0.3596898519503145, 0.9364428476890001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 40}], {
             RGBColor[
             0.23187934520351416`, 0.3610502721814919, 0.9365165577233654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 53}], {
             RGBColor[
             0.27181647740875625`, 0.40165680145894234`, 0.9388410781260154]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 65}], {
             RGBColor[
             0.2211496303742725, 0.34977266159274634`, 0.9359055163370308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 90}], {
             RGBColor[
             0.2640863311664119, 0.39490185646935017`, 0.9383506979279865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[
             0.2326661285681354, 0.3618772313826554, 0.9365613638720389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 37}], {
             RGBColor[
             0.5341526529828826, 0.6283946851552121, 0.9581776144798929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 43}], {
             RGBColor[
             0.29647101173303086`, 0.4258330666011419, 0.9403087252832609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 54}], {
             RGBColor[
             0.2966420896530224, 0.4260128803420197, 0.9403184679177174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 81}], {
             RGBColor[
             0.4414307993595177, 0.5543994591447239, 0.9500026902294574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 84}], {
             RGBColor[
             0.38958595737760626`, 0.5118615079460839, 0.9460450506001336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 85}], {
             RGBColor[
             0.4786656685472922, 0.5846284033631004, 0.952933955527739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 46}], {
             RGBColor[
             0.2635906122865721, 0.39438082449624623`, 0.93832246747113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 55}], {
             RGBColor[
             0.2523961825259005, 0.38261476904993935`, 0.9376849612569346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 59}], {
             RGBColor[
             0.2655146286535537, 0.39640308768762733`, 0.9384320373569025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 66}], {
             RGBColor[
             0.28917728429612277`, 0.42002387483007575`, 0.9398253652267791]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 79}], {
             RGBColor[
             0.24948857113393946`, 0.3795586851237783, 0.937519377089588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 83}], {
             RGBColor[
             0.24001916627606623`, 0.36960574022320836`, 0.9369801084916611]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 98}], {
             RGBColor[
             0.27549253247929834`, 0.40689049724412685`, 0.9390002642187927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 99}], {
             RGBColor[
             0.3297358504115952, 0.455153666266492, 0.9424097211951252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 33}], {
             RGBColor[
             0.29422509162390786`, 0.4255184180648389, 0.9401059109878009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 38}], {
             RGBColor[
             0.3762188058276783, 0.5002835531261081, 0.9451933075234802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 42}], {
             RGBColor[
             0.48821367053746006`, 0.5915669704381774, 0.9539966276833514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.34313416867820656`, 0.4716273033094493, 0.9430851836999117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 36}], {
             RGBColor[
             0.49884341476175903`, 0.2239951014274094, 0.5493725314270672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 50}], {
             RGBColor[
             0.9048589996840575, 0.566437416695873, 0.47911193415723874`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 82}], {
             RGBColor[
             0.8279231426855904, 0.21563508744640228`, 0.17437253901138755`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 86}], {
             RGBColor[
             0.9059013056614938, 0.5668684370035848, 0.46183822670971686`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 92}], {
             RGBColor[
             0.5023132309055276, 0.22764209819356024`, 0.5495701323233219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 94}], {
             RGBColor[
             0.4995877733317956, 0.224777469479577, 0.549414921546451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 32}], {
             RGBColor[
             0.3463701598777138, 0.472931174642505, 0.9433462632569267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 39}], {
             RGBColor[
             0.34736341039793694`, 0.47397514391497986`, 0.943402827404671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 44}], {
             RGBColor[
             0.5893518598321712, 0.6739738751825308, 0.9626393731710036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 45}], {
             RGBColor[
             0.5919024457294845, 0.6759664122706829, 0.9628935917366674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 51}], {
             RGBColor[
             0.33046646407782415`, 0.4562153820042676, 0.9424405713085325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 70}], {
             RGBColor[
             0.3382626356768291, 0.464409652660651, 0.9428845517476936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 75}], {
             RGBColor[
             0.3329280335215753, 0.45880264756216715`, 0.9425807540467885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 78}], {
             RGBColor[
             0.6972006995541824, 0.7564641060518543, 0.846300355646884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 80}], {
             RGBColor[
             0.33469414166217204`, 0.4606589391956579, 0.9426813312926726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 39}], {
             RGBColor[
             0.2935264779562271, 0.4258453173585629, 0.9400272707348724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 44}], {
             RGBColor[
             0.5355149273904612, 0.6258440486261139, 0.959263816501205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 45}], {
             RGBColor[
             0.5380655132877746, 0.6278365857142659, 0.9595180350668688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 51}], {
             RGBColor[
             0.27662953163611426`, 0.40808555544785063`, 0.9390650146387339]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 80}], {
             RGBColor[
             0.2808572092204622, 0.41252911263924097`, 0.939305774622874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 42}], {
             RGBColor[
             0.46221511877127164`, 0.5653020306816455, 0.952477193383617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 62}], {
             RGBColor[
             0.3171356169120182, 0.44536236355291736`, 0.9415657494001773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 49}], {
             RGBColor[
             0.678986366254469, 0.7482686816351451, 0.9692402627616367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 60}], {
             RGBColor[
             0.5274957486173808, 0.6272838379970835, 0.9559455440932065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 69}], {
             RGBColor[
             0.5043580739226968, 0.6076980492248905, 0.954345541111748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 71}], {
             RGBColor[
             0.46781157980336074`, 0.5760433128989255, 0.9520168308232597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 77}], {
             RGBColor[
             0.5013559504056586, 0.6050977607255472, 0.9541542484559159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 82}], {
             RGBColor[
             0.7111994736592744, 0.481494992557141, 0.5719947770859303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 87}], {
             RGBColor[
             0.687018378215704, 0.7545433504248138, 0.9700408186505132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 38}], {
             RGBColor[
             0.3673467656616922, 0.49201966294494187`, 0.9446492027229738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 53}], {
             RGBColor[
             0.3130212595870627, 0.4449656400624253, 0.9411876295140573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 62}], {
             RGBColor[
             0.3342621285122205, 0.46336341312828305`, 0.9425410788994055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 90}], {
             RGBColor[
             0.3052911133447183, 0.4382106950728331, 0.9406972493160285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 61}], {
             RGBColor[
             0.17912334491775841`, 0.3056003709575509, 0.9335121815526001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 67}], {
             RGBColor[
             0.18042977836149893`, 0.3069735153395867, 0.9335865810045261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 68}], {
             RGBColor[
             0.4983193449177584, 0.2199668709575509, 0.5488706815526001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 72}], {
             RGBColor[
             0.5053823219778242, 0.27425600765749925`, 0.5556341963618108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 82}], {
             RGBColor[
             0.5083994177593483, 0.2974467279340947, 0.5585233706895204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 86}], {
             RGBColor[
             0.5863775807352516, 0.6486800774912771, 0.8459890583878498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 92}], {
             RGBColor[
             0.18278950597928542`, 0.3094537386812527, 0.9337209640014548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 94}], {
             RGBColor[
             0.1800640484055534, 0.3065891099672694, 0.9335657532245839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 50}], {
             RGBColor[
             0.8586518765861698, 0.8882652786926387, 0.8831610133197494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 76}], {
             RGBColor[
             0.8601494153237335, 0.8880770205793902, 0.7996440970661025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 81}], {
             RGBColor[
             0.6332310398688609, 0.7118439589227601, 0.9651449338235201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 84}], {
             RGBColor[
             0.5813861978869495, 0.66930600772412, 0.9611872941941962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 85}], {
             RGBColor[
             0.6704659090566354, 0.7420729031411366, 0.9680761991218017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 42}], {
             RGBColor[
             0.5442088329750422, 0.6400671657429147, 0.9575645899192962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 62}], {
             RGBColor[
             0.39912933111578863`, 0.5201274986141865, 0.9466531459358565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 44}], {
             RGBColor[
             0.5365081779106845, 0.6268880178985887, 0.9593203806489492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 45}], {
             RGBColor[
             0.5390587638079978, 0.6288805549867408, 0.959574599214613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 80}], {
             RGBColor[
             0.28185045974068534`, 0.4135730819117158, 0.9393623387706183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 53}], {
             RGBColor[
             0.2836258239107592, 0.41406917338836174`, 0.9395136029389419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 54}], {
             RGBColor[
             0.24731022926901122`, 0.37726910970888733`, 0.9373953237429482]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.23295897687627548`, 0.36218503352216574`, 0.9365780411499574]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 90}], {
             RGBColor[
             0.27589567766841483`, 0.4073142283987696, 0.939023222740913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 100}], {
             RGBColor[
             0.24447547507013836`, 0.3742896033120748, 0.9372338886849655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 48}], {
             RGBColor[
             0.34329321321312134`, 0.4669781893550724, 0.9432705886491298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 56}], {
             RGBColor[
             0.3357366265014662, 0.459035737605853, 0.9428402522148693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 60}], {
             RGBColor[
             0.44984311664774745`, 0.5635983285779962, 0.9500102743152689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 64}], {
             RGBColor[
             0.3573126143001289, 0.48171346877888566`, 0.9440689728011896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 73}], {
             RGBColor[
             0.34062966364440406`, 0.46417862987955394`, 0.9431189034415599]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 74}], {
             RGBColor[
             0.39624144168094344`, 0.517626153935267, 0.9464691321747285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.3593964815136068, 0.4839037453450634, 0.9441876459561919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 91}], {
             RGBColor[
             0.34170136961930875`, 0.46530506080926215`, 0.9431799355113838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 93}], {
             RGBColor[
             0.34493630114672413`, 0.468705178951081, 0.9433641600762177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 44}], {
             RGBColor[
             0.7173501625148713, 0.7791186661105619, 0.9724624182472246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 62}], {
             RGBColor[
             0.5111241958255703, 0.6114109159262558, 0.9554564660957278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 78}], {
             RGBColor[
             0.8251990022368825, 0.8616088969798854, 0.8561234007231051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 46}], {
             RGBColor[
             0.2608419331067822, 0.3914917884019613, 0.9381659342581474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 54}], {
             RGBColor[
             0.2507606889125138, 0.3808957615659856, 0.9375918223151481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 45}], {
             RGBColor[
             0.7810472132422319, 0.8288792862542917, 0.9788111449809456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 78}], {
             RGBColor[
             0.88634546706693, 0.9093769800354632, 0.8622179088911622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 52}], {
             RGBColor[
             0.8611685991001501, 0.8128504925215565, 0.6243159249705089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 78}], {
             RGBColor[
             0.8888960529642432, 0.9113695171236152, 0.8624721274568261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 55}], {
             RGBColor[
             0.25989982546037066`, 0.390501573532508, 0.9381122826214077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 59}], {
             RGBColor[
             0.27301827158802383`, 0.40428989217019595`, 0.9388593587213756]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 79}], {
             RGBColor[
             0.25699221406840955`, 0.38744548960634695`, 0.937946698454061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 95}], {
             RGBColor[
             0.42837295229133143`, 0.5383825235467723, 0.9496367892337401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 98}], {
             RGBColor[
             0.2829961754137684, 0.41477730172669547`, 0.9394275855832659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 99}], {
             RGBColor[
             0.3372394933460653, 0.46304047074906063`, 0.9428370425595982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 51}], {
             RGBColor[
             0.26797369092262097`, 0.39898771804597, 0.9385720773152693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 57}], {
             RGBColor[
             0.2643065968573336, 0.3951333696761603, 0.9383632417332306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 70}], {
             RGBColor[
             0.27576986252162594`, 0.40718198870235345`, 0.9390160577544302]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 74}], {
             RGBColor[
             0.31904494583740095`, 0.4476628644149205, 0.9416637299737558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 75}], {
             RGBColor[
             0.2704352603663721, 0.40157498360386956`, 0.9387122600535251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 88}], {
             RGBColor[
             0.28219998567006427`, 0.41394045582471695`, 0.9393822437552191]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.280167857490329, 0.4118045602634469, 0.9392665170616474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 56}], {
             RGBColor[
             0.2494153020184852, 0.3794816746379056, 0.9375152045218548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 57}], {
             RGBColor[
             0.25518176821789507`, 0.38554259622855935`, 0.9378435962411888]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 64}], {
             RGBColor[
             0.27099128981714793`, 0.40215940581093823`, 0.9387439251081751]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 73}], {
             RGBColor[
             0.25430833916142304`, 0.38462456691160657`, 0.9377938557485452]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 74}], {
             RGBColor[
             0.3099201171979624, 0.4380720909673196, 0.941144084481714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 88}], {
             RGBColor[
             0.2730751570306258, 0.404349682377116, 0.9388625982631773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 91}], {
             RGBColor[
             0.2553800451363277, 0.3857509978413148, 0.9378548878183692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 93}], {
             RGBColor[
             0.2586149766637431, 0.3891511159831336, 0.9380391123832033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 96}], {
             RGBColor[
             0.2710430288508906, 0.402213786815846, 0.9387468715696057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 69}], {
             RGBColor[
             0.5984246385417968, 0.6820634596988412, 0.9631196279753649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 71}], {
             RGBColor[
             0.5618781444224608, 0.6504087233728764, 0.9607909176868766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 77}], {
             RGBColor[
             0.5954225150247585, 0.679463171199498, 0.9629283353195328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 82}], {
             RGBColor[
             0.8052660382783743, 0.5558604030310919, 0.5807688639495472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.781084942834804, 0.8289087608987646, 0.9788149055141302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 76}], {
             RGBColor[
             0.9928483984176775, 0.9905031143387806, 0.7094852523118963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 81}], {
             RGBColor[
             0.7659300229628049, 0.8142700526821505, 0.8749860890693137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 84}], {
             RGBColor[
             0.7140851809808935, 0.7717321014835103, 0.87102844943999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 85}], {
             RGBColor[
             0.8031648921505794, 0.844498996900527, 0.8779173543675954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 86}], {
             RGBColor[
             0.9923931656575502, 0.9911223927597408, 0.7757284611180213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 57}], {
             RGBColor[
             0.25705874177093724`, 0.3875154144398035, 0.9379504871083011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 70}], {
             RGBColor[
             0.2685220074352297, 0.3995640334659966, 0.9386033031295007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 75}], {
             RGBColor[
             0.2631874052799758, 0.3939570283675128, 0.9382995054285956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 67}], {
             RGBColor[
             0.560139632974118, 0.5514847252323705, 0.6016081426491302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 68}], {
             RGBColor[
             0.8780291995303775, 0.46447808085033465`, 0.21689224319720418`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 72}], {
             RGBColor[
             0.8850921765904433, 0.518767217550283, 0.2236557580064148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 78}], {
             RGBColor[
             0.9664668529248481, 0.8933481863027279, 0.5077226888807255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 65}], {
             RGBColor[
             0.2728961090815175, 0.40279156279961614`, 0.9389025615526072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 84}], {
             RGBColor[
             0.3801912291988372, 0.5037242665904019, 0.9454464268280143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 85}], {
             RGBColor[
             0.46927094036852307`, 0.5764911620074185, 0.9523353317556198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 90}], {
             RGBColor[
             0.3158328098736569, 0.44792075767621997`, 0.941347743143563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 100}], {
             RGBColor[
             0.2844126072753804, 0.4148961325895252, 0.9395584090876155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 84}], {
             RGBColor[
             0.3438756345570892, 0.4669242029109275, 0.9433281476320208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 100}], {
             RGBColor[
             0.24809701263363243`, 0.37809606891005076`, 0.9374401298916217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 59}], {
             RGBColor[
             0.26182384182735224`, 0.39252383672388913`, 0.9382218525071802]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 66}], {
             RGBColor[
             0.28548649746992133`, 0.41614462386633744`, 0.9396151803770567]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 79}], {
             RGBColor[
             0.24579778430773802`, 0.37567943416004, 0.9373091922398655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 98}], {
             RGBColor[
             0.2718017456530969, 0.4030112462803886, 0.9387900793690704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 99}], {
             RGBColor[
             0.32604506358539376`, 0.45127441530275375`, 0.9421995363454028]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 64}], {
             RGBColor[
             0.2634347031054928, 0.3942169540617188, 0.9383135886739146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 73}], {
             RGBColor[
             0.24675175244976794`, 0.37668211516238714`, 0.9373635193142849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 74}], {
             RGBColor[
             0.3023635304863073, 0.4301296392181001, 0.9407137480474534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 88}], {
             RGBColor[
             0.26551857031897064`, 0.39640723062789657`, 0.9384322618289168]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 89}], {
             RGBColor[
             0.2431918362429577, 0.37294041751730556`, 0.937160787352731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 91}], {
             RGBColor[
             0.2478234584246726, 0.37780854609209535`, 0.9374245513841087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 93}], {
             RGBColor[
             0.251058389952088, 0.3812086642339142, 0.9376087759489427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 64}], {
             RGBColor[
             0.2692011693049027, 0.4002778756523726, 0.9386419803932486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 70}], {
             RGBColor[
             0.26485491336994227`, 0.39570968509618687`, 0.9383944675474621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 74}], {
             RGBColor[
             0.3081299966857172, 0.43619056080875396`, 0.9410421397667876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 75}], {
             RGBColor[
             0.25952031121468844`, 0.390102679997703, 0.9380906698465571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 88}], {
             RGBColor[
             0.27128503651838054`, 0.40246815221855037`, 0.9387606535482509]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 96}], {
             RGBColor[
             0.26925290833864535`, 0.40033225665728034`, 0.9386449268546793]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 63}], {
             RGBColor[
             0.22145736040975994`, 0.3500961053712548, 0.9359230411073061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 83}], {
             RGBColor[
             0.22400482828107066`, 0.3527736556227943, 0.9360681156339361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 97}], {
             RGBColor[
             0.23746265977054243`, 0.3669186897940284, 0.936834519228184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 66}], {
             RGBColor[
             0.2986049435975745, 0.4299329425040255, 0.9403622564770246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 69}], {
             RGBColor[
             0.34936931708251506`, 0.4739024913250818, 0.9435969174663121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 77}], {
             RGBColor[
             0.3463671935654768, 0.47130220282573854`, 0.9434056248104801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 79}], {
             RGBColor[
             0.2589162304353912, 0.38946775279772805`, 0.9380562683398335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 83}], {
             RGBColor[
             0.24944682557751796`, 0.3795148078971581, 0.9375169997419068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 95}], {
             RGBColor[
             0.430296968658313, 0.5404047867381535, 0.9497463591195126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 97}], {
             RGBColor[
             0.26290465706698973`, 0.3936598420683923, 0.9382834033361547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 98}], {
             RGBColor[
             0.28492019178075007`, 0.41679956491807657`, 0.9395371554690384]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 99}], {
             RGBColor[
             0.33916350971304693`, 0.46506273394044173`, 0.9429466124453707]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 64}], {
             RGBColor[
             0.37754119325177404`, 0.49877954503386207`, 0.9454836107743141]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 71}], {
             RGBColor[
             0.41038752678537255`, 0.5294238797348146, 0.9474961990184465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 74}], {
             RGBColor[
             0.4164700206325886, 0.5346922301902434, 0.9478837701478531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 89}], {
             RGBColor[
             0.357298326389239, 0.4775030084894488, 0.9443308094531306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 93}], {
             RGBColor[
             0.3651648800983693, 0.48577125520605746`, 0.9447787980493423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 67}], {
             RGBColor[
             0.1802334334437405, 0.3067671443820358, 0.933575399451926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 68}], {
             RGBColor[0.49812300000000004`, 0.2197605, 0.5488595000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 72}], {
             RGBColor[
             0.5051859770600657, 0.2740496366999483, 0.5556230148092107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 86}], {
             RGBColor[
             0.5861812358174932, 0.6484737065337263, 0.8459778768352497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 92}], {
             RGBColor[
             0.182593161061527, 0.30924736772370176`, 0.9337097824488547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 94}], {
             RGBColor[
             0.17986770348779496`, 0.3063827390097185, 0.9335545716719839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 83}], {
             RGBColor[
             0.2214038953287198, 0.3500399101811996, 0.9359199963500353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 97}], {
             RGBColor[
             0.23486172681819156`, 0.36418494435243376`, 0.9366863999442832]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 73}], {
             RGBColor[
             0.26832774024843065`, 0.39935984633541977`, 0.938592239900605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 74}], {
             RGBColor[
             0.32393951828497003`, 0.45280737039113284`, 0.9419424686337738]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 88}], {
             RGBColor[
             0.2870945581176334, 0.41908496180092925`, 0.9396609824152371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 89}], {
             RGBColor[
             0.2647678240416204, 0.39561814869033823`, 0.9383895079390514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 91}], {
             RGBColor[
             0.26939944622333534`, 0.400486277265128, 0.938653271970429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 93}], {
             RGBColor[
             0.2726343777507507, 0.4038863954069468, 0.938837496535263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 96}], {
             RGBColor[
             0.28506242993789815`, 0.4169490662396592, 0.9395452557216655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 90}], {
             RGBColor[
             0.26516596283917315`, 0.39603661781002397`, 0.9384121813545784]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 100}], {
             RGBColor[
             0.2337457602408967, 0.3630119927233292, 0.9366228472986309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 69}], {
             RGBColor[
             0.37303197272508415`, 0.4975232784675301, 0.9449902453361887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 77}], {
             RGBColor[
             0.3700298492080458, 0.49492298996818684`, 0.9447989526803566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 79}], {
             RGBColor[
             0.2825788860779602, 0.4130885399401764, 0.93944959620971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 83}], {
             RGBColor[
             0.27310948122008705`, 0.4031355950396065, 0.9389103276117834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 95}], {
             RGBColor[
             0.4539596243008821, 0.5640255738806018, 0.9511396869893891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 97}], {
             RGBColor[
             0.2865673127095588, 0.41728062921084064`, 0.9396767312060312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[
             0.3085828474233191, 0.440420352060525, 0.9409304833389149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 99}], {
             RGBColor[
             0.36282616535561596`, 0.48868352108289015`, 0.9443399403152473]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 68}], {
             RGBColor[
             0.49942943344374047`, 0.22113364438203578`, 0.5489338994519259]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 72}], {
             RGBColor[
             0.5064924105038062, 0.2754227810819841, 0.5556974142611366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 86}], {
             RGBColor[
             0.5874876692612337, 0.649846850915762, 0.8460522762871756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 92}], {
             RGBColor[
             0.1838995945052675, 0.31062051210573755`, 0.9337841819007806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 94}], {
             RGBColor[
             0.18117413693153547`, 0.3077558833917543, 0.9336289711239099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 72}], {
             RGBColor[
             0.8243819770600658, 0.1884161366999483, 0.17098151480921064`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 82}], {
             RGBColor[
             0.8273990728415899, 0.2116068569765438, 0.1738706891369204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 92}], {
             RGBColor[
             0.501789161061527, 0.22361386772370176`, 0.5490682824488547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 71}], {
             RGBColor[
             0.38724985209068863`, 0.5098380909626216, 0.9458961960369879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 77}], {
             RGBColor[
             0.4207942226929865, 0.5388925387892431, 0.9480336136696441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 87}], {
             RGBColor[
             0.6064566505030319, 0.6883381284885098, 0.9639201838642415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 95}], {
             RGBColor[
             0.5047239977858227, 0.6079951227016581, 0.9543743479786766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 97}], {
             RGBColor[
             0.3373316861944994, 0.46125017803189694`, 0.9429113921953187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 98}], {
             RGBColor[
             0.35934722090825977`, 0.48438990088158124`, 0.9441651443282024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 99}], {
             RGBColor[
             0.41359053884055663`, 0.5326530699039465, 0.9475746013045347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 75}], {
             RGBColor[
             0.2709835768789808, 0.4021512990238961, 0.9387434858677567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 96}], {
             RGBColor[
             0.28071617400293775`, 0.4123808756834735, 0.9392977428758789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 77}], {
             RGBColor[
             0.3842477285736503, 0.5072378024632783, 0.9457049033811559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 87}], {
             RGBColor[
             0.5699101563836958, 0.656683392162545, 0.9615914735757531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 82}], {
             RGBColor[
             0.8344620499016556, 0.2658959936764921, 0.180634203946131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 92}], {
             RGBColor[
             0.5088521381215928, 0.27790300442365007`, 0.5558317972580653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 74}], {
             RGBColor[
             0.3072565676292452, 0.4352725314918011, 0.940992399274144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 88}], {
             RGBColor[
             0.2704116074619085, 0.40155012290159753`, 0.9387109130556073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.24808487338589558`, 0.37808330979100657`, 0.9374394385794216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 91}], {
             RGBColor[
             0.25271649556761044`, 0.3829514383657963, 0.9377032026107992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 93}], {
             RGBColor[
             0.2559514270950259, 0.38635155650761516`, 0.9378874271756332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 88}], {
             RGBColor[
             0.3260233854984479, 0.4549976469573106, 0.9420611417887761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 91}], {
             RGBColor[
             0.3083282736041498, 0.43639896242150933`, 0.941053431343968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 96}], {
             RGBColor[
             0.3239912573187127, 0.45286175139604057`, 0.9419454150952044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 96}], {
             RGBColor[
             0.27538157184768386`, 0.40677387058498965`, 0.9389939451749738]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 81}], {
             RGBColor[
             0.7674275617003685, 0.8140817945689018, 0.7914691728156671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 84}], {
             RGBColor[
             0.7155827197184571, 0.7715438433702618, 0.7875115331863431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 85}], {
             RGBColor[
             0.8046624308881429, 0.8443107387872784, 0.7944004381139487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 87}], {
             RGBColor[
             0.6034545269859937, 0.6857378399891666, 0.9637288912084094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 95}], {
             RGBColor[
             0.5017218742687843, 0.6053948342023149, 0.9541830553228445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 97}], {
             RGBColor[
             0.3343295626774611, 0.4586498895325537, 0.9427200995394867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 98}], {
             RGBColor[
             0.35634509739122144`, 0.481789612382238, 0.9439738516723704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 99}], {
             RGBColor[
             0.4105884153235183, 0.5300527814046032, 0.9473833086487027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 83}], {
             RGBColor[
             0.23342076805790374`, 0.3626704053333091, 0.9366043394745922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 98}], {
             RGBColor[
             0.26889413426113584`, 0.39995516235422757`, 0.9386244952017238]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 99}], {
             RGBColor[
             0.3231374521934327, 0.4482183313765927, 0.9420339521780562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 84}], {
             RGBColor[
             0.4886643442635845, 0.5953107817136317, 0.9530123699437607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 85}], {
             RGBColor[
             0.5777440554332705, 0.6680776771306483, 0.9599012748713662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 86}], {
             RGBColor[
             0.9154573086590831, 0.64032006351027, 0.4709890659721701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 87}], {
             RGBColor[
             0.8132980502396094, 0.5621350718207605, 0.5815694198384238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 92}], {
             RGBColor[
             0.5118692339031169, 0.30109372470024554`, 0.558720971585775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 97}], {
             RGBColor[
             0.23740919468950228`, 0.36686249460397324`, 0.9368314744709133]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 85}], {
             RGBColor[
             0.5258992134513589, 0.6255397259320082, 0.9559436352420423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.37246108295649283`, 0.49696932160080975`, 0.9449560466299856]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 90}], {
             RGBColor[
             0.4615407941261787, 0.5697362170178263, 0.951844951557591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 92}], {
             RGBColor[
             0.5898473968790202, 0.652327074257428, 0.8461866592841044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[
             0.5871219393052882, 0.6494624455434448, 0.8460314485072336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 91}], {
             RGBColor[
             0.2714833134368132, 0.40267655383130574`, 0.9387719451254313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 96}], {
             RGBColor[
             0.2871462971513761, 0.419139342805837, 0.9396639288766677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 91}], {
             RGBColor[
             0.24915657936080024`, 0.3792097407207148, 0.9375004706492456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 93}], {
             RGBColor[
             0.25239151088821565`, 0.3826098588625336, 0.9376846952140795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 100}], {
             RGBColor[
             0.27668246103303606`, 0.408141187599933, 0.9390680288895865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 93}], {
             RGBColor[
             0.2570231330699305, 0.38747798743732337`, 0.9379484592454572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 96}], {
             RGBColor[
             0.269451185257078, 0.40054065827003577`, 0.9386562184318596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 94}], {
             RGBColor[
             0.18353386454932197`, 0.3102361067334203, 0.9337633541208386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 98}], {
             RGBColor[
             0.44027487248405767`, 0.5508921962946529, 0.9503145859814027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 99}], {
             RGBColor[
             0.49451819041635453`, 0.5991553653170181, 0.9537240429577352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 99}], {
             RGBColor[
             0.3491414135387916, 0.47555014349694125`, 0.943514839307261]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.058168352269944726`], {
             RGBColor[
             0.2581082061950206, 0.38861846808940276`, 0.9380102525547092]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.058168352269944726`], {
             RGBColor[
             0.5167351398431651, 0.6185478910342742, 0.9550984295530915]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.058168352269944726`], {
             RGBColor[
             0.29928415304751665`, 0.4318969989371937, 0.9403551618136042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.058168352269944726`], {
             RGBColor[
             0.8388093398485373, 0.29931116920282663`, 0.1847971737088267]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.058168352269944726`], {
             RGBColor[
             0.2503401935643895, 0.38045379429416204`, 0.9375678757271396]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.058168352269944726`], {
             RGBColor[
             0.2567233930101477, 0.3871629416298741, 0.9379313894924781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.058168352269944726`], {
             RGBColor[
             0.3134760783279485, 0.4459389561070196, 0.9411953964084129]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.058168352269944726`], {
             RGBColor[
             0.9629022796012385, 0.9718531613853215, 0.9476809433867306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.058168352269944726`], {
             RGBColor[
             0.9513821482973379, 0.8449534494772841, 0.27973913919362886`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.058168352269944726`], {
             RGBColor[
             0.25142577857169485`, 0.38159481296690484`, 0.9376296981873266]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.058168352269944726`], {
             RGBColor[
             0.23420058730117388`, 0.3634900448013817, 0.9366487490268572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.058168352269944726`], {
             RGBColor[
             0.6054182467789488, 0.6905448323731828, 0.9620798885880011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.058168352269944726`], {
             RGBColor[
             0.2733697721409376, 0.40465934153773064`, 0.9388793761578655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.058168352269944726`], {
             RGBColor[
             0.7189648146431117, 0.780380044624954, 0.9726233516815856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.058168352269944726`], {
             RGBColor[
             0.3159380912379023, 0.44807142794525473`, 0.9413522736939626]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.058168352269944726`], {
             RGBColor[
             0.23643110434042502`, 0.36583445963258315`, 0.9367757736724883]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.058168352269944726`], {
             RGBColor[
             0.3883689323709583, 0.5108073820547808, 0.9459675028428829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.058168352269944726`], {
             RGBColor[
             0.21478615482912253`, 0.34308424532714094`, 0.935543125818653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.058168352269944726`], {
             RGBColor[
             0.2667049069717902, 0.39765414566809815`, 0.9384998219462671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.058168352269944726`], {
             RGBColor[
             0.22126439749034046`, 0.3498932891083892, 0.9359120521545081]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.058168352269944726`], {
             RGBColor[
             0.9031780751200748, 0.6532360771028892, 0.2409217513686888]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.058168352269944726`], {
             RGBColor[
             0.9615184195052529, 0.9708210807915982, 0.9500234575607163]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.058168352269944726`], {
             RGBColor[
             0.9867507212149456, 0.9887890969785158, 0.869238367710113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.058168352269944726`], {
             RGBColor[
             0.9075000820526815, 0.6709756796489449, 0.2444305986486977]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.058168352269944726`], {
             RGBColor[
             0.21590777704158132`, 0.3442631413873908, 0.9356070005443611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.058168352269944726`], {
             RGBColor[
             0.2200699987015112, 0.3486379002520725, 0.9358440329104389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.058168352269944726`], {
             RGBColor[
             0.3423524124735395, 0.470950185377176, 0.9430353708858302]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.058168352269944726`], {
             RGBColor[
             0.25608696935210196`, 0.3864940200136776, 0.9378951461066569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.058168352269944726`], {
             RGBColor[
             0.32022364339009624`, 0.4517833578213709, 0.9416253452875354]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.058168352269944726`], {
             RGBColor[
             0.8183671396880012, 0.14218346093971695`, 0.1652216997489344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.058168352269944726`], {
             RGBColor[
             0.40020709231942364`, 0.521061001198922, 0.9467218199267253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.058168352269944726`], {
             RGBColor[
             0.2925332274360039, 0.424801348086088, 0.9399707065871281]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.058168352269944726`], {
             RGBColor[
             0.26822653985771944`, 0.399253478308307, 0.9385864766880666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.058168352269944726`], {
             RGBColor[
             0.5849198016353689, 0.6739032711611944, 0.9604661758980197]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.058168352269944726`], {
             RGBColor[
             0.30247956305812407`, 0.4352555774590384, 0.9405371356865229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.058168352269944726`], {
             RGBColor[
             0.17931968983551683`, 0.3058067419151018, 0.9335233631052001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.058168352269944726`], {
             RGBColor[
             0.7259528934922258, 0.7858391849332483, 0.9733198580739556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.058168352269944726`], {
             RGBColor[
             0.43221396826526043`, 0.5487837484308453, 0.9487612697594249]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.058168352269944726`], {
             RGBColor[
             0.2945197284764503, 0.42688928663103776`, 0.9400838348826166]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.058168352269944726`], {
             RGBColor[
             0.24368869170551716`, 0.37346264411091135`, 0.937189082536292]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.058168352269944726`], {
             RGBColor[
             0.4296145376961023, 0.5465322523230198, 0.9485956363421444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.058168352269944726`], {
             RGBColor[
             0.6562036976848239, 0.731350583054984, 0.9663679100791674]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.058168352269944726`], {
             RGBColor[
             0.25058961099252225`, 0.3807159478251078, 0.9375820796806917]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.058168352269944726`], {
             RGBColor[
             0.7784966273449186, 0.8268867491661398, 0.9785569264152818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.058168352269944726`], {
             RGBColor[
             0.7835977991395453, 0.8308718233424438, 0.9790653635466094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.058168352269944726`], {
             RGBColor[
             0.2710942552210422, 0.40226762897881485`, 0.9387497888356031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.058168352269944726`], {
             RGBColor[
             0.27522154600901727`, 0.40660567328232683`, 0.9389848319401988]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.058168352269944726`], {
             RGBColor[
             0.2569718887301403, 0.38742412638712503`, 0.9379455409561153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.058168352269944726`], {
             RGBColor[
             0.773052930873569, 0.822634092109096, 0.9780143496252536]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.058168352269944726`], {
             RGBColor[
             0.9913508596801138, 0.9906913724520291, 0.7930021685655431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.058168352269944726`], {
             RGBColor[
             0.26072583583622466`, 0.3913697628096132, 0.9381593226903397]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.058168352269944726`], {
             RGBColor[
             0.938739399060755, 0.7948291617006693, 0.26956648639440833`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.058168352269944726`], {
             RGBColor[
             0.3235629561160013, 0.45467570266581214`, 0.9418381233415918]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.058168352269944726`], {
             RGBColor[
             0.2509317668325053, 0.3810755753068633, 0.9376015649496046]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.058168352269944726`], {
             RGBColor[
             0.2487053956996991, 0.3787355180862011, 0.9374747764072122]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.058168352269944726`], {
             RGBColor[
             0.24185871530683006`, 0.3715392228886861, 0.9370848680875943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.058168352269944726`], {
             RGBColor[
             0.25339164770564987`, 0.38366106606999373`, 0.9377416515262625]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.058168352269944726`], {
             RGBColor[
             0.22405829336211083`, 0.3528298508128494, 0.9360711603912069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.058168352269944726`], {
             RGBColor[
             0.2749422879550054, 0.4063121553615771, 0.9389689286071481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.058168352269944726`], {
             RGBColor[
             0.4700716955993926, 0.5806644048329727, 0.9514249122883933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.058168352269944726`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.058168352269944726`], {
             RGBColor[
             0.3660446939663169, 0.4914712487975277, 0.9445450221122881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.058168352269944726`], {
             RGBColor[
             0.21885642745740908`, 0.34736235992966014`, 0.9357749218234052]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.058168352269944726`], {
             RGBColor[
             0.2850106909041555, 0.4168946852347515, 0.9395423092602349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.058168352269944726`], {
             RGBColor[
             0.2222292620470338, 0.35090742293342014`, 0.9359669997636226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.058168352269944726`], {
             RGBColor[
             0.32226759924014353`, 0.45355372964647384`, 0.9417555843469012]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.058168352269944726`], {
             RGBColor[
             0.181539866887481, 0.30814028876407157`, 0.9336497989038519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.058168352269944726`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.058168352269944726`], {
             RGBColor[
             0.42379634621002477`, 0.5414928272885864, 0.9482249063254762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.058168352269944726`], {
             RGBColor[
             0.27631817903423467`, 0.40775830412238, 0.9390472835686617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.058168352269944726`], {
             RGBColor[
             0.3507033579713525, 0.4781833546366567, 0.9435674857484997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.058168352269944726`], {
             RGBColor[
             0.8314449541201315, 0.24270527339989661`, 0.17774502961842129`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.058168352269944726`], {
             RGBColor[
             0.2516447895927058, 0.3818250074360881, 0.9376421705409753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.058168352269944726`], {
             RGBColor[
             0.3628683456657846, 0.48872005554751413`, 0.9443426280073127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.058168352269944726`], {
             RGBColor[
             0.26564897472372695`, 0.3965442939254123, 0.9384396881668516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.058168352269944726`], {
             RGBColor[
             0.9943459371552411, 0.990314856225532, 0.6259683360582495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.058168352269944726`], {
             RGBColor[
             0.4177920991759482, 0.5362922502898999, 0.947842321013812]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.058168352269944726`], {
             RGBColor[
             0.9941943067889412, 0.9918672109047867, 0.7458788913670427]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.058168352269944726`], {
             RGBColor[
             0.24289017291577697`, 0.372623350233879, 0.937143608072519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.058168352269944726`], {
             RGBColor[
             0.26918119100492044`, 0.4002568771923939, 0.9386408426586199]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.058168352269944726`], {
             RGBColor[
             0.5405091862454959, 0.6378487329122717, 0.9569700095730845]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.058168352269944726`], {
             RGBColor[
             0.8374791456831797, 0.2890867139530876, 0.18352337827384074`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.058168352269944726`], {
             RGBColor[
             0.2239513632000305, 0.3527174604327391, 0.9360650708766655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.058168352269944726`], {
             RGBColor[
             0.4368195022816731, 0.5527728305149917, 0.9490547303144369]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.058168352269944726`], {
             RGBColor[
             0.6149789246210449, 0.6983066213490248, 0.9628325401696478]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.058168352269944726`], {
             RGBColor[
             0.9934354716349865, 0.9915534130674525, 0.7584547536704994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.058168352269944726`], {
             RGBColor[
             0.789116954796039, 0.8351834296884333, 0.9796154614030067]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.058168352269944726`], {
             RGBColor[
             0.28917842533111127`, 0.421275238367107, 0.9397796555702393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.058168352269944726`], {
             RGBColor[
             0.24452495717908534`, 0.374341612145925, 0.9372367066178678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.058168352269944726`], {
             RGBColor[
             0.30810266363131256`, 0.4411658126866278, 0.9408573629455341]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.058168352269944726`], {
             RGBColor[
             0.25378820154251513`, 0.3840778692955045, 0.9377642346806232]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.058168352269944726`], {
             RGBColor[
             0.18625932212305402`, 0.3131007354474035, 0.9339185648977094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.058168352269944726`], {
             RGBColor[
             0.26025806459734596`, 0.3908781055791422, 0.9381326838102911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.058168352269944726`], {
             RGBColor[
             0.18080840697558995`, 0.30737147801943704`, 0.9336081433439677]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.058168352269944726`], {
             RGBColor[
             0.5856516493616206, 0.6744974181147299, 0.9605237896318769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.058168352269944726`], {
             RGBColor[
             0.2851141689716408, 0.417003447244567, 0.939548202183096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.058168352269944726`], {
             RGBColor[
             0.25086702617897405`, 0.38100752877520744`, 0.9375978780651611]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.058168352269944726`], {
             RGBColor[
             0.2948980956064947, 0.4272869744745761, 0.9401053823309286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.058168352269944726`], {
             RGBColor[
             0.40338473147108844`, 0.5238133125193064, 0.9469242962835934]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.058168352269944726`], {
             RGBColor[
             0.24526225843475957`, 0.3751165625132382, 0.937278694833639]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{{3.8349502435193233`*^9, 3.8349502581408367`*^9}, 
   3.8349577843740606`*^9, 3.83501892289773*^9, 3.8350190217900667`*^9, 
   3.835020556050778*^9, 3.835044646730012*^9},
 CellLabel->
  "Out[245]=",ExpressionUUID->"6aec6de7-42d7-41c6-a086-8e02435689da"]
}, Open  ]],

Cell["Estimated with Max-Min Deviation v Calculated: (r = 6)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 3.8349503922098827`*^9}, {3.8349504781120467`*^9, 
  3.834950521977162*^9}},ExpressionUUID->"5e5893a2-3fe5-4150-8255-\
5641a33f5a5a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphinf1", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsif1", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}],
      "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"mMDi6f100", ",", "krif1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502554527807`*^9}, {3.8349505249112787`*^9, 3.834950525026289*^9}, {
   3.834957796266032*^9, 3.834957804349044*^9}, {3.835018837121126*^9, 
   3.835018838508815*^9}, {3.8350443533371973`*^9, 3.835044357496614*^9}},
 CellLabel->
  "In[246]:=",ExpressionUUID->"08ca981a-7106-4a9c-b1a9-9dec9ab97d94"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100}, {
          Null, CompressedData["
1:eJwVxVmbqQwAAOCxVtbppLIkW4w1a5YJk8gSaaRCIqr783/Pr/me7715C/Zf
xfZ+fHz883x8/D9363DUk1oFBOGSrgbkKTe9Ubr+DJzlM67jGn44aCN55AiO
7OTWuWMuH0qHqrVObVrjcvv1PnbAe71DT+vplLkyddN8hkqxEiiAOngBnQA/
4nmBl/kz71Cz2Wqmz8zZE8QwHhOwC+aAKIqhFLpCL6gZpsKz8Cpshp+ghVm8
JViWU9t1dtxud0NGCI/IiIU4oXgsHi/Fq3gmo3kQT8YzygyrQz/up/w9/8Gv
+58BCZQwiZcESbpIluT8+c395n89MAjDCIzBI5iHBViCZdiCncDPzznXz/f7
6/6+Nu6Mx9x4N755Y96s9xj4/v75PnvrsXq2Xj/6SZBESYzESZIie6ROmuQz
5MbdtFt1h+5nNkDABEIQI4InZOJMOOEtuqW2s+1quzU9NEwjNEHTI1qmLdpp
99vr9t5fxsuZcrlXPpS19qvz4l7r1/6Fqxm1rPbUoXpQVc1b+CxkC4V67dF5
jB/TB/fYPW6PXCvfah1r1/a1cx1fuevuen2l0qlqaphy0SJWLE6LQlEqXjzR
aCY6jKpRLfeV//pqff3WxLbYEcfiVOTEnShexZenEW0gjUyjQTeG3maumW9+
NevNZqt5DC+p5Wy5XC23S31pLp/+ZCyJJ5P1ZC95AKJACsgAZaAKDAEV0AAX
7KJdrFvsdoWu1L3U7p37+M7dd3fxfr3f7vfH/RV4f79/3vxbeEvv8xswQkbc
SBslo2qohmYYbhAIhoLxYCqYDpaC1aARdIub7ma6ETYbaXMJsDCLsARLsyOW
5VmBlViZPbMW+2Yd7zw2j88/59l5YV6a1+eBRIJIfCfYxE+CT8iJc+IdXACL
0CK1SC+qi4WxcEEFVTCFVIoKpXSVlbJVFF25KCZsIzZh0/bIZm3eFmzJlm3L
th1vJVaJV7KVUqVSr8zDg9ZgsBysBtvBEThFT/gpcyqfeqfD6aSetCADMCEm
xsSZNFNiqgyzYFRGYwzGbU86k/5kwk3WE3Gyn1wnL6/P9+nL+gq+iq/um0dq
kUFkGuEiYuQaefkhKAyhEAlR0AxaQitoCymQDpnQ8z9pR8GG
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[69, 98] -> 
             RGBColor[
              0.8833906315789475, 0.9089074736842107, 0.9453039210526315], 
             UndirectedEdge[29, 33] -> 
             RGBColor[
              0.9781415789473684, 0.9366647894736843, 0.477046052631579], 
             UndirectedEdge[55, 59] -> RGBColor[0.178927, 0.305394, 0.933501],
              UndirectedEdge[47, 74] -> 
             RGBColor[
              0.8836998157894738, 0.8952539473684211, 0.6872282105263157], 
             UndirectedEdge[19, 43] -> 
             RGBColor[
              0.9630773947368421, 0.8790152105263156, 0.5006163157894736], 
             UndirectedEdge[57, 75] -> 
             RGBColor[
              0.5391653157894737, 0.4707456052631579, 0.5856366315789474], 
             UndirectedEdge[19, 46] -> 
             RGBColor[
              0.5756894736842105, 0.5572188157894735, 0.5997710526315789], 
             UndirectedEdge[36, 67] -> 
             RGBColor[
              0.8441148157894738, 0.8344205789473684, 0.6396062105263158], 
             UndirectedEdge[79, 99] -> 
             RGBColor[
              0.9612216315789474, 0.9705997368421053, 0.9505258421052631], 
             UndirectedEdge[52, 68] -> 
             RGBColor[
              0.5850616052631579, 0.6480107105263158, 0.8645330526315789], 
             UndirectedEdge[81, 85] -> 
             RGBColor[
              0.9664009736842105, 0.9721106315789474, 0.8188312368421053], 
             UndirectedEdge[12, 88] -> 
             RGBColor[
              0.991122394736842, 0.9899660000000001, 0.7509289210526316], 
             UndirectedEdge[72, 82] -> 
             RGBColor[
              0.9325070526315788, 0.7477196315789474, 0.4309388157894737], 
             UndirectedEdge[31, 44] -> 
             RGBColor[
              0.9677441315789473, 0.9099537368421052, 0.5652281052631579], 
             UndirectedEdge[17, 79] -> 
             RGBColor[
              0.9343418157894736, 0.8330353157894737, 0.6070237894736842], 
             UndirectedEdge[91, 96] -> 
             RGBColor[
              0.5319302631578946, 0.43789292105263145`, 0.5795995263157895], 
             UndirectedEdge[55, 99] -> 
             RGBColor[
              0.5739027105263157, 0.6408520789473684, 0.9355329473684211], 
             UndirectedEdge[77, 99] -> 
             RGBColor[
              0.9817145526315789, 0.9835314736842106, 0.7929093421052631], 
             UndirectedEdge[29, 38] -> 
             RGBColor[0.8969485, 0.8757931052631579, 0.6448460526315789], 
             UndirectedEdge[26, 90] -> 
             RGBColor[
              0.887855552631579, 0.7159852105263158, 0.6022241842105263], 
             UndirectedEdge[13, 27] -> 
             RGBColor[0.8476877894736843, 0.8812872631578947, 0.9554695], 
             UndirectedEdge[22, 99] -> 
             RGBColor[
              0.9812757631578948, 0.9825929473684211, 0.7451498157894735], 
             UndirectedEdge[73, 74] -> 
             RGBColor[
              0.8488540263157895, 0.7656326315789475, 0.6147628157894737], 
             UndirectedEdge[8, 77] -> 
             RGBColor[
              0.9664009736842105, 0.9721106315789474, 0.8188312368421053], 
             UndirectedEdge[36, 94] -> 
             RGBColor[
              0.8323742105263158, 0.8698664210526316, 0.9813913947368421], 
             UndirectedEdge[21, 87] -> 
             RGBColor[0.9731801842105263, 0.975944, 0.7103512368421052], 
             UndirectedEdge[59, 83] -> 
             RGBColor[
              0.5319302631578946, 0.43789292105263145`, 0.5795995263157895], 
             UndirectedEdge[24, 42] -> 
             RGBColor[
              0.5838583157894737, 0.5896055526315789, 0.606343894736842], 
             UndirectedEdge[33, 42] -> 
             RGBColor[
              0.6072365789473684, 0.6696178157894737, 0.7920447105263158], 
             UndirectedEdge[14, 42] -> 
             RGBColor[
              0.6073103947368421, 0.6702792368421053, 0.836680894736842], 
             UndirectedEdge[45, 78] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[15, 38] -> 
             RGBColor[
              0.8736416578947368, 0.7850953684210527, 0.6172072894736842], 
             UndirectedEdge[84, 85] -> 
             RGBColor[
              0.9817145526315789, 0.9835314736842106, 0.7929093421052631], 
             UndirectedEdge[55, 98] -> 
             RGBColor[0.5815595, 0.6465624999999999, 0.922572], 
             UndirectedEdge[86, 92] -> 
             RGBColor[
              0.9099293157894737, 0.9290943157894738, 0.9187289210526316], 
             UndirectedEdge[72, 92] -> 
             RGBColor[
              0.8513139736842106, 0.686847947368421, 0.5987388157894737], 
             UndirectedEdge[19, 99] -> 
             RGBColor[
              0.950167447368421, 0.8711324736842103, 0.6006356842105263], 
             UndirectedEdge[4, 76] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.9634867894736842], 
             UndirectedEdge[23, 76] -> 
             RGBColor[
              0.9612216315789474, 0.9705997368421053, 0.9505258421052631], 
             UndirectedEdge[9, 72] -> 
             RGBColor[
              0.9290787631578947, 0.7469328421052632, 0.533613947368421], 
             UndirectedEdge[2, 44] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[74, 88] -> 
             RGBColor[
              0.8885699736842105, 0.9104183684210527, 0.8136093157894737], 
             UndirectedEdge[21, 49] -> 
             RGBColor[
              0.5858612631578948, 0.6461963421052632, 0.6953583421052633], 
             UndirectedEdge[21, 34] -> 
             RGBColor[
              0.9884937631578947, 0.9873648421052632, 0.6844293421052632], 
             UndirectedEdge[59, 66] -> RGBColor[0.178927, 0.305394, 0.933501],
              UndirectedEdge[17, 99] -> 
             RGBColor[
              0.9419986052631579, 0.8387457368421053, 0.5940628421052632], 
             UndirectedEdge[26, 53] -> 
             RGBColor[
              0.9308298157894737, 0.747656947368421, 0.5045944736842105], 
             UndirectedEdge[23, 50] -> 
             RGBColor[
              0.9710749210526315, 0.9489052631578947, 0.6441149210526314], 
             UndirectedEdge[41, 74] -> 
             RGBColor[
              0.8881311842105264, 0.9094798421052632, 0.765849789473684], 
             UndirectedEdge[59, 79] -> 
             RGBColor[
              0.5662459210526316, 0.6351416578947369, 0.9484938947368421], 
             UndirectedEdge[56, 93] -> 
             RGBColor[
              0.5585891315789473, 0.6294312368421053, 0.9614548421052631], 
             UndirectedEdge[19, 98] -> 
             RGBColor[
              0.9578242368421053, 0.876842894736842, 0.5876747368421051], 
             UndirectedEdge[2, 38] -> 
             RGBColor[
              0.9005214736842105, 0.9226597894736842, 0.960709342105263], 
             UndirectedEdge[19, 59] -> 
             RGBColor[
              0.5551917368421052, 0.535674394736842, 0.5986037368421053], 
             UndirectedEdge[24, 76] -> 
             RGBColor[0.9506795, 0.8978087894736841, 0.6201694736842105], 
             UndirectedEdge[5, 20] -> 
             RGBColor[
              0.9945506842105263, 0.9907527894736843, 0.6482537894736843], 
             UndirectedEdge[37, 84] -> 
             RGBColor[
              0.9612216315789474, 0.9705997368421053, 0.9505258421052631], 
             UndirectedEdge[9, 82] -> 
             RGBColor[
              0.991122394736842, 0.9899660000000001, 0.7509289210526316], 
             UndirectedEdge[47, 75] -> 
             RGBColor[
              0.5818686842105263, 0.6329089736842105, 0.6644962894736841], 
             UndirectedEdge[51, 75] -> 
             RGBColor[
              0.5662459210526316, 0.6351416578947369, 0.9484938947368421], 
             UndirectedEdge[58, 63] -> 
             RGBColor[
              0.8441148157894738, 0.8344205789473684, 0.6396062105263158], 
             UndirectedEdge[7, 25] -> 
             RGBColor[
              0.9269059736842105, 0.7733509999999999, 0.5816314736842104], 
             UndirectedEdge[1, 55] -> 
             RGBColor[
              0.4807581315789474, 0.5677389736842106, 0.9562329210526316], 
             UndirectedEdge[82, 86] -> 
             RGBColor[
              0.991122394736842, 0.9899660000000001, 0.7509289210526316], 
             UndirectedEdge[34, 71] -> 
             RGBColor[
              0.9729622368421053, 0.9351538947368421, 0.6087406578947369], 
             UndirectedEdge[41, 73] -> 
             RGBColor[
              0.954395947368421, 0.8450285263157895, 0.4016477631578946], 
             UndirectedEdge[92, 94] -> 
             RGBColor[
              0.885207894736842, 0.911238947368421, 0.9866312368421053], 
             UndirectedEdge[3, 62] -> 
             RGBColor[
              0.9782153947368422, 0.9373262105263158, 0.5216822368421052], 
             UndirectedEdge[70, 75] -> 
             RGBColor[
              0.4807581315789474, 0.5677389736842106, 0.9562329210526316], 
             UndirectedEdge[57, 96] -> 
             RGBColor[
              0.8921685789473683, 0.6032445263157893, 0.2317351578947368], 
             UndirectedEdge[68, 72] -> 
             RGBColor[
              0.5246952105263158, 0.4050402368421052, 0.5735624210526316], 
             UndirectedEdge[13, 54] -> 
             RGBColor[
              0.9196709210526315, 0.7404983157894737, 0.5755943684210526], 
             UndirectedEdge[48, 96] -> 
             RGBColor[
              0.9345627631578947, 0.7790614210526314, 0.5686705263157894], 
             UndirectedEdge[30, 50] -> 
             RGBColor[
              0.9605327894736841, 0.8761143157894735, 0.3137585526315788], 
             UndirectedEdge[11, 92] -> 
             RGBColor[0.8969485, 0.8757931052631579, 0.6448460526315789], 
             UndirectedEdge[41, 56] -> 
             RGBColor[
              0.5863000526315789, 0.6471348684210526, 0.7431178684210524], 
             UndirectedEdge[73, 91] -> 
             RGBColor[
              0.5470228947368421, 0.5032876578947368, 0.5920308947368421], 
             UndirectedEdge[32, 39] -> 
             RGBColor[0.9539571578947368, 0.84409, 0.35388823684210535`], 
             UndirectedEdge[32, 80] -> 
             RGBColor[
              0.9902448157894737, 0.9880889473684211, 0.6554098684210528], 
             UndirectedEdge[20, 66] -> 
             RGBColor[
              0.5867388421052632, 0.6480733947368421, 0.7908773947368422], 
             UndirectedEdge[47, 88] -> 
             RGBColor[
              0.9896805263157895, 0.9755883684210527, 0.5218726842105263], 
             UndirectedEdge[14, 53] -> 
             RGBColor[
              0.9929472631578947, 0.9913515263157895, 0.7665456315789474], 
             UndirectedEdge[51, 57] -> 
             RGBColor[
              0.9264842368421052, 0.8004932631578947, 0.6006295263157895], 
             UndirectedEdge[30, 94] -> 
             RGBColor[
              0.9430227105263158, 0.8920983684210526, 0.6331304210526316], 
             UndirectedEdge[22, 69] -> 
             RGBColor[
              0.8881311842105264, 0.9094798421052632, 0.765849789473684], 
             UndirectedEdge[4, 94] -> 
             RGBColor[
              0.9459080526315788, 0.959178894736842, 0.9764477368421052], 
             UndirectedEdge[4, 86] -> 
             RGBColor[
              0.9706294736842105, 0.9770342631578948, 0.9085454210526316], 
             UndirectedEdge[9, 94] -> 
             RGBColor[
              0.9629726842105262, 0.9713238421052632, 0.9215063684210527], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.9817145526315789, 0.9835314736842106, 0.7929093421052631], 
             UndirectedEdge[12, 60] -> 
             RGBColor[
              0.9862522368421052, 0.9748015789473685, 0.6245478157894737], 
             UndirectedEdge[25, 40] -> 
             RGBColor[
              0.8585490263157894, 0.7197006315789471, 0.6047759210526316], 
             UndirectedEdge[22, 95] -> 
             RGBColor[
              0.905496052631579, 0.5615013684210526, 0.35847636842105246`], 
             UndirectedEdge[3, 33] -> 
             RGBColor[
              0.9781415789473684, 0.9366647894736843, 0.477046052631579], 
             UndirectedEdge[48, 93] -> 
             RGBColor[
              0.9612216315789472, 0.9705997368421053, 0.9505258421052631], 
             UndirectedEdge[15, 90] -> 
             RGBColor[
              0.9101832368421052, 0.8142326315789474, 0.6206926578947368], 
             UndirectedEdge[77, 97] -> 
             RGBColor[
              0.9469771578947368, 0.8134250000000001, 0.44301302631578954`], 
             UndirectedEdge[44, 78] -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 
             UndirectedEdge[30, 92] -> 
             RGBColor[
              0.8899793421052632, 0.8498688421052631, 0.6303529736842105], 
             UndirectedEdge[37, 76] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.9634867894736842], 
             UndirectedEdge[9, 11] -> 
             RGBColor[0.9747132894736842, 0.935878, 0.5797211842105263], 
             UndirectedEdge[75, 96] -> 
             RGBColor[
              0.5319302631578946, 0.43789292105263145`, 0.5795995263157895], 
             UndirectedEdge[31, 80] -> 
             RGBColor[
              0.9677441315789473, 0.9099537368421052, 0.5652281052631579], 
             UndirectedEdge[85, 90] -> 
             RGBColor[
              0.9498991842105263, 0.9590183684210527, 0.8195391578947369], 
             UndirectedEdge[91, 93] -> 
             RGBColor[
              0.5585891315789473, 0.6294312368421053, 0.9614548421052631], 
             UndirectedEdge[22, 49] -> 
             RGBColor[
              0.5863000526315789, 0.6471348684210526, 0.7431178684210524], 
             UndirectedEdge[69, 87] -> 
             RGBColor[
              0.8680770526315791, 0.8974866315789474, 0.9712258157894736], 
             UndirectedEdge[47, 70] -> 
             RGBColor[
              0.8836998157894738, 0.8952539473684211, 0.6872282105263157], 
             UndirectedEdge[42, 78] -> 
             RGBColor[
              0.6038082894736843, 0.6688310263157895, 0.8947198421052631], 
             UndirectedEdge[1, 43] -> 
             RGBColor[0.8886437894736843, 0.9110797894736843, 0.8582455], 
             UndirectedEdge[10, 35] -> 
             RGBColor[
              0.934871947368421, 0.7654078947368419, 0.31059481578947357`], 
             UndirectedEdge[67, 94] -> 
             RGBColor[0.9499918684210527, 0.9180226315789474, 0.6476235], 
             UndirectedEdge[73, 93] -> 
             RGBColor[
              0.9266850263157894, 0.8273248947368421, 0.6199847368421052], 
             UndirectedEdge[68, 82] -> 
             RGBColor[
              0.5867388421052631, 0.6480733947368422, 0.7908773947368422], 
             UndirectedEdge[11, 52] -> 
             RGBColor[
              0.9764643421052632, 0.9366021052631579, 0.5507017105263158], 
             UndirectedEdge[15, 53] -> 
             RGBColor[0.9531575, 0.8459043684210527, 0.523062947368421], 
             UndirectedEdge[53, 100] -> 
             RGBColor[
              0.9694951842105264, 0.910677842105263, 0.5362086315789474], 
             UndirectedEdge[58, 83] -> 
             RGBColor[0.923333, 0.7264843157894736, 0.2657681842105263], 
             UndirectedEdge[74, 96] -> 
             RGBColor[
              0.8337613947368421, 0.700237894736842, 0.602331447368421], 
             UndirectedEdge[8, 87] -> 
             RGBColor[
              0.9459080526315788, 0.959178894736842, 0.9764477368421052], 
             UndirectedEdge[43, 46] -> 
             RGBColor[
              0.6073103947368421, 0.6702792368421053, 0.836680894736842], 
             UndirectedEdge[73, 89] -> 
             RGBColor[
              0.9343418157894736, 0.8330353157894737, 0.6070237894736842], 
             UndirectedEdge[11, 67] -> 
             RGBColor[
              0.9617324736842106, 0.8825767894736842, 0.30583831578947374`], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.9499645789473684, 0.8308026315789474, 0.32302618421052626`], 
             UndirectedEdge[98, 99] -> 
             RGBColor[
              0.9765352105263158, 0.9820205789473684, 0.924603947368421], 
             UndirectedEdge[4, 9] -> 
             RGBColor[
              0.9706294736842105, 0.9770342631578948, 0.9085454210526316], 
             UndirectedEdge[34, 49] -> 
             RGBColor[0.5815595, 0.6465625, 0.922572], UndirectedEdge[6, 7] -> 
             RGBColor[
              0.9583362894736842, 0.9035192105263157, 0.6072085263157894], 
             UndirectedEdge[7, 40] -> 
             RGBColor[
              0.9005214736842105, 0.9226597894736842, 0.960709342105263], 
             UndirectedEdge[23, 85] -> 
             RGBColor[
              0.9817145526315789, 0.9835314736842106, 0.7929093421052631], 
             UndirectedEdge[82, 92] -> 
             RGBColor[
              0.9133576052631579, 0.9298811052631579, 0.8160537894736842], 
             UndirectedEdge[34, 69] -> 
             RGBColor[
              0.8833906315789475, 0.9089074736842107, 0.9453039210526315], 
             UndirectedEdge[13, 85] -> 
             RGBColor[
              0.9817145526315789, 0.9835314736842106, 0.7929093421052631], 
             UndirectedEdge[95, 98] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], UndirectedEdge[34, 87] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[61, 94] -> 
             RGBColor[
              0.9664747894736841, 0.972772052631579, 0.8634674210526316], 
             UndirectedEdge[61, 72] -> 
             RGBColor[
              0.9325808684210526, 0.748381052631579, 0.47557499999999997`], 
             UndirectedEdge[50, 86] -> 
             RGBColor[
              0.9804827631578947, 0.9553397894736841, 0.6021344999999999], 
             UndirectedEdge[66, 97] -> 
             RGBColor[
              0.5391653157894736, 0.4707456052631579, 0.5856366315789474], 
             UndirectedEdge[9, 21] -> 
             RGBColor[
              0.9902448157894737, 0.9880889473684211, 0.6554098684210528], 
             UndirectedEdge[34, 60] -> 
             RGBColor[
              0.9845011842105262, 0.9740774736842106, 0.6535672894736841], 
             UndirectedEdge[53, 84] -> 
             RGBColor[
              0.9800373157894737, 0.9834687894736842, 0.8665649999999999], 
             UndirectedEdge[21, 22] -> 
             RGBColor[
              0.9932343157894736, 0.9879372105263158, 0.5049752105263157], 
             UndirectedEdge[14, 62] -> 
             RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947369], 
             UndirectedEdge[22, 30] -> 
             RGBColor[0.9707336315789474, 0.909802, 0.4147934473684209], 
             UndirectedEdge[67, 72] -> 
             RGBColor[
              0.916097947368421, 0.6936316315789474, 0.25973107894736847`], 
             UndirectedEdge[61, 86] -> 
             RGBColor[
              0.9911962105263157, 0.9906274210526316, 0.7955651052631579], 
             UndirectedEdge[5, 83] -> 
             RGBColor[
              0.9397421052631578, 0.7805723157894735, 0.4369759210526316], 
             UndirectedEdge[46, 99] -> 
             RGBColor[0.594400447368421, 0.6623965, 0.9367002631578947], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.5662459210526316, 0.6351416578947369, 0.9484938947368421], 
             UndirectedEdge[7, 37] -> 
             RGBColor[
              0.9612216315789474, 0.9705997368421053, 0.9505258421052631], 
             UndirectedEdge[7, 53] -> 
             RGBColor[
              0.9800373157894737, 0.9834687894736842, 0.8665649999999999], 
             UndirectedEdge[12, 52] -> 
             RGBColor[
              0.9894451578947367, 0.9899033157894737, 0.8245845789473685], 
             UndirectedEdge[50, 85] -> 
             RGBColor[
              0.9839110526315789, 0.9561265789473683, 0.49945936842105254`], 
             UndirectedEdge[14, 15] -> 
             RGBColor[
              0.9549085526315789, 0.8466284736842106, 0.49404347368421053`], 
             UndirectedEdge[14, 35] -> 
             RGBColor[
              0.9398159210526316, 0.7812337368421052, 0.4816121052631579], 
             UndirectedEdge[8, 95] -> 
             RGBColor[
              0.8777851315789473, 0.5437977368421052, 0.5768133421052631], 
             UndirectedEdge[7, 84] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[14, 76] -> 
             RGBColor[
              0.9741315789473683, 0.9784824736842106, 0.8505064736842105], 
             UndirectedEdge[60, 89] -> 
             RGBColor[
              0.9691876052631578, 0.9626566315789473, 0.6794891842105262], 
             UndirectedEdge[37, 85] -> 
             RGBColor[
              0.9740577631578947, 0.9778210526315789, 0.8058702894736842], 
             UndirectedEdge[39, 80] -> 
             RGBColor[
              0.951406447368421, 0.8451802631578949, 0.5520824210526316], 
             UndirectedEdge[23, 24] -> 
             RGBColor[
              0.9583362894736842, 0.9035192105263157, 0.6072085263157894], 
             UndirectedEdge[11, 68] -> 
             RGBColor[
              0.5703297368421053, 0.5939853947368421, 0.6196696578947369], 
             UndirectedEdge[27, 81] -> 
             RGBColor[
              0.8323742105263158, 0.8698664210526316, 0.9813913947368421], 
             UndirectedEdge[36, 61] -> 
             RGBColor[0.8605977368421053, 0.88917, 0.8554501315789473], 
             UndirectedEdge[28, 59] -> 
             RGBColor[
              0.5662459210526316, 0.6351416578947369, 0.9484938947368421], 
             UndirectedEdge[8, 30] -> 
             RGBColor[
              0.9430227105263158, 0.8920983684210526, 0.6331304210526316], 
             UndirectedEdge[34, 82] -> 
             RGBColor[
              0.9893713421052631, 0.9892418947368422, 0.7799483947368422], 
             UndirectedEdge[50, 84] -> 
             RGBColor[
              0.9710749210526315, 0.9489052631578947, 0.6441149210526314], 
             UndirectedEdge[57, 88] -> 
             RGBColor[
              0.9469771578947368, 0.8134250000000001, 0.44301302631578954`], 
             UndirectedEdge[6, 53] -> 
             RGBColor[
              0.9694951842105264, 0.910677842105263, 0.5362086315789474], 
             UndirectedEdge[8, 69] -> 
             RGBColor[
              0.8604202631578948, 0.8917762105263158, 0.9841867631578947], 
             UndirectedEdge[69, 99] -> 
             RGBColor[
              0.8757338421052632, 0.903197052631579, 0.9582648684210526], 
             UndirectedEdge[81, 84] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.9634867894736842], 
             UndirectedEdge[11, 94] -> 
             RGBColor[0.9499918684210527, 0.9180226315789474, 0.6476235], 
             UndirectedEdge[10, 65] -> 
             RGBColor[
              0.9450290263157894, 0.9438539473684211, 0.6931580526315788], 
             UndirectedEdge[79, 98] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[33, 62] -> 
             RGBColor[0.9946245, 0.9914142105263158, 0.6928899736842106], 
             UndirectedEdge[31, 70] -> 
             RGBColor[0.8651917105263158, 0.830406105263158, 0.6279085], 
             UndirectedEdge[31, 32] -> 
             RGBColor[
              0.9702948421052632, 0.9088634736842105, 0.36703392105263166`], 
             UndirectedEdge[15, 100] -> 
             RGBColor[
              0.9314564736842106, 0.7659547894736842, 0.2637064736842105], 
             UndirectedEdge[7, 65] -> 
             RGBColor[
              0.937063052631579, 0.951797052631579, 0.9641947105263158], 
             UndirectedEdge[59, 95] -> 
             RGBColor[0.49812300000000004`, 0.2197605, 0.5488595000000001], 
             UndirectedEdge[2, 3] -> 
             RGBColor[
              0.965305447368421, 0.9294434736842105, 0.6217016052631579], 
             UndirectedEdge[48, 88] -> 
             RGBColor[
              0.9893713421052631, 0.9892418947368422, 0.7799483947368422], 
             UndirectedEdge[14, 38] -> 
             RGBColor[
              0.9134314210526315, 0.9305425263157895, 0.8606899736842105], 
             UndirectedEdge[44, 45] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[24, 50] -> 
             RGBColor[
              0.9605327894736841, 0.8761143157894735, 0.3137585526315788], 
             UndirectedEdge[38, 62] -> 
             RGBColor[
              0.9134314210526315, 0.9305425263157895, 0.8606899736842105], 
             UndirectedEdge[4, 50] -> 
             RGBColor[
              0.9634181315789474, 0.943194842105263, 0.6570758684210525], 
             UndirectedEdge[48, 74] -> 
             RGBColor[
              0.8833906315789475, 0.9089074736842107, 0.9453039210526315], 
             UndirectedEdge[40, 100] -> 
             RGBColor[
              0.8899793421052632, 0.8498688421052631, 0.6303529736842105], 
             UndirectedEdge[19, 95] -> 
             RGBColor[
              0.8743877368421052, 0.45004089473684195`, 0.21396223684210525`],
              UndirectedEdge[19, 79] -> 
             RGBColor[
              0.9425106578947369, 0.8654220526315788, 0.6135966315789474], 
             UndirectedEdge[51, 70] -> 
             RGBColor[
              0.8680770526315791, 0.8974866315789474, 0.9712258157894736], 
             UndirectedEdge[17, 22] -> 
             RGBColor[
              0.954395947368421, 0.8450285263157895, 0.4016477631578946], 
             UndirectedEdge[59, 99] -> 
             RGBColor[
              0.5739027105263157, 0.6408520789473684, 0.9355329473684211], 
             UndirectedEdge[20, 63] -> 
             RGBColor[
              0.8605239210526316, 0.8885085789473685, 0.810813947368421], 
             UndirectedEdge[56, 89] -> 
             RGBColor[
              0.5662459210526316, 0.6351416578947369, 0.9484938947368421], 
             UndirectedEdge[12, 74] -> 
             RGBColor[
              0.8851416842105264, 0.9096315789473686, 0.9162844473684211], 
             UndirectedEdge[8, 17] -> 
             RGBColor[
              0.9266850263157894, 0.8273248947368421, 0.6199847368421052], 
             UndirectedEdge[53, 90] -> 
             RGBColor[
              0.948221947368421, 0.9589556842105263, 0.8931948157894736], 
             UndirectedEdge[21, 72] -> 
             RGBColor[
              0.9316294736842106, 0.7458425789473684, 0.3354197631578948], 
             UndirectedEdge[48, 73] -> 
             RGBColor[
              0.949655394736842, 0.8444561578947369, 0.581101894736842], 
             UndirectedEdge[8, 49] -> 
             RGBColor[
              0.5585891315789473, 0.6294312368421052, 0.9614548421052631], 
             UndirectedEdge[17, 69] -> 
             RGBColor[
              0.8488540263157895, 0.7656326315789475, 0.6147628157894737], 
             UndirectedEdge[21, 82] -> 
             RGBColor[
              0.9936731052631579, 0.9888757368421053, 0.5527347368421054], 
             UndirectedEdge[36, 68] -> 
             RGBColor[
              0.4527120789473684, 0.5458291842105263, 0.953437552631579], 
             UndirectedEdge[21, 30] -> 
             RGBColor[
              0.9702948421052632, 0.9088634736842105, 0.36703392105263166`], 
             UndirectedEdge[56, 64] -> 
             RGBColor[
              0.5818686842105263, 0.6329089736842106, 0.6644962894736841], 
             UndirectedEdge[48, 64] -> 
             RGBColor[
              0.9845011842105262, 0.9740774736842106, 0.6535672894736841], 
             UndirectedEdge[46, 59] -> 
             RGBColor[
              0.19942473684210527`, 0.3269384210526316, 0.9346683157894737], 
             UndirectedEdge[46, 79] -> 
             RGBColor[
              0.5867436578947369, 0.6566860789473684, 0.9496612105263158], 
             UndirectedEdge[9, 86] -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 
             UndirectedEdge[64, 91] -> 
             RGBColor[
              0.5818686842105263, 0.6329089736842105, 0.6644962894736841], 
             UndirectedEdge[1, 19] -> 
             RGBColor[
              0.8570228684210527, 0.7980193684210526, 0.6213356578947368], 
             UndirectedEdge[5, 69] -> 
             RGBColor[
              0.8885699736842105, 0.9104183684210527, 0.8136093157894737], 
             UndirectedEdge[36, 92] -> 
             RGBColor[
              0.7793308421052632, 0.8276368947368421, 0.978613947368421], 
             UndirectedEdge[17, 95] -> 
             RGBColor[
              0.8662188947368421, 0.41765415789473687`, 0.2073893947368421], 
             UndirectedEdge[7, 13] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[11, 61] -> 
             RGBColor[
              0.9782153947368422, 0.9373262105263158, 0.5216822368421052], 
             UndirectedEdge[66, 83] -> 
             RGBColor[
              0.5319302631578946, 0.43789292105263145`, 0.5795995263157895], 
             UndirectedEdge[27, 37] -> 
             RGBColor[0.840031, 0.8755768421052632, 0.9684304473684211], 
             UndirectedEdge[22, 34] -> 
             RGBColor[
              0.9889325526315789, 0.9883033684210527, 0.7321888684210525], 
             UndirectedEdge[6, 90] -> 
             RGBColor[
              0.9265209210526316, 0.8790061052631579, 0.6338383421052631], 
             UndirectedEdge[71, 77] -> 
             RGBColor[
              0.9781415789473684, 0.9366647894736843, 0.477046052631579], 
             UndirectedEdge[9, 68] -> 
             RGBColor[
              0.5833105526315789, 0.647286605263158, 0.8935525263157895], 
             UndirectedEdge[23, 86] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[54, 84] -> 
             RGBColor[
              0.9196709210526315, 0.7404983157894737, 0.5755943684210525], 
             UndirectedEdge[3, 16] -> 
             RGBColor[
              0.965305447368421, 0.9294434736842105, 0.6217016052631579], 
             UndirectedEdge[66, 98] -> 
             RGBColor[0.5815595, 0.6465624999999999, 0.922572], 
             UndirectedEdge[64, 93] -> 
             RGBColor[
              0.9615308157894736, 0.9569462105263158, 0.6924501315789473], 
             UndirectedEdge[2, 29] -> 
             RGBColor[
              0.965305447368421, 0.9294434736842105, 0.6217016052631579], 
             UndirectedEdge[50, 81] -> 
             RGBColor[
              0.9557613421052631, 0.9374844210526314, 0.6700368157894736], 
             UndirectedEdge[8, 99] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.9634867894736842], 
             UndirectedEdge[66, 69] -> 
             RGBColor[
              0.4807581315789475, 0.5677389736842107, 0.9562329210526316], 
             UndirectedEdge[9, 30] -> 
             RGBColor[
              0.9677441315789473, 0.9099537368421052, 0.5652281052631579], 
             UndirectedEdge[11, 36] -> 
             RGBColor[
              0.8441148157894738, 0.8344205789473684, 0.6396062105263158], 
             UndirectedEdge[16, 62] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157894], 
             UndirectedEdge[50, 76] -> 
             RGBColor[
              0.9634181315789474, 0.943194842105263, 0.6570758684210525], 
             UndirectedEdge[36, 86] -> 
             RGBColor[
              0.8570956315789473, 0.8877217894736842, 0.9134890789473684], 
             UndirectedEdge[60, 71] -> 
             RGBColor[
              0.9732714210526316, 0.9215003684210527, 0.350664947368421], 
             UndirectedEdge[43, 54] -> 
             RGBColor[
              0.9325808684210526, 0.748381052631579, 0.47557499999999997`], 
             UndirectedEdge[29, 42] -> 
             RGBColor[
              0.5908274736842105, 0.6155298157894737, 0.6208369736842105], 
             UndirectedEdge[76, 84] -> 
             RGBColor[
              0.9612216315789474, 0.9705997368421053, 0.9505258421052631], 
             UndirectedEdge[65, 90] -> 
             RGBColor[
              0.9052476842105264, 0.9272839473684211, 0.9908245263157894], 
             UndirectedEdge[52, 78] -> 
             RGBColor[
              0.9894451578947367, 0.9899033157894737, 0.8245845789473685], 
             UndirectedEdge[25, 65] -> 
             RGBColor[
              0.8950906052631579, 0.7488378947368419, 0.6082612894736841], 
             UndirectedEdge[45, 52] -> 
             RGBColor[
              0.9800373157894737, 0.9834687894736842, 0.8665649999999999], 
             UndirectedEdge[57, 74] -> 
             RGBColor[
              0.840996447368421, 0.7330905789473685, 0.608368552631579], 
             UndirectedEdge[17, 66] -> 
             RGBColor[
              0.5470228947368421, 0.5032876578947368, 0.5920308947368421], 
             UndirectedEdge[59, 98] -> 
             RGBColor[0.5815595, 0.6465624999999999, 0.922572], 
             UndirectedEdge[22, 77] -> 
             RGBColor[
              0.9941118947368421, 0.9898142631578948, 0.6004942631578947], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.9664009736842105, 0.9721106315789474, 0.8188312368421053], 
             UndirectedEdge[30, 36] -> 
             RGBColor[
              0.8371456578947369, 0.8084963157894736, 0.6251131315789473], 
             UndirectedEdge[60, 64] -> 
             RGBColor[
              0.9848103684210526, 0.9604239473684211, 0.3954915789473683], 
             UndirectedEdge[28, 99] -> 
             RGBColor[
              0.9612216315789474, 0.9705997368421053, 0.9505258421052631], 
             UndirectedEdge[59, 69] -> 
             RGBColor[
              0.4807581315789475, 0.5677389736842107, 0.9562329210526316], 
             UndirectedEdge[66, 79] -> 
             RGBColor[
              0.5662459210526316, 0.6351416578947369, 0.9484938947368421], 
             UndirectedEdge[7, 81] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.9634867894736842], 
             UndirectedEdge[26, 100] -> 
             RGBColor[
              0.9091287894736841, 0.6677073684210526, 0.24523799999999998`], 
             UndirectedEdge[5, 97] -> 
             RGBColor[
              0.9469771578947368, 0.8134250000000001, 0.44301302631578954`], 
             UndirectedEdge[20, 83] -> 
             RGBColor[
              0.9397421052631578, 0.7805723157894735, 0.4369759210526316], 
             UndirectedEdge[21, 92] -> 
             RGBColor[
              0.9124800263157895, 0.9280040526315789, 0.7205347368421053], 
             UndirectedEdge[77, 98] -> 
             RGBColor[
              0.9893713421052631, 0.9892418947368422, 0.7799483947368422], 
             UndirectedEdge[13, 84] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[83, 97] -> 
             RGBColor[
              0.8921685789473683, 0.6032445263157893, 0.2317351578947368], 
             UndirectedEdge[4, 24] -> 
             RGBColor[0.9506795, 0.8978087894736841, 0.6201694736842105], 
             UndirectedEdge[7, 85] -> 
             RGBColor[
              0.9817145526315789, 0.9835314736842106, 0.7929093421052631], 
             UndirectedEdge[10, 40] -> 
             RGBColor[
              0.908487447368421, 0.9147166842105263, 0.6896726842105263], 
             UndirectedEdge[26, 40] -> 
             RGBColor[
              0.8513139736842106, 0.686847947368421, 0.5987388157894737], 
             UndirectedEdge[56, 74] -> 
             RGBColor[
              0.4807581315789475, 0.5677389736842107, 0.9562329210526316], 
             UndirectedEdge[42, 62] -> 
             RGBColor[
              0.6073103947368421, 0.6702792368421053, 0.836680894736842], 
             UndirectedEdge[4, 36] -> 
             RGBColor[0.840031, 0.8755768421052632, 0.9684304473684211], 
             UndirectedEdge[2, 33] -> 
             RGBColor[
              0.9817145526315789, 0.9835314736842106, 0.7929093421052631], 
             UndirectedEdge[36, 82] -> 
             RGBColor[
              0.8605239210526316, 0.8885085789473685, 0.810813947368421], 
             UndirectedEdge[76, 81] -> 
             RGBColor[
              0.9459080526315788, 0.959178894736842, 0.9764477368421052], 
             UndirectedEdge[27, 43] -> 
             RGBColor[0.8605977368421053, 0.88917, 0.8554501315789473], 
             UndirectedEdge[61, 67] -> 
             RGBColor[
              0.9782153947368422, 0.9373262105263158, 0.5216822368421052], 
             UndirectedEdge[10, 26] -> 
             RGBColor[
              0.9276368947368421, 0.7325552105263158, 0.30455771052631575`], 
             UndirectedEdge[63, 83] -> 
             RGBColor[
              0.8057153421052632, 0.6783281052631578, 0.5995360789473684], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.9196709210526315, 0.7404983157894737, 0.5755943684210526], 
             UndirectedEdge[20, 97] -> 
             RGBColor[
              0.9469771578947368, 0.8134250000000001, 0.44301302631578954`], 
             UndirectedEdge[28, 98] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[4, 23] -> 
             RGBColor[
              0.9612216315789474, 0.9705997368421053, 0.9505258421052631], 
             UndirectedEdge[30, 86] -> 
             RGBColor[
              0.9677441315789473, 0.9099537368421052, 0.5652281052631579], 
             UndirectedEdge[27, 54] -> 
             RGBColor[
              0.7984802894736842, 0.6454754210526316, 0.5934989736842106], 
             UndirectedEdge[1, 13] -> 
             RGBColor[
              0.8757338421052632, 0.903197052631579, 0.9582648684210526], 
             UndirectedEdge[15, 35] -> 
             RGBColor[
              0.9000261578947368, 0.6357865789473682, 0.23812942105263155`], 
             UndirectedEdge[56, 73] -> 
             RGBColor[
              0.5470228947368421, 0.5032876578947368, 0.5920308947368421], 
             UndirectedEdge[16, 29] -> 
             RGBColor[
              0.965305447368421, 0.9294434736842105, 0.6217016052631579], 
             UndirectedEdge[53, 65] -> 
             RGBColor[
              0.948221947368421, 0.9589556842105263, 0.8931948157894736], 
             UndirectedEdge[6, 25] -> 
             RGBColor[
              0.9163638421052631, 0.7005600526315787, 0.2512751052631579], 
             UndirectedEdge[68, 92] -> 
             RGBColor[
              0.5055457631578948, 0.5872017105263159, 0.9586773947368421], 
             UndirectedEdge[69, 97] -> 
             RGBColor[
              0.840996447368421, 0.7330905789473685, 0.608368552631579], 
             UndirectedEdge[17, 77] -> 
             RGBColor[
              0.9548347368421053, 0.845967052631579, 0.44940728947368425`], 
             UndirectedEdge[46, 98] -> 
             RGBColor[
              0.6020572368421053, 0.6681069210526316, 0.9237393157894737], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.9782153947368422, 0.9373262105263158, 0.5216822368421052], 
             UndirectedEdge[17, 55] -> 
             RGBColor[
              0.5470228947368421, 0.5032876578947368, 0.5920308947368421], 
             UndirectedEdge[2, 78] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[6, 35] -> 
             RGBColor[
              0.9163638421052631, 0.7005600526315787, 0.2512751052631579], 
             UndirectedEdge[95, 99] -> 
             RGBColor[
              0.8930987105263157, 0.5552185789473685, 0.550891447368421], 
             UndirectedEdge[66, 99] -> 
             RGBColor[
              0.5739027105263157, 0.6408520789473684, 0.9355329473684211], 
             UndirectedEdge[31, 39] -> 
             RGBColor[
              0.9314564736842106, 0.7659547894736842, 0.2637064736842105], 
             UndirectedEdge[69, 71] -> 
             RGBColor[
              0.8721608684210527, 0.8563303684210527, 0.6424015789473685], 
             UndirectedEdge[64, 89] -> 
             RGBColor[
              0.9691876052631578, 0.9626566315789473, 0.6794891842105262], 
             UndirectedEdge[40, 53] -> 
             RGBColor[
              0.9116803684210526, 0.9298184210526316, 0.8897094473684211], 
             UndirectedEdge[1, 27] -> 
             RGBColor[
              0.7545432105263159, 0.8081741578947369, 0.9761694736842106], 
             UndirectedEdge[41, 48] -> 
             RGBColor[
              0.9889325526315789, 0.9883033684210527, 0.7321888684210525], 
             UndirectedEdge[57, 70] -> 
             RGBColor[
              0.840996447368421, 0.7330905789473685, 0.608368552631579], 
             UndirectedEdge[39, 44] -> 
             RGBColor[
              0.951406447368421, 0.8451802631578949, 0.5520824210526316], 
             UndirectedEdge[6, 15] -> 
             RGBColor[
              0.9314564736842106, 0.7659547894736842, 0.2637064736842105], 
             UndirectedEdge[6, 40] -> 
             RGBColor[
              0.8899793421052632, 0.8498688421052631, 0.6303529736842105], 
             UndirectedEdge[17, 59] -> 
             RGBColor[
              0.5470228947368421, 0.5032876578947368, 0.5920308947368421], 
             UndirectedEdge[56, 91] -> RGBColor[0.178927, 0.305394, 0.933501],
              UndirectedEdge[5, 59] -> 
             RGBColor[
              0.5867388421052632, 0.6480733947368421, 0.7908773947368422], 
             UndirectedEdge[20, 58] -> 
             RGBColor[
              0.9781415789473684, 0.9366647894736843, 0.477046052631579], 
             UndirectedEdge[17, 19] -> 
             RGBColor[
              0.9232876315789473, 0.7335680526315789, 0.2571336315789473], 
             UndirectedEdge[3, 38] -> 
             RGBColor[0.8969485, 0.8757931052631579, 0.6448460526315789], 
             UndirectedEdge[1, 17] -> 
             RGBColor[
              0.8488540263157895, 0.7656326315789475, 0.6147628157894737], 
             UndirectedEdge[2, 42] -> 
             RGBColor[0.594400447368421, 0.6623965, 0.9367002631578947], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.9862522368421052, 0.9748015789473685, 0.6245478157894737], 
             UndirectedEdge[48, 56] -> 
             RGBColor[0.5815595, 0.6465625, 0.922572], UndirectedEdge[86, 94] -> 
             RGBColor[
              0.9629726842105262, 0.9713238421052632, 0.9215063684210527], 
             UndirectedEdge[23, 30] -> 
             RGBColor[
              0.9583362894736842, 0.9035192105263157, 0.6072085263157894], 
             UndirectedEdge[30, 82] -> 
             RGBColor[
              0.9711724210526316, 0.9107405263157895, 0.46255297368421056`], 
             UndirectedEdge[60, 74] -> 
             RGBColor[
              0.8836998157894738, 0.8952539473684211, 0.6872282105263157], 
             UndirectedEdge[10, 90] -> 
             RGBColor[
              0.9450290263157894, 0.9438539473684211, 0.6931580526315788], 
             UndirectedEdge[49, 69] -> 
             RGBColor[
              0.4807581315789475, 0.5677389736842107, 0.9562329210526316], 
             UndirectedEdge[25, 100] -> 
             RGBColor[
              0.9163638421052631, 0.7005600526315787, 0.2512751052631579], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[31, 51] -> 
             RGBColor[0.9506795, 0.8978087894736841, 0.6201694736842105], 
             UndirectedEdge[37, 50] -> 
             RGBColor[
              0.9634181315789474, 0.943194842105263, 0.6570758684210525], 
             UndirectedEdge[6, 10] -> 
             RGBColor[
              0.9663022631578948, 0.8955761052631579, 0.33617186842105257`], 
             UndirectedEdge[69, 77] -> 
             RGBColor[
              0.8885699736842105, 0.9104183684210527, 0.8136093157894737], 
             UndirectedEdge[12, 96] -> 
             RGBColor[
              0.9363138157894736, 0.7797855263157893, 0.539651052631579], 
             UndirectedEdge[12, 41] -> 
             RGBColor[
              0.9906836052631578, 0.9890274736842106, 0.703169394736842], 
             UndirectedEdge[89, 93] -> 
             RGBColor[
              0.9459080526315788, 0.959178894736842, 0.9764477368421052], 
             UndirectedEdge[37, 81] -> 
             RGBColor[
              0.9459080526315788, 0.959178894736842, 0.9764477368421052], 
             UndirectedEdge[14, 24] -> 
             RGBColor[
              0.9712462368421053, 0.911401947368421, 0.5071891578947368], 
             UndirectedEdge[52, 67] -> 
             RGBColor[
              0.9764643421052632, 0.9366021052631579, 0.5507017105263158], 
             UndirectedEdge[23, 27] -> 
             RGBColor[0.8476877894736843, 0.8812872631578947, 0.9554695], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.9740577631578947, 0.9778210526315789, 0.8058702894736842], 
             UndirectedEdge[23, 81] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.9634867894736842], 
             UndirectedEdge[88, 96] -> 
             RGBColor[
              0.9397421052631578, 0.7805723157894735, 0.4369759210526316], 
             UndirectedEdge[77, 95] -> 
             RGBColor[
              0.9059348421052631, 0.5624398947368421, 0.40623589473684213`], 
             UndirectedEdge[74, 91] -> 
             RGBColor[
              0.4807581315789474, 0.5677389736842106, 0.9562329210526316], 
             UndirectedEdge[7, 100] -> 
             RGBColor[
              0.9583362894736842, 0.9035192105263157, 0.6072085263157894], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.9941118947368421, 0.9898142631578948, 0.6004942631578947], 
             UndirectedEdge[6, 100] -> 
             RGBColor[
              0.9477941578947369, 0.8307282631578946, 0.27685215789473683`], 
             UndirectedEdge[19, 55] -> 
             RGBColor[
              0.5551917368421052, 0.535674394736842, 0.5986037368421053], 
             UndirectedEdge[17, 28] -> 
             RGBColor[
              0.9343418157894736, 0.8330353157894737, 0.6070237894736842], 
             UndirectedEdge[64, 96] -> 
             RGBColor[
              0.934871947368421, 0.7654078947368419, 0.31059481578947357`], 
             UndirectedEdge[67, 68] -> 
             RGBColor[
              0.5703297368421053, 0.5939853947368421, 0.6196696578947369], 
             UndirectedEdge[22, 87] -> 
             RGBColor[
              0.9736189736842105, 0.9768825263157894, 0.7581107631578945], 
             UndirectedEdge[42, 44] -> 
             RGBColor[
              0.6038082894736843, 0.6688310263157895, 0.8947198421052631], 
             UndirectedEdge[70, 96] -> 
             RGBColor[
              0.8337613947368421, 0.700237894736842, 0.602331447368421], 
             UndirectedEdge[64, 88] -> 
             RGBColor[
              0.9896805263157895, 0.9755883684210527, 0.5218726842105263], 
             UndirectedEdge[26, 65] -> 
             RGBColor[
              0.887855552631579, 0.7159852105263158, 0.6022241842105263], 
             UndirectedEdge[2, 14] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157894], 
             UndirectedEdge[11, 72] -> 
             RGBColor[
              0.916097947368421, 0.6936316315789474, 0.25973107894736847`], 
             UndirectedEdge[67, 86] -> 
             RGBColor[0.9747132894736842, 0.935878, 0.5797211842105263], 
             UndirectedEdge[40, 90] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[27, 84] -> 
             RGBColor[0.8476877894736843, 0.8812872631578947, 0.9554695], 
             UndirectedEdge[13, 43] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157894], 
             UndirectedEdge[52, 72] -> 
             RGBColor[
              0.9308298157894737, 0.747656947368421, 0.5045944736842105], 
             UndirectedEdge[10, 53] -> 
             RGBColor[
              0.9880032894736842, 0.9755256842105263, 0.5955283421052631], 
             UndirectedEdge[15, 40] -> 
             RGBColor[
              0.8736416578947368, 0.7850953684210527, 0.6172072894736842], 
             UndirectedEdge[21, 68] -> 
             RGBColor[
              0.5858612631578948, 0.6461963421052632, 0.6953583421052633], 
             UndirectedEdge[28, 83] -> 
             RGBColor[
              0.9192491842105263, 0.7676405789473683, 0.5945924210526315], 
             UndirectedEdge[54, 100] -> 
             RGBColor[
              0.9091287894736841, 0.6677073684210526, 0.24523799999999998`], 
             UndirectedEdge[47, 96] -> 
             RGBColor[
              0.934871947368421, 0.7654078947368419, 0.31059481578947357`], 
             UndirectedEdge[47, 51] -> 
             RGBColor[
              0.9691876052631578, 0.9626566315789473, 0.6794891842105262], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.9549085526315789, 0.8466284736842106, 0.49404347368421053`], 
             UndirectedEdge[39, 45] -> 
             RGBColor[
              0.9419986052631579, 0.8387457368421053, 0.5940628421052632], 
             UndirectedEdge[58, 97] -> 
             RGBColor[
              0.9305680526315789, 0.7593369999999999, 0.2718052894736842], 
             UndirectedEdge[31, 45] -> 
             RGBColor[
              0.9583362894736842, 0.9035192105263157, 0.6072085263157894], 
             UndirectedEdge[6, 26] -> 
             RGBColor[
              0.9091287894736841, 0.6677073684210526, 0.24523799999999998`], 
             UndirectedEdge[41, 91] -> 
             RGBColor[
              0.5863000526315789, 0.6471348684210526, 0.7431178684210524], 
             UndirectedEdge[8, 22] -> 
             RGBColor[
              0.9659621842105263, 0.9711721052631579, 0.7710717105263156], 
             UndirectedEdge[46, 95] -> 
             RGBColor[
              0.5186207368421052, 0.24130492105263157`, 0.5500268157894737], 
             UndirectedEdge[66, 95] -> 
             RGBColor[0.49812300000000004`, 0.2197605, 0.5488595000000001], 
             UndirectedEdge[23, 37] -> 
             RGBColor[
              0.9612216315789474, 0.9705997368421053, 0.9505258421052631], 
             UndirectedEdge[10, 100] -> 
             RGBColor[
              0.9663022631578948, 0.8955761052631579, 0.33617186842105257`], 
             UndirectedEdge[5, 79] -> 
             RGBColor[
              0.9740577631578947, 0.9778210526315789, 0.8058702894736842], 
             UndirectedEdge[38, 42] -> 
             RGBColor[0.5260435, 0.6087461315789473, 0.9598447105263157], 
             UndirectedEdge[40, 54] -> 
             RGBColor[
              0.8513139736842106, 0.686847947368421, 0.5987388157894736], 
             UndirectedEdge[32, 45] -> 
             RGBColor[
              0.9808369736842105, 0.9816544210526317, 0.6973902894736842], 
             UndirectedEdge[41, 60] -> 
             RGBColor[
              0.9892417368421053, 0.9746498421052632, 0.4741131578947366], 
             UndirectedEdge[88, 91] -> 
             RGBColor[
              0.5867388421052632, 0.6480733947368421, 0.7908773947368422], 
             UndirectedEdge[47, 57] -> 
             RGBColor[0.942107, 0.7982605789473685, 0.3166319210526315], 
             UndirectedEdge[27, 85] -> 
             RGBColor[
              0.8605239210526316, 0.8885085789473685, 0.810813947368421], 
             UndirectedEdge[69, 95] -> 
             RGBColor[
              0.7999541315789475, 0.4821054736842106, 0.5715914210526316], 
             UndirectedEdge[36, 72] -> 
             RGBColor[
              0.7984802894736842, 0.6454754210526316, 0.5934989736842106], 
             UndirectedEdge[6, 65] -> 
             RGBColor[
              0.9265209210526316, 0.8790061052631579, 0.6338383421052631], 
             UndirectedEdge[49, 77] -> 
             RGBColor[
              0.5867388421052631, 0.6480733947368422, 0.7908773947368422], 
             UndirectedEdge[2, 62] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157894], 
             UndirectedEdge[22, 66] -> 
             RGBColor[
              0.5863000526315789, 0.6471348684210526, 0.7431178684210524], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.937063052631579, 0.951797052631579, 0.9641947105263158], 
             UndirectedEdge[73, 88] -> 
             RGBColor[
              0.9548347368421053, 0.845967052631579, 0.44940728947368425`], 
             UndirectedEdge[8, 21] -> 
             RGBColor[
              0.965523394736842, 0.9702335789473684, 0.7233121842105263], 
             UndirectedEdge[31, 75] -> 
             RGBColor[
              0.5633605789473685, 0.5680611315789473, 0.6051765789473684], 
             UndirectedEdge[4, 30] -> 
             RGBColor[0.9506795, 0.8978087894736841, 0.6201694736842105], 
             UndirectedEdge[48, 91] -> 
             RGBColor[0.5815595, 0.6465625, 0.922572], UndirectedEdge[19, 28] -> 
             RGBColor[
              0.9425106578947369, 0.8654220526315788, 0.6135966315789474], 
             UndirectedEdge[28, 66] -> 
             RGBColor[
              0.5662459210526316, 0.6351416578947369, 0.9484938947368421], 
             UndirectedEdge[3, 29] -> 
             RGBColor[
              0.9617324736842106, 0.8825767894736842, 0.30583831578947374`], 
             UndirectedEdge[22, 82] -> 
             RGBColor[
              0.9941118947368421, 0.9898142631578948, 0.6004942631578947], 
             UndirectedEdge[49, 82] -> 
             RGBColor[
              0.5867388421052631, 0.6480733947368422, 0.7908773947368422], 
             UndirectedEdge[23, 84] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[65, 100] -> 
             RGBColor[
              0.9265209210526316, 0.8790061052631579, 0.6338383421052631], 
             UndirectedEdge[53, 85] -> 
             RGBColor[
              0.9928734473684211, 0.9906901052631579, 0.7219094473684211], 
             UndirectedEdge[59, 97] -> 
             RGBColor[
              0.5391653157894736, 0.4707456052631579, 0.5856366315789474], 
             UndirectedEdge[17, 98] -> 
             RGBColor[
              0.949655394736842, 0.8444561578947369, 0.581101894736842], 
             UndirectedEdge[61, 68] -> 
             RGBColor[
              0.5868126578947368, 0.6487348157894737, 0.8355135789473684], 
             UndirectedEdge[28, 55] -> 
             RGBColor[
              0.5662459210526316, 0.6351416578947369, 0.9484938947368421], 
             UndirectedEdge[9, 36] -> 
             RGBColor[
              0.8570956315789473, 0.8877217894736842, 0.9134890789473684], 
             UndirectedEdge[20, 59] -> 
             RGBColor[
              0.5867388421052632, 0.6480733947368421, 0.7908773947368422], 
             UndirectedEdge[48, 57] -> 
             RGBColor[
              0.9417978157894736, 0.8119141052631579, 0.5747076315789473], 
             UndirectedEdge[1, 46] -> 
             RGBColor[
              0.5012558684210527, 0.5892833947368421, 0.9574002368421053], 
             UndirectedEdge[5, 66] -> 
             RGBColor[
              0.5867388421052632, 0.6480733947368421, 0.7908773947368422], 
             UndirectedEdge[64, 74] -> 
             RGBColor[
              0.8836998157894738, 0.8952539473684211, 0.6872282105263157], 
             UndirectedEdge[55, 79] -> 
             RGBColor[
              0.5662459210526316, 0.6351416578947369, 0.9484938947368421], 
             UndirectedEdge[32, 51] -> 
             RGBColor[0.9731801842105263, 0.975944, 0.7103512368421052], 
             UndirectedEdge[64, 73] -> 
             RGBColor[
              0.9499645789473684, 0.8308026315789474, 0.32302618421052626`], 
             UndirectedEdge[35, 38] -> 
             RGBColor[
              0.8585490263157894, 0.7197006315789471, 0.6047759210526316], 
             UndirectedEdge[71, 87] -> 
             RGBColor[
              0.9576486578947369, 0.923733052631579, 0.634662552631579], 
             UndirectedEdge[82, 87] -> 
             RGBColor[
              0.9740577631578947, 0.9778210526315789, 0.8058702894736842], 
             UndirectedEdge[5, 77] -> 
             RGBColor[
              0.9945506842105263, 0.9907527894736843, 0.6482537894736843], 
             UndirectedEdge[57, 64] -> 
             RGBColor[0.942107, 0.7982605789473685, 0.3166319210526315], 
             UndirectedEdge[63, 97] -> 
             RGBColor[
              0.8129503947368422, 0.7111807894736841, 0.6055731842105263], 
             UndirectedEdge[41, 93] -> 
             RGBColor[
              0.9659621842105263, 0.9711721052631579, 0.7710717105263156], 
             UndirectedEdge[9, 61] -> 
             RGBColor[
              0.9911962105263157, 0.9906274210526316, 0.7955651052631579], 
             UndirectedEdge[17, 46] -> 
             RGBColor[
              0.5675206315789474, 0.5248320789473684, 0.5931982105263158], 
             UndirectedEdge[25, 54] -> 
             RGBColor[
              0.8776984736842104, 0.5375391578947366, 0.219660947368421], 
             UndirectedEdge[59, 77] -> 
             RGBColor[
              0.5867388421052631, 0.6480733947368422, 0.7908773947368422], 
             UndirectedEdge[66, 77] -> 
             RGBColor[
              0.5867388421052631, 0.6480733947368422, 0.7908773947368422], 
             UndirectedEdge[7, 27] -> 
             RGBColor[0.8476877894736843, 0.8812872631578947, 0.9554695], 
             UndirectedEdge[61, 92] -> 
             RGBColor[
              0.9134314210526315, 0.9305425263157895, 0.8606899736842105], 
             UndirectedEdge[77, 87] -> 
             RGBColor[
              0.9740577631578947, 0.9778210526315789, 0.8058702894736842], 
             UndirectedEdge[28, 79] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.9634867894736842], 
             UndirectedEdge[5, 28] -> 
             RGBColor[
              0.9740577631578947, 0.9778210526315789, 0.8058702894736842], 
             UndirectedEdge[56, 88] -> 
             RGBColor[
              0.5867388421052631, 0.6480733947368422, 0.7908773947368422], 
             UndirectedEdge[25, 26] -> 
             RGBColor[
              0.8776984736842104, 0.5375391578947366, 0.219660947368421], 
             UndirectedEdge[9, 67] -> 
             RGBColor[0.9747132894736842, 0.935878, 0.5797211842105263], 
             UndirectedEdge[32, 44] -> 
             RGBColor[
              0.9902448157894737, 0.9880889473684211, 0.6554098684210528], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.8596463421052631, 0.8866315263157896, 0.7152948947368423], 
             UndirectedEdge[79, 83] -> 
             RGBColor[
              0.9192491842105263, 0.7676405789473683, 0.5945924210526315], 
             UndirectedEdge[60, 93] -> 
             RGBColor[
              0.9615308157894736, 0.9569462105263158, 0.6924501315789473], 
             UndirectedEdge[5, 63] -> 
             RGBColor[
              0.8605239210526316, 0.8885085789473685, 0.810813947368421], 
             UndirectedEdge[19, 66] -> 
             RGBColor[
              0.5551917368421052, 0.535674394736842, 0.5986037368421053], 
             UndirectedEdge[8, 86] -> 
             RGBColor[
              0.9629726842105262, 0.9713238421052632, 0.9215063684210527], 
             UndirectedEdge[4, 37] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.9634867894736842], 
             UndirectedEdge[9, 92] -> 
             RGBColor[
              0.9099293157894737, 0.9290943157894738, 0.9187289210526316], 
             UndirectedEdge[3, 42] -> 
             RGBColor[
              0.5908274736842105, 0.6155298157894737, 0.6208369736842105], 
             UndirectedEdge[7, 90] -> 
             RGBColor[
              0.937063052631579, 0.951797052631579, 0.9641947105263158], 
             UndirectedEdge[35, 62] -> 
             RGBColor[
              0.9398159210526316, 0.7812337368421052, 0.48161210526315784`], 
             UndirectedEdge[20, 79] -> 
             RGBColor[
              0.9740577631578947, 0.9778210526315789, 0.8058702894736842], 
             UndirectedEdge[31, 78] -> 
             RGBColor[
              0.9677441315789473, 0.9099537368421052, 0.5652281052631579], 
             UndirectedEdge[13, 81] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.9634867894736842], 
             UndirectedEdge[18, 80] -> 
             RGBColor[
              0.5833105526315789, 0.6472866052631578, 0.8935525263157895], 
             UndirectedEdge[90, 100] -> 
             RGBColor[
              0.9265209210526316, 0.8790061052631579, 0.6338383421052631], 
             UndirectedEdge[67, 92] -> 
             RGBColor[0.8969485, 0.8757931052631579, 0.6448460526315789], 
             UndirectedEdge[55, 66] -> RGBColor[0.178927, 0.305394, 0.933501],
              UndirectedEdge[89, 91] -> 
             RGBColor[
              0.5662459210526316, 0.6351416578947369, 0.9484938947368421], 
             UndirectedEdge[46, 55] -> 
             RGBColor[
              0.19942473684210527`, 0.3269384210526316, 0.9346683157894737], 
             UndirectedEdge[41, 64] -> 
             RGBColor[
              0.9892417368421053, 0.9746498421052632, 0.4741131578947366], 
             UndirectedEdge[28, 46] -> 
             RGBColor[
              0.5867436578947368, 0.6566860789473684, 0.9496612105263158], 
             UndirectedEdge[35, 53] -> 
             RGBColor[
              0.9380648684210526, 0.7805096315789473, 0.5106315789473683], 
             UndirectedEdge[35, 90] -> 
             RGBColor[
              0.8950906052631579, 0.7488378947368419, 0.6082612894736841], 
             UndirectedEdge[5, 58] -> 
             RGBColor[
              0.9781415789473684, 0.9366647894736843, 0.477046052631579], 
             UndirectedEdge[76, 85] -> 
             RGBColor[
              0.9740577631578947, 0.9778210526315789, 0.8058702894736842], 
             UndirectedEdge[34, 77] -> 
             RGBColor[
              0.9893713421052631, 0.9892418947368422, 0.7799483947368422], 
             UndirectedEdge[49, 71] -> 
             RGBColor[
              0.5703297368421052, 0.5939853947368421, 0.6196696578947369]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 25 -> 
             RGBColor[
              0.8849335263157894, 0.5703918421052628, 0.22569805263157888`], 
             55 -> RGBColor[0.178927, 0.305394, 0.933501], 90 -> 
             RGBColor[
              0.9052476842105264, 0.9272839473684211, 0.9908245263157894], 27 -> 
             RGBColor[
              0.7264971578947369, 0.7862643684210526, 0.9733741052631579], 15 -> 
             RGBColor[
              0.9151187894736842, 0.7011813157894737, 0.2505607894736842], 98 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 38 -> 
             RGBColor[
              0.8321645263157895, 0.8690094210526316, 0.9838537894736842], 99 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 71 -> 
             RGBColor[
              0.9617324736842106, 0.8825767894736842, 0.30583831578947374`], 
             41 -> RGBColor[
              0.9936731052631579, 0.9888757368421053, 0.552734736842105], 75 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 64 -> 
             RGBColor[
              0.9848103684210526, 0.9604239473684211, 0.3954915789473683], 63 -> 
             RGBColor[
              0.7264971578947369, 0.7862643684210526, 0.9733741052631579], 85 -> 
             RGBColor[
              0.9945506842105263, 0.9907527894736843, 0.6482537894736843], 3 -> 
             RGBColor[
              0.9617324736842106, 0.8825767894736842, 0.30583831578947374`], 
             86 -> RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 94 -> 
             RGBColor[
              0.9382512631578946, 0.9534684736842105, 0.9894086842105263], 61 -> 
             RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947369], 84 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 76 -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.9634867894736842], 21 -> 
             RGBColor[
              0.9927955263157895, 0.9869986842105264, 0.45721568421052644`], 
             87 -> RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.9634867894736842], 95 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 72 -> 
             RGBColor[
              0.8704634210526315, 0.5046864736842105, 0.21362384210526314`], 
             42 -> RGBColor[
              0.21992247368421053`, 0.34848284210526315`, 0.9358356315789473],
              66 -> RGBColor[0.178927, 0.305394, 0.933501], 1 -> 
             RGBColor[
              0.7825892631578949, 0.8300839473684212, 0.9789648421052631], 24 -> 
             RGBColor[
              0.9477941578947369, 0.8307282631578946, 0.27685215789473683`], 
             54 -> RGBColor[
              0.8704634210526315, 0.5046864736842105, 0.21362384210526314`], 
             4 -> RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.9634867894736842], 7 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 100 -> 
             RGBColor[
              0.9477941578947369, 0.8307282631578946, 0.27685215789473683`], 
             12 -> RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 65 -> 
             RGBColor[
              0.9052476842105264, 0.9272839473684211, 0.9908245263157894], 8 -> 
             RGBColor[
              0.9382512631578946, 0.9534684736842105, 0.9894086842105263], 57 -> 
             RGBColor[
              0.8994036315789473, 0.6360972105263157, 0.23777226315789474`], 
             74 -> RGBColor[
              0.7825892631578949, 0.8300839473684212, 0.9789648421052631], 37 -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.9634867894736842], 43 -> 
             RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947369], 39 -> 
             RGBColor[
              0.9151187894736842, 0.7011813157894737, 0.2505607894736842], 58 -> 
             RGBColor[
              0.9617324736842106, 0.8825767894736842, 0.30583831578947374`], 
             11 -> RGBColor[
              0.9617324736842106, 0.8825767894736842, 0.30583831578947374`], 
             51 -> RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.9634867894736842], 48 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 20 -> 
             RGBColor[
              0.9945506842105263, 0.9907527894736843, 0.6482537894736843], 33 -> 
             RGBColor[
              0.9945506842105263, 0.9907527894736843, 0.6482537894736843], 45 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 23 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 22 -> 
             RGBColor[
              0.9936731052631579, 0.9888757368421053, 0.552734736842105], 2 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 60 -> 
             RGBColor[
              0.9848103684210526, 0.9604239473684211, 0.3954915789473683], 16 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 79 -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.9634867894736842], 89 -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.9634867894736842], 36 -> 
             RGBColor[
              0.7264971578947369, 0.7862643684210526, 0.9733741052631579], 52 -> 
             RGBColor[
              0.9911962105263158, 0.9906274210526316, 0.7955651052631578], 32 -> 
             RGBColor[
              0.9927955263157895, 0.9869986842105264, 0.45721568421052644`], 
             31 -> RGBColor[
              0.9477941578947369, 0.8307282631578946, 0.27685215789473683`], 
             68 -> RGBColor[0.178927, 0.305394, 0.933501], 73 -> 
             RGBColor[
              0.9151187894736842, 0.7011813157894737, 0.2505607894736842], 82 -> 
             RGBColor[
              0.9945506842105263, 0.9907527894736843, 0.6482537894736843], 35 -> 
             RGBColor[
              0.8849335263157894, 0.5703918421052628, 0.22569805263157888`], 
             88 -> RGBColor[
              0.9945506842105263, 0.9907527894736843, 0.6482537894736843], 50 -> 
             RGBColor[
              0.9732714210526315, 0.9215003684210524, 0.3506649473684208], 19 -> 
             RGBColor[
              0.9314564736842105, 0.7659547894736839, 0.26370647368421046`], 
             17 -> RGBColor[
              0.9151187894736842, 0.7011813157894737, 0.2505607894736842], 96 -> 
             RGBColor[
              0.8849335263157894, 0.5703918421052628, 0.22569805263157888`], 
             14 -> RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947369], 5 -> 
             RGBColor[
              0.9945506842105263, 0.9907527894736843, 0.6482537894736843], 34 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 97 -> 
             RGBColor[
              0.8994036315789473, 0.6360972105263157, 0.23777226315789474`], 
             93 -> RGBColor[
              0.9382512631578946, 0.9534684736842105, 0.9894086842105263], 81 -> 
             RGBColor[
              0.9382512631578946, 0.9534684736842105, 0.9894086842105263], 69 -> 
             RGBColor[
              0.7825892631578949, 0.8300839473684212, 0.9789648421052631], 9 -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 13 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 30 -> 
             RGBColor[
              0.9477941578947369, 0.8307282631578946, 0.27685215789473683`], 
             59 -> RGBColor[0.178927, 0.305394, 0.933501], 28 -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.9634867894736842], 80 -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 47 -> 
             RGBColor[
              0.9848103684210526, 0.9604239473684211, 0.3954915789473683], 62 -> 
             RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947369], 77 -> 
             RGBColor[
              0.9945506842105263, 0.9907527894736843, 0.6482537894736843], 78 -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 40 -> 
             RGBColor[
              0.8321645263157895, 0.8690094210526316, 0.9838537894736842], 67 -> 
             RGBColor[
              0.9617324736842106, 0.8825767894736842, 0.30583831578947374`], 
             56 -> RGBColor[0.178927, 0.305394, 0.933501], 10 -> 
             RGBColor[
              0.9848103684210526, 0.9604239473684211, 0.3954915789473683], 53 -> 
             RGBColor[
              0.9911962105263158, 0.9906274210526316, 0.7955651052631578], 26 -> 
             RGBColor[
              0.8704634210526315, 0.5046864736842105, 0.21362384210526314`], 
             18 -> RGBColor[0.178927, 0.305394, 0.933501], 29 -> 
             RGBColor[
              0.9617324736842106, 0.8825767894736842, 0.30583831578947374`], 
             92 -> RGBColor[
              0.8321645263157895, 0.8690094210526316, 0.9838537894736842], 46 -> 
             RGBColor[
              0.21992247368421053`, 0.34848284210526315`, 0.9358356315789473],
              49 -> RGBColor[0.178927, 0.305394, 0.933501], 83 -> 
             RGBColor[
              0.8849335263157894, 0.5703918421052628, 0.22569805263157888`], 
             70 -> RGBColor[
              0.7825892631578949, 0.8300839473684212, 0.9789648421052631], 44 -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 91 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 6 -> 
             RGBColor[
              0.9477941578947369, 0.8307282631578946, 
               0.27685215789473683`]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9lHs01Akbx4dhXCZmRjNjDGZ+vxEpY003Oez6fWm7uFSIpJWyrGvrtqF9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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 13}], {
             RGBColor[
             0.8757338421052632, 0.903197052631579, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 17}], {
             RGBColor[
             0.8488540263157895, 0.7656326315789475, 0.6147628157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 19}], {
             RGBColor[
             0.8570228684210527, 0.7980193684210526, 0.6213356578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 27}], {
             RGBColor[
             0.7545432105263159, 0.8081741578947369, 0.9761694736842106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 43}], {
             RGBColor[0.8886437894736843, 0.9110797894736843, 0.8582455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 46}], {
             RGBColor[
             0.5012558684210527, 0.5892833947368421, 0.9574002368421053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 55}], {
             RGBColor[
             0.4807581315789474, 0.5677389736842106, 0.9562329210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 3}], {
             RGBColor[
             0.965305447368421, 0.9294434736842105, 0.6217016052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 14}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 29}], {
             RGBColor[
             0.965305447368421, 0.9294434736842105, 0.6217016052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 33}], {
             RGBColor[
             0.9817145526315789, 0.9835314736842106, 0.7929093421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 38}], {
             RGBColor[
             0.9005214736842105, 0.9226597894736842, 0.960709342105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 42}], {
             RGBColor[0.594400447368421, 0.6623965, 0.9367002631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 44}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 62}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 78}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 16}], {
             RGBColor[
             0.965305447368421, 0.9294434736842105, 0.6217016052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 29}], {
             RGBColor[
             0.9617324736842106, 0.8825767894736842, 0.30583831578947374`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 33}], {
             RGBColor[
             0.9781415789473684, 0.9366647894736843, 0.477046052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 38}], {
             RGBColor[0.8969485, 0.8757931052631579, 0.6448460526315789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 42}], {
             RGBColor[
             0.5908274736842105, 0.6155298157894737, 0.6208369736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 62}], {
             RGBColor[
             0.9782153947368422, 0.9373262105263158, 0.5216822368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 9}], {
             RGBColor[
             0.9706294736842105, 0.9770342631578948, 0.9085454210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 23}], {
             RGBColor[
             0.9612216315789474, 0.9705997368421053, 0.9505258421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 24}], {
             RGBColor[0.9506795, 0.8978087894736841, 0.6201694736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 30}], {
             RGBColor[0.9506795, 0.8978087894736841, 0.6201694736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 36}], {
             RGBColor[0.840031, 0.8755768421052632, 0.9684304473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 37}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.9634867894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 50}], {
             RGBColor[
             0.9634181315789474, 0.943194842105263, 0.6570758684210525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 76}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.9634867894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 86}], {
             RGBColor[
             0.9706294736842105, 0.9770342631578948, 0.9085454210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 94}], {
             RGBColor[
             0.9459080526315788, 0.959178894736842, 0.9764477368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 20}], {
             RGBColor[
             0.9945506842105263, 0.9907527894736843, 0.6482537894736843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 28}], {
             RGBColor[
             0.9740577631578947, 0.9778210526315789, 0.8058702894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 58}], {
             RGBColor[
             0.9781415789473684, 0.9366647894736843, 0.477046052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.5867388421052632, 0.6480733947368421, 0.7908773947368422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 63}], {
             RGBColor[
             0.8605239210526316, 0.8885085789473685, 0.810813947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 66}], {
             RGBColor[
             0.5867388421052632, 0.6480733947368421, 0.7908773947368422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 69}], {
             RGBColor[
             0.8885699736842105, 0.9104183684210527, 0.8136093157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[
             0.9945506842105263, 0.9907527894736843, 0.6482537894736843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 79}], {
             RGBColor[
             0.9740577631578947, 0.9778210526315789, 0.8058702894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[
             0.9397421052631578, 0.7805723157894735, 0.4369759210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 97}], {
             RGBColor[
             0.9469771578947368, 0.8134250000000001, 0.44301302631578954`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 7}], {
             RGBColor[
             0.9583362894736842, 0.9035192105263157, 0.6072085263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 10}], {
             RGBColor[
             0.9663022631578948, 0.8955761052631579, 0.33617186842105257`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 15}], {
             RGBColor[
             0.9314564736842106, 0.7659547894736842, 0.2637064736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 25}], {
             RGBColor[
             0.9163638421052631, 0.7005600526315787, 0.2512751052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 26}], {
             RGBColor[
             0.9091287894736841, 0.6677073684210526, 0.24523799999999998`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 35}], {
             RGBColor[
             0.9163638421052631, 0.7005600526315787, 0.2512751052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 40}], {
             RGBColor[
             0.8899793421052632, 0.8498688421052631, 0.6303529736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.9694951842105264, 0.910677842105263, 0.5362086315789474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 65}], {
             RGBColor[
             0.9265209210526316, 0.8790061052631579, 0.6338383421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 90}], {
             RGBColor[
             0.9265209210526316, 0.8790061052631579, 0.6338383421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 100}], {
             RGBColor[
             0.9477941578947369, 0.8307282631578946, 0.27685215789473683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 13}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 25}], {
             RGBColor[
             0.9269059736842105, 0.7733509999999999, 0.5816314736842104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 27}], {
             RGBColor[0.8476877894736843, 0.8812872631578947, 0.9554695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 37}], {
             RGBColor[
             0.9612216315789474, 0.9705997368421053, 0.9505258421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 40}], {
             RGBColor[
             0.9005214736842105, 0.9226597894736842, 0.960709342105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 53}], {
             RGBColor[
             0.9800373157894737, 0.9834687894736842, 0.8665649999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.9196709210526315, 0.7404983157894737, 0.5755943684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 65}], {
             RGBColor[
             0.937063052631579, 0.951797052631579, 0.9641947105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 81}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.9634867894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 85}], {
             RGBColor[
             0.9817145526315789, 0.9835314736842106, 0.7929093421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 90}], {
             RGBColor[
             0.937063052631579, 0.951797052631579, 0.9641947105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 100}], {
             RGBColor[
             0.9583362894736842, 0.9035192105263157, 0.6072085263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 17}], {
             RGBColor[
             0.9266850263157894, 0.8273248947368421, 0.6199847368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.965523394736842, 0.9702335789473684, 0.7233121842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 22}], {
             RGBColor[
             0.9659621842105263, 0.9711721052631579, 0.7710717105263156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 30}], {
             RGBColor[
             0.9430227105263158, 0.8920983684210526, 0.6331304210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 49}], {
             RGBColor[
             0.5585891315789473, 0.6294312368421052, 0.9614548421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 69}], {
             RGBColor[
             0.8604202631578948, 0.8917762105263158, 0.9841867631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 77}], {
             RGBColor[
             0.9664009736842105, 0.9721106315789474, 0.8188312368421053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.9664009736842105, 0.9721106315789474, 0.8188312368421053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 86}], {
             RGBColor[
             0.9629726842105262, 0.9713238421052632, 0.9215063684210527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 87}], {
             RGBColor[
             0.9459080526315788, 0.959178894736842, 0.9764477368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 95}], {
             RGBColor[
             0.8777851315789473, 0.5437977368421052, 0.5768133421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 99}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.9634867894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[0.9747132894736842, 0.935878, 0.5797211842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 21}], {
             RGBColor[
             0.9902448157894737, 0.9880889473684211, 0.6554098684210528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 30}], {
             RGBColor[
             0.9677441315789473, 0.9099537368421052, 0.5652281052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 36}], {
             RGBColor[
             0.8570956315789473, 0.8877217894736842, 0.9134890789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 61}], {
             RGBColor[
             0.9911962105263157, 0.9906274210526316, 0.7955651052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 67}], {
             RGBColor[0.9747132894736842, 0.935878, 0.5797211842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 68}], {
             RGBColor[
             0.5833105526315789, 0.647286605263158, 0.8935525263157895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 72}], {
             RGBColor[
             0.9290787631578947, 0.7469328421052632, 0.533613947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 82}], {
             RGBColor[
             0.991122394736842, 0.9899660000000001, 0.7509289210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 86}], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 92}], {
             RGBColor[
             0.9099293157894737, 0.9290943157894738, 0.9187289210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 94}], {
             RGBColor[
             0.9629726842105262, 0.9713238421052632, 0.9215063684210527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.9499645789473684, 0.8308026315789474, 0.32302618421052626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 26}], {
             RGBColor[
             0.9276368947368421, 0.7325552105263158, 0.30455771052631575`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 35}], {
             RGBColor[
             0.934871947368421, 0.7654078947368419, 0.31059481578947357`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 40}], {
             RGBColor[
             0.908487447368421, 0.9147166842105263, 0.6896726842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 53}], {
             RGBColor[
             0.9880032894736842, 0.9755256842105263, 0.5955283421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 65}], {
             RGBColor[
             0.9450290263157894, 0.9438539473684211, 0.6931580526315788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 90}], {
             RGBColor[
             0.9450290263157894, 0.9438539473684211, 0.6931580526315788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 100}], {
             RGBColor[
             0.9663022631578948, 0.8955761052631579, 0.33617186842105257`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 36}], {
             RGBColor[
             0.8441148157894738, 0.8344205789473684, 0.6396062105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 52}], {
             RGBColor[
             0.9764643421052632, 0.9366021052631579, 0.5507017105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 61}], {
             RGBColor[
             0.9782153947368422, 0.9373262105263158, 0.5216822368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 67}], {
             RGBColor[
             0.9617324736842106, 0.8825767894736842, 0.30583831578947374`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 68}], {
             RGBColor[
             0.5703297368421053, 0.5939853947368421, 0.6196696578947369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 72}], {
             RGBColor[
             0.916097947368421, 0.6936316315789474, 0.25973107894736847`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 92}], {
             RGBColor[0.8969485, 0.8757931052631579, 0.6448460526315789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 94}], {
             RGBColor[0.9499918684210527, 0.9180226315789474, 0.6476235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 41}], {
             RGBColor[
             0.9906836052631578, 0.9890274736842106, 0.703169394736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 52}], {
             RGBColor[
             0.9894451578947367, 0.9899033157894737, 0.8245845789473685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 60}], {
             RGBColor[
             0.9862522368421052, 0.9748015789473685, 0.6245478157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.9862522368421052, 0.9748015789473685, 0.6245478157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 74}], {
             RGBColor[
             0.8851416842105264, 0.9096315789473686, 0.9162844473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 88}], {
             RGBColor[
             0.991122394736842, 0.9899660000000001, 0.7509289210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 96}], {
             RGBColor[
             0.9363138157894736, 0.7797855263157893, 0.539651052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 27}], {
             RGBColor[0.8476877894736843, 0.8812872631578947, 0.9554695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 43}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 54}], {
             RGBColor[
             0.9196709210526315, 0.7404983157894737, 0.5755943684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 81}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.9634867894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 84}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 85}], {
             RGBColor[
             0.9817145526315789, 0.9835314736842106, 0.7929093421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 15}], {
             RGBColor[
             0.9549085526315789, 0.8466284736842106, 0.49404347368421053`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 24}], {
             RGBColor[
             0.9712462368421053, 0.911401947368421, 0.5071891578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 35}], {
             RGBColor[
             0.9398159210526316, 0.7812337368421052, 0.4816121052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 38}], {
             RGBColor[
             0.9134314210526315, 0.9305425263157895, 0.8606899736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 42}], {
             RGBColor[
             0.6073103947368421, 0.6702792368421053, 0.836680894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 53}], {
             RGBColor[
             0.9929472631578947, 0.9913515263157895, 0.7665456315789474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 62}], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 76}], {
             RGBColor[
             0.9741315789473683, 0.9784824736842106, 0.8505064736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 35}], {
             RGBColor[
             0.9000261578947368, 0.6357865789473682, 0.23812942105263155`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 38}], {
             RGBColor[
             0.8736416578947368, 0.7850953684210527, 0.6172072894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 40}], {
             RGBColor[
             0.8736416578947368, 0.7850953684210527, 0.6172072894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 53}], {
             RGBColor[0.9531575, 0.8459043684210527, 0.523062947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.9549085526315789, 0.8466284736842106, 0.49404347368421053`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 90}], {
             RGBColor[
             0.9101832368421052, 0.8142326315789474, 0.6206926578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 100}], {
             RGBColor[
             0.9314564736842106, 0.7659547894736842, 0.2637064736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 29}], {
             RGBColor[
             0.965305447368421, 0.9294434736842105, 0.6217016052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.9817145526315789, 0.9835314736842106, 0.7929093421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 62}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 19}], {
             RGBColor[
             0.9232876315789473, 0.7335680526315789, 0.2571336315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 22}], {
             RGBColor[
             0.954395947368421, 0.8450285263157895, 0.4016477631578946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 28}], {
             RGBColor[
             0.9343418157894736, 0.8330353157894737, 0.6070237894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 46}], {
             RGBColor[
             0.5675206315789474, 0.5248320789473684, 0.5931982105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 55}], {
             RGBColor[
             0.5470228947368421, 0.5032876578947368, 0.5920308947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 59}], {
             RGBColor[
             0.5470228947368421, 0.5032876578947368, 0.5920308947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 66}], {
             RGBColor[
             0.5470228947368421, 0.5032876578947368, 0.5920308947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 69}], {
             RGBColor[
             0.8488540263157895, 0.7656326315789475, 0.6147628157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 77}], {
             RGBColor[
             0.9548347368421053, 0.845967052631579, 0.44940728947368425`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 79}], {
             RGBColor[
             0.9343418157894736, 0.8330353157894737, 0.6070237894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 95}], {
             RGBColor[
             0.8662188947368421, 0.41765415789473687`, 0.2073893947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 98}], {
             RGBColor[
             0.949655394736842, 0.8444561578947369, 0.581101894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.9419986052631579, 0.8387457368421053, 0.5940628421052632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 80}], {
             RGBColor[
             0.5833105526315789, 0.6472866052631578, 0.8935525263157895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 28}], {
             RGBColor[
             0.9425106578947369, 0.8654220526315788, 0.6135966315789474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 43}], {
             RGBColor[
             0.9630773947368421, 0.8790152105263156, 0.5006163157894736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 46}], {
             RGBColor[
             0.5756894736842105, 0.5572188157894735, 0.5997710526315789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 55}], {
             RGBColor[
             0.5551917368421052, 0.535674394736842, 0.5986037368421053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 59}], {
             RGBColor[
             0.5551917368421052, 0.535674394736842, 0.5986037368421053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 66}], {
             RGBColor[
             0.5551917368421052, 0.535674394736842, 0.5986037368421053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 79}], {
             RGBColor[
             0.9425106578947369, 0.8654220526315788, 0.6135966315789474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 95}], {
             RGBColor[
             0.8743877368421052, 0.45004089473684195`, 0.21396223684210525`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 98}], {
             RGBColor[
             0.9578242368421053, 0.876842894736842, 0.5876747368421051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 99}], {
             RGBColor[
             0.950167447368421, 0.8711324736842103, 0.6006356842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.9740577631578947, 0.9778210526315789, 0.8058702894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 58}], {
             RGBColor[
             0.9781415789473684, 0.9366647894736843, 0.477046052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 59}], {
             RGBColor[
             0.5867388421052632, 0.6480733947368421, 0.7908773947368422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 63}], {
             RGBColor[
             0.8605239210526316, 0.8885085789473685, 0.810813947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 66}], {
             RGBColor[
             0.5867388421052632, 0.6480733947368421, 0.7908773947368422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 79}], {
             RGBColor[
             0.9740577631578947, 0.9778210526315789, 0.8058702894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 83}], {
             RGBColor[
             0.9397421052631578, 0.7805723157894735, 0.4369759210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 97}], {
             RGBColor[
             0.9469771578947368, 0.8134250000000001, 0.44301302631578954`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 22}], {
             RGBColor[
             0.9932343157894736, 0.9879372105263158, 0.5049752105263157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 30}], {
             RGBColor[
             0.9702948421052632, 0.9088634736842105, 0.36703392105263166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 34}], {
             RGBColor[
             0.9884937631578947, 0.9873648421052632, 0.6844293421052632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.8596463421052631, 0.8866315263157896, 0.7152948947368423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 49}], {
             RGBColor[
             0.5858612631578948, 0.6461963421052632, 0.6953583421052633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 68}], {
             RGBColor[
             0.5858612631578948, 0.6461963421052632, 0.6953583421052633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 72}], {
             RGBColor[
             0.9316294736842106, 0.7458425789473684, 0.3354197631578948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 82}], {
             RGBColor[
             0.9936731052631579, 0.9888757368421053, 0.5527347368421054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[0.9731801842105263, 0.975944, 0.7103512368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 92}], {
             RGBColor[
             0.9124800263157895, 0.9280040526315789, 0.7205347368421053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 30}], {
             RGBColor[0.9707336315789474, 0.909802, 0.4147934473684209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 34}], {
             RGBColor[
             0.9889325526315789, 0.9883033684210527, 0.7321888684210525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 49}], {
             RGBColor[
             0.5863000526315789, 0.6471348684210526, 0.7431178684210524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 66}], {
             RGBColor[
             0.5863000526315789, 0.6471348684210526, 0.7431178684210524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 69}], {
             RGBColor[
             0.8881311842105264, 0.9094798421052632, 0.765849789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 77}], {
             RGBColor[
             0.9941118947368421, 0.9898142631578948, 0.6004942631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 82}], {
             RGBColor[
             0.9941118947368421, 0.9898142631578948, 0.6004942631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 87}], {
             RGBColor[
             0.9736189736842105, 0.9768825263157894, 0.7581107631578945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 95}], {
             RGBColor[
             0.905496052631579, 0.5615013684210526, 0.35847636842105246`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 99}], {
             RGBColor[
             0.9812757631578948, 0.9825929473684211, 0.7451498157894735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 24}], {
             RGBColor[
             0.9583362894736842, 0.9035192105263157, 0.6072085263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 27}], {
             RGBColor[0.8476877894736843, 0.8812872631578947, 0.9554695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 30}], {
             RGBColor[
             0.9583362894736842, 0.9035192105263157, 0.6072085263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 37}], {
             RGBColor[
             0.9612216315789474, 0.9705997368421053, 0.9505258421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 50}], {
             RGBColor[
             0.9710749210526315, 0.9489052631578947, 0.6441149210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 76}], {
             RGBColor[
             0.9612216315789474, 0.9705997368421053, 0.9505258421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.9634867894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 84}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 85}], {
             RGBColor[
             0.9817145526315789, 0.9835314736842106, 0.7929093421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 86}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 42}], {
             RGBColor[
             0.5838583157894737, 0.5896055526315789, 0.606343894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 50}], {
             RGBColor[
             0.9605327894736841, 0.8761143157894735, 0.3137585526315788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 76}], {
             RGBColor[0.9506795, 0.8978087894736841, 0.6201694736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 26}], {
             RGBColor[
             0.8776984736842104, 0.5375391578947366, 0.219660947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 40}], {
             RGBColor[
             0.8585490263157894, 0.7197006315789471, 0.6047759210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 54}], {
             RGBColor[
             0.8776984736842104, 0.5375391578947366, 0.219660947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 65}], {
             RGBColor[
             0.8950906052631579, 0.7488378947368419, 0.6082612894736841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 100}], {
             RGBColor[
             0.9163638421052631, 0.7005600526315787, 0.2512751052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 40}], {
             RGBColor[
             0.8513139736842106, 0.686847947368421, 0.5987388157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 53}], {
             RGBColor[
             0.9308298157894737, 0.747656947368421, 0.5045944736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 65}], {
             RGBColor[
             0.887855552631579, 0.7159852105263158, 0.6022241842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 90}], {
             RGBColor[
             0.887855552631579, 0.7159852105263158, 0.6022241842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[
             0.9091287894736841, 0.6677073684210526, 0.24523799999999998`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 37}], {
             RGBColor[0.840031, 0.8755768421052632, 0.9684304473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 43}], {
             RGBColor[0.8605977368421053, 0.88917, 0.8554501315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 54}], {
             RGBColor[
             0.7984802894736842, 0.6454754210526316, 0.5934989736842106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 81}], {
             RGBColor[
             0.8323742105263158, 0.8698664210526316, 0.9813913947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 84}], {
             RGBColor[0.8476877894736843, 0.8812872631578947, 0.9554695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 85}], {
             RGBColor[
             0.8605239210526316, 0.8885085789473685, 0.810813947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 46}], {
             RGBColor[
             0.5867436578947368, 0.6566860789473684, 0.9496612105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 55}], {
             RGBColor[
             0.5662459210526316, 0.6351416578947369, 0.9484938947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 59}], {
             RGBColor[
             0.5662459210526316, 0.6351416578947369, 0.9484938947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 66}], {
             RGBColor[
             0.5662459210526316, 0.6351416578947369, 0.9484938947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 79}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.9634867894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 83}], {
             RGBColor[
             0.9192491842105263, 0.7676405789473683, 0.5945924210526315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 98}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 99}], {
             RGBColor[
             0.9612216315789474, 0.9705997368421053, 0.9505258421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 33}], {
             RGBColor[
             0.9781415789473684, 0.9366647894736843, 0.477046052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 38}], {
             RGBColor[0.8969485, 0.8757931052631579, 0.6448460526315789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 42}], {
             RGBColor[
             0.5908274736842105, 0.6155298157894737, 0.6208369736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.9782153947368422, 0.9373262105263158, 0.5216822368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 36}], {
             RGBColor[
             0.8371456578947369, 0.8084963157894736, 0.6251131315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 50}], {
             RGBColor[
             0.9605327894736841, 0.8761143157894735, 0.3137585526315788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 82}], {
             RGBColor[
             0.9711724210526316, 0.9107405263157895, 0.46255297368421056`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 86}], {
             RGBColor[
             0.9677441315789473, 0.9099537368421052, 0.5652281052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 92}], {
             RGBColor[
             0.8899793421052632, 0.8498688421052631, 0.6303529736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 94}], {
             RGBColor[
             0.9430227105263158, 0.8920983684210526, 0.6331304210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 32}], {
             RGBColor[
             0.9702948421052632, 0.9088634736842105, 0.36703392105263166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 39}], {
             RGBColor[
             0.9314564736842106, 0.7659547894736842, 0.2637064736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 44}], {
             RGBColor[
             0.9677441315789473, 0.9099537368421052, 0.5652281052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 45}], {
             RGBColor[
             0.9583362894736842, 0.9035192105263157, 0.6072085263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 51}], {
             RGBColor[0.9506795, 0.8978087894736841, 0.6201694736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 70}], {
             RGBColor[0.8651917105263158, 0.830406105263158, 0.6279085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 75}], {
             RGBColor[
             0.5633605789473685, 0.5680611315789473, 0.6051765789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 78}], {
             RGBColor[
             0.9677441315789473, 0.9099537368421052, 0.5652281052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 80}], {
             RGBColor[
             0.9677441315789473, 0.9099537368421052, 0.5652281052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 39}], {
             RGBColor[0.9539571578947368, 0.84409, 0.35388823684210535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 44}], {
             RGBColor[
             0.9902448157894737, 0.9880889473684211, 0.6554098684210528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 45}], {
             RGBColor[
             0.9808369736842105, 0.9816544210526317, 0.6973902894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 51}], {
             RGBColor[0.9731801842105263, 0.975944, 0.7103512368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 80}], {
             RGBColor[
             0.9902448157894737, 0.9880889473684211, 0.6554098684210528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 42}], {
             RGBColor[
             0.6072365789473684, 0.6696178157894737, 0.7920447105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 62}], {
             RGBColor[0.9946245, 0.9914142105263158, 0.6928899736842106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 49}], {
             RGBColor[0.5815595, 0.6465625, 0.922572]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{34, 60}], {
             RGBColor[
             0.9845011842105262, 0.9740774736842106, 0.6535672894736841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 69}], {
             RGBColor[
             0.8833906315789475, 0.9089074736842107, 0.9453039210526315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 71}], {
             RGBColor[
             0.9729622368421053, 0.9351538947368421, 0.6087406578947369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 77}], {
             RGBColor[
             0.9893713421052631, 0.9892418947368422, 0.7799483947368422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 82}], {
             RGBColor[
             0.9893713421052631, 0.9892418947368422, 0.7799483947368422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 87}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 38}], {
             RGBColor[
             0.8585490263157894, 0.7197006315789471, 0.6047759210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 53}], {
             RGBColor[
             0.9380648684210526, 0.7805096315789473, 0.5106315789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 62}], {
             RGBColor[
             0.9398159210526316, 0.7812337368421052, 0.48161210526315784`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 90}], {
             RGBColor[
             0.8950906052631579, 0.7488378947368419, 0.6082612894736841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 61}], {
             RGBColor[0.8605977368421053, 0.88917, 0.8554501315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 67}], {
             RGBColor[
             0.8441148157894738, 0.8344205789473684, 0.6396062105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 68}], {
             RGBColor[
             0.4527120789473684, 0.5458291842105263, 0.953437552631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 72}], {
             RGBColor[
             0.7984802894736842, 0.6454754210526316, 0.5934989736842106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 82}], {
             RGBColor[
             0.8605239210526316, 0.8885085789473685, 0.810813947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 86}], {
             RGBColor[
             0.8570956315789473, 0.8877217894736842, 0.9134890789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 92}], {
             RGBColor[
             0.7793308421052632, 0.8276368947368421, 0.978613947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 94}], {
             RGBColor[
             0.8323742105263158, 0.8698664210526316, 0.9813913947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 50}], {
             RGBColor[
             0.9634181315789474, 0.943194842105263, 0.6570758684210525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 76}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.9634867894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 81}], {
             RGBColor[
             0.9459080526315788, 0.959178894736842, 0.9764477368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 84}], {
             RGBColor[
             0.9612216315789474, 0.9705997368421053, 0.9505258421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 85}], {
             RGBColor[
             0.9740577631578947, 0.9778210526315789, 0.8058702894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 42}], {
             RGBColor[0.5260435, 0.6087461315789473, 0.9598447105263157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 62}], {
             RGBColor[
             0.9134314210526315, 0.9305425263157895, 0.8606899736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 44}], {
             RGBColor[
             0.951406447368421, 0.8451802631578949, 0.5520824210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 45}], {
             RGBColor[
             0.9419986052631579, 0.8387457368421053, 0.5940628421052632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 80}], {
             RGBColor[
             0.951406447368421, 0.8451802631578949, 0.5520824210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 53}], {
             RGBColor[
             0.9116803684210526, 0.9298184210526316, 0.8897094473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 54}], {
             RGBColor[
             0.8513139736842106, 0.686847947368421, 0.5987388157894736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 90}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 100}], {
             RGBColor[
             0.8899793421052632, 0.8498688421052631, 0.6303529736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 48}], {
             RGBColor[
             0.9889325526315789, 0.9883033684210527, 0.7321888684210525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 56}], {
             RGBColor[
             0.5863000526315789, 0.6471348684210526, 0.7431178684210524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 60}], {
             RGBColor[
             0.9892417368421053, 0.9746498421052632, 0.4741131578947366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 64}], {
             RGBColor[
             0.9892417368421053, 0.9746498421052632, 0.4741131578947366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 73}], {
             RGBColor[
             0.954395947368421, 0.8450285263157895, 0.4016477631578946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 74}], {
             RGBColor[
             0.8881311842105264, 0.9094798421052632, 0.765849789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.9941118947368421, 0.9898142631578948, 0.6004942631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 91}], {
             RGBColor[
             0.5863000526315789, 0.6471348684210526, 0.7431178684210524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 93}], {
             RGBColor[
             0.9659621842105263, 0.9711721052631579, 0.7710717105263156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 44}], {
             RGBColor[
             0.6038082894736843, 0.6688310263157895, 0.8947198421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 62}], {
             RGBColor[
             0.6073103947368421, 0.6702792368421053, 0.836680894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 78}], {
             RGBColor[
             0.6038082894736843, 0.6688310263157895, 0.8947198421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 46}], {
             RGBColor[
             0.6073103947368421, 0.6702792368421053, 0.836680894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 54}], {
             RGBColor[
             0.9325808684210526, 0.748381052631579, 0.47557499999999997`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 45}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 78}], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 52}], {
             RGBColor[
             0.9800373157894737, 0.9834687894736842, 0.8665649999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 78}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 55}], {
             RGBColor[
             0.19942473684210527`, 0.3269384210526316, 0.9346683157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 59}], {
             RGBColor[
             0.19942473684210527`, 0.3269384210526316, 0.9346683157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 79}], {
             RGBColor[
             0.5867436578947369, 0.6566860789473684, 0.9496612105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 95}], {
             RGBColor[
             0.5186207368421052, 0.24130492105263157`, 0.5500268157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 98}], {
             RGBColor[
             0.6020572368421053, 0.6681069210526316, 0.9237393157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 99}], {
             RGBColor[0.594400447368421, 0.6623965, 0.9367002631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 51}], {
             RGBColor[
             0.9691876052631578, 0.9626566315789473, 0.6794891842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 57}], {
             RGBColor[0.942107, 0.7982605789473685, 0.3166319210526315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 70}], {
             RGBColor[
             0.8836998157894738, 0.8952539473684211, 0.6872282105263157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 74}], {
             RGBColor[
             0.8836998157894738, 0.8952539473684211, 0.6872282105263157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 75}], {
             RGBColor[
             0.5818686842105263, 0.6329089736842105, 0.6644962894736841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 88}], {
             RGBColor[
             0.9896805263157895, 0.9755883684210527, 0.5218726842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.934871947368421, 0.7654078947368419, 0.31059481578947357`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 56}], {
             RGBColor[0.5815595, 0.6465625, 0.922572]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{48, 57}], {
             RGBColor[
             0.9417978157894736, 0.8119141052631579, 0.5747076315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 64}], {
             RGBColor[
             0.9845011842105262, 0.9740774736842106, 0.6535672894736841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 73}], {
             RGBColor[
             0.949655394736842, 0.8444561578947369, 0.581101894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 74}], {
             RGBColor[
             0.8833906315789475, 0.9089074736842107, 0.9453039210526315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 88}], {
             RGBColor[
             0.9893713421052631, 0.9892418947368422, 0.7799483947368422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 91}], {
             RGBColor[0.5815595, 0.6465625, 0.922572]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{48, 93}], {
             RGBColor[
             0.9612216315789472, 0.9705997368421053, 0.9505258421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 96}], {
             RGBColor[
             0.9345627631578947, 0.7790614210526314, 0.5686705263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 69}], {
             RGBColor[
             0.4807581315789475, 0.5677389736842107, 0.9562329210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 71}], {
             RGBColor[
             0.5703297368421052, 0.5939853947368421, 0.6196696578947369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 77}], {
             RGBColor[
             0.5867388421052631, 0.6480733947368422, 0.7908773947368422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 82}], {
             RGBColor[
             0.5867388421052631, 0.6480733947368422, 0.7908773947368422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.5662459210526316, 0.6351416578947369, 0.9484938947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 76}], {
             RGBColor[
             0.9634181315789474, 0.943194842105263, 0.6570758684210525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 81}], {
             RGBColor[
             0.9557613421052631, 0.9374844210526314, 0.6700368157894736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 84}], {
             RGBColor[
             0.9710749210526315, 0.9489052631578947, 0.6441149210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 85}], {
             RGBColor[
             0.9839110526315789, 0.9561265789473683, 0.49945936842105254`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 86}], {
             RGBColor[
             0.9804827631578947, 0.9553397894736841, 0.6021344999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 57}], {
             RGBColor[
             0.9264842368421052, 0.8004932631578947, 0.6006295263157895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 70}], {
             RGBColor[
             0.8680770526315791, 0.8974866315789474, 0.9712258157894736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 75}], {
             RGBColor[
             0.5662459210526316, 0.6351416578947369, 0.9484938947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 67}], {
             RGBColor[
             0.9764643421052632, 0.9366021052631579, 0.5507017105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 68}], {
             RGBColor[
             0.5850616052631579, 0.6480107105263158, 0.8645330526315789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 72}], {
             RGBColor[
             0.9308298157894737, 0.747656947368421, 0.5045944736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 78}], {
             RGBColor[
             0.9894451578947367, 0.9899033157894737, 0.8245845789473685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 65}], {
             RGBColor[
             0.948221947368421, 0.9589556842105263, 0.8931948157894736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 84}], {
             RGBColor[
             0.9800373157894737, 0.9834687894736842, 0.8665649999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 85}], {
             RGBColor[
             0.9928734473684211, 0.9906901052631579, 0.7219094473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 90}], {
             RGBColor[
             0.948221947368421, 0.9589556842105263, 0.8931948157894736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 100}], {
             RGBColor[
             0.9694951842105264, 0.910677842105263, 0.5362086315789474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 84}], {
             RGBColor[
             0.9196709210526315, 0.7404983157894737, 0.5755943684210525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 100}], {
             RGBColor[
             0.9091287894736841, 0.6677073684210526, 0.24523799999999998`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 59}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 66}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 79}], {
             RGBColor[
             0.5662459210526316, 0.6351416578947369, 0.9484938947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 98}], {
             RGBColor[0.5815595, 0.6465624999999999, 0.922572]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{55, 99}], {
             RGBColor[
             0.5739027105263157, 0.6408520789473684, 0.9355329473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 64}], {
             RGBColor[
             0.5818686842105263, 0.6329089736842106, 0.6644962894736841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 73}], {
             RGBColor[
             0.5470228947368421, 0.5032876578947368, 0.5920308947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 74}], {
             RGBColor[
             0.4807581315789475, 0.5677389736842107, 0.9562329210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 88}], {
             RGBColor[
             0.5867388421052631, 0.6480733947368422, 0.7908773947368422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 89}], {
             RGBColor[
             0.5662459210526316, 0.6351416578947369, 0.9484938947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 91}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 93}], {
             RGBColor[
             0.5585891315789473, 0.6294312368421053, 0.9614548421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 64}], {
             RGBColor[0.942107, 0.7982605789473685, 0.3166319210526315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 70}], {
             RGBColor[
             0.840996447368421, 0.7330905789473685, 0.608368552631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 74}], {
             RGBColor[
             0.840996447368421, 0.7330905789473685, 0.608368552631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 75}], {
             RGBColor[
             0.5391653157894737, 0.4707456052631579, 0.5856366315789474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 88}], {
             RGBColor[
             0.9469771578947368, 0.8134250000000001, 0.44301302631578954`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 96}], {
             RGBColor[
             0.8921685789473683, 0.6032445263157893, 0.2317351578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 63}], {
             RGBColor[
             0.8441148157894738, 0.8344205789473684, 0.6396062105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 83}], {
             RGBColor[0.923333, 0.7264843157894736, 0.2657681842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 97}], {
             RGBColor[
             0.9305680526315789, 0.7593369999999999, 0.2718052894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 66}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 69}], {
             RGBColor[
             0.4807581315789475, 0.5677389736842107, 0.9562329210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 77}], {
             RGBColor[
             0.5867388421052631, 0.6480733947368422, 0.7908773947368422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 79}], {
             RGBColor[
             0.5662459210526316, 0.6351416578947369, 0.9484938947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 83}], {
             RGBColor[
             0.5319302631578946, 0.43789292105263145`, 0.5795995263157895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 95}], {
             RGBColor[0.49812300000000004`, 0.2197605, 0.5488595000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 97}], {
             RGBColor[
             0.5391653157894736, 0.4707456052631579, 0.5856366315789474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 98}], {
             RGBColor[0.5815595, 0.6465624999999999, 0.922572]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{59, 99}], {
             RGBColor[
             0.5739027105263157, 0.6408520789473684, 0.9355329473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 64}], {
             RGBColor[
             0.9848103684210526, 0.9604239473684211, 0.3954915789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 71}], {
             RGBColor[
             0.9732714210526316, 0.9215003684210527, 0.350664947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 74}], {
             RGBColor[
             0.8836998157894738, 0.8952539473684211, 0.6872282105263157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 89}], {
             RGBColor[
             0.9691876052631578, 0.9626566315789473, 0.6794891842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 93}], {
             RGBColor[
             0.9615308157894736, 0.9569462105263158, 0.6924501315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 67}], {
             RGBColor[
             0.9782153947368422, 0.9373262105263158, 0.5216822368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 68}], {
             RGBColor[
             0.5868126578947368, 0.6487348157894737, 0.8355135789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 72}], {
             RGBColor[
             0.9325808684210526, 0.748381052631579, 0.47557499999999997`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 86}], {
             RGBColor[
             0.9911962105263157, 0.9906274210526316, 0.7955651052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 92}], {
             RGBColor[
             0.9134314210526315, 0.9305425263157895, 0.8606899736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 94}], {
             RGBColor[
             0.9664747894736841, 0.972772052631579, 0.8634674210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 83}], {
             RGBColor[
             0.8057153421052632, 0.6783281052631578, 0.5995360789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 97}], {
             RGBColor[
             0.8129503947368422, 0.7111807894736841, 0.6055731842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 73}], {
             RGBColor[
             0.9499645789473684, 0.8308026315789474, 0.32302618421052626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 74}], {
             RGBColor[
             0.8836998157894738, 0.8952539473684211, 0.6872282105263157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 88}], {
             RGBColor[
             0.9896805263157895, 0.9755883684210527, 0.5218726842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 89}], {
             RGBColor[
             0.9691876052631578, 0.9626566315789473, 0.6794891842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 91}], {
             RGBColor[
             0.5818686842105263, 0.6329089736842105, 0.6644962894736841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 93}], {
             RGBColor[
             0.9615308157894736, 0.9569462105263158, 0.6924501315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 96}], {
             RGBColor[
             0.934871947368421, 0.7654078947368419, 0.31059481578947357`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 90}], {
             RGBColor[
             0.9052476842105264, 0.9272839473684211, 0.9908245263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 100}], {
             RGBColor[
             0.9265209210526316, 0.8790061052631579, 0.6338383421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 69}], {
             RGBColor[
             0.4807581315789475, 0.5677389736842107, 0.9562329210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 77}], {
             RGBColor[
             0.5867388421052631, 0.6480733947368422, 0.7908773947368422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 79}], {
             RGBColor[
             0.5662459210526316, 0.6351416578947369, 0.9484938947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 83}], {
             RGBColor[
             0.5319302631578946, 0.43789292105263145`, 0.5795995263157895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 95}], {
             RGBColor[0.49812300000000004`, 0.2197605, 0.5488595000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 97}], {
             RGBColor[
             0.5391653157894736, 0.4707456052631579, 0.5856366315789474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[0.5815595, 0.6465624999999999, 0.922572]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{66, 99}], {
             RGBColor[
             0.5739027105263157, 0.6408520789473684, 0.9355329473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 68}], {
             RGBColor[
             0.5703297368421053, 0.5939853947368421, 0.6196696578947369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 72}], {
             RGBColor[
             0.916097947368421, 0.6936316315789474, 0.25973107894736847`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 86}], {
             RGBColor[0.9747132894736842, 0.935878, 0.5797211842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 92}], {
             RGBColor[0.8969485, 0.8757931052631579, 0.6448460526315789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 94}], {
             RGBColor[0.9499918684210527, 0.9180226315789474, 0.6476235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 72}], {
             RGBColor[
             0.5246952105263158, 0.4050402368421052, 0.5735624210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 82}], {
             RGBColor[
             0.5867388421052631, 0.6480733947368422, 0.7908773947368422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 92}], {
             RGBColor[
             0.5055457631578948, 0.5872017105263159, 0.9586773947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 71}], {
             RGBColor[
             0.8721608684210527, 0.8563303684210527, 0.6424015789473685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 77}], {
             RGBColor[
             0.8885699736842105, 0.9104183684210527, 0.8136093157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 87}], {
             RGBColor[
             0.8680770526315791, 0.8974866315789474, 0.9712258157894736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 95}], {
             RGBColor[
             0.7999541315789475, 0.4821054736842106, 0.5715914210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 97}], {
             RGBColor[
             0.840996447368421, 0.7330905789473685, 0.608368552631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 98}], {
             RGBColor[
             0.8833906315789475, 0.9089074736842107, 0.9453039210526315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 99}], {
             RGBColor[
             0.8757338421052632, 0.903197052631579, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 75}], {
             RGBColor[
             0.4807581315789474, 0.5677389736842106, 0.9562329210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 96}], {
             RGBColor[
             0.8337613947368421, 0.700237894736842, 0.602331447368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 77}], {
             RGBColor[
             0.9781415789473684, 0.9366647894736843, 0.477046052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 87}], {
             RGBColor[
             0.9576486578947369, 0.923733052631579, 0.634662552631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 82}], {
             RGBColor[
             0.9325070526315788, 0.7477196315789474, 0.4309388157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 92}], {
             RGBColor[
             0.8513139736842106, 0.686847947368421, 0.5987388157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 74}], {
             RGBColor[
             0.8488540263157895, 0.7656326315789475, 0.6147628157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 88}], {
             RGBColor[
             0.9548347368421053, 0.845967052631579, 0.44940728947368425`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.9343418157894736, 0.8330353157894737, 0.6070237894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 91}], {
             RGBColor[
             0.5470228947368421, 0.5032876578947368, 0.5920308947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 93}], {
             RGBColor[
             0.9266850263157894, 0.8273248947368421, 0.6199847368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 88}], {
             RGBColor[
             0.8885699736842105, 0.9104183684210527, 0.8136093157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 91}], {
             RGBColor[
             0.4807581315789474, 0.5677389736842106, 0.9562329210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 96}], {
             RGBColor[
             0.8337613947368421, 0.700237894736842, 0.602331447368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 96}], {
             RGBColor[
             0.5319302631578946, 0.43789292105263145`, 0.5795995263157895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 81}], {
             RGBColor[
             0.9459080526315788, 0.959178894736842, 0.9764477368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 84}], {
             RGBColor[
             0.9612216315789474, 0.9705997368421053, 0.9505258421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 85}], {
             RGBColor[
             0.9740577631578947, 0.9778210526315789, 0.8058702894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 87}], {
             RGBColor[
             0.9740577631578947, 0.9778210526315789, 0.8058702894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 95}], {
             RGBColor[
             0.9059348421052631, 0.5624398947368421, 0.40623589473684213`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 97}], {
             RGBColor[
             0.9469771578947368, 0.8134250000000001, 0.44301302631578954`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 98}], {
             RGBColor[
             0.9893713421052631, 0.9892418947368422, 0.7799483947368422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 99}], {
             RGBColor[
             0.9817145526315789, 0.9835314736842106, 0.7929093421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 83}], {
             RGBColor[
             0.9192491842105263, 0.7676405789473683, 0.5945924210526315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 98}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 99}], {
             RGBColor[
             0.9612216315789474, 0.9705997368421053, 0.9505258421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 84}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.9634867894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 85}], {
             RGBColor[
             0.9664009736842105, 0.9721106315789474, 0.8188312368421053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 86}], {
             RGBColor[
             0.991122394736842, 0.9899660000000001, 0.7509289210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 87}], {
             RGBColor[
             0.9740577631578947, 0.9778210526315789, 0.8058702894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 92}], {
             RGBColor[
             0.9133576052631579, 0.9298811052631579, 0.8160537894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 97}], {
             RGBColor[
             0.8921685789473683, 0.6032445263157893, 0.2317351578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 85}], {
             RGBColor[
             0.9817145526315789, 0.9835314736842106, 0.7929093421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.937063052631579, 0.951797052631579, 0.9641947105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 90}], {
             RGBColor[
             0.9498991842105263, 0.9590183684210527, 0.8195391578947369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 92}], {
             RGBColor[
             0.9099293157894737, 0.9290943157894738, 0.9187289210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[
             0.9629726842105262, 0.9713238421052632, 0.9215063684210527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 91}], {
             RGBColor[
             0.5867388421052632, 0.6480733947368421, 0.7908773947368422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 96}], {
             RGBColor[
             0.9397421052631578, 0.7805723157894735, 0.4369759210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 91}], {
             RGBColor[
             0.5662459210526316, 0.6351416578947369, 0.9484938947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 93}], {
             RGBColor[
             0.9459080526315788, 0.959178894736842, 0.9764477368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 100}], {
             RGBColor[
             0.9265209210526316, 0.8790061052631579, 0.6338383421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 93}], {
             RGBColor[
             0.5585891315789473, 0.6294312368421053, 0.9614548421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 96}], {
             RGBColor[
             0.5319302631578946, 0.43789292105263145`, 0.5795995263157895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 94}], {
             RGBColor[
             0.885207894736842, 0.911238947368421, 0.9866312368421053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 98}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{95, 99}], {
             RGBColor[
             0.8930987105263157, 0.5552185789473685, 0.550891447368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 99}], {
             RGBColor[
             0.9765352105263158, 0.9820205789473684, 0.924603947368421]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.058168352269944726`], {
             RGBColor[
             0.7825892631578949, 0.8300839473684212, 0.9789648421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.058168352269944726`], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.058168352269944726`], {
             RGBColor[
             0.9617324736842106, 0.8825767894736842, 0.30583831578947374`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.058168352269944726`], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.9634867894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.058168352269944726`], {
             RGBColor[
             0.9945506842105263, 0.9907527894736843, 0.6482537894736843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.058168352269944726`], {
             RGBColor[
             0.9477941578947369, 0.8307282631578946, 0.27685215789473683`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.058168352269944726`], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.058168352269944726`], {
             RGBColor[
             0.9382512631578946, 0.9534684736842105, 0.9894086842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.058168352269944726`], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.058168352269944726`], {
             RGBColor[
             0.9848103684210526, 0.9604239473684211, 0.3954915789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.058168352269944726`], {
             RGBColor[
             0.9617324736842106, 0.8825767894736842, 0.30583831578947374`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.058168352269944726`], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.058168352269944726`], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.058168352269944726`], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947369]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.058168352269944726`], {
             RGBColor[
             0.9151187894736842, 0.7011813157894737, 0.2505607894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.058168352269944726`], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.058168352269944726`], {
             RGBColor[
             0.9151187894736842, 0.7011813157894737, 0.2505607894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.058168352269944726`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.058168352269944726`], {
             RGBColor[
             0.9314564736842105, 0.7659547894736839, 0.26370647368421046`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.058168352269944726`], {
             RGBColor[
             0.9945506842105263, 0.9907527894736843, 0.6482537894736843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.058168352269944726`], {
             RGBColor[
             0.9927955263157895, 0.9869986842105264, 0.45721568421052644`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.058168352269944726`], {
             RGBColor[
             0.9936731052631579, 0.9888757368421053, 0.552734736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.058168352269944726`], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.058168352269944726`], {
             RGBColor[
             0.9477941578947369, 0.8307282631578946, 0.27685215789473683`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.058168352269944726`], {
             RGBColor[
             0.8849335263157894, 0.5703918421052628, 0.22569805263157888`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.058168352269944726`], {
             RGBColor[
             0.8704634210526315, 0.5046864736842105, 0.21362384210526314`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.058168352269944726`], {
             RGBColor[
             0.7264971578947369, 0.7862643684210526, 0.9733741052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.058168352269944726`], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.9634867894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.058168352269944726`], {
             RGBColor[
             0.9617324736842106, 0.8825767894736842, 0.30583831578947374`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.058168352269944726`], {
             RGBColor[
             0.9477941578947369, 0.8307282631578946, 0.27685215789473683`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.058168352269944726`], {
             RGBColor[
             0.9477941578947369, 0.8307282631578946, 0.27685215789473683`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.058168352269944726`], {
             RGBColor[
             0.9927955263157895, 0.9869986842105264, 0.45721568421052644`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.058168352269944726`], {
             RGBColor[
             0.9945506842105263, 0.9907527894736843, 0.6482537894736843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.058168352269944726`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.058168352269944726`], {
             RGBColor[
             0.8849335263157894, 0.5703918421052628, 0.22569805263157888`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.058168352269944726`], {
             RGBColor[
             0.7264971578947369, 0.7862643684210526, 0.9733741052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.058168352269944726`], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.9634867894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.058168352269944726`], {
             RGBColor[
             0.8321645263157895, 0.8690094210526316, 0.9838537894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.058168352269944726`], {
             RGBColor[
             0.9151187894736842, 0.7011813157894737, 0.2505607894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.058168352269944726`], {
             RGBColor[
             0.8321645263157895, 0.8690094210526316, 0.9838537894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.058168352269944726`], {
             RGBColor[
             0.9936731052631579, 0.9888757368421053, 0.552734736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.058168352269944726`], {
             RGBColor[
             0.21992247368421053`, 0.34848284210526315`, 0.9358356315789473]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.058168352269944726`], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947369]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.058168352269944726`], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.058168352269944726`], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.058168352269944726`], {
             RGBColor[
             0.21992247368421053`, 0.34848284210526315`, 0.9358356315789473]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.058168352269944726`], {
             RGBColor[
             0.9848103684210526, 0.9604239473684211, 0.3954915789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.058168352269944726`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.058168352269944726`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.058168352269944726`], {
             RGBColor[
             0.9732714210526315, 0.9215003684210524, 0.3506649473684208]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.058168352269944726`], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.9634867894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.058168352269944726`], {
             RGBColor[
             0.9911962105263158, 0.9906274210526316, 0.7955651052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.058168352269944726`], {
             RGBColor[
             0.9911962105263158, 0.9906274210526316, 0.7955651052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.058168352269944726`], {
             RGBColor[
             0.8704634210526315, 0.5046864736842105, 0.21362384210526314`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.058168352269944726`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.058168352269944726`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.058168352269944726`], {
             RGBColor[
             0.8994036315789473, 0.6360972105263157, 0.23777226315789474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.058168352269944726`], {
             RGBColor[
             0.9617324736842106, 0.8825767894736842, 0.30583831578947374`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.058168352269944726`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.058168352269944726`], {
             RGBColor[
             0.9848103684210526, 0.9604239473684211, 0.3954915789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.058168352269944726`], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947369]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.058168352269944726`], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947369]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.058168352269944726`], {
             RGBColor[
             0.7264971578947369, 0.7862643684210526, 0.9733741052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.058168352269944726`], {
             RGBColor[
             0.9848103684210526, 0.9604239473684211, 0.3954915789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.058168352269944726`], {
             RGBColor[
             0.9052476842105264, 0.9272839473684211, 0.9908245263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.058168352269944726`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.058168352269944726`], {
             RGBColor[
             0.9617324736842106, 0.8825767894736842, 0.30583831578947374`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.058168352269944726`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.058168352269944726`], {
             RGBColor[
             0.7825892631578949, 0.8300839473684212, 0.9789648421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.058168352269944726`], {
             RGBColor[
             0.7825892631578949, 0.8300839473684212, 0.9789648421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.058168352269944726`], {
             RGBColor[
             0.9617324736842106, 0.8825767894736842, 0.30583831578947374`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.058168352269944726`], {
             RGBColor[
             0.8704634210526315, 0.5046864736842105, 0.21362384210526314`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.058168352269944726`], {
             RGBColor[
             0.9151187894736842, 0.7011813157894737, 0.2505607894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.058168352269944726`], {
             RGBColor[
             0.7825892631578949, 0.8300839473684212, 0.9789648421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.058168352269944726`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.058168352269944726`], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.9634867894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.058168352269944726`], {
             RGBColor[
             0.9945506842105263, 0.9907527894736843, 0.6482537894736843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.058168352269944726`], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.058168352269944726`], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.9634867894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.058168352269944726`], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.058168352269944726`], {
             RGBColor[
             0.9382512631578946, 0.9534684736842105, 0.9894086842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.058168352269944726`], {
             RGBColor[
             0.9945506842105263, 0.9907527894736843, 0.6482537894736843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.058168352269944726`], {
             RGBColor[
             0.8849335263157894, 0.5703918421052628, 0.22569805263157888`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.058168352269944726`], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.058168352269944726`], {
             RGBColor[
             0.9945506842105263, 0.9907527894736843, 0.6482537894736843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.058168352269944726`], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.058168352269944726`], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.9634867894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.058168352269944726`], {
             RGBColor[
             0.9945506842105263, 0.9907527894736843, 0.6482537894736843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.058168352269944726`], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.9634867894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.058168352269944726`], {
             RGBColor[
             0.9052476842105264, 0.9272839473684211, 0.9908245263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.058168352269944726`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.058168352269944726`], {
             RGBColor[
             0.8321645263157895, 0.8690094210526316, 0.9838537894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.058168352269944726`], {
             RGBColor[
             0.9382512631578946, 0.9534684736842105, 0.9894086842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.058168352269944726`], {
             RGBColor[
             0.9382512631578946, 0.9534684736842105, 0.9894086842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.058168352269944726`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.058168352269944726`], {
             RGBColor[
             0.8849335263157894, 0.5703918421052628, 0.22569805263157888`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.058168352269944726`], {
             RGBColor[
             0.8994036315789473, 0.6360972105263157, 0.23777226315789474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.058168352269944726`], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.058168352269944726`], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.058168352269944726`], {
             RGBColor[
             0.9477941578947369, 0.8307282631578946, 0.27685215789473683`]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100}, {
          Null, CompressedData["
1:eJwVxVmbqQwAAOCxVtbppLIkW4w1a5YJk8gSaaRCIqr783/Pr/me7715C/Zf
xfZ+fHz883x8/D9363DUk1oFBOGSrgbkKTe9Ubr+DJzlM67jGn44aCN55AiO
7OTWuWMuH0qHqrVObVrjcvv1PnbAe71DT+vplLkyddN8hkqxEiiAOngBnQA/
4nmBl/kz71Cz2Wqmz8zZE8QwHhOwC+aAKIqhFLpCL6gZpsKz8Cpshp+ghVm8
JViWU9t1dtxud0NGCI/IiIU4oXgsHi/Fq3gmo3kQT8YzygyrQz/up/w9/8Gv
+58BCZQwiZcESbpIluT8+c395n89MAjDCIzBI5iHBViCZdiCncDPzznXz/f7
6/6+Nu6Mx9x4N755Y96s9xj4/v75PnvrsXq2Xj/6SZBESYzESZIie6ROmuQz
5MbdtFt1h+5nNkDABEIQI4InZOJMOOEtuqW2s+1quzU9NEwjNEHTI1qmLdpp
99vr9t5fxsuZcrlXPpS19qvz4l7r1/6Fqxm1rPbUoXpQVc1b+CxkC4V67dF5
jB/TB/fYPW6PXCvfah1r1/a1cx1fuevuen2l0qlqaphy0SJWLE6LQlEqXjzR
aCY6jKpRLfeV//pqff3WxLbYEcfiVOTEnShexZenEW0gjUyjQTeG3maumW9+
NevNZqt5DC+p5Wy5XC23S31pLp/+ZCyJJ5P1ZC95AKJACsgAZaAKDAEV0AAX
7KJdrFvsdoWu1L3U7p37+M7dd3fxfr3f7vfH/RV4f79/3vxbeEvv8xswQkbc
SBslo2qohmYYbhAIhoLxYCqYDpaC1aARdIub7ma6ETYbaXMJsDCLsARLsyOW
5VmBlViZPbMW+2Yd7zw2j88/59l5YV6a1+eBRIJIfCfYxE+CT8iJc+IdXACL
0CK1SC+qi4WxcEEFVTCFVIoKpXSVlbJVFF25KCZsIzZh0/bIZm3eFmzJlm3L
th1vJVaJV7KVUqVSr8zDg9ZgsBysBtvBEThFT/gpcyqfeqfD6aSetCADMCEm
xsSZNFNiqgyzYFRGYwzGbU86k/5kwk3WE3Gyn1wnL6/P9+nL+gq+iq/um0dq
kUFkGuEiYuQaefkhKAyhEAlR0AxaQitoCymQDpnQ8z9pR8GG
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[69, 98] -> 
             RGBColor[
              0.35934722090825977`, 0.48438990088158124`, 0.9441651443282024],
              UndirectedEdge[29, 33] -> 
             RGBColor[
              0.29422509162390786`, 0.4255184180648389, 0.9401059109878009], 
             UndirectedEdge[55, 59] -> 
             RGBColor[
              0.26182384182735224`, 0.39252383672388913`, 0.9382218525071802],
              UndirectedEdge[47, 74] -> 
             RGBColor[
              0.31904494583740095`, 0.4476628644149205, 0.9416637299737558], 
             UndirectedEdge[19, 43] -> 
             RGBColor[
              0.25864725898215624`, 0.389185046746603, 0.9380409508134795], 
             UndirectedEdge[57, 75] -> 
             RGBColor[
              0.25952031121468844`, 0.390102679997703, 0.9380906698465571], 
             UndirectedEdge[19, 46] -> 
             RGBColor[
              0.2688995810964162, 0.39996088732345647`, 0.9386248053909352], 
             UndirectedEdge[36, 67] -> 
             RGBColor[
              0.18042977836149893`, 0.3069735153395867, 0.9335865810045261], 
             UndirectedEdge[79, 99] -> 
             RGBColor[
              0.3231374521934327, 0.4482183313765927, 0.9420339521780562], 
             UndirectedEdge[52, 68] -> 
             RGBColor[
              0.8780291995303775, 0.46447808085033465`, 0.21689224319720418`],
              UndirectedEdge[81, 85] -> 
             RGBColor[
              0.5777440554332705, 0.6680776771306483, 0.9599012748713662], 
             UndirectedEdge[12, 88] -> 
             RGBColor[
              0.44729833605503005`, 0.5559100353701449, 0.9509297720791202], 
             UndirectedEdge[72, 82] -> 
             RGBColor[
              0.8344620499016556, 0.2658959936764921, 0.180634203946131], 
             UndirectedEdge[31, 44] -> 
             RGBColor[
              0.5893518598321712, 0.6739738751825308, 0.9626393731710036], 
             UndirectedEdge[17, 79] -> 
             RGBColor[
              0.3156295526433677, 0.44171536614432994`, 0.9415555554577009], 
             UndirectedEdge[91, 96] -> 
             RGBColor[
              0.269451185257078, 0.40054065827003577`, 0.9386562184318596], 
             UndirectedEdge[55, 99] -> 
             RGBColor[
              0.32604506358539376`, 0.45127441530275375`, 0.9421995363454028],
              UndirectedEdge[77, 99] -> 
             RGBColor[
              0.4105884153235183, 0.5300527814046032, 0.9473833086487027], 
             UndirectedEdge[29, 38] -> 
             RGBColor[
              0.3762188058276783, 0.5002835531261081, 0.9451933075234802], 
             UndirectedEdge[26, 90] -> 
             RGBColor[
              0.2640863311664119, 0.39490185646935017`, 0.9383506979279865], 
             UndirectedEdge[13, 27] -> 
             RGBColor[
              0.30786109230723857`, 0.43780476345745334`, 0.9409573735218479],
              UndirectedEdge[22, 99] -> 
             RGBColor[
              0.6824515754881706, 0.7473171966554524, 0.9484738769221548], 
             UndirectedEdge[73, 74] -> 
             RGBColor[
              0.3072565676292452, 0.4352725314918011, 0.940992399274144], 
             UndirectedEdge[8, 77] -> 
             RGBColor[
              0.6903471893885933, 0.7540727058376107, 0.9477616322002713], 
             UndirectedEdge[36, 94] -> 
             RGBColor[
              0.1800640484055534, 0.3065891099672694, 0.9335657532245839], 
             UndirectedEdge[21, 87] -> 
             RGBColor[
              0.8461475149580568, 0.7442097533956613, 0.6102686063858478], 
             UndirectedEdge[59, 83] -> 
             RGBColor[
              0.24944682557751796`, 0.3795148078971581, 0.9375169997419068], 
             UndirectedEdge[24, 42] -> 
             RGBColor[
              0.7818518898687528, 0.7011631313519644, 0.6053992543639326], 
             UndirectedEdge[33, 42] -> 
             RGBColor[
              0.46221511877127164`, 0.5653020306816455, 0.952477193383617], 
             UndirectedEdge[14, 42] -> 
             RGBColor[
              0.6875842561639678, 0.755865313839969, 0.9694956308803766], 
             UndirectedEdge[45, 78] -> 
             RGBColor[
              0.8888960529642432, 0.9113695171236152, 0.8624721274568261], 
             UndirectedEdge[15, 38] -> 
             RGBColor[
              0.3740760297515814, 0.49842758818805, 0.9450567717266938], 
             UndirectedEdge[84, 85] -> 
             RGBColor[
              0.5258992134513589, 0.6255397259320082, 0.9559436352420423], 
             UndirectedEdge[55, 98] -> 
             RGBColor[
              0.2718017456530969, 0.4030112462803886, 0.9387900793690704], 
             UndirectedEdge[86, 92] -> 
             RGBColor[
              0.5898473968790202, 0.652327074257428, 0.8461866592841044], 
             UndirectedEdge[72, 92] -> 
             RGBColor[
              0.5088521381215928, 0.27790300442365007`, 0.5558317972580653], 
             UndirectedEdge[19, 99] -> 
             RGBColor[
              0.33504481922143936`, 0.46073372909370225`, 0.9427120591149303],
              UndirectedEdge[4, 76] -> 
             RGBColor[
              0.9165776385018892, 0.6448130127141793, 0.40538275488353814`], 
             UndirectedEdge[23, 76] -> 
             RGBColor[
              0.9905483291850934, 0.9895519766020239, 0.7476033518841813], 
             UndirectedEdge[9, 72] -> 
             RGBColor[
              0.8914135512087347, 0.5438293614385904, 0.22874208440602506`], 
             UndirectedEdge[2, 44] -> 
             RGBColor[
              0.6476158835940419, 0.7227173201002071, 0.9668276779841867], 
             UndirectedEdge[74, 88] -> 
             RGBColor[
              0.3260233854984479, 0.4549976469573106, 0.9420611417887761], 
             UndirectedEdge[21, 49] -> 
             RGBColor[
              0.8381155029968219, 0.7379350846059927, 0.6094680504969712], 
             UndirectedEdge[21, 34] -> 
             RGBColor[
              0.7440489383777218, 0.6635696741320418, 0.6006939636333543], 
             UndirectedEdge[59, 66] -> 
             RGBColor[
              0.2986049435975745, 0.4299329425040255, 0.9403622564770246], 
             UndirectedEdge[17, 99] -> 
             RGBColor[
              0.3958768319210234, 0.5173103472870436, 0.9464458995632381], 
             UndirectedEdge[26, 53] -> 
             RGBColor[
              0.27181647740875625`, 0.40165680145894234`, 0.9388410781260154],
              UndirectedEdge[23, 50] -> 
             RGBColor[
              0.9890507904475296, 0.9897402347152724, 0.831120268137828], 
             UndirectedEdge[41, 74] -> 
             RGBColor[
              0.39624144168094344`, 0.517626153935267, 0.9464691321747285], 
             UndirectedEdge[59, 79] -> 
             RGBColor[
              0.2589162304353912, 0.38946775279772805`, 0.9380562683398335], 
             UndirectedEdge[56, 93] -> 
             RGBColor[
              0.251058389952088, 0.3812086642339142, 0.9376087759489427], 
             UndirectedEdge[19, 98] -> 
             RGBColor[
              0.2808015012891425, 0.4124705600713371, 0.9393026021385978], 
             UndirectedEdge[2, 38] -> 
             RGBColor[
              0.4744745540542128, 0.5836658197325597, 0.9519298496562583], 
             UndirectedEdge[19, 59] -> 
             RGBColor[
              0.2708235974633978, 0.40198315051483763`, 0.9387343752767077], 
             UndirectedEdge[24, 76] -> 
             RGBColor[
              0.9509230096039614, 0.8306452679372385, 0.4351994673534736], 
             UndirectedEdge[5, 20] -> 
             RGBColor[
              0.23580229552736498`, 0.3651735417012756, 0.9367399639408238], 
             UndirectedEdge[37, 84] -> 
             RGBColor[
              0.5813861978869495, 0.66930600772412, 0.9611872941941962], 
             UndirectedEdge[9, 82] -> 
             RGBColor[
              0.8944306469902588, 0.5670200817151858, 0.2316312587337348], 
             UndirectedEdge[47, 75] -> 
             RGBColor[
              0.2704352603663721, 0.40157498360386956`, 0.9387122600535251], 
             UndirectedEdge[51, 75] -> 
             RGBColor[
              0.2631874052799758, 0.3939570283675128, 0.9382995054285956], 
             UndirectedEdge[58, 63] -> 
             RGBColor[
              0.22145736040975994`, 0.3500961053712548, 0.9359230411073061], 
             UndirectedEdge[7, 25] -> 
             RGBColor[
              0.2646919276847649, 0.3951010487472052, 0.9384011984763869], 
             UndirectedEdge[1, 55] -> 
             RGBColor[
              0.25340680094735984`, 0.3836769930878019, 0.9377425144809607], 
             UndirectedEdge[82, 86] -> 
             RGBColor[
              0.9154573086590831, 0.64032006351027, 0.4709890659721701], 
             UndirectedEdge[34, 71] -> 
             RGBColor[
              0.46781157980336074`, 0.5760433128989255, 0.9520168308232597], 
             UndirectedEdge[41, 73] -> 
             RGBColor[
              0.34062966364440406`, 0.46417862987955394`, 0.9431189034415599],
              UndirectedEdge[92, 94] -> 
             RGBColor[
              0.18353386454932197`, 0.3102361067334203, 0.9337633541208386], 
             UndirectedEdge[3, 62] -> 
             RGBColor[
              0.3326644235069168, 0.4616841238673607, 0.9424500919629462], 
             UndirectedEdge[70, 75] -> 
             RGBColor[
              0.2709835768789808, 0.4021512990238961, 0.9387434858677567], 
             UndirectedEdge[57, 96] -> 
             RGBColor[
              0.26925290833864535`, 0.40033225665728034`, 0.9386449268546793],
              UndirectedEdge[68, 72] -> 
             RGBColor[
              0.8243819770600658, 0.1884161366999483, 0.17098151480921064`], 
             UndirectedEdge[13, 54] -> 
             RGBColor[
              0.26215076948672145`, 0.392867458422297, 0.938240470553735], 
             UndirectedEdge[48, 96] -> 
             RGBColor[
              0.2710430288508906, 0.402213786815846, 0.9387468715696057], 
             UndirectedEdge[30, 50] -> 
             RGBColor[
              0.9048589996840575, 0.566437416695873, 0.47911193415723874`], 
             UndirectedEdge[11, 92] -> 
             RGBColor[
              0.21022995471211395`, 0.3382953901243926, 0.9352836569622833], 
             UndirectedEdge[41, 56] -> 
             RGBColor[
              0.3357366265014662, 0.459035737605853, 0.9428402522148693], 
             UndirectedEdge[73, 91] -> 
             RGBColor[
              0.25271649556761044`, 0.3829514383657963, 0.9377032026107992], 
             UndirectedEdge[32, 39] -> 
             RGBColor[
              0.2935264779562271, 0.4258453173585629, 0.9400272707348724], 
             UndirectedEdge[32, 80] -> 
             RGBColor[
              0.2808572092204622, 0.41252911263924097`, 0.939305774622874], 
             UndirectedEdge[20, 66] -> 
             RGBColor[
              0.271765998365242, 0.4017235093774315, 0.9388338182507047], 
             UndirectedEdge[47, 88] -> 
             RGBColor[
              0.28219998567006427`, 0.41394045582471695`, 0.9393822437552191],
              UndirectedEdge[14, 53] -> 
             RGBColor[
              0.5212638853795565, 0.6175278736453831, 0.9572307375115887], 
             UndirectedEdge[51, 57] -> 
             RGBColor[
              0.25705874177093724`, 0.3875154144398035, 0.9379504871083011], 
             UndirectedEdge[30, 94] -> 
             RGBColor[
              0.4995877733317956, 0.224777469479577, 0.549414921546451], 
             UndirectedEdge[22, 69] -> 
             RGBColor[
              0.6926573828576388, 0.7561569540400923, 0.9491241819430962], 
             UndirectedEdge[4, 94] -> 
             RGBColor[
              0.5098088734120636, 0.30334132361113186`, 0.5592026585263972], 
             UndirectedEdge[4, 86] -> 
             RGBColor[
              0.9161224057417618, 0.6454322911351396, 0.4716259636896631], 
             UndirectedEdge[9, 94] -> 
             RGBColor[
              0.566095277636464, 0.5761624637483606, 0.6066736412687983], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.25232882209907226`, 0.38254396897044507`, 0.9376811251802775],
              UndirectedEdge[12, 60] -> 
             RGBColor[
              0.5377449711891708, 0.6356046186030777, 0.9567524004381972], 
             UndirectedEdge[25, 40] -> 
             RGBColor[
              0.22979823437354924`, 0.35886289274915106`, 0.9363980415403266],
              UndirectedEdge[22, 95] -> 
             RGBColor[
              0.7735850344334367, 0.822659249453164, 0.9552736235962966], 
             UndirectedEdge[3, 33] -> 
             RGBColor[
              0.283755346452618, 0.41557523862275036`, 0.9394708192508354], 
             UndirectedEdge[48, 93] -> 
             RGBColor[
              0.2586149766637431, 0.3891511159831336, 0.9380391123832033], 
             UndirectedEdge[15, 90] -> 
             RGBColor[
              0.3120203774346074, 0.44461862031594124`, 0.9411048183197483], 
             UndirectedEdge[77, 97] -> 
             RGBColor[
              0.3343295626774611, 0.4586498895325537, 0.9427200995394867], 
             UndirectedEdge[44, 78] -> 
             RGBColor[
              0.88634546706693, 0.9093769800354632, 0.8622179088911622], 
             UndirectedEdge[30, 92] -> 
             RGBColor[
              0.5023132309055276, 0.22764209819356024`, 0.5495701323233219], 
             UndirectedEdge[37, 76] -> 
             RGBColor[
              0.8601494153237335, 0.8880770205793902, 0.7996440970661025], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.5927913677992559, 0.604221747139333, 0.6081939441102431], 
             UndirectedEdge[75, 96] -> 
             RGBColor[
              0.27538157184768386`, 0.40677387058498965`, 0.9389939451749738],
              UndirectedEdge[31, 80] -> 
             RGBColor[
              0.33469414166217204`, 0.4606589391956579, 0.9426813312926726], 
             UndirectedEdge[85, 90] -> 
             RGBColor[
              0.4615407941261787, 0.5697362170178263, 0.951844951557591], 
             UndirectedEdge[91, 93] -> 
             RGBColor[
              0.2570231330699305, 0.38747798743732337`, 0.9379484592454572], 
             UndirectedEdge[22, 49] -> 
             RGBColor[
              0.8672856751894109, 0.8967275864503471, 0.9640189035929849], 
             UndirectedEdge[69, 87] -> 
             RGBColor[
              0.6064566505030319, 0.6883381284885098, 0.9639201838642415], 
             UndirectedEdge[47, 70] -> 
             RGBColor[
              0.27576986252162594`, 0.40718198870235345`, 0.9390160577544302],
              UndirectedEdge[42, 78] -> 
             RGBColor[
              0.8251990022368825, 0.8616088969798854, 0.8561234007231051], 
             UndirectedEdge[1, 43] -> 
             RGBColor[
              0.25434890859377146`, 0.3846672079572553, 0.9377961661177004], 
             UndirectedEdge[10, 35] -> 
             RGBColor[
              0.2769526708149095, 0.4084251952129716, 0.9390834169369247], 
             UndirectedEdge[67, 94] -> 
             RGBColor[
              0.18117413693153547`, 0.3077558833917543, 0.9336289711239099], 
             UndirectedEdge[73, 93] -> 
             RGBColor[
              0.2559514270950259, 0.38635155650761516`, 0.9378874271756332], 
             UndirectedEdge[68, 82] -> 
             RGBColor[
              0.8273990728415899, 0.2116068569765438, 0.1738706891369204], 
             UndirectedEdge[11, 52] -> 
             RGBColor[
              0.5864699931809645, 0.5791596032510256, 0.6031076177106328], 
             UndirectedEdge[15, 53] -> 
             RGBColor[
              0.3197505236769518, 0.4513735653055334, 0.9415951985177772], 
             UndirectedEdge[53, 100] -> 
             RGBColor[
              0.2844126072753804, 0.4148961325895252, 0.9395584090876155], 
             UndirectedEdge[58, 83] -> 
             RGBColor[
              0.22400482828107066`, 0.3527736556227943, 0.9360681156339361], 
             UndirectedEdge[74, 96] -> 
             RGBColor[
              0.3239912573187127, 0.45286175139604057`, 0.9419454150952044], 
             UndirectedEdge[8, 87] -> 
             RGBColor[
              0.8760096171986388, 0.9035182955368775, 0.9636482023948687], 
             UndirectedEdge[43, 46] -> 
             RGBColor[
              0.2608419331067822, 0.3914917884019613, 0.9381659342581474], 
             UndirectedEdge[73, 89] -> 
             RGBColor[
              0.24808487338589558`, 0.37808330979100657`, 0.9374394385794216],
              UndirectedEdge[11, 67] -> 
             RGBColor[
              0.20787022709432745`, 0.3358151667827266, 0.9351492739653546], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.28368193490479854`, 0.4148331204560798, 0.9394909859406446], 
             UndirectedEdge[98, 99] -> 
             RGBColor[
              0.3491414135387916, 0.47555014349694125`, 0.943514839307261], 
             UndirectedEdge[4, 9] -> 
             RGBColor[
              0.8950957440729377, 0.5721323093400554, 0.23226815645122778`], 
             UndirectedEdge[34, 49] -> 
             RGBColor[
              0.678986366254469, 0.7482686816351451, 0.9692402627616367], 
             UndirectedEdge[6, 7] -> 
             RGBColor[
              0.2850997356690481, 0.41655094886844685`, 0.9395633929504454], 
             UndirectedEdge[7, 40] -> 
             RGBColor[
              0.2785823850167328, 0.4097008001089655, 0.9391922394723524], 
             UndirectedEdge[23, 85] -> 
             RGBColor[
              0.8008648229179952, 0.8435478591637703, 0.9160354539398804], 
             UndirectedEdge[82, 92] -> 
             RGBColor[
              0.5118692339031169, 0.30109372470024554`, 0.558720971585775], 
             UndirectedEdge[34, 69] -> 
             RGBColor[
              0.5043580739226968, 0.6076980492248905, 0.954345541111748], 
             UndirectedEdge[13, 85] -> 
             RGBColor[
              0.44417434838099124`, 0.5514829814433777, 0.9508559581637567], 
             UndirectedEdge[95, 98] -> 
             RGBColor[
              0.44027487248405767`, 0.5508921962946529, 0.9503145859814027], 
             UndirectedEdge[34, 87] -> 
             RGBColor[
              0.687018378215704, 0.7545433504248138, 0.9700408186505132], 
             UndirectedEdge[61, 94] -> 
             RGBColor[
              0.17986770348779496`, 0.3063827390097185, 0.9335545716719839], 
             UndirectedEdge[61, 72] -> 
             RGBColor[
              0.5051859770600657, 0.2740496366999483, 0.5556230148092107], 
             UndirectedEdge[50, 86] -> 
             RGBColor[
              0.9923931656575502, 0.9911223927597408, 0.7757284611180213], 
             UndirectedEdge[66, 97] -> 
             RGBColor[
              0.2865673127095588, 0.41728062921084064`, 0.9396767312060312], 
             UndirectedEdge[9, 21] -> 
             RGBColor[
              0.9272801117087064, 0.7490947632900866, 0.26033044528115884`], 
             UndirectedEdge[34, 60] -> 
             RGBColor[
              0.5274957486173808, 0.6272838379970835, 0.9559455440932065], 
             UndirectedEdge[53, 84] -> 
             RGBColor[
              0.3801912291988372, 0.5037242665904019, 0.9454464268280143], 
             UndirectedEdge[21, 22] -> 
             RGBColor[
              0.9323482473126639, 0.8120285789472437, 0.5954726044647025], 
             UndirectedEdge[14, 62] -> 
             RGBColor[
              0.5425047543047143, 0.6359256467112409, 0.9585841868969369], 
             UndirectedEdge[22, 30] -> 
             RGBColor[
              0.889942779596627, 0.5565022708656576, 0.5576225786548253], 
             UndirectedEdge[67, 72] -> 
             RGBColor[
              0.5064924105038062, 0.2754227810819841, 0.5556974142611366], 
             UndirectedEdge[61, 86] -> 
             RGBColor[
              0.5861812358174932, 0.6484737065337263, 0.8459778768352497], 
             UndirectedEdge[5, 83] -> 
             RGBColor[
              0.23714577838221002`, 0.3665856273634506, 0.9368164733019025], 
             UndirectedEdge[46, 99] -> 
             RGBColor[
              0.3372394933460653, 0.46304047074906063`, 0.9428370425595982], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.781084942834804, 0.8289087608987646, 0.9788149055141302], 
             UndirectedEdge[7, 37] -> 
             RGBColor[
              0.5197144859100872, 0.615889070520134, 0.9572576272411842], 
             UndirectedEdge[7, 53] -> 
             RGBColor[
              0.3185195172219749, 0.4503073293864159, 0.9415167598750023], 
             UndirectedEdge[12, 52] -> 
             RGBColor[
              0.7720788229198519, 0.7426869970369261, 0.6158231874912047], 
             UndirectedEdge[50, 85] -> 
             RGBColor[
              0.8031648921505794, 0.844498996900527, 0.8779173543675954], 
             UndirectedEdge[14, 15] -> 
             RGBColor[
              0.517451452940507, 0.6142257362851044, 0.9569878126877741], 
             UndirectedEdge[14, 35] -> 
             RGBColor[
              0.5107221888506179, 0.6078178110419963, 0.9565802436840543], 
             UndirectedEdge[8, 95] -> 
             RGBColor[
              0.7742769644814296, 0.8231752897500257, 0.9541023665093038], 
             UndirectedEdge[7, 84] -> 
             RGBColor[
              0.3751477903048108, 0.49935589331100566`, 0.9451250633614249], 
             UndirectedEdge[14, 76] -> 
             RGBColor[
              0.8566553758991764, 0.885347450425243, 0.7992958438699176], 
             UndirectedEdge[60, 89] -> 
             RGBColor[
              0.357298326389239, 0.4775030084894488, 0.9443308094531306], 
             UndirectedEdge[37, 85] -> 
             RGBColor[
              0.6704659090566354, 0.7420729031411366, 0.9680761991218017], 
             UndirectedEdge[39, 80] -> 
             RGBColor[
              0.28185045974068534`, 0.4135730819117158, 0.9393623387706183], 
             UndirectedEdge[23, 24] -> 
             RGBColor[
              0.9471254016338135, 0.8298823883137303, 0.5568344831794053], 
             UndirectedEdge[11, 68] -> 
             RGBColor[
              0.5257597936505869, 0.24880852240069085`, 0.5504333745134287], 
             UndirectedEdge[27, 81] -> 
             RGBColor[
              0.4414307993595177, 0.5543994591447239, 0.9500026902294574], 
             UndirectedEdge[36, 61] -> 
             RGBColor[
              0.17912334491775841`, 0.3056003709575509, 0.9335121815526001], 
             UndirectedEdge[28, 59] -> 
             RGBColor[
              0.2655146286535537, 0.39640308768762733`, 0.9384320373569025], 
             UndirectedEdge[8, 30] -> 
             RGBColor[
              0.8906347096446199, 0.5570183111625192, 0.5564513215678325], 
             UndirectedEdge[34, 82] -> 
             RGBColor[
              0.7111994736592744, 0.481494992557141, 0.5719947770859303], 
             UndirectedEdge[50, 84] -> 
             RGBColor[
              0.7140851809808935, 0.7717321014835103, 0.87102844943999], 
             UndirectedEdge[57, 88] -> 
             RGBColor[
              0.27128503651838054`, 0.40246815221855037`, 0.9387606535482509],
              UndirectedEdge[6, 53] -> 
             RGBColor[
              0.2901431745630745, 0.4209193221478431, 0.939884756417035], 
             UndirectedEdge[8, 69] -> 
             RGBColor[
              0.6933493129056316, 0.7566729943369539, 0.9479529248561034], 
             UndirectedEdge[69, 99] -> 
             RGBColor[
              0.41359053884055663`, 0.5326530699039465, 0.9475746013045347], 
             UndirectedEdge[81, 84] -> 
             RGBColor[
              0.4886643442635845, 0.5953107817136317, 0.9530123699437607], 
             UndirectedEdge[11, 94] -> 
             RGBColor[
              0.20750449713838193`, 0.3354307614104094, 0.9351284461854125], 
             UndirectedEdge[10, 65] -> 
             RGBColor[
              0.23682752030936433`, 0.3662511179501625, 0.9367983489754745], 
             UndirectedEdge[79, 98] -> 
             RGBColor[
              0.26889413426113584`, 0.39995516235422757`, 0.9386244952017238],
              UndirectedEdge[33, 62] -> 
             RGBColor[
              0.3171356169120182, 0.44536236355291736`, 0.9415657494001773], 
             UndirectedEdge[31, 70] -> 
             RGBColor[
              0.3382626356768291, 0.464409652660651, 0.9428845517476936], 
             UndirectedEdge[31, 32] -> 
             RGBColor[
              0.3463701598777138, 0.472931174642505, 0.9433462632569267], 
             UndirectedEdge[15, 100] -> 
             RGBColor[
              0.28060017483633093`, 0.41159399522924645`, 0.9393154842638007],
              UndirectedEdge[7, 65] -> 
             RGBColor[
              0.26785267018749115`, 0.3984231895202199, 0.9385811980860177], 
             UndirectedEdge[59, 95] -> 
             RGBColor[
              0.430296968658313, 0.5404047867381535, 0.9497463591195126], 
             UndirectedEdge[2, 3] -> 
             RGBColor[
              0.4080096464453409, 0.5252224449857339, 0.947726795683348], 
             UndirectedEdge[48, 88] -> 
             RGBColor[
              0.2730751570306258, 0.404349682377116, 0.9388625982631773], 
             UndirectedEdge[14, 38] -> 
             RGBColor[
              0.5755893914541861, 0.6645818965278997, 0.9606923107205052], 
             UndirectedEdge[44, 45] -> 
             RGBColor[
              0.7810472132422319, 0.8288792862542917, 0.9788111449809456], 
             UndirectedEdge[24, 50] -> 
             RGBColor[
              0.9494254708663976, 0.830833526050487, 0.5187163836071205], 
             UndirectedEdge[38, 62] -> 
             RGBColor[
              0.39912933111578863`, 0.5201274986141865, 0.9466531459358565], 
             UndirectedEdge[4, 50] -> 
             RGBColor[
              0.9150800997643256, 0.6450012708274279, 0.48889967113718485`], 
             UndirectedEdge[48, 74] -> 
             RGBColor[
              0.3099201171979624, 0.4380720909673196, 0.941144084481714], 
             UndirectedEdge[40, 100] -> 
             RGBColor[
              0.24447547507013836`, 0.3742896033120748, 0.9372338886849655], 
             UndirectedEdge[19, 95] -> 
             RGBColor[
              0.4261782781667054, 0.536075781891414, 0.949511805789072], 
             UndirectedEdge[19, 79] -> 
             RGBColor[
              0.2547975399437836, 0.38513874795098857`, 0.937821715009393], 
             UndirectedEdge[51, 70] -> 
             RGBColor[
              0.2685220074352297, 0.3995640334659966, 0.9386033031295007], 
             UndirectedEdge[17, 22] -> 
             RGBColor[
              0.6749436759381056, 0.7408142314231896, 0.9479954802017996], 
             UndirectedEdge[59, 99] -> 
             RGBColor[
              0.33916350971304693`, 0.46506273394044173`, 0.9429466124453707],
              UndirectedEdge[20, 63] -> 
             RGBColor[
              0.22006041247387476`, 0.34862782451902463`, 0.9358434869889567],
              UndirectedEdge[56, 89] -> 
             RGBColor[
              0.2431918362429577, 0.37294041751730556`, 0.937160787352731], 
             UndirectedEdge[12, 74] -> 
             RGBColor[
              0.48414329622236674`, 0.5896324439603484, 0.9532112582976568], 
             UndirectedEdge[8, 17] -> 
             RGBColor[
              0.6756356059860984, 0.7413302717200512, 0.9468242231148067], 
             UndirectedEdge[53, 90] -> 
             RGBColor[
              0.3158328098736569, 0.44792075767621997`, 0.941347743143563], 
             UndirectedEdge[21, 72] -> 
             RGBColor[
              0.8673115146201031, 0.4479706752513929, 0.20933339049355504`], 
             UndirectedEdge[48, 73] -> 
             RGBColor[
              0.25430833916142304`, 0.38462456691160657`, 0.9377938557485452],
              UndirectedEdge[8, 49] -> 
             RGBColor[
              0.8679776052374037, 0.8972436267472088, 0.9628476465059921], 
             UndirectedEdge[17, 69] -> 
             RGBColor[
              0.40608263929049154`, 0.5261501046716837, 0.9470962045841795], 
             UndirectedEdge[21, 82] -> 
             RGBColor[
              0.8703286104016272, 0.4711613955279884, 0.21222256482126478`], 
             UndirectedEdge[36, 68] -> 
             RGBColor[
              0.4983193449177584, 0.2199668709575509, 0.5488706815526001], 
             UndirectedEdge[21, 30] -> 
             RGBColor[
              0.860772607404038, 0.39770976902130306`, 0.2030717255588116], 
             UndirectedEdge[56, 64] -> 
             RGBColor[
              0.2634347031054928, 0.3942169540617188, 0.9383135886739146], 
             UndirectedEdge[48, 64] -> 
             RGBColor[
              0.27099128981714793`, 0.40215940581093823`, 0.9387439251081751],
              UndirectedEdge[46, 59] -> 
             RGBColor[
              0.27301827158802383`, 0.40428989217019595`, 0.9388593587213756],
              UndirectedEdge[46, 79] -> 
             RGBColor[
              0.25699221406840955`, 0.38744548960634695`, 0.937946698454061], 
             UndirectedEdge[9, 86] -> 
             RGBColor[
              0.9724088099661622, 0.9182534312723682, 0.5190969464320642], 
             UndirectedEdge[64, 91] -> 
             RGBColor[
              0.26939944622333534`, 0.400486277265128, 0.938653271970429], 
             UndirectedEdge[1, 19] -> 
             RGBColor[
              0.2624065565834054, 0.39313630687875045`, 0.9382550372504881], 
             UndirectedEdge[5, 69] -> 
             RGBColor[
              0.3370682698872072, 0.4609733107913742, 0.942896391026308], 
             UndirectedEdge[36, 92] -> 
             RGBColor[
              0.18278950597928542`, 0.3094537386812527, 0.9337209640014548], 
             UndirectedEdge[17, 95] -> 
             RGBColor[
              0.48701029086628944`, 0.5926524000847553, 0.95324564623738], 
             UndirectedEdge[7, 13] -> 
             RGBColor[
              0.293422925234443, 0.42529914882237513`, 0.9400373862831393], 
             UndirectedEdge[11, 61] -> 
             RGBColor[
              0.20656379365058694`, 0.3344420224006909, 0.9350748745134286], 
             UndirectedEdge[66, 83] -> 
             RGBColor[
              0.27310948122008705`, 0.4031355950396065, 0.9389103276117834], 
             UndirectedEdge[27, 37] -> 
             RGBColor[
              0.5341526529828826, 0.6283946851552121, 0.9581776144798929], 
             UndirectedEdge[22, 34] -> 
             RGBColor[
              0.7732191105703109, 0.8223621759763964, 0.955244816729368], 
             UndirectedEdge[6, 90] -> 
             RGBColor[
              0.2824130283207301, 0.41416437715825094`, 0.9393943762190061], 
             UndirectedEdge[71, 77] -> 
             RGBColor[
              0.3842477285736503, 0.5072378024632783, 0.9457049033811559], 
             UndirectedEdge[9, 68] -> 
             RGBColor[
              0.884350574148669, 0.48954022473864206`, 0.22197856959681445`], 
             UndirectedEdge[23, 86] -> 
             RGBColor[
              0.990093096424966, 0.9901712550229842, 0.8138465606903063], 
             UndirectedEdge[54, 84] -> 
             RGBColor[
              0.3438756345570892, 0.4669242029109275, 0.9433281476320208], 
             UndirectedEdge[3, 16] -> 
             RGBColor[
              0.26785762869397084`, 0.3988657292848884, 0.9385654677430463], 
             UndirectedEdge[66, 98] -> 
             RGBColor[
              0.3085828474233191, 0.440420352060525, 0.9409304833389149], 
             UndirectedEdge[64, 93] -> 
             RGBColor[
              0.2726343777507507, 0.4038863954069468, 0.938837496535263], 
             UndirectedEdge[2, 29] -> 
             RGBColor[
              0.41847939161663067`, 0.5351656244278226, 0.9483618874203135], 
             UndirectedEdge[50, 81] -> 
             RGBColor[
              0.7659300229628049, 0.8142700526821505, 0.8749860890693137], 
             UndirectedEdge[8, 99] -> 
             RGBColor[
              0.6831435055361634, 0.747833236952314, 0.947302619835162], 
             UndirectedEdge[66, 69] -> 
             RGBColor[
              0.37303197272508415`, 0.4975232784675301, 0.9449902453361887], 
             UndirectedEdge[9, 30] -> 
             RGBColor[
              0.8848746439926696, 0.49356845520850057`, 0.2224804194712816], 
             UndirectedEdge[11, 36] -> 
             RGBColor[
              0.20676013856834535`, 0.33464839335824176`, 0.9350860560660287],
              UndirectedEdge[16, 62] -> 
             RGBColor[
              0.30123789915337096`, 0.4286528542150554, 0.9406603978923882], 
             UndirectedEdge[50, 76] -> 
             RGBColor[
              0.9928483984176775, 0.9905031143387806, 0.7094852523118963], 
             UndirectedEdge[36, 86] -> 
             RGBColor[
              0.5863775807352516, 0.6486800774912771, 0.8459890583878498], 
             UndirectedEdge[60, 71] -> 
             RGBColor[
              0.41038752678537255`, 0.5294238797348146, 0.9474961990184465], 
             UndirectedEdge[43, 54] -> 
             RGBColor[
              0.2507606889125138, 0.3808957615659856, 0.9375918223151481], 
             UndirectedEdge[29, 42] -> 
             RGBColor[
              0.48821367053746006`, 0.5915669704381774, 0.9539966276833514], 
             UndirectedEdge[76, 84] -> 
             RGBColor[
              0.7155827197184571, 0.7715438433702618, 0.7875115331863431], 
             UndirectedEdge[65, 90] -> 
             RGBColor[
              0.26516596283917315`, 0.39603661781002397`, 0.9384121813545784],
              UndirectedEdge[52, 78] -> 
             RGBColor[
              0.9664668529248481, 0.8933481863027279, 0.5077226888807255], 
             UndirectedEdge[25, 65] -> 
             RGBColor[
              0.21906851954430756`, 0.34758528216040546`, 0.9357870001539919],
              UndirectedEdge[45, 52] -> 
             RGBColor[
              0.8611685991001501, 0.8128504925215565, 0.6243159249705089], 
             UndirectedEdge[57, 74] -> 
             RGBColor[
              0.3081299966857172, 0.43619056080875396`, 0.9410421397667876], 
             UndirectedEdge[17, 66] -> 
             RGBColor[
              0.3553182658055509, 0.48218055585062736`, 0.943861543594892], 
             UndirectedEdge[59, 98] -> 
             RGBColor[
              0.28492019178075007`, 0.41679956491807657`, 0.9395371554690384],
              UndirectedEdge[22, 77] -> 
             RGBColor[
              0.6896552593406005, 0.7535566655407491, 0.9489328892872642], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.9001907126422091, 0.6304699376692046, 0.5656021608302857], 
             UndirectedEdge[30, 36] -> 
             RGBColor[
              0.49884341476175903`, 0.2239951014274094, 0.5493725314270672], 
             UndirectedEdge[60, 64] -> 
             RGBColor[
              0.37754119325177404`, 0.49877954503386207`, 0.9454836107743141],
              UndirectedEdge[28, 99] -> 
             RGBColor[
              0.3297358504115952, 0.455153666266492, 0.9424097211951252], 
             UndirectedEdge[59, 69] -> 
             RGBColor[
              0.34936931708251506`, 0.4739024913250818, 0.9435969174663121], 
             UndirectedEdge[66, 79] -> 
             RGBColor[
              0.2825788860779602, 0.4130885399401764, 0.93944959620971], 
             UndirectedEdge[7, 81] -> 
             RGBColor[
              0.42699263228672224`, 0.5418938445096457, 0.9490827029907487], 
             UndirectedEdge[26, 100] -> 
             RGBColor[
              0.2326661285681354, 0.3618772313826554, 0.9365613638720389], 
             UndirectedEdge[5, 97] -> 
             RGBColor[
              0.2506036098716818, 0.3807306615346847, 0.9375828768961504], 
             UndirectedEdge[20, 83] -> 
             RGBColor[
              0.22260788034518547`, 0.3513053747705641, 0.9359885615155867], 
             UndirectedEdge[21, 92] -> 
             RGBColor[
              0.5447186986215644, 0.48316840627514634`, 0.5874201581331991], 
             UndirectedEdge[77, 98] -> 
             RGBColor[
              0.35634509739122144`, 0.481789612382238, 0.9439738516723704], 
             UndirectedEdge[13, 84] -> 
             RGBColor[
              0.35509463721130535`, 0.4787160860263612, 0.9439670532361513], 
             UndirectedEdge[83, 97] -> 
             RGBColor[
              0.23740919468950228`, 0.36686249460397324`, 0.9368314744709133],
              UndirectedEdge[4, 24] -> 
             RGBColor[
              0.8731547109506095, 0.48514342442588576`, 0.2146138861787622], 
             UndirectedEdge[7, 85] -> 
             RGBColor[
              0.46422750147449665`, 0.5721227887280222, 0.9520139682890303], 
             UndirectedEdge[10, 40] -> 
             RGBColor[
              0.247557235138606, 0.37752872853890806`, 0.9374093903618093], 
             UndirectedEdge[26, 40] -> 
             RGBColor[
              0.23187934520351416`, 0.3610502721814919, 0.9365165577233654], 
             UndirectedEdge[56, 74] -> 
             RGBColor[
              0.3023635304863073, 0.4301296392181001, 0.9407137480474534], 
             UndirectedEdge[42, 62] -> 
             RGBColor[
              0.5111241958255703, 0.6114109159262558, 0.9554564660957278], 
             UndirectedEdge[4, 36] -> 
             RGBColor[
              0.5090645148420271, 0.3025589555589642, 0.5591602684070134], 
             UndirectedEdge[2, 33] -> 
             RGBColor[
              0.39248083985044224`, 0.5089006846712906, 0.946842453120579], 
             UndirectedEdge[36, 82] -> 
             RGBColor[
              0.5083994177593483, 0.2974467279340947, 0.5585233706895204], 
             UndirectedEdge[76, 81] -> 
             RGBColor[
              0.7674275617003685, 0.8140817945689018, 0.7914691728156671], 
             UndirectedEdge[27, 43] -> 
             RGBColor[
              0.29647101173303086`, 0.4258330666011419, 0.9403087252832609], 
             UndirectedEdge[61, 67] -> 
             RGBColor[
              0.1802334334437405, 0.3067671443820358, 0.933575399451926], 
             UndirectedEdge[10, 26] -> 
             RGBColor[
              0.235747888636603, 0.36511635660948866`, 0.9367368655488828], 
             UndirectedEdge[63, 83] -> 
             RGBColor[
              0.2214038953287198, 0.3500399101811996, 0.9359199963500353], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.28220392258022686`, 0.41350726570694146`, 0.9393984806790088],
              UndirectedEdge[20, 97] -> 
             RGBColor[
              0.23606571183465724`, 0.3654504089417983, 0.9367549651098346], 
             UndirectedEdge[28, 98] -> 
             RGBColor[
              0.27549253247929834`, 0.40689049724412685`, 0.9390002642187927],
              UndirectedEdge[4, 23] -> 
             RGBColor[
              0.9127800305317415, 0.6440501330906712, 0.5270177707094699], 
             UndirectedEdge[30, 86] -> 
             RGBColor[
              0.9059013056614938, 0.5668684370035848, 0.46183822670971686`], 
             UndirectedEdge[27, 54] -> 
             RGBColor[
              0.2966420896530224, 0.4260128803420197, 0.9403184679177174], 
             UndirectedEdge[1, 13] -> 
             RGBColor[
              0.2657389891679791, 0.3966389048135667, 0.9384448143562873], 
             UndirectedEdge[15, 35] -> 
             RGBColor[
              0.3092088271480132, 0.4416635027021466, 0.9409447046902427], 
             UndirectedEdge[56, 73] -> 
             RGBColor[
              0.24675175244976794`, 0.37668211516238714`, 0.9373635193142849],
              UndirectedEdge[16, 29] -> 
             RGBColor[
              0.27832737386526063`, 0.40880890872697706`, 0.9392005594800119],
              UndirectedEdge[53, 65] -> 
             RGBColor[
              0.2728961090815175, 0.40279156279961614`, 0.9389025615526072], 
             UndirectedEdge[6, 25] -> 
             RGBColor[
              0.2363155850258645, 0.36571304150863243`, 0.9367691950184196], 
             UndirectedEdge[68, 92] -> 
             RGBColor[
              0.501789161061527, 0.22361386772370176`, 0.5490682824488547], 
             UndirectedEdge[69, 97] -> 
             RGBColor[
              0.3373316861944994, 0.46125017803189694`, 0.9429113921953187], 
             UndirectedEdge[17, 77] -> 
             RGBColor[
              0.4030805157734533, 0.5235498161723404, 0.9469049119283475], 
             UndirectedEdge[46, 98] -> 
             RGBColor[
              0.2829961754137684, 0.41477730172669547`, 0.9394275855832659], 
             UndirectedEdge[29, 62] -> 
             RGBColor[
              0.34313416867820656`, 0.4716273033094493, 0.9430851836999117], 
             UndirectedEdge[17, 55] -> 
             RGBColor[
              0.3185371640353287, 0.44477145007049096`, 0.9417211396250476], 
             UndirectedEdge[2, 78] -> 
             RGBColor[
              0.7554647233160532, 0.8052075509695305, 0.8504886604600671], 
             UndirectedEdge[6, 35] -> 
             RGBColor[
              0.2796014780341359, 0.41120925954445625`, 0.9392342625895005], 
             UndirectedEdge[95, 99] -> 
             RGBColor[
              0.49451819041635453`, 0.5991553653170181, 0.9537240429577352], 
             UndirectedEdge[66, 99] -> 
             RGBColor[
              0.36282616535561596`, 0.48868352108289015`, 0.9443399403152473],
              UndirectedEdge[31, 39] -> 
             RGBColor[
              0.34736341039793694`, 0.47397514391497986`, 0.943402827404671], 
             UndirectedEdge[69, 71] -> 
             RGBColor[
              0.38724985209068863`, 0.5098380909626216, 0.9458961960369879], 
             UndirectedEdge[64, 89] -> 
             RGBColor[
              0.2647678240416204, 0.39561814869033823`, 0.9383895079390514], 
             UndirectedEdge[40, 53] -> 
             RGBColor[
              0.2836258239107592, 0.41406917338836174`, 0.9395136029389419], 
             UndirectedEdge[1, 27] -> 
             RGBColor[
              0.3002303093342801, 0.42978432673328937`, 0.9405228117202697], 
             UndirectedEdge[41, 48] -> 
             RGBColor[
              0.34329321321312134`, 0.4669781893550724, 0.9432705886491298], 
             UndirectedEdge[57, 70] -> 
             RGBColor[
              0.26485491336994227`, 0.39570968509618687`, 0.9383944675474621],
              UndirectedEdge[39, 44] -> 
             RGBColor[
              0.5365081779106845, 0.6268880178985887, 0.9593203806489492], 
             UndirectedEdge[6, 15] -> 
             RGBColor[
              0.286330742124025, 0.4176171847875644, 0.9396418315932203], 
             UndirectedEdge[6, 40] -> 
             RGBColor[
              0.2502060423578324, 0.3803127928703927, 0.9375602360143851], 
             UndirectedEdge[17, 59] -> 
             RGBColor[
              0.33165561016298184`, 0.45855976870817894`, 0.9424682157250155],
              UndirectedEdge[56, 91] -> 
             RGBColor[
              0.2478234584246726, 0.37780854609209535`, 0.9374245513841087], 
             UndirectedEdge[5, 59] -> 
             RGBColor[
              0.26264124075969747`, 0.39338297482786955`, 0.9382684021671439],
              UndirectedEdge[20, 58] -> 
             RGBColor[
              0.22266134542622565`, 0.3513615699606193, 0.9359916062728575], 
             UndirectedEdge[17, 19] -> 
             RGBColor[
              0.32753691967137427`, 0.45423076386143946`, 0.9422336623945751],
              UndirectedEdge[3, 38] -> 
             RGBColor[
              0.36574906065638857`, 0.4903403736840195, 0.9445582157865146], 
             UndirectedEdge[1, 17] -> 
             RGBColor[
              0.32323856928298944`, 0.4497129250720918, 0.941988877698796], 
             UndirectedEdge[2, 42] -> 
             RGBColor[
              0.5864694187639945, 0.6749492370446291, 0.9607331698161294], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.44521446884155214`, 0.5537197588039671, 0.950811098924118], 
             UndirectedEdge[48, 56] -> 
             RGBColor[
              0.2494153020184852, 0.3794816746379056, 0.9375152045218548], 
             UndirectedEdge[86, 94] -> 
             RGBColor[
              0.5871219393052882, 0.6494624455434448, 0.8460314485072336], 
             UndirectedEdge[23, 30] -> 
             RGBColor[
              0.9025589304514734, 0.5654862789591164, 0.5172300337295237], 
             UndirectedEdge[30, 82] -> 
             RGBColor[
              0.8279231426855904, 0.21563508744640228`, 0.17437253901138755`],
              UndirectedEdge[60, 74] -> 
             RGBColor[
              0.4164700206325886, 0.5346922301902434, 0.9478837701478531], 
             UndirectedEdge[10, 90] -> 
             RGBColor[
              0.2797642211015037, 0.41138031282676635`, 0.9392435305664304], 
             UndirectedEdge[49, 69] -> 
             RGBColor[
              0.5984246385417968, 0.6820634596988412, 0.9631196279753649], 
             UndirectedEdge[25, 100] -> 
             RGBColor[
              0.23058501773817044`, 0.3596898519503145, 0.9364428476890001], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.23295897687627548`, 0.36218503352216574`, 0.9365780411499574],
              UndirectedEdge[31, 51] -> 
             RGBColor[
              0.33046646407782415`, 0.4562153820042676, 0.9424405713085325], 
             UndirectedEdge[37, 50] -> 
             RGBColor[
              0.8586518765861698, 0.8882652786926387, 0.8831610133197494], 
             UndirectedEdge[6, 10] -> 
             RGBColor[
              0.25407458579092124`, 0.3843788772983895, 0.9377805438399023], 
             UndirectedEdge[69, 77] -> 
             RGBColor[
              0.4207942226929865, 0.5388925387892431, 0.9480336136696441], 
             UndirectedEdge[12, 96] -> 
             RGBColor[
              0.4452662078752948, 0.5537741398088749, 0.9508140453855485], 
             UndirectedEdge[12, 41] -> 
             RGBColor[
              0.5175163922375255, 0.6185385423481014, 0.9553377624650727], 
             UndirectedEdge[89, 93] -> 
             RGBColor[
              0.25239151088821565`, 0.3826098588625336, 0.9376846952140795], 
             UndirectedEdge[37, 81] -> 
             RGBColor[
              0.6332310398688609, 0.7118439589227601, 0.9651449338235201], 
             UndirectedEdge[14, 24] -> 
             RGBColor[
              0.8132324483478965, 0.7256778621369495, 0.6085269751651416], 
             UndirectedEdge[52, 67] -> 
             RGBColor[
              0.560139632974118, 0.5514847252323705, 0.6016081426491302], 
             UndirectedEdge[23, 27] -> 
             RGBColor[
              0.6645515668442425, 0.7298696411778459, 0.9061368692979717], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.2386756834212212, 0.36819365456103337`, 0.9369035991305825], 
             UndirectedEdge[23, 81] -> 
             RGBColor[
              0.7636299537302207, 0.8133189149453938, 0.9131041886415987], 
             UndirectedEdge[88, 96] -> 
             RGBColor[
              0.2871462971513761, 0.419139342805837, 0.9396639288766677], 
             UndirectedEdge[77, 95] -> 
             RGBColor[
              0.5017218742687843, 0.6053948342023149, 0.9541830553228445], 
             UndirectedEdge[74, 91] -> 
             RGBColor[
              0.3083282736041498, 0.43639896242150933`, 0.941053431343968], 
             UndirectedEdge[7, 100] -> 
             RGBColor[
              0.27936916838135406`, 0.4105277593101289, 0.939237045621026], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.3593964815136068, 0.4839037453450634, 0.9441876459561919], 
             UndirectedEdge[6, 100] -> 
             RGBColor[
              0.2509928257224536, 0.38113975207155615`, 0.9376050421630586], 
             UndirectedEdge[19, 55] -> 
             RGBColor[
              0.2577051513357447, 0.38819483187714965`, 0.9379872991767397], 
             UndirectedEdge[17, 28] -> 
             RGBColor[
              0.3222279508615301, 0.4486507010342292, 0.9419313244747699], 
             UndirectedEdge[64, 96] -> 
             RGBColor[
              0.28506242993789815`, 0.4169490662396592, 0.9395452557216655], 
             UndirectedEdge[67, 68] -> 
             RGBColor[
              0.49942943344374047`, 0.22113364438203578`, 0.5489338994519259],
              UndirectedEdge[22, 87] -> 
             RGBColor[
              0.875317687150646, 0.9030022552400158, 0.9648194594818615], 
             UndirectedEdge[42, 44] -> 
             RGBColor[
              0.7173501625148713, 0.7791186661105619, 0.9724624182472246], 
             UndirectedEdge[70, 96] -> 
             RGBColor[
              0.28071617400293775`, 0.4123808756834735, 0.9392977428758789], 
             UndirectedEdge[64, 88] -> 
             RGBColor[
              0.2870945581176334, 0.41908496180092925`, 0.9396609824152371], 
             UndirectedEdge[26, 65] -> 
             RGBColor[
              0.2211496303742725, 0.34977266159274634`, 0.9359055163370308], 
             UndirectedEdge[2, 14] -> 
             RGBColor[
              0.6178499772431384, 0.6994639678296142, 0.9638608906173386], 
             UndirectedEdge[11, 72] -> 
             RGBColor[
              0.5328227707106528, 0.3030976591006391, 0.5571968893226393], 
             UndirectedEdge[67, 86] -> 
             RGBColor[
              0.5874876692612337, 0.649846850915762, 0.8460522762871756], 
             UndirectedEdge[40, 90] -> 
             RGBColor[
              0.27589567766841483`, 0.4073142283987696, 0.939023222740913], 
             UndirectedEdge[27, 84] -> 
             RGBColor[
              0.38958595737760626`, 0.5118615079460839, 0.9460450506001336], 
             UndirectedEdge[13, 43] -> 
             RGBColor[
              0.26197969156672996`, 0.39268764468141926`, 0.9382307279192786],
              UndirectedEdge[52, 72] -> 
             RGBColor[
              0.8850921765904433, 0.518767217550283, 0.2236557580064148], 
             UndirectedEdge[10, 53] -> 
             RGBColor[
              0.28749436734384803`, 0.4181352578163585, 0.9397339107644591], 
             UndirectedEdge[15, 40] -> 
             RGBColor[
              0.2798133914717097, 0.41076703602808307`, 0.9392706781151272], 
             UndirectedEdge[21, 68] -> 
             RGBColor[
              0.8602485375600374, 0.3936815385514446, 0.2025698756843444], 
             UndirectedEdge[28, 83] -> 
             RGBColor[
              0.24001916627606623`, 0.36960574022320836`, 0.9369801084916611],
              UndirectedEdge[54, 100] -> 
             RGBColor[
              0.24809701263363243`, 0.37809606891005076`, 0.9374401298916217],
              UndirectedEdge[47, 96] -> 
             RGBColor[
              0.280167857490329, 0.4118045602634469, 0.9392665170616474], 
             UndirectedEdge[47, 51] -> 
             RGBColor[
              0.26797369092262097`, 0.39898771804597, 0.9385720773152693], 
             UndirectedEdge[15, 62] -> 
             RGBColor[
              0.3409913926021096, 0.4697713383713912, 0.9429486479031253], 
             UndirectedEdge[39, 45] -> 
             RGBColor[
              0.5390587638079978, 0.6288805549867408, 0.959574599214613], 
             UndirectedEdge[58, 97] -> 
             RGBColor[
              0.23746265977054243`, 0.3669186897940284, 0.936834519228184], 
             UndirectedEdge[31, 45] -> 
             RGBColor[
              0.5919024457294845, 0.6759664122706829, 0.9628935917366674], 
             UndirectedEdge[6, 26] -> 
             RGBColor[
              0.23839669585582945`, 0.3679004209409733, 0.9368877112014585], 
             UndirectedEdge[41, 91] -> 
             RGBColor[
              0.34170136961930875`, 0.46530506080926215`, 0.9431799355113838],
              UndirectedEdge[8, 22] -> 
             RGBColor[
              0.9622103495532457, 0.9713371210884598, 0.9488522004737234], 
             UndirectedEdge[46, 95] -> 
             RGBColor[
              0.42837295229133143`, 0.5383825235467723, 0.9496367892337401], 
             UndirectedEdge[66, 95] -> 
             RGBColor[
              0.4539596243008821, 0.5640255738806018, 0.9511396869893891], 
             UndirectedEdge[23, 37] -> 
             RGBColor[
              0.8563518073535856, 0.887314140955882, 0.9212791128920343], 
             UndirectedEdge[10, 100] -> 
             RGBColor[
              0.2483440185032272, 0.37835568774007156`, 0.9374541965104828], 
             UndirectedEdge[5, 79] -> 
             RGBColor[
              0.24661518324008325`, 0.37653857226402054`, 0.9373557418998293],
              UndirectedEdge[38, 42] -> 
             RGBColor[
              0.5442088329750422, 0.6400671657429147, 0.9575645899192962], 
             UndirectedEdge[40, 54] -> 
             RGBColor[
              0.24731022926901122`, 0.37726910970888733`, 0.9373953237429482],
              UndirectedEdge[32, 45] -> 
             RGBColor[
              0.5380655132877746, 0.6278365857142659, 0.9595180350668688], 
             UndirectedEdge[41, 60] -> 
             RGBColor[
              0.44984311664774745`, 0.5635983285779962, 0.9500102743152689], 
             UndirectedEdge[88, 91] -> 
             RGBColor[
              0.2714833134368132, 0.40267655383130574`, 0.9387719451254313], 
             UndirectedEdge[47, 57] -> 
             RGBColor[
              0.2643065968573336, 0.3951333696761603, 0.9383632417332306], 
             UndirectedEdge[27, 85] -> 
             RGBColor[
              0.4786656685472922, 0.5846284033631004, 0.952933955527739], 
             UndirectedEdge[69, 95] -> 
             RGBColor[
              0.5047239977858227, 0.6079951227016581, 0.9543743479786766], 
             UndirectedEdge[36, 72] -> 
             RGBColor[
              0.5053823219778242, 0.27425600765749925`, 0.5556341963618108], 
             UndirectedEdge[6, 65] -> 
             RGBColor[
              0.23947632752859074`, 0.3690351822816471, 0.9369491946280504], 
             UndirectedEdge[49, 77] -> 
             RGBColor[
              0.5954225150247585, 0.679463171199498, 0.9629283353195328], 
             UndirectedEdge[2, 62] -> 
             RGBColor[
              0.441389916904741, 0.555009569915901, 0.9498217258326898], 
             UndirectedEdge[22, 66] -> 
             RGBColor[
              0.6418930093726982, 0.712187405219036, 0.9458895209538087], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.37246108295649283`, 0.49696932160080975`, 0.9449560466299856],
              UndirectedEdge[73, 88] -> 
             RGBColor[
              0.2704116074619085, 0.40155012290159753`, 0.9387109130556073], 
             UndirectedEdge[8, 21] -> 
             RGBColor[
              0.9330401773606567, 0.8125446192441054, 0.5943013473777097], 
             UndirectedEdge[31, 75] -> 
             RGBColor[
              0.3329280335215753, 0.45880264756216715`, 0.9425807540467885], 
             UndirectedEdge[4, 30] -> 
             RGBColor[
              0.8285882397682693, 0.2207473150712718, 0.17500943672888053`], 
             UndirectedEdge[48, 91] -> 
             RGBColor[
              0.2553800451363277, 0.3857509978413148, 0.9378548878183692], 
             UndirectedEdge[19, 28] -> 
             RGBColor[
              0.26139593816194606`, 0.39207408284088785`, 0.938197484026462], 
             UndirectedEdge[28, 66] -> 
             RGBColor[
              0.28917728429612277`, 0.42002387483007575`, 0.9398253652267791],
              UndirectedEdge[3, 29] -> 
             RGBColor[
              0.30975389821880644`, 0.4418401783792823, 0.9409902535505699], 
             UndirectedEdge[22, 82] -> 
             RGBColor[
              0.8994987825942162, 0.6299538973723429, 0.5667734179172785], 
             UndirectedEdge[49, 82] -> 
             RGBColor[
              0.8052660382783743, 0.5558604030310919, 0.5807688639495472], 
             UndirectedEdge[23, 84] -> 
             RGBColor[
              0.7117851117483094, 0.7707809637467538, 0.909146549012275], 
             UndirectedEdge[65, 100] -> 
             RGBColor[
              0.2337457602408967, 0.3630119927233292, 0.9366228472986309], 
             UndirectedEdge[53, 85] -> 
             RGBColor[
              0.46927094036852307`, 0.5764911620074185, 0.9523353317556198], 
             UndirectedEdge[59, 97] -> 
             RGBColor[
              0.26290465706698973`, 0.3936598420683923, 0.9382834033361547], 
             UndirectedEdge[17, 98] -> 
             RGBColor[
              0.34163351398872654`, 0.46904717826467845`, 0.9430364425869058],
              UndirectedEdge[61, 68] -> 
             RGBColor[0.49812300000000004`, 0.2197605, 0.5488595000000001], 
             UndirectedEdge[28, 55] -> 
             RGBColor[
              0.2523961825259005, 0.38261476904993935`, 0.9376849612569346], 
             UndirectedEdge[9, 36] -> 
             RGBColor[
              0.5653509190664274, 0.575380095696193, 0.6066312511494145], 
             UndirectedEdge[20, 59] -> 
             RGBColor[
              0.24810334272267293`, 0.37810272223498315`, 0.9374404903808281],
              UndirectedEdge[48, 57] -> 
             RGBColor[
              0.25518176821789507`, 0.38554259622855935`, 0.9378435962411888],
              UndirectedEdge[1, 46] -> 
             RGBColor[
              0.26460123070803143`, 0.39544304853410883`, 0.9383800206951561],
              UndirectedEdge[5, 66] -> 
             RGBColor[
              0.2863038964022665, 0.41700376197031797`, 0.9396617300370205], 
             UndirectedEdge[64, 74] -> 
             RGBColor[
              0.32393951828497003`, 0.45280737039113284`, 0.9419424686337738],
              UndirectedEdge[55, 79] -> 
             RGBColor[
              0.24579778430773802`, 0.37567943416004, 0.9373091922398655], 
             UndirectedEdge[32, 51] -> 
             RGBColor[
              0.27662953163611426`, 0.40808555544785063`, 0.9390650146387339],
              UndirectedEdge[64, 73] -> 
             RGBColor[
              0.26832774024843065`, 0.39935984633541977`, 0.938592239900605], 
             UndirectedEdge[35, 38] -> 
             RGBColor[
              0.3673467656616922, 0.49201966294494187`, 0.9446492027229738], 
             UndirectedEdge[71, 87] -> 
             RGBColor[
              0.5699101563836958, 0.656683392162545, 0.9615914735757531], 
             UndirectedEdge[82, 87] -> 
             RGBColor[
              0.8132980502396094, 0.5621350718207605, 0.5815694198384238], 
             UndirectedEdge[5, 77] -> 
             RGBColor[
              0.33406614637016885`, 0.458373022292031, 0.9427050983704759], 
             UndirectedEdge[57, 64] -> 
             RGBColor[
              0.2692011693049027, 0.4002778756523726, 0.9386419803932486], 
             UndirectedEdge[63, 97] -> 
             RGBColor[
              0.23486172681819156`, 0.36418494435243376`, 0.9366863999442832],
              UndirectedEdge[41, 93] -> 
             RGBColor[
              0.34493630114672413`, 0.468705178951081, 0.9433641600762177], 
             UndirectedEdge[9, 61] -> 
             RGBColor[
              0.565154574148669, 0.575173724738642, 0.6066200695968145], 
             UndirectedEdge[17, 46] -> 
             RGBColor[
              0.32973159379600026`, 0.45653750551679784`, 0.942358645839243], 
             UndirectedEdge[25, 54] -> 
             RGBColor[
              0.2334197719370433, 0.36266935834712705`, 0.9366042827469828], 
             UndirectedEdge[59, 77] -> 
             RGBColor[
              0.3463671935654768, 0.47130220282573854`, 0.9434056248104801], 
             UndirectedEdge[66, 77] -> 
             RGBColor[
              0.3700298492080458, 0.49492298996818684`, 0.9447989526803566], 
             UndirectedEdge[7, 27] -> 
             RGBColor[
              0.327914245400744, 0.45844457074209777`, 0.9421153836471216], 
             UndirectedEdge[61, 92] -> 
             RGBColor[
              0.182593161061527, 0.30924736772370176`, 0.9337097824488547], 
             UndirectedEdge[77, 87] -> 
             RGBColor[
              0.6034545269859937, 0.6857378399891666, 0.9637288912084094], 
             UndirectedEdge[28, 79] -> 
             RGBColor[
              0.24948857113393946`, 0.3795586851237783, 0.937519377089588], 
             UndirectedEdge[5, 28] -> 
             RGBColor[
              0.25321358145824574`, 0.3834739071539198, 0.9377315109168982], 
             UndirectedEdge[56, 88] -> 
             RGBColor[
              0.26551857031897064`, 0.39640723062789657`, 0.9384322618289168],
              UndirectedEdge[25, 26] -> 
             RGBColor[
              0.21798888787154624`, 0.3464505208197316, 0.9357255167274], 
             UndirectedEdge[9, 67] -> 
             RGBColor[
              0.5664610075924095, 0.5765468691206779, 0.6066944690487404], 
             UndirectedEdge[32, 44] -> 
             RGBColor[
              0.5355149273904612, 0.6258440486261139, 0.959263816501205], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.5412488824777958, 0.4795214095089955, 0.5872225572369445], 
             UndirectedEdge[79, 83] -> 
             RGBColor[
              0.23342076805790374`, 0.3626704053333091, 0.9366043394745922], 
             UndirectedEdge[60, 93] -> 
             RGBColor[
              0.3651648800983693, 0.48577125520605746`, 0.9447787980493423], 
             UndirectedEdge[5, 63] -> 
             RGBColor[
              0.2345983105108993, 0.3639080771119111, 0.9366713987752724], 
             UndirectedEdge[19, 66] -> 
             RGBColor[
              0.2944862531059669, 0.425603937657286, 0.9401277031465842], 
             UndirectedEdge[8, 86] -> 
             RGBColor[
              0.9781688756181125, 0.981703287226387, 0.853067848528615], 
             UndirectedEdge[4, 37] -> 
             RGBColor[
              0.7823811166703816, 0.5425751770680375, 0.5790585158913912], 
             UndirectedEdge[9, 92] -> 
             RGBColor[
              0.5688207352101959, 0.5790270924623439, 0.606828852045669], 
             UndirectedEdge[3, 42] -> 
             RGBColor[
              0.4777439253661703, 0.5816237909960889, 0.9533615359463858], 
             UndirectedEdge[7, 90] -> 
             RGBColor[
              0.31078937097963055`, 0.4435523843968237, 0.9410263796769736], 
             UndirectedEdge[35, 62] -> 
             RGBColor[
              0.3342621285122205, 0.46336341312828305`, 0.9425410788994055], 
             UndirectedEdge[20, 79] -> 
             RGBColor[
              0.2320772852030587, 0.3612583196711341, 0.9365278301135136], 
             UndirectedEdge[31, 78] -> 
             RGBColor[
              0.6972006995541824, 0.7564641060518543, 0.846300355646884], 
             UndirectedEdge[13, 81] -> 
             RGBColor[
              0.40693947919321677`, 0.5212540372250012, 0.947924692865475], 
             UndirectedEdge[18, 80] -> 
             RGBColor[
              0.2419836729170215, 0.3716705612597674, 0.9370919842386365], 
             UndirectedEdge[90, 100] -> 
             RGBColor[
              0.27668246103303606`, 0.408141187599933, 0.9390680288895865], 
             UndirectedEdge[67, 92] -> 
             RGBColor[
              0.1838995945052675, 0.31062051210573755`, 0.9337841819007806], 
             UndirectedEdge[55, 66] -> 
             RGBColor[
              0.28548649746992133`, 0.41614462386633744`, 0.9396151803770567],
              UndirectedEdge[89, 91] -> 
             RGBColor[
              0.24915657936080024`, 0.3792097407207148, 0.9375004706492456], 
             UndirectedEdge[46, 55] -> 
             RGBColor[
              0.25989982546037066`, 0.390501573532508, 0.9381122826214077], 
             UndirectedEdge[41, 64] -> 
             RGBColor[
              0.3573126143001289, 0.48171346877888566`, 0.9440689728011896], 
             UndirectedEdge[28, 46] -> 
             RGBColor[
              0.2635906122865721, 0.39438082449624623`, 0.93832246747113], 
             UndirectedEdge[35, 53] -> 
             RGBColor[
              0.3130212595870627, 0.4449656400624253, 0.9411876295140573], 
             UndirectedEdge[35, 90] -> 
             RGBColor[
              0.3052911133447183, 0.4382106950728331, 0.9406972493160285], 
             UndirectedEdge[5, 58] -> 
             RGBColor[
              0.23719924346325016`, 0.36664182255350575`, 0.9368195180591732],
              UndirectedEdge[76, 85] -> 
             RGBColor[
              0.8046624308881429, 0.8443107387872784, 0.7944004381139487], 
             UndirectedEdge[34, 77] -> 
             RGBColor[
              0.5013559504056586, 0.6050977607255472, 0.9541542484559159], 
             UndirectedEdge[49, 71] -> 
             RGBColor[
              0.5618781444224608, 0.6504087233728764, 0.9607909176868766]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 25 -> 
             RGBColor[
              0.21590777704158132`, 0.3442631413873908, 0.9356070005443611], 
             55 -> RGBColor[
              0.2487053956996991, 0.3787355180862011, 0.9374747764072122], 90 -> 
             RGBColor[
              0.30810266363131256`, 0.4411658126866278, 0.9408573629455341], 
             27 -> RGBColor[
              0.3423524124735395, 0.470950185377176, 0.9430353708858302], 15 -> 
             RGBColor[
              0.3159380912379023, 0.44807142794525473`, 0.9413522736939626], 
             98 -> RGBColor[
              0.2948980956064947, 0.4272869744745761, 0.9401053823309286], 38 -> 
             RGBColor[
              0.43221396826526043`, 0.5487837484308453, 0.9487612697594249], 
             99 -> RGBColor[
              0.40338473147108844`, 0.5238133125193064, 0.9469242962835934], 
             71 -> RGBColor[
              0.3507033579713525, 0.4781833546366567, 0.9435674857484997], 41 -> 
             RGBColor[
              0.4296145376961023, 0.5465322523230198, 0.9485956363421444], 75 -> 
             RGBColor[
              0.26564897472372695`, 0.3965442939254123, 0.9384396881668516], 
             64 -> RGBColor[
              0.2850106909041555, 0.4168946852347515, 0.9395423092602349], 63 -> 
             RGBColor[
              0.21885642745740908`, 0.34736235992966014`, 0.9357749218234052],
              85 -> RGBColor[
              0.6149789246210449, 0.6983066213490248, 0.9628325401696478], 3 -> 
             RGBColor[
              0.29928415304751665`, 0.4318969989371937, 0.9403551618136042], 
             86 -> RGBColor[
              0.9934354716349865, 0.9915534130674525, 0.7584547536704994], 94 -> 
             RGBColor[
              0.18080840697558995`, 0.30737147801943704`, 0.9336081433439677],
              61 -> RGBColor[0.178927, 0.305394, 0.933501], 84 -> 
             RGBColor[
              0.4368195022816731, 0.5527728305149917, 0.9490547303144369], 76 -> 
             RGBColor[
              0.9943459371552411, 0.990314856225532, 0.6259683360582495], 21 -> 
             RGBColor[
              0.9031780751200748, 0.6532360771028892, 0.2409217513686888], 87 -> 
             RGBColor[
              0.789116954796039, 0.8351834296884333, 0.9796154614030067], 95 -> 
             RGBColor[
              0.5856516493616206, 0.6744974181147299, 0.9605237896318769], 72 -> 
             RGBColor[
              0.8314449541201315, 0.24270527339989661`, 0.17774502961842129`],
              42 -> RGBColor[
              0.6562036976848239, 0.731350583054984, 0.9663679100791674], 66 -> 
             RGBColor[
              0.32226759924014353`, 0.45355372964647384`, 0.9417555843469012],
              1 -> RGBColor[
              0.2581082061950206, 0.38861846808940276`, 0.9380102525547092], 
             24 -> RGBColor[
              0.9075000820526815, 0.6709756796489449, 0.2444305986486977], 54 -> 
             RGBColor[
              0.2509317668325053, 0.3810755753068633, 0.9376015649496046], 4 -> 
             RGBColor[
              0.8388093398485373, 0.29931116920282663`, 0.1847971737088267], 
             7 -> RGBColor[
              0.3134760783279485, 0.4459389561070196, 0.9411953964084129], 
             100 -> RGBColor[
              0.24526225843475957`, 0.3751165625132382, 0.937278694833639], 
             12 -> RGBColor[
              0.6054182467789488, 0.6905448323731828, 0.9620798885880011], 65 -> 
             RGBColor[
              0.2222292620470338, 0.35090742293342014`, 0.9359669997636226], 
             8 -> RGBColor[
              0.9629022796012385, 0.9718531613853215, 0.9476809433867306], 57 -> 
             RGBColor[
              0.25339164770564987`, 0.38366106606999373`, 0.9377416515262625],
              74 -> RGBColor[
              0.3628683456657846, 0.48872005554751413`, 0.9443426280073127], 
             37 -> RGBColor[
              0.7259528934922258, 0.7858391849332483, 0.9733198580739556], 43 -> 
             RGBColor[
              0.25058961099252225`, 0.3807159478251078, 0.9375820796806917], 
             39 -> RGBColor[
              0.2945197284764503, 0.42688928663103776`, 0.9400838348826166], 
             58 -> RGBColor[
              0.22405829336211083`, 0.3528298508128494, 0.9360711603912069], 
             11 -> RGBColor[
              0.23420058730117388`, 0.3634900448013817, 0.9366487490268572], 
             51 -> RGBColor[
              0.26072583583622466`, 0.3913697628096132, 0.9381593226903397], 
             48 -> RGBColor[
              0.2569718887301403, 0.38742412638712503`, 0.9379455409561153], 
             20 -> RGBColor[
              0.22126439749034046`, 0.3498932891083892, 0.9359120521545081], 
             33 -> 
             RGBColor[
              0.26822653985771944`, 0.399253478308307, 0.9385864766880666], 
             45 -> RGBColor[
              0.7835977991395453, 0.8308718233424438, 0.9790653635466094], 23 -> 
             RGBColor[
              0.9867507212149456, 0.9887890969785158, 0.869238367710113], 22 -> 
             RGBColor[
              0.9615184195052529, 0.9708210807915982, 0.9500234575607163], 2 -> 
             RGBColor[
              0.5167351398431651, 0.6185478910342742, 0.9550984295530915], 60 -> 
             RGBColor[
              0.4700716955993926, 0.5806644048329727, 0.9514249122883933], 16 -> 
             RGBColor[
              0.23643110434042502`, 0.36583445963258315`, 0.9367757736724883],
              79 -> RGBColor[
              0.24289017291577697`, 0.372623350233879, 0.937143608072519], 89 -> 
             RGBColor[
              0.24452495717908534`, 0.374341612145925, 0.9372367066178678], 
             36 -> RGBColor[
              0.17931968983551683`, 0.3058067419151018, 0.9335233631052001], 
             52 -> RGBColor[
              0.938739399060755, 0.7948291617006693, 0.26956648639440833`], 
             32 -> RGBColor[
              0.2925332274360039, 0.424801348086088, 0.9399707065871281], 31 -> 
             RGBColor[
              0.40020709231942364`, 0.521061001198922, 0.9467218199267253], 
             68 -> RGBColor[0.817319, 0.134127, 0.164218], 73 -> 
             RGBColor[
              0.2516447895927058, 0.3818250074360881, 0.9376421705409753], 82 -> 
             RGBColor[
              0.8374791456831797, 0.2890867139530876, 0.18352337827384074`], 
             35 -> RGBColor[
              0.30247956305812407`, 0.4352555774590384, 0.9405371356865229], 
             88 -> RGBColor[
              0.28917842533111127`, 0.421275238367107, 0.9397796555702393], 
             50 -> RGBColor[
              0.9913508596801138, 0.9906913724520291, 0.7930021685655431], 19 -> 
             RGBColor[
              0.2667049069717902, 0.39765414566809815`, 0.9384998219462671], 
             17 -> RGBColor[
              0.3883689323709583, 0.5108073820547808, 0.9459675028428829], 96 -> 
             RGBColor[
              0.2851141689716408, 0.417003447244567, 0.939548202183096], 14 -> 
             RGBColor[
              0.7189648146431117, 0.780380044624954, 0.9726233516815856], 5 -> 
             RGBColor[
              0.2503401935643895, 0.38045379429416204`, 0.9375678757271396], 
             34 -> RGBColor[
              0.5849198016353689, 0.6739032711611944, 0.9604661758980197], 97 -> 
             RGBColor[
              0.25086702617897405`, 0.38100752877520744`, 0.9375978780651611],
              93 -> RGBColor[
              0.26025806459734596`, 0.3908781055791422, 0.9381326838102911], 
             81 -> RGBColor[
              0.5405091862454959, 0.6378487329122717, 0.9569700095730845], 69 -> 
             RGBColor[
              0.42379634621002477`, 0.5414928272885864, 0.9482249063254762], 
             9 -> RGBColor[
              0.9513821482973379, 0.8449534494772841, 0.27973913919362886`], 
             13 -> RGBColor[
              0.2733697721409376, 0.40465934153773064`, 0.9388793761578655], 
             30 -> RGBColor[
              0.8183671396880012, 0.14218346093971695`, 0.1652216997489344], 
             59 -> RGBColor[
              0.2749422879550054, 0.4063121553615771, 0.9389689286071481], 28 -> 
             RGBColor[
              0.25608696935210196`, 0.3864940200136776, 0.9378951461066569], 
             80 -> RGBColor[
              0.26918119100492044`, 0.4002568771923939, 0.9386408426586199], 
             47 -> RGBColor[
              0.27522154600901727`, 0.40660567328232683`, 0.9389848319401988],
              62 -> RGBColor[
              0.3660446939663169, 0.4914712487975277, 0.9445450221122881], 77 -> 
             RGBColor[
              0.4177920991759482, 0.5362922502898999, 0.947842321013812], 78 -> 
             RGBColor[
              0.9941943067889412, 0.9918672109047867, 0.7458788913670427], 40 -> 
             RGBColor[
              0.24368869170551716`, 0.37346264411091135`, 0.937189082536292], 
             67 -> RGBColor[
              0.181539866887481, 0.30814028876407157`, 0.9336497989038519], 
             56 -> RGBColor[
              0.24185871530683006`, 0.3715392228886861, 0.9370848680875943], 
             10 -> RGBColor[
              0.25142577857169485`, 0.38159481296690484`, 0.9376296981873266],
              53 -> RGBColor[
              0.3235629561160013, 0.45467570266581214`, 0.9418381233415918], 
             26 -> RGBColor[
              0.2200699987015112, 0.3486379002520725, 0.9358440329104389], 18 -> 
             RGBColor[
              0.21478615482912253`, 0.34308424532714094`, 0.935543125818653], 
             29 -> RGBColor[
              0.32022364339009624`, 0.4517833578213709, 0.9416253452875354], 
             92 -> RGBColor[
              0.18625932212305402`, 0.3131007354474035, 0.9339185648977094], 
             46 -> RGBColor[
              0.2710942552210422, 0.40226762897881485`, 0.9387497888356031], 
             49 -> 
             RGBColor[
              0.773052930873569, 0.822634092109096, 0.9780143496252536], 83 -> 
             RGBColor[
              0.2239513632000305, 0.3527174604327391, 0.9360650708766655], 70 -> 
             RGBColor[
              0.27631817903423467`, 0.40775830412238, 0.9390472835686617], 44 -> 
             RGBColor[
              0.7784966273449186, 0.8268867491661398, 0.9785569264152818], 91 -> 
             RGBColor[
              0.25378820154251513`, 0.3840778692955045, 0.9377642346806232], 
             6 -> RGBColor[
              0.2567233930101477, 0.3871629416298741, 
               0.9379313894924781]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9lHs01Akbx4dhXCZmRjNjDGZ+vxEpY003Oez6fWm7uFSIpJWyrGvrtqF9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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 13}], {
             RGBColor[
             0.2657389891679791, 0.3966389048135667, 0.9384448143562873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 17}], {
             RGBColor[
             0.32323856928298944`, 0.4497129250720918, 0.941988877698796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 19}], {
             RGBColor[
             0.2624065565834054, 0.39313630687875045`, 0.9382550372504881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 27}], {
             RGBColor[
             0.3002303093342801, 0.42978432673328937`, 0.9405228117202697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 43}], {
             RGBColor[
             0.25434890859377146`, 0.3846672079572553, 0.9377961661177004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 46}], {
             RGBColor[
             0.26460123070803143`, 0.39544304853410883`, 0.9383800206951561]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 55}], {
             RGBColor[
             0.25340680094735984`, 0.3836769930878019, 0.9377425144809607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 3}], {
             RGBColor[
             0.4080096464453409, 0.5252224449857339, 0.947726795683348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 14}], {
             RGBColor[
             0.6178499772431384, 0.6994639678296142, 0.9638608906173386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 29}], {
             RGBColor[
             0.41847939161663067`, 0.5351656244278226, 0.9483618874203135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 33}], {
             RGBColor[
             0.39248083985044224`, 0.5089006846712906, 0.946842453120579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 38}], {
             RGBColor[
             0.4744745540542128, 0.5836658197325597, 0.9519298496562583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 42}], {
             RGBColor[
             0.5864694187639945, 0.6749492370446291, 0.9607331698161294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 44}], {
             RGBColor[
             0.6476158835940419, 0.7227173201002071, 0.9668276779841867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 62}], {
             RGBColor[
             0.441389916904741, 0.555009569915901, 0.9498217258326898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 78}], {
             RGBColor[
             0.7554647233160532, 0.8052075509695305, 0.8504886604600671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 16}], {
             RGBColor[
             0.26785762869397084`, 0.3988657292848884, 0.9385654677430463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 29}], {
             RGBColor[
             0.30975389821880644`, 0.4418401783792823, 0.9409902535505699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 33}], {
             RGBColor[
             0.283755346452618, 0.41557523862275036`, 0.9394708192508354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 38}], {
             RGBColor[
             0.36574906065638857`, 0.4903403736840195, 0.9445582157865146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 42}], {
             RGBColor[
             0.4777439253661703, 0.5816237909960889, 0.9533615359463858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 62}], {
             RGBColor[
             0.3326644235069168, 0.4616841238673607, 0.9424500919629462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 9}], {
             RGBColor[
             0.8950957440729377, 0.5721323093400554, 0.23226815645122778`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 23}], {
             RGBColor[
             0.9127800305317415, 0.6440501330906712, 0.5270177707094699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 24}], {
             RGBColor[
             0.8731547109506095, 0.48514342442588576`, 0.2146138861787622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 30}], {
             RGBColor[
             0.8285882397682693, 0.2207473150712718, 0.17500943672888053`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 36}], {
             RGBColor[
             0.5090645148420271, 0.3025589555589642, 0.5591602684070134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 37}], {
             RGBColor[
             0.7823811166703816, 0.5425751770680375, 0.5790585158913912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 50}], {
             RGBColor[
             0.9150800997643256, 0.6450012708274279, 0.48889967113718485`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 76}], {
             RGBColor[
             0.9165776385018892, 0.6448130127141793, 0.40538275488353814`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 86}], {
             RGBColor[
             0.9161224057417618, 0.6454322911351396, 0.4716259636896631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 94}], {
             RGBColor[
             0.5098088734120636, 0.30334132361113186`, 0.5592026585263972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 20}], {
             RGBColor[
             0.23580229552736498`, 0.3651735417012756, 0.9367399639408238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 28}], {
             RGBColor[
             0.25321358145824574`, 0.3834739071539198, 0.9377315109168982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 58}], {
             RGBColor[
             0.23719924346325016`, 0.36664182255350575`, 0.9368195180591732]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 59}], {
             RGBColor[
             0.26264124075969747`, 0.39338297482786955`, 0.9382684021671439]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 63}], {
             RGBColor[
             0.2345983105108993, 0.3639080771119111, 0.9366713987752724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 66}], {
             RGBColor[
             0.2863038964022665, 0.41700376197031797`, 0.9396617300370205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 69}], {
             RGBColor[
             0.3370682698872072, 0.4609733107913742, 0.942896391026308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[
             0.33406614637016885`, 0.458373022292031, 0.9427050983704759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 79}], {
             RGBColor[
             0.24661518324008325`, 0.37653857226402054`, 0.9373557418998293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 83}], {
             RGBColor[
             0.23714577838221002`, 0.3665856273634506, 0.9368164733019025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 97}], {
             RGBColor[
             0.2506036098716818, 0.3807306615346847, 0.9375828768961504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 7}], {
             RGBColor[
             0.2850997356690481, 0.41655094886844685`, 0.9395633929504454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 10}], {
             RGBColor[
             0.25407458579092124`, 0.3843788772983895, 0.9377805438399023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 15}], {
             RGBColor[
             0.286330742124025, 0.4176171847875644, 0.9396418315932203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 25}], {
             RGBColor[
             0.2363155850258645, 0.36571304150863243`, 0.9367691950184196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 26}], {
             RGBColor[
             0.23839669585582945`, 0.3679004209409733, 0.9368877112014585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 35}], {
             RGBColor[
             0.2796014780341359, 0.41120925954445625`, 0.9392342625895005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 40}], {
             RGBColor[
             0.2502060423578324, 0.3803127928703927, 0.9375602360143851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 53}], {
             RGBColor[
             0.2901431745630745, 0.4209193221478431, 0.939884756417035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 65}], {
             RGBColor[
             0.23947632752859074`, 0.3690351822816471, 0.9369491946280504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 90}], {
             RGBColor[
             0.2824130283207301, 0.41416437715825094`, 0.9393943762190061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 100}], {
             RGBColor[
             0.2509928257224536, 0.38113975207155615`, 0.9376050421630586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 13}], {
             RGBColor[
             0.293422925234443, 0.42529914882237513`, 0.9400373862831393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 25}], {
             RGBColor[
             0.2646919276847649, 0.3951010487472052, 0.9384011984763869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 27}], {
             RGBColor[
             0.327914245400744, 0.45844457074209777`, 0.9421153836471216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 37}], {
             RGBColor[
             0.5197144859100872, 0.615889070520134, 0.9572576272411842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 40}], {
             RGBColor[
             0.2785823850167328, 0.4097008001089655, 0.9391922394723524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 53}], {
             RGBColor[
             0.3185195172219749, 0.4503073293864159, 0.9415167598750023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.28220392258022686`, 0.41350726570694146`, 0.9393984806790088]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 65}], {
             RGBColor[
             0.26785267018749115`, 0.3984231895202199, 0.9385811980860177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 81}], {
             RGBColor[
             0.42699263228672224`, 0.5418938445096457, 0.9490827029907487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 84}], {
             RGBColor[
             0.3751477903048108, 0.49935589331100566`, 0.9451250633614249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 85}], {
             RGBColor[
             0.46422750147449665`, 0.5721227887280222, 0.9520139682890303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 90}], {
             RGBColor[
             0.31078937097963055`, 0.4435523843968237, 0.9410263796769736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 100}], {
             RGBColor[
             0.27936916838135406`, 0.4105277593101289, 0.939237045621026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 17}], {
             RGBColor[
             0.6756356059860984, 0.7413302717200512, 0.9468242231148067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.9330401773606567, 0.8125446192441054, 0.5943013473777097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 22}], {
             RGBColor[
             0.9622103495532457, 0.9713371210884598, 0.9488522004737234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 30}], {
             RGBColor[
             0.8906347096446199, 0.5570183111625192, 0.5564513215678325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 49}], {
             RGBColor[
             0.8679776052374037, 0.8972436267472088, 0.9628476465059921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 69}], {
             RGBColor[
             0.6933493129056316, 0.7566729943369539, 0.9479529248561034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 77}], {
             RGBColor[
             0.6903471893885933, 0.7540727058376107, 0.9477616322002713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.9001907126422091, 0.6304699376692046, 0.5656021608302857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 86}], {
             RGBColor[
             0.9781688756181125, 0.981703287226387, 0.853067848528615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 87}], {
             RGBColor[
             0.8760096171986388, 0.9035182955368775, 0.9636482023948687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 95}], {
             RGBColor[
             0.7742769644814296, 0.8231752897500257, 0.9541023665093038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 99}], {
             RGBColor[
             0.6831435055361634, 0.747833236952314, 0.947302619835162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.5927913677992559, 0.604221747139333, 0.6081939441102431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 21}], {
             RGBColor[
             0.9272801117087064, 0.7490947632900866, 0.26033044528115884`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 30}], {
             RGBColor[
             0.8848746439926696, 0.49356845520850057`, 0.2224804194712816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 36}], {
             RGBColor[
             0.5653509190664274, 0.575380095696193, 0.6066312511494145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 61}], {
             RGBColor[
             0.565154574148669, 0.575173724738642, 0.6066200695968145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 67}], {
             RGBColor[
             0.5664610075924095, 0.5765468691206779, 0.6066944690487404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 68}], {
             RGBColor[
             0.884350574148669, 0.48954022473864206`, 0.22197856959681445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 72}], {
             RGBColor[
             0.8914135512087347, 0.5438293614385904, 0.22874208440602506`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 82}], {
             RGBColor[
             0.8944306469902588, 0.5670200817151858, 0.2316312587337348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 86}], {
             RGBColor[
             0.9724088099661622, 0.9182534312723682, 0.5190969464320642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 92}], {
             RGBColor[
             0.5688207352101959, 0.5790270924623439, 0.606828852045669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 94}], {
             RGBColor[
             0.566095277636464, 0.5761624637483606, 0.6066736412687983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.28368193490479854`, 0.4148331204560798, 0.9394909859406446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 26}], {
             RGBColor[
             0.235747888636603, 0.36511635660948866`, 0.9367368655488828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 35}], {
             RGBColor[
             0.2769526708149095, 0.4084251952129716, 0.9390834169369247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 40}], {
             RGBColor[
             0.247557235138606, 0.37752872853890806`, 0.9374093903618093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 53}], {
             RGBColor[
             0.28749436734384803`, 0.4181352578163585, 0.9397339107644591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 65}], {
             RGBColor[
             0.23682752030936433`, 0.3662511179501625, 0.9367983489754745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 90}], {
             RGBColor[
             0.2797642211015037, 0.41138031282676635`, 0.9392435305664304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 100}], {
             RGBColor[
             0.2483440185032272, 0.37835568774007156`, 0.9374541965104828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 36}], {
             RGBColor[
             0.20676013856834535`, 0.33464839335824176`, 0.9350860560660287]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 52}], {
             RGBColor[
             0.5864699931809645, 0.5791596032510256, 0.6031076177106328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 61}], {
             RGBColor[
             0.20656379365058694`, 0.3344420224006909, 0.9350748745134286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 67}], {
             RGBColor[
             0.20787022709432745`, 0.3358151667827266, 0.9351492739653546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 68}], {
             RGBColor[
             0.5257597936505869, 0.24880852240069085`, 0.5504333745134287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 72}], {
             RGBColor[
             0.5328227707106528, 0.3030976591006391, 0.5571968893226393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 92}], {
             RGBColor[
             0.21022995471211395`, 0.3382953901243926, 0.9352836569622833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 94}], {
             RGBColor[
             0.20750449713838193`, 0.3354307614104094, 0.9351284461854125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 41}], {
             RGBColor[
             0.5175163922375255, 0.6185385423481014, 0.9553377624650727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 52}], {
             RGBColor[
             0.7720788229198519, 0.7426869970369261, 0.6158231874912047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 60}], {
             RGBColor[
             0.5377449711891708, 0.6356046186030777, 0.9567524004381972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.44521446884155214`, 0.5537197588039671, 0.950811098924118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 74}], {
             RGBColor[
             0.48414329622236674`, 0.5896324439603484, 0.9532112582976568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 88}], {
             RGBColor[
             0.44729833605503005`, 0.5559100353701449, 0.9509297720791202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 96}], {
             RGBColor[
             0.4452662078752948, 0.5537741398088749, 0.9508140453855485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 27}], {
             RGBColor[
             0.30786109230723857`, 0.43780476345745334`, 0.9409573735218479]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 43}], {
             RGBColor[
             0.26197969156672996`, 0.39268764468141926`, 0.9382307279192786]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 54}], {
             RGBColor[
             0.26215076948672145`, 0.392867458422297, 0.938240470553735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 81}], {
             RGBColor[
             0.40693947919321677`, 0.5212540372250012, 0.947924692865475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 84}], {
             RGBColor[
             0.35509463721130535`, 0.4787160860263612, 0.9439670532361513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 85}], {
             RGBColor[
             0.44417434838099124`, 0.5514829814433777, 0.9508559581637567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 15}], {
             RGBColor[
             0.517451452940507, 0.6142257362851044, 0.9569878126877741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 24}], {
             RGBColor[
             0.8132324483478965, 0.7256778621369495, 0.6085269751651416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 35}], {
             RGBColor[
             0.5107221888506179, 0.6078178110419963, 0.9565802436840543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 38}], {
             RGBColor[
             0.5755893914541861, 0.6645818965278997, 0.9606923107205052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 42}], {
             RGBColor[
             0.6875842561639678, 0.755865313839969, 0.9694956308803766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 53}], {
             RGBColor[
             0.5212638853795565, 0.6175278736453831, 0.9572307375115887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 62}], {
             RGBColor[
             0.5425047543047143, 0.6359256467112409, 0.9585841868969369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 76}], {
             RGBColor[
             0.8566553758991764, 0.885347450425243, 0.7992958438699176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 35}], {
             RGBColor[
             0.3092088271480132, 0.4416635027021466, 0.9409447046902427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 38}], {
             RGBColor[
             0.3740760297515814, 0.49842758818805, 0.9450567717266938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 40}], {
             RGBColor[
             0.2798133914717097, 0.41076703602808307`, 0.9392706781151272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 53}], {
             RGBColor[
             0.3197505236769518, 0.4513735653055334, 0.9415951985177772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 62}], {
             RGBColor[
             0.3409913926021096, 0.4697713383713912, 0.9429486479031253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 90}], {
             RGBColor[
             0.3120203774346074, 0.44461862031594124`, 0.9411048183197483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 100}], {
             RGBColor[
             0.28060017483633093`, 0.41159399522924645`, 0.9393154842638007]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 29}], {
             RGBColor[
             0.27832737386526063`, 0.40880890872697706`, 0.9392005594800119]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.25232882209907226`, 0.38254396897044507`, 0.9376811251802775]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 62}], {
             RGBColor[
             0.30123789915337096`, 0.4286528542150554, 0.9406603978923882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 19}], {
             RGBColor[
             0.32753691967137427`, 0.45423076386143946`, 0.9422336623945751]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 22}], {
             RGBColor[
             0.6749436759381056, 0.7408142314231896, 0.9479954802017996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 28}], {
             RGBColor[
             0.3222279508615301, 0.4486507010342292, 0.9419313244747699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 46}], {
             RGBColor[
             0.32973159379600026`, 0.45653750551679784`, 0.942358645839243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 55}], {
             RGBColor[
             0.3185371640353287, 0.44477145007049096`, 0.9417211396250476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 59}], {
             RGBColor[
             0.33165561016298184`, 0.45855976870817894`, 0.9424682157250155]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 66}], {
             RGBColor[
             0.3553182658055509, 0.48218055585062736`, 0.943861543594892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 69}], {
             RGBColor[
             0.40608263929049154`, 0.5261501046716837, 0.9470962045841795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 77}], {
             RGBColor[
             0.4030805157734533, 0.5235498161723404, 0.9469049119283475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 79}], {
             RGBColor[
             0.3156295526433677, 0.44171536614432994`, 0.9415555554577009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 95}], {
             RGBColor[
             0.48701029086628944`, 0.5926524000847553, 0.95324564623738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 98}], {
             RGBColor[
             0.34163351398872654`, 0.46904717826467845`, 0.9430364425869058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 99}], {
             RGBColor[
             0.3958768319210234, 0.5173103472870436, 0.9464458995632381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 80}], {
             RGBColor[
             0.2419836729170215, 0.3716705612597674, 0.9370919842386365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 28}], {
             RGBColor[
             0.26139593816194606`, 0.39207408284088785`, 0.938197484026462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 43}], {
             RGBColor[
             0.25864725898215624`, 0.389185046746603, 0.9380409508134795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 46}], {
             RGBColor[
             0.2688995810964162, 0.39996088732345647`, 0.9386248053909352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 55}], {
             RGBColor[
             0.2577051513357447, 0.38819483187714965`, 0.9379872991767397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 59}], {
             RGBColor[
             0.2708235974633978, 0.40198315051483763`, 0.9387343752767077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 66}], {
             RGBColor[
             0.2944862531059669, 0.425603937657286, 0.9401277031465842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 79}], {
             RGBColor[
             0.2547975399437836, 0.38513874795098857`, 0.937821715009393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 95}], {
             RGBColor[
             0.4261782781667054, 0.536075781891414, 0.949511805789072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 98}], {
             RGBColor[
             0.2808015012891425, 0.4124705600713371, 0.9393026021385978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 99}], {
             RGBColor[
             0.33504481922143936`, 0.46073372909370225`, 0.9427120591149303]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.2386756834212212, 0.36819365456103337`, 0.9369035991305825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 58}], {
             RGBColor[
             0.22266134542622565`, 0.3513615699606193, 0.9359916062728575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 59}], {
             RGBColor[
             0.24810334272267293`, 0.37810272223498315`, 0.9374404903808281]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 63}], {
             RGBColor[
             0.22006041247387476`, 0.34862782451902463`, 0.9358434869889567]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 66}], {
             RGBColor[
             0.271765998365242, 0.4017235093774315, 0.9388338182507047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 79}], {
             RGBColor[
             0.2320772852030587, 0.3612583196711341, 0.9365278301135136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 83}], {
             RGBColor[
             0.22260788034518547`, 0.3513053747705641, 0.9359885615155867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 97}], {
             RGBColor[
             0.23606571183465724`, 0.3654504089417983, 0.9367549651098346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 22}], {
             RGBColor[
             0.9323482473126639, 0.8120285789472437, 0.5954726044647025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 30}], {
             RGBColor[
             0.860772607404038, 0.39770976902130306`, 0.2030717255588116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 34}], {
             RGBColor[
             0.7440489383777218, 0.6635696741320418, 0.6006939636333543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.5412488824777958, 0.4795214095089955, 0.5872225572369445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 49}], {
             RGBColor[
             0.8381155029968219, 0.7379350846059927, 0.6094680504969712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 68}], {
             RGBColor[
             0.8602485375600374, 0.3936815385514446, 0.2025698756843444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 72}], {
             RGBColor[
             0.8673115146201031, 0.4479706752513929, 0.20933339049355504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 82}], {
             RGBColor[
             0.8703286104016272, 0.4711613955279884, 0.21222256482126478`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[
             0.8461475149580568, 0.7442097533956613, 0.6102686063858478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 92}], {
             RGBColor[
             0.5447186986215644, 0.48316840627514634`, 0.5874201581331991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 30}], {
             RGBColor[
             0.889942779596627, 0.5565022708656576, 0.5576225786548253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 34}], {
             RGBColor[
             0.7732191105703109, 0.8223621759763964, 0.955244816729368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 49}], {
             RGBColor[
             0.8672856751894109, 0.8967275864503471, 0.9640189035929849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 66}], {
             RGBColor[
             0.6418930093726982, 0.712187405219036, 0.9458895209538087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 69}], {
             RGBColor[
             0.6926573828576388, 0.7561569540400923, 0.9491241819430962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 77}], {
             RGBColor[
             0.6896552593406005, 0.7535566655407491, 0.9489328892872642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 82}], {
             RGBColor[
             0.8994987825942162, 0.6299538973723429, 0.5667734179172785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 87}], {
             RGBColor[
             0.875317687150646, 0.9030022552400158, 0.9648194594818615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 95}], {
             RGBColor[
             0.7735850344334367, 0.822659249453164, 0.9552736235962966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 99}], {
             RGBColor[
             0.6824515754881706, 0.7473171966554524, 0.9484738769221548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 24}], {
             RGBColor[
             0.9471254016338135, 0.8298823883137303, 0.5568344831794053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 27}], {
             RGBColor[
             0.6645515668442425, 0.7298696411778459, 0.9061368692979717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 30}], {
             RGBColor[
             0.9025589304514734, 0.5654862789591164, 0.5172300337295237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 37}], {
             RGBColor[
             0.8563518073535856, 0.887314140955882, 0.9212791128920343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 50}], {
             RGBColor[
             0.9890507904475296, 0.9897402347152724, 0.831120268137828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 76}], {
             RGBColor[
             0.9905483291850934, 0.9895519766020239, 0.7476033518841813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[
             0.7636299537302207, 0.8133189149453938, 0.9131041886415987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 84}], {
             RGBColor[
             0.7117851117483094, 0.7707809637467538, 0.909146549012275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 85}], {
             RGBColor[
             0.8008648229179952, 0.8435478591637703, 0.9160354539398804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 86}], {
             RGBColor[
             0.990093096424966, 0.9901712550229842, 0.8138465606903063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 42}], {
             RGBColor[
             0.7818518898687528, 0.7011631313519644, 0.6053992543639326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 50}], {
             RGBColor[
             0.9494254708663976, 0.830833526050487, 0.5187163836071205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 76}], {
             RGBColor[
             0.9509230096039614, 0.8306452679372385, 0.4351994673534736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 26}], {
             RGBColor[
             0.21798888787154624`, 0.3464505208197316, 0.9357255167274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 40}], {
             RGBColor[
             0.22979823437354924`, 0.35886289274915106`, 0.9363980415403266]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 54}], {
             RGBColor[
             0.2334197719370433, 0.36266935834712705`, 0.9366042827469828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 65}], {
             RGBColor[
             0.21906851954430756`, 0.34758528216040546`, 0.9357870001539919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 100}], {
             RGBColor[
             0.23058501773817044`, 0.3596898519503145, 0.9364428476890001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 40}], {
             RGBColor[
             0.23187934520351416`, 0.3610502721814919, 0.9365165577233654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 53}], {
             RGBColor[
             0.27181647740875625`, 0.40165680145894234`, 0.9388410781260154]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 65}], {
             RGBColor[
             0.2211496303742725, 0.34977266159274634`, 0.9359055163370308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 90}], {
             RGBColor[
             0.2640863311664119, 0.39490185646935017`, 0.9383506979279865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[
             0.2326661285681354, 0.3618772313826554, 0.9365613638720389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 37}], {
             RGBColor[
             0.5341526529828826, 0.6283946851552121, 0.9581776144798929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 43}], {
             RGBColor[
             0.29647101173303086`, 0.4258330666011419, 0.9403087252832609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 54}], {
             RGBColor[
             0.2966420896530224, 0.4260128803420197, 0.9403184679177174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 81}], {
             RGBColor[
             0.4414307993595177, 0.5543994591447239, 0.9500026902294574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 84}], {
             RGBColor[
             0.38958595737760626`, 0.5118615079460839, 0.9460450506001336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 85}], {
             RGBColor[
             0.4786656685472922, 0.5846284033631004, 0.952933955527739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 46}], {
             RGBColor[
             0.2635906122865721, 0.39438082449624623`, 0.93832246747113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 55}], {
             RGBColor[
             0.2523961825259005, 0.38261476904993935`, 0.9376849612569346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 59}], {
             RGBColor[
             0.2655146286535537, 0.39640308768762733`, 0.9384320373569025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 66}], {
             RGBColor[
             0.28917728429612277`, 0.42002387483007575`, 0.9398253652267791]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 79}], {
             RGBColor[
             0.24948857113393946`, 0.3795586851237783, 0.937519377089588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 83}], {
             RGBColor[
             0.24001916627606623`, 0.36960574022320836`, 0.9369801084916611]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 98}], {
             RGBColor[
             0.27549253247929834`, 0.40689049724412685`, 0.9390002642187927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 99}], {
             RGBColor[
             0.3297358504115952, 0.455153666266492, 0.9424097211951252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 33}], {
             RGBColor[
             0.29422509162390786`, 0.4255184180648389, 0.9401059109878009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 38}], {
             RGBColor[
             0.3762188058276783, 0.5002835531261081, 0.9451933075234802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 42}], {
             RGBColor[
             0.48821367053746006`, 0.5915669704381774, 0.9539966276833514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 62}], {
             RGBColor[
             0.34313416867820656`, 0.4716273033094493, 0.9430851836999117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 36}], {
             RGBColor[
             0.49884341476175903`, 0.2239951014274094, 0.5493725314270672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 50}], {
             RGBColor[
             0.9048589996840575, 0.566437416695873, 0.47911193415723874`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 82}], {
             RGBColor[
             0.8279231426855904, 0.21563508744640228`, 0.17437253901138755`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 86}], {
             RGBColor[
             0.9059013056614938, 0.5668684370035848, 0.46183822670971686`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 92}], {
             RGBColor[
             0.5023132309055276, 0.22764209819356024`, 0.5495701323233219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 94}], {
             RGBColor[
             0.4995877733317956, 0.224777469479577, 0.549414921546451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 32}], {
             RGBColor[
             0.3463701598777138, 0.472931174642505, 0.9433462632569267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 39}], {
             RGBColor[
             0.34736341039793694`, 0.47397514391497986`, 0.943402827404671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 44}], {
             RGBColor[
             0.5893518598321712, 0.6739738751825308, 0.9626393731710036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 45}], {
             RGBColor[
             0.5919024457294845, 0.6759664122706829, 0.9628935917366674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 51}], {
             RGBColor[
             0.33046646407782415`, 0.4562153820042676, 0.9424405713085325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 70}], {
             RGBColor[
             0.3382626356768291, 0.464409652660651, 0.9428845517476936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 75}], {
             RGBColor[
             0.3329280335215753, 0.45880264756216715`, 0.9425807540467885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 78}], {
             RGBColor[
             0.6972006995541824, 0.7564641060518543, 0.846300355646884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 80}], {
             RGBColor[
             0.33469414166217204`, 0.4606589391956579, 0.9426813312926726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 39}], {
             RGBColor[
             0.2935264779562271, 0.4258453173585629, 0.9400272707348724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 44}], {
             RGBColor[
             0.5355149273904612, 0.6258440486261139, 0.959263816501205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 45}], {
             RGBColor[
             0.5380655132877746, 0.6278365857142659, 0.9595180350668688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 51}], {
             RGBColor[
             0.27662953163611426`, 0.40808555544785063`, 0.9390650146387339]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 80}], {
             RGBColor[
             0.2808572092204622, 0.41252911263924097`, 0.939305774622874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 42}], {
             RGBColor[
             0.46221511877127164`, 0.5653020306816455, 0.952477193383617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 62}], {
             RGBColor[
             0.3171356169120182, 0.44536236355291736`, 0.9415657494001773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 49}], {
             RGBColor[
             0.678986366254469, 0.7482686816351451, 0.9692402627616367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 60}], {
             RGBColor[
             0.5274957486173808, 0.6272838379970835, 0.9559455440932065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 69}], {
             RGBColor[
             0.5043580739226968, 0.6076980492248905, 0.954345541111748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 71}], {
             RGBColor[
             0.46781157980336074`, 0.5760433128989255, 0.9520168308232597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 77}], {
             RGBColor[
             0.5013559504056586, 0.6050977607255472, 0.9541542484559159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 82}], {
             RGBColor[
             0.7111994736592744, 0.481494992557141, 0.5719947770859303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 87}], {
             RGBColor[
             0.687018378215704, 0.7545433504248138, 0.9700408186505132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 38}], {
             RGBColor[
             0.3673467656616922, 0.49201966294494187`, 0.9446492027229738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 53}], {
             RGBColor[
             0.3130212595870627, 0.4449656400624253, 0.9411876295140573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 62}], {
             RGBColor[
             0.3342621285122205, 0.46336341312828305`, 0.9425410788994055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 90}], {
             RGBColor[
             0.3052911133447183, 0.4382106950728331, 0.9406972493160285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 61}], {
             RGBColor[
             0.17912334491775841`, 0.3056003709575509, 0.9335121815526001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 67}], {
             RGBColor[
             0.18042977836149893`, 0.3069735153395867, 0.9335865810045261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 68}], {
             RGBColor[
             0.4983193449177584, 0.2199668709575509, 0.5488706815526001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 72}], {
             RGBColor[
             0.5053823219778242, 0.27425600765749925`, 0.5556341963618108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 82}], {
             RGBColor[
             0.5083994177593483, 0.2974467279340947, 0.5585233706895204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 86}], {
             RGBColor[
             0.5863775807352516, 0.6486800774912771, 0.8459890583878498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 92}], {
             RGBColor[
             0.18278950597928542`, 0.3094537386812527, 0.9337209640014548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 94}], {
             RGBColor[
             0.1800640484055534, 0.3065891099672694, 0.9335657532245839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 50}], {
             RGBColor[
             0.8586518765861698, 0.8882652786926387, 0.8831610133197494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 76}], {
             RGBColor[
             0.8601494153237335, 0.8880770205793902, 0.7996440970661025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 81}], {
             RGBColor[
             0.6332310398688609, 0.7118439589227601, 0.9651449338235201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 84}], {
             RGBColor[
             0.5813861978869495, 0.66930600772412, 0.9611872941941962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 85}], {
             RGBColor[
             0.6704659090566354, 0.7420729031411366, 0.9680761991218017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 42}], {
             RGBColor[
             0.5442088329750422, 0.6400671657429147, 0.9575645899192962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 62}], {
             RGBColor[
             0.39912933111578863`, 0.5201274986141865, 0.9466531459358565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 44}], {
             RGBColor[
             0.5365081779106845, 0.6268880178985887, 0.9593203806489492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 45}], {
             RGBColor[
             0.5390587638079978, 0.6288805549867408, 0.959574599214613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 80}], {
             RGBColor[
             0.28185045974068534`, 0.4135730819117158, 0.9393623387706183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 53}], {
             RGBColor[
             0.2836258239107592, 0.41406917338836174`, 0.9395136029389419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 54}], {
             RGBColor[
             0.24731022926901122`, 0.37726910970888733`, 0.9373953237429482]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.23295897687627548`, 0.36218503352216574`, 0.9365780411499574]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 90}], {
             RGBColor[
             0.27589567766841483`, 0.4073142283987696, 0.939023222740913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 100}], {
             RGBColor[
             0.24447547507013836`, 0.3742896033120748, 0.9372338886849655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 48}], {
             RGBColor[
             0.34329321321312134`, 0.4669781893550724, 0.9432705886491298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 56}], {
             RGBColor[
             0.3357366265014662, 0.459035737605853, 0.9428402522148693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 60}], {
             RGBColor[
             0.44984311664774745`, 0.5635983285779962, 0.9500102743152689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 64}], {
             RGBColor[
             0.3573126143001289, 0.48171346877888566`, 0.9440689728011896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 73}], {
             RGBColor[
             0.34062966364440406`, 0.46417862987955394`, 0.9431189034415599]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 74}], {
             RGBColor[
             0.39624144168094344`, 0.517626153935267, 0.9464691321747285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.3593964815136068, 0.4839037453450634, 0.9441876459561919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 91}], {
             RGBColor[
             0.34170136961930875`, 0.46530506080926215`, 0.9431799355113838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 93}], {
             RGBColor[
             0.34493630114672413`, 0.468705178951081, 0.9433641600762177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 44}], {
             RGBColor[
             0.7173501625148713, 0.7791186661105619, 0.9724624182472246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 62}], {
             RGBColor[
             0.5111241958255703, 0.6114109159262558, 0.9554564660957278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 78}], {
             RGBColor[
             0.8251990022368825, 0.8616088969798854, 0.8561234007231051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 46}], {
             RGBColor[
             0.2608419331067822, 0.3914917884019613, 0.9381659342581474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 54}], {
             RGBColor[
             0.2507606889125138, 0.3808957615659856, 0.9375918223151481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 45}], {
             RGBColor[
             0.7810472132422319, 0.8288792862542917, 0.9788111449809456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 78}], {
             RGBColor[
             0.88634546706693, 0.9093769800354632, 0.8622179088911622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 52}], {
             RGBColor[
             0.8611685991001501, 0.8128504925215565, 0.6243159249705089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 78}], {
             RGBColor[
             0.8888960529642432, 0.9113695171236152, 0.8624721274568261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 55}], {
             RGBColor[
             0.25989982546037066`, 0.390501573532508, 0.9381122826214077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 59}], {
             RGBColor[
             0.27301827158802383`, 0.40428989217019595`, 0.9388593587213756]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 79}], {
             RGBColor[
             0.25699221406840955`, 0.38744548960634695`, 0.937946698454061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 95}], {
             RGBColor[
             0.42837295229133143`, 0.5383825235467723, 0.9496367892337401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 98}], {
             RGBColor[
             0.2829961754137684, 0.41477730172669547`, 0.9394275855832659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 99}], {
             RGBColor[
             0.3372394933460653, 0.46304047074906063`, 0.9428370425595982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 51}], {
             RGBColor[
             0.26797369092262097`, 0.39898771804597, 0.9385720773152693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 57}], {
             RGBColor[
             0.2643065968573336, 0.3951333696761603, 0.9383632417332306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 70}], {
             RGBColor[
             0.27576986252162594`, 0.40718198870235345`, 0.9390160577544302]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 74}], {
             RGBColor[
             0.31904494583740095`, 0.4476628644149205, 0.9416637299737558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 75}], {
             RGBColor[
             0.2704352603663721, 0.40157498360386956`, 0.9387122600535251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 88}], {
             RGBColor[
             0.28219998567006427`, 0.41394045582471695`, 0.9393822437552191]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 96}], {
             RGBColor[
             0.280167857490329, 0.4118045602634469, 0.9392665170616474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 56}], {
             RGBColor[
             0.2494153020184852, 0.3794816746379056, 0.9375152045218548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 57}], {
             RGBColor[
             0.25518176821789507`, 0.38554259622855935`, 0.9378435962411888]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 64}], {
             RGBColor[
             0.27099128981714793`, 0.40215940581093823`, 0.9387439251081751]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 73}], {
             RGBColor[
             0.25430833916142304`, 0.38462456691160657`, 0.9377938557485452]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 74}], {
             RGBColor[
             0.3099201171979624, 0.4380720909673196, 0.941144084481714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 88}], {
             RGBColor[
             0.2730751570306258, 0.404349682377116, 0.9388625982631773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 91}], {
             RGBColor[
             0.2553800451363277, 0.3857509978413148, 0.9378548878183692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 93}], {
             RGBColor[
             0.2586149766637431, 0.3891511159831336, 0.9380391123832033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 96}], {
             RGBColor[
             0.2710430288508906, 0.402213786815846, 0.9387468715696057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 69}], {
             RGBColor[
             0.5984246385417968, 0.6820634596988412, 0.9631196279753649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 71}], {
             RGBColor[
             0.5618781444224608, 0.6504087233728764, 0.9607909176868766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 77}], {
             RGBColor[
             0.5954225150247585, 0.679463171199498, 0.9629283353195328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 82}], {
             RGBColor[
             0.8052660382783743, 0.5558604030310919, 0.5807688639495472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.781084942834804, 0.8289087608987646, 0.9788149055141302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 76}], {
             RGBColor[
             0.9928483984176775, 0.9905031143387806, 0.7094852523118963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 81}], {
             RGBColor[
             0.7659300229628049, 0.8142700526821505, 0.8749860890693137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 84}], {
             RGBColor[
             0.7140851809808935, 0.7717321014835103, 0.87102844943999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 85}], {
             RGBColor[
             0.8031648921505794, 0.844498996900527, 0.8779173543675954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 86}], {
             RGBColor[
             0.9923931656575502, 0.9911223927597408, 0.7757284611180213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 57}], {
             RGBColor[
             0.25705874177093724`, 0.3875154144398035, 0.9379504871083011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 70}], {
             RGBColor[
             0.2685220074352297, 0.3995640334659966, 0.9386033031295007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 75}], {
             RGBColor[
             0.2631874052799758, 0.3939570283675128, 0.9382995054285956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 67}], {
             RGBColor[
             0.560139632974118, 0.5514847252323705, 0.6016081426491302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 68}], {
             RGBColor[
             0.8780291995303775, 0.46447808085033465`, 0.21689224319720418`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 72}], {
             RGBColor[
             0.8850921765904433, 0.518767217550283, 0.2236557580064148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 78}], {
             RGBColor[
             0.9664668529248481, 0.8933481863027279, 0.5077226888807255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 65}], {
             RGBColor[
             0.2728961090815175, 0.40279156279961614`, 0.9389025615526072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 84}], {
             RGBColor[
             0.3801912291988372, 0.5037242665904019, 0.9454464268280143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 85}], {
             RGBColor[
             0.46927094036852307`, 0.5764911620074185, 0.9523353317556198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 90}], {
             RGBColor[
             0.3158328098736569, 0.44792075767621997`, 0.941347743143563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 100}], {
             RGBColor[
             0.2844126072753804, 0.4148961325895252, 0.9395584090876155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 84}], {
             RGBColor[
             0.3438756345570892, 0.4669242029109275, 0.9433281476320208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 100}], {
             RGBColor[
             0.24809701263363243`, 0.37809606891005076`, 0.9374401298916217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 59}], {
             RGBColor[
             0.26182384182735224`, 0.39252383672388913`, 0.9382218525071802]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 66}], {
             RGBColor[
             0.28548649746992133`, 0.41614462386633744`, 0.9396151803770567]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 79}], {
             RGBColor[
             0.24579778430773802`, 0.37567943416004, 0.9373091922398655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 98}], {
             RGBColor[
             0.2718017456530969, 0.4030112462803886, 0.9387900793690704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 99}], {
             RGBColor[
             0.32604506358539376`, 0.45127441530275375`, 0.9421995363454028]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 64}], {
             RGBColor[
             0.2634347031054928, 0.3942169540617188, 0.9383135886739146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 73}], {
             RGBColor[
             0.24675175244976794`, 0.37668211516238714`, 0.9373635193142849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 74}], {
             RGBColor[
             0.3023635304863073, 0.4301296392181001, 0.9407137480474534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 88}], {
             RGBColor[
             0.26551857031897064`, 0.39640723062789657`, 0.9384322618289168]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 89}], {
             RGBColor[
             0.2431918362429577, 0.37294041751730556`, 0.937160787352731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 91}], {
             RGBColor[
             0.2478234584246726, 0.37780854609209535`, 0.9374245513841087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 93}], {
             RGBColor[
             0.251058389952088, 0.3812086642339142, 0.9376087759489427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 64}], {
             RGBColor[
             0.2692011693049027, 0.4002778756523726, 0.9386419803932486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 70}], {
             RGBColor[
             0.26485491336994227`, 0.39570968509618687`, 0.9383944675474621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 74}], {
             RGBColor[
             0.3081299966857172, 0.43619056080875396`, 0.9410421397667876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 75}], {
             RGBColor[
             0.25952031121468844`, 0.390102679997703, 0.9380906698465571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 88}], {
             RGBColor[
             0.27128503651838054`, 0.40246815221855037`, 0.9387606535482509]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 96}], {
             RGBColor[
             0.26925290833864535`, 0.40033225665728034`, 0.9386449268546793]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 63}], {
             RGBColor[
             0.22145736040975994`, 0.3500961053712548, 0.9359230411073061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 83}], {
             RGBColor[
             0.22400482828107066`, 0.3527736556227943, 0.9360681156339361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 97}], {
             RGBColor[
             0.23746265977054243`, 0.3669186897940284, 0.936834519228184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 66}], {
             RGBColor[
             0.2986049435975745, 0.4299329425040255, 0.9403622564770246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 69}], {
             RGBColor[
             0.34936931708251506`, 0.4739024913250818, 0.9435969174663121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 77}], {
             RGBColor[
             0.3463671935654768, 0.47130220282573854`, 0.9434056248104801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 79}], {
             RGBColor[
             0.2589162304353912, 0.38946775279772805`, 0.9380562683398335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 83}], {
             RGBColor[
             0.24944682557751796`, 0.3795148078971581, 0.9375169997419068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 95}], {
             RGBColor[
             0.430296968658313, 0.5404047867381535, 0.9497463591195126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 97}], {
             RGBColor[
             0.26290465706698973`, 0.3936598420683923, 0.9382834033361547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 98}], {
             RGBColor[
             0.28492019178075007`, 0.41679956491807657`, 0.9395371554690384]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 99}], {
             RGBColor[
             0.33916350971304693`, 0.46506273394044173`, 0.9429466124453707]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 64}], {
             RGBColor[
             0.37754119325177404`, 0.49877954503386207`, 0.9454836107743141]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 71}], {
             RGBColor[
             0.41038752678537255`, 0.5294238797348146, 0.9474961990184465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 74}], {
             RGBColor[
             0.4164700206325886, 0.5346922301902434, 0.9478837701478531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 89}], {
             RGBColor[
             0.357298326389239, 0.4775030084894488, 0.9443308094531306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 93}], {
             RGBColor[
             0.3651648800983693, 0.48577125520605746`, 0.9447787980493423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 67}], {
             RGBColor[
             0.1802334334437405, 0.3067671443820358, 0.933575399451926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 68}], {
             RGBColor[0.49812300000000004`, 0.2197605, 0.5488595000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 72}], {
             RGBColor[
             0.5051859770600657, 0.2740496366999483, 0.5556230148092107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 86}], {
             RGBColor[
             0.5861812358174932, 0.6484737065337263, 0.8459778768352497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 92}], {
             RGBColor[
             0.182593161061527, 0.30924736772370176`, 0.9337097824488547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 94}], {
             RGBColor[
             0.17986770348779496`, 0.3063827390097185, 0.9335545716719839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 83}], {
             RGBColor[
             0.2214038953287198, 0.3500399101811996, 0.9359199963500353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 97}], {
             RGBColor[
             0.23486172681819156`, 0.36418494435243376`, 0.9366863999442832]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 73}], {
             RGBColor[
             0.26832774024843065`, 0.39935984633541977`, 0.938592239900605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 74}], {
             RGBColor[
             0.32393951828497003`, 0.45280737039113284`, 0.9419424686337738]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 88}], {
             RGBColor[
             0.2870945581176334, 0.41908496180092925`, 0.9396609824152371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 89}], {
             RGBColor[
             0.2647678240416204, 0.39561814869033823`, 0.9383895079390514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 91}], {
             RGBColor[
             0.26939944622333534`, 0.400486277265128, 0.938653271970429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 93}], {
             RGBColor[
             0.2726343777507507, 0.4038863954069468, 0.938837496535263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 96}], {
             RGBColor[
             0.28506242993789815`, 0.4169490662396592, 0.9395452557216655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 90}], {
             RGBColor[
             0.26516596283917315`, 0.39603661781002397`, 0.9384121813545784]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 100}], {
             RGBColor[
             0.2337457602408967, 0.3630119927233292, 0.9366228472986309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 69}], {
             RGBColor[
             0.37303197272508415`, 0.4975232784675301, 0.9449902453361887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 77}], {
             RGBColor[
             0.3700298492080458, 0.49492298996818684`, 0.9447989526803566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 79}], {
             RGBColor[
             0.2825788860779602, 0.4130885399401764, 0.93944959620971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 83}], {
             RGBColor[
             0.27310948122008705`, 0.4031355950396065, 0.9389103276117834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 95}], {
             RGBColor[
             0.4539596243008821, 0.5640255738806018, 0.9511396869893891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 97}], {
             RGBColor[
             0.2865673127095588, 0.41728062921084064`, 0.9396767312060312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[
             0.3085828474233191, 0.440420352060525, 0.9409304833389149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 99}], {
             RGBColor[
             0.36282616535561596`, 0.48868352108289015`, 0.9443399403152473]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 68}], {
             RGBColor[
             0.49942943344374047`, 0.22113364438203578`, 0.5489338994519259]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 72}], {
             RGBColor[
             0.5064924105038062, 0.2754227810819841, 0.5556974142611366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 86}], {
             RGBColor[
             0.5874876692612337, 0.649846850915762, 0.8460522762871756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 92}], {
             RGBColor[
             0.1838995945052675, 0.31062051210573755`, 0.9337841819007806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 94}], {
             RGBColor[
             0.18117413693153547`, 0.3077558833917543, 0.9336289711239099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 72}], {
             RGBColor[
             0.8243819770600658, 0.1884161366999483, 0.17098151480921064`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 82}], {
             RGBColor[
             0.8273990728415899, 0.2116068569765438, 0.1738706891369204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 92}], {
             RGBColor[
             0.501789161061527, 0.22361386772370176`, 0.5490682824488547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 71}], {
             RGBColor[
             0.38724985209068863`, 0.5098380909626216, 0.9458961960369879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 77}], {
             RGBColor[
             0.4207942226929865, 0.5388925387892431, 0.9480336136696441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 87}], {
             RGBColor[
             0.6064566505030319, 0.6883381284885098, 0.9639201838642415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 95}], {
             RGBColor[
             0.5047239977858227, 0.6079951227016581, 0.9543743479786766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 97}], {
             RGBColor[
             0.3373316861944994, 0.46125017803189694`, 0.9429113921953187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 98}], {
             RGBColor[
             0.35934722090825977`, 0.48438990088158124`, 0.9441651443282024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 99}], {
             RGBColor[
             0.41359053884055663`, 0.5326530699039465, 0.9475746013045347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 75}], {
             RGBColor[
             0.2709835768789808, 0.4021512990238961, 0.9387434858677567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 96}], {
             RGBColor[
             0.28071617400293775`, 0.4123808756834735, 0.9392977428758789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 77}], {
             RGBColor[
             0.3842477285736503, 0.5072378024632783, 0.9457049033811559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 87}], {
             RGBColor[
             0.5699101563836958, 0.656683392162545, 0.9615914735757531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 82}], {
             RGBColor[
             0.8344620499016556, 0.2658959936764921, 0.180634203946131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 92}], {
             RGBColor[
             0.5088521381215928, 0.27790300442365007`, 0.5558317972580653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 74}], {
             RGBColor[
             0.3072565676292452, 0.4352725314918011, 0.940992399274144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 88}], {
             RGBColor[
             0.2704116074619085, 0.40155012290159753`, 0.9387109130556073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 89}], {
             RGBColor[
             0.24808487338589558`, 0.37808330979100657`, 0.9374394385794216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 91}], {
             RGBColor[
             0.25271649556761044`, 0.3829514383657963, 0.9377032026107992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 93}], {
             RGBColor[
             0.2559514270950259, 0.38635155650761516`, 0.9378874271756332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 88}], {
             RGBColor[
             0.3260233854984479, 0.4549976469573106, 0.9420611417887761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 91}], {
             RGBColor[
             0.3083282736041498, 0.43639896242150933`, 0.941053431343968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 96}], {
             RGBColor[
             0.3239912573187127, 0.45286175139604057`, 0.9419454150952044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 96}], {
             RGBColor[
             0.27538157184768386`, 0.40677387058498965`, 0.9389939451749738]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 81}], {
             RGBColor[
             0.7674275617003685, 0.8140817945689018, 0.7914691728156671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 84}], {
             RGBColor[
             0.7155827197184571, 0.7715438433702618, 0.7875115331863431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 85}], {
             RGBColor[
             0.8046624308881429, 0.8443107387872784, 0.7944004381139487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 87}], {
             RGBColor[
             0.6034545269859937, 0.6857378399891666, 0.9637288912084094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 95}], {
             RGBColor[
             0.5017218742687843, 0.6053948342023149, 0.9541830553228445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 97}], {
             RGBColor[
             0.3343295626774611, 0.4586498895325537, 0.9427200995394867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 98}], {
             RGBColor[
             0.35634509739122144`, 0.481789612382238, 0.9439738516723704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 99}], {
             RGBColor[
             0.4105884153235183, 0.5300527814046032, 0.9473833086487027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 83}], {
             RGBColor[
             0.23342076805790374`, 0.3626704053333091, 0.9366043394745922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 98}], {
             RGBColor[
             0.26889413426113584`, 0.39995516235422757`, 0.9386244952017238]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 99}], {
             RGBColor[
             0.3231374521934327, 0.4482183313765927, 0.9420339521780562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 84}], {
             RGBColor[
             0.4886643442635845, 0.5953107817136317, 0.9530123699437607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 85}], {
             RGBColor[
             0.5777440554332705, 0.6680776771306483, 0.9599012748713662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 86}], {
             RGBColor[
             0.9154573086590831, 0.64032006351027, 0.4709890659721701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 87}], {
             RGBColor[
             0.8132980502396094, 0.5621350718207605, 0.5815694198384238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 92}], {
             RGBColor[
             0.5118692339031169, 0.30109372470024554`, 0.558720971585775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 97}], {
             RGBColor[
             0.23740919468950228`, 0.36686249460397324`, 0.9368314744709133]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 85}], {
             RGBColor[
             0.5258992134513589, 0.6255397259320082, 0.9559436352420423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.37246108295649283`, 0.49696932160080975`, 0.9449560466299856]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 90}], {
             RGBColor[
             0.4615407941261787, 0.5697362170178263, 0.951844951557591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 92}], {
             RGBColor[
             0.5898473968790202, 0.652327074257428, 0.8461866592841044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 94}], {
             RGBColor[
             0.5871219393052882, 0.6494624455434448, 0.8460314485072336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 91}], {
             RGBColor[
             0.2714833134368132, 0.40267655383130574`, 0.9387719451254313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 96}], {
             RGBColor[
             0.2871462971513761, 0.419139342805837, 0.9396639288766677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 91}], {
             RGBColor[
             0.24915657936080024`, 0.3792097407207148, 0.9375004706492456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 93}], {
             RGBColor[
             0.25239151088821565`, 0.3826098588625336, 0.9376846952140795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 100}], {
             RGBColor[
             0.27668246103303606`, 0.408141187599933, 0.9390680288895865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 93}], {
             RGBColor[
             0.2570231330699305, 0.38747798743732337`, 0.9379484592454572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 96}], {
             RGBColor[
             0.269451185257078, 0.40054065827003577`, 0.9386562184318596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 94}], {
             RGBColor[
             0.18353386454932197`, 0.3102361067334203, 0.9337633541208386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 98}], {
             RGBColor[
             0.44027487248405767`, 0.5508921962946529, 0.9503145859814027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 99}], {
             RGBColor[
             0.49451819041635453`, 0.5991553653170181, 0.9537240429577352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 99}], {
             RGBColor[
             0.3491414135387916, 0.47555014349694125`, 0.943514839307261]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.058168352269944726`], {
             RGBColor[
             0.2581082061950206, 0.38861846808940276`, 0.9380102525547092]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.058168352269944726`], {
             RGBColor[
             0.5167351398431651, 0.6185478910342742, 0.9550984295530915]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.058168352269944726`], {
             RGBColor[
             0.29928415304751665`, 0.4318969989371937, 0.9403551618136042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.058168352269944726`], {
             RGBColor[
             0.8388093398485373, 0.29931116920282663`, 0.1847971737088267]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.058168352269944726`], {
             RGBColor[
             0.2503401935643895, 0.38045379429416204`, 0.9375678757271396]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.058168352269944726`], {
             RGBColor[
             0.2567233930101477, 0.3871629416298741, 0.9379313894924781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.058168352269944726`], {
             RGBColor[
             0.3134760783279485, 0.4459389561070196, 0.9411953964084129]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.058168352269944726`], {
             RGBColor[
             0.9629022796012385, 0.9718531613853215, 0.9476809433867306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.058168352269944726`], {
             RGBColor[
             0.9513821482973379, 0.8449534494772841, 0.27973913919362886`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.058168352269944726`], {
             RGBColor[
             0.25142577857169485`, 0.38159481296690484`, 0.9376296981873266]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.058168352269944726`], {
             RGBColor[
             0.23420058730117388`, 0.3634900448013817, 0.9366487490268572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.058168352269944726`], {
             RGBColor[
             0.6054182467789488, 0.6905448323731828, 0.9620798885880011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.058168352269944726`], {
             RGBColor[
             0.2733697721409376, 0.40465934153773064`, 0.9388793761578655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.058168352269944726`], {
             RGBColor[
             0.7189648146431117, 0.780380044624954, 0.9726233516815856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.058168352269944726`], {
             RGBColor[
             0.3159380912379023, 0.44807142794525473`, 0.9413522736939626]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.058168352269944726`], {
             RGBColor[
             0.23643110434042502`, 0.36583445963258315`, 0.9367757736724883]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.058168352269944726`], {
             RGBColor[
             0.3883689323709583, 0.5108073820547808, 0.9459675028428829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.058168352269944726`], {
             RGBColor[
             0.21478615482912253`, 0.34308424532714094`, 0.935543125818653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.058168352269944726`], {
             RGBColor[
             0.2667049069717902, 0.39765414566809815`, 0.9384998219462671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.058168352269944726`], {
             RGBColor[
             0.22126439749034046`, 0.3498932891083892, 0.9359120521545081]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.058168352269944726`], {
             RGBColor[
             0.9031780751200748, 0.6532360771028892, 0.2409217513686888]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.058168352269944726`], {
             RGBColor[
             0.9615184195052529, 0.9708210807915982, 0.9500234575607163]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.058168352269944726`], {
             RGBColor[
             0.9867507212149456, 0.9887890969785158, 0.869238367710113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.058168352269944726`], {
             RGBColor[
             0.9075000820526815, 0.6709756796489449, 0.2444305986486977]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.058168352269944726`], {
             RGBColor[
             0.21590777704158132`, 0.3442631413873908, 0.9356070005443611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.058168352269944726`], {
             RGBColor[
             0.2200699987015112, 0.3486379002520725, 0.9358440329104389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.058168352269944726`], {
             RGBColor[
             0.3423524124735395, 0.470950185377176, 0.9430353708858302]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.058168352269944726`], {
             RGBColor[
             0.25608696935210196`, 0.3864940200136776, 0.9378951461066569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.058168352269944726`], {
             RGBColor[
             0.32022364339009624`, 0.4517833578213709, 0.9416253452875354]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.058168352269944726`], {
             RGBColor[
             0.8183671396880012, 0.14218346093971695`, 0.1652216997489344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.058168352269944726`], {
             RGBColor[
             0.40020709231942364`, 0.521061001198922, 0.9467218199267253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.058168352269944726`], {
             RGBColor[
             0.2925332274360039, 0.424801348086088, 0.9399707065871281]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.058168352269944726`], {
             RGBColor[
             0.26822653985771944`, 0.399253478308307, 0.9385864766880666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.058168352269944726`], {
             RGBColor[
             0.5849198016353689, 0.6739032711611944, 0.9604661758980197]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.058168352269944726`], {
             RGBColor[
             0.30247956305812407`, 0.4352555774590384, 0.9405371356865229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.058168352269944726`], {
             RGBColor[
             0.17931968983551683`, 0.3058067419151018, 0.9335233631052001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.058168352269944726`], {
             RGBColor[
             0.7259528934922258, 0.7858391849332483, 0.9733198580739556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.058168352269944726`], {
             RGBColor[
             0.43221396826526043`, 0.5487837484308453, 0.9487612697594249]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.058168352269944726`], {
             RGBColor[
             0.2945197284764503, 0.42688928663103776`, 0.9400838348826166]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.058168352269944726`], {
             RGBColor[
             0.24368869170551716`, 0.37346264411091135`, 0.937189082536292]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.058168352269944726`], {
             RGBColor[
             0.4296145376961023, 0.5465322523230198, 0.9485956363421444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.058168352269944726`], {
             RGBColor[
             0.6562036976848239, 0.731350583054984, 0.9663679100791674]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.058168352269944726`], {
             RGBColor[
             0.25058961099252225`, 0.3807159478251078, 0.9375820796806917]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.058168352269944726`], {
             RGBColor[
             0.7784966273449186, 0.8268867491661398, 0.9785569264152818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.058168352269944726`], {
             RGBColor[
             0.7835977991395453, 0.8308718233424438, 0.9790653635466094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.058168352269944726`], {
             RGBColor[
             0.2710942552210422, 0.40226762897881485`, 0.9387497888356031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.058168352269944726`], {
             RGBColor[
             0.27522154600901727`, 0.40660567328232683`, 0.9389848319401988]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.058168352269944726`], {
             RGBColor[
             0.2569718887301403, 0.38742412638712503`, 0.9379455409561153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.058168352269944726`], {
             RGBColor[
             0.773052930873569, 0.822634092109096, 0.9780143496252536]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.058168352269944726`], {
             RGBColor[
             0.9913508596801138, 0.9906913724520291, 0.7930021685655431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.058168352269944726`], {
             RGBColor[
             0.26072583583622466`, 0.3913697628096132, 0.9381593226903397]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.058168352269944726`], {
             RGBColor[
             0.938739399060755, 0.7948291617006693, 0.26956648639440833`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.058168352269944726`], {
             RGBColor[
             0.3235629561160013, 0.45467570266581214`, 0.9418381233415918]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.058168352269944726`], {
             RGBColor[
             0.2509317668325053, 0.3810755753068633, 0.9376015649496046]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.058168352269944726`], {
             RGBColor[
             0.2487053956996991, 0.3787355180862011, 0.9374747764072122]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.058168352269944726`], {
             RGBColor[
             0.24185871530683006`, 0.3715392228886861, 0.9370848680875943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.058168352269944726`], {
             RGBColor[
             0.25339164770564987`, 0.38366106606999373`, 0.9377416515262625]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.058168352269944726`], {
             RGBColor[
             0.22405829336211083`, 0.3528298508128494, 0.9360711603912069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.058168352269944726`], {
             RGBColor[
             0.2749422879550054, 0.4063121553615771, 0.9389689286071481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.058168352269944726`], {
             RGBColor[
             0.4700716955993926, 0.5806644048329727, 0.9514249122883933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.058168352269944726`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.058168352269944726`], {
             RGBColor[
             0.3660446939663169, 0.4914712487975277, 0.9445450221122881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.058168352269944726`], {
             RGBColor[
             0.21885642745740908`, 0.34736235992966014`, 0.9357749218234052]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.058168352269944726`], {
             RGBColor[
             0.2850106909041555, 0.4168946852347515, 0.9395423092602349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.058168352269944726`], {
             RGBColor[
             0.2222292620470338, 0.35090742293342014`, 0.9359669997636226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.058168352269944726`], {
             RGBColor[
             0.32226759924014353`, 0.45355372964647384`, 0.9417555843469012]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.058168352269944726`], {
             RGBColor[
             0.181539866887481, 0.30814028876407157`, 0.9336497989038519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.058168352269944726`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.058168352269944726`], {
             RGBColor[
             0.42379634621002477`, 0.5414928272885864, 0.9482249063254762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.058168352269944726`], {
             RGBColor[
             0.27631817903423467`, 0.40775830412238, 0.9390472835686617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.058168352269944726`], {
             RGBColor[
             0.3507033579713525, 0.4781833546366567, 0.9435674857484997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.058168352269944726`], {
             RGBColor[
             0.8314449541201315, 0.24270527339989661`, 0.17774502961842129`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.058168352269944726`], {
             RGBColor[
             0.2516447895927058, 0.3818250074360881, 0.9376421705409753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.058168352269944726`], {
             RGBColor[
             0.3628683456657846, 0.48872005554751413`, 0.9443426280073127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.058168352269944726`], {
             RGBColor[
             0.26564897472372695`, 0.3965442939254123, 0.9384396881668516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.058168352269944726`], {
             RGBColor[
             0.9943459371552411, 0.990314856225532, 0.6259683360582495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.058168352269944726`], {
             RGBColor[
             0.4177920991759482, 0.5362922502898999, 0.947842321013812]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.058168352269944726`], {
             RGBColor[
             0.9941943067889412, 0.9918672109047867, 0.7458788913670427]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.058168352269944726`], {
             RGBColor[
             0.24289017291577697`, 0.372623350233879, 0.937143608072519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.058168352269944726`], {
             RGBColor[
             0.26918119100492044`, 0.4002568771923939, 0.9386408426586199]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.058168352269944726`], {
             RGBColor[
             0.5405091862454959, 0.6378487329122717, 0.9569700095730845]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.058168352269944726`], {
             RGBColor[
             0.8374791456831797, 0.2890867139530876, 0.18352337827384074`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.058168352269944726`], {
             RGBColor[
             0.2239513632000305, 0.3527174604327391, 0.9360650708766655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.058168352269944726`], {
             RGBColor[
             0.4368195022816731, 0.5527728305149917, 0.9490547303144369]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.058168352269944726`], {
             RGBColor[
             0.6149789246210449, 0.6983066213490248, 0.9628325401696478]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.058168352269944726`], {
             RGBColor[
             0.9934354716349865, 0.9915534130674525, 0.7584547536704994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.058168352269944726`], {
             RGBColor[
             0.789116954796039, 0.8351834296884333, 0.9796154614030067]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.058168352269944726`], {
             RGBColor[
             0.28917842533111127`, 0.421275238367107, 0.9397796555702393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.058168352269944726`], {
             RGBColor[
             0.24452495717908534`, 0.374341612145925, 0.9372367066178678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.058168352269944726`], {
             RGBColor[
             0.30810266363131256`, 0.4411658126866278, 0.9408573629455341]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.058168352269944726`], {
             RGBColor[
             0.25378820154251513`, 0.3840778692955045, 0.9377642346806232]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.058168352269944726`], {
             RGBColor[
             0.18625932212305402`, 0.3131007354474035, 0.9339185648977094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.058168352269944726`], {
             RGBColor[
             0.26025806459734596`, 0.3908781055791422, 0.9381326838102911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.058168352269944726`], {
             RGBColor[
             0.18080840697558995`, 0.30737147801943704`, 0.9336081433439677]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.058168352269944726`], {
             RGBColor[
             0.5856516493616206, 0.6744974181147299, 0.9605237896318769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.058168352269944726`], {
             RGBColor[
             0.2851141689716408, 0.417003447244567, 0.939548202183096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.058168352269944726`], {
             RGBColor[
             0.25086702617897405`, 0.38100752877520744`, 0.9375978780651611]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.058168352269944726`], {
             RGBColor[
             0.2948980956064947, 0.4272869744745761, 0.9401053823309286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.058168352269944726`], {
             RGBColor[
             0.40338473147108844`, 0.5238133125193064, 0.9469242962835934]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.058168352269944726`], {
             RGBColor[
             0.24526225843475957`, 0.3751165625132382, 0.937278694833639]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{{3.8349502435193233`*^9, 3.8349502581408367`*^9}, 
   3.834950528174912*^9, 3.8349578088972807`*^9, 3.835018923470682*^9, 
   3.835019026079196*^9, 3.8350205603927774`*^9, 3.835044649527498*^9},
 CellLabel->
  "Out[246]=",ExpressionUUID->"461f90db-af0e-4055-b152-e2259715f342"]
}, Open  ]],

Cell["r = 3 :", "Text",
 CellChangeTimes->{{3.834793779215767*^9, 3.8347938725231647`*^9}, {
  3.8347953347101345`*^9, 3.8347953431477337`*^9}, {3.8348851911359825`*^9, 
  3.83488519180678*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"9ba526e9-351a-4fe2-b804-7b2aa6b3e77b"],

Cell["Cubic Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.834795179278664*^9}},ExpressionUUID->"0c97c55f-9a9a-4463-8f81-\
c8faa564c1a3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c\[Rho]3if1", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"CMDi3f100", ",", "krif1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.834947911760502*^9, 
   3.834947914304406*^9}, {3.834947957535968*^9, 3.8349479704802837`*^9}, {
   3.8349480487781425`*^9, 3.834948105065866*^9}, {3.8349497992119355`*^9, 
   3.83494980454772*^9}, {3.8349578354451995`*^9, 3.83495784069214*^9}, {
   3.835018838991932*^9, 3.8350188405169106`*^9}, {3.8350443590646524`*^9, 
   3.8350443609005165`*^9}},
 CellLabel->
  "In[247]:=",ExpressionUUID->"ba13801f-5532-4b86-ac7f-c77fdfacde84"],

Cell[BoxData[
 RowBox[{"-", "0.004197384875591692`"}]], "Output",
 CellChangeTimes->{
  3.834948013482303*^9, {3.834948049945756*^9, 3.834948058990469*^9}, 
   3.8349481059508953`*^9, 3.8349499476386404`*^9, 3.834957841643118*^9, 
   3.8350189236386824`*^9, 3.8350190270322647`*^9, 3.8350204164650445`*^9, 
   3.8350205609787445`*^9, 3.8350446521595054`*^9},
 CellLabel->
  "Out[247]=",ExpressionUUID->"a9269c28-ab73-4d03-bea8-7540304abedd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CP3if1", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"CMDi3f100", ",", "krif1"}], "}"}], "]"}], ",", "c\[Rho]3if1"}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.8349481210775223`*^9, 3.834948150679065*^9}, {
  3.8349481924167476`*^9, 3.8349481986802473`*^9}, {3.834949807949147*^9, 
  3.834949815491851*^9}, {3.8349578438231587`*^9, 3.8349578533989754`*^9}, {
  3.835018846742407*^9, 3.835018849961266*^9}, {3.835044361707146*^9, 
  3.835044363446494*^9}},
 CellLabel->
  "In[248]:=",ExpressionUUID->"9c4692c7-138d-4aed-9469-974e1cb46585"],

Cell[BoxData["0.9060838435553892`"], "Output",
 CellChangeTimes->{3.8349481513130674`*^9, 3.8349482002632475`*^9, 
  3.8349499490044084`*^9, 3.8349578559445095`*^9, 3.83501892389968*^9, 
  3.8350190272812295`*^9, 3.8350205613687525`*^9, 3.8350446533657885`*^9},
 CellLabel->
  "Out[248]=",ExpressionUUID->"84c8beb6-6803-4988-a7b9-cfe88759e17a"]
}, Open  ]],

Cell["Absolute Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.8347951985065947`*^9}},ExpressionUUID->"12273fa0-27a4-45bc-9b18-\
689582521376"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a\[Rho]3if1", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"AMDi3f100", ",", "krif1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.8348873709111376`*^9, 
   3.8348873755217657`*^9}, {3.8349481641806583`*^9, 
   3.8349481824982553`*^9}, {3.834949818653184*^9, 3.8349498238056817`*^9}, {
   3.834957866337153*^9, 3.834957872254816*^9}, {3.8350188531986103`*^9, 
   3.8350188546829796`*^9}, {3.8350443646261296`*^9, 3.835044365855239*^9}},
 CellLabel->
  "In[249]:=",ExpressionUUID->"2f1de749-fd40-43eb-8746-03cfab3497b6"],

Cell[BoxData["0.10810465643061204`"], "Output",
 CellChangeTimes->{3.834948182946122*^9, 3.83494995054953*^9, 
  3.834957874365346*^9, 3.835018924320698*^9, 3.8350190275072393`*^9, 
  3.8350205614078007`*^9, 3.835044655427159*^9},
 CellLabel->
  "Out[249]=",ExpressionUUID->"b25df181-741b-48a4-a3c8-b6c1d7576d79"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"aP3if1", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"AMDi3f100", ",", "krif1"}], "}"}], "]"}], ",", "a\[Rho]3if1"}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8349482041094093`*^9, 
  3.8349482202691827`*^9}, {3.8349498269490285`*^9, 3.8349498405604887`*^9}, {
  3.8349578796796703`*^9, 3.834957886620027*^9}, {3.8350188593392305`*^9, 
  3.835018861313801*^9}, {3.8350443665470304`*^9, 3.835044368736087*^9}},
 CellLabel->
  "In[250]:=",ExpressionUUID->"d4bc1470-3e2f-413b-8421-e0c125a43e68"],

Cell[BoxData["0.5536763691616662`"], "Output",
 CellChangeTimes->{3.834887440036944*^9, 3.8349482220989213`*^9, 
  3.8349499520491343`*^9, 3.8349578874036503`*^9, 3.83501892439668*^9, 
  3.8350190277232385`*^9, 3.8350205614517555`*^9, 3.8350446570245705`*^9},
 CellLabel->
  "Out[250]=",ExpressionUUID->"10e9f0be-2cb9-4eb6-8c13-404dabe3b4df"]
}, Open  ]],

Cell["Max-min Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 3.8347951985065947`*^9}, {
  3.8348543263190746`*^9, 
  3.834854330052075*^9}},ExpressionUUID->"03e86a48-2a10-4672-b467-\
f4078ce3a9b1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mM\[Rho]3if1", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"mMDi3f100", ",", "krif1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8348874651734295`*^9, 3.8348874872060013`*^9}, {
  3.8349482319487157`*^9, 3.834948245258479*^9}, {3.834949844516972*^9, 
  3.8349498489188633`*^9}, {3.834957895209076*^9, 3.834957899999796*^9}, {
  3.83501886583329*^9, 3.835018866821826*^9}, {3.835044369483486*^9, 
  3.835044370515362*^9}},
 CellLabel->
  "In[251]:=",ExpressionUUID->"e26434b5-9337-443a-a486-70c1d4563738"],

Cell[BoxData["0.036091074307452814`"], "Output",
 CellChangeTimes->{3.834948246413353*^9, 3.834949953689977*^9, 
  3.834957900696502*^9, 3.835018924463678*^9, 3.835019027994238*^9, 
  3.835020561490786*^9, 3.8350446585457473`*^9},
 CellLabel->
  "Out[251]=",ExpressionUUID->"1a86551f-417d-4233-b818-cc1e72e466ea"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mMP3if1", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"mMDi3f100", ",", "krif1"}], "}"}], "]"}], ",", 
    "mM\[Rho]3if1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8348875260806427`*^9, 
  3.8348875488478312`*^9}, {3.8349482525846663`*^9, 3.8349482707073736`*^9}, {
  3.8349498532537427`*^9, 3.834949860995207*^9}, {3.834957902898573*^9, 
  3.8349579090270967`*^9}, {3.8350188699780455`*^9, 3.835018871634328*^9}, {
  3.835044378315168*^9, 3.8350443808084726`*^9}},
 CellLabel->
  "In[252]:=",ExpressionUUID->"4598ee76-d098-42a2-8f90-fba06843f192"],

Cell[BoxData["0.3080545440513896`"], "Output",
 CellChangeTimes->{3.834887440036944*^9, 3.8348875533996215`*^9, 
  3.834948277702903*^9, 3.834949955989804*^9, 3.834957909480212*^9, 
  3.835018924542716*^9, 3.835019028341303*^9, 3.8350205615287514`*^9, 
  3.835044659514542*^9},
 CellLabel->
  "Out[252]=",ExpressionUUID->"dd2d7bf0-fba7-46b8-9ba0-4d6bd9344b6e"]
}, Open  ]],

Cell["r = 6 :", "Text",
 CellChangeTimes->{{3.834793779215767*^9, 3.8347938725231647`*^9}, {
  3.8347953347101345`*^9, 3.8347953431477337`*^9}, {3.8348851911359825`*^9, 
  3.83488519180678*^9}, {3.834948305866973*^9, 3.8349483068980722`*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"c8c03353-05ea-42fc-b7ab-bd9ff0286ca4"],

Cell["Cubic Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.834795179278664*^9}},ExpressionUUID->"f81a93a5-b160-4612-bb0d-\
a5fc29bd2410"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c\[Rho]6if1", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"CMDi6f100", ",", "krif1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.834947911760502*^9, 
   3.834947914304406*^9}, {3.834947957535968*^9, 3.8349479704802837`*^9}, {
   3.8349480487781425`*^9, 3.834948105065866*^9}, {3.8349483158342133`*^9, 
   3.8349483193845987`*^9}, {3.834949864783629*^9, 3.834949869574106*^9}, {
   3.834957963470776*^9, 3.834957967378231*^9}, {3.835018875109179*^9, 
   3.8350188762029247`*^9}, {3.83504438203627*^9, 3.8350443836235657`*^9}},
 CellLabel->
  "In[253]:=",ExpressionUUID->"0e72c27e-71cb-4889-a853-d2448803fded"],

Cell[BoxData["0.03169702126033092`"], "Output",
 CellChangeTimes->{
  3.834948013482303*^9, {3.834948049945756*^9, 3.834948058990469*^9}, 
   3.8349481059508953`*^9, 3.834948360850016*^9, 3.8349499580565577`*^9, 
   3.834957967763415*^9, 3.835018924610717*^9, 3.835019028526283*^9, 
   3.8350205615657897`*^9, 3.835044661527397*^9},
 CellLabel->
  "Out[253]=",ExpressionUUID->"4c0e8fa5-c04d-4acf-84d5-22206acb7369"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CP6if1", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"CMDi6f100", ",", "krif1"}], "}"}], "]"}], ",", "c\[Rho]6if1"}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.8349481210775223`*^9, 3.834948150679065*^9}, {
  3.8349481924167476`*^9, 3.8349481986802473`*^9}, {3.8349483230197706`*^9, 
  3.834948338654296*^9}, {3.8349498724373255`*^9, 3.8349498802583637`*^9}, {
  3.8349579696959915`*^9, 3.834957975592292*^9}, {3.8350188769841766`*^9, 
  3.835018878671647*^9}, {3.835044384544117*^9, 3.8350443867509155`*^9}},
 CellLabel->
  "In[254]:=",ExpressionUUID->"b3c79e45-2f94-46aa-ac74-1a28fec009fd"],

Cell[BoxData["0.9612801100230032`"], "Output",
 CellChangeTimes->{3.8350446625455046`*^9},
 CellLabel->
  "Out[254]=",ExpressionUUID->"f4c2e7d7-8306-451b-958e-92211254ac90"]
}, Open  ]],

Cell["Absolute Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.8347951985065947`*^9}},ExpressionUUID->"cff59d8e-1843-414a-ac02-\
b8d1d3e2dd22"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a\[Rho]6if1", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"AMDi6f100", ",", "krif1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.8348873709111376`*^9, 
   3.8348873755217657`*^9}, {3.8349481641806583`*^9, 
   3.8349481824982553`*^9}, {3.834948329127375*^9, 3.834948332212267*^9}, {
   3.834949883458797*^9, 3.8349498875077024`*^9}, {3.834957978394422*^9, 
   3.8349579827581863`*^9}, {3.8350188795779624`*^9, 3.83501888042175*^9}, {
   3.8350443900912123`*^9, 3.835044391591655*^9}},
 CellLabel->
  "In[255]:=",ExpressionUUID->"397d9cd1-759a-468a-b7fb-1cf0acbca9f7"],

Cell[BoxData["0.0504464955105306`"], "Output",
 CellChangeTimes->{3.8350446642338314`*^9},
 CellLabel->
  "Out[255]=",ExpressionUUID->"dc9951e3-91f4-4697-839b-55c0ff8f5d01"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"aP6if1", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"AMDi6f100", ",", "krif1"}], "}"}], "]"}], ",", "a\[Rho]6if1"}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8349482041094093`*^9, 
  3.8349482202691827`*^9}, {3.834948340881687*^9, 3.834948354997751*^9}, {
  3.8349498907390194`*^9, 3.8349498979971194`*^9}, {3.8349579853563895`*^9, 
  3.8349579919125147`*^9}, {3.8350188832810483`*^9, 3.83501888448921*^9}, {
  3.835044392264258*^9, 3.835044393785404*^9}},
 CellLabel->
  "In[256]:=",ExpressionUUID->"ab9e04a0-5df4-4262-99ec-d2223749d612"],

Cell[BoxData["0.9009103999917715`"], "Output",
 CellChangeTimes->{3.835044665314339*^9},
 CellLabel->
  "Out[256]=",ExpressionUUID->"b111e924-82ad-4f18-9b29-3563867101dc"]
}, Open  ]],

Cell["Max-min Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 3.8347951985065947`*^9}, {
  3.8348543263190746`*^9, 
  3.834854330052075*^9}},ExpressionUUID->"09e10526-35f8-4601-b88a-\
e8562e6b8407"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mM\[Rho]6if1", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"mMDi6f100", ",", "krif1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8348874651734295`*^9, 3.8348874872060013`*^9}, {
   3.8349482319487157`*^9, 3.834948245258479*^9}, 3.8349483527075925`*^9, {
   3.8349499042423377`*^9, 3.8349499090679235`*^9}, {3.834949978751977*^9, 
   3.8349499794842105`*^9}, {3.834957994342047*^9, 3.834957998175455*^9}, {
   3.835018886286111*^9, 3.8350188870361056`*^9}, {3.835044395189496*^9, 
   3.835044396222158*^9}},
 CellLabel->
  "In[257]:=",ExpressionUUID->"e686cbe5-2306-4a09-a294-2de1879f4970"],

Cell[BoxData["0.037220690515887514`"], "Output",
 CellChangeTimes->{3.835044666861985*^9},
 CellLabel->
  "Out[257]=",ExpressionUUID->"b06066e8-7bf7-46fb-b629-419d2a8c3c9b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mMP6if1", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"mMDi6f100", ",", "krif1"}], "}"}], "]"}], ",", 
    "mM\[Rho]6if1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8348875260806427`*^9, 
  3.8348875488478312`*^9}, {3.8349482525846663`*^9, 3.8349482707073736`*^9}, {
  3.83494834565068*^9, 3.8349483504716325`*^9}, {3.8349499122654495`*^9, 
  3.83494991854418*^9}, {3.834958000997678*^9, 3.8349580074869604`*^9}, {
  3.8350188877705455`*^9, 3.8350189082569094`*^9}, {3.8350443974385123`*^9, 
  3.8350443985852137`*^9}},
 CellLabel->
  "In[258]:=",ExpressionUUID->"650d1bef-a4bd-4d11-9a32-ad935e05b661"],

Cell[BoxData["0.8140705882227636`"], "Output",
 CellChangeTimes->{
  3.834887440036944*^9, 3.8348875533996215`*^9, 3.834948277702903*^9, 
   3.8349483617580156`*^9, {3.834949965578516*^9, 3.8349499927811513`*^9}, 
   3.834958007945059*^9, 3.8350189249776793`*^9, 3.835019029685795*^9, 
   3.835020561757756*^9, 3.835044668294428*^9},
 CellLabel->
  "Out[258]=",ExpressionUUID->"7106b89b-b412-4c24-a2c6-f0e8b6418ee4"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2nd imported file", "Subsubsection",
 CellChangeTimes->{{3.834947473073307*^9, 3.8349474798089457`*^9}, {
   3.8349497159535103`*^9, 3.8349497173354855`*^9}, {3.834956622993673*^9, 
   3.834956623710862*^9}, {3.8350187834860272`*^9, 3.835018783813758*^9}, {
   3.835044179773861*^9, 3.8350441837622757`*^9}, {3.8350447472475395`*^9, 
   3.8350447488425937`*^9}, 3.8352016910114775`*^9},
 Background->RGBColor[
  1, 1, 0],ExpressionUUID->"90786880-b2cf-4e40-a278-d6cbfabc00f1"],

Cell["Dividing stuff", "Text",
 CellChangeTimes->{{3.83494752022309*^9, 
  3.834947523245259*^9}},ExpressionUUID->"efc4fdec-8a2f-465a-9098-\
f176786ad0c2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dataf2", "=", 
   RowBox[{"StringSplit", "[", 
    RowBox[{
     RowBox[{"Import", "[", "\"\<ariadnaComputationf2.txt\>\"", "]"}], ",", 
     "\"\<]\n{\>\""}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8349434033501863`*^9, 3.834943479535334*^9}, {
   3.834943567297134*^9, 3.8349435736474867`*^9}, {3.8349441109152327`*^9, 
   3.8349441401892223`*^9}, 3.834944204627252*^9, {3.834949720382628*^9, 
   3.8349497230261507`*^9}, {3.834956627593688*^9, 3.834956631231691*^9}, {
   3.8350187858989725`*^9, 3.8350187908769827`*^9}, {3.835044188339929*^9, 
   3.835044192375786*^9}, {3.835044770661966*^9, 3.8350447715129805`*^9}},
 CellLabel->
  "In[259]:=",ExpressionUUID->"dbd1cadb-cd16-4a84-87f4-62fa2f8a3f0a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"graphif2", "=", 
   RowBox[{"ToExpression", "@", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
      "dataf2", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "<>", 
      "\"\<]\>\""}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834944474381714*^9, 3.83494454689666*^9}, 
   3.8349475108233376`*^9, {3.834949726505718*^9, 3.8349497324197383`*^9}, {
   3.8349566345564103`*^9, 3.834956636582815*^9}, {3.8350188037132354`*^9, 
   3.8350188065525265`*^9}, {3.835044199446479*^9, 3.8350442063533845`*^9}, {
   3.8350447722871337`*^9, 3.835044772707575*^9}},
 CellLabel->
  "In[260]:=",ExpressionUUID->"50bde2a6-8cda-435e-bc95-1878f05db12f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"otherif2", "=", 
   RowBox[{"ToExpression", "@", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "<>", "\"\<}}\>\""}], "&"}], ",", 
      RowBox[{"StringSplit", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\"\<{\>\"", "<>", 
          RowBox[{
          "dataf2", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
         ")"}], ",", "\"\<}}\>\""}], "]"}]}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834944518155362*^9, 3.8349445533517303`*^9}, 
   3.8349446259294133`*^9, {3.8349447635371876`*^9, 3.8349447780382657`*^9}, {
   3.834944820013957*^9, 3.8349448816359477`*^9}, {3.834944915595456*^9, 
   3.834944918286141*^9}, {3.8349449615053425`*^9, 3.834944967406804*^9}, {
   3.834945029266304*^9, 3.834945031628281*^9}, {3.834945108799203*^9, 
   3.8349451822852197`*^9}, 3.834945584171259*^9, {3.834949734758335*^9, 
   3.8349497379503355`*^9}, {3.834956638769047*^9, 3.8349566423540664`*^9}, {
   3.8350188094708586`*^9, 3.8350188125204616`*^9}, {3.8350442096862793`*^9, 
   3.835044210497281*^9}, 3.8350442469097853`*^9, {3.835044779420373*^9, 
   3.835044781545072*^9}},
 CellLabel->
  "In[261]:=",ExpressionUUID->"ae403df9-126d-472f-a0fb-a326a83e894a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "CMDi3f200", "}"}], ",", 
     RowBox[{"{", "AMDi3f200", "}"}], ",", 
     RowBox[{"{", "mMDi3f200", "}"}], ",", 
     RowBox[{"{", "CMDi6f200", "}"}], ",", 
     RowBox[{"{", "AMDi6f200", "}"}], ",", 
     RowBox[{"{", "mMDi6f200", "}"}]}], "}"}], "=", "otherif2"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.834945694541313*^9, 3.834945753140644*^9}, {
  3.8349459487260857`*^9, 3.8349459670133495`*^9}, {3.8349471029719105`*^9, 
  3.8349471182020655`*^9}, {3.83494974203613*^9, 3.8349497544188104`*^9}, {
  3.834956647753375*^9, 3.8349566844693546`*^9}, {3.8350188134722548`*^9, 
  3.835018816812196*^9}, {3.835044228572632*^9, 3.835044233700058*^9}, {
  3.8350447829709044`*^9, 3.835044786739727*^9}},
 CellLabel->
  "In[262]:=",ExpressionUUID->"7b461e93-b132-478b-a5b7-d5c63deb1c9c"],

Cell["\[OpenCurlyDoubleQuote]Cleaning\[CloseCurlyDoubleQuote] the graph:", \
"Text",
 CellChangeTimes->{{3.8349477786156034`*^9, 
  3.8349478283202667`*^9}},ExpressionUUID->"0a736082-11b0-4409-9551-\
5faf25d8f263"],

Cell[BoxData[
 RowBox[{
  RowBox[{"graphinf2", "=", 
   RowBox[{"IndexGraph", "@", "graphif2"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834946654863307*^9, 3.834946693639777*^9}, {
  3.834949757637121*^9, 3.834949759707878*^9}, {3.8349566892836237`*^9, 
  3.834956691608691*^9}, {3.83501881773997*^9, 3.8350188182388163`*^9}, {
  3.8350442520120163`*^9, 3.8350442531771507`*^9}, {3.835044787881835*^9, 
  3.8350447894788456`*^9}},
 CellLabel->
  "In[263]:=",ExpressionUUID->"5edb92fe-eac4-4b7c-af70-cc6c9c185641"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pointsif2", "=", 
   RowBox[{"VertexList", "@", "graphinf2"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834784420352569*^9, 3.8347844264642625`*^9}, {
  3.8348756828269844`*^9, 3.8348756865131674`*^9}, {3.834878831782991*^9, 
  3.8348788488376627`*^9}, {3.8349467020325813`*^9, 3.834946739879963*^9}, {
  3.8349497621629615`*^9, 3.8349497641865125`*^9}, {3.834956695197647*^9, 
  3.834956697830969*^9}, {3.835018818796376*^9, 3.8350188192932053`*^9}, {
  3.835044292816033*^9, 3.8350442934580317`*^9}, {3.835044790599271*^9, 
  3.835044791093337*^9}},
 CellLabel->
  "In[264]:=",ExpressionUUID->"011f2fea-0841-4d51-bc73-e24c715cb0b0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"coordpointsif2", "=", 
   RowBox[{"VertexList", "@", "graphif2"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834879134322084*^9, 3.834879146224797*^9}, {
  3.834946724882841*^9, 3.834946736706849*^9}, {3.834949767417904*^9, 
  3.8349497706963253`*^9}, {3.8349567000470257`*^9, 3.8349567019660654`*^9}, {
  3.835018819834511*^9, 3.835018820572505*^9}, {3.835044294376539*^9, 
  3.8350442977248926`*^9}, {3.835044791824248*^9, 3.8350447923863506`*^9}},
 CellLabel->
  "In[265]:=",ExpressionUUID->"debe8563-9192-4996-9b85-e8ef150a7fc9"],

Cell["Kretchmann \[OpenCurlyDoubleQuote]real\[CloseCurlyDoubleQuote] \
values:", "Text",
 CellChangeTimes->{
  3.8347933561184683`*^9, {3.8347935444076195`*^9, 
   3.834793546974228*^9}},ExpressionUUID->"4b0bd60c-12d4-40dd-b89d-\
27a2d2c09205"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rvalif2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1"}], "+", "r"}]]}], "\[Equal]", "#"}], ",", 
       RowBox[{"{", "r", "}"}]}], "]"}], "&"}], "/@", 
    RowBox[{"coordpointsif2", "\[LeftDoubleBracket]", 
     RowBox[{";;", ",", "3"}], "\[RightDoubleBracket]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834105426841242*^9, 3.8341054487325706`*^9}, {
   3.8341407674337025`*^9, 3.834140799285215*^9}, {3.8341408938375945`*^9, 
   3.834140946496229*^9}, {3.8341410168099756`*^9, 3.8341410671886864`*^9}, {
   3.8341411610986195`*^9, 3.834141210381962*^9}, {3.834141332672348*^9, 
   3.834141336755044*^9}, {3.834141461053176*^9, 3.834141468978607*^9}, {
   3.834141967115094*^9, 3.8341420256686225`*^9}, {3.8341640069512*^9, 
   3.834164012603241*^9}, {3.834164792400744*^9, 3.8341647947633886`*^9}, {
   3.83466546628111*^9, 3.834665483801684*^9}, {3.8347933895124626`*^9, 
   3.834793417249506*^9}, 3.8347960586942053`*^9, 3.834879156483405*^9, {
   3.8348862453609915`*^9, 3.8348862641404076`*^9}, 3.834886374221485*^9, {
   3.834946768449996*^9, 3.8349467823353415`*^9}, {3.8349468446168528`*^9, 
   3.834946857637892*^9}, 3.8349474594107084`*^9, {3.834949773350379*^9, 
   3.8349497766098785`*^9}, {3.8349567056279964`*^9, 
   3.8349567091770997`*^9}, {3.8350188215027976`*^9, 3.835018822410869*^9}, {
   3.835044298874358*^9, 3.8350443004592457`*^9}, 3.8350444868602533`*^9, {
   3.835044793477209*^9, 3.8350448005204644`*^9}},
 CellLabel->
  "In[266]:=",ExpressionUUID->"565b3db8-6c2d-46e2-9bd3-46d406e78722"],

Cell[BoxData[
 RowBox[{
  RowBox[{"krif2", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"KHFlamm", "/.", "rvalif2"}], ")"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834792366597866*^9, 3.834792376019791*^9}, {
   3.834793346399704*^9, 3.8347933590872536`*^9}, {3.834793445378667*^9, 
   3.8347934527754736`*^9}, {3.834793487784485*^9, 3.834793489659489*^9}, 
   3.8348550102643666`*^9, {3.8348863808528233`*^9, 3.83488645374378*^9}, {
   3.834886485165092*^9, 3.834886521271514*^9}, 3.8348865820814276`*^9, {
   3.83494679091998*^9, 3.8349467979310513`*^9}, {3.8349468742957215`*^9, 
   3.834946904080855*^9}, 3.8349474644429636`*^9, {3.834949779141443*^9, 
   3.834949781745859*^9}, {3.8349567110647635`*^9, 3.8349567138998594`*^9}, {
   3.8350188233356256`*^9, 3.8350188239955263`*^9}, {3.8350443047283278`*^9, 
   3.8350443056932993`*^9}, {3.835044525959175*^9, 3.835044526610751*^9}, {
   3.8350448048490252`*^9, 3.835044806579857*^9}},
 CellLabel->
  "In[267]:=",ExpressionUUID->"6769742d-9fc3-4ece-ab57-a35cde633ffd"],

Cell["Estimated with cubic Mean Deviation v Calculated: (r=3)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 
  3.8349503319477153`*^9}},ExpressionUUID->"f03f2fae-2ced-4eac-acae-\
bad5dd92775c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraphb", "[", 
     RowBox[{"graphinf2", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsif2", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}],
      "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"CMDi3f200", ",", "krif2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349567344957485`*^9, 3.834956749729442*^9}, {
   3.8349587420893497`*^9, 3.834958755264699*^9}, {3.835018825281867*^9, 
   3.835018828052806*^9}, {3.835044306768691*^9, 3.8350443152608557`*^9}, {
   3.8350445713666224`*^9, 3.835044576386869*^9}, {3.8350448259670086`*^9, 
   3.8350448323754845`*^9}, 3.8350516006437707`*^9},
 Background->RGBColor[1, 1, 0.85],
 CellLabel->
  "In[393]:=",ExpressionUUID->"b2feeb9c-5af5-4766-af61-faa0067bd900"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
          103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
          129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 
          142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 
          155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 
          168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 
          181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 
          194, 195, 196, 197, 198, 199, 200}, {Null, CompressedData["
1:eJwVxfk/GgwDAPA5ylXk6qBcTS9j5XjImZDN1UpNhz0LEUrEK0VRaK6QloU8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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[31, 80] -> 
             RGBColor[
              0.7060099970079379, 0.7645728181800082, 0.8644505837647853], 
             UndirectedEdge[36, 132] -> 
             RGBColor[
              0.7746095643140181, 0.8234587568633209, 0.9544892326994316], 
             UndirectedEdge[16, 101] -> 
             RGBColor[
              0.7293958937310011, 0.7883032847315528, 0.9738972636539306], 
             UndirectedEdge[86, 108] -> 
             RGBColor[
              0.6155106876294636, 0.6976901963953226, 0.963591017523529], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.304929102154823, 0.43430520788309035`, 0.9408057004832425], 
             UndirectedEdge[29, 136] -> 
             RGBColor[
              0.533705420333172, 0.615750682993256, 0.9604399031542156], 
             UndirectedEdge[55, 157] -> 
             RGBColor[
              0.536413816402582, 0.6312283372165055, 0.9579512905672762], 
             UndirectedEdge[7, 188] -> 
             RGBColor[
              0.39253472456736904`, 0.5059601253972593, 0.9471183451544185], 
             UndirectedEdge[19, 141] -> 
             RGBColor[
              0.2781481340314168, 0.40422506158431515`, 0.9393512911653399], 
             UndirectedEdge[62, 185] -> 
             RGBColor[
              0.584799478124786, 0.6617750001400082, 0.964512916049221], 
             UndirectedEdge[79, 144] -> 
             RGBColor[
              0.476772187734384, 0.5766742023728583, 0.95392809350238], 
             UndirectedEdge[47, 54] -> 
             RGBColor[
              0.46504745431516925`, 0.5717302619542061, 0.9521986376535785], 
             UndirectedEdge[32, 101] -> 
             RGBColor[
              0.4387895420407105, 0.5458028797222704, 0.9505511518663368], 
             UndirectedEdge[104, 163] -> 
             RGBColor[
              0.938202351719447, 0.9490791599163446, 0.7687745561727487], 
             UndirectedEdge[119, 125] -> 
             RGBColor[
              0.3354514153077125, 0.4630091962653788, 0.9426675458403294], 
             UndirectedEdge[9, 140] -> 
             RGBColor[
              0.5598586383709514, 0.6354480041177802, 0.9631096290502377], 
             UndirectedEdge[3, 63] -> 
             RGBColor[
              0.7663259816895718, 0.8169656972696406, 0.960057691192198], 
             UndirectedEdge[50, 104] -> 
             RGBColor[
              0.668618290682433, 0.7386781819735789, 0.9694384786142771], 
             UndirectedEdge[47, 61] -> 
             RGBColor[
              0.39217001335301216`, 0.5125650722898254, 0.9464614585421749], 
             UndirectedEdge[149, 195] -> 
             RGBColor[
              0.8458914293359808, 0.8799548809140758, 0.9851630737379011], 
             UndirectedEdge[99, 178] -> 
             RGBColor[
              0.33082849105857676`, 0.45124645566861, 0.9426809425196518], 
             UndirectedEdge[160, 174] -> 
             RGBColor[
              0.9858764800278226, 0.980603929344382, 0.6629163496862881], 
             UndirectedEdge[6, 124] -> 
             RGBColor[
              0.6725239958148274, 0.7422622336579585, 0.9692703364298605], 
             UndirectedEdge[24, 197] -> 
             RGBColor[
              0.8491579978695571, 0.8826653385313545, 0.9672351822783671], 
             UndirectedEdge[80, 120] -> 
             RGBColor[
              0.5398813580171884, 0.6361652296903697, 0.9573538979438538], 
             UndirectedEdge[83, 187] -> 
             RGBColor[
              0.5255028480577316, 0.6248029644359483, 0.956027090517916], 
             UndirectedEdge[47, 167] -> 
             RGBColor[
              0.5090643639328692, 0.606319375680241, 0.9564471973022755], 
             UndirectedEdge[132, 150] -> 
             RGBColor[
              0.5474090746349495, 0.6434503731432597, 0.9575131940622262], 
             UndirectedEdge[17, 189] -> 
             RGBColor[
              0.7226696293411441, 0.7821963486222077, 0.9741115712932545], 
             UndirectedEdge[69, 180] -> 
             RGBColor[
              0.59738524307587, 0.6837181088934665, 0.961656146953108], 
             UndirectedEdge[43, 95] -> 
             RGBColor[
              0.6139649678103271, 0.6915621723131897, 0.9658595950499089], 
             UndirectedEdge[82, 86] -> 
             RGBColor[
              0.7337434964322795, 0.7919252631607936, 0.9740963525676964], 
             UndirectedEdge[7, 61] -> 
             RGBColor[
              0.512580398246149, 0.6151748846368406, 0.9547713530752545], 
             UndirectedEdge[30, 65] -> 
             RGBColor[
              0.5173276838724596, 0.6042020552413041, 0.9586279902475696], 
             UndirectedEdge[62, 174] -> 
             RGBColor[
              0.6288142700011037, 0.6871134247650981, 0.6751837280498462], 
             UndirectedEdge[18, 47] -> 
             RGBColor[
              0.3605510579849325, 0.4859942344644095, 0.9442212877215592], 
             UndirectedEdge[56, 149] -> 
             RGBColor[
              0.6494413947564551, 0.7224979019330259, 0.9680244452587013], 
             UndirectedEdge[82, 163] -> 
             RGBColor[
              0.8751719092802234, 0.8993318466771009, 0.7626269330291704], 
             UndirectedEdge[10, 48] -> 
             RGBColor[
              0.31766386787321743`, 0.44578484467130103`, 0.9416006929239816],
              UndirectedEdge[58, 92] -> 
             RGBColor[
              0.4460025999625946, 0.5466110390748137, 0.9518152296385956], 
             UndirectedEdge[70, 72] -> 
             RGBColor[
              0.3068872930609914, 0.43739996655956526`, 0.940879262437793], 
             UndirectedEdge[35, 181] -> 
             RGBColor[
              0.4717654212370541, 0.5816467749456025, 0.9516667452012513], 
             UndirectedEdge[126, 174] -> 
             RGBColor[
              0.7322633448629401, 0.7798216348368993, 0.6818062445475817], 
             UndirectedEdge[108, 154] -> 
             RGBColor[
              0.48861433898670914`, 0.5957181580713613, 0.9528846570997836], 
             UndirectedEdge[63, 77] -> 
             RGBColor[
              0.42571496736118997`, 0.5366021011231958, 0.9493931851238637], 
             UndirectedEdge[32, 100] -> 
             RGBColor[
              0.25699609032299064`, 0.3874495637956803, 0.937946919201025], 
             UndirectedEdge[19, 50] -> 
             RGBColor[
              0.41111686187447705`, 0.5304792302717807, 0.9474256194013251], 
             UndirectedEdge[80, 81] -> 
             RGBColor[
              0.37749165740303653`, 0.5013860331853031, 0.9452744125003236], 
             UndirectedEdge[34, 163] -> 
             RGBColor[
              0.9230350291958236, 0.9369851486420095, 0.7673278834104169], 
             UndirectedEdge[146, 194] -> 
             RGBColor[
              0.7398106799109465, 0.7966436716911294, 0.9748492929610316], 
             UndirectedEdge[13, 83] -> 
             RGBColor[
              0.4111438017329291, 0.530533829197902, 0.9474186973796015], 
             UndirectedEdge[30, 41] -> 
             RGBColor[
              0.8519711342495158, 0.8849866809799397, 0.9856941312491454], 
             UndirectedEdge[35, 111] -> 
             RGBColor[
              0.7449763785375807, 0.79846839261966, 0.9238963981502963], 
             UndirectedEdge[29, 144] -> 
             RGBColor[
              0.45614835096765716`, 0.5549972423042524, 0.9527535965087471], 
             UndirectedEdge[6, 12] -> 
             RGBColor[
              0.909184174502621, 0.9253167834302884, 0.7154176680008075], 
             UndirectedEdge[67, 143] -> 
             RGBColor[
              0.32295407546577926`, 0.4521846286288605, 0.9418712263965652], 
             UndirectedEdge[135, 163] -> 
             RGBColor[
              0.931109097391084, 0.9434231914561675, 0.7680979952426865], 
             UndirectedEdge[50, 60] -> 
             RGBColor[
              0.5230706914530363, 0.6236913772445151, 0.9555971873837108], 
             UndirectedEdge[25, 143] -> 
             RGBColor[
              0.3971509062176437, 0.51841388640594, 0.9465270824507992], 
             UndirectedEdge[12, 13] -> 
             RGBColor[
              0.6967292411136606, 0.7541710567663009, 0.6971791698344312], 
             UndirectedEdge[89, 144] -> 
             RGBColor[
              0.4697717745542883, 0.5693163242687465, 0.9535294303279567], 
             UndirectedEdge[22, 24] -> 
             RGBColor[
              0.8529048166250223, 0.8854597098243278, 0.9608927954522044], 
             UndirectedEdge[107, 156] -> 
             RGBColor[
              0.670482676146146, 0.7415494524168997, 0.9684447119967263], 
             UndirectedEdge[23, 154] -> 
             RGBColor[
              0.4022322525551427, 0.5227154423625359, 0.9468783951715645], 
             UndirectedEdge[101, 135] -> 
             RGBColor[
              0.7418647464305879, 0.798245609416213, 0.9750865539554934], 
             UndirectedEdge[7, 42] -> 
             RGBColor[
              0.6955881827825956, 0.7608151261675999, 0.9712836037457591], 
             UndirectedEdge[122, 192] -> 
             RGBColor[
              0.7777597903996395, 0.8263111265443196, 0.9784834853947092], 
             UndirectedEdge[129, 133] -> 
             RGBColor[
              0.4372815821175513, 0.5478535054220381, 0.9501343420209429], 
             UndirectedEdge[40, 80] -> 
             RGBColor[
              0.7027391334365509, 0.7632202320358801, 0.9186572578662473], 
             UndirectedEdge[41, 172] -> 
             RGBColor[
              0.6234159709735542, 0.698733623430648, 0.9669288497895498], 
             UndirectedEdge[94, 115] -> 
             RGBColor[
              0.30568170495235014`, 0.431176335787152, 0.9409920870363234], 
             UndirectedEdge[87, 103] -> 
             RGBColor[
              0.5627260191593313, 0.6514563339074573, 0.9607123722509445], 
             UndirectedEdge[142, 160] -> 
             RGBColor[
              0.5808412105301699, 0.6460268008894918, 0.9237878767125249], 
             UndirectedEdge[21, 150] -> 
             RGBColor[
              0.4590891715051717, 0.5705743995395929, 0.9508846791318044], 
             UndirectedEdge[29, 142] -> 
             RGBColor[
              0.202953225093626, 0.33064708592405645`, 0.9348692579754672], 
             UndirectedEdge[67, 103] -> 
             RGBColor[
              0.32364054435350054`, 0.4527792134764751, 0.9419149675870702], 
             UndirectedEdge[50, 163] -> 
             RGBColor[
              0.7240535260509111, 0.7783987891139552, 0.7495327251023209], 
             UndirectedEdge[21, 46] -> 
             RGBColor[
              0.3575366863743365, 0.4837546905992475, 0.9440156175639738], 
             UndirectedEdge[43, 129] -> 
             RGBColor[
              0.5835159343385697, 0.663437971908318, 0.9639835141219889], 
             UndirectedEdge[11, 112] -> 
             RGBColor[
              0.29984945450106104`, 0.4245136220991934, 0.9406794518784954], 
             UndirectedEdge[119, 195] -> 
             RGBColor[
              0.6020001600817957, 0.6831458469742973, 0.9642009017556773], 
             UndirectedEdge[99, 109] -> 
             RGBColor[
              0.23795407175645295`, 0.3674351949485398, 0.9368625044138028], 
             UndirectedEdge[45, 120] -> 
             RGBColor[
              0.7987649922002842, 0.8436202717966593, 0.9785288864410415], 
             UndirectedEdge[29, 153] -> 
             RGBColor[
              0.24068455834584462`, 0.37030510947683937`, 0.9370180015856757],
              UndirectedEdge[27, 125] -> 
             RGBColor[
              0.2530918721759441, 0.38334598298140654`, 0.9377245797533239], 
             UndirectedEdge[35, 157] -> 
             RGBColor[
              0.43607755540166093`, 0.5507357392832767, 0.9493927459477607], 
             UndirectedEdge[28, 112] -> 
             RGBColor[
              0.5254178099271112, 0.623808232451538, 0.9563600869535931], 
             UndirectedEdge[22, 89] -> 
             RGBColor[
              0.6088167621868994, 0.6783840430577753, 0.9423076913594339], 
             UndirectedEdge[96, 116] -> 
             RGBColor[
              0.32195421347522446`, 0.44861081946698345`, 0.9419066611267857],
              UndirectedEdge[23, 143] -> 
             RGBColor[
              0.35293880437256564`, 0.4801195859525844, 0.9437099264164573], 
             UndirectedEdge[6, 14] -> 
             RGBColor[
              0.7421102920344216, 0.7985073537619717, 0.9749180997515294], 
             UndirectedEdge[9, 112] -> 
             RGBColor[
              0.6484427898114312, 0.7205780193334652, 0.9684464624096651], 
             UndirectedEdge[12, 25] -> 
             RGBColor[
              0.7143039220464362, 0.7693933620611236, 0.6982990129627875], 
             UndirectedEdge[176, 199] -> 
             RGBColor[
              0.42638413733154173`, 0.5418747025499597, 0.9489035943481191], 
             UndirectedEdge[48, 112] -> 
             RGBColor[
              0.33143864550918245`, 0.4577158647191193, 0.9424784095743877], 
             UndirectedEdge[79, 149] -> 
             RGBColor[
              0.5697027548271585, 0.6496860528470996, 0.9630807380851578], 
             UndirectedEdge[58, 155] -> 
             RGBColor[
              0.2339398720148713, 0.36321601650517377`, 0.936633901676996], 
             UndirectedEdge[118, 138] -> 
             RGBColor[
              0.6583733220825505, 0.7247927961315606, 0.9158303075979171], 
             UndirectedEdge[172, 173] -> 
             RGBColor[
              0.6053446070601489, 0.6843240083802045, 0.9652051869669923], 
             UndirectedEdge[53, 104] -> 
             RGBColor[
              0.6861096764306236, 0.7528784769019083, 0.9708154645734319], 
             UndirectedEdge[179, 185] -> 
             RGBColor[
              0.5512792057770495, 0.6265430685945181, 0.9626039861278165], 
             UndirectedEdge[82, 176] -> 
             RGBColor[
              0.6392548187953211, 0.7162632321082789, 0.9659412427187377], 
             UndirectedEdge[142, 181] -> 
             RGBColor[
              0.30889158369517666`, 0.4299654437331829, 0.941342752407105], 
             UndirectedEdge[54, 160] -> 
             RGBColor[
              0.8059388595562795, 0.8482242254155741, 0.9390103558800418], 
             UndirectedEdge[121, 151] -> 
             RGBColor[
              0.7647377988492109, 0.8163957294765397, 0.9773697584527196], 
             UndirectedEdge[138, 144] -> 
             RGBColor[
              0.5082629184641261, 0.6076961375205571, 0.9557974865656786], 
             UndirectedEdge[171, 196] -> 
             RGBColor[
              0.7162359277879733, 0.7775351384988411, 0.9729582826603984], 
             UndirectedEdge[120, 172] -> 
             RGBColor[
              0.4999651344516954, 0.6015918030856704, 0.9548104714747913], 
             UndirectedEdge[113, 159] -> 
             RGBColor[
              0.35212328685843197`, 0.4737600591462641, 0.9438816867056619], 
             UndirectedEdge[103, 108] -> 
             RGBColor[
              0.4400073596918533, 0.5537168865090245, 0.9497599295351815], 
             UndirectedEdge[64, 176] -> 
             RGBColor[
              0.7094868639069083, 0.7717529078361685, 0.9727757611541528], 
             UndirectedEdge[83, 101] -> 
             RGBColor[
              0.5183426029022146, 0.6189899548533311, 0.9554634097904314], 
             UndirectedEdge[15, 63] -> 
             RGBColor[
              0.5475868731258422, 0.6435947179678971, 0.9575271910107266], 
             UndirectedEdge[55, 72] -> 
             RGBColor[
              0.520503768390408, 0.6174478532906247, 0.9569375163766436], 
             UndirectedEdge[105, 142] -> 
             RGBColor[
              0.27671041496505955`, 0.40209173285172595`, 0.939292196792312], 
             UndirectedEdge[96, 105] -> 
             RGBColor[
              0.31635692978748764`, 0.44376273366432395`, 0.9415500071596867],
              UndirectedEdge[48, 63] -> 
             RGBColor[
              0.42251364476608844`, 0.5332373081001683, 0.949210874538005], 
             UndirectedEdge[64, 108] -> 
             RGBColor[
              0.7087054677812928, 0.7711185352598995, 0.9727142467887959], 
             UndirectedEdge[56, 119] -> 
             RGBColor[
              0.40555012550227, 0.5256888679932473, 0.9470622732764775], 
             UndirectedEdge[68, 157] -> 
             RGBColor[
              0.5027279304944753, 0.6048455163488042, 0.9546397076234356], 
             UndirectedEdge[137, 161] -> 
             RGBColor[
              0.8039832422986501, 0.8453353816659162, 0.8851725229444365], 
             UndirectedEdge[160, 188] -> 
             RGBColor[
              0.6130157449153426, 0.6798442765116122, 0.9256201688478023], 
             UndirectedEdge[127, 187] -> 
             RGBColor[
              0.41804614192638123`, 0.5222873889329851, 0.9495257612754475], 
             UndirectedEdge[41, 141] -> 
             RGBColor[
              0.54762809525884, 0.621975369888796, 0.9625066734938229], 
             UndirectedEdge[137, 175] -> 
             RGBColor[
              0.8664361047789204, 0.8945051576135106, 0.8911366632961364], 
             UndirectedEdge[1, 122] -> 
             RGBColor[
              0.6477584526758497, 0.7228443515057243, 0.9668311842859956], 
             UndirectedEdge[60, 177] -> 
             RGBColor[
              0.4418639831353846, 0.5518423729798455, 0.9504706295846521], 
             UndirectedEdge[72, 75] -> 
             RGBColor[
              0.3440990579398908, 0.47246304189117583`, 0.9431466655904481], 
             UndirectedEdge[13, 69] -> 
             RGBColor[
              0.46662072527130216`, 0.576435442040943, 0.9515476091622088], 
             UndirectedEdge[48, 77] -> 
             RGBColor[
              0.27104862262196944`, 0.40221966622391553`, 0.9387471901265934],
              UndirectedEdge[22, 183] -> 
             RGBColor[
              0.8951993681875081, 0.9185571740448601, 0.9650932908140569], 
             UndirectedEdge[16, 86] -> 
             RGBColor[
              0.7772118318435535, 0.8260742832551999, 0.9783781244796499], 
             UndirectedEdge[8, 62] -> 
             RGBColor[
              0.5464288316351475, 0.6311792881726231, 0.9608530895331588], 
             UndirectedEdge[26, 51] -> 
             RGBColor[
              0.6172310682767486, 0.6940345545863547, 0.9662318475374967], 
             UndirectedEdge[117, 121] -> 
             RGBColor[
              0.7220025332255146, 0.7823197886860871, 0.9732936306673095], 
             UndirectedEdge[89, 136] -> 
             RGBColor[
              0.5473288439198032, 0.63006976495775, 0.9612157369734251], 
             UndirectedEdge[81, 168] -> 
             RGBColor[
              0.3479586306646619, 0.4758060097976069, 0.9433925941515844], 
             UndirectedEdge[172, 198] -> 
             RGBColor[
              0.6626688572166416, 0.7285831006996069, 0.9186668825563536], 
             UndirectedEdge[55, 68] -> 
             RGBColor[
              0.6716613111774904, 0.7433590374235958, 0.9679544918834833], 
             UndirectedEdge[156, 192] -> 
             RGBColor[
              0.6788564993606718, 0.7480911467555009, 0.9692793364369232], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.4565118738689362, 0.5680732745868482, 0.9507947260471094], 
             UndirectedEdge[25, 154] -> 
             RGBColor[
              0.4464443544002208, 0.5610097428158916, 0.9496955512059062], 
             UndirectedEdge[100, 135] -> 
             RGBColor[
              0.5600712947128679, 0.639892293489623, 0.9624823212901816], 
             UndirectedEdge[37, 149] -> 
             RGBColor[
              0.5844849126503185, 0.6652230379621795, 0.963922560104944], 
             UndirectedEdge[125, 149] -> 
             RGBColor[
              0.5793426845618976, 0.6598182302051574, 0.9636297178225532], 
             UndirectedEdge[2, 184] -> 
             RGBColor[
              0.6653951629330277, 0.7279585482447807, 0.7744543139449456], 
             UndirectedEdge[6, 16] -> 
             RGBColor[
              0.834652025950676, 0.8709928857401112, 0.9840910494094768], 
             UndirectedEdge[55, 111] -> 
             RGBColor[
              0.8453126395385018, 0.8789609905528888, 0.9324549427698119], 
             UndirectedEdge[34, 50] -> 
             RGBColor[
              0.6534509681588097, 0.7265841706992439, 0.9679918058519453], 
             UndirectedEdge[56, 125] -> 
             RGBColor[
              0.3576056933847417, 0.48219811842930865`, 0.9440791968491389], 
             UndirectedEdge[98, 196] -> 
             RGBColor[
              0.6179989497532402, 0.6958103490719583, 0.9657694627421471], 
             UndirectedEdge[160, 167] -> 
             RGBColor[
              0.8499557691739795, 0.882813339141609, 0.9432589155287389], 
             UndirectedEdge[22, 149] -> 
             RGBColor[
              0.9172928064734477, 0.9361738820236621, 0.967200582680815], 
             UndirectedEdge[147, 194] -> 
             RGBColor[
              0.7414126047563112, 0.7979441864464882, 0.9749754023529027], 
             UndirectedEdge[83, 161] -> 
             RGBColor[
              0.5195078153394634, 0.6199359268021118, 0.9555551395818055], 
             UndirectedEdge[34, 177] -> 
             RGBColor[
              0.572244259841158, 0.6547351664345743, 0.9628652480528865], 
             UndirectedEdge[70, 145] -> 
             RGBColor[
              0.3832769450270144, 0.5026112086689032, 0.9460102356953903], 
             UndirectedEdge[125, 170] -> 
             RGBColor[
              0.39586378209886963`, 0.5139532275492577, 0.9468988535261018], 
             UndirectedEdge[190, 192] -> 
             RGBColor[
              0.47970399266470076`, 0.5672826374746115, 0.956069726710156], 
             UndirectedEdge[122, 188] -> 
             RGBColor[
              0.5105179295849924, 0.5996700388942802, 0.957824534832632], 
             UndirectedEdge[123, 130] -> 
             RGBColor[
              0.6640876805478197, 0.2508108563798329, 0.42414817643716063`], 
             UndirectedEdge[94, 116] -> 
             RGBColor[
              0.3874786678377304, 0.5100362796620952, 0.9459107759740557], 
             UndirectedEdge[23, 162] -> 
             RGBColor[
              0.527178407215033, 0.6231639743250604, 0.9573903784846969], 
             UndirectedEdge[116, 160] -> 
             RGBColor[
              0.6842219091829662, 0.7475726195438772, 0.9299357274719359], 
             UndirectedEdge[80, 117] -> 
             RGBColor[
              0.6304947869381454, 0.7071233925620726, 0.9663402150073388], 
             UndirectedEdge[147, 185] -> 
             RGBColor[
              0.762142288155326, 0.8144734732965968, 0.9769526180611077], 
             UndirectedEdge[55, 107] -> 
             RGBColor[
              0.7331796705280924, 0.7914847980792072, 0.9740401556708196], 
             UndirectedEdge[111, 174] -> 
             RGBColor[
              0.9871378104933559, 0.9813641898621305, 0.6527008783299132], 
             UndirectedEdge[126, 142] -> 
             RGBColor[
              0.3272280753652874, 0.4452445063820091, 0.9426777715738184], 
             UndirectedEdge[115, 160] -> 
             RGBColor[
              0.6024249462975861, 0.668712675668934, 0.9250170385342036], 
             UndirectedEdge[74, 164] -> 
             RGBColor[
              0.41405199305130275`, 0.5307345789216162, 0.9481472471220131], 
             UndirectedEdge[42, 97] -> 
             RGBColor[
              0.9189122096966348, 0.9361136015144932, 0.9133574898504107], 
             UndirectedEdge[25, 108] -> 
             RGBColor[
              0.4780706292804014, 0.5866853775110691, 0.9521852874153361], 
             UndirectedEdge[67, 133] -> 
             RGBColor[
              0.4361301572282011, 0.5466432848587766, 0.9500687700768748], 
             UndirectedEdge[38, 183] -> 
             RGBColor[
              0.5449889580825082, 0.6293151819878707, 0.9608242206806491], 
             UndirectedEdge[33, 41] -> 
             RGBColor[
              0.6163706286726707, 0.692631302038823, 0.9664799268080893], 
             UndirectedEdge[32, 123] -> 
             RGBColor[
              0.6323560663048293, 0.22047171882257627`, 0.4222307945487559], 
             UndirectedEdge[61, 116] -> 
             RGBColor[
              0.434527906716749, 0.549972053516087, 0.9491341508155244], 
             UndirectedEdge[93, 134] -> 
             RGBColor[
              0.27681292538421653`, 0.4082783139049413, 0.9390754586413815], 
             UndirectedEdge[45, 128] -> 
             RGBColor[
              0.8968108308342467, 0.9205048364261255, 0.9882241133779432], 
             UndirectedEdge[29, 35] -> 
             RGBColor[
              0.36582706263550346`, 0.4823284171364761, 0.9451932507696135], 
             UndirectedEdge[3, 106] -> 
             RGBColor[
              0.7390778784241445, 0.7948444595257034, 0.9579126206900526], 
             UndirectedEdge[77, 140] -> 
             RGBColor[
              0.24605581666380422`, 0.37595064252646193`, 0.9373238868008189],
              UndirectedEdge[79, 195] -> 
             RGBColor[
              0.5444157982295281, 0.6295229200523008, 0.9606688455909431], 
             UndirectedEdge[38, 46] -> 
             RGBColor[
              0.2839877611201045, 0.4158195211742196, 0.9394840549223221], 
             UndirectedEdge[14, 59] -> 
             RGBColor[
              0.5632651733841574, 0.6560748984230014, 0.9589311194188279], 
             UndirectedEdge[126, 191] -> 
             RGBColor[
              0.7305244919661522, 0.786687552958345, 0.9207459553364027], 
             UndirectedEdge[13, 64] -> 
             RGBColor[
              0.6489608022620289, 0.7211878147096069, 0.9684052977665621], 
             UndirectedEdge[3, 11] -> 
             RGBColor[
              0.5800704459422298, 0.6493810197504344, 0.9476127384990354], 
             UndirectedEdge[31, 98] -> 
             RGBColor[
              0.6863929097817639, 0.747581483208169, 0.8632006003134427], 
             UndirectedEdge[25, 162] -> 
             RGBColor[
              0.571390509060111, 0.6614582747784161, 0.9602075345190386], 
             UndirectedEdge[126, 157] -> 
             RGBColor[
              0.42150479322507084`, 0.5389049144528661, 0.9482455247274327], 
             UndirectedEdge[128, 183] -> 
             RGBColor[
              0.8414528473879215, 0.8764156761507905, 0.9847397178293262], 
             UndirectedEdge[22, 192] -> 
             RGBColor[
              0.870583508706462, 0.8992704384413847, 0.9626548422621117], 
             UndirectedEdge[99, 194] -> 
             RGBColor[
              0.5320887532276326, 0.6116316109602099, 0.9607144273394083], 
             UndirectedEdge[21, 151] -> 
             RGBColor[
              0.6683020772736208, 0.7369309688451078, 0.9701023365650208], 
             UndirectedEdge[48, 59] -> 
             RGBColor[
              0.3679091061663112, 0.48890688375843816`, 0.944912205236415], 
             UndirectedEdge[18, 115] -> 
             RGBColor[
              0.3211119884632891, 0.4445412718157279, 0.9419752910571765], 
             UndirectedEdge[29, 89] -> 
             RGBColor[
              0.24060287377388323`, 0.3702192538126069, 0.9370133497701439], 
             UndirectedEdge[15, 140] -> 
             RGBColor[
              0.3679277224284564, 0.4829432593711632, 0.9454578926876818], 
             UndirectedEdge[113, 136] -> 
             RGBColor[
              0.6481603425082536, 0.7223758434396859, 0.9674753560412221], 
             UndirectedEdge[111, 160] -> 
             RGBColor[
              0.9840167515258731, 0.9874198622967321, 0.9038592820686749], 
             UndirectedEdge[116, 188] -> 
             RGBColor[
              0.31448223303796907`, 0.4407572942765058, 0.9414811428946883], 
             UndirectedEdge[82, 127] -> 
             RGBColor[
              0.48166456992365847`, 0.5721840410107024, 0.9557316522035341], 
             UndirectedEdge[25, 95] -> 
             RGBColor[
              0.3933042723031561, 0.515082125446653, 0.9462819783392128], 
             UndirectedEdge[62, 111] -> 
             RGBColor[
              0.6269545414991542, 0.6939293577174481, 0.9161266604322329], 
             UndirectedEdge[162, 180] -> 
             RGBColor[
              0.6845803459319033, 0.7535186363361169, 0.9691962291815814], 
             UndirectedEdge[89, 159] -> 
             RGBColor[
              0.2512917882699816, 0.3814539806643284, 0.9376220676378648], 
             UndirectedEdge[7, 153] -> 
             RGBColor[
              0.39809152343441495`, 0.5118006733279219, 0.9474347966293495], 
             UndirectedEdge[146, 183] -> 
             RGBColor[
              0.7235521403694922, 0.7836795535870728, 0.9732985389453981], 
             UndirectedEdge[144, 197] -> 
             RGBColor[
              0.8206154206252081, 0.8603676602564476, 0.9643903249241998], 
             UndirectedEdge[120, 128] -> 
             RGBColor[
              0.7578683467801485, 0.8110621899208443, 0.9764238262231513], 
             UndirectedEdge[74, 166] -> 
             RGBColor[
              0.3933670070182812, 0.5089933470970472, 0.9469692677681272], 
             UndirectedEdge[147, 152] -> 
             RGBColor[
              0.7600746074557062, 0.8128247608324173, 0.9767554008301376], 
             UndirectedEdge[22, 190] -> 
             RGBColor[
              0.5725277109715231, 0.6402419493716766, 0.9402410835775585], 
             UndirectedEdge[27, 128] -> 
             RGBColor[
              0.5372954732879075, 0.6175601369058419, 0.9609418716268552], 
             UndirectedEdge[47, 88] -> 
             RGBColor[
              0.6266187222336668, 0.6987957233233801, 0.9530693406295663], 
             UndirectedEdge[69, 177] -> 
             RGBColor[
              0.4122731080464182, 0.5278191675288912, 0.9481411275027016], 
             UndirectedEdge[122, 167] -> 
             RGBColor[
              0.7474579538436295, 0.802639101524277, 0.9754632815135685], 
             UndirectedEdge[1, 78] -> 
             RGBColor[
              0.47521160380522603`, 0.5842764661614361, 0.9519844809516196], 
             UndirectedEdge[138, 159] -> 
             RGBColor[
              0.28978293217981943`, 0.419833793916139, 0.9398901238755868], 
             UndirectedEdge[101, 127] -> 
             RGBColor[
              0.41088589677086407`, 0.5164743793503679, 0.9489620805479629], 
             UndirectedEdge[65, 90] -> 
             RGBColor[
              0.5994601181847901, 0.6688433233110644, 0.9434582810247198], 
             UndirectedEdge[64, 127] -> 
             RGBColor[
              0.5518966150352457, 0.627673716738592, 0.962566170638949], 
             UndirectedEdge[117, 146] -> 
             RGBColor[
              0.7305810686826764, 0.7892842302288294, 0.9739689644027081], 
             UndirectedEdge[49, 103] -> 
             RGBColor[
              0.4010677097182158, 0.5218064247338675, 0.9467766577063623], 
             UndirectedEdge[88, 113] -> 
             RGBColor[
              0.7040770642133146, 0.7665351322657424, 0.9579978930059786], 
             UndirectedEdge[13, 176] -> 
             RGBColor[
              0.46127734447324126`, 0.5720974447925153, 0.9511269586523365], 
             UndirectedEdge[17, 112] -> 
             RGBColor[
              0.6639911599135793, 0.7329758676036549, 0.969929479830202], 
             UndirectedEdge[129, 170] -> 
             RGBColor[
              0.3970152069882198, 0.5151634481125192, 0.9469644254701698], 
             UndirectedEdge[35, 116] -> 
             RGBColor[
              0.44518153619467393`, 0.5586211498668051, 0.9499728435535573], 
             UndirectedEdge[69, 110] -> 
             RGBColor[
              0.6227436260287662, 0.7035282703871176, 0.9641836335782906], 
             UndirectedEdge[47, 126] -> 
             RGBColor[
              0.388250880654347, 0.509383343810133, 0.9461529300598799], 
             UndirectedEdge[83, 137] -> 
             RGBColor[
              0.7060117475966832, 0.7649347615936546, 0.8776982828570878], 
             UndirectedEdge[72, 84] -> 
             RGBColor[
              0.38848608435411575`, 0.5109088532143619, 0.9459749676636562], 
             UndirectedEdge[22, 37] -> 
             RGBColor[
              0.6305993331901552, 0.7012789062769671, 0.9435481765536433], 
             UndirectedEdge[90, 141] -> 
             RGBColor[
              0.5750074826307826, 0.6431420529571624, 0.9420657396043517], 
             UndirectedEdge[24, 79] -> 
             RGBColor[
              0.5053147649787331, 0.5989718806477653, 0.9567729508565471], 
             UndirectedEdge[34, 130] -> 
             RGBColor[
              0.6050287564735908, 0.6846745496833986, 0.9648977467357616], 
             UndirectedEdge[157, 174] -> 
             RGBColor[
              0.6782389873574362, 0.7336315365257472, 0.6781972261273775], 
             UndirectedEdge[131, 180] -> 
             RGBColor[
              0.6072668312875684, 0.6917404273641992, 0.9624340617745832], 
             UndirectedEdge[3, 48] -> 
             RGBColor[
              0.6116596369503513, 0.6825832623703603, 0.9494116961949276], 
             UndirectedEdge[49, 67] -> 
             RGBColor[
              0.3649341485548995, 0.48854565795883254`, 0.9445461595322828], 
             UndirectedEdge[79, 190] -> 
             RGBColor[
              0.22493765932523385`, 0.353754120195114, 0.9361212389819014], 
             UndirectedEdge[13, 82] -> 
             RGBColor[
              0.5787287571504417, 0.6656981389817174, 0.9615707793311472], 
             UndirectedEdge[68, 138] -> 
             RGBColor[
              0.48459200522478685`, 0.5891370894183083, 0.95348410250222], 
             UndirectedEdge[153, 160] -> 
             RGBColor[
              0.6185725437823885, 0.6856848244422746, 0.9259366203227334], 
             UndirectedEdge[178, 183] -> 
             RGBColor[
              0.6419897867341302, 0.7174635605637272, 0.9668776516944766], 
             UndirectedEdge[2, 166] -> 
             RGBColor[
              0.29980603300772574`, 0.42986786288081696`, 0.9404792630473418],
              UndirectedEdge[32, 53] -> 
             RGBColor[
              0.3759412177123833, 0.49477977874778845`, 0.9456035015542132], 
             UndirectedEdge[26, 184] -> 
             RGBColor[
              0.6705182320801251, 0.732395893247054, 0.7747807513808463], 
             UndirectedEdge[61, 115] -> 
             RGBColor[
              0.35273094383136877`, 0.4711121096411438, 0.9442154618777922], 
             UndirectedEdge[146, 178] -> 
             RGBColor[
              0.5385504177418906, 0.6362585163995294, 0.9568158081412752], 
             UndirectedEdge[88, 102] -> 
             RGBColor[
              0.855069981934506, 0.8873484252429176, 0.9710944662818928], 
             UndirectedEdge[118, 159] -> 
             RGBColor[
              0.6169476690821799, 0.6833286277669773, 0.9133951354087063], 
             UndirectedEdge[62, 75] -> 
             RGBColor[
              0.31058438859573234`, 0.4397254140564074, 0.9411469417035495], 
             UndirectedEdge[89, 197] -> 
             RGBColor[
              0.6050699434314342, 0.675589671764802, 0.9486500781855967], 
             UndirectedEdge[85, 146] -> 
             RGBColor[
              0.48994343844703475`, 0.5942572448371926, 0.9536910805766732], 
             UndirectedEdge[170, 190] -> 
             RGBColor[
              0.3429343879686585, 0.4583210784009893, 0.9438846028324078], 
             UndirectedEdge[82, 101] -> 
             RGBColor[
              0.6859275583197272, 0.7541542646371464, 0.9696154917419771], 
             UndirectedEdge[7, 73] -> 
             RGBColor[
              0.706485883149002, 0.7695046566295762, 0.9723230361351989], 
             UndirectedEdge[19, 34] -> 
             RGBColor[
              0.6100983650193895, 0.6890655897998352, 0.965220777709421], 
             UndirectedEdge[56, 170] -> 
             RGBColor[
              0.4659624922934271, 0.5766328992771261, 0.9512935809622499], 
             UndirectedEdge[32, 187] -> 
             RGBColor[
              0.4459497871962276, 0.5516158893048876, 0.9511148325938215], 
             UndirectedEdge[74, 169] -> 
             RGBColor[
              0.4992293690989513, 0.6043359177181367, 0.953720311154356], 
             UndirectedEdge[55, 147] -> 
             RGBColor[
              0.6643319090767895, 0.737408698612445, 0.9673774945016315], 
             UndirectedEdge[49, 143] -> 
             RGBColor[
              0.40038124083049453`, 0.5212118398862529, 0.9467329165158573], 
             UndirectedEdge[28, 77] -> 
             RGBColor[
              0.4650277870398981, 0.5683120339563343, 0.9526288675057986], 
             UndirectedEdge[122, 153] -> 
             RGBColor[
              0.5160747284520384, 0.6055105868249426, 0.9581409863075631], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.9181750508470145, 0.9324858641764708, 0.7162752258127858], 
             UndirectedEdge[16, 199] -> 
             RGBColor[
              0.5873038854200161, 0.6696244168335681, 0.9636291869388831], 
             UndirectedEdge[64, 180] -> 
             RGBColor[
              0.7797253200665968, 0.8284704815621304, 0.9785138355574614], 
             UndirectedEdge[38, 128] -> 
             RGBColor[
              0.5594502961086979, 0.6408462603873908, 0.962203556011376], 
             UndirectedEdge[46, 98] -> 
             RGBColor[
              0.34284757443638353`, 0.4710317201348256, 0.9430796403403592], 
             UndirectedEdge[68, 142] -> 
             RGBColor[
              0.40845121263469186`, 0.5111851082779473, 0.9490719544698213], 
             UndirectedEdge[5, 20] -> 
             RGBColor[
              0.45102286455557644`, 0.5561011155026875, 0.9514808269280646], 
             UndirectedEdge[169, 200] -> 
             RGBColor[
              0.45678364917748915`, 0.5694838974665077, 0.950487325224683], 
             UndirectedEdge[27, 133] -> 
             RGBColor[
              0.401715046213961, 0.510470821138743, 0.9481088804172082], 
             UndirectedEdge[32, 135] -> 
             RGBColor[
              0.5655054033043656, 0.6456038861616715, 0.9627917857354242], 
             UndirectedEdge[144, 190] -> 
             RGBColor[
              0.4334827233389121, 0.5311742305826477, 0.9514628225460813], 
             UndirectedEdge[62, 126] -> 
             RGBColor[
              0.3720800758687383, 0.4923868026922169, 0.9452320266499014], 
             UndirectedEdge[55, 62] -> 
             RGBColor[
              0.4869890990462495, 0.5847102254558564, 0.9549377924897449], 
             UndirectedEdge[62, 76] -> 
             RGBColor[
              0.29867548565494584`, 0.42941052088796383`, 0.940388116938792], 
             UndirectedEdge[157, 181] -> 
             RGBColor[
              0.4031683015549601, 0.52362585180404, 0.9469105055607192], 
             UndirectedEdge[64, 82] -> 
             RGBColor[
              0.8269382765841088, 0.8653536020253705, 0.9832195818329632], 
             UndirectedEdge[142, 153] -> 
             RGBColor[
              0.2166583332522186, 0.34505202355278286`, 0.9356497436102085], 
             UndirectedEdge[21, 109] -> 
             RGBColor[
              0.3406617414070149, 0.46601805350528513`, 0.9430546144123289], 
             UndirectedEdge[66, 198] -> 
             RGBColor[
              0.9779512096152074, 0.9829041869329407, 0.9144847334032875], 
             UndirectedEdge[141, 198] -> 
             RGBColor[
              0.5868809815019275, 0.6518248471577548, 0.9142447062606267], 
             UndirectedEdge[10, 28] -> 
             RGBColor[
              0.511643032291146, 0.6118772124037197, 0.955482370303187], 
             UndirectedEdge[31, 151] -> 
             RGBColor[
              0.9592998416815888, 0.967619317443172, 0.886887729956076], 
             UndirectedEdge[111, 142] -> 
             RGBColor[
              0.5821025409957032, 0.6467870614072403, 0.91357240535615], 
             UndirectedEdge[111, 181] -> 
             RGBColor[
              0.7120671246908798, 0.7713585051404233, 0.9214141577632549], 
             UndirectedEdge[86, 101] -> 
             RGBColor[
              0.6629648232794851, 0.7362156015004591, 0.9673267809121253], 
             UndirectedEdge[119, 144] -> 
             RGBColor[
              0.5343565495866516, 0.6302971292948547, 0.957460149667114], 
             UndirectedEdge[5, 102] -> 
             RGBColor[
              0.5116854626273406, 0.6035801856539313, 0.9574662665503124], 
             UndirectedEdge[157, 185] -> 
             RGBColor[
              0.6342241954811185, 0.7082931119006574, 0.9675264141267523], 
             UndirectedEdge[13, 110] -> 
             RGBColor[
              0.556874183585826, 0.6486251800121285, 0.959392519680828], 
             UndirectedEdge[32, 82] -> 
             RGBColor[
              0.5095682151935049, 0.6015125413826048, 0.9573207235219079], 
             UndirectedEdge[12, 23] -> 
             RGBColor[
              0.6700918202013582, 0.731099061607768, 0.6954818569284458], 
             UndirectedEdge[53, 130] -> 
             RGBColor[
              0.42353863907686884`, 0.5402884850836736, 0.9484795743868203], 
             UndirectedEdge[74, 80] -> 
             RGBColor[
              0.47184390756073424`, 0.5811968810294924, 0.951814836637507], 
             UndirectedEdge[35, 185] -> 
             RGBColor[
              0.7028213151632126, 0.76631403504222, 0.9722826537672844], 
             UndirectedEdge[117, 196] -> 
             RGBColor[
              0.8481706160293687, 0.8817722425165087, 0.9853804645993705], 
             UndirectedEdge[22, 181] -> 
             RGBColor[
              0.7011316972018188, 0.7633833189024077, 0.9480053519718621], 
             UndirectedEdge[143, 197] -> 
             RGBColor[
              0.6571573786218643, 0.7257459091543921, 0.9517844780809896], 
             UndirectedEdge[16, 124] -> 
             RGBColor[
              0.6815148721592208, 0.7494313144041409, 0.9701278942418389], 
             UndirectedEdge[182, 191] -> 
             RGBColor[
              0.8860281634990772, 0.9107238235479883, 0.9344978163457565], 
             UndirectedEdge[98, 146] -> 
             RGBColor[
              0.5004094024065477, 0.603322336784279, 0.9543579625454848], 
             UndirectedEdge[156, 183] -> 
             RGBColor[
              0.703472358841718, 0.7673778823589763, 0.9717177849888684], 
             UndirectedEdge[6, 13] -> 
             RGBColor[
              0.6132062162173222, 0.6926780783299414, 0.9649949934311223], 
             UndirectedEdge[50, 100] -> 
             RGBColor[
              0.3530157233726951, 0.4748678911474106, 0.9439170511498159], 
             UndirectedEdge[13, 175] -> 
             RGBColor[
              0.5715681589151663, 0.660104225217758, 0.96085707781865], 
             UndirectedEdge[62, 116] -> 
             RGBColor[
              0.3271596991562473, 0.4540821149645933, 0.9422031058354938], 
             UndirectedEdge[120, 171] -> 
             RGBColor[
              0.6185012488257475, 0.7008986841454135, 0.9632927344107625], 
             UndirectedEdge[72, 139] -> 
             RGBColor[
              0.35818318656553083`, 0.48466200621781763`, 0.944044093812368], 
             UndirectedEdge[6, 83] -> 
             RGBColor[
              0.6235987351218895, 0.7016795558618896, 0.9656571955459776], 
             UndirectedEdge[118, 190] -> 
             RGBColor[
              0.5835931269573364, 0.6482708891936511, 0.9114956435783197], 
             UndirectedEdge[36, 200] -> 
             RGBColor[
              0.7006756162235426, 0.7630431744555735, 0.9487773781031136], 
             UndirectedEdge[16, 161] -> 
             RGBColor[
              0.73056110616825, 0.7892492566803335, 0.9739889934453047], 
             UndirectedEdge[2, 169] -> 
             RGBColor[
              0.4056683950883959, 0.5252104335019063, 0.9472303064335704], 
             UndirectedEdge[107, 111] -> 
             RGBColor[
              0.8731451129809971, 0.900703930340799, 0.9352290236133077], 
             UndirectedEdge[127, 180] -> 
             RGBColor[
              0.43445161340614646`, 0.5353009205474625, 0.9510259059280322], 
             UndirectedEdge[138, 156] -> 
             RGBColor[
              0.45558089675094704`, 0.5655845646237021, 0.9512002417719674], 
             UndirectedEdge[72, 93] -> 
             RGBColor[
              0.3037350131118919, 0.43408672046696917`, 0.940699744758072], 
             UndirectedEdge[137, 187] -> 
             RGBColor[
              0.8099782750169184, 0.8502024192997526, 0.885644473880547], 
             UndirectedEdge[40, 121] -> 
             RGBColor[
              0.79424687972392, 0.8384166281598947, 0.9256106735262181], 
             UndirectedEdge[98, 178] -> 
             RGBColor[
              0.4188470487711857, 0.5371063437609334, 0.9479370752945633], 
             UndirectedEdge[10, 186] -> 
             RGBColor[
              0.3635119065178405, 0.489277475611256, 0.9443836351357272], 
             UndirectedEdge[63, 91] -> 
             RGBColor[
              0.6179561468996353, 0.7004728463778065, 0.9632384037450348], 
             UndirectedEdge[125, 195] -> 
             RGBColor[
              0.5540557279642674, 0.6396550974103585, 0.9612178253283385], 
             UndirectedEdge[86, 180] -> 
             RGBColor[
              0.6865305399147674, 0.7550421426975537, 0.9693906062921944], 
             UndirectedEdge[137, 186] -> 
             RGBColor[
              0.675015275935992, 0.7380871757691284, 0.8757232150919723], 
             UndirectedEdge[33, 44] -> 
             RGBColor[
              0.34897811486366204`, 0.4766890357700151, 0.9434575547832502], 
             UndirectedEdge[14, 193] -> 
             RGBColor[
              0.6371482128500751, 0.7160564782544312, 0.964747462928076], 
             UndirectedEdge[11, 28] -> 
             RGBColor[
              0.43023727343667517`, 0.5317449983133808, 0.9506475992240477], 
             UndirectedEdge[85, 151] -> 
             RGBColor[
              0.6431470013761548, 0.7151429064335995, 0.9684994773725946], 
             UndirectedEdge[175, 199] -> 
             RGBColor[
              0.5366749517734668, 0.6298814829752024, 0.9586337135144325], 
             UndirectedEdge[146, 196] -> 
             RGBColor[
              0.7377023187239451, 0.7949625217105543, 0.9746481955888592], 
             UndirectedEdge[20, 77] -> 
             RGBColor[
              0.45539993952667013`, 0.560701698819889, 0.9517300948723663], 
             UndirectedEdge[27, 56] -> 
             RGBColor[
              0.3231905823705016, 0.44602565470927513`, 0.942119307189472], 
             UndirectedEdge[101, 175] -> 
             RGBColor[
              0.6787669600844518, 0.7485603508731871, 0.96890179022948], 
             UndirectedEdge[21, 85] -> 
             RGBColor[
              0.38492918141428284`, 0.5078280426630185, 0.9457483249535759], 
             UndirectedEdge[150, 194] -> 
             RGBColor[
              0.6838013370716175, 0.7511727639820212, 0.9704400323237365], 
             UndirectedEdge[61, 160] -> 
             RGBColor[
              0.7330614185941224, 0.7890590357511934, 0.9332731767686384], 
             UndirectedEdge[24, 149] -> 
             RGBColor[
              0.8067903960851857, 0.8494038415095402, 0.981267179003505], 
             UndirectedEdge[14, 186] -> 
             RGBColor[
              0.5090514058893372, 0.6095155188054062, 0.9553667359348931], 
             UndirectedEdge[111, 126] -> 
             RGBColor[
              0.7304036163609906, 0.7866375677892494, 0.9227491769299685], 
             UndirectedEdge[35, 88] -> 
             RGBColor[
              0.7284697544864847, 0.7863382171076758, 0.9599181749376511], 
             UndirectedEdge[94, 111] -> 
             RGBColor[
              0.6872735101806371, 0.74988352241495, 0.9198343305707948], 
             UndirectedEdge[133, 162] -> 
             RGBColor[
              0.6458168523462635, 0.722353855158673, 0.9659359791286888], 
             UndirectedEdge[124, 199] -> 
             RGBColor[
              0.4251758552841674, 0.5408937647514154, 0.9488084739592668], 
             UndirectedEdge[54, 105] -> 
             RGBColor[
              0.5018080639911693, 0.6042891573778082, 0.9545146759598289], 
             UndirectedEdge[64, 162] -> 
             RGBColor[
              0.8020253475610025, 0.8458914325272464, 0.9807364938924984], 
             UndirectedEdge[57, 66] -> 
             RGBColor[
              0.6496962179286632, 0.7183953012510711, 0.9383473845413093], 
             UndirectedEdge[16, 137] -> 
             RGBColor[
              0.9170650384254697, 0.9342480914718763, 0.896132136720587], 
             UndirectedEdge[44, 50] -> 
             RGBColor[
              0.41320430929289176`, 0.5322872723074537, 0.9475586297049692], 
             UndirectedEdge[153, 167] -> 
             RGBColor[
              0.48577289189602824`, 0.5818385618049, 0.9551207824264224], 
             UndirectedEdge[165, 187] -> 
             RGBColor[
              0.41633491659886057`, 0.5204887826158087, 0.9494283095245762], 
             UndirectedEdge[32, 83] -> 
             RGBColor[
              0.34198325977599225`, 0.4663482315987896, 0.9431686415703622], 
             UndirectedEdge[6, 187] -> 
             RGBColor[
              0.7275652625421248, 0.7869472135679876, 0.9736033865694369], 
             UndirectedEdge[66, 141] -> 
             RGBColor[
              0.5796022374410565, 0.6465688135714442, 0.9342880182145398], 
             UndirectedEdge[23, 87] -> 
             RGBColor[
              0.5565771869028013, 0.6461305244561463, 0.9603205740967573], 
             UndirectedEdge[85, 152] -> 
             RGBColor[
              0.6283033496801237, 0.7033069814913759, 0.9670836766227429], 
             UndirectedEdge[26, 74] -> 
             RGBColor[
              0.4353097023698194, 0.5495527887556666, 0.949486909388671], 
             UndirectedEdge[81, 172] -> 
             RGBColor[
              0.3375754338375435, 0.46681260658060364`, 0.9427309860312609], 
             UndirectedEdge[54, 73] -> 
             RGBColor[
              0.7501503419929152, 0.8049534313805196, 0.9757604622835747], 
             UndirectedEdge[135, 165] -> 
             RGBColor[
              0.5358905327069985, 0.6144767794725926, 0.961105262666179], 
             UndirectedEdge[46, 109] -> 
             RGBColor[
              0.2881141704696025, 0.4201566390300059, 0.9397190478303005], 
             UndirectedEdge[40, 171] -> 
             RGBColor[
              0.7813590242451101, 0.8279536864909238, 0.9245960943331559], 
             UndirectedEdge[113, 167] -> 
             RGBColor[
              0.5865227059125172, 0.6740587846226034, 0.9613757496786877], 
             UndirectedEdge[103, 162] -> 
             RGBColor[
              0.5333272394715629, 0.6284897837763715, 0.9577821766388841], 
             UndirectedEdge[37, 119] -> 
             RGBColor[
              0.3405936433961334, 0.4684140040224009, 0.9429603881227202], 
             UndirectedEdge[71, 184] -> 
             RGBColor[
              0.6027577979827496, 0.6647003712273782, 0.7707928277326488], 
             UndirectedEdge[107, 142] -> 
             RGBColor[
              0.4699695719852939, 0.5593108689335586, 0.9551576182571577], 
             UndirectedEdge[136, 143] -> 
             RGBColor[
              0.5994162791102332, 0.6802260023473401, 0.9643501368688181], 
             UndirectedEdge[3, 5] -> 
             RGBColor[
              0.6104838845743592, 0.6813474720761863, 0.9493447388364846], 
             UndirectedEdge[24, 118] -> 
             RGBColor[
              0.8639702326108356, 0.8934886496463024, 0.9321473554529653], 
             UndirectedEdge[142, 185] -> 
             RGBColor[
              0.5399474776213351, 0.6146327038298003, 0.9619586609731381], 
             UndirectedEdge[3, 28] -> 
             RGBColor[
              0.80563880136828, 0.8486756301027791, 0.9632933735741329], 
             UndirectedEdge[43, 49] -> 
             RGBColor[
              0.6597916748139349, 0.7312549626024488, 0.9687796322972131], 
             UndirectedEdge[19, 60] -> 
             RGBColor[
              0.4797180883136162, 0.5861727963451064, 0.9528261592411866], 
             UndirectedEdge[87, 110] -> 
             RGBColor[
              0.739337508572568, 0.7962953479608539, 0.9746539114188246], 
             UndirectedEdge[107, 185] -> 
             RGBColor[
              0.8309900496066289, 0.868549572763359, 0.9836152792302958], 
             UndirectedEdge[66, 81] -> 
             RGBColor[
              0.6528577862361093, 0.7211336928139375, 0.9385488368781947], 
             UndirectedEdge[63, 112] -> 
             RGBColor[
              0.48610499024840303`, 0.5920982996183997, 0.953124404571658], 
             UndirectedEdge[59, 193] -> 
             RGBColor[
              0.5418539517716721, 0.6389404741474181, 0.9570758744413435], 
             UndirectedEdge[110, 180] -> 
             RGBColor[
              0.6876387013903937, 0.7559078468646521, 0.9695010574717271], 
             UndirectedEdge[21, 196] -> 
             RGBColor[
              0.6326880616911932, 0.7085333195363801, 0.9667054399657619], 
             UndirectedEdge[24, 190] -> 
             RGBColor[
              0.4620253005832611, 0.5534719088575546, 0.9543076799002486], 
             UndirectedEdge[44, 60] -> 
             RGBColor[
              0.4818055357320308, 0.5879808383807793, 0.9529591695448307], 
             UndirectedEdge[20, 106] -> 
             RGBColor[
              0.5796168584053618, 0.6695981029522045, 0.9600487087816325], 
             UndirectedEdge[75, 139] -> 
             RGBColor[
              0.36662190481020285`, 0.4919711998190411, 0.944581801476853], 
             UndirectedEdge[4, 81] -> 
             RGBColor[
              0.6615432336591223, 0.7269714343911211, 0.8951928097819842], 
             UndirectedEdge[79, 197] -> 
             RGBColor[
              0.61207035661153, 0.6829475498689139, 0.9490487413600199], 
             UndirectedEdge[66, 90] -> 
             RGBColor[
              0.9660777107440626, 0.9742213927323484, 0.9423057667470125], 
             UndirectedEdge[14, 15] -> 
             RGBColor[
              0.5882765956044679, 0.6763802977331801, 0.9609001101958692], 
             UndirectedEdge[14, 48] -> 
             RGBColor[
              0.4632033672447141, 0.5660228878654512, 0.9525837937231475], 
             UndirectedEdge[122, 144] -> 
             RGBColor[
              0.7315385210738509, 0.7902027196523558, 0.9738765812306345], 
             UndirectedEdge[80, 121] -> 
             RGBColor[0.51144795417556, 0.613349230213376, 0.954932612261429],
              UndirectedEdge[79, 170] -> 
             RGBColor[
              0.3862238523641304, 0.5038210501911999, 0.9463498737887064], 
             UndirectedEdge[91, 95] -> 
             RGBColor[
              0.5047201021031804, 0.6057566191969356, 0.9550938565558804], 
             UndirectedEdge[48, 193] -> 
             RGBColor[
              0.4417921456322288, 0.5488884635898679, 0.9507285487456631], 
             UndirectedEdge[67, 162] -> 
             RGBColor[
              0.4971936783082466, 0.5952290170013366, 0.9555516784648046], 
             UndirectedEdge[65, 87] -> 
             RGBColor[
              0.5015576066188187, 0.5918823510337334, 0.9570561763266774], 
             UndirectedEdge[98, 121] -> 
             RGBColor[
              0.491830866949386, 0.5963578952415367, 0.9536826288100863], 
             UndirectedEdge[161, 187] -> 
             RGBColor[
              0.6234743427596987, 0.7052035845082099, 0.9635013306052647], 
             UndirectedEdge[68, 122] -> 
             RGBColor[
              0.7078676078345116, 0.771643671550107, 0.9715631971671759], 
             UndirectedEdge[19, 90] -> 
             RGBColor[
              0.6646236073344227, 0.7318776407452193, 0.9473690396978125], 
             UndirectedEdge[80, 168] -> 
             RGBColor[
              0.39040718114981626`, 0.5125728107016652, 0.9460973782527191], 
             UndirectedEdge[109, 194] -> 
             RGBColor[
              0.5653739069734607, 0.6466164179477135, 0.962609967604261], 
             UndirectedEdge[44, 57] -> 
             RGBColor[
              0.350329561937438, 0.47785959129961497`, 0.9435436677957536], 
             UndirectedEdge[109, 151] -> 
             RGBColor[
              0.5988795613688869, 0.6733329172758662, 0.9658057668313474], 
             UndirectedEdge[122, 138] -> 
             RGBColor[
              0.5544841877899147, 0.6438045444125209, 0.9604043907297534], 
             UndirectedEdge[138, 192] -> 
             RGBColor[
              0.5544841877899147, 0.6438045444125209, 0.9604043907297534], 
             UndirectedEdge[31, 46] -> 
             RGBColor[
              0.6485344507823045, 0.7144430391973116, 0.860801010955029], 
             UndirectedEdge[101, 165] -> 
             RGBColor[
              0.4091746714433435, 0.5146757730331915, 0.9488646287970917], 
             UndirectedEdge[76, 105] -> 
             RGBColor[
              0.3516069001165545, 0.478965957429482, 0.943625058655021], 
             UndirectedEdge[6, 199] -> 
             RGBColor[
              0.5783130090756228, 0.6624553360873858, 0.9627716291269048], 
             UndirectedEdge[83, 175] -> 
             RGBColor[
              0.5819606778197336, 0.6691057027497063, 0.9615192799335054], 
             UndirectedEdge[139, 182] -> 
             RGBColor[
              0.5836212636161339, 0.6686688590444938, 0.9624187474325585], 
             UndirectedEdge[89, 149] -> 
             RGBColor[
              0.5627023416470627, 0.6423281747429878, 0.9626820749107345], 
             UndirectedEdge[53, 163] -> 
             RGBColor[
              0.7415449117991018, 0.7925990840422845, 0.7509097110614755], 
             UndirectedEdge[8, 96] -> 
             RGBColor[
              0.5412233459541247, 0.6257079926750133, 0.9605566448244506], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.7365561388865183, 0.79411629431417, 0.9744609443814152], 
             UndirectedEdge[55, 191] -> 
             RGBColor[
              0.8454335151436634, 0.8790109757219845, 0.9304517211762462], 
             UndirectedEdge[122, 181] -> 
             RGBColor[
              0.6083079788949963, 0.6904240070053427, 0.9638339951044594], 
             UndirectedEdge[130, 177] -> 
             RGBColor[
              0.32484054501102666`, 0.4542391858906746, 0.9419760306286068], 
             UndirectedEdge[25, 131] -> 
             RGBColor[
              0.4940769944157762, 0.5996800658064984, 0.9534453671120403], 
             UndirectedEdge[19, 33] -> 
             RGBColor[
              0.3468906674452473, 0.4748809937343422, 0.9433245444796061], 
             UndirectedEdge[1, 89] -> 
             RGBColor[
              0.38599170615628725`, 0.501957956122115, 0.9464840333833178], 
             UndirectedEdge[123, 127] -> 
             RGBColor[
              0.6137536361249318, 0.20091938524130798`, 0.4211714136698399], 
             UndirectedEdge[40, 173] -> 
             RGBColor[
              0.928059756174002, 0.9439648329314226, 0.9384266747008441], 
             UndirectedEdge[17, 106] -> 
             RGBColor[
              0.7278180559050579, 0.7863760732407665, 0.9745168742916738], 
             UndirectedEdge[51, 158] -> 
             RGBColor[
              0.7280681267432523, 0.7869073357656344, 0.9741587582448163], 
             UndirectedEdge[20, 189] -> 
             RGBColor[
              0.574468431841448, 0.6654183783336456, 0.9596434057832133], 
             UndirectedEdge[48, 140] -> 
             RGBColor[
              0.2428544940687027, 0.3725858495034343, 0.9371415762149602], 
             UndirectedEdge[11, 189] -> 
             RGBColor[
              0.35852792392862587`, 0.4737341031177463, 0.944861543341548], 
             UndirectedEdge[40, 169] -> 
             RGBColor[
              0.730124594974768, 0.7863592687245242, 0.9205627323830963], 
             UndirectedEdge[94, 167] -> 
             RGBColor[
              0.5532125278287436, 0.645276999259827, 0.9592339640308587], 
             UndirectedEdge[81, 198] -> 
             RGBColor[
              0.6601365302969803, 0.7263897264002479, 0.9185055249242816], 
             UndirectedEdge[34, 60] -> 
             RGBColor[
              0.7220521945979488, 0.7822777367725695, 0.9733923456918068], 
             UndirectedEdge[13, 101] -> 
             RGBColor[
              0.5079500839976473, 0.6099884773213828, 0.9548012076755761], 
             UndirectedEdge[31, 117] -> 
             RGBColor[
              0.9165645760578924, 0.9335433766527194, 0.8828116021706659], 
             UndirectedEdge[94, 105] -> 
             RGBColor[
              0.3818813841499935, 0.5051881938594358, 0.9455541220069568], 
             UndirectedEdge[125, 190] -> 
             RGBColor[
              0.23457758905997306`, 0.36388629755317176`, 0.9366702187192968],
              UndirectedEdge[79, 119] -> 
             RGBColor[
              0.32581148557297335`, 0.452877018907321, 0.9421185661029341], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.6461777813494973, 0.7234292735292802, 0.9654294616657129], 
             UndirectedEdge[156, 178] -> 
             RGBColor[
              0.5184706362141163, 0.619956845171433, 0.9552350541847455], 
             UndirectedEdge[95, 131] -> 
             RGBColor[
              0.4514806220250192, 0.5627852289975521, 0.9507311639297944], 
             UndirectedEdge[49, 133] -> 
             RGBColor[
              0.5135573225929163, 0.615670496116169, 0.954930460196167], 
             UndirectedEdge[34, 44] -> 
             RGBColor[
              0.6121858124378042, 0.6908736318355081, 0.9653537880130652], 
             UndirectedEdge[24, 125] -> 
             RGBColor[
              0.5149546947134722, 0.609104058005823, 0.9573219305939424], 
             UndirectedEdge[95, 129] -> 
             RGBColor[
              0.32025886644064183`, 0.450063088232835, 0.9416916942290467], 
             UndirectedEdge[13, 16] -> 
             RGBColor[
              0.6221970925617156, 0.6998471590761237, 0.9658525512431007], 
             UndirectedEdge[13, 199] -> 
             RGBColor[
              0.3658580756866623, 0.4913096094233983, 0.9445331309605285], 
             UndirectedEdge[121, 196] -> 
             RGBColor[
              0.7291237832667834, 0.787998080167812, 0.9739728618534607], 
             UndirectedEdge[26, 40] -> 
             RGBColor[
              0.6662049282456362, 0.7315761397620543, 0.9163293306174114], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.5854578392083061, 0.6743400743012211, 0.960508532186658], 
             UndirectedEdge[54, 126] -> 
             RGBColor[
              0.552325724391397, 0.6474419309080913, 0.9579002507413353], 
             UndirectedEdge[16, 193] -> 
             RGBColor[
              0.7296899467663296, 0.7885420102325708, 0.9739204125860235], 
             UndirectedEdge[85, 150] -> 
             RGBColor[
              0.43393409560770574`, 0.5487863371280844, 0.9492818199393781], 
             UndirectedEdge[26, 169] -> 
             RGBColor[
              0.4107914642354932, 0.5296477785041798, 0.9475567438694712], 
             UndirectedEdge[22, 79] -> 
             RGBColor[
              0.615817175366995, 0.6857419211618871, 0.9427063545338572], 
             UndirectedEdge[27, 67] -> 
             RGBColor[
              0.2530918721759441, 0.38334598298140654`, 0.9377245797533239], 
             UndirectedEdge[49, 95] -> 
             RGBColor[
              0.39653460691600695`, 0.5178800789269659, 0.9464878124042709], 
             UndirectedEdge[147, 178] -> 
             RGBColor[
              0.5401523425872552, 0.6375590311548883, 0.9569419175331464], 
             UndirectedEdge[1, 136] -> 
             RGBColor[
              0.6790942527155761, 0.7474893853027642, 0.9699105867673894], 
             UndirectedEdge[65, 110] -> 
             RGBColor[
              0.4752171823895408, 0.5713050114311828, 0.9544308090047625], 
             UndirectedEdge[77, 106] -> 
             RGBColor[
              0.3984668640957627, 0.5144808633792586, 0.9472481146217182], 
             UndirectedEdge[25, 64] -> 
             RGBColor[
              0.6665354831948045, 0.7364101200044296, 0.9695251408949185], 
             UndirectedEdge[82, 187] -> 
             RGBColor[
              0.6930878034752443, 0.7599672742197636, 0.9701791724694617], 
             UndirectedEdge[167, 188] -> 
             RGBColor[
              0.4802160930289823, 0.5759980138742375, 0.9548043309514913], 
             UndirectedEdge[13, 137] -> 
             RGBColor[
              0.6956192286921159, 0.7559332840617063, 0.8770360807422324], 
             UndirectedEdge[37, 125] -> 
             RGBColor[
              0.2926492112786051, 0.42492325445846224`, 0.9399773116953816], 
             UndirectedEdge[105, 182] -> 
             RGBColor[
              0.580515161863272, 0.6659785098233784, 0.9622208293754841], 
             UndirectedEdge[111, 116] -> 
             RGBColor[
              0.6854832396484997, 0.7483328800616258, 0.919720256115561], 
             UndirectedEdge[146, 179] -> 
             RGBColor[
              0.41085161384434066`, 0.5158446194761553, 0.9490141728507768], 
             UndirectedEdge[9, 63] -> 
             RGBColor[
              0.7395177890683372, 0.7960994627145143, 0.9751789273732825], 
             UndirectedEdge[38, 120] -> 
             RGBColor[
              0.46140445747473535`, 0.5639616957579245, 0.9525083290744741], 
             UndirectedEdge[71, 81] -> 
             RGBColor[
              0.2731970181147464, 0.4020464188918015, 0.93895856160329], 
             UndirectedEdge[68, 181] -> 
             RGBColor[
              0.5384157963298685, 0.6357565520111301, 0.9569137068769262], 
             UndirectedEdge[114, 158] -> 
             RGBColor[
              0.690809501101938, 0.7572541773685119, 0.9705901741864691], 
             UndirectedEdge[118, 149] -> 
             RGBColor[
              0.928358222459261, 0.9442028218456366, 0.9384551426815761], 
             UndirectedEdge[87, 162] -> 
             RGBColor[
              0.7362791531140774, 0.7939061374323186, 0.9743490831286791], 
             UndirectedEdge[88, 122] -> 
             RGBColor[
              0.8650123121444269, 0.895115449167416, 0.9720854248408595], 
             UndirectedEdge[49, 162] -> 
             RGBColor[
              0.5746208436729618, 0.664256228258729, 0.9604133685840968], 
             UndirectedEdge[47, 116] -> 
             RGBColor[
              0.34333050394185605`, 0.4710786560825093, 0.9431240092454725], 
             UndirectedEdge[23, 95] -> 
             RGBColor[
              0.34909217045807805`, 0.47678782499329736`, 0.9434648223048709],
              UndirectedEdge[54, 115] -> 
             RGBColor[
              0.42560838479352586`, 0.5302772993055245, 0.9499526409891956], 
             UndirectedEdge[62, 105] -> 
             RGBColor[
              0.3215624154685105, 0.4492340291619338, 0.9418464518683949], 
             UndirectedEdge[13, 108] -> 
             RGBColor[
              0.46049594834762575`, 0.5714630722162464, 0.9510654442869798], 
             UndirectedEdge[76, 182] -> 
             RGBColor[
              0.5576282320497074, 0.6461550015494084, 0.9607624944458812], 
             UndirectedEdge[117, 171] -> 
             RGBColor[
              0.7091146777467046, 0.7718568470171162, 0.9722790514742473], 
             UndirectedEdge[40, 46] -> 
             RGBColor[
              0.6452635872109176, 0.7130904530531835, 0.915007685056491], 
             UndirectedEdge[19, 177] -> 
             RGBColor[
              0.3299101535568254, 0.45863022600711123`, 0.9422990616022663], 
             UndirectedEdge[64, 87] -> 
             RGBColor[
              0.8314241272487709, 0.8688579826583323, 0.9836666895045589], 
             UndirectedEdge[62, 107] -> 
             RGBColor[
              0.5148215724887448, 0.6064531652437665, 0.9577118733332406], 
             UndirectedEdge[53, 148] -> 
             RGBColor[
              0.6008808296525914, 0.6857896014790655, 0.962455311941244], 
             UndirectedEdge[76, 111] -> 
             RGBColor[
              0.6569990261471981, 0.7236612859849963, 0.917905267218859], 
             UndirectedEdge[11, 48] -> 
             RGBColor[
              0.23625810901874644`, 0.3656526305809621, 0.9367659218448423], 
             UndirectedEdge[96, 111] -> 
             RGBColor[
              0.6217490558181313, 0.6884580622198384, 0.9158302157235247], 
             UndirectedEdge[168, 198] -> 
             RGBColor[0.67305205404376, 0.73757650391661, 0.9193284906766772],
              UndirectedEdge[118, 128] -> 
             RGBColor[
              0.920726122199511, 0.9381171922663547, 0.9377271861455447], 
             UndirectedEdge[56, 129] -> 
             RGBColor[
              0.35875711827409185`, 0.4834083389925702, 0.9441447687932069], 
             UndirectedEdge[53, 100] -> 
             RGBColor[
              0.3705071091208857, 0.48906818607574, 0.9452940371089706], 
             UndirectedEdge[129, 143] -> 
             RGBColor[
              0.32410550035512947`, 0.45339484919212203`, 0.9419367983406332],
              UndirectedEdge[18, 160] -> 
             RGBColor[
              0.7014424632260428, 0.7624881979257775, 0.9310330059480227], 
             UndirectedEdge[68, 111] -> 
             RGBColor[
              0.811626753630395, 0.8525781696851875, 0.9291433598259713], 
             UndirectedEdge[51, 166] -> 
             RGBColor[
              0.5752883729252103, 0.6534751129277354, 0.963714205916953], 
             UndirectedEdge[107, 181] -> 
             RGBColor[
              0.5999341556804705, 0.6838823126667415, 0.9629993706642626], 
             UndirectedEdge[31, 173] -> 
             RGBColor[
              0.931330619745389, 0.9453174190755507, 0.8842200005993821], 
             UndirectedEdge[135, 148] -> 
             RGBColor[
              0.7904450152445736, 0.8366137088929486, 0.979643596122455], 
             UndirectedEdge[44, 177] -> 
             RGBColor[
              0.3319976009752401, 0.4604382680427841, 0.9424320719059104], 
             UndirectedEdge[80, 184] -> 
             RGBColor[
              0.7070524372710398, 0.7640399855208799, 0.7771086786296824], 
             UndirectedEdge[65, 162] -> 
             RGBColor[
              0.47215882693105027`, 0.5689158009026477, 0.954125980714617], 
             UndirectedEdge[5, 17] -> 
             RGBColor[
              0.5992240620552725, 0.6728790857912494, 0.965948992438106], 
             UndirectedEdge[44, 141] -> 
             RGBColor[
              0.2802355814498314, 0.40603310361998807`, 0.939484301468984], 
             UndirectedEdge[94, 174] -> 
             RGBColor[
              0.6891332386825868, 0.7430675894626, 0.6788913981884079], 
             UndirectedEdge[161, 193] -> 
             RGBColor[
              0.6166081506395101, 0.6996293004266106, 0.962960798809873], 
             UndirectedEdge[101, 124] -> 
             RGBColor[
              0.5672678635951525, 0.6595726326494, 0.9590765506743143], 
             UndirectedEdge[106, 189] -> 
             RGBColor[
              0.5175353564105406, 0.6191975428930152, 0.9551614255325652], 
             UndirectedEdge[2, 80] -> 
             RGBColor[
              0.3782829335501788, 0.5020713968132622, 0.9453248319167215], 
             UndirectedEdge[97, 102] -> 
             RGBColor[
              0.8731582820861343, 0.9001326644696934, 0.9088602232621807], 
             UndirectedEdge[91, 136] -> 
             RGBColor[
              0.7495818473865268, 0.8044635719472818, 0.9756311141561453], 
             UndirectedEdge[59, 154] -> 
             RGBColor[
              0.4624794882061415, 0.5745007088460861, 0.9508272259112245], 
             UndirectedEdge[108, 162] -> 
             RGBColor[
              0.6135604936465994, 0.6961666900338859, 0.9633966404129161], 
             UndirectedEdge[146, 147] -> 
             RGBColor[
              0.6217146962226172, 0.7037750241782339, 0.9633628047840679], 
             UndirectedEdge[99, 156] -> 
             RGBColor[
              0.3923110631661645, 0.5011607774638591, 0.9475210758140438], 
             UndirectedEdge[143, 154] -> 
             RGBColor[
              0.40769461592395145`, 0.5274466669662323, 0.9472264521352467], 
             UndirectedEdge[139, 145] -> 
             RGBColor[
              0.43457283853155393`, 0.5498732483271556, 0.9491750670699655], 
             UndirectedEdge[104, 123] -> 
             RGBColor[
              0.8391350387836563, 0.3925375175919895, 0.43903876989490165`], 
             UndirectedEdge[116, 126] -> 
             RGBColor[
              0.43060877401808384`, 0.5467903250363946, 0.9488256223332294], 
             UndirectedEdge[17, 28] -> 
             RGBColor[
              0.7943789788491933, 0.8402072438178423, 0.9798976271757542], 
             UndirectedEdge[89, 118] -> 
             RGBColor[
              0.6198821781727126, 0.6864129828797498, 0.913562251360195], 
             UndirectedEdge[123, 163] -> 
             RGBColor[
              0.8760918623626417, 0.4190179223522403, 0.2924349342202641], 
             UndirectedEdge[47, 157] -> 
             RGBColor[
              0.33422652314884305`, 0.4631932454989809, 0.9425439116396759], 
             UndirectedEdge[117, 151] -> 
             RGBColor[
              0.8837846316117963, 0.9101698918252363, 0.9887773611986294], 
             UndirectedEdge[69, 86] -> 
             RGBColor[
              0.6216354645531399, 0.7026625662200192, 0.964073182398758], 
             UndirectedEdge[73, 94] -> 
             RGBColor[
              0.6302236621517395, 0.7058524678621471, 0.9667999083307026], 
             UndirectedEdge[61, 174] -> 
             RGBColor[
              0.7361824775616053, 0.7830033633165918, 0.6821147730298767], 
             UndirectedEdge[175, 187] -> 
             RGBColor[
              0.685927205239969, 0.7543733604558043, 0.9694654709569646], 
             UndirectedEdge[75, 134] -> 
             RGBColor[
              0.31717697021221547`, 0.44665463532914795`, 0.9415223794737577],
              UndirectedEdge[38, 178] -> 
             RGBColor[
              0.35998723545490663`, 0.4818941448003274, 0.9443414898765262], 
             UndirectedEdge[8, 179] -> 
             RGBColor[
              0.512908559287411, 0.5959473566271332, 0.9589441596117543], 
             UndirectedEdge[29, 167] -> 
             RGBColor[
              0.47206778373743563`, 0.5674336241761736, 0.9543402967916812], 
             UndirectedEdge[68, 185] -> 
             RGBColor[
              0.7694716902560269, 0.8204238121077476, 0.9775296154429594], 
             UndirectedEdge[79, 118] -> 
             RGBColor[
              0.6268825913528084, 0.6937708609838618, 0.9139609145346181], 
             UndirectedEdge[171, 173] -> 
             RGBColor[
              0.723880721434201, 0.7836308894399475, 0.9736874499029635], 
             UndirectedEdge[80, 166] -> 
             RGBColor[
              0.3414633073457378, 0.46594930015691616`, 0.9431336277320785], 
             UndirectedEdge[109, 132] -> 
             RGBColor[
              0.42898164453679266`, 0.5388940271089521, 0.9496831293427506], 
             UndirectedEdge[118, 197] -> 
             RGBColor[
              0.9707258242436325, 0.977464318867451, 0.9244231459564382], 
             UndirectedEdge[111, 167] -> 
             RGBColor[
              0.8512170996395129, 0.8835735996593574, 0.933043444172364], 
             UndirectedEdge[113, 122] -> 
             RGBColor[
              0.6168245424685272, 0.697730809642646, 0.9643959535598283], 
             UndirectedEdge[119, 190] -> 
             RGBColor[
              0.2825220211775014, 0.4073770471171104, 0.9396532951466354], 
             UndirectedEdge[19, 130] -> 
             RGBColor[
              0.36269465018925817`, 0.48856960925593546`, 0.9443315602851413],
              UndirectedEdge[35, 167] -> 
             RGBColor[
              0.6109153961856871, 0.6938618694645369, 0.9632960316103603], 
             UndirectedEdge[102, 112] -> 
             RGBColor[
              0.5764525604856474, 0.6636769674663366, 0.9614467539424084], 
             UndirectedEdge[134, 145] -> 
             RGBColor[
              0.3851279039335666, 0.5045566838372625, 0.9461156450668702], 
             UndirectedEdge[109, 150] -> 
             RGBColor[
              0.3896666556004378, 0.5069763479703512, 0.946588109398131], 
             UndirectedEdge[147, 179] -> 
             RGBColor[
              0.41245353868970525`, 0.5171451342315143, 0.949140282242648], 
             UndirectedEdge[63, 102] -> 
             RGBColor[
              0.6675275597425534, 0.7391984108473857, 0.9681792189060257], 
             UndirectedEdge[62, 182] -> 
             RGBColor[
              0.5275837474016634, 0.6164230732818602, 0.9589838876592551], 
             UndirectedEdge[8, 99] -> 
             RGBColor[
              0.5144477901370091, 0.5975651858429334, 0.959031816531551], 
             UndirectedEdge[60, 123] -> 
             RGBColor[
              0.7421033059640585, 0.31587964777261357`, 0.4298112424078575], 
             UndirectedEdge[7, 97] -> 
             RGBColor[
              0.7651174072784319, 0.8141897748971711, 0.8991449921429338], 
             UndirectedEdge[130, 163] -> 
             RGBColor[
              0.6756313143656922, 0.7364891680981098, 0.7464386659861371], 
             UndirectedEdge[127, 135] -> 
             RGBColor[
              0.5376017580345192, 0.6162753857897691, 0.9612027144170503], 
             UndirectedEdge[37, 56] -> 
             RGBColor[
              0.3627479214731626, 0.4876029261863308, 0.9443720391315297], 
             UndirectedEdge[100, 148] -> 
             RGBColor[
              0.48193570226319865`, 0.5784593865269574, 0.9547987295880559], 
             UndirectedEdge[53, 135] -> 
             RGBColor[
              0.6790164221022605, 0.7472225084417312, 0.9701389036433697], 
             UndirectedEdge[103, 154] -> 
             RGBColor[
              0.4083810848116727, 0.528041251813847, 0.9472701933257517], 
             UndirectedEdge[63, 140] -> 
             RGBColor[
              0.3975208388079232, 0.5069682844027147, 0.9477875712122306], 
             UndirectedEdge[8, 75] -> 
             RGBColor[
              0.588382219223978, 0.671226109608615, 0.9633905210845425], 
             UndirectedEdge[50, 53] -> 
             RGBColor[
              0.47196085076208777`, 0.5821981060995187, 0.9515736335030041], 
             UndirectedEdge[1, 167] -> 
             RGBColor[
              0.6174566161198397, 0.6991723264856817, 0.9638109804048549], 
             UndirectedEdge[27, 119] -> 
             RGBColor[
              0.3010363042934724, 0.42683673254534527`, 0.9407076561806627], 
             UndirectedEdge[96, 126] -> 
             RGBColor[
              0.3668745901877154, 0.4869155071946071, 0.9449355819411931], 
             UndirectedEdge[102, 106] -> 
             RGBColor[
              0.640279456477126, 0.7170771731034483, 0.9660341484038802], 
             UndirectedEdge[16, 176] -> 
             RGBColor[
              0.682723154206595, 0.7504122522026853, 0.9702230146306912], 
             UndirectedEdge[40, 166] -> 
             RGBColor[
              0.6242622328940979, 0.6910166981034349, 0.9138116889968676], 
             UndirectedEdge[33, 90] -> 
             RGBColor[
              0.6437500160446132, 0.7137979851071894, 0.9460389929186179], 
             UndirectedEdge[13, 161] -> 
             RGBColor[
              0.5091152964348962, 0.6109344492701636, 0.9548929374669501], 
             UndirectedEdge[11, 106] -> 
             RGBColor[
              0.36367635049253966`, 0.4779138277363051, 0.9452668463399673], 
             UndirectedEdge[88, 167] -> 
             RGBColor[
              0.8347104755884167, 0.8714434241473734, 0.9690652209597188], 
             UndirectedEdge[29, 159] -> 
             RGBColor[
              0.23766836468335045`, 0.3671348986998344, 0.9368462338186553], 
             UndirectedEdge[156, 157] -> 
             RGBColor[
              0.4737168220206355, 0.5812929915541981, 0.952355846893183], 
             UndirectedEdge[171, 183] -> 
             RGBColor[
              0.7020857494335204, 0.7662521703753595, 0.9716086260169374], 
             UndirectedEdge[100, 104] -> 
             RGBColor[
              0.5671645490412309, 0.6455482619498001, 0.9631588822202437], 
             UndirectedEdge[108, 180] -> 
             RGBColor[
              0.5912604661521936, 0.6787457390687699, 0.9611739820778791], 
             UndirectedEdge[178, 179] -> 
             RGBColor[
              0.3292892602089786, 0.44962862645280977`, 0.9425932855998553], 
             UndirectedEdge[150, 151] -> 
             RGBColor[
              0.7173069914670436, 0.7778892633101738, 0.9736358315508231], 
             UndirectedEdge[2, 121] -> 
             RGBColor[
              0.4697906798375479, 0.5772677929372767, 0.9522782475766922], 
             UndirectedEdge[12, 14] -> 
             RGBColor[
              0.8256333169307599, 0.8600003321983312, 0.7071022761548384], 
             UndirectedEdge[43, 131] -> 
             RGBColor[
              0.7147376899229472, 0.7761601126730351, 0.9730229838227364], 
             UndirectedEdge[75, 76] -> 
             RGBColor[
              0.34062887324377633`, 0.46945734232395564`, 0.9429255484901756],
              UndirectedEdge[113, 138] -> 
             RGBColor[
              0.3935489398588025, 0.5152242275108473, 0.9463168588948725], 
             UndirectedEdge[17, 20] -> 
             RGBColor[
              0.7847511313359653, 0.8325969086813969, 0.9789988545423218], 
             UndirectedEdge[86, 187] -> 
             RGBColor[
              0.6701250684350022, 0.7420286110830763, 0.9678904616396098], 
             UndirectedEdge[8, 185] -> 
             RGBColor[
              0.8625973087530318, 0.8932756956922157, 0.9867564954302139], 
             UndirectedEdge[4, 41] -> 
             RGBColor[
              0.9473837707951329, 0.9588924512411655, 0.9193906735402733], 
             UndirectedEdge[8, 107] -> 
             RGBColor[
              0.7926194031169906, 0.837953860795974, 0.9799554527142336], 
             UndirectedEdge[149, 192] -> 
             RGBColor[
              0.8244690881666252, 0.8632145701265971, 0.9830292258134125], 
             UndirectedEdge[11, 140] -> 
             RGBColor[
              0.21126530306058122`, 0.33938360688350844`, 0.9353426185190679],
              UndirectedEdge[94, 153] -> 
             RGBColor[
              0.3218293024371526, 0.44814848456049267`, 0.9419116688248532], 
             UndirectedEdge[56, 79] -> 
             RGBColor[
              0.3479657636500025, 0.4720659410712509, 0.9435302171117435], 
             UndirectedEdge[5, 15] -> 
             RGBColor[
              0.3917447760106295, 0.5079764927744428, 0.9468142386550134], 
             UndirectedEdge[79, 128] -> 
             RGBColor[
              0.5620706545674083, 0.6436004232678176, 0.9623527815491265], 
             UndirectedEdge[109, 152] -> 
             RGBColor[
              0.5840359096728558, 0.6614969923336427, 0.9643899660814957], 
             UndirectedEdge[118, 192] -> 
             RGBColor[
              0.8816489246922752, 0.9072993782633592, 0.9339094022628729], 
             UndirectedEdge[99, 107] -> 
             RGBColor[
              0.48284053099060636`, 0.5728390629140767, 0.9558906003316328], 
             UndirectedEdge[3, 189] -> 
             RGBColor[
              0.7339294518602307, 0.7906647349071445, 0.9575073176916333], 
             UndirectedEdge[35, 138] -> 
             RGBColor[
              0.4179416301319725, 0.5350273123527807, 0.9482371408265451], 
             UndirectedEdge[12, 86] -> 
             RGBColor[
              0.8517439803954985, 0.8803981809453771, 0.7097047430709804], 
             UndirectedEdge[16, 127] -> 
             RGBColor[
              0.5251329053349324, 0.6063330611051088, 0.9600134241154875], 
             UndirectedEdge[37, 195] -> 
             RGBColor[
              0.5591979560526883, 0.6450599051673807, 0.9615106676107295], 
             UndirectedEdge[57, 71] -> 
             RGBColor[
              0.2700354498073002, 0.3993080273289351, 0.9387571092664047], 
             UndirectedEdge[58, 73] -> 
             RGBColor[
              0.5473733203747251, 0.6262164014696769, 0.9618091098265298], 
             UndirectedEdge[35, 153] -> 
             RGBColor[
              0.37953217079409607`, 0.49673335476520253`, 0.9459737364043548],
              UndirectedEdge[35, 122] -> 
             RGBColor[
              0.6412172327416972, 0.7175338944845795, 0.9663162354915009], 
             UndirectedEdge[19, 44] -> 
             RGBColor[
              0.3698517061534716, 0.4947686914080449, 0.9447876015624449], 
             UndirectedEdge[181, 192] -> 
             RGBColor[
              0.6083079788949963, 0.6904240070053427, 0.9638339951044594], 
             UndirectedEdge[119, 128] -> 
             RGBColor[
              0.6196550164196759, 0.697223350189814, 0.9658848377138607], 
             UndirectedEdge[116, 153] -> 
             RGBColor[
              0.32003903190501504`, 0.44659784220716836`, 0.9417975943696194],
              UndirectedEdge[186, 193] -> 
             RGBColor[
              0.4876401842768519, 0.5923810945298229, 0.9535114909574087], 
             UndirectedEdge[22, 119] -> 
             RGBColor[
              0.6734015372192625, 0.7393648480838836, 0.9462384106985913], 
             UndirectedEdge[85, 109] -> 
             RGBColor[
              0.31550666550954887`, 0.4442299910937768, 0.9414517552199024], 
             UndirectedEdge[98, 99] -> 
             RGBColor[
              0.29268747572323395`, 0.4183102760533596, 0.9402230969238614], 
             UndirectedEdge[161, 175] -> 
             RGBColor[
              0.6799321725217007, 0.7495063228219678, 0.968993520020854], 
             UndirectedEdge[54, 61] -> 
             RGBColor[
              0.5562448570900622, 0.6506236593877839, 0.9582087792236303], 
             UndirectedEdge[43, 154] -> 
             RGBColor[
              0.6671050499073917, 0.7374897896824282, 0.9692731679166025], 
             UndirectedEdge[87, 95] -> 
             RGBColor[
              0.5581929163571224, 0.6475299881005556, 0.9604235269488532], 
             UndirectedEdge[12, 108] -> 
             RGBColor[
              0.7564739066329246, 0.8041017773165935, 0.7014881188566651], 
             UndirectedEdge[15, 48] -> 
             RGBColor[
              0.3929205283866216, 0.5092122830686168, 0.9468811960134562], 
             UndirectedEdge[13, 187] -> 
             RGBColor[0.5151103291531645, 0.615801486904, 0.9553648884030606],
              UndirectedEdge[15, 28] -> 
             RGBColor[
              0.5868996928045503, 0.6753046508010356, 0.9607628733926616], 
             UndirectedEdge[52, 134] -> 
             RGBColor[
              0.2837087404006422, 0.4155262527071294, 0.9394681651051229], 
             UndirectedEdge[66, 172] -> 
             RGBColor[
              0.6553901131557707, 0.7233270671132963, 0.9387101945102667], 
             UndirectedEdge[101, 176] -> 
             RGBColor[
              0.5684761456425267, 0.6605535704479444, 0.9591716710631666], 
             UndirectedEdge[119, 192] -> 
             RGBColor[
              0.5805778189124402, 0.6664055361868185, 0.9620670538311886], 
             UndirectedEdge[168, 184] -> 
             RGBColor[
              0.6775194105326652, 0.7384599621331838, 0.7752268602809431], 
             UndirectedEdge[16, 175] -> 
             RGBColor[
              0.7930139686485201, 0.8384190326279279, 0.9799531337970045], 
             UndirectedEdge[60, 104] -> 
             RGBColor[
              0.7372195171215721, 0.7943717480469046, 0.9748390184541387], 
             UndirectedEdge[122, 136] -> 
             RGBColor[
              0.8090955904393657, 0.8509561603413593, 0.9815628878761029], 
             UndirectedEdge[107, 157] -> 
             RGBColor[
              0.5642462898450773, 0.6529712770044157, 0.960725371410772], 
             UndirectedEdge[86, 110] -> 
             RGBColor[
              0.7118889228676637, 0.7748523041912048, 0.9719180929173772], 
             UndirectedEdge[5, 9] -> 
             RGBColor[
              0.5836756919531245, 0.6604812375210598, 0.9644659750175691], 
             UndirectedEdge[3, 77] -> 
             RGBColor[
              0.6148609595454528, 0.6859480553933879, 0.9495940067807862], 
             UndirectedEdge[84, 139] -> 
             RGBColor[
              0.4110089312244277, 0.5304170111422272, 0.9474101035500611], 
             UndirectedEdge[96, 191] -> 
             RGBColor[
              0.6218699314232927, 0.688508047388934, 0.9138269941299589], 
             UndirectedEdge[46, 151] -> 
             RGBColor[
              0.6157545063362084, 0.6910695543698285, 0.9667667699829925], 
             UndirectedEdge[72, 191] -> 
             RGBColor[
              0.6605900864484742, 0.7267169707213121, 0.9161231627255659], 
             UndirectedEdge[111, 185] -> 
             RGBColor[
              0.9431230186170383, 0.9560257652370406, 0.9420300663292881], 
             UndirectedEdge[23, 129] -> 
             RGBColor[
              0.31864313698632074`, 0.4486636245884256, 0.9415887413769509], 
             UndirectedEdge[101, 123] -> 
             RGBColor[
              0.7499289617223109, 0.3222328676589373, 0.4304273066954687], 
             UndirectedEdge[122, 142] -> 
             RGBColor[
              0.4783433951998197, 0.5658525632721598, 0.9559922426973546], 
             UndirectedEdge[18, 174] -> 
             RGBColor[
              0.7045635221935256, 0.7564325254911759, 0.679874602209261], 
             UndirectedEdge[123, 135] -> 
             RGBColor[
              0.8344062025647476, 0.3887668719518714, 0.4385877292748602], 
             UndirectedEdge[171, 178] -> 
             RGBColor[
              0.5170840268059188, 0.6188311331878162, 0.9551258952128145], 
             UndirectedEdge[81, 173] -> 
             RGBColor[
              0.6028122801404876, 0.6821306340808456, 0.9650438293349203], 
             UndirectedEdge[77, 102] -> 
             RGBColor[
              0.5160625375984343, 0.6081807689711329, 0.957715534494614], 
             UndirectedEdge[31, 171] -> 
             RGBColor[
              0.784629887816497, 0.8293062726350519, 0.870389420231694], 
             UndirectedEdge[109, 196] -> 
             RGBColor[
              0.5632655457864593, 0.6449352679671385, 0.9624088702320885], 
             UndirectedEdge[18, 153] -> 
             RGBColor[
              0.33725958594809147`, 0.4615134205890686, 0.9428948728457063], 
             UndirectedEdge[97, 140] -> 
             RGBColor[
              0.6031515611515043, 0.6679025380250225, 0.8884685755683855], 
             UndirectedEdge[116, 167] -> 
             RGBColor[
              0.5514222572966061, 0.6437263569065026, 0.9591198895756249], 
             UndirectedEdge[128, 190] -> 
             RGBColor[
              0.5187811901719365, 0.5981004514776069, 0.959887510592828], 
             UndirectedEdge[94, 126] -> 
             RGBColor[
              0.4323990445502214, 0.5483409673897188, 0.9489396967884631], 
             UndirectedEdge[41, 198] -> 
             RGBColor[
              0.9459770674329909, 0.9583107432502924, 0.9427033886825706], 
             UndirectedEdge[11, 77] -> 
             RGBColor[
              0.23945943161384797`, 0.36901742360398965`, 0.936948232430701], 
             UndirectedEdge[29, 122] -> 
             RGBColor[
              0.5023696202934458, 0.5911056491962162, 0.9573605006728219], 
             UndirectedEdge[84, 152] -> 
             RGBColor[
              0.6690722114282216, 0.7386189204350067, 0.9696814324428427], 
             UndirectedEdge[16, 64] -> 
             RGBColor[
              0.8704066119953827, 0.8995026221197768, 0.9875013537449167], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.4060472533286783, 0.5260881901553441, 0.9471025884276656], 
             UndirectedEdge[26, 121] -> 
             RGBColor[
              0.47491374898464517`, 0.5817051379395501, 0.952604685012593], 
             UndirectedEdge[40, 74] -> 
             RGBColor[
              0.7546428331090943, 0.8062642789760112, 0.922492897902296], 
             UndirectedEdge[78, 91] -> 
             RGBColor[
              0.5456991984761768, 0.6412506528059538, 0.9577050083403758], 
             UndirectedEdge[139, 152] -> 
             RGBColor[
              0.6387693136396366, 0.7123720734384624, 0.9677505585915545], 
             UndirectedEdge[40, 196] -> 
             RGBColor[
              0.9204149625277742, 0.9378690819903162, 0.937697507458279], 
             UndirectedEdge[6, 86] -> 
             RGBColor[
              0.76822095549916, 0.8189052025090177, 0.9775205666676715], 
             UndirectedEdge[82, 180] -> 
             RGBColor[
              0.7094932749550096, 0.7729808058342409, 0.9716793171220464], 
             UndirectedEdge[44, 90] -> 
             RGBColor[
              0.6667110547528374, 0.7336856827808922, 0.9475020500014566], 
             UndirectedEdge[4, 66] -> 
             RGBColor[
              0.9793579129773494, 0.9834858949238138, 0.8911720182609901], 
             UndirectedEdge[131, 143] -> 
             RGBColor[
              0.45532725593950685`, 0.5661169899568392, 0.9509762680413807], 
             UndirectedEdge[22, 144] -> 
             RGBColor[
              0.8243622393806733, 0.8631620315494208, 0.9580479380980371], 
             UndirectedEdge[35, 160] -> 
             RGBColor[
              0.7437150480720474, 0.7977081321019115, 0.9341118695066712], 
             UndirectedEdge[76, 174] -> 
             RGBColor[
              0.6588587546491477, 0.7168453530326462, 0.6769623348364723], 
             UndirectedEdge[85, 196] -> 
             RGBColor[
              0.6075329857937273, 0.6867452571248718, 0.9651025807733355], 
             UndirectedEdge[6, 137] -> 
             RGBColor[
              0.9080741620810763, 0.9270790107256939, 0.8952745789086087], 
             UndirectedEdge[123, 177] -> 
             RGBColor[
              0.6422313494595313, 0.23085126754728344`, 0.4227931773152439], 
             UndirectedEdge[29, 113] -> 
             RGBColor[
              0.34143437236233354`, 0.4625253322945426, 0.943272968837941], 
             UndirectedEdge[96, 174] -> 
             RGBColor[
              0.6236087843200808, 0.6816421292674881, 0.6748872833411379], 
             UndirectedEdge[74, 158] -> 
             RGBColor[
              0.5461467608363232, 0.6424255699349464, 0.9574138200959905], 
             UndirectedEdge[46, 121] -> 
             RGBColor[
              0.45397240794992666`, 0.5632194512306794, 0.9512830394516726], 
             UndirectedEdge[32, 165] -> 
             RGBColor[
              0.2328153283171212, 0.36203404977864995`, 0.9365698605770225], 
             UndirectedEdge[32, 148] -> 
             RGBColor[
              0.4873698108546962, 0.5841709791990058, 0.9551081940332984], 
             UndirectedEdge[27, 190] -> 
             RGBColor[
              0.20016247804573295`, 0.32771383383313824`, 0.9347103290596299],
              UndirectedEdge[100, 123] -> 
             RGBColor[
              0.628733327243831, 0.21666399037454395`, 0.42202448491859423`], 
             UndirectedEdge[45, 172] -> 
             RGBColor[
              0.6389076185057936, 0.7110344495909515, 0.9666107586295832], 
             UndirectedEdge[85, 99] -> 
             RGBColor[
              0.2822215117637209, 0.4092451841062732, 0.9395562149550498], 
             UndirectedEdge[106, 112] -> 
             RGBColor[
              0.4588568869829757, 0.5699770618744623, 0.9509793340695126], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.6040196233607302, 0.6872227783898147, 0.9633435641961573], 
             UndirectedEdge[43, 197] -> 
             RGBColor[
              0.9165678126053045, 0.9357890318705879, 0.9738311938623454], 
             UndirectedEdge[26, 164] -> 
             RGBColor[
              0.32561408818784454`, 0.45604643970765935`, 0.9419836798371286],
              UndirectedEdge[100, 130] -> 
             RGBColor[
              0.30459351168747617`, 0.43295827013156535`, 0.9408229920336322],
              UndirectedEdge[46, 196] -> 
             RGBColor[
              0.5801404907537808, 0.6626719050611009, 0.9633698733837335], 
             UndirectedEdge[156, 181] -> 
             RGBColor[
              0.5094046878560287, 0.6122040272165239, 0.9546298461466736], 
             UndirectedEdge[62, 96] -> 
             RGBColor[
              0.263425515325879, 0.39420729712280583`, 0.9383130654434576], 
             UndirectedEdge[54, 58] -> 
             RGBColor[
              0.42634527643402914`, 0.5310518191413218, 0.9499946058779888], 
             UndirectedEdge[179, 183] -> 
             RGBColor[
              0.5142909828365803, 0.5970496636403531, 0.9590760164039782], 
             UndirectedEdge[65, 198] -> 
             RGBColor[
              0.6113336170559349, 0.6775261175116567, 0.9156372476809949], 
             UndirectedEdge[4, 80] -> 
             RGBColor[
              0.7039917841442767, 0.7637382352951794, 0.8978975938831188], 
             UndirectedEdge[159, 197] -> 
             RGBColor[
              0.6021354343409014, 0.6725053166520295, 0.948482962234108], 
             UndirectedEdge[78, 136] -> 
             RGBColor[
              0.6365487415687421, 0.7123882749970711, 0.966716184541727], 
             UndirectedEdge[153, 188] -> 
             RGBColor[
              0.24883286763739126`, 0.3788694991749032, 0.9374820357454858], 
             UndirectedEdge[35, 174] -> 
             RGBColor[
              0.7468361070395302, 0.7916524596673098, 0.6829534657679095], 
             UndirectedEdge[82, 130] -> 
             RGBColor[
              0.5571656365579905, 0.6470212477184898, 0.960196796354515], 
             UndirectedEdge[124, 176] -> 
             RGBColor[
              0.5205951240707464, 0.6216816001205325, 0.9554023016510749], 
             UndirectedEdge[6, 186] -> 
             RGBColor[
              0.5926022634611984, 0.6748319700373635, 0.9636821277808622], 
             UndirectedEdge[1, 144] -> 
             RGBColor[
              0.6015371833500611, 0.6867359446137606, 0.962224280121921], 
             UndirectedEdge[43, 67] -> 
             RGBColor[
              0.5823645094492196, 0.6622277513450564, 0.9639179421779209], 
             UndirectedEdge[24, 119] -> 
             RGBColor[
              0.5628991268310005, 0.6525948075697616, 0.9603050070212813], 
             UndirectedEdge[93, 139] -> 
             RGBColor[
              0.32625785998220386`, 0.4535948783948345, 0.9421348806444768], 
             UndirectedEdge[38, 146] -> 
             RGBColor[
              0.4415495890902687, 0.548110137823673, 0.9507623771274478], 
             UndirectedEdge[110, 127] -> 
             RGBColor[
              0.45980999635904274`, 0.5551110820411136, 0.9535533925532148], 
             UndirectedEdge[41, 81] -> 
             RGBColor[
              0.6208836440538928, 0.6965402491312892, 0.9667674921574778], 
             UndirectedEdge[85, 194] -> 
             RGBColor[
              0.6096413469807287, 0.6884264071054469, 0.965303678145508], 
             UndirectedEdge[52, 70] -> 
             RGBColor[
              0.28185778149409, 0.4135807775387701, 0.939362755733643], 
             UndirectedEdge[149, 170] -> 
             RGBColor[
              0.6876994834705831, 0.7542530110529748, 0.9708441019356643], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.44273709623297114`, 0.5561422545390299, 0.9499170093967033], 
             UndirectedEdge[92, 155] -> 
             RGBColor[
              0.45637421716162696`, 0.5575122663495081, 0.9524058778946478], 
             UndirectedEdge[57, 141] -> 
             RGBColor[
              0.2586259898153832, 0.3873159614758852, 0.9381073573986485], 
             UndirectedEdge[149, 159] -> 
             RGBColor[
              0.55976783255653, 0.6392438196302153, 0.9625149589592459], 
             UndirectedEdge[142, 167] -> 
             RGBColor[
              0.4480415586438096, 0.5421805382521172, 0.952972038816214], 
             UndirectedEdge[117, 173] -> 
             RGBColor[
              0.8558154096755966, 0.887867993457615, 0.9861096318419355], 
             UndirectedEdge[99, 179] -> 
             RGBColor[
              0.2031296871610268, 0.330832558745236, 0.9348793072291535], 
             UndirectedEdge[5, 11] -> 
             RGBColor[
              0.23508235664275431`, 0.3644168402867881, 0.9366989644863994], 
             UndirectedEdge[29, 188] -> 
             RGBColor[
              0.23512775947879871`, 0.3644645615461768, 0.9367015501107446], 
             UndirectedEdge[46, 178] -> 
             RGBColor[
              0.38098858977172634`, 0.503967899750076, 0.9455374859361496], 
             UndirectedEdge[101, 137] -> 
             RGBColor[
              0.8028180298614014, 0.8443894097171354, 0.8850807931530624], 
             UndirectedEdge[3, 20] -> 
             RGBColor[
              0.7960109538550519, 0.8410652949663338, 0.9623946009407005], 
             UndirectedEdge[186, 199] -> 
             RGBColor[
              0.3452541229305384, 0.47346350113082025`, 0.9432202653102684], 
             UndirectedEdge[156, 179] -> 
             RGBColor[
              0.3907718323165663, 0.4995429482480589, 0.947433418894247], 
             UndirectedEdge[67, 87] -> 
             RGBColor[
              0.5265924579960151, 0.6181955671324223, 0.9584818740768651], 
             UndirectedEdge[3, 10] -> 
             RGBColor[
              0.6614762047967008, 0.7295132338407734, 0.9524475095781746], 
             UndirectedEdge[55, 185] -> 
             RGBColor[
              0.8031575761641336, 0.8468066329754489, 0.9808411983868], 
             UndirectedEdge[5, 28] -> 
             RGBColor[
              0.4606507120688045, 0.5637114506391327, 0.952379599561497], 
             UndirectedEdge[37, 170] -> 
             RGBColor[
              0.40100601018729054`, 0.5193580353062798, 0.9471916958084926], 
             UndirectedEdge[49, 154] -> 
             RGBColor[
              0.4496746890130716, 0.5638076962962044, 0.9499013852709643], 
             UndirectedEdge[24, 89] -> 
             RGBColor[
              0.4983143517986373, 0.5916140025436534, 0.956374287682124], 
             UndirectedEdge[73, 115] -> 
             RGBColor[
              0.5466364287342218, 0.6254418816338795, 0.9617671449377365], 
             UndirectedEdge[153, 174] -> 
             RGBColor[
              0.6216936027498714, 0.679629152007673, 0.6747782165839716], 
             UndirectedEdge[119, 183] -> 
             RGBColor[
              0.6051936783934864, 0.685692271790294, 0.9645055023831338], 
             UndirectedEdge[4, 168] -> 
             RGBColor[
              0.674458757405902, 0.7381582119074832, 0.8960157755343798], 
             UndirectedEdge[144, 181] -> 
             RGBColor[
              0.5620867095692077, 0.6543156001133789, 0.9592270909403848], 
             UndirectedEdge[53, 123] -> 
             RGBColor[
              0.7080300788367595, 0.28821746700928275`, 0.4271288731540529], 
             UndirectedEdge[110, 162] -> 
             RGBColor[
              0.7099387288847996, 0.773328797829768, 0.9717237158067642], 
             UndirectedEdge[127, 176] -> 
             RGBColor[
              0.3642131572464581, 0.4785833468215004, 0.9452878315247235], 
             UndirectedEdge[9, 102] -> 
             RGBColor[
              0.8298653593055816, 0.8676781305624512, 0.9835012767440328], 
             UndirectedEdge[27, 195] -> 
             RGBColor[
              0.5196406169500273, 0.603482633690325, 0.9592579356686718], 
             UndirectedEdge[60, 130] -> 
             RGBColor[
              0.4746484797678173, 0.5817817562286698, 0.9525031282675271], 
             UndirectedEdge[89, 122] -> 
             RGBColor[
              0.5159930438800769, 0.6054247311607103, 0.9581363344920313], 
             UndirectedEdge[5, 106] -> 
             RGBColor[
              0.394089789124669, 0.509880280062057, 0.9469988466774166], 
             UndirectedEdge[83, 199] -> 
             RGBColor[
              0.37625059459122956`, 0.5003110869553464, 0.945195333075384], 
             UndirectedEdge[118, 125] -> 
             RGBColor[
              0.6365225210875476, 0.7039030383419195, 0.9145098942720136], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.7122696858029098, 0.7739782249705769, 0.973033856871137], 
             UndirectedEdge[5, 112] -> 
             RGBColor[
              0.33026289313319035`, 0.4564800744249453, 0.9424114522159448], 
             UndirectedEdge[109, 146] -> 
             RGBColor[
              0.4456759984397668, 0.5524472556794593, 0.9509973700354262], 
             UndirectedEdge[164, 184] -> 
             RGBColor[
              0.6492605227616084, 0.7135776834130036, 0.7734410891141885], 
             UndirectedEdge[51, 164] -> 
             RGBColor[
              0.5959733589582319, 0.6752163447523044, 0.964892185270839], 
             UndirectedEdge[45, 168] -> 
             RGBColor[
              0.649290815332912, 0.7200278528079548, 0.9672723667499068], 
             UndirectedEdge[148, 165] -> 
             RGBColor[
              0.45775494025732927`, 0.5530438725099269, 0.9534216709640533], 
             UndirectedEdge[166, 184] -> 
             RGBColor[
              0.6285755367285868, 0.6918364515884348, 0.7722631097603025], 
             UndirectedEdge[21, 132] -> 
             RGBColor[
              0.4984041604415266, 0.6024920786781938, 0.953979699076424], 
             UndirectedEdge[96, 157] -> 
             RGBColor[
              0.31285023268221146`, 0.440725408883455, 0.941326563520989], 
             UndirectedEdge[42, 102] -> 
             RGBColor[
              0.803629057590298, 0.8467580157401224, 0.980998834865006], 
             UndirectedEdge[117, 120] -> 
             RGBColor[
              0.750435937067143, 0.805135788163081, 0.9757149163497344], 
             UndirectedEdge[25, 129] -> 
             RGBColor[
              0.3628552388313988, 0.48695792504178126`, 0.9444058974112928], 
             UndirectedEdge[57, 90] -> 
             RGBColor[
              0.6451014631183892, 0.7149685406367894, 0.9461251059311212], 
             UndirectedEdge[51, 184] -> 
             RGBColor[
              0.9408775028505123, 0.9515657982916991, 0.7976892568145568], 
             UndirectedEdge[95, 103] -> 
             RGBColor[
              0.355241002714608, 0.4821136344446084, 0.9438566204590582], 
             UndirectedEdge[47, 105] -> 
             RGBColor[
              0.33773322025411917`, 0.4662305702798498, 0.9427673552783735], 
             UndirectedEdge[127, 177] -> 
             RGBColor[
              0.24933947837669465`, 0.37940197918288715`, 0.9375108864776258],
              UndirectedEdge[73, 153] -> 
             RGBColor[
              0.5627840262190241, 0.6424140304072201, 0.9626867267262663], 
             UndirectedEdge[137, 199] -> 
             RGBColor[
              0.6607260215504163, 0.7257105418191507, 0.874812716438015], 
             UndirectedEdge[138, 185] -> 
             RGBColor[
              0.6160882702114301, 0.6925846849701613, 0.9663708090055368], 
             UndirectedEdge[88, 136] -> 
             RGBColor[
              0.8963481121841532, 0.9197604829644559, 0.9751648273222532], 
             UndirectedEdge[55, 76] -> 
             RGBColor[
              0.5170335836942934, 0.6144421537234046, 0.956716399276371], 
             UndirectedEdge[135, 176] -> 
             RGBColor[
              0.6951920069061818, 0.7603545768873455, 0.971412304932254], 
             UndirectedEdge[69, 123] -> 
             RGBColor[
              0.7223760559047475, 0.29986417747197736`, 0.4282582410198905], 
             UndirectedEdge[2, 40] -> 
             RGBColor[
              0.6610818590985388, 0.7271387947597809, 0.9160028931815105], 
             UndirectedEdge[105, 174] -> 
             RGBColor[
              0.6817456844627123, 0.7366688613066161, 0.6784206697660752], 
             UndirectedEdge[89, 138] -> 
             RGBColor[
              0.29271744127035215`, 0.42291814902891156`, 0.9400572398270755],
              UndirectedEdge[37, 128] -> 
             RGBColor[
              0.5768528123905685, 0.6591374083828975, 0.9631946035689127], 
             UndirectedEdge[88, 153] -> 
             RGBColor[
              0.6033272501968256, 0.6743149094480392, 0.9517429257537133], 
             UndirectedEdge[113, 197] -> 
             RGBColor[
              0.7059014420198846, 0.7678957502467378, 0.9549096972533937], 
             UndirectedEdge[31, 178] -> 
             RGBColor[
              0.7245339251171068, 0.7805176628234194, 0.8656584459092331], 
             UndirectedEdge[82, 177] -> 
             RGBColor[
              0.5243811399255578, 0.6170818644696656, 0.95816429767164], 
             UndirectedEdge[87, 108] -> 
             RGBColor[
              0.6429592733343678, 0.7191332401649717, 0.9663268360249766], 
             UndirectedEdge[64, 86] -> 
             RGBColor[
              0.8039755415438667, 0.8474149388886831, 0.9809308710031114], 
             UndirectedEdge[116, 157] -> 
             RGBColor[
              0.3765844165125799, 0.5006002267252425, 0.9452166039130252], 
             UndirectedEdge[120, 168] -> 
             RGBColor[
              0.5103483312788137, 0.6105852063026737, 0.9554720795951148], 
             UndirectedEdge[18, 54] -> 
             RGBColor[
              0.5246259017219825, 0.624052821562368, 0.9559686084030147], 
             UndirectedEdge[161, 176] -> 
             RGBColor[
              0.5696413580797757, 0.6614995423967251, 0.9592634008545406], 
             UndirectedEdge[168, 172] -> 
             RGBColor[
              0.35049095758432325`, 0.4779993840969658, 0.9435539517836564], 
             UndirectedEdge[142, 157] -> 
             RGBColor[
              0.2732037178597835, 0.399054408070857, 0.9390687531536144], 
             UndirectedEdge[121, 171] -> 
             RGBColor[
              0.590067844984119, 0.6780826846684196, 0.9608714487283375], 
             UndirectedEdge[47, 94] -> 
             RGBColor[
              0.3451207744739936, 0.47262929843583357`, 0.9432380837007062], 
             UndirectedEdge[70, 93] -> 
             RGBColor[
              0.27496196647766435`, 0.406332838736582, 0.9389700492699018], 
             UndirectedEdge[32, 163] -> 
             RGBColor[
              0.6280338930012066, 0.6909804617622248, 0.74356259315353], 
             UndirectedEdge[35, 142] -> 
             RGBColor[
              0.3418008375418775, 0.4570753312124196, 0.9438249927941463], 
             UndirectedEdge[12, 193] -> 
             RGBColor[
              0.8042220953182746, 0.842865907922748, 0.705247031177354], 
             UndirectedEdge[35, 94] -> 
             RGBColor[
              0.44697180672681147`, 0.5601717922201295, 0.950086918008791], 
             UndirectedEdge[116, 174] -> 
             RGBColor[
              0.6873429681504493, 0.7415169471092756, 0.6787773237331741], 
             UndirectedEdge[112, 140] -> 
             RGBColor[
              0.30644583955101723`, 0.43144684102166564`, 0.9410551062486132],
              UndirectedEdge[86, 176] -> 
             RGBColor[
              0.616292083755079, 0.6983245689715916, 0.9636525318888858], 
             UndirectedEdge[61, 73] -> 
             RGBColor[
              0.6772729010307581, 0.7457882417161389, 0.9700232831721713], 
             UndirectedEdge[33, 66] -> 
             RGBColor[
              0.6483447708548871, 0.7172247457214713, 0.9382612715288061], 
             UndirectedEdge[48, 106] -> 
             RGBColor[
              0.3952655415006612, 0.511116070356231, 0.9470658040358595], 
             UndirectedEdge[86, 199] -> 
             RGBColor[
              0.5208728149685, 0.6175367336024745, 0.9570587041970777], 
             UndirectedEdge[10, 59] -> 
             RGBColor[
              0.4177256740126607, 0.5358368552288513, 0.947948018619662], 
             UndirectedEdge[1, 113] -> 
             RGBColor[
              0.4868232047447376, 0.5942640346040509, 0.9527436524511148], 
             UndirectedEdge[125, 128] -> 
             RGBColor[
              0.5717105843021476, 0.6537326006258753, 0.9629017612865218], 
             UndirectedEdge[53, 165] -> 
             RGBColor[
              0.3463263471150163, 0.4636526720587096, 0.943916978484968], 
             UndirectedEdge[87, 143] -> 
             RGBColor[
              0.5620395502716101, 0.6508617490598427, 0.9606686310604395], 
             UndirectedEdge[61, 105] -> 
             RGBColor[
              0.42893062302901214`, 0.5451239677134276, 0.9487774968484255], 
             UndirectedEdge[29, 47] -> 
             RGBColor[
              0.26397603038268563`, 0.39478592335218027`, 0.9383444164615287],
              UndirectedEdge[24, 27] -> 
             RGBColor[
              0.4805395836992321, 0.5729315942857894, 0.9553620409342758], 
             UndirectedEdge[98, 117] -> 
             RGBColor[
              0.6108776997119714, 0.6901320575902333, 0.965090231555996], 
             UndirectedEdge[1, 88] -> 
             RGBColor[
              0.7350109744206372, 0.7916486741288209, 0.9604331237321457], 
             UndirectedEdge[190, 195] -> 
             RGBColor[
              0.5011263338340562, 0.5840229482620902, 0.9582035746346447], 
             UndirectedEdge[4, 173] -> 
             RGBColor[
              0.9293124068817277, 0.9444828361907219, 0.9176670107177156], 
             UndirectedEdge[81, 164] -> 
             RGBColor[
              0.31969974289360503`, 0.4509237310774269, 0.9416068229848298], 
             UndirectedEdge[82, 123] -> 
             RGBColor[
              0.7971147438241739, 0.3593726420991603, 0.43494035446584944`], 
             UndirectedEdge[43, 87] -> 
             RGBColor[
              0.8214499842550504, 0.8609048717760386, 0.9827153468417953], 
             UndirectedEdge[38, 171] -> 
             RGBColor[
              0.4200831981542969, 0.5306827546119599, 0.949072464198987], 
             UndirectedEdge[46, 85] -> 
             RGBColor[
              0.33238161047687054`, 0.46196662818773915`, 0.9424127583715476],
              UndirectedEdge[64, 69] -> 
             RGBColor[
              0.7148302447049693, 0.7760909050845961, 0.9731964116640248], 
             UndirectedEdge[60, 82] -> 
             RGBColor[
              0.6741890746823485, 0.7446244348076607, 0.9686913953105603], 
             UndirectedEdge[77, 189] -> 
             RGBColor[
              0.3933184375318489, 0.5103011387606997, 0.946842811623299], 
             UndirectedEdge[101, 187] -> 
             RGBColor[
              0.6223091303224499, 0.7042576125594291, 0.9634096008138906], 
             UndirectedEdge[64, 161] -> 
             RGBColor[
              0.7573248158685633, 0.8105899123138167, 0.9765417399687661], 
             UndirectedEdge[7, 160] -> 
             RGBColor[
              0.7622744007123663, 0.8127754506646307, 0.935572929731666], 
             UndirectedEdge[16, 83] -> 
             RGBColor[
              0.6325896114662829, 0.708848636608072, 0.966514753357956], 
             UndirectedEdge[13, 124] -> 
             RGBColor[
              0.4600690624258669, 0.571116506993971, 0.9510318382634844], 
             UndirectedEdge[46, 171] -> 
             RGBColor[
              0.4410845524711166, 0.5527565095617084, 0.9502684602586104], 
             UndirectedEdge[1, 197] -> 
             RGBColor[
              0.7368353522272071, 0.7930092921098162, 0.957344927979561], 
             UndirectedEdge[26, 80] -> 
             RGBColor[
              0.38340600269727604`, 0.5065087418155355, 0.9456512693526222], 
             UndirectedEdge[23, 43] -> 
             RGBColor[
              0.6123492383560059, 0.6901627086687804, 0.9657566421978131], 
             UndirectedEdge[13, 86] -> 
             RGBColor[
              0.5557660221101997, 0.6477594758450301, 0.9592820685012953], 
             UndirectedEdge[31, 146] -> 
             RGBColor[
              0.8060962787524688, 0.8467336558467651, 0.8720793331601546], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.21110153438517268`, 0.33921147562212034`, 0.9353332921352775],
              UndirectedEdge[124, 127] -> 
             RGBColor[
              0.36300487519908375`, 0.47760240902295603`, 0.9451927111358712],
              UndirectedEdge[60, 163] -> 
             RGBColor[
              0.7926547524900502, 0.8340923551872808, 0.7549332649421824], 
             UndirectedEdge[4, 184] -> 
             RGBColor[
              0.9911040135271256, 0.989625386726698, 0.727027075911343], 
             UndirectedEdge[144, 192] -> 
             RGBColor[
              0.7315385210738509, 0.7902027196523558, 0.9738765812306345], 
             UndirectedEdge[38, 192] -> 
             RGBColor[
              0.5203730986014621, 0.6100284463843952, 0.9583857721287039], 
             UndirectedEdge[49, 108] -> 
             RGBColor[
              0.48130096389325216`, 0.589483330991382, 0.9523911214803943], 
             UndirectedEdge[83, 165] -> 
             RGBColor[
              0.31236838917862525`, 0.43522112490971065`, 0.9414821185011171],
              UndirectedEdge[183, 192] -> 
             RGBColor[
              0.8023756498806857, 0.8455978621477951, 0.9809219339466544], 
             UndirectedEdge[79, 159] -> 
             RGBColor[
              0.2582922014500773, 0.38881185876844027`, 0.9380207308122881], 
             UndirectedEdge[81, 166] -> 
             RGBColor[
              0.2990147568605835, 0.4291824992528579, 0.9404288436309438], 
             UndirectedEdge[118, 119] -> 
             RGBColor[
              0.6844669532050759, 0.7473937879058581, 0.9174929706993523], 
             UndirectedEdge[47, 153] -> 
             RGBColor[
              0.2776811385412782, 0.40919086098090673`, 0.93912490209627], 
             UndirectedEdge[74, 184] -> 
             RGBColor[
              0.7589561369435832, 0.8070840324610109, 0.780944318665731], 
             UndirectedEdge[149, 190] -> 
             RGBColor[
              0.5264132904316865, 0.604186081056889, 0.9606154671288593], 
             UndirectedEdge[55, 139] -> 
             RGBColor[
              0.5430266152607199, 0.63695601121849, 0.9583726522630484], 
             UndirectedEdge[22, 138] -> 
             RGBColor[
              0.6473079060967372, 0.716763856309586, 0.9445757475971559], 
             UndirectedEdge[113, 144] -> 
             RGBColor[
              0.5706032731427386, 0.6616224027506822, 0.9597890493957537], 
             UndirectedEdge[80, 172] -> 
             RGBColor[
              0.38002398432269785`, 0.5035794074846619, 0.9454357701323957], 
             UndirectedEdge[8, 156] -> 
             RGBColor[
              0.7020899352925487, 0.7662755753457564, 0.9715859281966446], 
             UndirectedEdge[22, 118] -> 
             RGBColor[
              0.9744726429990976, 0.9802586901604242, 0.9180807591302754], 
             UndirectedEdge[100, 163] -> 
             RGBColor[
              0.6225997844097091, 0.6852688690901764, 0.7432531287082875], 
             UndirectedEdge[12, 154] -> 
             RGBColor[
              0.724847631752744, 0.7784261426214159, 0.698998382647235], 
             UndirectedEdge[67, 129] -> 
             RGBColor[
              0.28865840807953436`, 0.4207286672647017, 0.9397500413570588], 
             UndirectedEdge[49, 129] -> 
             RGBColor[
              0.36608557344424963`, 0.4897558785220941, 0.9446117314763509], 
             UndirectedEdge[127, 175] -> 
             RGBColor[
              0.47450397168838315`, 0.5665901272467431, 0.9550179506910369], 
             UndirectedEdge[30, 198] -> 
             RGBColor[
              0.8912240204926032, 0.9148361582488984, 0.9374321640159491], 
             UndirectedEdge[5, 140] -> 
             RGBColor[
              0.24167874169271053`, 0.37135005920926034`, 0.9370746188565172],
              UndirectedEdge[147, 156] -> 
             RGBColor[
              0.601634914694843, 0.6874733529501376, 0.9617820508275382], 
             UndirectedEdge[122, 159] -> 
             RGBColor[
              0.5130585347895442, 0.6023403760479378, 0.9579692185405426], 
             UndirectedEdge[82, 110] -> 
             RGBColor[
              0.7348516579079059, 0.792790967327892, 0.974206803747229], 
             UndirectedEdge[83, 176] -> 
             RGBColor[
              0.4716698633778085, 0.5810989223244636, 0.951789160767192], 
             UndirectedEdge[10, 77] -> 
             RGBColor[
              0.32086519046831896`, 0.4491496376943286, 0.9417830035098402], 
             UndirectedEdge[104, 130] -> 
             RGBColor[
              0.6201960789972141, 0.6967685609577337, 0.9663444194980935], 
             UndirectedEdge[30, 66] -> 
             RGBColor[
              0.8839452764317322, 0.909580124662588, 0.9574754759698623], 
             UndirectedEdge[85, 132] -> 
             RGBColor[
              0.4732490845440606, 0.5807040162666854, 0.9523768398839977], 
             UndirectedEdge[24, 195] -> 
             RGBColor[
              0.7815034394875554, 0.8292407087147414, 0.9788552865092903], 
             UndirectedEdge[50, 123] -> 
             RGBColor[
              0.6963691550046324, 0.27875060372372984`, 0.4262108825146165], 
             UndirectedEdge[42, 153] -> 
             RGBColor[
              0.5518863258526179, 0.6337244999452439, 0.9616472943368265], 
             UndirectedEdge[127, 161] -> 
             RGBColor[
              0.41205110920811294`, 0.5174203512991487, 0.949053810339337], 
             UndirectedEdge[7, 18] -> 
             RGBColor[
              0.48096144287806925`, 0.5886040468114246, 0.9525311822546388], 
             UndirectedEdge[65, 66] -> 
             RGBColor[
              0.604054872995064, 0.6722700839253464, 0.9356805596349079], 
             UndirectedEdge[150, 152] -> 
             RGBColor[
              0.7024633397710125, 0.7660533383679503, 0.9722200308009714], 
             UndirectedEdge[25, 87] -> 
             RGBColor[
              0.6007892887478794, 0.6844248249095018, 0.9631377301310992], 
             UndirectedEdge[69, 82] -> 
             RGBColor[
              0.644598199593382, 0.7206012293567065, 0.9663618932286099], 
             UndirectedEdge[1, 159] -> 
             RGBColor[
              0.3830571970657545, 0.4988736010093425, 0.9463169174318291], 
             UndirectedEdge[23, 131] -> 
             RGBColor[
              0.44986489257069806`, 0.5613857653531428, 0.9506282110776985], 
             UndirectedEdge[126, 160] -> 
             RGBColor[
              0.7291422858954573, 0.7858773072715008, 0.9329646482863434], 
             UndirectedEdge[67, 131] -> 
             RGBColor[
              0.41988016366391173`, 0.5334508080294188, 0.9487895110578063], 
             UndirectedEdge[142, 174] -> 
             RGBColor[
              0.5839622694976527, 0.6399711284548901, 0.6726294729737632], 
             UndirectedEdge[22, 122] -> 
             RGBColor[
              0.870583508706462, 0.8992704384413847, 0.9626548422621117], 
             UndirectedEdge[32, 176] -> 
             RGBColor[
              0.39211680251630443`, 0.5079118471934029, 0.9468769028430974], 
             UndirectedEdge[47, 160] -> 
             RGBColor[
              0.6418640158192295, 0.7101656383176156, 0.9272630351985864], 
             UndirectedEdge[79, 125] -> 
             RGBColor[
              0.277867053455445, 0.4093862693433824, 0.9391354896755952], 
             UndirectedEdge[47, 111] -> 
             RGBColor[
              0.6431253462847628, 0.7109258988353642, 0.9170475638422115], 
             UndirectedEdge[3, 186] -> 
             RGBColor[
              0.6575076755949744, 0.7260758933103153, 0.9521946384066732], 
             UndirectedEdge[105, 160] -> 
             RGBColor[
              0.6786246254952295, 0.7427245337412178, 0.9295790735048369], 
             UndirectedEdge[9, 189] -> 
             RGBColor[
              0.7071212592389962, 0.769798500352018, 0.9726285538727177], 
             UndirectedEdge[64, 175] -> 
             RGBColor[
              0.8197776783488334, 0.8597596882614111, 0.982505880320466], 
             UndirectedEdge[100, 165] -> 
             RGBColor[
              0.22738121972562364`, 0.35632245710660143`, 0.9362603961317799],
              UndirectedEdge[101, 161] -> 
             RGBColor[
              0.6163140976041817, 0.6993905749255926, 0.9629376498777801], 
             UndirectedEdge[123, 187] -> 
             RGBColor[
              0.7547024584926557, 0.3261082073806821, 0.430803093847125], 
             UndirectedEdge[90, 198] -> 
             RGBColor[
              0.9733564548049335, 0.9794774263186589, 0.9222624547930993], 
             UndirectedEdge[146, 171] -> 
             RGBColor[
              0.5986463804412808, 0.6850471262111619, 0.961546782463736], 
             UndirectedEdge[62, 157] -> 
             RGBColor[
              0.3180557183632344, 0.44619670438106485`, 0.9416230082296972], 
             UndirectedEdge[2, 164] -> 
             RGBColor[
              0.3204910190407473, 0.451609094705386, 0.9416572424012277], 
             UndirectedEdge[94, 142] -> 
             RGBColor[
              0.28409796918493396`, 0.4084904610077098, 0.9397629252146447], 
             UndirectedEdge[12, 175] -> 
             RGBColor[
              0.8675461172004651, 0.8927429303181051, 0.7112797523883352], 
             UndirectedEdge[23, 64] -> 
             RGBColor[
              0.6223233813497264, 0.698115819551074, 0.9667079848605766], 
             UndirectedEdge[73, 160] -> 
             RGBColor[
              0.9269669034969754, 0.9433888077439291, 0.9508248598285828], 
             UndirectedEdge[47, 142] -> 
             RGBColor[
              0.2399498052890596, 0.3695328374281238, 0.9369761584860615], 
             UndirectedEdge[31, 120] -> 
             RGBColor[
              0.8259511471369354, 0.8625852137810166, 0.873825285107181], 
             UndirectedEdge[9, 20] -> 
             RGBColor[
              0.7692027612338173, 0.8201990604112074, 0.9775158371217851], 
             UndirectedEdge[174, 188] -> 
             RGBColor[
              0.6161368038828254, 0.6737886040770105, 0.6744617651090405], 
             UndirectedEdge[45, 173] -> 
             RGBColor[
              0.9041444648087378, 0.9263524770911935, 0.9889236019332426], 
             UndirectedEdge[139, 191] -> 
             RGBColor[
              0.6831129333187862, 0.7462251286491774, 0.9175582986119707], 
             UndirectedEdge[24, 170] -> 
             RGBColor[
              0.6233114936221577, 0.7035388388536405, 0.9645363147070536], 
             UndirectedEdge[118, 195] -> 
             RGBColor[
              0.9030712658616308, 0.9240396890508379, 0.9360432501873615], 
             UndirectedEdge[124, 137] -> 
             RGBColor[
              0.754937008289621, 0.8055174393897235, 0.8813114237409707], 
             UndirectedEdge[28, 63] -> 
             RGBColor[
              0.6164928091840172, 0.6993296758325871, 0.9630925519172103], 
             UndirectedEdge[7, 94] -> 
             RGBColor[
              0.4655311593671303, 0.5752391107828487, 0.9515479782337858], 
             UndirectedEdge[37, 190] -> 
             RGBColor[
              0.23971981714839397`, 0.3692911053101939, 0.9369630610016876], 
             UndirectedEdge[31, 40] -> 
             RGBColor[
              0.9888089225562979, 0.989640216126527, 0.8351286450295745], 
             UndirectedEdge[18, 73] -> 
             RGBColor[
              0.6456539456626784, 0.719217403890723, 0.9677831123515557], 
             UndirectedEdge[170, 195] -> 
             RGBColor[
              0.6624125268729528, 0.7340898782581761, 0.9684322094414497], 
             UndirectedEdge[62, 191] -> 
             RGBColor[
              0.6270754171043157, 0.6939793428865437, 0.9141234388386672], 
             UndirectedEdge[152, 194] -> 
             RGBColor[
              0.8781705911440354, 0.9056934083453128, 0.9882418890071012], 
             UndirectedEdge[24, 37] -> 
             RGBColor[
              0.5200969228018931, 0.6145088657628451, 0.9576147728763333], 
             UndirectedEdge[90, 177] -> 
             RGBColor[
              0.6267695021561912, 0.6975472173799585, 0.945013510041278], 
             UndirectedEdge[94, 188] -> 
             RGBColor[
              0.3162725035701066, 0.44230793662983015`, 0.9415952173499221], 
             UndirectedEdge[103, 133] -> 
             RGBColor[
              0.47226371839151743`, 0.5799040516338115, 0.9522992682509543], 
             UndirectedEdge[38, 179] -> 
             RGBColor[
              0.2322884315573567, 0.3614802478769533, 0.9365398545860277], 
             UndirectedEdge[54, 116] -> 
             RGBColor[
              0.5074053476789061, 0.6091372431804677, 0.9548713299269278], 
             UndirectedEdge[4, 198] -> 
             RGBColor[
              0.9866366570382203, 0.9887419285101242, 0.871128706307077], 
             UndirectedEdge[31, 38] -> 
             RGBColor[
              0.6275330964654848, 0.692369284247563, 0.8596050148954056], 
             UndirectedEdge[35, 47] -> 
             RGBColor[
              0.4028236428309371, 0.5212141686405435, 0.9473001512802078], 
             UndirectedEdge[132, 151] -> 
             RGBColor[
              0.7566219804033985, 0.8098069424487748, 0.9767308514954427], 
             UndirectedEdge[124, 135] -> 
             RGBColor[
              0.6939837248588074, 0.7593736390888011, 0.9713171845434017], 
             UndirectedEdge[32, 127] -> 
             RGBColor[
              0.2345265536446418, 0.3638326560958264, 0.9366673123278937], 
             UndirectedEdge[187, 199] -> 
             RGBColor[
              0.4802171220114649, 0.5855787446614444, 0.9531415240988431], 
             UndirectedEdge[2, 51] -> 
             RGBColor[
              0.6121079991296513, 0.6895972095840813, 0.9659054101015959], 
             UndirectedEdge[40, 117] -> 
             RGBColor[
              0.9132937124865055, 0.9321907905085913, 0.9370182762721279], 
             UndirectedEdge[9, 17] -> 
             RGBColor[
              0.9174039587335134, 0.9369770306997693, 0.9919840026318263], 
             UndirectedEdge[33, 57] -> 
             RGBColor[
              0.3273685232292138, 0.4579718936259122, 0.9420806107129148], 
             UndirectedEdge[124, 175] -> 
             RGBColor[
              0.6308859385126715, 0.7096883805457751, 0.9651324208173883], 
             UndirectedEdge[8, 147] -> 
             RGBColor[
              0.7237716416656876, 0.7838777613292117, 0.9732927915450454], 
             UndirectedEdge[108, 110] -> 
             RGBColor[
              0.6166188491050899, 0.6985559005624211, 0.9637014687030616], 
             UndirectedEdge[68, 107] -> 
             RGBColor[
              0.6994937846199858, 0.765101977211506, 0.970728572726979], 
             UndirectedEdge[1, 138] -> 
             RGBColor[
              0.4244828500661251, 0.5403377693739257, 0.9487520896210397], 
             UndirectedEdge[94, 160] -> 
             RGBColor[
              0.6860121797151038, 0.7491232618972016, 0.9300498019271697], 
             UndirectedEdge[138, 142] -> 
             RGBColor[
              0.255067792590095, 0.3833459811403611, 0.9379131480323988], 
             UndirectedEdge[6, 175] -> 
             RGBColor[
              0.7840230923041267, 0.8312499518817456, 0.9790955759850262], 
             UndirectedEdge[34, 104] -> 
             RGBColor[
              0.8675997938273454, 0.8972645415016334, 0.9872336369223731], 
             UndirectedEdge[15, 106] -> 
             RGBColor[
              0.5203387698604149, 0.6214734802239599, 0.9553821205085812], 
             UndirectedEdge[61, 94] -> 
             RGBColor[
              0.43631817724888655`, 0.5515226958694114, 0.9492482252707581], 
             UndirectedEdge[144, 159] -> 
             RGBColor[
              0.46683726546375554`, 0.5662319691559738, 0.953362314376468], 
             UndirectedEdge[83, 86] -> 
             RGBColor[
              0.5661585410147668, 0.6567609533769783, 0.9599442706161507], 
             UndirectedEdge[137, 176] -> 
             RGBColor[
              0.7561452903369953, 0.8064983771882679, 0.881406544129823], 
             UndirectedEdge[143, 159] -> 
             RGBColor[
              0.3033792234604116, 0.43161021805391836`, 0.9407564675332578], 
             UndirectedEdge[24, 144] -> 
             RGBColor[
              0.7138598289924112, 0.776391991035299, 0.9721145344207271], 
             UndirectedEdge[76, 96] -> 
             RGBColor[
              0.293469999973923, 0.423939225390354, 0.9400916722300837], 
             UndirectedEdge[98, 120] -> 
             RGBColor[
              0.5202642707910143, 0.6191738947185306, 0.9561039144925112], 
             UndirectedEdge[98, 183] -> 
             RGBColor[
              0.6038487713987873, 0.6845273809484766, 0.9644198060986862], 
             UndirectedEdge[55, 75] -> 
             RGBColor[
              0.5289424866350799, 0.6247570468918482, 0.9574752240411285], 
             UndirectedEdge[35, 68] -> 
             RGBColor[
              0.5713250501765693, 0.6628664394903669, 0.9593959472639676], 
             UndirectedEdge[25, 43] -> 
             RGBColor[
              0.656561340201084, 0.728457009122136, 0.968573798232155], 
             UndirectedEdge[47, 174] -> 
             RGBColor[
              0.6449850747867123, 0.7041099658830139, 0.6761046314598247], 
             UndirectedEdge[29, 88] -> 
             RGBColor[
              0.5896221420382332, 0.6599099718193127, 0.950962440118972], 
             UndirectedEdge[17, 140] -> 
             RGBColor[
              0.5754070084730993, 0.6478458523879699, 0.9645926464707744], 
             UndirectedEdge[41, 90] -> 
             RGBColor[
              0.9341035685618461, 0.9496279490497002, 0.9705244220262956], 
             UndirectedEdge[151, 196] -> 
             RGBColor[
              0.8909058816530651, 0.9158481833069612, 0.9894565923847805], 
             UndirectedEdge[88, 94] -> 
             RGBColor[
              0.670766886129541, 0.737753346902966, 0.9558561073581495], 
             UndirectedEdge[57, 198] -> 
             RGBColor[
              0.6569749619895341, 0.7236513348373816, 0.9183040725873962], 
             UndirectedEdge[71, 164] -> 
             RGBColor[
              0.25785365409046923`, 0.3883509176879836, 0.937995756188931], 
             UndirectedEdge[95, 154] -> 
             RGBColor[
              0.4038479820094638, 0.5241149060069452, 0.9469813480236603], 
             UndirectedEdge[69, 90] -> 
             RGBColor[
              0.7469865618240156, 0.8010665822669993, 0.953211105598248], 
             UndirectedEdge[175, 176] -> 
             RGBColor[
              0.6320942205600457, 0.7106693183443196, 0.9652275412062405], 
             UndirectedEdge[58, 115] -> 
             RGBColor[
              0.2228313631753357, 0.35154026939468186`, 0.9360012885321506], 
             UndirectedEdge[42, 88] -> 
             RGBColor[
              0.9008239095450064, 0.9233293622877172, 0.9755917328701229], 
             UndirectedEdge[72, 134] -> 
             RGBColor[
              0.30873825196754356`, 0.4393454417279245, 0.9409846718092727], 
             UndirectedEdge[25, 49] -> 
             RGBColor[
              0.4391309793067639, 0.5547749157359121, 0.9492020155865168], 
             UndirectedEdge[23, 103] -> 
             RGBColor[
              0.3536252732602869, 0.48071417080019907`, 0.9437536676069623], 
             UndirectedEdge[79, 192] -> 
             RGBColor[
              0.5229934570601726, 0.6127826092648221, 0.9585349976664546], 
             UndirectedEdge[89, 170] -> 
             RGBColor[
              0.3792234391840347, 0.49646317208708807`, 0.9459512106142831], 
             UndirectedEdge[41, 57] -> 
             RGBColor[
              0.6177220757464467, 0.6938018575684228, 0.9665660398205924], 
             UndirectedEdge[10, 14] -> 
             RGBColor[
              0.5130199350910636, 0.6129528593358642, 0.9556196071063945], 
             UndirectedEdge[6, 59] -> 
             RGBColor[
              0.6468160309560186, 0.7213913496549587, 0.967246511264797], 
             UndirectedEdge[120, 183] -> 
             RGBColor[
              0.7434070087539588, 0.7995311115213244, 0.9750444908924245], 
             UndirectedEdge[8, 194] -> 
             RGBColor[
              0.8418676253540169, 0.8767464088421071, 0.9847792797220092], 
             UndirectedEdge[63, 106] -> 
             RGBColor[
              0.5499318862398817, 0.6454985052555113, 0.9577117990331299], 
             UndirectedEdge[129, 131] -> 
             RGBColor[
              0.42103158855326195`, 0.5346610285926804, 0.9488550830018743], 
             UndirectedEdge[22, 38] -> 
             RGBColor[
              0.6131968169082845, 0.6829877582814603, 0.9425571289961066], 
             UndirectedEdge[38, 117] -> 
             RGBColor[
              0.5520178863956924, 0.6349198586296274, 0.961494646137959], 
             UndirectedEdge[136, 159] -> 
             RGBColor[
              0.5443943348292705, 0.6269854098449775, 0.9610486210219364], 
             UndirectedEdge[158, 166] -> 
             RGBColor[
              0.41576616062132676`, 0.5271779890623701, 0.9487326111905621], 
             UndirectedEdge[75, 96] -> 
             RGBColor[
              0.3053789029147094, 0.4342541185587976, 0.9408504969948412], 
             UndirectedEdge[118, 170] -> 
             RGBColor[
              0.744879319996233, 0.798337819189737, 0.9217242783851247], 
             UndirectedEdge[7, 58] -> 
             RGBColor[
              0.38268081759011585`, 0.4956030443903786, 0.946557179729613], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.48130130014100825`, 0.5712212336982765, 0.9558029434118361], 
             UndirectedEdge[65, 180] -> 
             RGBColor[
              0.44985879943664453`, 0.5514948499375317, 0.9519033223795799], 
             UndirectedEdge[151, 171] -> 
             RGBColor[
              0.7518499433704009, 0.8059327878075688, 0.9763551792596574], 
             UndirectedEdge[37, 118] -> 
             RGBColor[
              0.6416647491759685, 0.7093078460989416, 0.9148027365544045], 
             UndirectedEdge[7, 47] -> 
             RGBColor[
              0.42138299547125596`, 0.5362814872032627, 0.9487612115052027], 
             UndirectedEdge[46, 99] -> 
             RGBColor[
              0.25482901672377456`, 0.3851718320425022, 0.9378235075654477], 
             UndirectedEdge[195, 197] -> 
             RGBColor[
              0.8882590311203523, 0.9132163779358901, 0.9711310770127631], 
             UndirectedEdge[5, 63] -> 
             RGBColor[
              0.42133789239009634`, 0.5320015178059944, 0.949143917179562], 
             UndirectedEdge[11, 63] -> 
             RGBColor[
              0.390924453757967, 0.5000350654802425, 0.9474119168421127], 
             UndirectedEdge[10, 193] -> 
             RGBColor[
              0.4916087134785783, 0.595818435060281, 0.9537643621289101], 
             UndirectedEdge[99, 147] -> 
             RGBColor[
              0.4139927695393034, 0.5187629634473145, 0.9492279391624445], 
             UndirectedEdge[9, 77] -> 
             RGBColor[
              0.5880527669242182, 0.6650818208382614, 0.9647152429618708], 
             UndirectedEdge[43, 103] -> 
             RGBColor[
              0.6184980706125359, 0.6954885181200914, 0.9661484403520003], 
             UndirectedEdge[54, 174] -> 
             RGBColor[
              0.8090599185237624, 0.8421685529809724, 0.6878519521412801], 
             UndirectedEdge[149, 197] -> 
             RGBColor[
              0.9135459877179826, 0.9333795107306888, 0.9735429695069777], 
             UndirectedEdge[87, 180] -> 
             RGBColor[
              0.7139791256196717, 0.7764851864672027, 0.9721264247936421], 
             UndirectedEdge[134, 191] -> 
             RGBColor[
              0.6336679987207989, 0.7009085641592843, 0.9144988766088754], 
             UndirectedEdge[65, 131] -> 
             RGBColor[
              0.3948453122867154, 0.5071375919307299, 0.9473638133076185], 
             UndirectedEdge[107, 147] -> 
             RGBColor[
              0.6921643825192849, 0.7591516384003552, 0.9701515753451273], 
             UndirectedEdge[50, 82] -> 
             RGBColor[
              0.6055878482432093, 0.6889308687343352, 0.9632908554706988], 
             UndirectedEdge[30, 162] -> 
             RGBColor[
              0.7520492303677184, 0.8062258416398893, 0.9759208970495712], 
             UndirectedEdge[51, 74] -> 
             RGBColor[
              0.7056689731402068, 0.7687226938003116, 0.9723954148223815], 
             UndirectedEdge[12, 161] -> 
             RGBColor[
              0.805093254720195, 0.8435731543705107, 0.7053156120366353], 
             UndirectedEdge[78, 113] -> 
             RGBColor[
              0.4442776935979035, 0.5591629242983578, 0.9495492502254524], 
             UndirectedEdge[131, 133] -> 
             RGBColor[
              0.5685033377019286, 0.6605756461867552, 0.9591738117216906], 
             UndirectedEdge[35, 188] -> 
             RGBColor[
              0.37397537192705016`, 0.49089280683453995`, 0.9456572849294238],
              UndirectedEdge[181, 185] -> 
             RGBColor[
              0.6699120613165117, 0.7392041475629831, 0.9698004133802429], 
             UndirectedEdge[111, 188] -> 
             RGBColor[
              0.614277075380876, 0.6806045370293606, 0.9154046974914274], 
             UndirectedEdge[41, 184] -> 
             RGBColor[
              0.9504444239218961, 0.959194201466866, 0.7986017582868365], 
             UndirectedEdge[135, 187] -> 
             RGBColor[
              0.7490249915861049, 0.8040586189988302, 0.975650234682978], 
             UndirectedEdge[51, 71] -> 
             RGBColor[
              0.5494706341793733, 0.6263390325666789, 0.9622439238892992], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.5532622533209952, 0.628514785195308, 0.9627339746801198], 
             UndirectedEdge[26, 158] -> 
             RGBColor[
              0.457708855972865, 0.5677374307209895, 0.951250252811106], 
             UndirectedEdge[101, 199] -> 
             RGBColor[
              0.47305687685594777`, 0.5797657350788272, 0.9525778433713585], 
             UndirectedEdge[84, 194] -> 
             RGBColor[
              0.6504102087288265, 0.7237383460490775, 0.9679014339656078], 
             UndirectedEdge[6, 176] -> 
             RGBColor[
              0.6737322778622017, 0.7432431714565029, 0.9693654568187129], 
             UndirectedEdge[18, 116] -> 
             RGBColor[
              0.40290895134866933`, 0.5234012156906711, 0.9468939799949088], 
             UndirectedEdge[98, 179] -> 
             RGBColor[
              0.2911482448736358, 0.41669244683755935`, 0.9401354400040649], 
             UndirectedEdge[116, 142] -> 
             RGBColor[
              0.2823076986527964, 0.40693981865438544`, 0.939648850759411], 
             UndirectedEdge[77, 112] -> 
             RGBColor[
              0.334639968104284, 0.46108065774214685`, 0.9426607201602464], 
             UndirectedEdge[56, 190] -> 
             RGBColor[
              0.30467629925453055`, 0.4265659692810403, 0.9410649461554449], 
             UndirectedEdge[76, 126] -> 
             RGBColor[
              0.4021245605167823, 0.5221187309597651, 0.9470106334365275], 
             UndirectedEdge[168, 173] -> 
             RGBColor[
              0.6157278038872673, 0.6933174115972077, 0.9658667950873159], 
             UndirectedEdge[158, 164] -> 
             RGBColor[
              0.4364511466543483, 0.5489192208869391, 0.9499105905444482], 
             UndirectedEdge[46, 146] -> 
             RGBColor[
              0.4625509434070884, 0.5701838927734216, 0.9519583731870711], 
             UndirectedEdge[23, 25] -> 
             RGBColor[
              0.39168854284883503`, 0.5136826618022436, 0.946179025487117], 
             UndirectedEdge[9, 28] -> 
             RGBColor[
              0.7788306087470453, 0.8278093955476526, 0.9784146097552174], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.47894301147057594`, 0.5858949535725658, 0.9526680496170241], 
             UndirectedEdge[103, 129] -> 
             RGBColor[
              0.3247919692428507, 0.4539894340397367, 0.9419805395311381], 
             UndirectedEdge[5, 48] -> 
             RGBColor[
              0.26667154765087575`, 0.397619082906714, 0.9384979221822917], 
             UndirectedEdge[36, 169] -> 
             RGBColor[
              0.7186030980106785, 0.7779901844557153, 0.9500801985135867], 
             UndirectedEdge[159, 170] -> 
             RGBColor[
              0.37628893009350195`, 0.4933788169743155, 0.9457840946627945], 
             UndirectedEdge[86, 175] -> 
             RGBColor[
              0.7265828981970042, 0.7863313493968342, 0.9733826510551993], 
             UndirectedEdge[9, 97] -> 
             RGBColor[
              0.9451485114119182, 0.9570337163368221, 0.9158599317294375], 
             UndirectedEdge[7, 88] -> 
             RGBColor[
              0.7470291071268035, 0.8014055356703952, 0.9613792351626459], 
             UndirectedEdge[5, 77] -> 
             RGBColor[
              0.2698728702459773, 0.4009838759297415, 0.9386802327681503], 
             UndirectedEdge[103, 131] -> 
             RGBColor[
              0.4560137248272281, 0.5667115748044538, 0.9510200092318857], 
             UndirectedEdge[15, 193] -> 
             RGBColor[
              0.5668653739919826, 0.6592458734575968, 0.9590448652183847], 
             UndirectedEdge[167, 181] -> 
             RGBColor[
              0.5780061423389863, 0.6667519819853001, 0.9608137912233188], 
             UndirectedEdge[99, 146] -> 
             RGBColor[
              0.41239084469393883`, 0.5174624486919557, 0.9491018297705734], 
             UndirectedEdge[163, 177] -> 
             RGBColor[
              0.6428468177332596, 0.7065497848492857, 0.744406167303262], 
             UndirectedEdge[76, 116] -> 
             RGBColor[
              0.3572041838042913, 0.4838140432321415, 0.9439817126221199], 
             UndirectedEdge[15, 59] -> 
             RGBColor[
              0.4929823345260649, 0.599264293626167, 0.9532285217091366], 
             UndirectedEdge[36, 151] -> 
             RGBColor[
              0.9445074811461123, 0.9578976470302349, 0.9706118701880284], 
             UndirectedEdge[38, 98] -> 
             RGBColor[
              0.3218462201195638, 0.44895796518507697`, 0.9418836442807358], 
             UndirectedEdge[70, 139] -> 
             RGBColor[
              0.32941013993130336`, 0.4569081244874305, 0.9423143983241977], 
             UndirectedEdge[56, 195] -> 
             RGBColor[
              0.6241544381588249, 0.7023347691382271, 0.9656125527644868], 
             UndirectedEdge[66, 168] -> 
             RGBColor[
              0.6657733099828891, 0.7323204703302996, 0.9393718026305903], 
             UndirectedEdge[6, 161] -> 
             RGBColor[
              0.7215702298238567, 0.7820801759341511, 0.9731314356333263], 
             UndirectedEdge[56, 118] -> 
             RGBColor[
              0.7066212312821051, 0.766582710069788, 0.9189046217081618], 
             UndirectedEdge[46, 117] -> 
             RGBColor[
              0.5730192407125121, 0.6569936135793759, 0.9626906421975824], 
             UndirectedEdge[79, 89] -> 
             RGBColor[
              0.2612267105406101, 0.39189621388121276`, 0.9381878467637768], 
             UndirectedEdge[102, 140] -> 
             RGBColor[
              0.48786840904516754`, 0.5785469522506517, 0.9561099205829808], 
             UndirectedEdge[32, 130] -> 
             RGBColor[
              0.3100276202789738, 0.43866986280361386`, 0.9411324564788748], 
             UndirectedEdge[105, 126] -> 
             RGBColor[
              0.42501149033034696`, 0.5419422392337351, 0.9484689683661305], 
             UndirectedEdge[86, 124] -> 
             RGBColor[
              0.6150838017077047, 0.6973436311730472, 0.9635574115000336], 
             UndirectedEdge[41, 168] -> 
             RGBColor[
              0.6337991678006726, 0.7077270266476513, 0.9675904579098734], 
             UndirectedEdge[43, 143] -> 
             RGBColor[
              0.6178116017248146, 0.6948939332724768, 0.9661046991614953], 
             UndirectedEdge[56, 197] -> 
             RGBColor[
              0.6918089965408266, 0.7557593989548401, 0.9539924485335634], 
             UndirectedEdge[47, 73] -> 
             RGBColor[
              0.5860754982558651, 0.6668948442825611, 0.9640131416021194], 
             UndirectedEdge[23, 108] -> 
             RGBColor[
              0.43385852743532327`, 0.5483910770577135, 0.9493681313809943], 
             UndirectedEdge[97, 155] -> 
             RGBColor[
              0.6163764617031874, 0.6818027470119663, 0.8892217140903168], 
             UndirectedEdge[86, 161] -> 
             RGBColor[
              0.6641300357167339, 0.7371615734492398, 0.9674185107034994], 
             UndirectedEdge[88, 188] -> 
             RGBColor[
              0.5977704513297798, 0.6684743615173766, 0.9514264742787822], 
             UndirectedEdge[136, 197] -> 
             RGBColor[
              0.8981724899907231, 0.9211211009454512, 0.9720766315696683], 
             UndirectedEdge[65, 69] -> 
             RGBColor[
              0.384963724075017, 0.4991152734599973, 0.9465858984861434], 
             UndirectedEdge[23, 67] -> 
             RGBColor[
              0.3174917120969706, 0.4474534040251641, 0.941523169432883], 
             UndirectedEdge[31, 121] -> 
             RGBColor[
              0.7975177432953071, 0.8397692143040227, 0.8714039994247561], 
             UndirectedEdge[52, 145] -> 
             RGBColor[
              0.38702048009434065`, 0.5065459013784952, 0.9462234244794108], 
             UndirectedEdge[12, 87] -> 
             RGBColor[
              0.8791925661004026, 0.9018412247150263, 0.7124405615724281], 
             UndirectedEdge[128, 192] -> 
             RGBColor[
              0.8168369879068753, 0.857128940547315, 0.9823012692773812], 
             UndirectedEdge[78, 95] -> 
             RGBColor[
              0.39168699628539555`, 0.5136813222467249, 0.9461789269414621], 
             UndirectedEdge[123, 165] -> 
             RGBColor[
              0.6126128192399181, 0.19972031436319032`, 0.4211064458359257], 
             UndirectedEdge[24, 56] -> 
             RGBColor[
              0.5850534049080297, 0.6717837297336915, 0.9617166580300907], 
             UndirectedEdge[50, 177] -> 
             RGBColor[
              0.37326275669624553`, 0.49614880690651986`, 0.9450700897447906],
              UndirectedEdge[18, 58] -> 
             RGBColor[
              0.32184888010379237`, 0.44531579165152535`, 0.9420172559459696],
              UndirectedEdge[96, 182] -> 
             RGBColor[
              0.5223782617206405, 0.6109517777842504, 0.9586874429505468], 
             UndirectedEdge[49, 131] -> 
             RGBColor[
              0.49730732902862695`, 0.6024780192868112, 0.9536512011770985], 
             UndirectedEdge[28, 106] -> 
             RGBColor[
              0.5892447059185899, 0.6772084380886497, 0.9609474814150649], 
             UndirectedEdge[57, 81] -> 
             RGBColor[
              0.331881538610436, 0.4618808407183784, 0.9423681760623035], 
             UndirectedEdge[7, 115] -> 
             RGBColor[
              0.3819439259496126, 0.49482852455458115`, 0.9465152148408198], 
             UndirectedEdge[54, 94] -> 
             RGBColor[
              0.5091956182110436, 0.610687885533792, 0.9549854043821616], 
             UndirectedEdge[138, 181] -> 
             RGBColor[
              0.38503237628527165`, 0.507917424873544, 0.9457549004395036], 
             UndirectedEdge[55, 182] -> 
             RGBColor[
              0.7459418454410109, 0.8014547061173009, 0.9753121699968341], 
             UndirectedEdge[17, 77] -> 
             RGBColor[
              0.6036011370263662, 0.677479669108451, 0.9661982603824075], 
             UndirectedEdge[144, 149] -> 
             RGBColor[
              0.7782478188408366, 0.8271061632346333, 0.9784223216493377], 
             UndirectedEdge[68, 179] -> 
             RGBColor[
              0.4197829407904061, 0.5230954730426651, 0.9497172796244997], 
             UndirectedEdge[103, 143] -> 
             RGBColor[
              0.3590876366290956, 0.48544539540389553`, 0.9441017245706446], 
             UndirectedEdge[80, 173] -> 
             RGBColor[
              0.645260830625642, 0.7188974349849039, 0.9677486134360549], 
             UndirectedEdge[161, 199] -> 
             RGBColor[
              0.47422208929319665`, 0.580711707027608, 0.9526695731627326], 
             UndirectedEdge[43, 133] -> 
             RGBColor[
              0.7309876834872364, 0.7893525895023928, 0.9743022428418051], 
             UndirectedEdge[6, 193] -> 
             RGBColor[
              0.7206990704219363, 0.7813729294863885, 0.9730628547740451], 
             UndirectedEdge[181, 188] -> 
             RGBColor[
              0.3410661180803493, 0.46378291935530325`, 0.9431750445423823], 
             UndirectedEdge[120, 173] -> 
             RGBColor[
              0.7652019807546395, 0.8169098305859124, 0.9771233147784506], 
             UndirectedEdge[2, 158] -> 
             RGBColor[
              0.4525857868257677, 0.563300085718716, 0.9509238153752051], 
             UndirectedEdge[95, 143] -> 
             RGBColor[
              0.35455453382688673`, 0.48151904959699376`, 0.9438128792685532],
              UndirectedEdge[4, 172] -> 
             RGBColor[
              0.6640755605787836, 0.72916480869048, 0.8953541674140563], 
             UndirectedEdge[89, 113] -> 
             RGBColor[
              0.3550577959489647, 0.4768444142590367, 0.9440488026571505], 
             UndirectedEdge[34, 90] -> 
             RGBColor[
              0.9069577136187554, 0.9279825811726825, 0.9679352261484329], 
             UndirectedEdge[28, 48] -> 
             RGBColor[
              0.4618264644447966, 0.5649472409333067, 0.95244655691994], 
             UndirectedEdge[5, 189] -> 
             RGBColor[
              0.38894136256075523`, 0.5057005554434981, 0.9465935436789974], 
             UndirectedEdge[8, 55] -> 
             RGBColor[
              0.7647869296744952, 0.8162109210080638, 0.9771813718707378], 
             UndirectedEdge[29, 138] -> 
             RGBColor[
              0.279094017683721, 0.4085990670644175, 0.939281406007866], 
             UndirectedEdge[8, 68] -> 
             RGBColor[
              0.7311010437663885, 0.7898281001403625, 0.9738697889268972], 
             UndirectedEdge[176, 187] -> 
             RGBColor[
              0.5756363907980439, 0.6663665800305616, 0.9597353517906512], 
             UndirectedEdge[65, 133] -> 
             RGBColor[
              0.41109530585100473`, 0.5203300687600877, 0.9486430723266872], 
             UndirectedEdge[68, 147] -> 
             RGBColor[
              0.6306460231686828, 0.7110258777447437, 0.9640659115577908], 
             UndirectedEdge[89, 192] -> 
             RGBColor[
              0.5159930438800769, 0.6054247311607103, 0.9581363344920313], 
             UndirectedEdge[2, 74] -> 
             RGBColor[
              0.43018663322272216`, 0.5451154437533932, 0.9491604719527702], 
             UndirectedEdge[156, 185] -> 
             RGBColor[
              0.7404605817821871, 0.7968712873131414, 0.9752457547127067], 
             UndirectedEdge[126, 182] -> 
             RGBColor[
              0.6310328222634998, 0.7091312833536614, 0.9656064041569905], 
             UndirectedEdge[18, 188] -> 
             RGBColor[
              0.33170278708104556`, 0.45567287265840606`, 0.9425784213707752],
              UndirectedEdge[68, 156] -> 
             RGBColor[
              0.6089643167955439, 0.6934236917612884, 0.96235904820939], 
             UndirectedEdge[29, 181] -> 
             RGBColor[
              0.33291780878880267`, 0.4552185296572393, 0.9427110103825721], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.3723682825696561, 0.4876388741576211, 0.9457081995641081], 
             UndirectedEdge[30, 180] -> 
             RGBColor[
              0.7297492028733128, 0.7888048906747733, 0.9736982387145341], 
             UndirectedEdge[31, 196] -> 
             RGBColor[
              0.9236858260991613, 0.9392216681344443, 0.883490833356817], 
             UndirectedEdge[193, 199] -> 
             RGBColor[
              0.47335092989127625`, 0.5800044605798452, 0.9526009923034513], 
             UndirectedEdge[30, 110] -> 
             RGBColor[
              0.755107585826209, 0.8086150521684246, 0.9762257253397169], 
             UndirectedEdge[12, 59] -> 
             RGBColor[
              0.7303390558523569, 0.7828843280913182, 0.6994306876681059], 
             UndirectedEdge[38, 156] -> 
             RGBColor[
              0.4214698075624944, 0.5318084665955766, 0.949181623170918], 
             UndirectedEdge[72, 152] -> 
             RGBColor[
              0.6162464667693246, 0.6928639155105971, 0.9663154227051496], 
             UndirectedEdge[37, 79] -> 
             RGBColor[
              0.2830092815438659, 0.4147910771004045, 0.9394283319579861], 
             UndirectedEdge[170, 197] -> 
             RGBColor[
              0.7300670852549546, 0.7875145080747892, 0.9568121052105263], 
             UndirectedEdge[86, 127] -> 
             RGBColor[
              0.4587018348834164, 0.5542453778740152, 0.9534429413736822], 
             UndirectedEdge[69, 127] -> 
             RGBColor[
              0.36955653804451893`, 0.48292134406992804`, 0.9457084820345957],
              UndirectedEdge[58, 61] -> 
             RGBColor[
              0.35346783547187205`, 0.47188662947694127`, 0.9442574267665853],
              UndirectedEdge[11, 17] -> 
             RGBColor[
              0.5688106234231431, 0.6409126334654975, 0.9642169921006566], 
             UndirectedEdge[11, 15] -> 
             RGBColor[
              0.3613313373785002, 0.47601004044869094`, 0.945082238317564], 
             UndirectedEdge[111, 157] -> 
             RGBColor[
              0.6763792588554867, 0.7404474694780974, 0.9191401585097643], 
             UndirectedEdge[75, 191] -> 
             RGBColor[
              0.6690288046931461, 0.7340261643225356, 0.9166608703900508], 
             UndirectedEdge[98, 156] -> 
             RGBColor[
              0.48032962087877346`, 0.5870206655561825, 0.9527772085889551], 
             UndirectedEdge[28, 140] -> 
             RGBColor[
              0.43683365848663136`, 0.5386782172358531, 0.9510232535941655], 
             UndirectedEdge[105, 157] -> 
             RGBColor[
              0.370987132824843, 0.495752140922583, 0.9448599499459263], 
             UndirectedEdge[3, 15] -> 
             RGBColor[
              0.7367328653101051, 0.7929406722380892, 0.9577280126676493], 
             UndirectedEdge[55, 96] -> 
             RGBColor[
              0.48178361336522657`, 0.5792389299582466, 0.9546413477810366], 
             UndirectedEdge[6, 64] -> 
             RGBColor[
              0.8614157356509893, 0.8923335413735944, 0.9866437959329384], 
             UndirectedEdge[70, 134] -> 
             RGBColor[
              0.27996520533331604`, 0.4115915599975374, 0.9392549763211024], 
             UndirectedEdge[106, 140] -> 
             RGBColor[
              0.3702727355424959, 0.4848470466587773, 0.945642500710085], 
             UndirectedEdge[64, 154] -> 
             RGBColor[
              0.6770791929011123, 0.7454429005647218, 0.970224510579366], 
             UndirectedEdge[8, 157] -> 
             RGBColor[
              0.5958535489914801, 0.6776973999332723, 0.9638665876106902], 
             UndirectedEdge[83, 124] -> 
             RGBColor[
              0.47046158133043414`, 0.5801179845259192, 0.9516940403783397], 
             UndirectedEdge[22, 128] -> 
             RGBColor[
              0.9096607062136977, 0.9300882524443801, 0.9664726261447838], 
             UndirectedEdge[83, 135] -> 
             RGBColor[
              0.6450584641658695, 0.7187909612927322, 0.9677040436595188], 
             UndirectedEdge[62, 68] -> 
             RGBColor[
              0.45330321313814276`, 0.5583274045881551, 0.9516262095459043], 
             UndirectedEdge[105, 116] -> 
             RGBColor[
              0.38009111361785597`, 0.5036375515061114, 0.945440047551723], 
             UndirectedEdge[93, 145] -> 
             RGBColor[
              0.3801246650779149, 0.4992979625763071, 0.9458307180156694], 
             UndirectedEdge[128, 195] -> 
             RGBColor[
              0.8382593290762308, 0.8738692513347938, 0.9844351172018697], 
             UndirectedEdge[87, 154] -> 
             RGBColor[
              0.6113329984541872, 0.6934576054697941, 0.9638370998155467], 
             UndirectedEdge[138, 167] -> 
             RGBColor[
              0.5241823512339047, 0.6201325193924783, 0.9573841868486127], 
             UndirectedEdge[179, 194] -> 
             RGBColor[
              0.5305495223780345, 0.6100137817444096, 0.9606267704196116], 
             UndirectedEdge[118, 144] -> 
             RGBColor[
              0.8354276553664866, 0.8711909713713955, 0.9293024980987982], 
             UndirectedEdge[47, 188] -> 
             RGBColor[
              0.2721243396742323, 0.40335031305024416`, 0.938808450621339], 
             UndirectedEdge[11, 20] -> 
             RGBColor[
              0.4206094259234471, 0.5241346631769356, 0.9497488265906153], 
             UndirectedEdge[124, 187] -> 
             RGBColor[
              0.5744281087506695, 0.6653856422320172, 0.9596402314017989], 
             UndirectedEdge[28, 189] -> 
             RGBColor[
              0.584096279354676, 0.673028713470091, 0.9605421784166457], 
             UndirectedEdge[84, 93] -> 
             RGBColor[
              0.35656075777078877`, 0.4798417253913787, 0.944065754495765], 
             UndirectedEdge[18, 94] -> 
             RGBColor[
              0.40469922188080687`, 0.5249518580439955, 0.9470080544501425], 
             UndirectedEdge[146, 156] -> 
             RGBColor[
              0.6000329898494783, 0.6861728381947786, 0.9616559414356671], 
             UndirectedEdge[2, 26] -> 
             RGBColor[
              0.34174872835926395`, 0.4704273045394363, 0.9429969046678854], 
             UndirectedEdge[124, 161] -> 
             RGBColor[
              0.5684330760324012, 0.6605186045981808, 0.9591682804656884], 
             UndirectedEdge[25, 67] -> 
             RGBColor[
              0.36170381394204865`, 0.48574770447851967`, 0.9443403254672247],
              UndirectedEdge[15, 77] -> 
             RGBColor[
              0.39612185098172314`, 0.5125770760916444, 0.9470635065993149], 
             UndirectedEdge[23, 49] -> 
             RGBColor[
              0.3949188774616858, 0.5164806152825565, 0.9463848595521751], 
             UndirectedEdge[27, 37] -> 
             RGBColor[
              0.258234100264365, 0.38875079073842866`, 0.9380174220357147], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.6862896611842404, 0.7505827832596539, 0.9478607177690097], 
             UndirectedEdge[134, 139] -> 
             RGBColor[
              0.33126109883785554`, 0.45885359965578976`, 0.9424198076956776],
              UndirectedEdge[13, 127] -> 
             RGBColor[
              0.3036870956015786, 0.42801825369493895`, 0.940917368137133], 
             UndirectedEdge[59, 186] -> 
             RGBColor[
              0.4137571448109343, 0.5323995146983931, 0.9476951474481605], 
             UndirectedEdge[119, 149] -> 
             RGBColor[
              0.6272871166794259, 0.703308979769096, 0.9666127942498919], 
             UndirectedEdge[41, 66] -> 
             RGBColor[
              0.93869832337212, 0.9530547096639819, 0.9627467006364837], 
             UndirectedEdge[25, 103] -> 
             RGBColor[
              0.397837375105365, 0.5190084712535546, 0.9465708236413042], 
             UndirectedEdge[164, 166] -> 
             RGBColor[
              0.2836713928363063, 0.41548699804904, 0.9394660382165847], 
             UndirectedEdge[30, 90] -> 
             RGBColor[
              0.8793505216214583, 0.9061533640483062, 0.9652531973596741], 
             UndirectedEdge[75, 182] -> 
             RGBColor[
              0.5695371349904939, 0.656469894717852, 0.9615213192106387], 
             UndirectedEdge[92, 97] -> 
             RGBColor[
              0.8284391896509107, 0.8651977695816062, 0.9044030420519164], 
             UndirectedEdge[18, 61] -> 
             RGBColor[
              0.45174846075982544`, 0.5648876318979873, 0.9502314292916112], 
             UndirectedEdge[76, 191] -> 
             RGBColor[
              0.6571199017523597, 0.7237112711540921, 0.9159020456252933], 
             UndirectedEdge[129, 197] -> 
             RGBColor[
              0.6228617112356194, 0.6942899477902331, 0.9496632930414832], 
             UndirectedEdge[97, 112] -> 
             RGBColor[
              0.6917357125919841, 0.7530325532407074, 0.8938054089278131], 
             UndirectedEdge[87, 131] -> 
             RGBColor[
              0.6589656384697425, 0.732127928460401, 0.9675869157216808], 
             UndirectedEdge[33, 198] -> 
             RGBColor[
              0.6556235149157581, 0.7224807793077817, 0.9182179595748929], 
             UndirectedEdge[39, 114] -> 
             RGBColor[
              0.6836091131677016, 0.751408578069719, 0.970023333272396], 
             UndirectedEdge[144, 170] -> 
             RGBColor[
              0.5947689163778087, 0.6812411605787336, 0.9616914573528863], 
             UndirectedEdge[64, 110] -> 
             RGBColor[
              0.8050837030194931, 0.8482806430557817, 0.981041322182644], 
             UndirectedEdge[108, 131] -> 
             RGBColor[
              0.5362469790022645, 0.6343884810619682, 0.9566344730059178], 
             UndirectedEdge[33, 141] -> 
             RGBColor[
              0.25727454274160716`, 0.3861454059462853, 0.9380212443861453], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.9449387605473277, 0.953826519809954, 0.7188279723362474], 
             UndirectedEdge[88, 142] -> 
             RGBColor[
              0.5655959169446071, 0.6346568858952563, 0.9495941821435048], 
             UndirectedEdge[12, 95] -> 
             RGBColor[
              0.6717075496556792, 0.7324985252521774, 0.6955848097805417], 
             UndirectedEdge[131, 162] -> 
             RGBColor[
              0.6295668587819742, 0.7091613783293151, 0.9646567201096202], 
             UndirectedEdge[21, 194] -> 
             RGBColor[
              0.6347964228781946, 0.7102144695169552, 0.9669065373379343], 
             UndirectedEdge[131, 154] -> 
             RGBColor[
              0.5046207041220839, 0.6087128463667906, 0.9541447367964878], 
             UndirectedEdge[81, 184] -> 
             RGBColor[
              0.6646038867858854, 0.7272731846168217, 0.7744038945285476], 
             UndirectedEdge[105, 111] -> 
             RGBColor[
              0.6798859559607628, 0.7434847942589663, 0.919363602148462]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 71 -> 
             RGBColor[
              0.21135092931161056`, 0.33947360550235817`, 0.9353474948073913],
              10 -> RGBColor[
              0.3674804357195669, 0.4927148161417141, 0.9446365063072286], 68 -> 
             RGBColor[
              0.6379754252693837, 0.7169762165558945, 0.9646429089396426], 
             155 -> RGBColor[
              0.2443114892139036, 0.37411724377986827`, 0.9372245499330483], 
             132 -> RGBColor[
              0.5867240635713044, 0.6753680522818607, 0.9606082140068458], 26 -> 
             RGBColor[
              0.3468717975063612, 0.4748646495417097, 0.9433233421037863], 29 -> 
             RGBColor[
              0.22697945018725205`, 0.3559001718481129, 0.9362375159509344], 
             113 -> RGBColor[
              0.45588929453741506`, 0.5691504927409724, 0.9503084217249476], 
             50 -> RGBColor[
              0.4544694650138972, 0.5679978111711894, 0.9501966475438494], 
             173 -> RGBColor[
              0.870581453363093, 0.8996420358804464, 0.9875180302706517], 192 -> 
             RGBColor[
              0.7777597903996395, 0.8263111265443196, 0.9784834853947092], 
             165 -> RGBColor[
              0.20320045771975423`, 0.330906943089571, 0.9348833375077773], 
             92 -> RGBColor[
              0.6684369451093503, 0.740907288919148, 0.9675872058562474], 11 -> 
             RGBColor[
              0.20466891801062498`, 0.3324503879610362, 0.9349669641489501], 
             137 -> RGBColor[
              0.9904871745558699, 0.9903342164574589, 0.8073156662197188], 
             120 -> RGBColor[
              0.6598225081461859, 0.7341776252913782, 0.9667285992862495], 51 -> 
             RGBColor[
              0.8875903390471359, 0.9132044596309997, 0.9891403529712072], 72 -> 
             RGBColor[
              0.33566033969521886`, 0.4651538482899524, 0.9426089579259632], 
             64 -> RGBColor[
              0.897170321695696, 0.92084327775326, 0.9900541002683783], 41 -> 
             RGBColor[
              0.9067241811899035, 0.9284612659813336, 0.9909653559157668], 
             103 -> RGBColor[
              0.3597741055168169, 0.48603998025151013`, 0.9441454657611495], 
             162 -> RGBColor[
              0.706880373426309, 0.7709395873012329, 0.9714188875166185], 196 -> 
             RGBColor[
              0.8552918660706376, 0.8874505339982335, 0.9860596957855216], 
             179 -> RGBColor[
              0.20159045631142863`, 0.3292147295294357, 0.9347916503093568], 
             160 -> RGBColor[
              0.9827554210603398, 0.9866596017789836, 0.9140747534250498], 
             123 -> RGBColor[0.817319, 0.134127, 0.164218], 150 -> 
             RGBColor[
              0.5080940856985946, 0.6115326940046588, 0.9544181741176067], 
             188 -> RGBColor[
              0.24327606877034536`, 0.3730289512442407, 0.9371655842705549], 
             46 -> RGBColor[
              0.3049891154369242, 0.4378932761239682, 0.9406800509819455], 
             182 -> RGBColor[
              0.7865364937964249, 0.8331675539433047, 0.9793582651663443], 6 -> 
             RGBColor[
              0.8256611496062827, 0.863823804993929, 0.9832334915974985], 131 -> 
             RGBColor[
              0.5522533441376393, 0.6473831693573975, 0.9578945527026219], 45 -> 
             RGBColor[
              0.9377074762543824, 0.9530629183019405, 0.9903291735958335], 
             195 -> RGBColor[
              0.8206044727383506, 0.8597917481192769, 0.9827511812436864], 
             148 -> RGBColor[
              0.7123094227949043, 0.7751808019302829, 0.9719600044203293], 
             161 -> RGBColor[
              0.6174793100414305, 0.7003365468743734, 0.9630293796691541], 1 -> 
             RGBColor[
              0.5177571149520601, 0.6193775764671292, 0.955178883177282], 101 -> 
             RGBColor[
              0.6151488851669328, 0.6984446029768119, 0.962845920086406], 12 -> 
             RGBColor[
              0.9927071993989595, 0.986809761866648, 0.44760184440411643`], 
             39 -> RGBColor[
              0.5541451385708962, 0.6489190133026834, 0.9580434816902792], 48 -> 
             RGBColor[
              0.2678473000268679, 0.39885487320088797`, 0.9385648795407346], 
             77 -> RGBColor[
              0.27424994521707097`, 0.4055844592469431, 0.938929500712452], 
             56 -> RGBColor[
              0.4277044035792992, 0.5448777901571772, 0.948473924285287], 110 -> 
             RGBColor[
              0.71299708434329, 0.7757180083583032, 0.9720285440969098], 73 -> 
             RGBColor[
              0.8711783859336111, 0.9001180137088746, 0.9875749662321157], 37 -> 
             RGBColor[
              0.297791439367026, 0.43032806221548436`, 0.9402701539777724], 
             130 -> RGBColor[
              0.3576250416434594, 0.48417856913949886`, 0.9440085293114818], 
             107 -> RGBColor[
              0.7610121439705878, 0.8132277378671173, 0.9768142365143154], 59 -> 
             RGBColor[
              0.46797091230575444`, 0.5789588943159883, 0.9512595309320954], 
             47 -> RGBColor[
              0.3009726105781192, 0.43367167485624764`, 0.940451316972123], 
             159 -> RGBColor[
              0.24835727917944883`, 0.37836962555155584`, 0.9374549516863762],
              55 -> RGBColor[
              0.7053471970855971, 0.769741858291297, 0.9712660748273239], 49 -> 
             RGBColor[
              0.4423613139196147, 0.557572869216225, 0.949407849651575], 82 -> 
             RGBColor[
              0.7567062314725216, 0.8098639262974808, 0.9763850633975483], 
             199 -> RGBColor[
              0.33096486854496276`, 0.46108686718084263`, 0.942309766656311], 
             89 -> RGBColor[
              0.2542262973605144, 0.38453833577710095`, 0.9377891835893535], 
             144 -> RGBColor[
              0.6853172517480622, 0.754094312760392, 0.9692696770665599], 78 -> 
             RGBColor[
              0.43266609265839195`, 0.5491753558557432, 0.9487900787259573], 
             42 -> RGBColor[
              0.8493829852007985, 0.8827389527849221, 0.9854961014532361], 
             154 -> RGBColor[
              0.45698806410652854`, 0.5700425233761838, 0.9503949208903537], 
             168 -> RGBColor[
              0.36087415441144166`, 0.48699278731396906`, 0.94421555990398], 
             121 -> RGBColor[
              0.6029557004629291, 0.6885456263373906, 0.9618860279213997], 
             128 -> RGBColor[
              0.855914185414111, 0.8879467545503106, 0.9861190531600531], 115 -> 
             RGBColor[
              0.22209447153483242`, 0.3507657495588844, 0.9359593236433574], 
             61 -> RGBColor[
              0.4833674161279051, 0.5914584697234032, 0.9524716001122269], 93 -> 
             RGBColor[
              0.27180968652856485`, 0.40301959264398596`, 0.9387905315901808],
              88 -> RGBColor[
              0.9522648338892142, 0.9639197717905125, 0.9656873642870096], 21 -> 
             RGBColor[
              0.4100842573117488, 0.5296161050745268, 0.9473511841460022], 62 -> 
             RGBColor[
              0.26863100100690185`, 0.39967859262041566`, 0.9386095101521659],
              136 -> RGBColor[
              0.8404313904790921, 0.8756011941383992, 0.9846422903574967], 
             190 -> RGBColor[
              0.18164819492976195`, 0.3082541484049034, 0.9336559680256028], 
             57 -> RGBColor[
              0.32871997030298983`, 0.45914244915551206`, 0.9421667237254181],
              111 -> RGBColor[
              0.9852780819914064, 0.9881801228144806, 0.8936438107123], 63 -> 
             RGBColor[
              0.577179989505309, 0.6676197429994487, 0.9598568695352754], 75 -> 
             RGBColor[
              0.3525377761845628, 0.4797722354923992, 0.9436843732549332], 30 -> 
             RGBColor[
              0.7972180873091279, 0.8415120959785458, 0.9804229065825238], 5 -> 
             RGBColor[
              0.26549579527488365`, 0.39638329261253996`, 0.9384309648238487],
              171 -> RGBColor[
              0.577179989505309, 0.6676197429994487, 0.9598568695352754], 102 -> 
             RGBColor[
              0.7578751299797977, 0.8107770786953227, 0.976501568276776], 31 -> 
             RGBColor[
              0.992079786127685, 0.990992802270655, 0.7809219709281126], 96 -> 
             RGBColor[
              0.2582200296448561, 0.388736001625196, 0.9380166207347493], 70 -> 
             RGBColor[
              0.27811424642676386`, 0.4096460848291781, 0.9391495669496227], 
             52 -> RGBColor[
              0.28560131656141624`, 0.4175154702483621, 0.9395759445176635], 
             183 -> RGBColor[
              0.8269915093617318, 0.8648845977512705, 0.9833603824985995], 
             158 -> RGBColor[
              0.5685459144393687, 0.6606102119002693, 0.9591771635184255], 13 -> 
             RGBColor[
              0.4007512828283618, 0.5215323516659539, 0.946756495264746], 170 -> 
             RGBColor[
              0.5042205810075551, 0.6083880083970752, 0.9541132376392129], 86 -> 
             RGBColor[
              0.7107807613920374, 0.7739866000241064, 0.9718076417378445], 18 -> 
             RGBColor[
              0.42012950539174576`, 0.5383167940725714, 0.9479912584709955], 
             153 -> RGBColor[
              0.2543896665044372, 0.3847100471055658, 0.9377984872204169], 58 -> 
             RGBColor[
              0.22356825481583897`, 0.3523147892304793, 0.9360432534209437], 
             22 -> RGBColor[
              0.9634072270132843, 0.9722297503384497, 0.9468261991295144], 66 -> 
             RGBColor[
              0.9706724655543365, 0.9776481533466301, 0.9345280453572006], 
             143 -> RGBColor[
              0.35840116774137437`, 0.4848508105562809, 0.9440579833801396], 
             119 -> RGBColor[
              0.38339584742524085`, 0.5064999458293175, 0.9456506222676682], 
             145 -> RGBColor[
              0.488439643627265, 0.5955763325086283, 0.9528709044411581], 91 -> 
             RGBColor[
              0.6587323042939616, 0.7333259497561644, 0.9666199379547941], 
             177 -> RGBColor[
              0.2920560483785939, 0.42429980264185035`, 0.9399435319457318], 
             200 -> RGBColor[
              0.43885616739035327`, 0.5545368874663658, 0.9491845048142098], 
             114 -> RGBColor[
              0.813073087764507, 0.8538981428367545, 0.9820031848545128], 24 -> 
             RGBColor[
              0.7424024062367602, 0.7986896693102059, 0.9749593917748943], 
             176 -> RGBColor[
              0.5218034061181207, 0.6226625379190769, 0.9554974220399272], 79 -> 
             RGBColor[
              0.2682271237207058, 0.39925409198532463`, 0.9385865099381999], 
             109 -> RGBColor[
              0.2712392255022809, 0.4024200019360435, 0.9387580446786554], 
             135 -> RGBColor[
              0.8685806076942428, 0.8980466158556142, 0.9873271878245807], 
             108 -> RGBColor[
              0.5202406138668897, 0.6213937927665389, 0.9553743933092136], 
             191 -> RGBColor[
              0.9855198332017295, 0.988280093152672, 0.8896373675251685], 14 -> 
             RGBColor[
              0.6585594344625604, 0.7331909025300144, 0.9666027079055604], 
             185 -> RGBColor[
              0.9009679552426701, 0.9238714076596006, 0.9904163219462762], 32 -> 
             RGBColor[
              0.2624301989144882, 0.3931611564677288, 0.9382563836462676], 
             122 -> RGBColor[
              0.7777597903996395, 0.8263111265443196, 0.9784834853947092], 
             187 -> RGBColor[
              0.629469375477967, 0.7100706221420463, 0.9639732815413752], 193 -> 
             RGBColor[
              0.6157369912375897, 0.6989220539788479, 0.9628922179505917], 
             100 -> RGBColor[
              0.251561981731493, 0.38173797112363184`, 0.9376374547557825], 
             180 -> RGBColor[
              0.6622803184374976, 0.736097685371001, 0.9669735708465445], 7 -> 
             RGBColor[
              0.5417933803643927, 0.6388912995502779, 0.9570711060382822], 
             175 -> RGBColor[
              0.7423850350019708, 0.7986760987695621, 0.9749576603725539], 
             9 -> 
             RGBColor[
              0.9018555886313654, 0.9245791824295798, 0.9905009852112896], 90 -> 
             RGBColor[
              0.9614829559337886, 0.9707946321180666, 0.9500834881368243], 
             174 -> RGBColor[
              0.9889975389953055, 0.9745482569097803, 0.4117579459475264], 
             142 -> RGBColor[0.178927, 0.305394, 0.933501], 134 -> 
             RGBColor[
              0.2818161642398682, 0.4135370351658966, 0.9393603856925823], 
             105 -> RGBColor[
              0.37449382993011915`, 0.49878946570345195`, 0.945083393584624], 
             16 -> RGBColor[
              0.8436429022950694, 0.8781619664862936, 0.9849486072214552], 
             139 -> RGBColor[
              0.38070603343584286`, 0.5041701641456829, 0.9454792296987728], 
             146 -> RGBColor[
              0.6201127713772526, 0.702474509422875, 0.9632366953921968], 126 -> 
             RGBColor[
              0.4755291507305748, 0.5850950127640182, 0.9518545431476368], 
             198 -> RGBColor[
              0.9852299536760784, 0.9881602205192511, 0.8944414214493743], 40 -> 
             RGBColor[
              0.985538058984911, 0.9882876299823988, 0.8893353191310365], 104 -> 
             RGBColor[
              0.8827671163509688, 0.9093585527759684, 0.988680309684705], 181 -> 
             RGBColor[
              0.43885616739035327`, 0.5545368874663658, 0.9491845048142098], 
             127 -> RGBColor[
              0.2066229083747954, 0.33450415572392395`, 0.9350782410095199], 
             76 -> RGBColor[
              0.32871997030298983`, 0.45914244915551206`, 0.9421667237254181],
              172 -> RGBColor[
              0.34010776075720484`, 0.46900598087996254`, 0.942892343663333], 
             84 -> RGBColor[
              0.44131182901301264`, 0.5566638581387714, 0.9493409774013493], 
             184 -> RGBColor[
              0.9941646666538888, 0.9899271369523984, 0.6062381606579064], 
             151 -> RGBColor[
              0.9265198972354927, 0.9442458326156888, 0.9928534889840395], 35 -> 
             RGBColor[
              0.504674675083755, 0.6087566624248393, 0.9541489855882926], 36 -> 
             RGBColor[
              0.9624950650567319, 0.971549461444781, 0.9483702513920174], 34 -> 
             RGBColor[
              0.8524324713037221, 0.8851705302272983, 0.9857869641600413], 38 -> 
             RGBColor[
              0.2629864068032848, 0.393745766224471, 0.9382880588626987], 54 -> 
             RGBColor[
              0.6291222980522193, 0.7097888490521644, 0.9639459583350338], 60 -> 
             RGBColor[
              0.5916719178921753, 0.6793849433178407, 0.9609977272235724], 87 -> 
             RGBColor[
              0.7656779328018458, 0.8168726875634045, 0.9772792787407396], 
             141 -> RGBColor[
              0.18853200932777658`, 0.3154894737962583, 0.934047991071879], 
             67 -> RGBColor[
              0.2875069831901842, 0.4195184467014401, 0.9396844694129907], 
             133 -> RGBColor[
              0.584753331266218, 0.673768123016113, 0.9604530707407591], 98 -> 
             RGBColor[
              0.38070603343584286`, 0.5041701641456829, 0.9454792296987728], 
             3 -> RGBColor[
              0.9554719738738346, 0.9663116515398327, 0.9602585128491206], 27 -> 
             RGBColor[
              0.21867676116170398`, 0.347173519261373, 0.9357646900936571], 
             163 -> RGBColor[
              0.9936375870879252, 0.9887997670567209, 0.5488688026607924], 85 -> 
             RGBColor[
              0.3597741055168169, 0.48603998025151013`, 0.9441454657611495], 
             83 -> RGBColor[
              0.4215363206374963, 0.5395353067298503, 0.9480808994944568], 28 -> 
             RGBColor[
              0.6558056288627253, 0.7310396086657255, 0.9663282342991453], 44 -> 
             RGBColor[
              0.3719391535718863, 0.49657673344371783`, 0.944920611866089], 
             189 -> RGBColor[
              0.5123869298466268, 0.6150178182744563, 0.954756122534146], 15 -> 
             RGBColor[
              0.5179937567463754, 0.6195696929363457, 0.9551975124861779], 80 -> 
             RGBColor[
              0.41994020788819086`, 0.5381528340893613, 0.9479791966014582], 
             112 -> RGBColor[
              0.39502999099149705`, 0.5165768562373506, 0.9463919396080408], 
             169 -> RGBColor[
              0.4747111309646251, 0.5844309074666497, 0.9517901456351562], 69 -> 
             RGBColor[
              0.5324901677142425, 0.6313385324159321, 0.9563387230596715], 20 -> 
             RGBColor[
              0.6365499338362692, 0.715818938392835, 0.9645306890322806], 8 -> 
             RGBColor[
              0.8242266622633934, 0.8626799837248306, 0.9830966689141518], 
             116 -> RGBColor[
              0.38568839730559284`, 0.5084856373087709, 0.9457967015188219], 
             97 -> RGBColor[
              0.9884414341924711, 0.9894882502440643, 0.8412188782475853], 
             118 -> RGBColor[
              0.985538058984911, 0.9882876299823988, 0.8893353191310365], 178 -> 
             RGBColor[
              0.45698806410652854`, 0.5700425233761838, 0.9503949208903537], 
             81 -> 
             RGBColor[
              0.3350431069178822, 0.4646192322812448, 0.9425696283991889], 
             166 -> RGBColor[
              0.2629864068032848, 0.393745766224471, 0.9382880588626987], 125 -> 
             RGBColor[
              0.2875069831901842, 0.4195184467014401, 0.9396844694129907], 95 -> 
             RGBColor[
              0.35070789991239915`, 0.4781872886377067, 0.9435677751569669], 
             157 -> RGBColor[
              0.3674804357195669, 0.4927148161417141, 0.9446365063072286], 74 -> 
             RGBColor[
              0.5237476072332776, 0.6242409279696235, 0.9556504766735556], 19 -> 
             RGBColor[
              0.36776425873505697`, 0.49296064937237205`, 0.9446545912588008],
              156 -> RGBColor[
              0.579953208321704, 0.6698711669666821, 0.9600751874791373], 167 -> 
             RGBColor[
              0.7171561172876193, 0.7789670765042344, 0.9724430776324279], 33 -> 
             RGBColor[
              0.32601707615543773`, 0.45680133809631235`, 0.9419944977004115],
              43 -> RGBColor[
              0.877222035708255, 0.9049370559886727, 0.9881514149428511], 140 -> 
             RGBColor[
              0.21786168811053744`, 0.3463168258059807, 0.9357182728891857], 
             186 -> RGBColor[
              0.3595433773161141, 0.48584013508079793`, 0.9441307639642258], 
             117 -> RGBColor[
              0.8410493659881, 0.8760939510347837, 0.9847012334132192], 4 -> 
             RGBColor[
              0.9880433604003623, 0.9893236365009974, 0.8478159911647796], 
             106 -> RGBColor[
              0.5226837829744544, 0.623377267511574, 0.9555667285309845], 65 -> 
             RGBColor[
              0.23743728043579151`, 0.36689201450406245`, 0.9368330739126153],
              53 -> RGBColor[
              0.48945223651027836`, 0.5963984010278481, 0.9529506194621588], 
             2 -> RGBColor[
              0.3366256592121667, 0.46598995953716293`, 0.9426704672319847], 
             147 -> RGBColor[
              0.6233166210679819, 0.7050755389335929, 0.9634889141759391], 94 -> 
             RGBColor[
              0.3892689383698679, 0.5115869220154196, 0.9460248504292894], 23 -> 
             RGBColor[
              0.3474764410037569, 0.475388361348888, 0.9433618694527751], 194 -> 
             RGBColor[
              0.8595085884446404, 0.8908128339593836, 0.9864618905298664], 
             129 -> RGBColor[
              0.2898098329688846, 0.42193888782796324`, 0.9398156133011267], 
             99 -> 
             RGBColor[
              0.20466891801062498`, 0.3324503879610362, 0.9349669641489501], 
             25 -> RGBColor[
              0.4359006446939131, 0.5519769622555992, 0.9489961815214587], 
             138 -> RGBColor[
              0.33120858518019, 0.4612979622807222, 0.9423252960647975], 124 -> 
             RGBColor[
              0.519386842023372, 0.6207006623219881, 0.9553071812622226], 197 -> 
             RGBColor[
              0.955913589502354, 0.9666410077525032, 0.9595109727818398], 164 -> 
             RGBColor[
              0.30435637886932787`, 0.43722822987360904`, 0.9406440175704708],
              152 -> RGBColor[
              0.8968325938434305, 0.9205739827312418, 0.9900218874843361], 17 -> 
             RGBColor[
              0.9329523288356614, 0.949374878969959, 0.9934670200523631], 149 -> 
             RGBColor[
              0.8711783859336111, 0.9001180137088746, 
               0.9875749662321157]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9lnk01I33xy0ZCmPGjGUM5jOLCfGgkIjPm8rSZv1l6yGUlK0nopQSkiYJ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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.3723682825696561, 0.4876388741576211, 0.9457081995641081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 78}], {
             RGBColor[
             0.47521160380522603`, 0.5842764661614361, 0.9519844809516196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 88}], {
             RGBColor[
             0.7350109744206372, 0.7916486741288209, 0.9604331237321457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 89}], {
             RGBColor[
             0.38599170615628725`, 0.501957956122115, 0.9464840333833178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[
             0.4868232047447376, 0.5942640346040509, 0.9527436524511148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 122}], {
             RGBColor[
             0.6477584526758497, 0.7228443515057243, 0.9668311842859956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 136}], {
             RGBColor[
             0.6790942527155761, 0.7474893853027642, 0.9699105867673894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 138}], {
             RGBColor[
             0.4244828500661251, 0.5403377693739257, 0.9487520896210397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 144}], {
             RGBColor[
             0.6015371833500611, 0.6867359446137606, 0.962224280121921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 159}], {
             RGBColor[
             0.3830571970657545, 0.4988736010093425, 0.9463169174318291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 167}], {
             RGBColor[
             0.6174566161198397, 0.6991723264856817, 0.9638109804048549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 197}], {
             RGBColor[
             0.7368353522272071, 0.7930092921098162, 0.957344927979561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 26}], {
             RGBColor[
             0.34174872835926395`, 0.4704273045394363, 0.9429969046678854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 40}], {
             RGBColor[
             0.6610818590985388, 0.7271387947597809, 0.9160028931815105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 51}], {
             RGBColor[
             0.6121079991296513, 0.6895972095840813, 0.9659054101015959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 74}], {
             RGBColor[
             0.43018663322272216`, 0.5451154437533932, 0.9491604719527702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 80}], {
             RGBColor[
             0.3782829335501788, 0.5020713968132622, 0.9453248319167215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 121}], {
             RGBColor[
             0.4697906798375479, 0.5772677929372767, 0.9522782475766922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 158}], {
             RGBColor[
             0.4525857868257677, 0.563300085718716, 0.9509238153752051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 164}], {
             RGBColor[
             0.3204910190407473, 0.451609094705386, 0.9416572424012277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 166}], {
             RGBColor[
             0.29980603300772574`, 0.42986786288081696`, 0.9404792630473418]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 169}], {
             RGBColor[
             0.4056683950883959, 0.5252104335019063, 0.9472303064335704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 184}], {
             RGBColor[
             0.6653951629330277, 0.7279585482447807, 0.7744543139449456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 5}], {
             RGBColor[
             0.6104838845743592, 0.6813474720761863, 0.9493447388364846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 10}], {
             RGBColor[
             0.6614762047967008, 0.7295132338407734, 0.9524475095781746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 11}], {
             RGBColor[
             0.5800704459422298, 0.6493810197504344, 0.9476127384990354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 15}], {
             RGBColor[
             0.7367328653101051, 0.7929406722380892, 0.9577280126676493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 20}], {
             RGBColor[
             0.7960109538550519, 0.8410652949663338, 0.9623946009407005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 28}], {
             RGBColor[
             0.80563880136828, 0.8486756301027791, 0.9632933735741329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 48}], {
             RGBColor[
             0.6116596369503513, 0.6825832623703603, 0.9494116961949276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 63}], {
             RGBColor[
             0.7663259816895718, 0.8169656972696406, 0.960057691192198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 77}], {
             RGBColor[
             0.6148609595454528, 0.6859480553933879, 0.9495940067807862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 106}], {
             RGBColor[
             0.7390778784241445, 0.7948444595257034, 0.9579126206900526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 186}], {
             RGBColor[
             0.6575076755949744, 0.7260758933103153, 0.9521946384066732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 189}], {
             RGBColor[
             0.7339294518602307, 0.7906647349071445, 0.9575073176916333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 41}], {
             RGBColor[
             0.9473837707951329, 0.9588924512411655, 0.9193906735402733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 66}], {
             RGBColor[
             0.9793579129773494, 0.9834858949238138, 0.8911720182609901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 80}], {
             RGBColor[
             0.7039917841442767, 0.7637382352951794, 0.8978975938831188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 81}], {
             RGBColor[
             0.6615432336591223, 0.7269714343911211, 0.8951928097819842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 168}], {
             RGBColor[
             0.674458757405902, 0.7381582119074832, 0.8960157755343798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 172}], {
             RGBColor[
             0.6640755605787836, 0.72916480869048, 0.8953541674140563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 173}], {
             RGBColor[
             0.9293124068817277, 0.9444828361907219, 0.9176670107177156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 184}], {
             RGBColor[
             0.9911040135271256, 0.989625386726698, 0.727027075911343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 198}], {
             RGBColor[
             0.9866366570382203, 0.9887419285101242, 0.871128706307077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 9}], {
             RGBColor[
             0.5836756919531245, 0.6604812375210598, 0.9644659750175691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.23508235664275431`, 0.3644168402867881, 0.9366989644863994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 15}], {
             RGBColor[
             0.3917447760106295, 0.5079764927744428, 0.9468142386550134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 17}], {
             RGBColor[
             0.5992240620552725, 0.6728790857912494, 0.965948992438106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 20}], {
             RGBColor[
             0.45102286455557644`, 0.5561011155026875, 0.9514808269280646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 28}], {
             RGBColor[
             0.4606507120688045, 0.5637114506391327, 0.952379599561497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 48}], {
             RGBColor[
             0.26667154765087575`, 0.397619082906714, 0.9384979221822917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 63}], {
             RGBColor[
             0.42133789239009634`, 0.5320015178059944, 0.949143917179562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[
             0.2698728702459773, 0.4009838759297415, 0.9386802327681503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 102}], {
             RGBColor[
             0.5116854626273406, 0.6035801856539313, 0.9574662665503124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 106}], {
             RGBColor[
             0.394089789124669, 0.509880280062057, 0.9469988466774166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 112}], {
             RGBColor[
             0.33026289313319035`, 0.4564800744249453, 0.9424114522159448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 140}], {
             RGBColor[
             0.24167874169271053`, 0.37135005920926034`, 0.9370746188565172]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 189}], {
             RGBColor[
             0.38894136256075523`, 0.5057005554434981, 0.9465935436789974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 12}], {
             RGBColor[
             0.909184174502621, 0.9253167834302884, 0.7154176680008075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 13}], {
             RGBColor[
             0.6132062162173222, 0.6926780783299414, 0.9649949934311223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 14}], {
             RGBColor[
             0.7421102920344216, 0.7985073537619717, 0.9749180997515294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 16}], {
             RGBColor[
             0.834652025950676, 0.8709928857401112, 0.9840910494094768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 59}], {
             RGBColor[
             0.6468160309560186, 0.7213913496549587, 0.967246511264797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 64}], {
             RGBColor[
             0.8614157356509893, 0.8923335413735944, 0.9866437959329384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 83}], {
             RGBColor[
             0.6235987351218895, 0.7016795558618896, 0.9656571955459776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 86}], {
             RGBColor[
             0.76822095549916, 0.8189052025090177, 0.9775205666676715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 124}], {
             RGBColor[
             0.6725239958148274, 0.7422622336579585, 0.9692703364298605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 137}], {
             RGBColor[
             0.9080741620810763, 0.9270790107256939, 0.8952745789086087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 161}], {
             RGBColor[
             0.7215702298238567, 0.7820801759341511, 0.9731314356333263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 175}], {
             RGBColor[
             0.7840230923041267, 0.8312499518817456, 0.9790955759850262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 176}], {
             RGBColor[
             0.6737322778622017, 0.7432431714565029, 0.9693654568187129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 186}], {
             RGBColor[
             0.5926022634611984, 0.6748319700373635, 0.9636821277808622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 187}], {
             RGBColor[
             0.7275652625421248, 0.7869472135679876, 0.9736033865694369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 193}], {
             RGBColor[
             0.7206990704219363, 0.7813729294863885, 0.9730628547740451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 199}], {
             RGBColor[
             0.5783130090756228, 0.6624553360873858, 0.9627716291269048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 18}], {
             RGBColor[
             0.48096144287806925`, 0.5886040468114246, 0.9525311822546388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 42}], {
             RGBColor[
             0.6955881827825956, 0.7608151261675999, 0.9712836037457591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 47}], {
             RGBColor[
             0.42138299547125596`, 0.5362814872032627, 0.9487612115052027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.5854578392083061, 0.6743400743012211, 0.960508532186658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 58}], {
             RGBColor[
             0.38268081759011585`, 0.4956030443903786, 0.946557179729613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.512580398246149, 0.6151748846368406, 0.9547713530752545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 73}], {
             RGBColor[
             0.706485883149002, 0.7695046566295762, 0.9723230361351989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 88}], {
             RGBColor[
             0.7470291071268035, 0.8014055356703952, 0.9613792351626459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 94}], {
             RGBColor[
             0.4655311593671303, 0.5752391107828487, 0.9515479782337858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 97}], {
             RGBColor[
             0.7651174072784319, 0.8141897748971711, 0.8991449921429338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 115}], {
             RGBColor[
             0.3819439259496126, 0.49482852455458115`, 0.9465152148408198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 153}], {
             RGBColor[
             0.39809152343441495`, 0.5118006733279219, 0.9474347966293495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 160}], {
             RGBColor[
             0.7622744007123663, 0.8127754506646307, 0.935572929731666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 188}], {
             RGBColor[
             0.39253472456736904`, 0.5059601253972593, 0.9471183451544185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 55}], {
             RGBColor[
             0.7647869296744952, 0.8162109210080638, 0.9771813718707378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 62}], {
             RGBColor[
             0.5464288316351475, 0.6311792881726231, 0.9608530895331588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 68}], {
             RGBColor[
             0.7311010437663885, 0.7898281001403625, 0.9738697889268972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 75}], {
             RGBColor[
             0.588382219223978, 0.671226109608615, 0.9633905210845425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 96}], {
             RGBColor[
             0.5412233459541247, 0.6257079926750133, 0.9605566448244506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 99}], {
             RGBColor[
             0.5144477901370091, 0.5975651858429334, 0.959031816531551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 107}], {
             RGBColor[
             0.7926194031169906, 0.837953860795974, 0.9799554527142336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 147}], {
             RGBColor[
             0.7237716416656876, 0.7838777613292117, 0.9732927915450454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 156}], {
             RGBColor[
             0.7020899352925487, 0.7662755753457564, 0.9715859281966446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 157}], {
             RGBColor[
             0.5958535489914801, 0.6776973999332723, 0.9638665876106902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 179}], {
             RGBColor[
             0.512908559287411, 0.5959473566271332, 0.9589441596117543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 185}], {
             RGBColor[
             0.8625973087530318, 0.8932756956922157, 0.9867564954302139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 194}], {
             RGBColor[
             0.8418676253540169, 0.8767464088421071, 0.9847792797220092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.5532622533209952, 0.628514785195308, 0.9627339746801198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 17}], {
             RGBColor[
             0.9174039587335134, 0.9369770306997693, 0.9919840026318263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 20}], {
             RGBColor[
             0.7692027612338173, 0.8201990604112074, 0.9775158371217851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 28}], {
             RGBColor[
             0.7788306087470453, 0.8278093955476526, 0.9784146097552174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 63}], {
             RGBColor[
             0.7395177890683372, 0.7960994627145143, 0.9751789273732825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 77}], {
             RGBColor[
             0.5880527669242182, 0.6650818208382614, 0.9647152429618708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 97}], {
             RGBColor[
             0.9451485114119182, 0.9570337163368221, 0.9158599317294375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 102}], {
             RGBColor[
             0.8298653593055816, 0.8676781305624512, 0.9835012767440328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.7122696858029098, 0.7739782249705769, 0.973033856871137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 112}], {
             RGBColor[
             0.6484427898114312, 0.7205780193334652, 0.9684464624096651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 140}], {
             RGBColor[
             0.5598586383709514, 0.6354480041177802, 0.9631096290502377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 189}], {
             RGBColor[
             0.7071212592389962, 0.769798500352018, 0.9726285538727177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 14}], {
             RGBColor[
             0.5130199350910636, 0.6129528593358642, 0.9556196071063945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.44273709623297114`, 0.5561422545390299, 0.9499170093967033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 28}], {
             RGBColor[
             0.511643032291146, 0.6118772124037197, 0.955482370303187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 48}], {
             RGBColor[
             0.31766386787321743`, 0.44578484467130103`, 0.9416006929239816]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 59}], {
             RGBColor[
             0.4177256740126607, 0.5358368552288513, 0.947948018619662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 77}], {
             RGBColor[
             0.32086519046831896`, 0.4491496376943286, 0.9417830035098402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 186}], {
             RGBColor[
             0.3635119065178405, 0.489277475611256, 0.9443836351357272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 193}], {
             RGBColor[
             0.4916087134785783, 0.595818435060281, 0.9537643621289101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 15}], {
             RGBColor[
             0.3613313373785002, 0.47601004044869094`, 0.945082238317564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 17}], {
             RGBColor[
             0.5688106234231431, 0.6409126334654975, 0.9642169921006566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 20}], {
             RGBColor[
             0.4206094259234471, 0.5241346631769356, 0.9497488265906153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 28}], {
             RGBColor[
             0.43023727343667517`, 0.5317449983133808, 0.9506475992240477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 48}], {
             RGBColor[
             0.23625810901874644`, 0.3656526305809621, 0.9367659218448423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 63}], {
             RGBColor[
             0.390924453757967, 0.5000350654802425, 0.9474119168421127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 77}], {
             RGBColor[
             0.23945943161384797`, 0.36901742360398965`, 0.936948232430701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 106}], {
             RGBColor[
             0.36367635049253966`, 0.4779138277363051, 0.9452668463399673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 112}], {
             RGBColor[
             0.29984945450106104`, 0.4245136220991934, 0.9406794518784954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 140}], {
             RGBColor[
             0.21126530306058122`, 0.33938360688350844`, 0.9353426185190679]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 189}], {
             RGBColor[
             0.35852792392862587`, 0.4737341031177463, 0.944861543341548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 13}], {
             RGBColor[
             0.6967292411136606, 0.7541710567663009, 0.6971791698344312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 14}], {
             RGBColor[
             0.8256333169307599, 0.8600003321983312, 0.7071022761548384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.9181750508470145, 0.9324858641764708, 0.7162752258127858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 23}], {
             RGBColor[
             0.6700918202013582, 0.731099061607768, 0.6954818569284458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 25}], {
             RGBColor[
             0.7143039220464362, 0.7693933620611236, 0.6982990129627875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 59}], {
             RGBColor[
             0.7303390558523569, 0.7828843280913182, 0.6994306876681059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.9449387605473277, 0.953826519809954, 0.7188279723362474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 86}], {
             RGBColor[
             0.8517439803954985, 0.8803981809453771, 0.7097047430709804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 87}], {
             RGBColor[
             0.8791925661004026, 0.9018412247150263, 0.7124405615724281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 95}], {
             RGBColor[
             0.6717075496556792, 0.7324985252521774, 0.6955848097805417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 108}], {
             RGBColor[
             0.7564739066329246, 0.8041017773165935, 0.7014881188566651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 154}], {
             RGBColor[
             0.724847631752744, 0.7784261426214159, 0.698998382647235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 161}], {
             RGBColor[
             0.805093254720195, 0.8435731543705107, 0.7053156120366353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 175}], {
             RGBColor[
             0.8675461172004651, 0.8927429303181051, 0.7112797523883352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 193}], {
             RGBColor[
             0.8042220953182746, 0.842865907922748, 0.705247031177354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 16}], {
             RGBColor[
             0.6221970925617156, 0.6998471590761237, 0.9658525512431007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 64}], {
             RGBColor[
             0.6489608022620289, 0.7211878147096069, 0.9684052977665621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 69}], {
             RGBColor[
             0.46662072527130216`, 0.576435442040943, 0.9515476091622088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 82}], {
             RGBColor[
             0.5787287571504417, 0.6656981389817174, 0.9615707793311472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 83}], {
             RGBColor[
             0.4111438017329291, 0.530533829197902, 0.9474186973796015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 86}], {
             RGBColor[
             0.5557660221101997, 0.6477594758450301, 0.9592820685012953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 101}], {
             RGBColor[
             0.5079500839976473, 0.6099884773213828, 0.9548012076755761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 108}], {
             RGBColor[
             0.46049594834762575`, 0.5714630722162464, 0.9510654442869798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 110}], {
             RGBColor[
             0.556874183585826, 0.6486251800121285, 0.959392519680828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 124}], {
             RGBColor[
             0.4600690624258669, 0.571116506993971, 0.9510318382634844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 127}], {
             RGBColor[
             0.3036870956015786, 0.42801825369493895`, 0.940917368137133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 137}], {
             RGBColor[
             0.6956192286921159, 0.7559332840617063, 0.8770360807422324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 161}], {
             RGBColor[
             0.5091152964348962, 0.6109344492701636, 0.9548929374669501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 175}], {
             RGBColor[
             0.5715681589151663, 0.660104225217758, 0.96085707781865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 176}], {
             RGBColor[
             0.46127734447324126`, 0.5720974447925153, 0.9511269586523365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 187}], {
             RGBColor[
             0.5151103291531645, 0.615801486904, 0.9553648884030606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 199}], {
             RGBColor[
             0.3658580756866623, 0.4913096094233983, 0.9445331309605285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 15}], {
             RGBColor[
             0.5882765956044679, 0.6763802977331801, 0.9609001101958692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 48}], {
             RGBColor[
             0.4632033672447141, 0.5660228878654512, 0.9525837937231475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 59}], {
             RGBColor[
             0.5632651733841574, 0.6560748984230014, 0.9589311194188279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 186}], {
             RGBColor[
             0.5090514058893372, 0.6095155188054062, 0.9553667359348931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 193}], {
             RGBColor[
             0.6371482128500751, 0.7160564782544312, 0.964747462928076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 28}], {
             RGBColor[
             0.5868996928045503, 0.6753046508010356, 0.9607628733926616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 48}], {
             RGBColor[
             0.3929205283866216, 0.5092122830686168, 0.9468811960134562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 59}], {
             RGBColor[
             0.4929823345260649, 0.599264293626167, 0.9532285217091366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 63}], {
             RGBColor[
             0.5475868731258422, 0.6435947179678971, 0.9575271910107266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 77}], {
             RGBColor[
             0.39612185098172314`, 0.5125770760916444, 0.9470635065993149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 106}], {
             RGBColor[
             0.5203387698604149, 0.6214734802239599, 0.9553821205085812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.4565118738689362, 0.5680732745868482, 0.9507947260471094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 140}], {
             RGBColor[
             0.3679277224284564, 0.4829432593711632, 0.9454578926876818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 193}], {
             RGBColor[
             0.5668653739919826, 0.6592458734575968, 0.9590448652183847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 64}], {
             RGBColor[
             0.8704066119953827, 0.8995026221197768, 0.9875013537449167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 83}], {
             RGBColor[
             0.6325896114662829, 0.708848636608072, 0.966514753357956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 86}], {
             RGBColor[
             0.7772118318435535, 0.8260742832551999, 0.9783781244796499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 101}], {
             RGBColor[
             0.7293958937310011, 0.7883032847315528, 0.9738972636539306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 124}], {
             RGBColor[
             0.6815148721592208, 0.7494313144041409, 0.9701278942418389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 127}], {
             RGBColor[
             0.5251329053349324, 0.6063330611051088, 0.9600134241154875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 137}], {
             RGBColor[
             0.9170650384254697, 0.9342480914718763, 0.896132136720587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 161}], {
             RGBColor[
             0.73056110616825, 0.7892492566803335, 0.9739889934453047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 175}], {
             RGBColor[
             0.7930139686485201, 0.8384190326279279, 0.9799531337970045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 176}], {
             RGBColor[
             0.682723154206595, 0.7504122522026853, 0.9702230146306912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.7365561388865183, 0.79411629431417, 0.9744609443814152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 193}], {
             RGBColor[
             0.7296899467663296, 0.7885420102325708, 0.9739204125860235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 199}], {
             RGBColor[
             0.5873038854200161, 0.6696244168335681, 0.9636291869388831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 20}], {
             RGBColor[
             0.7847511313359653, 0.8325969086813969, 0.9789988545423218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 28}], {
             RGBColor[
             0.7943789788491933, 0.8402072438178423, 0.9798976271757542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 77}], {
             RGBColor[
             0.6036011370263662, 0.677479669108451, 0.9661982603824075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 106}], {
             RGBColor[
             0.7278180559050579, 0.7863760732407665, 0.9745168742916738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 112}], {
             RGBColor[
             0.6639911599135793, 0.7329758676036549, 0.969929479830202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 140}], {
             RGBColor[
             0.5754070084730993, 0.6478458523879699, 0.9645926464707744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 189}], {
             RGBColor[
             0.7226696293411441, 0.7821963486222077, 0.9741115712932545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 47}], {
             RGBColor[
             0.3605510579849325, 0.4859942344644095, 0.9442212877215592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 54}], {
             RGBColor[
             0.5246259017219825, 0.624052821562368, 0.9559686084030147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 58}], {
             RGBColor[
             0.32184888010379237`, 0.44531579165152535`, 0.9420172559459696]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 61}], {
             RGBColor[
             0.45174846075982544`, 0.5648876318979873, 0.9502314292916112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 73}], {
             RGBColor[
             0.6456539456626784, 0.719217403890723, 0.9677831123515557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 94}], {
             RGBColor[
             0.40469922188080687`, 0.5249518580439955, 0.9470080544501425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 115}], {
             RGBColor[
             0.3211119884632891, 0.4445412718157279, 0.9419752910571765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 116}], {
             RGBColor[
             0.40290895134866933`, 0.5234012156906711, 0.9468939799949088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 153}], {
             RGBColor[
             0.33725958594809147`, 0.4615134205890686, 0.9428948728457063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 160}], {
             RGBColor[
             0.7014424632260428, 0.7624881979257775, 0.9310330059480227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 174}], {
             RGBColor[
             0.7045635221935256, 0.7564325254911759, 0.679874602209261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 188}], {
             RGBColor[
             0.33170278708104556`, 0.45567287265840606`, 0.9425784213707752]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 33}], {
             RGBColor[
             0.3468906674452473, 0.4748809937343422, 0.9433245444796061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 34}], {
             RGBColor[
             0.6100983650193895, 0.6890655897998352, 0.965220777709421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 44}], {
             RGBColor[
             0.3698517061534716, 0.4947686914080449, 0.9447876015624449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 50}], {
             RGBColor[
             0.41111686187447705`, 0.5304792302717807, 0.9474256194013251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 60}], {
             RGBColor[
             0.4797180883136162, 0.5861727963451064, 0.9528261592411866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 90}], {
             RGBColor[
             0.6646236073344227, 0.7318776407452193, 0.9473690396978125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 130}], {
             RGBColor[
             0.36269465018925817`, 0.48856960925593546`, 0.9443315602851413]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 141}], {
             RGBColor[
             0.2781481340314168, 0.40422506158431515`, 0.9393512911653399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 177}], {
             RGBColor[
             0.3299101535568254, 0.45863022600711123`, 0.9422990616022663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.6461777813494973, 0.7234292735292802, 0.9654294616657129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 77}], {
             RGBColor[
             0.45539993952667013`, 0.560701698819889, 0.9517300948723663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 106}], {
             RGBColor[
             0.5796168584053618, 0.6695981029522045, 0.9600487087816325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 189}], {
             RGBColor[
             0.574468431841448, 0.6654183783336456, 0.9596434057832133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.6862896611842404, 0.7505827832596539, 0.9478607177690097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 46}], {
             RGBColor[
             0.3575366863743365, 0.4837546905992475, 0.9440156175639738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 85}], {
             RGBColor[
             0.38492918141428284`, 0.5078280426630185, 0.9457483249535759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 109}], {
             RGBColor[
             0.3406617414070149, 0.46601805350528513`, 0.9430546144123289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 132}], {
             RGBColor[
             0.4984041604415266, 0.6024920786781938, 0.953979699076424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 150}], {
             RGBColor[
             0.4590891715051717, 0.5705743995395929, 0.9508846791318044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 151}], {
             RGBColor[
             0.6683020772736208, 0.7369309688451078, 0.9701023365650208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 194}], {
             RGBColor[
             0.6347964228781946, 0.7102144695169552, 0.9669065373379343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 196}], {
             RGBColor[
             0.6326880616911932, 0.7085333195363801, 0.9667054399657619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 24}], {
             RGBColor[
             0.8529048166250223, 0.8854597098243278, 0.9608927954522044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 37}], {
             RGBColor[
             0.6305993331901552, 0.7012789062769671, 0.9435481765536433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 38}], {
             RGBColor[
             0.6131968169082845, 0.6829877582814603, 0.9425571289961066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 79}], {
             RGBColor[
             0.615817175366995, 0.6857419211618871, 0.9427063545338572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 89}], {
             RGBColor[
             0.6088167621868994, 0.6783840430577753, 0.9423076913594339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 118}], {
             RGBColor[
             0.9744726429990976, 0.9802586901604242, 0.9180807591302754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 119}], {
             RGBColor[
             0.6734015372192625, 0.7393648480838836, 0.9462384106985913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 122}], {
             RGBColor[
             0.870583508706462, 0.8992704384413847, 0.9626548422621117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 128}], {
             RGBColor[
             0.9096607062136977, 0.9300882524443801, 0.9664726261447838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 138}], {
             RGBColor[
             0.6473079060967372, 0.716763856309586, 0.9445757475971559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 144}], {
             RGBColor[
             0.8243622393806733, 0.8631620315494208, 0.9580479380980371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 149}], {
             RGBColor[
             0.9172928064734477, 0.9361738820236621, 0.967200582680815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 181}], {
             RGBColor[
             0.7011316972018188, 0.7633833189024077, 0.9480053519718621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 183}], {
             RGBColor[
             0.8951993681875081, 0.9185571740448601, 0.9650932908140569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 190}], {
             RGBColor[
             0.5725277109715231, 0.6402419493716766, 0.9402410835775585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 192}], {
             RGBColor[
             0.870583508706462, 0.8992704384413847, 0.9626548422621117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 25}], {
             RGBColor[
             0.39168854284883503`, 0.5136826618022436, 0.946179025487117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 43}], {
             RGBColor[
             0.6123492383560059, 0.6901627086687804, 0.9657566421978131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 49}], {
             RGBColor[
             0.3949188774616858, 0.5164806152825565, 0.9463848595521751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 64}], {
             RGBColor[
             0.6223233813497264, 0.698115819551074, 0.9667079848605766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 67}], {
             RGBColor[
             0.3174917120969706, 0.4474534040251641, 0.941523169432883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 87}], {
             RGBColor[
             0.5565771869028013, 0.6461305244561463, 0.9603205740967573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 95}], {
             RGBColor[
             0.34909217045807805`, 0.47678782499329736`, 0.9434648223048709]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 103}], {
             RGBColor[
             0.3536252732602869, 0.48071417080019907`, 0.9437536676069623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 108}], {
             RGBColor[
             0.43385852743532327`, 0.5483910770577135, 0.9493681313809943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 129}], {
             RGBColor[
             0.31864313698632074`, 0.4486636245884256, 0.9415887413769509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 131}], {
             RGBColor[
             0.44986489257069806`, 0.5613857653531428, 0.9506282110776985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 143}], {
             RGBColor[
             0.35293880437256564`, 0.4801195859525844, 0.9437099264164573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 154}], {
             RGBColor[
             0.4022322525551427, 0.5227154423625359, 0.9468783951715645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 162}], {
             RGBColor[
             0.527178407215033, 0.6231639743250604, 0.9573903784846969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.4805395836992321, 0.5729315942857894, 0.9553620409342758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 37}], {
             RGBColor[
             0.5200969228018931, 0.6145088657628451, 0.9576147728763333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 56}], {
             RGBColor[
             0.5850534049080297, 0.6717837297336915, 0.9617166580300907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 79}], {
             RGBColor[
             0.5053147649787331, 0.5989718806477653, 0.9567729508565471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 89}], {
             RGBColor[
             0.4983143517986373, 0.5916140025436534, 0.956374287682124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 118}], {
             RGBColor[
             0.8639702326108356, 0.8934886496463024, 0.9321473554529653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 119}], {
             RGBColor[
             0.5628991268310005, 0.6525948075697616, 0.9603050070212813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 125}], {
             RGBColor[
             0.5149546947134722, 0.609104058005823, 0.9573219305939424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 144}], {
             RGBColor[
             0.7138598289924112, 0.776391991035299, 0.9721145344207271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 149}], {
             RGBColor[
             0.8067903960851857, 0.8494038415095402, 0.981267179003505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 170}], {
             RGBColor[
             0.6233114936221577, 0.7035388388536405, 0.9645363147070536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 190}], {
             RGBColor[
             0.4620253005832611, 0.5534719088575546, 0.9543076799002486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 195}], {
             RGBColor[
             0.7815034394875554, 0.8292407087147414, 0.9788552865092903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 197}], {
             RGBColor[
             0.8491579978695571, 0.8826653385313545, 0.9672351822783671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[
             0.656561340201084, 0.728457009122136, 0.968573798232155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 49}], {
             RGBColor[
             0.4391309793067639, 0.5547749157359121, 0.9492020155865168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 64}], {
             RGBColor[
             0.6665354831948045, 0.7364101200044296, 0.9695251408949185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 67}], {
             RGBColor[
             0.36170381394204865`, 0.48574770447851967`, 0.9443403254672247]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 87}], {
             RGBColor[
             0.6007892887478794, 0.6844248249095018, 0.9631377301310992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 95}], {
             RGBColor[
             0.3933042723031561, 0.515082125446653, 0.9462819783392128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 103}], {
             RGBColor[
             0.397837375105365, 0.5190084712535546, 0.9465708236413042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 108}], {
             RGBColor[
             0.4780706292804014, 0.5866853775110691, 0.9521852874153361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 129}], {
             RGBColor[
             0.3628552388313988, 0.48695792504178126`, 0.9444058974112928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 131}], {
             RGBColor[
             0.4940769944157762, 0.5996800658064984, 0.9534453671120403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 143}], {
             RGBColor[
             0.3971509062176437, 0.51841388640594, 0.9465270824507992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 154}], {
             RGBColor[
             0.4464443544002208, 0.5610097428158916, 0.9496955512059062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 162}], {
             RGBColor[
             0.571390509060111, 0.6614582747784161, 0.9602075345190386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 40}], {
             RGBColor[
             0.6662049282456362, 0.7315761397620543, 0.9163293306174114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 51}], {
             RGBColor[
             0.6172310682767486, 0.6940345545863547, 0.9662318475374967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 74}], {
             RGBColor[
             0.4353097023698194, 0.5495527887556666, 0.949486909388671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 80}], {
             RGBColor[
             0.38340600269727604`, 0.5065087418155355, 0.9456512693526222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 121}], {
             RGBColor[
             0.47491374898464517`, 0.5817051379395501, 0.952604685012593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 158}], {
             RGBColor[
             0.457708855972865, 0.5677374307209895, 0.951250252811106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 164}], {
             RGBColor[
             0.32561408818784454`, 0.45604643970765935`, 0.9419836798371286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.304929102154823, 0.43430520788309035`, 0.9408057004832425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 169}], {
             RGBColor[
             0.4107914642354932, 0.5296477785041798, 0.9475567438694712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 184}], {
             RGBColor[
             0.6705182320801251, 0.732395893247054, 0.7747807513808463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 37}], {
             RGBColor[
             0.258234100264365, 0.38875079073842866`, 0.9380174220357147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 56}], {
             RGBColor[
             0.3231905823705016, 0.44602565470927513`, 0.942119307189472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 67}], {
             RGBColor[
             0.2530918721759441, 0.38334598298140654`, 0.9377245797533239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 119}], {
             RGBColor[
             0.3010363042934724, 0.42683673254534527`, 0.9407076561806627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 125}], {
             RGBColor[
             0.2530918721759441, 0.38334598298140654`, 0.9377245797533239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 128}], {
             RGBColor[
             0.5372954732879075, 0.6175601369058419, 0.9609418716268552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 133}], {
             RGBColor[
             0.401715046213961, 0.510470821138743, 0.9481088804172082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 190}], {
             RGBColor[
             0.20016247804573295`, 0.32771383383313824`, 0.9347103290596299]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 195}], {
             RGBColor[
             0.5196406169500273, 0.603482633690325, 0.9592579356686718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 48}], {
             RGBColor[
             0.4618264644447966, 0.5649472409333067, 0.95244655691994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 63}], {
             RGBColor[
             0.6164928091840172, 0.6993296758325871, 0.9630925519172103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 77}], {
             RGBColor[
             0.4650277870398981, 0.5683120339563343, 0.9526288675057986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 106}], {
             RGBColor[
             0.5892447059185899, 0.6772084380886497, 0.9609474814150649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 112}], {
             RGBColor[
             0.5254178099271112, 0.623808232451538, 0.9563600869535931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 140}], {
             RGBColor[
             0.43683365848663136`, 0.5386782172358531, 0.9510232535941655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 189}], {
             RGBColor[
             0.584096279354676, 0.673028713470091, 0.9605421784166457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 35}], {
             RGBColor[
             0.36582706263550346`, 0.4823284171364761, 0.9451932507696135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 47}], {
             RGBColor[
             0.26397603038268563`, 0.39478592335218027`, 0.9383444164615287]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 88}], {
             RGBColor[
             0.5896221420382332, 0.6599099718193127, 0.950962440118972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 89}], {
             RGBColor[
             0.24060287377388323`, 0.3702192538126069, 0.9370133497701439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 113}], {
             RGBColor[
             0.34143437236233354`, 0.4625253322945426, 0.943272968837941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 122}], {
             RGBColor[
             0.5023696202934458, 0.5911056491962162, 0.9573605006728219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 136}], {
             RGBColor[
             0.533705420333172, 0.615750682993256, 0.9604399031542156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 138}], {
             RGBColor[
             0.279094017683721, 0.4085990670644175, 0.939281406007866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 142}], {
             RGBColor[
             0.202953225093626, 0.33064708592405645`, 0.9348692579754672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 144}], {
             RGBColor[
             0.45614835096765716`, 0.5549972423042524, 0.9527535965087471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 153}], {
             RGBColor[
             0.24068455834584462`, 0.37030510947683937`, 0.9370180015856757]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 159}], {
             RGBColor[
             0.23766836468335045`, 0.3671348986998344, 0.9368462338186553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 167}], {
             RGBColor[
             0.47206778373743563`, 0.5674336241761736, 0.9543402967916812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 181}], {
             RGBColor[
             0.33291780878880267`, 0.4552185296572393, 0.9427110103825721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 188}], {
             RGBColor[
             0.23512775947879871`, 0.3644645615461768, 0.9367015501107446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 41}], {
             RGBColor[
             0.8519711342495158, 0.8849866809799397, 0.9856941312491454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 65}], {
             RGBColor[
             0.5173276838724596, 0.6042020552413041, 0.9586279902475696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 66}], {
             RGBColor[
             0.8839452764317322, 0.909580124662588, 0.9574754759698623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 90}], {
             RGBColor[
             0.8793505216214583, 0.9061533640483062, 0.9652531973596741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 110}], {
             RGBColor[
             0.755107585826209, 0.8086150521684246, 0.9762257253397169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 162}], {
             RGBColor[
             0.7520492303677184, 0.8062258416398893, 0.9759208970495712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 180}], {
             RGBColor[
             0.7297492028733128, 0.7888048906747733, 0.9736982387145341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 198}], {
             RGBColor[
             0.8912240204926032, 0.9148361582488984, 0.9374321640159491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 38}], {
             RGBColor[
             0.6275330964654848, 0.692369284247563, 0.8596050148954056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[
             0.9888089225562979, 0.989640216126527, 0.8351286450295745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 46}], {
             RGBColor[
             0.6485344507823045, 0.7144430391973116, 0.860801010955029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 80}], {
             RGBColor[
             0.7060099970079379, 0.7645728181800082, 0.8644505837647853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 98}], {
             RGBColor[
             0.6863929097817639, 0.747581483208169, 0.8632006003134427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 117}], {
             RGBColor[
             0.9165645760578924, 0.9335433766527194, 0.8828116021706659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 120}], {
             RGBColor[
             0.8259511471369354, 0.8625852137810166, 0.873825285107181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 121}], {
             RGBColor[
             0.7975177432953071, 0.8397692143040227, 0.8714039994247561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 146}], {
             RGBColor[
             0.8060962787524688, 0.8467336558467651, 0.8720793331601546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 151}], {
             RGBColor[
             0.9592998416815888, 0.967619317443172, 0.886887729956076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 171}], {
             RGBColor[
             0.784629887816497, 0.8293062726350519, 0.870389420231694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 173}], {
             RGBColor[
             0.931330619745389, 0.9453174190755507, 0.8842200005993821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 178}], {
             RGBColor[
             0.7245339251171068, 0.7805176628234194, 0.8656584459092331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 196}], {
             RGBColor[
             0.9236858260991613, 0.9392216681344443, 0.883490833356817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 53}], {
             RGBColor[
             0.3759412177123833, 0.49477977874778845`, 0.9456035015542132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 82}], {
             RGBColor[
             0.5095682151935049, 0.6015125413826048, 0.9573207235219079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 83}], {
             RGBColor[
             0.34198325977599225`, 0.4663482315987896, 0.9431686415703622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 100}], {
             RGBColor[
             0.25699609032299064`, 0.3874495637956803, 0.937946919201025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 101}], {
             RGBColor[
             0.4387895420407105, 0.5458028797222704, 0.9505511518663368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 123}], {
             RGBColor[
             0.6323560663048293, 0.22047171882257627`, 0.4222307945487559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 127}], {
             RGBColor[
             0.2345265536446418, 0.3638326560958264, 0.9366673123278937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 130}], {
             RGBColor[
             0.3100276202789738, 0.43866986280361386`, 0.9411324564788748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 135}], {
             RGBColor[
             0.5655054033043656, 0.6456038861616715, 0.9627917857354242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 148}], {
             RGBColor[
             0.4873698108546962, 0.5841709791990058, 0.9551081940332984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 163}], {
             RGBColor[
             0.6280338930012066, 0.6909804617622248, 0.74356259315353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 165}], {
             RGBColor[
             0.2328153283171212, 0.36203404977864995`, 0.9365698605770225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 176}], {
             RGBColor[
             0.39211680251630443`, 0.5079118471934029, 0.9468769028430974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 187}], {
             RGBColor[
             0.4459497871962276, 0.5516158893048876, 0.9511148325938215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 41}], {
             RGBColor[
             0.6163706286726707, 0.692631302038823, 0.9664799268080893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 44}], {
             RGBColor[
             0.34897811486366204`, 0.4766890357700151, 0.9434575547832502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 57}], {
             RGBColor[
             0.3273685232292138, 0.4579718936259122, 0.9420806107129148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 66}], {
             RGBColor[
             0.6483447708548871, 0.7172247457214713, 0.9382612715288061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 90}], {
             RGBColor[
             0.6437500160446132, 0.7137979851071894, 0.9460389929186179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 141}], {
             RGBColor[
             0.25727454274160716`, 0.3861454059462853, 0.9380212443861453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 198}], {
             RGBColor[
             0.6556235149157581, 0.7224807793077817, 0.9182179595748929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 44}], {
             RGBColor[
             0.6121858124378042, 0.6908736318355081, 0.9653537880130652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 50}], {
             RGBColor[
             0.6534509681588097, 0.7265841706992439, 0.9679918058519453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 60}], {
             RGBColor[
             0.7220521945979488, 0.7822777367725695, 0.9733923456918068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 90}], {
             RGBColor[
             0.9069577136187554, 0.9279825811726825, 0.9679352261484329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 104}], {
             RGBColor[
             0.8675997938273454, 0.8972645415016334, 0.9872336369223731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 130}], {
             RGBColor[
             0.6050287564735908, 0.6846745496833986, 0.9648977467357616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 163}], {
             RGBColor[
             0.9230350291958236, 0.9369851486420095, 0.7673278834104169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 177}], {
             RGBColor[
             0.572244259841158, 0.6547351664345743, 0.9628652480528865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 47}], {
             RGBColor[
             0.4028236428309371, 0.5212141686405435, 0.9473001512802078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 68}], {
             RGBColor[
             0.5713250501765693, 0.6628664394903669, 0.9593959472639676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 88}], {
             RGBColor[
             0.7284697544864847, 0.7863382171076758, 0.9599181749376511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.44697180672681147`, 0.5601717922201295, 0.950086918008791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 111}], {
             RGBColor[
             0.7449763785375807, 0.79846839261966, 0.9238963981502963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 116}], {
             RGBColor[
             0.44518153619467393`, 0.5586211498668051, 0.9499728435535573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 122}], {
             RGBColor[
             0.6412172327416972, 0.7175338944845795, 0.9663162354915009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 138}], {
             RGBColor[
             0.4179416301319725, 0.5350273123527807, 0.9482371408265451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 142}], {
             RGBColor[
             0.3418008375418775, 0.4570753312124196, 0.9438249927941463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 153}], {
             RGBColor[
             0.37953217079409607`, 0.49673335476520253`, 0.9459737364043548]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 157}], {
             RGBColor[
             0.43607755540166093`, 0.5507357392832767, 0.9493927459477607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 160}], {
             RGBColor[
             0.7437150480720474, 0.7977081321019115, 0.9341118695066712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 167}], {
             RGBColor[
             0.6109153961856871, 0.6938618694645369, 0.9632960316103603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 174}], {
             RGBColor[
             0.7468361070395302, 0.7916524596673098, 0.6829534657679095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 181}], {
             RGBColor[
             0.4717654212370541, 0.5816467749456025, 0.9516667452012513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 185}], {
             RGBColor[
             0.7028213151632126, 0.76631403504222, 0.9722826537672844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 188}], {
             RGBColor[
             0.37397537192705016`, 0.49089280683453995`, 0.9456572849294238]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 132}], {
             RGBColor[
             0.7746095643140181, 0.8234587568633209, 0.9544892326994316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 151}], {
             RGBColor[
             0.9445074811461123, 0.9578976470302349, 0.9706118701880284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 169}], {
             RGBColor[
             0.7186030980106785, 0.7779901844557153, 0.9500801985135867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 200}], {
             RGBColor[
             0.7006756162235426, 0.7630431744555735, 0.9487773781031136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 56}], {
             RGBColor[
             0.3627479214731626, 0.4876029261863308, 0.9443720391315297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 79}], {
             RGBColor[
             0.2830092815438659, 0.4147910771004045, 0.9394283319579861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 118}], {
             RGBColor[
             0.6416647491759685, 0.7093078460989416, 0.9148027365544045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 119}], {
             RGBColor[
             0.3405936433961334, 0.4684140040224009, 0.9429603881227202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 125}], {
             RGBColor[
             0.2926492112786051, 0.42492325445846224`, 0.9399773116953816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 128}], {
             RGBColor[
             0.5768528123905685, 0.6591374083828975, 0.9631946035689127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 149}], {
             RGBColor[
             0.5844849126503185, 0.6652230379621795, 0.963922560104944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 170}], {
             RGBColor[
             0.40100601018729054`, 0.5193580353062798, 0.9471916958084926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 190}], {
             RGBColor[
             0.23971981714839397`, 0.3692911053101939, 0.9369630610016876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 195}], {
             RGBColor[
             0.5591979560526883, 0.6450599051673807, 0.9615106676107295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 46}], {
             RGBColor[
             0.2839877611201045, 0.4158195211742196, 0.9394840549223221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 98}], {
             RGBColor[
             0.3218462201195638, 0.44895796518507697`, 0.9418836442807358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 117}], {
             RGBColor[
             0.5520178863956924, 0.6349198586296274, 0.961494646137959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 120}], {
             RGBColor[
             0.46140445747473535`, 0.5639616957579245, 0.9525083290744741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 128}], {
             RGBColor[
             0.5594502961086979, 0.6408462603873908, 0.962203556011376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 146}], {
             RGBColor[
             0.4415495890902687, 0.548110137823673, 0.9507623771274478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 156}], {
             RGBColor[
             0.4214698075624944, 0.5318084665955766, 0.949181623170918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 171}], {
             RGBColor[
             0.4200831981542969, 0.5306827546119599, 0.949072464198987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 178}], {
             RGBColor[
             0.35998723545490663`, 0.4818941448003274, 0.9443414898765262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 179}], {
             RGBColor[
             0.2322884315573567, 0.3614802478769533, 0.9365398545860277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 183}], {
             RGBColor[
             0.5449889580825082, 0.6293151819878707, 0.9608242206806491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 192}], {
             RGBColor[
             0.5203730986014621, 0.6100284463843952, 0.9583857721287039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 114}], {
             RGBColor[
             0.6836091131677016, 0.751408578069719, 0.970023333272396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 46}], {
             RGBColor[
             0.6452635872109176, 0.7130904530531835, 0.915007685056491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 74}], {
             RGBColor[
             0.7546428331090943, 0.8062642789760112, 0.922492897902296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.7027391334365509, 0.7632202320358801, 0.9186572578662473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 117}], {
             RGBColor[
             0.9132937124865055, 0.9321907905085913, 0.9370182762721279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 121}], {
             RGBColor[
             0.79424687972392, 0.8384166281598947, 0.9256106735262181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 166}], {
             RGBColor[
             0.6242622328940979, 0.6910166981034349, 0.9138116889968676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 169}], {
             RGBColor[
             0.730124594974768, 0.7863592687245242, 0.9205627323830963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 171}], {
             RGBColor[
             0.7813590242451101, 0.8279536864909238, 0.9245960943331559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 173}], {
             RGBColor[
             0.928059756174002, 0.9439648329314226, 0.9384266747008441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 196}], {
             RGBColor[
             0.9204149625277742, 0.9378690819903162, 0.937697507458279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 57}], {
             RGBColor[
             0.6177220757464467, 0.6938018575684228, 0.9665660398205924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 66}], {
             RGBColor[
             0.93869832337212, 0.9530547096639819, 0.9627467006364837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 81}], {
             RGBColor[
             0.6208836440538928, 0.6965402491312892, 0.9667674921574778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 90}], {
             RGBColor[
             0.9341035685618461, 0.9496279490497002, 0.9705244220262956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 141}], {
             RGBColor[
             0.54762809525884, 0.621975369888796, 0.9625066734938229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 168}], {
             RGBColor[
             0.6337991678006726, 0.7077270266476513, 0.9675904579098734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 172}], {
             RGBColor[
             0.6234159709735542, 0.698733623430648, 0.9669288497895498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 184}], {
             RGBColor[
             0.9504444239218961, 0.959194201466866, 0.7986017582868365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 198}], {
             RGBColor[
             0.9459770674329909, 0.9583107432502924, 0.9427033886825706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 88}], {
             RGBColor[
             0.9008239095450064, 0.9233293622877172, 0.9755917328701229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[
             0.9189122096966348, 0.9361136015144932, 0.9133574898504107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 102}], {
             RGBColor[
             0.803629057590298, 0.8467580157401224, 0.980998834865006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 153}], {
             RGBColor[
             0.5518863258526179, 0.6337244999452439, 0.9616472943368265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 49}], {
             RGBColor[
             0.6597916748139349, 0.7312549626024488, 0.9687796322972131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 67}], {
             RGBColor[
             0.5823645094492196, 0.6622277513450564, 0.9639179421779209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 87}], {
             RGBColor[
             0.8214499842550504, 0.8609048717760386, 0.9827153468417953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 95}], {
             RGBColor[
             0.6139649678103271, 0.6915621723131897, 0.9658595950499089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 103}], {
             RGBColor[
             0.6184980706125359, 0.6954885181200914, 0.9661484403520003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 129}], {
             RGBColor[
             0.5835159343385697, 0.663437971908318, 0.9639835141219889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 131}], {
             RGBColor[
             0.7147376899229472, 0.7761601126730351, 0.9730229838227364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 133}], {
             RGBColor[
             0.7309876834872364, 0.7893525895023928, 0.9743022428418051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 143}], {
             RGBColor[
             0.6178116017248146, 0.6948939332724768, 0.9661046991614953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 154}], {
             RGBColor[
             0.6671050499073917, 0.7374897896824282, 0.9692731679166025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 197}], {
             RGBColor[
             0.9165678126053045, 0.9357890318705879, 0.9738311938623454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 50}], {
             RGBColor[
             0.41320430929289176`, 0.5322872723074537, 0.9475586297049692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 57}], {
             RGBColor[
             0.350329561937438, 0.47785959129961497`, 0.9435436677957536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 60}], {
             RGBColor[
             0.4818055357320308, 0.5879808383807793, 0.9529591695448307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 90}], {
             RGBColor[
             0.6667110547528374, 0.7336856827808922, 0.9475020500014566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 141}], {
             RGBColor[
             0.2802355814498314, 0.40603310361998807`, 0.939484301468984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 177}], {
             RGBColor[
             0.3319976009752401, 0.4604382680427841, 0.9424320719059104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 120}], {
             RGBColor[
             0.7987649922002842, 0.8436202717966593, 0.9785288864410415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 128}], {
             RGBColor[
             0.8968108308342467, 0.9205048364261255, 0.9882241133779432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 168}], {
             RGBColor[
             0.649290815332912, 0.7200278528079548, 0.9672723667499068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 172}], {
             RGBColor[
             0.6389076185057936, 0.7110344495909515, 0.9666107586295832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 173}], {
             RGBColor[
             0.9041444648087378, 0.9263524770911935, 0.9889236019332426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 85}], {
             RGBColor[
             0.33238161047687054`, 0.46196662818773915`, 0.9424127583715476]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 98}], {
             RGBColor[
             0.34284757443638353`, 0.4710317201348256, 0.9430796403403592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 99}], {
             RGBColor[
             0.25482901672377456`, 0.3851718320425022, 0.9378235075654477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 109}], {
             RGBColor[
             0.2881141704696025, 0.4201566390300059, 0.9397190478303005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 117}], {
             RGBColor[
             0.5730192407125121, 0.6569936135793759, 0.9626906421975824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 121}], {
             RGBColor[
             0.45397240794992666`, 0.5632194512306794, 0.9512830394516726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 146}], {
             RGBColor[
             0.4625509434070884, 0.5701838927734216, 0.9519583731870711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 151}], {
             RGBColor[
             0.6157545063362084, 0.6910695543698285, 0.9667667699829925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 171}], {
             RGBColor[
             0.4410845524711166, 0.5527565095617084, 0.9502684602586104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 178}], {
             RGBColor[
             0.38098858977172634`, 0.503967899750076, 0.9455374859361496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 196}], {
             RGBColor[
             0.5801404907537808, 0.6626719050611009, 0.9633698733837335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 54}], {
             RGBColor[
             0.46504745431516925`, 0.5717302619542061, 0.9521986376535785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 61}], {
             RGBColor[
             0.39217001335301216`, 0.5125650722898254, 0.9464614585421749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 73}], {
             RGBColor[
             0.5860754982558651, 0.6668948442825611, 0.9640131416021194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 88}], {
             RGBColor[
             0.6266187222336668, 0.6987957233233801, 0.9530693406295663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 94}], {
             RGBColor[
             0.3451207744739936, 0.47262929843583357`, 0.9432380837007062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 105}], {
             RGBColor[
             0.33773322025411917`, 0.4662305702798498, 0.9427673552783735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 111}], {
             RGBColor[
             0.6431253462847628, 0.7109258988353642, 0.9170475638422115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 116}], {
             RGBColor[
             0.34333050394185605`, 0.4710786560825093, 0.9431240092454725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 126}], {
             RGBColor[
             0.388250880654347, 0.509383343810133, 0.9461529300598799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 142}], {
             RGBColor[
             0.2399498052890596, 0.3695328374281238, 0.9369761584860615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 153}], {
             RGBColor[
             0.2776811385412782, 0.40919086098090673`, 0.93912490209627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 157}], {
             RGBColor[
             0.33422652314884305`, 0.4631932454989809, 0.9425439116396759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 160}], {
             RGBColor[
             0.6418640158192295, 0.7101656383176156, 0.9272630351985864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 167}], {
             RGBColor[
             0.5090643639328692, 0.606319375680241, 0.9564471973022755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 174}], {
             RGBColor[
             0.6449850747867123, 0.7041099658830139, 0.6761046314598247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 188}], {
             RGBColor[
             0.2721243396742323, 0.40335031305024416`, 0.938808450621339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 59}], {
             RGBColor[
             0.3679091061663112, 0.48890688375843816`, 0.944912205236415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.42251364476608844`, 0.5332373081001683, 0.949210874538005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 77}], {
             RGBColor[
             0.27104862262196944`, 0.40221966622391553`, 0.9387471901265934]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 106}], {
             RGBColor[
             0.3952655415006612, 0.511116070356231, 0.9470658040358595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 112}], {
             RGBColor[
             0.33143864550918245`, 0.4577158647191193, 0.9424784095743877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 140}], {
             RGBColor[
             0.2428544940687027, 0.3725858495034343, 0.9371415762149602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 193}], {
             RGBColor[
             0.4417921456322288, 0.5488884635898679, 0.9507285487456631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 67}], {
             RGBColor[
             0.3649341485548995, 0.48854565795883254`, 0.9445461595322828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.6040196233607302, 0.6872227783898147, 0.9633435641961573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 95}], {
             RGBColor[
             0.39653460691600695`, 0.5178800789269659, 0.9464878124042709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 103}], {
             RGBColor[
             0.4010677097182158, 0.5218064247338675, 0.9467766577063623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 108}], {
             RGBColor[
             0.48130096389325216`, 0.589483330991382, 0.9523911214803943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[
             0.36608557344424963`, 0.4897558785220941, 0.9446117314763509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 131}], {
             RGBColor[
             0.49730732902862695`, 0.6024780192868112, 0.9536512011770985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 133}], {
             RGBColor[
             0.5135573225929163, 0.615670496116169, 0.954930460196167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 143}], {
             RGBColor[
             0.40038124083049453`, 0.5212118398862529, 0.9467329165158573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 154}], {
             RGBColor[
             0.4496746890130716, 0.5638076962962044, 0.9499013852709643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 162}], {
             RGBColor[
             0.5746208436729618, 0.664256228258729, 0.9604133685840968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 53}], {
             RGBColor[
             0.47196085076208777`, 0.5821981060995187, 0.9515736335030041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 60}], {
             RGBColor[
             0.5230706914530363, 0.6236913772445151, 0.9555971873837108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 82}], {
             RGBColor[
             0.6055878482432093, 0.6889308687343352, 0.9632908554706988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 100}], {
             RGBColor[
             0.3530157233726951, 0.4748678911474106, 0.9439170511498159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 104}], {
             RGBColor[
             0.668618290682433, 0.7386781819735789, 0.9694384786142771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 123}], {
             RGBColor[
             0.6963691550046324, 0.27875060372372984`, 0.4262108825146165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.4060472533286783, 0.5260881901553441, 0.9471025884276656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 163}], {
             RGBColor[
             0.7240535260509111, 0.7783987891139552, 0.7495327251023209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 177}], {
             RGBColor[
             0.37326275669624553`, 0.49614880690651986`, 0.9450700897447906]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 71}], {
             RGBColor[
             0.5494706341793733, 0.6263390325666789, 0.9622439238892992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 74}], {
             RGBColor[
             0.7056689731402068, 0.7687226938003116, 0.9723954148223815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 158}], {
             RGBColor[
             0.7280681267432523, 0.7869073357656344, 0.9741587582448163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 164}], {
             RGBColor[
             0.5959733589582319, 0.6752163447523044, 0.964892185270839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 166}], {
             RGBColor[
             0.5752883729252103, 0.6534751129277354, 0.963714205916953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 184}], {
             RGBColor[
             0.9408775028505123, 0.9515657982916991, 0.7976892568145568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 70}], {
             RGBColor[
             0.28185778149409, 0.4135807775387701, 0.939362755733643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 134}], {
             RGBColor[
             0.2837087404006422, 0.4155262527071294, 0.9394681651051229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 145}], {
             RGBColor[
             0.38702048009434065`, 0.5065459013784952, 0.9462234244794108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 100}], {
             RGBColor[
             0.3705071091208857, 0.48906818607574, 0.9452940371089706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 104}], {
             RGBColor[
             0.6861096764306236, 0.7528784769019083, 0.9708154645734319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 123}], {
             RGBColor[
             0.7080300788367595, 0.28821746700928275`, 0.4271288731540529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 130}], {
             RGBColor[
             0.42353863907686884`, 0.5402884850836736, 0.9484795743868203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 135}], {
             RGBColor[
             0.6790164221022605, 0.7472225084417312, 0.9701389036433697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 148}], {
             RGBColor[
             0.6008808296525914, 0.6857896014790655, 0.962455311941244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 163}], {
             RGBColor[
             0.7415449117991018, 0.7925990840422845, 0.7509097110614755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 165}], {
             RGBColor[
             0.3463263471150163, 0.4636526720587096, 0.943916978484968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 58}], {
             RGBColor[
             0.42634527643402914`, 0.5310518191413218, 0.9499946058779888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 61}], {
             RGBColor[
             0.5562448570900622, 0.6506236593877839, 0.9582087792236303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 73}], {
             RGBColor[
             0.7501503419929152, 0.8049534313805196, 0.9757604622835747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 94}], {
             RGBColor[
             0.5091956182110436, 0.610687885533792, 0.9549854043821616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 105}], {
             RGBColor[
             0.5018080639911693, 0.6042891573778082, 0.9545146759598289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 115}], {
             RGBColor[
             0.42560838479352586`, 0.5302772993055245, 0.9499526409891956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 116}], {
             RGBColor[
             0.5074053476789061, 0.6091372431804677, 0.9548713299269278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 126}], {
             RGBColor[
             0.552325724391397, 0.6474419309080913, 0.9579002507413353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 160}], {
             RGBColor[
             0.8059388595562795, 0.8482242254155741, 0.9390103558800418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 174}], {
             RGBColor[
             0.8090599185237624, 0.8421685529809724, 0.6878519521412801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 62}], {
             RGBColor[
             0.4869890990462495, 0.5847102254558564, 0.9549377924897449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 68}], {
             RGBColor[
             0.6716613111774904, 0.7433590374235958, 0.9679544918834833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 72}], {
             RGBColor[
             0.520503768390408, 0.6174478532906247, 0.9569375163766436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 75}], {
             RGBColor[
             0.5289424866350799, 0.6247570468918482, 0.9574752240411285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 76}], {
             RGBColor[
             0.5170335836942934, 0.6144421537234046, 0.956716399276371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 96}], {
             RGBColor[
             0.48178361336522657`, 0.5792389299582466, 0.9546413477810366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 107}], {
             RGBColor[
             0.7331796705280924, 0.7914847980792072, 0.9740401556708196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 111}], {
             RGBColor[
             0.8453126395385018, 0.8789609905528888, 0.9324549427698119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 139}], {
             RGBColor[
             0.5430266152607199, 0.63695601121849, 0.9583726522630484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 147}], {
             RGBColor[
             0.6643319090767895, 0.737408698612445, 0.9673774945016315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 157}], {
             RGBColor[
             0.536413816402582, 0.6312283372165055, 0.9579512905672762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 182}], {
             RGBColor[
             0.7459418454410109, 0.8014547061173009, 0.9753121699968341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 185}], {
             RGBColor[
             0.8031575761641336, 0.8468066329754489, 0.9808411983868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 191}], {
             RGBColor[
             0.8454335151436634, 0.8790109757219845, 0.9304517211762462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 79}], {
             RGBColor[
             0.3479657636500025, 0.4720659410712509, 0.9435302171117435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 118}], {
             RGBColor[
             0.7066212312821051, 0.766582710069788, 0.9189046217081618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 119}], {
             RGBColor[
             0.40555012550227, 0.5256888679932473, 0.9470622732764775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 125}], {
             RGBColor[
             0.3576056933847417, 0.48219811842930865`, 0.9440791968491389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 129}], {
             RGBColor[
             0.35875711827409185`, 0.4834083389925702, 0.9441447687932069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 149}], {
             RGBColor[
             0.6494413947564551, 0.7224979019330259, 0.9680244452587013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 170}], {
             RGBColor[
             0.4659624922934271, 0.5766328992771261, 0.9512935809622499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 190}], {
             RGBColor[
             0.30467629925453055`, 0.4265659692810403, 0.9410649461554449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 195}], {
             RGBColor[
             0.6241544381588249, 0.7023347691382271, 0.9656125527644868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 197}], {
             RGBColor[
             0.6918089965408266, 0.7557593989548401, 0.9539924485335634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 66}], {
             RGBColor[
             0.6496962179286632, 0.7183953012510711, 0.9383473845413093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 71}], {
             RGBColor[
             0.2700354498073002, 0.3993080273289351, 0.9387571092664047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 81}], {
             RGBColor[
             0.331881538610436, 0.4618808407183784, 0.9423681760623035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 90}], {
             RGBColor[
             0.6451014631183892, 0.7149685406367894, 0.9461251059311212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 141}], {
             RGBColor[
             0.2586259898153832, 0.3873159614758852, 0.9381073573986485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 198}], {
             RGBColor[
             0.6569749619895341, 0.7236513348373816, 0.9183040725873962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 61}], {
             RGBColor[
             0.35346783547187205`, 0.47188662947694127`, 0.9442574267665853]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 73}], {
             RGBColor[
             0.5473733203747251, 0.6262164014696769, 0.9618091098265298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 92}], {
             RGBColor[
             0.4460025999625946, 0.5466110390748137, 0.9518152296385956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 115}], {
             RGBColor[
             0.2228313631753357, 0.35154026939468186`, 0.9360012885321506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 155}], {
             RGBColor[
             0.2339398720148713, 0.36321601650517377`, 0.936633901676996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 154}], {
             RGBColor[
             0.4624794882061415, 0.5745007088460861, 0.9508272259112245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 186}], {
             RGBColor[
             0.4137571448109343, 0.5323995146983931, 0.9476951474481605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 193}], {
             RGBColor[
             0.5418539517716721, 0.6389404741474181, 0.9570758744413435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.6741890746823485, 0.7446244348076607, 0.9686913953105603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 104}], {
             RGBColor[
             0.7372195171215721, 0.7943717480469046, 0.9748390184541387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 123}], {
             RGBColor[
             0.7421033059640585, 0.31587964777261357`, 0.4298112424078575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 130}], {
             RGBColor[
             0.4746484797678173, 0.5817817562286698, 0.9525031282675271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 163}], {
             RGBColor[
             0.7926547524900502, 0.8340923551872808, 0.7549332649421824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 177}], {
             RGBColor[
             0.4418639831353846, 0.5518423729798455, 0.9504706295846521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 73}], {
             RGBColor[
             0.6772729010307581, 0.7457882417161389, 0.9700232831721713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 94}], {
             RGBColor[
             0.43631817724888655`, 0.5515226958694114, 0.9492482252707581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 105}], {
             RGBColor[
             0.42893062302901214`, 0.5451239677134276, 0.9487774968484255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 115}], {
             RGBColor[
             0.35273094383136877`, 0.4711121096411438, 0.9442154618777922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 116}], {
             RGBColor[
             0.434527906716749, 0.549972053516087, 0.9491341508155244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 160}], {
             RGBColor[
             0.7330614185941224, 0.7890590357511934, 0.9332731767686384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 174}], {
             RGBColor[
             0.7361824775616053, 0.7830033633165918, 0.6821147730298767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 68}], {
             RGBColor[
             0.45330321313814276`, 0.5583274045881551, 0.9516262095459043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 75}], {
             RGBColor[
             0.31058438859573234`, 0.4397254140564074, 0.9411469417035495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 76}], {
             RGBColor[
             0.29867548565494584`, 0.42941052088796383`, 0.940388116938792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 96}], {
             RGBColor[
             0.263425515325879, 0.39420729712280583`, 0.9383130654434576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 105}], {
             RGBColor[
             0.3215624154685105, 0.4492340291619338, 0.9418464518683949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 107}], {
             RGBColor[
             0.5148215724887448, 0.6064531652437665, 0.9577118733332406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 111}], {
             RGBColor[
             0.6269545414991542, 0.6939293577174481, 0.9161266604322329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 116}], {
             RGBColor[
             0.3271596991562473, 0.4540821149645933, 0.9422031058354938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 126}], {
             RGBColor[
             0.3720800758687383, 0.4923868026922169, 0.9452320266499014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 157}], {
             RGBColor[
             0.3180557183632344, 0.44619670438106485`, 0.9416230082296972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 174}], {
             RGBColor[
             0.6288142700011037, 0.6871134247650981, 0.6751837280498462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 182}], {
             RGBColor[
             0.5275837474016634, 0.6164230732818602, 0.9589838876592551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 185}], {
             RGBColor[
             0.584799478124786, 0.6617750001400082, 0.964512916049221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 191}], {
             RGBColor[
             0.6270754171043157, 0.6939793428865437, 0.9141234388386672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 77}], {
             RGBColor[
             0.42571496736118997`, 0.5366021011231958, 0.9493931851238637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 91}], {
             RGBColor[
             0.6179561468996353, 0.7004728463778065, 0.9632384037450348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 102}], {
             RGBColor[
             0.6675275597425534, 0.7391984108473857, 0.9681792189060257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 106}], {
             RGBColor[
             0.5499318862398817, 0.6454985052555113, 0.9577117990331299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 112}], {
             RGBColor[
             0.48610499024840303`, 0.5920982996183997, 0.953124404571658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 140}], {
             RGBColor[
             0.3975208388079232, 0.5069682844027147, 0.9477875712122306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 69}], {
             RGBColor[
             0.7148302447049693, 0.7760909050845961, 0.9731964116640248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 82}], {
             RGBColor[
             0.8269382765841088, 0.8653536020253705, 0.9832195818329632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 86}], {
             RGBColor[
             0.8039755415438667, 0.8474149388886831, 0.9809308710031114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 87}], {
             RGBColor[
             0.8314241272487709, 0.8688579826583323, 0.9836666895045589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 108}], {
             RGBColor[
             0.7087054677812928, 0.7711185352598995, 0.9727142467887959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 110}], {
             RGBColor[
             0.8050837030194931, 0.8482806430557817, 0.981041322182644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 127}], {
             RGBColor[
             0.5518966150352457, 0.627673716738592, 0.962566170638949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 154}], {
             RGBColor[
             0.6770791929011123, 0.7454429005647218, 0.970224510579366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 161}], {
             RGBColor[
             0.7573248158685633, 0.8105899123138167, 0.9765417399687661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 162}], {
             RGBColor[
             0.8020253475610025, 0.8458914325272464, 0.9807364938924984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 175}], {
             RGBColor[
             0.8197776783488334, 0.8597596882614111, 0.982505880320466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 176}], {
             RGBColor[
             0.7094868639069083, 0.7717529078361685, 0.9727757611541528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 180}], {
             RGBColor[
             0.7797253200665968, 0.8284704815621304, 0.9785138355574614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 66}], {
             RGBColor[
             0.604054872995064, 0.6722700839253464, 0.9356805596349079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 69}], {
             RGBColor[
             0.384963724075017, 0.4991152734599973, 0.9465858984861434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 87}], {
             RGBColor[
             0.5015576066188187, 0.5918823510337334, 0.9570561763266774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 90}], {
             RGBColor[
             0.5994601181847901, 0.6688433233110644, 0.9434582810247198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 110}], {
             RGBColor[
             0.4752171823895408, 0.5713050114311828, 0.9544308090047625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 131}], {
             RGBColor[
             0.3948453122867154, 0.5071375919307299, 0.9473638133076185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 133}], {
             RGBColor[
             0.41109530585100473`, 0.5203300687600877, 0.9486430723266872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 162}], {
             RGBColor[
             0.47215882693105027`, 0.5689158009026477, 0.954125980714617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 180}], {
             RGBColor[
             0.44985879943664453`, 0.5514948499375317, 0.9519033223795799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 198}], {
             RGBColor[
             0.6113336170559349, 0.6775261175116567, 0.9156372476809949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 81}], {
             RGBColor[
             0.6528577862361093, 0.7211336928139375, 0.9385488368781947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 90}], {
             RGBColor[
             0.9660777107440626, 0.9742213927323484, 0.9423057667470125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 141}], {
             RGBColor[
             0.5796022374410565, 0.6465688135714442, 0.9342880182145398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 168}], {
             RGBColor[
             0.6657733099828891, 0.7323204703302996, 0.9393718026305903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 172}], {
             RGBColor[
             0.6553901131557707, 0.7233270671132963, 0.9387101945102667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 198}], {
             RGBColor[
             0.9779512096152074, 0.9829041869329407, 0.9144847334032875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 87}], {
             RGBColor[
             0.5265924579960151, 0.6181955671324223, 0.9584818740768651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 103}], {
             RGBColor[
             0.32364054435350054`, 0.4527792134764751, 0.9419149675870702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 129}], {
             RGBColor[
             0.28865840807953436`, 0.4207286672647017, 0.9397500413570588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 131}], {
             RGBColor[
             0.41988016366391173`, 0.5334508080294188, 0.9487895110578063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 133}], {
             RGBColor[
             0.4361301572282011, 0.5466432848587766, 0.9500687700768748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 143}], {
             RGBColor[
             0.32295407546577926`, 0.4521846286288605, 0.9418712263965652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 162}], {
             RGBColor[
             0.4971936783082466, 0.5952290170013366, 0.9555516784648046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 107}], {
             RGBColor[
             0.6994937846199858, 0.765101977211506, 0.970728572726979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 111}], {
             RGBColor[
             0.811626753630395, 0.8525781696851875, 0.9291433598259713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 122}], {
             RGBColor[
             0.7078676078345116, 0.771643671550107, 0.9715631971671759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 138}], {
             RGBColor[
             0.48459200522478685`, 0.5891370894183083, 0.95348410250222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 142}], {
             RGBColor[
             0.40845121263469186`, 0.5111851082779473, 0.9490719544698213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 147}], {
             RGBColor[
             0.6306460231686828, 0.7110258777447437, 0.9640659115577908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 156}], {
             RGBColor[
             0.6089643167955439, 0.6934236917612884, 0.96235904820939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 157}], {
             RGBColor[
             0.5027279304944753, 0.6048455163488042, 0.9546397076234356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 179}], {
             RGBColor[
             0.4197829407904061, 0.5230954730426651, 0.9497172796244997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 181}], {
             RGBColor[
             0.5384157963298685, 0.6357565520111301, 0.9569137068769262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 185}], {
             RGBColor[
             0.7694716902560269, 0.8204238121077476, 0.9775296154429594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 82}], {
             RGBColor[
             0.644598199593382, 0.7206012293567065, 0.9663618932286099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 86}], {
             RGBColor[
             0.6216354645531399, 0.7026625662200192, 0.964073182398758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 90}], {
             RGBColor[
             0.7469865618240156, 0.8010665822669993, 0.953211105598248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 110}], {
             RGBColor[
             0.6227436260287662, 0.7035282703871176, 0.9641836335782906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 123}], {
             RGBColor[
             0.7223760559047475, 0.29986417747197736`, 0.4282582410198905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 127}], {
             RGBColor[
             0.36955653804451893`, 0.48292134406992804`, 0.9457084820345957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 177}], {
             RGBColor[
             0.4122731080464182, 0.5278191675288912, 0.9481411275027016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 180}], {
             RGBColor[
             0.59738524307587, 0.6837181088934665, 0.961656146953108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 72}], {
             RGBColor[
             0.3068872930609914, 0.43739996655956526`, 0.940879262437793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 93}], {
             RGBColor[
             0.27496196647766435`, 0.406332838736582, 0.9389700492699018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 134}], {
             RGBColor[
             0.27996520533331604`, 0.4115915599975374, 0.9392549763211024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 139}], {
             RGBColor[
             0.32941013993130336`, 0.4569081244874305, 0.9423143983241977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.3832769450270144, 0.5026112086689032, 0.9460102356953903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 81}], {
             RGBColor[
             0.2731970181147464, 0.4020464188918015, 0.93895856160329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 164}], {
             RGBColor[
             0.25785365409046923`, 0.3883509176879836, 0.937995756188931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 184}], {
             RGBColor[
             0.6027577979827496, 0.6647003712273782, 0.7707928277326488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 75}], {
             RGBColor[
             0.3440990579398908, 0.47246304189117583`, 0.9431466655904481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 84}], {
             RGBColor[
             0.38848608435411575`, 0.5109088532143619, 0.9459749676636562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 93}], {
             RGBColor[
             0.3037350131118919, 0.43408672046696917`, 0.940699744758072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 134}], {
             RGBColor[
             0.30873825196754356`, 0.4393454417279245, 0.9409846718092727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 139}], {
             RGBColor[
             0.35818318656553083`, 0.48466200621781763`, 0.944044093812368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 152}], {
             RGBColor[
             0.6162464667693246, 0.6928639155105971, 0.9663154227051496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 191}], {
             RGBColor[
             0.6605900864484742, 0.7267169707213121, 0.9161231627255659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 94}], {
             RGBColor[
             0.6302236621517395, 0.7058524678621471, 0.9667999083307026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 115}], {
             RGBColor[
             0.5466364287342218, 0.6254418816338795, 0.9617671449377365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 153}], {
             RGBColor[
             0.5627840262190241, 0.6424140304072201, 0.9626867267262663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 160}], {
             RGBColor[
             0.9269669034969754, 0.9433888077439291, 0.9508248598285828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 80}], {
             RGBColor[
             0.47184390756073424`, 0.5811968810294924, 0.951814836637507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 158}], {
             RGBColor[
             0.5461467608363232, 0.6424255699349464, 0.9574138200959905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 164}], {
             RGBColor[
             0.41405199305130275`, 0.5307345789216162, 0.9481472471220131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 166}], {
             RGBColor[
             0.3933670070182812, 0.5089933470970472, 0.9469692677681272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 169}], {
             RGBColor[
             0.4992293690989513, 0.6043359177181367, 0.953720311154356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 184}], {
             RGBColor[
             0.7589561369435832, 0.8070840324610109, 0.780944318665731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 76}], {
             RGBColor[
             0.34062887324377633`, 0.46945734232395564`, 0.9429255484901756]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 96}], {
             RGBColor[
             0.3053789029147094, 0.4342541185587976, 0.9408504969948412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 134}], {
             RGBColor[
             0.31717697021221547`, 0.44665463532914795`, 0.9415223794737577]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 139}], {
             RGBColor[
             0.36662190481020285`, 0.4919711998190411, 0.944581801476853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 182}], {
             RGBColor[
             0.5695371349904939, 0.656469894717852, 0.9615213192106387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 191}], {
             RGBColor[
             0.6690288046931461, 0.7340261643225356, 0.9166608703900508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.293469999973923, 0.423939225390354, 0.9400916722300837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 105}], {
             RGBColor[
             0.3516069001165545, 0.478965957429482, 0.943625058655021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 111}], {
             RGBColor[
             0.6569990261471981, 0.7236612859849963, 0.917905267218859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 116}], {
             RGBColor[
             0.3572041838042913, 0.4838140432321415, 0.9439817126221199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 126}], {
             RGBColor[
             0.4021245605167823, 0.5221187309597651, 0.9470106334365275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 174}], {
             RGBColor[
             0.6588587546491477, 0.7168453530326462, 0.6769623348364723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.5576282320497074, 0.6461550015494084, 0.9607624944458812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 191}], {
             RGBColor[
             0.6571199017523597, 0.7237112711540921, 0.9159020456252933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 102}], {
             RGBColor[
             0.5160625375984343, 0.6081807689711329, 0.957715534494614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 106}], {
             RGBColor[
             0.3984668640957627, 0.5144808633792586, 0.9472481146217182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 112}], {
             RGBColor[
             0.334639968104284, 0.46108065774214685`, 0.9426607201602464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 140}], {
             RGBColor[
             0.24605581666380422`, 0.37595064252646193`, 0.9373238868008189]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 189}], {
             RGBColor[
             0.3933184375318489, 0.5103011387606997, 0.946842811623299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 91}], {
             RGBColor[
             0.5456991984761768, 0.6412506528059538, 0.9577050083403758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 95}], {
             RGBColor[
             0.39168699628539555`, 0.5136813222467249, 0.9461789269414621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 113}], {
             RGBColor[
             0.4442776935979035, 0.5591629242983578, 0.9495492502254524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 136}], {
             RGBColor[
             0.6365487415687421, 0.7123882749970711, 0.966716184541727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 89}], {
             RGBColor[
             0.2612267105406101, 0.39189621388121276`, 0.9381878467637768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 118}], {
             RGBColor[
             0.6268825913528084, 0.6937708609838618, 0.9139609145346181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 119}], {
             RGBColor[
             0.32581148557297335`, 0.452877018907321, 0.9421185661029341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 125}], {
             RGBColor[
             0.277867053455445, 0.4093862693433824, 0.9391354896755952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 128}], {
             RGBColor[
             0.5620706545674083, 0.6436004232678176, 0.9623527815491265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 144}], {
             RGBColor[
             0.476772187734384, 0.5766742023728583, 0.95392809350238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 149}], {
             RGBColor[
             0.5697027548271585, 0.6496860528470996, 0.9630807380851578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 159}], {
             RGBColor[
             0.2582922014500773, 0.38881185876844027`, 0.9380207308122881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 170}], {
             RGBColor[
             0.3862238523641304, 0.5038210501911999, 0.9463498737887064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 190}], {
             RGBColor[
             0.22493765932523385`, 0.353754120195114, 0.9361212389819014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 192}], {
             RGBColor[
             0.5229934570601726, 0.6127826092648221, 0.9585349976664546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 195}], {
             RGBColor[
             0.5444157982295281, 0.6295229200523008, 0.9606688455909431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 197}], {
             RGBColor[
             0.61207035661153, 0.6829475498689139, 0.9490487413600199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 81}], {
             RGBColor[
             0.37749165740303653`, 0.5013860331853031, 0.9452744125003236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 117}], {
             RGBColor[
             0.6304947869381454, 0.7071233925620726, 0.9663402150073388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 120}], {
             RGBColor[
             0.5398813580171884, 0.6361652296903697, 0.9573538979438538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 121}], {
             RGBColor[
             0.51144795417556, 0.613349230213376, 0.954932612261429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 166}], {
             RGBColor[
             0.3414633073457378, 0.46594930015691616`, 0.9431336277320785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 168}], {
             RGBColor[
             0.39040718114981626`, 0.5125728107016652, 0.9460973782527191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 172}], {
             RGBColor[
             0.38002398432269785`, 0.5035794074846619, 0.9454357701323957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 173}], {
             RGBColor[
             0.645260830625642, 0.7188974349849039, 0.9677486134360549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 184}], {
             RGBColor[
             0.7070524372710398, 0.7640399855208799, 0.7771086786296824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 164}], {
             RGBColor[
             0.31969974289360503`, 0.4509237310774269, 0.9416068229848298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 166}], {
             RGBColor[
             0.2990147568605835, 0.4291824992528579, 0.9404288436309438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 168}], {
             RGBColor[
             0.3479586306646619, 0.4758060097976069, 0.9433925941515844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 172}], {
             RGBColor[
             0.3375754338375435, 0.46681260658060364`, 0.9427309860312609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 173}], {
             RGBColor[
             0.6028122801404876, 0.6821306340808456, 0.9650438293349203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 184}], {
             RGBColor[
             0.6646038867858854, 0.7272731846168217, 0.7744038945285476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 198}], {
             RGBColor[
             0.6601365302969803, 0.7263897264002479, 0.9185055249242816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 86}], {
             RGBColor[
             0.7337434964322795, 0.7919252631607936, 0.9740963525676964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 101}], {
             RGBColor[
             0.6859275583197272, 0.7541542646371464, 0.9696154917419771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 110}], {
             RGBColor[
             0.7348516579079059, 0.792790967327892, 0.974206803747229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 123}], {
             RGBColor[
             0.7971147438241739, 0.3593726420991603, 0.43494035446584944`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 127}], {
             RGBColor[
             0.48166456992365847`, 0.5721840410107024, 0.9557316522035341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 130}], {
             RGBColor[
             0.5571656365579905, 0.6470212477184898, 0.960196796354515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 163}], {
             RGBColor[
             0.8751719092802234, 0.8993318466771009, 0.7626269330291704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 176}], {
             RGBColor[
             0.6392548187953211, 0.7162632321082789, 0.9659412427187377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 177}], {
             RGBColor[
             0.5243811399255578, 0.6170818644696656, 0.95816429767164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 180}], {
             RGBColor[
             0.7094932749550096, 0.7729808058342409, 0.9716793171220464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 187}], {
             RGBColor[
             0.6930878034752443, 0.7599672742197636, 0.9701791724694617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 86}], {
             RGBColor[
             0.5661585410147668, 0.6567609533769783, 0.9599442706161507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 101}], {
             RGBColor[
             0.5183426029022146, 0.6189899548533311, 0.9554634097904314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 124}], {
             RGBColor[
             0.47046158133043414`, 0.5801179845259192, 0.9516940403783397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 135}], {
             RGBColor[
             0.6450584641658695, 0.7187909612927322, 0.9677040436595188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 137}], {
             RGBColor[
             0.7060117475966832, 0.7649347615936546, 0.8776982828570878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 161}], {
             RGBColor[
             0.5195078153394634, 0.6199359268021118, 0.9555551395818055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 165}], {
             RGBColor[
             0.31236838917862525`, 0.43522112490971065`, 0.9414821185011171]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 175}], {
             RGBColor[
             0.5819606778197336, 0.6691057027497063, 0.9615192799335054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 176}], {
             RGBColor[
             0.4716698633778085, 0.5810989223244636, 0.951789160767192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 187}], {
             RGBColor[
             0.5255028480577316, 0.6248029644359483, 0.956027090517916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 199}], {
             RGBColor[
             0.37625059459122956`, 0.5003110869553464, 0.945195333075384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 93}], {
             RGBColor[
             0.35656075777078877`, 0.4798417253913787, 0.944065754495765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 139}], {
             RGBColor[
             0.4110089312244277, 0.5304170111422272, 0.9474101035500611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 152}], {
             RGBColor[
             0.6690722114282216, 0.7386189204350067, 0.9696814324428427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 194}], {
             RGBColor[
             0.6504102087288265, 0.7237383460490775, 0.9679014339656078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 99}], {
             RGBColor[
             0.2822215117637209, 0.4092451841062732, 0.9395562149550498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 109}], {
             RGBColor[
             0.31550666550954887`, 0.4442299910937768, 0.9414517552199024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 132}], {
             RGBColor[
             0.4732490845440606, 0.5807040162666854, 0.9523768398839977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 146}], {
             RGBColor[
             0.48994343844703475`, 0.5942572448371926, 0.9536910805766732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 150}], {
             RGBColor[
             0.43393409560770574`, 0.5487863371280844, 0.9492818199393781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 151}], {
             RGBColor[
             0.6431470013761548, 0.7151429064335995, 0.9684994773725946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 152}], {
             RGBColor[
             0.6283033496801237, 0.7033069814913759, 0.9670836766227429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 194}], {
             RGBColor[
             0.6096413469807287, 0.6884264071054469, 0.965303678145508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 196}], {
             RGBColor[
             0.6075329857937273, 0.6867452571248718, 0.9651025807733355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 101}], {
             RGBColor[
             0.6629648232794851, 0.7362156015004591, 0.9673267809121253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 108}], {
             RGBColor[
             0.6155106876294636, 0.6976901963953226, 0.963591017523529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 110}], {
             RGBColor[
             0.7118889228676637, 0.7748523041912048, 0.9719180929173772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 124}], {
             RGBColor[
             0.6150838017077047, 0.6973436311730472, 0.9635574115000336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 127}], {
             RGBColor[
             0.4587018348834164, 0.5542453778740152, 0.9534429413736822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 161}], {
             RGBColor[
             0.6641300357167339, 0.7371615734492398, 0.9674185107034994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 175}], {
             RGBColor[
             0.7265828981970042, 0.7863313493968342, 0.9733826510551993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 176}], {
             RGBColor[
             0.616292083755079, 0.6983245689715916, 0.9636525318888858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 180}], {
             RGBColor[
             0.6865305399147674, 0.7550421426975537, 0.9693906062921944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 187}], {
             RGBColor[
             0.6701250684350022, 0.7420286110830763, 0.9678904616396098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 199}], {
             RGBColor[
             0.5208728149685, 0.6175367336024745, 0.9570587041970777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 95}], {
             RGBColor[
             0.5581929163571224, 0.6475299881005556, 0.9604235269488532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 103}], {
             RGBColor[
             0.5627260191593313, 0.6514563339074573, 0.9607123722509445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 108}], {
             RGBColor[
             0.6429592733343678, 0.7191332401649717, 0.9663268360249766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 110}], {
             RGBColor[
             0.739337508572568, 0.7962953479608539, 0.9746539114188246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 131}], {
             RGBColor[
             0.6589656384697425, 0.732127928460401, 0.9675869157216808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 143}], {
             RGBColor[
             0.5620395502716101, 0.6508617490598427, 0.9606686310604395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[
             0.6113329984541872, 0.6934576054697941, 0.9638370998155467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 162}], {
             RGBColor[
             0.7362791531140774, 0.7939061374323186, 0.9743490831286791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 180}], {
             RGBColor[
             0.7139791256196717, 0.7764851864672027, 0.9721264247936421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 94}], {
             RGBColor[
             0.670766886129541, 0.737753346902966, 0.9558561073581495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 102}], {
             RGBColor[
             0.855069981934506, 0.8873484252429176, 0.9710944662818928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[
             0.7040770642133146, 0.7665351322657424, 0.9579978930059786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 122}], {
             RGBColor[
             0.8650123121444269, 0.895115449167416, 0.9720854248408595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 136}], {
             RGBColor[
             0.8963481121841532, 0.9197604829644559, 0.9751648273222532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 142}], {
             RGBColor[
             0.5655959169446071, 0.6346568858952563, 0.9495941821435048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 153}], {
             RGBColor[
             0.6033272501968256, 0.6743149094480392, 0.9517429257537133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 167}], {
             RGBColor[
             0.8347104755884167, 0.8714434241473734, 0.9690652209597188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 188}], {
             RGBColor[
             0.5977704513297798, 0.6684743615173766, 0.9514264742787822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 113}], {
             RGBColor[
             0.3550577959489647, 0.4768444142590367, 0.9440488026571505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 118}], {
             RGBColor[
             0.6198821781727126, 0.6864129828797498, 0.913562251360195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 122}], {
             RGBColor[
             0.5159930438800769, 0.6054247311607103, 0.9581363344920313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 136}], {
             RGBColor[
             0.5473288439198032, 0.63006976495775, 0.9612157369734251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 138}], {
             RGBColor[
             0.29271744127035215`, 0.42291814902891156`, 0.9400572398270755]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 144}], {
             RGBColor[
             0.4697717745542883, 0.5693163242687465, 0.9535294303279567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 149}], {
             RGBColor[
             0.5627023416470627, 0.6423281747429878, 0.9626820749107345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 159}], {
             RGBColor[
             0.2512917882699816, 0.3814539806643284, 0.9376220676378648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 170}], {
             RGBColor[
             0.3792234391840347, 0.49646317208708807`, 0.9459512106142831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 192}], {
             RGBColor[
             0.5159930438800769, 0.6054247311607103, 0.9581363344920313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 197}], {
             RGBColor[
             0.6050699434314342, 0.675589671764802, 0.9486500781855967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 141}], {
             RGBColor[
             0.5750074826307826, 0.6431420529571624, 0.9420657396043517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 177}], {
             RGBColor[
             0.6267695021561912, 0.6975472173799585, 0.945013510041278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 198}], {
             RGBColor[
             0.9733564548049335, 0.9794774263186589, 0.9222624547930993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 95}], {
             RGBColor[
             0.5047201021031804, 0.6057566191969356, 0.9550938565558804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 136}], {
             RGBColor[
             0.7495818473865268, 0.8044635719472818, 0.9756311141561453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 97}], {
             RGBColor[
             0.8284391896509107, 0.8651977695816062, 0.9044030420519164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 155}], {
             RGBColor[
             0.45637421716162696`, 0.5575122663495081, 0.9524058778946478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 134}], {
             RGBColor[
             0.27681292538421653`, 0.4082783139049413, 0.9390754586413815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 139}], {
             RGBColor[
             0.32625785998220386`, 0.4535948783948345, 0.9421348806444768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 145}], {
             RGBColor[
             0.3801246650779149, 0.4992979625763071, 0.9458307180156694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 105}], {
             RGBColor[
             0.3818813841499935, 0.5051881938594358, 0.9455541220069568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 111}], {
             RGBColor[
             0.6872735101806371, 0.74988352241495, 0.9198343305707948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 115}], {
             RGBColor[
             0.30568170495235014`, 0.431176335787152, 0.9409920870363234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 116}], {
             RGBColor[
             0.3874786678377304, 0.5100362796620952, 0.9459107759740557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 126}], {
             RGBColor[
             0.4323990445502214, 0.5483409673897188, 0.9489396967884631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 142}], {
             RGBColor[
             0.28409796918493396`, 0.4084904610077098, 0.9397629252146447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 153}], {
             RGBColor[
             0.3218293024371526, 0.44814848456049267`, 0.9419116688248532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 160}], {
             RGBColor[
             0.6860121797151038, 0.7491232618972016, 0.9300498019271697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 167}], {
             RGBColor[
             0.5532125278287436, 0.645276999259827, 0.9592339640308587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 174}], {
             RGBColor[
             0.6891332386825868, 0.7430675894626, 0.6788913981884079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 188}], {
             RGBColor[
             0.3162725035701066, 0.44230793662983015`, 0.9415952173499221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 103}], {
             RGBColor[
             0.355241002714608, 0.4821136344446084, 0.9438566204590582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 129}], {
             RGBColor[
             0.32025886644064183`, 0.450063088232835, 0.9416916942290467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 131}], {
             RGBColor[
             0.4514806220250192, 0.5627852289975521, 0.9507311639297944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 143}], {
             RGBColor[
             0.35455453382688673`, 0.48151904959699376`, 0.9438128792685532]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 154}], {
             RGBColor[
             0.4038479820094638, 0.5241149060069452, 0.9469813480236603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 105}], {
             RGBColor[
             0.31635692978748764`, 0.44376273366432395`, 0.9415500071596867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 111}], {
             RGBColor[
             0.6217490558181313, 0.6884580622198384, 0.9158302157235247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 116}], {
             RGBColor[
             0.32195421347522446`, 0.44861081946698345`, 0.9419066611267857]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 126}], {
             RGBColor[
             0.3668745901877154, 0.4869155071946071, 0.9449355819411931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.31285023268221146`, 0.440725408883455, 0.941326563520989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 174}], {
             RGBColor[
             0.6236087843200808, 0.6816421292674881, 0.6748872833411379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 182}], {
             RGBColor[
             0.5223782617206405, 0.6109517777842504, 0.9586874429505468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 191}], {
             RGBColor[
             0.6218699314232927, 0.688508047388934, 0.9138269941299589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 102}], {
             RGBColor[
             0.8731582820861343, 0.9001326644696934, 0.9088602232621807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 112}], {
             RGBColor[
             0.6917357125919841, 0.7530325532407074, 0.8938054089278131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 140}], {
             RGBColor[
             0.6031515611515043, 0.6679025380250225, 0.8884685755683855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 155}], {
             RGBColor[
             0.6163764617031874, 0.6818027470119663, 0.8892217140903168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 99}], {
             RGBColor[
             0.29268747572323395`, 0.4183102760533596, 0.9402230969238614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 117}], {
             RGBColor[
             0.6108776997119714, 0.6901320575902333, 0.965090231555996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 120}], {
             RGBColor[
             0.5202642707910143, 0.6191738947185306, 0.9561039144925112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 121}], {
             RGBColor[
             0.491830866949386, 0.5963578952415367, 0.9536826288100863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 146}], {
             RGBColor[
             0.5004094024065477, 0.603322336784279, 0.9543579625454848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 156}], {
             RGBColor[
             0.48032962087877346`, 0.5870206655561825, 0.9527772085889551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.47894301147057594`, 0.5858949535725658, 0.9526680496170241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 178}], {
             RGBColor[
             0.4188470487711857, 0.5371063437609334, 0.9479370752945633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 179}], {
             RGBColor[
             0.2911482448736358, 0.41669244683755935`, 0.9401354400040649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 183}], {
             RGBColor[
             0.6038487713987873, 0.6845273809484766, 0.9644198060986862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 196}], {
             RGBColor[
             0.6179989497532402, 0.6958103490719583, 0.9657694627421471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 107}], {
             RGBColor[
             0.48284053099060636`, 0.5728390629140767, 0.9558906003316328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 109}], {
             RGBColor[
             0.23795407175645295`, 0.3674351949485398, 0.9368625044138028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 146}], {
             RGBColor[
             0.41239084469393883`, 0.5174624486919557, 0.9491018297705734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 147}], {
             RGBColor[
             0.4139927695393034, 0.5187629634473145, 0.9492279391624445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 156}], {
             RGBColor[
             0.3923110631661645, 0.5011607774638591, 0.9475210758140438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 178}], {
             RGBColor[
             0.33082849105857676`, 0.45124645566861, 0.9426809425196518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 179}], {
             RGBColor[
             0.2031296871610268, 0.330832558745236, 0.9348793072291535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 194}], {
             RGBColor[
             0.5320887532276326, 0.6116316109602099, 0.9607144273394083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 104}], {
             RGBColor[
             0.5671645490412309, 0.6455482619498001, 0.9631588822202437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 123}], {
             RGBColor[
             0.628733327243831, 0.21666399037454395`, 0.42202448491859423`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 130}], {
             RGBColor[
             0.30459351168747617`, 0.43295827013156535`, 0.9408229920336322]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 135}], {
             RGBColor[
             0.5600712947128679, 0.639892293489623, 0.9624823212901816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 148}], {
             RGBColor[
             0.48193570226319865`, 0.5784593865269574, 0.9547987295880559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 163}], {
             RGBColor[
             0.6225997844097091, 0.6852688690901764, 0.7432531287082875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 165}], {
             RGBColor[
             0.22738121972562364`, 0.35632245710660143`, 0.9362603961317799]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 123}], {
             RGBColor[
             0.7499289617223109, 0.3222328676589373, 0.4304273066954687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 124}], {
             RGBColor[
             0.5672678635951525, 0.6595726326494, 0.9590765506743143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 127}], {
             RGBColor[
             0.41088589677086407`, 0.5164743793503679, 0.9489620805479629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 135}], {
             RGBColor[
             0.7418647464305879, 0.798245609416213, 0.9750865539554934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 137}], {
             RGBColor[
             0.8028180298614014, 0.8443894097171354, 0.8850807931530624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 161}], {
             RGBColor[
             0.6163140976041817, 0.6993905749255926, 0.9629376498777801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 165}], {
             RGBColor[
             0.4091746714433435, 0.5146757730331915, 0.9488646287970917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 175}], {
             RGBColor[
             0.6787669600844518, 0.7485603508731871, 0.96890179022948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 176}], {
             RGBColor[
             0.5684761456425267, 0.6605535704479444, 0.9591716710631666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 187}], {
             RGBColor[
             0.6223091303224499, 0.7042576125594291, 0.9634096008138906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 199}], {
             RGBColor[
             0.47305687685594777`, 0.5797657350788272, 0.9525778433713585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 106}], {
             RGBColor[
             0.640279456477126, 0.7170771731034483, 0.9660341484038802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 112}], {
             RGBColor[
             0.5764525604856474, 0.6636769674663366, 0.9614467539424084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 140}], {
             RGBColor[
             0.48786840904516754`, 0.5785469522506517, 0.9561099205829808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 108}], {
             RGBColor[
             0.4400073596918533, 0.5537168865090245, 0.9497599295351815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 129}], {
             RGBColor[
             0.3247919692428507, 0.4539894340397367, 0.9419805395311381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 131}], {
             RGBColor[
             0.4560137248272281, 0.5667115748044538, 0.9510200092318857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 133}], {
             RGBColor[
             0.47226371839151743`, 0.5799040516338115, 0.9522992682509543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 143}], {
             RGBColor[
             0.3590876366290956, 0.48544539540389553`, 0.9441017245706446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 154}], {
             RGBColor[
             0.4083810848116727, 0.528041251813847, 0.9472701933257517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 162}], {
             RGBColor[
             0.5333272394715629, 0.6284897837763715, 0.9577821766388841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 123}], {
             RGBColor[
             0.8391350387836563, 0.3925375175919895, 0.43903876989490165`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 130}], {
             RGBColor[
             0.6201960789972141, 0.6967685609577337, 0.9663444194980935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 163}], {
             RGBColor[
             0.938202351719447, 0.9490791599163446, 0.7687745561727487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 111}], {
             RGBColor[
             0.6798859559607628, 0.7434847942589663, 0.919363602148462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 116}], {
             RGBColor[
             0.38009111361785597`, 0.5036375515061114, 0.945440047551723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 126}], {
             RGBColor[
             0.42501149033034696`, 0.5419422392337351, 0.9484689683661305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 142}], {
             RGBColor[
             0.27671041496505955`, 0.40209173285172595`, 0.939292196792312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 157}], {
             RGBColor[
             0.370987132824843, 0.495752140922583, 0.9448599499459263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 160}], {
             RGBColor[
             0.6786246254952295, 0.7427245337412178, 0.9295790735048369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 174}], {
             RGBColor[
             0.6817456844627123, 0.7366688613066161, 0.6784206697660752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 182}], {
             RGBColor[
             0.580515161863272, 0.6659785098233784, 0.9622208293754841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 112}], {
             RGBColor[
             0.4588568869829757, 0.5699770618744623, 0.9509793340695126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 140}], {
             RGBColor[
             0.3702727355424959, 0.4848470466587773, 0.945642500710085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 189}], {
             RGBColor[
             0.5175353564105406, 0.6191975428930152, 0.9551614255325652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 111}], {
             RGBColor[
             0.8731451129809971, 0.900703930340799, 0.9352290236133077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 142}], {
             RGBColor[
             0.4699695719852939, 0.5593108689335586, 0.9551576182571577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[
             0.6921643825192849, 0.7591516384003552, 0.9701515753451273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.670482676146146, 0.7415494524168997, 0.9684447119967263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.5642462898450773, 0.6529712770044157, 0.960725371410772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.48130130014100825`, 0.5712212336982765, 0.9558029434118361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 181}], {
             RGBColor[
             0.5999341556804705, 0.6838823126667415, 0.9629993706642626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 185}], {
             RGBColor[
             0.8309900496066289, 0.868549572763359, 0.9836152792302958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 110}], {
             RGBColor[
             0.6166188491050899, 0.6985559005624211, 0.9637014687030616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 131}], {
             RGBColor[
             0.5362469790022645, 0.6343884810619682, 0.9566344730059178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 154}], {
             RGBColor[
             0.48861433898670914`, 0.5957181580713613, 0.9528846570997836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 162}], {
             RGBColor[
             0.6135604936465994, 0.6961666900338859, 0.9633966404129161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 180}], {
             RGBColor[
             0.5912604661521936, 0.6787457390687699, 0.9611739820778791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 132}], {
             RGBColor[
             0.42898164453679266`, 0.5388940271089521, 0.9496831293427506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 146}], {
             RGBColor[
             0.4456759984397668, 0.5524472556794593, 0.9509973700354262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 150}], {
             RGBColor[
             0.3896666556004378, 0.5069763479703512, 0.946588109398131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 151}], {
             RGBColor[
             0.5988795613688869, 0.6733329172758662, 0.9658057668313474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 152}], {
             RGBColor[
             0.5840359096728558, 0.6614969923336427, 0.9643899660814957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 194}], {
             RGBColor[
             0.5653739069734607, 0.6466164179477135, 0.962609967604261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 196}], {
             RGBColor[
             0.5632655457864593, 0.6449352679671385, 0.9624088702320885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 127}], {
             RGBColor[
             0.45980999635904274`, 0.5551110820411136, 0.9535533925532148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 162}], {
             RGBColor[
             0.7099387288847996, 0.773328797829768, 0.9717237158067642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 180}], {
             RGBColor[
             0.6876387013903937, 0.7559078468646521, 0.9695010574717271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 116}], {
             RGBColor[
             0.6854832396484997, 0.7483328800616258, 0.919720256115561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 126}], {
             RGBColor[
             0.7304036163609906, 0.7866375677892494, 0.9227491769299685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 142}], {
             RGBColor[
             0.5821025409957032, 0.6467870614072403, 0.91357240535615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 157}], {
             RGBColor[
             0.6763792588554867, 0.7404474694780974, 0.9191401585097643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 160}], {
             RGBColor[
             0.9840167515258731, 0.9874198622967321, 0.9038592820686749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 167}], {
             RGBColor[
             0.8512170996395129, 0.8835735996593574, 0.933043444172364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 174}], {
             RGBColor[
             0.9871378104933559, 0.9813641898621305, 0.6527008783299132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 181}], {
             RGBColor[
             0.7120671246908798, 0.7713585051404233, 0.9214141577632549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.9431230186170383, 0.9560257652370406, 0.9420300663292881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 188}], {
             RGBColor[
             0.614277075380876, 0.6806045370293606, 0.9154046974914274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 140}], {
             RGBColor[
             0.30644583955101723`, 0.43144684102166564`, 0.9410551062486132]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 122}], {
             RGBColor[
             0.6168245424685272, 0.697730809642646, 0.9643959535598283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 136}], {
             RGBColor[
             0.6481603425082536, 0.7223758434396859, 0.9674753560412221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 138}], {
             RGBColor[
             0.3935489398588025, 0.5152242275108473, 0.9463168588948725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 144}], {
             RGBColor[
             0.5706032731427386, 0.6616224027506822, 0.9597890493957537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 159}], {
             RGBColor[
             0.35212328685843197`, 0.4737600591462641, 0.9438816867056619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 167}], {
             RGBColor[
             0.5865227059125172, 0.6740587846226034, 0.9613757496786877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 197}], {
             RGBColor[
             0.7059014420198846, 0.7678957502467378, 0.9549096972533937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 158}], {
             RGBColor[
             0.690809501101938, 0.7572541773685119, 0.9705901741864691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 160}], {
             RGBColor[
             0.6024249462975861, 0.668712675668934, 0.9250170385342036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 126}], {
             RGBColor[
             0.43060877401808384`, 0.5467903250363946, 0.9488256223332294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 142}], {
             RGBColor[
             0.2823076986527964, 0.40693981865438544`, 0.939648850759411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 153}], {
             RGBColor[
             0.32003903190501504`, 0.44659784220716836`, 0.9417975943696194]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 157}], {
             RGBColor[
             0.3765844165125799, 0.5006002267252425, 0.9452166039130252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 160}], {
             RGBColor[
             0.6842219091829662, 0.7475726195438772, 0.9299357274719359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 167}], {
             RGBColor[
             0.5514222572966061, 0.6437263569065026, 0.9591198895756249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 174}], {
             RGBColor[
             0.6873429681504493, 0.7415169471092756, 0.6787773237331741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 188}], {
             RGBColor[
             0.31448223303796907`, 0.4407572942765058, 0.9414811428946883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 120}], {
             RGBColor[
             0.750435937067143, 0.805135788163081, 0.9757149163497344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 121}], {
             RGBColor[
             0.7220025332255146, 0.7823197886860871, 0.9732936306673095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 146}], {
             RGBColor[
             0.7305810686826764, 0.7892842302288294, 0.9739689644027081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 151}], {
             RGBColor[
             0.8837846316117963, 0.9101698918252363, 0.9887773611986294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 171}], {
             RGBColor[
             0.7091146777467046, 0.7718568470171162, 0.9722790514742473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 173}], {
             RGBColor[
             0.8558154096755966, 0.887867993457615, 0.9861096318419355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 196}], {
             RGBColor[
             0.8481706160293687, 0.8817722425165087, 0.9853804645993705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 119}], {
             RGBColor[
             0.6844669532050759, 0.7473937879058581, 0.9174929706993523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 125}], {
             RGBColor[
             0.6365225210875476, 0.7039030383419195, 0.9145098942720136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 128}], {
             RGBColor[
             0.920726122199511, 0.9381171922663547, 0.9377271861455447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 138}], {
             RGBColor[
             0.6583733220825505, 0.7247927961315606, 0.9158303075979171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 144}], {
             RGBColor[
             0.8354276553664866, 0.8711909713713955, 0.9293024980987982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 149}], {
             RGBColor[
             0.928358222459261, 0.9442028218456366, 0.9384551426815761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 159}], {
             RGBColor[
             0.6169476690821799, 0.6833286277669773, 0.9133951354087063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 170}], {
             RGBColor[
             0.744879319996233, 0.798337819189737, 0.9217242783851247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 190}], {
             RGBColor[
             0.5835931269573364, 0.6482708891936511, 0.9114956435783197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 192}], {
             RGBColor[
             0.8816489246922752, 0.9072993782633592, 0.9339094022628729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.9030712658616308, 0.9240396890508379, 0.9360432501873615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 197}], {
             RGBColor[
             0.9707258242436325, 0.977464318867451, 0.9244231459564382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 125}], {
             RGBColor[
             0.3354514153077125, 0.4630091962653788, 0.9426675458403294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 128}], {
             RGBColor[
             0.6196550164196759, 0.697223350189814, 0.9658848377138607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 144}], {
             RGBColor[
             0.5343565495866516, 0.6302971292948547, 0.957460149667114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 149}], {
             RGBColor[
             0.6272871166794259, 0.703308979769096, 0.9666127942498919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 183}], {
             RGBColor[
             0.6051936783934864, 0.685692271790294, 0.9645055023831338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 190}], {
             RGBColor[
             0.2825220211775014, 0.4073770471171104, 0.9396532951466354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 192}], {
             RGBColor[
             0.5805778189124402, 0.6664055361868185, 0.9620670538311886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 195}], {
             RGBColor[
             0.6020001600817957, 0.6831458469742973, 0.9642009017556773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 128}], {
             RGBColor[
             0.7578683467801485, 0.8110621899208443, 0.9764238262231513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 168}], {
             RGBColor[
             0.5103483312788137, 0.6105852063026737, 0.9554720795951148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 171}], {
             RGBColor[
             0.6185012488257475, 0.7008986841454135, 0.9632927344107625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 172}], {
             RGBColor[
             0.4999651344516954, 0.6015918030856704, 0.9548104714747913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 173}], {
             RGBColor[
             0.7652019807546395, 0.8169098305859124, 0.9771233147784506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 183}], {
             RGBColor[
             0.7434070087539588, 0.7995311115213244, 0.9750444908924245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 151}], {
             RGBColor[
             0.7647377988492109, 0.8163957294765397, 0.9773697584527196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 171}], {
             RGBColor[
             0.590067844984119, 0.6780826846684196, 0.9608714487283375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 196}], {
             RGBColor[
             0.7291237832667834, 0.787998080167812, 0.9739728618534607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 136}], {
             RGBColor[
             0.8090955904393657, 0.8509561603413593, 0.9815628878761029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 138}], {
             RGBColor[
             0.5544841877899147, 0.6438045444125209, 0.9604043907297534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 142}], {
             RGBColor[
             0.4783433951998197, 0.5658525632721598, 0.9559922426973546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 144}], {
             RGBColor[
             0.7315385210738509, 0.7902027196523558, 0.9738765812306345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 153}], {
             RGBColor[
             0.5160747284520384, 0.6055105868249426, 0.9581409863075631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.5130585347895442, 0.6023403760479378, 0.9579692185405426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 167}], {
             RGBColor[
             0.7474579538436295, 0.802639101524277, 0.9754632815135685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 181}], {
             RGBColor[
             0.6083079788949963, 0.6904240070053427, 0.9638339951044594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 188}], {
             RGBColor[
             0.5105179295849924, 0.5996700388942802, 0.957824534832632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 192}], {
             RGBColor[
             0.7777597903996395, 0.8263111265443196, 0.9784834853947092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 127}], {
             RGBColor[
             0.6137536361249318, 0.20091938524130798`, 0.4211714136698399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 130}], {
             RGBColor[
             0.6640876805478197, 0.2508108563798329, 0.42414817643716063`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 135}], {
             RGBColor[
             0.8344062025647476, 0.3887668719518714, 0.4385877292748602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 163}], {
             RGBColor[
             0.8760918623626417, 0.4190179223522403, 0.2924349342202641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 165}], {
             RGBColor[
             0.6126128192399181, 0.19972031436319032`, 0.4211064458359257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 177}], {
             RGBColor[
             0.6422313494595313, 0.23085126754728344`, 0.4227931773152439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 187}], {
             RGBColor[
             0.7547024584926557, 0.3261082073806821, 0.430803093847125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 127}], {
             RGBColor[
             0.36300487519908375`, 0.47760240902295603`, 0.9451927111358712]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 135}], {
             RGBColor[
             0.6939837248588074, 0.7593736390888011, 0.9713171845434017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.754937008289621, 0.8055174393897235, 0.8813114237409707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 161}], {
             RGBColor[
             0.5684330760324012, 0.6605186045981808, 0.9591682804656884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 175}], {
             RGBColor[
             0.6308859385126715, 0.7096883805457751, 0.9651324208173883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 176}], {
             RGBColor[
             0.5205951240707464, 0.6216816001205325, 0.9554023016510749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 187}], {
             RGBColor[
             0.5744281087506695, 0.6653856422320172, 0.9596402314017989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 199}], {
             RGBColor[
             0.4251758552841674, 0.5408937647514154, 0.9488084739592668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 128}], {
             RGBColor[
             0.5717105843021476, 0.6537326006258753, 0.9629017612865218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.5793426845618976, 0.6598182302051574, 0.9636297178225532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[
             0.39586378209886963`, 0.5139532275492577, 0.9468988535261018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 190}], {
             RGBColor[
             0.23457758905997306`, 0.36388629755317176`, 0.9366702187192968]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 195}], {
             RGBColor[
             0.5540557279642674, 0.6396550974103585, 0.9612178253283385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 142}], {
             RGBColor[
             0.3272280753652874, 0.4452445063820091, 0.9426777715738184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 157}], {
             RGBColor[
             0.42150479322507084`, 0.5389049144528661, 0.9482455247274327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 160}], {
             RGBColor[
             0.7291422858954573, 0.7858773072715008, 0.9329646482863434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 174}], {
             RGBColor[
             0.7322633448629401, 0.7798216348368993, 0.6818062445475817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 182}], {
             RGBColor[
             0.6310328222634998, 0.7091312833536614, 0.9656064041569905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 191}], {
             RGBColor[
             0.7305244919661522, 0.786687552958345, 0.9207459553364027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 135}], {
             RGBColor[
             0.5376017580345192, 0.6162753857897691, 0.9612027144170503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 161}], {
             RGBColor[
             0.41205110920811294`, 0.5174203512991487, 0.949053810339337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 175}], {
             RGBColor[
             0.47450397168838315`, 0.5665901272467431, 0.9550179506910369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 176}], {
             RGBColor[
             0.3642131572464581, 0.4785833468215004, 0.9452878315247235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 177}], {
             RGBColor[
             0.24933947837669465`, 0.37940197918288715`, 0.9375108864776258]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 180}], {
             RGBColor[
             0.43445161340614646`, 0.5353009205474625, 0.9510259059280322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 187}], {
             RGBColor[
             0.41804614192638123`, 0.5222873889329851, 0.9495257612754475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 183}], {
             RGBColor[
             0.8414528473879215, 0.8764156761507905, 0.9847397178293262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 190}], {
             RGBColor[
             0.5187811901719365, 0.5981004514776069, 0.959887510592828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 192}], {
             RGBColor[
             0.8168369879068753, 0.857128940547315, 0.9823012692773812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 195}], {
             RGBColor[
             0.8382593290762308, 0.8738692513347938, 0.9844351172018697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 131}], {
             RGBColor[
             0.42103158855326195`, 0.5346610285926804, 0.9488550830018743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 133}], {
             RGBColor[
             0.4372815821175513, 0.5478535054220381, 0.9501343420209429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 143}], {
             RGBColor[
             0.32410550035512947`, 0.45339484919212203`, 0.9419367983406332]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 170}], {
             RGBColor[
             0.3970152069882198, 0.5151634481125192, 0.9469644254701698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 197}], {
             RGBColor[
             0.6228617112356194, 0.6942899477902331, 0.9496632930414832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 163}], {
             RGBColor[
             0.6756313143656922, 0.7364891680981098, 0.7464386659861371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 177}], {
             RGBColor[
             0.32484054501102666`, 0.4542391858906746, 0.9419760306286068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 133}], {
             RGBColor[
             0.5685033377019286, 0.6605756461867552, 0.9591738117216906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 143}], {
             RGBColor[
             0.45532725593950685`, 0.5661169899568392, 0.9509762680413807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 154}], {
             RGBColor[
             0.5046207041220839, 0.6087128463667906, 0.9541447367964878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 162}], {
             RGBColor[
             0.6295668587819742, 0.7091613783293151, 0.9646567201096202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 180}], {
             RGBColor[
             0.6072668312875684, 0.6917404273641992, 0.9624340617745832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 150}], {
             RGBColor[
             0.5474090746349495, 0.6434503731432597, 0.9575131940622262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 151}], {
             RGBColor[
             0.7566219804033985, 0.8098069424487748, 0.9767308514954427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 162}], {
             RGBColor[
             0.6458168523462635, 0.722353855158673, 0.9659359791286888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 139}], {
             RGBColor[
             0.33126109883785554`, 0.45885359965578976`, 0.9424198076956776]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 145}], {
             RGBColor[
             0.3851279039335666, 0.5045566838372625, 0.9461156450668702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 191}], {
             RGBColor[
             0.6336679987207989, 0.7009085641592843, 0.9144988766088754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 148}], {
             RGBColor[
             0.7904450152445736, 0.8366137088929486, 0.979643596122455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 163}], {
             RGBColor[
             0.931109097391084, 0.9434231914561675, 0.7680979952426865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 165}], {
             RGBColor[
             0.5358905327069985, 0.6144767794725926, 0.961105262666179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 176}], {
             RGBColor[
             0.6951920069061818, 0.7603545768873455, 0.971412304932254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 187}], {
             RGBColor[
             0.7490249915861049, 0.8040586189988302, 0.975650234682978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 143}], {
             RGBColor[
             0.5994162791102332, 0.6802260023473401, 0.9643501368688181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 159}], {
             RGBColor[
             0.5443943348292705, 0.6269854098449775, 0.9610486210219364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 197}], {
             RGBColor[
             0.8981724899907231, 0.9211211009454512, 0.9720766315696683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 161}], {
             RGBColor[
             0.8039832422986501, 0.8453353816659162, 0.8851725229444365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 175}], {
             RGBColor[
             0.8664361047789204, 0.8945051576135106, 0.8911366632961364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 176}], {
             RGBColor[
             0.7561452903369953, 0.8064983771882679, 0.881406544129823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 186}], {
             RGBColor[
             0.675015275935992, 0.7380871757691284, 0.8757232150919723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 187}], {
             RGBColor[
             0.8099782750169184, 0.8502024192997526, 0.885644473880547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 199}], {
             RGBColor[
             0.6607260215504163, 0.7257105418191507, 0.874812716438015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 142}], {
             RGBColor[
             0.255067792590095, 0.3833459811403611, 0.9379131480323988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 144}], {
             RGBColor[
             0.5082629184641261, 0.6076961375205571, 0.9557974865656786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 156}], {
             RGBColor[
             0.45558089675094704`, 0.5655845646237021, 0.9512002417719674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 159}], {
             RGBColor[
             0.28978293217981943`, 0.419833793916139, 0.9398901238755868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 167}], {
             RGBColor[
             0.5241823512339047, 0.6201325193924783, 0.9573841868486127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 181}], {
             RGBColor[
             0.38503237628527165`, 0.507917424873544, 0.9457549004395036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 185}], {
             RGBColor[
             0.6160882702114301, 0.6925846849701613, 0.9663708090055368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 192}], {
             RGBColor[
             0.5544841877899147, 0.6438045444125209, 0.9604043907297534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 145}], {
             RGBColor[
             0.43457283853155393`, 0.5498732483271556, 0.9491750670699655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 152}], {
             RGBColor[
             0.6387693136396366, 0.7123720734384624, 0.9677505585915545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 182}], {
             RGBColor[
             0.5836212636161339, 0.6686688590444938, 0.9624187474325585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 191}], {
             RGBColor[
             0.6831129333187862, 0.7462251286491774, 0.9175582986119707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 198}], {
             RGBColor[
             0.5868809815019275, 0.6518248471577548, 0.9142447062606267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 153}], {
             RGBColor[
             0.2166583332522186, 0.34505202355278286`, 0.9356497436102085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 157}], {
             RGBColor[
             0.2732037178597835, 0.399054408070857, 0.9390687531536144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 160}], {
             RGBColor[
             0.5808412105301699, 0.6460268008894918, 0.9237878767125249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 167}], {
             RGBColor[
             0.4480415586438096, 0.5421805382521172, 0.952972038816214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 174}], {
             RGBColor[
             0.5839622694976527, 0.6399711284548901, 0.6726294729737632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 181}], {
             RGBColor[
             0.30889158369517666`, 0.4299654437331829, 0.941342752407105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 185}], {
             RGBColor[
             0.5399474776213351, 0.6146327038298003, 0.9619586609731381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.21110153438517268`, 0.33921147562212034`, 0.9353332921352775]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 154}], {
             RGBColor[
             0.40769461592395145`, 0.5274466669662323, 0.9472264521352467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 159}], {
             RGBColor[
             0.3033792234604116, 0.43161021805391836`, 0.9407564675332578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 197}], {
             RGBColor[
             0.6571573786218643, 0.7257459091543921, 0.9517844780809896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 149}], {
             RGBColor[
             0.7782478188408366, 0.8271061632346333, 0.9784223216493377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 159}], {
             RGBColor[
             0.46683726546375554`, 0.5662319691559738, 0.953362314376468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 170}], {
             RGBColor[
             0.5947689163778087, 0.6812411605787336, 0.9616914573528863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 181}], {
             RGBColor[
             0.5620867095692077, 0.6543156001133789, 0.9592270909403848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 190}], {
             RGBColor[
             0.4334827233389121, 0.5311742305826477, 0.9514628225460813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 192}], {
             RGBColor[
             0.7315385210738509, 0.7902027196523558, 0.9738765812306345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 197}], {
             RGBColor[
             0.8206154206252081, 0.8603676602564476, 0.9643903249241998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 147}], {
             RGBColor[
             0.6217146962226172, 0.7037750241782339, 0.9633628047840679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 156}], {
             RGBColor[
             0.6000329898494783, 0.6861728381947786, 0.9616559414356671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 171}], {
             RGBColor[
             0.5986463804412808, 0.6850471262111619, 0.961546782463736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 178}], {
             RGBColor[
             0.5385504177418906, 0.6362585163995294, 0.9568158081412752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 179}], {
             RGBColor[
             0.41085161384434066`, 0.5158446194761553, 0.9490141728507768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 183}], {
             RGBColor[
             0.7235521403694922, 0.7836795535870728, 0.9732985389453981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 194}], {
             RGBColor[
             0.7398106799109465, 0.7966436716911294, 0.9748492929610316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 196}], {
             RGBColor[
             0.7377023187239451, 0.7949625217105543, 0.9746481955888592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 152}], {
             RGBColor[
             0.7600746074557062, 0.8128247608324173, 0.9767554008301376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 156}], {
             RGBColor[
             0.601634914694843, 0.6874733529501376, 0.9617820508275382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 178}], {
             RGBColor[
             0.5401523425872552, 0.6375590311548883, 0.9569419175331464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 179}], {
             RGBColor[
             0.41245353868970525`, 0.5171451342315143, 0.949140282242648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 185}], {
             RGBColor[
             0.762142288155326, 0.8144734732965968, 0.9769526180611077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 194}], {
             RGBColor[
             0.7414126047563112, 0.7979441864464882, 0.9749754023529027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 165}], {
             RGBColor[
             0.45775494025732927`, 0.5530438725099269, 0.9534216709640533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 159}], {
             RGBColor[
             0.55976783255653, 0.6392438196302153, 0.9625149589592459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 170}], {
             RGBColor[
             0.6876994834705831, 0.7542530110529748, 0.9708441019356643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 190}], {
             RGBColor[
             0.5264132904316865, 0.604186081056889, 0.9606154671288593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 192}], {
             RGBColor[
             0.8244690881666252, 0.8632145701265971, 0.9830292258134125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 195}], {
             RGBColor[
             0.8458914293359808, 0.8799548809140758, 0.9851630737379011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.9135459877179826, 0.9333795107306888, 0.9735429695069777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 151}], {
             RGBColor[
             0.7173069914670436, 0.7778892633101738, 0.9736358315508231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 152}], {
             RGBColor[
             0.7024633397710125, 0.7660533383679503, 0.9722200308009714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 194}], {
             RGBColor[
             0.6838013370716175, 0.7511727639820212, 0.9704400323237365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 171}], {
             RGBColor[
             0.7518499433704009, 0.8059327878075688, 0.9763551792596574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 196}], {
             RGBColor[
             0.8909058816530651, 0.9158481833069612, 0.9894565923847805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 194}], {
             RGBColor[
             0.8781705911440354, 0.9056934083453128, 0.9882418890071012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 160}], {
             RGBColor[
             0.6185725437823885, 0.6856848244422746, 0.9259366203227334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 167}], {
             RGBColor[
             0.48577289189602824`, 0.5818385618049, 0.9551207824264224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 174}], {
             RGBColor[
             0.6216936027498714, 0.679629152007673, 0.6747782165839716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 188}], {
             RGBColor[
             0.24883286763739126`, 0.3788694991749032, 0.9374820357454858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 157}], {
             RGBColor[
             0.4737168220206355, 0.5812929915541981, 0.952355846893183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 178}], {
             RGBColor[
             0.5184706362141163, 0.619956845171433, 0.9552350541847455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.3907718323165663, 0.4995429482480589, 0.947433418894247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 181}], {
             RGBColor[
             0.5094046878560287, 0.6122040272165239, 0.9546298461466736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 183}], {
             RGBColor[
             0.703472358841718, 0.7673778823589763, 0.9717177849888684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 185}], {
             RGBColor[
             0.7404605817821871, 0.7968712873131414, 0.9752457547127067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 192}], {
             RGBColor[
             0.6788564993606718, 0.7480911467555009, 0.9692793364369232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 174}], {
             RGBColor[
             0.6782389873574362, 0.7336315365257472, 0.6781972261273775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 181}], {
             RGBColor[
             0.4031683015549601, 0.52362585180404, 0.9469105055607192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 185}], {
             RGBColor[
             0.6342241954811185, 0.7082931119006574, 0.9675264141267523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 164}], {
             RGBColor[
             0.4364511466543483, 0.5489192208869391, 0.9499105905444482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 166}], {
             RGBColor[
             0.41576616062132676`, 0.5271779890623701, 0.9487326111905621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 170}], {
             RGBColor[
             0.37628893009350195`, 0.4933788169743155, 0.9457840946627945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 197}], {
             RGBColor[
             0.6021354343409014, 0.6725053166520295, 0.948482962234108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 167}], {
             RGBColor[
             0.8499557691739795, 0.882813339141609, 0.9432589155287389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 174}], {
             RGBColor[
             0.9858764800278226, 0.980603929344382, 0.6629163496862881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 188}], {
             RGBColor[
             0.6130157449153426, 0.6798442765116122, 0.9256201688478023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 175}], {
             RGBColor[
             0.6799321725217007, 0.7495063228219678, 0.968993520020854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 176}], {
             RGBColor[
             0.5696413580797757, 0.6614995423967251, 0.9592634008545406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 187}], {
             RGBColor[
             0.6234743427596987, 0.7052035845082099, 0.9635013306052647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 193}], {
             RGBColor[
             0.6166081506395101, 0.6996293004266106, 0.962960798809873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 199}], {
             RGBColor[
             0.47422208929319665`, 0.580711707027608, 0.9526695731627326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 180}], {
             RGBColor[
             0.6845803459319033, 0.7535186363361169, 0.9691962291815814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 177}], {
             RGBColor[
             0.6428468177332596, 0.7065497848492857, 0.744406167303262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 166}], {
             RGBColor[
             0.2836713928363063, 0.41548699804904, 0.9394660382165847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 184}], {
             RGBColor[
             0.6492605227616084, 0.7135776834130036, 0.7734410891141885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 187}], {
             RGBColor[
             0.41633491659886057`, 0.5204887826158087, 0.9494283095245762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 184}], {
             RGBColor[
             0.6285755367285868, 0.6918364515884348, 0.7722631097603025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 181}], {
             RGBColor[
             0.5780061423389863, 0.6667519819853001, 0.9608137912233188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 188}], {
             RGBColor[
             0.4802160930289823, 0.5759980138742375, 0.9548043309514913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 172}], {
             RGBColor[
             0.35049095758432325`, 0.4779993840969658, 0.9435539517836564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 173}], {
             RGBColor[
             0.6157278038872673, 0.6933174115972077, 0.9658667950873159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 184}], {
             RGBColor[
             0.6775194105326652, 0.7384599621331838, 0.7752268602809431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 198}], {
             RGBColor[
             0.67305205404376, 0.73757650391661, 0.9193284906766772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 200}], {
             RGBColor[
             0.45678364917748915`, 0.5694838974665077, 0.950487325224683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 190}], {
             RGBColor[
             0.3429343879686585, 0.4583210784009893, 0.9438846028324078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 195}], {
             RGBColor[
             0.6624125268729528, 0.7340898782581761, 0.9684322094414497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 197}], {
             RGBColor[
             0.7300670852549546, 0.7875145080747892, 0.9568121052105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 173}], {
             RGBColor[
             0.723880721434201, 0.7836308894399475, 0.9736874499029635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 178}], {
             RGBColor[
             0.5170840268059188, 0.6188311331878162, 0.9551258952128145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 183}], {
             RGBColor[
             0.7020857494335204, 0.7662521703753595, 0.9716086260169374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 196}], {
             RGBColor[
             0.7162359277879733, 0.7775351384988411, 0.9729582826603984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 173}], {
             RGBColor[
             0.6053446070601489, 0.6843240083802045, 0.9652051869669923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 198}], {
             RGBColor[
             0.6626688572166416, 0.7285831006996069, 0.9186668825563536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 188}], {
             RGBColor[
             0.6161368038828254, 0.6737886040770105, 0.6744617651090405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 176}], {
             RGBColor[
             0.6320942205600457, 0.7106693183443196, 0.9652275412062405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 187}], {
             RGBColor[
             0.685927205239969, 0.7543733604558043, 0.9694654709569646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 199}], {
             RGBColor[
             0.5366749517734668, 0.6298814829752024, 0.9586337135144325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 187}], {
             RGBColor[
             0.5756363907980439, 0.6663665800305616, 0.9597353517906512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 199}], {
             RGBColor[
             0.42638413733154173`, 0.5418747025499597, 0.9489035943481191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 179}], {
             RGBColor[
             0.3292892602089786, 0.44962862645280977`, 0.9425932855998553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 183}], {
             RGBColor[
             0.6419897867341302, 0.7174635605637272, 0.9668776516944766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 183}], {
             RGBColor[
             0.5142909828365803, 0.5970496636403531, 0.9590760164039782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 185}], {
             RGBColor[
             0.5512792057770495, 0.6265430685945181, 0.9626039861278165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 194}], {
             RGBColor[
             0.5305495223780345, 0.6100137817444096, 0.9606267704196116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 185}], {
             RGBColor[
             0.6699120613165117, 0.7392041475629831, 0.9698004133802429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 188}], {
             RGBColor[
             0.3410661180803493, 0.46378291935530325`, 0.9431750445423823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 192}], {
             RGBColor[
             0.6083079788949963, 0.6904240070053427, 0.9638339951044594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 191}], {
             RGBColor[
             0.8860281634990772, 0.9107238235479883, 0.9344978163457565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 192}], {
             RGBColor[
             0.8023756498806857, 0.8455978621477951, 0.9809219339466544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 193}], {
             RGBColor[
             0.4876401842768519, 0.5923810945298229, 0.9535114909574087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 199}], {
             RGBColor[
             0.3452541229305384, 0.47346350113082025`, 0.9432202653102684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 199}], {
             RGBColor[
             0.4802171220114649, 0.5855787446614444, 0.9531415240988431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 192}], {
             RGBColor[
             0.47970399266470076`, 0.5672826374746115, 0.956069726710156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 195}], {
             RGBColor[
             0.5011263338340562, 0.5840229482620902, 0.9582035746346447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 199}], {
             RGBColor[
             0.47335092989127625`, 0.5800044605798452, 0.9526009923034513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 197}], {
             RGBColor[
             0.8882590311203523, 0.9132163779358901, 0.9711310770127631]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.04749427504982855], {
             RGBColor[
             0.5177571149520601, 0.6193775764671292, 0.955178883177282]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.04749427504982855], {
             RGBColor[
             0.3366256592121667, 0.46598995953716293`, 0.9426704672319847]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.04749427504982855], {
             RGBColor[
             0.9554719738738346, 0.9663116515398327, 0.9602585128491206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.04749427504982855], {
             RGBColor[
             0.9880433604003623, 0.9893236365009974, 0.8478159911647796]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.04749427504982855], {
             RGBColor[
             0.26549579527488365`, 0.39638329261253996`, 0.9384309648238487]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.04749427504982855], {
             RGBColor[
             0.8256611496062827, 0.863823804993929, 0.9832334915974985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.04749427504982855], {
             RGBColor[
             0.5417933803643927, 0.6388912995502779, 0.9570711060382822]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.04749427504982855], {
             RGBColor[
             0.8242266622633934, 0.8626799837248306, 0.9830966689141518]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.04749427504982855], {
             RGBColor[
             0.9018555886313654, 0.9245791824295798, 0.9905009852112896]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.04749427504982855], {
             RGBColor[
             0.3674804357195669, 0.4927148161417141, 0.9446365063072286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.04749427504982855], {
             RGBColor[
             0.20466891801062498`, 0.3324503879610362, 0.9349669641489501]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.04749427504982855], {
             RGBColor[
             0.9927071993989595, 0.986809761866648, 0.44760184440411643`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.04749427504982855], {
             RGBColor[
             0.4007512828283618, 0.5215323516659539, 0.946756495264746]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.04749427504982855], {
             RGBColor[
             0.6585594344625604, 0.7331909025300144, 0.9666027079055604]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.04749427504982855], {
             RGBColor[
             0.5179937567463754, 0.6195696929363457, 0.9551975124861779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.04749427504982855], {
             RGBColor[
             0.8436429022950694, 0.8781619664862936, 0.9849486072214552]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.04749427504982855], {
             RGBColor[
             0.9329523288356614, 0.949374878969959, 0.9934670200523631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.04749427504982855], {
             RGBColor[
             0.42012950539174576`, 0.5383167940725714, 0.9479912584709955]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.04749427504982855], {
             RGBColor[
             0.36776425873505697`, 0.49296064937237205`, 0.9446545912588008]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.04749427504982855], {
             RGBColor[
             0.6365499338362692, 0.715818938392835, 0.9645306890322806]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.04749427504982855], {
             RGBColor[
             0.4100842573117488, 0.5296161050745268, 0.9473511841460022]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.04749427504982855], {
             RGBColor[
             0.9634072270132843, 0.9722297503384497, 0.9468261991295144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.04749427504982855], {
             RGBColor[
             0.3474764410037569, 0.475388361348888, 0.9433618694527751]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.04749427504982855], {
             RGBColor[
             0.7424024062367602, 0.7986896693102059, 0.9749593917748943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.04749427504982855], {
             RGBColor[
             0.4359006446939131, 0.5519769622555992, 0.9489961815214587]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.04749427504982855], {
             RGBColor[
             0.3468717975063612, 0.4748646495417097, 0.9433233421037863]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.04749427504982855], {
             RGBColor[
             0.21867676116170398`, 0.347173519261373, 0.9357646900936571]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.04749427504982855], {
             RGBColor[
             0.6558056288627253, 0.7310396086657255, 0.9663282342991453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.04749427504982855], {
             RGBColor[
             0.22697945018725205`, 0.3559001718481129, 0.9362375159509344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.04749427504982855], {
             RGBColor[
             0.7972180873091279, 0.8415120959785458, 0.9804229065825238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.04749427504982855], {
             RGBColor[
             0.992079786127685, 0.990992802270655, 0.7809219709281126]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.04749427504982855], {
             RGBColor[
             0.2624301989144882, 0.3931611564677288, 0.9382563836462676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.04749427504982855], {
             RGBColor[
             0.32601707615543773`, 0.45680133809631235`, 0.9419944977004115]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.04749427504982855], {
             RGBColor[
             0.8524324713037221, 0.8851705302272983, 0.9857869641600413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.04749427504982855], {
             RGBColor[
             0.504674675083755, 0.6087566624248393, 0.9541489855882926]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.04749427504982855], {
             RGBColor[
             0.9624950650567319, 0.971549461444781, 0.9483702513920174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.04749427504982855], {
             RGBColor[
             0.297791439367026, 0.43032806221548436`, 0.9402701539777724]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.04749427504982855], {
             RGBColor[
             0.2629864068032848, 0.393745766224471, 0.9382880588626987]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.04749427504982855], {
             RGBColor[
             0.5541451385708962, 0.6489190133026834, 0.9580434816902792]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.04749427504982855], {
             RGBColor[
             0.985538058984911, 0.9882876299823988, 0.8893353191310365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.04749427504982855], {
             RGBColor[
             0.9067241811899035, 0.9284612659813336, 0.9909653559157668]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.04749427504982855], {
             RGBColor[
             0.8493829852007985, 0.8827389527849221, 0.9854961014532361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.04749427504982855], {
             RGBColor[
             0.877222035708255, 0.9049370559886727, 0.9881514149428511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.04749427504982855], {
             RGBColor[
             0.3719391535718863, 0.49657673344371783`, 0.944920611866089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.04749427504982855], {
             RGBColor[
             0.9377074762543824, 0.9530629183019405, 0.9903291735958335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.04749427504982855], {
             RGBColor[
             0.3049891154369242, 0.4378932761239682, 0.9406800509819455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.04749427504982855], {
             RGBColor[
             0.3009726105781192, 0.43367167485624764`, 0.940451316972123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.04749427504982855], {
             RGBColor[
             0.2678473000268679, 0.39885487320088797`, 0.9385648795407346]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.04749427504982855], {
             RGBColor[
             0.4423613139196147, 0.557572869216225, 0.949407849651575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.04749427504982855], {
             RGBColor[
             0.4544694650138972, 0.5679978111711894, 0.9501966475438494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.04749427504982855], {
             RGBColor[
             0.8875903390471359, 0.9132044596309997, 0.9891403529712072]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.04749427504982855], {
             RGBColor[
             0.28560131656141624`, 0.4175154702483621, 0.9395759445176635]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.04749427504982855], {
             RGBColor[
             0.48945223651027836`, 0.5963984010278481, 0.9529506194621588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.04749427504982855], {
             RGBColor[
             0.6291222980522193, 0.7097888490521644, 0.9639459583350338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.04749427504982855], {
             RGBColor[
             0.7053471970855971, 0.769741858291297, 0.9712660748273239]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.04749427504982855], {
             RGBColor[
             0.4277044035792992, 0.5448777901571772, 0.948473924285287]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.04749427504982855], {
             RGBColor[
             0.32871997030298983`, 0.45914244915551206`, 0.9421667237254181]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.04749427504982855], {
             RGBColor[
             0.22356825481583897`, 0.3523147892304793, 0.9360432534209437]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.04749427504982855], {
             RGBColor[
             0.46797091230575444`, 0.5789588943159883, 0.9512595309320954]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.04749427504982855], {
             RGBColor[
             0.5916719178921753, 0.6793849433178407, 0.9609977272235724]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.04749427504982855], {
             RGBColor[
             0.4833674161279051, 0.5914584697234032, 0.9524716001122269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.04749427504982855], {
             RGBColor[
             0.26863100100690185`, 0.39967859262041566`, 0.9386095101521659]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.04749427504982855], {
             RGBColor[
             0.577179989505309, 0.6676197429994487, 0.9598568695352754]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.04749427504982855], {
             RGBColor[
             0.897170321695696, 0.92084327775326, 0.9900541002683783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.04749427504982855], {
             RGBColor[
             0.23743728043579151`, 0.36689201450406245`, 0.9368330739126153]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.04749427504982855], {
             RGBColor[
             0.9706724655543365, 0.9776481533466301, 0.9345280453572006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.04749427504982855], {
             RGBColor[
             0.2875069831901842, 0.4195184467014401, 0.9396844694129907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.04749427504982855], {
             RGBColor[
             0.6379754252693837, 0.7169762165558945, 0.9646429089396426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.04749427504982855], {
             RGBColor[
             0.5324901677142425, 0.6313385324159321, 0.9563387230596715]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.04749427504982855], {
             RGBColor[
             0.27811424642676386`, 0.4096460848291781, 0.9391495669496227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.04749427504982855], {
             RGBColor[
             0.21135092931161056`, 0.33947360550235817`, 0.9353474948073913]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.04749427504982855], {
             RGBColor[
             0.33566033969521886`, 0.4651538482899524, 0.9426089579259632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.04749427504982855], {
             RGBColor[
             0.8711783859336111, 0.9001180137088746, 0.9875749662321157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.04749427504982855], {
             RGBColor[
             0.5237476072332776, 0.6242409279696235, 0.9556504766735556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.04749427504982855], {
             RGBColor[
             0.3525377761845628, 0.4797722354923992, 0.9436843732549332]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.04749427504982855], {
             RGBColor[
             0.32871997030298983`, 0.45914244915551206`, 0.9421667237254181]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.04749427504982855], {
             RGBColor[
             0.27424994521707097`, 0.4055844592469431, 0.938929500712452]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.04749427504982855], {
             RGBColor[
             0.43266609265839195`, 0.5491753558557432, 0.9487900787259573]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.04749427504982855], {
             RGBColor[
             0.2682271237207058, 0.39925409198532463`, 0.9385865099381999]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.04749427504982855], {
             RGBColor[
             0.41994020788819086`, 0.5381528340893613, 0.9479791966014582]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.04749427504982855], {
             RGBColor[
             0.3350431069178822, 0.4646192322812448, 0.9425696283991889]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.04749427504982855], {
             RGBColor[
             0.7567062314725216, 0.8098639262974808, 0.9763850633975483]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.04749427504982855], {
             RGBColor[
             0.4215363206374963, 0.5395353067298503, 0.9480808994944568]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.04749427504982855], {
             RGBColor[
             0.44131182901301264`, 0.5566638581387714, 0.9493409774013493]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.04749427504982855], {
             RGBColor[
             0.3597741055168169, 0.48603998025151013`, 0.9441454657611495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.04749427504982855], {
             RGBColor[
             0.7107807613920374, 0.7739866000241064, 0.9718076417378445]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.04749427504982855], {
             RGBColor[
             0.7656779328018458, 0.8168726875634045, 0.9772792787407396]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.04749427504982855], {
             RGBColor[
             0.9522648338892142, 0.9639197717905125, 0.9656873642870096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.04749427504982855], {
             RGBColor[
             0.2542262973605144, 0.38453833577710095`, 0.9377891835893535]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.04749427504982855], {
             RGBColor[
             0.9614829559337886, 0.9707946321180666, 0.9500834881368243]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.04749427504982855], {
             RGBColor[
             0.6587323042939616, 0.7333259497561644, 0.9666199379547941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.04749427504982855], {
             RGBColor[
             0.6684369451093503, 0.740907288919148, 0.9675872058562474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.04749427504982855], {
             RGBColor[
             0.27180968652856485`, 0.40301959264398596`, 0.9387905315901808]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.04749427504982855], {
             RGBColor[
             0.3892689383698679, 0.5115869220154196, 0.9460248504292894]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.04749427504982855], {
             RGBColor[
             0.35070789991239915`, 0.4781872886377067, 0.9435677751569669]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.04749427504982855], {
             RGBColor[
             0.2582200296448561, 0.388736001625196, 0.9380166207347493]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.04749427504982855], {
             RGBColor[
             0.9884414341924711, 0.9894882502440643, 0.8412188782475853]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.04749427504982855], {
             RGBColor[
             0.38070603343584286`, 0.5041701641456829, 0.9454792296987728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.04749427504982855], {
             RGBColor[
             0.20466891801062498`, 0.3324503879610362, 0.9349669641489501]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.04749427504982855], {
             RGBColor[
             0.251561981731493, 0.38173797112363184`, 0.9376374547557825]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.04749427504982855], {
             RGBColor[
             0.6151488851669328, 0.6984446029768119, 0.962845920086406]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.04749427504982855], {
             RGBColor[
             0.7578751299797977, 0.8107770786953227, 0.976501568276776]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.04749427504982855], {
             RGBColor[
             0.3597741055168169, 0.48603998025151013`, 0.9441454657611495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.04749427504982855], {
             RGBColor[
             0.8827671163509688, 0.9093585527759684, 0.988680309684705]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.04749427504982855], {
             RGBColor[
             0.37449382993011915`, 0.49878946570345195`, 0.945083393584624]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.04749427504982855], {
             RGBColor[
             0.5226837829744544, 0.623377267511574, 0.9555667285309845]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.04749427504982855], {
             RGBColor[
             0.7610121439705878, 0.8132277378671173, 0.9768142365143154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.04749427504982855], {
             RGBColor[
             0.5202406138668897, 0.6213937927665389, 0.9553743933092136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.04749427504982855], {
             RGBColor[
             0.2712392255022809, 0.4024200019360435, 0.9387580446786554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.04749427504982855], {
             RGBColor[
             0.71299708434329, 0.7757180083583032, 0.9720285440969098]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.04749427504982855], {
             RGBColor[
             0.9852780819914064, 0.9881801228144806, 0.8936438107123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.04749427504982855], {
             RGBColor[
             0.39502999099149705`, 0.5165768562373506, 0.9463919396080408]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.04749427504982855], {
             RGBColor[
             0.45588929453741506`, 0.5691504927409724, 0.9503084217249476]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.04749427504982855], {
             RGBColor[
             0.813073087764507, 0.8538981428367545, 0.9820031848545128]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.04749427504982855], {
             RGBColor[
             0.22209447153483242`, 0.3507657495588844, 0.9359593236433574]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.04749427504982855], {
             RGBColor[
             0.38568839730559284`, 0.5084856373087709, 0.9457967015188219]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.04749427504982855], {
             RGBColor[
             0.8410493659881, 0.8760939510347837, 0.9847012334132192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.04749427504982855], {
             RGBColor[
             0.985538058984911, 0.9882876299823988, 0.8893353191310365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.04749427504982855], {
             RGBColor[
             0.38339584742524085`, 0.5064999458293175, 0.9456506222676682]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.04749427504982855], {
             RGBColor[
             0.6598225081461859, 0.7341776252913782, 0.9667285992862495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.04749427504982855], {
             RGBColor[
             0.6029557004629291, 0.6885456263373906, 0.9618860279213997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.04749427504982855], {
             RGBColor[
             0.7777597903996395, 0.8263111265443196, 0.9784834853947092]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.04749427504982855], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.04749427504982855], {
             RGBColor[
             0.519386842023372, 0.6207006623219881, 0.9553071812622226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.04749427504982855], {
             RGBColor[
             0.2875069831901842, 0.4195184467014401, 0.9396844694129907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.04749427504982855], {
             RGBColor[
             0.4755291507305748, 0.5850950127640182, 0.9518545431476368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.04749427504982855], {
             RGBColor[
             0.2066229083747954, 0.33450415572392395`, 0.9350782410095199]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.04749427504982855], {
             RGBColor[
             0.855914185414111, 0.8879467545503106, 0.9861190531600531]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.04749427504982855], {
             RGBColor[
             0.2898098329688846, 0.42193888782796324`, 0.9398156133011267]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.04749427504982855], {
             RGBColor[
             0.3576250416434594, 0.48417856913949886`, 0.9440085293114818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.04749427504982855], {
             RGBColor[
             0.5522533441376393, 0.6473831693573975, 0.9578945527026219]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.04749427504982855], {
             RGBColor[
             0.5867240635713044, 0.6753680522818607, 0.9606082140068458]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.04749427504982855], {
             RGBColor[
             0.584753331266218, 0.673768123016113, 0.9604530707407591]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.04749427504982855], {
             RGBColor[
             0.2818161642398682, 0.4135370351658966, 0.9393603856925823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.04749427504982855], {
             RGBColor[
             0.8685806076942428, 0.8980466158556142, 0.9873271878245807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.04749427504982855], {
             RGBColor[
             0.8404313904790921, 0.8756011941383992, 0.9846422903574967]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.04749427504982855], {
             RGBColor[
             0.9904871745558699, 0.9903342164574589, 0.8073156662197188]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.04749427504982855], {
             RGBColor[
             0.33120858518019, 0.4612979622807222, 0.9423252960647975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.04749427504982855], {
             RGBColor[
             0.38070603343584286`, 0.5041701641456829, 0.9454792296987728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.04749427504982855], {
             RGBColor[
             0.21786168811053744`, 0.3463168258059807, 0.9357182728891857]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.04749427504982855], {
             RGBColor[
             0.18853200932777658`, 0.3154894737962583, 0.934047991071879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.04749427504982855], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.04749427504982855], {
             RGBColor[
             0.35840116774137437`, 0.4848508105562809, 0.9440579833801396]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.04749427504982855], {
             RGBColor[
             0.6853172517480622, 0.754094312760392, 0.9692696770665599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.04749427504982855], {
             RGBColor[
             0.488439643627265, 0.5955763325086283, 0.9528709044411581]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.04749427504982855], {
             RGBColor[
             0.6201127713772526, 0.702474509422875, 0.9632366953921968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.04749427504982855], {
             RGBColor[
             0.6233166210679819, 0.7050755389335929, 0.9634889141759391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.04749427504982855], {
             RGBColor[
             0.7123094227949043, 0.7751808019302829, 0.9719600044203293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.04749427504982855], {
             RGBColor[
             0.8711783859336111, 0.9001180137088746, 0.9875749662321157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.04749427504982855], {
             RGBColor[
             0.5080940856985946, 0.6115326940046588, 0.9544181741176067]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.04749427504982855], {
             RGBColor[
             0.9265198972354927, 0.9442458326156888, 0.9928534889840395]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.04749427504982855], {
             RGBColor[
             0.8968325938434305, 0.9205739827312418, 0.9900218874843361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.04749427504982855], {
             RGBColor[
             0.2543896665044372, 0.3847100471055658, 0.9377984872204169]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.04749427504982855], {
             RGBColor[
             0.45698806410652854`, 0.5700425233761838, 0.9503949208903537]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.04749427504982855], {
             RGBColor[
             0.2443114892139036, 0.37411724377986827`, 0.9372245499330483]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.04749427504982855], {
             RGBColor[
             0.579953208321704, 0.6698711669666821, 0.9600751874791373]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.04749427504982855], {
             RGBColor[
             0.3674804357195669, 0.4927148161417141, 0.9446365063072286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.04749427504982855], {
             RGBColor[
             0.5685459144393687, 0.6606102119002693, 0.9591771635184255]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.04749427504982855], {
             RGBColor[
             0.24835727917944883`, 0.37836962555155584`, 0.9374549516863762]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.04749427504982855], {
             RGBColor[
             0.9827554210603398, 0.9866596017789836, 0.9140747534250498]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.04749427504982855], {
             RGBColor[
             0.6174793100414305, 0.7003365468743734, 0.9630293796691541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.04749427504982855], {
             RGBColor[
             0.706880373426309, 0.7709395873012329, 0.9714188875166185]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.04749427504982855], {
             RGBColor[
             0.9936375870879252, 0.9887997670567209, 0.5488688026607924]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.04749427504982855], {
             RGBColor[
             0.30435637886932787`, 0.43722822987360904`, 0.9406440175704708]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.04749427504982855], {
             RGBColor[
             0.20320045771975423`, 0.330906943089571, 0.9348833375077773]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.04749427504982855], {
             RGBColor[
             0.2629864068032848, 0.393745766224471, 0.9382880588626987]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.04749427504982855], {
             RGBColor[
             0.7171561172876193, 0.7789670765042344, 0.9724430776324279]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.04749427504982855], {
             RGBColor[
             0.36087415441144166`, 0.48699278731396906`, 0.94421555990398]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.04749427504982855], {
             RGBColor[
             0.4747111309646251, 0.5844309074666497, 0.9517901456351562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.04749427504982855], {
             RGBColor[
             0.5042205810075551, 0.6083880083970752, 0.9541132376392129]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.04749427504982855], {
             RGBColor[
             0.577179989505309, 0.6676197429994487, 0.9598568695352754]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.04749427504982855], {
             RGBColor[
             0.34010776075720484`, 0.46900598087996254`, 0.942892343663333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.04749427504982855], {
             RGBColor[
             0.870581453363093, 0.8996420358804464, 0.9875180302706517]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.04749427504982855], {
             RGBColor[
             0.9889975389953055, 0.9745482569097803, 0.4117579459475264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.04749427504982855], {
             RGBColor[
             0.7423850350019708, 0.7986760987695621, 0.9749576603725539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.04749427504982855], {
             RGBColor[
             0.5218034061181207, 0.6226625379190769, 0.9554974220399272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.04749427504982855], {
             RGBColor[
             0.2920560483785939, 0.42429980264185035`, 0.9399435319457318]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.04749427504982855], {
             RGBColor[
             0.45698806410652854`, 0.5700425233761838, 0.9503949208903537]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.04749427504982855], {
             RGBColor[
             0.20159045631142863`, 0.3292147295294357, 0.9347916503093568]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.04749427504982855], {
             RGBColor[
             0.6622803184374976, 0.736097685371001, 0.9669735708465445]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.04749427504982855], {
             RGBColor[
             0.43885616739035327`, 0.5545368874663658, 0.9491845048142098]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.04749427504982855], {
             RGBColor[
             0.7865364937964249, 0.8331675539433047, 0.9793582651663443]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.04749427504982855], {
             RGBColor[
             0.8269915093617318, 0.8648845977512705, 0.9833603824985995]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.04749427504982855], {
             RGBColor[
             0.9941646666538888, 0.9899271369523984, 0.6062381606579064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.04749427504982855], {
             RGBColor[
             0.9009679552426701, 0.9238714076596006, 0.9904163219462762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.04749427504982855], {
             RGBColor[
             0.3595433773161141, 0.48584013508079793`, 0.9441307639642258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.04749427504982855], {
             RGBColor[
             0.629469375477967, 0.7100706221420463, 0.9639732815413752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.04749427504982855], {
             RGBColor[
             0.24327606877034536`, 0.3730289512442407, 0.9371655842705549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.04749427504982855], {
             RGBColor[
             0.5123869298466268, 0.6150178182744563, 0.954756122534146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.04749427504982855], {
             RGBColor[
             0.18164819492976195`, 0.3082541484049034, 0.9336559680256028]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.04749427504982855], {
             RGBColor[
             0.9855198332017295, 0.988280093152672, 0.8896373675251685]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.04749427504982855], {
             RGBColor[
             0.7777597903996395, 0.8263111265443196, 0.9784834853947092]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.04749427504982855], {
             RGBColor[
             0.6157369912375897, 0.6989220539788479, 0.9628922179505917]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.04749427504982855], {
             RGBColor[
             0.8595085884446404, 0.8908128339593836, 0.9864618905298664]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.04749427504982855], {
             RGBColor[
             0.8206044727383506, 0.8597917481192769, 0.9827511812436864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.04749427504982855], {
             RGBColor[
             0.8552918660706376, 0.8874505339982335, 0.9860596957855216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.04749427504982855], {
             RGBColor[
             0.955913589502354, 0.9666410077525032, 0.9595109727818398]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.04749427504982855], {
             RGBColor[
             0.9852299536760784, 0.9881602205192511, 0.8944414214493743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.04749427504982855], {
             RGBColor[
             0.33096486854496276`, 0.46108686718084263`, 0.942309766656311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.04749427504982855], {
             RGBColor[
             0.43885616739035327`, 0.5545368874663658, 0.9491845048142098]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
          103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
          129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 
          142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 
          155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 
          168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 
          181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 
          194, 195, 196, 197, 198, 199, 200}, {Null, CompressedData["
1:eJwVxfk/GgwDAPA5ylXk6qBcTS9j5XjImZDN1UpNhz0LEUrEK0VRaK6QloU8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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[31, 80] -> 
             RGBColor[
              0.7352027165067365, 0.7929678458962808, 0.9744115778147804], 
             UndirectedEdge[36, 132] -> 
             RGBColor[
              0.24999710016017773`, 0.3800931813729572, 0.937548337065331], 
             UndirectedEdge[16, 101] -> 
             RGBColor[
              0.28740281094428266`, 0.4180946549568002, 0.9397266599229551], 
             UndirectedEdge[86, 108] -> 
             RGBColor[
              0.5865960904370586, 0.6714707671165345, 0.9625129589589009], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.3936636675304358, 0.5153934155287933, 0.9463048786852943], 
             UndirectedEdge[29, 136] -> 
             RGBColor[
              0.950824845750427, 0.8323116913697606, 0.49992668872926316`], 
             UndirectedEdge[55, 157] -> 
             RGBColor[
              0.4550334300726567, 0.5657150158349769, 0.9509982940305055], 
             UndirectedEdge[7, 188] -> 
             RGBColor[
              0.5075570604878807, 0.6079623494198335, 0.955381071984007], 
             UndirectedEdge[19, 141] -> 
             RGBColor[
              0.31187008513103276`, 0.44044798095241544`, 0.9412431829967022],
              UndirectedEdge[62, 185] -> 
             RGBColor[
              0.5629039980331934, 0.6514450489037454, 0.9607937355315148], 
             UndirectedEdge[79, 144] -> 
             RGBColor[
              0.6389999811794337, 0.4008456236267517, 0.4461443465462792], 
             UndirectedEdge[47, 54] -> 
             RGBColor[
              0.3621640961349061, 0.48478721437619465`, 0.9444194198717641], 
             UndirectedEdge[32, 101] -> 
             RGBColor[
              0.2434980017964442, 0.3732622169260371, 0.9371782230280707], 
             UndirectedEdge[104, 163] -> 
             RGBColor[
              0.22597848605701326`, 0.35484809508244053`, 0.9361805125245111],
              UndirectedEdge[119, 125] -> 
             RGBColor[
              0.3719190998621983, 0.4815306199533135, 0.9461956553093709], 
             UndirectedEdge[9, 140] -> 
             RGBColor[
              0.2830352445403058, 0.4148183658558119, 0.9394298105122245], 
             UndirectedEdge[3, 63] -> 
             RGBColor[
              0.30825791983475437`, 0.437251051830131, 0.9410155180983026], 
             UndirectedEdge[50, 104] -> 
             RGBColor[
              0.2305835536607953, 0.3596883131121654, 0.9364427643119595], 
             UndirectedEdge[47, 61] -> 
             RGBColor[
              0.36265936899724993`, 0.48530777755663124`, 0.944447624928584], 
             UndirectedEdge[149, 195] -> 
             RGBColor[
              0.2062475040297809, 0.3341095819553035, 0.9350568622874322], 
             UndirectedEdge[99, 178] -> 
             RGBColor[
              0.7532636952500258, 0.8067917718917483, 0.970579392980242], 
             UndirectedEdge[160, 174] -> 
             RGBColor[
              0.37406119352792633`, 0.4984147377968103, 0.9450558263756417], 
             UndirectedEdge[6, 124] -> 
             RGBColor[
              0.3155531459350417, 0.4461023057398271, 0.9413876363800726], 
             UndirectedEdge[24, 197] -> 
             RGBColor[
              0.5339219982745609, 0.6098281505161249, 0.9613839453194717], 
             UndirectedEdge[80, 120] -> 
             RGBColor[
              0.7883329572883422, 0.7840663517109472, 0.6248876395864237], 
             UndirectedEdge[83, 187] -> 
             RGBColor[
              0.26933773838678554`, 0.40042141841641143`, 0.938649757800426], 
             UndirectedEdge[47, 167] -> 
             RGBColor[
              0.6833987505402253, 0.7503936163476059, 0.9708862787627], 
             UndirectedEdge[132, 150] -> 
             RGBColor[
              0.2675705658104447, 0.39856400799346436`, 0.938549119936501], 
             UndirectedEdge[17, 189] -> 
             RGBColor[
              0.23511483918268133`, 0.3644509814957634, 0.9367008143189947], 
             UndirectedEdge[69, 180] -> 
             RGBColor[
              0.5628268850068445, 0.6533109098577117, 0.9599708318719281], 
             UndirectedEdge[43, 95] -> 
             RGBColor[
              0.8967855212794014, 0.5986904854238292, 0.25888435369462925`], 
             UndirectedEdge[82, 86] -> 
             RGBColor[
              0.3552790109161934, 0.48214655523847394`, 0.943859042308054], 
             UndirectedEdge[7, 61] -> 
             RGBColor[
              0.3121285679978709, 0.4415405374828739, 0.9412278469715365], 
             UndirectedEdge[30, 65] -> 
             RGBColor[
              0.9079204151899432, 0.9294151105020584, 0.9910794537825813], 
             UndirectedEdge[62, 174] -> 
             RGBColor[
              0.36882264112374896`, 0.4938773670016114, 0.9447220304487174], 
             UndirectedEdge[18, 47] -> 
             RGBColor[
              0.38494609227374893`, 0.5078426899995235, 0.9457494024985874], 
             UndirectedEdge[56, 149] -> 
             RGBColor[
              0.2062475040297809, 0.3341095819553035, 0.9350568622874322], 
             UndirectedEdge[82, 163] -> 
             RGBColor[
              0.2758102937038249, 0.40631356017084397`, 0.9390517136501494], 
             UndirectedEdge[10, 48] -> 
             RGBColor[
              0.30320935155036544`, 0.43524999752426985`, 0.940606985973867], 
             UndirectedEdge[58, 92] -> 
             RGBColor[
              0.24643437763355744`, 0.3763485341078243, 0.9373454452880156], 
             UndirectedEdge[70, 72] -> 
             RGBColor[
              0.23177582019152226`, 0.36094146083002354`, 0.936510662127084], 
             UndirectedEdge[35, 181] -> 
             RGBColor[
              0.9113516048559902, 0.930874079920538, 0.9469017763992353], 
             UndirectedEdge[126, 174] -> 
             RGBColor[
              0.3443177986809051, 0.472511876251829, 0.9431657526324266], 
             UndirectedEdge[108, 154] -> 
             RGBColor[
              0.8838800631396134, 0.9088604535486795, 0.9258833443185683], 
             UndirectedEdge[63, 77] -> 
             RGBColor[
              0.3266232709961202, 0.4565542003312445, 0.9420613976778401], 
             UndirectedEdge[32, 100] -> 
             RGBColor[
              0.22448297168171977`, 0.35327621465291903`, 0.9360953451932534],
              UndirectedEdge[19, 50] -> 
             RGBColor[
              0.2533169376668154, 0.3835825410822887, 0.9377373969000744], 
             UndirectedEdge[80, 81] -> 
             RGBColor[
              0.5981154418108365, 0.6846160863124545, 0.9615049850298553], 
             UndirectedEdge[34, 163] -> 
             RGBColor[
              0.24238504014097356`, 0.3720924236602928, 0.9371148415082708], 
             UndirectedEdge[146, 194] -> 
             RGBColor[
              0.5723118578420975, 0.6584672801449877, 0.9618699351638069], 
             UndirectedEdge[13, 83] -> 
             RGBColor[
              0.316923827731624, 0.4440344737616491, 0.9415941582521057], 
             UndirectedEdge[30, 41] -> 
             RGBColor[
              0.7217306402299773, 0.781717727178925, 0.9737111260908631], 
             UndirectedEdge[35, 111] -> 
             RGBColor[
              0.6494345587146366, 0.7234252020636741, 0.9675585260086426], 
             UndirectedEdge[29, 144] -> 
             RGBColor[
              0.9022249366155904, 0.6208207570711475, 0.3861737156527596], 
             UndirectedEdge[6, 12] -> 
             RGBColor[
              0.4620072235822212, 0.5710418605945535, 0.9516398014511775], 
             UndirectedEdge[67, 143] -> 
             RGBColor[
              0.8190699438712857, 0.14758552186319893`, 0.16589470582855148`],
              UndirectedEdge[135, 163] -> 
             RGBColor[
              0.2331505740140204, 0.36238641426189583`, 0.9365889523235094], 
             UndirectedEdge[50, 60] -> 
             RGBColor[
              0.24809478057534154`, 0.3780937228752663, 0.9374400027792041], 
             UndirectedEdge[25, 143] -> 
             RGBColor[
              0.8735061292591867, 0.42076748591111013`, 0.23590476193812596`],
              UndirectedEdge[12, 13] -> 
             RGBColor[
              0.4809809724952037, 0.58747596825463, 0.9528487919540853], 
             UndirectedEdge[89, 144] -> 
             RGBColor[
              0.8548334539658015, 0.42247953211969835`, 0.20014188348416714`],
              UndirectedEdge[22, 24] -> 
             RGBColor[
              0.6225902394734423, 0.3300989620118385, 0.4379481515395359], 
             UndirectedEdge[107, 156] -> 
             RGBColor[
              0.7940373920785235, 0.8398425244747729, 0.979889552465069], 
             UndirectedEdge[23, 154] -> 
             RGBColor[
              0.9900533443030074, 0.9886857899175692, 0.707722631591383], 
             UndirectedEdge[101, 135] -> 
             RGBColor[
              0.2425616632808307, 0.3722780657788366, 0.9371248999347952], 
             UndirectedEdge[7, 42] -> 
             RGBColor[
              0.4359507962934013, 0.5501706892115099, 0.9495104580293312], 
             UndirectedEdge[122, 192] -> 
             RGBColor[
              0.8758587759165559, 0.41851937401271744`, 0.2670649130066242], 
             UndirectedEdge[129, 133] -> 
             RGBColor[
              0.8790384594977417, 0.4469900974919443, 0.2522656130299896], 
             UndirectedEdge[40, 80] -> 
             RGBColor[
              0.555739244439546, 0.6502131802605045, 0.9581689755436615], 
             UndirectedEdge[41, 172] -> 
             RGBColor[
              0.7718454040169196, 0.8174234076188627, 0.7717375932565325], 
             UndirectedEdge[94, 115] -> 
             RGBColor[
              0.34184068469654455`, 0.4665135495155001, 0.9431489820897013], 
             UndirectedEdge[87, 103] -> 
             RGBColor[
              0.9055186961480244, 0.6475369650177958, 0.42196747470883456`], 
             UndirectedEdge[142, 160] -> 
             RGBColor[
              0.5038004126414563, 0.6056953348255233, 0.9547299040233275], 
             UndirectedEdge[21, 150] -> 
             RGBColor[
              0.29956418872733326`, 0.4315020124177601, 0.9403963488781741], 
             UndirectedEdge[29, 142] -> 
             RGBColor[
              0.8172660326623933, 0.855490432397475, 0.8599437218958297], 
             UndirectedEdge[67, 103] -> 
             RGBColor[
              0.833567382441636, 0.252847633383231, 0.17953580679306383`], 
             UndirectedEdge[50, 163] -> 
             RGBColor[
              0.23762722721084206`, 0.36709166060796167`, 0.9368438911004533],
              UndirectedEdge[21, 46] -> 
             RGBColor[
              0.4569720284859443, 0.5663064733841641, 0.9514223432183879], 
             UndirectedEdge[43, 129] -> 
             RGBColor[
              0.9003301475995195, 0.6106473423194261, 0.27265455760177426`], 
             UndirectedEdge[11, 112] -> 
             RGBColor[
              0.2736557868068433, 0.4049599610859747, 0.9388956642699682], 
             UndirectedEdge[119, 195] -> 
             RGBColor[
              0.37190268566599016`, 0.4815133675923786, 0.9461947205451795], 
             UndirectedEdge[99, 109] -> 
             RGBColor[
              0.45081925257627997`, 0.561890841684138, 0.9507778651594582], 
             UndirectedEdge[45, 120] -> 
             RGBColor[
              0.9205644172331103, 0.7168104234407002, 0.25588752113131463`], 
             UndirectedEdge[29, 153] -> 
             RGBColor[
              0.7898065464682866, 0.8331975844693433, 0.8577820105552174], 
             UndirectedEdge[27, 125] -> 
             RGBColor[
              0.22785442897304503`, 0.35681983002884055`, 0.9362873446983702],
              UndirectedEdge[35, 157] -> 
             RGBColor[
              0.6980290555794366, 0.7628764037756551, 0.971384062809347], 
             UndirectedEdge[28, 112] -> 
             RGBColor[
              0.2981130439403854, 0.43066608901299275`, 0.9402884688824538], 
             UndirectedEdge[22, 89] -> 
             RGBColor[
              0.84761198290322, 0.36697214106389997`, 0.19322659463915418`], 
             UndirectedEdge[96, 116] -> 
             RGBColor[
              0.3478897367236583, 0.4755106363355533, 0.9433968344585502], 
             UndirectedEdge[23, 143] -> 
             RGBColor[
              0.8783920111917808, 0.4368059364020854, 0.2925360104669875], 
             UndirectedEdge[6, 14] -> 
             RGBColor[
              0.37841229319367853`, 0.5021834416346569, 0.945333074598817], 
             UndirectedEdge[9, 112] -> 
             RGBColor[
              0.28100806217130603`, 0.41268766865520734`, 0.9393143654752576],
              UndirectedEdge[12, 25] -> 
             RGBColor[
              0.7814420691727634, 0.8068428114651084, 0.666502637240134], 
             UndirectedEdge[176, 199] -> 
             RGBColor[
              0.28324272218403285`, 0.4150364380142114, 0.9394416260570992], 
             UndirectedEdge[48, 112] -> 
             RGBColor[
              0.3092759955003079, 0.44162642496310195`, 0.9409524723720207], 
             UndirectedEdge[79, 149] -> 
             RGBColor[
              0.21876808015896437`, 0.34726950131745254`, 0.9357698905754568],
              UndirectedEdge[58, 155] -> 
             RGBColor[
              0.25688825427596124`, 0.3873362212730521, 0.9379407780976758], 
             UndirectedEdge[118, 138] -> 
             RGBColor[
              0.9130416014388392, 0.812801149295034, 0.6201343733156849], 
             UndirectedEdge[172, 173] -> 
             RGBColor[
              0.9945590642006376, 0.9907707134251852, 0.6491658996819889], 
             UndirectedEdge[53, 104] -> 
             RGBColor[
              0.21517354122831484`, 0.34349141299440844`, 0.9355651869010002],
              UndirectedEdge[179, 185] -> 
             RGBColor[
              0.7887535289716312, 0.8348995186722672, 0.9795792385132371], 
             UndirectedEdge[82, 176] -> 
             RGBColor[
              0.30639768237766407`, 0.4384628450195025, 0.9407936201851381], 
             UndirectedEdge[142, 181] -> 
             RGBColor[
              0.8126094756619291, 0.8535648264097266, 0.9371149221767408], 
             UndirectedEdge[54, 160] -> 
             RGBColor[
              0.3197591214680627, 0.448058156655773, 0.9417174123832397], 
             UndirectedEdge[121, 151] -> 
             RGBColor[
              0.4472759744708069, 0.5594034354051198, 0.9503913919352824], 
             UndirectedEdge[138, 144] -> 
             RGBColor[
              0.8752691557383894, 0.5209048945205916, 0.21739381612783068`], 
             UndirectedEdge[171, 196] -> 
             RGBColor[
              0.6848218020180831, 0.7518929600057571, 0.9706449762400708], 
             UndirectedEdge[120, 172] -> 
             RGBColor[
              0.9753727800277856, 0.9276792174007213, 0.4361680487899127], 
             UndirectedEdge[113, 159] -> 
             RGBColor[
              0.8485303397063004, 0.33009952954163524`, 0.19238576661614035`],
              UndirectedEdge[103, 108] -> 
             RGBColor[
              0.8366047008902185, 0.5941132685295566, 0.465258687547469], 
             UndirectedEdge[64, 176] -> 
             RGBColor[
              0.45839978276888355`, 0.5655229499724335, 0.9517490792275327], 
             UndirectedEdge[83, 101] -> 
             RGBColor[
              0.2538463417938609, 0.3841389783859738, 0.9377675456819266], 
             UndirectedEdge[15, 63] -> 
             RGBColor[
              0.33898161598962545`, 0.46803057088396705`, 0.9428205867145535],
              UndirectedEdge[55, 72] -> 
             RGBColor[
              0.3011292819316679, 0.4298018950317811, 0.9406079602011264], 
             UndirectedEdge[105, 142] -> 
             RGBColor[
              0.4920496854617956, 0.5955174455512221, 0.9539811580781995], 
             UndirectedEdge[96, 105] -> 
             RGBColor[
              0.32470350781154744`, 0.4554278902256328, 0.9419194284550477], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.3349775869314745, 0.46456248216214874`, 0.942565453523592], 
             UndirectedEdge[64, 108] -> 
             RGBColor[
              0.7019176077126746, 0.7667599945944428, 0.9711311636805353], 
             UndirectedEdge[56, 119] -> 
             RGBColor[
              0.37190268566599016`, 0.4815133675923786, 0.9461947205451795], 
             UndirectedEdge[68, 157] -> 
             RGBColor[
              0.7066548099945791, 0.7697543462064234, 0.9722067949657651], 
             UndirectedEdge[137, 161] -> 
             RGBColor[
              0.2794230248160247, 0.4110216938976339, 0.939224099942727], 
             UndirectedEdge[160, 188] -> 
             RGBColor[
              0.5156828868204164, 0.6150005317731692, 0.9558988424525301], 
             UndirectedEdge[127, 187] -> 
             RGBColor[
              0.3022073859943112, 0.43378220468743567`, 0.9405651083800737], 
             UndirectedEdge[41, 141] -> 
             RGBColor[
              0.4545263425380657, 0.5654922255819677, 0.9509061844081543], 
             UndirectedEdge[137, 175] -> 
             RGBColor[
              0.2852924893069724, 0.4161135758232565, 0.9395978023974743], 
             UndirectedEdge[1, 122] -> 
             RGBColor[
              0.9756254576616791, 0.9291724163168037, 0.38265572153063876`], 
             UndirectedEdge[60, 177] -> 
             RGBColor[
              0.273782020378095, 0.40509264057303096`, 0.9389028530851051], 
             UndirectedEdge[72, 75] -> 
             RGBColor[
              0.26701897159742227`, 0.39798424750248473`, 0.9385177074620799],
              UndirectedEdge[13, 69] -> 
             RGBColor[
              0.38979245396039097`, 0.512040364907272, 0.9460582083797908], 
             UndirectedEdge[48, 77] -> 
             RGBColor[
              0.30874838296909257`, 0.4410718707402281, 0.9409224256189008], 
             UndirectedEdge[22, 183] -> 
             RGBColor[
              0.8495847316428689, 0.3805569710517512, 0.19505388777575874`], 
             UndirectedEdge[16, 86] -> 
             RGBColor[
              0.3574604388898408, 0.48403599850748935`, 0.9439980409695737], 
             UndirectedEdge[8, 62] -> 
             RGBColor[
              0.40221602470153694`, 0.5228010374564311, 0.9468498273216844], 
             UndirectedEdge[26, 51] -> 
             RGBColor[
              0.3392714220793772, 0.4658216765666159, 0.9429291222497664], 
             UndirectedEdge[117, 121] -> 
             RGBColor[
              0.6608369282647062, 0.733443073990961, 0.9678737418567172], 
             UndirectedEdge[89, 136] -> 
             RGBColor[
              0.8719970463971514, 0.5016704079877174, 0.2145036241613812], 
             UndirectedEdge[81, 168] -> 
             RGBColor[
              0.7574630871375609, 0.8103278215593543, 0.974310777757218], 
             UndirectedEdge[172, 198] -> 
             RGBColor[
              0.8450687656775151, 0.8760452560467036, 0.7780654976273946], 
             UndirectedEdge[55, 68] -> 
             RGBColor[
              0.6040034340544339, 0.6836766872491769, 0.9648829517187356], 
             UndirectedEdge[156, 192] -> 
             RGBColor[
              0.8518272488984739, 0.40265794141667954`, 0.4402493642261227], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.3132800245584588, 0.44509451368492026`, 0.9412076055629822], 
             UndirectedEdge[25, 154] -> 
             RGBColor[
              0.9827245214041163, 0.9646281141811062, 0.6227757587980907], 
             UndirectedEdge[100, 135] -> 
             RGBColor[
              0.2235466331661063, 0.3522920635057185, 0.9360420220999779], 
             UndirectedEdge[37, 149] -> 
             RGBColor[
              0.21228087842813756`, 0.34045104098600754`, 0.9354004540338412],
              UndirectedEdge[125, 149] -> 
             RGBColor[
              0.206263918225989, 0.33412683431623835`, 0.9350577970516237], 
             UndirectedEdge[2, 184] -> 
             RGBColor[
              0.37412689727752746`, 0.49847164708234826`, 0.9450600129604667],
              UndirectedEdge[6, 16] -> 
             RGBColor[
              0.3315065479690632, 0.46155604267239897`, 0.9423442819902264], 
             UndirectedEdge[55, 111] -> 
             RGBColor[
              0.40643893320785657`, 0.5262638141229958, 0.9471727572298012], 
             UndirectedEdge[34, 50] -> 
             RGBColor[
              0.2469901077447556, 0.3769326416900177, 0.9373770932957193], 
             UndirectedEdge[56, 125] -> 
             RGBColor[
              0.17894341419620807`, 0.3054112523609348, 0.9335019347641915], 
             UndirectedEdge[98, 196] -> 
             RGBColor[
              0.7343309142909232, 0.7903956980318739, 0.9415812202273133], 
             UndirectedEdge[160, 167] -> 
             RGBColor[
              0.6409937758733817, 0.7136645586271843, 0.9681842712741754], 
             UndirectedEdge[22, 149] -> 
             RGBColor[
              0.6408039078801677, 0.34924268232058286`, 0.43898539301059114`],
              UndirectedEdge[147, 194] -> 
             RGBColor[
              0.41461252572283636`, 0.5327948903127648, 0.9478451176521548], 
             UndirectedEdge[83, 161] -> 
             RGBColor[
              0.28225365624559345`, 0.41399686700250915`, 0.9393853002150969],
              UndirectedEdge[34, 177] -> 
             RGBColor[
              0.27267734754750905`, 0.40393155938778236`, 0.9388399436016203],
              UndirectedEdge[70, 145] -> 
             RGBColor[
              0.2107154956867174, 0.33880572447377666`, 0.9353113078024935], 
             UndirectedEdge[125, 170] -> 
             RGBColor[
              0.18066259612527297`, 0.307218221570812, 0.93359983963175], 
             UndirectedEdge[190, 192] -> 
             RGBColor[
              0.6047816873553487, 0.19148929823006858`, 0.42066047446022103`],
              UndirectedEdge[122, 188] -> 
             RGBColor[
              0.8287961614327686, 0.8626280708354541, 0.7199844478872237], 
             UndirectedEdge[123, 130] -> 
             RGBColor[
              0.24382776690061642`, 0.3736088209588374, 0.9371970026629095], 
             UndirectedEdge[94, 116] -> 
             RGBColor[
              0.4038551160855868, 0.5242207360301667, 0.9469542687752844], 
             UndirectedEdge[23, 162] -> 
             RGBColor[
              0.9882402059749112, 0.9877215722762983, 0.728168038634343], 
             UndirectedEdge[116, 160] -> 
             RGBColor[
              0.3781472802574135, 0.5019539007492015, 0.9453161882088599], 
             UndirectedEdge[80, 117] -> 
             RGBColor[
              0.699447709361209, 0.7647890454809683, 0.9709133239805854], 
             UndirectedEdge[147, 185] -> 
             RGBColor[
              0.625134594396598, 0.7046026904109504, 0.9649644103506239], 
             UndirectedEdge[55, 107] -> 
             RGBColor[
              0.5098065457970684, 0.609801290788619, 0.955570731517623], 
             UndirectedEdge[111, 174] -> 
             RGBColor[
              0.4209532104070455, 0.5388353515241499, 0.9480975941384622], 
             UndirectedEdge[126, 142] -> 
             RGBColor[
              0.47405701779443504`, 0.579792473280542, 0.9528398302801124], 
             UndirectedEdge[115, 160] -> 
             RGBColor[
              0.31613284886837134`, 0.44424671423453505`, 0.9415109015232768],
              UndirectedEdge[74, 164] -> 
             RGBColor[
              0.29875283098362904`, 0.4313385457602833, 0.9403249038080864], 
             UndirectedEdge[42, 97] -> 
             RGBColor[
              0.401201459999004, 0.517503689481011, 0.9473903200062829], 
             UndirectedEdge[25, 108] -> 
             RGBColor[
              0.8800770451068233, 0.8847917621519991, 0.6757220357685101], 
             UndirectedEdge[67, 133] -> 
             RGBColor[
              0.8199464110752147, 0.15432243286297473`, 0.166734011812862], 
             UndirectedEdge[38, 183] -> 
             RGBColor[
              0.8948764104777984, 0.602162747374174, 0.2424745440128403], 
             UndirectedEdge[33, 41] -> 
             RGBColor[
              0.4363770738073567, 0.5497722412161976, 0.9497497290534018], 
             UndirectedEdge[32, 123] -> 
             RGBColor[
              0.24279155375346242`, 0.3725196952414703, 0.9371379918571192], 
             UndirectedEdge[61, 116] -> 
             RGBColor[
              0.3316898960628568, 0.4584835766718288, 0.9424742774984342], 
             UndirectedEdge[93, 134] -> 
             RGBColor[
              0.2274998629101822, 0.35644715861598486`, 0.9362671526856237], 
             UndirectedEdge[45, 128] -> 
             RGBColor[
              0.8869707508914968, 0.5796424030976618, 0.22739796275449303`], 
             UndirectedEdge[29, 35] -> 
             RGBColor[
              0.9160081618564544, 0.9327996859082862, 0.8697305761183244], 
             UndirectedEdge[3, 106] -> 
             RGBColor[
              0.26935764073949675`, 0.40044233705099297`, 0.93865089120997], 
             UndirectedEdge[77, 140] -> 
             RGBColor[
              0.3029488619339533, 0.43574884033280226`, 0.9405638615632359], 
             UndirectedEdge[79, 195] -> 
             RGBColor[
              0.1914475761291835, 0.31855391936214905`, 0.9342140282880245], 
             UndirectedEdge[38, 46] -> 
             RGBColor[
              0.7812753615379626, 0.7886327284729578, 0.6396314180362879], 
             UndirectedEdge[14, 59] -> 
             RGBColor[
              0.43278883650636024`, 0.549281670407568, 0.9487978998554119], 
             UndirectedEdge[126, 191] -> 
             RGBColor[
              0.2937278856939699, 0.4260570096609187, 0.9400387406075807], 
             UndirectedEdge[13, 64] -> 
             RGBColor[
              0.5003009692996179, 0.6031608120163909, 0.9543697328740091], 
             UndirectedEdge[3, 11] -> 
             RGBColor[
              0.2547628231142621, 0.3851022583619874, 0.9378197379373108], 
             UndirectedEdge[31, 98] -> 
             RGBColor[
              0.9119983758560902, 0.9316922814327566, 0.9576824339727095], 
             UndirectedEdge[25, 162] -> 
             RGBColor[
              0.9809113830760201, 0.9636638965398352, 0.6432211658410507], 
             UndirectedEdge[126, 157] -> 
             RGBColor[
              0.43245489742186133`, 0.5460179978079216, 0.9495647589707952], 
             UndirectedEdge[128, 183] -> 
             RGBColor[
              0.8698008244556358, 0.5016777772906199, 0.21307095526300113`], 
             UndirectedEdge[22, 192] -> 
             RGBColor[
              0.8353875718603139, 0.2730099610170472, 0.18152048481896965`], 
             UndirectedEdge[99, 194] -> 
             RGBColor[
              0.45631234328201786`, 0.5666486807626816, 0.9511278800418784], 
             UndirectedEdge[21, 151] -> 
             RGBColor[
              0.33403902527338425`, 0.46374954722739153`, 0.9425056492046759],
              UndirectedEdge[48, 59] -> 
             RGBColor[
              0.382953798860026, 0.5061170655801353, 0.9456224553239809], 
             UndirectedEdge[18, 115] -> 
             RGBColor[
              0.2919621879503136, 0.4233113026000546, 0.9399707683828544], 
             UndirectedEdge[29, 89] -> 
             RGBColor[
              0.9005424949414248, 0.6078887731128675, 0.3845626076055324], 
             UndirectedEdge[15, 140] -> 
             RGBColor[
              0.31530720692745856`, 0.4472252108855248, 0.9413230505999493], 
             UndirectedEdge[113, 136] -> 
             RGBColor[
              0.9041543846818847, 0.6565805366270306, 0.24168008890791598`], 
             UndirectedEdge[111, 160] -> 
             RGBColor[
              0.41360379540408243`, 0.5324696576409218, 0.9476292959133059], 
             UndirectedEdge[116, 188] -> 
             RGBColor[
              0.5271183885528666, 0.6249053886087885, 0.9566275025109046], 
             UndirectedEdge[82, 127] -> 
             RGBColor[
              0.32009303423134106`, 0.45167023073266444`, 0.9416170229874327],
              UndirectedEdge[25, 95] -> 
             RGBColor[
              0.9792736576371948, 0.9417473218129542, 0.37398250307217895`], 
             UndirectedEdge[62, 111] -> 
             RGBColor[
              0.40836524299990506`, 0.527932286845723, 0.9472954999863816], 
             UndirectedEdge[162, 180] -> 
             RGBColor[
              0.853484717444914, 0.8855675982797966, 0.9434799440471393], 
             UndirectedEdge[89, 159] -> 
             RGBColor[
              0.8435429758673372, 0.3356959699358522, 0.18933010890630664`], 
             UndirectedEdge[7, 153] -> 
             RGBColor[
              0.46821510011481404`, 0.5763643045440561, 0.9520504222141921], 
             UndirectedEdge[146, 183] -> 
             RGBColor[
              0.8386384964590899, 0.584723475070088, 0.463315779566298], 
             UndirectedEdge[144, 197] -> 
             RGBColor[
              0.8673162616632236, 0.5950284434012776, 0.4642576245133444], 
             UndirectedEdge[120, 128] -> 
             RGBColor[
              0.9231751810131911, 0.7286652920066743, 0.2580660064250903], 
             UndirectedEdge[74, 166] -> 
             RGBColor[
              0.34685352759081295`, 0.47429746798031186`, 0.9433423658444682],
              UndirectedEdge[147, 152] -> 
             RGBColor[
              0.3812177118441309, 0.5013730508472783, 0.9458086544862003], 
             UndirectedEdge[22, 190] -> 
             RGBColor[
              0.6228502592156624, 0.3303722592471158, 0.4379629592791906], 
             UndirectedEdge[27, 128] -> 
             RGBColor[
              0.5831652721126257, 0.49985421349972364`, 0.5843241339583132], 
             UndirectedEdge[47, 88] -> 
             RGBColor[
              0.5818581666070413, 0.6702991325141743, 0.9609700518092634], 
             UndirectedEdge[69, 177] -> 
             RGBColor[
              0.3475961861623531, 0.47409235374214537`, 0.9434207502916752], 
             UndirectedEdge[122, 167] -> 
             RGBColor[
              0.9541070504857341, 0.9612920976894692, 0.7322698767088691], 
             UndirectedEdge[1, 78] -> 
             RGBColor[
              0.9431385588038124, 0.9082192270955545, 0.6427719916956993], 
             UndirectedEdge[138, 159] -> 
             RGBColor[
              0.8526881995414608, 0.34733777015289946`, 0.19577026697210964`],
              UndirectedEdge[101, 127] -> 
             RGBColor[
              0.28671598940138643`, 0.417499764656998, 0.9396828962615742], 
             UndirectedEdge[65, 90] -> 
             RGBColor[
              0.6550212395891795, 0.7255799866641114, 0.9691860218299977], 
             UndirectedEdge[64, 127] -> 
             RGBColor[
              0.4720951346225606, 0.5787303356855954, 0.9525724820298272], 
             UndirectedEdge[117, 146] -> 
             RGBColor[
              0.7875464410912392, 0.8339565324458974, 0.9794589272741974], 
             UndirectedEdge[49, 103] -> 
             RGBColor[
              0.8445886551123987, 0.33756196468319305`, 0.19008978994933337`],
              UndirectedEdge[88, 113] -> 
             RGBColor[
              0.8062483508925926, 0.7076340176229743, 0.6052352623718941], 
             UndirectedEdge[13, 176] -> 
             RGBColor[
              0.3360981234854725, 0.4641878743195114, 0.9426861060294587], 
             UndirectedEdge[17, 112] -> 
             RGBColor[
              0.27014379762534146`, 0.4012686377832412, 0.938695661681604], 
             UndirectedEdge[129, 170] -> 
             RGBColor[
              0.5863125273607737, 0.6439068649740138, 0.6751789886764388], 
             UndirectedEdge[35, 116] -> 
             RGBColor[
              0.6139780435679677, 0.6929094451719539, 0.9652454183041966], 
             UndirectedEdge[69, 110] -> 
             RGBColor[
              0.503306311820726, 0.6062411074789984, 0.9544293736590629], 
             UndirectedEdge[47, 126] -> 
             RGBColor[
              0.37937335834478547`, 0.5028752400890226, 0.9453994618957948], 
             UndirectedEdge[83, 137] -> 
             RGBColor[
              0.2530177140174724, 0.383268038054954, 0.9377203565559061], 
             UndirectedEdge[72, 84] -> 
             RGBColor[
              0.256326539038239, 0.386745822943403, 0.9379087892458708], 
             UndirectedEdge[22, 37] -> 
             RGBColor[
              0.626612488125885, 0.33432660037084994`, 0.4381772126499089], 
             UndirectedEdge[90, 141] -> 
             RGBColor[
              0.37364371183420664`, 0.49805313613695035`, 0.9450292248112824],
              UndirectedEdge[24, 79] -> 
             RGBColor[
              0.1914475775488761, 0.318553920854336, 0.9342140283688739], 
             UndirectedEdge[34, 130] -> 
             RGBColor[
              0.2444860062107015, 0.3743006722085195, 0.9372344884178412], 
             UndirectedEdge[157, 174] -> 
             RGBColor[
              0.4695477072718456, 0.5782865532361309, 0.9519231309391665], 
             UndirectedEdge[131, 180] -> 
             RGBColor[
              0.811663417266584, 0.70990288285835, 0.6053916520008711], 
             UndirectedEdge[3, 48] -> 
             RGBColor[
              0.29038303180772673`, 0.42176872223911466`, 0.9398765460393633],
              UndirectedEdge[49, 67] -> 
             RGBColor[
              0.8292269673761329, 0.22565685535753427`, 0.17562108300751042`],
              UndirectedEdge[79, 190] -> 
             RGBColor[
              0.19183760716220638`, 0.3189638667072519, 0.9342362399783559], 
             UndirectedEdge[13, 82] -> 
             RGBColor[
              0.34829886890839834`, 0.4761007070634601, 0.9434142738316145], 
             UndirectedEdge[68, 138] -> 
             RGBColor[
              0.8842002449557951, 0.7898038345132208, 0.6173834589873493], 
             UndirectedEdge[153, 160] -> 
             RGBColor[
              0.4763409264473496, 0.5834024868973917, 0.9525681926827152], 
             UndirectedEdge[178, 183] -> 
             RGBColor[
              0.8874176158778669, 0.6233741459180975, 0.46398946432897215`], 
             UndirectedEdge[2, 166] -> 
             RGBColor[
              0.3840226301972896, 0.5070428335634479, 0.9456905603116609], 
             UndirectedEdge[32, 53] -> 
             RGBColor[
              0.2232819677009355, 0.3520138833210643, 0.9360269497932738], 
             UndirectedEdge[26, 184] -> 
             RGBColor[
              0.38376793461067366`, 0.5068222290476936, 0.9456743313341002], 
             UndirectedEdge[61, 115] -> 
             RGBColor[
              0.2696754646738146, 0.40077639015716227`, 0.938668990812851], 
             UndirectedEdge[146, 178] -> 
             RGBColor[
              0.8692632098101054, 0.8986103712740543, 0.9813214481021706], 
             UndirectedEdge[88, 102] -> 
             RGBColor[
              0.5430147651889159, 0.6366549305319157, 0.9584949846187718], 
             UndirectedEdge[118, 159] -> 
             RGBColor[
              0.852865483210531, 0.4279441020790433, 0.443409538968764], 
             UndirectedEdge[62, 75] -> 
             RGBColor[
              0.3201980535903144, 0.44948818207116104`, 0.9417069408010099], 
             UndirectedEdge[89, 197] -> 
             RGBColor[
              0.865633819989058, 0.5820964594429976, 0.4626465164661172], 
             UndirectedEdge[85, 146] -> 
             RGBColor[
              0.578124805971577, 0.6635021636474746, 0.9622403310784291], 
             UndirectedEdge[170, 190] -> 
             RGBColor[
              0.1810362129620878, 0.3076109165549801, 0.93362111655789], 
             UndirectedEdge[82, 101] -> 
             RGBColor[
              0.2852213829706352, 0.4162052116877847, 0.9395876612614353], 
             UndirectedEdge[7, 73] -> 
             RGBColor[
              0.3217974307185043, 0.4517031252435637, 0.941778474399676], 
             UndirectedEdge[19, 34] -> 
             RGBColor[
              0.25807475059694696`, 0.38858330413461983`, 0.938008347307892], 
             UndirectedEdge[56, 170] -> 
             RGBColor[
              0.1806461819290649, 0.30720096920987716`, 0.9335989048675586], 
             UndirectedEdge[32, 187] -> 
             RGBColor[
              0.2589893983893689, 0.38954465695647483`, 0.9380604351465702], 
             UndirectedEdge[74, 169] -> 
             RGBColor[
              0.28768269698087445`, 0.4197031330363533, 0.9396944760534252], 
             UndirectedEdge[55, 147] -> 
             RGBColor[
              0.41653896028796467`, 0.5344634711076623, 0.9479678683591656], 
             UndirectedEdge[49, 143] -> 
             RGBColor[
              0.8300912165420485, 0.23229985316316096`, 0.17644868898482102`],
              UndirectedEdge[28, 77] -> 
             RGBColor[
              0.29758543140917015`, 0.4301115347901189, 0.9402584221293339], 
             UndirectedEdge[122, 153] -> 
             RGBColor[
              0.7894542010597019, 0.8310300259596766, 0.7166537981174088], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.45346195936104267`, 0.5636403822236367, 0.9510953047712845], 
             UndirectedEdge[16, 199] -> 
             RGBColor[
              0.29762489558060606`, 0.42883871402717555`, 0.9403087925207747],
              UndirectedEdge[64, 180] -> 
             RGBColor[
              0.6733354003460714, 0.7444313569668306, 0.9682823563661463], 
             UndirectedEdge[38, 128] -> 
             RGBColor[
              0.9271948937048214, 0.742224726788967, 0.2736818311730274], 
             UndirectedEdge[46, 98] -> 
             RGBColor[
              0.7856154181292234, 0.8320307685883754, 0.9456185242307917], 
             UndirectedEdge[68, 142] -> 
             RGBColor[
              0.7482569303671527, 0.8035288216790438, 0.9754818662750824], 
             UndirectedEdge[5, 20] -> 
             RGBColor[
              0.2538041540046914, 0.3840946363446963, 0.9377651431497445], 
             UndirectedEdge[169, 200] -> 
             RGBColor[
              0.2545855584826314, 0.3849159419949167, 0.9378096429787789], 
             UndirectedEdge[27, 133] -> 
             RGBColor[
              0.6412015723944939, 0.2567918854277903, 0.42640249711352196`], 
             UndirectedEdge[32, 135] -> 
             RGBColor[
              0.23421532693659433`, 0.36350553709275546`, 0.9366495884272892],
              UndirectedEdge[144, 190] -> 
             RGBColor[
              0.6309129511153266, 0.3923456422820542, 0.44568380214781717`], 
             UndirectedEdge[62, 126] -> 
             RGBColor[
              0.33172983127376465`, 0.4616088115734021, 0.9423636584803461], 
             UndirectedEdge[55, 62] -> 
             RGBColor[
              0.35430836392456, 0.4813058296004574, 0.9437971935400564], 
             UndirectedEdge[62, 76] -> 
             RGBColor[
              0.3162924905225524, 0.44538318765994256`, 0.9414845247620637], 
             UndirectedEdge[157, 181] -> 
             RGBColor[
              0.7710073552893554, 0.8197903509371063, 0.9338398508674235], 
             UndirectedEdge[64, 82] -> 
             RGBColor[
              0.4706005281918093, 0.5774357827163821, 0.9524772470296884], 
             UndirectedEdge[142, 153] -> 
             RGBColor[
              0.6134295605638427, 0.6970487778093326, 0.9627105685555573], 
             UndirectedEdge[21, 109] -> 
             RGBColor[
              0.32687230511240406`, 0.45754209443377936`, 0.9420489921333002],
              UndirectedEdge[66, 198] -> 
             RGBColor[
              0.6938904051885131, 0.7607917253864516, 0.97012416888083], 
             UndirectedEdge[141, 198] -> 
             RGBColor[
              0.5277497041986612, 0.6241140740098087, 0.9572340887790165], 
             UndirectedEdge[10, 28] -> 
             RGBColor[
              0.292046399990443, 0.42428966157416065`, 0.9399429824843], 
             UndirectedEdge[31, 151] -> 
             RGBColor[
              0.6011924048521665, 0.6814178617192261, 0.9646228375029955], 
             UndirectedEdge[111, 142] -> 
             RGBColor[
              0.5506924295205754, 0.6461159485528629, 0.957771671786148], 
             UndirectedEdge[111, 181] -> 
             RGBColor[
              0.7224128584245553, 0.7803391492251253, 0.9300143140667192], 
             UndirectedEdge[86, 101] -> 
             RGBColor[
              0.3219019660862388, 0.44797608916280746`, 0.9419249155821955], 
             UndirectedEdge[119, 144] -> 
             RGBColor[
              0.7593033875373049, 0.5094852557802381, 0.45413147471771587`], 
             UndirectedEdge[5, 102] -> 
             RGBColor[
              0.32802099544168023`, 0.45608332647208405`, 0.9422120278540836],
              UndirectedEdge[157, 185] -> 
             RGBColor[
              0.6636290641812901, 0.7358542351382649, 0.9679948360219639], 
             UndirectedEdge[13, 110] -> 
             RGBColor[
              0.49151316787654187`, 0.5960264789351953, 0.9536779249552072], 
             UndirectedEdge[32, 82] -> 
             RGBColor[
              0.27687504662639884`, 0.4074326830017036, 0.9391123497539292], 
             UndirectedEdge[12, 23] -> 
             RGBColor[
              0.7887708920716545, 0.8309004872015715, 0.7514495100334264], 
             UndirectedEdge[53, 130] -> 
             RGBColor[
              0.22431818084808952`, 0.35310300903843134`, 0.9360859605990643],
              UndirectedEdge[74, 80] -> 
             RGBColor[
              0.46133983359188224`, 0.5689367397653611, 0.9518870537804123], 
             UndirectedEdge[35, 185] -> 
             RGBColor[
              0.8039733137479249, 0.8469379641216965, 0.9810567615537757], 
             UndirectedEdge[117, 196] -> 
             RGBColor[
              0.6370858970808988, 0.7141609169041846, 0.966003973679034], 
             UndirectedEdge[22, 181] -> 
             RGBColor[
              0.8910578733822835, 0.5575636367110436, 0.4299003396380736], 
             UndirectedEdge[143, 197] -> 
             RGBColor[
              0.8435046260386568, 0.41200177766559354`, 0.4414555753478633], 
             UndirectedEdge[16, 124] -> 
             RGBColor[
              0.3070078817138632, 0.43870082736891025`, 0.9408431397001796], 
             UndirectedEdge[182, 191] -> 
             RGBColor[
              0.2726772055917506, 0.4039314101832797, 0.9388399355174497], 
             UndirectedEdge[98, 146] -> 
             RGBColor[
              0.8847914583012635, 0.9101913135735867, 0.9550361738224766], 
             UndirectedEdge[156, 183] -> 
             RGBColor[
              0.8802215684635839, 0.6177519614860875, 0.46731617013970106`], 
             UndirectedEdge[6, 13] -> 
             RGBColor[
              0.35902556110322426`, 0.48539162870339236`, 0.9440977691730272],
              UndirectedEdge[50, 100] -> 
             RGBColor[
              0.2280232863629279, 0.35699730985178435`, 0.9362969608769219], 
             UndirectedEdge[13, 175] -> 
             RGBColor[
              0.34919860302112393`, 0.4768800115299515, 0.9434716040936737], 
             UndirectedEdge[62, 116] -> 
             RGBColor[
              0.37290872785323614`, 0.4974165299540027, 0.9449823922819357], 
             UndirectedEdge[120, 171] -> 
             RGBColor[
              0.9156195043648556, 0.8842880492213061, 0.6372222517571104], 
             UndirectedEdge[72, 139] -> 
             RGBColor[
              0.24951735884561907`, 0.3795889428339999, 0.9375210165071806], 
             UndirectedEdge[6, 83] -> 
             RGBColor[
              0.29795007881864144`, 0.4276003661015726, 0.9403851677491978], 
             UndirectedEdge[118, 190] -> 
             RGBColor[
              0.5465072945042451, 0.6199622709372278, 0.9625693523456647], 
             UndirectedEdge[36, 200] -> 
             RGBColor[
              0.24218408124275126`, 0.3718812031167312, 0.9371033971963092], 
             UndirectedEdge[16, 161] -> 
             RGBColor[
              0.3158101253960152, 0.4479525435733356, 0.9413444144561256], 
             UndirectedEdge[2, 169] -> 
             RGBColor[
              0.3248517995873511, 0.4524484986194894, 0.942042670520618], 
             UndirectedEdge[107, 111] -> 
             RGBColor[
              0.5638634248724134, 0.6564277480338845, 0.9590690379639482], 
             UndirectedEdge[127, 180] -> 
             RGBColor[
              0.5228279063856032, 0.618665804983113, 0.9574221323238906], 
             UndirectedEdge[138, 156] -> 
             RGBColor[
              0.9168097113153278, 0.8158057378279282, 0.6204937789995357], 
             UndirectedEdge[72, 93] -> 
             RGBColor[
              0.23701205160573985`, 0.3664450720426131, 0.9368088577598136], 
             UndirectedEdge[137, 187] -> 
             RGBColor[
              0.2665071069572168, 0.39744624531153616`, 0.938488557528056], 
             UndirectedEdge[40, 121] -> 
             RGBColor[
              0.5171284633430432, 0.6188672087704971, 0.9551293934197934], 
             UndirectedEdge[98, 178] -> 
             RGBColor[
              0.957960137429429, 0.968167319845601, 0.9560467009664877], 
             UndirectedEdge[10, 186] -> 
             RGBColor[
              0.28567319780598677`, 0.4175910219939398, 0.939580038048203], 
             UndirectedEdge[63, 91] -> 
             RGBColor[
              0.5953350475574752, 0.6767809281925967, 0.9640487060966569], 
             UndirectedEdge[125, 195] -> 
             RGBColor[
              0.17894341419620807`, 0.3054112523609348, 0.9335019347641915], 
             UndirectedEdge[86, 180] -> 
             RGBColor[
              0.5580138830704554, 0.6491421294889225, 0.9596641516445119], 
             UndirectedEdge[137, 186] -> 
             RGBColor[
              0.2661087370017966, 0.3970275332302755, 0.9384658709484304], 
             UndirectedEdge[33, 44] -> 
             RGBColor[
              0.3032320659672701, 0.4347249229295589, 0.9406283792341544], 
             UndirectedEdge[14, 193] -> 
             RGBColor[
              0.36672963099697153`, 0.49206450682754455`, 0.9445886656942154],
              UndirectedEdge[11, 28] -> 
             RGBColor[
              0.2703195386510599, 0.4014533527438959, 0.9387056698730332], 
             UndirectedEdge[85, 151] -> 
             RGBColor[
              0.35601576258697687`, 0.48278469250549083`, 0.9439059874730323],
              UndirectedEdge[175, 199] -> 
             RGBColor[
              0.2963432017196842, 0.4277285752246516, 0.9402271241213142], 
             UndirectedEdge[146, 196] -> 
             RGBColor[
              0.6456339866715997, 0.7208387494603272, 0.9668559673629961], 
             UndirectedEdge[20, 77] -> 
             RGBColor[
              0.2628976545910799, 0.3936524820222284, 0.9382830045555108], 
             UndirectedEdge[27, 56] -> 
             RGBColor[
              0.22783801477683696`, 0.3568025776679057, 0.9362864099341788], 
             UndirectedEdge[101, 175] -> 
             RGBColor[
              0.2861211170833608, 0.41698451615427623`, 0.9396449915234946], 
             UndirectedEdge[21, 85] -> 
             RGBColor[
              0.3381783439476214, 0.46733481701480994`, 0.9427694029303426], 
             UndirectedEdge[150, 194] -> 
             RGBColor[
              0.31572797791144636`, 0.44550227419337246`, 0.9414262912319082],
              UndirectedEdge[61, 160] -> 
             RGBColor[
              0.3202543943304065, 0.44857871983620956`, 0.9417456174400596], 
             UndirectedEdge[24, 149] -> 
             RGBColor[
              0.20624750544947348`, 0.3341095834474904, 0.9350568623682817], 
             UndirectedEdge[14, 186] -> 
             RGBColor[
              0.34940158280640243`, 0.47458578186823513`, 0.9435749780704197],
              UndirectedEdge[111, 126] -> 
             RGBColor[
              0.3838604005570612, 0.5065667960959406, 0.9457392221700909], 
             UndirectedEdge[35, 88] -> 
             RGBColor[
              0.775283955250752, 0.8245256192165048, 0.9781972744160757], 
             UndirectedEdge[94, 111] -> 
             RGBColor[
              0.43931163123225564`, 0.554736492921887, 0.9492673764797304], 
             UndirectedEdge[133, 162] -> 
             RGBColor[
              0.8765856501368406, 0.44964429041426807`, 0.41798785096875907`],
              UndirectedEdge[124, 199] -> 
             RGBColor[
              0.2816714935465845, 0.4133849770946037, 0.939352146910621], 
             UndirectedEdge[54, 105] -> 
             RGBColor[
              0.3080083942884021, 0.4378802673814718, 0.9409686664381117], 
             UndirectedEdge[64, 162] -> 
             RGBColor[
              0.8027519456818715, 0.845632128982279, 0.9386302937530759], 
             UndirectedEdge[57, 66] -> 
             RGBColor[
              0.5260989516337345, 0.6228771288818142, 0.9570472794276266], 
             UndirectedEdge[16, 137] -> 
             RGBColor[
              0.2865741831678942, 0.41722371462578045`, 0.9396794707969347], 
             UndirectedEdge[44, 50] -> 
             RGBColor[
              0.2628281872337618, 0.3935794674252022, 0.9382790484922793], 
             UndirectedEdge[153, 167] -> 
             RGBColor[
              0.7506229237957682, 0.8050180016109936, 0.9761649358064053], 
             UndirectedEdge[165, 187] -> 
             RGBColor[
              0.2508650284302595, 0.38100542901464385`, 0.9375977642963274], 
             UndirectedEdge[32, 83] -> 
             RGBColor[
              0.2455000054496245, 0.37536644969989263`, 0.9372922341744203], 
             UndirectedEdge[6, 187] -> 
             RGBColor[
              0.3114394717583858, 0.44177857335815474`, 0.9411533687213477], 
             UndirectedEdge[66, 141] -> 
             RGBColor[
              0.5254792907329107, 0.622340409754583, 0.9570077951829706], 
             UndirectedEdge[23, 87] -> 
             RGBColor[
              0.9907768608924232, 0.9889849826208208, 0.6957320893038507], 
             UndirectedEdge[85, 152] -> 
             RGBColor[
              0.320947319253029, 0.44991323932493577`, 0.9417628821181223], 
             UndirectedEdge[26, 74] -> 
             RGBColor[
              0.3495927399015075, 0.4766700360070217, 0.9435169060307154], 
             UndirectedEdge[81, 172] -> 
             RGBColor[
              0.7851552645502801, 0.8282289520022286, 0.7727853942333442], 
             UndirectedEdge[54, 73] -> 
             RGBColor[
              0.28297059999413937`, 0.41475042033909004`, 0.9394261291009534],
              UndirectedEdge[135, 165] -> 
             RGBColor[
              0.22609095697748494`, 0.3549663091509244, 0.9361869175770461], 
             UndirectedEdge[46, 109] -> 
             RGBColor[
              0.4676427269643195, 0.5755488960812328, 0.9521022706897019], 
             UndirectedEdge[40, 171] -> 
             RGBColor[
              0.6830257915160596, 0.7504348777708634, 0.9705035877143484], 
             UndirectedEdge[113, 167] -> 
             RGBColor[
              0.9077889348257765, 0.7877285014564059, 0.6151514893253305], 
             UndirectedEdge[103, 162] -> 
             RGBColor[
              0.9038275928696831, 0.6466946914547808, 0.4435914409291628], 
             UndirectedEdge[37, 119] -> 
             RGBColor[
              0.3779360600643469, 0.4878548266230827, 0.9465383122915882], 
             UndirectedEdge[71, 184] -> 
             RGBColor[
              0.3307081584442233, 0.45915751757499346`, 0.9423559109556644], 
             UndirectedEdge[107, 142] -> 
             RGBColor[
              0.6540600421097872, 0.7296534252184859, 0.9661696460739697], 
             UndirectedEdge[136, 143] -> 
             RGBColor[
              0.8498678524467502, 0.3315757262103135, 0.19331268304312726`], 
             UndirectedEdge[3, 5] -> 
             RGBColor[
              0.27293521528598386`, 0.4042025947306783, 0.9388546287878452], 
             UndirectedEdge[24, 118] -> 
             RGBColor[
              0.5461172648909147, 0.6195523250843118, 0.9625471407361825], 
             UndirectedEdge[142, 185] -> 
             RGBColor[
              0.7052311845538637, 0.7696287106108853, 0.971269907331281], 
             UndirectedEdge[3, 28] -> 
             RGBColor[
              0.2792200802478043, 0.4108083862890054, 0.9392125425497964], 
             UndirectedEdge[43, 49] -> 
             RGBColor[
              0.8484894518822184, 0.3737167521458401, 0.1940668599244025], 
             UndirectedEdge[19, 60] -> 
             RGBColor[
              0.25917942342753286`, 0.38974438531986844`, 0.9380712567913769],
              UndirectedEdge[87, 110] -> 
             RGBColor[
              0.7965007991763076, 0.8397612062456058, 0.9055025365037817], 
             UndirectedEdge[107, 185] -> 
             RGBColor[
              0.7184021799057017, 0.779940510091907, 0.9725672735090811], 
             UndirectedEdge[66, 81] -> 
             RGBColor[
              0.633976904061278, 0.7129754213419766, 0.9648440654867796], 
             UndirectedEdge[63, 112] -> 
             RGBColor[
              0.32715088352733546`, 0.45710875455411837`, 0.94209144443096], 
             UndirectedEdge[59, 193] -> 
             RGBColor[
              0.38274569330621644`, 0.5059368150091147, 0.9456091950221126], 
             UndirectedEdge[110, 180] -> 
             RGBColor[
              0.6645475989229954, 0.737297023885635, 0.9675905484473445], 
             UndirectedEdge[21, 196] -> 
             RGBColor[
              0.4056875246476441, 0.5246714028276624, 0.9473850392149095], 
             UndirectedEdge[24, 190] -> 
             RGBColor[
              0.1793170324527155, 0.3058039488372898, 0.9335232117711809], 
             UndirectedEdge[44, 60] -> 
             RGBColor[
              0.2686906729944792, 0.399741311662782, 0.9386129083835817], 
             UndirectedEdge[20, 106] -> 
             RGBColor[
              0.25022657945820426`, 0.38033437866501096`, 0.9375614055718693],
              UndirectedEdge[75, 139] -> 
             RGBColor[
              0.26665982071221705`, 0.39760675715065275`, 0.9384972543504835],
              UndirectedEdge[4, 81] -> 
             RGBColor[
              0.6906097692395512, 0.7572174460449604, 0.9704887002235348], 
             UndirectedEdge[79, 197] -> 
             RGBColor[
              0.5464425729840517, 0.6229880683860871, 0.9620969735266468], 
             UndirectedEdge[66, 90] -> 
             RGBColor[
              0.5397844128240585, 0.6347307875135932, 0.9579193049130958], 
             UndirectedEdge[14, 15] -> 
             RGBColor[
              0.3709417656089321, 0.49571284612038347`, 0.9448570591870451], 
             UndirectedEdge[14, 48] -> 
             RGBColor[
              0.36693773655078116`, 0.49224475739856516`, 0.9446019259960836],
              UndirectedEdge[122, 144] -> 
             RGBColor[
              0.901990039676534, 0.619375718064703, 0.29208824069422046`], 
             UndirectedEdge[80, 121] -> 
             RGBColor[
              0.5812862861253769, 0.6709534195821745, 0.9601801322470673], 
             UndirectedEdge[79, 170] -> 
             RGBColor[
              0.1931667580582484, 0.32036088857202627`, 0.934311933155583], 
             UndirectedEdge[91, 95] -> 
             RGBColor[
              0.9087217160297558, 0.9082261327367556, 0.679871771253554], 
             UndirectedEdge[48, 193] -> 
             RGBColor[
              0.3168945933506373, 0.44889990200011176`, 0.9414132211627845], 
             UndirectedEdge[67, 162] -> 
             RGBColor[
              0.8731042173971515, 0.4228844728034631, 0.4146540270455168], 
             UndirectedEdge[65, 87] -> 
             RGBColor[
              0.9550341089343712, 0.965005825208276, 0.9206936459458361], 
             UndirectedEdge[98, 121] -> 
             RGBColor[
              0.7580819454747305, 0.8096778551186503, 0.9434509884049964], 
             UndirectedEdge[161, 187] -> 
             RGBColor[
              0.2957430491853379, 0.4281750742590913, 0.9401535011872468], 
             UndirectedEdge[68, 122] -> 
             RGBColor[
              0.924281570863012, 0.9375100698293877, 0.7294250958369339], 
             UndirectedEdge[19, 90] -> 
             RGBColor[
              0.32617520722218063`, 0.45283835871142575`, 0.9421546927268274],
              UndirectedEdge[80, 168] -> 
             RGBColor[
              0.7792447125486042, 0.8280111263190817, 0.9760255070982982], 
             UndirectedEdge[109, 194] -> 
             RGBColor[
              0.3430360942965171, 0.47154235620939167`, 0.9430789344870343], 
             UndirectedEdge[44, 57] -> 
             RGBColor[
              0.3220009955988029, 0.4509816264225601, 0.9418243188335629], 
             UndirectedEdge[109, 151] -> 
             RGBColor[
              0.34470972375175946`, 0.47299196992446024`, 0.9431855766759899],
              UndirectedEdge[122, 138] -> 
             RGBColor[
              0.9528570018424507, 0.8395978867219851, 0.360717102170288], 
             UndirectedEdge[138, 192] -> 
             RGBColor[
              0.8491378919784113, 0.32004855046860603`, 0.19237048844023447`],
              UndirectedEdge[31, 46] -> 
             RGBColor[
              0.7241254080647266, 0.7839747878759986, 0.9735395315167075], 
             UndirectedEdge[101, 165] -> 
             RGBColor[
              0.23537363183733478`, 0.36472298898420613`, 0.9367155521778278],
              UndirectedEdge[76, 105] -> 
             RGBColor[
              0.3097803157470692, 0.4397426691808402, 0.94106957474386], 
             UndirectedEdge[6, 199] -> 
             RGBColor[
              0.3061701598017846, 0.4362401923980924, 0.9408532892006678], 
             UndirectedEdge[83, 175] -> 
             RGBColor[
              0.2881231207365411, 0.41908874892813175`, 0.9397590026698441], 
             UndirectedEdge[139, 182] -> 
             RGBColor[
              0.2571409182934481, 0.38760178717525484`, 0.9379551669396888], 
             UndirectedEdge[89, 149] -> 
             RGBColor[
              0.6471841581056663, 0.3982840813972412, 0.44509512783199057`], 
             UndirectedEdge[53, 163] -> 
             RGBColor[
              0.2222172147783616, 0.3508947604902047, 0.935966313689494], 
             UndirectedEdge[8, 96] -> 
             RGBColor[
              0.3771970335719591, 0.5008951438379817, 0.9452642694982989], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.3028942075372073, 0.43437709498723787`, 0.9406088720414547], 
             UndirectedEdge[55, 191] -> 
             RGBColor[
              0.31630641834476525`, 0.445754027687974, 0.9414722756672911], 
             UndirectedEdge[122, 181] -> 
             RGBColor[
              0.9886341161577883, 0.9875460745600706, 0.6910581517385923], 
             UndirectedEdge[130, 177] -> 
             RGBColor[
              0.26541543308332344`, 0.3962988268539529, 0.9384263883159245], 
             UndirectedEdge[25, 131] -> 
             RGBColor[
              0.93909008289769, 0.7879991811183886, 0.30513287379478254`], 
             UndirectedEdge[19, 33] -> 
             RGBColor[
              0.29372081640032377`, 0.4247279965866454, 0.9400867276419496], 
             UndirectedEdge[1, 89] -> 
             RGBColor[
              0.8887656846103759, 0.567689263625524, 0.23040845432083734`], 
             UndirectedEdge[123, 127] -> 
             RGBColor[
              0.2860095413584047, 0.4167572429724312, 0.9396426650906227], 
             UndirectedEdge[40, 173] -> 
             RGBColor[
              0.7433614186788604, 0.7950716369237336, 0.832834751651226], 
             UndirectedEdge[17, 106] -> 
             RGBColor[
              0.25694510996125053`, 0.38739598020314986`, 0.9379440159448427],
              UndirectedEdge[51, 158] -> 
             RGBColor[
              0.267702506048196, 0.39870268554883526`, 0.9385566337378528], 
             UndirectedEdge[20, 189] -> 
             RGBColor[
              0.2283963086796351, 0.35738937995762443`, 0.9363182039460214], 
             UndirectedEdge[48, 140] -> 
             RGBColor[
              0.3113031778693076, 0.4437571221637065, 0.9410679174089878], 
             UndirectedEdge[11, 189] -> 
             RGBColor[
              0.2386268283641832, 0.36814230479849686`, 0.9369008169073587], 
             UndirectedEdge[40, 169] -> 
             RGBColor[
              0.38208210782853824`, 0.5009795735314966, 0.9459763978166744], 
             UndirectedEdge[94, 167] -> 
             RGBColor[0.666701611701555, 0.7359313939081493, 0.9698223518406],
              UndirectedEdge[81, 198] -> 
             RGBColor[
              0.6362473175270285, 0.7147490855972023, 0.9650703590828255], 
             UndirectedEdge[34, 60] -> 
             RGBColor[
              0.25285259350547307`, 0.38309448592759754`, 0.9377109531870217],
              UndirectedEdge[13, 101] -> 
             RGBColor[
              0.3149218240784437, 0.4419302409877936, 0.941480147105756], 
             UndirectedEdge[31, 117] -> 
             RGBColor[
              0.8147533586460658, 0.8554575003050673, 0.9821051874244302], 
             UndirectedEdge[94, 105] -> 
             RGBColor[
              0.3806688871734759, 0.5041379899202462, 0.945476862771782], 
             UndirectedEdge[125, 190] -> 
             RGBColor[
              0.179333445229231, 0.3058211997060377, 0.933524146454523], 
             UndirectedEdge[79, 119] -> 
             RGBColor[
              0.3844232617951737, 0.4946732869545277, 0.9469077488332039], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.2600890189665118, 0.39070042790302345`, 0.9381230569116956], 
             UndirectedEdge[156, 178] -> 
             RGBColor[
              0.9316378178168464, 0.9481531008980535, 0.987322033962275], 
             UndirectedEdge[95, 131] -> 
             RGBColor[
              0.9394422371635587, 0.7891870801469172, 0.306500926618929], 
             UndirectedEdge[49, 133] -> 
             RGBColor[
              0.8309676837459775, 0.23903676416293673`, 0.17728799496913153`],
              UndirectedEdge[34, 44] -> 
             RGBColor[
              0.2675860001638932, 0.3985802304775334, 0.9385499989000968], 
             UndirectedEdge[24, 125] -> 
             RGBColor[
              0.17894341561590066`, 0.30541125385312173`, 0.9335019348450408],
              UndirectedEdge[95, 129] -> 
             RGBColor[
              0.9849427513832404, 0.9608705061848779, 0.39600586175704294`], 
             UndirectedEdge[13, 16] -> 
             RGBColor[
              0.35048029688204574`, 0.4779901503324755, 0.9435532724931343], 
             UndirectedEdge[13, 199] -> 
             RGBColor[
              0.3251439087147671, 0.45267430005816894`, 0.9420622797035756], 
             UndirectedEdge[121, 196] -> 
             RGBColor[
              0.5189244738450667, 0.6203252910053908, 0.955270781945516], 
             UndirectedEdge[26, 40] -> 
             RGBColor[
              0.4439921507491714, 0.557946476502165, 0.9497988277939646], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.31163329513552707`, 0.44101997430243733`, 0.9411996419147166],
              UndirectedEdge[54, 126] -> 
             RGBColor[
              0.29001572662104147`, 0.4221552951107917, 0.9398273386400247], 
             UndirectedEdge[16, 193] -> 
             RGBColor[
              0.3198238857723562, 0.4514371078652866, 0.9415998730856248], 
             UndirectedEdge[85, 150] -> 
             RGBColor[
              0.3215409260409259, 0.45053715769585945`, 0.9417966871465304], 
             UndirectedEdge[26, 169] -> 
             RGBColor[
              0.3344928369204973, 0.4607990805848347, 0.9426569888942514], 
             UndirectedEdge[22, 79] -> 
             RGBColor[
              0.6309372892797696, 0.33887224059181326`, 0.43842350367765265`],
              UndirectedEdge[27, 67] -> 
             RGBColor[
              0.6377201396548048, 0.23003206781698532`, 0.42306867319027985`],
              UndirectedEdge[49, 95] -> 
             RGBColor[
              0.8830336731086973, 0.49298775428550434`, 0.24571556835587194`],
              UndirectedEdge[147, 178] -> 
             RGBColor[
              0.7115638776908443, 0.7729379814418316, 0.9672966305905184], 
             UndirectedEdge[1, 136] -> 
             RGBColor[
              0.9331596302538536, 0.7720124271387454, 0.2686954588022206], 
             UndirectedEdge[65, 110] -> 
             RGBColor[
              0.7635603354949406, 0.815471840469592, 0.9772401996765336], 
             UndirectedEdge[77, 106] -> 
             RGBColor[
              0.2877229919008626, 0.4197454855521064, 0.9396967707895075], 
             UndirectedEdge[25, 64] -> 
             RGBColor[
              0.8007620659771775, 0.8225276552268693, 0.6680235781600576], 
             UndirectedEdge[82, 187] -> 
             RGBColor[
              0.3007127795635599, 0.4324876517182224, 0.9404698733799348], 
             UndirectedEdge[167, 188] -> 
             RGBColor[
              0.7899648841688349, 0.8366160464867711, 0.9794955855762202], 
             UndirectedEdge[13, 137] -> 
             RGBColor[
              0.31409319630205523`, 0.44105930065677384`, 0.9414329579797356],
              UndirectedEdge[37, 125] -> 
             RGBColor[
              0.18497678859456473`, 0.3117527113916389, 0.9338455265106003], 
             UndirectedEdge[105, 182] -> 
             RGBColor[
              0.30416697639606216`, 0.43384269361666083`, 0.9407499033720115],
              UndirectedEdge[111, 116] -> 
             RGBColor[
              0.42503929713653266`, 0.5423745144765412, 0.9483579559716804], 
             UndirectedEdge[146, 179] -> 
             RGBColor[
              0.802014133137712, 0.8452588034311341, 0.9809009316091206], 
             UndirectedEdge[9, 63] -> 
             RGBColor[
              0.3067096536024727, 0.43562372585425413`, 0.9409273466268289], 
             UndirectedEdge[38, 120] -> 
             RGBColor[
              0.960788560046435, 0.8793927471320053, 0.302171389549849], 
             UndirectedEdge[71, 81] -> 
             RGBColor[
              0.43330857195401157`, 0.5446846710814149, 0.9498164169017225], 
             UndirectedEdge[68, 181] -> 
             RGBColor[
              0.9199773592711327, 0.9377520223513063, 0.9477245085556535], 
             UndirectedEdge[114, 158] -> 
             RGBColor[
              0.23522624458781927`, 0.364568075640074, 0.9367071586920077], 
             UndirectedEdge[118, 149] -> 
             RGBColor[
              0.5734377675010032, 0.6482679055474284, 0.9641030029427655], 
             UndirectedEdge[87, 162] -> 
             RGBColor[
              0.9854379176982261, 0.9880317806397674, 0.8813919321035765], 
             UndirectedEdge[88, 122] -> 
             RGBColor[
              0.8525664665525501, 0.8811976138560375, 0.7223536497554326], 
             UndirectedEdge[49, 162] -> 
             RGBColor[
              0.8841254900679142, 0.5075988041034252, 0.42520801020178634`], 
             UndirectedEdge[47, 116] -> 
             RGBColor[
              0.42055225492425696`, 0.5386829584696233, 0.9480181956973843], 
             UndirectedEdge[23, 95] -> 
             RGBColor[
              0.9866024805360858, 0.9658049975494172, 0.45892937586547133`], 
             UndirectedEdge[54, 115] -> 
             RGBColor[
              0.2691801918114708, 0.40025582697672574`, 0.938640785756031], 
             UndirectedEdge[62, 105] -> 
             RGBColor[
              0.3497224989411253, 0.4773337838440822, 0.9435049862784333], 
             UndirectedEdge[13, 108] -> 
             RGBColor[
              0.5796159484292636, 0.6654249189415207, 0.9620681904824614], 
             UndirectedEdge[76, 182] -> 
             RGBColor[
              0.27073696797748936`, 0.4018920974325212, 0.938729441855642], 
             UndirectedEdge[117, 171] -> 
             RGBColor[
              0.8267342564377225, 0.8650107429913272, 0.9832479361512722], 
             UndirectedEdge[40, 46] -> 
             RGBColor[
              0.5446619359975361, 0.6412201222402223, 0.9572969292455886], 
             UndirectedEdge[19, 177] -> 
             RGBColor[
              0.2790041774695689, 0.41058145878005325`, 0.9392002472059755], 
             UndirectedEdge[64, 87] -> 
             RGBColor[
              0.8052886005993835, 0.8468955393268014, 0.9061943444225835], 
             UndirectedEdge[62, 107] -> 
             RGBColor[
              0.5117328555891169, 0.611469763511346, 0.9556934742742034], 
             UndirectedEdge[53, 148] -> 
             RGBColor[
              0.20810268194188267`, 0.3360594915659958, 0.9351625119250367], 
             UndirectedEdge[76, 111] -> 
             RGBColor[
              0.368423059805849, 0.49034117218248097`, 0.9448600884518084], 
             UndirectedEdge[11, 48] -> 
             RGBColor[
              0.2814824902109824, 0.4124136886940051, 0.9393696733626], 
             UndirectedEdge[96, 111] -> 
             RGBColor[
              0.3833462518703272, 0.5060263932272735, 0.9457099421629962], 
             UndirectedEdge[168, 198] -> 
             RGBColor[
              0.8173765882647961, 0.8581441256038294, 0.9795908811512684], 
             UndirectedEdge[118, 128] -> 
             RGBColor[
              0.901444520807011, 0.7626039594239429, 0.6105848646794676], 
             UndirectedEdge[56, 129] -> 
             RGBColor[
              0.5845933454317087, 0.6420998957641366, 0.6750810838088802], 
             UndirectedEdge[53, 100] -> 
             RGBColor[
              0.21261327393044743`, 0.34080040973402737`, 0.9354193834659627],
              UndirectedEdge[129, 143] -> 
             RGBColor[
              0.8772855250898838, 0.4335162754923927, 0.2505870010613686], 
             UndirectedEdge[18, 160] -> 
             RGBColor[
              0.34254111760690553`, 0.47111363227910186`, 0.9430473950100628],
              UndirectedEdge[68, 111] -> 
             RGBColor[
              0.6580603131297789, 0.7303031444944423, 0.9683812581650608], 
             UndirectedEdge[51, 166] -> 
             RGBColor[
              0.33653220976868264`, 0.46344910853990606`, 0.9427545820635193],
              UndirectedEdge[107, 181] -> 
             RGBColor[
              0.8257804710137671, 0.8638766258907483, 0.9384122883545408], 
             UndirectedEdge[31, 173] -> 
             RGBColor[
              0.9228248907460509, 0.93782630255951, 0.8490773539223448], 
             UndirectedEdge[135, 148] -> 
             RGBColor[
              0.2190360411775415, 0.34755114533768694`, 0.935785150559052], 
             UndirectedEdge[44, 177] -> 
             RGBColor[
              0.2885154270365152, 0.4205783851229668, 0.9397418987981803], 
             UndirectedEdge[80, 184] -> 
             RGBColor[
              0.4955150283010483, 0.599088932806033, 0.9540444790837972], 
             UndirectedEdge[65, 162] -> 
             RGBColor[
              0.9524974540168591, 0.9637424148637534, 0.9531295952763283], 
             UndirectedEdge[5, 17] -> 
             RGBColor[
              0.26052268450773763`, 0.3911562378828352, 0.9381477535227178], 
             UndirectedEdge[44, 141] -> 
             RGBColor[
              0.321381334697979, 0.45044490729532893`, 0.941784834588907], 
             UndirectedEdge[94, 174] -> 
             RGBColor[
              0.39976902935609954`, 0.5206815730777754, 0.9466939069420661], 
             UndirectedEdge[161, 193] -> 
             RGBColor[
              0.31267272742048674`, 0.4452350871371401, 0.9411445022314171], 
             UndirectedEdge[101, 124] -> 
             RGBColor[
              0.2714494089102611, 0.40264091802422836`, 0.9387700143128014], 
             UndirectedEdge[106, 189] -> 
             RGBColor[
              0.25322164598941777`, 0.3834823834875024, 0.9377319701800181], 
             UndirectedEdge[2, 80] -> 
             RGBColor[
              0.4985089361983589, 0.6016821053484971, 0.954235248247605], 
             UndirectedEdge[97, 102] -> 
             RGBColor[
              0.3273981891467483, 0.4554287175679108, 0.9421765599569466], 
             UndirectedEdge[91, 136] -> 
             RGBColor[
              0.8729121465452325, 0.773250594157032, 0.6146156000869095], 
             UndirectedEdge[59, 154] -> 
             RGBColor[
              0.7176662191262557, 0.7759253920834623, 0.911377748265729], 
             UndirectedEdge[108, 162] -> 
             RGBColor[
              0.8820669248115173, 0.9078962359074088, 0.9463287513615282], 
             UndirectedEdge[146, 147] -> 
             RGBColor[
              0.6383951985626789, 0.7149619751698173, 0.9662861034465073], 
             UndirectedEdge[99, 156] -> 
             RGBColor[
              0.7424696241286013, 0.7983584952437333, 0.9755694516963352], 
             UndirectedEdge[143, 154] -> 
             RGBColor[
              0.8760414746143801, 0.43681328017556376`, 0.40267896763816474`],
              UndirectedEdge[139, 145] -> 
             RGBColor[
              0.2284570343408142, 0.357453206477753, 0.9363216621825899], 
             UndirectedEdge[104, 123] -> 
             RGBColor[
              0.23468312728084179`, 0.36399722491481445`, 0.9366762289648454],
              UndirectedEdge[116, 126] -> 
             RGBColor[
              0.34840388541039236`, 0.4760510392042203, 0.9434261144656448], 
             UndirectedEdge[17, 28] -> 
             RGBColor[
              0.2668075494695581, 0.39776202944116235`, 0.938505667284669], 
             UndirectedEdge[89, 118] -> 
             RGBColor[
              0.8737639977332939, 0.5885792424884555, 0.4634219800772578], 
             UndirectedEdge[123, 163] -> 
             RGBColor[
              0.2417268008308885, 0.37140057241061075`, 0.9370773557533394], 
             UndirectedEdge[47, 157] -> 
             RGBColor[
              0.5046032669357259, 0.6086499170733246, 0.9541568402025347], 
             UndirectedEdge[117, 151] -> 
             RGBColor[
              0.565437397706639, 0.6532390613039136, 0.9611245836688005], 
             UndirectedEdge[69, 86] -> 
             RGBColor[
              0.39677259596818604`, 0.5180862130822859, 0.9465029768562303], 
             UndirectedEdge[73, 94] -> 
             RGBColor[
              0.35563109287921313`, 0.4810081428778644, 0.9439343254346236], 
             UndirectedEdge[61, 174] -> 
             RGBColor[
              0.3276038093333696, 0.4549444137194375, 0.9422139156652158], 
             UndirectedEdge[175, 187] -> 
             RGBColor[
              0.3016125136762855, 0.4332669561847139, 0.940527203641994], 
             UndirectedEdge[75, 134] -> 
             RGBColor[
              0.2575067829018646, 0.3879863340758565, 0.93797600238789], 
             UndirectedEdge[38, 178] -> 
             RGBColor[
              0.9536200808381681, 0.9247692797301834, 0.650059594771984], 
             UndirectedEdge[8, 179] -> 
             RGBColor[
              0.6280655556399748, 0.706255507224953, 0.9656353303034069], 
             UndirectedEdge[29, 167] -> 
             RGBColor[
              0.9544593958943188, 0.963459656199136, 0.8733980891466777], 
             UndirectedEdge[68, 185] -> 
             RGBColor[
              0.8125990681630673, 0.8538159065524649, 0.9818794937101938], 
             UndirectedEdge[79, 118] -> 
             RGBColor[
              0.5586378396004057, 0.632712242954274, 0.9632601689433578], 
             UndirectedEdge[171, 173] -> 
             RGBColor[
              0.9348057885377076, 0.9473795452457701, 0.8502201026491867], 
             UndirectedEdge[80, 166] -> 
             RGBColor[
              0.5054107612208105, 0.6076601192871327, 0.9546750264349914], 
             UndirectedEdge[109, 132] -> 
             RGBColor[
              0.2948786821955154, 0.42460409000948357`, 0.9402017631916271], 
             UndirectedEdge[118, 197] -> 
             RGBColor[
              0.9011122603260905, 0.9239864726160629, 0.9904300858939554], 
             UndirectedEdge[111, 167] -> 
             RGBColor[
              0.687885792752501, 0.7540851723545239, 0.971226039036996], 
             UndirectedEdge[113, 122] -> 
             RGBColor[
              0.9466202120897103, 0.8137405258050889, 0.35564035163633406`], 
             UndirectedEdge[119, 190] -> 
             RGBColor[
              0.3722927166990131, 0.48192331493748153`, 0.946216932235511], 
             UndirectedEdge[19, 130] -> 
             RGBColor[
              0.2508128361327613, 0.38095057160079043`, 0.9375947920221963], 
             UndirectedEdge[35, 167] -> 
             RGBColor[
              0.876824539183936, 0.9046201030499366, 0.9881135013695121], 
             UndirectedEdge[102, 112] -> 
             RGBColor[
              0.337642108559284, 0.46619572637249007`, 0.9427599360129698], 
             UndirectedEdge[134, 145] -> 
             RGBColor[
              0.21930399653046173`, 0.34783278340295676`, 0.9358004102199964],
              UndirectedEdge[109, 150] -> 
             RGBColor[
              0.31023488720570846`, 0.44074443511482886`, 0.941076276349488], 
             UndirectedEdge[147, 179] -> 
             RGBColor[
              0.6443148010184508, 0.7195864135989113, 0.9668761140974684], 
             UndirectedEdge[63, 102] -> 
             RGBColor[
              0.3633436999904507, 0.48913178357153686`, 0.9443729171645411], 
             UndirectedEdge[62, 182] -> 
             RGBColor[
              0.31067915117154543`, 0.43948321209576313`, 0.9411648533902153],
              UndirectedEdge[8, 99] -> 
             RGBColor[
              0.5061464386241231, 0.6098124694135529, 0.9543032645305172], 
             UndirectedEdge[60, 123] -> 
             RGBColor[
              0.252194354195388, 0.3824026346779154, 0.9376734674320901], 
             UndirectedEdge[7, 97] -> 
             RGBColor[
              0.3157107895654947, 0.44530567947641203`, 0.9414318491903908], 
             UndirectedEdge[130, 163] -> 
             RGBColor[
              0.23512312567678792`, 0.3644596911264634, 0.9367012862225752], 
             UndirectedEdge[127, 135] -> 
             RGBColor[
              0.2774333145415366, 0.4077430848237163, 0.9391542616607926], 
             UndirectedEdge[37, 56] -> 
             RGBColor[
              0.18496037439835666`, 0.3117354590307041, 0.9338445917464089], 
             UndirectedEdge[100, 148] -> 
             RGBColor[
              0.20930368592266696`, 0.3373218228978505, 0.9352309073250162], 
             UndirectedEdge[53, 135] -> 
             RGBColor[
              0.222345629185322, 0.35102973217386374`, 0.9359736266999984], 
             UndirectedEdge[103, 154] -> 
             RGBColor[
              0.9050363517550805, 0.647337503215628, 0.4299611695671895], 
             UndirectedEdge[63, 140] -> 
             RGBColor[
              0.32917806589633525`, 0.4592394517547229, 0.942206889467927], 
             UndirectedEdge[8, 75] -> 
             RGBColor[
              0.36617940457524284`, 0.4893149172044077, 0.9446368318260574], 
             UndirectedEdge[50, 53] -> 
             RGBColor[
              0.22682228238214364`, 0.3557349785199296, 0.9362285654769424], 
             UndirectedEdge[1, 167] -> 
             RGBColor[
              0.9367941803977453, 0.9031603919681208, 0.6421668592196352], 
             UndirectedEdge[27, 119] -> 
             RGBColor[
              0.4208137004428272, 0.5329219452602844, 0.9489801304793581], 
             UndirectedEdge[96, 126] -> 
             RGBColor[
              0.3067108401441868, 0.4397029179549527, 0.9407781006569607], 
             UndirectedEdge[102, 106] -> 
             RGBColor[
              0.32444342089519307`, 0.4523230687923987, 0.9420082902762085], 
             UndirectedEdge[16, 176] -> 
             RGBColor[
              0.30857911035131147`, 0.440352288288518, 0.9409326188466578], 
             UndirectedEdge[40, 166] -> 
             RGBColor[
              0.4412529384384768, 0.5555739084754552, 0.9496242876077174], 
             UndirectedEdge[33, 90] -> 
             RGBColor[
              0.35549444310349765`, 0.4823331517711803, 0.9438727694565298], 
             UndirectedEdge[13, 161] -> 
             RGBColor[
              0.34332913853017627`, 0.471788129604329, 0.9430979016389265], 
             UndirectedEdge[11, 106] -> 
             RGBColor[
              0.2604570991427524, 0.3910873035058834, 0.9381440185332068], 
             UndirectedEdge[88, 167] -> 
             RGBColor[
              0.8137351892886164, 0.8551855895073546, 0.9818647874444291], 
             UndirectedEdge[29, 159] -> 
             RGBColor[
              0.879643980418662, 0.4472536327034553, 0.36455016649703853`], 
             UndirectedEdge[156, 157] -> 
             RGBColor[
              0.7392642763541118, 0.795756249521131, 0.9753171149779516], 
             UndirectedEdge[171, 183] -> 
             RGBColor[
              0.8647637066900788, 0.6054262821003745, 0.46584178548434796`], 
             UndirectedEdge[100, 104] -> 
             RGBColor[
              0.21637454520909913`, 0.34475374432626316`, 0.9356335823009796],
              UndirectedEdge[108, 180] -> 
             RGBColor[
              0.7526503794757171, 0.8066954638919603, 0.9759808139745987], 
             UndirectedEdge[178, 179] -> 
             RGBColor[
              0.8751828122658775, 0.9032348097031484, 0.9819114587531318], 
             UndirectedEdge[150, 151] -> 
             RGBColor[
              0.3174016073666887, 0.4469518879084411, 0.9415329334208639], 
             UndirectedEdge[2, 121] -> 
             RGBColor[
              0.45989815510185605`, 0.5703361338584898, 0.9511956661237368], 
             UndirectedEdge[12, 14] -> 
             RGBColor[
              0.500367704585658, 0.6042677811858945, 0.954084097379875], 
             UndirectedEdge[43, 131] -> 
             RGBColor[
              0.869996471453065, 0.49619172496078556`, 0.21298460084303164`], 
             UndirectedEdge[75, 76] -> 
             RGBColor[
              0.2802558703962583, 0.4118970674079191, 0.9392715292664366], 
             UndirectedEdge[113, 138] -> 
             RGBColor[
              0.9065388861824932, 0.6660342904889218, 0.24359871478674944`], 
             UndirectedEdge[17, 20] -> 
             RGBColor[
              0.23211977265146783`, 0.3613029766732719, 0.9365302497108459], 
             UndirectedEdge[86, 187] -> 
             RGBColor[
              0.3373933626791634, 0.4642585291932452, 0.9428071277006951], 
             UndirectedEdge[8, 185] -> 
             RGBColor[
              0.6088853490181219, 0.6912717840369921, 0.9637236265565623], 
             UndirectedEdge[4, 41] -> 
             RGBColor[
              0.6772999087061907, 0.7464119016615944, 0.969440899246723], 
             UndirectedEdge[8, 107] -> 
             RGBColor[
              0.5577142065740452, 0.6512964986445926, 0.9586233652992509], 
             UndirectedEdge[149, 192] -> 
             RGBColor[
              0.622735336019854, 0.21035972130353567`, 0.4216829081916216], 
             UndirectedEdge[11, 140] -> 
             RGBColor[
              0.27568296917584306`, 0.40709065828657925`, 0.9390111093069351],
              UndirectedEdge[94, 153] -> 
             RGBColor[
              0.5020487622755229, 0.6056693221783567, 0.9542062732491396], 
             UndirectedEdge[56, 79] -> 
             RGBColor[
              0.1914475761291835, 0.31855391936214905`, 0.9342140282880245], 
             UndirectedEdge[5, 15] -> 
             RGBColor[
              0.303658911440855, 0.4349821137845143, 0.940659697404096], 
             UndirectedEdge[79, 128] -> 
             RGBColor[
              0.5467748334649722, 0.46160555519396695`, 0.5822517523121589], 
             UndirectedEdge[109, 152] -> 
             RGBColor[
              0.3096412804178116, 0.4401205167439052, 0.9410424713210799], 
             UndirectedEdge[118, 192] -> 
             RGBColor[
              0.8493151756474815, 0.40065488239475, 0.4400097604368888], 
             UndirectedEdge[99, 107] -> 
             RGBColor[
              0.615663269511703, 0.6984811954684678, 0.963146911483036], 
             UndirectedEdge[3, 189] -> 
             RGBColor[
              0.24752736996092756`, 0.37749733834360644`, 0.937407689584122], 
             UndirectedEdge[35, 138] -> 
             RGBColor[
              0.8755744905406526, 0.7829258920824524, 0.6165607268309311], 
             UndirectedEdge[12, 86] -> 
             RGBColor[
              0.4879611145029988, 0.5935218164296439, 0.9532935604305248], 
             UndirectedEdge[16, 127] -> 
             RGBColor[
              0.3222744622049885, 0.4535596740016799, 0.9417560216489524], 
             UndirectedEdge[37, 195] -> 
             RGBColor[
              0.18496037439835666`, 0.3117354590307041, 0.9338445917464089], 
             UndirectedEdge[57, 71] -> 
             RGBColor[
              0.32543061952646807`, 0.4545863786212526, 0.9420196308425695], 
             UndirectedEdge[58, 73] -> 
             RGBColor[
              0.2786440888438728, 0.4102029828035092, 0.9391797406914454], 
             UndirectedEdge[35, 153] -> 
             RGBColor[
              0.7121716897579038, 0.7743580313201439, 0.9724974227780518], 
             UndirectedEdge[35, 122] -> 
             RGBColor[
              0.9156558164478696, 0.9306321273986194, 0.7286023636805157], 
             UndirectedEdge[19, 44] -> 
             RGBColor[
              0.2739128300859531, 0.40523012986980433`, 0.9389103025044521], 
             UndirectedEdge[181, 192] -> 
             RGBColor[
              0.8729893015219696, 0.41868067569399636`, 0.41259785481910394`],
              UndirectedEdge[119, 128] -> 
             RGBColor[
              0.727229943001779, 0.6245650034241965, 0.5942324445693138], 
             UndirectedEdge[116, 153] -> 
             RGBColor[
              0.48777642817979994`, 0.593307343733011, 0.9532968527410897], 
             UndirectedEdge[186, 193] -> 
             RGBColor[
              0.29935843960625863`, 0.43124092646978174`, 0.9403862732371204],
              UndirectedEdge[22, 119] -> 
             RGBColor[
              0.7512406956376406, 0.44751187274529963`, 0.44641063184908925`],
              UndirectedEdge[85, 109] -> 
             RGBColor[
              0.34884904242599657`, 0.47657723971187865`, 0.9434493304016565],
              UndirectedEdge[98, 99] -> 
             RGBColor[
              0.7687919437411839, 0.8183727141912807, 0.944294118700548], 
             UndirectedEdge[161, 175] -> 
             RGBColor[
              0.31452843153509336`, 0.4468424047708116, 0.941262746056665], 
             UndirectedEdge[54, 61] -> 
             RGBColor[
              0.27330173727350593`, 0.40458783257840025`, 0.9388755016728139],
              UndirectedEdge[43, 154] -> 
             RGBColor[
              0.8990860971240158, 0.6139443470025971, 0.4247465241785704], 
             UndirectedEdge[87, 95] -> 
             RGBColor[
              0.9838001922594006, 0.9661152059128862, 0.6121532693347048], 
             UndirectedEdge[12, 108] -> 
             RGBColor[
              0.6825976109082605, 0.7510751508326818, 0.9696102227606116], 
             UndirectedEdge[15, 48] -> 
             RGBColor[
              0.32110672796259787`, 0.4525482412929506, 0.9416816146556142], 
             UndirectedEdge[13, 187] -> 
             RGBColor[
              0.33041322067136836`, 0.4582126810182313, 0.9423623592242556], 
             UndirectedEdge[15, 28] -> 
             RGBColor[
              0.3099437764026754, 0.4415879053428414, 0.9410176111660472], 
             UndirectedEdge[52, 134] -> 
             RGBColor[
              0.22165741455534713`, 0.35030637496243233`, 0.9359344338949436],
              UndirectedEdge[66, 172] -> 
             RGBColor[
              0.8427983522117647, 0.874271591791478, 0.7778392040313489], 
             UndirectedEdge[101, 176] -> 
             RGBColor[
              0.27302063754770944`, 0.4042923789438361, 0.9388594934592795], 
             UndirectedEdge[119, 192] -> 
             RGBColor[
              0.7331721237773268, 0.30862891172825246`, 0.4291081470301197], 
             UndirectedEdge[168, 184] -> 
             RGBColor[
              0.6548626736277727, 0.7248006680529328, 0.9668502718111599], 
             UndirectedEdge[16, 175] -> 
             RGBColor[
              0.3216795898869629, 0.4530444254989581, 0.9417181169108728], 
             UndirectedEdge[60, 104] -> 
             RGBColor[
              0.23644603942151277`, 0.3658501573497452, 0.9367766242032618], 
             UndirectedEdge[122, 136] -> 
             RGBColor[
              0.9504725003418423, 0.8301441328600938, 0.35879847629145456`], 
             UndirectedEdge[107, 157] -> 
             RGBColor[
              0.6124579217372135, 0.6958789497458655, 0.9628945747646525], 
             UndirectedEdge[86, 110] -> 
             RGBColor[
              0.49849330988433693`, 0.6020723271102092, 0.9541226934316467], 
             UndirectedEdge[5, 9] -> 
             RGBColor[
              0.27138694905370225`, 0.40257526875480143`, 0.9387664573163714],
              UndirectedEdge[3, 77] -> 
             RGBColor[
              0.2820287158723724, 0.41376044040821036`, 0.9393724901936115], 
             UndirectedEdge[84, 139] -> 
             RGBColor[
              0.25596738815303377`, 0.386368332591571, 0.9378883361342745], 
             UndirectedEdge[96, 191] -> 
             RGBColor[
              0.29321373700723585`, 0.4255166067922517, 0.9400094606004861], 
             UndirectedEdge[46, 151] -> 
             RGBColor[
              0.4748094471252997, 0.581756348874845, 0.9525589277610778], 
             UndirectedEdge[72, 191] -> 
             RGBColor[
              0.2650536461439216, 0.3959185658420248, 0.9384057850849414], 
             UndirectedEdge[111, 185] -> 
             RGBColor[
              0.6150345673164899, 0.6964030334262838, 0.9641692992212595], 
             UndirectedEdge[23, 129] -> 
             RGBColor[
              0.9919194200162629, 0.9837402828928126, 0.4795846817261888], 
             UndirectedEdge[101, 123] -> 
             RGBColor[
              0.2511378900976988, 0.38129222392755147`, 0.9376133033646252], 
             UndirectedEdge[122, 142] -> 
             RGBColor[
              0.8169136872538085, 0.8533228738878083, 0.7188155094580211], 
             UndirectedEdge[18, 174] -> 
             RGBColor[
              0.3498905326098686, 0.47747932616232985`, 0.9435156932352192], 
             UndirectedEdge[123, 135] -> 
             RGBColor[
              0.24185521523784892`, 0.3715355440942698, 0.9370846687638437], 
             UndirectedEdge[171, 178] -> 
             RGBColor[
              0.9084510251565888, 0.9296645818194842, 0.9851104569792455], 
             UndirectedEdge[81, 173] -> 
             RGBColor[
              0.7857376160501509, 0.8294745429756838, 0.8361707611374197], 
             UndirectedEdge[77, 102] -> 
             RGBColor[
              0.33711449602806876`, 0.4656411721496162, 0.9427298892598499], 
             UndirectedEdge[31, 171] -> 
             RGBColor[
              0.8624892635832501, 0.8931895434066397, 0.9867461899854671], 
             UndirectedEdge[109, 196] -> 
             RGBColor[
              0.4163582231260193, 0.5339138255247312, 0.9480649666862233], 
             UndirectedEdge[18, 153] -> 
             RGBColor[
              0.4521702655292919, 0.5624670752629113, 0.9510280595422927], 
             UndirectedEdge[97, 140] -> 
             RGBColor[
              0.29323255505263285`, 0.42553638575109687`, 0.9400105322603325],
              UndirectedEdge[116, 167] -> 
             RGBColor[
              0.652429277605832, 0.7235694154628036, 0.96891293133255], 
             UndirectedEdge[128, 190] -> 
             RGBColor[
              0.5346442883688116, 0.44885558317692076`, 0.5815609357144658], 
             UndirectedEdge[94, 126] -> 
             RGBColor[
              0.3626762195061153, 0.4884130176495661, 0.9443355349736948], 
             UndirectedEdge[41, 198] -> 
             RGBColor[
              0.6229374569936681, 0.7039435412138363, 0.9640225581060137], 
             UndirectedEdge[11, 77] -> 
             RGBColor[
              0.27312817427562797`, 0.40440540686310084`, 0.9388656175168482],
              UndirectedEdge[29, 122] -> 
             RGBColor[
              0.9932906731582525, 0.9894716805478189, 0.6138869514576812], 
             UndirectedEdge[84, 152] -> 
             RGBColor[
              0.2722580627952489, 0.4034908645289682, 0.9388160659552552], 
             UndirectedEdge[16, 64] -> 
             RGBColor[
              0.47278195616545676`, 0.5793252259853976, 0.9526162456912082], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.23972819328057, 0.3692999091561883, 0.9369635380100236], 
             UndirectedEdge[26, 121] -> 
             RGBColor[
              0.46953919243500225`, 0.5786867158238351, 0.9518099844973704], 
             UndirectedEdge[40, 74] -> 
             RGBColor[
              0.3971820108095485, 0.5168505289536836, 0.9468363149531384], 
             UndirectedEdge[78, 91] -> 
             RGBColor[
              0.8828910750951913, 0.909457394113841, 0.9886921329803882], 
             UndirectedEdge[139, 152] -> 
             RGBColor[
              0.26544888260262894`, 0.3963339844195651, 0.9384282932165648], 
             UndirectedEdge[40, 196] -> 
             RGBColor[
              0.49337743215923585`, 0.5995850516837207, 0.9532596252421102], 
             UndirectedEdge[6, 86] -> 
             RGBColor[
              0.3660057031110193, 0.4914374768784062, 0.9445425376494667], 
             UndirectedEdge[82, 180] -> 
             RGBColor[
              0.5213332999548519, 0.6173712520138998, 0.9573268973237518], 
             UndirectedEdge[44, 90] -> 
             RGBColor[
              0.33568645678912695`, 0.46283528505433924`, 0.9426963443190322],
              UndirectedEdge[4, 66] -> 
             RGBColor[
              0.7482528569010358, 0.8032600858342098, 0.9755425100215394], 
             UndirectedEdge[131, 143] -> 
             RGBColor[
              0.8469518489434293, 0.3190606581337521, 0.19091704430262602`], 
             UndirectedEdge[22, 144] -> 
             RGBColor[
              0.8484532037403029, 0.37343813304304, 0.19403214866276774`], 
             UndirectedEdge[35, 160] -> 
             RGBColor[
              0.6025425418355174, 0.6830045883363345, 0.9645167582458221], 
             UndirectedEdge[76, 174] -> 
             RGBColor[
              0.3288804579296929, 0.4562862523383694, 0.9422866189141441], 
             UndirectedEdge[85, 196] -> 
             RGBColor[
              0.42766426196123664`, 0.5437065481057618, 0.9487853774832657], 
             UndirectedEdge[6, 137] -> 
             RGBColor[
              0.2951194473890727, 0.4246251929966973, 0.9402239674768278], 
             UndirectedEdge[123, 177] -> 
             RGBColor[
              0.27201910823742403`, 0.40323970813810023`, 0.9388024578466887],
              UndirectedEdge[29, 113] -> 
             RGBColor[
              0.946972557498295, 0.8159080843147557, 0.4967685640741427], 
             UndirectedEdge[96, 174] -> 
             RGBColor[
              0.3438036499941711, 0.471971473383162, 0.943136472625332], 
             UndirectedEdge[74, 158] -> 
             RGBColor[
              0.2780238238703263, 0.40955104498924105`, 0.9391444175188017], 
             UndirectedEdge[46, 121] -> 
             RGBColor[
              0.570208977683367, 0.6619603615618923, 0.9593080859489944], 
             UndirectedEdge[32, 165] -> 
             RGBColor[
              0.2270272954930984, 0.35595046029812505`, 0.9362402406703216], 
             UndirectedEdge[32, 148] -> 
             RGBColor[
              0.219972379693155, 0.3485352964848875, 0.9358384736523275], 
             UndirectedEdge[27, 190] -> 
             RGBColor[
              0.22822804580985986`, 0.3572125250130086, 0.9363086216245102], 
             UndirectedEdge[100, 123] -> 
             RGBColor[
              0.23212285998297438`, 0.3613062216544334, 0.9365304255298079], 
             UndirectedEdge[45, 172] -> 
             RGBColor[
              0.9391683499060914, 0.7786563284917088, 0.4055000051193155], 
             UndirectedEdge[85, 99] -> 
             RGBColor[
              0.4621252914114974, 0.5716835642651686, 0.9514982759565006], 
             UndirectedEdge[106, 112] -> 
             RGBColor[
              0.2882506044320779, 0.42030003977498026`, 0.9397268175426274], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.8858165933462555, 0.5084410776664401, 0.4035840439814582], 
             UndirectedEdge[43, 197] -> 
             RGBColor[
              0.8665492485482925, 0.589132844492627, 0.463523131888269], 
             UndirectedEdge[26, 164] -> 
             RGBColor[
              0.34556297092325194`, 0.47243449330876475`, 0.9432874166489127],
              UndirectedEdge[100, 130] -> 
             RGBColor[
              0.2255191848288738, 0.3543653403702861, 0.9361543559990437], 
             UndirectedEdge[46, 196] -> 
             RGBColor[
              0.5464579464995596, 0.642678204475116, 0.9574383177713113], 
             UndirectedEdge[156, 181] -> 
             RGBColor[
              0.9525868256306654, 0.9637539256660137, 0.9508348285678401], 
             UndirectedEdge[62, 96] -> 
             RGBColor[
              0.33121568258703066`, 0.4610684087047351, 0.9423343784732514], 
             UndirectedEdge[54, 58] -> 
             RGBColor[
              0.2684799532608956, 0.3995198318623828, 0.9386009082064859], 
             UndirectedEdge[179, 183] -> 
             RGBColor[
              0.8425848980962714, 0.5878064340228173, 0.4637091200002722], 
             UndirectedEdge[65, 198] -> 
             RGBColor[
              0.809127231953634, 0.8516409245369697, 0.9813908857977319], 
             UndirectedEdge[4, 80] -> 
             RGBColor[
              0.7123913946505943, 0.7749007508046878, 0.972203429564615], 
             UndirectedEdge[159, 197] -> 
             RGBColor[
              0.844735305466295, 0.4214613190335854, 0.44263407535762334`], 
             UndirectedEdge[78, 136] -> 
             RGBColor[
              0.9179856014839756, 0.8091909436388446, 0.6189147464565151], 
             UndirectedEdge[153, 188] -> 
             RGBColor[
              0.6253120347428027, 0.7063539747569785, 0.9638795069847599], 
             UndirectedEdge[35, 174] -> 
             RGBColor[
              0.6098919568384804, 0.6893702822195625, 0.9649850564709783], 
             UndirectedEdge[82, 130] -> 
             RGBColor[
              0.27791125977355285`, 0.4085218087190706, 0.9391713605597196], 
             UndirectedEdge[124, 176] -> 
             RGBColor[
              0.29262570831728996`, 0.4248985513559462, 0.9399759732365041], 
             UndirectedEdge[6, 186] -> 
             RGBColor[
              0.3110411018029656, 0.4413598612768941, 0.941130682141722], 
             UndirectedEdge[1, 144] -> 
             RGBColor[
              0.8904481262845415, 0.5806212475838041, 0.23201956236806448`], 
             UndirectedEdge[43, 67] -> 
             RGBColor[
              0.8429788155468371, 0.3313595864958591, 0.18878986834626774`], 
             UndirectedEdge[24, 119] -> 
             RGBColor[
              0.37190268708568275`, 0.48151336908456555`, 0.9461947206260288],
              UndirectedEdge[93, 139] -> 
             RGBColor[
              0.2366529007205347, 0.36606758169078113`, 0.9367884046482173], 
             UndirectedEdge[38, 146] -> 
             RGBColor[
              0.8804514017100027, 0.8667932734581691, 0.6490490676279728], 
             UndirectedEdge[110, 127] -> 
             RGBColor[
              0.46330733319948464`, 0.5715960026043997, 0.9518806741110254], 
             UndirectedEdge[41, 81] -> 
             RGBColor[
              0.563023955866433, 0.6561272371693612, 0.9587424547119633], 
             UndirectedEdge[85, 194] -> 
             RGBColor[
              0.35434213313173446`, 0.48133507879042225`, 0.9437993452840767],
              UndirectedEdge[52, 70] -> 
             RGBColor[
              0.2130689137116028, 0.34127931603325223`, 0.9354453314774407], 
             UndirectedEdge[149, 170] -> 
             RGBColor[
              0.2079666859588458, 0.3359165511651807, 0.9351547671549908], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.30721338060851633`, 0.43871808624608816`, 0.9408621191648285],
              UndirectedEdge[92, 155] -> 
             RGBColor[
              0.23916918979888965`, 0.36871236105407446`, 0.9369317035887135],
              UndirectedEdge[57, 141] -> 
             RGBColor[
              0.35995825064388254`, 0.48619947750517123`, 0.9441571993258131],
              UndirectedEdge[149, 159] -> 
             RGBColor[
              0.6262856435829035, 0.23764894098782902`, 0.4250826867234967], 
             UndirectedEdge[142, 167] -> 
             RGBColor[
              0.7780824099898748, 0.8273108495391253, 0.9783266471470176], 
             UndirectedEdge[117, 173] -> 
             RGBColor[
              0.8870698836005233, 0.9096475021441977, 0.8455791000881498], 
             UndirectedEdge[99, 179] -> 
             RGBColor[
              0.6860146185776324, 0.753440204048828, 0.970158876487192], 
             UndirectedEdge[5, 11] -> 
             RGBColor[
              0.2640346736892395, 0.39484756118556874`, 0.938347756111082], 
             UndirectedEdge[29, 188] -> 
             RGBColor[
              0.8291485068413533, 0.8647956293451209, 0.8611126603250323], 
             UndirectedEdge[46, 178] -> 
             RGBColor[
              0.7700871696380653, 0.8204498262888431, 0.9719037985104857], 
             UndirectedEdge[101, 137] -> 
             RGBColor[
              0.25101571036429215`, 0.3811638052810985, 0.9376063454095565], 
             UndirectedEdge[3, 20] -> 
             RGBColor[
              0.24453230342971405`, 0.374349333521115, 0.9372371249759732], 
             UndirectedEdge[186, 199] -> 
             RGBColor[
              0.2771594494145085, 0.4086425326316706, 0.9390951926722704], 
             UndirectedEdge[156, 179] -> 
             RGBColor[
              0.864388741144453, 0.8948015330551333, 0.986901517469225], 
             UndirectedEdge[67, 87] -> 
             RGBColor[
              0.8747953206754928, 0.4237267463664781, 0.39303006082518865`], 
             UndirectedEdge[3, 10] -> 
             RGBColor[
              0.27648968445364525`, 0.4079385671922522, 0.9390570505485776], 
             UndirectedEdge[55, 185] -> 
             RGBColor[
              0.5609776882411449, 0.6497765761810184, 0.9606709927749343], 
             UndirectedEdge[5, 28] -> 
             RGBColor[
              0.28849193082278163`, 0.4205536891125868, 0.9397405607235676], 
             UndirectedEdge[37, 170] -> 
             RGBColor[
              0.18667955632742156`, 0.31354242824058126`, 0.9339424966139673],
              UndirectedEdge[49, 154] -> 
             RGBColor[
              0.8853342489533117, 0.5082416158642724, 0.4115777388398131], 
             UndirectedEdge[24, 89] -> 
             RGBColor[
              0.6289704896989408, 0.3791403610884968, 0.44405788636093535`], 
             UndirectedEdge[73, 115] -> 
             RGBColor[
              0.27934432739444803`, 0.41093897791785206`, 0.9392196182409905],
              UndirectedEdge[153, 174] -> 
             RGBColor[
              0.4836903414503127, 0.5897681807806197, 0.9530364909078715], 
             UndirectedEdge[119, 183] -> 
             RGBColor[
              0.7615664433424367, 0.5237229317976604, 0.4561749529436979], 
             UndirectedEdge[4, 168] -> 
             RGBColor[
              0.8717390399773187, 0.9006124860515876, 0.9850092222919777], 
             UndirectedEdge[144, 181] -> 
             RGBColor[
              0.8991205652819477, 0.619537019745982, 0.4376211825067001], 
             UndirectedEdge[53, 123] -> 
             RGBColor[
              0.2309218560021901, 0.36004389032257866`, 0.9364620301298284], 
             UndirectedEdge[110, 162] -> 
             RGBColor[
              0.7939641442587955, 0.8384977959010833, 0.9379384858342741], 
             UndirectedEdge[127, 176] -> 
             RGBColor[
              0.3078922888084153, 0.4397573979887158, 0.940888855185277], 
             UndirectedEdge[9, 102] -> 
             RGBColor[
              0.31720087863442126`, 0.44471069767262583`, 0.9415958382088386],
              UndirectedEdge[27, 195] -> 
             RGBColor[
              0.22783801477683696`, 0.3568025776679057, 0.9362864099341788], 
             UndirectedEdge[60, 130] -> 
             RGBColor[
              0.2455906790412874, 0.3754617533937681, 0.9372973979013259], 
             UndirectedEdge[89, 122] -> 
             RGBColor[
              0.9003075980023684, 0.6064437341064228, 0.29047713264699326`], 
             UndirectedEdge[5, 106] -> 
             RGBColor[
              0.2786294913144741, 0.4101876398745743, 0.9391789093837413], 
             UndirectedEdge[83, 199] -> 
             RGBColor[
              0.2640684264301843, 0.3948830374563491, 0.938349678279746], 
             UndirectedEdge[118, 125] -> 
             RGBColor[
              0.5461336776674304, 0.6195695759530597, 0.9625480754195246], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.2678093745072151, 0.3988150110751161, 0.9385627197384963], 
             UndirectedEdge[5, 112] -> 
             RGBColor[
              0.29182817897856506`, 0.4240602974546656, 0.9399305551205026], 
             UndirectedEdge[109, 146] -> 
             RGBColor[
              0.5668187671363596, 0.653709441066444, 0.9615199202813867], 
             UndirectedEdge[164, 184] -> 
             RGBColor[
              0.33292802569279517`, 0.46149073880095526`, 0.9424823291114712],
              UndirectedEdge[51, 164] -> 
             RGBColor[
              0.28843151316149873`, 0.42049018631987756`, 0.9397371200271375],
              UndirectedEdge[45, 168] -> 
             RGBColor[
              0.9114761724933723, 0.7607551980488345, 0.6070253886431892], 
             UndirectedEdge[148, 165] -> 
             RGBColor[
              0.2118480097340456, 0.33999606854305653`, 0.9353758028020844], 
             UndirectedEdge[166, 184] -> 
             RGBColor[
              0.3810287222999791, 0.5044496610209838, 0.9454997911478531], 
             UndirectedEdge[21, 132] -> 
             RGBColor[
              0.28420798371714023`, 0.41536166731241486`, 0.9395218357203131],
              UndirectedEdge[96, 157] -> 
             RGBColor[
              0.43194074873512733`, 0.5454775949392545, 0.9495354789637005], 
             UndirectedEdge[42, 102] -> 
             RGBColor[
              0.4476381958746549, 0.5602937273030086, 0.9502551687958871], 
             UndirectedEdge[117, 120] -> 
             RGBColor[
              0.8678835994276715, 0.8465560061197337, 0.6325812491960736], 
             UndirectedEdge[25, 129] -> 
             RGBColor[
              0.9845905971173718, 0.9596826071563495, 0.39463780893289646`], 
             UndirectedEdge[57, 90] -> 
             RGBColor[
              0.37426337273503046`, 0.49858985526418154`, 0.9450687090559382],
              UndirectedEdge[51, 184] -> 
             RGBColor[
              0.3266364768489205, 0.4548779220588064, 0.942124034712325], 
             UndirectedEdge[95, 103] -> 
             RGBColor[
              0.9027357759104662, 0.63208364163686, 0.26409899908324835`], 
             UndirectedEdge[47, 105] -> 
             RGBColor[
              0.3973660260121461, 0.5186002123597028, 0.9465407896938819], 
             UndirectedEdge[127, 177] -> 
             RGBColor[
              0.3075972075411117, 0.4394472488675467, 0.9408720507436377], 
             UndirectedEdge[73, 153] -> 
             RGBColor[
              0.4395524049734263, 0.5500947505807087, 0.9502769094004289], 
             UndirectedEdge[137, 199] -> 
             RGBColor[
              0.26123779500061556`, 0.39190786435147384`, 0.9381884780073761],
              UndirectedEdge[138, 185] -> 
             RGBColor[
              0.8411744991425061, 0.7559037234450623, 0.613171500043548], 
             UndirectedEdge[88, 136] -> 
             RGBColor[
              0.8101006391447247, 0.7240376246779792, 0.6083933870270145], 
             UndirectedEdge[55, 76] -> 
             RGBColor[
              0.31436618073050393`, 0.4437147149372155, 0.9413617820054831], 
             UndirectedEdge[135, 176] -> 
             RGBColor[
              0.26373796268785954`, 0.3945356991105544, 0.938330858858498], 
             UndirectedEdge[69, 123] -> 
             RGBColor[
              0.3260085199796461, 0.4514023478470298, 0.9421913646386602], 
             UndirectedEdge[2, 40] -> 
             RGBColor[
              0.43435111341602517`, 0.5495958945368197, 0.9491845094203311], 
             UndirectedEdge[105, 174] -> 
             RGBColor[
              0.3623104663482657, 0.48823684852250904`, 0.9443070804305137], 
             UndirectedEdge[89, 138] -> 
             RGBColor[
              0.8735867140642237, 0.5079729105623115, 0.2157827080806035], 
             UndirectedEdge[37, 128] -> 
             RGBColor[
              0.5402876317341454, 0.454787094862522, 0.5818823157705433], 
             UndirectedEdge[88, 153] -> 
             RGBColor[
              0.6490823398625842, 0.7249235177775619, 0.9662487088529688], 
             UndirectedEdge[113, 197] -> 
             RGBColor[
              0.8946095450697447, 0.7772196138099509, 0.6138944273650201], 
             UndirectedEdge[31, 178] -> 
             RGBColor[
              0.8964701273649321, 0.9201113391332241, 0.9839677082524034], 
             UndirectedEdge[82, 177] -> 
             RGBColor[
              0.3061026011103605, 0.4381526958983335, 0.9407768157434988], 
             UndirectedEdge[87, 108] -> 
             RGBColor[
              0.8846035797290293, 0.9091596462519311, 0.913892802031036], 
             UndirectedEdge[64, 86] -> 
             RGBColor[
              0.5072811113074129, 0.6092066601914048, 0.9548145013504485], 
             UndirectedEdge[116, 157] -> 
             RGBColor[
              0.47363379400133276`, 0.5818257161885222, 0.9521834927723848], 
             UndirectedEdge[120, 168] -> 
             RGBColor[
              0.9476806026150666, 0.909778086957847, 0.6376934323137864], 
             UndirectedEdge[18, 54] -> 
             RGBColor[
              0.295588460550005, 0.42712274502129255`, 0.9401772792428172], 
             UndirectedEdge[161, 176] -> 
             RGBColor[
              0.301427951999442, 0.43415026756037145`, 0.9404772479924501], 
             UndirectedEdge[168, 172] -> 
             RGBColor[
              0.9662845352880476, 0.9716239920088556, 0.7873059163017873], 
             UndirectedEdge[142, 157] -> 
             RGBColor[
              0.5992869263853755, 0.6855671502648439, 0.9615972085868523], 
             UndirectedEdge[121, 171] -> 
             RGBColor[
              0.7085728332018904, 0.7711751170925334, 0.9725147444177542], 
             UndirectedEdge[47, 94] -> 
             RGBColor[
              0.4348245890199799, 0.551044936914969, 0.9489276162054343], 
             UndirectedEdge[70, 93] -> 
             RGBColor[
              0.21891136206643785`, 0.34742009968680476`, 0.9357780502681208],
              UndirectedEdge[32, 163] -> 
             RGBColor[
              0.23408691252963393`, 0.3633705654090964, 0.9366422754167848], 
             UndirectedEdge[35, 142] -> 
             RGBColor[
              0.7396311759520104, 0.7966508792482756, 0.9746591341186641], 
             UndirectedEdge[12, 193] -> 
             RGBColor[
              0.4503245613855142, 0.5609229257874412, 0.950895392546576], 
             UndirectedEdge[35, 94] -> 
             RGBColor[
              0.6282503776636906, 0.7052714236172997, 0.9661548388122466], 
             UndirectedEdge[116, 174] -> 
             RGBColor[
              0.38549669526037655`, 0.5083195946324296, 0.9457844864340161], 
             UndirectedEdge[112, 140] -> 
             RGBColor[
              0.30347647446516857`, 0.4363033945556761, 0.9405939083163557], 
             UndirectedEdge[86, 176] -> 
             RGBColor[
              0.3430782654932676, 0.4702337224945253, 0.9431308745058982], 
             UndirectedEdge[61, 73] -> 
             RGBColor[
              0.28346587285648317`, 0.41527098351952657`, 0.9394543341577734],
              UndirectedEdge[33, 66] -> 
             RGBColor[
              0.5073300220022017, 0.606620425388813, 0.955851339828218], 
             UndirectedEdge[48, 106] -> 
             RGBColor[
              0.29607730783621694`, 0.42775376738301063`, 0.9402008266352594],
              UndirectedEdge[86, 199] -> 
             RGBColor[
              0.3321240507225622, 0.4587201482331828, 0.9425070481800151], 
             UndirectedEdge[10, 59] -> 
             RGBColor[
              0.3690604515059446, 0.4922869105332728, 0.9448029598331952], 
             UndirectedEdge[1, 113] -> 
             RGBColor[
              0.9293073420017215, 0.7556088200837405, 0.2655373341471002], 
             UndirectedEdge[125, 128] -> 
             RGBColor[
              0.5342706715319968, 0.44846288819275276`, 0.5815396587883258], 
             UndirectedEdge[53, 165] -> 
             RGBColor[
              0.21515759774182608`, 0.3434746553792333, 0.935564278943031], 
             UndirectedEdge[87, 143] -> 
             RGBColor[
              0.876523819007324, 0.43701274197773154`, 0.3946852727798099], 
             UndirectedEdge[61, 105] -> 
             RGBColor[
              0.30850366715074595`, 0.4384008305619083, 0.9409968714949317], 
             UndirectedEdge[29, 47] -> 
             RGBColor[
              0.7225823732127437, 0.7785731992059557, 0.8525033535115121], 
             UndirectedEdge[24, 27] -> 
             RGBColor[
              0.22783801619652955`, 0.3568025791600926, 0.9362864100150281], 
             UndirectedEdge[98, 117] -> 
             RGBColor[
              0.8762433687105626, 0.9035134810174441, 0.9541841801385145], 
             UndirectedEdge[1, 88] -> 
             RGBColor[
              0.8352535964645615, 0.823065908134689, 0.6322506322661987], 
             UndirectedEdge[190, 195] -> 
             RGBColor[
              0.1793170310330229, 0.30580394734510286`, 0.9335232116903315], 
             UndirectedEdge[4, 173] -> 
             RGBColor[
              0.9000135688899087, 0.9197592074679171, 0.8468692056721795], 
             UndirectedEdge[81, 164] -> 
             RGBColor[
              0.43552843920258344`, 0.5470178923073767, 0.9499428350575294], 
             UndirectedEdge[82, 123] -> 
             RGBColor[
              0.28451493492765345`, 0.4154626900032179, 0.9395474300904838], 
             UndirectedEdge[43, 87] -> 
             RGBColor[
              0.8995684415169597, 0.6141438088047649, 0.4167528293202155], 
             UndirectedEdge[38, 171] -> 
             RGBColor[
              0.919639217056486, 0.8978474840035989, 0.6528380765050477], 
             UndirectedEdge[46, 85] -> 
             RGBColor[
              0.4789487657995369, 0.5853416186622634, 0.9528226814867443], 
             UndirectedEdge[64, 69] -> 
             RGBColor[
              0.512094113243802, 0.613375440560194, 0.9551211815778647], 
             UndirectedEdge[60, 82] -> 
             RGBColor[
              0.2862778470683244, 0.4173156224381487, 0.9396478253289002], 
             UndirectedEdge[77, 189] -> 
             RGBColor[
              0.2658927211222934, 0.3968004868447199, 0.9384535691636595], 
             UndirectedEdge[101, 187] -> 
             RGBColor[
              0.2673357347336053, 0.3983171856425559, 0.9385357466540765], 
             UndirectedEdge[64, 161] -> 
             RGBColor[
              0.4656307978135873, 0.573123205257251, 0.9521608748370004], 
             UndirectedEdge[7, 160] -> 
             RGBColor[
              0.3585859521924276, 0.48501086156024664`, 0.9440697576819622], 
             UndirectedEdge[16, 83] -> 
             RGBColor[
              0.2894048145974629, 0.4201988877306557, 0.9398406710693048], 
             UndirectedEdge[13, 124] -> 
             RGBColor[
              0.3345268948480242, 0.4625364133999037, 0.9425966268829805], 
             UndirectedEdge[46, 171] -> 
             RGBColor[
              0.7361063058563833, 0.7935280305622586, 0.9746822802435494], 
             UndirectedEdge[1, 197] -> 
             RGBColor[
              0.9236147906417135, 0.8926515043216656, 0.6409097972593247], 
             UndirectedEdge[26, 80] -> 
             RGBColor[
              0.5081499735315052, 0.6100326873138424, 0.9548495666212384], 
             UndirectedEdge[23, 43] -> 
             RGBColor[
              0.9014366337014165, 0.6139370032291189, 0.31460356700739317`], 
             UndirectedEdge[13, 86] -> 
             RGBColor[
              0.38497945202400186`, 0.5078715845384828, 0.9457515281523746], 
             UndirectedEdge[31, 146] -> 
             RGBColor[
              0.8233014482367667, 0.8621353328612098, 0.9829571811083924], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.6527715209369094, 0.7286468226851102, 0.9660412183253722], 
             UndirectedEdge[124, 127] -> 
             RGBColor[
              0.30632106017096694`, 0.43810593706910805`, 0.9407993760387987],
              UndirectedEdge[60, 163] -> 
             RGBColor[
              0.24348971297155947`, 0.37325350484554143`, 0.9371777509917558],
              UndirectedEdge[4, 184] -> 
             RGBColor[
              0.5880093557297629, 0.671690292538539, 0.9630281942774768], 
             UndirectedEdge[144, 192] -> 
             RGBColor[
              0.8434502637599781, 0.33498334405198565`, 0.18924132768759622`],
              UndirectedEdge[38, 192] -> 
             RGBColor[
              0.8664820909126885, 0.38706872730476605`, 0.21540773809926206`],
              UndirectedEdge[49, 108] -> 
             RGBColor[
              0.8169025980884497, 0.455017381178201, 0.44687525682009266`], 
             UndirectedEdge[83, 165] -> 
             RGBColor[
              0.2373756354905151, 0.36682722175806165`, 0.9368295633241774], 
             UndirectedEdge[183, 192] -> 
             RGBColor[
              0.84571331956511, 0.349221020069408, 0.19128480591357822`], 
             UndirectedEdge[79, 159] -> 
             RGBColor[
              0.6164190249825052, 0.2272784992590594, 0.42452079739055826`], 
             UndirectedEdge[81, 166] -> 
             RGBColor[
              0.4836291358097673, 0.5899768145274054, 0.9529602970939112], 
             UndirectedEdge[118, 119] -> 
             RGBColor[
              0.7390929491372125, 0.7956716911845035, 0.9752408612005126], 
             UndirectedEdge[47, 153] -> 
             RGBColor[
              0.518745901114193, 0.6201315446178133, 0.9552702001712396], 
             UndirectedEdge[74, 184] -> 
             RGBColor[
              0.3369577946710508, 0.46572628149921225`, 0.9427118184932739], 
             UndirectedEdge[149, 190] -> 
             RGBColor[
              0.2066375350628038, 0.33451952930040635`, 0.9350790739777637], 
             UndirectedEdge[55, 139] -> 
             RGBColor[
              0.3007701310464627, 0.42942440467994913`, 0.9405875070895301], 
             UndirectedEdge[22, 138] -> 
             RGBColor[
              0.8672064638387251, 0.45893151148565325`, 0.20967297325920412`],
              UndirectedEdge[113, 144] -> 
             RGBColor[
              0.871111295903229, 0.5036666539093275, 0.21400931577186139`], 
             UndirectedEdge[80, 172] -> 
             RGBColor[
              0.8069368899613232, 0.8459122567619559, 0.7745001235744244], 
             UndirectedEdge[8, 156] -> 
             RGBColor[
              0.6845205611909437, 0.7511737984198581, 0.97104590551255], 
             UndirectedEdge[22, 118] -> 
             RGBColor[
              0.8673837475077953, 0.5395378434117971, 0.45731224525585845`], 
             UndirectedEdge[100, 163] -> 
             RGBColor[
              0.22341821875914586`, 0.35215709182205945`, 0.9360347090894736],
              UndirectedEdge[12, 154] -> 
             RGBColor[
              0.7852450872055535, 0.8309115028617888, 0.9166639457901922], 
             UndirectedEdge[67, 129] -> 
             RGBColor[
              0.8755570267580526, 0.42023027988113926`, 0.24893178910674738`],
              UndirectedEdge[49, 129] -> 
             RGBColor[
              0.8865782994288154, 0.5049446111811012, 0.25948577226301694`], 
             UndirectedEdge[127, 175] -> 
             RGBColor[
              0.32099276834406665`, 0.45244953519915593`, 0.9416743532494919],
              UndirectedEdge[30, 198] -> 
             RGBColor[
              0.7949540018905729, 0.840339575606766, 0.9800390304617252], 
             UndirectedEdge[5, 140] -> 
             RGBColor[
              0.2938553613475648, 0.42619099465527016`, 0.9400460001574695], 
             UndirectedEdge[147, 156] -> 
             RGBColor[
              0.7007698065694198, 0.7645047047938165, 0.9722866893066117], 
             UndirectedEdge[122, 159] -> 
             RGBColor[
              0.8794090834796054, 0.44580859369701076`, 0.2704646915384994], 
             UndirectedEdge[82, 110] -> 
             RGBColor[
              0.4618127267687334, 0.5703014496351865, 0.9517854391108865], 
             UndirectedEdge[83, 176] -> 
             RGBColor[
              0.2750226412008897, 0.4063966117176916, 0.9389735046056292], 
             UndirectedEdge[10, 77] -> 
             RGBColor[
              0.2948550356150111, 0.4272417156933656, 0.9401029301281152], 
             UndirectedEdge[104, 130] -> 
             RGBColor[
              0.2280794521267412, 0.3570563436306672, 0.9363001594340813], 
             UndirectedEdge[30, 66] -> 
             RGBColor[
              0.7926835884248224, 0.8385659113515402, 0.9798127368656795], 
             UndirectedEdge[85, 132] -> 
             RGBColor[
              0.3061847210307328, 0.43439681259051416`, 0.9409221739886695], 
             UndirectedEdge[24, 195] -> 
             RGBColor[
              0.1789270014196926, 0.30539400149218693`, 0.9335010000808495], 
             UndirectedEdge[50, 123] -> 
             RGBColor[
              0.24633186843467056`, 0.37624079044033565`, 0.9373396075407877],
              UndirectedEdge[42, 153] -> 
             RGBColor[
              0.5537057705483233, 0.648562314548655, 0.9580088930300842], 
             UndirectedEdge[127, 161] -> 
             RGBColor[
              0.31512330385311904`, 0.4473576532735334, 0.9413006507947447], 
             UndirectedEdge[7, 18] -> 
             RGBColor[
              0.33441529127436986`, 0.4640754499257662, 0.9425296245415398], 
             UndirectedEdge[65, 66] -> 
             RGBColor[
              0.8068568184878835, 0.8498672602817441, 0.9811645922016861], 
             UndirectedEdge[150, 152] -> 
             RGBColor[
              0.2823331640327409, 0.4140804347278859, 0.9393898280659538], 
             UndirectedEdge[25, 87] -> 
             RGBColor[
              0.9834480379935321, 0.9649273068843578, 0.6107852165105583], 
             UndirectedEdge[69, 82] -> 
             RGBColor[
              0.3600920128525825, 0.48631533560726303`, 0.9441657225354702], 
             UndirectedEdge[1, 159] -> 
             RGBColor[
              0.867867170087613, 0.40705412321611184`, 0.21039601321234347`], 
             UndirectedEdge[23, 131] -> 
             RGBColor[
              0.9464189057965813, 0.8120568568548516, 0.39007974658807487`], 
             UndirectedEdge[126, 160] -> 
             RGBColor[
              0.336968383677942, 0.466146182368601, 0.9426974544072704], 
             UndirectedEdge[67, 131] -> 
             RGBColor[
              0.8452233506115981, 0.3057746625224987, 0.18926183234800478`], 
             UndirectedEdge[142, 174] -> 
             RGBColor[
              0.5111498276444193, 0.6120610287087513, 0.9551982022484837], 
             UndirectedEdge[22, 122] -> 
             RGBColor[
              0.8939273477768698, 0.5574023350297646, 0.28436739782559384`], 
             UndirectedEdge[32, 176] -> 
             RGBColor[
              0.264674301203473, 0.39551985025775493`, 0.9383841819517735], 
             UndirectedEdge[47, 160] -> 
             RGBColor[
              0.4091167531918066, 0.528778101634004, 0.9472895356390099], 
             UndirectedEdge[79, 125] -> 
             RGBColor[
              0.19146399032539158`, 0.3185711717230839, 0.934214963052216], 
             UndirectedEdge[47, 111] -> 
             RGBColor[
              0.45600877007092583`, 0.5691987153613436, 0.9503313034018304], 
             UndirectedEdge[3, 186] -> 
             RGBColor[
              0.27284687806334806`, 0.40410974670878463`, 0.9388495981136993],
              UndirectedEdge[105, 160] -> 
             RGBColor[
              0.35496105134530265`, 0.4818711546392811, 0.9438387822053573], 
             UndirectedEdge[9, 189] -> 
             RGBColor[
              0.24597910372864595`, 0.37587001236772954`, 0.9373195181126482],
              UndirectedEdge[64, 175] -> 
             RGBColor[
              0.4715002623045349, 0.5782150871828736, 0.9525345772917476], 
             UndirectedEdge[100, 165] -> 
             RGBColor[
              0.21635860172261037`, 0.34473698671108804`, 0.9356326743430103],
              UndirectedEdge[101, 161] -> 
             RGBColor[
              0.28025165259241314`, 0.41189263422865363`, 0.9392712890687474],
              UndirectedEdge[123, 187] -> 
             RGBColor[
              0.26662928669062347`, 0.3975746639579891, 0.9384955154831248], 
             UndirectedEdge[90, 198] -> 
             RGBColor[
              0.542054826289809, 0.636504451768819, 0.9581455985091416], 
             UndirectedEdge[146, 171] -> 
             RGBColor[
              0.8352823460284233, 0.8716885755474699, 0.9840999298352342], 
             UndirectedEdge[62, 157] -> 
             RGBColor[
              0.4569597398647052, 0.567383488557704, 0.951121036787086], 
             UndirectedEdge[2, 164] -> 
             RGBColor[
              0.3359219335901057, 0.4640839113434194, 0.9426730982752791], 
             UndirectedEdge[94, 142] -> 
             RGBColor[
              0.5295082484696294, 0.6279621701064884, 0.9563679845897519], 
             UndirectedEdge[12, 175] -> 
             RGBColor[
              0.4521802655001208, 0.5625302434211127, 0.9510136363718239], 
             UndirectedEdge[23, 64] -> 
             RGBColor[
              0.8080908888760686, 0.8465853309633324, 0.7529704509533501], 
             UndirectedEdge[73, 160] -> 
             RGBColor[
              0.3299232570510399, 0.45874130759689935`, 0.9422962448681991], 
             UndirectedEdge[47, 142] -> 
             RGBColor[
              0.5462053873082997, 0.642424392545945, 0.9574319115118519], 
             UndirectedEdge[31, 120] -> 
             RGBColor[
              0.9036386065731989, 0.8747348065350462, 0.6360795030302686], 
             UndirectedEdge[9, 20] -> 
             RGBColor[
              0.24298403719743245`, 0.3727220075452381, 0.9371489535044994], 
             UndirectedEdge[174, 188] -> 
             RGBColor[
              0.5230323018233795, 0.6213662256563972, 0.9563671406776864], 
             UndirectedEdge[45, 173] -> 
             RGBColor[
              0.9397507014059623, 0.7799019194651641, 0.46888537202339087`], 
             UndirectedEdge[139, 191] -> 
             RGBColor[
              0.2646944952587164, 0.3955410754901928, 0.9383853319733451], 
             UndirectedEdge[24, 170] -> 
             RGBColor[
              0.18064618334875748`, 0.3072009707020641, 0.9335989049484079], 
             UndirectedEdge[118, 195] -> 
             RGBColor[
              0.5461172634712222, 0.6195523235921249, 0.9625471406553332], 
             UndirectedEdge[124, 137] -> 
             RGBColor[
              0.27062078113387267`, 0.4017699776932086, 0.938722825186781], 
             UndirectedEdge[28, 63] -> 
             RGBColor[
              0.3238146353715521, 0.45360214621203954`, 0.941901450034025], 
             UndirectedEdge[7, 94] -> 
             RGBColor[
              0.3842937880206009, 0.5072776968412117, 0.9457078382483868], 
             UndirectedEdge[37, 190] -> 
             RGBColor[
              0.18535040543137957`, 0.3121454063758069, 0.9338668034367403], 
             UndirectedEdge[31, 40] -> 
             RGBColor[
              0.6710448937244029, 0.7408816350846033, 0.9693608389875064], 
             UndirectedEdge[18, 73] -> 
             RGBColor[
              0.3057525961329822, 0.4378058959624189, 0.9407561117277767], 
             UndirectedEdge[170, 195] -> 
             RGBColor[
              0.1806461819290649, 0.30720096920987716`, 0.9335989048675586], 
             UndirectedEdge[62, 191] -> 
             RGBColor[
              0.3182327281368137, 0.4474225004107011, 0.9415950184238715], 
             UndirectedEdge[152, 194] -> 
             RGBColor[
              0.3151343711235495, 0.4448783558224487, 0.9413924862035001], 
             UndirectedEdge[24, 37] -> 
             RGBColor[
              0.18496037581804925`, 0.31173546052289103`, 0.9338445918272582],
              UndirectedEdge[90, 177] -> 
             RGBColor[
              0.3407778041727428, 0.4681866139645882, 0.9429862890205556], 
             UndirectedEdge[94, 188] -> 
             RGBColor[
              0.5413907226485897, 0.6372673670541342, 0.9575369230189545], 
             UndirectedEdge[103, 133] -> 
             RGBColor[
              0.8506697865477463, 0.3781326515142924, 0.19567142569650792`], 
             UndirectedEdge[38, 179] -> 
             RGBColor[
              0.8863710041657746, 0.8714177118872631, 0.6496390782789341], 
             UndirectedEdge[54, 116] -> 
             RGBColor[
              0.33119462320051296`, 0.4579630134913923, 0.9424460724416142], 
             UndirectedEdge[4, 198] -> 
             RGBColor[
              0.7505232703667862, 0.8050337500894356, 0.9757688036175852], 
             UndirectedEdge[31, 38] -> 
             RGBColor[
              0.9076583192648293, 0.8882942413173389, 0.6516953277782057], 
             UndirectedEdge[35, 47] -> 
             RGBColor[
              0.6449475165023608, 0.7197336460567563, 0.9672187657343465], 
             UndirectedEdge[132, 151] -> 
             RGBColor[
              0.3020454023564957, 0.43081154280309575`, 0.9406584202630028], 
             UndirectedEdge[124, 135] -> 
             RGBColor[
              0.26216673405041124`, 0.39288423819094664`, 0.9382413797120197],
              UndirectedEdge[32, 127] -> 
             RGBColor[
              0.2783696530571501, 0.40872723597091687`, 0.9392075847540681], 
             UndirectedEdge[187, 199] -> 
             RGBColor[
              0.27755781936992874`, 0.40906124471293126`, 0.9391178792518959],
              UndirectedEdge[2, 51] -> 
             RGBColor[
              0.329630384746231, 0.45747109460127056`, 0.9423148038761329], 
             UndirectedEdge[40, 117] -> 
             RGBColor[
              0.6352898865788753, 0.7127028346692909, 0.9658625851533114], 
             UndirectedEdge[9, 17] -> 
             RGBColor[
              0.2497025677004787, 0.37978360908337694`, 0.9375315638774728], 
             UndirectedEdge[33, 57] -> 
             RGBColor[
              0.3418089819131736, 0.4704794931394012, 0.9430007439710605], 
             UndirectedEdge[124, 175] -> 
             RGBColor[
              0.3057261878529413, 0.4375906885663863, 0.9407614713007191], 
             UndirectedEdge[8, 147] -> 
             RGBColor[
              0.4644466210649416, 0.5759586789636362, 0.9510205021407936], 
             UndirectedEdge[108, 110] -> 
             RGBColor[
              0.6931298062895987, 0.7596256615132471, 0.9704393557617335], 
             UndirectedEdge[68, 107] -> 
             RGBColor[
              0.7614279257189907, 0.8138406211600655, 0.9767792324528825], 
             UndirectedEdge[1, 138] -> 
             RGBColor[
              0.9355441317544622, 0.7814661810006367, 0.2706140846810541], 
             UndirectedEdge[94, 160] -> 
             RGBColor[
              0.39241961435313644`, 0.5143158791945474, 0.9462256087169099], 
             UndirectedEdge[138, 142] -> 
             RGBColor[
              0.7768323613465915, 0.7056166385716411, 0.6067738726084364], 
             UndirectedEdge[6, 175] -> 
             RGBColor[
              0.3302248541081414, 0.460445903869875, 0.9422626135907659], 
             UndirectedEdge[34, 104] -> 
             RGBColor[
              0.2353413665909268, 0.3646890761644966, 0.936713714719777], 
             UndirectedEdge[15, 106] -> 
             RGBColor[
              0.3000813368943679, 0.43122185610482894`, 0.9404559598262209], 
             UndirectedEdge[61, 94] -> 
             RGBColor[
              0.34596223015857974`, 0.47084555511717463`, 0.9433836980064841],
              UndirectedEdge[144, 159] -> 
             RGBColor[
              0.8452254175415028, 0.3486279538941323, 0.1909412169535338], 
             UndirectedEdge[83, 86] -> 
             RGBColor[
              0.32390396973941904`, 0.450080321936663, 0.9420389267285452], 
             UndirectedEdge[137, 176] -> 
             RGBColor[
              0.27219200977132096`, 0.4034214386128163, 0.9388123043332592], 
             UndirectedEdge[143, 159] -> 
             RGBColor[
              0.821413781916936, 0.16560128815844824`, 0.1681391677880527], 
             UndirectedEdge[24, 144] -> 
             RGBColor[
              0.6306529313731064, 0.3920723450467769, 0.44566899440816243`], 
             UndirectedEdge[76, 96] -> 
             RGBColor[
              0.2912734993929746, 0.42347729404149315`, 0.9398989669386781], 
             UndirectedEdge[98, 120] -> 
             RGBColor[
              0.9651286166376958, 0.922790787247423, 0.6081584957443529], 
             UndirectedEdge[98, 183] -> 
             RGBColor[
              0.897769781538639, 0.6310947741177858, 0.4464659481425095], 
             UndirectedEdge[55, 75] -> 
             RGBColor[
              0.3182717437982659, 0.44781970934843396`, 0.9415841980444295], 
             UndirectedEdge[35, 68] -> 
             RGBColor[
              0.8469990595612139, 0.880838075189855, 0.985268720497577], 
             UndirectedEdge[25, 43] -> 
             RGBColor[
              0.8965507517688224, 0.5978985527381435, 0.25797231847853164`], 
             UndirectedEdge[47, 174] -> 
             RGBColor[
              0.4164661681947697, 0.535143795517232, 0.9477578338641661], 
             UndirectedEdge[29, 88] -> 
             RGBColor[
              0.8529188119611348, 0.8833651723657042, 0.8634818621932413], 
             UndirectedEdge[17, 140] -> 
             RGBColor[
              0.27217097999434126`, 0.4033993349838457, 0.9388111067185709], 
             UndirectedEdge[41, 90] -> 
             RGBColor[
              0.46883146462921355`, 0.577882603340978, 0.9518176941382794], 
             UndirectedEdge[151, 196] -> 
             RGBColor[
              0.4235249432869995, 0.5401212783183434, 0.9485216237575993], 
             UndirectedEdge[88, 94] -> 
             RGBColor[
              0.5651610277683712, 0.6558369100747177, 0.9599061248871635], 
             UndirectedEdge[57, 198] -> 
             RGBColor[
              0.528369365099485, 0.6246507931370399, 0.9572735730236723], 
             UndirectedEdge[71, 164] -> 
             RGBColor[
              0.2925031947568016, 0.42476978183606456`, 0.9399689962704769], 
             UndirectedEdge[95, 154] -> 
             RGBColor[
              0.9830766756699849, 0.9658160132096346, 0.6241438116222372], 
             UndirectedEdge[69, 90] -> 
             RGBColor[
              0.3947672159149649, 0.5163492536735178, 0.946375195812527], 
             UndirectedEdge[175, 176] -> 
             RGBColor[
              0.30729741649038966`, 0.43924214948599405`, 0.9408509504471974],
              UndirectedEdge[58, 115] -> 
             RGBColor[
              0.2648536806612042, 0.3957083894411449, 0.9383943973465231], 
             UndirectedEdge[42, 88] -> 
             RGBColor[
              0.6168180360411716, 0.6987299024450158, 0.9637087446681081], 
             UndirectedEdge[72, 134] -> 
             RGBColor[
              0.2403643210352666, 0.36996851975920364`, 0.9369997645445869], 
             UndirectedEdge[25, 49] -> 
             RGBColor[
              0.8827989035981182, 0.49219582159981873`, 0.2448035331397743], 
             UndirectedEdge[23, 103] -> 
             RGBColor[
              0.9073868883324812, 0.6473301594421497, 0.31981821239601227`], 
             UndirectedEdge[79, 192] -> 
             RGBColor[
              0.6128687174194557, 0.19998927957476603`, 0.421121018858683], 
             UndirectedEdge[89, 170] -> 
             RGBColor[
              0.6301166100385224, 0.38034500623362366`, 0.4441231562187414], 
             UndirectedEdge[41, 57] -> 
             RGBColor[
              0.4551460034388895, 0.5660289447091988, 0.9509456686528102], 
             UndirectedEdge[10, 14] -> 
             RGBColor[
              0.35304438919669967`, 0.4784146023517027, 0.943782430505298], 
             UndirectedEdge[6, 59] -> 
             RGBColor[
              0.39442835550292343`, 0.516055749816227, 0.9463536039267142], 
             UndirectedEdge[120, 183] -> 
             RGBColor[
              0.8921966020167115, 0.5931231241859789, 0.2320639941808822], 
             UndirectedEdge[8, 194] -> 
             RGBColor[
              0.3983632803443602, 0.5194639839388066, 0.9466043338580932], 
             UndirectedEdge[63, 106] -> 
             RGBColor[
              0.3139521958632445, 0.44323609697402705`, 0.9413397986941987], 
             UndirectedEdge[129, 131] -> 
             RGBColor[
              0.9447591766437358, 0.8071223654903125, 0.32715623247964654`], 
             UndirectedEdge[22, 38] -> 
             RGBColor[
              0.8845506627730023, 0.5259516883218133, 0.23271022291823168`], 
             UndirectedEdge[38, 117] -> 
             RGBColor[
              0.8719033121193018, 0.8601154409020264, 0.6481970739440106], 
             UndirectedEdge[136, 159] -> 
             RGBColor[
              0.8510985318743886, 0.34103526757830527`, 0.19449118305288732`],
              UndirectedEdge[158, 166] -> 
             RGBColor[
              0.3220947514992546, 0.4482744245110126, 0.9419323901733808], 
             UndirectedEdge[75, 96] -> 
             RGBColor[
              0.29517906246073655`, 0.4275822884527116, 0.9401213829776245], 
             UndirectedEdge[118, 170] -> 
             RGBColor[
              0.5478364454002871, 0.6213592928020021, 0.9626450455228917], 
             UndirectedEdge[7, 58] -> 
             RGBColor[
              0.3073067839852605, 0.4364725367668565, 0.9409532535052085], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.7375823865275546, 0.7949242332798678, 0.9744789772559258], 
             UndirectedEdge[65, 180] -> 
             RGBColor[
              0.8230809086810591, 0.8625416428483053, 0.9827816578893989], 
             UndirectedEdge[151, 171] -> 
             RGBColor[
              0.6131733026438233, 0.690971104405486, 0.9657655862298374], 
             UndirectedEdge[37, 118] -> 
             RGBColor[
              0.5521506378695789, 0.625893782622829, 0.962890732401742], 
             UndirectedEdge[7, 47] -> 
             RGBColor[
              0.40099092685927107`, 0.5217399192806683, 0.9467717651704868], 
             UndirectedEdge[46, 99] -> 
             RGBColor[
              0.5809189759498203, 0.6706552206345228, 0.960151216244546], 
             UndirectedEdge[195, 197] -> 
             RGBColor[
              0.5339219968548683, 0.6098281490239381, 0.9613839452386224], 
             UndirectedEdge[5, 63] -> 
             RGBColor[
              0.3175297704097317, 0.4469963546537124, 0.9415435362720739], 
             UndirectedEdge[11, 63] -> 
             RGBColor[
              0.29935737823800995`, 0.4278960182850215, 0.9405086454215394], 
             UndirectedEdge[10, 193] -> 
             RGBColor[
              0.30300124599655587`, 0.4350697469532493, 0.9405937256719987], 
             UndirectedEdge[99, 147] -> 
             RGBColor[
              0.5223956840025993, 0.6231433757875112, 0.9555440483245787], 
             UndirectedEdge[9, 77] -> 
             RGBColor[
              0.2804804496400908, 0.41213311443233347`, 0.9392843187221377], 
             UndirectedEdge[43, 103] -> 
             RGBColor[
              0.8583405032831029, 0.4432646958215179, 0.2032585752880907], 
             UndirectedEdge[54, 174] -> 
             RGBColor[
              0.3271085364710258, 0.454423850539001, 0.942185710608396], 
             UndirectedEdge[149, 197] -> 
             RGBColor[
              0.5612425008846491, 0.6385437309792414, 0.9629398075260546], 
             UndirectedEdge[87, 180] -> 
             RGBColor[
              0.8560213723624259, 0.8868310086243191, 0.9110439947166469], 
             UndirectedEdge[134, 191] -> 
             RGBColor[
              0.25554145744836393`, 0.3859206524153965, 0.9378640800107516], 
             UndirectedEdge[65, 131] -> 
             RGBColor[
              0.9106761538385292, 0.7880776994423069, 0.6150413032300603], 
             UndirectedEdge[107, 147] -> 
             RGBColor[
              0.5739634519525214, 0.664627405018551, 0.9598641490933124], 
             UndirectedEdge[50, 82] -> 
             RGBColor[
              0.28041536130760697`, 0.41115377820056886`, 0.9393139654375977],
              UndirectedEdge[30, 162] -> 
             RGBColor[
              0.9383242239537981, 0.9524410659335498, 0.9517777399403218], 
             UndirectedEdge[51, 74] -> 
             RGBColor[
              0.29246128213975436`, 0.4247257290181345, 0.9399666094089402], 
             UndirectedEdge[12, 161] -> 
             RGBColor[
              0.4463108010091732, 0.5574383614954901, 0.9506399339170767], 
             UndirectedEdge[78, 113] -> 
             RGBColor[
              0.9141333132318434, 0.7927873365838396, 0.6157566218013946], 
             UndirectedEdge[131, 133] -> 
             RGBColor[
              0.8487047833512873, 0.33253448013330367`, 0.19259565627124703`],
              UndirectedEdge[35, 188] -> 
             RGBColor[
              0.7515136501309705, 0.8059560761959215, 0.9758280725478667], 
             UndirectedEdge[181, 185] -> 
             RGBColor[
              0.8769516134578437, 0.9038519112831478, 0.9435125496118522], 
             UndirectedEdge[111, 188] -> 
             RGBColor[
              0.5625749036995356, 0.6554211455005088, 0.9589406102153506], 
             UndirectedEdge[41, 184] -> 
             RGBColor[
              0.46042354235664473`, 0.5706000836629397, 0.9512819487659052], 
             UndirectedEdge[135, 187] -> 
             RGBColor[
              0.2580530598737554, 0.38856050580927426`, 0.9380071120532948], 
             UndirectedEdge[51, 71] -> 
             RGBColor[
              0.2862116459129269, 0.41815696509391576`, 0.9396107018713307], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.2532145568819805, 0.3834749323861105, 0.937731566465837], 
             UndirectedEdge[26, 158] -> 
             RGBColor[
              0.3248339638099492, 0.45064699253772245`, 0.9421069303596279], 
             UndirectedEdge[101, 199] -> 
             RGBColor[
              0.262066422777004, 0.3927788046824936, 0.9382356671333965], 
             UndirectedEdge[84, 194] -> 
             RGBColor[
              0.30565287667395435`, 0.4349127039944547, 0.9408525291212098], 
             UndirectedEdge[6, 176] -> 
             RGBColor[
              0.31712437457249, 0.4477537666594349, 0.9414771155265509], 
             UndirectedEdge[18, 116] -> 
             RGBColor[
              0.35397661933935576`, 0.48101848911472117`, 0.9437760550684375],
              UndirectedEdge[98, 179] -> 
             RGBColor[
              0.8907110607570355, 0.9148157520026807, 0.9556261844734377], 
             UndirectedEdge[116, 142] -> 
             RGBColor[
              0.5152359143739065, 0.6156001916611427, 0.9554585640817019], 
             UndirectedEdge[77, 112] -> 
             RGBColor[
              0.3009216795649535, 0.4336181431321977, 0.9404484165262689], 
             UndirectedEdge[56, 190] -> 
             RGBColor[
              0.1793170310330229, 0.30580394734510286`, 0.9335232116903315], 
             UndirectedEdge[76, 126] -> 
             RGBColor[
              0.2917876480797086, 0.4240176969101601, 0.9399282469457728], 
             UndirectedEdge[168, 173] -> 
             RGBColor[
              0.9668668867879184, 0.9728695829823109, 0.8506912832058626], 
             UndirectedEdge[158, 164] -> 
             RGBColor[
              0.27399405489207074`, 0.4053155022909841, 0.9389149281369991], 
             UndirectedEdge[46, 146] -> 
             RGBColor[
              0.6969184905099, 0.7624738200168288, 0.9708932713664746], 
             UndirectedEdge[23, 25] -> 
             RGBColor[
              0.9862503262702172, 0.9646170985208886, 0.4575613230413248], 
             UndirectedEdge[9, 28] -> 
             RGBColor[
              0.27767181401552266`, 0.4091810603131285, 0.9391243710783226], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.9239792736477469, 0.9412455241190165, 0.9588251826995514], 
             UndirectedEdge[103, 129] -> 
             RGBColor[
              0.9062804022305841, 0.6440404985324568, 0.2778692029903933], 
             UndirectedEdge[5, 48] -> 
             RGBColor[
              0.2996548823827041, 0.431514025062696, 0.9404045642131346], 
             UndirectedEdge[36, 169] -> 
             RGBColor[
              0.260181316759984, 0.39079743873598083`, 0.9381283131344916], 
             UndirectedEdge[159, 170] -> 
             RGBColor[
              0.6092180955157596, 0.21970986582421148`, 0.4241107151102475], 
             UndirectedEdge[86, 175] -> 
             RGBColor[
              0.356178745028919, 0.4829258597049654, 0.9439163725701132], 
             UndirectedEdge[9, 97] -> 
             RGBColor[
              0.2707641427587703, 0.4019206598506281, 0.9387309894192344], 
             UndirectedEdge[7, 88] -> 
             RGBColor[
              0.5313273656076622, 0.6265318924404168, 0.9577502738522159], 
             UndirectedEdge[5, 77] -> 
             RGBColor[
              0.2913005664473497, 0.42350574323179174`, 0.9399005083673827], 
             UndirectedEdge[103, 131] -> 
             RGBColor[
              0.8759467260841297, 0.5295848811738163, 0.2181992462316507], 
             UndirectedEdge[15, 193] -> 
             RGBColor[
              0.32089862240878825`, 0.45236799072193, 0.941668354353746], 
             UndirectedEdge[167, 181] -> 
             RGBColor[
              0.9498028388938546, 0.9615340502113876, 0.9505692894275887], 
             UndirectedEdge[99, 146] -> 
             RGBColor[
              0.6800950161218604, 0.7488157656197341, 0.9695688658362309], 
             UndirectedEdge[163, 177] -> 
             RGBColor[
              0.2633144670135955, 0.39409057830572625`, 0.9383067414063544], 
             UndirectedEdge[76, 116] -> 
             RGBColor[
              0.3329665446591801, 0.4598254152907607, 0.9425469807473624], 
             UndirectedEdge[15, 59] -> 
             RGBColor[
              0.38695782791817696`, 0.5095851543019536, 0.9458775885149424], 
             UndirectedEdge[36, 151] -> 
             RGBColor[
              0.2998281417164218, 0.4284810612879339, 0.9405321505496939], 
             UndirectedEdge[38, 98] -> 
             RGBColor[
              0.9691483293293262, 0.9363502220297157, 0.6237743204922899], 
             UndirectedEdge[70, 139] -> 
             RGBColor[
              0.23141666930631707`, 0.36056397047819155`, 0.9364902090154877],
              UndirectedEdge[56, 195] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[66, 168] -> 
             RGBColor[
              0.8151061747990456, 0.8563704613486036, 0.9793645875552226], 
             UndirectedEdge[6, 161] -> 
             RGBColor[
              0.32435538961719373`, 0.45535402194425245`, 0.9418889111360187],
              UndirectedEdge[56, 118] -> 
             RGBColor[
              0.5461172634712221, 0.619552323592125, 0.9625471406553332], 
             UndirectedEdge[46, 117] -> 
             RGBColor[
              0.6883704009191991, 0.7557959874606861, 0.9700412776825125], 
             UndirectedEdge[79, 89] -> 
             RGBColor[
              0.637317539505268, 0.3879136396684716, 0.4445332384990521], 
             UndirectedEdge[102, 140] -> 
             RGBColor[
              0.3396692909282838, 0.4683264235730946, 0.9428753810499368], 
             UndirectedEdge[32, 130] -> 
             RGBColor[
              0.23618787859936186`, 0.36557881395732306`, 0.936761922326355], 
             UndirectedEdge[105, 126] -> 
             RGBColor[
              0.3252176564982815, 0.45596829309429976`, 0.9419487084621424], 
             UndirectedEdge[86, 124] -> 
             RGBColor[
              0.3415070368558193, 0.46858226157491756`, 0.94304139535942], 
             UndirectedEdge[41, 168] -> 
             RGBColor[
              0.7441532266042006, 0.7995222771759883, 0.9732629767804062], 
             UndirectedEdge[43, 143] -> 
             RGBColor[
              0.8438430647127526, 0.3380025843014858, 0.18961747432357834`], 
             UndirectedEdge[56, 197] -> 
             RGBColor[
              0.5339219968548683, 0.6098281490239381, 0.9613839452386224], 
             UndirectedEdge[47, 73] -> 
             RGBColor[
              0.3723282317178833, 0.495470365317321, 0.9449982523567235], 
             UndirectedEdge[23, 108] -> 
             RGBColor[
              0.8874058680057144, 0.9088494378884622, 0.7606689085618024], 
             UndirectedEdge[97, 155] -> 
             RGBColor[
              0.2652922598561954, 0.3961693639826077, 0.9384193737828581], 
             UndirectedEdge[86, 161] -> 
             RGBColor[
              0.35030928053797133`, 0.47783397777934283`, 0.943542670115366], 
             UndirectedEdge[88, 188] -> 
             RGBColor[
              0.688424300235651, 0.7565215626533395, 0.9695793586227837], 
             UndirectedEdge[136, 197] -> 
             RGBColor[
              0.8984618333218767, 0.7936232208649558, 0.6170525520201404], 
             UndirectedEdge[65, 69] -> 
             RGBColor[
              0.6618396215787897, 0.7314857264416685, 0.9696204831011173], 
             UndirectedEdge[23, 67] -> 
             RGBColor[
              0.8766635128599496, 0.4235199407908321, 0.29088079851236637`], 
             UndirectedEdge[31, 121] -> 
             RGBColor[
              0.6965919354102337, 0.7616218744062735, 0.9713719956909121], 
             UndirectedEdge[52, 145] -> 
             RGBColor[
              0.21010927874609994`, 0.3381685520328137, 0.9352767846445429], 
             UndirectedEdge[12, 87] -> 
             RGBColor[
              0.7859686037949694, 0.8312106955650405, 0.9046734035026598], 
             UndirectedEdge[128, 192] -> 
             RGBColor[
              0.8414065048905258, 0.286583757221212, 0.1860041493494229], 
             UndirectedEdge[78, 95] -> 
             RGBColor[
              0.9537951709684989, 0.944166482218568, 0.6841709176231596], 
             UndirectedEdge[123, 165] -> 
             RGBColor[
              0.23466718379435303`, 0.36398046729963934`, 0.9366753210068761],
              UndirectedEdge[24, 56] -> 
             RGBColor[
              0.1789270014196926, 0.30539400149218693`, 0.9335010000808495], 
             UndirectedEdge[50, 177] -> 
             RGBColor[
              0.2679195346173776, 0.39893079633545114`, 0.9385689931938027], 
             UndirectedEdge[18, 58] -> 
             RGBColor[
              0.2912619493997384, 0.4225753074857117, 0.9399308908333093], 
             UndirectedEdge[96, 182] -> 
             RGBColor[
              0.2856601600419676, 0.4175773184773137, 0.9395792955668297], 
             UndirectedEdge[49, 131] -> 
             RGBColor[
              0.8562446232823608, 0.3904889938224607, 0.19981581550427432`], 
             UndirectedEdge[28, 106] -> 
             RGBColor[
              0.28491435627629447`, 0.41679343143290143`, 0.9395368231456924],
              UndirectedEdge[57, 81] -> 
             RGBColor[
              0.4684558639722499, 0.5768344890925647, 0.951993469629622], 
             UndirectedEdge[7, 115] -> 
             RGBColor[
              0.3080070225358357, 0.4372085318811994, 0.9409931310547537], 
             UndirectedEdge[54, 94] -> 
             RGBColor[
              0.3454669572962359, 0.47032499193673805`, 0.9433554929496641], 
             UndirectedEdge[138, 181] -> 
             RGBColor[
              0.9485527902505714, 0.8398398392439036, 0.5790165148890076], 
             UndirectedEdge[55, 182] -> 
             RGBColor[
              0.30875284137949693`, 0.43781473937303605`, 0.9410421106336347],
              UndirectedEdge[17, 77] -> 
             RGBColor[
              0.26961618509412616`, 0.4007140835603673, 0.9386656149284841], 
             UndirectedEdge[144, 149] -> 
             RGBColor[
              0.648866599779832, 0.4112160653555213, 0.44670623587921776`], 
             UndirectedEdge[68, 179] -> 
             RGBColor[
              0.8317792747849202, 0.8687996297404257, 0.9837911974570385], 
             UndirectedEdge[103, 143] -> 
             RGBColor[
              0.8497933193438173, 0.37139574051451657`, 0.1948321197121974], 
             UndirectedEdge[80, 173] -> 
             RGBColor[
              0.807519241461194, 0.8471578477354111, 0.8378854904784999], 
             UndirectedEdge[161, 199] -> 
             RGBColor[
              0.2904737372287366, 0.422636693299029, 0.9398534216665669], 
             UndirectedEdge[43, 133] -> 
             RGBColor[
              0.8447195319166816, 0.3447394953012616, 0.19045678030788885`], 
             UndirectedEdge[6, 193] -> 
             RGBColor[
              0.3283691499935347, 0.4588385862362035, 0.9421443697655179], 
             UndirectedEdge[181, 188] -> 
             RGBColor[
              0.8244919498408892, 0.8628700233573725, 0.9382838606059434], 
             UndirectedEdge[120, 173] -> 
             RGBColor[
              0.9759551315276564, 0.9289248083741766, 0.49955341569398815`], 
             UndirectedEdge[2, 158] -> 
             RGBColor[
              0.31519292647680297`, 0.4422964105723771, 0.9414926119859944], 
             UndirectedEdge[95, 143] -> 
             RGBColor[
              0.8737408987697657, 0.4215594185967958, 0.23681679715422363`], 
             UndirectedEdge[4, 172] -> 
             RGBColor[
              0.8994312173900378, 0.9185136164944618, 0.783483838768104], 
             UndirectedEdge[89, 113] -> 
             RGBColor[
              0.8694288542290634, 0.4907346699510474, 0.21239820772463422`], 
             UndirectedEdge[34, 90] -> 
             RGBColor[
              0.31984837730012083`, 0.4461884593191548, 0.9417943891224722], 
             UndirectedEdge[28, 48] -> 
             RGBColor[
              0.30593974734452445`, 0.4381198166210231, 0.9407624779750857], 
             UndirectedEdge[5, 189] -> 
             RGBColor[
              0.2567992205359049, 0.38724264116718776`, 0.9379357077578933], 
             UndirectedEdge[8, 55] -> 
             RGBColor[
              0.4002897149094885, 0.5211325647337041, 0.9467270845651039], 
             UndirectedEdge[29, 138] -> 
             RGBColor[
              0.9532093472510355, 0.8417654452316519, 0.5018453146080967], 
             UndirectedEdge[8, 68] -> 
             RGBColor[
              0.6519110948314109, 0.7251718951051506, 0.9679355855003635], 
             UndirectedEdge[176, 187] -> 
             RGBColor[
              0.2885120341406341, 0.42057481897427373`, 0.9397417055777791], 
             UndirectedEdge[65, 133] -> 
             RGBColor[
              0.8563164442942707, 0.43429365345994053`, 0.44418899353026553`],
              UndirectedEdge[68, 147] -> 
             RGBColor[
              0.668160340209887, 0.7385028014791089, 0.9691763692944251], 
             UndirectedEdge[89, 192] -> 
             RGBColor[
              0.8417678220858125, 0.32205136009370555`, 0.18763021964036905`],
              UndirectedEdge[2, 74] -> 
             RGBColor[
              0.3399517025683613, 0.46831945404167635`, 0.9429025876570818], 
             UndirectedEdge[156, 185] -> 
             RGBColor[
              0.8452085345226001, 0.8798178098671724, 0.9849898137223804], 
             UndirectedEdge[126, 182] -> 
             RGBColor[
              0.2861743087287016, 0.41811772134598074`, 0.9396085755739244], 
             UndirectedEdge[18, 188] -> 
             RGBColor[
              0.49151222590235866`, 0.5940651201386887, 0.9543587093121076], 
             UndirectedEdge[68, 156] -> 
             RGBColor[
              0.8882342803358891, 0.9137179209353309, 0.9892017726661817], 
             UndirectedEdge[29, 181] -> 
             RGBColor[
              0.988986461566373, 0.9897136330697374, 0.8321863641764009], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.9759778030702638, 0.9313399748264705, 0.5237839339684474], 
             UndirectedEdge[30, 180] -> 
             RGBColor[
              0.8089076786179981, 0.8512402939181014, 0.9814298025533923], 
             UndirectedEdge[31, 196] -> 
             RGBColor[
              0.6728409042264264, 0.742339717319497, 0.969502227513229], 
             UndirectedEdge[193, 199] -> 
             RGBColor[
              0.2944874976050776, 0.4261212575909801, 0.9401088802960662], 
             UndirectedEdge[30, 110] -> 
             RGBColor[
              0.7493871054318795, 0.8041704915393881, 0.9758883443405271], 
             UndirectedEdge[12, 59] -> 
             RGBColor[
              0.516383766894903, 0.6181400893674647, 0.9551046267077723], 
             UndirectedEdge[38, 156] -> 
             RGBColor[
              0.9428260097167436, 0.9163360030821683, 0.6550496534880772], 
             UndirectedEdge[72, 152] -> 
             RGBColor[
              0.2658080334878341, 0.396711474771397, 0.9384487463281612], 
             UndirectedEdge[37, 79] -> 
             RGBColor[
              0.19748095052754017`, 0.3248953783928531, 0.9345576200344334], 
             UndirectedEdge[170, 197] -> 
             RGBColor[
              0.5356411787839332, 0.6116351182338152, 0.9614818501061808], 
             UndirectedEdge[86, 127] -> 
             RGBColor[
              0.3567736173469446, 0.48344110820768715`, 0.9439542773081928], 
             UndirectedEdge[69, 127] -> 
             RGBColor[
              0.3615866192833338, 0.48760988857647636`, 0.944260957535609], 
             UndirectedEdge[58, 61] -> 
             RGBColor[
              0.26897522612323943`, 0.4000403950428194, 0.9386291132633059], 
             UndirectedEdge[11, 17] -> 
             RGBColor[
              0.24235029233601593`, 0.3720559015141443, 0.9371128626721834], 
             UndirectedEdge[11, 15] -> 
             RGBColor[
              0.28548651926913327`, 0.4158817774158234, 0.9396248065535615], 
             UndirectedEdge[111, 157] -> 
             RGBColor[
              0.5090903091480017, 0.6123414730802424, 0.9544966004768307], 
             UndirectedEdge[75, 191] -> 
             RGBColor[
              0.2821961080105196, 0.4139363801586776, 0.9393820229282445], 
             UndirectedEdge[98, 156] -> 
             RGBColor[
              0.9471660663080045, 0.9597340431975859, 0.961036759682581], 
             UndirectedEdge[28, 140] -> 
             RGBColor[
              0.3001402263093852, 0.4327967862135973, 0.9404039139194207], 
             UndirectedEdge[105, 157] -> 
             RGBColor[
              0.4504475650892219, 0.5617429700786016, 0.9507060867688824], 
             UndirectedEdge[3, 15] -> 
             RGBColor[
              0.2943870608658776, 0.4252368109609329, 0.9401316792303248], 
             UndirectedEdge[55, 96] -> 
             RGBColor[
              0.32928937279498216`, 0.459399935982008, 0.942211635716671], 
             UndirectedEdge[6, 64] -> 
             RGBColor[
              0.4813272203866353, 0.5867267043563145, 0.9531607423711013], 
             UndirectedEdge[70, 134] -> 
             RGBColor[
              0.2222636314959646, 0.3509435474033953, 0.9359689570528942], 
             UndirectedEdge[106, 140] -> 
             RGBColor[
              0.29027778680107763`, 0.4224307369755848, 0.9398422625795944], 
             UndirectedEdge[64, 154] -> 
             RGBColor[
              0.8045650840099676, 0.8465963466235498, 0.9181848867101159], 
             UndirectedEdge[8, 157] -> 
             RGBColor[
              0.5029410908496337, 0.6072102236909507, 0.9540509278121335], 
             UndirectedEdge[83, 124] -> 
             RGBColor[
              0.2734514125634414, 0.4047451507980839, 0.9388840254591511], 
             UndirectedEdge[22, 128] -> 
             RGBColor[
              0.8594750767508397, 0.42546671823825916`, 0.20330663416839254`],
              UndirectedEdge[83, 135] -> 
             RGBColor[
              0.244563666934011, 0.3743822985526921, 0.9372389110811449], 
             UndirectedEdge[62, 68] -> 
             RGBColor[
              0.6059297438464823, 0.6853451599719039, 0.965005694475316], 
             UndirectedEdge[105, 116] -> 
             RGBColor[
              0.36639655307775293`, 0.49177601147490035`, 0.944567442263732], 
             UndirectedEdge[93, 145] -> 
             RGBColor[
              0.21595172710093502`, 0.34430933568636624`, 0.935609503435223], 
             UndirectedEdge[128, 195] -> 
             RGBColor[
              0.5342542573357888, 0.44844563583181796`, 0.5815387240241343], 
             UndirectedEdge[87, 154] -> 
             RGBColor[
              0.9872510560263222, 0.9889959982810382, 0.8609465250606165], 
             UndirectedEdge[138, 167] -> 
             RGBColor[
              0.914025724578517, 0.8135858623733021, 0.6202282398592844], 
             UndirectedEdge[179, 194] -> 
             RGBColor[
              0.5782314602978695, 0.6630917185740817, 0.9624599458147682], 
             UndirectedEdge[118, 144] -> 
             RGBColor[
              0.8754464394074596, 0.6015112264467356, 0.4650330881244851], 
             UndirectedEdge[47, 188] -> 
             RGBColor[
              0.5580878614872598, 0.6517295894935908, 0.9586008499410545], 
             UndirectedEdge[11, 20] -> 
             RGBColor[
              0.2356317618329697, 0.3649942999760054, 0.93673025229921], 
             UndirectedEdge[124, 187] -> 
             RGBColor[
              0.2869408055031858, 0.4189233580546661, 0.939652226431301], 
             UndirectedEdge[28, 189] -> 
             RGBColor[
              0.26308408549772533`, 0.39384843272551495`, 0.9382936215198444],
              UndirectedEdge[84, 93] -> 
             RGBColor[
              0.24346208091315458`, 0.3732244618001842, 0.9371761773869076], 
             UndirectedEdge[18, 94] -> 
             RGBColor[
              0.36824895343507874`, 0.4933804675600669, 0.9446854755764875], 
             UndirectedEdge[146, 156] -> 
             RGBColor[
              0.8584691386886809, 0.8901770946260392, 0.9863115068182637], 
             UndirectedEdge[2, 26] -> 
             RGBColor[
              0.3867618425079842, 0.5094154015901577, 0.945865100497908], 
             UndirectedEdge[124, 161] -> 
             RGBColor[
              0.29985672336199365`, 0.43249880664076373`, 0.9403877688459719],
              UndirectedEdge[25, 67] -> 
             RGBColor[
              0.8717776309273555, 0.4074814902998567, 0.23424954998350475`], 
             UndirectedEdge[15, 77] -> 
             RGBColor[
              0.31275241202724346`, 0.4445399594620464, 0.9411775588098623], 
             UndirectedEdge[23, 49] -> 
             RGBColor[
              0.8876847855307123, 0.5082342720907941, 0.3014347816686359], 
             UndirectedEdge[27, 37] -> 
             RGBColor[
              0.23387138917519362`, 0.3631440366986098, 0.9366300016805876], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.28199072307706635`, 0.41303118579725295`, 0.9393955660070041],
              UndirectedEdge[134, 139] -> 
             RGBColor[
              0.2400051701500614, 0.36959102940737165`, 0.9369793114329906], 
             UndirectedEdge[13, 127] -> 
             RGBColor[
              0.34979347533914956`, 0.4773952600326733, 0.9435095088317533], 
             UndirectedEdge[59, 186] -> 
             RGBColor[
              0.36541764511564734`, 0.4884580900498052, 0.9445955073983169], 
             UndirectedEdge[119, 149] -> 
             RGBColor[
              0.3992231896957711, 0.5102289495476822, 0.9477505828326117], 
             UndirectedEdge[41, 66] -> 
             RGBColor[
              0.6206670435279176, 0.7021698769586107, 0.9637962645099678], 
             UndirectedEdge[25, 103] -> 
             RGBColor[
              0.9025010063998871, 0.6312917089511744, 0.2631869638671507], 
             UndirectedEdge[164, 166] -> 
             RGBColor[
              0.3428237586125573, 0.4700619252820549, 0.9431128764626655], 
             UndirectedEdge[30, 90] -> 
             RGBColor[
              0.6408480095261183, 0.7142786377339077, 0.9678341664939911], 
             UndirectedEdge[75, 182] -> 
             RGBColor[
              0.27464253104525127`, 0.40599709184373967`, 0.9389518578945881],
              UndirectedEdge[92, 97] -> 
             RGBColor[
              0.2548383832137916, 0.38518167681737986`, 0.9378240409731977], 
             UndirectedEdge[18, 61] -> 
             RGBColor[
              0.2960837334123488, 0.42764330820172913`, 0.9402054842996372], 
             UndirectedEdge[76, 191] -> 
             RGBColor[
              0.2782905449427576, 0.40983138574745914`, 0.9391596068892982], 
             UndirectedEdge[129, 197] -> 
             RGBColor[
              0.939588342286577, 0.9465340447880747, 0.7029640290475025], 
             UndirectedEdge[97, 112] -> 
             RGBColor[
              0.2912053726836331, 0.4234056885504923, 0.9398950872233656], 
             UndirectedEdge[87, 131] -> 
             RGBColor[
              0.9436166175198961, 0.8123670652183208, 0.5433036400573084], 
             UndirectedEdge[33, 198] -> 
             RGBColor[
              0.5096004354679522, 0.6083940896440386, 0.956077633424264], 
             UndirectedEdge[39, 114] -> 
             RGBColor[
              0.20908858865686974`, 0.3370957420335433, 0.935218657853937], 
             UndirectedEdge[144, 170] -> 
             RGBColor[
              0.631799051712688, 0.39327699019190376`, 0.44573426426596857`], 
             UndirectedEdge[64, 110] -> 
             RGBColor[
              0.6138148271599528, 0.6973615545881173, 0.9627408981532811], 
             UndirectedEdge[108, 131] -> 
             RGBColor[
              0.8402456246331873, 0.7322315204859621, 0.6082404593152602], 
             UndirectedEdge[33, 141] -> 
             RGBColor[
              0.3411893210123498, 0.46994277401217005`, 0.9429612597264045], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.6032826317786147, 0.6888110439075521, 0.9619117651521593], 
             UndirectedEdge[88, 142] -> 
             RGBColor[
              0.6765418260566909, 0.7472163657056936, 0.968410420193581], 
             UndirectedEdge[12, 95] -> 
             RGBColor[
              0.7817942234386319, 0.8080307104936368, 0.6678706900642806], 
             UndirectedEdge[131, 162] -> 
             RGBColor[
              0.941079962602384, 0.8111036548737982, 0.5757395893878008], 
             UndirectedEdge[21, 194] -> 
             RGBColor[
              0.33236539581814195`, 0.4622999335123229, 0.9423990070157204], 
             UndirectedEdge[131, 154] -> 
             RGBColor[
              0.9428931009304802, 0.8120678725150692, 0.5552941823448407], 
             UndirectedEdge[81, 184] -> 
             RGBColor[
              0.47373340289000515`, 0.5814056280463057, 0.952329749742717], 
             UndirectedEdge[105, 111] -> 
             RGBColor[
              0.4018530682244218, 0.5222917683666206, 0.9468805499681779]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 71 -> 
             RGBColor[
              0.2902833275082297, 0.42243656061010276`, 0.93984257811467], 10 -> 
             RGBColor[
              0.28931600419628395`, 0.4214198424774074, 0.9397874904830813], 
             68 -> RGBColor[
              0.8556248139763563, 0.8877160176206234, 0.9860914526539951], 
             155 -> RGBColor[
              0.24962306644129345`, 0.3797000482193023, 0.9375270363983738], 
             132 -> RGBColor[
              0.2522143608002516, 0.3824236628881191, 0.93767460677864], 26 -> 
             RGBColor[
              0.39640287984113043`, 0.5177659835555031, 0.9464794188715415], 
             29 -> RGBColor[
              0.9936430185668372, 0.9916392390574856, 0.75501516389549], 113 -> 
             RGBColor[
              0.9003020964297527, 0.6401769295720257, 0.2385219642527955], 50 -> 
             RGBColor[
              0.2422322948146241, 0.37193187863768656`, 0.9371061428879017], 
             173 -> RGBColor[
              0.9951414157005084, 0.9920163043986404, 0.7125512665860644], 
             192 -> RGBColor[0.817319, 0.134127, 0.164218], 165 -> 
             RGBColor[
              0.21890292553398902`, 0.347411232356294, 0.9357775698200786], 
             92 -> RGBColor[
              0.22871531315648586`, 0.35772467388884666`, 0.9363363707790532],
              11 -> RGBColor[
              0.24586228151751777`, 0.37574722481687783`, 0.9373128652605475],
              137 -> RGBColor[
              0.2501870825879037, 0.38029286495007875`, 0.9375591562835361], 
             120 -> RGBColor[
              0.9567688473548046, 0.8658333123497126, 0.2865555648019119], 51 -> 
             RGBColor[
              0.28213996431762406`, 0.4138773695777287, 0.9393788256279912], 
             72 -> RGBColor[
              0.24987650973082426`, 0.37996643318583184`, 0.9375414696187768],
              64 -> RGBColor[
              0.6226026285830288, 0.704495887669313, 0.963432706072083], 41 -> 
             RGBColor[
              0.5497140953330726, 0.6453216927859953, 0.9576946537351515], 
             103 -> RGBColor[
              0.8642907579141675, 0.4766578520345487, 0.20847322067670976`], 
             162 -> RGBColor[
              0.9829012627807141, 0.9867683702952449, 0.9138278814340688], 
             196 -> RGBColor[
              0.49517344266125934`, 0.6010431339186144, 0.9534010137678327], 
             179 -> RGBColor[
              0.807933735593484, 0.8498832418602281, 0.9814909422600818], 160 -> 
             RGBColor[
              0.36671177852496323`, 0.4920490439135823, 0.9445875281504853], 
             123 -> RGBColor[
              0.250431442054717, 0.3805497022429847, 0.9375730721936737], 150 -> 
             RGBColor[
              0.2829267708206377, 0.41470435309880965`, 0.9394236330943619], 
             188 -> RGBColor[
              0.6646539951158695, 0.737952019632756, 0.9672101567545748], 46 -> 
             RGBColor[
              0.5977424503378598, 0.6843132750316175, 0.9614756217747897], 
             182 -> RGBColor[
              0.2651236286264823, 0.39599212186834176`, 0.9384097704837935], 
             6 -> RGBColor[
              0.3400518121902417, 0.46895752104331584`, 0.9428887786701194], 
             131 -> RGBColor[
              0.8992586624240541, 0.6354389394523516, 0.23765129734153262`], 
             45 -> RGBColor[
              0.8843599871114161, 0.5677875345316877, 0.22521947746071738`], 
             195 -> RGBColor[0.178927, 0.305394, 0.933501], 148 -> 
             RGBColor[
              0.20479309393410217`, 0.332580904729819, 0.9349740357840903], 
             161 -> RGBColor[
              0.30865896704414575`, 0.441750522845189, 0.9408890436019178], 1 -> 
             RGBColor[
              0.9583125875736904, 0.8710407105954553, 0.2925527040414048], 
             101 -> RGBColor[
              0.2518443381406806, 0.38203474561211825`, 0.9376535345355769], 
             12 -> RGBColor[
              0.5839626349742006, 0.6731262001457912, 0.9603908242322355], 39 -> 
             RGBColor[
              0.20098973591686892`, 0.3285833343068806, 0.9347574401715728], 
             48 -> RGBColor[
              0.3171026989044469, 0.4490801525711323, 0.9414264814646527], 77 -> 
             RGBColor[
              0.3003940670337382, 0.43306358890932384`, 0.940418369773149], 
             56 -> RGBColor[0.178927, 0.305394, 0.933501], 110 -> 
             RGBColor[
              0.6050270257368769, 0.6902272215069217, 0.9620490902344793], 73 -> 
             RGBColor[
              0.2931347355771166, 0.42543357128021636`, 0.9400049615859128], 
             37 -> RGBColor[
              0.19099374879671333`, 0.31807691806140814`, 0.9341881834928177],
              130 -> RGBColor[
              0.23722409174651585`, 0.3666679396746901, 0.9368209331321454], 
             107 -> RGBColor[
              0.6672310374616252, 0.7399652246995075, 0.9674670122517698], 59 -> 
             RGBColor[
              0.44880489881560515`, 0.5631539785891382, 0.949818429183309], 
             47 -> RGBColor[
              0.4515217278586501, 0.5655071593544256, 0.9499915431275343], 
             159 -> RGBColor[
              0.8226444613445744, 0.17506082952644003`, 0.16931766779781277`],
              55 -> RGBColor[
              0.35238205413251156`, 0.47963735687773035`, 0.943674450783476], 
             49 -> RGBColor[
              0.8347376037115143, 0.26801402100751526`, 0.1808980745856452], 
             82 -> RGBColor[
              0.31859842780058983`, 0.45037567776345117`, 0.9415217879872938],
              199 -> RGBColor[
              0.27228850741332744`, 0.40352286375286894`, 0.938817799731216], 
             89 -> RGBColor[
              0.8539922331287186, 0.4160135401405583, 0.19933632946055357`], 
             144 -> RGBColor[
              0.8565158956399671, 0.43541151607797846`, 0.2017529915313943], 
             78 -> RGBColor[
              0.9279645300339343, 0.9453977435956535, 0.9929912793499938], 42 -> 
             RGBColor[
              0.5214414667269106, 0.6223686992161088, 0.9554689288452234], 
             154 -> RGBColor[
              0.9865275394369064, 0.9886968055777866, 0.8729370673481489], 
             168 -> RGBColor[
              0.9385923578753286, 0.9537228615659814, 0.988831299825661], 121 -> 
             RGBColor[
              0.5426755050288741, 0.6396074480921672, 0.9571405501231992], 
             128 -> RGBColor[
              0.8895815146715775, 0.5914972716636359, 0.22957644804826868`], 
             115 -> RGBColor[
              0.2655539192117794, 0.3964443845554878, 0.9384342748960682], 61 -> 
             RGBColor[
              0.2737970101358498, 0.4051083957588368, 0.9389037067296339], 93 -> 
             RGBColor[
              0.22414759348065547`, 0.35292371089939434`, 0.9360762459008504],
              88 -> RGBColor[
              0.7121946053554326, 0.7750911056739228, 0.9719485604909927], 21 -> 
             RGBColor[
              0.31620160663402885`, 0.4482996717367106, 0.9413690646619862], 
             62 -> RGBColor[
              0.3562346737166085, 0.4829743023231845, 0.943919936296637], 136 -> 
             RGBColor[
              0.9080066729340168, 0.6729841436820356, 0.24483821356303642`], 
             190 -> RGBColor[
              0.1797070620660458, 0.3062138946902057, 0.9335454233806629], 57 -> 
             RGBColor[
              0.3605779115447064, 0.4867361966324024, 0.9441966835704689], 
             111 -> RGBColor[
              0.4604958122832016, 0.5728902713682614, 0.9506710636761264], 63 -> 
             RGBColor[
              0.35285247495850214`, 0.48004481175316516`, 0.9437044255825313],
              75 -> RGBColor[
              0.28416143346402023`, 0.4160020618191376, 0.9394939453053829], 
             30 -> RGBColor[
              0.8937471851268821, 0.9181137615718546, 0.9897275984465748], 5 -> 
             RGBColor[
              0.2822070658609612, 0.41394789755425965`, 0.9393826469616164], 
             171 -> RGBColor[
              0.8744701613749067, 0.9027427860928997, 0.9878889387123091], 
             102 -> RGBColor[
              0.37383492502239923`, 0.4982187553899085, 0.9450414087465508], 
             31 -> RGBColor[
              0.8505083657915934, 0.8836363007203797, 0.9856034412586252], 96 -> 
             RGBColor[
              0.3061966914574528, 0.4391625150862857, 0.940748820649866], 70 -> 
             RGBColor[
              0.21367513065222027`, 0.34191648847421524`, 0.9354798546353913],
              52 -> RGBColor[
              0.21246269677098534`, 0.3406421435922893, 0.9354108083194902], 
             183 -> RGBColor[
              0.859910479347665, 0.45676803010411193`, 0.20481820887036734`], 
             158 -> RGBColor[
              0.25326504777876796`, 0.3835280015199418, 0.9377344418477144], 
             13 -> RGBColor[
              0.3779993100162068, 0.5018257363634689, 0.9453067596759351], 
             170 -> RGBColor[
              0.1823653638581298, 0.3090079384197544, 0.933696809735117], 86 -> 
             RGBColor[
              0.3919595940317969, 0.5139174327134967, 0.9461962966288141], 18 -> 
             RGBColor[
              0.3183704566888478, 0.45017822064462143`, 0.9415072618696405], 
             153 -> RGBColor[
              0.585970074369736, 0.674755929881201, 0.960548857214945], 58 -> 
             RGBColor[
              0.264153442110629, 0.394972394326802, 0.9383545197969779], 22 -> 
             RGBColor[
              0.8444218577904707, 0.34245144152557083`, 0.19017172722845446`],
              66 -> RGBColor[
              0.6916199917227627, 0.7590180611312259, 0.9698978752847841], 
             143 -> RGBColor[
              0.8207984422031169, 0.16087151747445233`, 0.16754991778317269`],
              119 -> RGBColor[
              0.5648783713319804, 0.6576327351847573, 0.9588884410903589], 
             145 -> RGBColor[
              0.20775586072121455`, 0.33569496047333813`, 0.9351427609695957],
              91 -> RGBColor[
              0.8378176201564483, 0.8735170446320284, 0.9843929866107827], 
             177 -> RGBColor[
              0.29360677442013106`, 0.4259297140332158, 0.9400318434997037], 
             200 -> RGBColor[
              0.23658832296539867`, 0.36599970637566703`, 0.9367847270405965],
              114 -> RGBColor[
              0.21718744139687057`, 0.3456081497602061, 0.935679875536301], 
             24 -> RGBColor[
              0.17892700283938517`, 0.30539400298437386`, 0.9335010001616988],
              176 -> RGBColor[
              0.29419693695473825`, 0.4265500122755539, 0.9400654523829823], 
             79 -> RGBColor[
              0.20396815225836698`, 0.3317138387242981, 0.934927056576049], 
             109 -> RGBColor[
              0.3375430035907792, 0.46678451713084806`, 0.942728919604614], 
             135 -> RGBColor[
              0.23327898842098083`, 0.3625213859455549, 0.9365962653340136], 
             108 -> RGBColor[
              0.7812325868423204, 0.8290241015195725, 0.9788296212889877], 
             191 -> 
             RGBColor[
              0.28023078255701894`, 0.41187069849821767`, 0.939270100551106], 
             14 -> RGBColor[
              0.4167727741971154, 0.535409362225998, 0.9477773705275145], 185 -> 
             RGBColor[
              0.7695733223497783, 0.8199157954843064, 0.9776675347663926], 32 -> 
             RGBColor[
              0.23515166545220784`, 0.36448968823995603`, 0.9367029115205646],
              122 -> RGBColor[
              0.9929383277496677, 0.9873041220381521, 0.47275873901987264`], 
             187 -> RGBColor[
              0.28282713132653, 0.41459962567299363`, 0.939417958772576], 193 -> 
             RGBColor[
              0.31668648779682773`, 0.44871965142909115`, 0.9413999608609163],
              100 -> RGBColor[
              0.21381427791123173`, 0.3420627410658821, 0.9354877788659421], 
             180 -> RGBColor[
              0.7240681721091139, 0.7843668262643483, 0.9731320066602097], 7 -> 
             RGBColor[
              0.350460125859892, 0.477972679206911, 0.9435519872134391], 175 -> 
             RGBColor[
              0.320397896026041, 0.45193428669643415`, 0.9416364485114123], 9 -> 
             RGBColor[
              0.2605668322464433, 0.39120263995534316`, 0.9381502676711264], 
             90 -> RGBColor[
              0.3879488339253545, 0.5104435138959607, 0.9459407345414075], 
             174 -> RGBColor[
              0.3814106085308894, 0.5047804316800383, 0.9455241246007979], 
             142 -> RGBColor[
              0.6408890467579492, 0.7193416257374643, 0.9648722798961695], 
             134 -> RGBColor[
              0.23085213233970892`, 0.3599706063325754, 0.9364580594703971], 
             105 -> RGBColor[
              0.34321032416564207`, 0.47169326536497985`, 0.9430900362602295],
              16 -> RGBColor[
              0.3229612837478847, 0.4541545643014821, 0.9417997853103334], 
             139 -> RGBColor[
              0.24915820796041388`, 0.3792114524821679, 0.9375005633955842], 
             146 -> RGBColor[
              0.79609453068194, 0.84063436500204, 0.9803109209581594], 126 -> 
             RGBColor[
              0.30722498883092086`, 0.4402433208236197, 0.9408073806640553], 
             198 -> RGBColor[
              0.6961608186542636, 0.7625653896416773, 0.9703504624768758], 40 -> 
             RGBColor[
              0.49158142165721236`, 0.5981269694488269, 0.9531182367163876], 
             104 -> RGBColor[
              0.21893481250696653`, 0.34744474758664423`, 0.9357793857360172],
              181 -> 
             RGBColor[
              0.984329904565909, 0.9877880270819891, 0.9093575644573119], 127 -> 
             RGBColor[
              0.32158764066209233`, 0.4529647837018777, 0.9417122579875715], 
             76 -> RGBColor[
              0.27635030732849636`, 0.40779207299670056`, 0.9390491132274904],
              172 -> RGBColor[
              0.9939767127007667, 0.98952512245173, 0.5857805327779135], 84 -> 
             RGBColor[
              0.2627765683456537, 0.3935252127009741, 0.9382761088729649], 
             184 -> RGBColor[
              0.3711329893802169, 0.49587847453988415`, 0.9448692437966588], 
             151 -> RGBColor[
              0.3518764439127397, 0.4791994227180725, 0.9436422337473658], 35 -> 
             RGBColor[
              0.8383733051460716, 0.8739601327590868, 0.9844459883411588], 36 -> 
             RGBColor[
              0.24777983952010385`, 0.3777626998577953, 0.9374220673520219], 
             34 -> RGBColor[
              0.2517479206748871, 0.38193340474234894`, 0.9376480437035368], 
             38 -> RGBColor[
              0.9648082727380654, 0.8929521819142981, 0.31778721429778617`], 
             54 -> RGBColor[
              0.27280646441116213`, 0.40406726939796367`, 0.938847296615994], 
             60 -> RGBColor[
              0.253957266336059, 0.38425556711284614`, 0.9377738626705066], 
             87 -> RGBColor[
              0.9879745726157381, 0.9892951909842899, 0.8489559827730842], 
             141 -> RGBColor[
              0.3593385897430587, 0.4856627583779401, 0.9441177150811572], 67 -> 
             RGBColor[
              0.8182056947053702, 0.14094252405757224`, 0.16506709985124088`],
              133 -> RGBColor[
              0.8234278438149039, 0.18108225047377968`, 0.1700678357361042], 
             98 -> RGBColor[
              0.9734883859205871, 0.9797482621451334, 0.9297614266867937], 3 -> 
             RGBColor[
              0.26366336471100654`, 0.39445729190709694`, 0.938326610614074], 
             27 -> RGBColor[
              0.2767490295536739, 0.4082111553358114, 0.9390718198683575], 
             163 -> RGBColor[
              0.23302215960706, 0.36225144257823677`, 0.936581639313005], 85 -> 
             RGBColor[
              0.360155081261214, 0.48636996229290924`, 0.9441697411986989], 
             83 -> RGBColor[
              0.25584834544704116`, 0.3862432111598293, 0.9378815568282761], 
             28 -> RGBColor[
              0.29477679578460203`, 0.4271594806709139, 0.9400984744855188], 
             44 -> 
             RGBColor[
              0.2834240796528994, 0.4152270562127178, 0.9394519540966568], 
             189 -> RGBColor[
              0.2313913752108486, 0.36053738478011593`, 0.9364887685541701], 
             15 -> RGBColor[
              0.32511075702074876`, 0.45601633001476893`, 0.9419367478465757],
              80 -> RGBColor[
              0.6198970672218798, 0.7022993910721819, 0.9632197143709355], 
             112 -> RGBColor[
              0.30144929209616883`, 0.4341726973550716, 0.9404784632793888], 
             169 -> RGBColor[
              0.2725827939998642, 0.40383217761416634`, 0.9388345589169613], 
             69 -> RGBColor[
              0.4015855979045752, 0.522254993451075, 0.9468096570836465], 20 -> 
             RGBColor[
              0.22540124214842158`, 0.354241375135133, 0.9361476393378726], 8 -> 
             RGBColor[
              0.44819737568646545`, 0.5626277725896778, 0.9497797183467319], 
             116 -> RGBColor[
              0.3895827819898638, 0.5118587575848209, 0.9460448482672345], 97 -> 
             RGBColor[
              0.28096145327109734`, 0.41263867974591306`, 0.9393117111673424],
              118 -> RGBColor[
              0.9133075269424444, 0.9337106471842498, 0.9915932813106664], 
             178 -> RGBColor[
              0.9424318889382709, 0.9565863775460686, 0.9823319752461818], 81 -> 
             RGBColor[
              0.5763338163997934, 0.6669327815527272, 0.9597902556887751], 
             166 -> RGBColor[
              0.39092445521974123`, 0.5130208475020834, 0.9461303384990473], 
             125 -> RGBColor[
              0.17895982839241617`, 0.30542850472186966`, 0.9335028695283829],
              95 -> RGBColor[
              0.9796258119030633, 0.9429352208414826, 0.3753505558963255], 
             157 -> RGBColor[
              0.5576848060128018, 0.6517926747922235, 0.9583221372775351], 74 -> 
             RGBColor[
              0.30278259996188467`, 0.4355740884585403, 0.9405543931898891], 
             19 -> RGBColor[
              0.26440158051900675`, 0.3952332035268908, 0.9383686509122472], 
             156 -> RGBColor[
              0.9208437466954219, 0.9397198242500384, 0.9923120926783682], 
             167 -> RGBColor[
              0.9152757732218003, 0.9352800733407862, 0.9917810143978655], 33 -> 
             RGBColor[0.3230400522816408, 0.4542227896464, 0.941804804371652],
              43 -> RGBColor[
              0.8553653759675705, 0.4265681177150025, 0.20065125259378117`], 
             140 -> 
             RGBColor[
              0.30550365683416836`, 0.4384340917562807, 0.9407093533533227], 
             186 -> RGBColor[
              0.28203039141568953`, 0.41376220151047227`, 0.9393725856133247],
              117 -> RGBColor[
              0.7789983515005383, 0.8272786998897548, 0.9786069335902352], 4 -> 
             RGBColor[
              0.8048857220793089, 0.8475021105371937, 0.9811871447582946], 
             106 -> RGBColor[
              0.27505191676798696`, 0.40642738219488894`, 0.9389751718058661],
              65 -> RGBColor[
              0.9220936452530043, 0.9407164594322621, 0.992431309118588], 53 -> 
             RGBColor[
              0.21141226994966317`, 0.3395380784021726, 0.9353509880659832], 
             2 -> RGBColor[
              0.377120805174838, 0.5010648196248124, 0.9452507821242745], 147 -> 
             RGBColor[
              0.4806958664434177, 0.5892895853375945, 0.9522612859348552], 94 -> 
             RGBColor[
              0.4181274501813097, 0.5365827144755124, 0.9478636892833344], 23 -> 
             RGBColor[
              0.9935791491691084, 0.9886747742573517, 0.5425081958346172], 
             194 -> RGBColor[
              0.348529185002255, 0.47630019528793527`, 0.9434289493694545], 
             129 -> RGBColor[
              0.9902596908634175, 0.9788057915282733, 0.4166611676177604], 99 -> 
             RGBColor[
              0.5640955015617808, 0.656997166237428, 0.9588268107143023], 25 -> 
             RGBColor[
              0.9789215033713261, 0.9405594227844256, 0.37261445024803247`], 
             138 -> RGBColor[
              0.9127756759352338, 0.6918916514058181, 0.2486754653207034], 
             124 -> RGBColor[
              0.2910544796798416, 0.42324709043633846`, 0.9398864940900259], 
             197 -> RGBColor[
              0.8889169937097365, 0.9142622980478761, 0.9892668904772446], 
             164 -> RGBColor[
              0.29472306200537346`, 0.42710300306202637`, 0.9400954144262837],
              152 -> RGBColor[
              0.281739557244844, 0.41345651635696223`, 0.9393560230375456], 
             17 -> RGBColor[
              0.2388383031545141, 0.3683645782114108, 0.9369128600838192], 
             149 -> RGBColor[
              0.2335680080595618, 0.362825163910607, 0.9366127245748646]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9lnk01I33xy0ZCmPGjGUM5jOLCfGgkIjPm8rSZv1l6yGUlK0nopQSkiYJ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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.9759778030702638, 0.9313399748264705, 0.5237839339684474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 78}], {
             RGBColor[
             0.9431385588038124, 0.9082192270955545, 0.6427719916956993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 88}], {
             RGBColor[
             0.8352535964645615, 0.823065908134689, 0.6322506322661987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 89}], {
             RGBColor[
             0.8887656846103759, 0.567689263625524, 0.23040845432083734`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[
             0.9293073420017215, 0.7556088200837405, 0.2655373341471002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 122}], {
             RGBColor[
             0.9756254576616791, 0.9291724163168037, 0.38265572153063876`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 136}], {
             RGBColor[
             0.9331596302538536, 0.7720124271387454, 0.2686954588022206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 138}], {
             RGBColor[
             0.9355441317544622, 0.7814661810006367, 0.2706140846810541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 144}], {
             RGBColor[
             0.8904481262845415, 0.5806212475838041, 0.23201956236806448`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 159}], {
             RGBColor[
             0.867867170087613, 0.40705412321611184`, 0.21039601321234347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 167}], {
             RGBColor[
             0.9367941803977453, 0.9031603919681208, 0.6421668592196352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 197}], {
             RGBColor[
             0.9236147906417135, 0.8926515043216656, 0.6409097972593247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 26}], {
             RGBColor[
             0.3867618425079842, 0.5094154015901577, 0.945865100497908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 40}], {
             RGBColor[
             0.43435111341602517`, 0.5495958945368197, 0.9491845094203311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 51}], {
             RGBColor[
             0.329630384746231, 0.45747109460127056`, 0.9423148038761329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 74}], {
             RGBColor[
             0.3399517025683613, 0.46831945404167635`, 0.9429025876570818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 80}], {
             RGBColor[
             0.4985089361983589, 0.6016821053484971, 0.954235248247605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 121}], {
             RGBColor[
             0.45989815510185605`, 0.5703361338584898, 0.9511956661237368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 158}], {
             RGBColor[
             0.31519292647680297`, 0.4422964105723771, 0.9414926119859944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 164}], {
             RGBColor[
             0.3359219335901057, 0.4640839113434194, 0.9426730982752791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 166}], {
             RGBColor[
             0.3840226301972896, 0.5070428335634479, 0.9456905603116609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 169}], {
             RGBColor[
             0.3248517995873511, 0.4524484986194894, 0.942042670520618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 184}], {
             RGBColor[
             0.37412689727752746`, 0.49847164708234826`, 0.9450600129604667]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 5}], {
             RGBColor[
             0.27293521528598386`, 0.4042025947306783, 0.9388546287878452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 10}], {
             RGBColor[
             0.27648968445364525`, 0.4079385671922522, 0.9390570505485776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 11}], {
             RGBColor[
             0.2547628231142621, 0.3851022583619874, 0.9378197379373108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 15}], {
             RGBColor[
             0.2943870608658776, 0.4252368109609329, 0.9401316792303248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 20}], {
             RGBColor[
             0.24453230342971405`, 0.374349333521115, 0.9372371249759732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 28}], {
             RGBColor[
             0.2792200802478043, 0.4108083862890054, 0.9392125425497964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 48}], {
             RGBColor[
             0.29038303180772673`, 0.42176872223911466`, 0.9398765460393633]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 63}], {
             RGBColor[
             0.30825791983475437`, 0.437251051830131, 0.9410155180983026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 77}], {
             RGBColor[
             0.2820287158723724, 0.41376044040821036`, 0.9393724901936115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 106}], {
             RGBColor[
             0.26935764073949675`, 0.40044233705099297`, 0.93865089120997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 186}], {
             RGBColor[
             0.27284687806334806`, 0.40410974670878463`, 0.9388495981136993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 189}], {
             RGBColor[
             0.24752736996092756`, 0.37749733834360644`, 0.937407689584122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 41}], {
             RGBColor[
             0.6772999087061907, 0.7464119016615944, 0.969440899246723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 66}], {
             RGBColor[
             0.7482528569010358, 0.8032600858342098, 0.9755425100215394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 80}], {
             RGBColor[
             0.7123913946505943, 0.7749007508046878, 0.972203429564615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 81}], {
             RGBColor[
             0.6906097692395512, 0.7572174460449604, 0.9704887002235348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 168}], {
             RGBColor[
             0.8717390399773187, 0.9006124860515876, 0.9850092222919777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 172}], {
             RGBColor[
             0.8994312173900378, 0.9185136164944618, 0.783483838768104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 173}], {
             RGBColor[
             0.9000135688899087, 0.9197592074679171, 0.8468692056721795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 184}], {
             RGBColor[
             0.5880093557297629, 0.671690292538539, 0.9630281942774768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 198}], {
             RGBColor[
             0.7505232703667862, 0.8050337500894356, 0.9757688036175852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 9}], {
             RGBColor[
             0.27138694905370225`, 0.40257526875480143`, 0.9387664573163714]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.2640346736892395, 0.39484756118556874`, 0.938347756111082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 15}], {
             RGBColor[
             0.303658911440855, 0.4349821137845143, 0.940659697404096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 17}], {
             RGBColor[
             0.26052268450773763`, 0.3911562378828352, 0.9381477535227178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 20}], {
             RGBColor[
             0.2538041540046914, 0.3840946363446963, 0.9377651431497445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 28}], {
             RGBColor[
             0.28849193082278163`, 0.4205536891125868, 0.9397405607235676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 48}], {
             RGBColor[
             0.2996548823827041, 0.431514025062696, 0.9404045642131346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 63}], {
             RGBColor[
             0.3175297704097317, 0.4469963546537124, 0.9415435362720739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[
             0.2913005664473497, 0.42350574323179174`, 0.9399005083673827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 102}], {
             RGBColor[
             0.32802099544168023`, 0.45608332647208405`, 0.9422120278540836]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 106}], {
             RGBColor[
             0.2786294913144741, 0.4101876398745743, 0.9391789093837413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 112}], {
             RGBColor[
             0.29182817897856506`, 0.4240602974546656, 0.9399305551205026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 140}], {
             RGBColor[
             0.2938553613475648, 0.42619099465527016`, 0.9400460001574695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 189}], {
             RGBColor[
             0.2567992205359049, 0.38724264116718776`, 0.9379357077578933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 12}], {
             RGBColor[
             0.4620072235822212, 0.5710418605945535, 0.9516398014511775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 13}], {
             RGBColor[
             0.35902556110322426`, 0.48539162870339236`, 0.9440977691730272]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 14}], {
             RGBColor[
             0.37841229319367853`, 0.5021834416346569, 0.945333074598817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 16}], {
             RGBColor[
             0.3315065479690632, 0.46155604267239897`, 0.9423442819902264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 59}], {
             RGBColor[
             0.39442835550292343`, 0.516055749816227, 0.9463536039267142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 64}], {
             RGBColor[
             0.4813272203866353, 0.5867267043563145, 0.9531607423711013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 83}], {
             RGBColor[
             0.29795007881864144`, 0.4276003661015726, 0.9403851677491978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 86}], {
             RGBColor[
             0.3660057031110193, 0.4914374768784062, 0.9445425376494667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 124}], {
             RGBColor[
             0.3155531459350417, 0.4461023057398271, 0.9413876363800726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 137}], {
             RGBColor[
             0.2951194473890727, 0.4246251929966973, 0.9402239674768278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 161}], {
             RGBColor[
             0.32435538961719373`, 0.45535402194425245`, 0.9418889111360187]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 175}], {
             RGBColor[
             0.3302248541081414, 0.460445903869875, 0.9422626135907659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 176}], {
             RGBColor[
             0.31712437457249, 0.4477537666594349, 0.9414771155265509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 186}], {
             RGBColor[
             0.3110411018029656, 0.4413598612768941, 0.941130682141722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 187}], {
             RGBColor[
             0.3114394717583858, 0.44177857335815474`, 0.9411533687213477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 193}], {
             RGBColor[
             0.3283691499935347, 0.4588385862362035, 0.9421443697655179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 199}], {
             RGBColor[
             0.3061701598017846, 0.4362401923980924, 0.9408532892006678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 18}], {
             RGBColor[
             0.33441529127436986`, 0.4640754499257662, 0.9425296245415398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 42}], {
             RGBColor[
             0.4359507962934013, 0.5501706892115099, 0.9495104580293312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 47}], {
             RGBColor[
             0.40099092685927107`, 0.5217399192806683, 0.9467717651704868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.31163329513552707`, 0.44101997430243733`, 0.9411996419147166]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 58}], {
             RGBColor[
             0.3073067839852605, 0.4364725367668565, 0.9409532535052085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.3121285679978709, 0.4415405374828739, 0.9412278469715365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 73}], {
             RGBColor[
             0.3217974307185043, 0.4517031252435637, 0.941778474399676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 88}], {
             RGBColor[
             0.5313273656076622, 0.6265318924404168, 0.9577502738522159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 94}], {
             RGBColor[
             0.3842937880206009, 0.5072776968412117, 0.9457078382483868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 97}], {
             RGBColor[
             0.3157107895654947, 0.44530567947641203`, 0.9414318491903908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 115}], {
             RGBColor[
             0.3080070225358357, 0.4372085318811994, 0.9409931310547537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 153}], {
             RGBColor[
             0.46821510011481404`, 0.5763643045440561, 0.9520504222141921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 160}], {
             RGBColor[
             0.3585859521924276, 0.48501086156024664`, 0.9440697576819622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 188}], {
             RGBColor[
             0.5075570604878807, 0.6079623494198335, 0.955381071984007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 55}], {
             RGBColor[
             0.4002897149094885, 0.5211325647337041, 0.9467270845651039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 62}], {
             RGBColor[
             0.40221602470153694`, 0.5228010374564311, 0.9468498273216844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 68}], {
             RGBColor[
             0.6519110948314109, 0.7251718951051506, 0.9679355855003635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 75}], {
             RGBColor[
             0.36617940457524284`, 0.4893149172044077, 0.9446368318260574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 96}], {
             RGBColor[
             0.3771970335719591, 0.5008951438379817, 0.9452642694982989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 99}], {
             RGBColor[
             0.5061464386241231, 0.6098124694135529, 0.9543032645305172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 107}], {
             RGBColor[
             0.5577142065740452, 0.6512964986445926, 0.9586233652992509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 147}], {
             RGBColor[
             0.4644466210649416, 0.5759586789636362, 0.9510205021407936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 156}], {
             RGBColor[
             0.6845205611909437, 0.7511737984198581, 0.97104590551255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 157}], {
             RGBColor[
             0.5029410908496337, 0.6072102236909507, 0.9540509278121335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 179}], {
             RGBColor[
             0.6280655556399748, 0.706255507224953, 0.9656353303034069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 185}], {
             RGBColor[
             0.6088853490181219, 0.6912717840369921, 0.9637236265565623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 194}], {
             RGBColor[
             0.3983632803443602, 0.5194639839388066, 0.9466043338580932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.2532145568819805, 0.3834749323861105, 0.937731566465837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 17}], {
             RGBColor[
             0.2497025677004787, 0.37978360908337694`, 0.9375315638774728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 20}], {
             RGBColor[
             0.24298403719743245`, 0.3727220075452381, 0.9371489535044994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 28}], {
             RGBColor[
             0.27767181401552266`, 0.4091810603131285, 0.9391243710783226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 63}], {
             RGBColor[
             0.3067096536024727, 0.43562372585425413`, 0.9409273466268289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 77}], {
             RGBColor[
             0.2804804496400908, 0.41213311443233347`, 0.9392843187221377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 97}], {
             RGBColor[
             0.2707641427587703, 0.4019206598506281, 0.9387309894192344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 102}], {
             RGBColor[
             0.31720087863442126`, 0.44471069767262583`, 0.9415958382088386]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.2678093745072151, 0.3988150110751161, 0.9385627197384963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 112}], {
             RGBColor[
             0.28100806217130603`, 0.41268766865520734`, 0.9393143654752576]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 140}], {
             RGBColor[
             0.2830352445403058, 0.4148183658558119, 0.9394298105122245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 189}], {
             RGBColor[
             0.24597910372864595`, 0.37587001236772954`, 0.9373195181126482]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 14}], {
             RGBColor[
             0.35304438919669967`, 0.4784146023517027, 0.943782430505298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.30721338060851633`, 0.43871808624608816`, 0.9408621191648285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 28}], {
             RGBColor[
             0.292046399990443, 0.42428966157416065`, 0.9399429824843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 48}], {
             RGBColor[
             0.30320935155036544`, 0.43524999752426985`, 0.940606985973867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 59}], {
             RGBColor[
             0.3690604515059446, 0.4922869105332728, 0.9448029598331952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 77}], {
             RGBColor[
             0.2948550356150111, 0.4272417156933656, 0.9401029301281152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 186}], {
             RGBColor[
             0.28567319780598677`, 0.4175910219939398, 0.939580038048203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 193}], {
             RGBColor[
             0.30300124599655587`, 0.4350697469532493, 0.9405937256719987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 15}], {
             RGBColor[
             0.28548651926913327`, 0.4158817774158234, 0.9396248065535615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 17}], {
             RGBColor[
             0.24235029233601593`, 0.3720559015141443, 0.9371128626721834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 20}], {
             RGBColor[
             0.2356317618329697, 0.3649942999760054, 0.93673025229921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 28}], {
             RGBColor[
             0.2703195386510599, 0.4014533527438959, 0.9387056698730332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 48}], {
             RGBColor[
             0.2814824902109824, 0.4124136886940051, 0.9393696733626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 63}], {
             RGBColor[
             0.29935737823800995`, 0.4278960182850215, 0.9405086454215394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 77}], {
             RGBColor[
             0.27312817427562797`, 0.40440540686310084`, 0.9388656175168482]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 106}], {
             RGBColor[
             0.2604570991427524, 0.3910873035058834, 0.9381440185332068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 112}], {
             RGBColor[
             0.2736557868068433, 0.4049599610859747, 0.9388956642699682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 140}], {
             RGBColor[
             0.27568296917584306`, 0.40709065828657925`, 0.9390111093069351]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 189}], {
             RGBColor[
             0.2386268283641832, 0.36814230479849686`, 0.9369008169073587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 13}], {
             RGBColor[
             0.4809809724952037, 0.58747596825463, 0.9528487919540853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 14}], {
             RGBColor[
             0.500367704585658, 0.6042677811858945, 0.954084097379875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.45346195936104267`, 0.5636403822236367, 0.9510953047712845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 23}], {
             RGBColor[
             0.7887708920716545, 0.8309004872015715, 0.7514495100334264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 25}], {
             RGBColor[
             0.7814420691727634, 0.8068428114651084, 0.666502637240134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 59}], {
             RGBColor[
             0.516383766894903, 0.6181400893674647, 0.9551046267077723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.6032826317786147, 0.6888110439075521, 0.9619117651521593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 86}], {
             RGBColor[
             0.4879611145029988, 0.5935218164296439, 0.9532935604305248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 87}], {
             RGBColor[
             0.7859686037949694, 0.8312106955650405, 0.9046734035026598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 95}], {
             RGBColor[
             0.7817942234386319, 0.8080307104936368, 0.6678706900642806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 108}], {
             RGBColor[
             0.6825976109082605, 0.7510751508326818, 0.9696102227606116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 154}], {
             RGBColor[
             0.7852450872055535, 0.8309115028617888, 0.9166639457901922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 161}], {
             RGBColor[
             0.4463108010091732, 0.5574383614954901, 0.9506399339170767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 175}], {
             RGBColor[
             0.4521802655001208, 0.5625302434211127, 0.9510136363718239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 193}], {
             RGBColor[
             0.4503245613855142, 0.5609229257874412, 0.950895392546576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 16}], {
             RGBColor[
             0.35048029688204574`, 0.4779901503324755, 0.9435532724931343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 64}], {
             RGBColor[
             0.5003009692996179, 0.6031608120163909, 0.9543697328740091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 69}], {
             RGBColor[
             0.38979245396039097`, 0.512040364907272, 0.9460582083797908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 82}], {
             RGBColor[
             0.34829886890839834`, 0.4761007070634601, 0.9434142738316145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 83}], {
             RGBColor[
             0.316923827731624, 0.4440344737616491, 0.9415941582521057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 86}], {
             RGBColor[
             0.38497945202400186`, 0.5078715845384828, 0.9457515281523746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 101}], {
             RGBColor[
             0.3149218240784437, 0.4419302409877936, 0.941480147105756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 108}], {
             RGBColor[
             0.5796159484292636, 0.6654249189415207, 0.9620681904824614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 110}], {
             RGBColor[
             0.49151316787654187`, 0.5960264789351953, 0.9536779249552072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 124}], {
             RGBColor[
             0.3345268948480242, 0.4625364133999037, 0.9425966268829805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 127}], {
             RGBColor[
             0.34979347533914956`, 0.4773952600326733, 0.9435095088317533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 137}], {
             RGBColor[
             0.31409319630205523`, 0.44105930065677384`, 0.9414329579797356]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 161}], {
             RGBColor[
             0.34332913853017627`, 0.471788129604329, 0.9430979016389265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 175}], {
             RGBColor[
             0.34919860302112393`, 0.4768800115299515, 0.9434716040936737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 176}], {
             RGBColor[
             0.3360981234854725, 0.4641878743195114, 0.9426861060294587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 187}], {
             RGBColor[
             0.33041322067136836`, 0.4582126810182313, 0.9423623592242556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 199}], {
             RGBColor[
             0.3251439087147671, 0.45267430005816894`, 0.9420622797035756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 15}], {
             RGBColor[
             0.3709417656089321, 0.49571284612038347`, 0.9448570591870451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 48}], {
             RGBColor[
             0.36693773655078116`, 0.49224475739856516`, 0.9446019259960836]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 59}], {
             RGBColor[
             0.43278883650636024`, 0.549281670407568, 0.9487978998554119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 186}], {
             RGBColor[
             0.34940158280640243`, 0.47458578186823513`, 0.9435749780704197]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 193}], {
             RGBColor[
             0.36672963099697153`, 0.49206450682754455`, 0.9445886656942154]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 28}], {
             RGBColor[
             0.3099437764026754, 0.4415879053428414, 0.9410176111660472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 48}], {
             RGBColor[
             0.32110672796259787`, 0.4525482412929506, 0.9416816146556142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 59}], {
             RGBColor[
             0.38695782791817696`, 0.5095851543019536, 0.9458775885149424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 63}], {
             RGBColor[
             0.33898161598962545`, 0.46803057088396705`, 0.9428205867145535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 77}], {
             RGBColor[
             0.31275241202724346`, 0.4445399594620464, 0.9411775588098623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 106}], {
             RGBColor[
             0.3000813368943679, 0.43122185610482894`, 0.9404559598262209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.3132800245584588, 0.44509451368492026`, 0.9412076055629822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 140}], {
             RGBColor[
             0.31530720692745856`, 0.4472252108855248, 0.9413230505999493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 193}], {
             RGBColor[
             0.32089862240878825`, 0.45236799072193, 0.941668354353746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 64}], {
             RGBColor[
             0.47278195616545676`, 0.5793252259853976, 0.9526162456912082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 83}], {
             RGBColor[
             0.2894048145974629, 0.4201988877306557, 0.9398406710693048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 86}], {
             RGBColor[
             0.3574604388898408, 0.48403599850748935`, 0.9439980409695737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 101}], {
             RGBColor[
             0.28740281094428266`, 0.4180946549568002, 0.9397266599229551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 124}], {
             RGBColor[
             0.3070078817138632, 0.43870082736891025`, 0.9408431397001796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 127}], {
             RGBColor[
             0.3222744622049885, 0.4535596740016799, 0.9417560216489524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 137}], {
             RGBColor[
             0.2865741831678942, 0.41722371462578045`, 0.9396794707969347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 161}], {
             RGBColor[
             0.3158101253960152, 0.4479525435733356, 0.9413444144561256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 175}], {
             RGBColor[
             0.3216795898869629, 0.4530444254989581, 0.9417181169108728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 176}], {
             RGBColor[
             0.30857911035131147`, 0.440352288288518, 0.9409326188466578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.3028942075372073, 0.43437709498723787`, 0.9406088720414547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 193}], {
             RGBColor[
             0.3198238857723562, 0.4514371078652866, 0.9415998730856248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 199}], {
             RGBColor[
             0.29762489558060606`, 0.42883871402717555`, 0.9403087925207747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 20}], {
             RGBColor[
             0.23211977265146783`, 0.3613029766732719, 0.9365302497108459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 28}], {
             RGBColor[
             0.2668075494695581, 0.39776202944116235`, 0.938505667284669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 77}], {
             RGBColor[
             0.26961618509412616`, 0.4007140835603673, 0.9386656149284841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 106}], {
             RGBColor[
             0.25694510996125053`, 0.38739598020314986`, 0.9379440159448427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 112}], {
             RGBColor[
             0.27014379762534146`, 0.4012686377832412, 0.938695661681604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 140}], {
             RGBColor[
             0.27217097999434126`, 0.4033993349838457, 0.9388111067185709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 189}], {
             RGBColor[
             0.23511483918268133`, 0.3644509814957634, 0.9367008143189947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 47}], {
             RGBColor[
             0.38494609227374893`, 0.5078426899995235, 0.9457494024985874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 54}], {
             RGBColor[
             0.295588460550005, 0.42712274502129255`, 0.9401772792428172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 58}], {
             RGBColor[
             0.2912619493997384, 0.4225753074857117, 0.9399308908333093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 61}], {
             RGBColor[
             0.2960837334123488, 0.42764330820172913`, 0.9402054842996372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 73}], {
             RGBColor[
             0.3057525961329822, 0.4378058959624189, 0.9407561117277767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 94}], {
             RGBColor[
             0.36824895343507874`, 0.4933804675600669, 0.9446854755764875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 115}], {
             RGBColor[
             0.2919621879503136, 0.4233113026000546, 0.9399707683828544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 116}], {
             RGBColor[
             0.35397661933935576`, 0.48101848911472117`, 0.9437760550684375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 153}], {
             RGBColor[
             0.4521702655292919, 0.5624670752629113, 0.9510280595422927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 160}], {
             RGBColor[
             0.34254111760690553`, 0.47111363227910186`, 0.9430473950100628]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 174}], {
             RGBColor[
             0.3498905326098686, 0.47747932616232985`, 0.9435156932352192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 188}], {
             RGBColor[
             0.49151222590235866`, 0.5940651201386887, 0.9543587093121076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 33}], {
             RGBColor[
             0.29372081640032377`, 0.4247279965866454, 0.9400867276419496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 34}], {
             RGBColor[
             0.25807475059694696`, 0.38858330413461983`, 0.938008347307892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 44}], {
             RGBColor[
             0.2739128300859531, 0.40523012986980433`, 0.9389103025044521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 50}], {
             RGBColor[
             0.2533169376668154, 0.3835825410822887, 0.9377373969000744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 60}], {
             RGBColor[
             0.25917942342753286`, 0.38974438531986844`, 0.9380712567913769]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 90}], {
             RGBColor[
             0.32617520722218063`, 0.45283835871142575`, 0.9421546927268274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 130}], {
             RGBColor[
             0.2508128361327613, 0.38095057160079043`, 0.9375947920221963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 141}], {
             RGBColor[
             0.31187008513103276`, 0.44044798095241544`, 0.9412431829967022]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 177}], {
             RGBColor[
             0.2790041774695689, 0.41058145878005325`, 0.9392002472059755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.2600890189665118, 0.39070042790302345`, 0.9381230569116956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 77}], {
             RGBColor[
             0.2628976545910799, 0.3936524820222284, 0.9382830045555108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 106}], {
             RGBColor[
             0.25022657945820426`, 0.38033437866501096`, 0.9375614055718693]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 189}], {
             RGBColor[
             0.2283963086796351, 0.35738937995762443`, 0.9363182039460214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.28199072307706635`, 0.41303118579725295`, 0.9393955660070041]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 46}], {
             RGBColor[
             0.4569720284859443, 0.5663064733841641, 0.9514223432183879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 85}], {
             RGBColor[
             0.3381783439476214, 0.46733481701480994`, 0.9427694029303426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 109}], {
             RGBColor[
             0.32687230511240406`, 0.45754209443377936`, 0.9420489921333002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 132}], {
             RGBColor[
             0.28420798371714023`, 0.41536166731241486`, 0.9395218357203131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 150}], {
             RGBColor[
             0.29956418872733326`, 0.4315020124177601, 0.9403963488781741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 151}], {
             RGBColor[
             0.33403902527338425`, 0.46374954722739153`, 0.9425056492046759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 194}], {
             RGBColor[
             0.33236539581814195`, 0.4622999335123229, 0.9423990070157204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 196}], {
             RGBColor[
             0.4056875246476441, 0.5246714028276624, 0.9473850392149095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 24}], {
             RGBColor[
             0.6225902394734423, 0.3300989620118385, 0.4379481515395359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 37}], {
             RGBColor[
             0.626612488125885, 0.33432660037084994`, 0.4381772126499089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 38}], {
             RGBColor[
             0.8845506627730023, 0.5259516883218133, 0.23271022291823168`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 79}], {
             RGBColor[
             0.6309372892797696, 0.33887224059181326`, 0.43842350367765265`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 89}], {
             RGBColor[
             0.84761198290322, 0.36697214106389997`, 0.19322659463915418`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 118}], {
             RGBColor[
             0.8673837475077953, 0.5395378434117971, 0.45731224525585845`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 119}], {
             RGBColor[
             0.7512406956376406, 0.44751187274529963`, 0.44641063184908925`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 122}], {
             RGBColor[
             0.8939273477768698, 0.5574023350297646, 0.28436739782559384`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 128}], {
             RGBColor[
             0.8594750767508397, 0.42546671823825916`, 0.20330663416839254`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 138}], {
             RGBColor[
             0.8672064638387251, 0.45893151148565325`, 0.20967297325920412`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 144}], {
             RGBColor[
             0.8484532037403029, 0.37343813304304, 0.19403214866276774`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 149}], {
             RGBColor[
             0.6408039078801677, 0.34924268232058286`, 0.43898539301059114`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 181}], {
             RGBColor[
             0.8910578733822835, 0.5575636367110436, 0.4299003396380736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 183}], {
             RGBColor[
             0.8495847316428689, 0.3805569710517512, 0.19505388777575874`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 190}], {
             RGBColor[
             0.6228502592156624, 0.3303722592471158, 0.4379629592791906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 192}], {
             RGBColor[
             0.8353875718603139, 0.2730099610170472, 0.18152048481896965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 25}], {
             RGBColor[
             0.9862503262702172, 0.9646170985208886, 0.4575613230413248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 43}], {
             RGBColor[
             0.9014366337014165, 0.6139370032291189, 0.31460356700739317`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 49}], {
             RGBColor[
             0.8876847855307123, 0.5082342720907941, 0.3014347816686359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 64}], {
             RGBColor[
             0.8080908888760686, 0.8465853309633324, 0.7529704509533501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 67}], {
             RGBColor[
             0.8766635128599496, 0.4235199407908321, 0.29088079851236637`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 87}], {
             RGBColor[
             0.9907768608924232, 0.9889849826208208, 0.6957320893038507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 95}], {
             RGBColor[
             0.9866024805360858, 0.9658049975494172, 0.45892937586547133`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 103}], {
             RGBColor[
             0.9073868883324812, 0.6473301594421497, 0.31981821239601227`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 108}], {
             RGBColor[
             0.8874058680057144, 0.9088494378884622, 0.7606689085618024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 129}], {
             RGBColor[
             0.9919194200162629, 0.9837402828928126, 0.4795846817261888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 131}], {
             RGBColor[
             0.9464189057965813, 0.8120568568548516, 0.39007974658807487`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 143}], {
             RGBColor[
             0.8783920111917808, 0.4368059364020854, 0.2925360104669875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 154}], {
             RGBColor[
             0.9900533443030074, 0.9886857899175692, 0.707722631591383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 162}], {
             RGBColor[
             0.9882402059749112, 0.9877215722762983, 0.728168038634343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.22783801619652955`, 0.3568025791600926, 0.9362864100150281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 37}], {
             RGBColor[
             0.18496037581804925`, 0.31173546052289103`, 0.9338445918272582]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 56}], {
             RGBColor[
             0.1789270014196926, 0.30539400149218693`, 0.9335010000808495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 79}], {
             RGBColor[
             0.1914475775488761, 0.318553920854336, 0.9342140283688739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 89}], {
             RGBColor[
             0.6289704896989408, 0.3791403610884968, 0.44405788636093535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 118}], {
             RGBColor[
             0.5461172648909147, 0.6195523250843118, 0.9625471407361825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 119}], {
             RGBColor[
             0.37190268708568275`, 0.48151336908456555`, 0.9461947206260288]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 125}], {
             RGBColor[
             0.17894341561590066`, 0.30541125385312173`, 0.9335019348450408]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 144}], {
             RGBColor[
             0.6306529313731064, 0.3920723450467769, 0.44566899440816243`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 149}], {
             RGBColor[
             0.20624750544947348`, 0.3341095834474904, 0.9350568623682817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 170}], {
             RGBColor[
             0.18064618334875748`, 0.3072009707020641, 0.9335989049484079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 190}], {
             RGBColor[
             0.1793170324527155, 0.3058039488372898, 0.9335232117711809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 195}], {
             RGBColor[
             0.1789270014196926, 0.30539400149218693`, 0.9335010000808495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 197}], {
             RGBColor[
             0.5339219982745609, 0.6098281505161249, 0.9613839453194717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[
             0.8965507517688224, 0.5978985527381435, 0.25797231847853164`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 49}], {
             RGBColor[
             0.8827989035981182, 0.49219582159981873`, 0.2448035331397743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 64}], {
             RGBColor[
             0.8007620659771775, 0.8225276552268693, 0.6680235781600576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 67}], {
             RGBColor[
             0.8717776309273555, 0.4074814902998567, 0.23424954998350475`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 87}], {
             RGBColor[
             0.9834480379935321, 0.9649273068843578, 0.6107852165105583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 95}], {
             RGBColor[
             0.9792736576371948, 0.9417473218129542, 0.37398250307217895`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 103}], {
             RGBColor[
             0.9025010063998871, 0.6312917089511744, 0.2631869638671507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 108}], {
             RGBColor[
             0.8800770451068233, 0.8847917621519991, 0.6757220357685101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 129}], {
             RGBColor[
             0.9845905971173718, 0.9596826071563495, 0.39463780893289646`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 131}], {
             RGBColor[
             0.93909008289769, 0.7879991811183886, 0.30513287379478254`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 143}], {
             RGBColor[
             0.8735061292591867, 0.42076748591111013`, 0.23590476193812596`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 154}], {
             RGBColor[
             0.9827245214041163, 0.9646281141811062, 0.6227757587980907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 162}], {
             RGBColor[
             0.9809113830760201, 0.9636638965398352, 0.6432211658410507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 40}], {
             RGBColor[
             0.4439921507491714, 0.557946476502165, 0.9497988277939646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 51}], {
             RGBColor[
             0.3392714220793772, 0.4658216765666159, 0.9429291222497664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 74}], {
             RGBColor[
             0.3495927399015075, 0.4766700360070217, 0.9435169060307154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 80}], {
             RGBColor[
             0.5081499735315052, 0.6100326873138424, 0.9548495666212384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 121}], {
             RGBColor[
             0.46953919243500225`, 0.5786867158238351, 0.9518099844973704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 158}], {
             RGBColor[
             0.3248339638099492, 0.45064699253772245`, 0.9421069303596279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 164}], {
             RGBColor[
             0.34556297092325194`, 0.47243449330876475`, 0.9432874166489127]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.3936636675304358, 0.5153934155287933, 0.9463048786852943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 169}], {
             RGBColor[
             0.3344928369204973, 0.4607990805848347, 0.9426569888942514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 184}], {
             RGBColor[
             0.38376793461067366`, 0.5068222290476936, 0.9456743313341002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 37}], {
             RGBColor[
             0.23387138917519362`, 0.3631440366986098, 0.9366300016805876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 56}], {
             RGBColor[
             0.22783801477683696`, 0.3568025776679057, 0.9362864099341788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 67}], {
             RGBColor[
             0.6377201396548048, 0.23003206781698532`, 0.42306867319027985`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 119}], {
             RGBColor[
             0.4208137004428272, 0.5329219452602844, 0.9489801304793581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 125}], {
             RGBColor[
             0.22785442897304503`, 0.35681983002884055`, 0.9362873446983702]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 128}], {
             RGBColor[
             0.5831652721126257, 0.49985421349972364`, 0.5843241339583132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 133}], {
             RGBColor[
             0.6412015723944939, 0.2567918854277903, 0.42640249711352196`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 190}], {
             RGBColor[
             0.22822804580985986`, 0.3572125250130086, 0.9363086216245102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 195}], {
             RGBColor[
             0.22783801477683696`, 0.3568025776679057, 0.9362864099341788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 48}], {
             RGBColor[
             0.30593974734452445`, 0.4381198166210231, 0.9407624779750857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 63}], {
             RGBColor[
             0.3238146353715521, 0.45360214621203954`, 0.941901450034025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 77}], {
             RGBColor[
             0.29758543140917015`, 0.4301115347901189, 0.9402584221293339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 106}], {
             RGBColor[
             0.28491435627629447`, 0.41679343143290143`, 0.9395368231456924]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 112}], {
             RGBColor[
             0.2981130439403854, 0.43066608901299275`, 0.9402884688824538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 140}], {
             RGBColor[
             0.3001402263093852, 0.4327967862135973, 0.9404039139194207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 189}], {
             RGBColor[
             0.26308408549772533`, 0.39384843272551495`, 0.9382936215198444]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 35}], {
             RGBColor[
             0.9160081618564544, 0.9327996859082862, 0.8697305761183244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 47}], {
             RGBColor[
             0.7225823732127437, 0.7785731992059557, 0.8525033535115121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 88}], {
             RGBColor[
             0.8529188119611348, 0.8833651723657042, 0.8634818621932413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 89}], {
             RGBColor[
             0.9005424949414248, 0.6078887731128675, 0.3845626076055324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 113}], {
             RGBColor[
             0.946972557498295, 0.8159080843147557, 0.4967685640741427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 122}], {
             RGBColor[
             0.9932906731582525, 0.9894716805478189, 0.6138869514576812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 136}], {
             RGBColor[
             0.950824845750427, 0.8323116913697606, 0.49992668872926316`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 138}], {
             RGBColor[
             0.9532093472510355, 0.8417654452316519, 0.5018453146080967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 142}], {
             RGBColor[
             0.8172660326623933, 0.855490432397475, 0.8599437218958297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 144}], {
             RGBColor[
             0.9022249366155904, 0.6208207570711475, 0.3861737156527596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 153}], {
             RGBColor[
             0.7898065464682866, 0.8331975844693433, 0.8577820105552174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 159}], {
             RGBColor[
             0.879643980418662, 0.4472536327034553, 0.36455016649703853`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 167}], {
             RGBColor[
             0.9544593958943188, 0.963459656199136, 0.8733980891466777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 181}], {
             RGBColor[
             0.988986461566373, 0.9897136330697374, 0.8321863641764009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 188}], {
             RGBColor[
             0.8291485068413533, 0.8647956293451209, 0.8611126603250323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 41}], {
             RGBColor[
             0.7217306402299773, 0.781717727178925, 0.9737111260908631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 65}], {
             RGBColor[
             0.9079204151899432, 0.9294151105020584, 0.9910794537825813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 66}], {
             RGBColor[
             0.7926835884248224, 0.8385659113515402, 0.9798127368656795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 90}], {
             RGBColor[
             0.6408480095261183, 0.7142786377339077, 0.9678341664939911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 110}], {
             RGBColor[
             0.7493871054318795, 0.8041704915393881, 0.9758883443405271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 162}], {
             RGBColor[
             0.9383242239537981, 0.9524410659335498, 0.9517777399403218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 180}], {
             RGBColor[
             0.8089076786179981, 0.8512402939181014, 0.9814298025533923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 198}], {
             RGBColor[
             0.7949540018905729, 0.840339575606766, 0.9800390304617252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 38}], {
             RGBColor[
             0.9076583192648293, 0.8882942413173389, 0.6516953277782057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[
             0.6710448937244029, 0.7408816350846033, 0.9693608389875064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 46}], {
             RGBColor[
             0.7241254080647266, 0.7839747878759986, 0.9735395315167075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 80}], {
             RGBColor[
             0.7352027165067365, 0.7929678458962808, 0.9744115778147804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 98}], {
             RGBColor[
             0.9119983758560902, 0.9316922814327566, 0.9576824339727095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 117}], {
             RGBColor[
             0.8147533586460658, 0.8554575003050673, 0.9821051874244302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 120}], {
             RGBColor[
             0.9036386065731989, 0.8747348065350462, 0.6360795030302686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 121}], {
             RGBColor[
             0.6965919354102337, 0.7616218744062735, 0.9713719956909121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 146}], {
             RGBColor[
             0.8233014482367667, 0.8621353328612098, 0.9829571811083924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 151}], {
             RGBColor[
             0.6011924048521665, 0.6814178617192261, 0.9646228375029955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 171}], {
             RGBColor[
             0.8624892635832501, 0.8931895434066397, 0.9867461899854671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 173}], {
             RGBColor[
             0.9228248907460509, 0.93782630255951, 0.8490773539223448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 178}], {
             RGBColor[
             0.8964701273649321, 0.9201113391332241, 0.9839677082524034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 196}], {
             RGBColor[
             0.6728409042264264, 0.742339717319497, 0.969502227513229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 53}], {
             RGBColor[
             0.2232819677009355, 0.3520138833210643, 0.9360269497932738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 82}], {
             RGBColor[
             0.27687504662639884`, 0.4074326830017036, 0.9391123497539292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 83}], {
             RGBColor[
             0.2455000054496245, 0.37536644969989263`, 0.9372922341744203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 100}], {
             RGBColor[
             0.22448297168171977`, 0.35327621465291903`, 0.9360953451932534]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 101}], {
             RGBColor[
             0.2434980017964442, 0.3732622169260371, 0.9371782230280707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 123}], {
             RGBColor[
             0.24279155375346242`, 0.3725196952414703, 0.9371379918571192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 127}], {
             RGBColor[
             0.2783696530571501, 0.40872723597091687`, 0.9392075847540681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 130}], {
             RGBColor[
             0.23618787859936186`, 0.36557881395732306`, 0.936761922326355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 135}], {
             RGBColor[
             0.23421532693659433`, 0.36350553709275546`, 0.9366495884272892]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 148}], {
             RGBColor[
             0.219972379693155, 0.3485352964848875, 0.9358384736523275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 163}], {
             RGBColor[
             0.23408691252963393`, 0.3633705654090964, 0.9366422754167848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 165}], {
             RGBColor[
             0.2270272954930984, 0.35595046029812505`, 0.9362402406703216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 176}], {
             RGBColor[
             0.264674301203473, 0.39551985025775493`, 0.9383841819517735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 187}], {
             RGBColor[
             0.2589893983893689, 0.38954465695647483`, 0.9380604351465702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 41}], {
             RGBColor[
             0.4363770738073567, 0.5497722412161976, 0.9497497290534018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 44}], {
             RGBColor[
             0.3032320659672701, 0.4347249229295589, 0.9406283792341544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 57}], {
             RGBColor[
             0.3418089819131736, 0.4704794931394012, 0.9430007439710605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 66}], {
             RGBColor[
             0.5073300220022017, 0.606620425388813, 0.955851339828218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 90}], {
             RGBColor[
             0.35549444310349765`, 0.4823331517711803, 0.9438727694565298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 141}], {
             RGBColor[
             0.3411893210123498, 0.46994277401217005`, 0.9429612597264045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 198}], {
             RGBColor[
             0.5096004354679522, 0.6083940896440386, 0.956077633424264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 44}], {
             RGBColor[
             0.2675860001638932, 0.3985802304775334, 0.9385499989000968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 50}], {
             RGBColor[
             0.2469901077447556, 0.3769326416900177, 0.9373770932957193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 60}], {
             RGBColor[
             0.25285259350547307`, 0.38309448592759754`, 0.9377109531870217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 90}], {
             RGBColor[
             0.31984837730012083`, 0.4461884593191548, 0.9417943891224722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 104}], {
             RGBColor[
             0.2353413665909268, 0.3646890761644966, 0.936713714719777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 130}], {
             RGBColor[
             0.2444860062107015, 0.3743006722085195, 0.9372344884178412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 163}], {
             RGBColor[
             0.24238504014097356`, 0.3720924236602928, 0.9371148415082708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 177}], {
             RGBColor[
             0.27267734754750905`, 0.40393155938778236`, 0.9388399436016203]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 47}], {
             RGBColor[
             0.6449475165023608, 0.7197336460567563, 0.9672187657343465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 68}], {
             RGBColor[
             0.8469990595612139, 0.880838075189855, 0.985268720497577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 88}], {
             RGBColor[
             0.775283955250752, 0.8245256192165048, 0.9781972744160757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.6282503776636906, 0.7052714236172997, 0.9661548388122466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 111}], {
             RGBColor[
             0.6494345587146366, 0.7234252020636741, 0.9675585260086426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 116}], {
             RGBColor[
             0.6139780435679677, 0.6929094451719539, 0.9652454183041966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 122}], {
             RGBColor[
             0.9156558164478696, 0.9306321273986194, 0.7286023636805157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 138}], {
             RGBColor[
             0.8755744905406526, 0.7829258920824524, 0.6165607268309311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 142}], {
             RGBColor[
             0.7396311759520104, 0.7966508792482756, 0.9746591341186641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 153}], {
             RGBColor[
             0.7121716897579038, 0.7743580313201439, 0.9724974227780518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 157}], {
             RGBColor[
             0.6980290555794366, 0.7628764037756551, 0.971384062809347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 160}], {
             RGBColor[
             0.6025425418355174, 0.6830045883363345, 0.9645167582458221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 167}], {
             RGBColor[
             0.876824539183936, 0.9046201030499366, 0.9881135013695121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 174}], {
             RGBColor[
             0.6098919568384804, 0.6893702822195625, 0.9649850564709783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 181}], {
             RGBColor[
             0.9113516048559902, 0.930874079920538, 0.9469017763992353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 185}], {
             RGBColor[
             0.8039733137479249, 0.8469379641216965, 0.9810567615537757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 188}], {
             RGBColor[
             0.7515136501309705, 0.8059560761959215, 0.9758280725478667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 132}], {
             RGBColor[
             0.24999710016017773`, 0.3800931813729572, 0.937548337065331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 151}], {
             RGBColor[
             0.2998281417164218, 0.4284810612879339, 0.9405321505496939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 169}], {
             RGBColor[
             0.260181316759984, 0.39079743873598083`, 0.9381283131344916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 200}], {
             RGBColor[
             0.24218408124275126`, 0.3718812031167312, 0.9371033971963092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 56}], {
             RGBColor[
             0.18496037439835666`, 0.3117354590307041, 0.9338445917464089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 79}], {
             RGBColor[
             0.19748095052754017`, 0.3248953783928531, 0.9345576200344334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 118}], {
             RGBColor[
             0.5521506378695789, 0.625893782622829, 0.962890732401742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 119}], {
             RGBColor[
             0.3779360600643469, 0.4878548266230827, 0.9465383122915882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 125}], {
             RGBColor[
             0.18497678859456473`, 0.3117527113916389, 0.9338455265106003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 128}], {
             RGBColor[
             0.5402876317341454, 0.454787094862522, 0.5818823157705433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 149}], {
             RGBColor[
             0.21228087842813756`, 0.34045104098600754`, 0.9354004540338412]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 170}], {
             RGBColor[
             0.18667955632742156`, 0.31354242824058126`, 0.9339424966139673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 190}], {
             RGBColor[
             0.18535040543137957`, 0.3121454063758069, 0.9338668034367403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 195}], {
             RGBColor[
             0.18496037439835666`, 0.3117354590307041, 0.9338445917464089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 46}], {
             RGBColor[
             0.7812753615379626, 0.7886327284729578, 0.6396314180362879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 98}], {
             RGBColor[
             0.9691483293293262, 0.9363502220297157, 0.6237743204922899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 117}], {
             RGBColor[
             0.8719033121193018, 0.8601154409020264, 0.6481970739440106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 120}], {
             RGBColor[
             0.960788560046435, 0.8793927471320053, 0.302171389549849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 128}], {
             RGBColor[
             0.9271948937048214, 0.742224726788967, 0.2736818311730274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 146}], {
             RGBColor[
             0.8804514017100027, 0.8667932734581691, 0.6490490676279728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 156}], {
             RGBColor[
             0.9428260097167436, 0.9163360030821683, 0.6550496534880772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 171}], {
             RGBColor[
             0.919639217056486, 0.8978474840035989, 0.6528380765050477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 178}], {
             RGBColor[
             0.9536200808381681, 0.9247692797301834, 0.650059594771984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 179}], {
             RGBColor[
             0.8863710041657746, 0.8714177118872631, 0.6496390782789341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 183}], {
             RGBColor[
             0.8948764104777984, 0.602162747374174, 0.2424745440128403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 192}], {
             RGBColor[
             0.8664820909126885, 0.38706872730476605`, 0.21540773809926206`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 114}], {
             RGBColor[
             0.20908858865686974`, 0.3370957420335433, 0.935218657853937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 46}], {
             RGBColor[
             0.5446619359975361, 0.6412201222402223, 0.9572969292455886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 74}], {
             RGBColor[
             0.3971820108095485, 0.5168505289536836, 0.9468363149531384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.555739244439546, 0.6502131802605045, 0.9581689755436615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 117}], {
             RGBColor[
             0.6352898865788753, 0.7127028346692909, 0.9658625851533114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 121}], {
             RGBColor[
             0.5171284633430432, 0.6188672087704971, 0.9551293934197934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 166}], {
             RGBColor[
             0.4412529384384768, 0.5555739084754552, 0.9496242876077174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 169}], {
             RGBColor[
             0.38208210782853824`, 0.5009795735314966, 0.9459763978166744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 171}], {
             RGBColor[
             0.6830257915160596, 0.7504348777708634, 0.9705035877143484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 173}], {
             RGBColor[
             0.7433614186788604, 0.7950716369237336, 0.832834751651226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 196}], {
             RGBColor[
             0.49337743215923585`, 0.5995850516837207, 0.9532596252421102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 57}], {
             RGBColor[
             0.4551460034388895, 0.5660289447091988, 0.9509456686528102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 66}], {
             RGBColor[
             0.6206670435279176, 0.7021698769586107, 0.9637962645099678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 81}], {
             RGBColor[
             0.563023955866433, 0.6561272371693612, 0.9587424547119633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 90}], {
             RGBColor[
             0.46883146462921355`, 0.577882603340978, 0.9518176941382794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 141}], {
             RGBColor[
             0.4545263425380657, 0.5654922255819677, 0.9509061844081543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 168}], {
             RGBColor[
             0.7441532266042006, 0.7995222771759883, 0.9732629767804062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 172}], {
             RGBColor[
             0.7718454040169196, 0.8174234076188627, 0.7717375932565325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 184}], {
             RGBColor[
             0.46042354235664473`, 0.5706000836629397, 0.9512819487659052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 198}], {
             RGBColor[
             0.6229374569936681, 0.7039435412138363, 0.9640225581060137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 88}], {
             RGBColor[
             0.6168180360411716, 0.6987299024450158, 0.9637087446681081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[
             0.401201459999004, 0.517503689481011, 0.9473903200062829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 102}], {
             RGBColor[
             0.4476381958746549, 0.5602937273030086, 0.9502551687958871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 153}], {
             RGBColor[
             0.5537057705483233, 0.648562314548655, 0.9580088930300842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 49}], {
             RGBColor[
             0.8484894518822184, 0.3737167521458401, 0.1940668599244025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 67}], {
             RGBColor[
             0.8429788155468371, 0.3313595864958591, 0.18878986834626774`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 87}], {
             RGBColor[
             0.8995684415169597, 0.6141438088047649, 0.4167528293202155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 95}], {
             RGBColor[
             0.8967855212794014, 0.5986904854238292, 0.25888435369462925`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 103}], {
             RGBColor[
             0.8583405032831029, 0.4432646958215179, 0.2032585752880907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 129}], {
             RGBColor[
             0.9003301475995195, 0.6106473423194261, 0.27265455760177426`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 131}], {
             RGBColor[
             0.869996471453065, 0.49619172496078556`, 0.21298460084303164`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 133}], {
             RGBColor[
             0.8447195319166816, 0.3447394953012616, 0.19045678030788885`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 143}], {
             RGBColor[
             0.8438430647127526, 0.3380025843014858, 0.18961747432357834`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 154}], {
             RGBColor[
             0.8990860971240158, 0.6139443470025971, 0.4247465241785704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 197}], {
             RGBColor[
             0.8665492485482925, 0.589132844492627, 0.463523131888269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 50}], {
             RGBColor[
             0.2628281872337618, 0.3935794674252022, 0.9382790484922793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 57}], {
             RGBColor[
             0.3220009955988029, 0.4509816264225601, 0.9418243188335629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 60}], {
             RGBColor[
             0.2686906729944792, 0.399741311662782, 0.9386129083835817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 90}], {
             RGBColor[
             0.33568645678912695`, 0.46283528505433924`, 0.9426963443190322]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 141}], {
             RGBColor[
             0.321381334697979, 0.45044490729532893`, 0.941784834588907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 177}], {
             RGBColor[
             0.2885154270365152, 0.4205783851229668, 0.9397418987981803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 120}], {
             RGBColor[
             0.9205644172331103, 0.7168104234407002, 0.25588752113131463`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 128}], {
             RGBColor[
             0.8869707508914968, 0.5796424030976618, 0.22739796275449303`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 168}], {
             RGBColor[
             0.9114761724933723, 0.7607551980488345, 0.6070253886431892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 172}], {
             RGBColor[
             0.9391683499060914, 0.7786563284917088, 0.4055000051193155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 173}], {
             RGBColor[
             0.9397507014059623, 0.7799019194651641, 0.46888537202339087`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 85}], {
             RGBColor[
             0.4789487657995369, 0.5853416186622634, 0.9528226814867443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 98}], {
             RGBColor[
             0.7856154181292234, 0.8320307685883754, 0.9456185242307917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 99}], {
             RGBColor[
             0.5809189759498203, 0.6706552206345228, 0.960151216244546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 109}], {
             RGBColor[
             0.4676427269643195, 0.5755488960812328, 0.9521022706897019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 117}], {
             RGBColor[
             0.6883704009191991, 0.7557959874606861, 0.9700412776825125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 121}], {
             RGBColor[
             0.570208977683367, 0.6619603615618923, 0.9593080859489944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 146}], {
             RGBColor[
             0.6969184905099, 0.7624738200168288, 0.9708932713664746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 151}], {
             RGBColor[
             0.4748094471252997, 0.581756348874845, 0.9525589277610778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 171}], {
             RGBColor[
             0.7361063058563833, 0.7935280305622586, 0.9746822802435494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 178}], {
             RGBColor[
             0.7700871696380653, 0.8204498262888431, 0.9719037985104857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 196}], {
             RGBColor[
             0.5464579464995596, 0.642678204475116, 0.9574383177713113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 54}], {
             RGBColor[
             0.3621640961349061, 0.48478721437619465`, 0.9444194198717641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 61}], {
             RGBColor[
             0.36265936899724993`, 0.48530777755663124`, 0.944447624928584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 73}], {
             RGBColor[
             0.3723282317178833, 0.495470365317321, 0.9449982523567235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 88}], {
             RGBColor[
             0.5818581666070413, 0.6702991325141743, 0.9609700518092634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 94}], {
             RGBColor[
             0.4348245890199799, 0.551044936914969, 0.9489276162054343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 105}], {
             RGBColor[
             0.3973660260121461, 0.5186002123597028, 0.9465407896938819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 111}], {
             RGBColor[
             0.45600877007092583`, 0.5691987153613436, 0.9503313034018304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 116}], {
             RGBColor[
             0.42055225492425696`, 0.5386829584696233, 0.9480181956973843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 126}], {
             RGBColor[
             0.37937335834478547`, 0.5028752400890226, 0.9453994618957948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 142}], {
             RGBColor[
             0.5462053873082997, 0.642424392545945, 0.9574319115118519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 153}], {
             RGBColor[
             0.518745901114193, 0.6201315446178133, 0.9552702001712396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 157}], {
             RGBColor[
             0.5046032669357259, 0.6086499170733246, 0.9541568402025347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 160}], {
             RGBColor[
             0.4091167531918066, 0.528778101634004, 0.9472895356390099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 167}], {
             RGBColor[
             0.6833987505402253, 0.7503936163476059, 0.9708862787627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 174}], {
             RGBColor[
             0.4164661681947697, 0.535143795517232, 0.9477578338641661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 188}], {
             RGBColor[
             0.5580878614872598, 0.6517295894935908, 0.9586008499410545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 59}], {
             RGBColor[
             0.382953798860026, 0.5061170655801353, 0.9456224553239809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.3349775869314745, 0.46456248216214874`, 0.942565453523592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 77}], {
             RGBColor[
             0.30874838296909257`, 0.4410718707402281, 0.9409224256189008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 106}], {
             RGBColor[
             0.29607730783621694`, 0.42775376738301063`, 0.9402008266352594]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 112}], {
             RGBColor[
             0.3092759955003079, 0.44162642496310195`, 0.9409524723720207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 140}], {
             RGBColor[
             0.3113031778693076, 0.4437571221637065, 0.9410679174089878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 193}], {
             RGBColor[
             0.3168945933506373, 0.44889990200011176`, 0.9414132211627845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 67}], {
             RGBColor[
             0.8292269673761329, 0.22565685535753427`, 0.17562108300751042`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.8858165933462555, 0.5084410776664401, 0.4035840439814582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 95}], {
             RGBColor[
             0.8830336731086973, 0.49298775428550434`, 0.24571556835587194`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 103}], {
             RGBColor[
             0.8445886551123987, 0.33756196468319305`, 0.19008978994933337`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 108}], {
             RGBColor[
             0.8169025980884497, 0.455017381178201, 0.44687525682009266`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[
             0.8865782994288154, 0.5049446111811012, 0.25948577226301694`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 131}], {
             RGBColor[
             0.8562446232823608, 0.3904889938224607, 0.19981581550427432`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 133}], {
             RGBColor[
             0.8309676837459775, 0.23903676416293673`, 0.17728799496913153`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 143}], {
             RGBColor[
             0.8300912165420485, 0.23229985316316096`, 0.17644868898482102`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 154}], {
             RGBColor[
             0.8853342489533117, 0.5082416158642724, 0.4115777388398131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 162}], {
             RGBColor[
             0.8841254900679142, 0.5075988041034252, 0.42520801020178634`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 53}], {
             RGBColor[
             0.22682228238214364`, 0.3557349785199296, 0.9362285654769424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 60}], {
             RGBColor[
             0.24809478057534154`, 0.3780937228752663, 0.9374400027792041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 82}], {
             RGBColor[
             0.28041536130760697`, 0.41115377820056886`, 0.9393139654375977]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 100}], {
             RGBColor[
             0.2280232863629279, 0.35699730985178435`, 0.9362969608769219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 104}], {
             RGBColor[
             0.2305835536607953, 0.3596883131121654, 0.9364427643119595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 123}], {
             RGBColor[
             0.24633186843467056`, 0.37624079044033565`, 0.9373396075407877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.23972819328057, 0.3692999091561883, 0.9369635380100236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 163}], {
             RGBColor[
             0.23762722721084206`, 0.36709166060796167`, 0.9368438911004533]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 177}], {
             RGBColor[
             0.2679195346173776, 0.39893079633545114`, 0.9385689931938027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 71}], {
             RGBColor[
             0.2862116459129269, 0.41815696509391576`, 0.9396107018713307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 74}], {
             RGBColor[
             0.29246128213975436`, 0.4247257290181345, 0.9399666094089402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 158}], {
             RGBColor[
             0.267702506048196, 0.39870268554883526`, 0.9385566337378528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 164}], {
             RGBColor[
             0.28843151316149873`, 0.42049018631987756`, 0.9397371200271375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 166}], {
             RGBColor[
             0.33653220976868264`, 0.46344910853990606`, 0.9427545820635193]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 184}], {
             RGBColor[
             0.3266364768489205, 0.4548779220588064, 0.942124034712325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 70}], {
             RGBColor[
             0.2130689137116028, 0.34127931603325223`, 0.9354453314774407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 134}], {
             RGBColor[
             0.22165741455534713`, 0.35030637496243233`, 0.9359344338949436]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 145}], {
             RGBColor[
             0.21010927874609994`, 0.3381685520328137, 0.9352767846445429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 100}], {
             RGBColor[
             0.21261327393044743`, 0.34080040973402737`, 0.9354193834659627]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 104}], {
             RGBColor[
             0.21517354122831484`, 0.34349141299440844`, 0.9355651869010002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 123}], {
             RGBColor[
             0.2309218560021901, 0.36004389032257866`, 0.9364620301298284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 130}], {
             RGBColor[
             0.22431818084808952`, 0.35310300903843134`, 0.9360859605990643]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 135}], {
             RGBColor[
             0.222345629185322, 0.35102973217386374`, 0.9359736266999984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 148}], {
             RGBColor[
             0.20810268194188267`, 0.3360594915659958, 0.9351625119250367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 163}], {
             RGBColor[
             0.2222172147783616, 0.3508947604902047, 0.935966313689494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 165}], {
             RGBColor[
             0.21515759774182608`, 0.3434746553792333, 0.935564278943031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 58}], {
             RGBColor[
             0.2684799532608956, 0.3995198318623828, 0.9386009082064859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 61}], {
             RGBColor[
             0.27330173727350593`, 0.40458783257840025`, 0.9388755016728139]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 73}], {
             RGBColor[
             0.28297059999413937`, 0.41475042033909004`, 0.9394261291009534]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 94}], {
             RGBColor[
             0.3454669572962359, 0.47032499193673805`, 0.9433554929496641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 105}], {
             RGBColor[
             0.3080083942884021, 0.4378802673814718, 0.9409686664381117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 115}], {
             RGBColor[
             0.2691801918114708, 0.40025582697672574`, 0.938640785756031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 116}], {
             RGBColor[
             0.33119462320051296`, 0.4579630134913923, 0.9424460724416142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 126}], {
             RGBColor[
             0.29001572662104147`, 0.4221552951107917, 0.9398273386400247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 160}], {
             RGBColor[
             0.3197591214680627, 0.448058156655773, 0.9417174123832397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 174}], {
             RGBColor[
             0.3271085364710258, 0.454423850539001, 0.942185710608396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 62}], {
             RGBColor[
             0.35430836392456, 0.4813058296004574, 0.9437971935400564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 68}], {
             RGBColor[
             0.6040034340544339, 0.6836766872491769, 0.9648829517187356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 72}], {
             RGBColor[
             0.3011292819316679, 0.4298018950317811, 0.9406079602011264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 75}], {
             RGBColor[
             0.3182717437982659, 0.44781970934843396`, 0.9415841980444295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 76}], {
             RGBColor[
             0.31436618073050393`, 0.4437147149372155, 0.9413617820054831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 96}], {
             RGBColor[
             0.32928937279498216`, 0.459399935982008, 0.942211635716671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 107}], {
             RGBColor[
             0.5098065457970684, 0.609801290788619, 0.955570731517623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 111}], {
             RGBColor[
             0.40643893320785657`, 0.5262638141229958, 0.9471727572298012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 139}], {
             RGBColor[
             0.3007701310464627, 0.42942440467994913`, 0.9405875070895301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 147}], {
             RGBColor[
             0.41653896028796467`, 0.5344634711076623, 0.9479678683591656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 157}], {
             RGBColor[
             0.4550334300726567, 0.5657150158349769, 0.9509982940305055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 182}], {
             RGBColor[
             0.30875284137949693`, 0.43781473937303605`, 0.9410421106336347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 185}], {
             RGBColor[
             0.5609776882411449, 0.6497765761810184, 0.9606709927749343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 191}], {
             RGBColor[
             0.31630641834476525`, 0.445754027687974, 0.9414722756672911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 79}], {
             RGBColor[
             0.1914475761291835, 0.31855391936214905`, 0.9342140282880245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 118}], {
             RGBColor[
             0.5461172634712221, 0.619552323592125, 0.9625471406553332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 119}], {
             RGBColor[
             0.37190268566599016`, 0.4815133675923786, 0.9461947205451795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 125}], {
             RGBColor[
             0.17894341419620807`, 0.3054112523609348, 0.9335019347641915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 129}], {
             RGBColor[
             0.5845933454317087, 0.6420998957641366, 0.6750810838088802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 149}], {
             RGBColor[
             0.2062475040297809, 0.3341095819553035, 0.9350568622874322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 170}], {
             RGBColor[
             0.1806461819290649, 0.30720096920987716`, 0.9335989048675586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 190}], {
             RGBColor[
             0.1793170310330229, 0.30580394734510286`, 0.9335232116903315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 195}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 197}], {
             RGBColor[
             0.5339219968548683, 0.6098281490239381, 0.9613839452386224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 66}], {
             RGBColor[
             0.5260989516337345, 0.6228771288818142, 0.9570472794276266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 71}], {
             RGBColor[
             0.32543061952646807`, 0.4545863786212526, 0.9420196308425695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 81}], {
             RGBColor[
             0.4684558639722499, 0.5768344890925647, 0.951993469629622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 90}], {
             RGBColor[
             0.37426337273503046`, 0.49858985526418154`, 0.9450687090559382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 141}], {
             RGBColor[
             0.35995825064388254`, 0.48619947750517123`, 0.9441571993258131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 198}], {
             RGBColor[
             0.528369365099485, 0.6246507931370399, 0.9572735730236723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 61}], {
             RGBColor[
             0.26897522612323943`, 0.4000403950428194, 0.9386291132633059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 73}], {
             RGBColor[
             0.2786440888438728, 0.4102029828035092, 0.9391797406914454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 92}], {
             RGBColor[
             0.24643437763355744`, 0.3763485341078243, 0.9373454452880156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 115}], {
             RGBColor[
             0.2648536806612042, 0.3957083894411449, 0.9383943973465231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 155}], {
             RGBColor[
             0.25688825427596124`, 0.3873362212730521, 0.9379407780976758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 154}], {
             RGBColor[
             0.7176662191262557, 0.7759253920834623, 0.911377748265729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 186}], {
             RGBColor[
             0.36541764511564734`, 0.4884580900498052, 0.9445955073983169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 193}], {
             RGBColor[
             0.38274569330621644`, 0.5059368150091147, 0.9456091950221126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.2862778470683244, 0.4173156224381487, 0.9396478253289002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 104}], {
             RGBColor[
             0.23644603942151277`, 0.3658501573497452, 0.9367766242032618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 123}], {
             RGBColor[
             0.252194354195388, 0.3824026346779154, 0.9376734674320901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 130}], {
             RGBColor[
             0.2455906790412874, 0.3754617533937681, 0.9372973979013259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 163}], {
             RGBColor[
             0.24348971297155947`, 0.37325350484554143`, 0.9371777509917558]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 177}], {
             RGBColor[
             0.273782020378095, 0.40509264057303096`, 0.9389028530851051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 73}], {
             RGBColor[
             0.28346587285648317`, 0.41527098351952657`, 0.9394543341577734]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 94}], {
             RGBColor[
             0.34596223015857974`, 0.47084555511717463`, 0.9433836980064841]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 105}], {
             RGBColor[
             0.30850366715074595`, 0.4384008305619083, 0.9409968714949317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 115}], {
             RGBColor[
             0.2696754646738146, 0.40077639015716227`, 0.938668990812851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 116}], {
             RGBColor[
             0.3316898960628568, 0.4584835766718288, 0.9424742774984342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 160}], {
             RGBColor[
             0.3202543943304065, 0.44857871983620956`, 0.9417456174400596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 174}], {
             RGBColor[
             0.3276038093333696, 0.4549444137194375, 0.9422139156652158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 68}], {
             RGBColor[
             0.6059297438464823, 0.6853451599719039, 0.965005694475316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 75}], {
             RGBColor[
             0.3201980535903144, 0.44948818207116104`, 0.9417069408010099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 76}], {
             RGBColor[
             0.3162924905225524, 0.44538318765994256`, 0.9414845247620637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 96}], {
             RGBColor[
             0.33121568258703066`, 0.4610684087047351, 0.9423343784732514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 105}], {
             RGBColor[
             0.3497224989411253, 0.4773337838440822, 0.9435049862784333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 107}], {
             RGBColor[
             0.5117328555891169, 0.611469763511346, 0.9556934742742034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 111}], {
             RGBColor[
             0.40836524299990506`, 0.527932286845723, 0.9472954999863816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 116}], {
             RGBColor[
             0.37290872785323614`, 0.4974165299540027, 0.9449823922819357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 126}], {
             RGBColor[
             0.33172983127376465`, 0.4616088115734021, 0.9423636584803461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 157}], {
             RGBColor[
             0.4569597398647052, 0.567383488557704, 0.951121036787086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 174}], {
             RGBColor[
             0.36882264112374896`, 0.4938773670016114, 0.9447220304487174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 182}], {
             RGBColor[
             0.31067915117154543`, 0.43948321209576313`, 0.9411648533902153]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 185}], {
             RGBColor[
             0.5629039980331934, 0.6514450489037454, 0.9607937355315148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 191}], {
             RGBColor[
             0.3182327281368137, 0.4474225004107011, 0.9415950184238715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 77}], {
             RGBColor[
             0.3266232709961202, 0.4565542003312445, 0.9420613976778401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 91}], {
             RGBColor[
             0.5953350475574752, 0.6767809281925967, 0.9640487060966569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 102}], {
             RGBColor[
             0.3633436999904507, 0.48913178357153686`, 0.9443729171645411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 106}], {
             RGBColor[
             0.3139521958632445, 0.44323609697402705`, 0.9413397986941987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 112}], {
             RGBColor[
             0.32715088352733546`, 0.45710875455411837`, 0.94209144443096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 140}], {
             RGBColor[
             0.32917806589633525`, 0.4592394517547229, 0.942206889467927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 69}], {
             RGBColor[
             0.512094113243802, 0.613375440560194, 0.9551211815778647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 82}], {
             RGBColor[
             0.4706005281918093, 0.5774357827163821, 0.9524772470296884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 86}], {
             RGBColor[
             0.5072811113074129, 0.6092066601914048, 0.9548145013504485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 87}], {
             RGBColor[
             0.8052886005993835, 0.8468955393268014, 0.9061943444225835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 108}], {
             RGBColor[
             0.7019176077126746, 0.7667599945944428, 0.9711311636805353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 110}], {
             RGBColor[
             0.6138148271599528, 0.6973615545881173, 0.9627408981532811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 127}], {
             RGBColor[
             0.4720951346225606, 0.5787303356855954, 0.9525724820298272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 154}], {
             RGBColor[
             0.8045650840099676, 0.8465963466235498, 0.9181848867101159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 161}], {
             RGBColor[
             0.4656307978135873, 0.573123205257251, 0.9521608748370004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 162}], {
             RGBColor[
             0.8027519456818715, 0.845632128982279, 0.9386302937530759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 175}], {
             RGBColor[
             0.4715002623045349, 0.5782150871828736, 0.9525345772917476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 176}], {
             RGBColor[
             0.45839978276888355`, 0.5655229499724335, 0.9517490792275327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 180}], {
             RGBColor[
             0.6733354003460714, 0.7444313569668306, 0.9682823563661463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 66}], {
             RGBColor[
             0.8068568184878835, 0.8498672602817441, 0.9811645922016861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 69}], {
             RGBColor[
             0.6618396215787897, 0.7314857264416685, 0.9696204831011173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 87}], {
             RGBColor[
             0.9550341089343712, 0.965005825208276, 0.9206936459458361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 90}], {
             RGBColor[
             0.6550212395891795, 0.7255799866641114, 0.9691860218299977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 110}], {
             RGBColor[
             0.7635603354949406, 0.815471840469592, 0.9772401996765336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 131}], {
             RGBColor[
             0.9106761538385292, 0.7880776994423069, 0.6150413032300603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 133}], {
             RGBColor[
             0.8563164442942707, 0.43429365345994053`, 0.44418899353026553`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 162}], {
             RGBColor[
             0.9524974540168591, 0.9637424148637534, 0.9531295952763283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 180}], {
             RGBColor[
             0.8230809086810591, 0.8625416428483053, 0.9827816578893989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 198}], {
             RGBColor[
             0.809127231953634, 0.8516409245369697, 0.9813908857977319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 81}], {
             RGBColor[
             0.633976904061278, 0.7129754213419766, 0.9648440654867796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 90}], {
             RGBColor[
             0.5397844128240585, 0.6347307875135932, 0.9579193049130958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 141}], {
             RGBColor[
             0.5254792907329107, 0.622340409754583, 0.9570077951829706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 168}], {
             RGBColor[
             0.8151061747990456, 0.8563704613486036, 0.9793645875552226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 172}], {
             RGBColor[
             0.8427983522117647, 0.874271591791478, 0.7778392040313489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 198}], {
             RGBColor[
             0.6938904051885131, 0.7607917253864516, 0.97012416888083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 87}], {
             RGBColor[
             0.8747953206754928, 0.4237267463664781, 0.39303006082518865`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 103}], {
             RGBColor[
             0.833567382441636, 0.252847633383231, 0.17953580679306383`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 129}], {
             RGBColor[
             0.8755570267580526, 0.42023027988113926`, 0.24893178910674738`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 131}], {
             RGBColor[
             0.8452233506115981, 0.3057746625224987, 0.18926183234800478`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 133}], {
             RGBColor[
             0.8199464110752147, 0.15432243286297473`, 0.166734011812862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 143}], {
             RGBColor[
             0.8190699438712857, 0.14758552186319893`, 0.16589470582855148`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 162}], {
             RGBColor[
             0.8731042173971515, 0.4228844728034631, 0.4146540270455168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 107}], {
             RGBColor[
             0.7614279257189907, 0.8138406211600655, 0.9767792324528825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 111}], {
             RGBColor[
             0.6580603131297789, 0.7303031444944423, 0.9683812581650608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 122}], {
             RGBColor[
             0.924281570863012, 0.9375100698293877, 0.7294250958369339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 138}], {
             RGBColor[
             0.8842002449557951, 0.7898038345132208, 0.6173834589873493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 142}], {
             RGBColor[
             0.7482569303671527, 0.8035288216790438, 0.9754818662750824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 147}], {
             RGBColor[
             0.668160340209887, 0.7385028014791089, 0.9691763692944251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 156}], {
             RGBColor[
             0.8882342803358891, 0.9137179209353309, 0.9892017726661817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 157}], {
             RGBColor[
             0.7066548099945791, 0.7697543462064234, 0.9722067949657651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 179}], {
             RGBColor[
             0.8317792747849202, 0.8687996297404257, 0.9837911974570385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 181}], {
             RGBColor[
             0.9199773592711327, 0.9377520223513063, 0.9477245085556535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 185}], {
             RGBColor[
             0.8125990681630673, 0.8538159065524649, 0.9818794937101938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 82}], {
             RGBColor[
             0.3600920128525825, 0.48631533560726303`, 0.9441657225354702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 86}], {
             RGBColor[
             0.39677259596818604`, 0.5180862130822859, 0.9465029768562303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 90}], {
             RGBColor[
             0.3947672159149649, 0.5163492536735178, 0.946375195812527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 110}], {
             RGBColor[
             0.503306311820726, 0.6062411074789984, 0.9544293736590629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 123}], {
             RGBColor[
             0.3260085199796461, 0.4514023478470298, 0.9421913646386602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 127}], {
             RGBColor[
             0.3615866192833338, 0.48760988857647636`, 0.944260957535609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 177}], {
             RGBColor[
             0.3475961861623531, 0.47409235374214537`, 0.9434207502916752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 180}], {
             RGBColor[
             0.5628268850068445, 0.6533109098577117, 0.9599708318719281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 72}], {
             RGBColor[
             0.23177582019152226`, 0.36094146083002354`, 0.936510662127084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 93}], {
             RGBColor[
             0.21891136206643785`, 0.34742009968680476`, 0.9357780502681208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 134}], {
             RGBColor[
             0.2222636314959646, 0.3509435474033953, 0.9359689570528942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 139}], {
             RGBColor[
             0.23141666930631707`, 0.36056397047819155`, 0.9364902090154877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.2107154956867174, 0.33880572447377666`, 0.9353113078024935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 81}], {
             RGBColor[
             0.43330857195401157`, 0.5446846710814149, 0.9498164169017225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 164}], {
             RGBColor[
             0.2925031947568016, 0.42476978183606456`, 0.9399689962704769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 184}], {
             RGBColor[
             0.3307081584442233, 0.45915751757499346`, 0.9423559109556644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 75}], {
             RGBColor[
             0.26701897159742227`, 0.39798424750248473`, 0.9385177074620799]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 84}], {
             RGBColor[
             0.256326539038239, 0.386745822943403, 0.9379087892458708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 93}], {
             RGBColor[
             0.23701205160573985`, 0.3664450720426131, 0.9368088577598136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 134}], {
             RGBColor[
             0.2403643210352666, 0.36996851975920364`, 0.9369997645445869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 139}], {
             RGBColor[
             0.24951735884561907`, 0.3795889428339999, 0.9375210165071806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 152}], {
             RGBColor[
             0.2658080334878341, 0.396711474771397, 0.9384487463281612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 191}], {
             RGBColor[
             0.2650536461439216, 0.3959185658420248, 0.9384057850849414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 94}], {
             RGBColor[
             0.35563109287921313`, 0.4810081428778644, 0.9439343254346236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 115}], {
             RGBColor[
             0.27934432739444803`, 0.41093897791785206`, 0.9392196182409905]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 153}], {
             RGBColor[
             0.4395524049734263, 0.5500947505807087, 0.9502769094004289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 160}], {
             RGBColor[
             0.3299232570510399, 0.45874130759689935`, 0.9422962448681991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 80}], {
             RGBColor[
             0.46133983359188224`, 0.5689367397653611, 0.9518870537804123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 158}], {
             RGBColor[
             0.2780238238703263, 0.40955104498924105`, 0.9391444175188017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 164}], {
             RGBColor[
             0.29875283098362904`, 0.4313385457602833, 0.9403249038080864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 166}], {
             RGBColor[
             0.34685352759081295`, 0.47429746798031186`, 0.9433423658444682]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 169}], {
             RGBColor[
             0.28768269698087445`, 0.4197031330363533, 0.9396944760534252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 184}], {
             RGBColor[
             0.3369577946710508, 0.46572628149921225`, 0.9427118184932739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 76}], {
             RGBColor[
             0.2802558703962583, 0.4118970674079191, 0.9392715292664366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 96}], {
             RGBColor[
             0.29517906246073655`, 0.4275822884527116, 0.9401213829776245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 134}], {
             RGBColor[
             0.2575067829018646, 0.3879863340758565, 0.93797600238789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 139}], {
             RGBColor[
             0.26665982071221705`, 0.39760675715065275`, 0.9384972543504835]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 182}], {
             RGBColor[
             0.27464253104525127`, 0.40599709184373967`, 0.9389518578945881]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 191}], {
             RGBColor[
             0.2821961080105196, 0.4139363801586776, 0.9393820229282445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.2912734993929746, 0.42347729404149315`, 0.9398989669386781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 105}], {
             RGBColor[
             0.3097803157470692, 0.4397426691808402, 0.94106957474386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 111}], {
             RGBColor[
             0.368423059805849, 0.49034117218248097`, 0.9448600884518084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 116}], {
             RGBColor[
             0.3329665446591801, 0.4598254152907607, 0.9425469807473624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 126}], {
             RGBColor[
             0.2917876480797086, 0.4240176969101601, 0.9399282469457728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 174}], {
             RGBColor[
             0.3288804579296929, 0.4562862523383694, 0.9422866189141441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.27073696797748936`, 0.4018920974325212, 0.938729441855642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 191}], {
             RGBColor[
             0.2782905449427576, 0.40983138574745914`, 0.9391596068892982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 102}], {
             RGBColor[
             0.33711449602806876`, 0.4656411721496162, 0.9427298892598499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 106}], {
             RGBColor[
             0.2877229919008626, 0.4197454855521064, 0.9396967707895075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 112}], {
             RGBColor[
             0.3009216795649535, 0.4336181431321977, 0.9404484165262689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 140}], {
             RGBColor[
             0.3029488619339533, 0.43574884033280226`, 0.9405638615632359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 189}], {
             RGBColor[
             0.2658927211222934, 0.3968004868447199, 0.9384535691636595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 91}], {
             RGBColor[
             0.8828910750951913, 0.909457394113841, 0.9886921329803882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 95}], {
             RGBColor[
             0.9537951709684989, 0.944166482218568, 0.6841709176231596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 113}], {
             RGBColor[
             0.9141333132318434, 0.7927873365838396, 0.6157566218013946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 136}], {
             RGBColor[
             0.9179856014839756, 0.8091909436388446, 0.6189147464565151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 89}], {
             RGBColor[
             0.637317539505268, 0.3879136396684716, 0.4445332384990521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 118}], {
             RGBColor[
             0.5586378396004057, 0.632712242954274, 0.9632601689433578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 119}], {
             RGBColor[
             0.3844232617951737, 0.4946732869545277, 0.9469077488332039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 125}], {
             RGBColor[
             0.19146399032539158`, 0.3185711717230839, 0.934214963052216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 128}], {
             RGBColor[
             0.5467748334649722, 0.46160555519396695`, 0.5822517523121589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 144}], {
             RGBColor[
             0.6389999811794337, 0.4008456236267517, 0.4461443465462792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 149}], {
             RGBColor[
             0.21876808015896437`, 0.34726950131745254`, 0.9357698905754568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 159}], {
             RGBColor[
             0.6164190249825052, 0.2272784992590594, 0.42452079739055826`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 170}], {
             RGBColor[
             0.1931667580582484, 0.32036088857202627`, 0.934311933155583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 190}], {
             RGBColor[
             0.19183760716220638`, 0.3189638667072519, 0.9342362399783559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 192}], {
             RGBColor[
             0.6128687174194557, 0.19998927957476603`, 0.421121018858683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 195}], {
             RGBColor[
             0.1914475761291835, 0.31855391936214905`, 0.9342140282880245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 197}], {
             RGBColor[
             0.5464425729840517, 0.6229880683860871, 0.9620969735266468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 81}], {
             RGBColor[
             0.5981154418108365, 0.6846160863124545, 0.9615049850298553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 117}], {
             RGBColor[
             0.699447709361209, 0.7647890454809683, 0.9709133239805854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 120}], {
             RGBColor[
             0.7883329572883422, 0.7840663517109472, 0.6248876395864237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 121}], {
             RGBColor[
             0.5812862861253769, 0.6709534195821745, 0.9601801322470673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 166}], {
             RGBColor[
             0.5054107612208105, 0.6076601192871327, 0.9546750264349914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 168}], {
             RGBColor[
             0.7792447125486042, 0.8280111263190817, 0.9760255070982982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 172}], {
             RGBColor[
             0.8069368899613232, 0.8459122567619559, 0.7745001235744244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 173}], {
             RGBColor[
             0.807519241461194, 0.8471578477354111, 0.8378854904784999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 184}], {
             RGBColor[
             0.4955150283010483, 0.599088932806033, 0.9540444790837972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 164}], {
             RGBColor[
             0.43552843920258344`, 0.5470178923073767, 0.9499428350575294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 166}], {
             RGBColor[
             0.4836291358097673, 0.5899768145274054, 0.9529602970939112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 168}], {
             RGBColor[
             0.7574630871375609, 0.8103278215593543, 0.974310777757218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 172}], {
             RGBColor[
             0.7851552645502801, 0.8282289520022286, 0.7727853942333442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 173}], {
             RGBColor[
             0.7857376160501509, 0.8294745429756838, 0.8361707611374197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 184}], {
             RGBColor[
             0.47373340289000515`, 0.5814056280463057, 0.952329749742717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 198}], {
             RGBColor[
             0.6362473175270285, 0.7147490855972023, 0.9650703590828255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 86}], {
             RGBColor[
             0.3552790109161934, 0.48214655523847394`, 0.943859042308054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 101}], {
             RGBColor[
             0.2852213829706352, 0.4162052116877847, 0.9395876612614353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 110}], {
             RGBColor[
             0.4618127267687334, 0.5703014496351865, 0.9517854391108865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 123}], {
             RGBColor[
             0.28451493492765345`, 0.4154626900032179, 0.9395474300904838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 127}], {
             RGBColor[
             0.32009303423134106`, 0.45167023073266444`, 0.9416170229874327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 130}], {
             RGBColor[
             0.27791125977355285`, 0.4085218087190706, 0.9391713605597196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 163}], {
             RGBColor[
             0.2758102937038249, 0.40631356017084397`, 0.9390517136501494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 176}], {
             RGBColor[
             0.30639768237766407`, 0.4384628450195025, 0.9407936201851381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 177}], {
             RGBColor[
             0.3061026011103605, 0.4381526958983335, 0.9407768157434988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 180}], {
             RGBColor[
             0.5213332999548519, 0.6173712520138998, 0.9573268973237518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 187}], {
             RGBColor[
             0.3007127795635599, 0.4324876517182224, 0.9404698733799348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 86}], {
             RGBColor[
             0.32390396973941904`, 0.450080321936663, 0.9420389267285452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 101}], {
             RGBColor[
             0.2538463417938609, 0.3841389783859738, 0.9377675456819266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 124}], {
             RGBColor[
             0.2734514125634414, 0.4047451507980839, 0.9388840254591511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 135}], {
             RGBColor[
             0.244563666934011, 0.3743822985526921, 0.9372389110811449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 137}], {
             RGBColor[
             0.2530177140174724, 0.383268038054954, 0.9377203565559061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 161}], {
             RGBColor[
             0.28225365624559345`, 0.41399686700250915`, 0.9393853002150969]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 165}], {
             RGBColor[
             0.2373756354905151, 0.36682722175806165`, 0.9368295633241774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 175}], {
             RGBColor[
             0.2881231207365411, 0.41908874892813175`, 0.9397590026698441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 176}], {
             RGBColor[
             0.2750226412008897, 0.4063966117176916, 0.9389735046056292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 187}], {
             RGBColor[
             0.26933773838678554`, 0.40042141841641143`, 0.938649757800426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 199}], {
             RGBColor[
             0.2640684264301843, 0.3948830374563491, 0.938349678279746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 93}], {
             RGBColor[
             0.24346208091315458`, 0.3732244618001842, 0.9371761773869076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 139}], {
             RGBColor[
             0.25596738815303377`, 0.386368332591571, 0.9378883361342745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 152}], {
             RGBColor[
             0.2722580627952489, 0.4034908645289682, 0.9388160659552552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 194}], {
             RGBColor[
             0.30565287667395435`, 0.4349127039944547, 0.9408525291212098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 99}], {
             RGBColor[
             0.4621252914114974, 0.5716835642651686, 0.9514982759565006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 109}], {
             RGBColor[
             0.34884904242599657`, 0.47657723971187865`, 0.9434493304016565]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 132}], {
             RGBColor[
             0.3061847210307328, 0.43439681259051416`, 0.9409221739886695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 146}], {
             RGBColor[
             0.578124805971577, 0.6635021636474746, 0.9622403310784291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 150}], {
             RGBColor[
             0.3215409260409259, 0.45053715769585945`, 0.9417966871465304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 151}], {
             RGBColor[
             0.35601576258697687`, 0.48278469250549083`, 0.9439059874730323]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 152}], {
             RGBColor[
             0.320947319253029, 0.44991323932493577`, 0.9417628821181223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 194}], {
             RGBColor[
             0.35434213313173446`, 0.48133507879042225`, 0.9437993452840767]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 196}], {
             RGBColor[
             0.42766426196123664`, 0.5437065481057618, 0.9487853774832657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 101}], {
             RGBColor[
             0.3219019660862388, 0.44797608916280746`, 0.9419249155821955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 108}], {
             RGBColor[
             0.5865960904370586, 0.6714707671165345, 0.9625129589589009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 110}], {
             RGBColor[
             0.49849330988433693`, 0.6020723271102092, 0.9541226934316467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 124}], {
             RGBColor[
             0.3415070368558193, 0.46858226157491756`, 0.94304139535942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 127}], {
             RGBColor[
             0.3567736173469446, 0.48344110820768715`, 0.9439542773081928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 161}], {
             RGBColor[
             0.35030928053797133`, 0.47783397777934283`, 0.943542670115366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 175}], {
             RGBColor[
             0.356178745028919, 0.4829258597049654, 0.9439163725701132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 176}], {
             RGBColor[
             0.3430782654932676, 0.4702337224945253, 0.9431308745058982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 180}], {
             RGBColor[
             0.5580138830704554, 0.6491421294889225, 0.9596641516445119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 187}], {
             RGBColor[
             0.3373933626791634, 0.4642585291932452, 0.9428071277006951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 199}], {
             RGBColor[
             0.3321240507225622, 0.4587201482331828, 0.9425070481800151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 95}], {
             RGBColor[
             0.9838001922594006, 0.9661152059128862, 0.6121532693347048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 103}], {
             RGBColor[
             0.9055186961480244, 0.6475369650177958, 0.42196747470883456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 108}], {
             RGBColor[
             0.8846035797290293, 0.9091596462519311, 0.913892802031036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 110}], {
             RGBColor[
             0.7965007991763076, 0.8397612062456058, 0.9055025365037817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 131}], {
             RGBColor[
             0.9436166175198961, 0.8123670652183208, 0.5433036400573084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 143}], {
             RGBColor[
             0.876523819007324, 0.43701274197773154`, 0.3946852727798099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[
             0.9872510560263222, 0.9889959982810382, 0.8609465250606165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 162}], {
             RGBColor[
             0.9854379176982261, 0.9880317806397674, 0.8813919321035765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 180}], {
             RGBColor[
             0.8560213723624259, 0.8868310086243191, 0.9110439947166469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 94}], {
             RGBColor[
             0.5651610277683712, 0.6558369100747177, 0.9599061248871635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 102}], {
             RGBColor[
             0.5430147651889159, 0.6366549305319157, 0.9584949846187718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[
             0.8062483508925926, 0.7076340176229743, 0.6052352623718941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 122}], {
             RGBColor[
             0.8525664665525501, 0.8811976138560375, 0.7223536497554326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 136}], {
             RGBColor[
             0.8101006391447247, 0.7240376246779792, 0.6083933870270145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 142}], {
             RGBColor[
             0.6765418260566909, 0.7472163657056936, 0.968410420193581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 153}], {
             RGBColor[
             0.6490823398625842, 0.7249235177775619, 0.9662487088529688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 167}], {
             RGBColor[
             0.8137351892886164, 0.8551855895073546, 0.9818647874444291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 188}], {
             RGBColor[
             0.688424300235651, 0.7565215626533395, 0.9695793586227837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 113}], {
             RGBColor[
             0.8694288542290634, 0.4907346699510474, 0.21239820772463422`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 118}], {
             RGBColor[
             0.8737639977332939, 0.5885792424884555, 0.4634219800772578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 122}], {
             RGBColor[
             0.9003075980023684, 0.6064437341064228, 0.29047713264699326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 136}], {
             RGBColor[
             0.8719970463971514, 0.5016704079877174, 0.2145036241613812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 138}], {
             RGBColor[
             0.8735867140642237, 0.5079729105623115, 0.2157827080806035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 144}], {
             RGBColor[
             0.8548334539658015, 0.42247953211969835`, 0.20014188348416714`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 149}], {
             RGBColor[
             0.6471841581056663, 0.3982840813972412, 0.44509512783199057`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 159}], {
             RGBColor[
             0.8435429758673372, 0.3356959699358522, 0.18933010890630664`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 170}], {
             RGBColor[
             0.6301166100385224, 0.38034500623362366`, 0.4441231562187414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 192}], {
             RGBColor[
             0.8417678220858125, 0.32205136009370555`, 0.18763021964036905`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 197}], {
             RGBColor[
             0.865633819989058, 0.5820964594429976, 0.4626465164661172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 141}], {
             RGBColor[
             0.37364371183420664`, 0.49805313613695035`, 0.9450292248112824]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 177}], {
             RGBColor[
             0.3407778041727428, 0.4681866139645882, 0.9429862890205556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 198}], {
             RGBColor[
             0.542054826289809, 0.636504451768819, 0.9581455985091416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 95}], {
             RGBColor[
             0.9087217160297558, 0.9082261327367556, 0.679871771253554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 136}], {
             RGBColor[
             0.8729121465452325, 0.773250594157032, 0.6146156000869095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 97}], {
             RGBColor[
             0.2548383832137916, 0.38518167681737986`, 0.9378240409731977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 155}], {
             RGBColor[
             0.23916918979888965`, 0.36871236105407446`, 0.9369317035887135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 134}], {
             RGBColor[
             0.2274998629101822, 0.35644715861598486`, 0.9362671526856237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 139}], {
             RGBColor[
             0.2366529007205347, 0.36606758169078113`, 0.9367884046482173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 145}], {
             RGBColor[
             0.21595172710093502`, 0.34430933568636624`, 0.935609503435223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 105}], {
             RGBColor[
             0.3806688871734759, 0.5041379899202462, 0.945476862771782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 111}], {
             RGBColor[
             0.43931163123225564`, 0.554736492921887, 0.9492673764797304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 115}], {
             RGBColor[
             0.34184068469654455`, 0.4665135495155001, 0.9431489820897013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 116}], {
             RGBColor[
             0.4038551160855868, 0.5242207360301667, 0.9469542687752844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 126}], {
             RGBColor[
             0.3626762195061153, 0.4884130176495661, 0.9443355349736948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 142}], {
             RGBColor[
             0.5295082484696294, 0.6279621701064884, 0.9563679845897519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 153}], {
             RGBColor[
             0.5020487622755229, 0.6056693221783567, 0.9542062732491396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 160}], {
             RGBColor[
             0.39241961435313644`, 0.5143158791945474, 0.9462256087169099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 167}], {
             RGBColor[
             0.666701611701555, 0.7359313939081493, 0.9698223518406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 174}], {
             RGBColor[
             0.39976902935609954`, 0.5206815730777754, 0.9466939069420661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 188}], {
             RGBColor[
             0.5413907226485897, 0.6372673670541342, 0.9575369230189545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 103}], {
             RGBColor[
             0.9027357759104662, 0.63208364163686, 0.26409899908324835`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 129}], {
             RGBColor[
             0.9849427513832404, 0.9608705061848779, 0.39600586175704294`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 131}], {
             RGBColor[
             0.9394422371635587, 0.7891870801469172, 0.306500926618929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 143}], {
             RGBColor[
             0.8737408987697657, 0.4215594185967958, 0.23681679715422363`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 154}], {
             RGBColor[
             0.9830766756699849, 0.9658160132096346, 0.6241438116222372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 105}], {
             RGBColor[
             0.32470350781154744`, 0.4554278902256328, 0.9419194284550477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 111}], {
             RGBColor[
             0.3833462518703272, 0.5060263932272735, 0.9457099421629962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 116}], {
             RGBColor[
             0.3478897367236583, 0.4755106363355533, 0.9433968344585502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 126}], {
             RGBColor[
             0.3067108401441868, 0.4397029179549527, 0.9407781006569607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.43194074873512733`, 0.5454775949392545, 0.9495354789637005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 174}], {
             RGBColor[
             0.3438036499941711, 0.471971473383162, 0.943136472625332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 182}], {
             RGBColor[
             0.2856601600419676, 0.4175773184773137, 0.9395792955668297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 191}], {
             RGBColor[
             0.29321373700723585`, 0.4255166067922517, 0.9400094606004861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 102}], {
             RGBColor[
             0.3273981891467483, 0.4554287175679108, 0.9421765599569466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 112}], {
             RGBColor[
             0.2912053726836331, 0.4234056885504923, 0.9398950872233656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 140}], {
             RGBColor[
             0.29323255505263285`, 0.42553638575109687`, 0.9400105322603325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 155}], {
             RGBColor[
             0.2652922598561954, 0.3961693639826077, 0.9384193737828581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 99}], {
             RGBColor[
             0.7687919437411839, 0.8183727141912807, 0.944294118700548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 117}], {
             RGBColor[
             0.8762433687105626, 0.9035134810174441, 0.9541841801385145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 120}], {
             RGBColor[
             0.9651286166376958, 0.922790787247423, 0.6081584957443529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 121}], {
             RGBColor[
             0.7580819454747305, 0.8096778551186503, 0.9434509884049964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 146}], {
             RGBColor[
             0.8847914583012635, 0.9101913135735867, 0.9550361738224766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 156}], {
             RGBColor[
             0.9471660663080045, 0.9597340431975859, 0.961036759682581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.9239792736477469, 0.9412455241190165, 0.9588251826995514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 178}], {
             RGBColor[
             0.957960137429429, 0.968167319845601, 0.9560467009664877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 179}], {
             RGBColor[
             0.8907110607570355, 0.9148157520026807, 0.9556261844734377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 183}], {
             RGBColor[
             0.897769781538639, 0.6310947741177858, 0.4464659481425095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 196}], {
             RGBColor[
             0.7343309142909232, 0.7903956980318739, 0.9415812202273133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 107}], {
             RGBColor[
             0.615663269511703, 0.6984811954684678, 0.963146911483036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 109}], {
             RGBColor[
             0.45081925257627997`, 0.561890841684138, 0.9507778651594582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 146}], {
             RGBColor[
             0.6800950161218604, 0.7488157656197341, 0.9695688658362309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 147}], {
             RGBColor[
             0.5223956840025993, 0.6231433757875112, 0.9555440483245787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 156}], {
             RGBColor[
             0.7424696241286013, 0.7983584952437333, 0.9755694516963352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 178}], {
             RGBColor[
             0.7532636952500258, 0.8067917718917483, 0.970579392980242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 179}], {
             RGBColor[
             0.6860146185776324, 0.753440204048828, 0.970158876487192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 194}], {
             RGBColor[
             0.45631234328201786`, 0.5666486807626816, 0.9511278800418784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 104}], {
             RGBColor[
             0.21637454520909913`, 0.34475374432626316`, 0.9356335823009796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 123}], {
             RGBColor[
             0.23212285998297438`, 0.3613062216544334, 0.9365304255298079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 130}], {
             RGBColor[
             0.2255191848288738, 0.3543653403702861, 0.9361543559990437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 135}], {
             RGBColor[
             0.2235466331661063, 0.3522920635057185, 0.9360420220999779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 148}], {
             RGBColor[
             0.20930368592266696`, 0.3373218228978505, 0.9352309073250162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 163}], {
             RGBColor[
             0.22341821875914586`, 0.35215709182205945`, 0.9360347090894736]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 165}], {
             RGBColor[
             0.21635860172261037`, 0.34473698671108804`, 0.9356326743430103]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 123}], {
             RGBColor[
             0.2511378900976988, 0.38129222392755147`, 0.9376133033646252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 124}], {
             RGBColor[
             0.2714494089102611, 0.40264091802422836`, 0.9387700143128014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 127}], {
             RGBColor[
             0.28671598940138643`, 0.417499764656998, 0.9396828962615742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 135}], {
             RGBColor[
             0.2425616632808307, 0.3722780657788366, 0.9371248999347952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 137}], {
             RGBColor[
             0.25101571036429215`, 0.3811638052810985, 0.9376063454095565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 161}], {
             RGBColor[
             0.28025165259241314`, 0.41189263422865363`, 0.9392712890687474]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 165}], {
             RGBColor[
             0.23537363183733478`, 0.36472298898420613`, 0.9367155521778278]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 175}], {
             RGBColor[
             0.2861211170833608, 0.41698451615427623`, 0.9396449915234946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 176}], {
             RGBColor[
             0.27302063754770944`, 0.4042923789438361, 0.9388594934592795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 187}], {
             RGBColor[
             0.2673357347336053, 0.3983171856425559, 0.9385357466540765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 199}], {
             RGBColor[
             0.262066422777004, 0.3927788046824936, 0.9382356671333965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 106}], {
             RGBColor[
             0.32444342089519307`, 0.4523230687923987, 0.9420082902762085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 112}], {
             RGBColor[
             0.337642108559284, 0.46619572637249007`, 0.9427599360129698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 140}], {
             RGBColor[
             0.3396692909282838, 0.4683264235730946, 0.9428753810499368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 108}], {
             RGBColor[
             0.8366047008902185, 0.5941132685295566, 0.465258687547469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 129}], {
             RGBColor[
             0.9062804022305841, 0.6440404985324568, 0.2778692029903933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 131}], {
             RGBColor[
             0.8759467260841297, 0.5295848811738163, 0.2181992462316507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 133}], {
             RGBColor[
             0.8506697865477463, 0.3781326515142924, 0.19567142569650792`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 143}], {
             RGBColor[
             0.8497933193438173, 0.37139574051451657`, 0.1948321197121974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 154}], {
             RGBColor[
             0.9050363517550805, 0.647337503215628, 0.4299611695671895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 162}], {
             RGBColor[
             0.9038275928696831, 0.6466946914547808, 0.4435914409291628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 123}], {
             RGBColor[
             0.23468312728084179`, 0.36399722491481445`, 0.9366762289648454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 130}], {
             RGBColor[
             0.2280794521267412, 0.3570563436306672, 0.9363001594340813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 163}], {
             RGBColor[
             0.22597848605701326`, 0.35484809508244053`, 0.9361805125245111]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 111}], {
             RGBColor[
             0.4018530682244218, 0.5222917683666206, 0.9468805499681779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 116}], {
             RGBColor[
             0.36639655307775293`, 0.49177601147490035`, 0.944567442263732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 126}], {
             RGBColor[
             0.3252176564982815, 0.45596829309429976`, 0.9419487084621424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 142}], {
             RGBColor[
             0.4920496854617956, 0.5955174455512221, 0.9539811580781995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 157}], {
             RGBColor[
             0.4504475650892219, 0.5617429700786016, 0.9507060867688824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 160}], {
             RGBColor[
             0.35496105134530265`, 0.4818711546392811, 0.9438387822053573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 174}], {
             RGBColor[
             0.3623104663482657, 0.48823684852250904`, 0.9443070804305137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 182}], {
             RGBColor[
             0.30416697639606216`, 0.43384269361666083`, 0.9407499033720115]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 112}], {
             RGBColor[
             0.2882506044320779, 0.42030003977498026`, 0.9397268175426274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 140}], {
             RGBColor[
             0.29027778680107763`, 0.4224307369755848, 0.9398422625795944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 189}], {
             RGBColor[
             0.25322164598941777`, 0.3834823834875024, 0.9377319701800181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 111}], {
             RGBColor[
             0.5638634248724134, 0.6564277480338845, 0.9590690379639482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 142}], {
             RGBColor[
             0.6540600421097872, 0.7296534252184859, 0.9661696460739697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[
             0.5739634519525214, 0.664627405018551, 0.9598641490933124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.7940373920785235, 0.8398425244747729, 0.979889552465069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.6124579217372135, 0.6958789497458655, 0.9628945747646525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.7375823865275546, 0.7949242332798678, 0.9744789772559258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 181}], {
             RGBColor[
             0.8257804710137671, 0.8638766258907483, 0.9384122883545408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 185}], {
             RGBColor[
             0.7184021799057017, 0.779940510091907, 0.9725672735090811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 110}], {
             RGBColor[
             0.6931298062895987, 0.7596256615132471, 0.9704393557617335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 131}], {
             RGBColor[
             0.8402456246331873, 0.7322315204859621, 0.6082404593152602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 154}], {
             RGBColor[
             0.8838800631396134, 0.9088604535486795, 0.9258833443185683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 162}], {
             RGBColor[
             0.8820669248115173, 0.9078962359074088, 0.9463287513615282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 180}], {
             RGBColor[
             0.7526503794757171, 0.8066954638919603, 0.9759808139745987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 132}], {
             RGBColor[
             0.2948786821955154, 0.42460409000948357`, 0.9402017631916271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 146}], {
             RGBColor[
             0.5668187671363596, 0.653709441066444, 0.9615199202813867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 150}], {
             RGBColor[
             0.31023488720570846`, 0.44074443511482886`, 0.941076276349488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 151}], {
             RGBColor[
             0.34470972375175946`, 0.47299196992446024`, 0.9431855766759899]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 152}], {
             RGBColor[
             0.3096412804178116, 0.4401205167439052, 0.9410424713210799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 194}], {
             RGBColor[
             0.3430360942965171, 0.47154235620939167`, 0.9430789344870343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 196}], {
             RGBColor[
             0.4163582231260193, 0.5339138255247312, 0.9480649666862233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 127}], {
             RGBColor[
             0.46330733319948464`, 0.5715960026043997, 0.9518806741110254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 162}], {
             RGBColor[
             0.7939641442587955, 0.8384977959010833, 0.9379384858342741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 180}], {
             RGBColor[
             0.6645475989229954, 0.737297023885635, 0.9675905484473445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 116}], {
             RGBColor[
             0.42503929713653266`, 0.5423745144765412, 0.9483579559716804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 126}], {
             RGBColor[
             0.3838604005570612, 0.5065667960959406, 0.9457392221700909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 142}], {
             RGBColor[
             0.5506924295205754, 0.6461159485528629, 0.957771671786148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 157}], {
             RGBColor[
             0.5090903091480017, 0.6123414730802424, 0.9544966004768307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 160}], {
             RGBColor[
             0.41360379540408243`, 0.5324696576409218, 0.9476292959133059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 167}], {
             RGBColor[
             0.687885792752501, 0.7540851723545239, 0.971226039036996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 174}], {
             RGBColor[
             0.4209532104070455, 0.5388353515241499, 0.9480975941384622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 181}], {
             RGBColor[
             0.7224128584245553, 0.7803391492251253, 0.9300143140667192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.6150345673164899, 0.6964030334262838, 0.9641692992212595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 188}], {
             RGBColor[
             0.5625749036995356, 0.6554211455005088, 0.9589406102153506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 140}], {
             RGBColor[
             0.30347647446516857`, 0.4363033945556761, 0.9405939083163557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 122}], {
             RGBColor[
             0.9466202120897103, 0.8137405258050889, 0.35564035163633406`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 136}], {
             RGBColor[
             0.9041543846818847, 0.6565805366270306, 0.24168008890791598`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 138}], {
             RGBColor[
             0.9065388861824932, 0.6660342904889218, 0.24359871478674944`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 144}], {
             RGBColor[
             0.871111295903229, 0.5036666539093275, 0.21400931577186139`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 159}], {
             RGBColor[
             0.8485303397063004, 0.33009952954163524`, 0.19238576661614035`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 167}], {
             RGBColor[
             0.9077889348257765, 0.7877285014564059, 0.6151514893253305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 197}], {
             RGBColor[
             0.8946095450697447, 0.7772196138099509, 0.6138944273650201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 158}], {
             RGBColor[
             0.23522624458781927`, 0.364568075640074, 0.9367071586920077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 160}], {
             RGBColor[
             0.31613284886837134`, 0.44424671423453505`, 0.9415109015232768]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 126}], {
             RGBColor[
             0.34840388541039236`, 0.4760510392042203, 0.9434261144656448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 142}], {
             RGBColor[
             0.5152359143739065, 0.6156001916611427, 0.9554585640817019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 153}], {
             RGBColor[
             0.48777642817979994`, 0.593307343733011, 0.9532968527410897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 157}], {
             RGBColor[
             0.47363379400133276`, 0.5818257161885222, 0.9521834927723848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 160}], {
             RGBColor[
             0.3781472802574135, 0.5019539007492015, 0.9453161882088599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 167}], {
             RGBColor[
             0.652429277605832, 0.7235694154628036, 0.96891293133255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 174}], {
             RGBColor[
             0.38549669526037655`, 0.5083195946324296, 0.9457844864340161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 188}], {
             RGBColor[
             0.5271183885528666, 0.6249053886087885, 0.9566275025109046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 120}], {
             RGBColor[
             0.8678835994276715, 0.8465560061197337, 0.6325812491960736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 121}], {
             RGBColor[
             0.6608369282647062, 0.733443073990961, 0.9678737418567172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 146}], {
             RGBColor[
             0.7875464410912392, 0.8339565324458974, 0.9794589272741974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 151}], {
             RGBColor[
             0.565437397706639, 0.6532390613039136, 0.9611245836688005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 171}], {
             RGBColor[
             0.8267342564377225, 0.8650107429913272, 0.9832479361512722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 173}], {
             RGBColor[
             0.8870698836005233, 0.9096475021441977, 0.8455791000881498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 196}], {
             RGBColor[
             0.6370858970808988, 0.7141609169041846, 0.966003973679034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 119}], {
             RGBColor[
             0.7390929491372125, 0.7956716911845035, 0.9752408612005126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 125}], {
             RGBColor[
             0.5461336776674304, 0.6195695759530597, 0.9625480754195246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 128}], {
             RGBColor[
             0.901444520807011, 0.7626039594239429, 0.6105848646794676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 138}], {
             RGBColor[
             0.9130416014388392, 0.812801149295034, 0.6201343733156849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 144}], {
             RGBColor[
             0.8754464394074596, 0.6015112264467356, 0.4650330881244851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 149}], {
             RGBColor[
             0.5734377675010032, 0.6482679055474284, 0.9641030029427655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 159}], {
             RGBColor[
             0.852865483210531, 0.4279441020790433, 0.443409538968764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 170}], {
             RGBColor[
             0.5478364454002871, 0.6213592928020021, 0.9626450455228917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 190}], {
             RGBColor[
             0.5465072945042451, 0.6199622709372278, 0.9625693523456647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 192}], {
             RGBColor[
             0.8493151756474815, 0.40065488239475, 0.4400097604368888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.5461172634712222, 0.6195523235921249, 0.9625471406553332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 197}], {
             RGBColor[
             0.9011122603260905, 0.9239864726160629, 0.9904300858939554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 125}], {
             RGBColor[
             0.3719190998621983, 0.4815306199533135, 0.9461956553093709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 128}], {
             RGBColor[
             0.727229943001779, 0.6245650034241965, 0.5942324445693138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 144}], {
             RGBColor[
             0.7593033875373049, 0.5094852557802381, 0.45413147471771587`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 149}], {
             RGBColor[
             0.3992231896957711, 0.5102289495476822, 0.9477505828326117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 183}], {
             RGBColor[
             0.7615664433424367, 0.5237229317976604, 0.4561749529436979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 190}], {
             RGBColor[
             0.3722927166990131, 0.48192331493748153`, 0.946216932235511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 192}], {
             RGBColor[
             0.7331721237773268, 0.30862891172825246`, 0.4291081470301197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 195}], {
             RGBColor[
             0.37190268566599016`, 0.4815133675923786, 0.9461947205451795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 128}], {
             RGBColor[
             0.9231751810131911, 0.7286652920066743, 0.2580660064250903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 168}], {
             RGBColor[
             0.9476806026150666, 0.909778086957847, 0.6376934323137864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 171}], {
             RGBColor[
             0.9156195043648556, 0.8842880492213061, 0.6372222517571104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 172}], {
             RGBColor[
             0.9753727800277856, 0.9276792174007213, 0.4361680487899127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 173}], {
             RGBColor[
             0.9759551315276564, 0.9289248083741766, 0.49955341569398815`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 183}], {
             RGBColor[
             0.8921966020167115, 0.5931231241859789, 0.2320639941808822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 151}], {
             RGBColor[
             0.4472759744708069, 0.5594034354051198, 0.9503913919352824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 171}], {
             RGBColor[
             0.7085728332018904, 0.7711751170925334, 0.9725147444177542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 196}], {
             RGBColor[
             0.5189244738450667, 0.6203252910053908, 0.955270781945516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 136}], {
             RGBColor[
             0.9504725003418423, 0.8301441328600938, 0.35879847629145456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 138}], {
             RGBColor[
             0.9528570018424507, 0.8395978867219851, 0.360717102170288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 142}], {
             RGBColor[
             0.8169136872538085, 0.8533228738878083, 0.7188155094580211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 144}], {
             RGBColor[
             0.901990039676534, 0.619375718064703, 0.29208824069422046`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 153}], {
             RGBColor[
             0.7894542010597019, 0.8310300259596766, 0.7166537981174088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.8794090834796054, 0.44580859369701076`, 0.2704646915384994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 167}], {
             RGBColor[
             0.9541070504857341, 0.9612920976894692, 0.7322698767088691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 181}], {
             RGBColor[
             0.9886341161577883, 0.9875460745600706, 0.6910581517385923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 188}], {
             RGBColor[
             0.8287961614327686, 0.8626280708354541, 0.7199844478872237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 192}], {
             RGBColor[
             0.8758587759165559, 0.41851937401271744`, 0.2670649130066242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 127}], {
             RGBColor[
             0.2860095413584047, 0.4167572429724312, 0.9396426650906227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 130}], {
             RGBColor[
             0.24382776690061642`, 0.3736088209588374, 0.9371970026629095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 135}], {
             RGBColor[
             0.24185521523784892`, 0.3715355440942698, 0.9370846687638437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 163}], {
             RGBColor[
             0.2417268008308885, 0.37140057241061075`, 0.9370773557533394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 165}], {
             RGBColor[
             0.23466718379435303`, 0.36398046729963934`, 0.9366753210068761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 177}], {
             RGBColor[
             0.27201910823742403`, 0.40323970813810023`, 0.9388024578466887]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 187}], {
             RGBColor[
             0.26662928669062347`, 0.3975746639579891, 0.9384955154831248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 127}], {
             RGBColor[
             0.30632106017096694`, 0.43810593706910805`, 0.9407993760387987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 135}], {
             RGBColor[
             0.26216673405041124`, 0.39288423819094664`, 0.9382413797120197]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.27062078113387267`, 0.4017699776932086, 0.938722825186781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 161}], {
             RGBColor[
             0.29985672336199365`, 0.43249880664076373`, 0.9403877688459719]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 175}], {
             RGBColor[
             0.3057261878529413, 0.4375906885663863, 0.9407614713007191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 176}], {
             RGBColor[
             0.29262570831728996`, 0.4248985513559462, 0.9399759732365041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 187}], {
             RGBColor[
             0.2869408055031858, 0.4189233580546661, 0.939652226431301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 199}], {
             RGBColor[
             0.2816714935465845, 0.4133849770946037, 0.939352146910621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 128}], {
             RGBColor[
             0.5342706715319968, 0.44846288819275276`, 0.5815396587883258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.206263918225989, 0.33412683431623835`, 0.9350577970516237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[
             0.18066259612527297`, 0.307218221570812, 0.93359983963175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 190}], {
             RGBColor[
             0.179333445229231, 0.3058211997060377, 0.933524146454523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 195}], {
             RGBColor[
             0.17894341419620807`, 0.3054112523609348, 0.9335019347641915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 142}], {
             RGBColor[
             0.47405701779443504`, 0.579792473280542, 0.9528398302801124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 157}], {
             RGBColor[
             0.43245489742186133`, 0.5460179978079216, 0.9495647589707952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 160}], {
             RGBColor[
             0.336968383677942, 0.466146182368601, 0.9426974544072704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 174}], {
             RGBColor[
             0.3443177986809051, 0.472511876251829, 0.9431657526324266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 182}], {
             RGBColor[
             0.2861743087287016, 0.41811772134598074`, 0.9396085755739244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 191}], {
             RGBColor[
             0.2937278856939699, 0.4260570096609187, 0.9400387406075807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 135}], {
             RGBColor[
             0.2774333145415366, 0.4077430848237163, 0.9391542616607926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 161}], {
             RGBColor[
             0.31512330385311904`, 0.4473576532735334, 0.9413006507947447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 175}], {
             RGBColor[
             0.32099276834406665`, 0.45244953519915593`, 0.9416743532494919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 176}], {
             RGBColor[
             0.3078922888084153, 0.4397573979887158, 0.940888855185277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 177}], {
             RGBColor[
             0.3075972075411117, 0.4394472488675467, 0.9408720507436377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 180}], {
             RGBColor[
             0.5228279063856032, 0.618665804983113, 0.9574221323238906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 187}], {
             RGBColor[
             0.3022073859943112, 0.43378220468743567`, 0.9405651083800737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 183}], {
             RGBColor[
             0.8698008244556358, 0.5016777772906199, 0.21307095526300113`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 190}], {
             RGBColor[
             0.5346442883688116, 0.44885558317692076`, 0.5815609357144658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 192}], {
             RGBColor[
             0.8414065048905258, 0.286583757221212, 0.1860041493494229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 195}], {
             RGBColor[
             0.5342542573357888, 0.44844563583181796`, 0.5815387240241343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 131}], {
             RGBColor[
             0.9447591766437358, 0.8071223654903125, 0.32715623247964654`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 133}], {
             RGBColor[
             0.8790384594977417, 0.4469900974919443, 0.2522656130299896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 143}], {
             RGBColor[
             0.8772855250898838, 0.4335162754923927, 0.2505870010613686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 170}], {
             RGBColor[
             0.5863125273607737, 0.6439068649740138, 0.6751789886764388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 197}], {
             RGBColor[
             0.939588342286577, 0.9465340447880747, 0.7029640290475025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 163}], {
             RGBColor[
             0.23512312567678792`, 0.3644596911264634, 0.9367012862225752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 177}], {
             RGBColor[
             0.26541543308332344`, 0.3962988268539529, 0.9384263883159245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 133}], {
             RGBColor[
             0.8487047833512873, 0.33253448013330367`, 0.19259565627124703`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 143}], {
             RGBColor[
             0.8469518489434293, 0.3190606581337521, 0.19091704430262602`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 154}], {
             RGBColor[
             0.9428931009304802, 0.8120678725150692, 0.5552941823448407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 162}], {
             RGBColor[
             0.941079962602384, 0.8111036548737982, 0.5757395893878008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 180}], {
             RGBColor[
             0.811663417266584, 0.70990288285835, 0.6053916520008711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 150}], {
             RGBColor[
             0.2675705658104447, 0.39856400799346436`, 0.938549119936501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 151}], {
             RGBColor[
             0.3020454023564957, 0.43081154280309575`, 0.9406584202630028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 162}], {
             RGBColor[
             0.8765856501368406, 0.44964429041426807`, 0.41798785096875907`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 139}], {
             RGBColor[
             0.2400051701500614, 0.36959102940737165`, 0.9369793114329906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 145}], {
             RGBColor[
             0.21930399653046173`, 0.34783278340295676`, 0.9358004102199964]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 191}], {
             RGBColor[
             0.25554145744836393`, 0.3859206524153965, 0.9378640800107516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 148}], {
             RGBColor[
             0.2190360411775415, 0.34755114533768694`, 0.935785150559052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 163}], {
             RGBColor[
             0.2331505740140204, 0.36238641426189583`, 0.9365889523235094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 165}], {
             RGBColor[
             0.22609095697748494`, 0.3549663091509244, 0.9361869175770461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 176}], {
             RGBColor[
             0.26373796268785954`, 0.3945356991105544, 0.938330858858498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 187}], {
             RGBColor[
             0.2580530598737554, 0.38856050580927426`, 0.9380071120532948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 143}], {
             RGBColor[
             0.8498678524467502, 0.3315757262103135, 0.19331268304312726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 159}], {
             RGBColor[
             0.8510985318743886, 0.34103526757830527`, 0.19449118305288732`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 197}], {
             RGBColor[
             0.8984618333218767, 0.7936232208649558, 0.6170525520201404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 161}], {
             RGBColor[
             0.2794230248160247, 0.4110216938976339, 0.939224099942727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 175}], {
             RGBColor[
             0.2852924893069724, 0.4161135758232565, 0.9395978023974743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 176}], {
             RGBColor[
             0.27219200977132096`, 0.4034214386128163, 0.9388123043332592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 186}], {
             RGBColor[
             0.2661087370017966, 0.3970275332302755, 0.9384658709484304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 187}], {
             RGBColor[
             0.2665071069572168, 0.39744624531153616`, 0.938488557528056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 199}], {
             RGBColor[
             0.26123779500061556`, 0.39190786435147384`, 0.9381884780073761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 142}], {
             RGBColor[
             0.7768323613465915, 0.7056166385716411, 0.6067738726084364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 144}], {
             RGBColor[
             0.8752691557383894, 0.5209048945205916, 0.21739381612783068`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 156}], {
             RGBColor[
             0.9168097113153278, 0.8158057378279282, 0.6204937789995357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 159}], {
             RGBColor[
             0.8526881995414608, 0.34733777015289946`, 0.19577026697210964`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 167}], {
             RGBColor[
             0.914025724578517, 0.8135858623733021, 0.6202282398592844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 181}], {
             RGBColor[
             0.9485527902505714, 0.8398398392439036, 0.5790165148890076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 185}], {
             RGBColor[
             0.8411744991425061, 0.7559037234450623, 0.613171500043548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 192}], {
             RGBColor[
             0.8491378919784113, 0.32004855046860603`, 0.19237048844023447`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 145}], {
             RGBColor[
             0.2284570343408142, 0.357453206477753, 0.9363216621825899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 152}], {
             RGBColor[
             0.26544888260262894`, 0.3963339844195651, 0.9384282932165648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 182}], {
             RGBColor[
             0.2571409182934481, 0.38760178717525484`, 0.9379551669396888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 191}], {
             RGBColor[
             0.2646944952587164, 0.3955410754901928, 0.9383853319733451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 198}], {
             RGBColor[
             0.5277497041986612, 0.6241140740098087, 0.9572340887790165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 153}], {
             RGBColor[
             0.6134295605638427, 0.6970487778093326, 0.9627105685555573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 157}], {
             RGBColor[
             0.5992869263853755, 0.6855671502648439, 0.9615972085868523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 160}], {
             RGBColor[
             0.5038004126414563, 0.6056953348255233, 0.9547299040233275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 167}], {
             RGBColor[
             0.7780824099898748, 0.8273108495391253, 0.9783266471470176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 174}], {
             RGBColor[
             0.5111498276444193, 0.6120610287087513, 0.9551982022484837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 181}], {
             RGBColor[
             0.8126094756619291, 0.8535648264097266, 0.9371149221767408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 185}], {
             RGBColor[
             0.7052311845538637, 0.7696287106108853, 0.971269907331281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.6527715209369094, 0.7286468226851102, 0.9660412183253722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 154}], {
             RGBColor[
             0.8760414746143801, 0.43681328017556376`, 0.40267896763816474`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 159}], {
             RGBColor[
             0.821413781916936, 0.16560128815844824`, 0.1681391677880527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 197}], {
             RGBColor[
             0.8435046260386568, 0.41200177766559354`, 0.4414555753478633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 149}], {
             RGBColor[
             0.648866599779832, 0.4112160653555213, 0.44670623587921776`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 159}], {
             RGBColor[
             0.8452254175415028, 0.3486279538941323, 0.1909412169535338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 170}], {
             RGBColor[
             0.631799051712688, 0.39327699019190376`, 0.44573426426596857`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 181}], {
             RGBColor[
             0.8991205652819477, 0.619537019745982, 0.4376211825067001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 190}], {
             RGBColor[
             0.6309129511153266, 0.3923456422820542, 0.44568380214781717`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 192}], {
             RGBColor[
             0.8434502637599781, 0.33498334405198565`, 0.18924132768759622`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 197}], {
             RGBColor[
             0.8673162616632236, 0.5950284434012776, 0.4642576245133444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 147}], {
             RGBColor[
             0.6383951985626789, 0.7149619751698173, 0.9662861034465073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 156}], {
             RGBColor[
             0.8584691386886809, 0.8901770946260392, 0.9863115068182637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 171}], {
             RGBColor[
             0.8352823460284233, 0.8716885755474699, 0.9840999298352342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 178}], {
             RGBColor[
             0.8692632098101054, 0.8986103712740543, 0.9813214481021706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 179}], {
             RGBColor[
             0.802014133137712, 0.8452588034311341, 0.9809009316091206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 183}], {
             RGBColor[
             0.8386384964590899, 0.584723475070088, 0.463315779566298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 194}], {
             RGBColor[
             0.5723118578420975, 0.6584672801449877, 0.9618699351638069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 196}], {
             RGBColor[
             0.6456339866715997, 0.7208387494603272, 0.9668559673629961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 152}], {
             RGBColor[
             0.3812177118441309, 0.5013730508472783, 0.9458086544862003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 156}], {
             RGBColor[
             0.7007698065694198, 0.7645047047938165, 0.9722866893066117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 178}], {
             RGBColor[
             0.7115638776908443, 0.7729379814418316, 0.9672966305905184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 179}], {
             RGBColor[
             0.6443148010184508, 0.7195864135989113, 0.9668761140974684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 185}], {
             RGBColor[
             0.625134594396598, 0.7046026904109504, 0.9649644103506239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 194}], {
             RGBColor[
             0.41461252572283636`, 0.5327948903127648, 0.9478451176521548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 165}], {
             RGBColor[
             0.2118480097340456, 0.33999606854305653`, 0.9353758028020844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 159}], {
             RGBColor[
             0.6262856435829035, 0.23764894098782902`, 0.4250826867234967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 170}], {
             RGBColor[
             0.2079666859588458, 0.3359165511651807, 0.9351547671549908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 190}], {
             RGBColor[
             0.2066375350628038, 0.33451952930040635`, 0.9350790739777637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 192}], {
             RGBColor[
             0.622735336019854, 0.21035972130353567`, 0.4216829081916216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 195}], {
             RGBColor[
             0.2062475040297809, 0.3341095819553035, 0.9350568622874322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.5612425008846491, 0.6385437309792414, 0.9629398075260546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 151}], {
             RGBColor[
             0.3174016073666887, 0.4469518879084411, 0.9415329334208639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 152}], {
             RGBColor[
             0.2823331640327409, 0.4140804347278859, 0.9393898280659538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 194}], {
             RGBColor[
             0.31572797791144636`, 0.44550227419337246`, 0.9414262912319082]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 171}], {
             RGBColor[
             0.6131733026438233, 0.690971104405486, 0.9657655862298374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 196}], {
             RGBColor[
             0.4235249432869995, 0.5401212783183434, 0.9485216237575993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 194}], {
             RGBColor[
             0.3151343711235495, 0.4448783558224487, 0.9413924862035001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 160}], {
             RGBColor[
             0.4763409264473496, 0.5834024868973917, 0.9525681926827152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 167}], {
             RGBColor[
             0.7506229237957682, 0.8050180016109936, 0.9761649358064053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 174}], {
             RGBColor[
             0.4836903414503127, 0.5897681807806197, 0.9530364909078715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 188}], {
             RGBColor[
             0.6253120347428027, 0.7063539747569785, 0.9638795069847599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 157}], {
             RGBColor[
             0.7392642763541118, 0.795756249521131, 0.9753171149779516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 178}], {
             RGBColor[
             0.9316378178168464, 0.9481531008980535, 0.987322033962275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.864388741144453, 0.8948015330551333, 0.986901517469225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 181}], {
             RGBColor[
             0.9525868256306654, 0.9637539256660137, 0.9508348285678401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 183}], {
             RGBColor[
             0.8802215684635839, 0.6177519614860875, 0.46731617013970106`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 185}], {
             RGBColor[
             0.8452085345226001, 0.8798178098671724, 0.9849898137223804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 192}], {
             RGBColor[
             0.8518272488984739, 0.40265794141667954`, 0.4402493642261227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 174}], {
             RGBColor[
             0.4695477072718456, 0.5782865532361309, 0.9519231309391665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 181}], {
             RGBColor[
             0.7710073552893554, 0.8197903509371063, 0.9338398508674235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 185}], {
             RGBColor[
             0.6636290641812901, 0.7358542351382649, 0.9679948360219639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 164}], {
             RGBColor[
             0.27399405489207074`, 0.4053155022909841, 0.9389149281369991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 166}], {
             RGBColor[
             0.3220947514992546, 0.4482744245110126, 0.9419323901733808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 170}], {
             RGBColor[
             0.6092180955157596, 0.21970986582421148`, 0.4241107151102475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 197}], {
             RGBColor[
             0.844735305466295, 0.4214613190335854, 0.44263407535762334`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 167}], {
             RGBColor[
             0.6409937758733817, 0.7136645586271843, 0.9681842712741754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 174}], {
             RGBColor[
             0.37406119352792633`, 0.4984147377968103, 0.9450558263756417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 188}], {
             RGBColor[
             0.5156828868204164, 0.6150005317731692, 0.9558988424525301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 175}], {
             RGBColor[
             0.31452843153509336`, 0.4468424047708116, 0.941262746056665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 176}], {
             RGBColor[
             0.301427951999442, 0.43415026756037145`, 0.9404772479924501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 187}], {
             RGBColor[
             0.2957430491853379, 0.4281750742590913, 0.9401535011872468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 193}], {
             RGBColor[
             0.31267272742048674`, 0.4452350871371401, 0.9411445022314171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 199}], {
             RGBColor[
             0.2904737372287366, 0.422636693299029, 0.9398534216665669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 180}], {
             RGBColor[
             0.853484717444914, 0.8855675982797966, 0.9434799440471393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 177}], {
             RGBColor[
             0.2633144670135955, 0.39409057830572625`, 0.9383067414063544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 166}], {
             RGBColor[
             0.3428237586125573, 0.4700619252820549, 0.9431128764626655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 184}], {
             RGBColor[
             0.33292802569279517`, 0.46149073880095526`, 0.9424823291114712]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 187}], {
             RGBColor[
             0.2508650284302595, 0.38100542901464385`, 0.9375977642963274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 184}], {
             RGBColor[
             0.3810287222999791, 0.5044496610209838, 0.9454997911478531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 181}], {
             RGBColor[
             0.9498028388938546, 0.9615340502113876, 0.9505692894275887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 188}], {
             RGBColor[
             0.7899648841688349, 0.8366160464867711, 0.9794955855762202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 172}], {
             RGBColor[
             0.9662845352880476, 0.9716239920088556, 0.7873059163017873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 173}], {
             RGBColor[
             0.9668668867879184, 0.9728695829823109, 0.8506912832058626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 184}], {
             RGBColor[
             0.6548626736277727, 0.7248006680529328, 0.9668502718111599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 198}], {
             RGBColor[
             0.8173765882647961, 0.8581441256038294, 0.9795908811512684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 200}], {
             RGBColor[
             0.2545855584826314, 0.3849159419949167, 0.9378096429787789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 190}], {
             RGBColor[
             0.1810362129620878, 0.3076109165549801, 0.93362111655789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 195}], {
             RGBColor[
             0.1806461819290649, 0.30720096920987716`, 0.9335989048675586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 197}], {
             RGBColor[
             0.5356411787839332, 0.6116351182338152, 0.9614818501061808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 173}], {
             RGBColor[
             0.9348057885377076, 0.9473795452457701, 0.8502201026491867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 178}], {
             RGBColor[
             0.9084510251565888, 0.9296645818194842, 0.9851104569792455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 183}], {
             RGBColor[
             0.8647637066900788, 0.6054262821003745, 0.46584178548434796`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 196}], {
             RGBColor[
             0.6848218020180831, 0.7518929600057571, 0.9706449762400708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 173}], {
             RGBColor[
             0.9945590642006376, 0.9907707134251852, 0.6491658996819889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 198}], {
             RGBColor[
             0.8450687656775151, 0.8760452560467036, 0.7780654976273946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 188}], {
             RGBColor[
             0.5230323018233795, 0.6213662256563972, 0.9563671406776864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 176}], {
             RGBColor[
             0.30729741649038966`, 0.43924214948599405`, 0.9408509504471974]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 187}], {
             RGBColor[
             0.3016125136762855, 0.4332669561847139, 0.940527203641994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 199}], {
             RGBColor[
             0.2963432017196842, 0.4277285752246516, 0.9402271241213142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 187}], {
             RGBColor[
             0.2885120341406341, 0.42057481897427373`, 0.9397417055777791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 199}], {
             RGBColor[
             0.28324272218403285`, 0.4150364380142114, 0.9394416260570992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 179}], {
             RGBColor[
             0.8751828122658775, 0.9032348097031484, 0.9819114587531318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 183}], {
             RGBColor[
             0.8874176158778669, 0.6233741459180975, 0.46398946432897215`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 183}], {
             RGBColor[
             0.8425848980962714, 0.5878064340228173, 0.4637091200002722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 185}], {
             RGBColor[
             0.7887535289716312, 0.8348995186722672, 0.9795792385132371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 194}], {
             RGBColor[
             0.5782314602978695, 0.6630917185740817, 0.9624599458147682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 185}], {
             RGBColor[
             0.8769516134578437, 0.9038519112831478, 0.9435125496118522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 188}], {
             RGBColor[
             0.8244919498408892, 0.8628700233573725, 0.9382838606059434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 192}], {
             RGBColor[
             0.8729893015219696, 0.41868067569399636`, 0.41259785481910394`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 191}], {
             RGBColor[
             0.2726772055917506, 0.4039314101832797, 0.9388399355174497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 192}], {
             RGBColor[
             0.84571331956511, 0.349221020069408, 0.19128480591357822`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 193}], {
             RGBColor[
             0.29935843960625863`, 0.43124092646978174`, 0.9403862732371204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 199}], {
             RGBColor[
             0.2771594494145085, 0.4086425326316706, 0.9390951926722704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 199}], {
             RGBColor[
             0.27755781936992874`, 0.40906124471293126`, 0.9391178792518959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 192}], {
             RGBColor[
             0.6047816873553487, 0.19148929823006858`, 0.42066047446022103`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 195}], {
             RGBColor[
             0.1793170310330229, 0.30580394734510286`, 0.9335232116903315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 199}], {
             RGBColor[
             0.2944874976050776, 0.4261212575909801, 0.9401088802960662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 197}], {
             RGBColor[
             0.5339219968548683, 0.6098281490239381, 0.9613839452386224]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.04749427504982855], {
             RGBColor[
             0.9583125875736904, 0.8710407105954553, 0.2925527040414048]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.04749427504982855], {
             RGBColor[
             0.377120805174838, 0.5010648196248124, 0.9452507821242745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.04749427504982855], {
             RGBColor[
             0.26366336471100654`, 0.39445729190709694`, 0.938326610614074]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.04749427504982855], {
             RGBColor[
             0.8048857220793089, 0.8475021105371937, 0.9811871447582946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.04749427504982855], {
             RGBColor[
             0.2822070658609612, 0.41394789755425965`, 0.9393826469616164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.04749427504982855], {
             RGBColor[
             0.3400518121902417, 0.46895752104331584`, 0.9428887786701194]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.04749427504982855], {
             RGBColor[
             0.350460125859892, 0.477972679206911, 0.9435519872134391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.04749427504982855], {
             RGBColor[
             0.44819737568646545`, 0.5626277725896778, 0.9497797183467319]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.04749427504982855], {
             RGBColor[
             0.2605668322464433, 0.39120263995534316`, 0.9381502676711264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.04749427504982855], {
             RGBColor[
             0.28931600419628395`, 0.4214198424774074, 0.9397874904830813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.04749427504982855], {
             RGBColor[
             0.24586228151751777`, 0.37574722481687783`, 0.9373128652605475]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.04749427504982855], {
             RGBColor[
             0.5839626349742006, 0.6731262001457912, 0.9603908242322355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.04749427504982855], {
             RGBColor[
             0.3779993100162068, 0.5018257363634689, 0.9453067596759351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.04749427504982855], {
             RGBColor[
             0.4167727741971154, 0.535409362225998, 0.9477773705275145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.04749427504982855], {
             RGBColor[
             0.32511075702074876`, 0.45601633001476893`, 0.9419367478465757]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.04749427504982855], {
             RGBColor[
             0.3229612837478847, 0.4541545643014821, 0.9417997853103334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.04749427504982855], {
             RGBColor[
             0.2388383031545141, 0.3683645782114108, 0.9369128600838192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.04749427504982855], {
             RGBColor[
             0.3183704566888478, 0.45017822064462143`, 0.9415072618696405]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.04749427504982855], {
             RGBColor[
             0.26440158051900675`, 0.3952332035268908, 0.9383686509122472]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.04749427504982855], {
             RGBColor[
             0.22540124214842158`, 0.354241375135133, 0.9361476393378726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.04749427504982855], {
             RGBColor[
             0.31620160663402885`, 0.4482996717367106, 0.9413690646619862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.04749427504982855], {
             RGBColor[
             0.8444218577904707, 0.34245144152557083`, 0.19017172722845446`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.04749427504982855], {
             RGBColor[
             0.9935791491691084, 0.9886747742573517, 0.5425081958346172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.04749427504982855], {
             RGBColor[
             0.17892700283938517`, 0.30539400298437386`, 0.9335010001616988]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.04749427504982855], {
             RGBColor[
             0.9789215033713261, 0.9405594227844256, 0.37261445024803247`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.04749427504982855], {
             RGBColor[
             0.39640287984113043`, 0.5177659835555031, 0.9464794188715415]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.04749427504982855], {
             RGBColor[
             0.2767490295536739, 0.4082111553358114, 0.9390718198683575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.04749427504982855], {
             RGBColor[
             0.29477679578460203`, 0.4271594806709139, 0.9400984744855188]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.04749427504982855], {
             RGBColor[
             0.9936430185668372, 0.9916392390574856, 0.75501516389549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.04749427504982855], {
             RGBColor[
             0.8937471851268821, 0.9181137615718546, 0.9897275984465748]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.04749427504982855], {
             RGBColor[
             0.8505083657915934, 0.8836363007203797, 0.9856034412586252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.04749427504982855], {
             RGBColor[
             0.23515166545220784`, 0.36448968823995603`, 0.9367029115205646]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.04749427504982855], {
             RGBColor[
             0.3230400522816408, 0.4542227896464, 0.941804804371652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.04749427504982855], {
             RGBColor[
             0.2517479206748871, 0.38193340474234894`, 0.9376480437035368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.04749427504982855], {
             RGBColor[
             0.8383733051460716, 0.8739601327590868, 0.9844459883411588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.04749427504982855], {
             RGBColor[
             0.24777983952010385`, 0.3777626998577953, 0.9374220673520219]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.04749427504982855], {
             RGBColor[
             0.19099374879671333`, 0.31807691806140814`, 0.9341881834928177]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.04749427504982855], {
             RGBColor[
             0.9648082727380654, 0.8929521819142981, 0.31778721429778617`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.04749427504982855], {
             RGBColor[
             0.20098973591686892`, 0.3285833343068806, 0.9347574401715728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.04749427504982855], {
             RGBColor[
             0.49158142165721236`, 0.5981269694488269, 0.9531182367163876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.04749427504982855], {
             RGBColor[
             0.5497140953330726, 0.6453216927859953, 0.9576946537351515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.04749427504982855], {
             RGBColor[
             0.5214414667269106, 0.6223686992161088, 0.9554689288452234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.04749427504982855], {
             RGBColor[
             0.8553653759675705, 0.4265681177150025, 0.20065125259378117`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.04749427504982855], {
             RGBColor[
             0.2834240796528994, 0.4152270562127178, 0.9394519540966568]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.04749427504982855], {
             RGBColor[
             0.8843599871114161, 0.5677875345316877, 0.22521947746071738`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.04749427504982855], {
             RGBColor[
             0.5977424503378598, 0.6843132750316175, 0.9614756217747897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.04749427504982855], {
             RGBColor[
             0.4515217278586501, 0.5655071593544256, 0.9499915431275343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.04749427504982855], {
             RGBColor[
             0.3171026989044469, 0.4490801525711323, 0.9414264814646527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.04749427504982855], {
             RGBColor[
             0.8347376037115143, 0.26801402100751526`, 0.1808980745856452]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.04749427504982855], {
             RGBColor[
             0.2422322948146241, 0.37193187863768656`, 0.9371061428879017]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.04749427504982855], {
             RGBColor[
             0.28213996431762406`, 0.4138773695777287, 0.9393788256279912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.04749427504982855], {
             RGBColor[
             0.21246269677098534`, 0.3406421435922893, 0.9354108083194902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.04749427504982855], {
             RGBColor[
             0.21141226994966317`, 0.3395380784021726, 0.9353509880659832]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.04749427504982855], {
             RGBColor[
             0.27280646441116213`, 0.40406726939796367`, 0.938847296615994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.04749427504982855], {
             RGBColor[
             0.35238205413251156`, 0.47963735687773035`, 0.943674450783476]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.04749427504982855], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.04749427504982855], {
             RGBColor[
             0.3605779115447064, 0.4867361966324024, 0.9441966835704689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.04749427504982855], {
             RGBColor[
             0.264153442110629, 0.394972394326802, 0.9383545197969779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.04749427504982855], {
             RGBColor[
             0.44880489881560515`, 0.5631539785891382, 0.949818429183309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.04749427504982855], {
             RGBColor[
             0.253957266336059, 0.38425556711284614`, 0.9377738626705066]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.04749427504982855], {
             RGBColor[
             0.2737970101358498, 0.4051083957588368, 0.9389037067296339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.04749427504982855], {
             RGBColor[
             0.3562346737166085, 0.4829743023231845, 0.943919936296637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.04749427504982855], {
             RGBColor[
             0.35285247495850214`, 0.48004481175316516`, 0.9437044255825313]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.04749427504982855], {
             RGBColor[
             0.6226026285830288, 0.704495887669313, 0.963432706072083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.04749427504982855], {
             RGBColor[
             0.9220936452530043, 0.9407164594322621, 0.992431309118588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.04749427504982855], {
             RGBColor[
             0.6916199917227627, 0.7590180611312259, 0.9698978752847841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.04749427504982855], {
             RGBColor[
             0.8182056947053702, 0.14094252405757224`, 0.16506709985124088`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.04749427504982855], {
             RGBColor[
             0.8556248139763563, 0.8877160176206234, 0.9860914526539951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.04749427504982855], {
             RGBColor[
             0.4015855979045752, 0.522254993451075, 0.9468096570836465]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.04749427504982855], {
             RGBColor[
             0.21367513065222027`, 0.34191648847421524`, 0.9354798546353913]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.04749427504982855], {
             RGBColor[
             0.2902833275082297, 0.42243656061010276`, 0.93984257811467]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.04749427504982855], {
             RGBColor[
             0.24987650973082426`, 0.37996643318583184`, 0.9375414696187768]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.04749427504982855], {
             RGBColor[
             0.2931347355771166, 0.42543357128021636`, 0.9400049615859128]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.04749427504982855], {
             RGBColor[
             0.30278259996188467`, 0.4355740884585403, 0.9405543931898891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.04749427504982855], {
             RGBColor[
             0.28416143346402023`, 0.4160020618191376, 0.9394939453053829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.04749427504982855], {
             RGBColor[
             0.27635030732849636`, 0.40779207299670056`, 0.9390491132274904]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.04749427504982855], {
             RGBColor[
             0.3003940670337382, 0.43306358890932384`, 0.940418369773149]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.04749427504982855], {
             RGBColor[
             0.9279645300339343, 0.9453977435956535, 0.9929912793499938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.04749427504982855], {
             RGBColor[
             0.20396815225836698`, 0.3317138387242981, 0.934927056576049]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.04749427504982855], {
             RGBColor[
             0.6198970672218798, 0.7022993910721819, 0.9632197143709355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.04749427504982855], {
             RGBColor[
             0.5763338163997934, 0.6669327815527272, 0.9597902556887751]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.04749427504982855], {
             RGBColor[
             0.31859842780058983`, 0.45037567776345117`, 0.9415217879872938]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.04749427504982855], {
             RGBColor[
             0.25584834544704116`, 0.3862432111598293, 0.9378815568282761]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.04749427504982855], {
             RGBColor[
             0.2627765683456537, 0.3935252127009741, 0.9382761088729649]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.04749427504982855], {
             RGBColor[
             0.360155081261214, 0.48636996229290924`, 0.9441697411986989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.04749427504982855], {
             RGBColor[
             0.3919595940317969, 0.5139174327134967, 0.9461962966288141]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.04749427504982855], {
             RGBColor[
             0.9879745726157381, 0.9892951909842899, 0.8489559827730842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.04749427504982855], {
             RGBColor[
             0.7121946053554326, 0.7750911056739228, 0.9719485604909927]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.04749427504982855], {
             RGBColor[
             0.8539922331287186, 0.4160135401405583, 0.19933632946055357`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.04749427504982855], {
             RGBColor[
             0.3879488339253545, 0.5104435138959607, 0.9459407345414075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.04749427504982855], {
             RGBColor[
             0.8378176201564483, 0.8735170446320284, 0.9843929866107827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.04749427504982855], {
             RGBColor[
             0.22871531315648586`, 0.35772467388884666`, 0.9363363707790532]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.04749427504982855], {
             RGBColor[
             0.22414759348065547`, 0.35292371089939434`, 0.9360762459008504]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.04749427504982855], {
             RGBColor[
             0.4181274501813097, 0.5365827144755124, 0.9478636892833344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.04749427504982855], {
             RGBColor[
             0.9796258119030633, 0.9429352208414826, 0.3753505558963255]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.04749427504982855], {
             RGBColor[
             0.3061966914574528, 0.4391625150862857, 0.940748820649866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.04749427504982855], {
             RGBColor[
             0.28096145327109734`, 0.41263867974591306`, 0.9393117111673424]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.04749427504982855], {
             RGBColor[
             0.9734883859205871, 0.9797482621451334, 0.9297614266867937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.04749427504982855], {
             RGBColor[
             0.5640955015617808, 0.656997166237428, 0.9588268107143023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.04749427504982855], {
             RGBColor[
             0.21381427791123173`, 0.3420627410658821, 0.9354877788659421]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.04749427504982855], {
             RGBColor[
             0.2518443381406806, 0.38203474561211825`, 0.9376535345355769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.04749427504982855], {
             RGBColor[
             0.37383492502239923`, 0.4982187553899085, 0.9450414087465508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.04749427504982855], {
             RGBColor[
             0.8642907579141675, 0.4766578520345487, 0.20847322067670976`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.04749427504982855], {
             RGBColor[
             0.21893481250696653`, 0.34744474758664423`, 0.9357793857360172]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.04749427504982855], {
             RGBColor[
             0.34321032416564207`, 0.47169326536497985`, 0.9430900362602295]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.04749427504982855], {
             RGBColor[
             0.27505191676798696`, 0.40642738219488894`, 0.9389751718058661]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.04749427504982855], {
             RGBColor[
             0.6672310374616252, 0.7399652246995075, 0.9674670122517698]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.04749427504982855], {
             RGBColor[
             0.7812325868423204, 0.8290241015195725, 0.9788296212889877]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.04749427504982855], {
             RGBColor[
             0.3375430035907792, 0.46678451713084806`, 0.942728919604614]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.04749427504982855], {
             RGBColor[
             0.6050270257368769, 0.6902272215069217, 0.9620490902344793]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.04749427504982855], {
             RGBColor[
             0.4604958122832016, 0.5728902713682614, 0.9506710636761264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.04749427504982855], {
             RGBColor[
             0.30144929209616883`, 0.4341726973550716, 0.9404784632793888]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.04749427504982855], {
             RGBColor[
             0.9003020964297527, 0.6401769295720257, 0.2385219642527955]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.04749427504982855], {
             RGBColor[
             0.21718744139687057`, 0.3456081497602061, 0.935679875536301]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.04749427504982855], {
             RGBColor[
             0.2655539192117794, 0.3964443845554878, 0.9384342748960682]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.04749427504982855], {
             RGBColor[
             0.3895827819898638, 0.5118587575848209, 0.9460448482672345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.04749427504982855], {
             RGBColor[
             0.7789983515005383, 0.8272786998897548, 0.9786069335902352]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.04749427504982855], {
             RGBColor[
             0.9133075269424444, 0.9337106471842498, 0.9915932813106664]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.04749427504982855], {
             RGBColor[
             0.5648783713319804, 0.6576327351847573, 0.9588884410903589]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.04749427504982855], {
             RGBColor[
             0.9567688473548046, 0.8658333123497126, 0.2865555648019119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.04749427504982855], {
             RGBColor[
             0.5426755050288741, 0.6396074480921672, 0.9571405501231992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.04749427504982855], {
             RGBColor[
             0.9929383277496677, 0.9873041220381521, 0.47275873901987264`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.04749427504982855], {
             RGBColor[
             0.250431442054717, 0.3805497022429847, 0.9375730721936737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.04749427504982855], {
             RGBColor[
             0.2910544796798416, 0.42324709043633846`, 0.9398864940900259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.04749427504982855], {
             RGBColor[
             0.17895982839241617`, 0.30542850472186966`, 0.9335028695283829]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.04749427504982855], {
             RGBColor[
             0.30722498883092086`, 0.4402433208236197, 0.9408073806640553]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.04749427504982855], {
             RGBColor[
             0.32158764066209233`, 0.4529647837018777, 0.9417122579875715]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.04749427504982855], {
             RGBColor[
             0.8895815146715775, 0.5914972716636359, 0.22957644804826868`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.04749427504982855], {
             RGBColor[
             0.9902596908634175, 0.9788057915282733, 0.4166611676177604]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.04749427504982855], {
             RGBColor[
             0.23722409174651585`, 0.3666679396746901, 0.9368209331321454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.04749427504982855], {
             RGBColor[
             0.8992586624240541, 0.6354389394523516, 0.23765129734153262`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.04749427504982855], {
             RGBColor[
             0.2522143608002516, 0.3824236628881191, 0.93767460677864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.04749427504982855], {
             RGBColor[
             0.8234278438149039, 0.18108225047377968`, 0.1700678357361042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.04749427504982855], {
             RGBColor[
             0.23085213233970892`, 0.3599706063325754, 0.9364580594703971]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.04749427504982855], {
             RGBColor[
             0.23327898842098083`, 0.3625213859455549, 0.9365962653340136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.04749427504982855], {
             RGBColor[
             0.9080066729340168, 0.6729841436820356, 0.24483821356303642`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.04749427504982855], {
             RGBColor[
             0.2501870825879037, 0.38029286495007875`, 0.9375591562835361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.04749427504982855], {
             RGBColor[
             0.9127756759352338, 0.6918916514058181, 0.2486754653207034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.04749427504982855], {
             RGBColor[
             0.24915820796041388`, 0.3792114524821679, 0.9375005633955842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.04749427504982855], {
             RGBColor[
             0.30550365683416836`, 0.4384340917562807, 0.9407093533533227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.04749427504982855], {
             RGBColor[
             0.3593385897430587, 0.4856627583779401, 0.9441177150811572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.04749427504982855], {
             RGBColor[
             0.6408890467579492, 0.7193416257374643, 0.9648722798961695]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.04749427504982855], {
             RGBColor[
             0.8207984422031169, 0.16087151747445233`, 0.16754991778317269`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.04749427504982855], {
             RGBColor[
             0.8565158956399671, 0.43541151607797846`, 0.2017529915313943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.04749427504982855], {
             RGBColor[
             0.20775586072121455`, 0.33569496047333813`, 0.9351427609695957]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.04749427504982855], {
             RGBColor[
             0.79609453068194, 0.84063436500204, 0.9803109209581594]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.04749427504982855], {
             RGBColor[
             0.4806958664434177, 0.5892895853375945, 0.9522612859348552]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.04749427504982855], {
             RGBColor[
             0.20479309393410217`, 0.332580904729819, 0.9349740357840903]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.04749427504982855], {
             RGBColor[
             0.2335680080595618, 0.362825163910607, 0.9366127245748646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.04749427504982855], {
             RGBColor[
             0.2829267708206377, 0.41470435309880965`, 0.9394236330943619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.04749427504982855], {
             RGBColor[
             0.3518764439127397, 0.4791994227180725, 0.9436422337473658]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.04749427504982855], {
             RGBColor[
             0.281739557244844, 0.41345651635696223`, 0.9393560230375456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.04749427504982855], {
             RGBColor[
             0.585970074369736, 0.674755929881201, 0.960548857214945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.04749427504982855], {
             RGBColor[
             0.9865275394369064, 0.9886968055777866, 0.8729370673481489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.04749427504982855], {
             RGBColor[
             0.24962306644129345`, 0.3797000482193023, 0.9375270363983738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.04749427504982855], {
             RGBColor[
             0.9208437466954219, 0.9397198242500384, 0.9923120926783682]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.04749427504982855], {
             RGBColor[
             0.5576848060128018, 0.6517926747922235, 0.9583221372775351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.04749427504982855], {
             RGBColor[
             0.25326504777876796`, 0.3835280015199418, 0.9377344418477144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.04749427504982855], {
             RGBColor[
             0.8226444613445744, 0.17506082952644003`, 0.16931766779781277`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.04749427504982855], {
             RGBColor[
             0.36671177852496323`, 0.4920490439135823, 0.9445875281504853]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.04749427504982855], {
             RGBColor[
             0.30865896704414575`, 0.441750522845189, 0.9408890436019178]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.04749427504982855], {
             RGBColor[
             0.9829012627807141, 0.9867683702952449, 0.9138278814340688]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.04749427504982855], {
             RGBColor[
             0.23302215960706, 0.36225144257823677`, 0.936581639313005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.04749427504982855], {
             RGBColor[
             0.29472306200537346`, 0.42710300306202637`, 0.9400954144262837]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.04749427504982855], {
             RGBColor[
             0.21890292553398902`, 0.347411232356294, 0.9357775698200786]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.04749427504982855], {
             RGBColor[
             0.39092445521974123`, 0.5130208475020834, 0.9461303384990473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.04749427504982855], {
             RGBColor[
             0.9152757732218003, 0.9352800733407862, 0.9917810143978655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.04749427504982855], {
             RGBColor[
             0.9385923578753286, 0.9537228615659814, 0.988831299825661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.04749427504982855], {
             RGBColor[
             0.2725827939998642, 0.40383217761416634`, 0.9388345589169613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.04749427504982855], {
             RGBColor[
             0.1823653638581298, 0.3090079384197544, 0.933696809735117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.04749427504982855], {
             RGBColor[
             0.8744701613749067, 0.9027427860928997, 0.9878889387123091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.04749427504982855], {
             RGBColor[
             0.9939767127007667, 0.98952512245173, 0.5857805327779135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.04749427504982855], {
             RGBColor[
             0.9951414157005084, 0.9920163043986404, 0.7125512665860644]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.04749427504982855], {
             RGBColor[
             0.3814106085308894, 0.5047804316800383, 0.9455241246007979]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.04749427504982855], {
             RGBColor[
             0.320397896026041, 0.45193428669643415`, 0.9416364485114123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.04749427504982855], {
             RGBColor[
             0.29419693695473825`, 0.4265500122755539, 0.9400654523829823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.04749427504982855], {
             RGBColor[
             0.29360677442013106`, 0.4259297140332158, 0.9400318434997037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.04749427504982855], {
             RGBColor[
             0.9424318889382709, 0.9565863775460686, 0.9823319752461818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.04749427504982855], {
             RGBColor[
             0.807933735593484, 0.8498832418602281, 0.9814909422600818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.04749427504982855], {
             RGBColor[
             0.7240681721091139, 0.7843668262643483, 0.9731320066602097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.04749427504982855], {
             RGBColor[
             0.984329904565909, 0.9877880270819891, 0.9093575644573119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.04749427504982855], {
             RGBColor[
             0.2651236286264823, 0.39599212186834176`, 0.9384097704837935]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.04749427504982855], {
             RGBColor[
             0.859910479347665, 0.45676803010411193`, 0.20481820887036734`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.04749427504982855], {
             RGBColor[
             0.3711329893802169, 0.49587847453988415`, 0.9448692437966588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.04749427504982855], {
             RGBColor[
             0.7695733223497783, 0.8199157954843064, 0.9776675347663926]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.04749427504982855], {
             RGBColor[
             0.28203039141568953`, 0.41376220151047227`, 0.9393725856133247]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.04749427504982855], {
             RGBColor[
             0.28282713132653, 0.41459962567299363`, 0.939417958772576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.04749427504982855], {
             RGBColor[
             0.6646539951158695, 0.737952019632756, 0.9672101567545748]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.04749427504982855], {
             RGBColor[
             0.2313913752108486, 0.36053738478011593`, 0.9364887685541701]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.04749427504982855], {
             RGBColor[
             0.1797070620660458, 0.3062138946902057, 0.9335454233806629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.04749427504982855], {
             RGBColor[
             0.28023078255701894`, 0.41187069849821767`, 0.939270100551106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.04749427504982855], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.04749427504982855], {
             RGBColor[
             0.31668648779682773`, 0.44871965142909115`, 0.9413999608609163]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.04749427504982855], {
             RGBColor[
             0.348529185002255, 0.47630019528793527`, 0.9434289493694545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.04749427504982855], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.04749427504982855], {
             RGBColor[
             0.49517344266125934`, 0.6010431339186144, 0.9534010137678327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.04749427504982855], {
             RGBColor[
             0.8889169937097365, 0.9142622980478761, 0.9892668904772446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.04749427504982855], {
             RGBColor[
             0.6961608186542636, 0.7625653896416773, 0.9703504624768758]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.04749427504982855], {
             RGBColor[
             0.27228850741332744`, 0.40352286375286894`, 0.938817799731216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.04749427504982855], {
             RGBColor[
             0.23658832296539867`, 0.36599970637566703`, 0.9367847270405965]},
             StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{{3.834946926643799*^9, 3.8349469478612347`*^9}, 
   3.834947050298876*^9, {3.8349471234738255`*^9, 3.8349471300172663`*^9}, {
   3.8349471617829676`*^9, 3.834947218900016*^9}, {3.8349472753220577`*^9, 
   3.834947307624898*^9}, 3.83494993428115*^9, 3.8349573375769677`*^9, {
   3.8349587473655295`*^9, 3.83495875945916*^9}, 3.835018920680505*^9, 
   3.835019004300144*^9, 3.8350204747493663`*^9, 3.8350205388580465`*^9, {
   3.8350445644807453`*^9, 3.8350445774530525`*^9}, 3.8350450259183207`*^9, 
   3.8350516029103346`*^9},
 Background->RGBColor[1, 1, 0.85],
 CellLabel->
  "Out[393]=",ExpressionUUID->"312ed183-4b63-4269-a99f-8bdf86060afe"]
}, Open  ]],

Cell["Estimated with cubic Mean Deviation v Calculated: (r=6)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 
  3.834950339812094*^9}},ExpressionUUID->"1c89ef30-1e35-49eb-ab8b-\
535d2f8c92a4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraphb", "[", 
     RowBox[{"graphinf2", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsif2", ",", "#"}], "}"}], "]"}], ",", "500", ",", "2"}],
      "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"CMDi6f200", ",", "krif2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.834950273560528*^9, 3.834950273964845*^9}, {
   3.834957360267254*^9, 3.8349573712318316`*^9}, {3.8349587856645794`*^9, 
   3.83495878977224*^9}, {3.8350188291975336`*^9, 3.8350188308736053`*^9}, {
   3.8350443206807604`*^9, 3.835044327012074*^9}, {3.8350446304641314`*^9, 
   3.835044631224497*^9}, {3.8350448339393716`*^9, 3.8350448366448307`*^9}, 
   3.8350519477393885`*^9},
 CellLabel->
  "In[409]:=",ExpressionUUID->"d210dcda-70d8-466c-b24a-2d0911b2d61c"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
          103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
          129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 
          142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 
          155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 
          168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 
          181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 
          194, 195, 196, 197, 198, 199, 200}, {Null, CompressedData["
1:eJwVxfk/GgwDAPA5ylXk6qBcTS9j5XjImZDN1UpNhz0LEUrEK0VRaK6QloU8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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[31, 80] -> 
             RGBColor[
              0.6919463768369323, 0.7580052130683499, 0.970828094079077], 
             UndirectedEdge[36, 132] -> 
             RGBColor[
              0.30365033236976424`, 0.43641372706937487`, 0.9406064603014519],
              UndirectedEdge[16, 101] -> 
             RGBColor[
              0.5291770675794363, 0.6179940922907781, 0.959091036026173], 
             UndirectedEdge[86, 108] -> 
             RGBColor[
              0.2928262211263112, 0.42162682679905705`, 0.940114902658546], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.4166059425404712, 0.5352648610302156, 0.9477667401618766], 
             UndirectedEdge[29, 136] -> 
             RGBColor[
              0.4985734891626771, 0.587345024690986, 0.9571080071497744], 
             UndirectedEdge[55, 157] -> 
             RGBColor[
              0.6416373722842785, 0.7144103198336798, 0.9681385910736492], 
             UndirectedEdge[7, 188] -> 
             RGBColor[
              0.6262415566087332, 0.7058264462606696, 0.9648292995621698], 
             UndirectedEdge[19, 141] -> 
             RGBColor[
              0.5723480462168107, 0.6609398028125579, 0.9608390187768603], 
             UndirectedEdge[62, 185] -> 
             RGBColor[
              0.2723793241512982, 0.4025447524083894, 0.9388622801018254], 
             UndirectedEdge[79, 144] -> 
             RGBColor[
              0.29745652032581765`, 0.4299760410680807, 0.9402510808338438], 
             UndirectedEdge[47, 54] -> 
             RGBColor[
              0.41985783765081663`, 0.537468873517314, 0.9481432155617882], 
             UndirectedEdge[32, 101] -> 
             RGBColor[
              0.5984404174232583, 0.6814718358464396, 0.9633768211148634], 
             UndirectedEdge[104, 163] -> 
             RGBColor[
              0.43081132608518746`, 0.545126389684297, 0.9493467537780791], 
             UndirectedEdge[119, 125] -> 
             RGBColor[
              0.3750285662466696, 0.49925262742421916`, 0.9451174665098658], 
             UndirectedEdge[9, 140] -> 
             RGBColor[
              0.5956847812826688, 0.6820133871248488, 0.9617439447108378], 
             UndirectedEdge[3, 63] -> 
             RGBColor[
              0.37854869400699975`, 0.5023015851634516, 0.9453417659380273], 
             UndirectedEdge[50, 104] -> 
             RGBColor[
              0.6400733079972727, 0.7105945730540966, 0.9455298693047094], 
             UndirectedEdge[47, 61] -> 
             RGBColor[
              0.3807665106103465, 0.5042225464345669, 0.9454830832508543], 
             UndirectedEdge[149, 195] -> 
             RGBColor[
              0.4650776677772319, 0.5733415539426223, 0.9519348532639255], 
             UndirectedEdge[99, 178] -> 
             RGBColor[
              0.4983822625394131, 0.5997344604007662, 0.9549154538182942], 
             UndirectedEdge[160, 174] -> 
             RGBColor[
              0.4267621683932522, 0.5400544152325236, 0.9492387608259509], 
             UndirectedEdge[6, 124] -> 
             RGBColor[
              0.36065780124348923`, 0.48331389299058003`, 0.9443296149930258],
              UndirectedEdge[24, 197] -> 
             RGBColor[
              0.5748197743592356, 0.6657036140173856, 0.9596710647532236], 
             UndirectedEdge[80, 120] -> 
             RGBColor[
              0.6086053104293213, 0.6885742701123038, 0.9647564879663979], 
             UndirectedEdge[83, 187] -> 
             RGBColor[
              0.6870448393082296, 0.7471261635782485, 0.8113677147186754], 
             UndirectedEdge[47, 167] -> 
             RGBColor[
              0.44854703447928634`, 0.5607600559362543, 0.9504017342281159], 
             UndirectedEdge[132, 150] -> 
             RGBColor[
              0.3018212175064905, 0.43456361454275266`, 0.9404996438812923], 
             UndirectedEdge[17, 189] -> 
             RGBColor[
              0.7249593220992299, 0.7840684037332024, 0.9742766550693602], 
             UndirectedEdge[69, 180] -> 
             RGBColor[
              0.8492498984913881, 0.8787852319949783, 0.7363237358756791], 
             UndirectedEdge[43, 95] -> 
             RGBColor[
              0.3754925498657421, 0.499654506714565, 0.9451470311357886], 
             UndirectedEdge[82, 86] -> 
             RGBColor[
              0.2626694847342114, 0.38993018480343833`, 0.9383975211339095], 
             UndirectedEdge[7, 61] -> 
             RGBColor[
              0.4509139996552891, 0.5636010974741034, 0.9503340284366621], 
             UndirectedEdge[30, 65] -> 
             RGBColor[
              0.3236472216293153, 0.4484776746972461, 0.9420731052265208], 
             UndirectedEdge[62, 174] -> 
             RGBColor[
              0.438938246681396, 0.5517786800271146, 0.9499714789633003], 
             UndirectedEdge[18, 47] -> 
             RGBColor[
              0.3628875615489876, 0.4887366993797262, 0.9443438524263985], 
             UndirectedEdge[56, 149] -> 
             RGBColor[
              0.32815540346273664`, 0.4586534497344392, 0.942130750025584], 
             UndirectedEdge[82, 163] -> 
             RGBColor[
              0.361099474026641, 0.4727428337044167, 0.9453442521514617], 
             UndirectedEdge[10, 48] -> 
             RGBColor[
              0.33791167662682375`, 0.46651234172763906`, 0.9427740688903476],
              UndirectedEdge[58, 92] -> 
             RGBColor[
              0.6237447390308792, 0.7011452000915496, 0.965970709157043], 
             UndirectedEdge[70, 72] -> 
             RGBColor[
              0.36663293091413246`, 0.4919807500760769, 0.9445825040504454], 
             UndirectedEdge[35, 181] -> 
             RGBColor[
              0.36830818496460244`, 0.49343177093387713`, 0.9446892497571724],
              UndirectedEdge[126, 174] -> 
             RGBColor[
              0.7237797293514916, 0.7834080919882169, 0.9738415663200174], 
             UndirectedEdge[108, 154] -> 
             RGBColor[
              0.45525701847661265`, 0.5559552806394537, 0.9524028482918383], 
             UndirectedEdge[63, 77] -> 
             RGBColor[
              0.3261736310947641, 0.45319769091147244`, 0.9421413854000251], 
             UndirectedEdge[32, 100] -> 
             RGBColor[
              0.7013994686041497, 0.7585443324751371, 0.7255240818158382], 
             UndirectedEdge[19, 50] -> 
             RGBColor[
              0.8502059151312478, 0.8833798351852519, 0.9620678627043799], 
             UndirectedEdge[80, 81] -> 
             RGBColor[
              0.5901296220451963, 0.6725715574490735, 0.9635792334399711], 
             UndirectedEdge[34, 163] -> 
             RGBColor[
              0.7057271890448944, 0.7689103936042068, 0.972238356793526], 
             UndirectedEdge[146, 194] -> 
             RGBColor[
              0.32870551393703923`, 0.45616726414411035`, 0.9422742802071634],
              UndirectedEdge[13, 83] -> 
             RGBColor[
              0.8515390235427016, 0.8816709632268185, 0.8244519983349171], 
             UndirectedEdge[30, 41] -> 
             RGBColor[
              0.29768027590054535`, 0.4259864114436265, 0.9404185144063522], 
             UndirectedEdge[35, 111] -> 
             RGBColor[
              0.654730822856953, 0.24270641653734595`, 0.42355196573904297`], 
             UndirectedEdge[29, 144] -> 
             RGBColor[
              0.5337440270824012, 0.6243114899855156, 0.9591109172541545], 
             UndirectedEdge[6, 12] -> 
             RGBColor[
              0.43125704031528733`, 0.5407105807890878, 0.9498650527145889], 
             UndirectedEdge[67, 143] -> 
             RGBColor[
              0.382659946715757, 0.5058625456222077, 0.9456037313251913], 
             UndirectedEdge[135, 163] -> 
             RGBColor[
              0.6221567695623353, 0.7032349767790066, 0.9640122182804634], 
             UndirectedEdge[50, 60] -> 
             RGBColor[
              0.7343283678575127, 0.7907797553082503, 0.951937411291252], 
             UndirectedEdge[25, 143] -> 
             RGBColor[
              0.3970399571154558, 0.5183177878700889, 0.9465200128721162], 
             UndirectedEdge[12, 13] -> 
             RGBColor[
              0.6498958575254605, 0.7256442402163639, 0.9662715435442292], 
             UndirectedEdge[89, 144] -> 
             RGBColor[0.3079390997368, 0.4395419417119736, 0.940901211407045],
              UndirectedEdge[22, 24] -> 
             RGBColor[
              0.7577811706929066, 0.522215887631246, 0.45619432915086877`], 
             UndirectedEdge[107, 156] -> 
             RGBColor[0.4001274323215285, 0.520992003712573, 0.9467167440621],
              UndirectedEdge[23, 154] -> 
             RGBColor[
              0.8296055227762249, 0.8662015650470984, 0.9087203070079817], 
             UndirectedEdge[101, 135] -> 
             RGBColor[
              0.7441731791430564, 0.800073010562977, 0.9751358858693802], 
             UndirectedEdge[7, 42] -> 
             RGBColor[
              0.3808366391696752, 0.4981695231727783, 0.9460420991031777], 
             UndirectedEdge[122, 192] -> 
             RGBColor[
              0.378004193520771, 0.5018299662096704, 0.9453070708485277], 
             UndirectedEdge[129, 133] -> 
             RGBColor[
              0.274546183535549, 0.4058958245022577, 0.9389463710464441], 
             UndirectedEdge[40, 80] -> 
             RGBColor[
              0.8969076644427829, 0.9198859493313639, 0.9640991398372748], 
             UndirectedEdge[41, 172] -> 
             RGBColor[
              0.41128561023817056`, 0.530254468896595, 0.9475388589522767], 
             UndirectedEdge[94, 115] -> 
             RGBColor[
              0.6162308702411219, 0.6969200714662753, 0.9644938896435327], 
             UndirectedEdge[87, 103] -> 
             RGBColor[
              0.5760516491155421, 0.666381560499287, 0.9599882947018246], 
             UndirectedEdge[142, 160] -> 
             RGBColor[
              0.323801878818008, 0.4537046877327962, 0.9418964780891804], 
             UndirectedEdge[21, 150] -> 
             RGBColor[
              0.3468307869831054, 0.4745633031216738, 0.9433304621110141], 
             UndirectedEdge[29, 142] -> 
             RGBColor[
              0.5638291878253758, 0.6519709059329633, 0.9609692907151317], 
             UndirectedEdge[67, 103] -> 
             RGBColor[
              0.419072542216388, 0.5364401993176267, 0.9481894662676709], 
             UndirectedEdge[50, 163] -> 
             RGBColor[
              0.7525339299653672, 0.8055598507786331, 0.9533706198295537], 
             UndirectedEdge[21, 46] -> 
             RGBColor[
              0.4671220244792514, 0.5764905091461798, 0.9516843071020609], 
             UndirectedEdge[43, 129] -> 
             RGBColor[
              0.34555939284077203`, 0.4723761975723705, 0.9432892096738854], 
             UndirectedEdge[11, 112] -> 
             RGBColor[
              0.30466063702393986`, 0.43599983843809753`, 0.940718031297427], 
             UndirectedEdge[119, 195] -> 
             RGBColor[
              0.49891979292941246`, 0.6026539017947734, 0.9540912435532061], 
             UndirectedEdge[99, 109] -> 
             RGBColor[
              0.28988296936283786`, 0.42046757276803337`, 0.9398764649857274],
              UndirectedEdge[45, 120] -> 
             RGBColor[
              0.6880776672512711, 0.7499507740131675, 0.8967566410385563], 
             UndirectedEdge[29, 153] -> 
             RGBColor[
              0.5927200458980609, 0.6769947150987747, 0.9628101906443405], 
             UndirectedEdge[27, 125] -> 
             RGBColor[
              0.30175220990746937`, 0.4307295440205624, 0.9406334423756286], 
             UndirectedEdge[35, 157] -> 
             RGBColor[
              0.35151470888421665`, 0.478886106017697, 0.9436191843112179], 
             UndirectedEdge[28, 112] -> 
             RGBColor[
              0.3203216732443907, 0.44956464086568426`, 0.9417159386768836], 
             UndirectedEdge[22, 89] -> 
             RGBColor[
              0.6818436626854834, 0.4582336879784507, 0.45086078499451854`], 
             UndirectedEdge[96, 116] -> 
             RGBColor[
              0.3577376309726924, 0.48427608835757624`, 0.9440157034039817], 
             UndirectedEdge[23, 143] -> 
             RGBColor[
              0.7019135501307371, 0.7619621351419138, 0.8986458885665435], 
             UndirectedEdge[6, 14] -> 
             RGBColor[
              0.38644289611188276`, 0.5043284396705743, 0.9463371191232777], 
             UndirectedEdge[9, 112] -> 
             RGBColor[
              0.4836374722132627, 0.5841427203936149, 0.9542790601262239], 
             UndirectedEdge[12, 25] -> 
             RGBColor[
              0.48486097307344384`, 0.5906311132157398, 0.953152806988248], 
             UndirectedEdge[176, 199] -> 
             RGBColor[
              0.6236682646858369, 0.6535384655892642, 0.6284615944249446], 
             UndirectedEdge[48, 112] -> 
             RGBColor[
              0.2930893585970763, 0.4253858771971273, 0.9400023774340288], 
             UndirectedEdge[79, 149] -> 
             RGBColor[
              0.31821379391176474`, 0.4495561099933516, 0.9415150895735018], 
             UndirectedEdge[58, 155] -> 
             RGBColor[
              0.3222358292148373, 0.4473421058618795, 0.9419799904100252], 
             UndirectedEdge[118, 138] -> 
             RGBColor[
              0.7819570290148345, 0.829350898357584, 0.9531134106084076], 
             UndirectedEdge[172, 173] -> 
             RGBColor[
              0.6555674093530977, 0.7283706143247698, 0.9680798983681294], 
             UndirectedEdge[53, 104] -> 
             RGBColor[
              0.32747862119117865`, 0.4580672549468817, 0.9420876260576954], 
             UndirectedEdge[179, 185] -> 
             RGBColor[
              0.31909718152913324`, 0.44300941236128405`, 0.9418391006629618],
              UndirectedEdge[82, 176] -> 
             RGBColor[
              0.5718330264870417, 0.5990563436984071, 0.6255096542928862], 
             UndirectedEdge[142, 181] -> 
             RGBColor[
              0.3793301416539576, 0.5029784358385457, 0.9453915590910844], 
             UndirectedEdge[54, 160] -> 
             RGBColor[
              0.3859427691490409, 0.5069153880330928, 0.9460253081910603], 
             UndirectedEdge[121, 151] -> 
             RGBColor[
              0.4484569286704754, 0.5619934707822735, 0.9500336324687897], 
             UndirectedEdge[138, 144] -> 
             RGBColor[
              0.4453203472423283, 0.55457329195156, 0.9507495644913943], 
             UndirectedEdge[171, 196] -> 
             RGBColor[
              0.566415883912228, 0.6553696709299617, 0.9606438657284343], 
             UndirectedEdge[120, 172] -> 
             RGBColor[
              0.428113490095943, 0.5448299326355633, 0.9486111165765041], 
             UndirectedEdge[113, 159] -> 
             RGBColor[
              0.6322447879153683, 0.639749380938324, 0.6091314983221823], 
             UndirectedEdge[103, 108] -> 
             RGBColor[
              0.3639776413317559, 0.4822935044296881, 0.9449141647928798], 
             UndirectedEdge[64, 176] -> 
             RGBColor[
              0.8873187671618203, 0.8720684017871536, 0.6496025391706133], 
             UndirectedEdge[83, 101] -> 
             RGBColor[
              0.8910613750216162, 0.912546124583143, 0.8283912169729619], 
             UndirectedEdge[15, 63] -> 
             RGBColor[
              0.3663670856068513, 0.4917504882326835, 0.9445655646225433], 
             UndirectedEdge[55, 72] -> 
             RGBColor[
              0.6155416349177705, 0.6918075037367072, 0.9664757937642099], 
             UndirectedEdge[105, 142] -> 
             RGBColor[
              0.6636753697836414, 0.730197653975656, 0.9347768145134494], 
             UndirectedEdge[96, 105] -> 
             RGBColor[
              0.6615719424267781, 0.7283757709204738, 0.9346427859822579], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.34319641708258153`, 0.4710897182916379, 0.9431108078790762], 
             UndirectedEdge[64, 108] -> 
             RGBColor[
              0.5245694770668783, 0.6101027000843653, 0.9593112664023637], 
             UndirectedEdge[56, 119] -> 
             RGBColor[
              0.3619975286149172, 0.48796579758659037`, 0.9442871403148647], 
             UndirectedEdge[68, 157] -> 
             RGBColor[
              0.5089063710163263, 0.609993905212751, 0.9551018494911185], 
             UndirectedEdge[137, 161] -> 
             RGBColor[
              0.8700114058688266, 0.8992263382582346, 0.9874533509532666], 
             UndirectedEdge[160, 188] -> 
             RGBColor[
              0.5221789990620147, 0.615894409736912, 0.9578604470056341], 
             UndirectedEdge[127, 187] -> 
             RGBColor[
              0.42257891557893823`, 0.5400970957241684, 0.9482416223135508], 
             UndirectedEdge[41, 141] -> 
             RGBColor[
              0.3802605651573715, 0.5037843219127578, 0.9454508448539807], 
             UndirectedEdge[137, 175] -> 
             RGBColor[
              0.6561122196561839, 0.7264303403609027, 0.9692990869562053], 
             UndirectedEdge[1, 122] -> 
             RGBColor[
              0.4805502770295619, 0.5871264428716108, 0.9528148493919528], 
             UndirectedEdge[60, 177] -> 
             RGBColor[
              0.44084059174955725`, 0.5548018829065081, 0.9497126434983456], 
             UndirectedEdge[72, 75] -> 
             RGBColor[
              0.29346381735246196`, 0.42462028191377754`, 0.9400661453877874],
              UndirectedEdge[13, 69] -> 
             RGBColor[
              0.8507307033033928, 0.8799420479686497, 0.7364713286604321], 
             UndirectedEdge[48, 77] -> 
             RGBColor[
              0.28532561806825574`, 0.41722569365175644`, 0.9395602438963373],
              UndirectedEdge[22, 183] -> 
             RGBColor[
              0.7016351659608846, 0.4753760933657249, 0.45212188208228793`], 
             UndirectedEdge[16, 86] -> 
             RGBColor[
              0.30873066870628574`, 0.4383434096058293, 0.9410206374197039], 
             UndirectedEdge[8, 62] -> 
             RGBColor[
              0.35209109054945864`, 0.47938533884634477`, 0.9436559108412529],
              UndirectedEdge[26, 51] -> 
             RGBColor[
              0.4717456448110524, 0.5800710710867598, 0.9520961238464899], 
             UndirectedEdge[117, 121] -> 
             RGBColor[
              0.4987906242386788, 0.602856632351686, 0.9539960853623208], 
             UndirectedEdge[89, 136] -> 
             RGBColor[
              0.27276856181707587`, 0.40257547641744407`, 0.9388983013026648],
              UndirectedEdge[81, 168] -> 
             RGBColor[
              0.3083947497269127, 0.4375527050860453, 0.9410175311957825], 
             UndirectedEdge[172, 198] -> 
             RGBColor[
              0.4583146733386764, 0.5709886796048127, 0.9505355092668734], 
             UndirectedEdge[55, 68] -> 
             RGBColor[
              0.7770687941030305, 0.8264972626230744, 0.9782219691594607], 
             UndirectedEdge[156, 192] -> 
             RGBColor[
              0.4113299405769004, 0.5306950533089398, 0.9474305579821432], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.31626002712134604`, 0.4460466471381729, 0.9414571341774959], 
             UndirectedEdge[25, 154] -> 
             RGBColor[
              0.5247319297609436, 0.6225572177752735, 0.9565944313135544], 
             UndirectedEdge[100, 135] -> 
             RGBColor[
              0.8471322303239477, 0.8771455071916745, 0.7372831465703549], 
             UndirectedEdge[37, 149] -> 
             RGBColor[
              0.4194948681145545, 0.5363353836947373, 0.9483464082991826], 
             UndirectedEdge[125, 149] -> 
             RGBColor[
              0.34118644109448915`, 0.4699402795720681, 0.9429610762205851], 
             UndirectedEdge[2, 184] -> 
             RGBColor[
              0.5452006868645622, 0.6416575044645242, 0.9573393416873505], 
             UndirectedEdge[6, 16] -> 
             RGBColor[
              0.2710158988903486, 0.40218527150717753`, 0.938745326558488], 
             UndirectedEdge[55, 111] -> 
             RGBColor[
              0.8481459317903276, 0.39972255908133447`, 0.4398982369139971], 
             UndirectedEdge[34, 50] -> 
             RGBColor[
              0.9149891709569797, 0.9343785769740065, 0.9684214723201563], 
             UndirectedEdge[56, 125] -> 
             RGBColor[
              0.3363992369217113, 0.46579384392948575`, 0.9426560398038542], 
             UndirectedEdge[98, 196] -> 
             RGBColor[
              0.5490193724839719, 0.6403016871048941, 0.9595353754033569], 
             UndirectedEdge[160, 167] -> 
             RGBColor[
              0.4146319659775106, 0.5302065704520331, 0.9482838268573881], 
             UndirectedEdge[22, 149] -> 
             RGBColor[
              0.6846744855606617, 0.46068560447163537`, 0.45104116252492654`],
              UndirectedEdge[147, 194] -> 
             RGBColor[
              0.6545089647618209, 0.6288246237239578, 0.6033267345132787], 
             UndirectedEdge[83, 161] -> 
             RGBColor[
              0.9049981357136825, 0.9234336279590896, 0.8297803030323136], 
             UndirectedEdge[34, 177] -> 
             RGBColor[
              0.6215013948490243, 0.6984007045722643, 0.9661967045272499], 
             UndirectedEdge[70, 145] -> 
             RGBColor[
              0.34988890484931917`, 0.4755408922267051, 0.9435865134550195], 
             UndirectedEdge[125, 170] -> 
             RGBColor[
              0.5559578660934784, 0.6457296877326459, 0.9602237243250951], 
             UndirectedEdge[190, 192] -> 
             RGBColor[
              0.3820084750902006, 0.5052982736440667, 0.9455622201292846], 
             UndirectedEdge[122, 188] -> 
             RGBColor[
              0.563178407979177, 0.6525839948196385, 0.9604297622831941], 
             UndirectedEdge[123, 130] -> 
             RGBColor[
              0.4122744164741755, 0.5298414628772588, 0.9479526204695762], 
             UndirectedEdge[94, 116] -> 
             RGBColor[
              0.5772346491206743, 0.663143504738807, 0.962009084916742], 
             UndirectedEdge[23, 162] -> 
             RGBColor[
              0.8762004360428759, 0.9026018654254631, 0.9133644525081803], 
             UndirectedEdge[116, 160] -> 
             RGBColor[
              0.3320445551979943, 0.4608440797241795, 0.9424216941394006], 
             UndirectedEdge[80, 117] -> 
             RGBColor[
              0.707369894317615, 0.7705267193807125, 0.9720422898733625], 
             UndirectedEdge[147, 185] -> 
             RGBColor[
              0.5763551338154357, 0.5533334426702176, 0.5986323740432102], 
             UndirectedEdge[55, 107] -> 
             RGBColor[
              0.6326994861905049, 0.7066687721304701, 0.9675690768752163], 
             UndirectedEdge[111, 174] -> 
             RGBColor[
              0.7307189870333527, 0.30663734480694327`, 0.428915027119498], 
             UndirectedEdge[126, 142] -> 
             RGBColor[
              0.6208194397762473, 0.6970583644884895, 0.9664992835832469], 
             UndirectedEdge[115, 160] -> 
             RGBColor[
              0.3710407763184418, 0.4946206464516478, 0.9449064988661912], 
             UndirectedEdge[74, 164] -> 
             RGBColor[
              0.43387151719154204`, 0.5485531333826293, 0.9493272911366086], 
             UndirectedEdge[42, 97] -> 
             RGBColor[
              0.6245384441862358, 0.6893956623116928, 0.8639717207902855], 
             UndirectedEdge[25, 108] -> 
             RGBColor[
              0.3087153840685305, 0.43538922112705725`, 0.9411273460709891], 
             UndirectedEdge[67, 133] -> 
             RGBColor[
              0.3021982890100339, 0.43119840144040644`, 0.9406588459206049], 
             UndirectedEdge[38, 183] -> 
             RGBColor[
              0.4178105109648169, 0.5363081976560145, 0.9478434941967179], 
             UndirectedEdge[33, 41] -> 
             RGBColor[
              0.38800643862462636`, 0.5104934081911735, 0.9459444050619072], 
             UndirectedEdge[32, 123] -> 
             RGBColor[
              0.4622297896394739, 0.5731102962829793, 0.951135732673867], 
             UndirectedEdge[61, 116] -> 
             RGBColor[
              0.38289062162011855`, 0.5060623446303079, 0.9456184297261194], 
             UndirectedEdge[93, 134] -> 
             RGBColor[
              0.4865713902184377, 0.5897189770407766, 0.9540515394786058], 
             UndirectedEdge[45, 128] -> 
             RGBColor[
              0.727442275446909, 0.783679647075868, 0.8993662592697147], 
             UndirectedEdge[29, 35] -> 
             RGBColor[
              0.5528072311360206, 0.6424242410282947, 0.9602669813812195], 
             UndirectedEdge[3, 106] -> 
             RGBColor[
              0.38129851105017654`, 0.504683338476428, 0.9455169818484508], 
             UndirectedEdge[77, 140] -> 
             RGBColor[
              0.38811388167866495`, 0.5053645165481957, 0.9464978395395918], 
             UndirectedEdge[79, 195] -> 
             RGBColor[
              0.45034885405348224`, 0.5600977785589524, 0.9510141563951124], 
             UndirectedEdge[38, 46] -> 
             RGBColor[
              0.4991248603784277, 0.6042097570927446, 0.9537234995065598], 
             UndirectedEdge[14, 59] -> 
             RGBColor[
              0.42275330525767296`, 0.5392701911419644, 0.9485229453644193], 
             UndirectedEdge[126, 191] -> 
             RGBColor[
              0.8080634894153242, 0.8505508471215636, 0.9813536120662611], 
             UndirectedEdge[13, 64] -> 
             RGBColor[
              0.7590792728032261, 0.8117177642208093, 0.9766215859800609], 
             UndirectedEdge[3, 11] -> 
             RGBColor[
              0.349271959407355, 0.4769435491447057, 0.9434762782977378], 
             UndirectedEdge[31, 98] -> 
             RGBColor[
              0.45201512802475463`, 0.5631796178568591, 0.9507841692066193], 
             UndirectedEdge[25, 162] -> 
             RGBColor[
              0.5713268430275946, 0.6589575181536381, 0.961238576813753], 
             UndirectedEdge[126, 157] -> 
             RGBColor[
              0.6317577234002498, 0.7065325559894801, 0.967196261343424], 
             UndirectedEdge[128, 183] -> 
             RGBColor[
              0.42532529060458446`, 0.5424503500425493, 0.9484236695159937], 
             UndirectedEdge[22, 192] -> 
             RGBColor[
              0.6996950141890805, 0.47369563141585164`, 0.45199825732699744`],
              UndirectedEdge[99, 194] -> 
             RGBColor[
              0.35309986942121646`, 0.4802590924023611, 0.9437201893389331], 
             UndirectedEdge[21, 151] -> 
             RGBColor[
              0.43637459695849423`, 0.5515283623290046, 0.9492637569760887], 
             UndirectedEdge[48, 59] -> 
             RGBColor[
              0.32297582609210107`, 0.4535756586921377, 0.9418223697015293], 
             UndirectedEdge[18, 115] -> 
             RGBColor[
              0.4040078936792071, 0.5243530643029355, 0.9469640036284541], 
             UndirectedEdge[29, 89] -> 
             RGBColor[
              0.550255066355581, 0.6402136841710094, 0.9601043596982006], 
             UndirectedEdge[15, 140] -> 
             RGBColor[
              0.4283073361907521, 0.5439173138694068, 0.9489220187621099], 
             UndirectedEdge[113, 136] -> 
             RGBColor[
              0.584447528208782, 0.5902451220334752, 0.6063826510492172], 
             UndirectedEdge[111, 160] -> 
             RGBColor[
              0.6435477918954822, 0.2322349320147391, 0.42286814676446927`], 
             UndirectedEdge[116, 188] -> 
             RGBColor[
              0.5582181785735625, 0.6482876934168742, 0.960113700851627], 
             UndirectedEdge[82, 127] -> 
             RGBColor[
              0.32240656768496273`, 0.4413301892406758, 0.9422982048274586], 
             UndirectedEdge[25, 95] -> 
             RGBColor[
              0.3660913365036478, 0.4915116482190416, 0.9445479941335224], 
             UndirectedEdge[62, 111] -> 
             RGBColor[
              0.6516651774209113, 0.24005110854446648`, 0.42335662552270226`],
              UndirectedEdge[162, 180] -> 
             RGBColor[
              0.7348809226676065, 0.7928138291805907, 0.9742097205849813], 
             UndirectedEdge[89, 159] -> 
             RGBColor[
              0.32056582152366225`, 0.45207973532229273`, 0.9416471485756299],
              UndirectedEdge[7, 153] -> 
             RGBColor[
              0.4567552944374115, 0.5686605334223653, 0.9507062305749249], 
             UndirectedEdge[146, 183] -> 
             RGBColor[
              0.3302634493888146, 0.4575166695283256, 0.9423735504765223], 
             UndirectedEdge[144, 197] -> 
             RGBColor[
              0.444402473074921, 0.5538281203526987, 0.9506773060746521], 
             UndirectedEdge[120, 128] -> 
             RGBColor[
              0.4274613241773478, 0.544300474963108, 0.9485597756864299], 
             UndirectedEdge[74, 166] -> 
             RGBColor[
              0.48324147268148754`, 0.5913149074219071, 0.9524731010442904], 
             UndirectedEdge[147, 152] -> 
             RGBColor[
              0.8062040742253886, 0.7533096544698161, 0.615161158627705], 
             UndirectedEdge[22, 190] -> 
             RGBColor[
              0.7023645352353669, 0.47600783637211586`, 0.452168356847502], 
             UndirectedEdge[27, 128] -> 
             RGBColor[
              0.36045003881723037`, 0.48120388114990936`, 0.9444749563349951],
              UndirectedEdge[47, 88] -> 
             RGBColor[
              0.34485769721962134`, 0.4731201371049595, 0.9431950054145142], 
             UndirectedEdge[69, 177] -> 
             RGBColor[
              0.6840108510057162, 0.7434694865090613, 0.7232452274432839], 
             UndirectedEdge[122, 167] -> 
             RGBColor[
              0.45563137489467287`, 0.5668961555347596, 0.9508531421349481], 
             UndirectedEdge[1, 78] -> 
             RGBColor[
              0.438538437851828, 0.5493727293932374, 0.9501878777088095], 
             UndirectedEdge[138, 159] -> 
             RGBColor[
              0.45794706902919047`, 0.5671110855618793, 0.9514955016599793], 
             UndirectedEdge[101, 127] -> 
             RGBColor[
              0.6265954512923247, 0.705517056729063, 0.9652651245678372], 
             UndirectedEdge[65, 90] -> 
             RGBColor[
              0.32258887326206237`, 0.44736528346010107`, 0.9420128338526919],
              UndirectedEdge[64, 127] -> 
             RGBColor[
              0.6378923083597413, 0.7143422473294225, 0.9663910897051857], 
             UndirectedEdge[117, 146] -> 
             RGBColor[
              0.4311640668498716, 0.5413192437172929, 0.9497954585539231], 
             UndirectedEdge[49, 103] -> 
             RGBColor[
              0.39927938865770035`, 0.5192963645379154, 0.9469282640253097], 
             UndirectedEdge[88, 113] -> 
             RGBColor[
              0.6368439767713183, 0.6437329671633946, 0.6094245545691804], 
             UndirectedEdge[13, 176] -> 
             RGBColor[
              0.8364995586154893, 0.8323680498304697, 0.6445373553952201], 
             UndirectedEdge[17, 112] -> 
             RGBColor[
              0.6074806518296769, 0.6817883132996556, 0.966384193835339], 
             UndirectedEdge[129, 170] -> 
             RGBColor[
              0.5283057606189935, 0.6204271107944972, 0.9585112494509342], 
             UndirectedEdge[35, 116] -> 
             RGBColor[
              0.3488191016402006, 0.47655130650808974`, 0.9434474226012611], 
             UndirectedEdge[69, 110] -> 
             RGBColor[
              0.848259758652745, 0.8780117272276887, 0.736225047989946], 
             UndirectedEdge[47, 126] -> 
             RGBColor[
              0.6269380051464617, 0.7023579582841318, 0.966889153158202], 
             UndirectedEdge[83, 137] -> 
             RGBColor[
              0.9598312529836523, 0.9671172244886568, 0.8350206423861196], 
             UndirectedEdge[72, 84] -> 
             RGBColor[
              0.4621290159653829, 0.5706311327657808, 0.9517901946001008], 
             UndirectedEdge[22, 37] -> 
             RGBColor[
              0.7423759925466883, 0.5097092700167792, 0.4549815770961716], 
             UndirectedEdge[90, 141] -> 
             RGBColor[
              0.32244153642449913`, 0.44723766769676854`, 0.9420034456796872],
              UndirectedEdge[24, 79] -> 
             RGBColor[
              0.4278738216101322, 0.5418515347327676, 0.9492448395124153], 
             UndirectedEdge[34, 130] -> 
             RGBColor[
              0.5889238756688514, 0.6701836948521219, 0.9641208938122583], 
             UndirectedEdge[157, 174] -> 
             RGBColor[
              0.4654969551488161, 0.5747824984220931, 0.9516637763819005], 
             UndirectedEdge[131, 180] -> 
             RGBColor[
              0.8385281658337703, 0.8430493046840826, 0.6580231656512747], 
             UndirectedEdge[3, 48] -> 
             RGBColor[
              0.3377006809804914, 0.4663295879037355, 0.9427606244343396], 
             UndirectedEdge[49, 67] -> 
             RGBColor[
              0.32963712099477605`, 0.45993683898740323`, 0.9422251637564942],
              UndirectedEdge[79, 190] -> 
             RGBColor[
              0.3447488684238226, 0.47253945784407236`, 0.9432058810573651], 
             UndirectedEdge[13, 82] -> 
             RGBColor[
              0.44359353212844754`, 0.5387057061320627, 0.9525287011023338], 
             UndirectedEdge[68, 138] -> 
             RGBColor[
              0.6217752134280572, 0.7037938421893931, 0.9633882937983599], 
             UndirectedEdge[153, 160] -> 
             RGBColor[
              0.3526927368906931, 0.47872849689860775`, 0.9437373780183892], 
             UndirectedEdge[178, 183] -> 
             RGBColor[
              0.5275491065026046, 0.62499731467348, 0.9567739393244014], 
             UndirectedEdge[2, 166] -> 
             RGBColor[
              0.5145942712730829, 0.6167685217460449, 0.9549413081985063], 
             UndirectedEdge[32, 53] -> 
             RGBColor[
              0.37309130294852844`, 0.49757466732505384`, 0.9449940258055629],
              UndirectedEdge[26, 184] -> 
             RGBColor[
              0.44721235813195054`, 0.5601538437486949, 0.9501647736507208], 
             UndirectedEdge[61, 115] -> 
             RGBColor[
              0.42188684274056604`, 0.5398389113577762, 0.9481032344529099], 
             UndirectedEdge[146, 178] -> 
             RGBColor[
              0.47398790705523586`, 0.5756426321425154, 0.9534695446865245], 
             UndirectedEdge[88, 102] -> 
             RGBColor[
              0.6359858744745142, 0.70799924526905, 0.9590611712594084], 
             UndirectedEdge[118, 159] -> 
             RGBColor[
              0.6406914640229888, 0.7109551475428229, 0.9430175522485972], 
             UndirectedEdge[62, 75] -> 
             RGBColor[
              0.29300084625155, 0.42421927961577166`, 0.9400366452786266], 
             UndirectedEdge[89, 197] -> 
             RGBColor[
              0.46091351234810063`, 0.5697303145381927, 0.9516707485186982], 
             UndirectedEdge[85, 146] -> 
             RGBColor[
              0.38270852991037907`, 0.5019808559327499, 0.945980861187566], 
             UndirectedEdge[170, 190] -> 
             RGBColor[
              0.5742491071465616, 0.6615726413883202, 0.9613892260306882], 
             UndirectedEdge[82, 101] -> 
             RGBColor[
              0.4831158836073621, 0.5695808674883871, 0.9564679197403785], 
             UndirectedEdge[7, 73] -> 
             RGBColor[
              0.4185365492076989, 0.5355573772343771, 0.9482709659243971], 
             UndirectedEdge[19, 34] -> 
             RGBColor[
              0.8033991742107751, 0.8467303780108255, 0.9809355996683522], 
             UndirectedEdge[56, 170] -> 
             RGBColor[
              0.5429268284617259, 0.6344428578950172, 0.9593933981300939], 
             UndirectedEdge[32, 187] -> 
             RGBColor[
              0.39442388170987175`, 0.516051874841545, 0.946353318860577], 
             UndirectedEdge[74, 169] -> 
             RGBColor[
              0.44860517673923905`, 0.5613146887475835, 0.9502661068945243], 
             UndirectedEdge[55, 147] -> 
             RGBColor[
              0.919054473480996, 0.8421951917005295, 0.6262163875964337], 
             UndirectedEdge[49, 143] -> 
             RGBColor[
              0.36286679315706927`, 0.4887187108424963, 0.9443425290828302], 
             UndirectedEdge[28, 77] -> 
             RGBColor[
              0.3125579327155702, 0.4414044573203134, 0.9412738051391921], 
             UndirectedEdge[122, 153] -> 
             RGBColor[
              0.39369214580785533`, 0.5154180819813342, 0.9463066932959492], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.43129050936908736`, 0.5407457588866922, 0.9498669587276898], 
             UndirectedEdge[16, 199] -> 
             RGBColor[
              0.2768234221708694, 0.40828934669324823`, 0.9390760564178529], 
             UndirectedEdge[64, 180] -> 
             RGBColor[
              0.7575984679912213, 0.8105609482471379, 0.9764739931953079], 
             UndirectedEdge[38, 128] -> 
             RGBColor[
              0.45931115273321815`, 0.5718871956392737, 0.9505892185983124], 
             UndirectedEdge[46, 98] -> 
             RGBColor[
              0.4478523774579912, 0.5598001094169847, 0.950456462233346], 
             UndirectedEdge[68, 142] -> 
             RGBColor[
              0.4979680873923239, 0.6005197137117604, 0.9544048717309417], 
             UndirectedEdge[5, 20] -> 
             RGBColor[
              0.869579607617195, 0.8988431912770458, 0.9874224733290498], 
             UndirectedEdge[169, 200] -> 
             RGBColor[
              0.3947928412836497, 0.5163714490799041, 0.94637682863836], 
             UndirectedEdge[27, 133] -> 
             RGBColor[
              0.25452022436403954`, 0.38484727169385424`, 0.9378059222973782],
              UndirectedEdge[32, 135] -> 
             RGBColor[
              0.5553088293515906, 0.6477771114326423, 0.9590778675034866], 
             UndirectedEdge[144, 190] -> 
             RGBColor[
              0.3387204085616252, 0.46620316430247133`, 0.9428625691865202], 
             UndirectedEdge[62, 126] -> 
             RGBColor[
              0.6051990149328297, 0.6835287375945016, 0.9655039639248237], 
             UndirectedEdge[55, 62] -> 
             RGBColor[
              0.6150786638168584, 0.6914065014387013, 0.966446293655049], 
             UndirectedEdge[62, 76] -> 
             RGBColor[
              0.44004421956879414`, 0.5526765586406153, 0.9500585452003084], 
             UndirectedEdge[157, 181] -> 
             RGBColor[
              0.3902684252779601, 0.5124526273395362, 0.9460885368512615], 
             UndirectedEdge[64, 82] -> 
             RGBColor[
              0.4944127406747786, 0.5784060580887467, 0.9575938848777271], 
             UndirectedEdge[142, 153] -> 
             RGBColor[
              0.38048924002225454`, 0.5039823885871866, 0.9454654158141619], 
             UndirectedEdge[21, 109] -> 
             RGBColor[
              0.32103283955548667`, 0.44744802469090694`, 0.9418613071696544],
              UndirectedEdge[66, 198] -> 
             RGBColor[
              0.3871894821082106, 0.5097858015180826, 0.9458923493150875], 
             UndirectedEdge[141, 198] -> 
             RGBColor[
              0.4272896282578774, 0.5445185326209754, 0.9484474951685773], 
             UndirectedEdge[10, 28] -> 
             RGBColor[
              0.36514399127413816`, 0.49069110539619604`, 0.9444876301332026],
              UndirectedEdge[31, 151] -> 
             RGBColor[
              0.519868670709411, 0.6210918325554495, 0.9553451125813842], 
             UndirectedEdge[111, 142] -> 
             RGBColor[
              0.6620787939831898, 0.249070859807125, 0.424020171961651], 
             UndirectedEdge[111, 181] -> 
             RGBColor[
              0.6805666337861154, 0.2650840974185721, 0.42519820076573855`], 
             UndirectedEdge[86, 101] -> 
             RGBColor[
              0.5668583683415734, 0.6541170522918255, 0.961364440874288], 
             UndirectedEdge[119, 144] -> 
             RGBColor[
              0.3460274592017479, 0.47253216430390177`, 0.9433281679919376], 
             UndirectedEdge[5, 102] -> 
             RGBColor[
              0.8977751976027896, 0.9210575859539563, 0.9808199467590331], 
             UndirectedEdge[157, 185] -> 
             RGBColor[
              0.2989380326187183, 0.4255485708033678, 0.9405545775204256], 
             UndirectedEdge[13, 110] -> 
             RGBColor[
              0.7057891196062471, 0.7700870915231643, 0.9713101215341815], 
             UndirectedEdge[32, 82] -> 
             RGBColor[
              0.2942515338158963, 0.4172849683580524, 0.9404099013744849], 
             UndirectedEdge[12, 23] -> 
             RGBColor[
              0.789734566088725, 0.8342754604875646, 0.9052786826826753], 
             UndirectedEdge[53, 130] -> 
             RGBColor[
              0.32313592978323, 0.45430583391933327`, 0.9418109136012721], 
             UndirectedEdge[74, 80] -> 
             RGBColor[
              0.6719002385732287, 0.7417308549576378, 0.9692499886435342], 
             UndirectedEdge[35, 185] -> 
             RGBColor[
              0.2769777923053607, 0.40652771439770863`, 0.9391552904263365], 
             UndirectedEdge[117, 196] -> 
             RGBColor[
              0.6672066107368317, 0.7390770633728971, 0.9680587716716527], 
             UndirectedEdge[22, 181] -> 
             RGBColor[
              0.7093809168016054, 0.48208507343120033`, 0.45261543447656016`],
              UndirectedEdge[143, 197] -> 
             RGBColor[
              0.5066332522821358, 0.6093304553281093, 0.9545839699189163], 
             UndirectedEdge[16, 124] -> 
             RGBColor[
              0.3606912702972892, 0.4833490710881845, 0.9443315210061267], 
             UndirectedEdge[182, 191] -> 
             RGBColor[
              0.5347728922923395, 0.6289262316569805, 0.958219536922559], 
             UndirectedEdge[98, 146] -> 
             RGBColor[
              0.3129768285970117, 0.44254386744929, 0.9412720622856272], 
             UndirectedEdge[156, 183] -> 
             RGBColor[
              0.4142401682346065, 0.5332157462337497, 0.9476159951150789], 
             UndirectedEdge[6, 13] -> 
             RGBColor[
              0.48962124704672183`, 0.5870837528368492, 0.9551499113750272], 
             UndirectedEdge[50, 100] -> 
             RGBColor[
              0.9775093907269796, 0.979470381191301, 0.7266415481194453], 
             UndirectedEdge[13, 175] -> 
             RGBColor[
              0.5478199902152332, 0.6409840790990644, 0.9587304429050028], 
             UndirectedEdge[62, 116] -> 
             RGBColor[
              0.3442206334861381, 0.47256834451877056`, 0.94315441227675], 
             UndirectedEdge[120, 171] -> 
             RGBColor[
              0.3860705730453998, 0.5088166587258807, 0.9458210534190177], 
             UndirectedEdge[72, 139] -> 
             RGBColor[
              0.33526744085856786`, 0.464813539065315, 0.9425839227595186], 
             UndirectedEdge[6, 83] -> 
             RGBColor[
              0.6329002063325284, 0.6967373037995424, 0.8080455075052768], 
             UndirectedEdge[118, 190] -> 
             RGBColor[
              0.6753570903341315, 0.7409807707084952, 0.9452264153035335], 
             UndirectedEdge[36, 200] -> 
             RGBColor[
              0.35829550187800313`, 0.4847592880963494, 0.9440512504447622], 
             UndirectedEdge[16, 161] -> 
             RGBColor[
              0.5431138282715027, 0.6288815956667247, 0.9604801220855247], 
             UndirectedEdge[2, 169] -> 
             RGBColor[
              0.47995797533083445`, 0.5867683030717215, 0.9527343140487401], 
             UndirectedEdge[107, 111] -> 
             RGBColor[
              0.6634123923366757, 0.2502259556723123, 0.4241051476694805], 
             UndirectedEdge[127, 180] -> 
             RGBColor[
              0.5855922950014054, 0.673485079399067, 0.9611783131450395], 
             UndirectedEdge[138, 156] -> 
             RGBColor[
              0.521934160827033, 0.6225334883924248, 0.9555727025677742], 
             UndirectedEdge[72, 93] -> 
             RGBColor[
              0.31472731060086073`, 0.44696956150118394`, 0.9412770698717645],
              UndirectedEdge[137, 187] -> 
             RGBColor[
              0.6520581094633737, 0.7229188738773935, 0.9690407626396284], 
             UndirectedEdge[40, 121] -> 
             RGBColor[
              0.6883283943638466, 0.7522158623023374, 0.9460529353262331], 
             UndirectedEdge[98, 178] -> 
             RGBColor[
              0.5102624857108017, 0.6100245125944443, 0.9556724511335062], 
             UndirectedEdge[10, 186] -> 
             RGBColor[
              0.29209398238579554`, 0.41835504007071816`, 0.9401648189845256],
              UndirectedEdge[63, 91] -> 
             RGBColor[
              0.4558715223588308, 0.5672551246495475, 0.9508267319149598], 
             UndirectedEdge[125, 195] -> 
             RGBColor[
              0.4733215012362066, 0.5804819481376688, 0.9524601430421956], 
             UndirectedEdge[86, 180] -> 
             RGBColor[
              0.5258552120506541, 0.6220850749618295, 0.9572776294514903], 
             UndirectedEdge[137, 186] -> 
             RGBColor[
              0.5677787693564067, 0.6408565262529409, 0.9640024284354084], 
             UndirectedEdge[33, 44] -> 
             RGBColor[
              0.45214378132201866`, 0.5652477359044499, 0.9502517289778287], 
             UndirectedEdge[14, 193] -> 
             RGBColor[
              0.5633698089236312, 0.6564080162616974, 0.9587696815315274], 
             UndirectedEdge[11, 28] -> 
             RGBColor[
              0.3411519971302512, 0.46991044594144915`, 0.9429588814816414], 
             UndirectedEdge[85, 151] -> 
             RGBColor[
              0.4868366512506014, 0.5942749510832692, 0.9527447110093126], 
             UndirectedEdge[175, 199] -> 
             RGBColor[
              0.33498869628558076`, 0.46215449485785903`, 0.9426546819347275],
              UndirectedEdge[146, 196] -> 
             RGBColor[
              0.512744793828406, 0.6059198066529652, 0.9573324689563751], 
             UndirectedEdge[20, 77] -> 
             RGBColor[
              0.5790017596545165, 0.6571104301293053, 0.9639662306409855], 
             UndirectedEdge[27, 56] -> 
             RGBColor[
              0.2887211722757169, 0.41944271418293355`, 0.9398031161806275], 
             UndirectedEdge[101, 175] -> 
             RGBColor[
              0.5873423416941477, 0.6718592404553889, 0.9626696615430476], 
             UndirectedEdge[21, 85] -> 
             RGBColor[
              0.4382527555872051, 0.5530531361138742, 0.9494116125032626], 
             UndirectedEdge[150, 194] -> 
             RGBColor[
              0.3432898253018727, 0.4714963000872989, 0.9431048351638355], 
             UndirectedEdge[61, 160] -> 
             RGBColor[
              0.3468514421085708, 0.47366906095034567`, 0.9433651758801265], 
             UndirectedEdge[24, 149] -> 
             RGBColor[
              0.442602635333882, 0.5550953101164375, 0.9501655363812285], 
             UndirectedEdge[14, 186] -> 
             RGBColor[
              0.35630818898061684`, 0.4726549518248278, 0.9446209921324562], 
             UndirectedEdge[111, 126] -> 
             RGBColor[
              0.8415594992009751, 0.3944707165185346, 0.43927001709384694`], 
             UndirectedEdge[35, 88] -> 
             RGBColor[
              0.32771717516005183`, 0.4582738784046485, 0.942102826505647], 
             UndirectedEdge[94, 111] -> 
             RGBColor[
              0.8070078545106022, 0.36710121535782414`, 0.43592640728269694`],
              UndirectedEdge[133, 162] -> 
             RGBColor[
              0.5097148470844659, 0.6006200035790488, 0.9574947751885776], 
             UndirectedEdge[124, 199] -> 
             RGBColor[
              0.36646532452401004`, 0.48941796817665073`, 0.9446603448523907],
              UndirectedEdge[54, 105] -> 
             RGBColor[
              0.7258162601146743, 0.7834083542759525, 0.9389056446153293], 
             UndirectedEdge[64, 162] -> 
             RGBColor[
              0.7871809360259425, 0.8336709971109462, 0.9794224971451275], 
             UndirectedEdge[57, 66] -> 
             RGBColor[
              0.44280539431204935`, 0.5550681494225451, 0.9502344848133377], 
             UndirectedEdge[16, 137] -> 
             RGBColor[
              0.5979469455414725, 0.6725651921962919, 0.9657204614393307], 
             UndirectedEdge[44, 50] -> 
             RGBColor[
              0.7222557767692009, 0.7809786819987281, 0.9509870126974218], 
             UndirectedEdge[153, 167] -> 
             RGBColor[
              0.4713193271817572, 0.5804842713064235, 0.9518527645823696], 
             UndirectedEdge[165, 187] -> 
             RGBColor[
              0.3579919583006357, 0.4844963739061775, 0.9440319089164254], 
             UndirectedEdge[32, 83] -> 
             RGBColor[
              0.7021970252301504, 0.7602502254528083, 0.8123331986070683], 
             UndirectedEdge[6, 187] -> 
             RGBColor[
              0.3251270628122498, 0.4525389531882792, 0.9420656277587856], 
             UndirectedEdge[66, 141] -> 
             RGBColor[
              0.3659800278989114, 0.491415238300152, 0.9445409016476549], 
             UndirectedEdge[23, 87] -> 
             RGBColor[
              0.8256629848675978, 0.863121624468481, 0.9083273516743612], 
             UndirectedEdge[85, 152] -> 
             RGBColor[
              0.5864069033695402, 0.6744711638253575, 0.9610204096705102], 
             UndirectedEdge[26, 74] -> 
             RGBColor[
              0.44805104212850816`, 0.5608347251993838, 0.9502307979271305], 
             UndirectedEdge[81, 172] -> 
             RGBColor[
              0.40963780171181796`, 0.5288272199723331, 0.9474338620500775], 
             UndirectedEdge[54, 73] -> 
             RGBColor[
              0.4044113851235749, 0.5240899326994948, 0.9471589812655139], 
             UndirectedEdge[135, 165] -> 
             RGBColor[
              0.5188769059423546, 0.6162216104972746, 0.956756457559335], 
             UndirectedEdge[46, 109] -> 
             RGBColor[
              0.40036416273964004`, 0.5136319864774774, 0.9476149558016764], 
             UndirectedEdge[40, 171] -> 
             RGBColor[
              0.6743729270588614, 0.7401283379449408, 0.9451637052898947], 
             UndirectedEdge[113, 167] -> 
             RGBColor[
              0.7405333140309833, 0.7313728859946894, 0.6166312833827821], 
             UndirectedEdge[103, 162] -> 
             RGBColor[
              0.62658910029082, 0.705861801456269, 0.9650253955356436], 
             UndirectedEdge[37, 119] -> 
             RGBColor[
              0.45333699326673504`, 0.5656477315468884, 0.9505027985884632], 
             UndirectedEdge[71, 184] -> 
             RGBColor[
              0.37754703816119667`, 0.4936499683252, 0.9459514288180225], 
             UndirectedEdge[107, 142] -> 
             RGBColor[
              0.35359877947979823`, 0.48069122321915597`, 0.9437519794466972],
              UndirectedEdge[136, 143] -> 
             RGBColor[
              0.3184883017511111, 0.4421756172073607, 0.9418115227028829], 
             UndirectedEdge[3, 5] -> 
             RGBColor[
              0.6112557429553525, 0.6901703216713104, 0.9652474446433527], 
             UndirectedEdge[24, 118] -> 
             RGBColor[
              0.7584820435204411, 0.8102928475971906, 0.9512653737585837], 
             UndirectedEdge[142, 185] -> 
             RGBColor[
              0.28799974899471587`, 0.41607437930237723`, 0.9398575997602486],
              UndirectedEdge[3, 28] -> 
             RGBColor[
              0.3649329956278058, 0.4905083515722925, 0.9444741856771943], 
             UndirectedEdge[43, 49] -> 
             RGBColor[
              0.3534183447565693, 0.4805349397308079, 0.9437404823056852], 
             UndirectedEdge[19, 60] -> 
             RGBColor[
              0.622738371111308, 0.7031315563450693, 0.964451538639448], 
             UndirectedEdge[87, 110] -> 
             RGBColor[
              0.6833533316536855, 0.7525600834563193, 0.9690739318654291], 
             UndirectedEdge[107, 185] -> 
             RGBColor[
              0.29000014652494466`, 0.41780702310015816`, 0.9399850633219927],
              UndirectedEdge[66, 81] -> 
             RGBColor[
              0.3385126104813521, 0.467624341885603, 0.9427907020982916], 
             UndirectedEdge[63, 112] -> 
             RGBColor[
              0.3339373716235846, 0.4613578744568433, 0.9425835189377165], 
             UndirectedEdge[59, 193] -> 
             RGBColor[
              0.48421975179408727`, 0.5891714214720863, 0.9533618091947784], 
             UndirectedEdge[110, 180] -> 
             RGBColor[
              0.7043083147942424, 0.7689302755494929, 0.9711625287494287], 
             UndirectedEdge[21, 196] -> 
             RGBColor[
              0.5682890195052321, 0.6569920868340895, 0.9607632202720717], 
             UndirectedEdge[24, 190] -> 
             RGBColor[
              0.46913770984593983`, 0.5780786579671582, 0.9518563278650917], 
             UndirectedEdge[44, 60] -> 
             RGBColor[
              0.4947882327492612, 0.6007304031585455, 0.9533706886324897], 
             UndirectedEdge[20, 106] -> 
             RGBColor[
              0.6396223757120191, 0.7133562080821634, 0.9676920105341478], 
             UndirectedEdge[75, 139] -> 
             RGBColor[
              0.30744778374647175`, 0.4367324907496814, 0.9409571913608779], 
             UndirectedEdge[4, 81] -> 
             RGBColor[
              0.4765924469581073, 0.5831840172556659, 0.9527047769868122], 
             UndirectedEdge[79, 197] -> 
             RGBColor[
              0.45043093293711833`, 0.5601644138942997, 0.9510206179454971], 
             UndirectedEdge[66, 90] -> 
             RGBColor[
              0.2823413902748323, 0.4125049365938757, 0.9394482998261974], 
             UndirectedEdge[14, 15] -> 
             RGBColor[
              0.4252965517459148, 0.5414730234227944, 0.9486849987817454], 
             UndirectedEdge[14, 48] -> 
             RGBColor[
              0.402125883221645, 0.5208122534817488, 0.9472302420382783], 
             UndirectedEdge[122, 144] -> 
             RGBColor[
              0.33471612699219566`, 0.46273485686807503`, 0.9426074199057632],
              UndirectedEdge[80, 121] -> 
             RGBColor[
              0.6205346347979965, 0.6989068512951737, 0.9655166139664825], 
             UndirectedEdge[79, 170] -> 
             RGBColor[
              0.532985218910754, 0.6253455181539296, 0.9587777376780118], 
             UndirectedEdge[91, 95] -> 
             RGBColor[
              0.4408454961315029, 0.5542403359614736, 0.9498692868107477], 
             UndirectedEdge[48, 193] -> 
             RGBColor[
              0.4635923297580593, 0.5707134838118706, 0.9520691058686375], 
             UndirectedEdge[67, 162] -> 
             RGBColor[
              0.5569468326278957, 0.6465022759057568, 0.9603222952668281], 
             UndirectedEdge[65, 87] -> 
             RGBColor[
              0.5348816680377382, 0.6316832985300725, 0.9570994233571584], 
             UndirectedEdge[98, 121] -> 
             RGBColor[
              0.38060338598581894`, 0.5040812560836831, 0.9454726890940248], 
             UndirectedEdge[161, 187] -> 
             RGBColor[
              0.5972249921934039, 0.6792352773478264, 0.9638004232858224], 
             UndirectedEdge[68, 122] -> 
             RGBColor[
              0.5111709931779247, 0.6119554071059081, 0.9552461492127289], 
             UndirectedEdge[19, 90] -> 
             RGBColor[
              0.4887094085927316, 0.5820295011062816, 0.9557464169554029], 
             UndirectedEdge[80, 168] -> 
             RGBColor[
              0.5473790325586494, 0.631558085961172, 0.9610011162333354], 
             UndirectedEdge[109, 194] -> 
             RGBColor[
              0.3174918778742539, 0.4443810216565321, 0.9416356802224757], 
             UndirectedEdge[44, 57] -> 
             RGBColor[
              0.5212232742679018, 0.6221915607484272, 0.955451751935585], 
             UndirectedEdge[109, 151] -> 
             RGBColor[
              0.3696167352188829, 0.48866983966030203`, 0.9451944056757043], 
             UndirectedEdge[122, 138] -> 
             RGBColor[
              0.4886084137709036, 0.5936684012931555, 0.9534492154341587], 
             UndirectedEdge[138, 192] -> 
             RGBColor[
              0.4886084137709036, 0.5936684012931555, 0.9534492154341587], 
             UndirectedEdge[31, 46] -> 
             RGBColor[
              0.5506160982301682, 0.6460539793726249, 0.9577656627073563], 
             UndirectedEdge[101, 165] -> 
             RGBColor[
              0.5620084940140222, 0.6499163349110719, 0.9610554111707119], 
             UndirectedEdge[76, 105] -> 
             RGBColor[
              0.7677416322462838, 0.817445260088884, 0.9422061634872281], 
             UndirectedEdge[6, 199] -> 
             RGBColor[
              0.27678995311706944`, 0.4082541685956438, 0.939074150404752], 
             UndirectedEdge[83, 175] -> 
             RGBColor[
              0.6910989495010398, 0.7506376300617577, 0.8116260390352523], 
             UndirectedEdge[139, 182] -> 
             RGBColor[
              0.3463553553047667, 0.4744173332638283, 0.9432904348633726], 
             UndirectedEdge[89, 149] -> 
             RGBColor[
              0.3286963733227471, 0.4591220106372445, 0.942165220146703], 
             UndirectedEdge[53, 163] -> 
             RGBColor[
              0.43993924315927313`, 0.5530325326714182, 0.9499283765825397], 
             UndirectedEdge[8, 96] -> 
             RGBColor[
              0.36560808803601297`, 0.49109308268515045`, 0.9445172019684845],
              UndirectedEdge[16, 187] -> 
             RGBColor[
              0.32516053186604976`, 0.45257413128588364`, 0.9420675337718865],
              UndirectedEdge[55, 191] -> 
             RGBColor[
              0.817943138299353, 0.8584286109657633, 0.9822959417964865], 
             UndirectedEdge[122, 181] -> 
             RGBColor[
              0.3925330474395584, 0.5144141292326934, 0.9462328365728718], 
             UndirectedEdge[130, 177] -> 
             RGBColor[
              0.3422428404813687, 0.4708552796248061, 0.9430283890553798], 
             UndirectedEdge[25, 131] -> 
             RGBColor[
              0.6749740861937583, 0.70919299365713, 0.6450520218800464], 
             UndirectedEdge[19, 33] -> 
             RGBColor[
              0.5800939196840655, 0.6676488890909738, 0.9613325789847869], 
             UndirectedEdge[1, 89] -> 
             RGBColor[
              0.4537732497741662, 0.5639335277155093, 0.9511086408932344], 
             UndirectedEdge[123, 127] -> 
             RGBColor[
              0.4903848235085404, 0.5971555171656027, 0.9530240361268407], 
             UndirectedEdge[40, 173] -> 
             RGBColor[
              0.9038529892523259, 0.9254239628086739, 0.9647615911177737], 
             UndirectedEdge[17, 106] -> 
             RGBColor[
              0.660337527358359, 0.7298739077071428, 0.9696678401908099], 
             UndirectedEdge[51, 158] -> 
             RGBColor[
              0.6877201533111806, 0.7547416411506065, 0.9703500218201178], 
             UndirectedEdge[20, 189] -> 
             RGBColor[
              0.70424417045289, 0.767550704108223, 0.9723008254126981], 
             UndirectedEdge[48, 140] -> 
             RGBColor[
              0.4051366676664824, 0.5232565439283612, 0.9474672620186428], 
             UndirectedEdge[11, 189] -> 
             RGBColor[
              0.4221393072934928, 0.5382799288716443, 0.9486104925314482], 
             UndirectedEdge[40, 169] -> 
             RGBColor[
              0.6736126026087932, 0.7394697831213097, 0.9451152580882649], 
             UndirectedEdge[94, 167] -> 
             RGBColor[
              0.6598220599001906, 0.7325059954666606, 0.9678712176347295], 
             UndirectedEdge[81, 198] -> 
             RGBColor[
              0.3998222108403181, 0.5207276362064264, 0.9466972956192141], 
             UndirectedEdge[34, 60] -> 
             RGBColor[
              0.6875216269370399, 0.7541302981338239, 0.9708051482552242], 
             UndirectedEdge[13, 101] -> 
             RGBColor[
              0.7477824157358095, 0.8028925736204497, 0.9754956208427124], 
             UndirectedEdge[31, 117] -> 
             RGBColor[
              0.5702023662776144, 0.6619549941248621, 0.9593075654749152], 
             UndirectedEdge[94, 105] -> 
             RGBColor[
              0.8810689605747599, 0.9072431873017046, 0.9526361674950182], 
             UndirectedEdge[125, 190] -> 
             RGBColor[
              0.367721515606547, 0.4929236274227887, 0.9446518677044484], 
             UndirectedEdge[79, 119] -> 
             RGBColor[
              0.35205591906394523`, 0.4788684578455028, 0.9436714798627825], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.6232568602896484, 0.6991812211780277, 0.9666492143628914], 
             UndirectedEdge[156, 178] -> 
             RGBColor[
              0.5579646259010278, 0.6513417088479396, 0.9587119893250811], 
             UndirectedEdge[95, 131] -> 
             RGBColor[
              0.6628751273445446, 0.6987134836132944, 0.6442810869208637], 
             UndirectedEdge[49, 133] -> 
             RGBColor[
              0.28240513545134627`, 0.41405456666069507`, 0.9393976436782437],
              UndirectedEdge[34, 44] -> 
             RGBColor[
              0.6754490358487282, 0.7443292248243017, 0.9698547496613941], 
             UndirectedEdge[24, 125] -> 
             RGBColor[
              0.4508464687928566, 0.5622357043114841, 0.9506908261594986], 
             UndirectedEdge[95, 129] -> 
             RGBColor[
              0.324059220629464, 0.45375382903301154`, 0.9419192377124367], 
             UndirectedEdge[13, 16] -> 
             RGBColor[
              0.4896547161005218, 0.5871189309344537, 0.9551518173881282], 
             UndirectedEdge[13, 199] -> 
             RGBColor[
              0.49542877032724264`, 0.5931878280229199, 0.9554806412343921], 
             UndirectedEdge[121, 196] -> 
             RGBColor[
              0.5803713512172133, 0.6674571952873584, 0.9615330957647727], 
             UndirectedEdge[26, 40] -> 
             RGBColor[
              0.6730584679980623, 0.7389898195731099, 0.945079949120871], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.49000532669575925`, 0.5968474245568505, 0.952994160747596], 
             UndirectedEdge[54, 126] -> 
             RGBColor[
              0.6829603301072802, 0.750269064788786, 0.9706281136851268], 
             UndirectedEdge[16, 193] -> 
             RGBColor[
              0.44794281170209704`, 0.5542648480983006, 0.9511778889667377], 
             UndirectedEdge[85, 150] -> 
             RGBColor[
              0.3972928412752126, 0.5173098918759385, 0.946811416144238], 
             UndirectedEdge[26, 169] -> 
             RGBColor[
              0.3819696465982227, 0.5052646423558922, 0.9455597460121105], 
             UndirectedEdge[22, 79] -> 
             RGBColor[
              0.6748552764114951, 0.4518564208825221, 0.4504273646123845], 
             UndirectedEdge[27, 67] -> 
             RGBColor[
              0.30175220990746937`, 0.4307295440205624, 0.9406334423756286], 
             UndirectedEdge[49, 95] -> 
             RGBColor[
              0.33191817254526124`, 0.46191257119144896`, 0.9423705103442364],
              UndirectedEdge[147, 178] -> 
             RGBColor[
              0.7997913578800175, 0.7482999917223628, 0.6145219989926398], 
             UndirectedEdge[1, 136] -> 
             RGBColor[
              0.4020916725812624, 0.5110648682354859, 0.9481122883448082], 
             UndirectedEdge[65, 110] -> 
             RGBColor[
              0.554846511339652, 0.6472799858559566, 0.9590893323554248], 
             UndirectedEdge[77, 106] -> 
             RGBColor[
              0.32892344813794094`, 0.45557944422444896`, 0.9423166013104485],
              UndirectedEdge[25, 64] -> 
             RGBColor[
              0.5940443883512094, 0.6767046372201853, 0.9635028494240796], 
             UndirectedEdge[82, 187] -> 
             RGBColor[
              0.2790993478939755, 0.4041609064834927, 0.9394444174860921], 
             UndirectedEdge[167, 188] -> 
             RGBColor[
              0.6408055893530789, 0.7176501841447278, 0.9659758335696145], 
             UndirectedEdge[13, 137] -> 
             RGBColor[
              0.8165522936978458, 0.8574636735259635, 0.98212504625587], 
             UndirectedEdge[37, 125] -> 
             RGBColor[
              0.42773870157352917`, 0.5434757778897839, 0.9488716980774528], 
             UndirectedEdge[105, 182] -> 
             RGBColor[
              0.6596058304873346, 0.7266728235781873, 0.9345175070680412], 
             UndirectedEdge[111, 116] -> 
             RGBColor[
              0.6675739115698474, 0.2538304544680472, 0.4243703159951311], 
             UndirectedEdge[146, 179] -> 
             RGBColor[
              0.345247748479925, 0.4704953162682749, 0.9433283367645124], 
             UndirectedEdge[9, 63] -> 
             RGBColor[
              0.5337445306987679, 0.6298465614881255, 0.9573874905712711], 
             UndirectedEdge[38, 120] -> 
             RGBColor[
              0.4199465445375802, 0.5381583225765731, 0.9479796003671541], 
             UndirectedEdge[71, 81] -> 
             RGBColor[
              0.2966151056297218, 0.4251715522673246, 0.9403466978908692], 
             UndirectedEdge[68, 181] -> 
             RGBColor[
              0.525699847096712, 0.6245395701289311, 0.956171914937073], 
             UndirectedEdge[114, 158] -> 
             RGBColor[
              0.5450333894645971, 0.6311439029663735, 0.9605506944153089], 
             UndirectedEdge[118, 149] -> 
             RGBColor[
              0.6488220158220737, 0.7179974228577746, 0.9435356238196702], 
             UndirectedEdge[87, 162] -> 
             RGBColor[
              0.7139259395270497, 0.7764436370874171, 0.9721211237009818], 
             UndirectedEdge[88, 122] -> 
             RGBColor[
              0.3519420376350078, 0.47925623670346473`, 0.9436464133213465], 
             UndirectedEdge[49, 162] -> 
             RGBColor[
              0.5371536790692081, 0.6293584411260456, 0.959061093024467], 
             UndirectedEdge[47, 116] -> 
             RGBColor[
              0.3659596236997701, 0.4913975652084007, 0.9445396015101284], 
             UndirectedEdge[23, 95] -> 
             RGBColor[
              0.670964929518929, 0.7351559954908664, 0.8966738698279497], 
             UndirectedEdge[54, 115] -> 
             RGBColor[
              0.4609781697810362, 0.5730852384405232, 0.9507633667638438], 
             UndirectedEdge[62, 105] -> 
             RGBColor[
              0.6480549449402238, 0.7166680270816681, 0.9337814948550263], 
             UndirectedEdge[13, 108] -> 
             RGBColor[
              0.47375026852054725`, 0.5704023481276814, 0.9542460826269703], 
             UndirectedEdge[76, 182] -> 
             RGBColor[
              0.45159510511590495`, 0.5626813551371344, 0.9507945574133233], 
             UndirectedEdge[117, 171] -> 
             RGBColor[
              0.48483515693369356`, 0.5907691079942894, 0.9531068553259823], 
             UndirectedEdge[40, 46] -> 
             RGBColor[
              0.7555773858360189, 0.8079347156356389, 0.9510367084655542], 
             UndirectedEdge[19, 177] -> 
             RGBColor[
              0.5567181390232924, 0.6474019627835098, 0.9598430949114736], 
             UndirectedEdge[64, 87] -> 
             RGBColor[
              0.7366434848506644, 0.7941907561539643, 0.9743853963113085], 
             UndirectedEdge[62, 107] -> 
             RGBColor[
              0.3379783546363806, 0.4671615963251682, 0.9427566597882739], 
             UndirectedEdge[53, 148] -> 
             RGBColor[
              0.442250687121619, 0.5549090670094144, 0.9501103419183538], 
             UndirectedEdge[76, 111] -> 
             RGBColor[
              0.7314563022916181, 0.307235930549277, 0.4289730712775034], 
             UndirectedEdge[11, 48] -> 
             RGBColor[
              0.3139196824829368, 0.44573168227289217`, 0.9412453202387867], 
             UndirectedEdge[96, 111] -> 
             RGBColor[
              0.6606765090786142, 0.24785627110367026`, 0.4239308196075233], 
             UndirectedEdge[168, 198] -> 
             RGBColor[
              0.35707162135377124`, 0.47971416471852496`, 0.9441191784125783],
              UndirectedEdge[118, 128] -> 
             RGBColor[
              0.7157636781908093, 0.7756121541821681, 0.9479024275573068], 
             UndirectedEdge[56, 129] -> 
             RGBColor[
              0.3087471314472264, 0.440491266991337, 0.9409435649296933], 
             UndirectedEdge[53, 100] -> 
             RGBColor[
              0.6649147039208856, 0.7269430630840861, 0.7231993048724312], 
             UndirectedEdge[129, 143] -> 
             RGBColor[
              0.35500784124127205`, 0.4805599686840589, 0.9438912564510304], 
             UndirectedEdge[18, 160] -> 
             RGBColor[
              0.32897249304721177`, 0.458183213895505, 0.9422259450556707], 
             UndirectedEdge[68, 111] -> 
             RGBColor[
              0.7596585976116927, 0.33011161600071526`, 0.4312070758589768], 
             UndirectedEdge[51, 166] -> 
             RGBColor[
              0.5069360753640317, 0.610551253309283, 0.9543384269636499], 
             UndirectedEdge[107, 181] -> 
             RGBColor[
              0.38133053918418647`, 0.5047110796363267, 0.9455190226528285], 
             UndirectedEdge[31, 173] -> 
             RGBColor[
              0.6988917016464753, 0.7635432265456599, 0.9714905453595759], 
             UndirectedEdge[135, 148] -> 
             RGBColor[
              0.6244682135246812, 0.7051115111170028, 0.9641941836162775], 
             UndirectedEdge[44, 177] -> 
             RGBColor[
              0.42876800066124554`, 0.5450008095969859, 0.9487622449045154], 
             UndirectedEdge[80, 184] -> 
             RGBColor[
              0.671061554576671, 0.7410499735069489, 0.9691839643671245], 
             UndirectedEdge[65, 162] -> 
             RGBColor[
              0.5854191192130163, 0.6711635394870545, 0.9621365241909776], 
             UndirectedEdge[5, 17] -> 
             RGBColor[
              0.8902947592635349, 0.9153608909020252, 0.9893983029857117], 
             UndirectedEdge[44, 141] -> 
             RGBColor[
              0.44439790785476385`, 0.5585386496260341, 0.9497581687699022], 
             UndirectedEdge[94, 174] -> 
             RGBColor[
              0.6719522623159322, 0.7423538402471511, 0.9688261516032923], 
             UndirectedEdge[161, 193] -> 
             RGBColor[
              0.7200072720294511, 0.7809259941602433, 0.9729107784806735], 
             UndirectedEdge[101, 124] -> 
             RGBColor[
              0.618818969932577, 0.6991227137741807, 0.9646753244607108], 
             UndirectedEdge[106, 189] -> 
             RGBColor[
              0.45416585893631434`, 0.5660197182033666, 0.9506511960821612], 
             UndirectedEdge[2, 80] -> 
             RGBColor[
              0.703253037164824, 0.7671844692817755, 0.9717181957977501], 
             UndirectedEdge[97, 102] -> 
             RGBColor[
              0.9688129840063942, 0.9750415653552011, 0.8830509877526731], 
             UndirectedEdge[91, 136] -> 
             RGBColor[
              0.3743927996163719, 0.4885776753425809, 0.9459317316006972], 
             UndirectedEdge[59, 154] -> 
             RGBColor[
              0.5074384061485774, 0.6075784368200117, 0.9554925032810369], 
             UndirectedEdge[108, 162] -> 
             RGBColor[
              0.5018519317432636, 0.5923555810178183, 0.9570469937920371], 
             UndirectedEdge[146, 147] -> 
             RGBColor[
              0.6025057007662276, 0.5808193465772084, 0.6001216101447608], 
             UndirectedEdge[99, 156] -> 
             RGBColor[
              0.3850733242714151, 0.5079528919610358, 0.9457575096089719], 
             UndirectedEdge[143, 154] -> 
             RGBColor[
              0.543581591523538, 0.6388838473824854, 0.9577955150929653], 
             UndirectedEdge[139, 145] -> 
             RGBColor[
              0.31852341479375457`, 0.44837368121594323`, 0.9415879321640928],
              UndirectedEdge[104, 123] -> 
             RGBColor[
              0.41661710788212414`, 0.5336028839048071, 0.9482293329259994], 
             UndirectedEdge[116, 126] -> 
             RGBColor[
              0.6290621161562338, 0.7041977564798728, 0.9670244996334671], 
             UndirectedEdge[17, 28] -> 
             RGBColor[
              0.6439720119359883, 0.7156989208030072, 0.9686250440195534], 
             UndirectedEdge[89, 118] -> 
             RGBColor[
              0.6445757815093063, 0.7143195481179976, 0.9432650575240582], 
             UndirectedEdge[123, 163] -> 
             RGBColor[
              0.5290777298502186, 0.6285681616293437, 0.9560700834508438], 
             UndirectedEdge[47, 157] -> 
             RGBColor[
              0.36865523094378616`, 0.49373236471800797`, 0.9447113632200852],
              UndirectedEdge[117, 151] -> 
             RGBColor[
              0.5352921881900938, 0.6336133388678122, 0.9565593083756697], 
             UndirectedEdge[69, 86] -> 
             RGBColor[
              0.6698066559091568, 0.7311665266400253, 0.7223401486920077], 
             UndirectedEdge[73, 94] -> 
             RGBColor[
              0.5596640855836605, 0.6479247657252469, 0.9608895041452028], 
             UndirectedEdge[61, 174] -> 
             RGBColor[
              0.47760823481537645`, 0.5852726801386519, 0.9524354964126697], 
             UndirectedEdge[175, 187] -> 
             RGBColor[
              0.3833258059807611, 0.5064392794504944, 0.9456461592887611], 
             UndirectedEdge[75, 134] -> 
             RGBColor[
              0.46530789697003894`, 0.5673696974533702, 0.9528406149946287], 
             UndirectedEdge[38, 178] -> 
             RGBColor[
              0.5615349686312382, 0.6544341602702044, 0.95893948840672], 
             UndirectedEdge[8, 179] -> 
             RGBColor[
              0.3988089479272937, 0.5198499987992394, 0.9466327314023892], 
             UndirectedEdge[29, 167] -> 
             RGBColor[
              0.6546592749848784, 0.7284727886522002, 0.9673566394833393], 
             UndirectedEdge[68, 185] -> 
             RGBColor[
              0.4343694544374703, 0.5376355135927626, 0.9506379556062372], 
             UndirectedEdge[79, 118] -> 
             RGBColor[
              0.6340932020983239, 0.7047536474741047, 0.9426149269508571], 
             UndirectedEdge[171, 173] -> 
             RGBColor[
              0.6135244923025545, 0.6923573404150871, 0.9652898352106429], 
             UndirectedEdge[80, 166] -> 
             RGBColor[
              0.6404551389851917, 0.7161609907884696, 0.9667859308782804], 
             UndirectedEdge[109, 132] -> 
             RGBColor[
              0.27602327007887173`, 0.40744833611198583`, 0.9390304889399326],
              UndirectedEdge[118, 197] -> 
             RGBColor[
              0.7810391548474273, 0.8286057267587227, 0.9530411521916654], 
             UndirectedEdge[111, 167] -> 
             RGBColor[
              0.7226321854228582, 0.30007211495328295`, 0.4282784044737895], 
             UndirectedEdge[113, 122] -> 
             RGBColor[
              0.6629061326570814, 0.6663066966696001, 0.6110852120963617], 
             UndirectedEdge[119, 190] -> 
             RGBColor[
              0.3933198072997528, 0.5150955810798934, 0.9462829682154589], 
             UndirectedEdge[19, 130] -> 
             RGBColor[
              0.5241406198431194, 0.6191849530633673, 0.9577672841964822], 
             UndirectedEdge[35, 167] -> 
             RGBColor[
              0.43140651241971684`, 0.5459137972359434, 0.9493095553192487], 
             UndirectedEdge[102, 112] -> 
             RGBColor[
              0.6149610901689316, 0.6874850083515867, 0.9578058376086604], 
             UndirectedEdge[134, 145] -> 
             RGBColor[
              0.47638352801732176`, 0.5790108879196321, 0.9534713557978437], 
             UndirectedEdge[109, 150] -> 
             RGBColor[
              0.28007292524349403`, 0.41170478045297126`, 0.9392611108106298],
              UndirectedEdge[147, 179] -> 
             RGBColor[
              0.6710511993047066, 0.6431526758481223, 0.6043807910706278], 
             UndirectedEdge[63, 102] -> 
             RGBColor[
              0.6650681486544369, 0.7331888494460973, 0.9609142680537077], 
             UndirectedEdge[62, 182] -> 
             RGBColor[
              0.3319084178098449, 0.4619041221299186, 0.9423698887811215], 
             UndirectedEdge[8, 99] -> 
             RGBColor[
              0.3546578048729918, 0.4816084977865762, 0.943819459608292], 
             UndirectedEdge[60, 123] -> 
             RGBColor[
              0.5108721677423641, 0.6137880661589608, 0.954636874912542], 
             UndirectedEdge[7, 97] -> 
             RGBColor[
              0.7478322957964438, 0.7995410082306471, 0.8720357670935868], 
             UndirectedEdge[130, 163] -> 
             RGBColor[
              0.42646863467723883`, 0.5413649686567485, 0.9490700413216558], 
             UndirectedEdge[127, 135] -> 
             RGBColor[
              0.583463863220657, 0.6718223323152657, 0.9609661709564603], 
             UndirectedEdge[37, 56] -> 
             RGBColor[
              0.4147076639417767, 0.532188948052155, 0.9480413718824516], 
             UndirectedEdge[100, 148] -> 
             RGBColor[
              0.7705588527772402, 0.8158787321594976, 0.7306403979286289], 
             UndirectedEdge[53, 135] -> 
             RGBColor[
              0.5188240646683264, 0.6161758420415913, 0.9567530905600796], 
             UndirectedEdge[103, 154] -> 
             RGBColor[
              0.579994187024169, 0.6694615010779044, 0.9603812500354449], 
             UndirectedEdge[63, 140] -> 
             RGBColor[
              0.4459846806929907, 0.5592285411880772, 0.9500484035223306], 
             UndirectedEdge[8, 75] -> 
             RGBColor[
              0.3247344045382745, 0.451705292828717, 0.9420586795517729], 
             UndirectedEdge[50, 53] -> 
             RGBColor[
              0.6492012250713584, 0.7185007160412178, 0.94611149210917], 
             UndirectedEdge[1, 167] -> 
             RGBColor[
              0.5581774584034638, 0.6521926321967001, 0.9583609206783732], 
             UndirectedEdge[27, 119] -> 
             RGBColor[
              0.32735050160067525`, 0.452901497677667, 0.9422645428866392], 
             UndirectedEdge[96, 126] -> 
             RGBColor[
              0.618716012419384, 0.6952364814333074, 0.9663652550520554], 
             UndirectedEdge[102, 106] -> 
             RGBColor[
              0.6678179656976136, 0.7355706027590738, 0.9610894839641313], 
             UndirectedEdge[16, 176] -> 
             RGBColor[
              0.6178942104591161, 0.647469568500798, 0.6281327705786807], 
             UndirectedEdge[40, 166] -> 
             RGBColor[
              0.7082488985510418, 0.7694700017956333, 0.947322252238031], 
             UndirectedEdge[33, 90] -> 
             RGBColor[
              0.330187409891754, 0.45394675397518436`, 0.9424970058876136], 
             UndirectedEdge[13, 161] -> 
             RGBColor[
              0.7617191764278759, 0.8137800769963964, 0.9768847069020641], 
             UndirectedEdge[11, 106] -> 
             RGBColor[
              0.3575175125526219, 0.4840854328455847, 0.9440016776528979], 
             UndirectedEdge[88, 167] -> 
             RGBColor[
              0.42956921900890965`, 0.5443224260285541, 0.9491924846077668], 
             UndirectedEdge[29, 159] -> 
             RGBColor[
              0.5463707488692635, 0.6368492835958347, 0.9598568544227395], 
             UndirectedEdge[156, 157] -> 
             RGBColor[
              0.4090653184153021, 0.5287335514157827, 0.9472862582605328], 
             UndirectedEdge[171, 183] -> 
             RGBColor[
              0.38393453947263656`, 0.506966533805322, 0.9456849472485815], 
             UndirectedEdge[100, 104] -> 
             RGBColor[
              0.6557867868467999, 0.7190369200969648, 0.7226176820679706], 
             UndirectedEdge[108, 180] -> 
             RGBColor[
              0.47226946370854245`, 0.5692455321540099, 0.9540984898422175], 
             UndirectedEdge[178, 179] -> 
             RGBColor[
              0.542533405593715, 0.6379759614134293, 0.9577287256123914], 
             UndirectedEdge[150, 151] -> 
             RGBColor[
              0.3954146826465016, 0.5157851180910689, 0.9466635606170641], 
             UndirectedEdge[2, 121] -> 
             RGBColor[
              0.49467376708588784`, 0.5995143822527491, 0.9536719912867084], 
             UndirectedEdge[12, 14] -> 
             RGBColor[
              0.5467175065906216, 0.642888927050089, 0.9574587512924795], 
             UndirectedEdge[43, 131] -> 
             RGBColor[
              0.6843752995558527, 0.7173358521526534, 0.6456510588823124], 
             UndirectedEdge[75, 76] -> 
             RGBColor[
              0.41268753355761, 0.5249965126229874, 0.9484613139108284], 
             UndirectedEdge[113, 138] -> 
             RGBColor[
              0.773510352907214, 0.7581451317530852, 0.6192273566819928], 
             UndirectedEdge[17, 20] -> 
             RGBColor[
              0.9104158388749346, 0.9314048936119992, 0.9913174695213469], 
             UndirectedEdge[86, 187] -> 
             RGBColor[
              0.3628418326281869, 0.48869709128693095`, 0.9443409386200015], 
             UndirectedEdge[8, 185] -> 
             RGBColor[
              0.30411288243802276`, 0.43003076562133474`, 0.9408843143749717],
              UndirectedEdge[4, 41] -> 
             RGBColor[
              0.4782402554844599, 0.5846112661799279, 0.9528097738890114], 
             UndirectedEdge[8, 107] -> 
             RGBColor[
              0.3697119129231051, 0.4946476095381135, 0.9447786940614202], 
             UndirectedEdge[149, 192] -> 
             RGBColor[
              0.35547340057814275`, 0.48231492579334595`, 0.9438714286454213],
              UndirectedEdge[11, 140] -> 
             RGBColor[
              0.41670794609334594`, 0.5338705051693314, 0.9481829158820411], 
             UndirectedEdge[94, 153] -> 
             RGBColor[
              0.5978828308133731, 0.6810279219132352, 0.9633247687957307], 
             UndirectedEdge[56, 79] -> 
             RGBColor[
              0.31342658973898696`, 0.4454096743507693, 0.9412100531567709], 
             UndirectedEdge[5, 15] -> 
             RGBColor[
              0.599074134555204, 0.6796192247405425, 0.9644712433278686], 
             UndirectedEdge[79, 128] -> 
             RGBColor[
              0.3851554562805004, 0.5071708413177451, 0.9458818933111385], 
             UndirectedEdge[109, 152] -> 
             RGBColor[
              0.4691869873378217, 0.5688660524023904, 0.9534701043369019], 
             UndirectedEdge[118, 192] -> 
             RGBColor[
              0.6713528087647019, 0.737512463274099, 0.9449712660227766], 
             UndirectedEdge[99, 107] -> 
             RGBColor[
              0.3405450689599137, 0.46938475526539963`, 0.9429202085553131], 
             UndirectedEdge[3, 189] -> 
             RGBColor[
              0.44592030579104747`, 0.5588778345024876, 0.9501257967270011], 
             UndirectedEdge[35, 138] -> 
             RGBColor[
              0.4643835512959476, 0.5726860429943391, 0.9519056286184593], 
             UndirectedEdge[12, 86] -> 
             RGBColor[
              0.46897181013122446`, 0.5768687188877396, 0.9521403635758048], 
             UndirectedEdge[16, 127] -> 
             RGBColor[
              0.36846775165703705`, 0.48974341404306676`, 0.9449213211132531],
              UndirectedEdge[37, 195] -> 
             RGBColor[
              0.551629928256272, 0.6468770522603381, 0.957845475120793], 
             UndirectedEdge[57, 71] -> 
             RGBColor[
              0.4009078894604191, 0.5126153598042668, 0.9477904806059152], 
             UndirectedEdge[58, 73] -> 
             RGBColor[
              0.3677773411446277, 0.49297198069800113`, 0.9446554248583703], 
             UndirectedEdge[35, 153] -> 
             RGBColor[
              0.36946728333289935`, 0.494435723682518, 0.9447631064802497], 
             UndirectedEdge[35, 122] -> 
             RGBColor[
              0.35377933104581505`, 0.4808476079108541, 0.9437634840328283], 
             UndirectedEdge[19, 44] -> 
             RGBColor[
              0.6106657800229963, 0.6933304830355471, 0.9635011400456177], 
             UndirectedEdge[181, 192] -> 
             RGBColor[
              0.3925330474395584, 0.5144141292326934, 0.9462328365728718], 
             UndirectedEdge[119, 128] -> 
             RGBColor[
              0.43372639515643063`, 0.5497269645535662, 0.9489589804692322], 
             UndirectedEdge[116, 153] -> 
             RGBColor[
              0.38873191640224086`, 0.5111217805785699, 0.945990631864382], 
             UndirectedEdge[186, 193] -> 
             RGBColor[
              0.4177746355170312, 0.5225561821549497, 0.9494598559628153], 
             UndirectedEdge[22, 119] -> 
             RGBColor[
              0.707235902328782, 0.48022716970640283`, 0.45247875605111365`], 
             UndirectedEdge[85, 109] -> 
             RGBColor[
              0.3714948938475938, 0.4901946134451716, 0.9453422612028781], 
             UndirectedEdge[98, 99] -> 
             RGBColor[
              0.33737118408118894`, 0.4666356957075406, 0.942717971417397], 
             UndirectedEdge[161, 175] -> 
             RGBColor[
              0.6012791023862141, 0.6827467438313355, 0.9640587476023993], 
             UndirectedEdge[54, 61] -> 
             RGBColor[
              0.4367888355711651, 0.5521336529392211, 0.9492220437777791], 
             UndirectedEdge[43, 154] -> 
             RGBColor[
              0.5341331431230381, 0.6307000762707969, 0.9571934683158204], 
             UndirectedEdge[87, 95] -> 
             RGBColor[
              0.5086904330031029, 0.6089977671528206, 0.9554305410207512], 
             UndirectedEdge[12, 108] -> 
             RGBColor[
              0.4153860617891128, 0.52402917607992, 0.9489612239665319], 
             UndirectedEdge[15, 48] -> 
             RGBColor[
              0.32551907258034296`, 0.4557784909729675, 0.9419844231188554], 
             UndirectedEdge[13, 187] -> 
             RGBColor[
              0.543765880022423, 0.6374726126155553, 0.9584721185884258], 
             UndirectedEdge[15, 28] -> 
             RGBColor[
              0.35275138722765736`, 0.4799572546415245, 0.9436979843617103], 
             UndirectedEdge[52, 134] -> 
             RGBColor[
              0.5214701777591364, 0.6199997018563359, 0.9562733133115701], 
             UndirectedEdge[66, 172] -> 
             RGBColor[
              0.39700507297971044`, 0.5178853852839893, 0.9466289157459509], 
             UndirectedEdge[101, 176] -> 
             RGBColor[
              0.8760219100944038, 0.8632432111867941, 0.6484765740332648], 
             UndirectedEdge[119, 192] -> 
             RGBColor[
              0.38931552573032324`, 0.5116272736454971, 0.946027818934702], 
             UndirectedEdge[168, 184] -> 
             RGBColor[
              0.38932668225838757`, 0.5060311211439207, 0.9466222621229358], 
             UndirectedEdge[16, 175] -> 
             RGBColor[
              0.3292146420588599, 0.4560855977693927, 0.9423258580884635], 
             UndirectedEdge[60, 104] -> 
             RGBColor[
              0.41260576397733295`, 0.5303462942139141, 0.9479135452397773], 
             UndirectedEdge[122, 136] -> 
             RGBColor[
              0.29954558907247153`, 0.4257683915735455, 0.9406045098013831], 
             UndirectedEdge[107, 157] -> 
             RGBColor[
              0.3645370631038007, 0.4901654147201465, 0.9444489572068742], 
             UndirectedEdge[86, 110] -> 
             RGBColor[
              0.5248650722120111, 0.62131157019454, 0.9571789415657572], 
             UndirectedEdge[5, 9] -> 
             RGBColor[
              0.7664515796471206, 0.8177152979959845, 0.9772931692765965], 
             UndirectedEdge[3, 77] -> 
             RGBColor[
              0.32067789499267396`, 0.44843756052357, 0.9417912019552885], 
             UndirectedEdge[84, 139] -> 
             RGBColor[
              0.4761129823593927, 0.5827433416016847, 0.952681240573191], 
             UndirectedEdge[96, 191] -> 
             RGBColor[
              0.5367390042317829, 0.6306291789992671, 0.9583448158367758], 
             UndirectedEdge[46, 151] -> 
             RGBColor[
              0.5157059201426476, 0.617712324115575, 0.9550174056081109], 
             UndirectedEdge[72, 191] -> 
             RGBColor[
              0.5236849778461405, 0.6193224374584672, 0.9575130248187049], 
             UndirectedEdge[111, 185] -> 
             RGBColor[
              0.6196797053466208, 0.2071480597277931, 0.42150889454518137`], 
             UndirectedEdge[23, 129] -> 
             RGBColor[
              0.6410317724939589, 0.707877686348672, 0.8948160483660467], 
             UndirectedEdge[101, 123] -> 
             RGBColor[
              0.6510941394309397, 0.725406195413314, 0.9671937510397606], 
             UndirectedEdge[122, 142] -> 
             RGBColor[
              0.36480128773517023`, 0.4903942728155227, 0.9444657933667404], 
             UndirectedEdge[18, 174] -> 
             RGBColor[
              0.4597292857540175, 0.5697868330838112, 0.9512962655882138], 
             UndirectedEdge[123, 135] -> 
             RGBColor[
              0.6079625513592719, 0.6917114709995167, 0.9628947974283837], 
             UndirectedEdge[171, 178] -> 
             RGBColor[
              0.5276589971390578, 0.6250924964195119, 0.9567809414585837], 
             UndirectedEdge[81, 173] -> 
             RGBColor[
              0.5970749468547394, 0.6781095709263835, 0.96424168472047], 
             UndirectedEdge[77, 102] -> 
             RGBColor[
              0.6071973496401111, 0.6793248248062158, 0.9573637040709689], 
             UndirectedEdge[31, 171] -> 
             RGBColor[
              0.46941163945301073`, 0.5782476016819267, 0.9518926595316968], 
             UndirectedEdge[109, 196] -> 
             RGBColor[
              0.5015311577656207, 0.5941335641653869, 0.9566938689716873], 
             UndirectedEdge[18, 153] -> 
             RGBColor[
              0.3856598542514583, 0.5084609147498953, 0.9457948827806522], 
             UndirectedEdge[97, 140] -> 
             RGBColor[
              0.749729516044948, 0.801081257097181, 0.8721851232212958], 
             UndirectedEdge[116, 167] -> 
             RGBColor[
              0.4506711454890584, 0.5625998541319953, 0.9505370807033809], 
             UndirectedEdge[128, 190] -> 
             RGBColor[
              0.4264193445163079, 0.5433979645521357, 0.9484933816638148], 
             UndirectedEdge[94, 126] -> 
             RGBColor[
              0.8382130305673658, 0.8741038978145381, 0.9843586365648157], 
             UndirectedEdge[41, 198] -> 
             RGBColor[
              0.4014700193666707, 0.5221548851306883, 0.9468022925214133], 
             UndirectedEdge[11, 77] -> 
             RGBColor[
              0.29689689649511936`, 0.42783965489272663`, 0.9402758977597356],
              UndirectedEdge[29, 122] -> 
             RGBColor[
              0.5770320936109766, 0.6634065993271109, 0.9618105681969189], 
             UndirectedEdge[84, 152] -> 
             RGBColor[
              0.6435367771629878, 0.7208517690423635, 0.9655178826091535], 
             UndirectedEdge[16, 64] -> 
             RGBColor[
              0.5404739246468528, 0.6268192828911376, 0.9602170011635216], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.6357306165893241, 0.7068331520265482, 0.9452531568482861], 
             UndirectedEdge[26, 121] -> 
             RGBColor[
              0.3966854383532761, 0.5180107215369198, 0.9464974232500787], 
             UndirectedEdge[40, 74] -> 
             RGBColor[
              0.7396939981390787, 0.7950398659648015, 0.9497863100032848], 
             UndirectedEdge[78, 91] -> 
             RGBColor[
              0.4108395648869375, 0.5268855365003324, 0.9480073209646985], 
             UndirectedEdge[139, 152] -> 
             RGBColor[
              0.5166752020561728, 0.6150341753418976, 0.9563116107685714], 
             UndirectedEdge[40, 196] -> 
             RGBColor[
              0.8567443808619996, 0.8884362933235486, 0.9601156216355651], 
             UndirectedEdge[6, 86] -> 
             RGBColor[
              0.3086971996524857, 0.4383082315082249, 0.941018731406603], 
             UndirectedEdge[82, 180] -> 
             RGBColor[
              0.44211272731644274`, 0.5375488901583911, 0.9523811083175808], 
             UndirectedEdge[44, 90] -> 
             RGBColor[
              0.36075927023068477`, 0.47962834791975784`, 0.9446655669484446],
              UndirectedEdge[4, 66] -> 
             RGBColor[
              0.4639597182259998, 0.5722421825673221, 0.9518998306826856], 
             UndirectedEdge[131, 143] -> 
             RGBColor[
              0.6938237479563527, 0.7255196232643418, 0.6462531056594574], 
             UndirectedEdge[22, 144] -> 
             RGBColor[
              0.6708363031700302, 0.4476322251881214, 0.45019849003182116`], 
             UndirectedEdge[35, 160] -> 
             RGBColor[
              0.3127799221286528, 0.4441580228281276, 0.9411941687552683], 
             UndirectedEdge[76, 174] -> 
             RGBColor[
              0.558624933987456, 0.6525559130343304, 0.9583961475955021], 
             UndirectedEdge[85, 196] -> 
             RGBColor[
              0.6187510737973393, 0.6997386755883541, 0.9642441743052955], 
             UndirectedEdge[6, 137] -> 
             RGBColor[
              0.5979134764876726, 0.6725300140986874, 0.9657185554262298], 
             UndirectedEdge[123, 177] -> 
             RGBColor[
              0.44485193565434844`, 0.5580584725974012, 0.9500284311845677], 
             UndirectedEdge[29, 113] -> 
             RGBColor[
              0.8619340327472871, 0.8278833297870407, 0.627588709444753], 
             UndirectedEdge[96, 174] -> 
             RGBColor[
              0.4524552441679503, 0.5634864238659203, 0.9508327700905319], 
             UndirectedEdge[74, 158] -> 
             RGBColor[
              0.6640255506286363, 0.7355052952632306, 0.9684846959007584], 
             UndirectedEdge[46, 121] -> 
             RGBColor[
              0.4792043561912326, 0.5869556175994488, 0.9524541825947619], 
             UndirectedEdge[32, 165] -> 
             RGBColor[
              0.3731441442225565, 0.4976204357807372, 0.9449973928048183], 
             UndirectedEdge[32, 148] -> 
             RGBColor[
              0.47873545180488314`, 0.5865103364004653, 0.9524351188617607], 
             UndirectedEdge[27, 190] -> 
             RGBColor[
              0.32004345096055253`, 0.4465724976762366, 0.9417989440812218], 
             UndirectedEdge[100, 123] -> 
             RGBColor[
              0.7540531906118311, 0.8024786920420115, 0.7293410117407353], 
             UndirectedEdge[45, 172] -> 
             RGBColor[
              0.7280944413655043, 0.7842091047483235, 0.899417600159789], 
             UndirectedEdge[85, 99] -> 
             RGBColor[
              0.4071028853945563, 0.5260726841910006, 0.9474267703193356], 
             UndirectedEdge[106, 112] -> 
             RGBColor[
              0.3366871886667614, 0.4637396277698198, 0.9427587348481401], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.4866162278939301, 0.5898782001690634, 0.9540239921906479], 
             UndirectedEdge[43, 197] -> 
             RGBColor[
              0.4971848038816359, 0.6011466842164208, 0.9539819231417713], 
             UndirectedEdge[26, 164] -> 
             RGBColor[
              0.36723598705052574`, 0.4925030869909379, 0.9446209302541948], 
             UndirectedEdge[100, 130] -> 
             RGBColor[
              0.6514440954388513, 0.7152754990694165, 0.7223409696115473], 
             UndirectedEdge[46, 196] -> 
             RGBColor[
              0.6476203426893855, 0.7231760486206599, 0.9665168689040938], 
             UndirectedEdge[156, 181] -> 
             RGBColor[
              0.42585879449568786`, 0.5432792163319629, 0.9483563237064873], 
             UndirectedEdge[62, 96] -> 
             RGBColor[
              0.33387452974928833`, 0.4636070694722051, 0.9424951676953383], 
             UndirectedEdge[54, 58] -> 
             RGBColor[
              0.43924611863268803`, 0.5542620280204744, 0.9493786196815692], 
             UndirectedEdge[179, 183] -> 
             RGBColor[
              0.3988089479272937, 0.5198499987992394, 0.9466327314023892], 
             UndirectedEdge[65, 198] -> 
             RGBColor[
              0.42743696509544066`, 0.5446461483843079, 0.9484568833415821], 
             UndirectedEdge[4, 80] -> 
             RGBColor[
              0.7155767297898439, 0.7771893981307927, 0.9726883620243651], 
             UndirectedEdge[159, 197] -> 
             RGBColor[
              0.4570291948617832, 0.5663659139630179, 0.9514232432432371], 
             UndirectedEdge[78, 136] -> 
             RGBColor[
              0.2575337498947376, 0.38801467809517215`, 0.93797753811824], 
             UndirectedEdge[153, 188] -> 
             RGBColor[
              0.5788663602662613, 0.6661721105913023, 0.9614293847306156], 
             UndirectedEdge[35, 174] -> 
             RGBColor[
              0.4435367148354585, 0.5557616420164339, 0.9502644892878114], 
             UndirectedEdge[82, 130] -> 
             RGBColor[
              0.2442961606505979, 0.3740161349523318, 0.9372267891701942], 
             UndirectedEdge[124, 176] -> 
             RGBColor[
              0.7075361128122566, 0.7285981899842005, 0.6337170590132185], 
             UndirectedEdge[6, 186] -> 
             RGBColor[
              0.2408477227052827, 0.37047660556382667`, 0.9370272935545656], 
             UndirectedEdge[1, 144] -> 
             RGBColor[
              0.43726221050098657`, 0.5480313335300154, 0.9501151984491883], 
             UndirectedEdge[43, 67] -> 
             RGBColor[
              0.37321149831525696`, 0.49767877451051923`, 0.9450016845480462],
              UndirectedEdge[24, 119] -> 
             RGBColor[
              0.47644476048606244`, 0.5844076579685886, 0.9523219266705091], 
             UndirectedEdge[93, 139] -> 
             RGBColor[
              0.32871127699487046`, 0.4590817703370878, 0.9421681158448548], 
             UndirectedEdge[38, 146] -> 
             RGBColor[
              0.3642493115174482, 0.4869535151250499, 0.944539099558841], 
             UndirectedEdge[110, 127] -> 
             RGBColor[
              0.5846021551627624, 0.6727115746317776, 0.9610796252593065], 
             UndirectedEdge[41, 81] -> 
             RGBColor[
              0.35279314773981224`, 0.47999342549820867`, 0.9437006453046175],
              UndirectedEdge[85, 194] -> 
             RGBColor[
              0.4347117939059725, 0.5499861330794993, 0.9491859855560838], 
             UndirectedEdge[52, 70] -> 
             RGBColor[
              0.3949755545911338, 0.5165297061634091, 0.9463884709687459], 
             UndirectedEdge[149, 170] -> 
             RGBColor[
              0.5477140326345038, 0.6385892935375994, 0.9596984345468249], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.3610823451510935, 0.4871731116686847, 0.9442288256338147], 
             UndirectedEdge[92, 155] -> 
             RGBColor[
              0.5433684935919757, 0.6253432299344484, 0.9610756362926427], 
             UndirectedEdge[57, 141] -> 
             RGBColor[
              0.4829055404617162, 0.589800880525438, 0.9527896306668275], 
             UndirectedEdge[149, 159] -> 
             RGBColor[
              0.32481205583642964`, 0.45575761006206983`, 0.9419177148712419],
              UndirectedEdge[142, 167] -> 
             RGBColor[
              0.4424284691090721, 0.555460462140612, 0.9500118646531608], 
             UndirectedEdge[117, 173] -> 
             RGBColor[
              0.7143152191271582, 0.7760647328580225, 0.9727047411538614], 
             UndirectedEdge[99, 179] -> 
             RGBColor[
              0.36964210396410224`, 0.4945871445265255, 0.9447742458962822], 
             UndirectedEdge[5, 11] -> 
             RGBColor[
              0.5874747444577978, 0.6695724160404671, 0.9637321404477998], 
             UndirectedEdge[29, 188] -> 
             RGBColor[
              0.7622063080693826, 0.814160627937079, 0.9769332596315854], 
             UndirectedEdge[46, 178] -> 
             RGBColor[
              0.6088634559162154, 0.6928988741102101, 0.9626539446342433], 
             UndirectedEdge[101, 137] -> 
             RGBColor[
              0.8560746451767602, 0.888338834882288, 0.9860642648939149], 
             UndirectedEdge[3, 20] -> 
             RGBColor[
              0.6313768225667522, 0.7062143243812844, 0.9671666111789878], 
             UndirectedEdge[186, 199] -> 
             RGBColor[
              0.24665524598580352`, 0.3765806807498973, 0.9373580234139305], 
             UndirectedEdge[156, 179] -> 
             RGBColor[
              0.429224467325717, 0.546194392973699, 0.948570781403069], 
             UndirectedEdge[67, 87] -> 
             RGBColor[
              0.5064093814526178, 0.6070220349487748, 0.955285194433009], 
             UndirectedEdge[3, 10] -> 
             RGBColor[
              0.373263953551242, 0.49772420859945266`, 0.9450050269492989], 
             UndirectedEdge[55, 185] -> 
             RGBColor[
              0.5671004557054226, 0.6420519282136913, 0.9636746971887677], 
             UndirectedEdge[5, 28] -> 
             RGBColor[
              0.6031357806782487, 0.6831372184680539, 0.9647300478272562], 
             UndirectedEdge[37, 170] -> 
             RGBColor[
              0.6342662931135439, 0.7121247918553153, 0.9656090564036925], 
             UndirectedEdge[49, 154] -> 
             RGBColor[
              0.4905587658025571, 0.5929581407476809, 0.9544169475242683], 
             UndirectedEdge[24, 89] -> 
             RGBColor[
              0.4383564010211146, 0.5514174353766605, 0.9498949700856165], 
             UndirectedEdge[73, 115] -> 
             RGBColor[
              0.38950939229297576`, 0.5117951911180499, 0.9460401719406448], 
             UndirectedEdge[153, 174] -> 
             RGBColor[
              0.48344952959749876`, 0.5903321160869139, 0.9528076985509324], 
             UndirectedEdge[119, 183] -> 
             RGBColor[
              0.39222575338802934`, 0.514147966570307, 0.9462132560676377], 
             UndirectedEdge[4, 168] -> 
             RGBColor[
              0.4338418574715604, 0.5421705457677645, 0.9501266597801764], 
             UndirectedEdge[144, 181] -> 
             RGBColor[
              0.3492449809109831, 0.47531901989109804`, 0.9435331856301074], 
             UndirectedEdge[53, 123] -> 
             RGBColor[
              0.4257450249562098, 0.5415090268919284, 0.94881095573046], 
             UndirectedEdge[110, 162] -> 
             RGBColor[
              0.7338907828289636, 0.7920403244133012, 0.9741110326992483], 
             UndirectedEdge[127, 176] -> 
             RGBColor[
              0.7153125941720044, 0.7349925329390828, 0.6343068591203449], 
             UndirectedEdge[9, 102] -> 
             RGBColor[
              0.814768249244115, 0.8559736953828689, 0.9726098092422151], 
             UndirectedEdge[27, 195] -> 
             RGBColor[
              0.4256434365902122, 0.5341308183911166, 0.9496072194189691], 
             UndirectedEdge[60, 130] -> 
             RGBColor[
              0.4082630725693843, 0.5265848731863657, 0.9476368327833542], 
             UndirectedEdge[89, 122] -> 
             RGBColor[
              0.35122716626537537`, 0.4786370510535689, 0.9436008623498093], 
             UndirectedEdge[5, 106] -> 
             RGBColor[
              0.6195012961006193, 0.6973122053721894, 0.9657728439985127], 
             UndirectedEdge[83, 199] -> 
             RGBColor[
              0.6387077296130492, 0.7028413789856132, 0.8083762373646417], 
             UndirectedEdge[118, 125] -> 
             RGBColor[
              0.6570658492810484, 0.7251378170528211, 0.9440609135979403], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.5364943477419447, 0.6322283148011021, 0.9575627064816946], 
             UndirectedEdge[5, 112] -> 
             RGBColor[
              0.5666444205719373, 0.6492266109647022, 0.9624891976430419], 
             UndirectedEdge[109, 146] -> 
             RGBColor[
              0.26548861387866063`, 0.39637574450978275`, 0.9384305558539577],
              UndirectedEdge[164, 184] -> 
             RGBColor[
              0.4330328331949844, 0.5478722519319404, 0.9492612668601988], 
             UndirectedEdge[51, 164] -> 
             RGBColor[
              0.45756611987408635`, 0.5677894792700053, 0.9511926170559679], 
             UndirectedEdge[45, 168] -> 
             RGBColor[
              0.6268513893805991, 0.6929345898620358, 0.893001269305494], 
             UndirectedEdge[148, 165] -> 
             RGBColor[
              0.44230352839564707`, 0.5549548354650978, 0.950113708917609], 
             UndirectedEdge[166, 184] -> 
             RGBColor[
              0.4824027886849299, 0.5906340259712182, 0.9524070767678807], 
             UndirectedEdge[21, 132] -> 
             RGBColor[
              0.342781131818483, 0.47030685878068834`, 0.9430998402403169], 
             UndirectedEdge[96, 157] -> 
             RGBColor[
              0.3604332382167085, 0.4866108878671835, 0.9441874651139385], 
             UndirectedEdge[42, 102] -> 
             RGBColor[
              0.6018173273796255, 0.6736700802973323, 0.957057319762264], 
             UndirectedEdge[117, 120] -> 
             RGBColor[
              0.48686129987000354`, 0.592524051168816, 0.9532359593622362], 
             UndirectedEdge[25, 129] -> 
             RGBColor[
              0.3361581794786777, 0.46423333907684705`, 0.9426901726716194], 
             UndirectedEdge[57, 90] -> 
             RGBColor[
              0.3992669028376371, 0.5108905788191617, 0.9476970288453699], 
             UndirectedEdge[51, 184] -> 
             RGBColor[
              0.5375424909555111, 0.6354402360277622, 0.9567364604524939], 
             UndirectedEdge[95, 103] -> 
             RGBColor[
              0.4213535937668732, 0.5384159315216724, 0.948334812855413], 
             UndirectedEdge[47, 105] -> 
             RGBColor[
              0.6697939351538558, 0.7354972477712983, 0.9351666840884045], 
             UndirectedEdge[127, 177] -> 
             RGBColor[
              0.42035324751573355`, 0.5381693339131501, 0.9480998047126443], 
             UndirectedEdge[73, 153] -> 
             RGBColor[
              0.37116135286522706`, 0.4959030415650098, 0.9448710510928429], 
             UndirectedEdge[137, 199] -> 
             RGBColor[
              0.6037209997681934, 0.6786340892847581, 0.9660492852855946], 
             UndirectedEdge[138, 185] -> 
             RGBColor[
              0.4118068750304492, 0.51934850778001, 0.9488410218276668], 
             UndirectedEdge[88, 136] -> 
             RGBColor[
              0.2734834331867083, 0.4031946620673399, 0.9389438522742019], 
             UndirectedEdge[55, 76] -> 
             RGBColor[
              0.7347653511229184, 0.792183734445917, 0.9748709622872508], 
             UndirectedEdge[135, 176] -> 
             RGBColor[
              0.832890322022736, 0.8295484867729969, 0.6441776204218879], 
             UndirectedEdge[69, 123] -> 
             RGBColor[
              0.7540424269985231, 0.802455669761514, 0.7281694588574803], 
             UndirectedEdge[2, 40] -> 
             RGBColor[
              0.7710467967306741, 0.8204934802889392, 0.9522545171575008], 
             UndirectedEdge[105, 174] -> 
             RGBColor[
              0.7666356593588857, 0.8165473814753833, 0.9421190972502199], 
             UndirectedEdge[89, 138] -> 
             RGBColor[
              0.4618313865155079, 0.570475486137054, 0.9517430069354403], 
             UndirectedEdge[37, 128] -> 
             RGBColor[
              0.48643653048329016`, 0.5939501150191309, 0.9527132120368191], 
             UndirectedEdge[88, 153] -> 
             RGBColor[
              0.3676299899220921, 0.4928443524751286, 0.9446460357687678], 
             UndirectedEdge[113, 197] -> 
             RGBColor[
              0.7725924787398067, 0.7573999601542238, 0.6191550982652505], 
             UndirectedEdge[31, 178] -> 
             RGBColor[
              0.6130262064829788, 0.6962783825500847, 0.9629816516075167], 
             UndirectedEdge[82, 177] -> 
             RGBColor[
              0.2768736798307708, 0.4022331446724743, 0.9393025998851856], 
             UndirectedEdge[87, 108] -> 
             RGBColor[
              0.4513144805679856, 0.5528753400608363, 0.9520098929582179], 
             UndirectedEdge[64, 86] -> 
             RGBColor[
              0.57815522540899, 0.662942242892185, 0.9624904060116366], 
             UndirectedEdge[116, 157] -> 
             RGBColor[
              0.3707793419535582, 0.49557216291374895`, 0.9448467096953502], 
             UndirectedEdge[120, 168] -> 
             RGBColor[
              0.32687043811103783`, 0.4535554177492756, 0.942194785722209], 
             UndirectedEdge[18, 54] -> 
             RGBColor[
              0.41890988650980615`, 0.5366478058843803, 0.9480828129533232], 
             UndirectedEdge[161, 176] -> 
             RGBColor[
              0.8899586707864702, 0.8741307145627408, 0.6498656600926165], 
             UndirectedEdge[168, 172] -> 
             RGBColor[
              0.36688721222527104`, 0.48781374848443165`, 0.9448557448434417],
              UndirectedEdge[142, 157] -> 
             RGBColor[
              0.3625366655735719, 0.4884327709223656, 0.9443214936451301], 
             UndirectedEdge[121, 171] -> 
             RGBColor[
              0.39799989741407504`, 0.5191492399087506, 0.9465811794191024], 
             UndirectedEdge[47, 94] -> 
             RGBColor[
              0.5751105381109023, 0.6613037065430661, 0.961873738441477], 
             UndirectedEdge[70, 93] -> 
             RGBColor[
              0.3600767670504351, 0.48624898134784966`, 0.9441666971357816], 
             UndirectedEdge[32, 163] -> 
             RGBColor[
              0.47642400784253724`, 0.5846338020624691, 0.9522531535259466], 
             UndirectedEdge[35, 142] -> 
             RGBColor[
              0.34057642526021425`, 0.46941191451670644`, 0.942922206551041], 
             UndirectedEdge[12, 193] -> 
             RGBColor[
              0.6081839531270359, 0.6927901573802109, 0.9622976151228386], 
             UndirectedEdge[35, 94] -> 
             RGBColor[
              0.5579700160513328, 0.6464574478427552, 0.9607815595326097], 
             UndirectedEdge[116, 174] -> 
             RGBColor[
              0.4628013479048, 0.5724476989124858, 0.9514920146719437], 
             UndirectedEdge[112, 140] -> 
             RGBColor[
              0.39587762220748546`, 0.5135247000935665, 0.9469399730772832], 
             UndirectedEdge[86, 176] -> 
             RGBColor[
              0.6555755112212531, 0.6835925285018454, 0.6304061754267957], 
             UndirectedEdge[61, 73] -> 
             RGBColor[
              0.36532005808310475`, 0.4908436056167478, 0.9444988489545801], 
             UndirectedEdge[33, 66] -> 
             RGBColor[
              0.37372590136616624`, 0.4981243245785678, 0.9450344618555815], 
             UndirectedEdge[48, 106] -> 
             RGBColor[
              0.3459462341257583, 0.47347147160461445`, 0.9432860237894996], 
             UndirectedEdge[86, 199] -> 
             RGBColor[
              0.3145047229330066, 0.44441230669429554`, 0.9413494612659679], 
             UndirectedEdge[10, 59] -> 
             RGBColor[
              0.3585390986628516, 0.4849702793878548, 0.9440667722164886], 
             UndirectedEdge[1, 113] -> 
             RGBColor[
              0.7654522161658723, 0.7516031733315406, 0.6185929906397868], 
             UndirectedEdge[125, 128] -> 
             RGBColor[
              0.40812810346322476`, 0.5275550108964615, 0.9473278799582217], 
             UndirectedEdge[53, 165] -> 
             RGBColor[
              0.33665937953929237`, 0.4660191663896863, 0.9426726158614114], 
             UndirectedEdge[87, 143] -> 
             RGBColor[
              0.5396390536149109, 0.6358039068038679, 0.957402559759345], 
             UndirectedEdge[61, 105] -> 
             RGBColor[
              0.6867249330742042, 0.7501620271932055, 0.9362455123043956], 
             UndirectedEdge[29, 47] -> 
             RGBColor[
              0.5699477531955901, 0.6572704997286056, 0.9613591602900868], 
             UndirectedEdge[24, 27] -> 
             RGBColor[
              0.4031684041468622, 0.5158845745649319, 0.947837902536272], 
             UndirectedEdge[98, 117] -> 
             RGBColor[
              0.46743864550543746`, 0.5757011241692218, 0.9519983650009048], 
             UndirectedEdge[1, 88] -> 
             RGBColor[
              0.45448812114379866`, 0.5645527133654052, 0.9511541918647715], 
             UndirectedEdge[190, 195] -> 
             RGBColor[
              0.49161274228928975`, 0.596324901793343, 0.9536256447477887], 
             UndirectedEdge[4, 173] -> 
             RGBColor[
              0.722522054599387, 0.7827274116081027, 0.9733508133048641], 
             UndirectedEdge[81, 164] -> 
             RGBColor[
              0.35210090066350963`, 0.4793938358740651, 0.9436565359330455], 
             UndirectedEdge[82, 123] -> 
             RGBColor[
              0.3469052558235777, 0.4612193279249269, 0.944226831299382], 
             UndirectedEdge[43, 87] -> 
             RGBColor[
              0.530190605214411, 0.6276201356921796, 0.9568005129821999], 
             UndirectedEdge[38, 171] -> 
             RGBColor[
              0.4179204016012702, 0.5364033794020464, 0.9478504963309002], 
             UndirectedEdge[46, 85] -> 
             RGBColor[
              0.5175840787713586, 0.6192370979004446, 0.9551652611352847], 
             UndirectedEdge[64, 69] -> 
             RGBColor[
              0.901549911849724, 0.9196423999253337, 0.7415365124358253], 
             UndirectedEdge[60, 82] -> 
             RGBColor[
              0.3428939119187865, 0.4579627382340339, 0.94391104361316], 
             UndirectedEdge[77, 189] -> 
             RGBColor[
              0.3935452428788118, 0.5097739402505086, 0.9469254161889988], 
             UndirectedEdge[101, 187] -> 
             RGBColor[
              0.5832882315013375, 0.6683477739718797, 0.9624113372264707], 
             UndirectedEdge[64, 161] -> 
             RGBColor[
              0.8125383849742069, 0.8534804289530804, 0.9819498906774573], 
             UndirectedEdge[7, 160] -> 
             RGBColor[
              0.4000679332331649, 0.518382832567975, 0.9471372928499434], 
             UndirectedEdge[16, 83] -> 
             RGBColor[
              0.6329336753863284, 0.6967724818971468, 0.8080474135183777], 
             UndirectedEdge[13, 124] -> 
             RGBColor[
              0.5792966184536624, 0.6682475524178562, 0.960736105822666], 
             UndirectedEdge[46, 171] -> 
             RGBColor[
              0.4652488888862473, 0.5748680932420521, 0.9515649525584234], 
             UndirectedEdge[1, 197] -> 
             RGBColor[
              0.5902366231122872, 0.6782197063562345, 0.9608847355608416], 
             UndirectedEdge[26, 80] -> 
             RGBColor[
              0.6052647084322123, 0.6856808085659463, 0.9645436277611203], 
             UndirectedEdge[23, 43] -> 
             RGBColor[
              0.692465101730237, 0.7537783640302254, 0.8980438417893986], 
             UndirectedEdge[13, 86] -> 
             RGBColor[
              0.527336016862659, 0.623241890935501, 0.9574252222362432], 
             UndirectedEdge[31, 146] -> 
             RGBColor[
              0.41574054936918875`, 0.5287977374049302, 0.9485812627596376], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.5499755021935762, 0.6411483014254908, 0.9595884848014068], 
             UndirectedEdge[124, 127] -> 
             RGBColor[
              0.45810965401017767`, 0.5708720355264694, 0.950505609547791], 
             UndirectedEdge[60, 163] -> 
             RGBColor[
              0.5250663859454274, 0.6253115719384505, 0.9557542957646217], 
             UndirectedEdge[4, 184] -> 
             RGBColor[
              0.5575243794895821, 0.6516624333135412, 0.9583095079139655], 
             UndirectedEdge[144, 192] -> 
             RGBColor[
              0.33471612699219566`, 0.46273485686807503`, 0.9426074199057632],
              UndirectedEdge[38, 192] -> 
             RGBColor[
              0.4149002833071108, 0.5337875047312046, 0.9476580570637821], 
             UndirectedEdge[49, 108] -> 
             RGBColor[
              0.27454222011014395`, 0.4057901440994646, 0.9389498622817032], 
             UndirectedEdge[83, 165] -> 
             RGBColor[
              0.6657651018209143, 0.7286947245174407, 0.8100117886629167], 
             UndirectedEdge[183, 192] -> 
             RGBColor[
              0.3809144211784771, 0.5043506591344802, 0.9454925079814634], 
             UndirectedEdge[79, 159] -> 
             RGBColor[
              0.3100832421126799, 0.4425138346783999, 0.9409970180024289], 
             UndirectedEdge[81, 166] -> 
             RGBColor[
              0.4014708561534551, 0.5221556099133429, 0.9468023458407273], 
             UndirectedEdge[118, 119] -> 
             RGBColor[
              0.6826641409742542, 0.7473097707099257, 0.9456920141089509], 
             UndirectedEdge[47, 153] -> 
             RGBColor[
              0.38660780539246886`, 0.509281982382829, 0.945855285389117], 
             UndirectedEdge[74, 184] -> 
             RGBColor[
              0.5138478882729669, 0.6162038901403863, 0.9548711345331347], 
             UndirectedEdge[149, 190] -> 
             RGBColor[
              0.3594776821475723, 0.48578323322774225`, 0.9441265779261783], 
             UndirectedEdge[55, 139] -> 
             RGBColor[
              0.6295256013117801, 0.7039197125726111, 0.9673668397373001], 
             UndirectedEdge[22, 138] -> 
             RGBColor[
              0.7734311610225022, 0.5349212548048417, 0.457426353717418], 
             UndirectedEdge[113, 144] -> 
             RGBColor[
              0.6196180661285061, 0.6272115873280047, 0.6083855611535973], 
             UndirectedEdge[80, 172] -> 
             RGBColor[
              0.6486220845435545, 0.7228326008474598, 0.9674174470876304], 
             UndirectedEdge[8, 156] -> 
             RGBColor[
              0.4142401682346065, 0.5332157462337497, 0.9476159951150789], 
             UndirectedEdge[22, 118] -> 
             RGBColor[
              0.8952607576850344, 0.6308172961254708, 0.45177438744316334`], 
             UndirectedEdge[100, 163] -> 
             RGBColor[
              0.7682474088148944, 0.8140021978215014, 0.730458432592815], 
             UndirectedEdge[12, 154] -> 
             RGBColor[
              0.631402607481526, 0.7111971727281362, 0.9644283092090972], 
             UndirectedEdge[67, 129] -> 
             RGBColor[
              0.3217781690789788, 0.4517780968289658, 0.9417738911246945], 
             UndirectedEdge[49, 129] -> 
             RGBColor[
              0.3019850155202911, 0.4346342620492545, 0.9405126888823334], 
             UndirectedEdge[127, 175] -> 
             RGBColor[
              0.42663302577174833`, 0.5436085622076776, 0.9484999466301277], 
             UndirectedEdge[30, 198] -> 
             RGBColor[
              0.3447093390010513, 0.4667206221518442, 0.9434151647209488], 
             UndirectedEdge[5, 140] -> 
             RGBColor[
              0.6786917296413434, 0.7470972776959361, 0.9699540822276559], 
             UndirectedEdge[147, 156] -> 
             RGBColor[
              0.6864824196120195, 0.6565184232826324, 0.6053640547833175], 
             UndirectedEdge[122, 159] -> 
             RGBColor[
              0.3473428487790579, 0.4752726504783942, 0.9433533570743483], 
             UndirectedEdge[82, 110] -> 
             RGBColor[
              0.4411225874777997, 0.5367753853911017, 0.9522824204318479], 
             UndirectedEdge[83, 176] -> 
             RGBColor[
              0.9797785179012959, 0.9420216007931629, 0.49743295152546957`], 
             UndirectedEdge[10, 77] -> 
             RGBColor[
              0.32088889063900633`, 0.4486203143474735, 0.9418046464112966], 
             UndirectedEdge[104, 130] -> 
             RGBColor[
              0.31400801270914436`, 0.4463996909322121, 0.9412292907968115], 
             UndirectedEdge[30, 66] -> 
             RGBColor[
              0.28339973864208523`, 0.41361732783102073`, 0.9395085712000263],
              UndirectedEdge[85, 132] -> 
             RGBColor[
              0.3932431861105902, 0.5130534475349531, 0.9465807942735407], 
             UndirectedEdge[24, 195] -> 
             RGBColor[
              0.5747376954755994, 0.6656369786820383, 0.9596646032028389], 
             UndirectedEdge[50, 123] -> 
             RGBColor[
              0.7383397117623038, 0.7940363449991432, 0.9522531989774741], 
             UndirectedEdge[42, 153] -> 
             RGBColor[
              0.33346144282720336`, 0.45851518750341097`, 0.9426421842716235],
              UndirectedEdge[127, 161] -> 
             RGBColor[
              0.6405322119843911, 0.7164045601050095, 0.9666542106271889], 
             UndirectedEdge[7, 18] -> 
             RGBColor[
              0.43303505059393016`, 0.5481152504192626, 0.9491947976122064], 
             UndirectedEdge[65, 66] -> 
             RGBColor[
              0.36612736473647467`, 0.4915428540634845, 0.9445502898206597], 
             UndirectedEdge[150, 152] -> 
             RGBColor[
              0.4949849347654404, 0.5959813308331572, 0.9549392592782617], 
             UndirectedEdge[25, 87] -> 
             RGBColor[
              0.5207893918523167, 0.6194772771966561, 0.9562014759799339], 
             UndirectedEdge[69, 82] -> 
             RGBColor[
              0.5860641711749454, 0.6466303418365871, 0.7174436275580982], 
             UndirectedEdge[1, 159] -> 
             RGBColor[
              0.44988893228784876`, 0.5605691271403347, 0.9508611356177734], 
             UndirectedEdge[23, 131] -> 
             RGBColor[
              0.9798476792090396, 0.9528373409289549, 0.5971778975744737], 
             UndirectedEdge[126, 160] -> 
             RGBColor[
              0.5930229366446859, 0.6718044727999106, 0.9647712457874742], 
             UndirectedEdge[67, 131] -> 
             RGBColor[
              0.6605940757940595, 0.6967377514092488, 0.6441357403331214], 
             UndirectedEdge[142, 174] -> 
             RGBColor[
              0.45455867152481366`, 0.5653083069211025, 0.9509667986217236], 
             UndirectedEdge[22, 122] -> 
             RGBColor[
              0.6996950141890805, 0.47369563141585164`, 0.45199825732699744`],
              UndirectedEdge[32, 176] -> 
             RGBColor[
              0.6871575603029381, 0.7109473120564593, 0.6324185556673712], 
             UndirectedEdge[47, 160] -> 
             RGBColor[
              0.3299204441882223, 0.4590042815284386, 0.9422863476641355], 
             UndirectedEdge[79, 125] -> 
             RGBColor[
              0.32645762737073936`, 0.45669650418839813`, 0.942040379351772], 
             UndirectedEdge[47, 111] -> 
             RGBColor[
              0.6661578375633327, 0.25260392233755324`, 0.4242800850116212], 
             UndirectedEdge[3, 186] -> 
             RGBColor[
              0.2918829867394632, 0.41817228624681463`, 0.9401513745285175], 
             UndirectedEdge[105, 160] -> 
             RGBColor[
              0.6358788666520799, 0.7049437622870771, 0.9330487767176767], 
             UndirectedEdge[9, 189] -> 
             RGBColor[
              0.6011161424828156, 0.6864228108271617, 0.962171521360245], 
             UndirectedEdge[64, 175] -> 
             RGBColor[
              0.5986391987615642, 0.6806844310557485, 0.9637956266803962], 
             UndirectedEdge[100, 165] -> 
             RGBColor[
              0.6649675451949136, 0.7269888315397695, 0.7232026718716865], 
             UndirectedEdge[101, 161] -> 
             RGBColor[
              0.8012415279067904, 0.8446552383527208, 0.9808239255401088], 
             UndirectedEdge[123, 187] -> 
             RGBColor[
              0.4470776037175531, 0.5599862344084195, 0.9501702487854742], 
             UndirectedEdge[90, 198] -> 
             RGBColor[
              0.34365099063379834`, 0.46560823091469916`, 0.9433548933471199],
              UndirectedEdge[146, 171] -> 
             RGBColor[
              0.33037334002526786`, 0.45761185127435744`, 0.9423805526107047],
              UndirectedEdge[62, 157] -> 
             RGBColor[
              0.34691624073015415`, 0.4749031440283778, 0.9433261739867068], 
             UndirectedEdge[2, 164] -> 
             RGBColor[
              0.4652243157831375, 0.5740067477067672, 0.9517954982908244], 
             UndirectedEdge[94, 142] -> 
             RGBColor[
              0.568991972740688, 0.6560041127474238, 0.9614838688665219], 
             UndirectedEdge[12, 175] -> 
             RGBColor[
              0.4894557834837987, 0.594610907051303, 0.9534455842445644], 
             UndirectedEdge[23, 64] -> 
             RGBColor[
              0.8989179813664906, 0.9203489844920101, 0.9156287251185069], 
             UndirectedEdge[73, 160] -> 
             RGBColor[
              0.3144739916609805, 0.44562534071061943`, 0.9413021133678614], 
             UndirectedEdge[47, 142] -> 
             RGBColor[
              0.35771694731978376`, 0.4842581732170174, 0.9440143854599082], 
             UndirectedEdge[31, 120] -> 
             RGBColor[
              0.4714377823893207, 0.5800025448564534, 0.9520217635679507], 
             UndirectedEdge[9, 20] -> 
             RGBColor[
              0.7865726592585204, 0.8337593007059584, 0.9792123358122315], 
             UndirectedEdge[174, 188] -> 
             RGBColor[
              0.6529357917688204, 0.7274980289252182, 0.9669307675381773], 
             UndirectedEdge[45, 173] -> 
             RGBColor[
              0.9155315865084257, 0.9334914557023739, 0.9162254228301816], 
             UndirectedEdge[139, 191] -> 
             RGBColor[
              0.5376689442401503, 0.6314346462943711, 0.9584040707917953], 
             UndirectedEdge[24, 170] -> 
             RGBColor[
              0.6573740603328713, 0.7308847182770155, 0.9674281844857384], 
             UndirectedEdge[118, 195] -> 
             RGBColor[
              0.7809570759637912, 0.8285390914233753, 0.9530346906412808], 
             UndirectedEdge[124, 137] -> 
             RGBColor[
              0.6875888478946132, 0.7536938136796943, 0.9713047498738685], 
             UndirectedEdge[28, 63] -> 
             RGBColor[
              0.37042873172989593`, 0.4952684819601949, 0.9448243691219309], 
             UndirectedEdge[7, 94] -> 
             RGBColor[
              0.6452580271558449, 0.7206822575826026, 0.9667246836272849], 
             UndirectedEdge[37, 190] -> 
             RGBColor[
              0.44602994262661233`, 0.559318731545458, 0.9500371997830458], 
             UndirectedEdge[31, 40] -> 
             RGBColor[
              0.7597401364027823, 0.8113142240755136, 0.9513644154388277], 
             UndirectedEdge[18, 73] -> 
             RGBColor[
              0.34744110902174574`, 0.47535775856190704`, 0.9433596181301243],
              UndirectedEdge[170, 195] -> 
             RGBColor[
              0.6798490927762213, 0.7491309621032003, 0.9691975013684354], 
             UndirectedEdge[62, 191] -> 
             RGBColor[
              0.5232220067452286, 0.6189214351604613, 0.9574835247095441], 
             UndirectedEdge[152, 194] -> 
             RGBColor[
              0.5324038873962003, 0.628657572036718, 0.9573138286901076], 
             UndirectedEdge[24, 37] -> 
             RGBColor[
              0.529154895812922, 0.6286308084341533, 0.956076158238096], 
             UndirectedEdge[90, 177] -> 
             RGBColor[
              0.3068116292309808, 0.4336998276677204, 0.9410075218143005], 
             UndirectedEdge[94, 188] -> 
             RGBColor[
              0.7673690929846948, 0.8181938347515395, 0.9774478377829756], 
             UndirectedEdge[103, 133] -> 
             RGBColor[
              0.37184055667295823`, 0.49055792699091855`, 0.9453619461894204],
              UndirectedEdge[38, 179] -> 
             RGBColor[
              0.43279481005592735`, 0.5492868443959638, 0.9487982804847079], 
             UndirectedEdge[54, 116] -> 
             RGBColor[
              0.4219819486605887, 0.5393086717130549, 0.9482785620370531], 
             UndirectedEdge[4, 198] -> 
             RGBColor[
              0.5252693185849657, 0.6253454768881455, 0.9558064242036081], 
             UndirectedEdge[31, 38] -> 
             RGBColor[
              0.5032876109451911, 0.6075892655326192, 0.9540512064798332], 
             UndirectedEdge[35, 47] -> 
             RGBColor[
              0.3466949906304285, 0.4747115083123488, 0.9433120761259961], 
             UndirectedEdge[132, 151] -> 
             RGBColor[
              0.3913650274818793, 0.5115286737500835, 0.9464329387463668], 
             UndirectedEdge[124, 135] -> 
             RGBColor[
              0.5756873818609092, 0.6654279893603834, 0.960376370849334], 
             UndirectedEdge[32, 127] -> 
             RGBColor[
              0.43773110150085903`, 0.5532211575987283, 0.9492071062019436], 
             UndirectedEdge[187, 199] -> 
             RGBColor[
              0.3309345860927706, 0.4586430283743499, 0.9423963576181504], 
             UndirectedEdge[2, 51] -> 
             RGBColor[
              0.5697339735436642, 0.6615747318025891, 0.9592706918831195], 
             UndirectedEdge[40, 117] -> 
             RGBColor[
              0.7751636538834651, 0.8238357303878762, 0.9525786112331132], 
             UndirectedEdge[9, 17] -> 
             RGBColor[
              0.8072878109048602, 0.8502770003309379, 0.9811881654688936], 
             UndirectedEdge[33, 57] -> 
             RGBColor[
              0.49065141392897105`, 0.5965099668038537, 0.953283190874754], 
             UndirectedEdge[124, 175] -> 
             RGBColor[
              0.41885654441200054`, 0.5372142192527953, 0.9479101465230013], 
             UndirectedEdge[8, 147] -> 
             RGBColor[
              0.6560669002135961, 0.630174029108173, 0.6034260047826376], 
             UndirectedEdge[108, 110] -> 
             RGBColor[
              0.4712793238698994, 0.5684720273867203, 0.9539998019564844], 
             UndirectedEdge[68, 107] -> 
             RGBColor[
              0.4999684849225527, 0.6022523575095413, 0.9545323352926858], 
             UndirectedEdge[1, 138] -> 
             RGBColor[
              0.5911544972796945, 0.6789648779550959, 0.9609569939775837], 
             UndirectedEdge[94, 160] -> 
             RGBColor[
              0.5411954696091266, 0.6307502210588449, 0.9597558310707492], 
             UndirectedEdge[138, 142] -> 
             RGBColor[
              0.4754055079853028, 0.5822327078990077, 0.9526079379523713], 
             UndirectedEdge[6, 175] -> 
             RGBColor[
              0.3291811730050599, 0.4560504196717884, 0.9423239520753626], 
             UndirectedEdge[34, 104] -> 
             RGBColor[
              0.5932665670767999, 0.6739451158796703, 0.9643976062686817], 
             UndirectedEdge[15, 106] -> 
             RGBColor[
              0.36911690265002806`, 0.49413224154566004`, 0.9447407805329666],
              UndirectedEdge[61, 94] -> 
             RGBColor[
              0.5920415360312508, 0.6759684859649733, 0.962952566657468], 
             UndirectedEdge[144, 159] -> 
             RGBColor[
              0.30405478225048255`, 0.43617754113679885`, 0.9406537061315838],
              UndirectedEdge[83, 86] -> 
             RGBColor[
              0.6706149761484655, 0.7328954418981942, 0.8103208183664927], 
             UndirectedEdge[137, 176] -> 
             RGBColor[
              0.94479178805644, 0.9178143110923078, 0.6551059994464226], 
             UndirectedEdge[143, 159] -> 
             RGBColor[
              0.3662855614576975, 0.4916798761122094, 0.944560369975848], 
             UndirectedEdge[24, 144] -> 
             RGBColor[
              0.42184536174793485`, 0.5355152411911666, 0.9489015276415704], 
             UndirectedEdge[76, 96] -> 
             RGBColor[
              0.4535612170553484, 0.5643843024794208, 0.9509198363275401], 
             UndirectedEdge[98, 120] -> 
             RGBColor[
              0.36867406161714367`, 0.4937486749008131, 0.9447125630939402], 
             UndirectedEdge[98, 183] -> 
             RGBColor[
              0.3665380280443804, 0.4918985499802545, 0.944576456923504], 
             UndirectedEdge[55, 75] -> 
             RGBColor[
              0.5877219778056744, 0.6637264554210736, 0.964849062365569], 
             UndirectedEdge[35, 68] -> 
             RGBColor[
              0.48694613070296866`, 0.5909730488070918, 0.9537025623970294], 
             UndirectedEdge[25, 43] -> 
             RGBColor[
              0.38759150871495585`, 0.5101340167584005, 0.9459179660949713], 
             UndirectedEdge[47, 174] -> 
             RGBColor[
              0.46067723689502804`, 0.5706079007167448, 0.9513566681966787], 
             UndirectedEdge[29, 88] -> 
             RGBColor[
              0.5509699377252134, 0.6408328698209053, 0.9601499106697376], 
             UndirectedEdge[17, 140] -> 
             RGBColor[
              0.719527960899083, 0.7796589800308895, 0.973849078419953], 
             UndirectedEdge[41, 90] -> 
             RGBColor[
              0.2966219275332924, 0.42487402020648146`, 0.9403582430325232], 
             UndirectedEdge[151, 196] -> 
             RGBColor[
              0.6168729151686283, 0.6982139018034845, 0.9640963187781217], 
             UndirectedEdge[88, 94] -> 
             RGBColor[
              0.5561327226405256, 0.6448660766353658, 0.9606644888211279], 
             UndirectedEdge[57, 198] -> 
             RGBColor[
              0.5041149946710154, 0.6081714437433685, 0.9541410783342601], 
             UndirectedEdge[71, 164] -> 
             RGBColor[
              0.29757066707977187`, 0.42599921156744297`, 0.9404075854214965],
              UndirectedEdge[95, 154] -> 
             RGBColor[
              0.51263297091173, 0.612077707731438, 0.9558234963543717], 
             UndirectedEdge[69, 90] -> 
             RGBColor[
              0.6160021205751554, 0.6780970248318332, 0.7191485494872131], 
             UndirectedEdge[175, 176] -> 
             RGBColor[
              0.6760594845738274, 0.7013347166654088, 0.6317113960955553], 
             UndirectedEdge[58, 115] -> 
             RGBColor[
              0.42434412580208897`, 0.5419672864390295, 0.9482598103567002], 
             UndirectedEdge[42, 88] -> 
             RGBColor[
              0.29171133465435584`, 0.42235334222554155`, 0.9399819042970208],
              UndirectedEdge[72, 134] -> 
             RGBColor[
              0.49312755408213504`, 0.5954507457690038, 0.9544673463932696], 
             UndirectedEdge[25, 49] -> 
             RGBColor[
              0.344017131394475, 0.4723920812352845, 0.943141445303419], 
             UndirectedEdge[23, 103] -> 
             RGBColor[
              0.7383261456313681, 0.7925397888373329, 0.901231623509023], 
             UndirectedEdge[79, 192] -> 
             RGBColor[
              0.340744586854393, 0.46907115040967606`, 0.9429507317766083], 
             UndirectedEdge[89, 170] -> 
             RGBColor[
              0.5434677983217364, 0.6349114187978224, 0.959427868251213], 
             UndirectedEdge[41, 57] -> 
             RGBColor[
              0.4570859315705095, 0.5674372330351508, 0.9511444280196635], 
             UndirectedEdge[10, 14] -> 
             RGBColor[
              0.4376891557923956, 0.5522068741774658, 0.9494746445532376], 
             UndirectedEdge[6, 59] -> 
             RGBColor[
              0.3072928389823388, 0.4370918448809633, 0.9409292467865287], 
             UndirectedEdge[120, 183] -> 
             RGBColor[
              0.38596068240894654`, 0.5087214769798487, 0.9458140512848354], 
             UndirectedEdge[8, 194] -> 
             RGBColor[
              0.3822667133844079, 0.5055219466750749, 0.9455786748450403], 
             UndirectedEdge[63, 106] -> 
             RGBColor[
              0.3867942471522666, 0.5094434688643305, 0.9458671652931874], 
             UndirectedEdge[129, 131] -> 
             RGBColor[
              0.6329419703195746, 0.6714351744711, 0.6424232654589606], 
             UndirectedEdge[22, 38] -> 
             RGBColor[
              0.7242924073799737, 0.4950006570968745, 0.4535655814705004], 
             UndirectedEdge[38, 117] -> 
             RGBColor[
              0.5187111284258739, 0.6201107718449819, 0.9552654022741187], 
             UndirectedEdge[136, 159] -> 
             RGBColor[
              0.2688842443307584, 0.39921107584226934`, 0.9386507960272037], 
             UndirectedEdge[158, 166] -> 
             RGBColor[
              0.6325804510405995, 0.7099354310940624, 0.9660206381355045], 
             UndirectedEdge[75, 96] -> 
             RGBColor[
              0.30651784373810426`, 0.43592702345457734`, 0.9408979364058583],
              UndirectedEdge[118, 170] -> 
             RGBColor[
              0.863593440821063, 0.8937868310183525, 0.9607982719241801], 
             UndirectedEdge[7, 58] -> 
             RGBColor[
              0.45337128271681204`, 0.5657294725553568, 0.9504906043404524], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.3846962120142156, 0.5076262562780628, 0.9457334803494104], 
             UndirectedEdge[65, 180] -> 
             RGBColor[
              0.5558366511782951, 0.6480534906232461, 0.959188020241158], 
             UndirectedEdge[151, 171] -> 
             RGBColor[
              0.43450146136549017`, 0.5499059464248768, 0.9491444024324514], 
             UndirectedEdge[37, 118] -> 
             RGBColor[
              0.7353742763011137, 0.7915329211754903, 0.9494462456765378], 
             UndirectedEdge[7, 47] -> 
             RGBColor[
              0.43398300173494064`, 0.5489363180521962, 0.9492552002206712], 
             UndirectedEdge[46, 99] -> 
             RGBColor[
              0.4359721542866026, 0.5495100572233064, 0.949699464918134], 
             UndirectedEdge[195, 197] -> 
             RGBColor[
              0.5972948068025855, 0.6839498578435704, 0.9614403816359207], 
             UndirectedEdge[5, 63] -> 
             RGBColor[
              0.6167514790574425, 0.6949304520592129, 0.9655976280880892], 
             UndirectedEdge[11, 63] -> 
             RGBColor[
              0.3547676955094451, 0.4817036795326082, 0.9438264617424744], 
             UndirectedEdge[10, 193] -> 
             RGBColor[
              0.4991556023288099, 0.6021081045075878, 0.9543135083835967], 
             UndirectedEdge[99, 147] -> 
             RGBColor[
              0.6269000562504048, 0.6049111748354591, 0.6015675192765305], 
             UndirectedEdge[9, 77] -> 
             RGBColor[
              0.4758737316844422, 0.575982536848244, 0.9538369265885323], 
             UndirectedEdge[43, 103] -> 
             RGBColor[
              0.44285376597818127`, 0.5570383000610314, 0.9497047848168618], 
             UndirectedEdge[54, 174] -> 
             RGBColor[
              0.5166995618558465, 0.618519007221399, 0.9550956287236034], 
             UndirectedEdge[149, 197] -> 
             RGBColor[
              0.465159746660868, 0.5734081892779697, 0.9519413148143101], 
             UndirectedEdge[87, 180] -> 
             RGBColor[
              0.6843434714923287, 0.7533335882236087, 0.9691726197511622], 
             UndirectedEdge[134, 191] -> 
             RGBColor[
              0.6955290574637176, 0.7620718529980599, 0.9702874944255462], 
             UndirectedEdge[65, 131] -> 
             RGBColor[
              0.68906636237918, 0.7213990149905465, 0.6459499692572709], 
             UndirectedEdge[107, 147] -> 
             RGBColor[
              0.6419541643005181, 0.6179502865869964, 0.6025267537296587], 
             UndirectedEdge[50, 82] -> 
             RGBColor[
              0.5703614559387262, 0.6382110170742163, 0.941527367678092], 
             UndirectedEdge[30, 162] -> 
             RGBColor[
              0.5026914931186268, 0.5932380132545907, 0.9570948055703442], 
             UndirectedEdge[51, 74] -> 
             RGBColor[
              0.5383811749520688, 0.6361211174784511, 0.9568024847289037], 
             UndirectedEdge[12, 161] -> 
             RGBColor[
              0.7033549696964414, 0.767406904948635, 0.9715998482416257], 
             UndirectedEdge[78, 113] -> 
             RGBColor[
              0.6208942934793475, 0.6285529831912268, 0.6084582404132186], 
             UndirectedEdge[131, 133] -> 
             RGBColor[
              0.6133620902506296, 0.6508554790825406, 0.641308220254871], 
             UndirectedEdge[35, 188] -> 
             RGBColor[
              0.5389535455042209, 0.6316016365208222, 0.9588861754674947], 
             UndirectedEdge[181, 185] -> 
             RGBColor[
              0.31573150869910405`, 0.44009423571954787`, 0.9416246429663799],
              UndirectedEdge[111, 188] -> 
             RGBColor[
              0.7943302074791944, 0.3571973411432022, 0.4346628179059535], 
             UndirectedEdge[41, 184] -> 
             RGBColor[
              0.4337250802712871, 0.5484718415560841, 0.9493053762317708], 
             UndirectedEdge[135, 187] -> 
             RGBColor[
              0.5401566434296698, 0.6346530495580824, 0.9581123836150938], 
             UndirectedEdge[51, 71] -> 
             RGBColor[
              0.40208032484029854`, 0.5135671956632648, 0.9478827790137916], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.5044677960991232, 0.6044885254693797, 0.9555220029309817], 
             UndirectedEdge[26, 158] -> 
             RGBColor[
              0.59739002048762, 0.6794552488715391, 0.9637783350183445], 
             UndirectedEdge[101, 199] -> 
             RGBColor[
              0.5349511218061571, 0.6240629893792444, 0.9594198598724369], 
             UndirectedEdge[84, 194] -> 
             RGBColor[
              0.49184166769942017`, 0.5963667382965051, 0.9536834584947274], 
             UndirectedEdge[6, 176] -> 
             RGBColor[
              0.6178607414053161, 0.6474343904031936, 0.6281308645655798], 
             UndirectedEdge[18, 116] -> 
             RGBColor[
              0.36501167255875955`, 0.4905764975754671, 0.9444791989016634], 
             UndirectedEdge[98, 179] -> 
             RGBColor[
              0.38152232713549084`, 0.5048771967202038, 0.9455312432114942], 
             UndirectedEdge[116, 142] -> 
             RGBColor[
              0.35984105832955576`, 0.48609797141275835`, 0.9441497319351733],
              UndirectedEdge[77, 112] -> 
             RGBColor[
              0.2760665726092589, 0.4074938498169618, 0.9390329549549777], 
             UndirectedEdge[56, 190] -> 
             RGBColor[
              0.35469047797479447`, 0.4816367975851599, 0.9438215415094473], 
             UndirectedEdge[76, 126] -> 
             RGBColor[
              0.7248857022388897, 0.7843059706017175, 0.9739286325570256], 
             UndirectedEdge[168, 173] -> 
             RGBColor[
              0.5543243573681924, 0.637096099438482, 0.9616635675138343], 
             UndirectedEdge[158, 164] -> 
             RGBColor[
              0.583210495550654, 0.6671736570547846, 0.9628748282278226], 
             UndirectedEdge[46, 146] -> 
             RGBColor[
              0.41157779880242534`, 0.5254182289650556, 0.9482535557863643], 
             UndirectedEdge[23, 25] -> 
             RGBColor[
              0.6830638883681428, 0.7456355055347019, 0.8974448047871324], 
             UndirectedEdge[9, 28] -> 
             RGBColor[
              0.5201288323195741, 0.6180533278969664, 0.9565199103104383], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.3666479186808337, 0.4919937317262864, 0.9445834590576865], 
             UndirectedEdge[103, 129] -> 
             RGBColor[
              0.3914204367419031, 0.5111376223794779, 0.94647699139351], 
             UndirectedEdge[5, 48] -> 
             RGBColor[
              0.5759034660309342, 0.6589584547994969, 0.9630164865844015], 
             UndirectedEdge[36, 169] -> 
             RGBColor[
              0.346026441803307, 0.4741324449205372, 0.9432694767859064], 
             UndirectedEdge[159, 170] -> 
             RGBColor[
              0.539583480835419, 0.6315470182226477, 0.9591803629757518], 
             UndirectedEdge[86, 175] -> 
             RGBColor[
              0.366895942820997, 0.49220855777044015`, 0.9445992629365785], 
             UndirectedEdge[9, 97] -> 
             RGBColor[
              0.8374893660507252, 0.8716992773972294, 0.8795242102702365], 
             UndirectedEdge[7, 88] -> 
             RGBColor[
              0.41500518626456395`, 0.532498688144496, 0.948045950600322], 
             UndirectedEdge[5, 77] -> 
             RGBColor[
              0.5588806800431168, 0.6410664274193314, 0.9620470641053505], 
             UndirectedEdge[103, 131] -> 
             RGBColor[
              0.7302363434569837, 0.7560972769597609, 0.648838840601937], 
             UndirectedEdge[15, 193] -> 
             RGBColor[
              0.4867629982823291, 0.5913742537529162, 0.9535238626121045], 
             UndirectedEdge[167, 181] -> 
             RGBColor[
              0.47016022881346026`, 0.5794803185577826, 0.9517789078592922], 
             UndirectedEdge[99, 146] -> 
             RGBColor[
              0.3010966054256231, 0.4322538152556117, 0.9405150649704153], 
             UndirectedEdge[163, 177] -> 
             RGBColor[
              0.45904615385741177`, 0.5695819783768911, 0.9511458520366474], 
             UndirectedEdge[76, 116] -> 
             RGBColor[
              0.4639073207921981, 0.5733455775259864, 0.9515790809089518], 
             UndirectedEdge[15, 59] -> 
             RGBColor[
              0.3461464946163708, 0.47423642863318327`, 0.9432771264449964], 
             UndirectedEdge[36, 151] -> 
             RGBColor[
              0.39724379750977545`, 0.517635230617691, 0.9467703770372237], 
             UndirectedEdge[38, 98] -> 
             RGBColor[
              0.40052389017301404`, 0.5213353955769788, 0.9467420060058227], 
             UndirectedEdge[70, 139] -> 
             RGBColor[
              0.3806168973081422, 0.5040929589119807, 0.9454735500235357], 
             UndirectedEdge[56, 195] -> 
             RGBColor[
              0.46029046360445414`, 0.56919511830004, 0.9516298168471945], 
             UndirectedEdge[66, 168] -> 
             RGBColor[
              0.2957620209948052, 0.4266108703977015, 0.9402125848916558], 
             UndirectedEdge[6, 161] -> 
             RGBColor[
              0.5430803592177027, 0.6288464175691203, 0.9604782160724238], 
             UndirectedEdge[56, 118] -> 
             RGBColor[
              0.6440348116492959, 0.7138509872151922, 0.9432305874029392], 
             UndirectedEdge[46, 117] -> 
             RGBColor[
              0.566039615710851, 0.6585754856849875, 0.9589798585016418], 
             UndirectedEdge[79, 89] -> 
             RGBColor[
              0.31396755959899736`, 0.4458782352535746, 0.9412445232778899], 
             UndirectedEdge[102, 140] -> 
             RGBColor[
              0.7270083992383377, 0.7853556750828206, 0.9652707221932744], 
             UndirectedEdge[32, 130] -> 
             RGBColor[
              0.35962069446649414`, 0.4859071033103842, 0.944135690544679], 
             UndirectedEdge[105, 126] -> 
             RGBColor[
              0.9328964276103193, 0.9482974390427703, 0.9576515822117433], 
             UndirectedEdge[86, 124] -> 
             RGBColor[
              0.39837257105942636`, 0.5194720310892318, 0.9466049258542417], 
             UndirectedEdge[41, 168] -> 
             RGBColor[
              0.3100425582532653, 0.4389799540103073, 0.9411225280979817], 
             UndirectedEdge[43, 143] -> 
             RGBColor[
              0.40644117047755013`, 0.5264606463656123, 0.9471190498743822], 
             UndirectedEdge[56, 197] -> 
             RGBColor[
              0.46037254248809023`, 0.5692617536353873, 0.9516362783975791], 
             UndirectedEdge[47, 73] -> 
             RGBColor[
              0.3483890601627563, 0.47617882619484064`, 0.9434200207385892], 
             UndirectedEdge[23, 108] -> 
             RGBColor[
              0.6135889770838117, 0.6790335683988822, 0.8932532217654164], 
             UndirectedEdge[97, 155] -> 
             RGBColor[
              0.6166968422944692, 0.68115364153717, 0.8635251531631598], 
             UndirectedEdge[86, 161] -> 
             RGBColor[
              0.5807951290336398, 0.6650045556677721, 0.9627535269336397], 
             UndirectedEdge[88, 188] -> 
             RGBColor[
              0.5371162520934137, 0.6300102653134328, 0.9587691047560127], 
             UndirectedEdge[136, 197] -> 
             RGBColor[
              0.4092319351551968, 0.5168616550581693, 0.9486743959702719], 
             UndirectedEdge[65, 69] -> 
             RGBColor[
              0.6997880950367977, 0.757134942301442, 0.7242505394816754], 
             UndirectedEdge[23, 67] -> 
             RGBColor[
              0.6686838779684439, 0.7331802632868207, 0.8965285232402075], 
             UndirectedEdge[31, 121] -> 
             RGBColor[
              0.483367106757996, 0.5903351260393234, 0.9527818895680353], 
             UndirectedEdge[52, 145] -> 
             RGBColor[
              0.33288207207674614`, 0.4608104284673715, 0.9425028531093029], 
             UndirectedEdge[12, 87] -> 
             RGBColor[
              0.6274600695728989, 0.7081172321495188, 0.9640353538754767], 
             UndirectedEdge[128, 192] -> 
             RGBColor[
              0.42241506294687836`, 0.5399296571177394, 0.9482382323830579], 
             UndirectedEdge[78, 95] -> 
             RGBColor[
              0.3239864464098686, 0.45367733871406485`, 0.9419150933282905], 
             UndirectedEdge[123, 165] -> 
             RGBColor[
              0.42579786623023785`, 0.5415547953476118, 0.9488143227297154], 
             UndirectedEdge[24, 56] -> 
             RGBColor[
              0.43781543116110416`, 0.5509488744738552, 0.9498604999644975], 
             UndirectedEdge[50, 177] -> 
             RGBColor[
              0.668308135769497, 0.7350501617466907, 0.9473289675632777], 
             UndirectedEdge[18, 58] -> 
             RGBColor[
              0.38227584253085894`, 0.5055298538828866, 0.9455792565461796], 
             UndirectedEdge[96, 182] -> 
             RGBColor[
              0.34542541529639925`, 0.4736118659687243, 0.9432311799083531], 
             UndirectedEdge[49, 131] -> 
             RGBColor[
              0.6408009222353719, 0.6795939166295374, 0.6428745380907603], 
             UndirectedEdge[28, 106] -> 
             RGBColor[
              0.37317854877307277`, 0.4976502352731714, 0.9449995850323545], 
             UndirectedEdge[57, 81] -> 
             RGBColor[
              0.4554381230441569, 0.5660099841108889, 0.9510394311174641], 
             UndirectedEdge[7, 115] -> 
             RGBColor[
              0.4751033338651602, 0.5845526829754055, 0.9518753514227268], 
             UndirectedEdge[54, 94] -> 
             RGBColor[
              0.6311328630717209, 0.7092148130477203, 0.9656126989684017], 
             UndirectedEdge[138, 181] -> 
             RGBColor[
              0.503137267689691, 0.6062525643161785, 0.9543749811585027], 
             UndirectedEdge[55, 182] -> 
             RGBColor[
              0.6266295493639693, 0.7014112979352205, 0.9671823058680639], 
             UndirectedEdge[17, 77] -> 
             RGBColor[
              0.5997169113008565, 0.6736281297542848, 0.9659420602976476], 
             UndirectedEdge[144, 149] -> 
             RGBColor[
              0.3121853340495674, 0.44321981645175057`, 0.9411717777026569], 
             UndirectedEdge[68, 179] -> 
             RGBColor[
              0.5290655199267412, 0.6274547467706673, 0.9563863726336548], 
             UndirectedEdge[103, 143] -> 
             RGBColor[
              0.45230221437868123`, 0.5652220711727198, 0.9503068315940069], 
             UndirectedEdge[80, 173] -> 
             RGBColor[
              0.836059229686476, 0.8721149518015102, 0.984225269758023], 
             UndirectedEdge[161, 199] -> 
             RGBColor[
              0.5488878824982235, 0.634950492755191, 0.9608089459317887], 
             UndirectedEdge[43, 133] -> 
             RGBColor[
              0.32597951277182713`, 0.4517965021838111, 0.9421741644697958], 
             UndirectedEdge[6, 193] -> 
             RGBColor[
              0.44790934264829707`, 0.5542296700006962, 0.9511759829536368], 
             UndirectedEdge[181, 188] -> 
             RGBColor[
              0.5777072618979644, 0.6651681578426615, 0.9613555280075381], 
             UndirectedEdge[120, 173] -> 
             RGBColor[
              0.6155506352388644, 0.6941122835896137, 0.9654189392468968], 
             UndirectedEdge[2, 158] -> 
             RGBColor[
              0.6953783492202318, 0.7609589095873683, 0.9709529030549742], 
             UndirectedEdge[95, 143] -> 
             RGBColor[
              0.3849409982662421, 0.5078382778262533, 0.9457490779129335], 
             UndirectedEdge[4, 172] -> 
             RGBColor[
              0.5350849094564656, 0.6334450606540523, 0.9565429906344715], 
             UndirectedEdge[89, 113] -> 
             RGBColor[
              0.6361291054016858, 0.6431137815134986, 0.6093790035976434], 
             UndirectedEdge[34, 90] -> 
             RGBColor[
              0.5534926644184635, 0.6330282428950362, 0.962100026571179], 
             UndirectedEdge[28, 48] -> 
             RGBColor[
              0.32958071870338757`, 0.4592964847004789, 0.9422432276182432], 
             UndirectedEdge[5, 189] -> 
             RGBColor[
              0.6841230908414903, 0.751506701398249, 0.9703816588770631], 
             UndirectedEdge[8, 55] -> 
             RGBColor[
              0.646812222103583, 0.7188925146516467, 0.9684683279281953], 
             UndirectedEdge[29, 138] -> 
             RGBColor[
              0.6876363138611092, 0.7552450344105959, 0.9699527127825499], 
             UndirectedEdge[8, 68] -> 
             RGBColor[
              0.5140812208356308, 0.614476100030718, 0.9554315863456646], 
             UndirectedEdge[176, 187] -> 
             RGBColor[
              0.6720053743810173, 0.6978232501818997, 0.6314530717789784], 
             UndirectedEdge[65, 133] -> 
             RGBColor[
              0.3306705755951544, 0.4558596650217041, 0.9424730748447543], 
             UndirectedEdge[68, 147] -> 
             RGBColor[
              0.7863234722130437, 0.7377787770796007, 0.6131796460139032], 
             UndirectedEdge[89, 192] -> 
             RGBColor[
              0.35122716626537537`, 0.4786370510535689, 0.9436008623498093], 
             UndirectedEdge[2, 74] -> 
             RGBColor[
              0.54603937086112, 0.6423383859152131, 0.9574053659637602], 
             UndirectedEdge[156, 185] -> 
             RGBColor[
              0.33452840183644605`, 0.4563751597957943, 0.9428223643756515], 
             UndirectedEdge[126, 182] -> 
             RGBColor[
              0.6167499004799405, 0.6935335340910208, 0.9662399761378386], 
             UndirectedEdge[18, 188] -> 
             RGBColor[
              0.55514611642278, 0.6456268275881996, 0.9599179517678971], 
             UndirectedEdge[68, 156] -> 
             RGBColor[
              0.5444967402340541, 0.6408204942051775, 0.9573696363463444], 
             UndirectedEdge[29, 181] -> 
             RGBColor[
              0.5915609475297641, 0.6759907623501339, 0.962736333921263], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.6795781771197675, 0.7487030759890514, 0.969318346740344], 
             UndirectedEdge[30, 180] -> 
             RGBColor[
              0.4731090250839057, 0.5701279643907823, 0.9541463016205246], 
             UndirectedEdge[31, 196] -> 
             RGBColor[
              0.6517830932561489, 0.7265555570605344, 0.9668445758773672], 
             UndirectedEdge[193, 199] -> 
             RGBColor[
              0.4537168659288179, 0.5603337451867669, 0.9515067128130017], 
             UndirectedEdge[30, 110] -> 
             RGBColor[
              0.47211888524526263`, 0.5693544596234928, 0.9540476137347915], 
             UndirectedEdge[12, 59] -> 
             RGBColor[
              0.46756744946107753`, 0.575652332260478, 0.9520508789557305], 
             UndirectedEdge[38, 156] -> 
             RGBColor[
              0.4482260303632402, 0.5626525918304741, 0.9497815441973976], 
             UndirectedEdge[72, 152] -> 
             RGBColor[
              0.5026912356621631, 0.6029219665059937, 0.9554205647954811], 
             UndirectedEdge[37, 79] -> 
             RGBColor[
              0.4047660543908048, 0.5230916083110674, 0.9474257114303695], 
             UndirectedEdge[170, 197] -> 
             RGBColor[
              0.6799311716598573, 0.7491975974385476, 0.96920396291882], 
             UndirectedEdge[86, 127] -> 
             RGBColor[
              0.40614905241917415`, 0.5258663740441142, 0.9471947259613681], 
             UndirectedEdge[69, 127] -> 
             RGBColor[
              0.7295437388599081, 0.7825665310772629, 0.7262408323855569], 
             UndirectedEdge[58, 61] -> 
             RGBColor[
              0.4001547915922179, 0.5210157009377274, 0.9467184873706355], 
             UndirectedEdge[11, 17] -> 
             RGBColor[
              0.6283109757155374, 0.7021341183754205, 0.9676271366400969], 
             UndirectedEdge[11, 15] -> 
             RGBColor[
              0.3370903510072065, 0.46639245221393777`, 0.9427000769822538], 
             UndirectedEdge[111, 157] -> 
             RGBColor[
              0.6693709830658581, 0.25538698747445204`, 0.424484823801769], 
             UndirectedEdge[75, 191] -> 
             RGBColor[
              0.4958653207340445, 0.5912413891428336, 0.9558862934200641], 
             UndirectedEdge[98, 156] -> 
             RGBColor[
              0.39695354744280376`, 0.5182429441547141, 0.9465145069241838], 
             UndirectedEdge[28, 140] -> 
             RGBColor[
              0.4323689823137968, 0.5474353075969182, 0.9491808232614976], 
             UndirectedEdge[105, 157] -> 
             RGBColor[
              0.6746136534076439, 0.7396718454766464, 0.9354737922736265], 
             UndirectedEdge[3, 15] -> 
             RGBColor[
              0.3608713495047612, 0.4869903578447812, 0.9442153811778067], 
             UndirectedEdge[55, 96] -> 
             RGBColor[
              0.6285956613034127, 0.703114245277507, 0.9673075847822806], 
             UndirectedEdge[6, 64] -> 
             RGBColor[
              0.5404404555930529, 0.6267841047935332, 0.9602150951504207], 
             UndirectedEdge[70, 134] -> 
             RGBColor[
              0.5384770105317094, 0.6347301656156695, 0.9573569736572867], 
             UndirectedEdge[106, 140] -> 
             RGBColor[
              0.44873449773616747`, 0.5616102945010537, 0.950223619432754], 
             UndirectedEdge[64, 154] -> 
             RGBColor[
              0.7405860227592915, 0.7972706967325816, 0.9747783516449289], 
             UndirectedEdge[8, 157] -> 
             RGBColor[
              0.3786497990168788, 0.5023891572413232, 0.9453482082598531], 
             UndirectedEdge[83, 124] -> 
             RGBColor[
              0.7225755777394691, 0.7779011033805494, 0.8136317019529156], 
             UndirectedEdge[22, 128] -> 
             RGBColor[
              0.729302260473152, 0.49909542535456436`, 0.45395236501668423`], 
             UndirectedEdge[83, 135] -> 
             RGBColor[
              0.8479297869499485, 0.8788514001693457, 0.824092263361585], 
             UndirectedEdge[62, 68] -> 
             RGBColor[
              0.48234766254890615`, 0.5869900868177726, 0.9534095520725183], 
             UndirectedEdge[105, 116] -> 
             RGBColor[
              0.6719180461636277, 0.7373370459670392, 0.9353020305636697], 
             UndirectedEdge[93, 145] -> 
             RGBColor[
              0.29798328453604744`, 0.43052970365181215`, 0.9402810792763386],
              UndirectedEdge[128, 195] -> 
             RGBColor[
              0.5320193301459676, 0.6309562852670159, 0.9563016570015621], 
             UndirectedEdge[87, 154] -> 
             RGBColor[
              0.6673310262603989, 0.7400433367090525, 0.967476978200783], 
             UndirectedEdge[138, 167] -> 
             RGBColor[
              0.5662355951448055, 0.6587345906182447, 0.9589952867205791], 
             UndirectedEdge[179, 194] -> 
             RGBColor[
              0.39725101247551836`, 0.5185005934150242, 0.9465334611330304], 
             UndirectedEdge[118, 144] -> 
             RGBColor[
              0.6280647422361266, 0.6984173539325036, 0.9422716150800121], 
             UndirectedEdge[47, 188] -> 
             RGBColor[
              0.5560940675637905, 0.6464478952211332, 0.9599783543763619], 
             UndirectedEdge[11, 20] -> 
             RGBColor[
              0.6075958240691975, 0.685616418750441, 0.9656513069834349], 
             UndirectedEdge[124, 187] -> 
             RGBColor[
              0.4148024342191904, 0.5337027527692861, 0.9476518222064243], 
             UndirectedEdge[28, 189] -> 
             RGBColor[
              0.43780034351394365`, 0.5518447312992311, 0.9496083999109048], 
             UndirectedEdge[84, 93] -> 
             RGBColor[
              0.4555728521016856, 0.5648993640375536, 0.951374387685437], 
             UndirectedEdge[18, 94] -> 
             RGBColor[
              0.5741625869698919, 0.6604826389101325, 0.9618133358330121], 
             UndirectedEdge[146, 156] -> 
             RGBColor[
              0.3606789687872379, 0.48386106370278514`, 0.9443116004772021], 
             UndirectedEdge[2, 26] -> 
             RGBColor[
              0.47940384072010356`, 0.5862883395235217, 0.9526990050813464], 
             UndirectedEdge[124, 161] -> 
             RGBColor[
              0.6327557306246433, 0.7100102171501272, 0.9660644105200625], 
             UndirectedEdge[25, 67] -> 
             RGBColor[
              0.36381028495316264`, 0.4895359160149958, 0.9444026475457802], 
             UndirectedEdge[15, 77] -> 
             RGBColor[
              0.30849628659252554`, 0.43788646359280203`, 0.9410150006398044],
              UndirectedEdge[23, 49] -> 
             RGBColor[
              0.6488907244097561, 0.7160364285071094, 0.8952673209978463], 
             UndirectedEdge[27, 37] -> 
             RGBColor[
              0.3800606369275348, 0.49712464814323165`, 0.9460187744542261], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.3486599018463792, 0.476413415648296, 0.9434372785311738], 
             UndirectedEdge[134, 139] -> 
             RGBColor[
              0.5071115204761448, 0.6075629546049077, 0.9553583923663599], 
             UndirectedEdge[13, 127] -> 
             RGBColor[
              0.5870730998134103, 0.6746418953727384, 0.9613259059297925], 
             UndirectedEdge[59, 186] -> 
             RGBColor[
              0.2771581318510729, 0.4054183570352168, 0.9392131197957072], 
             UndirectedEdge[119, 149] -> 
             RGBColor[
              0.36678473278769497`, 0.4921122332291727, 0.9445921767315957], 
             UndirectedEdge[41, 66] -> 
             RGBColor[
              0.3401604190077047, 0.4690515908098649, 0.9428956990004909], 
             UndirectedEdge[25, 103] -> 
             RGBColor[
              0.43345255261608695`, 0.548895441565508, 0.9491057478145957], 
             UndirectedEdge[164, 166] -> 
             RGBColor[
              0.40242641760350506`, 0.5229832692134612, 0.9468632333713547], 
             UndirectedEdge[30, 90] -> 
             RGBColor[
              0.239861247167673, 0.3694397572276373, 0.9369711152320586], 
             UndirectedEdge[75, 182] -> 
             RGBColor[
              0.3045517317986608, 0.43422407611229086`, 0.9407726574916415], 
             UndirectedEdge[92, 97] -> 
             RGBColor[
              0.9182057521105111, 0.93495673576684, 0.8875158719101774], 
             UndirectedEdge[18, 61] -> 
             RGBColor[
              0.379818559469336, 0.5034014788016332, 0.9454226806423894], 
             UndirectedEdge[76, 191] -> 
             RGBColor[
              0.6429086940512887, 0.7196986681676771, 0.9659081933417459], 
             UndirectedEdge[129, 197] -> 
             RGBColor[
              0.44575147464535775`, 0.5552460065348674, 0.9507541297184194], 
             UndirectedEdge[97, 112] -> 
             RGBColor[
              0.6376822069755419, 0.7032105903659471, 0.8647202386366819], 
             UndirectedEdge[87, 131] -> 
             RGBColor[
              0.8175731826932136, 0.826679112590909, 0.6559345687672751], 
             UndirectedEdge[33, 198] -> 
             RGBColor[
              0.4350355017251323, 0.5512276188993912, 0.9489410553765039], 
             UndirectedEdge[39, 114] -> 
             RGBColor[
              0.2573301155566468, 0.38780064549467597`, 0.9379659414439357], 
             UndirectedEdge[144, 170] -> 
             RGBColor[
              0.5269567590485567, 0.6190092246123285, 0.9584344258071669], 
             UndirectedEdge[64, 110] -> 
             RGBColor[
              0.7566083281525783, 0.8097874434798483, 0.976375305309575], 
             UndirectedEdge[108, 131] -> 
             RGBColor[
              0.6054991749094274, 0.6425910565213102, 0.6408604388583303], 
             UndirectedEdge[33, 141] -> 
             RGBColor[
              0.4138260475158331, 0.5328570556814607, 0.9475896077090713], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.7007150660717917, 0.765344592173048, 0.9713367273196225], 
             UndirectedEdge[88, 142] -> 
             RGBColor[
              0.338739131849407, 0.4678205433093171, 0.942805135839559], 
             UndirectedEdge[12, 95] -> 
             RGBColor[
              0.47276201422423014`, 0.5801516031719043, 0.9523818720290653], 
             UndirectedEdge[131, 162] -> 
             RGBColor[
              0.8681106338684914, 0.8661593535478911, 0.6609716696010943], 
             UndirectedEdge[21, 194] -> 
             RGBColor[
              0.38424973961386527`, 0.5072395443252347, 0.9457050315228601], 
             UndirectedEdge[131, 154] -> 
             RGBColor[
              0.8215157206018405, 0.8297590531695265, 0.6563275241008956], 
             UndirectedEdge[81, 184] -> 
             RGBColor[
              0.4320772717449345, 0.5470445926318221, 0.9492003793295716], 
             UndirectedEdge[105, 111] -> 
             RGBColor[
              0.8701301192059044, 0.41656357617664563`, 
               0.41812170438064866`]}, GraphLayout -> {"Dimension" -> 2}, 
           ImageSize -> 500, VertexSize -> {2}, VertexStyle -> {
             EdgeForm[None], 71 -> 
             RGBColor[
              0.24208487204598406`, 0.3717769279607025, 0.9370977473793202], 
             10 -> RGBColor[
              0.3734749491975743, 0.4979069624233562, 0.945018471405307], 68 -> 
             RGBColor[
              0.6443377928350783, 0.7220808480021458, 0.9651852275769301], 
             155 -> RGBColor[
              0.2418595837759338, 0.37154013570477834`, 0.937084917545625], 
             132 -> RGBColor[
              0.29777156234186813`, 0.43030717020176723`, 0.940269022010595], 
             26 -> RGBColor[
              0.3814155119874918, 0.5047846788076924, 0.9455244370447167], 29 -> 
             RGBColor[
              0.7760599937011822, 0.8249832324445514, 0.9783140655453102], 
             113 -> RGBColor[
              0.9478080717933919, 0.8307834271295299, 0.2768633533441958], 50 -> 
             RGBColor[
              0.9617959118774524, 0.9710280341484328, 0.949553735356184], 173 -> 
             RGBColor[
              0.8430045544960191, 0.8776529652788202, 0.984887721038522], 192 -> 
             RGBColor[
              0.378004193520771, 0.5018299662096704, 0.9453070708485277], 165 -> 
             RGBColor[
              0.3367122208133204, 0.4660649348453697, 0.9426759828606667], 92 -> 
             RGBColor[
              0.8448774034080176, 0.8791463241641184, 0.9850663550396603], 11 -> 
             RGBColor[
              0.32549096090980034`, 0.45634564351386236`, 0.9419609741021849],
              137 -> RGBColor[
              0.9248445231387965, 0.9429099347878017, 0.9926936903070726], 
             120 -> RGBColor[
              0.3880967159817098, 0.5105716019004073, 0.9459501574552716], 51 -> 
             RGBColor[
              0.562075777634613, 0.6553574633658271, 0.9586678106482631], 72 -> 
             RGBColor[
              0.32128347446455807`, 0.4527013302294111, 0.9416928767864283], 
             64 -> RGBColor[
              0.8098984813495572, 0.8514181161774933, 0.9816867697554542], 41 -> 
             RGBColor[
              0.35444095626616484`, 0.48142067442247066`, 0.9438056422068167],
              103 -> RGBColor[
              0.4887148098793123, 0.5957997248681388, 0.9528925665364864], 
             162 -> RGBColor[
              0.7644633907023277, 0.8159238780443991, 0.977158224534801], 196 -> 
             RGBColor[
              0.7487873377153662, 0.8036776263085694, 0.9755957820741047], 
             179 -> RGBColor[
              0.41379324701840414`, 0.5328286455391887, 0.9475875176903794], 
             160 -> RGBColor[
              0.2960053756864465, 0.4284507960442174, 0.9401684402934077], 
             123 -> RGBColor[
              0.5148835116471553, 0.6170446558498538, 0.9549526625987641], 
             150 -> RGBColor[
              0.3058708726711128, 0.4388200588837381, 0.9407302657519896], 
             188 -> RGBColor[
              0.7483526224375829, 0.8033380234296066, 0.9755524537178605], 46 -> 
             RGBColor[
              0.5464533476634048, 0.6426744709327503, 0.957437955734083], 182 -> 
             RGBColor[
              0.3434593033569558, 0.47190891862643775`, 0.9431059009941364], 
             6 -> RGBColor[
              0.2709824298365486, 0.40215009340957314`, 0.9387434205453871], 
             131 -> RGBColor[
              0.9717578770346552, 0.9163948290513829, 0.3447851146673876], 45 -> 
             RGBColor[
              0.9880586185208323, 0.9893299461259276, 0.8475631246218412], 
             195 -> RGBColor[
              0.5972127279189494, 0.6838832225082231, 0.961433920085536], 148 -> 
             RGBColor[
              0.5478948359779737, 0.643844736084826, 0.9575514349745515], 161 -> 
             RGBColor[
              0.8151782885988568, 0.8555427417286675, 0.9822130115994605], 1 -> 
             RGBColor[
              0.5830963605383528, 0.6724229195335513, 0.9603226279353778], 
             101 -> RGBColor[
              0.7873047672147241, 0.8337677349767743, 0.979434839480757], 12 -> 
             RGBColor[
              0.5915316507940261, 0.6792710681686025, 0.9609866848837908], 39 -> 
             RGBColor[
              0.23795798117184772`, 0.367439303991991, 0.936862727049226], 48 -> 
             RGBColor[
              0.30234840405607316`, 0.4351177210319219, 0.9405296663753884], 
             77 -> RGBColor[
              0.26830283208043837`, 0.3993336662715909, 0.9385908214172862], 
             56 -> RGBColor[
              0.32336819928995886`, 0.4545070140918569, 0.941825713608853], 
             110 -> RGBColor[
              0.7033181749555993, 0.7681567707822033, 0.9710638408636956], 73 -> 
             RGBColor[
              0.3329426076355145, 0.46279988537702155`, 0.942435786442315], 
             37 -> RGBColor[
              0.5060471285935946, 0.6098708820124531, 0.9542570301560501], 
             130 -> RGBColor[
              0.3096653213011958, 0.44263826990466365`, 0.9409525783403883], 
             107 -> RGBColor[
              0.3555991770100271, 0.4824238670169369, 0.9438794430084413], 59 -> 
             RGBColor[
              0.343603248128129, 0.4720335963523534, 0.9431150730276702], 47 -> 
             RGBColor[
              0.3638355126899981, 0.4895577670126598, 0.9444042550348634], 
             159 -> RGBColor[
              0.3166815040373448, 0.44871533474711806`, 0.9413996433001689], 
             55 -> RGBColor[
              0.9097997953709828, 0.9309136772440032, 0.9912587107419913], 49 -> 
             RGBColor[
              0.3098439674360884, 0.44279300420769185`, 0.9409639615141331], 
             82 -> RGBColor[0.178927, 0.305394, 0.933501], 199 -> 
             RGBColor[
              0.28259747639759025`, 0.4143582437817145, 0.9394048802641168], 
             89 -> RGBColor[
              0.3244501390099797, 0.45544413589746746`, 0.9418946538510911], 
             144 -> RGBColor[
              0.2914280604636203, 0.42363974752647965`, 0.9399077689629989], 
             78 -> RGBColor[
              0.2939805151653032, 0.4263225392529236, 0.9400531274822413], 42 -> 
             RGBColor[
              0.25754278755946713`, 0.3880241772538239, 0.9379780527998763], 
             154 -> RGBColor[
              0.6712735641690258, 0.7431232772876699, 0.9678699335344035], 
             168 -> RGBColor[
              0.26564416024036586`, 0.3965392335981439, 0.9384394139891467], 
             121 -> 
             RGBColor[
              0.4119553647190603, 0.5312367642661473, 0.9474704094554408], 
             128 -> RGBColor[
              0.46682593237298575`, 0.5780293480258085, 0.9511693939175881], 
             115 -> RGBColor[
              0.4460761769504371, 0.5607904968590783, 0.9496445574389746], 61 -> 
             RGBColor[
              0.39769750853069497`, 0.518887325856474, 0.9465619114668453], 
             93 -> RGBColor[
              0.3081711467371634, 0.4412377927729567, 0.9408612629571007], 88 -> 
             RGBColor[
              0.3258798817492446, 0.45668250719725917`, 0.9419857557941651], 
             21 -> RGBColor[
              0.38779070129509796`, 0.5103065473596095, 0.9459306584700388], 
             62 -> RGBColor[
              0.32035753226273406`, 0.4518993256333994, 0.9416338765681066], 
             136 -> RGBColor[
              0.22108698462417198`, 0.3497068169374207, 0.9359019487542386], 
             190 -> RGBColor[
              0.38601275665963014`, 0.508766581078463, 0.9458173694100415], 
             57 -> RGBColor[
              0.5597309068748542, 0.653453791647831, 0.9584832138325102], 111 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 63 -> 
             RGBColor[
              0.38404443010908984`, 0.5070617155513539, 0.9456919493827639], 
             75 -> RGBColor[
              0.26564416024036586`, 0.3965392335981439, 0.9384394139891467], 
             30 -> RGBColor[
              0.24091959553492592`, 0.3705521484647823, 0.9370313866058875], 
             5 -> RGBColor[
              0.8494585280057952, 0.8827991885670718, 0.9855033067934146], 
             171 -> RGBColor[
              0.38404443010908984`, 0.5070617155513539, 0.9456919493827639], 
             102 -> RGBColor[
              0.9460918671997839, 0.9593159833408407, 0.9761365867246516], 31 -> 
             RGBColor[
              0.5547788487969316, 0.6494334878124994, 0.9580933696806297], 96 -> 
             RGBColor[
              0.34739152723584266`, 0.4753148133110108, 0.9433564588225699], 
             70 -> RGBColor[
              0.41198238736370685`, 0.5312601699227426, 0.9474721313144625], 
             52 -> RGBColor[
              0.3779687218185608, 0.5017992424040755, 0.9453048106230293], 
             183 -> RGBColor[
              0.3838246488361832, 0.5068713520592901, 0.9456779451143992], 
             158 -> RGBColor[
              0.8133645289877482, 0.8541258189353859, 0.9820322329919724], 13 -> 
             RGBColor[
              0.708260064256895, 0.7720174122641253, 0.9715564022046675], 170 -> 
             RGBColor[
              0.7624854576334931, 0.8143787016981774, 0.9769610826513349], 86 -> 
             RGBColor[
              0.34641196946842284`, 0.47446636960687666`, 0.9432940422678189],
              18 -> RGBColor[
              0.36193961040797706`, 0.48791563174679253`, 0.9442834498179336],
              153 -> RGBColor[
              0.40938009809493964`, 0.5290061977529981, 0.9473063157433707], 
             58 -> RGBColor[
              0.4026120746537408, 0.5231440760189807, 0.9468750632744256], 22 -> 
             RGBColor[
              0.8605404245232352, 0.4596284640189423, 0.2053438505662323], 66 -> 
             RGBColor[
              0.3258798817492446, 0.45668250719725917`, 0.9419857557941651], 
             143 -> RGBColor[
              0.41588961887805015`, 0.5346444174773007, 0.9477210966515273], 
             119 -> RGBColor[
              0.40062685793987546`, 0.5214245810813238, 0.9467485670208763], 
             145 -> RGBColor[
              0.2877954223349315, 0.4198216145306676, 0.9397008955955766], 91 -> 
             RGBColor[
              0.5276986146085718, 0.6274485337477411, 0.9559615144471557], 
             177 -> RGBColor[
              0.37482035966154165`, 0.49907228934494857`, 0.9451041997703713],
              200 -> RGBColor[
              0.40706190135834586`, 0.5269982922557164, 0.9471586022972158], 
             114 -> RGBColor[
              0.2767022499414459, 0.408161986997361, 0.9390691558386455], 24 -> 
             RGBColor[
              0.5522626630322495, 0.6473907348558535, 0.9578952863201419], 
             176 -> RGBColor[
              0.9647390529740835, 0.892718687396814, 0.31751830858577246`], 
             79 -> RGBColor[
              0.303484980188015, 0.4363123346096817, 0.9405943927046888], 109 -> 
             RGBColor[
              0.2542749778158753, 0.38458950202220443`, 0.93779195586927], 
             135 -> RGBColor[
              0.7010415910713886, 0.7663782861491797, 0.9708369322580034], 
             108 -> RGBColor[
              0.23924047278419946`, 0.3687872839912374, 0.9369357630492732], 
             191 -> RGBColor[
              0.7260864812277231, 0.7859435446875233, 0.9733331728509816], 14 -> 
             RGBColor[
              0.5019033623872169, 0.6065067859315755, 0.9539308177011683], 
             185 -> RGBColor[
              0.2244011160398623, 0.35319017918337936`, 0.9360906836355442], 
             32 -> RGBColor[
              0.40957606763179255`, 0.5291759367161047, 0.9473188027489698], 
             122 -> 
             RGBColor[
              0.378004193520771, 0.5018299662096704, 0.9453070708485277], 187 -> 
             RGBColor[
              0.37927169578795095`, 0.5029278129669853, 0.9453878349721841], 
             193 -> RGBColor[
              0.6248362554600455, 0.7063092465918193, 0.9636085453618866], 
             100 -> RGBColor[
              0.9932228695765069, 0.9879127282341693, 0.5037293608827064], 
             180 -> RGBColor[
              0.7052984546328854, 0.7697037803167823, 0.9712612166351617], 7 -> 
             RGBColor[
              0.5041304907798833, 0.6083148690917327, 0.9541061454064791], 
             175 -> RGBColor[
              0.38737991617357126`, 0.5099507459340036, 0.9459044836053381], 
             9 -> RGBColor[
              0.683444631288446, 0.7526314074248971, 0.9690830317597784], 90 -> 
             RGBColor[
              0.23880289880042005`, 0.36832736599049226`, 0.9369108438582296],
              174 -> RGBColor[
              0.5575189611000579, 0.6516580344208298, 0.958309081358494], 142 -> 
             RGBColor[
              0.35159838194956944`, 0.47895857942137504`, 0.9436245158849531],
              134 -> RGBColor[
              0.664971633699712, 0.7382001613085964, 0.9672418160001108], 105 -> 
             RGBColor[
              0.9757523576177134, 0.9814367285299368, 0.9259291131419458], 16 -> 
             RGBColor[
              0.2710493679441486, 0.4022204496047819, 0.9387472325715889], 
             139 -> RGBColor[
              0.3492514072525776, 0.4769257479012189, 0.9434749687326089], 
             146 -> RGBColor[
              0.2767022499414459, 0.408161986997361, 0.9390691558386455], 126 -> 
             RGBColor[
              0.8900404976029253, 0.9151581495556039, 0.9893740512815408], 
             198 -> RGBColor[
              0.4484990824671766, 0.562889095838906, 0.94979894283601], 40 -> 
             RGBColor[
              0.9647014240086329, 0.9731949603385276, 0.9446354611970255], 
             104 -> RGBColor[
              0.31835070411709293`, 0.4501611119597605, 0.9415060032532347], 
             181 -> RGBColor[
              0.40706190135834586`, 0.5269982922557164, 0.9471586022972158], 
             127 -> RGBColor[
              0.46588613536992546`, 0.5772663784813516, 0.9510954096549173], 
             76 -> RGBColor[
              0.5597309068748542, 0.653453791647831, 0.9584832138325102], 172 -> 
             RGBColor[
              0.46813026421017623`, 0.5790882633707194, 0.9512720756977368], 
             84 -> 
             RGBColor[
              0.6029745574662078, 0.6885609353021505, 0.9618875124137732], 
             184 -> RGBColor[
              0.5130092042764093, 0.6155230086896974, 0.9548051102567249], 
             151 -> RGBColor[
              0.48495849262189045`, 0.5927501772983996, 0.9525968554821387], 
             35 -> RGBColor[
              0.329554468570859, 0.45986524961203784`, 0.9422198972171288], 
             36 -> RGBColor[
              0.3095291023976604, 0.44252028393698245`, 0.9409438985923086], 
             34 -> RGBColor[
              0.868182430036507, 0.8977291197995801, 0.9872892092841284], 38 -> 
             RGBColor[
              0.45179637309345055`, 0.5657450432527389, 0.9500090432790366], 
             54 -> RGBColor[
              0.47588016261163524`, 0.5853799800219681, 0.9518821760887128], 
             60 -> RGBColor[
              0.5068608238375729, 0.6105314764680677, 0.95432108722632], 87 -> 
             RGBColor[
              0.6633884883517718, 0.7369633961304352, 0.9670840228671627], 
             141 -> RGBColor[
              0.4060801740485782, 0.5261479694030449, 0.9470960475011447], 67 -> 
             RGBColor[
              0.34943027455346376`, 0.47708067376711455`, 0.9434863659988553],
              133 -> RGBColor[
              0.2549663034666041, 0.3853161291136983, 0.9378313258423544], 98 -> 
             RGBColor[
              0.3492514072525776, 0.4769257479012189, 0.9434749687326089], 3 -> 
             RGBColor[
              0.3730529579049096, 0.4975414547755491, 0.9449915824932907], 27 -> 
             RGBColor[
              0.254074145261475, 0.3843784142740102, 0.9377805187524021], 163 -> 
             RGBColor[
              0.5432719480532819, 0.6400916674088335, 0.9571875043029234], 85 -> 
             RGBColor[
              0.4887148098793123, 0.5957997248681388, 0.9528925665364864], 83 -> 
             RGBColor[
              0.9948179828285083, 0.9913245141895117, 0.6773475944651667], 28 -> 
             RGBColor[
              0.356813033350702, 0.4834752483690359, 0.943956788861098], 44 -> 
             RGBColor[
              0.48271564166094943`, 0.5909293298490234, 0.9524202900386596], 
             189 -> RGBColor[
              0.5187876536771853, 0.6202142142294262, 0.9552600109607116], 15 -> 
             RGBColor[
              0.3486897411046127, 0.4764392609140132, 0.9434391798623225], 80 -> 
             RGBColor[
              0.8291139048769328, 0.8665769383242002, 0.9835628184775241], 
             112 -> RGBColor[
              0.2838303131380794, 0.41565403336233264`, 0.9394750884926693], 
             169 -> RGBColor[
              0.3825237812089536, 0.5057446059040919, 0.9455950549795042], 69 -> 
             RGBColor[
              0.9932013423498908, 0.9878666836731741, 0.5013862551161965], 20 -> 
             RGBColor[
              0.8897006872285947, 0.9148871939870197, 0.9893416398646848], 8 -> 
             RGBColor[
              0.3838246488361832, 0.5068713520592901, 0.9456779451143992], 
             116 -> RGBColor[
              0.3680837347095421, 0.4932373634041417, 0.9446749479853934], 97 -> 
             RGBColor[
              0.9915341008130045, 0.9907671473695616, 0.7899653887806946], 
             118 -> RGBColor[
              0.9647014240086329, 0.9731949603385276, 0.9446354611970255], 
             178 -> RGBColor[
              0.6712735641690258, 0.7431232772876699, 0.9678699335344035], 81 -> 
             RGBColor[
              0.35114533921345964`, 0.47856617657394673`, 0.9435956484024182],
              166 -> RGBColor[
              0.45179637309345055`, 0.5657450432527389, 0.9500090432790366], 
             125 -> RGBColor[
              0.34943027455346376`, 0.47708067376711455`, 0.9434863659988553],
              95 -> RGBColor[
              0.3539923776544341, 0.48103213817520607`, 0.9437770591743397], 
             157 -> RGBColor[
              0.3734749491975743, 0.4979069624233562, 0.945018471405307], 74 -> 
             RGBColor[
              0.5146865722695245, 0.6168847715910752, 0.9549371588095443], 19 -> 
             RGBColor[
              0.7386159183850431, 0.795731636222071, 0.974581990052576], 156 -> 
             RGBColor[
              0.4446556876330299, 0.5595601404082092, 0.9495540451157587], 
             167 -> RGBColor[
              0.5332585562685747, 0.6319623448598489, 0.9563992134213685], 33 -> 
             RGBColor[
              0.4215719209830879, 0.5395661419598764, 0.9480831679169978], 43 -> 
             RGBColor[
              0.39699272207705016`, 0.518276875253924, 0.9465170030972373], 
             140 -> RGBColor[
              0.5079249312768915, 0.6113953668248004, 0.9544048576618972], 
             186 -> RGBColor[
              0.2107130155740168, 0.33880311771808014`, 0.9353111665637442], 
             117 -> RGBColor[
              0.5856258837582973, 0.6744765004372247, 0.9605217612692007], 4 -> 
             RGBColor[
              0.6020395547027549, 0.687801857937385, 0.9618139055712062], 106 -> 
             RGBColor[
              0.38954406419544346`, 0.511825222177307, 0.9460423812036108], 
             65 -> RGBColor[
              0.4063748477237047, 0.5264032009297099, 0.9471148238471542], 53 -> 
             RGBColor[
              0.3366065382652643, 0.4659733979340029, 0.942669248862156], 2 -> 
             RGBColor[
              0.5773921694527153, 0.6677920002393509, 0.959873573117976], 147 -> 
             RGBColor[
              0.9283091515910091, 0.7534767061570558, 0.26117406445087615`], 
             94 -> RGBColor[
              0.7863855635318066, 0.8330496460734724, 0.9793432218480906], 23 -> 
             RGBColor[
              0.987937481383424, 0.9892798528065269, 0.8495706804815597], 194 -> 
             RGBColor[
              0.3807087779326326, 0.5041725412908598, 0.9454794045756814], 
             129 -> RGBColor[
              0.2941260636044939, 0.42647551989081706`, 0.9400614162505336], 
             99 -> RGBColor[
              0.32549096090980034`, 0.45634564351386236`, 0.9419609741021849],
              25 -> RGBColor[
              0.3781902953528615, 0.5019911582628771, 0.9453189290927051], 
             138 -> RGBColor[
              0.5992126340210362, 0.6855068363766404, 0.9615913600197896], 
             124 -> RGBColor[
              0.4503331726504298, 0.564477692571587, 0.9499158094406646], 197 -> 
             RGBColor[
              0.5973768856862216, 0.6840164931789178, 0.9614468431863054], 
             164 -> RGBColor[
              0.3530564621135596, 0.48022149517418344`, 0.9437174234636728], 
             152 -> RGBColor[
              0.684098996859768, 0.7531426027825764, 0.9691482528045339], 17 -> 
             RGBColor[
              0.9311309905212746, 0.9479225932369786, 0.9932932991780089], 
             149 -> RGBColor[
              0.3329426076355145, 0.46279988537702155`, 
               0.942435786442315]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9lnk01I33xy0ZCmPGjGUM5jOLCfGgkIjPm8rSZv1l6yGUlK0nopQSkiYJ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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.6795781771197675, 0.7487030759890514, 0.969318346740344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 78}], {
             RGBColor[
             0.438538437851828, 0.5493727293932374, 0.9501878777088095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 88}], {
             RGBColor[
             0.45448812114379866`, 0.5645527133654052, 0.9511541918647715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 89}], {
             RGBColor[
             0.4537732497741662, 0.5639335277155093, 0.9511086408932344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[
             0.7654522161658723, 0.7516031733315406, 0.6185929906397868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 122}], {
             RGBColor[
             0.4805502770295619, 0.5871264428716108, 0.9528148493919528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 136}], {
             RGBColor[
             0.4020916725812624, 0.5110648682354859, 0.9481122883448082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 138}], {
             RGBColor[
             0.5911544972796945, 0.6789648779550959, 0.9609569939775837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 144}], {
             RGBColor[
             0.43726221050098657`, 0.5480313335300154, 0.9501151984491883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 159}], {
             RGBColor[
             0.44988893228784876`, 0.5605691271403347, 0.9508611356177734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 167}], {
             RGBColor[
             0.5581774584034638, 0.6521926321967001, 0.9583609206783732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 197}], {
             RGBColor[
             0.5902366231122872, 0.6782197063562345, 0.9608847355608416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 26}], {
             RGBColor[
             0.47940384072010356`, 0.5862883395235217, 0.9526990050813464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 40}], {
             RGBColor[
             0.7710467967306741, 0.8204934802889392, 0.9522545171575008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 51}], {
             RGBColor[
             0.5697339735436642, 0.6615747318025891, 0.9592706918831195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 74}], {
             RGBColor[
             0.54603937086112, 0.6423383859152131, 0.9574053659637602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 80}], {
             RGBColor[
             0.703253037164824, 0.7671844692817755, 0.9717181957977501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 121}], {
             RGBColor[
             0.49467376708588784`, 0.5995143822527491, 0.9536719912867084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 158}], {
             RGBColor[
             0.6953783492202318, 0.7609589095873683, 0.9709529030549742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 164}], {
             RGBColor[
             0.4652243157831375, 0.5740067477067672, 0.9517954982908244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 166}], {
             RGBColor[
             0.5145942712730829, 0.6167685217460449, 0.9549413081985063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 169}], {
             RGBColor[
             0.47995797533083445`, 0.5867683030717215, 0.9527343140487401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 184}], {
             RGBColor[
             0.5452006868645622, 0.6416575044645242, 0.9573393416873505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 5}], {
             RGBColor[
             0.6112557429553525, 0.6901703216713104, 0.9652474446433527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 10}], {
             RGBColor[
             0.373263953551242, 0.49772420859945266`, 0.9450050269492989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 11}], {
             RGBColor[
             0.349271959407355, 0.4769435491447057, 0.9434762782977378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 15}], {
             RGBColor[
             0.3608713495047612, 0.4869903578447812, 0.9442153811778067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 20}], {
             RGBColor[
             0.6313768225667522, 0.7062143243812844, 0.9671666111789878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 28}], {
             RGBColor[
             0.3649329956278058, 0.4905083515722925, 0.9444741856771943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 48}], {
             RGBColor[
             0.3377006809804914, 0.4663295879037355, 0.9427606244343396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 63}], {
             RGBColor[
             0.37854869400699975`, 0.5023015851634516, 0.9453417659380273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 77}], {
             RGBColor[
             0.32067789499267396`, 0.44843756052357, 0.9417912019552885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 106}], {
             RGBColor[
             0.38129851105017654`, 0.504683338476428, 0.9455169818484508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 186}], {
             RGBColor[
             0.2918829867394632, 0.41817228624681463`, 0.9401513745285175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 189}], {
             RGBColor[
             0.44592030579104747`, 0.5588778345024876, 0.9501257967270011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 41}], {
             RGBColor[
             0.4782402554844599, 0.5846112661799279, 0.9528097738890114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 66}], {
             RGBColor[
             0.4639597182259998, 0.5722421825673221, 0.9518998306826856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 80}], {
             RGBColor[
             0.7155767297898439, 0.7771893981307927, 0.9726883620243651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 81}], {
             RGBColor[
             0.4765924469581073, 0.5831840172556659, 0.9527047769868122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 168}], {
             RGBColor[
             0.4338418574715604, 0.5421705457677645, 0.9501266597801764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 172}], {
             RGBColor[
             0.5350849094564656, 0.6334450606540523, 0.9565429906344715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 173}], {
             RGBColor[
             0.722522054599387, 0.7827274116081027, 0.9733508133048641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 184}], {
             RGBColor[
             0.5575243794895821, 0.6516624333135412, 0.9583095079139655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 198}], {
             RGBColor[
             0.5252693185849657, 0.6253454768881455, 0.9558064242036081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 9}], {
             RGBColor[
             0.7664515796471206, 0.8177152979959845, 0.9772931692765965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.5874747444577978, 0.6695724160404671, 0.9637321404477998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 15}], {
             RGBColor[
             0.599074134555204, 0.6796192247405425, 0.9644712433278686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 17}], {
             RGBColor[
             0.8902947592635349, 0.9153608909020252, 0.9893983029857117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 20}], {
             RGBColor[
             0.869579607617195, 0.8988431912770458, 0.9874224733290498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 28}], {
             RGBColor[
             0.6031357806782487, 0.6831372184680539, 0.9647300478272562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 48}], {
             RGBColor[
             0.5759034660309342, 0.6589584547994969, 0.9630164865844015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 63}], {
             RGBColor[
             0.6167514790574425, 0.6949304520592129, 0.9655976280880892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[
             0.5588806800431168, 0.6410664274193314, 0.9620470641053505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 102}], {
             RGBColor[
             0.8977751976027896, 0.9210575859539563, 0.9808199467590331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 106}], {
             RGBColor[
             0.6195012961006193, 0.6973122053721894, 0.9657728439985127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 112}], {
             RGBColor[
             0.5666444205719373, 0.6492266109647022, 0.9624891976430419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 140}], {
             RGBColor[
             0.6786917296413434, 0.7470972776959361, 0.9699540822276559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 189}], {
             RGBColor[
             0.6841230908414903, 0.751506701398249, 0.9703816588770631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 12}], {
             RGBColor[
             0.43125704031528733`, 0.5407105807890878, 0.9498650527145889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 13}], {
             RGBColor[
             0.48962124704672183`, 0.5870837528368492, 0.9551499113750272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 14}], {
             RGBColor[
             0.38644289611188276`, 0.5043284396705743, 0.9463371191232777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 16}], {
             RGBColor[
             0.2710158988903486, 0.40218527150717753`, 0.938745326558488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 59}], {
             RGBColor[
             0.3072928389823388, 0.4370918448809633, 0.9409292467865287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 64}], {
             RGBColor[
             0.5404404555930529, 0.6267841047935332, 0.9602150951504207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 83}], {
             RGBColor[
             0.6329002063325284, 0.6967373037995424, 0.8080455075052768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 86}], {
             RGBColor[
             0.3086971996524857, 0.4383082315082249, 0.941018731406603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 124}], {
             RGBColor[
             0.36065780124348923`, 0.48331389299058003`, 0.9443296149930258]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 137}], {
             RGBColor[
             0.5979134764876726, 0.6725300140986874, 0.9657185554262298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 161}], {
             RGBColor[
             0.5430803592177027, 0.6288464175691203, 0.9604782160724238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 175}], {
             RGBColor[
             0.3291811730050599, 0.4560504196717884, 0.9423239520753626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 176}], {
             RGBColor[
             0.6178607414053161, 0.6474343904031936, 0.6281308645655798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 186}], {
             RGBColor[
             0.2408477227052827, 0.37047660556382667`, 0.9370272935545656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 187}], {
             RGBColor[
             0.3251270628122498, 0.4525389531882792, 0.9420656277587856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 193}], {
             RGBColor[
             0.44790934264829707`, 0.5542296700006962, 0.9511759829536368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 199}], {
             RGBColor[
             0.27678995311706944`, 0.4082541685956438, 0.939074150404752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 18}], {
             RGBColor[
             0.43303505059393016`, 0.5481152504192626, 0.9491947976122064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 42}], {
             RGBColor[
             0.3808366391696752, 0.4981695231727783, 0.9460420991031777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 47}], {
             RGBColor[
             0.43398300173494064`, 0.5489363180521962, 0.9492552002206712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.49000532669575925`, 0.5968474245568505, 0.952994160747596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 58}], {
             RGBColor[
             0.45337128271681204`, 0.5657294725553568, 0.9504906043404524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.4509139996552891, 0.5636010974741034, 0.9503340284366621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 73}], {
             RGBColor[
             0.4185365492076989, 0.5355573772343771, 0.9482709659243971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 88}], {
             RGBColor[
             0.41500518626456395`, 0.532498688144496, 0.948045950600322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 94}], {
             RGBColor[
             0.6452580271558449, 0.7206822575826026, 0.9667246836272849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 97}], {
             RGBColor[
             0.7478322957964438, 0.7995410082306471, 0.8720357670935868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 115}], {
             RGBColor[
             0.4751033338651602, 0.5845526829754055, 0.9518753514227268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 153}], {
             RGBColor[
             0.4567552944374115, 0.5686605334223653, 0.9507062305749249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 160}], {
             RGBColor[
             0.4000679332331649, 0.518382832567975, 0.9471372928499434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 188}], {
             RGBColor[
             0.6262415566087332, 0.7058264462606696, 0.9648292995621698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 55}], {
             RGBColor[
             0.646812222103583, 0.7188925146516467, 0.9684683279281953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 62}], {
             RGBColor[
             0.35209109054945864`, 0.47938533884634477`, 0.9436559108412529]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 68}], {
             RGBColor[
             0.5140812208356308, 0.614476100030718, 0.9554315863456646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 75}], {
             RGBColor[
             0.3247344045382745, 0.451705292828717, 0.9420586795517729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 96}], {
             RGBColor[
             0.36560808803601297`, 0.49109308268515045`, 0.9445172019684845]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 99}], {
             RGBColor[
             0.3546578048729918, 0.4816084977865762, 0.943819459608292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 107}], {
             RGBColor[
             0.3697119129231051, 0.4946476095381135, 0.9447786940614202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 147}], {
             RGBColor[
             0.6560669002135961, 0.630174029108173, 0.6034260047826376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 156}], {
             RGBColor[
             0.4142401682346065, 0.5332157462337497, 0.9476159951150789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 157}], {
             RGBColor[
             0.3786497990168788, 0.5023891572413232, 0.9453482082598531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 179}], {
             RGBColor[
             0.3988089479272937, 0.5198499987992394, 0.9466327314023892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 185}], {
             RGBColor[
             0.30411288243802276`, 0.43003076562133474`, 0.9408843143749717]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 194}], {
             RGBColor[
             0.3822667133844079, 0.5055219466750749, 0.9455786748450403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.5044677960991232, 0.6044885254693797, 0.9555220029309817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 17}], {
             RGBColor[
             0.8072878109048602, 0.8502770003309379, 0.9811881654688936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 20}], {
             RGBColor[
             0.7865726592585204, 0.8337593007059584, 0.9792123358122315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 28}], {
             RGBColor[
             0.5201288323195741, 0.6180533278969664, 0.9565199103104383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 63}], {
             RGBColor[
             0.5337445306987679, 0.6298465614881255, 0.9573874905712711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 77}], {
             RGBColor[
             0.4758737316844422, 0.575982536848244, 0.9538369265885323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 97}], {
             RGBColor[
             0.8374893660507252, 0.8716992773972294, 0.8795242102702365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 102}], {
             RGBColor[
             0.814768249244115, 0.8559736953828689, 0.9726098092422151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.5364943477419447, 0.6322283148011021, 0.9575627064816946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 112}], {
             RGBColor[
             0.4836374722132627, 0.5841427203936149, 0.9542790601262239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 140}], {
             RGBColor[
             0.5956847812826688, 0.6820133871248488, 0.9617439447108378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 189}], {
             RGBColor[
             0.6011161424828156, 0.6864228108271617, 0.962171521360245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 14}], {
             RGBColor[
             0.4376891557923956, 0.5522068741774658, 0.9494746445532376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.3610823451510935, 0.4871731116686847, 0.9442288256338147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 28}], {
             RGBColor[
             0.36514399127413816`, 0.49069110539619604`, 0.9444876301332026]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 48}], {
             RGBColor[
             0.33791167662682375`, 0.46651234172763906`, 0.9427740688903476]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 59}], {
             RGBColor[
             0.3585390986628516, 0.4849702793878548, 0.9440667722164886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 77}], {
             RGBColor[
             0.32088889063900633`, 0.4486203143474735, 0.9418046464112966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 186}], {
             RGBColor[
             0.29209398238579554`, 0.41835504007071816`, 0.9401648189845256]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 193}], {
             RGBColor[
             0.4991556023288099, 0.6021081045075878, 0.9543135083835967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 15}], {
             RGBColor[
             0.3370903510072065, 0.46639245221393777`, 0.9427000769822538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 17}], {
             RGBColor[
             0.6283109757155374, 0.7021341183754205, 0.9676271366400969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 20}], {
             RGBColor[
             0.6075958240691975, 0.685616418750441, 0.9656513069834349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 28}], {
             RGBColor[
             0.3411519971302512, 0.46991044594144915`, 0.9429588814816414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 48}], {
             RGBColor[
             0.3139196824829368, 0.44573168227289217`, 0.9412453202387867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 63}], {
             RGBColor[
             0.3547676955094451, 0.4817036795326082, 0.9438264617424744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 77}], {
             RGBColor[
             0.29689689649511936`, 0.42783965489272663`, 0.9402758977597356]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 106}], {
             RGBColor[
             0.3575175125526219, 0.4840854328455847, 0.9440016776528979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 112}], {
             RGBColor[
             0.30466063702393986`, 0.43599983843809753`, 0.940718031297427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 140}], {
             RGBColor[
             0.41670794609334594`, 0.5338705051693314, 0.9481829158820411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 189}], {
             RGBColor[
             0.4221393072934928, 0.5382799288716443, 0.9486104925314482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 13}], {
             RGBColor[
             0.6498958575254605, 0.7256442402163639, 0.9662715435442292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 14}], {
             RGBColor[
             0.5467175065906216, 0.642888927050089, 0.9574587512924795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.43129050936908736`, 0.5407457588866922, 0.9498669587276898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 23}], {
             RGBColor[
             0.789734566088725, 0.8342754604875646, 0.9052786826826753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 25}], {
             RGBColor[
             0.48486097307344384`, 0.5906311132157398, 0.953152806988248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 59}], {
             RGBColor[
             0.46756744946107753`, 0.575652332260478, 0.9520508789557305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.7007150660717917, 0.765344592173048, 0.9713367273196225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 86}], {
             RGBColor[
             0.46897181013122446`, 0.5768687188877396, 0.9521403635758048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 87}], {
             RGBColor[
             0.6274600695728989, 0.7081172321495188, 0.9640353538754767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 95}], {
             RGBColor[
             0.47276201422423014`, 0.5801516031719043, 0.9523818720290653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 108}], {
             RGBColor[
             0.4153860617891128, 0.52402917607992, 0.9489612239665319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 154}], {
             RGBColor[
             0.631402607481526, 0.7111971727281362, 0.9644283092090972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 161}], {
             RGBColor[
             0.7033549696964414, 0.767406904948635, 0.9715998482416257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 175}], {
             RGBColor[
             0.4894557834837987, 0.594610907051303, 0.9534455842445644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 193}], {
             RGBColor[
             0.6081839531270359, 0.6927901573802109, 0.9622976151228386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 16}], {
             RGBColor[
             0.4896547161005218, 0.5871189309344537, 0.9551518173881282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 64}], {
             RGBColor[
             0.7590792728032261, 0.8117177642208093, 0.9766215859800609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 69}], {
             RGBColor[
             0.8507307033033928, 0.8799420479686497, 0.7364713286604321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 82}], {
             RGBColor[
             0.44359353212844754`, 0.5387057061320627, 0.9525287011023338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 83}], {
             RGBColor[
             0.8515390235427016, 0.8816709632268185, 0.8244519983349171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 86}], {
             RGBColor[
             0.527336016862659, 0.623241890935501, 0.9574252222362432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 101}], {
             RGBColor[
             0.7477824157358095, 0.8028925736204497, 0.9754956208427124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 108}], {
             RGBColor[
             0.47375026852054725`, 0.5704023481276814, 0.9542460826269703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 110}], {
             RGBColor[
             0.7057891196062471, 0.7700870915231643, 0.9713101215341815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 124}], {
             RGBColor[
             0.5792966184536624, 0.6682475524178562, 0.960736105822666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 127}], {
             RGBColor[
             0.5870730998134103, 0.6746418953727384, 0.9613259059297925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 137}], {
             RGBColor[
             0.8165522936978458, 0.8574636735259635, 0.98212504625587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 161}], {
             RGBColor[
             0.7617191764278759, 0.8137800769963964, 0.9768847069020641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 175}], {
             RGBColor[
             0.5478199902152332, 0.6409840790990644, 0.9587304429050028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 176}], {
             RGBColor[
             0.8364995586154893, 0.8323680498304697, 0.6445373553952201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 187}], {
             RGBColor[
             0.543765880022423, 0.6374726126155553, 0.9584721185884258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 199}], {
             RGBColor[
             0.49542877032724264`, 0.5931878280229199, 0.9554806412343921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 15}], {
             RGBColor[
             0.4252965517459148, 0.5414730234227944, 0.9486849987817454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 48}], {
             RGBColor[
             0.402125883221645, 0.5208122534817488, 0.9472302420382783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 59}], {
             RGBColor[
             0.42275330525767296`, 0.5392701911419644, 0.9485229453644193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 186}], {
             RGBColor[
             0.35630818898061684`, 0.4726549518248278, 0.9446209921324562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 193}], {
             RGBColor[
             0.5633698089236312, 0.6564080162616974, 0.9587696815315274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 28}], {
             RGBColor[
             0.35275138722765736`, 0.4799572546415245, 0.9436979843617103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 48}], {
             RGBColor[
             0.32551907258034296`, 0.4557784909729675, 0.9419844231188554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 59}], {
             RGBColor[
             0.3461464946163708, 0.47423642863318327`, 0.9432771264449964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 63}], {
             RGBColor[
             0.3663670856068513, 0.4917504882326835, 0.9445655646225433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 77}], {
             RGBColor[
             0.30849628659252554`, 0.43788646359280203`, 0.9410150006398044]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 106}], {
             RGBColor[
             0.36911690265002806`, 0.49413224154566004`, 0.9447407805329666]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.31626002712134604`, 0.4460466471381729, 0.9414571341774959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 140}], {
             RGBColor[
             0.4283073361907521, 0.5439173138694068, 0.9489220187621099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 193}], {
             RGBColor[
             0.4867629982823291, 0.5913742537529162, 0.9535238626121045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 64}], {
             RGBColor[
             0.5404739246468528, 0.6268192828911376, 0.9602170011635216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 83}], {
             RGBColor[
             0.6329336753863284, 0.6967724818971468, 0.8080474135183777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 86}], {
             RGBColor[
             0.30873066870628574`, 0.4383434096058293, 0.9410206374197039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 101}], {
             RGBColor[
             0.5291770675794363, 0.6179940922907781, 0.959091036026173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 124}], {
             RGBColor[
             0.3606912702972892, 0.4833490710881845, 0.9443315210061267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 127}], {
             RGBColor[
             0.36846775165703705`, 0.48974341404306676`, 0.9449213211132531]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 137}], {
             RGBColor[
             0.5979469455414725, 0.6725651921962919, 0.9657204614393307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 161}], {
             RGBColor[
             0.5431138282715027, 0.6288815956667247, 0.9604801220855247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 175}], {
             RGBColor[
             0.3292146420588599, 0.4560855977693927, 0.9423258580884635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 176}], {
             RGBColor[
             0.6178942104591161, 0.647469568500798, 0.6281327705786807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.32516053186604976`, 0.45257413128588364`, 0.9420675337718865]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 193}], {
             RGBColor[
             0.44794281170209704`, 0.5542648480983006, 0.9511778889667377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 199}], {
             RGBColor[
             0.2768234221708694, 0.40828934669324823`, 0.9390760564178529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 20}], {
             RGBColor[
             0.9104158388749346, 0.9314048936119992, 0.9913174695213469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 28}], {
             RGBColor[
             0.6439720119359883, 0.7156989208030072, 0.9686250440195534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 77}], {
             RGBColor[
             0.5997169113008565, 0.6736281297542848, 0.9659420602976476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 106}], {
             RGBColor[
             0.660337527358359, 0.7298739077071428, 0.9696678401908099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 112}], {
             RGBColor[
             0.6074806518296769, 0.6817883132996556, 0.966384193835339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 140}], {
             RGBColor[
             0.719527960899083, 0.7796589800308895, 0.973849078419953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 189}], {
             RGBColor[
             0.7249593220992299, 0.7840684037332024, 0.9742766550693602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 47}], {
             RGBColor[
             0.3628875615489876, 0.4887366993797262, 0.9443438524263985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 54}], {
             RGBColor[
             0.41890988650980615`, 0.5366478058843803, 0.9480828129533232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 58}], {
             RGBColor[
             0.38227584253085894`, 0.5055298538828866, 0.9455792565461796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 61}], {
             RGBColor[
             0.379818559469336, 0.5034014788016332, 0.9454226806423894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 73}], {
             RGBColor[
             0.34744110902174574`, 0.47535775856190704`, 0.9433596181301243]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 94}], {
             RGBColor[
             0.5741625869698919, 0.6604826389101325, 0.9618133358330121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 115}], {
             RGBColor[
             0.4040078936792071, 0.5243530643029355, 0.9469640036284541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 116}], {
             RGBColor[
             0.36501167255875955`, 0.4905764975754671, 0.9444791989016634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 153}], {
             RGBColor[
             0.3856598542514583, 0.5084609147498953, 0.9457948827806522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 160}], {
             RGBColor[
             0.32897249304721177`, 0.458183213895505, 0.9422259450556707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 174}], {
             RGBColor[
             0.4597292857540175, 0.5697868330838112, 0.9512962655882138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 188}], {
             RGBColor[
             0.55514611642278, 0.6456268275881996, 0.9599179517678971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 33}], {
             RGBColor[
             0.5800939196840655, 0.6676488890909738, 0.9613325789847869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 34}], {
             RGBColor[
             0.8033991742107751, 0.8467303780108255, 0.9809355996683522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 44}], {
             RGBColor[
             0.6106657800229963, 0.6933304830355471, 0.9635011400456177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 50}], {
             RGBColor[
             0.8502059151312478, 0.8833798351852519, 0.9620678627043799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 60}], {
             RGBColor[
             0.622738371111308, 0.7031315563450693, 0.964451538639448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 90}], {
             RGBColor[
             0.4887094085927316, 0.5820295011062816, 0.9557464169554029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 130}], {
             RGBColor[
             0.5241406198431194, 0.6191849530633673, 0.9577672841964822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 141}], {
             RGBColor[
             0.5723480462168107, 0.6609398028125579, 0.9608390187768603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 177}], {
             RGBColor[
             0.5567181390232924, 0.6474019627835098, 0.9598430949114736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.6232568602896484, 0.6991812211780277, 0.9666492143628914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 77}], {
             RGBColor[
             0.5790017596545165, 0.6571104301293053, 0.9639662306409855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 106}], {
             RGBColor[
             0.6396223757120191, 0.7133562080821634, 0.9676920105341478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 189}], {
             RGBColor[
             0.70424417045289, 0.767550704108223, 0.9723008254126981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.3486599018463792, 0.476413415648296, 0.9434372785311738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 46}], {
             RGBColor[
             0.4671220244792514, 0.5764905091461798, 0.9516843071020609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 85}], {
             RGBColor[
             0.4382527555872051, 0.5530531361138742, 0.9494116125032626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 109}], {
             RGBColor[
             0.32103283955548667`, 0.44744802469090694`, 0.9418613071696544]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 132}], {
             RGBColor[
             0.342781131818483, 0.47030685878068834`, 0.9430998402403169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 150}], {
             RGBColor[
             0.3468307869831054, 0.4745633031216738, 0.9433304621110141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 151}], {
             RGBColor[
             0.43637459695849423`, 0.5515283623290046, 0.9492637569760887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 194}], {
             RGBColor[
             0.38424973961386527`, 0.5072395443252347, 0.9457050315228601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 196}], {
             RGBColor[
             0.5682890195052321, 0.6569920868340895, 0.9607632202720717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 24}], {
             RGBColor[
             0.7577811706929066, 0.522215887631246, 0.45619432915086877`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 37}], {
             RGBColor[
             0.7423759925466883, 0.5097092700167792, 0.4549815770961716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 38}], {
             RGBColor[
             0.7242924073799737, 0.4950006570968745, 0.4535655814705004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 79}], {
             RGBColor[
             0.6748552764114951, 0.4518564208825221, 0.4504273646123845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 89}], {
             RGBColor[
             0.6818436626854834, 0.4582336879784507, 0.45086078499451854`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 118}], {
             RGBColor[
             0.8952607576850344, 0.6308172961254708, 0.45177438744316334`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 119}], {
             RGBColor[
             0.707235902328782, 0.48022716970640283`, 0.45247875605111365`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 122}], {
             RGBColor[
             0.6996950141890805, 0.47369563141585164`, 0.45199825732699744`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 128}], {
             RGBColor[
             0.729302260473152, 0.49909542535456436`, 0.45395236501668423`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 138}], {
             RGBColor[
             0.7734311610225022, 0.5349212548048417, 0.457426353717418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 144}], {
             RGBColor[
             0.6708363031700302, 0.4476322251881214, 0.45019849003182116`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 149}], {
             RGBColor[
             0.6846744855606617, 0.46068560447163537`, 0.45104116252492654`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 181}], {
             RGBColor[
             0.7093809168016054, 0.48208507343120033`, 0.45261543447656016`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 183}], {
             RGBColor[
             0.7016351659608846, 0.4753760933657249, 0.45212188208228793`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 190}], {
             RGBColor[
             0.7023645352353669, 0.47600783637211586`, 0.452168356847502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 192}], {
             RGBColor[
             0.6996950141890805, 0.47369563141585164`, 0.45199825732699744`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 25}], {
             RGBColor[
             0.6830638883681428, 0.7456355055347019, 0.8974448047871324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 43}], {
             RGBColor[
             0.692465101730237, 0.7537783640302254, 0.8980438417893986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 49}], {
             RGBColor[
             0.6488907244097561, 0.7160364285071094, 0.8952673209978463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 64}], {
             RGBColor[
             0.8989179813664906, 0.9203489844920101, 0.9156287251185069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 67}], {
             RGBColor[
             0.6686838779684439, 0.7331802632868207, 0.8965285232402075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 87}], {
             RGBColor[
             0.8256629848675978, 0.863121624468481, 0.9083273516743612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 95}], {
             RGBColor[
             0.670964929518929, 0.7351559954908664, 0.8966738698279497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 103}], {
             RGBColor[
             0.7383261456313681, 0.7925397888373329, 0.901231623509023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 108}], {
             RGBColor[
             0.6135889770838117, 0.6790335683988822, 0.8932532217654164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 129}], {
             RGBColor[
             0.6410317724939589, 0.707877686348672, 0.8948160483660467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 131}], {
             RGBColor[
             0.9798476792090396, 0.9528373409289549, 0.5971778975744737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 143}], {
             RGBColor[
             0.7019135501307371, 0.7619621351419138, 0.8986458885665435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 154}], {
             RGBColor[
             0.8296055227762249, 0.8662015650470984, 0.9087203070079817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 162}], {
             RGBColor[
             0.8762004360428759, 0.9026018654254631, 0.9133644525081803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.4031684041468622, 0.5158845745649319, 0.947837902536272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 37}], {
             RGBColor[
             0.529154895812922, 0.6286308084341533, 0.956076158238096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 56}], {
             RGBColor[
             0.43781543116110416`, 0.5509488744738552, 0.9498604999644975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 79}], {
             RGBColor[
             0.4278738216101322, 0.5418515347327676, 0.9492448395124153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 89}], {
             RGBColor[
             0.4383564010211146, 0.5514174353766605, 0.9498949700856165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 118}], {
             RGBColor[
             0.7584820435204411, 0.8102928475971906, 0.9512653737585837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 119}], {
             RGBColor[
             0.47644476048606244`, 0.5844076579685886, 0.9523219266705091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 125}], {
             RGBColor[
             0.4508464687928566, 0.5622357043114841, 0.9506908261594986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 144}], {
             RGBColor[
             0.42184536174793485`, 0.5355152411911666, 0.9489015276415704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 149}], {
             RGBColor[
             0.442602635333882, 0.5550953101164375, 0.9501655363812285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 170}], {
             RGBColor[
             0.6573740603328713, 0.7308847182770155, 0.9674281844857384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 190}], {
             RGBColor[
             0.46913770984593983`, 0.5780786579671582, 0.9518563278650917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 195}], {
             RGBColor[
             0.5747376954755994, 0.6656369786820383, 0.9596646032028389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 197}], {
             RGBColor[
             0.5748197743592356, 0.6657036140173856, 0.9596710647532236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[
             0.38759150871495585`, 0.5101340167584005, 0.9459179660949713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 49}], {
             RGBColor[
             0.344017131394475, 0.4723920812352845, 0.943141445303419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 64}], {
             RGBColor[
             0.5940443883512094, 0.6767046372201853, 0.9635028494240796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 67}], {
             RGBColor[
             0.36381028495316264`, 0.4895359160149958, 0.9444026475457802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 87}], {
             RGBColor[
             0.5207893918523167, 0.6194772771966561, 0.9562014759799339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 95}], {
             RGBColor[
             0.3660913365036478, 0.4915116482190416, 0.9445479941335224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 103}], {
             RGBColor[
             0.43345255261608695`, 0.548895441565508, 0.9491057478145957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 108}], {
             RGBColor[
             0.3087153840685305, 0.43538922112705725`, 0.9411273460709891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 129}], {
             RGBColor[
             0.3361581794786777, 0.46423333907684705`, 0.9426901726716194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 131}], {
             RGBColor[
             0.6749740861937583, 0.70919299365713, 0.6450520218800464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 143}], {
             RGBColor[
             0.3970399571154558, 0.5183177878700889, 0.9465200128721162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 154}], {
             RGBColor[
             0.5247319297609436, 0.6225572177752735, 0.9565944313135544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 162}], {
             RGBColor[
             0.5713268430275946, 0.6589575181536381, 0.961238576813753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 40}], {
             RGBColor[
             0.6730584679980623, 0.7389898195731099, 0.945079949120871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 51}], {
             RGBColor[
             0.4717456448110524, 0.5800710710867598, 0.9520961238464899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 74}], {
             RGBColor[
             0.44805104212850816`, 0.5608347251993838, 0.9502307979271305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 80}], {
             RGBColor[
             0.6052647084322123, 0.6856808085659463, 0.9645436277611203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 121}], {
             RGBColor[
             0.3966854383532761, 0.5180107215369198, 0.9464974232500787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 158}], {
             RGBColor[
             0.59739002048762, 0.6794552488715391, 0.9637783350183445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 164}], {
             RGBColor[
             0.36723598705052574`, 0.4925030869909379, 0.9446209302541948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.4166059425404712, 0.5352648610302156, 0.9477667401618766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 169}], {
             RGBColor[
             0.3819696465982227, 0.5052646423558922, 0.9455597460121105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 184}], {
             RGBColor[
             0.44721235813195054`, 0.5601538437486949, 0.9501647736507208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 37}], {
             RGBColor[
             0.3800606369275348, 0.49712464814323165`, 0.9460187744542261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 56}], {
             RGBColor[
             0.2887211722757169, 0.41944271418293355`, 0.9398031161806275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 67}], {
             RGBColor[
             0.30175220990746937`, 0.4307295440205624, 0.9406334423756286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 119}], {
             RGBColor[
             0.32735050160067525`, 0.452901497677667, 0.9422645428866392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 125}], {
             RGBColor[
             0.30175220990746937`, 0.4307295440205624, 0.9406334423756286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 128}], {
             RGBColor[
             0.36045003881723037`, 0.48120388114990936`, 0.9444749563349951]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 133}], {
             RGBColor[
             0.25452022436403954`, 0.38484727169385424`, 0.9378059222973782]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 190}], {
             RGBColor[
             0.32004345096055253`, 0.4465724976762366, 0.9417989440812218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 195}], {
             RGBColor[
             0.4256434365902122, 0.5341308183911166, 0.9496072194189691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 48}], {
             RGBColor[
             0.32958071870338757`, 0.4592964847004789, 0.9422432276182432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 63}], {
             RGBColor[
             0.37042873172989593`, 0.4952684819601949, 0.9448243691219309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 77}], {
             RGBColor[
             0.3125579327155702, 0.4414044573203134, 0.9412738051391921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 106}], {
             RGBColor[
             0.37317854877307277`, 0.4976502352731714, 0.9449995850323545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 112}], {
             RGBColor[
             0.3203216732443907, 0.44956464086568426`, 0.9417159386768836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 140}], {
             RGBColor[
             0.4323689823137968, 0.5474353075969182, 0.9491808232614976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 189}], {
             RGBColor[
             0.43780034351394365`, 0.5518447312992311, 0.9496083999109048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 35}], {
             RGBColor[
             0.5528072311360206, 0.6424242410282947, 0.9602669813812195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 47}], {
             RGBColor[
             0.5699477531955901, 0.6572704997286056, 0.9613591602900868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 88}], {
             RGBColor[
             0.5509699377252134, 0.6408328698209053, 0.9601499106697376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 89}], {
             RGBColor[
             0.550255066355581, 0.6402136841710094, 0.9601043596982006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 113}], {
             RGBColor[
             0.8619340327472871, 0.8278833297870407, 0.627588709444753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 122}], {
             RGBColor[
             0.5770320936109766, 0.6634065993271109, 0.9618105681969189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 136}], {
             RGBColor[
             0.4985734891626771, 0.587345024690986, 0.9571080071497744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 138}], {
             RGBColor[
             0.6876363138611092, 0.7552450344105959, 0.9699527127825499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 142}], {
             RGBColor[
             0.5638291878253758, 0.6519709059329633, 0.9609692907151317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 144}], {
             RGBColor[
             0.5337440270824012, 0.6243114899855156, 0.9591109172541545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 153}], {
             RGBColor[
             0.5927200458980609, 0.6769947150987747, 0.9628101906443405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 159}], {
             RGBColor[
             0.5463707488692635, 0.6368492835958347, 0.9598568544227395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 167}], {
             RGBColor[
             0.6546592749848784, 0.7284727886522002, 0.9673566394833393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 181}], {
             RGBColor[
             0.5915609475297641, 0.6759907623501339, 0.962736333921263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 188}], {
             RGBColor[
             0.7622063080693826, 0.814160627937079, 0.9769332596315854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 41}], {
             RGBColor[
             0.29768027590054535`, 0.4259864114436265, 0.9404185144063522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 65}], {
             RGBColor[
             0.3236472216293153, 0.4484776746972461, 0.9420731052265208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 66}], {
             RGBColor[
             0.28339973864208523`, 0.41361732783102073`, 0.9395085712000263]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 90}], {
             RGBColor[
             0.239861247167673, 0.3694397572276373, 0.9369711152320586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 110}], {
             RGBColor[
             0.47211888524526263`, 0.5693544596234928, 0.9540476137347915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 162}], {
             RGBColor[
             0.5026914931186268, 0.5932380132545907, 0.9570948055703442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 180}], {
             RGBColor[
             0.4731090250839057, 0.5701279643907823, 0.9541463016205246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 198}], {
             RGBColor[
             0.3447093390010513, 0.4667206221518442, 0.9434151647209488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 38}], {
             RGBColor[
             0.5032876109451911, 0.6075892655326192, 0.9540512064798332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[
             0.7597401364027823, 0.8113142240755136, 0.9513644154388277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 46}], {
             RGBColor[
             0.5506160982301682, 0.6460539793726249, 0.9577656627073563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 80}], {
             RGBColor[
             0.6919463768369323, 0.7580052130683499, 0.970828094079077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 98}], {
             RGBColor[
             0.45201512802475463`, 0.5631796178568591, 0.9507841692066193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 117}], {
             RGBColor[
             0.5702023662776144, 0.6619549941248621, 0.9593075654749152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 120}], {
             RGBColor[
             0.4714377823893207, 0.5800025448564534, 0.9520217635679507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 121}], {
             RGBColor[
             0.483367106757996, 0.5903351260393234, 0.9527818895680353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 146}], {
             RGBColor[
             0.41574054936918875`, 0.5287977374049302, 0.9485812627596376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 151}], {
             RGBColor[
             0.519868670709411, 0.6210918325554495, 0.9553451125813842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 171}], {
             RGBColor[
             0.46941163945301073`, 0.5782476016819267, 0.9518926595316968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 173}], {
             RGBColor[
             0.6988917016464753, 0.7635432265456599, 0.9714905453595759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 178}], {
             RGBColor[
             0.6130262064829788, 0.6962783825500847, 0.9629816516075167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 196}], {
             RGBColor[
             0.6517830932561489, 0.7265555570605344, 0.9668445758773672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 53}], {
             RGBColor[
             0.37309130294852844`, 0.49757466732505384`, 0.9449940258055629]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 82}], {
             RGBColor[
             0.2942515338158963, 0.4172849683580524, 0.9404099013744849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 83}], {
             RGBColor[
             0.7021970252301504, 0.7602502254528083, 0.8123331986070683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 100}], {
             RGBColor[
             0.7013994686041497, 0.7585443324751371, 0.7255240818158382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 101}], {
             RGBColor[
             0.5984404174232583, 0.6814718358464396, 0.9633768211148634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 123}], {
             RGBColor[
             0.4622297896394739, 0.5731102962829793, 0.951135732673867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 127}], {
             RGBColor[
             0.43773110150085903`, 0.5532211575987283, 0.9492071062019436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 130}], {
             RGBColor[
             0.35962069446649414`, 0.4859071033103842, 0.944135690544679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 135}], {
             RGBColor[
             0.5553088293515906, 0.6477771114326423, 0.9590778675034866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 148}], {
             RGBColor[
             0.47873545180488314`, 0.5865103364004653, 0.9524351188617607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 163}], {
             RGBColor[
             0.47642400784253724`, 0.5846338020624691, 0.9522531535259466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 165}], {
             RGBColor[
             0.3731441442225565, 0.4976204357807372, 0.9449973928048183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 176}], {
             RGBColor[
             0.6871575603029381, 0.7109473120564593, 0.6324185556673712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 187}], {
             RGBColor[
             0.39442388170987175`, 0.516051874841545, 0.946353318860577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 41}], {
             RGBColor[
             0.38800643862462636`, 0.5104934081911735, 0.9459444050619072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 44}], {
             RGBColor[
             0.45214378132201866`, 0.5652477359044499, 0.9502517289778287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 57}], {
             RGBColor[
             0.49065141392897105`, 0.5965099668038537, 0.953283190874754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 66}], {
             RGBColor[
             0.37372590136616624`, 0.4981243245785678, 0.9450344618555815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 90}], {
             RGBColor[
             0.330187409891754, 0.45394675397518436`, 0.9424970058876136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 141}], {
             RGBColor[
             0.4138260475158331, 0.5328570556814607, 0.9475896077090713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 198}], {
             RGBColor[
             0.4350355017251323, 0.5512276188993912, 0.9489410553765039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 44}], {
             RGBColor[
             0.6754490358487282, 0.7443292248243017, 0.9698547496613941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 50}], {
             RGBColor[
             0.9149891709569797, 0.9343785769740065, 0.9684214723201563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 60}], {
             RGBColor[
             0.6875216269370399, 0.7541302981338239, 0.9708051482552242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 90}], {
             RGBColor[
             0.5534926644184635, 0.6330282428950362, 0.962100026571179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 104}], {
             RGBColor[
             0.5932665670767999, 0.6739451158796703, 0.9643976062686817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 130}], {
             RGBColor[
             0.5889238756688514, 0.6701836948521219, 0.9641208938122583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 163}], {
             RGBColor[
             0.7057271890448944, 0.7689103936042068, 0.972238356793526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 177}], {
             RGBColor[
             0.6215013948490243, 0.6984007045722643, 0.9661967045272499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 47}], {
             RGBColor[
             0.3466949906304285, 0.4747115083123488, 0.9433120761259961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 68}], {
             RGBColor[
             0.48694613070296866`, 0.5909730488070918, 0.9537025623970294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 88}], {
             RGBColor[
             0.32771717516005183`, 0.4582738784046485, 0.942102826505647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.5579700160513328, 0.6464574478427552, 0.9607815595326097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 111}], {
             RGBColor[
             0.654730822856953, 0.24270641653734595`, 0.42355196573904297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 116}], {
             RGBColor[
             0.3488191016402006, 0.47655130650808974`, 0.9434474226012611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 122}], {
             RGBColor[
             0.35377933104581505`, 0.4808476079108541, 0.9437634840328283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 138}], {
             RGBColor[
             0.4643835512959476, 0.5726860429943391, 0.9519056286184593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 142}], {
             RGBColor[
             0.34057642526021425`, 0.46941191451670644`, 0.942922206551041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 153}], {
             RGBColor[
             0.36946728333289935`, 0.494435723682518, 0.9447631064802497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 157}], {
             RGBColor[
             0.35151470888421665`, 0.478886106017697, 0.9436191843112179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 160}], {
             RGBColor[
             0.3127799221286528, 0.4441580228281276, 0.9411941687552683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 167}], {
             RGBColor[
             0.43140651241971684`, 0.5459137972359434, 0.9493095553192487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 174}], {
             RGBColor[
             0.4435367148354585, 0.5557616420164339, 0.9502644892878114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 181}], {
             RGBColor[
             0.36830818496460244`, 0.49343177093387713`, 0.9446892497571724]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 185}], {
             RGBColor[
             0.2769777923053607, 0.40652771439770863`, 0.9391552904263365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 188}], {
             RGBColor[
             0.5389535455042209, 0.6316016365208222, 0.9588861754674947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 132}], {
             RGBColor[
             0.30365033236976424`, 0.43641372706937487`, 0.9406064603014519]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 151}], {
             RGBColor[
             0.39724379750977545`, 0.517635230617691, 0.9467703770372237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 169}], {
             RGBColor[
             0.346026441803307, 0.4741324449205372, 0.9432694767859064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 200}], {
             RGBColor[
             0.35829550187800313`, 0.4847592880963494, 0.9440512504447622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 56}], {
             RGBColor[
             0.4147076639417767, 0.532188948052155, 0.9480413718824516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 79}], {
             RGBColor[
             0.4047660543908048, 0.5230916083110674, 0.9474257114303695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 118}], {
             RGBColor[
             0.7353742763011137, 0.7915329211754903, 0.9494462456765378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 119}], {
             RGBColor[
             0.45333699326673504`, 0.5656477315468884, 0.9505027985884632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 125}], {
             RGBColor[
             0.42773870157352917`, 0.5434757778897839, 0.9488716980774528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 128}], {
             RGBColor[
             0.48643653048329016`, 0.5939501150191309, 0.9527132120368191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 149}], {
             RGBColor[
             0.4194948681145545, 0.5363353836947373, 0.9483464082991826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 170}], {
             RGBColor[
             0.6342662931135439, 0.7121247918553153, 0.9656090564036925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 190}], {
             RGBColor[
             0.44602994262661233`, 0.559318731545458, 0.9500371997830458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 195}], {
             RGBColor[
             0.551629928256272, 0.6468770522603381, 0.957845475120793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 46}], {
             RGBColor[
             0.4991248603784277, 0.6042097570927446, 0.9537234995065598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 98}], {
             RGBColor[
             0.40052389017301404`, 0.5213353955769788, 0.9467420060058227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 117}], {
             RGBColor[
             0.5187111284258739, 0.6201107718449819, 0.9552654022741187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 120}], {
             RGBColor[
             0.4199465445375802, 0.5381583225765731, 0.9479796003671541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 128}], {
             RGBColor[
             0.45931115273321815`, 0.5718871956392737, 0.9505892185983124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 146}], {
             RGBColor[
             0.3642493115174482, 0.4869535151250499, 0.944539099558841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 156}], {
             RGBColor[
             0.4482260303632402, 0.5626525918304741, 0.9497815441973976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 171}], {
             RGBColor[
             0.4179204016012702, 0.5364033794020464, 0.9478504963309002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 178}], {
             RGBColor[
             0.5615349686312382, 0.6544341602702044, 0.95893948840672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 179}], {
             RGBColor[
             0.43279481005592735`, 0.5492868443959638, 0.9487982804847079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 183}], {
             RGBColor[
             0.4178105109648169, 0.5363081976560145, 0.9478434941967179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 192}], {
             RGBColor[
             0.4149002833071108, 0.5337875047312046, 0.9476580570637821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 114}], {
             RGBColor[
             0.2573301155566468, 0.38780064549467597`, 0.9379659414439357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 46}], {
             RGBColor[
             0.7555773858360189, 0.8079347156356389, 0.9510367084655542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 74}], {
             RGBColor[
             0.7396939981390787, 0.7950398659648015, 0.9497863100032848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.8969076644427829, 0.9198859493313639, 0.9640991398372748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 117}], {
             RGBColor[
             0.7751636538834651, 0.8238357303878762, 0.9525786112331132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 121}], {
             RGBColor[
             0.6883283943638466, 0.7522158623023374, 0.9460529353262331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 166}], {
             RGBColor[
             0.7082488985510418, 0.7694700017956333, 0.947322252238031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 169}], {
             RGBColor[
             0.6736126026087932, 0.7394697831213097, 0.9451152580882649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 171}], {
             RGBColor[
             0.6743729270588614, 0.7401283379449408, 0.9451637052898947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 173}], {
             RGBColor[
             0.9038529892523259, 0.9254239628086739, 0.9647615911177737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 196}], {
             RGBColor[
             0.8567443808619996, 0.8884362933235486, 0.9601156216355651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 57}], {
             RGBColor[
             0.4570859315705095, 0.5674372330351508, 0.9511444280196635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 66}], {
             RGBColor[
             0.3401604190077047, 0.4690515908098649, 0.9428956990004909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 81}], {
             RGBColor[
             0.35279314773981224`, 0.47999342549820867`, 0.9437006453046175]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 90}], {
             RGBColor[
             0.2966219275332924, 0.42487402020648146`, 0.9403582430325232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 141}], {
             RGBColor[
             0.3802605651573715, 0.5037843219127578, 0.9454508448539807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 168}], {
             RGBColor[
             0.3100425582532653, 0.4389799540103073, 0.9411225280979817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 172}], {
             RGBColor[
             0.41128561023817056`, 0.530254468896595, 0.9475388589522767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 184}], {
             RGBColor[
             0.4337250802712871, 0.5484718415560841, 0.9493053762317708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 198}], {
             RGBColor[
             0.4014700193666707, 0.5221548851306883, 0.9468022925214133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 88}], {
             RGBColor[
             0.29171133465435584`, 0.42235334222554155`, 0.9399819042970208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[
             0.6245384441862358, 0.6893956623116928, 0.8639717207902855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 102}], {
             RGBColor[
             0.6018173273796255, 0.6736700802973323, 0.957057319762264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 153}], {
             RGBColor[
             0.33346144282720336`, 0.45851518750341097`, 0.9426421842716235]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 49}], {
             RGBColor[
             0.3534183447565693, 0.4805349397308079, 0.9437404823056852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 67}], {
             RGBColor[
             0.37321149831525696`, 0.49767877451051923`, 0.9450016845480462]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 87}], {
             RGBColor[
             0.530190605214411, 0.6276201356921796, 0.9568005129821999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 95}], {
             RGBColor[
             0.3754925498657421, 0.499654506714565, 0.9451470311357886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 103}], {
             RGBColor[
             0.44285376597818127`, 0.5570383000610314, 0.9497047848168618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 129}], {
             RGBColor[
             0.34555939284077203`, 0.4723761975723705, 0.9432892096738854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 131}], {
             RGBColor[
             0.6843752995558527, 0.7173358521526534, 0.6456510588823124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 133}], {
             RGBColor[
             0.32597951277182713`, 0.4517965021838111, 0.9421741644697958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 143}], {
             RGBColor[
             0.40644117047755013`, 0.5264606463656123, 0.9471190498743822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 154}], {
             RGBColor[
             0.5341331431230381, 0.6307000762707969, 0.9571934683158204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 197}], {
             RGBColor[
             0.4971848038816359, 0.6011466842164208, 0.9539819231417713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 50}], {
             RGBColor[
             0.7222557767692009, 0.7809786819987281, 0.9509870126974218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 57}], {
             RGBColor[
             0.5212232742679018, 0.6221915607484272, 0.955451751935585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 60}], {
             RGBColor[
             0.4947882327492612, 0.6007304031585455, 0.9533706886324897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 90}], {
             RGBColor[
             0.36075927023068477`, 0.47962834791975784`, 0.9446655669484446]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 141}], {
             RGBColor[
             0.44439790785476385`, 0.5585386496260341, 0.9497581687699022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 177}], {
             RGBColor[
             0.42876800066124554`, 0.5450008095969859, 0.9487622449045154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 120}], {
             RGBColor[
             0.6880776672512711, 0.7499507740131675, 0.8967566410385563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 128}], {
             RGBColor[
             0.727442275446909, 0.783679647075868, 0.8993662592697147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 168}], {
             RGBColor[
             0.6268513893805991, 0.6929345898620358, 0.893001269305494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 172}], {
             RGBColor[
             0.7280944413655043, 0.7842091047483235, 0.899417600159789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 173}], {
             RGBColor[
             0.9155315865084257, 0.9334914557023739, 0.9162254228301816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 85}], {
             RGBColor[
             0.5175840787713586, 0.6192370979004446, 0.9551652611352847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 98}], {
             RGBColor[
             0.4478523774579912, 0.5598001094169847, 0.950456462233346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 99}], {
             RGBColor[
             0.4359721542866026, 0.5495100572233064, 0.949699464918134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 109}], {
             RGBColor[
             0.40036416273964004`, 0.5136319864774774, 0.9476149558016764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 117}], {
             RGBColor[
             0.566039615710851, 0.6585754856849875, 0.9589798585016418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 121}], {
             RGBColor[
             0.4792043561912326, 0.5869556175994488, 0.9524541825947619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 146}], {
             RGBColor[
             0.41157779880242534`, 0.5254182289650556, 0.9482535557863643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 151}], {
             RGBColor[
             0.5157059201426476, 0.617712324115575, 0.9550174056081109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 171}], {
             RGBColor[
             0.4652488888862473, 0.5748680932420521, 0.9515649525584234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 178}], {
             RGBColor[
             0.6088634559162154, 0.6928988741102101, 0.9626539446342433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 196}], {
             RGBColor[
             0.6476203426893855, 0.7231760486206599, 0.9665168689040938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 54}], {
             RGBColor[
             0.41985783765081663`, 0.537468873517314, 0.9481432155617882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 61}], {
             RGBColor[
             0.3807665106103465, 0.5042225464345669, 0.9454830832508543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 73}], {
             RGBColor[
             0.3483890601627563, 0.47617882619484064`, 0.9434200207385892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 88}], {
             RGBColor[
             0.34485769721962134`, 0.4731201371049595, 0.9431950054145142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 94}], {
             RGBColor[
             0.5751105381109023, 0.6613037065430661, 0.961873738441477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 105}], {
             RGBColor[
             0.6697939351538558, 0.7354972477712983, 0.9351666840884045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 111}], {
             RGBColor[
             0.6661578375633327, 0.25260392233755324`, 0.4242800850116212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 116}], {
             RGBColor[
             0.3659596236997701, 0.4913975652084007, 0.9445396015101284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 126}], {
             RGBColor[
             0.6269380051464617, 0.7023579582841318, 0.966889153158202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 142}], {
             RGBColor[
             0.35771694731978376`, 0.4842581732170174, 0.9440143854599082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 153}], {
             RGBColor[
             0.38660780539246886`, 0.509281982382829, 0.945855285389117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 157}], {
             RGBColor[
             0.36865523094378616`, 0.49373236471800797`, 0.9447113632200852]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 160}], {
             RGBColor[
             0.3299204441882223, 0.4590042815284386, 0.9422863476641355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 167}], {
             RGBColor[
             0.44854703447928634`, 0.5607600559362543, 0.9504017342281159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 174}], {
             RGBColor[
             0.46067723689502804`, 0.5706079007167448, 0.9513566681966787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 188}], {
             RGBColor[
             0.5560940675637905, 0.6464478952211332, 0.9599783543763619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 59}], {
             RGBColor[
             0.32297582609210107`, 0.4535756586921377, 0.9418223697015293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.34319641708258153`, 0.4710897182916379, 0.9431108078790762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 77}], {
             RGBColor[
             0.28532561806825574`, 0.41722569365175644`, 0.9395602438963373]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 106}], {
             RGBColor[
             0.3459462341257583, 0.47347147160461445`, 0.9432860237894996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 112}], {
             RGBColor[
             0.2930893585970763, 0.4253858771971273, 0.9400023774340288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 140}], {
             RGBColor[
             0.4051366676664824, 0.5232565439283612, 0.9474672620186428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 193}], {
             RGBColor[
             0.4635923297580593, 0.5707134838118706, 0.9520691058686375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 67}], {
             RGBColor[
             0.32963712099477605`, 0.45993683898740323`, 0.9422251637564942]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.4866162278939301, 0.5898782001690634, 0.9540239921906479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 95}], {
             RGBColor[
             0.33191817254526124`, 0.46191257119144896`, 0.9423705103442364]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 103}], {
             RGBColor[
             0.39927938865770035`, 0.5192963645379154, 0.9469282640253097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 108}], {
             RGBColor[
             0.27454222011014395`, 0.4057901440994646, 0.9389498622817032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[
             0.3019850155202911, 0.4346342620492545, 0.9405126888823334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 131}], {
             RGBColor[
             0.6408009222353719, 0.6795939166295374, 0.6428745380907603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 133}], {
             RGBColor[
             0.28240513545134627`, 0.41405456666069507`, 0.9393976436782437]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 143}], {
             RGBColor[
             0.36286679315706927`, 0.4887187108424963, 0.9443425290828302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 154}], {
             RGBColor[
             0.4905587658025571, 0.5929581407476809, 0.9544169475242683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 162}], {
             RGBColor[
             0.5371536790692081, 0.6293584411260456, 0.959061093024467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 53}], {
             RGBColor[
             0.6492012250713584, 0.7185007160412178, 0.94611149210917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 60}], {
             RGBColor[
             0.7343283678575127, 0.7907797553082503, 0.951937411291252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 82}], {
             RGBColor[
             0.5703614559387262, 0.6382110170742163, 0.941527367678092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 100}], {
             RGBColor[
             0.9775093907269796, 0.979470381191301, 0.7266415481194453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 104}], {
             RGBColor[
             0.6400733079972727, 0.7105945730540966, 0.9455298693047094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 123}], {
             RGBColor[
             0.7383397117623038, 0.7940363449991432, 0.9522531989774741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.6357306165893241, 0.7068331520265482, 0.9452531568482861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 163}], {
             RGBColor[
             0.7525339299653672, 0.8055598507786331, 0.9533706198295537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 177}], {
             RGBColor[
             0.668308135769497, 0.7350501617466907, 0.9473289675632777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 71}], {
             RGBColor[
             0.40208032484029854`, 0.5135671956632648, 0.9478827790137916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 74}], {
             RGBColor[
             0.5383811749520688, 0.6361211174784511, 0.9568024847289037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 158}], {
             RGBColor[
             0.6877201533111806, 0.7547416411506065, 0.9703500218201178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 164}], {
             RGBColor[
             0.45756611987408635`, 0.5677894792700053, 0.9511926170559679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 166}], {
             RGBColor[
             0.5069360753640317, 0.610551253309283, 0.9543384269636499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 184}], {
             RGBColor[
             0.5375424909555111, 0.6354402360277622, 0.9567364604524939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 70}], {
             RGBColor[
             0.3949755545911338, 0.5165297061634091, 0.9463884709687459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 134}], {
             RGBColor[
             0.5214701777591364, 0.6199997018563359, 0.9562733133115701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 145}], {
             RGBColor[
             0.33288207207674614`, 0.4608104284673715, 0.9425028531093029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 100}], {
             RGBColor[
             0.6649147039208856, 0.7269430630840861, 0.7231993048724312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 104}], {
             RGBColor[
             0.32747862119117865`, 0.4580672549468817, 0.9420876260576954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 123}], {
             RGBColor[
             0.4257450249562098, 0.5415090268919284, 0.94881095573046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 130}], {
             RGBColor[
             0.32313592978323, 0.45430583391933327`, 0.9418109136012721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 135}], {
             RGBColor[
             0.5188240646683264, 0.6161758420415913, 0.9567530905600796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 148}], {
             RGBColor[
             0.442250687121619, 0.5549090670094144, 0.9501103419183538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 163}], {
             RGBColor[
             0.43993924315927313`, 0.5530325326714182, 0.9499283765825397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 165}], {
             RGBColor[
             0.33665937953929237`, 0.4660191663896863, 0.9426726158614114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 58}], {
             RGBColor[
             0.43924611863268803`, 0.5542620280204744, 0.9493786196815692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 61}], {
             RGBColor[
             0.4367888355711651, 0.5521336529392211, 0.9492220437777791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 73}], {
             RGBColor[
             0.4044113851235749, 0.5240899326994948, 0.9471589812655139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 94}], {
             RGBColor[
             0.6311328630717209, 0.7092148130477203, 0.9656126989684017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 105}], {
             RGBColor[
             0.7258162601146743, 0.7834083542759525, 0.9389056446153293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 115}], {
             RGBColor[
             0.4609781697810362, 0.5730852384405232, 0.9507633667638438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 116}], {
             RGBColor[
             0.4219819486605887, 0.5393086717130549, 0.9482785620370531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 126}], {
             RGBColor[
             0.6829603301072802, 0.750269064788786, 0.9706281136851268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 160}], {
             RGBColor[
             0.3859427691490409, 0.5069153880330928, 0.9460253081910603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 174}], {
             RGBColor[
             0.5166995618558465, 0.618519007221399, 0.9550956287236034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 62}], {
             RGBColor[
             0.6150786638168584, 0.6914065014387013, 0.966446293655049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 68}], {
             RGBColor[
             0.7770687941030305, 0.8264972626230744, 0.9782219691594607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 72}], {
             RGBColor[
             0.6155416349177705, 0.6918075037367072, 0.9664757937642099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 75}], {
             RGBColor[
             0.5877219778056744, 0.6637264554210736, 0.964849062365569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 76}], {
             RGBColor[
             0.7347653511229184, 0.792183734445917, 0.9748709622872508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 96}], {
             RGBColor[
             0.6285956613034127, 0.703114245277507, 0.9673075847822806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 107}], {
             RGBColor[
             0.6326994861905049, 0.7066687721304701, 0.9675690768752163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 111}], {
             RGBColor[
             0.8481459317903276, 0.39972255908133447`, 0.4398982369139971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 139}], {
             RGBColor[
             0.6295256013117801, 0.7039197125726111, 0.9673668397373001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 147}], {
             RGBColor[
             0.919054473480996, 0.8421951917005295, 0.6262163875964337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 157}], {
             RGBColor[
             0.6416373722842785, 0.7144103198336798, 0.9681385910736492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 182}], {
             RGBColor[
             0.6266295493639693, 0.7014112979352205, 0.9671823058680639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 185}], {
             RGBColor[
             0.5671004557054226, 0.6420519282136913, 0.9636746971887677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 191}], {
             RGBColor[
             0.817943138299353, 0.8584286109657633, 0.9822959417964865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 79}], {
             RGBColor[
             0.31342658973898696`, 0.4454096743507693, 0.9412100531567709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 118}], {
             RGBColor[
             0.6440348116492959, 0.7138509872151922, 0.9432305874029392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 119}], {
             RGBColor[
             0.3619975286149172, 0.48796579758659037`, 0.9442871403148647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 125}], {
             RGBColor[
             0.3363992369217113, 0.46579384392948575`, 0.9426560398038542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 129}], {
             RGBColor[
             0.3087471314472264, 0.440491266991337, 0.9409435649296933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 149}], {
             RGBColor[
             0.32815540346273664`, 0.4586534497344392, 0.942130750025584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 170}], {
             RGBColor[
             0.5429268284617259, 0.6344428578950172, 0.9593933981300939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 190}], {
             RGBColor[
             0.35469047797479447`, 0.4816367975851599, 0.9438215415094473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 195}], {
             RGBColor[
             0.46029046360445414`, 0.56919511830004, 0.9516298168471945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 197}], {
             RGBColor[
             0.46037254248809023`, 0.5692617536353873, 0.9516362783975791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 66}], {
             RGBColor[
             0.44280539431204935`, 0.5550681494225451, 0.9502344848133377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 71}], {
             RGBColor[
             0.4009078894604191, 0.5126153598042668, 0.9477904806059152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 81}], {
             RGBColor[
             0.4554381230441569, 0.5660099841108889, 0.9510394311174641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 90}], {
             RGBColor[
             0.3992669028376371, 0.5108905788191617, 0.9476970288453699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 141}], {
             RGBColor[
             0.4829055404617162, 0.589800880525438, 0.9527896306668275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 198}], {
             RGBColor[
             0.5041149946710154, 0.6081714437433685, 0.9541410783342601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 61}], {
             RGBColor[
             0.4001547915922179, 0.5210157009377274, 0.9467184873706355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 73}], {
             RGBColor[
             0.3677773411446277, 0.49297198069800113`, 0.9446554248583703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 92}], {
             RGBColor[
             0.6237447390308792, 0.7011452000915496, 0.965970709157043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 115}], {
             RGBColor[
             0.42434412580208897`, 0.5419672864390295, 0.9482598103567002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 155}], {
             RGBColor[
             0.3222358292148373, 0.4473421058618795, 0.9419799904100252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 154}], {
             RGBColor[
             0.5074384061485774, 0.6075784368200117, 0.9554925032810369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 186}], {
             RGBColor[
             0.2771581318510729, 0.4054183570352168, 0.9392131197957072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 193}], {
             RGBColor[
             0.48421975179408727`, 0.5891714214720863, 0.9533618091947784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.3428939119187865, 0.4579627382340339, 0.94391104361316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 104}], {
             RGBColor[
             0.41260576397733295`, 0.5303462942139141, 0.9479135452397773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 123}], {
             RGBColor[
             0.5108721677423641, 0.6137880661589608, 0.954636874912542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 130}], {
             RGBColor[
             0.4082630725693843, 0.5265848731863657, 0.9476368327833542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 163}], {
             RGBColor[
             0.5250663859454274, 0.6253115719384505, 0.9557542957646217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 177}], {
             RGBColor[
             0.44084059174955725`, 0.5548018829065081, 0.9497126434983456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 73}], {
             RGBColor[
             0.36532005808310475`, 0.4908436056167478, 0.9444988489545801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 94}], {
             RGBColor[
             0.5920415360312508, 0.6759684859649733, 0.962952566657468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 105}], {
             RGBColor[
             0.6867249330742042, 0.7501620271932055, 0.9362455123043956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 115}], {
             RGBColor[
             0.42188684274056604`, 0.5398389113577762, 0.9481032344529099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 116}], {
             RGBColor[
             0.38289062162011855`, 0.5060623446303079, 0.9456184297261194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 160}], {
             RGBColor[
             0.3468514421085708, 0.47366906095034567`, 0.9433651758801265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 174}], {
             RGBColor[
             0.47760823481537645`, 0.5852726801386519, 0.9524354964126697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 68}], {
             RGBColor[
             0.48234766254890615`, 0.5869900868177726, 0.9534095520725183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 75}], {
             RGBColor[
             0.29300084625155, 0.42421927961577166`, 0.9400366452786266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 76}], {
             RGBColor[
             0.44004421956879414`, 0.5526765586406153, 0.9500585452003084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 96}], {
             RGBColor[
             0.33387452974928833`, 0.4636070694722051, 0.9424951676953383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 105}], {
             RGBColor[
             0.6480549449402238, 0.7166680270816681, 0.9337814948550263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 107}], {
             RGBColor[
             0.3379783546363806, 0.4671615963251682, 0.9427566597882739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 111}], {
             RGBColor[
             0.6516651774209113, 0.24005110854446648`, 0.42335662552270226`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 116}], {
             RGBColor[
             0.3442206334861381, 0.47256834451877056`, 0.94315441227675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 126}], {
             RGBColor[
             0.6051990149328297, 0.6835287375945016, 0.9655039639248237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 157}], {
             RGBColor[
             0.34691624073015415`, 0.4749031440283778, 0.9433261739867068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 174}], {
             RGBColor[
             0.438938246681396, 0.5517786800271146, 0.9499714789633003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 182}], {
             RGBColor[
             0.3319084178098449, 0.4619041221299186, 0.9423698887811215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 185}], {
             RGBColor[
             0.2723793241512982, 0.4025447524083894, 0.9388622801018254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 191}], {
             RGBColor[
             0.5232220067452286, 0.6189214351604613, 0.9574835247095441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 77}], {
             RGBColor[
             0.3261736310947641, 0.45319769091147244`, 0.9421413854000251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 91}], {
             RGBColor[
             0.4558715223588308, 0.5672551246495475, 0.9508267319149598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 102}], {
             RGBColor[
             0.6650681486544369, 0.7331888494460973, 0.9609142680537077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 106}], {
             RGBColor[
             0.3867942471522666, 0.5094434688643305, 0.9458671652931874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 112}], {
             RGBColor[
             0.3339373716235846, 0.4613578744568433, 0.9425835189377165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 140}], {
             RGBColor[
             0.4459846806929907, 0.5592285411880772, 0.9500484035223306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 69}], {
             RGBColor[
             0.901549911849724, 0.9196423999253337, 0.7415365124358253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 82}], {
             RGBColor[
             0.4944127406747786, 0.5784060580887467, 0.9575938848777271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 86}], {
             RGBColor[
             0.57815522540899, 0.662942242892185, 0.9624904060116366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 87}], {
             RGBColor[
             0.7366434848506644, 0.7941907561539643, 0.9743853963113085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 108}], {
             RGBColor[
             0.5245694770668783, 0.6101027000843653, 0.9593112664023637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 110}], {
             RGBColor[
             0.7566083281525783, 0.8097874434798483, 0.976375305309575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 127}], {
             RGBColor[
             0.6378923083597413, 0.7143422473294225, 0.9663910897051857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 154}], {
             RGBColor[
             0.7405860227592915, 0.7972706967325816, 0.9747783516449289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 161}], {
             RGBColor[
             0.8125383849742069, 0.8534804289530804, 0.9819498906774573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 162}], {
             RGBColor[
             0.7871809360259425, 0.8336709971109462, 0.9794224971451275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 175}], {
             RGBColor[
             0.5986391987615642, 0.6806844310557485, 0.9637956266803962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 176}], {
             RGBColor[
             0.8873187671618203, 0.8720684017871536, 0.6496025391706133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 180}], {
             RGBColor[
             0.7575984679912213, 0.8105609482471379, 0.9764739931953079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 66}], {
             RGBColor[
             0.36612736473647467`, 0.4915428540634845, 0.9445502898206597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 69}], {
             RGBColor[
             0.6997880950367977, 0.757134942301442, 0.7242505394816754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 87}], {
             RGBColor[
             0.5348816680377382, 0.6316832985300725, 0.9570994233571584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 90}], {
             RGBColor[
             0.32258887326206237`, 0.44736528346010107`, 0.9420128338526919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 110}], {
             RGBColor[
             0.554846511339652, 0.6472799858559566, 0.9590893323554248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 131}], {
             RGBColor[
             0.68906636237918, 0.7213990149905465, 0.6459499692572709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 133}], {
             RGBColor[
             0.3306705755951544, 0.4558596650217041, 0.9424730748447543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 162}], {
             RGBColor[
             0.5854191192130163, 0.6711635394870545, 0.9621365241909776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 180}], {
             RGBColor[
             0.5558366511782951, 0.6480534906232461, 0.959188020241158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 198}], {
             RGBColor[
             0.42743696509544066`, 0.5446461483843079, 0.9484568833415821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 81}], {
             RGBColor[
             0.3385126104813521, 0.467624341885603, 0.9427907020982916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 90}], {
             RGBColor[
             0.2823413902748323, 0.4125049365938757, 0.9394482998261974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 141}], {
             RGBColor[
             0.3659800278989114, 0.491415238300152, 0.9445409016476549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 168}], {
             RGBColor[
             0.2957620209948052, 0.4266108703977015, 0.9402125848916558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 172}], {
             RGBColor[
             0.39700507297971044`, 0.5178853852839893, 0.9466289157459509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 198}], {
             RGBColor[
             0.3871894821082106, 0.5097858015180826, 0.9458923493150875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 87}], {
             RGBColor[
             0.5064093814526178, 0.6070220349487748, 0.955285194433009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 103}], {
             RGBColor[
             0.419072542216388, 0.5364401993176267, 0.9481894662676709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 129}], {
             RGBColor[
             0.3217781690789788, 0.4517780968289658, 0.9417738911246945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 131}], {
             RGBColor[
             0.6605940757940595, 0.6967377514092488, 0.6441357403331214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 133}], {
             RGBColor[
             0.3021982890100339, 0.43119840144040644`, 0.9406588459206049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 143}], {
             RGBColor[
             0.382659946715757, 0.5058625456222077, 0.9456037313251913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 162}], {
             RGBColor[
             0.5569468326278957, 0.6465022759057568, 0.9603222952668281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 107}], {
             RGBColor[
             0.4999684849225527, 0.6022523575095413, 0.9545323352926858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 111}], {
             RGBColor[
             0.7596585976116927, 0.33011161600071526`, 0.4312070758589768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 122}], {
             RGBColor[
             0.5111709931779247, 0.6119554071059081, 0.9552461492127289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 138}], {
             RGBColor[
             0.6217752134280572, 0.7037938421893931, 0.9633882937983599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 142}], {
             RGBColor[
             0.4979680873923239, 0.6005197137117604, 0.9544048717309417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 147}], {
             RGBColor[
             0.7863234722130437, 0.7377787770796007, 0.6131796460139032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 156}], {
             RGBColor[
             0.5444967402340541, 0.6408204942051775, 0.9573696363463444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 157}], {
             RGBColor[
             0.5089063710163263, 0.609993905212751, 0.9551018494911185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 179}], {
             RGBColor[
             0.5290655199267412, 0.6274547467706673, 0.9563863726336548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 181}], {
             RGBColor[
             0.525699847096712, 0.6245395701289311, 0.956171914937073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 185}], {
             RGBColor[
             0.4343694544374703, 0.5376355135927626, 0.9506379556062372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 82}], {
             RGBColor[
             0.5860641711749454, 0.6466303418365871, 0.7174436275580982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 86}], {
             RGBColor[
             0.6698066559091568, 0.7311665266400253, 0.7223401486920077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 90}], {
             RGBColor[
             0.6160021205751554, 0.6780970248318332, 0.7191485494872131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 110}], {
             RGBColor[
             0.848259758652745, 0.8780117272276887, 0.736225047989946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 123}], {
             RGBColor[
             0.7540424269985231, 0.802455669761514, 0.7281694588574803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 127}], {
             RGBColor[
             0.7295437388599081, 0.7825665310772629, 0.7262408323855569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 177}], {
             RGBColor[
             0.6840108510057162, 0.7434694865090613, 0.7232452274432839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 180}], {
             RGBColor[
             0.8492498984913881, 0.8787852319949783, 0.7363237358756791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 72}], {
             RGBColor[
             0.36663293091413246`, 0.4919807500760769, 0.9445825040504454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 93}], {
             RGBColor[
             0.3600767670504351, 0.48624898134784966`, 0.9441666971357816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 134}], {
             RGBColor[
             0.5384770105317094, 0.6347301656156695, 0.9573569736572867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 139}], {
             RGBColor[
             0.3806168973081422, 0.5040929589119807, 0.9454735500235357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.34988890484931917`, 0.4755408922267051, 0.9435865134550195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 81}], {
             RGBColor[
             0.2966151056297218, 0.4251715522673246, 0.9403466978908692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 164}], {
             RGBColor[
             0.29757066707977187`, 0.42599921156744297`, 0.9404075854214965]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 184}], {
             RGBColor[
             0.37754703816119667`, 0.4936499683252, 0.9459514288180225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 75}], {
             RGBColor[
             0.29346381735246196`, 0.42462028191377754`, 0.9400661453877874]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 84}], {
             RGBColor[
             0.4621290159653829, 0.5706311327657808, 0.9517901946001008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 93}], {
             RGBColor[
             0.31472731060086073`, 0.44696956150118394`, 0.9412770698717645]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 134}], {
             RGBColor[
             0.49312755408213504`, 0.5954507457690038, 0.9544673463932696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 139}], {
             RGBColor[
             0.33526744085856786`, 0.464813539065315, 0.9425839227595186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 152}], {
             RGBColor[
             0.5026912356621631, 0.6029219665059937, 0.9554205647954811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 191}], {
             RGBColor[
             0.5236849778461405, 0.6193224374584672, 0.9575130248187049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 94}], {
             RGBColor[
             0.5596640855836605, 0.6479247657252469, 0.9608895041452028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 115}], {
             RGBColor[
             0.38950939229297576`, 0.5117951911180499, 0.9460401719406448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 153}], {
             RGBColor[
             0.37116135286522706`, 0.4959030415650098, 0.9448710510928429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 160}], {
             RGBColor[
             0.3144739916609805, 0.44562534071061943`, 0.9413021133678614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 80}], {
             RGBColor[
             0.6719002385732287, 0.7417308549576378, 0.9692499886435342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 158}], {
             RGBColor[
             0.6640255506286363, 0.7355052952632306, 0.9684846959007584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 164}], {
             RGBColor[
             0.43387151719154204`, 0.5485531333826293, 0.9493272911366086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 166}], {
             RGBColor[
             0.48324147268148754`, 0.5913149074219071, 0.9524731010442904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 169}], {
             RGBColor[
             0.44860517673923905`, 0.5613146887475835, 0.9502661068945243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 184}], {
             RGBColor[
             0.5138478882729669, 0.6162038901403863, 0.9548711345331347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 76}], {
             RGBColor[
             0.41268753355761, 0.5249965126229874, 0.9484613139108284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 96}], {
             RGBColor[
             0.30651784373810426`, 0.43592702345457734`, 0.9408979364058583]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 134}], {
             RGBColor[
             0.46530789697003894`, 0.5673696974533702, 0.9528406149946287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 139}], {
             RGBColor[
             0.30744778374647175`, 0.4367324907496814, 0.9409571913608779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 182}], {
             RGBColor[
             0.3045517317986608, 0.43422407611229086`, 0.9407726574916415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 191}], {
             RGBColor[
             0.4958653207340445, 0.5912413891428336, 0.9558862934200641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.4535612170553484, 0.5643843024794208, 0.9509198363275401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 105}], {
             RGBColor[
             0.7677416322462838, 0.817445260088884, 0.9422061634872281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 111}], {
             RGBColor[
             0.7314563022916181, 0.307235930549277, 0.4289730712775034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 116}], {
             RGBColor[
             0.4639073207921981, 0.5733455775259864, 0.9515790809089518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 126}], {
             RGBColor[
             0.7248857022388897, 0.7843059706017175, 0.9739286325570256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 174}], {
             RGBColor[
             0.558624933987456, 0.6525559130343304, 0.9583961475955021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.45159510511590495`, 0.5626813551371344, 0.9507945574133233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 191}], {
             RGBColor[
             0.6429086940512887, 0.7196986681676771, 0.9659081933417459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 102}], {
             RGBColor[
             0.6071973496401111, 0.6793248248062158, 0.9573637040709689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 106}], {
             RGBColor[
             0.32892344813794094`, 0.45557944422444896`, 0.9423166013104485]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 112}], {
             RGBColor[
             0.2760665726092589, 0.4074938498169618, 0.9390329549549777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 140}], {
             RGBColor[
             0.38811388167866495`, 0.5053645165481957, 0.9464978395395918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 189}], {
             RGBColor[
             0.3935452428788118, 0.5097739402505086, 0.9469254161889988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 91}], {
             RGBColor[
             0.4108395648869375, 0.5268855365003324, 0.9480073209646985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 95}], {
             RGBColor[
             0.3239864464098686, 0.45367733871406485`, 0.9419150933282905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 113}], {
             RGBColor[
             0.6208942934793475, 0.6285529831912268, 0.6084582404132186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 136}], {
             RGBColor[
             0.2575337498947376, 0.38801467809517215`, 0.93797753811824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 89}], {
             RGBColor[
             0.31396755959899736`, 0.4458782352535746, 0.9412445232778899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 118}], {
             RGBColor[
             0.6340932020983239, 0.7047536474741047, 0.9426149269508571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 119}], {
             RGBColor[
             0.35205591906394523`, 0.4788684578455028, 0.9436714798627825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 125}], {
             RGBColor[
             0.32645762737073936`, 0.45669650418839813`, 0.942040379351772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 128}], {
             RGBColor[
             0.3851554562805004, 0.5071708413177451, 0.9458818933111385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 144}], {
             RGBColor[
             0.29745652032581765`, 0.4299760410680807, 0.9402510808338438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 149}], {
             RGBColor[
             0.31821379391176474`, 0.4495561099933516, 0.9415150895735018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 159}], {
             RGBColor[
             0.3100832421126799, 0.4425138346783999, 0.9409970180024289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 170}], {
             RGBColor[
             0.532985218910754, 0.6253455181539296, 0.9587777376780118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 190}], {
             RGBColor[
             0.3447488684238226, 0.47253945784407236`, 0.9432058810573651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 192}], {
             RGBColor[
             0.340744586854393, 0.46907115040967606`, 0.9429507317766083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 195}], {
             RGBColor[
             0.45034885405348224`, 0.5600977785589524, 0.9510141563951124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 197}], {
             RGBColor[
             0.45043093293711833`, 0.5601644138942997, 0.9510206179454971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 81}], {
             RGBColor[
             0.5901296220451963, 0.6725715574490735, 0.9635792334399711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 117}], {
             RGBColor[
             0.707369894317615, 0.7705267193807125, 0.9720422898733625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 120}], {
             RGBColor[
             0.6086053104293213, 0.6885742701123038, 0.9647564879663979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 121}], {
             RGBColor[
             0.6205346347979965, 0.6989068512951737, 0.9655166139664825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 166}], {
             RGBColor[
             0.6404551389851917, 0.7161609907884696, 0.9667859308782804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 168}], {
             RGBColor[
             0.5473790325586494, 0.631558085961172, 0.9610011162333354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 172}], {
             RGBColor[
             0.6486220845435545, 0.7228326008474598, 0.9674174470876304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 173}], {
             RGBColor[
             0.836059229686476, 0.8721149518015102, 0.984225269758023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 184}], {
             RGBColor[
             0.671061554576671, 0.7410499735069489, 0.9691839643671245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 164}], {
             RGBColor[
             0.35210090066350963`, 0.4793938358740651, 0.9436565359330455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 166}], {
             RGBColor[
             0.4014708561534551, 0.5221556099133429, 0.9468023458407273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 168}], {
             RGBColor[
             0.3083947497269127, 0.4375527050860453, 0.9410175311957825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 172}], {
             RGBColor[
             0.40963780171181796`, 0.5288272199723331, 0.9474338620500775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 173}], {
             RGBColor[
             0.5970749468547394, 0.6781095709263835, 0.96424168472047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 184}], {
             RGBColor[
             0.4320772717449345, 0.5470445926318221, 0.9492003793295716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 198}], {
             RGBColor[
             0.3998222108403181, 0.5207276362064264, 0.9466972956192141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 86}], {
             RGBColor[
             0.2626694847342114, 0.38993018480343833`, 0.9383975211339095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 101}], {
             RGBColor[
             0.4831158836073621, 0.5695808674883871, 0.9564679197403785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 110}], {
             RGBColor[
             0.4411225874777997, 0.5367753853911017, 0.9522824204318479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 123}], {
             RGBColor[
             0.3469052558235777, 0.4612193279249269, 0.944226831299382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 127}], {
             RGBColor[
             0.32240656768496273`, 0.4413301892406758, 0.9422982048274586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 130}], {
             RGBColor[
             0.2442961606505979, 0.3740161349523318, 0.9372267891701942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 163}], {
             RGBColor[
             0.361099474026641, 0.4727428337044167, 0.9453442521514617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 176}], {
             RGBColor[
             0.5718330264870417, 0.5990563436984071, 0.6255096542928862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 177}], {
             RGBColor[
             0.2768736798307708, 0.4022331446724743, 0.9393025998851856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 180}], {
             RGBColor[
             0.44211272731644274`, 0.5375488901583911, 0.9523811083175808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 187}], {
             RGBColor[
             0.2790993478939755, 0.4041609064834927, 0.9394444174860921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 86}], {
             RGBColor[
             0.6706149761484655, 0.7328954418981942, 0.8103208183664927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 101}], {
             RGBColor[
             0.8910613750216162, 0.912546124583143, 0.8283912169729619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 124}], {
             RGBColor[
             0.7225755777394691, 0.7779011033805494, 0.8136317019529156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 135}], {
             RGBColor[
             0.8479297869499485, 0.8788514001693457, 0.824092263361585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 137}], {
             RGBColor[
             0.9598312529836523, 0.9671172244886568, 0.8350206423861196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 161}], {
             RGBColor[
             0.9049981357136825, 0.9234336279590896, 0.8297803030323136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 165}], {
             RGBColor[
             0.6657651018209143, 0.7286947245174407, 0.8100117886629167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 175}], {
             RGBColor[
             0.6910989495010398, 0.7506376300617577, 0.8116260390352523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 176}], {
             RGBColor[
             0.9797785179012959, 0.9420216007931629, 0.49743295152546957`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 187}], {
             RGBColor[
             0.6870448393082296, 0.7471261635782485, 0.8113677147186754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 199}], {
             RGBColor[
             0.6387077296130492, 0.7028413789856132, 0.8083762373646417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 93}], {
             RGBColor[
             0.4555728521016856, 0.5648993640375536, 0.951374387685437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 139}], {
             RGBColor[
             0.4761129823593927, 0.5827433416016847, 0.952681240573191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 152}], {
             RGBColor[
             0.6435367771629878, 0.7208517690423635, 0.9655178826091535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 194}], {
             RGBColor[
             0.49184166769942017`, 0.5963667382965051, 0.9536834584947274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 99}], {
             RGBColor[
             0.4071028853945563, 0.5260726841910006, 0.9474267703193356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 109}], {
             RGBColor[
             0.3714948938475938, 0.4901946134451716, 0.9453422612028781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 132}], {
             RGBColor[
             0.3932431861105902, 0.5130534475349531, 0.9465807942735407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 146}], {
             RGBColor[
             0.38270852991037907`, 0.5019808559327499, 0.945980861187566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 150}], {
             RGBColor[
             0.3972928412752126, 0.5173098918759385, 0.946811416144238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 151}], {
             RGBColor[
             0.4868366512506014, 0.5942749510832692, 0.9527447110093126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 152}], {
             RGBColor[
             0.5864069033695402, 0.6744711638253575, 0.9610204096705102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 194}], {
             RGBColor[
             0.4347117939059725, 0.5499861330794993, 0.9491859855560838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 196}], {
             RGBColor[
             0.6187510737973393, 0.6997386755883541, 0.9642441743052955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 101}], {
             RGBColor[
             0.5668583683415734, 0.6541170522918255, 0.961364440874288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 108}], {
             RGBColor[
             0.2928262211263112, 0.42162682679905705`, 0.940114902658546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 110}], {
             RGBColor[
             0.5248650722120111, 0.62131157019454, 0.9571789415657572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 124}], {
             RGBColor[
             0.39837257105942636`, 0.5194720310892318, 0.9466049258542417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 127}], {
             RGBColor[
             0.40614905241917415`, 0.5258663740441142, 0.9471947259613681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 161}], {
             RGBColor[
             0.5807951290336398, 0.6650045556677721, 0.9627535269336397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 175}], {
             RGBColor[
             0.366895942820997, 0.49220855777044015`, 0.9445992629365785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 176}], {
             RGBColor[
             0.6555755112212531, 0.6835925285018454, 0.6304061754267957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 180}], {
             RGBColor[
             0.5258552120506541, 0.6220850749618295, 0.9572776294514903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 187}], {
             RGBColor[
             0.3628418326281869, 0.48869709128693095`, 0.9443409386200015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 199}], {
             RGBColor[
             0.3145047229330066, 0.44441230669429554`, 0.9413494612659679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 95}], {
             RGBColor[
             0.5086904330031029, 0.6089977671528206, 0.9554305410207512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 103}], {
             RGBColor[
             0.5760516491155421, 0.666381560499287, 0.9599882947018246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 108}], {
             RGBColor[
             0.4513144805679856, 0.5528753400608363, 0.9520098929582179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 110}], {
             RGBColor[
             0.6833533316536855, 0.7525600834563193, 0.9690739318654291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 131}], {
             RGBColor[
             0.8175731826932136, 0.826679112590909, 0.6559345687672751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 143}], {
             RGBColor[
             0.5396390536149109, 0.6358039068038679, 0.957402559759345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[
             0.6673310262603989, 0.7400433367090525, 0.967476978200783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 162}], {
             RGBColor[
             0.7139259395270497, 0.7764436370874171, 0.9721211237009818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 180}], {
             RGBColor[
             0.6843434714923287, 0.7533335882236087, 0.9691726197511622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 94}], {
             RGBColor[
             0.5561327226405256, 0.6448660766353658, 0.9606644888211279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 102}], {
             RGBColor[
             0.6359858744745142, 0.70799924526905, 0.9590611712594084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[
             0.6368439767713183, 0.6437329671633946, 0.6094245545691804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 122}], {
             RGBColor[
             0.3519420376350078, 0.47925623670346473`, 0.9436464133213465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 136}], {
             RGBColor[
             0.2734834331867083, 0.4031946620673399, 0.9389438522742019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 142}], {
             RGBColor[
             0.338739131849407, 0.4678205433093171, 0.942805135839559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 153}], {
             RGBColor[
             0.3676299899220921, 0.4928443524751286, 0.9446460357687678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 167}], {
             RGBColor[
             0.42956921900890965`, 0.5443224260285541, 0.9491924846077668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 188}], {
             RGBColor[
             0.5371162520934137, 0.6300102653134328, 0.9587691047560127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 113}], {
             RGBColor[
             0.6361291054016858, 0.6431137815134986, 0.6093790035976434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 118}], {
             RGBColor[
             0.6445757815093063, 0.7143195481179976, 0.9432650575240582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 122}], {
             RGBColor[
             0.35122716626537537`, 0.4786370510535689, 0.9436008623498093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 136}], {
             RGBColor[
             0.27276856181707587`, 0.40257547641744407`, 0.9388983013026648]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 138}], {
             RGBColor[
             0.4618313865155079, 0.570475486137054, 0.9517430069354403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 144}], {
             RGBColor[
             0.3079390997368, 0.4395419417119736, 0.940901211407045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 149}], {
             RGBColor[
             0.3286963733227471, 0.4591220106372445, 0.942165220146703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 159}], {
             RGBColor[
             0.32056582152366225`, 0.45207973532229273`, 0.9416471485756299]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 170}], {
             RGBColor[
             0.5434677983217364, 0.6349114187978224, 0.959427868251213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 192}], {
             RGBColor[
             0.35122716626537537`, 0.4786370510535689, 0.9436008623498093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 197}], {
             RGBColor[
             0.46091351234810063`, 0.5697303145381927, 0.9516707485186982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 141}], {
             RGBColor[
             0.32244153642449913`, 0.44723766769676854`, 0.9420034456796872]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 177}], {
             RGBColor[
             0.3068116292309808, 0.4336998276677204, 0.9410075218143005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 198}], {
             RGBColor[
             0.34365099063379834`, 0.46560823091469916`, 0.9433548933471199]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 95}], {
             RGBColor[
             0.4408454961315029, 0.5542403359614736, 0.9498692868107477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 136}], {
             RGBColor[
             0.3743927996163719, 0.4885776753425809, 0.9459317316006972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 97}], {
             RGBColor[
             0.9182057521105111, 0.93495673576684, 0.8875158719101774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 155}], {
             RGBColor[
             0.5433684935919757, 0.6253432299344484, 0.9610756362926427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 134}], {
             RGBColor[
             0.4865713902184377, 0.5897189770407766, 0.9540515394786058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 139}], {
             RGBColor[
             0.32871127699487046`, 0.4590817703370878, 0.9421681158448548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 145}], {
             RGBColor[
             0.29798328453604744`, 0.43052970365181215`, 0.9402810792763386]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 105}], {
             RGBColor[
             0.8810689605747599, 0.9072431873017046, 0.9526361674950182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 111}], {
             RGBColor[
             0.8070078545106022, 0.36710121535782414`, 0.43592640728269694`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 115}], {
             RGBColor[
             0.6162308702411219, 0.6969200714662753, 0.9644938896435327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 116}], {
             RGBColor[
             0.5772346491206743, 0.663143504738807, 0.962009084916742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 126}], {
             RGBColor[
             0.8382130305673658, 0.8741038978145381, 0.9843586365648157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 142}], {
             RGBColor[
             0.568991972740688, 0.6560041127474238, 0.9614838688665219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 153}], {
             RGBColor[
             0.5978828308133731, 0.6810279219132352, 0.9633247687957307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 160}], {
             RGBColor[
             0.5411954696091266, 0.6307502210588449, 0.9597558310707492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 167}], {
             RGBColor[
             0.6598220599001906, 0.7325059954666606, 0.9678712176347295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 174}], {
             RGBColor[
             0.6719522623159322, 0.7423538402471511, 0.9688261516032923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 188}], {
             RGBColor[
             0.7673690929846948, 0.8181938347515395, 0.9774478377829756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 103}], {
             RGBColor[
             0.4213535937668732, 0.5384159315216724, 0.948334812855413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 129}], {
             RGBColor[
             0.324059220629464, 0.45375382903301154`, 0.9419192377124367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 131}], {
             RGBColor[
             0.6628751273445446, 0.6987134836132944, 0.6442810869208637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 143}], {
             RGBColor[
             0.3849409982662421, 0.5078382778262533, 0.9457490779129335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 154}], {
             RGBColor[
             0.51263297091173, 0.612077707731438, 0.9558234963543717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 105}], {
             RGBColor[
             0.6615719424267781, 0.7283757709204738, 0.9346427859822579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 111}], {
             RGBColor[
             0.6606765090786142, 0.24785627110367026`, 0.4239308196075233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 116}], {
             RGBColor[
             0.3577376309726924, 0.48427608835757624`, 0.9440157034039817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 126}], {
             RGBColor[
             0.618716012419384, 0.6952364814333074, 0.9663652550520554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.3604332382167085, 0.4866108878671835, 0.9441874651139385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 174}], {
             RGBColor[
             0.4524552441679503, 0.5634864238659203, 0.9508327700905319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 182}], {
             RGBColor[
             0.34542541529639925`, 0.4736118659687243, 0.9432311799083531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 191}], {
             RGBColor[
             0.5367390042317829, 0.6306291789992671, 0.9583448158367758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 102}], {
             RGBColor[
             0.9688129840063942, 0.9750415653552011, 0.8830509877526731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 112}], {
             RGBColor[
             0.6376822069755419, 0.7032105903659471, 0.8647202386366819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 140}], {
             RGBColor[
             0.749729516044948, 0.801081257097181, 0.8721851232212958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 155}], {
             RGBColor[
             0.6166968422944692, 0.68115364153717, 0.8635251531631598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 99}], {
             RGBColor[
             0.33737118408118894`, 0.4666356957075406, 0.942717971417397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 117}], {
             RGBColor[
             0.46743864550543746`, 0.5757011241692218, 0.9519983650009048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 120}], {
             RGBColor[
             0.36867406161714367`, 0.4937486749008131, 0.9447125630939402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 121}], {
             RGBColor[
             0.38060338598581894`, 0.5040812560836831, 0.9454726890940248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 146}], {
             RGBColor[
             0.3129768285970117, 0.44254386744929, 0.9412720622856272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 156}], {
             RGBColor[
             0.39695354744280376`, 0.5182429441547141, 0.9465145069241838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.3666479186808337, 0.4919937317262864, 0.9445834590576865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 178}], {
             RGBColor[
             0.5102624857108017, 0.6100245125944443, 0.9556724511335062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 179}], {
             RGBColor[
             0.38152232713549084`, 0.5048771967202038, 0.9455312432114942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 183}], {
             RGBColor[
             0.3665380280443804, 0.4918985499802545, 0.944576456923504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 196}], {
             RGBColor[
             0.5490193724839719, 0.6403016871048941, 0.9595353754033569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 107}], {
             RGBColor[
             0.3405450689599137, 0.46938475526539963`, 0.9429202085553131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 109}], {
             RGBColor[
             0.28988296936283786`, 0.42046757276803337`, 0.9398764649857274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 146}], {
             RGBColor[
             0.3010966054256231, 0.4322538152556117, 0.9405150649704153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 147}], {
             RGBColor[
             0.6269000562504048, 0.6049111748354591, 0.6015675192765305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 156}], {
             RGBColor[
             0.3850733242714151, 0.5079528919610358, 0.9457575096089719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 178}], {
             RGBColor[
             0.4983822625394131, 0.5997344604007662, 0.9549154538182942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 179}], {
             RGBColor[
             0.36964210396410224`, 0.4945871445265255, 0.9447742458962822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 194}], {
             RGBColor[
             0.35309986942121646`, 0.4802590924023611, 0.9437201893389331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 104}], {
             RGBColor[
             0.6557867868467999, 0.7190369200969648, 0.7226176820679706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 123}], {
             RGBColor[
             0.7540531906118311, 0.8024786920420115, 0.7293410117407353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 130}], {
             RGBColor[
             0.6514440954388513, 0.7152754990694165, 0.7223409696115473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 135}], {
             RGBColor[
             0.8471322303239477, 0.8771455071916745, 0.7372831465703549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 148}], {
             RGBColor[
             0.7705588527772402, 0.8158787321594976, 0.7306403979286289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 163}], {
             RGBColor[
             0.7682474088148944, 0.8140021978215014, 0.730458432592815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 165}], {
             RGBColor[
             0.6649675451949136, 0.7269888315397695, 0.7232026718716865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 123}], {
             RGBColor[
             0.6510941394309397, 0.725406195413314, 0.9671937510397606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 124}], {
             RGBColor[
             0.618818969932577, 0.6991227137741807, 0.9646753244607108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 127}], {
             RGBColor[
             0.6265954512923247, 0.705517056729063, 0.9652651245678372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 135}], {
             RGBColor[
             0.7441731791430564, 0.800073010562977, 0.9751358858693802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 137}], {
             RGBColor[
             0.8560746451767602, 0.888338834882288, 0.9860642648939149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 161}], {
             RGBColor[
             0.8012415279067904, 0.8446552383527208, 0.9808239255401088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 165}], {
             RGBColor[
             0.5620084940140222, 0.6499163349110719, 0.9610554111707119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 175}], {
             RGBColor[
             0.5873423416941477, 0.6718592404553889, 0.9626696615430476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 176}], {
             RGBColor[
             0.8760219100944038, 0.8632432111867941, 0.6484765740332648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 187}], {
             RGBColor[
             0.5832882315013375, 0.6683477739718797, 0.9624113372264707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 199}], {
             RGBColor[
             0.5349511218061571, 0.6240629893792444, 0.9594198598724369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 106}], {
             RGBColor[
             0.6678179656976136, 0.7355706027590738, 0.9610894839641313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 112}], {
             RGBColor[
             0.6149610901689316, 0.6874850083515867, 0.9578058376086604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 140}], {
             RGBColor[
             0.7270083992383377, 0.7853556750828206, 0.9652707221932744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 108}], {
             RGBColor[
             0.3639776413317559, 0.4822935044296881, 0.9449141647928798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 129}], {
             RGBColor[
             0.3914204367419031, 0.5111376223794779, 0.94647699139351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 131}], {
             RGBColor[
             0.7302363434569837, 0.7560972769597609, 0.648838840601937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 133}], {
             RGBColor[
             0.37184055667295823`, 0.49055792699091855`, 0.9453619461894204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 143}], {
             RGBColor[
             0.45230221437868123`, 0.5652220711727198, 0.9503068315940069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 154}], {
             RGBColor[
             0.579994187024169, 0.6694615010779044, 0.9603812500354449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 162}], {
             RGBColor[
             0.62658910029082, 0.705861801456269, 0.9650253955356436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 123}], {
             RGBColor[
             0.41661710788212414`, 0.5336028839048071, 0.9482293329259994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 130}], {
             RGBColor[
             0.31400801270914436`, 0.4463996909322121, 0.9412292907968115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 163}], {
             RGBColor[
             0.43081132608518746`, 0.545126389684297, 0.9493467537780791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 111}], {
             RGBColor[
             0.8701301192059044, 0.41656357617664563`, 0.41812170438064866`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 116}], {
             RGBColor[
             0.6719180461636277, 0.7373370459670392, 0.9353020305636697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 126}], {
             RGBColor[
             0.9328964276103193, 0.9482974390427703, 0.9576515822117433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 142}], {
             RGBColor[
             0.6636753697836414, 0.730197653975656, 0.9347768145134494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 157}], {
             RGBColor[
             0.6746136534076439, 0.7396718454766464, 0.9354737922736265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 160}], {
             RGBColor[
             0.6358788666520799, 0.7049437622870771, 0.9330487767176767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 174}], {
             RGBColor[
             0.7666356593588857, 0.8165473814753833, 0.9421190972502199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 182}], {
             RGBColor[
             0.6596058304873346, 0.7266728235781873, 0.9345175070680412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 112}], {
             RGBColor[
             0.3366871886667614, 0.4637396277698198, 0.9427587348481401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 140}], {
             RGBColor[
             0.44873449773616747`, 0.5616102945010537, 0.950223619432754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 189}], {
             RGBColor[
             0.45416585893631434`, 0.5660197182033666, 0.9506511960821612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 111}], {
             RGBColor[
             0.6634123923366757, 0.2502259556723123, 0.4241051476694805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 142}], {
             RGBColor[
             0.35359877947979823`, 0.48069122321915597`, 0.9437519794466972]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[
             0.6419541643005181, 0.6179502865869964, 0.6025267537296587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.4001274323215285, 0.520992003712573, 0.9467167440621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.3645370631038007, 0.4901654147201465, 0.9444489572068742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.3846962120142156, 0.5076262562780628, 0.9457334803494104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 181}], {
             RGBColor[
             0.38133053918418647`, 0.5047110796363267, 0.9455190226528285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 185}], {
             RGBColor[
             0.29000014652494466`, 0.41780702310015816`, 0.9399850633219927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 110}], {
             RGBColor[
             0.4712793238698994, 0.5684720273867203, 0.9539998019564844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 131}], {
             RGBColor[
             0.6054991749094274, 0.6425910565213102, 0.6408604388583303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 154}], {
             RGBColor[
             0.45525701847661265`, 0.5559552806394537, 0.9524028482918383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 162}], {
             RGBColor[
             0.5018519317432636, 0.5923555810178183, 0.9570469937920371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 180}], {
             RGBColor[
             0.47226946370854245`, 0.5692455321540099, 0.9540984898422175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 132}], {
             RGBColor[
             0.27602327007887173`, 0.40744833611198583`, 0.9390304889399326]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 146}], {
             RGBColor[
             0.26548861387866063`, 0.39637574450978275`, 0.9384305558539577]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 150}], {
             RGBColor[
             0.28007292524349403`, 0.41170478045297126`, 0.9392611108106298]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 151}], {
             RGBColor[
             0.3696167352188829, 0.48866983966030203`, 0.9451944056757043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 152}], {
             RGBColor[
             0.4691869873378217, 0.5688660524023904, 0.9534701043369019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 194}], {
             RGBColor[
             0.3174918778742539, 0.4443810216565321, 0.9416356802224757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 196}], {
             RGBColor[
             0.5015311577656207, 0.5941335641653869, 0.9566938689716873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 127}], {
             RGBColor[
             0.5846021551627624, 0.6727115746317776, 0.9610796252593065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 162}], {
             RGBColor[
             0.7338907828289636, 0.7920403244133012, 0.9741110326992483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 180}], {
             RGBColor[
             0.7043083147942424, 0.7689302755494929, 0.9711625287494287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 116}], {
             RGBColor[
             0.6675739115698474, 0.2538304544680472, 0.4243703159951311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 126}], {
             RGBColor[
             0.8415594992009751, 0.3944707165185346, 0.43927001709384694`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 142}], {
             RGBColor[
             0.6620787939831898, 0.249070859807125, 0.424020171961651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 157}], {
             RGBColor[
             0.6693709830658581, 0.25538698747445204`, 0.424484823801769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 160}], {
             RGBColor[
             0.6435477918954822, 0.2322349320147391, 0.42286814676446927`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 167}], {
             RGBColor[
             0.7226321854228582, 0.30007211495328295`, 0.4282784044737895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 174}], {
             RGBColor[
             0.7307189870333527, 0.30663734480694327`, 0.428915027119498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 181}], {
             RGBColor[
             0.6805666337861154, 0.2650840974185721, 0.42519820076573855`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.6196797053466208, 0.2071480597277931, 0.42150889454518137`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 188}], {
             RGBColor[
             0.7943302074791944, 0.3571973411432022, 0.4346628179059535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 140}], {
             RGBColor[
             0.39587762220748546`, 0.5135247000935665, 0.9469399730772832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 122}], {
             RGBColor[
             0.6629061326570814, 0.6663066966696001, 0.6110852120963617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 136}], {
             RGBColor[
             0.584447528208782, 0.5902451220334752, 0.6063826510492172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 138}], {
             RGBColor[
             0.773510352907214, 0.7581451317530852, 0.6192273566819928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 144}], {
             RGBColor[
             0.6196180661285061, 0.6272115873280047, 0.6083855611535973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 159}], {
             RGBColor[
             0.6322447879153683, 0.639749380938324, 0.6091314983221823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 167}], {
             RGBColor[
             0.7405333140309833, 0.7313728859946894, 0.6166312833827821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 197}], {
             RGBColor[
             0.7725924787398067, 0.7573999601542238, 0.6191550982652505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 158}], {
             RGBColor[
             0.5450333894645971, 0.6311439029663735, 0.9605506944153089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 160}], {
             RGBColor[
             0.3710407763184418, 0.4946206464516478, 0.9449064988661912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 126}], {
             RGBColor[
             0.6290621161562338, 0.7041977564798728, 0.9670244996334671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 142}], {
             RGBColor[
             0.35984105832955576`, 0.48609797141275835`, 0.9441497319351733]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 153}], {
             RGBColor[
             0.38873191640224086`, 0.5111217805785699, 0.945990631864382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 157}], {
             RGBColor[
             0.3707793419535582, 0.49557216291374895`, 0.9448467096953502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 160}], {
             RGBColor[
             0.3320445551979943, 0.4608440797241795, 0.9424216941394006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 167}], {
             RGBColor[
             0.4506711454890584, 0.5625998541319953, 0.9505370807033809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 174}], {
             RGBColor[
             0.4628013479048, 0.5724476989124858, 0.9514920146719437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 188}], {
             RGBColor[
             0.5582181785735625, 0.6482876934168742, 0.960113700851627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 120}], {
             RGBColor[
             0.48686129987000354`, 0.592524051168816, 0.9532359593622362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 121}], {
             RGBColor[
             0.4987906242386788, 0.602856632351686, 0.9539960853623208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 146}], {
             RGBColor[
             0.4311640668498716, 0.5413192437172929, 0.9497954585539231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 151}], {
             RGBColor[
             0.5352921881900938, 0.6336133388678122, 0.9565593083756697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 171}], {
             RGBColor[
             0.48483515693369356`, 0.5907691079942894, 0.9531068553259823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 173}], {
             RGBColor[
             0.7143152191271582, 0.7760647328580225, 0.9727047411538614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 196}], {
             RGBColor[
             0.6672066107368317, 0.7390770633728971, 0.9680587716716527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 119}], {
             RGBColor[
             0.6826641409742542, 0.7473097707099257, 0.9456920141089509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 125}], {
             RGBColor[
             0.6570658492810484, 0.7251378170528211, 0.9440609135979403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 128}], {
             RGBColor[
             0.7157636781908093, 0.7756121541821681, 0.9479024275573068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 138}], {
             RGBColor[
             0.7819570290148345, 0.829350898357584, 0.9531134106084076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 144}], {
             RGBColor[
             0.6280647422361266, 0.6984173539325036, 0.9422716150800121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 149}], {
             RGBColor[
             0.6488220158220737, 0.7179974228577746, 0.9435356238196702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 159}], {
             RGBColor[
             0.6406914640229888, 0.7109551475428229, 0.9430175522485972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 170}], {
             RGBColor[
             0.863593440821063, 0.8937868310183525, 0.9607982719241801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 190}], {
             RGBColor[
             0.6753570903341315, 0.7409807707084952, 0.9452264153035335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 192}], {
             RGBColor[
             0.6713528087647019, 0.737512463274099, 0.9449712660227766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.7809570759637912, 0.8285390914233753, 0.9530346906412808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 197}], {
             RGBColor[
             0.7810391548474273, 0.8286057267587227, 0.9530411521916654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 125}], {
             RGBColor[
             0.3750285662466696, 0.49925262742421916`, 0.9451174665098658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 128}], {
             RGBColor[
             0.43372639515643063`, 0.5497269645535662, 0.9489589804692322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 144}], {
             RGBColor[
             0.3460274592017479, 0.47253216430390177`, 0.9433281679919376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 149}], {
             RGBColor[
             0.36678473278769497`, 0.4921122332291727, 0.9445921767315957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 183}], {
             RGBColor[
             0.39222575338802934`, 0.514147966570307, 0.9462132560676377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 190}], {
             RGBColor[
             0.3933198072997528, 0.5150955810798934, 0.9462829682154589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 192}], {
             RGBColor[
             0.38931552573032324`, 0.5116272736454971, 0.946027818934702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 195}], {
             RGBColor[
             0.49891979292941246`, 0.6026539017947734, 0.9540912435532061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 128}], {
             RGBColor[
             0.4274613241773478, 0.544300474963108, 0.9485597756864299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 168}], {
             RGBColor[
             0.32687043811103783`, 0.4535554177492756, 0.942194785722209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 171}], {
             RGBColor[
             0.3860705730453998, 0.5088166587258807, 0.9458210534190177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 172}], {
             RGBColor[
             0.428113490095943, 0.5448299326355633, 0.9486111165765041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 173}], {
             RGBColor[
             0.6155506352388644, 0.6941122835896137, 0.9654189392468968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 183}], {
             RGBColor[
             0.38596068240894654`, 0.5087214769798487, 0.9458140512848354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 151}], {
             RGBColor[
             0.4484569286704754, 0.5619934707822735, 0.9500336324687897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 171}], {
             RGBColor[
             0.39799989741407504`, 0.5191492399087506, 0.9465811794191024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 196}], {
             RGBColor[
             0.5803713512172133, 0.6674571952873584, 0.9615330957647727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 136}], {
             RGBColor[
             0.29954558907247153`, 0.4257683915735455, 0.9406045098013831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 138}], {
             RGBColor[
             0.4886084137709036, 0.5936684012931555, 0.9534492154341587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 142}], {
             RGBColor[
             0.36480128773517023`, 0.4903942728155227, 0.9444657933667404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 144}], {
             RGBColor[
             0.33471612699219566`, 0.46273485686807503`, 0.9426074199057632]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 153}], {
             RGBColor[
             0.39369214580785533`, 0.5154180819813342, 0.9463066932959492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.3473428487790579, 0.4752726504783942, 0.9433533570743483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 167}], {
             RGBColor[
             0.45563137489467287`, 0.5668961555347596, 0.9508531421349481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 181}], {
             RGBColor[
             0.3925330474395584, 0.5144141292326934, 0.9462328365728718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 188}], {
             RGBColor[
             0.563178407979177, 0.6525839948196385, 0.9604297622831941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 192}], {
             RGBColor[
             0.378004193520771, 0.5018299662096704, 0.9453070708485277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 127}], {
             RGBColor[
             0.4903848235085404, 0.5971555171656027, 0.9530240361268407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 130}], {
             RGBColor[
             0.4122744164741755, 0.5298414628772588, 0.9479526204695762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 135}], {
             RGBColor[
             0.6079625513592719, 0.6917114709995167, 0.9628947974283837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 163}], {
             RGBColor[
             0.5290777298502186, 0.6285681616293437, 0.9560700834508438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 165}], {
             RGBColor[
             0.42579786623023785`, 0.5415547953476118, 0.9488143227297154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 177}], {
             RGBColor[
             0.44485193565434844`, 0.5580584725974012, 0.9500284311845677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 187}], {
             RGBColor[
             0.4470776037175531, 0.5599862344084195, 0.9501702487854742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 127}], {
             RGBColor[
             0.45810965401017767`, 0.5708720355264694, 0.950505609547791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 135}], {
             RGBColor[
             0.5756873818609092, 0.6654279893603834, 0.960376370849334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.6875888478946132, 0.7536938136796943, 0.9713047498738685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 161}], {
             RGBColor[
             0.6327557306246433, 0.7100102171501272, 0.9660644105200625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 175}], {
             RGBColor[
             0.41885654441200054`, 0.5372142192527953, 0.9479101465230013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 176}], {
             RGBColor[
             0.7075361128122566, 0.7285981899842005, 0.6337170590132185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 187}], {
             RGBColor[
             0.4148024342191904, 0.5337027527692861, 0.9476518222064243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 199}], {
             RGBColor[
             0.36646532452401004`, 0.48941796817665073`, 0.9446603448523907]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 128}], {
             RGBColor[
             0.40812810346322476`, 0.5275550108964615, 0.9473278799582217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.34118644109448915`, 0.4699402795720681, 0.9429610762205851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[
             0.5559578660934784, 0.6457296877326459, 0.9602237243250951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 190}], {
             RGBColor[
             0.367721515606547, 0.4929236274227887, 0.9446518677044484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 195}], {
             RGBColor[
             0.4733215012362066, 0.5804819481376688, 0.9524601430421956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 142}], {
             RGBColor[
             0.6208194397762473, 0.6970583644884895, 0.9664992835832469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 157}], {
             RGBColor[
             0.6317577234002498, 0.7065325559894801, 0.967196261343424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 160}], {
             RGBColor[
             0.5930229366446859, 0.6718044727999106, 0.9647712457874742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 174}], {
             RGBColor[
             0.7237797293514916, 0.7834080919882169, 0.9738415663200174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 182}], {
             RGBColor[
             0.6167499004799405, 0.6935335340910208, 0.9662399761378386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 191}], {
             RGBColor[
             0.8080634894153242, 0.8505508471215636, 0.9813536120662611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 135}], {
             RGBColor[
             0.583463863220657, 0.6718223323152657, 0.9609661709564603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 161}], {
             RGBColor[
             0.6405322119843911, 0.7164045601050095, 0.9666542106271889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 175}], {
             RGBColor[
             0.42663302577174833`, 0.5436085622076776, 0.9484999466301277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 176}], {
             RGBColor[
             0.7153125941720044, 0.7349925329390828, 0.6343068591203449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 177}], {
             RGBColor[
             0.42035324751573355`, 0.5381693339131501, 0.9480998047126443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 180}], {
             RGBColor[
             0.5855922950014054, 0.673485079399067, 0.9611783131450395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 187}], {
             RGBColor[
             0.42257891557893823`, 0.5400970957241684, 0.9482416223135508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 183}], {
             RGBColor[
             0.42532529060458446`, 0.5424503500425493, 0.9484236695159937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 190}], {
             RGBColor[
             0.4264193445163079, 0.5433979645521357, 0.9484933816638148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 192}], {
             RGBColor[
             0.42241506294687836`, 0.5399296571177394, 0.9482382323830579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 195}], {
             RGBColor[
             0.5320193301459676, 0.6309562852670159, 0.9563016570015621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 131}], {
             RGBColor[
             0.6329419703195746, 0.6714351744711, 0.6424232654589606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 133}], {
             RGBColor[
             0.274546183535549, 0.4058958245022577, 0.9389463710464441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 143}], {
             RGBColor[
             0.35500784124127205`, 0.4805599686840589, 0.9438912564510304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 170}], {
             RGBColor[
             0.5283057606189935, 0.6204271107944972, 0.9585112494509342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 197}], {
             RGBColor[
             0.44575147464535775`, 0.5552460065348674, 0.9507541297184194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 163}], {
             RGBColor[
             0.42646863467723883`, 0.5413649686567485, 0.9490700413216558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 177}], {
             RGBColor[
             0.3422428404813687, 0.4708552796248061, 0.9430283890553798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 133}], {
             RGBColor[
             0.6133620902506296, 0.6508554790825406, 0.641308220254871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 143}], {
             RGBColor[
             0.6938237479563527, 0.7255196232643418, 0.6462531056594574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 154}], {
             RGBColor[
             0.8215157206018405, 0.8297590531695265, 0.6563275241008956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 162}], {
             RGBColor[
             0.8681106338684914, 0.8661593535478911, 0.6609716696010943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 180}], {
             RGBColor[
             0.8385281658337703, 0.8430493046840826, 0.6580231656512747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 150}], {
             RGBColor[
             0.3018212175064905, 0.43456361454275266`, 0.9404996438812923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 151}], {
             RGBColor[
             0.3913650274818793, 0.5115286737500835, 0.9464329387463668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 162}], {
             RGBColor[
             0.5097148470844659, 0.6006200035790488, 0.9574947751885776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 139}], {
             RGBColor[
             0.5071115204761448, 0.6075629546049077, 0.9553583923663599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 145}], {
             RGBColor[
             0.47638352801732176`, 0.5790108879196321, 0.9534713557978437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 191}], {
             RGBColor[
             0.6955290574637176, 0.7620718529980599, 0.9702874944255462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 148}], {
             RGBColor[
             0.6244682135246812, 0.7051115111170028, 0.9641941836162775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 163}], {
             RGBColor[
             0.6221567695623353, 0.7032349767790066, 0.9640122182804634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 165}], {
             RGBColor[
             0.5188769059423546, 0.6162216104972746, 0.956756457559335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 176}], {
             RGBColor[
             0.832890322022736, 0.8295484867729969, 0.6441776204218879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 187}], {
             RGBColor[
             0.5401566434296698, 0.6346530495580824, 0.9581123836150938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 143}], {
             RGBColor[
             0.3184883017511111, 0.4421756172073607, 0.9418115227028829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 159}], {
             RGBColor[
             0.2688842443307584, 0.39921107584226934`, 0.9386507960272037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 197}], {
             RGBColor[
             0.4092319351551968, 0.5168616550581693, 0.9486743959702719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 161}], {
             RGBColor[
             0.8700114058688266, 0.8992263382582346, 0.9874533509532666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 175}], {
             RGBColor[
             0.6561122196561839, 0.7264303403609027, 0.9692990869562053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 176}], {
             RGBColor[
             0.94479178805644, 0.9178143110923078, 0.6551059994464226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 186}], {
             RGBColor[
             0.5677787693564067, 0.6408565262529409, 0.9640024284354084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 187}], {
             RGBColor[
             0.6520581094633737, 0.7229188738773935, 0.9690407626396284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 199}], {
             RGBColor[
             0.6037209997681934, 0.6786340892847581, 0.9660492852855946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 142}], {
             RGBColor[
             0.4754055079853028, 0.5822327078990077, 0.9526079379523713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 144}], {
             RGBColor[
             0.4453203472423283, 0.55457329195156, 0.9507495644913943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 156}], {
             RGBColor[
             0.521934160827033, 0.6225334883924248, 0.9555727025677742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 159}], {
             RGBColor[
             0.45794706902919047`, 0.5671110855618793, 0.9514955016599793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 167}], {
             RGBColor[
             0.5662355951448055, 0.6587345906182447, 0.9589952867205791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 181}], {
             RGBColor[
             0.503137267689691, 0.6062525643161785, 0.9543749811585027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 185}], {
             RGBColor[
             0.4118068750304492, 0.51934850778001, 0.9488410218276668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 192}], {
             RGBColor[
             0.4886084137709036, 0.5936684012931555, 0.9534492154341587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 145}], {
             RGBColor[
             0.31852341479375457`, 0.44837368121594323`, 0.9415879321640928]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 152}], {
             RGBColor[
             0.5166752020561728, 0.6150341753418976, 0.9563116107685714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 182}], {
             RGBColor[
             0.3463553553047667, 0.4744173332638283, 0.9432904348633726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 191}], {
             RGBColor[
             0.5376689442401503, 0.6314346462943711, 0.9584040707917953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 198}], {
             RGBColor[
             0.4272896282578774, 0.5445185326209754, 0.9484474951685773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 153}], {
             RGBColor[
             0.38048924002225454`, 0.5039823885871866, 0.9454654158141619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 157}], {
             RGBColor[
             0.3625366655735719, 0.4884327709223656, 0.9443214936451301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 160}], {
             RGBColor[
             0.323801878818008, 0.4537046877327962, 0.9418964780891804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 167}], {
             RGBColor[
             0.4424284691090721, 0.555460462140612, 0.9500118646531608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 174}], {
             RGBColor[
             0.45455867152481366`, 0.5653083069211025, 0.9509667986217236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 181}], {
             RGBColor[
             0.3793301416539576, 0.5029784358385457, 0.9453915590910844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 185}], {
             RGBColor[
             0.28799974899471587`, 0.41607437930237723`, 0.9398575997602486]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.5499755021935762, 0.6411483014254908, 0.9595884848014068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 154}], {
             RGBColor[
             0.543581591523538, 0.6388838473824854, 0.9577955150929653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 159}], {
             RGBColor[
             0.3662855614576975, 0.4916798761122094, 0.944560369975848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 197}], {
             RGBColor[
             0.5066332522821358, 0.6093304553281093, 0.9545839699189163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 149}], {
             RGBColor[
             0.3121853340495674, 0.44321981645175057`, 0.9411717777026569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 159}], {
             RGBColor[
             0.30405478225048255`, 0.43617754113679885`, 0.9406537061315838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 170}], {
             RGBColor[
             0.5269567590485567, 0.6190092246123285, 0.9584344258071669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 181}], {
             RGBColor[
             0.3492449809109831, 0.47531901989109804`, 0.9435331856301074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 190}], {
             RGBColor[
             0.3387204085616252, 0.46620316430247133`, 0.9428625691865202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 192}], {
             RGBColor[
             0.33471612699219566`, 0.46273485686807503`, 0.9426074199057632]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 197}], {
             RGBColor[
             0.444402473074921, 0.5538281203526987, 0.9506773060746521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 147}], {
             RGBColor[
             0.6025057007662276, 0.5808193465772084, 0.6001216101447608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 156}], {
             RGBColor[
             0.3606789687872379, 0.48386106370278514`, 0.9443116004772021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 171}], {
             RGBColor[
             0.33037334002526786`, 0.45761185127435744`, 0.9423805526107047]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 178}], {
             RGBColor[
             0.47398790705523586`, 0.5756426321425154, 0.9534695446865245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 179}], {
             RGBColor[
             0.345247748479925, 0.4704953162682749, 0.9433283367645124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 183}], {
             RGBColor[
             0.3302634493888146, 0.4575166695283256, 0.9423735504765223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 194}], {
             RGBColor[
             0.32870551393703923`, 0.45616726414411035`, 0.9422742802071634]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 196}], {
             RGBColor[
             0.512744793828406, 0.6059198066529652, 0.9573324689563751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 152}], {
             RGBColor[
             0.8062040742253886, 0.7533096544698161, 0.615161158627705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 156}], {
             RGBColor[
             0.6864824196120195, 0.6565184232826324, 0.6053640547833175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 178}], {
             RGBColor[
             0.7997913578800175, 0.7482999917223628, 0.6145219989926398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 179}], {
             RGBColor[
             0.6710511993047066, 0.6431526758481223, 0.6043807910706278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 185}], {
             RGBColor[
             0.5763551338154357, 0.5533334426702176, 0.5986323740432102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 194}], {
             RGBColor[
             0.6545089647618209, 0.6288246237239578, 0.6033267345132787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 165}], {
             RGBColor[
             0.44230352839564707`, 0.5549548354650978, 0.950113708917609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 159}], {
             RGBColor[
             0.32481205583642964`, 0.45575761006206983`, 0.9419177148712419]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 170}], {
             RGBColor[
             0.5477140326345038, 0.6385892935375994, 0.9596984345468249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 190}], {
             RGBColor[
             0.3594776821475723, 0.48578323322774225`, 0.9441265779261783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 192}], {
             RGBColor[
             0.35547340057814275`, 0.48231492579334595`, 0.9438714286454213]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 195}], {
             RGBColor[
             0.4650776677772319, 0.5733415539426223, 0.9519348532639255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.465159746660868, 0.5734081892779697, 0.9519413148143101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 151}], {
             RGBColor[
             0.3954146826465016, 0.5157851180910689, 0.9466635606170641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 152}], {
             RGBColor[
             0.4949849347654404, 0.5959813308331572, 0.9549392592782617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 194}], {
             RGBColor[
             0.3432898253018727, 0.4714963000872989, 0.9431048351638355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 171}], {
             RGBColor[
             0.43450146136549017`, 0.5499059464248768, 0.9491444024324514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 196}], {
             RGBColor[
             0.6168729151686283, 0.6982139018034845, 0.9640963187781217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 194}], {
             RGBColor[
             0.5324038873962003, 0.628657572036718, 0.9573138286901076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 160}], {
             RGBColor[
             0.3526927368906931, 0.47872849689860775`, 0.9437373780183892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 167}], {
             RGBColor[
             0.4713193271817572, 0.5804842713064235, 0.9518527645823696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 174}], {
             RGBColor[
             0.48344952959749876`, 0.5903321160869139, 0.9528076985509324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 188}], {
             RGBColor[
             0.5788663602662613, 0.6661721105913023, 0.9614293847306156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 157}], {
             RGBColor[
             0.4090653184153021, 0.5287335514157827, 0.9472862582605328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 178}], {
             RGBColor[
             0.5579646259010278, 0.6513417088479396, 0.9587119893250811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.429224467325717, 0.546194392973699, 0.948570781403069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 181}], {
             RGBColor[
             0.42585879449568786`, 0.5432792163319629, 0.9483563237064873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 183}], {
             RGBColor[
             0.4142401682346065, 0.5332157462337497, 0.9476159951150789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 185}], {
             RGBColor[
             0.33452840183644605`, 0.4563751597957943, 0.9428223643756515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 192}], {
             RGBColor[
             0.4113299405769004, 0.5306950533089398, 0.9474305579821432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 174}], {
             RGBColor[
             0.4654969551488161, 0.5747824984220931, 0.9516637763819005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 181}], {
             RGBColor[
             0.3902684252779601, 0.5124526273395362, 0.9460885368512615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 185}], {
             RGBColor[
             0.2989380326187183, 0.4255485708033678, 0.9405545775204256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 164}], {
             RGBColor[
             0.583210495550654, 0.6671736570547846, 0.9628748282278226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 166}], {
             RGBColor[
             0.6325804510405995, 0.7099354310940624, 0.9660206381355045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 170}], {
             RGBColor[
             0.539583480835419, 0.6315470182226477, 0.9591803629757518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 197}], {
             RGBColor[
             0.4570291948617832, 0.5663659139630179, 0.9514232432432371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 167}], {
             RGBColor[
             0.4146319659775106, 0.5302065704520331, 0.9482838268573881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 174}], {
             RGBColor[
             0.4267621683932522, 0.5400544152325236, 0.9492387608259509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 188}], {
             RGBColor[
             0.5221789990620147, 0.615894409736912, 0.9578604470056341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 175}], {
             RGBColor[
             0.6012791023862141, 0.6827467438313355, 0.9640587476023993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 176}], {
             RGBColor[
             0.8899586707864702, 0.8741307145627408, 0.6498656600926165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 187}], {
             RGBColor[
             0.5972249921934039, 0.6792352773478264, 0.9638004232858224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 193}], {
             RGBColor[
             0.7200072720294511, 0.7809259941602433, 0.9729107784806735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 199}], {
             RGBColor[
             0.5488878824982235, 0.634950492755191, 0.9608089459317887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 180}], {
             RGBColor[
             0.7348809226676065, 0.7928138291805907, 0.9742097205849813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 177}], {
             RGBColor[
             0.45904615385741177`, 0.5695819783768911, 0.9511458520366474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 166}], {
             RGBColor[
             0.40242641760350506`, 0.5229832692134612, 0.9468632333713547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 184}], {
             RGBColor[
             0.4330328331949844, 0.5478722519319404, 0.9492612668601988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 187}], {
             RGBColor[
             0.3579919583006357, 0.4844963739061775, 0.9440319089164254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 184}], {
             RGBColor[
             0.4824027886849299, 0.5906340259712182, 0.9524070767678807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 181}], {
             RGBColor[
             0.47016022881346026`, 0.5794803185577826, 0.9517789078592922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 188}], {
             RGBColor[
             0.6408055893530789, 0.7176501841447278, 0.9659758335696145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 172}], {
             RGBColor[
             0.36688721222527104`, 0.48781374848443165`, 0.9448557448434417]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 173}], {
             RGBColor[
             0.5543243573681924, 0.637096099438482, 0.9616635675138343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 184}], {
             RGBColor[
             0.38932668225838757`, 0.5060311211439207, 0.9466222621229358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 198}], {
             RGBColor[
             0.35707162135377124`, 0.47971416471852496`, 0.9441191784125783]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 200}], {
             RGBColor[
             0.3947928412836497, 0.5163714490799041, 0.94637682863836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 190}], {
             RGBColor[
             0.5742491071465616, 0.6615726413883202, 0.9613892260306882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 195}], {
             RGBColor[
             0.6798490927762213, 0.7491309621032003, 0.9691975013684354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 197}], {
             RGBColor[
             0.6799311716598573, 0.7491975974385476, 0.96920396291882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 173}], {
             RGBColor[
             0.6135244923025545, 0.6923573404150871, 0.9652898352106429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 178}], {
             RGBColor[
             0.5276589971390578, 0.6250924964195119, 0.9567809414585837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 183}], {
             RGBColor[
             0.38393453947263656`, 0.506966533805322, 0.9456849472485815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 196}], {
             RGBColor[
             0.566415883912228, 0.6553696709299617, 0.9606438657284343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 173}], {
             RGBColor[
             0.6555674093530977, 0.7283706143247698, 0.9680798983681294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 198}], {
             RGBColor[
             0.4583146733386764, 0.5709886796048127, 0.9505355092668734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 188}], {
             RGBColor[
             0.6529357917688204, 0.7274980289252182, 0.9669307675381773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 176}], {
             RGBColor[
             0.6760594845738274, 0.7013347166654088, 0.6317113960955553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 187}], {
             RGBColor[
             0.3833258059807611, 0.5064392794504944, 0.9456461592887611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 199}], {
             RGBColor[
             0.33498869628558076`, 0.46215449485785903`, 0.9426546819347275]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 187}], {
             RGBColor[
             0.6720053743810173, 0.6978232501818997, 0.6314530717789784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 199}], {
             RGBColor[
             0.6236682646858369, 0.6535384655892642, 0.6284615944249446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 179}], {
             RGBColor[
             0.542533405593715, 0.6379759614134293, 0.9577287256123914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 183}], {
             RGBColor[
             0.5275491065026046, 0.62499731467348, 0.9567739393244014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 183}], {
             RGBColor[
             0.3988089479272937, 0.5198499987992394, 0.9466327314023892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 185}], {
             RGBColor[
             0.31909718152913324`, 0.44300941236128405`, 0.9418391006629618]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 194}], {
             RGBColor[
             0.39725101247551836`, 0.5185005934150242, 0.9465334611330304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 185}], {
             RGBColor[
             0.31573150869910405`, 0.44009423571954787`, 0.9416246429663799]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 188}], {
             RGBColor[
             0.5777072618979644, 0.6651681578426615, 0.9613555280075381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 192}], {
             RGBColor[
             0.3925330474395584, 0.5144141292326934, 0.9462328365728718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 191}], {
             RGBColor[
             0.5347728922923395, 0.6289262316569805, 0.958219536922559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 192}], {
             RGBColor[
             0.3809144211784771, 0.5043506591344802, 0.9454925079814634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 193}], {
             RGBColor[
             0.4177746355170312, 0.5225561821549497, 0.9494598559628153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 199}], {
             RGBColor[
             0.24665524598580352`, 0.3765806807498973, 0.9373580234139305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 199}], {
             RGBColor[
             0.3309345860927706, 0.4586430283743499, 0.9423963576181504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 192}], {
             RGBColor[
             0.3820084750902006, 0.5052982736440667, 0.9455622201292846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 195}], {
             RGBColor[
             0.49161274228928975`, 0.596324901793343, 0.9536256447477887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 199}], {
             RGBColor[
             0.4537168659288179, 0.5603337451867669, 0.9515067128130017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 197}], {
             RGBColor[
             0.5972948068025855, 0.6839498578435704, 0.9614403816359207]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.0949885500996571], {
             RGBColor[
             0.5830963605383528, 0.6724229195335513, 0.9603226279353778]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.0949885500996571], {
             RGBColor[
             0.5773921694527153, 0.6677920002393509, 0.959873573117976]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.0949885500996571], {
             RGBColor[
             0.3730529579049096, 0.4975414547755491, 0.9449915824932907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.0949885500996571], {
             RGBColor[
             0.6020395547027549, 0.687801857937385, 0.9618139055712062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.0949885500996571], {
             RGBColor[
             0.8494585280057952, 0.8827991885670718, 0.9855033067934146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.0949885500996571], {
             RGBColor[
             0.2709824298365486, 0.40215009340957314`, 0.9387434205453871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.0949885500996571], {
             RGBColor[
             0.5041304907798833, 0.6083148690917327, 0.9541061454064791]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.0949885500996571], {
             RGBColor[
             0.3838246488361832, 0.5068713520592901, 0.9456779451143992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.0949885500996571], {
             RGBColor[
             0.683444631288446, 0.7526314074248971, 0.9690830317597784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.0949885500996571], {
             RGBColor[
             0.3734749491975743, 0.4979069624233562, 0.945018471405307]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.0949885500996571], {
             RGBColor[
             0.32549096090980034`, 0.45634564351386236`, 0.9419609741021849]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.0949885500996571], {
             RGBColor[
             0.5915316507940261, 0.6792710681686025, 0.9609866848837908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.0949885500996571], {
             RGBColor[
             0.708260064256895, 0.7720174122641253, 0.9715564022046675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.0949885500996571], {
             RGBColor[
             0.5019033623872169, 0.6065067859315755, 0.9539308177011683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.0949885500996571], {
             RGBColor[
             0.3486897411046127, 0.4764392609140132, 0.9434391798623225]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.0949885500996571], {
             RGBColor[
             0.2710493679441486, 0.4022204496047819, 0.9387472325715889]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.0949885500996571], {
             RGBColor[
             0.9311309905212746, 0.9479225932369786, 0.9932932991780089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.0949885500996571], {
             RGBColor[
             0.36193961040797706`, 0.48791563174679253`, 0.9442834498179336]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.0949885500996571], {
             RGBColor[
             0.7386159183850431, 0.795731636222071, 0.974581990052576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.0949885500996571], {
             RGBColor[
             0.8897006872285947, 0.9148871939870197, 0.9893416398646848]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.0949885500996571], {
             RGBColor[
             0.38779070129509796`, 0.5103065473596095, 0.9459306584700388]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.0949885500996571], {
             RGBColor[
             0.8605404245232352, 0.4596284640189423, 0.2053438505662323]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.0949885500996571], {
             RGBColor[
             0.987937481383424, 0.9892798528065269, 0.8495706804815597]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.0949885500996571], {
             RGBColor[
             0.5522626630322495, 0.6473907348558535, 0.9578952863201419]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.0949885500996571], {
             RGBColor[
             0.3781902953528615, 0.5019911582628771, 0.9453189290927051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.0949885500996571], {
             RGBColor[
             0.3814155119874918, 0.5047846788076924, 0.9455244370447167]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.0949885500996571], {
             RGBColor[
             0.254074145261475, 0.3843784142740102, 0.9377805187524021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.0949885500996571], {
             RGBColor[
             0.356813033350702, 0.4834752483690359, 0.943956788861098]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.0949885500996571], {
             RGBColor[
             0.7760599937011822, 0.8249832324445514, 0.9783140655453102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.0949885500996571], {
             RGBColor[
             0.24091959553492592`, 0.3705521484647823, 0.9370313866058875]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.0949885500996571], {
             RGBColor[
             0.5547788487969316, 0.6494334878124994, 0.9580933696806297]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.0949885500996571], {
             RGBColor[
             0.40957606763179255`, 0.5291759367161047, 0.9473188027489698]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.0949885500996571], {
             RGBColor[
             0.4215719209830879, 0.5395661419598764, 0.9480831679169978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.0949885500996571], {
             RGBColor[
             0.868182430036507, 0.8977291197995801, 0.9872892092841284]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.0949885500996571], {
             RGBColor[
             0.329554468570859, 0.45986524961203784`, 0.9422198972171288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.0949885500996571], {
             RGBColor[
             0.3095291023976604, 0.44252028393698245`, 0.9409438985923086]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.0949885500996571], {
             RGBColor[
             0.5060471285935946, 0.6098708820124531, 0.9542570301560501]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.0949885500996571], {
             RGBColor[
             0.45179637309345055`, 0.5657450432527389, 0.9500090432790366]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.0949885500996571], {
             RGBColor[
             0.23795798117184772`, 0.367439303991991, 0.936862727049226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.0949885500996571], {
             RGBColor[
             0.9647014240086329, 0.9731949603385276, 0.9446354611970255]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.0949885500996571], {
             RGBColor[
             0.35444095626616484`, 0.48142067442247066`, 0.9438056422068167]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.0949885500996571], {
             RGBColor[
             0.25754278755946713`, 0.3880241772538239, 0.9379780527998763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.0949885500996571], {
             RGBColor[
             0.39699272207705016`, 0.518276875253924, 0.9465170030972373]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.0949885500996571], {
             RGBColor[
             0.48271564166094943`, 0.5909293298490234, 0.9524202900386596]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.0949885500996571], {
             RGBColor[
             0.9880586185208323, 0.9893299461259276, 0.8475631246218412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.0949885500996571], {
             RGBColor[
             0.5464533476634048, 0.6426744709327503, 0.957437955734083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.0949885500996571], {
             RGBColor[
             0.3638355126899981, 0.4895577670126598, 0.9444042550348634]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.0949885500996571], {
             RGBColor[
             0.30234840405607316`, 0.4351177210319219, 0.9405296663753884]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.0949885500996571], {
             RGBColor[
             0.3098439674360884, 0.44279300420769185`, 0.9409639615141331]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.0949885500996571], {
             RGBColor[
             0.9617959118774524, 0.9710280341484328, 0.949553735356184]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.0949885500996571], {
             RGBColor[
             0.562075777634613, 0.6553574633658271, 0.9586678106482631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.0949885500996571], {
             RGBColor[
             0.3779687218185608, 0.5017992424040755, 0.9453048106230293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.0949885500996571], {
             RGBColor[
             0.3366065382652643, 0.4659733979340029, 0.942669248862156]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.0949885500996571], {
             RGBColor[
             0.47588016261163524`, 0.5853799800219681, 0.9518821760887128]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.0949885500996571], {
             RGBColor[
             0.9097997953709828, 0.9309136772440032, 0.9912587107419913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.0949885500996571], {
             RGBColor[
             0.32336819928995886`, 0.4545070140918569, 0.941825713608853]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.0949885500996571], {
             RGBColor[
             0.5597309068748542, 0.653453791647831, 0.9584832138325102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.0949885500996571], {
             RGBColor[
             0.4026120746537408, 0.5231440760189807, 0.9468750632744256]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.0949885500996571], {
             RGBColor[
             0.343603248128129, 0.4720335963523534, 0.9431150730276702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.0949885500996571], {
             RGBColor[
             0.5068608238375729, 0.6105314764680677, 0.95432108722632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.0949885500996571], {
             RGBColor[
             0.39769750853069497`, 0.518887325856474, 0.9465619114668453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.0949885500996571], {
             RGBColor[
             0.32035753226273406`, 0.4518993256333994, 0.9416338765681066]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.0949885500996571], {
             RGBColor[
             0.38404443010908984`, 0.5070617155513539, 0.9456919493827639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.0949885500996571], {
             RGBColor[
             0.8098984813495572, 0.8514181161774933, 0.9816867697554542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.0949885500996571], {
             RGBColor[
             0.4063748477237047, 0.5264032009297099, 0.9471148238471542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.0949885500996571], {
             RGBColor[
             0.3258798817492446, 0.45668250719725917`, 0.9419857557941651]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.0949885500996571], {
             RGBColor[
             0.34943027455346376`, 0.47708067376711455`, 0.9434863659988553]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.0949885500996571], {
             RGBColor[
             0.6443377928350783, 0.7220808480021458, 0.9651852275769301]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.0949885500996571], {
             RGBColor[
             0.9932013423498908, 0.9878666836731741, 0.5013862551161965]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.0949885500996571], {
             RGBColor[
             0.41198238736370685`, 0.5312601699227426, 0.9474721313144625]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.0949885500996571], {
             RGBColor[
             0.24208487204598406`, 0.3717769279607025, 0.9370977473793202]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.0949885500996571], {
             RGBColor[
             0.32128347446455807`, 0.4527013302294111, 0.9416928767864283]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.0949885500996571], {
             RGBColor[
             0.3329426076355145, 0.46279988537702155`, 0.942435786442315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.0949885500996571], {
             RGBColor[
             0.5146865722695245, 0.6168847715910752, 0.9549371588095443]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.0949885500996571], {
             RGBColor[
             0.26564416024036586`, 0.3965392335981439, 0.9384394139891467]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.0949885500996571], {
             RGBColor[
             0.5597309068748542, 0.653453791647831, 0.9584832138325102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.0949885500996571], {
             RGBColor[
             0.26830283208043837`, 0.3993336662715909, 0.9385908214172862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.0949885500996571], {
             RGBColor[
             0.2939805151653032, 0.4263225392529236, 0.9400531274822413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.0949885500996571], {
             RGBColor[
             0.303484980188015, 0.4363123346096817, 0.9405943927046888]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.0949885500996571], {
             RGBColor[
             0.8291139048769328, 0.8665769383242002, 0.9835628184775241]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.0949885500996571], {
             RGBColor[
             0.35114533921345964`, 0.47856617657394673`, 0.9435956484024182]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.0949885500996571], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.0949885500996571], {
             RGBColor[
             0.9948179828285083, 0.9913245141895117, 0.6773475944651667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.0949885500996571], {
             RGBColor[
             0.6029745574662078, 0.6885609353021505, 0.9618875124137732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.0949885500996571], {
             RGBColor[
             0.4887148098793123, 0.5957997248681388, 0.9528925665364864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.0949885500996571], {
             RGBColor[
             0.34641196946842284`, 0.47446636960687666`, 0.9432940422678189]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.0949885500996571], {
             RGBColor[
             0.6633884883517718, 0.7369633961304352, 0.9670840228671627]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.0949885500996571], {
             RGBColor[
             0.3258798817492446, 0.45668250719725917`, 0.9419857557941651]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.0949885500996571], {
             RGBColor[
             0.3244501390099797, 0.45544413589746746`, 0.9418946538510911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.0949885500996571], {
             RGBColor[
             0.23880289880042005`, 0.36832736599049226`, 0.9369108438582296]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.0949885500996571], {
             RGBColor[
             0.5276986146085718, 0.6274485337477411, 0.9559615144471557]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.0949885500996571], {
             RGBColor[
             0.8448774034080176, 0.8791463241641184, 0.9850663550396603]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.0949885500996571], {
             RGBColor[
             0.3081711467371634, 0.4412377927729567, 0.9408612629571007]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.0949885500996571], {
             RGBColor[
             0.7863855635318066, 0.8330496460734724, 0.9793432218480906]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.0949885500996571], {
             RGBColor[
             0.3539923776544341, 0.48103213817520607`, 0.9437770591743397]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.0949885500996571], {
             RGBColor[
             0.34739152723584266`, 0.4753148133110108, 0.9433564588225699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.0949885500996571], {
             RGBColor[
             0.9915341008130045, 0.9907671473695616, 0.7899653887806946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.0949885500996571], {
             RGBColor[
             0.3492514072525776, 0.4769257479012189, 0.9434749687326089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.0949885500996571], {
             RGBColor[
             0.32549096090980034`, 0.45634564351386236`, 0.9419609741021849]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.0949885500996571], {
             RGBColor[
             0.9932228695765069, 0.9879127282341693, 0.5037293608827064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.0949885500996571], {
             RGBColor[
             0.7873047672147241, 0.8337677349767743, 0.979434839480757]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.0949885500996571], {
             RGBColor[
             0.9460918671997839, 0.9593159833408407, 0.9761365867246516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.0949885500996571], {
             RGBColor[
             0.4887148098793123, 0.5957997248681388, 0.9528925665364864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.0949885500996571], {
             RGBColor[
             0.31835070411709293`, 0.4501611119597605, 0.9415060032532347]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.0949885500996571], {
             RGBColor[
             0.9757523576177134, 0.9814367285299368, 0.9259291131419458]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.0949885500996571], {
             RGBColor[
             0.38954406419544346`, 0.511825222177307, 0.9460423812036108]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.0949885500996571], {
             RGBColor[
             0.3555991770100271, 0.4824238670169369, 0.9438794430084413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.0949885500996571], {
             RGBColor[
             0.23924047278419946`, 0.3687872839912374, 0.9369357630492732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.0949885500996571], {
             RGBColor[
             0.2542749778158753, 0.38458950202220443`, 0.93779195586927]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.0949885500996571], {
             RGBColor[
             0.7033181749555993, 0.7681567707822033, 0.9710638408636956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.0949885500996571], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.0949885500996571], {
             RGBColor[
             0.2838303131380794, 0.41565403336233264`, 0.9394750884926693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.0949885500996571], {
             RGBColor[
             0.9478080717933919, 0.8307834271295299, 0.2768633533441958]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.0949885500996571], {
             RGBColor[
             0.2767022499414459, 0.408161986997361, 0.9390691558386455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.0949885500996571], {
             RGBColor[
             0.4460761769504371, 0.5607904968590783, 0.9496445574389746]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.0949885500996571], {
             RGBColor[
             0.3680837347095421, 0.4932373634041417, 0.9446749479853934]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.0949885500996571], {
             RGBColor[
             0.5856258837582973, 0.6744765004372247, 0.9605217612692007]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.0949885500996571], {
             RGBColor[
             0.9647014240086329, 0.9731949603385276, 0.9446354611970255]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.0949885500996571], {
             RGBColor[
             0.40062685793987546`, 0.5214245810813238, 0.9467485670208763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.0949885500996571], {
             RGBColor[
             0.3880967159817098, 0.5105716019004073, 0.9459501574552716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.0949885500996571], {
             RGBColor[
             0.4119553647190603, 0.5312367642661473, 0.9474704094554408]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.0949885500996571], {
             RGBColor[
             0.378004193520771, 0.5018299662096704, 0.9453070708485277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.0949885500996571], {
             RGBColor[
             0.5148835116471553, 0.6170446558498538, 0.9549526625987641]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.0949885500996571], {
             RGBColor[
             0.4503331726504298, 0.564477692571587, 0.9499158094406646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.0949885500996571], {
             RGBColor[
             0.34943027455346376`, 0.47708067376711455`, 0.9434863659988553]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.0949885500996571], {
             RGBColor[
             0.8900404976029253, 0.9151581495556039, 0.9893740512815408]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.0949885500996571], {
             RGBColor[
             0.46588613536992546`, 0.5772663784813516, 0.9510954096549173]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.0949885500996571], {
             RGBColor[
             0.46682593237298575`, 0.5780293480258085, 0.9511693939175881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.0949885500996571], {
             RGBColor[
             0.2941260636044939, 0.42647551989081706`, 0.9400614162505336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.0949885500996571], {
             RGBColor[
             0.3096653213011958, 0.44263826990466365`, 0.9409525783403883]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.0949885500996571], {
             RGBColor[
             0.9717578770346552, 0.9163948290513829, 0.3447851146673876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.0949885500996571], {
             RGBColor[
             0.29777156234186813`, 0.43030717020176723`, 0.940269022010595]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.0949885500996571], {
             RGBColor[
             0.2549663034666041, 0.3853161291136983, 0.9378313258423544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.0949885500996571], {
             RGBColor[
             0.664971633699712, 0.7382001613085964, 0.9672418160001108]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.0949885500996571], {
             RGBColor[
             0.7010415910713886, 0.7663782861491797, 0.9708369322580034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.0949885500996571], {
             RGBColor[
             0.22108698462417198`, 0.3497068169374207, 0.9359019487542386]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.0949885500996571], {
             RGBColor[
             0.9248445231387965, 0.9429099347878017, 0.9926936903070726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.0949885500996571], {
             RGBColor[
             0.5992126340210362, 0.6855068363766404, 0.9615913600197896]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.0949885500996571], {
             RGBColor[
             0.3492514072525776, 0.4769257479012189, 0.9434749687326089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.0949885500996571], {
             RGBColor[
             0.5079249312768915, 0.6113953668248004, 0.9544048576618972]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.0949885500996571], {
             RGBColor[
             0.4060801740485782, 0.5261479694030449, 0.9470960475011447]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.0949885500996571], {
             RGBColor[
             0.35159838194956944`, 0.47895857942137504`, 0.9436245158849531]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.0949885500996571], {
             RGBColor[
             0.41588961887805015`, 0.5346444174773007, 0.9477210966515273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.0949885500996571], {
             RGBColor[
             0.2914280604636203, 0.42363974752647965`, 0.9399077689629989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.0949885500996571], {
             RGBColor[
             0.2877954223349315, 0.4198216145306676, 0.9397008955955766]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.0949885500996571], {
             RGBColor[
             0.2767022499414459, 0.408161986997361, 0.9390691558386455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.0949885500996571], {
             RGBColor[
             0.9283091515910091, 0.7534767061570558, 0.26117406445087615`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.0949885500996571], {
             RGBColor[
             0.5478948359779737, 0.643844736084826, 0.9575514349745515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.0949885500996571], {
             RGBColor[
             0.3329426076355145, 0.46279988537702155`, 0.942435786442315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.0949885500996571], {
             RGBColor[
             0.3058708726711128, 0.4388200588837381, 0.9407302657519896]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.0949885500996571], {
             RGBColor[
             0.48495849262189045`, 0.5927501772983996, 0.9525968554821387]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.0949885500996571], {
             RGBColor[
             0.684098996859768, 0.7531426027825764, 0.9691482528045339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.0949885500996571], {
             RGBColor[
             0.40938009809493964`, 0.5290061977529981, 0.9473063157433707]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.0949885500996571], {
             RGBColor[
             0.6712735641690258, 0.7431232772876699, 0.9678699335344035]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.0949885500996571], {
             RGBColor[
             0.2418595837759338, 0.37154013570477834`, 0.937084917545625]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.0949885500996571], {
             RGBColor[
             0.4446556876330299, 0.5595601404082092, 0.9495540451157587]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.0949885500996571], {
             RGBColor[
             0.3734749491975743, 0.4979069624233562, 0.945018471405307]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.0949885500996571], {
             RGBColor[
             0.8133645289877482, 0.8541258189353859, 0.9820322329919724]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.0949885500996571], {
             RGBColor[
             0.3166815040373448, 0.44871533474711806`, 0.9413996433001689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.0949885500996571], {
             RGBColor[
             0.2960053756864465, 0.4284507960442174, 0.9401684402934077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.0949885500996571], {
             RGBColor[
             0.8151782885988568, 0.8555427417286675, 0.9822130115994605]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.0949885500996571], {
             RGBColor[
             0.7644633907023277, 0.8159238780443991, 0.977158224534801]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.0949885500996571], {
             RGBColor[
             0.5432719480532819, 0.6400916674088335, 0.9571875043029234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.0949885500996571], {
             RGBColor[
             0.3530564621135596, 0.48022149517418344`, 0.9437174234636728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.0949885500996571], {
             RGBColor[
             0.3367122208133204, 0.4660649348453697, 0.9426759828606667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.0949885500996571], {
             RGBColor[
             0.45179637309345055`, 0.5657450432527389, 0.9500090432790366]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.0949885500996571], {
             RGBColor[
             0.5332585562685747, 0.6319623448598489, 0.9563992134213685]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.0949885500996571], {
             RGBColor[
             0.26564416024036586`, 0.3965392335981439, 0.9384394139891467]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.0949885500996571], {
             RGBColor[
             0.3825237812089536, 0.5057446059040919, 0.9455950549795042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.0949885500996571], {
             RGBColor[
             0.7624854576334931, 0.8143787016981774, 0.9769610826513349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.0949885500996571], {
             RGBColor[
             0.38404443010908984`, 0.5070617155513539, 0.9456919493827639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.0949885500996571], {
             RGBColor[
             0.46813026421017623`, 0.5790882633707194, 0.9512720756977368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.0949885500996571], {
             RGBColor[
             0.8430045544960191, 0.8776529652788202, 0.984887721038522]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.0949885500996571], {
             RGBColor[
             0.5575189611000579, 0.6516580344208298, 0.958309081358494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.0949885500996571], {
             RGBColor[
             0.38737991617357126`, 0.5099507459340036, 0.9459044836053381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.0949885500996571], {
             RGBColor[
             0.9647390529740835, 0.892718687396814, 0.31751830858577246`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.0949885500996571], {
             RGBColor[
             0.37482035966154165`, 0.49907228934494857`, 0.9451041997703713]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.0949885500996571], {
             RGBColor[
             0.6712735641690258, 0.7431232772876699, 0.9678699335344035]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.0949885500996571], {
             RGBColor[
             0.41379324701840414`, 0.5328286455391887, 0.9475875176903794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.0949885500996571], {
             RGBColor[
             0.7052984546328854, 0.7697037803167823, 0.9712612166351617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.0949885500996571], {
             RGBColor[
             0.40706190135834586`, 0.5269982922557164, 0.9471586022972158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.0949885500996571], {
             RGBColor[
             0.3434593033569558, 0.47190891862643775`, 0.9431059009941364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.0949885500996571], {
             RGBColor[
             0.3838246488361832, 0.5068713520592901, 0.9456779451143992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.0949885500996571], {
             RGBColor[
             0.5130092042764093, 0.6155230086896974, 0.9548051102567249]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.0949885500996571], {
             RGBColor[
             0.2244011160398623, 0.35319017918337936`, 0.9360906836355442]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.0949885500996571], {
             RGBColor[
             0.2107130155740168, 0.33880311771808014`, 0.9353111665637442]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.0949885500996571], {
             RGBColor[
             0.37927169578795095`, 0.5029278129669853, 0.9453878349721841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.0949885500996571], {
             RGBColor[
             0.7483526224375829, 0.8033380234296066, 0.9755524537178605]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.0949885500996571], {
             RGBColor[
             0.5187876536771853, 0.6202142142294262, 0.9552600109607116]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.0949885500996571], {
             RGBColor[
             0.38601275665963014`, 0.508766581078463, 0.9458173694100415]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.0949885500996571], {
             RGBColor[
             0.7260864812277231, 0.7859435446875233, 0.9733331728509816]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.0949885500996571], {
             RGBColor[
             0.378004193520771, 0.5018299662096704, 0.9453070708485277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.0949885500996571], {
             RGBColor[
             0.6248362554600455, 0.7063092465918193, 0.9636085453618866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.0949885500996571], {
             RGBColor[
             0.3807087779326326, 0.5041725412908598, 0.9454794045756814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.0949885500996571], {
             RGBColor[
             0.5972127279189494, 0.6838832225082231, 0.961433920085536]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.0949885500996571], {
             RGBColor[
             0.7487873377153662, 0.8036776263085694, 0.9755957820741047]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.0949885500996571], {
             RGBColor[
             0.5973768856862216, 0.6840164931789178, 0.9614468431863054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.0949885500996571], {
             RGBColor[
             0.4484990824671766, 0.562889095838906, 0.94979894283601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.0949885500996571], {
             RGBColor[
             0.28259747639759025`, 0.4143582437817145, 0.9394048802641168]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.0949885500996571], {
             RGBColor[
             0.40706190135834586`, 0.5269982922557164, 0.9471586022972158]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
          103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
          129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 
          142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 
          155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 
          168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 
          181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 
          194, 195, 196, 197, 198, 199, 200}, {Null, CompressedData["
1:eJwVxfk/GgwDAPA5ylXk6qBcTS9j5XjImZDN1UpNhz0LEUrEK0VRaK6QloU8
tcqVhcoRUpIjPX/W+3m/v3yzuSIaN/zdu3f/Rr579/9hmzOh+9CM1RqacVqd
ztDnw5llwRhsb3OPIwbOAK1AJ/AeGAo/BK7OrK5aV52r96uh7eeGjs8dHYcd
58D4+HuAADAGKy7eLN6bPA+/+3zXcXd4F56XN5l3jpls6Go46Tg5OT+5w+gm
dbpnzNTk1NTJ1PmXb7wZ3jJvlWflOXkh/wuQCCMS94hWohPNQYvRarV504w2
cAxiwwcDZyLdn/6iN+v9+peqCcCD4GFyZ3sHTSKpSVu6ra1nQF3dtzpB3Rhx
FNZd3P2l+1t392b3XmVD5efKjsouvd1st/vtL+HUPCq1gzpJnaKeUM+pd3gS
vhm/hb9B43AcnBhnCP+T9wc2WDzYPTi4ObgHmy+e754fnJ/fnLd/nPp48vH8
P/+t+juyIZIa2RF5EnkeeYdrqWpp4bRMtBgwRpJRbdQZt4yZmMy8TGrmZOZU
pi5zJ/OcJ5cvyJdr5DULfy01L6E1OA1Jw9GINWqNxoD24Xwcn9in8Rl8gPW6
dcH62Hp9Q31X/WhsfOw92oFzcBxih8ZhcDh8aBvOxrGJbWqbxmaw2XwwYbGQ
KBwUCkeFe+HHecfU447jw+PjOzyBQCKICQ7CTQ2NSKPxaKM0OW0hvLT0c+lh
6XHpHdBL8/K8cu+Md9m76rV6nV5viK1m69lmtj2LlsXLkmctZC1neWH7xfvE
/fr9wX3h/ug+oCi2KL6oqK5IUDRWtJ5Rn9GQ0ZUxmrEfefbxrOGMetZxNnV2
cnZ2nlyT3JW8AGQQGTQGg8cQMkYZMwwrw8nwMkJoGUnGlsnUMo3MIDPLbDJf
1T9//0Nsqm9qojUxmrqaRpvkf/5Fe/AegofkUXs0ni2P0cOWSNQSvcQssUv8
khecgqDgKMQKhUbhUNx8WWGvfFuRraxsrph/bP/YSS4pqSmhlchLFjKxGGwe
FjuJ1WF32EFJcD64EtwM6oPmoD34Esy8xFxiL3WXW5fGS2B1bHV8dVF19V71
PVsr0cq0aq1WrzVr7Vq/NohvJ7S3i9sV7Y72GxizmElk1jOZ3cxBppA5ytxk
7jH3kwsLSworC2sKuwApKYKUh8j8jPz8yvyG/I78rvyT/LP8u6xfy7/e/3i/
8/7P+38zronX9ddN17RrxjXzWng9er1/nXmKOc07xZ5Onk6d6k53Tk/PTy/R
IpwILyKISKJ2EUckEosUIo3IJnKIPCJfBCAiNiIloiiiLkIQcR/xkMnFcLFc
7iR3iqvjGrmn3Escn8Bv53P4fBFfzFfwNXwH/yZ5I3+jcKNyo2GjayN8OnM6
bxo7TZ3mTk9OT+9Mn0a+Zbzlv1W+1b81vHW8db1tvJ28nb1hAuyAJCALqAPa
gD5gDPgDf/1c+plVVlJWJi9bKFsu+4Vfa15bWlv7uXaT+j4Vm/ojdTt1J/UZ
28ft69P1bfUZ+y77ntEWnKXFwrHwLSLLhEVsUVg0FoPFYrM4LL4IJAAZi0xB
IouQdUgBcgy5jnwAgkDxIBioGkQEMUBMUDdICNoDWUFONOsDC8dicVgy1gpL
wzKwbCxf6mvma94r9pX7Ovk6/ap73Xk9fcVcka64V31XuqutK+PV5dWV5+oZ
ioGyoRKoDKqGaqF6qB8agDWmNxY3NjIbBxvnGzcb99EmnAlvIphIJr5JZBKb
FCaNyWgyOUweXG1VbW1LLaeWXztRK6611DqSc3IKc0pyanK6chbSKyokFfMV
+gp7hb/ipSIIhIAgECKEAeFBZiCrECvECfFCQvg2QltzW1t721LbWtsNrKCg
uKCxgFnQXTBYMF+wWbBXEIwgA8ix5BQyklxEriOTBeQx8jr5IX22YlYyO6uf
tc/6Z1+glAoKhU2RUGYpWoqeYqbYKX5KgPJCCULn0ucwcx/nKHOSuam52bk5
/1xg7iVnqGSobKhmaEg+tBCelpaXVppGTZtOO0w7TvuTdod/JDw2P7Y9tj8q
Hpce1x5vHvE9hJ62nvaeHn6PqEfco+gx9Th6bnoeUWgUDsVCsVEy1ApKjdKg
tCgDyoyyoXwgBAyBKEAUI4iIRgQT0Y0YRAgR84hNxB5iHz9MGCYN9w0Pi4Y1
w1vDxmHT8NWwB+pGudFuknvYLXLL3Gq3xq11G90mt83t9rh97kDqCHakb2Tk
x4huZHtkZ+R55BX4FPsEeop/gjwVPVU/WZ/un55CgJiYlBhkTF0MOUYQMxaz
HvMQhgr7EsYKY4fJwlbC1GHaMHOYLSwIUWYpicomJU3JUPKUo0q5ckapXFZa
lU7ltdKbvliwWLxYv9i4OLg4v7i4n3yRc1F4UXJRc9F0QbvoupBfKC8WLoB0
CD2LTmfQefQZ+jJ9lW6lO+leeigiDhAXExeXEoeMK4qriyPHCeLG4tbjHpq/
fl37+gwYiBn4MFA3QB5gDQwIBsYG1lM7sZ2dfZ0jnT86dZ3bnTudz52vUGm6
tEJKkUqk0lnpnFQr1Uv90oD0Jab3Q+/fvb0DvWO9673/4MrLq8pry1vKOeX8
8olycbmi3FLugKkQqgJVsape1ahiqrpVgyqhal6lWlRtqvZU+6rraHw0IZoU
3RbdE90XPRy9FW2MNkVfRXuin7P6S/rL+vuH+uX9C/3L/b+ScEnlSVVJtUkt
SZykiSRxkiHJkuRI8gHBIDAYAiaCm8A0MB3MAPPAQvAoeAasBK+CrWAn2AsO
hf9O+136+7+/fx/+PobC4enwCjgFzoZL4FL4LFwL18PtcD/8BR6E3mJuubfS
26nbuVvdrfH29Pby9ur2NhDemtaa11ra2kpt/d162Hrc+qf17q9Pn5o/LX1a
+/QzIgGQEJsQlxCfkIBMKEqoTqhLICcIEsYS1hOekrOz87MLsyuzG7K7sjey
36C58Nz03NyKXEquJFeaO5s7l6vPtef6c1+ALrAL4spyEV00F93FcPFcMy6l
a9m16rK6nC6X1xX69L35+9fv35e+r33/mXWQc1ByUHZQc0A76D8YOpAfLBws
HxxchI2jxr+Ms8bZ4+Oy8ZVx9bh23DxuGw9mHZUd0Y/6j3hH8qPlo19HR15A
YkxiXGJiSiIykZwoSBxLXE98aN79utu5O7K7tru1u727+xyVFPUhChdVHlUV
VRvVEsWK4kT1Rk1EGaIsUb7/AWRTyt8=
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[31, 80] -> 
             RGBColor[
              0.7352027165067365, 0.7929678458962808, 0.9744115778147804], 
             UndirectedEdge[36, 132] -> 
             RGBColor[
              0.24999710016017773`, 0.3800931813729572, 0.937548337065331], 
             UndirectedEdge[16, 101] -> 
             RGBColor[
              0.28740281094428266`, 0.4180946549568002, 0.9397266599229551], 
             UndirectedEdge[86, 108] -> 
             RGBColor[
              0.5865960904370586, 0.6714707671165345, 0.9625129589589009], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.3936636675304358, 0.5153934155287933, 0.9463048786852943], 
             UndirectedEdge[29, 136] -> 
             RGBColor[
              0.950824845750427, 0.8323116913697606, 0.49992668872926316`], 
             UndirectedEdge[55, 157] -> 
             RGBColor[
              0.4550334300726567, 0.5657150158349769, 0.9509982940305055], 
             UndirectedEdge[7, 188] -> 
             RGBColor[
              0.5075570604878807, 0.6079623494198335, 0.955381071984007], 
             UndirectedEdge[19, 141] -> 
             RGBColor[
              0.31187008513103276`, 0.44044798095241544`, 0.9412431829967022],
              UndirectedEdge[62, 185] -> 
             RGBColor[
              0.5629039980331934, 0.6514450489037454, 0.9607937355315148], 
             UndirectedEdge[79, 144] -> 
             RGBColor[
              0.6389999811794337, 0.4008456236267517, 0.4461443465462792], 
             UndirectedEdge[47, 54] -> 
             RGBColor[
              0.3621640961349061, 0.48478721437619465`, 0.9444194198717641], 
             UndirectedEdge[32, 101] -> 
             RGBColor[
              0.2434980017964442, 0.3732622169260371, 0.9371782230280707], 
             UndirectedEdge[104, 163] -> 
             RGBColor[
              0.22597848605701326`, 0.35484809508244053`, 0.9361805125245111],
              UndirectedEdge[119, 125] -> 
             RGBColor[
              0.3719190998621983, 0.4815306199533135, 0.9461956553093709], 
             UndirectedEdge[9, 140] -> 
             RGBColor[
              0.2830352445403058, 0.4148183658558119, 0.9394298105122245], 
             UndirectedEdge[3, 63] -> 
             RGBColor[
              0.30825791983475437`, 0.437251051830131, 0.9410155180983026], 
             UndirectedEdge[50, 104] -> 
             RGBColor[
              0.2305835536607953, 0.3596883131121654, 0.9364427643119595], 
             UndirectedEdge[47, 61] -> 
             RGBColor[
              0.36265936899724993`, 0.48530777755663124`, 0.944447624928584], 
             UndirectedEdge[149, 195] -> 
             RGBColor[
              0.2062475040297809, 0.3341095819553035, 0.9350568622874322], 
             UndirectedEdge[99, 178] -> 
             RGBColor[
              0.7532636952500258, 0.8067917718917483, 0.970579392980242], 
             UndirectedEdge[160, 174] -> 
             RGBColor[
              0.37406119352792633`, 0.4984147377968103, 0.9450558263756417], 
             UndirectedEdge[6, 124] -> 
             RGBColor[
              0.3155531459350417, 0.4461023057398271, 0.9413876363800726], 
             UndirectedEdge[24, 197] -> 
             RGBColor[
              0.5339219982745609, 0.6098281505161249, 0.9613839453194717], 
             UndirectedEdge[80, 120] -> 
             RGBColor[
              0.7883329572883422, 0.7840663517109472, 0.6248876395864237], 
             UndirectedEdge[83, 187] -> 
             RGBColor[
              0.26933773838678554`, 0.40042141841641143`, 0.938649757800426], 
             UndirectedEdge[47, 167] -> 
             RGBColor[
              0.6833987505402253, 0.7503936163476059, 0.9708862787627], 
             UndirectedEdge[132, 150] -> 
             RGBColor[
              0.2675705658104447, 0.39856400799346436`, 0.938549119936501], 
             UndirectedEdge[17, 189] -> 
             RGBColor[
              0.23511483918268133`, 0.3644509814957634, 0.9367008143189947], 
             UndirectedEdge[69, 180] -> 
             RGBColor[
              0.5628268850068445, 0.6533109098577117, 0.9599708318719281], 
             UndirectedEdge[43, 95] -> 
             RGBColor[
              0.8967855212794014, 0.5986904854238292, 0.25888435369462925`], 
             UndirectedEdge[82, 86] -> 
             RGBColor[
              0.3552790109161934, 0.48214655523847394`, 0.943859042308054], 
             UndirectedEdge[7, 61] -> 
             RGBColor[
              0.3121285679978709, 0.4415405374828739, 0.9412278469715365], 
             UndirectedEdge[30, 65] -> 
             RGBColor[
              0.9079204151899432, 0.9294151105020584, 0.9910794537825813], 
             UndirectedEdge[62, 174] -> 
             RGBColor[
              0.36882264112374896`, 0.4938773670016114, 0.9447220304487174], 
             UndirectedEdge[18, 47] -> 
             RGBColor[
              0.38494609227374893`, 0.5078426899995235, 0.9457494024985874], 
             UndirectedEdge[56, 149] -> 
             RGBColor[
              0.2062475040297809, 0.3341095819553035, 0.9350568622874322], 
             UndirectedEdge[82, 163] -> 
             RGBColor[
              0.2758102937038249, 0.40631356017084397`, 0.9390517136501494], 
             UndirectedEdge[10, 48] -> 
             RGBColor[
              0.30320935155036544`, 0.43524999752426985`, 0.940606985973867], 
             UndirectedEdge[58, 92] -> 
             RGBColor[
              0.24643437763355744`, 0.3763485341078243, 0.9373454452880156], 
             UndirectedEdge[70, 72] -> 
             RGBColor[
              0.23177582019152226`, 0.36094146083002354`, 0.936510662127084], 
             UndirectedEdge[35, 181] -> 
             RGBColor[
              0.9113516048559902, 0.930874079920538, 0.9469017763992353], 
             UndirectedEdge[126, 174] -> 
             RGBColor[
              0.3443177986809051, 0.472511876251829, 0.9431657526324266], 
             UndirectedEdge[108, 154] -> 
             RGBColor[
              0.8838800631396134, 0.9088604535486795, 0.9258833443185683], 
             UndirectedEdge[63, 77] -> 
             RGBColor[
              0.3266232709961202, 0.4565542003312445, 0.9420613976778401], 
             UndirectedEdge[32, 100] -> 
             RGBColor[
              0.22448297168171977`, 0.35327621465291903`, 0.9360953451932534],
              UndirectedEdge[19, 50] -> 
             RGBColor[
              0.2533169376668154, 0.3835825410822887, 0.9377373969000744], 
             UndirectedEdge[80, 81] -> 
             RGBColor[
              0.5981154418108365, 0.6846160863124545, 0.9615049850298553], 
             UndirectedEdge[34, 163] -> 
             RGBColor[
              0.24238504014097356`, 0.3720924236602928, 0.9371148415082708], 
             UndirectedEdge[146, 194] -> 
             RGBColor[
              0.5723118578420975, 0.6584672801449877, 0.9618699351638069], 
             UndirectedEdge[13, 83] -> 
             RGBColor[
              0.316923827731624, 0.4440344737616491, 0.9415941582521057], 
             UndirectedEdge[30, 41] -> 
             RGBColor[
              0.7217306402299773, 0.781717727178925, 0.9737111260908631], 
             UndirectedEdge[35, 111] -> 
             RGBColor[
              0.6494345587146366, 0.7234252020636741, 0.9675585260086426], 
             UndirectedEdge[29, 144] -> 
             RGBColor[
              0.9022249366155904, 0.6208207570711475, 0.3861737156527596], 
             UndirectedEdge[6, 12] -> 
             RGBColor[
              0.4620072235822212, 0.5710418605945535, 0.9516398014511775], 
             UndirectedEdge[67, 143] -> 
             RGBColor[
              0.8190699438712857, 0.14758552186319893`, 0.16589470582855148`],
              UndirectedEdge[135, 163] -> 
             RGBColor[
              0.2331505740140204, 0.36238641426189583`, 0.9365889523235094], 
             UndirectedEdge[50, 60] -> 
             RGBColor[
              0.24809478057534154`, 0.3780937228752663, 0.9374400027792041], 
             UndirectedEdge[25, 143] -> 
             RGBColor[
              0.8735061292591867, 0.42076748591111013`, 0.23590476193812596`],
              UndirectedEdge[12, 13] -> 
             RGBColor[
              0.4809809724952037, 0.58747596825463, 0.9528487919540853], 
             UndirectedEdge[89, 144] -> 
             RGBColor[
              0.8548334539658015, 0.42247953211969835`, 0.20014188348416714`],
              UndirectedEdge[22, 24] -> 
             RGBColor[
              0.6225902394734423, 0.3300989620118385, 0.4379481515395359], 
             UndirectedEdge[107, 156] -> 
             RGBColor[
              0.7940373920785235, 0.8398425244747729, 0.979889552465069], 
             UndirectedEdge[23, 154] -> 
             RGBColor[
              0.9900533443030074, 0.9886857899175692, 0.707722631591383], 
             UndirectedEdge[101, 135] -> 
             RGBColor[
              0.2425616632808307, 0.3722780657788366, 0.9371248999347952], 
             UndirectedEdge[7, 42] -> 
             RGBColor[
              0.4359507962934013, 0.5501706892115099, 0.9495104580293312], 
             UndirectedEdge[122, 192] -> 
             RGBColor[
              0.8758587759165559, 0.41851937401271744`, 0.2670649130066242], 
             UndirectedEdge[129, 133] -> 
             RGBColor[
              0.8790384594977417, 0.4469900974919443, 0.2522656130299896], 
             UndirectedEdge[40, 80] -> 
             RGBColor[
              0.555739244439546, 0.6502131802605045, 0.9581689755436615], 
             UndirectedEdge[41, 172] -> 
             RGBColor[
              0.7718454040169196, 0.8174234076188627, 0.7717375932565325], 
             UndirectedEdge[94, 115] -> 
             RGBColor[
              0.34184068469654455`, 0.4665135495155001, 0.9431489820897013], 
             UndirectedEdge[87, 103] -> 
             RGBColor[
              0.9055186961480244, 0.6475369650177958, 0.42196747470883456`], 
             UndirectedEdge[142, 160] -> 
             RGBColor[
              0.5038004126414563, 0.6056953348255233, 0.9547299040233275], 
             UndirectedEdge[21, 150] -> 
             RGBColor[
              0.29956418872733326`, 0.4315020124177601, 0.9403963488781741], 
             UndirectedEdge[29, 142] -> 
             RGBColor[
              0.8172660326623933, 0.855490432397475, 0.8599437218958297], 
             UndirectedEdge[67, 103] -> 
             RGBColor[
              0.833567382441636, 0.252847633383231, 0.17953580679306383`], 
             UndirectedEdge[50, 163] -> 
             RGBColor[
              0.23762722721084206`, 0.36709166060796167`, 0.9368438911004533],
              UndirectedEdge[21, 46] -> 
             RGBColor[
              0.4569720284859443, 0.5663064733841641, 0.9514223432183879], 
             UndirectedEdge[43, 129] -> 
             RGBColor[
              0.9003301475995195, 0.6106473423194261, 0.27265455760177426`], 
             UndirectedEdge[11, 112] -> 
             RGBColor[
              0.2736557868068433, 0.4049599610859747, 0.9388956642699682], 
             UndirectedEdge[119, 195] -> 
             RGBColor[
              0.37190268566599016`, 0.4815133675923786, 0.9461947205451795], 
             UndirectedEdge[99, 109] -> 
             RGBColor[
              0.45081925257627997`, 0.561890841684138, 0.9507778651594582], 
             UndirectedEdge[45, 120] -> 
             RGBColor[
              0.9205644172331103, 0.7168104234407002, 0.25588752113131463`], 
             UndirectedEdge[29, 153] -> 
             RGBColor[
              0.7898065464682866, 0.8331975844693433, 0.8577820105552174], 
             UndirectedEdge[27, 125] -> 
             RGBColor[
              0.22785442897304503`, 0.35681983002884055`, 0.9362873446983702],
              UndirectedEdge[35, 157] -> 
             RGBColor[
              0.6980290555794366, 0.7628764037756551, 0.971384062809347], 
             UndirectedEdge[28, 112] -> 
             RGBColor[
              0.2981130439403854, 0.43066608901299275`, 0.9402884688824538], 
             UndirectedEdge[22, 89] -> 
             RGBColor[
              0.84761198290322, 0.36697214106389997`, 0.19322659463915418`], 
             UndirectedEdge[96, 116] -> 
             RGBColor[
              0.3478897367236583, 0.4755106363355533, 0.9433968344585502], 
             UndirectedEdge[23, 143] -> 
             RGBColor[
              0.8783920111917808, 0.4368059364020854, 0.2925360104669875], 
             UndirectedEdge[6, 14] -> 
             RGBColor[
              0.37841229319367853`, 0.5021834416346569, 0.945333074598817], 
             UndirectedEdge[9, 112] -> 
             RGBColor[
              0.28100806217130603`, 0.41268766865520734`, 0.9393143654752576],
              UndirectedEdge[12, 25] -> 
             RGBColor[
              0.7814420691727634, 0.8068428114651084, 0.666502637240134], 
             UndirectedEdge[176, 199] -> 
             RGBColor[
              0.28324272218403285`, 0.4150364380142114, 0.9394416260570992], 
             UndirectedEdge[48, 112] -> 
             RGBColor[
              0.3092759955003079, 0.44162642496310195`, 0.9409524723720207], 
             UndirectedEdge[79, 149] -> 
             RGBColor[
              0.21876808015896437`, 0.34726950131745254`, 0.9357698905754568],
              UndirectedEdge[58, 155] -> 
             RGBColor[
              0.25688825427596124`, 0.3873362212730521, 0.9379407780976758], 
             UndirectedEdge[118, 138] -> 
             RGBColor[
              0.9130416014388392, 0.812801149295034, 0.6201343733156849], 
             UndirectedEdge[172, 173] -> 
             RGBColor[
              0.9945590642006376, 0.9907707134251852, 0.6491658996819889], 
             UndirectedEdge[53, 104] -> 
             RGBColor[
              0.21517354122831484`, 0.34349141299440844`, 0.9355651869010002],
              UndirectedEdge[179, 185] -> 
             RGBColor[
              0.7887535289716312, 0.8348995186722672, 0.9795792385132371], 
             UndirectedEdge[82, 176] -> 
             RGBColor[
              0.30639768237766407`, 0.4384628450195025, 0.9407936201851381], 
             UndirectedEdge[142, 181] -> 
             RGBColor[
              0.8126094756619291, 0.8535648264097266, 0.9371149221767408], 
             UndirectedEdge[54, 160] -> 
             RGBColor[
              0.3197591214680627, 0.448058156655773, 0.9417174123832397], 
             UndirectedEdge[121, 151] -> 
             RGBColor[
              0.4472759744708069, 0.5594034354051198, 0.9503913919352824], 
             UndirectedEdge[138, 144] -> 
             RGBColor[
              0.8752691557383894, 0.5209048945205916, 0.21739381612783068`], 
             UndirectedEdge[171, 196] -> 
             RGBColor[
              0.6848218020180831, 0.7518929600057571, 0.9706449762400708], 
             UndirectedEdge[120, 172] -> 
             RGBColor[
              0.9753727800277856, 0.9276792174007213, 0.4361680487899127], 
             UndirectedEdge[113, 159] -> 
             RGBColor[
              0.8485303397063004, 0.33009952954163524`, 0.19238576661614035`],
              UndirectedEdge[103, 108] -> 
             RGBColor[
              0.8366047008902185, 0.5941132685295566, 0.465258687547469], 
             UndirectedEdge[64, 176] -> 
             RGBColor[
              0.45839978276888355`, 0.5655229499724335, 0.9517490792275327], 
             UndirectedEdge[83, 101] -> 
             RGBColor[
              0.2538463417938609, 0.3841389783859738, 0.9377675456819266], 
             UndirectedEdge[15, 63] -> 
             RGBColor[
              0.33898161598962545`, 0.46803057088396705`, 0.9428205867145535],
              UndirectedEdge[55, 72] -> 
             RGBColor[
              0.3011292819316679, 0.4298018950317811, 0.9406079602011264], 
             UndirectedEdge[105, 142] -> 
             RGBColor[
              0.4920496854617956, 0.5955174455512221, 0.9539811580781995], 
             UndirectedEdge[96, 105] -> 
             RGBColor[
              0.32470350781154744`, 0.4554278902256328, 0.9419194284550477], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.3349775869314745, 0.46456248216214874`, 0.942565453523592], 
             UndirectedEdge[64, 108] -> 
             RGBColor[
              0.7019176077126746, 0.7667599945944428, 0.9711311636805353], 
             UndirectedEdge[56, 119] -> 
             RGBColor[
              0.37190268566599016`, 0.4815133675923786, 0.9461947205451795], 
             UndirectedEdge[68, 157] -> 
             RGBColor[
              0.7066548099945791, 0.7697543462064234, 0.9722067949657651], 
             UndirectedEdge[137, 161] -> 
             RGBColor[
              0.2794230248160247, 0.4110216938976339, 0.939224099942727], 
             UndirectedEdge[160, 188] -> 
             RGBColor[
              0.5156828868204164, 0.6150005317731692, 0.9558988424525301], 
             UndirectedEdge[127, 187] -> 
             RGBColor[
              0.3022073859943112, 0.43378220468743567`, 0.9405651083800737], 
             UndirectedEdge[41, 141] -> 
             RGBColor[
              0.4545263425380657, 0.5654922255819677, 0.9509061844081543], 
             UndirectedEdge[137, 175] -> 
             RGBColor[
              0.2852924893069724, 0.4161135758232565, 0.9395978023974743], 
             UndirectedEdge[1, 122] -> 
             RGBColor[
              0.9756254576616791, 0.9291724163168037, 0.38265572153063876`], 
             UndirectedEdge[60, 177] -> 
             RGBColor[
              0.273782020378095, 0.40509264057303096`, 0.9389028530851051], 
             UndirectedEdge[72, 75] -> 
             RGBColor[
              0.26701897159742227`, 0.39798424750248473`, 0.9385177074620799],
              UndirectedEdge[13, 69] -> 
             RGBColor[
              0.38979245396039097`, 0.512040364907272, 0.9460582083797908], 
             UndirectedEdge[48, 77] -> 
             RGBColor[
              0.30874838296909257`, 0.4410718707402281, 0.9409224256189008], 
             UndirectedEdge[22, 183] -> 
             RGBColor[
              0.8495847316428689, 0.3805569710517512, 0.19505388777575874`], 
             UndirectedEdge[16, 86] -> 
             RGBColor[
              0.3574604388898408, 0.48403599850748935`, 0.9439980409695737], 
             UndirectedEdge[8, 62] -> 
             RGBColor[
              0.40221602470153694`, 0.5228010374564311, 0.9468498273216844], 
             UndirectedEdge[26, 51] -> 
             RGBColor[
              0.3392714220793772, 0.4658216765666159, 0.9429291222497664], 
             UndirectedEdge[117, 121] -> 
             RGBColor[
              0.6608369282647062, 0.733443073990961, 0.9678737418567172], 
             UndirectedEdge[89, 136] -> 
             RGBColor[
              0.8719970463971514, 0.5016704079877174, 0.2145036241613812], 
             UndirectedEdge[81, 168] -> 
             RGBColor[
              0.7574630871375609, 0.8103278215593543, 0.974310777757218], 
             UndirectedEdge[172, 198] -> 
             RGBColor[
              0.8450687656775151, 0.8760452560467036, 0.7780654976273946], 
             UndirectedEdge[55, 68] -> 
             RGBColor[
              0.6040034340544339, 0.6836766872491769, 0.9648829517187356], 
             UndirectedEdge[156, 192] -> 
             RGBColor[
              0.8518272488984739, 0.40265794141667954`, 0.4402493642261227], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.3132800245584588, 0.44509451368492026`, 0.9412076055629822], 
             UndirectedEdge[25, 154] -> 
             RGBColor[
              0.9827245214041163, 0.9646281141811062, 0.6227757587980907], 
             UndirectedEdge[100, 135] -> 
             RGBColor[
              0.2235466331661063, 0.3522920635057185, 0.9360420220999779], 
             UndirectedEdge[37, 149] -> 
             RGBColor[
              0.21228087842813756`, 0.34045104098600754`, 0.9354004540338412],
              UndirectedEdge[125, 149] -> 
             RGBColor[
              0.206263918225989, 0.33412683431623835`, 0.9350577970516237], 
             UndirectedEdge[2, 184] -> 
             RGBColor[
              0.37412689727752746`, 0.49847164708234826`, 0.9450600129604667],
              UndirectedEdge[6, 16] -> 
             RGBColor[
              0.3315065479690632, 0.46155604267239897`, 0.9423442819902264], 
             UndirectedEdge[55, 111] -> 
             RGBColor[
              0.40643893320785657`, 0.5262638141229958, 0.9471727572298012], 
             UndirectedEdge[34, 50] -> 
             RGBColor[
              0.2469901077447556, 0.3769326416900177, 0.9373770932957193], 
             UndirectedEdge[56, 125] -> 
             RGBColor[
              0.17894341419620807`, 0.3054112523609348, 0.9335019347641915], 
             UndirectedEdge[98, 196] -> 
             RGBColor[
              0.7343309142909232, 0.7903956980318739, 0.9415812202273133], 
             UndirectedEdge[160, 167] -> 
             RGBColor[
              0.6409937758733817, 0.7136645586271843, 0.9681842712741754], 
             UndirectedEdge[22, 149] -> 
             RGBColor[
              0.6408039078801677, 0.34924268232058286`, 0.43898539301059114`],
              UndirectedEdge[147, 194] -> 
             RGBColor[
              0.41461252572283636`, 0.5327948903127648, 0.9478451176521548], 
             UndirectedEdge[83, 161] -> 
             RGBColor[
              0.28225365624559345`, 0.41399686700250915`, 0.9393853002150969],
              UndirectedEdge[34, 177] -> 
             RGBColor[
              0.27267734754750905`, 0.40393155938778236`, 0.9388399436016203],
              UndirectedEdge[70, 145] -> 
             RGBColor[
              0.2107154956867174, 0.33880572447377666`, 0.9353113078024935], 
             UndirectedEdge[125, 170] -> 
             RGBColor[
              0.18066259612527297`, 0.307218221570812, 0.93359983963175], 
             UndirectedEdge[190, 192] -> 
             RGBColor[
              0.6047816873553487, 0.19148929823006858`, 0.42066047446022103`],
              UndirectedEdge[122, 188] -> 
             RGBColor[
              0.8287961614327686, 0.8626280708354541, 0.7199844478872237], 
             UndirectedEdge[123, 130] -> 
             RGBColor[
              0.24382776690061642`, 0.3736088209588374, 0.9371970026629095], 
             UndirectedEdge[94, 116] -> 
             RGBColor[
              0.4038551160855868, 0.5242207360301667, 0.9469542687752844], 
             UndirectedEdge[23, 162] -> 
             RGBColor[
              0.9882402059749112, 0.9877215722762983, 0.728168038634343], 
             UndirectedEdge[116, 160] -> 
             RGBColor[
              0.3781472802574135, 0.5019539007492015, 0.9453161882088599], 
             UndirectedEdge[80, 117] -> 
             RGBColor[
              0.699447709361209, 0.7647890454809683, 0.9709133239805854], 
             UndirectedEdge[147, 185] -> 
             RGBColor[
              0.625134594396598, 0.7046026904109504, 0.9649644103506239], 
             UndirectedEdge[55, 107] -> 
             RGBColor[
              0.5098065457970684, 0.609801290788619, 0.955570731517623], 
             UndirectedEdge[111, 174] -> 
             RGBColor[
              0.4209532104070455, 0.5388353515241499, 0.9480975941384622], 
             UndirectedEdge[126, 142] -> 
             RGBColor[
              0.47405701779443504`, 0.579792473280542, 0.9528398302801124], 
             UndirectedEdge[115, 160] -> 
             RGBColor[
              0.31613284886837134`, 0.44424671423453505`, 0.9415109015232768],
              UndirectedEdge[74, 164] -> 
             RGBColor[
              0.29875283098362904`, 0.4313385457602833, 0.9403249038080864], 
             UndirectedEdge[42, 97] -> 
             RGBColor[
              0.401201459999004, 0.517503689481011, 0.9473903200062829], 
             UndirectedEdge[25, 108] -> 
             RGBColor[
              0.8800770451068233, 0.8847917621519991, 0.6757220357685101], 
             UndirectedEdge[67, 133] -> 
             RGBColor[
              0.8199464110752147, 0.15432243286297473`, 0.166734011812862], 
             UndirectedEdge[38, 183] -> 
             RGBColor[
              0.8948764104777984, 0.602162747374174, 0.2424745440128403], 
             UndirectedEdge[33, 41] -> 
             RGBColor[
              0.4363770738073567, 0.5497722412161976, 0.9497497290534018], 
             UndirectedEdge[32, 123] -> 
             RGBColor[
              0.24279155375346242`, 0.3725196952414703, 0.9371379918571192], 
             UndirectedEdge[61, 116] -> 
             RGBColor[
              0.3316898960628568, 0.4584835766718288, 0.9424742774984342], 
             UndirectedEdge[93, 134] -> 
             RGBColor[
              0.2274998629101822, 0.35644715861598486`, 0.9362671526856237], 
             UndirectedEdge[45, 128] -> 
             RGBColor[
              0.8869707508914968, 0.5796424030976618, 0.22739796275449303`], 
             UndirectedEdge[29, 35] -> 
             RGBColor[
              0.9160081618564544, 0.9327996859082862, 0.8697305761183244], 
             UndirectedEdge[3, 106] -> 
             RGBColor[
              0.26935764073949675`, 0.40044233705099297`, 0.93865089120997], 
             UndirectedEdge[77, 140] -> 
             RGBColor[
              0.3029488619339533, 0.43574884033280226`, 0.9405638615632359], 
             UndirectedEdge[79, 195] -> 
             RGBColor[
              0.1914475761291835, 0.31855391936214905`, 0.9342140282880245], 
             UndirectedEdge[38, 46] -> 
             RGBColor[
              0.7812753615379626, 0.7886327284729578, 0.6396314180362879], 
             UndirectedEdge[14, 59] -> 
             RGBColor[
              0.43278883650636024`, 0.549281670407568, 0.9487978998554119], 
             UndirectedEdge[126, 191] -> 
             RGBColor[
              0.2937278856939699, 0.4260570096609187, 0.9400387406075807], 
             UndirectedEdge[13, 64] -> 
             RGBColor[
              0.5003009692996179, 0.6031608120163909, 0.9543697328740091], 
             UndirectedEdge[3, 11] -> 
             RGBColor[
              0.2547628231142621, 0.3851022583619874, 0.9378197379373108], 
             UndirectedEdge[31, 98] -> 
             RGBColor[
              0.9119983758560902, 0.9316922814327566, 0.9576824339727095], 
             UndirectedEdge[25, 162] -> 
             RGBColor[
              0.9809113830760201, 0.9636638965398352, 0.6432211658410507], 
             UndirectedEdge[126, 157] -> 
             RGBColor[
              0.43245489742186133`, 0.5460179978079216, 0.9495647589707952], 
             UndirectedEdge[128, 183] -> 
             RGBColor[
              0.8698008244556358, 0.5016777772906199, 0.21307095526300113`], 
             UndirectedEdge[22, 192] -> 
             RGBColor[
              0.8353875718603139, 0.2730099610170472, 0.18152048481896965`], 
             UndirectedEdge[99, 194] -> 
             RGBColor[
              0.45631234328201786`, 0.5666486807626816, 0.9511278800418784], 
             UndirectedEdge[21, 151] -> 
             RGBColor[
              0.33403902527338425`, 0.46374954722739153`, 0.9425056492046759],
              UndirectedEdge[48, 59] -> 
             RGBColor[
              0.382953798860026, 0.5061170655801353, 0.9456224553239809], 
             UndirectedEdge[18, 115] -> 
             RGBColor[
              0.2919621879503136, 0.4233113026000546, 0.9399707683828544], 
             UndirectedEdge[29, 89] -> 
             RGBColor[
              0.9005424949414248, 0.6078887731128675, 0.3845626076055324], 
             UndirectedEdge[15, 140] -> 
             RGBColor[
              0.31530720692745856`, 0.4472252108855248, 0.9413230505999493], 
             UndirectedEdge[113, 136] -> 
             RGBColor[
              0.9041543846818847, 0.6565805366270306, 0.24168008890791598`], 
             UndirectedEdge[111, 160] -> 
             RGBColor[
              0.41360379540408243`, 0.5324696576409218, 0.9476292959133059], 
             UndirectedEdge[116, 188] -> 
             RGBColor[
              0.5271183885528666, 0.6249053886087885, 0.9566275025109046], 
             UndirectedEdge[82, 127] -> 
             RGBColor[
              0.32009303423134106`, 0.45167023073266444`, 0.9416170229874327],
              UndirectedEdge[25, 95] -> 
             RGBColor[
              0.9792736576371948, 0.9417473218129542, 0.37398250307217895`], 
             UndirectedEdge[62, 111] -> 
             RGBColor[
              0.40836524299990506`, 0.527932286845723, 0.9472954999863816], 
             UndirectedEdge[162, 180] -> 
             RGBColor[
              0.853484717444914, 0.8855675982797966, 0.9434799440471393], 
             UndirectedEdge[89, 159] -> 
             RGBColor[
              0.8435429758673372, 0.3356959699358522, 0.18933010890630664`], 
             UndirectedEdge[7, 153] -> 
             RGBColor[
              0.46821510011481404`, 0.5763643045440561, 0.9520504222141921], 
             UndirectedEdge[146, 183] -> 
             RGBColor[
              0.8386384964590899, 0.584723475070088, 0.463315779566298], 
             UndirectedEdge[144, 197] -> 
             RGBColor[
              0.8673162616632236, 0.5950284434012776, 0.4642576245133444], 
             UndirectedEdge[120, 128] -> 
             RGBColor[
              0.9231751810131911, 0.7286652920066743, 0.2580660064250903], 
             UndirectedEdge[74, 166] -> 
             RGBColor[
              0.34685352759081295`, 0.47429746798031186`, 0.9433423658444682],
              UndirectedEdge[147, 152] -> 
             RGBColor[
              0.3812177118441309, 0.5013730508472783, 0.9458086544862003], 
             UndirectedEdge[22, 190] -> 
             RGBColor[
              0.6228502592156624, 0.3303722592471158, 0.4379629592791906], 
             UndirectedEdge[27, 128] -> 
             RGBColor[
              0.5831652721126257, 0.49985421349972364`, 0.5843241339583132], 
             UndirectedEdge[47, 88] -> 
             RGBColor[
              0.5818581666070413, 0.6702991325141743, 0.9609700518092634], 
             UndirectedEdge[69, 177] -> 
             RGBColor[
              0.3475961861623531, 0.47409235374214537`, 0.9434207502916752], 
             UndirectedEdge[122, 167] -> 
             RGBColor[
              0.9541070504857341, 0.9612920976894692, 0.7322698767088691], 
             UndirectedEdge[1, 78] -> 
             RGBColor[
              0.9431385588038124, 0.9082192270955545, 0.6427719916956993], 
             UndirectedEdge[138, 159] -> 
             RGBColor[
              0.8526881995414608, 0.34733777015289946`, 0.19577026697210964`],
              UndirectedEdge[101, 127] -> 
             RGBColor[
              0.28671598940138643`, 0.417499764656998, 0.9396828962615742], 
             UndirectedEdge[65, 90] -> 
             RGBColor[
              0.6550212395891795, 0.7255799866641114, 0.9691860218299977], 
             UndirectedEdge[64, 127] -> 
             RGBColor[
              0.4720951346225606, 0.5787303356855954, 0.9525724820298272], 
             UndirectedEdge[117, 146] -> 
             RGBColor[
              0.7875464410912392, 0.8339565324458974, 0.9794589272741974], 
             UndirectedEdge[49, 103] -> 
             RGBColor[
              0.8445886551123987, 0.33756196468319305`, 0.19008978994933337`],
              UndirectedEdge[88, 113] -> 
             RGBColor[
              0.8062483508925926, 0.7076340176229743, 0.6052352623718941], 
             UndirectedEdge[13, 176] -> 
             RGBColor[
              0.3360981234854725, 0.4641878743195114, 0.9426861060294587], 
             UndirectedEdge[17, 112] -> 
             RGBColor[
              0.27014379762534146`, 0.4012686377832412, 0.938695661681604], 
             UndirectedEdge[129, 170] -> 
             RGBColor[
              0.5863125273607737, 0.6439068649740138, 0.6751789886764388], 
             UndirectedEdge[35, 116] -> 
             RGBColor[
              0.6139780435679677, 0.6929094451719539, 0.9652454183041966], 
             UndirectedEdge[69, 110] -> 
             RGBColor[
              0.503306311820726, 0.6062411074789984, 0.9544293736590629], 
             UndirectedEdge[47, 126] -> 
             RGBColor[
              0.37937335834478547`, 0.5028752400890226, 0.9453994618957948], 
             UndirectedEdge[83, 137] -> 
             RGBColor[
              0.2530177140174724, 0.383268038054954, 0.9377203565559061], 
             UndirectedEdge[72, 84] -> 
             RGBColor[
              0.256326539038239, 0.386745822943403, 0.9379087892458708], 
             UndirectedEdge[22, 37] -> 
             RGBColor[
              0.626612488125885, 0.33432660037084994`, 0.4381772126499089], 
             UndirectedEdge[90, 141] -> 
             RGBColor[
              0.37364371183420664`, 0.49805313613695035`, 0.9450292248112824],
              UndirectedEdge[24, 79] -> 
             RGBColor[
              0.1914475775488761, 0.318553920854336, 0.9342140283688739], 
             UndirectedEdge[34, 130] -> 
             RGBColor[
              0.2444860062107015, 0.3743006722085195, 0.9372344884178412], 
             UndirectedEdge[157, 174] -> 
             RGBColor[
              0.4695477072718456, 0.5782865532361309, 0.9519231309391665], 
             UndirectedEdge[131, 180] -> 
             RGBColor[
              0.811663417266584, 0.70990288285835, 0.6053916520008711], 
             UndirectedEdge[3, 48] -> 
             RGBColor[
              0.29038303180772673`, 0.42176872223911466`, 0.9398765460393633],
              UndirectedEdge[49, 67] -> 
             RGBColor[
              0.8292269673761329, 0.22565685535753427`, 0.17562108300751042`],
              UndirectedEdge[79, 190] -> 
             RGBColor[
              0.19183760716220638`, 0.3189638667072519, 0.9342362399783559], 
             UndirectedEdge[13, 82] -> 
             RGBColor[
              0.34829886890839834`, 0.4761007070634601, 0.9434142738316145], 
             UndirectedEdge[68, 138] -> 
             RGBColor[
              0.8842002449557951, 0.7898038345132208, 0.6173834589873493], 
             UndirectedEdge[153, 160] -> 
             RGBColor[
              0.4763409264473496, 0.5834024868973917, 0.9525681926827152], 
             UndirectedEdge[178, 183] -> 
             RGBColor[
              0.8874176158778669, 0.6233741459180975, 0.46398946432897215`], 
             UndirectedEdge[2, 166] -> 
             RGBColor[
              0.3840226301972896, 0.5070428335634479, 0.9456905603116609], 
             UndirectedEdge[32, 53] -> 
             RGBColor[
              0.2232819677009355, 0.3520138833210643, 0.9360269497932738], 
             UndirectedEdge[26, 184] -> 
             RGBColor[
              0.38376793461067366`, 0.5068222290476936, 0.9456743313341002], 
             UndirectedEdge[61, 115] -> 
             RGBColor[
              0.2696754646738146, 0.40077639015716227`, 0.938668990812851], 
             UndirectedEdge[146, 178] -> 
             RGBColor[
              0.8692632098101054, 0.8986103712740543, 0.9813214481021706], 
             UndirectedEdge[88, 102] -> 
             RGBColor[
              0.5430147651889159, 0.6366549305319157, 0.9584949846187718], 
             UndirectedEdge[118, 159] -> 
             RGBColor[
              0.852865483210531, 0.4279441020790433, 0.443409538968764], 
             UndirectedEdge[62, 75] -> 
             RGBColor[
              0.3201980535903144, 0.44948818207116104`, 0.9417069408010099], 
             UndirectedEdge[89, 197] -> 
             RGBColor[
              0.865633819989058, 0.5820964594429976, 0.4626465164661172], 
             UndirectedEdge[85, 146] -> 
             RGBColor[
              0.578124805971577, 0.6635021636474746, 0.9622403310784291], 
             UndirectedEdge[170, 190] -> 
             RGBColor[
              0.1810362129620878, 0.3076109165549801, 0.93362111655789], 
             UndirectedEdge[82, 101] -> 
             RGBColor[
              0.2852213829706352, 0.4162052116877847, 0.9395876612614353], 
             UndirectedEdge[7, 73] -> 
             RGBColor[
              0.3217974307185043, 0.4517031252435637, 0.941778474399676], 
             UndirectedEdge[19, 34] -> 
             RGBColor[
              0.25807475059694696`, 0.38858330413461983`, 0.938008347307892], 
             UndirectedEdge[56, 170] -> 
             RGBColor[
              0.1806461819290649, 0.30720096920987716`, 0.9335989048675586], 
             UndirectedEdge[32, 187] -> 
             RGBColor[
              0.2589893983893689, 0.38954465695647483`, 0.9380604351465702], 
             UndirectedEdge[74, 169] -> 
             RGBColor[
              0.28768269698087445`, 0.4197031330363533, 0.9396944760534252], 
             UndirectedEdge[55, 147] -> 
             RGBColor[
              0.41653896028796467`, 0.5344634711076623, 0.9479678683591656], 
             UndirectedEdge[49, 143] -> 
             RGBColor[
              0.8300912165420485, 0.23229985316316096`, 0.17644868898482102`],
              UndirectedEdge[28, 77] -> 
             RGBColor[
              0.29758543140917015`, 0.4301115347901189, 0.9402584221293339], 
             UndirectedEdge[122, 153] -> 
             RGBColor[
              0.7894542010597019, 0.8310300259596766, 0.7166537981174088], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.45346195936104267`, 0.5636403822236367, 0.9510953047712845], 
             UndirectedEdge[16, 199] -> 
             RGBColor[
              0.29762489558060606`, 0.42883871402717555`, 0.9403087925207747],
              UndirectedEdge[64, 180] -> 
             RGBColor[
              0.6733354003460714, 0.7444313569668306, 0.9682823563661463], 
             UndirectedEdge[38, 128] -> 
             RGBColor[
              0.9271948937048214, 0.742224726788967, 0.2736818311730274], 
             UndirectedEdge[46, 98] -> 
             RGBColor[
              0.7856154181292234, 0.8320307685883754, 0.9456185242307917], 
             UndirectedEdge[68, 142] -> 
             RGBColor[
              0.7482569303671527, 0.8035288216790438, 0.9754818662750824], 
             UndirectedEdge[5, 20] -> 
             RGBColor[
              0.2538041540046914, 0.3840946363446963, 0.9377651431497445], 
             UndirectedEdge[169, 200] -> 
             RGBColor[
              0.2545855584826314, 0.3849159419949167, 0.9378096429787789], 
             UndirectedEdge[27, 133] -> 
             RGBColor[
              0.6412015723944939, 0.2567918854277903, 0.42640249711352196`], 
             UndirectedEdge[32, 135] -> 
             RGBColor[
              0.23421532693659433`, 0.36350553709275546`, 0.9366495884272892],
              UndirectedEdge[144, 190] -> 
             RGBColor[
              0.6309129511153266, 0.3923456422820542, 0.44568380214781717`], 
             UndirectedEdge[62, 126] -> 
             RGBColor[
              0.33172983127376465`, 0.4616088115734021, 0.9423636584803461], 
             UndirectedEdge[55, 62] -> 
             RGBColor[
              0.35430836392456, 0.4813058296004574, 0.9437971935400564], 
             UndirectedEdge[62, 76] -> 
             RGBColor[
              0.3162924905225524, 0.44538318765994256`, 0.9414845247620637], 
             UndirectedEdge[157, 181] -> 
             RGBColor[
              0.7710073552893554, 0.8197903509371063, 0.9338398508674235], 
             UndirectedEdge[64, 82] -> 
             RGBColor[
              0.4706005281918093, 0.5774357827163821, 0.9524772470296884], 
             UndirectedEdge[142, 153] -> 
             RGBColor[
              0.6134295605638427, 0.6970487778093326, 0.9627105685555573], 
             UndirectedEdge[21, 109] -> 
             RGBColor[
              0.32687230511240406`, 0.45754209443377936`, 0.9420489921333002],
              UndirectedEdge[66, 198] -> 
             RGBColor[
              0.6938904051885131, 0.7607917253864516, 0.97012416888083], 
             UndirectedEdge[141, 198] -> 
             RGBColor[
              0.5277497041986612, 0.6241140740098087, 0.9572340887790165], 
             UndirectedEdge[10, 28] -> 
             RGBColor[
              0.292046399990443, 0.42428966157416065`, 0.9399429824843], 
             UndirectedEdge[31, 151] -> 
             RGBColor[
              0.6011924048521665, 0.6814178617192261, 0.9646228375029955], 
             UndirectedEdge[111, 142] -> 
             RGBColor[
              0.5506924295205754, 0.6461159485528629, 0.957771671786148], 
             UndirectedEdge[111, 181] -> 
             RGBColor[
              0.7224128584245553, 0.7803391492251253, 0.9300143140667192], 
             UndirectedEdge[86, 101] -> 
             RGBColor[
              0.3219019660862388, 0.44797608916280746`, 0.9419249155821955], 
             UndirectedEdge[119, 144] -> 
             RGBColor[
              0.7593033875373049, 0.5094852557802381, 0.45413147471771587`], 
             UndirectedEdge[5, 102] -> 
             RGBColor[
              0.32802099544168023`, 0.45608332647208405`, 0.9422120278540836],
              UndirectedEdge[157, 185] -> 
             RGBColor[
              0.6636290641812901, 0.7358542351382649, 0.9679948360219639], 
             UndirectedEdge[13, 110] -> 
             RGBColor[
              0.49151316787654187`, 0.5960264789351953, 0.9536779249552072], 
             UndirectedEdge[32, 82] -> 
             RGBColor[
              0.27687504662639884`, 0.4074326830017036, 0.9391123497539292], 
             UndirectedEdge[12, 23] -> 
             RGBColor[
              0.7887708920716545, 0.8309004872015715, 0.7514495100334264], 
             UndirectedEdge[53, 130] -> 
             RGBColor[
              0.22431818084808952`, 0.35310300903843134`, 0.9360859605990643],
              UndirectedEdge[74, 80] -> 
             RGBColor[
              0.46133983359188224`, 0.5689367397653611, 0.9518870537804123], 
             UndirectedEdge[35, 185] -> 
             RGBColor[
              0.8039733137479249, 0.8469379641216965, 0.9810567615537757], 
             UndirectedEdge[117, 196] -> 
             RGBColor[
              0.6370858970808988, 0.7141609169041846, 0.966003973679034], 
             UndirectedEdge[22, 181] -> 
             RGBColor[
              0.8910578733822835, 0.5575636367110436, 0.4299003396380736], 
             UndirectedEdge[143, 197] -> 
             RGBColor[
              0.8435046260386568, 0.41200177766559354`, 0.4414555753478633], 
             UndirectedEdge[16, 124] -> 
             RGBColor[
              0.3070078817138632, 0.43870082736891025`, 0.9408431397001796], 
             UndirectedEdge[182, 191] -> 
             RGBColor[
              0.2726772055917506, 0.4039314101832797, 0.9388399355174497], 
             UndirectedEdge[98, 146] -> 
             RGBColor[
              0.8847914583012635, 0.9101913135735867, 0.9550361738224766], 
             UndirectedEdge[156, 183] -> 
             RGBColor[
              0.8802215684635839, 0.6177519614860875, 0.46731617013970106`], 
             UndirectedEdge[6, 13] -> 
             RGBColor[
              0.35902556110322426`, 0.48539162870339236`, 0.9440977691730272],
              UndirectedEdge[50, 100] -> 
             RGBColor[
              0.2280232863629279, 0.35699730985178435`, 0.9362969608769219], 
             UndirectedEdge[13, 175] -> 
             RGBColor[
              0.34919860302112393`, 0.4768800115299515, 0.9434716040936737], 
             UndirectedEdge[62, 116] -> 
             RGBColor[
              0.37290872785323614`, 0.4974165299540027, 0.9449823922819357], 
             UndirectedEdge[120, 171] -> 
             RGBColor[
              0.9156195043648556, 0.8842880492213061, 0.6372222517571104], 
             UndirectedEdge[72, 139] -> 
             RGBColor[
              0.24951735884561907`, 0.3795889428339999, 0.9375210165071806], 
             UndirectedEdge[6, 83] -> 
             RGBColor[
              0.29795007881864144`, 0.4276003661015726, 0.9403851677491978], 
             UndirectedEdge[118, 190] -> 
             RGBColor[
              0.5465072945042451, 0.6199622709372278, 0.9625693523456647], 
             UndirectedEdge[36, 200] -> 
             RGBColor[
              0.24218408124275126`, 0.3718812031167312, 0.9371033971963092], 
             UndirectedEdge[16, 161] -> 
             RGBColor[
              0.3158101253960152, 0.4479525435733356, 0.9413444144561256], 
             UndirectedEdge[2, 169] -> 
             RGBColor[
              0.3248517995873511, 0.4524484986194894, 0.942042670520618], 
             UndirectedEdge[107, 111] -> 
             RGBColor[
              0.5638634248724134, 0.6564277480338845, 0.9590690379639482], 
             UndirectedEdge[127, 180] -> 
             RGBColor[
              0.5228279063856032, 0.618665804983113, 0.9574221323238906], 
             UndirectedEdge[138, 156] -> 
             RGBColor[
              0.9168097113153278, 0.8158057378279282, 0.6204937789995357], 
             UndirectedEdge[72, 93] -> 
             RGBColor[
              0.23701205160573985`, 0.3664450720426131, 0.9368088577598136], 
             UndirectedEdge[137, 187] -> 
             RGBColor[
              0.2665071069572168, 0.39744624531153616`, 0.938488557528056], 
             UndirectedEdge[40, 121] -> 
             RGBColor[
              0.5171284633430432, 0.6188672087704971, 0.9551293934197934], 
             UndirectedEdge[98, 178] -> 
             RGBColor[
              0.957960137429429, 0.968167319845601, 0.9560467009664877], 
             UndirectedEdge[10, 186] -> 
             RGBColor[
              0.28567319780598677`, 0.4175910219939398, 0.939580038048203], 
             UndirectedEdge[63, 91] -> 
             RGBColor[
              0.5953350475574752, 0.6767809281925967, 0.9640487060966569], 
             UndirectedEdge[125, 195] -> 
             RGBColor[
              0.17894341419620807`, 0.3054112523609348, 0.9335019347641915], 
             UndirectedEdge[86, 180] -> 
             RGBColor[
              0.5580138830704554, 0.6491421294889225, 0.9596641516445119], 
             UndirectedEdge[137, 186] -> 
             RGBColor[
              0.2661087370017966, 0.3970275332302755, 0.9384658709484304], 
             UndirectedEdge[33, 44] -> 
             RGBColor[
              0.3032320659672701, 0.4347249229295589, 0.9406283792341544], 
             UndirectedEdge[14, 193] -> 
             RGBColor[
              0.36672963099697153`, 0.49206450682754455`, 0.9445886656942154],
              UndirectedEdge[11, 28] -> 
             RGBColor[
              0.2703195386510599, 0.4014533527438959, 0.9387056698730332], 
             UndirectedEdge[85, 151] -> 
             RGBColor[
              0.35601576258697687`, 0.48278469250549083`, 0.9439059874730323],
              UndirectedEdge[175, 199] -> 
             RGBColor[
              0.2963432017196842, 0.4277285752246516, 0.9402271241213142], 
             UndirectedEdge[146, 196] -> 
             RGBColor[
              0.6456339866715997, 0.7208387494603272, 0.9668559673629961], 
             UndirectedEdge[20, 77] -> 
             RGBColor[
              0.2628976545910799, 0.3936524820222284, 0.9382830045555108], 
             UndirectedEdge[27, 56] -> 
             RGBColor[
              0.22783801477683696`, 0.3568025776679057, 0.9362864099341788], 
             UndirectedEdge[101, 175] -> 
             RGBColor[
              0.2861211170833608, 0.41698451615427623`, 0.9396449915234946], 
             UndirectedEdge[21, 85] -> 
             RGBColor[
              0.3381783439476214, 0.46733481701480994`, 0.9427694029303426], 
             UndirectedEdge[150, 194] -> 
             RGBColor[
              0.31572797791144636`, 0.44550227419337246`, 0.9414262912319082],
              UndirectedEdge[61, 160] -> 
             RGBColor[
              0.3202543943304065, 0.44857871983620956`, 0.9417456174400596], 
             UndirectedEdge[24, 149] -> 
             RGBColor[
              0.20624750544947348`, 0.3341095834474904, 0.9350568623682817], 
             UndirectedEdge[14, 186] -> 
             RGBColor[
              0.34940158280640243`, 0.47458578186823513`, 0.9435749780704197],
              UndirectedEdge[111, 126] -> 
             RGBColor[
              0.3838604005570612, 0.5065667960959406, 0.9457392221700909], 
             UndirectedEdge[35, 88] -> 
             RGBColor[
              0.775283955250752, 0.8245256192165048, 0.9781972744160757], 
             UndirectedEdge[94, 111] -> 
             RGBColor[
              0.43931163123225564`, 0.554736492921887, 0.9492673764797304], 
             UndirectedEdge[133, 162] -> 
             RGBColor[
              0.8765856501368406, 0.44964429041426807`, 0.41798785096875907`],
              UndirectedEdge[124, 199] -> 
             RGBColor[
              0.2816714935465845, 0.4133849770946037, 0.939352146910621], 
             UndirectedEdge[54, 105] -> 
             RGBColor[
              0.3080083942884021, 0.4378802673814718, 0.9409686664381117], 
             UndirectedEdge[64, 162] -> 
             RGBColor[
              0.8027519456818715, 0.845632128982279, 0.9386302937530759], 
             UndirectedEdge[57, 66] -> 
             RGBColor[
              0.5260989516337345, 0.6228771288818142, 0.9570472794276266], 
             UndirectedEdge[16, 137] -> 
             RGBColor[
              0.2865741831678942, 0.41722371462578045`, 0.9396794707969347], 
             UndirectedEdge[44, 50] -> 
             RGBColor[
              0.2628281872337618, 0.3935794674252022, 0.9382790484922793], 
             UndirectedEdge[153, 167] -> 
             RGBColor[
              0.7506229237957682, 0.8050180016109936, 0.9761649358064053], 
             UndirectedEdge[165, 187] -> 
             RGBColor[
              0.2508650284302595, 0.38100542901464385`, 0.9375977642963274], 
             UndirectedEdge[32, 83] -> 
             RGBColor[
              0.2455000054496245, 0.37536644969989263`, 0.9372922341744203], 
             UndirectedEdge[6, 187] -> 
             RGBColor[
              0.3114394717583858, 0.44177857335815474`, 0.9411533687213477], 
             UndirectedEdge[66, 141] -> 
             RGBColor[
              0.5254792907329107, 0.622340409754583, 0.9570077951829706], 
             UndirectedEdge[23, 87] -> 
             RGBColor[
              0.9907768608924232, 0.9889849826208208, 0.6957320893038507], 
             UndirectedEdge[85, 152] -> 
             RGBColor[
              0.320947319253029, 0.44991323932493577`, 0.9417628821181223], 
             UndirectedEdge[26, 74] -> 
             RGBColor[
              0.3495927399015075, 0.4766700360070217, 0.9435169060307154], 
             UndirectedEdge[81, 172] -> 
             RGBColor[
              0.7851552645502801, 0.8282289520022286, 0.7727853942333442], 
             UndirectedEdge[54, 73] -> 
             RGBColor[
              0.28297059999413937`, 0.41475042033909004`, 0.9394261291009534],
              UndirectedEdge[135, 165] -> 
             RGBColor[
              0.22609095697748494`, 0.3549663091509244, 0.9361869175770461], 
             UndirectedEdge[46, 109] -> 
             RGBColor[
              0.4676427269643195, 0.5755488960812328, 0.9521022706897019], 
             UndirectedEdge[40, 171] -> 
             RGBColor[
              0.6830257915160596, 0.7504348777708634, 0.9705035877143484], 
             UndirectedEdge[113, 167] -> 
             RGBColor[
              0.9077889348257765, 0.7877285014564059, 0.6151514893253305], 
             UndirectedEdge[103, 162] -> 
             RGBColor[
              0.9038275928696831, 0.6466946914547808, 0.4435914409291628], 
             UndirectedEdge[37, 119] -> 
             RGBColor[
              0.3779360600643469, 0.4878548266230827, 0.9465383122915882], 
             UndirectedEdge[71, 184] -> 
             RGBColor[
              0.3307081584442233, 0.45915751757499346`, 0.9423559109556644], 
             UndirectedEdge[107, 142] -> 
             RGBColor[
              0.6540600421097872, 0.7296534252184859, 0.9661696460739697], 
             UndirectedEdge[136, 143] -> 
             RGBColor[
              0.8498678524467502, 0.3315757262103135, 0.19331268304312726`], 
             UndirectedEdge[3, 5] -> 
             RGBColor[
              0.27293521528598386`, 0.4042025947306783, 0.9388546287878452], 
             UndirectedEdge[24, 118] -> 
             RGBColor[
              0.5461172648909147, 0.6195523250843118, 0.9625471407361825], 
             UndirectedEdge[142, 185] -> 
             RGBColor[
              0.7052311845538637, 0.7696287106108853, 0.971269907331281], 
             UndirectedEdge[3, 28] -> 
             RGBColor[
              0.2792200802478043, 0.4108083862890054, 0.9392125425497964], 
             UndirectedEdge[43, 49] -> 
             RGBColor[
              0.8484894518822184, 0.3737167521458401, 0.1940668599244025], 
             UndirectedEdge[19, 60] -> 
             RGBColor[
              0.25917942342753286`, 0.38974438531986844`, 0.9380712567913769],
              UndirectedEdge[87, 110] -> 
             RGBColor[
              0.7965007991763076, 0.8397612062456058, 0.9055025365037817], 
             UndirectedEdge[107, 185] -> 
             RGBColor[
              0.7184021799057017, 0.779940510091907, 0.9725672735090811], 
             UndirectedEdge[66, 81] -> 
             RGBColor[
              0.633976904061278, 0.7129754213419766, 0.9648440654867796], 
             UndirectedEdge[63, 112] -> 
             RGBColor[
              0.32715088352733546`, 0.45710875455411837`, 0.94209144443096], 
             UndirectedEdge[59, 193] -> 
             RGBColor[
              0.38274569330621644`, 0.5059368150091147, 0.9456091950221126], 
             UndirectedEdge[110, 180] -> 
             RGBColor[
              0.6645475989229954, 0.737297023885635, 0.9675905484473445], 
             UndirectedEdge[21, 196] -> 
             RGBColor[
              0.4056875246476441, 0.5246714028276624, 0.9473850392149095], 
             UndirectedEdge[24, 190] -> 
             RGBColor[
              0.1793170324527155, 0.3058039488372898, 0.9335232117711809], 
             UndirectedEdge[44, 60] -> 
             RGBColor[
              0.2686906729944792, 0.399741311662782, 0.9386129083835817], 
             UndirectedEdge[20, 106] -> 
             RGBColor[
              0.25022657945820426`, 0.38033437866501096`, 0.9375614055718693],
              UndirectedEdge[75, 139] -> 
             RGBColor[
              0.26665982071221705`, 0.39760675715065275`, 0.9384972543504835],
              UndirectedEdge[4, 81] -> 
             RGBColor[
              0.6906097692395512, 0.7572174460449604, 0.9704887002235348], 
             UndirectedEdge[79, 197] -> 
             RGBColor[
              0.5464425729840517, 0.6229880683860871, 0.9620969735266468], 
             UndirectedEdge[66, 90] -> 
             RGBColor[
              0.5397844128240585, 0.6347307875135932, 0.9579193049130958], 
             UndirectedEdge[14, 15] -> 
             RGBColor[
              0.3709417656089321, 0.49571284612038347`, 0.9448570591870451], 
             UndirectedEdge[14, 48] -> 
             RGBColor[
              0.36693773655078116`, 0.49224475739856516`, 0.9446019259960836],
              UndirectedEdge[122, 144] -> 
             RGBColor[
              0.901990039676534, 0.619375718064703, 0.29208824069422046`], 
             UndirectedEdge[80, 121] -> 
             RGBColor[
              0.5812862861253769, 0.6709534195821745, 0.9601801322470673], 
             UndirectedEdge[79, 170] -> 
             RGBColor[
              0.1931667580582484, 0.32036088857202627`, 0.934311933155583], 
             UndirectedEdge[91, 95] -> 
             RGBColor[
              0.9087217160297558, 0.9082261327367556, 0.679871771253554], 
             UndirectedEdge[48, 193] -> 
             RGBColor[
              0.3168945933506373, 0.44889990200011176`, 0.9414132211627845], 
             UndirectedEdge[67, 162] -> 
             RGBColor[
              0.8731042173971515, 0.4228844728034631, 0.4146540270455168], 
             UndirectedEdge[65, 87] -> 
             RGBColor[
              0.9550341089343712, 0.965005825208276, 0.9206936459458361], 
             UndirectedEdge[98, 121] -> 
             RGBColor[
              0.7580819454747305, 0.8096778551186503, 0.9434509884049964], 
             UndirectedEdge[161, 187] -> 
             RGBColor[
              0.2957430491853379, 0.4281750742590913, 0.9401535011872468], 
             UndirectedEdge[68, 122] -> 
             RGBColor[
              0.924281570863012, 0.9375100698293877, 0.7294250958369339], 
             UndirectedEdge[19, 90] -> 
             RGBColor[
              0.32617520722218063`, 0.45283835871142575`, 0.9421546927268274],
              UndirectedEdge[80, 168] -> 
             RGBColor[
              0.7792447125486042, 0.8280111263190817, 0.9760255070982982], 
             UndirectedEdge[109, 194] -> 
             RGBColor[
              0.3430360942965171, 0.47154235620939167`, 0.9430789344870343], 
             UndirectedEdge[44, 57] -> 
             RGBColor[
              0.3220009955988029, 0.4509816264225601, 0.9418243188335629], 
             UndirectedEdge[109, 151] -> 
             RGBColor[
              0.34470972375175946`, 0.47299196992446024`, 0.9431855766759899],
              UndirectedEdge[122, 138] -> 
             RGBColor[
              0.9528570018424507, 0.8395978867219851, 0.360717102170288], 
             UndirectedEdge[138, 192] -> 
             RGBColor[
              0.8491378919784113, 0.32004855046860603`, 0.19237048844023447`],
              UndirectedEdge[31, 46] -> 
             RGBColor[
              0.7241254080647266, 0.7839747878759986, 0.9735395315167075], 
             UndirectedEdge[101, 165] -> 
             RGBColor[
              0.23537363183733478`, 0.36472298898420613`, 0.9367155521778278],
              UndirectedEdge[76, 105] -> 
             RGBColor[
              0.3097803157470692, 0.4397426691808402, 0.94106957474386], 
             UndirectedEdge[6, 199] -> 
             RGBColor[
              0.3061701598017846, 0.4362401923980924, 0.9408532892006678], 
             UndirectedEdge[83, 175] -> 
             RGBColor[
              0.2881231207365411, 0.41908874892813175`, 0.9397590026698441], 
             UndirectedEdge[139, 182] -> 
             RGBColor[
              0.2571409182934481, 0.38760178717525484`, 0.9379551669396888], 
             UndirectedEdge[89, 149] -> 
             RGBColor[
              0.6471841581056663, 0.3982840813972412, 0.44509512783199057`], 
             UndirectedEdge[53, 163] -> 
             RGBColor[
              0.2222172147783616, 0.3508947604902047, 0.935966313689494], 
             UndirectedEdge[8, 96] -> 
             RGBColor[
              0.3771970335719591, 0.5008951438379817, 0.9452642694982989], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.3028942075372073, 0.43437709498723787`, 0.9406088720414547], 
             UndirectedEdge[55, 191] -> 
             RGBColor[
              0.31630641834476525`, 0.445754027687974, 0.9414722756672911], 
             UndirectedEdge[122, 181] -> 
             RGBColor[
              0.9886341161577883, 0.9875460745600706, 0.6910581517385923], 
             UndirectedEdge[130, 177] -> 
             RGBColor[
              0.26541543308332344`, 0.3962988268539529, 0.9384263883159245], 
             UndirectedEdge[25, 131] -> 
             RGBColor[
              0.93909008289769, 0.7879991811183886, 0.30513287379478254`], 
             UndirectedEdge[19, 33] -> 
             RGBColor[
              0.29372081640032377`, 0.4247279965866454, 0.9400867276419496], 
             UndirectedEdge[1, 89] -> 
             RGBColor[
              0.8887656846103759, 0.567689263625524, 0.23040845432083734`], 
             UndirectedEdge[123, 127] -> 
             RGBColor[
              0.2860095413584047, 0.4167572429724312, 0.9396426650906227], 
             UndirectedEdge[40, 173] -> 
             RGBColor[
              0.7433614186788604, 0.7950716369237336, 0.832834751651226], 
             UndirectedEdge[17, 106] -> 
             RGBColor[
              0.25694510996125053`, 0.38739598020314986`, 0.9379440159448427],
              UndirectedEdge[51, 158] -> 
             RGBColor[
              0.267702506048196, 0.39870268554883526`, 0.9385566337378528], 
             UndirectedEdge[20, 189] -> 
             RGBColor[
              0.2283963086796351, 0.35738937995762443`, 0.9363182039460214], 
             UndirectedEdge[48, 140] -> 
             RGBColor[
              0.3113031778693076, 0.4437571221637065, 0.9410679174089878], 
             UndirectedEdge[11, 189] -> 
             RGBColor[
              0.2386268283641832, 0.36814230479849686`, 0.9369008169073587], 
             UndirectedEdge[40, 169] -> 
             RGBColor[
              0.38208210782853824`, 0.5009795735314966, 0.9459763978166744], 
             UndirectedEdge[94, 167] -> 
             RGBColor[0.666701611701555, 0.7359313939081493, 0.9698223518406],
              UndirectedEdge[81, 198] -> 
             RGBColor[
              0.6362473175270285, 0.7147490855972023, 0.9650703590828255], 
             UndirectedEdge[34, 60] -> 
             RGBColor[
              0.25285259350547307`, 0.38309448592759754`, 0.9377109531870217],
              UndirectedEdge[13, 101] -> 
             RGBColor[
              0.3149218240784437, 0.4419302409877936, 0.941480147105756], 
             UndirectedEdge[31, 117] -> 
             RGBColor[
              0.8147533586460658, 0.8554575003050673, 0.9821051874244302], 
             UndirectedEdge[94, 105] -> 
             RGBColor[
              0.3806688871734759, 0.5041379899202462, 0.945476862771782], 
             UndirectedEdge[125, 190] -> 
             RGBColor[
              0.179333445229231, 0.3058211997060377, 0.933524146454523], 
             UndirectedEdge[79, 119] -> 
             RGBColor[
              0.3844232617951737, 0.4946732869545277, 0.9469077488332039], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.2600890189665118, 0.39070042790302345`, 0.9381230569116956], 
             UndirectedEdge[156, 178] -> 
             RGBColor[
              0.9316378178168464, 0.9481531008980535, 0.987322033962275], 
             UndirectedEdge[95, 131] -> 
             RGBColor[
              0.9394422371635587, 0.7891870801469172, 0.306500926618929], 
             UndirectedEdge[49, 133] -> 
             RGBColor[
              0.8309676837459775, 0.23903676416293673`, 0.17728799496913153`],
              UndirectedEdge[34, 44] -> 
             RGBColor[
              0.2675860001638932, 0.3985802304775334, 0.9385499989000968], 
             UndirectedEdge[24, 125] -> 
             RGBColor[
              0.17894341561590066`, 0.30541125385312173`, 0.9335019348450408],
              UndirectedEdge[95, 129] -> 
             RGBColor[
              0.9849427513832404, 0.9608705061848779, 0.39600586175704294`], 
             UndirectedEdge[13, 16] -> 
             RGBColor[
              0.35048029688204574`, 0.4779901503324755, 0.9435532724931343], 
             UndirectedEdge[13, 199] -> 
             RGBColor[
              0.3251439087147671, 0.45267430005816894`, 0.9420622797035756], 
             UndirectedEdge[121, 196] -> 
             RGBColor[
              0.5189244738450667, 0.6203252910053908, 0.955270781945516], 
             UndirectedEdge[26, 40] -> 
             RGBColor[
              0.4439921507491714, 0.557946476502165, 0.9497988277939646], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.31163329513552707`, 0.44101997430243733`, 0.9411996419147166],
              UndirectedEdge[54, 126] -> 
             RGBColor[
              0.29001572662104147`, 0.4221552951107917, 0.9398273386400247], 
             UndirectedEdge[16, 193] -> 
             RGBColor[
              0.3198238857723562, 0.4514371078652866, 0.9415998730856248], 
             UndirectedEdge[85, 150] -> 
             RGBColor[
              0.3215409260409259, 0.45053715769585945`, 0.9417966871465304], 
             UndirectedEdge[26, 169] -> 
             RGBColor[
              0.3344928369204973, 0.4607990805848347, 0.9426569888942514], 
             UndirectedEdge[22, 79] -> 
             RGBColor[
              0.6309372892797696, 0.33887224059181326`, 0.43842350367765265`],
              UndirectedEdge[27, 67] -> 
             RGBColor[
              0.6377201396548048, 0.23003206781698532`, 0.42306867319027985`],
              UndirectedEdge[49, 95] -> 
             RGBColor[
              0.8830336731086973, 0.49298775428550434`, 0.24571556835587194`],
              UndirectedEdge[147, 178] -> 
             RGBColor[
              0.7115638776908443, 0.7729379814418316, 0.9672966305905184], 
             UndirectedEdge[1, 136] -> 
             RGBColor[
              0.9331596302538536, 0.7720124271387454, 0.2686954588022206], 
             UndirectedEdge[65, 110] -> 
             RGBColor[
              0.7635603354949406, 0.815471840469592, 0.9772401996765336], 
             UndirectedEdge[77, 106] -> 
             RGBColor[
              0.2877229919008626, 0.4197454855521064, 0.9396967707895075], 
             UndirectedEdge[25, 64] -> 
             RGBColor[
              0.8007620659771775, 0.8225276552268693, 0.6680235781600576], 
             UndirectedEdge[82, 187] -> 
             RGBColor[
              0.3007127795635599, 0.4324876517182224, 0.9404698733799348], 
             UndirectedEdge[167, 188] -> 
             RGBColor[
              0.7899648841688349, 0.8366160464867711, 0.9794955855762202], 
             UndirectedEdge[13, 137] -> 
             RGBColor[
              0.31409319630205523`, 0.44105930065677384`, 0.9414329579797356],
              UndirectedEdge[37, 125] -> 
             RGBColor[
              0.18497678859456473`, 0.3117527113916389, 0.9338455265106003], 
             UndirectedEdge[105, 182] -> 
             RGBColor[
              0.30416697639606216`, 0.43384269361666083`, 0.9407499033720115],
              UndirectedEdge[111, 116] -> 
             RGBColor[
              0.42503929713653266`, 0.5423745144765412, 0.9483579559716804], 
             UndirectedEdge[146, 179] -> 
             RGBColor[
              0.802014133137712, 0.8452588034311341, 0.9809009316091206], 
             UndirectedEdge[9, 63] -> 
             RGBColor[
              0.3067096536024727, 0.43562372585425413`, 0.9409273466268289], 
             UndirectedEdge[38, 120] -> 
             RGBColor[
              0.960788560046435, 0.8793927471320053, 0.302171389549849], 
             UndirectedEdge[71, 81] -> 
             RGBColor[
              0.43330857195401157`, 0.5446846710814149, 0.9498164169017225], 
             UndirectedEdge[68, 181] -> 
             RGBColor[
              0.9199773592711327, 0.9377520223513063, 0.9477245085556535], 
             UndirectedEdge[114, 158] -> 
             RGBColor[
              0.23522624458781927`, 0.364568075640074, 0.9367071586920077], 
             UndirectedEdge[118, 149] -> 
             RGBColor[
              0.5734377675010032, 0.6482679055474284, 0.9641030029427655], 
             UndirectedEdge[87, 162] -> 
             RGBColor[
              0.9854379176982261, 0.9880317806397674, 0.8813919321035765], 
             UndirectedEdge[88, 122] -> 
             RGBColor[
              0.8525664665525501, 0.8811976138560375, 0.7223536497554326], 
             UndirectedEdge[49, 162] -> 
             RGBColor[
              0.8841254900679142, 0.5075988041034252, 0.42520801020178634`], 
             UndirectedEdge[47, 116] -> 
             RGBColor[
              0.42055225492425696`, 0.5386829584696233, 0.9480181956973843], 
             UndirectedEdge[23, 95] -> 
             RGBColor[
              0.9866024805360858, 0.9658049975494172, 0.45892937586547133`], 
             UndirectedEdge[54, 115] -> 
             RGBColor[
              0.2691801918114708, 0.40025582697672574`, 0.938640785756031], 
             UndirectedEdge[62, 105] -> 
             RGBColor[
              0.3497224989411253, 0.4773337838440822, 0.9435049862784333], 
             UndirectedEdge[13, 108] -> 
             RGBColor[
              0.5796159484292636, 0.6654249189415207, 0.9620681904824614], 
             UndirectedEdge[76, 182] -> 
             RGBColor[
              0.27073696797748936`, 0.4018920974325212, 0.938729441855642], 
             UndirectedEdge[117, 171] -> 
             RGBColor[
              0.8267342564377225, 0.8650107429913272, 0.9832479361512722], 
             UndirectedEdge[40, 46] -> 
             RGBColor[
              0.5446619359975361, 0.6412201222402223, 0.9572969292455886], 
             UndirectedEdge[19, 177] -> 
             RGBColor[
              0.2790041774695689, 0.41058145878005325`, 0.9392002472059755], 
             UndirectedEdge[64, 87] -> 
             RGBColor[
              0.8052886005993835, 0.8468955393268014, 0.9061943444225835], 
             UndirectedEdge[62, 107] -> 
             RGBColor[
              0.5117328555891169, 0.611469763511346, 0.9556934742742034], 
             UndirectedEdge[53, 148] -> 
             RGBColor[
              0.20810268194188267`, 0.3360594915659958, 0.9351625119250367], 
             UndirectedEdge[76, 111] -> 
             RGBColor[
              0.368423059805849, 0.49034117218248097`, 0.9448600884518084], 
             UndirectedEdge[11, 48] -> 
             RGBColor[
              0.2814824902109824, 0.4124136886940051, 0.9393696733626], 
             UndirectedEdge[96, 111] -> 
             RGBColor[
              0.3833462518703272, 0.5060263932272735, 0.9457099421629962], 
             UndirectedEdge[168, 198] -> 
             RGBColor[
              0.8173765882647961, 0.8581441256038294, 0.9795908811512684], 
             UndirectedEdge[118, 128] -> 
             RGBColor[
              0.901444520807011, 0.7626039594239429, 0.6105848646794676], 
             UndirectedEdge[56, 129] -> 
             RGBColor[
              0.5845933454317087, 0.6420998957641366, 0.6750810838088802], 
             UndirectedEdge[53, 100] -> 
             RGBColor[
              0.21261327393044743`, 0.34080040973402737`, 0.9354193834659627],
              UndirectedEdge[129, 143] -> 
             RGBColor[
              0.8772855250898838, 0.4335162754923927, 0.2505870010613686], 
             UndirectedEdge[18, 160] -> 
             RGBColor[
              0.34254111760690553`, 0.47111363227910186`, 0.9430473950100628],
              UndirectedEdge[68, 111] -> 
             RGBColor[
              0.6580603131297789, 0.7303031444944423, 0.9683812581650608], 
             UndirectedEdge[51, 166] -> 
             RGBColor[
              0.33653220976868264`, 0.46344910853990606`, 0.9427545820635193],
              UndirectedEdge[107, 181] -> 
             RGBColor[
              0.8257804710137671, 0.8638766258907483, 0.9384122883545408], 
             UndirectedEdge[31, 173] -> 
             RGBColor[
              0.9228248907460509, 0.93782630255951, 0.8490773539223448], 
             UndirectedEdge[135, 148] -> 
             RGBColor[
              0.2190360411775415, 0.34755114533768694`, 0.935785150559052], 
             UndirectedEdge[44, 177] -> 
             RGBColor[
              0.2885154270365152, 0.4205783851229668, 0.9397418987981803], 
             UndirectedEdge[80, 184] -> 
             RGBColor[
              0.4955150283010483, 0.599088932806033, 0.9540444790837972], 
             UndirectedEdge[65, 162] -> 
             RGBColor[
              0.9524974540168591, 0.9637424148637534, 0.9531295952763283], 
             UndirectedEdge[5, 17] -> 
             RGBColor[
              0.26052268450773763`, 0.3911562378828352, 0.9381477535227178], 
             UndirectedEdge[44, 141] -> 
             RGBColor[
              0.321381334697979, 0.45044490729532893`, 0.941784834588907], 
             UndirectedEdge[94, 174] -> 
             RGBColor[
              0.39976902935609954`, 0.5206815730777754, 0.9466939069420661], 
             UndirectedEdge[161, 193] -> 
             RGBColor[
              0.31267272742048674`, 0.4452350871371401, 0.9411445022314171], 
             UndirectedEdge[101, 124] -> 
             RGBColor[
              0.2714494089102611, 0.40264091802422836`, 0.9387700143128014], 
             UndirectedEdge[106, 189] -> 
             RGBColor[
              0.25322164598941777`, 0.3834823834875024, 0.9377319701800181], 
             UndirectedEdge[2, 80] -> 
             RGBColor[
              0.4985089361983589, 0.6016821053484971, 0.954235248247605], 
             UndirectedEdge[97, 102] -> 
             RGBColor[
              0.3273981891467483, 0.4554287175679108, 0.9421765599569466], 
             UndirectedEdge[91, 136] -> 
             RGBColor[
              0.8729121465452325, 0.773250594157032, 0.6146156000869095], 
             UndirectedEdge[59, 154] -> 
             RGBColor[
              0.7176662191262557, 0.7759253920834623, 0.911377748265729], 
             UndirectedEdge[108, 162] -> 
             RGBColor[
              0.8820669248115173, 0.9078962359074088, 0.9463287513615282], 
             UndirectedEdge[146, 147] -> 
             RGBColor[
              0.6383951985626789, 0.7149619751698173, 0.9662861034465073], 
             UndirectedEdge[99, 156] -> 
             RGBColor[
              0.7424696241286013, 0.7983584952437333, 0.9755694516963352], 
             UndirectedEdge[143, 154] -> 
             RGBColor[
              0.8760414746143801, 0.43681328017556376`, 0.40267896763816474`],
              UndirectedEdge[139, 145] -> 
             RGBColor[
              0.2284570343408142, 0.357453206477753, 0.9363216621825899], 
             UndirectedEdge[104, 123] -> 
             RGBColor[
              0.23468312728084179`, 0.36399722491481445`, 0.9366762289648454],
              UndirectedEdge[116, 126] -> 
             RGBColor[
              0.34840388541039236`, 0.4760510392042203, 0.9434261144656448], 
             UndirectedEdge[17, 28] -> 
             RGBColor[
              0.2668075494695581, 0.39776202944116235`, 0.938505667284669], 
             UndirectedEdge[89, 118] -> 
             RGBColor[
              0.8737639977332939, 0.5885792424884555, 0.4634219800772578], 
             UndirectedEdge[123, 163] -> 
             RGBColor[
              0.2417268008308885, 0.37140057241061075`, 0.9370773557533394], 
             UndirectedEdge[47, 157] -> 
             RGBColor[
              0.5046032669357259, 0.6086499170733246, 0.9541568402025347], 
             UndirectedEdge[117, 151] -> 
             RGBColor[
              0.565437397706639, 0.6532390613039136, 0.9611245836688005], 
             UndirectedEdge[69, 86] -> 
             RGBColor[
              0.39677259596818604`, 0.5180862130822859, 0.9465029768562303], 
             UndirectedEdge[73, 94] -> 
             RGBColor[
              0.35563109287921313`, 0.4810081428778644, 0.9439343254346236], 
             UndirectedEdge[61, 174] -> 
             RGBColor[
              0.3276038093333696, 0.4549444137194375, 0.9422139156652158], 
             UndirectedEdge[175, 187] -> 
             RGBColor[
              0.3016125136762855, 0.4332669561847139, 0.940527203641994], 
             UndirectedEdge[75, 134] -> 
             RGBColor[
              0.2575067829018646, 0.3879863340758565, 0.93797600238789], 
             UndirectedEdge[38, 178] -> 
             RGBColor[
              0.9536200808381681, 0.9247692797301834, 0.650059594771984], 
             UndirectedEdge[8, 179] -> 
             RGBColor[
              0.6280655556399748, 0.706255507224953, 0.9656353303034069], 
             UndirectedEdge[29, 167] -> 
             RGBColor[
              0.9544593958943188, 0.963459656199136, 0.8733980891466777], 
             UndirectedEdge[68, 185] -> 
             RGBColor[
              0.8125990681630673, 0.8538159065524649, 0.9818794937101938], 
             UndirectedEdge[79, 118] -> 
             RGBColor[
              0.5586378396004057, 0.632712242954274, 0.9632601689433578], 
             UndirectedEdge[171, 173] -> 
             RGBColor[
              0.9348057885377076, 0.9473795452457701, 0.8502201026491867], 
             UndirectedEdge[80, 166] -> 
             RGBColor[
              0.5054107612208105, 0.6076601192871327, 0.9546750264349914], 
             UndirectedEdge[109, 132] -> 
             RGBColor[
              0.2948786821955154, 0.42460409000948357`, 0.9402017631916271], 
             UndirectedEdge[118, 197] -> 
             RGBColor[
              0.9011122603260905, 0.9239864726160629, 0.9904300858939554], 
             UndirectedEdge[111, 167] -> 
             RGBColor[
              0.687885792752501, 0.7540851723545239, 0.971226039036996], 
             UndirectedEdge[113, 122] -> 
             RGBColor[
              0.9466202120897103, 0.8137405258050889, 0.35564035163633406`], 
             UndirectedEdge[119, 190] -> 
             RGBColor[
              0.3722927166990131, 0.48192331493748153`, 0.946216932235511], 
             UndirectedEdge[19, 130] -> 
             RGBColor[
              0.2508128361327613, 0.38095057160079043`, 0.9375947920221963], 
             UndirectedEdge[35, 167] -> 
             RGBColor[
              0.876824539183936, 0.9046201030499366, 0.9881135013695121], 
             UndirectedEdge[102, 112] -> 
             RGBColor[
              0.337642108559284, 0.46619572637249007`, 0.9427599360129698], 
             UndirectedEdge[134, 145] -> 
             RGBColor[
              0.21930399653046173`, 0.34783278340295676`, 0.9358004102199964],
              UndirectedEdge[109, 150] -> 
             RGBColor[
              0.31023488720570846`, 0.44074443511482886`, 0.941076276349488], 
             UndirectedEdge[147, 179] -> 
             RGBColor[
              0.6443148010184508, 0.7195864135989113, 0.9668761140974684], 
             UndirectedEdge[63, 102] -> 
             RGBColor[
              0.3633436999904507, 0.48913178357153686`, 0.9443729171645411], 
             UndirectedEdge[62, 182] -> 
             RGBColor[
              0.31067915117154543`, 0.43948321209576313`, 0.9411648533902153],
              UndirectedEdge[8, 99] -> 
             RGBColor[
              0.5061464386241231, 0.6098124694135529, 0.9543032645305172], 
             UndirectedEdge[60, 123] -> 
             RGBColor[
              0.252194354195388, 0.3824026346779154, 0.9376734674320901], 
             UndirectedEdge[7, 97] -> 
             RGBColor[
              0.3157107895654947, 0.44530567947641203`, 0.9414318491903908], 
             UndirectedEdge[130, 163] -> 
             RGBColor[
              0.23512312567678792`, 0.3644596911264634, 0.9367012862225752], 
             UndirectedEdge[127, 135] -> 
             RGBColor[
              0.2774333145415366, 0.4077430848237163, 0.9391542616607926], 
             UndirectedEdge[37, 56] -> 
             RGBColor[
              0.18496037439835666`, 0.3117354590307041, 0.9338445917464089], 
             UndirectedEdge[100, 148] -> 
             RGBColor[
              0.20930368592266696`, 0.3373218228978505, 0.9352309073250162], 
             UndirectedEdge[53, 135] -> 
             RGBColor[
              0.222345629185322, 0.35102973217386374`, 0.9359736266999984], 
             UndirectedEdge[103, 154] -> 
             RGBColor[
              0.9050363517550805, 0.647337503215628, 0.4299611695671895], 
             UndirectedEdge[63, 140] -> 
             RGBColor[
              0.32917806589633525`, 0.4592394517547229, 0.942206889467927], 
             UndirectedEdge[8, 75] -> 
             RGBColor[
              0.36617940457524284`, 0.4893149172044077, 0.9446368318260574], 
             UndirectedEdge[50, 53] -> 
             RGBColor[
              0.22682228238214364`, 0.3557349785199296, 0.9362285654769424], 
             UndirectedEdge[1, 167] -> 
             RGBColor[
              0.9367941803977453, 0.9031603919681208, 0.6421668592196352], 
             UndirectedEdge[27, 119] -> 
             RGBColor[
              0.4208137004428272, 0.5329219452602844, 0.9489801304793581], 
             UndirectedEdge[96, 126] -> 
             RGBColor[
              0.3067108401441868, 0.4397029179549527, 0.9407781006569607], 
             UndirectedEdge[102, 106] -> 
             RGBColor[
              0.32444342089519307`, 0.4523230687923987, 0.9420082902762085], 
             UndirectedEdge[16, 176] -> 
             RGBColor[
              0.30857911035131147`, 0.440352288288518, 0.9409326188466578], 
             UndirectedEdge[40, 166] -> 
             RGBColor[
              0.4412529384384768, 0.5555739084754552, 0.9496242876077174], 
             UndirectedEdge[33, 90] -> 
             RGBColor[
              0.35549444310349765`, 0.4823331517711803, 0.9438727694565298], 
             UndirectedEdge[13, 161] -> 
             RGBColor[
              0.34332913853017627`, 0.471788129604329, 0.9430979016389265], 
             UndirectedEdge[11, 106] -> 
             RGBColor[
              0.2604570991427524, 0.3910873035058834, 0.9381440185332068], 
             UndirectedEdge[88, 167] -> 
             RGBColor[
              0.8137351892886164, 0.8551855895073546, 0.9818647874444291], 
             UndirectedEdge[29, 159] -> 
             RGBColor[
              0.879643980418662, 0.4472536327034553, 0.36455016649703853`], 
             UndirectedEdge[156, 157] -> 
             RGBColor[
              0.7392642763541118, 0.795756249521131, 0.9753171149779516], 
             UndirectedEdge[171, 183] -> 
             RGBColor[
              0.8647637066900788, 0.6054262821003745, 0.46584178548434796`], 
             UndirectedEdge[100, 104] -> 
             RGBColor[
              0.21637454520909913`, 0.34475374432626316`, 0.9356335823009796],
              UndirectedEdge[108, 180] -> 
             RGBColor[
              0.7526503794757171, 0.8066954638919603, 0.9759808139745987], 
             UndirectedEdge[178, 179] -> 
             RGBColor[
              0.8751828122658775, 0.9032348097031484, 0.9819114587531318], 
             UndirectedEdge[150, 151] -> 
             RGBColor[
              0.3174016073666887, 0.4469518879084411, 0.9415329334208639], 
             UndirectedEdge[2, 121] -> 
             RGBColor[
              0.45989815510185605`, 0.5703361338584898, 0.9511956661237368], 
             UndirectedEdge[12, 14] -> 
             RGBColor[
              0.500367704585658, 0.6042677811858945, 0.954084097379875], 
             UndirectedEdge[43, 131] -> 
             RGBColor[
              0.869996471453065, 0.49619172496078556`, 0.21298460084303164`], 
             UndirectedEdge[75, 76] -> 
             RGBColor[
              0.2802558703962583, 0.4118970674079191, 0.9392715292664366], 
             UndirectedEdge[113, 138] -> 
             RGBColor[
              0.9065388861824932, 0.6660342904889218, 0.24359871478674944`], 
             UndirectedEdge[17, 20] -> 
             RGBColor[
              0.23211977265146783`, 0.3613029766732719, 0.9365302497108459], 
             UndirectedEdge[86, 187] -> 
             RGBColor[
              0.3373933626791634, 0.4642585291932452, 0.9428071277006951], 
             UndirectedEdge[8, 185] -> 
             RGBColor[
              0.6088853490181219, 0.6912717840369921, 0.9637236265565623], 
             UndirectedEdge[4, 41] -> 
             RGBColor[
              0.6772999087061907, 0.7464119016615944, 0.969440899246723], 
             UndirectedEdge[8, 107] -> 
             RGBColor[
              0.5577142065740452, 0.6512964986445926, 0.9586233652992509], 
             UndirectedEdge[149, 192] -> 
             RGBColor[
              0.622735336019854, 0.21035972130353567`, 0.4216829081916216], 
             UndirectedEdge[11, 140] -> 
             RGBColor[
              0.27568296917584306`, 0.40709065828657925`, 0.9390111093069351],
              UndirectedEdge[94, 153] -> 
             RGBColor[
              0.5020487622755229, 0.6056693221783567, 0.9542062732491396], 
             UndirectedEdge[56, 79] -> 
             RGBColor[
              0.1914475761291835, 0.31855391936214905`, 0.9342140282880245], 
             UndirectedEdge[5, 15] -> 
             RGBColor[
              0.303658911440855, 0.4349821137845143, 0.940659697404096], 
             UndirectedEdge[79, 128] -> 
             RGBColor[
              0.5467748334649722, 0.46160555519396695`, 0.5822517523121589], 
             UndirectedEdge[109, 152] -> 
             RGBColor[
              0.3096412804178116, 0.4401205167439052, 0.9410424713210799], 
             UndirectedEdge[118, 192] -> 
             RGBColor[
              0.8493151756474815, 0.40065488239475, 0.4400097604368888], 
             UndirectedEdge[99, 107] -> 
             RGBColor[
              0.615663269511703, 0.6984811954684678, 0.963146911483036], 
             UndirectedEdge[3, 189] -> 
             RGBColor[
              0.24752736996092756`, 0.37749733834360644`, 0.937407689584122], 
             UndirectedEdge[35, 138] -> 
             RGBColor[
              0.8755744905406526, 0.7829258920824524, 0.6165607268309311], 
             UndirectedEdge[12, 86] -> 
             RGBColor[
              0.4879611145029988, 0.5935218164296439, 0.9532935604305248], 
             UndirectedEdge[16, 127] -> 
             RGBColor[
              0.3222744622049885, 0.4535596740016799, 0.9417560216489524], 
             UndirectedEdge[37, 195] -> 
             RGBColor[
              0.18496037439835666`, 0.3117354590307041, 0.9338445917464089], 
             UndirectedEdge[57, 71] -> 
             RGBColor[
              0.32543061952646807`, 0.4545863786212526, 0.9420196308425695], 
             UndirectedEdge[58, 73] -> 
             RGBColor[
              0.2786440888438728, 0.4102029828035092, 0.9391797406914454], 
             UndirectedEdge[35, 153] -> 
             RGBColor[
              0.7121716897579038, 0.7743580313201439, 0.9724974227780518], 
             UndirectedEdge[35, 122] -> 
             RGBColor[
              0.9156558164478696, 0.9306321273986194, 0.7286023636805157], 
             UndirectedEdge[19, 44] -> 
             RGBColor[
              0.2739128300859531, 0.40523012986980433`, 0.9389103025044521], 
             UndirectedEdge[181, 192] -> 
             RGBColor[
              0.8729893015219696, 0.41868067569399636`, 0.41259785481910394`],
              UndirectedEdge[119, 128] -> 
             RGBColor[
              0.727229943001779, 0.6245650034241965, 0.5942324445693138], 
             UndirectedEdge[116, 153] -> 
             RGBColor[
              0.48777642817979994`, 0.593307343733011, 0.9532968527410897], 
             UndirectedEdge[186, 193] -> 
             RGBColor[
              0.29935843960625863`, 0.43124092646978174`, 0.9403862732371204],
              UndirectedEdge[22, 119] -> 
             RGBColor[
              0.7512406956376406, 0.44751187274529963`, 0.44641063184908925`],
              UndirectedEdge[85, 109] -> 
             RGBColor[
              0.34884904242599657`, 0.47657723971187865`, 0.9434493304016565],
              UndirectedEdge[98, 99] -> 
             RGBColor[
              0.7687919437411839, 0.8183727141912807, 0.944294118700548], 
             UndirectedEdge[161, 175] -> 
             RGBColor[
              0.31452843153509336`, 0.4468424047708116, 0.941262746056665], 
             UndirectedEdge[54, 61] -> 
             RGBColor[
              0.27330173727350593`, 0.40458783257840025`, 0.9388755016728139],
              UndirectedEdge[43, 154] -> 
             RGBColor[
              0.8990860971240158, 0.6139443470025971, 0.4247465241785704], 
             UndirectedEdge[87, 95] -> 
             RGBColor[
              0.9838001922594006, 0.9661152059128862, 0.6121532693347048], 
             UndirectedEdge[12, 108] -> 
             RGBColor[
              0.6825976109082605, 0.7510751508326818, 0.9696102227606116], 
             UndirectedEdge[15, 48] -> 
             RGBColor[
              0.32110672796259787`, 0.4525482412929506, 0.9416816146556142], 
             UndirectedEdge[13, 187] -> 
             RGBColor[
              0.33041322067136836`, 0.4582126810182313, 0.9423623592242556], 
             UndirectedEdge[15, 28] -> 
             RGBColor[
              0.3099437764026754, 0.4415879053428414, 0.9410176111660472], 
             UndirectedEdge[52, 134] -> 
             RGBColor[
              0.22165741455534713`, 0.35030637496243233`, 0.9359344338949436],
              UndirectedEdge[66, 172] -> 
             RGBColor[
              0.8427983522117647, 0.874271591791478, 0.7778392040313489], 
             UndirectedEdge[101, 176] -> 
             RGBColor[
              0.27302063754770944`, 0.4042923789438361, 0.9388594934592795], 
             UndirectedEdge[119, 192] -> 
             RGBColor[
              0.7331721237773268, 0.30862891172825246`, 0.4291081470301197], 
             UndirectedEdge[168, 184] -> 
             RGBColor[
              0.6548626736277727, 0.7248006680529328, 0.9668502718111599], 
             UndirectedEdge[16, 175] -> 
             RGBColor[
              0.3216795898869629, 0.4530444254989581, 0.9417181169108728], 
             UndirectedEdge[60, 104] -> 
             RGBColor[
              0.23644603942151277`, 0.3658501573497452, 0.9367766242032618], 
             UndirectedEdge[122, 136] -> 
             RGBColor[
              0.9504725003418423, 0.8301441328600938, 0.35879847629145456`], 
             UndirectedEdge[107, 157] -> 
             RGBColor[
              0.6124579217372135, 0.6958789497458655, 0.9628945747646525], 
             UndirectedEdge[86, 110] -> 
             RGBColor[
              0.49849330988433693`, 0.6020723271102092, 0.9541226934316467], 
             UndirectedEdge[5, 9] -> 
             RGBColor[
              0.27138694905370225`, 0.40257526875480143`, 0.9387664573163714],
              UndirectedEdge[3, 77] -> 
             RGBColor[
              0.2820287158723724, 0.41376044040821036`, 0.9393724901936115], 
             UndirectedEdge[84, 139] -> 
             RGBColor[
              0.25596738815303377`, 0.386368332591571, 0.9378883361342745], 
             UndirectedEdge[96, 191] -> 
             RGBColor[
              0.29321373700723585`, 0.4255166067922517, 0.9400094606004861], 
             UndirectedEdge[46, 151] -> 
             RGBColor[
              0.4748094471252997, 0.581756348874845, 0.9525589277610778], 
             UndirectedEdge[72, 191] -> 
             RGBColor[
              0.2650536461439216, 0.3959185658420248, 0.9384057850849414], 
             UndirectedEdge[111, 185] -> 
             RGBColor[
              0.6150345673164899, 0.6964030334262838, 0.9641692992212595], 
             UndirectedEdge[23, 129] -> 
             RGBColor[
              0.9919194200162629, 0.9837402828928126, 0.4795846817261888], 
             UndirectedEdge[101, 123] -> 
             RGBColor[
              0.2511378900976988, 0.38129222392755147`, 0.9376133033646252], 
             UndirectedEdge[122, 142] -> 
             RGBColor[
              0.8169136872538085, 0.8533228738878083, 0.7188155094580211], 
             UndirectedEdge[18, 174] -> 
             RGBColor[
              0.3498905326098686, 0.47747932616232985`, 0.9435156932352192], 
             UndirectedEdge[123, 135] -> 
             RGBColor[
              0.24185521523784892`, 0.3715355440942698, 0.9370846687638437], 
             UndirectedEdge[171, 178] -> 
             RGBColor[
              0.9084510251565888, 0.9296645818194842, 0.9851104569792455], 
             UndirectedEdge[81, 173] -> 
             RGBColor[
              0.7857376160501509, 0.8294745429756838, 0.8361707611374197], 
             UndirectedEdge[77, 102] -> 
             RGBColor[
              0.33711449602806876`, 0.4656411721496162, 0.9427298892598499], 
             UndirectedEdge[31, 171] -> 
             RGBColor[
              0.8624892635832501, 0.8931895434066397, 0.9867461899854671], 
             UndirectedEdge[109, 196] -> 
             RGBColor[
              0.4163582231260193, 0.5339138255247312, 0.9480649666862233], 
             UndirectedEdge[18, 153] -> 
             RGBColor[
              0.4521702655292919, 0.5624670752629113, 0.9510280595422927], 
             UndirectedEdge[97, 140] -> 
             RGBColor[
              0.29323255505263285`, 0.42553638575109687`, 0.9400105322603325],
              UndirectedEdge[116, 167] -> 
             RGBColor[
              0.652429277605832, 0.7235694154628036, 0.96891293133255], 
             UndirectedEdge[128, 190] -> 
             RGBColor[
              0.5346442883688116, 0.44885558317692076`, 0.5815609357144658], 
             UndirectedEdge[94, 126] -> 
             RGBColor[
              0.3626762195061153, 0.4884130176495661, 0.9443355349736948], 
             UndirectedEdge[41, 198] -> 
             RGBColor[
              0.6229374569936681, 0.7039435412138363, 0.9640225581060137], 
             UndirectedEdge[11, 77] -> 
             RGBColor[
              0.27312817427562797`, 0.40440540686310084`, 0.9388656175168482],
              UndirectedEdge[29, 122] -> 
             RGBColor[
              0.9932906731582525, 0.9894716805478189, 0.6138869514576812], 
             UndirectedEdge[84, 152] -> 
             RGBColor[
              0.2722580627952489, 0.4034908645289682, 0.9388160659552552], 
             UndirectedEdge[16, 64] -> 
             RGBColor[
              0.47278195616545676`, 0.5793252259853976, 0.9526162456912082], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.23972819328057, 0.3692999091561883, 0.9369635380100236], 
             UndirectedEdge[26, 121] -> 
             RGBColor[
              0.46953919243500225`, 0.5786867158238351, 0.9518099844973704], 
             UndirectedEdge[40, 74] -> 
             RGBColor[
              0.3971820108095485, 0.5168505289536836, 0.9468363149531384], 
             UndirectedEdge[78, 91] -> 
             RGBColor[
              0.8828910750951913, 0.909457394113841, 0.9886921329803882], 
             UndirectedEdge[139, 152] -> 
             RGBColor[
              0.26544888260262894`, 0.3963339844195651, 0.9384282932165648], 
             UndirectedEdge[40, 196] -> 
             RGBColor[
              0.49337743215923585`, 0.5995850516837207, 0.9532596252421102], 
             UndirectedEdge[6, 86] -> 
             RGBColor[
              0.3660057031110193, 0.4914374768784062, 0.9445425376494667], 
             UndirectedEdge[82, 180] -> 
             RGBColor[
              0.5213332999548519, 0.6173712520138998, 0.9573268973237518], 
             UndirectedEdge[44, 90] -> 
             RGBColor[
              0.33568645678912695`, 0.46283528505433924`, 0.9426963443190322],
              UndirectedEdge[4, 66] -> 
             RGBColor[
              0.7482528569010358, 0.8032600858342098, 0.9755425100215394], 
             UndirectedEdge[131, 143] -> 
             RGBColor[
              0.8469518489434293, 0.3190606581337521, 0.19091704430262602`], 
             UndirectedEdge[22, 144] -> 
             RGBColor[
              0.8484532037403029, 0.37343813304304, 0.19403214866276774`], 
             UndirectedEdge[35, 160] -> 
             RGBColor[
              0.6025425418355174, 0.6830045883363345, 0.9645167582458221], 
             UndirectedEdge[76, 174] -> 
             RGBColor[
              0.3288804579296929, 0.4562862523383694, 0.9422866189141441], 
             UndirectedEdge[85, 196] -> 
             RGBColor[
              0.42766426196123664`, 0.5437065481057618, 0.9487853774832657], 
             UndirectedEdge[6, 137] -> 
             RGBColor[
              0.2951194473890727, 0.4246251929966973, 0.9402239674768278], 
             UndirectedEdge[123, 177] -> 
             RGBColor[
              0.27201910823742403`, 0.40323970813810023`, 0.9388024578466887],
              UndirectedEdge[29, 113] -> 
             RGBColor[
              0.946972557498295, 0.8159080843147557, 0.4967685640741427], 
             UndirectedEdge[96, 174] -> 
             RGBColor[
              0.3438036499941711, 0.471971473383162, 0.943136472625332], 
             UndirectedEdge[74, 158] -> 
             RGBColor[
              0.2780238238703263, 0.40955104498924105`, 0.9391444175188017], 
             UndirectedEdge[46, 121] -> 
             RGBColor[
              0.570208977683367, 0.6619603615618923, 0.9593080859489944], 
             UndirectedEdge[32, 165] -> 
             RGBColor[
              0.2270272954930984, 0.35595046029812505`, 0.9362402406703216], 
             UndirectedEdge[32, 148] -> 
             RGBColor[
              0.219972379693155, 0.3485352964848875, 0.9358384736523275], 
             UndirectedEdge[27, 190] -> 
             RGBColor[
              0.22822804580985986`, 0.3572125250130086, 0.9363086216245102], 
             UndirectedEdge[100, 123] -> 
             RGBColor[
              0.23212285998297438`, 0.3613062216544334, 0.9365304255298079], 
             UndirectedEdge[45, 172] -> 
             RGBColor[
              0.9391683499060914, 0.7786563284917088, 0.4055000051193155], 
             UndirectedEdge[85, 99] -> 
             RGBColor[
              0.4621252914114974, 0.5716835642651686, 0.9514982759565006], 
             UndirectedEdge[106, 112] -> 
             RGBColor[
              0.2882506044320779, 0.42030003977498026`, 0.9397268175426274], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.8858165933462555, 0.5084410776664401, 0.4035840439814582], 
             UndirectedEdge[43, 197] -> 
             RGBColor[
              0.8665492485482925, 0.589132844492627, 0.463523131888269], 
             UndirectedEdge[26, 164] -> 
             RGBColor[
              0.34556297092325194`, 0.47243449330876475`, 0.9432874166489127],
              UndirectedEdge[100, 130] -> 
             RGBColor[
              0.2255191848288738, 0.3543653403702861, 0.9361543559990437], 
             UndirectedEdge[46, 196] -> 
             RGBColor[
              0.5464579464995596, 0.642678204475116, 0.9574383177713113], 
             UndirectedEdge[156, 181] -> 
             RGBColor[
              0.9525868256306654, 0.9637539256660137, 0.9508348285678401], 
             UndirectedEdge[62, 96] -> 
             RGBColor[
              0.33121568258703066`, 0.4610684087047351, 0.9423343784732514], 
             UndirectedEdge[54, 58] -> 
             RGBColor[
              0.2684799532608956, 0.3995198318623828, 0.9386009082064859], 
             UndirectedEdge[179, 183] -> 
             RGBColor[
              0.8425848980962714, 0.5878064340228173, 0.4637091200002722], 
             UndirectedEdge[65, 198] -> 
             RGBColor[
              0.809127231953634, 0.8516409245369697, 0.9813908857977319], 
             UndirectedEdge[4, 80] -> 
             RGBColor[
              0.7123913946505943, 0.7749007508046878, 0.972203429564615], 
             UndirectedEdge[159, 197] -> 
             RGBColor[
              0.844735305466295, 0.4214613190335854, 0.44263407535762334`], 
             UndirectedEdge[78, 136] -> 
             RGBColor[
              0.9179856014839756, 0.8091909436388446, 0.6189147464565151], 
             UndirectedEdge[153, 188] -> 
             RGBColor[
              0.6253120347428027, 0.7063539747569785, 0.9638795069847599], 
             UndirectedEdge[35, 174] -> 
             RGBColor[
              0.6098919568384804, 0.6893702822195625, 0.9649850564709783], 
             UndirectedEdge[82, 130] -> 
             RGBColor[
              0.27791125977355285`, 0.4085218087190706, 0.9391713605597196], 
             UndirectedEdge[124, 176] -> 
             RGBColor[
              0.29262570831728996`, 0.4248985513559462, 0.9399759732365041], 
             UndirectedEdge[6, 186] -> 
             RGBColor[
              0.3110411018029656, 0.4413598612768941, 0.941130682141722], 
             UndirectedEdge[1, 144] -> 
             RGBColor[
              0.8904481262845415, 0.5806212475838041, 0.23201956236806448`], 
             UndirectedEdge[43, 67] -> 
             RGBColor[
              0.8429788155468371, 0.3313595864958591, 0.18878986834626774`], 
             UndirectedEdge[24, 119] -> 
             RGBColor[
              0.37190268708568275`, 0.48151336908456555`, 0.9461947206260288],
              UndirectedEdge[93, 139] -> 
             RGBColor[
              0.2366529007205347, 0.36606758169078113`, 0.9367884046482173], 
             UndirectedEdge[38, 146] -> 
             RGBColor[
              0.8804514017100027, 0.8667932734581691, 0.6490490676279728], 
             UndirectedEdge[110, 127] -> 
             RGBColor[
              0.46330733319948464`, 0.5715960026043997, 0.9518806741110254], 
             UndirectedEdge[41, 81] -> 
             RGBColor[
              0.563023955866433, 0.6561272371693612, 0.9587424547119633], 
             UndirectedEdge[85, 194] -> 
             RGBColor[
              0.35434213313173446`, 0.48133507879042225`, 0.9437993452840767],
              UndirectedEdge[52, 70] -> 
             RGBColor[
              0.2130689137116028, 0.34127931603325223`, 0.9354453314774407], 
             UndirectedEdge[149, 170] -> 
             RGBColor[
              0.2079666859588458, 0.3359165511651807, 0.9351547671549908], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.30721338060851633`, 0.43871808624608816`, 0.9408621191648285],
              UndirectedEdge[92, 155] -> 
             RGBColor[
              0.23916918979888965`, 0.36871236105407446`, 0.9369317035887135],
              UndirectedEdge[57, 141] -> 
             RGBColor[
              0.35995825064388254`, 0.48619947750517123`, 0.9441571993258131],
              UndirectedEdge[149, 159] -> 
             RGBColor[
              0.6262856435829035, 0.23764894098782902`, 0.4250826867234967], 
             UndirectedEdge[142, 167] -> 
             RGBColor[
              0.7780824099898748, 0.8273108495391253, 0.9783266471470176], 
             UndirectedEdge[117, 173] -> 
             RGBColor[
              0.8870698836005233, 0.9096475021441977, 0.8455791000881498], 
             UndirectedEdge[99, 179] -> 
             RGBColor[
              0.6860146185776324, 0.753440204048828, 0.970158876487192], 
             UndirectedEdge[5, 11] -> 
             RGBColor[
              0.2640346736892395, 0.39484756118556874`, 0.938347756111082], 
             UndirectedEdge[29, 188] -> 
             RGBColor[
              0.8291485068413533, 0.8647956293451209, 0.8611126603250323], 
             UndirectedEdge[46, 178] -> 
             RGBColor[
              0.7700871696380653, 0.8204498262888431, 0.9719037985104857], 
             UndirectedEdge[101, 137] -> 
             RGBColor[
              0.25101571036429215`, 0.3811638052810985, 0.9376063454095565], 
             UndirectedEdge[3, 20] -> 
             RGBColor[
              0.24453230342971405`, 0.374349333521115, 0.9372371249759732], 
             UndirectedEdge[186, 199] -> 
             RGBColor[
              0.2771594494145085, 0.4086425326316706, 0.9390951926722704], 
             UndirectedEdge[156, 179] -> 
             RGBColor[
              0.864388741144453, 0.8948015330551333, 0.986901517469225], 
             UndirectedEdge[67, 87] -> 
             RGBColor[
              0.8747953206754928, 0.4237267463664781, 0.39303006082518865`], 
             UndirectedEdge[3, 10] -> 
             RGBColor[
              0.27648968445364525`, 0.4079385671922522, 0.9390570505485776], 
             UndirectedEdge[55, 185] -> 
             RGBColor[
              0.5609776882411449, 0.6497765761810184, 0.9606709927749343], 
             UndirectedEdge[5, 28] -> 
             RGBColor[
              0.28849193082278163`, 0.4205536891125868, 0.9397405607235676], 
             UndirectedEdge[37, 170] -> 
             RGBColor[
              0.18667955632742156`, 0.31354242824058126`, 0.9339424966139673],
              UndirectedEdge[49, 154] -> 
             RGBColor[
              0.8853342489533117, 0.5082416158642724, 0.4115777388398131], 
             UndirectedEdge[24, 89] -> 
             RGBColor[
              0.6289704896989408, 0.3791403610884968, 0.44405788636093535`], 
             UndirectedEdge[73, 115] -> 
             RGBColor[
              0.27934432739444803`, 0.41093897791785206`, 0.9392196182409905],
              UndirectedEdge[153, 174] -> 
             RGBColor[
              0.4836903414503127, 0.5897681807806197, 0.9530364909078715], 
             UndirectedEdge[119, 183] -> 
             RGBColor[
              0.7615664433424367, 0.5237229317976604, 0.4561749529436979], 
             UndirectedEdge[4, 168] -> 
             RGBColor[
              0.8717390399773187, 0.9006124860515876, 0.9850092222919777], 
             UndirectedEdge[144, 181] -> 
             RGBColor[
              0.8991205652819477, 0.619537019745982, 0.4376211825067001], 
             UndirectedEdge[53, 123] -> 
             RGBColor[
              0.2309218560021901, 0.36004389032257866`, 0.9364620301298284], 
             UndirectedEdge[110, 162] -> 
             RGBColor[
              0.7939641442587955, 0.8384977959010833, 0.9379384858342741], 
             UndirectedEdge[127, 176] -> 
             RGBColor[
              0.3078922888084153, 0.4397573979887158, 0.940888855185277], 
             UndirectedEdge[9, 102] -> 
             RGBColor[
              0.31720087863442126`, 0.44471069767262583`, 0.9415958382088386],
              UndirectedEdge[27, 195] -> 
             RGBColor[
              0.22783801477683696`, 0.3568025776679057, 0.9362864099341788], 
             UndirectedEdge[60, 130] -> 
             RGBColor[
              0.2455906790412874, 0.3754617533937681, 0.9372973979013259], 
             UndirectedEdge[89, 122] -> 
             RGBColor[
              0.9003075980023684, 0.6064437341064228, 0.29047713264699326`], 
             UndirectedEdge[5, 106] -> 
             RGBColor[
              0.2786294913144741, 0.4101876398745743, 0.9391789093837413], 
             UndirectedEdge[83, 199] -> 
             RGBColor[
              0.2640684264301843, 0.3948830374563491, 0.938349678279746], 
             UndirectedEdge[118, 125] -> 
             RGBColor[
              0.5461336776674304, 0.6195695759530597, 0.9625480754195246], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.2678093745072151, 0.3988150110751161, 0.9385627197384963], 
             UndirectedEdge[5, 112] -> 
             RGBColor[
              0.29182817897856506`, 0.4240602974546656, 0.9399305551205026], 
             UndirectedEdge[109, 146] -> 
             RGBColor[
              0.5668187671363596, 0.653709441066444, 0.9615199202813867], 
             UndirectedEdge[164, 184] -> 
             RGBColor[
              0.33292802569279517`, 0.46149073880095526`, 0.9424823291114712],
              UndirectedEdge[51, 164] -> 
             RGBColor[
              0.28843151316149873`, 0.42049018631987756`, 0.9397371200271375],
              UndirectedEdge[45, 168] -> 
             RGBColor[
              0.9114761724933723, 0.7607551980488345, 0.6070253886431892], 
             UndirectedEdge[148, 165] -> 
             RGBColor[
              0.2118480097340456, 0.33999606854305653`, 0.9353758028020844], 
             UndirectedEdge[166, 184] -> 
             RGBColor[
              0.3810287222999791, 0.5044496610209838, 0.9454997911478531], 
             UndirectedEdge[21, 132] -> 
             RGBColor[
              0.28420798371714023`, 0.41536166731241486`, 0.9395218357203131],
              UndirectedEdge[96, 157] -> 
             RGBColor[
              0.43194074873512733`, 0.5454775949392545, 0.9495354789637005], 
             UndirectedEdge[42, 102] -> 
             RGBColor[
              0.4476381958746549, 0.5602937273030086, 0.9502551687958871], 
             UndirectedEdge[117, 120] -> 
             RGBColor[
              0.8678835994276715, 0.8465560061197337, 0.6325812491960736], 
             UndirectedEdge[25, 129] -> 
             RGBColor[
              0.9845905971173718, 0.9596826071563495, 0.39463780893289646`], 
             UndirectedEdge[57, 90] -> 
             RGBColor[
              0.37426337273503046`, 0.49858985526418154`, 0.9450687090559382],
              UndirectedEdge[51, 184] -> 
             RGBColor[
              0.3266364768489205, 0.4548779220588064, 0.942124034712325], 
             UndirectedEdge[95, 103] -> 
             RGBColor[
              0.9027357759104662, 0.63208364163686, 0.26409899908324835`], 
             UndirectedEdge[47, 105] -> 
             RGBColor[
              0.3973660260121461, 0.5186002123597028, 0.9465407896938819], 
             UndirectedEdge[127, 177] -> 
             RGBColor[
              0.3075972075411117, 0.4394472488675467, 0.9408720507436377], 
             UndirectedEdge[73, 153] -> 
             RGBColor[
              0.4395524049734263, 0.5500947505807087, 0.9502769094004289], 
             UndirectedEdge[137, 199] -> 
             RGBColor[
              0.26123779500061556`, 0.39190786435147384`, 0.9381884780073761],
              UndirectedEdge[138, 185] -> 
             RGBColor[
              0.8411744991425061, 0.7559037234450623, 0.613171500043548], 
             UndirectedEdge[88, 136] -> 
             RGBColor[
              0.8101006391447247, 0.7240376246779792, 0.6083933870270145], 
             UndirectedEdge[55, 76] -> 
             RGBColor[
              0.31436618073050393`, 0.4437147149372155, 0.9413617820054831], 
             UndirectedEdge[135, 176] -> 
             RGBColor[
              0.26373796268785954`, 0.3945356991105544, 0.938330858858498], 
             UndirectedEdge[69, 123] -> 
             RGBColor[
              0.3260085199796461, 0.4514023478470298, 0.9421913646386602], 
             UndirectedEdge[2, 40] -> 
             RGBColor[
              0.43435111341602517`, 0.5495958945368197, 0.9491845094203311], 
             UndirectedEdge[105, 174] -> 
             RGBColor[
              0.3623104663482657, 0.48823684852250904`, 0.9443070804305137], 
             UndirectedEdge[89, 138] -> 
             RGBColor[
              0.8735867140642237, 0.5079729105623115, 0.2157827080806035], 
             UndirectedEdge[37, 128] -> 
             RGBColor[
              0.5402876317341454, 0.454787094862522, 0.5818823157705433], 
             UndirectedEdge[88, 153] -> 
             RGBColor[
              0.6490823398625842, 0.7249235177775619, 0.9662487088529688], 
             UndirectedEdge[113, 197] -> 
             RGBColor[
              0.8946095450697447, 0.7772196138099509, 0.6138944273650201], 
             UndirectedEdge[31, 178] -> 
             RGBColor[
              0.8964701273649321, 0.9201113391332241, 0.9839677082524034], 
             UndirectedEdge[82, 177] -> 
             RGBColor[
              0.3061026011103605, 0.4381526958983335, 0.9407768157434988], 
             UndirectedEdge[87, 108] -> 
             RGBColor[
              0.8846035797290293, 0.9091596462519311, 0.913892802031036], 
             UndirectedEdge[64, 86] -> 
             RGBColor[
              0.5072811113074129, 0.6092066601914048, 0.9548145013504485], 
             UndirectedEdge[116, 157] -> 
             RGBColor[
              0.47363379400133276`, 0.5818257161885222, 0.9521834927723848], 
             UndirectedEdge[120, 168] -> 
             RGBColor[
              0.9476806026150666, 0.909778086957847, 0.6376934323137864], 
             UndirectedEdge[18, 54] -> 
             RGBColor[
              0.295588460550005, 0.42712274502129255`, 0.9401772792428172], 
             UndirectedEdge[161, 176] -> 
             RGBColor[
              0.301427951999442, 0.43415026756037145`, 0.9404772479924501], 
             UndirectedEdge[168, 172] -> 
             RGBColor[
              0.9662845352880476, 0.9716239920088556, 0.7873059163017873], 
             UndirectedEdge[142, 157] -> 
             RGBColor[
              0.5992869263853755, 0.6855671502648439, 0.9615972085868523], 
             UndirectedEdge[121, 171] -> 
             RGBColor[
              0.7085728332018904, 0.7711751170925334, 0.9725147444177542], 
             UndirectedEdge[47, 94] -> 
             RGBColor[
              0.4348245890199799, 0.551044936914969, 0.9489276162054343], 
             UndirectedEdge[70, 93] -> 
             RGBColor[
              0.21891136206643785`, 0.34742009968680476`, 0.9357780502681208],
              UndirectedEdge[32, 163] -> 
             RGBColor[
              0.23408691252963393`, 0.3633705654090964, 0.9366422754167848], 
             UndirectedEdge[35, 142] -> 
             RGBColor[
              0.7396311759520104, 0.7966508792482756, 0.9746591341186641], 
             UndirectedEdge[12, 193] -> 
             RGBColor[
              0.4503245613855142, 0.5609229257874412, 0.950895392546576], 
             UndirectedEdge[35, 94] -> 
             RGBColor[
              0.6282503776636906, 0.7052714236172997, 0.9661548388122466], 
             UndirectedEdge[116, 174] -> 
             RGBColor[
              0.38549669526037655`, 0.5083195946324296, 0.9457844864340161], 
             UndirectedEdge[112, 140] -> 
             RGBColor[
              0.30347647446516857`, 0.4363033945556761, 0.9405939083163557], 
             UndirectedEdge[86, 176] -> 
             RGBColor[
              0.3430782654932676, 0.4702337224945253, 0.9431308745058982], 
             UndirectedEdge[61, 73] -> 
             RGBColor[
              0.28346587285648317`, 0.41527098351952657`, 0.9394543341577734],
              UndirectedEdge[33, 66] -> 
             RGBColor[
              0.5073300220022017, 0.606620425388813, 0.955851339828218], 
             UndirectedEdge[48, 106] -> 
             RGBColor[
              0.29607730783621694`, 0.42775376738301063`, 0.9402008266352594],
              UndirectedEdge[86, 199] -> 
             RGBColor[
              0.3321240507225622, 0.4587201482331828, 0.9425070481800151], 
             UndirectedEdge[10, 59] -> 
             RGBColor[
              0.3690604515059446, 0.4922869105332728, 0.9448029598331952], 
             UndirectedEdge[1, 113] -> 
             RGBColor[
              0.9293073420017215, 0.7556088200837405, 0.2655373341471002], 
             UndirectedEdge[125, 128] -> 
             RGBColor[
              0.5342706715319968, 0.44846288819275276`, 0.5815396587883258], 
             UndirectedEdge[53, 165] -> 
             RGBColor[
              0.21515759774182608`, 0.3434746553792333, 0.935564278943031], 
             UndirectedEdge[87, 143] -> 
             RGBColor[
              0.876523819007324, 0.43701274197773154`, 0.3946852727798099], 
             UndirectedEdge[61, 105] -> 
             RGBColor[
              0.30850366715074595`, 0.4384008305619083, 0.9409968714949317], 
             UndirectedEdge[29, 47] -> 
             RGBColor[
              0.7225823732127437, 0.7785731992059557, 0.8525033535115121], 
             UndirectedEdge[24, 27] -> 
             RGBColor[
              0.22783801619652955`, 0.3568025791600926, 0.9362864100150281], 
             UndirectedEdge[98, 117] -> 
             RGBColor[
              0.8762433687105626, 0.9035134810174441, 0.9541841801385145], 
             UndirectedEdge[1, 88] -> 
             RGBColor[
              0.8352535964645615, 0.823065908134689, 0.6322506322661987], 
             UndirectedEdge[190, 195] -> 
             RGBColor[
              0.1793170310330229, 0.30580394734510286`, 0.9335232116903315], 
             UndirectedEdge[4, 173] -> 
             RGBColor[
              0.9000135688899087, 0.9197592074679171, 0.8468692056721795], 
             UndirectedEdge[81, 164] -> 
             RGBColor[
              0.43552843920258344`, 0.5470178923073767, 0.9499428350575294], 
             UndirectedEdge[82, 123] -> 
             RGBColor[
              0.28451493492765345`, 0.4154626900032179, 0.9395474300904838], 
             UndirectedEdge[43, 87] -> 
             RGBColor[
              0.8995684415169597, 0.6141438088047649, 0.4167528293202155], 
             UndirectedEdge[38, 171] -> 
             RGBColor[
              0.919639217056486, 0.8978474840035989, 0.6528380765050477], 
             UndirectedEdge[46, 85] -> 
             RGBColor[
              0.4789487657995369, 0.5853416186622634, 0.9528226814867443], 
             UndirectedEdge[64, 69] -> 
             RGBColor[
              0.512094113243802, 0.613375440560194, 0.9551211815778647], 
             UndirectedEdge[60, 82] -> 
             RGBColor[
              0.2862778470683244, 0.4173156224381487, 0.9396478253289002], 
             UndirectedEdge[77, 189] -> 
             RGBColor[
              0.2658927211222934, 0.3968004868447199, 0.9384535691636595], 
             UndirectedEdge[101, 187] -> 
             RGBColor[
              0.2673357347336053, 0.3983171856425559, 0.9385357466540765], 
             UndirectedEdge[64, 161] -> 
             RGBColor[
              0.4656307978135873, 0.573123205257251, 0.9521608748370004], 
             UndirectedEdge[7, 160] -> 
             RGBColor[
              0.3585859521924276, 0.48501086156024664`, 0.9440697576819622], 
             UndirectedEdge[16, 83] -> 
             RGBColor[
              0.2894048145974629, 0.4201988877306557, 0.9398406710693048], 
             UndirectedEdge[13, 124] -> 
             RGBColor[
              0.3345268948480242, 0.4625364133999037, 0.9425966268829805], 
             UndirectedEdge[46, 171] -> 
             RGBColor[
              0.7361063058563833, 0.7935280305622586, 0.9746822802435494], 
             UndirectedEdge[1, 197] -> 
             RGBColor[
              0.9236147906417135, 0.8926515043216656, 0.6409097972593247], 
             UndirectedEdge[26, 80] -> 
             RGBColor[
              0.5081499735315052, 0.6100326873138424, 0.9548495666212384], 
             UndirectedEdge[23, 43] -> 
             RGBColor[
              0.9014366337014165, 0.6139370032291189, 0.31460356700739317`], 
             UndirectedEdge[13, 86] -> 
             RGBColor[
              0.38497945202400186`, 0.5078715845384828, 0.9457515281523746], 
             UndirectedEdge[31, 146] -> 
             RGBColor[
              0.8233014482367667, 0.8621353328612098, 0.9829571811083924], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.6527715209369094, 0.7286468226851102, 0.9660412183253722], 
             UndirectedEdge[124, 127] -> 
             RGBColor[
              0.30632106017096694`, 0.43810593706910805`, 0.9407993760387987],
              UndirectedEdge[60, 163] -> 
             RGBColor[
              0.24348971297155947`, 0.37325350484554143`, 0.9371777509917558],
              UndirectedEdge[4, 184] -> 
             RGBColor[
              0.5880093557297629, 0.671690292538539, 0.9630281942774768], 
             UndirectedEdge[144, 192] -> 
             RGBColor[
              0.8434502637599781, 0.33498334405198565`, 0.18924132768759622`],
              UndirectedEdge[38, 192] -> 
             RGBColor[
              0.8664820909126885, 0.38706872730476605`, 0.21540773809926206`],
              UndirectedEdge[49, 108] -> 
             RGBColor[
              0.8169025980884497, 0.455017381178201, 0.44687525682009266`], 
             UndirectedEdge[83, 165] -> 
             RGBColor[
              0.2373756354905151, 0.36682722175806165`, 0.9368295633241774], 
             UndirectedEdge[183, 192] -> 
             RGBColor[
              0.84571331956511, 0.349221020069408, 0.19128480591357822`], 
             UndirectedEdge[79, 159] -> 
             RGBColor[
              0.6164190249825052, 0.2272784992590594, 0.42452079739055826`], 
             UndirectedEdge[81, 166] -> 
             RGBColor[
              0.4836291358097673, 0.5899768145274054, 0.9529602970939112], 
             UndirectedEdge[118, 119] -> 
             RGBColor[
              0.7390929491372125, 0.7956716911845035, 0.9752408612005126], 
             UndirectedEdge[47, 153] -> 
             RGBColor[
              0.518745901114193, 0.6201315446178133, 0.9552702001712396], 
             UndirectedEdge[74, 184] -> 
             RGBColor[
              0.3369577946710508, 0.46572628149921225`, 0.9427118184932739], 
             UndirectedEdge[149, 190] -> 
             RGBColor[
              0.2066375350628038, 0.33451952930040635`, 0.9350790739777637], 
             UndirectedEdge[55, 139] -> 
             RGBColor[
              0.3007701310464627, 0.42942440467994913`, 0.9405875070895301], 
             UndirectedEdge[22, 138] -> 
             RGBColor[
              0.8672064638387251, 0.45893151148565325`, 0.20967297325920412`],
              UndirectedEdge[113, 144] -> 
             RGBColor[
              0.871111295903229, 0.5036666539093275, 0.21400931577186139`], 
             UndirectedEdge[80, 172] -> 
             RGBColor[
              0.8069368899613232, 0.8459122567619559, 0.7745001235744244], 
             UndirectedEdge[8, 156] -> 
             RGBColor[
              0.6845205611909437, 0.7511737984198581, 0.97104590551255], 
             UndirectedEdge[22, 118] -> 
             RGBColor[
              0.8673837475077953, 0.5395378434117971, 0.45731224525585845`], 
             UndirectedEdge[100, 163] -> 
             RGBColor[
              0.22341821875914586`, 0.35215709182205945`, 0.9360347090894736],
              UndirectedEdge[12, 154] -> 
             RGBColor[
              0.7852450872055535, 0.8309115028617888, 0.9166639457901922], 
             UndirectedEdge[67, 129] -> 
             RGBColor[
              0.8755570267580526, 0.42023027988113926`, 0.24893178910674738`],
              UndirectedEdge[49, 129] -> 
             RGBColor[
              0.8865782994288154, 0.5049446111811012, 0.25948577226301694`], 
             UndirectedEdge[127, 175] -> 
             RGBColor[
              0.32099276834406665`, 0.45244953519915593`, 0.9416743532494919],
              UndirectedEdge[30, 198] -> 
             RGBColor[
              0.7949540018905729, 0.840339575606766, 0.9800390304617252], 
             UndirectedEdge[5, 140] -> 
             RGBColor[
              0.2938553613475648, 0.42619099465527016`, 0.9400460001574695], 
             UndirectedEdge[147, 156] -> 
             RGBColor[
              0.7007698065694198, 0.7645047047938165, 0.9722866893066117], 
             UndirectedEdge[122, 159] -> 
             RGBColor[
              0.8794090834796054, 0.44580859369701076`, 0.2704646915384994], 
             UndirectedEdge[82, 110] -> 
             RGBColor[
              0.4618127267687334, 0.5703014496351865, 0.9517854391108865], 
             UndirectedEdge[83, 176] -> 
             RGBColor[
              0.2750226412008897, 0.4063966117176916, 0.9389735046056292], 
             UndirectedEdge[10, 77] -> 
             RGBColor[
              0.2948550356150111, 0.4272417156933656, 0.9401029301281152], 
             UndirectedEdge[104, 130] -> 
             RGBColor[
              0.2280794521267412, 0.3570563436306672, 0.9363001594340813], 
             UndirectedEdge[30, 66] -> 
             RGBColor[
              0.7926835884248224, 0.8385659113515402, 0.9798127368656795], 
             UndirectedEdge[85, 132] -> 
             RGBColor[
              0.3061847210307328, 0.43439681259051416`, 0.9409221739886695], 
             UndirectedEdge[24, 195] -> 
             RGBColor[
              0.1789270014196926, 0.30539400149218693`, 0.9335010000808495], 
             UndirectedEdge[50, 123] -> 
             RGBColor[
              0.24633186843467056`, 0.37624079044033565`, 0.9373396075407877],
              UndirectedEdge[42, 153] -> 
             RGBColor[
              0.5537057705483233, 0.648562314548655, 0.9580088930300842], 
             UndirectedEdge[127, 161] -> 
             RGBColor[
              0.31512330385311904`, 0.4473576532735334, 0.9413006507947447], 
             UndirectedEdge[7, 18] -> 
             RGBColor[
              0.33441529127436986`, 0.4640754499257662, 0.9425296245415398], 
             UndirectedEdge[65, 66] -> 
             RGBColor[
              0.8068568184878835, 0.8498672602817441, 0.9811645922016861], 
             UndirectedEdge[150, 152] -> 
             RGBColor[
              0.2823331640327409, 0.4140804347278859, 0.9393898280659538], 
             UndirectedEdge[25, 87] -> 
             RGBColor[
              0.9834480379935321, 0.9649273068843578, 0.6107852165105583], 
             UndirectedEdge[69, 82] -> 
             RGBColor[
              0.3600920128525825, 0.48631533560726303`, 0.9441657225354702], 
             UndirectedEdge[1, 159] -> 
             RGBColor[
              0.867867170087613, 0.40705412321611184`, 0.21039601321234347`], 
             UndirectedEdge[23, 131] -> 
             RGBColor[
              0.9464189057965813, 0.8120568568548516, 0.39007974658807487`], 
             UndirectedEdge[126, 160] -> 
             RGBColor[
              0.336968383677942, 0.466146182368601, 0.9426974544072704], 
             UndirectedEdge[67, 131] -> 
             RGBColor[
              0.8452233506115981, 0.3057746625224987, 0.18926183234800478`], 
             UndirectedEdge[142, 174] -> 
             RGBColor[
              0.5111498276444193, 0.6120610287087513, 0.9551982022484837], 
             UndirectedEdge[22, 122] -> 
             RGBColor[
              0.8939273477768698, 0.5574023350297646, 0.28436739782559384`], 
             UndirectedEdge[32, 176] -> 
             RGBColor[
              0.264674301203473, 0.39551985025775493`, 0.9383841819517735], 
             UndirectedEdge[47, 160] -> 
             RGBColor[
              0.4091167531918066, 0.528778101634004, 0.9472895356390099], 
             UndirectedEdge[79, 125] -> 
             RGBColor[
              0.19146399032539158`, 0.3185711717230839, 0.934214963052216], 
             UndirectedEdge[47, 111] -> 
             RGBColor[
              0.45600877007092583`, 0.5691987153613436, 0.9503313034018304], 
             UndirectedEdge[3, 186] -> 
             RGBColor[
              0.27284687806334806`, 0.40410974670878463`, 0.9388495981136993],
              UndirectedEdge[105, 160] -> 
             RGBColor[
              0.35496105134530265`, 0.4818711546392811, 0.9438387822053573], 
             UndirectedEdge[9, 189] -> 
             RGBColor[
              0.24597910372864595`, 0.37587001236772954`, 0.9373195181126482],
              UndirectedEdge[64, 175] -> 
             RGBColor[
              0.4715002623045349, 0.5782150871828736, 0.9525345772917476], 
             UndirectedEdge[100, 165] -> 
             RGBColor[
              0.21635860172261037`, 0.34473698671108804`, 0.9356326743430103],
              UndirectedEdge[101, 161] -> 
             RGBColor[
              0.28025165259241314`, 0.41189263422865363`, 0.9392712890687474],
              UndirectedEdge[123, 187] -> 
             RGBColor[
              0.26662928669062347`, 0.3975746639579891, 0.9384955154831248], 
             UndirectedEdge[90, 198] -> 
             RGBColor[
              0.542054826289809, 0.636504451768819, 0.9581455985091416], 
             UndirectedEdge[146, 171] -> 
             RGBColor[
              0.8352823460284233, 0.8716885755474699, 0.9840999298352342], 
             UndirectedEdge[62, 157] -> 
             RGBColor[
              0.4569597398647052, 0.567383488557704, 0.951121036787086], 
             UndirectedEdge[2, 164] -> 
             RGBColor[
              0.3359219335901057, 0.4640839113434194, 0.9426730982752791], 
             UndirectedEdge[94, 142] -> 
             RGBColor[
              0.5295082484696294, 0.6279621701064884, 0.9563679845897519], 
             UndirectedEdge[12, 175] -> 
             RGBColor[
              0.4521802655001208, 0.5625302434211127, 0.9510136363718239], 
             UndirectedEdge[23, 64] -> 
             RGBColor[
              0.8080908888760686, 0.8465853309633324, 0.7529704509533501], 
             UndirectedEdge[73, 160] -> 
             RGBColor[
              0.3299232570510399, 0.45874130759689935`, 0.9422962448681991], 
             UndirectedEdge[47, 142] -> 
             RGBColor[
              0.5462053873082997, 0.642424392545945, 0.9574319115118519], 
             UndirectedEdge[31, 120] -> 
             RGBColor[
              0.9036386065731989, 0.8747348065350462, 0.6360795030302686], 
             UndirectedEdge[9, 20] -> 
             RGBColor[
              0.24298403719743245`, 0.3727220075452381, 0.9371489535044994], 
             UndirectedEdge[174, 188] -> 
             RGBColor[
              0.5230323018233795, 0.6213662256563972, 0.9563671406776864], 
             UndirectedEdge[45, 173] -> 
             RGBColor[
              0.9397507014059623, 0.7799019194651641, 0.46888537202339087`], 
             UndirectedEdge[139, 191] -> 
             RGBColor[
              0.2646944952587164, 0.3955410754901928, 0.9383853319733451], 
             UndirectedEdge[24, 170] -> 
             RGBColor[
              0.18064618334875748`, 0.3072009707020641, 0.9335989049484079], 
             UndirectedEdge[118, 195] -> 
             RGBColor[
              0.5461172634712222, 0.6195523235921249, 0.9625471406553332], 
             UndirectedEdge[124, 137] -> 
             RGBColor[
              0.27062078113387267`, 0.4017699776932086, 0.938722825186781], 
             UndirectedEdge[28, 63] -> 
             RGBColor[
              0.3238146353715521, 0.45360214621203954`, 0.941901450034025], 
             UndirectedEdge[7, 94] -> 
             RGBColor[
              0.3842937880206009, 0.5072776968412117, 0.9457078382483868], 
             UndirectedEdge[37, 190] -> 
             RGBColor[
              0.18535040543137957`, 0.3121454063758069, 0.9338668034367403], 
             UndirectedEdge[31, 40] -> 
             RGBColor[
              0.6710448937244029, 0.7408816350846033, 0.9693608389875064], 
             UndirectedEdge[18, 73] -> 
             RGBColor[
              0.3057525961329822, 0.4378058959624189, 0.9407561117277767], 
             UndirectedEdge[170, 195] -> 
             RGBColor[
              0.1806461819290649, 0.30720096920987716`, 0.9335989048675586], 
             UndirectedEdge[62, 191] -> 
             RGBColor[
              0.3182327281368137, 0.4474225004107011, 0.9415950184238715], 
             UndirectedEdge[152, 194] -> 
             RGBColor[
              0.3151343711235495, 0.4448783558224487, 0.9413924862035001], 
             UndirectedEdge[24, 37] -> 
             RGBColor[
              0.18496037581804925`, 0.31173546052289103`, 0.9338445918272582],
              UndirectedEdge[90, 177] -> 
             RGBColor[
              0.3407778041727428, 0.4681866139645882, 0.9429862890205556], 
             UndirectedEdge[94, 188] -> 
             RGBColor[
              0.5413907226485897, 0.6372673670541342, 0.9575369230189545], 
             UndirectedEdge[103, 133] -> 
             RGBColor[
              0.8506697865477463, 0.3781326515142924, 0.19567142569650792`], 
             UndirectedEdge[38, 179] -> 
             RGBColor[
              0.8863710041657746, 0.8714177118872631, 0.6496390782789341], 
             UndirectedEdge[54, 116] -> 
             RGBColor[
              0.33119462320051296`, 0.4579630134913923, 0.9424460724416142], 
             UndirectedEdge[4, 198] -> 
             RGBColor[
              0.7505232703667862, 0.8050337500894356, 0.9757688036175852], 
             UndirectedEdge[31, 38] -> 
             RGBColor[
              0.9076583192648293, 0.8882942413173389, 0.6516953277782057], 
             UndirectedEdge[35, 47] -> 
             RGBColor[
              0.6449475165023608, 0.7197336460567563, 0.9672187657343465], 
             UndirectedEdge[132, 151] -> 
             RGBColor[
              0.3020454023564957, 0.43081154280309575`, 0.9406584202630028], 
             UndirectedEdge[124, 135] -> 
             RGBColor[
              0.26216673405041124`, 0.39288423819094664`, 0.9382413797120197],
              UndirectedEdge[32, 127] -> 
             RGBColor[
              0.2783696530571501, 0.40872723597091687`, 0.9392075847540681], 
             UndirectedEdge[187, 199] -> 
             RGBColor[
              0.27755781936992874`, 0.40906124471293126`, 0.9391178792518959],
              UndirectedEdge[2, 51] -> 
             RGBColor[
              0.329630384746231, 0.45747109460127056`, 0.9423148038761329], 
             UndirectedEdge[40, 117] -> 
             RGBColor[
              0.6352898865788753, 0.7127028346692909, 0.9658625851533114], 
             UndirectedEdge[9, 17] -> 
             RGBColor[
              0.2497025677004787, 0.37978360908337694`, 0.9375315638774728], 
             UndirectedEdge[33, 57] -> 
             RGBColor[
              0.3418089819131736, 0.4704794931394012, 0.9430007439710605], 
             UndirectedEdge[124, 175] -> 
             RGBColor[
              0.3057261878529413, 0.4375906885663863, 0.9407614713007191], 
             UndirectedEdge[8, 147] -> 
             RGBColor[
              0.4644466210649416, 0.5759586789636362, 0.9510205021407936], 
             UndirectedEdge[108, 110] -> 
             RGBColor[
              0.6931298062895987, 0.7596256615132471, 0.9704393557617335], 
             UndirectedEdge[68, 107] -> 
             RGBColor[
              0.7614279257189907, 0.8138406211600655, 0.9767792324528825], 
             UndirectedEdge[1, 138] -> 
             RGBColor[
              0.9355441317544622, 0.7814661810006367, 0.2706140846810541], 
             UndirectedEdge[94, 160] -> 
             RGBColor[
              0.39241961435313644`, 0.5143158791945474, 0.9462256087169099], 
             UndirectedEdge[138, 142] -> 
             RGBColor[
              0.7768323613465915, 0.7056166385716411, 0.6067738726084364], 
             UndirectedEdge[6, 175] -> 
             RGBColor[
              0.3302248541081414, 0.460445903869875, 0.9422626135907659], 
             UndirectedEdge[34, 104] -> 
             RGBColor[
              0.2353413665909268, 0.3646890761644966, 0.936713714719777], 
             UndirectedEdge[15, 106] -> 
             RGBColor[
              0.3000813368943679, 0.43122185610482894`, 0.9404559598262209], 
             UndirectedEdge[61, 94] -> 
             RGBColor[
              0.34596223015857974`, 0.47084555511717463`, 0.9433836980064841],
              UndirectedEdge[144, 159] -> 
             RGBColor[
              0.8452254175415028, 0.3486279538941323, 0.1909412169535338], 
             UndirectedEdge[83, 86] -> 
             RGBColor[
              0.32390396973941904`, 0.450080321936663, 0.9420389267285452], 
             UndirectedEdge[137, 176] -> 
             RGBColor[
              0.27219200977132096`, 0.4034214386128163, 0.9388123043332592], 
             UndirectedEdge[143, 159] -> 
             RGBColor[
              0.821413781916936, 0.16560128815844824`, 0.1681391677880527], 
             UndirectedEdge[24, 144] -> 
             RGBColor[
              0.6306529313731064, 0.3920723450467769, 0.44566899440816243`], 
             UndirectedEdge[76, 96] -> 
             RGBColor[
              0.2912734993929746, 0.42347729404149315`, 0.9398989669386781], 
             UndirectedEdge[98, 120] -> 
             RGBColor[
              0.9651286166376958, 0.922790787247423, 0.6081584957443529], 
             UndirectedEdge[98, 183] -> 
             RGBColor[
              0.897769781538639, 0.6310947741177858, 0.4464659481425095], 
             UndirectedEdge[55, 75] -> 
             RGBColor[
              0.3182717437982659, 0.44781970934843396`, 0.9415841980444295], 
             UndirectedEdge[35, 68] -> 
             RGBColor[
              0.8469990595612139, 0.880838075189855, 0.985268720497577], 
             UndirectedEdge[25, 43] -> 
             RGBColor[
              0.8965507517688224, 0.5978985527381435, 0.25797231847853164`], 
             UndirectedEdge[47, 174] -> 
             RGBColor[
              0.4164661681947697, 0.535143795517232, 0.9477578338641661], 
             UndirectedEdge[29, 88] -> 
             RGBColor[
              0.8529188119611348, 0.8833651723657042, 0.8634818621932413], 
             UndirectedEdge[17, 140] -> 
             RGBColor[
              0.27217097999434126`, 0.4033993349838457, 0.9388111067185709], 
             UndirectedEdge[41, 90] -> 
             RGBColor[
              0.46883146462921355`, 0.577882603340978, 0.9518176941382794], 
             UndirectedEdge[151, 196] -> 
             RGBColor[
              0.4235249432869995, 0.5401212783183434, 0.9485216237575993], 
             UndirectedEdge[88, 94] -> 
             RGBColor[
              0.5651610277683712, 0.6558369100747177, 0.9599061248871635], 
             UndirectedEdge[57, 198] -> 
             RGBColor[
              0.528369365099485, 0.6246507931370399, 0.9572735730236723], 
             UndirectedEdge[71, 164] -> 
             RGBColor[
              0.2925031947568016, 0.42476978183606456`, 0.9399689962704769], 
             UndirectedEdge[95, 154] -> 
             RGBColor[
              0.9830766756699849, 0.9658160132096346, 0.6241438116222372], 
             UndirectedEdge[69, 90] -> 
             RGBColor[
              0.3947672159149649, 0.5163492536735178, 0.946375195812527], 
             UndirectedEdge[175, 176] -> 
             RGBColor[
              0.30729741649038966`, 0.43924214948599405`, 0.9408509504471974],
              UndirectedEdge[58, 115] -> 
             RGBColor[
              0.2648536806612042, 0.3957083894411449, 0.9383943973465231], 
             UndirectedEdge[42, 88] -> 
             RGBColor[
              0.6168180360411716, 0.6987299024450158, 0.9637087446681081], 
             UndirectedEdge[72, 134] -> 
             RGBColor[
              0.2403643210352666, 0.36996851975920364`, 0.9369997645445869], 
             UndirectedEdge[25, 49] -> 
             RGBColor[
              0.8827989035981182, 0.49219582159981873`, 0.2448035331397743], 
             UndirectedEdge[23, 103] -> 
             RGBColor[
              0.9073868883324812, 0.6473301594421497, 0.31981821239601227`], 
             UndirectedEdge[79, 192] -> 
             RGBColor[
              0.6128687174194557, 0.19998927957476603`, 0.421121018858683], 
             UndirectedEdge[89, 170] -> 
             RGBColor[
              0.6301166100385224, 0.38034500623362366`, 0.4441231562187414], 
             UndirectedEdge[41, 57] -> 
             RGBColor[
              0.4551460034388895, 0.5660289447091988, 0.9509456686528102], 
             UndirectedEdge[10, 14] -> 
             RGBColor[
              0.35304438919669967`, 0.4784146023517027, 0.943782430505298], 
             UndirectedEdge[6, 59] -> 
             RGBColor[
              0.39442835550292343`, 0.516055749816227, 0.9463536039267142], 
             UndirectedEdge[120, 183] -> 
             RGBColor[
              0.8921966020167115, 0.5931231241859789, 0.2320639941808822], 
             UndirectedEdge[8, 194] -> 
             RGBColor[
              0.3983632803443602, 0.5194639839388066, 0.9466043338580932], 
             UndirectedEdge[63, 106] -> 
             RGBColor[
              0.3139521958632445, 0.44323609697402705`, 0.9413397986941987], 
             UndirectedEdge[129, 131] -> 
             RGBColor[
              0.9447591766437358, 0.8071223654903125, 0.32715623247964654`], 
             UndirectedEdge[22, 38] -> 
             RGBColor[
              0.8845506627730023, 0.5259516883218133, 0.23271022291823168`], 
             UndirectedEdge[38, 117] -> 
             RGBColor[
              0.8719033121193018, 0.8601154409020264, 0.6481970739440106], 
             UndirectedEdge[136, 159] -> 
             RGBColor[
              0.8510985318743886, 0.34103526757830527`, 0.19449118305288732`],
              UndirectedEdge[158, 166] -> 
             RGBColor[
              0.3220947514992546, 0.4482744245110126, 0.9419323901733808], 
             UndirectedEdge[75, 96] -> 
             RGBColor[
              0.29517906246073655`, 0.4275822884527116, 0.9401213829776245], 
             UndirectedEdge[118, 170] -> 
             RGBColor[
              0.5478364454002871, 0.6213592928020021, 0.9626450455228917], 
             UndirectedEdge[7, 58] -> 
             RGBColor[
              0.3073067839852605, 0.4364725367668565, 0.9409532535052085], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.7375823865275546, 0.7949242332798678, 0.9744789772559258], 
             UndirectedEdge[65, 180] -> 
             RGBColor[
              0.8230809086810591, 0.8625416428483053, 0.9827816578893989], 
             UndirectedEdge[151, 171] -> 
             RGBColor[
              0.6131733026438233, 0.690971104405486, 0.9657655862298374], 
             UndirectedEdge[37, 118] -> 
             RGBColor[
              0.5521506378695789, 0.625893782622829, 0.962890732401742], 
             UndirectedEdge[7, 47] -> 
             RGBColor[
              0.40099092685927107`, 0.5217399192806683, 0.9467717651704868], 
             UndirectedEdge[46, 99] -> 
             RGBColor[
              0.5809189759498203, 0.6706552206345228, 0.960151216244546], 
             UndirectedEdge[195, 197] -> 
             RGBColor[
              0.5339219968548683, 0.6098281490239381, 0.9613839452386224], 
             UndirectedEdge[5, 63] -> 
             RGBColor[
              0.3175297704097317, 0.4469963546537124, 0.9415435362720739], 
             UndirectedEdge[11, 63] -> 
             RGBColor[
              0.29935737823800995`, 0.4278960182850215, 0.9405086454215394], 
             UndirectedEdge[10, 193] -> 
             RGBColor[
              0.30300124599655587`, 0.4350697469532493, 0.9405937256719987], 
             UndirectedEdge[99, 147] -> 
             RGBColor[
              0.5223956840025993, 0.6231433757875112, 0.9555440483245787], 
             UndirectedEdge[9, 77] -> 
             RGBColor[
              0.2804804496400908, 0.41213311443233347`, 0.9392843187221377], 
             UndirectedEdge[43, 103] -> 
             RGBColor[
              0.8583405032831029, 0.4432646958215179, 0.2032585752880907], 
             UndirectedEdge[54, 174] -> 
             RGBColor[
              0.3271085364710258, 0.454423850539001, 0.942185710608396], 
             UndirectedEdge[149, 197] -> 
             RGBColor[
              0.5612425008846491, 0.6385437309792414, 0.9629398075260546], 
             UndirectedEdge[87, 180] -> 
             RGBColor[
              0.8560213723624259, 0.8868310086243191, 0.9110439947166469], 
             UndirectedEdge[134, 191] -> 
             RGBColor[
              0.25554145744836393`, 0.3859206524153965, 0.9378640800107516], 
             UndirectedEdge[65, 131] -> 
             RGBColor[
              0.9106761538385292, 0.7880776994423069, 0.6150413032300603], 
             UndirectedEdge[107, 147] -> 
             RGBColor[
              0.5739634519525214, 0.664627405018551, 0.9598641490933124], 
             UndirectedEdge[50, 82] -> 
             RGBColor[
              0.28041536130760697`, 0.41115377820056886`, 0.9393139654375977],
              UndirectedEdge[30, 162] -> 
             RGBColor[
              0.9383242239537981, 0.9524410659335498, 0.9517777399403218], 
             UndirectedEdge[51, 74] -> 
             RGBColor[
              0.29246128213975436`, 0.4247257290181345, 0.9399666094089402], 
             UndirectedEdge[12, 161] -> 
             RGBColor[
              0.4463108010091732, 0.5574383614954901, 0.9506399339170767], 
             UndirectedEdge[78, 113] -> 
             RGBColor[
              0.9141333132318434, 0.7927873365838396, 0.6157566218013946], 
             UndirectedEdge[131, 133] -> 
             RGBColor[
              0.8487047833512873, 0.33253448013330367`, 0.19259565627124703`],
              UndirectedEdge[35, 188] -> 
             RGBColor[
              0.7515136501309705, 0.8059560761959215, 0.9758280725478667], 
             UndirectedEdge[181, 185] -> 
             RGBColor[
              0.8769516134578437, 0.9038519112831478, 0.9435125496118522], 
             UndirectedEdge[111, 188] -> 
             RGBColor[
              0.5625749036995356, 0.6554211455005088, 0.9589406102153506], 
             UndirectedEdge[41, 184] -> 
             RGBColor[
              0.46042354235664473`, 0.5706000836629397, 0.9512819487659052], 
             UndirectedEdge[135, 187] -> 
             RGBColor[
              0.2580530598737554, 0.38856050580927426`, 0.9380071120532948], 
             UndirectedEdge[51, 71] -> 
             RGBColor[
              0.2862116459129269, 0.41815696509391576`, 0.9396107018713307], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.2532145568819805, 0.3834749323861105, 0.937731566465837], 
             UndirectedEdge[26, 158] -> 
             RGBColor[
              0.3248339638099492, 0.45064699253772245`, 0.9421069303596279], 
             UndirectedEdge[101, 199] -> 
             RGBColor[
              0.262066422777004, 0.3927788046824936, 0.9382356671333965], 
             UndirectedEdge[84, 194] -> 
             RGBColor[
              0.30565287667395435`, 0.4349127039944547, 0.9408525291212098], 
             UndirectedEdge[6, 176] -> 
             RGBColor[
              0.31712437457249, 0.4477537666594349, 0.9414771155265509], 
             UndirectedEdge[18, 116] -> 
             RGBColor[
              0.35397661933935576`, 0.48101848911472117`, 0.9437760550684375],
              UndirectedEdge[98, 179] -> 
             RGBColor[
              0.8907110607570355, 0.9148157520026807, 0.9556261844734377], 
             UndirectedEdge[116, 142] -> 
             RGBColor[
              0.5152359143739065, 0.6156001916611427, 0.9554585640817019], 
             UndirectedEdge[77, 112] -> 
             RGBColor[
              0.3009216795649535, 0.4336181431321977, 0.9404484165262689], 
             UndirectedEdge[56, 190] -> 
             RGBColor[
              0.1793170310330229, 0.30580394734510286`, 0.9335232116903315], 
             UndirectedEdge[76, 126] -> 
             RGBColor[
              0.2917876480797086, 0.4240176969101601, 0.9399282469457728], 
             UndirectedEdge[168, 173] -> 
             RGBColor[
              0.9668668867879184, 0.9728695829823109, 0.8506912832058626], 
             UndirectedEdge[158, 164] -> 
             RGBColor[
              0.27399405489207074`, 0.4053155022909841, 0.9389149281369991], 
             UndirectedEdge[46, 146] -> 
             RGBColor[
              0.6969184905099, 0.7624738200168288, 0.9708932713664746], 
             UndirectedEdge[23, 25] -> 
             RGBColor[
              0.9862503262702172, 0.9646170985208886, 0.4575613230413248], 
             UndirectedEdge[9, 28] -> 
             RGBColor[
              0.27767181401552266`, 0.4091810603131285, 0.9391243710783226], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.9239792736477469, 0.9412455241190165, 0.9588251826995514], 
             UndirectedEdge[103, 129] -> 
             RGBColor[
              0.9062804022305841, 0.6440404985324568, 0.2778692029903933], 
             UndirectedEdge[5, 48] -> 
             RGBColor[
              0.2996548823827041, 0.431514025062696, 0.9404045642131346], 
             UndirectedEdge[36, 169] -> 
             RGBColor[
              0.260181316759984, 0.39079743873598083`, 0.9381283131344916], 
             UndirectedEdge[159, 170] -> 
             RGBColor[
              0.6092180955157596, 0.21970986582421148`, 0.4241107151102475], 
             UndirectedEdge[86, 175] -> 
             RGBColor[
              0.356178745028919, 0.4829258597049654, 0.9439163725701132], 
             UndirectedEdge[9, 97] -> 
             RGBColor[
              0.2707641427587703, 0.4019206598506281, 0.9387309894192344], 
             UndirectedEdge[7, 88] -> 
             RGBColor[
              0.5313273656076622, 0.6265318924404168, 0.9577502738522159], 
             UndirectedEdge[5, 77] -> 
             RGBColor[
              0.2913005664473497, 0.42350574323179174`, 0.9399005083673827], 
             UndirectedEdge[103, 131] -> 
             RGBColor[
              0.8759467260841297, 0.5295848811738163, 0.2181992462316507], 
             UndirectedEdge[15, 193] -> 
             RGBColor[
              0.32089862240878825`, 0.45236799072193, 0.941668354353746], 
             UndirectedEdge[167, 181] -> 
             RGBColor[
              0.9498028388938546, 0.9615340502113876, 0.9505692894275887], 
             UndirectedEdge[99, 146] -> 
             RGBColor[
              0.6800950161218604, 0.7488157656197341, 0.9695688658362309], 
             UndirectedEdge[163, 177] -> 
             RGBColor[
              0.2633144670135955, 0.39409057830572625`, 0.9383067414063544], 
             UndirectedEdge[76, 116] -> 
             RGBColor[
              0.3329665446591801, 0.4598254152907607, 0.9425469807473624], 
             UndirectedEdge[15, 59] -> 
             RGBColor[
              0.38695782791817696`, 0.5095851543019536, 0.9458775885149424], 
             UndirectedEdge[36, 151] -> 
             RGBColor[
              0.2998281417164218, 0.4284810612879339, 0.9405321505496939], 
             UndirectedEdge[38, 98] -> 
             RGBColor[
              0.9691483293293262, 0.9363502220297157, 0.6237743204922899], 
             UndirectedEdge[70, 139] -> 
             RGBColor[
              0.23141666930631707`, 0.36056397047819155`, 0.9364902090154877],
              UndirectedEdge[56, 195] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[66, 168] -> 
             RGBColor[
              0.8151061747990456, 0.8563704613486036, 0.9793645875552226], 
             UndirectedEdge[6, 161] -> 
             RGBColor[
              0.32435538961719373`, 0.45535402194425245`, 0.9418889111360187],
              UndirectedEdge[56, 118] -> 
             RGBColor[
              0.5461172634712221, 0.619552323592125, 0.9625471406553332], 
             UndirectedEdge[46, 117] -> 
             RGBColor[
              0.6883704009191991, 0.7557959874606861, 0.9700412776825125], 
             UndirectedEdge[79, 89] -> 
             RGBColor[
              0.637317539505268, 0.3879136396684716, 0.4445332384990521], 
             UndirectedEdge[102, 140] -> 
             RGBColor[
              0.3396692909282838, 0.4683264235730946, 0.9428753810499368], 
             UndirectedEdge[32, 130] -> 
             RGBColor[
              0.23618787859936186`, 0.36557881395732306`, 0.936761922326355], 
             UndirectedEdge[105, 126] -> 
             RGBColor[
              0.3252176564982815, 0.45596829309429976`, 0.9419487084621424], 
             UndirectedEdge[86, 124] -> 
             RGBColor[
              0.3415070368558193, 0.46858226157491756`, 0.94304139535942], 
             UndirectedEdge[41, 168] -> 
             RGBColor[
              0.7441532266042006, 0.7995222771759883, 0.9732629767804062], 
             UndirectedEdge[43, 143] -> 
             RGBColor[
              0.8438430647127526, 0.3380025843014858, 0.18961747432357834`], 
             UndirectedEdge[56, 197] -> 
             RGBColor[
              0.5339219968548683, 0.6098281490239381, 0.9613839452386224], 
             UndirectedEdge[47, 73] -> 
             RGBColor[
              0.3723282317178833, 0.495470365317321, 0.9449982523567235], 
             UndirectedEdge[23, 108] -> 
             RGBColor[
              0.8874058680057144, 0.9088494378884622, 0.7606689085618024], 
             UndirectedEdge[97, 155] -> 
             RGBColor[
              0.2652922598561954, 0.3961693639826077, 0.9384193737828581], 
             UndirectedEdge[86, 161] -> 
             RGBColor[
              0.35030928053797133`, 0.47783397777934283`, 0.943542670115366], 
             UndirectedEdge[88, 188] -> 
             RGBColor[
              0.688424300235651, 0.7565215626533395, 0.9695793586227837], 
             UndirectedEdge[136, 197] -> 
             RGBColor[
              0.8984618333218767, 0.7936232208649558, 0.6170525520201404], 
             UndirectedEdge[65, 69] -> 
             RGBColor[
              0.6618396215787897, 0.7314857264416685, 0.9696204831011173], 
             UndirectedEdge[23, 67] -> 
             RGBColor[
              0.8766635128599496, 0.4235199407908321, 0.29088079851236637`], 
             UndirectedEdge[31, 121] -> 
             RGBColor[
              0.6965919354102337, 0.7616218744062735, 0.9713719956909121], 
             UndirectedEdge[52, 145] -> 
             RGBColor[
              0.21010927874609994`, 0.3381685520328137, 0.9352767846445429], 
             UndirectedEdge[12, 87] -> 
             RGBColor[
              0.7859686037949694, 0.8312106955650405, 0.9046734035026598], 
             UndirectedEdge[128, 192] -> 
             RGBColor[
              0.8414065048905258, 0.286583757221212, 0.1860041493494229], 
             UndirectedEdge[78, 95] -> 
             RGBColor[
              0.9537951709684989, 0.944166482218568, 0.6841709176231596], 
             UndirectedEdge[123, 165] -> 
             RGBColor[
              0.23466718379435303`, 0.36398046729963934`, 0.9366753210068761],
              UndirectedEdge[24, 56] -> 
             RGBColor[
              0.1789270014196926, 0.30539400149218693`, 0.9335010000808495], 
             UndirectedEdge[50, 177] -> 
             RGBColor[
              0.2679195346173776, 0.39893079633545114`, 0.9385689931938027], 
             UndirectedEdge[18, 58] -> 
             RGBColor[
              0.2912619493997384, 0.4225753074857117, 0.9399308908333093], 
             UndirectedEdge[96, 182] -> 
             RGBColor[
              0.2856601600419676, 0.4175773184773137, 0.9395792955668297], 
             UndirectedEdge[49, 131] -> 
             RGBColor[
              0.8562446232823608, 0.3904889938224607, 0.19981581550427432`], 
             UndirectedEdge[28, 106] -> 
             RGBColor[
              0.28491435627629447`, 0.41679343143290143`, 0.9395368231456924],
              UndirectedEdge[57, 81] -> 
             RGBColor[
              0.4684558639722499, 0.5768344890925647, 0.951993469629622], 
             UndirectedEdge[7, 115] -> 
             RGBColor[
              0.3080070225358357, 0.4372085318811994, 0.9409931310547537], 
             UndirectedEdge[54, 94] -> 
             RGBColor[
              0.3454669572962359, 0.47032499193673805`, 0.9433554929496641], 
             UndirectedEdge[138, 181] -> 
             RGBColor[
              0.9485527902505714, 0.8398398392439036, 0.5790165148890076], 
             UndirectedEdge[55, 182] -> 
             RGBColor[
              0.30875284137949693`, 0.43781473937303605`, 0.9410421106336347],
              UndirectedEdge[17, 77] -> 
             RGBColor[
              0.26961618509412616`, 0.4007140835603673, 0.9386656149284841], 
             UndirectedEdge[144, 149] -> 
             RGBColor[
              0.648866599779832, 0.4112160653555213, 0.44670623587921776`], 
             UndirectedEdge[68, 179] -> 
             RGBColor[
              0.8317792747849202, 0.8687996297404257, 0.9837911974570385], 
             UndirectedEdge[103, 143] -> 
             RGBColor[
              0.8497933193438173, 0.37139574051451657`, 0.1948321197121974], 
             UndirectedEdge[80, 173] -> 
             RGBColor[
              0.807519241461194, 0.8471578477354111, 0.8378854904784999], 
             UndirectedEdge[161, 199] -> 
             RGBColor[
              0.2904737372287366, 0.422636693299029, 0.9398534216665669], 
             UndirectedEdge[43, 133] -> 
             RGBColor[
              0.8447195319166816, 0.3447394953012616, 0.19045678030788885`], 
             UndirectedEdge[6, 193] -> 
             RGBColor[
              0.3283691499935347, 0.4588385862362035, 0.9421443697655179], 
             UndirectedEdge[181, 188] -> 
             RGBColor[
              0.8244919498408892, 0.8628700233573725, 0.9382838606059434], 
             UndirectedEdge[120, 173] -> 
             RGBColor[
              0.9759551315276564, 0.9289248083741766, 0.49955341569398815`], 
             UndirectedEdge[2, 158] -> 
             RGBColor[
              0.31519292647680297`, 0.4422964105723771, 0.9414926119859944], 
             UndirectedEdge[95, 143] -> 
             RGBColor[
              0.8737408987697657, 0.4215594185967958, 0.23681679715422363`], 
             UndirectedEdge[4, 172] -> 
             RGBColor[
              0.8994312173900378, 0.9185136164944618, 0.783483838768104], 
             UndirectedEdge[89, 113] -> 
             RGBColor[
              0.8694288542290634, 0.4907346699510474, 0.21239820772463422`], 
             UndirectedEdge[34, 90] -> 
             RGBColor[
              0.31984837730012083`, 0.4461884593191548, 0.9417943891224722], 
             UndirectedEdge[28, 48] -> 
             RGBColor[
              0.30593974734452445`, 0.4381198166210231, 0.9407624779750857], 
             UndirectedEdge[5, 189] -> 
             RGBColor[
              0.2567992205359049, 0.38724264116718776`, 0.9379357077578933], 
             UndirectedEdge[8, 55] -> 
             RGBColor[
              0.4002897149094885, 0.5211325647337041, 0.9467270845651039], 
             UndirectedEdge[29, 138] -> 
             RGBColor[
              0.9532093472510355, 0.8417654452316519, 0.5018453146080967], 
             UndirectedEdge[8, 68] -> 
             RGBColor[
              0.6519110948314109, 0.7251718951051506, 0.9679355855003635], 
             UndirectedEdge[176, 187] -> 
             RGBColor[
              0.2885120341406341, 0.42057481897427373`, 0.9397417055777791], 
             UndirectedEdge[65, 133] -> 
             RGBColor[
              0.8563164442942707, 0.43429365345994053`, 0.44418899353026553`],
              UndirectedEdge[68, 147] -> 
             RGBColor[
              0.668160340209887, 0.7385028014791089, 0.9691763692944251], 
             UndirectedEdge[89, 192] -> 
             RGBColor[
              0.8417678220858125, 0.32205136009370555`, 0.18763021964036905`],
              UndirectedEdge[2, 74] -> 
             RGBColor[
              0.3399517025683613, 0.46831945404167635`, 0.9429025876570818], 
             UndirectedEdge[156, 185] -> 
             RGBColor[
              0.8452085345226001, 0.8798178098671724, 0.9849898137223804], 
             UndirectedEdge[126, 182] -> 
             RGBColor[
              0.2861743087287016, 0.41811772134598074`, 0.9396085755739244], 
             UndirectedEdge[18, 188] -> 
             RGBColor[
              0.49151222590235866`, 0.5940651201386887, 0.9543587093121076], 
             UndirectedEdge[68, 156] -> 
             RGBColor[
              0.8882342803358891, 0.9137179209353309, 0.9892017726661817], 
             UndirectedEdge[29, 181] -> 
             RGBColor[
              0.988986461566373, 0.9897136330697374, 0.8321863641764009], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.9759778030702638, 0.9313399748264705, 0.5237839339684474], 
             UndirectedEdge[30, 180] -> 
             RGBColor[
              0.8089076786179981, 0.8512402939181014, 0.9814298025533923], 
             UndirectedEdge[31, 196] -> 
             RGBColor[
              0.6728409042264264, 0.742339717319497, 0.969502227513229], 
             UndirectedEdge[193, 199] -> 
             RGBColor[
              0.2944874976050776, 0.4261212575909801, 0.9401088802960662], 
             UndirectedEdge[30, 110] -> 
             RGBColor[
              0.7493871054318795, 0.8041704915393881, 0.9758883443405271], 
             UndirectedEdge[12, 59] -> 
             RGBColor[
              0.516383766894903, 0.6181400893674647, 0.9551046267077723], 
             UndirectedEdge[38, 156] -> 
             RGBColor[
              0.9428260097167436, 0.9163360030821683, 0.6550496534880772], 
             UndirectedEdge[72, 152] -> 
             RGBColor[
              0.2658080334878341, 0.396711474771397, 0.9384487463281612], 
             UndirectedEdge[37, 79] -> 
             RGBColor[
              0.19748095052754017`, 0.3248953783928531, 0.9345576200344334], 
             UndirectedEdge[170, 197] -> 
             RGBColor[
              0.5356411787839332, 0.6116351182338152, 0.9614818501061808], 
             UndirectedEdge[86, 127] -> 
             RGBColor[
              0.3567736173469446, 0.48344110820768715`, 0.9439542773081928], 
             UndirectedEdge[69, 127] -> 
             RGBColor[
              0.3615866192833338, 0.48760988857647636`, 0.944260957535609], 
             UndirectedEdge[58, 61] -> 
             RGBColor[
              0.26897522612323943`, 0.4000403950428194, 0.9386291132633059], 
             UndirectedEdge[11, 17] -> 
             RGBColor[
              0.24235029233601593`, 0.3720559015141443, 0.9371128626721834], 
             UndirectedEdge[11, 15] -> 
             RGBColor[
              0.28548651926913327`, 0.4158817774158234, 0.9396248065535615], 
             UndirectedEdge[111, 157] -> 
             RGBColor[
              0.5090903091480017, 0.6123414730802424, 0.9544966004768307], 
             UndirectedEdge[75, 191] -> 
             RGBColor[
              0.2821961080105196, 0.4139363801586776, 0.9393820229282445], 
             UndirectedEdge[98, 156] -> 
             RGBColor[
              0.9471660663080045, 0.9597340431975859, 0.961036759682581], 
             UndirectedEdge[28, 140] -> 
             RGBColor[
              0.3001402263093852, 0.4327967862135973, 0.9404039139194207], 
             UndirectedEdge[105, 157] -> 
             RGBColor[
              0.4504475650892219, 0.5617429700786016, 0.9507060867688824], 
             UndirectedEdge[3, 15] -> 
             RGBColor[
              0.2943870608658776, 0.4252368109609329, 0.9401316792303248], 
             UndirectedEdge[55, 96] -> 
             RGBColor[
              0.32928937279498216`, 0.459399935982008, 0.942211635716671], 
             UndirectedEdge[6, 64] -> 
             RGBColor[
              0.4813272203866353, 0.5867267043563145, 0.9531607423711013], 
             UndirectedEdge[70, 134] -> 
             RGBColor[
              0.2222636314959646, 0.3509435474033953, 0.9359689570528942], 
             UndirectedEdge[106, 140] -> 
             RGBColor[
              0.29027778680107763`, 0.4224307369755848, 0.9398422625795944], 
             UndirectedEdge[64, 154] -> 
             RGBColor[
              0.8045650840099676, 0.8465963466235498, 0.9181848867101159], 
             UndirectedEdge[8, 157] -> 
             RGBColor[
              0.5029410908496337, 0.6072102236909507, 0.9540509278121335], 
             UndirectedEdge[83, 124] -> 
             RGBColor[
              0.2734514125634414, 0.4047451507980839, 0.9388840254591511], 
             UndirectedEdge[22, 128] -> 
             RGBColor[
              0.8594750767508397, 0.42546671823825916`, 0.20330663416839254`],
              UndirectedEdge[83, 135] -> 
             RGBColor[
              0.244563666934011, 0.3743822985526921, 0.9372389110811449], 
             UndirectedEdge[62, 68] -> 
             RGBColor[
              0.6059297438464823, 0.6853451599719039, 0.965005694475316], 
             UndirectedEdge[105, 116] -> 
             RGBColor[
              0.36639655307775293`, 0.49177601147490035`, 0.944567442263732], 
             UndirectedEdge[93, 145] -> 
             RGBColor[
              0.21595172710093502`, 0.34430933568636624`, 0.935609503435223], 
             UndirectedEdge[128, 195] -> 
             RGBColor[
              0.5342542573357888, 0.44844563583181796`, 0.5815387240241343], 
             UndirectedEdge[87, 154] -> 
             RGBColor[
              0.9872510560263222, 0.9889959982810382, 0.8609465250606165], 
             UndirectedEdge[138, 167] -> 
             RGBColor[
              0.914025724578517, 0.8135858623733021, 0.6202282398592844], 
             UndirectedEdge[179, 194] -> 
             RGBColor[
              0.5782314602978695, 0.6630917185740817, 0.9624599458147682], 
             UndirectedEdge[118, 144] -> 
             RGBColor[
              0.8754464394074596, 0.6015112264467356, 0.4650330881244851], 
             UndirectedEdge[47, 188] -> 
             RGBColor[
              0.5580878614872598, 0.6517295894935908, 0.9586008499410545], 
             UndirectedEdge[11, 20] -> 
             RGBColor[
              0.2356317618329697, 0.3649942999760054, 0.93673025229921], 
             UndirectedEdge[124, 187] -> 
             RGBColor[
              0.2869408055031858, 0.4189233580546661, 0.939652226431301], 
             UndirectedEdge[28, 189] -> 
             RGBColor[
              0.26308408549772533`, 0.39384843272551495`, 0.9382936215198444],
              UndirectedEdge[84, 93] -> 
             RGBColor[
              0.24346208091315458`, 0.3732244618001842, 0.9371761773869076], 
             UndirectedEdge[18, 94] -> 
             RGBColor[
              0.36824895343507874`, 0.4933804675600669, 0.9446854755764875], 
             UndirectedEdge[146, 156] -> 
             RGBColor[
              0.8584691386886809, 0.8901770946260392, 0.9863115068182637], 
             UndirectedEdge[2, 26] -> 
             RGBColor[
              0.3867618425079842, 0.5094154015901577, 0.945865100497908], 
             UndirectedEdge[124, 161] -> 
             RGBColor[
              0.29985672336199365`, 0.43249880664076373`, 0.9403877688459719],
              UndirectedEdge[25, 67] -> 
             RGBColor[
              0.8717776309273555, 0.4074814902998567, 0.23424954998350475`], 
             UndirectedEdge[15, 77] -> 
             RGBColor[
              0.31275241202724346`, 0.4445399594620464, 0.9411775588098623], 
             UndirectedEdge[23, 49] -> 
             RGBColor[
              0.8876847855307123, 0.5082342720907941, 0.3014347816686359], 
             UndirectedEdge[27, 37] -> 
             RGBColor[
              0.23387138917519362`, 0.3631440366986098, 0.9366300016805876], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.28199072307706635`, 0.41303118579725295`, 0.9393955660070041],
              UndirectedEdge[134, 139] -> 
             RGBColor[
              0.2400051701500614, 0.36959102940737165`, 0.9369793114329906], 
             UndirectedEdge[13, 127] -> 
             RGBColor[
              0.34979347533914956`, 0.4773952600326733, 0.9435095088317533], 
             UndirectedEdge[59, 186] -> 
             RGBColor[
              0.36541764511564734`, 0.4884580900498052, 0.9445955073983169], 
             UndirectedEdge[119, 149] -> 
             RGBColor[
              0.3992231896957711, 0.5102289495476822, 0.9477505828326117], 
             UndirectedEdge[41, 66] -> 
             RGBColor[
              0.6206670435279176, 0.7021698769586107, 0.9637962645099678], 
             UndirectedEdge[25, 103] -> 
             RGBColor[
              0.9025010063998871, 0.6312917089511744, 0.2631869638671507], 
             UndirectedEdge[164, 166] -> 
             RGBColor[
              0.3428237586125573, 0.4700619252820549, 0.9431128764626655], 
             UndirectedEdge[30, 90] -> 
             RGBColor[
              0.6408480095261183, 0.7142786377339077, 0.9678341664939911], 
             UndirectedEdge[75, 182] -> 
             RGBColor[
              0.27464253104525127`, 0.40599709184373967`, 0.9389518578945881],
              UndirectedEdge[92, 97] -> 
             RGBColor[
              0.2548383832137916, 0.38518167681737986`, 0.9378240409731977], 
             UndirectedEdge[18, 61] -> 
             RGBColor[
              0.2960837334123488, 0.42764330820172913`, 0.9402054842996372], 
             UndirectedEdge[76, 191] -> 
             RGBColor[
              0.2782905449427576, 0.40983138574745914`, 0.9391596068892982], 
             UndirectedEdge[129, 197] -> 
             RGBColor[
              0.939588342286577, 0.9465340447880747, 0.7029640290475025], 
             UndirectedEdge[97, 112] -> 
             RGBColor[
              0.2912053726836331, 0.4234056885504923, 0.9398950872233656], 
             UndirectedEdge[87, 131] -> 
             RGBColor[
              0.9436166175198961, 0.8123670652183208, 0.5433036400573084], 
             UndirectedEdge[33, 198] -> 
             RGBColor[
              0.5096004354679522, 0.6083940896440386, 0.956077633424264], 
             UndirectedEdge[39, 114] -> 
             RGBColor[
              0.20908858865686974`, 0.3370957420335433, 0.935218657853937], 
             UndirectedEdge[144, 170] -> 
             RGBColor[
              0.631799051712688, 0.39327699019190376`, 0.44573426426596857`], 
             UndirectedEdge[64, 110] -> 
             RGBColor[
              0.6138148271599528, 0.6973615545881173, 0.9627408981532811], 
             UndirectedEdge[108, 131] -> 
             RGBColor[
              0.8402456246331873, 0.7322315204859621, 0.6082404593152602], 
             UndirectedEdge[33, 141] -> 
             RGBColor[
              0.3411893210123498, 0.46994277401217005`, 0.9429612597264045], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.6032826317786147, 0.6888110439075521, 0.9619117651521593], 
             UndirectedEdge[88, 142] -> 
             RGBColor[
              0.6765418260566909, 0.7472163657056936, 0.968410420193581], 
             UndirectedEdge[12, 95] -> 
             RGBColor[
              0.7817942234386319, 0.8080307104936368, 0.6678706900642806], 
             UndirectedEdge[131, 162] -> 
             RGBColor[
              0.941079962602384, 0.8111036548737982, 0.5757395893878008], 
             UndirectedEdge[21, 194] -> 
             RGBColor[
              0.33236539581814195`, 0.4622999335123229, 0.9423990070157204], 
             UndirectedEdge[131, 154] -> 
             RGBColor[
              0.9428931009304802, 0.8120678725150692, 0.5552941823448407], 
             UndirectedEdge[81, 184] -> 
             RGBColor[
              0.47373340289000515`, 0.5814056280463057, 0.952329749742717], 
             UndirectedEdge[105, 111] -> 
             RGBColor[
              0.4018530682244218, 0.5222917683666206, 0.9468805499681779]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {2}, VertexStyle -> {
             EdgeForm[None], 71 -> 
             RGBColor[
              0.2902833275082297, 0.42243656061010276`, 0.93984257811467], 10 -> 
             RGBColor[
              0.28931600419628395`, 0.4214198424774074, 0.9397874904830813], 
             68 -> RGBColor[
              0.8556248139763563, 0.8877160176206234, 0.9860914526539951], 
             155 -> RGBColor[
              0.24962306644129345`, 0.3797000482193023, 0.9375270363983738], 
             132 -> RGBColor[
              0.2522143608002516, 0.3824236628881191, 0.93767460677864], 26 -> 
             RGBColor[
              0.39640287984113043`, 0.5177659835555031, 0.9464794188715415], 
             29 -> RGBColor[
              0.9936430185668372, 0.9916392390574856, 0.75501516389549], 113 -> 
             RGBColor[
              0.9003020964297527, 0.6401769295720257, 0.2385219642527955], 50 -> 
             RGBColor[
              0.2422322948146241, 0.37193187863768656`, 0.9371061428879017], 
             173 -> RGBColor[
              0.9951414157005084, 0.9920163043986404, 0.7125512665860644], 
             192 -> RGBColor[0.817319, 0.134127, 0.164218], 165 -> 
             RGBColor[
              0.21890292553398902`, 0.347411232356294, 0.9357775698200786], 
             92 -> RGBColor[
              0.22871531315648586`, 0.35772467388884666`, 0.9363363707790532],
              11 -> RGBColor[
              0.24586228151751777`, 0.37574722481687783`, 0.9373128652605475],
              137 -> RGBColor[
              0.2501870825879037, 0.38029286495007875`, 0.9375591562835361], 
             120 -> RGBColor[
              0.9567688473548046, 0.8658333123497126, 0.2865555648019119], 51 -> 
             RGBColor[
              0.28213996431762406`, 0.4138773695777287, 0.9393788256279912], 
             72 -> RGBColor[
              0.24987650973082426`, 0.37996643318583184`, 0.9375414696187768],
              64 -> RGBColor[
              0.6226026285830288, 0.704495887669313, 0.963432706072083], 41 -> 
             RGBColor[
              0.5497140953330726, 0.6453216927859953, 0.9576946537351515], 
             103 -> 
             RGBColor[
              0.8642907579141675, 0.4766578520345487, 0.20847322067670976`], 
             162 -> RGBColor[
              0.9829012627807141, 0.9867683702952449, 0.9138278814340688], 
             196 -> RGBColor[
              0.49517344266125934`, 0.6010431339186144, 0.9534010137678327], 
             179 -> RGBColor[
              0.807933735593484, 0.8498832418602281, 0.9814909422600818], 160 -> 
             RGBColor[
              0.36671177852496323`, 0.4920490439135823, 0.9445875281504853], 
             123 -> RGBColor[
              0.250431442054717, 0.3805497022429847, 0.9375730721936737], 150 -> 
             RGBColor[
              0.2829267708206377, 0.41470435309880965`, 0.9394236330943619], 
             188 -> RGBColor[
              0.6646539951158695, 0.737952019632756, 0.9672101567545748], 46 -> 
             RGBColor[
              0.5977424503378598, 0.6843132750316175, 0.9614756217747897], 
             182 -> RGBColor[
              0.2651236286264823, 0.39599212186834176`, 0.9384097704837935], 
             6 -> RGBColor[
              0.3400518121902417, 0.46895752104331584`, 0.9428887786701194], 
             131 -> RGBColor[
              0.8992586624240541, 0.6354389394523516, 0.23765129734153262`], 
             45 -> RGBColor[
              0.8843599871114161, 0.5677875345316877, 0.22521947746071738`], 
             195 -> RGBColor[0.178927, 0.305394, 0.933501], 148 -> 
             RGBColor[
              0.20479309393410217`, 0.332580904729819, 0.9349740357840903], 
             161 -> RGBColor[
              0.30865896704414575`, 0.441750522845189, 0.9408890436019178], 1 -> 
             RGBColor[
              0.9583125875736904, 0.8710407105954553, 0.2925527040414048], 
             101 -> RGBColor[
              0.2518443381406806, 0.38203474561211825`, 0.9376535345355769], 
             12 -> RGBColor[
              0.5839626349742006, 0.6731262001457912, 0.9603908242322355], 39 -> 
             RGBColor[
              0.20098973591686892`, 0.3285833343068806, 0.9347574401715728], 
             48 -> RGBColor[
              0.3171026989044469, 0.4490801525711323, 0.9414264814646527], 77 -> 
             RGBColor[
              0.3003940670337382, 0.43306358890932384`, 0.940418369773149], 
             56 -> RGBColor[0.178927, 0.305394, 0.933501], 110 -> 
             RGBColor[
              0.6050270257368769, 0.6902272215069217, 0.9620490902344793], 73 -> 
             RGBColor[
              0.2931347355771166, 0.42543357128021636`, 0.9400049615859128], 
             37 -> 
             RGBColor[
              0.19099374879671333`, 0.31807691806140814`, 0.9341881834928177],
              130 -> RGBColor[
              0.23722409174651585`, 0.3666679396746901, 0.9368209331321454], 
             107 -> RGBColor[
              0.6672310374616252, 0.7399652246995075, 0.9674670122517698], 59 -> 
             RGBColor[
              0.44880489881560515`, 0.5631539785891382, 0.949818429183309], 
             47 -> RGBColor[
              0.4515217278586501, 0.5655071593544256, 0.9499915431275343], 
             159 -> RGBColor[
              0.8226444613445744, 0.17506082952644003`, 0.16931766779781277`],
              55 -> RGBColor[
              0.35238205413251156`, 0.47963735687773035`, 0.943674450783476], 
             49 -> RGBColor[
              0.8347376037115143, 0.26801402100751526`, 0.1808980745856452], 
             82 -> RGBColor[
              0.31859842780058983`, 0.45037567776345117`, 0.9415217879872938],
              199 -> RGBColor[
              0.27228850741332744`, 0.40352286375286894`, 0.938817799731216], 
             89 -> RGBColor[
              0.8539922331287186, 0.4160135401405583, 0.19933632946055357`], 
             144 -> RGBColor[
              0.8565158956399671, 0.43541151607797846`, 0.2017529915313943], 
             78 -> RGBColor[
              0.9279645300339343, 0.9453977435956535, 0.9929912793499938], 42 -> 
             RGBColor[
              0.5214414667269106, 0.6223686992161088, 0.9554689288452234], 
             154 -> RGBColor[
              0.9865275394369064, 0.9886968055777866, 0.8729370673481489], 
             168 -> RGBColor[
              0.9385923578753286, 0.9537228615659814, 0.988831299825661], 121 -> 
             RGBColor[
              0.5426755050288741, 0.6396074480921672, 0.9571405501231992], 
             128 -> RGBColor[
              0.8895815146715775, 0.5914972716636359, 0.22957644804826868`], 
             115 -> RGBColor[
              0.2655539192117794, 0.3964443845554878, 0.9384342748960682], 61 -> 
             RGBColor[
              0.2737970101358498, 0.4051083957588368, 0.9389037067296339], 93 -> 
             RGBColor[
              0.22414759348065547`, 0.35292371089939434`, 0.9360762459008504],
              88 -> RGBColor[
              0.7121946053554326, 0.7750911056739228, 0.9719485604909927], 21 -> 
             RGBColor[
              0.31620160663402885`, 0.4482996717367106, 0.9413690646619862], 
             62 -> RGBColor[
              0.3562346737166085, 0.4829743023231845, 0.943919936296637], 136 -> 
             RGBColor[
              0.9080066729340168, 0.6729841436820356, 0.24483821356303642`], 
             190 -> RGBColor[
              0.1797070620660458, 0.3062138946902057, 0.9335454233806629], 57 -> 
             RGBColor[
              0.3605779115447064, 0.4867361966324024, 0.9441966835704689], 
             111 -> RGBColor[
              0.4604958122832016, 0.5728902713682614, 0.9506710636761264], 63 -> 
             RGBColor[
              0.35285247495850214`, 0.48004481175316516`, 0.9437044255825313],
              75 -> RGBColor[
              0.28416143346402023`, 0.4160020618191376, 0.9394939453053829], 
             30 -> RGBColor[
              0.8937471851268821, 0.9181137615718546, 0.9897275984465748], 5 -> 
             RGBColor[
              0.2822070658609612, 0.41394789755425965`, 0.9393826469616164], 
             171 -> RGBColor[
              0.8744701613749067, 0.9027427860928997, 0.9878889387123091], 
             102 -> RGBColor[
              0.37383492502239923`, 0.4982187553899085, 0.9450414087465508], 
             31 -> RGBColor[
              0.8505083657915934, 0.8836363007203797, 0.9856034412586252], 96 -> 
             RGBColor[
              0.3061966914574528, 0.4391625150862857, 0.940748820649866], 70 -> 
             RGBColor[
              0.21367513065222027`, 0.34191648847421524`, 0.9354798546353913],
              52 -> RGBColor[
              0.21246269677098534`, 0.3406421435922893, 0.9354108083194902], 
             183 -> RGBColor[
              0.859910479347665, 0.45676803010411193`, 0.20481820887036734`], 
             158 -> RGBColor[
              0.25326504777876796`, 0.3835280015199418, 0.9377344418477144], 
             13 -> RGBColor[
              0.3779993100162068, 0.5018257363634689, 0.9453067596759351], 
             170 -> RGBColor[
              0.1823653638581298, 0.3090079384197544, 0.933696809735117], 86 -> 
             RGBColor[
              0.3919595940317969, 0.5139174327134967, 0.9461962966288141], 18 -> 
             RGBColor[
              0.3183704566888478, 0.45017822064462143`, 0.9415072618696405], 
             153 -> RGBColor[
              0.585970074369736, 0.674755929881201, 0.960548857214945], 58 -> 
             RGBColor[
              0.264153442110629, 0.394972394326802, 0.9383545197969779], 22 -> 
             RGBColor[
              0.8444218577904707, 0.34245144152557083`, 0.19017172722845446`],
              66 -> RGBColor[
              0.6916199917227627, 0.7590180611312259, 0.9698978752847841], 
             143 -> RGBColor[
              0.8207984422031169, 0.16087151747445233`, 0.16754991778317269`],
              119 -> RGBColor[
              0.5648783713319804, 0.6576327351847573, 0.9588884410903589], 
             145 -> RGBColor[
              0.20775586072121455`, 0.33569496047333813`, 0.9351427609695957],
              91 -> RGBColor[
              0.8378176201564483, 0.8735170446320284, 0.9843929866107827], 
             177 -> RGBColor[
              0.29360677442013106`, 0.4259297140332158, 0.9400318434997037], 
             200 -> RGBColor[
              0.23658832296539867`, 0.36599970637566703`, 0.9367847270405965],
              114 -> RGBColor[
              0.21718744139687057`, 0.3456081497602061, 0.935679875536301], 
             24 -> RGBColor[
              0.17892700283938517`, 0.30539400298437386`, 0.9335010001616988],
              176 -> RGBColor[
              0.29419693695473825`, 0.4265500122755539, 0.9400654523829823], 
             79 -> RGBColor[
              0.20396815225836698`, 0.3317138387242981, 0.934927056576049], 
             109 -> RGBColor[
              0.3375430035907792, 0.46678451713084806`, 0.942728919604614], 
             135 -> RGBColor[
              0.23327898842098083`, 0.3625213859455549, 0.9365962653340136], 
             108 -> RGBColor[
              0.7812325868423204, 0.8290241015195725, 0.9788296212889877], 
             191 -> RGBColor[
              0.28023078255701894`, 0.41187069849821767`, 0.939270100551106], 
             14 -> RGBColor[
              0.4167727741971154, 0.535409362225998, 0.9477773705275145], 185 -> 
             RGBColor[
              0.7695733223497783, 0.8199157954843064, 0.9776675347663926], 32 -> 
             RGBColor[
              0.23515166545220784`, 0.36448968823995603`, 0.9367029115205646],
              122 -> RGBColor[
              0.9929383277496677, 0.9873041220381521, 0.47275873901987264`], 
             187 -> RGBColor[
              0.28282713132653, 0.41459962567299363`, 0.939417958772576], 193 -> 
             RGBColor[
              0.31668648779682773`, 0.44871965142909115`, 0.9413999608609163],
              100 -> RGBColor[
              0.21381427791123173`, 0.3420627410658821, 0.9354877788659421], 
             180 -> RGBColor[
              0.7240681721091139, 0.7843668262643483, 0.9731320066602097], 7 -> 
             RGBColor[
              0.350460125859892, 0.477972679206911, 0.9435519872134391], 175 -> 
             RGBColor[
              0.320397896026041, 0.45193428669643415`, 0.9416364485114123], 9 -> 
             RGBColor[
              0.2605668322464433, 0.39120263995534316`, 0.9381502676711264], 
             90 -> RGBColor[
              0.3879488339253545, 0.5104435138959607, 0.9459407345414075], 
             174 -> RGBColor[
              0.3814106085308894, 0.5047804316800383, 0.9455241246007979], 
             142 -> RGBColor[
              0.6408890467579492, 0.7193416257374643, 0.9648722798961695], 
             134 -> RGBColor[
              0.23085213233970892`, 0.3599706063325754, 0.9364580594703971], 
             105 -> RGBColor[
              0.34321032416564207`, 0.47169326536497985`, 0.9430900362602295],
              16 -> RGBColor[
              0.3229612837478847, 0.4541545643014821, 0.9417997853103334], 
             139 -> RGBColor[
              0.24915820796041388`, 0.3792114524821679, 0.9375005633955842], 
             146 -> RGBColor[
              0.79609453068194, 0.84063436500204, 0.9803109209581594], 126 -> 
             RGBColor[
              0.30722498883092086`, 0.4402433208236197, 0.9408073806640553], 
             198 -> RGBColor[
              0.6961608186542636, 0.7625653896416773, 0.9703504624768758], 40 -> 
             RGBColor[
              0.49158142165721236`, 0.5981269694488269, 0.9531182367163876], 
             104 -> RGBColor[
              0.21893481250696653`, 0.34744474758664423`, 0.9357793857360172],
              181 -> RGBColor[
              0.984329904565909, 0.9877880270819891, 0.9093575644573119], 127 -> 
             RGBColor[
              0.32158764066209233`, 0.4529647837018777, 0.9417122579875715], 
             76 -> RGBColor[
              0.27635030732849636`, 0.40779207299670056`, 0.9390491132274904],
              172 -> RGBColor[
              0.9939767127007667, 0.98952512245173, 0.5857805327779135], 84 -> 
             RGBColor[
              0.2627765683456537, 0.3935252127009741, 0.9382761088729649], 
             184 -> RGBColor[
              0.3711329893802169, 0.49587847453988415`, 0.9448692437966588], 
             151 -> RGBColor[
              0.3518764439127397, 0.4791994227180725, 0.9436422337473658], 35 -> 
             RGBColor[
              0.8383733051460716, 0.8739601327590868, 0.9844459883411588], 36 -> 
             RGBColor[
              0.24777983952010385`, 0.3777626998577953, 0.9374220673520219], 
             34 -> RGBColor[
              0.2517479206748871, 0.38193340474234894`, 0.9376480437035368], 
             38 -> RGBColor[
              0.9648082727380654, 0.8929521819142981, 0.31778721429778617`], 
             54 -> 
             RGBColor[
              0.27280646441116213`, 0.40406726939796367`, 0.938847296615994], 
             60 -> RGBColor[
              0.253957266336059, 0.38425556711284614`, 0.9377738626705066], 
             87 -> RGBColor[
              0.9879745726157381, 0.9892951909842899, 0.8489559827730842], 
             141 -> RGBColor[
              0.3593385897430587, 0.4856627583779401, 0.9441177150811572], 67 -> 
             RGBColor[
              0.8182056947053702, 0.14094252405757224`, 0.16506709985124088`],
              133 -> RGBColor[
              0.8234278438149039, 0.18108225047377968`, 0.1700678357361042], 
             98 -> RGBColor[
              0.9734883859205871, 0.9797482621451334, 0.9297614266867937], 3 -> 
             RGBColor[
              0.26366336471100654`, 0.39445729190709694`, 0.938326610614074], 
             27 -> RGBColor[
              0.2767490295536739, 0.4082111553358114, 0.9390718198683575], 
             163 -> RGBColor[
              0.23302215960706, 0.36225144257823677`, 0.936581639313005], 85 -> 
             RGBColor[
              0.360155081261214, 0.48636996229290924`, 0.9441697411986989], 
             83 -> RGBColor[
              0.25584834544704116`, 0.3862432111598293, 0.9378815568282761], 
             28 -> RGBColor[
              0.29477679578460203`, 0.4271594806709139, 0.9400984744855188], 
             44 -> RGBColor[
              0.2834240796528994, 0.4152270562127178, 0.9394519540966568], 
             189 -> RGBColor[
              0.2313913752108486, 0.36053738478011593`, 0.9364887685541701], 
             15 -> RGBColor[
              0.32511075702074876`, 0.45601633001476893`, 0.9419367478465757],
              80 -> RGBColor[
              0.6198970672218798, 0.7022993910721819, 0.9632197143709355], 
             112 -> RGBColor[
              0.30144929209616883`, 0.4341726973550716, 0.9404784632793888], 
             169 -> RGBColor[
              0.2725827939998642, 0.40383217761416634`, 0.9388345589169613], 
             69 -> RGBColor[
              0.4015855979045752, 0.522254993451075, 0.9468096570836465], 20 -> 
             RGBColor[
              0.22540124214842158`, 0.354241375135133, 0.9361476393378726], 8 -> 
             RGBColor[
              0.44819737568646545`, 0.5626277725896778, 0.9497797183467319], 
             116 -> RGBColor[
              0.3895827819898638, 0.5118587575848209, 0.9460448482672345], 97 -> 
             RGBColor[
              0.28096145327109734`, 0.41263867974591306`, 0.9393117111673424],
              118 -> 
             RGBColor[
              0.9133075269424444, 0.9337106471842498, 0.9915932813106664], 
             178 -> RGBColor[
              0.9424318889382709, 0.9565863775460686, 0.9823319752461818], 81 -> 
             RGBColor[
              0.5763338163997934, 0.6669327815527272, 0.9597902556887751], 
             166 -> RGBColor[
              0.39092445521974123`, 0.5130208475020834, 0.9461303384990473], 
             125 -> RGBColor[
              0.17895982839241617`, 0.30542850472186966`, 0.9335028695283829],
              95 -> RGBColor[
              0.9796258119030633, 0.9429352208414826, 0.3753505558963255], 
             157 -> RGBColor[
              0.5576848060128018, 0.6517926747922235, 0.9583221372775351], 74 -> 
             RGBColor[
              0.30278259996188467`, 0.4355740884585403, 0.9405543931898891], 
             19 -> RGBColor[
              0.26440158051900675`, 0.3952332035268908, 0.9383686509122472], 
             156 -> RGBColor[
              0.9208437466954219, 0.9397198242500384, 0.9923120926783682], 
             167 -> RGBColor[
              0.9152757732218003, 0.9352800733407862, 0.9917810143978655], 33 -> 
             RGBColor[0.3230400522816408, 0.4542227896464, 0.941804804371652],
              43 -> RGBColor[
              0.8553653759675705, 0.4265681177150025, 0.20065125259378117`], 
             140 -> RGBColor[
              0.30550365683416836`, 0.4384340917562807, 0.9407093533533227], 
             186 -> RGBColor[
              0.28203039141568953`, 0.41376220151047227`, 0.9393725856133247],
              117 -> RGBColor[
              0.7789983515005383, 0.8272786998897548, 0.9786069335902352], 4 -> 
             RGBColor[
              0.8048857220793089, 0.8475021105371937, 0.9811871447582946], 
             106 -> RGBColor[
              0.27505191676798696`, 0.40642738219488894`, 0.9389751718058661],
              65 -> RGBColor[
              0.9220936452530043, 0.9407164594322621, 0.992431309118588], 53 -> 
             RGBColor[
              0.21141226994966317`, 0.3395380784021726, 0.9353509880659832], 
             2 -> RGBColor[
              0.377120805174838, 0.5010648196248124, 0.9452507821242745], 147 -> 
             RGBColor[
              0.4806958664434177, 0.5892895853375945, 0.9522612859348552], 94 -> 
             RGBColor[
              0.4181274501813097, 0.5365827144755124, 0.9478636892833344], 23 -> 
             RGBColor[
              0.9935791491691084, 0.9886747742573517, 0.5425081958346172], 
             194 -> 
             RGBColor[
              0.348529185002255, 0.47630019528793527`, 0.9434289493694545], 
             129 -> RGBColor[
              0.9902596908634175, 0.9788057915282733, 0.4166611676177604], 99 -> 
             RGBColor[
              0.5640955015617808, 0.656997166237428, 0.9588268107143023], 25 -> 
             RGBColor[
              0.9789215033713261, 0.9405594227844256, 0.37261445024803247`], 
             138 -> RGBColor[
              0.9127756759352338, 0.6918916514058181, 0.2486754653207034], 
             124 -> RGBColor[
              0.2910544796798416, 0.42324709043633846`, 0.9398864940900259], 
             197 -> RGBColor[
              0.8889169937097365, 0.9142622980478761, 0.9892668904772446], 
             164 -> RGBColor[
              0.29472306200537346`, 0.42710300306202637`, 0.9400954144262837],
              152 -> RGBColor[
              0.281739557244844, 0.41345651635696223`, 0.9393560230375456], 
             17 -> RGBColor[
              0.2388383031545141, 0.3683645782114108, 0.9369128600838192], 
             149 -> RGBColor[
              0.2335680080595618, 0.362825163910607, 0.9366127245748646]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9lnk01I33xy0ZCmPGjGUM5jOLCfGgkIjPm8rSZv1l6yGUlK0nopQSkiYJ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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.9759778030702638, 0.9313399748264705, 0.5237839339684474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 78}], {
             RGBColor[
             0.9431385588038124, 0.9082192270955545, 0.6427719916956993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 88}], {
             RGBColor[
             0.8352535964645615, 0.823065908134689, 0.6322506322661987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 89}], {
             RGBColor[
             0.8887656846103759, 0.567689263625524, 0.23040845432083734`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[
             0.9293073420017215, 0.7556088200837405, 0.2655373341471002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 122}], {
             RGBColor[
             0.9756254576616791, 0.9291724163168037, 0.38265572153063876`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 136}], {
             RGBColor[
             0.9331596302538536, 0.7720124271387454, 0.2686954588022206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 138}], {
             RGBColor[
             0.9355441317544622, 0.7814661810006367, 0.2706140846810541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 144}], {
             RGBColor[
             0.8904481262845415, 0.5806212475838041, 0.23201956236806448`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 159}], {
             RGBColor[
             0.867867170087613, 0.40705412321611184`, 0.21039601321234347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 167}], {
             RGBColor[
             0.9367941803977453, 0.9031603919681208, 0.6421668592196352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 197}], {
             RGBColor[
             0.9236147906417135, 0.8926515043216656, 0.6409097972593247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 26}], {
             RGBColor[
             0.3867618425079842, 0.5094154015901577, 0.945865100497908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 40}], {
             RGBColor[
             0.43435111341602517`, 0.5495958945368197, 0.9491845094203311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 51}], {
             RGBColor[
             0.329630384746231, 0.45747109460127056`, 0.9423148038761329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 74}], {
             RGBColor[
             0.3399517025683613, 0.46831945404167635`, 0.9429025876570818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 80}], {
             RGBColor[
             0.4985089361983589, 0.6016821053484971, 0.954235248247605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 121}], {
             RGBColor[
             0.45989815510185605`, 0.5703361338584898, 0.9511956661237368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 158}], {
             RGBColor[
             0.31519292647680297`, 0.4422964105723771, 0.9414926119859944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 164}], {
             RGBColor[
             0.3359219335901057, 0.4640839113434194, 0.9426730982752791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 166}], {
             RGBColor[
             0.3840226301972896, 0.5070428335634479, 0.9456905603116609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 169}], {
             RGBColor[
             0.3248517995873511, 0.4524484986194894, 0.942042670520618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 184}], {
             RGBColor[
             0.37412689727752746`, 0.49847164708234826`, 0.9450600129604667]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 5}], {
             RGBColor[
             0.27293521528598386`, 0.4042025947306783, 0.9388546287878452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 10}], {
             RGBColor[
             0.27648968445364525`, 0.4079385671922522, 0.9390570505485776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 11}], {
             RGBColor[
             0.2547628231142621, 0.3851022583619874, 0.9378197379373108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 15}], {
             RGBColor[
             0.2943870608658776, 0.4252368109609329, 0.9401316792303248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 20}], {
             RGBColor[
             0.24453230342971405`, 0.374349333521115, 0.9372371249759732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 28}], {
             RGBColor[
             0.2792200802478043, 0.4108083862890054, 0.9392125425497964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 48}], {
             RGBColor[
             0.29038303180772673`, 0.42176872223911466`, 0.9398765460393633]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 63}], {
             RGBColor[
             0.30825791983475437`, 0.437251051830131, 0.9410155180983026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 77}], {
             RGBColor[
             0.2820287158723724, 0.41376044040821036`, 0.9393724901936115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 106}], {
             RGBColor[
             0.26935764073949675`, 0.40044233705099297`, 0.93865089120997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 186}], {
             RGBColor[
             0.27284687806334806`, 0.40410974670878463`, 0.9388495981136993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 189}], {
             RGBColor[
             0.24752736996092756`, 0.37749733834360644`, 0.937407689584122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 41}], {
             RGBColor[
             0.6772999087061907, 0.7464119016615944, 0.969440899246723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 66}], {
             RGBColor[
             0.7482528569010358, 0.8032600858342098, 0.9755425100215394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 80}], {
             RGBColor[
             0.7123913946505943, 0.7749007508046878, 0.972203429564615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 81}], {
             RGBColor[
             0.6906097692395512, 0.7572174460449604, 0.9704887002235348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 168}], {
             RGBColor[
             0.8717390399773187, 0.9006124860515876, 0.9850092222919777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 172}], {
             RGBColor[
             0.8994312173900378, 0.9185136164944618, 0.783483838768104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 173}], {
             RGBColor[
             0.9000135688899087, 0.9197592074679171, 0.8468692056721795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 184}], {
             RGBColor[
             0.5880093557297629, 0.671690292538539, 0.9630281942774768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 198}], {
             RGBColor[
             0.7505232703667862, 0.8050337500894356, 0.9757688036175852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 9}], {
             RGBColor[
             0.27138694905370225`, 0.40257526875480143`, 0.9387664573163714]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.2640346736892395, 0.39484756118556874`, 0.938347756111082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 15}], {
             RGBColor[
             0.303658911440855, 0.4349821137845143, 0.940659697404096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 17}], {
             RGBColor[
             0.26052268450773763`, 0.3911562378828352, 0.9381477535227178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 20}], {
             RGBColor[
             0.2538041540046914, 0.3840946363446963, 0.9377651431497445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 28}], {
             RGBColor[
             0.28849193082278163`, 0.4205536891125868, 0.9397405607235676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 48}], {
             RGBColor[
             0.2996548823827041, 0.431514025062696, 0.9404045642131346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 63}], {
             RGBColor[
             0.3175297704097317, 0.4469963546537124, 0.9415435362720739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[
             0.2913005664473497, 0.42350574323179174`, 0.9399005083673827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 102}], {
             RGBColor[
             0.32802099544168023`, 0.45608332647208405`, 0.9422120278540836]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 106}], {
             RGBColor[
             0.2786294913144741, 0.4101876398745743, 0.9391789093837413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 112}], {
             RGBColor[
             0.29182817897856506`, 0.4240602974546656, 0.9399305551205026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 140}], {
             RGBColor[
             0.2938553613475648, 0.42619099465527016`, 0.9400460001574695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 189}], {
             RGBColor[
             0.2567992205359049, 0.38724264116718776`, 0.9379357077578933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 12}], {
             RGBColor[
             0.4620072235822212, 0.5710418605945535, 0.9516398014511775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 13}], {
             RGBColor[
             0.35902556110322426`, 0.48539162870339236`, 0.9440977691730272]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 14}], {
             RGBColor[
             0.37841229319367853`, 0.5021834416346569, 0.945333074598817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 16}], {
             RGBColor[
             0.3315065479690632, 0.46155604267239897`, 0.9423442819902264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 59}], {
             RGBColor[
             0.39442835550292343`, 0.516055749816227, 0.9463536039267142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 64}], {
             RGBColor[
             0.4813272203866353, 0.5867267043563145, 0.9531607423711013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 83}], {
             RGBColor[
             0.29795007881864144`, 0.4276003661015726, 0.9403851677491978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 86}], {
             RGBColor[
             0.3660057031110193, 0.4914374768784062, 0.9445425376494667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 124}], {
             RGBColor[
             0.3155531459350417, 0.4461023057398271, 0.9413876363800726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 137}], {
             RGBColor[
             0.2951194473890727, 0.4246251929966973, 0.9402239674768278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 161}], {
             RGBColor[
             0.32435538961719373`, 0.45535402194425245`, 0.9418889111360187]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 175}], {
             RGBColor[
             0.3302248541081414, 0.460445903869875, 0.9422626135907659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 176}], {
             RGBColor[
             0.31712437457249, 0.4477537666594349, 0.9414771155265509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 186}], {
             RGBColor[
             0.3110411018029656, 0.4413598612768941, 0.941130682141722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 187}], {
             RGBColor[
             0.3114394717583858, 0.44177857335815474`, 0.9411533687213477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 193}], {
             RGBColor[
             0.3283691499935347, 0.4588385862362035, 0.9421443697655179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 199}], {
             RGBColor[
             0.3061701598017846, 0.4362401923980924, 0.9408532892006678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 18}], {
             RGBColor[
             0.33441529127436986`, 0.4640754499257662, 0.9425296245415398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 42}], {
             RGBColor[
             0.4359507962934013, 0.5501706892115099, 0.9495104580293312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 47}], {
             RGBColor[
             0.40099092685927107`, 0.5217399192806683, 0.9467717651704868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.31163329513552707`, 0.44101997430243733`, 0.9411996419147166]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 58}], {
             RGBColor[
             0.3073067839852605, 0.4364725367668565, 0.9409532535052085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.3121285679978709, 0.4415405374828739, 0.9412278469715365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 73}], {
             RGBColor[
             0.3217974307185043, 0.4517031252435637, 0.941778474399676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 88}], {
             RGBColor[
             0.5313273656076622, 0.6265318924404168, 0.9577502738522159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 94}], {
             RGBColor[
             0.3842937880206009, 0.5072776968412117, 0.9457078382483868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 97}], {
             RGBColor[
             0.3157107895654947, 0.44530567947641203`, 0.9414318491903908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 115}], {
             RGBColor[
             0.3080070225358357, 0.4372085318811994, 0.9409931310547537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 153}], {
             RGBColor[
             0.46821510011481404`, 0.5763643045440561, 0.9520504222141921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 160}], {
             RGBColor[
             0.3585859521924276, 0.48501086156024664`, 0.9440697576819622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 188}], {
             RGBColor[
             0.5075570604878807, 0.6079623494198335, 0.955381071984007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 55}], {
             RGBColor[
             0.4002897149094885, 0.5211325647337041, 0.9467270845651039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 62}], {
             RGBColor[
             0.40221602470153694`, 0.5228010374564311, 0.9468498273216844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 68}], {
             RGBColor[
             0.6519110948314109, 0.7251718951051506, 0.9679355855003635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 75}], {
             RGBColor[
             0.36617940457524284`, 0.4893149172044077, 0.9446368318260574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 96}], {
             RGBColor[
             0.3771970335719591, 0.5008951438379817, 0.9452642694982989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 99}], {
             RGBColor[
             0.5061464386241231, 0.6098124694135529, 0.9543032645305172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 107}], {
             RGBColor[
             0.5577142065740452, 0.6512964986445926, 0.9586233652992509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 147}], {
             RGBColor[
             0.4644466210649416, 0.5759586789636362, 0.9510205021407936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 156}], {
             RGBColor[
             0.6845205611909437, 0.7511737984198581, 0.97104590551255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 157}], {
             RGBColor[
             0.5029410908496337, 0.6072102236909507, 0.9540509278121335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 179}], {
             RGBColor[
             0.6280655556399748, 0.706255507224953, 0.9656353303034069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 185}], {
             RGBColor[
             0.6088853490181219, 0.6912717840369921, 0.9637236265565623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 194}], {
             RGBColor[
             0.3983632803443602, 0.5194639839388066, 0.9466043338580932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.2532145568819805, 0.3834749323861105, 0.937731566465837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 17}], {
             RGBColor[
             0.2497025677004787, 0.37978360908337694`, 0.9375315638774728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 20}], {
             RGBColor[
             0.24298403719743245`, 0.3727220075452381, 0.9371489535044994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 28}], {
             RGBColor[
             0.27767181401552266`, 0.4091810603131285, 0.9391243710783226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 63}], {
             RGBColor[
             0.3067096536024727, 0.43562372585425413`, 0.9409273466268289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 77}], {
             RGBColor[
             0.2804804496400908, 0.41213311443233347`, 0.9392843187221377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 97}], {
             RGBColor[
             0.2707641427587703, 0.4019206598506281, 0.9387309894192344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 102}], {
             RGBColor[
             0.31720087863442126`, 0.44471069767262583`, 0.9415958382088386]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.2678093745072151, 0.3988150110751161, 0.9385627197384963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 112}], {
             RGBColor[
             0.28100806217130603`, 0.41268766865520734`, 0.9393143654752576]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 140}], {
             RGBColor[
             0.2830352445403058, 0.4148183658558119, 0.9394298105122245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 189}], {
             RGBColor[
             0.24597910372864595`, 0.37587001236772954`, 0.9373195181126482]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 14}], {
             RGBColor[
             0.35304438919669967`, 0.4784146023517027, 0.943782430505298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.30721338060851633`, 0.43871808624608816`, 0.9408621191648285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 28}], {
             RGBColor[
             0.292046399990443, 0.42428966157416065`, 0.9399429824843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 48}], {
             RGBColor[
             0.30320935155036544`, 0.43524999752426985`, 0.940606985973867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 59}], {
             RGBColor[
             0.3690604515059446, 0.4922869105332728, 0.9448029598331952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 77}], {
             RGBColor[
             0.2948550356150111, 0.4272417156933656, 0.9401029301281152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 186}], {
             RGBColor[
             0.28567319780598677`, 0.4175910219939398, 0.939580038048203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 193}], {
             RGBColor[
             0.30300124599655587`, 0.4350697469532493, 0.9405937256719987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 15}], {
             RGBColor[
             0.28548651926913327`, 0.4158817774158234, 0.9396248065535615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 17}], {
             RGBColor[
             0.24235029233601593`, 0.3720559015141443, 0.9371128626721834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 20}], {
             RGBColor[
             0.2356317618329697, 0.3649942999760054, 0.93673025229921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 28}], {
             RGBColor[
             0.2703195386510599, 0.4014533527438959, 0.9387056698730332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 48}], {
             RGBColor[
             0.2814824902109824, 0.4124136886940051, 0.9393696733626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 63}], {
             RGBColor[
             0.29935737823800995`, 0.4278960182850215, 0.9405086454215394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 77}], {
             RGBColor[
             0.27312817427562797`, 0.40440540686310084`, 0.9388656175168482]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 106}], {
             RGBColor[
             0.2604570991427524, 0.3910873035058834, 0.9381440185332068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 112}], {
             RGBColor[
             0.2736557868068433, 0.4049599610859747, 0.9388956642699682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 140}], {
             RGBColor[
             0.27568296917584306`, 0.40709065828657925`, 0.9390111093069351]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 189}], {
             RGBColor[
             0.2386268283641832, 0.36814230479849686`, 0.9369008169073587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 13}], {
             RGBColor[
             0.4809809724952037, 0.58747596825463, 0.9528487919540853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 14}], {
             RGBColor[
             0.500367704585658, 0.6042677811858945, 0.954084097379875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.45346195936104267`, 0.5636403822236367, 0.9510953047712845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 23}], {
             RGBColor[
             0.7887708920716545, 0.8309004872015715, 0.7514495100334264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 25}], {
             RGBColor[
             0.7814420691727634, 0.8068428114651084, 0.666502637240134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 59}], {
             RGBColor[
             0.516383766894903, 0.6181400893674647, 0.9551046267077723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.6032826317786147, 0.6888110439075521, 0.9619117651521593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 86}], {
             RGBColor[
             0.4879611145029988, 0.5935218164296439, 0.9532935604305248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 87}], {
             RGBColor[
             0.7859686037949694, 0.8312106955650405, 0.9046734035026598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 95}], {
             RGBColor[
             0.7817942234386319, 0.8080307104936368, 0.6678706900642806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 108}], {
             RGBColor[
             0.6825976109082605, 0.7510751508326818, 0.9696102227606116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 154}], {
             RGBColor[
             0.7852450872055535, 0.8309115028617888, 0.9166639457901922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 161}], {
             RGBColor[
             0.4463108010091732, 0.5574383614954901, 0.9506399339170767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 175}], {
             RGBColor[
             0.4521802655001208, 0.5625302434211127, 0.9510136363718239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 193}], {
             RGBColor[
             0.4503245613855142, 0.5609229257874412, 0.950895392546576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 16}], {
             RGBColor[
             0.35048029688204574`, 0.4779901503324755, 0.9435532724931343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 64}], {
             RGBColor[
             0.5003009692996179, 0.6031608120163909, 0.9543697328740091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 69}], {
             RGBColor[
             0.38979245396039097`, 0.512040364907272, 0.9460582083797908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 82}], {
             RGBColor[
             0.34829886890839834`, 0.4761007070634601, 0.9434142738316145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 83}], {
             RGBColor[
             0.316923827731624, 0.4440344737616491, 0.9415941582521057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 86}], {
             RGBColor[
             0.38497945202400186`, 0.5078715845384828, 0.9457515281523746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 101}], {
             RGBColor[
             0.3149218240784437, 0.4419302409877936, 0.941480147105756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 108}], {
             RGBColor[
             0.5796159484292636, 0.6654249189415207, 0.9620681904824614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 110}], {
             RGBColor[
             0.49151316787654187`, 0.5960264789351953, 0.9536779249552072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 124}], {
             RGBColor[
             0.3345268948480242, 0.4625364133999037, 0.9425966268829805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 127}], {
             RGBColor[
             0.34979347533914956`, 0.4773952600326733, 0.9435095088317533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 137}], {
             RGBColor[
             0.31409319630205523`, 0.44105930065677384`, 0.9414329579797356]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 161}], {
             RGBColor[
             0.34332913853017627`, 0.471788129604329, 0.9430979016389265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 175}], {
             RGBColor[
             0.34919860302112393`, 0.4768800115299515, 0.9434716040936737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 176}], {
             RGBColor[
             0.3360981234854725, 0.4641878743195114, 0.9426861060294587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 187}], {
             RGBColor[
             0.33041322067136836`, 0.4582126810182313, 0.9423623592242556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 199}], {
             RGBColor[
             0.3251439087147671, 0.45267430005816894`, 0.9420622797035756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 15}], {
             RGBColor[
             0.3709417656089321, 0.49571284612038347`, 0.9448570591870451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 48}], {
             RGBColor[
             0.36693773655078116`, 0.49224475739856516`, 0.9446019259960836]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 59}], {
             RGBColor[
             0.43278883650636024`, 0.549281670407568, 0.9487978998554119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 186}], {
             RGBColor[
             0.34940158280640243`, 0.47458578186823513`, 0.9435749780704197]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 193}], {
             RGBColor[
             0.36672963099697153`, 0.49206450682754455`, 0.9445886656942154]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 28}], {
             RGBColor[
             0.3099437764026754, 0.4415879053428414, 0.9410176111660472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 48}], {
             RGBColor[
             0.32110672796259787`, 0.4525482412929506, 0.9416816146556142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 59}], {
             RGBColor[
             0.38695782791817696`, 0.5095851543019536, 0.9458775885149424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 63}], {
             RGBColor[
             0.33898161598962545`, 0.46803057088396705`, 0.9428205867145535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 77}], {
             RGBColor[
             0.31275241202724346`, 0.4445399594620464, 0.9411775588098623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 106}], {
             RGBColor[
             0.3000813368943679, 0.43122185610482894`, 0.9404559598262209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.3132800245584588, 0.44509451368492026`, 0.9412076055629822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 140}], {
             RGBColor[
             0.31530720692745856`, 0.4472252108855248, 0.9413230505999493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 193}], {
             RGBColor[
             0.32089862240878825`, 0.45236799072193, 0.941668354353746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 64}], {
             RGBColor[
             0.47278195616545676`, 0.5793252259853976, 0.9526162456912082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 83}], {
             RGBColor[
             0.2894048145974629, 0.4201988877306557, 0.9398406710693048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 86}], {
             RGBColor[
             0.3574604388898408, 0.48403599850748935`, 0.9439980409695737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 101}], {
             RGBColor[
             0.28740281094428266`, 0.4180946549568002, 0.9397266599229551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 124}], {
             RGBColor[
             0.3070078817138632, 0.43870082736891025`, 0.9408431397001796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 127}], {
             RGBColor[
             0.3222744622049885, 0.4535596740016799, 0.9417560216489524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 137}], {
             RGBColor[
             0.2865741831678942, 0.41722371462578045`, 0.9396794707969347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 161}], {
             RGBColor[
             0.3158101253960152, 0.4479525435733356, 0.9413444144561256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 175}], {
             RGBColor[
             0.3216795898869629, 0.4530444254989581, 0.9417181169108728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 176}], {
             RGBColor[
             0.30857911035131147`, 0.440352288288518, 0.9409326188466578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.3028942075372073, 0.43437709498723787`, 0.9406088720414547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 193}], {
             RGBColor[
             0.3198238857723562, 0.4514371078652866, 0.9415998730856248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 199}], {
             RGBColor[
             0.29762489558060606`, 0.42883871402717555`, 0.9403087925207747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 20}], {
             RGBColor[
             0.23211977265146783`, 0.3613029766732719, 0.9365302497108459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 28}], {
             RGBColor[
             0.2668075494695581, 0.39776202944116235`, 0.938505667284669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 77}], {
             RGBColor[
             0.26961618509412616`, 0.4007140835603673, 0.9386656149284841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 106}], {
             RGBColor[
             0.25694510996125053`, 0.38739598020314986`, 0.9379440159448427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 112}], {
             RGBColor[
             0.27014379762534146`, 0.4012686377832412, 0.938695661681604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 140}], {
             RGBColor[
             0.27217097999434126`, 0.4033993349838457, 0.9388111067185709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 189}], {
             RGBColor[
             0.23511483918268133`, 0.3644509814957634, 0.9367008143189947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 47}], {
             RGBColor[
             0.38494609227374893`, 0.5078426899995235, 0.9457494024985874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 54}], {
             RGBColor[
             0.295588460550005, 0.42712274502129255`, 0.9401772792428172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 58}], {
             RGBColor[
             0.2912619493997384, 0.4225753074857117, 0.9399308908333093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 61}], {
             RGBColor[
             0.2960837334123488, 0.42764330820172913`, 0.9402054842996372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 73}], {
             RGBColor[
             0.3057525961329822, 0.4378058959624189, 0.9407561117277767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 94}], {
             RGBColor[
             0.36824895343507874`, 0.4933804675600669, 0.9446854755764875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 115}], {
             RGBColor[
             0.2919621879503136, 0.4233113026000546, 0.9399707683828544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 116}], {
             RGBColor[
             0.35397661933935576`, 0.48101848911472117`, 0.9437760550684375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 153}], {
             RGBColor[
             0.4521702655292919, 0.5624670752629113, 0.9510280595422927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 160}], {
             RGBColor[
             0.34254111760690553`, 0.47111363227910186`, 0.9430473950100628]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 174}], {
             RGBColor[
             0.3498905326098686, 0.47747932616232985`, 0.9435156932352192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 188}], {
             RGBColor[
             0.49151222590235866`, 0.5940651201386887, 0.9543587093121076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 33}], {
             RGBColor[
             0.29372081640032377`, 0.4247279965866454, 0.9400867276419496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 34}], {
             RGBColor[
             0.25807475059694696`, 0.38858330413461983`, 0.938008347307892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 44}], {
             RGBColor[
             0.2739128300859531, 0.40523012986980433`, 0.9389103025044521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 50}], {
             RGBColor[
             0.2533169376668154, 0.3835825410822887, 0.9377373969000744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 60}], {
             RGBColor[
             0.25917942342753286`, 0.38974438531986844`, 0.9380712567913769]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 90}], {
             RGBColor[
             0.32617520722218063`, 0.45283835871142575`, 0.9421546927268274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 130}], {
             RGBColor[
             0.2508128361327613, 0.38095057160079043`, 0.9375947920221963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 141}], {
             RGBColor[
             0.31187008513103276`, 0.44044798095241544`, 0.9412431829967022]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 177}], {
             RGBColor[
             0.2790041774695689, 0.41058145878005325`, 0.9392002472059755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.2600890189665118, 0.39070042790302345`, 0.9381230569116956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 77}], {
             RGBColor[
             0.2628976545910799, 0.3936524820222284, 0.9382830045555108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 106}], {
             RGBColor[
             0.25022657945820426`, 0.38033437866501096`, 0.9375614055718693]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 189}], {
             RGBColor[
             0.2283963086796351, 0.35738937995762443`, 0.9363182039460214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.28199072307706635`, 0.41303118579725295`, 0.9393955660070041]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 46}], {
             RGBColor[
             0.4569720284859443, 0.5663064733841641, 0.9514223432183879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 85}], {
             RGBColor[
             0.3381783439476214, 0.46733481701480994`, 0.9427694029303426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 109}], {
             RGBColor[
             0.32687230511240406`, 0.45754209443377936`, 0.9420489921333002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 132}], {
             RGBColor[
             0.28420798371714023`, 0.41536166731241486`, 0.9395218357203131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 150}], {
             RGBColor[
             0.29956418872733326`, 0.4315020124177601, 0.9403963488781741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 151}], {
             RGBColor[
             0.33403902527338425`, 0.46374954722739153`, 0.9425056492046759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 194}], {
             RGBColor[
             0.33236539581814195`, 0.4622999335123229, 0.9423990070157204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 196}], {
             RGBColor[
             0.4056875246476441, 0.5246714028276624, 0.9473850392149095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 24}], {
             RGBColor[
             0.6225902394734423, 0.3300989620118385, 0.4379481515395359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 37}], {
             RGBColor[
             0.626612488125885, 0.33432660037084994`, 0.4381772126499089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 38}], {
             RGBColor[
             0.8845506627730023, 0.5259516883218133, 0.23271022291823168`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 79}], {
             RGBColor[
             0.6309372892797696, 0.33887224059181326`, 0.43842350367765265`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 89}], {
             RGBColor[
             0.84761198290322, 0.36697214106389997`, 0.19322659463915418`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 118}], {
             RGBColor[
             0.8673837475077953, 0.5395378434117971, 0.45731224525585845`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 119}], {
             RGBColor[
             0.7512406956376406, 0.44751187274529963`, 0.44641063184908925`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 122}], {
             RGBColor[
             0.8939273477768698, 0.5574023350297646, 0.28436739782559384`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 128}], {
             RGBColor[
             0.8594750767508397, 0.42546671823825916`, 0.20330663416839254`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 138}], {
             RGBColor[
             0.8672064638387251, 0.45893151148565325`, 0.20967297325920412`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 144}], {
             RGBColor[
             0.8484532037403029, 0.37343813304304, 0.19403214866276774`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 149}], {
             RGBColor[
             0.6408039078801677, 0.34924268232058286`, 0.43898539301059114`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 181}], {
             RGBColor[
             0.8910578733822835, 0.5575636367110436, 0.4299003396380736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 183}], {
             RGBColor[
             0.8495847316428689, 0.3805569710517512, 0.19505388777575874`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 190}], {
             RGBColor[
             0.6228502592156624, 0.3303722592471158, 0.4379629592791906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 192}], {
             RGBColor[
             0.8353875718603139, 0.2730099610170472, 0.18152048481896965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 25}], {
             RGBColor[
             0.9862503262702172, 0.9646170985208886, 0.4575613230413248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 43}], {
             RGBColor[
             0.9014366337014165, 0.6139370032291189, 0.31460356700739317`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 49}], {
             RGBColor[
             0.8876847855307123, 0.5082342720907941, 0.3014347816686359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 64}], {
             RGBColor[
             0.8080908888760686, 0.8465853309633324, 0.7529704509533501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 67}], {
             RGBColor[
             0.8766635128599496, 0.4235199407908321, 0.29088079851236637`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 87}], {
             RGBColor[
             0.9907768608924232, 0.9889849826208208, 0.6957320893038507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 95}], {
             RGBColor[
             0.9866024805360858, 0.9658049975494172, 0.45892937586547133`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 103}], {
             RGBColor[
             0.9073868883324812, 0.6473301594421497, 0.31981821239601227`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 108}], {
             RGBColor[
             0.8874058680057144, 0.9088494378884622, 0.7606689085618024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 129}], {
             RGBColor[
             0.9919194200162629, 0.9837402828928126, 0.4795846817261888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 131}], {
             RGBColor[
             0.9464189057965813, 0.8120568568548516, 0.39007974658807487`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 143}], {
             RGBColor[
             0.8783920111917808, 0.4368059364020854, 0.2925360104669875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 154}], {
             RGBColor[
             0.9900533443030074, 0.9886857899175692, 0.707722631591383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 162}], {
             RGBColor[
             0.9882402059749112, 0.9877215722762983, 0.728168038634343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.22783801619652955`, 0.3568025791600926, 0.9362864100150281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 37}], {
             RGBColor[
             0.18496037581804925`, 0.31173546052289103`, 0.9338445918272582]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 56}], {
             RGBColor[
             0.1789270014196926, 0.30539400149218693`, 0.9335010000808495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 79}], {
             RGBColor[
             0.1914475775488761, 0.318553920854336, 0.9342140283688739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 89}], {
             RGBColor[
             0.6289704896989408, 0.3791403610884968, 0.44405788636093535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 118}], {
             RGBColor[
             0.5461172648909147, 0.6195523250843118, 0.9625471407361825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 119}], {
             RGBColor[
             0.37190268708568275`, 0.48151336908456555`, 0.9461947206260288]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 125}], {
             RGBColor[
             0.17894341561590066`, 0.30541125385312173`, 0.9335019348450408]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 144}], {
             RGBColor[
             0.6306529313731064, 0.3920723450467769, 0.44566899440816243`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 149}], {
             RGBColor[
             0.20624750544947348`, 0.3341095834474904, 0.9350568623682817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 170}], {
             RGBColor[
             0.18064618334875748`, 0.3072009707020641, 0.9335989049484079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 190}], {
             RGBColor[
             0.1793170324527155, 0.3058039488372898, 0.9335232117711809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 195}], {
             RGBColor[
             0.1789270014196926, 0.30539400149218693`, 0.9335010000808495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 197}], {
             RGBColor[
             0.5339219982745609, 0.6098281505161249, 0.9613839453194717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[
             0.8965507517688224, 0.5978985527381435, 0.25797231847853164`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 49}], {
             RGBColor[
             0.8827989035981182, 0.49219582159981873`, 0.2448035331397743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 64}], {
             RGBColor[
             0.8007620659771775, 0.8225276552268693, 0.6680235781600576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 67}], {
             RGBColor[
             0.8717776309273555, 0.4074814902998567, 0.23424954998350475`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 87}], {
             RGBColor[
             0.9834480379935321, 0.9649273068843578, 0.6107852165105583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 95}], {
             RGBColor[
             0.9792736576371948, 0.9417473218129542, 0.37398250307217895`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 103}], {
             RGBColor[
             0.9025010063998871, 0.6312917089511744, 0.2631869638671507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 108}], {
             RGBColor[
             0.8800770451068233, 0.8847917621519991, 0.6757220357685101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 129}], {
             RGBColor[
             0.9845905971173718, 0.9596826071563495, 0.39463780893289646`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 131}], {
             RGBColor[
             0.93909008289769, 0.7879991811183886, 0.30513287379478254`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 143}], {
             RGBColor[
             0.8735061292591867, 0.42076748591111013`, 0.23590476193812596`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 154}], {
             RGBColor[
             0.9827245214041163, 0.9646281141811062, 0.6227757587980907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 162}], {
             RGBColor[
             0.9809113830760201, 0.9636638965398352, 0.6432211658410507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 40}], {
             RGBColor[
             0.4439921507491714, 0.557946476502165, 0.9497988277939646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 51}], {
             RGBColor[
             0.3392714220793772, 0.4658216765666159, 0.9429291222497664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 74}], {
             RGBColor[
             0.3495927399015075, 0.4766700360070217, 0.9435169060307154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 80}], {
             RGBColor[
             0.5081499735315052, 0.6100326873138424, 0.9548495666212384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 121}], {
             RGBColor[
             0.46953919243500225`, 0.5786867158238351, 0.9518099844973704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 158}], {
             RGBColor[
             0.3248339638099492, 0.45064699253772245`, 0.9421069303596279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 164}], {
             RGBColor[
             0.34556297092325194`, 0.47243449330876475`, 0.9432874166489127]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.3936636675304358, 0.5153934155287933, 0.9463048786852943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 169}], {
             RGBColor[
             0.3344928369204973, 0.4607990805848347, 0.9426569888942514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 184}], {
             RGBColor[
             0.38376793461067366`, 0.5068222290476936, 0.9456743313341002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 37}], {
             RGBColor[
             0.23387138917519362`, 0.3631440366986098, 0.9366300016805876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 56}], {
             RGBColor[
             0.22783801477683696`, 0.3568025776679057, 0.9362864099341788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 67}], {
             RGBColor[
             0.6377201396548048, 0.23003206781698532`, 0.42306867319027985`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 119}], {
             RGBColor[
             0.4208137004428272, 0.5329219452602844, 0.9489801304793581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 125}], {
             RGBColor[
             0.22785442897304503`, 0.35681983002884055`, 0.9362873446983702]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 128}], {
             RGBColor[
             0.5831652721126257, 0.49985421349972364`, 0.5843241339583132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 133}], {
             RGBColor[
             0.6412015723944939, 0.2567918854277903, 0.42640249711352196`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 190}], {
             RGBColor[
             0.22822804580985986`, 0.3572125250130086, 0.9363086216245102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 195}], {
             RGBColor[
             0.22783801477683696`, 0.3568025776679057, 0.9362864099341788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 48}], {
             RGBColor[
             0.30593974734452445`, 0.4381198166210231, 0.9407624779750857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 63}], {
             RGBColor[
             0.3238146353715521, 0.45360214621203954`, 0.941901450034025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 77}], {
             RGBColor[
             0.29758543140917015`, 0.4301115347901189, 0.9402584221293339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 106}], {
             RGBColor[
             0.28491435627629447`, 0.41679343143290143`, 0.9395368231456924]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 112}], {
             RGBColor[
             0.2981130439403854, 0.43066608901299275`, 0.9402884688824538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 140}], {
             RGBColor[
             0.3001402263093852, 0.4327967862135973, 0.9404039139194207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 189}], {
             RGBColor[
             0.26308408549772533`, 0.39384843272551495`, 0.9382936215198444]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 35}], {
             RGBColor[
             0.9160081618564544, 0.9327996859082862, 0.8697305761183244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 47}], {
             RGBColor[
             0.7225823732127437, 0.7785731992059557, 0.8525033535115121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 88}], {
             RGBColor[
             0.8529188119611348, 0.8833651723657042, 0.8634818621932413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 89}], {
             RGBColor[
             0.9005424949414248, 0.6078887731128675, 0.3845626076055324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 113}], {
             RGBColor[
             0.946972557498295, 0.8159080843147557, 0.4967685640741427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 122}], {
             RGBColor[
             0.9932906731582525, 0.9894716805478189, 0.6138869514576812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 136}], {
             RGBColor[
             0.950824845750427, 0.8323116913697606, 0.49992668872926316`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 138}], {
             RGBColor[
             0.9532093472510355, 0.8417654452316519, 0.5018453146080967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 142}], {
             RGBColor[
             0.8172660326623933, 0.855490432397475, 0.8599437218958297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 144}], {
             RGBColor[
             0.9022249366155904, 0.6208207570711475, 0.3861737156527596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 153}], {
             RGBColor[
             0.7898065464682866, 0.8331975844693433, 0.8577820105552174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 159}], {
             RGBColor[
             0.879643980418662, 0.4472536327034553, 0.36455016649703853`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 167}], {
             RGBColor[
             0.9544593958943188, 0.963459656199136, 0.8733980891466777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 181}], {
             RGBColor[
             0.988986461566373, 0.9897136330697374, 0.8321863641764009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 188}], {
             RGBColor[
             0.8291485068413533, 0.8647956293451209, 0.8611126603250323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 41}], {
             RGBColor[
             0.7217306402299773, 0.781717727178925, 0.9737111260908631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 65}], {
             RGBColor[
             0.9079204151899432, 0.9294151105020584, 0.9910794537825813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 66}], {
             RGBColor[
             0.7926835884248224, 0.8385659113515402, 0.9798127368656795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 90}], {
             RGBColor[
             0.6408480095261183, 0.7142786377339077, 0.9678341664939911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 110}], {
             RGBColor[
             0.7493871054318795, 0.8041704915393881, 0.9758883443405271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 162}], {
             RGBColor[
             0.9383242239537981, 0.9524410659335498, 0.9517777399403218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 180}], {
             RGBColor[
             0.8089076786179981, 0.8512402939181014, 0.9814298025533923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 198}], {
             RGBColor[
             0.7949540018905729, 0.840339575606766, 0.9800390304617252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 38}], {
             RGBColor[
             0.9076583192648293, 0.8882942413173389, 0.6516953277782057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[
             0.6710448937244029, 0.7408816350846033, 0.9693608389875064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 46}], {
             RGBColor[
             0.7241254080647266, 0.7839747878759986, 0.9735395315167075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 80}], {
             RGBColor[
             0.7352027165067365, 0.7929678458962808, 0.9744115778147804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 98}], {
             RGBColor[
             0.9119983758560902, 0.9316922814327566, 0.9576824339727095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 117}], {
             RGBColor[
             0.8147533586460658, 0.8554575003050673, 0.9821051874244302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 120}], {
             RGBColor[
             0.9036386065731989, 0.8747348065350462, 0.6360795030302686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 121}], {
             RGBColor[
             0.6965919354102337, 0.7616218744062735, 0.9713719956909121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 146}], {
             RGBColor[
             0.8233014482367667, 0.8621353328612098, 0.9829571811083924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 151}], {
             RGBColor[
             0.6011924048521665, 0.6814178617192261, 0.9646228375029955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 171}], {
             RGBColor[
             0.8624892635832501, 0.8931895434066397, 0.9867461899854671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 173}], {
             RGBColor[
             0.9228248907460509, 0.93782630255951, 0.8490773539223448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 178}], {
             RGBColor[
             0.8964701273649321, 0.9201113391332241, 0.9839677082524034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 196}], {
             RGBColor[
             0.6728409042264264, 0.742339717319497, 0.969502227513229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 53}], {
             RGBColor[
             0.2232819677009355, 0.3520138833210643, 0.9360269497932738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 82}], {
             RGBColor[
             0.27687504662639884`, 0.4074326830017036, 0.9391123497539292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 83}], {
             RGBColor[
             0.2455000054496245, 0.37536644969989263`, 0.9372922341744203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 100}], {
             RGBColor[
             0.22448297168171977`, 0.35327621465291903`, 0.9360953451932534]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 101}], {
             RGBColor[
             0.2434980017964442, 0.3732622169260371, 0.9371782230280707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 123}], {
             RGBColor[
             0.24279155375346242`, 0.3725196952414703, 0.9371379918571192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 127}], {
             RGBColor[
             0.2783696530571501, 0.40872723597091687`, 0.9392075847540681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 130}], {
             RGBColor[
             0.23618787859936186`, 0.36557881395732306`, 0.936761922326355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 135}], {
             RGBColor[
             0.23421532693659433`, 0.36350553709275546`, 0.9366495884272892]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 148}], {
             RGBColor[
             0.219972379693155, 0.3485352964848875, 0.9358384736523275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 163}], {
             RGBColor[
             0.23408691252963393`, 0.3633705654090964, 0.9366422754167848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 165}], {
             RGBColor[
             0.2270272954930984, 0.35595046029812505`, 0.9362402406703216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 176}], {
             RGBColor[
             0.264674301203473, 0.39551985025775493`, 0.9383841819517735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 187}], {
             RGBColor[
             0.2589893983893689, 0.38954465695647483`, 0.9380604351465702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 41}], {
             RGBColor[
             0.4363770738073567, 0.5497722412161976, 0.9497497290534018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 44}], {
             RGBColor[
             0.3032320659672701, 0.4347249229295589, 0.9406283792341544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 57}], {
             RGBColor[
             0.3418089819131736, 0.4704794931394012, 0.9430007439710605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 66}], {
             RGBColor[
             0.5073300220022017, 0.606620425388813, 0.955851339828218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 90}], {
             RGBColor[
             0.35549444310349765`, 0.4823331517711803, 0.9438727694565298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 141}], {
             RGBColor[
             0.3411893210123498, 0.46994277401217005`, 0.9429612597264045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 198}], {
             RGBColor[
             0.5096004354679522, 0.6083940896440386, 0.956077633424264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 44}], {
             RGBColor[
             0.2675860001638932, 0.3985802304775334, 0.9385499989000968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 50}], {
             RGBColor[
             0.2469901077447556, 0.3769326416900177, 0.9373770932957193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 60}], {
             RGBColor[
             0.25285259350547307`, 0.38309448592759754`, 0.9377109531870217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 90}], {
             RGBColor[
             0.31984837730012083`, 0.4461884593191548, 0.9417943891224722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 104}], {
             RGBColor[
             0.2353413665909268, 0.3646890761644966, 0.936713714719777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 130}], {
             RGBColor[
             0.2444860062107015, 0.3743006722085195, 0.9372344884178412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 163}], {
             RGBColor[
             0.24238504014097356`, 0.3720924236602928, 0.9371148415082708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 177}], {
             RGBColor[
             0.27267734754750905`, 0.40393155938778236`, 0.9388399436016203]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 47}], {
             RGBColor[
             0.6449475165023608, 0.7197336460567563, 0.9672187657343465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 68}], {
             RGBColor[
             0.8469990595612139, 0.880838075189855, 0.985268720497577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 88}], {
             RGBColor[
             0.775283955250752, 0.8245256192165048, 0.9781972744160757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.6282503776636906, 0.7052714236172997, 0.9661548388122466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 111}], {
             RGBColor[
             0.6494345587146366, 0.7234252020636741, 0.9675585260086426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 116}], {
             RGBColor[
             0.6139780435679677, 0.6929094451719539, 0.9652454183041966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 122}], {
             RGBColor[
             0.9156558164478696, 0.9306321273986194, 0.7286023636805157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 138}], {
             RGBColor[
             0.8755744905406526, 0.7829258920824524, 0.6165607268309311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 142}], {
             RGBColor[
             0.7396311759520104, 0.7966508792482756, 0.9746591341186641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 153}], {
             RGBColor[
             0.7121716897579038, 0.7743580313201439, 0.9724974227780518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 157}], {
             RGBColor[
             0.6980290555794366, 0.7628764037756551, 0.971384062809347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 160}], {
             RGBColor[
             0.6025425418355174, 0.6830045883363345, 0.9645167582458221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 167}], {
             RGBColor[
             0.876824539183936, 0.9046201030499366, 0.9881135013695121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 174}], {
             RGBColor[
             0.6098919568384804, 0.6893702822195625, 0.9649850564709783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 181}], {
             RGBColor[
             0.9113516048559902, 0.930874079920538, 0.9469017763992353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 185}], {
             RGBColor[
             0.8039733137479249, 0.8469379641216965, 0.9810567615537757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 188}], {
             RGBColor[
             0.7515136501309705, 0.8059560761959215, 0.9758280725478667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 132}], {
             RGBColor[
             0.24999710016017773`, 0.3800931813729572, 0.937548337065331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 151}], {
             RGBColor[
             0.2998281417164218, 0.4284810612879339, 0.9405321505496939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 169}], {
             RGBColor[
             0.260181316759984, 0.39079743873598083`, 0.9381283131344916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 200}], {
             RGBColor[
             0.24218408124275126`, 0.3718812031167312, 0.9371033971963092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 56}], {
             RGBColor[
             0.18496037439835666`, 0.3117354590307041, 0.9338445917464089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 79}], {
             RGBColor[
             0.19748095052754017`, 0.3248953783928531, 0.9345576200344334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 118}], {
             RGBColor[
             0.5521506378695789, 0.625893782622829, 0.962890732401742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 119}], {
             RGBColor[
             0.3779360600643469, 0.4878548266230827, 0.9465383122915882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 125}], {
             RGBColor[
             0.18497678859456473`, 0.3117527113916389, 0.9338455265106003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 128}], {
             RGBColor[
             0.5402876317341454, 0.454787094862522, 0.5818823157705433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 149}], {
             RGBColor[
             0.21228087842813756`, 0.34045104098600754`, 0.9354004540338412]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 170}], {
             RGBColor[
             0.18667955632742156`, 0.31354242824058126`, 0.9339424966139673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 190}], {
             RGBColor[
             0.18535040543137957`, 0.3121454063758069, 0.9338668034367403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 195}], {
             RGBColor[
             0.18496037439835666`, 0.3117354590307041, 0.9338445917464089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 46}], {
             RGBColor[
             0.7812753615379626, 0.7886327284729578, 0.6396314180362879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 98}], {
             RGBColor[
             0.9691483293293262, 0.9363502220297157, 0.6237743204922899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 117}], {
             RGBColor[
             0.8719033121193018, 0.8601154409020264, 0.6481970739440106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 120}], {
             RGBColor[
             0.960788560046435, 0.8793927471320053, 0.302171389549849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 128}], {
             RGBColor[
             0.9271948937048214, 0.742224726788967, 0.2736818311730274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 146}], {
             RGBColor[
             0.8804514017100027, 0.8667932734581691, 0.6490490676279728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 156}], {
             RGBColor[
             0.9428260097167436, 0.9163360030821683, 0.6550496534880772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 171}], {
             RGBColor[
             0.919639217056486, 0.8978474840035989, 0.6528380765050477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 178}], {
             RGBColor[
             0.9536200808381681, 0.9247692797301834, 0.650059594771984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 179}], {
             RGBColor[
             0.8863710041657746, 0.8714177118872631, 0.6496390782789341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 183}], {
             RGBColor[
             0.8948764104777984, 0.602162747374174, 0.2424745440128403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 192}], {
             RGBColor[
             0.8664820909126885, 0.38706872730476605`, 0.21540773809926206`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 114}], {
             RGBColor[
             0.20908858865686974`, 0.3370957420335433, 0.935218657853937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 46}], {
             RGBColor[
             0.5446619359975361, 0.6412201222402223, 0.9572969292455886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 74}], {
             RGBColor[
             0.3971820108095485, 0.5168505289536836, 0.9468363149531384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.555739244439546, 0.6502131802605045, 0.9581689755436615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 117}], {
             RGBColor[
             0.6352898865788753, 0.7127028346692909, 0.9658625851533114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 121}], {
             RGBColor[
             0.5171284633430432, 0.6188672087704971, 0.9551293934197934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 166}], {
             RGBColor[
             0.4412529384384768, 0.5555739084754552, 0.9496242876077174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 169}], {
             RGBColor[
             0.38208210782853824`, 0.5009795735314966, 0.9459763978166744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 171}], {
             RGBColor[
             0.6830257915160596, 0.7504348777708634, 0.9705035877143484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 173}], {
             RGBColor[
             0.7433614186788604, 0.7950716369237336, 0.832834751651226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 196}], {
             RGBColor[
             0.49337743215923585`, 0.5995850516837207, 0.9532596252421102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 57}], {
             RGBColor[
             0.4551460034388895, 0.5660289447091988, 0.9509456686528102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 66}], {
             RGBColor[
             0.6206670435279176, 0.7021698769586107, 0.9637962645099678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 81}], {
             RGBColor[
             0.563023955866433, 0.6561272371693612, 0.9587424547119633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 90}], {
             RGBColor[
             0.46883146462921355`, 0.577882603340978, 0.9518176941382794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 141}], {
             RGBColor[
             0.4545263425380657, 0.5654922255819677, 0.9509061844081543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 168}], {
             RGBColor[
             0.7441532266042006, 0.7995222771759883, 0.9732629767804062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 172}], {
             RGBColor[
             0.7718454040169196, 0.8174234076188627, 0.7717375932565325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 184}], {
             RGBColor[
             0.46042354235664473`, 0.5706000836629397, 0.9512819487659052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 198}], {
             RGBColor[
             0.6229374569936681, 0.7039435412138363, 0.9640225581060137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 88}], {
             RGBColor[
             0.6168180360411716, 0.6987299024450158, 0.9637087446681081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[
             0.401201459999004, 0.517503689481011, 0.9473903200062829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 102}], {
             RGBColor[
             0.4476381958746549, 0.5602937273030086, 0.9502551687958871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 153}], {
             RGBColor[
             0.5537057705483233, 0.648562314548655, 0.9580088930300842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 49}], {
             RGBColor[
             0.8484894518822184, 0.3737167521458401, 0.1940668599244025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 67}], {
             RGBColor[
             0.8429788155468371, 0.3313595864958591, 0.18878986834626774`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 87}], {
             RGBColor[
             0.8995684415169597, 0.6141438088047649, 0.4167528293202155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 95}], {
             RGBColor[
             0.8967855212794014, 0.5986904854238292, 0.25888435369462925`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 103}], {
             RGBColor[
             0.8583405032831029, 0.4432646958215179, 0.2032585752880907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 129}], {
             RGBColor[
             0.9003301475995195, 0.6106473423194261, 0.27265455760177426`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 131}], {
             RGBColor[
             0.869996471453065, 0.49619172496078556`, 0.21298460084303164`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 133}], {
             RGBColor[
             0.8447195319166816, 0.3447394953012616, 0.19045678030788885`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 143}], {
             RGBColor[
             0.8438430647127526, 0.3380025843014858, 0.18961747432357834`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 154}], {
             RGBColor[
             0.8990860971240158, 0.6139443470025971, 0.4247465241785704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 197}], {
             RGBColor[
             0.8665492485482925, 0.589132844492627, 0.463523131888269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 50}], {
             RGBColor[
             0.2628281872337618, 0.3935794674252022, 0.9382790484922793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 57}], {
             RGBColor[
             0.3220009955988029, 0.4509816264225601, 0.9418243188335629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 60}], {
             RGBColor[
             0.2686906729944792, 0.399741311662782, 0.9386129083835817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 90}], {
             RGBColor[
             0.33568645678912695`, 0.46283528505433924`, 0.9426963443190322]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 141}], {
             RGBColor[
             0.321381334697979, 0.45044490729532893`, 0.941784834588907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 177}], {
             RGBColor[
             0.2885154270365152, 0.4205783851229668, 0.9397418987981803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 120}], {
             RGBColor[
             0.9205644172331103, 0.7168104234407002, 0.25588752113131463`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 128}], {
             RGBColor[
             0.8869707508914968, 0.5796424030976618, 0.22739796275449303`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 168}], {
             RGBColor[
             0.9114761724933723, 0.7607551980488345, 0.6070253886431892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 172}], {
             RGBColor[
             0.9391683499060914, 0.7786563284917088, 0.4055000051193155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 173}], {
             RGBColor[
             0.9397507014059623, 0.7799019194651641, 0.46888537202339087`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 85}], {
             RGBColor[
             0.4789487657995369, 0.5853416186622634, 0.9528226814867443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 98}], {
             RGBColor[
             0.7856154181292234, 0.8320307685883754, 0.9456185242307917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 99}], {
             RGBColor[
             0.5809189759498203, 0.6706552206345228, 0.960151216244546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 109}], {
             RGBColor[
             0.4676427269643195, 0.5755488960812328, 0.9521022706897019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 117}], {
             RGBColor[
             0.6883704009191991, 0.7557959874606861, 0.9700412776825125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 121}], {
             RGBColor[
             0.570208977683367, 0.6619603615618923, 0.9593080859489944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 146}], {
             RGBColor[
             0.6969184905099, 0.7624738200168288, 0.9708932713664746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 151}], {
             RGBColor[
             0.4748094471252997, 0.581756348874845, 0.9525589277610778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 171}], {
             RGBColor[
             0.7361063058563833, 0.7935280305622586, 0.9746822802435494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 178}], {
             RGBColor[
             0.7700871696380653, 0.8204498262888431, 0.9719037985104857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 196}], {
             RGBColor[
             0.5464579464995596, 0.642678204475116, 0.9574383177713113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 54}], {
             RGBColor[
             0.3621640961349061, 0.48478721437619465`, 0.9444194198717641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 61}], {
             RGBColor[
             0.36265936899724993`, 0.48530777755663124`, 0.944447624928584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 73}], {
             RGBColor[
             0.3723282317178833, 0.495470365317321, 0.9449982523567235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 88}], {
             RGBColor[
             0.5818581666070413, 0.6702991325141743, 0.9609700518092634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 94}], {
             RGBColor[
             0.4348245890199799, 0.551044936914969, 0.9489276162054343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 105}], {
             RGBColor[
             0.3973660260121461, 0.5186002123597028, 0.9465407896938819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 111}], {
             RGBColor[
             0.45600877007092583`, 0.5691987153613436, 0.9503313034018304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 116}], {
             RGBColor[
             0.42055225492425696`, 0.5386829584696233, 0.9480181956973843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 126}], {
             RGBColor[
             0.37937335834478547`, 0.5028752400890226, 0.9453994618957948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 142}], {
             RGBColor[
             0.5462053873082997, 0.642424392545945, 0.9574319115118519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 153}], {
             RGBColor[
             0.518745901114193, 0.6201315446178133, 0.9552702001712396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 157}], {
             RGBColor[
             0.5046032669357259, 0.6086499170733246, 0.9541568402025347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 160}], {
             RGBColor[
             0.4091167531918066, 0.528778101634004, 0.9472895356390099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 167}], {
             RGBColor[
             0.6833987505402253, 0.7503936163476059, 0.9708862787627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 174}], {
             RGBColor[
             0.4164661681947697, 0.535143795517232, 0.9477578338641661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 188}], {
             RGBColor[
             0.5580878614872598, 0.6517295894935908, 0.9586008499410545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 59}], {
             RGBColor[
             0.382953798860026, 0.5061170655801353, 0.9456224553239809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.3349775869314745, 0.46456248216214874`, 0.942565453523592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 77}], {
             RGBColor[
             0.30874838296909257`, 0.4410718707402281, 0.9409224256189008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 106}], {
             RGBColor[
             0.29607730783621694`, 0.42775376738301063`, 0.9402008266352594]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 112}], {
             RGBColor[
             0.3092759955003079, 0.44162642496310195`, 0.9409524723720207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 140}], {
             RGBColor[
             0.3113031778693076, 0.4437571221637065, 0.9410679174089878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 193}], {
             RGBColor[
             0.3168945933506373, 0.44889990200011176`, 0.9414132211627845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 67}], {
             RGBColor[
             0.8292269673761329, 0.22565685535753427`, 0.17562108300751042`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.8858165933462555, 0.5084410776664401, 0.4035840439814582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 95}], {
             RGBColor[
             0.8830336731086973, 0.49298775428550434`, 0.24571556835587194`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 103}], {
             RGBColor[
             0.8445886551123987, 0.33756196468319305`, 0.19008978994933337`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 108}], {
             RGBColor[
             0.8169025980884497, 0.455017381178201, 0.44687525682009266`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[
             0.8865782994288154, 0.5049446111811012, 0.25948577226301694`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 131}], {
             RGBColor[
             0.8562446232823608, 0.3904889938224607, 0.19981581550427432`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 133}], {
             RGBColor[
             0.8309676837459775, 0.23903676416293673`, 0.17728799496913153`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 143}], {
             RGBColor[
             0.8300912165420485, 0.23229985316316096`, 0.17644868898482102`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 154}], {
             RGBColor[
             0.8853342489533117, 0.5082416158642724, 0.4115777388398131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 162}], {
             RGBColor[
             0.8841254900679142, 0.5075988041034252, 0.42520801020178634`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 53}], {
             RGBColor[
             0.22682228238214364`, 0.3557349785199296, 0.9362285654769424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 60}], {
             RGBColor[
             0.24809478057534154`, 0.3780937228752663, 0.9374400027792041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 82}], {
             RGBColor[
             0.28041536130760697`, 0.41115377820056886`, 0.9393139654375977]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 100}], {
             RGBColor[
             0.2280232863629279, 0.35699730985178435`, 0.9362969608769219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 104}], {
             RGBColor[
             0.2305835536607953, 0.3596883131121654, 0.9364427643119595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 123}], {
             RGBColor[
             0.24633186843467056`, 0.37624079044033565`, 0.9373396075407877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.23972819328057, 0.3692999091561883, 0.9369635380100236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 163}], {
             RGBColor[
             0.23762722721084206`, 0.36709166060796167`, 0.9368438911004533]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 177}], {
             RGBColor[
             0.2679195346173776, 0.39893079633545114`, 0.9385689931938027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 71}], {
             RGBColor[
             0.2862116459129269, 0.41815696509391576`, 0.9396107018713307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 74}], {
             RGBColor[
             0.29246128213975436`, 0.4247257290181345, 0.9399666094089402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 158}], {
             RGBColor[
             0.267702506048196, 0.39870268554883526`, 0.9385566337378528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 164}], {
             RGBColor[
             0.28843151316149873`, 0.42049018631987756`, 0.9397371200271375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 166}], {
             RGBColor[
             0.33653220976868264`, 0.46344910853990606`, 0.9427545820635193]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 184}], {
             RGBColor[
             0.3266364768489205, 0.4548779220588064, 0.942124034712325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 70}], {
             RGBColor[
             0.2130689137116028, 0.34127931603325223`, 0.9354453314774407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 134}], {
             RGBColor[
             0.22165741455534713`, 0.35030637496243233`, 0.9359344338949436]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 145}], {
             RGBColor[
             0.21010927874609994`, 0.3381685520328137, 0.9352767846445429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 100}], {
             RGBColor[
             0.21261327393044743`, 0.34080040973402737`, 0.9354193834659627]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 104}], {
             RGBColor[
             0.21517354122831484`, 0.34349141299440844`, 0.9355651869010002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 123}], {
             RGBColor[
             0.2309218560021901, 0.36004389032257866`, 0.9364620301298284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 130}], {
             RGBColor[
             0.22431818084808952`, 0.35310300903843134`, 0.9360859605990643]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 135}], {
             RGBColor[
             0.222345629185322, 0.35102973217386374`, 0.9359736266999984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 148}], {
             RGBColor[
             0.20810268194188267`, 0.3360594915659958, 0.9351625119250367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 163}], {
             RGBColor[
             0.2222172147783616, 0.3508947604902047, 0.935966313689494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 165}], {
             RGBColor[
             0.21515759774182608`, 0.3434746553792333, 0.935564278943031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 58}], {
             RGBColor[
             0.2684799532608956, 0.3995198318623828, 0.9386009082064859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 61}], {
             RGBColor[
             0.27330173727350593`, 0.40458783257840025`, 0.9388755016728139]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 73}], {
             RGBColor[
             0.28297059999413937`, 0.41475042033909004`, 0.9394261291009534]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 94}], {
             RGBColor[
             0.3454669572962359, 0.47032499193673805`, 0.9433554929496641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 105}], {
             RGBColor[
             0.3080083942884021, 0.4378802673814718, 0.9409686664381117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 115}], {
             RGBColor[
             0.2691801918114708, 0.40025582697672574`, 0.938640785756031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 116}], {
             RGBColor[
             0.33119462320051296`, 0.4579630134913923, 0.9424460724416142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 126}], {
             RGBColor[
             0.29001572662104147`, 0.4221552951107917, 0.9398273386400247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 160}], {
             RGBColor[
             0.3197591214680627, 0.448058156655773, 0.9417174123832397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 174}], {
             RGBColor[
             0.3271085364710258, 0.454423850539001, 0.942185710608396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 62}], {
             RGBColor[
             0.35430836392456, 0.4813058296004574, 0.9437971935400564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 68}], {
             RGBColor[
             0.6040034340544339, 0.6836766872491769, 0.9648829517187356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 72}], {
             RGBColor[
             0.3011292819316679, 0.4298018950317811, 0.9406079602011264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 75}], {
             RGBColor[
             0.3182717437982659, 0.44781970934843396`, 0.9415841980444295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 76}], {
             RGBColor[
             0.31436618073050393`, 0.4437147149372155, 0.9413617820054831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 96}], {
             RGBColor[
             0.32928937279498216`, 0.459399935982008, 0.942211635716671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 107}], {
             RGBColor[
             0.5098065457970684, 0.609801290788619, 0.955570731517623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 111}], {
             RGBColor[
             0.40643893320785657`, 0.5262638141229958, 0.9471727572298012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 139}], {
             RGBColor[
             0.3007701310464627, 0.42942440467994913`, 0.9405875070895301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 147}], {
             RGBColor[
             0.41653896028796467`, 0.5344634711076623, 0.9479678683591656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 157}], {
             RGBColor[
             0.4550334300726567, 0.5657150158349769, 0.9509982940305055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 182}], {
             RGBColor[
             0.30875284137949693`, 0.43781473937303605`, 0.9410421106336347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 185}], {
             RGBColor[
             0.5609776882411449, 0.6497765761810184, 0.9606709927749343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 191}], {
             RGBColor[
             0.31630641834476525`, 0.445754027687974, 0.9414722756672911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 79}], {
             RGBColor[
             0.1914475761291835, 0.31855391936214905`, 0.9342140282880245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 118}], {
             RGBColor[
             0.5461172634712221, 0.619552323592125, 0.9625471406553332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 119}], {
             RGBColor[
             0.37190268566599016`, 0.4815133675923786, 0.9461947205451795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 125}], {
             RGBColor[
             0.17894341419620807`, 0.3054112523609348, 0.9335019347641915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 129}], {
             RGBColor[
             0.5845933454317087, 0.6420998957641366, 0.6750810838088802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 149}], {
             RGBColor[
             0.2062475040297809, 0.3341095819553035, 0.9350568622874322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 170}], {
             RGBColor[
             0.1806461819290649, 0.30720096920987716`, 0.9335989048675586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 190}], {
             RGBColor[
             0.1793170310330229, 0.30580394734510286`, 0.9335232116903315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 195}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 197}], {
             RGBColor[
             0.5339219968548683, 0.6098281490239381, 0.9613839452386224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 66}], {
             RGBColor[
             0.5260989516337345, 0.6228771288818142, 0.9570472794276266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 71}], {
             RGBColor[
             0.32543061952646807`, 0.4545863786212526, 0.9420196308425695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 81}], {
             RGBColor[
             0.4684558639722499, 0.5768344890925647, 0.951993469629622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 90}], {
             RGBColor[
             0.37426337273503046`, 0.49858985526418154`, 0.9450687090559382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 141}], {
             RGBColor[
             0.35995825064388254`, 0.48619947750517123`, 0.9441571993258131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 198}], {
             RGBColor[
             0.528369365099485, 0.6246507931370399, 0.9572735730236723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 61}], {
             RGBColor[
             0.26897522612323943`, 0.4000403950428194, 0.9386291132633059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 73}], {
             RGBColor[
             0.2786440888438728, 0.4102029828035092, 0.9391797406914454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 92}], {
             RGBColor[
             0.24643437763355744`, 0.3763485341078243, 0.9373454452880156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 115}], {
             RGBColor[
             0.2648536806612042, 0.3957083894411449, 0.9383943973465231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 155}], {
             RGBColor[
             0.25688825427596124`, 0.3873362212730521, 0.9379407780976758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 154}], {
             RGBColor[
             0.7176662191262557, 0.7759253920834623, 0.911377748265729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 186}], {
             RGBColor[
             0.36541764511564734`, 0.4884580900498052, 0.9445955073983169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 193}], {
             RGBColor[
             0.38274569330621644`, 0.5059368150091147, 0.9456091950221126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.2862778470683244, 0.4173156224381487, 0.9396478253289002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 104}], {
             RGBColor[
             0.23644603942151277`, 0.3658501573497452, 0.9367766242032618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 123}], {
             RGBColor[
             0.252194354195388, 0.3824026346779154, 0.9376734674320901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 130}], {
             RGBColor[
             0.2455906790412874, 0.3754617533937681, 0.9372973979013259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 163}], {
             RGBColor[
             0.24348971297155947`, 0.37325350484554143`, 0.9371777509917558]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 177}], {
             RGBColor[
             0.273782020378095, 0.40509264057303096`, 0.9389028530851051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 73}], {
             RGBColor[
             0.28346587285648317`, 0.41527098351952657`, 0.9394543341577734]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 94}], {
             RGBColor[
             0.34596223015857974`, 0.47084555511717463`, 0.9433836980064841]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 105}], {
             RGBColor[
             0.30850366715074595`, 0.4384008305619083, 0.9409968714949317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 115}], {
             RGBColor[
             0.2696754646738146, 0.40077639015716227`, 0.938668990812851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 116}], {
             RGBColor[
             0.3316898960628568, 0.4584835766718288, 0.9424742774984342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 160}], {
             RGBColor[
             0.3202543943304065, 0.44857871983620956`, 0.9417456174400596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 174}], {
             RGBColor[
             0.3276038093333696, 0.4549444137194375, 0.9422139156652158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 68}], {
             RGBColor[
             0.6059297438464823, 0.6853451599719039, 0.965005694475316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 75}], {
             RGBColor[
             0.3201980535903144, 0.44948818207116104`, 0.9417069408010099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 76}], {
             RGBColor[
             0.3162924905225524, 0.44538318765994256`, 0.9414845247620637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 96}], {
             RGBColor[
             0.33121568258703066`, 0.4610684087047351, 0.9423343784732514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 105}], {
             RGBColor[
             0.3497224989411253, 0.4773337838440822, 0.9435049862784333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 107}], {
             RGBColor[
             0.5117328555891169, 0.611469763511346, 0.9556934742742034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 111}], {
             RGBColor[
             0.40836524299990506`, 0.527932286845723, 0.9472954999863816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 116}], {
             RGBColor[
             0.37290872785323614`, 0.4974165299540027, 0.9449823922819357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 126}], {
             RGBColor[
             0.33172983127376465`, 0.4616088115734021, 0.9423636584803461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 157}], {
             RGBColor[
             0.4569597398647052, 0.567383488557704, 0.951121036787086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 174}], {
             RGBColor[
             0.36882264112374896`, 0.4938773670016114, 0.9447220304487174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 182}], {
             RGBColor[
             0.31067915117154543`, 0.43948321209576313`, 0.9411648533902153]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 185}], {
             RGBColor[
             0.5629039980331934, 0.6514450489037454, 0.9607937355315148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 191}], {
             RGBColor[
             0.3182327281368137, 0.4474225004107011, 0.9415950184238715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 77}], {
             RGBColor[
             0.3266232709961202, 0.4565542003312445, 0.9420613976778401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 91}], {
             RGBColor[
             0.5953350475574752, 0.6767809281925967, 0.9640487060966569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 102}], {
             RGBColor[
             0.3633436999904507, 0.48913178357153686`, 0.9443729171645411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 106}], {
             RGBColor[
             0.3139521958632445, 0.44323609697402705`, 0.9413397986941987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 112}], {
             RGBColor[
             0.32715088352733546`, 0.45710875455411837`, 0.94209144443096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 140}], {
             RGBColor[
             0.32917806589633525`, 0.4592394517547229, 0.942206889467927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 69}], {
             RGBColor[
             0.512094113243802, 0.613375440560194, 0.9551211815778647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 82}], {
             RGBColor[
             0.4706005281918093, 0.5774357827163821, 0.9524772470296884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 86}], {
             RGBColor[
             0.5072811113074129, 0.6092066601914048, 0.9548145013504485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 87}], {
             RGBColor[
             0.8052886005993835, 0.8468955393268014, 0.9061943444225835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 108}], {
             RGBColor[
             0.7019176077126746, 0.7667599945944428, 0.9711311636805353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 110}], {
             RGBColor[
             0.6138148271599528, 0.6973615545881173, 0.9627408981532811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 127}], {
             RGBColor[
             0.4720951346225606, 0.5787303356855954, 0.9525724820298272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 154}], {
             RGBColor[
             0.8045650840099676, 0.8465963466235498, 0.9181848867101159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 161}], {
             RGBColor[
             0.4656307978135873, 0.573123205257251, 0.9521608748370004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 162}], {
             RGBColor[
             0.8027519456818715, 0.845632128982279, 0.9386302937530759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 175}], {
             RGBColor[
             0.4715002623045349, 0.5782150871828736, 0.9525345772917476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 176}], {
             RGBColor[
             0.45839978276888355`, 0.5655229499724335, 0.9517490792275327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 180}], {
             RGBColor[
             0.6733354003460714, 0.7444313569668306, 0.9682823563661463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 66}], {
             RGBColor[
             0.8068568184878835, 0.8498672602817441, 0.9811645922016861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 69}], {
             RGBColor[
             0.6618396215787897, 0.7314857264416685, 0.9696204831011173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 87}], {
             RGBColor[
             0.9550341089343712, 0.965005825208276, 0.9206936459458361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 90}], {
             RGBColor[
             0.6550212395891795, 0.7255799866641114, 0.9691860218299977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 110}], {
             RGBColor[
             0.7635603354949406, 0.815471840469592, 0.9772401996765336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 131}], {
             RGBColor[
             0.9106761538385292, 0.7880776994423069, 0.6150413032300603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 133}], {
             RGBColor[
             0.8563164442942707, 0.43429365345994053`, 0.44418899353026553`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 162}], {
             RGBColor[
             0.9524974540168591, 0.9637424148637534, 0.9531295952763283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 180}], {
             RGBColor[
             0.8230809086810591, 0.8625416428483053, 0.9827816578893989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 198}], {
             RGBColor[
             0.809127231953634, 0.8516409245369697, 0.9813908857977319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 81}], {
             RGBColor[
             0.633976904061278, 0.7129754213419766, 0.9648440654867796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 90}], {
             RGBColor[
             0.5397844128240585, 0.6347307875135932, 0.9579193049130958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 141}], {
             RGBColor[
             0.5254792907329107, 0.622340409754583, 0.9570077951829706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 168}], {
             RGBColor[
             0.8151061747990456, 0.8563704613486036, 0.9793645875552226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 172}], {
             RGBColor[
             0.8427983522117647, 0.874271591791478, 0.7778392040313489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 198}], {
             RGBColor[
             0.6938904051885131, 0.7607917253864516, 0.97012416888083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 87}], {
             RGBColor[
             0.8747953206754928, 0.4237267463664781, 0.39303006082518865`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 103}], {
             RGBColor[
             0.833567382441636, 0.252847633383231, 0.17953580679306383`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 129}], {
             RGBColor[
             0.8755570267580526, 0.42023027988113926`, 0.24893178910674738`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 131}], {
             RGBColor[
             0.8452233506115981, 0.3057746625224987, 0.18926183234800478`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 133}], {
             RGBColor[
             0.8199464110752147, 0.15432243286297473`, 0.166734011812862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 143}], {
             RGBColor[
             0.8190699438712857, 0.14758552186319893`, 0.16589470582855148`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 162}], {
             RGBColor[
             0.8731042173971515, 0.4228844728034631, 0.4146540270455168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 107}], {
             RGBColor[
             0.7614279257189907, 0.8138406211600655, 0.9767792324528825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 111}], {
             RGBColor[
             0.6580603131297789, 0.7303031444944423, 0.9683812581650608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 122}], {
             RGBColor[
             0.924281570863012, 0.9375100698293877, 0.7294250958369339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 138}], {
             RGBColor[
             0.8842002449557951, 0.7898038345132208, 0.6173834589873493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 142}], {
             RGBColor[
             0.7482569303671527, 0.8035288216790438, 0.9754818662750824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 147}], {
             RGBColor[
             0.668160340209887, 0.7385028014791089, 0.9691763692944251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 156}], {
             RGBColor[
             0.8882342803358891, 0.9137179209353309, 0.9892017726661817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 157}], {
             RGBColor[
             0.7066548099945791, 0.7697543462064234, 0.9722067949657651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 179}], {
             RGBColor[
             0.8317792747849202, 0.8687996297404257, 0.9837911974570385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 181}], {
             RGBColor[
             0.9199773592711327, 0.9377520223513063, 0.9477245085556535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 185}], {
             RGBColor[
             0.8125990681630673, 0.8538159065524649, 0.9818794937101938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 82}], {
             RGBColor[
             0.3600920128525825, 0.48631533560726303`, 0.9441657225354702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 86}], {
             RGBColor[
             0.39677259596818604`, 0.5180862130822859, 0.9465029768562303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 90}], {
             RGBColor[
             0.3947672159149649, 0.5163492536735178, 0.946375195812527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 110}], {
             RGBColor[
             0.503306311820726, 0.6062411074789984, 0.9544293736590629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 123}], {
             RGBColor[
             0.3260085199796461, 0.4514023478470298, 0.9421913646386602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 127}], {
             RGBColor[
             0.3615866192833338, 0.48760988857647636`, 0.944260957535609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 177}], {
             RGBColor[
             0.3475961861623531, 0.47409235374214537`, 0.9434207502916752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 180}], {
             RGBColor[
             0.5628268850068445, 0.6533109098577117, 0.9599708318719281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 72}], {
             RGBColor[
             0.23177582019152226`, 0.36094146083002354`, 0.936510662127084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 93}], {
             RGBColor[
             0.21891136206643785`, 0.34742009968680476`, 0.9357780502681208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 134}], {
             RGBColor[
             0.2222636314959646, 0.3509435474033953, 0.9359689570528942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 139}], {
             RGBColor[
             0.23141666930631707`, 0.36056397047819155`, 0.9364902090154877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.2107154956867174, 0.33880572447377666`, 0.9353113078024935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 81}], {
             RGBColor[
             0.43330857195401157`, 0.5446846710814149, 0.9498164169017225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 164}], {
             RGBColor[
             0.2925031947568016, 0.42476978183606456`, 0.9399689962704769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 184}], {
             RGBColor[
             0.3307081584442233, 0.45915751757499346`, 0.9423559109556644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 75}], {
             RGBColor[
             0.26701897159742227`, 0.39798424750248473`, 0.9385177074620799]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 84}], {
             RGBColor[
             0.256326539038239, 0.386745822943403, 0.9379087892458708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 93}], {
             RGBColor[
             0.23701205160573985`, 0.3664450720426131, 0.9368088577598136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 134}], {
             RGBColor[
             0.2403643210352666, 0.36996851975920364`, 0.9369997645445869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 139}], {
             RGBColor[
             0.24951735884561907`, 0.3795889428339999, 0.9375210165071806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 152}], {
             RGBColor[
             0.2658080334878341, 0.396711474771397, 0.9384487463281612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 191}], {
             RGBColor[
             0.2650536461439216, 0.3959185658420248, 0.9384057850849414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 94}], {
             RGBColor[
             0.35563109287921313`, 0.4810081428778644, 0.9439343254346236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 115}], {
             RGBColor[
             0.27934432739444803`, 0.41093897791785206`, 0.9392196182409905]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 153}], {
             RGBColor[
             0.4395524049734263, 0.5500947505807087, 0.9502769094004289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 160}], {
             RGBColor[
             0.3299232570510399, 0.45874130759689935`, 0.9422962448681991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 80}], {
             RGBColor[
             0.46133983359188224`, 0.5689367397653611, 0.9518870537804123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 158}], {
             RGBColor[
             0.2780238238703263, 0.40955104498924105`, 0.9391444175188017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 164}], {
             RGBColor[
             0.29875283098362904`, 0.4313385457602833, 0.9403249038080864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 166}], {
             RGBColor[
             0.34685352759081295`, 0.47429746798031186`, 0.9433423658444682]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 169}], {
             RGBColor[
             0.28768269698087445`, 0.4197031330363533, 0.9396944760534252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 184}], {
             RGBColor[
             0.3369577946710508, 0.46572628149921225`, 0.9427118184932739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 76}], {
             RGBColor[
             0.2802558703962583, 0.4118970674079191, 0.9392715292664366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 96}], {
             RGBColor[
             0.29517906246073655`, 0.4275822884527116, 0.9401213829776245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 134}], {
             RGBColor[
             0.2575067829018646, 0.3879863340758565, 0.93797600238789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 139}], {
             RGBColor[
             0.26665982071221705`, 0.39760675715065275`, 0.9384972543504835]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 182}], {
             RGBColor[
             0.27464253104525127`, 0.40599709184373967`, 0.9389518578945881]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 191}], {
             RGBColor[
             0.2821961080105196, 0.4139363801586776, 0.9393820229282445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.2912734993929746, 0.42347729404149315`, 0.9398989669386781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 105}], {
             RGBColor[
             0.3097803157470692, 0.4397426691808402, 0.94106957474386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 111}], {
             RGBColor[
             0.368423059805849, 0.49034117218248097`, 0.9448600884518084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 116}], {
             RGBColor[
             0.3329665446591801, 0.4598254152907607, 0.9425469807473624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 126}], {
             RGBColor[
             0.2917876480797086, 0.4240176969101601, 0.9399282469457728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 174}], {
             RGBColor[
             0.3288804579296929, 0.4562862523383694, 0.9422866189141441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.27073696797748936`, 0.4018920974325212, 0.938729441855642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 191}], {
             RGBColor[
             0.2782905449427576, 0.40983138574745914`, 0.9391596068892982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 102}], {
             RGBColor[
             0.33711449602806876`, 0.4656411721496162, 0.9427298892598499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 106}], {
             RGBColor[
             0.2877229919008626, 0.4197454855521064, 0.9396967707895075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 112}], {
             RGBColor[
             0.3009216795649535, 0.4336181431321977, 0.9404484165262689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 140}], {
             RGBColor[
             0.3029488619339533, 0.43574884033280226`, 0.9405638615632359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 189}], {
             RGBColor[
             0.2658927211222934, 0.3968004868447199, 0.9384535691636595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 91}], {
             RGBColor[
             0.8828910750951913, 0.909457394113841, 0.9886921329803882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 95}], {
             RGBColor[
             0.9537951709684989, 0.944166482218568, 0.6841709176231596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 113}], {
             RGBColor[
             0.9141333132318434, 0.7927873365838396, 0.6157566218013946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 136}], {
             RGBColor[
             0.9179856014839756, 0.8091909436388446, 0.6189147464565151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 89}], {
             RGBColor[
             0.637317539505268, 0.3879136396684716, 0.4445332384990521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 118}], {
             RGBColor[
             0.5586378396004057, 0.632712242954274, 0.9632601689433578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 119}], {
             RGBColor[
             0.3844232617951737, 0.4946732869545277, 0.9469077488332039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 125}], {
             RGBColor[
             0.19146399032539158`, 0.3185711717230839, 0.934214963052216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 128}], {
             RGBColor[
             0.5467748334649722, 0.46160555519396695`, 0.5822517523121589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 144}], {
             RGBColor[
             0.6389999811794337, 0.4008456236267517, 0.4461443465462792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 149}], {
             RGBColor[
             0.21876808015896437`, 0.34726950131745254`, 0.9357698905754568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 159}], {
             RGBColor[
             0.6164190249825052, 0.2272784992590594, 0.42452079739055826`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 170}], {
             RGBColor[
             0.1931667580582484, 0.32036088857202627`, 0.934311933155583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 190}], {
             RGBColor[
             0.19183760716220638`, 0.3189638667072519, 0.9342362399783559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 192}], {
             RGBColor[
             0.6128687174194557, 0.19998927957476603`, 0.421121018858683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 195}], {
             RGBColor[
             0.1914475761291835, 0.31855391936214905`, 0.9342140282880245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 197}], {
             RGBColor[
             0.5464425729840517, 0.6229880683860871, 0.9620969735266468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 81}], {
             RGBColor[
             0.5981154418108365, 0.6846160863124545, 0.9615049850298553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 117}], {
             RGBColor[
             0.699447709361209, 0.7647890454809683, 0.9709133239805854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 120}], {
             RGBColor[
             0.7883329572883422, 0.7840663517109472, 0.6248876395864237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 121}], {
             RGBColor[
             0.5812862861253769, 0.6709534195821745, 0.9601801322470673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 166}], {
             RGBColor[
             0.5054107612208105, 0.6076601192871327, 0.9546750264349914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 168}], {
             RGBColor[
             0.7792447125486042, 0.8280111263190817, 0.9760255070982982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 172}], {
             RGBColor[
             0.8069368899613232, 0.8459122567619559, 0.7745001235744244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 173}], {
             RGBColor[
             0.807519241461194, 0.8471578477354111, 0.8378854904784999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 184}], {
             RGBColor[
             0.4955150283010483, 0.599088932806033, 0.9540444790837972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 164}], {
             RGBColor[
             0.43552843920258344`, 0.5470178923073767, 0.9499428350575294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 166}], {
             RGBColor[
             0.4836291358097673, 0.5899768145274054, 0.9529602970939112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 168}], {
             RGBColor[
             0.7574630871375609, 0.8103278215593543, 0.974310777757218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 172}], {
             RGBColor[
             0.7851552645502801, 0.8282289520022286, 0.7727853942333442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 173}], {
             RGBColor[
             0.7857376160501509, 0.8294745429756838, 0.8361707611374197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 184}], {
             RGBColor[
             0.47373340289000515`, 0.5814056280463057, 0.952329749742717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 198}], {
             RGBColor[
             0.6362473175270285, 0.7147490855972023, 0.9650703590828255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 86}], {
             RGBColor[
             0.3552790109161934, 0.48214655523847394`, 0.943859042308054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 101}], {
             RGBColor[
             0.2852213829706352, 0.4162052116877847, 0.9395876612614353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 110}], {
             RGBColor[
             0.4618127267687334, 0.5703014496351865, 0.9517854391108865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 123}], {
             RGBColor[
             0.28451493492765345`, 0.4154626900032179, 0.9395474300904838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 127}], {
             RGBColor[
             0.32009303423134106`, 0.45167023073266444`, 0.9416170229874327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 130}], {
             RGBColor[
             0.27791125977355285`, 0.4085218087190706, 0.9391713605597196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 163}], {
             RGBColor[
             0.2758102937038249, 0.40631356017084397`, 0.9390517136501494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 176}], {
             RGBColor[
             0.30639768237766407`, 0.4384628450195025, 0.9407936201851381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 177}], {
             RGBColor[
             0.3061026011103605, 0.4381526958983335, 0.9407768157434988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 180}], {
             RGBColor[
             0.5213332999548519, 0.6173712520138998, 0.9573268973237518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 187}], {
             RGBColor[
             0.3007127795635599, 0.4324876517182224, 0.9404698733799348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 86}], {
             RGBColor[
             0.32390396973941904`, 0.450080321936663, 0.9420389267285452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 101}], {
             RGBColor[
             0.2538463417938609, 0.3841389783859738, 0.9377675456819266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 124}], {
             RGBColor[
             0.2734514125634414, 0.4047451507980839, 0.9388840254591511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 135}], {
             RGBColor[
             0.244563666934011, 0.3743822985526921, 0.9372389110811449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 137}], {
             RGBColor[
             0.2530177140174724, 0.383268038054954, 0.9377203565559061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 161}], {
             RGBColor[
             0.28225365624559345`, 0.41399686700250915`, 0.9393853002150969]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 165}], {
             RGBColor[
             0.2373756354905151, 0.36682722175806165`, 0.9368295633241774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 175}], {
             RGBColor[
             0.2881231207365411, 0.41908874892813175`, 0.9397590026698441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 176}], {
             RGBColor[
             0.2750226412008897, 0.4063966117176916, 0.9389735046056292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 187}], {
             RGBColor[
             0.26933773838678554`, 0.40042141841641143`, 0.938649757800426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 199}], {
             RGBColor[
             0.2640684264301843, 0.3948830374563491, 0.938349678279746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 93}], {
             RGBColor[
             0.24346208091315458`, 0.3732244618001842, 0.9371761773869076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 139}], {
             RGBColor[
             0.25596738815303377`, 0.386368332591571, 0.9378883361342745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 152}], {
             RGBColor[
             0.2722580627952489, 0.4034908645289682, 0.9388160659552552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 194}], {
             RGBColor[
             0.30565287667395435`, 0.4349127039944547, 0.9408525291212098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 99}], {
             RGBColor[
             0.4621252914114974, 0.5716835642651686, 0.9514982759565006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 109}], {
             RGBColor[
             0.34884904242599657`, 0.47657723971187865`, 0.9434493304016565]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 132}], {
             RGBColor[
             0.3061847210307328, 0.43439681259051416`, 0.9409221739886695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 146}], {
             RGBColor[
             0.578124805971577, 0.6635021636474746, 0.9622403310784291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 150}], {
             RGBColor[
             0.3215409260409259, 0.45053715769585945`, 0.9417966871465304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 151}], {
             RGBColor[
             0.35601576258697687`, 0.48278469250549083`, 0.9439059874730323]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 152}], {
             RGBColor[
             0.320947319253029, 0.44991323932493577`, 0.9417628821181223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 194}], {
             RGBColor[
             0.35434213313173446`, 0.48133507879042225`, 0.9437993452840767]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 196}], {
             RGBColor[
             0.42766426196123664`, 0.5437065481057618, 0.9487853774832657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 101}], {
             RGBColor[
             0.3219019660862388, 0.44797608916280746`, 0.9419249155821955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 108}], {
             RGBColor[
             0.5865960904370586, 0.6714707671165345, 0.9625129589589009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 110}], {
             RGBColor[
             0.49849330988433693`, 0.6020723271102092, 0.9541226934316467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 124}], {
             RGBColor[
             0.3415070368558193, 0.46858226157491756`, 0.94304139535942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 127}], {
             RGBColor[
             0.3567736173469446, 0.48344110820768715`, 0.9439542773081928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 161}], {
             RGBColor[
             0.35030928053797133`, 0.47783397777934283`, 0.943542670115366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 175}], {
             RGBColor[
             0.356178745028919, 0.4829258597049654, 0.9439163725701132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 176}], {
             RGBColor[
             0.3430782654932676, 0.4702337224945253, 0.9431308745058982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 180}], {
             RGBColor[
             0.5580138830704554, 0.6491421294889225, 0.9596641516445119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 187}], {
             RGBColor[
             0.3373933626791634, 0.4642585291932452, 0.9428071277006951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 199}], {
             RGBColor[
             0.3321240507225622, 0.4587201482331828, 0.9425070481800151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 95}], {
             RGBColor[
             0.9838001922594006, 0.9661152059128862, 0.6121532693347048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 103}], {
             RGBColor[
             0.9055186961480244, 0.6475369650177958, 0.42196747470883456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 108}], {
             RGBColor[
             0.8846035797290293, 0.9091596462519311, 0.913892802031036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 110}], {
             RGBColor[
             0.7965007991763076, 0.8397612062456058, 0.9055025365037817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 131}], {
             RGBColor[
             0.9436166175198961, 0.8123670652183208, 0.5433036400573084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 143}], {
             RGBColor[
             0.876523819007324, 0.43701274197773154`, 0.3946852727798099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[
             0.9872510560263222, 0.9889959982810382, 0.8609465250606165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 162}], {
             RGBColor[
             0.9854379176982261, 0.9880317806397674, 0.8813919321035765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 180}], {
             RGBColor[
             0.8560213723624259, 0.8868310086243191, 0.9110439947166469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 94}], {
             RGBColor[
             0.5651610277683712, 0.6558369100747177, 0.9599061248871635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 102}], {
             RGBColor[
             0.5430147651889159, 0.6366549305319157, 0.9584949846187718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[
             0.8062483508925926, 0.7076340176229743, 0.6052352623718941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 122}], {
             RGBColor[
             0.8525664665525501, 0.8811976138560375, 0.7223536497554326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 136}], {
             RGBColor[
             0.8101006391447247, 0.7240376246779792, 0.6083933870270145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 142}], {
             RGBColor[
             0.6765418260566909, 0.7472163657056936, 0.968410420193581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 153}], {
             RGBColor[
             0.6490823398625842, 0.7249235177775619, 0.9662487088529688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 167}], {
             RGBColor[
             0.8137351892886164, 0.8551855895073546, 0.9818647874444291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 188}], {
             RGBColor[
             0.688424300235651, 0.7565215626533395, 0.9695793586227837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 113}], {
             RGBColor[
             0.8694288542290634, 0.4907346699510474, 0.21239820772463422`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 118}], {
             RGBColor[
             0.8737639977332939, 0.5885792424884555, 0.4634219800772578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 122}], {
             RGBColor[
             0.9003075980023684, 0.6064437341064228, 0.29047713264699326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 136}], {
             RGBColor[
             0.8719970463971514, 0.5016704079877174, 0.2145036241613812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 138}], {
             RGBColor[
             0.8735867140642237, 0.5079729105623115, 0.2157827080806035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 144}], {
             RGBColor[
             0.8548334539658015, 0.42247953211969835`, 0.20014188348416714`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 149}], {
             RGBColor[
             0.6471841581056663, 0.3982840813972412, 0.44509512783199057`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 159}], {
             RGBColor[
             0.8435429758673372, 0.3356959699358522, 0.18933010890630664`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 170}], {
             RGBColor[
             0.6301166100385224, 0.38034500623362366`, 0.4441231562187414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 192}], {
             RGBColor[
             0.8417678220858125, 0.32205136009370555`, 0.18763021964036905`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 197}], {
             RGBColor[
             0.865633819989058, 0.5820964594429976, 0.4626465164661172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 141}], {
             RGBColor[
             0.37364371183420664`, 0.49805313613695035`, 0.9450292248112824]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 177}], {
             RGBColor[
             0.3407778041727428, 0.4681866139645882, 0.9429862890205556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 198}], {
             RGBColor[
             0.542054826289809, 0.636504451768819, 0.9581455985091416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 95}], {
             RGBColor[
             0.9087217160297558, 0.9082261327367556, 0.679871771253554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 136}], {
             RGBColor[
             0.8729121465452325, 0.773250594157032, 0.6146156000869095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 97}], {
             RGBColor[
             0.2548383832137916, 0.38518167681737986`, 0.9378240409731977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 155}], {
             RGBColor[
             0.23916918979888965`, 0.36871236105407446`, 0.9369317035887135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 134}], {
             RGBColor[
             0.2274998629101822, 0.35644715861598486`, 0.9362671526856237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 139}], {
             RGBColor[
             0.2366529007205347, 0.36606758169078113`, 0.9367884046482173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 145}], {
             RGBColor[
             0.21595172710093502`, 0.34430933568636624`, 0.935609503435223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 105}], {
             RGBColor[
             0.3806688871734759, 0.5041379899202462, 0.945476862771782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 111}], {
             RGBColor[
             0.43931163123225564`, 0.554736492921887, 0.9492673764797304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 115}], {
             RGBColor[
             0.34184068469654455`, 0.4665135495155001, 0.9431489820897013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 116}], {
             RGBColor[
             0.4038551160855868, 0.5242207360301667, 0.9469542687752844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 126}], {
             RGBColor[
             0.3626762195061153, 0.4884130176495661, 0.9443355349736948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 142}], {
             RGBColor[
             0.5295082484696294, 0.6279621701064884, 0.9563679845897519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 153}], {
             RGBColor[
             0.5020487622755229, 0.6056693221783567, 0.9542062732491396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 160}], {
             RGBColor[
             0.39241961435313644`, 0.5143158791945474, 0.9462256087169099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 167}], {
             RGBColor[
             0.666701611701555, 0.7359313939081493, 0.9698223518406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 174}], {
             RGBColor[
             0.39976902935609954`, 0.5206815730777754, 0.9466939069420661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 188}], {
             RGBColor[
             0.5413907226485897, 0.6372673670541342, 0.9575369230189545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 103}], {
             RGBColor[
             0.9027357759104662, 0.63208364163686, 0.26409899908324835`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 129}], {
             RGBColor[
             0.9849427513832404, 0.9608705061848779, 0.39600586175704294`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 131}], {
             RGBColor[
             0.9394422371635587, 0.7891870801469172, 0.306500926618929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 143}], {
             RGBColor[
             0.8737408987697657, 0.4215594185967958, 0.23681679715422363`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 154}], {
             RGBColor[
             0.9830766756699849, 0.9658160132096346, 0.6241438116222372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 105}], {
             RGBColor[
             0.32470350781154744`, 0.4554278902256328, 0.9419194284550477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 111}], {
             RGBColor[
             0.3833462518703272, 0.5060263932272735, 0.9457099421629962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 116}], {
             RGBColor[
             0.3478897367236583, 0.4755106363355533, 0.9433968344585502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 126}], {
             RGBColor[
             0.3067108401441868, 0.4397029179549527, 0.9407781006569607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.43194074873512733`, 0.5454775949392545, 0.9495354789637005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 174}], {
             RGBColor[
             0.3438036499941711, 0.471971473383162, 0.943136472625332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 182}], {
             RGBColor[
             0.2856601600419676, 0.4175773184773137, 0.9395792955668297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 191}], {
             RGBColor[
             0.29321373700723585`, 0.4255166067922517, 0.9400094606004861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 102}], {
             RGBColor[
             0.3273981891467483, 0.4554287175679108, 0.9421765599569466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 112}], {
             RGBColor[
             0.2912053726836331, 0.4234056885504923, 0.9398950872233656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 140}], {
             RGBColor[
             0.29323255505263285`, 0.42553638575109687`, 0.9400105322603325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 155}], {
             RGBColor[
             0.2652922598561954, 0.3961693639826077, 0.9384193737828581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 99}], {
             RGBColor[
             0.7687919437411839, 0.8183727141912807, 0.944294118700548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 117}], {
             RGBColor[
             0.8762433687105626, 0.9035134810174441, 0.9541841801385145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 120}], {
             RGBColor[
             0.9651286166376958, 0.922790787247423, 0.6081584957443529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 121}], {
             RGBColor[
             0.7580819454747305, 0.8096778551186503, 0.9434509884049964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 146}], {
             RGBColor[
             0.8847914583012635, 0.9101913135735867, 0.9550361738224766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 156}], {
             RGBColor[
             0.9471660663080045, 0.9597340431975859, 0.961036759682581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.9239792736477469, 0.9412455241190165, 0.9588251826995514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 178}], {
             RGBColor[
             0.957960137429429, 0.968167319845601, 0.9560467009664877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 179}], {
             RGBColor[
             0.8907110607570355, 0.9148157520026807, 0.9556261844734377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 183}], {
             RGBColor[
             0.897769781538639, 0.6310947741177858, 0.4464659481425095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 196}], {
             RGBColor[
             0.7343309142909232, 0.7903956980318739, 0.9415812202273133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 107}], {
             RGBColor[
             0.615663269511703, 0.6984811954684678, 0.963146911483036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 109}], {
             RGBColor[
             0.45081925257627997`, 0.561890841684138, 0.9507778651594582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 146}], {
             RGBColor[
             0.6800950161218604, 0.7488157656197341, 0.9695688658362309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 147}], {
             RGBColor[
             0.5223956840025993, 0.6231433757875112, 0.9555440483245787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 156}], {
             RGBColor[
             0.7424696241286013, 0.7983584952437333, 0.9755694516963352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 178}], {
             RGBColor[
             0.7532636952500258, 0.8067917718917483, 0.970579392980242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 179}], {
             RGBColor[
             0.6860146185776324, 0.753440204048828, 0.970158876487192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 194}], {
             RGBColor[
             0.45631234328201786`, 0.5666486807626816, 0.9511278800418784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 104}], {
             RGBColor[
             0.21637454520909913`, 0.34475374432626316`, 0.9356335823009796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 123}], {
             RGBColor[
             0.23212285998297438`, 0.3613062216544334, 0.9365304255298079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 130}], {
             RGBColor[
             0.2255191848288738, 0.3543653403702861, 0.9361543559990437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 135}], {
             RGBColor[
             0.2235466331661063, 0.3522920635057185, 0.9360420220999779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 148}], {
             RGBColor[
             0.20930368592266696`, 0.3373218228978505, 0.9352309073250162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 163}], {
             RGBColor[
             0.22341821875914586`, 0.35215709182205945`, 0.9360347090894736]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 165}], {
             RGBColor[
             0.21635860172261037`, 0.34473698671108804`, 0.9356326743430103]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 123}], {
             RGBColor[
             0.2511378900976988, 0.38129222392755147`, 0.9376133033646252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 124}], {
             RGBColor[
             0.2714494089102611, 0.40264091802422836`, 0.9387700143128014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 127}], {
             RGBColor[
             0.28671598940138643`, 0.417499764656998, 0.9396828962615742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 135}], {
             RGBColor[
             0.2425616632808307, 0.3722780657788366, 0.9371248999347952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 137}], {
             RGBColor[
             0.25101571036429215`, 0.3811638052810985, 0.9376063454095565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 161}], {
             RGBColor[
             0.28025165259241314`, 0.41189263422865363`, 0.9392712890687474]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 165}], {
             RGBColor[
             0.23537363183733478`, 0.36472298898420613`, 0.9367155521778278]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 175}], {
             RGBColor[
             0.2861211170833608, 0.41698451615427623`, 0.9396449915234946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 176}], {
             RGBColor[
             0.27302063754770944`, 0.4042923789438361, 0.9388594934592795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 187}], {
             RGBColor[
             0.2673357347336053, 0.3983171856425559, 0.9385357466540765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 199}], {
             RGBColor[
             0.262066422777004, 0.3927788046824936, 0.9382356671333965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 106}], {
             RGBColor[
             0.32444342089519307`, 0.4523230687923987, 0.9420082902762085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 112}], {
             RGBColor[
             0.337642108559284, 0.46619572637249007`, 0.9427599360129698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 140}], {
             RGBColor[
             0.3396692909282838, 0.4683264235730946, 0.9428753810499368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 108}], {
             RGBColor[
             0.8366047008902185, 0.5941132685295566, 0.465258687547469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 129}], {
             RGBColor[
             0.9062804022305841, 0.6440404985324568, 0.2778692029903933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 131}], {
             RGBColor[
             0.8759467260841297, 0.5295848811738163, 0.2181992462316507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 133}], {
             RGBColor[
             0.8506697865477463, 0.3781326515142924, 0.19567142569650792`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 143}], {
             RGBColor[
             0.8497933193438173, 0.37139574051451657`, 0.1948321197121974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 154}], {
             RGBColor[
             0.9050363517550805, 0.647337503215628, 0.4299611695671895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 162}], {
             RGBColor[
             0.9038275928696831, 0.6466946914547808, 0.4435914409291628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 123}], {
             RGBColor[
             0.23468312728084179`, 0.36399722491481445`, 0.9366762289648454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 130}], {
             RGBColor[
             0.2280794521267412, 0.3570563436306672, 0.9363001594340813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 163}], {
             RGBColor[
             0.22597848605701326`, 0.35484809508244053`, 0.9361805125245111]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 111}], {
             RGBColor[
             0.4018530682244218, 0.5222917683666206, 0.9468805499681779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 116}], {
             RGBColor[
             0.36639655307775293`, 0.49177601147490035`, 0.944567442263732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 126}], {
             RGBColor[
             0.3252176564982815, 0.45596829309429976`, 0.9419487084621424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 142}], {
             RGBColor[
             0.4920496854617956, 0.5955174455512221, 0.9539811580781995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 157}], {
             RGBColor[
             0.4504475650892219, 0.5617429700786016, 0.9507060867688824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 160}], {
             RGBColor[
             0.35496105134530265`, 0.4818711546392811, 0.9438387822053573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 174}], {
             RGBColor[
             0.3623104663482657, 0.48823684852250904`, 0.9443070804305137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 182}], {
             RGBColor[
             0.30416697639606216`, 0.43384269361666083`, 0.9407499033720115]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 112}], {
             RGBColor[
             0.2882506044320779, 0.42030003977498026`, 0.9397268175426274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 140}], {
             RGBColor[
             0.29027778680107763`, 0.4224307369755848, 0.9398422625795944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 189}], {
             RGBColor[
             0.25322164598941777`, 0.3834823834875024, 0.9377319701800181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 111}], {
             RGBColor[
             0.5638634248724134, 0.6564277480338845, 0.9590690379639482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 142}], {
             RGBColor[
             0.6540600421097872, 0.7296534252184859, 0.9661696460739697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[
             0.5739634519525214, 0.664627405018551, 0.9598641490933124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.7940373920785235, 0.8398425244747729, 0.979889552465069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.6124579217372135, 0.6958789497458655, 0.9628945747646525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.7375823865275546, 0.7949242332798678, 0.9744789772559258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 181}], {
             RGBColor[
             0.8257804710137671, 0.8638766258907483, 0.9384122883545408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 185}], {
             RGBColor[
             0.7184021799057017, 0.779940510091907, 0.9725672735090811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 110}], {
             RGBColor[
             0.6931298062895987, 0.7596256615132471, 0.9704393557617335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 131}], {
             RGBColor[
             0.8402456246331873, 0.7322315204859621, 0.6082404593152602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 154}], {
             RGBColor[
             0.8838800631396134, 0.9088604535486795, 0.9258833443185683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 162}], {
             RGBColor[
             0.8820669248115173, 0.9078962359074088, 0.9463287513615282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 180}], {
             RGBColor[
             0.7526503794757171, 0.8066954638919603, 0.9759808139745987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 132}], {
             RGBColor[
             0.2948786821955154, 0.42460409000948357`, 0.9402017631916271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 146}], {
             RGBColor[
             0.5668187671363596, 0.653709441066444, 0.9615199202813867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 150}], {
             RGBColor[
             0.31023488720570846`, 0.44074443511482886`, 0.941076276349488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 151}], {
             RGBColor[
             0.34470972375175946`, 0.47299196992446024`, 0.9431855766759899]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 152}], {
             RGBColor[
             0.3096412804178116, 0.4401205167439052, 0.9410424713210799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 194}], {
             RGBColor[
             0.3430360942965171, 0.47154235620939167`, 0.9430789344870343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 196}], {
             RGBColor[
             0.4163582231260193, 0.5339138255247312, 0.9480649666862233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 127}], {
             RGBColor[
             0.46330733319948464`, 0.5715960026043997, 0.9518806741110254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 162}], {
             RGBColor[
             0.7939641442587955, 0.8384977959010833, 0.9379384858342741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 180}], {
             RGBColor[
             0.6645475989229954, 0.737297023885635, 0.9675905484473445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 116}], {
             RGBColor[
             0.42503929713653266`, 0.5423745144765412, 0.9483579559716804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 126}], {
             RGBColor[
             0.3838604005570612, 0.5065667960959406, 0.9457392221700909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 142}], {
             RGBColor[
             0.5506924295205754, 0.6461159485528629, 0.957771671786148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 157}], {
             RGBColor[
             0.5090903091480017, 0.6123414730802424, 0.9544966004768307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 160}], {
             RGBColor[
             0.41360379540408243`, 0.5324696576409218, 0.9476292959133059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 167}], {
             RGBColor[
             0.687885792752501, 0.7540851723545239, 0.971226039036996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 174}], {
             RGBColor[
             0.4209532104070455, 0.5388353515241499, 0.9480975941384622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 181}], {
             RGBColor[
             0.7224128584245553, 0.7803391492251253, 0.9300143140667192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.6150345673164899, 0.6964030334262838, 0.9641692992212595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 188}], {
             RGBColor[
             0.5625749036995356, 0.6554211455005088, 0.9589406102153506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 140}], {
             RGBColor[
             0.30347647446516857`, 0.4363033945556761, 0.9405939083163557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 122}], {
             RGBColor[
             0.9466202120897103, 0.8137405258050889, 0.35564035163633406`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 136}], {
             RGBColor[
             0.9041543846818847, 0.6565805366270306, 0.24168008890791598`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 138}], {
             RGBColor[
             0.9065388861824932, 0.6660342904889218, 0.24359871478674944`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 144}], {
             RGBColor[
             0.871111295903229, 0.5036666539093275, 0.21400931577186139`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 159}], {
             RGBColor[
             0.8485303397063004, 0.33009952954163524`, 0.19238576661614035`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 167}], {
             RGBColor[
             0.9077889348257765, 0.7877285014564059, 0.6151514893253305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 197}], {
             RGBColor[
             0.8946095450697447, 0.7772196138099509, 0.6138944273650201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 158}], {
             RGBColor[
             0.23522624458781927`, 0.364568075640074, 0.9367071586920077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 160}], {
             RGBColor[
             0.31613284886837134`, 0.44424671423453505`, 0.9415109015232768]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 126}], {
             RGBColor[
             0.34840388541039236`, 0.4760510392042203, 0.9434261144656448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 142}], {
             RGBColor[
             0.5152359143739065, 0.6156001916611427, 0.9554585640817019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 153}], {
             RGBColor[
             0.48777642817979994`, 0.593307343733011, 0.9532968527410897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 157}], {
             RGBColor[
             0.47363379400133276`, 0.5818257161885222, 0.9521834927723848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 160}], {
             RGBColor[
             0.3781472802574135, 0.5019539007492015, 0.9453161882088599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 167}], {
             RGBColor[
             0.652429277605832, 0.7235694154628036, 0.96891293133255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 174}], {
             RGBColor[
             0.38549669526037655`, 0.5083195946324296, 0.9457844864340161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 188}], {
             RGBColor[
             0.5271183885528666, 0.6249053886087885, 0.9566275025109046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 120}], {
             RGBColor[
             0.8678835994276715, 0.8465560061197337, 0.6325812491960736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 121}], {
             RGBColor[
             0.6608369282647062, 0.733443073990961, 0.9678737418567172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 146}], {
             RGBColor[
             0.7875464410912392, 0.8339565324458974, 0.9794589272741974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 151}], {
             RGBColor[
             0.565437397706639, 0.6532390613039136, 0.9611245836688005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 171}], {
             RGBColor[
             0.8267342564377225, 0.8650107429913272, 0.9832479361512722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 173}], {
             RGBColor[
             0.8870698836005233, 0.9096475021441977, 0.8455791000881498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 196}], {
             RGBColor[
             0.6370858970808988, 0.7141609169041846, 0.966003973679034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 119}], {
             RGBColor[
             0.7390929491372125, 0.7956716911845035, 0.9752408612005126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 125}], {
             RGBColor[
             0.5461336776674304, 0.6195695759530597, 0.9625480754195246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 128}], {
             RGBColor[
             0.901444520807011, 0.7626039594239429, 0.6105848646794676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 138}], {
             RGBColor[
             0.9130416014388392, 0.812801149295034, 0.6201343733156849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 144}], {
             RGBColor[
             0.8754464394074596, 0.6015112264467356, 0.4650330881244851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 149}], {
             RGBColor[
             0.5734377675010032, 0.6482679055474284, 0.9641030029427655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 159}], {
             RGBColor[
             0.852865483210531, 0.4279441020790433, 0.443409538968764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 170}], {
             RGBColor[
             0.5478364454002871, 0.6213592928020021, 0.9626450455228917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 190}], {
             RGBColor[
             0.5465072945042451, 0.6199622709372278, 0.9625693523456647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 192}], {
             RGBColor[
             0.8493151756474815, 0.40065488239475, 0.4400097604368888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.5461172634712222, 0.6195523235921249, 0.9625471406553332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 197}], {
             RGBColor[
             0.9011122603260905, 0.9239864726160629, 0.9904300858939554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 125}], {
             RGBColor[
             0.3719190998621983, 0.4815306199533135, 0.9461956553093709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 128}], {
             RGBColor[
             0.727229943001779, 0.6245650034241965, 0.5942324445693138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 144}], {
             RGBColor[
             0.7593033875373049, 0.5094852557802381, 0.45413147471771587`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 149}], {
             RGBColor[
             0.3992231896957711, 0.5102289495476822, 0.9477505828326117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 183}], {
             RGBColor[
             0.7615664433424367, 0.5237229317976604, 0.4561749529436979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 190}], {
             RGBColor[
             0.3722927166990131, 0.48192331493748153`, 0.946216932235511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 192}], {
             RGBColor[
             0.7331721237773268, 0.30862891172825246`, 0.4291081470301197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 195}], {
             RGBColor[
             0.37190268566599016`, 0.4815133675923786, 0.9461947205451795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 128}], {
             RGBColor[
             0.9231751810131911, 0.7286652920066743, 0.2580660064250903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 168}], {
             RGBColor[
             0.9476806026150666, 0.909778086957847, 0.6376934323137864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 171}], {
             RGBColor[
             0.9156195043648556, 0.8842880492213061, 0.6372222517571104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 172}], {
             RGBColor[
             0.9753727800277856, 0.9276792174007213, 0.4361680487899127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 173}], {
             RGBColor[
             0.9759551315276564, 0.9289248083741766, 0.49955341569398815`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 183}], {
             RGBColor[
             0.8921966020167115, 0.5931231241859789, 0.2320639941808822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 151}], {
             RGBColor[
             0.4472759744708069, 0.5594034354051198, 0.9503913919352824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 171}], {
             RGBColor[
             0.7085728332018904, 0.7711751170925334, 0.9725147444177542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 196}], {
             RGBColor[
             0.5189244738450667, 0.6203252910053908, 0.955270781945516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 136}], {
             RGBColor[
             0.9504725003418423, 0.8301441328600938, 0.35879847629145456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 138}], {
             RGBColor[
             0.9528570018424507, 0.8395978867219851, 0.360717102170288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 142}], {
             RGBColor[
             0.8169136872538085, 0.8533228738878083, 0.7188155094580211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 144}], {
             RGBColor[
             0.901990039676534, 0.619375718064703, 0.29208824069422046`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 153}], {
             RGBColor[
             0.7894542010597019, 0.8310300259596766, 0.7166537981174088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.8794090834796054, 0.44580859369701076`, 0.2704646915384994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 167}], {
             RGBColor[
             0.9541070504857341, 0.9612920976894692, 0.7322698767088691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 181}], {
             RGBColor[
             0.9886341161577883, 0.9875460745600706, 0.6910581517385923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 188}], {
             RGBColor[
             0.8287961614327686, 0.8626280708354541, 0.7199844478872237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 192}], {
             RGBColor[
             0.8758587759165559, 0.41851937401271744`, 0.2670649130066242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 127}], {
             RGBColor[
             0.2860095413584047, 0.4167572429724312, 0.9396426650906227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 130}], {
             RGBColor[
             0.24382776690061642`, 0.3736088209588374, 0.9371970026629095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 135}], {
             RGBColor[
             0.24185521523784892`, 0.3715355440942698, 0.9370846687638437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 163}], {
             RGBColor[
             0.2417268008308885, 0.37140057241061075`, 0.9370773557533394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 165}], {
             RGBColor[
             0.23466718379435303`, 0.36398046729963934`, 0.9366753210068761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 177}], {
             RGBColor[
             0.27201910823742403`, 0.40323970813810023`, 0.9388024578466887]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 187}], {
             RGBColor[
             0.26662928669062347`, 0.3975746639579891, 0.9384955154831248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 127}], {
             RGBColor[
             0.30632106017096694`, 0.43810593706910805`, 0.9407993760387987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 135}], {
             RGBColor[
             0.26216673405041124`, 0.39288423819094664`, 0.9382413797120197]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.27062078113387267`, 0.4017699776932086, 0.938722825186781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 161}], {
             RGBColor[
             0.29985672336199365`, 0.43249880664076373`, 0.9403877688459719]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 175}], {
             RGBColor[
             0.3057261878529413, 0.4375906885663863, 0.9407614713007191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 176}], {
             RGBColor[
             0.29262570831728996`, 0.4248985513559462, 0.9399759732365041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 187}], {
             RGBColor[
             0.2869408055031858, 0.4189233580546661, 0.939652226431301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 199}], {
             RGBColor[
             0.2816714935465845, 0.4133849770946037, 0.939352146910621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 128}], {
             RGBColor[
             0.5342706715319968, 0.44846288819275276`, 0.5815396587883258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.206263918225989, 0.33412683431623835`, 0.9350577970516237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[
             0.18066259612527297`, 0.307218221570812, 0.93359983963175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 190}], {
             RGBColor[
             0.179333445229231, 0.3058211997060377, 0.933524146454523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 195}], {
             RGBColor[
             0.17894341419620807`, 0.3054112523609348, 0.9335019347641915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 142}], {
             RGBColor[
             0.47405701779443504`, 0.579792473280542, 0.9528398302801124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 157}], {
             RGBColor[
             0.43245489742186133`, 0.5460179978079216, 0.9495647589707952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 160}], {
             RGBColor[
             0.336968383677942, 0.466146182368601, 0.9426974544072704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 174}], {
             RGBColor[
             0.3443177986809051, 0.472511876251829, 0.9431657526324266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 182}], {
             RGBColor[
             0.2861743087287016, 0.41811772134598074`, 0.9396085755739244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 191}], {
             RGBColor[
             0.2937278856939699, 0.4260570096609187, 0.9400387406075807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 135}], {
             RGBColor[
             0.2774333145415366, 0.4077430848237163, 0.9391542616607926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 161}], {
             RGBColor[
             0.31512330385311904`, 0.4473576532735334, 0.9413006507947447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 175}], {
             RGBColor[
             0.32099276834406665`, 0.45244953519915593`, 0.9416743532494919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 176}], {
             RGBColor[
             0.3078922888084153, 0.4397573979887158, 0.940888855185277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 177}], {
             RGBColor[
             0.3075972075411117, 0.4394472488675467, 0.9408720507436377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 180}], {
             RGBColor[
             0.5228279063856032, 0.618665804983113, 0.9574221323238906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 187}], {
             RGBColor[
             0.3022073859943112, 0.43378220468743567`, 0.9405651083800737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 183}], {
             RGBColor[
             0.8698008244556358, 0.5016777772906199, 0.21307095526300113`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 190}], {
             RGBColor[
             0.5346442883688116, 0.44885558317692076`, 0.5815609357144658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 192}], {
             RGBColor[
             0.8414065048905258, 0.286583757221212, 0.1860041493494229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 195}], {
             RGBColor[
             0.5342542573357888, 0.44844563583181796`, 0.5815387240241343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 131}], {
             RGBColor[
             0.9447591766437358, 0.8071223654903125, 0.32715623247964654`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 133}], {
             RGBColor[
             0.8790384594977417, 0.4469900974919443, 0.2522656130299896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 143}], {
             RGBColor[
             0.8772855250898838, 0.4335162754923927, 0.2505870010613686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 170}], {
             RGBColor[
             0.5863125273607737, 0.6439068649740138, 0.6751789886764388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 197}], {
             RGBColor[
             0.939588342286577, 0.9465340447880747, 0.7029640290475025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 163}], {
             RGBColor[
             0.23512312567678792`, 0.3644596911264634, 0.9367012862225752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 177}], {
             RGBColor[
             0.26541543308332344`, 0.3962988268539529, 0.9384263883159245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 133}], {
             RGBColor[
             0.8487047833512873, 0.33253448013330367`, 0.19259565627124703`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 143}], {
             RGBColor[
             0.8469518489434293, 0.3190606581337521, 0.19091704430262602`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 154}], {
             RGBColor[
             0.9428931009304802, 0.8120678725150692, 0.5552941823448407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 162}], {
             RGBColor[
             0.941079962602384, 0.8111036548737982, 0.5757395893878008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 180}], {
             RGBColor[
             0.811663417266584, 0.70990288285835, 0.6053916520008711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 150}], {
             RGBColor[
             0.2675705658104447, 0.39856400799346436`, 0.938549119936501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 151}], {
             RGBColor[
             0.3020454023564957, 0.43081154280309575`, 0.9406584202630028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 162}], {
             RGBColor[
             0.8765856501368406, 0.44964429041426807`, 0.41798785096875907`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 139}], {
             RGBColor[
             0.2400051701500614, 0.36959102940737165`, 0.9369793114329906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 145}], {
             RGBColor[
             0.21930399653046173`, 0.34783278340295676`, 0.9358004102199964]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 191}], {
             RGBColor[
             0.25554145744836393`, 0.3859206524153965, 0.9378640800107516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 148}], {
             RGBColor[
             0.2190360411775415, 0.34755114533768694`, 0.935785150559052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 163}], {
             RGBColor[
             0.2331505740140204, 0.36238641426189583`, 0.9365889523235094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 165}], {
             RGBColor[
             0.22609095697748494`, 0.3549663091509244, 0.9361869175770461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 176}], {
             RGBColor[
             0.26373796268785954`, 0.3945356991105544, 0.938330858858498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 187}], {
             RGBColor[
             0.2580530598737554, 0.38856050580927426`, 0.9380071120532948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 143}], {
             RGBColor[
             0.8498678524467502, 0.3315757262103135, 0.19331268304312726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 159}], {
             RGBColor[
             0.8510985318743886, 0.34103526757830527`, 0.19449118305288732`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 197}], {
             RGBColor[
             0.8984618333218767, 0.7936232208649558, 0.6170525520201404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 161}], {
             RGBColor[
             0.2794230248160247, 0.4110216938976339, 0.939224099942727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 175}], {
             RGBColor[
             0.2852924893069724, 0.4161135758232565, 0.9395978023974743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 176}], {
             RGBColor[
             0.27219200977132096`, 0.4034214386128163, 0.9388123043332592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 186}], {
             RGBColor[
             0.2661087370017966, 0.3970275332302755, 0.9384658709484304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 187}], {
             RGBColor[
             0.2665071069572168, 0.39744624531153616`, 0.938488557528056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 199}], {
             RGBColor[
             0.26123779500061556`, 0.39190786435147384`, 0.9381884780073761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 142}], {
             RGBColor[
             0.7768323613465915, 0.7056166385716411, 0.6067738726084364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 144}], {
             RGBColor[
             0.8752691557383894, 0.5209048945205916, 0.21739381612783068`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 156}], {
             RGBColor[
             0.9168097113153278, 0.8158057378279282, 0.6204937789995357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 159}], {
             RGBColor[
             0.8526881995414608, 0.34733777015289946`, 0.19577026697210964`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 167}], {
             RGBColor[
             0.914025724578517, 0.8135858623733021, 0.6202282398592844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 181}], {
             RGBColor[
             0.9485527902505714, 0.8398398392439036, 0.5790165148890076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 185}], {
             RGBColor[
             0.8411744991425061, 0.7559037234450623, 0.613171500043548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 192}], {
             RGBColor[
             0.8491378919784113, 0.32004855046860603`, 0.19237048844023447`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 145}], {
             RGBColor[
             0.2284570343408142, 0.357453206477753, 0.9363216621825899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 152}], {
             RGBColor[
             0.26544888260262894`, 0.3963339844195651, 0.9384282932165648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 182}], {
             RGBColor[
             0.2571409182934481, 0.38760178717525484`, 0.9379551669396888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 191}], {
             RGBColor[
             0.2646944952587164, 0.3955410754901928, 0.9383853319733451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 198}], {
             RGBColor[
             0.5277497041986612, 0.6241140740098087, 0.9572340887790165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 153}], {
             RGBColor[
             0.6134295605638427, 0.6970487778093326, 0.9627105685555573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 157}], {
             RGBColor[
             0.5992869263853755, 0.6855671502648439, 0.9615972085868523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 160}], {
             RGBColor[
             0.5038004126414563, 0.6056953348255233, 0.9547299040233275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 167}], {
             RGBColor[
             0.7780824099898748, 0.8273108495391253, 0.9783266471470176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 174}], {
             RGBColor[
             0.5111498276444193, 0.6120610287087513, 0.9551982022484837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 181}], {
             RGBColor[
             0.8126094756619291, 0.8535648264097266, 0.9371149221767408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 185}], {
             RGBColor[
             0.7052311845538637, 0.7696287106108853, 0.971269907331281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.6527715209369094, 0.7286468226851102, 0.9660412183253722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 154}], {
             RGBColor[
             0.8760414746143801, 0.43681328017556376`, 0.40267896763816474`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 159}], {
             RGBColor[
             0.821413781916936, 0.16560128815844824`, 0.1681391677880527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 197}], {
             RGBColor[
             0.8435046260386568, 0.41200177766559354`, 0.4414555753478633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 149}], {
             RGBColor[
             0.648866599779832, 0.4112160653555213, 0.44670623587921776`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 159}], {
             RGBColor[
             0.8452254175415028, 0.3486279538941323, 0.1909412169535338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 170}], {
             RGBColor[
             0.631799051712688, 0.39327699019190376`, 0.44573426426596857`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 181}], {
             RGBColor[
             0.8991205652819477, 0.619537019745982, 0.4376211825067001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 190}], {
             RGBColor[
             0.6309129511153266, 0.3923456422820542, 0.44568380214781717`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 192}], {
             RGBColor[
             0.8434502637599781, 0.33498334405198565`, 0.18924132768759622`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 197}], {
             RGBColor[
             0.8673162616632236, 0.5950284434012776, 0.4642576245133444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 147}], {
             RGBColor[
             0.6383951985626789, 0.7149619751698173, 0.9662861034465073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 156}], {
             RGBColor[
             0.8584691386886809, 0.8901770946260392, 0.9863115068182637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 171}], {
             RGBColor[
             0.8352823460284233, 0.8716885755474699, 0.9840999298352342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 178}], {
             RGBColor[
             0.8692632098101054, 0.8986103712740543, 0.9813214481021706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 179}], {
             RGBColor[
             0.802014133137712, 0.8452588034311341, 0.9809009316091206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 183}], {
             RGBColor[
             0.8386384964590899, 0.584723475070088, 0.463315779566298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 194}], {
             RGBColor[
             0.5723118578420975, 0.6584672801449877, 0.9618699351638069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 196}], {
             RGBColor[
             0.6456339866715997, 0.7208387494603272, 0.9668559673629961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 152}], {
             RGBColor[
             0.3812177118441309, 0.5013730508472783, 0.9458086544862003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 156}], {
             RGBColor[
             0.7007698065694198, 0.7645047047938165, 0.9722866893066117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 178}], {
             RGBColor[
             0.7115638776908443, 0.7729379814418316, 0.9672966305905184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 179}], {
             RGBColor[
             0.6443148010184508, 0.7195864135989113, 0.9668761140974684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 185}], {
             RGBColor[
             0.625134594396598, 0.7046026904109504, 0.9649644103506239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 194}], {
             RGBColor[
             0.41461252572283636`, 0.5327948903127648, 0.9478451176521548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 165}], {
             RGBColor[
             0.2118480097340456, 0.33999606854305653`, 0.9353758028020844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 159}], {
             RGBColor[
             0.6262856435829035, 0.23764894098782902`, 0.4250826867234967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 170}], {
             RGBColor[
             0.2079666859588458, 0.3359165511651807, 0.9351547671549908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 190}], {
             RGBColor[
             0.2066375350628038, 0.33451952930040635`, 0.9350790739777637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 192}], {
             RGBColor[
             0.622735336019854, 0.21035972130353567`, 0.4216829081916216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 195}], {
             RGBColor[
             0.2062475040297809, 0.3341095819553035, 0.9350568622874322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.5612425008846491, 0.6385437309792414, 0.9629398075260546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 151}], {
             RGBColor[
             0.3174016073666887, 0.4469518879084411, 0.9415329334208639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 152}], {
             RGBColor[
             0.2823331640327409, 0.4140804347278859, 0.9393898280659538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 194}], {
             RGBColor[
             0.31572797791144636`, 0.44550227419337246`, 0.9414262912319082]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 171}], {
             RGBColor[
             0.6131733026438233, 0.690971104405486, 0.9657655862298374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 196}], {
             RGBColor[
             0.4235249432869995, 0.5401212783183434, 0.9485216237575993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 194}], {
             RGBColor[
             0.3151343711235495, 0.4448783558224487, 0.9413924862035001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 160}], {
             RGBColor[
             0.4763409264473496, 0.5834024868973917, 0.9525681926827152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 167}], {
             RGBColor[
             0.7506229237957682, 0.8050180016109936, 0.9761649358064053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 174}], {
             RGBColor[
             0.4836903414503127, 0.5897681807806197, 0.9530364909078715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 188}], {
             RGBColor[
             0.6253120347428027, 0.7063539747569785, 0.9638795069847599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 157}], {
             RGBColor[
             0.7392642763541118, 0.795756249521131, 0.9753171149779516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 178}], {
             RGBColor[
             0.9316378178168464, 0.9481531008980535, 0.987322033962275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.864388741144453, 0.8948015330551333, 0.986901517469225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 181}], {
             RGBColor[
             0.9525868256306654, 0.9637539256660137, 0.9508348285678401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 183}], {
             RGBColor[
             0.8802215684635839, 0.6177519614860875, 0.46731617013970106`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 185}], {
             RGBColor[
             0.8452085345226001, 0.8798178098671724, 0.9849898137223804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 192}], {
             RGBColor[
             0.8518272488984739, 0.40265794141667954`, 0.4402493642261227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 174}], {
             RGBColor[
             0.4695477072718456, 0.5782865532361309, 0.9519231309391665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 181}], {
             RGBColor[
             0.7710073552893554, 0.8197903509371063, 0.9338398508674235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 185}], {
             RGBColor[
             0.6636290641812901, 0.7358542351382649, 0.9679948360219639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 164}], {
             RGBColor[
             0.27399405489207074`, 0.4053155022909841, 0.9389149281369991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 166}], {
             RGBColor[
             0.3220947514992546, 0.4482744245110126, 0.9419323901733808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 170}], {
             RGBColor[
             0.6092180955157596, 0.21970986582421148`, 0.4241107151102475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 197}], {
             RGBColor[
             0.844735305466295, 0.4214613190335854, 0.44263407535762334`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 167}], {
             RGBColor[
             0.6409937758733817, 0.7136645586271843, 0.9681842712741754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 174}], {
             RGBColor[
             0.37406119352792633`, 0.4984147377968103, 0.9450558263756417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 188}], {
             RGBColor[
             0.5156828868204164, 0.6150005317731692, 0.9558988424525301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 175}], {
             RGBColor[
             0.31452843153509336`, 0.4468424047708116, 0.941262746056665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 176}], {
             RGBColor[
             0.301427951999442, 0.43415026756037145`, 0.9404772479924501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 187}], {
             RGBColor[
             0.2957430491853379, 0.4281750742590913, 0.9401535011872468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 193}], {
             RGBColor[
             0.31267272742048674`, 0.4452350871371401, 0.9411445022314171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 199}], {
             RGBColor[
             0.2904737372287366, 0.422636693299029, 0.9398534216665669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 180}], {
             RGBColor[
             0.853484717444914, 0.8855675982797966, 0.9434799440471393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 177}], {
             RGBColor[
             0.2633144670135955, 0.39409057830572625`, 0.9383067414063544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 166}], {
             RGBColor[
             0.3428237586125573, 0.4700619252820549, 0.9431128764626655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 184}], {
             RGBColor[
             0.33292802569279517`, 0.46149073880095526`, 0.9424823291114712]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 187}], {
             RGBColor[
             0.2508650284302595, 0.38100542901464385`, 0.9375977642963274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 184}], {
             RGBColor[
             0.3810287222999791, 0.5044496610209838, 0.9454997911478531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 181}], {
             RGBColor[
             0.9498028388938546, 0.9615340502113876, 0.9505692894275887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 188}], {
             RGBColor[
             0.7899648841688349, 0.8366160464867711, 0.9794955855762202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 172}], {
             RGBColor[
             0.9662845352880476, 0.9716239920088556, 0.7873059163017873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 173}], {
             RGBColor[
             0.9668668867879184, 0.9728695829823109, 0.8506912832058626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 184}], {
             RGBColor[
             0.6548626736277727, 0.7248006680529328, 0.9668502718111599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 198}], {
             RGBColor[
             0.8173765882647961, 0.8581441256038294, 0.9795908811512684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 200}], {
             RGBColor[
             0.2545855584826314, 0.3849159419949167, 0.9378096429787789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 190}], {
             RGBColor[
             0.1810362129620878, 0.3076109165549801, 0.93362111655789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 195}], {
             RGBColor[
             0.1806461819290649, 0.30720096920987716`, 0.9335989048675586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 197}], {
             RGBColor[
             0.5356411787839332, 0.6116351182338152, 0.9614818501061808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 173}], {
             RGBColor[
             0.9348057885377076, 0.9473795452457701, 0.8502201026491867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 178}], {
             RGBColor[
             0.9084510251565888, 0.9296645818194842, 0.9851104569792455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 183}], {
             RGBColor[
             0.8647637066900788, 0.6054262821003745, 0.46584178548434796`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 196}], {
             RGBColor[
             0.6848218020180831, 0.7518929600057571, 0.9706449762400708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 173}], {
             RGBColor[
             0.9945590642006376, 0.9907707134251852, 0.6491658996819889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 198}], {
             RGBColor[
             0.8450687656775151, 0.8760452560467036, 0.7780654976273946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 188}], {
             RGBColor[
             0.5230323018233795, 0.6213662256563972, 0.9563671406776864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 176}], {
             RGBColor[
             0.30729741649038966`, 0.43924214948599405`, 0.9408509504471974]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 187}], {
             RGBColor[
             0.3016125136762855, 0.4332669561847139, 0.940527203641994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 199}], {
             RGBColor[
             0.2963432017196842, 0.4277285752246516, 0.9402271241213142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 187}], {
             RGBColor[
             0.2885120341406341, 0.42057481897427373`, 0.9397417055777791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 199}], {
             RGBColor[
             0.28324272218403285`, 0.4150364380142114, 0.9394416260570992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 179}], {
             RGBColor[
             0.8751828122658775, 0.9032348097031484, 0.9819114587531318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 183}], {
             RGBColor[
             0.8874176158778669, 0.6233741459180975, 0.46398946432897215`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 183}], {
             RGBColor[
             0.8425848980962714, 0.5878064340228173, 0.4637091200002722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 185}], {
             RGBColor[
             0.7887535289716312, 0.8348995186722672, 0.9795792385132371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 194}], {
             RGBColor[
             0.5782314602978695, 0.6630917185740817, 0.9624599458147682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 185}], {
             RGBColor[
             0.8769516134578437, 0.9038519112831478, 0.9435125496118522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 188}], {
             RGBColor[
             0.8244919498408892, 0.8628700233573725, 0.9382838606059434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 192}], {
             RGBColor[
             0.8729893015219696, 0.41868067569399636`, 0.41259785481910394`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 191}], {
             RGBColor[
             0.2726772055917506, 0.4039314101832797, 0.9388399355174497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 192}], {
             RGBColor[
             0.84571331956511, 0.349221020069408, 0.19128480591357822`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 193}], {
             RGBColor[
             0.29935843960625863`, 0.43124092646978174`, 0.9403862732371204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 199}], {
             RGBColor[
             0.2771594494145085, 0.4086425326316706, 0.9390951926722704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 199}], {
             RGBColor[
             0.27755781936992874`, 0.40906124471293126`, 0.9391178792518959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 192}], {
             RGBColor[
             0.6047816873553487, 0.19148929823006858`, 0.42066047446022103`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 195}], {
             RGBColor[
             0.1793170310330229, 0.30580394734510286`, 0.9335232116903315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 199}], {
             RGBColor[
             0.2944874976050776, 0.4261212575909801, 0.9401088802960662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 197}], {
             RGBColor[
             0.5339219968548683, 0.6098281490239381, 0.9613839452386224]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.0949885500996571], {
             RGBColor[
             0.9583125875736904, 0.8710407105954553, 0.2925527040414048]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.0949885500996571], {
             RGBColor[
             0.377120805174838, 0.5010648196248124, 0.9452507821242745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.0949885500996571], {
             RGBColor[
             0.26366336471100654`, 0.39445729190709694`, 0.938326610614074]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.0949885500996571], {
             RGBColor[
             0.8048857220793089, 0.8475021105371937, 0.9811871447582946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.0949885500996571], {
             RGBColor[
             0.2822070658609612, 0.41394789755425965`, 0.9393826469616164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.0949885500996571], {
             RGBColor[
             0.3400518121902417, 0.46895752104331584`, 0.9428887786701194]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.0949885500996571], {
             RGBColor[
             0.350460125859892, 0.477972679206911, 0.9435519872134391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.0949885500996571], {
             RGBColor[
             0.44819737568646545`, 0.5626277725896778, 0.9497797183467319]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.0949885500996571], {
             RGBColor[
             0.2605668322464433, 0.39120263995534316`, 0.9381502676711264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.0949885500996571], {
             RGBColor[
             0.28931600419628395`, 0.4214198424774074, 0.9397874904830813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.0949885500996571], {
             RGBColor[
             0.24586228151751777`, 0.37574722481687783`, 0.9373128652605475]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.0949885500996571], {
             RGBColor[
             0.5839626349742006, 0.6731262001457912, 0.9603908242322355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.0949885500996571], {
             RGBColor[
             0.3779993100162068, 0.5018257363634689, 0.9453067596759351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.0949885500996571], {
             RGBColor[
             0.4167727741971154, 0.535409362225998, 0.9477773705275145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.0949885500996571], {
             RGBColor[
             0.32511075702074876`, 0.45601633001476893`, 0.9419367478465757]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.0949885500996571], {
             RGBColor[
             0.3229612837478847, 0.4541545643014821, 0.9417997853103334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.0949885500996571], {
             RGBColor[
             0.2388383031545141, 0.3683645782114108, 0.9369128600838192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.0949885500996571], {
             RGBColor[
             0.3183704566888478, 0.45017822064462143`, 0.9415072618696405]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.0949885500996571], {
             RGBColor[
             0.26440158051900675`, 0.3952332035268908, 0.9383686509122472]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.0949885500996571], {
             RGBColor[
             0.22540124214842158`, 0.354241375135133, 0.9361476393378726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.0949885500996571], {
             RGBColor[
             0.31620160663402885`, 0.4482996717367106, 0.9413690646619862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.0949885500996571], {
             RGBColor[
             0.8444218577904707, 0.34245144152557083`, 0.19017172722845446`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.0949885500996571], {
             RGBColor[
             0.9935791491691084, 0.9886747742573517, 0.5425081958346172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.0949885500996571], {
             RGBColor[
             0.17892700283938517`, 0.30539400298437386`, 0.9335010001616988]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.0949885500996571], {
             RGBColor[
             0.9789215033713261, 0.9405594227844256, 0.37261445024803247`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.0949885500996571], {
             RGBColor[
             0.39640287984113043`, 0.5177659835555031, 0.9464794188715415]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.0949885500996571], {
             RGBColor[
             0.2767490295536739, 0.4082111553358114, 0.9390718198683575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.0949885500996571], {
             RGBColor[
             0.29477679578460203`, 0.4271594806709139, 0.9400984744855188]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.0949885500996571], {
             RGBColor[
             0.9936430185668372, 0.9916392390574856, 0.75501516389549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.0949885500996571], {
             RGBColor[
             0.8937471851268821, 0.9181137615718546, 0.9897275984465748]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.0949885500996571], {
             RGBColor[
             0.8505083657915934, 0.8836363007203797, 0.9856034412586252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.0949885500996571], {
             RGBColor[
             0.23515166545220784`, 0.36448968823995603`, 0.9367029115205646]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.0949885500996571], {
             RGBColor[
             0.3230400522816408, 0.4542227896464, 0.941804804371652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.0949885500996571], {
             RGBColor[
             0.2517479206748871, 0.38193340474234894`, 0.9376480437035368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.0949885500996571], {
             RGBColor[
             0.8383733051460716, 0.8739601327590868, 0.9844459883411588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.0949885500996571], {
             RGBColor[
             0.24777983952010385`, 0.3777626998577953, 0.9374220673520219]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.0949885500996571], {
             RGBColor[
             0.19099374879671333`, 0.31807691806140814`, 0.9341881834928177]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.0949885500996571], {
             RGBColor[
             0.9648082727380654, 0.8929521819142981, 0.31778721429778617`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.0949885500996571], {
             RGBColor[
             0.20098973591686892`, 0.3285833343068806, 0.9347574401715728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.0949885500996571], {
             RGBColor[
             0.49158142165721236`, 0.5981269694488269, 0.9531182367163876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.0949885500996571], {
             RGBColor[
             0.5497140953330726, 0.6453216927859953, 0.9576946537351515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.0949885500996571], {
             RGBColor[
             0.5214414667269106, 0.6223686992161088, 0.9554689288452234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.0949885500996571], {
             RGBColor[
             0.8553653759675705, 0.4265681177150025, 0.20065125259378117`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.0949885500996571], {
             RGBColor[
             0.2834240796528994, 0.4152270562127178, 0.9394519540966568]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.0949885500996571], {
             RGBColor[
             0.8843599871114161, 0.5677875345316877, 0.22521947746071738`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.0949885500996571], {
             RGBColor[
             0.5977424503378598, 0.6843132750316175, 0.9614756217747897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.0949885500996571], {
             RGBColor[
             0.4515217278586501, 0.5655071593544256, 0.9499915431275343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.0949885500996571], {
             RGBColor[
             0.3171026989044469, 0.4490801525711323, 0.9414264814646527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.0949885500996571], {
             RGBColor[
             0.8347376037115143, 0.26801402100751526`, 0.1808980745856452]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.0949885500996571], {
             RGBColor[
             0.2422322948146241, 0.37193187863768656`, 0.9371061428879017]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.0949885500996571], {
             RGBColor[
             0.28213996431762406`, 0.4138773695777287, 0.9393788256279912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.0949885500996571], {
             RGBColor[
             0.21246269677098534`, 0.3406421435922893, 0.9354108083194902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.0949885500996571], {
             RGBColor[
             0.21141226994966317`, 0.3395380784021726, 0.9353509880659832]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.0949885500996571], {
             RGBColor[
             0.27280646441116213`, 0.40406726939796367`, 0.938847296615994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.0949885500996571], {
             RGBColor[
             0.35238205413251156`, 0.47963735687773035`, 0.943674450783476]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.0949885500996571], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.0949885500996571], {
             RGBColor[
             0.3605779115447064, 0.4867361966324024, 0.9441966835704689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.0949885500996571], {
             RGBColor[
             0.264153442110629, 0.394972394326802, 0.9383545197969779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.0949885500996571], {
             RGBColor[
             0.44880489881560515`, 0.5631539785891382, 0.949818429183309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.0949885500996571], {
             RGBColor[
             0.253957266336059, 0.38425556711284614`, 0.9377738626705066]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.0949885500996571], {
             RGBColor[
             0.2737970101358498, 0.4051083957588368, 0.9389037067296339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.0949885500996571], {
             RGBColor[
             0.3562346737166085, 0.4829743023231845, 0.943919936296637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.0949885500996571], {
             RGBColor[
             0.35285247495850214`, 0.48004481175316516`, 0.9437044255825313]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.0949885500996571], {
             RGBColor[
             0.6226026285830288, 0.704495887669313, 0.963432706072083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.0949885500996571], {
             RGBColor[
             0.9220936452530043, 0.9407164594322621, 0.992431309118588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.0949885500996571], {
             RGBColor[
             0.6916199917227627, 0.7590180611312259, 0.9698978752847841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.0949885500996571], {
             RGBColor[
             0.8182056947053702, 0.14094252405757224`, 0.16506709985124088`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.0949885500996571], {
             RGBColor[
             0.8556248139763563, 0.8877160176206234, 0.9860914526539951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.0949885500996571], {
             RGBColor[
             0.4015855979045752, 0.522254993451075, 0.9468096570836465]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.0949885500996571], {
             RGBColor[
             0.21367513065222027`, 0.34191648847421524`, 0.9354798546353913]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.0949885500996571], {
             RGBColor[
             0.2902833275082297, 0.42243656061010276`, 0.93984257811467]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.0949885500996571], {
             RGBColor[
             0.24987650973082426`, 0.37996643318583184`, 0.9375414696187768]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.0949885500996571], {
             RGBColor[
             0.2931347355771166, 0.42543357128021636`, 0.9400049615859128]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.0949885500996571], {
             RGBColor[
             0.30278259996188467`, 0.4355740884585403, 0.9405543931898891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.0949885500996571], {
             RGBColor[
             0.28416143346402023`, 0.4160020618191376, 0.9394939453053829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.0949885500996571], {
             RGBColor[
             0.27635030732849636`, 0.40779207299670056`, 0.9390491132274904]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.0949885500996571], {
             RGBColor[
             0.3003940670337382, 0.43306358890932384`, 0.940418369773149]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.0949885500996571], {
             RGBColor[
             0.9279645300339343, 0.9453977435956535, 0.9929912793499938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.0949885500996571], {
             RGBColor[
             0.20396815225836698`, 0.3317138387242981, 0.934927056576049]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.0949885500996571], {
             RGBColor[
             0.6198970672218798, 0.7022993910721819, 0.9632197143709355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.0949885500996571], {
             RGBColor[
             0.5763338163997934, 0.6669327815527272, 0.9597902556887751]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.0949885500996571], {
             RGBColor[
             0.31859842780058983`, 0.45037567776345117`, 0.9415217879872938]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.0949885500996571], {
             RGBColor[
             0.25584834544704116`, 0.3862432111598293, 0.9378815568282761]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.0949885500996571], {
             RGBColor[
             0.2627765683456537, 0.3935252127009741, 0.9382761088729649]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.0949885500996571], {
             RGBColor[
             0.360155081261214, 0.48636996229290924`, 0.9441697411986989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.0949885500996571], {
             RGBColor[
             0.3919595940317969, 0.5139174327134967, 0.9461962966288141]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.0949885500996571], {
             RGBColor[
             0.9879745726157381, 0.9892951909842899, 0.8489559827730842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.0949885500996571], {
             RGBColor[
             0.7121946053554326, 0.7750911056739228, 0.9719485604909927]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.0949885500996571], {
             RGBColor[
             0.8539922331287186, 0.4160135401405583, 0.19933632946055357`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.0949885500996571], {
             RGBColor[
             0.3879488339253545, 0.5104435138959607, 0.9459407345414075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.0949885500996571], {
             RGBColor[
             0.8378176201564483, 0.8735170446320284, 0.9843929866107827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.0949885500996571], {
             RGBColor[
             0.22871531315648586`, 0.35772467388884666`, 0.9363363707790532]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.0949885500996571], {
             RGBColor[
             0.22414759348065547`, 0.35292371089939434`, 0.9360762459008504]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.0949885500996571], {
             RGBColor[
             0.4181274501813097, 0.5365827144755124, 0.9478636892833344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.0949885500996571], {
             RGBColor[
             0.9796258119030633, 0.9429352208414826, 0.3753505558963255]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.0949885500996571], {
             RGBColor[
             0.3061966914574528, 0.4391625150862857, 0.940748820649866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.0949885500996571], {
             RGBColor[
             0.28096145327109734`, 0.41263867974591306`, 0.9393117111673424]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.0949885500996571], {
             RGBColor[
             0.9734883859205871, 0.9797482621451334, 0.9297614266867937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.0949885500996571], {
             RGBColor[
             0.5640955015617808, 0.656997166237428, 0.9588268107143023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.0949885500996571], {
             RGBColor[
             0.21381427791123173`, 0.3420627410658821, 0.9354877788659421]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.0949885500996571], {
             RGBColor[
             0.2518443381406806, 0.38203474561211825`, 0.9376535345355769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.0949885500996571], {
             RGBColor[
             0.37383492502239923`, 0.4982187553899085, 0.9450414087465508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.0949885500996571], {
             RGBColor[
             0.8642907579141675, 0.4766578520345487, 0.20847322067670976`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.0949885500996571], {
             RGBColor[
             0.21893481250696653`, 0.34744474758664423`, 0.9357793857360172]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.0949885500996571], {
             RGBColor[
             0.34321032416564207`, 0.47169326536497985`, 0.9430900362602295]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.0949885500996571], {
             RGBColor[
             0.27505191676798696`, 0.40642738219488894`, 0.9389751718058661]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.0949885500996571], {
             RGBColor[
             0.6672310374616252, 0.7399652246995075, 0.9674670122517698]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.0949885500996571], {
             RGBColor[
             0.7812325868423204, 0.8290241015195725, 0.9788296212889877]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.0949885500996571], {
             RGBColor[
             0.3375430035907792, 0.46678451713084806`, 0.942728919604614]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.0949885500996571], {
             RGBColor[
             0.6050270257368769, 0.6902272215069217, 0.9620490902344793]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.0949885500996571], {
             RGBColor[
             0.4604958122832016, 0.5728902713682614, 0.9506710636761264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.0949885500996571], {
             RGBColor[
             0.30144929209616883`, 0.4341726973550716, 0.9404784632793888]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.0949885500996571], {
             RGBColor[
             0.9003020964297527, 0.6401769295720257, 0.2385219642527955]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.0949885500996571], {
             RGBColor[
             0.21718744139687057`, 0.3456081497602061, 0.935679875536301]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.0949885500996571], {
             RGBColor[
             0.2655539192117794, 0.3964443845554878, 0.9384342748960682]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.0949885500996571], {
             RGBColor[
             0.3895827819898638, 0.5118587575848209, 0.9460448482672345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.0949885500996571], {
             RGBColor[
             0.7789983515005383, 0.8272786998897548, 0.9786069335902352]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.0949885500996571], {
             RGBColor[
             0.9133075269424444, 0.9337106471842498, 0.9915932813106664]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.0949885500996571], {
             RGBColor[
             0.5648783713319804, 0.6576327351847573, 0.9588884410903589]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.0949885500996571], {
             RGBColor[
             0.9567688473548046, 0.8658333123497126, 0.2865555648019119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.0949885500996571], {
             RGBColor[
             0.5426755050288741, 0.6396074480921672, 0.9571405501231992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.0949885500996571], {
             RGBColor[
             0.9929383277496677, 0.9873041220381521, 0.47275873901987264`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.0949885500996571], {
             RGBColor[
             0.250431442054717, 0.3805497022429847, 0.9375730721936737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.0949885500996571], {
             RGBColor[
             0.2910544796798416, 0.42324709043633846`, 0.9398864940900259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.0949885500996571], {
             RGBColor[
             0.17895982839241617`, 0.30542850472186966`, 0.9335028695283829]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.0949885500996571], {
             RGBColor[
             0.30722498883092086`, 0.4402433208236197, 0.9408073806640553]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.0949885500996571], {
             RGBColor[
             0.32158764066209233`, 0.4529647837018777, 0.9417122579875715]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.0949885500996571], {
             RGBColor[
             0.8895815146715775, 0.5914972716636359, 0.22957644804826868`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.0949885500996571], {
             RGBColor[
             0.9902596908634175, 0.9788057915282733, 0.4166611676177604]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.0949885500996571], {
             RGBColor[
             0.23722409174651585`, 0.3666679396746901, 0.9368209331321454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.0949885500996571], {
             RGBColor[
             0.8992586624240541, 0.6354389394523516, 0.23765129734153262`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.0949885500996571], {
             RGBColor[
             0.2522143608002516, 0.3824236628881191, 0.93767460677864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.0949885500996571], {
             RGBColor[
             0.8234278438149039, 0.18108225047377968`, 0.1700678357361042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.0949885500996571], {
             RGBColor[
             0.23085213233970892`, 0.3599706063325754, 0.9364580594703971]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.0949885500996571], {
             RGBColor[
             0.23327898842098083`, 0.3625213859455549, 0.9365962653340136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.0949885500996571], {
             RGBColor[
             0.9080066729340168, 0.6729841436820356, 0.24483821356303642`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.0949885500996571], {
             RGBColor[
             0.2501870825879037, 0.38029286495007875`, 0.9375591562835361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.0949885500996571], {
             RGBColor[
             0.9127756759352338, 0.6918916514058181, 0.2486754653207034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.0949885500996571], {
             RGBColor[
             0.24915820796041388`, 0.3792114524821679, 0.9375005633955842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.0949885500996571], {
             RGBColor[
             0.30550365683416836`, 0.4384340917562807, 0.9407093533533227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.0949885500996571], {
             RGBColor[
             0.3593385897430587, 0.4856627583779401, 0.9441177150811572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.0949885500996571], {
             RGBColor[
             0.6408890467579492, 0.7193416257374643, 0.9648722798961695]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.0949885500996571], {
             RGBColor[
             0.8207984422031169, 0.16087151747445233`, 0.16754991778317269`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.0949885500996571], {
             RGBColor[
             0.8565158956399671, 0.43541151607797846`, 0.2017529915313943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.0949885500996571], {
             RGBColor[
             0.20775586072121455`, 0.33569496047333813`, 0.9351427609695957]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.0949885500996571], {
             RGBColor[
             0.79609453068194, 0.84063436500204, 0.9803109209581594]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.0949885500996571], {
             RGBColor[
             0.4806958664434177, 0.5892895853375945, 0.9522612859348552]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.0949885500996571], {
             RGBColor[
             0.20479309393410217`, 0.332580904729819, 0.9349740357840903]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.0949885500996571], {
             RGBColor[
             0.2335680080595618, 0.362825163910607, 0.9366127245748646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.0949885500996571], {
             RGBColor[
             0.2829267708206377, 0.41470435309880965`, 0.9394236330943619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.0949885500996571], {
             RGBColor[
             0.3518764439127397, 0.4791994227180725, 0.9436422337473658]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.0949885500996571], {
             RGBColor[
             0.281739557244844, 0.41345651635696223`, 0.9393560230375456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.0949885500996571], {
             RGBColor[
             0.585970074369736, 0.674755929881201, 0.960548857214945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.0949885500996571], {
             RGBColor[
             0.9865275394369064, 0.9886968055777866, 0.8729370673481489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.0949885500996571], {
             RGBColor[
             0.24962306644129345`, 0.3797000482193023, 0.9375270363983738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.0949885500996571], {
             RGBColor[
             0.9208437466954219, 0.9397198242500384, 0.9923120926783682]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.0949885500996571], {
             RGBColor[
             0.5576848060128018, 0.6517926747922235, 0.9583221372775351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.0949885500996571], {
             RGBColor[
             0.25326504777876796`, 0.3835280015199418, 0.9377344418477144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.0949885500996571], {
             RGBColor[
             0.8226444613445744, 0.17506082952644003`, 0.16931766779781277`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.0949885500996571], {
             RGBColor[
             0.36671177852496323`, 0.4920490439135823, 0.9445875281504853]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.0949885500996571], {
             RGBColor[
             0.30865896704414575`, 0.441750522845189, 0.9408890436019178]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.0949885500996571], {
             RGBColor[
             0.9829012627807141, 0.9867683702952449, 0.9138278814340688]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.0949885500996571], {
             RGBColor[
             0.23302215960706, 0.36225144257823677`, 0.936581639313005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.0949885500996571], {
             RGBColor[
             0.29472306200537346`, 0.42710300306202637`, 0.9400954144262837]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.0949885500996571], {
             RGBColor[
             0.21890292553398902`, 0.347411232356294, 0.9357775698200786]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.0949885500996571], {
             RGBColor[
             0.39092445521974123`, 0.5130208475020834, 0.9461303384990473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.0949885500996571], {
             RGBColor[
             0.9152757732218003, 0.9352800733407862, 0.9917810143978655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.0949885500996571], {
             RGBColor[
             0.9385923578753286, 0.9537228615659814, 0.988831299825661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.0949885500996571], {
             RGBColor[
             0.2725827939998642, 0.40383217761416634`, 0.9388345589169613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.0949885500996571], {
             RGBColor[
             0.1823653638581298, 0.3090079384197544, 0.933696809735117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.0949885500996571], {
             RGBColor[
             0.8744701613749067, 0.9027427860928997, 0.9878889387123091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.0949885500996571], {
             RGBColor[
             0.9939767127007667, 0.98952512245173, 0.5857805327779135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.0949885500996571], {
             RGBColor[
             0.9951414157005084, 0.9920163043986404, 0.7125512665860644]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.0949885500996571], {
             RGBColor[
             0.3814106085308894, 0.5047804316800383, 0.9455241246007979]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.0949885500996571], {
             RGBColor[
             0.320397896026041, 0.45193428669643415`, 0.9416364485114123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.0949885500996571], {
             RGBColor[
             0.29419693695473825`, 0.4265500122755539, 0.9400654523829823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.0949885500996571], {
             RGBColor[
             0.29360677442013106`, 0.4259297140332158, 0.9400318434997037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.0949885500996571], {
             RGBColor[
             0.9424318889382709, 0.9565863775460686, 0.9823319752461818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.0949885500996571], {
             RGBColor[
             0.807933735593484, 0.8498832418602281, 0.9814909422600818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.0949885500996571], {
             RGBColor[
             0.7240681721091139, 0.7843668262643483, 0.9731320066602097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.0949885500996571], {
             RGBColor[
             0.984329904565909, 0.9877880270819891, 0.9093575644573119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.0949885500996571], {
             RGBColor[
             0.2651236286264823, 0.39599212186834176`, 0.9384097704837935]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.0949885500996571], {
             RGBColor[
             0.859910479347665, 0.45676803010411193`, 0.20481820887036734`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.0949885500996571], {
             RGBColor[
             0.3711329893802169, 0.49587847453988415`, 0.9448692437966588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.0949885500996571], {
             RGBColor[
             0.7695733223497783, 0.8199157954843064, 0.9776675347663926]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.0949885500996571], {
             RGBColor[
             0.28203039141568953`, 0.41376220151047227`, 0.9393725856133247]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.0949885500996571], {
             RGBColor[
             0.28282713132653, 0.41459962567299363`, 0.939417958772576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.0949885500996571], {
             RGBColor[
             0.6646539951158695, 0.737952019632756, 0.9672101567545748]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.0949885500996571], {
             RGBColor[
             0.2313913752108486, 0.36053738478011593`, 0.9364887685541701]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.0949885500996571], {
             RGBColor[
             0.1797070620660458, 0.3062138946902057, 0.9335454233806629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.0949885500996571], {
             RGBColor[
             0.28023078255701894`, 0.41187069849821767`, 0.939270100551106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.0949885500996571], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.0949885500996571], {
             RGBColor[
             0.31668648779682773`, 0.44871965142909115`, 0.9413999608609163]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.0949885500996571], {
             RGBColor[
             0.348529185002255, 0.47630019528793527`, 0.9434289493694545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.0949885500996571], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.0949885500996571], {
             RGBColor[
             0.49517344266125934`, 0.6010431339186144, 0.9534010137678327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.0949885500996571], {
             RGBColor[
             0.8889169937097365, 0.9142622980478761, 0.9892668904772446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.0949885500996571], {
             RGBColor[
             0.6961608186542636, 0.7625653896416773, 0.9703504624768758]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.0949885500996571], {
             RGBColor[
             0.27228850741332744`, 0.40352286375286894`, 0.938817799731216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.0949885500996571], {
             RGBColor[
             0.23658832296539867`, 0.36599970637566703`, 0.9367847270405965]},
             StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{
  3.834950276960332*^9, {3.8349573666066523`*^9, 3.83495737580899*^9}, 
   3.8349587938370156`*^9, 3.8350189212906833`*^9, 3.835019008666805*^9, 
   3.8350204886401753`*^9, 3.83502054312705*^9, {3.8350446267813253`*^9, 
   3.8350446323653708`*^9}, 3.835045028161322*^9, 3.835051949829644*^9},
 CellLabel->
  "Out[409]=",ExpressionUUID->"d8669d65-1a9f-4ec6-983e-3965cb663bfb"]
}, Open  ]],

Cell["Estimated with absolute Mean Deviation v Calculated: (r=3)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 
  3.8349503756793146`*^9}},ExpressionUUID->"f4d46856-d76e-4ff8-bacb-\
726bf0cfec1e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraphb", "[", 
     RowBox[{"graphinf2", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsif2", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}],
      "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"AMDi3f200", ",", "krif2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502409842243`*^9}, {3.834957391671958*^9, 3.8349574025038147`*^9}, {
   3.8350188314314775`*^9, 3.835018832832349*^9}, {3.8350443332621727`*^9, 
   3.835044338598092*^9}, {3.835044923956807*^9, 3.8350449330660315`*^9}, 
   3.8350519547834587`*^9},
 CellLabel->
  "In[410]:=",ExpressionUUID->"8b1cada5-b6cb-40ae-9a02-876c52b33cea"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
          103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
          129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 
          142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 
          155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 
          168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 
          181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 
          194, 195, 196, 197, 198, 199, 200}, {Null, CompressedData["
1:eJwVxfk/GgwDAPA5ylXk6qBcTS9j5XjImZDN1UpNhz0LEUrEK0VRaK6QloU8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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[31, 80] -> 
             RGBColor[
              0.8992894856877498, 0.6305565996265416, 0.2374172185979564], 
             UndirectedEdge[36, 132] -> 
             RGBColor[
              0.8690092502585807, 0.4208558442690981, 0.20926471137318312`], 
             UndirectedEdge[16, 101] -> 
             RGBColor[
              0.9627453926262954, 0.885549306442335, 0.3120872181611117], 
             UndirectedEdge[86, 108] -> 
             RGBColor[
              0.966812144785852, 0.8978467408676918, 0.3352846846543052], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.9751745993664003, 0.9776873251210054, 0.7272792719571133], 
             UndirectedEdge[29, 136] -> 
             RGBColor[
              0.9128509372216211, 0.9107616814641174, 0.6791520030977434], 
             UndirectedEdge[55, 157] -> 
             RGBColor[
              0.8456366309972174, 0.6811634483123015, 0.5979687771402711], 
             UndirectedEdge[7, 188] -> 
             RGBColor[
              0.8847286324296482, 0.4856243644519167, 0.2964184372809593], 
             UndirectedEdge[19, 141] -> 
             RGBColor[
              0.9737391492415799, 0.9230781254301766, 0.35248198305942824`], 
             UndirectedEdge[62, 185] -> 
             RGBColor[
              0.8786467741465895, 0.7297301151718626, 0.6055091120338544], 
             UndirectedEdge[79, 144] -> 
             RGBColor[
              0.8568358936080525, 0.8694426724544752, 0.6775047493083423], 
             UndirectedEdge[47, 54] -> 
             RGBColor[
              0.9689594740557819, 0.9635689534070011, 0.682173212185085], 
             UndirectedEdge[32, 101] -> 
             RGBColor[
              0.9699523489074029, 0.9227035528970791, 0.586553940780651], 
             UndirectedEdge[104, 163] -> 
             RGBColor[
              0.9130244184832571, 0.6928778327201902, 0.248875609413581], 
             UndirectedEdge[119, 125] -> 
             RGBColor[
              0.9500199269246075, 0.9609723635430338, 0.9186830169652256], 
             UndirectedEdge[9, 140] -> 
             RGBColor[
              0.9405303505119309, 0.8039309341370057, 0.5642536261366028], 
             UndirectedEdge[3, 63] -> 
             RGBColor[
              0.9664661748787673, 0.8916848816054712, 0.4822554175409264], 
             UndirectedEdge[50, 104] -> 
             RGBColor[
              0.9489267444665141, 0.8268297804625953, 0.32145253411712515`], 
             UndirectedEdge[47, 61] -> 
             RGBColor[
              0.9449364768392541, 0.9584542951017356, 0.9780923612309608], 
             UndirectedEdge[149, 195] -> 
             RGBColor[
              0.9416953042539317, 0.821500905416319, 0.5813723285764894], 
             UndirectedEdge[99, 178] -> 
             RGBColor[
              0.702521122903111, 0.29902820985319256`, 0.42864905285481836`], 
             UndirectedEdge[160, 174] -> 
             RGBColor[
              0.8707066247357665, 0.4013190718577207, 0.23181925426564853`], 
             UndirectedEdge[6, 124] -> 
             RGBColor[
              0.9297827018382585, 0.7448466596441186, 0.299691533108426], 
             UndirectedEdge[24, 197] -> 
             RGBColor[
              0.952083524769889, 0.8477341734710945, 0.28030348316686515`], 
             UndirectedEdge[80, 120] -> 
             RGBColor[
              0.9347770410577048, 0.7603245595047881, 0.32951951143261893`], 
             UndirectedEdge[83, 187] -> 
             RGBColor[
              0.903357424240409, 0.6322493528355511, 0.27155973587099524`], 
             UndirectedEdge[47, 167] -> 
             RGBColor[
              0.9641840556794947, 0.9474603459022283, 0.6636216135553004], 
             UndirectedEdge[132, 150] -> 
             RGBColor[
              0.9714553737051967, 0.9236382560096703, 0.5631773706734964], 
             UndirectedEdge[17, 189] -> 
             RGBColor[
              0.9578175053926532, 0.8588192979108743, 0.3910608357732201], 
             UndirectedEdge[69, 180] -> 
             RGBColor[
              0.968548010495227, 0.9045035494011515, 0.3378548762628402], 
             UndirectedEdge[43, 95] -> 
             RGBColor[
              0.9489394553555663, 0.9417685960335458, 0.6858761186603097], 
             UndirectedEdge[82, 86] -> 
             RGBColor[
              0.9509089785798419, 0.9474574489007568, 0.6921226918107188], 
             UndirectedEdge[7, 61] -> 
             RGBColor[
              0.9655533589744547, 0.9707594273721243, 0.7632121248977437], 
             UndirectedEdge[30, 65] -> 
             RGBColor[
              0.991267074805541, 0.9892612100210688, 0.6929514751958381], 
             UndirectedEdge[62, 174] -> 
             RGBColor[
              0.9265226805436702, 0.9196588948731628, 0.6775074919359788], 
             UndirectedEdge[18, 47] -> 
             RGBColor[
              0.9680478249318563, 0.9604937468466064, 0.6786316274891255], 
             UndirectedEdge[56, 149] -> 
             RGBColor[
              0.9287551744637417, 0.9449155367679698, 0.9544905829722765], 
             UndirectedEdge[82, 163] -> 
             RGBColor[
              0.9151880903659009, 0.8141175333578694, 0.6202506185793205], 
             UndirectedEdge[10, 48] -> 
             RGBColor[
              0.9050457800279241, 0.9250143104337748, 0.9101860806448451], 
             UndirectedEdge[58, 92] -> 
             RGBColor[
              0.9108951978193185, 0.9278783415521662, 0.8126325817482734], 
             UndirectedEdge[70, 72] -> 
             RGBColor[
              0.9774752325211569, 0.9735448843183561, 0.6754532144606894], 
             UndirectedEdge[35, 181] -> 
             RGBColor[
              0.9691563485599455, 0.9765174357746271, 0.9370944359620628], 
             UndirectedEdge[126, 174] -> 
             RGBColor[
              0.9506889170131256, 0.8358415434814941, 0.31232243477854965`], 
             UndirectedEdge[108, 154] -> 
             RGBColor[
              0.8636545927065625, 0.38587643871459765`, 0.20439105686361025`],
              UndirectedEdge[63, 77] -> 
             RGBColor[
              0.9761415839744495, 0.9296499753063898, 0.4920959749199176], 
             UndirectedEdge[32, 100] -> 
             RGBColor[
              0.9770067941001136, 0.982164259086258, 0.9144898447868619], 
             UndirectedEdge[19, 50] -> 
             RGBColor[
              0.973638891716426, 0.9227399332562465, 0.3520925015062507], 
             UndirectedEdge[80, 81] -> 
             RGBColor[
              0.9349639634438675, 0.7626831115226702, 0.4922448661107881], 
             UndirectedEdge[34, 163] -> 
             RGBColor[
              0.8656834083124716, 0.44753420425099744`, 0.20822721775541006`],
              UndirectedEdge[146, 194] -> 
             RGBColor[
              0.9067977651401374, 0.6572648071488989, 0.43956724704847727`], 
             UndirectedEdge[13, 83] -> 
             RGBColor[
              0.8994671943697186, 0.6191266940123009, 0.25644692743163083`], 
             UndirectedEdge[30, 41] -> 
             RGBColor[
              0.9793155001184706, 0.9496624972168737, 0.5855741946963414], 
             UndirectedEdge[35, 111] -> 
             RGBColor[
              0.9244110855378193, 0.7495651976614404, 0.571254186373725], 
             UndirectedEdge[29, 144] -> 
             RGBColor[
              0.9138756223656286, 0.9142181850623676, 0.6831327113866595], 
             UndirectedEdge[6, 12] -> 
             RGBColor[
              0.912277051307069, 0.6826825669832939, 0.24790014582508027`], 
             UndirectedEdge[67, 143] -> 
             RGBColor[
              0.9518143715167877, 0.9617144124970228, 0.888944426199058], 
             UndirectedEdge[135, 163] -> 
             RGBColor[
              0.9327393881366066, 0.7710411177715358, 0.26473873676648085`], 
             UndirectedEdge[50, 60] -> 
             RGBColor[
              0.9711808021497957, 0.9144482199611255, 0.3425432877111564], 
             UndirectedEdge[25, 143] -> 
             RGBColor[
              0.9753303535344087, 0.9798667834218375, 0.8704323568393975], 
             UndirectedEdge[12, 13] -> 
             RGBColor[
              0.9601085242269312, 0.8739854037359032, 0.31574433817067676`], 
             UndirectedEdge[89, 144] -> 
             RGBColor[
              0.9634175269765481, 0.9534624287585554, 0.6788739923252735], 
             UndirectedEdge[22, 24] -> 
             RGBColor[
              0.962462856518594, 0.8833636505045934, 0.3174089960277927], 
             UndirectedEdge[107, 156] -> 
             RGBColor[
              0.9420851922507567, 0.8016603150865167, 0.5261975610492451], 
             UndirectedEdge[23, 154] -> 
             RGBColor[
              0.8295488475230253, 0.4002090840048961, 0.44004126400549104`], 
             UndirectedEdge[101, 135] -> 
             RGBColor[
              0.9537065937231601, 0.8541691010151482, 0.28160944254499204`], 
             UndirectedEdge[7, 42] -> 
             RGBColor[
              0.9883113509431135, 0.9716069259389707, 0.46237866934009353`], 
             UndirectedEdge[122, 192] -> 
             RGBColor[
              0.9952180639622157, 0.9921802472801042, 0.7208939568546597], 
             UndirectedEdge[129, 133] -> 
             RGBColor[
              0.9496620324988929, 0.85643576658935, 0.5903812106592613], 
             UndirectedEdge[40, 80] -> 
             RGBColor[
              0.9257049710220265, 0.7298054319097682, 0.2872104454732478], 
             UndirectedEdge[41, 172] -> 
             RGBColor[
              0.9773755119730243, 0.9488602622633104, 0.617724818794769], 
             UndirectedEdge[94, 115] -> 
             RGBColor[
              0.9436915545259837, 0.8127018798762595, 0.5433431548472379], 
             UndirectedEdge[87, 103] -> 
             RGBColor[
              0.953632448897662, 0.8560073087839417, 0.5636686230152723], 
             UndirectedEdge[142, 160] -> 
             RGBColor[0.6045216666666666, 0.191216, 0.4206456666666667], 
             UndirectedEdge[21, 150] -> 
             RGBColor[
              0.991582328267325, 0.9904496417304788, 0.7646371600743707], 
             UndirectedEdge[29, 142] -> 
             RGBColor[
              0.5127954057786627, 0.5929823787658095, 0.9593688721218434], 
             UndirectedEdge[67, 103] -> 
             RGBColor[
              0.9492240825892593, 0.9606432614581009, 0.9318722171810624], 
             UndirectedEdge[50, 163] -> 
             RGBColor[
              0.9484284715916946, 0.8248542945535284, 0.3210516120660777], 
             UndirectedEdge[21, 46] -> 
             RGBColor[
              0.9811929751973109, 0.946747932587897, 0.5067513326333408], 
             UndirectedEdge[43, 129] -> 
             RGBColor[
              0.9787676067058302, 0.964493775580535, 0.652005698884892], 
             UndirectedEdge[11, 112] -> 
             RGBColor[
              0.7305499187025462, 0.7844732606675623, 0.8156453934297074], 
             UndirectedEdge[119, 195] -> 
             RGBColor[
              0.9463514692994962, 0.8243144954145174, 0.543980620675106], 
             UndirectedEdge[99, 109] -> 
             RGBColor[
              0.7307309331169405, 0.7848604321965869, 0.8353476953450443], 
             UndirectedEdge[45, 120] -> 
             RGBColor[
              0.9932883783871598, 0.9880528449561994, 0.510859590648771], 
             UndirectedEdge[29, 153] -> 
             RGBColor[
              0.9197728926042632, 0.933877171925712, 0.7259308437113157], 
             UndirectedEdge[27, 125] -> 
             RGBColor[
              0.9243119622187881, 0.9424583758273757, 0.9917099305027148], 
             UndirectedEdge[35, 157] -> 
             RGBColor[
              0.8984358834832225, 0.9208275016196794, 0.9546408582864608], 
             UndirectedEdge[28, 112] -> 
             RGBColor[
              0.9485978371022779, 0.8204320178991245, 0.4601992731610123], 
             UndirectedEdge[22, 89] -> 
             RGBColor[
              0.9601904749214822, 0.9425768244289632, 0.6663375044689888], 
             UndirectedEdge[96, 116] -> 
             RGBColor[
              0.8495020432256661, 0.882650987415409, 0.9529378860828399], 
             UndirectedEdge[23, 143] -> 
             RGBColor[
              0.9195432320191325, 0.9359822818383385, 0.8858663761049854], 
             UndirectedEdge[6, 14] -> 
             RGBColor[
              0.9367722859489669, 0.7679772250682996, 0.48145082375051323`], 
             UndirectedEdge[9, 112] -> 
             RGBColor[
              0.945316484634817, 0.8055321627237242, 0.4574612322288538], 
             UndirectedEdge[12, 25] -> 
             RGBColor[
              0.9521739760430943, 0.8951257771756574, 0.6146933510775572], 
             UndirectedEdge[176, 199] -> 
             RGBColor[
              0.9855923324938398, 0.9883100734731064, 0.8884358666327489], 
             UndirectedEdge[48, 112] -> 
             RGBColor[
              0.9917535770761212, 0.9904799455735116, 0.7588543337410267], 
             UndirectedEdge[79, 149] -> 
             RGBColor[
              0.8557152334100881, 0.8873818891893779, 0.9473365063616013], 
             UndirectedEdge[58, 155] -> 
             RGBColor[
              0.857252879008686, 0.8890141924847551, 0.9862467389501696], 
             UndirectedEdge[118, 138] -> 
             RGBColor[
              0.9842659690350315, 0.9576399365418273, 0.4739557836235878], 
             UndirectedEdge[172, 173] -> 
             RGBColor[
              0.9379149339733737, 0.7926364646353823, 0.5645238978002467], 
             UndirectedEdge[53, 104] -> 
             RGBColor[
              0.9535028229802023, 0.841661171217514, 0.39065727117462323`], 
             UndirectedEdge[179, 185] -> 
             RGBColor[
              0.683513850566969, 0.5744355841811293, 0.5878242786883991], 
             UndirectedEdge[82, 176] -> 
             RGBColor[
              0.9516651492252637, 0.9627982249486274, 0.9411598462731982], 
             UndirectedEdge[142, 181] -> 
             RGBColor[
              0.5708981076685575, 0.6386112510556379, 0.9406189562806755], 
             UndirectedEdge[54, 160] -> 
             RGBColor[
              0.8734241121228887, 0.41048579491086523`, 0.24237617961018537`],
              UndirectedEdge[121, 151] -> 
             RGBColor[
              0.9051705405372776, 0.6377078786333292, 0.2981089009952892], 
             UndirectedEdge[138, 144] -> 
             RGBColor[
              0.9875629361728671, 0.968761380862444, 0.48676387837407753`], 
             UndirectedEdge[171, 196] -> 
             RGBColor[
              0.9940923852918198, 0.9897725344276993, 0.5983707804655489], 
             UndirectedEdge[120, 172] -> 
             RGBColor[
              0.9888137255027947, 0.9873609474608157, 0.6692259054199826], 
             UndirectedEdge[113, 159] -> 
             RGBColor[
              0.970458472534465, 0.9748057449427975, 0.7857024801416782], 
             UndirectedEdge[103, 108] -> 
             RGBColor[
              0.9681115608669101, 0.9134121628639691, 0.5753188563741687], 
             UndirectedEdge[64, 176] -> 
             RGBColor[
              0.9674314307495766, 0.9126448147667496, 0.5842116984887946], 
             UndirectedEdge[83, 101] -> 
             RGBColor[
              0.8926932228359007, 0.5959802997794601, 0.23167392955015434`], 
             UndirectedEdge[15, 63] -> 
             RGBColor[
              0.9754855973489136, 0.9791888081289926, 0.8274854993973524], 
             UndirectedEdge[55, 72] -> 
             RGBColor[
              0.9182009219643813, 0.738228504797352, 0.5773012385301673], 
             UndirectedEdge[105, 142] -> 
             RGBColor[
              0.5744088974608502, 0.6412295923343392, 0.9346761049229506], 
             UndirectedEdge[96, 105] -> 
             RGBColor[
              0.8484949368515069, 0.8818998891305464, 0.9546426544788813], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.9918243932102642, 0.9906314141238342, 0.7665622329159774], 
             UndirectedEdge[64, 108] -> 
             RGBColor[
              0.9495194828536873, 0.8375686016896728, 0.2782403948552902], 
             UndirectedEdge[56, 119] -> 
             RGBColor[
              0.9334113395093062, 0.947729126766168, 0.9170988750708933], 
             UndirectedEdge[68, 157] -> 
             RGBColor[
              0.9044684799279624, 0.9149873008737737, 0.6944018732055308], 
             UndirectedEdge[137, 161] -> 
             RGBColor[
              0.9224129508119414, 0.7178737199091463, 0.27658213702105017`], 
             UndirectedEdge[160, 188] -> 
             RGBColor[
              0.821657253545941, 0.16747271778892775`, 0.16837231649494966`], 
             UndirectedEdge[127, 187] -> 
             RGBColor[
              0.8322066530269007, 0.8571561787826127, 0.6852049536549585], 
             UndirectedEdge[41, 141] -> 
             RGBColor[
              0.9771462622676678, 0.9345711176953528, 0.3657179737864725], 
             UndirectedEdge[137, 175] -> 
             RGBColor[
              0.8653462415908117, 0.4814505568957145, 0.20935394212877412`], 
             UndirectedEdge[1, 122] -> 
             RGBColor[
              0.9893355117892959, 0.9896800360860326, 0.8168939797257662], 
             UndirectedEdge[60, 177] -> 
             RGBColor[
              0.9525144952396523, 0.9150410551849155, 0.6330302339275722], 
             UndirectedEdge[72, 75] -> 
             RGBColor[
              0.8974385929299551, 0.9202614505264698, 0.9624909027567314], 
             UndirectedEdge[13, 69] -> 
             RGBColor[
              0.9797561713221797, 0.9433749537720095, 0.3758569776232823], 
             UndirectedEdge[48, 77] -> 
             RGBColor[
              0.9729804656363648, 0.9285985482487247, 0.5630761460834834], 
             UndirectedEdge[22, 183] -> 
             RGBColor[
              0.900948435369117, 0.6259107062297671, 0.2575312639834115], 
             UndirectedEdge[16, 86] -> 
             RGBColor[
              0.9774990752536827, 0.93576123874161, 0.36708858561399893`], 
             UndirectedEdge[8, 62] -> 
             RGBColor[
              0.8674589312212018, 0.6163004179818913, 0.4678214084862351], 
             UndirectedEdge[26, 51] -> 
             RGBColor[
              0.9905211538318797, 0.9792804989719803, 0.45230807906644244`], 
             UndirectedEdge[117, 121] -> 
             RGBColor[
              0.8895686466597159, 0.5833744344298321, 0.22914854726640635`], 
             UndirectedEdge[89, 136] -> 
             RGBColor[
              0.9623928418325407, 0.9500059251603051, 0.6748932840363573], 
             UndirectedEdge[81, 168] -> 
             RGBColor[
              0.8756615331956423, 0.9012480610078105, 0.8710132000518639], 
             UndirectedEdge[172, 198] -> 
             RGBColor[
              0.9032161784197469, 0.6411880449402294, 0.4373647856466254], 
             UndirectedEdge[55, 68] -> 
             RGBColor[
              0.9286768257415112, 0.7357021153846945, 0.30954089313565486`], 
             UndirectedEdge[156, 192] -> 
             RGBColor[
              0.9447976365554163, 0.8027268237505372, 0.4772360249638993], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.9754147812147705, 0.97903733957867, 0.8197776002224018], 
             UndirectedEdge[25, 154] -> 
             RGBColor[
              0.8667402618665427, 0.4294654183938954, 0.42975191782843236`], 
             UndirectedEdge[100, 135] -> 
             RGBColor[
              0.960761038915871, 0.9136298072043272, 0.6095453465512031], 
             UndirectedEdge[37, 149] -> 
             RGBColor[
              0.9712789261232312, 0.9364986818902918, 0.6171097911222252], 
             UndirectedEdge[125, 149] -> 
             RGBColor[
              0.9453637618790429, 0.9581587735448355, 0.956074724866609], 
             UndirectedEdge[2, 184] -> 
             RGBColor[
              0.8762250616247991, 0.46461061277639837`, 0.22293702867845502`],
              UndirectedEdge[6, 16] -> 
             RGBColor[
              0.9250748770071602, 0.7289660610389868, 0.2814025226377299], 
             UndirectedEdge[55, 111] -> 
             RGBColor[
              0.8716118330518143, 0.5099011443540623, 0.21458210522753524`], 
             UndirectedEdge[34, 50] -> 
             RGBColor[
              0.8896182923013096, 0.5368355027459342, 0.25661183422443945`], 
             UndirectedEdge[56, 125] -> 
             RGBColor[
              0.8952728235647818, 0.9193302642498836, 0.9898731152027351], 
             UndirectedEdge[98, 196] -> 
             RGBColor[
              0.9908279021048281, 0.9802927926971299, 0.4554078931449859], 
             UndirectedEdge[160, 167] -> 
             RGBColor[
              0.8702404998720307, 0.3997467232410167, 0.23000844719032892`], 
             UndirectedEdge[22, 149] -> 
             RGBColor[
              0.9767397209209014, 0.9549192249984269, 0.6383239477266067], 
             UndirectedEdge[147, 194] -> 
             RGBColor[
              0.8958290268694752, 0.6491877092817983, 0.46276354271002906`], 
             UndirectedEdge[83, 161] -> 
             RGBColor[
              0.8976483855990062, 0.61299142495208, 0.2493811988106293], 
             UndirectedEdge[34, 177] -> 
             RGBColor[
              0.8771740876945473, 0.5372307262284609, 0.4502697983687166], 
             UndirectedEdge[70, 145] -> 
             RGBColor[
              0.9881101827316789, 0.9808725458259444, 0.6304086221663386], 
             UndirectedEdge[125, 170] -> 
             RGBColor[
              0.953337892723721, 0.9619237596594674, 0.8331176135725444], 
             UndirectedEdge[190, 192] -> 
             RGBColor[
              0.79114220416236, 0.8339130892639175, 0.8407645582296024], 
             UndirectedEdge[122, 188] -> 
             RGBColor[
              0.8852951950792872, 0.4868361846712237, 0.3580852852747859], 
             UndirectedEdge[123, 130] -> 
             RGBColor[
              0.8751795730490877, 0.43322307668481425`, 0.4091683869425677], 
             UndirectedEdge[94, 116] -> 
             RGBColor[
              0.9356554499144218, 0.8073374282649857, 0.5851079112474874], 
             UndirectedEdge[23, 162] -> 
             RGBColor[
              0.8868614321784342, 0.8134761501356824, 0.6224629919304314], 
             UndirectedEdge[116, 160] -> 
             RGBColor[
              0.8688476692233397, 0.4156071270794679, 0.42029255768460616`], 
             UndirectedEdge[80, 117] -> 
             RGBColor[
              0.9115691469063804, 0.6792413644038848, 0.24729772225516133`], 
             UndirectedEdge[147, 185] -> 
             RGBColor[
              0.9169745694623885, 0.7598656514647988, 0.5943949104458837], 
             UndirectedEdge[55, 107] -> 
             RGBColor[
              0.9298190760818313, 0.7459627463876428, 0.5159624130478732], 
             UndirectedEdge[111, 174] -> 
             RGBColor[
              0.925430281750081, 0.7268136207290322, 0.29153908809081047`], 
             UndirectedEdge[126, 142] -> 
             RGBColor[
              0.5514114799094757, 0.520686935694913, 0.5955620533800768], 
             UndirectedEdge[115, 160] -> 
             RGBColor[
              0.8742050722977143, 0.4191834281536505, 0.3924493867511065], 
             UndirectedEdge[74, 164] -> 
             RGBColor[
              0.9860950537971764, 0.9753704211530019, 0.6315338339915204], 
             UndirectedEdge[42, 97] -> 
             RGBColor[
              0.9820237778270036, 0.9510241229721073, 0.3846662006929658], 
             UndirectedEdge[25, 108] -> 
             RGBColor[
              0.9542848712753547, 0.9034947733574322, 0.6163918269305132], 
             UndirectedEdge[67, 133] -> 
             RGBColor[
              0.9172202455537681, 0.831626544964267, 0.6240023395384212], 
             UndirectedEdge[38, 183] -> 
             RGBColor[
              0.895132758913837, 0.6397426358959614, 0.457998231843277], 
             UndirectedEdge[33, 41] -> 
             RGBColor[
              0.9792312751379739, 0.949627668022955, 0.5869700205904345], 
             UndirectedEdge[32, 123] -> 
             RGBColor[
              0.875235707694182, 0.4332462898031554, 0.40823809060155], 
             UndirectedEdge[61, 116] -> 
             RGBColor[
              0.9547466748028148, 0.9657707246802343, 0.961486254988063], 
             UndirectedEdge[93, 134] -> 
             RGBColor[
              0.9333209544744971, 0.9464620176228753, 0.8651975534087386], 
             UndirectedEdge[45, 128] -> 
             RGBColor[
              0.9888371462548146, 0.9731208886334567, 0.4865016073718304], 
             UndirectedEdge[29, 35] -> 
             RGBColor[
              0.9110536466700507, 0.9308885634847988, 0.9558443518032307], 
             UndirectedEdge[3, 106] -> 
             RGBColor[
              0.9653295899315648, 0.891470651133071, 0.5196838310931069], 
             UndirectedEdge[77, 140] -> 
             RGBColor[
              0.9712846337174204, 0.9278972781693489, 0.5911804696527161], 
             UndirectedEdge[79, 195] -> 
             RGBColor[
              0.8185644248860169, 0.7251387485427753, 0.6080166423019402], 
             UndirectedEdge[38, 46] -> 
             RGBColor[
              0.9623407053031523, 0.9348028554473833, 0.6427908398095827], 
             UndirectedEdge[14, 59] -> 
             RGBColor[
              0.9913349528546127, 0.9906847945708975, 0.7932657858296424], 
             UndirectedEdge[126, 191] -> 
             RGBColor[
              0.9190531813446474, 0.7167798684994724, 0.2537264935251079], 
             UndirectedEdge[13, 64] -> 
             RGBColor[
              0.9620825347774944, 0.881811697768865, 0.31733267339564286`], 
             UndirectedEdge[3, 11] -> 
             RGBColor[
              0.7021013981671075, 0.6846267696418569, 0.6100266483931729], 
             UndirectedEdge[31, 98] -> 
             RGBColor[
              0.9550595367020364, 0.8499242085528949, 0.3327411611946779], 
             UndirectedEdge[25, 162] -> 
             RGBColor[
              0.9426485536937104, 0.8573606517191814, 0.6070289726648435], 
             UndirectedEdge[126, 157] -> 
             RGBColor[
              0.87266212250131, 0.7982142525956033, 0.6202264319851503], 
             UndirectedEdge[128, 183] -> 
             RGBColor[
              0.9039823839161591, 0.6361449270839356, 0.2693175811755618], 
             UndirectedEdge[22, 192] -> 
             RGBColor[
              0.9849256965130079, 0.9591373256070181, 0.5384248298358615], 
             UndirectedEdge[99, 194] -> 
             RGBColor[
              0.7338413204072721, 0.5204146994468765, 0.4578834445626404], 
             UndirectedEdge[21, 151] -> 
             RGBColor[
              0.9939591858929654, 0.9894876343820749, 0.5838728479116523], 
             UndirectedEdge[48, 59] -> 
             RGBColor[
              0.9884540671133726, 0.9894934742815082, 0.8410095180552969], 
             UndirectedEdge[18, 115] -> 
             RGBColor[
              0.9858941275069788, 0.9731746280363789, 0.6202607648459783], 
             UndirectedEdge[29, 89] -> 
             RGBColor[
              0.896205716168245, 0.9198150012278068, 0.9809780251823006], 
             UndirectedEdge[15, 140] -> 
             RGBColor[
              0.9706286470918843, 0.9774361109919516, 0.9265699941301508], 
             UndirectedEdge[113, 136] -> 
             RGBColor[
              0.9865568008605825, 0.9653445534785732, 0.4848022047919026], 
             UndirectedEdge[111, 160] -> 
             RGBColor[
              0.8360055630976208, 0.2620593419616341, 0.18149747112822512`], 
             UndirectedEdge[116, 188] -> 
             RGBColor[
              0.8775241763152216, 0.48229856265732346`, 0.4286011906745054], 
             UndirectedEdge[82, 127] -> 
             RGBColor[
              0.7979050900910478, 0.8428398025016102, 0.9802814696119728], 
             UndirectedEdge[25, 95] -> 
             RGBColor[
              0.9380110285925647, 0.9528099140296578, 0.9731944786336648], 
             UndirectedEdge[62, 111] -> 
             RGBColor[
              0.8744710880864515, 0.7107693000290327, 0.6020248172298437], 
             UndirectedEdge[162, 180] -> 
             RGBColor[
              0.9393749410505945, 0.797348873908569, 0.27007785839752096`], 
             UndirectedEdge[89, 159] -> 
             RGBColor[
              0.9462945135064232, 0.9594671166245294, 0.9757935593861329], 
             UndirectedEdge[7, 153] -> 
             RGBColor[
              0.9932001748322499, 0.9878641864709943, 0.5012591780260622], 
             UndirectedEdge[146, 183] -> 
             RGBColor[
              0.9044457564557254, 0.6465848850385691, 0.43760467334919545`], 
             UndirectedEdge[144, 197] -> 
             RGBColor[
              0.9674810493701609, 0.9013505312300251, 0.3313866778124203], 
             UndirectedEdge[120, 128] -> 
             RGBColor[
              0.9881864068372717, 0.9717290228191799, 0.41567263767045476`], 
             UndirectedEdge[74, 166] -> 
             RGBColor[
              0.9712124907249332, 0.9647294708693286, 0.6772560508771042], 
             UndirectedEdge[147, 152] -> 
             RGBColor[
              0.9558866992216801, 0.9195575077719937, 0.6315707107773787], 
             UndirectedEdge[22, 190] -> 
             RGBColor[
              0.7808498367131522, 0.8008701675908314, 0.658295431210804], 
             UndirectedEdge[27, 128] -> 
             RGBColor[
              0.9602388440812099, 0.9545701585622197, 0.6916386291509382], 
             UndirectedEdge[47, 88] -> 
             RGBColor[
              0.8668139587891215, 0.44536783805486313`, 0.4356786495372762], 
             UndirectedEdge[69, 177] -> 
             RGBColor[
              0.9658640275080129, 0.9600721621453314, 0.6848906459425164], 
             UndirectedEdge[122, 167] -> 
             RGBColor[
              0.9856507817891538, 0.9615832085015772, 0.5412416492128233], 
             UndirectedEdge[1, 78] -> 
             RGBColor[
              0.9757984276619862, 0.9814710874935226, 0.9258511285739839], 
             UndirectedEdge[138, 159] -> 
             RGBColor[
              0.9704399227027423, 0.974766068728418, 0.783683445434937], 
             UndirectedEdge[101, 127] -> 
             RGBColor[
              0.8162103509201382, 0.8027525991984764, 0.6253762441736971], 
             UndirectedEdge[65, 90] -> 
             RGBColor[
              0.9906845666660714, 0.9795222423977286, 0.4792593995857358], 
             UndirectedEdge[64, 127] -> 
             RGBColor[
              0.8136713716153608, 0.7926863923197325, 0.6233333218275692], 
             UndirectedEdge[117, 146] -> 
             RGBColor[
              0.9656735714952969, 0.906305764650227, 0.5858814867534476], 
             UndirectedEdge[49, 103] -> 
             RGBColor[
              0.9896046247862884, 0.9876921941947971, 0.656423193937321], 
             UndirectedEdge[88, 113] -> 
             RGBColor[
              0.8807442678199049, 0.4539684978812379, 0.31263973690140656`], 
             UndirectedEdge[13, 176] -> 
             RGBColor[
              0.9801313673550808, 0.9574306129947547, 0.6234141176571372], 
             UndirectedEdge[17, 112] -> 
             RGBColor[
              0.9585263660351013, 0.8603354791482658, 0.46821594212289513`], 
             UndirectedEdge[129, 170] -> 
             RGBColor[
              0.9857796796688458, 0.9867329812845503, 0.7994964846933845], 
             UndirectedEdge[35, 116] -> 
             RGBColor[
              0.9736742447263975, 0.9798868753381911, 0.9294468162082965], 
             UndirectedEdge[69, 110] -> 
             RGBColor[
              0.9263883706090752, 0.726932945552494, 0.30339313765919196`], 
             UndirectedEdge[47, 126] -> 
             RGBColor[
              0.9380902857809246, 0.8499571967356162, 0.6116384961498837], 
             UndirectedEdge[83, 137] -> 
             RGBColor[
              0.866372989426393, 0.48611277901403915`, 0.21021068569067553`], 
             UndirectedEdge[72, 84] -> 
             RGBColor[
              0.9558788326783311, 0.966615086170056, 0.9595698070188792], 
             UndirectedEdge[22, 37] -> 
             RGBColor[
              0.9691725342661297, 0.907673860825797, 0.3347415462126816], 
             UndirectedEdge[90, 141] -> 
             RGBColor[
              0.9861180423365927, 0.9648350385419743, 0.4005716451757435], 
             UndirectedEdge[24, 79] -> 
             RGBColor[
              0.8414383690077805, 0.8158263146955446, 0.6264215546627872], 
             UndirectedEdge[34, 130] -> 
             RGBColor[
              0.8899332721423183, 0.5466264730275521, 0.4232965458561653], 
             UndirectedEdge[157, 174] -> 
             RGBColor[
              0.8994550796954842, 0.8980759246872714, 0.6749257600035463], 
             UndirectedEdge[131, 180] -> 
             RGBColor[
              0.962055274002688, 0.9136511431353413, 0.6066222163534382], 
             UndirectedEdge[3, 48] -> 
             RGBColor[
              0.9633050565406824, 0.8906334545478063, 0.5532355887044922], 
             UndirectedEdge[49, 67] -> 
             RGBColor[
              0.9522619531771119, 0.9596224337634456, 0.716008233853326], 
             UndirectedEdge[79, 190] -> 
             RGBColor[
              0.6598253492023388, 0.7333328317817824, 0.9673079898457986], 
             UndirectedEdge[13, 82] -> 
             RGBColor[
              0.9463162532531815, 0.9319651079507428, 0.6742808211800464], 
             UndirectedEdge[68, 138] -> 
             RGBColor[
              0.9907735569220293, 0.9795915585389693, 0.49923653370971854`], 
             UndirectedEdge[153, 160] -> 
             RGBColor[
              0.875839991217067, 0.41847919543993506`, 0.26502031439298157`], 
             UndirectedEdge[178, 183] -> 
             RGBColor[
              0.8351377997020263, 0.26511228989433067`, 0.18104722655804542`],
              UndirectedEdge[2, 166] -> 
             RGBColor[
              0.9600746043014202, 0.927158764662723, 0.6339874653351201], 
             UndirectedEdge[32, 53] -> 
             RGBColor[
              0.9894635478177944, 0.9883589081507906, 0.711464896763182], 
             UndirectedEdge[26, 184] -> 
             RGBColor[
              0.8862917250014524, 0.49829631974858674`, 0.28513156642645043`],
              UndirectedEdge[61, 115] -> 
             RGBColor[
              0.9627827794143766, 0.9711351762915083, 0.9197214985878135], 
             UndirectedEdge[146, 178] -> 
             RGBColor[
              0.8754775676359763, 0.4358783175552151, 0.41033285534065533`], 
             UndirectedEdge[88, 102] -> 
             RGBColor[
              0.8805463170135172, 0.45354510112227114`, 0.29109401323686945`],
              UndirectedEdge[118, 159] -> 
             RGBColor[
              0.9606674525659713, 0.9427488561384736, 0.6651401508400022], 
             UndirectedEdge[62, 75] -> 
             RGBColor[
              0.8519419028109773, 0.8847793642273105, 0.9857401732992677], 
             UndirectedEdge[89, 197] -> 
             RGBColor[
              0.9498111431727774, 0.9069473473954642, 0.6292319916080613], 
             UndirectedEdge[85, 146] -> 
             RGBColor[
              0.9858460232610307, 0.9884149811248951, 0.8842315540897362], 
             UndirectedEdge[170, 190] -> 
             RGBColor[
              0.7909303594149318, 0.8334599747699583, 0.8177065648262831], 
             UndirectedEdge[82, 101] -> 
             RGBColor[
              0.9361552959524545, 0.8972455166014817, 0.6371213243578316], 
             UndirectedEdge[7, 73] -> 
             RGBColor[
              0.9861822443956508, 0.9861444163425526, 0.7282928027546651], 
             UndirectedEdge[19, 34] -> 
             RGBColor[
              0.8824903550622925, 0.5127912967194763, 0.22892114404885872`], 
             UndirectedEdge[56, 170] -> 
             RGBColor[
              0.9367293053084199, 0.9486805228826019, 0.831533471678212], 
             UndirectedEdge[32, 187] -> 
             RGBColor[
              0.9859486510141654, 0.9771071324812155, 0.6463826502619124], 
             UndirectedEdge[74, 169] -> 
             RGBColor[
              0.9897423108663173, 0.9768786556813228, 0.5710893455571285], 
             UndirectedEdge[55, 147] -> 
             RGBColor[
              0.9110320271612025, 0.732881954791129, 0.5894363074847329], 
             UndirectedEdge[49, 143] -> 
             RGBColor[
              0.9921949137138166, 0.988763345233719, 0.6134954029553166], 
             UndirectedEdge[28, 77] -> 
             RGBColor[
              0.9298247256625214, 0.7585506205743375, 0.264421085503469], 
             UndirectedEdge[122, 153] -> 
             RGBColor[
              0.9940500188067083, 0.9896819167999547, 0.5937594500168022], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.958232402770955, 0.8676568055306291, 0.3084559605900178], 
             UndirectedEdge[16, 199] -> 
             RGBColor[
              0.9783673150657813, 0.9511483582699477, 0.6142684639589382], 
             UndirectedEdge[64, 180] -> 
             RGBColor[
              0.9508743739505416, 0.8429402933980069, 0.27933057203520073`], 
             UndirectedEdge[38, 128] -> 
             RGBColor[
              0.9704607372014433, 0.962193629714476, 0.6743356303950869], 
             UndirectedEdge[46, 98] -> 
             RGBColor[
              0.9779758280413549, 0.937369437841306, 0.36894068016689563`], 
             UndirectedEdge[68, 142] -> 
             RGBColor[
              0.5832178373361281, 0.6374599839730835, 0.6697374946004573], 
             UndirectedEdge[5, 20] -> 
             RGBColor[
              0.9894895414580568, 0.9752012117296494, 0.4992705098249691], 
             UndirectedEdge[169, 200] -> 
             RGBColor[
              0.9785575776589217, 0.9818585323338895, 0.8463800541590297], 
             UndirectedEdge[27, 133] -> 
             RGBColor[
              0.9296507967924734, 0.8415114197648934, 0.6242550129440685], 
             UndirectedEdge[32, 135] -> 
             RGBColor[
              0.9691983858490183, 0.9197143406138792, 0.5859472844060871], 
             UndirectedEdge[144, 190] -> 
             RGBColor[
              0.784076888768218, 0.8117557719204235, 0.6708319190670886], 
             UndirectedEdge[62, 126] -> 
             RGBColor[
              0.8997297233494961, 0.8197972227814947, 0.6228081639175829], 
             UndirectedEdge[55, 62] -> 
             RGBColor[
              0.8727042318454035, 0.7027464184981929, 0.6005505090727036], 
             UndirectedEdge[62, 76] -> 
             RGBColor[
              0.9070690704582157, 0.9286621161225261, 0.9884272444410469], 
             UndirectedEdge[157, 181] -> 
             RGBColor[
              0.8921487502603918, 0.9161385679563281, 0.9652833348857489], 
             UndirectedEdge[64, 82] -> 
             RGBColor[
              0.9336163166476772, 0.8871793097227377, 0.6350784020117037], 
             UndirectedEdge[142, 153] -> 
             RGBColor[
              0.5859044868256005, 0.6462887931599024, 0.7000629715894724], 
             UndirectedEdge[21, 109] -> 
             RGBColor[
              0.9950483737975644, 0.9918172971762227, 0.7024242296386799], 
             UndirectedEdge[66, 198] -> 
             RGBColor[
              0.835600486167483, 0.2705315958506761, 0.18156324193744042`], 
             UndirectedEdge[141, 198] -> 
             RGBColor[
              0.9030633452828425, 0.6316619485615911, 0.269360222307761], 
             UndirectedEdge[10, 28] -> 
             RGBColor[
              0.8618900400540808, 0.7549663827593875, 0.6115310200648306], 
             UndirectedEdge[31, 151] -> 
             RGBColor[
              0.9573450302646802, 0.8573099904680186, 0.36914706952859944`], 
             UndirectedEdge[111, 142] -> 
             RGBColor[
              0.5261528446464312, 0.4116590129424511, 0.5747787066923377], 
             UndirectedEdge[111, 181] -> 
             RGBColor[
              0.9181239523149887, 0.744876263998089, 0.5818966629730131], 
             UndirectedEdge[86, 101] -> 
             RGBColor[
              0.969214239408932, 0.9073702455976229, 0.3372174663724431], 
             UndirectedEdge[119, 144] -> 
             RGBColor[
              0.9846229380215319, 0.9686184193262173, 0.6134687276815081], 
             UndirectedEdge[5, 102] -> 
             RGBColor[
              0.9938079113146716, 0.9891640733553106, 0.5674075436228607], 
             UndirectedEdge[157, 185] -> 
             RGBColor[
              0.8515791732984036, 0.7081471449859712, 0.6029273801014219], 
             UndirectedEdge[13, 110] -> 
             RGBColor[
              0.921414670669894, 0.7101554877773545, 0.284071252599895], 
             UndirectedEdge[32, 82] -> 
             RGBColor[
              0.9516470880783126, 0.9627907562002129, 0.9414591662189267], 
             UndirectedEdge[12, 23] -> 
             RGBColor[
              0.8963868545278182, 0.8512412755921583, 0.6301273703431451], 
             UndirectedEdge[53, 130] -> 
             RGBColor[
              0.989379345850153, 0.9883240884732789, 0.7128603412747087], 
             UndirectedEdge[74, 80] -> 
             RGBColor[
              0.9310775624488493, 0.747928444336898, 0.3080819486376955], 
             UndirectedEdge[35, 185] -> 
             RGBColor[
              0.9285867715979573, 0.7685260128042701, 0.5747384811777357], 
             UndirectedEdge[117, 196] -> 
             RGBColor[
              0.9697105548511293, 0.9061784083070079, 0.3883732708855832], 
             UndirectedEdge[22, 181] -> 
             RGBColor[
              0.9687512722004574, 0.9489614530226038, 0.6518463076892069], 
             UndirectedEdge[143, 197] -> 
             RGBColor[
              0.9728109988099414, 0.9228453869171152, 0.5340881361981283], 
             UndirectedEdge[16, 124] -> 
             RGBColor[
              0.9757380533021445, 0.9298208981914537, 0.3602473478733635], 
             UndirectedEdge[182, 191] -> 
             RGBColor[
              0.9040660225671397, 0.6543923215035506, 0.2415139185938285], 
             UndirectedEdge[98, 146] -> 
             RGBColor[
              0.9867909187489956, 0.980420149040349, 0.6529161090128504], 
             UndirectedEdge[156, 183] -> 
             RGBColor[
              0.8741963953973892, 0.5216370383254464, 0.21673872740210337`], 
             UndirectedEdge[6, 13] -> 
             RGBColor[
              0.9269509984631364, 0.7352946592442609, 0.28869090021838895`], 
             UndirectedEdge[50, 100] -> 
             RGBColor[
              0.976450122370959, 0.9674429839863197, 0.6658582218507998], 
             UndirectedEdge[13, 175] -> 
             RGBColor[
              0.8984404465341373, 0.6144644718939762, 0.2555901838697294], 
             UndirectedEdge[62, 116] -> 
             RGBColor[
              0.9237342472750298, 0.9410909777057834, 0.9602174470644151], 
             UndirectedEdge[120, 171] -> 
             RGBColor[
              0.9938115752589829, 0.9891719101617109, 0.5678063413499034], 
             UndirectedEdge[72, 139] -> 
             RGBColor[
              0.9775067061461811, 0.973651052245921, 0.6755754835506126], 
             UndirectedEdge[6, 83] -> 
             RGBColor[
              0.8675795457564772, 0.4915914695105614, 0.21121746586789983`], 
             UndirectedEdge[118, 190] -> 
             RGBColor[
              0.7807799216303825, 0.8006343275998068, 0.658023824316599], 
             UndirectedEdge[36, 200] -> 
             RGBColor[
              0.8717533452502786, 0.4588461530488816, 0.43105767781282434`], 
             UndirectedEdge[16, 161] -> 
             RGBColor[
              0.9701781367709538, 0.9110659942012649, 0.33864812205182415`], 
             UndirectedEdge[2, 169] -> 
             RGBColor[
              0.9786044244428043, 0.9393079494747172, 0.5278207600151446], 
             UndirectedEdge[107, 111] -> 
             RGBColor[
              0.9315859323228795, 0.7539856279184829, 0.5174367212050133], 
             UndirectedEdge[127, 180] -> 
             RGBColor[
              0.8151631473939123, 0.7986007861768794, 0.6245336396354697], 
             UndirectedEdge[138, 156] -> 
             RGBColor[
              0.9442078241602097, 0.8014652746763709, 0.41303858564583074`], 
             UndirectedEdge[72, 93] -> 
             RGBColor[
              0.9194068477987116, 0.9377783406464233, 0.9645862545174061], 
             UndirectedEdge[137, 187] -> 
             RGBColor[
              0.9309765087740457, 0.7467606117343528, 0.30984994261159915`], 
             UndirectedEdge[40, 121] -> 
             RGBColor[
              0.8989925294034801, 0.6170838127670876, 0.25575702941179734`], 
             UndirectedEdge[98, 178] -> 
             RGBColor[
              0.8765879852528896, 0.43074712334188914`, 0.24815964073961205`],
              UndirectedEdge[10, 186] -> 
             RGBColor[
              0.9044340914775091, 0.9247613614984995, 0.9203233429244453], 
             UndirectedEdge[63, 91] -> 
             RGBColor[
              0.9806737859779135, 0.9449381568757105, 0.509702723868843], 
             UndirectedEdge[125, 195] -> 
             RGBColor[
              0.9082129533549717, 0.7959156328982329, 0.616754860806948], 
             UndirectedEdge[86, 180] -> 
             RGBColor[
              0.9681670358827063, 0.903218432576026, 0.3363748618342158], 
             UndirectedEdge[137, 186] -> 
             RGBColor[
              0.9314698771621855, 0.7583149200988517, 0.5378216479899315], 
             UndirectedEdge[33, 44] -> 
             RGBColor[
              0.9907647587885887, 0.9883321263756598, 0.6488406719305344], 
             UndirectedEdge[14, 193] -> 
             RGBColor[
              0.9936250213464497, 0.9916317967443479, 0.7553134244126256], 
             UndirectedEdge[11, 28] -> 
             RGBColor[
              0.6843038765247612, 0.6135253744858324, 0.5956784031882094], 
             UndirectedEdge[85, 151] -> 
             RGBColor[
              0.9897971432490444, 0.9881039717200301, 0.6773776405220929], 
             UndirectedEdge[175, 199] -> 
             RGBColor[
              0.9020810899599767, 0.635050778879544, 0.4322713498534705], 
             UndirectedEdge[146, 196] -> 
             RGBColor[
              0.989162275679458, 0.9879895840171187, 0.6986677150465508], 
             UndirectedEdge[20, 77] -> 
             RGBColor[
              0.9710713015517025, 0.9140788487317939, 0.34211789856501706`], 
             UndirectedEdge[27, 56] -> 
             RGBColor[
              0.9077033748034868, 0.92921513905051, 0.9901257886083824], 
             UndirectedEdge[101, 175] -> 
             RGBColor[
              0.8916664750003195, 0.5913180776611355, 0.2308171859882529], 
             UndirectedEdge[21, 85] -> 
             RGBColor[
              0.9907287968423566, 0.9900966845514974, 0.7787823846546166], 
             UndirectedEdge[150, 194] -> 
             RGBColor[
              0.9078472733817198, 0.6576988057779247, 0.422174179445194], 
             UndirectedEdge[61, 160] -> 
             RGBColor[
              0.8574087806452035, 0.407076022707355, 0.4396556123074359], 
             UndirectedEdge[24, 149] -> 
             RGBColor[
              0.9645692483756954, 0.9121884715690883, 0.5997772409373363], 
             UndirectedEdge[14, 186] -> 
             RGBColor[
              0.9909324720630046, 0.990518358420283, 0.7999359341334887], 
             UndirectedEdge[111, 126] -> 
             RGBColor[
              0.898637324555907, 0.6269519486373641, 0.23683976007241447`], 
             UndirectedEdge[35, 88] -> 
             RGBColor[
              0.8745335821357476, 0.4511251205070539, 0.4226113408116632], 
             UndirectedEdge[94, 111] -> 
             RGBColor[
              0.8863922907258436, 0.577015750588235, 0.22691528141291584`], 
             UndirectedEdge[133, 162] -> 
             RGBColor[
              0.9244714062497746, 0.7382613247318844, 0.25808612446585777`], 
             UndirectedEdge[124, 199] -> 
             RGBColor[
              0.9830751398968796, 0.9670289568750794, 0.6325574744296342], 
             UndirectedEdge[54, 105] -> 
             RGBColor[
              0.9777625656451834, 0.9701342847006371, 0.6672718743382287], 
             UndirectedEdge[64, 162] -> 
             RGBColor[
              0.937883165272043, 0.7914344800514219, 0.2688775405896205], 
             UndirectedEdge[57, 66] -> 
             RGBColor[
              0.8610155836424019, 0.4325176120344759, 0.44223813669858336`], 
             UndirectedEdge[16, 137] -> 
             RGBColor[
              0.9232650425120339, 0.7207480252942033, 0.27989235237189347`], 
             UndirectedEdge[44, 50] -> 
             RGBColor[
              0.9885794883931288, 0.9729373838741275, 0.4271991435733949], 
             UndirectedEdge[153, 167] -> 
             RGBColor[
              0.9844827366336464, 0.9590848780214276, 0.4141071423749657], 
             UndirectedEdge[165, 187] -> 
             RGBColor[
              0.6899133316288371, 0.7405537807122743, 0.674079953746545], 
             UndirectedEdge[32, 83] -> 
             RGBColor[
              0.9030210842531394, 0.6396771261786143, 0.43456582412421774`], 
             UndirectedEdge[6, 187] -> 
             RGBColor[
              0.9327863432691721, 0.7549786474791361, 0.3113601128774356], 
             UndirectedEdge[66, 141] -> 
             RGBColor[
              0.8763344698386915, 0.4344419348917774, 0.24408688072154833`], 
             UndirectedEdge[23, 87] -> 
             RGBColor[
              0.8840186377908303, 0.8022054176939059, 0.6201756128372048], 
             UndirectedEdge[85, 152] -> 
             RGBColor[
              0.9730605375650787, 0.9319711953372021, 0.5848318904603721], 
             UndirectedEdge[26, 74] -> 
             RGBColor[
              0.989200790393373, 0.9748266030578192, 0.4471787164375576], 
             UndirectedEdge[81, 172] -> 
             RGBColor[
              0.9890006478889575, 0.9897194994786979, 0.8319512600981518], 
             UndirectedEdge[54, 73] -> 
             RGBColor[
              0.9822402245733346, 0.9734737153977586, 0.6596923657333533], 
             UndirectedEdge[135, 165] -> 
             RGBColor[
              0.6731630664636898, 0.6831609888449381, 0.6136445878907197], 
             UndirectedEdge[46, 109] -> 
             RGBColor[
              0.9813505095085977, 0.9470848825505775, 0.5238979702278448], 
             UndirectedEdge[40, 171] -> 
             RGBColor[
              0.9847395052233048, 0.9586527825666911, 0.5254972753905323], 
             UndirectedEdge[113, 167] -> 
             RGBColor[
              0.98507951922567, 0.9603613356417904, 0.4790632446014959], 
             UndirectedEdge[103, 162] -> 
             RGBColor[
              0.9564752432852658, 0.8672780412257182, 0.565956002108499], 
             UndirectedEdge[37, 119] -> 
             RGBColor[
              0.9759350911687957, 0.9393122718884901, 0.579718083220842], 
             UndirectedEdge[71, 184] -> 
             RGBColor[
              0.8838915153853119, 0.498522518050739, 0.41349926782014784`], 
             UndirectedEdge[107, 142] -> 
             RGBColor[
              0.5843600876764482, 0.6477206149760317, 0.8761590145126756], 
             UndirectedEdge[136, 143] -> 
             RGBColor[
              0.9853926974697047, 0.965903964681956, 0.5797494286264244], 
             UndirectedEdge[3, 5] -> 
             RGBColor[
              0.9660404872112219, 0.8907743787282172, 0.4359219419683845], 
             UndirectedEdge[24, 118] -> 
             RGBColor[
              0.9623929414358241, 0.8831278105135689, 0.31713738913358763`], 
             UndirectedEdge[142, 185] -> 
             RGBColor[
              0.5303285307065693, 0.430619828085281, 0.5782630014963484], 
             UndirectedEdge[3, 28] -> 
             RGBColor[
              0.9201493165668391, 0.7205855268734189, 0.2545805281244778], 
             UndirectedEdge[43, 49] -> 
             RGBColor[
              0.9867063619577345, 0.9667334866921484, 0.4101778045203105], 
             UndirectedEdge[19, 60] -> 
             RGBColor[
              0.9604888962912701, 0.8783819109214386, 0.30100725244778526`], 
             UndirectedEdge[87, 110] -> 
             RGBColor[
              0.8943725067768388, 0.6085075376181349, 0.23332874070064608`], 
             UndirectedEdge[107, 185] -> 
             RGBColor[
              0.9357616183830175, 0.7729464430613127, 0.5209210160090241], 
             UndirectedEdge[66, 81] -> 
             RGBColor[
              0.8791611935442524, 0.44507375373640845`, 0.36777815753080056`],
              UndirectedEdge[63, 112] -> 
             RGBColor[
              0.994914695414206, 0.9915313726311767, 0.6878741625774609], 
             UndirectedEdge[59, 193] -> 
             RGBColor[
              0.9905349278464027, 0.9903539636702978, 0.8065242706140339], 
             UndirectedEdge[110, 180] -> 
             RGBColor[
              0.9102065098429413, 0.6712840834064964, 0.24606915123945294`], 
             UndirectedEdge[21, 196] -> 
             RGBColor[
              0.994045049260784, 0.9896712874437208, 0.5932185456114312], 
             UndirectedEdge[24, 190] -> 
             RGBColor[
              0.7686793641679461, 0.7581394141614929, 0.6197487244215336], 
             UndirectedEdge[44, 60] -> 
             RGBColor[
              0.9754294929679728, 0.9285793615393196, 0.3761138945149295], 
             UndirectedEdge[20, 106] -> 
             RGBColor[
              0.9887786441783997, 0.9758974841345032, 0.5830323989496915], 
             UndirectedEdge[75, 139] -> 
             RGBColor[
              0.9083884319581398, 0.9193337560009089, 0.6965717063174044], 
             UndirectedEdge[4, 81] -> 
             RGBColor[
              0.9558348046677918, 0.8532958436344724, 0.5094449763492159], 
             UndirectedEdge[79, 197] -> 
             RGBColor[
              0.8432295098042817, 0.822927591091384, 0.6278627485911301], 
             UndirectedEdge[66, 90] -> 
             RGBColor[
              0.8773922896462469, 0.43801020949056446`, 0.24819631092139272`],
              UndirectedEdge[14, 15] -> 
             RGBColor[
              0.9752053647520689, 0.9793287013607167, 0.8507219383352637], 
             UndirectedEdge[14, 48] -> 
             RGBColor[
              0.9915441606134194, 0.9907713073555584, 0.7897986718538885], 
             UndirectedEdge[122, 144] -> 
             RGBColor[
              0.9881527485680737, 0.9700229299366102, 0.5509613176921461], 
             UndirectedEdge[80, 121] -> 
             RGBColor[
              0.8664668441526574, 0.4865389514056778, 0.21028900037486048`], 
             UndirectedEdge[79, 170] -> 
             RGBColor[
              0.8636893642547663, 0.8911468753040099, 0.8243793950675367], 
             UndirectedEdge[91, 95] -> 
             RGBColor[
              0.9417353712886414, 0.9174675288764292, 0.6578896124374289], 
             UndirectedEdge[48, 193] -> 
             RGBColor[
              0.9907441356052096, 0.9904404764549586, 0.8030571566382803], 
             UndirectedEdge[67, 162] -> 
             RGBColor[
              0.9191325716760894, 0.8392082807943666, 0.6255410420245041], 
             UndirectedEdge[65, 87] -> 
             RGBColor[
              0.9571812524405525, 0.8560793150168666, 0.4034165387307246], 
             UndirectedEdge[98, 121] -> 
             RGBColor[
              0.9036468781621817, 0.6327840240232467, 0.27383829543934146`], 
             UndirectedEdge[161, 187] -> 
             RGBColor[
              0.9778896030329656, 0.9370785806414141, 0.36860571229152983`], 
             UndirectedEdge[68, 122] -> 
             RGBColor[
              0.9913633693172359, 0.9808531076131355, 0.5634339730277871], 
             UndirectedEdge[19, 90] -> 
             RGBColor[
              0.9753258789529131, 0.9284305373283572, 0.35864612835919485`], 
             UndirectedEdge[80, 168] -> 
             RGBColor[
              0.8176140128975675, 0.6725530893527938, 0.5977767358589183], 
             UndirectedEdge[109, 194] -> 
             RGBColor[
              0.9101579704018794, 0.6586105760750874, 0.3806988924880668], 
             UndirectedEdge[44, 57] -> 
             RGBColor[
              0.9657014166238483, 0.9703890917621054, 0.7248155090921249], 
             UndirectedEdge[109, 151] -> 
             RGBColor[
              0.9941167202042522, 0.9898245843447555, 0.6010194855061562], 
             UndirectedEdge[122, 138] -> 
             RGBColor[
              0.9946282515670091, 0.9909186982059379, 0.6566965175365911], 
             UndirectedEdge[138, 192] -> 
             RGBColor[
              0.9946282515670091, 0.9909186982059379, 0.6566965175365911], 
             UndirectedEdge[31, 46] -> 
             RGBColor[
              0.9445788195690257, 0.8145702886738407, 0.29202555425028803`], 
             UndirectedEdge[101, 165] -> 
             RGBColor[
              0.6739170295220744, 0.686150201128138, 0.6142512442652835], 
             UndirectedEdge[76, 105] -> 
             RGBColor[
              0.9542327244790456, 0.9653874213702838, 0.9623562388264915], 
             UndirectedEdge[6, 199] -> 
             RGBColor[
              0.9324119636018955, 0.7661741197226125, 0.5537126491940005], 
             UndirectedEdge[83, 175] -> 
             RGBColor[
              0.861296181945288, 0.46306018196085397`, 0.20597447308450284`], 
             UndirectedEdge[139, 182] -> 
             RGBColor[
              0.9411890937191507, 0.7919640675591713, 0.3214271220044402], 
             UndirectedEdge[89, 149] -> 
             RGBColor[
              0.9622968667785837, 0.9714016454934581, 0.9487057493785325], 
             UndirectedEdge[53, 163] -> 
             RGBColor[
              0.9530045501053828, 0.8396856853084471, 0.3902563491235759], 
             UndirectedEdge[8, 96] -> 
             RGBColor[
              0.8179707951882927, 0.577340424454975, 0.4629683678318515], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.978741694733058, 0.9399528860264713, 0.37191592764237313`], 
             UndirectedEdge[55, 191] -> 
             RGBColor[
              0.8920276898405548, 0.5997290642161706, 0.23146883868022866`], 
             UndirectedEdge[122, 181] -> 
             RGBColor[
              0.9790436396496653, 0.98200437469569, 0.8343154347080053], 
             UndirectedEdge[130, 177] -> 
             RGBColor[
              0.9661369604263215, 0.9740855329421503, 0.9341425504336263], 
             UndirectedEdge[25, 131] -> 
             RGBColor[
              0.9653288866458039, 0.9736629209459539, 0.9435733306207608], 
             UndirectedEdge[19, 33] -> 
             RGBColor[
              0.9758241621118859, 0.9381346757577788, 0.5737340298633902], 
             UndirectedEdge[1, 89] -> 
             RGBColor[
              0.9646002901977704, 0.9731195349079778, 0.9448066543588934], 
             UndirectedEdge[123, 127] -> 
             RGBColor[
              0.7727410423693388, 0.35327898733742025`, 0.434119626196914], 
             UndirectedEdge[40, 173] -> 
             RGBColor[
              0.9326667774045176, 0.7614173687214693, 0.2930195473682883], 
             UndirectedEdge[17, 106] -> 
             RGBColor[
              0.9574605972220418, 0.860272717226188, 0.5133522548500262], 
             UndirectedEdge[51, 158] -> 
             RGBColor[
              0.9061953577189721, 0.9168417460967556, 0.6952690195901687], 
             UndirectedEdge[20, 189] -> 
             RGBColor[
              0.9891355523490111, 0.9744440648191894, 0.4607409798728853], 
             UndirectedEdge[48, 140] -> 
             RGBColor[
              0.986967442953235, 0.9888787169867932, 0.8656467276487758], 
             UndirectedEdge[11, 189] -> 
             RGBColor[
              0.7298410580600982, 0.7829570794301708, 0.7384902870800324], 
             UndirectedEdge[40, 169] -> 
             RGBColor[
              0.9843697194394945, 0.958755643254193, 0.5502178423926809], 
             UndirectedEdge[94, 167] -> 
             RGBColor[
              0.9377446958874583, 0.7835468225073088, 0.2996817455060716], 
             UndirectedEdge[81, 198] -> 
             RGBColor[
              0.9058900689884035, 0.6422937674062221, 0.3930514991170133], 
             UndirectedEdge[34, 60] -> 
             RGBColor[
              0.8808516286845389, 0.5072634878560622, 0.22255500151879584`], 
             UndirectedEdge[13, 101] -> 
             RGBColor[
              0.9646215140822716, 0.8918779046476091, 0.31937559574177066`], 
             UndirectedEdge[31, 117] -> 
             RGBColor[
              0.9339421894483376, 0.7758098241627729, 0.2657065389352752], 
             UndirectedEdge[94, 105] -> 
             RGBColor[
              0.9346483435402626, 0.806586329980123, 0.5868126796435288], 
             UndirectedEdge[125, 190] -> 
             RGBColor[
              0.7494738776712937, 0.80410971613724, 0.9760462083508062], 
             UndirectedEdge[79, 119] -> 
             RGBColor[
              0.8603713984556527, 0.8901954791875761, 0.9099447984602179], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.9435983708136739, 0.8050123598748511, 0.3179290959810624], 
             UndirectedEdge[156, 178] -> 
             RGBColor[
              0.8452282065776401, 0.31093047084209247`, 0.18946690939356317`],
              UndirectedEdge[95, 131] -> 
             RGBColor[
              0.9444265402230436, 0.9575945920992328, 0.9623346908766792], 
             UndirectedEdge[49, 133] -> 
             RGBColor[
              0.9576007877507973, 0.8586754777009633, 0.3485533162946798], 
             UndirectedEdge[34, 44] -> 
             RGBColor[
              0.892450752846761, 0.5462562637980636, 0.27899223876028817`], 
             UndirectedEdge[24, 125] -> 
             RGBColor[
              0.9310868974767353, 0.8866031990510022, 0.6351597731677949], 
             UndirectedEdge[95, 129] -> 
             RGBColor[
              0.9469368335200684, 0.9594667647299259, 0.9580854191141654], 
             UndirectedEdge[13, 16] -> 
             RGBColor[
              0.9729063499270223, 0.920268897791596, 0.34924671498332643`], 
             UndirectedEdge[13, 199] -> 
             RGBColor[
              0.9802434365217576, 0.9574769564752218, 0.6215568415395971], 
             UndirectedEdge[121, 196] -> 
             RGBColor[
              0.90522778278249, 0.6378303140077598, 0.30433936612847506`], 
             UndirectedEdge[26, 40] -> 
             RGBColor[
              0.9838281989665503, 0.9567035906306894, 0.42630721327310994`], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.9895763561909825, 0.9758740856773895, 0.467292975851868], 
             UndirectedEdge[54, 126] -> 
             RGBColor[
              0.9547651480938089, 0.8495916280612108, 0.3281578227953549], 
             UndirectedEdge[16, 193] -> 
             RGBColor[
              0.981927612404643, 0.952620632715035, 0.5552651232998423], 
             UndirectedEdge[85, 150] -> 
             RGBColor[
              0.987420285623404, 0.989065979068434, 0.8581419526848113], 
             UndirectedEdge[26, 169] -> 
             RGBColor[
              0.9937044195077843, 0.9898365099329997, 0.6211125666371377], 
             UndirectedEdge[22, 79] -> 
             RGBColor[
              0.8536088415529867, 0.8585570681248831, 0.6649682614520576], 
             UndirectedEdge[27, 67] -> 
             RGBColor[
              0.9243119622187881, 0.9424583758273757, 0.9917099305027148], 
             UndirectedEdge[49, 95] -> 
             RGBColor[
              0.9548755887719726, 0.9617064758415392, 0.7162575247495839], 
             UndirectedEdge[147, 178] -> 
             RGBColor[
              0.8645088293653139, 0.42780121968811446`, 0.433529151002207], 
             UndirectedEdge[1, 136] -> 
             RGBColor[
              0.9812455112511466, 0.9640662151442884, 0.6429806322743363], 
             UndirectedEdge[65, 110] -> 
             RGBColor[
              0.9308556156205031, 0.7412852569565707, 0.38169521066588313`], 
             UndirectedEdge[77, 106] -> 
             RGBColor[
              0.975004999027247, 0.9294357448339895, 0.5295243884720982], 
             UndirectedEdge[25, 64] -> 
             RGBColor[
              0.9541479865936575, 0.9029520712086194, 0.6162816863025232], 
             UndirectedEdge[82, 187] -> 
             RGBColor[
              0.952151598059217, 0.9516490961856181, 0.696950033839093], 
             UndirectedEdge[167, 188] -> 
             RGBColor[
              0.8789170069639126, 0.4664381588188723, 0.23831708018022824`], 
             UndirectedEdge[13, 137] -> 
             RGBColor[
              0.92514116396801, 0.7270766234994774, 0.28718072995255245`], 
             UndirectedEdge[37, 125] -> 
             RGBColor[
              0.9377965752242712, 0.9109134093722057, 0.6524923233526838], 
             UndirectedEdge[105, 182] -> 
             RGBColor[
              0.9319062185928182, 0.7941349810333305, 0.5845245833717481], 
             UndirectedEdge[111, 116] -> 
             RGBColor[
              0.9226418484814407, 0.748245703561653, 0.5742490432192469], 
             UndirectedEdge[146, 179] -> 
             RGBColor[
              0.7352114660222124, 0.7905712262760173, 0.9243997426492583], 
             UndirectedEdge[9, 63] -> 
             RGBColor[
              0.94538730076896, 0.8056836312740466, 0.46516913140380434`], 
             UndirectedEdge[38, 120] -> 
             RGBColor[
              0.9749119693337887, 0.9771255860372187, 0.6986936136720275], 
             UndirectedEdge[71, 81] -> 
             RGBColor[
              0.9894868769641805, 0.9899205676968199, 0.8238931860011962], 
             UndirectedEdge[68, 181] -> 
             RGBColor[
              0.9751889450046856, 0.9706772350287214, 0.6768554508811326], 
             UndirectedEdge[114, 158] -> 
             RGBColor[
              0.9097196211434855, 0.9272333216738942, 0.8362195401862109], 
             UndirectedEdge[118, 149] -> 
             RGBColor[
              0.9766698058381318, 0.9546833850074022, 0.6380523408324017], 
             UndirectedEdge[87, 162] -> 
             RGBColor[
              0.923540937984492, 0.7345723281202075, 0.2573374478587141], 
             UndirectedEdge[88, 122] -> 
             RGBColor[
              0.8811251095288941, 0.45478307978776245`, 0.35409200664229146`],
              UndirectedEdge[49, 162] -> 
             RGBColor[
              0.9595131138731183, 0.8662572135310629, 0.3500920187807627], 
             UndirectedEdge[47, 116] -> 
             RGBColor[
              0.9620948097064583, 0.971250951659905, 0.9490477792967162], 
             UndirectedEdge[23, 95] -> 
             RGBColor[
              0.8822239070772885, 0.9089254124461588, 0.9886284978992528], 
             UndirectedEdge[54, 115] -> 
             RGBColor[
              0.9868057766309044, 0.9762498345967736, 0.6238023495419378], 
             UndirectedEdge[62, 105] -> 
             RGBColor[
              0.9227271409008706, 0.9403398794209208, 0.9619222154604565], 
             UndirectedEdge[13, 108] -> 
             RGBColor[
              0.9622194194591915, 0.882354399917678, 0.3174428140236327], 
             UndirectedEdge[76, 182] -> 
             RGBColor[
              0.9162481481501634, 0.7824572177349357, 0.6110296123523382], 
             UndirectedEdge[117, 171] -> 
             RGBColor[
              0.9706036811076586, 0.9080887150608077, 0.4855845521724458], 
             UndirectedEdge[40, 46] -> 
             RGBColor[
              0.9709943049033023, 0.9138191209570674, 0.3418187811255794], 
             UndirectedEdge[19, 177] -> 
             RGBColor[
              0.9549725848062827, 0.9233327684800366, 0.6425794477226665], 
             UndirectedEdge[64, 87] -> 
             RGBColor[
              0.9350403708844393, 0.7801637476096455, 0.26659016149639386`], 
             UndirectedEdge[62, 107] -> 
             RGBColor[
              0.9326783311164686, 0.9468309020626133, 0.9034051250501816], 
             UndirectedEdge[53, 148] -> 
             RGBColor[
              0.993035765754303, 0.9875125320775737, 0.4833642645067685], 
             UndirectedEdge[76, 111] -> 
             RGBColor[
              0.9059766716646266, 0.7358168419783957, 0.6024588405958785], 
             UndirectedEdge[11, 48] -> 
             RGBColor[
              0.7274596164986045, 0.7835733021602198, 0.8943334637682239], 
             UndirectedEdge[96, 111] -> 
             RGBColor[
              0.8002388840370879, 0.6523293097386583, 0.5947452562482682], 
             UndirectedEdge[168, 198] -> 
             RGBColor[
              0.8276567686242036, 0.5822070859596379, 0.46340607894910013`], 
             UndirectedEdge[118, 128] -> 
             RGBColor[
              0.9791143368015935, 0.9412098952241601, 0.37336357171108364`], 
             UndirectedEdge[56, 129] -> 
             RGBColor[
              0.9277146105099064, 0.9441394858749665, 0.9562519863235752], 
             UndirectedEdge[53, 100] -> 
             RGBColor[
              0.9810262008846471, 0.9822743747412385, 0.735062958908298], 
             UndirectedEdge[129, 143] -> 
             RGBColor[
              0.9842561584619124, 0.9865236341221058, 0.8553232973198981], 
             UndirectedEdge[18, 160] -> 
             RGBColor[
              0.8728163460402717, 0.4084356572039355, 0.24001512314621232`], 
             UndirectedEdge[68, 111] -> 
             RGBColor[
              0.9304436819825592, 0.7437249969155346, 0.3110152012927949], 
             UndirectedEdge[51, 166] -> 
             RGBColor[
              0.9725328541634398, 0.9691833667834897, 0.682385413505989], 
             UndirectedEdge[107, 181] -> 
             RGBColor[
              0.9763311953450057, 0.9809378660316697, 0.883276970793351], 
             UndirectedEdge[31, 173] -> 
             RGBColor[
              0.9062512920702408, 0.6621685364382426, 0.2432263204929969], 
             UndirectedEdge[135, 148] -> 
             RGBColor[
              0.9727706037855268, 0.9188679645406623, 0.3578466521496736], 
             UndirectedEdge[44, 177] -> 
             RGBColor[
              0.9699131814829853, 0.9735302190979177, 0.7176860897898107], 
             UndirectedEdge[80, 184] -> 
             RGBColor[
              0.8475429063717699, 0.3470308806013059, 0.192400387893209], 
             UndirectedEdge[65, 162] -> 
             RGBColor[
              0.9600240468281563, 0.8673500474586432, 0.4057039178239512], 
             UndirectedEdge[5, 17] -> 
             RGBColor[
              0.958171494501699, 0.8595764448213342, 0.4295903657253039], 
             UndirectedEdge[44, 141] -> 
             RGBColor[
              0.9886797459182826, 0.9732755760480577, 0.4275886251265724], 
             UndirectedEdge[94, 174] -> 
             RGBColor[
              0.9384438831830623, 0.7859053454323648, 0.302397956119051], 
             UndirectedEdge[161, 193] -> 
             RGBColor[
              0.9810755207045505, 0.949746327329978, 0.551954907948999], 
             UndirectedEdge[101, 124] -> 
             RGBColor[
              0.9674532174573938, 0.9014299050474667, 0.3303762286318077], 
             UndirectedEdge[106, 189] -> 
             RGBColor[
              0.9930692498245555, 0.9898009609213849, 0.6481474697799664], 
             UndirectedEdge[2, 80] -> 
             RGBColor[
              0.9199396760253363, 0.7103577381302923, 0.2648133630957115], 
             UndirectedEdge[97, 102] -> 
             RGBColor[
              0.9872124580985817, 0.9679227459860433, 0.45618422610865905`], 
             UndirectedEdge[91, 136] -> 
             RGBColor[
              0.9727000616466975, 0.9195730389832688, 0.34844532396853733`], 
             UndirectedEdge[59, 154] -> 
             RGBColor[
              0.8765174233129563, 0.43630832460071833`, 0.39309975571286704`],
              UndirectedEdge[108, 162] -> 
             RGBColor[
              0.9380200499537401, 0.7919771822002348, 0.2689876812176104], 
             UndirectedEdge[146, 147] -> 
             RGBColor[
              0.9686721849176321, 0.9760012935596868, 0.9309703744067428], 
             UndirectedEdge[99, 156] -> 
             RGBColor[
              0.6803165836368232, 0.5954200087376202, 0.5923513082650218], 
             UndirectedEdge[143, 154] -> 
             RGBColor[
              0.8776849142125985, 0.43679111209086796`, 0.3737514101361997], 
             UndirectedEdge[139, 145] -> 
             RGBColor[
              0.9881416563567031, 0.9809787137535092, 0.6305308912562618], 
             UndirectedEdge[104, 123] -> 
             RGBColor[
              0.8512618911357872, 0.3354477985143044, 0.19436634020917745`], 
             UndirectedEdge[116, 126] -> 
             RGBColor[
              0.9479004837444852, 0.8572736263141149, 0.595032389906986], 
             UndirectedEdge[17, 28] -> 
             RGBColor[
              0.9122803238573163, 0.6893875929665361, 0.24824895188139715`], 
             UndirectedEdge[89, 118] -> 
             RGBColor[
              0.9601205598387126, 0.9423409844379387, 0.6660658975747837], 
             UndirectedEdge[123, 163] -> 
             RGBColor[
              0.8509297092192409, 0.33413080790825966`, 0.1940990588418125], 
             UndirectedEdge[47, 157] -> 
             RGBColor[
              0.8868564484632833, 0.9121915779413934, 0.9742418213748805], 
             UndirectedEdge[117, 151] -> 
             RGBColor[
              0.9696246914833107, 0.905994755245362, 0.3790275731858044], 
             UndirectedEdge[69, 86] -> 
             RGBColor[
              0.9843488966488402, 0.9588672947220236, 0.3936988482539548], 
             UndirectedEdge[73, 94] -> 
             RGBColor[
              0.9391260024684138, 0.8099257606772445, 0.5792331710386533], 
             UndirectedEdge[61, 174] -> 
             RGBColor[
              0.9575351080714551, 0.9443386418476136, 0.6787762998596266], 
             UndirectedEdge[175, 187] -> 
             RGBColor[
              0.9023306764048278, 0.6275871307172264, 0.27070299230909384`], 
             UndirectedEdge[75, 134] -> 
             RGBColor[
              0.9113526996057407, 0.9289451275029217, 0.863102201648064], 
             UndirectedEdge[38, 178] -> 
             RGBColor[
              0.8661645700940879, 0.42903606841260733`, 0.43072641383473687`],
              UndirectedEdge[8, 179] -> 
             RGBColor[
              0.7373703155014547, 0.5127707306547358, 0.45603151958926497`], 
             UndirectedEdge[29, 167] -> 
             RGBColor[
              0.9113736555867087, 0.9057784636273346, 0.6734130429073367], 
             UndirectedEdge[68, 185] -> 
             RGBColor[
              0.9346193680426973, 0.7626858120583644, 0.31449949609680566`], 
             UndirectedEdge[79, 118] -> 
             RGBColor[
              0.8535389264702169, 0.8583212281338585, 0.6646966545578525], 
             UndirectedEdge[171, 173] -> 
             RGBColor[
              0.9429127837295619, 0.7944474273362774, 0.46310433373016746`], 
             UndirectedEdge[80, 166] -> 
             RGBColor[
              0.9170513714218764, 0.7507891664000841, 0.5881825041572512], 
             UndirectedEdge[109, 132] -> 
             RGBColor[
              0.9749214192354363, 0.9250059114554143, 0.5009644402378055], 
             UndirectedEdge[118, 197] -> 
             RGBColor[
              0.9641840822323253, 0.8902290869094084, 0.31857858306193065`], 
             UndirectedEdge[111, 167] -> 
             RGBColor[
              0.9247310944544771, 0.7244550978039762, 0.28882287747783103`], 
             UndirectedEdge[113, 122] -> 
             RGBColor[
              0.994646801398732, 0.9909583744203174, 0.6587155522433323], 
             UndirectedEdge[119, 190] -> 
             RGBColor[
              0.7876123936158181, 0.8325085786535245, 0.9032719682189643], 
             UndirectedEdge[19, 130] -> 
             RGBColor[
              0.9741113614779392, 0.9374263886786733, 0.6021195689538394], 
             UndirectedEdge[35, 167] -> 
             RGBColor[
              0.975763490699434, 0.9560962695805142, 0.6440206504668807], 
             UndirectedEdge[102, 112] -> 
             RGBColor[
              0.9941627828480739, 0.9899231076822422, 0.606033120020452], 
             UndirectedEdge[134, 145] -> 
             RGBColor[
              0.9911059240043041, 0.990590085255522, 0.7970613865869214], 
             UndirectedEdge[109, 150] -> 
             RGBColor[
              0.9917398625786118, 0.9907865916931593, 0.7817837976688746], 
             UndirectedEdge[147, 179] -> 
             RGBColor[
              0.7187583586162191, 0.7784555794753663, 0.959194186141586], 
             UndirectedEdge[63, 102] -> 
             RGBColor[
              0.9942335989822169, 0.9900745762325647, 0.6137410191954025], 
             UndirectedEdge[62, 182] -> 
             RGBColor[
              0.8847425645719882, 0.7574096757855728, 0.6105955889863034], 
             UndirectedEdge[8, 99] -> 
             RGBColor[
              0.7310230883028648, 0.5076177656755937, 0.45553184261353263`], 
             UndirectedEdge[60, 123] -> 
             RGBColor[
              0.8660979295913083, 0.3938600915133244, 0.2084268426051983], 
             UndirectedEdge[7, 97] -> 
             RGBColor[
              0.9872308028971888, 0.9679619836553199, 0.4581809442260522], 
             UndirectedEdge[130, 163] -> 
             RGBColor[
              0.9489009413532078, 0.8395407499759551, 0.5710786795136664], 
             UndirectedEdge[127, 135] -> 
             RGBColor[
              0.8154563878617536, 0.7997633869152767, 0.6247695877991333], 
             UndirectedEdge[37, 56] -> 
             RGBColor[
              0.9211879878089699, 0.89767017259534, 0.6509081814583514], 
             UndirectedEdge[100, 148] -> 
             RGBColor[
              0.9805790120366222, 0.9813178830130411, 0.6863892125304484], 
             UndirectedEdge[53, 135] -> 
             RGBColor[
              0.9732177926335517, 0.9198244562688597, 0.40652039852752314`], 
             UndirectedEdge[103, 154] -> 
             RGBColor[
              0.8759580549275797, 0.4360770113982533, 0.402369937457536], 
             UndirectedEdge[63, 140] -> 
             RGBColor[
              0.9901285612913198, 0.9899301440444582, 0.7946665564852099], 
             UndirectedEdge[8, 75] -> 
             RGBColor[
              0.8517112085084929, 0.6037436113513228, 0.4663193766357389], 
             UndirectedEdge[50, 53] -> 
             RGBColor[
              0.9889068760886399, 0.9736376330508523, 0.46283327382712], 
             UndirectedEdge[1, 167] -> 
             RGBColor[
              0.979768229616234, 0.9590829973075056, 0.6372416720839296], 
             UndirectedEdge[27, 119] -> 
             RGBColor[
              0.9624504781633126, 0.9708572383436602, 0.918935690370873], 
             UndirectedEdge[96, 126] -> 
             RGBColor[
              0.8254975193001324, 0.7613572324911202, 0.6155286029360074], 
             UndirectedEdge[102, 106] -> 
             RGBColor[
              0.9930970140350144, 0.9898603457601645, 0.6511694327475831], 
             UndirectedEdge[16, 176] -> 
             RGBColor[
              0.9782552458991045, 0.9511020147894806, 0.6161257400764781], 
             UndirectedEdge[40, 166] -> 
             RGBColor[
              0.9658398992981104, 0.9466064584421987, 0.6563845477126564], 
             UndirectedEdge[33, 90] -> 
             RGBColor[
              0.9882030552068988, 0.9798915888695764, 0.6218236919797054], 
             UndirectedEdge[13, 161] -> 
             RGBColor[
              0.97205425822693, 0.917394592406539, 0.34593649963248313`], 
             UndirectedEdge[11, 106] -> 
             RGBColor[
              0.7294841498894868, 0.7844104987454845, 0.8607817061568386], 
             UndirectedEdge[88, 167] -> 
             RGBColor[
              0.8747469214135195, 0.4343850539354111, 0.2343238015477338], 
             UndirectedEdge[29, 159] -> 
             RGBColor[
              0.8967526088955037, 0.9202228729283417, 0.980052278447519], 
             UndirectedEdge[156, 157] -> 
             RGBColor[
              0.8579027471661429, 0.7368610170111752, 0.6082039251416429], 
             UndirectedEdge[171, 183] -> 
             RGBColor[
              0.9077324961973, 0.6477735186456228, 0.37074005029519425`], 
             UndirectedEdge[100, 104] -> 
             RGBColor[
              0.9410460692625214, 0.8354665221529816, 0.5936822191983031], 
             UndirectedEdge[108, 180] -> 
             RGBColor[
              0.9510112586322388, 0.8434829955468197, 0.27944071266319065`], 
             UndirectedEdge[178, 179] -> 
             RGBColor[
              0.7088683501017009, 0.30418117483233464`, 0.4291487298305507], 
             UndirectedEdge[150, 151] -> 
             RGBColor[
              0.9906506746740128, 0.9884569288990115, 0.663232415941847], 
             UndirectedEdge[2, 121] -> 
             RGBColor[
              0.8951489994056866, 0.6041186835807704, 0.24082564116010646`], 
             UndirectedEdge[12, 14] -> 
             RGBColor[
              0.9699298117127617, 0.9066679695599418, 0.508504261702801], 
             UndirectedEdge[43, 131] -> 
             RGBColor[
              0.9762573134088055, 0.962621602949842, 0.6562549706474057], 
             UndirectedEdge[75, 76] -> 
             RGBColor[
              0.8834474863891524, 0.9098269061766735, 0.9861741966653026], 
             UndirectedEdge[113, 138] -> 
             RGBColor[
              0.9940569890035253, 0.9896968253461512, 0.5945181129252638], 
             UndirectedEdge[17, 20] -> 
             RGBColor[
              0.9535268997464974, 0.8449158211239924, 0.32594576494294525`], 
             UndirectedEdge[86, 187] -> 
             RGBColor[
              0.9852105415156946, 0.9617738251817594, 0.39704617585370455`], 
             UndirectedEdge[8, 185] -> 
             RGBColor[
              0.8695144560655678, 0.5003774453143576, 0.21283200245879674`], 
             UndirectedEdge[4, 41] -> 
             RGBColor[
              0.9442096687518586, 0.8124366064190849, 0.2952185350458331], 
             UndirectedEdge[8, 107] -> 
             RGBColor[
              0.905535494045487, 0.6451113032415247, 0.4114293444696816], 
             UndirectedEdge[149, 192] -> 
             RGBColor[
              0.9870320883701094, 0.9879621466715129, 0.8207930747454051], 
             UndirectedEdge[11, 140] -> 
             RGBColor[
              0.7257637845796601, 0.7828720320808438, 0.9224377873374565], 
             UndirectedEdge[94, 153] -> 
             RGBColor[
              0.9461439329050129, 0.8116455308056862, 0.3521995463100505], 
             UndirectedEdge[56, 79] -> 
             RGBColor[
              0.8056242950958269, 0.848553379894426, 0.9811348966977274], 
             UndirectedEdge[5, 15] -> 
             RGBColor[
              0.9750599096813684, 0.9782783052517384, 0.7811520238248106], 
             UndirectedEdge[79, 128] -> 
             RGBColor[
              0.8581597643735499, 0.8739083994061357, 0.6826477372402832], 
             UndirectedEdge[109, 152] -> 
             RGBColor[
              0.9773801145202865, 0.9336918079619274, 0.5084737354444354], 
             UndirectedEdge[118, 192] -> 
             RGBColor[
              0.9848557814302381, 0.9589014856159935, 0.5381532229416564], 
             UndirectedEdge[99, 107] -> 
             RGBColor[
              0.7280245667389631, 0.7838069236031668, 0.8849707762411279], 
             UndirectedEdge[3, 189] -> 
             RGBColor[
              0.9656864981021762, 0.8900172318177573, 0.3973924120163007], 
             UndirectedEdge[35, 138] -> 
             RGBColor[
              0.9847409604772893, 0.985431759284875, 0.7594755187906486], 
             UndirectedEdge[12, 86] -> 
             RGBColor[
              0.9647012495535916, 0.889477744685917, 0.33358620880134926`], 
             UndirectedEdge[16, 127] -> 
             RGBColor[
              0.8244951867648889, 0.8311435923424635, 0.6552473634152529], 
             UndirectedEdge[37, 195] -> 
             RGBColor[
              0.9341281175991599, 0.7742555412436892, 0.2777899270625642], 
             UndirectedEdge[57, 71] -> 
             RGBColor[
              0.9622684621114047, 0.9710863551439208, 0.9355831547528703], 
             UndirectedEdge[58, 73] -> 
             RGBColor[
              0.9030722122095778, 0.9244366398119381, 0.9520409191050234], 
             UndirectedEdge[35, 153] -> 
             RGBColor[
              0.9841627277169885, 0.9841949778788917, 0.6965384512708597], 
             UndirectedEdge[35, 122] -> 
             RGBColor[
              0.9853307728724959, 0.9866933083590412, 0.8236729581087172], 
             UndirectedEdge[19, 44] -> 
             RGBColor[
              0.9778875825346032, 0.9368710748344407, 0.38566310831002376`], 
             UndirectedEdge[181, 192] -> 
             RGBColor[
              0.9790436396496653, 0.98200437469569, 0.8343154347080053], 
             UndirectedEdge[119, 128] -> 
             RGBColor[
              0.9859468087870292, 0.9730841462778779, 0.618611715613449], 
             UndirectedEdge[116, 153] -> 
             RGBColor[
              0.98239349066061, 0.9828754837791043, 0.6995333081163815], 
             UndirectedEdge[186, 193] -> 
             RGBColor[
              0.9901324470547946, 0.9901875275196833, 0.8131944189178804], 
             UndirectedEdge[22, 119] -> 
             RGBColor[
              0.981395885966466, 0.9577328149966251, 0.6009322398252235], 
             UndirectedEdge[85, 109] -> 
             RGBColor[
              0.9908863311536436, 0.9904336345141779, 0.7959290222491205], 
             UndirectedEdge[98, 99] -> 
             RGBColor[
              0.7273562516496976, 0.7751449874873153, 0.680390405284095], 
             UndirectedEdge[161, 175] -> 
             RGBColor[
              0.896621637763425, 0.6083292028337555, 0.2485244552487279], 
             UndirectedEdge[54, 61] -> 
             RGBColor[
              0.9616113391521384, 0.9580887264273303, 0.6946116878764319], 
             UndirectedEdge[43, 154] -> 
             RGBColor[
              0.8740258797085438, 0.42210453972982087`, 0.23820634451286232`],
              UndirectedEdge[87, 95] -> 
             RGBColor[
              0.9189034128833463, 0.8300215904306838, 0.6235029538275354], 
             UndirectedEdge[12, 108] -> 
             RGBColor[
              0.947545472303124, 0.8297423076567109, 0.27665205963032413`], 
             UndirectedEdge[15, 48] -> 
             RGBColor[
              0.9723244790108287, 0.9781373810713274, 0.8984656705609182], 
             UndirectedEdge[13, 187] -> 
             RGBColor[
              0.9806178161890342, 0.9462814842317454, 0.37920430522303206`], 
             UndirectedEdge[15, 28] -> 
             RGBColor[
              0.9291687390369855, 0.8080894533969403, 0.5998106099809039], 
             UndirectedEdge[52, 134] -> 
             RGBColor[
              0.9217483916418486, 0.9372343701489712, 0.8640937520348118], 
             UndirectedEdge[66, 172] -> 
             RGBColor[
              0.8764873029755959, 0.44396803127041573`, 0.41209144406041265`],
              UndirectedEdge[101, 176] -> 
             RGBColor[
              0.9699704100543538, 0.9227110216454937, 0.5862546208349224], 
             UndirectedEdge[119, 192] -> 
             RGBColor[
              0.9916882534156739, 0.9907757366697112, 0.7834013668440217], 
             UndirectedEdge[168, 184] -> 
             RGBColor[
              0.8080079528729531, 0.43940751359139935`, 0.44491261052059294`],
              UndirectedEdge[16, 175] -> 
             RGBColor[
              0.8971896988968199, 0.6102454064237935, 0.2507312654826234], 
             UndirectedEdge[60, 104] -> 
             RGBColor[
              0.9357767490413582, 0.7824717581277874, 0.2703672850586597], 
             UndirectedEdge[122, 136] -> 
             RGBColor[
              0.9871280634240662, 0.96656642633836, 0.5469806094032299], 
             UndirectedEdge[107, 157] -> 
             RGBColor[
              0.9056107302682825, 0.9252479318767219, 0.9008233931177492], 
             UndirectedEdge[86, 110] -> 
             RGBColor[
              0.9260073959965545, 0.7256478287273684, 0.3019131232305675], 
             UndirectedEdge[5, 9] -> 
             RGBColor[
              0.9449616131014147, 0.8047731283967925, 0.41883565583126253`], 
             UndirectedEdge[3, 77] -> 
             RGBColor[
              0.9476222473048677, 0.8296520157303618, 0.27876933070843246`], 
             UndirectedEdge[84, 139] -> 
             RGBColor[
              0.9668286717065158, 0.9656873916444952, 0.6936506105795521], 
             UndirectedEdge[96, 191] -> 
             RGBColor[
              0.8206547408258285, 0.7421572296007666, 0.6116319897009618], 
             UndirectedEdge[46, 151] -> 
             RGBColor[
              0.9802613216039987, 0.9447552197564297, 0.4053465885008172], 
             UndirectedEdge[72, 191] -> 
             RGBColor[
              0.9403836349941699, 0.8360793061903002, 0.5956622801400009], 
             UndirectedEdge[111, 185] -> 
             RGBColor[
              0.8775543753530004, 0.536884841027732, 0.21954070818868604`], 
             UndirectedEdge[23, 129] -> 
             RGBColor[
              0.9120520584275524, 0.9316505919931479, 0.954758078123835], 
             UndirectedEdge[101, 123] -> 
             RGBColor[
              0.8649078462769433, 0.3895494634040012, 0.2053461960274866], 
             UndirectedEdge[122, 142] -> 
             RGBColor[
              0.5870725319811079, 0.6487871236400521, 0.8271974784273299], 
             UndirectedEdge[18, 174] -> 
             RGBColor[
              0.9806464561640573, 0.9463780935924843, 0.37931556611779127`], 
             UndirectedEdge[123, 135] -> 
             RGBColor[
              0.8644052042380203, 0.3875566552152014, 0.204941758444444], 
             UndirectedEdge[171, 178] -> 
             RGBColor[
              0.8787643073775507, 0.4370669511622688, 0.3434682322866541], 
             UndirectedEdge[81, 173] -> 
             RGBColor[
              0.9419257698263586, 0.7942950483343714, 0.4980539680058286], 
             UndirectedEdge[77, 102] -> 
             RGBColor[
              0.9753896714083174, 0.9280417103574553, 0.41025493236290866`], 
             UndirectedEdge[31, 171] -> 
             RGBColor[
              0.958324019889028, 0.8594039502834644, 0.47570404851524084`], 
             UndirectedEdge[109, 196] -> 
             RGBColor[
              0.9942025835720709, 0.9900082374064014, 0.6103651832059351], 
             UndirectedEdge[18, 153] -> 
             RGBColor[
              0.9883465058860079, 0.9721182789658056, 0.42911715630879077`], 
             UndirectedEdge[97, 140] -> 
             RGBColor[
              0.9831074204076846, 0.9677783137979369, 0.6371097633984664], 
             UndirectedEdge[116, 167] -> 
             RGBColor[
              0.9739942536430555, 0.9547767754807269, 0.6470155073124026], 
             UndirectedEdge[128, 190] -> 
             RGBColor[
              0.7854007595337154, 0.8162214988720841, 0.6759749069990295], 
             UndirectedEdge[94, 126] -> 
             RGBColor[
              0.9116509259888881, 0.6860436733406967, 0.24769862810065502`], 
             UndirectedEdge[41, 198] -> 
             RGBColor[
              0.8981399783777815, 0.6150542759292972, 0.2502338715814248], 
             UndirectedEdge[11, 77] -> 
             RGBColor[
              0.7117768072627898, 0.7225918633427754, 0.6198672057721641], 
             UndirectedEdge[29, 122] -> 
             RGBColor[
              0.9209409377597706, 0.9363755024058616, 0.8530653505491732], 
             UndirectedEdge[84, 152] -> 
             RGBColor[
              0.9523775595851937, 0.9169403971767909, 0.637510768851753], 
             UndirectedEdge[16, 64] -> 
             RGBColor[
              0.9602064133215182, 0.8754830995635909, 0.31004429581498383`], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.9848032673364648, 0.9734926977183602, 0.6436556042172106], 
             UndirectedEdge[26, 121] -> 
             RGBColor[
              0.9052156627823399, 0.6378043905529587, 0.30302017890810184`], 
             UndirectedEdge[40, 74] -> 
             RGBColor[
              0.9798660903250833, 0.9437457363790126, 0.37628399219310077`], 
             UndirectedEdge[78, 91] -> 
             RGBColor[
              0.9672529780575372, 0.936977911332503, 0.6313158202681849], 
             UndirectedEdge[139, 152] -> 
             RGBColor[
              0.9740054330530437, 0.9239763632526559, 0.35351644538348626`], 
             UndirectedEdge[40, 196] -> 
             RGBColor[
              0.9838463789667755, 0.9567424758128912, 0.4282859941036697], 
             UndirectedEdge[6, 86] -> 
             RGBColor[
              0.9315437237897969, 0.7507870001942748, 0.3065327708490614], 
             UndirectedEdge[82, 180] -> 
             RGBColor[
              0.9351080924262287, 0.8930937035798847, 0.6362787198196043], 
             UndirectedEdge[44, 90] -> 
             RGBColor[
              0.9902664756296159, 0.9786279879462383, 0.433752770426339], 
             UndirectedEdge[4, 66] -> 
             RGBColor[
              0.8543767408281521, 0.3530189273742655, 0.19708725489445542`], 
             UndirectedEdge[131, 143] -> 
             RGBColor[
              0.9817458651648876, 0.9846514614914126, 0.8595725690824119], 
             UndirectedEdge[22, 144] -> 
             RGBColor[
              0.9778603811188659, 0.936980008263524, 0.3684921906733478], 
             UndirectedEdge[35, 160] -> 
             RGBColor[
              0.8700271605942588, 0.4164867898126595, 0.41829598645425825`], 
             UndirectedEdge[76, 174] -> 
             RGBColor[
              0.9580282641218453, 0.9447064368225255, 0.6779415153020136], 
             UndirectedEdge[85, 196] -> 
             RGBColor[
              0.9898830066168631, 0.988287624781676, 0.6867233382218718], 
             UndirectedEdge[6, 137] -> 
             RGBColor[
              0.8773096910481479, 0.5357737867468682, 0.21933653760695598`], 
             UndirectedEdge[123, 177] -> 
             RGBColor[
              0.8624203886013166, 0.42382732988572314`, 0.43614163945511913`],
              UndirectedEdge[29, 113] -> 
             RGBColor[
              0.9203696751962868, 0.935153629546075, 0.7908869459378458], 
             UndirectedEdge[96, 174] -> 
             RGBColor[
              0.8522904764943066, 0.8612189045827883, 0.6702279309544035], 
             UndirectedEdge[74, 158] -> 
             RGBColor[
              0.9048749942804655, 0.9123878501825945, 0.6901396569612839], 
             UndirectedEdge[46, 121] -> 
             RGBColor[
              0.8966597334068412, 0.6092147441038773, 0.2466945574764149], 
             UndirectedEdge[32, 165] -> 
             RGBColor[
              0.6894088216479326, 0.751695440726869, 0.9185890861263786], 
             UndirectedEdge[32, 148] -> 
             RGBColor[
              0.9890163589697696, 0.9874024164225933, 0.6627911503853325], 
             UndirectedEdge[27, 190] -> 
             RGBColor[
              0.7619044289099988, 0.8139945909378664, 0.9762988817564535], 
             UndirectedEdge[100, 123] -> 
             RGBColor[
              0.8696108097387505, 0.4291899341967873, 0.42397013203162737`], 
             UndirectedEdge[45, 172] -> 
             RGBColor[
              0.9894644649203377, 0.9887528132750925, 0.7400548751213583], 
             UndirectedEdge[85, 99] -> 
             RGBColor[
              0.7264113561617327, 0.7831398195718614, 0.911705850360981], 
             UndirectedEdge[106, 112] -> 
             RGBColor[
              0.9937781104670035, 0.9913171421587764, 0.7253025761296414], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.9566703194855146, 0.8549864810892864, 0.34780463968753605`], 
             UndirectedEdge[43, 197] -> 
             RGBColor[
              0.9673224470538592, 0.9008155283755445, 0.33077053776312226`], 
             UndirectedEdge[26, 164] -> 
             RGBColor[
              0.9900571624386434, 0.9883282754046787, 0.6815570550715295], 
             UndirectedEdge[100, 130] -> 
             RGBColor[
              0.9769225921324721, 0.9821294394087465, 0.9158852892983885], 
             UndirectedEdge[46, 196] -> 
             RGBColor[
              0.9803471849718173, 0.9449388728180756, 0.41469228620059606`], 
             UndirectedEdge[156, 181] -> 
             RGBColor[
              0.9286232122428659, 0.7925509511661228, 0.5906575028172448], 
             UndirectedEdge[62, 96] -> 
             RGBColor[
              0.801331282830677, 0.8451745838827889, 0.9807136600934366], 
             UndirectedEdge[54, 58] -> 
             RGBColor[
              0.9064663240049095, 0.9141663091467752, 0.6910410922022262], 
             UndirectedEdge[179, 183] -> 
             RGBColor[
              0.7378365389214501, 0.5148877423156887, 0.456420547839091], 
             UndirectedEdge[65, 198] -> 
             RGBColor[
              0.9061076948358283, 0.6414534177987606, 0.32181872524775595`], 
             UndirectedEdge[4, 80] -> 
             RGBColor[
              0.8977872843697169, 0.6246008719794558, 0.2362085121562703], 
             UndirectedEdge[159, 197] -> 
             RGBColor[
              0.9503580359000361, 0.907355219095999, 0.6283062448732798], 
             UndirectedEdge[78, 136] -> 
             RGBColor[
              0.9735909792967565, 0.95835747774585, 0.6559377582514478], 
             UndirectedEdge[153, 188] -> 
             RGBColor[
              0.884516498308949, 0.48517063101779057`, 0.2733289473828808], 
             UndirectedEdge[35, 174] -> 
             RGBColor[
              0.9764626779950379, 0.9584547925055702, 0.6467368610798602], 
             UndirectedEdge[82, 130] -> 
             RGBColor[
              0.9515628861106711, 0.9627559365227012, 0.9428546107304533], 
             UndirectedEdge[124, 176] -> 
             RGBColor[
              0.9829630707302028, 0.9669826133946124, 0.6344147505471742], 
             UndirectedEdge[6, 186] -> 
             RGBColor[
              0.9332797116573119, 0.766532955843635, 0.539331818255768], 
             UndirectedEdge[1, 144] -> 
             RGBColor[
              0.9822701963951539, 0.9675227187425386, 0.6469613405632525], 
             UndirectedEdge[43, 67] -> 
             RGBColor[
              0.9463258197607055, 0.9396845539554521, 0.6856268277640519], 
             UndirectedEdge[24, 119] -> 
             RGBColor[
              0.9692254134212599, 0.9150020615672867, 0.562385533035953], 
             UndirectedEdge[93, 139] -> 
             RGBColor[
              0.9303566868268962, 0.9368506461208626, 0.698667058078079], 
             UndirectedEdge[38, 146] -> 
             RGBColor[
              0.9711557960107928, 0.9778535666464263, 0.9267662686555375], 
             UndirectedEdge[110, 127] -> 
             RGBColor[
              0.7730035075077604, 0.6210301823282218, 0.5900719010318215], 
             UndirectedEdge[41, 81] -> 
             RGBColor[
              0.9813863478260092, 0.9505188459622995, 0.5512548890003509], 
             UndirectedEdge[85, 194] -> 
             RGBColor[
              0.9072782524317409, 0.6574635009919372, 0.43160432916535796`], 
             UndirectedEdge[52, 70] -> 
             RGBColor[
              0.9187526503692236, 0.9275168307193936, 0.6974409876142291], 
             UndirectedEdge[149, 170] -> 
             RGBColor[
              0.9868202436226812, 0.9875090321775537, 0.7977350813420858], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.8887069841665735, 0.9135717044389331, 0.9711093471262202], 
             UndirectedEdge[92, 155] -> 
             RGBColor[
              0.9408497651868517, 0.9517633004759666, 0.8154896751245466], 
             UndirectedEdge[57, 141] -> 
             RGBColor[
              0.9615529833308252, 0.9565961423578413, 0.6916343838415293], 
             UndirectedEdge[149, 159] -> 
             RGBColor[
              0.9628437595058424, 0.9718095171939929, 0.9477800026437508], 
             UndirectedEdge[142, 167] -> 
             RGBColor[
              0.577505249808046, 0.6181900848615252, 0.6475451707854933], 
             UndirectedEdge[117, 173] -> 
             RGBColor[
              0.9185309532888715, 0.710853301215586, 0.2531068241502018], 
             UndirectedEdge[99, 179] -> 
             RGBColor[
              0.4757767989229145, 0.5852960647229836, 0.951874038920503], 
             UndirectedEdge[5, 11] -> 
             RGBColor[
              0.730195047169144, 0.7837142263406307, 0.7770198170321162], 
             UndirectedEdge[29, 188] -> 
             RGBColor[
              0.8357771109443237, 0.44963302142172856`, 0.4461995477377949], 
             UndirectedEdge[46, 178] -> 
             RGBColor[
              0.8696008404975492, 0.4071778434225197, 0.22101590277668548`], 
             UndirectedEdge[101, 137] -> 
             RGBColor[
              0.9149802066672832, 0.6923570321502164, 0.2500212331303377], 
             UndirectedEdge[3, 20] -> 
             RGBColor[
              0.9613958924560203, 0.8761137550308755, 0.33227734118602587`], 
             UndirectedEdge[186, 199] -> 
             RGBColor[
              0.986572149715933, 0.988715253074596, 0.8721977595769761], 
             UndirectedEdge[156, 179] -> 
             RGBColor[
              0.6898374244347082, 0.6031494562063333, 0.5931008237286202], 
             UndirectedEdge[67, 87] -> 
             RGBColor[
              0.9162897772884855, 0.8279375483525901, 0.6232536629312775], 
             UndirectedEdge[3, 10] -> 
             RGBColor[
              0.879687561696427, 0.826067777915412, 0.6258792652697942], 
             UndirectedEdge[55, 185] -> 
             RGBColor[
              0.8757875191119524, 0.5288619594968922, 0.21806640003154595`], 
             UndirectedEdge[5, 28] -> 
             RGBColor[
              0.9482429655688756, 0.8196729835721928, 0.42157369676342105`], 
             UndirectedEdge[37, 170] -> 
             RGBColor[
              0.9792530569679094, 0.9402636680049239, 0.4941526798281607], 
             UndirectedEdge[49, 154] -> 
             RGBColor[
              0.877983301986148, 0.4353964596018164, 0.25846061523904507`], 
             UndirectedEdge[24, 89] -> 
             RGBColor[
              0.9480200023762761, 0.8998460709996248, 0.6277907976797183], 
             UndirectedEdge[73, 115] -> 
             RGBColor[
              0.9834116648355729, 0.9865201652619366, 0.8848021764447349], 
             UndirectedEdge[153, 174] -> 
             RGBColor[
              0.9851819239292503, 0.9614434009464836, 0.41682335298794515`], 
             UndirectedEdge[119, 183] -> 
             RGBColor[
              0.905456806637561, 0.6470029802715624, 0.420848955322185], 
             UndirectedEdge[4, 168] -> 
             RGBColor[
              0.8384848541214918, 0.763165821464596, 0.6149768460973462], 
             UndirectedEdge[144, 181] -> 
             RGBColor[
              0.9719783242555233, 0.959847057352196, 0.6643827955454917], 
             UndirectedEdge[53, 123] -> 
             RGBColor[
              0.8779153122172043, 0.43331970023980904`, 0.28862016668250734`],
              UndirectedEdge[110, 162] -> 
             RGBColor[
              0.8972153011644426, 0.6197782700599115, 0.2356161197938727], 
             UndirectedEdge[127, 176] -> 
             RGBColor[
              0.8317202041929472, 0.8683053075456222, 0.9294147660890636], 
             UndirectedEdge[9, 102] -> 
             RGBColor[
              0.944635388202828, 0.8040753663251121, 0.3833280888467955], 
             UndirectedEdge[27, 195] -> 
             RGBColor[
              0.9206435045936768, 0.8058005076988592, 0.6170075342125952], 
             UndirectedEdge[60, 130] -> 
             RGBColor[
              0.9716532719113089, 0.9291346753835522, 0.5925703551587451], 
             UndirectedEdge[89, 122] -> 
             RGBColor[
              0.9704828423706902, 0.9756197461020494, 0.8488066314877871], 
             UndirectedEdge[5, 106] -> 
             RGBColor[
              0.9934232389336013, 0.9905581078318448, 0.6866769997320502], 
             UndirectedEdge[83, 199] -> 
             RGBColor[
              0.9031078377955579, 0.6397130009978687, 0.43312809341537195`], 
             UndirectedEdge[118, 125] -> 
             RGBColor[
              0.9431874549391717, 0.9290981124893161, 0.6734348730628603], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.9442507158217576, 0.8054694008016463, 0.502597544955985], 
             UndirectedEdge[5, 112] -> 
             RGBColor[
              0.9944890077466606, 0.9906208697539226, 0.6415406870049191], 
             UndirectedEdge[109, 146] -> 
             RGBColor[
              0.9901656002162385, 0.9901355937496206, 0.8078733990737995], 
             UndirectedEdge[164, 184] -> 
             RGBColor[
              0.8842212339373213, 0.49865886514537505`, 0.40803497812909234`],
              UndirectedEdge[51, 164] -> 
             RGBColor[
              0.987415417235683, 0.979824317067163, 0.6366631966204053], 
             UndirectedEdge[45, 168] -> 
             RGBColor[
              0.8761253502270225, 0.9002813748042051, 0.7791168150750704], 
             UndirectedEdge[148, 165] -> 
             RGBColor[
              0.6929810395844411, 0.7508490646536521, 0.6904884538699652], 
             UndirectedEdge[166, 184] -> 
             RGBColor[
              0.8742995252224924, 0.4915648982895929, 0.43851645605281486`], 
             UndirectedEdge[21, 132] -> 
             RGBColor[
              0.9747638849241493, 0.9246689614927337, 0.48381780264330154`], 
             UndirectedEdge[96, 157] -> 
             RGBColor[
              0.7742636819824911, 0.8235916136968975, 0.9781319281610041], 
             UndirectedEdge[42, 102] -> 
             RGBColor[
              0.9882930061445065, 0.9715676882696941, 0.46038195122270037`], 
             UndirectedEdge[117, 120] -> 
             RGBColor[
              0.9694297448182925, 0.9055777840410194, 0.3578088317699377], 
             UndirectedEdge[25, 129] -> 
             RGBColor[
              0.9678391799428285, 0.9755350935766469, 0.939324058858247], 
             UndirectedEdge[57, 90] -> 
             RGBColor[
              0.9631397130421584, 0.961948554256022, 0.6977985291412959], 
             UndirectedEdge[51, 184] -> 
             RGBColor[
              0.8845305615328122, 0.4926270141902429, 0.25520232745903426`], 
             UndirectedEdge[95, 103] -> 
             RGBColor[
              0.9518377181841201, 0.9627273035361945, 0.9321215080773202], 
             UndirectedEdge[47, 105] -> 
             RGBColor[
              0.9610877033322991, 0.9704998533750424, 0.9507525476927576], 
             UndirectedEdge[127, 177] -> 
             RGBColor[
              0.8124791644066982, 0.8541693989210593, 0.9715694093151459], 
             UndirectedEdge[73, 153] -> 
             RGBColor[
              0.985864043214602, 0.9854638161913634, 0.6936585679075475], 
             UndirectedEdge[137, 199] -> 
             RGBColor[
              0.930602129106769, 0.7579560839778292, 0.5522024789281642], 
             UndirectedEdge[138, 185] -> 
             RGBColor[
              0.9378842502924705, 0.7727514026511668, 0.40776204060560967`], 
             UndirectedEdge[88, 136] -> 
             RGBColor[
              0.8757317758367945, 0.43770719915993295`, 0.23814977500800494`],
              UndirectedEdge[55, 76] -> 
             RGBColor[
              0.9042098154235785, 0.7277939604475556, 0.6009845324387384], 
             UndirectedEdge[135, 176] -> 
             RGBColor[
              0.9692164469959692, 0.9197218093622939, 0.5856479644603585], 
             UndirectedEdge[69, 123] -> 
             RGBColor[
              0.8749976177702153, 0.42388082948693495`, 0.24300045061516107`],
              UndirectedEdge[2, 40] -> 
             RGBColor[
              0.9687282039015703, 0.906175030172407, 0.3330154066511168], 
             UndirectedEdge[105, 174] -> 
             RGBColor[
              0.9736863345645002, 0.9563842001209203, 0.6514364863214235], 
             UndirectedEdge[89, 138] -> 
             RGBColor[
              0.9698930299754835, 0.9743581970278832, 0.7846091921697185], 
             UndirectedEdge[37, 128] -> 
             RGBColor[
              0.973723457086693, 0.9230251921070497, 0.35242102200090714`], 
             UndirectedEdge[88, 153] -> 
             RGBColor[
              0.8803464127585559, 0.4531175261343293, 0.26933566875038645`], 
             UndirectedEdge[113, 197] -> 
             RGBColor[
              0.9739751022008192, 0.9222859757137323, 0.43914091236360664`], 
             UndirectedEdge[31, 178] -> 
             RGBColor[
              0.8543233129380035, 0.3488810238969123, 0.19688289012854032`], 
             UndirectedEdge[82, 177] -> 
             RGBColor[
              0.9324241094390147, 0.9486623163240646, 0.9833144894992805], 
             UndirectedEdge[87, 108] -> 
             RGBColor[
              0.9351772555661363, 0.7807064497584584, 0.2667003021243838], 
             UndirectedEdge[64, 86] -> 
             RGBColor[
              0.9666752601041548, 0.897304038718879, 0.3351745440263153], 
             UndirectedEdge[116, 157] -> 
             RGBColor[
              0.8966666464268438, 0.919508007519892, 0.9576357151319828], 
             UndirectedEdge[120, 168] -> 
             RGBColor[
              0.8754746108094796, 0.8988895089899284, 0.7082878453736947], 
             UndirectedEdge[18, 54] -> 
             RGBColor[
              0.9847226872447405, 0.9601281781722011, 0.39515095413459655`], 
             UndirectedEdge[161, 176] -> 
             RGBColor[
              0.9774031541990122, 0.9482277094044236, 0.6128155247256348], 
             UndirectedEdge[168, 172] -> 
             RGBColor[
              0.8716506973426574, 0.8995894773088214, 0.937483129846282], 
             UndirectedEdge[142, 157] -> 
             RGBColor[
              0.5001776425918343, 0.5829213169006902, 0.9581653786050734], 
             UndirectedEdge[121, 171] -> 
             RGBColor[
              0.9058232002868428, 0.6391038518436263, 0.3691468869863834], 
             UndirectedEdge[47, 94] -> 
             RGBColor[
              0.9258452519508613, 0.800020998686487, 0.6017140174903852], 
             UndirectedEdge[70, 93] -> 
             RGBColor[
              0.9303252132018721, 0.9367444781932978, 0.6985447889881559], 
             UndirectedEdge[32, 163] -> 
             RGBColor[
              0.9489851433208493, 0.8395755696534668, 0.5696832350021398], 
             UndirectedEdge[35, 142] -> 
             RGBColor[
              0.5771852408913881, 0.6433001847189892, 0.9299764796813874], 
             UndirectedEdge[12, 193] -> 
             RGBColor[
              0.9691297867045517, 0.9063371386593422, 0.5217627464871927], 
             UndirectedEdge[35, 94] -> 
             RGBColor[
              0.9374246869708005, 0.8086569223647729, 0.5821130544019655], 
             UndirectedEdge[116, 174] -> 
             RGBColor[
              0.9746934409386594, 0.9571352984057829, 0.6497317179253821], 
             UndirectedEdge[112, 140] -> 
             RGBColor[
              0.9900577451571768, 0.9897786754941358, 0.7869586573102594], 
             UndirectedEdge[86, 176] -> 
             RGBColor[
              0.9847240926817412, 0.9729229539447687, 0.6412559882878096], 
             UndirectedEdge[61, 73] -> 
             RGBColor[
              0.9582172273568068, 0.9683590570924934, 0.955611514779229], 
             UndirectedEdge[33, 66] -> 
             RGBColor[
              0.8777244784188954, 0.44447963511017885`, 0.391588245257523], 
             UndirectedEdge[48, 106] -> 
             RGBColor[
              0.9906878082630617, 0.9904171836514339, 0.8039906464681579], 
             UndirectedEdge[86, 199] -> 
             RGBColor[
              0.984836161848418, 0.9729692974252357, 0.6393987121702696], 
             UndirectedEdge[10, 59] -> 
             RGBColor[
              0.9048365722691172, 0.9249277976491139, 0.9136531946205988], 
             UndirectedEdge[1, 113] -> 
             RGBColor[
              0.9887642492258122, 0.9884581632262459, 0.7547155751144388], 
             UndirectedEdge[125, 128] -> 
             RGBColor[
              0.9478082928425047, 0.9446852837615933, 0.6913859557452908], 
             UndirectedEdge[53, 165] -> 
             RGBColor[
              0.693428228432466, 0.7518055563818494, 0.7391622002478146], 
             UndirectedEdge[87, 143] -> 
             RGBColor[
              0.9562227378251903, 0.8570784598228637, 0.520740832033268], 
             UndirectedEdge[61, 105] -> 
             RGBColor[
              0.9537395684286556, 0.9650196263953716, 0.9631910233841043], 
             UndirectedEdge[29, 47] -> 
             RGBColor[
              0.8994742116501115, 0.9222526398065127, 0.9754453148916503], 
             UndirectedEdge[24, 27] -> 
             RGBColor[
              0.9435174487154405, 0.8964880738516285, 0.6354124465734421], 
             UndirectedEdge[98, 117] -> 
             RGBColor[
              0.9673391979206669, 0.8986089733302381, 0.34262166485188283`], 
             UndirectedEdge[1, 88] -> 
             RGBColor[
              0.877203408080281, 0.45311627232504803`, 0.41809202188969574`], 
             UndirectedEdge[190, 195] -> 
             RGBColor[
              0.7458054200461823, 0.6674518480087236, 0.6013438120606867], 
             UndirectedEdge[4, 173] -> 
             RGBColor[
              0.904749090752208, 0.6562128087911567, 0.24201761405131078`], 
             UndirectedEdge[81, 164] -> 
             RGBColor[
              0.9899814547921946, 0.9901250883387741, 0.815696751464613], 
             UndirectedEdge[82, 123] -> 
             RGBColor[
              0.8527043390575498, 0.4162742656060905, 0.4419496796530038], 
             UndirectedEdge[43, 87] -> 
             RGBColor[
              0.9507341860691081, 0.835048601281293, 0.31742323359826186`], 
             UndirectedEdge[38, 171] -> 
             RGBColor[
              0.9760859056231547, 0.9796365170570069, 0.8264693340745356], 
             UndirectedEdge[46, 85] -> 
             RGBColor[
              0.9770309325533899, 0.9453642699258522, 0.6002561252437815], 
             UndirectedEdge[64, 69] -> 
             RGBColor[
              0.9670562347166756, 0.8985891555440044, 0.33665455845493975`], 
             UndirectedEdge[60, 82] -> 
             RGBColor[
              0.937940420924002, 0.9037114587654664, 0.6417422942243991], 
             UndirectedEdge[77, 189] -> 
             RGBColor[
              0.9753619071978584, 0.9279823255186758, 0.40723296939529197`], 
             UndirectedEdge[101, 187] -> 
             RGBColor[
              0.9704568588883073, 0.9115618928824842, 0.3420448084008173], 
             UndirectedEdge[64, 161] -> 
             RGBColor[
              0.9593543216214258, 0.8726087941785339, 0.3067340804641405], 
             UndirectedEdge[7, 160] -> 
             RGBColor[
              0.8760521253377662, 0.4189329288740612, 0.28810980429106], 
             UndirectedEdge[16, 83] -> 
             RGBColor[
              0.8982164467324011, 0.6149076285421182, 0.25158800904452483`], 
             UndirectedEdge[13, 124] -> 
             RGBColor[
              0.9776141747581206, 0.9361494963967278, 0.36753572545402247`], 
             UndirectedEdge[46, 171] -> 
             RGBColor[
              0.9812403112283465, 0.9468491795718755, 0.5119035674874586], 
             UndirectedEdge[1, 197] -> 
             RGBColor[
              0.9686638125913832, 0.9210076373794475, 0.5973193398460404], 
             UndirectedEdge[26, 80] -> 
             RGBColor[
              0.9350396710903164, 0.7608862985885748, 0.3581051697177046], 
             UndirectedEdge[23, 43] -> 
             RGBColor[
              0.9140546802630503, 0.9139524232967678, 0.6825487776699792], 
             UndirectedEdge[13, 86] -> 
             RGBColor[
              0.979375196709659, 0.9420898369468841, 0.37437696319465785`], 
             UndirectedEdge[31, 146] -> 
             RGBColor[
              0.9533939102766662, 0.8576209998728836, 0.5760009830962427], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.6131981737585486, 0.2579074355778555, 0.42895429965656595`], 
             UndirectedEdge[124, 127] -> 
             RGBColor[
              0.8292030115959871, 0.8470241909475952, 0.6735363738859489], 
             UndirectedEdge[60, 163] -> 
             RGBColor[
              0.9352784761665387, 0.7804962722187203, 0.2699663630076123], 
             UndirectedEdge[4, 184] -> 
             RGBColor[
              0.8614568005210528, 0.40743936867584063`, 0.2038671280521609], 
             UndirectedEdge[144, 192] -> 
             RGBColor[
              0.9881527485680737, 0.9700229299366102, 0.5509613176921461], 
             UndirectedEdge[38, 192] -> 
             RGBColor[
              0.976202181830088, 0.9798852201063095, 0.8391252816256598], 
             UndirectedEdge[49, 108] -> 
             RGBColor[
              0.9711494314547626, 0.9123913351693137, 0.35945487304643237`], 
             UndirectedEdge[83, 165] -> 
             RGBColor[
              0.7056642046629205, 0.48197489166598684`, 0.4530306931139727], 
             UndirectedEdge[183, 192] -> 
             RGBColor[
              0.9078100136685888, 0.6479393206784911, 0.3791773486626103], 
             UndirectedEdge[79, 159] -> 
             RGBColor[
              0.8397128801379277, 0.8754473603204491, 0.9744243163692017], 
             UndirectedEdge[81, 166] -> 
             RGBColor[
              0.9750988917199513, 0.9794841380551008, 0.8614189683501967], 
             UndirectedEdge[118, 119] -> 
             RGBColor[
              0.9813259708836963, 0.9574969750056006, 0.6006606329310185], 
             UndirectedEdge[47, 153] -> 
             RGBColor[
              0.9725832926970492, 0.9755590542006056, 0.7161394143592793], 
             UndirectedEdge[74, 184] -> 
             RGBColor[
              0.8836503192404744, 0.4896577502474688, 0.251782752373111], 
             UndirectedEdge[149, 190] -> 
             RGBColor[
              0.7829562285702536, 0.8296949886553262, 0.9406636761203477], 
             UndirectedEdge[55, 139] -> 
             RGBColor[
              0.929150760992566, 0.7373008102717913, 0.31138204209084036`], 
             UndirectedEdge[22, 138] -> 
             RGBColor[
              0.9843358841178013, 0.9578757765328518, 0.47422739051779284`], 
             UndirectedEdge[113, 144] -> 
             RGBColor[
              0.98758148600459, 0.9688010570768235, 0.4887829130808188], 
             UndirectedEdge[80, 172] -> 
             RGBColor[
              0.9309531275908826, 0.7610245278236811, 0.5587147959052062], 
             UndirectedEdge[8, 156] -> 
             RGBColor[
              0.8737301719773939, 0.5195200266644936, 0.21634969915227745`], 
             UndirectedEdge[22, 118] -> 
             RGBColor[
              0.9745634139810303, 0.9258585639429073, 0.3556840959228581], 
             UndirectedEdge[100, 163] -> 
             RGBColor[
              0.9405477963877019, 0.8334910362439146, 0.5932812971472557], 
             UndirectedEdge[12, 154] -> 
             RGBColor[
              0.862247329218389, 0.38029710792674776`, 0.20325873962830626`], 
             UndirectedEdge[67, 129] -> 
             RGBColor[
              0.9443231979252076, 0.9573827226518321, 0.9578361282179076], 
             UndirectedEdge[49, 129] -> 
             RGBColor[
              0.9847037401222367, 0.9844316553885284, 0.6823871049741662], 
             UndirectedEdge[127, 175] -> 
             RGBColor[
              0.799499671092715, 0.5550476015945545, 0.4595906161576804], 
             UndirectedEdge[30, 198] -> 
             RGBColor[
              0.9045095038500444, 0.6417228682426049, 0.41593103624767364`], 
             UndirectedEdge[5, 140] -> 
             RGBColor[
              0.9897028736237745, 0.9890196411672041, 0.748333080912668], 
             UndirectedEdge[147, 156] -> 
             RGBColor[
              0.9232981433301277, 0.7885795234900028, 0.5996714554861047], 
             UndirectedEdge[122, 159] -> 
             RGBColor[
              0.9710297350979489, 0.9760276178025842, 0.8478808847530055], 
             UndirectedEdge[82, 110] -> 
             RGBColor[
              0.8929484525400768, 0.7155230997312272, 0.601816981215956], 
             UndirectedEdge[83, 176] -> 
             RGBColor[
              0.9030331250177734, 0.639682105344224, 0.434366277493732], 
             UndirectedEdge[10, 77] -> 
             RGBColor[
              0.8893629707921094, 0.8640328716163304, 0.6357198226487853], 
             UndirectedEdge[104, 130] -> 
             RGBColor[
              0.9493992142280273, 0.8415162358850221, 0.5714796015647139], 
             UndirectedEdge[30, 66] -> 
             RGBColor[
              0.8777806284058933, 0.44450285457279126`, 0.39065769466146094`],
              UndirectedEdge[85, 132] -> 
             RGBColor[
              0.9706018422802285, 0.9232852988306889, 0.5773225952537422], 
             UndirectedEdge[24, 195] -> 
             RGBColor[
              0.9274184398516241, 0.7499453309224857, 0.26045737687767523`], 
             UndirectedEdge[50, 123] -> 
             RGBColor[
              0.874864593208079, 0.4234321064031964, 0.24248367531084192`], 
             UndirectedEdge[42, 153] -> 
             RGBColor[
              0.9879931497620646, 0.9709263257877814, 0.4277444344929759], 
             UndirectedEdge[127, 161] -> 
             RGBColor[
              0.8236430950647964, 0.8282692869574063, 0.6519371480644096], 
             UndirectedEdge[7, 18] -> 
             RGBColor[
              0.9886647070670569, 0.9727988791169949, 0.46375139115590847`], 
             UndirectedEdge[65, 66] -> 
             RGBColor[
              0.8793788193916773, 0.44423340412894696`, 0.29654538366154326`],
              UndirectedEdge[150, 152] -> 
             RGBColor[
              0.973914068990047, 0.9323241525161835, 0.5706866658801262], 
             UndirectedEdge[25, 87] -> 
             RGBColor[
              0.9398057593061064, 0.846089919277405, 0.6047415935716168], 
             UndirectedEdge[69, 82] -> 
             RGBColor[
              0.9512899531923626, 0.9487425657258823, 0.6936027062393433], 
             UndirectedEdge[1, 159] -> 
             RGBColor[
              0.9651471829250291, 0.9735274066085127, 0.9438809076241119], 
             UndirectedEdge[23, 131] -> 
             RGBColor[
              0.9095417651305276, 0.9297784193624548, 0.9590073498863487], 
             UndirectedEdge[126, 160] -> 
             RGBColor[
              0.8528446532729839, 0.3347446237966087, 0.1953530355867179], 
             UndirectedEdge[67, 131] -> 
             RGBColor[
              0.9418129046281829, 0.9555105500211392, 0.9620853999804213], 
             UndirectedEdge[142, 174] -> 
             RGBColor[
              0.5782044371036499, 0.6205486077865812, 0.6502613813984728], 
             UndirectedEdge[22, 122] -> 
             RGBColor[
              0.9849256965130079, 0.9591373256070181, 0.5384248298358615], 
             UndirectedEdge[32, 176] -> 
             RGBColor[
              0.985462202180212, 0.9882562612442247, 0.8905924626960176], 
             UndirectedEdge[47, 160] -> 
             RGBColor[
              0.8623075372476325, 0.41072950736046887`, 0.4313632951798714], 
             UndirectedEdge[79, 125] -> 
             RGBColor[
              0.822232882511128, 0.8617966166712917, 0.9827190385920599], 
             UndirectedEdge[47, 111] -> 
             RGBColor[
              0.91283165051788, 0.7409292739831543, 0.5908551494621446], 
             UndirectedEdge[3, 186] -> 
             RGBColor[
              0.9626933679902675, 0.8903805056125309, 0.5633728509840923], 
             UndirectedEdge[105, 160] -> 
             RGBColor[
              0.8681762649739002, 0.41510639488955947`, 0.4214290699486337], 
             UndirectedEdge[9, 189] -> 
             RGBColor[
              0.944607623992369, 0.8040159814863326, 0.3803061258791788], 
             UndirectedEdge[64, 175] -> 
             RGBColor[
              0.8899738221304679, 0.5846072730753062, 0.22945523775750104`], 
             UndirectedEdge[100, 165] -> 
             RGBColor[
              0.6809714747147853, 0.7456109073173169, 0.9421871482714945], 
             UndirectedEdge[101, 161] -> 
             RGBColor[
              0.9618933009262031, 0.8826750010572778, 0.3087770028102684], 
             UndirectedEdge[123, 187] -> 
             RGBColor[
              0.8755720476814517, 0.4258185164600921, 0.24523200234832754`], 
             UndirectedEdge[90, 198] -> 
             RGBColor[
              0.9041211650903981, 0.6352302231603781, 0.2734696525076054], 
             UndirectedEdge[146, 171] -> 
             RGBColor[
              0.9900554019359873, 0.9898998907709184, 0.7958789963334133], 
             UndirectedEdge[62, 157] -> 
             RGBColor[
              0.8484958860318547, 0.8820316039872719, 0.9854114891425795], 
             UndirectedEdge[2, 164] -> 
             RGBColor[
              0.9749571673736634, 0.9377997149463962, 0.5882652484495364], 
             UndirectedEdge[94, 142] -> 
             RGBColor[
              0.5391664460794124, 0.4707507376457838, 0.5856375747205782], 
             UndirectedEdge[12, 175] -> 
             RGBColor[
              0.8886578150967591, 0.5793897437199982, 0.22839634760752364`], 
             UndirectedEdge[23, 64] -> 
             RGBColor[
              0.8983608650783814, 0.8590675696251203, 0.6317157055681112], 
             UndirectedEdge[73, 160] -> 
             RGBColor[
              0.871161370926001, 0.41733268202097396`, 0.4163760642120502], 
             UndirectedEdge[47, 142] -> 
             RGBColor[
              0.5656058058714488, 0.6346642610407032, 0.9495774427698069], 
             UndirectedEdge[31, 120] -> 
             RGBColor[
              0.957150083599662, 0.8568930192636761, 0.3479283281127328], 
             UndirectedEdge[9, 20] -> 
             RGBColor[
              0.9403170183462131, 0.7901125046994508, 0.3151910550489039], 
             UndirectedEdge[174, 188] -> 
             RGBColor[
              0.8793831318276485, 0.46801050743557626`, 0.24012788725554784`],
              UndirectedEdge[45, 173] -> 
             RGBColor[
              0.9423895868577387, 0.7933283621307659, 0.40615758302903504`], 
             UndirectedEdge[139, 191] -> 
             RGBColor[
              0.9513334740223546, 0.8351516116647395, 0.32974308370067384`], 
             UndirectedEdge[24, 170] -> 
             RGBColor[
              0.9725433792203735, 0.9159534576837203, 0.47682012964327175`], 
             UndirectedEdge[118, 195] -> 
             RGBColor[
              0.9395189973140605, 0.7924402443607996, 0.29873247677274073`], 
             UndirectedEdge[124, 137] -> 
             RGBColor[
              0.9279728673431321, 0.7366286238993351, 0.2981813628425895], 
             UndirectedEdge[28, 63] -> 
             RGBColor[
              0.9486686532364209, 0.8205834864494469, 0.4679071723359629], 
             UndirectedEdge[7, 94] -> 
             RGBColor[
              0.9464621340860617, 0.8123261309568754, 0.38683378115716816`], 
             UndirectedEdge[37, 190] -> 
             RGBColor[
              0.7753890419154819, 0.7824496244826964, 0.6370812746064225], 
             UndirectedEdge[31, 40] -> 
             RGBColor[
              0.9480780135639838, 0.8263738916686563, 0.30561926215336166`], 
             UndirectedEdge[18, 73] -> 
             RGBColor[
              0.981328575449409, 0.970398508837364, 0.6561507810373937], 
             UndirectedEdge[170, 195] -> 
             RGBColor[
              0.9496694350986099, 0.825265891530951, 0.45841521728242485`], 
             UndirectedEdge[62, 191] -> 
             RGBColor[
              0.894886944875192, 0.8005972198911411, 0.6189115506825371], 
             UndirectedEdge[152, 194] -> 
             RGBColor[
              0.8982741080095028, 0.6196356166237702, 0.23996747129556786`], 
             UndirectedEdge[24, 37] -> 
             RGBColor[
              0.9570020617209236, 0.8649431073964585, 0.2961948394234111], 
             UndirectedEdge[90, 177] -> 
             RGBColor[
              0.9673514779012955, 0.9650896815918343, 0.6906691098389817], 
             UndirectedEdge[94, 188] -> 
             RGBColor[
              0.8533578044781569, 0.3681452606750447, 0.19704534947028476`], 
             UndirectedEdge[103, 133] -> 
             RGBColor[
              0.9545629171629446, 0.8596963053956186, 0.564417299622416], 
             UndirectedEdge[38, 179] -> 
             RGBColor[
              0.7212419697093799, 0.7803078525621057, 0.9549900803903806], 
             UndirectedEdge[54, 116] -> 
             RGBColor[
              0.9787696720193426, 0.9708853829854998, 0.6655671059421873], 
             UndirectedEdge[4, 198] -> 
             RGBColor[
              0.8811056162723031, 0.5502389410440791, 0.22236059648066808`], 
             UndirectedEdge[31, 38] -> 
             RGBColor[
              0.9394244139638337, 0.8473576261589721, 0.606591320837365], 
             UndirectedEdge[35, 47] -> 
             RGBColor[
              0.963864046762837, 0.9725704457596924, 0.9460529224511943], 
             UndirectedEdge[132, 151] -> 
             RGBColor[
              0.9738322313308372, 0.9226762486612665, 0.3824130585107779], 
             UndirectedEdge[124, 135] -> 
             RGBColor[
              0.9666992543990092, 0.898440692764267, 0.32976957225724385`], 
             UndirectedEdge[32, 127] -> 
             RGBColor[
              0.8317021430459962, 0.8682978387972076, 0.9297140860347921], 
             UndirectedEdge[187, 199] -> 
             RGBColor[
              0.9860787813277931, 0.9771609447100971, 0.6442260541986438], 
             UndirectedEdge[2, 51] -> 
             RGBColor[
              0.9754211587668997, 0.928751938513698, 0.35901627244444934`], 
             UndirectedEdge[40, 117] -> 
             RGBColor[
              0.9603576747826144, 0.8750586564459994, 0.3154997658105666], 
             UndirectedEdge[9, 17] -> 
             RGBColor[
              0.9089989713898554, 0.6744877377911358, 0.2455109109492386], 
             UndirectedEdge[33, 57] -> 
             RGBColor[
              0.9636379962011312, 0.9716526926854434, 0.9128864306454914], 
             UndirectedEdge[124, 175] -> 
             RGBColor[
              0.9003282487842188, 0.620832472160548, 0.2629239391297541], 
             UndirectedEdge[8, 147] -> 
             RGBColor[
              0.8930107947650677, 0.6363907755105155, 0.4604119407609213], 
             UndirectedEdge[108, 110] -> 
             RGBColor[
              0.9088516187460869, 0.6659123916981622, 0.2449789740595424], 
             UndirectedEdge[68, 107] -> 
             RGBColor[
              0.9886509250125763, 0.9797865989491151, 0.6123955091131329], 
             UndirectedEdge[1, 138] -> 
             RGBColor[
              0.9887456993940893, 0.9884184870118664, 0.7526965404076975], 
             UndirectedEdge[94, 160] -> 
             RGBColor[
              0.844681297386275, 0.3014538250971892, 0.18873671648038548`], 
             UndirectedEdge[138, 142] -> 
             RGBColor[
              0.5864827195859013, 0.6475255745658859, 0.7630000391092613], 
             UndirectedEdge[6, 175] -> 
             RGBColor[
              0.866552797920896, 0.4869292473922367, 0.21036072230599842`], 
             UndirectedEdge[34, 104] -> 
             RGBColor[
              0.8660155902290179, 0.44885119485704206`, 0.20849449912277498`],
              UndirectedEdge[15, 106] -> 
             RGBColor[
              0.9743490124017111, 0.9789745776565922, 0.8649139129495329], 
             UndirectedEdge[61, 94] -> 
             RGBColor[
              0.9184971170472177, 0.7945407717068163, 0.6141524931817319], 
             UndirectedEdge[144, 159] -> 
             RGBColor[
              0.9639644197038069, 0.9538703004590903, 0.6779482455904919], 
             UndirectedEdge[83, 86] -> 
             RGBColor[
              0.9025290112541589, 0.6294549213123102, 0.26834150785207916`], 
             UndirectedEdge[137, 176] -> 
             RGBColor[
              0.9304900599400923, 0.757909740497362, 0.5540597550457043], 
             UndirectedEdge[143, 159] -> 
             RGBColor[
              0.9692943691435871, 0.9753651561461802, 0.8806497039762], 
             UndirectedEdge[24, 144] -> 
             RGBColor[
              0.9656899085736597, 0.8942492548341856, 0.3299454838840773], 
             UndirectedEdge[76, 96] -> 
             RGBColor[
              0.8328368664088521, 0.8702221258321516, 0.9811476834594715], 
             UndirectedEdge[98, 120] -> 
             RGBColor[
              0.9905470920719912, 0.9796921684311414, 0.42484345402934043`], 
             UndirectedEdge[98, 183] -> 
             RGBColor[
              0.9055561740726389, 0.6414536908252432, 0.2754314587481523], 
             UndirectedEdge[55, 75] -> 
             RGBColor[
              0.84908264777634, 0.6839112085523401, 0.5982974612969593], 
             UndirectedEdge[35, 68] -> 
             RGBColor[
              0.9814760782275161, 0.9753661686920726, 0.6662129742818446], 
             UndirectedEdge[25, 43] -> 
             RGBColor[
              0.9698418017783265, 0.957836924880267, 0.6671147584043913], 
             UndirectedEdge[47, 174] -> 
             RGBColor[
              0.9648832429750986, 0.9498188688272843, 0.6663378241682798], 
             UndirectedEdge[29, 88] -> 
             RGBColor[
              0.8316070253939307, 0.41757991653826737`, 0.4422062691053005], 
             UndirectedEdge[17, 140] -> 
             RGBColor[
              0.9537402319122151, 0.8587342505615474, 0.5750083360306442], 
             UndirectedEdge[41, 90] -> 
             RGBColor[
              0.9787329919790011, 0.9399235295935334, 0.37188211908623914`], 
             UndirectedEdge[151, 196] -> 
             RGBColor[
              0.9931133956674718, 0.9876785746122536, 0.49181380147890746`], 
             UndirectedEdge[88, 94] -> 
             RGBColor[
              0.8491877189277638, 0.3360921557915835, 0.19305207083779036`], 
             UndirectedEdge[57, 198] -> 
             RGBColor[
              0.887744459086553, 0.6297376257042895, 0.467511478284796], 
             UndirectedEdge[71, 164] -> 
             RGBColor[
              0.9864568480144327, 0.9886675728579071, 0.8741086071620756], 
             UndirectedEdge[95, 154] -> 
             RGBColor[
              0.8528053642513692, 0.418753199162748, 0.44225949133237796`], 
             UndirectedEdge[69, 90] -> 
             RGBColor[
              0.9862173216546435, 0.9651699309936519, 0.40095732657904465`], 
             UndirectedEdge[175, 176] -> 
             RGBColor[
              0.9020063771821922, 0.6350198832258993, 0.43350953393183056`], 
             UndirectedEdge[58, 115] -> 
             RGBColor[
              0.9076377642671477, 0.9272127590109531, 0.9161509029136079], 
             UndirectedEdge[42, 88] -> 
             RGBColor[
              0.8770871968324649, 0.44227935244631367`, 0.24341532962640727`],
              UndirectedEdge[72, 134] -> 
             RGBColor[
              0.980470973793782, 0.9832624237479337, 0.8421059788812721], 
             UndirectedEdge[25, 49] -> 
             RGBColor[
              0.9757779351947329, 0.9777748046882603, 0.6974961644936655], 
             UndirectedEdge[23, 103] -> 
             RGBColor[
              0.9169529430916041, 0.9349111307994166, 0.9287941670869897], 
             UndirectedEdge[79, 192] -> 
             RGBColor[
              0.8639012090021945, 0.8915999897979692, 0.8474373884708559], 
             UndirectedEdge[89, 170] -> 
             RGBColor[
              0.970270997623262, 0.97516663160809, 0.8257486380844679], 
             UndirectedEdge[41, 57] -> 
             RGBColor[
              0.9541679329732335, 0.9316846334094004, 0.6629448577520249], 
             UndirectedEdge[10, 14] -> 
             RGBColor[
              0.9079266657691641, 0.9262056307231641, 0.8624423484191905], 
             UndirectedEdge[6, 59] -> 
             RGBColor[
              0.93368219244892, 0.7666993919942495, 0.5326616699519215], 
             UndirectedEdge[120, 183] -> 
             RGBColor[
              0.9069498720043893, 0.6460995646324306, 0.2855562366935222], 
             UndirectedEdge[8, 194] -> 
             RGBColor[
              0.8648157694439861, 0.4790418067718967, 0.20891130316640058`], 
             UndirectedEdge[63, 106] -> 
             RGBColor[
              0.9938489266011465, 0.9914686107090989, 0.7330104753045921], 
             UndirectedEdge[129, 131] -> 
             RGBColor[
              0.9742546915733076, 0.980319771646222, 0.9284642711012614], 
             UndirectedEdge[22, 38] -> 
             RGBColor[
              0.9659098143808802, 0.9468422984332233, 0.6566561546068614], 
             UndirectedEdge[38, 117] -> 
             RGBColor[
              0.9517040751824642, 0.8960423909363154, 0.6164718244945699], 
             UndirectedEdge[136, 159] -> 
             RGBColor[
              0.9629397345597994, 0.9504137968608399, 0.6739675373015758], 
             UndirectedEdge[158, 166] -> 
             RGBColor[
              0.8908488032534925, 0.9152485722457806, 0.9702402124808396], 
             UndirectedEdge[75, 96] -> 
             RGBColor[
              0.7777096987616137, 0.8263393739369361, 0.9784606123176923], 
             UndirectedEdge[118, 170] -> 
             RGBColor[
              0.9846439366828099, 0.9584483711220342, 0.5150952295383372], 
             UndirectedEdge[7, 58] -> 
             RGBColor[
              0.9104083438272257, 0.926837010091569, 0.7596415292235381], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.7375454075368479, 0.7915363710718801, 0.8857202917047264], 
             UndirectedEdge[65, 180] -> 
             RGBColor[
              0.9730152555066549, 0.9188558608052282, 0.4161569492695314], 
             UndirectedEdge[151, 171] -> 
             RGBColor[
              0.9940065219240011, 0.9895888813660534, 0.58902508276577], 
             UndirectedEdge[37, 118] -> 
             RGBColor[
              0.96910261918336, 0.9074380208347724, 0.3344699393184766], 
             UndirectedEdge[7, 47] -> 
             RGBColor[
              0.9729014938780982, 0.9762396543517949, 0.750773649206397], 
             UndirectedEdge[46, 99] -> 
             RGBColor[
              0.7168755345166868, 0.7397910676082611, 0.6396747983397051], 
             UndirectedEdge[195, 197] -> 
             RGBColor[
              0.9292095806481253, 0.7570466073183252, 0.26189857080601825`], 
             UndirectedEdge[5, 63] -> 
             RGBColor[
              0.9945598238808038, 0.990772338304245, 0.6492485861798696], 
             UndirectedEdge[11, 63] -> 
             RGBColor[
              0.7306207348366893, 0.7846247292178847, 0.8233532926046581], 
             UndirectedEdge[10, 193] -> 
             RGBColor[
              0.9071266407609542, 0.9258747998225643, 0.875700833203582], 
             UndirectedEdge[99, 147] -> 
             RGBColor[
              0.7092375178183341, 0.7707261320066531, 0.9584446706779876], 
             UndirectedEdge[9, 77] -> 
             RGBColor[
              0.9265433731950605, 0.7436507653989373, 0.2616830445713105], 
             UndirectedEdge[43, 103] -> 
             RGBColor[
              0.9836684913698819, 0.9677543143868037, 0.6260417878480468], 
             UndirectedEdge[54, 174] -> 
             RGBColor[
              0.9815581052879829, 0.9494533001528789, 0.3828571508137509], 
             UndirectedEdge[149, 197] -> 
             RGBColor[
              0.9663603891721966, 0.9192897479649278, 0.6012184348656793], 
             UndirectedEdge[87, 180] -> 
             RGBColor[
              0.9365321466629906, 0.7860781414667924, 0.26779047930429434`], 
             UndirectedEdge[134, 191] -> 
             RGBColor[
              0.9542977416699555, 0.8447629831667522, 0.4962735790313334], 
             UndirectedEdge[65, 131] -> 
             RGBColor[
              0.9827043797802498, 0.9836523166854156, 0.7422482757798684], 
             UndirectedEdge[107, 147] -> 
             RGBColor[
              0.9710061264322676, 0.9769664383555496, 0.892290923462211], 
             UndirectedEdge[50, 82] -> 
             RGBColor[
              0.951090416349158, 0.9480694811002746, 0.6928275432828646], 
             UndirectedEdge[30, 162] -> 
             RGBColor[
              0.9576267603494804, 0.8677542231244096, 0.5468723843238277], 
             UndirectedEdge[51, 74] -> 
             RGBColor[
              0.9865590451904127, 0.9663226447203035, 0.4022848579864333], 
             UndirectedEdge[12, 161] -> 
             RGBColor[
              0.9573803110708625, 0.8647825001455719, 0.3051457452391745], 
             UndirectedEdge[78, 113] -> 
             RGBColor[
              0.981109717271422, 0.9827494258278076, 0.7676727010915503], 
             UndirectedEdge[131, 133] -> 
             RGBColor[
              0.9471517392018681, 0.8545635939586569, 0.594630482421775], 
             UndirectedEdge[35, 188] -> 
             RGBColor[
              0.8787036676861407, 0.483178225390515, 0.4266046194441575], 
             UndirectedEdge[181, 185] -> 
             RGBColor[
              0.9222996383751267, 0.7638370791409188, 0.5853809577770238], 
             UndirectedEdge[111, 188] -> 
             RGBColor[
              0.8446820701895027, 0.32875077753948967`, 0.1898061041181244], 
             UndirectedEdge[41, 184] -> 
             RGBColor[
              0.878491162626531, 0.4722547035610587, 0.23174040315291758`], 
             UndirectedEdge[135, 187] -> 
             RGBColor[
              0.9697028958299228, 0.9085726805992845, 0.3414381520262535], 
             UndirectedEdge[51, 71] -> 
             RGBColor[
              0.986920839407669, 0.9796197964252087, 0.6448596311569885], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.6810225240573003, 0.5986255193104322, 0.592940362256051], 
             UndirectedEdge[26, 158] -> 
             RGBColor[
              0.9088371029219324, 0.9253457044342713, 0.740162878041293], 
             UndirectedEdge[101, 199] -> 
             RGBColor[
              0.9700824792210306, 0.9227573651259606, 0.5843973447173824], 
             UndirectedEdge[84, 194] -> 
             RGBColor[
              0.8934896004451509, 0.6474429688849964, 0.46672358142627846`], 
             UndirectedEdge[6, 176] -> 
             RGBColor[
              0.9322998944352187, 0.7661277762421455, 0.5555699253115407], 
             UndirectedEdge[18, 116] -> 
             RGBColor[
              0.977858022895417, 0.967810176425105, 0.6620255212462276], 
             UndirectedEdge[98, 179] -> 
             RGBColor[
              0.7368770924475826, 0.7828744349560284, 0.6811399207476936], 
             UndirectedEdge[116, 142] -> 
             RGBColor[
              0.5754160038350095, 0.6419806906192018, 0.9329713365269092], 
             UndirectedEdge[77, 112] -> 
             RGBColor[
              0.9760707678403064, 0.9294985067560673, 0.484388075744967], 
             UndirectedEdge[56, 190] -> 
             RGBColor[
              0.7328652902559925, 0.7908664793603744, 0.9744620664564738], 
             UndirectedEdge[76, 126] -> 
             RGBColor[
              0.9312353069276711, 0.8448447647308575, 0.6232421872836177], 
             UndirectedEdge[168, 173] -> 
             RGBColor[
              0.8245758192800585, 0.704165026164495, 0.6035858377539588], 
             UndirectedEdge[158, 164] -> 
             RGBColor[
              0.9057313663257358, 0.9258895225294539, 0.9245179955952558], 
             UndirectedEdge[46, 146] -> 
             RGBColor[
              0.9763102016159848, 0.9450662291612948, 0.6122005020684604], 
             UndirectedEdge[23, 25] -> 
             RGBColor[
              0.9031262535000486, 0.9249937412928797, 0.9698671376433342], 
             UndirectedEdge[9, 28] -> 
             RGBColor[
              0.8990704424570319, 0.6345842765419943, 0.2374942419873558], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.9917210283613573, 0.9822030994509297, 0.5526191744318485], 
             UndirectedEdge[103, 129] -> 
             RGBColor[
              0.9816658695343841, 0.9854524830831837, 0.8982510883019025], 
             UndirectedEdge[5, 48] -> 
             RGBColor[
              0.9913987055427189, 0.9897209112465801, 0.7202287573434355], 
             UndirectedEdge[36, 169] -> 
             RGBColor[
              0.8822122534648165, 0.4655328398639574, 0.3634864388779436], 
             UndirectedEdge[159, 170] -> 
             RGBColor[
              0.9708178903505207, 0.9755745033086249, 0.8248228913496863], 
             UndirectedEdge[86, 175] -> 
             RGBColor[
              0.9015022634185776, 0.6247926991939856, 0.26748476429017776`], 
             UndirectedEdge[9, 97] -> 
             RGBColor[
              0.9383661598853249, 0.7835318010275253, 0.30761233831706086`], 
             UndirectedEdge[7, 88] -> 
             RGBColor[
              0.8805585468792552, 0.45357125956845556`, 0.29242515864846486`],
              UndirectedEdge[5, 77] -> 
             RGBColor[
              0.9757158963069041, 0.9287394724291357, 0.4457624993473758], 
             UndirectedEdge[103, 131] -> 
             RGBColor[
              0.9791555762373593, 0.9835803104524907, 0.9025003600644161], 
             UndirectedEdge[15, 193] -> 
             RGBColor[
              0.974405339743859, 0.978997870460117, 0.8639804231196553], 
             UndirectedEdge[167, 181] -> 
             RGBColor[
              0.9694763574766034, 0.951407335917163, 0.6546631270661688], 
             UndirectedEdge[99, 146] -> 
             RGBColor[
              0.7256906252243276, 0.7828417788073041, 0.9236502271856599], 
             UndirectedEdge[163, 177] -> 
             RGBColor[
              0.9297621646815513, 0.8254471297773185, 0.6115385582824935], 
             UndirectedEdge[76, 116] -> 
             RGBColor[
              0.9552398308532049, 0.9661385196551464, 0.9606514704304501], 
             UndirectedEdge[15, 59] -> 
             RGBColor[
              0.972115271252022, 0.9780508682866667, 0.901932784536672], 
             UndirectedEdge[36, 151] -> 
             RGBColor[
              0.8818061175711247, 0.4640682928619922, 0.2759680748854169], 
             UndirectedEdge[38, 98] -> 
             RGBColor[
              0.972821422436163, 0.9701567753264374, 0.6835064467539727], 
             UndirectedEdge[70, 139] -> 
             RGBColor[
              0.9884250715493416, 0.9726171897927953, 0.40953401802136236`], 
             UndirectedEdge[56, 195] -> 
             RGBColor[
              0.8916043659396704, 0.7826723961213672, 0.6151707189126155], 
             UndirectedEdge[66, 168] -> 
             RGBColor[
              0.8009278931800524, 0.3849870722898242, 0.4381327373628874], 
             UndirectedEdge[6, 161] -> 
             RGBColor[
              0.9242227853070679, 0.7260917556539297, 0.2780923072868866], 
             UndirectedEdge[56, 118] -> 
             RGBColor[
              0.9265788675238705, 0.9158548757124504, 0.6718507311685279], 
             UndirectedEdge[46, 117] -> 
             RGBColor[
              0.9568584807876561, 0.863255053451184, 0.3019060579074929], 
             UndirectedEdge[79, 89] -> 
             RGBColor[
              0.839165987410669, 0.8750394886199143, 0.9753500631039833], 
             UndirectedEdge[102, 140] -> 
             RGBColor[
              0.9893766487251877, 0.9883218790955237, 0.7128255139282009], 
             UndirectedEdge[32, 130] -> 
             RGBColor[
              0.9853599390656195, 0.9882139728182986, 0.8922872271532727], 
             UndirectedEdge[105, 126] -> 
             RGBColor[
              0.946893377370326, 0.8565225280292522, 0.5967371583030274], 
             UndirectedEdge[86, 124] -> 
             RGBColor[
              0.9822069000847811, 0.9516418373467417, 0.3853775960846949], 
             UndirectedEdge[41, 168] -> 
             RGBColor[
              0.8640363972797093, 0.8603888237924231, 0.6567867587484811], 
             UndirectedEdge[43, 143] -> 
             RGBColor[
              0.9862587802974103, 0.9688254654257257, 0.5831139968660424], 
             UndirectedEdge[56, 197] -> 
             RGBColor[
              0.9162694508579354, 0.8804612386699759, 0.6350168252018055], 
             UndirectedEdge[47, 73] -> 
             RGBColor[
              0.9655653622604503, 0.973839284072164, 0.9431730390878822], 
             UndirectedEdge[23, 108] -> 
             RGBColor[
              0.8984977497600785, 0.8596102717739331, 0.6318258461961012], 
             UndirectedEdge[97, 155] -> 
             RGBColor[
              0.9340753380786491, 0.930139166048506, 0.6847861539526836], 
             UndirectedEdge[86, 161] -> 
             RGBColor[
              0.9766469835535905, 0.9328869333565528, 0.3637783702631556], 
             UndirectedEdge[88, 188] -> 
             RGBColor[
              0.8261636750874298, 0.20211104848332212`, 0.17268767085235454`],
              UndirectedEdge[136, 197] -> 
             RGBColor[
              0.9664563642261536, 0.8978940276317748, 0.3274059695235042], 
             UndirectedEdge[65, 69] -> 
             RGBColor[
              0.9891971162727888, 0.9745047229512257, 0.4734809356892704], 
             UndirectedEdge[23, 67] -> 
             RGBColor[
              0.8796102714824277, 0.906841370368065, 0.9883792070029949], 
             UndirectedEdge[31, 121] -> 
             RGBColor[
              0.8813822058472955, 0.5509179245782698, 0.22256154482826973`], 
             UndirectedEdge[52, 145] -> 
             RGBColor[
              0.9184692351765851, 0.9358783546801075, 0.9184378608491286], 
             UndirectedEdge[12, 87] -> 
             RGBColor[
              0.933066360333876, 0.7723374535766836, 0.26500182627142777`], 
             UndirectedEdge[128, 192] -> 
             RGBColor[
              0.9894766193335711, 0.9744886568882708, 0.556104305624087], 
             UndirectedEdge[78, 95] -> 
             RGBColor[
              0.9426262889387003, 0.9562519676390104, 0.9653820467203393], 
             UndirectedEdge[123, 165] -> 
             RGBColor[
              0.6778788281039632, 0.2755440552905279, 0.426702959591305], 
             UndirectedEdge[24, 56] -> 
             RGBColor[
              0.9144783100614342, 0.8733599622741365, 0.6335756312734624], 
             UndirectedEdge[50, 177] -> 
             RGBColor[
              0.9656644906648084, 0.9593990775197236, 0.6841154829860376], 
             UndirectedEdge[18, 58] -> 
             RGBColor[
              0.9055546748809838, 0.9110911025863806, 0.6874995075062666], 
             UndirectedEdge[96, 182] -> 
             RGBColor[
              0.8105103605226247, 0.6989696854951983, 0.603316028004728], 
             UndirectedEdge[49, 131] -> 
             RGBColor[
              0.9821934468252118, 0.9825594827578353, 0.6866363767366799], 
             UndirectedEdge[28, 106] -> 
             RGBColor[
              0.9475320682892184, 0.8203692559770466, 0.5053355858881434], 
             UndirectedEdge[57, 81] -> 
             RGBColor[
              0.9657930688891666, 0.972543870624788, 0.8771712990554077], 
             UndirectedEdge[7, 115] -> 
             RGBColor[
              0.9907477964532208, 0.9889205355415676, 0.6924027865632497], 
             UndirectedEdge[54, 94] -> 
             RGBColor[
              0.9425201142637455, 0.7996554300120816, 0.31823334413585624`], 
             UndirectedEdge[138, 181] -> 
             RGBColor[
              0.9784538272544587, 0.9807428256215238, 0.7701179953899366], 
             UndirectedEdge[55, 182] -> 
             RGBColor[
              0.8818833095373511, 0.5565415201106023, 0.223152876983995], 
             UndirectedEdge[17, 77] -> 
             RGBColor[
              0.9397532545953449, 0.7984540818234789, 0.27243775446535184`], 
             UndirectedEdge[144, 149] -> 
             RGBColor[
              0.9799667729759673, 0.9658048293280189, 0.6508604355828915], 
             UndirectedEdge[68, 179] -> 
             RGBColor[
              0.7364031571965278, 0.7812757400689319, 0.6792987717925081], 
             UndirectedEdge[103, 143] -> 
             RGBColor[
              0.9891570431259641, 0.9897841729283744, 0.8293593862830528], 
             UndirectedEdge[80, 173] -> 
             RGBColor[
              0.8838782495282835, 0.5656000766793546, 0.224817503812883], 
             UndirectedEdge[161, 199] -> 
             RGBColor[
              0.977515223365689, 0.9482740528848905, 0.6109582486080949], 
             UndirectedEdge[43, 133] -> 
             RGBColor[
              0.9516646543343907, 0.8387375978929699, 0.3181719102054056], 
             UndirectedEdge[6, 193] -> 
             RGBColor[
              0.935972260940757, 0.7676463941676999, 0.49470930853490486`], 
             UndirectedEdge[181, 188] -> 
             RGBColor[
              0.8745122455375869, 0.4800522696149475, 0.4336996038436829], 
             UndirectedEdge[120, 173] -> 
             RGBColor[
              0.9417388474401958, 0.7919364963164892, 0.3353286133276594], 
             UndirectedEdge[2, 158] -> 
             RGBColor[
              0.8937371078569525, 0.8748171439759889, 0.6468710714192999], 
             UndirectedEdge[95, 143] -> 
             RGBColor[
              0.9544280071116484, 0.9637984545751166, 0.8891937170953159], 
             UndirectedEdge[4, 172] -> 
             RGBColor[
              0.9518239688148069, 0.8516372599354833, 0.5759149061436339], 
             UndirectedEdge[89, 113] -> 
             RGBColor[
              0.9699115798072063, 0.9743978732422627, 0.7866282268764597], 
             UndirectedEdge[34, 90] -> 
             RGBColor[
              0.8907429504589677, 0.5406292387940079, 0.26098091879306884`], 
             UndirectedEdge[28, 48] -> 
             RGBColor[
              0.9455075348983362, 0.8195320593917819, 0.5388873434995287], 
             UndirectedEdge[5, 189] -> 
             RGBColor[
              0.9937801471042127, 0.9891046885165311, 0.564385580655244], 
             UndirectedEdge[8, 55] -> 
             RGBColor[
              0.8655527611981103, 0.4823883141985777, 0.20952626715136285`], 
             UndirectedEdge[29, 138] -> 
             RGBColor[
              0.920351125364564, 0.9351139533316954, 0.7888679112311046], 
             UndirectedEdge[8, 68] -> 
             RGBColor[
              0.9047739938186069, 0.6382708825728924, 0.27381499786153596`], 
             UndirectedEdge[176, 187] -> 
             RGBColor[
              0.9859667121611164, 0.97711460122963, 0.6460833303161838], 
             UndirectedEdge[65, 133] -> 
             RGBColor[
              0.9581117207058352, 0.8597683116285436, 0.40416521533786826`], 
             UndirectedEdge[68, 147] -> 
             RGBColor[
              0.9698638760919474, 0.9667058073526014, 0.6858694035499926], 
             UndirectedEdge[89, 192] -> 
             RGBColor[
              0.9704828423706902, 0.9756197461020494, 0.8488066314877871], 
             UndirectedEdge[2, 74] -> 
             RGBColor[
              0.9741007953283931, 0.9242980425995369, 0.3538869098155645], 
             UndirectedEdge[156, 185] -> 
             RGBColor[
              0.8880536352808777, 0.584559528195766, 0.22830154803291783`], 
             UndirectedEdge[126, 182] -> 
             RGBColor[
              0.9089088010414437, 0.6735923243939042, 0.24541053182887423`], 
             UndirectedEdge[18, 188] -> 
             RGBColor[
              0.8814928531321536, 0.475127092781791, 0.24832375613611163`], 
             UndirectedEdge[68, 156] -> 
             RGBColor[
              0.9409429419104365, 0.7913996840835684, 0.31977604113702673`], 
             UndirectedEdge[29, 181] -> 
             RGBColor[
              0.9047665134472201, 0.9261996298214474, 0.9664868284025188], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.9150583855868508, 0.93387529121179, 0.9490653734202796], 
             UndirectedEdge[30, 180] -> 
             RGBColor[
              0.970617969027979, 0.9192600364709946, 0.557325415769408], 
             UndirectedEdge[31, 196] -> 
             RGBColor[
              0.9574308936324988, 0.8574936435296645, 0.3784927672283783], 
             UndirectedEdge[193, 199] -> 
             RGBColor[
              0.9892646989993781, 0.9898286913986608, 0.8275752498561131], 
             UndirectedEdge[30, 110] -> 
             RGBColor[
              0.9284583291418271, 0.7416894326223371, 0.5228636771657597], 
             UndirectedEdge[12, 59] -> 
             RGBColor[
              0.9668397182127147, 0.9053901364858918, 0.5597151079042093], 
             UndirectedEdge[38, 156] -> 
             RGBColor[
              0.9257817544232887, 0.7904317965767423, 0.5954673497348993], 
             UndirectedEdge[72, 152] -> 
             RGBColor[
              0.963055594024859, 0.9249040577782166, 0.6194356418228133], 
             UndirectedEdge[37, 79] -> 
             RGBColor[
              0.8481480467553164, 0.8401365250167481, 0.643754104847676], 
             UndirectedEdge[170, 197] -> 
             RGBColor[
              0.9743345200168747, 0.9230547340795598, 0.47826132357161477`], 
             UndirectedEdge[86, 127] -> 
             RGBColor[
              0.8309640335475255, 0.8529645314977514, 0.6803776116265843], 
             UndirectedEdge[69, 127] -> 
             RGBColor[
              0.8313450081600462, 0.854249648322877, 0.6818576260552087], 
             UndirectedEdge[58, 61] -> 
             RGBColor[
              0.8824433267883817, 0.9090516508415099, 0.986960241248102], 
             UndirectedEdge[11, 17] -> 
             RGBColor[
              0.6942324054575846, 0.6534288357349739, 0.6036950721500922], 
             UndirectedEdge[11, 15] -> 
             RGBColor[
              0.7111208206372539, 0.7721306961653781, 0.9552567302495989], 
             UndirectedEdge[111, 157] -> 
             RGBColor[
              0.8474034872382655, 0.6891863298431413, 0.5994430852974112], 
             UndirectedEdge[75, 191] -> 
             RGBColor[
              0.8712653608061287, 0.7817620099452884, 0.6166585029067928], 
             UndirectedEdge[98, 156] -> 
             RGBColor[
              0.9414168771614913, 0.792998378970665, 0.32161719009221224`], 
             UndirectedEdge[28, 140] -> 
             RGBColor[
              0.9438117029793918, 0.8188307893124059, 0.5669916670687614], 
             UndirectedEdge[105, 157] -> 
             RGBColor[
              0.8956595400526846, 0.9187569092350294, 0.9593404835280241], 
             UndirectedEdge[3, 15] -> 
             RGBColor[
              0.9469662606793319, 0.8791908485529646, 0.6141588551858672], 
             UndirectedEdge[55, 96] -> 
             RGBColor[
              0.7984720277960398, 0.6443064282078184, 0.5932709480911282], 
             UndirectedEdge[6, 64] -> 
             RGBColor[
              0.9142510618576323, 0.6905088610162557, 0.24948848105004634`], 
             UndirectedEdge[70, 134] -> 
             RGBColor[
              0.9913893391969425, 0.9822285612948081, 0.5760645133520219], 
             UndirectedEdge[106, 140] -> 
             RGBColor[
              0.9889919763441173, 0.9897159135720579, 0.8320949700373905], 
             UndirectedEdge[64, 154] -> 
             RGBColor[
              0.8635633362520978, 0.3855146372820558, 0.20431762977828363`], 
             UndirectedEdge[8, 157] -> 
             RGBColor[
              0.8494138639890778, 0.601911771191297, 0.46610025386461346`], 
             UndirectedEdge[83, 124] -> 
             RGBColor[
              0.9013549966198, 0.6254946942788726, 0.26378068269165555`], 
             UndirectedEdge[22, 128] -> 
             RGBColor[
              0.9791842518843632, 0.9414457352151846, 0.3736351786052887], 
             UndirectedEdge[83, 135] -> 
             RGBColor[
              0.8921905807969776, 0.5939874915906603, 0.23126949196711175`], 
             UndirectedEdge[62, 68] -> 
             RGBColor[
              0.9315360807761484, 0.9365702710596651, 0.6969836051379632], 
             UndirectedEdge[105, 116] -> 
             RGBColor[
              0.9708979012958597, 0.9778162829535411, 0.9341464414498598], 
             UndirectedEdge[93, 145] -> 
             RGBColor[
              0.9300417980092337, 0.9451060021540116, 0.9195416622230553], 
             UndirectedEdge[128, 195] -> 
             RGBColor[
              0.9441398352173934, 0.8080274156330769, 0.31668355945517124`], 
             UndirectedEdge[87, 154] -> 
             RGBColor[
              0.8540018513937305, 0.34760653599457947`, 0.19662423462434603`],
              UndirectedEdge[138, 167] -> 
             RGBColor[
              0.9850609693939472, 0.9603216594274109, 0.47704420989475466`], 
             UndirectedEdge[179, 194] -> 
             RGBColor[
              0.7401885476058621, 0.5255676644260185, 0.4583831215383727], 
             UndirectedEdge[118, 144] -> 
             RGBColor[
              0.9777904660360961, 0.9367441682724995, 0.3682205837791428], 
             UndirectedEdge[47, 188] -> 
             RGBColor[
              0.8709840443395145, 0.4774209429383244, 0.43967192816977063`], 
             UndirectedEdge[11, 20] -> 
             RGBColor[
              0.7255504524139424, 0.769053602643289, 0.6733752162497575], 
             UndirectedEdge[124, 187] -> 
             RGBColor[
              0.9834495195641563, 0.955833484631603, 0.3902049381130691], 
             UndirectedEdge[28, 189] -> 
             RGBColor[
              0.9478889764598298, 0.8189158366617328, 0.38304416681133724`], 
             UndirectedEdge[84, 93] -> 
             RGBColor[
              0.9087288133590463, 0.9298146800449976, 0.9826613815463456], 
             UndirectedEdge[18, 94] -> 
             RGBColor[
              0.9416084651398199, 0.796580223451687, 0.3146917594398967], 
             UndirectedEdge[146, 156] -> 
             RGBColor[
              0.9397512507361212, 0.800695170290654, 0.564877011993777], 
             UndirectedEdge[2, 26] -> 
             RGBColor[
              0.9780629039698601, 0.9372558968512137, 0.4039101308955736], 
             UndirectedEdge[124, 161] -> 
             RGBColor[
              0.974885961602052, 0.9269465928063966, 0.3569371325225202], 
             UndirectedEdge[25, 67] -> 
             RGBColor[
              0.9353973929977039, 0.9507258719515641, 0.9729451877374069], 
             UndirectedEdge[15, 77] -> 
             RGBColor[
              0.9566416697750141, 0.9171559422538831, 0.6239994125648585], 
             UndirectedEdge[23, 49] -> 
             RGBColor[
              0.9199908136794568, 0.9338903031047612, 0.7129301837592534], 
             UndirectedEdge[27, 37] -> 
             RGBColor[
              0.9502271264629764, 0.920798284172832, 0.6527449967583311], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.8824272199666662, 0.46539676808297037`, 0.34357123764043274`],
              UndirectedEdge[134, 139] -> 
             RGBColor[
              0.9914208128219666, 0.9823347292223729, 0.5761867824419451], 
             UndirectedEdge[13, 127] -> 
             RGBColor[
              0.826371308220865, 0.8374721905477376, 0.6625357409959118], 
             UndirectedEdge[59, 186] -> 
             RGBColor[
              0.9878423785629576, 0.989240525346233, 0.8511467803348971], 
             UndirectedEdge[119, 149] -> 
             RGBColor[
              0.9835022778235675, 0.9865576360611199, 0.8833004847347671], 
             UndirectedEdge[41, 66] -> 
             RGBColor[
              0.8714111029336303, 0.4178342622594835, 0.2249605299952121], 
             UndirectedEdge[25, 103] -> 
             RGBColor[
              0.9727400646068802, 0.9787956323829157, 0.9133601478214017], 
             UndirectedEdge[164, 166] -> 
             RGBColor[
              0.9720688627702035, 0.978231143216188, 0.9116343895110761], 
             UndirectedEdge[30, 90] -> 
             RGBColor[
              0.9882872801873954, 0.979926418063495, 0.6204278660856124], 
             UndirectedEdge[75, 182] -> 
             RGBColor[
              0.861120980502925, 0.7385744658397202, 0.6083425412105591], 
             UndirectedEdge[92, 97] -> 
             RGBColor[
              0.9877176568892815, 0.9690033151159171, 0.5111719967507875], 
             UndirectedEdge[18, 61] -> 
             RGBColor[
              0.9606996900282128, 0.9550135198669356, 0.6910701031804722], 
             UndirectedEdge[76, 191] -> 
             RGBColor[
              0.9263925284533672, 0.825644761840504, 0.6193455740485719], 
             UndirectedEdge[129, 197] -> 
             RGBColor[
              0.9653198252183612, 0.9185136970719245, 0.602979838216978], 
             UndirectedEdge[97, 112] -> 
             RGBColor[
              0.9878935545305708, 0.9693795423846554, 0.5303173694907174], 
             UndirectedEdge[87, 131] -> 
             RGBColor[
              0.9462212709365855, 0.85087459734698, 0.5938818058146313], 
             UndirectedEdge[33, 198] -> 
             RGBColor[
              0.9044533538630466, 0.6416996487799925, 0.4168615868437357], 
             UndirectedEdge[39, 114] -> 
             RGBColor[
              0.9941772175011536, 0.9899539819456123, 0.607604242927823], 
             UndirectedEdge[144, 170] -> 
             RGBColor[
              0.9879409038206455, 0.9695698154426509, 0.5279033242888269], 
             UndirectedEdge[64, 110] -> 
             RGBColor[
              0.9087147340643897, 0.6653696895493494, 0.24486883343155247`], 
             UndirectedEdge[108, 131] -> 
             RGBColor[
              0.9607003829058336, 0.9082794514270073, 0.6055320391735277], 
             UndirectedEdge[33, 141] -> 
             RGBColor[
              0.9866163254955655, 0.9745391769713958, 0.6156595466799388], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.947408587621427, 0.8291996055078981, 0.27654191900233416`], 
             UndirectedEdge[88, 142] -> 
             RGBColor[
              0.6090280882081556, 0.22585433069439437`, 0.4249610210240715], 
             UndirectedEdge[12, 95] -> 
             RGBColor[
              0.931271629620334, 0.8790574483289364, 0.6334547113334756], 
             UndirectedEdge[131, 162] -> 
             RGBColor[
              0.9490640653241893, 0.8621453297887565, 0.596169184907858], 
             UndirectedEdge[21, 194] -> 
             RGBColor[
              0.9100529475276882, 0.6583859427666336, 0.3692678007583975], 
             UndirectedEdge[131, 154] -> 
             RGBColor[
              0.8710172696201953, 0.4326552037736121, 0.4225120593237752], 
             UndirectedEdge[81, 184] -> 
             RGBColor[
              0.8862412532371532, 0.49949419503798365`, 0.3745580306885061], 
             UndirectedEdge[105, 111] -> 
             RGBColor[
              0.9216347421072815, 0.7474946052767903, 0.5759538116152882]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 71 -> 
             RGBColor[
              0.9859622701864186, 0.9884630522159528, 0.8823050416986589], 10 -> 
             RGBColor[
              0.8214282851836687, 0.8604486338013805, 0.982829757210147], 68 -> 
             RGBColor[
              0.9875086746722561, 0.9695259679461669, 0.40597398920091454`], 
             155 -> RGBColor[
              0.8872074463762193, 0.9128991514085555, 0.9891038323264428], 
             132 -> RGBColor[
              0.9546369303620211, 0.8578575757719253, 0.2823580132424272], 26 -> 
             RGBColor[
              0.9931628990348401, 0.987784457309496, 0.49720193751756675`], 
             29 -> RGBColor[
              0.8466638115573254, 0.8805707575316191, 0.9852367442436867], 
             113 -> RGBColor[
              0.9940755388352481, 0.9897365015605307, 0.596537147632005], 50 -> 
             RGBColor[
              0.9843307975749518, 0.9588062422959335, 0.39362853676962184`], 
             173 -> RGBColor[
              0.8908400559107746, 0.5972120134910557, 0.23062660570792348`], 
             192 -> RGBColor[
              0.9952180639622157, 0.9921802472801042, 0.7208939568546597], 
             165 -> RGBColor[
              0.39337350226260415`, 0.5151420889579279, 0.9462863896110112], 
             92 -> RGBColor[
              0.9944920839974842, 0.9906274495433777, 0.6418755179226505], 11 -> 
             RGBColor[
              0.46625595812502957`, 0.5775666172542704, 0.9511245234569046], 
             137 -> RGBColor[
              0.8754998565530215, 0.5275557510020848, 0.21782636734111951`], 
             120 -> RGBColor[
              0.9926376389696169, 0.9866609791419226, 0.4400306209473953], 51 -> 
             RGBColor[
              0.9878794086289193, 0.9707765406344646, 0.4074142206153182], 72 -> 
             RGBColor[
              0.9665568671179964, 0.9745787467714817, 0.9414946799899396], 64 -> 
             RGBColor[
              0.9493825981719902, 0.8370258995408599, 0.27813025422730026`], 
             41 -> RGBColor[
              0.9697612119100761, 0.909659608746912, 0.33702844769696816`], 
             103 -> RGBColor[
              0.9865667541984358, 0.9887130218894524, 0.8722871772650572], 
             162 -> RGBColor[
              0.9263837323720958, 0.745843060561984, 0.2596248269519407], 196 -> 
             RGBColor[
              0.9931992590352905, 0.9878622276738995, 0.5011594991786863], 
             179 -> RGBColor[
              0.4852976397207995, 0.5930255121916967, 0.9526235543841015], 
             160 -> RGBColor[0.817319, 0.134127, 0.164218], 123 -> 
             RGBColor[
              0.8201314910246426, 0.1557450384568279, 0.16691124458145196`], 
             150 -> RGBColor[
              0.9882738170483724, 0.9894189362474154, 0.8439967281045654], 
             188 -> RGBColor[
              0.8303337606378229, 0.23416415336678328`, 0.17668094948484894`],
              46 -> RGBColor[
              0.9674951109083442, 0.9020155179622519, 0.32822507322250577`], 
             182 -> RGBColor[
              0.8939216422639359, 0.6112047773979824, 0.23319795689759482`], 
             6 -> RGBColor[
              0.8791195255432743, 0.5439918224916516, 0.22084670787279242`], 
             131 -> RGBColor[
              0.9717443982762828, 0.9784475990155289, 0.9327135428637752], 45 -> 
             RGBColor[
              0.9939391178047027, 0.989444710770476, 0.5816885603501466], 195 -> 
             RGBColor[
              0.9045444957298604, 0.6592577647697164, 0.24205246451682833`], 
             148 -> RGBColor[
              0.9925885769062781, 0.9865560403493764, 0.43469051812891896`], 
             161 -> RGBColor[
              0.9693260450708614, 0.9081916888162077, 0.33533790670098085`], 
             1 -> RGBColor[
              0.9834529596163762, 0.987179824891961, 0.9128940025968725], 101 -> 
             RGBColor[
              0.9544605567815447, 0.8571583132983479, 0.2822160989195559], 12 -> 
             RGBColor[
              0.9454345770708638, 0.8213733114749361, 0.2749535837773681], 39 -> 
             RGBColor[
              0.9934264995243608, 0.9883482721024831, 0.5258932240482432], 48 -> 
             RGBColor[
              0.9886632748721794, 0.9895799870661691, 0.8375424040795432], 77 -> 
             RGBColor[
              0.95729765640055, 0.8676171094312803, 0.2886098880874237], 56 -> 
             RGBColor[
              0.8786642361494805, 0.906087027473018, 0.9882889733084027], 110 -> 
             RGBColor[
              0.8680468699567894, 0.49371347955783884`, 0.21160741263580465`],
              73 -> RGBColor[
              0.9788461127780029, 0.9837440460629217, 0.9206921926361504], 37 -> 
             RGBColor[
              0.9637117394684594, 0.889253317717662, 0.31352738960830007`], 
             130 -> RGBColor[
              0.985275737097978, 0.988179153140787, 0.8936826716647992], 107 -> 
             RGBColor[
              0.9897931753528965, 0.9900472299520634, 0.8188170290253513], 59 -> 
             RGBColor[
              0.9882448593545657, 0.9894069614968475, 0.8444766320310506], 47 -> 
             RGBColor[
              0.9522846117428977, 0.9639345220814064, 0.965653885539614], 159 -> 
             RGBColor[
              0.946841406233682, 0.9598749883250642, 0.9748678126513514], 55 -> 
             RGBColor[
              0.8698449768107662, 0.5018782628232223, 0.21310779707039515`], 
             49 -> RGBColor[
              0.992642495374141, 0.9866713665001418, 0.44055921060958464`], 
             82 -> RGBColor[
              0.9178500351233643, 0.9373327199046155, 0.9920265497961074], 
             199 -> RGBColor[
              0.9857044016605165, 0.9883564169535735, 0.8865785905152088], 89 -> 
             RGBColor[
              0.9457476207791645, 0.9590592449239945, 0.9767193061209144], 
             144 -> RGBColor[
              0.9810874331739317, 0.9478656125931162, 0.38102867852963246`], 
             78 -> RGBColor[
              0.9681438957075961, 0.9757623500950843, 0.9388082545510954], 42 -> 
             RGBColor[
              0.9831043258729283, 0.9546690652557579, 0.3888639258070071], 
             154 -> RGBColor[
              0.8206537052921516, 0.15975900615265365`, 0.1674113175537753], 
             168 -> RGBColor[
              0.7583115826493424, 0.8111180388379341, 0.9765450697999941], 
             121 -> RGBColor[
              0.8612420446560898, 0.46281435717468994`, 0.20592929960336945`],
              128 -> RGBColor[
              0.9837351747049264, 0.9567970664964374, 0.3913146543935142], 
             115 -> RGBColor[
              0.9879772168931427, 0.9892962844609515, 0.8489121602533195], 61 -> 
             RGBColor[
              0.9375883419356106, 0.952974068122065, 0.9905308369223076], 93 -> 
             RGBColor[
              0.8722568284794268, 0.900977934521365, 0.9876778290448726], 88 -> 
             RGBColor[
              0.8240786323122333, 0.18608449604159155`, 0.17069103153610735`],
              21 -> RGBColor[
              0.9948908394862775, 0.9914803472135422, 0.6852775920441759], 62 -> 
             RGBColor[
              0.8755634868800406, 0.9036145741731633, 0.987993221075012], 136 -> 
             RGBColor[
              0.9790380628859169, 0.9409526053966157, 0.3730672619518002], 
             190 -> RGBColor[
              0.5870663443625044, 0.6756459312477308, 0.9606351596045449], 57 -> 
             RGBColor[
              0.9385746540363908, 0.953709658071889, 0.9888612678070817], 111 -> 
             RGBColor[
              0.8733786892928623, 0.5179240258849023, 0.21605641338467532`], 
             63 -> RGBColor[
              0.994985511548349, 0.9916828411814992, 0.6955820617524114], 75 -> 
             RGBColor[
              0.8283203187419139, 0.8659441542814579, 0.9834871255235234], 30 -> 
             RGBColor[
              0.988869788326865, 0.9896653856868353, 0.8341199416957147], 5 -> 
             RGBColor[
              0.9941341362132584, 0.989861835426991, 0.6029151106073278], 171 -> 
             RGBColor[
              0.994985511548349, 0.9916828411814992, 0.6955820617524114], 102 -> 
             RGBColor[
              0.9934816864160848, 0.9884663112836303, 0.5318999766383936], 31 -> 
             RGBColor[
              0.9216625282297071, 0.7271250593854296, 0.2558260352780703], 96 -> 
             RGBColor[
              0.7270990787813134, 0.7867345935924144, 0.9734340991118613], 70 -> 
             RGBColor[
              0.9883935979243175, 0.9725110218652305, 0.40941174893143917`], 
             52 -> RGBColor[
              0.8491117028141297, 0.8825226395735567, 0.985470226297019], 183 -> 
             RGBColor[
              0.8641059885217754, 0.47581885737768465`, 0.20831904456658562`],
              158 -> RGBColor[
              0.8245113068090247, 0.8629069515590466, 0.9831238185650193], 13 -> 
             RGBColor[
              0.9747824713829986, 0.9265974959968701, 0.3565350925639854], 
             170 -> RGBColor[
              0.9947943744673593, 0.9912740182921856, 0.6747779700480213], 86 -> 
             RGBColor[
              0.9839679220363194, 0.957582177896898, 0.39221883382533035`], 
             18 -> RGBColor[
              0.9838110381208149, 0.9570529716118064, 0.39160936943863695`], 
             153 -> RGBColor[
              0.9928819736512009, 0.987183586319805, 0.46662494317894465`], 
             58 -> RGBColor[
              0.8272983116411528, 0.8651292335609547, 0.9833896455738963], 22 -> 
             RGBColor[
              0.9746333290638001, 0.9260944039339319, 0.3559557028170632], 66 -> 
             RGBColor[
              0.8222360484454074, 0.17192158901576926`, 0.16892657114433407`],
              143 -> RGBColor[
              0.9917473320534924, 0.9908553239672964, 0.7864315953010486], 
             119 -> RGBColor[
              0.988158442869132, 0.9893712260593183, 0.8459087768333837], 145 -> 
             RGBColor[
              0.9878267675390405, 0.9892340697866583, 0.8514054954012381], 91 -> 
             RGBColor[
              0.9663620604074782, 0.8981934725699218, 0.32382338598527444`], 
             177 -> RGBColor[
              0.9469981837546649, 0.9599919127435137, 0.9746024292024534], 
             200 -> RGBColor[
              0.9628692153371149, 0.9718285021112758, 0.9477369125613508], 
             114 -> RGBColor[
              0.9949279354779463, 0.9915596917887416, 0.6893152618074027], 24 -> 
             RGBColor[
              0.9502923839733878, 0.840632897075255, 0.2788622892385222], 176 -> 
             RGBColor[
              0.985480263327163, 0.9882637299926393, 0.8902931427502889], 79 -> 
             RGBColor[
              0.7325843540421733, 0.7910197323158341, 0.9739808200870521], 
             109 -> RGBColor[
              0.9952059081088513, 0.9921542471389033, 0.7195708672331839], 
             135 -> RGBColor[
              0.9529526306647755, 0.8511798887319484, 0.2810027861704282], 
             108 -> RGBColor[
              0.9496563675353844, 0.8381113038384856, 0.2783505354832801], 
             191 -> RGBColor[
              0.9142104028703435, 0.6975798656091189, 0.2498298802900622], 14 -> 
             RGBColor[
              0.9944250463546596, 0.9919626276449476, 0.742054939628234], 185 -> 
             RGBColor[
              0.8817300614131385, 0.5558456561705619, 0.22302500299269676`], 
             32 -> RGBColor[
              0.985444141033261, 0.9882487924958102, 0.8908917826417461], 122 -> 
             RGBColor[
              0.9952180639622157, 0.9921802472801042, 0.7208939568546597], 
             187 -> RGBColor[
              0.9864531609950699, 0.9659654724666207, 0.40187351788207876`], 
             193 -> RGBColor[
              0.9928249963382397, 0.9913009658437482, 0.7685719091970172], 
             100 -> RGBColor[
              0.9685694471669662, 0.976079725676706, 0.9380879069319779], 180 -> 
             RGBColor[
              0.9523661497290931, 0.8488546872551539, 0.2805308898431012], 7 -> 
             RGBColor[
              0.9935183760132987, 0.9885447866221835, 0.5358934128731799], 
             175 -> RGBColor[
              0.8602694341097068, 0.4583979598425293, 0.2051177295226014], 9 -> 
             RGBColor[
              0.8957890899895711, 0.6196844213665941, 0.23475620105519726`], 
             90 -> RGBColor[
              0.987704772047926, 0.9701874504401549, 0.40673579047551006`], 
             174 -> RGBColor[
              0.9774818742072997, 0.9357032155731622, 0.36702176279694565`], 
             142 -> RGBColor[0.178927, 0.305394, 0.933501], 134 -> 
             RGBColor[
              0.9943850804695675, 0.9919461007243856, 0.7427172777726045], 
             105 -> RGBColor[
              0.9698907949217005, 0.9770651846686784, 0.9358512098459012], 16 -> 
             RGBColor[
              0.9710302284710461, 0.913940299586322, 0.34195833740266746`], 
             139 -> RGBColor[
              0.9884565451743657, 0.9727233577203601, 0.40965628711128554`], 
             146 -> RGBColor[
              0.9851252923236254, 0.9881169403603378, 0.8961759309144152], 
             126 -> RGBColor[
              0.9238959598189515, 0.735979871389826, 0.25762310676015365`], 
             198 -> RGBColor[
              0.8623293616116341, 0.4677516095204898, 0.20683658352365308`], 
             40 -> RGBColor[
              0.9744934988982605, 0.9256227239518828, 0.3554124890286531], 
             104 -> RGBColor[
              0.9135226913580766, 0.6948533186292571, 0.24927653146462841`], 
             181 -> RGBColor[
              0.9628692153371149, 0.9718285021112758, 0.9477369125613508], 
             127 -> RGBColor[
              0.6779601450587315, 0.7483468850986049, 0.9685363894278383], 76 -> 
             RGBColor[
              0.9385746540363908, 0.953709658071889, 0.9888612678070817], 172 -> 
             RGBColor[
              0.9849898120359726, 0.9880609157797088, 0.8984211898925699], 84 -> 
             RGBColor[
              0.9452007982386658, 0.9586514255686303, 0.9776449340478188], 
             184 -> RGBColor[
              0.8328561379847585, 0.253552250968132, 0.17909638088089228`], 
             151 -> RGBColor[
              0.9930275322996532, 0.9874949215506077, 0.48246810377912863`], 
             35 -> RGBColor[
              0.9754434817827762, 0.9812063694379783, 0.9264519593627747], 36 -> 
             RGBColor[
              0.8261954102068605, 0.20235497851768453`, 0.17271806043856108`],
              34 -> RGBColor[
              0.8422620396644885, 0.32585013297093457`, 0.18810348295184828`],
              38 -> RGBColor[
              0.9571862996979603, 0.9675901929325147, 0.9573566063966598], 54 -> 
             RGBColor[
              0.9856343363686662, 0.9632033847325957, 0.3986925388305561], 60 -> 
             RGBColor[
              0.9580308067246397, 0.8700901976263175, 0.291458038652691], 87 -> 
             RGBColor[
              0.9206981435968882, 0.723301595678431, 0.25505006876548747`], 
             141 -> RGBColor[
              0.9845313126252594, 0.9594826266437937, 0.3944074998759769], 67 -> 
             RGBColor[
              0.9118814109800829, 0.9325735010267493, 0.9914572570970676], 
             133 -> RGBColor[
              0.9225590801274535, 0.7306795889017849, 0.25654742197977487`], 
             98 -> RGBColor[
              0.9884565451743657, 0.9727233577203601, 0.40965628711128554`], 
             3 -> RGBColor[
              0.9379468382091855, 0.7916869220294434, 0.26892877332944126`], 
             27 -> RGBColor[
              0.9367425134574933, 0.9523432506280021, 0.9919626039083621], 
             163 -> RGBColor[
              0.9125261456084376, 0.6909023468111233, 0.24847468736253359`], 
             85 -> RGBColor[
              0.9865667541984358, 0.9887130218894524, 0.8722871772650572], 83 -> 
             RGBColor[
              0.8618095558630786, 0.4653912930200163, 0.20640284486545354`], 
             28 -> RGBColor[
              0.9023517949244928, 0.6494841317173946, 0.24023228291951432`], 
             44 -> RGBColor[
              0.9928281792113058, 0.9870685254523217, 0.46076975037716794`], 
             189 -> RGBColor[
              0.9934261579951669, 0.9883475416060712, 0.5258560507031602], 15 -> 
             RGBColor[
              0.9559856831494782, 0.9666947750764858, 0.9593889370422933], 80 -> 
             RGBColor[
              0.8769164431457925, 0.5339881398676536, 0.21900840191784252`], 
             112 -> RGBColor[
              0.9948438792800629, 0.9913799040808542, 0.6801662634025103], 
             169 -> RGBColor[
              0.9942459399807285, 0.9918885625565033, 0.7450231957567086], 69 -> 
             RGBColor[
              0.9847298712613609, 0.960152411547149, 0.39517886268257923`], 
             20 -> RGBColor[
              0.9848449467028552, 0.9605405880323076, 0.39562590904261047`], 
             8 -> RGBColor[
              0.8634066533917824, 0.47264333988625534`, 0.20773550219184672`],
              116 -> RGBColor[
              0.971905007670019, 0.9785673812384037, 0.9324416730538184], 97 -> 
             RGBColor[
              0.9809432297810787, 0.9473791806884565, 0.3804684755789245], 
             118 -> RGBColor[
              0.9744934988982605, 0.9256227239518828, 0.3554124890286531], 
             178 -> RGBColor[
              0.8206537052921516, 0.15975900615265365`, 0.1674113175537753], 
             81 -> RGBColor[
              0.9930114837419424, 0.9913780831776869, 0.7654813303037337], 
             166 -> RGBColor[
              0.9571862996979603, 0.9675901929325147, 0.9573566063966598], 
             125 -> 
             RGBColor[
              0.9118814109800829, 0.9325735010267493, 0.9914572570970676], 95 -> 
             RGBColor[
              0.9171086821698045, 0.9367415851829367, 0.9919558388895833], 
             157 -> RGBColor[
              0.8214282851836687, 0.8604486338013805, 0.982829757210147], 74 -> 
             RGBColor[
              0.9852386817519061, 0.9618687488061424, 0.39715549535754846`], 
             19 -> RGBColor[
              0.9629469858579004, 0.8866736242165596, 0.3105564662428796], 
             156 -> RGBColor[
              0.894377209148617, 0.61327340022097, 0.2335780930731389], 167 -> 
             RGBColor[
              0.9760834996160919, 0.9309861697230501, 0.36158934157098677`], 
             33 -> RGBColor[
              0.9887013383658716, 0.9895957272989979, 0.8369115934839009], 43 -> 
             RGBColor[
              0.9807702285413281, 0.946795606884155, 0.3797963984310363], 140 -> 
             RGBColor[
              0.9852716110342906, 0.9881774469074173, 0.8937510512180084], 
             186 -> RGBColor[
              0.9874398977713496, 0.9890740891956185, 0.8578169286387435], 
             117 -> RGBColor[
              0.9462218506669682, 0.8244945889401162, 0.2755870425924801], 4 -> 
             RGBColor[
              0.9186581255936412, 0.7152136040912579, 0.2534086223946981], 
             106 -> RGBColor[
              0.9927123416539441, 0.9912543802366987, 0.7704388888567726], 65 -> 
             RGBColor[
              0.9936643612842169, 0.9888570343553024, 0.5517830086959616], 53 -> 
             RGBColor[
              0.9934829546023279, 0.988469023805771, 0.5320380108846181], 2 -> 
             RGBColor[
              0.9629629089048801, 0.8867273363929312, 0.3106183242735805], 
             147 -> RGBColor[
              0.9522190775116386, 0.9638856467590358, 0.9657648178990705], 94 -> 
             RGBColor[
              0.8994058921588248, 0.6361074752915675, 0.23777414944115638`], 
             23 -> RGBColor[
              0.8473391319847725, 0.8811092397093807, 0.9853011569089222], 
             194 -> RGBColor[
              0.8676340015483934, 0.49183874054317944`, 0.2112629051155083], 
             129 -> RGBColor[
              0.9767649848703324, 0.982191944276915, 0.9242149993387477], 99 -> 
             RGBColor[
              0.46625595812502957`, 0.5775666172542704, 0.9511245234569046], 
             25 -> RGBColor[
              0.9589133750153248, 0.9688782428763788, 0.9544331183777462], 
             138 -> RGBColor[
              0.9940384391718025, 0.9896571491317717, 0.5924990782185225], 
             124 -> RGBColor[
              0.9804458781332427, 0.9457014967965854, 0.3785363583440595], 
             197 -> RGBColor[
              0.9538746655663902, 0.8548354498669339, 0.2817446770952082], 
             164 -> RGBColor[
              0.9869514258424468, 0.9888720934998613, 0.8659121726254924], 
             152 -> RGBColor[
              0.9595543209317215, 0.8752293687849516, 0.29737660365568697`], 
             17 -> RGBColor[
              0.9222088527901396, 0.7292910542156774, 0.25626562084328], 149 -> 
             RGBColor[
              0.9788461127780029, 0.9837440460629217, 
               0.9206921926361504]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9lnk01I33xy0ZCmPGjGUM5jOLCfGgkIjPm8rSZv1l6yGUlK0nopQSkiYJ
LahIHqLta6lHok2FUhGiHm2iRUpCWSbL1++c3/ndc+65/9x/7rn3/bpvbmCk
2yYpCQmJh7P5v/VBawZ55xUHYW8zjtTbKsDaIH7bZwcCjpXZ32wt+Rjd7Lo7
tnseOvea6x/0HSa9rxx+IbmQhZy6z0cn7biwOZpxc1cVDS5hLi4Ldn8ic2o8
VUdXzJDjpy6p9EbQIJlfdrxXgYfJ2tv17DYxaTyjcbX3tQ7WSS68vkvIAC/w
UtnPR8ogRussGh69I4XBY/mqVbIgChKbi4qmyGiHwf5mUyU83PrZ1SjlI5mX
sKKu9CoFrPY7E5lTNHjZt/IvcmfIvvG49CY9JhydAwqLkmWQvJzdfNZDBkZ7
OPM+TspDoyrGRM5qnBxf0rVitPw32d1TPLVPRxl7HG983Z1CA7H64gUfbjNp
5+Wsl13Kx8ZD7XutgqfJynjmk8//SiPL7GpuXjgHBb4pBTJnqCCkP+YWW7SQ
qg4fXg016qAr7fejvW4cHFw5ErXvOYH08glrVjcDZ1Tb/r4tT0PM3UMv5lEY
+Ct0+59aT7WQlagpOkYwYJBc2qNLpSFoQWHZ2hxltOn8dehBJAFKFVH3PYiP
xze/qjdEaqCcGxuYYKCCbyyZC5k2VDj2gh3wbz+Zpr7vpnEgF81PDJfHJc9D
ddJig61sGvpXhrtI+muivSni5Zk1PKz3KG9xnMOBuuIAc3H8AHnSqfLJGUId
377rG8kkKaHI5G1p20kCPyof2DuumibFa3rFo5e1Edx6Yey4Ix8PunSawzLn
QoZv3ezH10FPFWm+YzkPPvyvd5So2vCsia1X6mBiWkM0ucCThz47abmlczXg
pU+4Gj8l0GPX+MGjcQHY+uacvONcdC01zP7jCBd3ha7O5GcmGl7LXKn6TOCY
U9gT07fa6C5fFDbTN0oq2oQPhNsyYJXW6uJ0VBm5Vt9zLiRSIFEoOZGoSMDy
+UwrJVkLE/faU/sCtGEsHdwz3cTH1q2vKzrVtCGusDg/mMfHRKQSLSZ/Dji6
YoyeVcBSlyK/EHKC3CQxtkJ1Ex3Jk7GrK+IZKFielBuAMfLkz6DUnQwtmC1D
2Y0mLbit6JKkhAhgff3D4JiuITZzmyUEkTTo/g8j2f9lN/lyLJ9lItZAnT3p
PL5egLutZ8ul5WdI1S1pKd/vCXFxS55qy1EaljwZ1GvuYkOsre/HvcJAr/9m
2rI4ZVScGymxiOCiY7pEiHM8jIvaGAXFA6RabCglbqUsPP/QWltiJAsJi1sd
zx3EZNXlqwfebNNCgO/QU5GuAOWTW05cYEyR2zL+PO5BFaI27HhSu7oiMuwX
l1zOoyOLff56L/Unec/ok06UtQzes36+r7dhokZsz02IVEIcPYUwY2uAaihr
WDjMgFStNE3oSkAZvm53ZnU6N7F90RNtJmxfr7WjrhXgoSjeuuYXDdtGJIML
iqSRf6OWbvpFHcPnfS/HX1qAxSZDce4n6PjuzckX16tj5XQhczKRD92Dczf0
bNfD+7HR9JBryugi3H/4J/Hxoy3Vgng2QfaLKpTC1AiUlNPZ2Xf4sMsLtc0X
6mLHikU3aiaVkHxc5d3QJSHE8qW6FgfmwnvOoeb1ejTkVNWvkPw9QAY71FdI
XWIh2uz0/jPieWDU+kyGPtZG/YGN07qBDCzcs9tUbMrB82dpTel7ubgi1eAx
BBb+5m3eurqLC3XtcL8gcpKU8o8KMFuvjsnj0rZFzsMkNddEpewTA6rZLzfc
26CHWsn4WxVTKigdDPLou6MDmcQro8cfaULCmTnhFyGBPbuda0LTmMj9MlbS
m0tF4bFo8yxTJnxoD2ui2wm8d9cLfaExB1TPln2+rRxYRuxfdz2Dhq9FTUeD
ExRgoPzQy2dWr0Ur2s/fnVBBVZZ8rOcqCkL0NWlP2AQk/i98d1UbJestQBZT
KrZJhoEYJw+X7WV8IHwy1WxYCkXeUtpLViojYj9l7fJiGuqzn2Wd2izE4u9a
b9pPyeN+ZU2Nd7AG5BJur/bM/0QmdmKZqTYfnekDO178ZCPHTuackpwOKIVi
jfBn6iD+sVrfXNlLOn44qR73twZKx8ujQ4pGyEtjj7t/zfKpZ5354PzXqrht
usCLNTpE6t97dsfMnY6Wnwc4SdIMlAduFCUPfSUn79nLRjloAW3mw7cCdLDT
5XznGlUKspOSD1IbaZDgdCTsX9BP1tp2jGbMCJCWVcAc1lPGydQvse7EPNyU
97YLlWFCTmWk+vdnHThwzMWWdC3EHBUNLuumoLV6pMbdTg3X9gY5qN0Q4IjZ
5otLZvno/93fL1OkjJ00yzcL+d/IAF5c741qDgxYtKOJcfJoeDcTs24LATnr
bMLaSg/rOsJ/HXzDR/O7w0nC4V+k4wv21uCjAuzWuG7KNaJgjXEzb8CUhwcC
hcVHDnMwKSUyjPfnIPlTivIWydl5Lern/N7FgeQy+Yg+RRV0/jb2HvCb5daS
sjDDWW5OpL0KrbbmYW6I1WHKBwL717W0L47jIvWrp02BsiLkTkoN5CSOkBt/
u9b1Xp696w/JA5NlP0kZ8eqYEU8GfALGXtjPcmC1nF7WEbYKmrqu/hZd0IGi
kZP+mL8sDJrmbhrYMElyKGe6AyNVseZOwnrRdQ4e1h+MiElTA/HmP1eCV6vg
gqtC/I1BZYQZL9y7VfST7IqYOTbHThNe2+tadnfQwOu+5v92DxO6WQoKLr5C
xA+9CtvpRYAavFn/01oGVK7Jv9lVrILD73qq0+/r41x7x1wr0SwfrAb/pBP9
5IMav4RSDzWsZctc3FmniZtaf2anpshj/K5xRUjGL/LOsGwTw4UOCo3wz/2X
CwVWgskpOxpe/vNaySFVD/b7z+Wu/kaH3EDt/lN7lPFMw3t8PLuP/CVfvtHT
Vgmf3rt+DH5FoLMuPUkznw+3hZGLzSXnYVX506iLsipYKbNdQr2Qji+vmDFY
SuBi0N9nrhvR4amtltJjbIDG7UqOAkc6TA6dHl+iJkDlnOApZ102LnsFtQxE
6cA5nKXk3qby/7rT2ffUJsWOBcnSs3ox57SRMVIc86lYGW8cfEy29Aixg/D/
ErFLC7fParK+ZwkgG+Bs81iaQH7Oj2JG83zEG3ZxC83UUVp+o3VHJg8d2Zan
522QxqzNobItqLgOi1FuFB3TYitfIZVAd2r1Nf7jRjLwPWF69SEft/7dPXnP
SQW8RcGRGZ8FaE4aq3iSpoiXB7kPQ+5zEFWp53zisA5ynRUoblxt3PO0jCqc
9SE5bf3IlxPAxDx2q9Njqdn+5yUjjlNkfYnTHHfnWdqLNFyu7aBicN2Pdw6E
KjKC/9kUeG6ITFsRPZwZzUbWqrTR05paMBZ63Eoc4mMngsuoDt3k89b8/Ip0
NTS0HPjPm2Pa4E/Ns6z04aN0/a1i9V08DJ6/vcgkSQ4NlIKo5+4aSLT4+mHL
IwL7pBv7XffxcPRmSqV6MR/r1p4POBGvCZuR6k7beGX8tumtub+HB+uJaItR
M230qq9daKGjgVQ71Q2COAJJRb8++GpxsOfwgHAqncDIEjfLskYBukWi20uK
ZWBaQoZlvhWTrLqwnUlqDLyM8cp+3DxGisMtlrK9mEgo7G8S60pgRPSX+bJV
mkhbU77Y9hYfR7YG8MTLNXDY//EW+80CmF7Lz6t+qQqdKT5rPEQOyb9YXQaW
aihNVDxNHeahqbE4IlaKhmmW4knVY/PR9O2vNIVCeZChFvqHVHiIuDwS//CW
Oh7IfpGM6GOjR6fjincjDy/PmGcoFwiwsLmgajuPDt7yhMgyH0l8bYqfb981
y3vb+31mXT/Jpmd+Vi8amTAcr9XaTuEj9N3e3PkKFJw4VRmz6NTsn6dEmNYs
7CAf8QuG06q0Ee4hK4x2Y0K1uV6ywFIXz0oz3weVKkJ9tOGLgg0XCekN+z6O
MJAYML5aslAalXqSTg2P5LCySzcoeZsQGdv+SCyKZsHQ8Bw1aHbflp+8ar+4
M5HseaGrs4uP16+HMo2COfCmT6m4RbChKCSn5a3paMiT3vVFlYlozzwtioBA
aZxX/26rCbLAsiPWj05HTnh7S9tdARQDOdF7RQL8F8y1UMw=
         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.9150583855868508, 0.93387529121179, 0.9490653734202796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 78}], {
             RGBColor[
             0.9757984276619862, 0.9814710874935226, 0.9258511285739839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 88}], {
             RGBColor[
             0.877203408080281, 0.45311627232504803`, 0.41809202188969574`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 89}], {
             RGBColor[
             0.9646002901977704, 0.9731195349079778, 0.9448066543588934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[
             0.9887642492258122, 0.9884581632262459, 0.7547155751144388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 122}], {
             RGBColor[
             0.9893355117892959, 0.9896800360860326, 0.8168939797257662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 136}], {
             RGBColor[
             0.9812455112511466, 0.9640662151442884, 0.6429806322743363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 138}], {
             RGBColor[
             0.9887456993940893, 0.9884184870118664, 0.7526965404076975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 144}], {
             RGBColor[
             0.9822701963951539, 0.9675227187425386, 0.6469613405632525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 159}], {
             RGBColor[
             0.9651471829250291, 0.9735274066085127, 0.9438809076241119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 167}], {
             RGBColor[
             0.979768229616234, 0.9590829973075056, 0.6372416720839296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 197}], {
             RGBColor[
             0.9686638125913832, 0.9210076373794475, 0.5973193398460404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 26}], {
             RGBColor[
             0.9780629039698601, 0.9372558968512137, 0.4039101308955736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 40}], {
             RGBColor[
             0.9687282039015703, 0.906175030172407, 0.3330154066511168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 51}], {
             RGBColor[
             0.9754211587668997, 0.928751938513698, 0.35901627244444934`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 74}], {
             RGBColor[
             0.9741007953283931, 0.9242980425995369, 0.3538869098155645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 80}], {
             RGBColor[
             0.9199396760253363, 0.7103577381302923, 0.2648133630957115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 121}], {
             RGBColor[
             0.8951489994056866, 0.6041186835807704, 0.24082564116010646`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 158}], {
             RGBColor[
             0.8937371078569525, 0.8748171439759889, 0.6468710714192999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 164}], {
             RGBColor[
             0.9749571673736634, 0.9377997149463962, 0.5882652484495364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 166}], {
             RGBColor[
             0.9600746043014202, 0.927158764662723, 0.6339874653351201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 169}], {
             RGBColor[
             0.9786044244428043, 0.9393079494747172, 0.5278207600151446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 184}], {
             RGBColor[
             0.8762250616247991, 0.46461061277639837`, 0.22293702867845502`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 5}], {
             RGBColor[
             0.9660404872112219, 0.8907743787282172, 0.4359219419683845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 10}], {
             RGBColor[
             0.879687561696427, 0.826067777915412, 0.6258792652697942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 11}], {
             RGBColor[
             0.7021013981671075, 0.6846267696418569, 0.6100266483931729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 15}], {
             RGBColor[
             0.9469662606793319, 0.8791908485529646, 0.6141588551858672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 20}], {
             RGBColor[
             0.9613958924560203, 0.8761137550308755, 0.33227734118602587`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 28}], {
             RGBColor[
             0.9201493165668391, 0.7205855268734189, 0.2545805281244778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 48}], {
             RGBColor[
             0.9633050565406824, 0.8906334545478063, 0.5532355887044922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 63}], {
             RGBColor[
             0.9664661748787673, 0.8916848816054712, 0.4822554175409264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 77}], {
             RGBColor[
             0.9476222473048677, 0.8296520157303618, 0.27876933070843246`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 106}], {
             RGBColor[
             0.9653295899315648, 0.891470651133071, 0.5196838310931069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 186}], {
             RGBColor[
             0.9626933679902675, 0.8903805056125309, 0.5633728509840923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 189}], {
             RGBColor[
             0.9656864981021762, 0.8900172318177573, 0.3973924120163007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 41}], {
             RGBColor[
             0.9442096687518586, 0.8124366064190849, 0.2952185350458331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 66}], {
             RGBColor[
             0.8543767408281521, 0.3530189273742655, 0.19708725489445542`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 80}], {
             RGBColor[
             0.8977872843697169, 0.6246008719794558, 0.2362085121562703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 81}], {
             RGBColor[
             0.9558348046677918, 0.8532958436344724, 0.5094449763492159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 168}], {
             RGBColor[
             0.8384848541214918, 0.763165821464596, 0.6149768460973462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 172}], {
             RGBColor[
             0.9518239688148069, 0.8516372599354833, 0.5759149061436339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 173}], {
             RGBColor[
             0.904749090752208, 0.6562128087911567, 0.24201761405131078`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 184}], {
             RGBColor[
             0.8614568005210528, 0.40743936867584063`, 0.2038671280521609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 198}], {
             RGBColor[
             0.8811056162723031, 0.5502389410440791, 0.22236059648066808`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 9}], {
             RGBColor[
             0.9449616131014147, 0.8047731283967925, 0.41883565583126253`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.730195047169144, 0.7837142263406307, 0.7770198170321162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 15}], {
             RGBColor[
             0.9750599096813684, 0.9782783052517384, 0.7811520238248106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 17}], {
             RGBColor[
             0.958171494501699, 0.8595764448213342, 0.4295903657253039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 20}], {
             RGBColor[
             0.9894895414580568, 0.9752012117296494, 0.4992705098249691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 28}], {
             RGBColor[
             0.9482429655688756, 0.8196729835721928, 0.42157369676342105`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 48}], {
             RGBColor[
             0.9913987055427189, 0.9897209112465801, 0.7202287573434355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 63}], {
             RGBColor[
             0.9945598238808038, 0.990772338304245, 0.6492485861798696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[
             0.9757158963069041, 0.9287394724291357, 0.4457624993473758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 102}], {
             RGBColor[
             0.9938079113146716, 0.9891640733553106, 0.5674075436228607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 106}], {
             RGBColor[
             0.9934232389336013, 0.9905581078318448, 0.6866769997320502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 112}], {
             RGBColor[
             0.9944890077466606, 0.9906208697539226, 0.6415406870049191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 140}], {
             RGBColor[
             0.9897028736237745, 0.9890196411672041, 0.748333080912668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 189}], {
             RGBColor[
             0.9937801471042127, 0.9891046885165311, 0.564385580655244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 12}], {
             RGBColor[
             0.912277051307069, 0.6826825669832939, 0.24790014582508027`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 13}], {
             RGBColor[
             0.9269509984631364, 0.7352946592442609, 0.28869090021838895`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 14}], {
             RGBColor[
             0.9367722859489669, 0.7679772250682996, 0.48145082375051323`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 16}], {
             RGBColor[
             0.9250748770071602, 0.7289660610389868, 0.2814025226377299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 59}], {
             RGBColor[
             0.93368219244892, 0.7666993919942495, 0.5326616699519215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 64}], {
             RGBColor[
             0.9142510618576323, 0.6905088610162557, 0.24948848105004634`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 83}], {
             RGBColor[
             0.8675795457564772, 0.4915914695105614, 0.21121746586789983`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 86}], {
             RGBColor[
             0.9315437237897969, 0.7507870001942748, 0.3065327708490614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 124}], {
             RGBColor[
             0.9297827018382585, 0.7448466596441186, 0.299691533108426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 137}], {
             RGBColor[
             0.8773096910481479, 0.5357737867468682, 0.21933653760695598`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 161}], {
             RGBColor[
             0.9242227853070679, 0.7260917556539297, 0.2780923072868866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 175}], {
             RGBColor[
             0.866552797920896, 0.4869292473922367, 0.21036072230599842`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 176}], {
             RGBColor[
             0.9322998944352187, 0.7661277762421455, 0.5555699253115407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 186}], {
             RGBColor[
             0.9332797116573119, 0.766532955843635, 0.539331818255768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 187}], {
             RGBColor[
             0.9327863432691721, 0.7549786474791361, 0.3113601128774356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 193}], {
             RGBColor[
             0.935972260940757, 0.7676463941676999, 0.49470930853490486`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 199}], {
             RGBColor[
             0.9324119636018955, 0.7661741197226125, 0.5537126491940005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 18}], {
             RGBColor[
             0.9886647070670569, 0.9727988791169949, 0.46375139115590847`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 42}], {
             RGBColor[
             0.9883113509431135, 0.9716069259389707, 0.46237866934009353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 47}], {
             RGBColor[
             0.9729014938780982, 0.9762396543517949, 0.750773649206397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.9895763561909825, 0.9758740856773895, 0.467292975851868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 58}], {
             RGBColor[
             0.9104083438272257, 0.926837010091569, 0.7596415292235381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.9655533589744547, 0.9707594273721243, 0.7632121248977437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 73}], {
             RGBColor[
             0.9861822443956508, 0.9861444163425526, 0.7282928027546651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 88}], {
             RGBColor[
             0.8805585468792552, 0.45357125956845556`, 0.29242515864846486`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 94}], {
             RGBColor[
             0.9464621340860617, 0.8123261309568754, 0.38683378115716816`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 97}], {
             RGBColor[
             0.9872308028971888, 0.9679619836553199, 0.4581809442260522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 115}], {
             RGBColor[
             0.9907477964532208, 0.9889205355415676, 0.6924027865632497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 153}], {
             RGBColor[
             0.9932001748322499, 0.9878641864709943, 0.5012591780260622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 160}], {
             RGBColor[
             0.8760521253377662, 0.4189329288740612, 0.28810980429106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 188}], {
             RGBColor[
             0.8847286324296482, 0.4856243644519167, 0.2964184372809593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 55}], {
             RGBColor[
             0.8655527611981103, 0.4823883141985777, 0.20952626715136285`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 62}], {
             RGBColor[
             0.8674589312212018, 0.6163004179818913, 0.4678214084862351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 68}], {
             RGBColor[
             0.9047739938186069, 0.6382708825728924, 0.27381499786153596`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 75}], {
             RGBColor[
             0.8517112085084929, 0.6037436113513228, 0.4663193766357389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 96}], {
             RGBColor[
             0.8179707951882927, 0.577340424454975, 0.4629683678318515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 99}], {
             RGBColor[
             0.7310230883028648, 0.5076177656755937, 0.45553184261353263`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 107}], {
             RGBColor[
             0.905535494045487, 0.6451113032415247, 0.4114293444696816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 147}], {
             RGBColor[
             0.8930107947650677, 0.6363907755105155, 0.4604119407609213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 156}], {
             RGBColor[
             0.8737301719773939, 0.5195200266644936, 0.21634969915227745`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 157}], {
             RGBColor[
             0.8494138639890778, 0.601911771191297, 0.46610025386461346`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 179}], {
             RGBColor[
             0.7373703155014547, 0.5127707306547358, 0.45603151958926497`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 185}], {
             RGBColor[
             0.8695144560655678, 0.5003774453143576, 0.21283200245879674`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 194}], {
             RGBColor[
             0.8648157694439861, 0.4790418067718967, 0.20891130316640058`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.6810225240573003, 0.5986255193104322, 0.592940362256051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 17}], {
             RGBColor[
             0.9089989713898554, 0.6744877377911358, 0.2455109109492386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 20}], {
             RGBColor[
             0.9403170183462131, 0.7901125046994508, 0.3151910550489039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 28}], {
             RGBColor[
             0.8990704424570319, 0.6345842765419943, 0.2374942419873558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 63}], {
             RGBColor[
             0.94538730076896, 0.8056836312740466, 0.46516913140380434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 77}], {
             RGBColor[
             0.9265433731950605, 0.7436507653989373, 0.2616830445713105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 97}], {
             RGBColor[
             0.9383661598853249, 0.7835318010275253, 0.30761233831706086`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 102}], {
             RGBColor[
             0.944635388202828, 0.8040753663251121, 0.3833280888467955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.9442507158217576, 0.8054694008016463, 0.502597544955985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 112}], {
             RGBColor[
             0.945316484634817, 0.8055321627237242, 0.4574612322288538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 140}], {
             RGBColor[
             0.9405303505119309, 0.8039309341370057, 0.5642536261366028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 189}], {
             RGBColor[
             0.944607623992369, 0.8040159814863326, 0.3803061258791788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 14}], {
             RGBColor[
             0.9079266657691641, 0.9262056307231641, 0.8624423484191905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.8887069841665735, 0.9135717044389331, 0.9711093471262202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 28}], {
             RGBColor[
             0.8618900400540808, 0.7549663827593875, 0.6115310200648306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 48}], {
             RGBColor[
             0.9050457800279241, 0.9250143104337748, 0.9101860806448451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 59}], {
             RGBColor[
             0.9048365722691172, 0.9249277976491139, 0.9136531946205988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 77}], {
             RGBColor[
             0.8893629707921094, 0.8640328716163304, 0.6357198226487853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 186}], {
             RGBColor[
             0.9044340914775091, 0.9247613614984995, 0.9203233429244453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 193}], {
             RGBColor[
             0.9071266407609542, 0.9258747998225643, 0.875700833203582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 15}], {
             RGBColor[
             0.7111208206372539, 0.7721306961653781, 0.9552567302495989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 17}], {
             RGBColor[
             0.6942324054575846, 0.6534288357349739, 0.6036950721500922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 20}], {
             RGBColor[
             0.7255504524139424, 0.769053602643289, 0.6733752162497575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 28}], {
             RGBColor[
             0.6843038765247612, 0.6135253744858324, 0.5956784031882094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 48}], {
             RGBColor[
             0.7274596164986045, 0.7835733021602198, 0.8943334637682239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 63}], {
             RGBColor[
             0.7306207348366893, 0.7846247292178847, 0.8233532926046581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 77}], {
             RGBColor[
             0.7117768072627898, 0.7225918633427754, 0.6198672057721641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 106}], {
             RGBColor[
             0.7294841498894868, 0.7844104987454845, 0.8607817061568386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 112}], {
             RGBColor[
             0.7305499187025462, 0.7844732606675623, 0.8156453934297074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 140}], {
             RGBColor[
             0.7257637845796601, 0.7828720320808438, 0.9224377873374565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 189}], {
             RGBColor[
             0.7298410580600982, 0.7829570794301708, 0.7384902870800324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 13}], {
             RGBColor[
             0.9601085242269312, 0.8739854037359032, 0.31574433817067676`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 14}], {
             RGBColor[
             0.9699298117127617, 0.9066679695599418, 0.508504261702801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.958232402770955, 0.8676568055306291, 0.3084559605900178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 23}], {
             RGBColor[
             0.8963868545278182, 0.8512412755921583, 0.6301273703431451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 25}], {
             RGBColor[
             0.9521739760430943, 0.8951257771756574, 0.6146933510775572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 59}], {
             RGBColor[
             0.9668397182127147, 0.9053901364858918, 0.5597151079042093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.947408587621427, 0.8291996055078981, 0.27654191900233416`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 86}], {
             RGBColor[
             0.9647012495535916, 0.889477744685917, 0.33358620880134926`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 87}], {
             RGBColor[
             0.933066360333876, 0.7723374535766836, 0.26500182627142777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 95}], {
             RGBColor[
             0.931271629620334, 0.8790574483289364, 0.6334547113334756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 108}], {
             RGBColor[
             0.947545472303124, 0.8297423076567109, 0.27665205963032413`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 154}], {
             RGBColor[
             0.862247329218389, 0.38029710792674776`, 0.20325873962830626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 161}], {
             RGBColor[
             0.9573803110708625, 0.8647825001455719, 0.3051457452391745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 175}], {
             RGBColor[
             0.8886578150967591, 0.5793897437199982, 0.22839634760752364`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 193}], {
             RGBColor[
             0.9691297867045517, 0.9063371386593422, 0.5217627464871927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 16}], {
             RGBColor[
             0.9729063499270223, 0.920268897791596, 0.34924671498332643`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 64}], {
             RGBColor[
             0.9620825347774944, 0.881811697768865, 0.31733267339564286`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 69}], {
             RGBColor[
             0.9797561713221797, 0.9433749537720095, 0.3758569776232823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 82}], {
             RGBColor[
             0.9463162532531815, 0.9319651079507428, 0.6742808211800464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 83}], {
             RGBColor[
             0.8994671943697186, 0.6191266940123009, 0.25644692743163083`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 86}], {
             RGBColor[
             0.979375196709659, 0.9420898369468841, 0.37437696319465785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 101}], {
             RGBColor[
             0.9646215140822716, 0.8918779046476091, 0.31937559574177066`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 108}], {
             RGBColor[
             0.9622194194591915, 0.882354399917678, 0.3174428140236327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 110}], {
             RGBColor[
             0.921414670669894, 0.7101554877773545, 0.284071252599895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 124}], {
             RGBColor[
             0.9776141747581206, 0.9361494963967278, 0.36753572545402247`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 127}], {
             RGBColor[
             0.826371308220865, 0.8374721905477376, 0.6625357409959118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 137}], {
             RGBColor[
             0.92514116396801, 0.7270766234994774, 0.28718072995255245`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 161}], {
             RGBColor[
             0.97205425822693, 0.917394592406539, 0.34593649963248313`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 175}], {
             RGBColor[
             0.8984404465341373, 0.6144644718939762, 0.2555901838697294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 176}], {
             RGBColor[
             0.9801313673550808, 0.9574306129947547, 0.6234141176571372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 187}], {
             RGBColor[
             0.9806178161890342, 0.9462814842317454, 0.37920430522303206`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 199}], {
             RGBColor[
             0.9802434365217576, 0.9574769564752218, 0.6215568415395971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 15}], {
             RGBColor[
             0.9752053647520689, 0.9793287013607167, 0.8507219383352637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 48}], {
             RGBColor[
             0.9915441606134194, 0.9907713073555584, 0.7897986718538885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 59}], {
             RGBColor[
             0.9913349528546127, 0.9906847945708975, 0.7932657858296424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 186}], {
             RGBColor[
             0.9909324720630046, 0.990518358420283, 0.7999359341334887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 193}], {
             RGBColor[
             0.9936250213464497, 0.9916317967443479, 0.7553134244126256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 28}], {
             RGBColor[
             0.9291687390369855, 0.8080894533969403, 0.5998106099809039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 48}], {
             RGBColor[
             0.9723244790108287, 0.9781373810713274, 0.8984656705609182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 59}], {
             RGBColor[
             0.972115271252022, 0.9780508682866667, 0.901932784536672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 63}], {
             RGBColor[
             0.9754855973489136, 0.9791888081289926, 0.8274854993973524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 77}], {
             RGBColor[
             0.9566416697750141, 0.9171559422538831, 0.6239994125648585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 106}], {
             RGBColor[
             0.9743490124017111, 0.9789745776565922, 0.8649139129495329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.9754147812147705, 0.97903733957867, 0.8197776002224018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 140}], {
             RGBColor[
             0.9706286470918843, 0.9774361109919516, 0.9265699941301508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 193}], {
             RGBColor[
             0.974405339743859, 0.978997870460117, 0.8639804231196553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 64}], {
             RGBColor[
             0.9602064133215182, 0.8754830995635909, 0.31004429581498383`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 83}], {
             RGBColor[
             0.8982164467324011, 0.6149076285421182, 0.25158800904452483`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 86}], {
             RGBColor[
             0.9774990752536827, 0.93576123874161, 0.36708858561399893`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 101}], {
             RGBColor[
             0.9627453926262954, 0.885549306442335, 0.3120872181611117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 124}], {
             RGBColor[
             0.9757380533021445, 0.9298208981914537, 0.3602473478733635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 127}], {
             RGBColor[
             0.8244951867648889, 0.8311435923424635, 0.6552473634152529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 137}], {
             RGBColor[
             0.9232650425120339, 0.7207480252942033, 0.27989235237189347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 161}], {
             RGBColor[
             0.9701781367709538, 0.9110659942012649, 0.33864812205182415`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 175}], {
             RGBColor[
             0.8971896988968199, 0.6102454064237935, 0.2507312654826234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 176}], {
             RGBColor[
             0.9782552458991045, 0.9511020147894806, 0.6161257400764781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.978741694733058, 0.9399528860264713, 0.37191592764237313`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 193}], {
             RGBColor[
             0.981927612404643, 0.952620632715035, 0.5552651232998423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 199}], {
             RGBColor[
             0.9783673150657813, 0.9511483582699477, 0.6142684639589382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 20}], {
             RGBColor[
             0.9535268997464974, 0.8449158211239924, 0.32594576494294525`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 28}], {
             RGBColor[
             0.9122803238573163, 0.6893875929665361, 0.24824895188139715`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 77}], {
             RGBColor[
             0.9397532545953449, 0.7984540818234789, 0.27243775446535184`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 106}], {
             RGBColor[
             0.9574605972220418, 0.860272717226188, 0.5133522548500262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 112}], {
             RGBColor[
             0.9585263660351013, 0.8603354791482658, 0.46821594212289513`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 140}], {
             RGBColor[
             0.9537402319122151, 0.8587342505615474, 0.5750083360306442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 189}], {
             RGBColor[
             0.9578175053926532, 0.8588192979108743, 0.3910608357732201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 47}], {
             RGBColor[
             0.9680478249318563, 0.9604937468466064, 0.6786316274891255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 54}], {
             RGBColor[
             0.9847226872447405, 0.9601281781722011, 0.39515095413459655`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 58}], {
             RGBColor[
             0.9055546748809838, 0.9110911025863806, 0.6874995075062666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 61}], {
             RGBColor[
             0.9606996900282128, 0.9550135198669356, 0.6910701031804722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 73}], {
             RGBColor[
             0.981328575449409, 0.970398508837364, 0.6561507810373937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 94}], {
             RGBColor[
             0.9416084651398199, 0.796580223451687, 0.3146917594398967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 115}], {
             RGBColor[
             0.9858941275069788, 0.9731746280363789, 0.6202607648459783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 116}], {
             RGBColor[
             0.977858022895417, 0.967810176425105, 0.6620255212462276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 153}], {
             RGBColor[
             0.9883465058860079, 0.9721182789658056, 0.42911715630879077`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 160}], {
             RGBColor[
             0.8728163460402717, 0.4084356572039355, 0.24001512314621232`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 174}], {
             RGBColor[
             0.9806464561640573, 0.9463780935924843, 0.37931556611779127`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 188}], {
             RGBColor[
             0.8814928531321536, 0.475127092781791, 0.24832375613611163`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 33}], {
             RGBColor[
             0.9758241621118859, 0.9381346757577788, 0.5737340298633902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 34}], {
             RGBColor[
             0.8824903550622925, 0.5127912967194763, 0.22892114404885872`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 44}], {
             RGBColor[
             0.9778875825346032, 0.9368710748344407, 0.38566310831002376`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 50}], {
             RGBColor[
             0.973638891716426, 0.9227399332562465, 0.3520925015062507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 60}], {
             RGBColor[
             0.9604888962912701, 0.8783819109214386, 0.30100725244778526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 90}], {
             RGBColor[
             0.9753258789529131, 0.9284305373283572, 0.35864612835919485`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 130}], {
             RGBColor[
             0.9741113614779392, 0.9374263886786733, 0.6021195689538394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 141}], {
             RGBColor[
             0.9737391492415799, 0.9230781254301766, 0.35248198305942824`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 177}], {
             RGBColor[
             0.9549725848062827, 0.9233327684800366, 0.6425794477226665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.9435983708136739, 0.8050123598748511, 0.3179290959810624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 77}], {
             RGBColor[
             0.9710713015517025, 0.9140788487317939, 0.34211789856501706`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 106}], {
             RGBColor[
             0.9887786441783997, 0.9758974841345032, 0.5830323989496915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 189}], {
             RGBColor[
             0.9891355523490111, 0.9744440648191894, 0.4607409798728853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.8824272199666662, 0.46539676808297037`, 0.34357123764043274`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 46}], {
             RGBColor[
             0.9811929751973109, 0.946747932587897, 0.5067513326333408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 85}], {
             RGBColor[
             0.9907287968423566, 0.9900966845514974, 0.7787823846546166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 109}], {
             RGBColor[
             0.9950483737975644, 0.9918172971762227, 0.7024242296386799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 132}], {
             RGBColor[
             0.9747638849241493, 0.9246689614927337, 0.48381780264330154`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 150}], {
             RGBColor[
             0.991582328267325, 0.9904496417304788, 0.7646371600743707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 151}], {
             RGBColor[
             0.9939591858929654, 0.9894876343820749, 0.5838728479116523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 194}], {
             RGBColor[
             0.9100529475276882, 0.6583859427666336, 0.3692678007583975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 196}], {
             RGBColor[
             0.994045049260784, 0.9896712874437208, 0.5932185456114312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 24}], {
             RGBColor[
             0.962462856518594, 0.8833636505045934, 0.3174089960277927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 37}], {
             RGBColor[
             0.9691725342661297, 0.907673860825797, 0.3347415462126816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 38}], {
             RGBColor[
             0.9659098143808802, 0.9468422984332233, 0.6566561546068614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 79}], {
             RGBColor[
             0.8536088415529867, 0.8585570681248831, 0.6649682614520576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 89}], {
             RGBColor[
             0.9601904749214822, 0.9425768244289632, 0.6663375044689888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 118}], {
             RGBColor[
             0.9745634139810303, 0.9258585639429073, 0.3556840959228581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 119}], {
             RGBColor[
             0.981395885966466, 0.9577328149966251, 0.6009322398252235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 122}], {
             RGBColor[
             0.9849256965130079, 0.9591373256070181, 0.5384248298358615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 128}], {
             RGBColor[
             0.9791842518843632, 0.9414457352151846, 0.3736351786052887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 138}], {
             RGBColor[
             0.9843358841178013, 0.9578757765328518, 0.47422739051779284`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 144}], {
             RGBColor[
             0.9778603811188659, 0.936980008263524, 0.3684921906733478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 149}], {
             RGBColor[
             0.9767397209209014, 0.9549192249984269, 0.6383239477266067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 181}], {
             RGBColor[
             0.9687512722004574, 0.9489614530226038, 0.6518463076892069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 183}], {
             RGBColor[
             0.900948435369117, 0.6259107062297671, 0.2575312639834115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 190}], {
             RGBColor[
             0.7808498367131522, 0.8008701675908314, 0.658295431210804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 192}], {
             RGBColor[
             0.9849256965130079, 0.9591373256070181, 0.5384248298358615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 25}], {
             RGBColor[
             0.9031262535000486, 0.9249937412928797, 0.9698671376433342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 43}], {
             RGBColor[
             0.9140546802630503, 0.9139524232967678, 0.6825487776699792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 49}], {
             RGBColor[
             0.9199908136794568, 0.9338903031047612, 0.7129301837592534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 64}], {
             RGBColor[
             0.8983608650783814, 0.8590675696251203, 0.6317157055681112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 67}], {
             RGBColor[
             0.8796102714824277, 0.906841370368065, 0.9883792070029949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 87}], {
             RGBColor[
             0.8840186377908303, 0.8022054176939059, 0.6201756128372048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 95}], {
             RGBColor[
             0.8822239070772885, 0.9089254124461588, 0.9886284978992528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 103}], {
             RGBColor[
             0.9169529430916041, 0.9349111307994166, 0.9287941670869897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 108}], {
             RGBColor[
             0.8984977497600785, 0.8596102717739331, 0.6318258461961012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 129}], {
             RGBColor[
             0.9120520584275524, 0.9316505919931479, 0.954758078123835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 131}], {
             RGBColor[
             0.9095417651305276, 0.9297784193624548, 0.9590073498863487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 143}], {
             RGBColor[
             0.9195432320191325, 0.9359822818383385, 0.8858663761049854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 154}], {
             RGBColor[
             0.8295488475230253, 0.4002090840048961, 0.44004126400549104`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 162}], {
             RGBColor[
             0.8868614321784342, 0.8134761501356824, 0.6224629919304314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.9435174487154405, 0.8964880738516285, 0.6354124465734421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 37}], {
             RGBColor[
             0.9570020617209236, 0.8649431073964585, 0.2961948394234111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 56}], {
             RGBColor[
             0.9144783100614342, 0.8733599622741365, 0.6335756312734624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 79}], {
             RGBColor[
             0.8414383690077805, 0.8158263146955446, 0.6264215546627872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 89}], {
             RGBColor[
             0.9480200023762761, 0.8998460709996248, 0.6277907976797183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 118}], {
             RGBColor[
             0.9623929414358241, 0.8831278105135689, 0.31713738913358763`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 119}], {
             RGBColor[
             0.9692254134212599, 0.9150020615672867, 0.562385533035953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 125}], {
             RGBColor[
             0.9310868974767353, 0.8866031990510022, 0.6351597731677949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 144}], {
             RGBColor[
             0.9656899085736597, 0.8942492548341856, 0.3299454838840773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 149}], {
             RGBColor[
             0.9645692483756954, 0.9121884715690883, 0.5997772409373363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 170}], {
             RGBColor[
             0.9725433792203735, 0.9159534576837203, 0.47682012964327175`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 190}], {
             RGBColor[
             0.7686793641679461, 0.7581394141614929, 0.6197487244215336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 195}], {
             RGBColor[
             0.9274184398516241, 0.7499453309224857, 0.26045737687767523`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 197}], {
             RGBColor[
             0.952083524769889, 0.8477341734710945, 0.28030348316686515`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[
             0.9698418017783265, 0.957836924880267, 0.6671147584043913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 49}], {
             RGBColor[
             0.9757779351947329, 0.9777748046882603, 0.6974961644936655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 64}], {
             RGBColor[
             0.9541479865936575, 0.9029520712086194, 0.6162816863025232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 67}], {
             RGBColor[
             0.9353973929977039, 0.9507258719515641, 0.9729451877374069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 87}], {
             RGBColor[
             0.9398057593061064, 0.846089919277405, 0.6047415935716168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 95}], {
             RGBColor[
             0.9380110285925647, 0.9528099140296578, 0.9731944786336648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 103}], {
             RGBColor[
             0.9727400646068802, 0.9787956323829157, 0.9133601478214017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 108}], {
             RGBColor[
             0.9542848712753547, 0.9034947733574322, 0.6163918269305132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 129}], {
             RGBColor[
             0.9678391799428285, 0.9755350935766469, 0.939324058858247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 131}], {
             RGBColor[
             0.9653288866458039, 0.9736629209459539, 0.9435733306207608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 143}], {
             RGBColor[
             0.9753303535344087, 0.9798667834218375, 0.8704323568393975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 154}], {
             RGBColor[
             0.8667402618665427, 0.4294654183938954, 0.42975191782843236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 162}], {
             RGBColor[
             0.9426485536937104, 0.8573606517191814, 0.6070289726648435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 40}], {
             RGBColor[
             0.9838281989665503, 0.9567035906306894, 0.42630721327310994`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 51}], {
             RGBColor[
             0.9905211538318797, 0.9792804989719803, 0.45230807906644244`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 74}], {
             RGBColor[
             0.989200790393373, 0.9748266030578192, 0.4471787164375576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 80}], {
             RGBColor[
             0.9350396710903164, 0.7608862985885748, 0.3581051697177046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 121}], {
             RGBColor[
             0.9052156627823399, 0.6378043905529587, 0.30302017890810184`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 158}], {
             RGBColor[
             0.9088371029219324, 0.9253457044342713, 0.740162878041293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 164}], {
             RGBColor[
             0.9900571624386434, 0.9883282754046787, 0.6815570550715295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.9751745993664003, 0.9776873251210054, 0.7272792719571133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 169}], {
             RGBColor[
             0.9937044195077843, 0.9898365099329997, 0.6211125666371377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 184}], {
             RGBColor[
             0.8862917250014524, 0.49829631974858674`, 0.28513156642645043`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 37}], {
             RGBColor[
             0.9502271264629764, 0.920798284172832, 0.6527449967583311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 56}], {
             RGBColor[
             0.9077033748034868, 0.92921513905051, 0.9901257886083824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 67}], {
             RGBColor[
             0.9243119622187881, 0.9424583758273757, 0.9917099305027148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 119}], {
             RGBColor[
             0.9624504781633126, 0.9708572383436602, 0.918935690370873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 125}], {
             RGBColor[
             0.9243119622187881, 0.9424583758273757, 0.9917099305027148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 128}], {
             RGBColor[
             0.9602388440812099, 0.9545701585622197, 0.6916386291509382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 133}], {
             RGBColor[
             0.9296507967924734, 0.8415114197648934, 0.6242550129440685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 190}], {
             RGBColor[
             0.7619044289099988, 0.8139945909378664, 0.9762988817564535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 195}], {
             RGBColor[
             0.9206435045936768, 0.8058005076988592, 0.6170075342125952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 48}], {
             RGBColor[
             0.9455075348983362, 0.8195320593917819, 0.5388873434995287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 63}], {
             RGBColor[
             0.9486686532364209, 0.8205834864494469, 0.4679071723359629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 77}], {
             RGBColor[
             0.9298247256625214, 0.7585506205743375, 0.264421085503469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 106}], {
             RGBColor[
             0.9475320682892184, 0.8203692559770466, 0.5053355858881434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 112}], {
             RGBColor[
             0.9485978371022779, 0.8204320178991245, 0.4601992731610123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 140}], {
             RGBColor[
             0.9438117029793918, 0.8188307893124059, 0.5669916670687614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 189}], {
             RGBColor[
             0.9478889764598298, 0.8189158366617328, 0.38304416681133724`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 35}], {
             RGBColor[
             0.9110536466700507, 0.9308885634847988, 0.9558443518032307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 47}], {
             RGBColor[
             0.8994742116501115, 0.9222526398065127, 0.9754453148916503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 88}], {
             RGBColor[
             0.8316070253939307, 0.41757991653826737`, 0.4422062691053005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 89}], {
             RGBColor[
             0.896205716168245, 0.9198150012278068, 0.9809780251823006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 113}], {
             RGBColor[
             0.9203696751962868, 0.935153629546075, 0.7908869459378458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 122}], {
             RGBColor[
             0.9209409377597706, 0.9363755024058616, 0.8530653505491732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 136}], {
             RGBColor[
             0.9128509372216211, 0.9107616814641174, 0.6791520030977434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 138}], {
             RGBColor[
             0.920351125364564, 0.9351139533316954, 0.7888679112311046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 142}], {
             RGBColor[
             0.5127954057786627, 0.5929823787658095, 0.9593688721218434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 144}], {
             RGBColor[
             0.9138756223656286, 0.9142181850623676, 0.6831327113866595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 153}], {
             RGBColor[
             0.9197728926042632, 0.933877171925712, 0.7259308437113157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 159}], {
             RGBColor[
             0.8967526088955037, 0.9202228729283417, 0.980052278447519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 167}], {
             RGBColor[
             0.9113736555867087, 0.9057784636273346, 0.6734130429073367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 181}], {
             RGBColor[
             0.9047665134472201, 0.9261996298214474, 0.9664868284025188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 188}], {
             RGBColor[
             0.8357771109443237, 0.44963302142172856`, 0.4461995477377949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 41}], {
             RGBColor[
             0.9793155001184706, 0.9496624972168737, 0.5855741946963414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 65}], {
             RGBColor[
             0.991267074805541, 0.9892612100210688, 0.6929514751958381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 66}], {
             RGBColor[
             0.8777806284058933, 0.44450285457279126`, 0.39065769466146094`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 90}], {
             RGBColor[
             0.9882872801873954, 0.979926418063495, 0.6204278660856124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 110}], {
             RGBColor[
             0.9284583291418271, 0.7416894326223371, 0.5228636771657597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 162}], {
             RGBColor[
             0.9576267603494804, 0.8677542231244096, 0.5468723843238277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 180}], {
             RGBColor[
             0.970617969027979, 0.9192600364709946, 0.557325415769408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 198}], {
             RGBColor[
             0.9045095038500444, 0.6417228682426049, 0.41593103624767364`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 38}], {
             RGBColor[
             0.9394244139638337, 0.8473576261589721, 0.606591320837365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[
             0.9480780135639838, 0.8263738916686563, 0.30561926215336166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 46}], {
             RGBColor[
             0.9445788195690257, 0.8145702886738407, 0.29202555425028803`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 80}], {
             RGBColor[
             0.8992894856877498, 0.6305565996265416, 0.2374172185979564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 98}], {
             RGBColor[
             0.9550595367020364, 0.8499242085528949, 0.3327411611946779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 117}], {
             RGBColor[
             0.9339421894483376, 0.7758098241627729, 0.2657065389352752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 120}], {
             RGBColor[
             0.957150083599662, 0.8568930192636761, 0.3479283281127328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 121}], {
             RGBColor[
             0.8813822058472955, 0.5509179245782698, 0.22256154482826973`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 146}], {
             RGBColor[
             0.9533939102766662, 0.8576209998728836, 0.5760009830962427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 151}], {
             RGBColor[
             0.9573450302646802, 0.8573099904680186, 0.36914706952859944`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 171}], {
             RGBColor[
             0.958324019889028, 0.8594039502834644, 0.47570404851524084`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 173}], {
             RGBColor[
             0.9062512920702408, 0.6621685364382426, 0.2432263204929969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 178}], {
             RGBColor[
             0.8543233129380035, 0.3488810238969123, 0.19688289012854032`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 196}], {
             RGBColor[
             0.9574308936324988, 0.8574936435296645, 0.3784927672283783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 53}], {
             RGBColor[
             0.9894635478177944, 0.9883589081507906, 0.711464896763182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 82}], {
             RGBColor[
             0.9516470880783126, 0.9627907562002129, 0.9414591662189267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 83}], {
             RGBColor[
             0.9030210842531394, 0.6396771261786143, 0.43456582412421774`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 100}], {
             RGBColor[
             0.9770067941001136, 0.982164259086258, 0.9144898447868619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 101}], {
             RGBColor[
             0.9699523489074029, 0.9227035528970791, 0.586553940780651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 123}], {
             RGBColor[
             0.875235707694182, 0.4332462898031554, 0.40823809060155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 127}], {
             RGBColor[
             0.8317021430459962, 0.8682978387972076, 0.9297140860347921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 130}], {
             RGBColor[
             0.9853599390656195, 0.9882139728182986, 0.8922872271532727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 135}], {
             RGBColor[
             0.9691983858490183, 0.9197143406138792, 0.5859472844060871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 148}], {
             RGBColor[
             0.9890163589697696, 0.9874024164225933, 0.6627911503853325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 163}], {
             RGBColor[
             0.9489851433208493, 0.8395755696534668, 0.5696832350021398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 165}], {
             RGBColor[
             0.6894088216479326, 0.751695440726869, 0.9185890861263786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 176}], {
             RGBColor[
             0.985462202180212, 0.9882562612442247, 0.8905924626960176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 187}], {
             RGBColor[
             0.9859486510141654, 0.9771071324812155, 0.6463826502619124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 41}], {
             RGBColor[
             0.9792312751379739, 0.949627668022955, 0.5869700205904345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 44}], {
             RGBColor[
             0.9907647587885887, 0.9883321263756598, 0.6488406719305344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 57}], {
             RGBColor[
             0.9636379962011312, 0.9716526926854434, 0.9128864306454914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 66}], {
             RGBColor[
             0.8777244784188954, 0.44447963511017885`, 0.391588245257523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 90}], {
             RGBColor[
             0.9882030552068988, 0.9798915888695764, 0.6218236919797054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 141}], {
             RGBColor[
             0.9866163254955655, 0.9745391769713958, 0.6156595466799388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 198}], {
             RGBColor[
             0.9044533538630466, 0.6416996487799925, 0.4168615868437357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 44}], {
             RGBColor[
             0.892450752846761, 0.5462562637980636, 0.27899223876028817`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 50}], {
             RGBColor[
             0.8896182923013096, 0.5368355027459342, 0.25661183422443945`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 60}], {
             RGBColor[
             0.8808516286845389, 0.5072634878560622, 0.22255500151879584`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 90}], {
             RGBColor[
             0.8907429504589677, 0.5406292387940079, 0.26098091879306884`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 104}], {
             RGBColor[
             0.8660155902290179, 0.44885119485704206`, 0.20849449912277498`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 130}], {
             RGBColor[
             0.8899332721423183, 0.5466264730275521, 0.4232965458561653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 163}], {
             RGBColor[
             0.8656834083124716, 0.44753420425099744`, 0.20822721775541006`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 177}], {
             RGBColor[
             0.8771740876945473, 0.5372307262284609, 0.4502697983687166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 47}], {
             RGBColor[
             0.963864046762837, 0.9725704457596924, 0.9460529224511943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 68}], {
             RGBColor[
             0.9814760782275161, 0.9753661686920726, 0.6662129742818446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 88}], {
             RGBColor[
             0.8745335821357476, 0.4511251205070539, 0.4226113408116632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.9374246869708005, 0.8086569223647729, 0.5821130544019655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 111}], {
             RGBColor[
             0.9244110855378193, 0.7495651976614404, 0.571254186373725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 116}], {
             RGBColor[
             0.9736742447263975, 0.9798868753381911, 0.9294468162082965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 122}], {
             RGBColor[
             0.9853307728724959, 0.9866933083590412, 0.8236729581087172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 138}], {
             RGBColor[
             0.9847409604772893, 0.985431759284875, 0.7594755187906486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 142}], {
             RGBColor[
             0.5771852408913881, 0.6433001847189892, 0.9299764796813874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 153}], {
             RGBColor[
             0.9841627277169885, 0.9841949778788917, 0.6965384512708597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 157}], {
             RGBColor[
             0.8984358834832225, 0.9208275016196794, 0.9546408582864608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 160}], {
             RGBColor[
             0.8700271605942588, 0.4164867898126595, 0.41829598645425825`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 167}], {
             RGBColor[
             0.975763490699434, 0.9560962695805142, 0.6440206504668807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 174}], {
             RGBColor[
             0.9764626779950379, 0.9584547925055702, 0.6467368610798602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 181}], {
             RGBColor[
             0.9691563485599455, 0.9765174357746271, 0.9370944359620628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 185}], {
             RGBColor[
             0.9285867715979573, 0.7685260128042701, 0.5747384811777357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 188}], {
             RGBColor[
             0.8787036676861407, 0.483178225390515, 0.4266046194441575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 132}], {
             RGBColor[
             0.8690092502585807, 0.4208558442690981, 0.20926471137318312`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 151}], {
             RGBColor[
             0.8818061175711247, 0.4640682928619922, 0.2759680748854169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 169}], {
             RGBColor[
             0.8822122534648165, 0.4655328398639574, 0.3634864388779436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 200}], {
             RGBColor[
             0.8717533452502786, 0.4588461530488816, 0.43105767781282434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 56}], {
             RGBColor[
             0.9211879878089699, 0.89767017259534, 0.6509081814583514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 79}], {
             RGBColor[
             0.8481480467553164, 0.8401365250167481, 0.643754104847676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 118}], {
             RGBColor[
             0.96910261918336, 0.9074380208347724, 0.3344699393184766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 119}], {
             RGBColor[
             0.9759350911687957, 0.9393122718884901, 0.579718083220842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 125}], {
             RGBColor[
             0.9377965752242712, 0.9109134093722057, 0.6524923233526838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 128}], {
             RGBColor[
             0.973723457086693, 0.9230251921070497, 0.35242102200090714`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 149}], {
             RGBColor[
             0.9712789261232312, 0.9364986818902918, 0.6171097911222252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 170}], {
             RGBColor[
             0.9792530569679094, 0.9402636680049239, 0.4941526798281607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 190}], {
             RGBColor[
             0.7753890419154819, 0.7824496244826964, 0.6370812746064225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 195}], {
             RGBColor[
             0.9341281175991599, 0.7742555412436892, 0.2777899270625642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 46}], {
             RGBColor[
             0.9623407053031523, 0.9348028554473833, 0.6427908398095827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 98}], {
             RGBColor[
             0.972821422436163, 0.9701567753264374, 0.6835064467539727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 117}], {
             RGBColor[
             0.9517040751824642, 0.8960423909363154, 0.6164718244945699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 120}], {
             RGBColor[
             0.9749119693337887, 0.9771255860372187, 0.6986936136720275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 128}], {
             RGBColor[
             0.9704607372014433, 0.962193629714476, 0.6743356303950869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 146}], {
             RGBColor[
             0.9711557960107928, 0.9778535666464263, 0.9267662686555375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 156}], {
             RGBColor[
             0.9257817544232887, 0.7904317965767423, 0.5954673497348993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 171}], {
             RGBColor[
             0.9760859056231547, 0.9796365170570069, 0.8264693340745356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 178}], {
             RGBColor[
             0.8661645700940879, 0.42903606841260733`, 0.43072641383473687`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 179}], {
             RGBColor[
             0.7212419697093799, 0.7803078525621057, 0.9549900803903806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 183}], {
             RGBColor[
             0.895132758913837, 0.6397426358959614, 0.457998231843277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 192}], {
             RGBColor[
             0.976202181830088, 0.9798852201063095, 0.8391252816256598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 114}], {
             RGBColor[
             0.9941772175011536, 0.9899539819456123, 0.607604242927823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 46}], {
             RGBColor[
             0.9709943049033023, 0.9138191209570674, 0.3418187811255794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 74}], {
             RGBColor[
             0.9798660903250833, 0.9437457363790126, 0.37628399219310077`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.9257049710220265, 0.7298054319097682, 0.2872104454732478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 117}], {
             RGBColor[
             0.9603576747826144, 0.8750586564459994, 0.3154997658105666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 121}], {
             RGBColor[
             0.8989925294034801, 0.6170838127670876, 0.25575702941179734`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 166}], {
             RGBColor[
             0.9658398992981104, 0.9466064584421987, 0.6563845477126564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 169}], {
             RGBColor[
             0.9843697194394945, 0.958755643254193, 0.5502178423926809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 171}], {
             RGBColor[
             0.9847395052233048, 0.9586527825666911, 0.5254972753905323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 173}], {
             RGBColor[
             0.9326667774045176, 0.7614173687214693, 0.2930195473682883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 196}], {
             RGBColor[
             0.9838463789667755, 0.9567424758128912, 0.4282859941036697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 57}], {
             RGBColor[
             0.9541679329732335, 0.9316846334094004, 0.6629448577520249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 66}], {
             RGBColor[
             0.8714111029336303, 0.4178342622594835, 0.2249605299952121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 81}], {
             RGBColor[
             0.9813863478260092, 0.9505188459622995, 0.5512548890003509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 90}], {
             RGBColor[
             0.9787329919790011, 0.9399235295935334, 0.37188211908623914`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 141}], {
             RGBColor[
             0.9771462622676678, 0.9345711176953528, 0.3657179737864725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 168}], {
             RGBColor[
             0.8640363972797093, 0.8603888237924231, 0.6567867587484811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 172}], {
             RGBColor[
             0.9773755119730243, 0.9488602622633104, 0.617724818794769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 184}], {
             RGBColor[
             0.878491162626531, 0.4722547035610587, 0.23174040315291758`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 198}], {
             RGBColor[
             0.8981399783777815, 0.6150542759292972, 0.2502338715814248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 88}], {
             RGBColor[
             0.8770871968324649, 0.44227935244631367`, 0.24341532962640727`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[
             0.9820237778270036, 0.9510241229721073, 0.3846662006929658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 102}], {
             RGBColor[
             0.9882930061445065, 0.9715676882696941, 0.46038195122270037`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 153}], {
             RGBColor[
             0.9879931497620646, 0.9709263257877814, 0.4277444344929759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 49}], {
             RGBColor[
             0.9867063619577345, 0.9667334866921484, 0.4101778045203105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 67}], {
             RGBColor[
             0.9463258197607055, 0.9396845539554521, 0.6856268277640519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 87}], {
             RGBColor[
             0.9507341860691081, 0.835048601281293, 0.31742323359826186`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 95}], {
             RGBColor[
             0.9489394553555663, 0.9417685960335458, 0.6858761186603097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 103}], {
             RGBColor[
             0.9836684913698819, 0.9677543143868037, 0.6260417878480468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 129}], {
             RGBColor[
             0.9787676067058302, 0.964493775580535, 0.652005698884892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 131}], {
             RGBColor[
             0.9762573134088055, 0.962621602949842, 0.6562549706474057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 133}], {
             RGBColor[
             0.9516646543343907, 0.8387375978929699, 0.3181719102054056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 143}], {
             RGBColor[
             0.9862587802974103, 0.9688254654257257, 0.5831139968660424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 154}], {
             RGBColor[
             0.8740258797085438, 0.42210453972982087`, 0.23820634451286232`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 197}], {
             RGBColor[
             0.9673224470538592, 0.9008155283755445, 0.33077053776312226`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 50}], {
             RGBColor[
             0.9885794883931288, 0.9729373838741275, 0.4271991435733949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 57}], {
             RGBColor[
             0.9657014166238483, 0.9703890917621054, 0.7248155090921249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 60}], {
             RGBColor[
             0.9754294929679728, 0.9285793615393196, 0.3761138945149295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 90}], {
             RGBColor[
             0.9902664756296159, 0.9786279879462383, 0.433752770426339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 141}], {
             RGBColor[
             0.9886797459182826, 0.9732755760480577, 0.4275886251265724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 177}], {
             RGBColor[
             0.9699131814829853, 0.9735302190979177, 0.7176860897898107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 120}], {
             RGBColor[
             0.9932883783871598, 0.9880528449561994, 0.510859590648771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 128}], {
             RGBColor[
             0.9888371462548146, 0.9731208886334567, 0.4865016073718304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 168}], {
             RGBColor[
             0.8761253502270225, 0.9002813748042051, 0.7791168150750704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 172}], {
             RGBColor[
             0.9894644649203377, 0.9887528132750925, 0.7400548751213583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 173}], {
             RGBColor[
             0.9423895868577387, 0.7933283621307659, 0.40615758302903504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 85}], {
             RGBColor[
             0.9770309325533899, 0.9453642699258522, 0.6002561252437815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 98}], {
             RGBColor[
             0.9779758280413549, 0.937369437841306, 0.36894068016689563`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 99}], {
             RGBColor[
             0.7168755345166868, 0.7397910676082611, 0.6396747983397051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 109}], {
             RGBColor[
             0.9813505095085977, 0.9470848825505775, 0.5238979702278448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 117}], {
             RGBColor[
             0.9568584807876561, 0.863255053451184, 0.3019060579074929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 121}], {
             RGBColor[
             0.8966597334068412, 0.6092147441038773, 0.2466945574764149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 146}], {
             RGBColor[
             0.9763102016159848, 0.9450662291612948, 0.6122005020684604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 151}], {
             RGBColor[
             0.9802613216039987, 0.9447552197564297, 0.4053465885008172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 171}], {
             RGBColor[
             0.9812403112283465, 0.9468491795718755, 0.5119035674874586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 178}], {
             RGBColor[
             0.8696008404975492, 0.4071778434225197, 0.22101590277668548`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 196}], {
             RGBColor[
             0.9803471849718173, 0.9449388728180756, 0.41469228620059606`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 54}], {
             RGBColor[
             0.9689594740557819, 0.9635689534070011, 0.682173212185085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 61}], {
             RGBColor[
             0.9449364768392541, 0.9584542951017356, 0.9780923612309608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 73}], {
             RGBColor[
             0.9655653622604503, 0.973839284072164, 0.9431730390878822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 88}], {
             RGBColor[
             0.8668139587891215, 0.44536783805486313`, 0.4356786495372762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 94}], {
             RGBColor[
             0.9258452519508613, 0.800020998686487, 0.6017140174903852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 105}], {
             RGBColor[
             0.9610877033322991, 0.9704998533750424, 0.9507525476927576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 111}], {
             RGBColor[
             0.91283165051788, 0.7409292739831543, 0.5908551494621446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 116}], {
             RGBColor[
             0.9620948097064583, 0.971250951659905, 0.9490477792967162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 126}], {
             RGBColor[
             0.9380902857809246, 0.8499571967356162, 0.6116384961498837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 142}], {
             RGBColor[
             0.5656058058714488, 0.6346642610407032, 0.9495774427698069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 153}], {
             RGBColor[
             0.9725832926970492, 0.9755590542006056, 0.7161394143592793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 157}], {
             RGBColor[
             0.8868564484632833, 0.9121915779413934, 0.9742418213748805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 160}], {
             RGBColor[
             0.8623075372476325, 0.41072950736046887`, 0.4313632951798714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 167}], {
             RGBColor[
             0.9641840556794947, 0.9474603459022283, 0.6636216135553004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 174}], {
             RGBColor[
             0.9648832429750986, 0.9498188688272843, 0.6663378241682798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 188}], {
             RGBColor[
             0.8709840443395145, 0.4774209429383244, 0.43967192816977063`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 59}], {
             RGBColor[
             0.9884540671133726, 0.9894934742815082, 0.8410095180552969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.9918243932102642, 0.9906314141238342, 0.7665622329159774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 77}], {
             RGBColor[
             0.9729804656363648, 0.9285985482487247, 0.5630761460834834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 106}], {
             RGBColor[
             0.9906878082630617, 0.9904171836514339, 0.8039906464681579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 112}], {
             RGBColor[
             0.9917535770761212, 0.9904799455735116, 0.7588543337410267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 140}], {
             RGBColor[
             0.986967442953235, 0.9888787169867932, 0.8656467276487758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 193}], {
             RGBColor[
             0.9907441356052096, 0.9904404764549586, 0.8030571566382803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 67}], {
             RGBColor[
             0.9522619531771119, 0.9596224337634456, 0.716008233853326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.9566703194855146, 0.8549864810892864, 0.34780463968753605`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 95}], {
             RGBColor[
             0.9548755887719726, 0.9617064758415392, 0.7162575247495839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 103}], {
             RGBColor[
             0.9896046247862884, 0.9876921941947971, 0.656423193937321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 108}], {
             RGBColor[
             0.9711494314547626, 0.9123913351693137, 0.35945487304643237`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[
             0.9847037401222367, 0.9844316553885284, 0.6823871049741662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 131}], {
             RGBColor[
             0.9821934468252118, 0.9825594827578353, 0.6866363767366799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 133}], {
             RGBColor[
             0.9576007877507973, 0.8586754777009633, 0.3485533162946798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 143}], {
             RGBColor[
             0.9921949137138166, 0.988763345233719, 0.6134954029553166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 154}], {
             RGBColor[
             0.877983301986148, 0.4353964596018164, 0.25846061523904507`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 162}], {
             RGBColor[
             0.9595131138731183, 0.8662572135310629, 0.3500920187807627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 53}], {
             RGBColor[
             0.9889068760886399, 0.9736376330508523, 0.46283327382712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 60}], {
             RGBColor[
             0.9711808021497957, 0.9144482199611255, 0.3425432877111564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 82}], {
             RGBColor[
             0.951090416349158, 0.9480694811002746, 0.6928275432828646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 100}], {
             RGBColor[
             0.976450122370959, 0.9674429839863197, 0.6658582218507998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 104}], {
             RGBColor[
             0.9489267444665141, 0.8268297804625953, 0.32145253411712515`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 123}], {
             RGBColor[
             0.874864593208079, 0.4234321064031964, 0.24248367531084192`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.9848032673364648, 0.9734926977183602, 0.6436556042172106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 163}], {
             RGBColor[
             0.9484284715916946, 0.8248542945535284, 0.3210516120660777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 177}], {
             RGBColor[
             0.9656644906648084, 0.9593990775197236, 0.6841154829860376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 71}], {
             RGBColor[
             0.986920839407669, 0.9796197964252087, 0.6448596311569885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 74}], {
             RGBColor[
             0.9865590451904127, 0.9663226447203035, 0.4022848579864333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 158}], {
             RGBColor[
             0.9061953577189721, 0.9168417460967556, 0.6952690195901687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 164}], {
             RGBColor[
             0.987415417235683, 0.979824317067163, 0.6366631966204053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 166}], {
             RGBColor[
             0.9725328541634398, 0.9691833667834897, 0.682385413505989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 184}], {
             RGBColor[
             0.8845305615328122, 0.4926270141902429, 0.25520232745903426`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 70}], {
             RGBColor[
             0.9187526503692236, 0.9275168307193936, 0.6974409876142291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 134}], {
             RGBColor[
             0.9217483916418486, 0.9372343701489712, 0.8640937520348118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 145}], {
             RGBColor[
             0.9184692351765851, 0.9358783546801075, 0.9184378608491286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 100}], {
             RGBColor[
             0.9810262008846471, 0.9822743747412385, 0.735062958908298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 104}], {
             RGBColor[
             0.9535028229802023, 0.841661171217514, 0.39065727117462323`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 123}], {
             RGBColor[
             0.8779153122172043, 0.43331970023980904`, 0.28862016668250734`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 130}], {
             RGBColor[
             0.989379345850153, 0.9883240884732789, 0.7128603412747087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 135}], {
             RGBColor[
             0.9732177926335517, 0.9198244562688597, 0.40652039852752314`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 148}], {
             RGBColor[
             0.993035765754303, 0.9875125320775737, 0.4833642645067685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 163}], {
             RGBColor[
             0.9530045501053828, 0.8396856853084471, 0.3902563491235759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 165}], {
             RGBColor[
             0.693428228432466, 0.7518055563818494, 0.7391622002478146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 58}], {
             RGBColor[
             0.9064663240049095, 0.9141663091467752, 0.6910410922022262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 61}], {
             RGBColor[
             0.9616113391521384, 0.9580887264273303, 0.6946116878764319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 73}], {
             RGBColor[
             0.9822402245733346, 0.9734737153977586, 0.6596923657333533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 94}], {
             RGBColor[
             0.9425201142637455, 0.7996554300120816, 0.31823334413585624`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 105}], {
             RGBColor[
             0.9777625656451834, 0.9701342847006371, 0.6672718743382287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 115}], {
             RGBColor[
             0.9868057766309044, 0.9762498345967736, 0.6238023495419378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 116}], {
             RGBColor[
             0.9787696720193426, 0.9708853829854998, 0.6655671059421873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 126}], {
             RGBColor[
             0.9547651480938089, 0.8495916280612108, 0.3281578227953549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 160}], {
             RGBColor[
             0.8734241121228887, 0.41048579491086523`, 0.24237617961018537`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 174}], {
             RGBColor[
             0.9815581052879829, 0.9494533001528789, 0.3828571508137509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 62}], {
             RGBColor[
             0.8727042318454035, 0.7027464184981929, 0.6005505090727036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 68}], {
             RGBColor[
             0.9286768257415112, 0.7357021153846945, 0.30954089313565486`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 72}], {
             RGBColor[
             0.9182009219643813, 0.738228504797352, 0.5773012385301673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 75}], {
             RGBColor[
             0.84908264777634, 0.6839112085523401, 0.5982974612969593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 76}], {
             RGBColor[
             0.9042098154235785, 0.7277939604475556, 0.6009845324387384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 96}], {
             RGBColor[
             0.7984720277960398, 0.6443064282078184, 0.5932709480911282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 107}], {
             RGBColor[
             0.9298190760818313, 0.7459627463876428, 0.5159624130478732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 111}], {
             RGBColor[
             0.8716118330518143, 0.5099011443540623, 0.21458210522753524`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 139}], {
             RGBColor[
             0.929150760992566, 0.7373008102717913, 0.31138204209084036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 147}], {
             RGBColor[
             0.9110320271612025, 0.732881954791129, 0.5894363074847329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 157}], {
             RGBColor[
             0.8456366309972174, 0.6811634483123015, 0.5979687771402711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 182}], {
             RGBColor[
             0.8818833095373511, 0.5565415201106023, 0.223152876983995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 185}], {
             RGBColor[
             0.8757875191119524, 0.5288619594968922, 0.21806640003154595`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 191}], {
             RGBColor[
             0.8920276898405548, 0.5997290642161706, 0.23146883868022866`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 79}], {
             RGBColor[
             0.8056242950958269, 0.848553379894426, 0.9811348966977274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 118}], {
             RGBColor[
             0.9265788675238705, 0.9158548757124504, 0.6718507311685279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 119}], {
             RGBColor[
             0.9334113395093062, 0.947729126766168, 0.9170988750708933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 125}], {
             RGBColor[
             0.8952728235647818, 0.9193302642498836, 0.9898731152027351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 129}], {
             RGBColor[
             0.9277146105099064, 0.9441394858749665, 0.9562519863235752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 149}], {
             RGBColor[
             0.9287551744637417, 0.9449155367679698, 0.9544905829722765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 170}], {
             RGBColor[
             0.9367293053084199, 0.9486805228826019, 0.831533471678212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 190}], {
             RGBColor[
             0.7328652902559925, 0.7908664793603744, 0.9744620664564738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 195}], {
             RGBColor[
             0.8916043659396704, 0.7826723961213672, 0.6151707189126155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 197}], {
             RGBColor[
             0.9162694508579354, 0.8804612386699759, 0.6350168252018055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 66}], {
             RGBColor[
             0.8610155836424019, 0.4325176120344759, 0.44223813669858336`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 71}], {
             RGBColor[
             0.9622684621114047, 0.9710863551439208, 0.9355831547528703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 81}], {
             RGBColor[
             0.9657930688891666, 0.972543870624788, 0.8771712990554077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 90}], {
             RGBColor[
             0.9631397130421584, 0.961948554256022, 0.6977985291412959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 141}], {
             RGBColor[
             0.9615529833308252, 0.9565961423578413, 0.6916343838415293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 198}], {
             RGBColor[
             0.887744459086553, 0.6297376257042895, 0.467511478284796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 61}], {
             RGBColor[
             0.8824433267883817, 0.9090516508415099, 0.986960241248102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 73}], {
             RGBColor[
             0.9030722122095778, 0.9244366398119381, 0.9520409191050234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 92}], {
             RGBColor[
             0.9108951978193185, 0.9278783415521662, 0.8126325817482734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 115}], {
             RGBColor[
             0.9076377642671477, 0.9272127590109531, 0.9161509029136079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 155}], {
             RGBColor[
             0.857252879008686, 0.8890141924847551, 0.9862467389501696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 154}], {
             RGBColor[
             0.8765174233129563, 0.43630832460071833`, 0.39309975571286704`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 186}], {
             RGBColor[
             0.9878423785629576, 0.989240525346233, 0.8511467803348971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 193}], {
             RGBColor[
             0.9905349278464027, 0.9903539636702978, 0.8065242706140339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.937940420924002, 0.9037114587654664, 0.6417422942243991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 104}], {
             RGBColor[
             0.9357767490413582, 0.7824717581277874, 0.2703672850586597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 123}], {
             RGBColor[
             0.8660979295913083, 0.3938600915133244, 0.2084268426051983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 130}], {
             RGBColor[
             0.9716532719113089, 0.9291346753835522, 0.5925703551587451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 163}], {
             RGBColor[
             0.9352784761665387, 0.7804962722187203, 0.2699663630076123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 177}], {
             RGBColor[
             0.9525144952396523, 0.9150410551849155, 0.6330302339275722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 73}], {
             RGBColor[
             0.9582172273568068, 0.9683590570924934, 0.955611514779229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 94}], {
             RGBColor[
             0.9184971170472177, 0.7945407717068163, 0.6141524931817319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 105}], {
             RGBColor[
             0.9537395684286556, 0.9650196263953716, 0.9631910233841043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 115}], {
             RGBColor[
             0.9627827794143766, 0.9711351762915083, 0.9197214985878135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 116}], {
             RGBColor[
             0.9547466748028148, 0.9657707246802343, 0.961486254988063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 160}], {
             RGBColor[
             0.8574087806452035, 0.407076022707355, 0.4396556123074359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 174}], {
             RGBColor[
             0.9575351080714551, 0.9443386418476136, 0.6787762998596266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 68}], {
             RGBColor[
             0.9315360807761484, 0.9365702710596651, 0.6969836051379632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 75}], {
             RGBColor[
             0.8519419028109773, 0.8847793642273105, 0.9857401732992677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 76}], {
             RGBColor[
             0.9070690704582157, 0.9286621161225261, 0.9884272444410469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 96}], {
             RGBColor[
             0.801331282830677, 0.8451745838827889, 0.9807136600934366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 105}], {
             RGBColor[
             0.9227271409008706, 0.9403398794209208, 0.9619222154604565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 107}], {
             RGBColor[
             0.9326783311164686, 0.9468309020626133, 0.9034051250501816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 111}], {
             RGBColor[
             0.8744710880864515, 0.7107693000290327, 0.6020248172298437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 116}], {
             RGBColor[
             0.9237342472750298, 0.9410909777057834, 0.9602174470644151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 126}], {
             RGBColor[
             0.8997297233494961, 0.8197972227814947, 0.6228081639175829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 157}], {
             RGBColor[
             0.8484958860318547, 0.8820316039872719, 0.9854114891425795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 174}], {
             RGBColor[
             0.9265226805436702, 0.9196588948731628, 0.6775074919359788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 182}], {
             RGBColor[
             0.8847425645719882, 0.7574096757855728, 0.6105955889863034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 185}], {
             RGBColor[
             0.8786467741465895, 0.7297301151718626, 0.6055091120338544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 191}], {
             RGBColor[
             0.894886944875192, 0.8005972198911411, 0.6189115506825371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 77}], {
             RGBColor[
             0.9761415839744495, 0.9296499753063898, 0.4920959749199176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 91}], {
             RGBColor[
             0.9806737859779135, 0.9449381568757105, 0.509702723868843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 102}], {
             RGBColor[
             0.9942335989822169, 0.9900745762325647, 0.6137410191954025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 106}], {
             RGBColor[
             0.9938489266011465, 0.9914686107090989, 0.7330104753045921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 112}], {
             RGBColor[
             0.994914695414206, 0.9915313726311767, 0.6878741625774609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 140}], {
             RGBColor[
             0.9901285612913198, 0.9899301440444582, 0.7946665564852099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 69}], {
             RGBColor[
             0.9670562347166756, 0.8985891555440044, 0.33665455845493975`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 82}], {
             RGBColor[
             0.9336163166476772, 0.8871793097227377, 0.6350784020117037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 86}], {
             RGBColor[
             0.9666752601041548, 0.897304038718879, 0.3351745440263153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 87}], {
             RGBColor[
             0.9350403708844393, 0.7801637476096455, 0.26659016149639386`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 108}], {
             RGBColor[
             0.9495194828536873, 0.8375686016896728, 0.2782403948552902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 110}], {
             RGBColor[
             0.9087147340643897, 0.6653696895493494, 0.24486883343155247`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 127}], {
             RGBColor[
             0.8136713716153608, 0.7926863923197325, 0.6233333218275692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 154}], {
             RGBColor[
             0.8635633362520978, 0.3855146372820558, 0.20431762977828363`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 161}], {
             RGBColor[
             0.9593543216214258, 0.8726087941785339, 0.3067340804641405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 162}], {
             RGBColor[
             0.937883165272043, 0.7914344800514219, 0.2688775405896205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 175}], {
             RGBColor[
             0.8899738221304679, 0.5846072730753062, 0.22945523775750104`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 176}], {
             RGBColor[
             0.9674314307495766, 0.9126448147667496, 0.5842116984887946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 180}], {
             RGBColor[
             0.9508743739505416, 0.8429402933980069, 0.27933057203520073`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 66}], {
             RGBColor[
             0.8793788193916773, 0.44423340412894696`, 0.29654538366154326`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 69}], {
             RGBColor[
             0.9891971162727888, 0.9745047229512257, 0.4734809356892704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 87}], {
             RGBColor[
             0.9571812524405525, 0.8560793150168666, 0.4034165387307246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 90}], {
             RGBColor[
             0.9906845666660714, 0.9795222423977286, 0.4792593995857358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 110}], {
             RGBColor[
             0.9308556156205031, 0.7412852569565707, 0.38169521066588313`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 131}], {
             RGBColor[
             0.9827043797802498, 0.9836523166854156, 0.7422482757798684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 133}], {
             RGBColor[
             0.9581117207058352, 0.8597683116285436, 0.40416521533786826`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 162}], {
             RGBColor[
             0.9600240468281563, 0.8673500474586432, 0.4057039178239512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 180}], {
             RGBColor[
             0.9730152555066549, 0.9188558608052282, 0.4161569492695314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 198}], {
             RGBColor[
             0.9061076948358283, 0.6414534177987606, 0.32181872524775595`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 81}], {
             RGBColor[
             0.8791611935442524, 0.44507375373640845`, 0.36777815753080056`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 90}], {
             RGBColor[
             0.8773922896462469, 0.43801020949056446`, 0.24819631092139272`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 141}], {
             RGBColor[
             0.8763344698386915, 0.4344419348917774, 0.24408688072154833`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 168}], {
             RGBColor[
             0.8009278931800524, 0.3849870722898242, 0.4381327373628874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 172}], {
             RGBColor[
             0.8764873029755959, 0.44396803127041573`, 0.41209144406041265`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 198}], {
             RGBColor[
             0.835600486167483, 0.2705315958506761, 0.18156324193744042`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 87}], {
             RGBColor[
             0.9162897772884855, 0.8279375483525901, 0.6232536629312775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 103}], {
             RGBColor[
             0.9492240825892593, 0.9606432614581009, 0.9318722171810624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 129}], {
             RGBColor[
             0.9443231979252076, 0.9573827226518321, 0.9578361282179076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 131}], {
             RGBColor[
             0.9418129046281829, 0.9555105500211392, 0.9620853999804213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 133}], {
             RGBColor[
             0.9172202455537681, 0.831626544964267, 0.6240023395384212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 143}], {
             RGBColor[
             0.9518143715167877, 0.9617144124970228, 0.888944426199058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 162}], {
             RGBColor[
             0.9191325716760894, 0.8392082807943666, 0.6255410420245041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 107}], {
             RGBColor[
             0.9886509250125763, 0.9797865989491151, 0.6123955091131329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 111}], {
             RGBColor[
             0.9304436819825592, 0.7437249969155346, 0.3110152012927949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 122}], {
             RGBColor[
             0.9913633693172359, 0.9808531076131355, 0.5634339730277871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 138}], {
             RGBColor[
             0.9907735569220293, 0.9795915585389693, 0.49923653370971854`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 142}], {
             RGBColor[
             0.5832178373361281, 0.6374599839730835, 0.6697374946004573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 147}], {
             RGBColor[
             0.9698638760919474, 0.9667058073526014, 0.6858694035499926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 156}], {
             RGBColor[
             0.9409429419104365, 0.7913996840835684, 0.31977604113702673`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 157}], {
             RGBColor[
             0.9044684799279624, 0.9149873008737737, 0.6944018732055308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 179}], {
             RGBColor[
             0.7364031571965278, 0.7812757400689319, 0.6792987717925081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 181}], {
             RGBColor[
             0.9751889450046856, 0.9706772350287214, 0.6768554508811326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 185}], {
             RGBColor[
             0.9346193680426973, 0.7626858120583644, 0.31449949609680566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 82}], {
             RGBColor[
             0.9512899531923626, 0.9487425657258823, 0.6936027062393433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 86}], {
             RGBColor[
             0.9843488966488402, 0.9588672947220236, 0.3936988482539548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 90}], {
             RGBColor[
             0.9862173216546435, 0.9651699309936519, 0.40095732657904465`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 110}], {
             RGBColor[
             0.9263883706090752, 0.726932945552494, 0.30339313765919196`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 123}], {
             RGBColor[
             0.8749976177702153, 0.42388082948693495`, 0.24300045061516107`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 127}], {
             RGBColor[
             0.8313450081600462, 0.854249648322877, 0.6818576260552087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 177}], {
             RGBColor[
             0.9658640275080129, 0.9600721621453314, 0.6848906459425164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 180}], {
             RGBColor[
             0.968548010495227, 0.9045035494011515, 0.3378548762628402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 72}], {
             RGBColor[
             0.9774752325211569, 0.9735448843183561, 0.6754532144606894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 93}], {
             RGBColor[
             0.9303252132018721, 0.9367444781932978, 0.6985447889881559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 134}], {
             RGBColor[
             0.9913893391969425, 0.9822285612948081, 0.5760645133520219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 139}], {
             RGBColor[
             0.9884250715493416, 0.9726171897927953, 0.40953401802136236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.9881101827316789, 0.9808725458259444, 0.6304086221663386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 81}], {
             RGBColor[
             0.9894868769641805, 0.9899205676968199, 0.8238931860011962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 164}], {
             RGBColor[
             0.9864568480144327, 0.9886675728579071, 0.8741086071620756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 184}], {
             RGBColor[
             0.8838915153853119, 0.498522518050739, 0.41349926782014784`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 75}], {
             RGBColor[
             0.8974385929299551, 0.9202614505264698, 0.9624909027567314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 84}], {
             RGBColor[
             0.9558788326783311, 0.966615086170056, 0.9595698070188792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 93}], {
             RGBColor[
             0.9194068477987116, 0.9377783406464233, 0.9645862545174061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 134}], {
             RGBColor[
             0.980470973793782, 0.9832624237479337, 0.8421059788812721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 139}], {
             RGBColor[
             0.9775067061461811, 0.973651052245921, 0.6755754835506126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 152}], {
             RGBColor[
             0.963055594024859, 0.9249040577782166, 0.6194356418228133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 191}], {
             RGBColor[
             0.9403836349941699, 0.8360793061903002, 0.5956622801400009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 94}], {
             RGBColor[
             0.9391260024684138, 0.8099257606772445, 0.5792331710386533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 115}], {
             RGBColor[
             0.9834116648355729, 0.9865201652619366, 0.8848021764447349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 153}], {
             RGBColor[
             0.985864043214602, 0.9854638161913634, 0.6936585679075475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 160}], {
             RGBColor[
             0.871161370926001, 0.41733268202097396`, 0.4163760642120502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 80}], {
             RGBColor[
             0.9310775624488493, 0.747928444336898, 0.3080819486376955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 158}], {
             RGBColor[
             0.9048749942804655, 0.9123878501825945, 0.6901396569612839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 164}], {
             RGBColor[
             0.9860950537971764, 0.9753704211530019, 0.6315338339915204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 166}], {
             RGBColor[
             0.9712124907249332, 0.9647294708693286, 0.6772560508771042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 169}], {
             RGBColor[
             0.9897423108663173, 0.9768786556813228, 0.5710893455571285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 184}], {
             RGBColor[
             0.8836503192404744, 0.4896577502474688, 0.251782752373111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 76}], {
             RGBColor[
             0.8834474863891524, 0.9098269061766735, 0.9861741966653026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 96}], {
             RGBColor[
             0.7777096987616137, 0.8263393739369361, 0.9784606123176923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 134}], {
             RGBColor[
             0.9113526996057407, 0.9289451275029217, 0.863102201648064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 139}], {
             RGBColor[
             0.9083884319581398, 0.9193337560009089, 0.6965717063174044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 182}], {
             RGBColor[
             0.861120980502925, 0.7385744658397202, 0.6083425412105591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 191}], {
             RGBColor[
             0.8712653608061287, 0.7817620099452884, 0.6166585029067928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.8328368664088521, 0.8702221258321516, 0.9811476834594715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 105}], {
             RGBColor[
             0.9542327244790456, 0.9653874213702838, 0.9623562388264915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 111}], {
             RGBColor[
             0.9059766716646266, 0.7358168419783957, 0.6024588405958785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 116}], {
             RGBColor[
             0.9552398308532049, 0.9661385196551464, 0.9606514704304501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 126}], {
             RGBColor[
             0.9312353069276711, 0.8448447647308575, 0.6232421872836177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 174}], {
             RGBColor[
             0.9580282641218453, 0.9447064368225255, 0.6779415153020136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.9162481481501634, 0.7824572177349357, 0.6110296123523382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 191}], {
             RGBColor[
             0.9263925284533672, 0.825644761840504, 0.6193455740485719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 102}], {
             RGBColor[
             0.9753896714083174, 0.9280417103574553, 0.41025493236290866`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 106}], {
             RGBColor[
             0.975004999027247, 0.9294357448339895, 0.5295243884720982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 112}], {
             RGBColor[
             0.9760707678403064, 0.9294985067560673, 0.484388075744967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 140}], {
             RGBColor[
             0.9712846337174204, 0.9278972781693489, 0.5911804696527161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 189}], {
             RGBColor[
             0.9753619071978584, 0.9279823255186758, 0.40723296939529197`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 91}], {
             RGBColor[
             0.9672529780575372, 0.936977911332503, 0.6313158202681849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 95}], {
             RGBColor[
             0.9426262889387003, 0.9562519676390104, 0.9653820467203393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 113}], {
             RGBColor[
             0.981109717271422, 0.9827494258278076, 0.7676727010915503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 136}], {
             RGBColor[
             0.9735909792967565, 0.95835747774585, 0.6559377582514478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 89}], {
             RGBColor[
             0.839165987410669, 0.8750394886199143, 0.9753500631039833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 118}], {
             RGBColor[
             0.8535389264702169, 0.8583212281338585, 0.6646966545578525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 119}], {
             RGBColor[
             0.8603713984556527, 0.8901954791875761, 0.9099447984602179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 125}], {
             RGBColor[
             0.822232882511128, 0.8617966166712917, 0.9827190385920599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 128}], {
             RGBColor[
             0.8581597643735499, 0.8739083994061357, 0.6826477372402832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 144}], {
             RGBColor[
             0.8568358936080525, 0.8694426724544752, 0.6775047493083423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 149}], {
             RGBColor[
             0.8557152334100881, 0.8873818891893779, 0.9473365063616013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 159}], {
             RGBColor[
             0.8397128801379277, 0.8754473603204491, 0.9744243163692017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 170}], {
             RGBColor[
             0.8636893642547663, 0.8911468753040099, 0.8243793950675367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 190}], {
             RGBColor[
             0.6598253492023388, 0.7333328317817824, 0.9673079898457986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 192}], {
             RGBColor[
             0.8639012090021945, 0.8915999897979692, 0.8474373884708559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 195}], {
             RGBColor[
             0.8185644248860169, 0.7251387485427753, 0.6080166423019402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 197}], {
             RGBColor[
             0.8432295098042817, 0.822927591091384, 0.6278627485911301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 81}], {
             RGBColor[
             0.9349639634438675, 0.7626831115226702, 0.4922448661107881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 117}], {
             RGBColor[
             0.9115691469063804, 0.6792413644038848, 0.24729772225516133`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 120}], {
             RGBColor[
             0.9347770410577048, 0.7603245595047881, 0.32951951143261893`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 121}], {
             RGBColor[
             0.8664668441526574, 0.4865389514056778, 0.21028900037486048`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 166}], {
             RGBColor[
             0.9170513714218764, 0.7507891664000841, 0.5881825041572512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 168}], {
             RGBColor[
             0.8176140128975675, 0.6725530893527938, 0.5977767358589183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 172}], {
             RGBColor[
             0.9309531275908826, 0.7610245278236811, 0.5587147959052062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 173}], {
             RGBColor[
             0.8838782495282835, 0.5656000766793546, 0.224817503812883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 184}], {
             RGBColor[
             0.8475429063717699, 0.3470308806013059, 0.192400387893209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 164}], {
             RGBColor[
             0.9899814547921946, 0.9901250883387741, 0.815696751464613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 166}], {
             RGBColor[
             0.9750988917199513, 0.9794841380551008, 0.8614189683501967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 168}], {
             RGBColor[
             0.8756615331956423, 0.9012480610078105, 0.8710132000518639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 172}], {
             RGBColor[
             0.9890006478889575, 0.9897194994786979, 0.8319512600981518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 173}], {
             RGBColor[
             0.9419257698263586, 0.7942950483343714, 0.4980539680058286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 184}], {
             RGBColor[
             0.8862412532371532, 0.49949419503798365`, 0.3745580306885061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 198}], {
             RGBColor[
             0.9058900689884035, 0.6422937674062221, 0.3930514991170133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 86}], {
             RGBColor[
             0.9509089785798419, 0.9474574489007568, 0.6921226918107188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 101}], {
             RGBColor[
             0.9361552959524545, 0.8972455166014817, 0.6371213243578316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 110}], {
             RGBColor[
             0.8929484525400768, 0.7155230997312272, 0.601816981215956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 123}], {
             RGBColor[
             0.8527043390575498, 0.4162742656060905, 0.4419496796530038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 127}], {
             RGBColor[
             0.7979050900910478, 0.8428398025016102, 0.9802814696119728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 130}], {
             RGBColor[
             0.9515628861106711, 0.9627559365227012, 0.9428546107304533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 163}], {
             RGBColor[
             0.9151880903659009, 0.8141175333578694, 0.6202506185793205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 176}], {
             RGBColor[
             0.9516651492252637, 0.9627982249486274, 0.9411598462731982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 177}], {
             RGBColor[
             0.9324241094390147, 0.9486623163240646, 0.9833144894992805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 180}], {
             RGBColor[
             0.9351080924262287, 0.8930937035798847, 0.6362787198196043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 187}], {
             RGBColor[
             0.952151598059217, 0.9516490961856181, 0.696950033839093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 86}], {
             RGBColor[
             0.9025290112541589, 0.6294549213123102, 0.26834150785207916`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 101}], {
             RGBColor[
             0.8926932228359007, 0.5959802997794601, 0.23167392955015434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 124}], {
             RGBColor[
             0.9013549966198, 0.6254946942788726, 0.26378068269165555`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 135}], {
             RGBColor[
             0.8921905807969776, 0.5939874915906603, 0.23126949196711175`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 137}], {
             RGBColor[
             0.866372989426393, 0.48611277901403915`, 0.21021068569067553`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 161}], {
             RGBColor[
             0.8976483855990062, 0.61299142495208, 0.2493811988106293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 165}], {
             RGBColor[
             0.7056642046629205, 0.48197489166598684`, 0.4530306931139727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 175}], {
             RGBColor[
             0.861296181945288, 0.46306018196085397`, 0.20597447308450284`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 176}], {
             RGBColor[
             0.9030331250177734, 0.639682105344224, 0.434366277493732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 187}], {
             RGBColor[
             0.903357424240409, 0.6322493528355511, 0.27155973587099524`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 199}], {
             RGBColor[
             0.9031078377955579, 0.6397130009978687, 0.43312809341537195`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 93}], {
             RGBColor[
             0.9087288133590463, 0.9298146800449976, 0.9826613815463456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 139}], {
             RGBColor[
             0.9668286717065158, 0.9656873916444952, 0.6936506105795521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 152}], {
             RGBColor[
             0.9523775595851937, 0.9169403971767909, 0.637510768851753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 194}], {
             RGBColor[
             0.8934896004451509, 0.6474429688849964, 0.46672358142627846`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 99}], {
             RGBColor[
             0.7264113561617327, 0.7831398195718614, 0.911705850360981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 109}], {
             RGBColor[
             0.9908863311536436, 0.9904336345141779, 0.7959290222491205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 132}], {
             RGBColor[
             0.9706018422802285, 0.9232852988306889, 0.5773225952537422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 146}], {
             RGBColor[
             0.9858460232610307, 0.9884149811248951, 0.8842315540897362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 150}], {
             RGBColor[
             0.987420285623404, 0.989065979068434, 0.8581419526848113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 151}], {
             RGBColor[
             0.9897971432490444, 0.9881039717200301, 0.6773776405220929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 152}], {
             RGBColor[
             0.9730605375650787, 0.9319711953372021, 0.5848318904603721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 194}], {
             RGBColor[
             0.9072782524317409, 0.6574635009919372, 0.43160432916535796`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 196}], {
             RGBColor[
             0.9898830066168631, 0.988287624781676, 0.6867233382218718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 101}], {
             RGBColor[
             0.969214239408932, 0.9073702455976229, 0.3372174663724431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 108}], {
             RGBColor[
             0.966812144785852, 0.8978467408676918, 0.3352846846543052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 110}], {
             RGBColor[
             0.9260073959965545, 0.7256478287273684, 0.3019131232305675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 124}], {
             RGBColor[
             0.9822069000847811, 0.9516418373467417, 0.3853775960846949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 127}], {
             RGBColor[
             0.8309640335475255, 0.8529645314977514, 0.6803776116265843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 161}], {
             RGBColor[
             0.9766469835535905, 0.9328869333565528, 0.3637783702631556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 175}], {
             RGBColor[
             0.9015022634185776, 0.6247926991939856, 0.26748476429017776`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 176}], {
             RGBColor[
             0.9847240926817412, 0.9729229539447687, 0.6412559882878096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 180}], {
             RGBColor[
             0.9681670358827063, 0.903218432576026, 0.3363748618342158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 187}], {
             RGBColor[
             0.9852105415156946, 0.9617738251817594, 0.39704617585370455`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 199}], {
             RGBColor[
             0.984836161848418, 0.9729692974252357, 0.6393987121702696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 95}], {
             RGBColor[
             0.9189034128833463, 0.8300215904306838, 0.6235029538275354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 103}], {
             RGBColor[
             0.953632448897662, 0.8560073087839417, 0.5636686230152723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 108}], {
             RGBColor[
             0.9351772555661363, 0.7807064497584584, 0.2667003021243838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 110}], {
             RGBColor[
             0.8943725067768388, 0.6085075376181349, 0.23332874070064608`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 131}], {
             RGBColor[
             0.9462212709365855, 0.85087459734698, 0.5938818058146313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 143}], {
             RGBColor[
             0.9562227378251903, 0.8570784598228637, 0.520740832033268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[
             0.8540018513937305, 0.34760653599457947`, 0.19662423462434603`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 162}], {
             RGBColor[
             0.923540937984492, 0.7345723281202075, 0.2573374478587141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 180}], {
             RGBColor[
             0.9365321466629906, 0.7860781414667924, 0.26779047930429434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 94}], {
             RGBColor[
             0.8491877189277638, 0.3360921557915835, 0.19305207083779036`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 102}], {
             RGBColor[
             0.8805463170135172, 0.45354510112227114`, 0.29109401323686945`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[
             0.8807442678199049, 0.4539684978812379, 0.31263973690140656`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 122}], {
             RGBColor[
             0.8811251095288941, 0.45478307978776245`, 0.35409200664229146`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 136}], {
             RGBColor[
             0.8757317758367945, 0.43770719915993295`, 0.23814977500800494`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 142}], {
             RGBColor[
             0.6090280882081556, 0.22585433069439437`, 0.4249610210240715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 153}], {
             RGBColor[
             0.8803464127585559, 0.4531175261343293, 0.26933566875038645`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 167}], {
             RGBColor[
             0.8747469214135195, 0.4343850539354111, 0.2343238015477338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 188}], {
             RGBColor[
             0.8261636750874298, 0.20211104848332212`, 0.17268767085235454`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 113}], {
             RGBColor[
             0.9699115798072063, 0.9743978732422627, 0.7866282268764597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 118}], {
             RGBColor[
             0.9601205598387126, 0.9423409844379387, 0.6660658975747837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 122}], {
             RGBColor[
             0.9704828423706902, 0.9756197461020494, 0.8488066314877871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 136}], {
             RGBColor[
             0.9623928418325407, 0.9500059251603051, 0.6748932840363573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 138}], {
             RGBColor[
             0.9698930299754835, 0.9743581970278832, 0.7846091921697185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 144}], {
             RGBColor[
             0.9634175269765481, 0.9534624287585554, 0.6788739923252735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 149}], {
             RGBColor[
             0.9622968667785837, 0.9714016454934581, 0.9487057493785325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 159}], {
             RGBColor[
             0.9462945135064232, 0.9594671166245294, 0.9757935593861329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 170}], {
             RGBColor[
             0.970270997623262, 0.97516663160809, 0.8257486380844679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 192}], {
             RGBColor[
             0.9704828423706902, 0.9756197461020494, 0.8488066314877871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 197}], {
             RGBColor[
             0.9498111431727774, 0.9069473473954642, 0.6292319916080613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 141}], {
             RGBColor[
             0.9861180423365927, 0.9648350385419743, 0.4005716451757435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 177}], {
             RGBColor[
             0.9673514779012955, 0.9650896815918343, 0.6906691098389817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 198}], {
             RGBColor[
             0.9041211650903981, 0.6352302231603781, 0.2734696525076054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 95}], {
             RGBColor[
             0.9417353712886414, 0.9174675288764292, 0.6578896124374289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 136}], {
             RGBColor[
             0.9727000616466975, 0.9195730389832688, 0.34844532396853733`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 97}], {
             RGBColor[
             0.9877176568892815, 0.9690033151159171, 0.5111719967507875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 155}], {
             RGBColor[
             0.9408497651868517, 0.9517633004759666, 0.8154896751245466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 134}], {
             RGBColor[
             0.9333209544744971, 0.9464620176228753, 0.8651975534087386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 139}], {
             RGBColor[
             0.9303566868268962, 0.9368506461208626, 0.698667058078079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 145}], {
             RGBColor[
             0.9300417980092337, 0.9451060021540116, 0.9195416622230553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 105}], {
             RGBColor[
             0.9346483435402626, 0.806586329980123, 0.5868126796435288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 111}], {
             RGBColor[
             0.8863922907258436, 0.577015750588235, 0.22691528141291584`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 115}], {
             RGBColor[
             0.9436915545259837, 0.8127018798762595, 0.5433431548472379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 116}], {
             RGBColor[
             0.9356554499144218, 0.8073374282649857, 0.5851079112474874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 126}], {
             RGBColor[
             0.9116509259888881, 0.6860436733406967, 0.24769862810065502`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 142}], {
             RGBColor[
             0.5391664460794124, 0.4707507376457838, 0.5856375747205782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 153}], {
             RGBColor[
             0.9461439329050129, 0.8116455308056862, 0.3521995463100505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 160}], {
             RGBColor[
             0.844681297386275, 0.3014538250971892, 0.18873671648038548`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 167}], {
             RGBColor[
             0.9377446958874583, 0.7835468225073088, 0.2996817455060716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 174}], {
             RGBColor[
             0.9384438831830623, 0.7859053454323648, 0.302397956119051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 188}], {
             RGBColor[
             0.8533578044781569, 0.3681452606750447, 0.19704534947028476`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 103}], {
             RGBColor[
             0.9518377181841201, 0.9627273035361945, 0.9321215080773202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 129}], {
             RGBColor[
             0.9469368335200684, 0.9594667647299259, 0.9580854191141654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 131}], {
             RGBColor[
             0.9444265402230436, 0.9575945920992328, 0.9623346908766792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 143}], {
             RGBColor[
             0.9544280071116484, 0.9637984545751166, 0.8891937170953159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 154}], {
             RGBColor[
             0.8528053642513692, 0.418753199162748, 0.44225949133237796`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 105}], {
             RGBColor[
             0.8484949368515069, 0.8818998891305464, 0.9546426544788813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 111}], {
             RGBColor[
             0.8002388840370879, 0.6523293097386583, 0.5947452562482682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 116}], {
             RGBColor[
             0.8495020432256661, 0.882650987415409, 0.9529378860828399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 126}], {
             RGBColor[
             0.8254975193001324, 0.7613572324911202, 0.6155286029360074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.7742636819824911, 0.8235916136968975, 0.9781319281610041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 174}], {
             RGBColor[
             0.8522904764943066, 0.8612189045827883, 0.6702279309544035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 182}], {
             RGBColor[
             0.8105103605226247, 0.6989696854951983, 0.603316028004728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 191}], {
             RGBColor[
             0.8206547408258285, 0.7421572296007666, 0.6116319897009618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 102}], {
             RGBColor[
             0.9872124580985817, 0.9679227459860433, 0.45618422610865905`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 112}], {
             RGBColor[
             0.9878935545305708, 0.9693795423846554, 0.5303173694907174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 140}], {
             RGBColor[
             0.9831074204076846, 0.9677783137979369, 0.6371097633984664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 155}], {
             RGBColor[
             0.9340753380786491, 0.930139166048506, 0.6847861539526836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 99}], {
             RGBColor[
             0.7273562516496976, 0.7751449874873153, 0.680390405284095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 117}], {
             RGBColor[
             0.9673391979206669, 0.8986089733302381, 0.34262166485188283`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 120}], {
             RGBColor[
             0.9905470920719912, 0.9796921684311414, 0.42484345402934043`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 121}], {
             RGBColor[
             0.9036468781621817, 0.6327840240232467, 0.27383829543934146`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 146}], {
             RGBColor[
             0.9867909187489956, 0.980420149040349, 0.6529161090128504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 156}], {
             RGBColor[
             0.9414168771614913, 0.792998378970665, 0.32161719009221224`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.9917210283613573, 0.9822030994509297, 0.5526191744318485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 178}], {
             RGBColor[
             0.8765879852528896, 0.43074712334188914`, 0.24815964073961205`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 179}], {
             RGBColor[
             0.7368770924475826, 0.7828744349560284, 0.6811399207476936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 183}], {
             RGBColor[
             0.9055561740726389, 0.6414536908252432, 0.2754314587481523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 196}], {
             RGBColor[
             0.9908279021048281, 0.9802927926971299, 0.4554078931449859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 107}], {
             RGBColor[
             0.7280245667389631, 0.7838069236031668, 0.8849707762411279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 109}], {
             RGBColor[
             0.7307309331169405, 0.7848604321965869, 0.8353476953450443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 146}], {
             RGBColor[
             0.7256906252243276, 0.7828417788073041, 0.9236502271856599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 147}], {
             RGBColor[
             0.7092375178183341, 0.7707261320066531, 0.9584446706779876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 156}], {
             RGBColor[
             0.6803165836368232, 0.5954200087376202, 0.5923513082650218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 178}], {
             RGBColor[
             0.702521122903111, 0.29902820985319256`, 0.42864905285481836`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 179}], {
             RGBColor[
             0.4757767989229145, 0.5852960647229836, 0.951874038920503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 194}], {
             RGBColor[
             0.7338413204072721, 0.5204146994468765, 0.4578834445626404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 104}], {
             RGBColor[
             0.9410460692625214, 0.8354665221529816, 0.5936822191983031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 123}], {
             RGBColor[
             0.8696108097387505, 0.4291899341967873, 0.42397013203162737`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 130}], {
             RGBColor[
             0.9769225921324721, 0.9821294394087465, 0.9158852892983885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 135}], {
             RGBColor[
             0.960761038915871, 0.9136298072043272, 0.6095453465512031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 148}], {
             RGBColor[
             0.9805790120366222, 0.9813178830130411, 0.6863892125304484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 163}], {
             RGBColor[
             0.9405477963877019, 0.8334910362439146, 0.5932812971472557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 165}], {
             RGBColor[
             0.6809714747147853, 0.7456109073173169, 0.9421871482714945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 123}], {
             RGBColor[
             0.8649078462769433, 0.3895494634040012, 0.2053461960274866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 124}], {
             RGBColor[
             0.9674532174573938, 0.9014299050474667, 0.3303762286318077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 127}], {
             RGBColor[
             0.8162103509201382, 0.8027525991984764, 0.6253762441736971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 135}], {
             RGBColor[
             0.9537065937231601, 0.8541691010151482, 0.28160944254499204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 137}], {
             RGBColor[
             0.9149802066672832, 0.6923570321502164, 0.2500212331303377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 161}], {
             RGBColor[
             0.9618933009262031, 0.8826750010572778, 0.3087770028102684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 165}], {
             RGBColor[
             0.6739170295220744, 0.686150201128138, 0.6142512442652835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 175}], {
             RGBColor[
             0.8916664750003195, 0.5913180776611355, 0.2308171859882529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 176}], {
             RGBColor[
             0.9699704100543538, 0.9227110216454937, 0.5862546208349224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 187}], {
             RGBColor[
             0.9704568588883073, 0.9115618928824842, 0.3420448084008173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 199}], {
             RGBColor[
             0.9700824792210306, 0.9227573651259606, 0.5843973447173824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 106}], {
             RGBColor[
             0.9930970140350144, 0.9898603457601645, 0.6511694327475831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 112}], {
             RGBColor[
             0.9941627828480739, 0.9899231076822422, 0.606033120020452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 140}], {
             RGBColor[
             0.9893766487251877, 0.9883218790955237, 0.7128255139282009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 108}], {
             RGBColor[
             0.9681115608669101, 0.9134121628639691, 0.5753188563741687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 129}], {
             RGBColor[
             0.9816658695343841, 0.9854524830831837, 0.8982510883019025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 131}], {
             RGBColor[
             0.9791555762373593, 0.9835803104524907, 0.9025003600644161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 133}], {
             RGBColor[
             0.9545629171629446, 0.8596963053956186, 0.564417299622416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 143}], {
             RGBColor[
             0.9891570431259641, 0.9897841729283744, 0.8293593862830528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 154}], {
             RGBColor[
             0.8759580549275797, 0.4360770113982533, 0.402369937457536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 162}], {
             RGBColor[
             0.9564752432852658, 0.8672780412257182, 0.565956002108499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 123}], {
             RGBColor[
             0.8512618911357872, 0.3354477985143044, 0.19436634020917745`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 130}], {
             RGBColor[
             0.9493992142280273, 0.8415162358850221, 0.5714796015647139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 163}], {
             RGBColor[
             0.9130244184832571, 0.6928778327201902, 0.248875609413581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 111}], {
             RGBColor[
             0.9216347421072815, 0.7474946052767903, 0.5759538116152882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 116}], {
             RGBColor[
             0.9708979012958597, 0.9778162829535411, 0.9341464414498598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 126}], {
             RGBColor[
             0.946893377370326, 0.8565225280292522, 0.5967371583030274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 142}], {
             RGBColor[
             0.5744088974608502, 0.6412295923343392, 0.9346761049229506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 157}], {
             RGBColor[
             0.8956595400526846, 0.9187569092350294, 0.9593404835280241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 160}], {
             RGBColor[
             0.8681762649739002, 0.41510639488955947`, 0.4214290699486337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 174}], {
             RGBColor[
             0.9736863345645002, 0.9563842001209203, 0.6514364863214235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 182}], {
             RGBColor[
             0.9319062185928182, 0.7941349810333305, 0.5845245833717481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 112}], {
             RGBColor[
             0.9937781104670035, 0.9913171421587764, 0.7253025761296414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 140}], {
             RGBColor[
             0.9889919763441173, 0.9897159135720579, 0.8320949700373905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 189}], {
             RGBColor[
             0.9930692498245555, 0.9898009609213849, 0.6481474697799664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 111}], {
             RGBColor[
             0.9315859323228795, 0.7539856279184829, 0.5174367212050133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 142}], {
             RGBColor[
             0.5843600876764482, 0.6477206149760317, 0.8761590145126756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[
             0.9710061264322676, 0.9769664383555496, 0.892290923462211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.9420851922507567, 0.8016603150865167, 0.5261975610492451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.9056107302682825, 0.9252479318767219, 0.9008233931177492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.7375454075368479, 0.7915363710718801, 0.8857202917047264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 181}], {
             RGBColor[
             0.9763311953450057, 0.9809378660316697, 0.883276970793351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 185}], {
             RGBColor[
             0.9357616183830175, 0.7729464430613127, 0.5209210160090241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 110}], {
             RGBColor[
             0.9088516187460869, 0.6659123916981622, 0.2449789740595424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 131}], {
             RGBColor[
             0.9607003829058336, 0.9082794514270073, 0.6055320391735277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 154}], {
             RGBColor[
             0.8636545927065625, 0.38587643871459765`, 0.20439105686361025`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 162}], {
             RGBColor[
             0.9380200499537401, 0.7919771822002348, 0.2689876812176104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 180}], {
             RGBColor[
             0.9510112586322388, 0.8434829955468197, 0.27944071266319065`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 132}], {
             RGBColor[
             0.9749214192354363, 0.9250059114554143, 0.5009644402378055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 146}], {
             RGBColor[
             0.9901656002162385, 0.9901355937496206, 0.8078733990737995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 150}], {
             RGBColor[
             0.9917398625786118, 0.9907865916931593, 0.7817837976688746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 151}], {
             RGBColor[
             0.9941167202042522, 0.9898245843447555, 0.6010194855061562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 152}], {
             RGBColor[
             0.9773801145202865, 0.9336918079619274, 0.5084737354444354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 194}], {
             RGBColor[
             0.9101579704018794, 0.6586105760750874, 0.3806988924880668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 196}], {
             RGBColor[
             0.9942025835720709, 0.9900082374064014, 0.6103651832059351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 127}], {
             RGBColor[
             0.7730035075077604, 0.6210301823282218, 0.5900719010318215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 162}], {
             RGBColor[
             0.8972153011644426, 0.6197782700599115, 0.2356161197938727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 180}], {
             RGBColor[
             0.9102065098429413, 0.6712840834064964, 0.24606915123945294`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 116}], {
             RGBColor[
             0.9226418484814407, 0.748245703561653, 0.5742490432192469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 126}], {
             RGBColor[
             0.898637324555907, 0.6269519486373641, 0.23683976007241447`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 142}], {
             RGBColor[
             0.5261528446464312, 0.4116590129424511, 0.5747787066923377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 157}], {
             RGBColor[
             0.8474034872382655, 0.6891863298431413, 0.5994430852974112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 160}], {
             RGBColor[
             0.8360055630976208, 0.2620593419616341, 0.18149747112822512`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 167}], {
             RGBColor[
             0.9247310944544771, 0.7244550978039762, 0.28882287747783103`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 174}], {
             RGBColor[
             0.925430281750081, 0.7268136207290322, 0.29153908809081047`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 181}], {
             RGBColor[
             0.9181239523149887, 0.744876263998089, 0.5818966629730131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.8775543753530004, 0.536884841027732, 0.21954070818868604`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 188}], {
             RGBColor[
             0.8446820701895027, 0.32875077753948967`, 0.1898061041181244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 140}], {
             RGBColor[
             0.9900577451571768, 0.9897786754941358, 0.7869586573102594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 122}], {
             RGBColor[
             0.994646801398732, 0.9909583744203174, 0.6587155522433323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 136}], {
             RGBColor[
             0.9865568008605825, 0.9653445534785732, 0.4848022047919026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 138}], {
             RGBColor[
             0.9940569890035253, 0.9896968253461512, 0.5945181129252638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 144}], {
             RGBColor[
             0.98758148600459, 0.9688010570768235, 0.4887829130808188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 159}], {
             RGBColor[
             0.970458472534465, 0.9748057449427975, 0.7857024801416782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 167}], {
             RGBColor[
             0.98507951922567, 0.9603613356417904, 0.4790632446014959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 197}], {
             RGBColor[
             0.9739751022008192, 0.9222859757137323, 0.43914091236360664`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 158}], {
             RGBColor[
             0.9097196211434855, 0.9272333216738942, 0.8362195401862109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 160}], {
             RGBColor[
             0.8742050722977143, 0.4191834281536505, 0.3924493867511065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 126}], {
             RGBColor[
             0.9479004837444852, 0.8572736263141149, 0.595032389906986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 142}], {
             RGBColor[
             0.5754160038350095, 0.6419806906192018, 0.9329713365269092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 153}], {
             RGBColor[
             0.98239349066061, 0.9828754837791043, 0.6995333081163815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 157}], {
             RGBColor[
             0.8966666464268438, 0.919508007519892, 0.9576357151319828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 160}], {
             RGBColor[
             0.8688476692233397, 0.4156071270794679, 0.42029255768460616`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 167}], {
             RGBColor[
             0.9739942536430555, 0.9547767754807269, 0.6470155073124026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 174}], {
             RGBColor[
             0.9746934409386594, 0.9571352984057829, 0.6497317179253821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 188}], {
             RGBColor[
             0.8775241763152216, 0.48229856265732346`, 0.4286011906745054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 120}], {
             RGBColor[
             0.9694297448182925, 0.9055777840410194, 0.3578088317699377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 121}], {
             RGBColor[
             0.8895686466597159, 0.5833744344298321, 0.22914854726640635`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 146}], {
             RGBColor[
             0.9656735714952969, 0.906305764650227, 0.5858814867534476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 151}], {
             RGBColor[
             0.9696246914833107, 0.905994755245362, 0.3790275731858044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 171}], {
             RGBColor[
             0.9706036811076586, 0.9080887150608077, 0.4855845521724458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 173}], {
             RGBColor[
             0.9185309532888715, 0.710853301215586, 0.2531068241502018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 196}], {
             RGBColor[
             0.9697105548511293, 0.9061784083070079, 0.3883732708855832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 119}], {
             RGBColor[
             0.9813259708836963, 0.9574969750056006, 0.6006606329310185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 125}], {
             RGBColor[
             0.9431874549391717, 0.9290981124893161, 0.6734348730628603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 128}], {
             RGBColor[
             0.9791143368015935, 0.9412098952241601, 0.37336357171108364`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 138}], {
             RGBColor[
             0.9842659690350315, 0.9576399365418273, 0.4739557836235878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 144}], {
             RGBColor[
             0.9777904660360961, 0.9367441682724995, 0.3682205837791428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 149}], {
             RGBColor[
             0.9766698058381318, 0.9546833850074022, 0.6380523408324017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 159}], {
             RGBColor[
             0.9606674525659713, 0.9427488561384736, 0.6651401508400022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 170}], {
             RGBColor[
             0.9846439366828099, 0.9584483711220342, 0.5150952295383372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 190}], {
             RGBColor[
             0.7807799216303825, 0.8006343275998068, 0.658023824316599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 192}], {
             RGBColor[
             0.9848557814302381, 0.9589014856159935, 0.5381532229416564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.9395189973140605, 0.7924402443607996, 0.29873247677274073`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 197}], {
             RGBColor[
             0.9641840822323253, 0.8902290869094084, 0.31857858306193065`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 125}], {
             RGBColor[
             0.9500199269246075, 0.9609723635430338, 0.9186830169652256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 128}], {
             RGBColor[
             0.9859468087870292, 0.9730841462778779, 0.618611715613449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 144}], {
             RGBColor[
             0.9846229380215319, 0.9686184193262173, 0.6134687276815081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 149}], {
             RGBColor[
             0.9835022778235675, 0.9865576360611199, 0.8833004847347671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 183}], {
             RGBColor[
             0.905456806637561, 0.6470029802715624, 0.420848955322185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 190}], {
             RGBColor[
             0.7876123936158181, 0.8325085786535245, 0.9032719682189643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 192}], {
             RGBColor[
             0.9916882534156739, 0.9907757366697112, 0.7834013668440217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 195}], {
             RGBColor[
             0.9463514692994962, 0.8243144954145174, 0.543980620675106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 128}], {
             RGBColor[
             0.9881864068372717, 0.9717290228191799, 0.41567263767045476`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 168}], {
             RGBColor[
             0.8754746108094796, 0.8988895089899284, 0.7082878453736947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 171}], {
             RGBColor[
             0.9938115752589829, 0.9891719101617109, 0.5678063413499034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 172}], {
             RGBColor[
             0.9888137255027947, 0.9873609474608157, 0.6692259054199826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 173}], {
             RGBColor[
             0.9417388474401958, 0.7919364963164892, 0.3353286133276594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 183}], {
             RGBColor[
             0.9069498720043893, 0.6460995646324306, 0.2855562366935222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 151}], {
             RGBColor[
             0.9051705405372776, 0.6377078786333292, 0.2981089009952892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 171}], {
             RGBColor[
             0.9058232002868428, 0.6391038518436263, 0.3691468869863834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 196}], {
             RGBColor[
             0.90522778278249, 0.6378303140077598, 0.30433936612847506`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 136}], {
             RGBColor[
             0.9871280634240662, 0.96656642633836, 0.5469806094032299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 138}], {
             RGBColor[
             0.9946282515670091, 0.9909186982059379, 0.6566965175365911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 142}], {
             RGBColor[
             0.5870725319811079, 0.6487871236400521, 0.8271974784273299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 144}], {
             RGBColor[
             0.9881527485680737, 0.9700229299366102, 0.5509613176921461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 153}], {
             RGBColor[
             0.9940500188067083, 0.9896819167999547, 0.5937594500168022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.9710297350979489, 0.9760276178025842, 0.8478808847530055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 167}], {
             RGBColor[
             0.9856507817891538, 0.9615832085015772, 0.5412416492128233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 181}], {
             RGBColor[
             0.9790436396496653, 0.98200437469569, 0.8343154347080053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 188}], {
             RGBColor[
             0.8852951950792872, 0.4868361846712237, 0.3580852852747859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 192}], {
             RGBColor[
             0.9952180639622157, 0.9921802472801042, 0.7208939568546597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 127}], {
             RGBColor[
             0.7727410423693388, 0.35327898733742025`, 0.434119626196914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 130}], {
             RGBColor[
             0.8751795730490877, 0.43322307668481425`, 0.4091683869425677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 135}], {
             RGBColor[
             0.8644052042380203, 0.3875566552152014, 0.204941758444444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 163}], {
             RGBColor[
             0.8509297092192409, 0.33413080790825966`, 0.1940990588418125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 165}], {
             RGBColor[
             0.6778788281039632, 0.2755440552905279, 0.426702959591305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 177}], {
             RGBColor[
             0.8624203886013166, 0.42382732988572314`, 0.43614163945511913`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 187}], {
             RGBColor[
             0.8755720476814517, 0.4258185164600921, 0.24523200234832754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 127}], {
             RGBColor[
             0.8292030115959871, 0.8470241909475952, 0.6735363738859489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 135}], {
             RGBColor[
             0.9666992543990092, 0.898440692764267, 0.32976957225724385`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.9279728673431321, 0.7366286238993351, 0.2981813628425895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 161}], {
             RGBColor[
             0.974885961602052, 0.9269465928063966, 0.3569371325225202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 175}], {
             RGBColor[
             0.9003282487842188, 0.620832472160548, 0.2629239391297541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 176}], {
             RGBColor[
             0.9829630707302028, 0.9669826133946124, 0.6344147505471742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 187}], {
             RGBColor[
             0.9834495195641563, 0.955833484631603, 0.3902049381130691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 199}], {
             RGBColor[
             0.9830751398968796, 0.9670289568750794, 0.6325574744296342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 128}], {
             RGBColor[
             0.9478082928425047, 0.9446852837615933, 0.6913859557452908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.9453637618790429, 0.9581587735448355, 0.956074724866609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[
             0.953337892723721, 0.9619237596594674, 0.8331176135725444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 190}], {
             RGBColor[
             0.7494738776712937, 0.80410971613724, 0.9760462083508062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 195}], {
             RGBColor[
             0.9082129533549717, 0.7959156328982329, 0.616754860806948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 142}], {
             RGBColor[
             0.5514114799094757, 0.520686935694913, 0.5955620533800768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 157}], {
             RGBColor[
             0.87266212250131, 0.7982142525956033, 0.6202264319851503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 160}], {
             RGBColor[
             0.8528446532729839, 0.3347446237966087, 0.1953530355867179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 174}], {
             RGBColor[
             0.9506889170131256, 0.8358415434814941, 0.31232243477854965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 182}], {
             RGBColor[
             0.9089088010414437, 0.6735923243939042, 0.24541053182887423`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 191}], {
             RGBColor[
             0.9190531813446474, 0.7167798684994724, 0.2537264935251079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 135}], {
             RGBColor[
             0.8154563878617536, 0.7997633869152767, 0.6247695877991333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 161}], {
             RGBColor[
             0.8236430950647964, 0.8282692869574063, 0.6519371480644096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 175}], {
             RGBColor[
             0.799499671092715, 0.5550476015945545, 0.4595906161576804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 176}], {
             RGBColor[
             0.8317202041929472, 0.8683053075456222, 0.9294147660890636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 177}], {
             RGBColor[
             0.8124791644066982, 0.8541693989210593, 0.9715694093151459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 180}], {
             RGBColor[
             0.8151631473939123, 0.7986007861768794, 0.6245336396354697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 187}], {
             RGBColor[
             0.8322066530269007, 0.8571561787826127, 0.6852049536549585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 183}], {
             RGBColor[
             0.9039823839161591, 0.6361449270839356, 0.2693175811755618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 190}], {
             RGBColor[
             0.7854007595337154, 0.8162214988720841, 0.6759749069990295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 192}], {
             RGBColor[
             0.9894766193335711, 0.9744886568882708, 0.556104305624087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 195}], {
             RGBColor[
             0.9441398352173934, 0.8080274156330769, 0.31668355945517124`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 131}], {
             RGBColor[
             0.9742546915733076, 0.980319771646222, 0.9284642711012614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 133}], {
             RGBColor[
             0.9496620324988929, 0.85643576658935, 0.5903812106592613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 143}], {
             RGBColor[
             0.9842561584619124, 0.9865236341221058, 0.8553232973198981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 170}], {
             RGBColor[
             0.9857796796688458, 0.9867329812845503, 0.7994964846933845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 197}], {
             RGBColor[
             0.9653198252183612, 0.9185136970719245, 0.602979838216978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 163}], {
             RGBColor[
             0.9489009413532078, 0.8395407499759551, 0.5710786795136664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 177}], {
             RGBColor[
             0.9661369604263215, 0.9740855329421503, 0.9341425504336263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 133}], {
             RGBColor[
             0.9471517392018681, 0.8545635939586569, 0.594630482421775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 143}], {
             RGBColor[
             0.9817458651648876, 0.9846514614914126, 0.8595725690824119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 154}], {
             RGBColor[
             0.8710172696201953, 0.4326552037736121, 0.4225120593237752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 162}], {
             RGBColor[
             0.9490640653241893, 0.8621453297887565, 0.596169184907858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 180}], {
             RGBColor[
             0.962055274002688, 0.9136511431353413, 0.6066222163534382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 150}], {
             RGBColor[
             0.9714553737051967, 0.9236382560096703, 0.5631773706734964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 151}], {
             RGBColor[
             0.9738322313308372, 0.9226762486612665, 0.3824130585107779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 162}], {
             RGBColor[
             0.9244714062497746, 0.7382613247318844, 0.25808612446585777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 139}], {
             RGBColor[
             0.9914208128219666, 0.9823347292223729, 0.5761867824419451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 145}], {
             RGBColor[
             0.9911059240043041, 0.990590085255522, 0.7970613865869214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 191}], {
             RGBColor[
             0.9542977416699555, 0.8447629831667522, 0.4962735790313334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 148}], {
             RGBColor[
             0.9727706037855268, 0.9188679645406623, 0.3578466521496736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 163}], {
             RGBColor[
             0.9327393881366066, 0.7710411177715358, 0.26473873676648085`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 165}], {
             RGBColor[
             0.6731630664636898, 0.6831609888449381, 0.6136445878907197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 176}], {
             RGBColor[
             0.9692164469959692, 0.9197218093622939, 0.5856479644603585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 187}], {
             RGBColor[
             0.9697028958299228, 0.9085726805992845, 0.3414381520262535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 143}], {
             RGBColor[
             0.9853926974697047, 0.965903964681956, 0.5797494286264244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 159}], {
             RGBColor[
             0.9629397345597994, 0.9504137968608399, 0.6739675373015758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 197}], {
             RGBColor[
             0.9664563642261536, 0.8978940276317748, 0.3274059695235042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 161}], {
             RGBColor[
             0.9224129508119414, 0.7178737199091463, 0.27658213702105017`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 175}], {
             RGBColor[
             0.8653462415908117, 0.4814505568957145, 0.20935394212877412`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 176}], {
             RGBColor[
             0.9304900599400923, 0.757909740497362, 0.5540597550457043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 186}], {
             RGBColor[
             0.9314698771621855, 0.7583149200988517, 0.5378216479899315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 187}], {
             RGBColor[
             0.9309765087740457, 0.7467606117343528, 0.30984994261159915`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 199}], {
             RGBColor[
             0.930602129106769, 0.7579560839778292, 0.5522024789281642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 142}], {
             RGBColor[
             0.5864827195859013, 0.6475255745658859, 0.7630000391092613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 144}], {
             RGBColor[
             0.9875629361728671, 0.968761380862444, 0.48676387837407753`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 156}], {
             RGBColor[
             0.9442078241602097, 0.8014652746763709, 0.41303858564583074`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 159}], {
             RGBColor[
             0.9704399227027423, 0.974766068728418, 0.783683445434937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 167}], {
             RGBColor[
             0.9850609693939472, 0.9603216594274109, 0.47704420989475466`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 181}], {
             RGBColor[
             0.9784538272544587, 0.9807428256215238, 0.7701179953899366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 185}], {
             RGBColor[
             0.9378842502924705, 0.7727514026511668, 0.40776204060560967`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 192}], {
             RGBColor[
             0.9946282515670091, 0.9909186982059379, 0.6566965175365911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 145}], {
             RGBColor[
             0.9881416563567031, 0.9809787137535092, 0.6305308912562618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 152}], {
             RGBColor[
             0.9740054330530437, 0.9239763632526559, 0.35351644538348626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 182}], {
             RGBColor[
             0.9411890937191507, 0.7919640675591713, 0.3214271220044402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 191}], {
             RGBColor[
             0.9513334740223546, 0.8351516116647395, 0.32974308370067384`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 198}], {
             RGBColor[
             0.9030633452828425, 0.6316619485615911, 0.269360222307761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 153}], {
             RGBColor[
             0.5859044868256005, 0.6462887931599024, 0.7000629715894724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 157}], {
             RGBColor[
             0.5001776425918343, 0.5829213169006902, 0.9581653786050734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 160}], {
             RGBColor[0.6045216666666666, 0.191216, 0.4206456666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 167}], {
             RGBColor[
             0.577505249808046, 0.6181900848615252, 0.6475451707854933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 174}], {
             RGBColor[
             0.5782044371036499, 0.6205486077865812, 0.6502613813984728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 181}], {
             RGBColor[
             0.5708981076685575, 0.6386112510556379, 0.9406189562806755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 185}], {
             RGBColor[
             0.5303285307065693, 0.430619828085281, 0.5782630014963484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.6131981737585486, 0.2579074355778555, 0.42895429965656595`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 154}], {
             RGBColor[
             0.8776849142125985, 0.43679111209086796`, 0.3737514101361997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 159}], {
             RGBColor[
             0.9692943691435871, 0.9753651561461802, 0.8806497039762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 197}], {
             RGBColor[
             0.9728109988099414, 0.9228453869171152, 0.5340881361981283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 149}], {
             RGBColor[
             0.9799667729759673, 0.9658048293280189, 0.6508604355828915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 159}], {
             RGBColor[
             0.9639644197038069, 0.9538703004590903, 0.6779482455904919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 170}], {
             RGBColor[
             0.9879409038206455, 0.9695698154426509, 0.5279033242888269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 181}], {
             RGBColor[
             0.9719783242555233, 0.959847057352196, 0.6643827955454917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 190}], {
             RGBColor[
             0.784076888768218, 0.8117557719204235, 0.6708319190670886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 192}], {
             RGBColor[
             0.9881527485680737, 0.9700229299366102, 0.5509613176921461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 197}], {
             RGBColor[
             0.9674810493701609, 0.9013505312300251, 0.3313866778124203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 147}], {
             RGBColor[
             0.9686721849176321, 0.9760012935596868, 0.9309703744067428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 156}], {
             RGBColor[
             0.9397512507361212, 0.800695170290654, 0.564877011993777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 171}], {
             RGBColor[
             0.9900554019359873, 0.9898998907709184, 0.7958789963334133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 178}], {
             RGBColor[
             0.8754775676359763, 0.4358783175552151, 0.41033285534065533`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 179}], {
             RGBColor[
             0.7352114660222124, 0.7905712262760173, 0.9243997426492583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 183}], {
             RGBColor[
             0.9044457564557254, 0.6465848850385691, 0.43760467334919545`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 194}], {
             RGBColor[
             0.9067977651401374, 0.6572648071488989, 0.43956724704847727`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 196}], {
             RGBColor[
             0.989162275679458, 0.9879895840171187, 0.6986677150465508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 152}], {
             RGBColor[
             0.9558866992216801, 0.9195575077719937, 0.6315707107773787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 156}], {
             RGBColor[
             0.9232981433301277, 0.7885795234900028, 0.5996714554861047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 178}], {
             RGBColor[
             0.8645088293653139, 0.42780121968811446`, 0.433529151002207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 179}], {
             RGBColor[
             0.7187583586162191, 0.7784555794753663, 0.959194186141586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 185}], {
             RGBColor[
             0.9169745694623885, 0.7598656514647988, 0.5943949104458837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 194}], {
             RGBColor[
             0.8958290268694752, 0.6491877092817983, 0.46276354271002906`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 165}], {
             RGBColor[
             0.6929810395844411, 0.7508490646536521, 0.6904884538699652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 159}], {
             RGBColor[
             0.9628437595058424, 0.9718095171939929, 0.9477800026437508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 170}], {
             RGBColor[
             0.9868202436226812, 0.9875090321775537, 0.7977350813420858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 190}], {
             RGBColor[
             0.7829562285702536, 0.8296949886553262, 0.9406636761203477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 192}], {
             RGBColor[
             0.9870320883701094, 0.9879621466715129, 0.8207930747454051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 195}], {
             RGBColor[
             0.9416953042539317, 0.821500905416319, 0.5813723285764894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.9663603891721966, 0.9192897479649278, 0.6012184348656793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 151}], {
             RGBColor[
             0.9906506746740128, 0.9884569288990115, 0.663232415941847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 152}], {
             RGBColor[
             0.973914068990047, 0.9323241525161835, 0.5706866658801262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 194}], {
             RGBColor[
             0.9078472733817198, 0.6576988057779247, 0.422174179445194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 171}], {
             RGBColor[
             0.9940065219240011, 0.9895888813660534, 0.58902508276577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 196}], {
             RGBColor[
             0.9931133956674718, 0.9876785746122536, 0.49181380147890746`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 194}], {
             RGBColor[
             0.8982741080095028, 0.6196356166237702, 0.23996747129556786`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 160}], {
             RGBColor[
             0.875839991217067, 0.41847919543993506`, 0.26502031439298157`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 167}], {
             RGBColor[
             0.9844827366336464, 0.9590848780214276, 0.4141071423749657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 174}], {
             RGBColor[
             0.9851819239292503, 0.9614434009464836, 0.41682335298794515`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 188}], {
             RGBColor[
             0.884516498308949, 0.48517063101779057`, 0.2733289473828808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 157}], {
             RGBColor[
             0.8579027471661429, 0.7368610170111752, 0.6082039251416429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 178}], {
             RGBColor[
             0.8452282065776401, 0.31093047084209247`, 0.18946690939356317`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.6898374244347082, 0.6031494562063333, 0.5931008237286202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 181}], {
             RGBColor[
             0.9286232122428659, 0.7925509511661228, 0.5906575028172448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 183}], {
             RGBColor[
             0.8741963953973892, 0.5216370383254464, 0.21673872740210337`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 185}], {
             RGBColor[
             0.8880536352808777, 0.584559528195766, 0.22830154803291783`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 192}], {
             RGBColor[
             0.9447976365554163, 0.8027268237505372, 0.4772360249638993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 174}], {
             RGBColor[
             0.8994550796954842, 0.8980759246872714, 0.6749257600035463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 181}], {
             RGBColor[
             0.8921487502603918, 0.9161385679563281, 0.9652833348857489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 185}], {
             RGBColor[
             0.8515791732984036, 0.7081471449859712, 0.6029273801014219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 164}], {
             RGBColor[
             0.9057313663257358, 0.9258895225294539, 0.9245179955952558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 166}], {
             RGBColor[
             0.8908488032534925, 0.9152485722457806, 0.9702402124808396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 170}], {
             RGBColor[
             0.9708178903505207, 0.9755745033086249, 0.8248228913496863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 197}], {
             RGBColor[
             0.9503580359000361, 0.907355219095999, 0.6283062448732798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 167}], {
             RGBColor[
             0.8702404998720307, 0.3997467232410167, 0.23000844719032892`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 174}], {
             RGBColor[
             0.8707066247357665, 0.4013190718577207, 0.23181925426564853`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 188}], {
             RGBColor[
             0.821657253545941, 0.16747271778892775`, 0.16837231649494966`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 175}], {
             RGBColor[
             0.896621637763425, 0.6083292028337555, 0.2485244552487279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 176}], {
             RGBColor[
             0.9774031541990122, 0.9482277094044236, 0.6128155247256348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 187}], {
             RGBColor[
             0.9778896030329656, 0.9370785806414141, 0.36860571229152983`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 193}], {
             RGBColor[
             0.9810755207045505, 0.949746327329978, 0.551954907948999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 199}], {
             RGBColor[
             0.977515223365689, 0.9482740528848905, 0.6109582486080949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 180}], {
             RGBColor[
             0.9393749410505945, 0.797348873908569, 0.27007785839752096`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 177}], {
             RGBColor[
             0.9297621646815513, 0.8254471297773185, 0.6115385582824935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 166}], {
             RGBColor[
             0.9720688627702035, 0.978231143216188, 0.9116343895110761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 184}], {
             RGBColor[
             0.8842212339373213, 0.49865886514537505`, 0.40803497812909234`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 187}], {
             RGBColor[
             0.6899133316288371, 0.7405537807122743, 0.674079953746545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 184}], {
             RGBColor[
             0.8742995252224924, 0.4915648982895929, 0.43851645605281486`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 181}], {
             RGBColor[
             0.9694763574766034, 0.951407335917163, 0.6546631270661688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 188}], {
             RGBColor[
             0.8789170069639126, 0.4664381588188723, 0.23831708018022824`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 172}], {
             RGBColor[
             0.8716506973426574, 0.8995894773088214, 0.937483129846282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 173}], {
             RGBColor[
             0.8245758192800585, 0.704165026164495, 0.6035858377539588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 184}], {
             RGBColor[
             0.8080079528729531, 0.43940751359139935`, 0.44491261052059294`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 198}], {
             RGBColor[
             0.8276567686242036, 0.5822070859596379, 0.46340607894910013`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 200}], {
             RGBColor[
             0.9785575776589217, 0.9818585323338895, 0.8463800541590297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 190}], {
             RGBColor[
             0.7909303594149318, 0.8334599747699583, 0.8177065648262831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 195}], {
             RGBColor[
             0.9496694350986099, 0.825265891530951, 0.45841521728242485`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 197}], {
             RGBColor[
             0.9743345200168747, 0.9230547340795598, 0.47826132357161477`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 173}], {
             RGBColor[
             0.9429127837295619, 0.7944474273362774, 0.46310433373016746`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 178}], {
             RGBColor[
             0.8787643073775507, 0.4370669511622688, 0.3434682322866541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 183}], {
             RGBColor[
             0.9077324961973, 0.6477735186456228, 0.37074005029519425`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 196}], {
             RGBColor[
             0.9940923852918198, 0.9897725344276993, 0.5983707804655489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 173}], {
             RGBColor[
             0.9379149339733737, 0.7926364646353823, 0.5645238978002467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 198}], {
             RGBColor[
             0.9032161784197469, 0.6411880449402294, 0.4373647856466254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 188}], {
             RGBColor[
             0.8793831318276485, 0.46801050743557626`, 0.24012788725554784`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 176}], {
             RGBColor[
             0.9020063771821922, 0.6350198832258993, 0.43350953393183056`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 187}], {
             RGBColor[
             0.9023306764048278, 0.6275871307172264, 0.27070299230909384`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 199}], {
             RGBColor[
             0.9020810899599767, 0.635050778879544, 0.4322713498534705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 187}], {
             RGBColor[
             0.9859667121611164, 0.97711460122963, 0.6460833303161838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 199}], {
             RGBColor[
             0.9855923324938398, 0.9883100734731064, 0.8884358666327489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 179}], {
             RGBColor[
             0.7088683501017009, 0.30418117483233464`, 0.4291487298305507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 183}], {
             RGBColor[
             0.8351377997020263, 0.26511228989433067`, 0.18104722655804542`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 183}], {
             RGBColor[
             0.7378365389214501, 0.5148877423156887, 0.456420547839091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 185}], {
             RGBColor[
             0.683513850566969, 0.5744355841811293, 0.5878242786883991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 194}], {
             RGBColor[
             0.7401885476058621, 0.5255676644260185, 0.4583831215383727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 185}], {
             RGBColor[
             0.9222996383751267, 0.7638370791409188, 0.5853809577770238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 188}], {
             RGBColor[
             0.8745122455375869, 0.4800522696149475, 0.4336996038436829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 192}], {
             RGBColor[
             0.9790436396496653, 0.98200437469569, 0.8343154347080053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 191}], {
             RGBColor[
             0.9040660225671397, 0.6543923215035506, 0.2415139185938285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 192}], {
             RGBColor[
             0.9078100136685888, 0.6479393206784911, 0.3791773486626103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 193}], {
             RGBColor[
             0.9901324470547946, 0.9901875275196833, 0.8131944189178804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 199}], {
             RGBColor[
             0.986572149715933, 0.988715253074596, 0.8721977595769761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 199}], {
             RGBColor[
             0.9860787813277931, 0.9771609447100971, 0.6442260541986438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 192}], {
             RGBColor[
             0.79114220416236, 0.8339130892639175, 0.8407645582296024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 195}], {
             RGBColor[
             0.7458054200461823, 0.6674518480087236, 0.6013438120606867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 199}], {
             RGBColor[
             0.9892646989993781, 0.9898286913986608, 0.8275752498561131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 197}], {
             RGBColor[
             0.9292095806481253, 0.7570466073183252, 0.26189857080601825`]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.04749427504982855], {
             RGBColor[
             0.9834529596163762, 0.987179824891961, 0.9128940025968725]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.04749427504982855], {
             RGBColor[
             0.9629629089048801, 0.8867273363929312, 0.3106183242735805]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.04749427504982855], {
             RGBColor[
             0.9379468382091855, 0.7916869220294434, 0.26892877332944126`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.04749427504982855], {
             RGBColor[
             0.9186581255936412, 0.7152136040912579, 0.2534086223946981]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.04749427504982855], {
             RGBColor[
             0.9941341362132584, 0.989861835426991, 0.6029151106073278]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.04749427504982855], {
             RGBColor[
             0.8791195255432743, 0.5439918224916516, 0.22084670787279242`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.04749427504982855], {
             RGBColor[
             0.9935183760132987, 0.9885447866221835, 0.5358934128731799]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.04749427504982855], {
             RGBColor[
             0.8634066533917824, 0.47264333988625534`, 0.20773550219184672`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.04749427504982855], {
             RGBColor[
             0.8957890899895711, 0.6196844213665941, 0.23475620105519726`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.04749427504982855], {
             RGBColor[
             0.8214282851836687, 0.8604486338013805, 0.982829757210147]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.04749427504982855], {
             RGBColor[
             0.46625595812502957`, 0.5775666172542704, 0.9511245234569046]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.04749427504982855], {
             RGBColor[
             0.9454345770708638, 0.8213733114749361, 0.2749535837773681]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.04749427504982855], {
             RGBColor[
             0.9747824713829986, 0.9265974959968701, 0.3565350925639854]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.04749427504982855], {
             RGBColor[
             0.9944250463546596, 0.9919626276449476, 0.742054939628234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.04749427504982855], {
             RGBColor[
             0.9559856831494782, 0.9666947750764858, 0.9593889370422933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.04749427504982855], {
             RGBColor[
             0.9710302284710461, 0.913940299586322, 0.34195833740266746`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.04749427504982855], {
             RGBColor[
             0.9222088527901396, 0.7292910542156774, 0.25626562084328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.04749427504982855], {
             RGBColor[
             0.9838110381208149, 0.9570529716118064, 0.39160936943863695`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.04749427504982855], {
             RGBColor[
             0.9629469858579004, 0.8866736242165596, 0.3105564662428796]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.04749427504982855], {
             RGBColor[
             0.9848449467028552, 0.9605405880323076, 0.39562590904261047`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.04749427504982855], {
             RGBColor[
             0.9948908394862775, 0.9914803472135422, 0.6852775920441759]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.04749427504982855], {
             RGBColor[
             0.9746333290638001, 0.9260944039339319, 0.3559557028170632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.04749427504982855], {
             RGBColor[
             0.8473391319847725, 0.8811092397093807, 0.9853011569089222]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.04749427504982855], {
             RGBColor[
             0.9502923839733878, 0.840632897075255, 0.2788622892385222]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.04749427504982855], {
             RGBColor[
             0.9589133750153248, 0.9688782428763788, 0.9544331183777462]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.04749427504982855], {
             RGBColor[
             0.9931628990348401, 0.987784457309496, 0.49720193751756675`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.04749427504982855], {
             RGBColor[
             0.9367425134574933, 0.9523432506280021, 0.9919626039083621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.04749427504982855], {
             RGBColor[
             0.9023517949244928, 0.6494841317173946, 0.24023228291951432`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.04749427504982855], {
             RGBColor[
             0.8466638115573254, 0.8805707575316191, 0.9852367442436867]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.04749427504982855], {
             RGBColor[
             0.988869788326865, 0.9896653856868353, 0.8341199416957147]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.04749427504982855], {
             RGBColor[
             0.9216625282297071, 0.7271250593854296, 0.2558260352780703]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.04749427504982855], {
             RGBColor[
             0.985444141033261, 0.9882487924958102, 0.8908917826417461]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.04749427504982855], {
             RGBColor[
             0.9887013383658716, 0.9895957272989979, 0.8369115934839009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.04749427504982855], {
             RGBColor[
             0.8422620396644885, 0.32585013297093457`, 0.18810348295184828`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.04749427504982855], {
             RGBColor[
             0.9754434817827762, 0.9812063694379783, 0.9264519593627747]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.04749427504982855], {
             RGBColor[
             0.8261954102068605, 0.20235497851768453`, 0.17271806043856108`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.04749427504982855], {
             RGBColor[
             0.9637117394684594, 0.889253317717662, 0.31352738960830007`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.04749427504982855], {
             RGBColor[
             0.9571862996979603, 0.9675901929325147, 0.9573566063966598]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.04749427504982855], {
             RGBColor[
             0.9934264995243608, 0.9883482721024831, 0.5258932240482432]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.04749427504982855], {
             RGBColor[
             0.9744934988982605, 0.9256227239518828, 0.3554124890286531]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.04749427504982855], {
             RGBColor[
             0.9697612119100761, 0.909659608746912, 0.33702844769696816`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.04749427504982855], {
             RGBColor[
             0.9831043258729283, 0.9546690652557579, 0.3888639258070071]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.04749427504982855], {
             RGBColor[
             0.9807702285413281, 0.946795606884155, 0.3797963984310363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.04749427504982855], {
             RGBColor[
             0.9928281792113058, 0.9870685254523217, 0.46076975037716794`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.04749427504982855], {
             RGBColor[
             0.9939391178047027, 0.989444710770476, 0.5816885603501466]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.04749427504982855], {
             RGBColor[
             0.9674951109083442, 0.9020155179622519, 0.32822507322250577`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.04749427504982855], {
             RGBColor[
             0.9522846117428977, 0.9639345220814064, 0.965653885539614]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.04749427504982855], {
             RGBColor[
             0.9886632748721794, 0.9895799870661691, 0.8375424040795432]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.04749427504982855], {
             RGBColor[
             0.992642495374141, 0.9866713665001418, 0.44055921060958464`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.04749427504982855], {
             RGBColor[
             0.9843307975749518, 0.9588062422959335, 0.39362853676962184`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.04749427504982855], {
             RGBColor[
             0.9878794086289193, 0.9707765406344646, 0.4074142206153182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.04749427504982855], {
             RGBColor[
             0.8491117028141297, 0.8825226395735567, 0.985470226297019]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.04749427504982855], {
             RGBColor[
             0.9934829546023279, 0.988469023805771, 0.5320380108846181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.04749427504982855], {
             RGBColor[
             0.9856343363686662, 0.9632033847325957, 0.3986925388305561]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.04749427504982855], {
             RGBColor[
             0.8698449768107662, 0.5018782628232223, 0.21310779707039515`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.04749427504982855], {
             RGBColor[
             0.8786642361494805, 0.906087027473018, 0.9882889733084027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.04749427504982855], {
             RGBColor[
             0.9385746540363908, 0.953709658071889, 0.9888612678070817]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.04749427504982855], {
             RGBColor[
             0.8272983116411528, 0.8651292335609547, 0.9833896455738963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.04749427504982855], {
             RGBColor[
             0.9882448593545657, 0.9894069614968475, 0.8444766320310506]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.04749427504982855], {
             RGBColor[
             0.9580308067246397, 0.8700901976263175, 0.291458038652691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.04749427504982855], {
             RGBColor[
             0.9375883419356106, 0.952974068122065, 0.9905308369223076]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.04749427504982855], {
             RGBColor[
             0.8755634868800406, 0.9036145741731633, 0.987993221075012]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.04749427504982855], {
             RGBColor[
             0.994985511548349, 0.9916828411814992, 0.6955820617524114]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.04749427504982855], {
             RGBColor[
             0.9493825981719902, 0.8370258995408599, 0.27813025422730026`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.04749427504982855], {
             RGBColor[
             0.9936643612842169, 0.9888570343553024, 0.5517830086959616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.04749427504982855], {
             RGBColor[
             0.8222360484454074, 0.17192158901576926`, 0.16892657114433407`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.04749427504982855], {
             RGBColor[
             0.9118814109800829, 0.9325735010267493, 0.9914572570970676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.04749427504982855], {
             RGBColor[
             0.9875086746722561, 0.9695259679461669, 0.40597398920091454`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.04749427504982855], {
             RGBColor[
             0.9847298712613609, 0.960152411547149, 0.39517886268257923`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.04749427504982855], {
             RGBColor[
             0.9883935979243175, 0.9725110218652305, 0.40941174893143917`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.04749427504982855], {
             RGBColor[
             0.9859622701864186, 0.9884630522159528, 0.8823050416986589]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.04749427504982855], {
             RGBColor[
             0.9665568671179964, 0.9745787467714817, 0.9414946799899396]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.04749427504982855], {
             RGBColor[
             0.9788461127780029, 0.9837440460629217, 0.9206921926361504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.04749427504982855], {
             RGBColor[
             0.9852386817519061, 0.9618687488061424, 0.39715549535754846`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.04749427504982855], {
             RGBColor[
             0.8283203187419139, 0.8659441542814579, 0.9834871255235234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.04749427504982855], {
             RGBColor[
             0.9385746540363908, 0.953709658071889, 0.9888612678070817]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.04749427504982855], {
             RGBColor[
             0.95729765640055, 0.8676171094312803, 0.2886098880874237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.04749427504982855], {
             RGBColor[
             0.9681438957075961, 0.9757623500950843, 0.9388082545510954]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.04749427504982855], {
             RGBColor[
             0.7325843540421733, 0.7910197323158341, 0.9739808200870521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.04749427504982855], {
             RGBColor[
             0.8769164431457925, 0.5339881398676536, 0.21900840191784252`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.04749427504982855], {
             RGBColor[
             0.9930114837419424, 0.9913780831776869, 0.7654813303037337]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.04749427504982855], {
             RGBColor[
             0.9178500351233643, 0.9373327199046155, 0.9920265497961074]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.04749427504982855], {
             RGBColor[
             0.8618095558630786, 0.4653912930200163, 0.20640284486545354`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.04749427504982855], {
             RGBColor[
             0.9452007982386658, 0.9586514255686303, 0.9776449340478188]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.04749427504982855], {
             RGBColor[
             0.9865667541984358, 0.9887130218894524, 0.8722871772650572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.04749427504982855], {
             RGBColor[
             0.9839679220363194, 0.957582177896898, 0.39221883382533035`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.04749427504982855], {
             RGBColor[
             0.9206981435968882, 0.723301595678431, 0.25505006876548747`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.04749427504982855], {
             RGBColor[
             0.8240786323122333, 0.18608449604159155`, 0.17069103153610735`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.04749427504982855], {
             RGBColor[
             0.9457476207791645, 0.9590592449239945, 0.9767193061209144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.04749427504982855], {
             RGBColor[
             0.987704772047926, 0.9701874504401549, 0.40673579047551006`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.04749427504982855], {
             RGBColor[
             0.9663620604074782, 0.8981934725699218, 0.32382338598527444`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.04749427504982855], {
             RGBColor[
             0.9944920839974842, 0.9906274495433777, 0.6418755179226505]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.04749427504982855], {
             RGBColor[
             0.8722568284794268, 0.900977934521365, 0.9876778290448726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.04749427504982855], {
             RGBColor[
             0.8994058921588248, 0.6361074752915675, 0.23777414944115638`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.04749427504982855], {
             RGBColor[
             0.9171086821698045, 0.9367415851829367, 0.9919558388895833]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.04749427504982855], {
             RGBColor[
             0.7270990787813134, 0.7867345935924144, 0.9734340991118613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.04749427504982855], {
             RGBColor[
             0.9809432297810787, 0.9473791806884565, 0.3804684755789245]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.04749427504982855], {
             RGBColor[
             0.9884565451743657, 0.9727233577203601, 0.40965628711128554`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.04749427504982855], {
             RGBColor[
             0.46625595812502957`, 0.5775666172542704, 0.9511245234569046]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.04749427504982855], {
             RGBColor[
             0.9685694471669662, 0.976079725676706, 0.9380879069319779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.04749427504982855], {
             RGBColor[
             0.9544605567815447, 0.8571583132983479, 0.2822160989195559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.04749427504982855], {
             RGBColor[
             0.9934816864160848, 0.9884663112836303, 0.5318999766383936]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.04749427504982855], {
             RGBColor[
             0.9865667541984358, 0.9887130218894524, 0.8722871772650572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.04749427504982855], {
             RGBColor[
             0.9135226913580766, 0.6948533186292571, 0.24927653146462841`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.04749427504982855], {
             RGBColor[
             0.9698907949217005, 0.9770651846686784, 0.9358512098459012]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.04749427504982855], {
             RGBColor[
             0.9927123416539441, 0.9912543802366987, 0.7704388888567726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.04749427504982855], {
             RGBColor[
             0.9897931753528965, 0.9900472299520634, 0.8188170290253513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.04749427504982855], {
             RGBColor[
             0.9496563675353844, 0.8381113038384856, 0.2783505354832801]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.04749427504982855], {
             RGBColor[
             0.9952059081088513, 0.9921542471389033, 0.7195708672331839]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.04749427504982855], {
             RGBColor[
             0.8680468699567894, 0.49371347955783884`, 0.21160741263580465`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.04749427504982855], {
             RGBColor[
             0.8733786892928623, 0.5179240258849023, 0.21605641338467532`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.04749427504982855], {
             RGBColor[
             0.9948438792800629, 0.9913799040808542, 0.6801662634025103]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.04749427504982855], {
             RGBColor[
             0.9940755388352481, 0.9897365015605307, 0.596537147632005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.04749427504982855], {
             RGBColor[
             0.9949279354779463, 0.9915596917887416, 0.6893152618074027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.04749427504982855], {
             RGBColor[
             0.9879772168931427, 0.9892962844609515, 0.8489121602533195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.04749427504982855], {
             RGBColor[
             0.971905007670019, 0.9785673812384037, 0.9324416730538184]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.04749427504982855], {
             RGBColor[
             0.9462218506669682, 0.8244945889401162, 0.2755870425924801]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.04749427504982855], {
             RGBColor[
             0.9744934988982605, 0.9256227239518828, 0.3554124890286531]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.04749427504982855], {
             RGBColor[
             0.988158442869132, 0.9893712260593183, 0.8459087768333837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.04749427504982855], {
             RGBColor[
             0.9926376389696169, 0.9866609791419226, 0.4400306209473953]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.04749427504982855], {
             RGBColor[
             0.8612420446560898, 0.46281435717468994`, 0.20592929960336945`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.04749427504982855], {
             RGBColor[
             0.9952180639622157, 0.9921802472801042, 0.7208939568546597]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.04749427504982855], {
             RGBColor[
             0.8201314910246426, 0.1557450384568279, 0.16691124458145196`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.04749427504982855], {
             RGBColor[
             0.9804458781332427, 0.9457014967965854, 0.3785363583440595]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.04749427504982855], {
             RGBColor[
             0.9118814109800829, 0.9325735010267493, 0.9914572570970676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.04749427504982855], {
             RGBColor[
             0.9238959598189515, 0.735979871389826, 0.25762310676015365`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.04749427504982855], {
             RGBColor[
             0.6779601450587315, 0.7483468850986049, 0.9685363894278383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.04749427504982855], {
             RGBColor[
             0.9837351747049264, 0.9567970664964374, 0.3913146543935142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.04749427504982855], {
             RGBColor[
             0.9767649848703324, 0.982191944276915, 0.9242149993387477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.04749427504982855], {
             RGBColor[
             0.985275737097978, 0.988179153140787, 0.8936826716647992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.04749427504982855], {
             RGBColor[
             0.9717443982762828, 0.9784475990155289, 0.9327135428637752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.04749427504982855], {
             RGBColor[
             0.9546369303620211, 0.8578575757719253, 0.2823580132424272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.04749427504982855], {
             RGBColor[
             0.9225590801274535, 0.7306795889017849, 0.25654742197977487`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.04749427504982855], {
             RGBColor[
             0.9943850804695675, 0.9919461007243856, 0.7427172777726045]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.04749427504982855], {
             RGBColor[
             0.9529526306647755, 0.8511798887319484, 0.2810027861704282]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.04749427504982855], {
             RGBColor[
             0.9790380628859169, 0.9409526053966157, 0.3730672619518002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.04749427504982855], {
             RGBColor[
             0.8754998565530215, 0.5275557510020848, 0.21782636734111951`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.04749427504982855], {
             RGBColor[
             0.9940384391718025, 0.9896571491317717, 0.5924990782185225]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.04749427504982855], {
             RGBColor[
             0.9884565451743657, 0.9727233577203601, 0.40965628711128554`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.04749427504982855], {
             RGBColor[
             0.9852716110342906, 0.9881774469074173, 0.8937510512180084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.04749427504982855], {
             RGBColor[
             0.9845313126252594, 0.9594826266437937, 0.3944074998759769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.04749427504982855], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.04749427504982855], {
             RGBColor[
             0.9917473320534924, 0.9908553239672964, 0.7864315953010486]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.04749427504982855], {
             RGBColor[
             0.9810874331739317, 0.9478656125931162, 0.38102867852963246`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.04749427504982855], {
             RGBColor[
             0.9878267675390405, 0.9892340697866583, 0.8514054954012381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.04749427504982855], {
             RGBColor[
             0.9851252923236254, 0.9881169403603378, 0.8961759309144152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.04749427504982855], {
             RGBColor[
             0.9522190775116386, 0.9638856467590358, 0.9657648178990705]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.04749427504982855], {
             RGBColor[
             0.9925885769062781, 0.9865560403493764, 0.43469051812891896`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.04749427504982855], {
             RGBColor[
             0.9788461127780029, 0.9837440460629217, 0.9206921926361504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.04749427504982855], {
             RGBColor[
             0.9882738170483724, 0.9894189362474154, 0.8439967281045654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.04749427504982855], {
             RGBColor[
             0.9930275322996532, 0.9874949215506077, 0.48246810377912863`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.04749427504982855], {
             RGBColor[
             0.9595543209317215, 0.8752293687849516, 0.29737660365568697`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.04749427504982855], {
             RGBColor[
             0.9928819736512009, 0.987183586319805, 0.46662494317894465`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.04749427504982855], {
             RGBColor[
             0.8206537052921516, 0.15975900615265365`, 0.1674113175537753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.04749427504982855], {
             RGBColor[
             0.8872074463762193, 0.9128991514085555, 0.9891038323264428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.04749427504982855], {
             RGBColor[
             0.894377209148617, 0.61327340022097, 0.2335780930731389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.04749427504982855], {
             RGBColor[
             0.8214282851836687, 0.8604486338013805, 0.982829757210147]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.04749427504982855], {
             RGBColor[
             0.8245113068090247, 0.8629069515590466, 0.9831238185650193]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.04749427504982855], {
             RGBColor[
             0.946841406233682, 0.9598749883250642, 0.9748678126513514]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.04749427504982855], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.04749427504982855], {
             RGBColor[
             0.9693260450708614, 0.9081916888162077, 0.33533790670098085`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.04749427504982855], {
             RGBColor[
             0.9263837323720958, 0.745843060561984, 0.2596248269519407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.04749427504982855], {
             RGBColor[
             0.9125261456084376, 0.6909023468111233, 0.24847468736253359`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.04749427504982855], {
             RGBColor[
             0.9869514258424468, 0.9888720934998613, 0.8659121726254924]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.04749427504982855], {
             RGBColor[
             0.39337350226260415`, 0.5151420889579279, 0.9462863896110112]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.04749427504982855], {
             RGBColor[
             0.9571862996979603, 0.9675901929325147, 0.9573566063966598]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.04749427504982855], {
             RGBColor[
             0.9760834996160919, 0.9309861697230501, 0.36158934157098677`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.04749427504982855], {
             RGBColor[
             0.7583115826493424, 0.8111180388379341, 0.9765450697999941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.04749427504982855], {
             RGBColor[
             0.9942459399807285, 0.9918885625565033, 0.7450231957567086]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.04749427504982855], {
             RGBColor[
             0.9947943744673593, 0.9912740182921856, 0.6747779700480213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.04749427504982855], {
             RGBColor[
             0.994985511548349, 0.9916828411814992, 0.6955820617524114]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.04749427504982855], {
             RGBColor[
             0.9849898120359726, 0.9880609157797088, 0.8984211898925699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.04749427504982855], {
             RGBColor[
             0.8908400559107746, 0.5972120134910557, 0.23062660570792348`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.04749427504982855], {
             RGBColor[
             0.9774818742072997, 0.9357032155731622, 0.36702176279694565`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.04749427504982855], {
             RGBColor[
             0.8602694341097068, 0.4583979598425293, 0.2051177295226014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.04749427504982855], {
             RGBColor[
             0.985480263327163, 0.9882637299926393, 0.8902931427502889]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.04749427504982855], {
             RGBColor[
             0.9469981837546649, 0.9599919127435137, 0.9746024292024534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.04749427504982855], {
             RGBColor[
             0.8206537052921516, 0.15975900615265365`, 0.1674113175537753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.04749427504982855], {
             RGBColor[
             0.4852976397207995, 0.5930255121916967, 0.9526235543841015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.04749427504982855], {
             RGBColor[
             0.9523661497290931, 0.8488546872551539, 0.2805308898431012]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.04749427504982855], {
             RGBColor[
             0.9628692153371149, 0.9718285021112758, 0.9477369125613508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.04749427504982855], {
             RGBColor[
             0.8939216422639359, 0.6112047773979824, 0.23319795689759482`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.04749427504982855], {
             RGBColor[
             0.8641059885217754, 0.47581885737768465`, 0.20831904456658562`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.04749427504982855], {
             RGBColor[
             0.8328561379847585, 0.253552250968132, 0.17909638088089228`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.04749427504982855], {
             RGBColor[
             0.8817300614131385, 0.5558456561705619, 0.22302500299269676`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.04749427504982855], {
             RGBColor[
             0.9874398977713496, 0.9890740891956185, 0.8578169286387435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.04749427504982855], {
             RGBColor[
             0.9864531609950699, 0.9659654724666207, 0.40187351788207876`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.04749427504982855], {
             RGBColor[
             0.8303337606378229, 0.23416415336678328`, 0.17668094948484894`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.04749427504982855], {
             RGBColor[
             0.9934261579951669, 0.9883475416060712, 0.5258560507031602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.04749427504982855], {
             RGBColor[
             0.5870663443625044, 0.6756459312477308, 0.9606351596045449]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.04749427504982855], {
             RGBColor[
             0.9142104028703435, 0.6975798656091189, 0.2498298802900622]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.04749427504982855], {
             RGBColor[
             0.9952180639622157, 0.9921802472801042, 0.7208939568546597]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.04749427504982855], {
             RGBColor[
             0.9928249963382397, 0.9913009658437482, 0.7685719091970172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.04749427504982855], {
             RGBColor[
             0.8676340015483934, 0.49183874054317944`, 0.2112629051155083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.04749427504982855], {
             RGBColor[
             0.9045444957298604, 0.6592577647697164, 0.24205246451682833`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.04749427504982855], {
             RGBColor[
             0.9931992590352905, 0.9878622276738995, 0.5011594991786863]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.04749427504982855], {
             RGBColor[
             0.9538746655663902, 0.8548354498669339, 0.2817446770952082]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.04749427504982855], {
             RGBColor[
             0.8623293616116341, 0.4677516095204898, 0.20683658352365308`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.04749427504982855], {
             RGBColor[
             0.9857044016605165, 0.9883564169535735, 0.8865785905152088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.04749427504982855], {
             RGBColor[
             0.9628692153371149, 0.9718285021112758, 0.9477369125613508]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
          103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
          129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 
          142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 
          155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 
          168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 
          181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 
          194, 195, 196, 197, 198, 199, 200}, {Null, CompressedData["
1:eJwVxfk/GgwDAPA5ylXk6qBcTS9j5XjImZDN1UpNhz0LEUrEK0VRaK6QloU8
tcqVhcoRUpIjPX/W+3m/v3yzuSIaN/zdu3f/Rr579/9hmzOh+9CM1RqacVqd
ztDnw5llwRhsb3OPIwbOAK1AJ/AeGAo/BK7OrK5aV52r96uh7eeGjs8dHYcd
58D4+HuAADAGKy7eLN6bPA+/+3zXcXd4F56XN5l3jpls6Go46Tg5OT+5w+gm
dbpnzNTk1NTJ1PmXb7wZ3jJvlWflOXkh/wuQCCMS94hWohPNQYvRarV504w2
cAxiwwcDZyLdn/6iN+v9+peqCcCD4GFyZ3sHTSKpSVu6ra1nQF3dtzpB3Rhx
FNZd3P2l+1t392b3XmVD5efKjsouvd1st/vtL+HUPCq1gzpJnaKeUM+pd3gS
vhm/hb9B43AcnBhnCP+T9wc2WDzYPTi4ObgHmy+e754fnJ/fnLd/nPp48vH8
P/+t+juyIZIa2RF5EnkeeYdrqWpp4bRMtBgwRpJRbdQZt4yZmMy8TGrmZOZU
pi5zJ/OcJ5cvyJdr5DULfy01L6E1OA1Jw9GINWqNxoD24Xwcn9in8Rl8gPW6
dcH62Hp9Q31X/WhsfOw92oFzcBxih8ZhcDh8aBvOxrGJbWqbxmaw2XwwYbGQ
KBwUCkeFe+HHecfU447jw+PjOzyBQCKICQ7CTQ2NSKPxaKM0OW0hvLT0c+lh
6XHpHdBL8/K8cu+Md9m76rV6nV5viK1m69lmtj2LlsXLkmctZC1neWH7xfvE
/fr9wX3h/ug+oCi2KL6oqK5IUDRWtJ5Rn9GQ0ZUxmrEfefbxrOGMetZxNnV2
cnZ2nlyT3JW8AGQQGTQGg8cQMkYZMwwrw8nwMkJoGUnGlsnUMo3MIDPLbDJf
1T9//0Nsqm9qojUxmrqaRpvkf/5Fe/AegofkUXs0ni2P0cOWSNQSvcQssUv8
khecgqDgKMQKhUbhUNx8WWGvfFuRraxsrph/bP/YSS4pqSmhlchLFjKxGGwe
FjuJ1WF32EFJcD64EtwM6oPmoD34Esy8xFxiL3WXW5fGS2B1bHV8dVF19V71
PVsr0cq0aq1WrzVr7Vq/NohvJ7S3i9sV7Y72GxizmElk1jOZ3cxBppA5ytxk
7jH3kwsLSworC2sKuwApKYKUh8j8jPz8yvyG/I78rvyT/LP8u6xfy7/e/3i/
8/7P+38zronX9ddN17RrxjXzWng9er1/nXmKOc07xZ5Onk6d6k53Tk/PTy/R
IpwILyKISKJ2EUckEosUIo3IJnKIPCJfBCAiNiIloiiiLkIQcR/xkMnFcLFc
7iR3iqvjGrmn3Escn8Bv53P4fBFfzFfwNXwH/yZ5I3+jcKNyo2GjayN8OnM6
bxo7TZ3mTk9OT+9Mn0a+Zbzlv1W+1b81vHW8db1tvJ28nb1hAuyAJCALqAPa
gD5gDPgDf/1c+plVVlJWJi9bKFsu+4Vfa15bWlv7uXaT+j4Vm/ojdTt1J/UZ
28ft69P1bfUZ+y77ntEWnKXFwrHwLSLLhEVsUVg0FoPFYrM4LL4IJAAZi0xB
IouQdUgBcgy5jnwAgkDxIBioGkQEMUBMUDdICNoDWUFONOsDC8dicVgy1gpL
wzKwbCxf6mvma94r9pX7Ovk6/ap73Xk9fcVcka64V31XuqutK+PV5dWV5+oZ
ioGyoRKoDKqGaqF6qB8agDWmNxY3NjIbBxvnGzcb99EmnAlvIphIJr5JZBKb
FCaNyWgyOUweXG1VbW1LLaeWXztRK6611DqSc3IKc0pyanK6chbSKyokFfMV
+gp7hb/ipSIIhIAgECKEAeFBZiCrECvECfFCQvg2QltzW1t721LbWtsNrKCg
uKCxgFnQXTBYMF+wWbBXEIwgA8ix5BQyklxEriOTBeQx8jr5IX22YlYyO6uf
tc/6Z1+glAoKhU2RUGYpWoqeYqbYKX5KgPJCCULn0ucwcx/nKHOSuam52bk5
/1xg7iVnqGSobKhmaEg+tBCelpaXVppGTZtOO0w7TvuTdod/JDw2P7Y9tj8q
Hpce1x5vHvE9hJ62nvaeHn6PqEfco+gx9Th6bnoeUWgUDsVCsVEy1ApKjdKg
tCgDyoyyoXwgBAyBKEAUI4iIRgQT0Y0YRAgR84hNxB5iHz9MGCYN9w0Pi4Y1
w1vDxmHT8NWwB+pGudFuknvYLXLL3Gq3xq11G90mt83t9rh97kDqCHakb2Tk
x4huZHtkZ+R55BX4FPsEeop/gjwVPVU/WZ/un55CgJiYlBhkTF0MOUYQMxaz
HvMQhgr7EsYKY4fJwlbC1GHaMHOYLSwIUWYpicomJU3JUPKUo0q5ckapXFZa
lU7ltdKbvliwWLxYv9i4OLg4v7i4n3yRc1F4UXJRc9F0QbvoupBfKC8WLoB0
CD2LTmfQefQZ+jJ9lW6lO+leeigiDhAXExeXEoeMK4qriyPHCeLG4tbjHpq/
fl37+gwYiBn4MFA3QB5gDQwIBsYG1lM7sZ2dfZ0jnT86dZ3bnTudz52vUGm6
tEJKkUqk0lnpnFQr1Uv90oD0Jab3Q+/fvb0DvWO9673/4MrLq8pry1vKOeX8
8olycbmi3FLugKkQqgJVsape1ahiqrpVgyqhal6lWlRtqvZU+6rraHw0IZoU
3RbdE90XPRy9FW2MNkVfRXuin7P6S/rL+vuH+uX9C/3L/b+ScEnlSVVJtUkt
SZykiSRxkiHJkuRI8gHBIDAYAiaCm8A0MB3MAPPAQvAoeAasBK+CrWAn2AsO
hf9O+136+7+/fx/+PobC4enwCjgFzoZL4FL4LFwL18PtcD/8BR6E3mJuubfS
26nbuVvdrfH29Pby9ur2NhDemtaa11ra2kpt/d162Hrc+qf17q9Pn5o/LX1a
+/QzIgGQEJsQlxCfkIBMKEqoTqhLICcIEsYS1hOekrOz87MLsyuzG7K7sjey
36C58Nz03NyKXEquJFeaO5s7l6vPtef6c1+ALrAL4spyEV00F93FcPFcMy6l
a9m16rK6nC6X1xX69L35+9fv35e+r33/mXWQc1ByUHZQc0A76D8YOpAfLBws
HxxchI2jxr+Ms8bZ4+Oy8ZVx9bh23DxuGw9mHZUd0Y/6j3hH8qPlo19HR15A
YkxiXGJiSiIykZwoSBxLXE98aN79utu5O7K7tru1u727+xyVFPUhChdVHlUV
VRvVEsWK4kT1Rk1EGaIsUb7/AWRTyt8=
           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[31, 80] -> 
             RGBColor[
              0.7352027165067365, 0.7929678458962808, 0.9744115778147804], 
             UndirectedEdge[36, 132] -> 
             RGBColor[
              0.24999710016017773`, 0.3800931813729572, 0.937548337065331], 
             UndirectedEdge[16, 101] -> 
             RGBColor[
              0.28740281094428266`, 0.4180946549568002, 0.9397266599229551], 
             UndirectedEdge[86, 108] -> 
             RGBColor[
              0.5865960904370586, 0.6714707671165345, 0.9625129589589009], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.3936636675304358, 0.5153934155287933, 0.9463048786852943], 
             UndirectedEdge[29, 136] -> 
             RGBColor[
              0.950824845750427, 0.8323116913697606, 0.49992668872926316`], 
             UndirectedEdge[55, 157] -> 
             RGBColor[
              0.4550334300726567, 0.5657150158349769, 0.9509982940305055], 
             UndirectedEdge[7, 188] -> 
             RGBColor[
              0.5075570604878807, 0.6079623494198335, 0.955381071984007], 
             UndirectedEdge[19, 141] -> 
             RGBColor[
              0.31187008513103276`, 0.44044798095241544`, 0.9412431829967022],
              UndirectedEdge[62, 185] -> 
             RGBColor[
              0.5629039980331934, 0.6514450489037454, 0.9607937355315148], 
             UndirectedEdge[79, 144] -> 
             RGBColor[
              0.6389999811794337, 0.4008456236267517, 0.4461443465462792], 
             UndirectedEdge[47, 54] -> 
             RGBColor[
              0.3621640961349061, 0.48478721437619465`, 0.9444194198717641], 
             UndirectedEdge[32, 101] -> 
             RGBColor[
              0.2434980017964442, 0.3732622169260371, 0.9371782230280707], 
             UndirectedEdge[104, 163] -> 
             RGBColor[
              0.22597848605701326`, 0.35484809508244053`, 0.9361805125245111],
              UndirectedEdge[119, 125] -> 
             RGBColor[
              0.3719190998621983, 0.4815306199533135, 0.9461956553093709], 
             UndirectedEdge[9, 140] -> 
             RGBColor[
              0.2830352445403058, 0.4148183658558119, 0.9394298105122245], 
             UndirectedEdge[3, 63] -> 
             RGBColor[
              0.30825791983475437`, 0.437251051830131, 0.9410155180983026], 
             UndirectedEdge[50, 104] -> 
             RGBColor[
              0.2305835536607953, 0.3596883131121654, 0.9364427643119595], 
             UndirectedEdge[47, 61] -> 
             RGBColor[
              0.36265936899724993`, 0.48530777755663124`, 0.944447624928584], 
             UndirectedEdge[149, 195] -> 
             RGBColor[
              0.2062475040297809, 0.3341095819553035, 0.9350568622874322], 
             UndirectedEdge[99, 178] -> 
             RGBColor[
              0.7532636952500258, 0.8067917718917483, 0.970579392980242], 
             UndirectedEdge[160, 174] -> 
             RGBColor[
              0.37406119352792633`, 0.4984147377968103, 0.9450558263756417], 
             UndirectedEdge[6, 124] -> 
             RGBColor[
              0.3155531459350417, 0.4461023057398271, 0.9413876363800726], 
             UndirectedEdge[24, 197] -> 
             RGBColor[
              0.5339219982745609, 0.6098281505161249, 0.9613839453194717], 
             UndirectedEdge[80, 120] -> 
             RGBColor[
              0.7883329572883422, 0.7840663517109472, 0.6248876395864237], 
             UndirectedEdge[83, 187] -> 
             RGBColor[
              0.26933773838678554`, 0.40042141841641143`, 0.938649757800426], 
             UndirectedEdge[47, 167] -> 
             RGBColor[
              0.6833987505402253, 0.7503936163476059, 0.9708862787627], 
             UndirectedEdge[132, 150] -> 
             RGBColor[
              0.2675705658104447, 0.39856400799346436`, 0.938549119936501], 
             UndirectedEdge[17, 189] -> 
             RGBColor[
              0.23511483918268133`, 0.3644509814957634, 0.9367008143189947], 
             UndirectedEdge[69, 180] -> 
             RGBColor[
              0.5628268850068445, 0.6533109098577117, 0.9599708318719281], 
             UndirectedEdge[43, 95] -> 
             RGBColor[
              0.8967855212794014, 0.5986904854238292, 0.25888435369462925`], 
             UndirectedEdge[82, 86] -> 
             RGBColor[
              0.3552790109161934, 0.48214655523847394`, 0.943859042308054], 
             UndirectedEdge[7, 61] -> 
             RGBColor[
              0.3121285679978709, 0.4415405374828739, 0.9412278469715365], 
             UndirectedEdge[30, 65] -> 
             RGBColor[
              0.9079204151899432, 0.9294151105020584, 0.9910794537825813], 
             UndirectedEdge[62, 174] -> 
             RGBColor[
              0.36882264112374896`, 0.4938773670016114, 0.9447220304487174], 
             UndirectedEdge[18, 47] -> 
             RGBColor[
              0.38494609227374893`, 0.5078426899995235, 0.9457494024985874], 
             UndirectedEdge[56, 149] -> 
             RGBColor[
              0.2062475040297809, 0.3341095819553035, 0.9350568622874322], 
             UndirectedEdge[82, 163] -> 
             RGBColor[
              0.2758102937038249, 0.40631356017084397`, 0.9390517136501494], 
             UndirectedEdge[10, 48] -> 
             RGBColor[
              0.30320935155036544`, 0.43524999752426985`, 0.940606985973867], 
             UndirectedEdge[58, 92] -> 
             RGBColor[
              0.24643437763355744`, 0.3763485341078243, 0.9373454452880156], 
             UndirectedEdge[70, 72] -> 
             RGBColor[
              0.23177582019152226`, 0.36094146083002354`, 0.936510662127084], 
             UndirectedEdge[35, 181] -> 
             RGBColor[
              0.9113516048559902, 0.930874079920538, 0.9469017763992353], 
             UndirectedEdge[126, 174] -> 
             RGBColor[
              0.3443177986809051, 0.472511876251829, 0.9431657526324266], 
             UndirectedEdge[108, 154] -> 
             RGBColor[
              0.8838800631396134, 0.9088604535486795, 0.9258833443185683], 
             UndirectedEdge[63, 77] -> 
             RGBColor[
              0.3266232709961202, 0.4565542003312445, 0.9420613976778401], 
             UndirectedEdge[32, 100] -> 
             RGBColor[
              0.22448297168171977`, 0.35327621465291903`, 0.9360953451932534],
              UndirectedEdge[19, 50] -> 
             RGBColor[
              0.2533169376668154, 0.3835825410822887, 0.9377373969000744], 
             UndirectedEdge[80, 81] -> 
             RGBColor[
              0.5981154418108365, 0.6846160863124545, 0.9615049850298553], 
             UndirectedEdge[34, 163] -> 
             RGBColor[
              0.24238504014097356`, 0.3720924236602928, 0.9371148415082708], 
             UndirectedEdge[146, 194] -> 
             RGBColor[
              0.5723118578420975, 0.6584672801449877, 0.9618699351638069], 
             UndirectedEdge[13, 83] -> 
             RGBColor[
              0.316923827731624, 0.4440344737616491, 0.9415941582521057], 
             UndirectedEdge[30, 41] -> 
             RGBColor[
              0.7217306402299773, 0.781717727178925, 0.9737111260908631], 
             UndirectedEdge[35, 111] -> 
             RGBColor[
              0.6494345587146366, 0.7234252020636741, 0.9675585260086426], 
             UndirectedEdge[29, 144] -> 
             RGBColor[
              0.9022249366155904, 0.6208207570711475, 0.3861737156527596], 
             UndirectedEdge[6, 12] -> 
             RGBColor[
              0.4620072235822212, 0.5710418605945535, 0.9516398014511775], 
             UndirectedEdge[67, 143] -> 
             RGBColor[
              0.8190699438712857, 0.14758552186319893`, 0.16589470582855148`],
              UndirectedEdge[135, 163] -> 
             RGBColor[
              0.2331505740140204, 0.36238641426189583`, 0.9365889523235094], 
             UndirectedEdge[50, 60] -> 
             RGBColor[
              0.24809478057534154`, 0.3780937228752663, 0.9374400027792041], 
             UndirectedEdge[25, 143] -> 
             RGBColor[
              0.8735061292591867, 0.42076748591111013`, 0.23590476193812596`],
              UndirectedEdge[12, 13] -> 
             RGBColor[
              0.4809809724952037, 0.58747596825463, 0.9528487919540853], 
             UndirectedEdge[89, 144] -> 
             RGBColor[
              0.8548334539658015, 0.42247953211969835`, 0.20014188348416714`],
              UndirectedEdge[22, 24] -> 
             RGBColor[
              0.6225902394734423, 0.3300989620118385, 0.4379481515395359], 
             UndirectedEdge[107, 156] -> 
             RGBColor[
              0.7940373920785235, 0.8398425244747729, 0.979889552465069], 
             UndirectedEdge[23, 154] -> 
             RGBColor[
              0.9900533443030074, 0.9886857899175692, 0.707722631591383], 
             UndirectedEdge[101, 135] -> 
             RGBColor[
              0.2425616632808307, 0.3722780657788366, 0.9371248999347952], 
             UndirectedEdge[7, 42] -> 
             RGBColor[
              0.4359507962934013, 0.5501706892115099, 0.9495104580293312], 
             UndirectedEdge[122, 192] -> 
             RGBColor[
              0.8758587759165559, 0.41851937401271744`, 0.2670649130066242], 
             UndirectedEdge[129, 133] -> 
             RGBColor[
              0.8790384594977417, 0.4469900974919443, 0.2522656130299896], 
             UndirectedEdge[40, 80] -> 
             RGBColor[
              0.555739244439546, 0.6502131802605045, 0.9581689755436615], 
             UndirectedEdge[41, 172] -> 
             RGBColor[
              0.7718454040169196, 0.8174234076188627, 0.7717375932565325], 
             UndirectedEdge[94, 115] -> 
             RGBColor[
              0.34184068469654455`, 0.4665135495155001, 0.9431489820897013], 
             UndirectedEdge[87, 103] -> 
             RGBColor[
              0.9055186961480244, 0.6475369650177958, 0.42196747470883456`], 
             UndirectedEdge[142, 160] -> 
             RGBColor[
              0.5038004126414563, 0.6056953348255233, 0.9547299040233275], 
             UndirectedEdge[21, 150] -> 
             RGBColor[
              0.29956418872733326`, 0.4315020124177601, 0.9403963488781741], 
             UndirectedEdge[29, 142] -> 
             RGBColor[
              0.8172660326623933, 0.855490432397475, 0.8599437218958297], 
             UndirectedEdge[67, 103] -> 
             RGBColor[
              0.833567382441636, 0.252847633383231, 0.17953580679306383`], 
             UndirectedEdge[50, 163] -> 
             RGBColor[
              0.23762722721084206`, 0.36709166060796167`, 0.9368438911004533],
              UndirectedEdge[21, 46] -> 
             RGBColor[
              0.4569720284859443, 0.5663064733841641, 0.9514223432183879], 
             UndirectedEdge[43, 129] -> 
             RGBColor[
              0.9003301475995195, 0.6106473423194261, 0.27265455760177426`], 
             UndirectedEdge[11, 112] -> 
             RGBColor[
              0.2736557868068433, 0.4049599610859747, 0.9388956642699682], 
             UndirectedEdge[119, 195] -> 
             RGBColor[
              0.37190268566599016`, 0.4815133675923786, 0.9461947205451795], 
             UndirectedEdge[99, 109] -> 
             RGBColor[
              0.45081925257627997`, 0.561890841684138, 0.9507778651594582], 
             UndirectedEdge[45, 120] -> 
             RGBColor[
              0.9205644172331103, 0.7168104234407002, 0.25588752113131463`], 
             UndirectedEdge[29, 153] -> 
             RGBColor[
              0.7898065464682866, 0.8331975844693433, 0.8577820105552174], 
             UndirectedEdge[27, 125] -> 
             RGBColor[
              0.22785442897304503`, 0.35681983002884055`, 0.9362873446983702],
              UndirectedEdge[35, 157] -> 
             RGBColor[
              0.6980290555794366, 0.7628764037756551, 0.971384062809347], 
             UndirectedEdge[28, 112] -> 
             RGBColor[
              0.2981130439403854, 0.43066608901299275`, 0.9402884688824538], 
             UndirectedEdge[22, 89] -> 
             RGBColor[
              0.84761198290322, 0.36697214106389997`, 0.19322659463915418`], 
             UndirectedEdge[96, 116] -> 
             RGBColor[
              0.3478897367236583, 0.4755106363355533, 0.9433968344585502], 
             UndirectedEdge[23, 143] -> 
             RGBColor[
              0.8783920111917808, 0.4368059364020854, 0.2925360104669875], 
             UndirectedEdge[6, 14] -> 
             RGBColor[
              0.37841229319367853`, 0.5021834416346569, 0.945333074598817], 
             UndirectedEdge[9, 112] -> 
             RGBColor[
              0.28100806217130603`, 0.41268766865520734`, 0.9393143654752576],
              UndirectedEdge[12, 25] -> 
             RGBColor[
              0.7814420691727634, 0.8068428114651084, 0.666502637240134], 
             UndirectedEdge[176, 199] -> 
             RGBColor[
              0.28324272218403285`, 0.4150364380142114, 0.9394416260570992], 
             UndirectedEdge[48, 112] -> 
             RGBColor[
              0.3092759955003079, 0.44162642496310195`, 0.9409524723720207], 
             UndirectedEdge[79, 149] -> 
             RGBColor[
              0.21876808015896437`, 0.34726950131745254`, 0.9357698905754568],
              UndirectedEdge[58, 155] -> 
             RGBColor[
              0.25688825427596124`, 0.3873362212730521, 0.9379407780976758], 
             UndirectedEdge[118, 138] -> 
             RGBColor[
              0.9130416014388392, 0.812801149295034, 0.6201343733156849], 
             UndirectedEdge[172, 173] -> 
             RGBColor[
              0.9945590642006376, 0.9907707134251852, 0.6491658996819889], 
             UndirectedEdge[53, 104] -> 
             RGBColor[
              0.21517354122831484`, 0.34349141299440844`, 0.9355651869010002],
              UndirectedEdge[179, 185] -> 
             RGBColor[
              0.7887535289716312, 0.8348995186722672, 0.9795792385132371], 
             UndirectedEdge[82, 176] -> 
             RGBColor[
              0.30639768237766407`, 0.4384628450195025, 0.9407936201851381], 
             UndirectedEdge[142, 181] -> 
             RGBColor[
              0.8126094756619291, 0.8535648264097266, 0.9371149221767408], 
             UndirectedEdge[54, 160] -> 
             RGBColor[
              0.3197591214680627, 0.448058156655773, 0.9417174123832397], 
             UndirectedEdge[121, 151] -> 
             RGBColor[
              0.4472759744708069, 0.5594034354051198, 0.9503913919352824], 
             UndirectedEdge[138, 144] -> 
             RGBColor[
              0.8752691557383894, 0.5209048945205916, 0.21739381612783068`], 
             UndirectedEdge[171, 196] -> 
             RGBColor[
              0.6848218020180831, 0.7518929600057571, 0.9706449762400708], 
             UndirectedEdge[120, 172] -> 
             RGBColor[
              0.9753727800277856, 0.9276792174007213, 0.4361680487899127], 
             UndirectedEdge[113, 159] -> 
             RGBColor[
              0.8485303397063004, 0.33009952954163524`, 0.19238576661614035`],
              UndirectedEdge[103, 108] -> 
             RGBColor[
              0.8366047008902185, 0.5941132685295566, 0.465258687547469], 
             UndirectedEdge[64, 176] -> 
             RGBColor[
              0.45839978276888355`, 0.5655229499724335, 0.9517490792275327], 
             UndirectedEdge[83, 101] -> 
             RGBColor[
              0.2538463417938609, 0.3841389783859738, 0.9377675456819266], 
             UndirectedEdge[15, 63] -> 
             RGBColor[
              0.33898161598962545`, 0.46803057088396705`, 0.9428205867145535],
              UndirectedEdge[55, 72] -> 
             RGBColor[
              0.3011292819316679, 0.4298018950317811, 0.9406079602011264], 
             UndirectedEdge[105, 142] -> 
             RGBColor[
              0.4920496854617956, 0.5955174455512221, 0.9539811580781995], 
             UndirectedEdge[96, 105] -> 
             RGBColor[
              0.32470350781154744`, 0.4554278902256328, 0.9419194284550477], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.3349775869314745, 0.46456248216214874`, 0.942565453523592], 
             UndirectedEdge[64, 108] -> 
             RGBColor[
              0.7019176077126746, 0.7667599945944428, 0.9711311636805353], 
             UndirectedEdge[56, 119] -> 
             RGBColor[
              0.37190268566599016`, 0.4815133675923786, 0.9461947205451795], 
             UndirectedEdge[68, 157] -> 
             RGBColor[
              0.7066548099945791, 0.7697543462064234, 0.9722067949657651], 
             UndirectedEdge[137, 161] -> 
             RGBColor[
              0.2794230248160247, 0.4110216938976339, 0.939224099942727], 
             UndirectedEdge[160, 188] -> 
             RGBColor[
              0.5156828868204164, 0.6150005317731692, 0.9558988424525301], 
             UndirectedEdge[127, 187] -> 
             RGBColor[
              0.3022073859943112, 0.43378220468743567`, 0.9405651083800737], 
             UndirectedEdge[41, 141] -> 
             RGBColor[
              0.4545263425380657, 0.5654922255819677, 0.9509061844081543], 
             UndirectedEdge[137, 175] -> 
             RGBColor[
              0.2852924893069724, 0.4161135758232565, 0.9395978023974743], 
             UndirectedEdge[1, 122] -> 
             RGBColor[
              0.9756254576616791, 0.9291724163168037, 0.38265572153063876`], 
             UndirectedEdge[60, 177] -> 
             RGBColor[
              0.273782020378095, 0.40509264057303096`, 0.9389028530851051], 
             UndirectedEdge[72, 75] -> 
             RGBColor[
              0.26701897159742227`, 0.39798424750248473`, 0.9385177074620799],
              UndirectedEdge[13, 69] -> 
             RGBColor[
              0.38979245396039097`, 0.512040364907272, 0.9460582083797908], 
             UndirectedEdge[48, 77] -> 
             RGBColor[
              0.30874838296909257`, 0.4410718707402281, 0.9409224256189008], 
             UndirectedEdge[22, 183] -> 
             RGBColor[
              0.8495847316428689, 0.3805569710517512, 0.19505388777575874`], 
             UndirectedEdge[16, 86] -> 
             RGBColor[
              0.3574604388898408, 0.48403599850748935`, 0.9439980409695737], 
             UndirectedEdge[8, 62] -> 
             RGBColor[
              0.40221602470153694`, 0.5228010374564311, 0.9468498273216844], 
             UndirectedEdge[26, 51] -> 
             RGBColor[
              0.3392714220793772, 0.4658216765666159, 0.9429291222497664], 
             UndirectedEdge[117, 121] -> 
             RGBColor[
              0.6608369282647062, 0.733443073990961, 0.9678737418567172], 
             UndirectedEdge[89, 136] -> 
             RGBColor[
              0.8719970463971514, 0.5016704079877174, 0.2145036241613812], 
             UndirectedEdge[81, 168] -> 
             RGBColor[
              0.7574630871375609, 0.8103278215593543, 0.974310777757218], 
             UndirectedEdge[172, 198] -> 
             RGBColor[
              0.8450687656775151, 0.8760452560467036, 0.7780654976273946], 
             UndirectedEdge[55, 68] -> 
             RGBColor[
              0.6040034340544339, 0.6836766872491769, 0.9648829517187356], 
             UndirectedEdge[156, 192] -> 
             RGBColor[
              0.8518272488984739, 0.40265794141667954`, 0.4402493642261227], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.3132800245584588, 0.44509451368492026`, 0.9412076055629822], 
             UndirectedEdge[25, 154] -> 
             RGBColor[
              0.9827245214041163, 0.9646281141811062, 0.6227757587980907], 
             UndirectedEdge[100, 135] -> 
             RGBColor[
              0.2235466331661063, 0.3522920635057185, 0.9360420220999779], 
             UndirectedEdge[37, 149] -> 
             RGBColor[
              0.21228087842813756`, 0.34045104098600754`, 0.9354004540338412],
              UndirectedEdge[125, 149] -> 
             RGBColor[
              0.206263918225989, 0.33412683431623835`, 0.9350577970516237], 
             UndirectedEdge[2, 184] -> 
             RGBColor[
              0.37412689727752746`, 0.49847164708234826`, 0.9450600129604667],
              UndirectedEdge[6, 16] -> 
             RGBColor[
              0.3315065479690632, 0.46155604267239897`, 0.9423442819902264], 
             UndirectedEdge[55, 111] -> 
             RGBColor[
              0.40643893320785657`, 0.5262638141229958, 0.9471727572298012], 
             UndirectedEdge[34, 50] -> 
             RGBColor[
              0.2469901077447556, 0.3769326416900177, 0.9373770932957193], 
             UndirectedEdge[56, 125] -> 
             RGBColor[
              0.17894341419620807`, 0.3054112523609348, 0.9335019347641915], 
             UndirectedEdge[98, 196] -> 
             RGBColor[
              0.7343309142909232, 0.7903956980318739, 0.9415812202273133], 
             UndirectedEdge[160, 167] -> 
             RGBColor[
              0.6409937758733817, 0.7136645586271843, 0.9681842712741754], 
             UndirectedEdge[22, 149] -> 
             RGBColor[
              0.6408039078801677, 0.34924268232058286`, 0.43898539301059114`],
              UndirectedEdge[147, 194] -> 
             RGBColor[
              0.41461252572283636`, 0.5327948903127648, 0.9478451176521548], 
             UndirectedEdge[83, 161] -> 
             RGBColor[
              0.28225365624559345`, 0.41399686700250915`, 0.9393853002150969],
              UndirectedEdge[34, 177] -> 
             RGBColor[
              0.27267734754750905`, 0.40393155938778236`, 0.9388399436016203],
              UndirectedEdge[70, 145] -> 
             RGBColor[
              0.2107154956867174, 0.33880572447377666`, 0.9353113078024935], 
             UndirectedEdge[125, 170] -> 
             RGBColor[
              0.18066259612527297`, 0.307218221570812, 0.93359983963175], 
             UndirectedEdge[190, 192] -> 
             RGBColor[
              0.6047816873553487, 0.19148929823006858`, 0.42066047446022103`],
              UndirectedEdge[122, 188] -> 
             RGBColor[
              0.8287961614327686, 0.8626280708354541, 0.7199844478872237], 
             UndirectedEdge[123, 130] -> 
             RGBColor[
              0.24382776690061642`, 0.3736088209588374, 0.9371970026629095], 
             UndirectedEdge[94, 116] -> 
             RGBColor[
              0.4038551160855868, 0.5242207360301667, 0.9469542687752844], 
             UndirectedEdge[23, 162] -> 
             RGBColor[
              0.9882402059749112, 0.9877215722762983, 0.728168038634343], 
             UndirectedEdge[116, 160] -> 
             RGBColor[
              0.3781472802574135, 0.5019539007492015, 0.9453161882088599], 
             UndirectedEdge[80, 117] -> 
             RGBColor[
              0.699447709361209, 0.7647890454809683, 0.9709133239805854], 
             UndirectedEdge[147, 185] -> 
             RGBColor[
              0.625134594396598, 0.7046026904109504, 0.9649644103506239], 
             UndirectedEdge[55, 107] -> 
             RGBColor[
              0.5098065457970684, 0.609801290788619, 0.955570731517623], 
             UndirectedEdge[111, 174] -> 
             RGBColor[
              0.4209532104070455, 0.5388353515241499, 0.9480975941384622], 
             UndirectedEdge[126, 142] -> 
             RGBColor[
              0.47405701779443504`, 0.579792473280542, 0.9528398302801124], 
             UndirectedEdge[115, 160] -> 
             RGBColor[
              0.31613284886837134`, 0.44424671423453505`, 0.9415109015232768],
              UndirectedEdge[74, 164] -> 
             RGBColor[
              0.29875283098362904`, 0.4313385457602833, 0.9403249038080864], 
             UndirectedEdge[42, 97] -> 
             RGBColor[
              0.401201459999004, 0.517503689481011, 0.9473903200062829], 
             UndirectedEdge[25, 108] -> 
             RGBColor[
              0.8800770451068233, 0.8847917621519991, 0.6757220357685101], 
             UndirectedEdge[67, 133] -> 
             RGBColor[
              0.8199464110752147, 0.15432243286297473`, 0.166734011812862], 
             UndirectedEdge[38, 183] -> 
             RGBColor[
              0.8948764104777984, 0.602162747374174, 0.2424745440128403], 
             UndirectedEdge[33, 41] -> 
             RGBColor[
              0.4363770738073567, 0.5497722412161976, 0.9497497290534018], 
             UndirectedEdge[32, 123] -> 
             RGBColor[
              0.24279155375346242`, 0.3725196952414703, 0.9371379918571192], 
             UndirectedEdge[61, 116] -> 
             RGBColor[
              0.3316898960628568, 0.4584835766718288, 0.9424742774984342], 
             UndirectedEdge[93, 134] -> 
             RGBColor[
              0.2274998629101822, 0.35644715861598486`, 0.9362671526856237], 
             UndirectedEdge[45, 128] -> 
             RGBColor[
              0.8869707508914968, 0.5796424030976618, 0.22739796275449303`], 
             UndirectedEdge[29, 35] -> 
             RGBColor[
              0.9160081618564544, 0.9327996859082862, 0.8697305761183244], 
             UndirectedEdge[3, 106] -> 
             RGBColor[
              0.26935764073949675`, 0.40044233705099297`, 0.93865089120997], 
             UndirectedEdge[77, 140] -> 
             RGBColor[
              0.3029488619339533, 0.43574884033280226`, 0.9405638615632359], 
             UndirectedEdge[79, 195] -> 
             RGBColor[
              0.1914475761291835, 0.31855391936214905`, 0.9342140282880245], 
             UndirectedEdge[38, 46] -> 
             RGBColor[
              0.7812753615379626, 0.7886327284729578, 0.6396314180362879], 
             UndirectedEdge[14, 59] -> 
             RGBColor[
              0.43278883650636024`, 0.549281670407568, 0.9487978998554119], 
             UndirectedEdge[126, 191] -> 
             RGBColor[
              0.2937278856939699, 0.4260570096609187, 0.9400387406075807], 
             UndirectedEdge[13, 64] -> 
             RGBColor[
              0.5003009692996179, 0.6031608120163909, 0.9543697328740091], 
             UndirectedEdge[3, 11] -> 
             RGBColor[
              0.2547628231142621, 0.3851022583619874, 0.9378197379373108], 
             UndirectedEdge[31, 98] -> 
             RGBColor[
              0.9119983758560902, 0.9316922814327566, 0.9576824339727095], 
             UndirectedEdge[25, 162] -> 
             RGBColor[
              0.9809113830760201, 0.9636638965398352, 0.6432211658410507], 
             UndirectedEdge[126, 157] -> 
             RGBColor[
              0.43245489742186133`, 0.5460179978079216, 0.9495647589707952], 
             UndirectedEdge[128, 183] -> 
             RGBColor[
              0.8698008244556358, 0.5016777772906199, 0.21307095526300113`], 
             UndirectedEdge[22, 192] -> 
             RGBColor[
              0.8353875718603139, 0.2730099610170472, 0.18152048481896965`], 
             UndirectedEdge[99, 194] -> 
             RGBColor[
              0.45631234328201786`, 0.5666486807626816, 0.9511278800418784], 
             UndirectedEdge[21, 151] -> 
             RGBColor[
              0.33403902527338425`, 0.46374954722739153`, 0.9425056492046759],
              UndirectedEdge[48, 59] -> 
             RGBColor[
              0.382953798860026, 0.5061170655801353, 0.9456224553239809], 
             UndirectedEdge[18, 115] -> 
             RGBColor[
              0.2919621879503136, 0.4233113026000546, 0.9399707683828544], 
             UndirectedEdge[29, 89] -> 
             RGBColor[
              0.9005424949414248, 0.6078887731128675, 0.3845626076055324], 
             UndirectedEdge[15, 140] -> 
             RGBColor[
              0.31530720692745856`, 0.4472252108855248, 0.9413230505999493], 
             UndirectedEdge[113, 136] -> 
             RGBColor[
              0.9041543846818847, 0.6565805366270306, 0.24168008890791598`], 
             UndirectedEdge[111, 160] -> 
             RGBColor[
              0.41360379540408243`, 0.5324696576409218, 0.9476292959133059], 
             UndirectedEdge[116, 188] -> 
             RGBColor[
              0.5271183885528666, 0.6249053886087885, 0.9566275025109046], 
             UndirectedEdge[82, 127] -> 
             RGBColor[
              0.32009303423134106`, 0.45167023073266444`, 0.9416170229874327],
              UndirectedEdge[25, 95] -> 
             RGBColor[
              0.9792736576371948, 0.9417473218129542, 0.37398250307217895`], 
             UndirectedEdge[62, 111] -> 
             RGBColor[
              0.40836524299990506`, 0.527932286845723, 0.9472954999863816], 
             UndirectedEdge[162, 180] -> 
             RGBColor[
              0.853484717444914, 0.8855675982797966, 0.9434799440471393], 
             UndirectedEdge[89, 159] -> 
             RGBColor[
              0.8435429758673372, 0.3356959699358522, 0.18933010890630664`], 
             UndirectedEdge[7, 153] -> 
             RGBColor[
              0.46821510011481404`, 0.5763643045440561, 0.9520504222141921], 
             UndirectedEdge[146, 183] -> 
             RGBColor[
              0.8386384964590899, 0.584723475070088, 0.463315779566298], 
             UndirectedEdge[144, 197] -> 
             RGBColor[
              0.8673162616632236, 0.5950284434012776, 0.4642576245133444], 
             UndirectedEdge[120, 128] -> 
             RGBColor[
              0.9231751810131911, 0.7286652920066743, 0.2580660064250903], 
             UndirectedEdge[74, 166] -> 
             RGBColor[
              0.34685352759081295`, 0.47429746798031186`, 0.9433423658444682],
              UndirectedEdge[147, 152] -> 
             RGBColor[
              0.3812177118441309, 0.5013730508472783, 0.9458086544862003], 
             UndirectedEdge[22, 190] -> 
             RGBColor[
              0.6228502592156624, 0.3303722592471158, 0.4379629592791906], 
             UndirectedEdge[27, 128] -> 
             RGBColor[
              0.5831652721126257, 0.49985421349972364`, 0.5843241339583132], 
             UndirectedEdge[47, 88] -> 
             RGBColor[
              0.5818581666070413, 0.6702991325141743, 0.9609700518092634], 
             UndirectedEdge[69, 177] -> 
             RGBColor[
              0.3475961861623531, 0.47409235374214537`, 0.9434207502916752], 
             UndirectedEdge[122, 167] -> 
             RGBColor[
              0.9541070504857341, 0.9612920976894692, 0.7322698767088691], 
             UndirectedEdge[1, 78] -> 
             RGBColor[
              0.9431385588038124, 0.9082192270955545, 0.6427719916956993], 
             UndirectedEdge[138, 159] -> 
             RGBColor[
              0.8526881995414608, 0.34733777015289946`, 0.19577026697210964`],
              UndirectedEdge[101, 127] -> 
             RGBColor[
              0.28671598940138643`, 0.417499764656998, 0.9396828962615742], 
             UndirectedEdge[65, 90] -> 
             RGBColor[
              0.6550212395891795, 0.7255799866641114, 0.9691860218299977], 
             UndirectedEdge[64, 127] -> 
             RGBColor[
              0.4720951346225606, 0.5787303356855954, 0.9525724820298272], 
             UndirectedEdge[117, 146] -> 
             RGBColor[
              0.7875464410912392, 0.8339565324458974, 0.9794589272741974], 
             UndirectedEdge[49, 103] -> 
             RGBColor[
              0.8445886551123987, 0.33756196468319305`, 0.19008978994933337`],
              UndirectedEdge[88, 113] -> 
             RGBColor[
              0.8062483508925926, 0.7076340176229743, 0.6052352623718941], 
             UndirectedEdge[13, 176] -> 
             RGBColor[
              0.3360981234854725, 0.4641878743195114, 0.9426861060294587], 
             UndirectedEdge[17, 112] -> 
             RGBColor[
              0.27014379762534146`, 0.4012686377832412, 0.938695661681604], 
             UndirectedEdge[129, 170] -> 
             RGBColor[
              0.5863125273607737, 0.6439068649740138, 0.6751789886764388], 
             UndirectedEdge[35, 116] -> 
             RGBColor[
              0.6139780435679677, 0.6929094451719539, 0.9652454183041966], 
             UndirectedEdge[69, 110] -> 
             RGBColor[
              0.503306311820726, 0.6062411074789984, 0.9544293736590629], 
             UndirectedEdge[47, 126] -> 
             RGBColor[
              0.37937335834478547`, 0.5028752400890226, 0.9453994618957948], 
             UndirectedEdge[83, 137] -> 
             RGBColor[
              0.2530177140174724, 0.383268038054954, 0.9377203565559061], 
             UndirectedEdge[72, 84] -> 
             RGBColor[
              0.256326539038239, 0.386745822943403, 0.9379087892458708], 
             UndirectedEdge[22, 37] -> 
             RGBColor[
              0.626612488125885, 0.33432660037084994`, 0.4381772126499089], 
             UndirectedEdge[90, 141] -> 
             RGBColor[
              0.37364371183420664`, 0.49805313613695035`, 0.9450292248112824],
              UndirectedEdge[24, 79] -> 
             RGBColor[
              0.1914475775488761, 0.318553920854336, 0.9342140283688739], 
             UndirectedEdge[34, 130] -> 
             RGBColor[
              0.2444860062107015, 0.3743006722085195, 0.9372344884178412], 
             UndirectedEdge[157, 174] -> 
             RGBColor[
              0.4695477072718456, 0.5782865532361309, 0.9519231309391665], 
             UndirectedEdge[131, 180] -> 
             RGBColor[
              0.811663417266584, 0.70990288285835, 0.6053916520008711], 
             UndirectedEdge[3, 48] -> 
             RGBColor[
              0.29038303180772673`, 0.42176872223911466`, 0.9398765460393633],
              UndirectedEdge[49, 67] -> 
             RGBColor[
              0.8292269673761329, 0.22565685535753427`, 0.17562108300751042`],
              UndirectedEdge[79, 190] -> 
             RGBColor[
              0.19183760716220638`, 0.3189638667072519, 0.9342362399783559], 
             UndirectedEdge[13, 82] -> 
             RGBColor[
              0.34829886890839834`, 0.4761007070634601, 0.9434142738316145], 
             UndirectedEdge[68, 138] -> 
             RGBColor[
              0.8842002449557951, 0.7898038345132208, 0.6173834589873493], 
             UndirectedEdge[153, 160] -> 
             RGBColor[
              0.4763409264473496, 0.5834024868973917, 0.9525681926827152], 
             UndirectedEdge[178, 183] -> 
             RGBColor[
              0.8874176158778669, 0.6233741459180975, 0.46398946432897215`], 
             UndirectedEdge[2, 166] -> 
             RGBColor[
              0.3840226301972896, 0.5070428335634479, 0.9456905603116609], 
             UndirectedEdge[32, 53] -> 
             RGBColor[
              0.2232819677009355, 0.3520138833210643, 0.9360269497932738], 
             UndirectedEdge[26, 184] -> 
             RGBColor[
              0.38376793461067366`, 0.5068222290476936, 0.9456743313341002], 
             UndirectedEdge[61, 115] -> 
             RGBColor[
              0.2696754646738146, 0.40077639015716227`, 0.938668990812851], 
             UndirectedEdge[146, 178] -> 
             RGBColor[
              0.8692632098101054, 0.8986103712740543, 0.9813214481021706], 
             UndirectedEdge[88, 102] -> 
             RGBColor[
              0.5430147651889159, 0.6366549305319157, 0.9584949846187718], 
             UndirectedEdge[118, 159] -> 
             RGBColor[
              0.852865483210531, 0.4279441020790433, 0.443409538968764], 
             UndirectedEdge[62, 75] -> 
             RGBColor[
              0.3201980535903144, 0.44948818207116104`, 0.9417069408010099], 
             UndirectedEdge[89, 197] -> 
             RGBColor[
              0.865633819989058, 0.5820964594429976, 0.4626465164661172], 
             UndirectedEdge[85, 146] -> 
             RGBColor[
              0.578124805971577, 0.6635021636474746, 0.9622403310784291], 
             UndirectedEdge[170, 190] -> 
             RGBColor[
              0.1810362129620878, 0.3076109165549801, 0.93362111655789], 
             UndirectedEdge[82, 101] -> 
             RGBColor[
              0.2852213829706352, 0.4162052116877847, 0.9395876612614353], 
             UndirectedEdge[7, 73] -> 
             RGBColor[
              0.3217974307185043, 0.4517031252435637, 0.941778474399676], 
             UndirectedEdge[19, 34] -> 
             RGBColor[
              0.25807475059694696`, 0.38858330413461983`, 0.938008347307892], 
             UndirectedEdge[56, 170] -> 
             RGBColor[
              0.1806461819290649, 0.30720096920987716`, 0.9335989048675586], 
             UndirectedEdge[32, 187] -> 
             RGBColor[
              0.2589893983893689, 0.38954465695647483`, 0.9380604351465702], 
             UndirectedEdge[74, 169] -> 
             RGBColor[
              0.28768269698087445`, 0.4197031330363533, 0.9396944760534252], 
             UndirectedEdge[55, 147] -> 
             RGBColor[
              0.41653896028796467`, 0.5344634711076623, 0.9479678683591656], 
             UndirectedEdge[49, 143] -> 
             RGBColor[
              0.8300912165420485, 0.23229985316316096`, 0.17644868898482102`],
              UndirectedEdge[28, 77] -> 
             RGBColor[
              0.29758543140917015`, 0.4301115347901189, 0.9402584221293339], 
             UndirectedEdge[122, 153] -> 
             RGBColor[
              0.7894542010597019, 0.8310300259596766, 0.7166537981174088], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.45346195936104267`, 0.5636403822236367, 0.9510953047712845], 
             UndirectedEdge[16, 199] -> 
             RGBColor[
              0.29762489558060606`, 0.42883871402717555`, 0.9403087925207747],
              UndirectedEdge[64, 180] -> 
             RGBColor[
              0.6733354003460714, 0.7444313569668306, 0.9682823563661463], 
             UndirectedEdge[38, 128] -> 
             RGBColor[
              0.9271948937048214, 0.742224726788967, 0.2736818311730274], 
             UndirectedEdge[46, 98] -> 
             RGBColor[
              0.7856154181292234, 0.8320307685883754, 0.9456185242307917], 
             UndirectedEdge[68, 142] -> 
             RGBColor[
              0.7482569303671527, 0.8035288216790438, 0.9754818662750824], 
             UndirectedEdge[5, 20] -> 
             RGBColor[
              0.2538041540046914, 0.3840946363446963, 0.9377651431497445], 
             UndirectedEdge[169, 200] -> 
             RGBColor[
              0.2545855584826314, 0.3849159419949167, 0.9378096429787789], 
             UndirectedEdge[27, 133] -> 
             RGBColor[
              0.6412015723944939, 0.2567918854277903, 0.42640249711352196`], 
             UndirectedEdge[32, 135] -> 
             RGBColor[
              0.23421532693659433`, 0.36350553709275546`, 0.9366495884272892],
              UndirectedEdge[144, 190] -> 
             RGBColor[
              0.6309129511153266, 0.3923456422820542, 0.44568380214781717`], 
             UndirectedEdge[62, 126] -> 
             RGBColor[
              0.33172983127376465`, 0.4616088115734021, 0.9423636584803461], 
             UndirectedEdge[55, 62] -> 
             RGBColor[
              0.35430836392456, 0.4813058296004574, 0.9437971935400564], 
             UndirectedEdge[62, 76] -> 
             RGBColor[
              0.3162924905225524, 0.44538318765994256`, 0.9414845247620637], 
             UndirectedEdge[157, 181] -> 
             RGBColor[
              0.7710073552893554, 0.8197903509371063, 0.9338398508674235], 
             UndirectedEdge[64, 82] -> 
             RGBColor[
              0.4706005281918093, 0.5774357827163821, 0.9524772470296884], 
             UndirectedEdge[142, 153] -> 
             RGBColor[
              0.6134295605638427, 0.6970487778093326, 0.9627105685555573], 
             UndirectedEdge[21, 109] -> 
             RGBColor[
              0.32687230511240406`, 0.45754209443377936`, 0.9420489921333002],
              UndirectedEdge[66, 198] -> 
             RGBColor[
              0.6938904051885131, 0.7607917253864516, 0.97012416888083], 
             UndirectedEdge[141, 198] -> 
             RGBColor[
              0.5277497041986612, 0.6241140740098087, 0.9572340887790165], 
             UndirectedEdge[10, 28] -> 
             RGBColor[
              0.292046399990443, 0.42428966157416065`, 0.9399429824843], 
             UndirectedEdge[31, 151] -> 
             RGBColor[
              0.6011924048521665, 0.6814178617192261, 0.9646228375029955], 
             UndirectedEdge[111, 142] -> 
             RGBColor[
              0.5506924295205754, 0.6461159485528629, 0.957771671786148], 
             UndirectedEdge[111, 181] -> 
             RGBColor[
              0.7224128584245553, 0.7803391492251253, 0.9300143140667192], 
             UndirectedEdge[86, 101] -> 
             RGBColor[
              0.3219019660862388, 0.44797608916280746`, 0.9419249155821955], 
             UndirectedEdge[119, 144] -> 
             RGBColor[
              0.7593033875373049, 0.5094852557802381, 0.45413147471771587`], 
             UndirectedEdge[5, 102] -> 
             RGBColor[
              0.32802099544168023`, 0.45608332647208405`, 0.9422120278540836],
              UndirectedEdge[157, 185] -> 
             RGBColor[
              0.6636290641812901, 0.7358542351382649, 0.9679948360219639], 
             UndirectedEdge[13, 110] -> 
             RGBColor[
              0.49151316787654187`, 0.5960264789351953, 0.9536779249552072], 
             UndirectedEdge[32, 82] -> 
             RGBColor[
              0.27687504662639884`, 0.4074326830017036, 0.9391123497539292], 
             UndirectedEdge[12, 23] -> 
             RGBColor[
              0.7887708920716545, 0.8309004872015715, 0.7514495100334264], 
             UndirectedEdge[53, 130] -> 
             RGBColor[
              0.22431818084808952`, 0.35310300903843134`, 0.9360859605990643],
              UndirectedEdge[74, 80] -> 
             RGBColor[
              0.46133983359188224`, 0.5689367397653611, 0.9518870537804123], 
             UndirectedEdge[35, 185] -> 
             RGBColor[
              0.8039733137479249, 0.8469379641216965, 0.9810567615537757], 
             UndirectedEdge[117, 196] -> 
             RGBColor[
              0.6370858970808988, 0.7141609169041846, 0.966003973679034], 
             UndirectedEdge[22, 181] -> 
             RGBColor[
              0.8910578733822835, 0.5575636367110436, 0.4299003396380736], 
             UndirectedEdge[143, 197] -> 
             RGBColor[
              0.8435046260386568, 0.41200177766559354`, 0.4414555753478633], 
             UndirectedEdge[16, 124] -> 
             RGBColor[
              0.3070078817138632, 0.43870082736891025`, 0.9408431397001796], 
             UndirectedEdge[182, 191] -> 
             RGBColor[
              0.2726772055917506, 0.4039314101832797, 0.9388399355174497], 
             UndirectedEdge[98, 146] -> 
             RGBColor[
              0.8847914583012635, 0.9101913135735867, 0.9550361738224766], 
             UndirectedEdge[156, 183] -> 
             RGBColor[
              0.8802215684635839, 0.6177519614860875, 0.46731617013970106`], 
             UndirectedEdge[6, 13] -> 
             RGBColor[
              0.35902556110322426`, 0.48539162870339236`, 0.9440977691730272],
              UndirectedEdge[50, 100] -> 
             RGBColor[
              0.2280232863629279, 0.35699730985178435`, 0.9362969608769219], 
             UndirectedEdge[13, 175] -> 
             RGBColor[
              0.34919860302112393`, 0.4768800115299515, 0.9434716040936737], 
             UndirectedEdge[62, 116] -> 
             RGBColor[
              0.37290872785323614`, 0.4974165299540027, 0.9449823922819357], 
             UndirectedEdge[120, 171] -> 
             RGBColor[
              0.9156195043648556, 0.8842880492213061, 0.6372222517571104], 
             UndirectedEdge[72, 139] -> 
             RGBColor[
              0.24951735884561907`, 0.3795889428339999, 0.9375210165071806], 
             UndirectedEdge[6, 83] -> 
             RGBColor[
              0.29795007881864144`, 0.4276003661015726, 0.9403851677491978], 
             UndirectedEdge[118, 190] -> 
             RGBColor[
              0.5465072945042451, 0.6199622709372278, 0.9625693523456647], 
             UndirectedEdge[36, 200] -> 
             RGBColor[
              0.24218408124275126`, 0.3718812031167312, 0.9371033971963092], 
             UndirectedEdge[16, 161] -> 
             RGBColor[
              0.3158101253960152, 0.4479525435733356, 0.9413444144561256], 
             UndirectedEdge[2, 169] -> 
             RGBColor[
              0.3248517995873511, 0.4524484986194894, 0.942042670520618], 
             UndirectedEdge[107, 111] -> 
             RGBColor[
              0.5638634248724134, 0.6564277480338845, 0.9590690379639482], 
             UndirectedEdge[127, 180] -> 
             RGBColor[
              0.5228279063856032, 0.618665804983113, 0.9574221323238906], 
             UndirectedEdge[138, 156] -> 
             RGBColor[
              0.9168097113153278, 0.8158057378279282, 0.6204937789995357], 
             UndirectedEdge[72, 93] -> 
             RGBColor[
              0.23701205160573985`, 0.3664450720426131, 0.9368088577598136], 
             UndirectedEdge[137, 187] -> 
             RGBColor[
              0.2665071069572168, 0.39744624531153616`, 0.938488557528056], 
             UndirectedEdge[40, 121] -> 
             RGBColor[
              0.5171284633430432, 0.6188672087704971, 0.9551293934197934], 
             UndirectedEdge[98, 178] -> 
             RGBColor[
              0.957960137429429, 0.968167319845601, 0.9560467009664877], 
             UndirectedEdge[10, 186] -> 
             RGBColor[
              0.28567319780598677`, 0.4175910219939398, 0.939580038048203], 
             UndirectedEdge[63, 91] -> 
             RGBColor[
              0.5953350475574752, 0.6767809281925967, 0.9640487060966569], 
             UndirectedEdge[125, 195] -> 
             RGBColor[
              0.17894341419620807`, 0.3054112523609348, 0.9335019347641915], 
             UndirectedEdge[86, 180] -> 
             RGBColor[
              0.5580138830704554, 0.6491421294889225, 0.9596641516445119], 
             UndirectedEdge[137, 186] -> 
             RGBColor[
              0.2661087370017966, 0.3970275332302755, 0.9384658709484304], 
             UndirectedEdge[33, 44] -> 
             RGBColor[
              0.3032320659672701, 0.4347249229295589, 0.9406283792341544], 
             UndirectedEdge[14, 193] -> 
             RGBColor[
              0.36672963099697153`, 0.49206450682754455`, 0.9445886656942154],
              UndirectedEdge[11, 28] -> 
             RGBColor[
              0.2703195386510599, 0.4014533527438959, 0.9387056698730332], 
             UndirectedEdge[85, 151] -> 
             RGBColor[
              0.35601576258697687`, 0.48278469250549083`, 0.9439059874730323],
              UndirectedEdge[175, 199] -> 
             RGBColor[
              0.2963432017196842, 0.4277285752246516, 0.9402271241213142], 
             UndirectedEdge[146, 196] -> 
             RGBColor[
              0.6456339866715997, 0.7208387494603272, 0.9668559673629961], 
             UndirectedEdge[20, 77] -> 
             RGBColor[
              0.2628976545910799, 0.3936524820222284, 0.9382830045555108], 
             UndirectedEdge[27, 56] -> 
             RGBColor[
              0.22783801477683696`, 0.3568025776679057, 0.9362864099341788], 
             UndirectedEdge[101, 175] -> 
             RGBColor[
              0.2861211170833608, 0.41698451615427623`, 0.9396449915234946], 
             UndirectedEdge[21, 85] -> 
             RGBColor[
              0.3381783439476214, 0.46733481701480994`, 0.9427694029303426], 
             UndirectedEdge[150, 194] -> 
             RGBColor[
              0.31572797791144636`, 0.44550227419337246`, 0.9414262912319082],
              UndirectedEdge[61, 160] -> 
             RGBColor[
              0.3202543943304065, 0.44857871983620956`, 0.9417456174400596], 
             UndirectedEdge[24, 149] -> 
             RGBColor[
              0.20624750544947348`, 0.3341095834474904, 0.9350568623682817], 
             UndirectedEdge[14, 186] -> 
             RGBColor[
              0.34940158280640243`, 0.47458578186823513`, 0.9435749780704197],
              UndirectedEdge[111, 126] -> 
             RGBColor[
              0.3838604005570612, 0.5065667960959406, 0.9457392221700909], 
             UndirectedEdge[35, 88] -> 
             RGBColor[
              0.775283955250752, 0.8245256192165048, 0.9781972744160757], 
             UndirectedEdge[94, 111] -> 
             RGBColor[
              0.43931163123225564`, 0.554736492921887, 0.9492673764797304], 
             UndirectedEdge[133, 162] -> 
             RGBColor[
              0.8765856501368406, 0.44964429041426807`, 0.41798785096875907`],
              UndirectedEdge[124, 199] -> 
             RGBColor[
              0.2816714935465845, 0.4133849770946037, 0.939352146910621], 
             UndirectedEdge[54, 105] -> 
             RGBColor[
              0.3080083942884021, 0.4378802673814718, 0.9409686664381117], 
             UndirectedEdge[64, 162] -> 
             RGBColor[
              0.8027519456818715, 0.845632128982279, 0.9386302937530759], 
             UndirectedEdge[57, 66] -> 
             RGBColor[
              0.5260989516337345, 0.6228771288818142, 0.9570472794276266], 
             UndirectedEdge[16, 137] -> 
             RGBColor[
              0.2865741831678942, 0.41722371462578045`, 0.9396794707969347], 
             UndirectedEdge[44, 50] -> 
             RGBColor[
              0.2628281872337618, 0.3935794674252022, 0.9382790484922793], 
             UndirectedEdge[153, 167] -> 
             RGBColor[
              0.7506229237957682, 0.8050180016109936, 0.9761649358064053], 
             UndirectedEdge[165, 187] -> 
             RGBColor[
              0.2508650284302595, 0.38100542901464385`, 0.9375977642963274], 
             UndirectedEdge[32, 83] -> 
             RGBColor[
              0.2455000054496245, 0.37536644969989263`, 0.9372922341744203], 
             UndirectedEdge[6, 187] -> 
             RGBColor[
              0.3114394717583858, 0.44177857335815474`, 0.9411533687213477], 
             UndirectedEdge[66, 141] -> 
             RGBColor[
              0.5254792907329107, 0.622340409754583, 0.9570077951829706], 
             UndirectedEdge[23, 87] -> 
             RGBColor[
              0.9907768608924232, 0.9889849826208208, 0.6957320893038507], 
             UndirectedEdge[85, 152] -> 
             RGBColor[
              0.320947319253029, 0.44991323932493577`, 0.9417628821181223], 
             UndirectedEdge[26, 74] -> 
             RGBColor[
              0.3495927399015075, 0.4766700360070217, 0.9435169060307154], 
             UndirectedEdge[81, 172] -> 
             RGBColor[
              0.7851552645502801, 0.8282289520022286, 0.7727853942333442], 
             UndirectedEdge[54, 73] -> 
             RGBColor[
              0.28297059999413937`, 0.41475042033909004`, 0.9394261291009534],
              UndirectedEdge[135, 165] -> 
             RGBColor[
              0.22609095697748494`, 0.3549663091509244, 0.9361869175770461], 
             UndirectedEdge[46, 109] -> 
             RGBColor[
              0.4676427269643195, 0.5755488960812328, 0.9521022706897019], 
             UndirectedEdge[40, 171] -> 
             RGBColor[
              0.6830257915160596, 0.7504348777708634, 0.9705035877143484], 
             UndirectedEdge[113, 167] -> 
             RGBColor[
              0.9077889348257765, 0.7877285014564059, 0.6151514893253305], 
             UndirectedEdge[103, 162] -> 
             RGBColor[
              0.9038275928696831, 0.6466946914547808, 0.4435914409291628], 
             UndirectedEdge[37, 119] -> 
             RGBColor[
              0.3779360600643469, 0.4878548266230827, 0.9465383122915882], 
             UndirectedEdge[71, 184] -> 
             RGBColor[
              0.3307081584442233, 0.45915751757499346`, 0.9423559109556644], 
             UndirectedEdge[107, 142] -> 
             RGBColor[
              0.6540600421097872, 0.7296534252184859, 0.9661696460739697], 
             UndirectedEdge[136, 143] -> 
             RGBColor[
              0.8498678524467502, 0.3315757262103135, 0.19331268304312726`], 
             UndirectedEdge[3, 5] -> 
             RGBColor[
              0.27293521528598386`, 0.4042025947306783, 0.9388546287878452], 
             UndirectedEdge[24, 118] -> 
             RGBColor[
              0.5461172648909147, 0.6195523250843118, 0.9625471407361825], 
             UndirectedEdge[142, 185] -> 
             RGBColor[
              0.7052311845538637, 0.7696287106108853, 0.971269907331281], 
             UndirectedEdge[3, 28] -> 
             RGBColor[
              0.2792200802478043, 0.4108083862890054, 0.9392125425497964], 
             UndirectedEdge[43, 49] -> 
             RGBColor[
              0.8484894518822184, 0.3737167521458401, 0.1940668599244025], 
             UndirectedEdge[19, 60] -> 
             RGBColor[
              0.25917942342753286`, 0.38974438531986844`, 0.9380712567913769],
              UndirectedEdge[87, 110] -> 
             RGBColor[
              0.7965007991763076, 0.8397612062456058, 0.9055025365037817], 
             UndirectedEdge[107, 185] -> 
             RGBColor[
              0.7184021799057017, 0.779940510091907, 0.9725672735090811], 
             UndirectedEdge[66, 81] -> 
             RGBColor[
              0.633976904061278, 0.7129754213419766, 0.9648440654867796], 
             UndirectedEdge[63, 112] -> 
             RGBColor[
              0.32715088352733546`, 0.45710875455411837`, 0.94209144443096], 
             UndirectedEdge[59, 193] -> 
             RGBColor[
              0.38274569330621644`, 0.5059368150091147, 0.9456091950221126], 
             UndirectedEdge[110, 180] -> 
             RGBColor[
              0.6645475989229954, 0.737297023885635, 0.9675905484473445], 
             UndirectedEdge[21, 196] -> 
             RGBColor[
              0.4056875246476441, 0.5246714028276624, 0.9473850392149095], 
             UndirectedEdge[24, 190] -> 
             RGBColor[
              0.1793170324527155, 0.3058039488372898, 0.9335232117711809], 
             UndirectedEdge[44, 60] -> 
             RGBColor[
              0.2686906729944792, 0.399741311662782, 0.9386129083835817], 
             UndirectedEdge[20, 106] -> 
             RGBColor[
              0.25022657945820426`, 0.38033437866501096`, 0.9375614055718693],
              UndirectedEdge[75, 139] -> 
             RGBColor[
              0.26665982071221705`, 0.39760675715065275`, 0.9384972543504835],
              UndirectedEdge[4, 81] -> 
             RGBColor[
              0.6906097692395512, 0.7572174460449604, 0.9704887002235348], 
             UndirectedEdge[79, 197] -> 
             RGBColor[
              0.5464425729840517, 0.6229880683860871, 0.9620969735266468], 
             UndirectedEdge[66, 90] -> 
             RGBColor[
              0.5397844128240585, 0.6347307875135932, 0.9579193049130958], 
             UndirectedEdge[14, 15] -> 
             RGBColor[
              0.3709417656089321, 0.49571284612038347`, 0.9448570591870451], 
             UndirectedEdge[14, 48] -> 
             RGBColor[
              0.36693773655078116`, 0.49224475739856516`, 0.9446019259960836],
              UndirectedEdge[122, 144] -> 
             RGBColor[
              0.901990039676534, 0.619375718064703, 0.29208824069422046`], 
             UndirectedEdge[80, 121] -> 
             RGBColor[
              0.5812862861253769, 0.6709534195821745, 0.9601801322470673], 
             UndirectedEdge[79, 170] -> 
             RGBColor[
              0.1931667580582484, 0.32036088857202627`, 0.934311933155583], 
             UndirectedEdge[91, 95] -> 
             RGBColor[
              0.9087217160297558, 0.9082261327367556, 0.679871771253554], 
             UndirectedEdge[48, 193] -> 
             RGBColor[
              0.3168945933506373, 0.44889990200011176`, 0.9414132211627845], 
             UndirectedEdge[67, 162] -> 
             RGBColor[
              0.8731042173971515, 0.4228844728034631, 0.4146540270455168], 
             UndirectedEdge[65, 87] -> 
             RGBColor[
              0.9550341089343712, 0.965005825208276, 0.9206936459458361], 
             UndirectedEdge[98, 121] -> 
             RGBColor[
              0.7580819454747305, 0.8096778551186503, 0.9434509884049964], 
             UndirectedEdge[161, 187] -> 
             RGBColor[
              0.2957430491853379, 0.4281750742590913, 0.9401535011872468], 
             UndirectedEdge[68, 122] -> 
             RGBColor[
              0.924281570863012, 0.9375100698293877, 0.7294250958369339], 
             UndirectedEdge[19, 90] -> 
             RGBColor[
              0.32617520722218063`, 0.45283835871142575`, 0.9421546927268274],
              UndirectedEdge[80, 168] -> 
             RGBColor[
              0.7792447125486042, 0.8280111263190817, 0.9760255070982982], 
             UndirectedEdge[109, 194] -> 
             RGBColor[
              0.3430360942965171, 0.47154235620939167`, 0.9430789344870343], 
             UndirectedEdge[44, 57] -> 
             RGBColor[
              0.3220009955988029, 0.4509816264225601, 0.9418243188335629], 
             UndirectedEdge[109, 151] -> 
             RGBColor[
              0.34470972375175946`, 0.47299196992446024`, 0.9431855766759899],
              UndirectedEdge[122, 138] -> 
             RGBColor[
              0.9528570018424507, 0.8395978867219851, 0.360717102170288], 
             UndirectedEdge[138, 192] -> 
             RGBColor[
              0.8491378919784113, 0.32004855046860603`, 0.19237048844023447`],
              UndirectedEdge[31, 46] -> 
             RGBColor[
              0.7241254080647266, 0.7839747878759986, 0.9735395315167075], 
             UndirectedEdge[101, 165] -> 
             RGBColor[
              0.23537363183733478`, 0.36472298898420613`, 0.9367155521778278],
              UndirectedEdge[76, 105] -> 
             RGBColor[
              0.3097803157470692, 0.4397426691808402, 0.94106957474386], 
             UndirectedEdge[6, 199] -> 
             RGBColor[
              0.3061701598017846, 0.4362401923980924, 0.9408532892006678], 
             UndirectedEdge[83, 175] -> 
             RGBColor[
              0.2881231207365411, 0.41908874892813175`, 0.9397590026698441], 
             UndirectedEdge[139, 182] -> 
             RGBColor[
              0.2571409182934481, 0.38760178717525484`, 0.9379551669396888], 
             UndirectedEdge[89, 149] -> 
             RGBColor[
              0.6471841581056663, 0.3982840813972412, 0.44509512783199057`], 
             UndirectedEdge[53, 163] -> 
             RGBColor[
              0.2222172147783616, 0.3508947604902047, 0.935966313689494], 
             UndirectedEdge[8, 96] -> 
             RGBColor[
              0.3771970335719591, 0.5008951438379817, 0.9452642694982989], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.3028942075372073, 0.43437709498723787`, 0.9406088720414547], 
             UndirectedEdge[55, 191] -> 
             RGBColor[
              0.31630641834476525`, 0.445754027687974, 0.9414722756672911], 
             UndirectedEdge[122, 181] -> 
             RGBColor[
              0.9886341161577883, 0.9875460745600706, 0.6910581517385923], 
             UndirectedEdge[130, 177] -> 
             RGBColor[
              0.26541543308332344`, 0.3962988268539529, 0.9384263883159245], 
             UndirectedEdge[25, 131] -> 
             RGBColor[
              0.93909008289769, 0.7879991811183886, 0.30513287379478254`], 
             UndirectedEdge[19, 33] -> 
             RGBColor[
              0.29372081640032377`, 0.4247279965866454, 0.9400867276419496], 
             UndirectedEdge[1, 89] -> 
             RGBColor[
              0.8887656846103759, 0.567689263625524, 0.23040845432083734`], 
             UndirectedEdge[123, 127] -> 
             RGBColor[
              0.2860095413584047, 0.4167572429724312, 0.9396426650906227], 
             UndirectedEdge[40, 173] -> 
             RGBColor[
              0.7433614186788604, 0.7950716369237336, 0.832834751651226], 
             UndirectedEdge[17, 106] -> 
             RGBColor[
              0.25694510996125053`, 0.38739598020314986`, 0.9379440159448427],
              UndirectedEdge[51, 158] -> 
             RGBColor[
              0.267702506048196, 0.39870268554883526`, 0.9385566337378528], 
             UndirectedEdge[20, 189] -> 
             RGBColor[
              0.2283963086796351, 0.35738937995762443`, 0.9363182039460214], 
             UndirectedEdge[48, 140] -> 
             RGBColor[
              0.3113031778693076, 0.4437571221637065, 0.9410679174089878], 
             UndirectedEdge[11, 189] -> 
             RGBColor[
              0.2386268283641832, 0.36814230479849686`, 0.9369008169073587], 
             UndirectedEdge[40, 169] -> 
             RGBColor[
              0.38208210782853824`, 0.5009795735314966, 0.9459763978166744], 
             UndirectedEdge[94, 167] -> 
             RGBColor[0.666701611701555, 0.7359313939081493, 0.9698223518406],
              UndirectedEdge[81, 198] -> 
             RGBColor[
              0.6362473175270285, 0.7147490855972023, 0.9650703590828255], 
             UndirectedEdge[34, 60] -> 
             RGBColor[
              0.25285259350547307`, 0.38309448592759754`, 0.9377109531870217],
              UndirectedEdge[13, 101] -> 
             RGBColor[
              0.3149218240784437, 0.4419302409877936, 0.941480147105756], 
             UndirectedEdge[31, 117] -> 
             RGBColor[
              0.8147533586460658, 0.8554575003050673, 0.9821051874244302], 
             UndirectedEdge[94, 105] -> 
             RGBColor[
              0.3806688871734759, 0.5041379899202462, 0.945476862771782], 
             UndirectedEdge[125, 190] -> 
             RGBColor[
              0.179333445229231, 0.3058211997060377, 0.933524146454523], 
             UndirectedEdge[79, 119] -> 
             RGBColor[
              0.3844232617951737, 0.4946732869545277, 0.9469077488332039], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.2600890189665118, 0.39070042790302345`, 0.9381230569116956], 
             UndirectedEdge[156, 178] -> 
             RGBColor[
              0.9316378178168464, 0.9481531008980535, 0.987322033962275], 
             UndirectedEdge[95, 131] -> 
             RGBColor[
              0.9394422371635587, 0.7891870801469172, 0.306500926618929], 
             UndirectedEdge[49, 133] -> 
             RGBColor[
              0.8309676837459775, 0.23903676416293673`, 0.17728799496913153`],
              UndirectedEdge[34, 44] -> 
             RGBColor[
              0.2675860001638932, 0.3985802304775334, 0.9385499989000968], 
             UndirectedEdge[24, 125] -> 
             RGBColor[
              0.17894341561590066`, 0.30541125385312173`, 0.9335019348450408],
              UndirectedEdge[95, 129] -> 
             RGBColor[
              0.9849427513832404, 0.9608705061848779, 0.39600586175704294`], 
             UndirectedEdge[13, 16] -> 
             RGBColor[
              0.35048029688204574`, 0.4779901503324755, 0.9435532724931343], 
             UndirectedEdge[13, 199] -> 
             RGBColor[
              0.3251439087147671, 0.45267430005816894`, 0.9420622797035756], 
             UndirectedEdge[121, 196] -> 
             RGBColor[
              0.5189244738450667, 0.6203252910053908, 0.955270781945516], 
             UndirectedEdge[26, 40] -> 
             RGBColor[
              0.4439921507491714, 0.557946476502165, 0.9497988277939646], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.31163329513552707`, 0.44101997430243733`, 0.9411996419147166],
              UndirectedEdge[54, 126] -> 
             RGBColor[
              0.29001572662104147`, 0.4221552951107917, 0.9398273386400247], 
             UndirectedEdge[16, 193] -> 
             RGBColor[
              0.3198238857723562, 0.4514371078652866, 0.9415998730856248], 
             UndirectedEdge[85, 150] -> 
             RGBColor[
              0.3215409260409259, 0.45053715769585945`, 0.9417966871465304], 
             UndirectedEdge[26, 169] -> 
             RGBColor[
              0.3344928369204973, 0.4607990805848347, 0.9426569888942514], 
             UndirectedEdge[22, 79] -> 
             RGBColor[
              0.6309372892797696, 0.33887224059181326`, 0.43842350367765265`],
              UndirectedEdge[27, 67] -> 
             RGBColor[
              0.6377201396548048, 0.23003206781698532`, 0.42306867319027985`],
              UndirectedEdge[49, 95] -> 
             RGBColor[
              0.8830336731086973, 0.49298775428550434`, 0.24571556835587194`],
              UndirectedEdge[147, 178] -> 
             RGBColor[
              0.7115638776908443, 0.7729379814418316, 0.9672966305905184], 
             UndirectedEdge[1, 136] -> 
             RGBColor[
              0.9331596302538536, 0.7720124271387454, 0.2686954588022206], 
             UndirectedEdge[65, 110] -> 
             RGBColor[
              0.7635603354949406, 0.815471840469592, 0.9772401996765336], 
             UndirectedEdge[77, 106] -> 
             RGBColor[
              0.2877229919008626, 0.4197454855521064, 0.9396967707895075], 
             UndirectedEdge[25, 64] -> 
             RGBColor[
              0.8007620659771775, 0.8225276552268693, 0.6680235781600576], 
             UndirectedEdge[82, 187] -> 
             RGBColor[
              0.3007127795635599, 0.4324876517182224, 0.9404698733799348], 
             UndirectedEdge[167, 188] -> 
             RGBColor[
              0.7899648841688349, 0.8366160464867711, 0.9794955855762202], 
             UndirectedEdge[13, 137] -> 
             RGBColor[
              0.31409319630205523`, 0.44105930065677384`, 0.9414329579797356],
              UndirectedEdge[37, 125] -> 
             RGBColor[
              0.18497678859456473`, 0.3117527113916389, 0.9338455265106003], 
             UndirectedEdge[105, 182] -> 
             RGBColor[
              0.30416697639606216`, 0.43384269361666083`, 0.9407499033720115],
              UndirectedEdge[111, 116] -> 
             RGBColor[
              0.42503929713653266`, 0.5423745144765412, 0.9483579559716804], 
             UndirectedEdge[146, 179] -> 
             RGBColor[
              0.802014133137712, 0.8452588034311341, 0.9809009316091206], 
             UndirectedEdge[9, 63] -> 
             RGBColor[
              0.3067096536024727, 0.43562372585425413`, 0.9409273466268289], 
             UndirectedEdge[38, 120] -> 
             RGBColor[
              0.960788560046435, 0.8793927471320053, 0.302171389549849], 
             UndirectedEdge[71, 81] -> 
             RGBColor[
              0.43330857195401157`, 0.5446846710814149, 0.9498164169017225], 
             UndirectedEdge[68, 181] -> 
             RGBColor[
              0.9199773592711327, 0.9377520223513063, 0.9477245085556535], 
             UndirectedEdge[114, 158] -> 
             RGBColor[
              0.23522624458781927`, 0.364568075640074, 0.9367071586920077], 
             UndirectedEdge[118, 149] -> 
             RGBColor[
              0.5734377675010032, 0.6482679055474284, 0.9641030029427655], 
             UndirectedEdge[87, 162] -> 
             RGBColor[
              0.9854379176982261, 0.9880317806397674, 0.8813919321035765], 
             UndirectedEdge[88, 122] -> 
             RGBColor[
              0.8525664665525501, 0.8811976138560375, 0.7223536497554326], 
             UndirectedEdge[49, 162] -> 
             RGBColor[
              0.8841254900679142, 0.5075988041034252, 0.42520801020178634`], 
             UndirectedEdge[47, 116] -> 
             RGBColor[
              0.42055225492425696`, 0.5386829584696233, 0.9480181956973843], 
             UndirectedEdge[23, 95] -> 
             RGBColor[
              0.9866024805360858, 0.9658049975494172, 0.45892937586547133`], 
             UndirectedEdge[54, 115] -> 
             RGBColor[
              0.2691801918114708, 0.40025582697672574`, 0.938640785756031], 
             UndirectedEdge[62, 105] -> 
             RGBColor[
              0.3497224989411253, 0.4773337838440822, 0.9435049862784333], 
             UndirectedEdge[13, 108] -> 
             RGBColor[
              0.5796159484292636, 0.6654249189415207, 0.9620681904824614], 
             UndirectedEdge[76, 182] -> 
             RGBColor[
              0.27073696797748936`, 0.4018920974325212, 0.938729441855642], 
             UndirectedEdge[117, 171] -> 
             RGBColor[
              0.8267342564377225, 0.8650107429913272, 0.9832479361512722], 
             UndirectedEdge[40, 46] -> 
             RGBColor[
              0.5446619359975361, 0.6412201222402223, 0.9572969292455886], 
             UndirectedEdge[19, 177] -> 
             RGBColor[
              0.2790041774695689, 0.41058145878005325`, 0.9392002472059755], 
             UndirectedEdge[64, 87] -> 
             RGBColor[
              0.8052886005993835, 0.8468955393268014, 0.9061943444225835], 
             UndirectedEdge[62, 107] -> 
             RGBColor[
              0.5117328555891169, 0.611469763511346, 0.9556934742742034], 
             UndirectedEdge[53, 148] -> 
             RGBColor[
              0.20810268194188267`, 0.3360594915659958, 0.9351625119250367], 
             UndirectedEdge[76, 111] -> 
             RGBColor[
              0.368423059805849, 0.49034117218248097`, 0.9448600884518084], 
             UndirectedEdge[11, 48] -> 
             RGBColor[
              0.2814824902109824, 0.4124136886940051, 0.9393696733626], 
             UndirectedEdge[96, 111] -> 
             RGBColor[
              0.3833462518703272, 0.5060263932272735, 0.9457099421629962], 
             UndirectedEdge[168, 198] -> 
             RGBColor[
              0.8173765882647961, 0.8581441256038294, 0.9795908811512684], 
             UndirectedEdge[118, 128] -> 
             RGBColor[
              0.901444520807011, 0.7626039594239429, 0.6105848646794676], 
             UndirectedEdge[56, 129] -> 
             RGBColor[
              0.5845933454317087, 0.6420998957641366, 0.6750810838088802], 
             UndirectedEdge[53, 100] -> 
             RGBColor[
              0.21261327393044743`, 0.34080040973402737`, 0.9354193834659627],
              UndirectedEdge[129, 143] -> 
             RGBColor[
              0.8772855250898838, 0.4335162754923927, 0.2505870010613686], 
             UndirectedEdge[18, 160] -> 
             RGBColor[
              0.34254111760690553`, 0.47111363227910186`, 0.9430473950100628],
              UndirectedEdge[68, 111] -> 
             RGBColor[
              0.6580603131297789, 0.7303031444944423, 0.9683812581650608], 
             UndirectedEdge[51, 166] -> 
             RGBColor[
              0.33653220976868264`, 0.46344910853990606`, 0.9427545820635193],
              UndirectedEdge[107, 181] -> 
             RGBColor[
              0.8257804710137671, 0.8638766258907483, 0.9384122883545408], 
             UndirectedEdge[31, 173] -> 
             RGBColor[
              0.9228248907460509, 0.93782630255951, 0.8490773539223448], 
             UndirectedEdge[135, 148] -> 
             RGBColor[
              0.2190360411775415, 0.34755114533768694`, 0.935785150559052], 
             UndirectedEdge[44, 177] -> 
             RGBColor[
              0.2885154270365152, 0.4205783851229668, 0.9397418987981803], 
             UndirectedEdge[80, 184] -> 
             RGBColor[
              0.4955150283010483, 0.599088932806033, 0.9540444790837972], 
             UndirectedEdge[65, 162] -> 
             RGBColor[
              0.9524974540168591, 0.9637424148637534, 0.9531295952763283], 
             UndirectedEdge[5, 17] -> 
             RGBColor[
              0.26052268450773763`, 0.3911562378828352, 0.9381477535227178], 
             UndirectedEdge[44, 141] -> 
             RGBColor[
              0.321381334697979, 0.45044490729532893`, 0.941784834588907], 
             UndirectedEdge[94, 174] -> 
             RGBColor[
              0.39976902935609954`, 0.5206815730777754, 0.9466939069420661], 
             UndirectedEdge[161, 193] -> 
             RGBColor[
              0.31267272742048674`, 0.4452350871371401, 0.9411445022314171], 
             UndirectedEdge[101, 124] -> 
             RGBColor[
              0.2714494089102611, 0.40264091802422836`, 0.9387700143128014], 
             UndirectedEdge[106, 189] -> 
             RGBColor[
              0.25322164598941777`, 0.3834823834875024, 0.9377319701800181], 
             UndirectedEdge[2, 80] -> 
             RGBColor[
              0.4985089361983589, 0.6016821053484971, 0.954235248247605], 
             UndirectedEdge[97, 102] -> 
             RGBColor[
              0.3273981891467483, 0.4554287175679108, 0.9421765599569466], 
             UndirectedEdge[91, 136] -> 
             RGBColor[
              0.8729121465452325, 0.773250594157032, 0.6146156000869095], 
             UndirectedEdge[59, 154] -> 
             RGBColor[
              0.7176662191262557, 0.7759253920834623, 0.911377748265729], 
             UndirectedEdge[108, 162] -> 
             RGBColor[
              0.8820669248115173, 0.9078962359074088, 0.9463287513615282], 
             UndirectedEdge[146, 147] -> 
             RGBColor[
              0.6383951985626789, 0.7149619751698173, 0.9662861034465073], 
             UndirectedEdge[99, 156] -> 
             RGBColor[
              0.7424696241286013, 0.7983584952437333, 0.9755694516963352], 
             UndirectedEdge[143, 154] -> 
             RGBColor[
              0.8760414746143801, 0.43681328017556376`, 0.40267896763816474`],
              UndirectedEdge[139, 145] -> 
             RGBColor[
              0.2284570343408142, 0.357453206477753, 0.9363216621825899], 
             UndirectedEdge[104, 123] -> 
             RGBColor[
              0.23468312728084179`, 0.36399722491481445`, 0.9366762289648454],
              UndirectedEdge[116, 126] -> 
             RGBColor[
              0.34840388541039236`, 0.4760510392042203, 0.9434261144656448], 
             UndirectedEdge[17, 28] -> 
             RGBColor[
              0.2668075494695581, 0.39776202944116235`, 0.938505667284669], 
             UndirectedEdge[89, 118] -> 
             RGBColor[
              0.8737639977332939, 0.5885792424884555, 0.4634219800772578], 
             UndirectedEdge[123, 163] -> 
             RGBColor[
              0.2417268008308885, 0.37140057241061075`, 0.9370773557533394], 
             UndirectedEdge[47, 157] -> 
             RGBColor[
              0.5046032669357259, 0.6086499170733246, 0.9541568402025347], 
             UndirectedEdge[117, 151] -> 
             RGBColor[
              0.565437397706639, 0.6532390613039136, 0.9611245836688005], 
             UndirectedEdge[69, 86] -> 
             RGBColor[
              0.39677259596818604`, 0.5180862130822859, 0.9465029768562303], 
             UndirectedEdge[73, 94] -> 
             RGBColor[
              0.35563109287921313`, 0.4810081428778644, 0.9439343254346236], 
             UndirectedEdge[61, 174] -> 
             RGBColor[
              0.3276038093333696, 0.4549444137194375, 0.9422139156652158], 
             UndirectedEdge[175, 187] -> 
             RGBColor[
              0.3016125136762855, 0.4332669561847139, 0.940527203641994], 
             UndirectedEdge[75, 134] -> 
             RGBColor[
              0.2575067829018646, 0.3879863340758565, 0.93797600238789], 
             UndirectedEdge[38, 178] -> 
             RGBColor[
              0.9536200808381681, 0.9247692797301834, 0.650059594771984], 
             UndirectedEdge[8, 179] -> 
             RGBColor[
              0.6280655556399748, 0.706255507224953, 0.9656353303034069], 
             UndirectedEdge[29, 167] -> 
             RGBColor[
              0.9544593958943188, 0.963459656199136, 0.8733980891466777], 
             UndirectedEdge[68, 185] -> 
             RGBColor[
              0.8125990681630673, 0.8538159065524649, 0.9818794937101938], 
             UndirectedEdge[79, 118] -> 
             RGBColor[
              0.5586378396004057, 0.632712242954274, 0.9632601689433578], 
             UndirectedEdge[171, 173] -> 
             RGBColor[
              0.9348057885377076, 0.9473795452457701, 0.8502201026491867], 
             UndirectedEdge[80, 166] -> 
             RGBColor[
              0.5054107612208105, 0.6076601192871327, 0.9546750264349914], 
             UndirectedEdge[109, 132] -> 
             RGBColor[
              0.2948786821955154, 0.42460409000948357`, 0.9402017631916271], 
             UndirectedEdge[118, 197] -> 
             RGBColor[
              0.9011122603260905, 0.9239864726160629, 0.9904300858939554], 
             UndirectedEdge[111, 167] -> 
             RGBColor[
              0.687885792752501, 0.7540851723545239, 0.971226039036996], 
             UndirectedEdge[113, 122] -> 
             RGBColor[
              0.9466202120897103, 0.8137405258050889, 0.35564035163633406`], 
             UndirectedEdge[119, 190] -> 
             RGBColor[
              0.3722927166990131, 0.48192331493748153`, 0.946216932235511], 
             UndirectedEdge[19, 130] -> 
             RGBColor[
              0.2508128361327613, 0.38095057160079043`, 0.9375947920221963], 
             UndirectedEdge[35, 167] -> 
             RGBColor[
              0.876824539183936, 0.9046201030499366, 0.9881135013695121], 
             UndirectedEdge[102, 112] -> 
             RGBColor[
              0.337642108559284, 0.46619572637249007`, 0.9427599360129698], 
             UndirectedEdge[134, 145] -> 
             RGBColor[
              0.21930399653046173`, 0.34783278340295676`, 0.9358004102199964],
              UndirectedEdge[109, 150] -> 
             RGBColor[
              0.31023488720570846`, 0.44074443511482886`, 0.941076276349488], 
             UndirectedEdge[147, 179] -> 
             RGBColor[
              0.6443148010184508, 0.7195864135989113, 0.9668761140974684], 
             UndirectedEdge[63, 102] -> 
             RGBColor[
              0.3633436999904507, 0.48913178357153686`, 0.9443729171645411], 
             UndirectedEdge[62, 182] -> 
             RGBColor[
              0.31067915117154543`, 0.43948321209576313`, 0.9411648533902153],
              UndirectedEdge[8, 99] -> 
             RGBColor[
              0.5061464386241231, 0.6098124694135529, 0.9543032645305172], 
             UndirectedEdge[60, 123] -> 
             RGBColor[
              0.252194354195388, 0.3824026346779154, 0.9376734674320901], 
             UndirectedEdge[7, 97] -> 
             RGBColor[
              0.3157107895654947, 0.44530567947641203`, 0.9414318491903908], 
             UndirectedEdge[130, 163] -> 
             RGBColor[
              0.23512312567678792`, 0.3644596911264634, 0.9367012862225752], 
             UndirectedEdge[127, 135] -> 
             RGBColor[
              0.2774333145415366, 0.4077430848237163, 0.9391542616607926], 
             UndirectedEdge[37, 56] -> 
             RGBColor[
              0.18496037439835666`, 0.3117354590307041, 0.9338445917464089], 
             UndirectedEdge[100, 148] -> 
             RGBColor[
              0.20930368592266696`, 0.3373218228978505, 0.9352309073250162], 
             UndirectedEdge[53, 135] -> 
             RGBColor[
              0.222345629185322, 0.35102973217386374`, 0.9359736266999984], 
             UndirectedEdge[103, 154] -> 
             RGBColor[
              0.9050363517550805, 0.647337503215628, 0.4299611695671895], 
             UndirectedEdge[63, 140] -> 
             RGBColor[
              0.32917806589633525`, 0.4592394517547229, 0.942206889467927], 
             UndirectedEdge[8, 75] -> 
             RGBColor[
              0.36617940457524284`, 0.4893149172044077, 0.9446368318260574], 
             UndirectedEdge[50, 53] -> 
             RGBColor[
              0.22682228238214364`, 0.3557349785199296, 0.9362285654769424], 
             UndirectedEdge[1, 167] -> 
             RGBColor[
              0.9367941803977453, 0.9031603919681208, 0.6421668592196352], 
             UndirectedEdge[27, 119] -> 
             RGBColor[
              0.4208137004428272, 0.5329219452602844, 0.9489801304793581], 
             UndirectedEdge[96, 126] -> 
             RGBColor[
              0.3067108401441868, 0.4397029179549527, 0.9407781006569607], 
             UndirectedEdge[102, 106] -> 
             RGBColor[
              0.32444342089519307`, 0.4523230687923987, 0.9420082902762085], 
             UndirectedEdge[16, 176] -> 
             RGBColor[
              0.30857911035131147`, 0.440352288288518, 0.9409326188466578], 
             UndirectedEdge[40, 166] -> 
             RGBColor[
              0.4412529384384768, 0.5555739084754552, 0.9496242876077174], 
             UndirectedEdge[33, 90] -> 
             RGBColor[
              0.35549444310349765`, 0.4823331517711803, 0.9438727694565298], 
             UndirectedEdge[13, 161] -> 
             RGBColor[
              0.34332913853017627`, 0.471788129604329, 0.9430979016389265], 
             UndirectedEdge[11, 106] -> 
             RGBColor[
              0.2604570991427524, 0.3910873035058834, 0.9381440185332068], 
             UndirectedEdge[88, 167] -> 
             RGBColor[
              0.8137351892886164, 0.8551855895073546, 0.9818647874444291], 
             UndirectedEdge[29, 159] -> 
             RGBColor[
              0.879643980418662, 0.4472536327034553, 0.36455016649703853`], 
             UndirectedEdge[156, 157] -> 
             RGBColor[
              0.7392642763541118, 0.795756249521131, 0.9753171149779516], 
             UndirectedEdge[171, 183] -> 
             RGBColor[
              0.8647637066900788, 0.6054262821003745, 0.46584178548434796`], 
             UndirectedEdge[100, 104] -> 
             RGBColor[
              0.21637454520909913`, 0.34475374432626316`, 0.9356335823009796],
              UndirectedEdge[108, 180] -> 
             RGBColor[
              0.7526503794757171, 0.8066954638919603, 0.9759808139745987], 
             UndirectedEdge[178, 179] -> 
             RGBColor[
              0.8751828122658775, 0.9032348097031484, 0.9819114587531318], 
             UndirectedEdge[150, 151] -> 
             RGBColor[
              0.3174016073666887, 0.4469518879084411, 0.9415329334208639], 
             UndirectedEdge[2, 121] -> 
             RGBColor[
              0.45989815510185605`, 0.5703361338584898, 0.9511956661237368], 
             UndirectedEdge[12, 14] -> 
             RGBColor[
              0.500367704585658, 0.6042677811858945, 0.954084097379875], 
             UndirectedEdge[43, 131] -> 
             RGBColor[
              0.869996471453065, 0.49619172496078556`, 0.21298460084303164`], 
             UndirectedEdge[75, 76] -> 
             RGBColor[
              0.2802558703962583, 0.4118970674079191, 0.9392715292664366], 
             UndirectedEdge[113, 138] -> 
             RGBColor[
              0.9065388861824932, 0.6660342904889218, 0.24359871478674944`], 
             UndirectedEdge[17, 20] -> 
             RGBColor[
              0.23211977265146783`, 0.3613029766732719, 0.9365302497108459], 
             UndirectedEdge[86, 187] -> 
             RGBColor[
              0.3373933626791634, 0.4642585291932452, 0.9428071277006951], 
             UndirectedEdge[8, 185] -> 
             RGBColor[
              0.6088853490181219, 0.6912717840369921, 0.9637236265565623], 
             UndirectedEdge[4, 41] -> 
             RGBColor[
              0.6772999087061907, 0.7464119016615944, 0.969440899246723], 
             UndirectedEdge[8, 107] -> 
             RGBColor[
              0.5577142065740452, 0.6512964986445926, 0.9586233652992509], 
             UndirectedEdge[149, 192] -> 
             RGBColor[
              0.622735336019854, 0.21035972130353567`, 0.4216829081916216], 
             UndirectedEdge[11, 140] -> 
             RGBColor[
              0.27568296917584306`, 0.40709065828657925`, 0.9390111093069351],
              UndirectedEdge[94, 153] -> 
             RGBColor[
              0.5020487622755229, 0.6056693221783567, 0.9542062732491396], 
             UndirectedEdge[56, 79] -> 
             RGBColor[
              0.1914475761291835, 0.31855391936214905`, 0.9342140282880245], 
             UndirectedEdge[5, 15] -> 
             RGBColor[
              0.303658911440855, 0.4349821137845143, 0.940659697404096], 
             UndirectedEdge[79, 128] -> 
             RGBColor[
              0.5467748334649722, 0.46160555519396695`, 0.5822517523121589], 
             UndirectedEdge[109, 152] -> 
             RGBColor[
              0.3096412804178116, 0.4401205167439052, 0.9410424713210799], 
             UndirectedEdge[118, 192] -> 
             RGBColor[
              0.8493151756474815, 0.40065488239475, 0.4400097604368888], 
             UndirectedEdge[99, 107] -> 
             RGBColor[
              0.615663269511703, 0.6984811954684678, 0.963146911483036], 
             UndirectedEdge[3, 189] -> 
             RGBColor[
              0.24752736996092756`, 0.37749733834360644`, 0.937407689584122], 
             UndirectedEdge[35, 138] -> 
             RGBColor[
              0.8755744905406526, 0.7829258920824524, 0.6165607268309311], 
             UndirectedEdge[12, 86] -> 
             RGBColor[
              0.4879611145029988, 0.5935218164296439, 0.9532935604305248], 
             UndirectedEdge[16, 127] -> 
             RGBColor[
              0.3222744622049885, 0.4535596740016799, 0.9417560216489524], 
             UndirectedEdge[37, 195] -> 
             RGBColor[
              0.18496037439835666`, 0.3117354590307041, 0.9338445917464089], 
             UndirectedEdge[57, 71] -> 
             RGBColor[
              0.32543061952646807`, 0.4545863786212526, 0.9420196308425695], 
             UndirectedEdge[58, 73] -> 
             RGBColor[
              0.2786440888438728, 0.4102029828035092, 0.9391797406914454], 
             UndirectedEdge[35, 153] -> 
             RGBColor[
              0.7121716897579038, 0.7743580313201439, 0.9724974227780518], 
             UndirectedEdge[35, 122] -> 
             RGBColor[
              0.9156558164478696, 0.9306321273986194, 0.7286023636805157], 
             UndirectedEdge[19, 44] -> 
             RGBColor[
              0.2739128300859531, 0.40523012986980433`, 0.9389103025044521], 
             UndirectedEdge[181, 192] -> 
             RGBColor[
              0.8729893015219696, 0.41868067569399636`, 0.41259785481910394`],
              UndirectedEdge[119, 128] -> 
             RGBColor[
              0.727229943001779, 0.6245650034241965, 0.5942324445693138], 
             UndirectedEdge[116, 153] -> 
             RGBColor[
              0.48777642817979994`, 0.593307343733011, 0.9532968527410897], 
             UndirectedEdge[186, 193] -> 
             RGBColor[
              0.29935843960625863`, 0.43124092646978174`, 0.9403862732371204],
              UndirectedEdge[22, 119] -> 
             RGBColor[
              0.7512406956376406, 0.44751187274529963`, 0.44641063184908925`],
              UndirectedEdge[85, 109] -> 
             RGBColor[
              0.34884904242599657`, 0.47657723971187865`, 0.9434493304016565],
              UndirectedEdge[98, 99] -> 
             RGBColor[
              0.7687919437411839, 0.8183727141912807, 0.944294118700548], 
             UndirectedEdge[161, 175] -> 
             RGBColor[
              0.31452843153509336`, 0.4468424047708116, 0.941262746056665], 
             UndirectedEdge[54, 61] -> 
             RGBColor[
              0.27330173727350593`, 0.40458783257840025`, 0.9388755016728139],
              UndirectedEdge[43, 154] -> 
             RGBColor[
              0.8990860971240158, 0.6139443470025971, 0.4247465241785704], 
             UndirectedEdge[87, 95] -> 
             RGBColor[
              0.9838001922594006, 0.9661152059128862, 0.6121532693347048], 
             UndirectedEdge[12, 108] -> 
             RGBColor[
              0.6825976109082605, 0.7510751508326818, 0.9696102227606116], 
             UndirectedEdge[15, 48] -> 
             RGBColor[
              0.32110672796259787`, 0.4525482412929506, 0.9416816146556142], 
             UndirectedEdge[13, 187] -> 
             RGBColor[
              0.33041322067136836`, 0.4582126810182313, 0.9423623592242556], 
             UndirectedEdge[15, 28] -> 
             RGBColor[
              0.3099437764026754, 0.4415879053428414, 0.9410176111660472], 
             UndirectedEdge[52, 134] -> 
             RGBColor[
              0.22165741455534713`, 0.35030637496243233`, 0.9359344338949436],
              UndirectedEdge[66, 172] -> 
             RGBColor[
              0.8427983522117647, 0.874271591791478, 0.7778392040313489], 
             UndirectedEdge[101, 176] -> 
             RGBColor[
              0.27302063754770944`, 0.4042923789438361, 0.9388594934592795], 
             UndirectedEdge[119, 192] -> 
             RGBColor[
              0.7331721237773268, 0.30862891172825246`, 0.4291081470301197], 
             UndirectedEdge[168, 184] -> 
             RGBColor[
              0.6548626736277727, 0.7248006680529328, 0.9668502718111599], 
             UndirectedEdge[16, 175] -> 
             RGBColor[
              0.3216795898869629, 0.4530444254989581, 0.9417181169108728], 
             UndirectedEdge[60, 104] -> 
             RGBColor[
              0.23644603942151277`, 0.3658501573497452, 0.9367766242032618], 
             UndirectedEdge[122, 136] -> 
             RGBColor[
              0.9504725003418423, 0.8301441328600938, 0.35879847629145456`], 
             UndirectedEdge[107, 157] -> 
             RGBColor[
              0.6124579217372135, 0.6958789497458655, 0.9628945747646525], 
             UndirectedEdge[86, 110] -> 
             RGBColor[
              0.49849330988433693`, 0.6020723271102092, 0.9541226934316467], 
             UndirectedEdge[5, 9] -> 
             RGBColor[
              0.27138694905370225`, 0.40257526875480143`, 0.9387664573163714],
              UndirectedEdge[3, 77] -> 
             RGBColor[
              0.2820287158723724, 0.41376044040821036`, 0.9393724901936115], 
             UndirectedEdge[84, 139] -> 
             RGBColor[
              0.25596738815303377`, 0.386368332591571, 0.9378883361342745], 
             UndirectedEdge[96, 191] -> 
             RGBColor[
              0.29321373700723585`, 0.4255166067922517, 0.9400094606004861], 
             UndirectedEdge[46, 151] -> 
             RGBColor[
              0.4748094471252997, 0.581756348874845, 0.9525589277610778], 
             UndirectedEdge[72, 191] -> 
             RGBColor[
              0.2650536461439216, 0.3959185658420248, 0.9384057850849414], 
             UndirectedEdge[111, 185] -> 
             RGBColor[
              0.6150345673164899, 0.6964030334262838, 0.9641692992212595], 
             UndirectedEdge[23, 129] -> 
             RGBColor[
              0.9919194200162629, 0.9837402828928126, 0.4795846817261888], 
             UndirectedEdge[101, 123] -> 
             RGBColor[
              0.2511378900976988, 0.38129222392755147`, 0.9376133033646252], 
             UndirectedEdge[122, 142] -> 
             RGBColor[
              0.8169136872538085, 0.8533228738878083, 0.7188155094580211], 
             UndirectedEdge[18, 174] -> 
             RGBColor[
              0.3498905326098686, 0.47747932616232985`, 0.9435156932352192], 
             UndirectedEdge[123, 135] -> 
             RGBColor[
              0.24185521523784892`, 0.3715355440942698, 0.9370846687638437], 
             UndirectedEdge[171, 178] -> 
             RGBColor[
              0.9084510251565888, 0.9296645818194842, 0.9851104569792455], 
             UndirectedEdge[81, 173] -> 
             RGBColor[
              0.7857376160501509, 0.8294745429756838, 0.8361707611374197], 
             UndirectedEdge[77, 102] -> 
             RGBColor[
              0.33711449602806876`, 0.4656411721496162, 0.9427298892598499], 
             UndirectedEdge[31, 171] -> 
             RGBColor[
              0.8624892635832501, 0.8931895434066397, 0.9867461899854671], 
             UndirectedEdge[109, 196] -> 
             RGBColor[
              0.4163582231260193, 0.5339138255247312, 0.9480649666862233], 
             UndirectedEdge[18, 153] -> 
             RGBColor[
              0.4521702655292919, 0.5624670752629113, 0.9510280595422927], 
             UndirectedEdge[97, 140] -> 
             RGBColor[
              0.29323255505263285`, 0.42553638575109687`, 0.9400105322603325],
              UndirectedEdge[116, 167] -> 
             RGBColor[
              0.652429277605832, 0.7235694154628036, 0.96891293133255], 
             UndirectedEdge[128, 190] -> 
             RGBColor[
              0.5346442883688116, 0.44885558317692076`, 0.5815609357144658], 
             UndirectedEdge[94, 126] -> 
             RGBColor[
              0.3626762195061153, 0.4884130176495661, 0.9443355349736948], 
             UndirectedEdge[41, 198] -> 
             RGBColor[
              0.6229374569936681, 0.7039435412138363, 0.9640225581060137], 
             UndirectedEdge[11, 77] -> 
             RGBColor[
              0.27312817427562797`, 0.40440540686310084`, 0.9388656175168482],
              UndirectedEdge[29, 122] -> 
             RGBColor[
              0.9932906731582525, 0.9894716805478189, 0.6138869514576812], 
             UndirectedEdge[84, 152] -> 
             RGBColor[
              0.2722580627952489, 0.4034908645289682, 0.9388160659552552], 
             UndirectedEdge[16, 64] -> 
             RGBColor[
              0.47278195616545676`, 0.5793252259853976, 0.9526162456912082], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.23972819328057, 0.3692999091561883, 0.9369635380100236], 
             UndirectedEdge[26, 121] -> 
             RGBColor[
              0.46953919243500225`, 0.5786867158238351, 0.9518099844973704], 
             UndirectedEdge[40, 74] -> 
             RGBColor[
              0.3971820108095485, 0.5168505289536836, 0.9468363149531384], 
             UndirectedEdge[78, 91] -> 
             RGBColor[
              0.8828910750951913, 0.909457394113841, 0.9886921329803882], 
             UndirectedEdge[139, 152] -> 
             RGBColor[
              0.26544888260262894`, 0.3963339844195651, 0.9384282932165648], 
             UndirectedEdge[40, 196] -> 
             RGBColor[
              0.49337743215923585`, 0.5995850516837207, 0.9532596252421102], 
             UndirectedEdge[6, 86] -> 
             RGBColor[
              0.3660057031110193, 0.4914374768784062, 0.9445425376494667], 
             UndirectedEdge[82, 180] -> 
             RGBColor[
              0.5213332999548519, 0.6173712520138998, 0.9573268973237518], 
             UndirectedEdge[44, 90] -> 
             RGBColor[
              0.33568645678912695`, 0.46283528505433924`, 0.9426963443190322],
              UndirectedEdge[4, 66] -> 
             RGBColor[
              0.7482528569010358, 0.8032600858342098, 0.9755425100215394], 
             UndirectedEdge[131, 143] -> 
             RGBColor[
              0.8469518489434293, 0.3190606581337521, 0.19091704430262602`], 
             UndirectedEdge[22, 144] -> 
             RGBColor[
              0.8484532037403029, 0.37343813304304, 0.19403214866276774`], 
             UndirectedEdge[35, 160] -> 
             RGBColor[
              0.6025425418355174, 0.6830045883363345, 0.9645167582458221], 
             UndirectedEdge[76, 174] -> 
             RGBColor[
              0.3288804579296929, 0.4562862523383694, 0.9422866189141441], 
             UndirectedEdge[85, 196] -> 
             RGBColor[
              0.42766426196123664`, 0.5437065481057618, 0.9487853774832657], 
             UndirectedEdge[6, 137] -> 
             RGBColor[
              0.2951194473890727, 0.4246251929966973, 0.9402239674768278], 
             UndirectedEdge[123, 177] -> 
             RGBColor[
              0.27201910823742403`, 0.40323970813810023`, 0.9388024578466887],
              UndirectedEdge[29, 113] -> 
             RGBColor[
              0.946972557498295, 0.8159080843147557, 0.4967685640741427], 
             UndirectedEdge[96, 174] -> 
             RGBColor[
              0.3438036499941711, 0.471971473383162, 0.943136472625332], 
             UndirectedEdge[74, 158] -> 
             RGBColor[
              0.2780238238703263, 0.40955104498924105`, 0.9391444175188017], 
             UndirectedEdge[46, 121] -> 
             RGBColor[
              0.570208977683367, 0.6619603615618923, 0.9593080859489944], 
             UndirectedEdge[32, 165] -> 
             RGBColor[
              0.2270272954930984, 0.35595046029812505`, 0.9362402406703216], 
             UndirectedEdge[32, 148] -> 
             RGBColor[
              0.219972379693155, 0.3485352964848875, 0.9358384736523275], 
             UndirectedEdge[27, 190] -> 
             RGBColor[
              0.22822804580985986`, 0.3572125250130086, 0.9363086216245102], 
             UndirectedEdge[100, 123] -> 
             RGBColor[
              0.23212285998297438`, 0.3613062216544334, 0.9365304255298079], 
             UndirectedEdge[45, 172] -> 
             RGBColor[
              0.9391683499060914, 0.7786563284917088, 0.4055000051193155], 
             UndirectedEdge[85, 99] -> 
             RGBColor[
              0.4621252914114974, 0.5716835642651686, 0.9514982759565006], 
             UndirectedEdge[106, 112] -> 
             RGBColor[
              0.2882506044320779, 0.42030003977498026`, 0.9397268175426274], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.8858165933462555, 0.5084410776664401, 0.4035840439814582], 
             UndirectedEdge[43, 197] -> 
             RGBColor[
              0.8665492485482925, 0.589132844492627, 0.463523131888269], 
             UndirectedEdge[26, 164] -> 
             RGBColor[
              0.34556297092325194`, 0.47243449330876475`, 0.9432874166489127],
              UndirectedEdge[100, 130] -> 
             RGBColor[
              0.2255191848288738, 0.3543653403702861, 0.9361543559990437], 
             UndirectedEdge[46, 196] -> 
             RGBColor[
              0.5464579464995596, 0.642678204475116, 0.9574383177713113], 
             UndirectedEdge[156, 181] -> 
             RGBColor[
              0.9525868256306654, 0.9637539256660137, 0.9508348285678401], 
             UndirectedEdge[62, 96] -> 
             RGBColor[
              0.33121568258703066`, 0.4610684087047351, 0.9423343784732514], 
             UndirectedEdge[54, 58] -> 
             RGBColor[
              0.2684799532608956, 0.3995198318623828, 0.9386009082064859], 
             UndirectedEdge[179, 183] -> 
             RGBColor[
              0.8425848980962714, 0.5878064340228173, 0.4637091200002722], 
             UndirectedEdge[65, 198] -> 
             RGBColor[
              0.809127231953634, 0.8516409245369697, 0.9813908857977319], 
             UndirectedEdge[4, 80] -> 
             RGBColor[
              0.7123913946505943, 0.7749007508046878, 0.972203429564615], 
             UndirectedEdge[159, 197] -> 
             RGBColor[
              0.844735305466295, 0.4214613190335854, 0.44263407535762334`], 
             UndirectedEdge[78, 136] -> 
             RGBColor[
              0.9179856014839756, 0.8091909436388446, 0.6189147464565151], 
             UndirectedEdge[153, 188] -> 
             RGBColor[
              0.6253120347428027, 0.7063539747569785, 0.9638795069847599], 
             UndirectedEdge[35, 174] -> 
             RGBColor[
              0.6098919568384804, 0.6893702822195625, 0.9649850564709783], 
             UndirectedEdge[82, 130] -> 
             RGBColor[
              0.27791125977355285`, 0.4085218087190706, 0.9391713605597196], 
             UndirectedEdge[124, 176] -> 
             RGBColor[
              0.29262570831728996`, 0.4248985513559462, 0.9399759732365041], 
             UndirectedEdge[6, 186] -> 
             RGBColor[
              0.3110411018029656, 0.4413598612768941, 0.941130682141722], 
             UndirectedEdge[1, 144] -> 
             RGBColor[
              0.8904481262845415, 0.5806212475838041, 0.23201956236806448`], 
             UndirectedEdge[43, 67] -> 
             RGBColor[
              0.8429788155468371, 0.3313595864958591, 0.18878986834626774`], 
             UndirectedEdge[24, 119] -> 
             RGBColor[
              0.37190268708568275`, 0.48151336908456555`, 0.9461947206260288],
              UndirectedEdge[93, 139] -> 
             RGBColor[
              0.2366529007205347, 0.36606758169078113`, 0.9367884046482173], 
             UndirectedEdge[38, 146] -> 
             RGBColor[
              0.8804514017100027, 0.8667932734581691, 0.6490490676279728], 
             UndirectedEdge[110, 127] -> 
             RGBColor[
              0.46330733319948464`, 0.5715960026043997, 0.9518806741110254], 
             UndirectedEdge[41, 81] -> 
             RGBColor[
              0.563023955866433, 0.6561272371693612, 0.9587424547119633], 
             UndirectedEdge[85, 194] -> 
             RGBColor[
              0.35434213313173446`, 0.48133507879042225`, 0.9437993452840767],
              UndirectedEdge[52, 70] -> 
             RGBColor[
              0.2130689137116028, 0.34127931603325223`, 0.9354453314774407], 
             UndirectedEdge[149, 170] -> 
             RGBColor[
              0.2079666859588458, 0.3359165511651807, 0.9351547671549908], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.30721338060851633`, 0.43871808624608816`, 0.9408621191648285],
              UndirectedEdge[92, 155] -> 
             RGBColor[
              0.23916918979888965`, 0.36871236105407446`, 0.9369317035887135],
              UndirectedEdge[57, 141] -> 
             RGBColor[
              0.35995825064388254`, 0.48619947750517123`, 0.9441571993258131],
              UndirectedEdge[149, 159] -> 
             RGBColor[
              0.6262856435829035, 0.23764894098782902`, 0.4250826867234967], 
             UndirectedEdge[142, 167] -> 
             RGBColor[
              0.7780824099898748, 0.8273108495391253, 0.9783266471470176], 
             UndirectedEdge[117, 173] -> 
             RGBColor[
              0.8870698836005233, 0.9096475021441977, 0.8455791000881498], 
             UndirectedEdge[99, 179] -> 
             RGBColor[
              0.6860146185776324, 0.753440204048828, 0.970158876487192], 
             UndirectedEdge[5, 11] -> 
             RGBColor[
              0.2640346736892395, 0.39484756118556874`, 0.938347756111082], 
             UndirectedEdge[29, 188] -> 
             RGBColor[
              0.8291485068413533, 0.8647956293451209, 0.8611126603250323], 
             UndirectedEdge[46, 178] -> 
             RGBColor[
              0.7700871696380653, 0.8204498262888431, 0.9719037985104857], 
             UndirectedEdge[101, 137] -> 
             RGBColor[
              0.25101571036429215`, 0.3811638052810985, 0.9376063454095565], 
             UndirectedEdge[3, 20] -> 
             RGBColor[
              0.24453230342971405`, 0.374349333521115, 0.9372371249759732], 
             UndirectedEdge[186, 199] -> 
             RGBColor[
              0.2771594494145085, 0.4086425326316706, 0.9390951926722704], 
             UndirectedEdge[156, 179] -> 
             RGBColor[
              0.864388741144453, 0.8948015330551333, 0.986901517469225], 
             UndirectedEdge[67, 87] -> 
             RGBColor[
              0.8747953206754928, 0.4237267463664781, 0.39303006082518865`], 
             UndirectedEdge[3, 10] -> 
             RGBColor[
              0.27648968445364525`, 0.4079385671922522, 0.9390570505485776], 
             UndirectedEdge[55, 185] -> 
             RGBColor[
              0.5609776882411449, 0.6497765761810184, 0.9606709927749343], 
             UndirectedEdge[5, 28] -> 
             RGBColor[
              0.28849193082278163`, 0.4205536891125868, 0.9397405607235676], 
             UndirectedEdge[37, 170] -> 
             RGBColor[
              0.18667955632742156`, 0.31354242824058126`, 0.9339424966139673],
              UndirectedEdge[49, 154] -> 
             RGBColor[
              0.8853342489533117, 0.5082416158642724, 0.4115777388398131], 
             UndirectedEdge[24, 89] -> 
             RGBColor[
              0.6289704896989408, 0.3791403610884968, 0.44405788636093535`], 
             UndirectedEdge[73, 115] -> 
             RGBColor[
              0.27934432739444803`, 0.41093897791785206`, 0.9392196182409905],
              UndirectedEdge[153, 174] -> 
             RGBColor[
              0.4836903414503127, 0.5897681807806197, 0.9530364909078715], 
             UndirectedEdge[119, 183] -> 
             RGBColor[
              0.7615664433424367, 0.5237229317976604, 0.4561749529436979], 
             UndirectedEdge[4, 168] -> 
             RGBColor[
              0.8717390399773187, 0.9006124860515876, 0.9850092222919777], 
             UndirectedEdge[144, 181] -> 
             RGBColor[
              0.8991205652819477, 0.619537019745982, 0.4376211825067001], 
             UndirectedEdge[53, 123] -> 
             RGBColor[
              0.2309218560021901, 0.36004389032257866`, 0.9364620301298284], 
             UndirectedEdge[110, 162] -> 
             RGBColor[
              0.7939641442587955, 0.8384977959010833, 0.9379384858342741], 
             UndirectedEdge[127, 176] -> 
             RGBColor[
              0.3078922888084153, 0.4397573979887158, 0.940888855185277], 
             UndirectedEdge[9, 102] -> 
             RGBColor[
              0.31720087863442126`, 0.44471069767262583`, 0.9415958382088386],
              UndirectedEdge[27, 195] -> 
             RGBColor[
              0.22783801477683696`, 0.3568025776679057, 0.9362864099341788], 
             UndirectedEdge[60, 130] -> 
             RGBColor[
              0.2455906790412874, 0.3754617533937681, 0.9372973979013259], 
             UndirectedEdge[89, 122] -> 
             RGBColor[
              0.9003075980023684, 0.6064437341064228, 0.29047713264699326`], 
             UndirectedEdge[5, 106] -> 
             RGBColor[
              0.2786294913144741, 0.4101876398745743, 0.9391789093837413], 
             UndirectedEdge[83, 199] -> 
             RGBColor[
              0.2640684264301843, 0.3948830374563491, 0.938349678279746], 
             UndirectedEdge[118, 125] -> 
             RGBColor[
              0.5461336776674304, 0.6195695759530597, 0.9625480754195246], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.2678093745072151, 0.3988150110751161, 0.9385627197384963], 
             UndirectedEdge[5, 112] -> 
             RGBColor[
              0.29182817897856506`, 0.4240602974546656, 0.9399305551205026], 
             UndirectedEdge[109, 146] -> 
             RGBColor[
              0.5668187671363596, 0.653709441066444, 0.9615199202813867], 
             UndirectedEdge[164, 184] -> 
             RGBColor[
              0.33292802569279517`, 0.46149073880095526`, 0.9424823291114712],
              UndirectedEdge[51, 164] -> 
             RGBColor[
              0.28843151316149873`, 0.42049018631987756`, 0.9397371200271375],
              UndirectedEdge[45, 168] -> 
             RGBColor[
              0.9114761724933723, 0.7607551980488345, 0.6070253886431892], 
             UndirectedEdge[148, 165] -> 
             RGBColor[
              0.2118480097340456, 0.33999606854305653`, 0.9353758028020844], 
             UndirectedEdge[166, 184] -> 
             RGBColor[
              0.3810287222999791, 0.5044496610209838, 0.9454997911478531], 
             UndirectedEdge[21, 132] -> 
             RGBColor[
              0.28420798371714023`, 0.41536166731241486`, 0.9395218357203131],
              UndirectedEdge[96, 157] -> 
             RGBColor[
              0.43194074873512733`, 0.5454775949392545, 0.9495354789637005], 
             UndirectedEdge[42, 102] -> 
             RGBColor[
              0.4476381958746549, 0.5602937273030086, 0.9502551687958871], 
             UndirectedEdge[117, 120] -> 
             RGBColor[
              0.8678835994276715, 0.8465560061197337, 0.6325812491960736], 
             UndirectedEdge[25, 129] -> 
             RGBColor[
              0.9845905971173718, 0.9596826071563495, 0.39463780893289646`], 
             UndirectedEdge[57, 90] -> 
             RGBColor[
              0.37426337273503046`, 0.49858985526418154`, 0.9450687090559382],
              UndirectedEdge[51, 184] -> 
             RGBColor[
              0.3266364768489205, 0.4548779220588064, 0.942124034712325], 
             UndirectedEdge[95, 103] -> 
             RGBColor[
              0.9027357759104662, 0.63208364163686, 0.26409899908324835`], 
             UndirectedEdge[47, 105] -> 
             RGBColor[
              0.3973660260121461, 0.5186002123597028, 0.9465407896938819], 
             UndirectedEdge[127, 177] -> 
             RGBColor[
              0.3075972075411117, 0.4394472488675467, 0.9408720507436377], 
             UndirectedEdge[73, 153] -> 
             RGBColor[
              0.4395524049734263, 0.5500947505807087, 0.9502769094004289], 
             UndirectedEdge[137, 199] -> 
             RGBColor[
              0.26123779500061556`, 0.39190786435147384`, 0.9381884780073761],
              UndirectedEdge[138, 185] -> 
             RGBColor[
              0.8411744991425061, 0.7559037234450623, 0.613171500043548], 
             UndirectedEdge[88, 136] -> 
             RGBColor[
              0.8101006391447247, 0.7240376246779792, 0.6083933870270145], 
             UndirectedEdge[55, 76] -> 
             RGBColor[
              0.31436618073050393`, 0.4437147149372155, 0.9413617820054831], 
             UndirectedEdge[135, 176] -> 
             RGBColor[
              0.26373796268785954`, 0.3945356991105544, 0.938330858858498], 
             UndirectedEdge[69, 123] -> 
             RGBColor[
              0.3260085199796461, 0.4514023478470298, 0.9421913646386602], 
             UndirectedEdge[2, 40] -> 
             RGBColor[
              0.43435111341602517`, 0.5495958945368197, 0.9491845094203311], 
             UndirectedEdge[105, 174] -> 
             RGBColor[
              0.3623104663482657, 0.48823684852250904`, 0.9443070804305137], 
             UndirectedEdge[89, 138] -> 
             RGBColor[
              0.8735867140642237, 0.5079729105623115, 0.2157827080806035], 
             UndirectedEdge[37, 128] -> 
             RGBColor[
              0.5402876317341454, 0.454787094862522, 0.5818823157705433], 
             UndirectedEdge[88, 153] -> 
             RGBColor[
              0.6490823398625842, 0.7249235177775619, 0.9662487088529688], 
             UndirectedEdge[113, 197] -> 
             RGBColor[
              0.8946095450697447, 0.7772196138099509, 0.6138944273650201], 
             UndirectedEdge[31, 178] -> 
             RGBColor[
              0.8964701273649321, 0.9201113391332241, 0.9839677082524034], 
             UndirectedEdge[82, 177] -> 
             RGBColor[
              0.3061026011103605, 0.4381526958983335, 0.9407768157434988], 
             UndirectedEdge[87, 108] -> 
             RGBColor[
              0.8846035797290293, 0.9091596462519311, 0.913892802031036], 
             UndirectedEdge[64, 86] -> 
             RGBColor[
              0.5072811113074129, 0.6092066601914048, 0.9548145013504485], 
             UndirectedEdge[116, 157] -> 
             RGBColor[
              0.47363379400133276`, 0.5818257161885222, 0.9521834927723848], 
             UndirectedEdge[120, 168] -> 
             RGBColor[
              0.9476806026150666, 0.909778086957847, 0.6376934323137864], 
             UndirectedEdge[18, 54] -> 
             RGBColor[
              0.295588460550005, 0.42712274502129255`, 0.9401772792428172], 
             UndirectedEdge[161, 176] -> 
             RGBColor[
              0.301427951999442, 0.43415026756037145`, 0.9404772479924501], 
             UndirectedEdge[168, 172] -> 
             RGBColor[
              0.9662845352880476, 0.9716239920088556, 0.7873059163017873], 
             UndirectedEdge[142, 157] -> 
             RGBColor[
              0.5992869263853755, 0.6855671502648439, 0.9615972085868523], 
             UndirectedEdge[121, 171] -> 
             RGBColor[
              0.7085728332018904, 0.7711751170925334, 0.9725147444177542], 
             UndirectedEdge[47, 94] -> 
             RGBColor[
              0.4348245890199799, 0.551044936914969, 0.9489276162054343], 
             UndirectedEdge[70, 93] -> 
             RGBColor[
              0.21891136206643785`, 0.34742009968680476`, 0.9357780502681208],
              UndirectedEdge[32, 163] -> 
             RGBColor[
              0.23408691252963393`, 0.3633705654090964, 0.9366422754167848], 
             UndirectedEdge[35, 142] -> 
             RGBColor[
              0.7396311759520104, 0.7966508792482756, 0.9746591341186641], 
             UndirectedEdge[12, 193] -> 
             RGBColor[
              0.4503245613855142, 0.5609229257874412, 0.950895392546576], 
             UndirectedEdge[35, 94] -> 
             RGBColor[
              0.6282503776636906, 0.7052714236172997, 0.9661548388122466], 
             UndirectedEdge[116, 174] -> 
             RGBColor[
              0.38549669526037655`, 0.5083195946324296, 0.9457844864340161], 
             UndirectedEdge[112, 140] -> 
             RGBColor[
              0.30347647446516857`, 0.4363033945556761, 0.9405939083163557], 
             UndirectedEdge[86, 176] -> 
             RGBColor[
              0.3430782654932676, 0.4702337224945253, 0.9431308745058982], 
             UndirectedEdge[61, 73] -> 
             RGBColor[
              0.28346587285648317`, 0.41527098351952657`, 0.9394543341577734],
              UndirectedEdge[33, 66] -> 
             RGBColor[
              0.5073300220022017, 0.606620425388813, 0.955851339828218], 
             UndirectedEdge[48, 106] -> 
             RGBColor[
              0.29607730783621694`, 0.42775376738301063`, 0.9402008266352594],
              UndirectedEdge[86, 199] -> 
             RGBColor[
              0.3321240507225622, 0.4587201482331828, 0.9425070481800151], 
             UndirectedEdge[10, 59] -> 
             RGBColor[
              0.3690604515059446, 0.4922869105332728, 0.9448029598331952], 
             UndirectedEdge[1, 113] -> 
             RGBColor[
              0.9293073420017215, 0.7556088200837405, 0.2655373341471002], 
             UndirectedEdge[125, 128] -> 
             RGBColor[
              0.5342706715319968, 0.44846288819275276`, 0.5815396587883258], 
             UndirectedEdge[53, 165] -> 
             RGBColor[
              0.21515759774182608`, 0.3434746553792333, 0.935564278943031], 
             UndirectedEdge[87, 143] -> 
             RGBColor[
              0.876523819007324, 0.43701274197773154`, 0.3946852727798099], 
             UndirectedEdge[61, 105] -> 
             RGBColor[
              0.30850366715074595`, 0.4384008305619083, 0.9409968714949317], 
             UndirectedEdge[29, 47] -> 
             RGBColor[
              0.7225823732127437, 0.7785731992059557, 0.8525033535115121], 
             UndirectedEdge[24, 27] -> 
             RGBColor[
              0.22783801619652955`, 0.3568025791600926, 0.9362864100150281], 
             UndirectedEdge[98, 117] -> 
             RGBColor[
              0.8762433687105626, 0.9035134810174441, 0.9541841801385145], 
             UndirectedEdge[1, 88] -> 
             RGBColor[
              0.8352535964645615, 0.823065908134689, 0.6322506322661987], 
             UndirectedEdge[190, 195] -> 
             RGBColor[
              0.1793170310330229, 0.30580394734510286`, 0.9335232116903315], 
             UndirectedEdge[4, 173] -> 
             RGBColor[
              0.9000135688899087, 0.9197592074679171, 0.8468692056721795], 
             UndirectedEdge[81, 164] -> 
             RGBColor[
              0.43552843920258344`, 0.5470178923073767, 0.9499428350575294], 
             UndirectedEdge[82, 123] -> 
             RGBColor[
              0.28451493492765345`, 0.4154626900032179, 0.9395474300904838], 
             UndirectedEdge[43, 87] -> 
             RGBColor[
              0.8995684415169597, 0.6141438088047649, 0.4167528293202155], 
             UndirectedEdge[38, 171] -> 
             RGBColor[
              0.919639217056486, 0.8978474840035989, 0.6528380765050477], 
             UndirectedEdge[46, 85] -> 
             RGBColor[
              0.4789487657995369, 0.5853416186622634, 0.9528226814867443], 
             UndirectedEdge[64, 69] -> 
             RGBColor[
              0.512094113243802, 0.613375440560194, 0.9551211815778647], 
             UndirectedEdge[60, 82] -> 
             RGBColor[
              0.2862778470683244, 0.4173156224381487, 0.9396478253289002], 
             UndirectedEdge[77, 189] -> 
             RGBColor[
              0.2658927211222934, 0.3968004868447199, 0.9384535691636595], 
             UndirectedEdge[101, 187] -> 
             RGBColor[
              0.2673357347336053, 0.3983171856425559, 0.9385357466540765], 
             UndirectedEdge[64, 161] -> 
             RGBColor[
              0.4656307978135873, 0.573123205257251, 0.9521608748370004], 
             UndirectedEdge[7, 160] -> 
             RGBColor[
              0.3585859521924276, 0.48501086156024664`, 0.9440697576819622], 
             UndirectedEdge[16, 83] -> 
             RGBColor[
              0.2894048145974629, 0.4201988877306557, 0.9398406710693048], 
             UndirectedEdge[13, 124] -> 
             RGBColor[
              0.3345268948480242, 0.4625364133999037, 0.9425966268829805], 
             UndirectedEdge[46, 171] -> 
             RGBColor[
              0.7361063058563833, 0.7935280305622586, 0.9746822802435494], 
             UndirectedEdge[1, 197] -> 
             RGBColor[
              0.9236147906417135, 0.8926515043216656, 0.6409097972593247], 
             UndirectedEdge[26, 80] -> 
             RGBColor[
              0.5081499735315052, 0.6100326873138424, 0.9548495666212384], 
             UndirectedEdge[23, 43] -> 
             RGBColor[
              0.9014366337014165, 0.6139370032291189, 0.31460356700739317`], 
             UndirectedEdge[13, 86] -> 
             RGBColor[
              0.38497945202400186`, 0.5078715845384828, 0.9457515281523746], 
             UndirectedEdge[31, 146] -> 
             RGBColor[
              0.8233014482367667, 0.8621353328612098, 0.9829571811083924], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.6527715209369094, 0.7286468226851102, 0.9660412183253722], 
             UndirectedEdge[124, 127] -> 
             RGBColor[
              0.30632106017096694`, 0.43810593706910805`, 0.9407993760387987],
              UndirectedEdge[60, 163] -> 
             RGBColor[
              0.24348971297155947`, 0.37325350484554143`, 0.9371777509917558],
              UndirectedEdge[4, 184] -> 
             RGBColor[
              0.5880093557297629, 0.671690292538539, 0.9630281942774768], 
             UndirectedEdge[144, 192] -> 
             RGBColor[
              0.8434502637599781, 0.33498334405198565`, 0.18924132768759622`],
              UndirectedEdge[38, 192] -> 
             RGBColor[
              0.8664820909126885, 0.38706872730476605`, 0.21540773809926206`],
              UndirectedEdge[49, 108] -> 
             RGBColor[
              0.8169025980884497, 0.455017381178201, 0.44687525682009266`], 
             UndirectedEdge[83, 165] -> 
             RGBColor[
              0.2373756354905151, 0.36682722175806165`, 0.9368295633241774], 
             UndirectedEdge[183, 192] -> 
             RGBColor[
              0.84571331956511, 0.349221020069408, 0.19128480591357822`], 
             UndirectedEdge[79, 159] -> 
             RGBColor[
              0.6164190249825052, 0.2272784992590594, 0.42452079739055826`], 
             UndirectedEdge[81, 166] -> 
             RGBColor[
              0.4836291358097673, 0.5899768145274054, 0.9529602970939112], 
             UndirectedEdge[118, 119] -> 
             RGBColor[
              0.7390929491372125, 0.7956716911845035, 0.9752408612005126], 
             UndirectedEdge[47, 153] -> 
             RGBColor[
              0.518745901114193, 0.6201315446178133, 0.9552702001712396], 
             UndirectedEdge[74, 184] -> 
             RGBColor[
              0.3369577946710508, 0.46572628149921225`, 0.9427118184932739], 
             UndirectedEdge[149, 190] -> 
             RGBColor[
              0.2066375350628038, 0.33451952930040635`, 0.9350790739777637], 
             UndirectedEdge[55, 139] -> 
             RGBColor[
              0.3007701310464627, 0.42942440467994913`, 0.9405875070895301], 
             UndirectedEdge[22, 138] -> 
             RGBColor[
              0.8672064638387251, 0.45893151148565325`, 0.20967297325920412`],
              UndirectedEdge[113, 144] -> 
             RGBColor[
              0.871111295903229, 0.5036666539093275, 0.21400931577186139`], 
             UndirectedEdge[80, 172] -> 
             RGBColor[
              0.8069368899613232, 0.8459122567619559, 0.7745001235744244], 
             UndirectedEdge[8, 156] -> 
             RGBColor[
              0.6845205611909437, 0.7511737984198581, 0.97104590551255], 
             UndirectedEdge[22, 118] -> 
             RGBColor[
              0.8673837475077953, 0.5395378434117971, 0.45731224525585845`], 
             UndirectedEdge[100, 163] -> 
             RGBColor[
              0.22341821875914586`, 0.35215709182205945`, 0.9360347090894736],
              UndirectedEdge[12, 154] -> 
             RGBColor[
              0.7852450872055535, 0.8309115028617888, 0.9166639457901922], 
             UndirectedEdge[67, 129] -> 
             RGBColor[
              0.8755570267580526, 0.42023027988113926`, 0.24893178910674738`],
              UndirectedEdge[49, 129] -> 
             RGBColor[
              0.8865782994288154, 0.5049446111811012, 0.25948577226301694`], 
             UndirectedEdge[127, 175] -> 
             RGBColor[
              0.32099276834406665`, 0.45244953519915593`, 0.9416743532494919],
              UndirectedEdge[30, 198] -> 
             RGBColor[
              0.7949540018905729, 0.840339575606766, 0.9800390304617252], 
             UndirectedEdge[5, 140] -> 
             RGBColor[
              0.2938553613475648, 0.42619099465527016`, 0.9400460001574695], 
             UndirectedEdge[147, 156] -> 
             RGBColor[
              0.7007698065694198, 0.7645047047938165, 0.9722866893066117], 
             UndirectedEdge[122, 159] -> 
             RGBColor[
              0.8794090834796054, 0.44580859369701076`, 0.2704646915384994], 
             UndirectedEdge[82, 110] -> 
             RGBColor[
              0.4618127267687334, 0.5703014496351865, 0.9517854391108865], 
             UndirectedEdge[83, 176] -> 
             RGBColor[
              0.2750226412008897, 0.4063966117176916, 0.9389735046056292], 
             UndirectedEdge[10, 77] -> 
             RGBColor[
              0.2948550356150111, 0.4272417156933656, 0.9401029301281152], 
             UndirectedEdge[104, 130] -> 
             RGBColor[
              0.2280794521267412, 0.3570563436306672, 0.9363001594340813], 
             UndirectedEdge[30, 66] -> 
             RGBColor[
              0.7926835884248224, 0.8385659113515402, 0.9798127368656795], 
             UndirectedEdge[85, 132] -> 
             RGBColor[
              0.3061847210307328, 0.43439681259051416`, 0.9409221739886695], 
             UndirectedEdge[24, 195] -> 
             RGBColor[
              0.1789270014196926, 0.30539400149218693`, 0.9335010000808495], 
             UndirectedEdge[50, 123] -> 
             RGBColor[
              0.24633186843467056`, 0.37624079044033565`, 0.9373396075407877],
              UndirectedEdge[42, 153] -> 
             RGBColor[
              0.5537057705483233, 0.648562314548655, 0.9580088930300842], 
             UndirectedEdge[127, 161] -> 
             RGBColor[
              0.31512330385311904`, 0.4473576532735334, 0.9413006507947447], 
             UndirectedEdge[7, 18] -> 
             RGBColor[
              0.33441529127436986`, 0.4640754499257662, 0.9425296245415398], 
             UndirectedEdge[65, 66] -> 
             RGBColor[
              0.8068568184878835, 0.8498672602817441, 0.9811645922016861], 
             UndirectedEdge[150, 152] -> 
             RGBColor[
              0.2823331640327409, 0.4140804347278859, 0.9393898280659538], 
             UndirectedEdge[25, 87] -> 
             RGBColor[
              0.9834480379935321, 0.9649273068843578, 0.6107852165105583], 
             UndirectedEdge[69, 82] -> 
             RGBColor[
              0.3600920128525825, 0.48631533560726303`, 0.9441657225354702], 
             UndirectedEdge[1, 159] -> 
             RGBColor[
              0.867867170087613, 0.40705412321611184`, 0.21039601321234347`], 
             UndirectedEdge[23, 131] -> 
             RGBColor[
              0.9464189057965813, 0.8120568568548516, 0.39007974658807487`], 
             UndirectedEdge[126, 160] -> 
             RGBColor[
              0.336968383677942, 0.466146182368601, 0.9426974544072704], 
             UndirectedEdge[67, 131] -> 
             RGBColor[
              0.8452233506115981, 0.3057746625224987, 0.18926183234800478`], 
             UndirectedEdge[142, 174] -> 
             RGBColor[
              0.5111498276444193, 0.6120610287087513, 0.9551982022484837], 
             UndirectedEdge[22, 122] -> 
             RGBColor[
              0.8939273477768698, 0.5574023350297646, 0.28436739782559384`], 
             UndirectedEdge[32, 176] -> 
             RGBColor[
              0.264674301203473, 0.39551985025775493`, 0.9383841819517735], 
             UndirectedEdge[47, 160] -> 
             RGBColor[
              0.4091167531918066, 0.528778101634004, 0.9472895356390099], 
             UndirectedEdge[79, 125] -> 
             RGBColor[
              0.19146399032539158`, 0.3185711717230839, 0.934214963052216], 
             UndirectedEdge[47, 111] -> 
             RGBColor[
              0.45600877007092583`, 0.5691987153613436, 0.9503313034018304], 
             UndirectedEdge[3, 186] -> 
             RGBColor[
              0.27284687806334806`, 0.40410974670878463`, 0.9388495981136993],
              UndirectedEdge[105, 160] -> 
             RGBColor[
              0.35496105134530265`, 0.4818711546392811, 0.9438387822053573], 
             UndirectedEdge[9, 189] -> 
             RGBColor[
              0.24597910372864595`, 0.37587001236772954`, 0.9373195181126482],
              UndirectedEdge[64, 175] -> 
             RGBColor[
              0.4715002623045349, 0.5782150871828736, 0.9525345772917476], 
             UndirectedEdge[100, 165] -> 
             RGBColor[
              0.21635860172261037`, 0.34473698671108804`, 0.9356326743430103],
              UndirectedEdge[101, 161] -> 
             RGBColor[
              0.28025165259241314`, 0.41189263422865363`, 0.9392712890687474],
              UndirectedEdge[123, 187] -> 
             RGBColor[
              0.26662928669062347`, 0.3975746639579891, 0.9384955154831248], 
             UndirectedEdge[90, 198] -> 
             RGBColor[
              0.542054826289809, 0.636504451768819, 0.9581455985091416], 
             UndirectedEdge[146, 171] -> 
             RGBColor[
              0.8352823460284233, 0.8716885755474699, 0.9840999298352342], 
             UndirectedEdge[62, 157] -> 
             RGBColor[
              0.4569597398647052, 0.567383488557704, 0.951121036787086], 
             UndirectedEdge[2, 164] -> 
             RGBColor[
              0.3359219335901057, 0.4640839113434194, 0.9426730982752791], 
             UndirectedEdge[94, 142] -> 
             RGBColor[
              0.5295082484696294, 0.6279621701064884, 0.9563679845897519], 
             UndirectedEdge[12, 175] -> 
             RGBColor[
              0.4521802655001208, 0.5625302434211127, 0.9510136363718239], 
             UndirectedEdge[23, 64] -> 
             RGBColor[
              0.8080908888760686, 0.8465853309633324, 0.7529704509533501], 
             UndirectedEdge[73, 160] -> 
             RGBColor[
              0.3299232570510399, 0.45874130759689935`, 0.9422962448681991], 
             UndirectedEdge[47, 142] -> 
             RGBColor[
              0.5462053873082997, 0.642424392545945, 0.9574319115118519], 
             UndirectedEdge[31, 120] -> 
             RGBColor[
              0.9036386065731989, 0.8747348065350462, 0.6360795030302686], 
             UndirectedEdge[9, 20] -> 
             RGBColor[
              0.24298403719743245`, 0.3727220075452381, 0.9371489535044994], 
             UndirectedEdge[174, 188] -> 
             RGBColor[
              0.5230323018233795, 0.6213662256563972, 0.9563671406776864], 
             UndirectedEdge[45, 173] -> 
             RGBColor[
              0.9397507014059623, 0.7799019194651641, 0.46888537202339087`], 
             UndirectedEdge[139, 191] -> 
             RGBColor[
              0.2646944952587164, 0.3955410754901928, 0.9383853319733451], 
             UndirectedEdge[24, 170] -> 
             RGBColor[
              0.18064618334875748`, 0.3072009707020641, 0.9335989049484079], 
             UndirectedEdge[118, 195] -> 
             RGBColor[
              0.5461172634712222, 0.6195523235921249, 0.9625471406553332], 
             UndirectedEdge[124, 137] -> 
             RGBColor[
              0.27062078113387267`, 0.4017699776932086, 0.938722825186781], 
             UndirectedEdge[28, 63] -> 
             RGBColor[
              0.3238146353715521, 0.45360214621203954`, 0.941901450034025], 
             UndirectedEdge[7, 94] -> 
             RGBColor[
              0.3842937880206009, 0.5072776968412117, 0.9457078382483868], 
             UndirectedEdge[37, 190] -> 
             RGBColor[
              0.18535040543137957`, 0.3121454063758069, 0.9338668034367403], 
             UndirectedEdge[31, 40] -> 
             RGBColor[
              0.6710448937244029, 0.7408816350846033, 0.9693608389875064], 
             UndirectedEdge[18, 73] -> 
             RGBColor[
              0.3057525961329822, 0.4378058959624189, 0.9407561117277767], 
             UndirectedEdge[170, 195] -> 
             RGBColor[
              0.1806461819290649, 0.30720096920987716`, 0.9335989048675586], 
             UndirectedEdge[62, 191] -> 
             RGBColor[
              0.3182327281368137, 0.4474225004107011, 0.9415950184238715], 
             UndirectedEdge[152, 194] -> 
             RGBColor[
              0.3151343711235495, 0.4448783558224487, 0.9413924862035001], 
             UndirectedEdge[24, 37] -> 
             RGBColor[
              0.18496037581804925`, 0.31173546052289103`, 0.9338445918272582],
              UndirectedEdge[90, 177] -> 
             RGBColor[
              0.3407778041727428, 0.4681866139645882, 0.9429862890205556], 
             UndirectedEdge[94, 188] -> 
             RGBColor[
              0.5413907226485897, 0.6372673670541342, 0.9575369230189545], 
             UndirectedEdge[103, 133] -> 
             RGBColor[
              0.8506697865477463, 0.3781326515142924, 0.19567142569650792`], 
             UndirectedEdge[38, 179] -> 
             RGBColor[
              0.8863710041657746, 0.8714177118872631, 0.6496390782789341], 
             UndirectedEdge[54, 116] -> 
             RGBColor[
              0.33119462320051296`, 0.4579630134913923, 0.9424460724416142], 
             UndirectedEdge[4, 198] -> 
             RGBColor[
              0.7505232703667862, 0.8050337500894356, 0.9757688036175852], 
             UndirectedEdge[31, 38] -> 
             RGBColor[
              0.9076583192648293, 0.8882942413173389, 0.6516953277782057], 
             UndirectedEdge[35, 47] -> 
             RGBColor[
              0.6449475165023608, 0.7197336460567563, 0.9672187657343465], 
             UndirectedEdge[132, 151] -> 
             RGBColor[
              0.3020454023564957, 0.43081154280309575`, 0.9406584202630028], 
             UndirectedEdge[124, 135] -> 
             RGBColor[
              0.26216673405041124`, 0.39288423819094664`, 0.9382413797120197],
              UndirectedEdge[32, 127] -> 
             RGBColor[
              0.2783696530571501, 0.40872723597091687`, 0.9392075847540681], 
             UndirectedEdge[187, 199] -> 
             RGBColor[
              0.27755781936992874`, 0.40906124471293126`, 0.9391178792518959],
              UndirectedEdge[2, 51] -> 
             RGBColor[
              0.329630384746231, 0.45747109460127056`, 0.9423148038761329], 
             UndirectedEdge[40, 117] -> 
             RGBColor[
              0.6352898865788753, 0.7127028346692909, 0.9658625851533114], 
             UndirectedEdge[9, 17] -> 
             RGBColor[
              0.2497025677004787, 0.37978360908337694`, 0.9375315638774728], 
             UndirectedEdge[33, 57] -> 
             RGBColor[
              0.3418089819131736, 0.4704794931394012, 0.9430007439710605], 
             UndirectedEdge[124, 175] -> 
             RGBColor[
              0.3057261878529413, 0.4375906885663863, 0.9407614713007191], 
             UndirectedEdge[8, 147] -> 
             RGBColor[
              0.4644466210649416, 0.5759586789636362, 0.9510205021407936], 
             UndirectedEdge[108, 110] -> 
             RGBColor[
              0.6931298062895987, 0.7596256615132471, 0.9704393557617335], 
             UndirectedEdge[68, 107] -> 
             RGBColor[
              0.7614279257189907, 0.8138406211600655, 0.9767792324528825], 
             UndirectedEdge[1, 138] -> 
             RGBColor[
              0.9355441317544622, 0.7814661810006367, 0.2706140846810541], 
             UndirectedEdge[94, 160] -> 
             RGBColor[
              0.39241961435313644`, 0.5143158791945474, 0.9462256087169099], 
             UndirectedEdge[138, 142] -> 
             RGBColor[
              0.7768323613465915, 0.7056166385716411, 0.6067738726084364], 
             UndirectedEdge[6, 175] -> 
             RGBColor[
              0.3302248541081414, 0.460445903869875, 0.9422626135907659], 
             UndirectedEdge[34, 104] -> 
             RGBColor[
              0.2353413665909268, 0.3646890761644966, 0.936713714719777], 
             UndirectedEdge[15, 106] -> 
             RGBColor[
              0.3000813368943679, 0.43122185610482894`, 0.9404559598262209], 
             UndirectedEdge[61, 94] -> 
             RGBColor[
              0.34596223015857974`, 0.47084555511717463`, 0.9433836980064841],
              UndirectedEdge[144, 159] -> 
             RGBColor[
              0.8452254175415028, 0.3486279538941323, 0.1909412169535338], 
             UndirectedEdge[83, 86] -> 
             RGBColor[
              0.32390396973941904`, 0.450080321936663, 0.9420389267285452], 
             UndirectedEdge[137, 176] -> 
             RGBColor[
              0.27219200977132096`, 0.4034214386128163, 0.9388123043332592], 
             UndirectedEdge[143, 159] -> 
             RGBColor[
              0.821413781916936, 0.16560128815844824`, 0.1681391677880527], 
             UndirectedEdge[24, 144] -> 
             RGBColor[
              0.6306529313731064, 0.3920723450467769, 0.44566899440816243`], 
             UndirectedEdge[76, 96] -> 
             RGBColor[
              0.2912734993929746, 0.42347729404149315`, 0.9398989669386781], 
             UndirectedEdge[98, 120] -> 
             RGBColor[
              0.9651286166376958, 0.922790787247423, 0.6081584957443529], 
             UndirectedEdge[98, 183] -> 
             RGBColor[
              0.897769781538639, 0.6310947741177858, 0.4464659481425095], 
             UndirectedEdge[55, 75] -> 
             RGBColor[
              0.3182717437982659, 0.44781970934843396`, 0.9415841980444295], 
             UndirectedEdge[35, 68] -> 
             RGBColor[
              0.8469990595612139, 0.880838075189855, 0.985268720497577], 
             UndirectedEdge[25, 43] -> 
             RGBColor[
              0.8965507517688224, 0.5978985527381435, 0.25797231847853164`], 
             UndirectedEdge[47, 174] -> 
             RGBColor[
              0.4164661681947697, 0.535143795517232, 0.9477578338641661], 
             UndirectedEdge[29, 88] -> 
             RGBColor[
              0.8529188119611348, 0.8833651723657042, 0.8634818621932413], 
             UndirectedEdge[17, 140] -> 
             RGBColor[
              0.27217097999434126`, 0.4033993349838457, 0.9388111067185709], 
             UndirectedEdge[41, 90] -> 
             RGBColor[
              0.46883146462921355`, 0.577882603340978, 0.9518176941382794], 
             UndirectedEdge[151, 196] -> 
             RGBColor[
              0.4235249432869995, 0.5401212783183434, 0.9485216237575993], 
             UndirectedEdge[88, 94] -> 
             RGBColor[
              0.5651610277683712, 0.6558369100747177, 0.9599061248871635], 
             UndirectedEdge[57, 198] -> 
             RGBColor[
              0.528369365099485, 0.6246507931370399, 0.9572735730236723], 
             UndirectedEdge[71, 164] -> 
             RGBColor[
              0.2925031947568016, 0.42476978183606456`, 0.9399689962704769], 
             UndirectedEdge[95, 154] -> 
             RGBColor[
              0.9830766756699849, 0.9658160132096346, 0.6241438116222372], 
             UndirectedEdge[69, 90] -> 
             RGBColor[
              0.3947672159149649, 0.5163492536735178, 0.946375195812527], 
             UndirectedEdge[175, 176] -> 
             RGBColor[
              0.30729741649038966`, 0.43924214948599405`, 0.9408509504471974],
              UndirectedEdge[58, 115] -> 
             RGBColor[
              0.2648536806612042, 0.3957083894411449, 0.9383943973465231], 
             UndirectedEdge[42, 88] -> 
             RGBColor[
              0.6168180360411716, 0.6987299024450158, 0.9637087446681081], 
             UndirectedEdge[72, 134] -> 
             RGBColor[
              0.2403643210352666, 0.36996851975920364`, 0.9369997645445869], 
             UndirectedEdge[25, 49] -> 
             RGBColor[
              0.8827989035981182, 0.49219582159981873`, 0.2448035331397743], 
             UndirectedEdge[23, 103] -> 
             RGBColor[
              0.9073868883324812, 0.6473301594421497, 0.31981821239601227`], 
             UndirectedEdge[79, 192] -> 
             RGBColor[
              0.6128687174194557, 0.19998927957476603`, 0.421121018858683], 
             UndirectedEdge[89, 170] -> 
             RGBColor[
              0.6301166100385224, 0.38034500623362366`, 0.4441231562187414], 
             UndirectedEdge[41, 57] -> 
             RGBColor[
              0.4551460034388895, 0.5660289447091988, 0.9509456686528102], 
             UndirectedEdge[10, 14] -> 
             RGBColor[
              0.35304438919669967`, 0.4784146023517027, 0.943782430505298], 
             UndirectedEdge[6, 59] -> 
             RGBColor[
              0.39442835550292343`, 0.516055749816227, 0.9463536039267142], 
             UndirectedEdge[120, 183] -> 
             RGBColor[
              0.8921966020167115, 0.5931231241859789, 0.2320639941808822], 
             UndirectedEdge[8, 194] -> 
             RGBColor[
              0.3983632803443602, 0.5194639839388066, 0.9466043338580932], 
             UndirectedEdge[63, 106] -> 
             RGBColor[
              0.3139521958632445, 0.44323609697402705`, 0.9413397986941987], 
             UndirectedEdge[129, 131] -> 
             RGBColor[
              0.9447591766437358, 0.8071223654903125, 0.32715623247964654`], 
             UndirectedEdge[22, 38] -> 
             RGBColor[
              0.8845506627730023, 0.5259516883218133, 0.23271022291823168`], 
             UndirectedEdge[38, 117] -> 
             RGBColor[
              0.8719033121193018, 0.8601154409020264, 0.6481970739440106], 
             UndirectedEdge[136, 159] -> 
             RGBColor[
              0.8510985318743886, 0.34103526757830527`, 0.19449118305288732`],
              UndirectedEdge[158, 166] -> 
             RGBColor[
              0.3220947514992546, 0.4482744245110126, 0.9419323901733808], 
             UndirectedEdge[75, 96] -> 
             RGBColor[
              0.29517906246073655`, 0.4275822884527116, 0.9401213829776245], 
             UndirectedEdge[118, 170] -> 
             RGBColor[
              0.5478364454002871, 0.6213592928020021, 0.9626450455228917], 
             UndirectedEdge[7, 58] -> 
             RGBColor[
              0.3073067839852605, 0.4364725367668565, 0.9409532535052085], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.7375823865275546, 0.7949242332798678, 0.9744789772559258], 
             UndirectedEdge[65, 180] -> 
             RGBColor[
              0.8230809086810591, 0.8625416428483053, 0.9827816578893989], 
             UndirectedEdge[151, 171] -> 
             RGBColor[
              0.6131733026438233, 0.690971104405486, 0.9657655862298374], 
             UndirectedEdge[37, 118] -> 
             RGBColor[
              0.5521506378695789, 0.625893782622829, 0.962890732401742], 
             UndirectedEdge[7, 47] -> 
             RGBColor[
              0.40099092685927107`, 0.5217399192806683, 0.9467717651704868], 
             UndirectedEdge[46, 99] -> 
             RGBColor[
              0.5809189759498203, 0.6706552206345228, 0.960151216244546], 
             UndirectedEdge[195, 197] -> 
             RGBColor[
              0.5339219968548683, 0.6098281490239381, 0.9613839452386224], 
             UndirectedEdge[5, 63] -> 
             RGBColor[
              0.3175297704097317, 0.4469963546537124, 0.9415435362720739], 
             UndirectedEdge[11, 63] -> 
             RGBColor[
              0.29935737823800995`, 0.4278960182850215, 0.9405086454215394], 
             UndirectedEdge[10, 193] -> 
             RGBColor[
              0.30300124599655587`, 0.4350697469532493, 0.9405937256719987], 
             UndirectedEdge[99, 147] -> 
             RGBColor[
              0.5223956840025993, 0.6231433757875112, 0.9555440483245787], 
             UndirectedEdge[9, 77] -> 
             RGBColor[
              0.2804804496400908, 0.41213311443233347`, 0.9392843187221377], 
             UndirectedEdge[43, 103] -> 
             RGBColor[
              0.8583405032831029, 0.4432646958215179, 0.2032585752880907], 
             UndirectedEdge[54, 174] -> 
             RGBColor[
              0.3271085364710258, 0.454423850539001, 0.942185710608396], 
             UndirectedEdge[149, 197] -> 
             RGBColor[
              0.5612425008846491, 0.6385437309792414, 0.9629398075260546], 
             UndirectedEdge[87, 180] -> 
             RGBColor[
              0.8560213723624259, 0.8868310086243191, 0.9110439947166469], 
             UndirectedEdge[134, 191] -> 
             RGBColor[
              0.25554145744836393`, 0.3859206524153965, 0.9378640800107516], 
             UndirectedEdge[65, 131] -> 
             RGBColor[
              0.9106761538385292, 0.7880776994423069, 0.6150413032300603], 
             UndirectedEdge[107, 147] -> 
             RGBColor[
              0.5739634519525214, 0.664627405018551, 0.9598641490933124], 
             UndirectedEdge[50, 82] -> 
             RGBColor[
              0.28041536130760697`, 0.41115377820056886`, 0.9393139654375977],
              UndirectedEdge[30, 162] -> 
             RGBColor[
              0.9383242239537981, 0.9524410659335498, 0.9517777399403218], 
             UndirectedEdge[51, 74] -> 
             RGBColor[
              0.29246128213975436`, 0.4247257290181345, 0.9399666094089402], 
             UndirectedEdge[12, 161] -> 
             RGBColor[
              0.4463108010091732, 0.5574383614954901, 0.9506399339170767], 
             UndirectedEdge[78, 113] -> 
             RGBColor[
              0.9141333132318434, 0.7927873365838396, 0.6157566218013946], 
             UndirectedEdge[131, 133] -> 
             RGBColor[
              0.8487047833512873, 0.33253448013330367`, 0.19259565627124703`],
              UndirectedEdge[35, 188] -> 
             RGBColor[
              0.7515136501309705, 0.8059560761959215, 0.9758280725478667], 
             UndirectedEdge[181, 185] -> 
             RGBColor[
              0.8769516134578437, 0.9038519112831478, 0.9435125496118522], 
             UndirectedEdge[111, 188] -> 
             RGBColor[
              0.5625749036995356, 0.6554211455005088, 0.9589406102153506], 
             UndirectedEdge[41, 184] -> 
             RGBColor[
              0.46042354235664473`, 0.5706000836629397, 0.9512819487659052], 
             UndirectedEdge[135, 187] -> 
             RGBColor[
              0.2580530598737554, 0.38856050580927426`, 0.9380071120532948], 
             UndirectedEdge[51, 71] -> 
             RGBColor[
              0.2862116459129269, 0.41815696509391576`, 0.9396107018713307], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.2532145568819805, 0.3834749323861105, 0.937731566465837], 
             UndirectedEdge[26, 158] -> 
             RGBColor[
              0.3248339638099492, 0.45064699253772245`, 0.9421069303596279], 
             UndirectedEdge[101, 199] -> 
             RGBColor[
              0.262066422777004, 0.3927788046824936, 0.9382356671333965], 
             UndirectedEdge[84, 194] -> 
             RGBColor[
              0.30565287667395435`, 0.4349127039944547, 0.9408525291212098], 
             UndirectedEdge[6, 176] -> 
             RGBColor[
              0.31712437457249, 0.4477537666594349, 0.9414771155265509], 
             UndirectedEdge[18, 116] -> 
             RGBColor[
              0.35397661933935576`, 0.48101848911472117`, 0.9437760550684375],
              UndirectedEdge[98, 179] -> 
             RGBColor[
              0.8907110607570355, 0.9148157520026807, 0.9556261844734377], 
             UndirectedEdge[116, 142] -> 
             RGBColor[
              0.5152359143739065, 0.6156001916611427, 0.9554585640817019], 
             UndirectedEdge[77, 112] -> 
             RGBColor[
              0.3009216795649535, 0.4336181431321977, 0.9404484165262689], 
             UndirectedEdge[56, 190] -> 
             RGBColor[
              0.1793170310330229, 0.30580394734510286`, 0.9335232116903315], 
             UndirectedEdge[76, 126] -> 
             RGBColor[
              0.2917876480797086, 0.4240176969101601, 0.9399282469457728], 
             UndirectedEdge[168, 173] -> 
             RGBColor[
              0.9668668867879184, 0.9728695829823109, 0.8506912832058626], 
             UndirectedEdge[158, 164] -> 
             RGBColor[
              0.27399405489207074`, 0.4053155022909841, 0.9389149281369991], 
             UndirectedEdge[46, 146] -> 
             RGBColor[
              0.6969184905099, 0.7624738200168288, 0.9708932713664746], 
             UndirectedEdge[23, 25] -> 
             RGBColor[
              0.9862503262702172, 0.9646170985208886, 0.4575613230413248], 
             UndirectedEdge[9, 28] -> 
             RGBColor[
              0.27767181401552266`, 0.4091810603131285, 0.9391243710783226], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.9239792736477469, 0.9412455241190165, 0.9588251826995514], 
             UndirectedEdge[103, 129] -> 
             RGBColor[
              0.9062804022305841, 0.6440404985324568, 0.2778692029903933], 
             UndirectedEdge[5, 48] -> 
             RGBColor[
              0.2996548823827041, 0.431514025062696, 0.9404045642131346], 
             UndirectedEdge[36, 169] -> 
             RGBColor[
              0.260181316759984, 0.39079743873598083`, 0.9381283131344916], 
             UndirectedEdge[159, 170] -> 
             RGBColor[
              0.6092180955157596, 0.21970986582421148`, 0.4241107151102475], 
             UndirectedEdge[86, 175] -> 
             RGBColor[
              0.356178745028919, 0.4829258597049654, 0.9439163725701132], 
             UndirectedEdge[9, 97] -> 
             RGBColor[
              0.2707641427587703, 0.4019206598506281, 0.9387309894192344], 
             UndirectedEdge[7, 88] -> 
             RGBColor[
              0.5313273656076622, 0.6265318924404168, 0.9577502738522159], 
             UndirectedEdge[5, 77] -> 
             RGBColor[
              0.2913005664473497, 0.42350574323179174`, 0.9399005083673827], 
             UndirectedEdge[103, 131] -> 
             RGBColor[
              0.8759467260841297, 0.5295848811738163, 0.2181992462316507], 
             UndirectedEdge[15, 193] -> 
             RGBColor[
              0.32089862240878825`, 0.45236799072193, 0.941668354353746], 
             UndirectedEdge[167, 181] -> 
             RGBColor[
              0.9498028388938546, 0.9615340502113876, 0.9505692894275887], 
             UndirectedEdge[99, 146] -> 
             RGBColor[
              0.6800950161218604, 0.7488157656197341, 0.9695688658362309], 
             UndirectedEdge[163, 177] -> 
             RGBColor[
              0.2633144670135955, 0.39409057830572625`, 0.9383067414063544], 
             UndirectedEdge[76, 116] -> 
             RGBColor[
              0.3329665446591801, 0.4598254152907607, 0.9425469807473624], 
             UndirectedEdge[15, 59] -> 
             RGBColor[
              0.38695782791817696`, 0.5095851543019536, 0.9458775885149424], 
             UndirectedEdge[36, 151] -> 
             RGBColor[
              0.2998281417164218, 0.4284810612879339, 0.9405321505496939], 
             UndirectedEdge[38, 98] -> 
             RGBColor[
              0.9691483293293262, 0.9363502220297157, 0.6237743204922899], 
             UndirectedEdge[70, 139] -> 
             RGBColor[
              0.23141666930631707`, 0.36056397047819155`, 0.9364902090154877],
              UndirectedEdge[56, 195] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[66, 168] -> 
             RGBColor[
              0.8151061747990456, 0.8563704613486036, 0.9793645875552226], 
             UndirectedEdge[6, 161] -> 
             RGBColor[
              0.32435538961719373`, 0.45535402194425245`, 0.9418889111360187],
              UndirectedEdge[56, 118] -> 
             RGBColor[
              0.5461172634712221, 0.619552323592125, 0.9625471406553332], 
             UndirectedEdge[46, 117] -> 
             RGBColor[
              0.6883704009191991, 0.7557959874606861, 0.9700412776825125], 
             UndirectedEdge[79, 89] -> 
             RGBColor[
              0.637317539505268, 0.3879136396684716, 0.4445332384990521], 
             UndirectedEdge[102, 140] -> 
             RGBColor[
              0.3396692909282838, 0.4683264235730946, 0.9428753810499368], 
             UndirectedEdge[32, 130] -> 
             RGBColor[
              0.23618787859936186`, 0.36557881395732306`, 0.936761922326355], 
             UndirectedEdge[105, 126] -> 
             RGBColor[
              0.3252176564982815, 0.45596829309429976`, 0.9419487084621424], 
             UndirectedEdge[86, 124] -> 
             RGBColor[
              0.3415070368558193, 0.46858226157491756`, 0.94304139535942], 
             UndirectedEdge[41, 168] -> 
             RGBColor[
              0.7441532266042006, 0.7995222771759883, 0.9732629767804062], 
             UndirectedEdge[43, 143] -> 
             RGBColor[
              0.8438430647127526, 0.3380025843014858, 0.18961747432357834`], 
             UndirectedEdge[56, 197] -> 
             RGBColor[
              0.5339219968548683, 0.6098281490239381, 0.9613839452386224], 
             UndirectedEdge[47, 73] -> 
             RGBColor[
              0.3723282317178833, 0.495470365317321, 0.9449982523567235], 
             UndirectedEdge[23, 108] -> 
             RGBColor[
              0.8874058680057144, 0.9088494378884622, 0.7606689085618024], 
             UndirectedEdge[97, 155] -> 
             RGBColor[
              0.2652922598561954, 0.3961693639826077, 0.9384193737828581], 
             UndirectedEdge[86, 161] -> 
             RGBColor[
              0.35030928053797133`, 0.47783397777934283`, 0.943542670115366], 
             UndirectedEdge[88, 188] -> 
             RGBColor[
              0.688424300235651, 0.7565215626533395, 0.9695793586227837], 
             UndirectedEdge[136, 197] -> 
             RGBColor[
              0.8984618333218767, 0.7936232208649558, 0.6170525520201404], 
             UndirectedEdge[65, 69] -> 
             RGBColor[
              0.6618396215787897, 0.7314857264416685, 0.9696204831011173], 
             UndirectedEdge[23, 67] -> 
             RGBColor[
              0.8766635128599496, 0.4235199407908321, 0.29088079851236637`], 
             UndirectedEdge[31, 121] -> 
             RGBColor[
              0.6965919354102337, 0.7616218744062735, 0.9713719956909121], 
             UndirectedEdge[52, 145] -> 
             RGBColor[
              0.21010927874609994`, 0.3381685520328137, 0.9352767846445429], 
             UndirectedEdge[12, 87] -> 
             RGBColor[
              0.7859686037949694, 0.8312106955650405, 0.9046734035026598], 
             UndirectedEdge[128, 192] -> 
             RGBColor[
              0.8414065048905258, 0.286583757221212, 0.1860041493494229], 
             UndirectedEdge[78, 95] -> 
             RGBColor[
              0.9537951709684989, 0.944166482218568, 0.6841709176231596], 
             UndirectedEdge[123, 165] -> 
             RGBColor[
              0.23466718379435303`, 0.36398046729963934`, 0.9366753210068761],
              UndirectedEdge[24, 56] -> 
             RGBColor[
              0.1789270014196926, 0.30539400149218693`, 0.9335010000808495], 
             UndirectedEdge[50, 177] -> 
             RGBColor[
              0.2679195346173776, 0.39893079633545114`, 0.9385689931938027], 
             UndirectedEdge[18, 58] -> 
             RGBColor[
              0.2912619493997384, 0.4225753074857117, 0.9399308908333093], 
             UndirectedEdge[96, 182] -> 
             RGBColor[
              0.2856601600419676, 0.4175773184773137, 0.9395792955668297], 
             UndirectedEdge[49, 131] -> 
             RGBColor[
              0.8562446232823608, 0.3904889938224607, 0.19981581550427432`], 
             UndirectedEdge[28, 106] -> 
             RGBColor[
              0.28491435627629447`, 0.41679343143290143`, 0.9395368231456924],
              UndirectedEdge[57, 81] -> 
             RGBColor[
              0.4684558639722499, 0.5768344890925647, 0.951993469629622], 
             UndirectedEdge[7, 115] -> 
             RGBColor[
              0.3080070225358357, 0.4372085318811994, 0.9409931310547537], 
             UndirectedEdge[54, 94] -> 
             RGBColor[
              0.3454669572962359, 0.47032499193673805`, 0.9433554929496641], 
             UndirectedEdge[138, 181] -> 
             RGBColor[
              0.9485527902505714, 0.8398398392439036, 0.5790165148890076], 
             UndirectedEdge[55, 182] -> 
             RGBColor[
              0.30875284137949693`, 0.43781473937303605`, 0.9410421106336347],
              UndirectedEdge[17, 77] -> 
             RGBColor[
              0.26961618509412616`, 0.4007140835603673, 0.9386656149284841], 
             UndirectedEdge[144, 149] -> 
             RGBColor[
              0.648866599779832, 0.4112160653555213, 0.44670623587921776`], 
             UndirectedEdge[68, 179] -> 
             RGBColor[
              0.8317792747849202, 0.8687996297404257, 0.9837911974570385], 
             UndirectedEdge[103, 143] -> 
             RGBColor[
              0.8497933193438173, 0.37139574051451657`, 0.1948321197121974], 
             UndirectedEdge[80, 173] -> 
             RGBColor[
              0.807519241461194, 0.8471578477354111, 0.8378854904784999], 
             UndirectedEdge[161, 199] -> 
             RGBColor[
              0.2904737372287366, 0.422636693299029, 0.9398534216665669], 
             UndirectedEdge[43, 133] -> 
             RGBColor[
              0.8447195319166816, 0.3447394953012616, 0.19045678030788885`], 
             UndirectedEdge[6, 193] -> 
             RGBColor[
              0.3283691499935347, 0.4588385862362035, 0.9421443697655179], 
             UndirectedEdge[181, 188] -> 
             RGBColor[
              0.8244919498408892, 0.8628700233573725, 0.9382838606059434], 
             UndirectedEdge[120, 173] -> 
             RGBColor[
              0.9759551315276564, 0.9289248083741766, 0.49955341569398815`], 
             UndirectedEdge[2, 158] -> 
             RGBColor[
              0.31519292647680297`, 0.4422964105723771, 0.9414926119859944], 
             UndirectedEdge[95, 143] -> 
             RGBColor[
              0.8737408987697657, 0.4215594185967958, 0.23681679715422363`], 
             UndirectedEdge[4, 172] -> 
             RGBColor[
              0.8994312173900378, 0.9185136164944618, 0.783483838768104], 
             UndirectedEdge[89, 113] -> 
             RGBColor[
              0.8694288542290634, 0.4907346699510474, 0.21239820772463422`], 
             UndirectedEdge[34, 90] -> 
             RGBColor[
              0.31984837730012083`, 0.4461884593191548, 0.9417943891224722], 
             UndirectedEdge[28, 48] -> 
             RGBColor[
              0.30593974734452445`, 0.4381198166210231, 0.9407624779750857], 
             UndirectedEdge[5, 189] -> 
             RGBColor[
              0.2567992205359049, 0.38724264116718776`, 0.9379357077578933], 
             UndirectedEdge[8, 55] -> 
             RGBColor[
              0.4002897149094885, 0.5211325647337041, 0.9467270845651039], 
             UndirectedEdge[29, 138] -> 
             RGBColor[
              0.9532093472510355, 0.8417654452316519, 0.5018453146080967], 
             UndirectedEdge[8, 68] -> 
             RGBColor[
              0.6519110948314109, 0.7251718951051506, 0.9679355855003635], 
             UndirectedEdge[176, 187] -> 
             RGBColor[
              0.2885120341406341, 0.42057481897427373`, 0.9397417055777791], 
             UndirectedEdge[65, 133] -> 
             RGBColor[
              0.8563164442942707, 0.43429365345994053`, 0.44418899353026553`],
              UndirectedEdge[68, 147] -> 
             RGBColor[
              0.668160340209887, 0.7385028014791089, 0.9691763692944251], 
             UndirectedEdge[89, 192] -> 
             RGBColor[
              0.8417678220858125, 0.32205136009370555`, 0.18763021964036905`],
              UndirectedEdge[2, 74] -> 
             RGBColor[
              0.3399517025683613, 0.46831945404167635`, 0.9429025876570818], 
             UndirectedEdge[156, 185] -> 
             RGBColor[
              0.8452085345226001, 0.8798178098671724, 0.9849898137223804], 
             UndirectedEdge[126, 182] -> 
             RGBColor[
              0.2861743087287016, 0.41811772134598074`, 0.9396085755739244], 
             UndirectedEdge[18, 188] -> 
             RGBColor[
              0.49151222590235866`, 0.5940651201386887, 0.9543587093121076], 
             UndirectedEdge[68, 156] -> 
             RGBColor[
              0.8882342803358891, 0.9137179209353309, 0.9892017726661817], 
             UndirectedEdge[29, 181] -> 
             RGBColor[
              0.988986461566373, 0.9897136330697374, 0.8321863641764009], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.9759778030702638, 0.9313399748264705, 0.5237839339684474], 
             UndirectedEdge[30, 180] -> 
             RGBColor[
              0.8089076786179981, 0.8512402939181014, 0.9814298025533923], 
             UndirectedEdge[31, 196] -> 
             RGBColor[
              0.6728409042264264, 0.742339717319497, 0.969502227513229], 
             UndirectedEdge[193, 199] -> 
             RGBColor[
              0.2944874976050776, 0.4261212575909801, 0.9401088802960662], 
             UndirectedEdge[30, 110] -> 
             RGBColor[
              0.7493871054318795, 0.8041704915393881, 0.9758883443405271], 
             UndirectedEdge[12, 59] -> 
             RGBColor[
              0.516383766894903, 0.6181400893674647, 0.9551046267077723], 
             UndirectedEdge[38, 156] -> 
             RGBColor[
              0.9428260097167436, 0.9163360030821683, 0.6550496534880772], 
             UndirectedEdge[72, 152] -> 
             RGBColor[
              0.2658080334878341, 0.396711474771397, 0.9384487463281612], 
             UndirectedEdge[37, 79] -> 
             RGBColor[
              0.19748095052754017`, 0.3248953783928531, 0.9345576200344334], 
             UndirectedEdge[170, 197] -> 
             RGBColor[
              0.5356411787839332, 0.6116351182338152, 0.9614818501061808], 
             UndirectedEdge[86, 127] -> 
             RGBColor[
              0.3567736173469446, 0.48344110820768715`, 0.9439542773081928], 
             UndirectedEdge[69, 127] -> 
             RGBColor[
              0.3615866192833338, 0.48760988857647636`, 0.944260957535609], 
             UndirectedEdge[58, 61] -> 
             RGBColor[
              0.26897522612323943`, 0.4000403950428194, 0.9386291132633059], 
             UndirectedEdge[11, 17] -> 
             RGBColor[
              0.24235029233601593`, 0.3720559015141443, 0.9371128626721834], 
             UndirectedEdge[11, 15] -> 
             RGBColor[
              0.28548651926913327`, 0.4158817774158234, 0.9396248065535615], 
             UndirectedEdge[111, 157] -> 
             RGBColor[
              0.5090903091480017, 0.6123414730802424, 0.9544966004768307], 
             UndirectedEdge[75, 191] -> 
             RGBColor[
              0.2821961080105196, 0.4139363801586776, 0.9393820229282445], 
             UndirectedEdge[98, 156] -> 
             RGBColor[
              0.9471660663080045, 0.9597340431975859, 0.961036759682581], 
             UndirectedEdge[28, 140] -> 
             RGBColor[
              0.3001402263093852, 0.4327967862135973, 0.9404039139194207], 
             UndirectedEdge[105, 157] -> 
             RGBColor[
              0.4504475650892219, 0.5617429700786016, 0.9507060867688824], 
             UndirectedEdge[3, 15] -> 
             RGBColor[
              0.2943870608658776, 0.4252368109609329, 0.9401316792303248], 
             UndirectedEdge[55, 96] -> 
             RGBColor[
              0.32928937279498216`, 0.459399935982008, 0.942211635716671], 
             UndirectedEdge[6, 64] -> 
             RGBColor[
              0.4813272203866353, 0.5867267043563145, 0.9531607423711013], 
             UndirectedEdge[70, 134] -> 
             RGBColor[
              0.2222636314959646, 0.3509435474033953, 0.9359689570528942], 
             UndirectedEdge[106, 140] -> 
             RGBColor[
              0.29027778680107763`, 0.4224307369755848, 0.9398422625795944], 
             UndirectedEdge[64, 154] -> 
             RGBColor[
              0.8045650840099676, 0.8465963466235498, 0.9181848867101159], 
             UndirectedEdge[8, 157] -> 
             RGBColor[
              0.5029410908496337, 0.6072102236909507, 0.9540509278121335], 
             UndirectedEdge[83, 124] -> 
             RGBColor[
              0.2734514125634414, 0.4047451507980839, 0.9388840254591511], 
             UndirectedEdge[22, 128] -> 
             RGBColor[
              0.8594750767508397, 0.42546671823825916`, 0.20330663416839254`],
              UndirectedEdge[83, 135] -> 
             RGBColor[
              0.244563666934011, 0.3743822985526921, 0.9372389110811449], 
             UndirectedEdge[62, 68] -> 
             RGBColor[
              0.6059297438464823, 0.6853451599719039, 0.965005694475316], 
             UndirectedEdge[105, 116] -> 
             RGBColor[
              0.36639655307775293`, 0.49177601147490035`, 0.944567442263732], 
             UndirectedEdge[93, 145] -> 
             RGBColor[
              0.21595172710093502`, 0.34430933568636624`, 0.935609503435223], 
             UndirectedEdge[128, 195] -> 
             RGBColor[
              0.5342542573357888, 0.44844563583181796`, 0.5815387240241343], 
             UndirectedEdge[87, 154] -> 
             RGBColor[
              0.9872510560263222, 0.9889959982810382, 0.8609465250606165], 
             UndirectedEdge[138, 167] -> 
             RGBColor[
              0.914025724578517, 0.8135858623733021, 0.6202282398592844], 
             UndirectedEdge[179, 194] -> 
             RGBColor[
              0.5782314602978695, 0.6630917185740817, 0.9624599458147682], 
             UndirectedEdge[118, 144] -> 
             RGBColor[
              0.8754464394074596, 0.6015112264467356, 0.4650330881244851], 
             UndirectedEdge[47, 188] -> 
             RGBColor[
              0.5580878614872598, 0.6517295894935908, 0.9586008499410545], 
             UndirectedEdge[11, 20] -> 
             RGBColor[
              0.2356317618329697, 0.3649942999760054, 0.93673025229921], 
             UndirectedEdge[124, 187] -> 
             RGBColor[
              0.2869408055031858, 0.4189233580546661, 0.939652226431301], 
             UndirectedEdge[28, 189] -> 
             RGBColor[
              0.26308408549772533`, 0.39384843272551495`, 0.9382936215198444],
              UndirectedEdge[84, 93] -> 
             RGBColor[
              0.24346208091315458`, 0.3732244618001842, 0.9371761773869076], 
             UndirectedEdge[18, 94] -> 
             RGBColor[
              0.36824895343507874`, 0.4933804675600669, 0.9446854755764875], 
             UndirectedEdge[146, 156] -> 
             RGBColor[
              0.8584691386886809, 0.8901770946260392, 0.9863115068182637], 
             UndirectedEdge[2, 26] -> 
             RGBColor[
              0.3867618425079842, 0.5094154015901577, 0.945865100497908], 
             UndirectedEdge[124, 161] -> 
             RGBColor[
              0.29985672336199365`, 0.43249880664076373`, 0.9403877688459719],
              UndirectedEdge[25, 67] -> 
             RGBColor[
              0.8717776309273555, 0.4074814902998567, 0.23424954998350475`], 
             UndirectedEdge[15, 77] -> 
             RGBColor[
              0.31275241202724346`, 0.4445399594620464, 0.9411775588098623], 
             UndirectedEdge[23, 49] -> 
             RGBColor[
              0.8876847855307123, 0.5082342720907941, 0.3014347816686359], 
             UndirectedEdge[27, 37] -> 
             RGBColor[
              0.23387138917519362`, 0.3631440366986098, 0.9366300016805876], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.28199072307706635`, 0.41303118579725295`, 0.9393955660070041],
              UndirectedEdge[134, 139] -> 
             RGBColor[
              0.2400051701500614, 0.36959102940737165`, 0.9369793114329906], 
             UndirectedEdge[13, 127] -> 
             RGBColor[
              0.34979347533914956`, 0.4773952600326733, 0.9435095088317533], 
             UndirectedEdge[59, 186] -> 
             RGBColor[
              0.36541764511564734`, 0.4884580900498052, 0.9445955073983169], 
             UndirectedEdge[119, 149] -> 
             RGBColor[
              0.3992231896957711, 0.5102289495476822, 0.9477505828326117], 
             UndirectedEdge[41, 66] -> 
             RGBColor[
              0.6206670435279176, 0.7021698769586107, 0.9637962645099678], 
             UndirectedEdge[25, 103] -> 
             RGBColor[
              0.9025010063998871, 0.6312917089511744, 0.2631869638671507], 
             UndirectedEdge[164, 166] -> 
             RGBColor[
              0.3428237586125573, 0.4700619252820549, 0.9431128764626655], 
             UndirectedEdge[30, 90] -> 
             RGBColor[
              0.6408480095261183, 0.7142786377339077, 0.9678341664939911], 
             UndirectedEdge[75, 182] -> 
             RGBColor[
              0.27464253104525127`, 0.40599709184373967`, 0.9389518578945881],
              UndirectedEdge[92, 97] -> 
             RGBColor[
              0.2548383832137916, 0.38518167681737986`, 0.9378240409731977], 
             UndirectedEdge[18, 61] -> 
             RGBColor[
              0.2960837334123488, 0.42764330820172913`, 0.9402054842996372], 
             UndirectedEdge[76, 191] -> 
             RGBColor[
              0.2782905449427576, 0.40983138574745914`, 0.9391596068892982], 
             UndirectedEdge[129, 197] -> 
             RGBColor[
              0.939588342286577, 0.9465340447880747, 0.7029640290475025], 
             UndirectedEdge[97, 112] -> 
             RGBColor[
              0.2912053726836331, 0.4234056885504923, 0.9398950872233656], 
             UndirectedEdge[87, 131] -> 
             RGBColor[
              0.9436166175198961, 0.8123670652183208, 0.5433036400573084], 
             UndirectedEdge[33, 198] -> 
             RGBColor[
              0.5096004354679522, 0.6083940896440386, 0.956077633424264], 
             UndirectedEdge[39, 114] -> 
             RGBColor[
              0.20908858865686974`, 0.3370957420335433, 0.935218657853937], 
             UndirectedEdge[144, 170] -> 
             RGBColor[
              0.631799051712688, 0.39327699019190376`, 0.44573426426596857`], 
             UndirectedEdge[64, 110] -> 
             RGBColor[
              0.6138148271599528, 0.6973615545881173, 0.9627408981532811], 
             UndirectedEdge[108, 131] -> 
             RGBColor[
              0.8402456246331873, 0.7322315204859621, 0.6082404593152602], 
             UndirectedEdge[33, 141] -> 
             RGBColor[
              0.3411893210123498, 0.46994277401217005`, 0.9429612597264045], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.6032826317786147, 0.6888110439075521, 0.9619117651521593], 
             UndirectedEdge[88, 142] -> 
             RGBColor[
              0.6765418260566909, 0.7472163657056936, 0.968410420193581], 
             UndirectedEdge[12, 95] -> 
             RGBColor[
              0.7817942234386319, 0.8080307104936368, 0.6678706900642806], 
             UndirectedEdge[131, 162] -> 
             RGBColor[
              0.941079962602384, 0.8111036548737982, 0.5757395893878008], 
             UndirectedEdge[21, 194] -> 
             RGBColor[
              0.33236539581814195`, 0.4622999335123229, 0.9423990070157204], 
             UndirectedEdge[131, 154] -> 
             RGBColor[
              0.9428931009304802, 0.8120678725150692, 0.5552941823448407], 
             UndirectedEdge[81, 184] -> 
             RGBColor[
              0.47373340289000515`, 0.5814056280463057, 0.952329749742717], 
             UndirectedEdge[105, 111] -> 
             RGBColor[
              0.4018530682244218, 0.5222917683666206, 0.9468805499681779]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 71 -> 
             RGBColor[
              0.2902833275082297, 0.42243656061010276`, 0.93984257811467], 10 -> 
             RGBColor[
              0.28931600419628395`, 0.4214198424774074, 0.9397874904830813], 
             68 -> RGBColor[
              0.8556248139763563, 0.8877160176206234, 0.9860914526539951], 
             155 -> RGBColor[
              0.24962306644129345`, 0.3797000482193023, 0.9375270363983738], 
             132 -> RGBColor[
              0.2522143608002516, 0.3824236628881191, 0.93767460677864], 26 -> 
             RGBColor[
              0.39640287984113043`, 0.5177659835555031, 0.9464794188715415], 
             29 -> RGBColor[
              0.9936430185668372, 0.9916392390574856, 0.75501516389549], 113 -> 
             RGBColor[
              0.9003020964297527, 0.6401769295720257, 0.2385219642527955], 50 -> 
             RGBColor[
              0.2422322948146241, 0.37193187863768656`, 0.9371061428879017], 
             173 -> RGBColor[
              0.9951414157005084, 0.9920163043986404, 0.7125512665860644], 
             192 -> RGBColor[0.817319, 0.134127, 0.164218], 165 -> 
             RGBColor[
              0.21890292553398902`, 0.347411232356294, 0.9357775698200786], 
             92 -> RGBColor[
              0.22871531315648586`, 0.35772467388884666`, 0.9363363707790532],
              11 -> RGBColor[
              0.24586228151751777`, 0.37574722481687783`, 0.9373128652605475],
              137 -> RGBColor[
              0.2501870825879037, 0.38029286495007875`, 0.9375591562835361], 
             120 -> RGBColor[
              0.9567688473548046, 0.8658333123497126, 0.2865555648019119], 51 -> 
             RGBColor[
              0.28213996431762406`, 0.4138773695777287, 0.9393788256279912], 
             72 -> RGBColor[
              0.24987650973082426`, 0.37996643318583184`, 0.9375414696187768],
              64 -> RGBColor[
              0.6226026285830288, 0.704495887669313, 0.963432706072083], 41 -> 
             RGBColor[
              0.5497140953330726, 0.6453216927859953, 0.9576946537351515], 
             103 -> RGBColor[
              0.8642907579141675, 0.4766578520345487, 0.20847322067670976`], 
             162 -> RGBColor[
              0.9829012627807141, 0.9867683702952449, 0.9138278814340688], 
             196 -> RGBColor[
              0.49517344266125934`, 0.6010431339186144, 0.9534010137678327], 
             179 -> RGBColor[
              0.807933735593484, 0.8498832418602281, 0.9814909422600818], 160 -> 
             RGBColor[
              0.36671177852496323`, 0.4920490439135823, 0.9445875281504853], 
             123 -> RGBColor[
              0.250431442054717, 0.3805497022429847, 0.9375730721936737], 150 -> 
             RGBColor[
              0.2829267708206377, 0.41470435309880965`, 0.9394236330943619], 
             188 -> RGBColor[
              0.6646539951158695, 0.737952019632756, 0.9672101567545748], 46 -> 
             RGBColor[
              0.5977424503378598, 0.6843132750316175, 0.9614756217747897], 
             182 -> RGBColor[
              0.2651236286264823, 0.39599212186834176`, 0.9384097704837935], 
             6 -> RGBColor[
              0.3400518121902417, 0.46895752104331584`, 0.9428887786701194], 
             131 -> RGBColor[
              0.8992586624240541, 0.6354389394523516, 0.23765129734153262`], 
             45 -> RGBColor[
              0.8843599871114161, 0.5677875345316877, 0.22521947746071738`], 
             195 -> RGBColor[0.178927, 0.305394, 0.933501], 148 -> 
             RGBColor[
              0.20479309393410217`, 0.332580904729819, 0.9349740357840903], 
             161 -> 
             RGBColor[
              0.30865896704414575`, 0.441750522845189, 0.9408890436019178], 1 -> 
             RGBColor[
              0.9583125875736904, 0.8710407105954553, 0.2925527040414048], 
             101 -> RGBColor[
              0.2518443381406806, 0.38203474561211825`, 0.9376535345355769], 
             12 -> RGBColor[
              0.5839626349742006, 0.6731262001457912, 0.9603908242322355], 39 -> 
             RGBColor[
              0.20098973591686892`, 0.3285833343068806, 0.9347574401715728], 
             48 -> RGBColor[
              0.3171026989044469, 0.4490801525711323, 0.9414264814646527], 77 -> 
             RGBColor[
              0.3003940670337382, 0.43306358890932384`, 0.940418369773149], 
             56 -> RGBColor[0.178927, 0.305394, 0.933501], 110 -> 
             RGBColor[
              0.6050270257368769, 0.6902272215069217, 0.9620490902344793], 73 -> 
             RGBColor[
              0.2931347355771166, 0.42543357128021636`, 0.9400049615859128], 
             37 -> RGBColor[
              0.19099374879671333`, 0.31807691806140814`, 0.9341881834928177],
              130 -> RGBColor[
              0.23722409174651585`, 0.3666679396746901, 0.9368209331321454], 
             107 -> RGBColor[
              0.6672310374616252, 0.7399652246995075, 0.9674670122517698], 59 -> 
             RGBColor[
              0.44880489881560515`, 0.5631539785891382, 0.949818429183309], 
             47 -> RGBColor[
              0.4515217278586501, 0.5655071593544256, 0.9499915431275343], 
             159 -> RGBColor[
              0.8226444613445744, 0.17506082952644003`, 0.16931766779781277`],
              55 -> RGBColor[
              0.35238205413251156`, 0.47963735687773035`, 0.943674450783476], 
             49 -> RGBColor[
              0.8347376037115143, 0.26801402100751526`, 0.1808980745856452], 
             82 -> RGBColor[
              0.31859842780058983`, 0.45037567776345117`, 0.9415217879872938],
              199 -> RGBColor[
              0.27228850741332744`, 0.40352286375286894`, 0.938817799731216], 
             89 -> RGBColor[
              0.8539922331287186, 0.4160135401405583, 0.19933632946055357`], 
             144 -> RGBColor[
              0.8565158956399671, 0.43541151607797846`, 0.2017529915313943], 
             78 -> RGBColor[
              0.9279645300339343, 0.9453977435956535, 0.9929912793499938], 42 -> 
             RGBColor[
              0.5214414667269106, 0.6223686992161088, 0.9554689288452234], 
             154 -> RGBColor[
              0.9865275394369064, 0.9886968055777866, 0.8729370673481489], 
             168 -> RGBColor[
              0.9385923578753286, 0.9537228615659814, 0.988831299825661], 121 -> 
             RGBColor[
              0.5426755050288741, 0.6396074480921672, 0.9571405501231992], 
             128 -> RGBColor[
              0.8895815146715775, 0.5914972716636359, 0.22957644804826868`], 
             115 -> RGBColor[
              0.2655539192117794, 0.3964443845554878, 0.9384342748960682], 61 -> 
             RGBColor[
              0.2737970101358498, 0.4051083957588368, 0.9389037067296339], 93 -> 
             RGBColor[
              0.22414759348065547`, 0.35292371089939434`, 0.9360762459008504],
              88 -> RGBColor[
              0.7121946053554326, 0.7750911056739228, 0.9719485604909927], 21 -> 
             RGBColor[
              0.31620160663402885`, 0.4482996717367106, 0.9413690646619862], 
             62 -> RGBColor[
              0.3562346737166085, 0.4829743023231845, 0.943919936296637], 136 -> 
             RGBColor[
              0.9080066729340168, 0.6729841436820356, 0.24483821356303642`], 
             190 -> RGBColor[
              0.1797070620660458, 0.3062138946902057, 0.9335454233806629], 57 -> 
             RGBColor[
              0.3605779115447064, 0.4867361966324024, 0.9441966835704689], 
             111 -> RGBColor[
              0.4604958122832016, 0.5728902713682614, 0.9506710636761264], 63 -> 
             RGBColor[
              0.35285247495850214`, 0.48004481175316516`, 0.9437044255825313],
              75 -> RGBColor[
              0.28416143346402023`, 0.4160020618191376, 0.9394939453053829], 
             30 -> RGBColor[
              0.8937471851268821, 0.9181137615718546, 0.9897275984465748], 5 -> 
             RGBColor[
              0.2822070658609612, 0.41394789755425965`, 0.9393826469616164], 
             171 -> RGBColor[
              0.8744701613749067, 0.9027427860928997, 0.9878889387123091], 
             102 -> RGBColor[
              0.37383492502239923`, 0.4982187553899085, 0.9450414087465508], 
             31 -> RGBColor[
              0.8505083657915934, 0.8836363007203797, 0.9856034412586252], 96 -> 
             RGBColor[
              0.3061966914574528, 0.4391625150862857, 0.940748820649866], 70 -> 
             RGBColor[
              0.21367513065222027`, 0.34191648847421524`, 0.9354798546353913],
              52 -> RGBColor[
              0.21246269677098534`, 0.3406421435922893, 0.9354108083194902], 
             183 -> RGBColor[
              0.859910479347665, 0.45676803010411193`, 0.20481820887036734`], 
             158 -> RGBColor[
              0.25326504777876796`, 0.3835280015199418, 0.9377344418477144], 
             13 -> RGBColor[
              0.3779993100162068, 0.5018257363634689, 0.9453067596759351], 
             170 -> RGBColor[
              0.1823653638581298, 0.3090079384197544, 0.933696809735117], 86 -> 
             RGBColor[
              0.3919595940317969, 0.5139174327134967, 0.9461962966288141], 18 -> 
             RGBColor[
              0.3183704566888478, 0.45017822064462143`, 0.9415072618696405], 
             153 -> RGBColor[
              0.585970074369736, 0.674755929881201, 0.960548857214945], 58 -> 
             RGBColor[
              0.264153442110629, 0.394972394326802, 0.9383545197969779], 22 -> 
             RGBColor[
              0.8444218577904707, 0.34245144152557083`, 0.19017172722845446`],
              66 -> RGBColor[
              0.6916199917227627, 0.7590180611312259, 0.9698978752847841], 
             143 -> RGBColor[
              0.8207984422031169, 0.16087151747445233`, 0.16754991778317269`],
              119 -> RGBColor[
              0.5648783713319804, 0.6576327351847573, 0.9588884410903589], 
             145 -> RGBColor[
              0.20775586072121455`, 0.33569496047333813`, 0.9351427609695957],
              91 -> RGBColor[
              0.8378176201564483, 0.8735170446320284, 0.9843929866107827], 
             177 -> RGBColor[
              0.29360677442013106`, 0.4259297140332158, 0.9400318434997037], 
             200 -> RGBColor[
              0.23658832296539867`, 0.36599970637566703`, 0.9367847270405965],
              114 -> RGBColor[
              0.21718744139687057`, 0.3456081497602061, 0.935679875536301], 
             24 -> RGBColor[
              0.17892700283938517`, 0.30539400298437386`, 0.9335010001616988],
              176 -> RGBColor[
              0.29419693695473825`, 0.4265500122755539, 0.9400654523829823], 
             79 -> RGBColor[
              0.20396815225836698`, 0.3317138387242981, 0.934927056576049], 
             109 -> RGBColor[
              0.3375430035907792, 0.46678451713084806`, 0.942728919604614], 
             135 -> RGBColor[
              0.23327898842098083`, 0.3625213859455549, 0.9365962653340136], 
             108 -> RGBColor[
              0.7812325868423204, 0.8290241015195725, 0.9788296212889877], 
             191 -> RGBColor[
              0.28023078255701894`, 0.41187069849821767`, 0.939270100551106], 
             14 -> 
             RGBColor[
              0.4167727741971154, 0.535409362225998, 0.9477773705275145], 185 -> 
             RGBColor[
              0.7695733223497783, 0.8199157954843064, 0.9776675347663926], 32 -> 
             RGBColor[
              0.23515166545220784`, 0.36448968823995603`, 0.9367029115205646],
              122 -> RGBColor[
              0.9929383277496677, 0.9873041220381521, 0.47275873901987264`], 
             187 -> RGBColor[
              0.28282713132653, 0.41459962567299363`, 0.939417958772576], 193 -> 
             RGBColor[
              0.31668648779682773`, 0.44871965142909115`, 0.9413999608609163],
              100 -> RGBColor[
              0.21381427791123173`, 0.3420627410658821, 0.9354877788659421], 
             180 -> RGBColor[
              0.7240681721091139, 0.7843668262643483, 0.9731320066602097], 7 -> 
             RGBColor[
              0.350460125859892, 0.477972679206911, 0.9435519872134391], 175 -> 
             RGBColor[
              0.320397896026041, 0.45193428669643415`, 0.9416364485114123], 9 -> 
             RGBColor[
              0.2605668322464433, 0.39120263995534316`, 0.9381502676711264], 
             90 -> RGBColor[
              0.3879488339253545, 0.5104435138959607, 0.9459407345414075], 
             174 -> RGBColor[
              0.3814106085308894, 0.5047804316800383, 0.9455241246007979], 
             142 -> RGBColor[
              0.6408890467579492, 0.7193416257374643, 0.9648722798961695], 
             134 -> RGBColor[
              0.23085213233970892`, 0.3599706063325754, 0.9364580594703971], 
             105 -> RGBColor[
              0.34321032416564207`, 0.47169326536497985`, 0.9430900362602295],
              16 -> RGBColor[
              0.3229612837478847, 0.4541545643014821, 0.9417997853103334], 
             139 -> RGBColor[
              0.24915820796041388`, 0.3792114524821679, 0.9375005633955842], 
             146 -> RGBColor[
              0.79609453068194, 0.84063436500204, 0.9803109209581594], 126 -> 
             RGBColor[
              0.30722498883092086`, 0.4402433208236197, 0.9408073806640553], 
             198 -> RGBColor[
              0.6961608186542636, 0.7625653896416773, 0.9703504624768758], 40 -> 
             RGBColor[
              0.49158142165721236`, 0.5981269694488269, 0.9531182367163876], 
             104 -> RGBColor[
              0.21893481250696653`, 0.34744474758664423`, 0.9357793857360172],
              181 -> RGBColor[
              0.984329904565909, 0.9877880270819891, 0.9093575644573119], 127 -> 
             RGBColor[
              0.32158764066209233`, 0.4529647837018777, 0.9417122579875715], 
             76 -> RGBColor[
              0.27635030732849636`, 0.40779207299670056`, 0.9390491132274904],
              172 -> RGBColor[
              0.9939767127007667, 0.98952512245173, 0.5857805327779135], 84 -> 
             RGBColor[
              0.2627765683456537, 0.3935252127009741, 0.9382761088729649], 
             184 -> RGBColor[
              0.3711329893802169, 0.49587847453988415`, 0.9448692437966588], 
             151 -> RGBColor[
              0.3518764439127397, 0.4791994227180725, 0.9436422337473658], 35 -> 
             RGBColor[
              0.8383733051460716, 0.8739601327590868, 0.9844459883411588], 36 -> 
             RGBColor[
              0.24777983952010385`, 0.3777626998577953, 0.9374220673520219], 
             34 -> RGBColor[
              0.2517479206748871, 0.38193340474234894`, 0.9376480437035368], 
             38 -> RGBColor[
              0.9648082727380654, 0.8929521819142981, 0.31778721429778617`], 
             54 -> RGBColor[
              0.27280646441116213`, 0.40406726939796367`, 0.938847296615994], 
             60 -> RGBColor[
              0.253957266336059, 0.38425556711284614`, 0.9377738626705066], 
             87 -> RGBColor[
              0.9879745726157381, 0.9892951909842899, 0.8489559827730842], 
             141 -> RGBColor[
              0.3593385897430587, 0.4856627583779401, 0.9441177150811572], 67 -> 
             RGBColor[
              0.8182056947053702, 0.14094252405757224`, 0.16506709985124088`],
              133 -> RGBColor[
              0.8234278438149039, 0.18108225047377968`, 0.1700678357361042], 
             98 -> RGBColor[
              0.9734883859205871, 0.9797482621451334, 0.9297614266867937], 3 -> 
             RGBColor[
              0.26366336471100654`, 0.39445729190709694`, 0.938326610614074], 
             27 -> RGBColor[
              0.2767490295536739, 0.4082111553358114, 0.9390718198683575], 
             163 -> RGBColor[
              0.23302215960706, 0.36225144257823677`, 0.936581639313005], 85 -> 
             RGBColor[
              0.360155081261214, 0.48636996229290924`, 0.9441697411986989], 
             83 -> RGBColor[
              0.25584834544704116`, 0.3862432111598293, 0.9378815568282761], 
             28 -> RGBColor[
              0.29477679578460203`, 0.4271594806709139, 0.9400984744855188], 
             44 -> RGBColor[
              0.2834240796528994, 0.4152270562127178, 0.9394519540966568], 
             189 -> 
             RGBColor[
              0.2313913752108486, 0.36053738478011593`, 0.9364887685541701], 
             15 -> RGBColor[
              0.32511075702074876`, 0.45601633001476893`, 0.9419367478465757],
              80 -> RGBColor[
              0.6198970672218798, 0.7022993910721819, 0.9632197143709355], 
             112 -> RGBColor[
              0.30144929209616883`, 0.4341726973550716, 0.9404784632793888], 
             169 -> RGBColor[
              0.2725827939998642, 0.40383217761416634`, 0.9388345589169613], 
             69 -> RGBColor[
              0.4015855979045752, 0.522254993451075, 0.9468096570836465], 20 -> 
             RGBColor[
              0.22540124214842158`, 0.354241375135133, 0.9361476393378726], 8 -> 
             RGBColor[
              0.44819737568646545`, 0.5626277725896778, 0.9497797183467319], 
             116 -> RGBColor[
              0.3895827819898638, 0.5118587575848209, 0.9460448482672345], 97 -> 
             RGBColor[
              0.28096145327109734`, 0.41263867974591306`, 0.9393117111673424],
              118 -> RGBColor[
              0.9133075269424444, 0.9337106471842498, 0.9915932813106664], 
             178 -> RGBColor[
              0.9424318889382709, 0.9565863775460686, 0.9823319752461818], 81 -> 
             RGBColor[
              0.5763338163997934, 0.6669327815527272, 0.9597902556887751], 
             166 -> RGBColor[
              0.39092445521974123`, 0.5130208475020834, 0.9461303384990473], 
             125 -> RGBColor[
              0.17895982839241617`, 0.30542850472186966`, 0.9335028695283829],
              95 -> RGBColor[
              0.9796258119030633, 0.9429352208414826, 0.3753505558963255], 
             157 -> RGBColor[
              0.5576848060128018, 0.6517926747922235, 0.9583221372775351], 74 -> 
             RGBColor[
              0.30278259996188467`, 0.4355740884585403, 0.9405543931898891], 
             19 -> RGBColor[
              0.26440158051900675`, 0.3952332035268908, 0.9383686509122472], 
             156 -> RGBColor[
              0.9208437466954219, 0.9397198242500384, 0.9923120926783682], 
             167 -> RGBColor[
              0.9152757732218003, 0.9352800733407862, 0.9917810143978655], 33 -> 
             RGBColor[0.3230400522816408, 0.4542227896464, 0.941804804371652],
              43 -> RGBColor[
              0.8553653759675705, 0.4265681177150025, 0.20065125259378117`], 
             140 -> RGBColor[
              0.30550365683416836`, 0.4384340917562807, 0.9407093533533227], 
             186 -> 
             RGBColor[
              0.28203039141568953`, 0.41376220151047227`, 0.9393725856133247],
              117 -> RGBColor[
              0.7789983515005383, 0.8272786998897548, 0.9786069335902352], 4 -> 
             RGBColor[
              0.8048857220793089, 0.8475021105371937, 0.9811871447582946], 
             106 -> RGBColor[
              0.27505191676798696`, 0.40642738219488894`, 0.9389751718058661],
              65 -> RGBColor[
              0.9220936452530043, 0.9407164594322621, 0.992431309118588], 53 -> 
             RGBColor[
              0.21141226994966317`, 0.3395380784021726, 0.9353509880659832], 
             2 -> RGBColor[
              0.377120805174838, 0.5010648196248124, 0.9452507821242745], 147 -> 
             RGBColor[
              0.4806958664434177, 0.5892895853375945, 0.9522612859348552], 94 -> 
             RGBColor[
              0.4181274501813097, 0.5365827144755124, 0.9478636892833344], 23 -> 
             RGBColor[
              0.9935791491691084, 0.9886747742573517, 0.5425081958346172], 
             194 -> RGBColor[
              0.348529185002255, 0.47630019528793527`, 0.9434289493694545], 
             129 -> RGBColor[
              0.9902596908634175, 0.9788057915282733, 0.4166611676177604], 99 -> 
             RGBColor[
              0.5640955015617808, 0.656997166237428, 0.9588268107143023], 25 -> 
             RGBColor[
              0.9789215033713261, 0.9405594227844256, 0.37261445024803247`], 
             138 -> RGBColor[
              0.9127756759352338, 0.6918916514058181, 0.2486754653207034], 
             124 -> RGBColor[
              0.2910544796798416, 0.42324709043633846`, 0.9398864940900259], 
             197 -> RGBColor[
              0.8889169937097365, 0.9142622980478761, 0.9892668904772446], 
             164 -> RGBColor[
              0.29472306200537346`, 0.42710300306202637`, 0.9400954144262837],
              152 -> RGBColor[
              0.281739557244844, 0.41345651635696223`, 0.9393560230375456], 
             17 -> RGBColor[
              0.2388383031545141, 0.3683645782114108, 0.9369128600838192], 
             149 -> RGBColor[
              0.2335680080595618, 0.362825163910607, 0.9366127245748646]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9lnk01I33xy0ZCmPGjGUM5jOLCfGgkIjPm8rSZv1l6yGUlK0nopQSkiYJ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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.9759778030702638, 0.9313399748264705, 0.5237839339684474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 78}], {
             RGBColor[
             0.9431385588038124, 0.9082192270955545, 0.6427719916956993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 88}], {
             RGBColor[
             0.8352535964645615, 0.823065908134689, 0.6322506322661987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 89}], {
             RGBColor[
             0.8887656846103759, 0.567689263625524, 0.23040845432083734`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[
             0.9293073420017215, 0.7556088200837405, 0.2655373341471002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 122}], {
             RGBColor[
             0.9756254576616791, 0.9291724163168037, 0.38265572153063876`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 136}], {
             RGBColor[
             0.9331596302538536, 0.7720124271387454, 0.2686954588022206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 138}], {
             RGBColor[
             0.9355441317544622, 0.7814661810006367, 0.2706140846810541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 144}], {
             RGBColor[
             0.8904481262845415, 0.5806212475838041, 0.23201956236806448`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 159}], {
             RGBColor[
             0.867867170087613, 0.40705412321611184`, 0.21039601321234347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 167}], {
             RGBColor[
             0.9367941803977453, 0.9031603919681208, 0.6421668592196352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 197}], {
             RGBColor[
             0.9236147906417135, 0.8926515043216656, 0.6409097972593247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 26}], {
             RGBColor[
             0.3867618425079842, 0.5094154015901577, 0.945865100497908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 40}], {
             RGBColor[
             0.43435111341602517`, 0.5495958945368197, 0.9491845094203311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 51}], {
             RGBColor[
             0.329630384746231, 0.45747109460127056`, 0.9423148038761329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 74}], {
             RGBColor[
             0.3399517025683613, 0.46831945404167635`, 0.9429025876570818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 80}], {
             RGBColor[
             0.4985089361983589, 0.6016821053484971, 0.954235248247605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 121}], {
             RGBColor[
             0.45989815510185605`, 0.5703361338584898, 0.9511956661237368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 158}], {
             RGBColor[
             0.31519292647680297`, 0.4422964105723771, 0.9414926119859944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 164}], {
             RGBColor[
             0.3359219335901057, 0.4640839113434194, 0.9426730982752791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 166}], {
             RGBColor[
             0.3840226301972896, 0.5070428335634479, 0.9456905603116609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 169}], {
             RGBColor[
             0.3248517995873511, 0.4524484986194894, 0.942042670520618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 184}], {
             RGBColor[
             0.37412689727752746`, 0.49847164708234826`, 0.9450600129604667]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 5}], {
             RGBColor[
             0.27293521528598386`, 0.4042025947306783, 0.9388546287878452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 10}], {
             RGBColor[
             0.27648968445364525`, 0.4079385671922522, 0.9390570505485776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 11}], {
             RGBColor[
             0.2547628231142621, 0.3851022583619874, 0.9378197379373108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 15}], {
             RGBColor[
             0.2943870608658776, 0.4252368109609329, 0.9401316792303248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 20}], {
             RGBColor[
             0.24453230342971405`, 0.374349333521115, 0.9372371249759732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 28}], {
             RGBColor[
             0.2792200802478043, 0.4108083862890054, 0.9392125425497964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 48}], {
             RGBColor[
             0.29038303180772673`, 0.42176872223911466`, 0.9398765460393633]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 63}], {
             RGBColor[
             0.30825791983475437`, 0.437251051830131, 0.9410155180983026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 77}], {
             RGBColor[
             0.2820287158723724, 0.41376044040821036`, 0.9393724901936115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 106}], {
             RGBColor[
             0.26935764073949675`, 0.40044233705099297`, 0.93865089120997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 186}], {
             RGBColor[
             0.27284687806334806`, 0.40410974670878463`, 0.9388495981136993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 189}], {
             RGBColor[
             0.24752736996092756`, 0.37749733834360644`, 0.937407689584122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 41}], {
             RGBColor[
             0.6772999087061907, 0.7464119016615944, 0.969440899246723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 66}], {
             RGBColor[
             0.7482528569010358, 0.8032600858342098, 0.9755425100215394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 80}], {
             RGBColor[
             0.7123913946505943, 0.7749007508046878, 0.972203429564615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 81}], {
             RGBColor[
             0.6906097692395512, 0.7572174460449604, 0.9704887002235348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 168}], {
             RGBColor[
             0.8717390399773187, 0.9006124860515876, 0.9850092222919777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 172}], {
             RGBColor[
             0.8994312173900378, 0.9185136164944618, 0.783483838768104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 173}], {
             RGBColor[
             0.9000135688899087, 0.9197592074679171, 0.8468692056721795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 184}], {
             RGBColor[
             0.5880093557297629, 0.671690292538539, 0.9630281942774768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 198}], {
             RGBColor[
             0.7505232703667862, 0.8050337500894356, 0.9757688036175852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 9}], {
             RGBColor[
             0.27138694905370225`, 0.40257526875480143`, 0.9387664573163714]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.2640346736892395, 0.39484756118556874`, 0.938347756111082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 15}], {
             RGBColor[
             0.303658911440855, 0.4349821137845143, 0.940659697404096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 17}], {
             RGBColor[
             0.26052268450773763`, 0.3911562378828352, 0.9381477535227178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 20}], {
             RGBColor[
             0.2538041540046914, 0.3840946363446963, 0.9377651431497445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 28}], {
             RGBColor[
             0.28849193082278163`, 0.4205536891125868, 0.9397405607235676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 48}], {
             RGBColor[
             0.2996548823827041, 0.431514025062696, 0.9404045642131346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 63}], {
             RGBColor[
             0.3175297704097317, 0.4469963546537124, 0.9415435362720739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[
             0.2913005664473497, 0.42350574323179174`, 0.9399005083673827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 102}], {
             RGBColor[
             0.32802099544168023`, 0.45608332647208405`, 0.9422120278540836]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 106}], {
             RGBColor[
             0.2786294913144741, 0.4101876398745743, 0.9391789093837413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 112}], {
             RGBColor[
             0.29182817897856506`, 0.4240602974546656, 0.9399305551205026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 140}], {
             RGBColor[
             0.2938553613475648, 0.42619099465527016`, 0.9400460001574695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 189}], {
             RGBColor[
             0.2567992205359049, 0.38724264116718776`, 0.9379357077578933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 12}], {
             RGBColor[
             0.4620072235822212, 0.5710418605945535, 0.9516398014511775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 13}], {
             RGBColor[
             0.35902556110322426`, 0.48539162870339236`, 0.9440977691730272]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 14}], {
             RGBColor[
             0.37841229319367853`, 0.5021834416346569, 0.945333074598817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 16}], {
             RGBColor[
             0.3315065479690632, 0.46155604267239897`, 0.9423442819902264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 59}], {
             RGBColor[
             0.39442835550292343`, 0.516055749816227, 0.9463536039267142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 64}], {
             RGBColor[
             0.4813272203866353, 0.5867267043563145, 0.9531607423711013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 83}], {
             RGBColor[
             0.29795007881864144`, 0.4276003661015726, 0.9403851677491978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 86}], {
             RGBColor[
             0.3660057031110193, 0.4914374768784062, 0.9445425376494667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 124}], {
             RGBColor[
             0.3155531459350417, 0.4461023057398271, 0.9413876363800726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 137}], {
             RGBColor[
             0.2951194473890727, 0.4246251929966973, 0.9402239674768278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 161}], {
             RGBColor[
             0.32435538961719373`, 0.45535402194425245`, 0.9418889111360187]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 175}], {
             RGBColor[
             0.3302248541081414, 0.460445903869875, 0.9422626135907659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 176}], {
             RGBColor[
             0.31712437457249, 0.4477537666594349, 0.9414771155265509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 186}], {
             RGBColor[
             0.3110411018029656, 0.4413598612768941, 0.941130682141722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 187}], {
             RGBColor[
             0.3114394717583858, 0.44177857335815474`, 0.9411533687213477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 193}], {
             RGBColor[
             0.3283691499935347, 0.4588385862362035, 0.9421443697655179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 199}], {
             RGBColor[
             0.3061701598017846, 0.4362401923980924, 0.9408532892006678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 18}], {
             RGBColor[
             0.33441529127436986`, 0.4640754499257662, 0.9425296245415398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 42}], {
             RGBColor[
             0.4359507962934013, 0.5501706892115099, 0.9495104580293312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 47}], {
             RGBColor[
             0.40099092685927107`, 0.5217399192806683, 0.9467717651704868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.31163329513552707`, 0.44101997430243733`, 0.9411996419147166]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 58}], {
             RGBColor[
             0.3073067839852605, 0.4364725367668565, 0.9409532535052085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.3121285679978709, 0.4415405374828739, 0.9412278469715365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 73}], {
             RGBColor[
             0.3217974307185043, 0.4517031252435637, 0.941778474399676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 88}], {
             RGBColor[
             0.5313273656076622, 0.6265318924404168, 0.9577502738522159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 94}], {
             RGBColor[
             0.3842937880206009, 0.5072776968412117, 0.9457078382483868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 97}], {
             RGBColor[
             0.3157107895654947, 0.44530567947641203`, 0.9414318491903908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 115}], {
             RGBColor[
             0.3080070225358357, 0.4372085318811994, 0.9409931310547537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 153}], {
             RGBColor[
             0.46821510011481404`, 0.5763643045440561, 0.9520504222141921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 160}], {
             RGBColor[
             0.3585859521924276, 0.48501086156024664`, 0.9440697576819622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 188}], {
             RGBColor[
             0.5075570604878807, 0.6079623494198335, 0.955381071984007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 55}], {
             RGBColor[
             0.4002897149094885, 0.5211325647337041, 0.9467270845651039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 62}], {
             RGBColor[
             0.40221602470153694`, 0.5228010374564311, 0.9468498273216844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 68}], {
             RGBColor[
             0.6519110948314109, 0.7251718951051506, 0.9679355855003635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 75}], {
             RGBColor[
             0.36617940457524284`, 0.4893149172044077, 0.9446368318260574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 96}], {
             RGBColor[
             0.3771970335719591, 0.5008951438379817, 0.9452642694982989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 99}], {
             RGBColor[
             0.5061464386241231, 0.6098124694135529, 0.9543032645305172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 107}], {
             RGBColor[
             0.5577142065740452, 0.6512964986445926, 0.9586233652992509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 147}], {
             RGBColor[
             0.4644466210649416, 0.5759586789636362, 0.9510205021407936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 156}], {
             RGBColor[
             0.6845205611909437, 0.7511737984198581, 0.97104590551255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 157}], {
             RGBColor[
             0.5029410908496337, 0.6072102236909507, 0.9540509278121335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 179}], {
             RGBColor[
             0.6280655556399748, 0.706255507224953, 0.9656353303034069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 185}], {
             RGBColor[
             0.6088853490181219, 0.6912717840369921, 0.9637236265565623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 194}], {
             RGBColor[
             0.3983632803443602, 0.5194639839388066, 0.9466043338580932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.2532145568819805, 0.3834749323861105, 0.937731566465837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 17}], {
             RGBColor[
             0.2497025677004787, 0.37978360908337694`, 0.9375315638774728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 20}], {
             RGBColor[
             0.24298403719743245`, 0.3727220075452381, 0.9371489535044994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 28}], {
             RGBColor[
             0.27767181401552266`, 0.4091810603131285, 0.9391243710783226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 63}], {
             RGBColor[
             0.3067096536024727, 0.43562372585425413`, 0.9409273466268289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 77}], {
             RGBColor[
             0.2804804496400908, 0.41213311443233347`, 0.9392843187221377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 97}], {
             RGBColor[
             0.2707641427587703, 0.4019206598506281, 0.9387309894192344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 102}], {
             RGBColor[
             0.31720087863442126`, 0.44471069767262583`, 0.9415958382088386]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.2678093745072151, 0.3988150110751161, 0.9385627197384963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 112}], {
             RGBColor[
             0.28100806217130603`, 0.41268766865520734`, 0.9393143654752576]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 140}], {
             RGBColor[
             0.2830352445403058, 0.4148183658558119, 0.9394298105122245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 189}], {
             RGBColor[
             0.24597910372864595`, 0.37587001236772954`, 0.9373195181126482]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 14}], {
             RGBColor[
             0.35304438919669967`, 0.4784146023517027, 0.943782430505298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.30721338060851633`, 0.43871808624608816`, 0.9408621191648285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 28}], {
             RGBColor[
             0.292046399990443, 0.42428966157416065`, 0.9399429824843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 48}], {
             RGBColor[
             0.30320935155036544`, 0.43524999752426985`, 0.940606985973867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 59}], {
             RGBColor[
             0.3690604515059446, 0.4922869105332728, 0.9448029598331952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 77}], {
             RGBColor[
             0.2948550356150111, 0.4272417156933656, 0.9401029301281152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 186}], {
             RGBColor[
             0.28567319780598677`, 0.4175910219939398, 0.939580038048203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 193}], {
             RGBColor[
             0.30300124599655587`, 0.4350697469532493, 0.9405937256719987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 15}], {
             RGBColor[
             0.28548651926913327`, 0.4158817774158234, 0.9396248065535615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 17}], {
             RGBColor[
             0.24235029233601593`, 0.3720559015141443, 0.9371128626721834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 20}], {
             RGBColor[
             0.2356317618329697, 0.3649942999760054, 0.93673025229921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 28}], {
             RGBColor[
             0.2703195386510599, 0.4014533527438959, 0.9387056698730332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 48}], {
             RGBColor[
             0.2814824902109824, 0.4124136886940051, 0.9393696733626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 63}], {
             RGBColor[
             0.29935737823800995`, 0.4278960182850215, 0.9405086454215394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 77}], {
             RGBColor[
             0.27312817427562797`, 0.40440540686310084`, 0.9388656175168482]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 106}], {
             RGBColor[
             0.2604570991427524, 0.3910873035058834, 0.9381440185332068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 112}], {
             RGBColor[
             0.2736557868068433, 0.4049599610859747, 0.9388956642699682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 140}], {
             RGBColor[
             0.27568296917584306`, 0.40709065828657925`, 0.9390111093069351]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 189}], {
             RGBColor[
             0.2386268283641832, 0.36814230479849686`, 0.9369008169073587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 13}], {
             RGBColor[
             0.4809809724952037, 0.58747596825463, 0.9528487919540853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 14}], {
             RGBColor[
             0.500367704585658, 0.6042677811858945, 0.954084097379875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.45346195936104267`, 0.5636403822236367, 0.9510953047712845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 23}], {
             RGBColor[
             0.7887708920716545, 0.8309004872015715, 0.7514495100334264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 25}], {
             RGBColor[
             0.7814420691727634, 0.8068428114651084, 0.666502637240134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 59}], {
             RGBColor[
             0.516383766894903, 0.6181400893674647, 0.9551046267077723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.6032826317786147, 0.6888110439075521, 0.9619117651521593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 86}], {
             RGBColor[
             0.4879611145029988, 0.5935218164296439, 0.9532935604305248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 87}], {
             RGBColor[
             0.7859686037949694, 0.8312106955650405, 0.9046734035026598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 95}], {
             RGBColor[
             0.7817942234386319, 0.8080307104936368, 0.6678706900642806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 108}], {
             RGBColor[
             0.6825976109082605, 0.7510751508326818, 0.9696102227606116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 154}], {
             RGBColor[
             0.7852450872055535, 0.8309115028617888, 0.9166639457901922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 161}], {
             RGBColor[
             0.4463108010091732, 0.5574383614954901, 0.9506399339170767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 175}], {
             RGBColor[
             0.4521802655001208, 0.5625302434211127, 0.9510136363718239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 193}], {
             RGBColor[
             0.4503245613855142, 0.5609229257874412, 0.950895392546576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 16}], {
             RGBColor[
             0.35048029688204574`, 0.4779901503324755, 0.9435532724931343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 64}], {
             RGBColor[
             0.5003009692996179, 0.6031608120163909, 0.9543697328740091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 69}], {
             RGBColor[
             0.38979245396039097`, 0.512040364907272, 0.9460582083797908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 82}], {
             RGBColor[
             0.34829886890839834`, 0.4761007070634601, 0.9434142738316145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 83}], {
             RGBColor[
             0.316923827731624, 0.4440344737616491, 0.9415941582521057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 86}], {
             RGBColor[
             0.38497945202400186`, 0.5078715845384828, 0.9457515281523746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 101}], {
             RGBColor[
             0.3149218240784437, 0.4419302409877936, 0.941480147105756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 108}], {
             RGBColor[
             0.5796159484292636, 0.6654249189415207, 0.9620681904824614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 110}], {
             RGBColor[
             0.49151316787654187`, 0.5960264789351953, 0.9536779249552072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 124}], {
             RGBColor[
             0.3345268948480242, 0.4625364133999037, 0.9425966268829805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 127}], {
             RGBColor[
             0.34979347533914956`, 0.4773952600326733, 0.9435095088317533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 137}], {
             RGBColor[
             0.31409319630205523`, 0.44105930065677384`, 0.9414329579797356]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 161}], {
             RGBColor[
             0.34332913853017627`, 0.471788129604329, 0.9430979016389265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 175}], {
             RGBColor[
             0.34919860302112393`, 0.4768800115299515, 0.9434716040936737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 176}], {
             RGBColor[
             0.3360981234854725, 0.4641878743195114, 0.9426861060294587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 187}], {
             RGBColor[
             0.33041322067136836`, 0.4582126810182313, 0.9423623592242556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 199}], {
             RGBColor[
             0.3251439087147671, 0.45267430005816894`, 0.9420622797035756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 15}], {
             RGBColor[
             0.3709417656089321, 0.49571284612038347`, 0.9448570591870451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 48}], {
             RGBColor[
             0.36693773655078116`, 0.49224475739856516`, 0.9446019259960836]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 59}], {
             RGBColor[
             0.43278883650636024`, 0.549281670407568, 0.9487978998554119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 186}], {
             RGBColor[
             0.34940158280640243`, 0.47458578186823513`, 0.9435749780704197]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 193}], {
             RGBColor[
             0.36672963099697153`, 0.49206450682754455`, 0.9445886656942154]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 28}], {
             RGBColor[
             0.3099437764026754, 0.4415879053428414, 0.9410176111660472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 48}], {
             RGBColor[
             0.32110672796259787`, 0.4525482412929506, 0.9416816146556142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 59}], {
             RGBColor[
             0.38695782791817696`, 0.5095851543019536, 0.9458775885149424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 63}], {
             RGBColor[
             0.33898161598962545`, 0.46803057088396705`, 0.9428205867145535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 77}], {
             RGBColor[
             0.31275241202724346`, 0.4445399594620464, 0.9411775588098623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 106}], {
             RGBColor[
             0.3000813368943679, 0.43122185610482894`, 0.9404559598262209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.3132800245584588, 0.44509451368492026`, 0.9412076055629822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 140}], {
             RGBColor[
             0.31530720692745856`, 0.4472252108855248, 0.9413230505999493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 193}], {
             RGBColor[
             0.32089862240878825`, 0.45236799072193, 0.941668354353746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 64}], {
             RGBColor[
             0.47278195616545676`, 0.5793252259853976, 0.9526162456912082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 83}], {
             RGBColor[
             0.2894048145974629, 0.4201988877306557, 0.9398406710693048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 86}], {
             RGBColor[
             0.3574604388898408, 0.48403599850748935`, 0.9439980409695737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 101}], {
             RGBColor[
             0.28740281094428266`, 0.4180946549568002, 0.9397266599229551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 124}], {
             RGBColor[
             0.3070078817138632, 0.43870082736891025`, 0.9408431397001796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 127}], {
             RGBColor[
             0.3222744622049885, 0.4535596740016799, 0.9417560216489524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 137}], {
             RGBColor[
             0.2865741831678942, 0.41722371462578045`, 0.9396794707969347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 161}], {
             RGBColor[
             0.3158101253960152, 0.4479525435733356, 0.9413444144561256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 175}], {
             RGBColor[
             0.3216795898869629, 0.4530444254989581, 0.9417181169108728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 176}], {
             RGBColor[
             0.30857911035131147`, 0.440352288288518, 0.9409326188466578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.3028942075372073, 0.43437709498723787`, 0.9406088720414547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 193}], {
             RGBColor[
             0.3198238857723562, 0.4514371078652866, 0.9415998730856248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 199}], {
             RGBColor[
             0.29762489558060606`, 0.42883871402717555`, 0.9403087925207747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 20}], {
             RGBColor[
             0.23211977265146783`, 0.3613029766732719, 0.9365302497108459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 28}], {
             RGBColor[
             0.2668075494695581, 0.39776202944116235`, 0.938505667284669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 77}], {
             RGBColor[
             0.26961618509412616`, 0.4007140835603673, 0.9386656149284841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 106}], {
             RGBColor[
             0.25694510996125053`, 0.38739598020314986`, 0.9379440159448427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 112}], {
             RGBColor[
             0.27014379762534146`, 0.4012686377832412, 0.938695661681604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 140}], {
             RGBColor[
             0.27217097999434126`, 0.4033993349838457, 0.9388111067185709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 189}], {
             RGBColor[
             0.23511483918268133`, 0.3644509814957634, 0.9367008143189947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 47}], {
             RGBColor[
             0.38494609227374893`, 0.5078426899995235, 0.9457494024985874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 54}], {
             RGBColor[
             0.295588460550005, 0.42712274502129255`, 0.9401772792428172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 58}], {
             RGBColor[
             0.2912619493997384, 0.4225753074857117, 0.9399308908333093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 61}], {
             RGBColor[
             0.2960837334123488, 0.42764330820172913`, 0.9402054842996372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 73}], {
             RGBColor[
             0.3057525961329822, 0.4378058959624189, 0.9407561117277767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 94}], {
             RGBColor[
             0.36824895343507874`, 0.4933804675600669, 0.9446854755764875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 115}], {
             RGBColor[
             0.2919621879503136, 0.4233113026000546, 0.9399707683828544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 116}], {
             RGBColor[
             0.35397661933935576`, 0.48101848911472117`, 0.9437760550684375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 153}], {
             RGBColor[
             0.4521702655292919, 0.5624670752629113, 0.9510280595422927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 160}], {
             RGBColor[
             0.34254111760690553`, 0.47111363227910186`, 0.9430473950100628]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 174}], {
             RGBColor[
             0.3498905326098686, 0.47747932616232985`, 0.9435156932352192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 188}], {
             RGBColor[
             0.49151222590235866`, 0.5940651201386887, 0.9543587093121076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 33}], {
             RGBColor[
             0.29372081640032377`, 0.4247279965866454, 0.9400867276419496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 34}], {
             RGBColor[
             0.25807475059694696`, 0.38858330413461983`, 0.938008347307892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 44}], {
             RGBColor[
             0.2739128300859531, 0.40523012986980433`, 0.9389103025044521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 50}], {
             RGBColor[
             0.2533169376668154, 0.3835825410822887, 0.9377373969000744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 60}], {
             RGBColor[
             0.25917942342753286`, 0.38974438531986844`, 0.9380712567913769]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 90}], {
             RGBColor[
             0.32617520722218063`, 0.45283835871142575`, 0.9421546927268274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 130}], {
             RGBColor[
             0.2508128361327613, 0.38095057160079043`, 0.9375947920221963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 141}], {
             RGBColor[
             0.31187008513103276`, 0.44044798095241544`, 0.9412431829967022]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 177}], {
             RGBColor[
             0.2790041774695689, 0.41058145878005325`, 0.9392002472059755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.2600890189665118, 0.39070042790302345`, 0.9381230569116956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 77}], {
             RGBColor[
             0.2628976545910799, 0.3936524820222284, 0.9382830045555108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 106}], {
             RGBColor[
             0.25022657945820426`, 0.38033437866501096`, 0.9375614055718693]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 189}], {
             RGBColor[
             0.2283963086796351, 0.35738937995762443`, 0.9363182039460214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.28199072307706635`, 0.41303118579725295`, 0.9393955660070041]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 46}], {
             RGBColor[
             0.4569720284859443, 0.5663064733841641, 0.9514223432183879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 85}], {
             RGBColor[
             0.3381783439476214, 0.46733481701480994`, 0.9427694029303426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 109}], {
             RGBColor[
             0.32687230511240406`, 0.45754209443377936`, 0.9420489921333002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 132}], {
             RGBColor[
             0.28420798371714023`, 0.41536166731241486`, 0.9395218357203131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 150}], {
             RGBColor[
             0.29956418872733326`, 0.4315020124177601, 0.9403963488781741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 151}], {
             RGBColor[
             0.33403902527338425`, 0.46374954722739153`, 0.9425056492046759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 194}], {
             RGBColor[
             0.33236539581814195`, 0.4622999335123229, 0.9423990070157204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 196}], {
             RGBColor[
             0.4056875246476441, 0.5246714028276624, 0.9473850392149095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 24}], {
             RGBColor[
             0.6225902394734423, 0.3300989620118385, 0.4379481515395359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 37}], {
             RGBColor[
             0.626612488125885, 0.33432660037084994`, 0.4381772126499089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 38}], {
             RGBColor[
             0.8845506627730023, 0.5259516883218133, 0.23271022291823168`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 79}], {
             RGBColor[
             0.6309372892797696, 0.33887224059181326`, 0.43842350367765265`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 89}], {
             RGBColor[
             0.84761198290322, 0.36697214106389997`, 0.19322659463915418`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 118}], {
             RGBColor[
             0.8673837475077953, 0.5395378434117971, 0.45731224525585845`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 119}], {
             RGBColor[
             0.7512406956376406, 0.44751187274529963`, 0.44641063184908925`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 122}], {
             RGBColor[
             0.8939273477768698, 0.5574023350297646, 0.28436739782559384`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 128}], {
             RGBColor[
             0.8594750767508397, 0.42546671823825916`, 0.20330663416839254`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 138}], {
             RGBColor[
             0.8672064638387251, 0.45893151148565325`, 0.20967297325920412`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 144}], {
             RGBColor[
             0.8484532037403029, 0.37343813304304, 0.19403214866276774`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 149}], {
             RGBColor[
             0.6408039078801677, 0.34924268232058286`, 0.43898539301059114`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 181}], {
             RGBColor[
             0.8910578733822835, 0.5575636367110436, 0.4299003396380736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 183}], {
             RGBColor[
             0.8495847316428689, 0.3805569710517512, 0.19505388777575874`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 190}], {
             RGBColor[
             0.6228502592156624, 0.3303722592471158, 0.4379629592791906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 192}], {
             RGBColor[
             0.8353875718603139, 0.2730099610170472, 0.18152048481896965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 25}], {
             RGBColor[
             0.9862503262702172, 0.9646170985208886, 0.4575613230413248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 43}], {
             RGBColor[
             0.9014366337014165, 0.6139370032291189, 0.31460356700739317`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 49}], {
             RGBColor[
             0.8876847855307123, 0.5082342720907941, 0.3014347816686359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 64}], {
             RGBColor[
             0.8080908888760686, 0.8465853309633324, 0.7529704509533501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 67}], {
             RGBColor[
             0.8766635128599496, 0.4235199407908321, 0.29088079851236637`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 87}], {
             RGBColor[
             0.9907768608924232, 0.9889849826208208, 0.6957320893038507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 95}], {
             RGBColor[
             0.9866024805360858, 0.9658049975494172, 0.45892937586547133`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 103}], {
             RGBColor[
             0.9073868883324812, 0.6473301594421497, 0.31981821239601227`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 108}], {
             RGBColor[
             0.8874058680057144, 0.9088494378884622, 0.7606689085618024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 129}], {
             RGBColor[
             0.9919194200162629, 0.9837402828928126, 0.4795846817261888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 131}], {
             RGBColor[
             0.9464189057965813, 0.8120568568548516, 0.39007974658807487`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 143}], {
             RGBColor[
             0.8783920111917808, 0.4368059364020854, 0.2925360104669875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 154}], {
             RGBColor[
             0.9900533443030074, 0.9886857899175692, 0.707722631591383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 162}], {
             RGBColor[
             0.9882402059749112, 0.9877215722762983, 0.728168038634343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.22783801619652955`, 0.3568025791600926, 0.9362864100150281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 37}], {
             RGBColor[
             0.18496037581804925`, 0.31173546052289103`, 0.9338445918272582]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 56}], {
             RGBColor[
             0.1789270014196926, 0.30539400149218693`, 0.9335010000808495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 79}], {
             RGBColor[
             0.1914475775488761, 0.318553920854336, 0.9342140283688739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 89}], {
             RGBColor[
             0.6289704896989408, 0.3791403610884968, 0.44405788636093535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 118}], {
             RGBColor[
             0.5461172648909147, 0.6195523250843118, 0.9625471407361825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 119}], {
             RGBColor[
             0.37190268708568275`, 0.48151336908456555`, 0.9461947206260288]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 125}], {
             RGBColor[
             0.17894341561590066`, 0.30541125385312173`, 0.9335019348450408]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 144}], {
             RGBColor[
             0.6306529313731064, 0.3920723450467769, 0.44566899440816243`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 149}], {
             RGBColor[
             0.20624750544947348`, 0.3341095834474904, 0.9350568623682817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 170}], {
             RGBColor[
             0.18064618334875748`, 0.3072009707020641, 0.9335989049484079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 190}], {
             RGBColor[
             0.1793170324527155, 0.3058039488372898, 0.9335232117711809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 195}], {
             RGBColor[
             0.1789270014196926, 0.30539400149218693`, 0.9335010000808495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 197}], {
             RGBColor[
             0.5339219982745609, 0.6098281505161249, 0.9613839453194717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[
             0.8965507517688224, 0.5978985527381435, 0.25797231847853164`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 49}], {
             RGBColor[
             0.8827989035981182, 0.49219582159981873`, 0.2448035331397743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 64}], {
             RGBColor[
             0.8007620659771775, 0.8225276552268693, 0.6680235781600576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 67}], {
             RGBColor[
             0.8717776309273555, 0.4074814902998567, 0.23424954998350475`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 87}], {
             RGBColor[
             0.9834480379935321, 0.9649273068843578, 0.6107852165105583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 95}], {
             RGBColor[
             0.9792736576371948, 0.9417473218129542, 0.37398250307217895`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 103}], {
             RGBColor[
             0.9025010063998871, 0.6312917089511744, 0.2631869638671507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 108}], {
             RGBColor[
             0.8800770451068233, 0.8847917621519991, 0.6757220357685101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 129}], {
             RGBColor[
             0.9845905971173718, 0.9596826071563495, 0.39463780893289646`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 131}], {
             RGBColor[
             0.93909008289769, 0.7879991811183886, 0.30513287379478254`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 143}], {
             RGBColor[
             0.8735061292591867, 0.42076748591111013`, 0.23590476193812596`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 154}], {
             RGBColor[
             0.9827245214041163, 0.9646281141811062, 0.6227757587980907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 162}], {
             RGBColor[
             0.9809113830760201, 0.9636638965398352, 0.6432211658410507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 40}], {
             RGBColor[
             0.4439921507491714, 0.557946476502165, 0.9497988277939646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 51}], {
             RGBColor[
             0.3392714220793772, 0.4658216765666159, 0.9429291222497664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 74}], {
             RGBColor[
             0.3495927399015075, 0.4766700360070217, 0.9435169060307154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 80}], {
             RGBColor[
             0.5081499735315052, 0.6100326873138424, 0.9548495666212384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 121}], {
             RGBColor[
             0.46953919243500225`, 0.5786867158238351, 0.9518099844973704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 158}], {
             RGBColor[
             0.3248339638099492, 0.45064699253772245`, 0.9421069303596279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 164}], {
             RGBColor[
             0.34556297092325194`, 0.47243449330876475`, 0.9432874166489127]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.3936636675304358, 0.5153934155287933, 0.9463048786852943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 169}], {
             RGBColor[
             0.3344928369204973, 0.4607990805848347, 0.9426569888942514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 184}], {
             RGBColor[
             0.38376793461067366`, 0.5068222290476936, 0.9456743313341002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 37}], {
             RGBColor[
             0.23387138917519362`, 0.3631440366986098, 0.9366300016805876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 56}], {
             RGBColor[
             0.22783801477683696`, 0.3568025776679057, 0.9362864099341788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 67}], {
             RGBColor[
             0.6377201396548048, 0.23003206781698532`, 0.42306867319027985`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 119}], {
             RGBColor[
             0.4208137004428272, 0.5329219452602844, 0.9489801304793581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 125}], {
             RGBColor[
             0.22785442897304503`, 0.35681983002884055`, 0.9362873446983702]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 128}], {
             RGBColor[
             0.5831652721126257, 0.49985421349972364`, 0.5843241339583132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 133}], {
             RGBColor[
             0.6412015723944939, 0.2567918854277903, 0.42640249711352196`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 190}], {
             RGBColor[
             0.22822804580985986`, 0.3572125250130086, 0.9363086216245102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 195}], {
             RGBColor[
             0.22783801477683696`, 0.3568025776679057, 0.9362864099341788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 48}], {
             RGBColor[
             0.30593974734452445`, 0.4381198166210231, 0.9407624779750857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 63}], {
             RGBColor[
             0.3238146353715521, 0.45360214621203954`, 0.941901450034025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 77}], {
             RGBColor[
             0.29758543140917015`, 0.4301115347901189, 0.9402584221293339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 106}], {
             RGBColor[
             0.28491435627629447`, 0.41679343143290143`, 0.9395368231456924]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 112}], {
             RGBColor[
             0.2981130439403854, 0.43066608901299275`, 0.9402884688824538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 140}], {
             RGBColor[
             0.3001402263093852, 0.4327967862135973, 0.9404039139194207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 189}], {
             RGBColor[
             0.26308408549772533`, 0.39384843272551495`, 0.9382936215198444]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 35}], {
             RGBColor[
             0.9160081618564544, 0.9327996859082862, 0.8697305761183244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 47}], {
             RGBColor[
             0.7225823732127437, 0.7785731992059557, 0.8525033535115121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 88}], {
             RGBColor[
             0.8529188119611348, 0.8833651723657042, 0.8634818621932413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 89}], {
             RGBColor[
             0.9005424949414248, 0.6078887731128675, 0.3845626076055324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 113}], {
             RGBColor[
             0.946972557498295, 0.8159080843147557, 0.4967685640741427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 122}], {
             RGBColor[
             0.9932906731582525, 0.9894716805478189, 0.6138869514576812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 136}], {
             RGBColor[
             0.950824845750427, 0.8323116913697606, 0.49992668872926316`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 138}], {
             RGBColor[
             0.9532093472510355, 0.8417654452316519, 0.5018453146080967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 142}], {
             RGBColor[
             0.8172660326623933, 0.855490432397475, 0.8599437218958297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 144}], {
             RGBColor[
             0.9022249366155904, 0.6208207570711475, 0.3861737156527596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 153}], {
             RGBColor[
             0.7898065464682866, 0.8331975844693433, 0.8577820105552174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 159}], {
             RGBColor[
             0.879643980418662, 0.4472536327034553, 0.36455016649703853`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 167}], {
             RGBColor[
             0.9544593958943188, 0.963459656199136, 0.8733980891466777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 181}], {
             RGBColor[
             0.988986461566373, 0.9897136330697374, 0.8321863641764009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 188}], {
             RGBColor[
             0.8291485068413533, 0.8647956293451209, 0.8611126603250323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 41}], {
             RGBColor[
             0.7217306402299773, 0.781717727178925, 0.9737111260908631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 65}], {
             RGBColor[
             0.9079204151899432, 0.9294151105020584, 0.9910794537825813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 66}], {
             RGBColor[
             0.7926835884248224, 0.8385659113515402, 0.9798127368656795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 90}], {
             RGBColor[
             0.6408480095261183, 0.7142786377339077, 0.9678341664939911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 110}], {
             RGBColor[
             0.7493871054318795, 0.8041704915393881, 0.9758883443405271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 162}], {
             RGBColor[
             0.9383242239537981, 0.9524410659335498, 0.9517777399403218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 180}], {
             RGBColor[
             0.8089076786179981, 0.8512402939181014, 0.9814298025533923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 198}], {
             RGBColor[
             0.7949540018905729, 0.840339575606766, 0.9800390304617252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 38}], {
             RGBColor[
             0.9076583192648293, 0.8882942413173389, 0.6516953277782057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[
             0.6710448937244029, 0.7408816350846033, 0.9693608389875064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 46}], {
             RGBColor[
             0.7241254080647266, 0.7839747878759986, 0.9735395315167075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 80}], {
             RGBColor[
             0.7352027165067365, 0.7929678458962808, 0.9744115778147804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 98}], {
             RGBColor[
             0.9119983758560902, 0.9316922814327566, 0.9576824339727095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 117}], {
             RGBColor[
             0.8147533586460658, 0.8554575003050673, 0.9821051874244302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 120}], {
             RGBColor[
             0.9036386065731989, 0.8747348065350462, 0.6360795030302686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 121}], {
             RGBColor[
             0.6965919354102337, 0.7616218744062735, 0.9713719956909121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 146}], {
             RGBColor[
             0.8233014482367667, 0.8621353328612098, 0.9829571811083924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 151}], {
             RGBColor[
             0.6011924048521665, 0.6814178617192261, 0.9646228375029955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 171}], {
             RGBColor[
             0.8624892635832501, 0.8931895434066397, 0.9867461899854671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 173}], {
             RGBColor[
             0.9228248907460509, 0.93782630255951, 0.8490773539223448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 178}], {
             RGBColor[
             0.8964701273649321, 0.9201113391332241, 0.9839677082524034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 196}], {
             RGBColor[
             0.6728409042264264, 0.742339717319497, 0.969502227513229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 53}], {
             RGBColor[
             0.2232819677009355, 0.3520138833210643, 0.9360269497932738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 82}], {
             RGBColor[
             0.27687504662639884`, 0.4074326830017036, 0.9391123497539292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 83}], {
             RGBColor[
             0.2455000054496245, 0.37536644969989263`, 0.9372922341744203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 100}], {
             RGBColor[
             0.22448297168171977`, 0.35327621465291903`, 0.9360953451932534]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 101}], {
             RGBColor[
             0.2434980017964442, 0.3732622169260371, 0.9371782230280707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 123}], {
             RGBColor[
             0.24279155375346242`, 0.3725196952414703, 0.9371379918571192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 127}], {
             RGBColor[
             0.2783696530571501, 0.40872723597091687`, 0.9392075847540681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 130}], {
             RGBColor[
             0.23618787859936186`, 0.36557881395732306`, 0.936761922326355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 135}], {
             RGBColor[
             0.23421532693659433`, 0.36350553709275546`, 0.9366495884272892]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 148}], {
             RGBColor[
             0.219972379693155, 0.3485352964848875, 0.9358384736523275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 163}], {
             RGBColor[
             0.23408691252963393`, 0.3633705654090964, 0.9366422754167848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 165}], {
             RGBColor[
             0.2270272954930984, 0.35595046029812505`, 0.9362402406703216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 176}], {
             RGBColor[
             0.264674301203473, 0.39551985025775493`, 0.9383841819517735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 187}], {
             RGBColor[
             0.2589893983893689, 0.38954465695647483`, 0.9380604351465702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 41}], {
             RGBColor[
             0.4363770738073567, 0.5497722412161976, 0.9497497290534018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 44}], {
             RGBColor[
             0.3032320659672701, 0.4347249229295589, 0.9406283792341544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 57}], {
             RGBColor[
             0.3418089819131736, 0.4704794931394012, 0.9430007439710605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 66}], {
             RGBColor[
             0.5073300220022017, 0.606620425388813, 0.955851339828218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 90}], {
             RGBColor[
             0.35549444310349765`, 0.4823331517711803, 0.9438727694565298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 141}], {
             RGBColor[
             0.3411893210123498, 0.46994277401217005`, 0.9429612597264045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 198}], {
             RGBColor[
             0.5096004354679522, 0.6083940896440386, 0.956077633424264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 44}], {
             RGBColor[
             0.2675860001638932, 0.3985802304775334, 0.9385499989000968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 50}], {
             RGBColor[
             0.2469901077447556, 0.3769326416900177, 0.9373770932957193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 60}], {
             RGBColor[
             0.25285259350547307`, 0.38309448592759754`, 0.9377109531870217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 90}], {
             RGBColor[
             0.31984837730012083`, 0.4461884593191548, 0.9417943891224722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 104}], {
             RGBColor[
             0.2353413665909268, 0.3646890761644966, 0.936713714719777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 130}], {
             RGBColor[
             0.2444860062107015, 0.3743006722085195, 0.9372344884178412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 163}], {
             RGBColor[
             0.24238504014097356`, 0.3720924236602928, 0.9371148415082708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 177}], {
             RGBColor[
             0.27267734754750905`, 0.40393155938778236`, 0.9388399436016203]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 47}], {
             RGBColor[
             0.6449475165023608, 0.7197336460567563, 0.9672187657343465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 68}], {
             RGBColor[
             0.8469990595612139, 0.880838075189855, 0.985268720497577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 88}], {
             RGBColor[
             0.775283955250752, 0.8245256192165048, 0.9781972744160757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.6282503776636906, 0.7052714236172997, 0.9661548388122466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 111}], {
             RGBColor[
             0.6494345587146366, 0.7234252020636741, 0.9675585260086426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 116}], {
             RGBColor[
             0.6139780435679677, 0.6929094451719539, 0.9652454183041966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 122}], {
             RGBColor[
             0.9156558164478696, 0.9306321273986194, 0.7286023636805157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 138}], {
             RGBColor[
             0.8755744905406526, 0.7829258920824524, 0.6165607268309311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 142}], {
             RGBColor[
             0.7396311759520104, 0.7966508792482756, 0.9746591341186641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 153}], {
             RGBColor[
             0.7121716897579038, 0.7743580313201439, 0.9724974227780518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 157}], {
             RGBColor[
             0.6980290555794366, 0.7628764037756551, 0.971384062809347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 160}], {
             RGBColor[
             0.6025425418355174, 0.6830045883363345, 0.9645167582458221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 167}], {
             RGBColor[
             0.876824539183936, 0.9046201030499366, 0.9881135013695121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 174}], {
             RGBColor[
             0.6098919568384804, 0.6893702822195625, 0.9649850564709783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 181}], {
             RGBColor[
             0.9113516048559902, 0.930874079920538, 0.9469017763992353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 185}], {
             RGBColor[
             0.8039733137479249, 0.8469379641216965, 0.9810567615537757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 188}], {
             RGBColor[
             0.7515136501309705, 0.8059560761959215, 0.9758280725478667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 132}], {
             RGBColor[
             0.24999710016017773`, 0.3800931813729572, 0.937548337065331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 151}], {
             RGBColor[
             0.2998281417164218, 0.4284810612879339, 0.9405321505496939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 169}], {
             RGBColor[
             0.260181316759984, 0.39079743873598083`, 0.9381283131344916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 200}], {
             RGBColor[
             0.24218408124275126`, 0.3718812031167312, 0.9371033971963092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 56}], {
             RGBColor[
             0.18496037439835666`, 0.3117354590307041, 0.9338445917464089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 79}], {
             RGBColor[
             0.19748095052754017`, 0.3248953783928531, 0.9345576200344334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 118}], {
             RGBColor[
             0.5521506378695789, 0.625893782622829, 0.962890732401742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 119}], {
             RGBColor[
             0.3779360600643469, 0.4878548266230827, 0.9465383122915882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 125}], {
             RGBColor[
             0.18497678859456473`, 0.3117527113916389, 0.9338455265106003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 128}], {
             RGBColor[
             0.5402876317341454, 0.454787094862522, 0.5818823157705433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 149}], {
             RGBColor[
             0.21228087842813756`, 0.34045104098600754`, 0.9354004540338412]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 170}], {
             RGBColor[
             0.18667955632742156`, 0.31354242824058126`, 0.9339424966139673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 190}], {
             RGBColor[
             0.18535040543137957`, 0.3121454063758069, 0.9338668034367403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 195}], {
             RGBColor[
             0.18496037439835666`, 0.3117354590307041, 0.9338445917464089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 46}], {
             RGBColor[
             0.7812753615379626, 0.7886327284729578, 0.6396314180362879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 98}], {
             RGBColor[
             0.9691483293293262, 0.9363502220297157, 0.6237743204922899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 117}], {
             RGBColor[
             0.8719033121193018, 0.8601154409020264, 0.6481970739440106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 120}], {
             RGBColor[
             0.960788560046435, 0.8793927471320053, 0.302171389549849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 128}], {
             RGBColor[
             0.9271948937048214, 0.742224726788967, 0.2736818311730274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 146}], {
             RGBColor[
             0.8804514017100027, 0.8667932734581691, 0.6490490676279728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 156}], {
             RGBColor[
             0.9428260097167436, 0.9163360030821683, 0.6550496534880772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 171}], {
             RGBColor[
             0.919639217056486, 0.8978474840035989, 0.6528380765050477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 178}], {
             RGBColor[
             0.9536200808381681, 0.9247692797301834, 0.650059594771984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 179}], {
             RGBColor[
             0.8863710041657746, 0.8714177118872631, 0.6496390782789341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 183}], {
             RGBColor[
             0.8948764104777984, 0.602162747374174, 0.2424745440128403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 192}], {
             RGBColor[
             0.8664820909126885, 0.38706872730476605`, 0.21540773809926206`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 114}], {
             RGBColor[
             0.20908858865686974`, 0.3370957420335433, 0.935218657853937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 46}], {
             RGBColor[
             0.5446619359975361, 0.6412201222402223, 0.9572969292455886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 74}], {
             RGBColor[
             0.3971820108095485, 0.5168505289536836, 0.9468363149531384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.555739244439546, 0.6502131802605045, 0.9581689755436615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 117}], {
             RGBColor[
             0.6352898865788753, 0.7127028346692909, 0.9658625851533114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 121}], {
             RGBColor[
             0.5171284633430432, 0.6188672087704971, 0.9551293934197934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 166}], {
             RGBColor[
             0.4412529384384768, 0.5555739084754552, 0.9496242876077174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 169}], {
             RGBColor[
             0.38208210782853824`, 0.5009795735314966, 0.9459763978166744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 171}], {
             RGBColor[
             0.6830257915160596, 0.7504348777708634, 0.9705035877143484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 173}], {
             RGBColor[
             0.7433614186788604, 0.7950716369237336, 0.832834751651226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 196}], {
             RGBColor[
             0.49337743215923585`, 0.5995850516837207, 0.9532596252421102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 57}], {
             RGBColor[
             0.4551460034388895, 0.5660289447091988, 0.9509456686528102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 66}], {
             RGBColor[
             0.6206670435279176, 0.7021698769586107, 0.9637962645099678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 81}], {
             RGBColor[
             0.563023955866433, 0.6561272371693612, 0.9587424547119633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 90}], {
             RGBColor[
             0.46883146462921355`, 0.577882603340978, 0.9518176941382794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 141}], {
             RGBColor[
             0.4545263425380657, 0.5654922255819677, 0.9509061844081543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 168}], {
             RGBColor[
             0.7441532266042006, 0.7995222771759883, 0.9732629767804062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 172}], {
             RGBColor[
             0.7718454040169196, 0.8174234076188627, 0.7717375932565325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 184}], {
             RGBColor[
             0.46042354235664473`, 0.5706000836629397, 0.9512819487659052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 198}], {
             RGBColor[
             0.6229374569936681, 0.7039435412138363, 0.9640225581060137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 88}], {
             RGBColor[
             0.6168180360411716, 0.6987299024450158, 0.9637087446681081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[
             0.401201459999004, 0.517503689481011, 0.9473903200062829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 102}], {
             RGBColor[
             0.4476381958746549, 0.5602937273030086, 0.9502551687958871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 153}], {
             RGBColor[
             0.5537057705483233, 0.648562314548655, 0.9580088930300842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 49}], {
             RGBColor[
             0.8484894518822184, 0.3737167521458401, 0.1940668599244025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 67}], {
             RGBColor[
             0.8429788155468371, 0.3313595864958591, 0.18878986834626774`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 87}], {
             RGBColor[
             0.8995684415169597, 0.6141438088047649, 0.4167528293202155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 95}], {
             RGBColor[
             0.8967855212794014, 0.5986904854238292, 0.25888435369462925`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 103}], {
             RGBColor[
             0.8583405032831029, 0.4432646958215179, 0.2032585752880907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 129}], {
             RGBColor[
             0.9003301475995195, 0.6106473423194261, 0.27265455760177426`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 131}], {
             RGBColor[
             0.869996471453065, 0.49619172496078556`, 0.21298460084303164`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 133}], {
             RGBColor[
             0.8447195319166816, 0.3447394953012616, 0.19045678030788885`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 143}], {
             RGBColor[
             0.8438430647127526, 0.3380025843014858, 0.18961747432357834`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 154}], {
             RGBColor[
             0.8990860971240158, 0.6139443470025971, 0.4247465241785704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 197}], {
             RGBColor[
             0.8665492485482925, 0.589132844492627, 0.463523131888269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 50}], {
             RGBColor[
             0.2628281872337618, 0.3935794674252022, 0.9382790484922793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 57}], {
             RGBColor[
             0.3220009955988029, 0.4509816264225601, 0.9418243188335629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 60}], {
             RGBColor[
             0.2686906729944792, 0.399741311662782, 0.9386129083835817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 90}], {
             RGBColor[
             0.33568645678912695`, 0.46283528505433924`, 0.9426963443190322]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 141}], {
             RGBColor[
             0.321381334697979, 0.45044490729532893`, 0.941784834588907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 177}], {
             RGBColor[
             0.2885154270365152, 0.4205783851229668, 0.9397418987981803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 120}], {
             RGBColor[
             0.9205644172331103, 0.7168104234407002, 0.25588752113131463`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 128}], {
             RGBColor[
             0.8869707508914968, 0.5796424030976618, 0.22739796275449303`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 168}], {
             RGBColor[
             0.9114761724933723, 0.7607551980488345, 0.6070253886431892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 172}], {
             RGBColor[
             0.9391683499060914, 0.7786563284917088, 0.4055000051193155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 173}], {
             RGBColor[
             0.9397507014059623, 0.7799019194651641, 0.46888537202339087`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 85}], {
             RGBColor[
             0.4789487657995369, 0.5853416186622634, 0.9528226814867443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 98}], {
             RGBColor[
             0.7856154181292234, 0.8320307685883754, 0.9456185242307917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 99}], {
             RGBColor[
             0.5809189759498203, 0.6706552206345228, 0.960151216244546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 109}], {
             RGBColor[
             0.4676427269643195, 0.5755488960812328, 0.9521022706897019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 117}], {
             RGBColor[
             0.6883704009191991, 0.7557959874606861, 0.9700412776825125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 121}], {
             RGBColor[
             0.570208977683367, 0.6619603615618923, 0.9593080859489944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 146}], {
             RGBColor[
             0.6969184905099, 0.7624738200168288, 0.9708932713664746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 151}], {
             RGBColor[
             0.4748094471252997, 0.581756348874845, 0.9525589277610778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 171}], {
             RGBColor[
             0.7361063058563833, 0.7935280305622586, 0.9746822802435494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 178}], {
             RGBColor[
             0.7700871696380653, 0.8204498262888431, 0.9719037985104857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 196}], {
             RGBColor[
             0.5464579464995596, 0.642678204475116, 0.9574383177713113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 54}], {
             RGBColor[
             0.3621640961349061, 0.48478721437619465`, 0.9444194198717641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 61}], {
             RGBColor[
             0.36265936899724993`, 0.48530777755663124`, 0.944447624928584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 73}], {
             RGBColor[
             0.3723282317178833, 0.495470365317321, 0.9449982523567235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 88}], {
             RGBColor[
             0.5818581666070413, 0.6702991325141743, 0.9609700518092634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 94}], {
             RGBColor[
             0.4348245890199799, 0.551044936914969, 0.9489276162054343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 105}], {
             RGBColor[
             0.3973660260121461, 0.5186002123597028, 0.9465407896938819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 111}], {
             RGBColor[
             0.45600877007092583`, 0.5691987153613436, 0.9503313034018304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 116}], {
             RGBColor[
             0.42055225492425696`, 0.5386829584696233, 0.9480181956973843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 126}], {
             RGBColor[
             0.37937335834478547`, 0.5028752400890226, 0.9453994618957948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 142}], {
             RGBColor[
             0.5462053873082997, 0.642424392545945, 0.9574319115118519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 153}], {
             RGBColor[
             0.518745901114193, 0.6201315446178133, 0.9552702001712396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 157}], {
             RGBColor[
             0.5046032669357259, 0.6086499170733246, 0.9541568402025347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 160}], {
             RGBColor[
             0.4091167531918066, 0.528778101634004, 0.9472895356390099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 167}], {
             RGBColor[
             0.6833987505402253, 0.7503936163476059, 0.9708862787627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 174}], {
             RGBColor[
             0.4164661681947697, 0.535143795517232, 0.9477578338641661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 188}], {
             RGBColor[
             0.5580878614872598, 0.6517295894935908, 0.9586008499410545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 59}], {
             RGBColor[
             0.382953798860026, 0.5061170655801353, 0.9456224553239809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.3349775869314745, 0.46456248216214874`, 0.942565453523592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 77}], {
             RGBColor[
             0.30874838296909257`, 0.4410718707402281, 0.9409224256189008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 106}], {
             RGBColor[
             0.29607730783621694`, 0.42775376738301063`, 0.9402008266352594]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 112}], {
             RGBColor[
             0.3092759955003079, 0.44162642496310195`, 0.9409524723720207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 140}], {
             RGBColor[
             0.3113031778693076, 0.4437571221637065, 0.9410679174089878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 193}], {
             RGBColor[
             0.3168945933506373, 0.44889990200011176`, 0.9414132211627845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 67}], {
             RGBColor[
             0.8292269673761329, 0.22565685535753427`, 0.17562108300751042`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.8858165933462555, 0.5084410776664401, 0.4035840439814582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 95}], {
             RGBColor[
             0.8830336731086973, 0.49298775428550434`, 0.24571556835587194`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 103}], {
             RGBColor[
             0.8445886551123987, 0.33756196468319305`, 0.19008978994933337`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 108}], {
             RGBColor[
             0.8169025980884497, 0.455017381178201, 0.44687525682009266`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[
             0.8865782994288154, 0.5049446111811012, 0.25948577226301694`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 131}], {
             RGBColor[
             0.8562446232823608, 0.3904889938224607, 0.19981581550427432`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 133}], {
             RGBColor[
             0.8309676837459775, 0.23903676416293673`, 0.17728799496913153`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 143}], {
             RGBColor[
             0.8300912165420485, 0.23229985316316096`, 0.17644868898482102`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 154}], {
             RGBColor[
             0.8853342489533117, 0.5082416158642724, 0.4115777388398131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 162}], {
             RGBColor[
             0.8841254900679142, 0.5075988041034252, 0.42520801020178634`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 53}], {
             RGBColor[
             0.22682228238214364`, 0.3557349785199296, 0.9362285654769424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 60}], {
             RGBColor[
             0.24809478057534154`, 0.3780937228752663, 0.9374400027792041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 82}], {
             RGBColor[
             0.28041536130760697`, 0.41115377820056886`, 0.9393139654375977]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 100}], {
             RGBColor[
             0.2280232863629279, 0.35699730985178435`, 0.9362969608769219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 104}], {
             RGBColor[
             0.2305835536607953, 0.3596883131121654, 0.9364427643119595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 123}], {
             RGBColor[
             0.24633186843467056`, 0.37624079044033565`, 0.9373396075407877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.23972819328057, 0.3692999091561883, 0.9369635380100236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 163}], {
             RGBColor[
             0.23762722721084206`, 0.36709166060796167`, 0.9368438911004533]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 177}], {
             RGBColor[
             0.2679195346173776, 0.39893079633545114`, 0.9385689931938027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 71}], {
             RGBColor[
             0.2862116459129269, 0.41815696509391576`, 0.9396107018713307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 74}], {
             RGBColor[
             0.29246128213975436`, 0.4247257290181345, 0.9399666094089402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 158}], {
             RGBColor[
             0.267702506048196, 0.39870268554883526`, 0.9385566337378528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 164}], {
             RGBColor[
             0.28843151316149873`, 0.42049018631987756`, 0.9397371200271375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 166}], {
             RGBColor[
             0.33653220976868264`, 0.46344910853990606`, 0.9427545820635193]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 184}], {
             RGBColor[
             0.3266364768489205, 0.4548779220588064, 0.942124034712325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 70}], {
             RGBColor[
             0.2130689137116028, 0.34127931603325223`, 0.9354453314774407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 134}], {
             RGBColor[
             0.22165741455534713`, 0.35030637496243233`, 0.9359344338949436]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 145}], {
             RGBColor[
             0.21010927874609994`, 0.3381685520328137, 0.9352767846445429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 100}], {
             RGBColor[
             0.21261327393044743`, 0.34080040973402737`, 0.9354193834659627]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 104}], {
             RGBColor[
             0.21517354122831484`, 0.34349141299440844`, 0.9355651869010002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 123}], {
             RGBColor[
             0.2309218560021901, 0.36004389032257866`, 0.9364620301298284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 130}], {
             RGBColor[
             0.22431818084808952`, 0.35310300903843134`, 0.9360859605990643]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 135}], {
             RGBColor[
             0.222345629185322, 0.35102973217386374`, 0.9359736266999984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 148}], {
             RGBColor[
             0.20810268194188267`, 0.3360594915659958, 0.9351625119250367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 163}], {
             RGBColor[
             0.2222172147783616, 0.3508947604902047, 0.935966313689494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 165}], {
             RGBColor[
             0.21515759774182608`, 0.3434746553792333, 0.935564278943031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 58}], {
             RGBColor[
             0.2684799532608956, 0.3995198318623828, 0.9386009082064859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 61}], {
             RGBColor[
             0.27330173727350593`, 0.40458783257840025`, 0.9388755016728139]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 73}], {
             RGBColor[
             0.28297059999413937`, 0.41475042033909004`, 0.9394261291009534]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 94}], {
             RGBColor[
             0.3454669572962359, 0.47032499193673805`, 0.9433554929496641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 105}], {
             RGBColor[
             0.3080083942884021, 0.4378802673814718, 0.9409686664381117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 115}], {
             RGBColor[
             0.2691801918114708, 0.40025582697672574`, 0.938640785756031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 116}], {
             RGBColor[
             0.33119462320051296`, 0.4579630134913923, 0.9424460724416142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 126}], {
             RGBColor[
             0.29001572662104147`, 0.4221552951107917, 0.9398273386400247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 160}], {
             RGBColor[
             0.3197591214680627, 0.448058156655773, 0.9417174123832397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 174}], {
             RGBColor[
             0.3271085364710258, 0.454423850539001, 0.942185710608396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 62}], {
             RGBColor[
             0.35430836392456, 0.4813058296004574, 0.9437971935400564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 68}], {
             RGBColor[
             0.6040034340544339, 0.6836766872491769, 0.9648829517187356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 72}], {
             RGBColor[
             0.3011292819316679, 0.4298018950317811, 0.9406079602011264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 75}], {
             RGBColor[
             0.3182717437982659, 0.44781970934843396`, 0.9415841980444295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 76}], {
             RGBColor[
             0.31436618073050393`, 0.4437147149372155, 0.9413617820054831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 96}], {
             RGBColor[
             0.32928937279498216`, 0.459399935982008, 0.942211635716671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 107}], {
             RGBColor[
             0.5098065457970684, 0.609801290788619, 0.955570731517623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 111}], {
             RGBColor[
             0.40643893320785657`, 0.5262638141229958, 0.9471727572298012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 139}], {
             RGBColor[
             0.3007701310464627, 0.42942440467994913`, 0.9405875070895301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 147}], {
             RGBColor[
             0.41653896028796467`, 0.5344634711076623, 0.9479678683591656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 157}], {
             RGBColor[
             0.4550334300726567, 0.5657150158349769, 0.9509982940305055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 182}], {
             RGBColor[
             0.30875284137949693`, 0.43781473937303605`, 0.9410421106336347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 185}], {
             RGBColor[
             0.5609776882411449, 0.6497765761810184, 0.9606709927749343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 191}], {
             RGBColor[
             0.31630641834476525`, 0.445754027687974, 0.9414722756672911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 79}], {
             RGBColor[
             0.1914475761291835, 0.31855391936214905`, 0.9342140282880245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 118}], {
             RGBColor[
             0.5461172634712221, 0.619552323592125, 0.9625471406553332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 119}], {
             RGBColor[
             0.37190268566599016`, 0.4815133675923786, 0.9461947205451795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 125}], {
             RGBColor[
             0.17894341419620807`, 0.3054112523609348, 0.9335019347641915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 129}], {
             RGBColor[
             0.5845933454317087, 0.6420998957641366, 0.6750810838088802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 149}], {
             RGBColor[
             0.2062475040297809, 0.3341095819553035, 0.9350568622874322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 170}], {
             RGBColor[
             0.1806461819290649, 0.30720096920987716`, 0.9335989048675586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 190}], {
             RGBColor[
             0.1793170310330229, 0.30580394734510286`, 0.9335232116903315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 195}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 197}], {
             RGBColor[
             0.5339219968548683, 0.6098281490239381, 0.9613839452386224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 66}], {
             RGBColor[
             0.5260989516337345, 0.6228771288818142, 0.9570472794276266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 71}], {
             RGBColor[
             0.32543061952646807`, 0.4545863786212526, 0.9420196308425695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 81}], {
             RGBColor[
             0.4684558639722499, 0.5768344890925647, 0.951993469629622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 90}], {
             RGBColor[
             0.37426337273503046`, 0.49858985526418154`, 0.9450687090559382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 141}], {
             RGBColor[
             0.35995825064388254`, 0.48619947750517123`, 0.9441571993258131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 198}], {
             RGBColor[
             0.528369365099485, 0.6246507931370399, 0.9572735730236723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 61}], {
             RGBColor[
             0.26897522612323943`, 0.4000403950428194, 0.9386291132633059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 73}], {
             RGBColor[
             0.2786440888438728, 0.4102029828035092, 0.9391797406914454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 92}], {
             RGBColor[
             0.24643437763355744`, 0.3763485341078243, 0.9373454452880156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 115}], {
             RGBColor[
             0.2648536806612042, 0.3957083894411449, 0.9383943973465231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 155}], {
             RGBColor[
             0.25688825427596124`, 0.3873362212730521, 0.9379407780976758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 154}], {
             RGBColor[
             0.7176662191262557, 0.7759253920834623, 0.911377748265729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 186}], {
             RGBColor[
             0.36541764511564734`, 0.4884580900498052, 0.9445955073983169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 193}], {
             RGBColor[
             0.38274569330621644`, 0.5059368150091147, 0.9456091950221126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.2862778470683244, 0.4173156224381487, 0.9396478253289002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 104}], {
             RGBColor[
             0.23644603942151277`, 0.3658501573497452, 0.9367766242032618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 123}], {
             RGBColor[
             0.252194354195388, 0.3824026346779154, 0.9376734674320901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 130}], {
             RGBColor[
             0.2455906790412874, 0.3754617533937681, 0.9372973979013259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 163}], {
             RGBColor[
             0.24348971297155947`, 0.37325350484554143`, 0.9371777509917558]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 177}], {
             RGBColor[
             0.273782020378095, 0.40509264057303096`, 0.9389028530851051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 73}], {
             RGBColor[
             0.28346587285648317`, 0.41527098351952657`, 0.9394543341577734]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 94}], {
             RGBColor[
             0.34596223015857974`, 0.47084555511717463`, 0.9433836980064841]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 105}], {
             RGBColor[
             0.30850366715074595`, 0.4384008305619083, 0.9409968714949317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 115}], {
             RGBColor[
             0.2696754646738146, 0.40077639015716227`, 0.938668990812851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 116}], {
             RGBColor[
             0.3316898960628568, 0.4584835766718288, 0.9424742774984342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 160}], {
             RGBColor[
             0.3202543943304065, 0.44857871983620956`, 0.9417456174400596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 174}], {
             RGBColor[
             0.3276038093333696, 0.4549444137194375, 0.9422139156652158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 68}], {
             RGBColor[
             0.6059297438464823, 0.6853451599719039, 0.965005694475316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 75}], {
             RGBColor[
             0.3201980535903144, 0.44948818207116104`, 0.9417069408010099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 76}], {
             RGBColor[
             0.3162924905225524, 0.44538318765994256`, 0.9414845247620637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 96}], {
             RGBColor[
             0.33121568258703066`, 0.4610684087047351, 0.9423343784732514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 105}], {
             RGBColor[
             0.3497224989411253, 0.4773337838440822, 0.9435049862784333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 107}], {
             RGBColor[
             0.5117328555891169, 0.611469763511346, 0.9556934742742034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 111}], {
             RGBColor[
             0.40836524299990506`, 0.527932286845723, 0.9472954999863816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 116}], {
             RGBColor[
             0.37290872785323614`, 0.4974165299540027, 0.9449823922819357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 126}], {
             RGBColor[
             0.33172983127376465`, 0.4616088115734021, 0.9423636584803461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 157}], {
             RGBColor[
             0.4569597398647052, 0.567383488557704, 0.951121036787086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 174}], {
             RGBColor[
             0.36882264112374896`, 0.4938773670016114, 0.9447220304487174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 182}], {
             RGBColor[
             0.31067915117154543`, 0.43948321209576313`, 0.9411648533902153]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 185}], {
             RGBColor[
             0.5629039980331934, 0.6514450489037454, 0.9607937355315148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 191}], {
             RGBColor[
             0.3182327281368137, 0.4474225004107011, 0.9415950184238715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 77}], {
             RGBColor[
             0.3266232709961202, 0.4565542003312445, 0.9420613976778401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 91}], {
             RGBColor[
             0.5953350475574752, 0.6767809281925967, 0.9640487060966569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 102}], {
             RGBColor[
             0.3633436999904507, 0.48913178357153686`, 0.9443729171645411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 106}], {
             RGBColor[
             0.3139521958632445, 0.44323609697402705`, 0.9413397986941987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 112}], {
             RGBColor[
             0.32715088352733546`, 0.45710875455411837`, 0.94209144443096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 140}], {
             RGBColor[
             0.32917806589633525`, 0.4592394517547229, 0.942206889467927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 69}], {
             RGBColor[
             0.512094113243802, 0.613375440560194, 0.9551211815778647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 82}], {
             RGBColor[
             0.4706005281918093, 0.5774357827163821, 0.9524772470296884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 86}], {
             RGBColor[
             0.5072811113074129, 0.6092066601914048, 0.9548145013504485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 87}], {
             RGBColor[
             0.8052886005993835, 0.8468955393268014, 0.9061943444225835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 108}], {
             RGBColor[
             0.7019176077126746, 0.7667599945944428, 0.9711311636805353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 110}], {
             RGBColor[
             0.6138148271599528, 0.6973615545881173, 0.9627408981532811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 127}], {
             RGBColor[
             0.4720951346225606, 0.5787303356855954, 0.9525724820298272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 154}], {
             RGBColor[
             0.8045650840099676, 0.8465963466235498, 0.9181848867101159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 161}], {
             RGBColor[
             0.4656307978135873, 0.573123205257251, 0.9521608748370004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 162}], {
             RGBColor[
             0.8027519456818715, 0.845632128982279, 0.9386302937530759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 175}], {
             RGBColor[
             0.4715002623045349, 0.5782150871828736, 0.9525345772917476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 176}], {
             RGBColor[
             0.45839978276888355`, 0.5655229499724335, 0.9517490792275327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 180}], {
             RGBColor[
             0.6733354003460714, 0.7444313569668306, 0.9682823563661463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 66}], {
             RGBColor[
             0.8068568184878835, 0.8498672602817441, 0.9811645922016861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 69}], {
             RGBColor[
             0.6618396215787897, 0.7314857264416685, 0.9696204831011173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 87}], {
             RGBColor[
             0.9550341089343712, 0.965005825208276, 0.9206936459458361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 90}], {
             RGBColor[
             0.6550212395891795, 0.7255799866641114, 0.9691860218299977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 110}], {
             RGBColor[
             0.7635603354949406, 0.815471840469592, 0.9772401996765336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 131}], {
             RGBColor[
             0.9106761538385292, 0.7880776994423069, 0.6150413032300603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 133}], {
             RGBColor[
             0.8563164442942707, 0.43429365345994053`, 0.44418899353026553`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 162}], {
             RGBColor[
             0.9524974540168591, 0.9637424148637534, 0.9531295952763283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 180}], {
             RGBColor[
             0.8230809086810591, 0.8625416428483053, 0.9827816578893989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 198}], {
             RGBColor[
             0.809127231953634, 0.8516409245369697, 0.9813908857977319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 81}], {
             RGBColor[
             0.633976904061278, 0.7129754213419766, 0.9648440654867796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 90}], {
             RGBColor[
             0.5397844128240585, 0.6347307875135932, 0.9579193049130958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 141}], {
             RGBColor[
             0.5254792907329107, 0.622340409754583, 0.9570077951829706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 168}], {
             RGBColor[
             0.8151061747990456, 0.8563704613486036, 0.9793645875552226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 172}], {
             RGBColor[
             0.8427983522117647, 0.874271591791478, 0.7778392040313489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 198}], {
             RGBColor[
             0.6938904051885131, 0.7607917253864516, 0.97012416888083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 87}], {
             RGBColor[
             0.8747953206754928, 0.4237267463664781, 0.39303006082518865`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 103}], {
             RGBColor[
             0.833567382441636, 0.252847633383231, 0.17953580679306383`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 129}], {
             RGBColor[
             0.8755570267580526, 0.42023027988113926`, 0.24893178910674738`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 131}], {
             RGBColor[
             0.8452233506115981, 0.3057746625224987, 0.18926183234800478`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 133}], {
             RGBColor[
             0.8199464110752147, 0.15432243286297473`, 0.166734011812862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 143}], {
             RGBColor[
             0.8190699438712857, 0.14758552186319893`, 0.16589470582855148`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 162}], {
             RGBColor[
             0.8731042173971515, 0.4228844728034631, 0.4146540270455168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 107}], {
             RGBColor[
             0.7614279257189907, 0.8138406211600655, 0.9767792324528825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 111}], {
             RGBColor[
             0.6580603131297789, 0.7303031444944423, 0.9683812581650608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 122}], {
             RGBColor[
             0.924281570863012, 0.9375100698293877, 0.7294250958369339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 138}], {
             RGBColor[
             0.8842002449557951, 0.7898038345132208, 0.6173834589873493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 142}], {
             RGBColor[
             0.7482569303671527, 0.8035288216790438, 0.9754818662750824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 147}], {
             RGBColor[
             0.668160340209887, 0.7385028014791089, 0.9691763692944251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 156}], {
             RGBColor[
             0.8882342803358891, 0.9137179209353309, 0.9892017726661817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 157}], {
             RGBColor[
             0.7066548099945791, 0.7697543462064234, 0.9722067949657651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 179}], {
             RGBColor[
             0.8317792747849202, 0.8687996297404257, 0.9837911974570385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 181}], {
             RGBColor[
             0.9199773592711327, 0.9377520223513063, 0.9477245085556535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 185}], {
             RGBColor[
             0.8125990681630673, 0.8538159065524649, 0.9818794937101938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 82}], {
             RGBColor[
             0.3600920128525825, 0.48631533560726303`, 0.9441657225354702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 86}], {
             RGBColor[
             0.39677259596818604`, 0.5180862130822859, 0.9465029768562303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 90}], {
             RGBColor[
             0.3947672159149649, 0.5163492536735178, 0.946375195812527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 110}], {
             RGBColor[
             0.503306311820726, 0.6062411074789984, 0.9544293736590629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 123}], {
             RGBColor[
             0.3260085199796461, 0.4514023478470298, 0.9421913646386602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 127}], {
             RGBColor[
             0.3615866192833338, 0.48760988857647636`, 0.944260957535609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 177}], {
             RGBColor[
             0.3475961861623531, 0.47409235374214537`, 0.9434207502916752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 180}], {
             RGBColor[
             0.5628268850068445, 0.6533109098577117, 0.9599708318719281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 72}], {
             RGBColor[
             0.23177582019152226`, 0.36094146083002354`, 0.936510662127084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 93}], {
             RGBColor[
             0.21891136206643785`, 0.34742009968680476`, 0.9357780502681208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 134}], {
             RGBColor[
             0.2222636314959646, 0.3509435474033953, 0.9359689570528942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 139}], {
             RGBColor[
             0.23141666930631707`, 0.36056397047819155`, 0.9364902090154877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.2107154956867174, 0.33880572447377666`, 0.9353113078024935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 81}], {
             RGBColor[
             0.43330857195401157`, 0.5446846710814149, 0.9498164169017225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 164}], {
             RGBColor[
             0.2925031947568016, 0.42476978183606456`, 0.9399689962704769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 184}], {
             RGBColor[
             0.3307081584442233, 0.45915751757499346`, 0.9423559109556644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 75}], {
             RGBColor[
             0.26701897159742227`, 0.39798424750248473`, 0.9385177074620799]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 84}], {
             RGBColor[
             0.256326539038239, 0.386745822943403, 0.9379087892458708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 93}], {
             RGBColor[
             0.23701205160573985`, 0.3664450720426131, 0.9368088577598136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 134}], {
             RGBColor[
             0.2403643210352666, 0.36996851975920364`, 0.9369997645445869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 139}], {
             RGBColor[
             0.24951735884561907`, 0.3795889428339999, 0.9375210165071806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 152}], {
             RGBColor[
             0.2658080334878341, 0.396711474771397, 0.9384487463281612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 191}], {
             RGBColor[
             0.2650536461439216, 0.3959185658420248, 0.9384057850849414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 94}], {
             RGBColor[
             0.35563109287921313`, 0.4810081428778644, 0.9439343254346236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 115}], {
             RGBColor[
             0.27934432739444803`, 0.41093897791785206`, 0.9392196182409905]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 153}], {
             RGBColor[
             0.4395524049734263, 0.5500947505807087, 0.9502769094004289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 160}], {
             RGBColor[
             0.3299232570510399, 0.45874130759689935`, 0.9422962448681991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 80}], {
             RGBColor[
             0.46133983359188224`, 0.5689367397653611, 0.9518870537804123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 158}], {
             RGBColor[
             0.2780238238703263, 0.40955104498924105`, 0.9391444175188017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 164}], {
             RGBColor[
             0.29875283098362904`, 0.4313385457602833, 0.9403249038080864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 166}], {
             RGBColor[
             0.34685352759081295`, 0.47429746798031186`, 0.9433423658444682]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 169}], {
             RGBColor[
             0.28768269698087445`, 0.4197031330363533, 0.9396944760534252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 184}], {
             RGBColor[
             0.3369577946710508, 0.46572628149921225`, 0.9427118184932739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 76}], {
             RGBColor[
             0.2802558703962583, 0.4118970674079191, 0.9392715292664366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 96}], {
             RGBColor[
             0.29517906246073655`, 0.4275822884527116, 0.9401213829776245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 134}], {
             RGBColor[
             0.2575067829018646, 0.3879863340758565, 0.93797600238789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 139}], {
             RGBColor[
             0.26665982071221705`, 0.39760675715065275`, 0.9384972543504835]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 182}], {
             RGBColor[
             0.27464253104525127`, 0.40599709184373967`, 0.9389518578945881]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 191}], {
             RGBColor[
             0.2821961080105196, 0.4139363801586776, 0.9393820229282445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.2912734993929746, 0.42347729404149315`, 0.9398989669386781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 105}], {
             RGBColor[
             0.3097803157470692, 0.4397426691808402, 0.94106957474386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 111}], {
             RGBColor[
             0.368423059805849, 0.49034117218248097`, 0.9448600884518084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 116}], {
             RGBColor[
             0.3329665446591801, 0.4598254152907607, 0.9425469807473624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 126}], {
             RGBColor[
             0.2917876480797086, 0.4240176969101601, 0.9399282469457728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 174}], {
             RGBColor[
             0.3288804579296929, 0.4562862523383694, 0.9422866189141441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.27073696797748936`, 0.4018920974325212, 0.938729441855642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 191}], {
             RGBColor[
             0.2782905449427576, 0.40983138574745914`, 0.9391596068892982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 102}], {
             RGBColor[
             0.33711449602806876`, 0.4656411721496162, 0.9427298892598499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 106}], {
             RGBColor[
             0.2877229919008626, 0.4197454855521064, 0.9396967707895075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 112}], {
             RGBColor[
             0.3009216795649535, 0.4336181431321977, 0.9404484165262689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 140}], {
             RGBColor[
             0.3029488619339533, 0.43574884033280226`, 0.9405638615632359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 189}], {
             RGBColor[
             0.2658927211222934, 0.3968004868447199, 0.9384535691636595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 91}], {
             RGBColor[
             0.8828910750951913, 0.909457394113841, 0.9886921329803882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 95}], {
             RGBColor[
             0.9537951709684989, 0.944166482218568, 0.6841709176231596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 113}], {
             RGBColor[
             0.9141333132318434, 0.7927873365838396, 0.6157566218013946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 136}], {
             RGBColor[
             0.9179856014839756, 0.8091909436388446, 0.6189147464565151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 89}], {
             RGBColor[
             0.637317539505268, 0.3879136396684716, 0.4445332384990521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 118}], {
             RGBColor[
             0.5586378396004057, 0.632712242954274, 0.9632601689433578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 119}], {
             RGBColor[
             0.3844232617951737, 0.4946732869545277, 0.9469077488332039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 125}], {
             RGBColor[
             0.19146399032539158`, 0.3185711717230839, 0.934214963052216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 128}], {
             RGBColor[
             0.5467748334649722, 0.46160555519396695`, 0.5822517523121589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 144}], {
             RGBColor[
             0.6389999811794337, 0.4008456236267517, 0.4461443465462792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 149}], {
             RGBColor[
             0.21876808015896437`, 0.34726950131745254`, 0.9357698905754568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 159}], {
             RGBColor[
             0.6164190249825052, 0.2272784992590594, 0.42452079739055826`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 170}], {
             RGBColor[
             0.1931667580582484, 0.32036088857202627`, 0.934311933155583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 190}], {
             RGBColor[
             0.19183760716220638`, 0.3189638667072519, 0.9342362399783559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 192}], {
             RGBColor[
             0.6128687174194557, 0.19998927957476603`, 0.421121018858683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 195}], {
             RGBColor[
             0.1914475761291835, 0.31855391936214905`, 0.9342140282880245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 197}], {
             RGBColor[
             0.5464425729840517, 0.6229880683860871, 0.9620969735266468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 81}], {
             RGBColor[
             0.5981154418108365, 0.6846160863124545, 0.9615049850298553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 117}], {
             RGBColor[
             0.699447709361209, 0.7647890454809683, 0.9709133239805854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 120}], {
             RGBColor[
             0.7883329572883422, 0.7840663517109472, 0.6248876395864237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 121}], {
             RGBColor[
             0.5812862861253769, 0.6709534195821745, 0.9601801322470673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 166}], {
             RGBColor[
             0.5054107612208105, 0.6076601192871327, 0.9546750264349914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 168}], {
             RGBColor[
             0.7792447125486042, 0.8280111263190817, 0.9760255070982982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 172}], {
             RGBColor[
             0.8069368899613232, 0.8459122567619559, 0.7745001235744244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 173}], {
             RGBColor[
             0.807519241461194, 0.8471578477354111, 0.8378854904784999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 184}], {
             RGBColor[
             0.4955150283010483, 0.599088932806033, 0.9540444790837972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 164}], {
             RGBColor[
             0.43552843920258344`, 0.5470178923073767, 0.9499428350575294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 166}], {
             RGBColor[
             0.4836291358097673, 0.5899768145274054, 0.9529602970939112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 168}], {
             RGBColor[
             0.7574630871375609, 0.8103278215593543, 0.974310777757218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 172}], {
             RGBColor[
             0.7851552645502801, 0.8282289520022286, 0.7727853942333442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 173}], {
             RGBColor[
             0.7857376160501509, 0.8294745429756838, 0.8361707611374197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 184}], {
             RGBColor[
             0.47373340289000515`, 0.5814056280463057, 0.952329749742717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 198}], {
             RGBColor[
             0.6362473175270285, 0.7147490855972023, 0.9650703590828255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 86}], {
             RGBColor[
             0.3552790109161934, 0.48214655523847394`, 0.943859042308054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 101}], {
             RGBColor[
             0.2852213829706352, 0.4162052116877847, 0.9395876612614353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 110}], {
             RGBColor[
             0.4618127267687334, 0.5703014496351865, 0.9517854391108865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 123}], {
             RGBColor[
             0.28451493492765345`, 0.4154626900032179, 0.9395474300904838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 127}], {
             RGBColor[
             0.32009303423134106`, 0.45167023073266444`, 0.9416170229874327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 130}], {
             RGBColor[
             0.27791125977355285`, 0.4085218087190706, 0.9391713605597196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 163}], {
             RGBColor[
             0.2758102937038249, 0.40631356017084397`, 0.9390517136501494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 176}], {
             RGBColor[
             0.30639768237766407`, 0.4384628450195025, 0.9407936201851381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 177}], {
             RGBColor[
             0.3061026011103605, 0.4381526958983335, 0.9407768157434988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 180}], {
             RGBColor[
             0.5213332999548519, 0.6173712520138998, 0.9573268973237518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 187}], {
             RGBColor[
             0.3007127795635599, 0.4324876517182224, 0.9404698733799348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 86}], {
             RGBColor[
             0.32390396973941904`, 0.450080321936663, 0.9420389267285452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 101}], {
             RGBColor[
             0.2538463417938609, 0.3841389783859738, 0.9377675456819266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 124}], {
             RGBColor[
             0.2734514125634414, 0.4047451507980839, 0.9388840254591511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 135}], {
             RGBColor[
             0.244563666934011, 0.3743822985526921, 0.9372389110811449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 137}], {
             RGBColor[
             0.2530177140174724, 0.383268038054954, 0.9377203565559061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 161}], {
             RGBColor[
             0.28225365624559345`, 0.41399686700250915`, 0.9393853002150969]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 165}], {
             RGBColor[
             0.2373756354905151, 0.36682722175806165`, 0.9368295633241774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 175}], {
             RGBColor[
             0.2881231207365411, 0.41908874892813175`, 0.9397590026698441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 176}], {
             RGBColor[
             0.2750226412008897, 0.4063966117176916, 0.9389735046056292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 187}], {
             RGBColor[
             0.26933773838678554`, 0.40042141841641143`, 0.938649757800426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 199}], {
             RGBColor[
             0.2640684264301843, 0.3948830374563491, 0.938349678279746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 93}], {
             RGBColor[
             0.24346208091315458`, 0.3732244618001842, 0.9371761773869076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 139}], {
             RGBColor[
             0.25596738815303377`, 0.386368332591571, 0.9378883361342745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 152}], {
             RGBColor[
             0.2722580627952489, 0.4034908645289682, 0.9388160659552552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 194}], {
             RGBColor[
             0.30565287667395435`, 0.4349127039944547, 0.9408525291212098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 99}], {
             RGBColor[
             0.4621252914114974, 0.5716835642651686, 0.9514982759565006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 109}], {
             RGBColor[
             0.34884904242599657`, 0.47657723971187865`, 0.9434493304016565]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 132}], {
             RGBColor[
             0.3061847210307328, 0.43439681259051416`, 0.9409221739886695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 146}], {
             RGBColor[
             0.578124805971577, 0.6635021636474746, 0.9622403310784291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 150}], {
             RGBColor[
             0.3215409260409259, 0.45053715769585945`, 0.9417966871465304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 151}], {
             RGBColor[
             0.35601576258697687`, 0.48278469250549083`, 0.9439059874730323]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 152}], {
             RGBColor[
             0.320947319253029, 0.44991323932493577`, 0.9417628821181223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 194}], {
             RGBColor[
             0.35434213313173446`, 0.48133507879042225`, 0.9437993452840767]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 196}], {
             RGBColor[
             0.42766426196123664`, 0.5437065481057618, 0.9487853774832657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 101}], {
             RGBColor[
             0.3219019660862388, 0.44797608916280746`, 0.9419249155821955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 108}], {
             RGBColor[
             0.5865960904370586, 0.6714707671165345, 0.9625129589589009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 110}], {
             RGBColor[
             0.49849330988433693`, 0.6020723271102092, 0.9541226934316467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 124}], {
             RGBColor[
             0.3415070368558193, 0.46858226157491756`, 0.94304139535942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 127}], {
             RGBColor[
             0.3567736173469446, 0.48344110820768715`, 0.9439542773081928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 161}], {
             RGBColor[
             0.35030928053797133`, 0.47783397777934283`, 0.943542670115366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 175}], {
             RGBColor[
             0.356178745028919, 0.4829258597049654, 0.9439163725701132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 176}], {
             RGBColor[
             0.3430782654932676, 0.4702337224945253, 0.9431308745058982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 180}], {
             RGBColor[
             0.5580138830704554, 0.6491421294889225, 0.9596641516445119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 187}], {
             RGBColor[
             0.3373933626791634, 0.4642585291932452, 0.9428071277006951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 199}], {
             RGBColor[
             0.3321240507225622, 0.4587201482331828, 0.9425070481800151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 95}], {
             RGBColor[
             0.9838001922594006, 0.9661152059128862, 0.6121532693347048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 103}], {
             RGBColor[
             0.9055186961480244, 0.6475369650177958, 0.42196747470883456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 108}], {
             RGBColor[
             0.8846035797290293, 0.9091596462519311, 0.913892802031036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 110}], {
             RGBColor[
             0.7965007991763076, 0.8397612062456058, 0.9055025365037817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 131}], {
             RGBColor[
             0.9436166175198961, 0.8123670652183208, 0.5433036400573084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 143}], {
             RGBColor[
             0.876523819007324, 0.43701274197773154`, 0.3946852727798099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[
             0.9872510560263222, 0.9889959982810382, 0.8609465250606165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 162}], {
             RGBColor[
             0.9854379176982261, 0.9880317806397674, 0.8813919321035765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 180}], {
             RGBColor[
             0.8560213723624259, 0.8868310086243191, 0.9110439947166469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 94}], {
             RGBColor[
             0.5651610277683712, 0.6558369100747177, 0.9599061248871635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 102}], {
             RGBColor[
             0.5430147651889159, 0.6366549305319157, 0.9584949846187718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[
             0.8062483508925926, 0.7076340176229743, 0.6052352623718941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 122}], {
             RGBColor[
             0.8525664665525501, 0.8811976138560375, 0.7223536497554326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 136}], {
             RGBColor[
             0.8101006391447247, 0.7240376246779792, 0.6083933870270145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 142}], {
             RGBColor[
             0.6765418260566909, 0.7472163657056936, 0.968410420193581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 153}], {
             RGBColor[
             0.6490823398625842, 0.7249235177775619, 0.9662487088529688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 167}], {
             RGBColor[
             0.8137351892886164, 0.8551855895073546, 0.9818647874444291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 188}], {
             RGBColor[
             0.688424300235651, 0.7565215626533395, 0.9695793586227837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 113}], {
             RGBColor[
             0.8694288542290634, 0.4907346699510474, 0.21239820772463422`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 118}], {
             RGBColor[
             0.8737639977332939, 0.5885792424884555, 0.4634219800772578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 122}], {
             RGBColor[
             0.9003075980023684, 0.6064437341064228, 0.29047713264699326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 136}], {
             RGBColor[
             0.8719970463971514, 0.5016704079877174, 0.2145036241613812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 138}], {
             RGBColor[
             0.8735867140642237, 0.5079729105623115, 0.2157827080806035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 144}], {
             RGBColor[
             0.8548334539658015, 0.42247953211969835`, 0.20014188348416714`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 149}], {
             RGBColor[
             0.6471841581056663, 0.3982840813972412, 0.44509512783199057`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 159}], {
             RGBColor[
             0.8435429758673372, 0.3356959699358522, 0.18933010890630664`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 170}], {
             RGBColor[
             0.6301166100385224, 0.38034500623362366`, 0.4441231562187414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 192}], {
             RGBColor[
             0.8417678220858125, 0.32205136009370555`, 0.18763021964036905`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 197}], {
             RGBColor[
             0.865633819989058, 0.5820964594429976, 0.4626465164661172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 141}], {
             RGBColor[
             0.37364371183420664`, 0.49805313613695035`, 0.9450292248112824]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 177}], {
             RGBColor[
             0.3407778041727428, 0.4681866139645882, 0.9429862890205556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 198}], {
             RGBColor[
             0.542054826289809, 0.636504451768819, 0.9581455985091416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 95}], {
             RGBColor[
             0.9087217160297558, 0.9082261327367556, 0.679871771253554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 136}], {
             RGBColor[
             0.8729121465452325, 0.773250594157032, 0.6146156000869095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 97}], {
             RGBColor[
             0.2548383832137916, 0.38518167681737986`, 0.9378240409731977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 155}], {
             RGBColor[
             0.23916918979888965`, 0.36871236105407446`, 0.9369317035887135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 134}], {
             RGBColor[
             0.2274998629101822, 0.35644715861598486`, 0.9362671526856237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 139}], {
             RGBColor[
             0.2366529007205347, 0.36606758169078113`, 0.9367884046482173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 145}], {
             RGBColor[
             0.21595172710093502`, 0.34430933568636624`, 0.935609503435223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 105}], {
             RGBColor[
             0.3806688871734759, 0.5041379899202462, 0.945476862771782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 111}], {
             RGBColor[
             0.43931163123225564`, 0.554736492921887, 0.9492673764797304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 115}], {
             RGBColor[
             0.34184068469654455`, 0.4665135495155001, 0.9431489820897013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 116}], {
             RGBColor[
             0.4038551160855868, 0.5242207360301667, 0.9469542687752844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 126}], {
             RGBColor[
             0.3626762195061153, 0.4884130176495661, 0.9443355349736948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 142}], {
             RGBColor[
             0.5295082484696294, 0.6279621701064884, 0.9563679845897519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 153}], {
             RGBColor[
             0.5020487622755229, 0.6056693221783567, 0.9542062732491396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 160}], {
             RGBColor[
             0.39241961435313644`, 0.5143158791945474, 0.9462256087169099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 167}], {
             RGBColor[
             0.666701611701555, 0.7359313939081493, 0.9698223518406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 174}], {
             RGBColor[
             0.39976902935609954`, 0.5206815730777754, 0.9466939069420661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 188}], {
             RGBColor[
             0.5413907226485897, 0.6372673670541342, 0.9575369230189545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 103}], {
             RGBColor[
             0.9027357759104662, 0.63208364163686, 0.26409899908324835`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 129}], {
             RGBColor[
             0.9849427513832404, 0.9608705061848779, 0.39600586175704294`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 131}], {
             RGBColor[
             0.9394422371635587, 0.7891870801469172, 0.306500926618929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 143}], {
             RGBColor[
             0.8737408987697657, 0.4215594185967958, 0.23681679715422363`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 154}], {
             RGBColor[
             0.9830766756699849, 0.9658160132096346, 0.6241438116222372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 105}], {
             RGBColor[
             0.32470350781154744`, 0.4554278902256328, 0.9419194284550477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 111}], {
             RGBColor[
             0.3833462518703272, 0.5060263932272735, 0.9457099421629962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 116}], {
             RGBColor[
             0.3478897367236583, 0.4755106363355533, 0.9433968344585502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 126}], {
             RGBColor[
             0.3067108401441868, 0.4397029179549527, 0.9407781006569607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.43194074873512733`, 0.5454775949392545, 0.9495354789637005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 174}], {
             RGBColor[
             0.3438036499941711, 0.471971473383162, 0.943136472625332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 182}], {
             RGBColor[
             0.2856601600419676, 0.4175773184773137, 0.9395792955668297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 191}], {
             RGBColor[
             0.29321373700723585`, 0.4255166067922517, 0.9400094606004861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 102}], {
             RGBColor[
             0.3273981891467483, 0.4554287175679108, 0.9421765599569466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 112}], {
             RGBColor[
             0.2912053726836331, 0.4234056885504923, 0.9398950872233656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 140}], {
             RGBColor[
             0.29323255505263285`, 0.42553638575109687`, 0.9400105322603325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 155}], {
             RGBColor[
             0.2652922598561954, 0.3961693639826077, 0.9384193737828581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 99}], {
             RGBColor[
             0.7687919437411839, 0.8183727141912807, 0.944294118700548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 117}], {
             RGBColor[
             0.8762433687105626, 0.9035134810174441, 0.9541841801385145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 120}], {
             RGBColor[
             0.9651286166376958, 0.922790787247423, 0.6081584957443529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 121}], {
             RGBColor[
             0.7580819454747305, 0.8096778551186503, 0.9434509884049964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 146}], {
             RGBColor[
             0.8847914583012635, 0.9101913135735867, 0.9550361738224766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 156}], {
             RGBColor[
             0.9471660663080045, 0.9597340431975859, 0.961036759682581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.9239792736477469, 0.9412455241190165, 0.9588251826995514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 178}], {
             RGBColor[
             0.957960137429429, 0.968167319845601, 0.9560467009664877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 179}], {
             RGBColor[
             0.8907110607570355, 0.9148157520026807, 0.9556261844734377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 183}], {
             RGBColor[
             0.897769781538639, 0.6310947741177858, 0.4464659481425095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 196}], {
             RGBColor[
             0.7343309142909232, 0.7903956980318739, 0.9415812202273133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 107}], {
             RGBColor[
             0.615663269511703, 0.6984811954684678, 0.963146911483036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 109}], {
             RGBColor[
             0.45081925257627997`, 0.561890841684138, 0.9507778651594582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 146}], {
             RGBColor[
             0.6800950161218604, 0.7488157656197341, 0.9695688658362309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 147}], {
             RGBColor[
             0.5223956840025993, 0.6231433757875112, 0.9555440483245787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 156}], {
             RGBColor[
             0.7424696241286013, 0.7983584952437333, 0.9755694516963352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 178}], {
             RGBColor[
             0.7532636952500258, 0.8067917718917483, 0.970579392980242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 179}], {
             RGBColor[
             0.6860146185776324, 0.753440204048828, 0.970158876487192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 194}], {
             RGBColor[
             0.45631234328201786`, 0.5666486807626816, 0.9511278800418784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 104}], {
             RGBColor[
             0.21637454520909913`, 0.34475374432626316`, 0.9356335823009796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 123}], {
             RGBColor[
             0.23212285998297438`, 0.3613062216544334, 0.9365304255298079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 130}], {
             RGBColor[
             0.2255191848288738, 0.3543653403702861, 0.9361543559990437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 135}], {
             RGBColor[
             0.2235466331661063, 0.3522920635057185, 0.9360420220999779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 148}], {
             RGBColor[
             0.20930368592266696`, 0.3373218228978505, 0.9352309073250162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 163}], {
             RGBColor[
             0.22341821875914586`, 0.35215709182205945`, 0.9360347090894736]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 165}], {
             RGBColor[
             0.21635860172261037`, 0.34473698671108804`, 0.9356326743430103]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 123}], {
             RGBColor[
             0.2511378900976988, 0.38129222392755147`, 0.9376133033646252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 124}], {
             RGBColor[
             0.2714494089102611, 0.40264091802422836`, 0.9387700143128014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 127}], {
             RGBColor[
             0.28671598940138643`, 0.417499764656998, 0.9396828962615742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 135}], {
             RGBColor[
             0.2425616632808307, 0.3722780657788366, 0.9371248999347952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 137}], {
             RGBColor[
             0.25101571036429215`, 0.3811638052810985, 0.9376063454095565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 161}], {
             RGBColor[
             0.28025165259241314`, 0.41189263422865363`, 0.9392712890687474]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 165}], {
             RGBColor[
             0.23537363183733478`, 0.36472298898420613`, 0.9367155521778278]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 175}], {
             RGBColor[
             0.2861211170833608, 0.41698451615427623`, 0.9396449915234946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 176}], {
             RGBColor[
             0.27302063754770944`, 0.4042923789438361, 0.9388594934592795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 187}], {
             RGBColor[
             0.2673357347336053, 0.3983171856425559, 0.9385357466540765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 199}], {
             RGBColor[
             0.262066422777004, 0.3927788046824936, 0.9382356671333965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 106}], {
             RGBColor[
             0.32444342089519307`, 0.4523230687923987, 0.9420082902762085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 112}], {
             RGBColor[
             0.337642108559284, 0.46619572637249007`, 0.9427599360129698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 140}], {
             RGBColor[
             0.3396692909282838, 0.4683264235730946, 0.9428753810499368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 108}], {
             RGBColor[
             0.8366047008902185, 0.5941132685295566, 0.465258687547469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 129}], {
             RGBColor[
             0.9062804022305841, 0.6440404985324568, 0.2778692029903933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 131}], {
             RGBColor[
             0.8759467260841297, 0.5295848811738163, 0.2181992462316507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 133}], {
             RGBColor[
             0.8506697865477463, 0.3781326515142924, 0.19567142569650792`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 143}], {
             RGBColor[
             0.8497933193438173, 0.37139574051451657`, 0.1948321197121974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 154}], {
             RGBColor[
             0.9050363517550805, 0.647337503215628, 0.4299611695671895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 162}], {
             RGBColor[
             0.9038275928696831, 0.6466946914547808, 0.4435914409291628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 123}], {
             RGBColor[
             0.23468312728084179`, 0.36399722491481445`, 0.9366762289648454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 130}], {
             RGBColor[
             0.2280794521267412, 0.3570563436306672, 0.9363001594340813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 163}], {
             RGBColor[
             0.22597848605701326`, 0.35484809508244053`, 0.9361805125245111]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 111}], {
             RGBColor[
             0.4018530682244218, 0.5222917683666206, 0.9468805499681779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 116}], {
             RGBColor[
             0.36639655307775293`, 0.49177601147490035`, 0.944567442263732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 126}], {
             RGBColor[
             0.3252176564982815, 0.45596829309429976`, 0.9419487084621424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 142}], {
             RGBColor[
             0.4920496854617956, 0.5955174455512221, 0.9539811580781995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 157}], {
             RGBColor[
             0.4504475650892219, 0.5617429700786016, 0.9507060867688824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 160}], {
             RGBColor[
             0.35496105134530265`, 0.4818711546392811, 0.9438387822053573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 174}], {
             RGBColor[
             0.3623104663482657, 0.48823684852250904`, 0.9443070804305137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 182}], {
             RGBColor[
             0.30416697639606216`, 0.43384269361666083`, 0.9407499033720115]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 112}], {
             RGBColor[
             0.2882506044320779, 0.42030003977498026`, 0.9397268175426274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 140}], {
             RGBColor[
             0.29027778680107763`, 0.4224307369755848, 0.9398422625795944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 189}], {
             RGBColor[
             0.25322164598941777`, 0.3834823834875024, 0.9377319701800181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 111}], {
             RGBColor[
             0.5638634248724134, 0.6564277480338845, 0.9590690379639482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 142}], {
             RGBColor[
             0.6540600421097872, 0.7296534252184859, 0.9661696460739697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[
             0.5739634519525214, 0.664627405018551, 0.9598641490933124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.7940373920785235, 0.8398425244747729, 0.979889552465069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.6124579217372135, 0.6958789497458655, 0.9628945747646525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.7375823865275546, 0.7949242332798678, 0.9744789772559258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 181}], {
             RGBColor[
             0.8257804710137671, 0.8638766258907483, 0.9384122883545408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 185}], {
             RGBColor[
             0.7184021799057017, 0.779940510091907, 0.9725672735090811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 110}], {
             RGBColor[
             0.6931298062895987, 0.7596256615132471, 0.9704393557617335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 131}], {
             RGBColor[
             0.8402456246331873, 0.7322315204859621, 0.6082404593152602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 154}], {
             RGBColor[
             0.8838800631396134, 0.9088604535486795, 0.9258833443185683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 162}], {
             RGBColor[
             0.8820669248115173, 0.9078962359074088, 0.9463287513615282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 180}], {
             RGBColor[
             0.7526503794757171, 0.8066954638919603, 0.9759808139745987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 132}], {
             RGBColor[
             0.2948786821955154, 0.42460409000948357`, 0.9402017631916271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 146}], {
             RGBColor[
             0.5668187671363596, 0.653709441066444, 0.9615199202813867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 150}], {
             RGBColor[
             0.31023488720570846`, 0.44074443511482886`, 0.941076276349488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 151}], {
             RGBColor[
             0.34470972375175946`, 0.47299196992446024`, 0.9431855766759899]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 152}], {
             RGBColor[
             0.3096412804178116, 0.4401205167439052, 0.9410424713210799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 194}], {
             RGBColor[
             0.3430360942965171, 0.47154235620939167`, 0.9430789344870343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 196}], {
             RGBColor[
             0.4163582231260193, 0.5339138255247312, 0.9480649666862233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 127}], {
             RGBColor[
             0.46330733319948464`, 0.5715960026043997, 0.9518806741110254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 162}], {
             RGBColor[
             0.7939641442587955, 0.8384977959010833, 0.9379384858342741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 180}], {
             RGBColor[
             0.6645475989229954, 0.737297023885635, 0.9675905484473445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 116}], {
             RGBColor[
             0.42503929713653266`, 0.5423745144765412, 0.9483579559716804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 126}], {
             RGBColor[
             0.3838604005570612, 0.5065667960959406, 0.9457392221700909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 142}], {
             RGBColor[
             0.5506924295205754, 0.6461159485528629, 0.957771671786148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 157}], {
             RGBColor[
             0.5090903091480017, 0.6123414730802424, 0.9544966004768307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 160}], {
             RGBColor[
             0.41360379540408243`, 0.5324696576409218, 0.9476292959133059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 167}], {
             RGBColor[
             0.687885792752501, 0.7540851723545239, 0.971226039036996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 174}], {
             RGBColor[
             0.4209532104070455, 0.5388353515241499, 0.9480975941384622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 181}], {
             RGBColor[
             0.7224128584245553, 0.7803391492251253, 0.9300143140667192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.6150345673164899, 0.6964030334262838, 0.9641692992212595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 188}], {
             RGBColor[
             0.5625749036995356, 0.6554211455005088, 0.9589406102153506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 140}], {
             RGBColor[
             0.30347647446516857`, 0.4363033945556761, 0.9405939083163557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 122}], {
             RGBColor[
             0.9466202120897103, 0.8137405258050889, 0.35564035163633406`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 136}], {
             RGBColor[
             0.9041543846818847, 0.6565805366270306, 0.24168008890791598`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 138}], {
             RGBColor[
             0.9065388861824932, 0.6660342904889218, 0.24359871478674944`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 144}], {
             RGBColor[
             0.871111295903229, 0.5036666539093275, 0.21400931577186139`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 159}], {
             RGBColor[
             0.8485303397063004, 0.33009952954163524`, 0.19238576661614035`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 167}], {
             RGBColor[
             0.9077889348257765, 0.7877285014564059, 0.6151514893253305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 197}], {
             RGBColor[
             0.8946095450697447, 0.7772196138099509, 0.6138944273650201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 158}], {
             RGBColor[
             0.23522624458781927`, 0.364568075640074, 0.9367071586920077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 160}], {
             RGBColor[
             0.31613284886837134`, 0.44424671423453505`, 0.9415109015232768]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 126}], {
             RGBColor[
             0.34840388541039236`, 0.4760510392042203, 0.9434261144656448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 142}], {
             RGBColor[
             0.5152359143739065, 0.6156001916611427, 0.9554585640817019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 153}], {
             RGBColor[
             0.48777642817979994`, 0.593307343733011, 0.9532968527410897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 157}], {
             RGBColor[
             0.47363379400133276`, 0.5818257161885222, 0.9521834927723848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 160}], {
             RGBColor[
             0.3781472802574135, 0.5019539007492015, 0.9453161882088599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 167}], {
             RGBColor[
             0.652429277605832, 0.7235694154628036, 0.96891293133255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 174}], {
             RGBColor[
             0.38549669526037655`, 0.5083195946324296, 0.9457844864340161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 188}], {
             RGBColor[
             0.5271183885528666, 0.6249053886087885, 0.9566275025109046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 120}], {
             RGBColor[
             0.8678835994276715, 0.8465560061197337, 0.6325812491960736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 121}], {
             RGBColor[
             0.6608369282647062, 0.733443073990961, 0.9678737418567172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 146}], {
             RGBColor[
             0.7875464410912392, 0.8339565324458974, 0.9794589272741974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 151}], {
             RGBColor[
             0.565437397706639, 0.6532390613039136, 0.9611245836688005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 171}], {
             RGBColor[
             0.8267342564377225, 0.8650107429913272, 0.9832479361512722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 173}], {
             RGBColor[
             0.8870698836005233, 0.9096475021441977, 0.8455791000881498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 196}], {
             RGBColor[
             0.6370858970808988, 0.7141609169041846, 0.966003973679034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 119}], {
             RGBColor[
             0.7390929491372125, 0.7956716911845035, 0.9752408612005126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 125}], {
             RGBColor[
             0.5461336776674304, 0.6195695759530597, 0.9625480754195246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 128}], {
             RGBColor[
             0.901444520807011, 0.7626039594239429, 0.6105848646794676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 138}], {
             RGBColor[
             0.9130416014388392, 0.812801149295034, 0.6201343733156849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 144}], {
             RGBColor[
             0.8754464394074596, 0.6015112264467356, 0.4650330881244851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 149}], {
             RGBColor[
             0.5734377675010032, 0.6482679055474284, 0.9641030029427655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 159}], {
             RGBColor[
             0.852865483210531, 0.4279441020790433, 0.443409538968764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 170}], {
             RGBColor[
             0.5478364454002871, 0.6213592928020021, 0.9626450455228917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 190}], {
             RGBColor[
             0.5465072945042451, 0.6199622709372278, 0.9625693523456647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 192}], {
             RGBColor[
             0.8493151756474815, 0.40065488239475, 0.4400097604368888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.5461172634712222, 0.6195523235921249, 0.9625471406553332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 197}], {
             RGBColor[
             0.9011122603260905, 0.9239864726160629, 0.9904300858939554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 125}], {
             RGBColor[
             0.3719190998621983, 0.4815306199533135, 0.9461956553093709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 128}], {
             RGBColor[
             0.727229943001779, 0.6245650034241965, 0.5942324445693138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 144}], {
             RGBColor[
             0.7593033875373049, 0.5094852557802381, 0.45413147471771587`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 149}], {
             RGBColor[
             0.3992231896957711, 0.5102289495476822, 0.9477505828326117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 183}], {
             RGBColor[
             0.7615664433424367, 0.5237229317976604, 0.4561749529436979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 190}], {
             RGBColor[
             0.3722927166990131, 0.48192331493748153`, 0.946216932235511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 192}], {
             RGBColor[
             0.7331721237773268, 0.30862891172825246`, 0.4291081470301197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 195}], {
             RGBColor[
             0.37190268566599016`, 0.4815133675923786, 0.9461947205451795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 128}], {
             RGBColor[
             0.9231751810131911, 0.7286652920066743, 0.2580660064250903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 168}], {
             RGBColor[
             0.9476806026150666, 0.909778086957847, 0.6376934323137864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 171}], {
             RGBColor[
             0.9156195043648556, 0.8842880492213061, 0.6372222517571104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 172}], {
             RGBColor[
             0.9753727800277856, 0.9276792174007213, 0.4361680487899127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 173}], {
             RGBColor[
             0.9759551315276564, 0.9289248083741766, 0.49955341569398815`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 183}], {
             RGBColor[
             0.8921966020167115, 0.5931231241859789, 0.2320639941808822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 151}], {
             RGBColor[
             0.4472759744708069, 0.5594034354051198, 0.9503913919352824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 171}], {
             RGBColor[
             0.7085728332018904, 0.7711751170925334, 0.9725147444177542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 196}], {
             RGBColor[
             0.5189244738450667, 0.6203252910053908, 0.955270781945516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 136}], {
             RGBColor[
             0.9504725003418423, 0.8301441328600938, 0.35879847629145456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 138}], {
             RGBColor[
             0.9528570018424507, 0.8395978867219851, 0.360717102170288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 142}], {
             RGBColor[
             0.8169136872538085, 0.8533228738878083, 0.7188155094580211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 144}], {
             RGBColor[
             0.901990039676534, 0.619375718064703, 0.29208824069422046`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 153}], {
             RGBColor[
             0.7894542010597019, 0.8310300259596766, 0.7166537981174088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.8794090834796054, 0.44580859369701076`, 0.2704646915384994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 167}], {
             RGBColor[
             0.9541070504857341, 0.9612920976894692, 0.7322698767088691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 181}], {
             RGBColor[
             0.9886341161577883, 0.9875460745600706, 0.6910581517385923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 188}], {
             RGBColor[
             0.8287961614327686, 0.8626280708354541, 0.7199844478872237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 192}], {
             RGBColor[
             0.8758587759165559, 0.41851937401271744`, 0.2670649130066242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 127}], {
             RGBColor[
             0.2860095413584047, 0.4167572429724312, 0.9396426650906227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 130}], {
             RGBColor[
             0.24382776690061642`, 0.3736088209588374, 0.9371970026629095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 135}], {
             RGBColor[
             0.24185521523784892`, 0.3715355440942698, 0.9370846687638437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 163}], {
             RGBColor[
             0.2417268008308885, 0.37140057241061075`, 0.9370773557533394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 165}], {
             RGBColor[
             0.23466718379435303`, 0.36398046729963934`, 0.9366753210068761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 177}], {
             RGBColor[
             0.27201910823742403`, 0.40323970813810023`, 0.9388024578466887]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 187}], {
             RGBColor[
             0.26662928669062347`, 0.3975746639579891, 0.9384955154831248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 127}], {
             RGBColor[
             0.30632106017096694`, 0.43810593706910805`, 0.9407993760387987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 135}], {
             RGBColor[
             0.26216673405041124`, 0.39288423819094664`, 0.9382413797120197]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.27062078113387267`, 0.4017699776932086, 0.938722825186781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 161}], {
             RGBColor[
             0.29985672336199365`, 0.43249880664076373`, 0.9403877688459719]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 175}], {
             RGBColor[
             0.3057261878529413, 0.4375906885663863, 0.9407614713007191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 176}], {
             RGBColor[
             0.29262570831728996`, 0.4248985513559462, 0.9399759732365041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 187}], {
             RGBColor[
             0.2869408055031858, 0.4189233580546661, 0.939652226431301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 199}], {
             RGBColor[
             0.2816714935465845, 0.4133849770946037, 0.939352146910621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 128}], {
             RGBColor[
             0.5342706715319968, 0.44846288819275276`, 0.5815396587883258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.206263918225989, 0.33412683431623835`, 0.9350577970516237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[
             0.18066259612527297`, 0.307218221570812, 0.93359983963175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 190}], {
             RGBColor[
             0.179333445229231, 0.3058211997060377, 0.933524146454523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 195}], {
             RGBColor[
             0.17894341419620807`, 0.3054112523609348, 0.9335019347641915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 142}], {
             RGBColor[
             0.47405701779443504`, 0.579792473280542, 0.9528398302801124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 157}], {
             RGBColor[
             0.43245489742186133`, 0.5460179978079216, 0.9495647589707952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 160}], {
             RGBColor[
             0.336968383677942, 0.466146182368601, 0.9426974544072704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 174}], {
             RGBColor[
             0.3443177986809051, 0.472511876251829, 0.9431657526324266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 182}], {
             RGBColor[
             0.2861743087287016, 0.41811772134598074`, 0.9396085755739244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 191}], {
             RGBColor[
             0.2937278856939699, 0.4260570096609187, 0.9400387406075807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 135}], {
             RGBColor[
             0.2774333145415366, 0.4077430848237163, 0.9391542616607926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 161}], {
             RGBColor[
             0.31512330385311904`, 0.4473576532735334, 0.9413006507947447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 175}], {
             RGBColor[
             0.32099276834406665`, 0.45244953519915593`, 0.9416743532494919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 176}], {
             RGBColor[
             0.3078922888084153, 0.4397573979887158, 0.940888855185277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 177}], {
             RGBColor[
             0.3075972075411117, 0.4394472488675467, 0.9408720507436377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 180}], {
             RGBColor[
             0.5228279063856032, 0.618665804983113, 0.9574221323238906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 187}], {
             RGBColor[
             0.3022073859943112, 0.43378220468743567`, 0.9405651083800737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 183}], {
             RGBColor[
             0.8698008244556358, 0.5016777772906199, 0.21307095526300113`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 190}], {
             RGBColor[
             0.5346442883688116, 0.44885558317692076`, 0.5815609357144658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 192}], {
             RGBColor[
             0.8414065048905258, 0.286583757221212, 0.1860041493494229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 195}], {
             RGBColor[
             0.5342542573357888, 0.44844563583181796`, 0.5815387240241343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 131}], {
             RGBColor[
             0.9447591766437358, 0.8071223654903125, 0.32715623247964654`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 133}], {
             RGBColor[
             0.8790384594977417, 0.4469900974919443, 0.2522656130299896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 143}], {
             RGBColor[
             0.8772855250898838, 0.4335162754923927, 0.2505870010613686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 170}], {
             RGBColor[
             0.5863125273607737, 0.6439068649740138, 0.6751789886764388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 197}], {
             RGBColor[
             0.939588342286577, 0.9465340447880747, 0.7029640290475025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 163}], {
             RGBColor[
             0.23512312567678792`, 0.3644596911264634, 0.9367012862225752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 177}], {
             RGBColor[
             0.26541543308332344`, 0.3962988268539529, 0.9384263883159245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 133}], {
             RGBColor[
             0.8487047833512873, 0.33253448013330367`, 0.19259565627124703`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 143}], {
             RGBColor[
             0.8469518489434293, 0.3190606581337521, 0.19091704430262602`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 154}], {
             RGBColor[
             0.9428931009304802, 0.8120678725150692, 0.5552941823448407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 162}], {
             RGBColor[
             0.941079962602384, 0.8111036548737982, 0.5757395893878008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 180}], {
             RGBColor[
             0.811663417266584, 0.70990288285835, 0.6053916520008711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 150}], {
             RGBColor[
             0.2675705658104447, 0.39856400799346436`, 0.938549119936501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 151}], {
             RGBColor[
             0.3020454023564957, 0.43081154280309575`, 0.9406584202630028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 162}], {
             RGBColor[
             0.8765856501368406, 0.44964429041426807`, 0.41798785096875907`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 139}], {
             RGBColor[
             0.2400051701500614, 0.36959102940737165`, 0.9369793114329906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 145}], {
             RGBColor[
             0.21930399653046173`, 0.34783278340295676`, 0.9358004102199964]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 191}], {
             RGBColor[
             0.25554145744836393`, 0.3859206524153965, 0.9378640800107516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 148}], {
             RGBColor[
             0.2190360411775415, 0.34755114533768694`, 0.935785150559052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 163}], {
             RGBColor[
             0.2331505740140204, 0.36238641426189583`, 0.9365889523235094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 165}], {
             RGBColor[
             0.22609095697748494`, 0.3549663091509244, 0.9361869175770461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 176}], {
             RGBColor[
             0.26373796268785954`, 0.3945356991105544, 0.938330858858498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 187}], {
             RGBColor[
             0.2580530598737554, 0.38856050580927426`, 0.9380071120532948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 143}], {
             RGBColor[
             0.8498678524467502, 0.3315757262103135, 0.19331268304312726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 159}], {
             RGBColor[
             0.8510985318743886, 0.34103526757830527`, 0.19449118305288732`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 197}], {
             RGBColor[
             0.8984618333218767, 0.7936232208649558, 0.6170525520201404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 161}], {
             RGBColor[
             0.2794230248160247, 0.4110216938976339, 0.939224099942727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 175}], {
             RGBColor[
             0.2852924893069724, 0.4161135758232565, 0.9395978023974743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 176}], {
             RGBColor[
             0.27219200977132096`, 0.4034214386128163, 0.9388123043332592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 186}], {
             RGBColor[
             0.2661087370017966, 0.3970275332302755, 0.9384658709484304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 187}], {
             RGBColor[
             0.2665071069572168, 0.39744624531153616`, 0.938488557528056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 199}], {
             RGBColor[
             0.26123779500061556`, 0.39190786435147384`, 0.9381884780073761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 142}], {
             RGBColor[
             0.7768323613465915, 0.7056166385716411, 0.6067738726084364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 144}], {
             RGBColor[
             0.8752691557383894, 0.5209048945205916, 0.21739381612783068`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 156}], {
             RGBColor[
             0.9168097113153278, 0.8158057378279282, 0.6204937789995357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 159}], {
             RGBColor[
             0.8526881995414608, 0.34733777015289946`, 0.19577026697210964`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 167}], {
             RGBColor[
             0.914025724578517, 0.8135858623733021, 0.6202282398592844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 181}], {
             RGBColor[
             0.9485527902505714, 0.8398398392439036, 0.5790165148890076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 185}], {
             RGBColor[
             0.8411744991425061, 0.7559037234450623, 0.613171500043548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 192}], {
             RGBColor[
             0.8491378919784113, 0.32004855046860603`, 0.19237048844023447`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 145}], {
             RGBColor[
             0.2284570343408142, 0.357453206477753, 0.9363216621825899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 152}], {
             RGBColor[
             0.26544888260262894`, 0.3963339844195651, 0.9384282932165648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 182}], {
             RGBColor[
             0.2571409182934481, 0.38760178717525484`, 0.9379551669396888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 191}], {
             RGBColor[
             0.2646944952587164, 0.3955410754901928, 0.9383853319733451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 198}], {
             RGBColor[
             0.5277497041986612, 0.6241140740098087, 0.9572340887790165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 153}], {
             RGBColor[
             0.6134295605638427, 0.6970487778093326, 0.9627105685555573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 157}], {
             RGBColor[
             0.5992869263853755, 0.6855671502648439, 0.9615972085868523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 160}], {
             RGBColor[
             0.5038004126414563, 0.6056953348255233, 0.9547299040233275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 167}], {
             RGBColor[
             0.7780824099898748, 0.8273108495391253, 0.9783266471470176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 174}], {
             RGBColor[
             0.5111498276444193, 0.6120610287087513, 0.9551982022484837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 181}], {
             RGBColor[
             0.8126094756619291, 0.8535648264097266, 0.9371149221767408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 185}], {
             RGBColor[
             0.7052311845538637, 0.7696287106108853, 0.971269907331281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.6527715209369094, 0.7286468226851102, 0.9660412183253722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 154}], {
             RGBColor[
             0.8760414746143801, 0.43681328017556376`, 0.40267896763816474`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 159}], {
             RGBColor[
             0.821413781916936, 0.16560128815844824`, 0.1681391677880527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 197}], {
             RGBColor[
             0.8435046260386568, 0.41200177766559354`, 0.4414555753478633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 149}], {
             RGBColor[
             0.648866599779832, 0.4112160653555213, 0.44670623587921776`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 159}], {
             RGBColor[
             0.8452254175415028, 0.3486279538941323, 0.1909412169535338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 170}], {
             RGBColor[
             0.631799051712688, 0.39327699019190376`, 0.44573426426596857`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 181}], {
             RGBColor[
             0.8991205652819477, 0.619537019745982, 0.4376211825067001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 190}], {
             RGBColor[
             0.6309129511153266, 0.3923456422820542, 0.44568380214781717`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 192}], {
             RGBColor[
             0.8434502637599781, 0.33498334405198565`, 0.18924132768759622`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 197}], {
             RGBColor[
             0.8673162616632236, 0.5950284434012776, 0.4642576245133444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 147}], {
             RGBColor[
             0.6383951985626789, 0.7149619751698173, 0.9662861034465073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 156}], {
             RGBColor[
             0.8584691386886809, 0.8901770946260392, 0.9863115068182637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 171}], {
             RGBColor[
             0.8352823460284233, 0.8716885755474699, 0.9840999298352342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 178}], {
             RGBColor[
             0.8692632098101054, 0.8986103712740543, 0.9813214481021706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 179}], {
             RGBColor[
             0.802014133137712, 0.8452588034311341, 0.9809009316091206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 183}], {
             RGBColor[
             0.8386384964590899, 0.584723475070088, 0.463315779566298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 194}], {
             RGBColor[
             0.5723118578420975, 0.6584672801449877, 0.9618699351638069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 196}], {
             RGBColor[
             0.6456339866715997, 0.7208387494603272, 0.9668559673629961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 152}], {
             RGBColor[
             0.3812177118441309, 0.5013730508472783, 0.9458086544862003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 156}], {
             RGBColor[
             0.7007698065694198, 0.7645047047938165, 0.9722866893066117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 178}], {
             RGBColor[
             0.7115638776908443, 0.7729379814418316, 0.9672966305905184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 179}], {
             RGBColor[
             0.6443148010184508, 0.7195864135989113, 0.9668761140974684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 185}], {
             RGBColor[
             0.625134594396598, 0.7046026904109504, 0.9649644103506239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 194}], {
             RGBColor[
             0.41461252572283636`, 0.5327948903127648, 0.9478451176521548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 165}], {
             RGBColor[
             0.2118480097340456, 0.33999606854305653`, 0.9353758028020844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 159}], {
             RGBColor[
             0.6262856435829035, 0.23764894098782902`, 0.4250826867234967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 170}], {
             RGBColor[
             0.2079666859588458, 0.3359165511651807, 0.9351547671549908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 190}], {
             RGBColor[
             0.2066375350628038, 0.33451952930040635`, 0.9350790739777637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 192}], {
             RGBColor[
             0.622735336019854, 0.21035972130353567`, 0.4216829081916216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 195}], {
             RGBColor[
             0.2062475040297809, 0.3341095819553035, 0.9350568622874322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.5612425008846491, 0.6385437309792414, 0.9629398075260546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 151}], {
             RGBColor[
             0.3174016073666887, 0.4469518879084411, 0.9415329334208639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 152}], {
             RGBColor[
             0.2823331640327409, 0.4140804347278859, 0.9393898280659538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 194}], {
             RGBColor[
             0.31572797791144636`, 0.44550227419337246`, 0.9414262912319082]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 171}], {
             RGBColor[
             0.6131733026438233, 0.690971104405486, 0.9657655862298374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 196}], {
             RGBColor[
             0.4235249432869995, 0.5401212783183434, 0.9485216237575993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 194}], {
             RGBColor[
             0.3151343711235495, 0.4448783558224487, 0.9413924862035001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 160}], {
             RGBColor[
             0.4763409264473496, 0.5834024868973917, 0.9525681926827152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 167}], {
             RGBColor[
             0.7506229237957682, 0.8050180016109936, 0.9761649358064053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 174}], {
             RGBColor[
             0.4836903414503127, 0.5897681807806197, 0.9530364909078715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 188}], {
             RGBColor[
             0.6253120347428027, 0.7063539747569785, 0.9638795069847599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 157}], {
             RGBColor[
             0.7392642763541118, 0.795756249521131, 0.9753171149779516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 178}], {
             RGBColor[
             0.9316378178168464, 0.9481531008980535, 0.987322033962275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.864388741144453, 0.8948015330551333, 0.986901517469225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 181}], {
             RGBColor[
             0.9525868256306654, 0.9637539256660137, 0.9508348285678401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 183}], {
             RGBColor[
             0.8802215684635839, 0.6177519614860875, 0.46731617013970106`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 185}], {
             RGBColor[
             0.8452085345226001, 0.8798178098671724, 0.9849898137223804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 192}], {
             RGBColor[
             0.8518272488984739, 0.40265794141667954`, 0.4402493642261227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 174}], {
             RGBColor[
             0.4695477072718456, 0.5782865532361309, 0.9519231309391665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 181}], {
             RGBColor[
             0.7710073552893554, 0.8197903509371063, 0.9338398508674235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 185}], {
             RGBColor[
             0.6636290641812901, 0.7358542351382649, 0.9679948360219639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 164}], {
             RGBColor[
             0.27399405489207074`, 0.4053155022909841, 0.9389149281369991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 166}], {
             RGBColor[
             0.3220947514992546, 0.4482744245110126, 0.9419323901733808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 170}], {
             RGBColor[
             0.6092180955157596, 0.21970986582421148`, 0.4241107151102475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 197}], {
             RGBColor[
             0.844735305466295, 0.4214613190335854, 0.44263407535762334`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 167}], {
             RGBColor[
             0.6409937758733817, 0.7136645586271843, 0.9681842712741754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 174}], {
             RGBColor[
             0.37406119352792633`, 0.4984147377968103, 0.9450558263756417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 188}], {
             RGBColor[
             0.5156828868204164, 0.6150005317731692, 0.9558988424525301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 175}], {
             RGBColor[
             0.31452843153509336`, 0.4468424047708116, 0.941262746056665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 176}], {
             RGBColor[
             0.301427951999442, 0.43415026756037145`, 0.9404772479924501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 187}], {
             RGBColor[
             0.2957430491853379, 0.4281750742590913, 0.9401535011872468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 193}], {
             RGBColor[
             0.31267272742048674`, 0.4452350871371401, 0.9411445022314171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 199}], {
             RGBColor[
             0.2904737372287366, 0.422636693299029, 0.9398534216665669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 180}], {
             RGBColor[
             0.853484717444914, 0.8855675982797966, 0.9434799440471393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 177}], {
             RGBColor[
             0.2633144670135955, 0.39409057830572625`, 0.9383067414063544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 166}], {
             RGBColor[
             0.3428237586125573, 0.4700619252820549, 0.9431128764626655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 184}], {
             RGBColor[
             0.33292802569279517`, 0.46149073880095526`, 0.9424823291114712]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 187}], {
             RGBColor[
             0.2508650284302595, 0.38100542901464385`, 0.9375977642963274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 184}], {
             RGBColor[
             0.3810287222999791, 0.5044496610209838, 0.9454997911478531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 181}], {
             RGBColor[
             0.9498028388938546, 0.9615340502113876, 0.9505692894275887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 188}], {
             RGBColor[
             0.7899648841688349, 0.8366160464867711, 0.9794955855762202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 172}], {
             RGBColor[
             0.9662845352880476, 0.9716239920088556, 0.7873059163017873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 173}], {
             RGBColor[
             0.9668668867879184, 0.9728695829823109, 0.8506912832058626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 184}], {
             RGBColor[
             0.6548626736277727, 0.7248006680529328, 0.9668502718111599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 198}], {
             RGBColor[
             0.8173765882647961, 0.8581441256038294, 0.9795908811512684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 200}], {
             RGBColor[
             0.2545855584826314, 0.3849159419949167, 0.9378096429787789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 190}], {
             RGBColor[
             0.1810362129620878, 0.3076109165549801, 0.93362111655789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 195}], {
             RGBColor[
             0.1806461819290649, 0.30720096920987716`, 0.9335989048675586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 197}], {
             RGBColor[
             0.5356411787839332, 0.6116351182338152, 0.9614818501061808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 173}], {
             RGBColor[
             0.9348057885377076, 0.9473795452457701, 0.8502201026491867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 178}], {
             RGBColor[
             0.9084510251565888, 0.9296645818194842, 0.9851104569792455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 183}], {
             RGBColor[
             0.8647637066900788, 0.6054262821003745, 0.46584178548434796`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 196}], {
             RGBColor[
             0.6848218020180831, 0.7518929600057571, 0.9706449762400708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 173}], {
             RGBColor[
             0.9945590642006376, 0.9907707134251852, 0.6491658996819889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 198}], {
             RGBColor[
             0.8450687656775151, 0.8760452560467036, 0.7780654976273946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 188}], {
             RGBColor[
             0.5230323018233795, 0.6213662256563972, 0.9563671406776864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 176}], {
             RGBColor[
             0.30729741649038966`, 0.43924214948599405`, 0.9408509504471974]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 187}], {
             RGBColor[
             0.3016125136762855, 0.4332669561847139, 0.940527203641994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 199}], {
             RGBColor[
             0.2963432017196842, 0.4277285752246516, 0.9402271241213142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 187}], {
             RGBColor[
             0.2885120341406341, 0.42057481897427373`, 0.9397417055777791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 199}], {
             RGBColor[
             0.28324272218403285`, 0.4150364380142114, 0.9394416260570992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 179}], {
             RGBColor[
             0.8751828122658775, 0.9032348097031484, 0.9819114587531318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 183}], {
             RGBColor[
             0.8874176158778669, 0.6233741459180975, 0.46398946432897215`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 183}], {
             RGBColor[
             0.8425848980962714, 0.5878064340228173, 0.4637091200002722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 185}], {
             RGBColor[
             0.7887535289716312, 0.8348995186722672, 0.9795792385132371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 194}], {
             RGBColor[
             0.5782314602978695, 0.6630917185740817, 0.9624599458147682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 185}], {
             RGBColor[
             0.8769516134578437, 0.9038519112831478, 0.9435125496118522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 188}], {
             RGBColor[
             0.8244919498408892, 0.8628700233573725, 0.9382838606059434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 192}], {
             RGBColor[
             0.8729893015219696, 0.41868067569399636`, 0.41259785481910394`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 191}], {
             RGBColor[
             0.2726772055917506, 0.4039314101832797, 0.9388399355174497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 192}], {
             RGBColor[
             0.84571331956511, 0.349221020069408, 0.19128480591357822`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 193}], {
             RGBColor[
             0.29935843960625863`, 0.43124092646978174`, 0.9403862732371204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 199}], {
             RGBColor[
             0.2771594494145085, 0.4086425326316706, 0.9390951926722704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 199}], {
             RGBColor[
             0.27755781936992874`, 0.40906124471293126`, 0.9391178792518959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 192}], {
             RGBColor[
             0.6047816873553487, 0.19148929823006858`, 0.42066047446022103`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 195}], {
             RGBColor[
             0.1793170310330229, 0.30580394734510286`, 0.9335232116903315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 199}], {
             RGBColor[
             0.2944874976050776, 0.4261212575909801, 0.9401088802960662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 197}], {
             RGBColor[
             0.5339219968548683, 0.6098281490239381, 0.9613839452386224]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.04749427504982855], {
             RGBColor[
             0.9583125875736904, 0.8710407105954553, 0.2925527040414048]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.04749427504982855], {
             RGBColor[
             0.377120805174838, 0.5010648196248124, 0.9452507821242745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.04749427504982855], {
             RGBColor[
             0.26366336471100654`, 0.39445729190709694`, 0.938326610614074]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.04749427504982855], {
             RGBColor[
             0.8048857220793089, 0.8475021105371937, 0.9811871447582946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.04749427504982855], {
             RGBColor[
             0.2822070658609612, 0.41394789755425965`, 0.9393826469616164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.04749427504982855], {
             RGBColor[
             0.3400518121902417, 0.46895752104331584`, 0.9428887786701194]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.04749427504982855], {
             RGBColor[
             0.350460125859892, 0.477972679206911, 0.9435519872134391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.04749427504982855], {
             RGBColor[
             0.44819737568646545`, 0.5626277725896778, 0.9497797183467319]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.04749427504982855], {
             RGBColor[
             0.2605668322464433, 0.39120263995534316`, 0.9381502676711264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.04749427504982855], {
             RGBColor[
             0.28931600419628395`, 0.4214198424774074, 0.9397874904830813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.04749427504982855], {
             RGBColor[
             0.24586228151751777`, 0.37574722481687783`, 0.9373128652605475]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.04749427504982855], {
             RGBColor[
             0.5839626349742006, 0.6731262001457912, 0.9603908242322355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.04749427504982855], {
             RGBColor[
             0.3779993100162068, 0.5018257363634689, 0.9453067596759351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.04749427504982855], {
             RGBColor[
             0.4167727741971154, 0.535409362225998, 0.9477773705275145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.04749427504982855], {
             RGBColor[
             0.32511075702074876`, 0.45601633001476893`, 0.9419367478465757]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.04749427504982855], {
             RGBColor[
             0.3229612837478847, 0.4541545643014821, 0.9417997853103334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.04749427504982855], {
             RGBColor[
             0.2388383031545141, 0.3683645782114108, 0.9369128600838192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.04749427504982855], {
             RGBColor[
             0.3183704566888478, 0.45017822064462143`, 0.9415072618696405]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.04749427504982855], {
             RGBColor[
             0.26440158051900675`, 0.3952332035268908, 0.9383686509122472]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.04749427504982855], {
             RGBColor[
             0.22540124214842158`, 0.354241375135133, 0.9361476393378726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.04749427504982855], {
             RGBColor[
             0.31620160663402885`, 0.4482996717367106, 0.9413690646619862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.04749427504982855], {
             RGBColor[
             0.8444218577904707, 0.34245144152557083`, 0.19017172722845446`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.04749427504982855], {
             RGBColor[
             0.9935791491691084, 0.9886747742573517, 0.5425081958346172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.04749427504982855], {
             RGBColor[
             0.17892700283938517`, 0.30539400298437386`, 0.9335010001616988]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.04749427504982855], {
             RGBColor[
             0.9789215033713261, 0.9405594227844256, 0.37261445024803247`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.04749427504982855], {
             RGBColor[
             0.39640287984113043`, 0.5177659835555031, 0.9464794188715415]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.04749427504982855], {
             RGBColor[
             0.2767490295536739, 0.4082111553358114, 0.9390718198683575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.04749427504982855], {
             RGBColor[
             0.29477679578460203`, 0.4271594806709139, 0.9400984744855188]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.04749427504982855], {
             RGBColor[
             0.9936430185668372, 0.9916392390574856, 0.75501516389549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.04749427504982855], {
             RGBColor[
             0.8937471851268821, 0.9181137615718546, 0.9897275984465748]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.04749427504982855], {
             RGBColor[
             0.8505083657915934, 0.8836363007203797, 0.9856034412586252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.04749427504982855], {
             RGBColor[
             0.23515166545220784`, 0.36448968823995603`, 0.9367029115205646]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.04749427504982855], {
             RGBColor[
             0.3230400522816408, 0.4542227896464, 0.941804804371652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.04749427504982855], {
             RGBColor[
             0.2517479206748871, 0.38193340474234894`, 0.9376480437035368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.04749427504982855], {
             RGBColor[
             0.8383733051460716, 0.8739601327590868, 0.9844459883411588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.04749427504982855], {
             RGBColor[
             0.24777983952010385`, 0.3777626998577953, 0.9374220673520219]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.04749427504982855], {
             RGBColor[
             0.19099374879671333`, 0.31807691806140814`, 0.9341881834928177]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.04749427504982855], {
             RGBColor[
             0.9648082727380654, 0.8929521819142981, 0.31778721429778617`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.04749427504982855], {
             RGBColor[
             0.20098973591686892`, 0.3285833343068806, 0.9347574401715728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.04749427504982855], {
             RGBColor[
             0.49158142165721236`, 0.5981269694488269, 0.9531182367163876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.04749427504982855], {
             RGBColor[
             0.5497140953330726, 0.6453216927859953, 0.9576946537351515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.04749427504982855], {
             RGBColor[
             0.5214414667269106, 0.6223686992161088, 0.9554689288452234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.04749427504982855], {
             RGBColor[
             0.8553653759675705, 0.4265681177150025, 0.20065125259378117`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.04749427504982855], {
             RGBColor[
             0.2834240796528994, 0.4152270562127178, 0.9394519540966568]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.04749427504982855], {
             RGBColor[
             0.8843599871114161, 0.5677875345316877, 0.22521947746071738`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.04749427504982855], {
             RGBColor[
             0.5977424503378598, 0.6843132750316175, 0.9614756217747897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.04749427504982855], {
             RGBColor[
             0.4515217278586501, 0.5655071593544256, 0.9499915431275343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.04749427504982855], {
             RGBColor[
             0.3171026989044469, 0.4490801525711323, 0.9414264814646527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.04749427504982855], {
             RGBColor[
             0.8347376037115143, 0.26801402100751526`, 0.1808980745856452]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.04749427504982855], {
             RGBColor[
             0.2422322948146241, 0.37193187863768656`, 0.9371061428879017]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.04749427504982855], {
             RGBColor[
             0.28213996431762406`, 0.4138773695777287, 0.9393788256279912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.04749427504982855], {
             RGBColor[
             0.21246269677098534`, 0.3406421435922893, 0.9354108083194902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.04749427504982855], {
             RGBColor[
             0.21141226994966317`, 0.3395380784021726, 0.9353509880659832]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.04749427504982855], {
             RGBColor[
             0.27280646441116213`, 0.40406726939796367`, 0.938847296615994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.04749427504982855], {
             RGBColor[
             0.35238205413251156`, 0.47963735687773035`, 0.943674450783476]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.04749427504982855], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.04749427504982855], {
             RGBColor[
             0.3605779115447064, 0.4867361966324024, 0.9441966835704689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.04749427504982855], {
             RGBColor[
             0.264153442110629, 0.394972394326802, 0.9383545197969779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.04749427504982855], {
             RGBColor[
             0.44880489881560515`, 0.5631539785891382, 0.949818429183309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.04749427504982855], {
             RGBColor[
             0.253957266336059, 0.38425556711284614`, 0.9377738626705066]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.04749427504982855], {
             RGBColor[
             0.2737970101358498, 0.4051083957588368, 0.9389037067296339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.04749427504982855], {
             RGBColor[
             0.3562346737166085, 0.4829743023231845, 0.943919936296637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.04749427504982855], {
             RGBColor[
             0.35285247495850214`, 0.48004481175316516`, 0.9437044255825313]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.04749427504982855], {
             RGBColor[
             0.6226026285830288, 0.704495887669313, 0.963432706072083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.04749427504982855], {
             RGBColor[
             0.9220936452530043, 0.9407164594322621, 0.992431309118588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.04749427504982855], {
             RGBColor[
             0.6916199917227627, 0.7590180611312259, 0.9698978752847841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.04749427504982855], {
             RGBColor[
             0.8182056947053702, 0.14094252405757224`, 0.16506709985124088`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.04749427504982855], {
             RGBColor[
             0.8556248139763563, 0.8877160176206234, 0.9860914526539951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.04749427504982855], {
             RGBColor[
             0.4015855979045752, 0.522254993451075, 0.9468096570836465]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.04749427504982855], {
             RGBColor[
             0.21367513065222027`, 0.34191648847421524`, 0.9354798546353913]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.04749427504982855], {
             RGBColor[
             0.2902833275082297, 0.42243656061010276`, 0.93984257811467]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.04749427504982855], {
             RGBColor[
             0.24987650973082426`, 0.37996643318583184`, 0.9375414696187768]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.04749427504982855], {
             RGBColor[
             0.2931347355771166, 0.42543357128021636`, 0.9400049615859128]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.04749427504982855], {
             RGBColor[
             0.30278259996188467`, 0.4355740884585403, 0.9405543931898891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.04749427504982855], {
             RGBColor[
             0.28416143346402023`, 0.4160020618191376, 0.9394939453053829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.04749427504982855], {
             RGBColor[
             0.27635030732849636`, 0.40779207299670056`, 0.9390491132274904]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.04749427504982855], {
             RGBColor[
             0.3003940670337382, 0.43306358890932384`, 0.940418369773149]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.04749427504982855], {
             RGBColor[
             0.9279645300339343, 0.9453977435956535, 0.9929912793499938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.04749427504982855], {
             RGBColor[
             0.20396815225836698`, 0.3317138387242981, 0.934927056576049]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.04749427504982855], {
             RGBColor[
             0.6198970672218798, 0.7022993910721819, 0.9632197143709355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.04749427504982855], {
             RGBColor[
             0.5763338163997934, 0.6669327815527272, 0.9597902556887751]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.04749427504982855], {
             RGBColor[
             0.31859842780058983`, 0.45037567776345117`, 0.9415217879872938]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.04749427504982855], {
             RGBColor[
             0.25584834544704116`, 0.3862432111598293, 0.9378815568282761]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.04749427504982855], {
             RGBColor[
             0.2627765683456537, 0.3935252127009741, 0.9382761088729649]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.04749427504982855], {
             RGBColor[
             0.360155081261214, 0.48636996229290924`, 0.9441697411986989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.04749427504982855], {
             RGBColor[
             0.3919595940317969, 0.5139174327134967, 0.9461962966288141]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.04749427504982855], {
             RGBColor[
             0.9879745726157381, 0.9892951909842899, 0.8489559827730842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.04749427504982855], {
             RGBColor[
             0.7121946053554326, 0.7750911056739228, 0.9719485604909927]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.04749427504982855], {
             RGBColor[
             0.8539922331287186, 0.4160135401405583, 0.19933632946055357`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.04749427504982855], {
             RGBColor[
             0.3879488339253545, 0.5104435138959607, 0.9459407345414075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.04749427504982855], {
             RGBColor[
             0.8378176201564483, 0.8735170446320284, 0.9843929866107827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.04749427504982855], {
             RGBColor[
             0.22871531315648586`, 0.35772467388884666`, 0.9363363707790532]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.04749427504982855], {
             RGBColor[
             0.22414759348065547`, 0.35292371089939434`, 0.9360762459008504]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.04749427504982855], {
             RGBColor[
             0.4181274501813097, 0.5365827144755124, 0.9478636892833344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.04749427504982855], {
             RGBColor[
             0.9796258119030633, 0.9429352208414826, 0.3753505558963255]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.04749427504982855], {
             RGBColor[
             0.3061966914574528, 0.4391625150862857, 0.940748820649866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.04749427504982855], {
             RGBColor[
             0.28096145327109734`, 0.41263867974591306`, 0.9393117111673424]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.04749427504982855], {
             RGBColor[
             0.9734883859205871, 0.9797482621451334, 0.9297614266867937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.04749427504982855], {
             RGBColor[
             0.5640955015617808, 0.656997166237428, 0.9588268107143023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.04749427504982855], {
             RGBColor[
             0.21381427791123173`, 0.3420627410658821, 0.9354877788659421]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.04749427504982855], {
             RGBColor[
             0.2518443381406806, 0.38203474561211825`, 0.9376535345355769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.04749427504982855], {
             RGBColor[
             0.37383492502239923`, 0.4982187553899085, 0.9450414087465508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.04749427504982855], {
             RGBColor[
             0.8642907579141675, 0.4766578520345487, 0.20847322067670976`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.04749427504982855], {
             RGBColor[
             0.21893481250696653`, 0.34744474758664423`, 0.9357793857360172]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.04749427504982855], {
             RGBColor[
             0.34321032416564207`, 0.47169326536497985`, 0.9430900362602295]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.04749427504982855], {
             RGBColor[
             0.27505191676798696`, 0.40642738219488894`, 0.9389751718058661]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.04749427504982855], {
             RGBColor[
             0.6672310374616252, 0.7399652246995075, 0.9674670122517698]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.04749427504982855], {
             RGBColor[
             0.7812325868423204, 0.8290241015195725, 0.9788296212889877]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.04749427504982855], {
             RGBColor[
             0.3375430035907792, 0.46678451713084806`, 0.942728919604614]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.04749427504982855], {
             RGBColor[
             0.6050270257368769, 0.6902272215069217, 0.9620490902344793]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.04749427504982855], {
             RGBColor[
             0.4604958122832016, 0.5728902713682614, 0.9506710636761264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.04749427504982855], {
             RGBColor[
             0.30144929209616883`, 0.4341726973550716, 0.9404784632793888]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.04749427504982855], {
             RGBColor[
             0.9003020964297527, 0.6401769295720257, 0.2385219642527955]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.04749427504982855], {
             RGBColor[
             0.21718744139687057`, 0.3456081497602061, 0.935679875536301]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.04749427504982855], {
             RGBColor[
             0.2655539192117794, 0.3964443845554878, 0.9384342748960682]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.04749427504982855], {
             RGBColor[
             0.3895827819898638, 0.5118587575848209, 0.9460448482672345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.04749427504982855], {
             RGBColor[
             0.7789983515005383, 0.8272786998897548, 0.9786069335902352]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.04749427504982855], {
             RGBColor[
             0.9133075269424444, 0.9337106471842498, 0.9915932813106664]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.04749427504982855], {
             RGBColor[
             0.5648783713319804, 0.6576327351847573, 0.9588884410903589]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.04749427504982855], {
             RGBColor[
             0.9567688473548046, 0.8658333123497126, 0.2865555648019119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.04749427504982855], {
             RGBColor[
             0.5426755050288741, 0.6396074480921672, 0.9571405501231992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.04749427504982855], {
             RGBColor[
             0.9929383277496677, 0.9873041220381521, 0.47275873901987264`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.04749427504982855], {
             RGBColor[
             0.250431442054717, 0.3805497022429847, 0.9375730721936737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.04749427504982855], {
             RGBColor[
             0.2910544796798416, 0.42324709043633846`, 0.9398864940900259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.04749427504982855], {
             RGBColor[
             0.17895982839241617`, 0.30542850472186966`, 0.9335028695283829]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.04749427504982855], {
             RGBColor[
             0.30722498883092086`, 0.4402433208236197, 0.9408073806640553]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.04749427504982855], {
             RGBColor[
             0.32158764066209233`, 0.4529647837018777, 0.9417122579875715]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.04749427504982855], {
             RGBColor[
             0.8895815146715775, 0.5914972716636359, 0.22957644804826868`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.04749427504982855], {
             RGBColor[
             0.9902596908634175, 0.9788057915282733, 0.4166611676177604]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.04749427504982855], {
             RGBColor[
             0.23722409174651585`, 0.3666679396746901, 0.9368209331321454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.04749427504982855], {
             RGBColor[
             0.8992586624240541, 0.6354389394523516, 0.23765129734153262`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.04749427504982855], {
             RGBColor[
             0.2522143608002516, 0.3824236628881191, 0.93767460677864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.04749427504982855], {
             RGBColor[
             0.8234278438149039, 0.18108225047377968`, 0.1700678357361042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.04749427504982855], {
             RGBColor[
             0.23085213233970892`, 0.3599706063325754, 0.9364580594703971]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.04749427504982855], {
             RGBColor[
             0.23327898842098083`, 0.3625213859455549, 0.9365962653340136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.04749427504982855], {
             RGBColor[
             0.9080066729340168, 0.6729841436820356, 0.24483821356303642`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.04749427504982855], {
             RGBColor[
             0.2501870825879037, 0.38029286495007875`, 0.9375591562835361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.04749427504982855], {
             RGBColor[
             0.9127756759352338, 0.6918916514058181, 0.2486754653207034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.04749427504982855], {
             RGBColor[
             0.24915820796041388`, 0.3792114524821679, 0.9375005633955842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.04749427504982855], {
             RGBColor[
             0.30550365683416836`, 0.4384340917562807, 0.9407093533533227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.04749427504982855], {
             RGBColor[
             0.3593385897430587, 0.4856627583779401, 0.9441177150811572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.04749427504982855], {
             RGBColor[
             0.6408890467579492, 0.7193416257374643, 0.9648722798961695]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.04749427504982855], {
             RGBColor[
             0.8207984422031169, 0.16087151747445233`, 0.16754991778317269`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.04749427504982855], {
             RGBColor[
             0.8565158956399671, 0.43541151607797846`, 0.2017529915313943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.04749427504982855], {
             RGBColor[
             0.20775586072121455`, 0.33569496047333813`, 0.9351427609695957]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.04749427504982855], {
             RGBColor[
             0.79609453068194, 0.84063436500204, 0.9803109209581594]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.04749427504982855], {
             RGBColor[
             0.4806958664434177, 0.5892895853375945, 0.9522612859348552]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.04749427504982855], {
             RGBColor[
             0.20479309393410217`, 0.332580904729819, 0.9349740357840903]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.04749427504982855], {
             RGBColor[
             0.2335680080595618, 0.362825163910607, 0.9366127245748646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.04749427504982855], {
             RGBColor[
             0.2829267708206377, 0.41470435309880965`, 0.9394236330943619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.04749427504982855], {
             RGBColor[
             0.3518764439127397, 0.4791994227180725, 0.9436422337473658]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.04749427504982855], {
             RGBColor[
             0.281739557244844, 0.41345651635696223`, 0.9393560230375456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.04749427504982855], {
             RGBColor[
             0.585970074369736, 0.674755929881201, 0.960548857214945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.04749427504982855], {
             RGBColor[
             0.9865275394369064, 0.9886968055777866, 0.8729370673481489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.04749427504982855], {
             RGBColor[
             0.24962306644129345`, 0.3797000482193023, 0.9375270363983738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.04749427504982855], {
             RGBColor[
             0.9208437466954219, 0.9397198242500384, 0.9923120926783682]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.04749427504982855], {
             RGBColor[
             0.5576848060128018, 0.6517926747922235, 0.9583221372775351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.04749427504982855], {
             RGBColor[
             0.25326504777876796`, 0.3835280015199418, 0.9377344418477144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.04749427504982855], {
             RGBColor[
             0.8226444613445744, 0.17506082952644003`, 0.16931766779781277`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.04749427504982855], {
             RGBColor[
             0.36671177852496323`, 0.4920490439135823, 0.9445875281504853]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.04749427504982855], {
             RGBColor[
             0.30865896704414575`, 0.441750522845189, 0.9408890436019178]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.04749427504982855], {
             RGBColor[
             0.9829012627807141, 0.9867683702952449, 0.9138278814340688]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.04749427504982855], {
             RGBColor[
             0.23302215960706, 0.36225144257823677`, 0.936581639313005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.04749427504982855], {
             RGBColor[
             0.29472306200537346`, 0.42710300306202637`, 0.9400954144262837]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.04749427504982855], {
             RGBColor[
             0.21890292553398902`, 0.347411232356294, 0.9357775698200786]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.04749427504982855], {
             RGBColor[
             0.39092445521974123`, 0.5130208475020834, 0.9461303384990473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.04749427504982855], {
             RGBColor[
             0.9152757732218003, 0.9352800733407862, 0.9917810143978655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.04749427504982855], {
             RGBColor[
             0.9385923578753286, 0.9537228615659814, 0.988831299825661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.04749427504982855], {
             RGBColor[
             0.2725827939998642, 0.40383217761416634`, 0.9388345589169613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.04749427504982855], {
             RGBColor[
             0.1823653638581298, 0.3090079384197544, 0.933696809735117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.04749427504982855], {
             RGBColor[
             0.8744701613749067, 0.9027427860928997, 0.9878889387123091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.04749427504982855], {
             RGBColor[
             0.9939767127007667, 0.98952512245173, 0.5857805327779135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.04749427504982855], {
             RGBColor[
             0.9951414157005084, 0.9920163043986404, 0.7125512665860644]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.04749427504982855], {
             RGBColor[
             0.3814106085308894, 0.5047804316800383, 0.9455241246007979]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.04749427504982855], {
             RGBColor[
             0.320397896026041, 0.45193428669643415`, 0.9416364485114123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.04749427504982855], {
             RGBColor[
             0.29419693695473825`, 0.4265500122755539, 0.9400654523829823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.04749427504982855], {
             RGBColor[
             0.29360677442013106`, 0.4259297140332158, 0.9400318434997037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.04749427504982855], {
             RGBColor[
             0.9424318889382709, 0.9565863775460686, 0.9823319752461818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.04749427504982855], {
             RGBColor[
             0.807933735593484, 0.8498832418602281, 0.9814909422600818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.04749427504982855], {
             RGBColor[
             0.7240681721091139, 0.7843668262643483, 0.9731320066602097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.04749427504982855], {
             RGBColor[
             0.984329904565909, 0.9877880270819891, 0.9093575644573119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.04749427504982855], {
             RGBColor[
             0.2651236286264823, 0.39599212186834176`, 0.9384097704837935]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.04749427504982855], {
             RGBColor[
             0.859910479347665, 0.45676803010411193`, 0.20481820887036734`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.04749427504982855], {
             RGBColor[
             0.3711329893802169, 0.49587847453988415`, 0.9448692437966588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.04749427504982855], {
             RGBColor[
             0.7695733223497783, 0.8199157954843064, 0.9776675347663926]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.04749427504982855], {
             RGBColor[
             0.28203039141568953`, 0.41376220151047227`, 0.9393725856133247]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.04749427504982855], {
             RGBColor[
             0.28282713132653, 0.41459962567299363`, 0.939417958772576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.04749427504982855], {
             RGBColor[
             0.6646539951158695, 0.737952019632756, 0.9672101567545748]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.04749427504982855], {
             RGBColor[
             0.2313913752108486, 0.36053738478011593`, 0.9364887685541701]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.04749427504982855], {
             RGBColor[
             0.1797070620660458, 0.3062138946902057, 0.9335454233806629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.04749427504982855], {
             RGBColor[
             0.28023078255701894`, 0.41187069849821767`, 0.939270100551106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.04749427504982855], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.04749427504982855], {
             RGBColor[
             0.31668648779682773`, 0.44871965142909115`, 0.9413999608609163]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.04749427504982855], {
             RGBColor[
             0.348529185002255, 0.47630019528793527`, 0.9434289493694545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.04749427504982855], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.04749427504982855], {
             RGBColor[
             0.49517344266125934`, 0.6010431339186144, 0.9534010137678327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.04749427504982855], {
             RGBColor[
             0.8889169937097365, 0.9142622980478761, 0.9892668904772446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.04749427504982855], {
             RGBColor[
             0.6961608186542636, 0.7625653896416773, 0.9703504624768758]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.04749427504982855], {
             RGBColor[
             0.27228850741332744`, 0.40352286375286894`, 0.938817799731216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.04749427504982855], {
             RGBColor[
             0.23658832296539867`, 0.36599970637566703`, 0.9367847270405965]},
             StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{3.8349502435193233`*^9, 3.834957407142641*^9, 
  3.835018921852682*^9, 3.8350190129675236`*^9, 3.8350205474078445`*^9, 
  3.8350446401426015`*^9, 3.835045030495333*^9, 3.8350519568471727`*^9},
 CellLabel->
  "Out[410]=",ExpressionUUID->"39dde4e3-ad9d-41f6-92cc-a7e90d80aff5"]
}, Open  ]],

Cell["Estimated with absolute Mean Deviation v Calculated: (r=6)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 
  3.8349503922098827`*^9}},ExpressionUUID->"b9119875-642a-47f4-aa6e-\
3a86fea24f14"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphinf2", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsif2", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}],
      "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"AMDi6f200", ",", "krif2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502409842243`*^9}, {3.8349504019691753`*^9, 3.834950402221115*^9}, {
   3.8349577477528667`*^9, 3.8349577551942053`*^9}, {3.835018833417392*^9, 
   3.8350188346728773`*^9}, {3.8350443403897114`*^9, 
   3.8350443452390656`*^9}, {3.8350449339623103`*^9, 3.835044937670579*^9}},
 CellLabel->
  "In[271]:=",ExpressionUUID->"7adbd969-86c2-4578-93f4-2b48caa0b04e"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
          103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
          129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 
          142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 
          155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 
          168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 
          181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 
          194, 195, 196, 197, 198, 199, 200}, {Null, CompressedData["
1:eJwVxfk/GgwDAPA5ylXk6qBcTS9j5XjImZDN1UpNhz0LEUrEK0VRaK6QloU8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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[31, 80] -> 
             RGBColor[
              0.9626146469370097, 0.9700346371419625, 0.8773113402992566], 
             UndirectedEdge[36, 132] -> 
             RGBColor[
              0.5111330915962867, 0.6129614555321319, 0.9549443399612596], 
             UndirectedEdge[16, 101] -> 
             RGBColor[
              0.8580504587448748, 0.8899196128969017, 0.98625130854675], 
             UndirectedEdge[86, 108] -> 
             RGBColor[
              0.640192839827979, 0.7167053187484513, 0.9662334907894026], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.9493043263229181, 0.9593179990892389, 0.871553989498518], 
             UndirectedEdge[29, 136] -> 
             RGBColor[
              0.7604338847873271, 0.810072598705585, 0.8856130000455075], 
             UndirectedEdge[55, 157] -> 
             RGBColor[
              0.9176875410955417, 0.9041338914370621, 0.6641894462813742], 
             UndirectedEdge[7, 188] -> 
             RGBColor[
              0.9079970852388948, 0.9272040856390731, 0.9033671729979962], 
             UndirectedEdge[19, 141] -> 
             RGBColor[
              0.8553773162499736, 0.8875761574400001, 0.9704994522003183], 
             UndirectedEdge[62, 185] -> 
             RGBColor[
              0.3567122093353099, 0.4826509704870196, 0.9439773477637796], 
             UndirectedEdge[79, 144] -> 
             RGBColor[
              0.7051580074510218, 0.7243987586987787, 0.6303044718058681], 
             UndirectedEdge[47, 54] -> 
             RGBColor[
              0.8235564641909814, 0.8622693241379311, 0.9446429811671088], 
             UndirectedEdge[32, 101] -> 
             RGBColor[
              0.9481816153492972, 0.9607134751369111, 0.9670158666358989], 
             UndirectedEdge[104, 163] -> 
             RGBColor[
              0.6424141113343264, 0.7162590754067071, 0.9676467145149805], 
             UndirectedEdge[119, 125] -> 
             RGBColor[
              0.6062680801047657, 0.6882052929578437, 0.963895261535368], 
             UndirectedEdge[9, 140] -> 
             RGBColor[
              0.9175639132578981, 0.9337600513105063, 0.8577139484313963], 
             UndirectedEdge[3, 63] -> 
             RGBColor[
              0.7206582583796906, 0.7808772479654866, 0.9735920267019386], 
             UndirectedEdge[50, 104] -> 
             RGBColor[
              0.7005460036665887, 0.759888444177677, 0.8658763192909291], 
             UndirectedEdge[47, 61] -> 
             RGBColor[
              0.766926880038582, 0.8182123508328911, 0.9773071740380999], 
             UndirectedEdge[149, 195] -> 
             RGBColor[
              0.7141271040813661, 0.6306078015242869, 0.5965813546608629], 
             UndirectedEdge[99, 178] -> 
             RGBColor[
              0.8470277313567135, 0.8790996976686691, 0.8781612968591709], 
             UndirectedEdge[160, 174] -> 
             RGBColor[
              0.6545671356575089, 0.7240226026154548, 0.9592119093215867], 
             UndirectedEdge[6, 124] -> 
             RGBColor[
              0.76856873310439, 0.8192092056685449, 0.9715727633647764], 
             UndirectedEdge[24, 197] -> 
             RGBColor[
              0.8615254265438324, 0.8921994622684526, 0.9620186044500952], 
             UndirectedEdge[80, 120] -> 
             RGBColor[
              0.8572092230674584, 0.8867860384289872, 0.86704569324707], 
             UndirectedEdge[83, 187] -> 
             RGBColor[
              0.845231899686216, 0.8795363461908166, 0.9637107709693544], 
             UndirectedEdge[47, 167] -> 
             RGBColor[
              0.743442153846154, 0.7995019280450388, 0.9750630240996048], 
             UndirectedEdge[132, 150] -> 
             RGBColor[
              0.6402452160883892, 0.7147307457352627, 0.9673472712568614], 
             UndirectedEdge[17, 189] -> 
             RGBColor[
              0.9172871978269982, 0.9334370982270543, 0.8506893699446612], 
             UndirectedEdge[69, 180] -> 
             RGBColor[
              0.9662124139548477, 0.9725869433536934, 0.8643848985240299], 
             UndirectedEdge[43, 95] -> 
             RGBColor[
              0.7715300242453473, 0.8219862039897408, 0.9777187786570796], 
             UndirectedEdge[82, 86] -> 
             RGBColor[
              0.8843492673821165, 0.9083791651455382, 0.8874857021228117], 
             UndirectedEdge[7, 61] -> 
             RGBColor[
              0.8457474137001912, 0.8798400467552974, 0.9851493373979952], 
             UndirectedEdge[30, 65] -> 
             RGBColor[
              0.8303782699963229, 0.867993080951026, 0.9652929603218625], 
             UndirectedEdge[62, 174] -> 
             RGBColor[
              0.6799587658512948, 0.7460155564688709, 0.9608298415445977], 
             UndirectedEdge[18, 47] -> 
             RGBColor[
              0.6996707768595042, 0.7653073956682817, 0.97070030230835], 
             UndirectedEdge[56, 149] -> 
             RGBColor[
              0.6897077474638125, 0.7560389078149068, 0.9708232249699862], 
             UndirectedEdge[82, 163] -> 
             RGBColor[
              0.9333710332638308, 0.9471248868452323, 0.8922524380278436], 
             UndirectedEdge[10, 48] -> 
             RGBColor[
              0.8692305928299071, 0.8985648963594165, 0.987389183987069], 
             UndirectedEdge[58, 92] -> 
             RGBColor[
              0.9566791518784397, 0.9672119629190945, 0.9582150753697729], 
             UndirectedEdge[70, 72] -> 
             RGBColor[
              0.9005322454960281, 0.9188346173774622, 0.7404119600020911], 
             UndirectedEdge[35, 181] -> 
             RGBColor[
              0.7774836436306078, 0.8262898723308596, 0.9784043543140888], 
             UndirectedEdge[126, 174] -> 
             RGBColor[
              0.9696772500761971, 0.975594422283574, 0.877480991728024], 
             UndirectedEdge[108, 154] -> 
             RGBColor[
              0.7473190533489926, 0.7990690601332788, 0.869684661057366], 
             UndirectedEdge[63, 77] -> 
             RGBColor[
              0.3653299982853787, 0.47617736388060594`, 0.9456772945180305], 
             UndirectedEdge[32, 100] -> 
             RGBColor[
              0.9800328365177198, 0.9831397676395934, 0.8519879126723364], 
             UndirectedEdge[19, 50] -> 
             RGBColor[
              0.9724147351477108, 0.9776725168761814, 0.8744809137772608], 
             UndirectedEdge[80, 81] -> 
             RGBColor[
              0.930750596504915, 0.9446271082540179, 0.8742721187236697], 
             UndirectedEdge[34, 163] -> 
             RGBColor[
              0.9066040297697455, 0.9283163019086286, 0.9892495365324937], 
             UndirectedEdge[146, 194] -> 
             RGBColor[
              0.550940621134697, 0.6426702805639504, 0.9593596159984821], 
             UndirectedEdge[13, 83] -> 
             RGBColor[
              0.966365167364521, 0.9744357774092194, 0.9418191776692701], 
             UndirectedEdge[30, 41] -> 
             RGBColor[
              0.8284025372637924, 0.8664496235242483, 0.9650960377473561], 
             UndirectedEdge[35, 111] -> 
             RGBColor[
              0.8306818537425054, 0.5063046775190206, 0.5746024658795836], 
             UndirectedEdge[29, 144] -> 
             RGBColor[
              0.7469387328619483, 0.7584820755590385, 0.6335483335884409], 
             UndirectedEdge[6, 12] -> 
             RGBColor[
              0.8987458017230769, 0.9219197425196817, 0.9839712771068434], 
             UndirectedEdge[67, 143] -> 
             RGBColor[
              0.5269856644292852, 0.6260774019691246, 0.956124310626759], 
             UndirectedEdge[135, 163] -> 
             RGBColor[
              0.9117611313614709, 0.9321624598317586, 0.9805199087252149], 
             UndirectedEdge[50, 60] -> 
             RGBColor[
              0.9308247055993426, 0.9449549457275179, 0.8859490184390757], 
             UndirectedEdge[25, 143] -> 
             RGBColor[
              0.6485229378982258, 0.7251584498393999, 0.9657335430740448], 
             UndirectedEdge[12, 13] -> 
             RGBColor[
              0.9140708590964397, 0.9333491452162573, 0.9580299523888458], 
             UndirectedEdge[89, 144] -> 
             RGBColor[
              0.9134578757493368, 0.89063116735809, 0.6488833077732092], 
             UndirectedEdge[22, 24] -> 
             RGBColor[
              0.8662446440128335, 0.8957190469298243, 0.9540302002441186], 
             UndirectedEdge[107, 156] -> 
             RGBColor[
              0.5442101162440318, 0.6408533146100794, 0.9572613603395226], 
             UndirectedEdge[23, 154] -> 
             RGBColor[
              0.9913840190816188, 0.9907050847167092, 0.7924526314688264], 
             UndirectedEdge[101, 135] -> 
             RGBColor[
              0.9386868052239347, 0.9536322612917405, 0.9830881035350495], 
             UndirectedEdge[7, 42] -> 
             RGBColor[
              0.629952234966216, 0.7071545164659021, 0.9660749808665267], 
             UndirectedEdge[122, 192] -> 
             RGBColor[
              0.6758825880014396, 0.7467238817354301, 0.968329317956242], 
             UndirectedEdge[129, 133] -> 
             RGBColor[
              0.4178555911758306, 0.5325365719855557, 0.9485637344876652], 
             UndirectedEdge[40, 80] -> 
             RGBColor[
              0.9920652251521298, 0.9909867809330628, 0.781163283975659], 
             UndirectedEdge[41, 172] -> 
             RGBColor[
              0.7319083870430845, 0.7904916617586064, 0.9739134460138537], 
             UndirectedEdge[94, 115] -> 
             RGBColor[
              0.7826725619995397, 0.8285534732742074, 0.9051936924096966], 
             UndirectedEdge[87, 103] -> 
             RGBColor[
              0.876723470557029, 0.9040552098522168, 0.9626688212580523], 
             UndirectedEdge[142, 160] -> 
             RGBColor[
              0.42030383738955035`, 0.5377774764936554, 0.9481931028964257], 
             UndirectedEdge[21, 150] -> 
             RGBColor[
              0.8684101754364506, 0.8979107177995111, 0.9873109318436859], 
             UndirectedEdge[29, 142] -> 
             RGBColor[
              0.5047935313473054, 0.6088531552940032, 0.9541583423887443], 
             UndirectedEdge[67, 103] -> 
             RGBColor[
              0.6067548386895731, 0.6885855524637976, 0.9639437770820839], 
             UndirectedEdge[50, 163] -> 
             RGBColor[
              0.9337346377709047, 0.947275246653117, 0.8862265703673264], 
             UndirectedEdge[21, 46] -> 
             RGBColor[
              0.9262484857232207, 0.9428588040239209, 0.9522417340828626], 
             UndirectedEdge[43, 129] -> 
             RGBColor[
              0.7145624377227788, 0.7759469440077165, 0.9730907816077339], 
             UndirectedEdge[11, 112] -> 
             RGBColor[
              0.6940449403745437, 0.7609124494482895, 0.9701395715039601], 
             UndirectedEdge[119, 195] -> 
             RGBColor[
              0.8434634461013111, 0.7333717248231273, 0.6082927340048818], 
             UndirectedEdge[99, 109] -> 
             RGBColor[
              0.6058189631615543, 0.689952792888616, 0.9627386378736271], 
             UndirectedEdge[45, 120] -> 
             RGBColor[
              0.8385912459259386, 0.8227161373367731, 0.6282649420300315], 
             UndirectedEdge[29, 153] -> 
             RGBColor[
              0.6101905904523399, 0.6936965460704283, 0.9629496919873427], 
             UndirectedEdge[27, 125] -> 
             RGBColor[
              0.3862415090041078, 0.5089647148618224, 0.9458319453071538], 
             UndirectedEdge[35, 157] -> 
             RGBColor[
              0.8542610996310995, 0.8866286288187555, 0.9859613803623424], 
             UndirectedEdge[28, 112] -> 
             RGBColor[
              0.8385631297076235, 0.8725847869719912, 0.8817477774782329], 
             UndirectedEdge[22, 89] -> 
             RGBColor[
              0.9182158848098501, 0.9366741991176051, 0.9591160484796996], 
             UndirectedEdge[96, 116] -> 
             RGBColor[
              0.6582083655691326, 0.7313134914161586, 0.9676638013922279], 
             UndirectedEdge[23, 143] -> 
             RGBColor[
              0.8103952552319409, 0.8504474923445977, 0.8817707118185033], 
             UndirectedEdge[6, 14] -> 
             RGBColor[
              0.9265090356454173, 0.9440573916364471, 0.9866193591428878], 
             UndirectedEdge[9, 112] -> 
             RGBColor[
              0.8404743826368581, 0.8733751391751896, 0.850073370276786], 
             UndirectedEdge[12, 25] -> 
             RGBColor[
              0.7610163467728372, 0.8135125950705033, 0.9767399343436783], 
             UndirectedEdge[176, 199] -> 
             RGBColor[
              0.9714357073172626, 0.9772263052749642, 0.8888538234200621], 
             UndirectedEdge[48, 112] -> 
             RGBColor[
              0.7799148763177639, 0.828431155465509, 0.9785824613077203], 
             UndirectedEdge[79, 149] -> 
             RGBColor[
              0.48850504684626944`, 0.5954655880167583, 0.9529213231917535], 
             UndirectedEdge[58, 155] -> 
             RGBColor[
              0.8169557569823804, 0.8577687608361504, 0.9771896386140353], 
             UndirectedEdge[118, 138] -> 
             RGBColor[
              0.9923591044203766, 0.9898768733271123, 0.6867806747092144], 
             UndirectedEdge[172, 173] -> 
             RGBColor[
              0.8787870729813354, 0.9027891845691792, 0.8136989116378877], 
             UndirectedEdge[53, 104] -> 
             RGBColor[
              0.47035486749993716`, 0.579697081169313, 0.9517779987913318], 
             UndirectedEdge[179, 185] -> 
             RGBColor[
              0.5795324585927684, 0.6616525693284936, 0.9633928529247522], 
             UndirectedEdge[82, 176] -> 
             RGBColor[
              0.9719266592713, 0.9774293265248484, 0.8807174789987329], 
             UndirectedEdge[142, 181] -> 
             RGBColor[
              0.5948321791426903, 0.680900279172798, 0.9619646149218108], 
             UndirectedEdge[54, 160] -> 
             RGBColor[
              0.6700704892490209, 0.7355849783395927, 0.9329687756133639], 
             UndirectedEdge[121, 151] -> 
             RGBColor[
              0.8813883020383939, 0.907786446831939, 0.9675394742471668], 
             UndirectedEdge[138, 144] -> 
             RGBColor[
              0.9784433702559203, 0.9381124286162368, 0.441686144385607], 
             UndirectedEdge[171, 196] -> 
             RGBColor[
              0.7606697685028853, 0.8119069579495715, 0.9470929837912401], 
             UndirectedEdge[120, 172] -> 
             RGBColor[
              0.7420777631856873, 0.7984360556913291, 0.9749270343895251], 
             UndirectedEdge[113, 159] -> 
             RGBColor[
              0.9100294650475376, 0.930085821057028, 0.9562290090614016], 
             UndirectedEdge[103, 108] -> 
             RGBColor[
              0.6460994637596027, 0.7213196182558403, 0.9668222078623678], 
             UndirectedEdge[64, 176] -> 
             RGBColor[
              0.9523447208534173, 0.9639793513576123, 0.965552136494471], 
             UndirectedEdge[83, 101] -> 
             RGBColor[
              0.9444318202334208, 0.9579168840792165, 0.973363291663879], 
             UndirectedEdge[15, 63] -> 
             RGBColor[
              0.6643506354279998, 0.7363267579506095, 0.9681290917508129], 
             UndirectedEdge[55, 72] -> 
             RGBColor[
              0.8893897780422941, 0.8816678395388663, 0.6614644229576132], 
             UndirectedEdge[105, 142] -> 
             RGBColor[
              0.7368379192368313, 0.789637980084045, 0.8210446636730042], 
             UndirectedEdge[96, 105] -> 
             RGBColor[
              0.7663199340129144, 0.8135728078288995, 0.823365595872356], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.7128583452266917, 0.7746578089402877, 0.9728480640223409], 
             UndirectedEdge[64, 108] -> 
             RGBColor[
              0.7274009551169989, 0.7854800742439945, 0.9600903566266381], 
             UndirectedEdge[56, 119] -> 
             RGBColor[
              0.8190440894837574, 0.8588028311137472, 0.9825346043140051], 
             UndirectedEdge[68, 157] -> 
             RGBColor[
              0.7499061950557029, 0.8048037102175065, 0.9756854329761273], 
             UndirectedEdge[137, 161] -> 
             RGBColor[
              0.9327003165940663, 0.947657473170098, 0.9385385531435961], 
             UndirectedEdge[160, 188] -> 
             RGBColor[
              0.6756905766353252, 0.7388920439183284, 0.883850804084356], 
             UndirectedEdge[127, 187] -> 
             RGBColor[
              0.7723152798807342, 0.8220578335471382, 0.9779408274680282], 
             UndirectedEdge[41, 141] -> 
             RGBColor[
              0.7293022928602589, 0.7884557611759337, 0.9736536949010445], 
             UndirectedEdge[137, 175] -> 
             RGBColor[
              0.8649228420764943, 0.8942255394923642, 0.9319114751873665], 
             UndirectedEdge[1, 122] -> 
             RGBColor[
              0.8296256823296322, 0.8669204615573702, 0.940682910171755], 
             UndirectedEdge[60, 177] -> 
             RGBColor[
              0.7458210448080663, 0.801448810901451, 0.9754080215282044], 
             UndirectedEdge[72, 75] -> 
             RGBColor[
              0.5937044031271237, 0.6764958026840323, 0.9634449374454699], 
             UndirectedEdge[13, 69] -> 
             RGBColor[
              0.9555554608595318, 0.9663739159970683, 0.9601171911592284], 
             UndirectedEdge[48, 77] -> 
             RGBColor[
              0.526455346941313, 0.6038744450596817, 0.9606717695043103], 
             UndirectedEdge[22, 183] -> 
             RGBColor[
              0.8553909523257113, 0.8872400604927322, 0.9529484056902617], 
             UndirectedEdge[16, 86] -> 
             RGBColor[
              0.7821030190006969, 0.8297040897372256, 0.9789163778318837], 
             UndirectedEdge[8, 62] -> 
             RGBColor[
              0.5754414308247158, 0.6636353700933347, 0.9610292559289], 
             UndirectedEdge[26, 51] -> 
             RGBColor[
              0.9316550252619101, 0.8993125626612991, 0.6420444551925941], 
             UndirectedEdge[117, 121] -> 
             RGBColor[
              0.9543645846103621, 0.9654857624403184, 0.962133034018803], 
             UndirectedEdge[89, 136] -> 
             RGBColor[
              0.9269530276747155, 0.9422216905046364, 0.900947974230276], 
             UndirectedEdge[81, 168] -> 
             RGBColor[
              0.6238806165782493, 0.7004596799403183, 0.9663491290450928], 
             UndirectedEdge[172, 198] -> 
             RGBColor[
              0.8782890105107336, 0.9031972269305139, 0.8665847042228496], 
             UndirectedEdge[55, 68] -> 
             RGBColor[
              0.8031162443740563, 0.8141626990550992, 0.6529390502919843], 
             UndirectedEdge[156, 192] -> 
             RGBColor[
              0.5672278134702158, 0.6590265795414552, 0.9594245069356807], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.7314071665190719, 0.7901001044758309, 0.9738634890361922], 
             UndirectedEdge[25, 154] -> 
             RGBColor[
              0.8295117017479037, 0.8654160422115112, 0.8764154627243679], 
             UndirectedEdge[100, 135] -> 
             RGBColor[
              0.9705380263923573, 0.9760585537944229, 0.868060149571487], 
             UndirectedEdge[37, 149] -> 
             RGBColor[
              0.7621635736658046, 0.8099774180288548, 0.8049195958633384], 
             UndirectedEdge[125, 149] -> 
             RGBColor[
              0.47693173808482076`, 0.5854413696590033, 0.9521838821913491], 
             UndirectedEdge[2, 184] -> 
             RGBColor[
              0.9908359773435669, 0.9896512594175609, 0.7414066876466316], 
             UndirectedEdge[6, 16] -> 
             RGBColor[
              0.8646587485026125, 0.8950091035303289, 0.9806485192701389], 
             UndirectedEdge[55, 111] -> 
             RGBColor[
              0.8941082952069476, 0.5238099401373273, 0.25283053179861553`], 
             UndirectedEdge[34, 50] -> 
             RGBColor[
              0.9647359221020078, 0.9719456706795985, 0.8874791413084422], 
             UndirectedEdge[56, 125] -> 
             RGBColor[
              0.6369132252196765, 0.7123856095859618, 0.9668859690155598], 
             UndirectedEdge[98, 196] -> 
             RGBColor[
              0.9442389561104314, 0.9575001470868836, 0.9642281721725763], 
             UndirectedEdge[160, 167] -> 
             RGBColor[
              0.5899561789041934, 0.6728175822467004, 0.9633888185458599], 
             UndirectedEdge[22, 149] -> 
             RGBColor[
              0.7511372299942223, 0.8040708703294839, 0.9437370274663803], 
             UndirectedEdge[147, 194] -> 
             RGBColor[
              0.8467478407465743, 0.880687208212552, 0.9621710288181136], 
             UndirectedEdge[83, 161] -> 
             RGBColor[
              0.9196162177623839, 0.9381295962703963, 0.9709963573470416], 
             UndirectedEdge[34, 177] -> 
             RGBColor[
              0.7797322613107316, 0.8284395358535315, 0.9769381443975709], 
             UndirectedEdge[70, 145] -> 
             RGBColor[
              0.9356808276474189, 0.946763326463987, 0.7437904205672312], 
             UndirectedEdge[125, 170] -> 
             RGBColor[
              0.654610065227925, 0.7264965894406139, 0.9685739094137021], 
             UndirectedEdge[190, 192] -> 
             RGBColor[
              0.5094659974009256, 0.6091388842832945, 0.9557045503521263], 
             UndirectedEdge[122, 188] -> 
             RGBColor[
              0.8326989225010824, 0.8683280926533474, 0.8958760866533572], 
             UndirectedEdge[123, 130] -> 
             RGBColor[
              0.9699801438496285, 0.9759689350588399, 0.8836235591687656], 
             UndirectedEdge[94, 116] -> 
             RGBColor[
              0.8832959187790096, 0.9081553097797004, 0.9145432129273642], 
             UndirectedEdge[23, 162] -> 
             RGBColor[
              0.9215820735503651, 0.9377597977326532, 0.8926524793144806], 
             UndirectedEdge[116, 160] -> 
             RGBColor[
              0.5702884096734242, 0.657452971443041, 0.9614285191146901], 
             UndirectedEdge[80, 117] -> 
             RGBColor[
              0.971418724321844, 0.9766970578561398, 0.8657489949106332], 
             UndirectedEdge[147, 185] -> 
             RGBColor[
              0.6310357363543777, 0.7020598034135159, 0.9454198386886808], 
             UndirectedEdge[55, 107] -> 
             RGBColor[
              0.8003723919814834, 0.8119351160736668, 0.6527230441805782], 
             UndirectedEdge[111, 174] -> 
             RGBColor[
              0.8822936875225464, 0.5471602104827586, 0.5691815329124669], 
             UndirectedEdge[126, 142] -> 
             RGBColor[
              0.7354139518082385, 0.7893492961617745, 0.866462185302863], 
             UndirectedEdge[115, 160] -> 
             RGBColor[
              0.4696650528939544, 0.5778511349375479, 0.9520789985970226], 
             UndirectedEdge[74, 164] -> 
             RGBColor[
              0.48389344625920555`, 0.5915148438124145, 0.9526154313596142], 
             UndirectedEdge[42, 97] -> 
             RGBColor[
              0.6842132782276837, 0.6649204101986685, 0.607698476923077], 
             UndirectedEdge[25, 108] -> 
             RGBColor[
              0.5850191143796549, 0.6736031850923763, 0.9607342894644926], 
             UndirectedEdge[67, 133] -> 
             RGBColor[
              0.35887120964925634`, 0.4838580671411443, 0.9441391901363236], 
             UndirectedEdge[38, 183] -> 
             RGBColor[
              0.8660194997108215, 0.8935696962557638, 0.8634348637423923], 
             UndirectedEdge[33, 41] -> 
             RGBColor[
              0.7675253552244394, 0.818431116297568, 0.9774328398030652], 
             UndirectedEdge[32, 123] -> 
             RGBColor[
              0.9578389185606155, 0.9680769150117177, 0.9562518928924443], 
             UndirectedEdge[61, 116] -> 
             RGBColor[
              0.8218634185001206, 0.8611291922122015, 0.9827827347808054], 
             UndirectedEdge[93, 134] -> 
             RGBColor[
              0.7499483557820832, 0.8045846224463529, 0.9757115015046642], 
             UndirectedEdge[45, 128] -> 
             RGBColor[
              0.7952319491333297, 0.7887221097266279, 0.6240263049223189], 
             UndirectedEdge[29, 35] -> 
             RGBColor[
              0.6874449958352229, 0.7542427484520646, 0.9705980817810221], 
             UndirectedEdge[3, 106] -> 
             RGBColor[
              0.7959013245274983, 0.8410459778970006, 0.9801423812942536], 
             UndirectedEdge[77, 140] -> 
             RGBColor[
              0.5094760599974908, 0.590335622541144, 0.9590522699580202], 
             UndirectedEdge[79, 195] -> 
             RGBColor[
              0.6729058905986789, 0.596978721653097, 0.593381539706841], 
             UndirectedEdge[38, 46] -> 
             RGBColor[
              0.987449654246062, 0.9885634357286592, 0.8346064574997192], 
             UndirectedEdge[14, 59] -> 
             RGBColor[
              0.8066233916135872, 0.8495899648947159, 0.981166520692176], 
             UndirectedEdge[126, 191] -> 
             RGBColor[
              0.9752389330188437, 0.9797423163157798, 0.8680665132253518], 
             UndirectedEdge[13, 64] -> 
             RGBColor[
              0.9626481158395123, 0.971663606467981, 0.9481111763388075], 
             UndirectedEdge[3, 11] -> 
             RGBColor[
              0.7959136710924046, 0.8410556231273428, 0.9801436118844583], 
             UndirectedEdge[31, 98] -> 
             RGBColor[
              0.9254169326114917, 0.9433663585636878, 0.9927482872335742], 
             UndirectedEdge[25, 162] -> 
             RGBColor[
              0.7597097562166499, 0.8124707552274553, 0.976615310570022], 
             UndirectedEdge[126, 157] -> 
             RGBColor[
              0.9282818084422448, 0.9428851631005501, 0.8838763732983158], 
             UndirectedEdge[128, 183] -> 
             RGBColor[
              0.686333378552374, 0.7547667033298718, 0.9694539674710775], 
             UndirectedEdge[22, 192] -> 
             RGBColor[
              0.8242153938304637, 0.8628854772532247, 0.9498411173716137], 
             UndirectedEdge[99, 194] -> 
             RGBColor[
              0.7172216463968508, 0.7790182683424057, 0.9724496089616318], 
             UndirectedEdge[21, 151] -> 
             RGBColor[
              0.8375105202234459, 0.8734044510953705, 0.9843285922027146], 
             UndirectedEdge[48, 59] -> 
             RGBColor[
              0.7884415392490054, 0.8350922493524333, 0.979432319382511], 
             UndirectedEdge[18, 115] -> 
             RGBColor[
              0.653983958541573, 0.7286224005420989, 0.966826342533388], 
             UndirectedEdge[29, 89] -> 
             RGBColor[
              0.6973644270728238, 0.7621522336651394, 0.9715442059876453], 
             UndirectedEdge[15, 140] -> 
             RGBColor[
              0.8084966971401117, 0.8504850166111475, 0.9815040671908025], 
             UndirectedEdge[113, 136] -> 
             RGBColor[
              0.9824632340155643, 0.9854730337035755, 0.8711909794862441], 
             UndirectedEdge[111, 160] -> 
             RGBColor[
              0.5895924481349626, 0.31098939213269616`, 0.5542483764091198], 
             UndirectedEdge[116, 188] -> 
             RGBColor[
              0.8841130900388242, 0.9084932310959772, 0.9010005703808064], 
             UndirectedEdge[82, 127] -> 
             RGBColor[
              0.9023578143906634, 0.9224475789386415, 0.8892806257891838], 
             UndirectedEdge[25, 95] -> 
             RGBColor[
              0.661626457358768, 0.7355868841267692, 0.9669084000848959], 
             UndirectedEdge[62, 111] -> 
             RGBColor[
              0.6149840783287484, 0.33298234598611215`, 0.5558663086321309], 
             UndirectedEdge[162, 180] -> 
             RGBColor[
              0.9234212216355683, 0.9385203327298346, 0.862173035979991], 
             UndirectedEdge[89, 159] -> 
             RGBColor[
              0.8545192587066888, 0.886834477858089, 0.9859860038054333], 
             UndirectedEdge[7, 153] -> 
             RGBColor[
              0.7580074050981545, 0.810932908990825, 0.9765008214086643], 
             UndirectedEdge[146, 183] -> 
             RGBColor[
              0.5539577382319062, 0.6450272753712295, 0.9596603340341696], 
             UndirectedEdge[144, 197] -> 
             RGBColor[
              0.9630709731299734, 0.9294844563501324, 0.6291085802864718], 
             UndirectedEdge[120, 128] -> 
             RGBColor[
              0.6777923489054221, 0.7480943860554436, 0.9686026774563294], 
             UndirectedEdge[74, 166] -> 
             RGBColor[
              0.7167357013262599, 0.7734723809018567, 0.850780973209549], 
             UndirectedEdge[147, 152] -> 
             RGBColor[
              0.9780576923136641, 0.9813904836759428, 0.8429614124106666], 
             UndirectedEdge[22, 190] -> 
             RGBColor[
              0.6577988032299497, 0.7253004798010891, 0.9372163497674979], 
             UndirectedEdge[27, 128] -> 
             RGBColor[
              0.4913894271401721, 0.5951208583694425, 0.9538906523630009], 
             UndirectedEdge[47, 88] -> 
             RGBColor[
              0.5840857331013422, 0.6728205145988877, 0.9606778410483721], 
             UndirectedEdge[69, 177] -> 
             RGBColor[
              0.7798246714069538, 0.8285084551519863, 0.9767817182090799], 
             UndirectedEdge[122, 167] -> 
             RGBColor[
              0.7469645247699507, 0.8022536309817194, 0.9754141011148612], 
             UndirectedEdge[1, 78] -> 
             RGBColor[
              0.8130733806099877, 0.8539896776518315, 0.9390331314263949], 
             UndirectedEdge[138, 159] -> 
             RGBColor[
              0.9195047532132723, 0.9343157391162358, 0.7787888404178311], 
             UndirectedEdge[101, 127] -> 
             RGBColor[
              0.8715152004279388, 0.9004383714355383, 0.9875933481625527], 
             UndirectedEdge[65, 90] -> 
             RGBColor[
              0.835856053895861, 0.8720784032142537, 0.956020501014798], 
             UndirectedEdge[64, 127] -> 
             RGBColor[
              0.8827758759727807, 0.9089976037714054, 0.974115283284922], 
             UndirectedEdge[117, 146] -> 
             RGBColor[
              0.6596262098393401, 0.7282659775239538, 0.9575123456829846], 
             UndirectedEdge[49, 103] -> 
             RGBColor[
              0.8587530005775263, 0.8904577703733791, 0.9863241637810547], 
             UndirectedEdge[88, 113] -> 
             RGBColor[
              0.737118801345374, 0.7926122825988877, 0.9405468544276825], 
             UndirectedEdge[13, 176] -> 
             RGBColor[
              0.9630173924396759, 0.9719390123517481, 0.9474860873774931], 
             UndirectedEdge[17, 112] -> 
             RGBColor[
              0.840513417563844, 0.8733039568563006, 0.8430789083410597], 
             UndirectedEdge[129, 170] -> 
             RGBColor[
              0.7135944467544992, 0.7751750942850253, 0.9729984537650437], 
             UndirectedEdge[35, 116] -> 
             RGBColor[
              0.811377815280967, 0.8527682568293655, 0.981782608585154], 
             UndirectedEdge[69, 110] -> 
             RGBColor[
              0.9659223939226977, 0.9724670126172246, 0.8691912810045378], 
             UndirectedEdge[47, 126] -> 
             RGBColor[
              0.8304619856305737, 0.8661079497318498, 0.8742220407784219], 
             UndirectedEdge[83, 137] -> 
             RGBColor[
              0.9724936461349538, 0.9787761642560237, 0.9211354239132654], 
             UndirectedEdge[72, 84] -> 
             RGBColor[
              0.7709386934682041, 0.8209824337792255, 0.9778036221993587], 
             UndirectedEdge[22, 37] -> 
             RGBColor[
              0.9835745433310701, 0.9849536204703904, 0.7925354851839433], 
             UndirectedEdge[90, 141] -> 
             RGBColor[
              0.8623697206107641, 0.8927910811632663, 0.9586631355286368], 
             UndirectedEdge[24, 79] -> 
             RGBColor[
              0.6036124608648807, 0.6871137646170988, 0.9632144959694916], 
             UndirectedEdge[34, 130] -> 
             RGBColor[
              0.9643984511069493, 0.9718061177505328, 0.8930719090435013], 
             UndirectedEdge[157, 174] -> 
             RGBColor[
              0.9058729334111406, 0.9274841617824934, 0.9805404473952255], 
             UndirectedEdge[131, 180] -> 
             RGBColor[
              0.9695993899912251, 0.9751129445359594, 0.8586516315592706], 
             UndirectedEdge[3, 48] -> 
             RGBColor[
              0.8817836070356249, 0.9085743291445623, 0.9885865016882185], 
             UndirectedEdge[49, 67] -> 
             RGBColor[
              0.6761353777286381, 0.7436602893396398, 0.9706270129358935], 
             UndirectedEdge[79, 190] -> 
             RGBColor[
              0.3951666200819968, 0.5166951974883638, 0.9464006454928711], 
             UndirectedEdge[13, 82] -> 
             RGBColor[
              0.982230054257395, 0.9851135816352172, 0.8632765188430693], 
             UndirectedEdge[68, 138] -> 
             RGBColor[
              0.8145947286537982, 0.852048182908014, 0.7684599451919734], 
             UndirectedEdge[153, 160] -> 
             RGBColor[
              0.5257008964945848, 0.6226208672700805, 0.9569844524950242], 
             UndirectedEdge[178, 183] -> 
             RGBColor[
              0.865022672854588, 0.8931574827334294, 0.8799548644553896], 
             UndirectedEdge[2, 166] -> 
             RGBColor[
              0.9905770547265185, 0.9903713842178372, 0.8058261191896451], 
             UndirectedEdge[32, 53] -> 
             RGBColor[
              0.7491966976524442, 0.8026816794395351, 0.9485789561024156], 
             UndirectedEdge[26, 184] -> 
             RGBColor[
              0.9495632489399664, 0.9585978742889627, 0.8071345579555046], 
             UndirectedEdge[61, 115] -> 
             RGBColor[
              0.7212400617206507, 0.7815273557067085, 0.9734332142631378], 
             UndirectedEdge[146, 178] -> 
             RGBColor[
              0.6807467060945596, 0.7427517098902138, 0.8650713038960212], 
             UndirectedEdge[88, 102] -> 
             RGBColor[
              0.7459811044746857, 0.7955310876474806, 0.6963870474745903], 
             UndirectedEdge[118, 159] -> 
             RGBColor[
              0.9180092986602697, 0.9349287644628634, 0.8930846617298364], 
             UndirectedEdge[62, 75] -> 
             RGBColor[
              0.39608799862052557`, 0.5174932492686055, 0.9464593549186031], 
             UndirectedEdge[89, 197] -> 
             RGBColor[
              0.9134966673408489, 0.9331546144562335, 0.9671044526856762], 
             UndirectedEdge[85, 146] -> 
             RGBColor[
              0.5795271165051696, 0.6650022680127753, 0.9622088507010231], 
             UndirectedEdge[170, 190] -> 
             RGBColor[
              0.6140661607077884, 0.6913794971411642, 0.9659904876692461], 
             UndirectedEdge[82, 101] -> 
             RGBColor[
              0.9602967071262944, 0.9685946883052143, 0.8948206328376782], 
             UndirectedEdge[7, 73] -> 
             RGBColor[
              0.6781025869030106, 0.7467852677974149, 0.9697163143956478], 
             UndirectedEdge[19, 34] -> 
             RGBColor[
              0.9452841271465516, 0.958713572131693, 0.977503879942428], 
             UndirectedEdge[56, 170] -> 
             RGBColor[
              0.8673860746069169, 0.8970941275965173, 0.9872132521923394], 
             UndirectedEdge[32, 187] -> 
             RGBColor[
              0.8489816948020925, 0.8823329372485111, 0.9573633459413744], 
             UndirectedEdge[74, 169] -> 
             RGBColor[
              0.53349392977618, 0.631782750807813, 0.9565201631146283], 
             UndirectedEdge[55, 147] -> 
             RGBColor[
              0.9660969005547637, 0.9420741190499358, 0.6459213313556476], 
             UndirectedEdge[49, 143] -> 
             RGBColor[
              0.7789838263172385, 0.8279496198787062, 0.9785046973257296], 
             UndirectedEdge[28, 77] -> 
             RGBColor[
              0.5851036003311726, 0.6480280765661639, 0.863837085674823], 
             UndirectedEdge[122, 153] -> 
             RGBColor[
              0.682709242360342, 0.7520569160050994, 0.9690097350640252], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.8207338775466442, 0.8601643839810451, 0.9826920197191575], 
             UndirectedEdge[16, 199] -> 
             RGBColor[
              0.888402120753562, 0.9117257991501208, 0.8960749305947103], 
             UndirectedEdge[64, 180] -> 
             RGBColor[
              0.9733050689348282, 0.9778766338246061, 0.852378883703609], 
             UndirectedEdge[38, 128] -> 
             RGBColor[
              0.8141191732712607, 0.8529033513711903, 0.8583449366199318], 
             UndirectedEdge[46, 98] -> 
             RGBColor[
              0.9499826929241327, 0.9617838165980361, 0.9545055239534624], 
             UndirectedEdge[68, 142] -> 
             RGBColor[
              0.5570383384216964, 0.651267843278731, 0.9582712449806745], 
             UndirectedEdge[5, 20] -> 
             RGBColor[
              0.9183643634375671, 0.9343228579900914, 0.8529692381038756], 
             UndirectedEdge[169, 200] -> 
             RGBColor[
              0.6691221655528767, 0.7412122368663363, 0.9678129947852077], 
             UndirectedEdge[27, 133] -> 
             RGBColor[
              0.3209755028126794, 0.45103471057290845`, 0.9417245092065547], 
             UndirectedEdge[32, 135] -> 
             RGBColor[
              0.9574143274096618, 0.9677602556265406, 0.9569706149599012], 
             UndirectedEdge[144, 190] -> 
             RGBColor[
              0.6530407941694365, 0.6792574480415741, 0.6269836090610077], 
             UndirectedEdge[62, 126] -> 
             RGBColor[
              0.7023676408823991, 0.7614165577869275, 0.8641657674476881], 
             UndirectedEdge[55, 62] -> 
             RGBColor[
              0.6917733735356959, 0.7226652861234395, 0.6444788404307464], 
             UndirectedEdge[62, 76] -> 
             RGBColor[
              0.6767215244161191, 0.743601227107013, 0.9663096468865613], 
             UndirectedEdge[157, 181] -> 
             RGBColor[
              0.7877000357766968, 0.8344361461115737, 0.9793788029172636], 
             UndirectedEdge[64, 82] -> 
             RGBColor[
              0.9715573826711363, 0.9771539206410813, 0.8813425679600473], 
             UndirectedEdge[142, 153] -> 
             RGBColor[
              0.58413883761421, 0.6725465594983435, 0.9608988025732101], 
             UndirectedEdge[21, 109] -> 
             RGBColor[
              0.6903985308554743, 0.7564425942899566, 0.9710584512018436], 
             UndirectedEdge[66, 198] -> 
             RGBColor[
              0.7464538801984809, 0.7980156547398323, 0.8549425862008528], 
             UndirectedEdge[141, 198] -> 
             RGBColor[
              0.8756829163279081, 0.9011613263478412, 0.8663249531100404], 
             UndirectedEdge[10, 28] -> 
             RGBColor[
              0.9278788462197668, 0.9427185278658987, 0.8905545001575816], 
             UndirectedEdge[31, 151] -> 
             RGBColor[
              0.8677902882499999, 0.8975487161973372, 0.9872167035081554], 
             UndirectedEdge[111, 142] -> 
             RGBColor[
              0.6480303892545878, 0.3609150843609592, 0.5581627264873058], 
             UndirectedEdge[111, 181] -> 
             RGBColor[
              0.7641207898881026, 0.4541121948118389, 0.5680198884345051], 
             UndirectedEdge[86, 101] -> 
             RGBColor[
              0.853506653419392, 0.886369957642435, 0.9857984244961808], 
             UndirectedEdge[119, 144] -> 
             RGBColor[
              0.8757155629536539, 0.860791761868809, 0.645215666103909], 
             UndirectedEdge[5, 102] -> 
             RGBColor[
              0.9170682498547759, 0.9315506020936857, 0.711895273302876], 
             UndirectedEdge[157, 185] -> 
             RGBColor[
              0.5826263768951557, 0.6641195758006422, 0.9636879536144074], 
             UndirectedEdge[13, 110] -> 
             RGBColor[
              0.9836877204889367, 0.9857163640822731, 0.8391192170671389], 
             UndirectedEdge[32, 82] -> 
             RGBColor[
              0.9790242293120217, 0.9827226826400144, 0.8687031442625299], 
             UndirectedEdge[12, 23] -> 
             RGBColor[
              0.9228886641065525, 0.9388016375757011, 0.8927771030881368], 
             UndirectedEdge[53, 130] -> 
             RGBColor[
              0.761337922941457, 0.8105736994866573, 0.8759506223787369], 
             UndirectedEdge[74, 80] -> 
             RGBColor[
              0.7164664543298487, 0.7733610403495084, 0.8552430927289748], 
             UndirectedEdge[35, 185] -> 
             RGBColor[
              0.5724099847490668, 0.6559733020199281, 0.9627135050112325], 
             UndirectedEdge[117, 196] -> 
             RGBColor[
              0.9595885943209077, 0.9693818203289124, 0.9532901482187937], 
             UndirectedEdge[22, 181] -> 
             RGBColor[
              0.8417353897178464, 0.8765722311973485, 0.9515873468279977], 
             UndirectedEdge[143, 197] -> 
             RGBColor[
              0.7964719388696855, 0.8411873179782334, 0.955665860107767], 
             UndirectedEdge[16, 124] -> 
             RGBColor[
              0.6905568089279573, 0.7574538471299084, 0.9702935059770903], 
             UndirectedEdge[182, 191] -> 
             RGBColor[
              0.7588443162619276, 0.810795323760083, 0.9568825776896492], 
             UndirectedEdge[98, 146] -> 
             RGBColor[
              0.6442765716288638, 0.716384304281925, 0.9684503696367672], 
             UndirectedEdge[156, 183] -> 
             RGBColor[
              0.5984033719654633, 0.6833811627809626, 0.9625317952543287], 
             UndirectedEdge[6, 13] -> 
             RGBColor[
              0.957995730052408, 0.9681938647655413, 0.9559864519398271], 
             UndirectedEdge[50, 100] -> 
             RGBColor[
              0.992511532801791, 0.9911713406157813, 0.7737668112135986], 
             UndirectedEdge[13, 175] -> 
             RGBColor[
              0.8587943633060615, 0.8898851526455598, 0.9525952289433712], 
             UndirectedEdge[62, 116] -> 
             RGBColor[
              0.5956800398672101, 0.6794459252964571, 0.9630464513377012], 
             UndirectedEdge[120, 171] -> 
             RGBColor[
              0.6364423211343941, 0.7145245707134003, 0.9653474518000514], 
             UndirectedEdge[72, 139] -> 
             RGBColor[
              0.8633766687282713, 0.893994952419457, 0.9868048740583644], 
             UndirectedEdge[6, 83] -> 
             RGBColor[
              0.9510401099911583, 0.9630063747126438, 0.9677605023872677], 
             UndirectedEdge[118, 190] -> 
             RGBColor[
              0.6669565283338927, 0.7310218927524496, 0.8720781393846152], 
             UndirectedEdge[36, 200] -> 
             RGBColor[
              0.6590578621404379, 0.7330415819644165, 0.9670206959538223], 
             UndirectedEdge[16, 161] -> 
             RGBColor[
              0.833234856273838, 0.8701323250880815, 0.9838843742299126], 
             UndirectedEdge[2, 169] -> 
             RGBColor[
              0.8073352831764387, 0.8486817541237934, 0.9115653090947243], 
             UndirectedEdge[107, 111] -> 
             RGBColor[
              0.7235830967745358, 0.42225217593633946`, 0.5641105123819627], 
             UndirectedEdge[127, 180] -> 
             RGBColor[
              0.904105500654355, 0.9231702921221663, 0.8603169415327454], 
             UndirectedEdge[138, 156] -> 
             RGBColor[
              0.7262137989561857, 0.7802965626639823, 0.7615022746561644], 
             UndirectedEdge[72, 93] -> 
             RGBColor[
              0.7730044091681807, 0.8225961865840681, 0.9780095134351217], 
             UndirectedEdge[137, 187] -> 
             RGBColor[
              0.8583159985178985, 0.8890642230905181, 0.9312529667659091], 
             UndirectedEdge[40, 121] -> 
             RGBColor[
              0.975011085440648, 0.9797754855172414, 0.8775473230838289], 
             UndirectedEdge[98, 178] -> 
             RGBColor[
              0.9553415062515456, 0.9645145116441249, 0.8887449000579872], 
             UndirectedEdge[10, 186] -> 
             RGBColor[
              0.9179731840001255, 0.9365085088594165, 0.9600578793988668], 
             UndirectedEdge[63, 91] -> 
             RGBColor[
              0.5694169290546096, 0.661317340803683, 0.9592457329795689], 
             UndirectedEdge[125, 195] -> 
             RGBColor[
              0.6613325818372302, 0.5869545032953418, 0.5926440987064366], 
             UndirectedEdge[86, 180] -> 
             RGBColor[
              0.8860969536458083, 0.909101878329063, 0.8585220178663735], 
             UndirectedEdge[137, 186] -> 
             RGBColor[
              0.9785233105948495, 0.9832730781375444, 0.9109287747710182], 
             UndirectedEdge[33, 44] -> 
             RGBColor[
              0.5997803802456722, 0.6807543557880524, 0.9642752873006879], 
             UndirectedEdge[14, 193] -> 
             RGBColor[
              0.8853472928300876, 0.911415915463393, 0.9889264092206341], 
             UndirectedEdge[11, 28] -> 
             RGBColor[
              0.8467620113292654, 0.8789898156086261, 0.8825649653753732], 
             UndirectedEdge[85, 151] -> 
             RGBColor[
              0.7964952723006637, 0.8409474274003361, 0.9803508631375704], 
             UndirectedEdge[175, 199] -> 
             RGBColor[
              0.8672126781836482, 0.895172445568776, 0.8939629649859404], 
             UndirectedEdge[146, 196] -> 
             RGBColor[
              0.6696441559534454, 0.7357373453329724, 0.9405545760106101], 
             UndirectedEdge[20, 77] -> 
             RGBColor[
              0.5870739080330578, 0.648790066876033, 0.8273472531900825], 
             UndirectedEdge[27, 56] -> 
             RGBColor[
              0.5990175183830997, 0.6795622530177259, 0.964471288085791], 
             UndirectedEdge[101, 175] -> 
             RGBColor[
              0.8368610161749612, 0.8733662593155569, 0.9841393429379801], 
             UndirectedEdge[21, 85] -> 
             RGBColor[
              0.8303877094612435, 0.8678400571925712, 0.9836186569923893], 
             UndirectedEdge[150, 194] -> 
             RGBColor[
              0.7988084321431959, 0.8431217066556518, 0.9804839680760007], 
             UndirectedEdge[61, 160] -> 
             RGBColor[
              0.6134409050966215, 0.6915280050345528, 0.965632968484355], 
             UndirectedEdge[24, 149] -> 
             RGBColor[
              0.644833674347568, 0.7207428444882888, 0.9664143109235135], 
             UndirectedEdge[14, 186] -> 
             RGBColor[
              0.9409081374174262, 0.9547962181616461, 0.9622454357300836], 
             UndirectedEdge[111, 126] -> 
             RGBColor[
              0.9047025625536507, 0.5625612118008154, 0.4725174588155572], 
             UndirectedEdge[35, 88] -> 
             RGBColor[
              0.6716891637669244, 0.741451454186874, 0.9693577249650911], 
             UndirectedEdge[94, 111] -> 
             RGBColor[
              0.9025999572405479, 0.5616917304693556, 0.5073630702217939], 
             UndirectedEdge[133, 162] -> 
             RGBColor[
              0.572906476556281, 0.6554597030682662, 0.962898642022137], 
             UndirectedEdge[124, 199] -> 
             RGBColor[
              0.7923121053553396, 0.8359259012883367, 0.8869991746893477], 
             UndirectedEdge[54, 105] -> 
             RGBColor[
              0.9866045710963018, 0.9874454819299823, 0.8058203363899424], 
             UndirectedEdge[64, 162] -> 
             RGBColor[
              0.902091596953994, 0.9243476443790736, 0.9759713777321675], 
             UndirectedEdge[57, 66] -> 
             RGBColor[
              0.7200637561117897, 0.7798926577887542, 0.9694165973399378], 
             UndirectedEdge[16, 137] -> 
             RGBColor[
              0.886112284646408, 0.9107788930737089, 0.9340234407961364], 
             UndirectedEdge[44, 50] -> 
             RGBColor[
              0.6785947367792289, 0.7408753601025996, 0.8644776039756097], 
             UndirectedEdge[153, 167] -> 
             RGBColor[
              0.7537911791288531, 0.8075866652513887, 0.9760945182226444], 
             UndirectedEdge[165, 187] -> 
             RGBColor[
              0.756886446433228, 0.8100047115944691, 0.976403025540627], 
             UndirectedEdge[32, 83] -> 
             RGBColor[
              0.9631593424191479, 0.9720448784140165, 0.9472458030887307], 
             UndirectedEdge[6, 187] -> 
             RGBColor[
              0.8368624623741029, 0.8732944335471383, 0.9778780452399114], 
             UndirectedEdge[66, 141] -> 
             RGBColor[
              0.6285626561782653, 0.7075662249437153, 0.9651108850802024], 
             UndirectedEdge[23, 87] -> 
             RGBColor[
              0.9775154385107965, 0.9816278191939505, 0.8726180716046354], 
             UndirectedEdge[85, 152] -> 
             RGBColor[
              0.8920958177350786, 0.9137543215121029, 0.8575820768172571], 
             UndirectedEdge[26, 74] -> 
             RGBColor[
              0.6722347332194698, 0.7410840356940134, 0.9700091298168203], 
             UndirectedEdge[81, 172] -> 
             RGBColor[
              0.815619136623144, 0.8562771255163597, 0.9821534598661249], 
             UndirectedEdge[54, 73] -> 
             RGBColor[
              0.7540006712785368, 0.8062064201508707, 0.9388899682771317], 
             UndirectedEdge[135, 165] -> 
             RGBColor[
              0.8653190790407974, 0.8954320299724986, 0.9760102945591538], 
             UndirectedEdge[46, 109] -> 
             RGBColor[
              0.7452440591946694, 0.799004317426272, 0.9357037992271727], 
             UndirectedEdge[40, 171] -> 
             RGBColor[
              0.7712983232190657, 0.818725313217476, 0.8794650425286403], 
             UndirectedEdge[113, 167] -> 
             RGBColor[
              0.8964752220901857, 0.9192936960450389, 0.9549320374789152], 
             UndirectedEdge[103, 162] -> 
             RGBColor[
              0.8207901055965978, 0.8601871883909193, 0.9827032289678973], 
             UndirectedEdge[37, 119] -> 
             RGBColor[
              0.8914999156857495, 0.9127413413276952, 0.8166309752073573], 
             UndirectedEdge[71, 184] -> 
             RGBColor[
              0.7237537326565102, 0.7786066563462742, 0.7867922260968958], 
             UndirectedEdge[107, 142] -> 
             RGBColor[
              0.5542944860291235, 0.6490402602972987, 0.9580552388692687], 
             UndirectedEdge[136, 143] -> 
             RGBColor[
              0.8099282992035522, 0.8502543940266365, 0.8895093816523666], 
             UndirectedEdge[3, 5] -> 
             RGBColor[
              0.8655457154988211, 0.895626675198939, 0.9870377170977012], 
             UndirectedEdge[24, 118] -> 
             RGBColor[
              0.8754023691167767, 0.9014404598811847, 0.8888919898612357], 
             UndirectedEdge[142, 185] -> 
             RGBColor[
              0.3897585202611493, 0.5105837088618667, 0.9462737656189546], 
             UndirectedEdge[3, 28] -> 
             RGBColor[
              0.9404318604254844, 0.9527279606510445, 0.891751817858731], 
             UndirectedEdge[43, 49] -> 
             RGBColor[
              0.9075762180841578, 0.9291406570728866, 0.9910466239553632], 
             UndirectedEdge[19, 60] -> 
             RGBColor[
              0.9113729106438864, 0.9317228471796124, 0.9759737570730616], 
             UndirectedEdge[87, 110] -> 
             RGBColor[
              0.9790645665638498, 0.982268423454663, 0.8469450107506538], 
             UndirectedEdge[107, 185] -> 
             RGBColor[
              0.46531122778109724`, 0.5719208004372469, 0.9522215515136117], 
             UndirectedEdge[66, 81] -> 
             RGBColor[
              0.6837840063108913, 0.7510955533256782, 0.970511341844128], 
             UndirectedEdge[63, 112] -> 
             RGBColor[
              0.6187895276618296, 0.7007340742864333, 0.9635879863214404], 
             UndirectedEdge[59, 193] -> 
             RGBColor[
              0.7816232858318852, 0.8296555591541803, 0.9787819882848594], 
             UndirectedEdge[110, 180] -> 
             RGBColor[
              0.9943446735842525, 0.9919293914388982, 0.7433869244319403], 
             UndirectedEdge[21, 196] -> 
             RGBColor[
              0.9205047489095193, 0.9385751345127682, 0.9619643823019763], 
             UndirectedEdge[24, 190] -> 
             RGBColor[
              0.5514952475832955, 0.6419724539598941, 0.9598936332246312], 
             UndirectedEdge[44, 60] -> 
             RGBColor[
              0.6175529122754044, 0.6949256904060306, 0.9659704472714105], 
             UndirectedEdge[20, 106] -> 
             RGBColor[
              0.8487199724662443, 0.879742160688153, 0.8460739023004281], 
             UndirectedEdge[75, 139] -> 
             RGBColor[
              0.649199106184702, 0.7206479563004115, 0.9687640291858388], 
             UndirectedEdge[4, 81] -> 
             RGBColor[
              0.8724111822811671, 0.9011010120530505, 0.9876925514482758], 
             UndirectedEdge[79, 197] -> 
             RGBColor[
              0.7051967990425339, 0.7669222057969222, 0.9485256167183351], 
             UndirectedEdge[66, 90] -> 
             RGBColor[
              0.733140684481337, 0.7896454095552574, 0.9472807686194493], 
             UndirectedEdge[14, 15] -> 
             RGBColor[
              0.8436578364485158, 0.8785215546719678, 0.9848577680467577], 
             UndirectedEdge[14, 48] -> 
             RGBColor[
              0.8921655462472078, 0.916852605661646, 0.9895767403182858], 
             UndirectedEdge[122, 144] -> 
             RGBColor[
              0.8194573847699504, 0.8168424454937095, 0.6396083766651234], 
             UndirectedEdge[80, 121] -> 
             RGBColor[
              0.9762126607254038, 0.9802723677765642, 0.857634111038268], 
             UndirectedEdge[79, 170] -> 
             RGBColor[
              0.6661833739893737, 0.7365208077983689, 0.9693113504141065], 
             UndirectedEdge[91, 95] -> 
             RGBColor[
              0.621571006738716, 0.7034487774645419, 0.963494792980687], 
             UndirectedEdge[48, 193] -> 
             RGBColor[
              0.8671654404655058, 0.8969181999211104, 0.9871922079109692], 
             UndirectedEdge[67, 162] -> 
             RGBColor[
              0.6381724827477094, 0.7133897073571801, 0.9670060781227361], 
             UndirectedEdge[65, 87] -> 
             RGBColor[
              0.8344194192267416, 0.8710069634302977, 0.9584523487752857], 
             UndirectedEdge[98, 121] -> 
             RGBColor[
              0.9390149463998858, 0.9536040891982895, 0.9730710579725856], 
             UndirectedEdge[161, 187] -> 
             RGBColor[
              0.8054385701453284, 0.8484176551048908, 0.9811139001996853], 
             UndirectedEdge[68, 122] -> 
             RGBColor[
              0.6556087431678285, 0.7307781997854869, 0.9663821774714897], 
             UndirectedEdge[19, 90] -> 
             RGBColor[
              0.9599553445530451, 0.9696553420515421, 0.9526693357395651], 
             UndirectedEdge[80, 168] -> 
             RGBColor[
              0.68639682051022, 0.7473162348786861, 0.8533270822515213], 
             UndirectedEdge[109, 194] -> 
             RGBColor[
              0.6207967875622196, 0.7016535831460973, 0.9642314874341584], 
             UndirectedEdge[44, 57] -> 
             RGBColor[
              0.6530584178150161, 0.7231054335114571, 0.9648018546584025], 
             UndirectedEdge[109, 151] -> 
             RGBColor[
              0.6565060936948945, 0.7295499644977215, 0.9677906573470247], 
             UndirectedEdge[122, 138] -> 
             RGBColor[
              0.8348685734874095, 0.8679938648579573, 0.7704070856767256], 
             UndirectedEdge[138, 192] -> 
             RGBColor[
              0.8348685734874095, 0.8679938648579573, 0.7704070856767256], 
             UndirectedEdge[31, 46] -> 
             RGBColor[
              0.9565282537497748, 0.9670030691258877, 0.9551298453883033], 
             UndirectedEdge[101, 165] -> 
             RGBColor[
              0.8560863669804326, 0.8883852494828691, 0.9860555462351515], 
             UndirectedEdge[76, 105] -> 
             RGBColor[
              0.9678639760696142, 0.9734687768439866, 0.8375432754401287], 
             UndirectedEdge[6, 199] -> 
             RGBColor[
              0.9664140449299947, 0.9734811576887574, 0.8973541879823963], 
             UndirectedEdge[83, 175] -> 
             RGBColor[
              0.8518387432448119, 0.8846976625926624, 0.9643692793908119], 
             UndirectedEdge[139, 182] -> 
             RGBColor[
              0.7390841316896595, 0.7956242722630367, 0.9752865061792213], 
             UndirectedEdge[89, 149] -> 
             RGBColor[
              0.6968049151445845, 0.7616979966760696, 0.9715001591590946], 
             UndirectedEdge[53, 163] -> 
             RGBColor[
              0.7035435016042532, 0.7670838836447531, 0.9721282498677293], 
             UndirectedEdge[8, 96] -> 
             RGBColor[
              0.6379697565266382, 0.7155029362130363, 0.9656466059834267], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.7588505381976702, 0.8115390750085016, 0.9765987878522255], 
             UndirectedEdge[55, 191] -> 
             RGBColor[
              0.9646446656721406, 0.9409910446522918, 0.6483795862084101], 
             UndirectedEdge[122, 181] -> 
             RGBColor[
              0.6934025838888224, 0.7604106356795539, 0.9700755474126261], 
             UndirectedEdge[130, 177] -> 
             RGBColor[
              0.8065253983168323, 0.8472589276689544, 0.8795079459674628], 
             UndirectedEdge[25, 131] -> 
             RGBColor[
              0.8058879245723067, 0.8490633670335802, 0.9730939061493017], 
             UndirectedEdge[19, 33] -> 
             RGBColor[
              0.8936003786141541, 0.9175515125616343, 0.974278597102339], 
             UndirectedEdge[1, 89] -> 
             RGBColor[
              0.9236261733090185, 0.9407091834217507, 0.9499578412798408], 
             UndirectedEdge[123, 127] -> 
             RGBColor[
              0.8811725036392573, 0.9078018113103448, 0.9768293744190981], 
             UndirectedEdge[40, 173] -> 
             RGBColor[
              0.9927169575783507, 0.9906422850475145, 0.7257307825409933], 
             UndirectedEdge[17, 106] -> 
             RGBColor[
              0.8486999526205796, 0.8796993402625932, 0.8438948656479953], 
             UndirectedEdge[51, 158] -> 
             RGBColor[
              0.9131636067631372, 0.8845680074865613, 0.640280727188697], 
             UndirectedEdge[20, 189] -> 
             RGBColor[
              0.9173072176726629, 0.9334799186526141, 0.852868406597094], 
             UndirectedEdge[48, 140] -> 
             RGBColor[
              0.8570044069388038, 0.8888160676008257, 0.9862230394623306], 
             UndirectedEdge[11, 189] -> 
             RGBColor[
              0.7708187206376977, 0.8210455908190433, 0.9777500331075616], 
             UndirectedEdge[40, 169] -> 
             RGBColor[
              0.8090927005984612, 0.8494084913913674, 0.8824403543613124], 
             UndirectedEdge[94, 167] -> 
             RGBColor[
              0.9029636880097788, 0.9235199205833599, 0.916503512358534], 
             UndirectedEdge[81, 198] -> 
             RGBColor[
              0.930904266460534, 0.944690654729804, 0.8717254098739662], 
             UndirectedEdge[34, 60] -> 
             RGBColor[
              0.9036940975981833, 0.9259960009830295, 0.988971984604243], 
             UndirectedEdge[13, 101] -> 
             RGBColor[
              0.9513874402946704, 0.9631043741321139, 0.9615892412164384], 
             UndirectedEdge[31, 117] -> 
             RGBColor[
              0.9407665708219681, 0.9552480318057166, 0.9818102632797916], 
             UndirectedEdge[94, 105] -> 
             RGBColor[
              0.9914074872227914, 0.9904146261924412, 0.7702450074074922], 
             UndirectedEdge[125, 190] -> 
             RGBColor[
              0.38359331132054814`, 0.5066709791306087, 0.9456632044924667], 
             UndirectedEdge[79, 119] -> 
             RGBColor[
              0.6178413888662144, 0.6982295113155987, 0.9646327025357724], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.9932505083642305, 0.9914241434421969, 0.7576833388649056], 
             UndirectedEdge[156, 178] -> 
             RGBColor[
              0.7251923398281167, 0.781105597299947, 0.8679427651161804], 
             UndirectedEdge[95, 131] -> 
             RGBColor[
              0.800302619152509, 0.8447000839897407, 0.972537215102703], 
             UndirectedEdge[49, 133] -> 
             RGBColor[
              0.6108693715372097, 0.6857302850507259, 0.9665195768352943], 
             UndirectedEdge[34, 44] -> 
             RGBColor[
              0.6514641287780697, 0.7219164153581111, 0.967500570140777], 
             UndirectedEdge[24, 125] -> 
             RGBColor[
              0.592039152103432, 0.6770895462593438, 0.9624770549690872], 
             UndirectedEdge[95, 129] -> 
             RGBColor[
              0.5990735654164018, 0.6851843411009053, 0.9617237119889515], 
             UndirectedEdge[13, 16] -> 
             RGBColor[
              0.8799838058759752, 0.9064385062269046, 0.9547071945521413], 
             UndirectedEdge[13, 199] -> 
             RGBColor[
              0.9817391023033575, 0.984910560385333, 0.8714128632643987], 
             UndirectedEdge[121, 196] -> 
             RGBColor[
              0.9643825307244676, 0.9729571302493369, 0.9451752643464285], 
             UndirectedEdge[26, 40] -> 
             RGBColor[
              0.9478335040417509, 0.9587097762775678, 0.8959293210635045], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.9023769978525906, 0.9238970200603374, 0.9524851445270042], 
             UndirectedEdge[54, 126] -> 
             RGBColor[
              0.9851806036677091, 0.9871567980077119, 0.8512378580198012], 
             UndirectedEdge[16, 193] -> 
             RGBColor[
              0.8234970056872827, 0.8623676273572749, 0.9829555693478852], 
             UndirectedEdge[85, 150] -> 
             RGBColor[
              0.8273949275136685, 0.8654536941044768, 0.9833332027785416], 
             UndirectedEdge[26, 169] -> 
             RGBColor[
              0.7660625547728381, 0.8176283689951952, 0.9772931794035973], 
             UndirectedEdge[22, 79] -> 
             RGBColor[
              0.709916016511535, 0.7704417904582939, 0.9405372125123583], 
             UndirectedEdge[27, 67] -> 
             RGBColor[
              0.3862415090041078, 0.5089647148618224, 0.9458319453071538], 
             UndirectedEdge[49, 95] -> 
             RGBColor[
              0.7920873457777808, 0.8383780541660756, 0.9796795543365807], 
             UndirectedEdge[147, 178] -> 
             RGBColor[
              0.9765539257064368, 0.9807686375388154, 0.8678827167156526], 
             UndirectedEdge[1, 136] -> 
             RGBColor[
              0.9866956310235219, 0.9886295484621961, 0.8640266353377031], 
             UndirectedEdge[65, 110] -> 
             RGBColor[
              0.8494095062149946, 0.8805480006780642, 0.8597006449370801], 
             UndirectedEdge[77, 106] -> 
             RGBColor[
              0.4405730644331865, 0.5363460938121201, 0.9522276491103456], 
             UndirectedEdge[25, 64] -> 
             RGBColor[
              0.8095936035159098, 0.851827056322227, 0.9668211582936401], 
             UndirectedEdge[82, 187] -> 
             RGBColor[
              0.8610967865790898, 0.8902141504168143, 0.8851681121431536], 
             UndirectedEdge[167, 188] -> 
             RGBColor[
              0.9037808592695934, 0.9238578418996366, 0.9029608698119762], 
             UndirectedEdge[13, 137] -> 
             RGBColor[
              0.9794492661962035, 0.9839636543089211, 0.9093613734658248], 
             UndirectedEdge[37, 125] -> 
             RGBColor[
              0.7093690514216686, 0.7663241197999098, 0.800982339908912], 
             UndirectedEdge[105, 182] -> 
             RGBColor[
              0.7771154757789782, 0.8223371149682043, 0.824215460465553], 
             UndirectedEdge[111, 116] -> 
             RGBColor[
              0.7980149615384617, 0.4805905793103449, 0.5713981427055703], 
             UndirectedEdge[146, 179] -> 
             RGBColor[
              0.6139857133221458, 0.6922311960915931, 0.965561200530504], 
             UndirectedEdge[9, 63] -> 
             RGBColor[
              0.7734178515457859, 0.8196017926499684, 0.8443389729914066], 
             UndirectedEdge[38, 120] -> 
             RGBColor[
              0.8574784700638696, 0.8868973789813355, 0.8625835737276443], 
             UndirectedEdge[71, 81] -> 
             RGBColor[
              0.66070935911108, 0.7323588856558343, 0.9686958239529064], 
             UndirectedEdge[68, 181] -> 
             RGBColor[
              0.6731287390552112, 0.7444649537296106, 0.9681284069278737], 
             UndirectedEdge[114, 158] -> 
             RGBColor[
              0.6187511463452299, 0.6960310230299669, 0.966015731786398], 
             UndirectedEdge[118, 149] -> 
             RGBColor[
              0.7602949550981654, 0.8097922832808442, 0.8785988170834975], 
             UndirectedEdge[87, 162] -> 
             RGBColor[
              0.9081411146151654, 0.9288593647455993, 0.9657311222987044], 
             UndirectedEdge[88, 122] -> 
             RGBColor[
              0.587608104025139, 0.6755722175355683, 0.9610289180636284], 
             UndirectedEdge[49, 162] -> 
             RGBColor[
              0.8901706446356628, 0.9152619252667618, 0.9893864648217069], 
             UndirectedEdge[47, 116] -> 
             RGBColor[
              0.7237743846153848, 0.7841373172413794, 0.973102724668435], 
             UndirectedEdge[23, 95] -> 
             RGBColor[
              0.8234987746924832, 0.860875926631967, 0.8829455688293544], 
             UndirectedEdge[54, 115] -> 
             RGBColor[
              0.7778696458730501, 0.8255843290117484, 0.9407690213921467], 
             UndirectedEdge[62, 105] -> 
             RGBColor[
              0.7037916083109919, 0.7617052417091978, 0.8187482458178292], 
             UndirectedEdge[13, 108] -> 
             RGBColor[
              0.7380736267032574, 0.7934397352381303, 0.9420243075096602], 
             UndirectedEdge[76, 182] -> 
             RGBColor[
              0.7500453918841054, 0.8042331003660195, 0.971776861534285], 
             UndirectedEdge[117, 171] -> 
             RGBColor[
              0.7506518223887799, 0.8044355901405529, 0.9640507534636146], 
             UndirectedEdge[40, 46] -> 
             RGBColor[
              0.9859788319648949, 0.9879552129169882, 0.8589817890647057], 
             UndirectedEdge[19, 177] -> 
             RGBColor[
              0.7874110743564346, 0.8341663820501144, 0.9639399168663894], 
             UndirectedEdge[64, 87] -> 
             RGBColor[
              0.9580249619144252, 0.9682156658403709, 0.9559369700223225], 
             UndirectedEdge[62, 107] -> 
             RGBColor[
              0.5212481751032841, 0.6211075219224516, 0.9557588210140937], 
             UndirectedEdge[53, 148] -> 
             RGBColor[
              0.7344973091886733, 0.7917188995912944, 0.9734611865570605], 
             UndirectedEdge[76, 111] -> 
             RGBColor[
              0.8790564460873707, 0.5447458811209009, 0.5746613382544303], 
             UndirectedEdge[11, 48] -> 
             RGBColor[
              0.7881137579394057, 0.8348361841021439, 0.9793996492048607], 
             UndirectedEdge[96, 111] -> 
             RGBColor[
              0.677512404030671, 0.38484991210581376`, 0.5604836586866576], 
             UndirectedEdge[168, 198] -> 
             RGBColor[
              0.686550490465839, 0.7473797813544725, 0.8507803734018176], 
             UndirectedEdge[118, 128] -> 
             RGBColor[
              0.8126483509900936, 0.8522951285595193, 0.8827202681849183], 
             UndirectedEdge[56, 129] -> 
             RGBColor[
              0.6958976067462508, 0.7610641144303731, 0.9713105133669013], 
             UndirectedEdge[53, 100] -> 
             RGBColor[
              0.7623203966351395, 0.8109799776074174, 0.8596684907140013], 
             UndirectedEdge[129, 143] -> 
             RGBColor[
              0.5859700459558594, 0.674755906813536, 0.9605488549781005], 
             UndirectedEdge[18, 160] -> 
             RGBColor[
              0.5461848019175437, 0.6386230498699432, 0.9590260967546052], 
             UndirectedEdge[68, 111] -> 
             RGBColor[
              0.7263269491671087, 0.4244797589177718, 0.5643265184933687], 
             UndirectedEdge[51, 166] -> 
             RGBColor[
              0.9761559933687003, 0.9317009078691425, 0.5228162985853229], 
             UndirectedEdge[107, 181] -> 
             RGBColor[
              0.6703848866626383, 0.7422373707481784, 0.9679124008164679], 
             UndirectedEdge[31, 173] -> 
             RGBColor[
              0.9632663793632306, 0.9696901412564141, 0.821878838864591], 
             UndirectedEdge[135, 148] -> 
             RGBColor[
              0.9427149389458911, 0.9567974757782999, 0.9818528454145461], 
             UndirectedEdge[44, 177] -> 
             RGBColor[
              0.4935910759879527, 0.5973692252765326, 0.9539366070647384], 
             UndirectedEdge[80, 184] -> 
             RGBColor[
              0.9937949700503452, 0.9908748789444577, 0.6923685208676591], 
             UndirectedEdge[65, 162] -> 
             RGBColor[
              0.7784860542663103, 0.8271389419690005, 0.9784867564851307], 
             UndirectedEdge[5, 17] -> 
             RGBColor[
              0.9183443435919025, 0.9342800375645316, 0.8507902014514428], 
             UndirectedEdge[44, 141] -> 
             RGBColor[
              0.5615573178814917, 0.6507790006664183, 0.9604961423986672], 
             UndirectedEdge[94, 174] -> 
             RGBColor[
              0.9675746447630943, 0.9747249409521141, 0.9123266031342607], 
             UndirectedEdge[161, 193] -> 
             RGBColor[
              0.8700850376349409, 0.899246207453664, 0.9874706816953449], 
             UndirectedEdge[101, 124] -> 
             RGBColor[
              0.7619604433466525, 0.8141197150351176, 0.9771755526413874], 
             UndirectedEdge[106, 189] -> 
             RGBColor[
              0.7708063740727915, 0.8210359455887011, 0.9777488025173569], 
             UndirectedEdge[2, 80] -> 
             RGBColor[
              0.9903078077301072, 0.9902600436654889, 0.8102882387090709], 
             UndirectedEdge[97, 102] -> 
             RGBColor[
              0.9638147944502666, 0.8833246385658343, 0.35280202976839337`], 
             UndirectedEdge[91, 136] -> 
             RGBColor[
              0.7885616734638403, 0.832908004695618, 0.8878273226056075], 
             UndirectedEdge[59, 154] -> 
             RGBColor[
              0.847355512666313, 0.8793557629189586, 0.8781939670368213], 
             UndirectedEdge[108, 162] -> 
             RGBColor[
              0.6775171078177391, 0.7461237731492228, 0.9698845089030201], 
             UndirectedEdge[146, 147] -> 
             RGBColor[
              0.6654889910837551, 0.7326384301766153, 0.9475881862944326], 
             UndirectedEdge[99, 156] -> 
             RGBColor[
              0.5804084304675888, 0.6693233777162022, 0.96073822765811], 
             UndirectedEdge[143, 154] -> 
             RGBColor[
              0.8108228768675635, 0.8506243248803025, 0.8746839146669182], 
             UndirectedEdge[139, 145] -> 
             RGBColor[
              0.8985252508796622, 0.9219236615059817, 0.9901833346235045], 
             UndirectedEdge[104, 123] -> 
             RGBColor[
              0.6789970884081085, 0.7450923167414956, 0.9594509355813605], 
             UndirectedEdge[116, 126] -> 
             RGBColor[
              0.8853985240921124, 0.9090247911111602, 0.8796976015211275], 
             UndirectedEdge[17, 28] -> 
             RGBColor[
              0.9932304885185659, 0.9913813230166371, 0.7555043022124728], 
             UndirectedEdge[89, 118] -> 
             RGBColor[
              0.927373609913793, 0.9423956120689655, 0.8939778380968169], 
             UndirectedEdge[123, 163] -> 
             RGBColor[
              0.9121857225124246, 0.9324791192169356, 0.979801186657758], 
             UndirectedEdge[47, 157] -> 
             RGBColor[
              0.7666576689655172, 0.8179976892307692, 0.9772814964456233], 
             UndirectedEdge[117, 151] -> 
             RGBColor[
              0.8765943656348343, 0.9042111369115147, 0.9756543581195319], 
             UndirectedEdge[69, 86] -> 
             RGBColor[
              0.8576746739842536, 0.8896394995073893, 0.984326374438971], 
             UndirectedEdge[73, 94] -> 
             RGBColor[
              0.7588035874050263, 0.8091755644133297, 0.9033146392946816], 
             UndirectedEdge[61, 174] -> 
             RGBColor[
              0.9061421444842053, 0.9276988233846153, 0.9805661249877019], 
             UndirectedEdge[175, 187] -> 
             RGBColor[
              0.7376610956277565, 0.794985721427157, 0.9744868222434555], 
             UndirectedEdge[75, 134] -> 
             RGBColor[
              0.5706483497410262, 0.6584842385463171, 0.9611469255150127], 
             UndirectedEdge[38, 178] -> 
             RGBColor[
              0.9928084675734747, 0.991294130774748, 0.768845833604244], 
             UndirectedEdge[8, 179] -> 
             RGBColor[
              0.7982616800821742, 0.8426369689348088, 0.9804447610898726], 
             UndirectedEdge[29, 167] -> 
             RGBColor[
              0.6744458728619485, 0.7438932610470483, 0.9693540580381785], 
             UndirectedEdge[68, 185] -> 
             RGBColor[
              0.46805508017367015`, 0.5741483834186792, 0.9524375576250175], 
             UndirectedEdge[79, 118] -> 
             RGBColor[
              0.719073741615478, 0.7761632034096542, 0.8753990021294756], 
             UndirectedEdge[171, 173] -> 
             RGBColor[
              0.7731516309300424, 0.8188776995912503, 0.804119329048414], 
             UndirectedEdge[80, 166] -> 
             RGBColor[
              0.9935360474332969, 0.991595003744734, 0.7567879524106724], 
             UndirectedEdge[109, 132] -> 
             RGBColor[
              0.46223357150741295`, 0.5732626222257082, 0.9510947906150192], 
             UndirectedEdge[118, 197] -> 
             RGBColor[
              0.9769867072944297, 0.9812489010610079, 0.8742031106100793], 
             UndirectedEdge[111, 167] -> 
             RGBColor[
              0.8176827307692309, 0.4959551901140043, 0.5733584421367401], 
             UndirectedEdge[113, 122] -> 
             RGBColor[
              0.8253932853216747, 0.8637639467987496, 0.947847254320296], 
             UndirectedEdge[119, 190] -> 
             RGBColor[
              0.5657241755846291, 0.6530882006583941, 0.961311839790912], 
             UndirectedEdge[19, 130] -> 
             RGBColor[
              0.9720772641526524, 0.9775329639471158, 0.8800736815123199], 
             UndirectedEdge[35, 167] -> 
             RGBColor[
              0.8310455845117362, 0.8681328676330249, 0.9837429080163238], 
             UndirectedEdge[102, 112] -> 
             RGBColor[
              0.8392373238267175, 0.8705745213854545, 0.704183980192493], 
             UndirectedEdge[134, 145] -> 
             RGBColor[
              0.8199744944359864, 0.8597599437518874, 0.9825662309526784], 
             UndirectedEdge[109, 150] -> 
             RGBColor[
              0.6874057489078993, 0.7540562312018622, 0.970772996987996], 
             UndirectedEdge[147, 179] -> 
             RGBColor[
              0.9097929329340231, 0.9302481237401947, 0.9683726133501356], 
             UndirectedEdge[63, 102] -> 
             RGBColor[
              0.7721807927356452, 0.8168011748602333, 0.6984495829071136], 
             UndirectedEdge[62, 182] -> 
             RGBColor[
              0.4859730241254831, 0.5924695652312307, 0.9529818319119856], 
             UndirectedEdge[8, 99] -> 
             RGBColor[
              0.7202387634940601, 0.7813752631496849, 0.9727503269973192], 
             UndirectedEdge[60, 123] -> 
             RGBColor[
              0.9092757903408624, 0.9301588182913365, 0.9795236347295072], 
             UndirectedEdge[7, 97] -> 
             RGBColor[
              0.8807399567385323, 0.8222417614396478, 0.6249349867020705], 
             UndirectedEdge[130, 163] -> 
             RGBColor[
              0.9333971667758463, 0.9471356937240514, 0.8918193381023856], 
             UndirectedEdge[127, 135] -> 
             RGBColor[
              0.8807479124883035, 0.9074851519251678, 0.977548096486555], 
             UndirectedEdge[37, 56] -> 
             RGBColor[
              0.9221450608006604, 0.9369216579558133, 0.8196216826875492], 
             UndirectedEdge[100, 148] -> 
             RGBColor[
              0.9653334480539489, 0.9721769877913526, 0.8768701431269813], 
             UndirectedEdge[53, 135] -> 
             RGBColor[
              0.7397018875270817, 0.7956004655943645, 0.9646511930015662], 
             UndirectedEdge[103, 154] -> 
             RGBColor[
              0.8905920511278513, 0.9131324753749753, 0.8825033811222431], 
             UndirectedEdge[63, 140] -> 
             RGBColor[
              0.6958790582828694, 0.76111898642175, 0.9712285644760507], 
             UndirectedEdge[8, 75] -> 
             RGBColor[
              0.5588802727877444, 0.6492909273897159, 0.9599739935832412], 
             UndirectedEdge[50, 53] -> 
             RGBColor[
              0.7616753939365155, 0.810713252415723, 0.8703578546436778], 
             UndirectedEdge[1, 167] -> 
             RGBColor[
              0.9007076190981433, 0.9224502108036594, 0.947767693330374], 
             UndirectedEdge[27, 119] -> 
             RGBColor[
              0.5683723732681888, 0.6553819363896078, 0.961480580605599], 
             UndirectedEdge[96, 126] -> 
             RGBColor[
              0.7648959665843217, 0.8132841239066291, 0.8687831175022148], 
             UndirectedEdge[102, 106] -> 
             RGBColor[
              0.8474238588834531, 0.8769699047917473, 0.7049999374994286], 
             UndirectedEdge[16, 176] -> 
             RGBColor[
              0.8696804108898804, 0.8987542511165358, 0.9721481547078047], 
             UndirectedEdge[40, 166] -> 
             RGBColor[
              0.9923344721485411, 0.9910981214854111, 0.7767011644562332], 
             UndirectedEdge[33, 90] -> 
             RGBColor[
              0.9005927829749445, 0.9227664362849006, 0.9624422804306576], 
             UndirectedEdge[13, 161] -> 
             RGBColor[
              0.9265718378236335, 0.9433170863232937, 0.959222306899601], 
             UndirectedEdge[11, 106] -> 
             RGBColor[
              0.7022314754312793, 0.7673078328545823, 0.9709555288108958], 
             UndirectedEdge[88, 167] -> 
             RGBColor[
              0.65869004079365, 0.7311019667818576, 0.9681137012222475], 
             UndirectedEdge[29, 159] -> 
             RGBColor[
              0.6880001158193003, 0.7546853860590375, 0.970651029620665], 
             UndirectedEdge[156, 157] -> 
             RGBColor[
              0.6615252653580902, 0.7330520899734748, 0.9687277624403183], 
             UndirectedEdge[171, 183] -> 
             RGBColor[
              0.644983350781346, 0.7211968879878285, 0.9661987418147995], 
             UndirectedEdge[100, 104] -> 
             RGBColor[
              0.7011910063652127, 0.7601551693693713, 0.8551869553612527], 
             UndirectedEdge[108, 180] -> 
             RGBColor[
              0.7487305797985733, 0.7996527625947554, 0.8462920148744615], 
             UndirectedEdge[178, 179] -> 
             RGBColor[
              0.9250506479448275, 0.940361403453793, 0.8858557309517241], 
             UndirectedEdge[150, 151] -> 
             RGBColor[
              0.8345177382758708, 0.871018088007276, 0.984043137988867], 
             UndirectedEdge[2, 121] -> 
             RGBColor[
              0.9732536680186252, 0.9790487482496675, 0.9066722778172407], 
             UndirectedEdge[12, 14] -> 
             RGBColor[
              0.8825841646894491, 0.9092126720871632, 0.9886628595919065], 
             UndirectedEdge[43, 131] -> 
             RGBColor[
              0.915791491458886, 0.9354626868965519, 0.9839042847214854], 
             UndirectedEdge[75, 76] -> 
             RGBColor[
              0.6601603663791478, 0.7292567844033943, 0.9652543845409025], 
             UndirectedEdge[113, 138] -> 
             RGBColor[
              0.9843792708076444, 0.9850339299212767, 0.7499250220407797], 
             UndirectedEdge[17, 20] -> 
             RGBColor[
              0.995200796220451, 0.9921433133265063, 0.7190144697277323], 
             UndirectedEdge[86, 187] -> 
             RGBColor[
              0.7543067328721873, 0.8079894197540349, 0.9761459038016562], 
             UndirectedEdge[8, 185] -> 
             RGBColor[
              0.5195044835025289, 0.61444864860813, 0.9574919864284178], 
             UndirectedEdge[4, 41] -> 
             RGBColor[
              0.7887004327011077, 0.8353155482952972, 0.9794525375960046], 
             UndirectedEdge[8, 107] -> 
             RGBColor[
              0.684040449270503, 0.7529052000435621, 0.9692734596787318], 
             UndirectedEdge[149, 192] -> 
             RGBColor[
              0.6028044241651982, 0.6879092748116893, 0.9622252280510086], 
             UndirectedEdge[11, 140] -> 
             RGBColor[
              0.7711344709955836, 0.8212973615836062, 0.9777801496585704], 
             UndirectedEdge[94, 153] -> 
             RGBColor[
              0.8387084056001701, 0.8733232056067399, 0.9100991463076982], 
             UndirectedEdge[56, 79] -> 
             RGBColor[
              0.6484865339811252, 0.7224098279437168, 0.9676234100159642], 
             UndirectedEdge[5, 15] -> 
             RGBColor[
              0.8092380925471303, 0.8510761851840619, 0.9815747821465755], 
             UndirectedEdge[79, 128] -> 
             RGBColor[
              0.5408584427381977, 0.6379684332954334, 0.9570427742931742], 
             UndirectedEdge[109, 152] -> 
             RGBColor[
              0.7521066391293094, 0.8023568586094882, 0.8450218710267114], 
             UndirectedEdge[118, 192] -> 
             RGBColor[
              0.8333731189344068, 0.8686068902045851, 0.8847029069887309], 
             UndirectedEdge[99, 107] -> 
             RGBColor[
              0.6660455077726286, 0.7388474149788017, 0.9674798920825131], 
             UndirectedEdge[3, 189] -> 
             RGBColor[
              0.8644885697339169, 0.8947837358614616, 0.9869368855909194], 
             UndirectedEdge[35, 138] -> 
             RGBColor[
              0.9189496332291949, 0.933873101509263, 0.7787358925781883], 
             UndirectedEdge[12, 86] -> 
             RGBColor[
              0.8161900722211615, 0.8566147287265784, 0.9822391356685882], 
             UndirectedEdge[16, 127] -> 
             RGBColor[
              0.8001115660092437, 0.843772503530329, 0.9807113014982556], 
             UndirectedEdge[37, 195] -> 
             RGBColor[
              0.946564417418214, 0.8114905516651933, 0.445379812378426], 
             UndirectedEdge[57, 71] -> 
             RGBColor[
              0.6969891089119784, 0.7611559901189102, 0.9676010794487162], 
             UndirectedEdge[58, 73] -> 
             RGBColor[
              0.7354755806328943, 0.7923904378794027, 0.9702481146227528], 
             UndirectedEdge[35, 153] -> 
             RGBColor[
              0.7667903021021275, 0.8179361526564051, 0.977338541965488], 
             UndirectedEdge[35, 122] -> 
             RGBColor[
              0.7599636477432251, 0.8126031183867357, 0.9766581248577046], 
             UndirectedEdge[19, 44] -> 
             RGBColor[
              0.6591429418237728, 0.727643261554694, 0.9545023426095955], 
             UndirectedEdge[181, 192] -> 
             RGBColor[
              0.6934025838888224, 0.7604106356795539, 0.9700755474126261], 
             UndirectedEdge[119, 128] -> 
             RGBColor[
              0.7114159982408299, 0.7743614364654638, 0.9719539685912151], 
             UndirectedEdge[116, 153] -> 
             RGBColor[
              0.7341234098980839, 0.7922220544477292, 0.9741342187914745], 
             UndirectedEdge[186, 193] -> 
             RGBColor[
              0.9159080316357242, 0.9348618124211104, 0.959860903322767], 
             UndirectedEdge[22, 119] -> 
             RGBColor[
              0.8804735720141672, 0.9068347936283243, 0.9554484068103992], 
             UndirectedEdge[85, 109] -> 
             RGBColor[
              0.6493832829326922, 0.7239855705949223, 0.9670807221366995], 
             UndirectedEdge[98, 99] -> 
             RGBColor[
              0.8105575968910177, 0.8527322920603804, 0.9815403625999168], 
             UndirectedEdge[161, 175] -> 
             RGBColor[
              0.8120454137039244, 0.8535789715067368, 0.9817724086211428], 
             UndirectedEdge[54, 61] -> 
             RGBColor[
              0.9216454980757173, 0.9392611991087533, 0.9543229912794791], 
             UndirectedEdge[43, 154] -> 
             RGBColor[
              0.9394152686344828, 0.9518153620744829, 0.8872258412965517], 
             UndirectedEdge[87, 95] -> 
             RGBColor[
              0.8100578157572835, 0.8519754936449131, 0.9560242118135782], 
             UndirectedEdge[12, 108] -> 
             RGBColor[
              0.6788236983739264, 0.7471656129922708, 0.9700091326766764], 
             UndirectedEdge[15, 48] -> 
             RGBColor[
              0.8254759840839341, 0.8640238391296853, 0.9831235667370928], 
             UndirectedEdge[13, 187] -> 
             RGBColor[
              0.8521875197474658, 0.884723836243714, 0.9519367205219138], 
             UndirectedEdge[15, 28] -> 
             RGBColor[
              0.8841242374737937, 0.9081774706361674, 0.8862888829076053], 
             UndirectedEdge[52, 134] -> 
             RGBColor[
              0.8643588039061669, 0.894344968151228, 0.9588613887624822], 
             UndirectedEdge[66, 172] -> 
             RGBColor[
              0.6311687503610909, 0.709602125526388, 0.9653706361930117], 
             UndirectedEdge[101, 176] -> 
             RGBColor[
              0.9410840453085754, 0.9554201190217452, 0.9790302013721018], 
             UndirectedEdge[119, 192] -> 
             RGBColor[
              0.7321407661851431, 0.7906731981105297, 0.9739366073950275], 
             UndirectedEdge[168, 184] -> 
             RGBColor[
              0.6869249901236796, 0.7467074506307583, 0.7844455311890821], 
             UndirectedEdge[16, 175] -> 
             RGBColor[
              0.765457381756266, 0.8167003914103477, 0.977257296273683], 
             UndirectedEdge[60, 104] -> 
             RGBColor[
              0.6395041791627641, 0.713938774481108, 0.9673691625867298], 
             UndirectedEdge[122, 136] -> 
             RGBColor[
              0.8329525366953292, 0.8684329686402561, 0.89167304312219], 
             UndirectedEdge[107, 157] -> 
             RGBColor[
              0.74716234266313, 0.8025761272360743, 0.9754694268647215], 
             UndirectedEdge[86, 110] -> 
             RGBColor[
              0.8858069336136584, 0.9089819475925942, 0.8633284003468813], 
             UndirectedEdge[5, 9] -> 
             RGBColor[
              0.9183053086649167, 0.9343512198834207, 0.8577846633871692], 
             UndirectedEdge[3, 77] -> 
             RGBColor[
              0.5342552600943118, 0.6100938840848806, 0.9614157321839081], 
             UndirectedEdge[84, 139] -> 
             RGBColor[
              0.8264333965257824, 0.8651345873956047, 0.9831227139397276], 
             UndirectedEdge[96, 191] -> 
             RGBColor[
              0.7480487744958639, 0.8020310166207782, 0.9560327130964522], 
             UndirectedEdge[46, 151] -> 
             RGBColor[
              0.892356048562641, 0.9159661742316858, 0.9489739402280437], 
             UndirectedEdge[72, 191] -> 
             RGBColor[
              0.8831368533005395, 0.9091660039165034, 0.9684009455687923], 
             UndirectedEdge[111, 185] -> 
             RGBColor[
              0.5590471310065616, 0.28379562450090745`, 0.5523290391316488], 
             UndirectedEdge[23, 129] -> 
             RGBColor[
              0.7665311881699147, 0.8148366666499427, 0.8783175717800087], 
             UndirectedEdge[101, 123] -> 
             RGBColor[
              0.9391113963748884, 0.9539489206769176, 0.9823693814675926], 
             UndirectedEdge[122, 142] -> 
             RGBColor[
              0.5773121832553076, 0.6672135252286743, 0.9602183854654268], 
             UndirectedEdge[18, 174] -> 
             RGBColor[
              0.8388860413051276, 0.8747938682200058, 0.9739592532579521], 
             UndirectedEdge[123, 135] -> 
             RGBColor[
              0.9483441084352531, 0.9609957011665471, 0.9723241297915949], 
             UndirectedEdge[171, 178] -> 
             RGBColor[
              0.7717723186439993, 0.8189213225068128, 0.8716097116766511], 
             UndirectedEdge[81, 173] -> 
             RGBColor[
              0.9314023289311358, 0.9442826123684693, 0.8188396172890042], 
             UndirectedEdge[77, 102] -> 
             RGBColor[
              0.5857777944502665, 0.6460178109796273, 0.686273288389083], 
             UndirectedEdge[31, 171] -> 
             RGBColor[
              0.7418477450039456, 0.7977731694263757, 0.975613098852238], 
             UndirectedEdge[109, 196] -> 
             RGBColor[
              0.7395003223809681, 0.7947206479151193, 0.9454264474462866], 
             UndirectedEdge[18, 153] -> 
             RGBColor[
              0.7100198021422033, 0.7733921328746315, 0.9717317964313895], 
             UndirectedEdge[97, 140] -> 
             RGBColor[
              0.8875130599974907, 0.827642450127351, 0.6255810113373306], 
             UndirectedEdge[116, 167] -> 
             RGBColor[
              0.7983786923076925, 0.8424187694243492, 0.9805385848423104], 
             UndirectedEdge[128, 190] -> 
             RGBColor[
              0.48874122945661236`, 0.5928271226382288, 0.9537219115483138], 
             UndirectedEdge[94, 126] -> 
             RGBColor[
              0.9899835197941986, 0.9901259422701709, 0.8156625290373511], 
             UndirectedEdge[41, 198] -> 
             RGBColor[
              0.8471935168804745, 0.8789051909720507, 0.8634853960216949], 
             UndirectedEdge[11, 77] -> 
             RGBColor[
              0.4405854109980928, 0.5363557390424623, 0.9522288797005503], 
             UndirectedEdge[29, 122] -> 
             RGBColor[
              0.6033639360934375, 0.688363511800759, 0.9622692748795594], 
             UndirectedEdge[84, 152] -> 
             RGBColor[
              0.8644072975987055, 0.8921238391410211, 0.8548223438939954], 
             UndirectedEdge[16, 64] -> 
             RGBColor[
              0.8693111342897167, 0.8984788452327688, 0.9727732436691192], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.9915290591081085, 0.9907650624950213, 0.7900489428783342], 
             UndirectedEdge[26, 121] -> 
             RGBColor[
              0.9319809396150249, 0.9479953631210691, 0.9724001481261135], 
             UndirectedEdge[40, 74] -> 
             RGBColor[
              0.7152648790450928, 0.7728641580901856, 0.8751563047745357], 
             UndirectedEdge[78, 91] -> 
             RGBColor[
              0.6149394230503062, 0.6982681338852534, 0.9628338186942993], 
             UndirectedEdge[139, 152] -> 
             RGBColor[
              0.9568452728587727, 0.9651363577812525, 0.8638235957530012], 
             UndirectedEdge[40, 196] -> 
             RGBColor[
              0.9802350951511936, 0.9836715434058355, 0.8687044372838195], 
             UndirectedEdge[6, 86] -> 
             RGBColor[
              0.8601149431771296, 0.8914594482758622, 0.9801956352195696], 
             UndirectedEdge[82, 180] -> 
             RGBColor[
              0.9928870073527107, 0.9913266089918423, 0.7675442262078708], 
             UndirectedEdge[44, 90] -> 
             RGBColor[
              0.6661353461845632, 0.7328581852779603, 0.942666025937914], 
             UndirectedEdge[4, 66] -> 
             RGBColor[
              0.6879607960191141, 0.7544260120630788, 0.9709097277751626], 
             UndirectedEdge[131, 143] -> 
             RGBColor[
              0.7871990996919667, 0.8342716497023714, 0.971362358091852], 
             UndirectedEdge[22, 144] -> 
             RGBColor[
              0.9677901905989745, 0.9330040410115041, 0.621120176080495], 
             UndirectedEdge[35, 160] -> 
             RGBColor[
              0.6029553018774678, 0.6831670696517168, 0.9646328422887036], 
             UndirectedEdge[76, 174] -> 
             RGBColor[
              0.944031133609917, 0.9577790916036595, 0.9796248711668971], 
             UndirectedEdge[85, 196] -> 
             RGBColor[
              0.8794895009867373, 0.9061181108177339, 0.9579866532368322], 
             UndirectedEdge[6, 137] -> 
             RGBColor[
              0.9641242088228408, 0.9725342516123454, 0.9353026981838224], 
             UndirectedEdge[123, 177] -> 
             RGBColor[
              0.7853139540534106, 0.8326023531618385, 0.9674897945228351], 
             UndirectedEdge[29, 113] -> 
             RGBColor[
              0.7528746334136724, 0.8054035768640785, 0.9417872112436135], 
             UndirectedEdge[96, 174] -> 
             RGBColor[
              0.7424870915532173, 0.7978831225885724, 0.9654471915991245], 
             UndirectedEdge[74, 158] -> 
             RGBColor[
              0.6537433147206968, 0.7263394805192755, 0.9682454018129232], 
             UndirectedEdge[46, 121] -> 
             RGBColor[
              0.9701262675381688, 0.9772407997604895, 0.9354526161273147], 
             UndirectedEdge[32, 165] -> 
             RGBColor[
              0.8748138891661599, 0.9025132438176693, 0.9599380576600032], 
             UndirectedEdge[32, 148] -> 
             RGBColor[
              0.9522097490712536, 0.9638786896234706, 0.9657806085153955], 
             UndirectedEdge[27, 190] -> 
             RGBColor[
              0.34569760448397124`, 0.4738476225623728, 0.9432485235626977], 
             UndirectedEdge[100, 123] -> 
             RGBColor[
              0.970962617543311, 0.9763752131795999, 0.8673414275040301], 
             UndirectedEdge[45, 172] -> 
             RGBColor[
              0.8595173634135949, 0.8390637793625135, 0.6303506618555147], 
             UndirectedEdge[85, 99] -> 
             RGBColor[
              0.7458081417673235, 0.8013502557912306, 0.9752988436641727], 
             UndirectedEdge[106, 112] -> 
             RGBColor[
              0.6940325938096373, 0.7609028042179473, 0.9701383409137554], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.9461040095960941, 0.959129946728059, 0.9693520571118619], 
             UndirectedEdge[43, 197] -> 
             RGBColor[
              0.9250643306366049, 0.9423783551724139, 0.9682077867374004], 
             UndirectedEdge[26, 164] -> 
             RGBColor[
              0.7164620712558637, 0.7773604619997967, 0.9733884476485832], 
             UndirectedEdge[100, 130] -> 
             RGBColor[
              0.9921740618067326, 0.9910317876867156, 0.7793595789486577], 
             UndirectedEdge[46, 196] -> 
             RGBColor[
              0.9753502772487145, 0.9811368576490835, 0.9266097303273053], 
             UndirectedEdge[156, 181] -> 
             RGBColor[
              0.5847478093575986, 0.6727133334855789, 0.9611707363920647], 
             UndirectedEdge[62, 96] -> 
             RGBColor[
              0.47517748235941937`, 0.583705258091926, 0.9521319673187885], 
             UndirectedEdge[54, 58] -> 
             RGBColor[
              0.9597499915824743, 0.9695021901423251, 0.9530169447541091], 
             UndirectedEdge[179, 183] -> 
             RGBColor[
              0.7982616800821742, 0.8426369689348088, 0.9804447610898726], 
             UndirectedEdge[65, 198] -> 
             RGBColor[
              0.849169249613005, 0.8804486483988285, 0.8636823185962015], 
             UndirectedEdge[4, 80] -> 
             RGBColor[
              0.9349273862131378, 0.9479575669914183, 0.8746705046547043], 
             UndirectedEdge[159, 197] -> 
             RGBColor[
              0.9041323560873255, 0.9256877668501314, 0.9662112763186959], 
             UndirectedEdge[78, 136] -> 
             RGBColor[
              0.8164002349756847, 0.8555021847347173, 0.89002326437683], 
             UndirectedEdge[153, 188] -> 
             RGBColor[
              0.8395255768599847, 0.8736611269230168, 0.8965565037611405], 
             UndirectedEdge[35, 174] -> 
             RGBColor[
              0.8956565412650517, 0.9193378880017793, 0.9795659987920505], 
             UndirectedEdge[82, 130] -> 
             RGBColor[
              0.9911654546010346, 0.9906147026871366, 0.7960748105388512], 
             UndirectedEdge[124, 176] -> 
             RGBColor[
              0.7735903954916579, 0.8229543532547519, 0.9630723988024421], 
             UndirectedEdge[6, 186] -> 
             RGBColor[
              0.9570697744510539, 0.9675032885941646, 0.9575538532450205], 
             UndirectedEdge[1, 144] -> 
             RGBColor[
              0.9732004790981431, 0.9370390253156496, 0.6119619688806364], 
             UndirectedEdge[43, 67] -> 
             RGBColor[
              0.6555780561962046, 0.7272684391633051, 0.9686662372563923], 
             UndirectedEdge[24, 119] -> 
             RGBColor[
              0.7741700163675129, 0.8235067677871293, 0.9781256902675324], 
             UndirectedEdge[93, 139] -> 
             RGBColor[
              0.828499112225759, 0.8667483402004472, 0.9833286051754905], 
             UndirectedEdge[38, 146] -> 
             RGBColor[
              0.681743532950793, 0.743163923412548, 0.8485513031830239], 
             UndirectedEdge[110, 127] -> 
             RGBColor[
              0.9038154806222052, 0.9230503613856975, 0.8651233240132533], 
             UndirectedEdge[41, 81] -> 
             RGBColor[
              0.7845236429928848, 0.8319850895578966, 0.9790541516649702], 
             UndirectedEdge[85, 194] -> 
             RGBColor[
              0.7607859661679888, 0.8130510460487119, 0.976791693224704], 
             UndirectedEdge[52, 70] -> 
             RGBColor[
              0.9800651371175995, 0.9813483508633276, 0.720085578377035], 
             UndirectedEdge[149, 170] -> 
             RGBColor[
              0.707404587472061, 0.7701498876695589, 0.9725111653681284], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.8207228830312152, 0.8602338453697383, 0.982670211715541], 
             UndirectedEdge[92, 155] -> 
             RGBColor[
              0.8324100079239882, 0.8692945158843881, 0.951029622884078], 
             UndirectedEdge[57, 141] -> 
             RGBColor[
              0.8492927922412169, 0.883038329396763, 0.9807989642491253], 
             UndirectedEdge[149, 159] -> 
             RGBColor[
              0.6874406038910611, 0.7542311490699676, 0.9706069827921142], 
             UndirectedEdge[142, 167] -> 
             RGBColor[
              0.6483941200238186, 0.7227432744749636, 0.9673031686240459], 
             UndirectedEdge[117, 173] -> 
             RGBColor[
              0.9720704567480649, 0.9763525619705914, 0.8103164934759676], 
             UndirectedEdge[99, 179] -> 
             RGBColor[
              0.7802667385842996, 0.8285791838700485, 0.9786511934936537], 
             UndirectedEdge[5, 11] -> 
             RGBColor[
              0.7718758664026022, 0.8218885301565206, 0.9778508646143433], 
             UndirectedEdge[29, 188] -> 
             RGBColor[
              0.7601802705930802, 0.8099677227186763, 0.8898160435766747], 
             UndirectedEdge[46, 178] -> 
             RGBColor[
              0.9864528273898285, 0.988151222206325, 0.8511264582127165], 
             UndirectedEdge[101, 137] -> 
             RGBColor[
              0.9575159190651031, 0.9674447609789182, 0.9409054874604336], 
             UndirectedEdge[3, 20] -> 
             RGBColor[
              0.9424021681273697, 0.9534899509609136, 0.8552619853739907], 
             UndirectedEdge[186, 199] -> 
             RGBColor[
              0.9808131467020035, 0.9842199842139563, 0.8729802645695921], 
             UndirectedEdge[156, 179] -> 
             RGBColor[
              0.6584313470557028, 0.7305850835013262, 0.9684326617506631], 
             UndirectedEdge[67, 87] -> 
             RGBColor[
              0.6941058477081408, 0.7572577288184774, 0.946971670412891], 
             UndirectedEdge[3, 10] -> 
             RGBColor[
              0.877030505982906, 0.9047843353846154, 0.9881331466666667], 
             UndirectedEdge[55, 185] -> 
             RGBColor[
              0.6358364262135091, 0.6734785646382349, 0.6409415709302644], 
             UndirectedEdge[5, 28] -> 
             RGBColor[
              0.916394055735682, 0.9335608676802223, 0.8894590705886161], 
             UndirectedEdge[37, 170] -> 
             RGBColor[
              0.939841900808909, 0.9510326378104654, 0.8213096230856916], 
             UndirectedEdge[49, 154] -> 
             RGBColor[
              0.9599725901669164, 0.9682072122508176, 0.8891866169760527], 
             UndirectedEdge[24, 89] -> 
             RGBColor[
              0.8119123291631958, 0.85334617327641, 0.9817933319368328], 
             UndirectedEdge[73, 115] -> 
             RGBColor[
              0.5535952349234702, 0.648472576748826, 0.9580001912607904], 
             UndirectedEdge[153, 174] -> 
             RGBColor[
              0.8184021358821686, 0.858791685620143, 0.9719176089983711], 
             UndirectedEdge[119, 183] -> 
             RGBColor[
              0.7633163246803907, 0.8150277813500372, 0.9770438957136756], 
             UndirectedEdge[4, 168] -> 
             RGBColor[
              0.6280574062864721, 0.7037901386777188, 0.9667475149761273], 
             UndirectedEdge[144, 181] -> 
             RGBColor[
              0.8369773806573333, 0.8305291994378334, 0.6413546061215074], 
             UndirectedEdge[53, 123] -> 
             RGBColor[
              0.7401264786780354, 0.7959171249795416, 0.9639324709341093], 
             UndirectedEdge[110, 162] -> 
             RGBColor[
              0.9231312016034183, 0.9384004019933657, 0.8669794184604989], 
             UndirectedEdge[127, 176] -> 
             RGBColor[
              0.8831451525729443, 0.9092730096551724, 0.9734901943236074], 
             UndirectedEdge[9, 102] -> 
             RGBColor[
              0.9938656477106738, 0.9894422397489896, 0.584934966862459], 
             UndirectedEdge[27, 195] -> 
             RGBColor[
              0.6234368750006531, 0.554131146727106, 0.5902294177766678], 
             UndirectedEdge[60, 130] -> 
             RGBColor[
              0.9304872346042841, 0.9448153927984524, 0.8915417861741348], 
             UndirectedEdge[89, 122] -> 
             RGBColor[
              0.769883078980826, 0.8205126035998105, 0.977604249064328], 
             UndirectedEdge[5, 106] -> 
             RGBColor[
              0.7718635198376957, 0.8218788849261784, 0.9778496340241387], 
             UndirectedEdge[83, 199] -> 
             RGBColor[
              0.9747834822421078, 0.9797230703324356, 0.8831869137118393], 
             UndirectedEdge[118, 125] -> 
             RGBColor[
              0.7075004328540293, 0.7661389850518991, 0.8746615611290712], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.8486609176935938, 0.8797705225814824, 0.8508893275837217], 
             UndirectedEdge[5, 112] -> 
             RGBColor[
              0.7636769847809601, 0.8154835015198857, 0.977033676717203], 
             UndirectedEdge[109, 146] -> 
             RGBColor[
              0.43953793789940043`, 0.5536048051101607, 0.9496486449104775], 
             UndirectedEdge[164, 184] -> 
             RGBColor[
              0.7612219619797023, 0.8090286824073638, 0.7897408594982984], 
             UndirectedEdge[51, 164] -> 
             RGBColor[
              0.7433137383016459, 0.7497433707797003, 0.6246507567353881], 
             UndirectedEdge[45, 168] -> 
             RGBColor[
              0.6677788433687002, 0.683246333786472, 0.6145463310344826], 
             UndirectedEdge[148, 165] -> 
             RGBColor[
              0.860114500702389, 0.8915504639694285, 0.9848202881146482], 
             UndirectedEdge[166, 184] -> 
             RGBColor[
              0.9940642170467566, 0.990986219496806, 0.6879064013482332], 
             UndirectedEdge[21, 132] -> 
             RGBColor[
              0.6432379980359642, 0.7171171088233572, 0.9676327254707091], 
             UndirectedEdge[96, 157] -> 
             RGBColor[
              0.7010916499192652, 0.7651738634055485, 0.9718425731694162], 
             UndirectedEdge[42, 102] -> 
             RGBColor[
              0.7130270726779502, 0.7682373935920888, 0.6939420239328495], 
             UndirectedEdge[117, 120] -> 
             RGBColor[
              0.8353611469524167, 0.8719994330927413, 0.971544616227605], 
             UndirectedEdge[25, 129] -> 
             RGBColor[
              0.6046588708361995, 0.6895476241447449, 0.9622804030355502], 
             UndirectedEdge[57, 90] -> 
             RGBColor[
              0.9538708205442885, 0.965117514008305, 0.9629688477883722], 
             UndirectedEdge[51, 184] -> 
             RGBColor[
              0.9764149159857487, 0.9309807830688662, 0.4583968670423094], 
             UndirectedEdge[95, 103] -> 
             RGBColor[
              0.7227068067387159, 0.7833033172902333, 0.9729963184827711], 
             UndirectedEdge[47, 105] -> 
             RGBColor[
              0.8318859530591665, 0.8663966336541202, 0.8288045191485631], 
             UndirectedEdge[127, 177] -> 
             RGBColor[
              0.7177177581064611, 0.7790918039204593, 0.9727137612177954], 
             UndirectedEdge[73, 153] -> 
             RGBColor[
              0.6096310785241006, 0.6932423090813585, 0.962905645158792], 
             UndirectedEdge[137, 199] -> 
             RGBColor[
              0.9878675810737902, 0.9892509472321372, 0.8507291095083939], 
             UndirectedEdge[138, 185] -> 
             RGBColor[
              0.6473149104932512, 0.7113640484911496, 0.7564624658302534], 
             UndirectedEdge[88, 136] -> 
             RGBColor[
              0.7446780527190285, 0.7972813044403942, 0.8843726432295764], 
             UndirectedEdge[55, 76] -> 
             RGBColor[
              0.9558457412943182, 0.9344288212582282, 0.6632738700530458], 
             UndirectedEdge[135, 176] -> 
             RGBColor[
              0.9503167573689402, 0.9624668995113747, 0.9689849496961042], 
             UndirectedEdge[69, 123] -> 
             RGBColor[
              0.9432794169397498, 0.9572184625418719, 0.9808973314103826], 
             UndirectedEdge[2, 40] -> 
             RGBColor[
              0.9891062324453513, 0.989763161406166, 0.8302014507546316], 
             UndirectedEdge[105, 174] -> 
             RGBColor[
              0.9711012175047898, 0.9758831062058444, 0.8320634700981653], 
             UndirectedEdge[89, 138] -> 
             RGBColor[
              0.9288690644667957, 0.9417825867223377, 0.7796820167848115], 
             UndirectedEdge[37, 128] -> 
             RGBColor[
              0.8145169695577328, 0.8524802633075299, 0.8090410469647591], 
             UndirectedEdge[88, 153] -> 
             RGBColor[
              0.5944347583840414, 0.6809052518052376, 0.9617093351714117], 
             UndirectedEdge[113, 197] -> 
             RGBColor[
              0.9690068736816976, 0.9764059576551725, 0.9373474579416445], 
             UndirectedEdge[31, 178] -> 
             RGBColor[
              0.9618870670771875, 0.9697337641719765, 0.8893692214928282], 
             UndirectedEdge[82, 177] -> 
             RGBColor[
              0.8064992648048168, 0.8472481207901352, 0.8799410458929207], 
             UndirectedEdge[87, 108] -> 
             RGBColor[
              0.7334504727781703, 0.7899917946105202, 0.949850101193175], 
             UndirectedEdge[64, 86] -> 
             RGBColor[
              0.8647673289642339, 0.8949291899783021, 0.97232035961855], 
             UndirectedEdge[116, 157] -> 
             RGBColor[
              0.8215942074270559, 0.8609145306100796, 0.9827570571883288], 
             UndirectedEdge[120, 168] -> 
             RGBColor[
              0.5503392431407927, 0.6426186101152878, 0.959122703568493], 
             UndirectedEdge[18, 54] -> 
             RGBColor[
              0.8543893948966395, 0.8863562439441437, 0.9477161195497292], 
             UndirectedEdge[161, 176] -> 
             RGBColor[
              0.9162684428375385, 0.935632831212925, 0.9766632670552644], 
             UndirectedEdge[168, 172] -> 
             RGBColor[
              0.571265360628449, 0.6589662521410282, 0.9612084233939764], 
             UndirectedEdge[142, 157] -> 
             RGBColor[
              0.671609635143182, 0.7412390356606939, 0.9695216409700644], 
             UndirectedEdge[121, 171] -> 
             RGBColor[
              0.7554457587923396, 0.8080109000609774, 0.9559358695912494], 
             UndirectedEdge[47, 94] -> 
             RGBColor[
              0.8283593803174709, 0.86523846840039, 0.9090676521846586], 
             UndirectedEdge[70, 93] -> 
             RGBColor[
              0.8656546889935157, 0.8915880051584524, 0.7369356911192172], 
             UndirectedEdge[32, 163] -> 
             RGBColor[
              0.9212559414868333, 0.9392436736769292, 0.9644476718260643], 
             UndirectedEdge[35, 142] -> 
             RGBColor[
              0.661393242997093, 0.7330927618799798, 0.9685471923668896], 
             UndirectedEdge[12, 193] -> 
             RGBColor[
              0.8575840589077472, 0.8892782663466277, 0.9862783271845899], 
             UndirectedEdge[35, 94] -> 
             RGBColor[
              0.9159628109830532, 0.9338694079883763, 0.9177475361013776], 
             UndirectedEdge[116, 174] -> 
             RGBColor[
              0.8629896490610081, 0.8936237897931035, 0.9763616756180371], 
             UndirectedEdge[112, 140] -> 
             RGBColor[
              0.7629355893739416, 0.8148923329469713, 0.97696296176143], 
             UndirectedEdge[86, 176] -> 
             RGBColor[
              0.8651366055643974, 0.8952045958620691, 0.9716952706572355], 
             UndirectedEdge[61, 73] -> 
             RGBColor[
              0.6973710871261374, 0.7621494468458309, 0.9715541611481228], 
             UndirectedEdge[33, 66] -> 
             RGBColor[
              0.6667857185424458, 0.7375415800653496, 0.9688900299822232], 
             UndirectedEdge[48, 106] -> 
             RGBColor[
              0.7881014113744995, 0.8348265388718017, 0.9793984186146559], 
             UndirectedEdge[86, 199] -> 
             RGBColor[
              0.8838583154280791, 0.908176143895654, 0.8956220465441411], 
             UndirectedEdge[10, 59] -> 
             RGBColor[
              0.7836884381962865, 0.8313022555924865, 0.9789789643609592], 
             UndirectedEdge[1, 113] -> 
             RGBColor[
              0.9791363796498673, 0.9839605266206897, 0.9202008465358091], 
             UndirectedEdge[125, 128] -> 
             RGBColor[
              0.529285133976749, 0.6279442149376784, 0.9563053332927698], 
             UndirectedEdge[53, 165] -> 
             RGBColor[
              0.6571014492835796, 0.7303534537854931, 0.9676186357016682], 
             UndirectedEdge[87, 143] -> 
             RGBColor[
              0.7969542962967412, 0.8415470593575438, 0.9548493548027273], 
             UndirectedEdge[61, 105] -> 
             RGBColor[
              0.9299749869439025, 0.9433885086249424, 0.8384845292609335], 
             UndirectedEdge[29, 47] -> 
             RGBColor[
              0.5998415651696407, 0.6856118088640785, 0.9619181978643032], 
             UndirectedEdge[24, 27] -> 
             RGBColor[
              0.5541434452668551, 0.6442661896911079, 0.9600623740393184], 
             UndirectedEdge[98, 117] -> 
             RGBColor[
              0.934221009996326, 0.950028779277865, 0.9811859418449507], 
             UndirectedEdge[1, 88] -> 
             RGBColor[
              0.7413511983533315, 0.7957687973575085, 0.9333825102791413], 
             UndirectedEdge[190, 195] -> 
             RGBColor[
              0.6207886773170935, 0.5518374109958923, 0.5900606769619806], 
             UndirectedEdge[4, 173] -> 
             RGBColor[
              0.9355791186393587, 0.9476130711058699, 0.8192380032200386], 
             UndirectedEdge[81, 164] -> 
             RGBColor[
              0.6981775884342719, 0.762780911716924, 0.9716444573543093], 
             UndirectedEdge[82, 123] -> 
             RGBColor[
              0.969954010337613, 0.9759581281800208, 0.8840566590942236], 
             UndirectedEdge[43, 87] -> 
             RGBColor[
              0.9255466880636605, 0.9427380965517242, 0.9673912814323608], 
             UndirectedEdge[38, 171] -> 
             RGBColor[
              0.7727691455002328, 0.8193335360291472, 0.8550897109636538], 
             UndirectedEdge[46, 85] -> 
             RGBColor[
              0.8852332378004386, 0.9104017803288865, 0.9482640050177183], 
             UndirectedEdge[64, 69] -> 
             RGBColor[
              0.9448827892732734, 0.9584142550029324, 0.9781832402762065], 
             UndirectedEdge[60, 82] -> 
             RGBColor[
              0.9304611010922685, 0.9448045859196332, 0.8919748860995929], 
             UndirectedEdge[77, 189] -> 
             RGBColor[
              0.5091603096396049, 0.590083851776581, 0.9590221534070114], 
             UndirectedEdge[101, 187] -> 
             RGBColor[
              0.8302541726163652, 0.8682049429137111, 0.9834808345165227], 
             UndirectedEdge[64, 161] -> 
             RGBColor[
              0.915899166237375, 0.9353574253291579, 0.977288356016579], 
             UndirectedEdge[7, 160] -> 
             RGBColor[
              0.5941724048734949, 0.6761638259861369, 0.9637951217318799], 
             UndirectedEdge[16, 83] -> 
             RGBColor[
              0.8730281858147255, 0.9012510161740072, 0.9664812449995819], 
             UndirectedEdge[13, 124] -> 
             RGBColor[
              0.7838937904777529, 0.8306386083651205, 0.9456314386467787], 
             UndirectedEdge[46, 171] -> 
             RGBColor[
              0.7664135053165866, 0.816190627460724, 0.9373703355721263], 
             UndirectedEdge[1, 197] -> 
             RGBColor[
              0.9732392706896551, 0.9795624724137931, 0.9301831137931034], 
             UndirectedEdge[26, 80] -> 
             RGBColor[
              0.9490350793265068, 0.9592066585368906, 0.8760161090179437], 
             UndirectedEdge[23, 43] -> 
             RGBColor[
              0.9389876469988603, 0.9516385295387781, 0.8943126384481368], 
             UndirectedEdge[13, 86] -> 
             RGBColor[
              0.8754400005504924, 0.9028888509724379, 0.954254310501572], 
             UndirectedEdge[31, 146] -> 
             RGBColor[
              0.6508221324545058, 0.7216035568097765, 0.969074691071608], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.7341285177549504, 0.7888177361465916, 0.887765154162542], 
             UndirectedEdge[124, 127] -> 
             RGBColor[
              0.7040215506110213, 0.767972605668545, 0.9716355455928931], 
             UndirectedEdge[60, 163] -> 
             RGBColor[
              0.8726928132670801, 0.901325576956548, 0.9877194136631272], 
             UndirectedEdge[4, 184] -> 
             RGBColor[
              0.9354555558265975, 0.9473487827434903, 0.8057889535922651], 
             UndirectedEdge[144, 192] -> 
             RGBColor[
              0.8194573847699504, 0.8168424454937095, 0.6396083766651234], 
             UndirectedEdge[38, 192] -> 
             RGBColor[
              0.8348439412155739, 0.8692151130162562, 0.8603275754237443], 
             UndirectedEdge[49, 108] -> 
             RGBColor[
              0.7154800027986676, 0.7763943551316825, 0.9735054437161774], 
             UndirectedEdge[83, 165] -> 
             RGBColor[
              0.8710640940502834, 0.8997166527599746, 0.9662854826879833], 
             UndirectedEdge[183, 192] -> 
             RGBColor[
              0.7070581464966872, 0.7710784649749376, 0.97143660627489], 
             UndirectedEdge[79, 159] -> 
             RGBColor[
              0.6462193904083737, 0.7206020691987777, 0.9674071678380922], 
             UndirectedEdge[81, 166] -> 
             RGBColor[
              0.9310198435013263, 0.9447384488063661, 0.8698099992042441], 
             UndirectedEdge[118, 119] -> 
             RGBColor[
              0.8896312971181103, 0.9125562065796846, 0.8903101964275164], 
             UndirectedEdge[47, 153] -> 
             RGBColor[
              0.6791868714365452, 0.7493052130684188, 0.968658658048769], 
             UndirectedEdge[74, 184] -> 
             RGBColor[
              0.7169946239433083, 0.7727522561015805, 0.7863615416665357], 
             UndirectedEdge[149, 190] -> 
             RGBColor[
              0.43638783356468414`, 0.5503242773595537, 0.9496004604468931], 
             UndirectedEdge[55, 139] -> 
             RGBColor[
              0.9448844810998724, 0.9258199931552454, 0.6667835146979821], 
             UndirectedEdge[22, 138] -> 
             RGBColor[
              0.9832013793164336, 0.9841554603757519, 0.7519188850920973], 
             UndirectedEdge[113, 144] -> 
             RGBColor[
              0.9689680820901856, 0.933882510557029, 0.6191263130291775], 
             UndirectedEdge[80, 172] -> 
             RGBColor[
              0.8781353405551147, 0.9031336804547276, 0.8691314130725534], 
             UndirectedEdge[8, 156] -> 
             RGBColor[
              0.5984033719654633, 0.6833811627809626, 0.9625317952543287], 
             UndirectedEdge[22, 118] -> 
             RGBColor[
              0.9817059247634309, 0.9847684857223797, 0.8662147064041026], 
             UndirectedEdge[100, 163] -> 
             RGBColor[
              0.9343796404695288, 0.9475419718448114, 0.8755372064376501], 
             UndirectedEdge[12, 154] -> 
             RGBColor[
              0.9233162857421751, 0.9389784701114059, 0.8856903059365517], 
             UndirectedEdge[67, 129] -> 
             RGBColor[
              0.483121597367259, 0.5904665762744696, 0.9526711705882642], 
             UndirectedEdge[49, 129] -> 
             RGBColor[
              0.7351197592552123, 0.7923387941840512, 0.975051557287235], 
             UndirectedEdge[127, 175] -> 
             RGBColor[
              0.77892212343933, 0.8272191499489843, 0.9785993358894858], 
             UndirectedEdge[30, 198] -> 
             RGBColor[
              0.9747831607314414, 0.9791551886961556, 0.857767295956352], 
             UndirectedEdge[5, 140] -> 
             RGBColor[
              0.8407665154020001, 0.8758684136552024, 0.9846742548718133], 
             UndirectedEdge[147, 156] -> 
             RGBColor[
              0.7099346248173122, 0.7709923175863485, 0.9504596475145918], 
             UndirectedEdge[122, 159] -> 
             RGBColor[
              0.7605187677273025, 0.8130457559937085, 0.9767110726973475], 
             UndirectedEdge[82, 110] -> 
             RGBColor[
              0.9925969873205609, 0.9912066782553735, 0.7723506086883787], 
             UndirectedEdge[83, 176] -> 
             RGBColor[
              0.9560617723784262, 0.9667515222988506, 0.9592601378249337], 
             UndirectedEdge[10, 77] -> 
             RGBColor[
              0.5217022458885942, 0.6000844512997348, 0.9602184144827586], 
             UndirectedEdge[104, 130] -> 
             RGBColor[
              0.7002085326715302, 0.7597488912486112, 0.8714690870259882], 
             UndirectedEdge[30, 66] -> 
             RGBColor[
              0.7276629005817988, 0.7855600872920299, 0.9565532279265139], 
             UndirectedEdge[85, 132] -> 
             RGBColor[
              0.6022227501131822, 0.6846600851283229, 0.9636549964055648], 
             UndirectedEdge[24, 195] -> 
             RGBColor[
              0.8292345180999774, 0.7222559781246274, 0.6068745274386012], 
             UndirectedEdge[50, 123] -> 
             RGBColor[
              0.9703176148446869, 0.9761084879879055, 0.8780307914337064], 
             UndirectedEdge[42, 153] -> 
             RGBColor[
              0.5614807265873059, 0.6536115577498458, 0.9592643116296709], 
             UndirectedEdge[127, 161] -> 
             RGBColor[
              0.846699597956902, 0.8806510836267181, 0.9852264138457154], 
             UndirectedEdge[7, 18] -> 
             RGBColor[
              0.7784913105211134, 0.8269350915906879, 0.9785424656682453], 
             UndirectedEdge[65, 66] -> 
             RGBColor[
              0.6020489894633624, 0.6868535469947028, 0.9624682505663634], 
             UndirectedEdge[150, 152] -> 
             RGBColor[
              0.9301182837102857, 0.9438249821190428, 0.8612743516685535], 
             UndirectedEdge[25, 87] -> 
             RGBColor[
              0.8156431211770814, 0.8563387766887527, 0.956580902860177], 
             UndirectedEdge[69, 82] -> 
             RGBColor[
              0.964464727691156, 0.9718642301701687, 0.8933485827804682], 
             UndirectedEdge[1, 159] -> 
             RGBColor[
              0.9142618620554952, 0.9332423358156486, 0.9490646649128605], 
             UndirectedEdge[23, 131] -> 
             RGBColor[
              0.967760241906022, 0.9743524095387781, 0.8891310748937602], 
             UndirectedEdge[126, 160] -> 
             RGBColor[
              0.6769760106886133, 0.7394236039335115, 0.862547835224677], 
             UndirectedEdge[67, 131] -> 
             RGBColor[
              0.6843506511033662, 0.749982319163305, 0.9634846737020157], 
             UndirectedEdge[142, 174] -> 
             RGBColor[
              0.7130050767771341, 0.7739482948437179, 0.9631262593997727], 
             UndirectedEdge[22, 122] -> 
             RGBColor[
              0.8242153938304637, 0.8628854772532247, 0.9498411173716137], 
             UndirectedEdge[32, 176] -> 
             RGBColor[
              0.9598115674943026, 0.9695481133565453, 0.9529127127969536], 
             UndirectedEdge[47, 160] -> 
             RGBColor[
              0.5153518712118856, 0.6145361300637306, 0.9559529583719846], 
             UndirectedEdge[79, 125] -> 
             RGBColor[
              0.43571052460213344`, 0.5518122897878133, 0.9489840672373271], 
             UndirectedEdge[47, 111] -> 
             RGBColor[
              0.7430784230769231, 0.4376737379310345, 0.5659225819628647], 
             UndirectedEdge[3, 186] -> 
             RGBColor[
              0.9305261982058433, 0.9465179416445624, 0.9612551971000163], 
             UndirectedEdge[105, 160] -> 
             RGBColor[
              0.6783999781172061, 0.7397122878557818, 0.8171303135948182], 
             UndirectedEdge[9, 189] -> 
             RGBColor[
              0.9172481629000122, 0.9335082805459434, 0.8576838318803874], 
             UndirectedEdge[64, 175] -> 
             RGBColor[
              0.8481216917198031, 0.8819254916514241, 0.9706612780603493], 
             UndirectedEdge[100, 165] -> 
             RGBColor[
              0.8879375881488553, 0.9108115419855514, 0.871027592271589], 
             UndirectedEdge[101, 161] -> 
             RGBColor[
              0.9046384906925331, 0.9267981929932908, 0.9907664208942097], 
             UndirectedEdge[123, 187] -> 
             RGBColor[
              0.8399114758276838, 0.8755683827885176, 0.9727168607730681], 
             UndirectedEdge[90, 198] -> 
             RGBColor[
              0.9802609446309796, 0.9832405109593833, 0.8484948366492873], 
             UndirectedEdge[146, 171] -> 
             RGBColor[
              0.4607073840213176, 0.5707911151446129, 0.951315181255431], 
             UndirectedEdge[62, 157] -> 
             RGBColor[
              0.6385633242173425, 0.7133062972858469, 0.9672252231148895], 
             UndirectedEdge[2, 164] -> 
             RGBColor[
              0.7577347996594641, 0.808413847128395, 0.9076605773397103], 
             UndirectedEdge[94, 142] -> 
             RGBColor[
              0.7333113464951357, 0.7884798148303147, 0.9013077967090997], 
             UndirectedEdge[12, 175] -> 
             RGBColor[
              0.7995444349767306, 0.8436110303997004, 0.9805800541103875], 
             UndirectedEdge[23, 64] -> 
             RGBColor[
              0.971465920849625, 0.9771160988274248, 0.8828583270380985], 
             UndirectedEdge[73, 160] -> 
             RGBColor[
              0.44579607829944096`, 0.5584732260766703, 0.9501999454820076], 
             UndirectedEdge[47, 142] -> 
             RGBColor[
              0.5737898123315108, 0.6644618222919937, 0.9598673084501705], 
             UndirectedEdge[31, 120] -> 
             RGBColor[
              0.8265570695675823, 0.865337012378564, 0.9831069616162285], 
             UndirectedEdge[9, 20] -> 
             RGBColor[
              0.9951617612934651, 0.9922144956453953, 0.7260089316634586], 
             UndirectedEdge[174, 188] -> 
             RGBColor[
              0.9683918160229089, 0.975062862268391, 0.898783960587703], 
             UndirectedEdge[45, 173] -> 
             RGBColor[
              0.9753005557215868, 0.9270692662146232, 0.46703681927839397`], 
             UndirectedEdge[139, 191] -> 
             RGBColor[
              0.9386315563581178, 0.9533181575328825, 0.9737200373091612], 
             UndirectedEdge[24, 170] -> 
             RGBColor[
              0.8225120014906724, 0.8617980642698994, 0.9828043381458667], 
             UndirectedEdge[118, 195] -> 
             RGBColor[
              0.9446957988505748, 0.8113054169171827, 0.5190590335985852], 
             UndirectedEdge[124, 137] -> 
             RGBColor[
              0.7900222692481856, 0.8349789952119249, 0.9249476848907738], 
             UndirectedEdge[28, 63] -> 
             RGBColor[
              0.7715065986165512, 0.8188114404467699, 0.8760133801928535], 
             UndirectedEdge[7, 94] -> 
             RGBColor[
              0.9071799139790802, 0.9268661643227962, 0.916909815544554], 
             UndirectedEdge[37, 190] -> 
             RGBColor[
              0.668825146901532, 0.7312070275004602, 0.798398918164456], 
             UndirectedEdge[31, 40] -> 
             RGBColor[
              0.9614130716522539, 0.9695377548826396, 0.8972245523448175], 
             UndirectedEdge[18, 73] -> 
             RGBColor[
              0.6301149839470594, 0.7092444916812213, 0.9649472894183729], 
             UndirectedEdge[170, 195] -> 
             RGBColor[
              0.8918054312244704, 0.7716630213058975, 0.6129713818832161], 
             UndirectedEdge[62, 191] -> 
             RGBColor[
              0.6855204487939414, 0.7501634505010766, 0.9514153630419255], 
             UndirectedEdge[152, 194] -> 
             RGBColor[
              0.863509322364606, 0.8914223340632779, 0.854732842114716], 
             UndirectedEdge[24, 37] -> 
             RGBColor[
              0.8772709876844159, 0.9016255946291953, 0.8152127686410766], 
             UndirectedEdge[90, 177] -> 
             RGBColor[
              0.7944034787172252, 0.8393813057733808, 0.9521036001947081], 
             UndirectedEdge[94, 188] -> 
             RGBColor[
              0.9886980857409104, 0.989594382254988, 0.83696549789703], 
             UndirectedEdge[103, 133] -> 
             RGBColor[
              0.5414888324981446, 0.6306555481748837, 0.9598363409814847], 
             UndirectedEdge[38, 179] -> 
             RGBColor[
              0.926047474801061, 0.9407736169761274, 0.8693357302387268], 
             UndirectedEdge[54, 116] -> 
             RGBColor[
              0.87849300265252, 0.9051861655172415, 0.9501185419098144], 
             UndirectedEdge[4, 198] -> 
             RGBColor[
              0.9350810561687568, 0.9480211134672045, 0.8721237958050005], 
             UndirectedEdge[31, 38] -> 
             RGBColor[
              0.962883893933421, 0.9701459776943108, 0.8728492207798308], 
             UndirectedEdge[35, 47] -> 
             RGBColor[
              0.7564412768194284, 0.8098514154500551, 0.9763070478424485], 
             UndirectedEdge[132, 151] -> 
             RGBColor[
              0.6093455608753845, 0.690224479031122, 0.9643649316158902], 
             UndirectedEdge[124, 135] -> 
             RGBColor[
              0.7711931554070172, 0.8211664955247471, 0.9671303009653898], 
             UndirectedEdge[32, 127] -> 
             RGBColor[
              0.890242722613666, 0.9145663657703385, 0.9614758595874044], 
             UndirectedEdge[187, 199] -> 
             RGBColor[
              0.8606058346250525, 0.8900111291669301, 0.893304456564483], 
             UndirectedEdge[2, 51] -> 
             RGBColor[
              0.9729277536655105, 0.9303659477898973, 0.5763165848837213], 
             UndirectedEdge[40, 117] -> 
             RGBColor[
              0.9702171490370881, 0.976200175596817, 0.8856622069561939], 
             UndirectedEdge[9, 17] -> 
             RGBColor[
              0.9951417414478005, 0.9921716752198355, 0.7238298950110258], 
             UndirectedEdge[33, 57] -> 
             RGBColor[
              0.8875158546053974, 0.9130136845183973, 0.9845781091511461], 
             UndirectedEdge[124, 175] -> 
             RGBColor[
              0.6693673663580437, 0.7409004935485636, 0.9681815403683205], 
             UndirectedEdge[8, 147] -> 
             RGBColor[
              0.8497649578437836, 0.8830442030198311, 0.9624717468538011], 
             UndirectedEdge[108, 110] -> 
             RGBColor[
              0.7484405597664233, 0.7995328318582866, 0.8510983973549695], 
             UndirectedEdge[68, 107] -> 
             RGBColor[
              0.6325910459416444, 0.7126049348541112, 0.9642190308753316], 
             UndirectedEdge[1, 138] -> 
             RGBColor[
              0.9886116678156021, 0.9881904446798975, 0.7427606778922387], 
             UndirectedEdge[94, 160] -> 
             RGBColor[
              0.6748734053755105, 0.7385541226020517, 0.8973934466309137], 
             UndirectedEdge[138, 142] -> 
             RGBColor[
              0.7362981687412774, 0.7884835083512014, 0.7622961531859105], 
             UndirectedEdge[6, 175] -> 
             RGBColor[
              0.8434693059326988, 0.8784557499489842, 0.9785365536613689], 
             UndirectedEdge[34, 104] -> 
             RGBColor[
              0.6734153956654294, 0.7409294994331885, 0.9688992854560963], 
             UndirectedEdge[15, 106] -> 
             RGBColor[
              0.7395937015758075, 0.7964954878821235, 0.9746794463431279], 
             UndirectedEdge[61, 94] -> 
             RGBColor[
              0.9264484142022069, 0.9422303433712123, 0.918747662297029], 
             UndirectedEdge[144, 159] -> 
             RGBColor[
              0.9040935644958135, 0.883164319751988, 0.6479901314062289], 
             UndirectedEdge[83, 86] -> 
             RGBColor[
              0.8684843804892428, 0.8977013609195404, 0.9660283609490126], 
             UndirectedEdge[137, 176] -> 
             RGBColor[
              0.9691458712101086, 0.9762793991985523, 0.9268023336214882], 
             UndirectedEdge[143, 159] -> 
             RGBColor[
              0.7374945302355256, 0.7948671813800889, 0.9745474112275241], 
             UndirectedEdge[24, 144] -> 
             RGBColor[
              0.8614866349523204, 0.8496760151703091, 0.6437974595376282], 
             UndirectedEdge[76, 96] -> 
             RGBColor[
              0.7392498501180416, 0.7954687932267146, 0.970926996941088], 
             UndirectedEdge[98, 120] -> 
             RGBColor[
              0.8200115087419404, 0.8601177598507124, 0.9824826401813875], 
             UndirectedEdge[98, 183] -> 
             RGBColor[
              0.8285525383888921, 0.8667900771251407, 0.9833339301961357], 
             UndirectedEdge[55, 75] -> 
             RGBColor[
              0.6752122154987248, 0.7083208434198207, 0.6434235780850877], 
             UndirectedEdge[35, 68] -> 
             RGBColor[
              0.739689802909614, 0.7966574364367924, 0.9747109843729524], 
             UndirectedEdge[25, 43] -> 
             RGBColor[
              0.7771153296651451, 0.8263494870335804, 0.9782754697036784], 
             UndirectedEdge[47, 174] -> 
             RGBColor[
              0.8080531105994695, 0.8507069484137931, 0.9708861148753316], 
             UndirectedEdge[29, 88] -> 
             RGBColor[
              0.5150894521171367, 0.6172118476008972, 0.9549688749869458], 
             UndirectedEdge[17, 140] -> 
             RGBColor[
              0.917602948184884, 0.9336888689916172, 0.85071948649567], 
             UndirectedEdge[41, 90] -> 
             RGBColor[
              0.8338803211633306, 0.8705349457874758, 0.9558235784402913], 
             UndirectedEdge[151, 196] -> 
             RGBColor[
              0.8866123117489396, 0.9116825047205331, 0.9586965884471574], 
             UndirectedEdge[88, 94] -> 
             RGBColor[
              0.7436072672649671, 0.7968385071372088, 0.9021183293073013], 
             UndirectedEdge[57, 198] -> 
             RGBColor[
              0.9671840162614325, 0.9734877591928799, 0.8706306653697757], 
             UndirectedEdge[71, 164] -> 
             RGBColor[
              0.4906525549724075, 0.5973692440571083, 0.9530461157899743], 
             UndirectedEdge[95, 154] -> 
             RGBColor[
              0.8239263963281058, 0.8610527591676718, 0.8758587716777693], 
             UndirectedEdge[69, 90] -> 
             RGBColor[
              0.9523689416035643, 0.9639974151534141, 0.9655111370822556], 
             UndirectedEdge[175, 176] -> 
             RGBColor[
              0.8484909683199666, 0.8822008975351912, 0.9700361890990348], 
             UndirectedEdge[58, 115] -> 
             RGBColor[
              0.7593445552274077, 0.8117683467402803, 0.9721271677377679], 
             UndirectedEdge[42, 88] -> 
             RGBColor[
              0.4663795882521028, 0.5771268592803147, 0.951283494629274], 
             UndirectedEdge[72, 134] -> 
             RGBColor[
              0.7848259122845956, 0.8318312346653627, 0.9791877703875382], 
             UndirectedEdge[25, 49] -> 
             RGBColor[
              0.7976726511975787, 0.8427413372099151, 0.9802362453831794], 
             UndirectedEdge[23, 103] -> 
             RGBColor[
              0.8901644294922288, 0.9129556428392707, 0.8895901782738282], 
             UndirectedEdge[79, 192] -> 
             RGBColor[
              0.5615832106825109, 0.6542801949404993, 0.9590254130969867], 
             UndirectedEdge[89, 170] -> 
             RGBColor[
              0.8744832422876887, 0.9027532164576801, 0.9878901863814478], 
             UndirectedEdge[41, 57] -> 
             RGBColor[
              0.8208033927937833, 0.8607821940209726, 0.9779594071607798], 
             UndirectedEdge[10, 14] -> 
             RGBColor[
              0.8874124451944889, 0.9130626119016991, 0.989123385296734], 
             UndirectedEdge[6, 59] -> 
             RGBColor[
              0.8227850286472149, 0.8622970353272345, 0.976474938207113], 
             UndirectedEdge[120, 183] -> 
             RGBColor[
              0.7296926753449828, 0.7887607309400169, 0.9736926045787899], 
             UndirectedEdge[8, 194] -> 
             RGBColor[
              0.7352165878947254, 0.7930760534071661, 0.9742431765578505], 
             UndirectedEdge[63, 106] -> 
             RGBColor[
              0.6269760627185652, 0.7071294576927261, 0.964403943628376], 
             UndirectedEdge[129, 131] -> 
             RGBColor[
              0.7433350326299405, 0.7986608240077164, 0.9679092180533573], 
             UndirectedEdge[22, 38] -> 
             RGBColor[
              0.983176747044598, 0.9853767085340508, 0.841839374839116], 
             UndirectedEdge[38, 117] -> 
             RGBColor[
              0.9716879713182554, 0.9768083984084881, 0.8612868753912074], 
             UndirectedEdge[136, 159] -> 
             RGBColor[
              0.9175887164211922, 0.9347548428985344, 0.9000547978632956], 
             UndirectedEdge[158, 166] -> 
             RGBColor[
              0.9308129078241452, 0.944573443914501, 0.8697902614946208], 
             UndirectedEdge[75, 96] -> 
             RGBColor[
              0.45861632432244814`, 0.5693608153883072, 0.9510767049731298], 
             UndirectedEdge[118, 170] -> 
             RGBColor[
              0.9379732822412696, 0.9508475030624548, 0.8949888443058507], 
             UndirectedEdge[7, 58] -> 
             RGBColor[
              0.8838519072069482, 0.9100810377888692, 0.9838432908726251], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.7440684243607426, 0.8001091207639257, 0.9751743261750663], 
             UndirectedEdge[65, 180] -> 
             RGBColor[
              0.8496995262471445, 0.880667931414533, 0.8548942624565723], 
             UndirectedEdge[151, 171] -> 
             RGBColor[
              0.6776755398168117, 0.7467362745321736, 0.9694571936919784], 
             UndirectedEdge[37, 118] -> 
             RGBColor[
              0.9927322684350133, 0.9906750334217507, 0.7273972748010606], 
             UndirectedEdge[7, 47] -> 
             RGBColor[
              0.7476583798154554, 0.8028481717844752, 0.9754693272856247], 
             UndirectedEdge[46, 99] -> 
             RGBColor[
              0.8416689180293007, 0.8763690026225803, 0.9439219207546461], 
             UndirectedEdge[195, 197] -> 
             RGBColor[
              0.9308188562776305, 0.8020644193044507, 0.5921856481874447], 
             UndirectedEdge[5, 63] -> 
             RGBColor[
              0.696620453689888, 0.7617101549946643, 0.9712992794318236], 
             UndirectedEdge[11, 63] -> 
             RGBColor[
              0.6269884092834714, 0.7071391029230683, 0.9644051742185807], 
             UndirectedEdge[10, 193] -> 
             RGBColor[
              0.8624123394127869, 0.8931282061611635, 0.9867388528894174], 
             UndirectedEdge[99, 147] -> 
             RGBColor[
              0.831770016345909, 0.8689864179550707, 0.9606781792575823], 
             UndirectedEdge[9, 77] -> 
             RGBColor[
              0.5870148532604073, 0.6488184287693624, 0.8321626784733761], 
             UndirectedEdge[43, 103] -> 
             RGBColor[
              0.8381956790450928, 0.8740659201970444, 0.9843633881015537], 
             UndirectedEdge[54, 174] -> 
             RGBColor[
              0.9627717286366047, 0.9717557966896553, 0.9479019321167108], 
             UndirectedEdge[149, 197] -> 
             RGBColor[
              0.7464180125252211, 0.8005512856681121, 0.9517254316723571], 
             UndirectedEdge[87, 180] -> 
             RGBColor[
              0.9793545865959996, 0.9823883541911318, 0.842138628270146], 
             UndirectedEdge[134, 191] -> 
             RGBColor[
              0.860080799914442, 0.8911544397787882, 0.9661029336383351], 
             UndirectedEdge[65, 131] -> 
             RGBColor[
              0.8246642226219671, 0.8637315537751253, 0.9749653520644104], 
             UndirectedEdge[107, 147] -> 
             RGBColor[
              0.795571702122352, 0.8405163548489479, 0.9572013119389948], 
             UndirectedEdge[50, 82] -> 
             RGBColor[
              0.991502925596093, 0.9907542556162022, 0.7904820428037921], 
             UndirectedEdge[30, 162] -> 
             RGBColor[
              0.9040999653847468, 0.9258454822663276, 0.9725717338452813], 
             UndirectedEdge[51, 74] -> 
             RGBColor[
              0.6990864002652519, 0.7134669444739169, 0.6212714389036251], 
             UndirectedEdge[12, 161] -> 
             RGBColor[
              0.8673219094943025, 0.8970429640774342, 0.9872071320666173], 
             UndirectedEdge[78, 113] -> 
             RGBColor[
              0.8088409836020302, 0.8508331628932109, 0.946197475574936], 
             UndirectedEdge[131, 133] -> 
             RGBColor[
              0.6190846449119378, 0.6920523148743911, 0.9593772376014167], 
             UndirectedEdge[35, 188] -> 
             RGBColor[
              0.9167799822428678, 0.934207329304653, 0.9042048935548199], 
             UndirectedEdge[181, 185] -> 
             RGBColor[
              0.505848920894664, 0.6037808193127463, 0.9561309275661538], 
             UndirectedEdge[111, 188] -> 
             RGBColor[
              0.9034171285003625, 0.5620296517856324, 0.49382042767523615`], 
             UndirectedEdge[41, 184] -> 
             RGBColor[
              0.8475680165383151, 0.8782328602483366, 0.7971505538089594], 
             UndirectedEdge[135, 187] -> 
             RGBColor[
              0.83948688467673, 0.8752517234033406, 0.973435582840525], 
             UndirectedEdge[51, 71] -> 
             RGBColor[
              0.7058455089784539, 0.7193213447186106, 0.6217021233339852], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.8486732642585001, 0.8797801678118246, 0.8508905581739263], 
             UndirectedEdge[26, 158] -> 
             RGBColor[
              0.8863119397173549, 0.9121850987066578, 0.9890184181018922], 
             UndirectedEdge[101, 199] -> 
             RGBColor[
              0.9598057551722571, 0.9683916670553301, 0.9029569772590075], 
             UndirectedEdge[84, 194] -> 
             RGBColor[
              0.7330974460316156, 0.7914205636776301, 0.9740319603014425], 
             UndirectedEdge[6, 176] -> 
             RGBColor[
              0.947692335066313, 0.9605096096551724, 0.9734274120954907], 
             UndirectedEdge[18, 116] -> 
             RGBColor[
              0.7546073153210429, 0.808224237047592, 0.9761758630510555], 
             UndirectedEdge[98, 179] -> 
             RGBColor[
              0.8885805134791317, 0.9139939978455043, 0.9892347966924702], 
             UndirectedEdge[116, 142] -> 
             RGBColor[
              0.6287263507930494, 0.7073786636713041, 0.965342869192876], 
             UndirectedEdge[77, 112] -> 
             RGBColor[
              0.4323865293764509, 0.5299507104058273, 0.9514116918034099], 
             UndirectedEdge[56, 190] -> 
             RGBColor[
              0.59636932069954, 0.677268517286512, 0.9643025472711038], 
             UndirectedEdge[76, 126] -> 
             RGBColor[
              0.9664400086410214, 0.9731800929217163, 0.8829607970699875], 
             UndirectedEdge[168, 173] -> 
             RGBColor[
              0.6870485529364408, 0.7469717389931378, 0.7978945808168556], 
             UndirectedEdge[158, 164] -> 
             RGBColor[
              0.6979706527570908, 0.7626159068250589, 0.971624719644686], 
             UndirectedEdge[46, 146] -> 
             RGBColor[
              0.6753878927671468, 0.740021014844125, 0.9308319277914963], 
             UndirectedEdge[23, 25] -> 
             RGBColor[
              0.829084080112281, 0.8652392096758066, 0.883502259875953], 
             UndirectedEdge[9, 28] -> 
             RGBColor[
              0.9931914535915799, 0.9914525053355262, 0.7624987641481991], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.7353021841783035, 0.7925539168985241, 0.9749887774173971], 
             UndirectedEdge[103, 129] -> 
             RGBColor[
              0.6657392202161474, 0.737264057308209, 0.9683683214334254], 
             UndirectedEdge[5, 48] -> 
             RGBColor[
              0.8577458023458223, 0.8894072361737401, 0.9862937544181034], 
             UndirectedEdge[36, 169] -> 
             RGBColor[
              0.6172574479171096, 0.700156429207075, 0.9630119138700198], 
             UndirectedEdge[159, 170] -> 
             RGBColor[
              0.8651189310341654, 0.8952863688515782, 0.9869970100144673], 
             UndirectedEdge[86, 175] -> 
             RGBColor[
              0.7609135764307833, 0.813150736155881, 0.9768044122231138], 
             UndirectedEdge[9, 97] -> 
             RGBColor[
              0.9650518532604073, 0.8861252563555694, 0.4986914198526865], 
             UndirectedEdge[7, 88] -> 
             RGBColor[
              0.6629062667629514, 0.7344482105212939, 0.9685200044082675], 
             UndirectedEdge[5, 77] -> 
             RGBColor[
              0.5102174554045094, 0.5909267911140583, 0.9591229849137931], 
             UndirectedEdge[103, 131] -> 
             RGBColor[
              0.8669682739522546, 0.8967798001970443, 0.979181824547177], 
             UndirectedEdge[15, 193] -> 
             RGBColor[
              0.8186577306668139, 0.8585871489314323, 0.9824732356394411], 
             UndirectedEdge[167, 181] -> 
             RGBColor[
              0.7644845206573334, 0.8159403849258432, 0.9771603305712452], 
             UndirectedEdge[99, 146] -> 
             RGBColor[
              0.5359627967340317, 0.6309694903064691, 0.9578667664379508], 
             UndirectedEdge[163, 177] -> 
             RGBColor[
              0.7487309769796284, 0.80376911182705, 0.9756855734564551], 
             UndirectedEdge[76, 116] -> 
             RGBColor[
              0.8597524076258323, 0.8912094604312457, 0.9818414809600007], 
             UndirectedEdge[15, 59] -> 
             RGBColor[
              0.7399338294503135, 0.7967611983627552, 0.974713347110983], 
             UndirectedEdge[36, 151] -> 
             RGBColor[
              0.7054056137837683, 0.7692487978041451, 0.9716402066932651], 
             UndirectedEdge[38, 98] -> 
             RGBColor[
              0.9563383331077789, 0.9649267251664593, 0.8722248993449899], 
             UndirectedEdge[70, 139] -> 
             RGBColor[
              0.9560269485536064, 0.9629867709938413, 0.74573105174246], 
             UndirectedEdge[56, 195] -> 
             RGBColor[
              0.8741085912162219, 0.7575520414512453, 0.6112834414850739], 
             UndirectedEdge[66, 168] -> 
             RGBColor[
              0.4394302303161963, 0.5537846799503466, 0.9495663053719796], 
             UndirectedEdge[6, 161] -> 
             RGBColor[
              0.9112467804502706, 0.931887683626718, 0.9851636316175987], 
             UndirectedEdge[56, 118] -> 
             RGBColor[
              0.9202764422330212, 0.9367365232078027, 0.8933009039077084], 
             UndirectedEdge[46, 117] -> 
             RGBColor[
              0.9653323311346091, 0.9736654898400651, 0.9435674999996799], 
             UndirectedEdge[79, 89] -> 
             RGBColor[
              0.6555837016618972, 0.7280689168048797, 0.9683003442050726], 
             UndirectedEdge[102, 140] -> 
             RGBColor[
              0.9163268544477573, 0.9309594335207713, 0.7118245583471032], 
             UndirectedEdge[32, 130] -> 
             RGBColor[
              0.9790503628240372, 0.9827334895188334, 0.8682700443370719], 
             UndirectedEdge[105, 126] -> 
             RGBColor[
              0.9935100925358942, 0.9912841075239011, 0.7353993960012556], 
             UndirectedEdge[86, 124] -> 
             RGBColor[
              0.6860130036024745, 0.7539041918754417, 0.9698406219265212], 
             UndirectedEdge[41, 168] -> 
             RGBColor[
              0.5401698669981898, 0.634674216182565, 0.9581091151928216], 
             UndirectedEdge[43, 143] -> 
             RGBColor[
              0.7584265047848049, 0.8115577697023715, 0.9765439216462286], 
             UndirectedEdge[56, 197] -> 
             RGBColor[
              0.9063994996600768, 0.9274955255950705, 0.9664275184965678], 
             UndirectedEdge[47, 73] -> 
             RGBColor[
              0.5992820532414014, 0.6851575718750087, 0.9618741510357525], 
             UndirectedEdge[23, 108] -> 
             RGBColor[
              0.7468914317133701, 0.7988922275975741, 0.8767714582089511], 
             UndirectedEdge[97, 155] -> 
             RGBColor[
              0.8138438065139646, 0.7699294844869291, 0.6182813344434805], 
             UndirectedEdge[86, 161] -> 
             RGBColor[
              0.8286910509483552, 0.8665826698336148, 0.9834314901793435], 
             UndirectedEdge[88, 188] -> 
             RGBColor[
              0.7444244385247817, 0.7971764284534857, 0.8885756867607435], 
             UndirectedEdge[136, 197] -> 
             RGBColor[
              0.9765661250553521, 0.9810749794966789, 0.8811732467435385], 
             UndirectedEdge[65, 69] -> 
             RGBColor[
              0.8212772465855898, 0.8612055525928594, 0.9806986190291698], 
             UndirectedEdge[23, 67] -> 
             RGBColor[
              0.7075468066433405, 0.7661581618055313, 0.8738930274286671], 
             UndirectedEdge[31, 121] -> 
             RGBColor[
              0.9455605072255278, 0.958823341726141, 0.9736953794074265], 
             UndirectedEdge[52, 145] -> 
             RGBColor[
              0.9225634394436553, 0.9402852413754679, 0.9645378612580796], 
             UndirectedEdge[12, 87] -> 
             RGBColor[
              0.9094477051713528, 0.9299012045886472, 0.9658557460723607], 
             UndirectedEdge[128, 192] -> 
             RGBColor[
              0.6551578200571264, 0.7304121200903644, 0.9663466791524294], 
             UndirectedEdge[78, 95] -> 
             RGBColor[
              0.6494095682505605, 0.7260429575036412, 0.9656907347519095], 
             UndirectedEdge[123, 165] -> 
             RGBColor[
              0.8657436701917511, 0.8957486893576756, 0.9752915724916968], 
             UndirectedEdge[24, 56] -> 
             RGBColor[
              0.8048151614824238, 0.8476870844152472, 0.9811163977477244], 
             UndirectedEdge[50, 177] -> 
             RGBColor[
              0.8068628693118909, 0.8473984805980199, 0.8739151782324037], 
             UndirectedEdge[18, 58] -> 
             RGBColor[
              0.835864304250997, 0.8725402616726756, 0.9790742658953504], 
             UndirectedEdge[96, 182] -> 
             RGBColor[
              0.5485013498274056, 0.6443371313509323, 0.9575991819665123], 
             UndirectedEdge[49, 131] -> 
             RGBColor[
              0.9363488129913196, 0.9518545370728866, 0.9858650604009865], 
             UndirectedEdge[28, 106] -> 
             RGBColor[
              0.8467496647643591, 0.8789801703782839, 0.8825637347851685], 
             UndirectedEdge[57, 81] -> 
             RGBColor[
              0.9045141423738428, 0.9265676577787259, 0.986199421013051], 
             UndirectedEdge[7, 115] -> 
             RGBColor[
              0.7019715614975242, 0.7661631766582926, 0.9715953675106628], 
             UndirectedEdge[54, 94] -> 
             RGBColor[
              0.9830779983546063, 0.9862873166762521, 0.886083469426038], 
             UndirectedEdge[138, 181] -> 
             RGBColor[
              0.8523885693747921, 0.8816806188020812, 0.7721533151331097], 
             UndirectedEdge[55, 182] -> 
             RGBColor[
              0.7650972410036823, 0.7832971593824459, 0.6499460550784701], 
             UndirectedEdge[17, 77] -> 
             RGBColor[
              0.5870538881873932, 0.6487472464504732, 0.8251682165376497], 
             UndirectedEdge[144, 149] -> 
             RGBColor[
              0.746379220933709, 0.7580278385699686, 0.6335042867598901], 
             UndirectedEdge[68, 179] -> 
             RGBColor[
              0.7468122767533155, 0.8023367037453579, 0.9753903322864721], 
             UndirectedEdge[103, 143] -> 
             RGBColor[
              0.7096032872781735, 0.772874883002864, 0.9718214614719201], 
             UndirectedEdge[80, 173] -> 
             RGBColor[
              0.9939185328631065, 0.9911391673068373, 0.7058175704954326], 
             UndirectedEdge[161, 199] -> 
             RGBColor[
              0.9349901527012202, 0.9486043792465099, 0.90059004294217], 
             UndirectedEdge[43, 133] -> 
             RGBColor[
              0.590312050004776, 0.6693384348743912, 0.9645588011557933], 
             UndirectedEdge[6, 193] -> 
             RGBColor[
              0.9015089298637153, 0.9241229858959115, 0.9842348267355712], 
             UndirectedEdge[181, 188] -> 
             RGBColor[
              0.8502189183884651, 0.8820148465974713, 0.8976223161097412], 
             UndirectedEdge[120, 173] -> 
             RGBColor[
              0.8578609554936791, 0.8864415425434388, 0.8116131918124044], 
             UndirectedEdge[2, 158] -> 
             RGBColor[
              0.9275846681209554, 0.943238483835256, 0.9232905477930192], 
             UndirectedEdge[95, 143] -> 
             RGBColor[
              0.642937632478428, 0.7207951667955603, 0.9651768520274462], 
             UndirectedEdge[4, 172] -> 
             RGBColor[
              0.8197959263313668, 0.8596075842537603, 0.9825518457971594], 
             UndirectedEdge[89, 113] -> 
             RGBColor[
              0.9193937763010609, 0.9375526686631299, 0.957122185428382], 
             UndirectedEdge[34, 90] -> 
             RGBColor[
              0.952276531507342, 0.9639284958549592, 0.9656675632707465], 
             UndirectedEdge[28, 48] -> 
             RGBColor[
              0.9326319472724856, 0.9465085216258455, 0.8910078551791334], 
             UndirectedEdge[5, 189] -> 
             RGBColor[
              0.8404507650441143, 0.8756166428906393, 0.9846441383208044], 
             UndirectedEdge[8, 55] -> 
             RGBColor[
              0.8545656477029149, 0.8544629642445499, 0.6579934790953845], 
             UndirectedEdge[29, 138] -> 
             RGBColor[
              0.7623499215794073, 0.8096334949232862, 0.764347042600043], 
             UndirectedEdge[8, 68] -> 
             RGBColor[
              0.6867843016630759, 0.7551327830249943, 0.9694894657901377], 
             UndirectedEdge[176, 187] -> 
             RGBColor[
              0.8418841247613708, 0.8770395811333451, 0.9693776806775773], 
             UndirectedEdge[65, 133] -> 
             RGBColor[
              0.4991847811678572, 0.5976073017529646, 0.9556198684987183], 
             UndirectedEdge[68, 147] -> 
             RGBColor[
              0.7983155545149249, 0.8427439378303803, 0.9574173180504008], 
             UndirectedEdge[89, 192] -> 
             RGBColor[
              0.769883078980826, 0.8205126035998105, 0.977604249064328], 
             UndirectedEdge[2, 74] -> 
             RGBColor[
              0.7135074616230701, 0.7721374208226116, 0.9042812595079475], 
             UndirectedEdge[156, 185] -> 
             RGBColor[
              0.37967415047605757`, 0.5023967631746475, 0.9454798870892085], 
             UndirectedEdge[126, 182] -> 
             RGBColor[
              0.7756915083503855, 0.822048431045934, 0.8696329820954118], 
             UndirectedEdge[18, 188] -> 
             RGBColor[
              0.8600094822829436, 0.8896633095228794, 0.8985981480207215], 
             UndirectedEdge[68, 156] -> 
             RGBColor[
              0.5469539686366047, 0.6430808975915119, 0.9574773664509284], 
             UndirectedEdge[29, 181] -> 
             RGBColor[
              0.6208839319808201, 0.7020502657448828, 0.9640155043359435], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.7571070304216301, 0.8085600916226992, 0.9346228670950725], 
             UndirectedEdge[30, 180] -> 
             RGBColor[
              0.975313437365581, 0.9793744717118601, 0.8489792398167227], 
             UndirectedEdge[31, 196] -> 
             RGBColor[
              0.9507845169360735, 0.9627193996147352, 0.9648524936074171], 
             UndirectedEdge[193, 199] -> 
             RGBColor[
              0.9252523021146649, 0.9408396815157033, 0.8996612380601426], 
             UndirectedEdge[30, 110] -> 
             RGBColor[
              0.975023417333431, 0.9792545409753912, 0.8537856222972307], 
             UndirectedEdge[12, 59] -> 
             RGBColor[
              0.7788601576912468, 0.8274523157779505, 0.9785184386561316], 
             UndirectedEdge[38, 156] -> 
             RGBColor[
              0.7261891666843501, 0.7815178108222811, 0.8514227644031831], 
             UndirectedEdge[72, 152] -> 
             RGBColor[
              0.9013505698011945, 0.9209842041648734, 0.8585045040126322], 
             UndirectedEdge[37, 79] -> 
             RGBColor[
              0.7209423601831173, 0.7763483381576648, 0.8017197809093164], 
             UndirectedEdge[170, 197] -> 
             RGBColor[
              0.9240963396683254, 0.9416065054497227, 0.9681154588947102], 
             UndirectedEdge[86, 127] -> 
             RGBColor[
              0.7955677606837609, 0.8402228482758622, 0.9802584174476865], 
             UndirectedEdge[69, 127] -> 
             RGBColor[
              0.8756832209928003, 0.9037079133004926, 0.9861212981053429], 
             UndirectedEdge[58, 61] -> 
             RGBColor[
              0.9031204074300749, 0.9254452168372851, 0.9856811376251002], 
             UndirectedEdge[11, 17] -> 
             RGBColor[
              0.8487122991854861, 0.8797089854929354, 0.8438960962382], 
             UndirectedEdge[11, 15] -> 
             RGBColor[
              0.7396060481407138, 0.7965051331124657, 0.9746806769333326], 
             UndirectedEdge[111, 157] -> 
             RGBColor[
              0.8408982458885942, 0.5144509512997348, 0.5755769144827586], 
             UndirectedEdge[75, 191] -> 
             RGBColor[
              0.6689592907569701, 0.7358190077974578, 0.9503601006962668], 
             UndirectedEdge[98, 156] -> 
             RGBColor[
              0.6887222053624209, 0.7547381916916581, 0.9713218308569264], 
             UndirectedEdge[28, 140] -> 
             RGBColor[
              0.9156526603286634, 0.9329696991073079, 0.8893883556328431], 
             UndirectedEdge[105, 157] -> 
             RGBColor[
              0.9297057758708376, 0.9431738470228205, 0.838458851668457], 
             UndirectedEdge[3, 15] -> 
             RGBColor[
              0.8332758972369328, 0.8702432781548841, 0.9838675294166904], 
             UndirectedEdge[55, 96] -> 
             RGBColor[
              0.7543016992376186, 0.7745328522431412, 0.6490961904852732], 
             UndirectedEdge[6, 64] -> 
             RGBColor[
              0.9473230584661494, 0.9602342037714053, 0.9740525010568052], 
             UndirectedEdge[70, 134] -> 
             RGBColor[
              0.8774761921099306, 0.900823053239747, 0.7381139480716339], 
             UndirectedEdge[106, 140] -> 
             RGBColor[
              0.7711221244306772, 0.821287716353264, 0.9777789190683657], 
             UndirectedEdge[64, 154] -> 
             RGBColor[
              0.9718935424852475, 0.9772929313631296, 0.8757715298865134], 
             UndirectedEdge[8, 157] -> 
             RGBColor[
              0.8013555983845615, 0.8451039754069574, 0.9807398617795277], 
             UndirectedEdge[83, 124] -> 
             RGBColor[
              0.7769381704165033, 0.8254511183122231, 0.9574054890942193], 
             UndirectedEdge[22, 128] -> 
             RGBColor[
              0.8034906258861505, 0.846573715608159, 0.947858478567801], 
             UndirectedEdge[83, 135] -> 
             RGBColor[
              0.9536645322937853, 0.964963664568846, 0.9633180399878813], 
             UndirectedEdge[62, 68] -> 
             RGBColor[
              0.523992027495857, 0.623335104903884, 0.9559748271254995], 
             UndirectedEdge[105, 116] -> 
             RGBColor[
              0.8868224915207051, 0.9093134750334306, 0.8342800798912686], 
             UndirectedEdge[93, 145] -> 
             RGBColor[
              0.8081529913195715, 0.8505248956705928, 0.9813879740002618], 
             UndirectedEdge[128, 195] -> 
             RGBColor[
              0.7664804999732944, 0.673110646802962, 0.6007028057622837], 
             UndirectedEdge[87, 154] -> 
             RGBColor[
              0.9779430601464191, 0.9818046517296553, 0.8655312744530503], 
             UndirectedEdge[138, 167] -> 
             RGBColor[
              0.9059505102559204, 0.9235236141042465, 0.7774918688353447], 
             UndirectedEdge[179, 194] -> 
             RGBColor[
              0.7952445629849649, 0.8402799741275297, 0.980144043054185], 
             UndirectedEdge[118, 144] -> 
             RGBColor[
              0.9769479157029177, 0.9387254539628644, 0.5559819656976123], 
             UndirectedEdge[47, 188] -> 
             RGBColor[
              0.8291765515772855, 0.8655763897166668, 0.8955250096381009], 
             UndirectedEdge[11, 20] -> 
             RGBColor[
              0.8487323190311507, 0.8797518059184952, 0.8460751328906329], 
             UndirectedEdge[124, 187] -> 
             RGBColor[
              0.6627605227994477, 0.7357391771467177, 0.967523031946863], 
             UndirectedEdge[28, 189] -> 
             RGBColor[
              0.9153369099707775, 0.9327179283427449, 0.8893582390818343], 
             UndirectedEdge[84, 93] -> 
             RGBColor[
              0.7360611369656918, 0.7937358215602157, 0.9743273533164847], 
             UndirectedEdge[18, 94] -> 
             RGBColor[
              0.859192311023129, 0.8893253882066027, 0.9121407905672791], 
             UndirectedEdge[146, 156] -> 
             RGBColor[
              0.4141274052054349, 0.532975389937747, 0.9476482346949602], 
             UndirectedEdge[2, 26] -> 
             RGBColor[
              0.9460760866197283, 0.9579830390099938, 0.9250542757969165], 
             UndirectedEdge[124, 161] -> 
             RGBColor[
              0.7371448408756156, 0.7943324272262975, 0.9748086183245501], 
             UndirectedEdge[25, 67] -> 
             RGBColor[
              0.5456744893096253, 0.6408691193003335, 0.9578558586842086], 
             UndirectedEdge[15, 77] -> 
             RGBColor[
              0.477947637142621, 0.5655433940700035, 0.9559527972327824], 
             UndirectedEdge[23, 49] -> 
             RGBColor[
              0.9595449685312938, 0.9680303797151129, 0.8962734141276378], 
             UndirectedEdge[27, 37] -> 
             RGBColor[
              0.6714733445850918, 0.7335007632316739, 0.7985676589791432], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.7392980509443481, 0.7961414275963803, 0.974908000548084], 
             UndirectedEdge[134, 139] -> 
             RGBColor[
              0.8403206153421738, 0.8759833882817418, 0.9845068621279072], 
             UndirectedEdge[13, 127] -> 
             RGBColor[
              0.8934485475590392, 0.9169572647655412, 0.956049234167944], 
             UndirectedEdge[59, 186] -> 
             RGBColor[
              0.8371841304192238, 0.8730358618524334, 0.9521010147943088], 
             UndirectedEdge[119, 149] -> 
             RGBColor[
              0.6590626023489017, 0.7318585911867888, 0.9678325174897943], 
             UndirectedEdge[41, 66] -> 
             RGBColor[
              0.6000732567308318, 0.6853100895679249, 0.9622713279918569], 
             UndirectedEdge[25, 103] -> 
             RGBColor[
              0.7282921121585136, 0.7876666003340728, 0.9735530095293699], 
             UndirectedEdge[164, 166] -> 
             RGBColor[
              0.7609630393626539, 0.8097488072076401, 0.8541602910413119], 
             UndirectedEdge[30, 90] -> 
             RGBColor[
              0.9614699650142975, 0.9707849435115807, 0.9501054783749484], 
             UndirectedEdge[75, 182] -> 
             RGBColor[
              0.4694118660885119, 0.578125122527612, 0.9519265695663268], 
             UndirectedEdge[92, 97] -> 
             RGBColor[
              0.9535672014100238, 0.8793726865698731, 0.5993067711992183], 
             UndirectedEdge[18, 61] -> 
             RGBColor[
              0.7977598107442401, 0.8422992706391038, 0.9803803124207203], 
             UndirectedEdge[76, 191] -> 
             RGBColor[
              0.9495928165525636, 0.9619269856358653, 0.9702103926642249], 
             UndirectedEdge[129, 197] -> 
             RGBColor[
              0.7526078718076594, 0.8055764922835784, 0.9522127200692723], 
             UndirectedEdge[97, 112] -> 
             RGBColor[
              0.8104235293764509, 0.7672575379920343, 0.6179404331827203], 
             UndirectedEdge[87, 131] -> 
             RGBColor[
              0.9543192829708222, 0.9654519765517242, 0.962209717877984], 
             UndirectedEdge[33, 198] -> 
             RGBColor[
              0.9139059786920886, 0.9311366814694755, 0.8701040980120611], 
             UndirectedEdge[39, 114] -> 
             RGBColor[
              0.3216005121285118, 0.4497189788502137, 0.9418323311671087], 
             UndirectedEdge[144, 170] -> 
             RGBColor[
              0.9240575480768134, 0.8990830583515792, 0.6498943139822432], 
             UndirectedEdge[64, 110] -> 
             RGBColor[
              0.9730150489026782, 0.9777567030881373, 0.8571852661841168], 
             UndirectedEdge[108, 131] -> 
             RGBColor[
              0.7236952761733959, 0.7827163849553478, 0.9663631044822998], 
             UndirectedEdge[33, 141] -> 
             RGBColor[
              0.796014754671873, 0.8406872516733586, 0.9802723968914107], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.9033981875101813, 0.9253894842221215, 0.9760960015058238], 
             UndirectedEdge[88, 142] -> 
             RGBColor[
              0.48903769927900687`, 0.5960618610288124, 0.9529179855728132], 
             UndirectedEdge[12, 95] -> 
             RGBColor[
              0.7554310413530395, 0.8091493120266637, 0.9761832432970796], 
             UndirectedEdge[131, 162] -> 
             RGBColor[
              0.8983859180103909, 0.9215839550904268, 0.9822441255878291], 
             UndirectedEdge[21, 194] -> 
             RGBColor[
              0.8018012140907709, 0.8455080697437463, 0.9807694222898483], 
             UndirectedEdge[131, 154] -> 
             RGBColor[
              0.9681878635416445, 0.9745292420744828, 0.8820442777421751], 
             UndirectedEdge[81, 184] -> 
             RGBColor[
              0.9312787661183746, 0.9440183240060899, 0.8053905676612306], 
             UndirectedEdge[105, 111] -> 
             RGBColor[
              0.9061265299822434, 0.5628498957230856, 0.4270999371856984]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 71 -> 
             RGBColor[
              0.4531843256492155, 0.5669472179960187, 0.9500974823885716], 10 -> 
             RGBColor[
              0.8644774917771884, 0.8947749025994696, 0.9869358289655172], 68 -> 
             RGBColor[
              0.6353348983342173, 0.7148325178355436, 0.9644350369867374], 
             155 -> RGBColor[
              0.692686613027929, 0.759851313801444, 0.9700041861283403], 132 -> 
             RGBColor[
              0.41507303868790285`, 0.5339371367591088, 0.9476690648838846], 
             26 -> RGBColor[
              0.9048033582161279, 0.9269296538813956, 0.9907821461057893], 29 -> 
             RGBColor[
              0.5308452841854353, 0.630003141866088, 0.9562092318028769], 113 -> 
             RGBColor[
              0.9749039826419097, 0.980804011862069, 0.9273651906843502], 50 -> 
             RGBColor[
              0.991866530103167, 0.9909046154240869, 0.784456175143275], 173 -> 
             RGBColor[
              0.9945702652893273, 0.9907946714212889, 0.650385069060767], 192 -> 
             RGBColor[
              0.6758825880014396, 0.7467238817354301, 0.968329317956242], 165 -> 
             RGBColor[
              0.7827186407972954, 0.8301850181636272, 0.9789777372592559], 92 -> 
             RGBColor[
              0.9721334028200475, 0.9787377179673321, 0.9320550596398157], 11 -> 
             RGBColor[
              0.7022438219961856, 0.7673174780849245, 0.9709567594011005], 
             137 -> RGBColor[
              0.9855777449666363, 0.9883040411557253, 0.88867761970982], 120 -> 
             RGBColor[
              0.721151645698031, 0.7820884136655887, 0.9728413145640419], 51 -> 
             RGBColor[
              0.9585066923076924, 0.8716954714412026, 0.29330676427939895`], 
             72 -> RGBColor[
              0.8078819656706931, 0.8498427988030779, 0.9814857823179955], 64 -> 
             RGBColor[
              0.9519754442532538, 0.9637039454738452, 0.9661772254557855], 41 -> 
             RGBColor[
              0.7008128934128254, 0.7661996258001433, 0.970814137812699], 103 -> 
             RGBColor[
              0.7893724615384614, 0.8353830334975368, 0.9796409279272451], 
             162 -> RGBColor[
              0.8522077496547341, 0.884991343284302, 0.9857655300085495], 196 -> 
             RGBColor[
              0.9696065404350132, 0.976853188137931, 0.9363323785464192], 179 -> 
             RGBColor[
              0.8582896551724137, 0.8898408896551724, 0.9863456275862069], 
             160 -> RGBColor[
              0.36186589626992516`, 0.4878517842653923, 0.9442787528182397], 
             123 -> RGBColor[
              0.9487686995862068, 0.9613123605517241, 0.971605407724138], 150 -> 
             RGBColor[
              0.8654173934888757, 0.8955243547114167, 0.9870254776298382], 
             188 -> RGBColor[
              0.9895152570007251, 0.9899323035712647, 0.8234228553504723], 46 -> 
             RGBColor[
              0.9810940140624158, 0.9854205271602362, 0.9168870821081916], 
             182 -> RGBColor[
              0.5592968915934694, 0.6531014384902372, 0.9584490465597093], 6 -> 
             RGBColor[
              0.9426706726790451, 0.9567644620689656, 0.9819277766578248], 
             131 -> RGBColor[
              0.9445640863660477, 0.9581765668965517, 0.9787227211671088], 45 -> 
             RGBColor[
              0.9560308461538461, 0.8633438610079573, 0.28368856949602095`], 
             195 -> RGBColor[
              0.8985279478337755, 0.6321209351606255, 0.23704157117595062`], 
             148 -> RGBColor[
              0.9375103606074827, 0.9529159097752298, 0.9906628389700405], 
             161 -> RGBColor[
              0.8798228882214962, 0.9070109051844706, 0.9883994865773724], 1 -> 
             RGBColor[
              0.9833687766578249, 0.9871170413793103, 0.913036502387268], 101 -> 
             RGBColor[
              0.92945409316357, 0.946585480802111, 0.9931333552110472], 12 -> 
             RGBColor[
              0.8548209307671087, 0.8870750229703979, 0.9860147775558621], 39 -> 
             RGBColor[
              0.2735192527851458, 0.4048164551724137, 0.9388878888594164], 48 -> 
             RGBColor[
              0.873983693882626, 0.9023548901193634, 0.9878425390086207], 77 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 56 -> 
             RGBColor[
              0.8496892345986683, 0.8829831477418651, 0.985525311794197], 110 -> 
             RGBColor[
              0.9940546535521027, 0.9918094607024295, 0.7481933069124482], 73 -> 
             RGBColor[
              0.5297262603289568, 0.6290946678879483, 0.9561211381457754], 37 -> 
             RGBColor[
              0.9946008870026525, 0.9908601681697613, 0.6537180535809014], 
             130 -> RGBColor[
              0.9911915881130501, 0.9906255095659556, 0.7956417106133933], 
             107 -> RGBColor[
              0.6298471935490715, 0.7103773518726789, 0.9640030247639256], 59 -> 
             RGBColor[
              0.7028993846153848, 0.7678296085855033, 0.9710220997564012], 47 -> 
             RGBColor[
              0.6688378461538461, 0.741220475862069, 0.9676271639257294], 159 -> 
             RGBColor[
              0.8451549474531654, 0.8793676302519869, 0.985092827438453], 55 -> 
             RGBColor[
              0.9708975904138951, 0.9134928802746547, 0.34144306359723103`], 
             49 -> RGBColor[
              0.9281335396165914, 0.9455325072492214, 0.9930073996348643], 82 -> 
             RGBColor[
              0.991139321089019, 0.9906038958083175, 0.7965079104643091], 199 -> 
             RGBColor[
              0.9901574171809442, 0.9901978533085491, 0.8127805993069678], 89 -> 
             RGBColor[
              0.8638835699602122, 0.8943013254641909, 0.9868791801724138], 
             144 -> RGBColor[
              0.9630321815384614, 0.886961009251989, 0.31088743537400476`], 
             78 -> RGBColor[
              0.6427779845621506, 0.7208623139243527, 0.9650297604655218], 42 -> 
             RGBColor[
              0.4334255564553674, 0.5498331652249229, 0.9488384710875332], 
             154 -> RGBColor[
              0.9918116407172414, 0.9908819172524138, 0.7853658343172413], 
             168 -> RGBColor[
              0.37952684058355435`, 0.5031488065649867, 0.9454040925729443], 
             121 -> RGBColor[
              0.9591585210139218, 0.9690610723607428, 0.9540181501464379], 
             128 -> RGBColor[
              0.6344330521128132, 0.7141003584452985, 0.9643640403486169], 
             115 -> 
             RGBColor[
              0.5774642095179836, 0.6678504856097036, 0.9598792443758054], 61 -> 
             RGBColor[
              0.8650159139233179, 0.8952042258037134, 0.9869871841504702], 93 -> 
             RGBColor[
              0.7381268526656684, 0.7953495743650583, 0.9745332445522477], 88 -> 
             RGBColor[
              0.49933362004883824`, 0.6044205533357065, 0.9537285181710148], 
             21 -> RGBColor[
              0.8714029573840255, 0.9002970808876055, 0.9875963860575335], 62 -> 
             RGBColor[
              0.4126491566574968, 0.5318376919722243, 0.9475146172642618], 
             136 -> RGBColor[
              0.9900224853892189, 0.990142055545082, 0.8150167682881381], 190 -> 
             RGBColor[
              0.3430494068004115, 0.47155388683115906`, 0.9430797827480106], 
             57 -> RGBColor[
              0.9407938921747413, 0.9553647622418018, 0.9851046765088607], 
             111 -> RGBColor[0.817319, 0.134127, 0.164218], 63 -> 
             RGBColor[
              0.5517329965707574, 0.6469607277612119, 0.957853589036061], 75 -> 
             RGBColor[
              0.37952684058355435`, 0.5031488065649867, 0.9454040925729443], 
             30 -> RGBColor[
              0.9559921811147594, 0.9666996212483531, 0.9593779376820131], 5 -> 
             RGBColor[
              0.8415079108090187, 0.8764595822281167, 0.9847449698275862], 
             171 -> RGBColor[
              0.5517329965707574, 0.6469607277612119, 0.957853589036061], 102 -> 
             RGBColor[
              0.9926285889005331, 0.9866416219592545, 0.439045576778166], 31 -> 
             RGBColor[
              0.9319624934371338, 0.9485856110915393, 0.993372608668415], 96 -> 
             RGBColor[
              0.5377058080613419, 0.6355728242116275, 0.9567493173733153], 70 -> 
             RGBColor[
              0.993182525321363, 0.9878264359518466, 0.49933813768618673`], 
             52 -> RGBColor[
              0.9669477489138358, 0.9748702657748085, 0.9408330190678834], 
             183 -> RGBColor[
              0.7382337049919346, 0.7954330482144452, 0.9745438945935381], 
             158 -> RGBColor[
              0.867820521218582, 0.8974405435319199, 0.9872546900979949], 13 -> 
             RGBColor[
              0.9733207874257708, 0.9796232674621168, 0.9300451272218295], 
             170 -> RGBColor[
              0.8850829146151653, 0.9112051074511694, 0.9889011925904816], 86 -> 
             RGBColor[
              0.7775592136752141, 0.8261544344827589, 0.9784634937813145], 18 -> 
             RGBColor[
              0.7305037075651623, 0.7893943154744942, 0.9737734406909705], 
             153 -> RGBColor[
              0.6895358967192444, 0.7573899502747687, 0.9696901521718085], 58 -> 
             RGBColor[
              0.9412249009368319, 0.9556862078708569, 0.9843750910997302], 22 -> 
             RGBColor[
              0.9725481996594878, 0.9790470727710193, 0.9313529167869853], 66 -> 
             RGBColor[
              0.49933362004883824`, 0.6044205533357065, 0.9537285181710148], 
             143 -> RGBColor[
              0.6298341130178856, 0.710366732508191, 0.9640019950165951], 119 -> 
             RGBColor[
              0.7883989443688466, 0.8346225144856292, 0.9795438968338132], 
             145 -> RGBColor[
              0.8781791299734747, 0.9057002169761272, 0.9882427034482758], 91 -> 
             RGBColor[
              0.5871008615384617, 0.675673953846154, 0.9606378769230769], 177 -> 
             RGBColor[
              0.6218592085206146, 0.703892345771953, 0.9633741813215323], 200 -> 
             RGBColor[
              0.7109225797762051, 0.7740973896236778, 0.9718217768690102], 
             114 -> RGBColor[
              0.3696817714718778, 0.4946215025280138, 0.944776773474801], 24 -> 
             RGBColor[
              0.7599410883661794, 0.8123910210886293, 0.9767074837012517], 
             176 -> RGBColor[
              0.9527139974535809, 0.9642547572413793, 0.9649270475331565], 79 -> 
             RGBColor[
              0.44728383336358213`, 0.5618365081455684, 0.9497215082377315], 
             109 -> RGBColor[
              0.509394104326923, 0.6125881076923076, 0.9545205163461539], 135 -> 
             RGBColor[
              0.9479195172842994, 0.96067904178137, 0.9730428518590518], 108 -> 
             RGBColor[
              0.502826465980744, 0.6072562030141437, 0.9540034877974907], 191 -> 
             RGBColor[
              0.9583917409303859, 0.9684892090299289, 0.9553161088195892], 14 -> 
             RGBColor[
              0.9103473986117895, 0.9313503212039286, 0.9913109416279507], 
             185 -> RGBColor[
              0.30077526201312305`, 0.4334642490018149, 0.9404400782632976], 
             32 -> RGBColor[
              0.9669091375350244, 0.9748414694717112, 0.9408983780607506], 
             122 -> RGBColor[
              0.6758825880014396, 0.7467238817354301, 0.968329317956242], 187 -> 
             RGBColor[
              0.7310542520691606, 0.789824405025311, 0.9738283138219981], 193 -> 
             RGBColor[
              0.8603471870483856, 0.8914815097228574, 0.9865418768133175], 
             100 -> 
             RGBColor[
              0.9931565355004152, 0.9914380658074756, 0.7630774472839221], 
             180 -> RGBColor[
              0.9946346936164024, 0.9920493221753671, 0.7385805419514324], 7 -> 
             RGBColor[
              0.8264789134770646, 0.8644758677068815, 0.9833114906455201], 
             175 -> RGBColor[
              0.7442679391863524, 0.8001470378290029, 0.975145330664913], 9 -> 
             RGBColor[
              0.9951027065208146, 0.9922428575387247, 0.7308243569467522], 90 -> 
             RGBColor[
              0.9669477489138356, 0.9748702657748084, 0.9408330190678837], 
             174 -> RGBColor[
              0.9472683750450928, 0.9601934209655173, 0.9741450658249337], 
             142 -> RGBColor[
              0.47874177850917554`, 0.5877031687219184, 0.9521074529746116], 
             134 -> RGBColor[
              0.7617698588984981, 0.8138196705276475, 0.9768897584570809], 
             105 -> RGBColor[
              0.9949340599644869, 0.9915727914461714, 0.6899818743713968], 16 -> 
             RGBColor[
              0.7866468243261797, 0.8332537449916924, 0.9793692618824529], 
             139 -> RGBColor[
              0.9188713717858497, 0.9381471060358362, 0.9921239657987333], 
             146 -> RGBColor[
              0.3696817714718778, 0.4946215025280138, 0.944776773474801], 126 -> 
             RGBColor[
              0.9920861251073014, 0.9909954236016307, 0.7808169176311144], 
             198 -> RGBColor[
              0.9935741403481236, 0.9916107561439581, 0.7561566542306909], 40 -> 
             RGBColor[
              0.990863649867374, 0.99048989867374, 0.8010764960212198], 104 -> 
             RGBColor[
              0.4092254772300103, 0.5288722729312669, 0.9472964634385832], 
             181 -> RGBColor[
              0.7109225797762051, 0.7740973896236778, 0.9718217768690102], 
             127 -> RGBColor[
              0.8135763076923077, 0.8542912620689656, 0.9820533411140584], 76 -> 
             RGBColor[
              0.9407938921747413, 0.9553647622418018, 0.9851046765088607], 
             172 -> RGBColor[
              0.7630038806733436, 0.8147836977170696, 0.9770127542150084], 84 -> 
             RGBColor[
              0.7339954212657152, 0.7921220687553733, 0.9741214620807218], 
             184 -> RGBColor[
              0.9943231396638049, 0.9902660946965298, 0.6234869698052199], 
             151 -> RGBColor[
              0.8036180830628661, 0.8465118213031353, 0.9810607983478957], 35 -> 
             RGBColor[
              0.8440447074850106, 0.8784823550380413, 0.9849869317591674], 36 -> 
             RGBColor[
              0.6071931445046707, 0.6919857743051551, 0.9622196150386345], 34 -> 
             RGBColor[
              0.9376053141008486, 0.95298672593511, 0.9905021074736094], 38 -> 
             RGBColor[
              0.9938052944297082, 0.9917063442970823, 0.7523258328912467], 54 -> 
             RGBColor[
              0.9782750822281167, 0.9833181724137932, 0.9216587984084881], 60 -> 
             RGBColor[
              0.869782881095518, 0.899005276030949, 0.9874418617348765], 87 -> 
             RGBColor[
              0.9640744795755968, 0.9727273862068966, 0.9456967145888594], 
             141 -> RGBColor[
              0.7577916923076925, 0.8107118965517243, 0.97649325198939], 67 -> 
             RGBColor[
              0.42413721584068476`, 0.5417880714300582, 0.9482466262369227], 
             133 -> RGBColor[
              0.2936052034578279, 0.4259280628522304, 0.9400317540357245], 98 -> 
             RGBColor[
              0.9188713717858497, 0.9381471060358362, 0.9921239657987333], 3 -> 
             RGBColor[
              0.8895835201886236, 0.9147937681697612, 0.9893304643678161], 27 -> 
             RGBColor[
              0.3483458021675309, 0.4761413582935865, 0.9434172643773849], 
             163 -> RGBColor[
              0.8756027454386424, 0.9036458778821471, 0.987996965591378], 85 -> 
             RGBColor[
              0.7893724615384614, 0.8353830334975368, 0.9796409279272451], 83 -> 
             RGBColor[
              0.9594095473032714, 0.969248287356322, 0.9535932281167108], 28 -> 
             RGBColor[
              0.9912802006623452, 0.9906621531323277, 0.7941731713496459], 44 -> 
             RGBColor[
              0.36532294345529076`, 0.49084610478111224`, 0.9444990328079444],
              189 -> RGBColor[
              0.83939361927921, 0.8747737035531621, 0.9845433068140227], 15 -> 
             RGBColor[
              0.7769682742852421, 0.8256927881400071, 0.9784045944655647], 80 -> 
             RGBColor[
              0.9932668004368856, 0.9914836631923857, 0.7612500719300982], 
             112 -> RGBColor[
              0.6858460587529017, 0.7545074208116547, 0.9693223836068198], 
             169 -> RGBColor[
              0.6273217513295485, 0.7083270841089948, 0.9638042127014051], 69 -> 
             RGBColor[
              0.9377901342932929, 0.9531245645320198, 0.9901892550966274], 20 -> 
             RGBColor[
              0.9952208160661157, 0.9921861337520661, 0.7211935063801651], 8 -> 
             RGBColor[
              0.7382337049919346, 0.7954330482144452, 0.9745438945935381], 
             116 -> RGBColor[
              0.7787109230769234, 0.8270541586206898, 0.9785782854111406], 97 -> 
             RGBColor[
              0.9350010000000001, 0.7800076551724141, 0.26655848275862076`], 
             118 -> RGBColor[
              0.990863649867374, 0.99048989867374, 0.8010764960212198], 178 -> 
             RGBColor[
              0.9918116407172414, 0.9908819172524138, 0.7853658343172413], 81 -> 
             RGBColor[
              0.8682343925729443, 0.8977705533156499, 0.9872941655172414], 
             166 -> RGBColor[
              0.9938052944297082, 0.9917063442970823, 0.7523258328912467], 
             125 -> RGBColor[
              0.42413721584068476`, 0.5417880714300582, 0.9482466262369227], 
             95 -> RGBColor[
              0.6560411519389703, 0.7312236010829297, 0.9663517090382971], 
             157 -> RGBColor[
              0.8644774917771884, 0.8947749025994696, 0.9869358289655172], 74 -> 
             RGBColor[
              0.4396661082228116, 0.5552384175066312, 0.9492361135278514], 19 -> 
             RGBColor[
              0.9529629401922547, 0.9644404183282759, 0.9645056524112465], 
             156 -> RGBColor[
              0.45857303893899204`, 0.5713292773474801, 0.9505196959151194], 
             167 -> RGBColor[
              0.8180464615384617, 0.8577833802280086, 0.9824988842734802], 33 -> 
             RGBColor[
              0.8342378170360535, 0.8706626067949927, 0.9840515417934315], 43 -> 
             RGBColor[
              0.8870188965517243, 0.9127488068965519, 0.9890858482758621], 
             140 -> RGBColor[
              0.8400251199949815, 0.875277245082288, 0.9846035399160403], 186 -> 
             RGBColor[
              0.9714688762230628, 0.9782421151193634, 0.9331799298322163], 
             117 -> RGBColor[
              0.9495706482068024, 0.9619104525198939, 0.9702479178911682], 4 -> 
             RGBColor[
              0.87658797198939, 0.9044314707904509, 0.9880909373793103], 106 -> 
             RGBColor[
              0.7022191288663729, 0.7672981876242401, 0.9709542982206911], 65 -> 
             RGBColor[
              0.7047643588778865, 0.769286540653699, 0.9712079829617121], 53 -> 
             RGBColor[
              0.531484257769864, 0.630521889407359, 0.9562595341440805], 2 -> 
             RGBColor[
              0.9873488150233287, 0.989036424138592, 0.8593264054880435], 147 -> 
             RGBColor[
              0.9612962106956324, 0.970655357825217, 0.9503995991140641], 94 -> 
             RGBColor[
              0.9878809144810958, 0.9892564609387111, 0.8505081404435878], 23 -> 
             RGBColor[
              0.9909563974459962, 0.9905282521810044, 0.7995394286204115], 
             194 -> RGBColor[
              0.7321994707975161, 0.790719058599887, 0.9739424585221631], 129 -> 
             RGBColor[
              0.5421059788938333, 0.639145081118881, 0.9570957149396058], 99 -> 
             RGBColor[
              0.7022438219961856, 0.7673174780849245, 0.9709567594011005], 25 -> 
             RGBColor[
              0.6672117627785659, 0.7399501671706087, 0.9674650911314946], 
             138 -> RGBColor[
              0.9938545589733793, 0.9892638479804845, 0.5724848533972092], 
             124 -> RGBColor[
              0.594466793529735, 0.6816539492681243, 0.9612177500717278], 197 -> 
             RGBColor[
              0.9631097647214855, 0.9720079034482759, 0.9473297251989388], 
             164 -> RGBColor[
              0.5281207842955995, 0.6277912701181979, 0.9559947491913771], 
             152 -> RGBColor[
              0.9948191739316958, 0.9921256095266688, 0.7355232257072689], 17 -> 
             RGBColor[
              0.9951807763747864, 0.9921004929009465, 0.7168354330752995], 
             149 -> RGBColor[
              0.5297262603289568, 0.6290946678879483, 
               0.9561211381457754]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9lnk01I33xy0ZCmPGjGUM5jOLCfGgkIjPm8rSZv1l6yGUlK0nopQSkiYJ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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.7571070304216301, 0.8085600916226992, 0.9346228670950725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 78}], {
             RGBColor[
             0.8130733806099877, 0.8539896776518315, 0.9390331314263949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 88}], {
             RGBColor[
             0.7413511983533315, 0.7957687973575085, 0.9333825102791413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 89}], {
             RGBColor[
             0.9236261733090185, 0.9407091834217507, 0.9499578412798408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[
             0.9791363796498673, 0.9839605266206897, 0.9202008465358091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 122}], {
             RGBColor[
             0.8296256823296322, 0.8669204615573702, 0.940682910171755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 136}], {
             RGBColor[
             0.9866956310235219, 0.9886295484621961, 0.8640266353377031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 138}], {
             RGBColor[
             0.9886116678156021, 0.9881904446798975, 0.7427606778922387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 144}], {
             RGBColor[
             0.9732004790981431, 0.9370390253156496, 0.6119619688806364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 159}], {
             RGBColor[
             0.9142618620554952, 0.9332423358156486, 0.9490646649128605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 167}], {
             RGBColor[
             0.9007076190981433, 0.9224502108036594, 0.947767693330374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 197}], {
             RGBColor[
             0.9732392706896551, 0.9795624724137931, 0.9301831137931034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 26}], {
             RGBColor[
             0.9460760866197283, 0.9579830390099938, 0.9250542757969165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 40}], {
             RGBColor[
             0.9891062324453513, 0.989763161406166, 0.8302014507546316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 51}], {
             RGBColor[
             0.9729277536655105, 0.9303659477898973, 0.5763165848837213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 74}], {
             RGBColor[
             0.7135074616230701, 0.7721374208226116, 0.9042812595079475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 80}], {
             RGBColor[
             0.9903078077301072, 0.9902600436654889, 0.8102882387090709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 121}], {
             RGBColor[
             0.9732536680186252, 0.9790487482496675, 0.9066722778172407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 158}], {
             RGBColor[
             0.9275846681209554, 0.943238483835256, 0.9232905477930192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 164}], {
             RGBColor[
             0.7577347996594641, 0.808413847128395, 0.9076605773397103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 166}], {
             RGBColor[
             0.9905770547265185, 0.9903713842178372, 0.8058261191896451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 169}], {
             RGBColor[
             0.8073352831764387, 0.8486817541237934, 0.9115653090947243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 184}], {
             RGBColor[
             0.9908359773435669, 0.9896512594175609, 0.7414066876466316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 5}], {
             RGBColor[
             0.8655457154988211, 0.895626675198939, 0.9870377170977012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 10}], {
             RGBColor[
             0.877030505982906, 0.9047843353846154, 0.9881331466666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 11}], {
             RGBColor[
             0.7959136710924046, 0.8410556231273428, 0.9801436118844583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 15}], {
             RGBColor[
             0.8332758972369328, 0.8702432781548841, 0.9838675294166904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 20}], {
             RGBColor[
             0.9424021681273697, 0.9534899509609136, 0.8552619853739907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 28}], {
             RGBColor[
             0.9404318604254844, 0.9527279606510445, 0.891751817858731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 48}], {
             RGBColor[
             0.8817836070356249, 0.9085743291445623, 0.9885865016882185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 63}], {
             RGBColor[
             0.7206582583796906, 0.7808772479654866, 0.9735920267019386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 77}], {
             RGBColor[
             0.5342552600943118, 0.6100938840848806, 0.9614157321839081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 106}], {
             RGBColor[
             0.7959013245274983, 0.8410459778970006, 0.9801423812942536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 186}], {
             RGBColor[
             0.9305261982058433, 0.9465179416445624, 0.9612551971000163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 189}], {
             RGBColor[
             0.8644885697339169, 0.8947837358614616, 0.9869368855909194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 41}], {
             RGBColor[
             0.7887004327011077, 0.8353155482952972, 0.9794525375960046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 66}], {
             RGBColor[
             0.6879607960191141, 0.7544260120630788, 0.9709097277751626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 80}], {
             RGBColor[
             0.9349273862131378, 0.9479575669914183, 0.8746705046547043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 81}], {
             RGBColor[
             0.8724111822811671, 0.9011010120530505, 0.9876925514482758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 168}], {
             RGBColor[
             0.6280574062864721, 0.7037901386777188, 0.9667475149761273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 172}], {
             RGBColor[
             0.8197959263313668, 0.8596075842537603, 0.9825518457971594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 173}], {
             RGBColor[
             0.9355791186393587, 0.9476130711058699, 0.8192380032200386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 184}], {
             RGBColor[
             0.9354555558265975, 0.9473487827434903, 0.8057889535922651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 198}], {
             RGBColor[
             0.9350810561687568, 0.9480211134672045, 0.8721237958050005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 9}], {
             RGBColor[
             0.9183053086649167, 0.9343512198834207, 0.8577846633871692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.7718758664026022, 0.8218885301565206, 0.9778508646143433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 15}], {
             RGBColor[
             0.8092380925471303, 0.8510761851840619, 0.9815747821465755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 17}], {
             RGBColor[
             0.9183443435919025, 0.9342800375645316, 0.8507902014514428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 20}], {
             RGBColor[
             0.9183643634375671, 0.9343228579900914, 0.8529692381038756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 28}], {
             RGBColor[
             0.916394055735682, 0.9335608676802223, 0.8894590705886161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 48}], {
             RGBColor[
             0.8577458023458223, 0.8894072361737401, 0.9862937544181034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 63}], {
             RGBColor[
             0.696620453689888, 0.7617101549946643, 0.9712992794318236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[
             0.5102174554045094, 0.5909267911140583, 0.9591229849137931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 102}], {
             RGBColor[
             0.9170682498547759, 0.9315506020936857, 0.711895273302876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 106}], {
             RGBColor[
             0.7718635198376957, 0.8218788849261784, 0.9778496340241387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 112}], {
             RGBColor[
             0.7636769847809601, 0.8154835015198857, 0.977033676717203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 140}], {
             RGBColor[
             0.8407665154020001, 0.8758684136552024, 0.9846742548718133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 189}], {
             RGBColor[
             0.8404507650441143, 0.8756166428906393, 0.9846441383208044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 12}], {
             RGBColor[
             0.8987458017230769, 0.9219197425196817, 0.9839712771068434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 13}], {
             RGBColor[
             0.957995730052408, 0.9681938647655413, 0.9559864519398271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 14}], {
             RGBColor[
             0.9265090356454173, 0.9440573916364471, 0.9866193591428878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 16}], {
             RGBColor[
             0.8646587485026125, 0.8950091035303289, 0.9806485192701389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 59}], {
             RGBColor[
             0.8227850286472149, 0.8622970353272345, 0.976474938207113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 64}], {
             RGBColor[
             0.9473230584661494, 0.9602342037714053, 0.9740525010568052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 83}], {
             RGBColor[
             0.9510401099911583, 0.9630063747126438, 0.9677605023872677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 86}], {
             RGBColor[
             0.8601149431771296, 0.8914594482758622, 0.9801956352195696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 124}], {
             RGBColor[
             0.76856873310439, 0.8192092056685449, 0.9715727633647764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 137}], {
             RGBColor[
             0.9641242088228408, 0.9725342516123454, 0.9353026981838224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 161}], {
             RGBColor[
             0.9112467804502706, 0.931887683626718, 0.9851636316175987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 175}], {
             RGBColor[
             0.8434693059326988, 0.8784557499489842, 0.9785365536613689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 176}], {
             RGBColor[
             0.947692335066313, 0.9605096096551724, 0.9734274120954907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 186}], {
             RGBColor[
             0.9570697744510539, 0.9675032885941646, 0.9575538532450205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 187}], {
             RGBColor[
             0.8368624623741029, 0.8732944335471383, 0.9778780452399114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 193}], {
             RGBColor[
             0.9015089298637153, 0.9241229858959115, 0.9842348267355712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 199}], {
             RGBColor[
             0.9664140449299947, 0.9734811576887574, 0.8973541879823963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 18}], {
             RGBColor[
             0.7784913105211134, 0.8269350915906879, 0.9785424656682453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 42}], {
             RGBColor[
             0.629952234966216, 0.7071545164659021, 0.9660749808665267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 47}], {
             RGBColor[
             0.7476583798154554, 0.8028481717844752, 0.9754693272856247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.9023769978525906, 0.9238970200603374, 0.9524851445270042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 58}], {
             RGBColor[
             0.8838519072069482, 0.9100810377888692, 0.9838432908726251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.8457474137001912, 0.8798400467552974, 0.9851493373979952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 73}], {
             RGBColor[
             0.6781025869030106, 0.7467852677974149, 0.9697163143956478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 88}], {
             RGBColor[
             0.6629062667629514, 0.7344482105212939, 0.9685200044082675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 94}], {
             RGBColor[
             0.9071799139790802, 0.9268661643227962, 0.916909815544554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 97}], {
             RGBColor[
             0.8807399567385323, 0.8222417614396478, 0.6249349867020705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 115}], {
             RGBColor[
             0.7019715614975242, 0.7661631766582926, 0.9715953675106628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 153}], {
             RGBColor[
             0.7580074050981545, 0.810932908990825, 0.9765008214086643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 160}], {
             RGBColor[
             0.5941724048734949, 0.6761638259861369, 0.9637951217318799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 188}], {
             RGBColor[
             0.9079970852388948, 0.9272040856390731, 0.9033671729979962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 55}], {
             RGBColor[
             0.8545656477029149, 0.8544629642445499, 0.6579934790953845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 62}], {
             RGBColor[
             0.5754414308247158, 0.6636353700933347, 0.9610292559289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 68}], {
             RGBColor[
             0.6867843016630759, 0.7551327830249943, 0.9694894657901377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 75}], {
             RGBColor[
             0.5588802727877444, 0.6492909273897159, 0.9599739935832412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 96}], {
             RGBColor[
             0.6379697565266382, 0.7155029362130363, 0.9656466059834267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 99}], {
             RGBColor[
             0.7202387634940601, 0.7813752631496849, 0.9727503269973192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 107}], {
             RGBColor[
             0.684040449270503, 0.7529052000435621, 0.9692734596787318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 147}], {
             RGBColor[
             0.8497649578437836, 0.8830442030198311, 0.9624717468538011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 156}], {
             RGBColor[
             0.5984033719654633, 0.6833811627809626, 0.9625317952543287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 157}], {
             RGBColor[
             0.8013555983845615, 0.8451039754069574, 0.9807398617795277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 179}], {
             RGBColor[
             0.7982616800821742, 0.8426369689348088, 0.9804447610898726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 185}], {
             RGBColor[
             0.5195044835025289, 0.61444864860813, 0.9574919864284178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 194}], {
             RGBColor[
             0.7352165878947254, 0.7930760534071661, 0.9742431765578505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.8486732642585001, 0.8797801678118246, 0.8508905581739263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 17}], {
             RGBColor[
             0.9951417414478005, 0.9921716752198355, 0.7238298950110258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 20}], {
             RGBColor[
             0.9951617612934651, 0.9922144956453953, 0.7260089316634586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 28}], {
             RGBColor[
             0.9931914535915799, 0.9914525053355262, 0.7624987641481991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 63}], {
             RGBColor[
             0.7734178515457859, 0.8196017926499684, 0.8443389729914066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 77}], {
             RGBColor[
             0.5870148532604073, 0.6488184287693624, 0.8321626784733761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 97}], {
             RGBColor[
             0.9650518532604073, 0.8861252563555694, 0.4986914198526865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 102}], {
             RGBColor[
             0.9938656477106738, 0.9894422397489896, 0.584934966862459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.8486609176935938, 0.8797705225814824, 0.8508893275837217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 112}], {
             RGBColor[
             0.8404743826368581, 0.8733751391751896, 0.850073370276786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 140}], {
             RGBColor[
             0.9175639132578981, 0.9337600513105063, 0.8577139484313963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 189}], {
             RGBColor[
             0.9172481629000122, 0.9335082805459434, 0.8576838318803874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 14}], {
             RGBColor[
             0.8874124451944889, 0.9130626119016991, 0.989123385296734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.8207228830312152, 0.8602338453697383, 0.982670211715541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 28}], {
             RGBColor[
             0.9278788462197668, 0.9427185278658987, 0.8905545001575816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 48}], {
             RGBColor[
             0.8692305928299071, 0.8985648963594165, 0.987389183987069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 59}], {
             RGBColor[
             0.7836884381962865, 0.8313022555924865, 0.9789789643609592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 77}], {
             RGBColor[
             0.5217022458885942, 0.6000844512997348, 0.9602184144827586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 186}], {
             RGBColor[
             0.9179731840001255, 0.9365085088594165, 0.9600578793988668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 193}], {
             RGBColor[
             0.8624123394127869, 0.8931282061611635, 0.9867388528894174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 15}], {
             RGBColor[
             0.7396060481407138, 0.7965051331124657, 0.9746806769333326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 17}], {
             RGBColor[
             0.8487122991854861, 0.8797089854929354, 0.8438960962382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 20}], {
             RGBColor[
             0.8487323190311507, 0.8797518059184952, 0.8460751328906329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 28}], {
             RGBColor[
             0.8467620113292654, 0.8789898156086261, 0.8825649653753732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 48}], {
             RGBColor[
             0.7881137579394057, 0.8348361841021439, 0.9793996492048607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 63}], {
             RGBColor[
             0.6269884092834714, 0.7071391029230683, 0.9644051742185807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 77}], {
             RGBColor[
             0.4405854109980928, 0.5363557390424623, 0.9522288797005503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 106}], {
             RGBColor[
             0.7022314754312793, 0.7673078328545823, 0.9709555288108958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 112}], {
             RGBColor[
             0.6940449403745437, 0.7609124494482895, 0.9701395715039601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 140}], {
             RGBColor[
             0.7711344709955836, 0.8212973615836062, 0.9777801496585704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 189}], {
             RGBColor[
             0.7708187206376977, 0.8210455908190433, 0.9777500331075616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 13}], {
             RGBColor[
             0.9140708590964397, 0.9333491452162573, 0.9580299523888458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 14}], {
             RGBColor[
             0.8825841646894491, 0.9092126720871632, 0.9886628595919065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.8207338775466442, 0.8601643839810451, 0.9826920197191575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 23}], {
             RGBColor[
             0.9228886641065525, 0.9388016375757011, 0.8927771030881368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 25}], {
             RGBColor[
             0.7610163467728372, 0.8135125950705033, 0.9767399343436783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 59}], {
             RGBColor[
             0.7788601576912468, 0.8274523157779505, 0.9785184386561316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.9033981875101813, 0.9253894842221215, 0.9760960015058238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 86}], {
             RGBColor[
             0.8161900722211615, 0.8566147287265784, 0.9822391356685882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 87}], {
             RGBColor[
             0.9094477051713528, 0.9299012045886472, 0.9658557460723607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 95}], {
             RGBColor[
             0.7554310413530395, 0.8091493120266637, 0.9761832432970796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 108}], {
             RGBColor[
             0.6788236983739264, 0.7471656129922708, 0.9700091326766764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 154}], {
             RGBColor[
             0.9233162857421751, 0.9389784701114059, 0.8856903059365517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 161}], {
             RGBColor[
             0.8673219094943025, 0.8970429640774342, 0.9872071320666173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 175}], {
             RGBColor[
             0.7995444349767306, 0.8436110303997004, 0.9805800541103875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 193}], {
             RGBColor[
             0.8575840589077472, 0.8892782663466277, 0.9862783271845899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 16}], {
             RGBColor[
             0.8799838058759752, 0.9064385062269046, 0.9547071945521413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 64}], {
             RGBColor[
             0.9626481158395123, 0.971663606467981, 0.9481111763388075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 69}], {
             RGBColor[
             0.9555554608595318, 0.9663739159970683, 0.9601171911592284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 82}], {
             RGBColor[
             0.982230054257395, 0.9851135816352172, 0.8632765188430693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 83}], {
             RGBColor[
             0.966365167364521, 0.9744357774092194, 0.9418191776692701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 86}], {
             RGBColor[
             0.8754400005504924, 0.9028888509724379, 0.954254310501572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 101}], {
             RGBColor[
             0.9513874402946704, 0.9631043741321139, 0.9615892412164384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 108}], {
             RGBColor[
             0.7380736267032574, 0.7934397352381303, 0.9420243075096602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 110}], {
             RGBColor[
             0.9836877204889367, 0.9857163640822731, 0.8391192170671389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 124}], {
             RGBColor[
             0.7838937904777529, 0.8306386083651205, 0.9456314386467787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 127}], {
             RGBColor[
             0.8934485475590392, 0.9169572647655412, 0.956049234167944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 137}], {
             RGBColor[
             0.9794492661962035, 0.9839636543089211, 0.9093613734658248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 161}], {
             RGBColor[
             0.9265718378236335, 0.9433170863232937, 0.959222306899601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 175}], {
             RGBColor[
             0.8587943633060615, 0.8898851526455598, 0.9525952289433712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 176}], {
             RGBColor[
             0.9630173924396759, 0.9719390123517481, 0.9474860873774931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 187}], {
             RGBColor[
             0.8521875197474658, 0.884723836243714, 0.9519367205219138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 199}], {
             RGBColor[
             0.9817391023033575, 0.984910560385333, 0.8714128632643987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 15}], {
             RGBColor[
             0.8436578364485158, 0.8785215546719678, 0.9848577680467577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 48}], {
             RGBColor[
             0.8921655462472078, 0.916852605661646, 0.9895767403182858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 59}], {
             RGBColor[
             0.8066233916135872, 0.8495899648947159, 0.981166520692176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 186}], {
             RGBColor[
             0.9409081374174262, 0.9547962181616461, 0.9622454357300836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 193}], {
             RGBColor[
             0.8853472928300876, 0.911415915463393, 0.9889264092206341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 28}], {
             RGBColor[
             0.8841242374737937, 0.9081774706361674, 0.8862888829076053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 48}], {
             RGBColor[
             0.8254759840839341, 0.8640238391296853, 0.9831235667370928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 59}], {
             RGBColor[
             0.7399338294503135, 0.7967611983627552, 0.974713347110983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 63}], {
             RGBColor[
             0.6643506354279998, 0.7363267579506095, 0.9681290917508129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 77}], {
             RGBColor[
             0.477947637142621, 0.5655433940700035, 0.9559527972327824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 106}], {
             RGBColor[
             0.7395937015758075, 0.7964954878821235, 0.9746794463431279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.7314071665190719, 0.7901001044758309, 0.9738634890361922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 140}], {
             RGBColor[
             0.8084966971401117, 0.8504850166111475, 0.9815040671908025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 193}], {
             RGBColor[
             0.8186577306668139, 0.8585871489314323, 0.9824732356394411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 64}], {
             RGBColor[
             0.8693111342897167, 0.8984788452327688, 0.9727732436691192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 83}], {
             RGBColor[
             0.8730281858147255, 0.9012510161740072, 0.9664812449995819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 86}], {
             RGBColor[
             0.7821030190006969, 0.8297040897372256, 0.9789163778318837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 101}], {
             RGBColor[
             0.8580504587448748, 0.8899196128969017, 0.98625130854675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 124}], {
             RGBColor[
             0.6905568089279573, 0.7574538471299084, 0.9702935059770903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 127}], {
             RGBColor[
             0.8001115660092437, 0.843772503530329, 0.9807113014982556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 137}], {
             RGBColor[
             0.886112284646408, 0.9107788930737089, 0.9340234407961364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 161}], {
             RGBColor[
             0.833234856273838, 0.8701323250880815, 0.9838843742299126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 175}], {
             RGBColor[
             0.765457381756266, 0.8167003914103477, 0.977257296273683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 176}], {
             RGBColor[
             0.8696804108898804, 0.8987542511165358, 0.9721481547078047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.7588505381976702, 0.8115390750085016, 0.9765987878522255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 193}], {
             RGBColor[
             0.8234970056872827, 0.8623676273572749, 0.9829555693478852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 199}], {
             RGBColor[
             0.888402120753562, 0.9117257991501208, 0.8960749305947103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 20}], {
             RGBColor[
             0.995200796220451, 0.9921433133265063, 0.7190144697277323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 28}], {
             RGBColor[
             0.9932304885185659, 0.9913813230166371, 0.7555043022124728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 77}], {
             RGBColor[
             0.5870538881873932, 0.6487472464504732, 0.8251682165376497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 106}], {
             RGBColor[
             0.8486999526205796, 0.8796993402625932, 0.8438948656479953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 112}], {
             RGBColor[
             0.840513417563844, 0.8733039568563006, 0.8430789083410597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 140}], {
             RGBColor[
             0.917602948184884, 0.9336888689916172, 0.85071948649567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 189}], {
             RGBColor[
             0.9172871978269982, 0.9334370982270543, 0.8506893699446612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 47}], {
             RGBColor[
             0.6996707768595042, 0.7653073956682817, 0.97070030230835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 54}], {
             RGBColor[
             0.8543893948966395, 0.8863562439441437, 0.9477161195497292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 58}], {
             RGBColor[
             0.835864304250997, 0.8725402616726756, 0.9790742658953504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 61}], {
             RGBColor[
             0.7977598107442401, 0.8422992706391038, 0.9803803124207203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 73}], {
             RGBColor[
             0.6301149839470594, 0.7092444916812213, 0.9649472894183729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 94}], {
             RGBColor[
             0.859192311023129, 0.8893253882066027, 0.9121407905672791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 115}], {
             RGBColor[
             0.653983958541573, 0.7286224005420989, 0.966826342533388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 116}], {
             RGBColor[
             0.7546073153210429, 0.808224237047592, 0.9761758630510555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 153}], {
             RGBColor[
             0.7100198021422033, 0.7733921328746315, 0.9717317964313895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 160}], {
             RGBColor[
             0.5461848019175437, 0.6386230498699432, 0.9590260967546052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 174}], {
             RGBColor[
             0.8388860413051276, 0.8747938682200058, 0.9739592532579521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 188}], {
             RGBColor[
             0.8600094822829436, 0.8896633095228794, 0.8985981480207215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 33}], {
             RGBColor[
             0.8936003786141541, 0.9175515125616343, 0.974278597102339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 34}], {
             RGBColor[
             0.9452841271465516, 0.958713572131693, 0.977503879942428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 44}], {
             RGBColor[
             0.6591429418237728, 0.727643261554694, 0.9545023426095955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 50}], {
             RGBColor[
             0.9724147351477108, 0.9776725168761814, 0.8744809137772608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 60}], {
             RGBColor[
             0.9113729106438864, 0.9317228471796124, 0.9759737570730616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 90}], {
             RGBColor[
             0.9599553445530451, 0.9696553420515421, 0.9526693357395651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 130}], {
             RGBColor[
             0.9720772641526524, 0.9775329639471158, 0.8800736815123199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 141}], {
             RGBColor[
             0.8553773162499736, 0.8875761574400001, 0.9704994522003183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 177}], {
             RGBColor[
             0.7874110743564346, 0.8341663820501144, 0.9639399168663894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.9932505083642305, 0.9914241434421969, 0.7576833388649056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 77}], {
             RGBColor[
             0.5870739080330578, 0.648790066876033, 0.8273472531900825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 106}], {
             RGBColor[
             0.8487199724662443, 0.879742160688153, 0.8460739023004281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 189}], {
             RGBColor[
             0.9173072176726629, 0.9334799186526141, 0.852868406597094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.7392980509443481, 0.7961414275963803, 0.974908000548084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 46}], {
             RGBColor[
             0.9262484857232207, 0.9428588040239209, 0.9522417340828626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 85}], {
             RGBColor[
             0.8303877094612435, 0.8678400571925712, 0.9836186569923893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 109}], {
             RGBColor[
             0.6903985308554743, 0.7564425942899566, 0.9710584512018436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 132}], {
             RGBColor[
             0.6432379980359642, 0.7171171088233572, 0.9676327254707091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 150}], {
             RGBColor[
             0.8684101754364506, 0.8979107177995111, 0.9873109318436859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 151}], {
             RGBColor[
             0.8375105202234459, 0.8734044510953705, 0.9843285922027146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 194}], {
             RGBColor[
             0.8018012140907709, 0.8455080697437463, 0.9807694222898483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 196}], {
             RGBColor[
             0.9205047489095193, 0.9385751345127682, 0.9619643823019763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 24}], {
             RGBColor[
             0.8662446440128335, 0.8957190469298243, 0.9540302002441186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 37}], {
             RGBColor[
             0.9835745433310701, 0.9849536204703904, 0.7925354851839433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 38}], {
             RGBColor[
             0.983176747044598, 0.9853767085340508, 0.841839374839116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 79}], {
             RGBColor[
             0.709916016511535, 0.7704417904582939, 0.9405372125123583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 89}], {
             RGBColor[
             0.9182158848098501, 0.9366741991176051, 0.9591160484796996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 118}], {
             RGBColor[
             0.9817059247634309, 0.9847684857223797, 0.8662147064041026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 119}], {
             RGBColor[
             0.8804735720141672, 0.9068347936283243, 0.9554484068103992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 122}], {
             RGBColor[
             0.8242153938304637, 0.8628854772532247, 0.9498411173716137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 128}], {
             RGBColor[
             0.8034906258861505, 0.846573715608159, 0.947858478567801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 138}], {
             RGBColor[
             0.9832013793164336, 0.9841554603757519, 0.7519188850920973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 144}], {
             RGBColor[
             0.9677901905989745, 0.9330040410115041, 0.621120176080495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 149}], {
             RGBColor[
             0.7511372299942223, 0.8040708703294839, 0.9437370274663803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 181}], {
             RGBColor[
             0.8417353897178464, 0.8765722311973485, 0.9515873468279977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 183}], {
             RGBColor[
             0.8553909523257113, 0.8872400604927322, 0.9529484056902617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 190}], {
             RGBColor[
             0.6577988032299497, 0.7253004798010891, 0.9372163497674979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 192}], {
             RGBColor[
             0.8242153938304637, 0.8628854772532247, 0.9498411173716137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 25}], {
             RGBColor[
             0.829084080112281, 0.8652392096758066, 0.883502259875953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 43}], {
             RGBColor[
             0.9389876469988603, 0.9516385295387781, 0.8943126384481368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 49}], {
             RGBColor[
             0.9595449685312938, 0.9680303797151129, 0.8962734141276378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 64}], {
             RGBColor[
             0.971465920849625, 0.9771160988274248, 0.8828583270380985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 67}], {
             RGBColor[
             0.7075468066433405, 0.7661581618055313, 0.8738930274286671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 87}], {
             RGBColor[
             0.9775154385107965, 0.9816278191939505, 0.8726180716046354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 95}], {
             RGBColor[
             0.8234987746924832, 0.860875926631967, 0.8829455688293544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 103}], {
             RGBColor[
             0.8901644294922288, 0.9129556428392707, 0.8895901782738282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 108}], {
             RGBColor[
             0.7468914317133701, 0.7988922275975741, 0.8767714582089511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 129}], {
             RGBColor[
             0.7665311881699147, 0.8148366666499427, 0.8783175717800087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 131}], {
             RGBColor[
             0.967760241906022, 0.9743524095387781, 0.8891310748937602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 143}], {
             RGBColor[
             0.8103952552319409, 0.8504474923445977, 0.8817707118185033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 154}], {
             RGBColor[
             0.9913840190816188, 0.9907050847167092, 0.7924526314688264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 162}], {
             RGBColor[
             0.9215820735503651, 0.9377597977326532, 0.8926524793144806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.5541434452668551, 0.6442661896911079, 0.9600623740393184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 37}], {
             RGBColor[
             0.8772709876844159, 0.9016255946291953, 0.8152127686410766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 56}], {
             RGBColor[
             0.8048151614824238, 0.8476870844152472, 0.9811163977477244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 79}], {
             RGBColor[
             0.6036124608648807, 0.6871137646170988, 0.9632144959694916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 89}], {
             RGBColor[
             0.8119123291631958, 0.85334617327641, 0.9817933319368328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 118}], {
             RGBColor[
             0.8754023691167767, 0.9014404598811847, 0.8888919898612357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 119}], {
             RGBColor[
             0.7741700163675129, 0.8235067677871293, 0.9781256902675324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 125}], {
             RGBColor[
             0.592039152103432, 0.6770895462593438, 0.9624770549690872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 144}], {
             RGBColor[
             0.8614866349523204, 0.8496760151703091, 0.6437974595376282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 149}], {
             RGBColor[
             0.644833674347568, 0.7207428444882888, 0.9664143109235135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 170}], {
             RGBColor[
             0.8225120014906724, 0.8617980642698994, 0.9828043381458667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 190}], {
             RGBColor[
             0.5514952475832955, 0.6419724539598941, 0.9598936332246312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 195}], {
             RGBColor[
             0.8292345180999774, 0.7222559781246274, 0.6068745274386012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 197}], {
             RGBColor[
             0.8615254265438324, 0.8921994622684526, 0.9620186044500952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[
             0.7771153296651451, 0.8263494870335804, 0.9782754697036784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 49}], {
             RGBColor[
             0.7976726511975787, 0.8427413372099151, 0.9802362453831794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 64}], {
             RGBColor[
             0.8095936035159098, 0.851827056322227, 0.9668211582936401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 67}], {
             RGBColor[
             0.5456744893096253, 0.6408691193003335, 0.9578558586842086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 87}], {
             RGBColor[
             0.8156431211770814, 0.8563387766887527, 0.956580902860177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 95}], {
             RGBColor[
             0.661626457358768, 0.7355868841267692, 0.9669084000848959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 103}], {
             RGBColor[
             0.7282921121585136, 0.7876666003340728, 0.9735530095293699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 108}], {
             RGBColor[
             0.5850191143796549, 0.6736031850923763, 0.9607342894644926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 129}], {
             RGBColor[
             0.6046588708361995, 0.6895476241447449, 0.9622804030355502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 131}], {
             RGBColor[
             0.8058879245723067, 0.8490633670335802, 0.9730939061493017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 143}], {
             RGBColor[
             0.6485229378982258, 0.7251584498393999, 0.9657335430740448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 154}], {
             RGBColor[
             0.8295117017479037, 0.8654160422115112, 0.8764154627243679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 162}], {
             RGBColor[
             0.7597097562166499, 0.8124707552274553, 0.976615310570022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 40}], {
             RGBColor[
             0.9478335040417509, 0.9587097762775678, 0.8959293210635045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 51}], {
             RGBColor[
             0.9316550252619101, 0.8993125626612991, 0.6420444551925941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 74}], {
             RGBColor[
             0.6722347332194698, 0.7410840356940134, 0.9700091298168203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 80}], {
             RGBColor[
             0.9490350793265068, 0.9592066585368906, 0.8760161090179437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 121}], {
             RGBColor[
             0.9319809396150249, 0.9479953631210691, 0.9724001481261135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 158}], {
             RGBColor[
             0.8863119397173549, 0.9121850987066578, 0.9890184181018922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 164}], {
             RGBColor[
             0.7164620712558637, 0.7773604619997967, 0.9733884476485832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.9493043263229181, 0.9593179990892389, 0.871553989498518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 169}], {
             RGBColor[
             0.7660625547728381, 0.8176283689951952, 0.9772931794035973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 184}], {
             RGBColor[
             0.9495632489399664, 0.9585978742889627, 0.8071345579555046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 37}], {
             RGBColor[
             0.6714733445850918, 0.7335007632316739, 0.7985676589791432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 56}], {
             RGBColor[
             0.5990175183830997, 0.6795622530177259, 0.964471288085791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 67}], {
             RGBColor[
             0.3862415090041078, 0.5089647148618224, 0.9458319453071538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 119}], {
             RGBColor[
             0.5683723732681888, 0.6553819363896078, 0.961480580605599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 125}], {
             RGBColor[
             0.3862415090041078, 0.5089647148618224, 0.9458319453071538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 128}], {
             RGBColor[
             0.4913894271401721, 0.5951208583694425, 0.9538906523630009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 133}], {
             RGBColor[
             0.3209755028126794, 0.45103471057290845`, 0.9417245092065547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 190}], {
             RGBColor[
             0.34569760448397124`, 0.4738476225623728, 0.9432485235626977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 195}], {
             RGBColor[
             0.6234368750006531, 0.554131146727106, 0.5902294177766678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 48}], {
             RGBColor[
             0.9326319472724856, 0.9465085216258455, 0.8910078551791334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 63}], {
             RGBColor[
             0.7715065986165512, 0.8188114404467699, 0.8760133801928535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 77}], {
             RGBColor[
             0.5851036003311726, 0.6480280765661639, 0.863837085674823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 106}], {
             RGBColor[
             0.8467496647643591, 0.8789801703782839, 0.8825637347851685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 112}], {
             RGBColor[
             0.8385631297076235, 0.8725847869719912, 0.8817477774782329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 140}], {
             RGBColor[
             0.9156526603286634, 0.9329696991073079, 0.8893883556328431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 189}], {
             RGBColor[
             0.9153369099707775, 0.9327179283427449, 0.8893582390818343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 35}], {
             RGBColor[
             0.6874449958352229, 0.7542427484520646, 0.9705980817810221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 47}], {
             RGBColor[
             0.5998415651696407, 0.6856118088640785, 0.9619181978643032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 88}], {
             RGBColor[
             0.5150894521171367, 0.6172118476008972, 0.9549688749869458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 89}], {
             RGBColor[
             0.6973644270728238, 0.7621522336651394, 0.9715442059876453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 113}], {
             RGBColor[
             0.7528746334136724, 0.8054035768640785, 0.9417872112436135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 122}], {
             RGBColor[
             0.6033639360934375, 0.688363511800759, 0.9622692748795594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 136}], {
             RGBColor[
             0.7604338847873271, 0.810072598705585, 0.8856130000455075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 138}], {
             RGBColor[
             0.7623499215794073, 0.8096334949232862, 0.764347042600043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 142}], {
             RGBColor[
             0.5047935313473054, 0.6088531552940032, 0.9541583423887443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 144}], {
             RGBColor[
             0.7469387328619483, 0.7584820755590385, 0.6335483335884409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 153}], {
             RGBColor[
             0.6101905904523399, 0.6936965460704283, 0.9629496919873427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 159}], {
             RGBColor[
             0.6880001158193003, 0.7546853860590375, 0.970651029620665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 167}], {
             RGBColor[
             0.6744458728619485, 0.7438932610470483, 0.9693540580381785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 181}], {
             RGBColor[
             0.6208839319808201, 0.7020502657448828, 0.9640155043359435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 188}], {
             RGBColor[
             0.7601802705930802, 0.8099677227186763, 0.8898160435766747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 41}], {
             RGBColor[
             0.8284025372637924, 0.8664496235242483, 0.9650960377473561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 65}], {
             RGBColor[
             0.8303782699963229, 0.867993080951026, 0.9652929603218625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 66}], {
             RGBColor[
             0.7276629005817988, 0.7855600872920299, 0.9565532279265139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 90}], {
             RGBColor[
             0.9614699650142975, 0.9707849435115807, 0.9501054783749484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 110}], {
             RGBColor[
             0.975023417333431, 0.9792545409753912, 0.8537856222972307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 162}], {
             RGBColor[
             0.9040999653847468, 0.9258454822663276, 0.9725717338452813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 180}], {
             RGBColor[
             0.975313437365581, 0.9793744717118601, 0.8489792398167227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 198}], {
             RGBColor[
             0.9747831607314414, 0.9791551886961556, 0.857767295956352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 38}], {
             RGBColor[
             0.962883893933421, 0.9701459776943108, 0.8728492207798308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[
             0.9614130716522539, 0.9695377548826396, 0.8972245523448175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 46}], {
             RGBColor[
             0.9565282537497748, 0.9670030691258877, 0.9551298453883033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 80}], {
             RGBColor[
             0.9626146469370097, 0.9700346371419625, 0.8773113402992566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 98}], {
             RGBColor[
             0.9254169326114917, 0.9433663585636878, 0.9927482872335742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 117}], {
             RGBColor[
             0.9407665708219681, 0.9552480318057166, 0.9818102632797916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 120}], {
             RGBColor[
             0.8265570695675823, 0.865337012378564, 0.9831069616162285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 121}], {
             RGBColor[
             0.9455605072255278, 0.958823341726141, 0.9736953794074265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 146}], {
             RGBColor[
             0.6508221324545058, 0.7216035568097765, 0.969074691071608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 151}], {
             RGBColor[
             0.8677902882499999, 0.8975487161973372, 0.9872167035081554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 171}], {
             RGBColor[
             0.7418477450039456, 0.7977731694263757, 0.975613098852238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 173}], {
             RGBColor[
             0.9632663793632306, 0.9696901412564141, 0.821878838864591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 178}], {
             RGBColor[
             0.9618870670771875, 0.9697337641719765, 0.8893692214928282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 196}], {
             RGBColor[
             0.9507845169360735, 0.9627193996147352, 0.9648524936074171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 53}], {
             RGBColor[
             0.7491966976524442, 0.8026816794395351, 0.9485789561024156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 82}], {
             RGBColor[
             0.9790242293120217, 0.9827226826400144, 0.8687031442625299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 83}], {
             RGBColor[
             0.9631593424191479, 0.9720448784140165, 0.9472458030887307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 100}], {
             RGBColor[
             0.9800328365177198, 0.9831397676395934, 0.8519879126723364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 101}], {
             RGBColor[
             0.9481816153492972, 0.9607134751369111, 0.9670158666358989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 123}], {
             RGBColor[
             0.9578389185606155, 0.9680769150117177, 0.9562518928924443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 127}], {
             RGBColor[
             0.890242722613666, 0.9145663657703385, 0.9614758595874044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 130}], {
             RGBColor[
             0.9790503628240372, 0.9827334895188334, 0.8682700443370719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 135}], {
             RGBColor[
             0.9574143274096618, 0.9677602556265406, 0.9569706149599012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 148}], {
             RGBColor[
             0.9522097490712536, 0.9638786896234706, 0.9657806085153955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 163}], {
             RGBColor[
             0.9212559414868333, 0.9392436736769292, 0.9644476718260643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 165}], {
             RGBColor[
             0.8748138891661599, 0.9025132438176693, 0.9599380576600032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 176}], {
             RGBColor[
             0.9598115674943026, 0.9695481133565453, 0.9529127127969536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 187}], {
             RGBColor[
             0.8489816948020925, 0.8823329372485111, 0.9573633459413744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 41}], {
             RGBColor[
             0.7675253552244394, 0.818431116297568, 0.9774328398030652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 44}], {
             RGBColor[
             0.5997803802456722, 0.6807543557880524, 0.9642752873006879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 57}], {
             RGBColor[
             0.8875158546053974, 0.9130136845183973, 0.9845781091511461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 66}], {
             RGBColor[
             0.6667857185424458, 0.7375415800653496, 0.9688900299822232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 90}], {
             RGBColor[
             0.9005927829749445, 0.9227664362849006, 0.9624422804306576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 141}], {
             RGBColor[
             0.796014754671873, 0.8406872516733586, 0.9802723968914107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 198}], {
             RGBColor[
             0.9139059786920886, 0.9311366814694755, 0.8701040980120611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 44}], {
             RGBColor[
             0.6514641287780697, 0.7219164153581111, 0.967500570140777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 50}], {
             RGBColor[
             0.9647359221020078, 0.9719456706795985, 0.8874791413084422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 60}], {
             RGBColor[
             0.9036940975981833, 0.9259960009830295, 0.988971984604243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 90}], {
             RGBColor[
             0.952276531507342, 0.9639284958549592, 0.9656675632707465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 104}], {
             RGBColor[
             0.6734153956654294, 0.7409294994331885, 0.9688992854560963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 130}], {
             RGBColor[
             0.9643984511069493, 0.9718061177505328, 0.8930719090435013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 163}], {
             RGBColor[
             0.9066040297697455, 0.9283163019086286, 0.9892495365324937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 177}], {
             RGBColor[
             0.7797322613107316, 0.8284395358535315, 0.9769381443975709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 47}], {
             RGBColor[
             0.7564412768194284, 0.8098514154500551, 0.9763070478424485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 68}], {
             RGBColor[
             0.739689802909614, 0.7966574364367924, 0.9747109843729524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 88}], {
             RGBColor[
             0.6716891637669244, 0.741451454186874, 0.9693577249650911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.9159628109830532, 0.9338694079883763, 0.9177475361013776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 111}], {
             RGBColor[
             0.8306818537425054, 0.5063046775190206, 0.5746024658795836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 116}], {
             RGBColor[
             0.811377815280967, 0.8527682568293655, 0.981782608585154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 122}], {
             RGBColor[
             0.7599636477432251, 0.8126031183867357, 0.9766581248577046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 138}], {
             RGBColor[
             0.9189496332291949, 0.933873101509263, 0.7787358925781883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 142}], {
             RGBColor[
             0.661393242997093, 0.7330927618799798, 0.9685471923668896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 153}], {
             RGBColor[
             0.7667903021021275, 0.8179361526564051, 0.977338541965488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 157}], {
             RGBColor[
             0.8542610996310995, 0.8866286288187555, 0.9859613803623424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 160}], {
             RGBColor[
             0.6029553018774678, 0.6831670696517168, 0.9646328422887036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 167}], {
             RGBColor[
             0.8310455845117362, 0.8681328676330249, 0.9837429080163238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 174}], {
             RGBColor[
             0.8956565412650517, 0.9193378880017793, 0.9795659987920505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 181}], {
             RGBColor[
             0.7774836436306078, 0.8262898723308596, 0.9784043543140888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 185}], {
             RGBColor[
             0.5724099847490668, 0.6559733020199281, 0.9627135050112325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 188}], {
             RGBColor[
             0.9167799822428678, 0.934207329304653, 0.9042048935548199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 132}], {
             RGBColor[
             0.5111330915962867, 0.6129614555321319, 0.9549443399612596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 151}], {
             RGBColor[
             0.7054056137837683, 0.7692487978041451, 0.9716402066932651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 169}], {
             RGBColor[
             0.6172574479171096, 0.700156429207075, 0.9630119138700198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 200}], {
             RGBColor[
             0.6590578621404379, 0.7330415819644165, 0.9670206959538223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 56}], {
             RGBColor[
             0.9221450608006604, 0.9369216579558133, 0.8196216826875492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 79}], {
             RGBColor[
             0.7209423601831173, 0.7763483381576648, 0.8017197809093164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 118}], {
             RGBColor[
             0.9927322684350133, 0.9906750334217507, 0.7273972748010606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 119}], {
             RGBColor[
             0.8914999156857495, 0.9127413413276952, 0.8166309752073573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 125}], {
             RGBColor[
             0.7093690514216686, 0.7663241197999098, 0.800982339908912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 128}], {
             RGBColor[
             0.8145169695577328, 0.8524802633075299, 0.8090410469647591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 149}], {
             RGBColor[
             0.7621635736658046, 0.8099774180288548, 0.8049195958633384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 170}], {
             RGBColor[
             0.939841900808909, 0.9510326378104654, 0.8213096230856916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 190}], {
             RGBColor[
             0.668825146901532, 0.7312070275004602, 0.798398918164456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 195}], {
             RGBColor[
             0.946564417418214, 0.8114905516651933, 0.445379812378426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 46}], {
             RGBColor[
             0.987449654246062, 0.9885634357286592, 0.8346064574997192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 98}], {
             RGBColor[
             0.9563383331077789, 0.9649267251664593, 0.8722248993449899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 117}], {
             RGBColor[
             0.9716879713182554, 0.9768083984084881, 0.8612868753912074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 120}], {
             RGBColor[
             0.8574784700638696, 0.8868973789813355, 0.8625835737276443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 128}], {
             RGBColor[
             0.8141191732712607, 0.8529033513711903, 0.8583449366199318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 146}], {
             RGBColor[
             0.681743532950793, 0.743163923412548, 0.8485513031830239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 156}], {
             RGBColor[
             0.7261891666843501, 0.7815178108222811, 0.8514227644031831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 171}], {
             RGBColor[
             0.7727691455002328, 0.8193335360291472, 0.8550897109636538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 178}], {
             RGBColor[
             0.9928084675734747, 0.991294130774748, 0.768845833604244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 179}], {
             RGBColor[
             0.926047474801061, 0.9407736169761274, 0.8693357302387268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 183}], {
             RGBColor[
             0.8660194997108215, 0.8935696962557638, 0.8634348637423923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 192}], {
             RGBColor[
             0.8348439412155739, 0.8692151130162562, 0.8603275754237443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 114}], {
             RGBColor[
             0.3216005121285118, 0.4497189788502137, 0.9418323311671087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 46}], {
             RGBColor[
             0.9859788319648949, 0.9879552129169882, 0.8589817890647057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 74}], {
             RGBColor[
             0.7152648790450928, 0.7728641580901856, 0.8751563047745357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.9920652251521298, 0.9909867809330628, 0.781163283975659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 117}], {
             RGBColor[
             0.9702171490370881, 0.976200175596817, 0.8856622069561939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 121}], {
             RGBColor[
             0.975011085440648, 0.9797754855172414, 0.8775473230838289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 166}], {
             RGBColor[
             0.9923344721485411, 0.9910981214854111, 0.7767011644562332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 169}], {
             RGBColor[
             0.8090927005984612, 0.8494084913913674, 0.8824403543613124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 171}], {
             RGBColor[
             0.7712983232190657, 0.818725313217476, 0.8794650425286403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 173}], {
             RGBColor[
             0.9927169575783507, 0.9906422850475145, 0.7257307825409933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 196}], {
             RGBColor[
             0.9802350951511936, 0.9836715434058355, 0.8687044372838195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 57}], {
             RGBColor[
             0.8208033927937833, 0.8607821940209726, 0.9779594071607798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 66}], {
             RGBColor[
             0.6000732567308318, 0.6853100895679249, 0.9622713279918569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 81}], {
             RGBColor[
             0.7845236429928848, 0.8319850895578966, 0.9790541516649702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 90}], {
             RGBColor[
             0.8338803211633306, 0.8705349457874758, 0.9558235784402913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 141}], {
             RGBColor[
             0.7293022928602589, 0.7884557611759337, 0.9736536949010445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 168}], {
             RGBColor[
             0.5401698669981898, 0.634674216182565, 0.9581091151928216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 172}], {
             RGBColor[
             0.7319083870430845, 0.7904916617586064, 0.9739134460138537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 184}], {
             RGBColor[
             0.8475680165383151, 0.8782328602483366, 0.7971505538089594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 198}], {
             RGBColor[
             0.8471935168804745, 0.8789051909720507, 0.8634853960216949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 88}], {
             RGBColor[
             0.4663795882521028, 0.5771268592803147, 0.951283494629274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[
             0.6842132782276837, 0.6649204101986685, 0.607698476923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 102}], {
             RGBColor[
             0.7130270726779502, 0.7682373935920888, 0.6939420239328495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 153}], {
             RGBColor[
             0.5614807265873059, 0.6536115577498458, 0.9592643116296709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 49}], {
             RGBColor[
             0.9075762180841578, 0.9291406570728866, 0.9910466239553632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 67}], {
             RGBColor[
             0.6555780561962046, 0.7272684391633051, 0.9686662372563923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 87}], {
             RGBColor[
             0.9255466880636605, 0.9427380965517242, 0.9673912814323608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 95}], {
             RGBColor[
             0.7715300242453473, 0.8219862039897408, 0.9777187786570796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 103}], {
             RGBColor[
             0.8381956790450928, 0.8740659201970444, 0.9843633881015537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 129}], {
             RGBColor[
             0.7145624377227788, 0.7759469440077165, 0.9730907816077339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 131}], {
             RGBColor[
             0.915791491458886, 0.9354626868965519, 0.9839042847214854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 133}], {
             RGBColor[
             0.590312050004776, 0.6693384348743912, 0.9645588011557933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 143}], {
             RGBColor[
             0.7584265047848049, 0.8115577697023715, 0.9765439216462286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 154}], {
             RGBColor[
             0.9394152686344828, 0.9518153620744829, 0.8872258412965517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 197}], {
             RGBColor[
             0.9250643306366049, 0.9423783551724139, 0.9682077867374004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 50}], {
             RGBColor[
             0.6785947367792289, 0.7408753601025996, 0.8644776039756097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 57}], {
             RGBColor[
             0.6530584178150161, 0.7231054335114571, 0.9648018546584025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 60}], {
             RGBColor[
             0.6175529122754044, 0.6949256904060306, 0.9659704472714105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 90}], {
             RGBColor[
             0.6661353461845632, 0.7328581852779603, 0.942666025937914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 141}], {
             RGBColor[
             0.5615573178814917, 0.6507790006664183, 0.9604961423986672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 177}], {
             RGBColor[
             0.4935910759879527, 0.5973692252765326, 0.9539366070647384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 120}], {
             RGBColor[
             0.8385912459259386, 0.8227161373367731, 0.6282649420300315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 128}], {
             RGBColor[
             0.7952319491333297, 0.7887221097266279, 0.6240263049223189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 168}], {
             RGBColor[
             0.6677788433687002, 0.683246333786472, 0.6145463310344826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 172}], {
             RGBColor[
             0.8595173634135949, 0.8390637793625135, 0.6303506618555147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 173}], {
             RGBColor[
             0.9753005557215868, 0.9270692662146232, 0.46703681927839397`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 85}], {
             RGBColor[
             0.8852332378004386, 0.9104017803288865, 0.9482640050177183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 98}], {
             RGBColor[
             0.9499826929241327, 0.9617838165980361, 0.9545055239534624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 99}], {
             RGBColor[
             0.8416689180293007, 0.8763690026225803, 0.9439219207546461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 109}], {
             RGBColor[
             0.7452440591946694, 0.799004317426272, 0.9357037992271727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 117}], {
             RGBColor[
             0.9653323311346091, 0.9736654898400651, 0.9435674999996799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 121}], {
             RGBColor[
             0.9701262675381688, 0.9772407997604895, 0.9354526161273147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 146}], {
             RGBColor[
             0.6753878927671468, 0.740021014844125, 0.9308319277914963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 151}], {
             RGBColor[
             0.892356048562641, 0.9159661742316858, 0.9489739402280437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 171}], {
             RGBColor[
             0.7664135053165866, 0.816190627460724, 0.9373703355721263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 178}], {
             RGBColor[
             0.9864528273898285, 0.988151222206325, 0.8511264582127165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 196}], {
             RGBColor[
             0.9753502772487145, 0.9811368576490835, 0.9266097303273053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 54}], {
             RGBColor[
             0.8235564641909814, 0.8622693241379311, 0.9446429811671088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 61}], {
             RGBColor[
             0.766926880038582, 0.8182123508328911, 0.9773071740380999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 73}], {
             RGBColor[
             0.5992820532414014, 0.6851575718750087, 0.9618741510357525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 88}], {
             RGBColor[
             0.5840857331013422, 0.6728205145988877, 0.9606778410483721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 94}], {
             RGBColor[
             0.8283593803174709, 0.86523846840039, 0.9090676521846586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 105}], {
             RGBColor[
             0.8318859530591665, 0.8663966336541202, 0.8288045191485631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 111}], {
             RGBColor[
             0.7430784230769231, 0.4376737379310345, 0.5659225819628647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 116}], {
             RGBColor[
             0.7237743846153848, 0.7841373172413794, 0.973102724668435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 126}], {
             RGBColor[
             0.8304619856305737, 0.8661079497318498, 0.8742220407784219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 142}], {
             RGBColor[
             0.5737898123315108, 0.6644618222919937, 0.9598673084501705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 153}], {
             RGBColor[
             0.6791868714365452, 0.7493052130684188, 0.968658658048769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 157}], {
             RGBColor[
             0.7666576689655172, 0.8179976892307692, 0.9772814964456233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 160}], {
             RGBColor[
             0.5153518712118856, 0.6145361300637306, 0.9559529583719846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 167}], {
             RGBColor[
             0.743442153846154, 0.7995019280450388, 0.9750630240996048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 174}], {
             RGBColor[
             0.8080531105994695, 0.8507069484137931, 0.9708861148753316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 188}], {
             RGBColor[
             0.8291765515772855, 0.8655763897166668, 0.8955250096381009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 59}], {
             RGBColor[
             0.7884415392490054, 0.8350922493524333, 0.979432319382511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.7128583452266917, 0.7746578089402877, 0.9728480640223409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 77}], {
             RGBColor[
             0.526455346941313, 0.6038744450596817, 0.9606717695043103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 106}], {
             RGBColor[
             0.7881014113744995, 0.8348265388718017, 0.9793984186146559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 112}], {
             RGBColor[
             0.7799148763177639, 0.828431155465509, 0.9785824613077203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 140}], {
             RGBColor[
             0.8570044069388038, 0.8888160676008257, 0.9862230394623306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 193}], {
             RGBColor[
             0.8671654404655058, 0.8969181999211104, 0.9871922079109692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 67}], {
             RGBColor[
             0.6761353777286381, 0.7436602893396398, 0.9706270129358935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.9461040095960941, 0.959129946728059, 0.9693520571118619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 95}], {
             RGBColor[
             0.7920873457777808, 0.8383780541660756, 0.9796795543365807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 103}], {
             RGBColor[
             0.8587530005775263, 0.8904577703733791, 0.9863241637810547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 108}], {
             RGBColor[
             0.7154800027986676, 0.7763943551316825, 0.9735054437161774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[
             0.7351197592552123, 0.7923387941840512, 0.975051557287235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 131}], {
             RGBColor[
             0.9363488129913196, 0.9518545370728866, 0.9858650604009865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 133}], {
             RGBColor[
             0.6108693715372097, 0.6857302850507259, 0.9665195768352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 143}], {
             RGBColor[
             0.7789838263172385, 0.8279496198787062, 0.9785046973257296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 154}], {
             RGBColor[
             0.9599725901669164, 0.9682072122508176, 0.8891866169760527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 162}], {
             RGBColor[
             0.8901706446356628, 0.9152619252667618, 0.9893864648217069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 53}], {
             RGBColor[
             0.7616753939365155, 0.810713252415723, 0.8703578546436778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 60}], {
             RGBColor[
             0.9308247055993426, 0.9449549457275179, 0.8859490184390757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 82}], {
             RGBColor[
             0.991502925596093, 0.9907542556162022, 0.7904820428037921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 100}], {
             RGBColor[
             0.992511532801791, 0.9911713406157813, 0.7737668112135986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 104}], {
             RGBColor[
             0.7005460036665887, 0.759888444177677, 0.8658763192909291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 123}], {
             RGBColor[
             0.9703176148446869, 0.9761084879879055, 0.8780307914337064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.9915290591081085, 0.9907650624950213, 0.7900489428783342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 163}], {
             RGBColor[
             0.9337346377709047, 0.947275246653117, 0.8862265703673264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 177}], {
             RGBColor[
             0.8068628693118909, 0.8473984805980199, 0.8739151782324037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 71}], {
             RGBColor[
             0.7058455089784539, 0.7193213447186106, 0.6217021233339852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 74}], {
             RGBColor[
             0.6990864002652519, 0.7134669444739169, 0.6212714389036251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 158}], {
             RGBColor[
             0.9131636067631372, 0.8845680074865613, 0.640280727188697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 164}], {
             RGBColor[
             0.7433137383016459, 0.7497433707797003, 0.6246507567353881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 166}], {
             RGBColor[
             0.9761559933687003, 0.9317009078691425, 0.5228162985853229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 184}], {
             RGBColor[
             0.9764149159857487, 0.9309807830688662, 0.4583968670423094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 70}], {
             RGBColor[
             0.9800651371175995, 0.9813483508633276, 0.720085578377035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 134}], {
             RGBColor[
             0.8643588039061669, 0.894344968151228, 0.9588613887624822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 145}], {
             RGBColor[
             0.9225634394436553, 0.9402852413754679, 0.9645378612580796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 100}], {
             RGBColor[
             0.7623203966351395, 0.8109799776074174, 0.8596684907140013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 104}], {
             RGBColor[
             0.47035486749993716`, 0.579697081169313, 0.9517779987913318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 123}], {
             RGBColor[
             0.7401264786780354, 0.7959171249795416, 0.9639324709341093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 130}], {
             RGBColor[
             0.761337922941457, 0.8105736994866573, 0.8759506223787369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 135}], {
             RGBColor[
             0.7397018875270817, 0.7956004655943645, 0.9646511930015662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 148}], {
             RGBColor[
             0.7344973091886733, 0.7917188995912944, 0.9734611865570605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 163}], {
             RGBColor[
             0.7035435016042532, 0.7670838836447531, 0.9721282498677293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 165}], {
             RGBColor[
             0.6571014492835796, 0.7303534537854931, 0.9676186357016682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 58}], {
             RGBColor[
             0.9597499915824743, 0.9695021901423251, 0.9530169447541091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 61}], {
             RGBColor[
             0.9216454980757173, 0.9392611991087533, 0.9543229912794791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 73}], {
             RGBColor[
             0.7540006712785368, 0.8062064201508707, 0.9388899682771317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 94}], {
             RGBColor[
             0.9830779983546063, 0.9862873166762521, 0.886083469426038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 105}], {
             RGBColor[
             0.9866045710963018, 0.9874454819299823, 0.8058203363899424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 115}], {
             RGBColor[
             0.7778696458730501, 0.8255843290117484, 0.9407690213921467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 116}], {
             RGBColor[
             0.87849300265252, 0.9051861655172415, 0.9501185419098144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 126}], {
             RGBColor[
             0.9851806036677091, 0.9871567980077119, 0.8512378580198012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 160}], {
             RGBColor[
             0.6700704892490209, 0.7355849783395927, 0.9329687756133639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 174}], {
             RGBColor[
             0.9627717286366047, 0.9717557966896553, 0.9479019321167108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 62}], {
             RGBColor[
             0.6917733735356959, 0.7226652861234395, 0.6444788404307464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 68}], {
             RGBColor[
             0.8031162443740563, 0.8141626990550992, 0.6529390502919843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 72}], {
             RGBColor[
             0.8893897780422941, 0.8816678395388663, 0.6614644229576132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 75}], {
             RGBColor[
             0.6752122154987248, 0.7083208434198207, 0.6434235780850877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 76}], {
             RGBColor[
             0.9558457412943182, 0.9344288212582282, 0.6632738700530458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 96}], {
             RGBColor[
             0.7543016992376186, 0.7745328522431412, 0.6490961904852732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 107}], {
             RGBColor[
             0.8003723919814834, 0.8119351160736668, 0.6527230441805782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 111}], {
             RGBColor[
             0.8941082952069476, 0.5238099401373273, 0.25283053179861553`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 139}], {
             RGBColor[
             0.9448844810998724, 0.9258199931552454, 0.6667835146979821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 147}], {
             RGBColor[
             0.9660969005547637, 0.9420741190499358, 0.6459213313556476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 157}], {
             RGBColor[
             0.9176875410955417, 0.9041338914370621, 0.6641894462813742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 182}], {
             RGBColor[
             0.7650972410036823, 0.7832971593824459, 0.6499460550784701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 185}], {
             RGBColor[
             0.6358364262135091, 0.6734785646382349, 0.6409415709302644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 191}], {
             RGBColor[
             0.9646446656721406, 0.9409910446522918, 0.6483795862084101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 79}], {
             RGBColor[
             0.6484865339811252, 0.7224098279437168, 0.9676234100159642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 118}], {
             RGBColor[
             0.9202764422330212, 0.9367365232078027, 0.8933009039077084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 119}], {
             RGBColor[
             0.8190440894837574, 0.8588028311137472, 0.9825346043140051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 125}], {
             RGBColor[
             0.6369132252196765, 0.7123856095859618, 0.9668859690155598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 129}], {
             RGBColor[
             0.6958976067462508, 0.7610641144303731, 0.9713105133669013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 149}], {
             RGBColor[
             0.6897077474638125, 0.7560389078149068, 0.9708232249699862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 170}], {
             RGBColor[
             0.8673860746069169, 0.8970941275965173, 0.9872132521923394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 190}], {
             RGBColor[
             0.59636932069954, 0.677268517286512, 0.9643025472711038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 195}], {
             RGBColor[
             0.8741085912162219, 0.7575520414512453, 0.6112834414850739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 197}], {
             RGBColor[
             0.9063994996600768, 0.9274955255950705, 0.9664275184965678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 66}], {
             RGBColor[
             0.7200637561117897, 0.7798926577887542, 0.9694165973399378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 71}], {
             RGBColor[
             0.6969891089119784, 0.7611559901189102, 0.9676010794487162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 81}], {
             RGBColor[
             0.9045141423738428, 0.9265676577787259, 0.986199421013051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 90}], {
             RGBColor[
             0.9538708205442885, 0.965117514008305, 0.9629688477883722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 141}], {
             RGBColor[
             0.8492927922412169, 0.883038329396763, 0.9807989642491253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 198}], {
             RGBColor[
             0.9671840162614325, 0.9734877591928799, 0.8706306653697757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 61}], {
             RGBColor[
             0.9031204074300749, 0.9254452168372851, 0.9856811376251002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 73}], {
             RGBColor[
             0.7354755806328943, 0.7923904378794027, 0.9702481146227528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 92}], {
             RGBColor[
             0.9566791518784397, 0.9672119629190945, 0.9582150753697729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 115}], {
             RGBColor[
             0.7593445552274077, 0.8117683467402803, 0.9721271677377679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 155}], {
             RGBColor[
             0.8169557569823804, 0.8577687608361504, 0.9771896386140353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 154}], {
             RGBColor[
             0.847355512666313, 0.8793557629189586, 0.8781939670368213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 186}], {
             RGBColor[
             0.8371841304192238, 0.8730358618524334, 0.9521010147943088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 193}], {
             RGBColor[
             0.7816232858318852, 0.8296555591541803, 0.9787819882848594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.9304611010922685, 0.9448045859196332, 0.8919748860995929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 104}], {
             RGBColor[
             0.6395041791627641, 0.713938774481108, 0.9673691625867298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 123}], {
             RGBColor[
             0.9092757903408624, 0.9301588182913365, 0.9795236347295072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 130}], {
             RGBColor[
             0.9304872346042841, 0.9448153927984524, 0.8915417861741348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 163}], {
             RGBColor[
             0.8726928132670801, 0.901325576956548, 0.9877194136631272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 177}], {
             RGBColor[
             0.7458210448080663, 0.801448810901451, 0.9754080215282044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 73}], {
             RGBColor[
             0.6973710871261374, 0.7621494468458309, 0.9715541611481228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 94}], {
             RGBColor[
             0.9264484142022069, 0.9422303433712123, 0.918747662297029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 105}], {
             RGBColor[
             0.9299749869439025, 0.9433885086249424, 0.8384845292609335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 115}], {
             RGBColor[
             0.7212400617206507, 0.7815273557067085, 0.9734332142631378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 116}], {
             RGBColor[
             0.8218634185001206, 0.8611291922122015, 0.9827827347808054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 160}], {
             RGBColor[
             0.6134409050966215, 0.6915280050345528, 0.965632968484355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 174}], {
             RGBColor[
             0.9061421444842053, 0.9276988233846153, 0.9805661249877019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 68}], {
             RGBColor[
             0.523992027495857, 0.623335104903884, 0.9559748271254995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 75}], {
             RGBColor[
             0.39608799862052557`, 0.5174932492686055, 0.9464593549186031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 76}], {
             RGBColor[
             0.6767215244161191, 0.743601227107013, 0.9663096468865613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 96}], {
             RGBColor[
             0.47517748235941937`, 0.583705258091926, 0.9521319673187885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 105}], {
             RGBColor[
             0.7037916083109919, 0.7617052417091978, 0.8187482458178292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 107}], {
             RGBColor[
             0.5212481751032841, 0.6211075219224516, 0.9557588210140937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 111}], {
             RGBColor[
             0.6149840783287484, 0.33298234598611215`, 0.5558663086321309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 116}], {
             RGBColor[
             0.5956800398672101, 0.6794459252964571, 0.9630464513377012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 126}], {
             RGBColor[
             0.7023676408823991, 0.7614165577869275, 0.8641657674476881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 157}], {
             RGBColor[
             0.6385633242173425, 0.7133062972858469, 0.9672252231148895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 174}], {
             RGBColor[
             0.6799587658512948, 0.7460155564688709, 0.9608298415445977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 182}], {
             RGBColor[
             0.4859730241254831, 0.5924695652312307, 0.9529818319119856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 185}], {
             RGBColor[
             0.3567122093353099, 0.4826509704870196, 0.9439773477637796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 191}], {
             RGBColor[
             0.6855204487939414, 0.7501634505010766, 0.9514153630419255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 77}], {
             RGBColor[
             0.3653299982853787, 0.47617736388060594`, 0.9456772945180305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 91}], {
             RGBColor[
             0.5694169290546096, 0.661317340803683, 0.9592457329795689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 102}], {
             RGBColor[
             0.7721807927356452, 0.8168011748602333, 0.6984495829071136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 106}], {
             RGBColor[
             0.6269760627185652, 0.7071294576927261, 0.964403943628376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 112}], {
             RGBColor[
             0.6187895276618296, 0.7007340742864333, 0.9635879863214404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 140}], {
             RGBColor[
             0.6958790582828694, 0.76111898642175, 0.9712285644760507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 69}], {
             RGBColor[
             0.9448827892732734, 0.9584142550029324, 0.9781832402762065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 82}], {
             RGBColor[
             0.9715573826711363, 0.9771539206410813, 0.8813425679600473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 86}], {
             RGBColor[
             0.8647673289642339, 0.8949291899783021, 0.97232035961855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 87}], {
             RGBColor[
             0.9580249619144252, 0.9682156658403709, 0.9559369700223225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 108}], {
             RGBColor[
             0.7274009551169989, 0.7854800742439945, 0.9600903566266381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 110}], {
             RGBColor[
             0.9730150489026782, 0.9777567030881373, 0.8571852661841168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 127}], {
             RGBColor[
             0.8827758759727807, 0.9089976037714054, 0.974115283284922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 154}], {
             RGBColor[
             0.9718935424852475, 0.9772929313631296, 0.8757715298865134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 161}], {
             RGBColor[
             0.915899166237375, 0.9353574253291579, 0.977288356016579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 162}], {
             RGBColor[
             0.902091596953994, 0.9243476443790736, 0.9759713777321675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 175}], {
             RGBColor[
             0.8481216917198031, 0.8819254916514241, 0.9706612780603493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 176}], {
             RGBColor[
             0.9523447208534173, 0.9639793513576123, 0.965552136494471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 180}], {
             RGBColor[
             0.9733050689348282, 0.9778766338246061, 0.852378883703609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 66}], {
             RGBColor[
             0.6020489894633624, 0.6868535469947028, 0.9624682505663634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 69}], {
             RGBColor[
             0.8212772465855898, 0.8612055525928594, 0.9806986190291698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 87}], {
             RGBColor[
             0.8344194192267416, 0.8710069634302977, 0.9584523487752857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 90}], {
             RGBColor[
             0.835856053895861, 0.8720784032142537, 0.956020501014798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 110}], {
             RGBColor[
             0.8494095062149946, 0.8805480006780642, 0.8597006449370801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 131}], {
             RGBColor[
             0.8246642226219671, 0.8637315537751253, 0.9749653520644104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 133}], {
             RGBColor[
             0.4991847811678572, 0.5976073017529646, 0.9556198684987183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 162}], {
             RGBColor[
             0.7784860542663103, 0.8271389419690005, 0.9784867564851307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 180}], {
             RGBColor[
             0.8496995262471445, 0.880667931414533, 0.8548942624565723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 198}], {
             RGBColor[
             0.849169249613005, 0.8804486483988285, 0.8636823185962015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 81}], {
             RGBColor[
             0.6837840063108913, 0.7510955533256782, 0.970511341844128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 90}], {
             RGBColor[
             0.733140684481337, 0.7896454095552574, 0.9472807686194493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 141}], {
             RGBColor[
             0.6285626561782653, 0.7075662249437153, 0.9651108850802024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 168}], {
             RGBColor[
             0.4394302303161963, 0.5537846799503466, 0.9495663053719796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 172}], {
             RGBColor[
             0.6311687503610909, 0.709602125526388, 0.9653706361930117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 198}], {
             RGBColor[
             0.7464538801984809, 0.7980156547398323, 0.8549425862008528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 87}], {
             RGBColor[
             0.6941058477081408, 0.7572577288184774, 0.946971670412891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 103}], {
             RGBColor[
             0.6067548386895731, 0.6885855524637976, 0.9639437770820839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 129}], {
             RGBColor[
             0.483121597367259, 0.5904665762744696, 0.9526711705882642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 131}], {
             RGBColor[
             0.6843506511033662, 0.749982319163305, 0.9634846737020157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 133}], {
             RGBColor[
             0.35887120964925634`, 0.4838580671411443, 0.9441391901363236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 143}], {
             RGBColor[
             0.5269856644292852, 0.6260774019691246, 0.956124310626759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 162}], {
             RGBColor[
             0.6381724827477094, 0.7133897073571801, 0.9670060781227361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 107}], {
             RGBColor[
             0.6325910459416444, 0.7126049348541112, 0.9642190308753316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 111}], {
             RGBColor[
             0.7263269491671087, 0.4244797589177718, 0.5643265184933687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 122}], {
             RGBColor[
             0.6556087431678285, 0.7307781997854869, 0.9663821774714897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 138}], {
             RGBColor[
             0.8145947286537982, 0.852048182908014, 0.7684599451919734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 142}], {
             RGBColor[
             0.5570383384216964, 0.651267843278731, 0.9582712449806745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 147}], {
             RGBColor[
             0.7983155545149249, 0.8427439378303803, 0.9574173180504008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 156}], {
             RGBColor[
             0.5469539686366047, 0.6430808975915119, 0.9574773664509284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 157}], {
             RGBColor[
             0.7499061950557029, 0.8048037102175065, 0.9756854329761273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 179}], {
             RGBColor[
             0.7468122767533155, 0.8023367037453579, 0.9753903322864721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 181}], {
             RGBColor[
             0.6731287390552112, 0.7444649537296106, 0.9681284069278737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 185}], {
             RGBColor[
             0.46805508017367015`, 0.5741483834186792, 0.9524375576250175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 82}], {
             RGBColor[
             0.964464727691156, 0.9718642301701687, 0.8933485827804682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 86}], {
             RGBColor[
             0.8576746739842536, 0.8896394995073893, 0.984326374438971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 90}], {
             RGBColor[
             0.9523689416035643, 0.9639974151534141, 0.9655111370822556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 110}], {
             RGBColor[
             0.9659223939226977, 0.9724670126172246, 0.8691912810045378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 123}], {
             RGBColor[
             0.9432794169397498, 0.9572184625418719, 0.9808973314103826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 127}], {
             RGBColor[
             0.8756832209928003, 0.9037079133004926, 0.9861212981053429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 177}], {
             RGBColor[
             0.7798246714069538, 0.8285084551519863, 0.9767817182090799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 180}], {
             RGBColor[
             0.9662124139548477, 0.9725869433536934, 0.8643848985240299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 72}], {
             RGBColor[
             0.9005322454960281, 0.9188346173774622, 0.7404119600020911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 93}], {
             RGBColor[
             0.8656546889935157, 0.8915880051584524, 0.7369356911192172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 134}], {
             RGBColor[
             0.8774761921099306, 0.900823053239747, 0.7381139480716339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 139}], {
             RGBColor[
             0.9560269485536064, 0.9629867709938413, 0.74573105174246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.9356808276474189, 0.946763326463987, 0.7437904205672312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 81}], {
             RGBColor[
             0.66070935911108, 0.7323588856558343, 0.9686958239529064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 164}], {
             RGBColor[
             0.4906525549724075, 0.5973692440571083, 0.9530461157899743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 184}], {
             RGBColor[
             0.7237537326565102, 0.7786066563462742, 0.7867922260968958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 75}], {
             RGBColor[
             0.5937044031271237, 0.6764958026840323, 0.9634449374454699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 84}], {
             RGBColor[
             0.7709386934682041, 0.8209824337792255, 0.9778036221993587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 93}], {
             RGBColor[
             0.7730044091681807, 0.8225961865840681, 0.9780095134351217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 134}], {
             RGBColor[
             0.7848259122845956, 0.8318312346653627, 0.9791877703875382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 139}], {
             RGBColor[
             0.8633766687282713, 0.893994952419457, 0.9868048740583644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 152}], {
             RGBColor[
             0.9013505698011945, 0.9209842041648734, 0.8585045040126322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 191}], {
             RGBColor[
             0.8831368533005395, 0.9091660039165034, 0.9684009455687923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 94}], {
             RGBColor[
             0.7588035874050263, 0.8091755644133297, 0.9033146392946816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 115}], {
             RGBColor[
             0.5535952349234702, 0.648472576748826, 0.9580001912607904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 153}], {
             RGBColor[
             0.6096310785241006, 0.6932423090813585, 0.962905645158792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 160}], {
             RGBColor[
             0.44579607829944096`, 0.5584732260766703, 0.9501999454820076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 80}], {
             RGBColor[
             0.7164664543298487, 0.7733610403495084, 0.8552430927289748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 158}], {
             RGBColor[
             0.6537433147206968, 0.7263394805192755, 0.9682454018129232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 164}], {
             RGBColor[
             0.48389344625920555`, 0.5915148438124145, 0.9526154313596142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 166}], {
             RGBColor[
             0.7167357013262599, 0.7734723809018567, 0.850780973209549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 169}], {
             RGBColor[
             0.53349392977618, 0.631782750807813, 0.9565201631146283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 184}], {
             RGBColor[
             0.7169946239433083, 0.7727522561015805, 0.7863615416665357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 76}], {
             RGBColor[
             0.6601603663791478, 0.7292567844033943, 0.9652543845409025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 96}], {
             RGBColor[
             0.45861632432244814`, 0.5693608153883072, 0.9510767049731298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 134}], {
             RGBColor[
             0.5706483497410262, 0.6584842385463171, 0.9611469255150127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 139}], {
             RGBColor[
             0.649199106184702, 0.7206479563004115, 0.9687640291858388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 182}], {
             RGBColor[
             0.4694118660885119, 0.578125122527612, 0.9519265695663268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 191}], {
             RGBColor[
             0.6689592907569701, 0.7358190077974578, 0.9503601006962668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.7392498501180416, 0.7954687932267146, 0.970926996941088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 105}], {
             RGBColor[
             0.9678639760696142, 0.9734687768439866, 0.8375432754401287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 111}], {
             RGBColor[
             0.8790564460873707, 0.5447458811209009, 0.5746613382544303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 116}], {
             RGBColor[
             0.8597524076258323, 0.8912094604312457, 0.9818414809600007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 126}], {
             RGBColor[
             0.9664400086410214, 0.9731800929217163, 0.8829607970699875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 174}], {
             RGBColor[
             0.944031133609917, 0.9577790916036595, 0.9796248711668971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.7500453918841054, 0.8042331003660195, 0.971776861534285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 191}], {
             RGBColor[
             0.9495928165525636, 0.9619269856358653, 0.9702103926642249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 102}], {
             RGBColor[
             0.5857777944502665, 0.6460178109796273, 0.686273288389083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 106}], {
             RGBColor[
             0.4405730644331865, 0.5363460938121201, 0.9522276491103456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 112}], {
             RGBColor[
             0.4323865293764509, 0.5299507104058273, 0.9514116918034099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 140}], {
             RGBColor[
             0.5094760599974908, 0.590335622541144, 0.9590522699580202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 189}], {
             RGBColor[
             0.5091603096396049, 0.590083851776581, 0.9590221534070114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 91}], {
             RGBColor[
             0.6149394230503062, 0.6982681338852534, 0.9628338186942993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 95}], {
             RGBColor[
             0.6494095682505605, 0.7260429575036412, 0.9656907347519095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 113}], {
             RGBColor[
             0.8088409836020302, 0.8508331628932109, 0.946197475574936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 136}], {
             RGBColor[
             0.8164002349756847, 0.8555021847347173, 0.89002326437683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 89}], {
             RGBColor[
             0.6555837016618972, 0.7280689168048797, 0.9683003442050726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 118}], {
             RGBColor[
             0.719073741615478, 0.7761632034096542, 0.8753990021294756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 119}], {
             RGBColor[
             0.6178413888662144, 0.6982295113155987, 0.9646327025357724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 125}], {
             RGBColor[
             0.43571052460213344`, 0.5518122897878133, 0.9489840672373271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 128}], {
             RGBColor[
             0.5408584427381977, 0.6379684332954334, 0.9570427742931742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 144}], {
             RGBColor[
             0.7051580074510218, 0.7243987586987787, 0.6303044718058681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 149}], {
             RGBColor[
             0.48850504684626944`, 0.5954655880167583, 0.9529213231917535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 159}], {
             RGBColor[
             0.6462193904083737, 0.7206020691987777, 0.9674071678380922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 170}], {
             RGBColor[
             0.6661833739893737, 0.7365208077983689, 0.9693113504141065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 190}], {
             RGBColor[
             0.3951666200819968, 0.5166951974883638, 0.9464006454928711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 192}], {
             RGBColor[
             0.5615832106825109, 0.6542801949404993, 0.9590254130969867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 195}], {
             RGBColor[
             0.6729058905986789, 0.596978721653097, 0.593381539706841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 197}], {
             RGBColor[
             0.7051967990425339, 0.7669222057969222, 0.9485256167183351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 81}], {
             RGBColor[
             0.930750596504915, 0.9446271082540179, 0.8742721187236697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 117}], {
             RGBColor[
             0.971418724321844, 0.9766970578561398, 0.8657489949106332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 120}], {
             RGBColor[
             0.8572092230674584, 0.8867860384289872, 0.86704569324707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 121}], {
             RGBColor[
             0.9762126607254038, 0.9802723677765642, 0.857634111038268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 166}], {
             RGBColor[
             0.9935360474332969, 0.991595003744734, 0.7567879524106724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 168}], {
             RGBColor[
             0.68639682051022, 0.7473162348786861, 0.8533270822515213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 172}], {
             RGBColor[
             0.8781353405551147, 0.9031336804547276, 0.8691314130725534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 173}], {
             RGBColor[
             0.9939185328631065, 0.9911391673068373, 0.7058175704954326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 184}], {
             RGBColor[
             0.9937949700503452, 0.9908748789444577, 0.6923685208676591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 164}], {
             RGBColor[
             0.6981775884342719, 0.762780911716924, 0.9716444573543093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 166}], {
             RGBColor[
             0.9310198435013263, 0.9447384488063661, 0.8698099992042441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 168}], {
             RGBColor[
             0.6238806165782493, 0.7004596799403183, 0.9663491290450928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 172}], {
             RGBColor[
             0.815619136623144, 0.8562771255163597, 0.9821534598661249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 173}], {
             RGBColor[
             0.9314023289311358, 0.9442826123684693, 0.8188396172890042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 184}], {
             RGBColor[
             0.9312787661183746, 0.9440183240060899, 0.8053905676612306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 198}], {
             RGBColor[
             0.930904266460534, 0.944690654729804, 0.8717254098739662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 86}], {
             RGBColor[
             0.8843492673821165, 0.9083791651455382, 0.8874857021228117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 101}], {
             RGBColor[
             0.9602967071262944, 0.9685946883052143, 0.8948206328376782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 110}], {
             RGBColor[
             0.9925969873205609, 0.9912066782553735, 0.7723506086883787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 123}], {
             RGBColor[
             0.969954010337613, 0.9759581281800208, 0.8840566590942236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 127}], {
             RGBColor[
             0.9023578143906634, 0.9224475789386415, 0.8892806257891838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 130}], {
             RGBColor[
             0.9911654546010346, 0.9906147026871366, 0.7960748105388512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 163}], {
             RGBColor[
             0.9333710332638308, 0.9471248868452323, 0.8922524380278436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 176}], {
             RGBColor[
             0.9719266592713, 0.9774293265248484, 0.8807174789987329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 177}], {
             RGBColor[
             0.8064992648048168, 0.8472481207901352, 0.8799410458929207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 180}], {
             RGBColor[
             0.9928870073527107, 0.9913266089918423, 0.7675442262078708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 187}], {
             RGBColor[
             0.8610967865790898, 0.8902141504168143, 0.8851681121431536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 86}], {
             RGBColor[
             0.8684843804892428, 0.8977013609195404, 0.9660283609490126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 101}], {
             RGBColor[
             0.9444318202334208, 0.9579168840792165, 0.973363291663879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 124}], {
             RGBColor[
             0.7769381704165033, 0.8254511183122231, 0.9574054890942193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 135}], {
             RGBColor[
             0.9536645322937853, 0.964963664568846, 0.9633180399878813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 137}], {
             RGBColor[
             0.9724936461349538, 0.9787761642560237, 0.9211354239132654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 161}], {
             RGBColor[
             0.9196162177623839, 0.9381295962703963, 0.9709963573470416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 165}], {
             RGBColor[
             0.8710640940502834, 0.8997166527599746, 0.9662854826879833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 175}], {
             RGBColor[
             0.8518387432448119, 0.8846976625926624, 0.9643692793908119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 176}], {
             RGBColor[
             0.9560617723784262, 0.9667515222988506, 0.9592601378249337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 187}], {
             RGBColor[
             0.845231899686216, 0.8795363461908166, 0.9637107709693544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 199}], {
             RGBColor[
             0.9747834822421078, 0.9797230703324356, 0.8831869137118393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 93}], {
             RGBColor[
             0.7360611369656918, 0.7937358215602157, 0.9743273533164847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 139}], {
             RGBColor[
             0.8264333965257824, 0.8651345873956047, 0.9831227139397276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 152}], {
             RGBColor[
             0.8644072975987055, 0.8921238391410211, 0.8548223438939954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 194}], {
             RGBColor[
             0.7330974460316156, 0.7914205636776301, 0.9740319603014425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 99}], {
             RGBColor[
             0.7458081417673235, 0.8013502557912306, 0.9752988436641727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 109}], {
             RGBColor[
             0.6493832829326922, 0.7239855705949223, 0.9670807221366995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 132}], {
             RGBColor[
             0.6022227501131822, 0.6846600851283229, 0.9636549964055648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 146}], {
             RGBColor[
             0.5795271165051696, 0.6650022680127753, 0.9622088507010231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 150}], {
             RGBColor[
             0.8273949275136685, 0.8654536941044768, 0.9833332027785416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 151}], {
             RGBColor[
             0.7964952723006637, 0.8409474274003361, 0.9803508631375704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 152}], {
             RGBColor[
             0.8920958177350786, 0.9137543215121029, 0.8575820768172571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 194}], {
             RGBColor[
             0.7607859661679888, 0.8130510460487119, 0.976791693224704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 196}], {
             RGBColor[
             0.8794895009867373, 0.9061181108177339, 0.9579866532368322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 101}], {
             RGBColor[
             0.853506653419392, 0.886369957642435, 0.9857984244961808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 108}], {
             RGBColor[
             0.640192839827979, 0.7167053187484513, 0.9662334907894026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 110}], {
             RGBColor[
             0.8858069336136584, 0.9089819475925942, 0.8633284003468813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 124}], {
             RGBColor[
             0.6860130036024745, 0.7539041918754417, 0.9698406219265212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 127}], {
             RGBColor[
             0.7955677606837609, 0.8402228482758622, 0.9802584174476865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 161}], {
             RGBColor[
             0.8286910509483552, 0.8665826698336148, 0.9834314901793435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 175}], {
             RGBColor[
             0.7609135764307833, 0.813150736155881, 0.9768044122231138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 176}], {
             RGBColor[
             0.8651366055643974, 0.8952045958620691, 0.9716952706572355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 180}], {
             RGBColor[
             0.8860969536458083, 0.909101878329063, 0.8585220178663735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 187}], {
             RGBColor[
             0.7543067328721873, 0.8079894197540349, 0.9761459038016562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 199}], {
             RGBColor[
             0.8838583154280791, 0.908176143895654, 0.8956220465441411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 95}], {
             RGBColor[
             0.8100578157572835, 0.8519754936449131, 0.9560242118135782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 103}], {
             RGBColor[
             0.876723470557029, 0.9040552098522168, 0.9626688212580523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 108}], {
             RGBColor[
             0.7334504727781703, 0.7899917946105202, 0.949850101193175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 110}], {
             RGBColor[
             0.9790645665638498, 0.982268423454663, 0.8469450107506538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 131}], {
             RGBColor[
             0.9543192829708222, 0.9654519765517242, 0.962209717877984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 143}], {
             RGBColor[
             0.7969542962967412, 0.8415470593575438, 0.9548493548027273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[
             0.9779430601464191, 0.9818046517296553, 0.8655312744530503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 162}], {
             RGBColor[
             0.9081411146151654, 0.9288593647455993, 0.9657311222987044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 180}], {
             RGBColor[
             0.9793545865959996, 0.9823883541911318, 0.842138628270146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 94}], {
             RGBColor[
             0.7436072672649671, 0.7968385071372088, 0.9021183293073013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 102}], {
             RGBColor[
             0.7459811044746857, 0.7955310876474806, 0.6963870474745903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[
             0.737118801345374, 0.7926122825988877, 0.9405468544276825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 122}], {
             RGBColor[
             0.587608104025139, 0.6755722175355683, 0.9610289180636284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 136}], {
             RGBColor[
             0.7446780527190285, 0.7972813044403942, 0.8843726432295764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 142}], {
             RGBColor[
             0.48903769927900687`, 0.5960618610288124, 0.9529179855728132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 153}], {
             RGBColor[
             0.5944347583840414, 0.6809052518052376, 0.9617093351714117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 167}], {
             RGBColor[
             0.65869004079365, 0.7311019667818576, 0.9681137012222475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 188}], {
             RGBColor[
             0.7444244385247817, 0.7971764284534857, 0.8885756867607435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 113}], {
             RGBColor[
             0.9193937763010609, 0.9375526686631299, 0.957122185428382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 118}], {
             RGBColor[
             0.927373609913793, 0.9423956120689655, 0.8939778380968169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 122}], {
             RGBColor[
             0.769883078980826, 0.8205126035998105, 0.977604249064328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 136}], {
             RGBColor[
             0.9269530276747155, 0.9422216905046364, 0.900947974230276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 138}], {
             RGBColor[
             0.9288690644667957, 0.9417825867223377, 0.7796820167848115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 144}], {
             RGBColor[
             0.9134578757493368, 0.89063116735809, 0.6488833077732092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 149}], {
             RGBColor[
             0.6968049151445845, 0.7616979966760696, 0.9715001591590946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 159}], {
             RGBColor[
             0.8545192587066888, 0.886834477858089, 0.9859860038054333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 170}], {
             RGBColor[
             0.8744832422876887, 0.9027532164576801, 0.9878901863814478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 192}], {
             RGBColor[
             0.769883078980826, 0.8205126035998105, 0.977604249064328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 197}], {
             RGBColor[
             0.9134966673408489, 0.9331546144562335, 0.9671044526856762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 141}], {
             RGBColor[
             0.8623697206107641, 0.8927910811632663, 0.9586631355286368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 177}], {
             RGBColor[
             0.7944034787172252, 0.8393813057733808, 0.9521036001947081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 198}], {
             RGBColor[
             0.9802609446309796, 0.9832405109593833, 0.8484948366492873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 95}], {
             RGBColor[
             0.621571006738716, 0.7034487774645419, 0.963494792980687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 136}], {
             RGBColor[
             0.7885616734638403, 0.832908004695618, 0.8878273226056075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 97}], {
             RGBColor[
             0.9535672014100238, 0.8793726865698731, 0.5993067711992183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 155}], {
             RGBColor[
             0.8324100079239882, 0.8692945158843881, 0.951029622884078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 134}], {
             RGBColor[
             0.7499483557820832, 0.8045846224463529, 0.9757115015046642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 139}], {
             RGBColor[
             0.828499112225759, 0.8667483402004472, 0.9833286051754905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 145}], {
             RGBColor[
             0.8081529913195715, 0.8505248956705928, 0.9813879740002618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 105}], {
             RGBColor[
             0.9914074872227914, 0.9904146261924412, 0.7702450074074922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 111}], {
             RGBColor[
             0.9025999572405479, 0.5616917304693556, 0.5073630702217939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 115}], {
             RGBColor[
             0.7826725619995397, 0.8285534732742074, 0.9051936924096966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 116}], {
             RGBColor[
             0.8832959187790096, 0.9081553097797004, 0.9145432129273642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 126}], {
             RGBColor[
             0.9899835197941986, 0.9901259422701709, 0.8156625290373511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 142}], {
             RGBColor[
             0.7333113464951357, 0.7884798148303147, 0.9013077967090997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 153}], {
             RGBColor[
             0.8387084056001701, 0.8733232056067399, 0.9100991463076982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 160}], {
             RGBColor[
             0.6748734053755105, 0.7385541226020517, 0.8973934466309137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 167}], {
             RGBColor[
             0.9029636880097788, 0.9235199205833599, 0.916503512358534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 174}], {
             RGBColor[
             0.9675746447630943, 0.9747249409521141, 0.9123266031342607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 188}], {
             RGBColor[
             0.9886980857409104, 0.989594382254988, 0.83696549789703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 103}], {
             RGBColor[
             0.7227068067387159, 0.7833033172902333, 0.9729963184827711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 129}], {
             RGBColor[
             0.5990735654164018, 0.6851843411009053, 0.9617237119889515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 131}], {
             RGBColor[
             0.800302619152509, 0.8447000839897407, 0.972537215102703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 143}], {
             RGBColor[
             0.642937632478428, 0.7207951667955603, 0.9651768520274462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 154}], {
             RGBColor[
             0.8239263963281058, 0.8610527591676718, 0.8758587716777693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 105}], {
             RGBColor[
             0.7663199340129144, 0.8135728078288995, 0.823365595872356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 111}], {
             RGBColor[
             0.677512404030671, 0.38484991210581376`, 0.5604836586866576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 116}], {
             RGBColor[
             0.6582083655691326, 0.7313134914161586, 0.9676638013922279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 126}], {
             RGBColor[
             0.7648959665843217, 0.8132841239066291, 0.8687831175022148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.7010916499192652, 0.7651738634055485, 0.9718425731694162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 174}], {
             RGBColor[
             0.7424870915532173, 0.7978831225885724, 0.9654471915991245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 182}], {
             RGBColor[
             0.5485013498274056, 0.6443371313509323, 0.9575991819665123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 191}], {
             RGBColor[
             0.7480487744958639, 0.8020310166207782, 0.9560327130964522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 102}], {
             RGBColor[
             0.9638147944502666, 0.8833246385658343, 0.35280202976839337`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 112}], {
             RGBColor[
             0.8104235293764509, 0.7672575379920343, 0.6179404331827203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 140}], {
             RGBColor[
             0.8875130599974907, 0.827642450127351, 0.6255810113373306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 155}], {
             RGBColor[
             0.8138438065139646, 0.7699294844869291, 0.6182813344434805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 99}], {
             RGBColor[
             0.8105575968910177, 0.8527322920603804, 0.9815403625999168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 117}], {
             RGBColor[
             0.934221009996326, 0.950028779277865, 0.9811859418449507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 120}], {
             RGBColor[
             0.8200115087419404, 0.8601177598507124, 0.9824826401813875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 121}], {
             RGBColor[
             0.9390149463998858, 0.9536040891982895, 0.9730710579725856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 146}], {
             RGBColor[
             0.6442765716288638, 0.716384304281925, 0.9684503696367672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 156}], {
             RGBColor[
             0.6887222053624209, 0.7547381916916581, 0.9713218308569264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.7353021841783035, 0.7925539168985241, 0.9749887774173971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 178}], {
             RGBColor[
             0.9553415062515456, 0.9645145116441249, 0.8887449000579872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 179}], {
             RGBColor[
             0.8885805134791317, 0.9139939978455043, 0.9892347966924702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 183}], {
             RGBColor[
             0.8285525383888921, 0.8667900771251407, 0.9833339301961357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 196}], {
             RGBColor[
             0.9442389561104314, 0.9575001470868836, 0.9642281721725763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 107}], {
             RGBColor[
             0.6660455077726286, 0.7388474149788017, 0.9674798920825131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 109}], {
             RGBColor[
             0.6058189631615543, 0.689952792888616, 0.9627386378736271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 146}], {
             RGBColor[
             0.5359627967340317, 0.6309694903064691, 0.9578667664379508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 147}], {
             RGBColor[
             0.831770016345909, 0.8689864179550707, 0.9606781792575823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 156}], {
             RGBColor[
             0.5804084304675888, 0.6693233777162022, 0.96073822765811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 178}], {
             RGBColor[
             0.8470277313567135, 0.8790996976686691, 0.8781612968591709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 179}], {
             RGBColor[
             0.7802667385842996, 0.8285791838700485, 0.9786511934936537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 194}], {
             RGBColor[
             0.7172216463968508, 0.7790182683424057, 0.9724496089616318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 104}], {
             RGBColor[
             0.7011910063652127, 0.7601551693693713, 0.8551869553612527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 123}], {
             RGBColor[
             0.970962617543311, 0.9763752131795999, 0.8673414275040301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 130}], {
             RGBColor[
             0.9921740618067326, 0.9910317876867156, 0.7793595789486577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 135}], {
             RGBColor[
             0.9705380263923573, 0.9760585537944229, 0.868060149571487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 148}], {
             RGBColor[
             0.9653334480539489, 0.9721769877913526, 0.8768701431269813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 163}], {
             RGBColor[
             0.9343796404695288, 0.9475419718448114, 0.8755372064376501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 165}], {
             RGBColor[
             0.8879375881488553, 0.9108115419855514, 0.871027592271589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 123}], {
             RGBColor[
             0.9391113963748884, 0.9539489206769176, 0.9823693814675926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 124}], {
             RGBColor[
             0.7619604433466525, 0.8141197150351176, 0.9771755526413874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 127}], {
             RGBColor[
             0.8715152004279388, 0.9004383714355383, 0.9875933481625527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 135}], {
             RGBColor[
             0.9386868052239347, 0.9536322612917405, 0.9830881035350495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 137}], {
             RGBColor[
             0.9575159190651031, 0.9674447609789182, 0.9409054874604336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 161}], {
             RGBColor[
             0.9046384906925331, 0.9267981929932908, 0.9907664208942097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 165}], {
             RGBColor[
             0.8560863669804326, 0.8883852494828691, 0.9860555462351515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 175}], {
             RGBColor[
             0.8368610161749612, 0.8733662593155569, 0.9841393429379801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 176}], {
             RGBColor[
             0.9410840453085754, 0.9554201190217452, 0.9790302013721018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 187}], {
             RGBColor[
             0.8302541726163652, 0.8682049429137111, 0.9834808345165227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 199}], {
             RGBColor[
             0.9598057551722571, 0.9683916670553301, 0.9029569772590075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 106}], {
             RGBColor[
             0.8474238588834531, 0.8769699047917473, 0.7049999374994286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 112}], {
             RGBColor[
             0.8392373238267175, 0.8705745213854545, 0.704183980192493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 140}], {
             RGBColor[
             0.9163268544477573, 0.9309594335207713, 0.7118245583471032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 108}], {
             RGBColor[
             0.6460994637596027, 0.7213196182558403, 0.9668222078623678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 129}], {
             RGBColor[
             0.6657392202161474, 0.737264057308209, 0.9683683214334254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 131}], {
             RGBColor[
             0.8669682739522546, 0.8967798001970443, 0.979181824547177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 133}], {
             RGBColor[
             0.5414888324981446, 0.6306555481748837, 0.9598363409814847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 143}], {
             RGBColor[
             0.7096032872781735, 0.772874883002864, 0.9718214614719201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 154}], {
             RGBColor[
             0.8905920511278513, 0.9131324753749753, 0.8825033811222431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 162}], {
             RGBColor[
             0.8207901055965978, 0.8601871883909193, 0.9827032289678973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 123}], {
             RGBColor[
             0.6789970884081085, 0.7450923167414956, 0.9594509355813605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 130}], {
             RGBColor[
             0.7002085326715302, 0.7597488912486112, 0.8714690870259882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 163}], {
             RGBColor[
             0.6424141113343264, 0.7162590754067071, 0.9676467145149805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 111}], {
             RGBColor[
             0.9061265299822434, 0.5628498957230856, 0.4270999371856984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 116}], {
             RGBColor[
             0.8868224915207051, 0.9093134750334306, 0.8342800798912686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 126}], {
             RGBColor[
             0.9935100925358942, 0.9912841075239011, 0.7353993960012556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 142}], {
             RGBColor[
             0.7368379192368313, 0.789637980084045, 0.8210446636730042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 157}], {
             RGBColor[
             0.9297057758708376, 0.9431738470228205, 0.838458851668457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 160}], {
             RGBColor[
             0.6783999781172061, 0.7397122878557818, 0.8171303135948182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 174}], {
             RGBColor[
             0.9711012175047898, 0.9758831062058444, 0.8320634700981653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 182}], {
             RGBColor[
             0.7771154757789782, 0.8223371149682043, 0.824215460465553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 112}], {
             RGBColor[
             0.6940325938096373, 0.7609028042179473, 0.9701383409137554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 140}], {
             RGBColor[
             0.7711221244306772, 0.821287716353264, 0.9777789190683657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 189}], {
             RGBColor[
             0.7708063740727915, 0.8210359455887011, 0.9777488025173569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 111}], {
             RGBColor[
             0.7235830967745358, 0.42225217593633946`, 0.5641105123819627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 142}], {
             RGBColor[
             0.5542944860291235, 0.6490402602972987, 0.9580552388692687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[
             0.795571702122352, 0.8405163548489479, 0.9572013119389948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.5442101162440318, 0.6408533146100794, 0.9572613603395226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.74716234266313, 0.8025761272360743, 0.9754694268647215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.7440684243607426, 0.8001091207639257, 0.9751743261750663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 181}], {
             RGBColor[
             0.6703848866626383, 0.7422373707481784, 0.9679124008164679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 185}], {
             RGBColor[
             0.46531122778109724`, 0.5719208004372469, 0.9522215515136117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 110}], {
             RGBColor[
             0.7484405597664233, 0.7995328318582866, 0.8510983973549695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 131}], {
             RGBColor[
             0.7236952761733959, 0.7827163849553478, 0.9663631044822998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 154}], {
             RGBColor[
             0.7473190533489926, 0.7990690601332788, 0.869684661057366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 162}], {
             RGBColor[
             0.6775171078177391, 0.7461237731492228, 0.9698845089030201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 180}], {
             RGBColor[
             0.7487305797985733, 0.7996527625947554, 0.8462920148744615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 132}], {
             RGBColor[
             0.46223357150741295`, 0.5732626222257082, 0.9510947906150192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 146}], {
             RGBColor[
             0.43953793789940043`, 0.5536048051101607, 0.9496486449104775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 150}], {
             RGBColor[
             0.6874057489078993, 0.7540562312018622, 0.970772996987996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 151}], {
             RGBColor[
             0.6565060936948945, 0.7295499644977215, 0.9677906573470247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 152}], {
             RGBColor[
             0.7521066391293094, 0.8023568586094882, 0.8450218710267114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 194}], {
             RGBColor[
             0.6207967875622196, 0.7016535831460973, 0.9642314874341584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 196}], {
             RGBColor[
             0.7395003223809681, 0.7947206479151193, 0.9454264474462866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 127}], {
             RGBColor[
             0.9038154806222052, 0.9230503613856975, 0.8651233240132533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 162}], {
             RGBColor[
             0.9231312016034183, 0.9384004019933657, 0.8669794184604989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 180}], {
             RGBColor[
             0.9943446735842525, 0.9919293914388982, 0.7433869244319403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 116}], {
             RGBColor[
             0.7980149615384617, 0.4805905793103449, 0.5713981427055703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 126}], {
             RGBColor[
             0.9047025625536507, 0.5625612118008154, 0.4725174588155572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 142}], {
             RGBColor[
             0.6480303892545878, 0.3609150843609592, 0.5581627264873058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 157}], {
             RGBColor[
             0.8408982458885942, 0.5144509512997348, 0.5755769144827586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 160}], {
             RGBColor[
             0.5895924481349626, 0.31098939213269616`, 0.5542483764091198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 167}], {
             RGBColor[
             0.8176827307692309, 0.4959551901140043, 0.5733584421367401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 174}], {
             RGBColor[
             0.8822936875225464, 0.5471602104827586, 0.5691815329124669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 181}], {
             RGBColor[
             0.7641207898881026, 0.4541121948118389, 0.5680198884345051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.5590471310065616, 0.28379562450090745`, 0.5523290391316488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 188}], {
             RGBColor[
             0.9034171285003625, 0.5620296517856324, 0.49382042767523615`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 140}], {
             RGBColor[
             0.7629355893739416, 0.8148923329469713, 0.97696296176143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 122}], {
             RGBColor[
             0.8253932853216747, 0.8637639467987496, 0.947847254320296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 136}], {
             RGBColor[
             0.9824632340155643, 0.9854730337035755, 0.8711909794862441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 138}], {
             RGBColor[
             0.9843792708076444, 0.9850339299212767, 0.7499250220407797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 144}], {
             RGBColor[
             0.9689680820901856, 0.933882510557029, 0.6191263130291775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 159}], {
             RGBColor[
             0.9100294650475376, 0.930085821057028, 0.9562290090614016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 167}], {
             RGBColor[
             0.8964752220901857, 0.9192936960450389, 0.9549320374789152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 197}], {
             RGBColor[
             0.9690068736816976, 0.9764059576551725, 0.9373474579416445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 158}], {
             RGBColor[
             0.6187511463452299, 0.6960310230299669, 0.966015731786398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 160}], {
             RGBColor[
             0.4696650528939544, 0.5778511349375479, 0.9520789985970226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 126}], {
             RGBColor[
             0.8853985240921124, 0.9090247911111602, 0.8796976015211275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 142}], {
             RGBColor[
             0.6287263507930494, 0.7073786636713041, 0.965342869192876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 153}], {
             RGBColor[
             0.7341234098980839, 0.7922220544477292, 0.9741342187914745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 157}], {
             RGBColor[
             0.8215942074270559, 0.8609145306100796, 0.9827570571883288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 160}], {
             RGBColor[
             0.5702884096734242, 0.657452971443041, 0.9614285191146901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 167}], {
             RGBColor[
             0.7983786923076925, 0.8424187694243492, 0.9805385848423104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 174}], {
             RGBColor[
             0.8629896490610081, 0.8936237897931035, 0.9763616756180371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 188}], {
             RGBColor[
             0.8841130900388242, 0.9084932310959772, 0.9010005703808064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 120}], {
             RGBColor[
             0.8353611469524167, 0.8719994330927413, 0.971544616227605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 121}], {
             RGBColor[
             0.9543645846103621, 0.9654857624403184, 0.962133034018803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 146}], {
             RGBColor[
             0.6596262098393401, 0.7282659775239538, 0.9575123456829846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 151}], {
             RGBColor[
             0.8765943656348343, 0.9042111369115147, 0.9756543581195319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 171}], {
             RGBColor[
             0.7506518223887799, 0.8044355901405529, 0.9640507534636146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 173}], {
             RGBColor[
             0.9720704567480649, 0.9763525619705914, 0.8103164934759676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 196}], {
             RGBColor[
             0.9595885943209077, 0.9693818203289124, 0.9532901482187937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 119}], {
             RGBColor[
             0.8896312971181103, 0.9125562065796846, 0.8903101964275164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 125}], {
             RGBColor[
             0.7075004328540293, 0.7661389850518991, 0.8746615611290712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 128}], {
             RGBColor[
             0.8126483509900936, 0.8522951285595193, 0.8827202681849183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 138}], {
             RGBColor[
             0.9923591044203766, 0.9898768733271123, 0.6867806747092144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 144}], {
             RGBColor[
             0.9769479157029177, 0.9387254539628644, 0.5559819656976123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 149}], {
             RGBColor[
             0.7602949550981654, 0.8097922832808442, 0.8785988170834975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 159}], {
             RGBColor[
             0.9180092986602697, 0.9349287644628634, 0.8930846617298364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 170}], {
             RGBColor[
             0.9379732822412696, 0.9508475030624548, 0.8949888443058507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 190}], {
             RGBColor[
             0.6669565283338927, 0.7310218927524496, 0.8720781393846152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 192}], {
             RGBColor[
             0.8333731189344068, 0.8686068902045851, 0.8847029069887309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.9446957988505748, 0.8113054169171827, 0.5190590335985852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 197}], {
             RGBColor[
             0.9769867072944297, 0.9812489010610079, 0.8742031106100793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 125}], {
             RGBColor[
             0.6062680801047657, 0.6882052929578437, 0.963895261535368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 128}], {
             RGBColor[
             0.7114159982408299, 0.7743614364654638, 0.9719539685912151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 144}], {
             RGBColor[
             0.8757155629536539, 0.860791761868809, 0.645215666103909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 149}], {
             RGBColor[
             0.6590626023489017, 0.7318585911867888, 0.9678325174897943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 183}], {
             RGBColor[
             0.7633163246803907, 0.8150277813500372, 0.9770438957136756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 190}], {
             RGBColor[
             0.5657241755846291, 0.6530882006583941, 0.961311839790912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 192}], {
             RGBColor[
             0.7321407661851431, 0.7906731981105297, 0.9739366073950275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 195}], {
             RGBColor[
             0.8434634461013111, 0.7333717248231273, 0.6082927340048818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 128}], {
             RGBColor[
             0.6777923489054221, 0.7480943860554436, 0.9686026774563294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 168}], {
             RGBColor[
             0.5503392431407927, 0.6426186101152878, 0.959122703568493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 171}], {
             RGBColor[
             0.6364423211343941, 0.7145245707134003, 0.9653474518000514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 172}], {
             RGBColor[
             0.7420777631856873, 0.7984360556913291, 0.9749270343895251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 173}], {
             RGBColor[
             0.8578609554936791, 0.8864415425434388, 0.8116131918124044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 183}], {
             RGBColor[
             0.7296926753449828, 0.7887607309400169, 0.9736926045787899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 151}], {
             RGBColor[
             0.8813883020383939, 0.907786446831939, 0.9675394742471668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 171}], {
             RGBColor[
             0.7554457587923396, 0.8080109000609774, 0.9559358695912494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 196}], {
             RGBColor[
             0.9643825307244676, 0.9729571302493369, 0.9451752643464285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 136}], {
             RGBColor[
             0.8329525366953292, 0.8684329686402561, 0.89167304312219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 138}], {
             RGBColor[
             0.8348685734874095, 0.8679938648579573, 0.7704070856767256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 142}], {
             RGBColor[
             0.5773121832553076, 0.6672135252286743, 0.9602183854654268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 144}], {
             RGBColor[
             0.8194573847699504, 0.8168424454937095, 0.6396083766651234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 153}], {
             RGBColor[
             0.682709242360342, 0.7520569160050994, 0.9690097350640252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.7605187677273025, 0.8130457559937085, 0.9767110726973475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 167}], {
             RGBColor[
             0.7469645247699507, 0.8022536309817194, 0.9754141011148612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 181}], {
             RGBColor[
             0.6934025838888224, 0.7604106356795539, 0.9700755474126261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 188}], {
             RGBColor[
             0.8326989225010824, 0.8683280926533474, 0.8958760866533572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 192}], {
             RGBColor[
             0.6758825880014396, 0.7467238817354301, 0.968329317956242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 127}], {
             RGBColor[
             0.8811725036392573, 0.9078018113103448, 0.9768293744190981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 130}], {
             RGBColor[
             0.9699801438496285, 0.9759689350588399, 0.8836235591687656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 135}], {
             RGBColor[
             0.9483441084352531, 0.9609957011665471, 0.9723241297915949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 163}], {
             RGBColor[
             0.9121857225124246, 0.9324791192169356, 0.979801186657758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 165}], {
             RGBColor[
             0.8657436701917511, 0.8957486893576756, 0.9752915724916968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 177}], {
             RGBColor[
             0.7853139540534106, 0.8326023531618385, 0.9674897945228351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 187}], {
             RGBColor[
             0.8399114758276838, 0.8755683827885176, 0.9727168607730681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 127}], {
             RGBColor[
             0.7040215506110213, 0.767972605668545, 0.9716355455928931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 135}], {
             RGBColor[
             0.7711931554070172, 0.8211664955247471, 0.9671303009653898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.7900222692481856, 0.8349789952119249, 0.9249476848907738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 161}], {
             RGBColor[
             0.7371448408756156, 0.7943324272262975, 0.9748086183245501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 175}], {
             RGBColor[
             0.6693673663580437, 0.7409004935485636, 0.9681815403683205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 176}], {
             RGBColor[
             0.7735903954916579, 0.8229543532547519, 0.9630723988024421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 187}], {
             RGBColor[
             0.6627605227994477, 0.7357391771467177, 0.967523031946863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 199}], {
             RGBColor[
             0.7923121053553396, 0.8359259012883367, 0.8869991746893477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 128}], {
             RGBColor[
             0.529285133976749, 0.6279442149376784, 0.9563053332927698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.47693173808482076`, 0.5854413696590033, 0.9521838821913491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[
             0.654610065227925, 0.7264965894406139, 0.9685739094137021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 190}], {
             RGBColor[
             0.38359331132054814`, 0.5066709791306087, 0.9456632044924667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 195}], {
             RGBColor[
             0.6613325818372302, 0.5869545032953418, 0.5926440987064366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 142}], {
             RGBColor[
             0.7354139518082385, 0.7893492961617745, 0.866462185302863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 157}], {
             RGBColor[
             0.9282818084422448, 0.9428851631005501, 0.8838763732983158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 160}], {
             RGBColor[
             0.6769760106886133, 0.7394236039335115, 0.862547835224677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 174}], {
             RGBColor[
             0.9696772500761971, 0.975594422283574, 0.877480991728024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 182}], {
             RGBColor[
             0.7756915083503855, 0.822048431045934, 0.8696329820954118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 191}], {
             RGBColor[
             0.9752389330188437, 0.9797423163157798, 0.8680665132253518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 135}], {
             RGBColor[
             0.8807479124883035, 0.9074851519251678, 0.977548096486555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 161}], {
             RGBColor[
             0.846699597956902, 0.8806510836267181, 0.9852264138457154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 175}], {
             RGBColor[
             0.77892212343933, 0.8272191499489843, 0.9785993358894858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 176}], {
             RGBColor[
             0.8831451525729443, 0.9092730096551724, 0.9734901943236074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 177}], {
             RGBColor[
             0.7177177581064611, 0.7790918039204593, 0.9727137612177954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 180}], {
             RGBColor[
             0.904105500654355, 0.9231702921221663, 0.8603169415327454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 187}], {
             RGBColor[
             0.7723152798807342, 0.8220578335471382, 0.9779408274680282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 183}], {
             RGBColor[
             0.686333378552374, 0.7547667033298718, 0.9694539674710775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 190}], {
             RGBColor[
             0.48874122945661236`, 0.5928271226382288, 0.9537219115483138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 192}], {
             RGBColor[
             0.6551578200571264, 0.7304121200903644, 0.9663466791524294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 195}], {
             RGBColor[
             0.7664804999732944, 0.673110646802962, 0.6007028057622837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 131}], {
             RGBColor[
             0.7433350326299405, 0.7986608240077164, 0.9679092180533573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 133}], {
             RGBColor[
             0.4178555911758306, 0.5325365719855557, 0.9485637344876652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 143}], {
             RGBColor[
             0.5859700459558594, 0.674755906813536, 0.9605488549781005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 170}], {
             RGBColor[
             0.7135944467544992, 0.7751750942850253, 0.9729984537650437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 197}], {
             RGBColor[
             0.7526078718076594, 0.8055764922835784, 0.9522127200692723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 163}], {
             RGBColor[
             0.9333971667758463, 0.9471356937240514, 0.8918193381023856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 177}], {
             RGBColor[
             0.8065253983168323, 0.8472589276689544, 0.8795079459674628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 133}], {
             RGBColor[
             0.6190846449119378, 0.6920523148743911, 0.9593772376014167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 143}], {
             RGBColor[
             0.7871990996919667, 0.8342716497023714, 0.971362358091852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 154}], {
             RGBColor[
             0.9681878635416445, 0.9745292420744828, 0.8820442777421751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 162}], {
             RGBColor[
             0.8983859180103909, 0.9215839550904268, 0.9822441255878291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 180}], {
             RGBColor[
             0.9695993899912251, 0.9751129445359594, 0.8586516315592706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 150}], {
             RGBColor[
             0.6402452160883892, 0.7147307457352627, 0.9673472712568614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 151}], {
             RGBColor[
             0.6093455608753845, 0.690224479031122, 0.9643649316158902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 162}], {
             RGBColor[
             0.572906476556281, 0.6554597030682662, 0.962898642022137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 139}], {
             RGBColor[
             0.8403206153421738, 0.8759833882817418, 0.9845068621279072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 145}], {
             RGBColor[
             0.8199744944359864, 0.8597599437518874, 0.9825662309526784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 191}], {
             RGBColor[
             0.860080799914442, 0.8911544397787882, 0.9661029336383351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 148}], {
             RGBColor[
             0.9427149389458911, 0.9567974757782999, 0.9818528454145461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 163}], {
             RGBColor[
             0.9117611313614709, 0.9321624598317586, 0.9805199087252149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 165}], {
             RGBColor[
             0.8653190790407974, 0.8954320299724986, 0.9760102945591538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 176}], {
             RGBColor[
             0.9503167573689402, 0.9624668995113747, 0.9689849496961042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 187}], {
             RGBColor[
             0.83948688467673, 0.8752517234033406, 0.973435582840525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 143}], {
             RGBColor[
             0.8099282992035522, 0.8502543940266365, 0.8895093816523666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 159}], {
             RGBColor[
             0.9175887164211922, 0.9347548428985344, 0.9000547978632956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 197}], {
             RGBColor[
             0.9765661250553521, 0.9810749794966789, 0.8811732467435385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 161}], {
             RGBColor[
             0.9327003165940663, 0.947657473170098, 0.9385385531435961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 175}], {
             RGBColor[
             0.8649228420764943, 0.8942255394923642, 0.9319114751873665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 176}], {
             RGBColor[
             0.9691458712101086, 0.9762793991985523, 0.9268023336214882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 186}], {
             RGBColor[
             0.9785233105948495, 0.9832730781375444, 0.9109287747710182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 187}], {
             RGBColor[
             0.8583159985178985, 0.8890642230905181, 0.9312529667659091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 199}], {
             RGBColor[
             0.9878675810737902, 0.9892509472321372, 0.8507291095083939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 142}], {
             RGBColor[
             0.7362981687412774, 0.7884835083512014, 0.7622961531859105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 144}], {
             RGBColor[
             0.9784433702559203, 0.9381124286162368, 0.441686144385607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 156}], {
             RGBColor[
             0.7262137989561857, 0.7802965626639823, 0.7615022746561644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 159}], {
             RGBColor[
             0.9195047532132723, 0.9343157391162358, 0.7787888404178311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 167}], {
             RGBColor[
             0.9059505102559204, 0.9235236141042465, 0.7774918688353447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 181}], {
             RGBColor[
             0.8523885693747921, 0.8816806188020812, 0.7721533151331097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 185}], {
             RGBColor[
             0.6473149104932512, 0.7113640484911496, 0.7564624658302534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 192}], {
             RGBColor[
             0.8348685734874095, 0.8679938648579573, 0.7704070856767256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 145}], {
             RGBColor[
             0.8985252508796622, 0.9219236615059817, 0.9901833346235045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 152}], {
             RGBColor[
             0.9568452728587727, 0.9651363577812525, 0.8638235957530012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 182}], {
             RGBColor[
             0.7390841316896595, 0.7956242722630367, 0.9752865061792213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 191}], {
             RGBColor[
             0.9386315563581178, 0.9533181575328825, 0.9737200373091612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 198}], {
             RGBColor[
             0.8756829163279081, 0.9011613263478412, 0.8663249531100404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 153}], {
             RGBColor[
             0.58413883761421, 0.6725465594983435, 0.9608988025732101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 157}], {
             RGBColor[
             0.671609635143182, 0.7412390356606939, 0.9695216409700644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 160}], {
             RGBColor[
             0.42030383738955035`, 0.5377774764936554, 0.9481931028964257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 167}], {
             RGBColor[
             0.6483941200238186, 0.7227432744749636, 0.9673031686240459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 174}], {
             RGBColor[
             0.7130050767771341, 0.7739482948437179, 0.9631262593997727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 181}], {
             RGBColor[
             0.5948321791426903, 0.680900279172798, 0.9619646149218108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 185}], {
             RGBColor[
             0.3897585202611493, 0.5105837088618667, 0.9462737656189546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.7341285177549504, 0.7888177361465916, 0.887765154162542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 154}], {
             RGBColor[
             0.8108228768675635, 0.8506243248803025, 0.8746839146669182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 159}], {
             RGBColor[
             0.7374945302355256, 0.7948671813800889, 0.9745474112275241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 197}], {
             RGBColor[
             0.7964719388696855, 0.8411873179782334, 0.955665860107767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 149}], {
             RGBColor[
             0.746379220933709, 0.7580278385699686, 0.6335042867598901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 159}], {
             RGBColor[
             0.9040935644958135, 0.883164319751988, 0.6479901314062289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 170}], {
             RGBColor[
             0.9240575480768134, 0.8990830583515792, 0.6498943139822432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 181}], {
             RGBColor[
             0.8369773806573333, 0.8305291994378334, 0.6413546061215074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 190}], {
             RGBColor[
             0.6530407941694365, 0.6792574480415741, 0.6269836090610077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 192}], {
             RGBColor[
             0.8194573847699504, 0.8168424454937095, 0.6396083766651234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 197}], {
             RGBColor[
             0.9630709731299734, 0.9294844563501324, 0.6291085802864718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 147}], {
             RGBColor[
             0.6654889910837551, 0.7326384301766153, 0.9475881862944326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 156}], {
             RGBColor[
             0.4141274052054349, 0.532975389937747, 0.9476482346949602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 171}], {
             RGBColor[
             0.4607073840213176, 0.5707911151446129, 0.951315181255431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 178}], {
             RGBColor[
             0.6807467060945596, 0.7427517098902138, 0.8650713038960212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 179}], {
             RGBColor[
             0.6139857133221458, 0.6922311960915931, 0.965561200530504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 183}], {
             RGBColor[
             0.5539577382319062, 0.6450272753712295, 0.9596603340341696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 194}], {
             RGBColor[
             0.550940621134697, 0.6426702805639504, 0.9593596159984821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 196}], {
             RGBColor[
             0.6696441559534454, 0.7357373453329724, 0.9405545760106101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 152}], {
             RGBColor[
             0.9780576923136641, 0.9813904836759428, 0.8429614124106666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 156}], {
             RGBColor[
             0.7099346248173122, 0.7709923175863485, 0.9504596475145918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 178}], {
             RGBColor[
             0.9765539257064368, 0.9807686375388154, 0.8678827167156526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 179}], {
             RGBColor[
             0.9097929329340231, 0.9302481237401947, 0.9683726133501356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 185}], {
             RGBColor[
             0.6310357363543777, 0.7020598034135159, 0.9454198386886808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 194}], {
             RGBColor[
             0.8467478407465743, 0.880687208212552, 0.9621710288181136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 165}], {
             RGBColor[
             0.860114500702389, 0.8915504639694285, 0.9848202881146482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 159}], {
             RGBColor[
             0.6874406038910611, 0.7542311490699676, 0.9706069827921142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 170}], {
             RGBColor[
             0.707404587472061, 0.7701498876695589, 0.9725111653681284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 190}], {
             RGBColor[
             0.43638783356468414`, 0.5503242773595537, 0.9496004604468931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 192}], {
             RGBColor[
             0.6028044241651982, 0.6879092748116893, 0.9622252280510086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 195}], {
             RGBColor[
             0.7141271040813661, 0.6306078015242869, 0.5965813546608629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.7464180125252211, 0.8005512856681121, 0.9517254316723571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 151}], {
             RGBColor[
             0.8345177382758708, 0.871018088007276, 0.984043137988867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 152}], {
             RGBColor[
             0.9301182837102857, 0.9438249821190428, 0.8612743516685535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 194}], {
             RGBColor[
             0.7988084321431959, 0.8431217066556518, 0.9804839680760007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 171}], {
             RGBColor[
             0.6776755398168117, 0.7467362745321736, 0.9694571936919784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 196}], {
             RGBColor[
             0.8866123117489396, 0.9116825047205331, 0.9586965884471574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 194}], {
             RGBColor[
             0.863509322364606, 0.8914223340632779, 0.854732842114716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 160}], {
             RGBColor[
             0.5257008964945848, 0.6226208672700805, 0.9569844524950242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 167}], {
             RGBColor[
             0.7537911791288531, 0.8075866652513887, 0.9760945182226444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 174}], {
             RGBColor[
             0.8184021358821686, 0.858791685620143, 0.9719176089983711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 188}], {
             RGBColor[
             0.8395255768599847, 0.8736611269230168, 0.8965565037611405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 157}], {
             RGBColor[
             0.6615252653580902, 0.7330520899734748, 0.9687277624403183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 178}], {
             RGBColor[
             0.7251923398281167, 0.781105597299947, 0.8679427651161804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.6584313470557028, 0.7305850835013262, 0.9684326617506631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 181}], {
             RGBColor[
             0.5847478093575986, 0.6727133334855789, 0.9611707363920647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 183}], {
             RGBColor[
             0.5984033719654633, 0.6833811627809626, 0.9625317952543287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 185}], {
             RGBColor[
             0.37967415047605757`, 0.5023967631746475, 0.9454798870892085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 192}], {
             RGBColor[
             0.5672278134702158, 0.6590265795414552, 0.9594245069356807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 174}], {
             RGBColor[
             0.9058729334111406, 0.9274841617824934, 0.9805404473952255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 181}], {
             RGBColor[
             0.7877000357766968, 0.8344361461115737, 0.9793788029172636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 185}], {
             RGBColor[
             0.5826263768951557, 0.6641195758006422, 0.9636879536144074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 164}], {
             RGBColor[
             0.6979706527570908, 0.7626159068250589, 0.971624719644686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 166}], {
             RGBColor[
             0.9308129078241452, 0.944573443914501, 0.8697902614946208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 170}], {
             RGBColor[
             0.8651189310341654, 0.8952863688515782, 0.9869970100144673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 197}], {
             RGBColor[
             0.9041323560873255, 0.9256877668501314, 0.9662112763186959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 167}], {
             RGBColor[
             0.5899561789041934, 0.6728175822467004, 0.9633888185458599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 174}], {
             RGBColor[
             0.6545671356575089, 0.7240226026154548, 0.9592119093215867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 188}], {
             RGBColor[
             0.6756905766353252, 0.7388920439183284, 0.883850804084356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 175}], {
             RGBColor[
             0.8120454137039244, 0.8535789715067368, 0.9817724086211428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 176}], {
             RGBColor[
             0.9162684428375385, 0.935632831212925, 0.9766632670552644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 187}], {
             RGBColor[
             0.8054385701453284, 0.8484176551048908, 0.9811139001996853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 193}], {
             RGBColor[
             0.8700850376349409, 0.899246207453664, 0.9874706816953449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 199}], {
             RGBColor[
             0.9349901527012202, 0.9486043792465099, 0.90059004294217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 180}], {
             RGBColor[
             0.9234212216355683, 0.9385203327298346, 0.862173035979991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 177}], {
             RGBColor[
             0.7487309769796284, 0.80376911182705, 0.9756855734564551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 166}], {
             RGBColor[
             0.7609630393626539, 0.8097488072076401, 0.8541602910413119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 184}], {
             RGBColor[
             0.7612219619797023, 0.8090286824073638, 0.7897408594982984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 187}], {
             RGBColor[
             0.756886446433228, 0.8100047115944691, 0.976403025540627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 184}], {
             RGBColor[
             0.9940642170467566, 0.990986219496806, 0.6879064013482332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 181}], {
             RGBColor[
             0.7644845206573334, 0.8159403849258432, 0.9771603305712452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 188}], {
             RGBColor[
             0.9037808592695934, 0.9238578418996366, 0.9029608698119762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 172}], {
             RGBColor[
             0.571265360628449, 0.6589662521410282, 0.9612084233939764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 173}], {
             RGBColor[
             0.6870485529364408, 0.7469717389931378, 0.7978945808168556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 184}], {
             RGBColor[
             0.6869249901236796, 0.7467074506307583, 0.7844455311890821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 198}], {
             RGBColor[
             0.686550490465839, 0.7473797813544725, 0.8507803734018176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 200}], {
             RGBColor[
             0.6691221655528767, 0.7412122368663363, 0.9678129947852077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 190}], {
             RGBColor[
             0.6140661607077884, 0.6913794971411642, 0.9659904876692461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 195}], {
             RGBColor[
             0.8918054312244704, 0.7716630213058975, 0.6129713818832161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 197}], {
             RGBColor[
             0.9240963396683254, 0.9416065054497227, 0.9681154588947102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 173}], {
             RGBColor[
             0.7731516309300424, 0.8188776995912503, 0.804119329048414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 178}], {
             RGBColor[
             0.7717723186439993, 0.8189213225068128, 0.8716097116766511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 183}], {
             RGBColor[
             0.644983350781346, 0.7211968879878285, 0.9661987418147995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 196}], {
             RGBColor[
             0.7606697685028853, 0.8119069579495715, 0.9470929837912401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 173}], {
             RGBColor[
             0.8787870729813354, 0.9027891845691792, 0.8136989116378877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 198}], {
             RGBColor[
             0.8782890105107336, 0.9031972269305139, 0.8665847042228496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 188}], {
             RGBColor[
             0.9683918160229089, 0.975062862268391, 0.898783960587703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 176}], {
             RGBColor[
             0.8484909683199666, 0.8822008975351912, 0.9700361890990348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 187}], {
             RGBColor[
             0.7376610956277565, 0.794985721427157, 0.9744868222434555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 199}], {
             RGBColor[
             0.8672126781836482, 0.895172445568776, 0.8939629649859404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 187}], {
             RGBColor[
             0.8418841247613708, 0.8770395811333451, 0.9693776806775773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 199}], {
             RGBColor[
             0.9714357073172626, 0.9772263052749642, 0.8888538234200621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 179}], {
             RGBColor[
             0.9250506479448275, 0.940361403453793, 0.8858557309517241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 183}], {
             RGBColor[
             0.865022672854588, 0.8931574827334294, 0.8799548644553896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 183}], {
             RGBColor[
             0.7982616800821742, 0.8426369689348088, 0.9804447610898726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 185}], {
             RGBColor[
             0.5795324585927684, 0.6616525693284936, 0.9633928529247522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 194}], {
             RGBColor[
             0.7952445629849649, 0.8402799741275297, 0.980144043054185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 185}], {
             RGBColor[
             0.505848920894664, 0.6037808193127463, 0.9561309275661538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 188}], {
             RGBColor[
             0.8502189183884651, 0.8820148465974713, 0.8976223161097412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 192}], {
             RGBColor[
             0.6934025838888224, 0.7604106356795539, 0.9700755474126261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 191}], {
             RGBColor[
             0.7588443162619276, 0.810795323760083, 0.9568825776896492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 192}], {
             RGBColor[
             0.7070581464966872, 0.7710784649749376, 0.97143660627489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 193}], {
             RGBColor[
             0.9159080316357242, 0.9348618124211104, 0.959860903322767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 199}], {
             RGBColor[
             0.9808131467020035, 0.9842199842139563, 0.8729802645695921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 199}], {
             RGBColor[
             0.8606058346250525, 0.8900111291669301, 0.893304456564483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 192}], {
             RGBColor[
             0.5094659974009256, 0.6091388842832945, 0.9557045503521263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 195}], {
             RGBColor[
             0.6207886773170935, 0.5518374109958923, 0.5900606769619806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 199}], {
             RGBColor[
             0.9252523021146649, 0.9408396815157033, 0.8996612380601426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 197}], {
             RGBColor[
             0.9308188562776305, 0.8020644193044507, 0.5921856481874447]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.04749427504982855], {
             RGBColor[
             0.9833687766578249, 0.9871170413793103, 0.913036502387268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.04749427504982855], {
             RGBColor[
             0.9873488150233287, 0.989036424138592, 0.8593264054880435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.04749427504982855], {
             RGBColor[
             0.8895835201886236, 0.9147937681697612, 0.9893304643678161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.04749427504982855], {
             RGBColor[
             0.87658797198939, 0.9044314707904509, 0.9880909373793103]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.04749427504982855], {
             RGBColor[
             0.8415079108090187, 0.8764595822281167, 0.9847449698275862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.04749427504982855], {
             RGBColor[
             0.9426706726790451, 0.9567644620689656, 0.9819277766578248]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.04749427504982855], {
             RGBColor[
             0.8264789134770646, 0.8644758677068815, 0.9833114906455201]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.04749427504982855], {
             RGBColor[
             0.7382337049919346, 0.7954330482144452, 0.9745438945935381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.04749427504982855], {
             RGBColor[
             0.9951027065208146, 0.9922428575387247, 0.7308243569467522]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.04749427504982855], {
             RGBColor[
             0.8644774917771884, 0.8947749025994696, 0.9869358289655172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.04749427504982855], {
             RGBColor[
             0.7022438219961856, 0.7673174780849245, 0.9709567594011005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.04749427504982855], {
             RGBColor[
             0.8548209307671087, 0.8870750229703979, 0.9860147775558621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.04749427504982855], {
             RGBColor[
             0.9733207874257708, 0.9796232674621168, 0.9300451272218295]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.04749427504982855], {
             RGBColor[
             0.9103473986117895, 0.9313503212039286, 0.9913109416279507]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.04749427504982855], {
             RGBColor[
             0.7769682742852421, 0.8256927881400071, 0.9784045944655647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.04749427504982855], {
             RGBColor[
             0.7866468243261797, 0.8332537449916924, 0.9793692618824529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.04749427504982855], {
             RGBColor[
             0.9951807763747864, 0.9921004929009465, 0.7168354330752995]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.04749427504982855], {
             RGBColor[
             0.7305037075651623, 0.7893943154744942, 0.9737734406909705]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.04749427504982855], {
             RGBColor[
             0.9529629401922547, 0.9644404183282759, 0.9645056524112465]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.04749427504982855], {
             RGBColor[
             0.9952208160661157, 0.9921861337520661, 0.7211935063801651]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.04749427504982855], {
             RGBColor[
             0.8714029573840255, 0.9002970808876055, 0.9875963860575335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.04749427504982855], {
             RGBColor[
             0.9725481996594878, 0.9790470727710193, 0.9313529167869853]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.04749427504982855], {
             RGBColor[
             0.9909563974459962, 0.9905282521810044, 0.7995394286204115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.04749427504982855], {
             RGBColor[
             0.7599410883661794, 0.8123910210886293, 0.9767074837012517]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.04749427504982855], {
             RGBColor[
             0.6672117627785659, 0.7399501671706087, 0.9674650911314946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.04749427504982855], {
             RGBColor[
             0.9048033582161279, 0.9269296538813956, 0.9907821461057893]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.04749427504982855], {
             RGBColor[
             0.3483458021675309, 0.4761413582935865, 0.9434172643773849]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.04749427504982855], {
             RGBColor[
             0.9912802006623452, 0.9906621531323277, 0.7941731713496459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.04749427504982855], {
             RGBColor[
             0.5308452841854353, 0.630003141866088, 0.9562092318028769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.04749427504982855], {
             RGBColor[
             0.9559921811147594, 0.9666996212483531, 0.9593779376820131]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.04749427504982855], {
             RGBColor[
             0.9319624934371338, 0.9485856110915393, 0.993372608668415]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.04749427504982855], {
             RGBColor[
             0.9669091375350244, 0.9748414694717112, 0.9408983780607506]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.04749427504982855], {
             RGBColor[
             0.8342378170360535, 0.8706626067949927, 0.9840515417934315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.04749427504982855], {
             RGBColor[
             0.9376053141008486, 0.95298672593511, 0.9905021074736094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.04749427504982855], {
             RGBColor[
             0.8440447074850106, 0.8784823550380413, 0.9849869317591674]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.04749427504982855], {
             RGBColor[
             0.6071931445046707, 0.6919857743051551, 0.9622196150386345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.04749427504982855], {
             RGBColor[
             0.9946008870026525, 0.9908601681697613, 0.6537180535809014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.04749427504982855], {
             RGBColor[
             0.9938052944297082, 0.9917063442970823, 0.7523258328912467]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.04749427504982855], {
             RGBColor[
             0.2735192527851458, 0.4048164551724137, 0.9388878888594164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.04749427504982855], {
             RGBColor[
             0.990863649867374, 0.99048989867374, 0.8010764960212198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.04749427504982855], {
             RGBColor[
             0.7008128934128254, 0.7661996258001433, 0.970814137812699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.04749427504982855], {
             RGBColor[
             0.4334255564553674, 0.5498331652249229, 0.9488384710875332]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.04749427504982855], {
             RGBColor[
             0.8870188965517243, 0.9127488068965519, 0.9890858482758621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.04749427504982855], {
             RGBColor[
             0.36532294345529076`, 0.49084610478111224`, 0.9444990328079444]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.04749427504982855], {
             RGBColor[
             0.9560308461538461, 0.8633438610079573, 0.28368856949602095`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.04749427504982855], {
             RGBColor[
             0.9810940140624158, 0.9854205271602362, 0.9168870821081916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.04749427504982855], {
             RGBColor[
             0.6688378461538461, 0.741220475862069, 0.9676271639257294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.04749427504982855], {
             RGBColor[
             0.873983693882626, 0.9023548901193634, 0.9878425390086207]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.04749427504982855], {
             RGBColor[
             0.9281335396165914, 0.9455325072492214, 0.9930073996348643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.04749427504982855], {
             RGBColor[
             0.991866530103167, 0.9909046154240869, 0.784456175143275]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.04749427504982855], {
             RGBColor[
             0.9585066923076924, 0.8716954714412026, 0.29330676427939895`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.04749427504982855], {
             RGBColor[
             0.9669477489138358, 0.9748702657748085, 0.9408330190678834]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.04749427504982855], {
             RGBColor[
             0.531484257769864, 0.630521889407359, 0.9562595341440805]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.04749427504982855], {
             RGBColor[
             0.9782750822281167, 0.9833181724137932, 0.9216587984084881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.04749427504982855], {
             RGBColor[
             0.9708975904138951, 0.9134928802746547, 0.34144306359723103`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.04749427504982855], {
             RGBColor[
             0.8496892345986683, 0.8829831477418651, 0.985525311794197]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.04749427504982855], {
             RGBColor[
             0.9407938921747413, 0.9553647622418018, 0.9851046765088607]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.04749427504982855], {
             RGBColor[
             0.9412249009368319, 0.9556862078708569, 0.9843750910997302]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.04749427504982855], {
             RGBColor[
             0.7028993846153848, 0.7678296085855033, 0.9710220997564012]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.04749427504982855], {
             RGBColor[
             0.869782881095518, 0.899005276030949, 0.9874418617348765]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.04749427504982855], {
             RGBColor[
             0.8650159139233179, 0.8952042258037134, 0.9869871841504702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.04749427504982855], {
             RGBColor[
             0.4126491566574968, 0.5318376919722243, 0.9475146172642618]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.04749427504982855], {
             RGBColor[
             0.5517329965707574, 0.6469607277612119, 0.957853589036061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.04749427504982855], {
             RGBColor[
             0.9519754442532538, 0.9637039454738452, 0.9661772254557855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.04749427504982855], {
             RGBColor[
             0.7047643588778865, 0.769286540653699, 0.9712079829617121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.04749427504982855], {
             RGBColor[
             0.49933362004883824`, 0.6044205533357065, 0.9537285181710148]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.04749427504982855], {
             RGBColor[
             0.42413721584068476`, 0.5417880714300582, 0.9482466262369227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.04749427504982855], {
             RGBColor[
             0.6353348983342173, 0.7148325178355436, 0.9644350369867374]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.04749427504982855], {
             RGBColor[
             0.9377901342932929, 0.9531245645320198, 0.9901892550966274]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.04749427504982855], {
             RGBColor[
             0.993182525321363, 0.9878264359518466, 0.49933813768618673`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.04749427504982855], {
             RGBColor[
             0.4531843256492155, 0.5669472179960187, 0.9500974823885716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.04749427504982855], {
             RGBColor[
             0.8078819656706931, 0.8498427988030779, 0.9814857823179955]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.04749427504982855], {
             RGBColor[
             0.5297262603289568, 0.6290946678879483, 0.9561211381457754]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.04749427504982855], {
             RGBColor[
             0.4396661082228116, 0.5552384175066312, 0.9492361135278514]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.04749427504982855], {
             RGBColor[
             0.37952684058355435`, 0.5031488065649867, 0.9454040925729443]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.04749427504982855], {
             RGBColor[
             0.9407938921747413, 0.9553647622418018, 0.9851046765088607]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.04749427504982855], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.04749427504982855], {
             RGBColor[
             0.6427779845621506, 0.7208623139243527, 0.9650297604655218]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.04749427504982855], {
             RGBColor[
             0.44728383336358213`, 0.5618365081455684, 0.9497215082377315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.04749427504982855], {
             RGBColor[
             0.9932668004368856, 0.9914836631923857, 0.7612500719300982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.04749427504982855], {
             RGBColor[
             0.8682343925729443, 0.8977705533156499, 0.9872941655172414]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.04749427504982855], {
             RGBColor[
             0.991139321089019, 0.9906038958083175, 0.7965079104643091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.04749427504982855], {
             RGBColor[
             0.9594095473032714, 0.969248287356322, 0.9535932281167108]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.04749427504982855], {
             RGBColor[
             0.7339954212657152, 0.7921220687553733, 0.9741214620807218]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.04749427504982855], {
             RGBColor[
             0.7893724615384614, 0.8353830334975368, 0.9796409279272451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.04749427504982855], {
             RGBColor[
             0.7775592136752141, 0.8261544344827589, 0.9784634937813145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.04749427504982855], {
             RGBColor[
             0.9640744795755968, 0.9727273862068966, 0.9456967145888594]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.04749427504982855], {
             RGBColor[
             0.49933362004883824`, 0.6044205533357065, 0.9537285181710148]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.04749427504982855], {
             RGBColor[
             0.8638835699602122, 0.8943013254641909, 0.9868791801724138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.04749427504982855], {
             RGBColor[
             0.9669477489138356, 0.9748702657748084, 0.9408330190678837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.04749427504982855], {
             RGBColor[
             0.5871008615384617, 0.675673953846154, 0.9606378769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.04749427504982855], {
             RGBColor[
             0.9721334028200475, 0.9787377179673321, 0.9320550596398157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.04749427504982855], {
             RGBColor[
             0.7381268526656684, 0.7953495743650583, 0.9745332445522477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.04749427504982855], {
             RGBColor[
             0.9878809144810958, 0.9892564609387111, 0.8505081404435878]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.04749427504982855], {
             RGBColor[
             0.6560411519389703, 0.7312236010829297, 0.9663517090382971]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.04749427504982855], {
             RGBColor[
             0.5377058080613419, 0.6355728242116275, 0.9567493173733153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.04749427504982855], {
             RGBColor[
             0.9350010000000001, 0.7800076551724141, 0.26655848275862076`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.04749427504982855], {
             RGBColor[
             0.9188713717858497, 0.9381471060358362, 0.9921239657987333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.04749427504982855], {
             RGBColor[
             0.7022438219961856, 0.7673174780849245, 0.9709567594011005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.04749427504982855], {
             RGBColor[
             0.9931565355004152, 0.9914380658074756, 0.7630774472839221]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.04749427504982855], {
             RGBColor[
             0.92945409316357, 0.946585480802111, 0.9931333552110472]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.04749427504982855], {
             RGBColor[
             0.9926285889005331, 0.9866416219592545, 0.439045576778166]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.04749427504982855], {
             RGBColor[
             0.7893724615384614, 0.8353830334975368, 0.9796409279272451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.04749427504982855], {
             RGBColor[
             0.4092254772300103, 0.5288722729312669, 0.9472964634385832]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.04749427504982855], {
             RGBColor[
             0.9949340599644869, 0.9915727914461714, 0.6899818743713968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.04749427504982855], {
             RGBColor[
             0.7022191288663729, 0.7672981876242401, 0.9709542982206911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.04749427504982855], {
             RGBColor[
             0.6298471935490715, 0.7103773518726789, 0.9640030247639256]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.04749427504982855], {
             RGBColor[
             0.502826465980744, 0.6072562030141437, 0.9540034877974907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.04749427504982855], {
             RGBColor[
             0.509394104326923, 0.6125881076923076, 0.9545205163461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.04749427504982855], {
             RGBColor[
             0.9940546535521027, 0.9918094607024295, 0.7481933069124482]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.04749427504982855], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.04749427504982855], {
             RGBColor[
             0.6858460587529017, 0.7545074208116547, 0.9693223836068198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.04749427504982855], {
             RGBColor[
             0.9749039826419097, 0.980804011862069, 0.9273651906843502]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.04749427504982855], {
             RGBColor[
             0.3696817714718778, 0.4946215025280138, 0.944776773474801]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.04749427504982855], {
             RGBColor[
             0.5774642095179836, 0.6678504856097036, 0.9598792443758054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.04749427504982855], {
             RGBColor[
             0.7787109230769234, 0.8270541586206898, 0.9785782854111406]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.04749427504982855], {
             RGBColor[
             0.9495706482068024, 0.9619104525198939, 0.9702479178911682]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.04749427504982855], {
             RGBColor[
             0.990863649867374, 0.99048989867374, 0.8010764960212198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.04749427504982855], {
             RGBColor[
             0.7883989443688466, 0.8346225144856292, 0.9795438968338132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.04749427504982855], {
             RGBColor[
             0.721151645698031, 0.7820884136655887, 0.9728413145640419]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.04749427504982855], {
             RGBColor[
             0.9591585210139218, 0.9690610723607428, 0.9540181501464379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.04749427504982855], {
             RGBColor[
             0.6758825880014396, 0.7467238817354301, 0.968329317956242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.04749427504982855], {
             RGBColor[
             0.9487686995862068, 0.9613123605517241, 0.971605407724138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.04749427504982855], {
             RGBColor[
             0.594466793529735, 0.6816539492681243, 0.9612177500717278]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.04749427504982855], {
             RGBColor[
             0.42413721584068476`, 0.5417880714300582, 0.9482466262369227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.04749427504982855], {
             RGBColor[
             0.9920861251073014, 0.9909954236016307, 0.7808169176311144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.04749427504982855], {
             RGBColor[
             0.8135763076923077, 0.8542912620689656, 0.9820533411140584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.04749427504982855], {
             RGBColor[
             0.6344330521128132, 0.7141003584452985, 0.9643640403486169]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.04749427504982855], {
             RGBColor[
             0.5421059788938333, 0.639145081118881, 0.9570957149396058]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.04749427504982855], {
             RGBColor[
             0.9911915881130501, 0.9906255095659556, 0.7956417106133933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.04749427504982855], {
             RGBColor[
             0.9445640863660477, 0.9581765668965517, 0.9787227211671088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.04749427504982855], {
             RGBColor[
             0.41507303868790285`, 0.5339371367591088, 0.9476690648838846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.04749427504982855], {
             RGBColor[
             0.2936052034578279, 0.4259280628522304, 0.9400317540357245]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.04749427504982855], {
             RGBColor[
             0.7617698588984981, 0.8138196705276475, 0.9768897584570809]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.04749427504982855], {
             RGBColor[
             0.9479195172842994, 0.96067904178137, 0.9730428518590518]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.04749427504982855], {
             RGBColor[
             0.9900224853892189, 0.990142055545082, 0.8150167682881381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.04749427504982855], {
             RGBColor[
             0.9855777449666363, 0.9883040411557253, 0.88867761970982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.04749427504982855], {
             RGBColor[
             0.9938545589733793, 0.9892638479804845, 0.5724848533972092]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.04749427504982855], {
             RGBColor[
             0.9188713717858497, 0.9381471060358362, 0.9921239657987333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.04749427504982855], {
             RGBColor[
             0.8400251199949815, 0.875277245082288, 0.9846035399160403]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.04749427504982855], {
             RGBColor[
             0.7577916923076925, 0.8107118965517243, 0.97649325198939]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.04749427504982855], {
             RGBColor[
             0.47874177850917554`, 0.5877031687219184, 0.9521074529746116]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.04749427504982855], {
             RGBColor[
             0.6298341130178856, 0.710366732508191, 0.9640019950165951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.04749427504982855], {
             RGBColor[
             0.9630321815384614, 0.886961009251989, 0.31088743537400476`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.04749427504982855], {
             RGBColor[
             0.8781791299734747, 0.9057002169761272, 0.9882427034482758]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.04749427504982855], {
             RGBColor[
             0.3696817714718778, 0.4946215025280138, 0.944776773474801]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.04749427504982855], {
             RGBColor[
             0.9612962106956324, 0.970655357825217, 0.9503995991140641]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.04749427504982855], {
             RGBColor[
             0.9375103606074827, 0.9529159097752298, 0.9906628389700405]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.04749427504982855], {
             RGBColor[
             0.5297262603289568, 0.6290946678879483, 0.9561211381457754]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.04749427504982855], {
             RGBColor[
             0.8654173934888757, 0.8955243547114167, 0.9870254776298382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.04749427504982855], {
             RGBColor[
             0.8036180830628661, 0.8465118213031353, 0.9810607983478957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.04749427504982855], {
             RGBColor[
             0.9948191739316958, 0.9921256095266688, 0.7355232257072689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.04749427504982855], {
             RGBColor[
             0.6895358967192444, 0.7573899502747687, 0.9696901521718085]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.04749427504982855], {
             RGBColor[
             0.9918116407172414, 0.9908819172524138, 0.7853658343172413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.04749427504982855], {
             RGBColor[
             0.692686613027929, 0.759851313801444, 0.9700041861283403]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.04749427504982855], {
             RGBColor[
             0.45857303893899204`, 0.5713292773474801, 0.9505196959151194]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.04749427504982855], {
             RGBColor[
             0.8644774917771884, 0.8947749025994696, 0.9869358289655172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.04749427504982855], {
             RGBColor[
             0.867820521218582, 0.8974405435319199, 0.9872546900979949]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.04749427504982855], {
             RGBColor[
             0.8451549474531654, 0.8793676302519869, 0.985092827438453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.04749427504982855], {
             RGBColor[
             0.36186589626992516`, 0.4878517842653923, 0.9442787528182397]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.04749427504982855], {
             RGBColor[
             0.8798228882214962, 0.9070109051844706, 0.9883994865773724]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.04749427504982855], {
             RGBColor[
             0.8522077496547341, 0.884991343284302, 0.9857655300085495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.04749427504982855], {
             RGBColor[
             0.8756027454386424, 0.9036458778821471, 0.987996965591378]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.04749427504982855], {
             RGBColor[
             0.5281207842955995, 0.6277912701181979, 0.9559947491913771]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.04749427504982855], {
             RGBColor[
             0.7827186407972954, 0.8301850181636272, 0.9789777372592559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.04749427504982855], {
             RGBColor[
             0.9938052944297082, 0.9917063442970823, 0.7523258328912467]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.04749427504982855], {
             RGBColor[
             0.8180464615384617, 0.8577833802280086, 0.9824988842734802]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.04749427504982855], {
             RGBColor[
             0.37952684058355435`, 0.5031488065649867, 0.9454040925729443]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.04749427504982855], {
             RGBColor[
             0.6273217513295485, 0.7083270841089948, 0.9638042127014051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.04749427504982855], {
             RGBColor[
             0.8850829146151653, 0.9112051074511694, 0.9889011925904816]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.04749427504982855], {
             RGBColor[
             0.5517329965707574, 0.6469607277612119, 0.957853589036061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.04749427504982855], {
             RGBColor[
             0.7630038806733436, 0.8147836977170696, 0.9770127542150084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.04749427504982855], {
             RGBColor[
             0.9945702652893273, 0.9907946714212889, 0.650385069060767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.04749427504982855], {
             RGBColor[
             0.9472683750450928, 0.9601934209655173, 0.9741450658249337]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.04749427504982855], {
             RGBColor[
             0.7442679391863524, 0.8001470378290029, 0.975145330664913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.04749427504982855], {
             RGBColor[
             0.9527139974535809, 0.9642547572413793, 0.9649270475331565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.04749427504982855], {
             RGBColor[
             0.6218592085206146, 0.703892345771953, 0.9633741813215323]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.04749427504982855], {
             RGBColor[
             0.9918116407172414, 0.9908819172524138, 0.7853658343172413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.04749427504982855], {
             RGBColor[
             0.8582896551724137, 0.8898408896551724, 0.9863456275862069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.04749427504982855], {
             RGBColor[
             0.9946346936164024, 0.9920493221753671, 0.7385805419514324]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.04749427504982855], {
             RGBColor[
             0.7109225797762051, 0.7740973896236778, 0.9718217768690102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.04749427504982855], {
             RGBColor[
             0.5592968915934694, 0.6531014384902372, 0.9584490465597093]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.04749427504982855], {
             RGBColor[
             0.7382337049919346, 0.7954330482144452, 0.9745438945935381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.04749427504982855], {
             RGBColor[
             0.9943231396638049, 0.9902660946965298, 0.6234869698052199]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.04749427504982855], {
             RGBColor[
             0.30077526201312305`, 0.4334642490018149, 0.9404400782632976]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.04749427504982855], {
             RGBColor[
             0.9714688762230628, 0.9782421151193634, 0.9331799298322163]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.04749427504982855], {
             RGBColor[
             0.7310542520691606, 0.789824405025311, 0.9738283138219981]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.04749427504982855], {
             RGBColor[
             0.9895152570007251, 0.9899323035712647, 0.8234228553504723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.04749427504982855], {
             RGBColor[
             0.83939361927921, 0.8747737035531621, 0.9845433068140227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.04749427504982855], {
             RGBColor[
             0.3430494068004115, 0.47155388683115906`, 0.9430797827480106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.04749427504982855], {
             RGBColor[
             0.9583917409303859, 0.9684892090299289, 0.9553161088195892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.04749427504982855], {
             RGBColor[
             0.6758825880014396, 0.7467238817354301, 0.968329317956242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.04749427504982855], {
             RGBColor[
             0.8603471870483856, 0.8914815097228574, 0.9865418768133175]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.04749427504982855], {
             RGBColor[
             0.7321994707975161, 0.790719058599887, 0.9739424585221631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.04749427504982855], {
             RGBColor[
             0.8985279478337755, 0.6321209351606255, 0.23704157117595062`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.04749427504982855], {
             RGBColor[
             0.9696065404350132, 0.976853188137931, 0.9363323785464192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.04749427504982855], {
             RGBColor[
             0.9631097647214855, 0.9720079034482759, 0.9473297251989388]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.04749427504982855], {
             RGBColor[
             0.9935741403481236, 0.9916107561439581, 0.7561566542306909]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.04749427504982855], {
             RGBColor[
             0.9901574171809442, 0.9901978533085491, 0.8127805993069678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.04749427504982855], {
             RGBColor[
             0.7109225797762051, 0.7740973896236778, 0.9718217768690102]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
          103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
          129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 
          142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 
          155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 
          168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 
          181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 
          194, 195, 196, 197, 198, 199, 200}, {Null, CompressedData["
1:eJwVxfk/GgwDAPA5ylXk6qBcTS9j5XjImZDN1UpNhz0LEUrEK0VRaK6QloU8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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[31, 80] -> 
             RGBColor[
              0.7352027165067365, 0.7929678458962808, 0.9744115778147804], 
             UndirectedEdge[36, 132] -> 
             RGBColor[
              0.24999710016017773`, 0.3800931813729572, 0.937548337065331], 
             UndirectedEdge[16, 101] -> 
             RGBColor[
              0.28740281094428266`, 0.4180946549568002, 0.9397266599229551], 
             UndirectedEdge[86, 108] -> 
             RGBColor[
              0.5865960904370586, 0.6714707671165345, 0.9625129589589009], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.3936636675304358, 0.5153934155287933, 0.9463048786852943], 
             UndirectedEdge[29, 136] -> 
             RGBColor[
              0.950824845750427, 0.8323116913697606, 0.49992668872926316`], 
             UndirectedEdge[55, 157] -> 
             RGBColor[
              0.4550334300726567, 0.5657150158349769, 0.9509982940305055], 
             UndirectedEdge[7, 188] -> 
             RGBColor[
              0.5075570604878807, 0.6079623494198335, 0.955381071984007], 
             UndirectedEdge[19, 141] -> 
             RGBColor[
              0.31187008513103276`, 0.44044798095241544`, 0.9412431829967022],
              UndirectedEdge[62, 185] -> 
             RGBColor[
              0.5629039980331934, 0.6514450489037454, 0.9607937355315148], 
             UndirectedEdge[79, 144] -> 
             RGBColor[
              0.5302420239491671, 0.38356267740113825`, 0.5683400240537216], 
             UndirectedEdge[47, 54] -> 
             RGBColor[
              0.3621640961349061, 0.48478721437619465`, 0.9444194198717641], 
             UndirectedEdge[32, 101] -> 
             RGBColor[
              0.2434980017964442, 0.3732622169260371, 0.9371782230280707], 
             UndirectedEdge[104, 163] -> 
             RGBColor[
              0.22597848605701326`, 0.35484809508244053`, 0.9361805125245111],
              UndirectedEdge[119, 125] -> 
             RGBColor[
              0.3719190998621983, 0.4815306199533135, 0.9461956553093709], 
             UndirectedEdge[9, 140] -> 
             RGBColor[
              0.2830352445403058, 0.4148183658558119, 0.9394298105122245], 
             UndirectedEdge[3, 63] -> 
             RGBColor[
              0.30825791983475437`, 0.437251051830131, 0.9410155180983026], 
             UndirectedEdge[50, 104] -> 
             RGBColor[
              0.2305835536607953, 0.3596883131121654, 0.9364427643119595], 
             UndirectedEdge[47, 61] -> 
             RGBColor[
              0.36265936899724993`, 0.48530777755663124`, 0.944447624928584], 
             UndirectedEdge[149, 195] -> 
             RGBColor[
              0.2062475040297809, 0.3341095819553035, 0.9350568622874322], 
             UndirectedEdge[99, 178] -> 
             RGBColor[
              0.7532636952500258, 0.8067917718917483, 0.970579392980242], 
             UndirectedEdge[160, 174] -> 
             RGBColor[
              0.37406119352792633`, 0.4984147377968103, 0.9450558263756417], 
             UndirectedEdge[6, 124] -> 
             RGBColor[
              0.3155531459350417, 0.4461023057398271, 0.9413876363800726], 
             UndirectedEdge[24, 197] -> 
             RGBColor[
              0.5339219982745609, 0.6098281505161249, 0.9613839453194717], 
             UndirectedEdge[80, 120] -> 
             RGBColor[
              0.7883329572883422, 0.7840663517109472, 0.6248876395864237], 
             UndirectedEdge[83, 187] -> 
             RGBColor[
              0.26933773838678554`, 0.40042141841641143`, 0.938649757800426], 
             UndirectedEdge[47, 167] -> 
             RGBColor[
              0.6833987505402253, 0.7503936163476059, 0.9708862787627], 
             UndirectedEdge[132, 150] -> 
             RGBColor[
              0.2675705658104447, 0.39856400799346436`, 0.938549119936501], 
             UndirectedEdge[17, 189] -> 
             RGBColor[
              0.23511483918268133`, 0.3644509814957634, 0.9367008143189947], 
             UndirectedEdge[69, 180] -> 
             RGBColor[
              0.5628268850068445, 0.6533109098577117, 0.9599708318719281], 
             UndirectedEdge[43, 95] -> 
             RGBColor[
              0.9174955939353169, 0.6847516692782425, 0.2880009042450533], 
             UndirectedEdge[82, 86] -> 
             RGBColor[
              0.3552790109161934, 0.48214655523847394`, 0.943859042308054], 
             UndirectedEdge[7, 61] -> 
             RGBColor[
              0.3121285679978709, 0.4415405374828739, 0.9412278469715365], 
             UndirectedEdge[30, 65] -> 
             RGBColor[
              0.9079204151899432, 0.9294151105020584, 0.9910794537825813], 
             UndirectedEdge[62, 174] -> 
             RGBColor[
              0.36882264112374896`, 0.4938773670016114, 0.9447220304487174], 
             UndirectedEdge[18, 47] -> 
             RGBColor[
              0.38494609227374893`, 0.5078426899995235, 0.9457494024985874], 
             UndirectedEdge[56, 149] -> 
             RGBColor[
              0.2062475040297809, 0.3341095819553035, 0.9350568622874322], 
             UndirectedEdge[82, 163] -> 
             RGBColor[
              0.2758102937038249, 0.40631356017084397`, 0.9390517136501494], 
             UndirectedEdge[10, 48] -> 
             RGBColor[
              0.30320935155036544`, 0.43524999752426985`, 0.940606985973867], 
             UndirectedEdge[58, 92] -> 
             RGBColor[
              0.24643437763355744`, 0.3763485341078243, 0.9373454452880156], 
             UndirectedEdge[70, 72] -> 
             RGBColor[
              0.23177582019152226`, 0.36094146083002354`, 0.936510662127084], 
             UndirectedEdge[35, 181] -> 
             RGBColor[
              0.9113516048559902, 0.930874079920538, 0.9469017763992353], 
             UndirectedEdge[126, 174] -> 
             RGBColor[
              0.3443177986809051, 0.472511876251829, 0.9431657526324266], 
             UndirectedEdge[108, 154] -> 
             RGBColor[
              0.8838800631396134, 0.9088604535486795, 0.9258833443185683], 
             UndirectedEdge[63, 77] -> 
             RGBColor[
              0.3266232709961202, 0.4565542003312445, 0.9420613976778401], 
             UndirectedEdge[32, 100] -> 
             RGBColor[
              0.22448297168171977`, 0.35327621465291903`, 0.9360953451932534],
              UndirectedEdge[19, 50] -> 
             RGBColor[
              0.2533169376668154, 0.3835825410822887, 0.9377373969000744], 
             UndirectedEdge[80, 81] -> 
             RGBColor[
              0.5981154418108365, 0.6846160863124545, 0.9615049850298553], 
             UndirectedEdge[34, 163] -> 
             RGBColor[
              0.24238504014097356`, 0.3720924236602928, 0.9371148415082708], 
             UndirectedEdge[146, 194] -> 
             RGBColor[
              0.5723118578420975, 0.6584672801449877, 0.9618699351638069], 
             UndirectedEdge[13, 83] -> 
             RGBColor[
              0.316923827731624, 0.4440344737616491, 0.9415941582521057], 
             UndirectedEdge[30, 41] -> 
             RGBColor[
              0.7217306402299773, 0.781717727178925, 0.9737111260908631], 
             UndirectedEdge[35, 111] -> 
             RGBColor[
              0.6494345587146366, 0.7234252020636741, 0.9675585260086426], 
             UndirectedEdge[29, 144] -> 
             RGBColor[
              0.9250794571034022, 0.713525377567732, 0.47838407771344216`], 
             UndirectedEdge[6, 12] -> 
             RGBColor[
              0.4620072235822212, 0.5710418605945535, 0.9516398014511775], 
             UndirectedEdge[67, 143] -> 
             RGBColor[
              0.8195020684542436, 0.15090702076601228`, 0.16630850881720677`],
              UndirectedEdge[135, 163] -> 
             RGBColor[
              0.2331505740140204, 0.36238641426189583`, 0.9365889523235094], 
             UndirectedEdge[50, 60] -> 
             RGBColor[
              0.24809478057534154`, 0.3780937228752663, 0.9374400027792041], 
             UndirectedEdge[25, 143] -> 
             RGBColor[
              0.8998599727872215, 0.550715470129439, 0.2700821840156026], 
             UndirectedEdge[12, 13] -> 
             RGBColor[
              0.4809809724952037, 0.58747596825463, 0.9528487919540853], 
             UndirectedEdge[89, 144] -> 
             RGBColor[
              0.8552540643843429, 0.4257125281092684, 0.20054466049597394`], 
             UndirectedEdge[22, 24] -> 
             RGBColor[
              0.511674430314928, 0.3239227222549723, 0.5618363636950766], 
             UndirectedEdge[107, 156] -> 
             RGBColor[
              0.7940373920785235, 0.8398425244747729, 0.979889552465069], 
             UndirectedEdge[23, 154] -> 
             RGBColor[
              0.9900533443030074, 0.9886857899175692, 0.707722631591383], 
             UndirectedEdge[101, 135] -> 
             RGBColor[
              0.2425616632808307, 0.3722780657788366, 0.9371248999347952], 
             UndirectedEdge[7, 42] -> 
             RGBColor[
              0.4359507962934013, 0.5501706892115099, 0.9495104580293312], 
             UndirectedEdge[122, 192] -> 
             RGBColor[
              0.9051286638748339, 0.560715561019076, 0.3184883695099363], 
             UndirectedEdge[129, 133] -> 
             RGBColor[
              0.9068437673391607, 0.5799440210010265, 0.2933645016769323], 
             UndirectedEdge[40, 80] -> 
             RGBColor[
              0.555739244439546, 0.6502131802605045, 0.9581689755436615], 
             UndirectedEdge[41, 172] -> 
             RGBColor[
              0.7718454040169196, 0.8174234076188627, 0.7717375932565325], 
             UndirectedEdge[94, 115] -> 
             RGBColor[
              0.34184068469654455`, 0.4665135495155001, 0.9431489820897013], 
             UndirectedEdge[87, 103] -> 
             RGBColor[
              0.9261326652649529, 0.7329765215094193, 0.5287146017248969], 
             UndirectedEdge[142, 160] -> 
             RGBColor[
              0.5038004126414563, 0.6056953348255233, 0.9547299040233275], 
             UndirectedEdge[21, 150] -> 
             RGBColor[
              0.29956418872733326`, 0.4315020124177601, 0.9403963488781741], 
             UndirectedEdge[29, 142] -> 
             RGBColor[
              0.8172660326623933, 0.855490432397475, 0.8599437218958297], 
             UndirectedEdge[67, 103] -> 
             RGBColor[
              0.8412482263097689, 0.30880018804606046`, 0.1867701602639753], 
             UndirectedEdge[50, 163] -> 
             RGBColor[
              0.23762722721084206`, 0.36709166060796167`, 0.9368438911004533],
              UndirectedEdge[21, 46] -> 
             RGBColor[
              0.4569720284859443, 0.5663064733841641, 0.9514223432183879], 
             UndirectedEdge[43, 129] -> 
             RGBColor[
              0.922812533415494, 0.7026869546216379, 0.30865621010577077`], 
             UndirectedEdge[11, 112] -> 
             RGBColor[
              0.2736557868068433, 0.4049599610859747, 0.9388956642699682], 
             UndirectedEdge[119, 195] -> 
             RGBColor[
              0.37190268566599016`, 0.4815133675923786, 0.9461947205451795], 
             UndirectedEdge[99, 109] -> 
             RGBColor[
              0.45081925257627997`, 0.561890841684138, 0.9507778651594582], 
             UndirectedEdge[45, 120] -> 
             RGBColor[
              0.9205644172331103, 0.7168104234407002, 0.25588752113131463`], 
             UndirectedEdge[29, 153] -> 
             RGBColor[
              0.7898065464682866, 0.8331975844693433, 0.8577820105552174], 
             UndirectedEdge[27, 125] -> 
             RGBColor[
              0.22785442897304503`, 0.35681983002884055`, 0.9362873446983702],
              UndirectedEdge[35, 157] -> 
             RGBColor[
              0.6980290555794366, 0.7628764037756551, 0.971384062809347], 
             UndirectedEdge[28, 112] -> 
             RGBColor[
              0.2981130439403854, 0.43066608901299275`, 0.9402884688824538], 
             UndirectedEdge[22, 89] -> 
             RGBColor[
              0.8492070454595947, 0.37923249083306454`, 0.194754028344504], 
             UndirectedEdge[96, 116] -> 
             RGBColor[
              0.3478897367236583, 0.4755106363355533, 0.9433968344585502], 
             UndirectedEdge[23, 143] -> 
             RGBColor[
              0.9071887956861127, 0.574773145865902, 0.35502905680889496`], 
             UndirectedEdge[6, 14] -> 
             RGBColor[
              0.37841229319367853`, 0.5021834416346569, 0.945333074598817], 
             UndirectedEdge[9, 112] -> 
             RGBColor[
              0.28100806217130603`, 0.41268766865520734`, 0.9393143654752576],
              UndirectedEdge[12, 25] -> 
             RGBColor[
              0.7814420691727634, 0.8068428114651084, 0.666502637240134], 
             UndirectedEdge[176, 199] -> 
             RGBColor[
              0.28324272218403285`, 0.4150364380142114, 0.9394416260570992], 
             UndirectedEdge[48, 112] -> 
             RGBColor[
              0.3092759955003079, 0.44162642496310195`, 0.9409524723720207], 
             UndirectedEdge[79, 149] -> 
             RGBColor[
              0.21876808015896437`, 0.34726950131745254`, 0.9357698905754568],
              UndirectedEdge[58, 155] -> 
             RGBColor[
              0.25688825427596124`, 0.3873362212730521, 0.9379407780976758], 
             UndirectedEdge[118, 138] -> 
             RGBColor[
              0.9130416014388392, 0.812801149295034, 0.6201343733156849], 
             UndirectedEdge[172, 173] -> 
             RGBColor[
              0.9945590642006376, 0.9907707134251852, 0.6491658996819889], 
             UndirectedEdge[53, 104] -> 
             RGBColor[
              0.21517354122831484`, 0.34349141299440844`, 0.9355651869010002],
              UndirectedEdge[179, 185] -> 
             RGBColor[
              0.7887535289716312, 0.8348995186722672, 0.9795792385132371], 
             UndirectedEdge[82, 176] -> 
             RGBColor[
              0.30639768237766407`, 0.4384628450195025, 0.9407936201851381], 
             UndirectedEdge[142, 181] -> 
             RGBColor[
              0.8126094756619291, 0.8535648264097266, 0.9371149221767408], 
             UndirectedEdge[54, 160] -> 
             RGBColor[
              0.3197591214680627, 0.448058156655773, 0.9417174123832397], 
             UndirectedEdge[121, 151] -> 
             RGBColor[
              0.4472759744708069, 0.5594034354051198, 0.9503913919352824], 
             UndirectedEdge[138, 144] -> 
             RGBColor[
              0.8846457857876004, 0.5636515837418983, 0.22521422842604885`], 
             UndirectedEdge[171, 196] -> 
             RGBColor[
              0.6848218020180831, 0.7518929600057571, 0.9706449762400708], 
             UndirectedEdge[120, 172] -> 
             RGBColor[
              0.9753727800277856, 0.9276792174007213, 0.4361680487899127], 
             UndirectedEdge[113, 159] -> 
             RGBColor[
              0.8614732788871635, 0.4076188795492328, 0.20391981602530412`], 
             UndirectedEdge[103, 108] -> 
             RGBColor[
              0.822761672378244, 0.6528409767770607, 0.5936514209828487], 
             UndirectedEdge[64, 176] -> 
             RGBColor[
              0.45839978276888355`, 0.5655229499724335, 0.9517490792275327], 
             UndirectedEdge[83, 101] -> 
             RGBColor[
              0.2538463417938609, 0.3841389783859738, 0.9377675456819266], 
             UndirectedEdge[15, 63] -> 
             RGBColor[
              0.33898161598962545`, 0.46803057088396705`, 0.9428205867145535],
              UndirectedEdge[55, 72] -> 
             RGBColor[
              0.3011292819316679, 0.4298018950317811, 0.9406079602011264], 
             UndirectedEdge[105, 142] -> 
             RGBColor[
              0.4920496854617956, 0.5955174455512221, 0.9539811580781995], 
             UndirectedEdge[96, 105] -> 
             RGBColor[
              0.32470350781154744`, 0.4554278902256328, 0.9419194284550477], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.3349775869314745, 0.46456248216214874`, 0.942565453523592], 
             UndirectedEdge[64, 108] -> 
             RGBColor[
              0.7019176077126746, 0.7667599945944428, 0.9711311636805353], 
             UndirectedEdge[56, 119] -> 
             RGBColor[
              0.37190268566599016`, 0.4815133675923786, 0.9461947205451795], 
             UndirectedEdge[68, 157] -> 
             RGBColor[
              0.7066548099945791, 0.7697543462064234, 0.9722067949657651], 
             UndirectedEdge[137, 161] -> 
             RGBColor[
              0.2794230248160247, 0.4110216938976339, 0.939224099942727], 
             UndirectedEdge[160, 188] -> 
             RGBColor[
              0.5156828868204164, 0.6150005317731692, 0.9558988424525301], 
             UndirectedEdge[127, 187] -> 
             RGBColor[
              0.3022073859943112, 0.43378220468743567`, 0.9405651083800737], 
             UndirectedEdge[41, 141] -> 
             RGBColor[
              0.4545263425380657, 0.5654922255819677, 0.9509061844081543], 
             UndirectedEdge[137, 175] -> 
             RGBColor[
              0.2852924893069724, 0.4161135758232565, 0.9395978023974743], 
             UndirectedEdge[1, 122] -> 
             RGBColor[
              0.9756254576616791, 0.9291724163168037, 0.38265572153063876`], 
             UndirectedEdge[60, 177] -> 
             RGBColor[
              0.273782020378095, 0.40509264057303096`, 0.9389028530851051], 
             UndirectedEdge[72, 75] -> 
             RGBColor[
              0.26701897159742227`, 0.39798424750248473`, 0.9385177074620799],
              UndirectedEdge[13, 69] -> 
             RGBColor[
              0.38979245396039097`, 0.512040364907272, 0.9460582083797908], 
             UndirectedEdge[48, 77] -> 
             RGBColor[
              0.30874838296909257`, 0.4410718707402281, 0.9409224256189008], 
             UndirectedEdge[22, 183] -> 
             RGBColor[
              0.8521661685690678, 0.3996097358148414, 0.1974949680494109], 
             UndirectedEdge[16, 86] -> 
             RGBColor[
              0.3574604388898408, 0.48403599850748935`, 0.9439980409695737], 
             UndirectedEdge[8, 62] -> 
             RGBColor[
              0.40221602470153694`, 0.5228010374564311, 0.9468498273216844], 
             UndirectedEdge[26, 51] -> 
             RGBColor[
              0.3392714220793772, 0.4658216765666159, 0.9429291222497664], 
             UndirectedEdge[117, 121] -> 
             RGBColor[
              0.6608369282647062, 0.733443073990961, 0.9678737418567172], 
             UndirectedEdge[89, 136] -> 
             RGBColor[
              0.8809994530313677, 0.5444988419112969, 0.222087271511795], 
             UndirectedEdge[81, 168] -> 
             RGBColor[
              0.7574630871375609, 0.8103278215593543, 0.974310777757218], 
             UndirectedEdge[172, 198] -> 
             RGBColor[
              0.8450687656775151, 0.8760452560467036, 0.7780654976273946], 
             UndirectedEdge[55, 68] -> 
             RGBColor[
              0.6040034340544339, 0.6836766872491769, 0.9648829517187356], 
             UndirectedEdge[156, 192] -> 
             RGBColor[
              0.869081373347711, 0.5369234121250193, 0.5782650463391841], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.3132800245584588, 0.44509451368492026`, 0.9412076055629822], 
             UndirectedEdge[25, 154] -> 
             RGBColor[
              0.9827245214041163, 0.9646281141811062, 0.6227757587980907], 
             UndirectedEdge[100, 135] -> 
             RGBColor[
              0.2235466331661063, 0.3522920635057185, 0.9360420220999779], 
             UndirectedEdge[37, 149] -> 
             RGBColor[
              0.21228087842813756`, 0.34045104098600754`, 0.9354004540338412],
              UndirectedEdge[125, 149] -> 
             RGBColor[
              0.206263918225989, 0.33412683431623835`, 0.9350577970516237], 
             UndirectedEdge[2, 184] -> 
             RGBColor[
              0.37412689727752746`, 0.49847164708234826`, 0.9450600129604667],
              UndirectedEdge[6, 16] -> 
             RGBColor[
              0.3315065479690632, 0.46155604267239897`, 0.9423442819902264], 
             UndirectedEdge[55, 111] -> 
             RGBColor[
              0.40643893320785657`, 0.5262638141229958, 0.9471727572298012], 
             UndirectedEdge[34, 50] -> 
             RGBColor[
              0.2469901077447556, 0.3769326416900177, 0.9373770932957193], 
             UndirectedEdge[56, 125] -> 
             RGBColor[
              0.17894341419620807`, 0.3054112523609348, 0.9335019347641915], 
             UndirectedEdge[98, 196] -> 
             RGBColor[
              0.7343309142909232, 0.7903956980318739, 0.9415812202273133], 
             UndirectedEdge[160, 167] -> 
             RGBColor[
              0.6409937758733817, 0.7136645586271843, 0.9681842712741754], 
             UndirectedEdge[22, 149] -> 
             RGBColor[
              0.5389949329250163, 0.35263830271808894`, 0.5633922259016595], 
             UndirectedEdge[147, 194] -> 
             RGBColor[
              0.41461252572283636`, 0.5327948903127648, 0.9478451176521548], 
             UndirectedEdge[83, 161] -> 
             RGBColor[
              0.28225365624559345`, 0.41399686700250915`, 0.9393853002150969],
              UndirectedEdge[34, 177] -> 
             RGBColor[
              0.27267734754750905`, 0.40393155938778236`, 0.9388399436016203],
              UndirectedEdge[70, 145] -> 
             RGBColor[
              0.2107154956867174, 0.33880572447377666`, 0.9353113078024935], 
             UndirectedEdge[125, 170] -> 
             RGBColor[
              0.18066259612527297`, 0.307218221570812, 0.93359983963175], 
             UndirectedEdge[190, 192] -> 
             RGBColor[
              0.4985130310330229, 0.22017044734510285`, 0.5488817116903315], 
             UndirectedEdge[122, 188] -> 
             RGBColor[
              0.8287961614327686, 0.8626280708354541, 0.7199844478872237], 
             UndirectedEdge[123, 130] -> 
             RGBColor[
              0.24382776690061642`, 0.3736088209588374, 0.9371970026629095], 
             UndirectedEdge[94, 116] -> 
             RGBColor[
              0.4038551160855868, 0.5242207360301667, 0.9469542687752844], 
             UndirectedEdge[23, 162] -> 
             RGBColor[
              0.9882402059749112, 0.9877215722762983, 0.728168038634343], 
             UndirectedEdge[116, 160] -> 
             RGBColor[
              0.3781472802574135, 0.5019539007492015, 0.9453161882088599], 
             UndirectedEdge[80, 117] -> 
             RGBColor[
              0.699447709361209, 0.7647890454809683, 0.9709133239805854], 
             UndirectedEdge[147, 185] -> 
             RGBColor[
              0.625134594396598, 0.7046026904109504, 0.9649644103506239], 
             UndirectedEdge[55, 107] -> 
             RGBColor[
              0.5098065457970684, 0.609801290788619, 0.955570731517623], 
             UndirectedEdge[111, 174] -> 
             RGBColor[
              0.4209532104070455, 0.5388353515241499, 0.9480975941384622], 
             UndirectedEdge[126, 142] -> 
             RGBColor[
              0.47405701779443504`, 0.579792473280542, 0.9528398302801124], 
             UndirectedEdge[115, 160] -> 
             RGBColor[
              0.31613284886837134`, 0.44424671423453505`, 0.9415109015232768],
              UndirectedEdge[74, 164] -> 
             RGBColor[
              0.29875283098362904`, 0.4313385457602833, 0.9403249038080864], 
             UndirectedEdge[42, 97] -> 
             RGBColor[
              0.401201459999004, 0.517503689481011, 0.9473903200062829], 
             UndirectedEdge[25, 108] -> 
             RGBColor[
              0.8800770451068233, 0.8847917621519991, 0.6757220357685101], 
             UndirectedEdge[67, 133] -> 
             RGBColor[
              0.820816769260137, 0.16101238726567596`, 0.16756746779367254`], 
             UndirectedEdge[38, 183] -> 
             RGBColor[
              0.9123593760428652, 0.674860106009205, 0.26130271158407675`], 
             UndirectedEdge[33, 41] -> 
             RGBColor[
              0.4363770738073567, 0.5497722412161976, 0.9497497290534018], 
             UndirectedEdge[32, 123] -> 
             RGBColor[
              0.24279155375346242`, 0.3725196952414703, 0.9371379918571192], 
             UndirectedEdge[61, 116] -> 
             RGBColor[
              0.3316898960628568, 0.4584835766718288, 0.9424742774984342], 
             UndirectedEdge[93, 134] -> 
             RGBColor[
              0.2274998629101822, 0.35644715861598486`, 0.9362671526856237], 
             UndirectedEdge[45, 128] -> 
             RGBColor[
              0.8869707508914968, 0.5796424030976618, 0.22739796275449303`], 
             UndirectedEdge[29, 35] -> 
             RGBColor[
              0.9160081618564544, 0.9327996859082862, 0.8697305761183244], 
             UndirectedEdge[3, 106] -> 
             RGBColor[
              0.26935764073949675`, 0.40044233705099297`, 0.93865089120997], 
             UndirectedEdge[77, 140] -> 
             RGBColor[
              0.3029488619339533, 0.43574884033280226`, 0.9405638615632359], 
             UndirectedEdge[79, 195] -> 
             RGBColor[
              0.1914475761291835, 0.31855391936214905`, 0.9342140282880245], 
             UndirectedEdge[38, 46] -> 
             RGBColor[
              0.7812753615379626, 0.7886327284729578, 0.6396314180362879], 
             UndirectedEdge[14, 59] -> 
             RGBColor[
              0.43278883650636024`, 0.549281670407568, 0.9487978998554119], 
             UndirectedEdge[126, 191] -> 
             RGBColor[
              0.2937278856939699, 0.4260570096609187, 0.9400387406075807], 
             UndirectedEdge[13, 64] -> 
             RGBColor[
              0.5003009692996179, 0.6031608120163909, 0.9543697328740091], 
             UndirectedEdge[3, 11] -> 
             RGBColor[
              0.2547628231142621, 0.3851022583619874, 0.9378197379373108], 
             UndirectedEdge[31, 98] -> 
             RGBColor[
              0.9119983758560902, 0.9316922814327566, 0.9576824339727095], 
             UndirectedEdge[25, 162] -> 
             RGBColor[
              0.9809113830760201, 0.9636638965398352, 0.6432211658410507], 
             UndirectedEdge[126, 157] -> 
             RGBColor[
              0.43245489742186133`, 0.5460179978079216, 0.9495647589707952], 
             UndirectedEdge[128, 183] -> 
             RGBColor[
              0.8747459970096212, 0.524132650883874, 0.217197328459318], 
             UndirectedEdge[22, 192] -> 
             RGBColor[
              0.8308704288952353, 0.23828922076278541`, 0.17719486361422723`],
              UndirectedEdge[99, 194] -> 
             RGBColor[
              0.45631234328201786`, 0.5666486807626816, 0.9511278800418784], 
             UndirectedEdge[21, 151] -> 
             RGBColor[
              0.33403902527338425`, 0.46374954722739153`, 0.9425056492046759],
              UndirectedEdge[48, 59] -> 
             RGBColor[
              0.382953798860026, 0.5061170655801353, 0.9456224553239809], 
             UndirectedEdge[18, 115] -> 
             RGBColor[
              0.2919621879503136, 0.4233113026000546, 0.9399707683828544], 
             UndirectedEdge[29, 89] -> 
             RGBColor[
              0.9238176258477779, 0.703826389599022, 0.47717574667802176`], 
             UndirectedEdge[15, 140] -> 
             RGBColor[
              0.31530720692745856`, 0.4472252108855248, 0.9413230505999493], 
             UndirectedEdge[113, 136] -> 
             RGBColor[
              0.9041543846818847, 0.6565805366270306, 0.24168008890791598`], 
             UndirectedEdge[111, 160] -> 
             RGBColor[
              0.41360379540408243`, 0.5324696576409218, 0.9476292959133059], 
             UndirectedEdge[116, 188] -> 
             RGBColor[
              0.5271183885528666, 0.6249053886087885, 0.9566275025109046], 
             UndirectedEdge[82, 127] -> 
             RGBColor[
              0.32009303423134106`, 0.45167023073266444`, 0.9416170229874327],
              UndirectedEdge[25, 95] -> 
             RGBColor[
              0.9792736576371948, 0.9417473218129542, 0.37398250307217895`], 
             UndirectedEdge[62, 111] -> 
             RGBColor[
              0.40836524299990506`, 0.527932286845723, 0.9472954999863816], 
             UndirectedEdge[162, 180] -> 
             RGBColor[
              0.853484717444914, 0.8855675982797966, 0.9434799440471393], 
             UndirectedEdge[89, 159] -> 
             RGBColor[
              0.8383183472366464, 0.29553718483349917`, 0.18432699862918317`],
              UndirectedEdge[7, 153] -> 
             RGBColor[
              0.46821510011481404`, 0.5763643045440561, 0.9520504222141921], 
             UndirectedEdge[146, 183] -> 
             RGBColor[
              0.8280025050148025, 0.648701197553076, 0.5925645649142633], 
             UndirectedEdge[144, 197] -> 
             RGBColor[
              0.8727164446748519, 0.6748369070629272, 0.5955099410043194], 
             UndirectedEdge[120, 128] -> 
             RGBColor[
              0.9231751810131911, 0.7286652920066743, 0.2580660064250903], 
             UndirectedEdge[74, 166] -> 
             RGBColor[
              0.34685352759081295`, 0.47429746798031186`, 0.9433423658444682],
              UndirectedEdge[147, 152] -> 
             RGBColor[
              0.3812177118441309, 0.5013730508472783, 0.9458086544862003], 
             UndirectedEdge[22, 190] -> 
             RGBColor[
              0.5120644599282582, 0.3243326681078883, 0.5618585753045587], 
             UndirectedEdge[27, 128] -> 
             RGBColor[
              0.5831652721126257, 0.49985421349972364`, 0.5843241339583132], 
             UndirectedEdge[47, 88] -> 
             RGBColor[
              0.5818581666070413, 0.6702991325141743, 0.9609700518092634], 
             UndirectedEdge[69, 177] -> 
             RGBColor[
              0.3475961861623531, 0.47409235374214537`, 0.9434207502916752], 
             UndirectedEdge[122, 167] -> 
             RGBColor[
              0.9541070504857341, 0.9612920976894692, 0.7322698767088691], 
             UndirectedEdge[1, 78] -> 
             RGBColor[
              0.9431385588038124, 0.9082192270955545, 0.6427719916956993], 
             UndirectedEdge[138, 159] -> 
             RGBColor[
              0.8677100686399041, 0.4334762404661291, 0.20899656655925808`], 
             UndirectedEdge[101, 127] -> 
             RGBColor[
              0.28671598940138643`, 0.417499764656998, 0.9396828962615742], 
             UndirectedEdge[65, 90] -> 
             RGBColor[
              0.6550212395891795, 0.7255799866641114, 0.9691860218299977], 
             UndirectedEdge[64, 127] -> 
             RGBColor[
              0.4720951346225606, 0.5787303356855954, 0.9525724820298272], 
             UndirectedEdge[117, 146] -> 
             RGBColor[
              0.7875464410912392, 0.8339565324458974, 0.9794589272741974], 
             UndirectedEdge[49, 103] -> 
             RGBColor[
              0.8495141808128409, 0.372335936521032, 0.19468564763117746`], 
             UndirectedEdge[88, 113] -> 
             RGBColor[
              0.8062483508925926, 0.7076340176229743, 0.6052352623718941], 
             UndirectedEdge[13, 176] -> 
             RGBColor[
              0.3360981234854725, 0.4641878743195114, 0.9426861060294587], 
             UndirectedEdge[17, 112] -> 
             RGBColor[
              0.27014379762534146`, 0.4012686377832412, 0.938695661681604], 
             UndirectedEdge[129, 170] -> 
             RGBColor[
              0.5863125273607737, 0.6439068649740138, 0.6751789886764388], 
             UndirectedEdge[35, 116] -> 
             RGBColor[
              0.6139780435679677, 0.6929094451719539, 0.9652454183041966], 
             UndirectedEdge[69, 110] -> 
             RGBColor[
              0.503306311820726, 0.6062411074789984, 0.9544293736590629], 
             UndirectedEdge[47, 126] -> 
             RGBColor[
              0.37937335834478547`, 0.5028752400890226, 0.9453994618957948], 
             UndirectedEdge[83, 137] -> 
             RGBColor[
              0.2530177140174724, 0.383268038054954, 0.9377203565559061], 
             UndirectedEdge[72, 84] -> 
             RGBColor[
              0.256326539038239, 0.386745822943403, 0.9379087892458708], 
             UndirectedEdge[22, 37] -> 
             RGBColor[
              0.517707803293592, 0.3302641797934895, 0.5621799553606361], 
             UndirectedEdge[90, 141] -> 
             RGBColor[
              0.37364371183420664`, 0.49805313613695035`, 0.9450292248112824],
              UndirectedEdge[24, 79] -> 
             RGBColor[
              0.1914475775488761, 0.318553920854336, 0.9342140283688739], 
             UndirectedEdge[34, 130] -> 
             RGBColor[
              0.2444860062107015, 0.3743006722085195, 0.9372344884178412], 
             UndirectedEdge[157, 174] -> 
             RGBColor[
              0.4695477072718456, 0.5782865532361309, 0.9519231309391665], 
             UndirectedEdge[131, 180] -> 
             RGBColor[
              0.811663417266584, 0.70990288285835, 0.6053916520008711], 
             UndirectedEdge[3, 48] -> 
             RGBColor[
              0.29038303180772673`, 0.42176872223911466`, 0.9398765460393633],
              UndirectedEdge[49, 67] -> 
             RGBColor[
              0.8264716492084423, 0.20447827253254375`, 0.17298258721844303`],
              UndirectedEdge[79, 190] -> 
             RGBColor[
              0.19183760716220638`, 0.3189638667072519, 0.9342362399783559], 
             UndirectedEdge[13, 82] -> 
             RGBColor[
              0.34829886890839834`, 0.4761007070634601, 0.9434142738316145], 
             UndirectedEdge[68, 138] -> 
             RGBColor[
              0.8842002449557951, 0.7898038345132208, 0.6173834589873493], 
             UndirectedEdge[153, 160] -> 
             RGBColor[
              0.4763409264473496, 0.5834024868973917, 0.9525681926827152], 
             UndirectedEdge[178, 183] -> 
             RGBColor[
              0.9011711841429679, 0.7066772038250902, 0.5935750920582745], 
             UndirectedEdge[2, 166] -> 
             RGBColor[
              0.3840226301972896, 0.5070428335634479, 0.9456905603116609], 
             UndirectedEdge[32, 53] -> 
             RGBColor[
              0.2232819677009355, 0.3520138833210643, 0.9360269497932738], 
             UndirectedEdge[26, 184] -> 
             RGBColor[
              0.38376793461067366`, 0.5068222290476936, 0.9456743313341002], 
             UndirectedEdge[61, 115] -> 
             RGBColor[
              0.2696754646738146, 0.40077639015716227`, 0.938668990812851], 
             UndirectedEdge[146, 178] -> 
             RGBColor[
              0.8692632098101054, 0.8986103712740543, 0.9813214481021706], 
             UndirectedEdge[88, 102] -> 
             RGBColor[
              0.5430147651889159, 0.6366549305319157, 0.9584949846187718], 
             UndirectedEdge[118, 159] -> 
             RGBColor[
              0.8679759941435095, 0.5543857383553449, 0.5804554745542396], 
             UndirectedEdge[62, 75] -> 
             RGBColor[
              0.3201980535903144, 0.44948818207116104`, 0.9417069408010099], 
             UndirectedEdge[89, 197] -> 
             RGBColor[
              0.8714546134192276, 0.6651379190942172, 0.5943016099688991], 
             UndirectedEdge[85, 146] -> 
             RGBColor[
              0.578124805971577, 0.6635021636474746, 0.9622403310784291], 
             UndirectedEdge[170, 190] -> 
             RGBColor[
              0.1810362129620878, 0.3076109165549801, 0.93362111655789], 
             UndirectedEdge[82, 101] -> 
             RGBColor[
              0.2852213829706352, 0.4162052116877847, 0.9395876612614353], 
             UndirectedEdge[7, 73] -> 
             RGBColor[
              0.3217974307185043, 0.4517031252435637, 0.941778474399676], 
             UndirectedEdge[19, 34] -> 
             RGBColor[
              0.25807475059694696`, 0.38858330413461983`, 0.938008347307892], 
             UndirectedEdge[56, 170] -> 
             RGBColor[
              0.1806461819290649, 0.30720096920987716`, 0.9335989048675586], 
             UndirectedEdge[32, 187] -> 
             RGBColor[
              0.2589893983893689, 0.38954465695647483`, 0.9380604351465702], 
             UndirectedEdge[74, 169] -> 
             RGBColor[
              0.28768269698087445`, 0.4197031330363533, 0.9396944760534252], 
             UndirectedEdge[55, 147] -> 
             RGBColor[
              0.41653896028796467`, 0.5344634711076623, 0.9479678683591656], 
             UndirectedEdge[49, 143] -> 
             RGBColor[
              0.8277680229573157, 0.2144427692409838, 0.17422399618440892`], 
             UndirectedEdge[28, 77] -> 
             RGBColor[
              0.29758543140917015`, 0.4301115347901189, 0.9402584221293339], 
             UndirectedEdge[122, 153] -> 
             RGBColor[
              0.7894542010597019, 0.8310300259596766, 0.7166537981174088], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.45346195936104267`, 0.5636403822236367, 0.9510953047712845], 
             UndirectedEdge[16, 199] -> 
             RGBColor[
              0.29762489558060606`, 0.42883871402717555`, 0.9403087925207747],
              UndirectedEdge[64, 180] -> 
             RGBColor[
              0.6733354003460714, 0.7444313569668306, 0.9682823563661463], 
             UndirectedEdge[38, 128] -> 
             RGBColor[
              0.9271948937048214, 0.742224726788967, 0.2736818311730274], 
             UndirectedEdge[46, 98] -> 
             RGBColor[
              0.7856154181292234, 0.8320307685883754, 0.9456185242307917], 
             UndirectedEdge[68, 142] -> 
             RGBColor[
              0.7482569303671527, 0.8035288216790438, 0.9754818662750824], 
             UndirectedEdge[5, 20] -> 
             RGBColor[
              0.2538041540046914, 0.3840946363446963, 0.9377651431497445], 
             UndirectedEdge[169, 200] -> 
             RGBColor[
              0.2545855584826314, 0.3849159419949167, 0.9378096429787789], 
             UndirectedEdge[27, 133] -> 
             RGBColor[
              0.5500884366842889, 0.29464670290479555`, 0.5545698278022309], 
             UndirectedEdge[32, 135] -> 
             RGBColor[
              0.23421532693659433`, 0.36350553709275546`, 0.9366495884272892],
              UndirectedEdge[144, 190] -> 
             RGBColor[
              0.5181114788530065, 0.37081270538409206`, 0.5676492074560286], 
             UndirectedEdge[62, 126] -> 
             RGBColor[
              0.33172983127376465`, 0.4616088115734021, 0.9423636584803461], 
             UndirectedEdge[55, 62] -> 
             RGBColor[
              0.35430836392456, 0.4813058296004574, 0.9437971935400564], 
             UndirectedEdge[62, 76] -> 
             RGBColor[
              0.3162924905225524, 0.44538318765994256`, 0.9414845247620637], 
             UndirectedEdge[157, 181] -> 
             RGBColor[
              0.7710073552893554, 0.8197903509371063, 0.9338398508674235], 
             UndirectedEdge[64, 82] -> 
             RGBColor[
              0.4706005281918093, 0.5774357827163821, 0.9524772470296884], 
             UndirectedEdge[142, 153] -> 
             RGBColor[
              0.6134295605638427, 0.6970487778093326, 0.9627105685555573], 
             UndirectedEdge[21, 109] -> 
             RGBColor[
              0.32687230511240406`, 0.45754209443377936`, 0.9420489921333002],
              UndirectedEdge[66, 198] -> 
             RGBColor[
              0.6938904051885131, 0.7607917253864516, 0.97012416888083], 
             UndirectedEdge[141, 198] -> 
             RGBColor[
              0.5277497041986612, 0.6241140740098087, 0.9572340887790165], 
             UndirectedEdge[10, 28] -> 
             RGBColor[
              0.292046399990443, 0.42428966157416065`, 0.9399429824843], 
             UndirectedEdge[31, 151] -> 
             RGBColor[
              0.6011924048521665, 0.6814178617192261, 0.9646228375029955], 
             UndirectedEdge[111, 142] -> 
             RGBColor[
              0.5506924295205754, 0.6461159485528629, 0.957771671786148], 
             UndirectedEdge[111, 181] -> 
             RGBColor[
              0.7224128584245553, 0.7803391492251253, 0.9300143140667192], 
             UndirectedEdge[86, 101] -> 
             RGBColor[
              0.3219019660862388, 0.44797608916280746`, 0.9419249155821955], 
             UndirectedEdge[119, 144] -> 
             RGBColor[
              0.7106971334859737, 0.5465221256313679, 0.5803207163108766], 
             UndirectedEdge[5, 102] -> 
             RGBColor[
              0.32802099544168023`, 0.45608332647208405`, 0.9422120278540836],
              UndirectedEdge[157, 185] -> 
             RGBColor[
              0.6636290641812901, 0.7358542351382649, 0.9679948360219639], 
             UndirectedEdge[13, 110] -> 
             RGBColor[
              0.49151316787654187`, 0.5960264789351953, 0.9536779249552072], 
             UndirectedEdge[32, 82] -> 
             RGBColor[
              0.27687504662639884`, 0.4074326830017036, 0.9391123497539292], 
             UndirectedEdge[12, 23] -> 
             RGBColor[
              0.7887708920716545, 0.8309004872015715, 0.7514495100334264], 
             UndirectedEdge[53, 130] -> 
             RGBColor[
              0.22431818084808952`, 0.35310300903843134`, 0.9360859605990643],
              UndirectedEdge[74, 80] -> 
             RGBColor[
              0.46133983359188224`, 0.5689367397653611, 0.9518870537804123], 
             UndirectedEdge[35, 185] -> 
             RGBColor[
              0.8039733137479249, 0.8469379641216965, 0.9810567615537757], 
             UndirectedEdge[117, 196] -> 
             RGBColor[
              0.6370858970808988, 0.7141609169041846, 0.966003973679034], 
             UndirectedEdge[22, 181] -> 
             RGBColor[
              0.9143758811781899, 0.66511973430378, 0.5497646458428832], 
             UndirectedEdge[143, 197] -> 
             RGBColor[
              0.8548577179564267, 0.5375669077611642, 0.5784084041302087], 
             UndirectedEdge[16, 124] -> 
             RGBColor[
              0.3070078817138632, 0.43870082736891025`, 0.9408431397001796], 
             UndirectedEdge[182, 191] -> 
             RGBColor[
              0.2726772055917506, 0.4039314101832797, 0.9388399355174497], 
             UndirectedEdge[98, 146] -> 
             RGBColor[
              0.8847914583012635, 0.9101913135735867, 0.9550361738224766], 
             UndirectedEdge[156, 183] -> 
             RGBColor[
              0.8903771130215434, 0.6982439271770752, 0.5985651507743678], 
             UndirectedEdge[6, 13] -> 
             RGBColor[
              0.35902556110322426`, 0.48539162870339236`, 0.9440977691730272],
              UndirectedEdge[50, 100] -> 
             RGBColor[
              0.2280232863629279, 0.35699730985178435`, 0.9362969608769219], 
             UndirectedEdge[13, 175] -> 
             RGBColor[
              0.34919860302112393`, 0.4768800115299515, 0.9434716040936737], 
             UndirectedEdge[62, 116] -> 
             RGBColor[
              0.37290872785323614`, 0.4974165299540027, 0.9449823922819357], 
             UndirectedEdge[120, 171] -> 
             RGBColor[
              0.9156195043648556, 0.8842880492213061, 0.6372222517571104], 
             UndirectedEdge[72, 139] -> 
             RGBColor[
              0.24951735884561907`, 0.3795889428339999, 0.9375210165071806], 
             UndirectedEdge[6, 83] -> 
             RGBColor[
              0.29795007881864144`, 0.4276003661015726, 0.9403851677491978], 
             UndirectedEdge[118, 190] -> 
             RGBColor[
              0.5465072945042451, 0.6199622709372278, 0.9625693523456647], 
             UndirectedEdge[36, 200] -> 
             RGBColor[
              0.24218408124275126`, 0.3718812031167312, 0.9371033971963092], 
             UndirectedEdge[16, 161] -> 
             RGBColor[
              0.3158101253960152, 0.4479525435733356, 0.9413444144561256], 
             UndirectedEdge[2, 169] -> 
             RGBColor[
              0.3248517995873511, 0.4524484986194894, 0.942042670520618], 
             UndirectedEdge[107, 111] -> 
             RGBColor[
              0.5638634248724134, 0.6564277480338845, 0.9590690379639482], 
             UndirectedEdge[127, 180] -> 
             RGBColor[
              0.5228279063856032, 0.618665804983113, 0.9574221323238906], 
             UndirectedEdge[138, 156] -> 
             RGBColor[
              0.9168097113153278, 0.8158057378279282, 0.6204937789995357], 
             UndirectedEdge[72, 93] -> 
             RGBColor[
              0.23701205160573985`, 0.3664450720426131, 0.9368088577598136], 
             UndirectedEdge[137, 187] -> 
             RGBColor[
              0.2665071069572168, 0.39744624531153616`, 0.938488557528056], 
             UndirectedEdge[40, 121] -> 
             RGBColor[
              0.5171284633430432, 0.6188672087704971, 0.9551293934197934], 
             UndirectedEdge[98, 178] -> 
             RGBColor[
              0.957960137429429, 0.968167319845601, 0.9560467009664877], 
             UndirectedEdge[10, 186] -> 
             RGBColor[
              0.28567319780598677`, 0.4175910219939398, 0.939580038048203], 
             UndirectedEdge[63, 91] -> 
             RGBColor[
              0.5953350475574752, 0.6767809281925967, 0.9640487060966569], 
             UndirectedEdge[125, 195] -> 
             RGBColor[
              0.17894341419620807`, 0.3054112523609348, 0.9335019347641915], 
             UndirectedEdge[86, 180] -> 
             RGBColor[
              0.5580138830704554, 0.6491421294889225, 0.9596641516445119], 
             UndirectedEdge[137, 186] -> 
             RGBColor[
              0.2661087370017966, 0.3970275332302755, 0.9384658709484304], 
             UndirectedEdge[33, 44] -> 
             RGBColor[
              0.3032320659672701, 0.4347249229295589, 0.9406283792341544], 
             UndirectedEdge[14, 193] -> 
             RGBColor[
              0.36672963099697153`, 0.49206450682754455`, 0.9445886656942154],
              UndirectedEdge[11, 28] -> 
             RGBColor[
              0.2703195386510599, 0.4014533527438959, 0.9387056698730332], 
             UndirectedEdge[85, 151] -> 
             RGBColor[
              0.35601576258697687`, 0.48278469250549083`, 0.9439059874730323],
              UndirectedEdge[175, 199] -> 
             RGBColor[
              0.2963432017196842, 0.4277285752246516, 0.9402271241213142], 
             UndirectedEdge[146, 196] -> 
             RGBColor[
              0.6456339866715997, 0.7208387494603272, 0.9668559673629961], 
             UndirectedEdge[20, 77] -> 
             RGBColor[
              0.2628976545910799, 0.3936524820222284, 0.9382830045555108], 
             UndirectedEdge[27, 56] -> 
             RGBColor[
              0.22783801477683696`, 0.3568025776679057, 0.9362864099341788], 
             UndirectedEdge[101, 175] -> 
             RGBColor[
              0.2861211170833608, 0.41698451615427623`, 0.9396449915234946], 
             UndirectedEdge[21, 85] -> 
             RGBColor[
              0.3381783439476214, 0.46733481701480994`, 0.9427694029303426], 
             UndirectedEdge[150, 194] -> 
             RGBColor[
              0.31572797791144636`, 0.44550227419337246`, 0.9414262912319082],
              UndirectedEdge[61, 160] -> 
             RGBColor[
              0.3202543943304065, 0.44857871983620956`, 0.9417456174400596], 
             UndirectedEdge[24, 149] -> 
             RGBColor[
              0.20624750544947348`, 0.3341095834474904, 0.9350568623682817], 
             UndirectedEdge[14, 186] -> 
             RGBColor[
              0.34940158280640243`, 0.47458578186823513`, 0.9435749780704197],
              UndirectedEdge[111, 126] -> 
             RGBColor[
              0.3838604005570612, 0.5065667960959406, 0.9457392221700909], 
             UndirectedEdge[35, 88] -> 
             RGBColor[
              0.775283955250752, 0.8245256192165048, 0.9781972744160757], 
             UndirectedEdge[94, 111] -> 
             RGBColor[
              0.43931163123225564`, 0.554736492921887, 0.9492673764797304], 
             UndirectedEdge[133, 162] -> 
             RGBColor[
              0.903164553297809, 0.5839253103845123, 0.5419478585850865], 
             UndirectedEdge[124, 199] -> 
             RGBColor[
              0.2816714935465845, 0.4133849770946037, 0.939352146910621], 
             UndirectedEdge[54, 105] -> 
             RGBColor[
              0.3080083942884021, 0.4378802673814718, 0.9409686664381117], 
             UndirectedEdge[64, 162] -> 
             RGBColor[
              0.8027519456818715, 0.845632128982279, 0.9386302937530759], 
             UndirectedEdge[57, 66] -> 
             RGBColor[
              0.5260989516337345, 0.6228771288818142, 0.9570472794276266], 
             UndirectedEdge[16, 137] -> 
             RGBColor[
              0.2865741831678942, 0.41722371462578045`, 0.9396794707969347], 
             UndirectedEdge[44, 50] -> 
             RGBColor[
              0.2628281872337618, 0.3935794674252022, 0.9382790484922793], 
             UndirectedEdge[153, 167] -> 
             RGBColor[
              0.7506229237957682, 0.8050180016109936, 0.9761649358064053], 
             UndirectedEdge[165, 187] -> 
             RGBColor[
              0.2508650284302595, 0.38100542901464385`, 0.9375977642963274], 
             UndirectedEdge[32, 83] -> 
             RGBColor[
              0.2455000054496245, 0.37536644969989263`, 0.9372922341744203], 
             UndirectedEdge[6, 187] -> 
             RGBColor[
              0.3114394717583858, 0.44177857335815474`, 0.9411533687213477], 
             UndirectedEdge[66, 141] -> 
             RGBColor[
              0.5254792907329107, 0.622340409754583, 0.9570077951829706], 
             UndirectedEdge[23, 87] -> 
             RGBColor[
              0.9907768608924232, 0.9889849826208208, 0.6957320893038507], 
             UndirectedEdge[85, 152] -> 
             RGBColor[
              0.320947319253029, 0.44991323932493577`, 0.9417628821181223], 
             UndirectedEdge[26, 74] -> 
             RGBColor[
              0.3495927399015075, 0.4766700360070217, 0.9435169060307154], 
             UndirectedEdge[81, 172] -> 
             RGBColor[
              0.7851552645502801, 0.8282289520022286, 0.7727853942333442], 
             UndirectedEdge[54, 73] -> 
             RGBColor[
              0.28297059999413937`, 0.41475042033909004`, 0.9394261291009534],
              UndirectedEdge[135, 165] -> 
             RGBColor[
              0.22609095697748494`, 0.3549663091509244, 0.9361869175770461], 
             UndirectedEdge[46, 109] -> 
             RGBColor[
              0.4676427269643195, 0.5755488960812328, 0.9521022706897019], 
             UndirectedEdge[40, 171] -> 
             RGBColor[
              0.6830257915160596, 0.7504348777708634, 0.9705035877143484], 
             UndirectedEdge[113, 167] -> 
             RGBColor[
              0.9077889348257765, 0.7877285014564059, 0.6151514893253305], 
             UndirectedEdge[103, 162] -> 
             RGBColor[
              0.9235960103474408, 0.7317131111648968, 0.5611505510553894], 
             UndirectedEdge[37, 119] -> 
             RGBColor[
              0.3779360600643469, 0.4878548266230827, 0.9465383122915882], 
             UndirectedEdge[71, 184] -> 
             RGBColor[
              0.3307081584442233, 0.45915751757499346`, 0.9423559109556644], 
             UndirectedEdge[107, 142] -> 
             RGBColor[
              0.6540600421097872, 0.7296534252184859, 0.9661696460739697], 
             UndirectedEdge[136, 143] -> 
             RGBColor[
              0.8644025575685669, 0.416927830578244, 0.20619406567310455`], 
             UndirectedEdge[3, 5] -> 
             RGBColor[
              0.27293521528598386`, 0.4042025947306783, 0.9388546287878452], 
             UndirectedEdge[24, 118] -> 
             RGBColor[
              0.5461172648909147, 0.6195523250843118, 0.9625471407361825], 
             UndirectedEdge[142, 185] -> 
             RGBColor[
              0.7052311845538637, 0.7696287106108853, 0.971269907331281], 
             UndirectedEdge[3, 28] -> 
             RGBColor[
              0.2792200802478043, 0.4108083862890054, 0.9392125425497964], 
             UndirectedEdge[43, 49] -> 
             RGBColor[
              0.8450514898395424, 0.34729106936125886`, 0.19077466358971318`],
              UndirectedEdge[19, 60] -> 
             RGBColor[
              0.25917942342753286`, 0.38974438531986844`, 0.9380712567913769],
              UndirectedEdge[87, 110] -> 
             RGBColor[
              0.7965007991763076, 0.8397612062456058, 0.9055025365037817], 
             UndirectedEdge[107, 185] -> 
             RGBColor[
              0.7184021799057017, 0.779940510091907, 0.9725672735090811], 
             UndirectedEdge[66, 81] -> 
             RGBColor[
              0.633976904061278, 0.7129754213419766, 0.9648440654867796], 
             UndirectedEdge[63, 112] -> 
             RGBColor[
              0.32715088352733546`, 0.45710875455411837`, 0.94209144443096], 
             UndirectedEdge[59, 193] -> 
             RGBColor[
              0.38274569330621644`, 0.5059368150091147, 0.9456091950221126], 
             UndirectedEdge[110, 180] -> 
             RGBColor[
              0.6645475989229954, 0.737297023885635, 0.9675905484473445], 
             UndirectedEdge[21, 196] -> 
             RGBColor[
              0.4056875246476441, 0.5246714028276624, 0.9473850392149095], 
             UndirectedEdge[24, 190] -> 
             RGBColor[
              0.1793170324527155, 0.3058039488372898, 0.9335232117711809], 
             UndirectedEdge[44, 60] -> 
             RGBColor[
              0.2686906729944792, 0.399741311662782, 0.9386129083835817], 
             UndirectedEdge[20, 106] -> 
             RGBColor[
              0.25022657945820426`, 0.38033437866501096`, 0.9375614055718693],
              UndirectedEdge[75, 139] -> 
             RGBColor[
              0.26665982071221705`, 0.39760675715065275`, 0.9384972543504835],
              UndirectedEdge[4, 81] -> 
             RGBColor[
              0.6906097692395512, 0.7572174460449604, 0.9704887002235348], 
             UndirectedEdge[79, 197] -> 
             RGBColor[
              0.5464425729840517, 0.6229880683860871, 0.9620969735266468], 
             UndirectedEdge[66, 90] -> 
             RGBColor[
              0.5397844128240585, 0.6347307875135932, 0.9579193049130958], 
             UndirectedEdge[14, 15] -> 
             RGBColor[
              0.3709417656089321, 0.49571284612038347`, 0.9448570591870451], 
             UndirectedEdge[14, 48] -> 
             RGBColor[
              0.36693773655078116`, 0.49224475739856516`, 0.9446019259960836],
              UndirectedEdge[122, 144] -> 
             RGBColor[
              0.9247271116948175, 0.7113578190580653, 0.33725586527563345`], 
             UndirectedEdge[80, 121] -> 
             RGBColor[
              0.5812862861253769, 0.6709534195821745, 0.9601801322470673], 
             UndirectedEdge[79, 170] -> 
             RGBColor[
              0.1931667580582484, 0.32036088857202627`, 0.934311933155583], 
             UndirectedEdge[91, 95] -> 
             RGBColor[
              0.9087217160297558, 0.9082261327367556, 0.679871771253554], 
             UndirectedEdge[48, 193] -> 
             RGBColor[
              0.3168945933506373, 0.44889990200011176`, 0.9414132211627845], 
             UndirectedEdge[67, 162] -> 
             RGBColor[
              0.9005534787430421, 0.5638554471764086, 0.5394474906426548], 
             UndirectedEdge[65, 87] -> 
             RGBColor[
              0.9550341089343712, 0.965005825208276, 0.9206936459458361], 
             UndirectedEdge[98, 121] -> 
             RGBColor[
              0.7580819454747305, 0.8096778551186503, 0.9434509884049964], 
             UndirectedEdge[161, 187] -> 
             RGBColor[
              0.2957430491853379, 0.4281750742590913, 0.9401535011872468], 
             UndirectedEdge[68, 122] -> 
             RGBColor[
              0.924281570863012, 0.9375100698293877, 0.7294250958369339], 
             UndirectedEdge[19, 90] -> 
             RGBColor[
              0.32617520722218063`, 0.45283835871142575`, 0.9421546927268274],
              UndirectedEdge[80, 168] -> 
             RGBColor[
              0.7792447125486042, 0.8280111263190817, 0.9760255070982982], 
             UndirectedEdge[109, 194] -> 
             RGBColor[
              0.3430360942965171, 0.47154235620939167`, 0.9430789344870343], 
             UndirectedEdge[44, 57] -> 
             RGBColor[
              0.3220009955988029, 0.4509816264225601, 0.9418243188335629], 
             UndirectedEdge[109, 151] -> 
             RGBColor[
              0.34470972375175946`, 0.47299196992446024`, 0.9431855766759899],
              UndirectedEdge[122, 138] -> 
             RGBColor[
              0.9528570018424507, 0.8395978867219851, 0.360717102170288], 
             UndirectedEdge[138, 192] -> 
             RGBColor[
              0.8650473379676169, 0.41300932570290905`, 0.20644673266035168`],
              UndirectedEdge[31, 46] -> 
             RGBColor[
              0.7241254080647266, 0.7839747878759986, 0.9735395315167075], 
             UndirectedEdge[101, 165] -> 
             RGBColor[
              0.23537363183733478`, 0.36472298898420613`, 0.9367155521778278],
              UndirectedEdge[76, 105] -> 
             RGBColor[
              0.3097803157470692, 0.4397426691808402, 0.94106957474386], 
             UndirectedEdge[6, 199] -> 
             RGBColor[
              0.3061701598017846, 0.4362401923980924, 0.9408532892006678], 
             UndirectedEdge[83, 175] -> 
             RGBColor[
              0.2881231207365411, 0.41908874892813175`, 0.9397590026698441], 
             UndirectedEdge[139, 182] -> 
             RGBColor[
              0.2571409182934481, 0.38760178717525484`, 0.9379551669396888], 
             UndirectedEdge[89, 149] -> 
             RGBColor[
              0.5437801205941402, 0.38941935202558264`, 0.567974527017709], 
             UndirectedEdge[53, 163] -> 
             RGBColor[
              0.2222172147783616, 0.3508947604902047, 0.935966313689494], 
             UndirectedEdge[8, 96] -> 
             RGBColor[
              0.3771970335719591, 0.5008951438379817, 0.9452642694982989], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.3028942075372073, 0.43437709498723787`, 0.9406088720414547], 
             UndirectedEdge[55, 191] -> 
             RGBColor[
              0.31630641834476525`, 0.445754027687974, 0.9414722756672911], 
             UndirectedEdge[122, 181] -> 
             RGBColor[
              0.9886341161577883, 0.9875460745600706, 0.6910581517385923], 
             UndirectedEdge[130, 177] -> 
             RGBColor[
              0.26541543308332344`, 0.3962988268539529, 0.9384263883159245], 
             UndirectedEdge[25, 131] -> 
             RGBColor[
              0.93909008289769, 0.7879991811183886, 0.30513287379478254`], 
             UndirectedEdge[19, 33] -> 
             RGBColor[
              0.29372081640032377`, 0.4247279965866454, 0.9400867276419496], 
             UndirectedEdge[1, 89] -> 
             RGBColor[
              0.9061524103512045, 0.6435271253680068, 0.2459445167509792], 
             UndirectedEdge[123, 127] -> 
             RGBColor[
              0.2860095413584047, 0.4167572429724312, 0.9396426650906227], 
             UndirectedEdge[40, 173] -> 
             RGBColor[
              0.7433614186788604, 0.7950716369237336, 0.832834751651226], 
             UndirectedEdge[17, 106] -> 
             RGBColor[
              0.25694510996125053`, 0.38739598020314986`, 0.9379440159448427],
              UndirectedEdge[51, 158] -> 
             RGBColor[
              0.267702506048196, 0.39870268554883526`, 0.9385566337378528], 
             UndirectedEdge[20, 189] -> 
             RGBColor[
              0.2283963086796351, 0.35738937995762443`, 0.9363182039460214], 
             UndirectedEdge[48, 140] -> 
             RGBColor[
              0.3113031778693076, 0.4437571221637065, 0.9410679174089878], 
             UndirectedEdge[11, 189] -> 
             RGBColor[
              0.2386268283641832, 0.36814230479849686`, 0.9369008169073587], 
             UndirectedEdge[40, 169] -> 
             RGBColor[
              0.38208210782853824`, 0.5009795735314966, 0.9459763978166744], 
             UndirectedEdge[94, 167] -> 
             RGBColor[0.666701611701555, 0.7359313939081493, 0.9698223518406],
              UndirectedEdge[81, 198] -> 
             RGBColor[
              0.6362473175270285, 0.7147490855972023, 0.9650703590828255], 
             UndirectedEdge[34, 60] -> 
             RGBColor[
              0.25285259350547307`, 0.38309448592759754`, 0.9377109531870217],
              UndirectedEdge[13, 101] -> 
             RGBColor[
              0.3149218240784437, 0.4419302409877936, 0.941480147105756], 
             UndirectedEdge[31, 117] -> 
             RGBColor[
              0.8147533586460658, 0.8554575003050673, 0.9821051874244302], 
             UndirectedEdge[94, 105] -> 
             RGBColor[
              0.3806688871734759, 0.5041379899202462, 0.945476862771782], 
             UndirectedEdge[125, 190] -> 
             RGBColor[
              0.179333445229231, 0.3058211997060377, 0.933524146454523], 
             UndirectedEdge[79, 119] -> 
             RGBColor[
              0.3844232617951737, 0.4946732869545277, 0.9469077488332039], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.2600890189665118, 0.39070042790302345`, 0.9381230569116956], 
             UndirectedEdge[156, 178] -> 
             RGBColor[
              0.9316378178168464, 0.9481531008980535, 0.987322033962275], 
             UndirectedEdge[95, 131] -> 
             RGBColor[
              0.9394422371635587, 0.7891870801469172, 0.306500926618929], 
             UndirectedEdge[49, 133] -> 
             RGBColor[
              0.829082723763209, 0.22454813574064747`, 0.1754829551608747], 
             UndirectedEdge[34, 44] -> 
             RGBColor[
              0.2675860001638932, 0.3985802304775334, 0.9385499989000968], 
             UndirectedEdge[24, 125] -> 
             RGBColor[
              0.17894341561590066`, 0.30541125385312173`, 0.9335019348450408],
              UndirectedEdge[95, 129] -> 
             RGBColor[
              0.9849427513832404, 0.9608705061848779, 0.39600586175704294`], 
             UndirectedEdge[13, 16] -> 
             RGBColor[
              0.35048029688204574`, 0.4779901503324755, 0.9435532724931343], 
             UndirectedEdge[13, 199] -> 
             RGBColor[
              0.3251439087147671, 0.45267430005816894`, 0.9420622797035756], 
             UndirectedEdge[121, 196] -> 
             RGBColor[
              0.5189244738450667, 0.6203252910053908, 0.955270781945516], 
             UndirectedEdge[26, 40] -> 
             RGBColor[
              0.4439921507491714, 0.557946476502165, 0.9497988277939646], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.31163329513552707`, 0.44101997430243733`, 0.9411996419147166],
              UndirectedEdge[54, 126] -> 
             RGBColor[
              0.29001572662104147`, 0.4221552951107917, 0.9398273386400247], 
             UndirectedEdge[16, 193] -> 
             RGBColor[
              0.3198238857723562, 0.4514371078652866, 0.9415998730856248], 
             UndirectedEdge[85, 150] -> 
             RGBColor[
              0.3215409260409259, 0.45053715769585945`, 0.9417966871465304], 
             UndirectedEdge[26, 169] -> 
             RGBColor[
              0.3344928369204973, 0.4607990805848347, 0.9426569888942514], 
             UndirectedEdge[22, 79] -> 
             RGBColor[
              0.5241950050244188, 0.3370826401249345, 0.5625493919022517], 
             UndirectedEdge[27, 67] -> 
             RGBColor[
              0.5474773621295221, 0.27457683969669183`, 0.5520694598597993], 
             UndirectedEdge[49, 95] -> 
             RGBColor[
              0.9071817078072888, 0.605474620924499, 0.27812431524098535`], 
             UndirectedEdge[147, 178] -> 
             RGBColor[
              0.7115638776908443, 0.7729379814418316, 0.9672966305905184], 
             UndirectedEdge[1, 136] -> 
             RGBColor[
              0.9331596302538536, 0.7720124271387454, 0.2686954588022206], 
             UndirectedEdge[65, 110] -> 
             RGBColor[
              0.7635603354949406, 0.815471840469592, 0.9772401996765336], 
             UndirectedEdge[77, 106] -> 
             RGBColor[
              0.2877229919008626, 0.4197454855521064, 0.9396967707895075], 
             UndirectedEdge[25, 64] -> 
             RGBColor[
              0.8007620659771775, 0.8225276552268693, 0.6680235781600576], 
             UndirectedEdge[82, 187] -> 
             RGBColor[
              0.3007127795635599, 0.4324876517182224, 0.9404698733799348], 
             UndirectedEdge[167, 188] -> 
             RGBColor[
              0.7899648841688349, 0.8366160464867711, 0.9794955855762202], 
             UndirectedEdge[13, 137] -> 
             RGBColor[
              0.31409319630205523`, 0.44105930065677384`, 0.9414329579797356],
              UndirectedEdge[37, 125] -> 
             RGBColor[
              0.18497678859456473`, 0.3117527113916389, 0.9338455265106003], 
             UndirectedEdge[105, 182] -> 
             RGBColor[
              0.30416697639606216`, 0.43384269361666083`, 0.9407499033720115],
              UndirectedEdge[111, 116] -> 
             RGBColor[
              0.42503929713653266`, 0.5423745144765412, 0.9483579559716804], 
             UndirectedEdge[146, 179] -> 
             RGBColor[
              0.802014133137712, 0.8452588034311341, 0.9809009316091206], 
             UndirectedEdge[9, 63] -> 
             RGBColor[
              0.3067096536024727, 0.43562372585425413`, 0.9409273466268289], 
             UndirectedEdge[38, 120] -> 
             RGBColor[
              0.960788560046435, 0.8793927471320053, 0.302171389549849], 
             UndirectedEdge[71, 81] -> 
             RGBColor[
              0.43330857195401157`, 0.5446846710814149, 0.9498164169017225], 
             UndirectedEdge[68, 181] -> 
             RGBColor[
              0.9199773592711327, 0.9377520223513063, 0.9477245085556535], 
             UndirectedEdge[114, 158] -> 
             RGBColor[
              0.23522624458781927`, 0.364568075640074, 0.9367071586920077], 
             UndirectedEdge[118, 149] -> 
             RGBColor[
              0.5734377675010032, 0.6482679055474284, 0.9641030029427655], 
             UndirectedEdge[87, 162] -> 
             RGBColor[
              0.9854379176982261, 0.9880317806397674, 0.8813919321035765], 
             UndirectedEdge[88, 122] -> 
             RGBColor[
              0.8525664665525501, 0.8811976138560375, 0.7223536497554326], 
             UndirectedEdge[49, 162] -> 
             RGBColor[
              0.9088194332461141, 0.62739119565138, 0.547362978009857], 
             UndirectedEdge[47, 116] -> 
             RGBColor[
              0.42055225492425696`, 0.5386829584696233, 0.9480181956973843], 
             UndirectedEdge[23, 95] -> 
             RGBColor[
              0.9866024805360858, 0.9658049975494172, 0.45892937586547133`], 
             UndirectedEdge[54, 115] -> 
             RGBColor[
              0.2691801918114708, 0.40025582697672574`, 0.938640785756031], 
             UndirectedEdge[62, 105] -> 
             RGBColor[
              0.3497224989411253, 0.4773337838440822, 0.9435049862784333], 
             UndirectedEdge[13, 108] -> 
             RGBColor[
              0.5796159484292636, 0.6654249189415207, 0.9620681904824614], 
             UndirectedEdge[76, 182] -> 
             RGBColor[
              0.27073696797748936`, 0.4018920974325212, 0.938729441855642], 
             UndirectedEdge[117, 171] -> 
             RGBColor[
              0.8267342564377225, 0.8650107429913272, 0.9832479361512722], 
             UndirectedEdge[40, 46] -> 
             RGBColor[
              0.5446619359975361, 0.6412201222402223, 0.9572969292455886], 
             UndirectedEdge[19, 177] -> 
             RGBColor[
              0.2790041774695689, 0.41058145878005325`, 0.9392002472059755], 
             UndirectedEdge[64, 87] -> 
             RGBColor[
              0.8052886005993835, 0.8468955393268014, 0.9061943444225835], 
             UndirectedEdge[62, 107] -> 
             RGBColor[
              0.5117328555891169, 0.611469763511346, 0.9556934742742034], 
             UndirectedEdge[53, 148] -> 
             RGBColor[
              0.20810268194188267`, 0.3360594915659958, 0.9351625119250367], 
             UndirectedEdge[76, 111] -> 
             RGBColor[
              0.368423059805849, 0.49034117218248097`, 0.9448600884518084], 
             UndirectedEdge[11, 48] -> 
             RGBColor[
              0.2814824902109824, 0.4124136886940051, 0.9393696733626], 
             UndirectedEdge[96, 111] -> 
             RGBColor[
              0.3833462518703272, 0.5060263932272735, 0.9457099421629962], 
             UndirectedEdge[168, 198] -> 
             RGBColor[
              0.8173765882647961, 0.8581441256038294, 0.9795908811512684], 
             UndirectedEdge[118, 128] -> 
             RGBColor[
              0.901444520807011, 0.7626039594239429, 0.6105848646794676], 
             UndirectedEdge[56, 129] -> 
             RGBColor[
              0.5845933454317087, 0.6420998957641366, 0.6750810838088802], 
             UndirectedEdge[53, 100] -> 
             RGBColor[
              0.21261327393044743`, 0.34080040973402737`, 0.9354193834659627],
              UndirectedEdge[129, 143] -> 
             RGBColor[
              0.9055290665332671, 0.5698386545013628, 0.2921055427004665], 
             UndirectedEdge[18, 160] -> 
             RGBColor[
              0.34254111760690553`, 0.47111363227910186`, 0.9430473950100628],
              UndirectedEdge[68, 111] -> 
             RGBColor[
              0.6580603131297789, 0.7303031444944423, 0.9683812581650608], 
             UndirectedEdge[51, 166] -> 
             RGBColor[
              0.33653220976868264`, 0.46344910853990606`, 0.9427545820635193],
              UndirectedEdge[107, 181] -> 
             RGBColor[
              0.8257804710137671, 0.8638766258907483, 0.9384122883545408], 
             UndirectedEdge[31, 173] -> 
             RGBColor[
              0.9228248907460509, 0.93782630255951, 0.8490773539223448], 
             UndirectedEdge[135, 148] -> 
             RGBColor[
              0.2190360411775415, 0.34755114533768694`, 0.935785150559052], 
             UndirectedEdge[44, 177] -> 
             RGBColor[
              0.2885154270365152, 0.4205783851229668, 0.9397418987981803], 
             UndirectedEdge[80, 184] -> 
             RGBColor[
              0.4955150283010483, 0.599088932806033, 0.9540444790837972], 
             UndirectedEdge[65, 162] -> 
             RGBColor[
              0.9524974540168591, 0.9637424148637534, 0.9531295952763283], 
             UndirectedEdge[5, 17] -> 
             RGBColor[
              0.26052268450773763`, 0.3911562378828352, 0.9381477535227178], 
             UndirectedEdge[44, 141] -> 
             RGBColor[
              0.321381334697979, 0.45044490729532893`, 0.941784834588907], 
             UndirectedEdge[94, 174] -> 
             RGBColor[
              0.39976902935609954`, 0.5206815730777754, 0.9466939069420661], 
             UndirectedEdge[161, 193] -> 
             RGBColor[
              0.31267272742048674`, 0.4452350871371401, 0.9411445022314171], 
             UndirectedEdge[101, 124] -> 
             RGBColor[
              0.2714494089102611, 0.40264091802422836`, 0.9387700143128014], 
             UndirectedEdge[106, 189] -> 
             RGBColor[
              0.25322164598941777`, 0.3834823834875024, 0.9377319701800181], 
             UndirectedEdge[2, 80] -> 
             RGBColor[
              0.4985089361983589, 0.6016821053484971, 0.954235248247605], 
             UndirectedEdge[97, 102] -> 
             RGBColor[
              0.3273981891467483, 0.4554287175679108, 0.9421765599569466], 
             UndirectedEdge[91, 136] -> 
             RGBColor[
              0.8729121465452325, 0.773250594157032, 0.6146156000869095], 
             UndirectedEdge[59, 154] -> 
             RGBColor[
              0.7176662191262557, 0.7759253920834623, 0.911377748265729], 
             UndirectedEdge[108, 162] -> 
             RGBColor[
              0.8820669248115173, 0.9078962359074088, 0.9463287513615282], 
             UndirectedEdge[146, 147] -> 
             RGBColor[
              0.6383951985626789, 0.7149619751698173, 0.9662861034465073], 
             UndirectedEdge[99, 156] -> 
             RGBColor[
              0.7424696241286013, 0.7983584952437333, 0.9755694516963352], 
             UndirectedEdge[143, 154] -> 
             RGBColor[
              0.9036629908200117, 0.5747841615261196, 0.5202434925656607], 
             UndirectedEdge[139, 145] -> 
             RGBColor[
              0.2284570343408142, 0.357453206477753, 0.9363216621825899], 
             UndirectedEdge[104, 123] -> 
             RGBColor[
              0.23468312728084179`, 0.36399722491481445`, 0.9366762289648454],
              UndirectedEdge[116, 126] -> 
             RGBColor[
              0.34840388541039236`, 0.4760510392042203, 0.9434261144656448], 
             UndirectedEdge[17, 28] -> 
             RGBColor[
              0.2668075494695581, 0.39776202944116235`, 0.938505667284669], 
             UndirectedEdge[89, 118] -> 
             RGBColor[
              0.8836498800355815, 0.6748620936624041, 0.59546480538561], 
             UndirectedEdge[123, 163] -> 
             RGBColor[
              0.2417268008308885, 0.37140057241061075`, 0.9370773557533394], 
             UndirectedEdge[47, 157] -> 
             RGBColor[
              0.5046032669357259, 0.6086499170733246, 0.9541568402025347], 
             UndirectedEdge[117, 151] -> 
             RGBColor[
              0.565437397706639, 0.6532390613039136, 0.9611245836688005], 
             UndirectedEdge[69, 86] -> 
             RGBColor[
              0.39677259596818604`, 0.5180862130822859, 0.9465029768562303], 
             UndirectedEdge[73, 94] -> 
             RGBColor[
              0.35563109287921313`, 0.4810081428778644, 0.9439343254346236], 
             UndirectedEdge[61, 174] -> 
             RGBColor[
              0.3276038093333696, 0.4549444137194375, 0.9422139156652158], 
             UndirectedEdge[175, 187] -> 
             RGBColor[
              0.3016125136762855, 0.4332669561847139, 0.940527203641994], 
             UndirectedEdge[75, 134] -> 
             RGBColor[
              0.2575067829018646, 0.3879863340758565, 0.93797600238789], 
             UndirectedEdge[38, 178] -> 
             RGBColor[
              0.9536200808381681, 0.9247692797301834, 0.650059594771984], 
             UndirectedEdge[8, 179] -> 
             RGBColor[
              0.6280655556399748, 0.706255507224953, 0.9656353303034069], 
             UndirectedEdge[29, 167] -> 
             RGBColor[
              0.9544593958943188, 0.963459656199136, 0.8733980891466777], 
             UndirectedEdge[68, 185] -> 
             RGBColor[
              0.8125990681630673, 0.8538159065524649, 0.9818794937101938], 
             UndirectedEdge[79, 118] -> 
             RGBColor[
              0.5586378396004057, 0.632712242954274, 0.9632601689433578], 
             UndirectedEdge[171, 173] -> 
             RGBColor[
              0.9348057885377076, 0.9473795452457701, 0.8502201026491867], 
             UndirectedEdge[80, 166] -> 
             RGBColor[
              0.5054107612208105, 0.6076601192871327, 0.9546750264349914], 
             UndirectedEdge[109, 132] -> 
             RGBColor[
              0.2948786821955154, 0.42460409000948357`, 0.9402017631916271], 
             UndirectedEdge[118, 197] -> 
             RGBColor[
              0.9011122603260905, 0.9239864726160629, 0.9904300858939554], 
             UndirectedEdge[111, 167] -> 
             RGBColor[
              0.687885792752501, 0.7540851723545239, 0.971226039036996], 
             UndirectedEdge[113, 122] -> 
             RGBColor[
              0.9466202120897103, 0.8137405258050889, 0.35564035163633406`], 
             UndirectedEdge[119, 190] -> 
             RGBColor[
              0.3722927166990131, 0.48192331493748153`, 0.946216932235511], 
             UndirectedEdge[19, 130] -> 
             RGBColor[
              0.2508128361327613, 0.38095057160079043`, 0.9375947920221963], 
             UndirectedEdge[35, 167] -> 
             RGBColor[
              0.876824539183936, 0.9046201030499366, 0.9881135013695121], 
             UndirectedEdge[102, 112] -> 
             RGBColor[
              0.337642108559284, 0.46619572637249007`, 0.9427599360129698], 
             UndirectedEdge[134, 145] -> 
             RGBColor[
              0.21930399653046173`, 0.34783278340295676`, 0.9358004102199964],
              UndirectedEdge[109, 150] -> 
             RGBColor[
              0.31023488720570846`, 0.44074443511482886`, 0.941076276349488], 
             UndirectedEdge[147, 179] -> 
             RGBColor[
              0.6443148010184508, 0.7195864135989113, 0.9668761140974684], 
             UndirectedEdge[63, 102] -> 
             RGBColor[
              0.3633436999904507, 0.48913178357153686`, 0.9443729171645411], 
             UndirectedEdge[62, 182] -> 
             RGBColor[
              0.31067915117154543`, 0.43948321209576313`, 0.9411648533902153],
              UndirectedEdge[8, 99] -> 
             RGBColor[
              0.5061464386241231, 0.6098124694135529, 0.9543032645305172], 
             UndirectedEdge[60, 123] -> 
             RGBColor[
              0.252194354195388, 0.3824026346779154, 0.9376734674320901], 
             UndirectedEdge[7, 97] -> 
             RGBColor[
              0.3157107895654947, 0.44530567947641203`, 0.9414318491903908], 
             UndirectedEdge[130, 163] -> 
             RGBColor[
              0.23512312567678792`, 0.3644596911264634, 0.9367012862225752], 
             UndirectedEdge[127, 135] -> 
             RGBColor[
              0.2774333145415366, 0.4077430848237163, 0.9391542616607926], 
             UndirectedEdge[37, 56] -> 
             RGBColor[
              0.18496037439835666`, 0.3117354590307041, 0.9338445917464089], 
             UndirectedEdge[100, 148] -> 
             RGBColor[
              0.20930368592266696`, 0.3373218228978505, 0.9352309073250162], 
             UndirectedEdge[53, 135] -> 
             RGBColor[
              0.222345629185322, 0.35102973217386374`, 0.9359736266999984], 
             UndirectedEdge[103, 154] -> 
             RGBColor[
              0.9254091486755369, 0.7326773288061676, 0.5407051440124293], 
             UndirectedEdge[63, 140] -> 
             RGBColor[
              0.32917806589633525`, 0.4592394517547229, 0.942206889467927], 
             UndirectedEdge[8, 75] -> 
             RGBColor[
              0.36617940457524284`, 0.4893149172044077, 0.9446368318260574], 
             UndirectedEdge[50, 53] -> 
             RGBColor[
              0.22682228238214364`, 0.3557349785199296, 0.9362285654769424], 
             UndirectedEdge[1, 167] -> 
             RGBColor[
              0.9367941803977453, 0.9031603919681208, 0.6421668592196352], 
             UndirectedEdge[27, 119] -> 
             RGBColor[
              0.4208137004428272, 0.5329219452602844, 0.9489801304793581], 
             UndirectedEdge[96, 126] -> 
             RGBColor[
              0.3067108401441868, 0.4397029179549527, 0.9407781006569607], 
             UndirectedEdge[102, 106] -> 
             RGBColor[
              0.32444342089519307`, 0.4523230687923987, 0.9420082902762085], 
             UndirectedEdge[16, 176] -> 
             RGBColor[
              0.30857911035131147`, 0.440352288288518, 0.9409326188466578], 
             UndirectedEdge[40, 166] -> 
             RGBColor[
              0.4412529384384768, 0.5555739084754552, 0.9496242876077174], 
             UndirectedEdge[33, 90] -> 
             RGBColor[
              0.35549444310349765`, 0.4823331517711803, 0.9438727694565298], 
             UndirectedEdge[13, 161] -> 
             RGBColor[
              0.34332913853017627`, 0.471788129604329, 0.9430979016389265], 
             UndirectedEdge[11, 106] -> 
             RGBColor[
              0.2604570991427524, 0.3910873035058834, 0.9381440185332068], 
             UndirectedEdge[88, 167] -> 
             RGBColor[
              0.8137351892886164, 0.8551855895073546, 0.9818647874444291], 
             UndirectedEdge[29, 159] -> 
             RGBColor[
              0.9081437399557057, 0.5833500342919629, 0.46216641584665136`], 
             UndirectedEdge[156, 157] -> 
             RGBColor[
              0.7392642763541118, 0.795756249521131, 0.9753171149779516], 
             UndirectedEdge[171, 183] -> 
             RGBColor[
              0.8671903203612858, 0.6797554080985058, 0.5963535737913382], 
             UndirectedEdge[100, 104] -> 
             RGBColor[
              0.21637454520909913`, 0.34475374432626316`, 0.9356335823009796],
              UndirectedEdge[108, 180] -> 
             RGBColor[
              0.7526503794757171, 0.8066954638919603, 0.9759808139745987], 
             UndirectedEdge[178, 179] -> 
             RGBColor[
              0.8751828122658775, 0.9032348097031484, 0.9819114587531318], 
             UndirectedEdge[150, 151] -> 
             RGBColor[
              0.3174016073666887, 0.4469518879084411, 0.9415329334208639], 
             UndirectedEdge[2, 121] -> 
             RGBColor[
              0.45989815510185605`, 0.5703361338584898, 0.9511956661237368], 
             UndirectedEdge[12, 14] -> 
             RGBColor[
              0.500367704585658, 0.6042677811858945, 0.954084097379875], 
             UndirectedEdge[43, 131] -> 
             RGBColor[
              0.8773120191958123, 0.531003528583677, 0.2191512749676569], 
             UndirectedEdge[75, 76] -> 
             RGBColor[
              0.2802558703962583, 0.4118970674079191, 0.9392715292664366], 
             UndirectedEdge[113, 138] -> 
             RGBColor[
              0.9065388861824932, 0.6660342904889218, 0.24359871478674944`], 
             UndirectedEdge[17, 20] -> 
             RGBColor[
              0.23211977265146783`, 0.3613029766732719, 0.9365302497108459], 
             UndirectedEdge[86, 187] -> 
             RGBColor[
              0.3373933626791634, 0.4642585291932452, 0.9428071277006951], 
             UndirectedEdge[8, 185] -> 
             RGBColor[
              0.6088853490181219, 0.6912717840369921, 0.9637236265565623], 
             UndirectedEdge[4, 41] -> 
             RGBColor[
              0.6772999087061907, 0.7464119016615944, 0.969440899246723], 
             UndirectedEdge[8, 107] -> 
             RGBColor[
              0.5577142065740452, 0.6512964986445926, 0.9586233652992509], 
             UndirectedEdge[149, 192] -> 
             RGBColor[
              0.5254435040297809, 0.2484760819553035, 0.5504153622874323], 
             UndirectedEdge[11, 140] -> 
             RGBColor[
              0.27568296917584306`, 0.40709065828657925`, 0.9390111093069351],
              UndirectedEdge[94, 153] -> 
             RGBColor[
              0.5020487622755229, 0.6056693221783567, 0.9542062732491396], 
             UndirectedEdge[56, 79] -> 
             RGBColor[
              0.1914475761291835, 0.31855391936214905`, 0.9342140282880245], 
             UndirectedEdge[5, 15] -> 
             RGBColor[
              0.303658911440855, 0.4349821137845143, 0.940659697404096], 
             UndirectedEdge[79, 128] -> 
             RGBColor[
              0.5467748334649722, 0.46160555519396695`, 0.5822517523121589], 
             UndirectedEdge[109, 152] -> 
             RGBColor[
              0.3096412804178116, 0.4401205167439052, 0.9410424713210799], 
             UndirectedEdge[118, 192] -> 
             RGBColor[
              0.8653132634712222, 0.5339188235921248, 0.5779056406553331], 
             UndirectedEdge[99, 107] -> 
             RGBColor[
              0.615663269511703, 0.6984811954684678, 0.963146911483036], 
             UndirectedEdge[3, 189] -> 
             RGBColor[
              0.24752736996092756`, 0.37749733834360644`, 0.937407689584122], 
             UndirectedEdge[35, 138] -> 
             RGBColor[
              0.8755744905406526, 0.7829258920824524, 0.6165607268309311], 
             UndirectedEdge[12, 86] -> 
             RGBColor[
              0.4879611145029988, 0.5935218164296439, 0.9532935604305248], 
             UndirectedEdge[16, 127] -> 
             RGBColor[
              0.3222744622049885, 0.4535596740016799, 0.9417560216489524], 
             UndirectedEdge[37, 195] -> 
             RGBColor[
              0.18496037439835666`, 0.3117354590307041, 0.9338445917464089], 
             UndirectedEdge[57, 71] -> 
             RGBColor[
              0.32543061952646807`, 0.4545863786212526, 0.9420196308425695], 
             UndirectedEdge[58, 73] -> 
             RGBColor[
              0.2786440888438728, 0.4102029828035092, 0.9391797406914454], 
             UndirectedEdge[35, 153] -> 
             RGBColor[
              0.7121716897579038, 0.7743580313201439, 0.9724974227780518], 
             UndirectedEdge[35, 122] -> 
             RGBColor[
              0.9156558164478696, 0.9306321273986194, 0.7286023636805157], 
             UndirectedEdge[19, 44] -> 
             RGBColor[
              0.2739128300859531, 0.40523012986980433`, 0.9389103025044521], 
             UndirectedEdge[181, 192] -> 
             RGBColor[
              0.9008244522829545, 0.5609575135409945, 0.536787782228656], 
             UndirectedEdge[119, 128] -> 
             RGBColor[
              0.727229943001779, 0.6245650034241965, 0.5942324445693138], 
             UndirectedEdge[116, 153] -> 
             RGBColor[
              0.48777642817979994`, 0.593307343733011, 0.9532968527410897], 
             UndirectedEdge[186, 193] -> 
             RGBColor[
              0.29935843960625863`, 0.43124092646978174`, 0.9403862732371204],
              UndirectedEdge[22, 119] -> 
             RGBColor[
              0.7046501145612256, 0.5000420883551641, 0.5745300841594067], 
             UndirectedEdge[85, 109] -> 
             RGBColor[
              0.34884904242599657`, 0.47657723971187865`, 0.9434493304016565],
              UndirectedEdge[98, 99] -> 
             RGBColor[
              0.7687919437411839, 0.8183727141912807, 0.944294118700548], 
             UndirectedEdge[161, 175] -> 
             RGBColor[
              0.31452843153509336`, 0.4468424047708116, 0.941262746056665], 
             UndirectedEdge[54, 61] -> 
             RGBColor[
              0.27330173727350593`, 0.40458783257840025`, 0.9388755016728139],
              UndirectedEdge[43, 154] -> 
             RGBColor[
              0.9209464577022384, 0.7076324616463945, 0.536794159970965], 
             UndirectedEdge[87, 95] -> 
             RGBColor[
              0.9838001922594006, 0.9661152059128862, 0.6121532693347048], 
             UndirectedEdge[12, 108] -> 
             RGBColor[
              0.6825976109082605, 0.7510751508326818, 0.9696102227606116], 
             UndirectedEdge[15, 48] -> 
             RGBColor[
              0.32110672796259787`, 0.4525482412929506, 0.9416816146556142], 
             UndirectedEdge[13, 187] -> 
             RGBColor[
              0.33041322067136836`, 0.4582126810182313, 0.9423623592242556], 
             UndirectedEdge[15, 28] -> 
             RGBColor[
              0.3099437764026754, 0.4415879053428414, 0.9410176111660472], 
             UndirectedEdge[52, 134] -> 
             RGBColor[
              0.22165741455534713`, 0.35030637496243233`, 0.9359344338949436],
              UndirectedEdge[66, 172] -> 
             RGBColor[
              0.8427983522117647, 0.874271591791478, 0.7778392040313489], 
             UndirectedEdge[101, 176] -> 
             RGBColor[
              0.27302063754770944`, 0.4042923789438361, 0.9388594934592795], 
             UndirectedEdge[119, 192] -> 
             RGBColor[
              0.6910986856659902, 0.39587986759237864`, 0.5615532205451794], 
             UndirectedEdge[168, 184] -> 
             RGBColor[
              0.6548626736277727, 0.7248006680529328, 0.9668502718111599], 
             UndirectedEdge[16, 175] -> 
             RGBColor[
              0.3216795898869629, 0.4530444254989581, 0.9417181169108728], 
             UndirectedEdge[60, 104] -> 
             RGBColor[
              0.23644603942151277`, 0.3658501573497452, 0.9367766242032618], 
             UndirectedEdge[122, 136] -> 
             RGBColor[
              0.9504725003418423, 0.8301441328600938, 0.35879847629145456`], 
             UndirectedEdge[107, 157] -> 
             RGBColor[
              0.6124579217372135, 0.6958789497458655, 0.9628945747646525], 
             UndirectedEdge[86, 110] -> 
             RGBColor[
              0.49849330988433693`, 0.6020723271102092, 0.9541226934316467], 
             UndirectedEdge[5, 9] -> 
             RGBColor[
              0.27138694905370225`, 0.40257526875480143`, 0.9387664573163714],
              UndirectedEdge[3, 77] -> 
             RGBColor[
              0.2820287158723724, 0.41376044040821036`, 0.9393724901936115], 
             UndirectedEdge[84, 139] -> 
             RGBColor[
              0.25596738815303377`, 0.386368332591571, 0.9378883361342745], 
             UndirectedEdge[96, 191] -> 
             RGBColor[
              0.29321373700723585`, 0.4255166067922517, 0.9400094606004861], 
             UndirectedEdge[46, 151] -> 
             RGBColor[
              0.4748094471252997, 0.581756348874845, 0.9525589277610778], 
             UndirectedEdge[72, 191] -> 
             RGBColor[
              0.2650536461439216, 0.3959185658420248, 0.9384057850849414], 
             UndirectedEdge[111, 185] -> 
             RGBColor[
              0.6150345673164899, 0.6964030334262838, 0.9641692992212595], 
             UndirectedEdge[23, 129] -> 
             RGBColor[
              0.9919194200162629, 0.9837402828928126, 0.4795846817261888], 
             UndirectedEdge[101, 123] -> 
             RGBColor[
              0.2511378900976988, 0.38129222392755147`, 0.9376133033646252], 
             UndirectedEdge[122, 142] -> 
             RGBColor[
              0.8169136872538085, 0.8533228738878083, 0.7188155094580211], 
             UndirectedEdge[18, 174] -> 
             RGBColor[
              0.3498905326098686, 0.47747932616232985`, 0.9435156932352192], 
             UndirectedEdge[123, 135] -> 
             RGBColor[
              0.24185521523784892`, 0.3715355440942698, 0.9370846687638437], 
             UndirectedEdge[171, 178] -> 
             RGBColor[
              0.9084510251565888, 0.9296645818194842, 0.9851104569792455], 
             UndirectedEdge[81, 173] -> 
             RGBColor[
              0.7857376160501509, 0.8294745429756838, 0.8361707611374197], 
             UndirectedEdge[77, 102] -> 
             RGBColor[
              0.33711449602806876`, 0.4656411721496162, 0.9427298892598499], 
             UndirectedEdge[31, 171] -> 
             RGBColor[
              0.8624892635832501, 0.8931895434066397, 0.9867461899854671], 
             UndirectedEdge[109, 196] -> 
             RGBColor[
              0.4163582231260193, 0.5339138255247312, 0.9480649666862233], 
             UndirectedEdge[18, 153] -> 
             RGBColor[
              0.4521702655292919, 0.5624670752629113, 0.9510280595422927], 
             UndirectedEdge[97, 140] -> 
             RGBColor[
              0.29323255505263285`, 0.42553638575109687`, 0.9400105322603325],
              UndirectedEdge[116, 167] -> 
             RGBColor[
              0.652429277605832, 0.7235694154628036, 0.96891293133255], 
             UndirectedEdge[128, 190] -> 
             RGBColor[
              0.5346442883688116, 0.44885558317692076`, 0.5815609357144658], 
             UndirectedEdge[94, 126] -> 
             RGBColor[
              0.3626762195061153, 0.4884130176495661, 0.9443355349736948], 
             UndirectedEdge[41, 198] -> 
             RGBColor[
              0.6229374569936681, 0.7039435412138363, 0.9640225581060137], 
             UndirectedEdge[11, 77] -> 
             RGBColor[
              0.27312817427562797`, 0.40440540686310084`, 0.9388656175168482],
              UndirectedEdge[29, 122] -> 
             RGBColor[
              0.9932906731582525, 0.9894716805478189, 0.6138869514576812], 
             UndirectedEdge[84, 152] -> 
             RGBColor[
              0.2722580627952489, 0.4034908645289682, 0.9388160659552552], 
             UndirectedEdge[16, 64] -> 
             RGBColor[
              0.47278195616545676`, 0.5793252259853976, 0.9526162456912082], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.23972819328057, 0.3692999091561883, 0.9369635380100236], 
             UndirectedEdge[26, 121] -> 
             RGBColor[
              0.46953919243500225`, 0.5786867158238351, 0.9518099844973704], 
             UndirectedEdge[40, 74] -> 
             RGBColor[
              0.3971820108095485, 0.5168505289536836, 0.9468363149531384], 
             UndirectedEdge[78, 91] -> 
             RGBColor[
              0.8828910750951913, 0.909457394113841, 0.9886921329803882], 
             UndirectedEdge[139, 152] -> 
             RGBColor[
              0.26544888260262894`, 0.3963339844195651, 0.9384282932165648], 
             UndirectedEdge[40, 196] -> 
             RGBColor[
              0.49337743215923585`, 0.5995850516837207, 0.9532596252421102], 
             UndirectedEdge[6, 86] -> 
             RGBColor[
              0.3660057031110193, 0.4914374768784062, 0.9445425376494667], 
             UndirectedEdge[82, 180] -> 
             RGBColor[
              0.5213332999548519, 0.6173712520138998, 0.9573268973237518], 
             UndirectedEdge[44, 90] -> 
             RGBColor[
              0.33568645678912695`, 0.46283528505433924`, 0.9426963443190322],
              UndirectedEdge[4, 66] -> 
             RGBColor[
              0.7482528569010358, 0.8032600858342098, 0.9755425100215394], 
             UndirectedEdge[131, 143] -> 
             RGBColor[
              0.8600285523135855, 0.398155228463402, 0.20260060756235265`], 
             UndirectedEdge[22, 144] -> 
             RGBColor[
              0.8504688767152189, 0.38893147880177464`, 0.1959623593799244], 
             UndirectedEdge[35, 160] -> 
             RGBColor[
              0.6025425418355174, 0.6830045883363345, 0.9645167582458221], 
             UndirectedEdge[76, 174] -> 
             RGBColor[
              0.3288804579296929, 0.4562862523383694, 0.9422866189141441], 
             UndirectedEdge[85, 196] -> 
             RGBColor[
              0.42766426196123664`, 0.5437065481057618, 0.9487853774832657], 
             UndirectedEdge[6, 137] -> 
             RGBColor[
              0.2951194473890727, 0.4246251929966973, 0.9402239674768278], 
             UndirectedEdge[123, 177] -> 
             RGBColor[
              0.27201910823742403`, 0.40323970813810023`, 0.9388024578466887],
              UndirectedEdge[29, 113] -> 
             RGBColor[
              0.946972557498295, 0.8159080843147557, 0.4967685640741427], 
             UndirectedEdge[96, 174] -> 
             RGBColor[
              0.3438036499941711, 0.471971473383162, 0.943136472625332], 
             UndirectedEdge[74, 158] -> 
             RGBColor[
              0.2780238238703263, 0.40955104498924105`, 0.9391444175188017], 
             UndirectedEdge[46, 121] -> 
             RGBColor[
              0.570208977683367, 0.6619603615618923, 0.9593080859489944], 
             UndirectedEdge[32, 165] -> 
             RGBColor[
              0.2270272954930984, 0.35595046029812505`, 0.9362402406703216], 
             UndirectedEdge[32, 148] -> 
             RGBColor[
              0.219972379693155, 0.3485352964848875, 0.9358384736523275], 
             UndirectedEdge[27, 190] -> 
             RGBColor[
              0.22822804580985986`, 0.3572125250130086, 0.9363086216245102], 
             UndirectedEdge[100, 123] -> 
             RGBColor[
              0.23212285998297438`, 0.3613062216544334, 0.9365304255298079], 
             UndirectedEdge[45, 172] -> 
             RGBColor[
              0.9391683499060914, 0.7786563284917088, 0.4055000051193155], 
             UndirectedEdge[85, 99] -> 
             RGBColor[
              0.4621252914114974, 0.5716835642651686, 0.9514982759565006], 
             UndirectedEdge[106, 112] -> 
             RGBColor[
              0.2882506044320779, 0.42030003977498026`, 0.9397268175426274], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.9113560881636262, 0.6286546059959026, 0.5149270286793647], 
             UndirectedEdge[43, 197] -> 
             RGBColor[
              0.8721411848386535, 0.6704152078814393, 0.5949590715355129], 
             UndirectedEdge[26, 164] -> 
             RGBColor[
              0.34556297092325194`, 0.47243449330876475`, 0.9432874166489127],
              UndirectedEdge[100, 130] -> 
             RGBColor[
              0.2255191848288738, 0.3543653403702861, 0.9361543559990437], 
             UndirectedEdge[46, 196] -> 
             RGBColor[
              0.5464579464995596, 0.642678204475116, 0.9574383177713113], 
             UndirectedEdge[156, 181] -> 
             RGBColor[
              0.9525868256306654, 0.9637539256660137, 0.9508348285678401], 
             UndirectedEdge[62, 96] -> 
             RGBColor[
              0.33121568258703066`, 0.4610684087047351, 0.9423343784732514], 
             UndirectedEdge[54, 58] -> 
             RGBColor[
              0.2684799532608956, 0.3995198318623828, 0.9386009082064859], 
             UndirectedEdge[179, 183] -> 
             RGBColor[
              0.8339221074705745, 0.65332563598217, 0.5931545755652246], 
             UndirectedEdge[65, 198] -> 
             RGBColor[
              0.809127231953634, 0.8516409245369697, 0.9813908857977319], 
             UndirectedEdge[4, 80] -> 
             RGBColor[
              0.7123913946505943, 0.7749007508046878, 0.972203429564615], 
             UndirectedEdge[159, 197] -> 
             RGBColor[
              0.8557807275271554, 0.5446615637871581, 0.5792922791375287], 
             UndirectedEdge[78, 136] -> 
             RGBColor[
              0.9179856014839756, 0.8091909436388446, 0.6189147464565151], 
             UndirectedEdge[153, 188] -> 
             RGBColor[
              0.6253120347428027, 0.7063539747569785, 0.9638795069847599], 
             UndirectedEdge[35, 174] -> 
             RGBColor[
              0.6098919568384804, 0.6893702822195625, 0.9649850564709783], 
             UndirectedEdge[82, 130] -> 
             RGBColor[
              0.27791125977355285`, 0.4085218087190706, 0.9391713605597196], 
             UndirectedEdge[124, 176] -> 
             RGBColor[
              0.29262570831728996`, 0.4248985513559462, 0.9399759732365041], 
             UndirectedEdge[6, 186] -> 
             RGBColor[
              0.3110411018029656, 0.4413598612768941, 0.941130682141722], 
             UndirectedEdge[1, 144] -> 
             RGBColor[
              0.9074142416068287, 0.6532261133367169, 0.24715284778639957`], 
             UndirectedEdge[43, 67] -> 
             RGBColor[
              0.8367855353364704, 0.2837553208862874, 0.18285917622251102`], 
             UndirectedEdge[24, 119] -> 
             RGBColor[
              0.37190268708568275`, 0.48151336908456555`, 0.9461947206260288],
              UndirectedEdge[93, 139] -> 
             RGBColor[
              0.2366529007205347, 0.36606758169078113`, 0.9367884046482173], 
             UndirectedEdge[38, 146] -> 
             RGBColor[
              0.8804514017100027, 0.8667932734581691, 0.6490490676279728], 
             UndirectedEdge[110, 127] -> 
             RGBColor[
              0.46330733319948464`, 0.5715960026043997, 0.9518806741110254], 
             UndirectedEdge[41, 81] -> 
             RGBColor[
              0.563023955866433, 0.6561272371693612, 0.9587424547119633], 
             UndirectedEdge[85, 194] -> 
             RGBColor[
              0.35434213313173446`, 0.48133507879042225`, 0.9437993452840767],
              UndirectedEdge[52, 70] -> 
             RGBColor[
              0.2130689137116028, 0.34127931603325223`, 0.9354453314774407], 
             UndirectedEdge[149, 170] -> 
             RGBColor[
              0.2079666859588458, 0.3359165511651807, 0.9351547671549908], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.30721338060851633`, 0.43871808624608816`, 0.9408621191648285],
              UndirectedEdge[92, 155] -> 
             RGBColor[
              0.23916918979888965`, 0.36871236105407446`, 0.9369317035887135],
              UndirectedEdge[57, 141] -> 
             RGBColor[
              0.35995825064388254`, 0.48619947750517123`, 0.9441571993258131],
              UndirectedEdge[149, 159] -> 
             RGBColor[
              0.5281062347020681, 0.2689429967185235, 0.5529651961863387], 
             UndirectedEdge[142, 167] -> 
             RGBColor[
              0.7780824099898748, 0.8273108495391253, 0.9783266471470176], 
             UndirectedEdge[117, 173] -> 
             RGBColor[
              0.8870698836005233, 0.9096475021441977, 0.8455791000881498], 
             UndirectedEdge[99, 179] -> 
             RGBColor[
              0.6860146185776324, 0.753440204048828, 0.970158876487192], 
             UndirectedEdge[5, 11] -> 
             RGBColor[
              0.2640346736892395, 0.39484756118556874`, 0.938347756111082], 
             UndirectedEdge[29, 188] -> 
             RGBColor[
              0.8291485068413533, 0.8647956293451209, 0.8611126603250323], 
             UndirectedEdge[46, 178] -> 
             RGBColor[
              0.7700871696380653, 0.8204498262888431, 0.9719037985104857], 
             UndirectedEdge[101, 137] -> 
             RGBColor[
              0.25101571036429215`, 0.3811638052810985, 0.9376063454095565], 
             UndirectedEdge[3, 20] -> 
             RGBColor[
              0.24453230342971405`, 0.374349333521115, 0.9372371249759732], 
             UndirectedEdge[186, 199] -> 
             RGBColor[
              0.2771594494145085, 0.4086425326316706, 0.9390951926722704], 
             UndirectedEdge[156, 179] -> 
             RGBColor[
              0.864388741144453, 0.8948015330551333, 0.986901517469225], 
             UndirectedEdge[67, 87] -> 
             RGBColor[
              0.9030901336605541, 0.565118857520931, 0.5070115413121625], 
             UndirectedEdge[3, 10] -> 
             RGBColor[
              0.27648968445364525`, 0.4079385671922522, 0.9390570505485776], 
             UndirectedEdge[55, 185] -> 
             RGBColor[
              0.5609776882411449, 0.6497765761810184, 0.9606709927749343], 
             UndirectedEdge[5, 28] -> 
             RGBColor[
              0.28849193082278163`, 0.4205536891125868, 0.9397405607235676], 
             UndirectedEdge[37, 170] -> 
             RGBColor[
              0.18667955632742156`, 0.31354242824058126`, 0.9339424966139673],
              UndirectedEdge[49, 154] -> 
             RGBColor[
              0.9106325715742103, 0.628355413292651, 0.5269175709668971], 
             UndirectedEdge[24, 89] -> 
             RGBColor[
              0.5164596179840519, 0.3607037715624661, 0.5664186648111262], 
             UndirectedEdge[73, 115] -> 
             RGBColor[
              0.27934432739444803`, 0.41093897791785206`, 0.9392196182409905],
              UndirectedEdge[153, 174] -> 
             RGBColor[
              0.4836903414503127, 0.5897681807806197, 0.9530364909078715], 
             UndirectedEdge[119, 183] -> 
             RGBColor[
              0.7123944253398227, 0.5572003826444346, 0.5818533249803631], 
             UndirectedEdge[4, 168] -> 
             RGBColor[
              0.8717390399773187, 0.9006124860515876, 0.9850092222919777], 
             UndirectedEdge[144, 181] -> 
             RGBColor[
              0.920422900102938, 0.7115997715799838, 0.5555552779943531], 
             UndirectedEdge[53, 123] -> 
             RGBColor[
              0.2309218560021901, 0.36004389032257866`, 0.9364620301298284], 
             UndirectedEdge[110, 162] -> 
             RGBColor[
              0.7939641442587955, 0.8384977959010833, 0.9379384858342741], 
             UndirectedEdge[127, 176] -> 
             RGBColor[
              0.3078922888084153, 0.4397573979887158, 0.940888855185277], 
             UndirectedEdge[9, 102] -> 
             RGBColor[
              0.31720087863442126`, 0.44471069767262583`, 0.9415958382088386],
              UndirectedEdge[27, 195] -> 
             RGBColor[
              0.22783801477683696`, 0.3568025776679057, 0.9362864099341788], 
             UndirectedEdge[60, 130] -> 
             RGBColor[
              0.2455906790412874, 0.3754617533937681, 0.9372973979013259], 
             UndirectedEdge[89, 122] -> 
             RGBColor[
              0.9234652804391932, 0.7016588310893552, 0.3360475342402131], 
             UndirectedEdge[5, 106] -> 
             RGBColor[
              0.2786294913144741, 0.4101876398745743, 0.9391789093837413], 
             UndirectedEdge[83, 199] -> 
             RGBColor[
              0.2640684264301843, 0.3948830374563491, 0.938349678279746], 
             UndirectedEdge[118, 125] -> 
             RGBColor[
              0.5461336776674304, 0.6195695759530597, 0.9625480754195246], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.2678093745072151, 0.3988150110751161, 0.9385627197384963], 
             UndirectedEdge[5, 112] -> 
             RGBColor[
              0.29182817897856506`, 0.4240602974546656, 0.9399305551205026], 
             UndirectedEdge[109, 146] -> 
             RGBColor[
              0.5668187671363596, 0.653709441066444, 0.9615199202813867], 
             UndirectedEdge[164, 184] -> 
             RGBColor[
              0.33292802569279517`, 0.46149073880095526`, 0.9424823291114712],
              UndirectedEdge[51, 164] -> 
             RGBColor[
              0.28843151316149873`, 0.42049018631987756`, 0.9397371200271375],
              UndirectedEdge[45, 168] -> 
             RGBColor[
              0.9114761724933723, 0.7607551980488345, 0.6070253886431892], 
             UndirectedEdge[148, 165] -> 
             RGBColor[
              0.2118480097340456, 0.33999606854305653`, 0.9353758028020844], 
             UndirectedEdge[166, 184] -> 
             RGBColor[
              0.3810287222999791, 0.5044496610209838, 0.9454997911478531], 
             UndirectedEdge[21, 132] -> 
             RGBColor[
              0.28420798371714023`, 0.41536166731241486`, 0.9395218357203131],
              UndirectedEdge[96, 157] -> 
             RGBColor[
              0.43194074873512733`, 0.5454775949392545, 0.9495354789637005], 
             UndirectedEdge[42, 102] -> 
             RGBColor[
              0.4476381958746549, 0.5602937273030086, 0.9502551687958871], 
             UndirectedEdge[117, 120] -> 
             RGBColor[
              0.8678835994276715, 0.8465560061197337, 0.6325812491960736], 
             UndirectedEdge[25, 129] -> 
             RGBColor[
              0.9845905971173718, 0.9596826071563495, 0.39463780893289646`], 
             UndirectedEdge[57, 90] -> 
             RGBColor[
              0.37426337273503046`, 0.49858985526418154`, 0.9450687090559382],
              UndirectedEdge[51, 184] -> 
             RGBColor[
              0.3266364768489205, 0.4548779220588064, 0.942124034712325], 
             UndirectedEdge[95, 103] -> 
             RGBColor[
              0.9219582849086154, 0.7097965364380157, 0.2919118882865176], 
             UndirectedEdge[47, 105] -> 
             RGBColor[
              0.3973660260121461, 0.5186002123597028, 0.9465407896938819], 
             UndirectedEdge[127, 177] -> 
             RGBColor[
              0.3075972075411117, 0.4394472488675467, 0.9408720507436377], 
             UndirectedEdge[73, 153] -> 
             RGBColor[
              0.4395524049734263, 0.5500947505807087, 0.9502769094004289], 
             UndirectedEdge[137, 199] -> 
             RGBColor[
              0.26123779500061556`, 0.39190786435147384`, 0.9381884780073761],
              UndirectedEdge[138, 185] -> 
             RGBColor[
              0.8411744991425061, 0.7559037234450623, 0.613171500043548], 
             UndirectedEdge[88, 136] -> 
             RGBColor[
              0.8101006391447247, 0.7240376246779792, 0.6083933870270145], 
             UndirectedEdge[55, 76] -> 
             RGBColor[
              0.31436618073050393`, 0.4437147149372155, 0.9413617820054831], 
             UndirectedEdge[135, 176] -> 
             RGBColor[
              0.26373796268785954`, 0.3945356991105544, 0.938330858858498], 
             UndirectedEdge[69, 123] -> 
             RGBColor[
              0.3260085199796461, 0.4514023478470298, 0.9421913646386602], 
             UndirectedEdge[2, 40] -> 
             RGBColor[
              0.43435111341602517`, 0.5495958945368197, 0.9491845094203311], 
             UndirectedEdge[105, 174] -> 
             RGBColor[
              0.3623104663482657, 0.48823684852250904`, 0.9443070804305137], 
             UndirectedEdge[89, 138] -> 
             RGBColor[
              0.8833839545319762, 0.5539525957731882, 0.22400589739062848`], 
             UndirectedEdge[37, 128] -> 
             RGBColor[
              0.5402876317341454, 0.454787094862522, 0.5818823157705433], 
             UndirectedEdge[88, 153] -> 
             RGBColor[
              0.6490823398625842, 0.7249235177775619, 0.9662487088529688], 
             UndirectedEdge[113, 197] -> 
             RGBColor[
              0.8946095450697447, 0.7772196138099509, 0.6138944273650201], 
             UndirectedEdge[31, 178] -> 
             RGBColor[
              0.8964701273649321, 0.9201113391332241, 0.9839677082524034], 
             UndirectedEdge[82, 177] -> 
             RGBColor[
              0.3061026011103605, 0.4381526958983335, 0.9407768157434988], 
             UndirectedEdge[87, 108] -> 
             RGBColor[
              0.8846035797290293, 0.9091596462519311, 0.913892802031036], 
             UndirectedEdge[64, 86] -> 
             RGBColor[
              0.5072811113074129, 0.6092066601914048, 0.9548145013504485], 
             UndirectedEdge[116, 157] -> 
             RGBColor[
              0.47363379400133276`, 0.5818257161885222, 0.9521834927723848], 
             UndirectedEdge[120, 168] -> 
             RGBColor[
              0.9476806026150666, 0.909778086957847, 0.6376934323137864], 
             UndirectedEdge[18, 54] -> 
             RGBColor[
              0.295588460550005, 0.42712274502129255`, 0.9401772792428172], 
             UndirectedEdge[161, 176] -> 
             RGBColor[
              0.301427951999442, 0.43415026756037145`, 0.9404772479924501], 
             UndirectedEdge[168, 172] -> 
             RGBColor[
              0.9662845352880476, 0.9716239920088556, 0.7873059163017873], 
             UndirectedEdge[142, 157] -> 
             RGBColor[
              0.5992869263853755, 0.6855671502648439, 0.9615972085868523], 
             UndirectedEdge[121, 171] -> 
             RGBColor[
              0.7085728332018904, 0.7711751170925334, 0.9725147444177542], 
             UndirectedEdge[47, 94] -> 
             RGBColor[
              0.4348245890199799, 0.551044936914969, 0.9489276162054343], 
             UndirectedEdge[70, 93] -> 
             RGBColor[
              0.21891136206643785`, 0.34742009968680476`, 0.9357780502681208],
              UndirectedEdge[32, 163] -> 
             RGBColor[
              0.23408691252963393`, 0.3633705654090964, 0.9366422754167848], 
             UndirectedEdge[35, 142] -> 
             RGBColor[
              0.7396311759520104, 0.7966508792482756, 0.9746591341186641], 
             UndirectedEdge[12, 193] -> 
             RGBColor[
              0.4503245613855142, 0.5609229257874412, 0.950895392546576], 
             UndirectedEdge[35, 94] -> 
             RGBColor[
              0.6282503776636906, 0.7052714236172997, 0.9661548388122466], 
             UndirectedEdge[116, 174] -> 
             RGBColor[
              0.38549669526037655`, 0.5083195946324296, 0.9457844864340161], 
             UndirectedEdge[112, 140] -> 
             RGBColor[
              0.30347647446516857`, 0.4363033945556761, 0.9405939083163557], 
             UndirectedEdge[86, 176] -> 
             RGBColor[
              0.3430782654932676, 0.4702337224945253, 0.9431308745058982], 
             UndirectedEdge[61, 73] -> 
             RGBColor[
              0.28346587285648317`, 0.41527098351952657`, 0.9394543341577734],
              UndirectedEdge[33, 66] -> 
             RGBColor[
              0.5073300220022017, 0.606620425388813, 0.955851339828218], 
             UndirectedEdge[48, 106] -> 
             RGBColor[
              0.29607730783621694`, 0.42775376738301063`, 0.9402008266352594],
              UndirectedEdge[86, 199] -> 
             RGBColor[
              0.3321240507225622, 0.4587201482331828, 0.9425070481800151], 
             UndirectedEdge[10, 59] -> 
             RGBColor[
              0.3690604515059446, 0.4922869105332728, 0.9448029598331952], 
             UndirectedEdge[1, 113] -> 
             RGBColor[
              0.9293073420017215, 0.7556088200837405, 0.2655373341471002], 
             UndirectedEdge[125, 128] -> 
             RGBColor[
              0.5342706715319968, 0.44846288819275276`, 0.5815396587883258], 
             UndirectedEdge[53, 165] -> 
             RGBColor[
              0.21515759774182608`, 0.3434746553792333, 0.935564278943031], 
             UndirectedEdge[87, 143] -> 
             RGBColor[
              0.9043865074094275, 0.5750833542293711, 0.5082529502781284], 
             UndirectedEdge[61, 105] -> 
             RGBColor[
              0.30850366715074595`, 0.4384008305619083, 0.9409968714949317], 
             UndirectedEdge[29, 47] -> 
             RGBColor[
              0.7225823732127437, 0.7785731992059557, 0.8525033535115121], 
             UndirectedEdge[24, 27] -> 
             RGBColor[
              0.22783801619652955`, 0.3568025791600926, 0.9362864100150281], 
             UndirectedEdge[98, 117] -> 
             RGBColor[
              0.8762433687105626, 0.9035134810174441, 0.9541841801385145], 
             UndirectedEdge[1, 88] -> 
             RGBColor[
              0.8352535964645615, 0.823065908134689, 0.6322506322661987], 
             UndirectedEdge[190, 195] -> 
             RGBColor[
              0.1793170310330229, 0.30580394734510286`, 0.9335232116903315], 
             UndirectedEdge[4, 173] -> 
             RGBColor[
              0.9000135688899087, 0.9197592074679171, 0.8468692056721795], 
             UndirectedEdge[81, 164] -> 
             RGBColor[
              0.43552843920258344`, 0.5470178923073767, 0.9499428350575294], 
             UndirectedEdge[82, 123] -> 
             RGBColor[
              0.28451493492765345`, 0.4154626900032179, 0.9395474300904838], 
             UndirectedEdge[43, 87] -> 
             RGBColor[
              0.9216699742916543, 0.7079316543496461, 0.5248036176834326], 
             UndirectedEdge[38, 171] -> 
             RGBColor[
              0.919639217056486, 0.8978474840035989, 0.6528380765050477], 
             UndirectedEdge[46, 85] -> 
             RGBColor[
              0.4789487657995369, 0.5853416186622634, 0.9528226814867443], 
             UndirectedEdge[64, 69] -> 
             RGBColor[
              0.512094113243802, 0.613375440560194, 0.9551211815778647], 
             UndirectedEdge[60, 82] -> 
             RGBColor[
              0.2862778470683244, 0.4173156224381487, 0.9396478253289002], 
             UndirectedEdge[77, 189] -> 
             RGBColor[
              0.2658927211222934, 0.3968004868447199, 0.9384535691636595], 
             UndirectedEdge[101, 187] -> 
             RGBColor[
              0.2673357347336053, 0.3983171856425559, 0.9385357466540765], 
             UndirectedEdge[64, 161] -> 
             RGBColor[
              0.4656307978135873, 0.573123205257251, 0.9521608748370004], 
             UndirectedEdge[7, 160] -> 
             RGBColor[
              0.3585859521924276, 0.48501086156024664`, 0.9440697576819622], 
             UndirectedEdge[16, 83] -> 
             RGBColor[
              0.2894048145974629, 0.4201988877306557, 0.9398406710693048], 
             UndirectedEdge[13, 124] -> 
             RGBColor[
              0.3345268948480242, 0.4625364133999037, 0.9425966268829805], 
             UndirectedEdge[46, 171] -> 
             RGBColor[
              0.7361063058563833, 0.7935280305622586, 0.9746822802435494], 
             UndirectedEdge[1, 197] -> 
             RGBColor[
              0.9236147906417135, 0.8926515043216656, 0.6409097972593247], 
             UndirectedEdge[26, 80] -> 
             RGBColor[
              0.5081499735315052, 0.6100326873138424, 0.9548495666212384], 
             UndirectedEdge[23, 43] -> 
             RGBColor[
              0.9244722625683395, 0.7076214459861772, 0.37157972421419916`], 
             UndirectedEdge[13, 86] -> 
             RGBColor[
              0.38497945202400186`, 0.5078715845384828, 0.9457515281523746], 
             UndirectedEdge[31, 146] -> 
             RGBColor[
              0.8233014482367667, 0.8621353328612098, 0.9829571811083924], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.6527715209369094, 0.7286468226851102, 0.9660412183253722], 
             UndirectedEdge[124, 127] -> 
             RGBColor[
              0.30632106017096694`, 0.43810593706910805`, 0.9407993760387987],
              UndirectedEdge[60, 163] -> 
             RGBColor[
              0.24348971297155947`, 0.37325350484554143`, 0.9371777509917558],
              UndirectedEdge[4, 184] -> 
             RGBColor[
              0.5880093557297629, 0.671690292538539, 0.9630281942774768], 
             UndirectedEdge[144, 192] -> 
             RGBColor[
              0.8369174478199836, 0.2847692580389892, 0.18298549576569717`], 
             UndirectedEdge[38, 192] -> 
             RGBColor[
              0.8910636363690327, 0.5135395909571491, 0.2410026071488931], 
             UndirectedEdge[49, 108] -> 
             RGBColor[
              0.8079850952769174, 0.5485190612635439, 0.5798638479373164], 
             UndirectedEdge[83, 165] -> 
             RGBColor[
              0.2373756354905151, 0.36682722175806165`, 0.9368295633241774], 
             UndirectedEdge[183, 192] -> 
             RGBColor[
              0.8386147396738325, 0.29544751505205596`, 0.18451810443518368`],
              UndirectedEdge[79, 159] -> 
             RGBColor[
              0.5133063068014707, 0.25338733412536907`, 0.5521223621869309], 
             UndirectedEdge[81, 166] -> 
             RGBColor[
              0.4836291358097673, 0.5899768145274054, 0.9529602970939112], 
             UndirectedEdge[118, 119] -> 
             RGBColor[
              0.7390929491372125, 0.7956716911845035, 0.9752408612005126], 
             UndirectedEdge[47, 153] -> 
             RGBColor[
              0.518745901114193, 0.6201315446178133, 0.9552702001712396], 
             UndirectedEdge[74, 184] -> 
             RGBColor[
              0.3369577946710508, 0.46572628149921225`, 0.9427118184932739], 
             UndirectedEdge[149, 190] -> 
             RGBColor[
              0.2066375350628038, 0.33451952930040635`, 0.9350790739777637], 
             UndirectedEdge[55, 139] -> 
             RGBColor[
              0.3007701310464627, 0.42942440467994913`, 0.9405875070895301], 
             UndirectedEdge[22, 138] -> 
             RGBColor[
              0.8785987668628523, 0.5171715464656945, 0.2194235962745789], 
             UndirectedEdge[113, 144] -> 
             RGBColor[
              0.8784089960348599, 0.5377942228250021, 0.22013747789209492`], 
             UndirectedEdge[80, 172] -> 
             RGBColor[
              0.8069368899613232, 0.8459122567619559, 0.7745001235744244], 
             UndirectedEdge[8, 156] -> 
             RGBColor[
              0.6845205611909437, 0.7511737984198581, 0.97104590551255], 
             UndirectedEdge[22, 118] -> 
             RGBColor[
              0.8788646923664576, 0.6380810443549103, 0.5908825042695605], 
             UndirectedEdge[100, 163] -> 
             RGBColor[
              0.22341821875914586`, 0.35215709182205945`, 0.9360347090894736],
              UndirectedEdge[12, 154] -> 
             RGBColor[
              0.7852450872055535, 0.8309115028617888, 0.9166639457901922], 
             UndirectedEdge[67, 129] -> 
             RGBColor[
              0.9042326927843938, 0.5598741577929227, 0.2908641337345006], 
             UndirectedEdge[49, 129] -> 
             RGBColor[
              0.9124986472874659, 0.6234099062678943, 0.2987796211017028], 
             UndirectedEdge[127, 175] -> 
             RGBColor[
              0.32099276834406665`, 0.45244953519915593`, 0.9416743532494919],
              UndirectedEdge[30, 198] -> 
             RGBColor[
              0.7949540018905729, 0.840339575606766, 0.9800390304617252], 
             UndirectedEdge[5, 140] -> 
             RGBColor[
              0.2938553613475648, 0.42619099465527016`, 0.9400460001574695], 
             UndirectedEdge[147, 156] -> 
             RGBColor[
              0.7007698065694198, 0.7645047047938165, 0.9722866893066117], 
             UndirectedEdge[122, 159] -> 
             RGBColor[
              0.907791394547121, 0.5811824757822961, 0.3210382034088427], 
             UndirectedEdge[82, 110] -> 
             RGBColor[
              0.4618127267687334, 0.5703014496351865, 0.9517854391108865], 
             UndirectedEdge[83, 176] -> 
             RGBColor[
              0.2750226412008897, 0.4063966117176916, 0.9389735046056292], 
             UndirectedEdge[10, 77] -> 
             RGBColor[
              0.2948550356150111, 0.4272417156933656, 0.9401029301281152], 
             UndirectedEdge[104, 130] -> 
             RGBColor[
              0.2280794521267412, 0.3570563436306672, 0.9363001594340813], 
             UndirectedEdge[30, 66] -> 
             RGBColor[
              0.7926835884248224, 0.8385659113515402, 0.9798127368656795], 
             UndirectedEdge[85, 132] -> 
             RGBColor[
              0.3061847210307328, 0.43439681259051416`, 0.9409221739886695], 
             UndirectedEdge[24, 195] -> 
             RGBColor[
              0.1789270014196926, 0.30539400149218693`, 0.9335010000808495], 
             UndirectedEdge[50, 123] -> 
             RGBColor[
              0.24633186843467056`, 0.37624079044033565`, 0.9373396075407877],
              UndirectedEdge[42, 153] -> 
             RGBColor[
              0.5537057705483233, 0.648562314548655, 0.9580088930300842], 
             UndirectedEdge[127, 161] -> 
             RGBColor[
              0.31512330385311904`, 0.4473576532735334, 0.9413006507947447], 
             UndirectedEdge[7, 18] -> 
             RGBColor[
              0.33441529127436986`, 0.4640754499257662, 0.9425296245415398], 
             UndirectedEdge[65, 66] -> 
             RGBColor[
              0.8068568184878835, 0.8498672602817441, 0.9811645922016861], 
             UndirectedEdge[150, 152] -> 
             RGBColor[
              0.2823331640327409, 0.4140804347278859, 0.9393898280659538], 
             UndirectedEdge[25, 87] -> 
             RGBColor[
              0.9834480379935321, 0.9649273068843578, 0.6107852165105583], 
             UndirectedEdge[69, 82] -> 
             RGBColor[
              0.3600920128525825, 0.48631533560726303`, 0.9441657225354702], 
             UndirectedEdge[1, 159] -> 
             RGBColor[
              0.8904785244591324, 0.5230507700609477, 0.2309351859196088], 
             UndirectedEdge[23, 131] -> 
             RGBColor[
              0.9464189057965813, 0.8120568568548516, 0.39007974658807487`], 
             UndirectedEdge[126, 160] -> 
             RGBColor[
              0.336968383677942, 0.466146182368601, 0.9426974544072704], 
             UndirectedEdge[67, 131] -> 
             RGBColor[
              0.8587321785647122, 0.38819073175496194`, 0.20135919859638673`],
              UndirectedEdge[142, 174] -> 
             RGBColor[
              0.5111498276444193, 0.6120610287087513, 0.9551982022484837], 
             UndirectedEdge[22, 122] -> 
             RGBColor[
              0.9186800927700692, 0.6648777817818614, 0.33146523312416354`], 
             UndirectedEdge[32, 176] -> 
             RGBColor[
              0.264674301203473, 0.39551985025775493`, 0.9383841819517735], 
             UndirectedEdge[47, 160] -> 
             RGBColor[
              0.4091167531918066, 0.528778101634004, 0.9472895356390099], 
             UndirectedEdge[79, 125] -> 
             RGBColor[
              0.19146399032539158`, 0.3185711717230839, 0.934214963052216], 
             UndirectedEdge[47, 111] -> 
             RGBColor[
              0.45600877007092583`, 0.5691987153613436, 0.9503313034018304], 
             UndirectedEdge[3, 186] -> 
             RGBColor[
              0.27284687806334806`, 0.40410974670878463`, 0.9388495981136993],
              UndirectedEdge[105, 160] -> 
             RGBColor[
              0.35496105134530265`, 0.4818711546392811, 0.9438387822053573], 
             UndirectedEdge[9, 189] -> 
             RGBColor[
              0.24597910372864595`, 0.37587001236772954`, 0.9373195181126482],
              UndirectedEdge[64, 175] -> 
             RGBColor[
              0.4715002623045349, 0.5782150871828736, 0.9525345772917476], 
             UndirectedEdge[100, 165] -> 
             RGBColor[
              0.21635860172261037`, 0.34473698671108804`, 0.9356326743430103],
              UndirectedEdge[101, 161] -> 
             RGBColor[
              0.28025165259241314`, 0.41189263422865363`, 0.9392712890687474],
              UndirectedEdge[123, 187] -> 
             RGBColor[
              0.26662928669062347`, 0.3975746639579891, 0.9384955154831248], 
             UndirectedEdge[90, 198] -> 
             RGBColor[
              0.542054826289809, 0.636504451768819, 0.9581455985091416], 
             UndirectedEdge[146, 171] -> 
             RGBColor[
              0.8352823460284233, 0.8716885755474699, 0.9840999298352342], 
             UndirectedEdge[62, 157] -> 
             RGBColor[
              0.4569597398647052, 0.567383488557704, 0.951121036787086], 
             UndirectedEdge[2, 164] -> 
             RGBColor[
              0.3359219335901057, 0.4640839113434194, 0.9426730982752791], 
             UndirectedEdge[94, 142] -> 
             RGBColor[
              0.5295082484696294, 0.6279621701064884, 0.9563679845897519], 
             UndirectedEdge[12, 175] -> 
             RGBColor[
              0.4521802655001208, 0.5625302434211127, 0.9510136363718239], 
             UndirectedEdge[23, 64] -> 
             RGBColor[
              0.8080908888760686, 0.8465853309633324, 0.7529704509533501], 
             UndirectedEdge[73, 160] -> 
             RGBColor[
              0.3299232570510399, 0.45874130759689935`, 0.9422962448681991], 
             UndirectedEdge[47, 142] -> 
             RGBColor[
              0.5462053873082997, 0.642424392545945, 0.9574319115118519], 
             UndirectedEdge[31, 120] -> 
             RGBColor[
              0.9036386065731989, 0.8747348065350462, 0.6360795030302686], 
             UndirectedEdge[9, 20] -> 
             RGBColor[
              0.24298403719743245`, 0.3727220075452381, 0.9371489535044994], 
             UndirectedEdge[174, 188] -> 
             RGBColor[
              0.5230323018233795, 0.6213662256563972, 0.9563671406776864], 
             UndirectedEdge[45, 173] -> 
             RGBColor[
              0.9397507014059623, 0.7799019194651641, 0.46888537202339087`], 
             UndirectedEdge[139, 191] -> 
             RGBColor[
              0.2646944952587164, 0.3955410754901928, 0.9383853319733451], 
             UndirectedEdge[24, 170] -> 
             RGBColor[
              0.18064618334875748`, 0.3072009707020641, 0.9335989049484079], 
             UndirectedEdge[118, 195] -> 
             RGBColor[
              0.5461172634712222, 0.6195523235921249, 0.9625471406553332], 
             UndirectedEdge[124, 137] -> 
             RGBColor[
              0.27062078113387267`, 0.4017699776932086, 0.938722825186781], 
             UndirectedEdge[28, 63] -> 
             RGBColor[
              0.3238146353715521, 0.45360214621203954`, 0.941901450034025], 
             UndirectedEdge[7, 94] -> 
             RGBColor[
              0.3842937880206009, 0.5072776968412117, 0.9457078382483868], 
             UndirectedEdge[37, 190] -> 
             RGBColor[
              0.18535040543137957`, 0.3121454063758069, 0.9338668034367403], 
             UndirectedEdge[31, 40] -> 
             RGBColor[
              0.6710448937244029, 0.7408816350846033, 0.9693608389875064], 
             UndirectedEdge[18, 73] -> 
             RGBColor[
              0.3057525961329822, 0.4378058959624189, 0.9407561117277767], 
             UndirectedEdge[170, 195] -> 
             RGBColor[
              0.1806461819290649, 0.30720096920987716`, 0.9335989048675586], 
             UndirectedEdge[62, 191] -> 
             RGBColor[
              0.3182327281368137, 0.4474225004107011, 0.9415950184238715], 
             UndirectedEdge[152, 194] -> 
             RGBColor[
              0.3151343711235495, 0.4448783558224487, 0.9413924862035001], 
             UndirectedEdge[24, 37] -> 
             RGBColor[
              0.18496037581804925`, 0.31173546052289103`, 0.9338445918272582],
              UndirectedEdge[90, 177] -> 
             RGBColor[
              0.3407778041727428, 0.4681866139645882, 0.9429862890205556], 
             UndirectedEdge[94, 188] -> 
             RGBColor[
              0.5413907226485897, 0.6372673670541342, 0.9575369230189545], 
             UndirectedEdge[103, 133] -> 
             RGBColor[
              0.8438593008645356, 0.3288700512541642, 0.189270528206407], 
             UndirectedEdge[38, 179] -> 
             RGBColor[
              0.8863710041657746, 0.8714177118872631, 0.6496390782789341], 
             UndirectedEdge[54, 116] -> 
             RGBColor[
              0.33119462320051296`, 0.4579630134913923, 0.9424460724416142], 
             UndirectedEdge[4, 198] -> 
             RGBColor[
              0.7505232703667862, 0.8050337500894356, 0.9757688036175852], 
             UndirectedEdge[31, 38] -> 
             RGBColor[
              0.9076583192648293, 0.8882942413173389, 0.6516953277782057], 
             UndirectedEdge[35, 47] -> 
             RGBColor[
              0.6449475165023608, 0.7197336460567563, 0.9672187657343465], 
             UndirectedEdge[132, 151] -> 
             RGBColor[
              0.3020454023564957, 0.43081154280309575`, 0.9406584202630028], 
             UndirectedEdge[124, 135] -> 
             RGBColor[
              0.26216673405041124`, 0.39288423819094664`, 0.9382413797120197],
              UndirectedEdge[32, 127] -> 
             RGBColor[
              0.2783696530571501, 0.40872723597091687`, 0.9392075847540681], 
             UndirectedEdge[187, 199] -> 
             RGBColor[
              0.27755781936992874`, 0.40906124471293126`, 0.9391178792518959],
              UndirectedEdge[2, 51] -> 
             RGBColor[
              0.329630384746231, 0.45747109460127056`, 0.9423148038761329], 
             UndirectedEdge[40, 117] -> 
             RGBColor[
              0.6352898865788753, 0.7127028346692909, 0.9658625851533114], 
             UndirectedEdge[9, 17] -> 
             RGBColor[
              0.2497025677004787, 0.37978360908337694`, 0.9375315638774728], 
             UndirectedEdge[33, 57] -> 
             RGBColor[
              0.3418089819131736, 0.4704794931394012, 0.9430007439710605], 
             UndirectedEdge[124, 175] -> 
             RGBColor[
              0.3057261878529413, 0.4375906885663863, 0.9407614713007191], 
             UndirectedEdge[8, 147] -> 
             RGBColor[
              0.4644466210649416, 0.5759586789636362, 0.9510205021407936], 
             UndirectedEdge[108, 110] -> 
             RGBColor[
              0.6931298062895987, 0.7596256615132471, 0.9704393557617335], 
             UndirectedEdge[68, 107] -> 
             RGBColor[
              0.7614279257189907, 0.8138406211600655, 0.9767792324528825], 
             UndirectedEdge[1, 138] -> 
             RGBColor[
              0.9355441317544622, 0.7814661810006367, 0.2706140846810541], 
             UndirectedEdge[94, 160] -> 
             RGBColor[
              0.39241961435313644`, 0.5143158791945474, 0.9462256087169099], 
             UndirectedEdge[138, 142] -> 
             RGBColor[
              0.7768323613465915, 0.7056166385716411, 0.6067738726084364], 
             UndirectedEdge[6, 175] -> 
             RGBColor[
              0.3302248541081414, 0.460445903869875, 0.9422626135907659], 
             UndirectedEdge[34, 104] -> 
             RGBColor[
              0.2353413665909268, 0.3646890761644966, 0.936713714719777], 
             UndirectedEdge[15, 106] -> 
             RGBColor[
              0.3000813368943679, 0.43122185610482894`, 0.9404559598262209], 
             UndirectedEdge[61, 94] -> 
             RGBColor[
              0.34596223015857974`, 0.47084555511717463`, 0.9433836980064841],
              UndirectedEdge[144, 159] -> 
             RGBColor[
              0.8395801784922707, 0.30523617280220927`, 0.18553532966460354`],
              UndirectedEdge[83, 86] -> 
             RGBColor[
              0.32390396973941904`, 0.450080321936663, 0.9420389267285452], 
             UndirectedEdge[137, 176] -> 
             RGBColor[
              0.27219200977132096`, 0.4034214386128163, 0.9388123043332592], 
             UndirectedEdge[143, 159] -> 
             RGBColor[
              0.8217214517738456, 0.16796617350044618`, 0.16843379279049273`],
              UndirectedEdge[24, 144] -> 
             RGBColor[
              0.5177214492396762, 0.3704027595311762, 0.5676269958465465], 
             UndirectedEdge[76, 96] -> 
             RGBColor[
              0.2912734993929746, 0.42347729404149315`, 0.9398989669386781], 
             UndirectedEdge[98, 120] -> 
             RGBColor[
              0.9651286166376958, 0.922790787247423, 0.6081584957443529], 
             UndirectedEdge[98, 183] -> 
             RGBColor[
              0.916699432634126, 0.7182581461246227, 0.5672898177785806], 
             UndirectedEdge[55, 75] -> 
             RGBColor[
              0.3182717437982659, 0.44781970934843396`, 0.9415841980444295], 
             UndirectedEdge[35, 68] -> 
             RGBColor[
              0.8469990595612139, 0.880838075189855, 0.985268720497577], 
             UndirectedEdge[25, 43] -> 
             RGBColor[
              0.9171434396694482, 0.683563770249714, 0.28663285142090683`], 
             UndirectedEdge[47, 174] -> 
             RGBColor[
              0.4164661681947697, 0.535143795517232, 0.9477578338641661], 
             UndirectedEdge[29, 88] -> 
             RGBColor[
              0.8529188119611348, 0.8833651723657042, 0.8634818621932413], 
             UndirectedEdge[17, 140] -> 
             RGBColor[
              0.27217097999434126`, 0.4033993349838457, 0.9388111067185709], 
             UndirectedEdge[41, 90] -> 
             RGBColor[
              0.46883146462921355`, 0.577882603340978, 0.9518176941382794], 
             UndirectedEdge[151, 196] -> 
             RGBColor[
              0.4235249432869995, 0.5401212783183434, 0.9485216237575993], 
             UndirectedEdge[88, 94] -> 
             RGBColor[
              0.5651610277683712, 0.6558369100747177, 0.9599061248871635], 
             UndirectedEdge[57, 198] -> 
             RGBColor[
              0.528369365099485, 0.6246507931370399, 0.9572735730236723], 
             UndirectedEdge[71, 164] -> 
             RGBColor[
              0.2925031947568016, 0.42476978183606456`, 0.9399689962704769], 
             UndirectedEdge[95, 154] -> 
             RGBColor[
              0.9830766756699849, 0.9658160132096346, 0.6241438116222372], 
             UndirectedEdge[69, 90] -> 
             RGBColor[
              0.3947672159149649, 0.5163492536735178, 0.946375195812527], 
             UndirectedEdge[175, 176] -> 
             RGBColor[
              0.30729741649038966`, 0.43924214948599405`, 0.9408509504471974],
              UndirectedEdge[58, 115] -> 
             RGBColor[
              0.2648536806612042, 0.3957083894411449, 0.9383943973465231], 
             UndirectedEdge[42, 88] -> 
             RGBColor[
              0.6168180360411716, 0.6987299024450158, 0.9637087446681081], 
             UndirectedEdge[72, 134] -> 
             RGBColor[
              0.2403643210352666, 0.36996851975920364`, 0.9369997645445869], 
             UndirectedEdge[25, 49] -> 
             RGBColor[
              0.9068295535414201, 0.6042867218959704, 0.2767562624168388], 
             UndirectedEdge[23, 103] -> 
             RGBColor[
              0.928934953541638, 0.7326663131459502, 0.37549070825566344`], 
             UndirectedEdge[79, 192] -> 
             RGBColor[
              0.5106435761291835, 0.23292041936214905`, 0.5495725282880245], 
             UndirectedEdge[89, 170] -> 
             RGBColor[
              0.5181787984934242, 0.3625107392801563, 0.5665165695978354], 
             UndirectedEdge[41, 57] -> 
             RGBColor[
              0.4551460034388895, 0.5660289447091988, 0.9509456686528102], 
             UndirectedEdge[10, 14] -> 
             RGBColor[
              0.35304438919669967`, 0.4784146023517027, 0.943782430505298], 
             UndirectedEdge[6, 59] -> 
             RGBColor[
              0.39442835550292343`, 0.516055749816227, 0.9463536039267142], 
             UndirectedEdge[120, 183] -> 
             RGBColor[
              0.9083396633512348, 0.6613006712269123, 0.24568688683613962`], 
             UndirectedEdge[8, 194] -> 
             RGBColor[
              0.3983632803443602, 0.5194639839388066, 0.9466043338580932], 
             UndirectedEdge[63, 106] -> 
             RGBColor[
              0.3139521958632445, 0.44323609697402705`, 0.9413397986941987], 
             UndirectedEdge[129, 131] -> 
             RGBColor[
              0.9447591766437358, 0.8071223654903125, 0.32715623247964654`], 
             UndirectedEdge[22, 38] -> 
             RGBColor[
              0.904615065264268, 0.6177018117199344, 0.25397947076312033`], 
             UndirectedEdge[38, 117] -> 
             RGBColor[
              0.8719033121193018, 0.8601154409020264, 0.6481970739440106], 
             UndirectedEdge[136, 159] -> 
             RGBColor[
              0.8653255671392956, 0.4240224866042378, 0.2070779406804246], 
             UndirectedEdge[158, 166] -> 
             RGBColor[
              0.3220947514992546, 0.4482744245110126, 0.9419323901733808], 
             UndirectedEdge[75, 96] -> 
             RGBColor[
              0.29517906246073655`, 0.4275822884527116, 0.9401213829776245], 
             UndirectedEdge[118, 170] -> 
             RGBColor[
              0.5478364454002871, 0.6213592928020021, 0.9626450455228917], 
             UndirectedEdge[7, 58] -> 
             RGBColor[
              0.3073067839852605, 0.4364725367668565, 0.9409532535052085], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.7375823865275546, 0.7949242332798678, 0.9744789772559258], 
             UndirectedEdge[65, 180] -> 
             RGBColor[
              0.8230809086810591, 0.8625416428483053, 0.9827816578893989], 
             UndirectedEdge[151, 171] -> 
             RGBColor[
              0.6131733026438233, 0.690971104405486, 0.9657655862298374], 
             UndirectedEdge[37, 118] -> 
             RGBColor[
              0.5521506378695789, 0.625893782622829, 0.962890732401742], 
             UndirectedEdge[7, 47] -> 
             RGBColor[
              0.40099092685927107`, 0.5217399192806683, 0.9467717651704868], 
             UndirectedEdge[46, 99] -> 
             RGBColor[
              0.5809189759498203, 0.6706552206345228, 0.960151216244546], 
             UndirectedEdge[195, 197] -> 
             RGBColor[
              0.5339219968548683, 0.6098281490239381, 0.9613839452386224], 
             UndirectedEdge[5, 63] -> 
             RGBColor[
              0.3175297704097317, 0.4469963546537124, 0.9415435362720739], 
             UndirectedEdge[11, 63] -> 
             RGBColor[
              0.29935737823800995`, 0.4278960182850215, 0.9405086454215394], 
             UndirectedEdge[10, 193] -> 
             RGBColor[
              0.30300124599655587`, 0.4350697469532493, 0.9405937256719987], 
             UndirectedEdge[99, 147] -> 
             RGBColor[
              0.5223956840025993, 0.6231433757875112, 0.9555440483245787], 
             UndirectedEdge[9, 77] -> 
             RGBColor[
              0.2804804496400908, 0.41213311443233347`, 0.9392843187221377], 
             UndirectedEdge[43, 103] -> 
             RGBColor[
              0.859828066940869, 0.45161298487477564`, 0.20456223663524548`], 
             UndirectedEdge[54, 174] -> 
             RGBColor[
              0.3271085364710258, 0.454423850539001, 0.942185710608396], 
             UndirectedEdge[149, 197] -> 
             RGBColor[
              0.5612425008846491, 0.6385437309792414, 0.9629398075260546], 
             UndirectedEdge[87, 180] -> 
             RGBColor[
              0.8560213723624259, 0.8868310086243191, 0.9110439947166469], 
             UndirectedEdge[134, 191] -> 
             RGBColor[
              0.25554145744836393`, 0.3859206524153965, 0.9378640800107516], 
             UndirectedEdge[65, 131] -> 
             RGBColor[
              0.9106761538385292, 0.7880776994423069, 0.6150413032300603], 
             UndirectedEdge[107, 147] -> 
             RGBColor[
              0.5739634519525214, 0.664627405018551, 0.9598641490933124], 
             UndirectedEdge[50, 82] -> 
             RGBColor[
              0.28041536130760697`, 0.41115377820056886`, 0.9393139654375977],
              UndirectedEdge[30, 162] -> 
             RGBColor[
              0.9383242239537981, 0.9524410659335498, 0.9517777399403218], 
             UndirectedEdge[51, 74] -> 
             RGBColor[
              0.29246128213975436`, 0.4247257290181345, 0.9399666094089402], 
             UndirectedEdge[12, 161] -> 
             RGBColor[
              0.4463108010091732, 0.5574383614954901, 0.9506399339170767], 
             UndirectedEdge[78, 113] -> 
             RGBColor[
              0.9141333132318434, 0.7927873365838396, 0.6157566218013946], 
             UndirectedEdge[131, 133] -> 
             RGBColor[
              0.8613432531194789, 0.40826059496306566`, 0.20385956653881843`],
              UndirectedEdge[35, 188] -> 
             RGBColor[
              0.7515136501309705, 0.8059560761959215, 0.9758280725478667], 
             UndirectedEdge[181, 185] -> 
             RGBColor[
              0.8769516134578437, 0.9038519112831478, 0.9435125496118522], 
             UndirectedEdge[111, 188] -> 
             RGBColor[
              0.5625749036995356, 0.6554211455005088, 0.9589406102153506], 
             UndirectedEdge[41, 184] -> 
             RGBColor[
              0.46042354235664473`, 0.5706000836629397, 0.9512819487659052], 
             UndirectedEdge[135, 187] -> 
             RGBColor[
              0.2580530598737554, 0.38856050580927426`, 0.9380071120532948], 
             UndirectedEdge[51, 71] -> 
             RGBColor[
              0.2862116459129269, 0.41815696509391576`, 0.9396107018713307], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.2532145568819805, 0.3834749323861105, 0.937731566465837], 
             UndirectedEdge[26, 158] -> 
             RGBColor[
              0.3248339638099492, 0.45064699253772245`, 0.9421069303596279], 
             UndirectedEdge[101, 199] -> 
             RGBColor[
              0.262066422777004, 0.3927788046824936, 0.9382356671333965], 
             UndirectedEdge[84, 194] -> 
             RGBColor[
              0.30565287667395435`, 0.4349127039944547, 0.9408525291212098], 
             UndirectedEdge[6, 176] -> 
             RGBColor[
              0.31712437457249, 0.4477537666594349, 0.9414771155265509], 
             UndirectedEdge[18, 116] -> 
             RGBColor[
              0.35397661933935576`, 0.48101848911472117`, 0.9437760550684375],
              UndirectedEdge[98, 179] -> 
             RGBColor[
              0.8907110607570355, 0.9148157520026807, 0.9556261844734377], 
             UndirectedEdge[116, 142] -> 
             RGBColor[
              0.5152359143739065, 0.6156001916611427, 0.9554585640817019], 
             UndirectedEdge[77, 112] -> 
             RGBColor[
              0.3009216795649535, 0.4336181431321977, 0.9404484165262689], 
             UndirectedEdge[56, 190] -> 
             RGBColor[
              0.1793170310330229, 0.30580394734510286`, 0.9335232116903315], 
             UndirectedEdge[76, 126] -> 
             RGBColor[
              0.2917876480797086, 0.4240176969101601, 0.9399282469457728], 
             UndirectedEdge[168, 173] -> 
             RGBColor[
              0.9668668867879184, 0.9728695829823109, 0.8506912832058626], 
             UndirectedEdge[158, 164] -> 
             RGBColor[
              0.27399405489207074`, 0.4053155022909841, 0.9389149281369991], 
             UndirectedEdge[46, 146] -> 
             RGBColor[
              0.6969184905099, 0.7624738200168288, 0.9708932713664746], 
             UndirectedEdge[23, 25] -> 
             RGBColor[
              0.9862503262702172, 0.9646170985208886, 0.4575613230413248], 
             UndirectedEdge[9, 28] -> 
             RGBColor[
              0.27767181401552266`, 0.4091810603131285, 0.9391243710783226], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.9239792736477469, 0.9412455241190165, 0.9588251826995514], 
             UndirectedEdge[103, 129] -> 
             RGBColor[
              0.9272752243887925, 0.727731821781411, 0.3125671941472351], 
             UndirectedEdge[5, 48] -> 
             RGBColor[
              0.2996548823827041, 0.431514025062696, 0.9404045642131346], 
             UndirectedEdge[36, 169] -> 
             RGBColor[
              0.260181316759984, 0.39079743873598083`, 0.9381283131344916], 
             UndirectedEdge[159, 170] -> 
             RGBColor[
              0.5025049126013521, 0.2420343839730972, 0.5515072387664649], 
             UndirectedEdge[86, 175] -> 
             RGBColor[
              0.356178745028919, 0.4829258597049654, 0.9439163725701132], 
             UndirectedEdge[9, 97] -> 
             RGBColor[
              0.2707641427587703, 0.4019206598506281, 0.9387309894192344], 
             UndirectedEdge[7, 88] -> 
             RGBColor[
              0.5313273656076622, 0.6265318924404168, 0.9577502738522159], 
             UndirectedEdge[5, 77] -> 
             RGBColor[
              0.2913005664473497, 0.42350574323179174`, 0.9399005083673827], 
             UndirectedEdge[103, 131] -> 
             RGBColor[
              0.8817747101691108, 0.5560483957434501, 0.2230622590091212], 
             UndirectedEdge[15, 193] -> 
             RGBColor[
              0.32089862240878825`, 0.45236799072193, 0.941668354353746], 
             UndirectedEdge[167, 181] -> 
             RGBColor[
              0.9498028388938546, 0.9615340502113876, 0.9505692894275887], 
             UndirectedEdge[99, 146] -> 
             RGBColor[
              0.6800950161218604, 0.7488157656197341, 0.9695688658362309], 
             UndirectedEdge[163, 177] -> 
             RGBColor[
              0.2633144670135955, 0.39409057830572625`, 0.9383067414063544], 
             UndirectedEdge[76, 116] -> 
             RGBColor[
              0.3329665446591801, 0.4598254152907607, 0.9425469807473624], 
             UndirectedEdge[15, 59] -> 
             RGBColor[
              0.38695782791817696`, 0.5095851543019536, 0.9458775885149424], 
             UndirectedEdge[36, 151] -> 
             RGBColor[
              0.2998281417164218, 0.4284810612879339, 0.9405321505496939], 
             UndirectedEdge[38, 98] -> 
             RGBColor[
              0.9691483293293262, 0.9363502220297157, 0.6237743204922899], 
             UndirectedEdge[70, 139] -> 
             RGBColor[
              0.23141666930631707`, 0.36056397047819155`, 0.9364902090154877],
              UndirectedEdge[56, 195] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[66, 168] -> 
             RGBColor[
              0.8151061747990456, 0.8563704613486036, 0.9793645875552226], 
             UndirectedEdge[6, 161] -> 
             RGBColor[
              0.32435538961719373`, 0.45535402194425245`, 0.9418889111360187],
              UndirectedEdge[56, 118] -> 
             RGBColor[
              0.5461172634712221, 0.619552323592125, 0.9625471406553332], 
             UndirectedEdge[46, 117] -> 
             RGBColor[
              0.6883704009191991, 0.7557959874606861, 0.9700412776825125], 
             UndirectedEdge[79, 89] -> 
             RGBColor[
              0.5289801926935428, 0.3738636894324282, 0.5671316930183012], 
             UndirectedEdge[102, 140] -> 
             RGBColor[
              0.3396692909282838, 0.4683264235730946, 0.9428753810499368], 
             UndirectedEdge[32, 130] -> 
             RGBColor[
              0.23618787859936186`, 0.36557881395732306`, 0.936761922326355], 
             UndirectedEdge[105, 126] -> 
             RGBColor[
              0.3252176564982815, 0.45596829309429976`, 0.9419487084621424], 
             UndirectedEdge[86, 124] -> 
             RGBColor[
              0.3415070368558193, 0.46858226157491756`, 0.94304139535942], 
             UndirectedEdge[41, 168] -> 
             RGBColor[
              0.7441532266042006, 0.7995222771759883, 0.9732629767804062], 
             UndirectedEdge[43, 143] -> 
             RGBColor[
              0.8380819090853437, 0.29371981759472743`, 0.18410058518847694`],
              UndirectedEdge[56, 197] -> 
             RGBColor[
              0.5339219968548683, 0.6098281490239381, 0.9613839452386224], 
             UndirectedEdge[47, 73] -> 
             RGBColor[
              0.3723282317178833, 0.495470365317321, 0.9449982523567235], 
             UndirectedEdge[23, 108] -> 
             RGBColor[
              0.8874058680057144, 0.9088494378884622, 0.7606689085618024], 
             UndirectedEdge[97, 155] -> 
             RGBColor[
              0.2652922598561954, 0.3961693639826077, 0.9384193737828581], 
             UndirectedEdge[86, 161] -> 
             RGBColor[
              0.35030928053797133`, 0.47783397777934283`, 0.943542670115366], 
             UndirectedEdge[88, 188] -> 
             RGBColor[
              0.688424300235651, 0.7565215626533395, 0.9695793586227837], 
             UndirectedEdge[136, 197] -> 
             RGBColor[
              0.8984618333218767, 0.7936232208649558, 0.6170525520201404], 
             UndirectedEdge[65, 69] -> 
             RGBColor[
              0.6618396215787897, 0.7314857264416685, 0.9696204831011173], 
             UndirectedEdge[23, 67] -> 
             RGBColor[
              0.9058924219372393, 0.564808649157462, 0.35378764784292904`], 
             UndirectedEdge[31, 121] -> 
             RGBColor[
              0.6965919354102337, 0.7616218744062735, 0.9713719956909121], 
             UndirectedEdge[52, 145] -> 
             RGBColor[
              0.21010927874609994`, 0.3381685520328137, 0.9352767846445429], 
             UndirectedEdge[12, 87] -> 
             RGBColor[
              0.7859686037949694, 0.8312106955650405, 0.9046734035026598], 
             UndirectedEdge[128, 192] -> 
             RGBColor[
              0.8534502573357887, 0.36281213583181793`, 0.19689722402413434`],
              UndirectedEdge[78, 95] -> 
             RGBColor[
              0.9537951709684989, 0.944166482218568, 0.6841709176231596], 
             UndirectedEdge[123, 165] -> 
             RGBColor[
              0.23466718379435303`, 0.36398046729963934`, 0.9366753210068761],
              UndirectedEdge[24, 56] -> 
             RGBColor[
              0.1789270014196926, 0.30539400149218693`, 0.9335010000808495], 
             UndirectedEdge[50, 177] -> 
             RGBColor[
              0.2679195346173776, 0.39893079633545114`, 0.9385689931938027], 
             UndirectedEdge[18, 58] -> 
             RGBColor[
              0.2912619493997384, 0.4225753074857117, 0.9399308908333093], 
             UndirectedEdge[96, 182] -> 
             RGBColor[
              0.2856601600419676, 0.4175773184773137, 0.9395792955668297], 
             UndirectedEdge[49, 131] -> 
             RGBColor[
              0.8669981330677842, 0.45172648022993345`, 0.2092746859635889], 
             UndirectedEdge[28, 106] -> 
             RGBColor[
              0.28491435627629447`, 0.41679343143290143`, 0.9395368231456924],
              UndirectedEdge[57, 81] -> 
             RGBColor[
              0.4684558639722499, 0.5768344890925647, 0.951993469629622], 
             UndirectedEdge[7, 115] -> 
             RGBColor[
              0.3080070225358357, 0.4372085318811994, 0.9409931310547537], 
             UndirectedEdge[54, 94] -> 
             RGBColor[
              0.3454669572962359, 0.47032499193673805`, 0.9433554929496641], 
             UndirectedEdge[138, 181] -> 
             RGBColor[
              0.9485527902505714, 0.8398398392439036, 0.5790165148890076], 
             UndirectedEdge[55, 182] -> 
             RGBColor[
              0.30875284137949693`, 0.43781473937303605`, 0.9410421106336347],
              UndirectedEdge[17, 77] -> 
             RGBColor[
              0.26961618509412616`, 0.4007140835603673, 0.9386656149284841], 
             UndirectedEdge[144, 149] -> 
             RGBColor[
              0.5450419518497644, 0.3991183399942927, 0.5691828580531295], 
             UndirectedEdge[68, 179] -> 
             RGBColor[
              0.8317792747849202, 0.8687996297404257, 0.9837911974570385], 
             UndirectedEdge[103, 143] -> 
             RGBColor[
              0.8425446000586423, 0.3187646847545005, 0.18801156922994122`], 
             UndirectedEdge[80, 173] -> 
             RGBColor[
              0.807519241461194, 0.8471578477354111, 0.8378854904784999], 
             UndirectedEdge[161, 199] -> 
             RGBColor[
              0.2904737372287366, 0.422636693299029, 0.9398534216665669], 
             UndirectedEdge[43, 133] -> 
             RGBColor[
              0.8393966098912371, 0.3038251840943911, 0.18535954416494269`], 
             UndirectedEdge[6, 193] -> 
             RGBColor[
              0.3283691499935347, 0.4588385862362035, 0.9421443697655179], 
             UndirectedEdge[181, 188] -> 
             RGBColor[
              0.8244919498408892, 0.8628700233573725, 0.9382838606059434], 
             UndirectedEdge[120, 173] -> 
             RGBColor[
              0.9759551315276564, 0.9289248083741766, 0.49955341569398815`], 
             UndirectedEdge[2, 158] -> 
             RGBColor[
              0.31519292647680297`, 0.4422964105723771, 0.9414926119859944], 
             UndirectedEdge[95, 143] -> 
             RGBColor[
              0.9002121270530901, 0.5519033691579674, 0.2714502368397491], 
             UndirectedEdge[4, 172] -> 
             RGBColor[
              0.8994312173900378, 0.9185136164944618, 0.783483838768104], 
             UndirectedEdge[89, 113] -> 
             RGBColor[
              0.8771471647792357, 0.528095234856292, 0.21892914685667453`], 
             UndirectedEdge[34, 90] -> 
             RGBColor[
              0.31984837730012083`, 0.4461884593191548, 0.9417943891224722], 
             UndirectedEdge[28, 48] -> 
             RGBColor[
              0.30593974734452445`, 0.4381198166210231, 0.9407624779750857], 
             UndirectedEdge[5, 189] -> 
             RGBColor[
              0.2567992205359049, 0.38724264116718776`, 0.9379357077578933], 
             UndirectedEdge[8, 55] -> 
             RGBColor[
              0.4002897149094885, 0.5211325647337041, 0.9467270845651039], 
             UndirectedEdge[29, 138] -> 
             RGBColor[
              0.9532093472510355, 0.8417654452316519, 0.5018453146080967], 
             UndirectedEdge[8, 68] -> 
             RGBColor[
              0.6519110948314109, 0.7251718951051506, 0.9679355855003635], 
             UndirectedEdge[176, 187] -> 
             RGBColor[
              0.2885120341406341, 0.42057481897427373`, 0.9397417055777791], 
             UndirectedEdge[65, 133] -> 
             RGBColor[
              0.872760744533954, 0.5608993549530209, 0.5812495724273461], 
             UndirectedEdge[68, 147] -> 
             RGBColor[
              0.668160340209887, 0.7385028014791089, 0.9691763692944251], 
             UndirectedEdge[89, 192] -> 
             RGBColor[
              0.8356556165643594, 0.2750702700702792, 0.18177716473027677`], 
             UndirectedEdge[2, 74] -> 
             RGBColor[
              0.3399517025683613, 0.46831945404167635`, 0.9429025876570818], 
             UndirectedEdge[156, 185] -> 
             RGBColor[
              0.8452085345226001, 0.8798178098671724, 0.9849898137223804], 
             UndirectedEdge[126, 182] -> 
             RGBColor[
              0.2861743087287016, 0.41811772134598074`, 0.9396085755739244], 
             UndirectedEdge[18, 188] -> 
             RGBColor[
              0.49151222590235866`, 0.5940651201386887, 0.9543587093121076], 
             UndirectedEdge[68, 156] -> 
             RGBColor[
              0.8882342803358891, 0.9137179209353309, 0.9892017726661817], 
             UndirectedEdge[29, 181] -> 
             RGBColor[
              0.988986461566373, 0.9897136330697374, 0.8321863641764009], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.9759778030702638, 0.9313399748264705, 0.5237839339684474], 
             UndirectedEdge[30, 180] -> 
             RGBColor[
              0.8089076786179981, 0.8512402939181014, 0.9814298025533923], 
             UndirectedEdge[31, 196] -> 
             RGBColor[
              0.6728409042264264, 0.742339717319497, 0.969502227513229], 
             UndirectedEdge[193, 199] -> 
             RGBColor[
              0.2944874976050776, 0.4261212575909801, 0.9401088802960662], 
             UndirectedEdge[30, 110] -> 
             RGBColor[
              0.7493871054318795, 0.8041704915393881, 0.9758883443405271], 
             UndirectedEdge[12, 59] -> 
             RGBColor[
              0.516383766894903, 0.6181400893674647, 0.9551046267077723], 
             UndirectedEdge[38, 156] -> 
             RGBColor[
              0.9428260097167436, 0.9163360030821683, 0.6550496534880772], 
             UndirectedEdge[72, 152] -> 
             RGBColor[
              0.2658080334878341, 0.396711474771397, 0.9384487463281612], 
             UndirectedEdge[37, 79] -> 
             RGBColor[
              0.19748095052754017`, 0.3248953783928531, 0.9345576200344334], 
             UndirectedEdge[170, 197] -> 
             RGBColor[
              0.5356411787839332, 0.6116351182338152, 0.9614818501061808], 
             UndirectedEdge[86, 127] -> 
             RGBColor[
              0.3567736173469446, 0.48344110820768715`, 0.9439542773081928], 
             UndirectedEdge[69, 127] -> 
             RGBColor[
              0.3615866192833338, 0.48760988857647636`, 0.944260957535609], 
             UndirectedEdge[58, 61] -> 
             RGBColor[
              0.26897522612323943`, 0.4000403950428194, 0.9386291132633059], 
             UndirectedEdge[11, 17] -> 
             RGBColor[
              0.24235029233601593`, 0.3720559015141443, 0.9371128626721834], 
             UndirectedEdge[11, 15] -> 
             RGBColor[
              0.28548651926913327`, 0.4158817774158234, 0.9396248065535615], 
             UndirectedEdge[111, 157] -> 
             RGBColor[
              0.5090903091480017, 0.6123414730802424, 0.9544966004768307], 
             UndirectedEdge[75, 191] -> 
             RGBColor[
              0.2821961080105196, 0.4139363801586776, 0.9393820229282445], 
             UndirectedEdge[98, 156] -> 
             RGBColor[
              0.9471660663080045, 0.9597340431975859, 0.961036759682581], 
             UndirectedEdge[28, 140] -> 
             RGBColor[
              0.3001402263093852, 0.4327967862135973, 0.9404039139194207], 
             UndirectedEdge[105, 157] -> 
             RGBColor[
              0.4504475650892219, 0.5617429700786016, 0.9507060867688824], 
             UndirectedEdge[3, 15] -> 
             RGBColor[
              0.2943870608658776, 0.4252368109609329, 0.9401316792303248], 
             UndirectedEdge[55, 96] -> 
             RGBColor[
              0.32928937279498216`, 0.459399935982008, 0.942211635716671], 
             UndirectedEdge[6, 64] -> 
             RGBColor[
              0.4813272203866353, 0.5867267043563145, 0.9531607423711013], 
             UndirectedEdge[70, 134] -> 
             RGBColor[
              0.2222636314959646, 0.3509435474033953, 0.9359689570528942], 
             UndirectedEdge[106, 140] -> 
             RGBColor[
              0.29027778680107763`, 0.4224307369755848, 0.9398422625795944], 
             UndirectedEdge[64, 154] -> 
             RGBColor[
              0.8045650840099676, 0.8465963466235498, 0.9181848867101159], 
             UndirectedEdge[8, 157] -> 
             RGBColor[
              0.5029410908496337, 0.6072102236909507, 0.9540509278121335], 
             UndirectedEdge[83, 124] -> 
             RGBColor[
              0.2734514125634414, 0.4047451507980839, 0.9388840254591511], 
             UndirectedEdge[22, 128] -> 
             RGBColor[
              0.8670016862310241, 0.46697435659460335`, 0.20987408763836157`],
              UndirectedEdge[83, 135] -> 
             RGBColor[
              0.244563666934011, 0.3743822985526921, 0.9372389110811449], 
             UndirectedEdge[62, 68] -> 
             RGBColor[
              0.6059297438464823, 0.6853451599719039, 0.965005694475316], 
             UndirectedEdge[105, 116] -> 
             RGBColor[
              0.36639655307775293`, 0.49177601147490035`, 0.944567442263732], 
             UndirectedEdge[93, 145] -> 
             RGBColor[
              0.21595172710093502`, 0.34430933568636624`, 0.935609503435223], 
             UndirectedEdge[128, 195] -> 
             RGBColor[
              0.5342542573357888, 0.44844563583181796`, 0.5815387240241343], 
             UndirectedEdge[87, 154] -> 
             RGBColor[
              0.9872510560263222, 0.9889959982810382, 0.8609465250606165], 
             UndirectedEdge[138, 167] -> 
             RGBColor[
              0.914025724578517, 0.8135858623733021, 0.6202282398592844], 
             UndirectedEdge[179, 194] -> 
             RGBColor[
              0.5782314602978695, 0.6630917185740817, 0.9624599458147682], 
             UndirectedEdge[118, 144] -> 
             RGBColor[
              0.8849117112912057, 0.6845610816311141, 0.5966731364210304], 
             UndirectedEdge[47, 188] -> 
             RGBColor[
              0.5580878614872598, 0.6517295894935908, 0.9586008499410545], 
             UndirectedEdge[11, 20] -> 
             RGBColor[
              0.2356317618329697, 0.3649942999760054, 0.93673025229921], 
             UndirectedEdge[124, 187] -> 
             RGBColor[
              0.2869408055031858, 0.4189233580546661, 0.939652226431301], 
             UndirectedEdge[28, 189] -> 
             RGBColor[
              0.26308408549772533`, 0.39384843272551495`, 0.9382936215198444],
              UndirectedEdge[84, 93] -> 
             RGBColor[
              0.24346208091315458`, 0.3732244618001842, 0.9371761773869076], 
             UndirectedEdge[18, 94] -> 
             RGBColor[
              0.36824895343507874`, 0.4933804675600669, 0.9446854755764875], 
             UndirectedEdge[146, 156] -> 
             RGBColor[
              0.8584691386886809, 0.8901770946260392, 0.9863115068182637], 
             UndirectedEdge[2, 26] -> 
             RGBColor[
              0.3867618425079842, 0.5094154015901577, 0.945865100497908], 
             UndirectedEdge[124, 161] -> 
             RGBColor[
              0.29985672336199365`, 0.43249880664076373`, 0.9403877688459719],
              UndirectedEdge[25, 67] -> 
             RGBColor[
              0.8985635990383481, 0.540750973420999, 0.26884077504963666`], 
             UndirectedEdge[15, 77] -> 
             RGBColor[
              0.31275241202724346`, 0.4445399594620464, 0.9411775588098623], 
             UndirectedEdge[23, 49] -> 
             RGBColor[
              0.9141583764403114, 0.6283443976324334, 0.3617031352101312], 
             UndirectedEdge[27, 37] -> 
             RGBColor[
              0.23387138917519362`, 0.3631440366986098, 0.9366300016805876], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.28199072307706635`, 0.41303118579725295`, 0.9393955660070041],
              UndirectedEdge[134, 139] -> 
             RGBColor[
              0.2400051701500614, 0.36959102940737165`, 0.9369793114329906], 
             UndirectedEdge[13, 127] -> 
             RGBColor[
              0.34979347533914956`, 0.4773952600326733, 0.9435095088317533], 
             UndirectedEdge[59, 186] -> 
             RGBColor[
              0.36541764511564734`, 0.4884580900498052, 0.9445955073983169], 
             UndirectedEdge[119, 149] -> 
             RGBColor[
              0.3992231896957711, 0.5102289495476822, 0.9477505828326117], 
             UndirectedEdge[41, 66] -> 
             RGBColor[
              0.6206670435279176, 0.7021698769586107, 0.9637962645099678], 
             UndirectedEdge[25, 103] -> 
             RGBColor[
              0.9216061306427468, 0.7086086374094871, 0.2905438354623711], 
             UndirectedEdge[164, 166] -> 
             RGBColor[
              0.3428237586125573, 0.4700619252820549, 0.9431128764626655], 
             UndirectedEdge[30, 90] -> 
             RGBColor[
              0.6408480095261183, 0.7142786377339077, 0.9678341664939911], 
             UndirectedEdge[75, 182] -> 
             RGBColor[
              0.27464253104525127`, 0.40599709184373967`, 0.9389518578945881],
              UndirectedEdge[92, 97] -> 
             RGBColor[
              0.2548383832137916, 0.38518167681737986`, 0.9378240409731977], 
             UndirectedEdge[18, 61] -> 
             RGBColor[
              0.2960837334123488, 0.42764330820172913`, 0.9402054842996372], 
             UndirectedEdge[76, 191] -> 
             RGBColor[
              0.2782905449427576, 0.40983138574745914`, 0.9391596068892982], 
             UndirectedEdge[129, 197] -> 
             RGBColor[
              0.939588342286577, 0.9465340447880747, 0.7029640290475025], 
             UndirectedEdge[97, 112] -> 
             RGBColor[
              0.2912053726836331, 0.4234056885504923, 0.9398950872233656], 
             UndirectedEdge[87, 131] -> 
             RGBColor[
              0.9436166175198961, 0.8123670652183208, 0.5433036400573084], 
             UndirectedEdge[33, 198] -> 
             RGBColor[
              0.5096004354679522, 0.6083940896440386, 0.956077633424264], 
             UndirectedEdge[39, 114] -> 
             RGBColor[
              0.20908858865686974`, 0.3370957420335433, 0.935218657853937], 
             UndirectedEdge[144, 170] -> 
             RGBColor[
              0.5194406297490485, 0.3722097272488664, 0.5677249006332556], 
             UndirectedEdge[64, 110] -> 
             RGBColor[
              0.6138148271599528, 0.6973615545881173, 0.9627408981532811], 
             UndirectedEdge[108, 131] -> 
             RGBColor[
              0.8402456246331873, 0.7322315204859621, 0.6082404593152602], 
             UndirectedEdge[33, 141] -> 
             RGBColor[
              0.3411893210123498, 0.46994277401217005`, 0.9429612597264045], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.6032826317786147, 0.6888110439075521, 0.9619117651521593], 
             UndirectedEdge[88, 142] -> 
             RGBColor[
              0.6765418260566909, 0.7472163657056936, 0.968410420193581], 
             UndirectedEdge[12, 95] -> 
             RGBColor[
              0.7817942234386319, 0.8080307104936368, 0.6678706900642806], 
             UndirectedEdge[131, 162] -> 
             RGBColor[
              0.941079962602384, 0.8111036548737982, 0.5757395893878008], 
             UndirectedEdge[21, 194] -> 
             RGBColor[
              0.33236539581814195`, 0.4622999335123229, 0.9423990070157204], 
             UndirectedEdge[131, 154] -> 
             RGBColor[
              0.9428931009304802, 0.8120678725150692, 0.5552941823448407], 
             UndirectedEdge[81, 184] -> 
             RGBColor[
              0.47373340289000515`, 0.5814056280463057, 0.952329749742717], 
             UndirectedEdge[105, 111] -> 
             RGBColor[
              0.4018530682244218, 0.5222917683666206, 0.9468805499681779]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 71 -> 
             RGBColor[
              0.2902833275082297, 0.42243656061010276`, 0.93984257811467], 10 -> 
             RGBColor[
              0.28931600419628395`, 0.4214198424774074, 0.9397874904830813], 
             68 -> RGBColor[
              0.8556248139763563, 0.8877160176206234, 0.9860914526539951], 
             155 -> RGBColor[
              0.24962306644129345`, 0.3797000482193023, 0.9375270363983738], 
             132 -> RGBColor[
              0.2522143608002516, 0.3824236628881191, 0.93767460677864], 26 -> 
             RGBColor[
              0.39640287984113043`, 0.5177659835555031, 0.9464794188715415], 
             29 -> RGBColor[
              0.9936430185668372, 0.9916392390574856, 0.75501516389549], 113 -> 
             RGBColor[
              0.9003020964297527, 0.6401769295720257, 0.2385219642527955], 50 -> 
             RGBColor[
              0.2422322948146241, 0.37193187863768656`, 0.9371061428879017], 
             173 -> RGBColor[
              0.9951414157005084, 0.9920163043986404, 0.7125512665860644], 
             192 -> RGBColor[0.817319, 0.134127, 0.164218], 165 -> 
             RGBColor[
              0.21890292553398902`, 0.347411232356294, 0.9357775698200786], 
             92 -> RGBColor[
              0.22871531315648586`, 0.35772467388884666`, 0.9363363707790532],
              11 -> RGBColor[
              0.24586228151751777`, 0.37574722481687783`, 0.9373128652605475],
              137 -> RGBColor[
              0.2501870825879037, 0.38029286495007875`, 0.9375591562835361], 
             120 -> RGBColor[
              0.9567688473548046, 0.8658333123497126, 0.2865555648019119], 51 -> 
             RGBColor[
              0.28213996431762406`, 0.4138773695777287, 0.9393788256279912], 
             72 -> 
             RGBColor[
              0.24987650973082426`, 0.37996643318583184`, 0.9375414696187768],
              64 -> RGBColor[
              0.6226026285830288, 0.704495887669313, 0.963432706072083], 41 -> 
             RGBColor[
              0.5497140953330726, 0.6453216927859953, 0.9576946537351515], 
             103 -> RGBColor[
              0.8642907579141675, 0.4766578520345487, 0.20847322067670976`], 
             162 -> RGBColor[
              0.9829012627807141, 0.9867683702952449, 0.9138278814340688], 
             196 -> RGBColor[
              0.49517344266125934`, 0.6010431339186144, 0.9534010137678327], 
             179 -> RGBColor[
              0.807933735593484, 0.8498832418602281, 0.9814909422600818], 160 -> 
             RGBColor[
              0.36671177852496323`, 0.4920490439135823, 0.9445875281504853], 
             123 -> RGBColor[
              0.250431442054717, 0.3805497022429847, 0.9375730721936737], 150 -> 
             RGBColor[
              0.2829267708206377, 0.41470435309880965`, 0.9394236330943619], 
             188 -> RGBColor[
              0.6646539951158695, 0.737952019632756, 0.9672101567545748], 46 -> 
             RGBColor[
              0.5977424503378598, 0.6843132750316175, 0.9614756217747897], 
             182 -> RGBColor[
              0.2651236286264823, 0.39599212186834176`, 0.9384097704837935], 
             6 -> RGBColor[
              0.3400518121902417, 0.46895752104331584`, 0.9428887786701194], 
             131 -> RGBColor[
              0.8992586624240541, 0.6354389394523516, 0.23765129734153262`], 
             45 -> RGBColor[
              0.8843599871114161, 0.5677875345316877, 0.22521947746071738`], 
             195 -> RGBColor[0.178927, 0.305394, 0.933501], 148 -> 
             RGBColor[
              0.20479309393410217`, 0.332580904729819, 0.9349740357840903], 
             161 -> RGBColor[
              0.30865896704414575`, 0.441750522845189, 0.9408890436019178], 1 -> 
             RGBColor[
              0.9583125875736904, 0.8710407105954553, 0.2925527040414048], 
             101 -> RGBColor[
              0.2518443381406806, 0.38203474561211825`, 0.9376535345355769], 
             12 -> RGBColor[
              0.5839626349742006, 0.6731262001457912, 0.9603908242322355], 39 -> 
             RGBColor[
              0.20098973591686892`, 0.3285833343068806, 0.9347574401715728], 
             48 -> RGBColor[
              0.3171026989044469, 0.4490801525711323, 0.9414264814646527], 77 -> 
             RGBColor[
              0.3003940670337382, 0.43306358890932384`, 0.940418369773149], 
             56 -> RGBColor[0.178927, 0.305394, 0.933501], 110 -> 
             RGBColor[
              0.6050270257368769, 0.6902272215069217, 0.9620490902344793], 73 -> 
             RGBColor[
              0.2931347355771166, 0.42543357128021636`, 0.9400049615859128], 
             37 -> RGBColor[
              0.19099374879671333`, 0.31807691806140814`, 0.9341881834928177],
              130 -> RGBColor[
              0.23722409174651585`, 0.3666679396746901, 0.9368209331321454], 
             107 -> RGBColor[
              0.6672310374616252, 0.7399652246995075, 0.9674670122517698], 59 -> 
             RGBColor[
              0.44880489881560515`, 0.5631539785891382, 0.949818429183309], 
             47 -> RGBColor[
              0.4515217278586501, 0.5655071593544256, 0.9499915431275343], 
             159 -> RGBColor[
              0.8226444613445744, 0.17506082952644003`, 0.16931766779781277`],
              55 -> RGBColor[
              0.35238205413251156`, 0.47963735687773035`, 0.943674450783476], 
             49 -> RGBColor[
              0.8347376037115143, 0.26801402100751526`, 0.1808980745856452], 
             82 -> RGBColor[
              0.31859842780058983`, 0.45037567776345117`, 0.9415217879872938],
              199 -> RGBColor[
              0.27228850741332744`, 0.40352286375286894`, 0.938817799731216], 
             89 -> RGBColor[
              0.8539922331287186, 0.4160135401405583, 0.19933632946055357`], 
             144 -> RGBColor[
              0.8565158956399671, 0.43541151607797846`, 0.2017529915313943], 
             78 -> RGBColor[
              0.9279645300339343, 0.9453977435956535, 0.9929912793499938], 42 -> 
             RGBColor[
              0.5214414667269106, 0.6223686992161088, 0.9554689288452234], 
             154 -> RGBColor[
              0.9865275394369064, 0.9886968055777866, 0.8729370673481489], 
             168 -> RGBColor[
              0.9385923578753286, 0.9537228615659814, 0.988831299825661], 121 -> 
             RGBColor[
              0.5426755050288741, 0.6396074480921672, 0.9571405501231992], 
             128 -> RGBColor[
              0.8895815146715775, 0.5914972716636359, 0.22957644804826868`], 
             115 -> RGBColor[
              0.2655539192117794, 0.3964443845554878, 0.9384342748960682], 61 -> 
             RGBColor[
              0.2737970101358498, 0.4051083957588368, 0.9389037067296339], 93 -> 
             RGBColor[
              0.22414759348065547`, 0.35292371089939434`, 0.9360762459008504],
              88 -> RGBColor[
              0.7121946053554326, 0.7750911056739228, 0.9719485604909927], 21 -> 
             RGBColor[
              0.31620160663402885`, 0.4482996717367106, 0.9413690646619862], 
             62 -> RGBColor[
              0.3562346737166085, 0.4829743023231845, 0.943919936296637], 136 -> 
             RGBColor[
              0.9080066729340168, 0.6729841436820356, 0.24483821356303642`], 
             190 -> RGBColor[
              0.1797070620660458, 0.3062138946902057, 0.9335454233806629], 57 -> 
             RGBColor[
              0.3605779115447064, 0.4867361966324024, 0.9441966835704689], 
             111 -> RGBColor[
              0.4604958122832016, 0.5728902713682614, 0.9506710636761264], 63 -> 
             RGBColor[
              0.35285247495850214`, 0.48004481175316516`, 0.9437044255825313],
              75 -> RGBColor[
              0.28416143346402023`, 0.4160020618191376, 0.9394939453053829], 
             30 -> RGBColor[
              0.8937471851268821, 0.9181137615718546, 0.9897275984465748], 5 -> 
             RGBColor[
              0.2822070658609612, 0.41394789755425965`, 0.9393826469616164], 
             171 -> RGBColor[
              0.8744701613749067, 0.9027427860928997, 0.9878889387123091], 
             102 -> RGBColor[
              0.37383492502239923`, 0.4982187553899085, 0.9450414087465508], 
             31 -> RGBColor[
              0.8505083657915934, 0.8836363007203797, 0.9856034412586252], 96 -> 
             RGBColor[
              0.3061966914574528, 0.4391625150862857, 0.940748820649866], 70 -> 
             RGBColor[
              0.21367513065222027`, 0.34191648847421524`, 0.9354798546353913],
              52 -> RGBColor[
              0.21246269677098534`, 0.3406421435922893, 0.9354108083194902], 
             183 -> RGBColor[
              0.859910479347665, 0.45676803010411193`, 0.20481820887036734`], 
             158 -> RGBColor[
              0.25326504777876796`, 0.3835280015199418, 0.9377344418477144], 
             13 -> RGBColor[
              0.3779993100162068, 0.5018257363634689, 0.9453067596759351], 
             170 -> RGBColor[
              0.1823653638581298, 0.3090079384197544, 0.933696809735117], 86 -> 
             RGBColor[
              0.3919595940317969, 0.5139174327134967, 0.9461962966288141], 18 -> 
             RGBColor[
              0.3183704566888478, 0.45017822064462143`, 0.9415072618696405], 
             153 -> RGBColor[
              0.585970074369736, 0.674755929881201, 0.960548857214945], 58 -> 
             RGBColor[
              0.264153442110629, 0.394972394326802, 0.9383545197969779], 22 -> 
             RGBColor[
              0.8444218577904707, 0.34245144152557083`, 0.19017172722845446`],
              66 -> RGBColor[
              0.6916199917227627, 0.7590180611312259, 0.9698978752847841], 
             143 -> RGBColor[
              0.8207984422031169, 0.16087151747445233`, 0.16754991778317269`],
              119 -> RGBColor[
              0.5648783713319804, 0.6576327351847573, 0.9588884410903589], 
             145 -> RGBColor[
              0.20775586072121455`, 0.33569496047333813`, 0.9351427609695957],
              91 -> RGBColor[
              0.8378176201564483, 0.8735170446320284, 0.9843929866107827], 
             177 -> RGBColor[
              0.29360677442013106`, 0.4259297140332158, 0.9400318434997037], 
             200 -> RGBColor[
              0.23658832296539867`, 0.36599970637566703`, 0.9367847270405965],
              114 -> RGBColor[
              0.21718744139687057`, 0.3456081497602061, 0.935679875536301], 
             24 -> RGBColor[
              0.17892700283938517`, 0.30539400298437386`, 0.9335010001616988],
              176 -> RGBColor[
              0.29419693695473825`, 0.4265500122755539, 0.9400654523829823], 
             79 -> RGBColor[
              0.20396815225836698`, 0.3317138387242981, 0.934927056576049], 
             109 -> RGBColor[
              0.3375430035907792, 0.46678451713084806`, 0.942728919604614], 
             135 -> RGBColor[
              0.23327898842098083`, 0.3625213859455549, 0.9365962653340136], 
             108 -> RGBColor[
              0.7812325868423204, 0.8290241015195725, 0.9788296212889877], 
             191 -> RGBColor[
              0.28023078255701894`, 0.41187069849821767`, 0.939270100551106], 
             14 -> RGBColor[
              0.4167727741971154, 0.535409362225998, 0.9477773705275145], 185 -> 
             RGBColor[
              0.7695733223497783, 0.8199157954843064, 0.9776675347663926], 32 -> 
             RGBColor[
              0.23515166545220784`, 0.36448968823995603`, 0.9367029115205646],
              122 -> RGBColor[
              0.9929383277496677, 0.9873041220381521, 0.47275873901987264`], 
             187 -> RGBColor[
              0.28282713132653, 0.41459962567299363`, 0.939417958772576], 193 -> 
             RGBColor[
              0.31668648779682773`, 0.44871965142909115`, 0.9413999608609163],
              100 -> RGBColor[
              0.21381427791123173`, 0.3420627410658821, 0.9354877788659421], 
             180 -> 
             RGBColor[
              0.7240681721091139, 0.7843668262643483, 0.9731320066602097], 7 -> 
             RGBColor[
              0.350460125859892, 0.477972679206911, 0.9435519872134391], 175 -> 
             RGBColor[
              0.320397896026041, 0.45193428669643415`, 0.9416364485114123], 9 -> 
             RGBColor[
              0.2605668322464433, 0.39120263995534316`, 0.9381502676711264], 
             90 -> RGBColor[
              0.3879488339253545, 0.5104435138959607, 0.9459407345414075], 
             174 -> RGBColor[
              0.3814106085308894, 0.5047804316800383, 0.9455241246007979], 
             142 -> RGBColor[
              0.6408890467579492, 0.7193416257374643, 0.9648722798961695], 
             134 -> RGBColor[
              0.23085213233970892`, 0.3599706063325754, 0.9364580594703971], 
             105 -> RGBColor[
              0.34321032416564207`, 0.47169326536497985`, 0.9430900362602295],
              16 -> RGBColor[
              0.3229612837478847, 0.4541545643014821, 0.9417997853103334], 
             139 -> RGBColor[
              0.24915820796041388`, 0.3792114524821679, 0.9375005633955842], 
             146 -> RGBColor[
              0.79609453068194, 0.84063436500204, 0.9803109209581594], 126 -> 
             RGBColor[
              0.30722498883092086`, 0.4402433208236197, 0.9408073806640553], 
             198 -> RGBColor[
              0.6961608186542636, 0.7625653896416773, 0.9703504624768758], 40 -> 
             RGBColor[
              0.49158142165721236`, 0.5981269694488269, 0.9531182367163876], 
             104 -> RGBColor[
              0.21893481250696653`, 0.34744474758664423`, 0.9357793857360172],
              181 -> RGBColor[
              0.984329904565909, 0.9877880270819891, 0.9093575644573119], 127 -> 
             RGBColor[
              0.32158764066209233`, 0.4529647837018777, 0.9417122579875715], 
             76 -> RGBColor[
              0.27635030732849636`, 0.40779207299670056`, 0.9390491132274904],
              172 -> RGBColor[
              0.9939767127007667, 0.98952512245173, 0.5857805327779135], 84 -> 
             RGBColor[
              0.2627765683456537, 0.3935252127009741, 0.9382761088729649], 
             184 -> RGBColor[
              0.3711329893802169, 0.49587847453988415`, 0.9448692437966588], 
             151 -> RGBColor[
              0.3518764439127397, 0.4791994227180725, 0.9436422337473658], 35 -> 
             RGBColor[
              0.8383733051460716, 0.8739601327590868, 0.9844459883411588], 36 -> 
             RGBColor[
              0.24777983952010385`, 0.3777626998577953, 0.9374220673520219], 
             34 -> RGBColor[
              0.2517479206748871, 0.38193340474234894`, 0.9376480437035368], 
             38 -> RGBColor[
              0.9648082727380654, 0.8929521819142981, 0.31778721429778617`], 
             54 -> RGBColor[
              0.27280646441116213`, 0.40406726939796367`, 0.938847296615994], 
             60 -> RGBColor[
              0.253957266336059, 0.38425556711284614`, 0.9377738626705066], 
             87 -> RGBColor[
              0.9879745726157381, 0.9892951909842899, 0.8489559827730842], 
             141 -> RGBColor[
              0.3593385897430587, 0.4856627583779401, 0.9441177150811572], 67 -> 
             RGBColor[
              0.8182056947053702, 0.14094252405757224`, 0.16506709985124088`],
              133 -> RGBColor[
              0.8234278438149039, 0.18108225047377968`, 0.1700678357361042], 
             98 -> RGBColor[
              0.9734883859205871, 0.9797482621451334, 0.9297614266867937], 3 -> 
             RGBColor[
              0.26366336471100654`, 0.39445729190709694`, 0.938326610614074], 
             27 -> RGBColor[
              0.2767490295536739, 0.4082111553358114, 0.9390718198683575], 
             163 -> RGBColor[
              0.23302215960706, 0.36225144257823677`, 0.936581639313005], 85 -> 
             RGBColor[
              0.360155081261214, 0.48636996229290924`, 0.9441697411986989], 
             83 -> RGBColor[
              0.25584834544704116`, 0.3862432111598293, 0.9378815568282761], 
             28 -> RGBColor[
              0.29477679578460203`, 0.4271594806709139, 0.9400984744855188], 
             44 -> RGBColor[
              0.2834240796528994, 0.4152270562127178, 0.9394519540966568], 
             189 -> RGBColor[
              0.2313913752108486, 0.36053738478011593`, 0.9364887685541701], 
             15 -> RGBColor[
              0.32511075702074876`, 0.45601633001476893`, 0.9419367478465757],
              80 -> RGBColor[
              0.6198970672218798, 0.7022993910721819, 0.9632197143709355], 
             112 -> RGBColor[
              0.30144929209616883`, 0.4341726973550716, 0.9404784632793888], 
             169 -> RGBColor[
              0.2725827939998642, 0.40383217761416634`, 0.9388345589169613], 
             69 -> RGBColor[
              0.4015855979045752, 0.522254993451075, 0.9468096570836465], 20 -> 
             RGBColor[
              0.22540124214842158`, 0.354241375135133, 0.9361476393378726], 8 -> 
             RGBColor[
              0.44819737568646545`, 0.5626277725896778, 0.9497797183467319], 
             116 -> RGBColor[
              0.3895827819898638, 0.5118587575848209, 0.9460448482672345], 97 -> 
             RGBColor[
              0.28096145327109734`, 0.41263867974591306`, 0.9393117111673424],
              118 -> RGBColor[
              0.9133075269424444, 0.9337106471842498, 0.9915932813106664], 
             178 -> RGBColor[
              0.9424318889382709, 0.9565863775460686, 0.9823319752461818], 81 -> 
             RGBColor[
              0.5763338163997934, 0.6669327815527272, 0.9597902556887751], 
             166 -> RGBColor[
              0.39092445521974123`, 0.5130208475020834, 0.9461303384990473], 
             125 -> RGBColor[
              0.17895982839241617`, 0.30542850472186966`, 0.9335028695283829],
              95 -> RGBColor[
              0.9796258119030633, 0.9429352208414826, 0.3753505558963255], 
             157 -> RGBColor[
              0.5576848060128018, 0.6517926747922235, 0.9583221372775351], 74 -> 
             RGBColor[
              0.30278259996188467`, 0.4355740884585403, 0.9405543931898891], 
             19 -> RGBColor[
              0.26440158051900675`, 0.3952332035268908, 0.9383686509122472], 
             156 -> RGBColor[
              0.9208437466954219, 0.9397198242500384, 0.9923120926783682], 
             167 -> RGBColor[
              0.9152757732218003, 0.9352800733407862, 0.9917810143978655], 33 -> 
             RGBColor[0.3230400522816408, 0.4542227896464, 0.941804804371652],
              43 -> RGBColor[
              0.8553653759675705, 0.4265681177150025, 0.20065125259378117`], 
             140 -> RGBColor[
              0.30550365683416836`, 0.4384340917562807, 0.9407093533533227], 
             186 -> RGBColor[
              0.28203039141568953`, 0.41376220151047227`, 0.9393725856133247],
              117 -> RGBColor[
              0.7789983515005383, 0.8272786998897548, 0.9786069335902352], 4 -> 
             RGBColor[
              0.8048857220793089, 0.8475021105371937, 0.9811871447582946], 
             106 -> RGBColor[
              0.27505191676798696`, 0.40642738219488894`, 0.9389751718058661],
              65 -> RGBColor[
              0.9220936452530043, 0.9407164594322621, 0.992431309118588], 53 -> 
             RGBColor[
              0.21141226994966317`, 0.3395380784021726, 0.9353509880659832], 
             2 -> RGBColor[
              0.377120805174838, 0.5010648196248124, 0.9452507821242745], 147 -> 
             RGBColor[
              0.4806958664434177, 0.5892895853375945, 0.9522612859348552], 94 -> 
             RGBColor[
              0.4181274501813097, 0.5365827144755124, 0.9478636892833344], 23 -> 
             RGBColor[
              0.9935791491691084, 0.9886747742573517, 0.5425081958346172], 
             194 -> RGBColor[
              0.348529185002255, 0.47630019528793527`, 0.9434289493694545], 
             129 -> RGBColor[
              0.9902596908634175, 0.9788057915282733, 0.4166611676177604], 99 -> 
             RGBColor[
              0.5640955015617808, 0.656997166237428, 0.9588268107143023], 25 -> 
             RGBColor[
              0.9789215033713261, 0.9405594227844256, 0.37261445024803247`], 
             138 -> RGBColor[
              0.9127756759352338, 0.6918916514058181, 0.2486754653207034], 
             124 -> RGBColor[
              0.2910544796798416, 0.42324709043633846`, 0.9398864940900259], 
             197 -> RGBColor[
              0.8889169937097365, 0.9142622980478761, 0.9892668904772446], 
             164 -> RGBColor[
              0.29472306200537346`, 0.42710300306202637`, 0.9400954144262837],
              152 -> RGBColor[
              0.281739557244844, 0.41345651635696223`, 0.9393560230375456], 
             17 -> RGBColor[
              0.2388383031545141, 0.3683645782114108, 0.9369128600838192], 
             149 -> RGBColor[
              0.2335680080595618, 0.362825163910607, 0.9366127245748646]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9lnk01I33xy0ZCmPGjGUM5jOLCfGgkIjPm8rSZv1l6yGUlK0nopQSkiYJ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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.9759778030702638, 0.9313399748264705, 0.5237839339684474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 78}], {
             RGBColor[
             0.9431385588038124, 0.9082192270955545, 0.6427719916956993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 88}], {
             RGBColor[
             0.8352535964645615, 0.823065908134689, 0.6322506322661987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 89}], {
             RGBColor[
             0.9061524103512045, 0.6435271253680068, 0.2459445167509792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[
             0.9293073420017215, 0.7556088200837405, 0.2655373341471002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 122}], {
             RGBColor[
             0.9756254576616791, 0.9291724163168037, 0.38265572153063876`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 136}], {
             RGBColor[
             0.9331596302538536, 0.7720124271387454, 0.2686954588022206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 138}], {
             RGBColor[
             0.9355441317544622, 0.7814661810006367, 0.2706140846810541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 144}], {
             RGBColor[
             0.9074142416068287, 0.6532261133367169, 0.24715284778639957`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 159}], {
             RGBColor[
             0.8904785244591324, 0.5230507700609477, 0.2309351859196088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 167}], {
             RGBColor[
             0.9367941803977453, 0.9031603919681208, 0.6421668592196352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 197}], {
             RGBColor[
             0.9236147906417135, 0.8926515043216656, 0.6409097972593247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 26}], {
             RGBColor[
             0.3867618425079842, 0.5094154015901577, 0.945865100497908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 40}], {
             RGBColor[
             0.43435111341602517`, 0.5495958945368197, 0.9491845094203311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 51}], {
             RGBColor[
             0.329630384746231, 0.45747109460127056`, 0.9423148038761329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 74}], {
             RGBColor[
             0.3399517025683613, 0.46831945404167635`, 0.9429025876570818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 80}], {
             RGBColor[
             0.4985089361983589, 0.6016821053484971, 0.954235248247605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 121}], {
             RGBColor[
             0.45989815510185605`, 0.5703361338584898, 0.9511956661237368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 158}], {
             RGBColor[
             0.31519292647680297`, 0.4422964105723771, 0.9414926119859944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 164}], {
             RGBColor[
             0.3359219335901057, 0.4640839113434194, 0.9426730982752791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 166}], {
             RGBColor[
             0.3840226301972896, 0.5070428335634479, 0.9456905603116609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 169}], {
             RGBColor[
             0.3248517995873511, 0.4524484986194894, 0.942042670520618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 184}], {
             RGBColor[
             0.37412689727752746`, 0.49847164708234826`, 0.9450600129604667]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 5}], {
             RGBColor[
             0.27293521528598386`, 0.4042025947306783, 0.9388546287878452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 10}], {
             RGBColor[
             0.27648968445364525`, 0.4079385671922522, 0.9390570505485776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 11}], {
             RGBColor[
             0.2547628231142621, 0.3851022583619874, 0.9378197379373108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 15}], {
             RGBColor[
             0.2943870608658776, 0.4252368109609329, 0.9401316792303248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 20}], {
             RGBColor[
             0.24453230342971405`, 0.374349333521115, 0.9372371249759732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 28}], {
             RGBColor[
             0.2792200802478043, 0.4108083862890054, 0.9392125425497964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 48}], {
             RGBColor[
             0.29038303180772673`, 0.42176872223911466`, 0.9398765460393633]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 63}], {
             RGBColor[
             0.30825791983475437`, 0.437251051830131, 0.9410155180983026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 77}], {
             RGBColor[
             0.2820287158723724, 0.41376044040821036`, 0.9393724901936115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 106}], {
             RGBColor[
             0.26935764073949675`, 0.40044233705099297`, 0.93865089120997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 186}], {
             RGBColor[
             0.27284687806334806`, 0.40410974670878463`, 0.9388495981136993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 189}], {
             RGBColor[
             0.24752736996092756`, 0.37749733834360644`, 0.937407689584122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 41}], {
             RGBColor[
             0.6772999087061907, 0.7464119016615944, 0.969440899246723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 66}], {
             RGBColor[
             0.7482528569010358, 0.8032600858342098, 0.9755425100215394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 80}], {
             RGBColor[
             0.7123913946505943, 0.7749007508046878, 0.972203429564615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 81}], {
             RGBColor[
             0.6906097692395512, 0.7572174460449604, 0.9704887002235348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 168}], {
             RGBColor[
             0.8717390399773187, 0.9006124860515876, 0.9850092222919777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 172}], {
             RGBColor[
             0.8994312173900378, 0.9185136164944618, 0.783483838768104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 173}], {
             RGBColor[
             0.9000135688899087, 0.9197592074679171, 0.8468692056721795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 184}], {
             RGBColor[
             0.5880093557297629, 0.671690292538539, 0.9630281942774768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 198}], {
             RGBColor[
             0.7505232703667862, 0.8050337500894356, 0.9757688036175852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 9}], {
             RGBColor[
             0.27138694905370225`, 0.40257526875480143`, 0.9387664573163714]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.2640346736892395, 0.39484756118556874`, 0.938347756111082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 15}], {
             RGBColor[
             0.303658911440855, 0.4349821137845143, 0.940659697404096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 17}], {
             RGBColor[
             0.26052268450773763`, 0.3911562378828352, 0.9381477535227178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 20}], {
             RGBColor[
             0.2538041540046914, 0.3840946363446963, 0.9377651431497445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 28}], {
             RGBColor[
             0.28849193082278163`, 0.4205536891125868, 0.9397405607235676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 48}], {
             RGBColor[
             0.2996548823827041, 0.431514025062696, 0.9404045642131346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 63}], {
             RGBColor[
             0.3175297704097317, 0.4469963546537124, 0.9415435362720739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[
             0.2913005664473497, 0.42350574323179174`, 0.9399005083673827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 102}], {
             RGBColor[
             0.32802099544168023`, 0.45608332647208405`, 0.9422120278540836]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 106}], {
             RGBColor[
             0.2786294913144741, 0.4101876398745743, 0.9391789093837413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 112}], {
             RGBColor[
             0.29182817897856506`, 0.4240602974546656, 0.9399305551205026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 140}], {
             RGBColor[
             0.2938553613475648, 0.42619099465527016`, 0.9400460001574695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 189}], {
             RGBColor[
             0.2567992205359049, 0.38724264116718776`, 0.9379357077578933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 12}], {
             RGBColor[
             0.4620072235822212, 0.5710418605945535, 0.9516398014511775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 13}], {
             RGBColor[
             0.35902556110322426`, 0.48539162870339236`, 0.9440977691730272]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 14}], {
             RGBColor[
             0.37841229319367853`, 0.5021834416346569, 0.945333074598817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 16}], {
             RGBColor[
             0.3315065479690632, 0.46155604267239897`, 0.9423442819902264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 59}], {
             RGBColor[
             0.39442835550292343`, 0.516055749816227, 0.9463536039267142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 64}], {
             RGBColor[
             0.4813272203866353, 0.5867267043563145, 0.9531607423711013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 83}], {
             RGBColor[
             0.29795007881864144`, 0.4276003661015726, 0.9403851677491978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 86}], {
             RGBColor[
             0.3660057031110193, 0.4914374768784062, 0.9445425376494667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 124}], {
             RGBColor[
             0.3155531459350417, 0.4461023057398271, 0.9413876363800726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 137}], {
             RGBColor[
             0.2951194473890727, 0.4246251929966973, 0.9402239674768278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 161}], {
             RGBColor[
             0.32435538961719373`, 0.45535402194425245`, 0.9418889111360187]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 175}], {
             RGBColor[
             0.3302248541081414, 0.460445903869875, 0.9422626135907659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 176}], {
             RGBColor[
             0.31712437457249, 0.4477537666594349, 0.9414771155265509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 186}], {
             RGBColor[
             0.3110411018029656, 0.4413598612768941, 0.941130682141722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 187}], {
             RGBColor[
             0.3114394717583858, 0.44177857335815474`, 0.9411533687213477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 193}], {
             RGBColor[
             0.3283691499935347, 0.4588385862362035, 0.9421443697655179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 199}], {
             RGBColor[
             0.3061701598017846, 0.4362401923980924, 0.9408532892006678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 18}], {
             RGBColor[
             0.33441529127436986`, 0.4640754499257662, 0.9425296245415398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 42}], {
             RGBColor[
             0.4359507962934013, 0.5501706892115099, 0.9495104580293312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 47}], {
             RGBColor[
             0.40099092685927107`, 0.5217399192806683, 0.9467717651704868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.31163329513552707`, 0.44101997430243733`, 0.9411996419147166]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 58}], {
             RGBColor[
             0.3073067839852605, 0.4364725367668565, 0.9409532535052085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.3121285679978709, 0.4415405374828739, 0.9412278469715365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 73}], {
             RGBColor[
             0.3217974307185043, 0.4517031252435637, 0.941778474399676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 88}], {
             RGBColor[
             0.5313273656076622, 0.6265318924404168, 0.9577502738522159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 94}], {
             RGBColor[
             0.3842937880206009, 0.5072776968412117, 0.9457078382483868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 97}], {
             RGBColor[
             0.3157107895654947, 0.44530567947641203`, 0.9414318491903908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 115}], {
             RGBColor[
             0.3080070225358357, 0.4372085318811994, 0.9409931310547537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 153}], {
             RGBColor[
             0.46821510011481404`, 0.5763643045440561, 0.9520504222141921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 160}], {
             RGBColor[
             0.3585859521924276, 0.48501086156024664`, 0.9440697576819622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 188}], {
             RGBColor[
             0.5075570604878807, 0.6079623494198335, 0.955381071984007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 55}], {
             RGBColor[
             0.4002897149094885, 0.5211325647337041, 0.9467270845651039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 62}], {
             RGBColor[
             0.40221602470153694`, 0.5228010374564311, 0.9468498273216844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 68}], {
             RGBColor[
             0.6519110948314109, 0.7251718951051506, 0.9679355855003635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 75}], {
             RGBColor[
             0.36617940457524284`, 0.4893149172044077, 0.9446368318260574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 96}], {
             RGBColor[
             0.3771970335719591, 0.5008951438379817, 0.9452642694982989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 99}], {
             RGBColor[
             0.5061464386241231, 0.6098124694135529, 0.9543032645305172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 107}], {
             RGBColor[
             0.5577142065740452, 0.6512964986445926, 0.9586233652992509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 147}], {
             RGBColor[
             0.4644466210649416, 0.5759586789636362, 0.9510205021407936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 156}], {
             RGBColor[
             0.6845205611909437, 0.7511737984198581, 0.97104590551255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 157}], {
             RGBColor[
             0.5029410908496337, 0.6072102236909507, 0.9540509278121335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 179}], {
             RGBColor[
             0.6280655556399748, 0.706255507224953, 0.9656353303034069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 185}], {
             RGBColor[
             0.6088853490181219, 0.6912717840369921, 0.9637236265565623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 194}], {
             RGBColor[
             0.3983632803443602, 0.5194639839388066, 0.9466043338580932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.2532145568819805, 0.3834749323861105, 0.937731566465837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 17}], {
             RGBColor[
             0.2497025677004787, 0.37978360908337694`, 0.9375315638774728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 20}], {
             RGBColor[
             0.24298403719743245`, 0.3727220075452381, 0.9371489535044994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 28}], {
             RGBColor[
             0.27767181401552266`, 0.4091810603131285, 0.9391243710783226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 63}], {
             RGBColor[
             0.3067096536024727, 0.43562372585425413`, 0.9409273466268289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 77}], {
             RGBColor[
             0.2804804496400908, 0.41213311443233347`, 0.9392843187221377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 97}], {
             RGBColor[
             0.2707641427587703, 0.4019206598506281, 0.9387309894192344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 102}], {
             RGBColor[
             0.31720087863442126`, 0.44471069767262583`, 0.9415958382088386]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.2678093745072151, 0.3988150110751161, 0.9385627197384963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 112}], {
             RGBColor[
             0.28100806217130603`, 0.41268766865520734`, 0.9393143654752576]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 140}], {
             RGBColor[
             0.2830352445403058, 0.4148183658558119, 0.9394298105122245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 189}], {
             RGBColor[
             0.24597910372864595`, 0.37587001236772954`, 0.9373195181126482]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 14}], {
             RGBColor[
             0.35304438919669967`, 0.4784146023517027, 0.943782430505298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.30721338060851633`, 0.43871808624608816`, 0.9408621191648285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 28}], {
             RGBColor[
             0.292046399990443, 0.42428966157416065`, 0.9399429824843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 48}], {
             RGBColor[
             0.30320935155036544`, 0.43524999752426985`, 0.940606985973867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 59}], {
             RGBColor[
             0.3690604515059446, 0.4922869105332728, 0.9448029598331952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 77}], {
             RGBColor[
             0.2948550356150111, 0.4272417156933656, 0.9401029301281152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 186}], {
             RGBColor[
             0.28567319780598677`, 0.4175910219939398, 0.939580038048203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 193}], {
             RGBColor[
             0.30300124599655587`, 0.4350697469532493, 0.9405937256719987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 15}], {
             RGBColor[
             0.28548651926913327`, 0.4158817774158234, 0.9396248065535615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 17}], {
             RGBColor[
             0.24235029233601593`, 0.3720559015141443, 0.9371128626721834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 20}], {
             RGBColor[
             0.2356317618329697, 0.3649942999760054, 0.93673025229921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 28}], {
             RGBColor[
             0.2703195386510599, 0.4014533527438959, 0.9387056698730332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 48}], {
             RGBColor[
             0.2814824902109824, 0.4124136886940051, 0.9393696733626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 63}], {
             RGBColor[
             0.29935737823800995`, 0.4278960182850215, 0.9405086454215394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 77}], {
             RGBColor[
             0.27312817427562797`, 0.40440540686310084`, 0.9388656175168482]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 106}], {
             RGBColor[
             0.2604570991427524, 0.3910873035058834, 0.9381440185332068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 112}], {
             RGBColor[
             0.2736557868068433, 0.4049599610859747, 0.9388956642699682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 140}], {
             RGBColor[
             0.27568296917584306`, 0.40709065828657925`, 0.9390111093069351]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 189}], {
             RGBColor[
             0.2386268283641832, 0.36814230479849686`, 0.9369008169073587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 13}], {
             RGBColor[
             0.4809809724952037, 0.58747596825463, 0.9528487919540853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 14}], {
             RGBColor[
             0.500367704585658, 0.6042677811858945, 0.954084097379875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.45346195936104267`, 0.5636403822236367, 0.9510953047712845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 23}], {
             RGBColor[
             0.7887708920716545, 0.8309004872015715, 0.7514495100334264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 25}], {
             RGBColor[
             0.7814420691727634, 0.8068428114651084, 0.666502637240134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 59}], {
             RGBColor[
             0.516383766894903, 0.6181400893674647, 0.9551046267077723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.6032826317786147, 0.6888110439075521, 0.9619117651521593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 86}], {
             RGBColor[
             0.4879611145029988, 0.5935218164296439, 0.9532935604305248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 87}], {
             RGBColor[
             0.7859686037949694, 0.8312106955650405, 0.9046734035026598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 95}], {
             RGBColor[
             0.7817942234386319, 0.8080307104936368, 0.6678706900642806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 108}], {
             RGBColor[
             0.6825976109082605, 0.7510751508326818, 0.9696102227606116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 154}], {
             RGBColor[
             0.7852450872055535, 0.8309115028617888, 0.9166639457901922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 161}], {
             RGBColor[
             0.4463108010091732, 0.5574383614954901, 0.9506399339170767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 175}], {
             RGBColor[
             0.4521802655001208, 0.5625302434211127, 0.9510136363718239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 193}], {
             RGBColor[
             0.4503245613855142, 0.5609229257874412, 0.950895392546576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 16}], {
             RGBColor[
             0.35048029688204574`, 0.4779901503324755, 0.9435532724931343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 64}], {
             RGBColor[
             0.5003009692996179, 0.6031608120163909, 0.9543697328740091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 69}], {
             RGBColor[
             0.38979245396039097`, 0.512040364907272, 0.9460582083797908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 82}], {
             RGBColor[
             0.34829886890839834`, 0.4761007070634601, 0.9434142738316145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 83}], {
             RGBColor[
             0.316923827731624, 0.4440344737616491, 0.9415941582521057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 86}], {
             RGBColor[
             0.38497945202400186`, 0.5078715845384828, 0.9457515281523746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 101}], {
             RGBColor[
             0.3149218240784437, 0.4419302409877936, 0.941480147105756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 108}], {
             RGBColor[
             0.5796159484292636, 0.6654249189415207, 0.9620681904824614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 110}], {
             RGBColor[
             0.49151316787654187`, 0.5960264789351953, 0.9536779249552072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 124}], {
             RGBColor[
             0.3345268948480242, 0.4625364133999037, 0.9425966268829805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 127}], {
             RGBColor[
             0.34979347533914956`, 0.4773952600326733, 0.9435095088317533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 137}], {
             RGBColor[
             0.31409319630205523`, 0.44105930065677384`, 0.9414329579797356]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 161}], {
             RGBColor[
             0.34332913853017627`, 0.471788129604329, 0.9430979016389265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 175}], {
             RGBColor[
             0.34919860302112393`, 0.4768800115299515, 0.9434716040936737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 176}], {
             RGBColor[
             0.3360981234854725, 0.4641878743195114, 0.9426861060294587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 187}], {
             RGBColor[
             0.33041322067136836`, 0.4582126810182313, 0.9423623592242556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 199}], {
             RGBColor[
             0.3251439087147671, 0.45267430005816894`, 0.9420622797035756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 15}], {
             RGBColor[
             0.3709417656089321, 0.49571284612038347`, 0.9448570591870451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 48}], {
             RGBColor[
             0.36693773655078116`, 0.49224475739856516`, 0.9446019259960836]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 59}], {
             RGBColor[
             0.43278883650636024`, 0.549281670407568, 0.9487978998554119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 186}], {
             RGBColor[
             0.34940158280640243`, 0.47458578186823513`, 0.9435749780704197]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 193}], {
             RGBColor[
             0.36672963099697153`, 0.49206450682754455`, 0.9445886656942154]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 28}], {
             RGBColor[
             0.3099437764026754, 0.4415879053428414, 0.9410176111660472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 48}], {
             RGBColor[
             0.32110672796259787`, 0.4525482412929506, 0.9416816146556142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 59}], {
             RGBColor[
             0.38695782791817696`, 0.5095851543019536, 0.9458775885149424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 63}], {
             RGBColor[
             0.33898161598962545`, 0.46803057088396705`, 0.9428205867145535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 77}], {
             RGBColor[
             0.31275241202724346`, 0.4445399594620464, 0.9411775588098623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 106}], {
             RGBColor[
             0.3000813368943679, 0.43122185610482894`, 0.9404559598262209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.3132800245584588, 0.44509451368492026`, 0.9412076055629822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 140}], {
             RGBColor[
             0.31530720692745856`, 0.4472252108855248, 0.9413230505999493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 193}], {
             RGBColor[
             0.32089862240878825`, 0.45236799072193, 0.941668354353746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 64}], {
             RGBColor[
             0.47278195616545676`, 0.5793252259853976, 0.9526162456912082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 83}], {
             RGBColor[
             0.2894048145974629, 0.4201988877306557, 0.9398406710693048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 86}], {
             RGBColor[
             0.3574604388898408, 0.48403599850748935`, 0.9439980409695737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 101}], {
             RGBColor[
             0.28740281094428266`, 0.4180946549568002, 0.9397266599229551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 124}], {
             RGBColor[
             0.3070078817138632, 0.43870082736891025`, 0.9408431397001796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 127}], {
             RGBColor[
             0.3222744622049885, 0.4535596740016799, 0.9417560216489524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 137}], {
             RGBColor[
             0.2865741831678942, 0.41722371462578045`, 0.9396794707969347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 161}], {
             RGBColor[
             0.3158101253960152, 0.4479525435733356, 0.9413444144561256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 175}], {
             RGBColor[
             0.3216795898869629, 0.4530444254989581, 0.9417181169108728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 176}], {
             RGBColor[
             0.30857911035131147`, 0.440352288288518, 0.9409326188466578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.3028942075372073, 0.43437709498723787`, 0.9406088720414547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 193}], {
             RGBColor[
             0.3198238857723562, 0.4514371078652866, 0.9415998730856248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 199}], {
             RGBColor[
             0.29762489558060606`, 0.42883871402717555`, 0.9403087925207747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 20}], {
             RGBColor[
             0.23211977265146783`, 0.3613029766732719, 0.9365302497108459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 28}], {
             RGBColor[
             0.2668075494695581, 0.39776202944116235`, 0.938505667284669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 77}], {
             RGBColor[
             0.26961618509412616`, 0.4007140835603673, 0.9386656149284841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 106}], {
             RGBColor[
             0.25694510996125053`, 0.38739598020314986`, 0.9379440159448427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 112}], {
             RGBColor[
             0.27014379762534146`, 0.4012686377832412, 0.938695661681604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 140}], {
             RGBColor[
             0.27217097999434126`, 0.4033993349838457, 0.9388111067185709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 189}], {
             RGBColor[
             0.23511483918268133`, 0.3644509814957634, 0.9367008143189947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 47}], {
             RGBColor[
             0.38494609227374893`, 0.5078426899995235, 0.9457494024985874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 54}], {
             RGBColor[
             0.295588460550005, 0.42712274502129255`, 0.9401772792428172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 58}], {
             RGBColor[
             0.2912619493997384, 0.4225753074857117, 0.9399308908333093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 61}], {
             RGBColor[
             0.2960837334123488, 0.42764330820172913`, 0.9402054842996372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 73}], {
             RGBColor[
             0.3057525961329822, 0.4378058959624189, 0.9407561117277767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 94}], {
             RGBColor[
             0.36824895343507874`, 0.4933804675600669, 0.9446854755764875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 115}], {
             RGBColor[
             0.2919621879503136, 0.4233113026000546, 0.9399707683828544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 116}], {
             RGBColor[
             0.35397661933935576`, 0.48101848911472117`, 0.9437760550684375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 153}], {
             RGBColor[
             0.4521702655292919, 0.5624670752629113, 0.9510280595422927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 160}], {
             RGBColor[
             0.34254111760690553`, 0.47111363227910186`, 0.9430473950100628]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 174}], {
             RGBColor[
             0.3498905326098686, 0.47747932616232985`, 0.9435156932352192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 188}], {
             RGBColor[
             0.49151222590235866`, 0.5940651201386887, 0.9543587093121076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 33}], {
             RGBColor[
             0.29372081640032377`, 0.4247279965866454, 0.9400867276419496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 34}], {
             RGBColor[
             0.25807475059694696`, 0.38858330413461983`, 0.938008347307892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 44}], {
             RGBColor[
             0.2739128300859531, 0.40523012986980433`, 0.9389103025044521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 50}], {
             RGBColor[
             0.2533169376668154, 0.3835825410822887, 0.9377373969000744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 60}], {
             RGBColor[
             0.25917942342753286`, 0.38974438531986844`, 0.9380712567913769]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 90}], {
             RGBColor[
             0.32617520722218063`, 0.45283835871142575`, 0.9421546927268274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 130}], {
             RGBColor[
             0.2508128361327613, 0.38095057160079043`, 0.9375947920221963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 141}], {
             RGBColor[
             0.31187008513103276`, 0.44044798095241544`, 0.9412431829967022]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 177}], {
             RGBColor[
             0.2790041774695689, 0.41058145878005325`, 0.9392002472059755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.2600890189665118, 0.39070042790302345`, 0.9381230569116956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 77}], {
             RGBColor[
             0.2628976545910799, 0.3936524820222284, 0.9382830045555108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 106}], {
             RGBColor[
             0.25022657945820426`, 0.38033437866501096`, 0.9375614055718693]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 189}], {
             RGBColor[
             0.2283963086796351, 0.35738937995762443`, 0.9363182039460214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.28199072307706635`, 0.41303118579725295`, 0.9393955660070041]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 46}], {
             RGBColor[
             0.4569720284859443, 0.5663064733841641, 0.9514223432183879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 85}], {
             RGBColor[
             0.3381783439476214, 0.46733481701480994`, 0.9427694029303426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 109}], {
             RGBColor[
             0.32687230511240406`, 0.45754209443377936`, 0.9420489921333002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 132}], {
             RGBColor[
             0.28420798371714023`, 0.41536166731241486`, 0.9395218357203131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 150}], {
             RGBColor[
             0.29956418872733326`, 0.4315020124177601, 0.9403963488781741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 151}], {
             RGBColor[
             0.33403902527338425`, 0.46374954722739153`, 0.9425056492046759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 194}], {
             RGBColor[
             0.33236539581814195`, 0.4622999335123229, 0.9423990070157204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 196}], {
             RGBColor[
             0.4056875246476441, 0.5246714028276624, 0.9473850392149095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 24}], {
             RGBColor[
             0.511674430314928, 0.3239227222549723, 0.5618363636950766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 37}], {
             RGBColor[
             0.517707803293592, 0.3302641797934895, 0.5621799553606361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 38}], {
             RGBColor[
             0.904615065264268, 0.6177018117199344, 0.25397947076312033`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 79}], {
             RGBColor[
             0.5241950050244188, 0.3370826401249345, 0.5625493919022517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 89}], {
             RGBColor[
             0.8492070454595947, 0.37923249083306454`, 0.194754028344504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 118}], {
             RGBColor[
             0.8788646923664576, 0.6380810443549103, 0.5908825042695605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 119}], {
             RGBColor[
             0.7046501145612256, 0.5000420883551641, 0.5745300841594067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 122}], {
             RGBColor[
             0.9186800927700692, 0.6648777817818614, 0.33146523312416354`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 128}], {
             RGBColor[
             0.8670016862310241, 0.46697435659460335`, 0.20987408763836157`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 138}], {
             RGBColor[
             0.8785987668628523, 0.5171715464656945, 0.2194235962745789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 144}], {
             RGBColor[
             0.8504688767152189, 0.38893147880177464`, 0.1959623593799244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 149}], {
             RGBColor[
             0.5389949329250163, 0.35263830271808894`, 0.5633922259016595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 181}], {
             RGBColor[
             0.9143758811781899, 0.66511973430378, 0.5497646458428832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 183}], {
             RGBColor[
             0.8521661685690678, 0.3996097358148414, 0.1974949680494109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 190}], {
             RGBColor[
             0.5120644599282582, 0.3243326681078883, 0.5618585753045587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 192}], {
             RGBColor[
             0.8308704288952353, 0.23828922076278541`, 0.17719486361422723`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 25}], {
             RGBColor[
             0.9862503262702172, 0.9646170985208886, 0.4575613230413248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 43}], {
             RGBColor[
             0.9244722625683395, 0.7076214459861772, 0.37157972421419916`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 49}], {
             RGBColor[
             0.9141583764403114, 0.6283443976324334, 0.3617031352101312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 64}], {
             RGBColor[
             0.8080908888760686, 0.8465853309633324, 0.7529704509533501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 67}], {
             RGBColor[
             0.9058924219372393, 0.564808649157462, 0.35378764784292904`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 87}], {
             RGBColor[
             0.9907768608924232, 0.9889849826208208, 0.6957320893038507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 95}], {
             RGBColor[
             0.9866024805360858, 0.9658049975494172, 0.45892937586547133`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 103}], {
             RGBColor[
             0.928934953541638, 0.7326663131459502, 0.37549070825566344`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 108}], {
             RGBColor[
             0.8874058680057144, 0.9088494378884622, 0.7606689085618024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 129}], {
             RGBColor[
             0.9919194200162629, 0.9837402828928126, 0.4795846817261888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 131}], {
             RGBColor[
             0.9464189057965813, 0.8120568568548516, 0.39007974658807487`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 143}], {
             RGBColor[
             0.9071887956861127, 0.574773145865902, 0.35502905680889496`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 154}], {
             RGBColor[
             0.9900533443030074, 0.9886857899175692, 0.707722631591383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 162}], {
             RGBColor[
             0.9882402059749112, 0.9877215722762983, 0.728168038634343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.22783801619652955`, 0.3568025791600926, 0.9362864100150281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 37}], {
             RGBColor[
             0.18496037581804925`, 0.31173546052289103`, 0.9338445918272582]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 56}], {
             RGBColor[
             0.1789270014196926, 0.30539400149218693`, 0.9335010000808495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 79}], {
             RGBColor[
             0.1914475775488761, 0.318553920854336, 0.9342140283688739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 89}], {
             RGBColor[
             0.5164596179840519, 0.3607037715624661, 0.5664186648111262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 118}], {
             RGBColor[
             0.5461172648909147, 0.6195523250843118, 0.9625471407361825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 119}], {
             RGBColor[
             0.37190268708568275`, 0.48151336908456555`, 0.9461947206260288]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 125}], {
             RGBColor[
             0.17894341561590066`, 0.30541125385312173`, 0.9335019348450408]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 144}], {
             RGBColor[
             0.5177214492396762, 0.3704027595311762, 0.5676269958465465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 149}], {
             RGBColor[
             0.20624750544947348`, 0.3341095834474904, 0.9350568623682817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 170}], {
             RGBColor[
             0.18064618334875748`, 0.3072009707020641, 0.9335989049484079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 190}], {
             RGBColor[
             0.1793170324527155, 0.3058039488372898, 0.9335232117711809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 195}], {
             RGBColor[
             0.1789270014196926, 0.30539400149218693`, 0.9335010000808495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 197}], {
             RGBColor[
             0.5339219982745609, 0.6098281505161249, 0.9613839453194717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[
             0.9171434396694482, 0.683563770249714, 0.28663285142090683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 49}], {
             RGBColor[
             0.9068295535414201, 0.6042867218959704, 0.2767562624168388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 64}], {
             RGBColor[
             0.8007620659771775, 0.8225276552268693, 0.6680235781600576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 67}], {
             RGBColor[
             0.8985635990383481, 0.540750973420999, 0.26884077504963666`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 87}], {
             RGBColor[
             0.9834480379935321, 0.9649273068843578, 0.6107852165105583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 95}], {
             RGBColor[
             0.9792736576371948, 0.9417473218129542, 0.37398250307217895`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 103}], {
             RGBColor[
             0.9216061306427468, 0.7086086374094871, 0.2905438354623711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 108}], {
             RGBColor[
             0.8800770451068233, 0.8847917621519991, 0.6757220357685101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 129}], {
             RGBColor[
             0.9845905971173718, 0.9596826071563495, 0.39463780893289646`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 131}], {
             RGBColor[
             0.93909008289769, 0.7879991811183886, 0.30513287379478254`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 143}], {
             RGBColor[
             0.8998599727872215, 0.550715470129439, 0.2700821840156026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 154}], {
             RGBColor[
             0.9827245214041163, 0.9646281141811062, 0.6227757587980907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 162}], {
             RGBColor[
             0.9809113830760201, 0.9636638965398352, 0.6432211658410507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 40}], {
             RGBColor[
             0.4439921507491714, 0.557946476502165, 0.9497988277939646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 51}], {
             RGBColor[
             0.3392714220793772, 0.4658216765666159, 0.9429291222497664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 74}], {
             RGBColor[
             0.3495927399015075, 0.4766700360070217, 0.9435169060307154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 80}], {
             RGBColor[
             0.5081499735315052, 0.6100326873138424, 0.9548495666212384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 121}], {
             RGBColor[
             0.46953919243500225`, 0.5786867158238351, 0.9518099844973704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 158}], {
             RGBColor[
             0.3248339638099492, 0.45064699253772245`, 0.9421069303596279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 164}], {
             RGBColor[
             0.34556297092325194`, 0.47243449330876475`, 0.9432874166489127]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.3936636675304358, 0.5153934155287933, 0.9463048786852943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 169}], {
             RGBColor[
             0.3344928369204973, 0.4607990805848347, 0.9426569888942514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 184}], {
             RGBColor[
             0.38376793461067366`, 0.5068222290476936, 0.9456743313341002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 37}], {
             RGBColor[
             0.23387138917519362`, 0.3631440366986098, 0.9366300016805876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 56}], {
             RGBColor[
             0.22783801477683696`, 0.3568025776679057, 0.9362864099341788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 67}], {
             RGBColor[
             0.5474773621295221, 0.27457683969669183`, 0.5520694598597993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 119}], {
             RGBColor[
             0.4208137004428272, 0.5329219452602844, 0.9489801304793581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 125}], {
             RGBColor[
             0.22785442897304503`, 0.35681983002884055`, 0.9362873446983702]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 128}], {
             RGBColor[
             0.5831652721126257, 0.49985421349972364`, 0.5843241339583132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 133}], {
             RGBColor[
             0.5500884366842889, 0.29464670290479555`, 0.5545698278022309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 190}], {
             RGBColor[
             0.22822804580985986`, 0.3572125250130086, 0.9363086216245102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 195}], {
             RGBColor[
             0.22783801477683696`, 0.3568025776679057, 0.9362864099341788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 48}], {
             RGBColor[
             0.30593974734452445`, 0.4381198166210231, 0.9407624779750857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 63}], {
             RGBColor[
             0.3238146353715521, 0.45360214621203954`, 0.941901450034025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 77}], {
             RGBColor[
             0.29758543140917015`, 0.4301115347901189, 0.9402584221293339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 106}], {
             RGBColor[
             0.28491435627629447`, 0.41679343143290143`, 0.9395368231456924]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 112}], {
             RGBColor[
             0.2981130439403854, 0.43066608901299275`, 0.9402884688824538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 140}], {
             RGBColor[
             0.3001402263093852, 0.4327967862135973, 0.9404039139194207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 189}], {
             RGBColor[
             0.26308408549772533`, 0.39384843272551495`, 0.9382936215198444]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 35}], {
             RGBColor[
             0.9160081618564544, 0.9327996859082862, 0.8697305761183244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 47}], {
             RGBColor[
             0.7225823732127437, 0.7785731992059557, 0.8525033535115121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 88}], {
             RGBColor[
             0.8529188119611348, 0.8833651723657042, 0.8634818621932413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 89}], {
             RGBColor[
             0.9238176258477779, 0.703826389599022, 0.47717574667802176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 113}], {
             RGBColor[
             0.946972557498295, 0.8159080843147557, 0.4967685640741427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 122}], {
             RGBColor[
             0.9932906731582525, 0.9894716805478189, 0.6138869514576812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 136}], {
             RGBColor[
             0.950824845750427, 0.8323116913697606, 0.49992668872926316`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 138}], {
             RGBColor[
             0.9532093472510355, 0.8417654452316519, 0.5018453146080967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 142}], {
             RGBColor[
             0.8172660326623933, 0.855490432397475, 0.8599437218958297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 144}], {
             RGBColor[
             0.9250794571034022, 0.713525377567732, 0.47838407771344216`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 153}], {
             RGBColor[
             0.7898065464682866, 0.8331975844693433, 0.8577820105552174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 159}], {
             RGBColor[
             0.9081437399557057, 0.5833500342919629, 0.46216641584665136`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 167}], {
             RGBColor[
             0.9544593958943188, 0.963459656199136, 0.8733980891466777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 181}], {
             RGBColor[
             0.988986461566373, 0.9897136330697374, 0.8321863641764009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 188}], {
             RGBColor[
             0.8291485068413533, 0.8647956293451209, 0.8611126603250323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 41}], {
             RGBColor[
             0.7217306402299773, 0.781717727178925, 0.9737111260908631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 65}], {
             RGBColor[
             0.9079204151899432, 0.9294151105020584, 0.9910794537825813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 66}], {
             RGBColor[
             0.7926835884248224, 0.8385659113515402, 0.9798127368656795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 90}], {
             RGBColor[
             0.6408480095261183, 0.7142786377339077, 0.9678341664939911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 110}], {
             RGBColor[
             0.7493871054318795, 0.8041704915393881, 0.9758883443405271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 162}], {
             RGBColor[
             0.9383242239537981, 0.9524410659335498, 0.9517777399403218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 180}], {
             RGBColor[
             0.8089076786179981, 0.8512402939181014, 0.9814298025533923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 198}], {
             RGBColor[
             0.7949540018905729, 0.840339575606766, 0.9800390304617252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 38}], {
             RGBColor[
             0.9076583192648293, 0.8882942413173389, 0.6516953277782057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[
             0.6710448937244029, 0.7408816350846033, 0.9693608389875064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 46}], {
             RGBColor[
             0.7241254080647266, 0.7839747878759986, 0.9735395315167075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 80}], {
             RGBColor[
             0.7352027165067365, 0.7929678458962808, 0.9744115778147804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 98}], {
             RGBColor[
             0.9119983758560902, 0.9316922814327566, 0.9576824339727095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 117}], {
             RGBColor[
             0.8147533586460658, 0.8554575003050673, 0.9821051874244302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 120}], {
             RGBColor[
             0.9036386065731989, 0.8747348065350462, 0.6360795030302686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 121}], {
             RGBColor[
             0.6965919354102337, 0.7616218744062735, 0.9713719956909121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 146}], {
             RGBColor[
             0.8233014482367667, 0.8621353328612098, 0.9829571811083924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 151}], {
             RGBColor[
             0.6011924048521665, 0.6814178617192261, 0.9646228375029955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 171}], {
             RGBColor[
             0.8624892635832501, 0.8931895434066397, 0.9867461899854671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 173}], {
             RGBColor[
             0.9228248907460509, 0.93782630255951, 0.8490773539223448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 178}], {
             RGBColor[
             0.8964701273649321, 0.9201113391332241, 0.9839677082524034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 196}], {
             RGBColor[
             0.6728409042264264, 0.742339717319497, 0.969502227513229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 53}], {
             RGBColor[
             0.2232819677009355, 0.3520138833210643, 0.9360269497932738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 82}], {
             RGBColor[
             0.27687504662639884`, 0.4074326830017036, 0.9391123497539292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 83}], {
             RGBColor[
             0.2455000054496245, 0.37536644969989263`, 0.9372922341744203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 100}], {
             RGBColor[
             0.22448297168171977`, 0.35327621465291903`, 0.9360953451932534]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 101}], {
             RGBColor[
             0.2434980017964442, 0.3732622169260371, 0.9371782230280707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 123}], {
             RGBColor[
             0.24279155375346242`, 0.3725196952414703, 0.9371379918571192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 127}], {
             RGBColor[
             0.2783696530571501, 0.40872723597091687`, 0.9392075847540681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 130}], {
             RGBColor[
             0.23618787859936186`, 0.36557881395732306`, 0.936761922326355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 135}], {
             RGBColor[
             0.23421532693659433`, 0.36350553709275546`, 0.9366495884272892]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 148}], {
             RGBColor[
             0.219972379693155, 0.3485352964848875, 0.9358384736523275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 163}], {
             RGBColor[
             0.23408691252963393`, 0.3633705654090964, 0.9366422754167848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 165}], {
             RGBColor[
             0.2270272954930984, 0.35595046029812505`, 0.9362402406703216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 176}], {
             RGBColor[
             0.264674301203473, 0.39551985025775493`, 0.9383841819517735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 187}], {
             RGBColor[
             0.2589893983893689, 0.38954465695647483`, 0.9380604351465702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 41}], {
             RGBColor[
             0.4363770738073567, 0.5497722412161976, 0.9497497290534018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 44}], {
             RGBColor[
             0.3032320659672701, 0.4347249229295589, 0.9406283792341544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 57}], {
             RGBColor[
             0.3418089819131736, 0.4704794931394012, 0.9430007439710605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 66}], {
             RGBColor[
             0.5073300220022017, 0.606620425388813, 0.955851339828218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 90}], {
             RGBColor[
             0.35549444310349765`, 0.4823331517711803, 0.9438727694565298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 141}], {
             RGBColor[
             0.3411893210123498, 0.46994277401217005`, 0.9429612597264045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 198}], {
             RGBColor[
             0.5096004354679522, 0.6083940896440386, 0.956077633424264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 44}], {
             RGBColor[
             0.2675860001638932, 0.3985802304775334, 0.9385499989000968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 50}], {
             RGBColor[
             0.2469901077447556, 0.3769326416900177, 0.9373770932957193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 60}], {
             RGBColor[
             0.25285259350547307`, 0.38309448592759754`, 0.9377109531870217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 90}], {
             RGBColor[
             0.31984837730012083`, 0.4461884593191548, 0.9417943891224722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 104}], {
             RGBColor[
             0.2353413665909268, 0.3646890761644966, 0.936713714719777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 130}], {
             RGBColor[
             0.2444860062107015, 0.3743006722085195, 0.9372344884178412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 163}], {
             RGBColor[
             0.24238504014097356`, 0.3720924236602928, 0.9371148415082708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 177}], {
             RGBColor[
             0.27267734754750905`, 0.40393155938778236`, 0.9388399436016203]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 47}], {
             RGBColor[
             0.6449475165023608, 0.7197336460567563, 0.9672187657343465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 68}], {
             RGBColor[
             0.8469990595612139, 0.880838075189855, 0.985268720497577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 88}], {
             RGBColor[
             0.775283955250752, 0.8245256192165048, 0.9781972744160757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.6282503776636906, 0.7052714236172997, 0.9661548388122466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 111}], {
             RGBColor[
             0.6494345587146366, 0.7234252020636741, 0.9675585260086426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 116}], {
             RGBColor[
             0.6139780435679677, 0.6929094451719539, 0.9652454183041966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 122}], {
             RGBColor[
             0.9156558164478696, 0.9306321273986194, 0.7286023636805157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 138}], {
             RGBColor[
             0.8755744905406526, 0.7829258920824524, 0.6165607268309311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 142}], {
             RGBColor[
             0.7396311759520104, 0.7966508792482756, 0.9746591341186641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 153}], {
             RGBColor[
             0.7121716897579038, 0.7743580313201439, 0.9724974227780518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 157}], {
             RGBColor[
             0.6980290555794366, 0.7628764037756551, 0.971384062809347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 160}], {
             RGBColor[
             0.6025425418355174, 0.6830045883363345, 0.9645167582458221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 167}], {
             RGBColor[
             0.876824539183936, 0.9046201030499366, 0.9881135013695121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 174}], {
             RGBColor[
             0.6098919568384804, 0.6893702822195625, 0.9649850564709783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 181}], {
             RGBColor[
             0.9113516048559902, 0.930874079920538, 0.9469017763992353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 185}], {
             RGBColor[
             0.8039733137479249, 0.8469379641216965, 0.9810567615537757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 188}], {
             RGBColor[
             0.7515136501309705, 0.8059560761959215, 0.9758280725478667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 132}], {
             RGBColor[
             0.24999710016017773`, 0.3800931813729572, 0.937548337065331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 151}], {
             RGBColor[
             0.2998281417164218, 0.4284810612879339, 0.9405321505496939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 169}], {
             RGBColor[
             0.260181316759984, 0.39079743873598083`, 0.9381283131344916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 200}], {
             RGBColor[
             0.24218408124275126`, 0.3718812031167312, 0.9371033971963092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 56}], {
             RGBColor[
             0.18496037439835666`, 0.3117354590307041, 0.9338445917464089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 79}], {
             RGBColor[
             0.19748095052754017`, 0.3248953783928531, 0.9345576200344334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 118}], {
             RGBColor[
             0.5521506378695789, 0.625893782622829, 0.962890732401742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 119}], {
             RGBColor[
             0.3779360600643469, 0.4878548266230827, 0.9465383122915882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 125}], {
             RGBColor[
             0.18497678859456473`, 0.3117527113916389, 0.9338455265106003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 128}], {
             RGBColor[
             0.5402876317341454, 0.454787094862522, 0.5818823157705433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 149}], {
             RGBColor[
             0.21228087842813756`, 0.34045104098600754`, 0.9354004540338412]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 170}], {
             RGBColor[
             0.18667955632742156`, 0.31354242824058126`, 0.9339424966139673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 190}], {
             RGBColor[
             0.18535040543137957`, 0.3121454063758069, 0.9338668034367403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 195}], {
             RGBColor[
             0.18496037439835666`, 0.3117354590307041, 0.9338445917464089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 46}], {
             RGBColor[
             0.7812753615379626, 0.7886327284729578, 0.6396314180362879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 98}], {
             RGBColor[
             0.9691483293293262, 0.9363502220297157, 0.6237743204922899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 117}], {
             RGBColor[
             0.8719033121193018, 0.8601154409020264, 0.6481970739440106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 120}], {
             RGBColor[
             0.960788560046435, 0.8793927471320053, 0.302171389549849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 128}], {
             RGBColor[
             0.9271948937048214, 0.742224726788967, 0.2736818311730274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 146}], {
             RGBColor[
             0.8804514017100027, 0.8667932734581691, 0.6490490676279728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 156}], {
             RGBColor[
             0.9428260097167436, 0.9163360030821683, 0.6550496534880772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 171}], {
             RGBColor[
             0.919639217056486, 0.8978474840035989, 0.6528380765050477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 178}], {
             RGBColor[
             0.9536200808381681, 0.9247692797301834, 0.650059594771984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 179}], {
             RGBColor[
             0.8863710041657746, 0.8714177118872631, 0.6496390782789341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 183}], {
             RGBColor[
             0.9123593760428652, 0.674860106009205, 0.26130271158407675`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 192}], {
             RGBColor[
             0.8910636363690327, 0.5135395909571491, 0.2410026071488931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 114}], {
             RGBColor[
             0.20908858865686974`, 0.3370957420335433, 0.935218657853937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 46}], {
             RGBColor[
             0.5446619359975361, 0.6412201222402223, 0.9572969292455886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 74}], {
             RGBColor[
             0.3971820108095485, 0.5168505289536836, 0.9468363149531384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.555739244439546, 0.6502131802605045, 0.9581689755436615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 117}], {
             RGBColor[
             0.6352898865788753, 0.7127028346692909, 0.9658625851533114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 121}], {
             RGBColor[
             0.5171284633430432, 0.6188672087704971, 0.9551293934197934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 166}], {
             RGBColor[
             0.4412529384384768, 0.5555739084754552, 0.9496242876077174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 169}], {
             RGBColor[
             0.38208210782853824`, 0.5009795735314966, 0.9459763978166744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 171}], {
             RGBColor[
             0.6830257915160596, 0.7504348777708634, 0.9705035877143484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 173}], {
             RGBColor[
             0.7433614186788604, 0.7950716369237336, 0.832834751651226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 196}], {
             RGBColor[
             0.49337743215923585`, 0.5995850516837207, 0.9532596252421102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 57}], {
             RGBColor[
             0.4551460034388895, 0.5660289447091988, 0.9509456686528102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 66}], {
             RGBColor[
             0.6206670435279176, 0.7021698769586107, 0.9637962645099678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 81}], {
             RGBColor[
             0.563023955866433, 0.6561272371693612, 0.9587424547119633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 90}], {
             RGBColor[
             0.46883146462921355`, 0.577882603340978, 0.9518176941382794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 141}], {
             RGBColor[
             0.4545263425380657, 0.5654922255819677, 0.9509061844081543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 168}], {
             RGBColor[
             0.7441532266042006, 0.7995222771759883, 0.9732629767804062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 172}], {
             RGBColor[
             0.7718454040169196, 0.8174234076188627, 0.7717375932565325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 184}], {
             RGBColor[
             0.46042354235664473`, 0.5706000836629397, 0.9512819487659052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 198}], {
             RGBColor[
             0.6229374569936681, 0.7039435412138363, 0.9640225581060137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 88}], {
             RGBColor[
             0.6168180360411716, 0.6987299024450158, 0.9637087446681081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[
             0.401201459999004, 0.517503689481011, 0.9473903200062829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 102}], {
             RGBColor[
             0.4476381958746549, 0.5602937273030086, 0.9502551687958871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 153}], {
             RGBColor[
             0.5537057705483233, 0.648562314548655, 0.9580088930300842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 49}], {
             RGBColor[
             0.8450514898395424, 0.34729106936125886`, 0.19077466358971318`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 67}], {
             RGBColor[
             0.8367855353364704, 0.2837553208862874, 0.18285917622251102`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 87}], {
             RGBColor[
             0.9216699742916543, 0.7079316543496461, 0.5248036176834326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 95}], {
             RGBColor[
             0.9174955939353169, 0.6847516692782425, 0.2880009042450533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 103}], {
             RGBColor[
             0.859828066940869, 0.45161298487477564`, 0.20456223663524548`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 129}], {
             RGBColor[
             0.922812533415494, 0.7026869546216379, 0.30865621010577077`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 131}], {
             RGBColor[
             0.8773120191958123, 0.531003528583677, 0.2191512749676569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 133}], {
             RGBColor[
             0.8393966098912371, 0.3038251840943911, 0.18535954416494269`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 143}], {
             RGBColor[
             0.8380819090853437, 0.29371981759472743`, 0.18410058518847694`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 154}], {
             RGBColor[
             0.9209464577022384, 0.7076324616463945, 0.536794159970965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 197}], {
             RGBColor[
             0.8721411848386535, 0.6704152078814393, 0.5949590715355129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 50}], {
             RGBColor[
             0.2628281872337618, 0.3935794674252022, 0.9382790484922793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 57}], {
             RGBColor[
             0.3220009955988029, 0.4509816264225601, 0.9418243188335629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 60}], {
             RGBColor[
             0.2686906729944792, 0.399741311662782, 0.9386129083835817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 90}], {
             RGBColor[
             0.33568645678912695`, 0.46283528505433924`, 0.9426963443190322]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 141}], {
             RGBColor[
             0.321381334697979, 0.45044490729532893`, 0.941784834588907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 177}], {
             RGBColor[
             0.2885154270365152, 0.4205783851229668, 0.9397418987981803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 120}], {
             RGBColor[
             0.9205644172331103, 0.7168104234407002, 0.25588752113131463`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 128}], {
             RGBColor[
             0.8869707508914968, 0.5796424030976618, 0.22739796275449303`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 168}], {
             RGBColor[
             0.9114761724933723, 0.7607551980488345, 0.6070253886431892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 172}], {
             RGBColor[
             0.9391683499060914, 0.7786563284917088, 0.4055000051193155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 173}], {
             RGBColor[
             0.9397507014059623, 0.7799019194651641, 0.46888537202339087`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 85}], {
             RGBColor[
             0.4789487657995369, 0.5853416186622634, 0.9528226814867443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 98}], {
             RGBColor[
             0.7856154181292234, 0.8320307685883754, 0.9456185242307917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 99}], {
             RGBColor[
             0.5809189759498203, 0.6706552206345228, 0.960151216244546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 109}], {
             RGBColor[
             0.4676427269643195, 0.5755488960812328, 0.9521022706897019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 117}], {
             RGBColor[
             0.6883704009191991, 0.7557959874606861, 0.9700412776825125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 121}], {
             RGBColor[
             0.570208977683367, 0.6619603615618923, 0.9593080859489944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 146}], {
             RGBColor[
             0.6969184905099, 0.7624738200168288, 0.9708932713664746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 151}], {
             RGBColor[
             0.4748094471252997, 0.581756348874845, 0.9525589277610778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 171}], {
             RGBColor[
             0.7361063058563833, 0.7935280305622586, 0.9746822802435494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 178}], {
             RGBColor[
             0.7700871696380653, 0.8204498262888431, 0.9719037985104857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 196}], {
             RGBColor[
             0.5464579464995596, 0.642678204475116, 0.9574383177713113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 54}], {
             RGBColor[
             0.3621640961349061, 0.48478721437619465`, 0.9444194198717641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 61}], {
             RGBColor[
             0.36265936899724993`, 0.48530777755663124`, 0.944447624928584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 73}], {
             RGBColor[
             0.3723282317178833, 0.495470365317321, 0.9449982523567235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 88}], {
             RGBColor[
             0.5818581666070413, 0.6702991325141743, 0.9609700518092634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 94}], {
             RGBColor[
             0.4348245890199799, 0.551044936914969, 0.9489276162054343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 105}], {
             RGBColor[
             0.3973660260121461, 0.5186002123597028, 0.9465407896938819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 111}], {
             RGBColor[
             0.45600877007092583`, 0.5691987153613436, 0.9503313034018304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 116}], {
             RGBColor[
             0.42055225492425696`, 0.5386829584696233, 0.9480181956973843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 126}], {
             RGBColor[
             0.37937335834478547`, 0.5028752400890226, 0.9453994618957948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 142}], {
             RGBColor[
             0.5462053873082997, 0.642424392545945, 0.9574319115118519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 153}], {
             RGBColor[
             0.518745901114193, 0.6201315446178133, 0.9552702001712396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 157}], {
             RGBColor[
             0.5046032669357259, 0.6086499170733246, 0.9541568402025347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 160}], {
             RGBColor[
             0.4091167531918066, 0.528778101634004, 0.9472895356390099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 167}], {
             RGBColor[
             0.6833987505402253, 0.7503936163476059, 0.9708862787627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 174}], {
             RGBColor[
             0.4164661681947697, 0.535143795517232, 0.9477578338641661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 188}], {
             RGBColor[
             0.5580878614872598, 0.6517295894935908, 0.9586008499410545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 59}], {
             RGBColor[
             0.382953798860026, 0.5061170655801353, 0.9456224553239809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.3349775869314745, 0.46456248216214874`, 0.942565453523592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 77}], {
             RGBColor[
             0.30874838296909257`, 0.4410718707402281, 0.9409224256189008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 106}], {
             RGBColor[
             0.29607730783621694`, 0.42775376738301063`, 0.9402008266352594]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 112}], {
             RGBColor[
             0.3092759955003079, 0.44162642496310195`, 0.9409524723720207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 140}], {
             RGBColor[
             0.3113031778693076, 0.4437571221637065, 0.9410679174089878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 193}], {
             RGBColor[
             0.3168945933506373, 0.44889990200011176`, 0.9414132211627845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 67}], {
             RGBColor[
             0.8264716492084423, 0.20447827253254375`, 0.17298258721844303`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.9113560881636262, 0.6286546059959026, 0.5149270286793647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 95}], {
             RGBColor[
             0.9071817078072888, 0.605474620924499, 0.27812431524098535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 103}], {
             RGBColor[
             0.8495141808128409, 0.372335936521032, 0.19468564763117746`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 108}], {
             RGBColor[
             0.8079850952769174, 0.5485190612635439, 0.5798638479373164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[
             0.9124986472874659, 0.6234099062678943, 0.2987796211017028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 131}], {
             RGBColor[
             0.8669981330677842, 0.45172648022993345`, 0.2092746859635889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 133}], {
             RGBColor[
             0.829082723763209, 0.22454813574064747`, 0.1754829551608747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 143}], {
             RGBColor[
             0.8277680229573157, 0.2144427692409838, 0.17422399618440892`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 154}], {
             RGBColor[
             0.9106325715742103, 0.628355413292651, 0.5269175709668971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 162}], {
             RGBColor[
             0.9088194332461141, 0.62739119565138, 0.547362978009857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 53}], {
             RGBColor[
             0.22682228238214364`, 0.3557349785199296, 0.9362285654769424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 60}], {
             RGBColor[
             0.24809478057534154`, 0.3780937228752663, 0.9374400027792041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 82}], {
             RGBColor[
             0.28041536130760697`, 0.41115377820056886`, 0.9393139654375977]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 100}], {
             RGBColor[
             0.2280232863629279, 0.35699730985178435`, 0.9362969608769219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 104}], {
             RGBColor[
             0.2305835536607953, 0.3596883131121654, 0.9364427643119595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 123}], {
             RGBColor[
             0.24633186843467056`, 0.37624079044033565`, 0.9373396075407877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.23972819328057, 0.3692999091561883, 0.9369635380100236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 163}], {
             RGBColor[
             0.23762722721084206`, 0.36709166060796167`, 0.9368438911004533]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 177}], {
             RGBColor[
             0.2679195346173776, 0.39893079633545114`, 0.9385689931938027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 71}], {
             RGBColor[
             0.2862116459129269, 0.41815696509391576`, 0.9396107018713307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 74}], {
             RGBColor[
             0.29246128213975436`, 0.4247257290181345, 0.9399666094089402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 158}], {
             RGBColor[
             0.267702506048196, 0.39870268554883526`, 0.9385566337378528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 164}], {
             RGBColor[
             0.28843151316149873`, 0.42049018631987756`, 0.9397371200271375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 166}], {
             RGBColor[
             0.33653220976868264`, 0.46344910853990606`, 0.9427545820635193]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 184}], {
             RGBColor[
             0.3266364768489205, 0.4548779220588064, 0.942124034712325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 70}], {
             RGBColor[
             0.2130689137116028, 0.34127931603325223`, 0.9354453314774407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 134}], {
             RGBColor[
             0.22165741455534713`, 0.35030637496243233`, 0.9359344338949436]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 145}], {
             RGBColor[
             0.21010927874609994`, 0.3381685520328137, 0.9352767846445429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 100}], {
             RGBColor[
             0.21261327393044743`, 0.34080040973402737`, 0.9354193834659627]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 104}], {
             RGBColor[
             0.21517354122831484`, 0.34349141299440844`, 0.9355651869010002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 123}], {
             RGBColor[
             0.2309218560021901, 0.36004389032257866`, 0.9364620301298284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 130}], {
             RGBColor[
             0.22431818084808952`, 0.35310300903843134`, 0.9360859605990643]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 135}], {
             RGBColor[
             0.222345629185322, 0.35102973217386374`, 0.9359736266999984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 148}], {
             RGBColor[
             0.20810268194188267`, 0.3360594915659958, 0.9351625119250367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 163}], {
             RGBColor[
             0.2222172147783616, 0.3508947604902047, 0.935966313689494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 165}], {
             RGBColor[
             0.21515759774182608`, 0.3434746553792333, 0.935564278943031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 58}], {
             RGBColor[
             0.2684799532608956, 0.3995198318623828, 0.9386009082064859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 61}], {
             RGBColor[
             0.27330173727350593`, 0.40458783257840025`, 0.9388755016728139]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 73}], {
             RGBColor[
             0.28297059999413937`, 0.41475042033909004`, 0.9394261291009534]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 94}], {
             RGBColor[
             0.3454669572962359, 0.47032499193673805`, 0.9433554929496641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 105}], {
             RGBColor[
             0.3080083942884021, 0.4378802673814718, 0.9409686664381117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 115}], {
             RGBColor[
             0.2691801918114708, 0.40025582697672574`, 0.938640785756031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 116}], {
             RGBColor[
             0.33119462320051296`, 0.4579630134913923, 0.9424460724416142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 126}], {
             RGBColor[
             0.29001572662104147`, 0.4221552951107917, 0.9398273386400247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 160}], {
             RGBColor[
             0.3197591214680627, 0.448058156655773, 0.9417174123832397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 174}], {
             RGBColor[
             0.3271085364710258, 0.454423850539001, 0.942185710608396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 62}], {
             RGBColor[
             0.35430836392456, 0.4813058296004574, 0.9437971935400564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 68}], {
             RGBColor[
             0.6040034340544339, 0.6836766872491769, 0.9648829517187356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 72}], {
             RGBColor[
             0.3011292819316679, 0.4298018950317811, 0.9406079602011264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 75}], {
             RGBColor[
             0.3182717437982659, 0.44781970934843396`, 0.9415841980444295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 76}], {
             RGBColor[
             0.31436618073050393`, 0.4437147149372155, 0.9413617820054831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 96}], {
             RGBColor[
             0.32928937279498216`, 0.459399935982008, 0.942211635716671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 107}], {
             RGBColor[
             0.5098065457970684, 0.609801290788619, 0.955570731517623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 111}], {
             RGBColor[
             0.40643893320785657`, 0.5262638141229958, 0.9471727572298012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 139}], {
             RGBColor[
             0.3007701310464627, 0.42942440467994913`, 0.9405875070895301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 147}], {
             RGBColor[
             0.41653896028796467`, 0.5344634711076623, 0.9479678683591656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 157}], {
             RGBColor[
             0.4550334300726567, 0.5657150158349769, 0.9509982940305055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 182}], {
             RGBColor[
             0.30875284137949693`, 0.43781473937303605`, 0.9410421106336347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 185}], {
             RGBColor[
             0.5609776882411449, 0.6497765761810184, 0.9606709927749343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 191}], {
             RGBColor[
             0.31630641834476525`, 0.445754027687974, 0.9414722756672911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 79}], {
             RGBColor[
             0.1914475761291835, 0.31855391936214905`, 0.9342140282880245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 118}], {
             RGBColor[
             0.5461172634712221, 0.619552323592125, 0.9625471406553332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 119}], {
             RGBColor[
             0.37190268566599016`, 0.4815133675923786, 0.9461947205451795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 125}], {
             RGBColor[
             0.17894341419620807`, 0.3054112523609348, 0.9335019347641915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 129}], {
             RGBColor[
             0.5845933454317087, 0.6420998957641366, 0.6750810838088802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 149}], {
             RGBColor[
             0.2062475040297809, 0.3341095819553035, 0.9350568622874322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 170}], {
             RGBColor[
             0.1806461819290649, 0.30720096920987716`, 0.9335989048675586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 190}], {
             RGBColor[
             0.1793170310330229, 0.30580394734510286`, 0.9335232116903315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 195}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 197}], {
             RGBColor[
             0.5339219968548683, 0.6098281490239381, 0.9613839452386224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 66}], {
             RGBColor[
             0.5260989516337345, 0.6228771288818142, 0.9570472794276266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 71}], {
             RGBColor[
             0.32543061952646807`, 0.4545863786212526, 0.9420196308425695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 81}], {
             RGBColor[
             0.4684558639722499, 0.5768344890925647, 0.951993469629622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 90}], {
             RGBColor[
             0.37426337273503046`, 0.49858985526418154`, 0.9450687090559382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 141}], {
             RGBColor[
             0.35995825064388254`, 0.48619947750517123`, 0.9441571993258131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 198}], {
             RGBColor[
             0.528369365099485, 0.6246507931370399, 0.9572735730236723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 61}], {
             RGBColor[
             0.26897522612323943`, 0.4000403950428194, 0.9386291132633059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 73}], {
             RGBColor[
             0.2786440888438728, 0.4102029828035092, 0.9391797406914454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 92}], {
             RGBColor[
             0.24643437763355744`, 0.3763485341078243, 0.9373454452880156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 115}], {
             RGBColor[
             0.2648536806612042, 0.3957083894411449, 0.9383943973465231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 155}], {
             RGBColor[
             0.25688825427596124`, 0.3873362212730521, 0.9379407780976758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 154}], {
             RGBColor[
             0.7176662191262557, 0.7759253920834623, 0.911377748265729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 186}], {
             RGBColor[
             0.36541764511564734`, 0.4884580900498052, 0.9445955073983169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 193}], {
             RGBColor[
             0.38274569330621644`, 0.5059368150091147, 0.9456091950221126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.2862778470683244, 0.4173156224381487, 0.9396478253289002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 104}], {
             RGBColor[
             0.23644603942151277`, 0.3658501573497452, 0.9367766242032618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 123}], {
             RGBColor[
             0.252194354195388, 0.3824026346779154, 0.9376734674320901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 130}], {
             RGBColor[
             0.2455906790412874, 0.3754617533937681, 0.9372973979013259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 163}], {
             RGBColor[
             0.24348971297155947`, 0.37325350484554143`, 0.9371777509917558]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 177}], {
             RGBColor[
             0.273782020378095, 0.40509264057303096`, 0.9389028530851051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 73}], {
             RGBColor[
             0.28346587285648317`, 0.41527098351952657`, 0.9394543341577734]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 94}], {
             RGBColor[
             0.34596223015857974`, 0.47084555511717463`, 0.9433836980064841]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 105}], {
             RGBColor[
             0.30850366715074595`, 0.4384008305619083, 0.9409968714949317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 115}], {
             RGBColor[
             0.2696754646738146, 0.40077639015716227`, 0.938668990812851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 116}], {
             RGBColor[
             0.3316898960628568, 0.4584835766718288, 0.9424742774984342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 160}], {
             RGBColor[
             0.3202543943304065, 0.44857871983620956`, 0.9417456174400596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 174}], {
             RGBColor[
             0.3276038093333696, 0.4549444137194375, 0.9422139156652158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 68}], {
             RGBColor[
             0.6059297438464823, 0.6853451599719039, 0.965005694475316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 75}], {
             RGBColor[
             0.3201980535903144, 0.44948818207116104`, 0.9417069408010099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 76}], {
             RGBColor[
             0.3162924905225524, 0.44538318765994256`, 0.9414845247620637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 96}], {
             RGBColor[
             0.33121568258703066`, 0.4610684087047351, 0.9423343784732514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 105}], {
             RGBColor[
             0.3497224989411253, 0.4773337838440822, 0.9435049862784333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 107}], {
             RGBColor[
             0.5117328555891169, 0.611469763511346, 0.9556934742742034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 111}], {
             RGBColor[
             0.40836524299990506`, 0.527932286845723, 0.9472954999863816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 116}], {
             RGBColor[
             0.37290872785323614`, 0.4974165299540027, 0.9449823922819357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 126}], {
             RGBColor[
             0.33172983127376465`, 0.4616088115734021, 0.9423636584803461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 157}], {
             RGBColor[
             0.4569597398647052, 0.567383488557704, 0.951121036787086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 174}], {
             RGBColor[
             0.36882264112374896`, 0.4938773670016114, 0.9447220304487174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 182}], {
             RGBColor[
             0.31067915117154543`, 0.43948321209576313`, 0.9411648533902153]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 185}], {
             RGBColor[
             0.5629039980331934, 0.6514450489037454, 0.9607937355315148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 191}], {
             RGBColor[
             0.3182327281368137, 0.4474225004107011, 0.9415950184238715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 77}], {
             RGBColor[
             0.3266232709961202, 0.4565542003312445, 0.9420613976778401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 91}], {
             RGBColor[
             0.5953350475574752, 0.6767809281925967, 0.9640487060966569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 102}], {
             RGBColor[
             0.3633436999904507, 0.48913178357153686`, 0.9443729171645411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 106}], {
             RGBColor[
             0.3139521958632445, 0.44323609697402705`, 0.9413397986941987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 112}], {
             RGBColor[
             0.32715088352733546`, 0.45710875455411837`, 0.94209144443096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 140}], {
             RGBColor[
             0.32917806589633525`, 0.4592394517547229, 0.942206889467927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 69}], {
             RGBColor[
             0.512094113243802, 0.613375440560194, 0.9551211815778647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 82}], {
             RGBColor[
             0.4706005281918093, 0.5774357827163821, 0.9524772470296884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 86}], {
             RGBColor[
             0.5072811113074129, 0.6092066601914048, 0.9548145013504485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 87}], {
             RGBColor[
             0.8052886005993835, 0.8468955393268014, 0.9061943444225835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 108}], {
             RGBColor[
             0.7019176077126746, 0.7667599945944428, 0.9711311636805353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 110}], {
             RGBColor[
             0.6138148271599528, 0.6973615545881173, 0.9627408981532811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 127}], {
             RGBColor[
             0.4720951346225606, 0.5787303356855954, 0.9525724820298272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 154}], {
             RGBColor[
             0.8045650840099676, 0.8465963466235498, 0.9181848867101159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 161}], {
             RGBColor[
             0.4656307978135873, 0.573123205257251, 0.9521608748370004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 162}], {
             RGBColor[
             0.8027519456818715, 0.845632128982279, 0.9386302937530759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 175}], {
             RGBColor[
             0.4715002623045349, 0.5782150871828736, 0.9525345772917476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 176}], {
             RGBColor[
             0.45839978276888355`, 0.5655229499724335, 0.9517490792275327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 180}], {
             RGBColor[
             0.6733354003460714, 0.7444313569668306, 0.9682823563661463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 66}], {
             RGBColor[
             0.8068568184878835, 0.8498672602817441, 0.9811645922016861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 69}], {
             RGBColor[
             0.6618396215787897, 0.7314857264416685, 0.9696204831011173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 87}], {
             RGBColor[
             0.9550341089343712, 0.965005825208276, 0.9206936459458361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 90}], {
             RGBColor[
             0.6550212395891795, 0.7255799866641114, 0.9691860218299977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 110}], {
             RGBColor[
             0.7635603354949406, 0.815471840469592, 0.9772401996765336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 131}], {
             RGBColor[
             0.9106761538385292, 0.7880776994423069, 0.6150413032300603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 133}], {
             RGBColor[
             0.872760744533954, 0.5608993549530209, 0.5812495724273461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 162}], {
             RGBColor[
             0.9524974540168591, 0.9637424148637534, 0.9531295952763283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 180}], {
             RGBColor[
             0.8230809086810591, 0.8625416428483053, 0.9827816578893989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 198}], {
             RGBColor[
             0.809127231953634, 0.8516409245369697, 0.9813908857977319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 81}], {
             RGBColor[
             0.633976904061278, 0.7129754213419766, 0.9648440654867796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 90}], {
             RGBColor[
             0.5397844128240585, 0.6347307875135932, 0.9579193049130958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 141}], {
             RGBColor[
             0.5254792907329107, 0.622340409754583, 0.9570077951829706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 168}], {
             RGBColor[
             0.8151061747990456, 0.8563704613486036, 0.9793645875552226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 172}], {
             RGBColor[
             0.8427983522117647, 0.874271591791478, 0.7778392040313489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 198}], {
             RGBColor[
             0.6938904051885131, 0.7607917253864516, 0.97012416888083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 87}], {
             RGBColor[
             0.9030901336605541, 0.565118857520931, 0.5070115413121625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 103}], {
             RGBColor[
             0.8412482263097689, 0.30880018804606046`, 0.1867701602639753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 129}], {
             RGBColor[
             0.9042326927843938, 0.5598741577929227, 0.2908641337345006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 131}], {
             RGBColor[
             0.8587321785647122, 0.38819073175496194`, 0.20135919859638673`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 133}], {
             RGBColor[
             0.820816769260137, 0.16101238726567596`, 0.16756746779367254`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 143}], {
             RGBColor[
             0.8195020684542436, 0.15090702076601228`, 0.16630850881720677`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 162}], {
             RGBColor[
             0.9005534787430421, 0.5638554471764086, 0.5394474906426548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 107}], {
             RGBColor[
             0.7614279257189907, 0.8138406211600655, 0.9767792324528825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 111}], {
             RGBColor[
             0.6580603131297789, 0.7303031444944423, 0.9683812581650608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 122}], {
             RGBColor[
             0.924281570863012, 0.9375100698293877, 0.7294250958369339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 138}], {
             RGBColor[
             0.8842002449557951, 0.7898038345132208, 0.6173834589873493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 142}], {
             RGBColor[
             0.7482569303671527, 0.8035288216790438, 0.9754818662750824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 147}], {
             RGBColor[
             0.668160340209887, 0.7385028014791089, 0.9691763692944251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 156}], {
             RGBColor[
             0.8882342803358891, 0.9137179209353309, 0.9892017726661817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 157}], {
             RGBColor[
             0.7066548099945791, 0.7697543462064234, 0.9722067949657651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 179}], {
             RGBColor[
             0.8317792747849202, 0.8687996297404257, 0.9837911974570385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 181}], {
             RGBColor[
             0.9199773592711327, 0.9377520223513063, 0.9477245085556535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 185}], {
             RGBColor[
             0.8125990681630673, 0.8538159065524649, 0.9818794937101938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 82}], {
             RGBColor[
             0.3600920128525825, 0.48631533560726303`, 0.9441657225354702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 86}], {
             RGBColor[
             0.39677259596818604`, 0.5180862130822859, 0.9465029768562303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 90}], {
             RGBColor[
             0.3947672159149649, 0.5163492536735178, 0.946375195812527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 110}], {
             RGBColor[
             0.503306311820726, 0.6062411074789984, 0.9544293736590629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 123}], {
             RGBColor[
             0.3260085199796461, 0.4514023478470298, 0.9421913646386602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 127}], {
             RGBColor[
             0.3615866192833338, 0.48760988857647636`, 0.944260957535609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 177}], {
             RGBColor[
             0.3475961861623531, 0.47409235374214537`, 0.9434207502916752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 180}], {
             RGBColor[
             0.5628268850068445, 0.6533109098577117, 0.9599708318719281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 72}], {
             RGBColor[
             0.23177582019152226`, 0.36094146083002354`, 0.936510662127084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 93}], {
             RGBColor[
             0.21891136206643785`, 0.34742009968680476`, 0.9357780502681208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 134}], {
             RGBColor[
             0.2222636314959646, 0.3509435474033953, 0.9359689570528942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 139}], {
             RGBColor[
             0.23141666930631707`, 0.36056397047819155`, 0.9364902090154877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.2107154956867174, 0.33880572447377666`, 0.9353113078024935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 81}], {
             RGBColor[
             0.43330857195401157`, 0.5446846710814149, 0.9498164169017225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 164}], {
             RGBColor[
             0.2925031947568016, 0.42476978183606456`, 0.9399689962704769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 184}], {
             RGBColor[
             0.3307081584442233, 0.45915751757499346`, 0.9423559109556644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 75}], {
             RGBColor[
             0.26701897159742227`, 0.39798424750248473`, 0.9385177074620799]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 84}], {
             RGBColor[
             0.256326539038239, 0.386745822943403, 0.9379087892458708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 93}], {
             RGBColor[
             0.23701205160573985`, 0.3664450720426131, 0.9368088577598136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 134}], {
             RGBColor[
             0.2403643210352666, 0.36996851975920364`, 0.9369997645445869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 139}], {
             RGBColor[
             0.24951735884561907`, 0.3795889428339999, 0.9375210165071806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 152}], {
             RGBColor[
             0.2658080334878341, 0.396711474771397, 0.9384487463281612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 191}], {
             RGBColor[
             0.2650536461439216, 0.3959185658420248, 0.9384057850849414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 94}], {
             RGBColor[
             0.35563109287921313`, 0.4810081428778644, 0.9439343254346236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 115}], {
             RGBColor[
             0.27934432739444803`, 0.41093897791785206`, 0.9392196182409905]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 153}], {
             RGBColor[
             0.4395524049734263, 0.5500947505807087, 0.9502769094004289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 160}], {
             RGBColor[
             0.3299232570510399, 0.45874130759689935`, 0.9422962448681991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 80}], {
             RGBColor[
             0.46133983359188224`, 0.5689367397653611, 0.9518870537804123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 158}], {
             RGBColor[
             0.2780238238703263, 0.40955104498924105`, 0.9391444175188017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 164}], {
             RGBColor[
             0.29875283098362904`, 0.4313385457602833, 0.9403249038080864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 166}], {
             RGBColor[
             0.34685352759081295`, 0.47429746798031186`, 0.9433423658444682]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 169}], {
             RGBColor[
             0.28768269698087445`, 0.4197031330363533, 0.9396944760534252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 184}], {
             RGBColor[
             0.3369577946710508, 0.46572628149921225`, 0.9427118184932739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 76}], {
             RGBColor[
             0.2802558703962583, 0.4118970674079191, 0.9392715292664366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 96}], {
             RGBColor[
             0.29517906246073655`, 0.4275822884527116, 0.9401213829776245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 134}], {
             RGBColor[
             0.2575067829018646, 0.3879863340758565, 0.93797600238789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 139}], {
             RGBColor[
             0.26665982071221705`, 0.39760675715065275`, 0.9384972543504835]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 182}], {
             RGBColor[
             0.27464253104525127`, 0.40599709184373967`, 0.9389518578945881]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 191}], {
             RGBColor[
             0.2821961080105196, 0.4139363801586776, 0.9393820229282445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.2912734993929746, 0.42347729404149315`, 0.9398989669386781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 105}], {
             RGBColor[
             0.3097803157470692, 0.4397426691808402, 0.94106957474386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 111}], {
             RGBColor[
             0.368423059805849, 0.49034117218248097`, 0.9448600884518084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 116}], {
             RGBColor[
             0.3329665446591801, 0.4598254152907607, 0.9425469807473624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 126}], {
             RGBColor[
             0.2917876480797086, 0.4240176969101601, 0.9399282469457728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 174}], {
             RGBColor[
             0.3288804579296929, 0.4562862523383694, 0.9422866189141441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.27073696797748936`, 0.4018920974325212, 0.938729441855642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 191}], {
             RGBColor[
             0.2782905449427576, 0.40983138574745914`, 0.9391596068892982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 102}], {
             RGBColor[
             0.33711449602806876`, 0.4656411721496162, 0.9427298892598499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 106}], {
             RGBColor[
             0.2877229919008626, 0.4197454855521064, 0.9396967707895075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 112}], {
             RGBColor[
             0.3009216795649535, 0.4336181431321977, 0.9404484165262689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 140}], {
             RGBColor[
             0.3029488619339533, 0.43574884033280226`, 0.9405638615632359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 189}], {
             RGBColor[
             0.2658927211222934, 0.3968004868447199, 0.9384535691636595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 91}], {
             RGBColor[
             0.8828910750951913, 0.909457394113841, 0.9886921329803882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 95}], {
             RGBColor[
             0.9537951709684989, 0.944166482218568, 0.6841709176231596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 113}], {
             RGBColor[
             0.9141333132318434, 0.7927873365838396, 0.6157566218013946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 136}], {
             RGBColor[
             0.9179856014839756, 0.8091909436388446, 0.6189147464565151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 89}], {
             RGBColor[
             0.5289801926935428, 0.3738636894324282, 0.5671316930183012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 118}], {
             RGBColor[
             0.5586378396004057, 0.632712242954274, 0.9632601689433578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 119}], {
             RGBColor[
             0.3844232617951737, 0.4946732869545277, 0.9469077488332039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 125}], {
             RGBColor[
             0.19146399032539158`, 0.3185711717230839, 0.934214963052216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 128}], {
             RGBColor[
             0.5467748334649722, 0.46160555519396695`, 0.5822517523121589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 144}], {
             RGBColor[
             0.5302420239491671, 0.38356267740113825`, 0.5683400240537216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 149}], {
             RGBColor[
             0.21876808015896437`, 0.34726950131745254`, 0.9357698905754568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 159}], {
             RGBColor[
             0.5133063068014707, 0.25338733412536907`, 0.5521223621869309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 170}], {
             RGBColor[
             0.1931667580582484, 0.32036088857202627`, 0.934311933155583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 190}], {
             RGBColor[
             0.19183760716220638`, 0.3189638667072519, 0.9342362399783559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 192}], {
             RGBColor[
             0.5106435761291835, 0.23292041936214905`, 0.5495725282880245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 195}], {
             RGBColor[
             0.1914475761291835, 0.31855391936214905`, 0.9342140282880245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 197}], {
             RGBColor[
             0.5464425729840517, 0.6229880683860871, 0.9620969735266468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 81}], {
             RGBColor[
             0.5981154418108365, 0.6846160863124545, 0.9615049850298553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 117}], {
             RGBColor[
             0.699447709361209, 0.7647890454809683, 0.9709133239805854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 120}], {
             RGBColor[
             0.7883329572883422, 0.7840663517109472, 0.6248876395864237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 121}], {
             RGBColor[
             0.5812862861253769, 0.6709534195821745, 0.9601801322470673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 166}], {
             RGBColor[
             0.5054107612208105, 0.6076601192871327, 0.9546750264349914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 168}], {
             RGBColor[
             0.7792447125486042, 0.8280111263190817, 0.9760255070982982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 172}], {
             RGBColor[
             0.8069368899613232, 0.8459122567619559, 0.7745001235744244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 173}], {
             RGBColor[
             0.807519241461194, 0.8471578477354111, 0.8378854904784999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 184}], {
             RGBColor[
             0.4955150283010483, 0.599088932806033, 0.9540444790837972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 164}], {
             RGBColor[
             0.43552843920258344`, 0.5470178923073767, 0.9499428350575294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 166}], {
             RGBColor[
             0.4836291358097673, 0.5899768145274054, 0.9529602970939112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 168}], {
             RGBColor[
             0.7574630871375609, 0.8103278215593543, 0.974310777757218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 172}], {
             RGBColor[
             0.7851552645502801, 0.8282289520022286, 0.7727853942333442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 173}], {
             RGBColor[
             0.7857376160501509, 0.8294745429756838, 0.8361707611374197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 184}], {
             RGBColor[
             0.47373340289000515`, 0.5814056280463057, 0.952329749742717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 198}], {
             RGBColor[
             0.6362473175270285, 0.7147490855972023, 0.9650703590828255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 86}], {
             RGBColor[
             0.3552790109161934, 0.48214655523847394`, 0.943859042308054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 101}], {
             RGBColor[
             0.2852213829706352, 0.4162052116877847, 0.9395876612614353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 110}], {
             RGBColor[
             0.4618127267687334, 0.5703014496351865, 0.9517854391108865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 123}], {
             RGBColor[
             0.28451493492765345`, 0.4154626900032179, 0.9395474300904838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 127}], {
             RGBColor[
             0.32009303423134106`, 0.45167023073266444`, 0.9416170229874327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 130}], {
             RGBColor[
             0.27791125977355285`, 0.4085218087190706, 0.9391713605597196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 163}], {
             RGBColor[
             0.2758102937038249, 0.40631356017084397`, 0.9390517136501494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 176}], {
             RGBColor[
             0.30639768237766407`, 0.4384628450195025, 0.9407936201851381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 177}], {
             RGBColor[
             0.3061026011103605, 0.4381526958983335, 0.9407768157434988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 180}], {
             RGBColor[
             0.5213332999548519, 0.6173712520138998, 0.9573268973237518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 187}], {
             RGBColor[
             0.3007127795635599, 0.4324876517182224, 0.9404698733799348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 86}], {
             RGBColor[
             0.32390396973941904`, 0.450080321936663, 0.9420389267285452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 101}], {
             RGBColor[
             0.2538463417938609, 0.3841389783859738, 0.9377675456819266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 124}], {
             RGBColor[
             0.2734514125634414, 0.4047451507980839, 0.9388840254591511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 135}], {
             RGBColor[
             0.244563666934011, 0.3743822985526921, 0.9372389110811449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 137}], {
             RGBColor[
             0.2530177140174724, 0.383268038054954, 0.9377203565559061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 161}], {
             RGBColor[
             0.28225365624559345`, 0.41399686700250915`, 0.9393853002150969]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 165}], {
             RGBColor[
             0.2373756354905151, 0.36682722175806165`, 0.9368295633241774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 175}], {
             RGBColor[
             0.2881231207365411, 0.41908874892813175`, 0.9397590026698441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 176}], {
             RGBColor[
             0.2750226412008897, 0.4063966117176916, 0.9389735046056292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 187}], {
             RGBColor[
             0.26933773838678554`, 0.40042141841641143`, 0.938649757800426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 199}], {
             RGBColor[
             0.2640684264301843, 0.3948830374563491, 0.938349678279746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 93}], {
             RGBColor[
             0.24346208091315458`, 0.3732244618001842, 0.9371761773869076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 139}], {
             RGBColor[
             0.25596738815303377`, 0.386368332591571, 0.9378883361342745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 152}], {
             RGBColor[
             0.2722580627952489, 0.4034908645289682, 0.9388160659552552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 194}], {
             RGBColor[
             0.30565287667395435`, 0.4349127039944547, 0.9408525291212098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 99}], {
             RGBColor[
             0.4621252914114974, 0.5716835642651686, 0.9514982759565006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 109}], {
             RGBColor[
             0.34884904242599657`, 0.47657723971187865`, 0.9434493304016565]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 132}], {
             RGBColor[
             0.3061847210307328, 0.43439681259051416`, 0.9409221739886695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 146}], {
             RGBColor[
             0.578124805971577, 0.6635021636474746, 0.9622403310784291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 150}], {
             RGBColor[
             0.3215409260409259, 0.45053715769585945`, 0.9417966871465304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 151}], {
             RGBColor[
             0.35601576258697687`, 0.48278469250549083`, 0.9439059874730323]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 152}], {
             RGBColor[
             0.320947319253029, 0.44991323932493577`, 0.9417628821181223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 194}], {
             RGBColor[
             0.35434213313173446`, 0.48133507879042225`, 0.9437993452840767]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 196}], {
             RGBColor[
             0.42766426196123664`, 0.5437065481057618, 0.9487853774832657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 101}], {
             RGBColor[
             0.3219019660862388, 0.44797608916280746`, 0.9419249155821955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 108}], {
             RGBColor[
             0.5865960904370586, 0.6714707671165345, 0.9625129589589009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 110}], {
             RGBColor[
             0.49849330988433693`, 0.6020723271102092, 0.9541226934316467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 124}], {
             RGBColor[
             0.3415070368558193, 0.46858226157491756`, 0.94304139535942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 127}], {
             RGBColor[
             0.3567736173469446, 0.48344110820768715`, 0.9439542773081928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 161}], {
             RGBColor[
             0.35030928053797133`, 0.47783397777934283`, 0.943542670115366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 175}], {
             RGBColor[
             0.356178745028919, 0.4829258597049654, 0.9439163725701132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 176}], {
             RGBColor[
             0.3430782654932676, 0.4702337224945253, 0.9431308745058982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 180}], {
             RGBColor[
             0.5580138830704554, 0.6491421294889225, 0.9596641516445119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 187}], {
             RGBColor[
             0.3373933626791634, 0.4642585291932452, 0.9428071277006951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 199}], {
             RGBColor[
             0.3321240507225622, 0.4587201482331828, 0.9425070481800151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 95}], {
             RGBColor[
             0.9838001922594006, 0.9661152059128862, 0.6121532693347048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 103}], {
             RGBColor[
             0.9261326652649529, 0.7329765215094193, 0.5287146017248969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 108}], {
             RGBColor[
             0.8846035797290293, 0.9091596462519311, 0.913892802031036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 110}], {
             RGBColor[
             0.7965007991763076, 0.8397612062456058, 0.9055025365037817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 131}], {
             RGBColor[
             0.9436166175198961, 0.8123670652183208, 0.5433036400573084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 143}], {
             RGBColor[
             0.9043865074094275, 0.5750833542293711, 0.5082529502781284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[
             0.9872510560263222, 0.9889959982810382, 0.8609465250606165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 162}], {
             RGBColor[
             0.9854379176982261, 0.9880317806397674, 0.8813919321035765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 180}], {
             RGBColor[
             0.8560213723624259, 0.8868310086243191, 0.9110439947166469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 94}], {
             RGBColor[
             0.5651610277683712, 0.6558369100747177, 0.9599061248871635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 102}], {
             RGBColor[
             0.5430147651889159, 0.6366549305319157, 0.9584949846187718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[
             0.8062483508925926, 0.7076340176229743, 0.6052352623718941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 122}], {
             RGBColor[
             0.8525664665525501, 0.8811976138560375, 0.7223536497554326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 136}], {
             RGBColor[
             0.8101006391447247, 0.7240376246779792, 0.6083933870270145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 142}], {
             RGBColor[
             0.6765418260566909, 0.7472163657056936, 0.968410420193581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 153}], {
             RGBColor[
             0.6490823398625842, 0.7249235177775619, 0.9662487088529688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 167}], {
             RGBColor[
             0.8137351892886164, 0.8551855895073546, 0.9818647874444291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 188}], {
             RGBColor[
             0.688424300235651, 0.7565215626533395, 0.9695793586227837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 113}], {
             RGBColor[
             0.8771471647792357, 0.528095234856292, 0.21892914685667453`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 118}], {
             RGBColor[
             0.8836498800355815, 0.6748620936624041, 0.59546480538561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 122}], {
             RGBColor[
             0.9234652804391932, 0.7016588310893552, 0.3360475342402131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 136}], {
             RGBColor[
             0.8809994530313677, 0.5444988419112969, 0.222087271511795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 138}], {
             RGBColor[
             0.8833839545319762, 0.5539525957731882, 0.22400589739062848`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 144}], {
             RGBColor[
             0.8552540643843429, 0.4257125281092684, 0.20054466049597394`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 149}], {
             RGBColor[
             0.5437801205941402, 0.38941935202558264`, 0.567974527017709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 159}], {
             RGBColor[
             0.8383183472366464, 0.29553718483349917`, 0.18432699862918317`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 170}], {
             RGBColor[
             0.5181787984934242, 0.3625107392801563, 0.5665165695978354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 192}], {
             RGBColor[
             0.8356556165643594, 0.2750702700702792, 0.18177716473027677`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 197}], {
             RGBColor[
             0.8714546134192276, 0.6651379190942172, 0.5943016099688991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 141}], {
             RGBColor[
             0.37364371183420664`, 0.49805313613695035`, 0.9450292248112824]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 177}], {
             RGBColor[
             0.3407778041727428, 0.4681866139645882, 0.9429862890205556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 198}], {
             RGBColor[
             0.542054826289809, 0.636504451768819, 0.9581455985091416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 95}], {
             RGBColor[
             0.9087217160297558, 0.9082261327367556, 0.679871771253554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 136}], {
             RGBColor[
             0.8729121465452325, 0.773250594157032, 0.6146156000869095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 97}], {
             RGBColor[
             0.2548383832137916, 0.38518167681737986`, 0.9378240409731977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 155}], {
             RGBColor[
             0.23916918979888965`, 0.36871236105407446`, 0.9369317035887135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 134}], {
             RGBColor[
             0.2274998629101822, 0.35644715861598486`, 0.9362671526856237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 139}], {
             RGBColor[
             0.2366529007205347, 0.36606758169078113`, 0.9367884046482173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 145}], {
             RGBColor[
             0.21595172710093502`, 0.34430933568636624`, 0.935609503435223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 105}], {
             RGBColor[
             0.3806688871734759, 0.5041379899202462, 0.945476862771782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 111}], {
             RGBColor[
             0.43931163123225564`, 0.554736492921887, 0.9492673764797304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 115}], {
             RGBColor[
             0.34184068469654455`, 0.4665135495155001, 0.9431489820897013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 116}], {
             RGBColor[
             0.4038551160855868, 0.5242207360301667, 0.9469542687752844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 126}], {
             RGBColor[
             0.3626762195061153, 0.4884130176495661, 0.9443355349736948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 142}], {
             RGBColor[
             0.5295082484696294, 0.6279621701064884, 0.9563679845897519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 153}], {
             RGBColor[
             0.5020487622755229, 0.6056693221783567, 0.9542062732491396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 160}], {
             RGBColor[
             0.39241961435313644`, 0.5143158791945474, 0.9462256087169099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 167}], {
             RGBColor[
             0.666701611701555, 0.7359313939081493, 0.9698223518406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 174}], {
             RGBColor[
             0.39976902935609954`, 0.5206815730777754, 0.9466939069420661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 188}], {
             RGBColor[
             0.5413907226485897, 0.6372673670541342, 0.9575369230189545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 103}], {
             RGBColor[
             0.9219582849086154, 0.7097965364380157, 0.2919118882865176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 129}], {
             RGBColor[
             0.9849427513832404, 0.9608705061848779, 0.39600586175704294`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 131}], {
             RGBColor[
             0.9394422371635587, 0.7891870801469172, 0.306500926618929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 143}], {
             RGBColor[
             0.9002121270530901, 0.5519033691579674, 0.2714502368397491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 154}], {
             RGBColor[
             0.9830766756699849, 0.9658160132096346, 0.6241438116222372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 105}], {
             RGBColor[
             0.32470350781154744`, 0.4554278902256328, 0.9419194284550477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 111}], {
             RGBColor[
             0.3833462518703272, 0.5060263932272735, 0.9457099421629962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 116}], {
             RGBColor[
             0.3478897367236583, 0.4755106363355533, 0.9433968344585502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 126}], {
             RGBColor[
             0.3067108401441868, 0.4397029179549527, 0.9407781006569607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.43194074873512733`, 0.5454775949392545, 0.9495354789637005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 174}], {
             RGBColor[
             0.3438036499941711, 0.471971473383162, 0.943136472625332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 182}], {
             RGBColor[
             0.2856601600419676, 0.4175773184773137, 0.9395792955668297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 191}], {
             RGBColor[
             0.29321373700723585`, 0.4255166067922517, 0.9400094606004861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 102}], {
             RGBColor[
             0.3273981891467483, 0.4554287175679108, 0.9421765599569466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 112}], {
             RGBColor[
             0.2912053726836331, 0.4234056885504923, 0.9398950872233656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 140}], {
             RGBColor[
             0.29323255505263285`, 0.42553638575109687`, 0.9400105322603325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 155}], {
             RGBColor[
             0.2652922598561954, 0.3961693639826077, 0.9384193737828581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 99}], {
             RGBColor[
             0.7687919437411839, 0.8183727141912807, 0.944294118700548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 117}], {
             RGBColor[
             0.8762433687105626, 0.9035134810174441, 0.9541841801385145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 120}], {
             RGBColor[
             0.9651286166376958, 0.922790787247423, 0.6081584957443529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 121}], {
             RGBColor[
             0.7580819454747305, 0.8096778551186503, 0.9434509884049964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 146}], {
             RGBColor[
             0.8847914583012635, 0.9101913135735867, 0.9550361738224766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 156}], {
             RGBColor[
             0.9471660663080045, 0.9597340431975859, 0.961036759682581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.9239792736477469, 0.9412455241190165, 0.9588251826995514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 178}], {
             RGBColor[
             0.957960137429429, 0.968167319845601, 0.9560467009664877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 179}], {
             RGBColor[
             0.8907110607570355, 0.9148157520026807, 0.9556261844734377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 183}], {
             RGBColor[
             0.916699432634126, 0.7182581461246227, 0.5672898177785806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 196}], {
             RGBColor[
             0.7343309142909232, 0.7903956980318739, 0.9415812202273133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 107}], {
             RGBColor[
             0.615663269511703, 0.6984811954684678, 0.963146911483036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 109}], {
             RGBColor[
             0.45081925257627997`, 0.561890841684138, 0.9507778651594582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 146}], {
             RGBColor[
             0.6800950161218604, 0.7488157656197341, 0.9695688658362309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 147}], {
             RGBColor[
             0.5223956840025993, 0.6231433757875112, 0.9555440483245787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 156}], {
             RGBColor[
             0.7424696241286013, 0.7983584952437333, 0.9755694516963352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 178}], {
             RGBColor[
             0.7532636952500258, 0.8067917718917483, 0.970579392980242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 179}], {
             RGBColor[
             0.6860146185776324, 0.753440204048828, 0.970158876487192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 194}], {
             RGBColor[
             0.45631234328201786`, 0.5666486807626816, 0.9511278800418784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 104}], {
             RGBColor[
             0.21637454520909913`, 0.34475374432626316`, 0.9356335823009796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 123}], {
             RGBColor[
             0.23212285998297438`, 0.3613062216544334, 0.9365304255298079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 130}], {
             RGBColor[
             0.2255191848288738, 0.3543653403702861, 0.9361543559990437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 135}], {
             RGBColor[
             0.2235466331661063, 0.3522920635057185, 0.9360420220999779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 148}], {
             RGBColor[
             0.20930368592266696`, 0.3373218228978505, 0.9352309073250162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 163}], {
             RGBColor[
             0.22341821875914586`, 0.35215709182205945`, 0.9360347090894736]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 165}], {
             RGBColor[
             0.21635860172261037`, 0.34473698671108804`, 0.9356326743430103]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 123}], {
             RGBColor[
             0.2511378900976988, 0.38129222392755147`, 0.9376133033646252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 124}], {
             RGBColor[
             0.2714494089102611, 0.40264091802422836`, 0.9387700143128014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 127}], {
             RGBColor[
             0.28671598940138643`, 0.417499764656998, 0.9396828962615742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 135}], {
             RGBColor[
             0.2425616632808307, 0.3722780657788366, 0.9371248999347952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 137}], {
             RGBColor[
             0.25101571036429215`, 0.3811638052810985, 0.9376063454095565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 161}], {
             RGBColor[
             0.28025165259241314`, 0.41189263422865363`, 0.9392712890687474]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 165}], {
             RGBColor[
             0.23537363183733478`, 0.36472298898420613`, 0.9367155521778278]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 175}], {
             RGBColor[
             0.2861211170833608, 0.41698451615427623`, 0.9396449915234946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 176}], {
             RGBColor[
             0.27302063754770944`, 0.4042923789438361, 0.9388594934592795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 187}], {
             RGBColor[
             0.2673357347336053, 0.3983171856425559, 0.9385357466540765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 199}], {
             RGBColor[
             0.262066422777004, 0.3927788046824936, 0.9382356671333965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 106}], {
             RGBColor[
             0.32444342089519307`, 0.4523230687923987, 0.9420082902762085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 112}], {
             RGBColor[
             0.337642108559284, 0.46619572637249007`, 0.9427599360129698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 140}], {
             RGBColor[
             0.3396692909282838, 0.4683264235730946, 0.9428753810499368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 108}], {
             RGBColor[
             0.822761672378244, 0.6528409767770607, 0.5936514209828487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 129}], {
             RGBColor[
             0.9272752243887925, 0.727731821781411, 0.3125671941472351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 131}], {
             RGBColor[
             0.8817747101691108, 0.5560483957434501, 0.2230622590091212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 133}], {
             RGBColor[
             0.8438593008645356, 0.3288700512541642, 0.189270528206407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 143}], {
             RGBColor[
             0.8425446000586423, 0.3187646847545005, 0.18801156922994122`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 154}], {
             RGBColor[
             0.9254091486755369, 0.7326773288061676, 0.5407051440124293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 162}], {
             RGBColor[
             0.9235960103474408, 0.7317131111648968, 0.5611505510553894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 123}], {
             RGBColor[
             0.23468312728084179`, 0.36399722491481445`, 0.9366762289648454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 130}], {
             RGBColor[
             0.2280794521267412, 0.3570563436306672, 0.9363001594340813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 163}], {
             RGBColor[
             0.22597848605701326`, 0.35484809508244053`, 0.9361805125245111]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 111}], {
             RGBColor[
             0.4018530682244218, 0.5222917683666206, 0.9468805499681779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 116}], {
             RGBColor[
             0.36639655307775293`, 0.49177601147490035`, 0.944567442263732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 126}], {
             RGBColor[
             0.3252176564982815, 0.45596829309429976`, 0.9419487084621424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 142}], {
             RGBColor[
             0.4920496854617956, 0.5955174455512221, 0.9539811580781995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 157}], {
             RGBColor[
             0.4504475650892219, 0.5617429700786016, 0.9507060867688824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 160}], {
             RGBColor[
             0.35496105134530265`, 0.4818711546392811, 0.9438387822053573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 174}], {
             RGBColor[
             0.3623104663482657, 0.48823684852250904`, 0.9443070804305137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 182}], {
             RGBColor[
             0.30416697639606216`, 0.43384269361666083`, 0.9407499033720115]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 112}], {
             RGBColor[
             0.2882506044320779, 0.42030003977498026`, 0.9397268175426274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 140}], {
             RGBColor[
             0.29027778680107763`, 0.4224307369755848, 0.9398422625795944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 189}], {
             RGBColor[
             0.25322164598941777`, 0.3834823834875024, 0.9377319701800181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 111}], {
             RGBColor[
             0.5638634248724134, 0.6564277480338845, 0.9590690379639482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 142}], {
             RGBColor[
             0.6540600421097872, 0.7296534252184859, 0.9661696460739697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[
             0.5739634519525214, 0.664627405018551, 0.9598641490933124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.7940373920785235, 0.8398425244747729, 0.979889552465069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.6124579217372135, 0.6958789497458655, 0.9628945747646525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.7375823865275546, 0.7949242332798678, 0.9744789772559258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 181}], {
             RGBColor[
             0.8257804710137671, 0.8638766258907483, 0.9384122883545408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 185}], {
             RGBColor[
             0.7184021799057017, 0.779940510091907, 0.9725672735090811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 110}], {
             RGBColor[
             0.6931298062895987, 0.7596256615132471, 0.9704393557617335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 131}], {
             RGBColor[
             0.8402456246331873, 0.7322315204859621, 0.6082404593152602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 154}], {
             RGBColor[
             0.8838800631396134, 0.9088604535486795, 0.9258833443185683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 162}], {
             RGBColor[
             0.8820669248115173, 0.9078962359074088, 0.9463287513615282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 180}], {
             RGBColor[
             0.7526503794757171, 0.8066954638919603, 0.9759808139745987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 132}], {
             RGBColor[
             0.2948786821955154, 0.42460409000948357`, 0.9402017631916271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 146}], {
             RGBColor[
             0.5668187671363596, 0.653709441066444, 0.9615199202813867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 150}], {
             RGBColor[
             0.31023488720570846`, 0.44074443511482886`, 0.941076276349488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 151}], {
             RGBColor[
             0.34470972375175946`, 0.47299196992446024`, 0.9431855766759899]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 152}], {
             RGBColor[
             0.3096412804178116, 0.4401205167439052, 0.9410424713210799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 194}], {
             RGBColor[
             0.3430360942965171, 0.47154235620939167`, 0.9430789344870343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 196}], {
             RGBColor[
             0.4163582231260193, 0.5339138255247312, 0.9480649666862233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 127}], {
             RGBColor[
             0.46330733319948464`, 0.5715960026043997, 0.9518806741110254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 162}], {
             RGBColor[
             0.7939641442587955, 0.8384977959010833, 0.9379384858342741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 180}], {
             RGBColor[
             0.6645475989229954, 0.737297023885635, 0.9675905484473445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 116}], {
             RGBColor[
             0.42503929713653266`, 0.5423745144765412, 0.9483579559716804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 126}], {
             RGBColor[
             0.3838604005570612, 0.5065667960959406, 0.9457392221700909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 142}], {
             RGBColor[
             0.5506924295205754, 0.6461159485528629, 0.957771671786148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 157}], {
             RGBColor[
             0.5090903091480017, 0.6123414730802424, 0.9544966004768307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 160}], {
             RGBColor[
             0.41360379540408243`, 0.5324696576409218, 0.9476292959133059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 167}], {
             RGBColor[
             0.687885792752501, 0.7540851723545239, 0.971226039036996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 174}], {
             RGBColor[
             0.4209532104070455, 0.5388353515241499, 0.9480975941384622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 181}], {
             RGBColor[
             0.7224128584245553, 0.7803391492251253, 0.9300143140667192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.6150345673164899, 0.6964030334262838, 0.9641692992212595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 188}], {
             RGBColor[
             0.5625749036995356, 0.6554211455005088, 0.9589406102153506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 140}], {
             RGBColor[
             0.30347647446516857`, 0.4363033945556761, 0.9405939083163557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 122}], {
             RGBColor[
             0.9466202120897103, 0.8137405258050889, 0.35564035163633406`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 136}], {
             RGBColor[
             0.9041543846818847, 0.6565805366270306, 0.24168008890791598`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 138}], {
             RGBColor[
             0.9065388861824932, 0.6660342904889218, 0.24359871478674944`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 144}], {
             RGBColor[
             0.8784089960348599, 0.5377942228250021, 0.22013747789209492`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 159}], {
             RGBColor[
             0.8614732788871635, 0.4076188795492328, 0.20391981602530412`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 167}], {
             RGBColor[
             0.9077889348257765, 0.7877285014564059, 0.6151514893253305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 197}], {
             RGBColor[
             0.8946095450697447, 0.7772196138099509, 0.6138944273650201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 158}], {
             RGBColor[
             0.23522624458781927`, 0.364568075640074, 0.9367071586920077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 160}], {
             RGBColor[
             0.31613284886837134`, 0.44424671423453505`, 0.9415109015232768]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 126}], {
             RGBColor[
             0.34840388541039236`, 0.4760510392042203, 0.9434261144656448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 142}], {
             RGBColor[
             0.5152359143739065, 0.6156001916611427, 0.9554585640817019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 153}], {
             RGBColor[
             0.48777642817979994`, 0.593307343733011, 0.9532968527410897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 157}], {
             RGBColor[
             0.47363379400133276`, 0.5818257161885222, 0.9521834927723848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 160}], {
             RGBColor[
             0.3781472802574135, 0.5019539007492015, 0.9453161882088599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 167}], {
             RGBColor[
             0.652429277605832, 0.7235694154628036, 0.96891293133255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 174}], {
             RGBColor[
             0.38549669526037655`, 0.5083195946324296, 0.9457844864340161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 188}], {
             RGBColor[
             0.5271183885528666, 0.6249053886087885, 0.9566275025109046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 120}], {
             RGBColor[
             0.8678835994276715, 0.8465560061197337, 0.6325812491960736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 121}], {
             RGBColor[
             0.6608369282647062, 0.733443073990961, 0.9678737418567172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 146}], {
             RGBColor[
             0.7875464410912392, 0.8339565324458974, 0.9794589272741974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 151}], {
             RGBColor[
             0.565437397706639, 0.6532390613039136, 0.9611245836688005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 171}], {
             RGBColor[
             0.8267342564377225, 0.8650107429913272, 0.9832479361512722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 173}], {
             RGBColor[
             0.8870698836005233, 0.9096475021441977, 0.8455791000881498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 196}], {
             RGBColor[
             0.6370858970808988, 0.7141609169041846, 0.966003973679034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 119}], {
             RGBColor[
             0.7390929491372125, 0.7956716911845035, 0.9752408612005126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 125}], {
             RGBColor[
             0.5461336776674304, 0.6195695759530597, 0.9625480754195246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 128}], {
             RGBColor[
             0.901444520807011, 0.7626039594239429, 0.6105848646794676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 138}], {
             RGBColor[
             0.9130416014388392, 0.812801149295034, 0.6201343733156849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 144}], {
             RGBColor[
             0.8849117112912057, 0.6845610816311141, 0.5966731364210304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 149}], {
             RGBColor[
             0.5734377675010032, 0.6482679055474284, 0.9641030029427655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 159}], {
             RGBColor[
             0.8679759941435095, 0.5543857383553449, 0.5804554745542396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 170}], {
             RGBColor[
             0.5478364454002871, 0.6213592928020021, 0.9626450455228917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 190}], {
             RGBColor[
             0.5465072945042451, 0.6199622709372278, 0.9625693523456647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 192}], {
             RGBColor[
             0.8653132634712222, 0.5339188235921248, 0.5779056406553331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.5461172634712222, 0.6195523235921249, 0.9625471406553332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 197}], {
             RGBColor[
             0.9011122603260905, 0.9239864726160629, 0.9904300858939554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 125}], {
             RGBColor[
             0.3719190998621983, 0.4815306199533135, 0.9461956553093709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 128}], {
             RGBColor[
             0.727229943001779, 0.6245650034241965, 0.5942324445693138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 144}], {
             RGBColor[
             0.7106971334859737, 0.5465221256313679, 0.5803207163108766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 149}], {
             RGBColor[
             0.3992231896957711, 0.5102289495476822, 0.9477505828326117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 183}], {
             RGBColor[
             0.7123944253398227, 0.5572003826444346, 0.5818533249803631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 190}], {
             RGBColor[
             0.3722927166990131, 0.48192331493748153`, 0.946216932235511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 192}], {
             RGBColor[
             0.6910986856659902, 0.39587986759237864`, 0.5615532205451794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 195}], {
             RGBColor[
             0.37190268566599016`, 0.4815133675923786, 0.9461947205451795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 128}], {
             RGBColor[
             0.9231751810131911, 0.7286652920066743, 0.2580660064250903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 168}], {
             RGBColor[
             0.9476806026150666, 0.909778086957847, 0.6376934323137864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 171}], {
             RGBColor[
             0.9156195043648556, 0.8842880492213061, 0.6372222517571104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 172}], {
             RGBColor[
             0.9753727800277856, 0.9276792174007213, 0.4361680487899127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 173}], {
             RGBColor[
             0.9759551315276564, 0.9289248083741766, 0.49955341569398815`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 183}], {
             RGBColor[
             0.9083396633512348, 0.6613006712269123, 0.24568688683613962`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 151}], {
             RGBColor[
             0.4472759744708069, 0.5594034354051198, 0.9503913919352824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 171}], {
             RGBColor[
             0.7085728332018904, 0.7711751170925334, 0.9725147444177542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 196}], {
             RGBColor[
             0.5189244738450667, 0.6203252910053908, 0.955270781945516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 136}], {
             RGBColor[
             0.9504725003418423, 0.8301441328600938, 0.35879847629145456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 138}], {
             RGBColor[
             0.9528570018424507, 0.8395978867219851, 0.360717102170288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 142}], {
             RGBColor[
             0.8169136872538085, 0.8533228738878083, 0.7188155094580211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 144}], {
             RGBColor[
             0.9247271116948175, 0.7113578190580653, 0.33725586527563345`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 153}], {
             RGBColor[
             0.7894542010597019, 0.8310300259596766, 0.7166537981174088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.907791394547121, 0.5811824757822961, 0.3210382034088427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 167}], {
             RGBColor[
             0.9541070504857341, 0.9612920976894692, 0.7322698767088691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 181}], {
             RGBColor[
             0.9886341161577883, 0.9875460745600706, 0.6910581517385923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 188}], {
             RGBColor[
             0.8287961614327686, 0.8626280708354541, 0.7199844478872237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 192}], {
             RGBColor[
             0.9051286638748339, 0.560715561019076, 0.3184883695099363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 127}], {
             RGBColor[
             0.2860095413584047, 0.4167572429724312, 0.9396426650906227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 130}], {
             RGBColor[
             0.24382776690061642`, 0.3736088209588374, 0.9371970026629095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 135}], {
             RGBColor[
             0.24185521523784892`, 0.3715355440942698, 0.9370846687638437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 163}], {
             RGBColor[
             0.2417268008308885, 0.37140057241061075`, 0.9370773557533394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 165}], {
             RGBColor[
             0.23466718379435303`, 0.36398046729963934`, 0.9366753210068761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 177}], {
             RGBColor[
             0.27201910823742403`, 0.40323970813810023`, 0.9388024578466887]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 187}], {
             RGBColor[
             0.26662928669062347`, 0.3975746639579891, 0.9384955154831248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 127}], {
             RGBColor[
             0.30632106017096694`, 0.43810593706910805`, 0.9407993760387987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 135}], {
             RGBColor[
             0.26216673405041124`, 0.39288423819094664`, 0.9382413797120197]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.27062078113387267`, 0.4017699776932086, 0.938722825186781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 161}], {
             RGBColor[
             0.29985672336199365`, 0.43249880664076373`, 0.9403877688459719]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 175}], {
             RGBColor[
             0.3057261878529413, 0.4375906885663863, 0.9407614713007191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 176}], {
             RGBColor[
             0.29262570831728996`, 0.4248985513559462, 0.9399759732365041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 187}], {
             RGBColor[
             0.2869408055031858, 0.4189233580546661, 0.939652226431301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 199}], {
             RGBColor[
             0.2816714935465845, 0.4133849770946037, 0.939352146910621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 128}], {
             RGBColor[
             0.5342706715319968, 0.44846288819275276`, 0.5815396587883258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.206263918225989, 0.33412683431623835`, 0.9350577970516237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[
             0.18066259612527297`, 0.307218221570812, 0.93359983963175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 190}], {
             RGBColor[
             0.179333445229231, 0.3058211997060377, 0.933524146454523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 195}], {
             RGBColor[
             0.17894341419620807`, 0.3054112523609348, 0.9335019347641915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 142}], {
             RGBColor[
             0.47405701779443504`, 0.579792473280542, 0.9528398302801124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 157}], {
             RGBColor[
             0.43245489742186133`, 0.5460179978079216, 0.9495647589707952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 160}], {
             RGBColor[
             0.336968383677942, 0.466146182368601, 0.9426974544072704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 174}], {
             RGBColor[
             0.3443177986809051, 0.472511876251829, 0.9431657526324266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 182}], {
             RGBColor[
             0.2861743087287016, 0.41811772134598074`, 0.9396085755739244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 191}], {
             RGBColor[
             0.2937278856939699, 0.4260570096609187, 0.9400387406075807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 135}], {
             RGBColor[
             0.2774333145415366, 0.4077430848237163, 0.9391542616607926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 161}], {
             RGBColor[
             0.31512330385311904`, 0.4473576532735334, 0.9413006507947447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 175}], {
             RGBColor[
             0.32099276834406665`, 0.45244953519915593`, 0.9416743532494919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 176}], {
             RGBColor[
             0.3078922888084153, 0.4397573979887158, 0.940888855185277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 177}], {
             RGBColor[
             0.3075972075411117, 0.4394472488675467, 0.9408720507436377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 180}], {
             RGBColor[
             0.5228279063856032, 0.618665804983113, 0.9574221323238906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 187}], {
             RGBColor[
             0.3022073859943112, 0.43378220468743567`, 0.9405651083800737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 183}], {
             RGBColor[
             0.8747459970096212, 0.524132650883874, 0.217197328459318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 190}], {
             RGBColor[
             0.5346442883688116, 0.44885558317692076`, 0.5815609357144658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 192}], {
             RGBColor[
             0.8534502573357887, 0.36281213583181793`, 0.19689722402413434`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 195}], {
             RGBColor[
             0.5342542573357888, 0.44844563583181796`, 0.5815387240241343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 131}], {
             RGBColor[
             0.9447591766437358, 0.8071223654903125, 0.32715623247964654`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 133}], {
             RGBColor[
             0.9068437673391607, 0.5799440210010265, 0.2933645016769323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 143}], {
             RGBColor[
             0.9055290665332671, 0.5698386545013628, 0.2921055427004665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 170}], {
             RGBColor[
             0.5863125273607737, 0.6439068649740138, 0.6751789886764388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 197}], {
             RGBColor[
             0.939588342286577, 0.9465340447880747, 0.7029640290475025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 163}], {
             RGBColor[
             0.23512312567678792`, 0.3644596911264634, 0.9367012862225752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 177}], {
             RGBColor[
             0.26541543308332344`, 0.3962988268539529, 0.9384263883159245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 133}], {
             RGBColor[
             0.8613432531194789, 0.40826059496306566`, 0.20385956653881843`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 143}], {
             RGBColor[
             0.8600285523135855, 0.398155228463402, 0.20260060756235265`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 154}], {
             RGBColor[
             0.9428931009304802, 0.8120678725150692, 0.5552941823448407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 162}], {
             RGBColor[
             0.941079962602384, 0.8111036548737982, 0.5757395893878008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 180}], {
             RGBColor[
             0.811663417266584, 0.70990288285835, 0.6053916520008711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 150}], {
             RGBColor[
             0.2675705658104447, 0.39856400799346436`, 0.938549119936501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 151}], {
             RGBColor[
             0.3020454023564957, 0.43081154280309575`, 0.9406584202630028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 162}], {
             RGBColor[
             0.903164553297809, 0.5839253103845123, 0.5419478585850865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 139}], {
             RGBColor[
             0.2400051701500614, 0.36959102940737165`, 0.9369793114329906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 145}], {
             RGBColor[
             0.21930399653046173`, 0.34783278340295676`, 0.9358004102199964]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 191}], {
             RGBColor[
             0.25554145744836393`, 0.3859206524153965, 0.9378640800107516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 148}], {
             RGBColor[
             0.2190360411775415, 0.34755114533768694`, 0.935785150559052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 163}], {
             RGBColor[
             0.2331505740140204, 0.36238641426189583`, 0.9365889523235094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 165}], {
             RGBColor[
             0.22609095697748494`, 0.3549663091509244, 0.9361869175770461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 176}], {
             RGBColor[
             0.26373796268785954`, 0.3945356991105544, 0.938330858858498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 187}], {
             RGBColor[
             0.2580530598737554, 0.38856050580927426`, 0.9380071120532948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 143}], {
             RGBColor[
             0.8644025575685669, 0.416927830578244, 0.20619406567310455`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 159}], {
             RGBColor[
             0.8653255671392956, 0.4240224866042378, 0.2070779406804246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 197}], {
             RGBColor[
             0.8984618333218767, 0.7936232208649558, 0.6170525520201404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 161}], {
             RGBColor[
             0.2794230248160247, 0.4110216938976339, 0.939224099942727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 175}], {
             RGBColor[
             0.2852924893069724, 0.4161135758232565, 0.9395978023974743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 176}], {
             RGBColor[
             0.27219200977132096`, 0.4034214386128163, 0.9388123043332592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 186}], {
             RGBColor[
             0.2661087370017966, 0.3970275332302755, 0.9384658709484304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 187}], {
             RGBColor[
             0.2665071069572168, 0.39744624531153616`, 0.938488557528056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 199}], {
             RGBColor[
             0.26123779500061556`, 0.39190786435147384`, 0.9381884780073761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 142}], {
             RGBColor[
             0.7768323613465915, 0.7056166385716411, 0.6067738726084364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 144}], {
             RGBColor[
             0.8846457857876004, 0.5636515837418983, 0.22521422842604885`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 156}], {
             RGBColor[
             0.9168097113153278, 0.8158057378279282, 0.6204937789995357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 159}], {
             RGBColor[
             0.8677100686399041, 0.4334762404661291, 0.20899656655925808`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 167}], {
             RGBColor[
             0.914025724578517, 0.8135858623733021, 0.6202282398592844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 181}], {
             RGBColor[
             0.9485527902505714, 0.8398398392439036, 0.5790165148890076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 185}], {
             RGBColor[
             0.8411744991425061, 0.7559037234450623, 0.613171500043548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 192}], {
             RGBColor[
             0.8650473379676169, 0.41300932570290905`, 0.20644673266035168`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 145}], {
             RGBColor[
             0.2284570343408142, 0.357453206477753, 0.9363216621825899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 152}], {
             RGBColor[
             0.26544888260262894`, 0.3963339844195651, 0.9384282932165648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 182}], {
             RGBColor[
             0.2571409182934481, 0.38760178717525484`, 0.9379551669396888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 191}], {
             RGBColor[
             0.2646944952587164, 0.3955410754901928, 0.9383853319733451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 198}], {
             RGBColor[
             0.5277497041986612, 0.6241140740098087, 0.9572340887790165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 153}], {
             RGBColor[
             0.6134295605638427, 0.6970487778093326, 0.9627105685555573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 157}], {
             RGBColor[
             0.5992869263853755, 0.6855671502648439, 0.9615972085868523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 160}], {
             RGBColor[
             0.5038004126414563, 0.6056953348255233, 0.9547299040233275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 167}], {
             RGBColor[
             0.7780824099898748, 0.8273108495391253, 0.9783266471470176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 174}], {
             RGBColor[
             0.5111498276444193, 0.6120610287087513, 0.9551982022484837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 181}], {
             RGBColor[
             0.8126094756619291, 0.8535648264097266, 0.9371149221767408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 185}], {
             RGBColor[
             0.7052311845538637, 0.7696287106108853, 0.971269907331281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.6527715209369094, 0.7286468226851102, 0.9660412183253722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 154}], {
             RGBColor[
             0.9036629908200117, 0.5747841615261196, 0.5202434925656607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 159}], {
             RGBColor[
             0.8217214517738456, 0.16796617350044618`, 0.16843379279049273`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 197}], {
             RGBColor[
             0.8548577179564267, 0.5375669077611642, 0.5784084041302087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 149}], {
             RGBColor[
             0.5450419518497644, 0.3991183399942927, 0.5691828580531295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 159}], {
             RGBColor[
             0.8395801784922707, 0.30523617280220927`, 0.18553532966460354`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 170}], {
             RGBColor[
             0.5194406297490485, 0.3722097272488664, 0.5677249006332556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 181}], {
             RGBColor[
             0.920422900102938, 0.7115997715799838, 0.5555552779943531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 190}], {
             RGBColor[
             0.5181114788530065, 0.37081270538409206`, 0.5676492074560286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 192}], {
             RGBColor[
             0.8369174478199836, 0.2847692580389892, 0.18298549576569717`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 197}], {
             RGBColor[
             0.8727164446748519, 0.6748369070629272, 0.5955099410043194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 147}], {
             RGBColor[
             0.6383951985626789, 0.7149619751698173, 0.9662861034465073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 156}], {
             RGBColor[
             0.8584691386886809, 0.8901770946260392, 0.9863115068182637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 171}], {
             RGBColor[
             0.8352823460284233, 0.8716885755474699, 0.9840999298352342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 178}], {
             RGBColor[
             0.8692632098101054, 0.8986103712740543, 0.9813214481021706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 179}], {
             RGBColor[
             0.802014133137712, 0.8452588034311341, 0.9809009316091206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 183}], {
             RGBColor[
             0.8280025050148025, 0.648701197553076, 0.5925645649142633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 194}], {
             RGBColor[
             0.5723118578420975, 0.6584672801449877, 0.9618699351638069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 196}], {
             RGBColor[
             0.6456339866715997, 0.7208387494603272, 0.9668559673629961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 152}], {
             RGBColor[
             0.3812177118441309, 0.5013730508472783, 0.9458086544862003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 156}], {
             RGBColor[
             0.7007698065694198, 0.7645047047938165, 0.9722866893066117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 178}], {
             RGBColor[
             0.7115638776908443, 0.7729379814418316, 0.9672966305905184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 179}], {
             RGBColor[
             0.6443148010184508, 0.7195864135989113, 0.9668761140974684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 185}], {
             RGBColor[
             0.625134594396598, 0.7046026904109504, 0.9649644103506239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 194}], {
             RGBColor[
             0.41461252572283636`, 0.5327948903127648, 0.9478451176521548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 165}], {
             RGBColor[
             0.2118480097340456, 0.33999606854305653`, 0.9353758028020844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 159}], {
             RGBColor[
             0.5281062347020681, 0.2689429967185235, 0.5529651961863387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 170}], {
             RGBColor[
             0.2079666859588458, 0.3359165511651807, 0.9351547671549908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 190}], {
             RGBColor[
             0.2066375350628038, 0.33451952930040635`, 0.9350790739777637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 192}], {
             RGBColor[
             0.5254435040297809, 0.2484760819553035, 0.5504153622874323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 195}], {
             RGBColor[
             0.2062475040297809, 0.3341095819553035, 0.9350568622874322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.5612425008846491, 0.6385437309792414, 0.9629398075260546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 151}], {
             RGBColor[
             0.3174016073666887, 0.4469518879084411, 0.9415329334208639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 152}], {
             RGBColor[
             0.2823331640327409, 0.4140804347278859, 0.9393898280659538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 194}], {
             RGBColor[
             0.31572797791144636`, 0.44550227419337246`, 0.9414262912319082]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 171}], {
             RGBColor[
             0.6131733026438233, 0.690971104405486, 0.9657655862298374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 196}], {
             RGBColor[
             0.4235249432869995, 0.5401212783183434, 0.9485216237575993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 194}], {
             RGBColor[
             0.3151343711235495, 0.4448783558224487, 0.9413924862035001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 160}], {
             RGBColor[
             0.4763409264473496, 0.5834024868973917, 0.9525681926827152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 167}], {
             RGBColor[
             0.7506229237957682, 0.8050180016109936, 0.9761649358064053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 174}], {
             RGBColor[
             0.4836903414503127, 0.5897681807806197, 0.9530364909078715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 188}], {
             RGBColor[
             0.6253120347428027, 0.7063539747569785, 0.9638795069847599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 157}], {
             RGBColor[
             0.7392642763541118, 0.795756249521131, 0.9753171149779516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 178}], {
             RGBColor[
             0.9316378178168464, 0.9481531008980535, 0.987322033962275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.864388741144453, 0.8948015330551333, 0.986901517469225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 181}], {
             RGBColor[
             0.9525868256306654, 0.9637539256660137, 0.9508348285678401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 183}], {
             RGBColor[
             0.8903771130215434, 0.6982439271770752, 0.5985651507743678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 185}], {
             RGBColor[
             0.8452085345226001, 0.8798178098671724, 0.9849898137223804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 192}], {
             RGBColor[
             0.869081373347711, 0.5369234121250193, 0.5782650463391841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 174}], {
             RGBColor[
             0.4695477072718456, 0.5782865532361309, 0.9519231309391665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 181}], {
             RGBColor[
             0.7710073552893554, 0.8197903509371063, 0.9338398508674235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 185}], {
             RGBColor[
             0.6636290641812901, 0.7358542351382649, 0.9679948360219639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 164}], {
             RGBColor[
             0.27399405489207074`, 0.4053155022909841, 0.9389149281369991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 166}], {
             RGBColor[
             0.3220947514992546, 0.4482744245110126, 0.9419323901733808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 170}], {
             RGBColor[
             0.5025049126013521, 0.2420343839730972, 0.5515072387664649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 197}], {
             RGBColor[
             0.8557807275271554, 0.5446615637871581, 0.5792922791375287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 167}], {
             RGBColor[
             0.6409937758733817, 0.7136645586271843, 0.9681842712741754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 174}], {
             RGBColor[
             0.37406119352792633`, 0.4984147377968103, 0.9450558263756417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 188}], {
             RGBColor[
             0.5156828868204164, 0.6150005317731692, 0.9558988424525301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 175}], {
             RGBColor[
             0.31452843153509336`, 0.4468424047708116, 0.941262746056665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 176}], {
             RGBColor[
             0.301427951999442, 0.43415026756037145`, 0.9404772479924501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 187}], {
             RGBColor[
             0.2957430491853379, 0.4281750742590913, 0.9401535011872468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 193}], {
             RGBColor[
             0.31267272742048674`, 0.4452350871371401, 0.9411445022314171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 199}], {
             RGBColor[
             0.2904737372287366, 0.422636693299029, 0.9398534216665669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 180}], {
             RGBColor[
             0.853484717444914, 0.8855675982797966, 0.9434799440471393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 177}], {
             RGBColor[
             0.2633144670135955, 0.39409057830572625`, 0.9383067414063544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 166}], {
             RGBColor[
             0.3428237586125573, 0.4700619252820549, 0.9431128764626655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 184}], {
             RGBColor[
             0.33292802569279517`, 0.46149073880095526`, 0.9424823291114712]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 187}], {
             RGBColor[
             0.2508650284302595, 0.38100542901464385`, 0.9375977642963274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 184}], {
             RGBColor[
             0.3810287222999791, 0.5044496610209838, 0.9454997911478531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 181}], {
             RGBColor[
             0.9498028388938546, 0.9615340502113876, 0.9505692894275887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 188}], {
             RGBColor[
             0.7899648841688349, 0.8366160464867711, 0.9794955855762202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 172}], {
             RGBColor[
             0.9662845352880476, 0.9716239920088556, 0.7873059163017873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 173}], {
             RGBColor[
             0.9668668867879184, 0.9728695829823109, 0.8506912832058626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 184}], {
             RGBColor[
             0.6548626736277727, 0.7248006680529328, 0.9668502718111599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 198}], {
             RGBColor[
             0.8173765882647961, 0.8581441256038294, 0.9795908811512684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 200}], {
             RGBColor[
             0.2545855584826314, 0.3849159419949167, 0.9378096429787789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 190}], {
             RGBColor[
             0.1810362129620878, 0.3076109165549801, 0.93362111655789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 195}], {
             RGBColor[
             0.1806461819290649, 0.30720096920987716`, 0.9335989048675586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 197}], {
             RGBColor[
             0.5356411787839332, 0.6116351182338152, 0.9614818501061808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 173}], {
             RGBColor[
             0.9348057885377076, 0.9473795452457701, 0.8502201026491867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 178}], {
             RGBColor[
             0.9084510251565888, 0.9296645818194842, 0.9851104569792455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 183}], {
             RGBColor[
             0.8671903203612858, 0.6797554080985058, 0.5963535737913382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 196}], {
             RGBColor[
             0.6848218020180831, 0.7518929600057571, 0.9706449762400708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 173}], {
             RGBColor[
             0.9945590642006376, 0.9907707134251852, 0.6491658996819889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 198}], {
             RGBColor[
             0.8450687656775151, 0.8760452560467036, 0.7780654976273946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 188}], {
             RGBColor[
             0.5230323018233795, 0.6213662256563972, 0.9563671406776864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 176}], {
             RGBColor[
             0.30729741649038966`, 0.43924214948599405`, 0.9408509504471974]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 187}], {
             RGBColor[
             0.3016125136762855, 0.4332669561847139, 0.940527203641994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 199}], {
             RGBColor[
             0.2963432017196842, 0.4277285752246516, 0.9402271241213142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 187}], {
             RGBColor[
             0.2885120341406341, 0.42057481897427373`, 0.9397417055777791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 199}], {
             RGBColor[
             0.28324272218403285`, 0.4150364380142114, 0.9394416260570992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 179}], {
             RGBColor[
             0.8751828122658775, 0.9032348097031484, 0.9819114587531318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 183}], {
             RGBColor[
             0.9011711841429679, 0.7066772038250902, 0.5935750920582745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 183}], {
             RGBColor[
             0.8339221074705745, 0.65332563598217, 0.5931545755652246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 185}], {
             RGBColor[
             0.7887535289716312, 0.8348995186722672, 0.9795792385132371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 194}], {
             RGBColor[
             0.5782314602978695, 0.6630917185740817, 0.9624599458147682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 185}], {
             RGBColor[
             0.8769516134578437, 0.9038519112831478, 0.9435125496118522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 188}], {
             RGBColor[
             0.8244919498408892, 0.8628700233573725, 0.9382838606059434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 192}], {
             RGBColor[
             0.9008244522829545, 0.5609575135409945, 0.536787782228656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 191}], {
             RGBColor[
             0.2726772055917506, 0.4039314101832797, 0.9388399355174497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 192}], {
             RGBColor[
             0.8386147396738325, 0.29544751505205596`, 0.18451810443518368`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 193}], {
             RGBColor[
             0.29935843960625863`, 0.43124092646978174`, 0.9403862732371204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 199}], {
             RGBColor[
             0.2771594494145085, 0.4086425326316706, 0.9390951926722704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 199}], {
             RGBColor[
             0.27755781936992874`, 0.40906124471293126`, 0.9391178792518959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 192}], {
             RGBColor[
             0.4985130310330229, 0.22017044734510285`, 0.5488817116903315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 195}], {
             RGBColor[
             0.1793170310330229, 0.30580394734510286`, 0.9335232116903315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 199}], {
             RGBColor[
             0.2944874976050776, 0.4261212575909801, 0.9401088802960662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 197}], {
             RGBColor[
             0.5339219968548683, 0.6098281490239381, 0.9613839452386224]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.04749427504982855], {
             RGBColor[
             0.9583125875736904, 0.8710407105954553, 0.2925527040414048]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.04749427504982855], {
             RGBColor[
             0.377120805174838, 0.5010648196248124, 0.9452507821242745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.04749427504982855], {
             RGBColor[
             0.26366336471100654`, 0.39445729190709694`, 0.938326610614074]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.04749427504982855], {
             RGBColor[
             0.8048857220793089, 0.8475021105371937, 0.9811871447582946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.04749427504982855], {
             RGBColor[
             0.2822070658609612, 0.41394789755425965`, 0.9393826469616164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.04749427504982855], {
             RGBColor[
             0.3400518121902417, 0.46895752104331584`, 0.9428887786701194]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.04749427504982855], {
             RGBColor[
             0.350460125859892, 0.477972679206911, 0.9435519872134391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.04749427504982855], {
             RGBColor[
             0.44819737568646545`, 0.5626277725896778, 0.9497797183467319]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.04749427504982855], {
             RGBColor[
             0.2605668322464433, 0.39120263995534316`, 0.9381502676711264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.04749427504982855], {
             RGBColor[
             0.28931600419628395`, 0.4214198424774074, 0.9397874904830813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.04749427504982855], {
             RGBColor[
             0.24586228151751777`, 0.37574722481687783`, 0.9373128652605475]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.04749427504982855], {
             RGBColor[
             0.5839626349742006, 0.6731262001457912, 0.9603908242322355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.04749427504982855], {
             RGBColor[
             0.3779993100162068, 0.5018257363634689, 0.9453067596759351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.04749427504982855], {
             RGBColor[
             0.4167727741971154, 0.535409362225998, 0.9477773705275145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.04749427504982855], {
             RGBColor[
             0.32511075702074876`, 0.45601633001476893`, 0.9419367478465757]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.04749427504982855], {
             RGBColor[
             0.3229612837478847, 0.4541545643014821, 0.9417997853103334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.04749427504982855], {
             RGBColor[
             0.2388383031545141, 0.3683645782114108, 0.9369128600838192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.04749427504982855], {
             RGBColor[
             0.3183704566888478, 0.45017822064462143`, 0.9415072618696405]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.04749427504982855], {
             RGBColor[
             0.26440158051900675`, 0.3952332035268908, 0.9383686509122472]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.04749427504982855], {
             RGBColor[
             0.22540124214842158`, 0.354241375135133, 0.9361476393378726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.04749427504982855], {
             RGBColor[
             0.31620160663402885`, 0.4482996717367106, 0.9413690646619862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.04749427504982855], {
             RGBColor[
             0.8444218577904707, 0.34245144152557083`, 0.19017172722845446`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.04749427504982855], {
             RGBColor[
             0.9935791491691084, 0.9886747742573517, 0.5425081958346172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.04749427504982855], {
             RGBColor[
             0.17892700283938517`, 0.30539400298437386`, 0.9335010001616988]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.04749427504982855], {
             RGBColor[
             0.9789215033713261, 0.9405594227844256, 0.37261445024803247`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.04749427504982855], {
             RGBColor[
             0.39640287984113043`, 0.5177659835555031, 0.9464794188715415]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.04749427504982855], {
             RGBColor[
             0.2767490295536739, 0.4082111553358114, 0.9390718198683575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.04749427504982855], {
             RGBColor[
             0.29477679578460203`, 0.4271594806709139, 0.9400984744855188]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.04749427504982855], {
             RGBColor[
             0.9936430185668372, 0.9916392390574856, 0.75501516389549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.04749427504982855], {
             RGBColor[
             0.8937471851268821, 0.9181137615718546, 0.9897275984465748]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.04749427504982855], {
             RGBColor[
             0.8505083657915934, 0.8836363007203797, 0.9856034412586252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.04749427504982855], {
             RGBColor[
             0.23515166545220784`, 0.36448968823995603`, 0.9367029115205646]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.04749427504982855], {
             RGBColor[
             0.3230400522816408, 0.4542227896464, 0.941804804371652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.04749427504982855], {
             RGBColor[
             0.2517479206748871, 0.38193340474234894`, 0.9376480437035368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.04749427504982855], {
             RGBColor[
             0.8383733051460716, 0.8739601327590868, 0.9844459883411588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.04749427504982855], {
             RGBColor[
             0.24777983952010385`, 0.3777626998577953, 0.9374220673520219]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.04749427504982855], {
             RGBColor[
             0.19099374879671333`, 0.31807691806140814`, 0.9341881834928177]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.04749427504982855], {
             RGBColor[
             0.9648082727380654, 0.8929521819142981, 0.31778721429778617`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.04749427504982855], {
             RGBColor[
             0.20098973591686892`, 0.3285833343068806, 0.9347574401715728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.04749427504982855], {
             RGBColor[
             0.49158142165721236`, 0.5981269694488269, 0.9531182367163876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.04749427504982855], {
             RGBColor[
             0.5497140953330726, 0.6453216927859953, 0.9576946537351515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.04749427504982855], {
             RGBColor[
             0.5214414667269106, 0.6223686992161088, 0.9554689288452234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.04749427504982855], {
             RGBColor[
             0.8553653759675705, 0.4265681177150025, 0.20065125259378117`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.04749427504982855], {
             RGBColor[
             0.2834240796528994, 0.4152270562127178, 0.9394519540966568]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.04749427504982855], {
             RGBColor[
             0.8843599871114161, 0.5677875345316877, 0.22521947746071738`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.04749427504982855], {
             RGBColor[
             0.5977424503378598, 0.6843132750316175, 0.9614756217747897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.04749427504982855], {
             RGBColor[
             0.4515217278586501, 0.5655071593544256, 0.9499915431275343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.04749427504982855], {
             RGBColor[
             0.3171026989044469, 0.4490801525711323, 0.9414264814646527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.04749427504982855], {
             RGBColor[
             0.8347376037115143, 0.26801402100751526`, 0.1808980745856452]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.04749427504982855], {
             RGBColor[
             0.2422322948146241, 0.37193187863768656`, 0.9371061428879017]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.04749427504982855], {
             RGBColor[
             0.28213996431762406`, 0.4138773695777287, 0.9393788256279912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.04749427504982855], {
             RGBColor[
             0.21246269677098534`, 0.3406421435922893, 0.9354108083194902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.04749427504982855], {
             RGBColor[
             0.21141226994966317`, 0.3395380784021726, 0.9353509880659832]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.04749427504982855], {
             RGBColor[
             0.27280646441116213`, 0.40406726939796367`, 0.938847296615994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.04749427504982855], {
             RGBColor[
             0.35238205413251156`, 0.47963735687773035`, 0.943674450783476]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.04749427504982855], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.04749427504982855], {
             RGBColor[
             0.3605779115447064, 0.4867361966324024, 0.9441966835704689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.04749427504982855], {
             RGBColor[
             0.264153442110629, 0.394972394326802, 0.9383545197969779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.04749427504982855], {
             RGBColor[
             0.44880489881560515`, 0.5631539785891382, 0.949818429183309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.04749427504982855], {
             RGBColor[
             0.253957266336059, 0.38425556711284614`, 0.9377738626705066]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.04749427504982855], {
             RGBColor[
             0.2737970101358498, 0.4051083957588368, 0.9389037067296339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.04749427504982855], {
             RGBColor[
             0.3562346737166085, 0.4829743023231845, 0.943919936296637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.04749427504982855], {
             RGBColor[
             0.35285247495850214`, 0.48004481175316516`, 0.9437044255825313]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.04749427504982855], {
             RGBColor[
             0.6226026285830288, 0.704495887669313, 0.963432706072083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.04749427504982855], {
             RGBColor[
             0.9220936452530043, 0.9407164594322621, 0.992431309118588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.04749427504982855], {
             RGBColor[
             0.6916199917227627, 0.7590180611312259, 0.9698978752847841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.04749427504982855], {
             RGBColor[
             0.8182056947053702, 0.14094252405757224`, 0.16506709985124088`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.04749427504982855], {
             RGBColor[
             0.8556248139763563, 0.8877160176206234, 0.9860914526539951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.04749427504982855], {
             RGBColor[
             0.4015855979045752, 0.522254993451075, 0.9468096570836465]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.04749427504982855], {
             RGBColor[
             0.21367513065222027`, 0.34191648847421524`, 0.9354798546353913]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.04749427504982855], {
             RGBColor[
             0.2902833275082297, 0.42243656061010276`, 0.93984257811467]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.04749427504982855], {
             RGBColor[
             0.24987650973082426`, 0.37996643318583184`, 0.9375414696187768]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.04749427504982855], {
             RGBColor[
             0.2931347355771166, 0.42543357128021636`, 0.9400049615859128]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.04749427504982855], {
             RGBColor[
             0.30278259996188467`, 0.4355740884585403, 0.9405543931898891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.04749427504982855], {
             RGBColor[
             0.28416143346402023`, 0.4160020618191376, 0.9394939453053829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.04749427504982855], {
             RGBColor[
             0.27635030732849636`, 0.40779207299670056`, 0.9390491132274904]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.04749427504982855], {
             RGBColor[
             0.3003940670337382, 0.43306358890932384`, 0.940418369773149]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.04749427504982855], {
             RGBColor[
             0.9279645300339343, 0.9453977435956535, 0.9929912793499938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.04749427504982855], {
             RGBColor[
             0.20396815225836698`, 0.3317138387242981, 0.934927056576049]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.04749427504982855], {
             RGBColor[
             0.6198970672218798, 0.7022993910721819, 0.9632197143709355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.04749427504982855], {
             RGBColor[
             0.5763338163997934, 0.6669327815527272, 0.9597902556887751]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.04749427504982855], {
             RGBColor[
             0.31859842780058983`, 0.45037567776345117`, 0.9415217879872938]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.04749427504982855], {
             RGBColor[
             0.25584834544704116`, 0.3862432111598293, 0.9378815568282761]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.04749427504982855], {
             RGBColor[
             0.2627765683456537, 0.3935252127009741, 0.9382761088729649]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.04749427504982855], {
             RGBColor[
             0.360155081261214, 0.48636996229290924`, 0.9441697411986989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.04749427504982855], {
             RGBColor[
             0.3919595940317969, 0.5139174327134967, 0.9461962966288141]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.04749427504982855], {
             RGBColor[
             0.9879745726157381, 0.9892951909842899, 0.8489559827730842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.04749427504982855], {
             RGBColor[
             0.7121946053554326, 0.7750911056739228, 0.9719485604909927]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.04749427504982855], {
             RGBColor[
             0.8539922331287186, 0.4160135401405583, 0.19933632946055357`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.04749427504982855], {
             RGBColor[
             0.3879488339253545, 0.5104435138959607, 0.9459407345414075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.04749427504982855], {
             RGBColor[
             0.8378176201564483, 0.8735170446320284, 0.9843929866107827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.04749427504982855], {
             RGBColor[
             0.22871531315648586`, 0.35772467388884666`, 0.9363363707790532]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.04749427504982855], {
             RGBColor[
             0.22414759348065547`, 0.35292371089939434`, 0.9360762459008504]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.04749427504982855], {
             RGBColor[
             0.4181274501813097, 0.5365827144755124, 0.9478636892833344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.04749427504982855], {
             RGBColor[
             0.9796258119030633, 0.9429352208414826, 0.3753505558963255]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.04749427504982855], {
             RGBColor[
             0.3061966914574528, 0.4391625150862857, 0.940748820649866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.04749427504982855], {
             RGBColor[
             0.28096145327109734`, 0.41263867974591306`, 0.9393117111673424]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.04749427504982855], {
             RGBColor[
             0.9734883859205871, 0.9797482621451334, 0.9297614266867937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.04749427504982855], {
             RGBColor[
             0.5640955015617808, 0.656997166237428, 0.9588268107143023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.04749427504982855], {
             RGBColor[
             0.21381427791123173`, 0.3420627410658821, 0.9354877788659421]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.04749427504982855], {
             RGBColor[
             0.2518443381406806, 0.38203474561211825`, 0.9376535345355769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.04749427504982855], {
             RGBColor[
             0.37383492502239923`, 0.4982187553899085, 0.9450414087465508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.04749427504982855], {
             RGBColor[
             0.8642907579141675, 0.4766578520345487, 0.20847322067670976`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.04749427504982855], {
             RGBColor[
             0.21893481250696653`, 0.34744474758664423`, 0.9357793857360172]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.04749427504982855], {
             RGBColor[
             0.34321032416564207`, 0.47169326536497985`, 0.9430900362602295]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.04749427504982855], {
             RGBColor[
             0.27505191676798696`, 0.40642738219488894`, 0.9389751718058661]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.04749427504982855], {
             RGBColor[
             0.6672310374616252, 0.7399652246995075, 0.9674670122517698]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.04749427504982855], {
             RGBColor[
             0.7812325868423204, 0.8290241015195725, 0.9788296212889877]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.04749427504982855], {
             RGBColor[
             0.3375430035907792, 0.46678451713084806`, 0.942728919604614]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.04749427504982855], {
             RGBColor[
             0.6050270257368769, 0.6902272215069217, 0.9620490902344793]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.04749427504982855], {
             RGBColor[
             0.4604958122832016, 0.5728902713682614, 0.9506710636761264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.04749427504982855], {
             RGBColor[
             0.30144929209616883`, 0.4341726973550716, 0.9404784632793888]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.04749427504982855], {
             RGBColor[
             0.9003020964297527, 0.6401769295720257, 0.2385219642527955]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.04749427504982855], {
             RGBColor[
             0.21718744139687057`, 0.3456081497602061, 0.935679875536301]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.04749427504982855], {
             RGBColor[
             0.2655539192117794, 0.3964443845554878, 0.9384342748960682]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.04749427504982855], {
             RGBColor[
             0.3895827819898638, 0.5118587575848209, 0.9460448482672345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.04749427504982855], {
             RGBColor[
             0.7789983515005383, 0.8272786998897548, 0.9786069335902352]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.04749427504982855], {
             RGBColor[
             0.9133075269424444, 0.9337106471842498, 0.9915932813106664]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.04749427504982855], {
             RGBColor[
             0.5648783713319804, 0.6576327351847573, 0.9588884410903589]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.04749427504982855], {
             RGBColor[
             0.9567688473548046, 0.8658333123497126, 0.2865555648019119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.04749427504982855], {
             RGBColor[
             0.5426755050288741, 0.6396074480921672, 0.9571405501231992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.04749427504982855], {
             RGBColor[
             0.9929383277496677, 0.9873041220381521, 0.47275873901987264`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.04749427504982855], {
             RGBColor[
             0.250431442054717, 0.3805497022429847, 0.9375730721936737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.04749427504982855], {
             RGBColor[
             0.2910544796798416, 0.42324709043633846`, 0.9398864940900259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.04749427504982855], {
             RGBColor[
             0.17895982839241617`, 0.30542850472186966`, 0.9335028695283829]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.04749427504982855], {
             RGBColor[
             0.30722498883092086`, 0.4402433208236197, 0.9408073806640553]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.04749427504982855], {
             RGBColor[
             0.32158764066209233`, 0.4529647837018777, 0.9417122579875715]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.04749427504982855], {
             RGBColor[
             0.8895815146715775, 0.5914972716636359, 0.22957644804826868`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.04749427504982855], {
             RGBColor[
             0.9902596908634175, 0.9788057915282733, 0.4166611676177604]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.04749427504982855], {
             RGBColor[
             0.23722409174651585`, 0.3666679396746901, 0.9368209331321454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.04749427504982855], {
             RGBColor[
             0.8992586624240541, 0.6354389394523516, 0.23765129734153262`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.04749427504982855], {
             RGBColor[
             0.2522143608002516, 0.3824236628881191, 0.93767460677864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.04749427504982855], {
             RGBColor[
             0.8234278438149039, 0.18108225047377968`, 0.1700678357361042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.04749427504982855], {
             RGBColor[
             0.23085213233970892`, 0.3599706063325754, 0.9364580594703971]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.04749427504982855], {
             RGBColor[
             0.23327898842098083`, 0.3625213859455549, 0.9365962653340136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.04749427504982855], {
             RGBColor[
             0.9080066729340168, 0.6729841436820356, 0.24483821356303642`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.04749427504982855], {
             RGBColor[
             0.2501870825879037, 0.38029286495007875`, 0.9375591562835361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.04749427504982855], {
             RGBColor[
             0.9127756759352338, 0.6918916514058181, 0.2486754653207034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.04749427504982855], {
             RGBColor[
             0.24915820796041388`, 0.3792114524821679, 0.9375005633955842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.04749427504982855], {
             RGBColor[
             0.30550365683416836`, 0.4384340917562807, 0.9407093533533227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.04749427504982855], {
             RGBColor[
             0.3593385897430587, 0.4856627583779401, 0.9441177150811572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.04749427504982855], {
             RGBColor[
             0.6408890467579492, 0.7193416257374643, 0.9648722798961695]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.04749427504982855], {
             RGBColor[
             0.8207984422031169, 0.16087151747445233`, 0.16754991778317269`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.04749427504982855], {
             RGBColor[
             0.8565158956399671, 0.43541151607797846`, 0.2017529915313943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.04749427504982855], {
             RGBColor[
             0.20775586072121455`, 0.33569496047333813`, 0.9351427609695957]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.04749427504982855], {
             RGBColor[
             0.79609453068194, 0.84063436500204, 0.9803109209581594]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.04749427504982855], {
             RGBColor[
             0.4806958664434177, 0.5892895853375945, 0.9522612859348552]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.04749427504982855], {
             RGBColor[
             0.20479309393410217`, 0.332580904729819, 0.9349740357840903]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.04749427504982855], {
             RGBColor[
             0.2335680080595618, 0.362825163910607, 0.9366127245748646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.04749427504982855], {
             RGBColor[
             0.2829267708206377, 0.41470435309880965`, 0.9394236330943619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.04749427504982855], {
             RGBColor[
             0.3518764439127397, 0.4791994227180725, 0.9436422337473658]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.04749427504982855], {
             RGBColor[
             0.281739557244844, 0.41345651635696223`, 0.9393560230375456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.04749427504982855], {
             RGBColor[
             0.585970074369736, 0.674755929881201, 0.960548857214945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.04749427504982855], {
             RGBColor[
             0.9865275394369064, 0.9886968055777866, 0.8729370673481489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.04749427504982855], {
             RGBColor[
             0.24962306644129345`, 0.3797000482193023, 0.9375270363983738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.04749427504982855], {
             RGBColor[
             0.9208437466954219, 0.9397198242500384, 0.9923120926783682]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.04749427504982855], {
             RGBColor[
             0.5576848060128018, 0.6517926747922235, 0.9583221372775351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.04749427504982855], {
             RGBColor[
             0.25326504777876796`, 0.3835280015199418, 0.9377344418477144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.04749427504982855], {
             RGBColor[
             0.8226444613445744, 0.17506082952644003`, 0.16931766779781277`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.04749427504982855], {
             RGBColor[
             0.36671177852496323`, 0.4920490439135823, 0.9445875281504853]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.04749427504982855], {
             RGBColor[
             0.30865896704414575`, 0.441750522845189, 0.9408890436019178]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.04749427504982855], {
             RGBColor[
             0.9829012627807141, 0.9867683702952449, 0.9138278814340688]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.04749427504982855], {
             RGBColor[
             0.23302215960706, 0.36225144257823677`, 0.936581639313005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.04749427504982855], {
             RGBColor[
             0.29472306200537346`, 0.42710300306202637`, 0.9400954144262837]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.04749427504982855], {
             RGBColor[
             0.21890292553398902`, 0.347411232356294, 0.9357775698200786]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.04749427504982855], {
             RGBColor[
             0.39092445521974123`, 0.5130208475020834, 0.9461303384990473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.04749427504982855], {
             RGBColor[
             0.9152757732218003, 0.9352800733407862, 0.9917810143978655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.04749427504982855], {
             RGBColor[
             0.9385923578753286, 0.9537228615659814, 0.988831299825661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.04749427504982855], {
             RGBColor[
             0.2725827939998642, 0.40383217761416634`, 0.9388345589169613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.04749427504982855], {
             RGBColor[
             0.1823653638581298, 0.3090079384197544, 0.933696809735117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.04749427504982855], {
             RGBColor[
             0.8744701613749067, 0.9027427860928997, 0.9878889387123091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.04749427504982855], {
             RGBColor[
             0.9939767127007667, 0.98952512245173, 0.5857805327779135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.04749427504982855], {
             RGBColor[
             0.9951414157005084, 0.9920163043986404, 0.7125512665860644]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.04749427504982855], {
             RGBColor[
             0.3814106085308894, 0.5047804316800383, 0.9455241246007979]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.04749427504982855], {
             RGBColor[
             0.320397896026041, 0.45193428669643415`, 0.9416364485114123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.04749427504982855], {
             RGBColor[
             0.29419693695473825`, 0.4265500122755539, 0.9400654523829823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.04749427504982855], {
             RGBColor[
             0.29360677442013106`, 0.4259297140332158, 0.9400318434997037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.04749427504982855], {
             RGBColor[
             0.9424318889382709, 0.9565863775460686, 0.9823319752461818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.04749427504982855], {
             RGBColor[
             0.807933735593484, 0.8498832418602281, 0.9814909422600818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.04749427504982855], {
             RGBColor[
             0.7240681721091139, 0.7843668262643483, 0.9731320066602097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.04749427504982855], {
             RGBColor[
             0.984329904565909, 0.9877880270819891, 0.9093575644573119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.04749427504982855], {
             RGBColor[
             0.2651236286264823, 0.39599212186834176`, 0.9384097704837935]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.04749427504982855], {
             RGBColor[
             0.859910479347665, 0.45676803010411193`, 0.20481820887036734`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.04749427504982855], {
             RGBColor[
             0.3711329893802169, 0.49587847453988415`, 0.9448692437966588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.04749427504982855], {
             RGBColor[
             0.7695733223497783, 0.8199157954843064, 0.9776675347663926]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.04749427504982855], {
             RGBColor[
             0.28203039141568953`, 0.41376220151047227`, 0.9393725856133247]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.04749427504982855], {
             RGBColor[
             0.28282713132653, 0.41459962567299363`, 0.939417958772576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.04749427504982855], {
             RGBColor[
             0.6646539951158695, 0.737952019632756, 0.9672101567545748]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.04749427504982855], {
             RGBColor[
             0.2313913752108486, 0.36053738478011593`, 0.9364887685541701]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.04749427504982855], {
             RGBColor[
             0.1797070620660458, 0.3062138946902057, 0.9335454233806629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.04749427504982855], {
             RGBColor[
             0.28023078255701894`, 0.41187069849821767`, 0.939270100551106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.04749427504982855], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.04749427504982855], {
             RGBColor[
             0.31668648779682773`, 0.44871965142909115`, 0.9413999608609163]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.04749427504982855], {
             RGBColor[
             0.348529185002255, 0.47630019528793527`, 0.9434289493694545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.04749427504982855], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.04749427504982855], {
             RGBColor[
             0.49517344266125934`, 0.6010431339186144, 0.9534010137678327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.04749427504982855], {
             RGBColor[
             0.8889169937097365, 0.9142622980478761, 0.9892668904772446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.04749427504982855], {
             RGBColor[
             0.6961608186542636, 0.7625653896416773, 0.9703504624768758]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.04749427504982855], {
             RGBColor[
             0.27228850741332744`, 0.40352286375286894`, 0.938817799731216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.04749427504982855], {
             RGBColor[
             0.23658832296539867`, 0.36599970637566703`, 0.9367847270405965]},
             StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{3.8349504055390835`*^9, 3.834957759852075*^9, 
  3.835018922383715*^9, 3.835019017360054*^9, 3.835020551743785*^9, 
  3.835044643191966*^9, 3.835045032973324*^9},
 CellLabel->
  "Out[271]=",ExpressionUUID->"c6fd1b61-a5a6-48d6-b092-8b7d490d6927"]
}, Open  ]],

Cell["Estimated with Max-Min Deviation v Calculated: (r = 3)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 3.8349503922098827`*^9}, {3.8349504781120467`*^9, 
  3.8349504928656063`*^9}},ExpressionUUID->"5c5e2603-db64-4465-8e0b-\
e308b6af8ad6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphinf2", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsif2", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}],
      "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"mMDi3f200", ",", "krif2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502554527807`*^9}, {3.8349577716948586`*^9, 
   3.8349577796673746`*^9}, {3.835018835203446*^9, 3.8350188366714215`*^9}, {
   3.8350443464072504`*^9, 3.835044352231003*^9}, {3.8350449386312246`*^9, 
   3.835044944694197*^9}},
 CellLabel->
  "In[272]:=",ExpressionUUID->"4be3761e-29f9-4781-9a4d-4cc74e0635be"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
          103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
          129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 
          142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 
          155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 
          168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 
          181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 
          194, 195, 196, 197, 198, 199, 200}, {Null, CompressedData["
1:eJwVxfk/GgwDAPA5ylXk6qBcTS9j5XjImZDN1UpNhz0LEUrEK0VRaK6QloU8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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[31, 80] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[36, 132] -> 
             RGBColor[
              0.8963133529411764, 0.5312481176470589, 0.26139676470588236`], 
             UndirectedEdge[16, 101] -> 
             RGBColor[
              0.9285733529411765, 0.7545241764705882, 0.26138664705882353`], 
             UndirectedEdge[86, 108] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[29, 136] -> 
             RGBColor[0.8020586764705881, 0.8427095294117647, 0.836211], 
             UndirectedEdge[55, 157] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058822, 0.6345793235294117], 
             UndirectedEdge[7, 188] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[19, 141] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 
             UndirectedEdge[62, 185] -> 
             RGBColor[
              0.8233546764705882, 0.7380637647058824, 0.6105275588235294], 
             UndirectedEdge[79, 144] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647059], 
             UndirectedEdge[47, 54] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[32, 101] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058822, 0.6345793235294117], 
             UndirectedEdge[104, 163] -> 
             RGBColor[
              0.9285733529411765, 0.7545241764705882, 0.26138664705882353`], 
             UndirectedEdge[119, 125] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[9, 140] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[3, 63] -> 
             RGBColor[
              0.9062187647058824, 0.5630471764705882, 0.4371391176470588], 
             UndirectedEdge[50, 104] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[47, 61] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[149, 195] -> 
             RGBColor[
              0.9527160588235295, 0.8370488235294118, 0.47837732352941176`], 
             UndirectedEdge[99, 178] -> 
             RGBColor[
              0.7111956176470589, 0.7060182941176469, 0.6139678529411765], 
             UndirectedEdge[160, 174] -> 
             RGBColor[
              0.9285733529411765, 0.7545241764705882, 0.26138664705882353`], 
             UndirectedEdge[6, 124] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[24, 197] -> 
             RGBColor[
              0.9610704117647059, 0.8776436470588235, 0.31732720588235297`], 
             UndirectedEdge[80, 120] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[83, 187] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[47, 167] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[132, 150] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.4275612941176472], 
             UndirectedEdge[17, 189] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001], 
             UndirectedEdge[69, 180] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705882], 
             UndirectedEdge[43, 95] -> 
             RGBColor[
              0.8622419705882354, 0.7083068823529411, 0.6022973823529412], 
             UndirectedEdge[82, 86] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.4275612941176472], 
             UndirectedEdge[7, 61] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[30, 65] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[62, 174] -> 
             RGBColor[
              0.8233546764705882, 0.7380637647058824, 0.6105275588235294], 
             UndirectedEdge[18, 47] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[56, 149] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[82, 163] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764707, 0.37162073529411777`], 
             UndirectedEdge[10, 48] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[58, 92] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[70, 72] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941177], 
             UndirectedEdge[35, 181] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[126, 174] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764707, 0.37162073529411777`], 
             UndirectedEdge[108, 154] -> 
             RGBColor[
              0.9610704117647059, 0.8776436470588235, 0.31732720588235297`], 
             UndirectedEdge[63, 77] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[32, 100] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[19, 50] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[80, 81] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.7185807941176472], 
             UndirectedEdge[34, 163] -> 
             RGBColor[
              0.9285733529411765, 0.7545241764705882, 0.26138664705882353`], 
             UndirectedEdge[146, 194] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[13, 83] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             UndirectedEdge[30, 41] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             UndirectedEdge[35, 111] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058822, 0.6345793235294117], 
             UndirectedEdge[29, 144] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647059], 
             UndirectedEdge[6, 12] -> 
             RGBColor[0.912053, 0.6812623529411763, 0.24769235294117647`], 
             UndirectedEdge[67, 143] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[135, 163] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764707, 0.37162073529411777`], 
             UndirectedEdge[50, 60] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             UndirectedEdge[25, 143] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[12, 13] -> 
             RGBColor[
              0.9352148823529411, 0.7616891176470588, 0.35792644117647066`], 
             UndirectedEdge[89, 144] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.744813411764706], 
             UndirectedEdge[22, 24] -> 
             RGBColor[0.912053, 0.6812623529411763, 0.24769235294117647`], 
             UndirectedEdge[107, 156] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941177], 
             UndirectedEdge[23, 154] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.608346705882353], 
             UndirectedEdge[101, 135] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[7, 42] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             UndirectedEdge[122, 192] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             UndirectedEdge[129, 133] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515699999999999], 
             UndirectedEdge[40, 80] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764707, 0.37162073529411777`], 
             UndirectedEdge[41, 172] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[94, 115] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941177], 
             UndirectedEdge[87, 103] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[142, 160] -> 
             RGBColor[
              0.5628800588235294, 0.5661560294117647, 0.6047899411764706], 
             UndirectedEdge[21, 150] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001], 
             UndirectedEdge[29, 142] -> 
             RGBColor[
              0.3939629117647059, 0.4994228529411765, 0.9479313823529412], 
             UndirectedEdge[67, 103] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[50, 163] -> 
             RGBColor[
              0.9527160588235295, 0.8370488235294118, 0.47837732352941176`], 
             UndirectedEdge[21, 46] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[43, 129] -> 
             RGBColor[
              0.9030825588235294, 0.7408720588235294, 0.606192794117647], 
             UndirectedEdge[11, 112] -> 
             RGBColor[
              0.7213174705882353, 0.7800425294117648, 0.9462356764705883], 
             UndirectedEdge[119, 195] -> 
             RGBColor[
              0.8787623235294117, 0.781568705882353, 0.6159916764705883], 
             UndirectedEdge[99, 109] -> 
             RGBColor[
              0.7213174705882353, 0.7800425294117648, 0.9462356764705883], 
             UndirectedEdge[45, 120] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529412], 
             UndirectedEdge[29, 153] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411764], 
             UndirectedEdge[27, 125] -> 
             RGBColor[0.7022251764705882, 0.765628, 0.972468294117647], 
             UndirectedEdge[35, 157] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[28, 112] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.7185807941176472], 
             UndirectedEdge[22, 89] -> 
             RGBColor[
              0.9030825588235294, 0.7408720588235294, 0.606192794117647], 
             UndirectedEdge[96, 116] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882353], 
             UndirectedEdge[23, 143] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[6, 14] -> 
             RGBColor[
              0.9674696176470587, 0.9081338235294116, 0.5614274117647058], 
             UndirectedEdge[9, 112] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[12, 25] -> 
             RGBColor[
              0.9221748529411764, 0.7552865882352942, 0.5799601764705883], 
             UndirectedEdge[176, 199] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.7185807941176472], 
             UndirectedEdge[48, 112] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941177], 
             UndirectedEdge[79, 149] -> 
             RGBColor[0.8020586764705881, 0.8427095294117647, 0.836211], 
             UndirectedEdge[58, 155] -> 
             RGBColor[
              0.672697294117647, 0.7437244705882353, 0.9683612352941176], 
             UndirectedEdge[118, 138] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764707, 0.37162073529411777`], 
             UndirectedEdge[172, 173] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.608346705882353], 
             UndirectedEdge[53, 104] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[179, 185] -> 
             RGBColor[
              0.6929358529411764, 0.633624411764706, 0.5992756176470588], 
             UndirectedEdge[82, 176] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             UndirectedEdge[142, 181] -> 
             RGBColor[
              0.5730019117647058, 0.6401802647058823, 0.9370577647058824], 
             UndirectedEdge[54, 160] -> 
             RGBColor[
              0.9674696176470587, 0.9081338235294116, 0.5614274117647059], 
             UndirectedEdge[121, 151] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[138, 144] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             UndirectedEdge[171, 196] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[120, 172] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[113, 159] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352941], 
             UndirectedEdge[103, 108] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[64, 176] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764707, 0.37162073529411777`], 
             UndirectedEdge[83, 101] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[15, 63] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[55, 72] -> 
             RGBColor[
              0.9674696176470587, 0.9081338235294116, 0.5614274117647058], 
             UndirectedEdge[105, 142] -> 
             RGBColor[
              0.5730019117647058, 0.6401802647058824, 0.9370577647058824], 
             UndirectedEdge[96, 105] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[64, 108] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058825, 0.3026349705882353], 
             UndirectedEdge[56, 119] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[68, 157] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515699999999999], 
             UndirectedEdge[137, 161] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[160, 188] -> 
             RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             UndirectedEdge[127, 187] -> 
             RGBColor[0.8020586764705881, 0.8427095294117647, 0.836211], 
             UndirectedEdge[41, 141] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[137, 175] -> 
             RGBColor[
              0.9610704117647059, 0.8776436470588235, 0.31732720588235297`], 
             UndirectedEdge[1, 122] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             UndirectedEdge[60, 177] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352941], 
             UndirectedEdge[72, 75] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 
             UndirectedEdge[13, 69] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001], 
             UndirectedEdge[48, 77] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 
             UndirectedEdge[22, 183] -> 
             RGBColor[0.912053, 0.6812623529411763, 0.24769235294117647`], 
             UndirectedEdge[16, 86] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058825, 0.3026349705882353], 
             UndirectedEdge[8, 62] -> 
             RGBColor[
              0.8416144411764706, 0.8104576470588234, 0.6252197941176469], 
             UndirectedEdge[26, 51] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.608346705882353], 
             UndirectedEdge[117, 121] -> 
             RGBColor[
              0.9610704117647059, 0.8776436470588235, 0.31732720588235297`], 
             UndirectedEdge[89, 136] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515699999999999], 
             UndirectedEdge[81, 168] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941177], 
             UndirectedEdge[172, 198] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.608346705882353], 
             UndirectedEdge[55, 68] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[156, 192] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.4275612941176472], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941177], 
             UndirectedEdge[25, 154] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.608346705882353], 
             UndirectedEdge[100, 135] -> 
             RGBColor[
              0.9201839705882353, 0.9343893529411764, 0.7409180000000001], 
             UndirectedEdge[37, 149] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             UndirectedEdge[125, 149] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515699999999999], 
             UndirectedEdge[2, 184] -> 
             RGBColor[
              0.9527160588235295, 0.8370488235294118, 0.47837732352941176`], 
             UndirectedEdge[6, 16] -> 
             RGBColor[
              0.9285733529411765, 0.7545241764705882, 0.26138664705882353`], 
             UndirectedEdge[55, 111] -> 
             RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             UndirectedEdge[34, 50] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[56, 125] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[98, 196] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[160, 167] -> 
             RGBColor[
              0.9610704117647059, 0.8776436470588235, 0.31732720588235297`], 
             UndirectedEdge[22, 149] -> 
             RGBColor[0.9361957058823529, 0.763787, 0.46468302941176476`], 
             UndirectedEdge[147, 194] -> 
             RGBColor[
              0.9674696176470587, 0.9081338235294116, 0.5614274117647059], 
             UndirectedEdge[83, 161] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[34, 177] -> 
             RGBColor[
              0.8970220882352942, 0.8539625882352939, 0.6306839117647058], 
             UndirectedEdge[70, 145] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[125, 170] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515699999999999], 
             UndirectedEdge[190, 192] -> 
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764707], 
             UndirectedEdge[122, 188] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[123, 130] -> 
             RGBColor[0.9326895, 0.7624781176470589, 0.5330408823529412], 
             UndirectedEdge[94, 116] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529412], 
             UndirectedEdge[23, 162] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.7185807941176472], 
             UndirectedEdge[116, 160] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[80, 117] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[147, 185] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705882], 
             UndirectedEdge[55, 107] -> 
             RGBColor[
              0.9674696176470587, 0.9081338235294116, 0.5614274117647058], 
             UndirectedEdge[111, 174] -> 
             RGBColor[
              0.9285733529411765, 0.7545241764705882, 0.26138664705882353`], 
             UndirectedEdge[126, 142] -> 
             RGBColor[
              0.5860419411764706, 0.6465827941176471, 0.7150240294117648], 
             UndirectedEdge[115, 160] -> 
             RGBColor[
              0.9674696176470587, 0.9081338235294116, 0.5614274117647059], 
             UndirectedEdge[74, 164] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515699999999999], 
             UndirectedEdge[42, 97] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[25, 108] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[67, 133] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515699999999999], 
             UndirectedEdge[38, 183] -> 
             RGBColor[
              0.8416144411764706, 0.8104576470588234, 0.625219794117647], 
             UndirectedEdge[33, 41] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[32, 123] -> 
             RGBColor[
              0.9030825588235294, 0.7408720588235294, 0.606192794117647], 
             UndirectedEdge[61, 116] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[93, 134] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[45, 128] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.4275612941176472], 
             UndirectedEdge[29, 35] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[3, 106] -> 
             RGBColor[
              0.8921979117647059, 0.5545467647058824, 0.5524162647058823], 
             UndirectedEdge[77, 140] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[79, 195] -> 
             RGBColor[0.7596562058823529, 0.687791, 0.6045280882352941], 
             UndirectedEdge[38, 46] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882353], 
             UndirectedEdge[14, 59] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 
             UndirectedEdge[126, 191] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.4275612941176472], 
             UndirectedEdge[13, 64] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764707, 0.37162073529411777`], 
             UndirectedEdge[3, 11] -> 
             RGBColor[
              0.6464385588235294, 0.35962276470588234`, 0.5580374117647059], 
             UndirectedEdge[31, 98] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[25, 162] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.7185807941176472], 
             UndirectedEdge[126, 157] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.744813411764706], 
             UndirectedEdge[128, 183] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[22, 192] -> 
             RGBColor[
              0.9352148823529411, 0.7616891176470588, 0.35792644117647066`], 
             UndirectedEdge[99, 194] -> 
             RGBColor[
              0.7111956176470589, 0.7060182941176469, 0.6139678529411765], 
             UndirectedEdge[21, 151] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941177], 
             UndirectedEdge[48, 59] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 
             UndirectedEdge[18, 115] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941177], 
             UndirectedEdge[29, 89] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[15, 140] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[113, 136] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             UndirectedEdge[111, 160] -> 
             RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             UndirectedEdge[116, 188] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[82, 127] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647059], 
             UndirectedEdge[25, 95] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[62, 111] -> 
             RGBColor[
              0.8416144411764706, 0.8104576470588234, 0.625219794117647], 
             UndirectedEdge[162, 180] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764707, 0.37162073529411777`], 
             UndirectedEdge[89, 159] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[7, 153] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[146, 183] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[144, 197] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.4275612941176472], 
             UndirectedEdge[120, 128] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[74, 166] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882353], 
             UndirectedEdge[147, 152] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001], 
             UndirectedEdge[22, 190] -> 
             RGBColor[
              0.6764155000000001, 0.5603625882352941, 0.5855813235294118], 
             UndirectedEdge[27, 128] -> 
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764707], 
             UndirectedEdge[47, 88] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058822, 0.6345793235294117], 
             UndirectedEdge[69, 177] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[122, 167] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.4275612941176472], 
             UndirectedEdge[1, 78] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.7185807941176472], 
             UndirectedEdge[138, 159] -> 
             RGBColor[
              0.9201839705882353, 0.9343893529411764, 0.7409180000000001], 
             UndirectedEdge[101, 127] -> 
             RGBColor[
              0.7779159705882353, 0.7601848823529411, 0.6192203235294118], 
             UndirectedEdge[65, 90] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001], 
             UndirectedEdge[64, 127] -> 
             RGBColor[0.7596562058823529, 0.687791, 0.6045280882352941], 
             UndirectedEdge[117, 146] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[49, 103] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058822, 0.6345793235294117], 
             UndirectedEdge[88, 113] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[13, 176] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             UndirectedEdge[17, 112] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.7185807941176472], 
             UndirectedEdge[129, 170] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515699999999999], 
             UndirectedEdge[35, 116] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515699999999999], 
             UndirectedEdge[69, 110] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001], 
             UndirectedEdge[47, 126] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.744813411764706], 
             UndirectedEdge[83, 137] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[72, 84] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 
             UndirectedEdge[22, 37] -> 
             RGBColor[0.9361957058823529, 0.763787, 0.46468302941176476`], 
             UndirectedEdge[90, 141] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001], 
             UndirectedEdge[24, 79] -> 
             RGBColor[
              0.7779159705882353, 0.7601848823529411, 0.6192203235294118], 
             UndirectedEdge[34, 130] -> 
             RGBColor[
              0.9674696176470587, 0.9081338235294116, 0.5614274117647058], 
             UndirectedEdge[157, 174] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529413, 0.6198870882352941], 
             UndirectedEdge[131, 180] -> 
             RGBColor[
              0.9527160588235295, 0.8370488235294118, 0.47837732352941176`], 
             UndirectedEdge[3, 48] -> 
             RGBColor[
              0.9027125588235294, 0.5617382941176471, 0.5054969705882353], 
             UndirectedEdge[49, 67] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058822, 0.6345793235294117], 
             UndirectedEdge[79, 190] -> 
             RGBColor[
              0.5422784705882353, 0.6392851176470589, 0.9571092941176471], 
             UndirectedEdge[13, 82] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             UndirectedEdge[68, 138] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[153, 160] -> 
             RGBColor[
              0.9674696176470587, 0.9081338235294116, 0.5614274117647059], 
             UndirectedEdge[178, 183] -> 
             RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             UndirectedEdge[2, 166] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882353], 
             UndirectedEdge[32, 53] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515699999999999], 
             UndirectedEdge[26, 184] -> 
             RGBColor[
              0.938695205882353, 0.828548411764706, 0.5936544705882353], 
             UndirectedEdge[61, 115] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941177], 
             UndirectedEdge[146, 178] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[88, 102] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[118, 159] -> 
             RGBColor[
              0.8787623235294117, 0.781568705882353, 0.6159916764705882], 
             UndirectedEdge[62, 75] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294117], 
             UndirectedEdge[89, 197] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[85, 146] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.744813411764706], 
             UndirectedEdge[170, 190] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.8309585294117647], 
             UndirectedEdge[82, 101] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[7, 73] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             UndirectedEdge[19, 34] -> 
             RGBColor[
              0.9674696176470587, 0.9081338235294116, 0.5614274117647059], 
             UndirectedEdge[56, 170] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[32, 187] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515699999999999], 
             UndirectedEdge[74, 169] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[55, 147] -> 
             RGBColor[
              0.9674696176470587, 0.9081338235294116, 0.5614274117647058], 
             UndirectedEdge[49, 143] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.6083467058823528], 
             UndirectedEdge[28, 77] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001], 
             UndirectedEdge[122, 153] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.8937932352941177, 0.6088684705882355, 0.23300011764705886`], 
             UndirectedEdge[16, 199] -> 
             RGBColor[
              0.938695205882353, 0.828548411764706, 0.5936544705882354], 
             UndirectedEdge[64, 180] -> 
             RGBColor[
              0.9103135882352942, 0.6821302941176473, 0.2466944117647059], 
             UndirectedEdge[38, 128] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529413], 
             UndirectedEdge[46, 98] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             UndirectedEdge[68, 142] -> 
             RGBColor[
              0.5870227647058823, 0.6486806764705882, 0.8217806176470588], 
             UndirectedEdge[5, 20] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058822, 0.6345793235294117], 
             UndirectedEdge[169, 200] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[27, 133] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.8309585294117647], 
             UndirectedEdge[32, 135] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.744813411764706], 
             UndirectedEdge[144, 190] -> 
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764707], 
             UndirectedEdge[62, 126] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529413], 
             UndirectedEdge[55, 62] -> 
             RGBColor[
              0.8416144411764706, 0.8104576470588234, 0.6252197941176469], 
             UndirectedEdge[62, 76] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[157, 181] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[64, 82] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764707, 0.37162073529411777`], 
             UndirectedEdge[142, 153] -> 
             RGBColor[
              0.5835165588235294, 0.6473717941176471, 0.8901384705882354], 
             UndirectedEdge[21, 109] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941177], 
             UndirectedEdge[66, 198] -> 
             RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             UndirectedEdge[141, 198] -> 
             RGBColor[
              0.9674696176470587, 0.9081338235294116, 0.5614274117647059], 
             UndirectedEdge[10, 28] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.744813411764706], 
             UndirectedEdge[31, 151] -> 
             RGBColor[
              0.9610704117647059, 0.8776436470588235, 0.31732720588235297`], 
             UndirectedEdge[111, 142] -> 
             RGBColor[
              0.5628800588235294, 0.5661560294117646, 0.6047899411764706], 
             UndirectedEdge[111, 181] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.6083467058823528], 
             UndirectedEdge[86, 101] -> 
             RGBColor[
              0.9610704117647059, 0.8776436470588235, 0.31732720588235297`], 
             UndirectedEdge[119, 144] -> 
             RGBColor[
              0.9201839705882353, 0.9343893529411764, 0.7409180000000001], 
             UndirectedEdge[5, 102] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515699999999999], 
             UndirectedEdge[157, 185] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529413, 0.6198870882352941], 
             UndirectedEdge[13, 110] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             UndirectedEdge[32, 82] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.744813411764706], 
             UndirectedEdge[12, 23] -> 
             RGBColor[
              0.9221748529411764, 0.7552865882352942, 0.5799601764705883], 
             UndirectedEdge[53, 130] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[74, 80] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[35, 185] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529413, 0.6198870882352941], 
             UndirectedEdge[117, 196] -> 
             RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             UndirectedEdge[22, 181] -> 
             RGBColor[
              0.9221748529411764, 0.7552865882352942, 0.5799601764705883], 
             UndirectedEdge[143, 197] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[16, 124] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764707, 0.37162073529411777`], 
             UndirectedEdge[182, 191] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[98, 146] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[156, 183] -> 
             RGBColor[
              0.9610704117647059, 0.8776436470588235, 0.31732720588235297`], 
             UndirectedEdge[6, 13] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[50, 100] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352941], 
             UndirectedEdge[13, 175] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.4275612941176472], 
             UndirectedEdge[62, 116] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882353], 
             UndirectedEdge[120, 171] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             UndirectedEdge[72, 139] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[6, 83] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[118, 190] -> 
             RGBColor[
              0.6929358529411764, 0.633624411764706, 0.5992756176470588], 
             UndirectedEdge[36, 200] -> 
             RGBColor[
              0.8921979117647059, 0.5545467647058824, 0.5524162647058823], 
             UndirectedEdge[16, 161] -> 
             RGBColor[
              0.9527160588235295, 0.8370488235294118, 0.47837732352941176`], 
             UndirectedEdge[2, 169] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[107, 111] -> 
             RGBColor[
              0.9674696176470587, 0.9081338235294116, 0.5614274117647059], 
             UndirectedEdge[127, 180] -> 
             RGBColor[0.7596562058823529, 0.687791, 0.6045280882352941], 
             UndirectedEdge[138, 156] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.4275612941176472], 
             UndirectedEdge[72, 93] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294117], 
             UndirectedEdge[137, 187] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[40, 121] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058825, 0.3026349705882353], 
             UndirectedEdge[98, 178] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[10, 186] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[63, 91] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             UndirectedEdge[125, 195] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529413, 0.6198870882352941], 
             UndirectedEdge[86, 180] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058825, 0.3026349705882353], 
             UndirectedEdge[137, 186] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.6083467058823528], 
             UndirectedEdge[33, 44] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[14, 193] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[11, 28] -> 
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764707], 
             UndirectedEdge[85, 151] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[175, 199] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[146, 196] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[20, 77] -> 
             RGBColor[
              0.9674696176470587, 0.9081338235294116, 0.5614274117647058], 
             UndirectedEdge[27, 56] -> 
             RGBColor[
              0.7213174705882353, 0.7800425294117648, 0.9462356764705883], 
             UndirectedEdge[101, 175] -> 
             RGBColor[
              0.9610704117647059, 0.8776436470588235, 0.31732720588235297`], 
             UndirectedEdge[21, 85] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[150, 194] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[61, 160] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.608346705882353], 
             UndirectedEdge[24, 149] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[14, 186] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941177], 
             UndirectedEdge[111, 126] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[35, 88] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058822, 0.6345793235294117], 
             UndirectedEdge[94, 111] -> 
             RGBColor[
              0.9610704117647059, 0.8776436470588235, 0.31732720588235297`], 
             UndirectedEdge[133, 162] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[124, 199] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.7185807941176472], 
             UndirectedEdge[54, 105] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941177], 
             UndirectedEdge[64, 162] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764707, 0.37162073529411777`], 
             UndirectedEdge[57, 66] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.608346705882353], 
             UndirectedEdge[16, 137] -> 
             RGBColor[
              0.9285733529411765, 0.7545241764705882, 0.26138664705882353`], 
             UndirectedEdge[44, 50] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             UndirectedEdge[153, 167] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941177], 
             UndirectedEdge[165, 187] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.8309585294117647], 
             UndirectedEdge[32, 83] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.744813411764706], 
             UndirectedEdge[6, 187] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[66, 141] -> 
             RGBColor[
              0.9674696176470587, 0.9081338235294116, 0.5614274117647058], 
             UndirectedEdge[23, 87] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[85, 152] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.744813411764706], 
             UndirectedEdge[26, 74] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[81, 172] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[54, 73] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[135, 165] -> 
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764707], 
             UndirectedEdge[46, 109] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[40, 171] -> 
             RGBColor[
              0.9527160588235295, 0.8370488235294118, 0.47837732352941176`], 
             UndirectedEdge[113, 167] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529412], 
             UndirectedEdge[103, 162] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.744813411764706], 
             UndirectedEdge[37, 119] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352941], 
             UndirectedEdge[71, 184] -> 
             RGBColor[
              0.6929358529411764, 0.633624411764706, 0.5992756176470588], 
             UndirectedEdge[107, 142] -> 
             RGBColor[
              0.5835165588235294, 0.6473717941176471, 0.8901384705882354], 
             UndirectedEdge[136, 143] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[3, 5] -> 
             RGBColor[
              0.8731056176470589, 0.5401322352941176, 0.5786488823529412], 
             UndirectedEdge[24, 118] -> 
             RGBColor[
              0.9285733529411765, 0.7545241764705882, 0.26138664705882353`], 
             UndirectedEdge[142, 185] -> 
             RGBColor[
              0.544620294117647, 0.4937621470588236, 0.590097705882353], 
             UndirectedEdge[3, 28] -> 
             RGBColor[
              0.9052379411764706, 0.560949294117647, 0.3303825294117648], 
             UndirectedEdge[43, 49] -> 
             RGBColor[0.912053, 0.6812623529411763, 0.24769235294117647`], 
             UndirectedEdge[19, 60] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[87, 110] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.4275612941176472], 
             UndirectedEdge[107, 185] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705882], 
             UndirectedEdge[66, 81] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.6083467058823528], 
             UndirectedEdge[63, 112] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[59, 193] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[110, 180] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764707, 0.37162073529411777`], 
             UndirectedEdge[21, 196] -> 
             RGBColor[
              0.9674696176470587, 0.9081338235294116, 0.5614274117647059], 
             UndirectedEdge[24, 190] -> 
             RGBColor[
              0.7111956176470589, 0.7060182941176469, 0.6139678529411765], 
             UndirectedEdge[44, 60] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             UndirectedEdge[20, 106] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.6083467058823528], 
             UndirectedEdge[75, 139] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[4, 81] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.6083467058823528], 
             UndirectedEdge[79, 197] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[66, 90] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[14, 15] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 
             UndirectedEdge[14, 48] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 
             UndirectedEdge[122, 144] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             UndirectedEdge[80, 121] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.4275612941176472], 
             UndirectedEdge[79, 170] -> 
             RGBColor[0.8020586764705881, 0.8427095294117647, 0.836211], 
             UndirectedEdge[91, 95] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352941], 
             UndirectedEdge[48, 193] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[67, 162] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.744813411764706], 
             UndirectedEdge[65, 87] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941177], 
             UndirectedEdge[98, 121] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529412], 
             UndirectedEdge[161, 187] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             UndirectedEdge[68, 122] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[19, 90] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001], 
             UndirectedEdge[80, 168] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001], 
             UndirectedEdge[109, 194] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.608346705882353], 
             UndirectedEdge[44, 57] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[109, 151] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[122, 138] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             UndirectedEdge[138, 192] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             UndirectedEdge[31, 46] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[101, 165] -> 
             RGBColor[
              0.7111956176470589, 0.7060182941176469, 0.6139678529411765], 
             UndirectedEdge[76, 105] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[6, 199] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.6083467058823528], 
             UndirectedEdge[83, 175] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.4275612941176472], 
             UndirectedEdge[139, 182] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529412], 
             UndirectedEdge[89, 149] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515699999999999], 
             UndirectedEdge[53, 163] -> 
             RGBColor[
              0.9527160588235295, 0.8370488235294118, 0.47837732352941176`], 
             UndirectedEdge[8, 96] -> 
             RGBColor[
              0.8416144411764706, 0.8104576470588234, 0.6252197941176469], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.9527160588235295, 0.8370488235294118, 0.47837732352941176`], 
             UndirectedEdge[55, 191] -> 
             RGBColor[
              0.9610704117647059, 0.8776436470588235, 0.31732720588235297`], 
             UndirectedEdge[122, 181] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.7185807941176472], 
             UndirectedEdge[130, 177] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[25, 131] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[19, 33] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941177], 
             UndirectedEdge[1, 89] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.744813411764706], 
             UndirectedEdge[123, 127] -> 
             RGBColor[
              0.7431358529411765, 0.6145291764705882, 0.590833794117647], 
             UndirectedEdge[40, 173] -> 
             RGBColor[
              0.9285733529411765, 0.7545241764705882, 0.26138664705882353`], 
             UndirectedEdge[17, 106] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.7185807941176472], 
             UndirectedEdge[51, 158] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[20, 189] -> 
             RGBColor[
              0.9674696176470587, 0.9081338235294116, 0.5614274117647058], 
             UndirectedEdge[48, 140] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[11, 189] -> 
             RGBColor[
              0.7318321176470588, 0.7872340588235294, 0.8993163823529412], 
             UndirectedEdge[40, 169] -> 
             RGBColor[
              0.938695205882353, 0.828548411764706, 0.5936544705882354], 
             UndirectedEdge[94, 167] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[81, 198] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.608346705882353], 
             UndirectedEdge[34, 60] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[13, 101] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[31, 117] -> 
             RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             UndirectedEdge[94, 105] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[125, 190] -> 
             RGBColor[0.7022251764705882, 0.765628, 0.972468294117647], 
             UndirectedEdge[79, 119] -> 
             RGBColor[
              0.7281049411764706, 0.7872294117647058, 0.9738253529411764], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[156, 178] -> 
             RGBColor[
              0.9610704117647059, 0.8776436470588235, 0.31732720588235297`], 
             UndirectedEdge[95, 131] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352941], 
             UndirectedEdge[49, 133] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[34, 44] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[24, 125] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058822, 0.6345793235294117], 
             UndirectedEdge[95, 129] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[13, 16] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764707, 0.37162073529411777`], 
             UndirectedEdge[13, 199] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.7185807941176472], 
             UndirectedEdge[121, 196] -> 
             RGBColor[
              0.9610704117647059, 0.8776436470588235, 0.31732720588235297`], 
             UndirectedEdge[26, 40] -> 
             RGBColor[
              0.938695205882353, 0.828548411764706, 0.5936544705882353], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[54, 126] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001], 
             UndirectedEdge[16, 193] -> 
             RGBColor[
              0.9527160588235295, 0.8370488235294118, 0.47837732352941176`], 
             UndirectedEdge[85, 150] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.744813411764706], 
             UndirectedEdge[26, 169] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[22, 79] -> 
             RGBColor[
              0.7431358529411765, 0.6145291764705882, 0.590833794117647], 
             UndirectedEdge[27, 67] -> 
             RGBColor[0.7022251764705882, 0.765628, 0.972468294117647], 
             UndirectedEdge[49, 95] -> 
             RGBColor[
              0.8970220882352942, 0.8539625882352939, 0.6306839117647058], 
             UndirectedEdge[147, 178] -> 
             RGBColor[
              0.9674696176470587, 0.9081338235294116, 0.5614274117647059], 
             UndirectedEdge[1, 136] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[65, 110] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001], 
             UndirectedEdge[77, 106] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941177], 
             UndirectedEdge[25, 64] -> 
             RGBColor[
              0.938695205882353, 0.828548411764706, 0.5936544705882353], 
             UndirectedEdge[82, 187] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[167, 188] -> 
             RGBColor[
              0.9610704117647059, 0.8776436470588235, 0.31732720588235297`], 
             UndirectedEdge[13, 137] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[37, 125] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515699999999999], 
             UndirectedEdge[105, 182] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[111, 116] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[146, 179] -> 
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764707], 
             UndirectedEdge[9, 63] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529412], 
             UndirectedEdge[38, 120] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882353], 
             UndirectedEdge[71, 81] -> 
             RGBColor[
              0.7213174705882353, 0.7800425294117648, 0.9462356764705883], 
             UndirectedEdge[68, 181] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[114, 158] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[118, 149] -> 
             RGBColor[
              0.9527160588235295, 0.8370488235294118, 0.47837732352941176`], 
             UndirectedEdge[87, 162] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.4275612941176472], 
             UndirectedEdge[88, 122] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[49, 162] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[47, 116] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515699999999999], 
             UndirectedEdge[23, 95] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[54, 115] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 
             UndirectedEdge[62, 105] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[13, 108] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.4275612941176472], 
             UndirectedEdge[76, 182] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[117, 171] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[40, 46] -> 
             RGBColor[
              0.9527160588235295, 0.8370488235294118, 0.47837732352941176`], 
             UndirectedEdge[19, 177] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[64, 87] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058825, 0.3026349705882353], 
             UndirectedEdge[62, 107] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294117], 
             UndirectedEdge[53, 148] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             UndirectedEdge[76, 111] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.608346705882353], 
             UndirectedEdge[11, 48] -> 
             RGBColor[
              0.7318321176470588, 0.7872340588235294, 0.8993163823529412], 
             UndirectedEdge[96, 111] -> 
             RGBColor[
              0.8416144411764706, 0.8104576470588234, 0.625219794117647], 
             UndirectedEdge[168, 198] -> 
             RGBColor[
              0.9674696176470587, 0.9081338235294116, 0.5614274117647059], 
             UndirectedEdge[118, 128] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764707, 0.37162073529411777`], 
             UndirectedEdge[56, 129] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[53, 100] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352941], 
             UndirectedEdge[129, 143] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[18, 160] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.608346705882353], 
             UndirectedEdge[68, 111] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[51, 166] -> 
             RGBColor[
              0.8416144411764706, 0.8104576470588234, 0.6252197941176469], 
             UndirectedEdge[107, 181] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941177], 
             UndirectedEdge[31, 173] -> 
             RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             UndirectedEdge[135, 148] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[44, 177] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352941], 
             UndirectedEdge[80, 184] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764707, 0.37162073529411777`], 
             UndirectedEdge[65, 162] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001], 
             UndirectedEdge[5, 17] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.744813411764706], 
             UndirectedEdge[44, 141] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[94, 174] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058825, 0.3026349705882353], 
             UndirectedEdge[161, 193] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             UndirectedEdge[101, 124] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[106, 189] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941177], 
             UndirectedEdge[2, 80] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[97, 102] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[91, 136] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             UndirectedEdge[59, 154] -> 
             RGBColor[
              0.9674696176470587, 0.9081338235294116, 0.5614274117647059], 
             UndirectedEdge[108, 162] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.4275612941176472], 
             UndirectedEdge[146, 147] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001], 
             UndirectedEdge[99, 156] -> 
             RGBColor[
              0.7254329117647058, 0.7567438823529412, 0.6552161764705883], 
             UndirectedEdge[143, 154] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.608346705882353], 
             UndirectedEdge[139, 145] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529412], 
             UndirectedEdge[104, 123] -> 
             RGBColor[0.912053, 0.6812623529411763, 0.24769235294117647`], 
             UndirectedEdge[116, 126] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[17, 28] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             UndirectedEdge[89, 118] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529413, 0.6198870882352941], 
             UndirectedEdge[123, 163] -> 
             RGBColor[
              0.8937932352941177, 0.6088684705882355, 0.23300011764705886`], 
             UndirectedEdge[47, 157] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[117, 151] -> 
             RGBColor[
              0.9610704117647059, 0.8776436470588235, 0.31732720588235297`], 
             UndirectedEdge[69, 86] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941177], 
             UndirectedEdge[73, 94] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529412], 
             UndirectedEdge[61, 174] -> 
             RGBColor[
              0.938695205882353, 0.828548411764706, 0.5936544705882353], 
             UndirectedEdge[175, 187] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529412], 
             UndirectedEdge[75, 134] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941177], 
             UndirectedEdge[38, 178] -> 
             RGBColor[
              0.8416144411764706, 0.8104576470588234, 0.625219794117647], 
             UndirectedEdge[8, 179] -> 
             RGBColor[
              0.7111956176470589, 0.7060182941176469, 0.6139678529411765], 
             UndirectedEdge[29, 167] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[68, 185] -> 
             RGBColor[
              0.9527160588235295, 0.8370488235294118, 0.47837732352941176`], 
             UndirectedEdge[79, 118] -> 
             RGBColor[0.7596562058823529, 0.687791, 0.6045280882352941], 
             UndirectedEdge[171, 173] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[80, 166] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529413], 
             UndirectedEdge[109, 132] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[118, 197] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058825, 0.3026349705882353], 
             UndirectedEdge[111, 167] -> 
             RGBColor[
              0.9610704117647059, 0.8776436470588235, 0.31732720588235297`], 
             UndirectedEdge[113, 122] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[119, 190] -> 
             RGBColor[
              0.6613845882352941, 0.7330628235294117, 0.9685728823529411], 
             UndirectedEdge[19, 130] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 
             UndirectedEdge[35, 167] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[102, 112] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[134, 145] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[109, 150] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.7185807941176472], 
             UndirectedEdge[147, 179] -> 
             RGBColor[
              0.7318321176470588, 0.7872340588235294, 0.8993163823529412], 
             UndirectedEdge[63, 102] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             UndirectedEdge[62, 182] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[8, 99] -> 
             RGBColor[
              0.7111956176470589, 0.7060182941176469, 0.6139678529411765], 
             UndirectedEdge[60, 123] -> 
             RGBColor[0.9361957058823529, 0.763787, 0.4646830294117647], 
             UndirectedEdge[7, 97] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[130, 163] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705882], 
             UndirectedEdge[127, 135] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647059], 
             UndirectedEdge[37, 56] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[100, 148] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352941], 
             UndirectedEdge[53, 135] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[103, 154] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058822, 0.6345793235294117], 
             UndirectedEdge[63, 140] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352941], 
             UndirectedEdge[8, 75] -> 
             RGBColor[
              0.9674696176470587, 0.9081338235294116, 0.5614274117647058], 
             UndirectedEdge[50, 53] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             UndirectedEdge[1, 167] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.4275612941176472], 
             UndirectedEdge[27, 119] -> 
             RGBColor[
              0.6613845882352941, 0.7330628235294117, 0.9685728823529411], 
             UndirectedEdge[96, 126] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529413], 
             UndirectedEdge[102, 106] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[16, 176] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764707, 0.37162073529411777`], 
             UndirectedEdge[40, 166] -> 
             RGBColor[
              0.8233546764705882, 0.7380637647058824, 0.6105275588235295], 
             UndirectedEdge[33, 90] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.7185807941176472], 
             UndirectedEdge[13, 161] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[11, 106] -> 
             RGBColor[
              0.7213174705882353, 0.7800425294117648, 0.9462356764705883], 
             UndirectedEdge[88, 167] -> 
             RGBColor[
              0.9610704117647059, 0.8776436470588235, 0.31732720588235297`], 
             UndirectedEdge[29, 159] -> 
             RGBColor[
              0.7281049411764706, 0.7872294117647058, 0.9738253529411764], 
             UndirectedEdge[156, 157] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[171, 183] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[100, 104] -> 
             RGBColor[
              0.8970220882352942, 0.8539625882352939, 0.6306839117647058], 
             UndirectedEdge[108, 180] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058825, 0.3026349705882353], 
             UndirectedEdge[178, 179] -> 
             RGBColor[
              0.7111956176470589, 0.7060182941176469, 0.6139678529411765], 
             UndirectedEdge[150, 151] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.4275612941176472], 
             UndirectedEdge[2, 121] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529412], 
             UndirectedEdge[12, 14] -> 
             RGBColor[0.9326895, 0.7624781176470589, 0.5330408823529412], 
             UndirectedEdge[43, 131] -> 
             RGBColor[0.9361957058823529, 0.763787, 0.46468302941176476`], 
             UndirectedEdge[75, 76] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941177], 
             UndirectedEdge[113, 138] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[17, 20] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[86, 187] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529412], 
             UndirectedEdge[8, 185] -> 
             RGBColor[
              0.9285733529411765, 0.7545241764705882, 0.26138664705882353`], 
             UndirectedEdge[4, 41] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[8, 107] -> 
             RGBColor[
              0.9674696176470587, 0.9081338235294116, 0.5614274117647058], 
             UndirectedEdge[149, 192] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[11, 140] -> 
             RGBColor[
              0.6613845882352941, 0.7330628235294117, 0.9685728823529411], 
             UndirectedEdge[94, 153] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941177], 
             UndirectedEdge[56, 79] -> 
             RGBColor[
              0.7880378235294117, 0.8342091176470589, 0.9514881470588235], 
             UndirectedEdge[5, 15] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[79, 128] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647059], 
             UndirectedEdge[109, 152] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.7185807941176472], 
             UndirectedEdge[118, 192] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764707, 0.37162073529411777`], 
             UndirectedEdge[99, 107] -> 
             RGBColor[
              0.7318321176470588, 0.7872340588235294, 0.8993163823529412], 
             UndirectedEdge[3, 189] -> 
             RGBColor[
              0.9027125588235294, 0.5617382941176471, 0.5054969705882353], 
             UndirectedEdge[35, 138] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.744813411764706], 
             UndirectedEdge[12, 86] -> 
             RGBColor[
              0.9262902941176471, 0.7319879411764707, 0.28894067647058824`], 
             UndirectedEdge[16, 127] -> 
             RGBColor[0.7596562058823529, 0.687791, 0.6045280882352941], 
             UndirectedEdge[37, 195] -> 
             RGBColor[
              0.9527160588235295, 0.8370488235294118, 0.47837732352941176`], 
             UndirectedEdge[57, 71] -> 
             RGBColor[
              0.7213174705882353, 0.7800425294117648, 0.9462356764705883], 
             UndirectedEdge[58, 73] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882353], 
             UndirectedEdge[35, 153] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[35, 122] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.744813411764706], 
             UndirectedEdge[19, 44] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[181, 192] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.7185807941176472], 
             UndirectedEdge[119, 128] -> 
             RGBColor[
              0.9201839705882353, 0.9343893529411764, 0.7409180000000001], 
             UndirectedEdge[116, 153] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[186, 193] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[22, 119] -> 
             RGBColor[
              0.8622419705882354, 0.7083068823529411, 0.6022973823529412], 
             UndirectedEdge[85, 109] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[98, 99] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.8309585294117647], 
             UndirectedEdge[161, 175] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529412], 
             UndirectedEdge[54, 61] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941177], 
             UndirectedEdge[43, 154] -> 
             RGBColor[0.912053, 0.6812623529411763, 0.24769235294117647`], 
             UndirectedEdge[87, 95] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[12, 108] -> 
             RGBColor[
              0.9262902941176471, 0.7319879411764707, 0.28894067647058824`], 
             UndirectedEdge[15, 48] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 
             UndirectedEdge[13, 187] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[15, 28] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001], 
             UndirectedEdge[52, 134] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[66, 172] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.6083467058823528], 
             UndirectedEdge[101, 176] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[119, 192] -> 
             RGBColor[
              0.9201839705882353, 0.9343893529411764, 0.7409180000000001], 
             UndirectedEdge[168, 184] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705882], 
             UndirectedEdge[16, 175] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058825, 0.3026349705882353], 
             UndirectedEdge[60, 104] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[122, 136] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[107, 157] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[86, 110] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.4275612941176472], 
             UndirectedEdge[5, 9] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[3, 77] -> 
             RGBColor[
              0.9027125588235294, 0.5617382941176471, 0.5054969705882353], 
             UndirectedEdge[84, 139] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[96, 191] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[46, 151] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529412], 
             UndirectedEdge[72, 191] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941177], 
             UndirectedEdge[111, 185] -> 
             RGBColor[
              0.9285733529411765, 0.7545241764705882, 0.26138664705882353`], 
             UndirectedEdge[23, 129] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[101, 123] -> 
             RGBColor[0.912053, 0.6812623529411763, 0.24769235294117647`], 
             UndirectedEdge[122, 142] -> 
             RGBColor[
              0.5860419411764706, 0.6465827941176471, 0.7150240294117648], 
             UndirectedEdge[18, 174] -> 
             RGBColor[
              0.938695205882353, 0.828548411764706, 0.5936544705882353], 
             UndirectedEdge[123, 135] -> 
             RGBColor[
              0.9352148823529411, 0.7616891176470588, 0.35792644117647066`], 
             UndirectedEdge[171, 178] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[81, 173] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.608346705882353], 
             UndirectedEdge[77, 102] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[31, 171] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[109, 196] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.608346705882353], 
             UndirectedEdge[18, 153] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941177], 
             UndirectedEdge[97, 140] -> 
             RGBColor[
              0.8970220882352942, 0.8539625882352939, 0.6306839117647058], 
             UndirectedEdge[116, 167] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529412], 
             UndirectedEdge[128, 190] -> 
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764707], 
             UndirectedEdge[94, 126] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.4275612941176472], 
             UndirectedEdge[41, 198] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[11, 77] -> 
             RGBColor[
              0.7318321176470588, 0.7872340588235294, 0.8993163823529412], 
             UndirectedEdge[29, 122] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647059], 
             UndirectedEdge[84, 152] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001], 
             UndirectedEdge[16, 64] -> 
             RGBColor[
              0.9103135882352942, 0.6821302941176473, 0.2466944117647059], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[26, 121] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[40, 74] -> 
             RGBColor[
              0.9527160588235295, 0.8370488235294118, 0.47837732352941176`], 
             UndirectedEdge[78, 91] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[139, 152] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[40, 196] -> 
             RGBColor[
              0.9285733529411765, 0.7545241764705882, 0.26138664705882353`], 
             UndirectedEdge[6, 86] -> 
             RGBColor[
              0.9610704117647059, 0.8776436470588235, 0.31732720588235297`], 
             UndirectedEdge[82, 180] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764707, 0.37162073529411777`], 
             UndirectedEdge[44, 90] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[4, 66] -> 
             RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             UndirectedEdge[131, 143] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[22, 144] -> 
             RGBColor[
              0.9352148823529411, 0.7616891176470588, 0.35792644117647066`], 
             UndirectedEdge[35, 160] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058822, 0.6345793235294117], 
             UndirectedEdge[76, 174] -> 
             RGBColor[
              0.938695205882353, 0.828548411764706, 0.5936544705882353], 
             UndirectedEdge[85, 196] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058822, 0.6345793235294117], 
             UndirectedEdge[6, 137] -> 
             RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             UndirectedEdge[123, 177] -> 
             RGBColor[
              0.8622419705882354, 0.7083068823529411, 0.6022973823529412], 
             UndirectedEdge[29, 113] -> 
             RGBColor[0.8020586764705881, 0.8427095294117647, 0.836211], 
             UndirectedEdge[96, 174] -> 
             RGBColor[
              0.8233546764705882, 0.7380637647058824, 0.6105275588235294], 
             UndirectedEdge[74, 158] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             UndirectedEdge[46, 121] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529412], 
             UndirectedEdge[32, 165] -> 
             RGBColor[0.7022251764705882, 0.765628, 0.972468294117647], 
             UndirectedEdge[32, 148] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515699999999999], 
             UndirectedEdge[27, 190] -> 
             RGBColor[
              0.4755581176470588, 0.5851185294117647, 0.9518568235294118], 
             UndirectedEdge[100, 123] -> 
             RGBColor[
              0.8622419705882354, 0.7083068823529411, 0.6022973823529412], 
             UndirectedEdge[45, 172] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[85, 99] -> 
             RGBColor[0.7022251764705882, 0.765628, 0.972468294117647], 
             UndirectedEdge[106, 112] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.9610704117647059, 0.8776436470588235, 0.31732720588235297`], 
             UndirectedEdge[43, 197] -> 
             RGBColor[
              0.9262902941176471, 0.7319879411764707, 0.28894067647058824`], 
             UndirectedEdge[26, 164] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[100, 130] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[46, 196] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[156, 181] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[62, 96] -> 
             RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 
             UndirectedEdge[54, 58] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294117], 
             UndirectedEdge[179, 183] -> 
             RGBColor[
              0.7111956176470589, 0.7060182941176469, 0.6139678529411765], 
             UndirectedEdge[65, 198] -> 
             RGBColor[
              0.9674696176470587, 0.9081338235294116, 0.5614274117647059], 
             UndirectedEdge[4, 80] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[159, 197] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[78, 136] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[153, 188] -> 
             RGBColor[
              0.9674696176470587, 0.9081338235294116, 0.5614274117647059], 
             UndirectedEdge[35, 174] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529413, 0.6198870882352941], 
             UndirectedEdge[82, 130] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001], 
             UndirectedEdge[124, 176] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             UndirectedEdge[6, 186] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.6083467058823528], 
             UndirectedEdge[1, 144] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             UndirectedEdge[43, 67] -> 
             RGBColor[
              0.9030825588235294, 0.7408720588235294, 0.606192794117647], 
             UndirectedEdge[24, 119] -> 
             RGBColor[
              0.8970220882352942, 0.8539625882352939, 0.6306839117647058], 
             UndirectedEdge[93, 139] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882353], 
             UndirectedEdge[38, 146] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529413], 
             UndirectedEdge[110, 127] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647059], 
             UndirectedEdge[41, 81] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[85, 194] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058822, 0.6345793235294117], 
             UndirectedEdge[52, 70] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[149, 170] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[92, 155] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[57, 141] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941177], 
             UndirectedEdge[149, 159] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352941], 
             UndirectedEdge[142, 167] -> 
             RGBColor[
              0.5771173529411764, 0.6168816176470588, 0.6460382647058824], 
             UndirectedEdge[117, 173] -> 
             RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             UndirectedEdge[99, 179] -> 
             RGBColor[
              0.4755581176470588, 0.5851185294117647, 0.9518568235294118], 
             UndirectedEdge[5, 11] -> 
             RGBColor[0.7022251764705882, 0.765628, 0.972468294117647], 
             UndirectedEdge[29, 188] -> 
             RGBColor[
              0.7779159705882353, 0.7601848823529411, 0.6192203235294117], 
             UndirectedEdge[46, 178] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[101, 137] -> 
             RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             UndirectedEdge[3, 20] -> 
             RGBColor[
              0.8820760588235295, 0.4805225294117646, 0.2201484411764706], 
             UndirectedEdge[186, 199] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[156, 179] -> 
             RGBColor[
              0.7254329117647058, 0.7567438823529412, 0.6552161764705883], 
             UndirectedEdge[67, 87] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[3, 10] -> 
             RGBColor[
              0.8731056176470589, 0.5401322352941176, 0.5786488823529412], 
             UndirectedEdge[55, 185] -> 
             RGBColor[
              0.9285733529411765, 0.7545241764705882, 0.26138664705882353`], 
             UndirectedEdge[5, 28] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.744813411764706], 
             UndirectedEdge[37, 170] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             UndirectedEdge[49, 154] -> 
             RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             UndirectedEdge[24, 89] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058822, 0.6345793235294117], 
             UndirectedEdge[73, 115] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[153, 174] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705882], 
             UndirectedEdge[119, 183] -> 
             RGBColor[
              0.8970220882352942, 0.8539625882352939, 0.6306839117647058], 
             UndirectedEdge[4, 168] -> 
             RGBColor[
              0.9674696176470587, 0.9081338235294116, 0.5614274117647058], 
             UndirectedEdge[144, 181] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.7185807941176472], 
             UndirectedEdge[53, 123] -> 
             RGBColor[0.9361957058823529, 0.763787, 0.4646830294117647], 
             UndirectedEdge[110, 162] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             UndirectedEdge[127, 176] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647059], 
             UndirectedEdge[9, 102] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529412], 
             UndirectedEdge[27, 195] -> 
             RGBColor[
              0.6929358529411764, 0.633624411764706, 0.5992756176470588], 
             UndirectedEdge[60, 130] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[89, 122] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.744813411764706], 
             UndirectedEdge[5, 106] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[83, 199] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.7185807941176472], 
             UndirectedEdge[118, 125] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529413, 0.619887088235294], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[5, 112] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[109, 146] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.7185807941176472], 
             UndirectedEdge[164, 184] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529413, 0.6198870882352941], 
             UndirectedEdge[51, 164] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058822, 0.6345793235294117], 
             UndirectedEdge[45, 168] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941177], 
             UndirectedEdge[148, 165] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.8309585294117647], 
             UndirectedEdge[166, 184] -> 
             RGBColor[
              0.8233546764705882, 0.7380637647058824, 0.6105275588235294], 
             UndirectedEdge[21, 132] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941177], 
             UndirectedEdge[96, 157] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[42, 102] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             UndirectedEdge[117, 120] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[25, 129] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[57, 90] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.7185807941176472], 
             UndirectedEdge[51, 184] -> 
             RGBColor[
              0.9285733529411765, 0.7545241764705882, 0.26138664705882353`], 
             UndirectedEdge[95, 103] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[47, 105] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[127, 177] -> 
             RGBColor[
              0.7281049411764706, 0.7872294117647058, 0.9738253529411764], 
             UndirectedEdge[73, 153] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[137, 199] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.6083467058823528], 
             UndirectedEdge[138, 185] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764707, 0.37162073529411777`], 
             UndirectedEdge[88, 136] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[55, 76] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.6083467058823528], 
             UndirectedEdge[135, 176] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             UndirectedEdge[69, 123] -> 
             RGBColor[0.9326895, 0.7624781176470589, 0.5330408823529411], 
             UndirectedEdge[2, 40] -> 
             RGBColor[
              0.9527160588235295, 0.8370488235294118, 0.47837732352941176`], 
             UndirectedEdge[105, 174] -> 
             RGBColor[
              0.938695205882353, 0.828548411764706, 0.5936544705882353], 
             UndirectedEdge[89, 138] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.744813411764706], 
             UndirectedEdge[37, 128] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[88, 153] -> 
             RGBColor[
              0.9674696176470587, 0.9081338235294116, 0.5614274117647058], 
             UndirectedEdge[113, 197] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529412], 
             UndirectedEdge[31, 178] -> 
             RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             UndirectedEdge[82, 177] -> 
             RGBColor[
              0.9201839705882353, 0.9343893529411764, 0.7409180000000001], 
             UndirectedEdge[87, 108] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[64, 86] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058825, 0.3026349705882353], 
             UndirectedEdge[116, 157] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515699999999999], 
             UndirectedEdge[120, 168] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[18, 54] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941177], 
             UndirectedEdge[161, 176] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[168, 172] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941177], 
             UndirectedEdge[142, 157] -> 
             RGBColor[
              0.5539096176470588, 0.6257657352941177, 0.9632903823529412], 
             UndirectedEdge[121, 171] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529412], 
             UndirectedEdge[47, 94] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[70, 93] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[32, 163] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529413, 0.6198870882352941], 
             UndirectedEdge[35, 142] -> 
             RGBColor[
              0.5539096176470588, 0.6257657352941176, 0.9632903823529412], 
             UndirectedEdge[12, 193] -> 
             RGBColor[0.9361957058823529, 0.763787, 0.46468302941176476`], 
             UndirectedEdge[35, 94] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[116, 174] -> 
             RGBColor[
              0.9527160588235295, 0.8370488235294118, 0.47837732352941176`], 
             UndirectedEdge[112, 140] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[86, 176] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.4275612941176472], 
             UndirectedEdge[61, 73] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[33, 66] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.608346705882353], 
             UndirectedEdge[48, 106] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941177], 
             UndirectedEdge[86, 199] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[10, 59] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[1, 113] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[125, 128] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.744813411764706], 
             UndirectedEdge[53, 165] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.8309585294117647], 
             UndirectedEdge[87, 143] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[61, 105] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[29, 47] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[24, 27] -> 
             RGBColor[
              0.7111956176470589, 0.7060182941176469, 0.6139678529411765], 
             UndirectedEdge[98, 117] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[1, 88] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[190, 195] -> 
             RGBColor[
              0.6929358529411764, 0.633624411764706, 0.5992756176470588], 
             UndirectedEdge[4, 173] -> 
             RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             UndirectedEdge[81, 164] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[82, 123] -> 
             RGBColor[
              0.9352148823529411, 0.7616891176470588, 0.3579264411764707], 
             UndirectedEdge[43, 87] -> 
             RGBColor[
              0.9262902941176471, 0.7319879411764707, 0.28894067647058824`], 
             UndirectedEdge[38, 171] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882353], 
             UndirectedEdge[46, 85] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515699999999999], 
             UndirectedEdge[64, 69] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705883], 
             UndirectedEdge[60, 82] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[77, 189] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 
             UndirectedEdge[101, 187] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[64, 161] -> 
             RGBColor[
              0.9527160588235295, 0.8370488235294118, 0.47837732352941176`], 
             UndirectedEdge[7, 160] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[16, 83] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764707, 0.37162073529411777`], 
             UndirectedEdge[13, 124] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             UndirectedEdge[46, 171] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             UndirectedEdge[1, 197] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.4275612941176472], 
             UndirectedEdge[26, 80] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.7185807941176472], 
             UndirectedEdge[23, 43] -> 
             RGBColor[
              0.9221748529411764, 0.7552865882352942, 0.5799601764705882], 
             UndirectedEdge[13, 86] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.4275612941176472], 
             UndirectedEdge[31, 146] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.5628800588235294, 0.5661560294117647, 0.6047899411764706], 
             UndirectedEdge[124, 127] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647059], 
             UndirectedEdge[60, 163] -> 
             RGBColor[
              0.9527160588235295, 0.8370488235294118, 0.47837732352941176`], 
             UndirectedEdge[4, 184] -> 
             RGBColor[
              0.9285733529411765, 0.7545241764705882, 0.26138664705882353`], 
             UndirectedEdge[144, 192] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             UndirectedEdge[38, 192] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529413], 
             UndirectedEdge[49, 108] -> 
             RGBColor[
              0.9610704117647059, 0.8776436470588235, 0.31732720588235297`], 
             UndirectedEdge[83, 165] -> 
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764707], 
             UndirectedEdge[183, 192] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[79, 159] -> 
             RGBColor[
              0.7281049411764706, 0.7872294117647058, 0.9738253529411764], 
             UndirectedEdge[81, 166] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[118, 119] -> 
             RGBColor[
              0.8787623235294117, 0.781568705882353, 0.6159916764705882], 
             UndirectedEdge[47, 153] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[74, 184] -> 
             RGBColor[
              0.9527160588235295, 0.8370488235294118, 0.47837732352941176`], 
             UndirectedEdge[149, 190] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.8309585294117647], 
             UndirectedEdge[55, 139] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[22, 138] -> 
             RGBColor[
              0.9352148823529411, 0.7616891176470588, 0.35792644117647066`], 
             UndirectedEdge[113, 144] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[80, 172] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.7185807941176472], 
             UndirectedEdge[8, 156] -> 
             RGBColor[
              0.9610704117647059, 0.8776436470588235, 0.31732720588235297`], 
             UndirectedEdge[22, 118] -> 
             RGBColor[
              0.8937932352941177, 0.6088684705882355, 0.23300011764705886`], 
             UndirectedEdge[100, 163] -> 
             RGBColor[
              0.8787623235294117, 0.781568705882353, 0.6159916764705883], 
             UndirectedEdge[12, 154] -> 
             RGBColor[0.912053, 0.6812623529411763, 0.24769235294117647`], 
             UndirectedEdge[67, 129] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[49, 129] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058822, 0.6345793235294117], 
             UndirectedEdge[127, 175] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[30, 198] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[5, 140] -> 
             RGBColor[
              0.8880516470588236, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[147, 156] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941177], 
             UndirectedEdge[122, 159] -> 
             RGBColor[
              0.9201839705882353, 0.9343893529411764, 0.7409180000000001], 
             UndirectedEdge[82, 110] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             UndirectedEdge[83, 176] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             UndirectedEdge[10, 77] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[104, 130] -> 
             RGBColor[
              0.9674696176470587, 0.9081338235294116, 0.5614274117647058], 
             UndirectedEdge[30, 66] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[85, 132] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[24, 195] -> 
             RGBColor[
              0.9285733529411765, 0.7545241764705882, 0.26138664705882353`], 
             UndirectedEdge[50, 123] -> 
             RGBColor[0.9361957058823529, 0.763787, 0.4646830294117647], 
             UndirectedEdge[42, 153] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[127, 161] -> 
             RGBColor[0.8020586764705881, 0.8427095294117647, 0.836211], 
             UndirectedEdge[7, 18] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[65, 66] -> 
             RGBColor[
              0.9674696176470587, 0.9081338235294116, 0.5614274117647059], 
             UndirectedEdge[150, 152] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             UndirectedEdge[25, 87] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[69, 82] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001], 
             UndirectedEdge[1, 159] -> 
             RGBColor[
              0.9201839705882353, 0.9343893529411764, 0.7409180000000001], 
             UndirectedEdge[23, 131] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[126, 160] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[67, 131] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515699999999999], 
             UndirectedEdge[142, 174] -> 
             RGBColor[
              0.544620294117647, 0.4937621470588236, 0.590097705882353], 
             UndirectedEdge[22, 122] -> 
             RGBColor[
              0.9352148823529411, 0.7616891176470588, 0.35792644117647066`], 
             UndirectedEdge[32, 176] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.744813411764706], 
             UndirectedEdge[47, 160] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058822, 0.6345793235294117], 
             UndirectedEdge[79, 125] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[47, 111] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058822, 0.6345793235294117], 
             UndirectedEdge[3, 186] -> 
             RGBColor[
              0.8921979117647059, 0.5545467647058824, 0.5524162647058823], 
             UndirectedEdge[105, 160] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.608346705882353], 
             UndirectedEdge[9, 189] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941177], 
             UndirectedEdge[64, 175] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058825, 0.3026349705882353], 
             UndirectedEdge[100, 165] -> 
             RGBColor[
              0.6613845882352941, 0.7330628235294117, 0.9685728823529411], 
             UndirectedEdge[101, 161] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[123, 187] -> 
             RGBColor[0.9361957058823529, 0.763787, 0.46468302941176476`], 
             UndirectedEdge[90, 198] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[146, 171] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[62, 157] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[2, 164] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515699999999999], 
             UndirectedEdge[94, 142] -> 
             RGBColor[
              0.5771173529411765, 0.6168816176470588, 0.6460382647058824], 
             UndirectedEdge[12, 175] -> 
             RGBColor[
              0.9262902941176471, 0.7319879411764707, 0.28894067647058824`], 
             UndirectedEdge[23, 64] -> 
             RGBColor[
              0.938695205882353, 0.828548411764706, 0.5936544705882353], 
             UndirectedEdge[73, 160] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[47, 142] -> 
             RGBColor[
              0.5539096176470588, 0.6257657352941176, 0.9632903823529412], 
             UndirectedEdge[31, 120] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[9, 20] -> 
             RGBColor[
              0.9610704117647059, 0.8776436470588235, 0.31732720588235297`], 
             UndirectedEdge[174, 188] -> 
             RGBColor[
              0.9285733529411765, 0.7545241764705882, 0.26138664705882353`], 
             UndirectedEdge[45, 173] -> 
             RGBColor[
              0.9610704117647059, 0.8776436470588235, 0.31732720588235297`], 
             UndirectedEdge[139, 191] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529412], 
             UndirectedEdge[24, 170] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[118, 195] -> 
             RGBColor[
              0.9103135882352942, 0.6821302941176473, 0.2466944117647059], 
             UndirectedEdge[124, 137] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[28, 63] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[7, 94] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529412], 
             UndirectedEdge[37, 190] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.8309585294117647], 
             UndirectedEdge[31, 40] -> 
             RGBColor[
              0.9285733529411765, 0.7545241764705882, 0.26138664705882353`], 
             UndirectedEdge[18, 73] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[170, 195] -> 
             RGBColor[
              0.9527160588235295, 0.8370488235294118, 0.47837732352941176`], 
             UndirectedEdge[62, 191] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[152, 194] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[24, 37] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[90, 177] -> 
             RGBColor[
              0.9201839705882353, 0.9343893529411764, 0.7409180000000001], 
             UndirectedEdge[94, 188] -> 
             RGBColor[
              0.9610704117647059, 0.8776436470588235, 0.31732720588235297`], 
             UndirectedEdge[103, 133] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515699999999999], 
             UndirectedEdge[38, 179] -> 
             RGBColor[
              0.6059769411764706, 0.6895578823529411, 0.9631087647058824], 
             UndirectedEdge[54, 116] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[4, 198] -> 
             RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             UndirectedEdge[31, 38] -> 
             RGBColor[
              0.8416144411764706, 0.8104576470588234, 0.6252197941176469], 
             UndirectedEdge[35, 47] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[132, 151] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[124, 135] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             UndirectedEdge[32, 127] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[187, 199] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[2, 51] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[40, 117] -> 
             RGBColor[
              0.9285733529411765, 0.7545241764705882, 0.26138664705882353`], 
             UndirectedEdge[9, 17] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.4275612941176472], 
             UndirectedEdge[33, 57] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[124, 175] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.4275612941176472], 
             UndirectedEdge[8, 147] -> 
             RGBColor[
              0.9674696176470587, 0.9081338235294116, 0.5614274117647058], 
             UndirectedEdge[108, 110] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.4275612941176472], 
             UndirectedEdge[68, 107] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[1, 138] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             UndirectedEdge[94, 160] -> 
             RGBColor[
              0.9610704117647059, 0.8776436470588235, 0.31732720588235297`], 
             UndirectedEdge[138, 142] -> 
             RGBColor[
              0.5860419411764706, 0.6465827941176471, 0.7150240294117648], 
             UndirectedEdge[6, 175] -> 
             RGBColor[
              0.9610704117647059, 0.8776436470588235, 0.31732720588235297`], 
             UndirectedEdge[34, 104] -> 
             RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             UndirectedEdge[15, 106] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941177], 
             UndirectedEdge[61, 94] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[144, 159] -> 
             RGBColor[
              0.9201839705882353, 0.9343893529411764, 0.7409180000000001], 
             UndirectedEdge[83, 86] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.4275612941176472], 
             UndirectedEdge[137, 176] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[143, 159] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[24, 144] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[76, 96] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[98, 120] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             UndirectedEdge[98, 183] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[55, 75] -> 
             RGBColor[
              0.9674696176470587, 0.9081338235294116, 0.5614274117647058], 
             UndirectedEdge[35, 68] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515699999999999], 
             UndirectedEdge[25, 43] -> 
             RGBColor[
              0.9221748529411764, 0.7552865882352942, 0.5799601764705882], 
             UndirectedEdge[47, 174] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529413, 0.6198870882352941], 
             UndirectedEdge[29, 88] -> 
             RGBColor[
              0.7779159705882353, 0.7601848823529411, 0.6192203235294117], 
             UndirectedEdge[17, 140] -> 
             RGBColor[
              0.9201839705882353, 0.9343893529411764, 0.7409180000000001], 
             UndirectedEdge[41, 90] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[151, 196] -> 
             RGBColor[
              0.9610704117647059, 0.8776436470588235, 0.31732720588235297`], 
             UndirectedEdge[88, 94] -> 
             RGBColor[
              0.9610704117647059, 0.8776436470588235, 0.31732720588235297`], 
             UndirectedEdge[57, 198] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.608346705882353], 
             UndirectedEdge[71, 164] -> 
             RGBColor[0.7022251764705882, 0.765628, 0.972468294117647], 
             UndirectedEdge[95, 154] -> 
             RGBColor[
              0.8970220882352942, 0.8539625882352939, 0.6306839117647058], 
             UndirectedEdge[69, 90] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001], 
             UndirectedEdge[175, 176] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.4275612941176472], 
             UndirectedEdge[58, 115] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294117], 
             UndirectedEdge[42, 88] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[72, 134] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941177], 
             UndirectedEdge[25, 49] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.608346705882353], 
             UndirectedEdge[23, 103] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[79, 192] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647059], 
             UndirectedEdge[89, 170] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515699999999999], 
             UndirectedEdge[41, 57] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[10, 14] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[6, 59] -> 
             RGBColor[
              0.9674696176470587, 0.9081338235294116, 0.5614274117647058], 
             UndirectedEdge[120, 183] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[8, 194] -> 
             RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             UndirectedEdge[63, 106] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[129, 131] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515699999999999], 
             UndirectedEdge[22, 38] -> 
             RGBColor[
              0.8068343235294118, 0.6648019411764705, 0.5968332647058824], 
             UndirectedEdge[38, 117] -> 
             RGBColor[
              0.8416144411764706, 0.8104576470588234, 0.625219794117647], 
             UndirectedEdge[136, 159] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352941], 
             UndirectedEdge[158, 166] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882353], 
             UndirectedEdge[75, 96] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294117], 
             UndirectedEdge[118, 170] -> 
             RGBColor[
              0.9527160588235295, 0.8370488235294118, 0.47837732352941176`], 
             UndirectedEdge[7, 58] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882353], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.7318321176470588, 0.7872340588235294, 0.8993163823529412], 
             UndirectedEdge[65, 180] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705882], 
             UndirectedEdge[151, 171] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529412], 
             UndirectedEdge[37, 118] -> 
             RGBColor[
              0.9527160588235295, 0.8370488235294118, 0.47837732352941176`], 
             UndirectedEdge[7, 47] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515699999999999], 
             UndirectedEdge[46, 99] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.8309585294117647], 
             UndirectedEdge[195, 197] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058825, 0.3026349705882353], 
             UndirectedEdge[5, 63] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515699999999999], 
             UndirectedEdge[11, 63] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.8309585294117647], 
             UndirectedEdge[10, 193] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515699999999999], 
             UndirectedEdge[99, 147] -> 
             RGBColor[
              0.7318321176470588, 0.7872340588235294, 0.8993163823529412], 
             UndirectedEdge[9, 77] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941177], 
             UndirectedEdge[43, 103] -> 
             RGBColor[
              0.9030825588235294, 0.7408720588235294, 0.606192794117647], 
             UndirectedEdge[54, 174] -> 
             RGBColor[
              0.9492098529411765, 0.8357399411764708, 0.5467351764705882], 
             UndirectedEdge[149, 197] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529412], 
             UndirectedEdge[87, 180] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058825, 0.3026349705882353], 
             UndirectedEdge[134, 191] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[65, 131] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[107, 147] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 
             UndirectedEdge[50, 82] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[30, 162] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[51, 74] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[12, 161] -> 
             RGBColor[0.9361957058823529, 0.763787, 0.46468302941176476`], 
             UndirectedEdge[78, 113] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[131, 133] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             UndirectedEdge[35, 188] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058822, 0.6345793235294117], 
             UndirectedEdge[181, 185] -> 
             RGBColor[
              0.938695205882353, 0.828548411764706, 0.5936544705882353], 
             UndirectedEdge[111, 188] -> 
             RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             UndirectedEdge[41, 184] -> 
             RGBColor[
              0.9527160588235295, 0.8370488235294118, 0.47837732352941176`], 
             UndirectedEdge[135, 187] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[51, 71] -> 
             RGBColor[
              0.7111956176470589, 0.7060182941176469, 0.6139678529411765], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.7254329117647058, 0.7567438823529412, 0.6552161764705883], 
             UndirectedEdge[26, 158] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[101, 199] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.6083467058823528], 
             UndirectedEdge[84, 194] -> 
             RGBColor[
              0.9674696176470587, 0.9081338235294116, 0.5614274117647059], 
             UndirectedEdge[6, 176] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[18, 116] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[98, 179] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.8309585294117647], 
             UndirectedEdge[116, 142] -> 
             RGBColor[
              0.5870227647058823, 0.6486806764705882, 0.8217806176470588], 
             UndirectedEdge[77, 112] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941177], 
             UndirectedEdge[56, 190] -> 
             RGBColor[
              0.7213174705882353, 0.7800425294117648, 0.9462356764705883], 
             UndirectedEdge[76, 126] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.7185807941176472], 
             UndirectedEdge[168, 173] -> 
             RGBColor[
              0.9674696176470587, 0.9081338235294116, 0.5614274117647059], 
             UndirectedEdge[158, 164] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515699999999999], 
             UndirectedEdge[46, 146] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[23, 25] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[9, 28] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.4275612941176472], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             UndirectedEdge[103, 129] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[5, 48] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[36, 169] -> 
             RGBColor[
              0.8921979117647059, 0.5545467647058824, 0.5524162647058823], 
             UndirectedEdge[159, 170] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352941], 
             UndirectedEdge[86, 175] -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             UndirectedEdge[9, 97] -> 
             RGBColor[
              0.9610704117647059, 0.8776436470588235, 0.31732720588235297`], 
             UndirectedEdge[7, 88] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[5, 77] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[103, 131] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515699999999999], 
             UndirectedEdge[15, 193] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[167, 181] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[99, 146] -> 
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764707], 
             UndirectedEdge[163, 177] -> 
             RGBColor[
              0.8787623235294117, 0.781568705882353, 0.6159916764705882], 
             UndirectedEdge[76, 116] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[15, 59] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 
             UndirectedEdge[36, 151] -> 
             RGBColor[
              0.8963133529411764, 0.5312481176470589, 0.26139676470588236`], 
             UndirectedEdge[38, 98] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882353], 
             UndirectedEdge[70, 139] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[56, 195] -> 
             RGBColor[
              0.938695205882353, 0.828548411764706, 0.5936544705882353], 
             UndirectedEdge[66, 168] -> 
             RGBColor[
              0.9674696176470587, 0.9081338235294116, 0.5614274117647058], 
             UndirectedEdge[6, 161] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[56, 118] -> 
             RGBColor[
              0.938695205882353, 0.828548411764706, 0.5936544705882353], 
             UndirectedEdge[46, 117] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[79, 89] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[102, 140] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352941], 
             UndirectedEdge[32, 130] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[105, 126] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.7185807941176472], 
             UndirectedEdge[86, 124] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.4275612941176472], 
             UndirectedEdge[41, 168] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[43, 143] -> 
             RGBColor[
              0.9221748529411764, 0.7552865882352942, 0.5799601764705883], 
             UndirectedEdge[56, 197] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[47, 73] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515699999999999], 
             UndirectedEdge[23, 108] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[97, 155] -> 
             RGBColor[
              0.7779159705882353, 0.7601848823529411, 0.6192203235294118], 
             UndirectedEdge[86, 161] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529412], 
             UndirectedEdge[88, 188] -> 
             RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             UndirectedEdge[136, 197] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529412], 
             UndirectedEdge[65, 69] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 
             UndirectedEdge[23, 67] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[31, 121] -> 
             RGBColor[
              0.9610704117647059, 0.8776436470588235, 0.31732720588235297`], 
             UndirectedEdge[52, 145] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[12, 87] -> 
             RGBColor[
              0.9262902941176471, 0.7319879411764707, 0.28894067647058824`], 
             UndirectedEdge[128, 192] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             UndirectedEdge[78, 95] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[123, 165] -> 
             RGBColor[
              0.6764155000000001, 0.5603625882352941, 0.5855813235294118], 
             UndirectedEdge[24, 56] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.6083467058823528], 
             UndirectedEdge[50, 177] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352941], 
             UndirectedEdge[18, 58] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[96, 182] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[49, 131] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[28, 106] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.7185807941176472], 
             UndirectedEdge[57, 81] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[7, 115] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[54, 94] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941177], 
             UndirectedEdge[138, 181] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235295, 0.7185807941176472], 
             UndirectedEdge[55, 182] -> 
             RGBColor[
              0.9610704117647059, 0.8776436470588235, 0.31732720588235297`], 
             UndirectedEdge[17, 77] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001], 
             UndirectedEdge[144, 149] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[68, 179] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.8309585294117647], 
             UndirectedEdge[103, 143] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[80, 173] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[161, 199] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[43, 133] -> 
             RGBColor[0.9361957058823529, 0.763787, 0.46468302941176476`], 
             UndirectedEdge[6, 193] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[181, 188] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.608346705882353], 
             UndirectedEdge[120, 173] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[2, 158] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             UndirectedEdge[95, 143] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[4, 172] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.6083467058823528], 
             UndirectedEdge[89, 113] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515699999999999], 
             UndirectedEdge[34, 90] -> 
             RGBColor[
              0.9699949999999999, 0.9073448235294117, 0.3863129705882354], 
             UndirectedEdge[28, 48] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001], 
             UndirectedEdge[5, 189] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[8, 55] -> 
             RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             UndirectedEdge[29, 138] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647059], 
             UndirectedEdge[8, 68] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[176, 187] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[65, 133] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[68, 147] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352941], 
             UndirectedEdge[89, 192] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.744813411764706], 
             UndirectedEdge[2, 74] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             UndirectedEdge[156, 185] -> 
             RGBColor[
              0.9428106470588236, 0.8052497647058825, 0.3026349705882353], 
             UndirectedEdge[126, 182] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.4275612941176472], 
             UndirectedEdge[18, 188] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.608346705882353], 
             UndirectedEdge[68, 156] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529412], 
             UndirectedEdge[29, 181] -> 
             RGBColor[
              0.7880378235294117, 0.8342091176470589, 0.9514881470588235], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647059], 
             UndirectedEdge[30, 180] -> 
             RGBColor[
              0.9527160588235295, 0.8370488235294118, 0.47837732352941176`], 
             UndirectedEdge[31, 196] -> 
             RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             UndirectedEdge[193, 199] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[30, 110] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[12, 59] -> 
             RGBColor[0.9326895, 0.7624781176470589, 0.5330408823529412], 
             UndirectedEdge[38, 156] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[72, 152] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001], 
             UndirectedEdge[37, 79] -> 
             RGBColor[0.8020586764705881, 0.8427095294117647, 0.836211], 
             UndirectedEdge[170, 197] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529412], 
             UndirectedEdge[86, 127] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[69, 127] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411764], 
             UndirectedEdge[58, 61] -> 
             RGBColor[
              0.851736294117647, 0.8844818823529412, 0.9574876176470588], 
             UndirectedEdge[11, 17] -> 
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764707], 
             UndirectedEdge[11, 15] -> 
             RGBColor[
              0.7318321176470588, 0.7872340588235294, 0.8993163823529412], 
             UndirectedEdge[111, 157] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058822, 0.6345793235294117], 
             UndirectedEdge[75, 191] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941177], 
             UndirectedEdge[98, 156] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529412], 
             UndirectedEdge[28, 140] -> 
             RGBColor[
              0.9201839705882353, 0.9343893529411764, 0.7409180000000001], 
             UndirectedEdge[105, 157] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[3, 15] -> 
             RGBColor[
              0.9027125588235294, 0.5617382941176471, 0.5054969705882353], 
             UndirectedEdge[55, 96] -> 
             RGBColor[
              0.8416144411764706, 0.8104576470588234, 0.6252197941176469], 
             UndirectedEdge[6, 64] -> 
             RGBColor[
              0.9285733529411765, 0.7545241764705882, 0.26138664705882353`], 
             UndirectedEdge[70, 134] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[106, 140] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[64, 154] -> 
             RGBColor[
              0.9285733529411765, 0.7545241764705882, 0.26138664705882353`], 
             UndirectedEdge[8, 157] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058822, 0.6345793235294117], 
             UndirectedEdge[83, 124] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             UndirectedEdge[22, 128] -> 
             RGBColor[
              0.9352148823529411, 0.7616891176470588, 0.35792644117647066`], 
             UndirectedEdge[83, 135] -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             UndirectedEdge[62, 68] -> 
             RGBColor[
              0.8657571470588235, 0.8929822941176471, 0.8422104705882353], 
             UndirectedEdge[105, 116] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[93, 145] -> 
             RGBColor[
              0.8558517352941176, 0.8611832352941177, 0.6664681176470588], 
             UndirectedEdge[128, 195] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764707, 0.37162073529411777`], 
             UndirectedEdge[87, 154] -> 
             RGBColor[
              0.9610704117647059, 0.8776436470588235, 0.31732720588235297`], 
             UndirectedEdge[138, 167] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.4275612941176472], 
             UndirectedEdge[179, 194] -> 
             RGBColor[
              0.7111956176470589, 0.7060182941176469, 0.6139678529411765], 
             UndirectedEdge[118, 144] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764707, 0.37162073529411777`], 
             UndirectedEdge[47, 188] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058822, 0.6345793235294117], 
             UndirectedEdge[11, 20] -> 
             RGBColor[
              0.7111956176470589, 0.7060182941176469, 0.6139678529411765], 
             UndirectedEdge[124, 187] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[28, 189] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001], 
             UndirectedEdge[84, 93] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294117], 
             UndirectedEdge[18, 94] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[146, 156] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.4275612941176472], 
             UndirectedEdge[2, 26] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[124, 161] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[25, 67] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[15, 77] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 
             UndirectedEdge[23, 49] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.608346705882353], 
             UndirectedEdge[27, 37] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.8309585294117647], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.9027125588235294, 0.5617382941176471, 0.5054969705882353], 
             UndirectedEdge[134, 139] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764706, 0.8253373823529412], 
             UndirectedEdge[13, 127] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647059], 
             UndirectedEdge[59, 186] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941177], 
             UndirectedEdge[119, 149] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352941], 
             UndirectedEdge[41, 66] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[25, 103] -> 
             RGBColor[
              0.9479845294117646, 0.9605520000000001, 0.9668471470588236], 
             UndirectedEdge[164, 166] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[30, 90] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[75, 182] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941177], 
             UndirectedEdge[92, 97] -> 
             RGBColor[
              0.9610704117647059, 0.8776436470588235, 0.31732720588235297`], 
             UndirectedEdge[18, 61] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             UndirectedEdge[76, 191] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[129, 197] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[97, 112] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.6083467058823528], 
             UndirectedEdge[87, 131] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529412], 
             UndirectedEdge[33, 198] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.608346705882353], 
             UndirectedEdge[39, 114] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[144, 170] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[64, 110] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764707, 0.37162073529411777`], 
             UndirectedEdge[108, 131] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529412], 
             UndirectedEdge[33, 141] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941177], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.8937932352941177, 0.6088684705882355, 0.23300011764705886`], 
             UndirectedEdge[88, 142] -> 
             RGBColor[
              0.5628800588235294, 0.5661560294117646, 0.6047899411764706], 
             UndirectedEdge[12, 95] -> 
             RGBColor[
              0.8622419705882354, 0.7083068823529411, 0.6022973823529412], 
             UndirectedEdge[131, 162] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588237], 
             UndirectedEdge[21, 194] -> 
             RGBColor[
              0.9674696176470587, 0.9081338235294116, 0.5614274117647059], 
             UndirectedEdge[131, 154] -> 
             RGBColor[
              0.9709758235294117, 0.9094427058823529, 0.49306955882352943`], 
             UndirectedEdge[81, 184] -> 
             RGBColor[
              0.938695205882353, 0.828548411764706, 0.5936544705882353], 
             UndirectedEdge[105, 111] -> 
             RGBColor[
              0.9569549705882352, 0.900942294117647, 0.608346705882353]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 71 -> 
             RGBColor[
              0.4755581176470588, 0.5851185294117647, 0.9518568235294118], 10 -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 68 -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             155 -> RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             132 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             26 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 29 -> 
             RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             113 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 50 -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             173 -> RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             192 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             165 -> RGBColor[
              0.4755581176470588, 0.5851185294117647, 0.9518568235294118], 92 -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             11 -> 
             RGBColor[
              0.4755581176470588, 0.5851185294117647, 0.9518568235294118], 
             137 -> RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             120 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 51 -> 
             RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             72 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 64 -> 
             RGBColor[
              0.9103135882352942, 0.6821302941176473, 0.2466944117647059], 41 -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             103 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             162 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             196 -> RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             179 -> RGBColor[
              0.4755581176470588, 0.5851185294117647, 0.9518568235294118], 
             160 -> RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             123 -> RGBColor[
              0.8772728823529412, 0.5356066470588235, 0.21930582352941178`], 
             150 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             188 -> RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             46 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             182 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             6 -> RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             131 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 45 -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             195 -> RGBColor[
              0.9103135882352942, 0.6821302941176473, 0.2466944117647059], 
             148 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             161 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 1 -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             101 -> 
             RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             12 -> RGBColor[
              0.8772728823529412, 0.5356066470588235, 0.21930582352941178`], 
             39 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 48 -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 77 -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 56 -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             110 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 73 -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 37 -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             130 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 
             107 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 59 -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 47 -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             159 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 55 -> 
             RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             49 -> RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             82 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             199 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 89 -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             144 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 78 -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 42 -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             154 -> RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             168 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 
             121 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             128 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             115 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 61 -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 93 -> 
             RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 88 -> 
             RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             21 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 62 -> 
             RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 
             136 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             190 -> RGBColor[
              0.4755581176470588, 0.5851185294117647, 0.9518568235294118], 57 -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             111 -> RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             63 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 75 -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 30 -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 5 -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             171 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             102 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 31 -> 
             RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             96 -> RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 70 -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 52 -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             183 -> RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             158 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 13 -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             170 -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 86 -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             18 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             153 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 58 -> 
             RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 22 -> 
             RGBColor[
              0.8772728823529412, 0.5356066470588235, 0.21930582352941178`], 
             66 -> RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             143 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             119 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             145 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             91 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             177 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             200 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             114 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 24 -> 
             RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             176 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 79 -> 
             RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             109 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             135 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             108 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             191 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             14 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 
             185 -> RGBColor[
              0.9103135882352942, 0.6821302941176473, 0.2466944117647059], 32 -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             122 -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             187 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             193 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             100 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             180 -> RGBColor[
              0.9103135882352942, 0.6821302941176473, 0.2466944117647059], 7 -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             175 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             9 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             90 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             174 -> RGBColor[
              0.9103135882352942, 0.6821302941176473, 0.2466944117647059], 
             142 -> RGBColor[0.178927, 0.305394, 0.933501], 134 -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             105 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 16 -> 
             RGBColor[
              0.9103135882352942, 0.6821302941176473, 0.2466944117647059], 
             139 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             146 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             126 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             198 -> RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             40 -> RGBColor[
              0.9103135882352942, 0.6821302941176473, 0.2466944117647059], 
             104 -> RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             181 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             127 -> RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 76 -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             172 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 84 -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 
             184 -> 
             RGBColor[
              0.9103135882352942, 0.6821302941176473, 0.2466944117647059], 
             151 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             35 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 36 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 34 -> 
             RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             38 -> RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 54 -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 60 -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 87 -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             141 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 67 -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             133 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 98 -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 3 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 27 -> 
             RGBColor[
              0.4755581176470588, 0.5851185294117647, 0.9518568235294118], 
             163 -> RGBColor[
              0.9103135882352942, 0.6821302941176473, 0.2466944117647059], 85 -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 83 -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 28 -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 44 -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             189 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 15 -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 80 -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             112 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             169 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 69 -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 20 -> 
             RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             8 -> RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             116 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 97 -> 
             RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             118 -> RGBColor[
              0.9103135882352942, 0.6821302941176473, 0.2466944117647059], 
             178 -> RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             81 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             166 -> RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 
             125 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 95 -> 
             RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             157 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 74 -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 19 -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 
             156 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             167 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             33 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 43 -> 
             RGBColor[
              0.8772728823529412, 0.5356066470588235, 0.21930582352941178`], 
             140 -> RGBColor[
              0.8472110588235294, 0.8810071176470587, 0.9852889411764706], 
             186 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             117 -> RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             4 -> RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             106 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 65 -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 53 -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 2 -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941177], 
             147 -> RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764706], 94 -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             23 -> RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             194 -> RGBColor[
              0.9468331176470588, 0.8269180588235292, 0.27607888235294115`], 
             129 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 99 -> 
             RGBColor[
              0.4755581176470588, 0.5851185294117647, 0.9518568235294118], 25 -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117648, 0.9406145294117647], 
             138 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             124 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             197 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             164 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             152 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 17 -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             149 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 
               0.7100602352941177]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9lnk01I33xy0ZCmPGjGUM5jOLCfGgkIjPm8rSZv1l6yGUlK0nopQSkiYJ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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 78}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.7185807941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 88}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 89}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.744813411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 122}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 136}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 138}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 144}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 159}], {
             RGBColor[
             0.9201839705882353, 0.9343893529411764, 0.7409180000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 167}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.4275612941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 197}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.4275612941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 26}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 40}], {
             RGBColor[
             0.9527160588235295, 0.8370488235294118, 0.47837732352941176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 51}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 74}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 80}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 121}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 158}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 164}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515699999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 166}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 169}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 184}], {
             RGBColor[
             0.9527160588235295, 0.8370488235294118, 0.47837732352941176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 5}], {
             RGBColor[
             0.8731056176470589, 0.5401322352941176, 0.5786488823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 10}], {
             RGBColor[
             0.8731056176470589, 0.5401322352941176, 0.5786488823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 11}], {
             RGBColor[
             0.6464385588235294, 0.35962276470588234`, 0.5580374117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 15}], {
             RGBColor[
             0.9027125588235294, 0.5617382941176471, 0.5054969705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 20}], {
             RGBColor[
             0.8820760588235295, 0.4805225294117646, 0.2201484411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 28}], {
             RGBColor[
             0.9052379411764706, 0.560949294117647, 0.3303825294117648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 48}], {
             RGBColor[
             0.9027125588235294, 0.5617382941176471, 0.5054969705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 63}], {
             RGBColor[
             0.9062187647058824, 0.5630471764705882, 0.4371391176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 77}], {
             RGBColor[
             0.9027125588235294, 0.5617382941176471, 0.5054969705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 106}], {
             RGBColor[
             0.8921979117647059, 0.5545467647058824, 0.5524162647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 186}], {
             RGBColor[
             0.8921979117647059, 0.5545467647058824, 0.5524162647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 189}], {
             RGBColor[
             0.9027125588235294, 0.5617382941176471, 0.5054969705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 41}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 66}], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 80}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 81}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.6083467058823528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 168}], {
             RGBColor[
             0.9674696176470587, 0.9081338235294116, 0.5614274117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 172}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.6083467058823528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 173}], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 184}], {
             RGBColor[
             0.9285733529411765, 0.7545241764705882, 0.26138664705882353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 198}], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 9}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[0.7022251764705882, 0.765628, 0.972468294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 15}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 17}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.744813411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 20}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058822, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 28}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.744813411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 48}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 63}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515699999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 102}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515699999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 106}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 112}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 140}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 189}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 12}], {
             RGBColor[0.912053, 0.6812623529411763, 0.24769235294117647`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 13}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 14}], {
             RGBColor[
             0.9674696176470587, 0.9081338235294116, 0.5614274117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 16}], {
             RGBColor[
             0.9285733529411765, 0.7545241764705882, 0.26138664705882353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 59}], {
             RGBColor[
             0.9674696176470587, 0.9081338235294116, 0.5614274117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 64}], {
             RGBColor[
             0.9285733529411765, 0.7545241764705882, 0.26138664705882353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 83}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 86}], {
             RGBColor[
             0.9610704117647059, 0.8776436470588235, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 124}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 137}], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 161}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 175}], {
             RGBColor[
             0.9610704117647059, 0.8776436470588235, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 176}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 186}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.6083467058823528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 187}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 193}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 199}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.6083467058823528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 18}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 42}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 47}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515699999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 58}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 73}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 88}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 94}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 97}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 115}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 153}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 160}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 188}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 55}], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 62}], {
             RGBColor[
             0.8416144411764706, 0.8104576470588234, 0.6252197941176469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 68}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 75}], {
             RGBColor[
             0.9674696176470587, 0.9081338235294116, 0.5614274117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 96}], {
             RGBColor[
             0.8416144411764706, 0.8104576470588234, 0.6252197941176469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 99}], {
             RGBColor[
             0.7111956176470589, 0.7060182941176469, 0.6139678529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 107}], {
             RGBColor[
             0.9674696176470587, 0.9081338235294116, 0.5614274117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 147}], {
             RGBColor[
             0.9674696176470587, 0.9081338235294116, 0.5614274117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 156}], {
             RGBColor[
             0.9610704117647059, 0.8776436470588235, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 157}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058822, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 179}], {
             RGBColor[
             0.7111956176470589, 0.7060182941176469, 0.6139678529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 185}], {
             RGBColor[
             0.9285733529411765, 0.7545241764705882, 0.26138664705882353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 194}], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.7254329117647058, 0.7567438823529412, 0.6552161764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 17}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.4275612941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 20}], {
             RGBColor[
             0.9610704117647059, 0.8776436470588235, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 28}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.4275612941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 63}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 77}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 97}], {
             RGBColor[
             0.9610704117647059, 0.8776436470588235, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 102}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 112}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 140}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 189}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 14}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 28}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.744813411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 48}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 59}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 77}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 186}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 193}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515699999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 15}], {
             RGBColor[
             0.7318321176470588, 0.7872340588235294, 0.8993163823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 17}], {
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 20}], {
             RGBColor[
             0.7111956176470589, 0.7060182941176469, 0.6139678529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 28}], {
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 48}], {
             RGBColor[
             0.7318321176470588, 0.7872340588235294, 0.8993163823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 63}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.8309585294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 77}], {
             RGBColor[
             0.7318321176470588, 0.7872340588235294, 0.8993163823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 106}], {
             RGBColor[
             0.7213174705882353, 0.7800425294117648, 0.9462356764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 112}], {
             RGBColor[
             0.7213174705882353, 0.7800425294117648, 0.9462356764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 140}], {
             RGBColor[
             0.6613845882352941, 0.7330628235294117, 0.9685728823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 189}], {
             RGBColor[
             0.7318321176470588, 0.7872340588235294, 0.8993163823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 13}], {
             RGBColor[
             0.9352148823529411, 0.7616891176470588, 0.35792644117647066`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 14}], {
             RGBColor[0.9326895, 0.7624781176470589, 0.5330408823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.8937932352941177, 0.6088684705882355, 0.23300011764705886`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 23}], {
             RGBColor[
             0.9221748529411764, 0.7552865882352942, 0.5799601764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 25}], {
             RGBColor[
             0.9221748529411764, 0.7552865882352942, 0.5799601764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 59}], {
             RGBColor[0.9326895, 0.7624781176470589, 0.5330408823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.8937932352941177, 0.6088684705882355, 0.23300011764705886`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 86}], {
             RGBColor[
             0.9262902941176471, 0.7319879411764707, 0.28894067647058824`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 87}], {
             RGBColor[
             0.9262902941176471, 0.7319879411764707, 0.28894067647058824`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 95}], {
             RGBColor[
             0.8622419705882354, 0.7083068823529411, 0.6022973823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 108}], {
             RGBColor[
             0.9262902941176471, 0.7319879411764707, 0.28894067647058824`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 154}], {
             RGBColor[0.912053, 0.6812623529411763, 0.24769235294117647`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 161}], {
             RGBColor[0.9361957058823529, 0.763787, 0.46468302941176476`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 175}], {
             RGBColor[
             0.9262902941176471, 0.7319879411764707, 0.28894067647058824`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 193}], {
             RGBColor[0.9361957058823529, 0.763787, 0.46468302941176476`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 16}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764707, 0.37162073529411777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 64}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764707, 0.37162073529411777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 69}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 82}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 83}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 86}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.4275612941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 101}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 108}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.4275612941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 110}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 124}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 127}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 137}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 161}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 175}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.4275612941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 176}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 187}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 199}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.7185807941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 15}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 48}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 59}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 186}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 193}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 28}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 48}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 59}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 63}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 77}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 106}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 140}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 193}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 64}], {
             RGBColor[
             0.9103135882352942, 0.6821302941176473, 0.2466944117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 83}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764707, 0.37162073529411777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 86}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058825, 0.3026349705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 101}], {
             RGBColor[
             0.9285733529411765, 0.7545241764705882, 0.26138664705882353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 124}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764707, 0.37162073529411777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 127}], {
             RGBColor[0.7596562058823529, 0.687791, 0.6045280882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 137}], {
             RGBColor[
             0.9285733529411765, 0.7545241764705882, 0.26138664705882353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 161}], {
             RGBColor[
             0.9527160588235295, 0.8370488235294118, 0.47837732352941176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 175}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058825, 0.3026349705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 176}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764707, 0.37162073529411777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.9527160588235295, 0.8370488235294118, 0.47837732352941176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 193}], {
             RGBColor[
             0.9527160588235295, 0.8370488235294118, 0.47837732352941176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 199}], {
             RGBColor[
             0.938695205882353, 0.828548411764706, 0.5936544705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 20}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 28}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 77}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 106}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.7185807941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 112}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.7185807941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 140}], {
             RGBColor[
             0.9201839705882353, 0.9343893529411764, 0.7409180000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 189}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 47}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 54}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 58}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 61}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 73}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 94}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 115}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 116}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 153}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 160}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 174}], {
             RGBColor[
             0.938695205882353, 0.828548411764706, 0.5936544705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 188}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 33}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 34}], {
             RGBColor[
             0.9674696176470587, 0.9081338235294116, 0.5614274117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 44}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 50}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 60}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 90}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 130}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 141}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 177}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 77}], {
             RGBColor[
             0.9674696176470587, 0.9081338235294116, 0.5614274117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 106}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.6083467058823528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 189}], {
             RGBColor[
             0.9674696176470587, 0.9081338235294116, 0.5614274117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.9027125588235294, 0.5617382941176471, 0.5054969705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 46}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 85}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 109}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 132}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 150}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 151}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 194}], {
             RGBColor[
             0.9674696176470587, 0.9081338235294116, 0.5614274117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 196}], {
             RGBColor[
             0.9674696176470587, 0.9081338235294116, 0.5614274117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 24}], {
             RGBColor[0.912053, 0.6812623529411763, 0.24769235294117647`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 37}], {
             RGBColor[0.9361957058823529, 0.763787, 0.46468302941176476`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 38}], {
             RGBColor[
             0.8068343235294118, 0.6648019411764705, 0.5968332647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 79}], {
             RGBColor[
             0.7431358529411765, 0.6145291764705882, 0.590833794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 89}], {
             RGBColor[
             0.9030825588235294, 0.7408720588235294, 0.606192794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 118}], {
             RGBColor[
             0.8937932352941177, 0.6088684705882355, 0.23300011764705886`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 119}], {
             RGBColor[
             0.8622419705882354, 0.7083068823529411, 0.6022973823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 122}], {
             RGBColor[
             0.9352148823529411, 0.7616891176470588, 0.35792644117647066`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 128}], {
             RGBColor[
             0.9352148823529411, 0.7616891176470588, 0.35792644117647066`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 138}], {
             RGBColor[
             0.9352148823529411, 0.7616891176470588, 0.35792644117647066`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 144}], {
             RGBColor[
             0.9352148823529411, 0.7616891176470588, 0.35792644117647066`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 149}], {
             RGBColor[0.9361957058823529, 0.763787, 0.46468302941176476`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 181}], {
             RGBColor[
             0.9221748529411764, 0.7552865882352942, 0.5799601764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 183}], {
             RGBColor[0.912053, 0.6812623529411763, 0.24769235294117647`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 190}], {
             RGBColor[
             0.6764155000000001, 0.5603625882352941, 0.5855813235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 192}], {
             RGBColor[
             0.9352148823529411, 0.7616891176470588, 0.35792644117647066`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 25}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 43}], {
             RGBColor[
             0.9221748529411764, 0.7552865882352942, 0.5799601764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 49}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 64}], {
             RGBColor[
             0.938695205882353, 0.828548411764706, 0.5936544705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 67}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 87}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 95}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 103}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 108}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 129}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 131}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 143}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 154}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 162}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.7185807941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.7111956176470589, 0.7060182941176469, 0.6139678529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 37}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 56}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.6083467058823528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 79}], {
             RGBColor[
             0.7779159705882353, 0.7601848823529411, 0.6192203235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 89}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058822, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 118}], {
             RGBColor[
             0.9285733529411765, 0.7545241764705882, 0.26138664705882353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 119}], {
             RGBColor[
             0.8970220882352942, 0.8539625882352939, 0.6306839117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 125}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058822, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 144}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 149}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 170}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 190}], {
             RGBColor[
             0.7111956176470589, 0.7060182941176469, 0.6139678529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 195}], {
             RGBColor[
             0.9285733529411765, 0.7545241764705882, 0.26138664705882353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 197}], {
             RGBColor[
             0.9610704117647059, 0.8776436470588235, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[
             0.9221748529411764, 0.7552865882352942, 0.5799601764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 49}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 64}], {
             RGBColor[
             0.938695205882353, 0.828548411764706, 0.5936544705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 67}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 87}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 95}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 103}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 108}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 129}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 131}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 143}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 154}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 162}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.7185807941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 40}], {
             RGBColor[
             0.938695205882353, 0.828548411764706, 0.5936544705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 51}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 74}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 80}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.7185807941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 121}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 158}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 164}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 169}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 184}], {
             RGBColor[
             0.938695205882353, 0.828548411764706, 0.5936544705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 37}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.8309585294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 56}], {
             RGBColor[
             0.7213174705882353, 0.7800425294117648, 0.9462356764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 67}], {
             RGBColor[0.7022251764705882, 0.765628, 0.972468294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 119}], {
             RGBColor[
             0.6613845882352941, 0.7330628235294117, 0.9685728823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 125}], {
             RGBColor[0.7022251764705882, 0.765628, 0.972468294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 128}], {
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 133}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.8309585294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 190}], {
             RGBColor[
             0.4755581176470588, 0.5851185294117647, 0.9518568235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 195}], {
             RGBColor[
             0.6929358529411764, 0.633624411764706, 0.5992756176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 48}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 63}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 77}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 106}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.7185807941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 112}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.7185807941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 140}], {
             RGBColor[
             0.9201839705882353, 0.9343893529411764, 0.7409180000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 189}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 35}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 47}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 88}], {
             RGBColor[
             0.7779159705882353, 0.7601848823529411, 0.6192203235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 89}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 113}], {
             RGBColor[0.8020586764705881, 0.8427095294117647, 0.836211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 122}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 136}], {
             RGBColor[0.8020586764705881, 0.8427095294117647, 0.836211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 138}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 142}], {
             RGBColor[
             0.3939629117647059, 0.4994228529411765, 0.9479313823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 144}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 153}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 159}], {
             RGBColor[
             0.7281049411764706, 0.7872294117647058, 0.9738253529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 167}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 181}], {
             RGBColor[
             0.7880378235294117, 0.8342091176470589, 0.9514881470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 188}], {
             RGBColor[
             0.7779159705882353, 0.7601848823529411, 0.6192203235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 41}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 65}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 66}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 90}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 110}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 162}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 180}], {
             RGBColor[
             0.9527160588235295, 0.8370488235294118, 0.47837732352941176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 198}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 38}], {
             RGBColor[
             0.8416144411764706, 0.8104576470588234, 0.6252197941176469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[
             0.9285733529411765, 0.7545241764705882, 0.26138664705882353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 46}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 80}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 98}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 117}], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 120}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 121}], {
             RGBColor[
             0.9610704117647059, 0.8776436470588235, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 146}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 151}], {
             RGBColor[
             0.9610704117647059, 0.8776436470588235, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 171}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 173}], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 178}], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 196}], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 53}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515699999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 82}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.744813411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 83}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.744813411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 100}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 101}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058822, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 123}], {
             RGBColor[
             0.9030825588235294, 0.7408720588235294, 0.606192794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 127}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 130}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 135}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.744813411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 148}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515699999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 163}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529413, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 165}], {
             RGBColor[0.7022251764705882, 0.765628, 0.972468294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 176}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.744813411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 187}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515699999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 41}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 44}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 57}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 66}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 90}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.7185807941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 141}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 198}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 44}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 50}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 60}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 90}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 104}], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 130}], {
             RGBColor[
             0.9674696176470587, 0.9081338235294116, 0.5614274117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 163}], {
             RGBColor[
             0.9285733529411765, 0.7545241764705882, 0.26138664705882353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 177}], {
             RGBColor[
             0.8970220882352942, 0.8539625882352939, 0.6306839117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 47}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 68}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515699999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 88}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058822, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 111}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058822, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 116}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515699999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 122}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.744813411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 138}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.744813411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 142}], {
             RGBColor[
             0.5539096176470588, 0.6257657352941176, 0.9632903823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 153}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 157}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 160}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058822, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 167}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 174}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529413, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 181}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 185}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529413, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 188}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058822, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 132}], {
             RGBColor[
             0.8963133529411764, 0.5312481176470589, 0.26139676470588236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 151}], {
             RGBColor[
             0.8963133529411764, 0.5312481176470589, 0.26139676470588236`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 169}], {
             RGBColor[
             0.8921979117647059, 0.5545467647058824, 0.5524162647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 200}], {
             RGBColor[
             0.8921979117647059, 0.5545467647058824, 0.5524162647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 56}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 79}], {
             RGBColor[0.8020586764705881, 0.8427095294117647, 0.836211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 118}], {
             RGBColor[
             0.9527160588235295, 0.8370488235294118, 0.47837732352941176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 119}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 125}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515699999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 128}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 149}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 170}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 190}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.8309585294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 195}], {
             RGBColor[
             0.9527160588235295, 0.8370488235294118, 0.47837732352941176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 46}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 98}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 117}], {
             RGBColor[
             0.8416144411764706, 0.8104576470588234, 0.625219794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 120}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 128}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 146}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 156}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 171}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 178}], {
             RGBColor[
             0.8416144411764706, 0.8104576470588234, 0.625219794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 179}], {
             RGBColor[
             0.6059769411764706, 0.6895578823529411, 0.9631087647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 183}], {
             RGBColor[
             0.8416144411764706, 0.8104576470588234, 0.625219794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 192}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 114}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 46}], {
             RGBColor[
             0.9527160588235295, 0.8370488235294118, 0.47837732352941176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 74}], {
             RGBColor[
             0.9527160588235295, 0.8370488235294118, 0.47837732352941176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764707, 0.37162073529411777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 117}], {
             RGBColor[
             0.9285733529411765, 0.7545241764705882, 0.26138664705882353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 121}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058825, 0.3026349705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 166}], {
             RGBColor[
             0.8233546764705882, 0.7380637647058824, 0.6105275588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 169}], {
             RGBColor[
             0.938695205882353, 0.828548411764706, 0.5936544705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 171}], {
             RGBColor[
             0.9527160588235295, 0.8370488235294118, 0.47837732352941176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 173}], {
             RGBColor[
             0.9285733529411765, 0.7545241764705882, 0.26138664705882353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 196}], {
             RGBColor[
             0.9285733529411765, 0.7545241764705882, 0.26138664705882353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 57}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 66}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 81}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 90}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 141}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 168}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 172}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 184}], {
             RGBColor[
             0.9527160588235295, 0.8370488235294118, 0.47837732352941176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 198}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 88}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 102}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 153}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 49}], {
             RGBColor[0.912053, 0.6812623529411763, 0.24769235294117647`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 67}], {
             RGBColor[
             0.9030825588235294, 0.7408720588235294, 0.606192794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 87}], {
             RGBColor[
             0.9262902941176471, 0.7319879411764707, 0.28894067647058824`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 95}], {
             RGBColor[
             0.8622419705882354, 0.7083068823529411, 0.6022973823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 103}], {
             RGBColor[
             0.9030825588235294, 0.7408720588235294, 0.606192794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 129}], {
             RGBColor[
             0.9030825588235294, 0.7408720588235294, 0.606192794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 131}], {
             RGBColor[0.9361957058823529, 0.763787, 0.46468302941176476`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 133}], {
             RGBColor[0.9361957058823529, 0.763787, 0.46468302941176476`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 143}], {
             RGBColor[
             0.9221748529411764, 0.7552865882352942, 0.5799601764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 154}], {
             RGBColor[0.912053, 0.6812623529411763, 0.24769235294117647`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 197}], {
             RGBColor[
             0.9262902941176471, 0.7319879411764707, 0.28894067647058824`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 50}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 57}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 60}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 90}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 141}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 177}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 120}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 128}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.4275612941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 168}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 172}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 173}], {
             RGBColor[
             0.9610704117647059, 0.8776436470588235, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 85}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515699999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 98}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 99}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.8309585294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 109}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 117}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 121}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 146}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 151}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 171}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 178}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 196}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 54}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 61}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 73}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515699999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 88}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058822, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 94}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 105}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 111}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058822, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 116}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515699999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 126}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.744813411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 142}], {
             RGBColor[
             0.5539096176470588, 0.6257657352941176, 0.9632903823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 153}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 157}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 160}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058822, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 167}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 174}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529413, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 188}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058822, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 59}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 77}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 106}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 112}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 140}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 193}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 67}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058822, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.9610704117647059, 0.8776436470588235, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 95}], {
             RGBColor[
             0.8970220882352942, 0.8539625882352939, 0.6306839117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 103}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058822, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 108}], {
             RGBColor[
             0.9610704117647059, 0.8776436470588235, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058822, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 131}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 133}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 143}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.6083467058823528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 154}], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 162}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 53}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 60}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 82}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 100}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 104}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 123}], {
             RGBColor[0.9361957058823529, 0.763787, 0.4646830294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 163}], {
             RGBColor[
             0.9527160588235295, 0.8370488235294118, 0.47837732352941176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 177}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 71}], {
             RGBColor[
             0.7111956176470589, 0.7060182941176469, 0.6139678529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 74}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 158}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 164}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058822, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 166}], {
             RGBColor[
             0.8416144411764706, 0.8104576470588234, 0.6252197941176469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 184}], {
             RGBColor[
             0.9285733529411765, 0.7545241764705882, 0.26138664705882353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 70}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 134}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 145}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 100}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 104}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 123}], {
             RGBColor[0.9361957058823529, 0.763787, 0.4646830294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 130}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 135}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 148}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 163}], {
             RGBColor[
             0.9527160588235295, 0.8370488235294118, 0.47837732352941176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 165}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.8309585294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 58}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 61}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 73}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 94}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 105}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 115}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 116}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 126}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 160}], {
             RGBColor[
             0.9674696176470587, 0.9081338235294116, 0.5614274117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 174}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 62}], {
             RGBColor[
             0.8416144411764706, 0.8104576470588234, 0.6252197941176469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 68}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 72}], {
             RGBColor[
             0.9674696176470587, 0.9081338235294116, 0.5614274117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 75}], {
             RGBColor[
             0.9674696176470587, 0.9081338235294116, 0.5614274117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 76}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.6083467058823528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 96}], {
             RGBColor[
             0.8416144411764706, 0.8104576470588234, 0.6252197941176469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 107}], {
             RGBColor[
             0.9674696176470587, 0.9081338235294116, 0.5614274117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 111}], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 139}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 147}], {
             RGBColor[
             0.9674696176470587, 0.9081338235294116, 0.5614274117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 157}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058822, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 182}], {
             RGBColor[
             0.9610704117647059, 0.8776436470588235, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 185}], {
             RGBColor[
             0.9285733529411765, 0.7545241764705882, 0.26138664705882353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 191}], {
             RGBColor[
             0.9610704117647059, 0.8776436470588235, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 79}], {
             RGBColor[
             0.7880378235294117, 0.8342091176470589, 0.9514881470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 118}], {
             RGBColor[
             0.938695205882353, 0.828548411764706, 0.5936544705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 119}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 125}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 129}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 149}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 170}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 190}], {
             RGBColor[
             0.7213174705882353, 0.7800425294117648, 0.9462356764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 195}], {
             RGBColor[
             0.938695205882353, 0.828548411764706, 0.5936544705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 197}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 66}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 71}], {
             RGBColor[
             0.7213174705882353, 0.7800425294117648, 0.9462356764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 81}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 90}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.7185807941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 141}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 198}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 61}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 73}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 92}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 115}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 155}], {
             RGBColor[
             0.672697294117647, 0.7437244705882353, 0.9683612352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 154}], {
             RGBColor[
             0.9674696176470587, 0.9081338235294116, 0.5614274117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 186}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 193}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 104}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 123}], {
             RGBColor[0.9361957058823529, 0.763787, 0.4646830294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 130}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 163}], {
             RGBColor[
             0.9527160588235295, 0.8370488235294118, 0.47837732352941176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 177}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 73}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 94}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 105}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 115}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 116}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 160}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 174}], {
             RGBColor[
             0.938695205882353, 0.828548411764706, 0.5936544705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 68}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 75}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 76}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 96}], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 105}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 107}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 111}], {
             RGBColor[
             0.8416144411764706, 0.8104576470588234, 0.625219794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 116}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 126}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 157}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 174}], {
             RGBColor[
             0.8233546764705882, 0.7380637647058824, 0.6105275588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 182}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 185}], {
             RGBColor[
             0.8233546764705882, 0.7380637647058824, 0.6105275588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 191}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 77}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 91}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 102}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 106}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 112}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 140}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 69}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 82}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764707, 0.37162073529411777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 86}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058825, 0.3026349705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 87}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058825, 0.3026349705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 108}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058825, 0.3026349705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 110}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764707, 0.37162073529411777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 127}], {
             RGBColor[0.7596562058823529, 0.687791, 0.6045280882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 154}], {
             RGBColor[
             0.9285733529411765, 0.7545241764705882, 0.26138664705882353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 161}], {
             RGBColor[
             0.9527160588235295, 0.8370488235294118, 0.47837732352941176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 162}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764707, 0.37162073529411777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 175}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058825, 0.3026349705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 176}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764707, 0.37162073529411777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 180}], {
             RGBColor[
             0.9103135882352942, 0.6821302941176473, 0.2466944117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 66}], {
             RGBColor[
             0.9674696176470587, 0.9081338235294116, 0.5614274117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 69}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 87}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 90}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 110}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 131}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 133}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 162}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 180}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 198}], {
             RGBColor[
             0.9674696176470587, 0.9081338235294116, 0.5614274117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 81}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.6083467058823528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 90}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 141}], {
             RGBColor[
             0.9674696176470587, 0.9081338235294116, 0.5614274117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 168}], {
             RGBColor[
             0.9674696176470587, 0.9081338235294116, 0.5614274117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 172}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.6083467058823528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 198}], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 87}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 103}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 129}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 131}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515699999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 133}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515699999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 143}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 162}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.744813411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 107}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 111}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 122}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 138}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 142}], {
             RGBColor[
             0.5870227647058823, 0.6486806764705882, 0.8217806176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 147}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 156}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 157}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515699999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 179}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.8309585294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 181}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 185}], {
             RGBColor[
             0.9527160588235295, 0.8370488235294118, 0.47837732352941176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 82}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 86}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 90}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 110}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 123}], {
             RGBColor[0.9326895, 0.7624781176470589, 0.5330408823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 127}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 177}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 180}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 72}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 93}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 134}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 139}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 81}], {
             RGBColor[
             0.7213174705882353, 0.7800425294117648, 0.9462356764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 164}], {
             RGBColor[0.7022251764705882, 0.765628, 0.972468294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 184}], {
             RGBColor[
             0.6929358529411764, 0.633624411764706, 0.5992756176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 75}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 84}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 93}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 134}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 139}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 152}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 191}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 94}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 115}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 153}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 160}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 80}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 158}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 164}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515699999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 166}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 169}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 184}], {
             RGBColor[
             0.9527160588235295, 0.8370488235294118, 0.47837732352941176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 76}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 96}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 134}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 139}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 182}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 191}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 105}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 111}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 116}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 126}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.7185807941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 174}], {
             RGBColor[
             0.938695205882353, 0.828548411764706, 0.5936544705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 191}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 102}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 106}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 112}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 140}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 189}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 91}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 95}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 113}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 136}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 89}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 118}], {
             RGBColor[0.7596562058823529, 0.687791, 0.6045280882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 119}], {
             RGBColor[
             0.7281049411764706, 0.7872294117647058, 0.9738253529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 125}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 128}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 144}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 149}], {
             RGBColor[0.8020586764705881, 0.8427095294117647, 0.836211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 159}], {
             RGBColor[
             0.7281049411764706, 0.7872294117647058, 0.9738253529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 170}], {
             RGBColor[0.8020586764705881, 0.8427095294117647, 0.836211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 190}], {
             RGBColor[
             0.5422784705882353, 0.6392851176470589, 0.9571092941176471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 192}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 195}], {
             RGBColor[0.7596562058823529, 0.687791, 0.6045280882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 197}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 81}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.7185807941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 117}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 120}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 121}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.4275612941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 166}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 168}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 172}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.7185807941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 173}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 184}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764707, 0.37162073529411777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 164}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 166}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 168}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 172}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 173}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 184}], {
             RGBColor[
             0.938695205882353, 0.828548411764706, 0.5936544705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 198}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 86}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.4275612941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 101}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 110}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 123}], {
             RGBColor[
             0.9352148823529411, 0.7616891176470588, 0.3579264411764707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 127}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 130}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 163}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764707, 0.37162073529411777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 176}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 177}], {
             RGBColor[
             0.9201839705882353, 0.9343893529411764, 0.7409180000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 180}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764707, 0.37162073529411777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 187}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 86}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.4275612941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 101}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 124}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 135}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 137}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 161}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 165}], {
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 175}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.4275612941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 176}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 187}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 199}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.7185807941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 93}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 139}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 152}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 194}], {
             RGBColor[
             0.9674696176470587, 0.9081338235294116, 0.5614274117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 99}], {
             RGBColor[0.7022251764705882, 0.765628, 0.972468294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 109}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 132}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 146}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.744813411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 150}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.744813411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 151}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 152}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.744813411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 194}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058822, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 196}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058822, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 101}], {
             RGBColor[
             0.9610704117647059, 0.8776436470588235, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 108}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 110}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.4275612941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 124}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.4275612941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 127}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 161}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 175}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 176}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.4275612941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 180}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058825, 0.3026349705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 187}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 199}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 95}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 103}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 108}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 110}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.4275612941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 131}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 143}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[
             0.9610704117647059, 0.8776436470588235, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 162}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.4275612941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 180}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058825, 0.3026349705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 94}], {
             RGBColor[
             0.9610704117647059, 0.8776436470588235, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 102}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 122}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 136}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 142}], {
             RGBColor[
             0.5628800588235294, 0.5661560294117646, 0.6047899411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 153}], {
             RGBColor[
             0.9674696176470587, 0.9081338235294116, 0.5614274117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 167}], {
             RGBColor[
             0.9610704117647059, 0.8776436470588235, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 188}], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 113}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515699999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 118}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529413, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 122}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.744813411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 136}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515699999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 138}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.744813411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 144}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.744813411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 149}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515699999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 159}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 170}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515699999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 192}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.744813411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 197}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 141}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 177}], {
             RGBColor[
             0.9201839705882353, 0.9343893529411764, 0.7409180000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 198}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 95}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 136}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 97}], {
             RGBColor[
             0.9610704117647059, 0.8776436470588235, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 155}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 134}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 139}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 145}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 105}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 111}], {
             RGBColor[
             0.9610704117647059, 0.8776436470588235, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 115}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 116}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 126}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.4275612941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 142}], {
             RGBColor[
             0.5771173529411765, 0.6168816176470588, 0.6460382647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 153}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 160}], {
             RGBColor[
             0.9610704117647059, 0.8776436470588235, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 167}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 174}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058825, 0.3026349705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 188}], {
             RGBColor[
             0.9610704117647059, 0.8776436470588235, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 103}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 129}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 131}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 143}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 154}], {
             RGBColor[
             0.8970220882352942, 0.8539625882352939, 0.6306839117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 105}], {
             RGBColor[
             0.851736294117647, 0.8844818823529412, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 111}], {
             RGBColor[
             0.8416144411764706, 0.8104576470588234, 0.625219794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 116}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 126}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 174}], {
             RGBColor[
             0.8233546764705882, 0.7380637647058824, 0.6105275588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 182}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 191}], {
             RGBColor[
             0.8558517352941176, 0.8611832352941177, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 102}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 112}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.6083467058823528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 140}], {
             RGBColor[
             0.8970220882352942, 0.8539625882352939, 0.6306839117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 155}], {
             RGBColor[
             0.7779159705882353, 0.7601848823529411, 0.6192203235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 99}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.8309585294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 117}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 120}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 121}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 146}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 156}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 178}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 179}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.8309585294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 183}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 196}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 107}], {
             RGBColor[
             0.7318321176470588, 0.7872340588235294, 0.8993163823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 109}], {
             RGBColor[
             0.7213174705882353, 0.7800425294117648, 0.9462356764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 146}], {
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 147}], {
             RGBColor[
             0.7318321176470588, 0.7872340588235294, 0.8993163823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 156}], {
             RGBColor[
             0.7254329117647058, 0.7567438823529412, 0.6552161764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 178}], {
             RGBColor[
             0.7111956176470589, 0.7060182941176469, 0.6139678529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 179}], {
             RGBColor[
             0.4755581176470588, 0.5851185294117647, 0.9518568235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 194}], {
             RGBColor[
             0.7111956176470589, 0.7060182941176469, 0.6139678529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 104}], {
             RGBColor[
             0.8970220882352942, 0.8539625882352939, 0.6306839117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 123}], {
             RGBColor[
             0.8622419705882354, 0.7083068823529411, 0.6022973823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 130}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 135}], {
             RGBColor[
             0.9201839705882353, 0.9343893529411764, 0.7409180000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 148}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 163}], {
             RGBColor[
             0.8787623235294117, 0.781568705882353, 0.6159916764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 165}], {
             RGBColor[
             0.6613845882352941, 0.7330628235294117, 0.9685728823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 123}], {
             RGBColor[0.912053, 0.6812623529411763, 0.24769235294117647`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 124}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 127}], {
             RGBColor[
             0.7779159705882353, 0.7601848823529411, 0.6192203235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 135}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 137}], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 161}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 165}], {
             RGBColor[
             0.7111956176470589, 0.7060182941176469, 0.6139678529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 175}], {
             RGBColor[
             0.9610704117647059, 0.8776436470588235, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 176}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 187}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 199}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.6083467058823528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 106}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 112}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 140}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 108}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 129}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 131}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515699999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 133}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515699999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 143}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 154}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058822, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 162}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.744813411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 123}], {
             RGBColor[0.912053, 0.6812623529411763, 0.24769235294117647`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 130}], {
             RGBColor[
             0.9674696176470587, 0.9081338235294116, 0.5614274117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 163}], {
             RGBColor[
             0.9285733529411765, 0.7545241764705882, 0.26138664705882353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 111}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 116}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 126}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.7185807941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 142}], {
             RGBColor[
             0.5730019117647058, 0.6401802647058824, 0.9370577647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 157}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 160}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 174}], {
             RGBColor[
             0.938695205882353, 0.828548411764706, 0.5936544705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 182}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 112}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 140}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 189}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 111}], {
             RGBColor[
             0.9674696176470587, 0.9081338235294116, 0.5614274117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 142}], {
             RGBColor[
             0.5835165588235294, 0.6473717941176471, 0.8901384705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.7318321176470588, 0.7872340588235294, 0.8993163823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 181}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 185}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 110}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.4275612941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 131}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 154}], {
             RGBColor[
             0.9610704117647059, 0.8776436470588235, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 162}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.4275612941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 180}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058825, 0.3026349705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 132}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 146}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.7185807941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 150}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.7185807941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 151}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 152}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.7185807941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 194}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 196}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 127}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 162}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 180}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764707, 0.37162073529411777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 116}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 126}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 142}], {
             RGBColor[
             0.5628800588235294, 0.5661560294117646, 0.6047899411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 157}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058822, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 160}], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 167}], {
             RGBColor[
             0.9610704117647059, 0.8776436470588235, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 174}], {
             RGBColor[
             0.9285733529411765, 0.7545241764705882, 0.26138664705882353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 181}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.6083467058823528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.9285733529411765, 0.7545241764705882, 0.26138664705882353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 188}], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 140}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 122}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 136}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 138}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 144}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 159}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 167}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 197}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 158}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 160}], {
             RGBColor[
             0.9674696176470587, 0.9081338235294116, 0.5614274117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 126}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 142}], {
             RGBColor[
             0.5870227647058823, 0.6486806764705882, 0.8217806176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 153}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 157}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515699999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 160}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 167}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 174}], {
             RGBColor[
             0.9527160588235295, 0.8370488235294118, 0.47837732352941176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 188}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 120}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 121}], {
             RGBColor[
             0.9610704117647059, 0.8776436470588235, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 146}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 151}], {
             RGBColor[
             0.9610704117647059, 0.8776436470588235, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 171}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 173}], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 196}], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 119}], {
             RGBColor[
             0.8787623235294117, 0.781568705882353, 0.6159916764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 125}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529413, 0.619887088235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 128}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764707, 0.37162073529411777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 138}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764707, 0.37162073529411777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 144}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764707, 0.37162073529411777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 149}], {
             RGBColor[
             0.9527160588235295, 0.8370488235294118, 0.47837732352941176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 159}], {
             RGBColor[
             0.8787623235294117, 0.781568705882353, 0.6159916764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 170}], {
             RGBColor[
             0.9527160588235295, 0.8370488235294118, 0.47837732352941176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 190}], {
             RGBColor[
             0.6929358529411764, 0.633624411764706, 0.5992756176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 192}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764707, 0.37162073529411777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.9103135882352942, 0.6821302941176473, 0.2466944117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 197}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058825, 0.3026349705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 125}], {
             RGBColor[
             0.8880516470588236, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 128}], {
             RGBColor[
             0.9201839705882353, 0.9343893529411764, 0.7409180000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 144}], {
             RGBColor[
             0.9201839705882353, 0.9343893529411764, 0.7409180000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 149}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 183}], {
             RGBColor[
             0.8970220882352942, 0.8539625882352939, 0.6306839117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 190}], {
             RGBColor[
             0.6613845882352941, 0.7330628235294117, 0.9685728823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 192}], {
             RGBColor[
             0.9201839705882353, 0.9343893529411764, 0.7409180000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 195}], {
             RGBColor[
             0.8787623235294117, 0.781568705882353, 0.6159916764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 128}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 168}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 171}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 172}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 173}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 183}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 151}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 171}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 196}], {
             RGBColor[
             0.9610704117647059, 0.8776436470588235, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 136}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 138}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 142}], {
             RGBColor[
             0.5860419411764706, 0.6465827941176471, 0.7150240294117648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 144}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 153}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.9201839705882353, 0.9343893529411764, 0.7409180000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 167}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.4275612941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 181}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.7185807941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 188}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 192}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 127}], {
             RGBColor[
             0.7431358529411765, 0.6145291764705882, 0.590833794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 130}], {
             RGBColor[0.9326895, 0.7624781176470589, 0.5330408823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 135}], {
             RGBColor[
             0.9352148823529411, 0.7616891176470588, 0.35792644117647066`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 163}], {
             RGBColor[
             0.8937932352941177, 0.6088684705882355, 0.23300011764705886`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 165}], {
             RGBColor[
             0.6764155000000001, 0.5603625882352941, 0.5855813235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 177}], {
             RGBColor[
             0.8622419705882354, 0.7083068823529411, 0.6022973823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 187}], {
             RGBColor[0.9361957058823529, 0.763787, 0.46468302941176476`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 127}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 135}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 161}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 175}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.4275612941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 176}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 187}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 199}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.7185807941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 128}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.744813411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515699999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515699999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 190}], {
             RGBColor[0.7022251764705882, 0.765628, 0.972468294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 195}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529413, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 142}], {
             RGBColor[
             0.5860419411764706, 0.6465827941176471, 0.7150240294117648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 157}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.744813411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 160}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 174}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764707, 0.37162073529411777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 182}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.4275612941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 191}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.4275612941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 135}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 161}], {
             RGBColor[0.8020586764705881, 0.8427095294117647, 0.836211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 175}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 176}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 177}], {
             RGBColor[
             0.7281049411764706, 0.7872294117647058, 0.9738253529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 180}], {
             RGBColor[0.7596562058823529, 0.687791, 0.6045280882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 187}], {
             RGBColor[0.8020586764705881, 0.8427095294117647, 0.836211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 183}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 190}], {
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 192}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 195}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764707, 0.37162073529411777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 131}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515699999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 133}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515699999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 143}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 170}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515699999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 197}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 163}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 177}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 133}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 143}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 154}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 162}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 180}], {
             RGBColor[
             0.9527160588235295, 0.8370488235294118, 0.47837732352941176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 150}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.4275612941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 151}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 162}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 139}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 145}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 191}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 148}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 163}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764707, 0.37162073529411777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 165}], {
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 176}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 187}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 143}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 159}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 197}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 161}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 175}], {
             RGBColor[
             0.9610704117647059, 0.8776436470588235, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 176}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 186}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.6083467058823528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 187}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 199}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.6083467058823528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 142}], {
             RGBColor[
             0.5860419411764706, 0.6465827941176471, 0.7150240294117648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 144}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 156}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.4275612941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 159}], {
             RGBColor[
             0.9201839705882353, 0.9343893529411764, 0.7409180000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 167}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.4275612941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 181}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.7185807941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 185}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764707, 0.37162073529411777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 192}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 145}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 152}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 182}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 191}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 198}], {
             RGBColor[
             0.9674696176470587, 0.9081338235294116, 0.5614274117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 153}], {
             RGBColor[
             0.5835165588235294, 0.6473717941176471, 0.8901384705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 157}], {
             RGBColor[
             0.5539096176470588, 0.6257657352941177, 0.9632903823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 160}], {
             RGBColor[
             0.5628800588235294, 0.5661560294117647, 0.6047899411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 167}], {
             RGBColor[
             0.5771173529411764, 0.6168816176470588, 0.6460382647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 174}], {
             RGBColor[
             0.544620294117647, 0.4937621470588236, 0.590097705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 181}], {
             RGBColor[
             0.5730019117647058, 0.6401802647058823, 0.9370577647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 185}], {
             RGBColor[
             0.544620294117647, 0.4937621470588236, 0.590097705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.5628800588235294, 0.5661560294117647, 0.6047899411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 154}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 159}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 197}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 149}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 159}], {
             RGBColor[
             0.9201839705882353, 0.9343893529411764, 0.7409180000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 170}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 181}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.7185807941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 190}], {
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 192}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 197}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.4275612941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 147}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 156}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.4275612941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 171}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 178}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 179}], {
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 183}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 194}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 196}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 152}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 156}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 178}], {
             RGBColor[
             0.9674696176470587, 0.9081338235294116, 0.5614274117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 179}], {
             RGBColor[
             0.7318321176470588, 0.7872340588235294, 0.8993163823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 185}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 194}], {
             RGBColor[
             0.9674696176470587, 0.9081338235294116, 0.5614274117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 165}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.8309585294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 159}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 170}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 190}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.8309585294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 192}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 195}], {
             RGBColor[
             0.9527160588235295, 0.8370488235294118, 0.47837732352941176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 151}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.4275612941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 152}], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 194}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 171}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 196}], {
             RGBColor[
             0.9610704117647059, 0.8776436470588235, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 194}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 160}], {
             RGBColor[
             0.9674696176470587, 0.9081338235294116, 0.5614274117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 167}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 174}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 188}], {
             RGBColor[
             0.9674696176470587, 0.9081338235294116, 0.5614274117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 157}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 178}], {
             RGBColor[
             0.9610704117647059, 0.8776436470588235, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.7254329117647058, 0.7567438823529412, 0.6552161764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 181}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 183}], {
             RGBColor[
             0.9610704117647059, 0.8776436470588235, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 185}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058825, 0.3026349705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 192}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.4275612941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 174}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529413, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 181}], {
             RGBColor[
             0.9479845294117646, 0.9605520000000001, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 185}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529413, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 164}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515699999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 166}], {
             RGBColor[
             0.8657571470588235, 0.8929822941176471, 0.8422104705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 170}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 197}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 167}], {
             RGBColor[
             0.9610704117647059, 0.8776436470588235, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 174}], {
             RGBColor[
             0.9285733529411765, 0.7545241764705882, 0.26138664705882353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 188}], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 175}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 176}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 187}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 193}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 199}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 180}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764707, 0.37162073529411777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 177}], {
             RGBColor[
             0.8787623235294117, 0.781568705882353, 0.6159916764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 166}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 184}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529413, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 187}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.8309585294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 184}], {
             RGBColor[
             0.8233546764705882, 0.7380637647058824, 0.6105275588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 181}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 188}], {
             RGBColor[
             0.9610704117647059, 0.8776436470588235, 0.31732720588235297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 172}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 173}], {
             RGBColor[
             0.9674696176470587, 0.9081338235294116, 0.5614274117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 184}], {
             RGBColor[
             0.9492098529411765, 0.8357399411764708, 0.5467351764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 198}], {
             RGBColor[
             0.9674696176470587, 0.9081338235294116, 0.5614274117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 200}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 190}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.8309585294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 195}], {
             RGBColor[
             0.9527160588235295, 0.8370488235294118, 0.47837732352941176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 197}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 173}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 178}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 183}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 196}], {
             RGBColor[
             0.9709758235294117, 0.9094427058823529, 0.49306955882352943`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 173}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 198}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 188}], {
             RGBColor[
             0.9285733529411765, 0.7545241764705882, 0.26138664705882353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 176}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.4275612941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 187}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 199}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 187}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 199}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.7185807941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 179}], {
             RGBColor[
             0.7111956176470589, 0.7060182941176469, 0.6139678529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 183}], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 183}], {
             RGBColor[
             0.7111956176470589, 0.7060182941176469, 0.6139678529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 185}], {
             RGBColor[
             0.6929358529411764, 0.633624411764706, 0.5992756176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 194}], {
             RGBColor[
             0.7111956176470589, 0.7060182941176469, 0.6139678529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 185}], {
             RGBColor[
             0.938695205882353, 0.828548411764706, 0.5936544705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 188}], {
             RGBColor[
             0.9569549705882352, 0.900942294117647, 0.608346705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 192}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235295, 0.7185807941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 191}], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 192}], {
             RGBColor[
             0.9699949999999999, 0.9073448235294117, 0.3863129705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 193}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 199}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 199}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 192}], {
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 195}], {
             RGBColor[
             0.6929358529411764, 0.633624411764706, 0.5992756176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 199}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764706, 0.8253373823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 197}], {
             RGBColor[
             0.9428106470588236, 0.8052497647058825, 0.3026349705882353]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.04749427504982855], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.04749427504982855], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.04749427504982855], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.04749427504982855], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.04749427504982855], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.04749427504982855], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.04749427504982855], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.04749427504982855], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.04749427504982855], {
             RGBColor[
             0.4755581176470588, 0.5851185294117647, 0.9518568235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.04749427504982855], {
             RGBColor[
             0.8772728823529412, 0.5356066470588235, 0.21930582352941178`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.04749427504982855], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.04749427504982855], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.04749427504982855], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.04749427504982855], {
             RGBColor[
             0.9103135882352942, 0.6821302941176473, 0.2466944117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.04749427504982855], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.04749427504982855], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.04749427504982855], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.04749427504982855], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.04749427504982855], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.04749427504982855], {
             RGBColor[
             0.8772728823529412, 0.5356066470588235, 0.21930582352941178`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.04749427504982855], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.04749427504982855], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.04749427504982855], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.04749427504982855], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.04749427504982855], {
             RGBColor[
             0.4755581176470588, 0.5851185294117647, 0.9518568235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.04749427504982855], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.04749427504982855], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.04749427504982855], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.04749427504982855], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.04749427504982855], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.04749427504982855], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.04749427504982855], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.04749427504982855], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.04749427504982855], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.04749427504982855], {
             RGBColor[
             0.9103135882352942, 0.6821302941176473, 0.2466944117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.04749427504982855], {
             RGBColor[
             0.8772728823529412, 0.5356066470588235, 0.21930582352941178`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.04749427504982855], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.04749427504982855], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.04749427504982855], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.04749427504982855], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.04749427504982855], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.04749427504982855], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.04749427504982855], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.04749427504982855], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.04749427504982855], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.04749427504982855], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.04749427504982855], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.04749427504982855], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.04749427504982855], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.04749427504982855], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.04749427504982855], {
             RGBColor[
             0.9103135882352942, 0.6821302941176473, 0.2466944117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.04749427504982855], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.04749427504982855], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.04749427504982855], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.04749427504982855], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.04749427504982855], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.04749427504982855], {
             RGBColor[
             0.4755581176470588, 0.5851185294117647, 0.9518568235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.04749427504982855], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.04749427504982855], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.04749427504982855], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.04749427504982855], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.04749427504982855], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.04749427504982855], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.04749427504982855], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.04749427504982855], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.04749427504982855], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.04749427504982855], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.04749427504982855], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.04749427504982855], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.04749427504982855], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.04749427504982855], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.04749427504982855], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.04749427504982855], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.04749427504982855], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.04749427504982855], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.04749427504982855], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.04749427504982855], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.04749427504982855], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.04749427504982855], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.04749427504982855], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.04749427504982855], {
             RGBColor[
             0.4755581176470588, 0.5851185294117647, 0.9518568235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.04749427504982855], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.04749427504982855], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.04749427504982855], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.04749427504982855], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.04749427504982855], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.04749427504982855], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.04749427504982855], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.04749427504982855], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.04749427504982855], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.04749427504982855], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.04749427504982855], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.04749427504982855], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.04749427504982855], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.04749427504982855], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.04749427504982855], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.04749427504982855], {
             RGBColor[
             0.9103135882352942, 0.6821302941176473, 0.2466944117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.04749427504982855], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.04749427504982855], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.04749427504982855], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.04749427504982855], {
             RGBColor[
             0.8772728823529412, 0.5356066470588235, 0.21930582352941178`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.04749427504982855], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.04749427504982855], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.04749427504982855], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.04749427504982855], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.04749427504982855], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.04749427504982855], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.04749427504982855], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.04749427504982855], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.04749427504982855], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.04749427504982855], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.04749427504982855], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.04749427504982855], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.04749427504982855], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.04749427504982855], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.04749427504982855], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.04749427504982855], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.04749427504982855], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.04749427504982855], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.04749427504982855], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.04749427504982855], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.04749427504982855], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.04749427504982855], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.04749427504982855], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.04749427504982855], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.04749427504982855], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.04749427504982855], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.04749427504982855], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.04749427504982855], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.04749427504982855], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.04749427504982855], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.04749427504982855], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.04749427504982855], {
             RGBColor[
             0.9103135882352942, 0.6821302941176473, 0.2466944117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.04749427504982855], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.04749427504982855], {
             RGBColor[
             0.4755581176470588, 0.5851185294117647, 0.9518568235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.04749427504982855], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.04749427504982855], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.04749427504982855], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.04749427504982855], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.04749427504982855], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.04749427504982855], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.04749427504982855], {
             RGBColor[
             0.9103135882352942, 0.6821302941176473, 0.2466944117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.04749427504982855], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.04749427504982855], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.04749427504982855], {
             RGBColor[
             0.8472110588235294, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.04749427504982855], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.04749427504982855], {
             RGBColor[
             0.4755581176470588, 0.5851185294117647, 0.9518568235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.04749427504982855], {
             RGBColor[
             0.9103135882352942, 0.6821302941176473, 0.2466944117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.04749427504982855], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.04749427504982855], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.04749427504982855], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.04749427504982855], {
             RGBColor[
             0.9103135882352942, 0.6821302941176473, 0.2466944117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.04749427504982855], {
             RGBColor[
             0.9103135882352942, 0.6821302941176473, 0.2466944117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.04749427504982855], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.04749427504982855], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.04749427504982855], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.04749427504982855], {
             RGBColor[
             0.4755581176470588, 0.5851185294117647, 0.9518568235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.04749427504982855], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.04749427504982855], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.04749427504982855], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.04749427504982855], {
             RGBColor[
             0.9103135882352942, 0.6821302941176473, 0.2466944117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.04749427504982855], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.04749427504982855], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.04749427504982855], {
             RGBColor[
             0.9468331176470588, 0.8269180588235292, 0.27607888235294115`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.04749427504982855], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.04749427504982855], {
             RGBColor[
             0.9670768235294117, 0.9749665294117648, 0.9406145294117647]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
          103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
          129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 
          142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 
          155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 
          168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 
          181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 
          194, 195, 196, 197, 198, 199, 200}, {Null, CompressedData["
1:eJwVxfk/GgwDAPA5ylXk6qBcTS9j5XjImZDN1UpNhz0LEUrEK0VRaK6QloU8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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[31, 80] -> 
             RGBColor[
              0.7352027165067365, 0.7929678458962808, 0.9744115778147804], 
             UndirectedEdge[36, 132] -> 
             RGBColor[
              0.24999710016017773`, 0.3800931813729572, 0.937548337065331], 
             UndirectedEdge[16, 101] -> 
             RGBColor[
              0.28740281094428266`, 0.4180946549568002, 0.9397266599229551], 
             UndirectedEdge[86, 108] -> 
             RGBColor[
              0.5865960904370586, 0.6714707671165345, 0.9625129589589009], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.3936636675304358, 0.5153934155287933, 0.9463048786852943], 
             UndirectedEdge[29, 136] -> 
             RGBColor[
              0.950824845750427, 0.8323116913697606, 0.49992668872926316`], 
             UndirectedEdge[55, 157] -> 
             RGBColor[
              0.4550334300726567, 0.5657150158349769, 0.9509982940305055], 
             UndirectedEdge[7, 188] -> 
             RGBColor[
              0.5075570604878807, 0.6079623494198335, 0.955381071984007], 
             UndirectedEdge[19, 141] -> 
             RGBColor[
              0.31187008513103276`, 0.44044798095241544`, 0.9412431829967022],
              UndirectedEdge[62, 185] -> 
             RGBColor[
              0.5629039980331934, 0.6514450489037454, 0.9607937355315148], 
             UndirectedEdge[79, 144] -> 
             RGBColor[
              0.5302420239491671, 0.38356267740113825`, 0.5683400240537216], 
             UndirectedEdge[47, 54] -> 
             RGBColor[
              0.3621640961349061, 0.48478721437619465`, 0.9444194198717641], 
             UndirectedEdge[32, 101] -> 
             RGBColor[
              0.2434980017964442, 0.3732622169260371, 0.9371782230280707], 
             UndirectedEdge[104, 163] -> 
             RGBColor[
              0.22597848605701326`, 0.35484809508244053`, 0.9361805125245111],
              UndirectedEdge[119, 125] -> 
             RGBColor[
              0.3719190998621983, 0.4815306199533135, 0.9461956553093709], 
             UndirectedEdge[9, 140] -> 
             RGBColor[
              0.2830352445403058, 0.4148183658558119, 0.9394298105122245], 
             UndirectedEdge[3, 63] -> 
             RGBColor[
              0.30825791983475437`, 0.437251051830131, 0.9410155180983026], 
             UndirectedEdge[50, 104] -> 
             RGBColor[
              0.2305835536607953, 0.3596883131121654, 0.9364427643119595], 
             UndirectedEdge[47, 61] -> 
             RGBColor[
              0.36265936899724993`, 0.48530777755663124`, 0.944447624928584], 
             UndirectedEdge[149, 195] -> 
             RGBColor[
              0.2062475040297809, 0.3341095819553035, 0.9350568622874322], 
             UndirectedEdge[99, 178] -> 
             RGBColor[
              0.7532636952500258, 0.8067917718917483, 0.970579392980242], 
             UndirectedEdge[160, 174] -> 
             RGBColor[
              0.37406119352792633`, 0.4984147377968103, 0.9450558263756417], 
             UndirectedEdge[6, 124] -> 
             RGBColor[
              0.3155531459350417, 0.4461023057398271, 0.9413876363800726], 
             UndirectedEdge[24, 197] -> 
             RGBColor[
              0.5339219982745609, 0.6098281505161249, 0.9613839453194717], 
             UndirectedEdge[80, 120] -> 
             RGBColor[
              0.7883329572883422, 0.7840663517109472, 0.6248876395864237], 
             UndirectedEdge[83, 187] -> 
             RGBColor[
              0.26933773838678554`, 0.40042141841641143`, 0.938649757800426], 
             UndirectedEdge[47, 167] -> 
             RGBColor[
              0.6833987505402253, 0.7503936163476059, 0.9708862787627], 
             UndirectedEdge[132, 150] -> 
             RGBColor[
              0.2675705658104447, 0.39856400799346436`, 0.938549119936501], 
             UndirectedEdge[17, 189] -> 
             RGBColor[
              0.23511483918268133`, 0.3644509814957634, 0.9367008143189947], 
             UndirectedEdge[69, 180] -> 
             RGBColor[
              0.5628268850068445, 0.6533109098577117, 0.9599708318719281], 
             UndirectedEdge[43, 95] -> 
             RGBColor[
              0.9174955939353169, 0.6847516692782425, 0.2880009042450533], 
             UndirectedEdge[82, 86] -> 
             RGBColor[
              0.3552790109161934, 0.48214655523847394`, 0.943859042308054], 
             UndirectedEdge[7, 61] -> 
             RGBColor[
              0.3121285679978709, 0.4415405374828739, 0.9412278469715365], 
             UndirectedEdge[30, 65] -> 
             RGBColor[
              0.9079204151899432, 0.9294151105020584, 0.9910794537825813], 
             UndirectedEdge[62, 174] -> 
             RGBColor[
              0.36882264112374896`, 0.4938773670016114, 0.9447220304487174], 
             UndirectedEdge[18, 47] -> 
             RGBColor[
              0.38494609227374893`, 0.5078426899995235, 0.9457494024985874], 
             UndirectedEdge[56, 149] -> 
             RGBColor[
              0.2062475040297809, 0.3341095819553035, 0.9350568622874322], 
             UndirectedEdge[82, 163] -> 
             RGBColor[
              0.2758102937038249, 0.40631356017084397`, 0.9390517136501494], 
             UndirectedEdge[10, 48] -> 
             RGBColor[
              0.30320935155036544`, 0.43524999752426985`, 0.940606985973867], 
             UndirectedEdge[58, 92] -> 
             RGBColor[
              0.24643437763355744`, 0.3763485341078243, 0.9373454452880156], 
             UndirectedEdge[70, 72] -> 
             RGBColor[
              0.23177582019152226`, 0.36094146083002354`, 0.936510662127084], 
             UndirectedEdge[35, 181] -> 
             RGBColor[
              0.9113516048559902, 0.930874079920538, 0.9469017763992353], 
             UndirectedEdge[126, 174] -> 
             RGBColor[
              0.3443177986809051, 0.472511876251829, 0.9431657526324266], 
             UndirectedEdge[108, 154] -> 
             RGBColor[
              0.8838800631396134, 0.9088604535486795, 0.9258833443185683], 
             UndirectedEdge[63, 77] -> 
             RGBColor[
              0.3266232709961202, 0.4565542003312445, 0.9420613976778401], 
             UndirectedEdge[32, 100] -> 
             RGBColor[
              0.22448297168171977`, 0.35327621465291903`, 0.9360953451932534],
              UndirectedEdge[19, 50] -> 
             RGBColor[
              0.2533169376668154, 0.3835825410822887, 0.9377373969000744], 
             UndirectedEdge[80, 81] -> 
             RGBColor[
              0.5981154418108365, 0.6846160863124545, 0.9615049850298553], 
             UndirectedEdge[34, 163] -> 
             RGBColor[
              0.24238504014097356`, 0.3720924236602928, 0.9371148415082708], 
             UndirectedEdge[146, 194] -> 
             RGBColor[
              0.5723118578420975, 0.6584672801449877, 0.9618699351638069], 
             UndirectedEdge[13, 83] -> 
             RGBColor[
              0.316923827731624, 0.4440344737616491, 0.9415941582521057], 
             UndirectedEdge[30, 41] -> 
             RGBColor[
              0.7217306402299773, 0.781717727178925, 0.9737111260908631], 
             UndirectedEdge[35, 111] -> 
             RGBColor[
              0.6494345587146366, 0.7234252020636741, 0.9675585260086426], 
             UndirectedEdge[29, 144] -> 
             RGBColor[
              0.9250794571034022, 0.713525377567732, 0.47838407771344216`], 
             UndirectedEdge[6, 12] -> 
             RGBColor[
              0.4620072235822212, 0.5710418605945535, 0.9516398014511775], 
             UndirectedEdge[67, 143] -> 
             RGBColor[
              0.8195020684542436, 0.15090702076601228`, 0.16630850881720677`],
              UndirectedEdge[135, 163] -> 
             RGBColor[
              0.2331505740140204, 0.36238641426189583`, 0.9365889523235094], 
             UndirectedEdge[50, 60] -> 
             RGBColor[
              0.24809478057534154`, 0.3780937228752663, 0.9374400027792041], 
             UndirectedEdge[25, 143] -> 
             RGBColor[
              0.8998599727872215, 0.550715470129439, 0.2700821840156026], 
             UndirectedEdge[12, 13] -> 
             RGBColor[
              0.4809809724952037, 0.58747596825463, 0.9528487919540853], 
             UndirectedEdge[89, 144] -> 
             RGBColor[
              0.8552540643843429, 0.4257125281092684, 0.20054466049597394`], 
             UndirectedEdge[22, 24] -> 
             RGBColor[
              0.511674430314928, 0.3239227222549723, 0.5618363636950766], 
             UndirectedEdge[107, 156] -> 
             RGBColor[
              0.7940373920785235, 0.8398425244747729, 0.979889552465069], 
             UndirectedEdge[23, 154] -> 
             RGBColor[
              0.9900533443030074, 0.9886857899175692, 0.707722631591383], 
             UndirectedEdge[101, 135] -> 
             RGBColor[
              0.2425616632808307, 0.3722780657788366, 0.9371248999347952], 
             UndirectedEdge[7, 42] -> 
             RGBColor[
              0.4359507962934013, 0.5501706892115099, 0.9495104580293312], 
             UndirectedEdge[122, 192] -> 
             RGBColor[
              0.9051286638748339, 0.560715561019076, 0.3184883695099363], 
             UndirectedEdge[129, 133] -> 
             RGBColor[
              0.9068437673391607, 0.5799440210010265, 0.2933645016769323], 
             UndirectedEdge[40, 80] -> 
             RGBColor[
              0.555739244439546, 0.6502131802605045, 0.9581689755436615], 
             UndirectedEdge[41, 172] -> 
             RGBColor[
              0.7718454040169196, 0.8174234076188627, 0.7717375932565325], 
             UndirectedEdge[94, 115] -> 
             RGBColor[
              0.34184068469654455`, 0.4665135495155001, 0.9431489820897013], 
             UndirectedEdge[87, 103] -> 
             RGBColor[
              0.9261326652649529, 0.7329765215094193, 0.5287146017248969], 
             UndirectedEdge[142, 160] -> 
             RGBColor[
              0.5038004126414563, 0.6056953348255233, 0.9547299040233275], 
             UndirectedEdge[21, 150] -> 
             RGBColor[
              0.29956418872733326`, 0.4315020124177601, 0.9403963488781741], 
             UndirectedEdge[29, 142] -> 
             RGBColor[
              0.8172660326623933, 0.855490432397475, 0.8599437218958297], 
             UndirectedEdge[67, 103] -> 
             RGBColor[
              0.8412482263097689, 0.30880018804606046`, 0.1867701602639753], 
             UndirectedEdge[50, 163] -> 
             RGBColor[
              0.23762722721084206`, 0.36709166060796167`, 0.9368438911004533],
              UndirectedEdge[21, 46] -> 
             RGBColor[
              0.4569720284859443, 0.5663064733841641, 0.9514223432183879], 
             UndirectedEdge[43, 129] -> 
             RGBColor[
              0.922812533415494, 0.7026869546216379, 0.30865621010577077`], 
             UndirectedEdge[11, 112] -> 
             RGBColor[
              0.2736557868068433, 0.4049599610859747, 0.9388956642699682], 
             UndirectedEdge[119, 195] -> 
             RGBColor[
              0.37190268566599016`, 0.4815133675923786, 0.9461947205451795], 
             UndirectedEdge[99, 109] -> 
             RGBColor[
              0.45081925257627997`, 0.561890841684138, 0.9507778651594582], 
             UndirectedEdge[45, 120] -> 
             RGBColor[
              0.9205644172331103, 0.7168104234407002, 0.25588752113131463`], 
             UndirectedEdge[29, 153] -> 
             RGBColor[
              0.7898065464682866, 0.8331975844693433, 0.8577820105552174], 
             UndirectedEdge[27, 125] -> 
             RGBColor[
              0.22785442897304503`, 0.35681983002884055`, 0.9362873446983702],
              UndirectedEdge[35, 157] -> 
             RGBColor[
              0.6980290555794366, 0.7628764037756551, 0.971384062809347], 
             UndirectedEdge[28, 112] -> 
             RGBColor[
              0.2981130439403854, 0.43066608901299275`, 0.9402884688824538], 
             UndirectedEdge[22, 89] -> 
             RGBColor[
              0.8492070454595947, 0.37923249083306454`, 0.194754028344504], 
             UndirectedEdge[96, 116] -> 
             RGBColor[
              0.3478897367236583, 0.4755106363355533, 0.9433968344585502], 
             UndirectedEdge[23, 143] -> 
             RGBColor[
              0.9071887956861127, 0.574773145865902, 0.35502905680889496`], 
             UndirectedEdge[6, 14] -> 
             RGBColor[
              0.37841229319367853`, 0.5021834416346569, 0.945333074598817], 
             UndirectedEdge[9, 112] -> 
             RGBColor[
              0.28100806217130603`, 0.41268766865520734`, 0.9393143654752576],
              UndirectedEdge[12, 25] -> 
             RGBColor[
              0.7814420691727634, 0.8068428114651084, 0.666502637240134], 
             UndirectedEdge[176, 199] -> 
             RGBColor[
              0.28324272218403285`, 0.4150364380142114, 0.9394416260570992], 
             UndirectedEdge[48, 112] -> 
             RGBColor[
              0.3092759955003079, 0.44162642496310195`, 0.9409524723720207], 
             UndirectedEdge[79, 149] -> 
             RGBColor[
              0.21876808015896437`, 0.34726950131745254`, 0.9357698905754568],
              UndirectedEdge[58, 155] -> 
             RGBColor[
              0.25688825427596124`, 0.3873362212730521, 0.9379407780976758], 
             UndirectedEdge[118, 138] -> 
             RGBColor[
              0.9130416014388392, 0.812801149295034, 0.6201343733156849], 
             UndirectedEdge[172, 173] -> 
             RGBColor[
              0.9945590642006376, 0.9907707134251852, 0.6491658996819889], 
             UndirectedEdge[53, 104] -> 
             RGBColor[
              0.21517354122831484`, 0.34349141299440844`, 0.9355651869010002],
              UndirectedEdge[179, 185] -> 
             RGBColor[
              0.7887535289716312, 0.8348995186722672, 0.9795792385132371], 
             UndirectedEdge[82, 176] -> 
             RGBColor[
              0.30639768237766407`, 0.4384628450195025, 0.9407936201851381], 
             UndirectedEdge[142, 181] -> 
             RGBColor[
              0.8126094756619291, 0.8535648264097266, 0.9371149221767408], 
             UndirectedEdge[54, 160] -> 
             RGBColor[
              0.3197591214680627, 0.448058156655773, 0.9417174123832397], 
             UndirectedEdge[121, 151] -> 
             RGBColor[
              0.4472759744708069, 0.5594034354051198, 0.9503913919352824], 
             UndirectedEdge[138, 144] -> 
             RGBColor[
              0.8846457857876004, 0.5636515837418983, 0.22521422842604885`], 
             UndirectedEdge[171, 196] -> 
             RGBColor[
              0.6848218020180831, 0.7518929600057571, 0.9706449762400708], 
             UndirectedEdge[120, 172] -> 
             RGBColor[
              0.9753727800277856, 0.9276792174007213, 0.4361680487899127], 
             UndirectedEdge[113, 159] -> 
             RGBColor[
              0.8614732788871635, 0.4076188795492328, 0.20391981602530412`], 
             UndirectedEdge[103, 108] -> 
             RGBColor[
              0.822761672378244, 0.6528409767770607, 0.5936514209828487], 
             UndirectedEdge[64, 176] -> 
             RGBColor[
              0.45839978276888355`, 0.5655229499724335, 0.9517490792275327], 
             UndirectedEdge[83, 101] -> 
             RGBColor[
              0.2538463417938609, 0.3841389783859738, 0.9377675456819266], 
             UndirectedEdge[15, 63] -> 
             RGBColor[
              0.33898161598962545`, 0.46803057088396705`, 0.9428205867145535],
              UndirectedEdge[55, 72] -> 
             RGBColor[
              0.3011292819316679, 0.4298018950317811, 0.9406079602011264], 
             UndirectedEdge[105, 142] -> 
             RGBColor[
              0.4920496854617956, 0.5955174455512221, 0.9539811580781995], 
             UndirectedEdge[96, 105] -> 
             RGBColor[
              0.32470350781154744`, 0.4554278902256328, 0.9419194284550477], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.3349775869314745, 0.46456248216214874`, 0.942565453523592], 
             UndirectedEdge[64, 108] -> 
             RGBColor[
              0.7019176077126746, 0.7667599945944428, 0.9711311636805353], 
             UndirectedEdge[56, 119] -> 
             RGBColor[
              0.37190268566599016`, 0.4815133675923786, 0.9461947205451795], 
             UndirectedEdge[68, 157] -> 
             RGBColor[
              0.7066548099945791, 0.7697543462064234, 0.9722067949657651], 
             UndirectedEdge[137, 161] -> 
             RGBColor[
              0.2794230248160247, 0.4110216938976339, 0.939224099942727], 
             UndirectedEdge[160, 188] -> 
             RGBColor[
              0.5156828868204164, 0.6150005317731692, 0.9558988424525301], 
             UndirectedEdge[127, 187] -> 
             RGBColor[
              0.3022073859943112, 0.43378220468743567`, 0.9405651083800737], 
             UndirectedEdge[41, 141] -> 
             RGBColor[
              0.4545263425380657, 0.5654922255819677, 0.9509061844081543], 
             UndirectedEdge[137, 175] -> 
             RGBColor[
              0.2852924893069724, 0.4161135758232565, 0.9395978023974743], 
             UndirectedEdge[1, 122] -> 
             RGBColor[
              0.9756254576616791, 0.9291724163168037, 0.38265572153063876`], 
             UndirectedEdge[60, 177] -> 
             RGBColor[
              0.273782020378095, 0.40509264057303096`, 0.9389028530851051], 
             UndirectedEdge[72, 75] -> 
             RGBColor[
              0.26701897159742227`, 0.39798424750248473`, 0.9385177074620799],
              UndirectedEdge[13, 69] -> 
             RGBColor[
              0.38979245396039097`, 0.512040364907272, 0.9460582083797908], 
             UndirectedEdge[48, 77] -> 
             RGBColor[
              0.30874838296909257`, 0.4410718707402281, 0.9409224256189008], 
             UndirectedEdge[22, 183] -> 
             RGBColor[
              0.8521661685690678, 0.3996097358148414, 0.1974949680494109], 
             UndirectedEdge[16, 86] -> 
             RGBColor[
              0.3574604388898408, 0.48403599850748935`, 0.9439980409695737], 
             UndirectedEdge[8, 62] -> 
             RGBColor[
              0.40221602470153694`, 0.5228010374564311, 0.9468498273216844], 
             UndirectedEdge[26, 51] -> 
             RGBColor[
              0.3392714220793772, 0.4658216765666159, 0.9429291222497664], 
             UndirectedEdge[117, 121] -> 
             RGBColor[
              0.6608369282647062, 0.733443073990961, 0.9678737418567172], 
             UndirectedEdge[89, 136] -> 
             RGBColor[
              0.8809994530313677, 0.5444988419112969, 0.222087271511795], 
             UndirectedEdge[81, 168] -> 
             RGBColor[
              0.7574630871375609, 0.8103278215593543, 0.974310777757218], 
             UndirectedEdge[172, 198] -> 
             RGBColor[
              0.8450687656775151, 0.8760452560467036, 0.7780654976273946], 
             UndirectedEdge[55, 68] -> 
             RGBColor[
              0.6040034340544339, 0.6836766872491769, 0.9648829517187356], 
             UndirectedEdge[156, 192] -> 
             RGBColor[
              0.869081373347711, 0.5369234121250193, 0.5782650463391841], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.3132800245584588, 0.44509451368492026`, 0.9412076055629822], 
             UndirectedEdge[25, 154] -> 
             RGBColor[
              0.9827245214041163, 0.9646281141811062, 0.6227757587980907], 
             UndirectedEdge[100, 135] -> 
             RGBColor[
              0.2235466331661063, 0.3522920635057185, 0.9360420220999779], 
             UndirectedEdge[37, 149] -> 
             RGBColor[
              0.21228087842813756`, 0.34045104098600754`, 0.9354004540338412],
              UndirectedEdge[125, 149] -> 
             RGBColor[
              0.206263918225989, 0.33412683431623835`, 0.9350577970516237], 
             UndirectedEdge[2, 184] -> 
             RGBColor[
              0.37412689727752746`, 0.49847164708234826`, 0.9450600129604667],
              UndirectedEdge[6, 16] -> 
             RGBColor[
              0.3315065479690632, 0.46155604267239897`, 0.9423442819902264], 
             UndirectedEdge[55, 111] -> 
             RGBColor[
              0.40643893320785657`, 0.5262638141229958, 0.9471727572298012], 
             UndirectedEdge[34, 50] -> 
             RGBColor[
              0.2469901077447556, 0.3769326416900177, 0.9373770932957193], 
             UndirectedEdge[56, 125] -> 
             RGBColor[
              0.17894341419620807`, 0.3054112523609348, 0.9335019347641915], 
             UndirectedEdge[98, 196] -> 
             RGBColor[
              0.7343309142909232, 0.7903956980318739, 0.9415812202273133], 
             UndirectedEdge[160, 167] -> 
             RGBColor[
              0.6409937758733817, 0.7136645586271843, 0.9681842712741754], 
             UndirectedEdge[22, 149] -> 
             RGBColor[
              0.5389949329250163, 0.35263830271808894`, 0.5633922259016595], 
             UndirectedEdge[147, 194] -> 
             RGBColor[
              0.41461252572283636`, 0.5327948903127648, 0.9478451176521548], 
             UndirectedEdge[83, 161] -> 
             RGBColor[
              0.28225365624559345`, 0.41399686700250915`, 0.9393853002150969],
              UndirectedEdge[34, 177] -> 
             RGBColor[
              0.27267734754750905`, 0.40393155938778236`, 0.9388399436016203],
              UndirectedEdge[70, 145] -> 
             RGBColor[
              0.2107154956867174, 0.33880572447377666`, 0.9353113078024935], 
             UndirectedEdge[125, 170] -> 
             RGBColor[
              0.18066259612527297`, 0.307218221570812, 0.93359983963175], 
             UndirectedEdge[190, 192] -> 
             RGBColor[
              0.4985130310330229, 0.22017044734510285`, 0.5488817116903315], 
             UndirectedEdge[122, 188] -> 
             RGBColor[
              0.8287961614327686, 0.8626280708354541, 0.7199844478872237], 
             UndirectedEdge[123, 130] -> 
             RGBColor[
              0.24382776690061642`, 0.3736088209588374, 0.9371970026629095], 
             UndirectedEdge[94, 116] -> 
             RGBColor[
              0.4038551160855868, 0.5242207360301667, 0.9469542687752844], 
             UndirectedEdge[23, 162] -> 
             RGBColor[
              0.9882402059749112, 0.9877215722762983, 0.728168038634343], 
             UndirectedEdge[116, 160] -> 
             RGBColor[
              0.3781472802574135, 0.5019539007492015, 0.9453161882088599], 
             UndirectedEdge[80, 117] -> 
             RGBColor[
              0.699447709361209, 0.7647890454809683, 0.9709133239805854], 
             UndirectedEdge[147, 185] -> 
             RGBColor[
              0.625134594396598, 0.7046026904109504, 0.9649644103506239], 
             UndirectedEdge[55, 107] -> 
             RGBColor[
              0.5098065457970684, 0.609801290788619, 0.955570731517623], 
             UndirectedEdge[111, 174] -> 
             RGBColor[
              0.4209532104070455, 0.5388353515241499, 0.9480975941384622], 
             UndirectedEdge[126, 142] -> 
             RGBColor[
              0.47405701779443504`, 0.579792473280542, 0.9528398302801124], 
             UndirectedEdge[115, 160] -> 
             RGBColor[
              0.31613284886837134`, 0.44424671423453505`, 0.9415109015232768],
              UndirectedEdge[74, 164] -> 
             RGBColor[
              0.29875283098362904`, 0.4313385457602833, 0.9403249038080864], 
             UndirectedEdge[42, 97] -> 
             RGBColor[
              0.401201459999004, 0.517503689481011, 0.9473903200062829], 
             UndirectedEdge[25, 108] -> 
             RGBColor[
              0.8800770451068233, 0.8847917621519991, 0.6757220357685101], 
             UndirectedEdge[67, 133] -> 
             RGBColor[
              0.820816769260137, 0.16101238726567596`, 0.16756746779367254`], 
             UndirectedEdge[38, 183] -> 
             RGBColor[
              0.9123593760428652, 0.674860106009205, 0.26130271158407675`], 
             UndirectedEdge[33, 41] -> 
             RGBColor[
              0.4363770738073567, 0.5497722412161976, 0.9497497290534018], 
             UndirectedEdge[32, 123] -> 
             RGBColor[
              0.24279155375346242`, 0.3725196952414703, 0.9371379918571192], 
             UndirectedEdge[61, 116] -> 
             RGBColor[
              0.3316898960628568, 0.4584835766718288, 0.9424742774984342], 
             UndirectedEdge[93, 134] -> 
             RGBColor[
              0.2274998629101822, 0.35644715861598486`, 0.9362671526856237], 
             UndirectedEdge[45, 128] -> 
             RGBColor[
              0.8869707508914968, 0.5796424030976618, 0.22739796275449303`], 
             UndirectedEdge[29, 35] -> 
             RGBColor[
              0.9160081618564544, 0.9327996859082862, 0.8697305761183244], 
             UndirectedEdge[3, 106] -> 
             RGBColor[
              0.26935764073949675`, 0.40044233705099297`, 0.93865089120997], 
             UndirectedEdge[77, 140] -> 
             RGBColor[
              0.3029488619339533, 0.43574884033280226`, 0.9405638615632359], 
             UndirectedEdge[79, 195] -> 
             RGBColor[
              0.1914475761291835, 0.31855391936214905`, 0.9342140282880245], 
             UndirectedEdge[38, 46] -> 
             RGBColor[
              0.7812753615379626, 0.7886327284729578, 0.6396314180362879], 
             UndirectedEdge[14, 59] -> 
             RGBColor[
              0.43278883650636024`, 0.549281670407568, 0.9487978998554119], 
             UndirectedEdge[126, 191] -> 
             RGBColor[
              0.2937278856939699, 0.4260570096609187, 0.9400387406075807], 
             UndirectedEdge[13, 64] -> 
             RGBColor[
              0.5003009692996179, 0.6031608120163909, 0.9543697328740091], 
             UndirectedEdge[3, 11] -> 
             RGBColor[
              0.2547628231142621, 0.3851022583619874, 0.9378197379373108], 
             UndirectedEdge[31, 98] -> 
             RGBColor[
              0.9119983758560902, 0.9316922814327566, 0.9576824339727095], 
             UndirectedEdge[25, 162] -> 
             RGBColor[
              0.9809113830760201, 0.9636638965398352, 0.6432211658410507], 
             UndirectedEdge[126, 157] -> 
             RGBColor[
              0.43245489742186133`, 0.5460179978079216, 0.9495647589707952], 
             UndirectedEdge[128, 183] -> 
             RGBColor[
              0.8747459970096212, 0.524132650883874, 0.217197328459318], 
             UndirectedEdge[22, 192] -> 
             RGBColor[
              0.8308704288952353, 0.23828922076278541`, 0.17719486361422723`],
              UndirectedEdge[99, 194] -> 
             RGBColor[
              0.45631234328201786`, 0.5666486807626816, 0.9511278800418784], 
             UndirectedEdge[21, 151] -> 
             RGBColor[
              0.33403902527338425`, 0.46374954722739153`, 0.9425056492046759],
              UndirectedEdge[48, 59] -> 
             RGBColor[
              0.382953798860026, 0.5061170655801353, 0.9456224553239809], 
             UndirectedEdge[18, 115] -> 
             RGBColor[
              0.2919621879503136, 0.4233113026000546, 0.9399707683828544], 
             UndirectedEdge[29, 89] -> 
             RGBColor[
              0.9238176258477779, 0.703826389599022, 0.47717574667802176`], 
             UndirectedEdge[15, 140] -> 
             RGBColor[
              0.31530720692745856`, 0.4472252108855248, 0.9413230505999493], 
             UndirectedEdge[113, 136] -> 
             RGBColor[
              0.9041543846818847, 0.6565805366270306, 0.24168008890791598`], 
             UndirectedEdge[111, 160] -> 
             RGBColor[
              0.41360379540408243`, 0.5324696576409218, 0.9476292959133059], 
             UndirectedEdge[116, 188] -> 
             RGBColor[
              0.5271183885528666, 0.6249053886087885, 0.9566275025109046], 
             UndirectedEdge[82, 127] -> 
             RGBColor[
              0.32009303423134106`, 0.45167023073266444`, 0.9416170229874327],
              UndirectedEdge[25, 95] -> 
             RGBColor[
              0.9792736576371948, 0.9417473218129542, 0.37398250307217895`], 
             UndirectedEdge[62, 111] -> 
             RGBColor[
              0.40836524299990506`, 0.527932286845723, 0.9472954999863816], 
             UndirectedEdge[162, 180] -> 
             RGBColor[
              0.853484717444914, 0.8855675982797966, 0.9434799440471393], 
             UndirectedEdge[89, 159] -> 
             RGBColor[
              0.8383183472366464, 0.29553718483349917`, 0.18432699862918317`],
              UndirectedEdge[7, 153] -> 
             RGBColor[
              0.46821510011481404`, 0.5763643045440561, 0.9520504222141921], 
             UndirectedEdge[146, 183] -> 
             RGBColor[
              0.8280025050148025, 0.648701197553076, 0.5925645649142633], 
             UndirectedEdge[144, 197] -> 
             RGBColor[
              0.8727164446748519, 0.6748369070629272, 0.5955099410043194], 
             UndirectedEdge[120, 128] -> 
             RGBColor[
              0.9231751810131911, 0.7286652920066743, 0.2580660064250903], 
             UndirectedEdge[74, 166] -> 
             RGBColor[
              0.34685352759081295`, 0.47429746798031186`, 0.9433423658444682],
              UndirectedEdge[147, 152] -> 
             RGBColor[
              0.3812177118441309, 0.5013730508472783, 0.9458086544862003], 
             UndirectedEdge[22, 190] -> 
             RGBColor[
              0.5120644599282582, 0.3243326681078883, 0.5618585753045587], 
             UndirectedEdge[27, 128] -> 
             RGBColor[
              0.5831652721126257, 0.49985421349972364`, 0.5843241339583132], 
             UndirectedEdge[47, 88] -> 
             RGBColor[
              0.5818581666070413, 0.6702991325141743, 0.9609700518092634], 
             UndirectedEdge[69, 177] -> 
             RGBColor[
              0.3475961861623531, 0.47409235374214537`, 0.9434207502916752], 
             UndirectedEdge[122, 167] -> 
             RGBColor[
              0.9541070504857341, 0.9612920976894692, 0.7322698767088691], 
             UndirectedEdge[1, 78] -> 
             RGBColor[
              0.9431385588038124, 0.9082192270955545, 0.6427719916956993], 
             UndirectedEdge[138, 159] -> 
             RGBColor[
              0.8677100686399041, 0.4334762404661291, 0.20899656655925808`], 
             UndirectedEdge[101, 127] -> 
             RGBColor[
              0.28671598940138643`, 0.417499764656998, 0.9396828962615742], 
             UndirectedEdge[65, 90] -> 
             RGBColor[
              0.6550212395891795, 0.7255799866641114, 0.9691860218299977], 
             UndirectedEdge[64, 127] -> 
             RGBColor[
              0.4720951346225606, 0.5787303356855954, 0.9525724820298272], 
             UndirectedEdge[117, 146] -> 
             RGBColor[
              0.7875464410912392, 0.8339565324458974, 0.9794589272741974], 
             UndirectedEdge[49, 103] -> 
             RGBColor[
              0.8495141808128409, 0.372335936521032, 0.19468564763117746`], 
             UndirectedEdge[88, 113] -> 
             RGBColor[
              0.8062483508925926, 0.7076340176229743, 0.6052352623718941], 
             UndirectedEdge[13, 176] -> 
             RGBColor[
              0.3360981234854725, 0.4641878743195114, 0.9426861060294587], 
             UndirectedEdge[17, 112] -> 
             RGBColor[
              0.27014379762534146`, 0.4012686377832412, 0.938695661681604], 
             UndirectedEdge[129, 170] -> 
             RGBColor[
              0.5863125273607737, 0.6439068649740138, 0.6751789886764388], 
             UndirectedEdge[35, 116] -> 
             RGBColor[
              0.6139780435679677, 0.6929094451719539, 0.9652454183041966], 
             UndirectedEdge[69, 110] -> 
             RGBColor[
              0.503306311820726, 0.6062411074789984, 0.9544293736590629], 
             UndirectedEdge[47, 126] -> 
             RGBColor[
              0.37937335834478547`, 0.5028752400890226, 0.9453994618957948], 
             UndirectedEdge[83, 137] -> 
             RGBColor[
              0.2530177140174724, 0.383268038054954, 0.9377203565559061], 
             UndirectedEdge[72, 84] -> 
             RGBColor[
              0.256326539038239, 0.386745822943403, 0.9379087892458708], 
             UndirectedEdge[22, 37] -> 
             RGBColor[
              0.517707803293592, 0.3302641797934895, 0.5621799553606361], 
             UndirectedEdge[90, 141] -> 
             RGBColor[
              0.37364371183420664`, 0.49805313613695035`, 0.9450292248112824],
              UndirectedEdge[24, 79] -> 
             RGBColor[
              0.1914475775488761, 0.318553920854336, 0.9342140283688739], 
             UndirectedEdge[34, 130] -> 
             RGBColor[
              0.2444860062107015, 0.3743006722085195, 0.9372344884178412], 
             UndirectedEdge[157, 174] -> 
             RGBColor[
              0.4695477072718456, 0.5782865532361309, 0.9519231309391665], 
             UndirectedEdge[131, 180] -> 
             RGBColor[
              0.811663417266584, 0.70990288285835, 0.6053916520008711], 
             UndirectedEdge[3, 48] -> 
             RGBColor[
              0.29038303180772673`, 0.42176872223911466`, 0.9398765460393633],
              UndirectedEdge[49, 67] -> 
             RGBColor[
              0.8264716492084423, 0.20447827253254375`, 0.17298258721844303`],
              UndirectedEdge[79, 190] -> 
             RGBColor[
              0.19183760716220638`, 0.3189638667072519, 0.9342362399783559], 
             UndirectedEdge[13, 82] -> 
             RGBColor[
              0.34829886890839834`, 0.4761007070634601, 0.9434142738316145], 
             UndirectedEdge[68, 138] -> 
             RGBColor[
              0.8842002449557951, 0.7898038345132208, 0.6173834589873493], 
             UndirectedEdge[153, 160] -> 
             RGBColor[
              0.4763409264473496, 0.5834024868973917, 0.9525681926827152], 
             UndirectedEdge[178, 183] -> 
             RGBColor[
              0.9011711841429679, 0.7066772038250902, 0.5935750920582745], 
             UndirectedEdge[2, 166] -> 
             RGBColor[
              0.3840226301972896, 0.5070428335634479, 0.9456905603116609], 
             UndirectedEdge[32, 53] -> 
             RGBColor[
              0.2232819677009355, 0.3520138833210643, 0.9360269497932738], 
             UndirectedEdge[26, 184] -> 
             RGBColor[
              0.38376793461067366`, 0.5068222290476936, 0.9456743313341002], 
             UndirectedEdge[61, 115] -> 
             RGBColor[
              0.2696754646738146, 0.40077639015716227`, 0.938668990812851], 
             UndirectedEdge[146, 178] -> 
             RGBColor[
              0.8692632098101054, 0.8986103712740543, 0.9813214481021706], 
             UndirectedEdge[88, 102] -> 
             RGBColor[
              0.5430147651889159, 0.6366549305319157, 0.9584949846187718], 
             UndirectedEdge[118, 159] -> 
             RGBColor[
              0.8679759941435095, 0.5543857383553449, 0.5804554745542396], 
             UndirectedEdge[62, 75] -> 
             RGBColor[
              0.3201980535903144, 0.44948818207116104`, 0.9417069408010099], 
             UndirectedEdge[89, 197] -> 
             RGBColor[
              0.8714546134192276, 0.6651379190942172, 0.5943016099688991], 
             UndirectedEdge[85, 146] -> 
             RGBColor[
              0.578124805971577, 0.6635021636474746, 0.9622403310784291], 
             UndirectedEdge[170, 190] -> 
             RGBColor[
              0.1810362129620878, 0.3076109165549801, 0.93362111655789], 
             UndirectedEdge[82, 101] -> 
             RGBColor[
              0.2852213829706352, 0.4162052116877847, 0.9395876612614353], 
             UndirectedEdge[7, 73] -> 
             RGBColor[
              0.3217974307185043, 0.4517031252435637, 0.941778474399676], 
             UndirectedEdge[19, 34] -> 
             RGBColor[
              0.25807475059694696`, 0.38858330413461983`, 0.938008347307892], 
             UndirectedEdge[56, 170] -> 
             RGBColor[
              0.1806461819290649, 0.30720096920987716`, 0.9335989048675586], 
             UndirectedEdge[32, 187] -> 
             RGBColor[
              0.2589893983893689, 0.38954465695647483`, 0.9380604351465702], 
             UndirectedEdge[74, 169] -> 
             RGBColor[
              0.28768269698087445`, 0.4197031330363533, 0.9396944760534252], 
             UndirectedEdge[55, 147] -> 
             RGBColor[
              0.41653896028796467`, 0.5344634711076623, 0.9479678683591656], 
             UndirectedEdge[49, 143] -> 
             RGBColor[
              0.8277680229573157, 0.2144427692409838, 0.17422399618440892`], 
             UndirectedEdge[28, 77] -> 
             RGBColor[
              0.29758543140917015`, 0.4301115347901189, 0.9402584221293339], 
             UndirectedEdge[122, 153] -> 
             RGBColor[
              0.7894542010597019, 0.8310300259596766, 0.7166537981174088], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.45346195936104267`, 0.5636403822236367, 0.9510953047712845], 
             UndirectedEdge[16, 199] -> 
             RGBColor[
              0.29762489558060606`, 0.42883871402717555`, 0.9403087925207747],
              UndirectedEdge[64, 180] -> 
             RGBColor[
              0.6733354003460714, 0.7444313569668306, 0.9682823563661463], 
             UndirectedEdge[38, 128] -> 
             RGBColor[
              0.9271948937048214, 0.742224726788967, 0.2736818311730274], 
             UndirectedEdge[46, 98] -> 
             RGBColor[
              0.7856154181292234, 0.8320307685883754, 0.9456185242307917], 
             UndirectedEdge[68, 142] -> 
             RGBColor[
              0.7482569303671527, 0.8035288216790438, 0.9754818662750824], 
             UndirectedEdge[5, 20] -> 
             RGBColor[
              0.2538041540046914, 0.3840946363446963, 0.9377651431497445], 
             UndirectedEdge[169, 200] -> 
             RGBColor[
              0.2545855584826314, 0.3849159419949167, 0.9378096429787789], 
             UndirectedEdge[27, 133] -> 
             RGBColor[
              0.5500884366842889, 0.29464670290479555`, 0.5545698278022309], 
             UndirectedEdge[32, 135] -> 
             RGBColor[
              0.23421532693659433`, 0.36350553709275546`, 0.9366495884272892],
              UndirectedEdge[144, 190] -> 
             RGBColor[
              0.5181114788530065, 0.37081270538409206`, 0.5676492074560286], 
             UndirectedEdge[62, 126] -> 
             RGBColor[
              0.33172983127376465`, 0.4616088115734021, 0.9423636584803461], 
             UndirectedEdge[55, 62] -> 
             RGBColor[
              0.35430836392456, 0.4813058296004574, 0.9437971935400564], 
             UndirectedEdge[62, 76] -> 
             RGBColor[
              0.3162924905225524, 0.44538318765994256`, 0.9414845247620637], 
             UndirectedEdge[157, 181] -> 
             RGBColor[
              0.7710073552893554, 0.8197903509371063, 0.9338398508674235], 
             UndirectedEdge[64, 82] -> 
             RGBColor[
              0.4706005281918093, 0.5774357827163821, 0.9524772470296884], 
             UndirectedEdge[142, 153] -> 
             RGBColor[
              0.6134295605638427, 0.6970487778093326, 0.9627105685555573], 
             UndirectedEdge[21, 109] -> 
             RGBColor[
              0.32687230511240406`, 0.45754209443377936`, 0.9420489921333002],
              UndirectedEdge[66, 198] -> 
             RGBColor[
              0.6938904051885131, 0.7607917253864516, 0.97012416888083], 
             UndirectedEdge[141, 198] -> 
             RGBColor[
              0.5277497041986612, 0.6241140740098087, 0.9572340887790165], 
             UndirectedEdge[10, 28] -> 
             RGBColor[
              0.292046399990443, 0.42428966157416065`, 0.9399429824843], 
             UndirectedEdge[31, 151] -> 
             RGBColor[
              0.6011924048521665, 0.6814178617192261, 0.9646228375029955], 
             UndirectedEdge[111, 142] -> 
             RGBColor[
              0.5506924295205754, 0.6461159485528629, 0.957771671786148], 
             UndirectedEdge[111, 181] -> 
             RGBColor[
              0.7224128584245553, 0.7803391492251253, 0.9300143140667192], 
             UndirectedEdge[86, 101] -> 
             RGBColor[
              0.3219019660862388, 0.44797608916280746`, 0.9419249155821955], 
             UndirectedEdge[119, 144] -> 
             RGBColor[
              0.7106971334859737, 0.5465221256313679, 0.5803207163108766], 
             UndirectedEdge[5, 102] -> 
             RGBColor[
              0.32802099544168023`, 0.45608332647208405`, 0.9422120278540836],
              UndirectedEdge[157, 185] -> 
             RGBColor[
              0.6636290641812901, 0.7358542351382649, 0.9679948360219639], 
             UndirectedEdge[13, 110] -> 
             RGBColor[
              0.49151316787654187`, 0.5960264789351953, 0.9536779249552072], 
             UndirectedEdge[32, 82] -> 
             RGBColor[
              0.27687504662639884`, 0.4074326830017036, 0.9391123497539292], 
             UndirectedEdge[12, 23] -> 
             RGBColor[
              0.7887708920716545, 0.8309004872015715, 0.7514495100334264], 
             UndirectedEdge[53, 130] -> 
             RGBColor[
              0.22431818084808952`, 0.35310300903843134`, 0.9360859605990643],
              UndirectedEdge[74, 80] -> 
             RGBColor[
              0.46133983359188224`, 0.5689367397653611, 0.9518870537804123], 
             UndirectedEdge[35, 185] -> 
             RGBColor[
              0.8039733137479249, 0.8469379641216965, 0.9810567615537757], 
             UndirectedEdge[117, 196] -> 
             RGBColor[
              0.6370858970808988, 0.7141609169041846, 0.966003973679034], 
             UndirectedEdge[22, 181] -> 
             RGBColor[
              0.9143758811781899, 0.66511973430378, 0.5497646458428832], 
             UndirectedEdge[143, 197] -> 
             RGBColor[
              0.8548577179564267, 0.5375669077611642, 0.5784084041302087], 
             UndirectedEdge[16, 124] -> 
             RGBColor[
              0.3070078817138632, 0.43870082736891025`, 0.9408431397001796], 
             UndirectedEdge[182, 191] -> 
             RGBColor[
              0.2726772055917506, 0.4039314101832797, 0.9388399355174497], 
             UndirectedEdge[98, 146] -> 
             RGBColor[
              0.8847914583012635, 0.9101913135735867, 0.9550361738224766], 
             UndirectedEdge[156, 183] -> 
             RGBColor[
              0.8903771130215434, 0.6982439271770752, 0.5985651507743678], 
             UndirectedEdge[6, 13] -> 
             RGBColor[
              0.35902556110322426`, 0.48539162870339236`, 0.9440977691730272],
              UndirectedEdge[50, 100] -> 
             RGBColor[
              0.2280232863629279, 0.35699730985178435`, 0.9362969608769219], 
             UndirectedEdge[13, 175] -> 
             RGBColor[
              0.34919860302112393`, 0.4768800115299515, 0.9434716040936737], 
             UndirectedEdge[62, 116] -> 
             RGBColor[
              0.37290872785323614`, 0.4974165299540027, 0.9449823922819357], 
             UndirectedEdge[120, 171] -> 
             RGBColor[
              0.9156195043648556, 0.8842880492213061, 0.6372222517571104], 
             UndirectedEdge[72, 139] -> 
             RGBColor[
              0.24951735884561907`, 0.3795889428339999, 0.9375210165071806], 
             UndirectedEdge[6, 83] -> 
             RGBColor[
              0.29795007881864144`, 0.4276003661015726, 0.9403851677491978], 
             UndirectedEdge[118, 190] -> 
             RGBColor[
              0.5465072945042451, 0.6199622709372278, 0.9625693523456647], 
             UndirectedEdge[36, 200] -> 
             RGBColor[
              0.24218408124275126`, 0.3718812031167312, 0.9371033971963092], 
             UndirectedEdge[16, 161] -> 
             RGBColor[
              0.3158101253960152, 0.4479525435733356, 0.9413444144561256], 
             UndirectedEdge[2, 169] -> 
             RGBColor[
              0.3248517995873511, 0.4524484986194894, 0.942042670520618], 
             UndirectedEdge[107, 111] -> 
             RGBColor[
              0.5638634248724134, 0.6564277480338845, 0.9590690379639482], 
             UndirectedEdge[127, 180] -> 
             RGBColor[
              0.5228279063856032, 0.618665804983113, 0.9574221323238906], 
             UndirectedEdge[138, 156] -> 
             RGBColor[
              0.9168097113153278, 0.8158057378279282, 0.6204937789995357], 
             UndirectedEdge[72, 93] -> 
             RGBColor[
              0.23701205160573985`, 0.3664450720426131, 0.9368088577598136], 
             UndirectedEdge[137, 187] -> 
             RGBColor[
              0.2665071069572168, 0.39744624531153616`, 0.938488557528056], 
             UndirectedEdge[40, 121] -> 
             RGBColor[
              0.5171284633430432, 0.6188672087704971, 0.9551293934197934], 
             UndirectedEdge[98, 178] -> 
             RGBColor[
              0.957960137429429, 0.968167319845601, 0.9560467009664877], 
             UndirectedEdge[10, 186] -> 
             RGBColor[
              0.28567319780598677`, 0.4175910219939398, 0.939580038048203], 
             UndirectedEdge[63, 91] -> 
             RGBColor[
              0.5953350475574752, 0.6767809281925967, 0.9640487060966569], 
             UndirectedEdge[125, 195] -> 
             RGBColor[
              0.17894341419620807`, 0.3054112523609348, 0.9335019347641915], 
             UndirectedEdge[86, 180] -> 
             RGBColor[
              0.5580138830704554, 0.6491421294889225, 0.9596641516445119], 
             UndirectedEdge[137, 186] -> 
             RGBColor[
              0.2661087370017966, 0.3970275332302755, 0.9384658709484304], 
             UndirectedEdge[33, 44] -> 
             RGBColor[
              0.3032320659672701, 0.4347249229295589, 0.9406283792341544], 
             UndirectedEdge[14, 193] -> 
             RGBColor[
              0.36672963099697153`, 0.49206450682754455`, 0.9445886656942154],
              UndirectedEdge[11, 28] -> 
             RGBColor[
              0.2703195386510599, 0.4014533527438959, 0.9387056698730332], 
             UndirectedEdge[85, 151] -> 
             RGBColor[
              0.35601576258697687`, 0.48278469250549083`, 0.9439059874730323],
              UndirectedEdge[175, 199] -> 
             RGBColor[
              0.2963432017196842, 0.4277285752246516, 0.9402271241213142], 
             UndirectedEdge[146, 196] -> 
             RGBColor[
              0.6456339866715997, 0.7208387494603272, 0.9668559673629961], 
             UndirectedEdge[20, 77] -> 
             RGBColor[
              0.2628976545910799, 0.3936524820222284, 0.9382830045555108], 
             UndirectedEdge[27, 56] -> 
             RGBColor[
              0.22783801477683696`, 0.3568025776679057, 0.9362864099341788], 
             UndirectedEdge[101, 175] -> 
             RGBColor[
              0.2861211170833608, 0.41698451615427623`, 0.9396449915234946], 
             UndirectedEdge[21, 85] -> 
             RGBColor[
              0.3381783439476214, 0.46733481701480994`, 0.9427694029303426], 
             UndirectedEdge[150, 194] -> 
             RGBColor[
              0.31572797791144636`, 0.44550227419337246`, 0.9414262912319082],
              UndirectedEdge[61, 160] -> 
             RGBColor[
              0.3202543943304065, 0.44857871983620956`, 0.9417456174400596], 
             UndirectedEdge[24, 149] -> 
             RGBColor[
              0.20624750544947348`, 0.3341095834474904, 0.9350568623682817], 
             UndirectedEdge[14, 186] -> 
             RGBColor[
              0.34940158280640243`, 0.47458578186823513`, 0.9435749780704197],
              UndirectedEdge[111, 126] -> 
             RGBColor[
              0.3838604005570612, 0.5065667960959406, 0.9457392221700909], 
             UndirectedEdge[35, 88] -> 
             RGBColor[
              0.775283955250752, 0.8245256192165048, 0.9781972744160757], 
             UndirectedEdge[94, 111] -> 
             RGBColor[
              0.43931163123225564`, 0.554736492921887, 0.9492673764797304], 
             UndirectedEdge[133, 162] -> 
             RGBColor[
              0.903164553297809, 0.5839253103845123, 0.5419478585850865], 
             UndirectedEdge[124, 199] -> 
             RGBColor[
              0.2816714935465845, 0.4133849770946037, 0.939352146910621], 
             UndirectedEdge[54, 105] -> 
             RGBColor[
              0.3080083942884021, 0.4378802673814718, 0.9409686664381117], 
             UndirectedEdge[64, 162] -> 
             RGBColor[
              0.8027519456818715, 0.845632128982279, 0.9386302937530759], 
             UndirectedEdge[57, 66] -> 
             RGBColor[
              0.5260989516337345, 0.6228771288818142, 0.9570472794276266], 
             UndirectedEdge[16, 137] -> 
             RGBColor[
              0.2865741831678942, 0.41722371462578045`, 0.9396794707969347], 
             UndirectedEdge[44, 50] -> 
             RGBColor[
              0.2628281872337618, 0.3935794674252022, 0.9382790484922793], 
             UndirectedEdge[153, 167] -> 
             RGBColor[
              0.7506229237957682, 0.8050180016109936, 0.9761649358064053], 
             UndirectedEdge[165, 187] -> 
             RGBColor[
              0.2508650284302595, 0.38100542901464385`, 0.9375977642963274], 
             UndirectedEdge[32, 83] -> 
             RGBColor[
              0.2455000054496245, 0.37536644969989263`, 0.9372922341744203], 
             UndirectedEdge[6, 187] -> 
             RGBColor[
              0.3114394717583858, 0.44177857335815474`, 0.9411533687213477], 
             UndirectedEdge[66, 141] -> 
             RGBColor[
              0.5254792907329107, 0.622340409754583, 0.9570077951829706], 
             UndirectedEdge[23, 87] -> 
             RGBColor[
              0.9907768608924232, 0.9889849826208208, 0.6957320893038507], 
             UndirectedEdge[85, 152] -> 
             RGBColor[
              0.320947319253029, 0.44991323932493577`, 0.9417628821181223], 
             UndirectedEdge[26, 74] -> 
             RGBColor[
              0.3495927399015075, 0.4766700360070217, 0.9435169060307154], 
             UndirectedEdge[81, 172] -> 
             RGBColor[
              0.7851552645502801, 0.8282289520022286, 0.7727853942333442], 
             UndirectedEdge[54, 73] -> 
             RGBColor[
              0.28297059999413937`, 0.41475042033909004`, 0.9394261291009534],
              UndirectedEdge[135, 165] -> 
             RGBColor[
              0.22609095697748494`, 0.3549663091509244, 0.9361869175770461], 
             UndirectedEdge[46, 109] -> 
             RGBColor[
              0.4676427269643195, 0.5755488960812328, 0.9521022706897019], 
             UndirectedEdge[40, 171] -> 
             RGBColor[
              0.6830257915160596, 0.7504348777708634, 0.9705035877143484], 
             UndirectedEdge[113, 167] -> 
             RGBColor[
              0.9077889348257765, 0.7877285014564059, 0.6151514893253305], 
             UndirectedEdge[103, 162] -> 
             RGBColor[
              0.9235960103474408, 0.7317131111648968, 0.5611505510553894], 
             UndirectedEdge[37, 119] -> 
             RGBColor[
              0.3779360600643469, 0.4878548266230827, 0.9465383122915882], 
             UndirectedEdge[71, 184] -> 
             RGBColor[
              0.3307081584442233, 0.45915751757499346`, 0.9423559109556644], 
             UndirectedEdge[107, 142] -> 
             RGBColor[
              0.6540600421097872, 0.7296534252184859, 0.9661696460739697], 
             UndirectedEdge[136, 143] -> 
             RGBColor[
              0.8644025575685669, 0.416927830578244, 0.20619406567310455`], 
             UndirectedEdge[3, 5] -> 
             RGBColor[
              0.27293521528598386`, 0.4042025947306783, 0.9388546287878452], 
             UndirectedEdge[24, 118] -> 
             RGBColor[
              0.5461172648909147, 0.6195523250843118, 0.9625471407361825], 
             UndirectedEdge[142, 185] -> 
             RGBColor[
              0.7052311845538637, 0.7696287106108853, 0.971269907331281], 
             UndirectedEdge[3, 28] -> 
             RGBColor[
              0.2792200802478043, 0.4108083862890054, 0.9392125425497964], 
             UndirectedEdge[43, 49] -> 
             RGBColor[
              0.8450514898395424, 0.34729106936125886`, 0.19077466358971318`],
              UndirectedEdge[19, 60] -> 
             RGBColor[
              0.25917942342753286`, 0.38974438531986844`, 0.9380712567913769],
              UndirectedEdge[87, 110] -> 
             RGBColor[
              0.7965007991763076, 0.8397612062456058, 0.9055025365037817], 
             UndirectedEdge[107, 185] -> 
             RGBColor[
              0.7184021799057017, 0.779940510091907, 0.9725672735090811], 
             UndirectedEdge[66, 81] -> 
             RGBColor[
              0.633976904061278, 0.7129754213419766, 0.9648440654867796], 
             UndirectedEdge[63, 112] -> 
             RGBColor[
              0.32715088352733546`, 0.45710875455411837`, 0.94209144443096], 
             UndirectedEdge[59, 193] -> 
             RGBColor[
              0.38274569330621644`, 0.5059368150091147, 0.9456091950221126], 
             UndirectedEdge[110, 180] -> 
             RGBColor[
              0.6645475989229954, 0.737297023885635, 0.9675905484473445], 
             UndirectedEdge[21, 196] -> 
             RGBColor[
              0.4056875246476441, 0.5246714028276624, 0.9473850392149095], 
             UndirectedEdge[24, 190] -> 
             RGBColor[
              0.1793170324527155, 0.3058039488372898, 0.9335232117711809], 
             UndirectedEdge[44, 60] -> 
             RGBColor[
              0.2686906729944792, 0.399741311662782, 0.9386129083835817], 
             UndirectedEdge[20, 106] -> 
             RGBColor[
              0.25022657945820426`, 0.38033437866501096`, 0.9375614055718693],
              UndirectedEdge[75, 139] -> 
             RGBColor[
              0.26665982071221705`, 0.39760675715065275`, 0.9384972543504835],
              UndirectedEdge[4, 81] -> 
             RGBColor[
              0.6906097692395512, 0.7572174460449604, 0.9704887002235348], 
             UndirectedEdge[79, 197] -> 
             RGBColor[
              0.5464425729840517, 0.6229880683860871, 0.9620969735266468], 
             UndirectedEdge[66, 90] -> 
             RGBColor[
              0.5397844128240585, 0.6347307875135932, 0.9579193049130958], 
             UndirectedEdge[14, 15] -> 
             RGBColor[
              0.3709417656089321, 0.49571284612038347`, 0.9448570591870451], 
             UndirectedEdge[14, 48] -> 
             RGBColor[
              0.36693773655078116`, 0.49224475739856516`, 0.9446019259960836],
              UndirectedEdge[122, 144] -> 
             RGBColor[
              0.9247271116948175, 0.7113578190580653, 0.33725586527563345`], 
             UndirectedEdge[80, 121] -> 
             RGBColor[
              0.5812862861253769, 0.6709534195821745, 0.9601801322470673], 
             UndirectedEdge[79, 170] -> 
             RGBColor[
              0.1931667580582484, 0.32036088857202627`, 0.934311933155583], 
             UndirectedEdge[91, 95] -> 
             RGBColor[
              0.9087217160297558, 0.9082261327367556, 0.679871771253554], 
             UndirectedEdge[48, 193] -> 
             RGBColor[
              0.3168945933506373, 0.44889990200011176`, 0.9414132211627845], 
             UndirectedEdge[67, 162] -> 
             RGBColor[
              0.9005534787430421, 0.5638554471764086, 0.5394474906426548], 
             UndirectedEdge[65, 87] -> 
             RGBColor[
              0.9550341089343712, 0.965005825208276, 0.9206936459458361], 
             UndirectedEdge[98, 121] -> 
             RGBColor[
              0.7580819454747305, 0.8096778551186503, 0.9434509884049964], 
             UndirectedEdge[161, 187] -> 
             RGBColor[
              0.2957430491853379, 0.4281750742590913, 0.9401535011872468], 
             UndirectedEdge[68, 122] -> 
             RGBColor[
              0.924281570863012, 0.9375100698293877, 0.7294250958369339], 
             UndirectedEdge[19, 90] -> 
             RGBColor[
              0.32617520722218063`, 0.45283835871142575`, 0.9421546927268274],
              UndirectedEdge[80, 168] -> 
             RGBColor[
              0.7792447125486042, 0.8280111263190817, 0.9760255070982982], 
             UndirectedEdge[109, 194] -> 
             RGBColor[
              0.3430360942965171, 0.47154235620939167`, 0.9430789344870343], 
             UndirectedEdge[44, 57] -> 
             RGBColor[
              0.3220009955988029, 0.4509816264225601, 0.9418243188335629], 
             UndirectedEdge[109, 151] -> 
             RGBColor[
              0.34470972375175946`, 0.47299196992446024`, 0.9431855766759899],
              UndirectedEdge[122, 138] -> 
             RGBColor[
              0.9528570018424507, 0.8395978867219851, 0.360717102170288], 
             UndirectedEdge[138, 192] -> 
             RGBColor[
              0.8650473379676169, 0.41300932570290905`, 0.20644673266035168`],
              UndirectedEdge[31, 46] -> 
             RGBColor[
              0.7241254080647266, 0.7839747878759986, 0.9735395315167075], 
             UndirectedEdge[101, 165] -> 
             RGBColor[
              0.23537363183733478`, 0.36472298898420613`, 0.9367155521778278],
              UndirectedEdge[76, 105] -> 
             RGBColor[
              0.3097803157470692, 0.4397426691808402, 0.94106957474386], 
             UndirectedEdge[6, 199] -> 
             RGBColor[
              0.3061701598017846, 0.4362401923980924, 0.9408532892006678], 
             UndirectedEdge[83, 175] -> 
             RGBColor[
              0.2881231207365411, 0.41908874892813175`, 0.9397590026698441], 
             UndirectedEdge[139, 182] -> 
             RGBColor[
              0.2571409182934481, 0.38760178717525484`, 0.9379551669396888], 
             UndirectedEdge[89, 149] -> 
             RGBColor[
              0.5437801205941402, 0.38941935202558264`, 0.567974527017709], 
             UndirectedEdge[53, 163] -> 
             RGBColor[
              0.2222172147783616, 0.3508947604902047, 0.935966313689494], 
             UndirectedEdge[8, 96] -> 
             RGBColor[
              0.3771970335719591, 0.5008951438379817, 0.9452642694982989], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.3028942075372073, 0.43437709498723787`, 0.9406088720414547], 
             UndirectedEdge[55, 191] -> 
             RGBColor[
              0.31630641834476525`, 0.445754027687974, 0.9414722756672911], 
             UndirectedEdge[122, 181] -> 
             RGBColor[
              0.9886341161577883, 0.9875460745600706, 0.6910581517385923], 
             UndirectedEdge[130, 177] -> 
             RGBColor[
              0.26541543308332344`, 0.3962988268539529, 0.9384263883159245], 
             UndirectedEdge[25, 131] -> 
             RGBColor[
              0.93909008289769, 0.7879991811183886, 0.30513287379478254`], 
             UndirectedEdge[19, 33] -> 
             RGBColor[
              0.29372081640032377`, 0.4247279965866454, 0.9400867276419496], 
             UndirectedEdge[1, 89] -> 
             RGBColor[
              0.9061524103512045, 0.6435271253680068, 0.2459445167509792], 
             UndirectedEdge[123, 127] -> 
             RGBColor[
              0.2860095413584047, 0.4167572429724312, 0.9396426650906227], 
             UndirectedEdge[40, 173] -> 
             RGBColor[
              0.7433614186788604, 0.7950716369237336, 0.832834751651226], 
             UndirectedEdge[17, 106] -> 
             RGBColor[
              0.25694510996125053`, 0.38739598020314986`, 0.9379440159448427],
              UndirectedEdge[51, 158] -> 
             RGBColor[
              0.267702506048196, 0.39870268554883526`, 0.9385566337378528], 
             UndirectedEdge[20, 189] -> 
             RGBColor[
              0.2283963086796351, 0.35738937995762443`, 0.9363182039460214], 
             UndirectedEdge[48, 140] -> 
             RGBColor[
              0.3113031778693076, 0.4437571221637065, 0.9410679174089878], 
             UndirectedEdge[11, 189] -> 
             RGBColor[
              0.2386268283641832, 0.36814230479849686`, 0.9369008169073587], 
             UndirectedEdge[40, 169] -> 
             RGBColor[
              0.38208210782853824`, 0.5009795735314966, 0.9459763978166744], 
             UndirectedEdge[94, 167] -> 
             RGBColor[0.666701611701555, 0.7359313939081493, 0.9698223518406],
              UndirectedEdge[81, 198] -> 
             RGBColor[
              0.6362473175270285, 0.7147490855972023, 0.9650703590828255], 
             UndirectedEdge[34, 60] -> 
             RGBColor[
              0.25285259350547307`, 0.38309448592759754`, 0.9377109531870217],
              UndirectedEdge[13, 101] -> 
             RGBColor[
              0.3149218240784437, 0.4419302409877936, 0.941480147105756], 
             UndirectedEdge[31, 117] -> 
             RGBColor[
              0.8147533586460658, 0.8554575003050673, 0.9821051874244302], 
             UndirectedEdge[94, 105] -> 
             RGBColor[
              0.3806688871734759, 0.5041379899202462, 0.945476862771782], 
             UndirectedEdge[125, 190] -> 
             RGBColor[
              0.179333445229231, 0.3058211997060377, 0.933524146454523], 
             UndirectedEdge[79, 119] -> 
             RGBColor[
              0.3844232617951737, 0.4946732869545277, 0.9469077488332039], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.2600890189665118, 0.39070042790302345`, 0.9381230569116956], 
             UndirectedEdge[156, 178] -> 
             RGBColor[
              0.9316378178168464, 0.9481531008980535, 0.987322033962275], 
             UndirectedEdge[95, 131] -> 
             RGBColor[
              0.9394422371635587, 0.7891870801469172, 0.306500926618929], 
             UndirectedEdge[49, 133] -> 
             RGBColor[
              0.829082723763209, 0.22454813574064747`, 0.1754829551608747], 
             UndirectedEdge[34, 44] -> 
             RGBColor[
              0.2675860001638932, 0.3985802304775334, 0.9385499989000968], 
             UndirectedEdge[24, 125] -> 
             RGBColor[
              0.17894341561590066`, 0.30541125385312173`, 0.9335019348450408],
              UndirectedEdge[95, 129] -> 
             RGBColor[
              0.9849427513832404, 0.9608705061848779, 0.39600586175704294`], 
             UndirectedEdge[13, 16] -> 
             RGBColor[
              0.35048029688204574`, 0.4779901503324755, 0.9435532724931343], 
             UndirectedEdge[13, 199] -> 
             RGBColor[
              0.3251439087147671, 0.45267430005816894`, 0.9420622797035756], 
             UndirectedEdge[121, 196] -> 
             RGBColor[
              0.5189244738450667, 0.6203252910053908, 0.955270781945516], 
             UndirectedEdge[26, 40] -> 
             RGBColor[
              0.4439921507491714, 0.557946476502165, 0.9497988277939646], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.31163329513552707`, 0.44101997430243733`, 0.9411996419147166],
              UndirectedEdge[54, 126] -> 
             RGBColor[
              0.29001572662104147`, 0.4221552951107917, 0.9398273386400247], 
             UndirectedEdge[16, 193] -> 
             RGBColor[
              0.3198238857723562, 0.4514371078652866, 0.9415998730856248], 
             UndirectedEdge[85, 150] -> 
             RGBColor[
              0.3215409260409259, 0.45053715769585945`, 0.9417966871465304], 
             UndirectedEdge[26, 169] -> 
             RGBColor[
              0.3344928369204973, 0.4607990805848347, 0.9426569888942514], 
             UndirectedEdge[22, 79] -> 
             RGBColor[
              0.5241950050244188, 0.3370826401249345, 0.5625493919022517], 
             UndirectedEdge[27, 67] -> 
             RGBColor[
              0.5474773621295221, 0.27457683969669183`, 0.5520694598597993], 
             UndirectedEdge[49, 95] -> 
             RGBColor[
              0.9071817078072888, 0.605474620924499, 0.27812431524098535`], 
             UndirectedEdge[147, 178] -> 
             RGBColor[
              0.7115638776908443, 0.7729379814418316, 0.9672966305905184], 
             UndirectedEdge[1, 136] -> 
             RGBColor[
              0.9331596302538536, 0.7720124271387454, 0.2686954588022206], 
             UndirectedEdge[65, 110] -> 
             RGBColor[
              0.7635603354949406, 0.815471840469592, 0.9772401996765336], 
             UndirectedEdge[77, 106] -> 
             RGBColor[
              0.2877229919008626, 0.4197454855521064, 0.9396967707895075], 
             UndirectedEdge[25, 64] -> 
             RGBColor[
              0.8007620659771775, 0.8225276552268693, 0.6680235781600576], 
             UndirectedEdge[82, 187] -> 
             RGBColor[
              0.3007127795635599, 0.4324876517182224, 0.9404698733799348], 
             UndirectedEdge[167, 188] -> 
             RGBColor[
              0.7899648841688349, 0.8366160464867711, 0.9794955855762202], 
             UndirectedEdge[13, 137] -> 
             RGBColor[
              0.31409319630205523`, 0.44105930065677384`, 0.9414329579797356],
              UndirectedEdge[37, 125] -> 
             RGBColor[
              0.18497678859456473`, 0.3117527113916389, 0.9338455265106003], 
             UndirectedEdge[105, 182] -> 
             RGBColor[
              0.30416697639606216`, 0.43384269361666083`, 0.9407499033720115],
              UndirectedEdge[111, 116] -> 
             RGBColor[
              0.42503929713653266`, 0.5423745144765412, 0.9483579559716804], 
             UndirectedEdge[146, 179] -> 
             RGBColor[
              0.802014133137712, 0.8452588034311341, 0.9809009316091206], 
             UndirectedEdge[9, 63] -> 
             RGBColor[
              0.3067096536024727, 0.43562372585425413`, 0.9409273466268289], 
             UndirectedEdge[38, 120] -> 
             RGBColor[
              0.960788560046435, 0.8793927471320053, 0.302171389549849], 
             UndirectedEdge[71, 81] -> 
             RGBColor[
              0.43330857195401157`, 0.5446846710814149, 0.9498164169017225], 
             UndirectedEdge[68, 181] -> 
             RGBColor[
              0.9199773592711327, 0.9377520223513063, 0.9477245085556535], 
             UndirectedEdge[114, 158] -> 
             RGBColor[
              0.23522624458781927`, 0.364568075640074, 0.9367071586920077], 
             UndirectedEdge[118, 149] -> 
             RGBColor[
              0.5734377675010032, 0.6482679055474284, 0.9641030029427655], 
             UndirectedEdge[87, 162] -> 
             RGBColor[
              0.9854379176982261, 0.9880317806397674, 0.8813919321035765], 
             UndirectedEdge[88, 122] -> 
             RGBColor[
              0.8525664665525501, 0.8811976138560375, 0.7223536497554326], 
             UndirectedEdge[49, 162] -> 
             RGBColor[
              0.9088194332461141, 0.62739119565138, 0.547362978009857], 
             UndirectedEdge[47, 116] -> 
             RGBColor[
              0.42055225492425696`, 0.5386829584696233, 0.9480181956973843], 
             UndirectedEdge[23, 95] -> 
             RGBColor[
              0.9866024805360858, 0.9658049975494172, 0.45892937586547133`], 
             UndirectedEdge[54, 115] -> 
             RGBColor[
              0.2691801918114708, 0.40025582697672574`, 0.938640785756031], 
             UndirectedEdge[62, 105] -> 
             RGBColor[
              0.3497224989411253, 0.4773337838440822, 0.9435049862784333], 
             UndirectedEdge[13, 108] -> 
             RGBColor[
              0.5796159484292636, 0.6654249189415207, 0.9620681904824614], 
             UndirectedEdge[76, 182] -> 
             RGBColor[
              0.27073696797748936`, 0.4018920974325212, 0.938729441855642], 
             UndirectedEdge[117, 171] -> 
             RGBColor[
              0.8267342564377225, 0.8650107429913272, 0.9832479361512722], 
             UndirectedEdge[40, 46] -> 
             RGBColor[
              0.5446619359975361, 0.6412201222402223, 0.9572969292455886], 
             UndirectedEdge[19, 177] -> 
             RGBColor[
              0.2790041774695689, 0.41058145878005325`, 0.9392002472059755], 
             UndirectedEdge[64, 87] -> 
             RGBColor[
              0.8052886005993835, 0.8468955393268014, 0.9061943444225835], 
             UndirectedEdge[62, 107] -> 
             RGBColor[
              0.5117328555891169, 0.611469763511346, 0.9556934742742034], 
             UndirectedEdge[53, 148] -> 
             RGBColor[
              0.20810268194188267`, 0.3360594915659958, 0.9351625119250367], 
             UndirectedEdge[76, 111] -> 
             RGBColor[
              0.368423059805849, 0.49034117218248097`, 0.9448600884518084], 
             UndirectedEdge[11, 48] -> 
             RGBColor[
              0.2814824902109824, 0.4124136886940051, 0.9393696733626], 
             UndirectedEdge[96, 111] -> 
             RGBColor[
              0.3833462518703272, 0.5060263932272735, 0.9457099421629962], 
             UndirectedEdge[168, 198] -> 
             RGBColor[
              0.8173765882647961, 0.8581441256038294, 0.9795908811512684], 
             UndirectedEdge[118, 128] -> 
             RGBColor[
              0.901444520807011, 0.7626039594239429, 0.6105848646794676], 
             UndirectedEdge[56, 129] -> 
             RGBColor[
              0.5845933454317087, 0.6420998957641366, 0.6750810838088802], 
             UndirectedEdge[53, 100] -> 
             RGBColor[
              0.21261327393044743`, 0.34080040973402737`, 0.9354193834659627],
              UndirectedEdge[129, 143] -> 
             RGBColor[
              0.9055290665332671, 0.5698386545013628, 0.2921055427004665], 
             UndirectedEdge[18, 160] -> 
             RGBColor[
              0.34254111760690553`, 0.47111363227910186`, 0.9430473950100628],
              UndirectedEdge[68, 111] -> 
             RGBColor[
              0.6580603131297789, 0.7303031444944423, 0.9683812581650608], 
             UndirectedEdge[51, 166] -> 
             RGBColor[
              0.33653220976868264`, 0.46344910853990606`, 0.9427545820635193],
              UndirectedEdge[107, 181] -> 
             RGBColor[
              0.8257804710137671, 0.8638766258907483, 0.9384122883545408], 
             UndirectedEdge[31, 173] -> 
             RGBColor[
              0.9228248907460509, 0.93782630255951, 0.8490773539223448], 
             UndirectedEdge[135, 148] -> 
             RGBColor[
              0.2190360411775415, 0.34755114533768694`, 0.935785150559052], 
             UndirectedEdge[44, 177] -> 
             RGBColor[
              0.2885154270365152, 0.4205783851229668, 0.9397418987981803], 
             UndirectedEdge[80, 184] -> 
             RGBColor[
              0.4955150283010483, 0.599088932806033, 0.9540444790837972], 
             UndirectedEdge[65, 162] -> 
             RGBColor[
              0.9524974540168591, 0.9637424148637534, 0.9531295952763283], 
             UndirectedEdge[5, 17] -> 
             RGBColor[
              0.26052268450773763`, 0.3911562378828352, 0.9381477535227178], 
             UndirectedEdge[44, 141] -> 
             RGBColor[
              0.321381334697979, 0.45044490729532893`, 0.941784834588907], 
             UndirectedEdge[94, 174] -> 
             RGBColor[
              0.39976902935609954`, 0.5206815730777754, 0.9466939069420661], 
             UndirectedEdge[161, 193] -> 
             RGBColor[
              0.31267272742048674`, 0.4452350871371401, 0.9411445022314171], 
             UndirectedEdge[101, 124] -> 
             RGBColor[
              0.2714494089102611, 0.40264091802422836`, 0.9387700143128014], 
             UndirectedEdge[106, 189] -> 
             RGBColor[
              0.25322164598941777`, 0.3834823834875024, 0.9377319701800181], 
             UndirectedEdge[2, 80] -> 
             RGBColor[
              0.4985089361983589, 0.6016821053484971, 0.954235248247605], 
             UndirectedEdge[97, 102] -> 
             RGBColor[
              0.3273981891467483, 0.4554287175679108, 0.9421765599569466], 
             UndirectedEdge[91, 136] -> 
             RGBColor[
              0.8729121465452325, 0.773250594157032, 0.6146156000869095], 
             UndirectedEdge[59, 154] -> 
             RGBColor[
              0.7176662191262557, 0.7759253920834623, 0.911377748265729], 
             UndirectedEdge[108, 162] -> 
             RGBColor[
              0.8820669248115173, 0.9078962359074088, 0.9463287513615282], 
             UndirectedEdge[146, 147] -> 
             RGBColor[
              0.6383951985626789, 0.7149619751698173, 0.9662861034465073], 
             UndirectedEdge[99, 156] -> 
             RGBColor[
              0.7424696241286013, 0.7983584952437333, 0.9755694516963352], 
             UndirectedEdge[143, 154] -> 
             RGBColor[
              0.9036629908200117, 0.5747841615261196, 0.5202434925656607], 
             UndirectedEdge[139, 145] -> 
             RGBColor[
              0.2284570343408142, 0.357453206477753, 0.9363216621825899], 
             UndirectedEdge[104, 123] -> 
             RGBColor[
              0.23468312728084179`, 0.36399722491481445`, 0.9366762289648454],
              UndirectedEdge[116, 126] -> 
             RGBColor[
              0.34840388541039236`, 0.4760510392042203, 0.9434261144656448], 
             UndirectedEdge[17, 28] -> 
             RGBColor[
              0.2668075494695581, 0.39776202944116235`, 0.938505667284669], 
             UndirectedEdge[89, 118] -> 
             RGBColor[
              0.8836498800355815, 0.6748620936624041, 0.59546480538561], 
             UndirectedEdge[123, 163] -> 
             RGBColor[
              0.2417268008308885, 0.37140057241061075`, 0.9370773557533394], 
             UndirectedEdge[47, 157] -> 
             RGBColor[
              0.5046032669357259, 0.6086499170733246, 0.9541568402025347], 
             UndirectedEdge[117, 151] -> 
             RGBColor[
              0.565437397706639, 0.6532390613039136, 0.9611245836688005], 
             UndirectedEdge[69, 86] -> 
             RGBColor[
              0.39677259596818604`, 0.5180862130822859, 0.9465029768562303], 
             UndirectedEdge[73, 94] -> 
             RGBColor[
              0.35563109287921313`, 0.4810081428778644, 0.9439343254346236], 
             UndirectedEdge[61, 174] -> 
             RGBColor[
              0.3276038093333696, 0.4549444137194375, 0.9422139156652158], 
             UndirectedEdge[175, 187] -> 
             RGBColor[
              0.3016125136762855, 0.4332669561847139, 0.940527203641994], 
             UndirectedEdge[75, 134] -> 
             RGBColor[
              0.2575067829018646, 0.3879863340758565, 0.93797600238789], 
             UndirectedEdge[38, 178] -> 
             RGBColor[
              0.9536200808381681, 0.9247692797301834, 0.650059594771984], 
             UndirectedEdge[8, 179] -> 
             RGBColor[
              0.6280655556399748, 0.706255507224953, 0.9656353303034069], 
             UndirectedEdge[29, 167] -> 
             RGBColor[
              0.9544593958943188, 0.963459656199136, 0.8733980891466777], 
             UndirectedEdge[68, 185] -> 
             RGBColor[
              0.8125990681630673, 0.8538159065524649, 0.9818794937101938], 
             UndirectedEdge[79, 118] -> 
             RGBColor[
              0.5586378396004057, 0.632712242954274, 0.9632601689433578], 
             UndirectedEdge[171, 173] -> 
             RGBColor[
              0.9348057885377076, 0.9473795452457701, 0.8502201026491867], 
             UndirectedEdge[80, 166] -> 
             RGBColor[
              0.5054107612208105, 0.6076601192871327, 0.9546750264349914], 
             UndirectedEdge[109, 132] -> 
             RGBColor[
              0.2948786821955154, 0.42460409000948357`, 0.9402017631916271], 
             UndirectedEdge[118, 197] -> 
             RGBColor[
              0.9011122603260905, 0.9239864726160629, 0.9904300858939554], 
             UndirectedEdge[111, 167] -> 
             RGBColor[
              0.687885792752501, 0.7540851723545239, 0.971226039036996], 
             UndirectedEdge[113, 122] -> 
             RGBColor[
              0.9466202120897103, 0.8137405258050889, 0.35564035163633406`], 
             UndirectedEdge[119, 190] -> 
             RGBColor[
              0.3722927166990131, 0.48192331493748153`, 0.946216932235511], 
             UndirectedEdge[19, 130] -> 
             RGBColor[
              0.2508128361327613, 0.38095057160079043`, 0.9375947920221963], 
             UndirectedEdge[35, 167] -> 
             RGBColor[
              0.876824539183936, 0.9046201030499366, 0.9881135013695121], 
             UndirectedEdge[102, 112] -> 
             RGBColor[
              0.337642108559284, 0.46619572637249007`, 0.9427599360129698], 
             UndirectedEdge[134, 145] -> 
             RGBColor[
              0.21930399653046173`, 0.34783278340295676`, 0.9358004102199964],
              UndirectedEdge[109, 150] -> 
             RGBColor[
              0.31023488720570846`, 0.44074443511482886`, 0.941076276349488], 
             UndirectedEdge[147, 179] -> 
             RGBColor[
              0.6443148010184508, 0.7195864135989113, 0.9668761140974684], 
             UndirectedEdge[63, 102] -> 
             RGBColor[
              0.3633436999904507, 0.48913178357153686`, 0.9443729171645411], 
             UndirectedEdge[62, 182] -> 
             RGBColor[
              0.31067915117154543`, 0.43948321209576313`, 0.9411648533902153],
              UndirectedEdge[8, 99] -> 
             RGBColor[
              0.5061464386241231, 0.6098124694135529, 0.9543032645305172], 
             UndirectedEdge[60, 123] -> 
             RGBColor[
              0.252194354195388, 0.3824026346779154, 0.9376734674320901], 
             UndirectedEdge[7, 97] -> 
             RGBColor[
              0.3157107895654947, 0.44530567947641203`, 0.9414318491903908], 
             UndirectedEdge[130, 163] -> 
             RGBColor[
              0.23512312567678792`, 0.3644596911264634, 0.9367012862225752], 
             UndirectedEdge[127, 135] -> 
             RGBColor[
              0.2774333145415366, 0.4077430848237163, 0.9391542616607926], 
             UndirectedEdge[37, 56] -> 
             RGBColor[
              0.18496037439835666`, 0.3117354590307041, 0.9338445917464089], 
             UndirectedEdge[100, 148] -> 
             RGBColor[
              0.20930368592266696`, 0.3373218228978505, 0.9352309073250162], 
             UndirectedEdge[53, 135] -> 
             RGBColor[
              0.222345629185322, 0.35102973217386374`, 0.9359736266999984], 
             UndirectedEdge[103, 154] -> 
             RGBColor[
              0.9254091486755369, 0.7326773288061676, 0.5407051440124293], 
             UndirectedEdge[63, 140] -> 
             RGBColor[
              0.32917806589633525`, 0.4592394517547229, 0.942206889467927], 
             UndirectedEdge[8, 75] -> 
             RGBColor[
              0.36617940457524284`, 0.4893149172044077, 0.9446368318260574], 
             UndirectedEdge[50, 53] -> 
             RGBColor[
              0.22682228238214364`, 0.3557349785199296, 0.9362285654769424], 
             UndirectedEdge[1, 167] -> 
             RGBColor[
              0.9367941803977453, 0.9031603919681208, 0.6421668592196352], 
             UndirectedEdge[27, 119] -> 
             RGBColor[
              0.4208137004428272, 0.5329219452602844, 0.9489801304793581], 
             UndirectedEdge[96, 126] -> 
             RGBColor[
              0.3067108401441868, 0.4397029179549527, 0.9407781006569607], 
             UndirectedEdge[102, 106] -> 
             RGBColor[
              0.32444342089519307`, 0.4523230687923987, 0.9420082902762085], 
             UndirectedEdge[16, 176] -> 
             RGBColor[
              0.30857911035131147`, 0.440352288288518, 0.9409326188466578], 
             UndirectedEdge[40, 166] -> 
             RGBColor[
              0.4412529384384768, 0.5555739084754552, 0.9496242876077174], 
             UndirectedEdge[33, 90] -> 
             RGBColor[
              0.35549444310349765`, 0.4823331517711803, 0.9438727694565298], 
             UndirectedEdge[13, 161] -> 
             RGBColor[
              0.34332913853017627`, 0.471788129604329, 0.9430979016389265], 
             UndirectedEdge[11, 106] -> 
             RGBColor[
              0.2604570991427524, 0.3910873035058834, 0.9381440185332068], 
             UndirectedEdge[88, 167] -> 
             RGBColor[
              0.8137351892886164, 0.8551855895073546, 0.9818647874444291], 
             UndirectedEdge[29, 159] -> 
             RGBColor[
              0.9081437399557057, 0.5833500342919629, 0.46216641584665136`], 
             UndirectedEdge[156, 157] -> 
             RGBColor[
              0.7392642763541118, 0.795756249521131, 0.9753171149779516], 
             UndirectedEdge[171, 183] -> 
             RGBColor[
              0.8671903203612858, 0.6797554080985058, 0.5963535737913382], 
             UndirectedEdge[100, 104] -> 
             RGBColor[
              0.21637454520909913`, 0.34475374432626316`, 0.9356335823009796],
              UndirectedEdge[108, 180] -> 
             RGBColor[
              0.7526503794757171, 0.8066954638919603, 0.9759808139745987], 
             UndirectedEdge[178, 179] -> 
             RGBColor[
              0.8751828122658775, 0.9032348097031484, 0.9819114587531318], 
             UndirectedEdge[150, 151] -> 
             RGBColor[
              0.3174016073666887, 0.4469518879084411, 0.9415329334208639], 
             UndirectedEdge[2, 121] -> 
             RGBColor[
              0.45989815510185605`, 0.5703361338584898, 0.9511956661237368], 
             UndirectedEdge[12, 14] -> 
             RGBColor[
              0.500367704585658, 0.6042677811858945, 0.954084097379875], 
             UndirectedEdge[43, 131] -> 
             RGBColor[
              0.8773120191958123, 0.531003528583677, 0.2191512749676569], 
             UndirectedEdge[75, 76] -> 
             RGBColor[
              0.2802558703962583, 0.4118970674079191, 0.9392715292664366], 
             UndirectedEdge[113, 138] -> 
             RGBColor[
              0.9065388861824932, 0.6660342904889218, 0.24359871478674944`], 
             UndirectedEdge[17, 20] -> 
             RGBColor[
              0.23211977265146783`, 0.3613029766732719, 0.9365302497108459], 
             UndirectedEdge[86, 187] -> 
             RGBColor[
              0.3373933626791634, 0.4642585291932452, 0.9428071277006951], 
             UndirectedEdge[8, 185] -> 
             RGBColor[
              0.6088853490181219, 0.6912717840369921, 0.9637236265565623], 
             UndirectedEdge[4, 41] -> 
             RGBColor[
              0.6772999087061907, 0.7464119016615944, 0.969440899246723], 
             UndirectedEdge[8, 107] -> 
             RGBColor[
              0.5577142065740452, 0.6512964986445926, 0.9586233652992509], 
             UndirectedEdge[149, 192] -> 
             RGBColor[
              0.5254435040297809, 0.2484760819553035, 0.5504153622874323], 
             UndirectedEdge[11, 140] -> 
             RGBColor[
              0.27568296917584306`, 0.40709065828657925`, 0.9390111093069351],
              UndirectedEdge[94, 153] -> 
             RGBColor[
              0.5020487622755229, 0.6056693221783567, 0.9542062732491396], 
             UndirectedEdge[56, 79] -> 
             RGBColor[
              0.1914475761291835, 0.31855391936214905`, 0.9342140282880245], 
             UndirectedEdge[5, 15] -> 
             RGBColor[
              0.303658911440855, 0.4349821137845143, 0.940659697404096], 
             UndirectedEdge[79, 128] -> 
             RGBColor[
              0.5467748334649722, 0.46160555519396695`, 0.5822517523121589], 
             UndirectedEdge[109, 152] -> 
             RGBColor[
              0.3096412804178116, 0.4401205167439052, 0.9410424713210799], 
             UndirectedEdge[118, 192] -> 
             RGBColor[
              0.8653132634712222, 0.5339188235921248, 0.5779056406553331], 
             UndirectedEdge[99, 107] -> 
             RGBColor[
              0.615663269511703, 0.6984811954684678, 0.963146911483036], 
             UndirectedEdge[3, 189] -> 
             RGBColor[
              0.24752736996092756`, 0.37749733834360644`, 0.937407689584122], 
             UndirectedEdge[35, 138] -> 
             RGBColor[
              0.8755744905406526, 0.7829258920824524, 0.6165607268309311], 
             UndirectedEdge[12, 86] -> 
             RGBColor[
              0.4879611145029988, 0.5935218164296439, 0.9532935604305248], 
             UndirectedEdge[16, 127] -> 
             RGBColor[
              0.3222744622049885, 0.4535596740016799, 0.9417560216489524], 
             UndirectedEdge[37, 195] -> 
             RGBColor[
              0.18496037439835666`, 0.3117354590307041, 0.9338445917464089], 
             UndirectedEdge[57, 71] -> 
             RGBColor[
              0.32543061952646807`, 0.4545863786212526, 0.9420196308425695], 
             UndirectedEdge[58, 73] -> 
             RGBColor[
              0.2786440888438728, 0.4102029828035092, 0.9391797406914454], 
             UndirectedEdge[35, 153] -> 
             RGBColor[
              0.7121716897579038, 0.7743580313201439, 0.9724974227780518], 
             UndirectedEdge[35, 122] -> 
             RGBColor[
              0.9156558164478696, 0.9306321273986194, 0.7286023636805157], 
             UndirectedEdge[19, 44] -> 
             RGBColor[
              0.2739128300859531, 0.40523012986980433`, 0.9389103025044521], 
             UndirectedEdge[181, 192] -> 
             RGBColor[
              0.9008244522829545, 0.5609575135409945, 0.536787782228656], 
             UndirectedEdge[119, 128] -> 
             RGBColor[
              0.727229943001779, 0.6245650034241965, 0.5942324445693138], 
             UndirectedEdge[116, 153] -> 
             RGBColor[
              0.48777642817979994`, 0.593307343733011, 0.9532968527410897], 
             UndirectedEdge[186, 193] -> 
             RGBColor[
              0.29935843960625863`, 0.43124092646978174`, 0.9403862732371204],
              UndirectedEdge[22, 119] -> 
             RGBColor[
              0.7046501145612256, 0.5000420883551641, 0.5745300841594067], 
             UndirectedEdge[85, 109] -> 
             RGBColor[
              0.34884904242599657`, 0.47657723971187865`, 0.9434493304016565],
              UndirectedEdge[98, 99] -> 
             RGBColor[
              0.7687919437411839, 0.8183727141912807, 0.944294118700548], 
             UndirectedEdge[161, 175] -> 
             RGBColor[
              0.31452843153509336`, 0.4468424047708116, 0.941262746056665], 
             UndirectedEdge[54, 61] -> 
             RGBColor[
              0.27330173727350593`, 0.40458783257840025`, 0.9388755016728139],
              UndirectedEdge[43, 154] -> 
             RGBColor[
              0.9209464577022384, 0.7076324616463945, 0.536794159970965], 
             UndirectedEdge[87, 95] -> 
             RGBColor[
              0.9838001922594006, 0.9661152059128862, 0.6121532693347048], 
             UndirectedEdge[12, 108] -> 
             RGBColor[
              0.6825976109082605, 0.7510751508326818, 0.9696102227606116], 
             UndirectedEdge[15, 48] -> 
             RGBColor[
              0.32110672796259787`, 0.4525482412929506, 0.9416816146556142], 
             UndirectedEdge[13, 187] -> 
             RGBColor[
              0.33041322067136836`, 0.4582126810182313, 0.9423623592242556], 
             UndirectedEdge[15, 28] -> 
             RGBColor[
              0.3099437764026754, 0.4415879053428414, 0.9410176111660472], 
             UndirectedEdge[52, 134] -> 
             RGBColor[
              0.22165741455534713`, 0.35030637496243233`, 0.9359344338949436],
              UndirectedEdge[66, 172] -> 
             RGBColor[
              0.8427983522117647, 0.874271591791478, 0.7778392040313489], 
             UndirectedEdge[101, 176] -> 
             RGBColor[
              0.27302063754770944`, 0.4042923789438361, 0.9388594934592795], 
             UndirectedEdge[119, 192] -> 
             RGBColor[
              0.6910986856659902, 0.39587986759237864`, 0.5615532205451794], 
             UndirectedEdge[168, 184] -> 
             RGBColor[
              0.6548626736277727, 0.7248006680529328, 0.9668502718111599], 
             UndirectedEdge[16, 175] -> 
             RGBColor[
              0.3216795898869629, 0.4530444254989581, 0.9417181169108728], 
             UndirectedEdge[60, 104] -> 
             RGBColor[
              0.23644603942151277`, 0.3658501573497452, 0.9367766242032618], 
             UndirectedEdge[122, 136] -> 
             RGBColor[
              0.9504725003418423, 0.8301441328600938, 0.35879847629145456`], 
             UndirectedEdge[107, 157] -> 
             RGBColor[
              0.6124579217372135, 0.6958789497458655, 0.9628945747646525], 
             UndirectedEdge[86, 110] -> 
             RGBColor[
              0.49849330988433693`, 0.6020723271102092, 0.9541226934316467], 
             UndirectedEdge[5, 9] -> 
             RGBColor[
              0.27138694905370225`, 0.40257526875480143`, 0.9387664573163714],
              UndirectedEdge[3, 77] -> 
             RGBColor[
              0.2820287158723724, 0.41376044040821036`, 0.9393724901936115], 
             UndirectedEdge[84, 139] -> 
             RGBColor[
              0.25596738815303377`, 0.386368332591571, 0.9378883361342745], 
             UndirectedEdge[96, 191] -> 
             RGBColor[
              0.29321373700723585`, 0.4255166067922517, 0.9400094606004861], 
             UndirectedEdge[46, 151] -> 
             RGBColor[
              0.4748094471252997, 0.581756348874845, 0.9525589277610778], 
             UndirectedEdge[72, 191] -> 
             RGBColor[
              0.2650536461439216, 0.3959185658420248, 0.9384057850849414], 
             UndirectedEdge[111, 185] -> 
             RGBColor[
              0.6150345673164899, 0.6964030334262838, 0.9641692992212595], 
             UndirectedEdge[23, 129] -> 
             RGBColor[
              0.9919194200162629, 0.9837402828928126, 0.4795846817261888], 
             UndirectedEdge[101, 123] -> 
             RGBColor[
              0.2511378900976988, 0.38129222392755147`, 0.9376133033646252], 
             UndirectedEdge[122, 142] -> 
             RGBColor[
              0.8169136872538085, 0.8533228738878083, 0.7188155094580211], 
             UndirectedEdge[18, 174] -> 
             RGBColor[
              0.3498905326098686, 0.47747932616232985`, 0.9435156932352192], 
             UndirectedEdge[123, 135] -> 
             RGBColor[
              0.24185521523784892`, 0.3715355440942698, 0.9370846687638437], 
             UndirectedEdge[171, 178] -> 
             RGBColor[
              0.9084510251565888, 0.9296645818194842, 0.9851104569792455], 
             UndirectedEdge[81, 173] -> 
             RGBColor[
              0.7857376160501509, 0.8294745429756838, 0.8361707611374197], 
             UndirectedEdge[77, 102] -> 
             RGBColor[
              0.33711449602806876`, 0.4656411721496162, 0.9427298892598499], 
             UndirectedEdge[31, 171] -> 
             RGBColor[
              0.8624892635832501, 0.8931895434066397, 0.9867461899854671], 
             UndirectedEdge[109, 196] -> 
             RGBColor[
              0.4163582231260193, 0.5339138255247312, 0.9480649666862233], 
             UndirectedEdge[18, 153] -> 
             RGBColor[
              0.4521702655292919, 0.5624670752629113, 0.9510280595422927], 
             UndirectedEdge[97, 140] -> 
             RGBColor[
              0.29323255505263285`, 0.42553638575109687`, 0.9400105322603325],
              UndirectedEdge[116, 167] -> 
             RGBColor[
              0.652429277605832, 0.7235694154628036, 0.96891293133255], 
             UndirectedEdge[128, 190] -> 
             RGBColor[
              0.5346442883688116, 0.44885558317692076`, 0.5815609357144658], 
             UndirectedEdge[94, 126] -> 
             RGBColor[
              0.3626762195061153, 0.4884130176495661, 0.9443355349736948], 
             UndirectedEdge[41, 198] -> 
             RGBColor[
              0.6229374569936681, 0.7039435412138363, 0.9640225581060137], 
             UndirectedEdge[11, 77] -> 
             RGBColor[
              0.27312817427562797`, 0.40440540686310084`, 0.9388656175168482],
              UndirectedEdge[29, 122] -> 
             RGBColor[
              0.9932906731582525, 0.9894716805478189, 0.6138869514576812], 
             UndirectedEdge[84, 152] -> 
             RGBColor[
              0.2722580627952489, 0.4034908645289682, 0.9388160659552552], 
             UndirectedEdge[16, 64] -> 
             RGBColor[
              0.47278195616545676`, 0.5793252259853976, 0.9526162456912082], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.23972819328057, 0.3692999091561883, 0.9369635380100236], 
             UndirectedEdge[26, 121] -> 
             RGBColor[
              0.46953919243500225`, 0.5786867158238351, 0.9518099844973704], 
             UndirectedEdge[40, 74] -> 
             RGBColor[
              0.3971820108095485, 0.5168505289536836, 0.9468363149531384], 
             UndirectedEdge[78, 91] -> 
             RGBColor[
              0.8828910750951913, 0.909457394113841, 0.9886921329803882], 
             UndirectedEdge[139, 152] -> 
             RGBColor[
              0.26544888260262894`, 0.3963339844195651, 0.9384282932165648], 
             UndirectedEdge[40, 196] -> 
             RGBColor[
              0.49337743215923585`, 0.5995850516837207, 0.9532596252421102], 
             UndirectedEdge[6, 86] -> 
             RGBColor[
              0.3660057031110193, 0.4914374768784062, 0.9445425376494667], 
             UndirectedEdge[82, 180] -> 
             RGBColor[
              0.5213332999548519, 0.6173712520138998, 0.9573268973237518], 
             UndirectedEdge[44, 90] -> 
             RGBColor[
              0.33568645678912695`, 0.46283528505433924`, 0.9426963443190322],
              UndirectedEdge[4, 66] -> 
             RGBColor[
              0.7482528569010358, 0.8032600858342098, 0.9755425100215394], 
             UndirectedEdge[131, 143] -> 
             RGBColor[
              0.8600285523135855, 0.398155228463402, 0.20260060756235265`], 
             UndirectedEdge[22, 144] -> 
             RGBColor[
              0.8504688767152189, 0.38893147880177464`, 0.1959623593799244], 
             UndirectedEdge[35, 160] -> 
             RGBColor[
              0.6025425418355174, 0.6830045883363345, 0.9645167582458221], 
             UndirectedEdge[76, 174] -> 
             RGBColor[
              0.3288804579296929, 0.4562862523383694, 0.9422866189141441], 
             UndirectedEdge[85, 196] -> 
             RGBColor[
              0.42766426196123664`, 0.5437065481057618, 0.9487853774832657], 
             UndirectedEdge[6, 137] -> 
             RGBColor[
              0.2951194473890727, 0.4246251929966973, 0.9402239674768278], 
             UndirectedEdge[123, 177] -> 
             RGBColor[
              0.27201910823742403`, 0.40323970813810023`, 0.9388024578466887],
              UndirectedEdge[29, 113] -> 
             RGBColor[
              0.946972557498295, 0.8159080843147557, 0.4967685640741427], 
             UndirectedEdge[96, 174] -> 
             RGBColor[
              0.3438036499941711, 0.471971473383162, 0.943136472625332], 
             UndirectedEdge[74, 158] -> 
             RGBColor[
              0.2780238238703263, 0.40955104498924105`, 0.9391444175188017], 
             UndirectedEdge[46, 121] -> 
             RGBColor[
              0.570208977683367, 0.6619603615618923, 0.9593080859489944], 
             UndirectedEdge[32, 165] -> 
             RGBColor[
              0.2270272954930984, 0.35595046029812505`, 0.9362402406703216], 
             UndirectedEdge[32, 148] -> 
             RGBColor[
              0.219972379693155, 0.3485352964848875, 0.9358384736523275], 
             UndirectedEdge[27, 190] -> 
             RGBColor[
              0.22822804580985986`, 0.3572125250130086, 0.9363086216245102], 
             UndirectedEdge[100, 123] -> 
             RGBColor[
              0.23212285998297438`, 0.3613062216544334, 0.9365304255298079], 
             UndirectedEdge[45, 172] -> 
             RGBColor[
              0.9391683499060914, 0.7786563284917088, 0.4055000051193155], 
             UndirectedEdge[85, 99] -> 
             RGBColor[
              0.4621252914114974, 0.5716835642651686, 0.9514982759565006], 
             UndirectedEdge[106, 112] -> 
             RGBColor[
              0.2882506044320779, 0.42030003977498026`, 0.9397268175426274], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.9113560881636262, 0.6286546059959026, 0.5149270286793647], 
             UndirectedEdge[43, 197] -> 
             RGBColor[
              0.8721411848386535, 0.6704152078814393, 0.5949590715355129], 
             UndirectedEdge[26, 164] -> 
             RGBColor[
              0.34556297092325194`, 0.47243449330876475`, 0.9432874166489127],
              UndirectedEdge[100, 130] -> 
             RGBColor[
              0.2255191848288738, 0.3543653403702861, 0.9361543559990437], 
             UndirectedEdge[46, 196] -> 
             RGBColor[
              0.5464579464995596, 0.642678204475116, 0.9574383177713113], 
             UndirectedEdge[156, 181] -> 
             RGBColor[
              0.9525868256306654, 0.9637539256660137, 0.9508348285678401], 
             UndirectedEdge[62, 96] -> 
             RGBColor[
              0.33121568258703066`, 0.4610684087047351, 0.9423343784732514], 
             UndirectedEdge[54, 58] -> 
             RGBColor[
              0.2684799532608956, 0.3995198318623828, 0.9386009082064859], 
             UndirectedEdge[179, 183] -> 
             RGBColor[
              0.8339221074705745, 0.65332563598217, 0.5931545755652246], 
             UndirectedEdge[65, 198] -> 
             RGBColor[
              0.809127231953634, 0.8516409245369697, 0.9813908857977319], 
             UndirectedEdge[4, 80] -> 
             RGBColor[
              0.7123913946505943, 0.7749007508046878, 0.972203429564615], 
             UndirectedEdge[159, 197] -> 
             RGBColor[
              0.8557807275271554, 0.5446615637871581, 0.5792922791375287], 
             UndirectedEdge[78, 136] -> 
             RGBColor[
              0.9179856014839756, 0.8091909436388446, 0.6189147464565151], 
             UndirectedEdge[153, 188] -> 
             RGBColor[
              0.6253120347428027, 0.7063539747569785, 0.9638795069847599], 
             UndirectedEdge[35, 174] -> 
             RGBColor[
              0.6098919568384804, 0.6893702822195625, 0.9649850564709783], 
             UndirectedEdge[82, 130] -> 
             RGBColor[
              0.27791125977355285`, 0.4085218087190706, 0.9391713605597196], 
             UndirectedEdge[124, 176] -> 
             RGBColor[
              0.29262570831728996`, 0.4248985513559462, 0.9399759732365041], 
             UndirectedEdge[6, 186] -> 
             RGBColor[
              0.3110411018029656, 0.4413598612768941, 0.941130682141722], 
             UndirectedEdge[1, 144] -> 
             RGBColor[
              0.9074142416068287, 0.6532261133367169, 0.24715284778639957`], 
             UndirectedEdge[43, 67] -> 
             RGBColor[
              0.8367855353364704, 0.2837553208862874, 0.18285917622251102`], 
             UndirectedEdge[24, 119] -> 
             RGBColor[
              0.37190268708568275`, 0.48151336908456555`, 0.9461947206260288],
              UndirectedEdge[93, 139] -> 
             RGBColor[
              0.2366529007205347, 0.36606758169078113`, 0.9367884046482173], 
             UndirectedEdge[38, 146] -> 
             RGBColor[
              0.8804514017100027, 0.8667932734581691, 0.6490490676279728], 
             UndirectedEdge[110, 127] -> 
             RGBColor[
              0.46330733319948464`, 0.5715960026043997, 0.9518806741110254], 
             UndirectedEdge[41, 81] -> 
             RGBColor[
              0.563023955866433, 0.6561272371693612, 0.9587424547119633], 
             UndirectedEdge[85, 194] -> 
             RGBColor[
              0.35434213313173446`, 0.48133507879042225`, 0.9437993452840767],
              UndirectedEdge[52, 70] -> 
             RGBColor[
              0.2130689137116028, 0.34127931603325223`, 0.9354453314774407], 
             UndirectedEdge[149, 170] -> 
             RGBColor[
              0.2079666859588458, 0.3359165511651807, 0.9351547671549908], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.30721338060851633`, 0.43871808624608816`, 0.9408621191648285],
              UndirectedEdge[92, 155] -> 
             RGBColor[
              0.23916918979888965`, 0.36871236105407446`, 0.9369317035887135],
              UndirectedEdge[57, 141] -> 
             RGBColor[
              0.35995825064388254`, 0.48619947750517123`, 0.9441571993258131],
              UndirectedEdge[149, 159] -> 
             RGBColor[
              0.5281062347020681, 0.2689429967185235, 0.5529651961863387], 
             UndirectedEdge[142, 167] -> 
             RGBColor[
              0.7780824099898748, 0.8273108495391253, 0.9783266471470176], 
             UndirectedEdge[117, 173] -> 
             RGBColor[
              0.8870698836005233, 0.9096475021441977, 0.8455791000881498], 
             UndirectedEdge[99, 179] -> 
             RGBColor[
              0.6860146185776324, 0.753440204048828, 0.970158876487192], 
             UndirectedEdge[5, 11] -> 
             RGBColor[
              0.2640346736892395, 0.39484756118556874`, 0.938347756111082], 
             UndirectedEdge[29, 188] -> 
             RGBColor[
              0.8291485068413533, 0.8647956293451209, 0.8611126603250323], 
             UndirectedEdge[46, 178] -> 
             RGBColor[
              0.7700871696380653, 0.8204498262888431, 0.9719037985104857], 
             UndirectedEdge[101, 137] -> 
             RGBColor[
              0.25101571036429215`, 0.3811638052810985, 0.9376063454095565], 
             UndirectedEdge[3, 20] -> 
             RGBColor[
              0.24453230342971405`, 0.374349333521115, 0.9372371249759732], 
             UndirectedEdge[186, 199] -> 
             RGBColor[
              0.2771594494145085, 0.4086425326316706, 0.9390951926722704], 
             UndirectedEdge[156, 179] -> 
             RGBColor[
              0.864388741144453, 0.8948015330551333, 0.986901517469225], 
             UndirectedEdge[67, 87] -> 
             RGBColor[
              0.9030901336605541, 0.565118857520931, 0.5070115413121625], 
             UndirectedEdge[3, 10] -> 
             RGBColor[
              0.27648968445364525`, 0.4079385671922522, 0.9390570505485776], 
             UndirectedEdge[55, 185] -> 
             RGBColor[
              0.5609776882411449, 0.6497765761810184, 0.9606709927749343], 
             UndirectedEdge[5, 28] -> 
             RGBColor[
              0.28849193082278163`, 0.4205536891125868, 0.9397405607235676], 
             UndirectedEdge[37, 170] -> 
             RGBColor[
              0.18667955632742156`, 0.31354242824058126`, 0.9339424966139673],
              UndirectedEdge[49, 154] -> 
             RGBColor[
              0.9106325715742103, 0.628355413292651, 0.5269175709668971], 
             UndirectedEdge[24, 89] -> 
             RGBColor[
              0.5164596179840519, 0.3607037715624661, 0.5664186648111262], 
             UndirectedEdge[73, 115] -> 
             RGBColor[
              0.27934432739444803`, 0.41093897791785206`, 0.9392196182409905],
              UndirectedEdge[153, 174] -> 
             RGBColor[
              0.4836903414503127, 0.5897681807806197, 0.9530364909078715], 
             UndirectedEdge[119, 183] -> 
             RGBColor[
              0.7123944253398227, 0.5572003826444346, 0.5818533249803631], 
             UndirectedEdge[4, 168] -> 
             RGBColor[
              0.8717390399773187, 0.9006124860515876, 0.9850092222919777], 
             UndirectedEdge[144, 181] -> 
             RGBColor[
              0.920422900102938, 0.7115997715799838, 0.5555552779943531], 
             UndirectedEdge[53, 123] -> 
             RGBColor[
              0.2309218560021901, 0.36004389032257866`, 0.9364620301298284], 
             UndirectedEdge[110, 162] -> 
             RGBColor[
              0.7939641442587955, 0.8384977959010833, 0.9379384858342741], 
             UndirectedEdge[127, 176] -> 
             RGBColor[
              0.3078922888084153, 0.4397573979887158, 0.940888855185277], 
             UndirectedEdge[9, 102] -> 
             RGBColor[
              0.31720087863442126`, 0.44471069767262583`, 0.9415958382088386],
              UndirectedEdge[27, 195] -> 
             RGBColor[
              0.22783801477683696`, 0.3568025776679057, 0.9362864099341788], 
             UndirectedEdge[60, 130] -> 
             RGBColor[
              0.2455906790412874, 0.3754617533937681, 0.9372973979013259], 
             UndirectedEdge[89, 122] -> 
             RGBColor[
              0.9234652804391932, 0.7016588310893552, 0.3360475342402131], 
             UndirectedEdge[5, 106] -> 
             RGBColor[
              0.2786294913144741, 0.4101876398745743, 0.9391789093837413], 
             UndirectedEdge[83, 199] -> 
             RGBColor[
              0.2640684264301843, 0.3948830374563491, 0.938349678279746], 
             UndirectedEdge[118, 125] -> 
             RGBColor[
              0.5461336776674304, 0.6195695759530597, 0.9625480754195246], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.2678093745072151, 0.3988150110751161, 0.9385627197384963], 
             UndirectedEdge[5, 112] -> 
             RGBColor[
              0.29182817897856506`, 0.4240602974546656, 0.9399305551205026], 
             UndirectedEdge[109, 146] -> 
             RGBColor[
              0.5668187671363596, 0.653709441066444, 0.9615199202813867], 
             UndirectedEdge[164, 184] -> 
             RGBColor[
              0.33292802569279517`, 0.46149073880095526`, 0.9424823291114712],
              UndirectedEdge[51, 164] -> 
             RGBColor[
              0.28843151316149873`, 0.42049018631987756`, 0.9397371200271375],
              UndirectedEdge[45, 168] -> 
             RGBColor[
              0.9114761724933723, 0.7607551980488345, 0.6070253886431892], 
             UndirectedEdge[148, 165] -> 
             RGBColor[
              0.2118480097340456, 0.33999606854305653`, 0.9353758028020844], 
             UndirectedEdge[166, 184] -> 
             RGBColor[
              0.3810287222999791, 0.5044496610209838, 0.9454997911478531], 
             UndirectedEdge[21, 132] -> 
             RGBColor[
              0.28420798371714023`, 0.41536166731241486`, 0.9395218357203131],
              UndirectedEdge[96, 157] -> 
             RGBColor[
              0.43194074873512733`, 0.5454775949392545, 0.9495354789637005], 
             UndirectedEdge[42, 102] -> 
             RGBColor[
              0.4476381958746549, 0.5602937273030086, 0.9502551687958871], 
             UndirectedEdge[117, 120] -> 
             RGBColor[
              0.8678835994276715, 0.8465560061197337, 0.6325812491960736], 
             UndirectedEdge[25, 129] -> 
             RGBColor[
              0.9845905971173718, 0.9596826071563495, 0.39463780893289646`], 
             UndirectedEdge[57, 90] -> 
             RGBColor[
              0.37426337273503046`, 0.49858985526418154`, 0.9450687090559382],
              UndirectedEdge[51, 184] -> 
             RGBColor[
              0.3266364768489205, 0.4548779220588064, 0.942124034712325], 
             UndirectedEdge[95, 103] -> 
             RGBColor[
              0.9219582849086154, 0.7097965364380157, 0.2919118882865176], 
             UndirectedEdge[47, 105] -> 
             RGBColor[
              0.3973660260121461, 0.5186002123597028, 0.9465407896938819], 
             UndirectedEdge[127, 177] -> 
             RGBColor[
              0.3075972075411117, 0.4394472488675467, 0.9408720507436377], 
             UndirectedEdge[73, 153] -> 
             RGBColor[
              0.4395524049734263, 0.5500947505807087, 0.9502769094004289], 
             UndirectedEdge[137, 199] -> 
             RGBColor[
              0.26123779500061556`, 0.39190786435147384`, 0.9381884780073761],
              UndirectedEdge[138, 185] -> 
             RGBColor[
              0.8411744991425061, 0.7559037234450623, 0.613171500043548], 
             UndirectedEdge[88, 136] -> 
             RGBColor[
              0.8101006391447247, 0.7240376246779792, 0.6083933870270145], 
             UndirectedEdge[55, 76] -> 
             RGBColor[
              0.31436618073050393`, 0.4437147149372155, 0.9413617820054831], 
             UndirectedEdge[135, 176] -> 
             RGBColor[
              0.26373796268785954`, 0.3945356991105544, 0.938330858858498], 
             UndirectedEdge[69, 123] -> 
             RGBColor[
              0.3260085199796461, 0.4514023478470298, 0.9421913646386602], 
             UndirectedEdge[2, 40] -> 
             RGBColor[
              0.43435111341602517`, 0.5495958945368197, 0.9491845094203311], 
             UndirectedEdge[105, 174] -> 
             RGBColor[
              0.3623104663482657, 0.48823684852250904`, 0.9443070804305137], 
             UndirectedEdge[89, 138] -> 
             RGBColor[
              0.8833839545319762, 0.5539525957731882, 0.22400589739062848`], 
             UndirectedEdge[37, 128] -> 
             RGBColor[
              0.5402876317341454, 0.454787094862522, 0.5818823157705433], 
             UndirectedEdge[88, 153] -> 
             RGBColor[
              0.6490823398625842, 0.7249235177775619, 0.9662487088529688], 
             UndirectedEdge[113, 197] -> 
             RGBColor[
              0.8946095450697447, 0.7772196138099509, 0.6138944273650201], 
             UndirectedEdge[31, 178] -> 
             RGBColor[
              0.8964701273649321, 0.9201113391332241, 0.9839677082524034], 
             UndirectedEdge[82, 177] -> 
             RGBColor[
              0.3061026011103605, 0.4381526958983335, 0.9407768157434988], 
             UndirectedEdge[87, 108] -> 
             RGBColor[
              0.8846035797290293, 0.9091596462519311, 0.913892802031036], 
             UndirectedEdge[64, 86] -> 
             RGBColor[
              0.5072811113074129, 0.6092066601914048, 0.9548145013504485], 
             UndirectedEdge[116, 157] -> 
             RGBColor[
              0.47363379400133276`, 0.5818257161885222, 0.9521834927723848], 
             UndirectedEdge[120, 168] -> 
             RGBColor[
              0.9476806026150666, 0.909778086957847, 0.6376934323137864], 
             UndirectedEdge[18, 54] -> 
             RGBColor[
              0.295588460550005, 0.42712274502129255`, 0.9401772792428172], 
             UndirectedEdge[161, 176] -> 
             RGBColor[
              0.301427951999442, 0.43415026756037145`, 0.9404772479924501], 
             UndirectedEdge[168, 172] -> 
             RGBColor[
              0.9662845352880476, 0.9716239920088556, 0.7873059163017873], 
             UndirectedEdge[142, 157] -> 
             RGBColor[
              0.5992869263853755, 0.6855671502648439, 0.9615972085868523], 
             UndirectedEdge[121, 171] -> 
             RGBColor[
              0.7085728332018904, 0.7711751170925334, 0.9725147444177542], 
             UndirectedEdge[47, 94] -> 
             RGBColor[
              0.4348245890199799, 0.551044936914969, 0.9489276162054343], 
             UndirectedEdge[70, 93] -> 
             RGBColor[
              0.21891136206643785`, 0.34742009968680476`, 0.9357780502681208],
              UndirectedEdge[32, 163] -> 
             RGBColor[
              0.23408691252963393`, 0.3633705654090964, 0.9366422754167848], 
             UndirectedEdge[35, 142] -> 
             RGBColor[
              0.7396311759520104, 0.7966508792482756, 0.9746591341186641], 
             UndirectedEdge[12, 193] -> 
             RGBColor[
              0.4503245613855142, 0.5609229257874412, 0.950895392546576], 
             UndirectedEdge[35, 94] -> 
             RGBColor[
              0.6282503776636906, 0.7052714236172997, 0.9661548388122466], 
             UndirectedEdge[116, 174] -> 
             RGBColor[
              0.38549669526037655`, 0.5083195946324296, 0.9457844864340161], 
             UndirectedEdge[112, 140] -> 
             RGBColor[
              0.30347647446516857`, 0.4363033945556761, 0.9405939083163557], 
             UndirectedEdge[86, 176] -> 
             RGBColor[
              0.3430782654932676, 0.4702337224945253, 0.9431308745058982], 
             UndirectedEdge[61, 73] -> 
             RGBColor[
              0.28346587285648317`, 0.41527098351952657`, 0.9394543341577734],
              UndirectedEdge[33, 66] -> 
             RGBColor[
              0.5073300220022017, 0.606620425388813, 0.955851339828218], 
             UndirectedEdge[48, 106] -> 
             RGBColor[
              0.29607730783621694`, 0.42775376738301063`, 0.9402008266352594],
              UndirectedEdge[86, 199] -> 
             RGBColor[
              0.3321240507225622, 0.4587201482331828, 0.9425070481800151], 
             UndirectedEdge[10, 59] -> 
             RGBColor[
              0.3690604515059446, 0.4922869105332728, 0.9448029598331952], 
             UndirectedEdge[1, 113] -> 
             RGBColor[
              0.9293073420017215, 0.7556088200837405, 0.2655373341471002], 
             UndirectedEdge[125, 128] -> 
             RGBColor[
              0.5342706715319968, 0.44846288819275276`, 0.5815396587883258], 
             UndirectedEdge[53, 165] -> 
             RGBColor[
              0.21515759774182608`, 0.3434746553792333, 0.935564278943031], 
             UndirectedEdge[87, 143] -> 
             RGBColor[
              0.9043865074094275, 0.5750833542293711, 0.5082529502781284], 
             UndirectedEdge[61, 105] -> 
             RGBColor[
              0.30850366715074595`, 0.4384008305619083, 0.9409968714949317], 
             UndirectedEdge[29, 47] -> 
             RGBColor[
              0.7225823732127437, 0.7785731992059557, 0.8525033535115121], 
             UndirectedEdge[24, 27] -> 
             RGBColor[
              0.22783801619652955`, 0.3568025791600926, 0.9362864100150281], 
             UndirectedEdge[98, 117] -> 
             RGBColor[
              0.8762433687105626, 0.9035134810174441, 0.9541841801385145], 
             UndirectedEdge[1, 88] -> 
             RGBColor[
              0.8352535964645615, 0.823065908134689, 0.6322506322661987], 
             UndirectedEdge[190, 195] -> 
             RGBColor[
              0.1793170310330229, 0.30580394734510286`, 0.9335232116903315], 
             UndirectedEdge[4, 173] -> 
             RGBColor[
              0.9000135688899087, 0.9197592074679171, 0.8468692056721795], 
             UndirectedEdge[81, 164] -> 
             RGBColor[
              0.43552843920258344`, 0.5470178923073767, 0.9499428350575294], 
             UndirectedEdge[82, 123] -> 
             RGBColor[
              0.28451493492765345`, 0.4154626900032179, 0.9395474300904838], 
             UndirectedEdge[43, 87] -> 
             RGBColor[
              0.9216699742916543, 0.7079316543496461, 0.5248036176834326], 
             UndirectedEdge[38, 171] -> 
             RGBColor[
              0.919639217056486, 0.8978474840035989, 0.6528380765050477], 
             UndirectedEdge[46, 85] -> 
             RGBColor[
              0.4789487657995369, 0.5853416186622634, 0.9528226814867443], 
             UndirectedEdge[64, 69] -> 
             RGBColor[
              0.512094113243802, 0.613375440560194, 0.9551211815778647], 
             UndirectedEdge[60, 82] -> 
             RGBColor[
              0.2862778470683244, 0.4173156224381487, 0.9396478253289002], 
             UndirectedEdge[77, 189] -> 
             RGBColor[
              0.2658927211222934, 0.3968004868447199, 0.9384535691636595], 
             UndirectedEdge[101, 187] -> 
             RGBColor[
              0.2673357347336053, 0.3983171856425559, 0.9385357466540765], 
             UndirectedEdge[64, 161] -> 
             RGBColor[
              0.4656307978135873, 0.573123205257251, 0.9521608748370004], 
             UndirectedEdge[7, 160] -> 
             RGBColor[
              0.3585859521924276, 0.48501086156024664`, 0.9440697576819622], 
             UndirectedEdge[16, 83] -> 
             RGBColor[
              0.2894048145974629, 0.4201988877306557, 0.9398406710693048], 
             UndirectedEdge[13, 124] -> 
             RGBColor[
              0.3345268948480242, 0.4625364133999037, 0.9425966268829805], 
             UndirectedEdge[46, 171] -> 
             RGBColor[
              0.7361063058563833, 0.7935280305622586, 0.9746822802435494], 
             UndirectedEdge[1, 197] -> 
             RGBColor[
              0.9236147906417135, 0.8926515043216656, 0.6409097972593247], 
             UndirectedEdge[26, 80] -> 
             RGBColor[
              0.5081499735315052, 0.6100326873138424, 0.9548495666212384], 
             UndirectedEdge[23, 43] -> 
             RGBColor[
              0.9244722625683395, 0.7076214459861772, 0.37157972421419916`], 
             UndirectedEdge[13, 86] -> 
             RGBColor[
              0.38497945202400186`, 0.5078715845384828, 0.9457515281523746], 
             UndirectedEdge[31, 146] -> 
             RGBColor[
              0.8233014482367667, 0.8621353328612098, 0.9829571811083924], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.6527715209369094, 0.7286468226851102, 0.9660412183253722], 
             UndirectedEdge[124, 127] -> 
             RGBColor[
              0.30632106017096694`, 0.43810593706910805`, 0.9407993760387987],
              UndirectedEdge[60, 163] -> 
             RGBColor[
              0.24348971297155947`, 0.37325350484554143`, 0.9371777509917558],
              UndirectedEdge[4, 184] -> 
             RGBColor[
              0.5880093557297629, 0.671690292538539, 0.9630281942774768], 
             UndirectedEdge[144, 192] -> 
             RGBColor[
              0.8369174478199836, 0.2847692580389892, 0.18298549576569717`], 
             UndirectedEdge[38, 192] -> 
             RGBColor[
              0.8910636363690327, 0.5135395909571491, 0.2410026071488931], 
             UndirectedEdge[49, 108] -> 
             RGBColor[
              0.8079850952769174, 0.5485190612635439, 0.5798638479373164], 
             UndirectedEdge[83, 165] -> 
             RGBColor[
              0.2373756354905151, 0.36682722175806165`, 0.9368295633241774], 
             UndirectedEdge[183, 192] -> 
             RGBColor[
              0.8386147396738325, 0.29544751505205596`, 0.18451810443518368`],
              UndirectedEdge[79, 159] -> 
             RGBColor[
              0.5133063068014707, 0.25338733412536907`, 0.5521223621869309], 
             UndirectedEdge[81, 166] -> 
             RGBColor[
              0.4836291358097673, 0.5899768145274054, 0.9529602970939112], 
             UndirectedEdge[118, 119] -> 
             RGBColor[
              0.7390929491372125, 0.7956716911845035, 0.9752408612005126], 
             UndirectedEdge[47, 153] -> 
             RGBColor[
              0.518745901114193, 0.6201315446178133, 0.9552702001712396], 
             UndirectedEdge[74, 184] -> 
             RGBColor[
              0.3369577946710508, 0.46572628149921225`, 0.9427118184932739], 
             UndirectedEdge[149, 190] -> 
             RGBColor[
              0.2066375350628038, 0.33451952930040635`, 0.9350790739777637], 
             UndirectedEdge[55, 139] -> 
             RGBColor[
              0.3007701310464627, 0.42942440467994913`, 0.9405875070895301], 
             UndirectedEdge[22, 138] -> 
             RGBColor[
              0.8785987668628523, 0.5171715464656945, 0.2194235962745789], 
             UndirectedEdge[113, 144] -> 
             RGBColor[
              0.8784089960348599, 0.5377942228250021, 0.22013747789209492`], 
             UndirectedEdge[80, 172] -> 
             RGBColor[
              0.8069368899613232, 0.8459122567619559, 0.7745001235744244], 
             UndirectedEdge[8, 156] -> 
             RGBColor[
              0.6845205611909437, 0.7511737984198581, 0.97104590551255], 
             UndirectedEdge[22, 118] -> 
             RGBColor[
              0.8788646923664576, 0.6380810443549103, 0.5908825042695605], 
             UndirectedEdge[100, 163] -> 
             RGBColor[
              0.22341821875914586`, 0.35215709182205945`, 0.9360347090894736],
              UndirectedEdge[12, 154] -> 
             RGBColor[
              0.7852450872055535, 0.8309115028617888, 0.9166639457901922], 
             UndirectedEdge[67, 129] -> 
             RGBColor[
              0.9042326927843938, 0.5598741577929227, 0.2908641337345006], 
             UndirectedEdge[49, 129] -> 
             RGBColor[
              0.9124986472874659, 0.6234099062678943, 0.2987796211017028], 
             UndirectedEdge[127, 175] -> 
             RGBColor[
              0.32099276834406665`, 0.45244953519915593`, 0.9416743532494919],
              UndirectedEdge[30, 198] -> 
             RGBColor[
              0.7949540018905729, 0.840339575606766, 0.9800390304617252], 
             UndirectedEdge[5, 140] -> 
             RGBColor[
              0.2938553613475648, 0.42619099465527016`, 0.9400460001574695], 
             UndirectedEdge[147, 156] -> 
             RGBColor[
              0.7007698065694198, 0.7645047047938165, 0.9722866893066117], 
             UndirectedEdge[122, 159] -> 
             RGBColor[
              0.907791394547121, 0.5811824757822961, 0.3210382034088427], 
             UndirectedEdge[82, 110] -> 
             RGBColor[
              0.4618127267687334, 0.5703014496351865, 0.9517854391108865], 
             UndirectedEdge[83, 176] -> 
             RGBColor[
              0.2750226412008897, 0.4063966117176916, 0.9389735046056292], 
             UndirectedEdge[10, 77] -> 
             RGBColor[
              0.2948550356150111, 0.4272417156933656, 0.9401029301281152], 
             UndirectedEdge[104, 130] -> 
             RGBColor[
              0.2280794521267412, 0.3570563436306672, 0.9363001594340813], 
             UndirectedEdge[30, 66] -> 
             RGBColor[
              0.7926835884248224, 0.8385659113515402, 0.9798127368656795], 
             UndirectedEdge[85, 132] -> 
             RGBColor[
              0.3061847210307328, 0.43439681259051416`, 0.9409221739886695], 
             UndirectedEdge[24, 195] -> 
             RGBColor[
              0.1789270014196926, 0.30539400149218693`, 0.9335010000808495], 
             UndirectedEdge[50, 123] -> 
             RGBColor[
              0.24633186843467056`, 0.37624079044033565`, 0.9373396075407877],
              UndirectedEdge[42, 153] -> 
             RGBColor[
              0.5537057705483233, 0.648562314548655, 0.9580088930300842], 
             UndirectedEdge[127, 161] -> 
             RGBColor[
              0.31512330385311904`, 0.4473576532735334, 0.9413006507947447], 
             UndirectedEdge[7, 18] -> 
             RGBColor[
              0.33441529127436986`, 0.4640754499257662, 0.9425296245415398], 
             UndirectedEdge[65, 66] -> 
             RGBColor[
              0.8068568184878835, 0.8498672602817441, 0.9811645922016861], 
             UndirectedEdge[150, 152] -> 
             RGBColor[
              0.2823331640327409, 0.4140804347278859, 0.9393898280659538], 
             UndirectedEdge[25, 87] -> 
             RGBColor[
              0.9834480379935321, 0.9649273068843578, 0.6107852165105583], 
             UndirectedEdge[69, 82] -> 
             RGBColor[
              0.3600920128525825, 0.48631533560726303`, 0.9441657225354702], 
             UndirectedEdge[1, 159] -> 
             RGBColor[
              0.8904785244591324, 0.5230507700609477, 0.2309351859196088], 
             UndirectedEdge[23, 131] -> 
             RGBColor[
              0.9464189057965813, 0.8120568568548516, 0.39007974658807487`], 
             UndirectedEdge[126, 160] -> 
             RGBColor[
              0.336968383677942, 0.466146182368601, 0.9426974544072704], 
             UndirectedEdge[67, 131] -> 
             RGBColor[
              0.8587321785647122, 0.38819073175496194`, 0.20135919859638673`],
              UndirectedEdge[142, 174] -> 
             RGBColor[
              0.5111498276444193, 0.6120610287087513, 0.9551982022484837], 
             UndirectedEdge[22, 122] -> 
             RGBColor[
              0.9186800927700692, 0.6648777817818614, 0.33146523312416354`], 
             UndirectedEdge[32, 176] -> 
             RGBColor[
              0.264674301203473, 0.39551985025775493`, 0.9383841819517735], 
             UndirectedEdge[47, 160] -> 
             RGBColor[
              0.4091167531918066, 0.528778101634004, 0.9472895356390099], 
             UndirectedEdge[79, 125] -> 
             RGBColor[
              0.19146399032539158`, 0.3185711717230839, 0.934214963052216], 
             UndirectedEdge[47, 111] -> 
             RGBColor[
              0.45600877007092583`, 0.5691987153613436, 0.9503313034018304], 
             UndirectedEdge[3, 186] -> 
             RGBColor[
              0.27284687806334806`, 0.40410974670878463`, 0.9388495981136993],
              UndirectedEdge[105, 160] -> 
             RGBColor[
              0.35496105134530265`, 0.4818711546392811, 0.9438387822053573], 
             UndirectedEdge[9, 189] -> 
             RGBColor[
              0.24597910372864595`, 0.37587001236772954`, 0.9373195181126482],
              UndirectedEdge[64, 175] -> 
             RGBColor[
              0.4715002623045349, 0.5782150871828736, 0.9525345772917476], 
             UndirectedEdge[100, 165] -> 
             RGBColor[
              0.21635860172261037`, 0.34473698671108804`, 0.9356326743430103],
              UndirectedEdge[101, 161] -> 
             RGBColor[
              0.28025165259241314`, 0.41189263422865363`, 0.9392712890687474],
              UndirectedEdge[123, 187] -> 
             RGBColor[
              0.26662928669062347`, 0.3975746639579891, 0.9384955154831248], 
             UndirectedEdge[90, 198] -> 
             RGBColor[
              0.542054826289809, 0.636504451768819, 0.9581455985091416], 
             UndirectedEdge[146, 171] -> 
             RGBColor[
              0.8352823460284233, 0.8716885755474699, 0.9840999298352342], 
             UndirectedEdge[62, 157] -> 
             RGBColor[
              0.4569597398647052, 0.567383488557704, 0.951121036787086], 
             UndirectedEdge[2, 164] -> 
             RGBColor[
              0.3359219335901057, 0.4640839113434194, 0.9426730982752791], 
             UndirectedEdge[94, 142] -> 
             RGBColor[
              0.5295082484696294, 0.6279621701064884, 0.9563679845897519], 
             UndirectedEdge[12, 175] -> 
             RGBColor[
              0.4521802655001208, 0.5625302434211127, 0.9510136363718239], 
             UndirectedEdge[23, 64] -> 
             RGBColor[
              0.8080908888760686, 0.8465853309633324, 0.7529704509533501], 
             UndirectedEdge[73, 160] -> 
             RGBColor[
              0.3299232570510399, 0.45874130759689935`, 0.9422962448681991], 
             UndirectedEdge[47, 142] -> 
             RGBColor[
              0.5462053873082997, 0.642424392545945, 0.9574319115118519], 
             UndirectedEdge[31, 120] -> 
             RGBColor[
              0.9036386065731989, 0.8747348065350462, 0.6360795030302686], 
             UndirectedEdge[9, 20] -> 
             RGBColor[
              0.24298403719743245`, 0.3727220075452381, 0.9371489535044994], 
             UndirectedEdge[174, 188] -> 
             RGBColor[
              0.5230323018233795, 0.6213662256563972, 0.9563671406776864], 
             UndirectedEdge[45, 173] -> 
             RGBColor[
              0.9397507014059623, 0.7799019194651641, 0.46888537202339087`], 
             UndirectedEdge[139, 191] -> 
             RGBColor[
              0.2646944952587164, 0.3955410754901928, 0.9383853319733451], 
             UndirectedEdge[24, 170] -> 
             RGBColor[
              0.18064618334875748`, 0.3072009707020641, 0.9335989049484079], 
             UndirectedEdge[118, 195] -> 
             RGBColor[
              0.5461172634712222, 0.6195523235921249, 0.9625471406553332], 
             UndirectedEdge[124, 137] -> 
             RGBColor[
              0.27062078113387267`, 0.4017699776932086, 0.938722825186781], 
             UndirectedEdge[28, 63] -> 
             RGBColor[
              0.3238146353715521, 0.45360214621203954`, 0.941901450034025], 
             UndirectedEdge[7, 94] -> 
             RGBColor[
              0.3842937880206009, 0.5072776968412117, 0.9457078382483868], 
             UndirectedEdge[37, 190] -> 
             RGBColor[
              0.18535040543137957`, 0.3121454063758069, 0.9338668034367403], 
             UndirectedEdge[31, 40] -> 
             RGBColor[
              0.6710448937244029, 0.7408816350846033, 0.9693608389875064], 
             UndirectedEdge[18, 73] -> 
             RGBColor[
              0.3057525961329822, 0.4378058959624189, 0.9407561117277767], 
             UndirectedEdge[170, 195] -> 
             RGBColor[
              0.1806461819290649, 0.30720096920987716`, 0.9335989048675586], 
             UndirectedEdge[62, 191] -> 
             RGBColor[
              0.3182327281368137, 0.4474225004107011, 0.9415950184238715], 
             UndirectedEdge[152, 194] -> 
             RGBColor[
              0.3151343711235495, 0.4448783558224487, 0.9413924862035001], 
             UndirectedEdge[24, 37] -> 
             RGBColor[
              0.18496037581804925`, 0.31173546052289103`, 0.9338445918272582],
              UndirectedEdge[90, 177] -> 
             RGBColor[
              0.3407778041727428, 0.4681866139645882, 0.9429862890205556], 
             UndirectedEdge[94, 188] -> 
             RGBColor[
              0.5413907226485897, 0.6372673670541342, 0.9575369230189545], 
             UndirectedEdge[103, 133] -> 
             RGBColor[
              0.8438593008645356, 0.3288700512541642, 0.189270528206407], 
             UndirectedEdge[38, 179] -> 
             RGBColor[
              0.8863710041657746, 0.8714177118872631, 0.6496390782789341], 
             UndirectedEdge[54, 116] -> 
             RGBColor[
              0.33119462320051296`, 0.4579630134913923, 0.9424460724416142], 
             UndirectedEdge[4, 198] -> 
             RGBColor[
              0.7505232703667862, 0.8050337500894356, 0.9757688036175852], 
             UndirectedEdge[31, 38] -> 
             RGBColor[
              0.9076583192648293, 0.8882942413173389, 0.6516953277782057], 
             UndirectedEdge[35, 47] -> 
             RGBColor[
              0.6449475165023608, 0.7197336460567563, 0.9672187657343465], 
             UndirectedEdge[132, 151] -> 
             RGBColor[
              0.3020454023564957, 0.43081154280309575`, 0.9406584202630028], 
             UndirectedEdge[124, 135] -> 
             RGBColor[
              0.26216673405041124`, 0.39288423819094664`, 0.9382413797120197],
              UndirectedEdge[32, 127] -> 
             RGBColor[
              0.2783696530571501, 0.40872723597091687`, 0.9392075847540681], 
             UndirectedEdge[187, 199] -> 
             RGBColor[
              0.27755781936992874`, 0.40906124471293126`, 0.9391178792518959],
              UndirectedEdge[2, 51] -> 
             RGBColor[
              0.329630384746231, 0.45747109460127056`, 0.9423148038761329], 
             UndirectedEdge[40, 117] -> 
             RGBColor[
              0.6352898865788753, 0.7127028346692909, 0.9658625851533114], 
             UndirectedEdge[9, 17] -> 
             RGBColor[
              0.2497025677004787, 0.37978360908337694`, 0.9375315638774728], 
             UndirectedEdge[33, 57] -> 
             RGBColor[
              0.3418089819131736, 0.4704794931394012, 0.9430007439710605], 
             UndirectedEdge[124, 175] -> 
             RGBColor[
              0.3057261878529413, 0.4375906885663863, 0.9407614713007191], 
             UndirectedEdge[8, 147] -> 
             RGBColor[
              0.4644466210649416, 0.5759586789636362, 0.9510205021407936], 
             UndirectedEdge[108, 110] -> 
             RGBColor[
              0.6931298062895987, 0.7596256615132471, 0.9704393557617335], 
             UndirectedEdge[68, 107] -> 
             RGBColor[
              0.7614279257189907, 0.8138406211600655, 0.9767792324528825], 
             UndirectedEdge[1, 138] -> 
             RGBColor[
              0.9355441317544622, 0.7814661810006367, 0.2706140846810541], 
             UndirectedEdge[94, 160] -> 
             RGBColor[
              0.39241961435313644`, 0.5143158791945474, 0.9462256087169099], 
             UndirectedEdge[138, 142] -> 
             RGBColor[
              0.7768323613465915, 0.7056166385716411, 0.6067738726084364], 
             UndirectedEdge[6, 175] -> 
             RGBColor[
              0.3302248541081414, 0.460445903869875, 0.9422626135907659], 
             UndirectedEdge[34, 104] -> 
             RGBColor[
              0.2353413665909268, 0.3646890761644966, 0.936713714719777], 
             UndirectedEdge[15, 106] -> 
             RGBColor[
              0.3000813368943679, 0.43122185610482894`, 0.9404559598262209], 
             UndirectedEdge[61, 94] -> 
             RGBColor[
              0.34596223015857974`, 0.47084555511717463`, 0.9433836980064841],
              UndirectedEdge[144, 159] -> 
             RGBColor[
              0.8395801784922707, 0.30523617280220927`, 0.18553532966460354`],
              UndirectedEdge[83, 86] -> 
             RGBColor[
              0.32390396973941904`, 0.450080321936663, 0.9420389267285452], 
             UndirectedEdge[137, 176] -> 
             RGBColor[
              0.27219200977132096`, 0.4034214386128163, 0.9388123043332592], 
             UndirectedEdge[143, 159] -> 
             RGBColor[
              0.8217214517738456, 0.16796617350044618`, 0.16843379279049273`],
              UndirectedEdge[24, 144] -> 
             RGBColor[
              0.5177214492396762, 0.3704027595311762, 0.5676269958465465], 
             UndirectedEdge[76, 96] -> 
             RGBColor[
              0.2912734993929746, 0.42347729404149315`, 0.9398989669386781], 
             UndirectedEdge[98, 120] -> 
             RGBColor[
              0.9651286166376958, 0.922790787247423, 0.6081584957443529], 
             UndirectedEdge[98, 183] -> 
             RGBColor[
              0.916699432634126, 0.7182581461246227, 0.5672898177785806], 
             UndirectedEdge[55, 75] -> 
             RGBColor[
              0.3182717437982659, 0.44781970934843396`, 0.9415841980444295], 
             UndirectedEdge[35, 68] -> 
             RGBColor[
              0.8469990595612139, 0.880838075189855, 0.985268720497577], 
             UndirectedEdge[25, 43] -> 
             RGBColor[
              0.9171434396694482, 0.683563770249714, 0.28663285142090683`], 
             UndirectedEdge[47, 174] -> 
             RGBColor[
              0.4164661681947697, 0.535143795517232, 0.9477578338641661], 
             UndirectedEdge[29, 88] -> 
             RGBColor[
              0.8529188119611348, 0.8833651723657042, 0.8634818621932413], 
             UndirectedEdge[17, 140] -> 
             RGBColor[
              0.27217097999434126`, 0.4033993349838457, 0.9388111067185709], 
             UndirectedEdge[41, 90] -> 
             RGBColor[
              0.46883146462921355`, 0.577882603340978, 0.9518176941382794], 
             UndirectedEdge[151, 196] -> 
             RGBColor[
              0.4235249432869995, 0.5401212783183434, 0.9485216237575993], 
             UndirectedEdge[88, 94] -> 
             RGBColor[
              0.5651610277683712, 0.6558369100747177, 0.9599061248871635], 
             UndirectedEdge[57, 198] -> 
             RGBColor[
              0.528369365099485, 0.6246507931370399, 0.9572735730236723], 
             UndirectedEdge[71, 164] -> 
             RGBColor[
              0.2925031947568016, 0.42476978183606456`, 0.9399689962704769], 
             UndirectedEdge[95, 154] -> 
             RGBColor[
              0.9830766756699849, 0.9658160132096346, 0.6241438116222372], 
             UndirectedEdge[69, 90] -> 
             RGBColor[
              0.3947672159149649, 0.5163492536735178, 0.946375195812527], 
             UndirectedEdge[175, 176] -> 
             RGBColor[
              0.30729741649038966`, 0.43924214948599405`, 0.9408509504471974],
              UndirectedEdge[58, 115] -> 
             RGBColor[
              0.2648536806612042, 0.3957083894411449, 0.9383943973465231], 
             UndirectedEdge[42, 88] -> 
             RGBColor[
              0.6168180360411716, 0.6987299024450158, 0.9637087446681081], 
             UndirectedEdge[72, 134] -> 
             RGBColor[
              0.2403643210352666, 0.36996851975920364`, 0.9369997645445869], 
             UndirectedEdge[25, 49] -> 
             RGBColor[
              0.9068295535414201, 0.6042867218959704, 0.2767562624168388], 
             UndirectedEdge[23, 103] -> 
             RGBColor[
              0.928934953541638, 0.7326663131459502, 0.37549070825566344`], 
             UndirectedEdge[79, 192] -> 
             RGBColor[
              0.5106435761291835, 0.23292041936214905`, 0.5495725282880245], 
             UndirectedEdge[89, 170] -> 
             RGBColor[
              0.5181787984934242, 0.3625107392801563, 0.5665165695978354], 
             UndirectedEdge[41, 57] -> 
             RGBColor[
              0.4551460034388895, 0.5660289447091988, 0.9509456686528102], 
             UndirectedEdge[10, 14] -> 
             RGBColor[
              0.35304438919669967`, 0.4784146023517027, 0.943782430505298], 
             UndirectedEdge[6, 59] -> 
             RGBColor[
              0.39442835550292343`, 0.516055749816227, 0.9463536039267142], 
             UndirectedEdge[120, 183] -> 
             RGBColor[
              0.9083396633512348, 0.6613006712269123, 0.24568688683613962`], 
             UndirectedEdge[8, 194] -> 
             RGBColor[
              0.3983632803443602, 0.5194639839388066, 0.9466043338580932], 
             UndirectedEdge[63, 106] -> 
             RGBColor[
              0.3139521958632445, 0.44323609697402705`, 0.9413397986941987], 
             UndirectedEdge[129, 131] -> 
             RGBColor[
              0.9447591766437358, 0.8071223654903125, 0.32715623247964654`], 
             UndirectedEdge[22, 38] -> 
             RGBColor[
              0.904615065264268, 0.6177018117199344, 0.25397947076312033`], 
             UndirectedEdge[38, 117] -> 
             RGBColor[
              0.8719033121193018, 0.8601154409020264, 0.6481970739440106], 
             UndirectedEdge[136, 159] -> 
             RGBColor[
              0.8653255671392956, 0.4240224866042378, 0.2070779406804246], 
             UndirectedEdge[158, 166] -> 
             RGBColor[
              0.3220947514992546, 0.4482744245110126, 0.9419323901733808], 
             UndirectedEdge[75, 96] -> 
             RGBColor[
              0.29517906246073655`, 0.4275822884527116, 0.9401213829776245], 
             UndirectedEdge[118, 170] -> 
             RGBColor[
              0.5478364454002871, 0.6213592928020021, 0.9626450455228917], 
             UndirectedEdge[7, 58] -> 
             RGBColor[
              0.3073067839852605, 0.4364725367668565, 0.9409532535052085], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.7375823865275546, 0.7949242332798678, 0.9744789772559258], 
             UndirectedEdge[65, 180] -> 
             RGBColor[
              0.8230809086810591, 0.8625416428483053, 0.9827816578893989], 
             UndirectedEdge[151, 171] -> 
             RGBColor[
              0.6131733026438233, 0.690971104405486, 0.9657655862298374], 
             UndirectedEdge[37, 118] -> 
             RGBColor[
              0.5521506378695789, 0.625893782622829, 0.962890732401742], 
             UndirectedEdge[7, 47] -> 
             RGBColor[
              0.40099092685927107`, 0.5217399192806683, 0.9467717651704868], 
             UndirectedEdge[46, 99] -> 
             RGBColor[
              0.5809189759498203, 0.6706552206345228, 0.960151216244546], 
             UndirectedEdge[195, 197] -> 
             RGBColor[
              0.5339219968548683, 0.6098281490239381, 0.9613839452386224], 
             UndirectedEdge[5, 63] -> 
             RGBColor[
              0.3175297704097317, 0.4469963546537124, 0.9415435362720739], 
             UndirectedEdge[11, 63] -> 
             RGBColor[
              0.29935737823800995`, 0.4278960182850215, 0.9405086454215394], 
             UndirectedEdge[10, 193] -> 
             RGBColor[
              0.30300124599655587`, 0.4350697469532493, 0.9405937256719987], 
             UndirectedEdge[99, 147] -> 
             RGBColor[
              0.5223956840025993, 0.6231433757875112, 0.9555440483245787], 
             UndirectedEdge[9, 77] -> 
             RGBColor[
              0.2804804496400908, 0.41213311443233347`, 0.9392843187221377], 
             UndirectedEdge[43, 103] -> 
             RGBColor[
              0.859828066940869, 0.45161298487477564`, 0.20456223663524548`], 
             UndirectedEdge[54, 174] -> 
             RGBColor[
              0.3271085364710258, 0.454423850539001, 0.942185710608396], 
             UndirectedEdge[149, 197] -> 
             RGBColor[
              0.5612425008846491, 0.6385437309792414, 0.9629398075260546], 
             UndirectedEdge[87, 180] -> 
             RGBColor[
              0.8560213723624259, 0.8868310086243191, 0.9110439947166469], 
             UndirectedEdge[134, 191] -> 
             RGBColor[
              0.25554145744836393`, 0.3859206524153965, 0.9378640800107516], 
             UndirectedEdge[65, 131] -> 
             RGBColor[
              0.9106761538385292, 0.7880776994423069, 0.6150413032300603], 
             UndirectedEdge[107, 147] -> 
             RGBColor[
              0.5739634519525214, 0.664627405018551, 0.9598641490933124], 
             UndirectedEdge[50, 82] -> 
             RGBColor[
              0.28041536130760697`, 0.41115377820056886`, 0.9393139654375977],
              UndirectedEdge[30, 162] -> 
             RGBColor[
              0.9383242239537981, 0.9524410659335498, 0.9517777399403218], 
             UndirectedEdge[51, 74] -> 
             RGBColor[
              0.29246128213975436`, 0.4247257290181345, 0.9399666094089402], 
             UndirectedEdge[12, 161] -> 
             RGBColor[
              0.4463108010091732, 0.5574383614954901, 0.9506399339170767], 
             UndirectedEdge[78, 113] -> 
             RGBColor[
              0.9141333132318434, 0.7927873365838396, 0.6157566218013946], 
             UndirectedEdge[131, 133] -> 
             RGBColor[
              0.8613432531194789, 0.40826059496306566`, 0.20385956653881843`],
              UndirectedEdge[35, 188] -> 
             RGBColor[
              0.7515136501309705, 0.8059560761959215, 0.9758280725478667], 
             UndirectedEdge[181, 185] -> 
             RGBColor[
              0.8769516134578437, 0.9038519112831478, 0.9435125496118522], 
             UndirectedEdge[111, 188] -> 
             RGBColor[
              0.5625749036995356, 0.6554211455005088, 0.9589406102153506], 
             UndirectedEdge[41, 184] -> 
             RGBColor[
              0.46042354235664473`, 0.5706000836629397, 0.9512819487659052], 
             UndirectedEdge[135, 187] -> 
             RGBColor[
              0.2580530598737554, 0.38856050580927426`, 0.9380071120532948], 
             UndirectedEdge[51, 71] -> 
             RGBColor[
              0.2862116459129269, 0.41815696509391576`, 0.9396107018713307], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.2532145568819805, 0.3834749323861105, 0.937731566465837], 
             UndirectedEdge[26, 158] -> 
             RGBColor[
              0.3248339638099492, 0.45064699253772245`, 0.9421069303596279], 
             UndirectedEdge[101, 199] -> 
             RGBColor[
              0.262066422777004, 0.3927788046824936, 0.9382356671333965], 
             UndirectedEdge[84, 194] -> 
             RGBColor[
              0.30565287667395435`, 0.4349127039944547, 0.9408525291212098], 
             UndirectedEdge[6, 176] -> 
             RGBColor[
              0.31712437457249, 0.4477537666594349, 0.9414771155265509], 
             UndirectedEdge[18, 116] -> 
             RGBColor[
              0.35397661933935576`, 0.48101848911472117`, 0.9437760550684375],
              UndirectedEdge[98, 179] -> 
             RGBColor[
              0.8907110607570355, 0.9148157520026807, 0.9556261844734377], 
             UndirectedEdge[116, 142] -> 
             RGBColor[
              0.5152359143739065, 0.6156001916611427, 0.9554585640817019], 
             UndirectedEdge[77, 112] -> 
             RGBColor[
              0.3009216795649535, 0.4336181431321977, 0.9404484165262689], 
             UndirectedEdge[56, 190] -> 
             RGBColor[
              0.1793170310330229, 0.30580394734510286`, 0.9335232116903315], 
             UndirectedEdge[76, 126] -> 
             RGBColor[
              0.2917876480797086, 0.4240176969101601, 0.9399282469457728], 
             UndirectedEdge[168, 173] -> 
             RGBColor[
              0.9668668867879184, 0.9728695829823109, 0.8506912832058626], 
             UndirectedEdge[158, 164] -> 
             RGBColor[
              0.27399405489207074`, 0.4053155022909841, 0.9389149281369991], 
             UndirectedEdge[46, 146] -> 
             RGBColor[
              0.6969184905099, 0.7624738200168288, 0.9708932713664746], 
             UndirectedEdge[23, 25] -> 
             RGBColor[
              0.9862503262702172, 0.9646170985208886, 0.4575613230413248], 
             UndirectedEdge[9, 28] -> 
             RGBColor[
              0.27767181401552266`, 0.4091810603131285, 0.9391243710783226], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.9239792736477469, 0.9412455241190165, 0.9588251826995514], 
             UndirectedEdge[103, 129] -> 
             RGBColor[
              0.9272752243887925, 0.727731821781411, 0.3125671941472351], 
             UndirectedEdge[5, 48] -> 
             RGBColor[
              0.2996548823827041, 0.431514025062696, 0.9404045642131346], 
             UndirectedEdge[36, 169] -> 
             RGBColor[
              0.260181316759984, 0.39079743873598083`, 0.9381283131344916], 
             UndirectedEdge[159, 170] -> 
             RGBColor[
              0.5025049126013521, 0.2420343839730972, 0.5515072387664649], 
             UndirectedEdge[86, 175] -> 
             RGBColor[
              0.356178745028919, 0.4829258597049654, 0.9439163725701132], 
             UndirectedEdge[9, 97] -> 
             RGBColor[
              0.2707641427587703, 0.4019206598506281, 0.9387309894192344], 
             UndirectedEdge[7, 88] -> 
             RGBColor[
              0.5313273656076622, 0.6265318924404168, 0.9577502738522159], 
             UndirectedEdge[5, 77] -> 
             RGBColor[
              0.2913005664473497, 0.42350574323179174`, 0.9399005083673827], 
             UndirectedEdge[103, 131] -> 
             RGBColor[
              0.8817747101691108, 0.5560483957434501, 0.2230622590091212], 
             UndirectedEdge[15, 193] -> 
             RGBColor[
              0.32089862240878825`, 0.45236799072193, 0.941668354353746], 
             UndirectedEdge[167, 181] -> 
             RGBColor[
              0.9498028388938546, 0.9615340502113876, 0.9505692894275887], 
             UndirectedEdge[99, 146] -> 
             RGBColor[
              0.6800950161218604, 0.7488157656197341, 0.9695688658362309], 
             UndirectedEdge[163, 177] -> 
             RGBColor[
              0.2633144670135955, 0.39409057830572625`, 0.9383067414063544], 
             UndirectedEdge[76, 116] -> 
             RGBColor[
              0.3329665446591801, 0.4598254152907607, 0.9425469807473624], 
             UndirectedEdge[15, 59] -> 
             RGBColor[
              0.38695782791817696`, 0.5095851543019536, 0.9458775885149424], 
             UndirectedEdge[36, 151] -> 
             RGBColor[
              0.2998281417164218, 0.4284810612879339, 0.9405321505496939], 
             UndirectedEdge[38, 98] -> 
             RGBColor[
              0.9691483293293262, 0.9363502220297157, 0.6237743204922899], 
             UndirectedEdge[70, 139] -> 
             RGBColor[
              0.23141666930631707`, 0.36056397047819155`, 0.9364902090154877],
              UndirectedEdge[56, 195] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[66, 168] -> 
             RGBColor[
              0.8151061747990456, 0.8563704613486036, 0.9793645875552226], 
             UndirectedEdge[6, 161] -> 
             RGBColor[
              0.32435538961719373`, 0.45535402194425245`, 0.9418889111360187],
              UndirectedEdge[56, 118] -> 
             RGBColor[
              0.5461172634712221, 0.619552323592125, 0.9625471406553332], 
             UndirectedEdge[46, 117] -> 
             RGBColor[
              0.6883704009191991, 0.7557959874606861, 0.9700412776825125], 
             UndirectedEdge[79, 89] -> 
             RGBColor[
              0.5289801926935428, 0.3738636894324282, 0.5671316930183012], 
             UndirectedEdge[102, 140] -> 
             RGBColor[
              0.3396692909282838, 0.4683264235730946, 0.9428753810499368], 
             UndirectedEdge[32, 130] -> 
             RGBColor[
              0.23618787859936186`, 0.36557881395732306`, 0.936761922326355], 
             UndirectedEdge[105, 126] -> 
             RGBColor[
              0.3252176564982815, 0.45596829309429976`, 0.9419487084621424], 
             UndirectedEdge[86, 124] -> 
             RGBColor[
              0.3415070368558193, 0.46858226157491756`, 0.94304139535942], 
             UndirectedEdge[41, 168] -> 
             RGBColor[
              0.7441532266042006, 0.7995222771759883, 0.9732629767804062], 
             UndirectedEdge[43, 143] -> 
             RGBColor[
              0.8380819090853437, 0.29371981759472743`, 0.18410058518847694`],
              UndirectedEdge[56, 197] -> 
             RGBColor[
              0.5339219968548683, 0.6098281490239381, 0.9613839452386224], 
             UndirectedEdge[47, 73] -> 
             RGBColor[
              0.3723282317178833, 0.495470365317321, 0.9449982523567235], 
             UndirectedEdge[23, 108] -> 
             RGBColor[
              0.8874058680057144, 0.9088494378884622, 0.7606689085618024], 
             UndirectedEdge[97, 155] -> 
             RGBColor[
              0.2652922598561954, 0.3961693639826077, 0.9384193737828581], 
             UndirectedEdge[86, 161] -> 
             RGBColor[
              0.35030928053797133`, 0.47783397777934283`, 0.943542670115366], 
             UndirectedEdge[88, 188] -> 
             RGBColor[
              0.688424300235651, 0.7565215626533395, 0.9695793586227837], 
             UndirectedEdge[136, 197] -> 
             RGBColor[
              0.8984618333218767, 0.7936232208649558, 0.6170525520201404], 
             UndirectedEdge[65, 69] -> 
             RGBColor[
              0.6618396215787897, 0.7314857264416685, 0.9696204831011173], 
             UndirectedEdge[23, 67] -> 
             RGBColor[
              0.9058924219372393, 0.564808649157462, 0.35378764784292904`], 
             UndirectedEdge[31, 121] -> 
             RGBColor[
              0.6965919354102337, 0.7616218744062735, 0.9713719956909121], 
             UndirectedEdge[52, 145] -> 
             RGBColor[
              0.21010927874609994`, 0.3381685520328137, 0.9352767846445429], 
             UndirectedEdge[12, 87] -> 
             RGBColor[
              0.7859686037949694, 0.8312106955650405, 0.9046734035026598], 
             UndirectedEdge[128, 192] -> 
             RGBColor[
              0.8534502573357887, 0.36281213583181793`, 0.19689722402413434`],
              UndirectedEdge[78, 95] -> 
             RGBColor[
              0.9537951709684989, 0.944166482218568, 0.6841709176231596], 
             UndirectedEdge[123, 165] -> 
             RGBColor[
              0.23466718379435303`, 0.36398046729963934`, 0.9366753210068761],
              UndirectedEdge[24, 56] -> 
             RGBColor[
              0.1789270014196926, 0.30539400149218693`, 0.9335010000808495], 
             UndirectedEdge[50, 177] -> 
             RGBColor[
              0.2679195346173776, 0.39893079633545114`, 0.9385689931938027], 
             UndirectedEdge[18, 58] -> 
             RGBColor[
              0.2912619493997384, 0.4225753074857117, 0.9399308908333093], 
             UndirectedEdge[96, 182] -> 
             RGBColor[
              0.2856601600419676, 0.4175773184773137, 0.9395792955668297], 
             UndirectedEdge[49, 131] -> 
             RGBColor[
              0.8669981330677842, 0.45172648022993345`, 0.2092746859635889], 
             UndirectedEdge[28, 106] -> 
             RGBColor[
              0.28491435627629447`, 0.41679343143290143`, 0.9395368231456924],
              UndirectedEdge[57, 81] -> 
             RGBColor[
              0.4684558639722499, 0.5768344890925647, 0.951993469629622], 
             UndirectedEdge[7, 115] -> 
             RGBColor[
              0.3080070225358357, 0.4372085318811994, 0.9409931310547537], 
             UndirectedEdge[54, 94] -> 
             RGBColor[
              0.3454669572962359, 0.47032499193673805`, 0.9433554929496641], 
             UndirectedEdge[138, 181] -> 
             RGBColor[
              0.9485527902505714, 0.8398398392439036, 0.5790165148890076], 
             UndirectedEdge[55, 182] -> 
             RGBColor[
              0.30875284137949693`, 0.43781473937303605`, 0.9410421106336347],
              UndirectedEdge[17, 77] -> 
             RGBColor[
              0.26961618509412616`, 0.4007140835603673, 0.9386656149284841], 
             UndirectedEdge[144, 149] -> 
             RGBColor[
              0.5450419518497644, 0.3991183399942927, 0.5691828580531295], 
             UndirectedEdge[68, 179] -> 
             RGBColor[
              0.8317792747849202, 0.8687996297404257, 0.9837911974570385], 
             UndirectedEdge[103, 143] -> 
             RGBColor[
              0.8425446000586423, 0.3187646847545005, 0.18801156922994122`], 
             UndirectedEdge[80, 173] -> 
             RGBColor[
              0.807519241461194, 0.8471578477354111, 0.8378854904784999], 
             UndirectedEdge[161, 199] -> 
             RGBColor[
              0.2904737372287366, 0.422636693299029, 0.9398534216665669], 
             UndirectedEdge[43, 133] -> 
             RGBColor[
              0.8393966098912371, 0.3038251840943911, 0.18535954416494269`], 
             UndirectedEdge[6, 193] -> 
             RGBColor[
              0.3283691499935347, 0.4588385862362035, 0.9421443697655179], 
             UndirectedEdge[181, 188] -> 
             RGBColor[
              0.8244919498408892, 0.8628700233573725, 0.9382838606059434], 
             UndirectedEdge[120, 173] -> 
             RGBColor[
              0.9759551315276564, 0.9289248083741766, 0.49955341569398815`], 
             UndirectedEdge[2, 158] -> 
             RGBColor[
              0.31519292647680297`, 0.4422964105723771, 0.9414926119859944], 
             UndirectedEdge[95, 143] -> 
             RGBColor[
              0.9002121270530901, 0.5519033691579674, 0.2714502368397491], 
             UndirectedEdge[4, 172] -> 
             RGBColor[
              0.8994312173900378, 0.9185136164944618, 0.783483838768104], 
             UndirectedEdge[89, 113] -> 
             RGBColor[
              0.8771471647792357, 0.528095234856292, 0.21892914685667453`], 
             UndirectedEdge[34, 90] -> 
             RGBColor[
              0.31984837730012083`, 0.4461884593191548, 0.9417943891224722], 
             UndirectedEdge[28, 48] -> 
             RGBColor[
              0.30593974734452445`, 0.4381198166210231, 0.9407624779750857], 
             UndirectedEdge[5, 189] -> 
             RGBColor[
              0.2567992205359049, 0.38724264116718776`, 0.9379357077578933], 
             UndirectedEdge[8, 55] -> 
             RGBColor[
              0.4002897149094885, 0.5211325647337041, 0.9467270845651039], 
             UndirectedEdge[29, 138] -> 
             RGBColor[
              0.9532093472510355, 0.8417654452316519, 0.5018453146080967], 
             UndirectedEdge[8, 68] -> 
             RGBColor[
              0.6519110948314109, 0.7251718951051506, 0.9679355855003635], 
             UndirectedEdge[176, 187] -> 
             RGBColor[
              0.2885120341406341, 0.42057481897427373`, 0.9397417055777791], 
             UndirectedEdge[65, 133] -> 
             RGBColor[
              0.872760744533954, 0.5608993549530209, 0.5812495724273461], 
             UndirectedEdge[68, 147] -> 
             RGBColor[
              0.668160340209887, 0.7385028014791089, 0.9691763692944251], 
             UndirectedEdge[89, 192] -> 
             RGBColor[
              0.8356556165643594, 0.2750702700702792, 0.18177716473027677`], 
             UndirectedEdge[2, 74] -> 
             RGBColor[
              0.3399517025683613, 0.46831945404167635`, 0.9429025876570818], 
             UndirectedEdge[156, 185] -> 
             RGBColor[
              0.8452085345226001, 0.8798178098671724, 0.9849898137223804], 
             UndirectedEdge[126, 182] -> 
             RGBColor[
              0.2861743087287016, 0.41811772134598074`, 0.9396085755739244], 
             UndirectedEdge[18, 188] -> 
             RGBColor[
              0.49151222590235866`, 0.5940651201386887, 0.9543587093121076], 
             UndirectedEdge[68, 156] -> 
             RGBColor[
              0.8882342803358891, 0.9137179209353309, 0.9892017726661817], 
             UndirectedEdge[29, 181] -> 
             RGBColor[
              0.988986461566373, 0.9897136330697374, 0.8321863641764009], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.9759778030702638, 0.9313399748264705, 0.5237839339684474], 
             UndirectedEdge[30, 180] -> 
             RGBColor[
              0.8089076786179981, 0.8512402939181014, 0.9814298025533923], 
             UndirectedEdge[31, 196] -> 
             RGBColor[
              0.6728409042264264, 0.742339717319497, 0.969502227513229], 
             UndirectedEdge[193, 199] -> 
             RGBColor[
              0.2944874976050776, 0.4261212575909801, 0.9401088802960662], 
             UndirectedEdge[30, 110] -> 
             RGBColor[
              0.7493871054318795, 0.8041704915393881, 0.9758883443405271], 
             UndirectedEdge[12, 59] -> 
             RGBColor[
              0.516383766894903, 0.6181400893674647, 0.9551046267077723], 
             UndirectedEdge[38, 156] -> 
             RGBColor[
              0.9428260097167436, 0.9163360030821683, 0.6550496534880772], 
             UndirectedEdge[72, 152] -> 
             RGBColor[
              0.2658080334878341, 0.396711474771397, 0.9384487463281612], 
             UndirectedEdge[37, 79] -> 
             RGBColor[
              0.19748095052754017`, 0.3248953783928531, 0.9345576200344334], 
             UndirectedEdge[170, 197] -> 
             RGBColor[
              0.5356411787839332, 0.6116351182338152, 0.9614818501061808], 
             UndirectedEdge[86, 127] -> 
             RGBColor[
              0.3567736173469446, 0.48344110820768715`, 0.9439542773081928], 
             UndirectedEdge[69, 127] -> 
             RGBColor[
              0.3615866192833338, 0.48760988857647636`, 0.944260957535609], 
             UndirectedEdge[58, 61] -> 
             RGBColor[
              0.26897522612323943`, 0.4000403950428194, 0.9386291132633059], 
             UndirectedEdge[11, 17] -> 
             RGBColor[
              0.24235029233601593`, 0.3720559015141443, 0.9371128626721834], 
             UndirectedEdge[11, 15] -> 
             RGBColor[
              0.28548651926913327`, 0.4158817774158234, 0.9396248065535615], 
             UndirectedEdge[111, 157] -> 
             RGBColor[
              0.5090903091480017, 0.6123414730802424, 0.9544966004768307], 
             UndirectedEdge[75, 191] -> 
             RGBColor[
              0.2821961080105196, 0.4139363801586776, 0.9393820229282445], 
             UndirectedEdge[98, 156] -> 
             RGBColor[
              0.9471660663080045, 0.9597340431975859, 0.961036759682581], 
             UndirectedEdge[28, 140] -> 
             RGBColor[
              0.3001402263093852, 0.4327967862135973, 0.9404039139194207], 
             UndirectedEdge[105, 157] -> 
             RGBColor[
              0.4504475650892219, 0.5617429700786016, 0.9507060867688824], 
             UndirectedEdge[3, 15] -> 
             RGBColor[
              0.2943870608658776, 0.4252368109609329, 0.9401316792303248], 
             UndirectedEdge[55, 96] -> 
             RGBColor[
              0.32928937279498216`, 0.459399935982008, 0.942211635716671], 
             UndirectedEdge[6, 64] -> 
             RGBColor[
              0.4813272203866353, 0.5867267043563145, 0.9531607423711013], 
             UndirectedEdge[70, 134] -> 
             RGBColor[
              0.2222636314959646, 0.3509435474033953, 0.9359689570528942], 
             UndirectedEdge[106, 140] -> 
             RGBColor[
              0.29027778680107763`, 0.4224307369755848, 0.9398422625795944], 
             UndirectedEdge[64, 154] -> 
             RGBColor[
              0.8045650840099676, 0.8465963466235498, 0.9181848867101159], 
             UndirectedEdge[8, 157] -> 
             RGBColor[
              0.5029410908496337, 0.6072102236909507, 0.9540509278121335], 
             UndirectedEdge[83, 124] -> 
             RGBColor[
              0.2734514125634414, 0.4047451507980839, 0.9388840254591511], 
             UndirectedEdge[22, 128] -> 
             RGBColor[
              0.8670016862310241, 0.46697435659460335`, 0.20987408763836157`],
              UndirectedEdge[83, 135] -> 
             RGBColor[
              0.244563666934011, 0.3743822985526921, 0.9372389110811449], 
             UndirectedEdge[62, 68] -> 
             RGBColor[
              0.6059297438464823, 0.6853451599719039, 0.965005694475316], 
             UndirectedEdge[105, 116] -> 
             RGBColor[
              0.36639655307775293`, 0.49177601147490035`, 0.944567442263732], 
             UndirectedEdge[93, 145] -> 
             RGBColor[
              0.21595172710093502`, 0.34430933568636624`, 0.935609503435223], 
             UndirectedEdge[128, 195] -> 
             RGBColor[
              0.5342542573357888, 0.44844563583181796`, 0.5815387240241343], 
             UndirectedEdge[87, 154] -> 
             RGBColor[
              0.9872510560263222, 0.9889959982810382, 0.8609465250606165], 
             UndirectedEdge[138, 167] -> 
             RGBColor[
              0.914025724578517, 0.8135858623733021, 0.6202282398592844], 
             UndirectedEdge[179, 194] -> 
             RGBColor[
              0.5782314602978695, 0.6630917185740817, 0.9624599458147682], 
             UndirectedEdge[118, 144] -> 
             RGBColor[
              0.8849117112912057, 0.6845610816311141, 0.5966731364210304], 
             UndirectedEdge[47, 188] -> 
             RGBColor[
              0.5580878614872598, 0.6517295894935908, 0.9586008499410545], 
             UndirectedEdge[11, 20] -> 
             RGBColor[
              0.2356317618329697, 0.3649942999760054, 0.93673025229921], 
             UndirectedEdge[124, 187] -> 
             RGBColor[
              0.2869408055031858, 0.4189233580546661, 0.939652226431301], 
             UndirectedEdge[28, 189] -> 
             RGBColor[
              0.26308408549772533`, 0.39384843272551495`, 0.9382936215198444],
              UndirectedEdge[84, 93] -> 
             RGBColor[
              0.24346208091315458`, 0.3732244618001842, 0.9371761773869076], 
             UndirectedEdge[18, 94] -> 
             RGBColor[
              0.36824895343507874`, 0.4933804675600669, 0.9446854755764875], 
             UndirectedEdge[146, 156] -> 
             RGBColor[
              0.8584691386886809, 0.8901770946260392, 0.9863115068182637], 
             UndirectedEdge[2, 26] -> 
             RGBColor[
              0.3867618425079842, 0.5094154015901577, 0.945865100497908], 
             UndirectedEdge[124, 161] -> 
             RGBColor[
              0.29985672336199365`, 0.43249880664076373`, 0.9403877688459719],
              UndirectedEdge[25, 67] -> 
             RGBColor[
              0.8985635990383481, 0.540750973420999, 0.26884077504963666`], 
             UndirectedEdge[15, 77] -> 
             RGBColor[
              0.31275241202724346`, 0.4445399594620464, 0.9411775588098623], 
             UndirectedEdge[23, 49] -> 
             RGBColor[
              0.9141583764403114, 0.6283443976324334, 0.3617031352101312], 
             UndirectedEdge[27, 37] -> 
             RGBColor[
              0.23387138917519362`, 0.3631440366986098, 0.9366300016805876], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.28199072307706635`, 0.41303118579725295`, 0.9393955660070041],
              UndirectedEdge[134, 139] -> 
             RGBColor[
              0.2400051701500614, 0.36959102940737165`, 0.9369793114329906], 
             UndirectedEdge[13, 127] -> 
             RGBColor[
              0.34979347533914956`, 0.4773952600326733, 0.9435095088317533], 
             UndirectedEdge[59, 186] -> 
             RGBColor[
              0.36541764511564734`, 0.4884580900498052, 0.9445955073983169], 
             UndirectedEdge[119, 149] -> 
             RGBColor[
              0.3992231896957711, 0.5102289495476822, 0.9477505828326117], 
             UndirectedEdge[41, 66] -> 
             RGBColor[
              0.6206670435279176, 0.7021698769586107, 0.9637962645099678], 
             UndirectedEdge[25, 103] -> 
             RGBColor[
              0.9216061306427468, 0.7086086374094871, 0.2905438354623711], 
             UndirectedEdge[164, 166] -> 
             RGBColor[
              0.3428237586125573, 0.4700619252820549, 0.9431128764626655], 
             UndirectedEdge[30, 90] -> 
             RGBColor[
              0.6408480095261183, 0.7142786377339077, 0.9678341664939911], 
             UndirectedEdge[75, 182] -> 
             RGBColor[
              0.27464253104525127`, 0.40599709184373967`, 0.9389518578945881],
              UndirectedEdge[92, 97] -> 
             RGBColor[
              0.2548383832137916, 0.38518167681737986`, 0.9378240409731977], 
             UndirectedEdge[18, 61] -> 
             RGBColor[
              0.2960837334123488, 0.42764330820172913`, 0.9402054842996372], 
             UndirectedEdge[76, 191] -> 
             RGBColor[
              0.2782905449427576, 0.40983138574745914`, 0.9391596068892982], 
             UndirectedEdge[129, 197] -> 
             RGBColor[
              0.939588342286577, 0.9465340447880747, 0.7029640290475025], 
             UndirectedEdge[97, 112] -> 
             RGBColor[
              0.2912053726836331, 0.4234056885504923, 0.9398950872233656], 
             UndirectedEdge[87, 131] -> 
             RGBColor[
              0.9436166175198961, 0.8123670652183208, 0.5433036400573084], 
             UndirectedEdge[33, 198] -> 
             RGBColor[
              0.5096004354679522, 0.6083940896440386, 0.956077633424264], 
             UndirectedEdge[39, 114] -> 
             RGBColor[
              0.20908858865686974`, 0.3370957420335433, 0.935218657853937], 
             UndirectedEdge[144, 170] -> 
             RGBColor[
              0.5194406297490485, 0.3722097272488664, 0.5677249006332556], 
             UndirectedEdge[64, 110] -> 
             RGBColor[
              0.6138148271599528, 0.6973615545881173, 0.9627408981532811], 
             UndirectedEdge[108, 131] -> 
             RGBColor[
              0.8402456246331873, 0.7322315204859621, 0.6082404593152602], 
             UndirectedEdge[33, 141] -> 
             RGBColor[
              0.3411893210123498, 0.46994277401217005`, 0.9429612597264045], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.6032826317786147, 0.6888110439075521, 0.9619117651521593], 
             UndirectedEdge[88, 142] -> 
             RGBColor[
              0.6765418260566909, 0.7472163657056936, 0.968410420193581], 
             UndirectedEdge[12, 95] -> 
             RGBColor[
              0.7817942234386319, 0.8080307104936368, 0.6678706900642806], 
             UndirectedEdge[131, 162] -> 
             RGBColor[
              0.941079962602384, 0.8111036548737982, 0.5757395893878008], 
             UndirectedEdge[21, 194] -> 
             RGBColor[
              0.33236539581814195`, 0.4622999335123229, 0.9423990070157204], 
             UndirectedEdge[131, 154] -> 
             RGBColor[
              0.9428931009304802, 0.8120678725150692, 0.5552941823448407], 
             UndirectedEdge[81, 184] -> 
             RGBColor[
              0.47373340289000515`, 0.5814056280463057, 0.952329749742717], 
             UndirectedEdge[105, 111] -> 
             RGBColor[
              0.4018530682244218, 0.5222917683666206, 0.9468805499681779]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 71 -> 
             RGBColor[
              0.2902833275082297, 0.42243656061010276`, 0.93984257811467], 10 -> 
             RGBColor[
              0.28931600419628395`, 0.4214198424774074, 0.9397874904830813], 
             68 -> RGBColor[
              0.8556248139763563, 0.8877160176206234, 0.9860914526539951], 
             155 -> RGBColor[
              0.24962306644129345`, 0.3797000482193023, 0.9375270363983738], 
             132 -> RGBColor[
              0.2522143608002516, 0.3824236628881191, 0.93767460677864], 26 -> 
             RGBColor[
              0.39640287984113043`, 0.5177659835555031, 0.9464794188715415], 
             29 -> RGBColor[
              0.9936430185668372, 0.9916392390574856, 0.75501516389549], 113 -> 
             RGBColor[
              0.9003020964297527, 0.6401769295720257, 0.2385219642527955], 50 -> 
             RGBColor[
              0.2422322948146241, 0.37193187863768656`, 0.9371061428879017], 
             173 -> RGBColor[
              0.9951414157005084, 0.9920163043986404, 0.7125512665860644], 
             192 -> RGBColor[0.817319, 0.134127, 0.164218], 165 -> 
             RGBColor[
              0.21890292553398902`, 0.347411232356294, 0.9357775698200786], 
             92 -> RGBColor[
              0.22871531315648586`, 0.35772467388884666`, 0.9363363707790532],
              11 -> RGBColor[
              0.24586228151751777`, 0.37574722481687783`, 0.9373128652605475],
              137 -> RGBColor[
              0.2501870825879037, 0.38029286495007875`, 0.9375591562835361], 
             120 -> RGBColor[
              0.9567688473548046, 0.8658333123497126, 0.2865555648019119], 51 -> 
             RGBColor[
              0.28213996431762406`, 0.4138773695777287, 0.9393788256279912], 
             72 -> RGBColor[
              0.24987650973082426`, 0.37996643318583184`, 0.9375414696187768],
              64 -> RGBColor[
              0.6226026285830288, 0.704495887669313, 0.963432706072083], 41 -> 
             RGBColor[
              0.5497140953330726, 0.6453216927859953, 0.9576946537351515], 
             103 -> RGBColor[
              0.8642907579141675, 0.4766578520345487, 0.20847322067670976`], 
             162 -> RGBColor[
              0.9829012627807141, 0.9867683702952449, 0.9138278814340688], 
             196 -> RGBColor[
              0.49517344266125934`, 0.6010431339186144, 0.9534010137678327], 
             179 -> RGBColor[
              0.807933735593484, 0.8498832418602281, 0.9814909422600818], 160 -> 
             RGBColor[
              0.36671177852496323`, 0.4920490439135823, 0.9445875281504853], 
             123 -> RGBColor[
              0.250431442054717, 0.3805497022429847, 0.9375730721936737], 150 -> 
             RGBColor[
              0.2829267708206377, 0.41470435309880965`, 0.9394236330943619], 
             188 -> RGBColor[
              0.6646539951158695, 0.737952019632756, 0.9672101567545748], 46 -> 
             RGBColor[
              0.5977424503378598, 0.6843132750316175, 0.9614756217747897], 
             182 -> RGBColor[
              0.2651236286264823, 0.39599212186834176`, 0.9384097704837935], 
             6 -> RGBColor[
              0.3400518121902417, 0.46895752104331584`, 0.9428887786701194], 
             131 -> RGBColor[
              0.8992586624240541, 0.6354389394523516, 0.23765129734153262`], 
             45 -> RGBColor[
              0.8843599871114161, 0.5677875345316877, 0.22521947746071738`], 
             195 -> RGBColor[0.178927, 0.305394, 0.933501], 148 -> 
             RGBColor[
              0.20479309393410217`, 0.332580904729819, 0.9349740357840903], 
             161 -> 
             RGBColor[
              0.30865896704414575`, 0.441750522845189, 0.9408890436019178], 1 -> 
             RGBColor[
              0.9583125875736904, 0.8710407105954553, 0.2925527040414048], 
             101 -> RGBColor[
              0.2518443381406806, 0.38203474561211825`, 0.9376535345355769], 
             12 -> RGBColor[
              0.5839626349742006, 0.6731262001457912, 0.9603908242322355], 39 -> 
             RGBColor[
              0.20098973591686892`, 0.3285833343068806, 0.9347574401715728], 
             48 -> RGBColor[
              0.3171026989044469, 0.4490801525711323, 0.9414264814646527], 77 -> 
             RGBColor[
              0.3003940670337382, 0.43306358890932384`, 0.940418369773149], 
             56 -> RGBColor[0.178927, 0.305394, 0.933501], 110 -> 
             RGBColor[
              0.6050270257368769, 0.6902272215069217, 0.9620490902344793], 73 -> 
             RGBColor[
              0.2931347355771166, 0.42543357128021636`, 0.9400049615859128], 
             37 -> RGBColor[
              0.19099374879671333`, 0.31807691806140814`, 0.9341881834928177],
              130 -> RGBColor[
              0.23722409174651585`, 0.3666679396746901, 0.9368209331321454], 
             107 -> RGBColor[
              0.6672310374616252, 0.7399652246995075, 0.9674670122517698], 59 -> 
             RGBColor[
              0.44880489881560515`, 0.5631539785891382, 0.949818429183309], 
             47 -> RGBColor[
              0.4515217278586501, 0.5655071593544256, 0.9499915431275343], 
             159 -> RGBColor[
              0.8226444613445744, 0.17506082952644003`, 0.16931766779781277`],
              55 -> RGBColor[
              0.35238205413251156`, 0.47963735687773035`, 0.943674450783476], 
             49 -> RGBColor[
              0.8347376037115143, 0.26801402100751526`, 0.1808980745856452], 
             82 -> RGBColor[
              0.31859842780058983`, 0.45037567776345117`, 0.9415217879872938],
              199 -> RGBColor[
              0.27228850741332744`, 0.40352286375286894`, 0.938817799731216], 
             89 -> RGBColor[
              0.8539922331287186, 0.4160135401405583, 0.19933632946055357`], 
             144 -> RGBColor[
              0.8565158956399671, 0.43541151607797846`, 0.2017529915313943], 
             78 -> RGBColor[
              0.9279645300339343, 0.9453977435956535, 0.9929912793499938], 42 -> 
             RGBColor[
              0.5214414667269106, 0.6223686992161088, 0.9554689288452234], 
             154 -> RGBColor[
              0.9865275394369064, 0.9886968055777866, 0.8729370673481489], 
             168 -> RGBColor[
              0.9385923578753286, 0.9537228615659814, 0.988831299825661], 121 -> 
             RGBColor[
              0.5426755050288741, 0.6396074480921672, 0.9571405501231992], 
             128 -> RGBColor[
              0.8895815146715775, 0.5914972716636359, 0.22957644804826868`], 
             115 -> RGBColor[
              0.2655539192117794, 0.3964443845554878, 0.9384342748960682], 61 -> 
             RGBColor[
              0.2737970101358498, 0.4051083957588368, 0.9389037067296339], 93 -> 
             RGBColor[
              0.22414759348065547`, 0.35292371089939434`, 0.9360762459008504],
              88 -> RGBColor[
              0.7121946053554326, 0.7750911056739228, 0.9719485604909927], 21 -> 
             RGBColor[
              0.31620160663402885`, 0.4482996717367106, 0.9413690646619862], 
             62 -> RGBColor[
              0.3562346737166085, 0.4829743023231845, 0.943919936296637], 136 -> 
             RGBColor[
              0.9080066729340168, 0.6729841436820356, 0.24483821356303642`], 
             190 -> RGBColor[
              0.1797070620660458, 0.3062138946902057, 0.9335454233806629], 57 -> 
             RGBColor[
              0.3605779115447064, 0.4867361966324024, 0.9441966835704689], 
             111 -> RGBColor[
              0.4604958122832016, 0.5728902713682614, 0.9506710636761264], 63 -> 
             RGBColor[
              0.35285247495850214`, 0.48004481175316516`, 0.9437044255825313],
              75 -> RGBColor[
              0.28416143346402023`, 0.4160020618191376, 0.9394939453053829], 
             30 -> RGBColor[
              0.8937471851268821, 0.9181137615718546, 0.9897275984465748], 5 -> 
             RGBColor[
              0.2822070658609612, 0.41394789755425965`, 0.9393826469616164], 
             171 -> RGBColor[
              0.8744701613749067, 0.9027427860928997, 0.9878889387123091], 
             102 -> RGBColor[
              0.37383492502239923`, 0.4982187553899085, 0.9450414087465508], 
             31 -> RGBColor[
              0.8505083657915934, 0.8836363007203797, 0.9856034412586252], 96 -> 
             RGBColor[
              0.3061966914574528, 0.4391625150862857, 0.940748820649866], 70 -> 
             RGBColor[
              0.21367513065222027`, 0.34191648847421524`, 0.9354798546353913],
              52 -> RGBColor[
              0.21246269677098534`, 0.3406421435922893, 0.9354108083194902], 
             183 -> RGBColor[
              0.859910479347665, 0.45676803010411193`, 0.20481820887036734`], 
             158 -> RGBColor[
              0.25326504777876796`, 0.3835280015199418, 0.9377344418477144], 
             13 -> RGBColor[
              0.3779993100162068, 0.5018257363634689, 0.9453067596759351], 
             170 -> RGBColor[
              0.1823653638581298, 0.3090079384197544, 0.933696809735117], 86 -> 
             RGBColor[
              0.3919595940317969, 0.5139174327134967, 0.9461962966288141], 18 -> 
             RGBColor[
              0.3183704566888478, 0.45017822064462143`, 0.9415072618696405], 
             153 -> RGBColor[
              0.585970074369736, 0.674755929881201, 0.960548857214945], 58 -> 
             RGBColor[
              0.264153442110629, 0.394972394326802, 0.9383545197969779], 22 -> 
             RGBColor[
              0.8444218577904707, 0.34245144152557083`, 0.19017172722845446`],
              66 -> RGBColor[
              0.6916199917227627, 0.7590180611312259, 0.9698978752847841], 
             143 -> RGBColor[
              0.8207984422031169, 0.16087151747445233`, 0.16754991778317269`],
              119 -> RGBColor[
              0.5648783713319804, 0.6576327351847573, 0.9588884410903589], 
             145 -> RGBColor[
              0.20775586072121455`, 0.33569496047333813`, 0.9351427609695957],
              91 -> RGBColor[
              0.8378176201564483, 0.8735170446320284, 0.9843929866107827], 
             177 -> RGBColor[
              0.29360677442013106`, 0.4259297140332158, 0.9400318434997037], 
             200 -> RGBColor[
              0.23658832296539867`, 0.36599970637566703`, 0.9367847270405965],
              114 -> RGBColor[
              0.21718744139687057`, 0.3456081497602061, 0.935679875536301], 
             24 -> RGBColor[
              0.17892700283938517`, 0.30539400298437386`, 0.9335010001616988],
              176 -> RGBColor[
              0.29419693695473825`, 0.4265500122755539, 0.9400654523829823], 
             79 -> RGBColor[
              0.20396815225836698`, 0.3317138387242981, 0.934927056576049], 
             109 -> RGBColor[
              0.3375430035907792, 0.46678451713084806`, 0.942728919604614], 
             135 -> RGBColor[
              0.23327898842098083`, 0.3625213859455549, 0.9365962653340136], 
             108 -> RGBColor[
              0.7812325868423204, 0.8290241015195725, 0.9788296212889877], 
             191 -> RGBColor[
              0.28023078255701894`, 0.41187069849821767`, 0.939270100551106], 
             14 -> 
             RGBColor[
              0.4167727741971154, 0.535409362225998, 0.9477773705275145], 185 -> 
             RGBColor[
              0.7695733223497783, 0.8199157954843064, 0.9776675347663926], 32 -> 
             RGBColor[
              0.23515166545220784`, 0.36448968823995603`, 0.9367029115205646],
              122 -> RGBColor[
              0.9929383277496677, 0.9873041220381521, 0.47275873901987264`], 
             187 -> RGBColor[
              0.28282713132653, 0.41459962567299363`, 0.939417958772576], 193 -> 
             RGBColor[
              0.31668648779682773`, 0.44871965142909115`, 0.9413999608609163],
              100 -> RGBColor[
              0.21381427791123173`, 0.3420627410658821, 0.9354877788659421], 
             180 -> RGBColor[
              0.7240681721091139, 0.7843668262643483, 0.9731320066602097], 7 -> 
             RGBColor[
              0.350460125859892, 0.477972679206911, 0.9435519872134391], 175 -> 
             RGBColor[
              0.320397896026041, 0.45193428669643415`, 0.9416364485114123], 9 -> 
             RGBColor[
              0.2605668322464433, 0.39120263995534316`, 0.9381502676711264], 
             90 -> RGBColor[
              0.3879488339253545, 0.5104435138959607, 0.9459407345414075], 
             174 -> RGBColor[
              0.3814106085308894, 0.5047804316800383, 0.9455241246007979], 
             142 -> RGBColor[
              0.6408890467579492, 0.7193416257374643, 0.9648722798961695], 
             134 -> RGBColor[
              0.23085213233970892`, 0.3599706063325754, 0.9364580594703971], 
             105 -> RGBColor[
              0.34321032416564207`, 0.47169326536497985`, 0.9430900362602295],
              16 -> RGBColor[
              0.3229612837478847, 0.4541545643014821, 0.9417997853103334], 
             139 -> RGBColor[
              0.24915820796041388`, 0.3792114524821679, 0.9375005633955842], 
             146 -> RGBColor[
              0.79609453068194, 0.84063436500204, 0.9803109209581594], 126 -> 
             RGBColor[
              0.30722498883092086`, 0.4402433208236197, 0.9408073806640553], 
             198 -> RGBColor[
              0.6961608186542636, 0.7625653896416773, 0.9703504624768758], 40 -> 
             RGBColor[
              0.49158142165721236`, 0.5981269694488269, 0.9531182367163876], 
             104 -> RGBColor[
              0.21893481250696653`, 0.34744474758664423`, 0.9357793857360172],
              181 -> RGBColor[
              0.984329904565909, 0.9877880270819891, 0.9093575644573119], 127 -> 
             RGBColor[
              0.32158764066209233`, 0.4529647837018777, 0.9417122579875715], 
             76 -> RGBColor[
              0.27635030732849636`, 0.40779207299670056`, 0.9390491132274904],
              172 -> RGBColor[
              0.9939767127007667, 0.98952512245173, 0.5857805327779135], 84 -> 
             RGBColor[
              0.2627765683456537, 0.3935252127009741, 0.9382761088729649], 
             184 -> RGBColor[
              0.3711329893802169, 0.49587847453988415`, 0.9448692437966588], 
             151 -> RGBColor[
              0.3518764439127397, 0.4791994227180725, 0.9436422337473658], 35 -> 
             RGBColor[
              0.8383733051460716, 0.8739601327590868, 0.9844459883411588], 36 -> 
             RGBColor[
              0.24777983952010385`, 0.3777626998577953, 0.9374220673520219], 
             34 -> RGBColor[
              0.2517479206748871, 0.38193340474234894`, 0.9376480437035368], 
             38 -> RGBColor[
              0.9648082727380654, 0.8929521819142981, 0.31778721429778617`], 
             54 -> RGBColor[
              0.27280646441116213`, 0.40406726939796367`, 0.938847296615994], 
             60 -> RGBColor[
              0.253957266336059, 0.38425556711284614`, 0.9377738626705066], 
             87 -> RGBColor[
              0.9879745726157381, 0.9892951909842899, 0.8489559827730842], 
             141 -> RGBColor[
              0.3593385897430587, 0.4856627583779401, 0.9441177150811572], 67 -> 
             RGBColor[
              0.8182056947053702, 0.14094252405757224`, 0.16506709985124088`],
              133 -> RGBColor[
              0.8234278438149039, 0.18108225047377968`, 0.1700678357361042], 
             98 -> RGBColor[
              0.9734883859205871, 0.9797482621451334, 0.9297614266867937], 3 -> 
             RGBColor[
              0.26366336471100654`, 0.39445729190709694`, 0.938326610614074], 
             27 -> RGBColor[
              0.2767490295536739, 0.4082111553358114, 0.9390718198683575], 
             163 -> RGBColor[
              0.23302215960706, 0.36225144257823677`, 0.936581639313005], 85 -> 
             RGBColor[
              0.360155081261214, 0.48636996229290924`, 0.9441697411986989], 
             83 -> RGBColor[
              0.25584834544704116`, 0.3862432111598293, 0.9378815568282761], 
             28 -> RGBColor[
              0.29477679578460203`, 0.4271594806709139, 0.9400984744855188], 
             44 -> RGBColor[
              0.2834240796528994, 0.4152270562127178, 0.9394519540966568], 
             189 -> 
             RGBColor[
              0.2313913752108486, 0.36053738478011593`, 0.9364887685541701], 
             15 -> RGBColor[
              0.32511075702074876`, 0.45601633001476893`, 0.9419367478465757],
              80 -> RGBColor[
              0.6198970672218798, 0.7022993910721819, 0.9632197143709355], 
             112 -> RGBColor[
              0.30144929209616883`, 0.4341726973550716, 0.9404784632793888], 
             169 -> RGBColor[
              0.2725827939998642, 0.40383217761416634`, 0.9388345589169613], 
             69 -> RGBColor[
              0.4015855979045752, 0.522254993451075, 0.9468096570836465], 20 -> 
             RGBColor[
              0.22540124214842158`, 0.354241375135133, 0.9361476393378726], 8 -> 
             RGBColor[
              0.44819737568646545`, 0.5626277725896778, 0.9497797183467319], 
             116 -> RGBColor[
              0.3895827819898638, 0.5118587575848209, 0.9460448482672345], 97 -> 
             RGBColor[
              0.28096145327109734`, 0.41263867974591306`, 0.9393117111673424],
              118 -> RGBColor[
              0.9133075269424444, 0.9337106471842498, 0.9915932813106664], 
             178 -> RGBColor[
              0.9424318889382709, 0.9565863775460686, 0.9823319752461818], 81 -> 
             RGBColor[
              0.5763338163997934, 0.6669327815527272, 0.9597902556887751], 
             166 -> RGBColor[
              0.39092445521974123`, 0.5130208475020834, 0.9461303384990473], 
             125 -> RGBColor[
              0.17895982839241617`, 0.30542850472186966`, 0.9335028695283829],
              95 -> RGBColor[
              0.9796258119030633, 0.9429352208414826, 0.3753505558963255], 
             157 -> RGBColor[
              0.5576848060128018, 0.6517926747922235, 0.9583221372775351], 74 -> 
             RGBColor[
              0.30278259996188467`, 0.4355740884585403, 0.9405543931898891], 
             19 -> RGBColor[
              0.26440158051900675`, 0.3952332035268908, 0.9383686509122472], 
             156 -> RGBColor[
              0.9208437466954219, 0.9397198242500384, 0.9923120926783682], 
             167 -> RGBColor[
              0.9152757732218003, 0.9352800733407862, 0.9917810143978655], 33 -> 
             RGBColor[0.3230400522816408, 0.4542227896464, 0.941804804371652],
              43 -> RGBColor[
              0.8553653759675705, 0.4265681177150025, 0.20065125259378117`], 
             140 -> RGBColor[
              0.30550365683416836`, 0.4384340917562807, 0.9407093533533227], 
             186 -> 
             RGBColor[
              0.28203039141568953`, 0.41376220151047227`, 0.9393725856133247],
              117 -> RGBColor[
              0.7789983515005383, 0.8272786998897548, 0.9786069335902352], 4 -> 
             RGBColor[
              0.8048857220793089, 0.8475021105371937, 0.9811871447582946], 
             106 -> RGBColor[
              0.27505191676798696`, 0.40642738219488894`, 0.9389751718058661],
              65 -> RGBColor[
              0.9220936452530043, 0.9407164594322621, 0.992431309118588], 53 -> 
             RGBColor[
              0.21141226994966317`, 0.3395380784021726, 0.9353509880659832], 
             2 -> RGBColor[
              0.377120805174838, 0.5010648196248124, 0.9452507821242745], 147 -> 
             RGBColor[
              0.4806958664434177, 0.5892895853375945, 0.9522612859348552], 94 -> 
             RGBColor[
              0.4181274501813097, 0.5365827144755124, 0.9478636892833344], 23 -> 
             RGBColor[
              0.9935791491691084, 0.9886747742573517, 0.5425081958346172], 
             194 -> RGBColor[
              0.348529185002255, 0.47630019528793527`, 0.9434289493694545], 
             129 -> RGBColor[
              0.9902596908634175, 0.9788057915282733, 0.4166611676177604], 99 -> 
             RGBColor[
              0.5640955015617808, 0.656997166237428, 0.9588268107143023], 25 -> 
             RGBColor[
              0.9789215033713261, 0.9405594227844256, 0.37261445024803247`], 
             138 -> RGBColor[
              0.9127756759352338, 0.6918916514058181, 0.2486754653207034], 
             124 -> RGBColor[
              0.2910544796798416, 0.42324709043633846`, 0.9398864940900259], 
             197 -> RGBColor[
              0.8889169937097365, 0.9142622980478761, 0.9892668904772446], 
             164 -> RGBColor[
              0.29472306200537346`, 0.42710300306202637`, 0.9400954144262837],
              152 -> RGBColor[
              0.281739557244844, 0.41345651635696223`, 0.9393560230375456], 
             17 -> RGBColor[
              0.2388383031545141, 0.3683645782114108, 0.9369128600838192], 
             149 -> RGBColor[
              0.2335680080595618, 0.362825163910607, 0.9366127245748646]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9lnk01I33xy0ZCmPGjGUM5jOLCfGgkIjPm8rSZv1l6yGUlK0nopQSkiYJ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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.9759778030702638, 0.9313399748264705, 0.5237839339684474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 78}], {
             RGBColor[
             0.9431385588038124, 0.9082192270955545, 0.6427719916956993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 88}], {
             RGBColor[
             0.8352535964645615, 0.823065908134689, 0.6322506322661987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 89}], {
             RGBColor[
             0.9061524103512045, 0.6435271253680068, 0.2459445167509792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[
             0.9293073420017215, 0.7556088200837405, 0.2655373341471002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 122}], {
             RGBColor[
             0.9756254576616791, 0.9291724163168037, 0.38265572153063876`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 136}], {
             RGBColor[
             0.9331596302538536, 0.7720124271387454, 0.2686954588022206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 138}], {
             RGBColor[
             0.9355441317544622, 0.7814661810006367, 0.2706140846810541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 144}], {
             RGBColor[
             0.9074142416068287, 0.6532261133367169, 0.24715284778639957`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 159}], {
             RGBColor[
             0.8904785244591324, 0.5230507700609477, 0.2309351859196088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 167}], {
             RGBColor[
             0.9367941803977453, 0.9031603919681208, 0.6421668592196352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 197}], {
             RGBColor[
             0.9236147906417135, 0.8926515043216656, 0.6409097972593247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 26}], {
             RGBColor[
             0.3867618425079842, 0.5094154015901577, 0.945865100497908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 40}], {
             RGBColor[
             0.43435111341602517`, 0.5495958945368197, 0.9491845094203311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 51}], {
             RGBColor[
             0.329630384746231, 0.45747109460127056`, 0.9423148038761329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 74}], {
             RGBColor[
             0.3399517025683613, 0.46831945404167635`, 0.9429025876570818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 80}], {
             RGBColor[
             0.4985089361983589, 0.6016821053484971, 0.954235248247605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 121}], {
             RGBColor[
             0.45989815510185605`, 0.5703361338584898, 0.9511956661237368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 158}], {
             RGBColor[
             0.31519292647680297`, 0.4422964105723771, 0.9414926119859944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 164}], {
             RGBColor[
             0.3359219335901057, 0.4640839113434194, 0.9426730982752791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 166}], {
             RGBColor[
             0.3840226301972896, 0.5070428335634479, 0.9456905603116609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 169}], {
             RGBColor[
             0.3248517995873511, 0.4524484986194894, 0.942042670520618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 184}], {
             RGBColor[
             0.37412689727752746`, 0.49847164708234826`, 0.9450600129604667]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 5}], {
             RGBColor[
             0.27293521528598386`, 0.4042025947306783, 0.9388546287878452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 10}], {
             RGBColor[
             0.27648968445364525`, 0.4079385671922522, 0.9390570505485776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 11}], {
             RGBColor[
             0.2547628231142621, 0.3851022583619874, 0.9378197379373108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 15}], {
             RGBColor[
             0.2943870608658776, 0.4252368109609329, 0.9401316792303248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 20}], {
             RGBColor[
             0.24453230342971405`, 0.374349333521115, 0.9372371249759732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 28}], {
             RGBColor[
             0.2792200802478043, 0.4108083862890054, 0.9392125425497964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 48}], {
             RGBColor[
             0.29038303180772673`, 0.42176872223911466`, 0.9398765460393633]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 63}], {
             RGBColor[
             0.30825791983475437`, 0.437251051830131, 0.9410155180983026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 77}], {
             RGBColor[
             0.2820287158723724, 0.41376044040821036`, 0.9393724901936115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 106}], {
             RGBColor[
             0.26935764073949675`, 0.40044233705099297`, 0.93865089120997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 186}], {
             RGBColor[
             0.27284687806334806`, 0.40410974670878463`, 0.9388495981136993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 189}], {
             RGBColor[
             0.24752736996092756`, 0.37749733834360644`, 0.937407689584122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 41}], {
             RGBColor[
             0.6772999087061907, 0.7464119016615944, 0.969440899246723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 66}], {
             RGBColor[
             0.7482528569010358, 0.8032600858342098, 0.9755425100215394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 80}], {
             RGBColor[
             0.7123913946505943, 0.7749007508046878, 0.972203429564615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 81}], {
             RGBColor[
             0.6906097692395512, 0.7572174460449604, 0.9704887002235348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 168}], {
             RGBColor[
             0.8717390399773187, 0.9006124860515876, 0.9850092222919777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 172}], {
             RGBColor[
             0.8994312173900378, 0.9185136164944618, 0.783483838768104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 173}], {
             RGBColor[
             0.9000135688899087, 0.9197592074679171, 0.8468692056721795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 184}], {
             RGBColor[
             0.5880093557297629, 0.671690292538539, 0.9630281942774768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 198}], {
             RGBColor[
             0.7505232703667862, 0.8050337500894356, 0.9757688036175852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 9}], {
             RGBColor[
             0.27138694905370225`, 0.40257526875480143`, 0.9387664573163714]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.2640346736892395, 0.39484756118556874`, 0.938347756111082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 15}], {
             RGBColor[
             0.303658911440855, 0.4349821137845143, 0.940659697404096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 17}], {
             RGBColor[
             0.26052268450773763`, 0.3911562378828352, 0.9381477535227178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 20}], {
             RGBColor[
             0.2538041540046914, 0.3840946363446963, 0.9377651431497445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 28}], {
             RGBColor[
             0.28849193082278163`, 0.4205536891125868, 0.9397405607235676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 48}], {
             RGBColor[
             0.2996548823827041, 0.431514025062696, 0.9404045642131346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 63}], {
             RGBColor[
             0.3175297704097317, 0.4469963546537124, 0.9415435362720739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[
             0.2913005664473497, 0.42350574323179174`, 0.9399005083673827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 102}], {
             RGBColor[
             0.32802099544168023`, 0.45608332647208405`, 0.9422120278540836]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 106}], {
             RGBColor[
             0.2786294913144741, 0.4101876398745743, 0.9391789093837413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 112}], {
             RGBColor[
             0.29182817897856506`, 0.4240602974546656, 0.9399305551205026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 140}], {
             RGBColor[
             0.2938553613475648, 0.42619099465527016`, 0.9400460001574695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 189}], {
             RGBColor[
             0.2567992205359049, 0.38724264116718776`, 0.9379357077578933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 12}], {
             RGBColor[
             0.4620072235822212, 0.5710418605945535, 0.9516398014511775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 13}], {
             RGBColor[
             0.35902556110322426`, 0.48539162870339236`, 0.9440977691730272]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 14}], {
             RGBColor[
             0.37841229319367853`, 0.5021834416346569, 0.945333074598817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 16}], {
             RGBColor[
             0.3315065479690632, 0.46155604267239897`, 0.9423442819902264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 59}], {
             RGBColor[
             0.39442835550292343`, 0.516055749816227, 0.9463536039267142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 64}], {
             RGBColor[
             0.4813272203866353, 0.5867267043563145, 0.9531607423711013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 83}], {
             RGBColor[
             0.29795007881864144`, 0.4276003661015726, 0.9403851677491978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 86}], {
             RGBColor[
             0.3660057031110193, 0.4914374768784062, 0.9445425376494667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 124}], {
             RGBColor[
             0.3155531459350417, 0.4461023057398271, 0.9413876363800726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 137}], {
             RGBColor[
             0.2951194473890727, 0.4246251929966973, 0.9402239674768278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 161}], {
             RGBColor[
             0.32435538961719373`, 0.45535402194425245`, 0.9418889111360187]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 175}], {
             RGBColor[
             0.3302248541081414, 0.460445903869875, 0.9422626135907659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 176}], {
             RGBColor[
             0.31712437457249, 0.4477537666594349, 0.9414771155265509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 186}], {
             RGBColor[
             0.3110411018029656, 0.4413598612768941, 0.941130682141722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 187}], {
             RGBColor[
             0.3114394717583858, 0.44177857335815474`, 0.9411533687213477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 193}], {
             RGBColor[
             0.3283691499935347, 0.4588385862362035, 0.9421443697655179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 199}], {
             RGBColor[
             0.3061701598017846, 0.4362401923980924, 0.9408532892006678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 18}], {
             RGBColor[
             0.33441529127436986`, 0.4640754499257662, 0.9425296245415398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 42}], {
             RGBColor[
             0.4359507962934013, 0.5501706892115099, 0.9495104580293312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 47}], {
             RGBColor[
             0.40099092685927107`, 0.5217399192806683, 0.9467717651704868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.31163329513552707`, 0.44101997430243733`, 0.9411996419147166]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 58}], {
             RGBColor[
             0.3073067839852605, 0.4364725367668565, 0.9409532535052085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.3121285679978709, 0.4415405374828739, 0.9412278469715365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 73}], {
             RGBColor[
             0.3217974307185043, 0.4517031252435637, 0.941778474399676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 88}], {
             RGBColor[
             0.5313273656076622, 0.6265318924404168, 0.9577502738522159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 94}], {
             RGBColor[
             0.3842937880206009, 0.5072776968412117, 0.9457078382483868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 97}], {
             RGBColor[
             0.3157107895654947, 0.44530567947641203`, 0.9414318491903908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 115}], {
             RGBColor[
             0.3080070225358357, 0.4372085318811994, 0.9409931310547537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 153}], {
             RGBColor[
             0.46821510011481404`, 0.5763643045440561, 0.9520504222141921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 160}], {
             RGBColor[
             0.3585859521924276, 0.48501086156024664`, 0.9440697576819622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 188}], {
             RGBColor[
             0.5075570604878807, 0.6079623494198335, 0.955381071984007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 55}], {
             RGBColor[
             0.4002897149094885, 0.5211325647337041, 0.9467270845651039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 62}], {
             RGBColor[
             0.40221602470153694`, 0.5228010374564311, 0.9468498273216844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 68}], {
             RGBColor[
             0.6519110948314109, 0.7251718951051506, 0.9679355855003635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 75}], {
             RGBColor[
             0.36617940457524284`, 0.4893149172044077, 0.9446368318260574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 96}], {
             RGBColor[
             0.3771970335719591, 0.5008951438379817, 0.9452642694982989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 99}], {
             RGBColor[
             0.5061464386241231, 0.6098124694135529, 0.9543032645305172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 107}], {
             RGBColor[
             0.5577142065740452, 0.6512964986445926, 0.9586233652992509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 147}], {
             RGBColor[
             0.4644466210649416, 0.5759586789636362, 0.9510205021407936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 156}], {
             RGBColor[
             0.6845205611909437, 0.7511737984198581, 0.97104590551255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 157}], {
             RGBColor[
             0.5029410908496337, 0.6072102236909507, 0.9540509278121335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 179}], {
             RGBColor[
             0.6280655556399748, 0.706255507224953, 0.9656353303034069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 185}], {
             RGBColor[
             0.6088853490181219, 0.6912717840369921, 0.9637236265565623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 194}], {
             RGBColor[
             0.3983632803443602, 0.5194639839388066, 0.9466043338580932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.2532145568819805, 0.3834749323861105, 0.937731566465837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 17}], {
             RGBColor[
             0.2497025677004787, 0.37978360908337694`, 0.9375315638774728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 20}], {
             RGBColor[
             0.24298403719743245`, 0.3727220075452381, 0.9371489535044994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 28}], {
             RGBColor[
             0.27767181401552266`, 0.4091810603131285, 0.9391243710783226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 63}], {
             RGBColor[
             0.3067096536024727, 0.43562372585425413`, 0.9409273466268289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 77}], {
             RGBColor[
             0.2804804496400908, 0.41213311443233347`, 0.9392843187221377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 97}], {
             RGBColor[
             0.2707641427587703, 0.4019206598506281, 0.9387309894192344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 102}], {
             RGBColor[
             0.31720087863442126`, 0.44471069767262583`, 0.9415958382088386]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.2678093745072151, 0.3988150110751161, 0.9385627197384963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 112}], {
             RGBColor[
             0.28100806217130603`, 0.41268766865520734`, 0.9393143654752576]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 140}], {
             RGBColor[
             0.2830352445403058, 0.4148183658558119, 0.9394298105122245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 189}], {
             RGBColor[
             0.24597910372864595`, 0.37587001236772954`, 0.9373195181126482]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 14}], {
             RGBColor[
             0.35304438919669967`, 0.4784146023517027, 0.943782430505298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.30721338060851633`, 0.43871808624608816`, 0.9408621191648285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 28}], {
             RGBColor[
             0.292046399990443, 0.42428966157416065`, 0.9399429824843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 48}], {
             RGBColor[
             0.30320935155036544`, 0.43524999752426985`, 0.940606985973867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 59}], {
             RGBColor[
             0.3690604515059446, 0.4922869105332728, 0.9448029598331952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 77}], {
             RGBColor[
             0.2948550356150111, 0.4272417156933656, 0.9401029301281152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 186}], {
             RGBColor[
             0.28567319780598677`, 0.4175910219939398, 0.939580038048203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 193}], {
             RGBColor[
             0.30300124599655587`, 0.4350697469532493, 0.9405937256719987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 15}], {
             RGBColor[
             0.28548651926913327`, 0.4158817774158234, 0.9396248065535615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 17}], {
             RGBColor[
             0.24235029233601593`, 0.3720559015141443, 0.9371128626721834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 20}], {
             RGBColor[
             0.2356317618329697, 0.3649942999760054, 0.93673025229921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 28}], {
             RGBColor[
             0.2703195386510599, 0.4014533527438959, 0.9387056698730332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 48}], {
             RGBColor[
             0.2814824902109824, 0.4124136886940051, 0.9393696733626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 63}], {
             RGBColor[
             0.29935737823800995`, 0.4278960182850215, 0.9405086454215394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 77}], {
             RGBColor[
             0.27312817427562797`, 0.40440540686310084`, 0.9388656175168482]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 106}], {
             RGBColor[
             0.2604570991427524, 0.3910873035058834, 0.9381440185332068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 112}], {
             RGBColor[
             0.2736557868068433, 0.4049599610859747, 0.9388956642699682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 140}], {
             RGBColor[
             0.27568296917584306`, 0.40709065828657925`, 0.9390111093069351]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 189}], {
             RGBColor[
             0.2386268283641832, 0.36814230479849686`, 0.9369008169073587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 13}], {
             RGBColor[
             0.4809809724952037, 0.58747596825463, 0.9528487919540853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 14}], {
             RGBColor[
             0.500367704585658, 0.6042677811858945, 0.954084097379875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.45346195936104267`, 0.5636403822236367, 0.9510953047712845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 23}], {
             RGBColor[
             0.7887708920716545, 0.8309004872015715, 0.7514495100334264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 25}], {
             RGBColor[
             0.7814420691727634, 0.8068428114651084, 0.666502637240134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 59}], {
             RGBColor[
             0.516383766894903, 0.6181400893674647, 0.9551046267077723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.6032826317786147, 0.6888110439075521, 0.9619117651521593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 86}], {
             RGBColor[
             0.4879611145029988, 0.5935218164296439, 0.9532935604305248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 87}], {
             RGBColor[
             0.7859686037949694, 0.8312106955650405, 0.9046734035026598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 95}], {
             RGBColor[
             0.7817942234386319, 0.8080307104936368, 0.6678706900642806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 108}], {
             RGBColor[
             0.6825976109082605, 0.7510751508326818, 0.9696102227606116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 154}], {
             RGBColor[
             0.7852450872055535, 0.8309115028617888, 0.9166639457901922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 161}], {
             RGBColor[
             0.4463108010091732, 0.5574383614954901, 0.9506399339170767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 175}], {
             RGBColor[
             0.4521802655001208, 0.5625302434211127, 0.9510136363718239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 193}], {
             RGBColor[
             0.4503245613855142, 0.5609229257874412, 0.950895392546576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 16}], {
             RGBColor[
             0.35048029688204574`, 0.4779901503324755, 0.9435532724931343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 64}], {
             RGBColor[
             0.5003009692996179, 0.6031608120163909, 0.9543697328740091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 69}], {
             RGBColor[
             0.38979245396039097`, 0.512040364907272, 0.9460582083797908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 82}], {
             RGBColor[
             0.34829886890839834`, 0.4761007070634601, 0.9434142738316145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 83}], {
             RGBColor[
             0.316923827731624, 0.4440344737616491, 0.9415941582521057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 86}], {
             RGBColor[
             0.38497945202400186`, 0.5078715845384828, 0.9457515281523746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 101}], {
             RGBColor[
             0.3149218240784437, 0.4419302409877936, 0.941480147105756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 108}], {
             RGBColor[
             0.5796159484292636, 0.6654249189415207, 0.9620681904824614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 110}], {
             RGBColor[
             0.49151316787654187`, 0.5960264789351953, 0.9536779249552072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 124}], {
             RGBColor[
             0.3345268948480242, 0.4625364133999037, 0.9425966268829805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 127}], {
             RGBColor[
             0.34979347533914956`, 0.4773952600326733, 0.9435095088317533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 137}], {
             RGBColor[
             0.31409319630205523`, 0.44105930065677384`, 0.9414329579797356]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 161}], {
             RGBColor[
             0.34332913853017627`, 0.471788129604329, 0.9430979016389265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 175}], {
             RGBColor[
             0.34919860302112393`, 0.4768800115299515, 0.9434716040936737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 176}], {
             RGBColor[
             0.3360981234854725, 0.4641878743195114, 0.9426861060294587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 187}], {
             RGBColor[
             0.33041322067136836`, 0.4582126810182313, 0.9423623592242556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 199}], {
             RGBColor[
             0.3251439087147671, 0.45267430005816894`, 0.9420622797035756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 15}], {
             RGBColor[
             0.3709417656089321, 0.49571284612038347`, 0.9448570591870451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 48}], {
             RGBColor[
             0.36693773655078116`, 0.49224475739856516`, 0.9446019259960836]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 59}], {
             RGBColor[
             0.43278883650636024`, 0.549281670407568, 0.9487978998554119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 186}], {
             RGBColor[
             0.34940158280640243`, 0.47458578186823513`, 0.9435749780704197]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 193}], {
             RGBColor[
             0.36672963099697153`, 0.49206450682754455`, 0.9445886656942154]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 28}], {
             RGBColor[
             0.3099437764026754, 0.4415879053428414, 0.9410176111660472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 48}], {
             RGBColor[
             0.32110672796259787`, 0.4525482412929506, 0.9416816146556142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 59}], {
             RGBColor[
             0.38695782791817696`, 0.5095851543019536, 0.9458775885149424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 63}], {
             RGBColor[
             0.33898161598962545`, 0.46803057088396705`, 0.9428205867145535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 77}], {
             RGBColor[
             0.31275241202724346`, 0.4445399594620464, 0.9411775588098623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 106}], {
             RGBColor[
             0.3000813368943679, 0.43122185610482894`, 0.9404559598262209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.3132800245584588, 0.44509451368492026`, 0.9412076055629822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 140}], {
             RGBColor[
             0.31530720692745856`, 0.4472252108855248, 0.9413230505999493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 193}], {
             RGBColor[
             0.32089862240878825`, 0.45236799072193, 0.941668354353746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 64}], {
             RGBColor[
             0.47278195616545676`, 0.5793252259853976, 0.9526162456912082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 83}], {
             RGBColor[
             0.2894048145974629, 0.4201988877306557, 0.9398406710693048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 86}], {
             RGBColor[
             0.3574604388898408, 0.48403599850748935`, 0.9439980409695737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 101}], {
             RGBColor[
             0.28740281094428266`, 0.4180946549568002, 0.9397266599229551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 124}], {
             RGBColor[
             0.3070078817138632, 0.43870082736891025`, 0.9408431397001796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 127}], {
             RGBColor[
             0.3222744622049885, 0.4535596740016799, 0.9417560216489524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 137}], {
             RGBColor[
             0.2865741831678942, 0.41722371462578045`, 0.9396794707969347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 161}], {
             RGBColor[
             0.3158101253960152, 0.4479525435733356, 0.9413444144561256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 175}], {
             RGBColor[
             0.3216795898869629, 0.4530444254989581, 0.9417181169108728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 176}], {
             RGBColor[
             0.30857911035131147`, 0.440352288288518, 0.9409326188466578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.3028942075372073, 0.43437709498723787`, 0.9406088720414547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 193}], {
             RGBColor[
             0.3198238857723562, 0.4514371078652866, 0.9415998730856248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 199}], {
             RGBColor[
             0.29762489558060606`, 0.42883871402717555`, 0.9403087925207747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 20}], {
             RGBColor[
             0.23211977265146783`, 0.3613029766732719, 0.9365302497108459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 28}], {
             RGBColor[
             0.2668075494695581, 0.39776202944116235`, 0.938505667284669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 77}], {
             RGBColor[
             0.26961618509412616`, 0.4007140835603673, 0.9386656149284841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 106}], {
             RGBColor[
             0.25694510996125053`, 0.38739598020314986`, 0.9379440159448427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 112}], {
             RGBColor[
             0.27014379762534146`, 0.4012686377832412, 0.938695661681604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 140}], {
             RGBColor[
             0.27217097999434126`, 0.4033993349838457, 0.9388111067185709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 189}], {
             RGBColor[
             0.23511483918268133`, 0.3644509814957634, 0.9367008143189947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 47}], {
             RGBColor[
             0.38494609227374893`, 0.5078426899995235, 0.9457494024985874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 54}], {
             RGBColor[
             0.295588460550005, 0.42712274502129255`, 0.9401772792428172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 58}], {
             RGBColor[
             0.2912619493997384, 0.4225753074857117, 0.9399308908333093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 61}], {
             RGBColor[
             0.2960837334123488, 0.42764330820172913`, 0.9402054842996372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 73}], {
             RGBColor[
             0.3057525961329822, 0.4378058959624189, 0.9407561117277767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 94}], {
             RGBColor[
             0.36824895343507874`, 0.4933804675600669, 0.9446854755764875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 115}], {
             RGBColor[
             0.2919621879503136, 0.4233113026000546, 0.9399707683828544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 116}], {
             RGBColor[
             0.35397661933935576`, 0.48101848911472117`, 0.9437760550684375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 153}], {
             RGBColor[
             0.4521702655292919, 0.5624670752629113, 0.9510280595422927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 160}], {
             RGBColor[
             0.34254111760690553`, 0.47111363227910186`, 0.9430473950100628]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 174}], {
             RGBColor[
             0.3498905326098686, 0.47747932616232985`, 0.9435156932352192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 188}], {
             RGBColor[
             0.49151222590235866`, 0.5940651201386887, 0.9543587093121076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 33}], {
             RGBColor[
             0.29372081640032377`, 0.4247279965866454, 0.9400867276419496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 34}], {
             RGBColor[
             0.25807475059694696`, 0.38858330413461983`, 0.938008347307892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 44}], {
             RGBColor[
             0.2739128300859531, 0.40523012986980433`, 0.9389103025044521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 50}], {
             RGBColor[
             0.2533169376668154, 0.3835825410822887, 0.9377373969000744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 60}], {
             RGBColor[
             0.25917942342753286`, 0.38974438531986844`, 0.9380712567913769]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 90}], {
             RGBColor[
             0.32617520722218063`, 0.45283835871142575`, 0.9421546927268274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 130}], {
             RGBColor[
             0.2508128361327613, 0.38095057160079043`, 0.9375947920221963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 141}], {
             RGBColor[
             0.31187008513103276`, 0.44044798095241544`, 0.9412431829967022]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 177}], {
             RGBColor[
             0.2790041774695689, 0.41058145878005325`, 0.9392002472059755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.2600890189665118, 0.39070042790302345`, 0.9381230569116956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 77}], {
             RGBColor[
             0.2628976545910799, 0.3936524820222284, 0.9382830045555108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 106}], {
             RGBColor[
             0.25022657945820426`, 0.38033437866501096`, 0.9375614055718693]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 189}], {
             RGBColor[
             0.2283963086796351, 0.35738937995762443`, 0.9363182039460214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.28199072307706635`, 0.41303118579725295`, 0.9393955660070041]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 46}], {
             RGBColor[
             0.4569720284859443, 0.5663064733841641, 0.9514223432183879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 85}], {
             RGBColor[
             0.3381783439476214, 0.46733481701480994`, 0.9427694029303426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 109}], {
             RGBColor[
             0.32687230511240406`, 0.45754209443377936`, 0.9420489921333002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 132}], {
             RGBColor[
             0.28420798371714023`, 0.41536166731241486`, 0.9395218357203131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 150}], {
             RGBColor[
             0.29956418872733326`, 0.4315020124177601, 0.9403963488781741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 151}], {
             RGBColor[
             0.33403902527338425`, 0.46374954722739153`, 0.9425056492046759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 194}], {
             RGBColor[
             0.33236539581814195`, 0.4622999335123229, 0.9423990070157204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 196}], {
             RGBColor[
             0.4056875246476441, 0.5246714028276624, 0.9473850392149095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 24}], {
             RGBColor[
             0.511674430314928, 0.3239227222549723, 0.5618363636950766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 37}], {
             RGBColor[
             0.517707803293592, 0.3302641797934895, 0.5621799553606361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 38}], {
             RGBColor[
             0.904615065264268, 0.6177018117199344, 0.25397947076312033`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 79}], {
             RGBColor[
             0.5241950050244188, 0.3370826401249345, 0.5625493919022517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 89}], {
             RGBColor[
             0.8492070454595947, 0.37923249083306454`, 0.194754028344504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 118}], {
             RGBColor[
             0.8788646923664576, 0.6380810443549103, 0.5908825042695605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 119}], {
             RGBColor[
             0.7046501145612256, 0.5000420883551641, 0.5745300841594067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 122}], {
             RGBColor[
             0.9186800927700692, 0.6648777817818614, 0.33146523312416354`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 128}], {
             RGBColor[
             0.8670016862310241, 0.46697435659460335`, 0.20987408763836157`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 138}], {
             RGBColor[
             0.8785987668628523, 0.5171715464656945, 0.2194235962745789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 144}], {
             RGBColor[
             0.8504688767152189, 0.38893147880177464`, 0.1959623593799244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 149}], {
             RGBColor[
             0.5389949329250163, 0.35263830271808894`, 0.5633922259016595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 181}], {
             RGBColor[
             0.9143758811781899, 0.66511973430378, 0.5497646458428832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 183}], {
             RGBColor[
             0.8521661685690678, 0.3996097358148414, 0.1974949680494109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 190}], {
             RGBColor[
             0.5120644599282582, 0.3243326681078883, 0.5618585753045587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 192}], {
             RGBColor[
             0.8308704288952353, 0.23828922076278541`, 0.17719486361422723`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 25}], {
             RGBColor[
             0.9862503262702172, 0.9646170985208886, 0.4575613230413248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 43}], {
             RGBColor[
             0.9244722625683395, 0.7076214459861772, 0.37157972421419916`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 49}], {
             RGBColor[
             0.9141583764403114, 0.6283443976324334, 0.3617031352101312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 64}], {
             RGBColor[
             0.8080908888760686, 0.8465853309633324, 0.7529704509533501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 67}], {
             RGBColor[
             0.9058924219372393, 0.564808649157462, 0.35378764784292904`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 87}], {
             RGBColor[
             0.9907768608924232, 0.9889849826208208, 0.6957320893038507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 95}], {
             RGBColor[
             0.9866024805360858, 0.9658049975494172, 0.45892937586547133`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 103}], {
             RGBColor[
             0.928934953541638, 0.7326663131459502, 0.37549070825566344`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 108}], {
             RGBColor[
             0.8874058680057144, 0.9088494378884622, 0.7606689085618024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 129}], {
             RGBColor[
             0.9919194200162629, 0.9837402828928126, 0.4795846817261888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 131}], {
             RGBColor[
             0.9464189057965813, 0.8120568568548516, 0.39007974658807487`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 143}], {
             RGBColor[
             0.9071887956861127, 0.574773145865902, 0.35502905680889496`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 154}], {
             RGBColor[
             0.9900533443030074, 0.9886857899175692, 0.707722631591383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 162}], {
             RGBColor[
             0.9882402059749112, 0.9877215722762983, 0.728168038634343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.22783801619652955`, 0.3568025791600926, 0.9362864100150281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 37}], {
             RGBColor[
             0.18496037581804925`, 0.31173546052289103`, 0.9338445918272582]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 56}], {
             RGBColor[
             0.1789270014196926, 0.30539400149218693`, 0.9335010000808495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 79}], {
             RGBColor[
             0.1914475775488761, 0.318553920854336, 0.9342140283688739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 89}], {
             RGBColor[
             0.5164596179840519, 0.3607037715624661, 0.5664186648111262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 118}], {
             RGBColor[
             0.5461172648909147, 0.6195523250843118, 0.9625471407361825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 119}], {
             RGBColor[
             0.37190268708568275`, 0.48151336908456555`, 0.9461947206260288]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 125}], {
             RGBColor[
             0.17894341561590066`, 0.30541125385312173`, 0.9335019348450408]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 144}], {
             RGBColor[
             0.5177214492396762, 0.3704027595311762, 0.5676269958465465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 149}], {
             RGBColor[
             0.20624750544947348`, 0.3341095834474904, 0.9350568623682817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 170}], {
             RGBColor[
             0.18064618334875748`, 0.3072009707020641, 0.9335989049484079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 190}], {
             RGBColor[
             0.1793170324527155, 0.3058039488372898, 0.9335232117711809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 195}], {
             RGBColor[
             0.1789270014196926, 0.30539400149218693`, 0.9335010000808495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 197}], {
             RGBColor[
             0.5339219982745609, 0.6098281505161249, 0.9613839453194717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[
             0.9171434396694482, 0.683563770249714, 0.28663285142090683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 49}], {
             RGBColor[
             0.9068295535414201, 0.6042867218959704, 0.2767562624168388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 64}], {
             RGBColor[
             0.8007620659771775, 0.8225276552268693, 0.6680235781600576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 67}], {
             RGBColor[
             0.8985635990383481, 0.540750973420999, 0.26884077504963666`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 87}], {
             RGBColor[
             0.9834480379935321, 0.9649273068843578, 0.6107852165105583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 95}], {
             RGBColor[
             0.9792736576371948, 0.9417473218129542, 0.37398250307217895`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 103}], {
             RGBColor[
             0.9216061306427468, 0.7086086374094871, 0.2905438354623711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 108}], {
             RGBColor[
             0.8800770451068233, 0.8847917621519991, 0.6757220357685101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 129}], {
             RGBColor[
             0.9845905971173718, 0.9596826071563495, 0.39463780893289646`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 131}], {
             RGBColor[
             0.93909008289769, 0.7879991811183886, 0.30513287379478254`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 143}], {
             RGBColor[
             0.8998599727872215, 0.550715470129439, 0.2700821840156026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 154}], {
             RGBColor[
             0.9827245214041163, 0.9646281141811062, 0.6227757587980907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 162}], {
             RGBColor[
             0.9809113830760201, 0.9636638965398352, 0.6432211658410507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 40}], {
             RGBColor[
             0.4439921507491714, 0.557946476502165, 0.9497988277939646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 51}], {
             RGBColor[
             0.3392714220793772, 0.4658216765666159, 0.9429291222497664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 74}], {
             RGBColor[
             0.3495927399015075, 0.4766700360070217, 0.9435169060307154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 80}], {
             RGBColor[
             0.5081499735315052, 0.6100326873138424, 0.9548495666212384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 121}], {
             RGBColor[
             0.46953919243500225`, 0.5786867158238351, 0.9518099844973704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 158}], {
             RGBColor[
             0.3248339638099492, 0.45064699253772245`, 0.9421069303596279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 164}], {
             RGBColor[
             0.34556297092325194`, 0.47243449330876475`, 0.9432874166489127]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.3936636675304358, 0.5153934155287933, 0.9463048786852943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 169}], {
             RGBColor[
             0.3344928369204973, 0.4607990805848347, 0.9426569888942514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 184}], {
             RGBColor[
             0.38376793461067366`, 0.5068222290476936, 0.9456743313341002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 37}], {
             RGBColor[
             0.23387138917519362`, 0.3631440366986098, 0.9366300016805876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 56}], {
             RGBColor[
             0.22783801477683696`, 0.3568025776679057, 0.9362864099341788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 67}], {
             RGBColor[
             0.5474773621295221, 0.27457683969669183`, 0.5520694598597993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 119}], {
             RGBColor[
             0.4208137004428272, 0.5329219452602844, 0.9489801304793581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 125}], {
             RGBColor[
             0.22785442897304503`, 0.35681983002884055`, 0.9362873446983702]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 128}], {
             RGBColor[
             0.5831652721126257, 0.49985421349972364`, 0.5843241339583132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 133}], {
             RGBColor[
             0.5500884366842889, 0.29464670290479555`, 0.5545698278022309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 190}], {
             RGBColor[
             0.22822804580985986`, 0.3572125250130086, 0.9363086216245102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 195}], {
             RGBColor[
             0.22783801477683696`, 0.3568025776679057, 0.9362864099341788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 48}], {
             RGBColor[
             0.30593974734452445`, 0.4381198166210231, 0.9407624779750857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 63}], {
             RGBColor[
             0.3238146353715521, 0.45360214621203954`, 0.941901450034025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 77}], {
             RGBColor[
             0.29758543140917015`, 0.4301115347901189, 0.9402584221293339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 106}], {
             RGBColor[
             0.28491435627629447`, 0.41679343143290143`, 0.9395368231456924]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 112}], {
             RGBColor[
             0.2981130439403854, 0.43066608901299275`, 0.9402884688824538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 140}], {
             RGBColor[
             0.3001402263093852, 0.4327967862135973, 0.9404039139194207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 189}], {
             RGBColor[
             0.26308408549772533`, 0.39384843272551495`, 0.9382936215198444]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 35}], {
             RGBColor[
             0.9160081618564544, 0.9327996859082862, 0.8697305761183244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 47}], {
             RGBColor[
             0.7225823732127437, 0.7785731992059557, 0.8525033535115121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 88}], {
             RGBColor[
             0.8529188119611348, 0.8833651723657042, 0.8634818621932413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 89}], {
             RGBColor[
             0.9238176258477779, 0.703826389599022, 0.47717574667802176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 113}], {
             RGBColor[
             0.946972557498295, 0.8159080843147557, 0.4967685640741427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 122}], {
             RGBColor[
             0.9932906731582525, 0.9894716805478189, 0.6138869514576812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 136}], {
             RGBColor[
             0.950824845750427, 0.8323116913697606, 0.49992668872926316`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 138}], {
             RGBColor[
             0.9532093472510355, 0.8417654452316519, 0.5018453146080967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 142}], {
             RGBColor[
             0.8172660326623933, 0.855490432397475, 0.8599437218958297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 144}], {
             RGBColor[
             0.9250794571034022, 0.713525377567732, 0.47838407771344216`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 153}], {
             RGBColor[
             0.7898065464682866, 0.8331975844693433, 0.8577820105552174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 159}], {
             RGBColor[
             0.9081437399557057, 0.5833500342919629, 0.46216641584665136`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 167}], {
             RGBColor[
             0.9544593958943188, 0.963459656199136, 0.8733980891466777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 181}], {
             RGBColor[
             0.988986461566373, 0.9897136330697374, 0.8321863641764009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 188}], {
             RGBColor[
             0.8291485068413533, 0.8647956293451209, 0.8611126603250323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 41}], {
             RGBColor[
             0.7217306402299773, 0.781717727178925, 0.9737111260908631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 65}], {
             RGBColor[
             0.9079204151899432, 0.9294151105020584, 0.9910794537825813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 66}], {
             RGBColor[
             0.7926835884248224, 0.8385659113515402, 0.9798127368656795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 90}], {
             RGBColor[
             0.6408480095261183, 0.7142786377339077, 0.9678341664939911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 110}], {
             RGBColor[
             0.7493871054318795, 0.8041704915393881, 0.9758883443405271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 162}], {
             RGBColor[
             0.9383242239537981, 0.9524410659335498, 0.9517777399403218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 180}], {
             RGBColor[
             0.8089076786179981, 0.8512402939181014, 0.9814298025533923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 198}], {
             RGBColor[
             0.7949540018905729, 0.840339575606766, 0.9800390304617252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 38}], {
             RGBColor[
             0.9076583192648293, 0.8882942413173389, 0.6516953277782057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[
             0.6710448937244029, 0.7408816350846033, 0.9693608389875064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 46}], {
             RGBColor[
             0.7241254080647266, 0.7839747878759986, 0.9735395315167075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 80}], {
             RGBColor[
             0.7352027165067365, 0.7929678458962808, 0.9744115778147804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 98}], {
             RGBColor[
             0.9119983758560902, 0.9316922814327566, 0.9576824339727095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 117}], {
             RGBColor[
             0.8147533586460658, 0.8554575003050673, 0.9821051874244302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 120}], {
             RGBColor[
             0.9036386065731989, 0.8747348065350462, 0.6360795030302686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 121}], {
             RGBColor[
             0.6965919354102337, 0.7616218744062735, 0.9713719956909121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 146}], {
             RGBColor[
             0.8233014482367667, 0.8621353328612098, 0.9829571811083924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 151}], {
             RGBColor[
             0.6011924048521665, 0.6814178617192261, 0.9646228375029955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 171}], {
             RGBColor[
             0.8624892635832501, 0.8931895434066397, 0.9867461899854671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 173}], {
             RGBColor[
             0.9228248907460509, 0.93782630255951, 0.8490773539223448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 178}], {
             RGBColor[
             0.8964701273649321, 0.9201113391332241, 0.9839677082524034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 196}], {
             RGBColor[
             0.6728409042264264, 0.742339717319497, 0.969502227513229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 53}], {
             RGBColor[
             0.2232819677009355, 0.3520138833210643, 0.9360269497932738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 82}], {
             RGBColor[
             0.27687504662639884`, 0.4074326830017036, 0.9391123497539292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 83}], {
             RGBColor[
             0.2455000054496245, 0.37536644969989263`, 0.9372922341744203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 100}], {
             RGBColor[
             0.22448297168171977`, 0.35327621465291903`, 0.9360953451932534]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 101}], {
             RGBColor[
             0.2434980017964442, 0.3732622169260371, 0.9371782230280707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 123}], {
             RGBColor[
             0.24279155375346242`, 0.3725196952414703, 0.9371379918571192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 127}], {
             RGBColor[
             0.2783696530571501, 0.40872723597091687`, 0.9392075847540681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 130}], {
             RGBColor[
             0.23618787859936186`, 0.36557881395732306`, 0.936761922326355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 135}], {
             RGBColor[
             0.23421532693659433`, 0.36350553709275546`, 0.9366495884272892]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 148}], {
             RGBColor[
             0.219972379693155, 0.3485352964848875, 0.9358384736523275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 163}], {
             RGBColor[
             0.23408691252963393`, 0.3633705654090964, 0.9366422754167848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 165}], {
             RGBColor[
             0.2270272954930984, 0.35595046029812505`, 0.9362402406703216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 176}], {
             RGBColor[
             0.264674301203473, 0.39551985025775493`, 0.9383841819517735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 187}], {
             RGBColor[
             0.2589893983893689, 0.38954465695647483`, 0.9380604351465702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 41}], {
             RGBColor[
             0.4363770738073567, 0.5497722412161976, 0.9497497290534018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 44}], {
             RGBColor[
             0.3032320659672701, 0.4347249229295589, 0.9406283792341544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 57}], {
             RGBColor[
             0.3418089819131736, 0.4704794931394012, 0.9430007439710605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 66}], {
             RGBColor[
             0.5073300220022017, 0.606620425388813, 0.955851339828218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 90}], {
             RGBColor[
             0.35549444310349765`, 0.4823331517711803, 0.9438727694565298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 141}], {
             RGBColor[
             0.3411893210123498, 0.46994277401217005`, 0.9429612597264045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 198}], {
             RGBColor[
             0.5096004354679522, 0.6083940896440386, 0.956077633424264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 44}], {
             RGBColor[
             0.2675860001638932, 0.3985802304775334, 0.9385499989000968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 50}], {
             RGBColor[
             0.2469901077447556, 0.3769326416900177, 0.9373770932957193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 60}], {
             RGBColor[
             0.25285259350547307`, 0.38309448592759754`, 0.9377109531870217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 90}], {
             RGBColor[
             0.31984837730012083`, 0.4461884593191548, 0.9417943891224722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 104}], {
             RGBColor[
             0.2353413665909268, 0.3646890761644966, 0.936713714719777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 130}], {
             RGBColor[
             0.2444860062107015, 0.3743006722085195, 0.9372344884178412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 163}], {
             RGBColor[
             0.24238504014097356`, 0.3720924236602928, 0.9371148415082708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 177}], {
             RGBColor[
             0.27267734754750905`, 0.40393155938778236`, 0.9388399436016203]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 47}], {
             RGBColor[
             0.6449475165023608, 0.7197336460567563, 0.9672187657343465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 68}], {
             RGBColor[
             0.8469990595612139, 0.880838075189855, 0.985268720497577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 88}], {
             RGBColor[
             0.775283955250752, 0.8245256192165048, 0.9781972744160757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.6282503776636906, 0.7052714236172997, 0.9661548388122466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 111}], {
             RGBColor[
             0.6494345587146366, 0.7234252020636741, 0.9675585260086426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 116}], {
             RGBColor[
             0.6139780435679677, 0.6929094451719539, 0.9652454183041966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 122}], {
             RGBColor[
             0.9156558164478696, 0.9306321273986194, 0.7286023636805157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 138}], {
             RGBColor[
             0.8755744905406526, 0.7829258920824524, 0.6165607268309311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 142}], {
             RGBColor[
             0.7396311759520104, 0.7966508792482756, 0.9746591341186641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 153}], {
             RGBColor[
             0.7121716897579038, 0.7743580313201439, 0.9724974227780518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 157}], {
             RGBColor[
             0.6980290555794366, 0.7628764037756551, 0.971384062809347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 160}], {
             RGBColor[
             0.6025425418355174, 0.6830045883363345, 0.9645167582458221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 167}], {
             RGBColor[
             0.876824539183936, 0.9046201030499366, 0.9881135013695121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 174}], {
             RGBColor[
             0.6098919568384804, 0.6893702822195625, 0.9649850564709783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 181}], {
             RGBColor[
             0.9113516048559902, 0.930874079920538, 0.9469017763992353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 185}], {
             RGBColor[
             0.8039733137479249, 0.8469379641216965, 0.9810567615537757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 188}], {
             RGBColor[
             0.7515136501309705, 0.8059560761959215, 0.9758280725478667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 132}], {
             RGBColor[
             0.24999710016017773`, 0.3800931813729572, 0.937548337065331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 151}], {
             RGBColor[
             0.2998281417164218, 0.4284810612879339, 0.9405321505496939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 169}], {
             RGBColor[
             0.260181316759984, 0.39079743873598083`, 0.9381283131344916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 200}], {
             RGBColor[
             0.24218408124275126`, 0.3718812031167312, 0.9371033971963092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 56}], {
             RGBColor[
             0.18496037439835666`, 0.3117354590307041, 0.9338445917464089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 79}], {
             RGBColor[
             0.19748095052754017`, 0.3248953783928531, 0.9345576200344334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 118}], {
             RGBColor[
             0.5521506378695789, 0.625893782622829, 0.962890732401742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 119}], {
             RGBColor[
             0.3779360600643469, 0.4878548266230827, 0.9465383122915882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 125}], {
             RGBColor[
             0.18497678859456473`, 0.3117527113916389, 0.9338455265106003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 128}], {
             RGBColor[
             0.5402876317341454, 0.454787094862522, 0.5818823157705433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 149}], {
             RGBColor[
             0.21228087842813756`, 0.34045104098600754`, 0.9354004540338412]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 170}], {
             RGBColor[
             0.18667955632742156`, 0.31354242824058126`, 0.9339424966139673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 190}], {
             RGBColor[
             0.18535040543137957`, 0.3121454063758069, 0.9338668034367403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 195}], {
             RGBColor[
             0.18496037439835666`, 0.3117354590307041, 0.9338445917464089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 46}], {
             RGBColor[
             0.7812753615379626, 0.7886327284729578, 0.6396314180362879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 98}], {
             RGBColor[
             0.9691483293293262, 0.9363502220297157, 0.6237743204922899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 117}], {
             RGBColor[
             0.8719033121193018, 0.8601154409020264, 0.6481970739440106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 120}], {
             RGBColor[
             0.960788560046435, 0.8793927471320053, 0.302171389549849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 128}], {
             RGBColor[
             0.9271948937048214, 0.742224726788967, 0.2736818311730274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 146}], {
             RGBColor[
             0.8804514017100027, 0.8667932734581691, 0.6490490676279728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 156}], {
             RGBColor[
             0.9428260097167436, 0.9163360030821683, 0.6550496534880772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 171}], {
             RGBColor[
             0.919639217056486, 0.8978474840035989, 0.6528380765050477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 178}], {
             RGBColor[
             0.9536200808381681, 0.9247692797301834, 0.650059594771984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 179}], {
             RGBColor[
             0.8863710041657746, 0.8714177118872631, 0.6496390782789341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 183}], {
             RGBColor[
             0.9123593760428652, 0.674860106009205, 0.26130271158407675`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 192}], {
             RGBColor[
             0.8910636363690327, 0.5135395909571491, 0.2410026071488931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 114}], {
             RGBColor[
             0.20908858865686974`, 0.3370957420335433, 0.935218657853937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 46}], {
             RGBColor[
             0.5446619359975361, 0.6412201222402223, 0.9572969292455886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 74}], {
             RGBColor[
             0.3971820108095485, 0.5168505289536836, 0.9468363149531384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.555739244439546, 0.6502131802605045, 0.9581689755436615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 117}], {
             RGBColor[
             0.6352898865788753, 0.7127028346692909, 0.9658625851533114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 121}], {
             RGBColor[
             0.5171284633430432, 0.6188672087704971, 0.9551293934197934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 166}], {
             RGBColor[
             0.4412529384384768, 0.5555739084754552, 0.9496242876077174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 169}], {
             RGBColor[
             0.38208210782853824`, 0.5009795735314966, 0.9459763978166744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 171}], {
             RGBColor[
             0.6830257915160596, 0.7504348777708634, 0.9705035877143484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 173}], {
             RGBColor[
             0.7433614186788604, 0.7950716369237336, 0.832834751651226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 196}], {
             RGBColor[
             0.49337743215923585`, 0.5995850516837207, 0.9532596252421102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 57}], {
             RGBColor[
             0.4551460034388895, 0.5660289447091988, 0.9509456686528102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 66}], {
             RGBColor[
             0.6206670435279176, 0.7021698769586107, 0.9637962645099678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 81}], {
             RGBColor[
             0.563023955866433, 0.6561272371693612, 0.9587424547119633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 90}], {
             RGBColor[
             0.46883146462921355`, 0.577882603340978, 0.9518176941382794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 141}], {
             RGBColor[
             0.4545263425380657, 0.5654922255819677, 0.9509061844081543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 168}], {
             RGBColor[
             0.7441532266042006, 0.7995222771759883, 0.9732629767804062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 172}], {
             RGBColor[
             0.7718454040169196, 0.8174234076188627, 0.7717375932565325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 184}], {
             RGBColor[
             0.46042354235664473`, 0.5706000836629397, 0.9512819487659052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 198}], {
             RGBColor[
             0.6229374569936681, 0.7039435412138363, 0.9640225581060137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 88}], {
             RGBColor[
             0.6168180360411716, 0.6987299024450158, 0.9637087446681081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[
             0.401201459999004, 0.517503689481011, 0.9473903200062829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 102}], {
             RGBColor[
             0.4476381958746549, 0.5602937273030086, 0.9502551687958871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 153}], {
             RGBColor[
             0.5537057705483233, 0.648562314548655, 0.9580088930300842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 49}], {
             RGBColor[
             0.8450514898395424, 0.34729106936125886`, 0.19077466358971318`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 67}], {
             RGBColor[
             0.8367855353364704, 0.2837553208862874, 0.18285917622251102`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 87}], {
             RGBColor[
             0.9216699742916543, 0.7079316543496461, 0.5248036176834326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 95}], {
             RGBColor[
             0.9174955939353169, 0.6847516692782425, 0.2880009042450533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 103}], {
             RGBColor[
             0.859828066940869, 0.45161298487477564`, 0.20456223663524548`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 129}], {
             RGBColor[
             0.922812533415494, 0.7026869546216379, 0.30865621010577077`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 131}], {
             RGBColor[
             0.8773120191958123, 0.531003528583677, 0.2191512749676569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 133}], {
             RGBColor[
             0.8393966098912371, 0.3038251840943911, 0.18535954416494269`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 143}], {
             RGBColor[
             0.8380819090853437, 0.29371981759472743`, 0.18410058518847694`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 154}], {
             RGBColor[
             0.9209464577022384, 0.7076324616463945, 0.536794159970965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 197}], {
             RGBColor[
             0.8721411848386535, 0.6704152078814393, 0.5949590715355129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 50}], {
             RGBColor[
             0.2628281872337618, 0.3935794674252022, 0.9382790484922793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 57}], {
             RGBColor[
             0.3220009955988029, 0.4509816264225601, 0.9418243188335629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 60}], {
             RGBColor[
             0.2686906729944792, 0.399741311662782, 0.9386129083835817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 90}], {
             RGBColor[
             0.33568645678912695`, 0.46283528505433924`, 0.9426963443190322]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 141}], {
             RGBColor[
             0.321381334697979, 0.45044490729532893`, 0.941784834588907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 177}], {
             RGBColor[
             0.2885154270365152, 0.4205783851229668, 0.9397418987981803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 120}], {
             RGBColor[
             0.9205644172331103, 0.7168104234407002, 0.25588752113131463`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 128}], {
             RGBColor[
             0.8869707508914968, 0.5796424030976618, 0.22739796275449303`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 168}], {
             RGBColor[
             0.9114761724933723, 0.7607551980488345, 0.6070253886431892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 172}], {
             RGBColor[
             0.9391683499060914, 0.7786563284917088, 0.4055000051193155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 173}], {
             RGBColor[
             0.9397507014059623, 0.7799019194651641, 0.46888537202339087`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 85}], {
             RGBColor[
             0.4789487657995369, 0.5853416186622634, 0.9528226814867443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 98}], {
             RGBColor[
             0.7856154181292234, 0.8320307685883754, 0.9456185242307917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 99}], {
             RGBColor[
             0.5809189759498203, 0.6706552206345228, 0.960151216244546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 109}], {
             RGBColor[
             0.4676427269643195, 0.5755488960812328, 0.9521022706897019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 117}], {
             RGBColor[
             0.6883704009191991, 0.7557959874606861, 0.9700412776825125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 121}], {
             RGBColor[
             0.570208977683367, 0.6619603615618923, 0.9593080859489944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 146}], {
             RGBColor[
             0.6969184905099, 0.7624738200168288, 0.9708932713664746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 151}], {
             RGBColor[
             0.4748094471252997, 0.581756348874845, 0.9525589277610778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 171}], {
             RGBColor[
             0.7361063058563833, 0.7935280305622586, 0.9746822802435494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 178}], {
             RGBColor[
             0.7700871696380653, 0.8204498262888431, 0.9719037985104857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 196}], {
             RGBColor[
             0.5464579464995596, 0.642678204475116, 0.9574383177713113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 54}], {
             RGBColor[
             0.3621640961349061, 0.48478721437619465`, 0.9444194198717641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 61}], {
             RGBColor[
             0.36265936899724993`, 0.48530777755663124`, 0.944447624928584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 73}], {
             RGBColor[
             0.3723282317178833, 0.495470365317321, 0.9449982523567235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 88}], {
             RGBColor[
             0.5818581666070413, 0.6702991325141743, 0.9609700518092634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 94}], {
             RGBColor[
             0.4348245890199799, 0.551044936914969, 0.9489276162054343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 105}], {
             RGBColor[
             0.3973660260121461, 0.5186002123597028, 0.9465407896938819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 111}], {
             RGBColor[
             0.45600877007092583`, 0.5691987153613436, 0.9503313034018304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 116}], {
             RGBColor[
             0.42055225492425696`, 0.5386829584696233, 0.9480181956973843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 126}], {
             RGBColor[
             0.37937335834478547`, 0.5028752400890226, 0.9453994618957948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 142}], {
             RGBColor[
             0.5462053873082997, 0.642424392545945, 0.9574319115118519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 153}], {
             RGBColor[
             0.518745901114193, 0.6201315446178133, 0.9552702001712396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 157}], {
             RGBColor[
             0.5046032669357259, 0.6086499170733246, 0.9541568402025347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 160}], {
             RGBColor[
             0.4091167531918066, 0.528778101634004, 0.9472895356390099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 167}], {
             RGBColor[
             0.6833987505402253, 0.7503936163476059, 0.9708862787627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 174}], {
             RGBColor[
             0.4164661681947697, 0.535143795517232, 0.9477578338641661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 188}], {
             RGBColor[
             0.5580878614872598, 0.6517295894935908, 0.9586008499410545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 59}], {
             RGBColor[
             0.382953798860026, 0.5061170655801353, 0.9456224553239809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.3349775869314745, 0.46456248216214874`, 0.942565453523592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 77}], {
             RGBColor[
             0.30874838296909257`, 0.4410718707402281, 0.9409224256189008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 106}], {
             RGBColor[
             0.29607730783621694`, 0.42775376738301063`, 0.9402008266352594]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 112}], {
             RGBColor[
             0.3092759955003079, 0.44162642496310195`, 0.9409524723720207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 140}], {
             RGBColor[
             0.3113031778693076, 0.4437571221637065, 0.9410679174089878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 193}], {
             RGBColor[
             0.3168945933506373, 0.44889990200011176`, 0.9414132211627845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 67}], {
             RGBColor[
             0.8264716492084423, 0.20447827253254375`, 0.17298258721844303`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.9113560881636262, 0.6286546059959026, 0.5149270286793647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 95}], {
             RGBColor[
             0.9071817078072888, 0.605474620924499, 0.27812431524098535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 103}], {
             RGBColor[
             0.8495141808128409, 0.372335936521032, 0.19468564763117746`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 108}], {
             RGBColor[
             0.8079850952769174, 0.5485190612635439, 0.5798638479373164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[
             0.9124986472874659, 0.6234099062678943, 0.2987796211017028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 131}], {
             RGBColor[
             0.8669981330677842, 0.45172648022993345`, 0.2092746859635889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 133}], {
             RGBColor[
             0.829082723763209, 0.22454813574064747`, 0.1754829551608747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 143}], {
             RGBColor[
             0.8277680229573157, 0.2144427692409838, 0.17422399618440892`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 154}], {
             RGBColor[
             0.9106325715742103, 0.628355413292651, 0.5269175709668971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 162}], {
             RGBColor[
             0.9088194332461141, 0.62739119565138, 0.547362978009857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 53}], {
             RGBColor[
             0.22682228238214364`, 0.3557349785199296, 0.9362285654769424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 60}], {
             RGBColor[
             0.24809478057534154`, 0.3780937228752663, 0.9374400027792041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 82}], {
             RGBColor[
             0.28041536130760697`, 0.41115377820056886`, 0.9393139654375977]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 100}], {
             RGBColor[
             0.2280232863629279, 0.35699730985178435`, 0.9362969608769219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 104}], {
             RGBColor[
             0.2305835536607953, 0.3596883131121654, 0.9364427643119595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 123}], {
             RGBColor[
             0.24633186843467056`, 0.37624079044033565`, 0.9373396075407877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.23972819328057, 0.3692999091561883, 0.9369635380100236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 163}], {
             RGBColor[
             0.23762722721084206`, 0.36709166060796167`, 0.9368438911004533]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 177}], {
             RGBColor[
             0.2679195346173776, 0.39893079633545114`, 0.9385689931938027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 71}], {
             RGBColor[
             0.2862116459129269, 0.41815696509391576`, 0.9396107018713307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 74}], {
             RGBColor[
             0.29246128213975436`, 0.4247257290181345, 0.9399666094089402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 158}], {
             RGBColor[
             0.267702506048196, 0.39870268554883526`, 0.9385566337378528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 164}], {
             RGBColor[
             0.28843151316149873`, 0.42049018631987756`, 0.9397371200271375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 166}], {
             RGBColor[
             0.33653220976868264`, 0.46344910853990606`, 0.9427545820635193]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 184}], {
             RGBColor[
             0.3266364768489205, 0.4548779220588064, 0.942124034712325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 70}], {
             RGBColor[
             0.2130689137116028, 0.34127931603325223`, 0.9354453314774407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 134}], {
             RGBColor[
             0.22165741455534713`, 0.35030637496243233`, 0.9359344338949436]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 145}], {
             RGBColor[
             0.21010927874609994`, 0.3381685520328137, 0.9352767846445429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 100}], {
             RGBColor[
             0.21261327393044743`, 0.34080040973402737`, 0.9354193834659627]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 104}], {
             RGBColor[
             0.21517354122831484`, 0.34349141299440844`, 0.9355651869010002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 123}], {
             RGBColor[
             0.2309218560021901, 0.36004389032257866`, 0.9364620301298284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 130}], {
             RGBColor[
             0.22431818084808952`, 0.35310300903843134`, 0.9360859605990643]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 135}], {
             RGBColor[
             0.222345629185322, 0.35102973217386374`, 0.9359736266999984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 148}], {
             RGBColor[
             0.20810268194188267`, 0.3360594915659958, 0.9351625119250367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 163}], {
             RGBColor[
             0.2222172147783616, 0.3508947604902047, 0.935966313689494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 165}], {
             RGBColor[
             0.21515759774182608`, 0.3434746553792333, 0.935564278943031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 58}], {
             RGBColor[
             0.2684799532608956, 0.3995198318623828, 0.9386009082064859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 61}], {
             RGBColor[
             0.27330173727350593`, 0.40458783257840025`, 0.9388755016728139]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 73}], {
             RGBColor[
             0.28297059999413937`, 0.41475042033909004`, 0.9394261291009534]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 94}], {
             RGBColor[
             0.3454669572962359, 0.47032499193673805`, 0.9433554929496641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 105}], {
             RGBColor[
             0.3080083942884021, 0.4378802673814718, 0.9409686664381117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 115}], {
             RGBColor[
             0.2691801918114708, 0.40025582697672574`, 0.938640785756031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 116}], {
             RGBColor[
             0.33119462320051296`, 0.4579630134913923, 0.9424460724416142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 126}], {
             RGBColor[
             0.29001572662104147`, 0.4221552951107917, 0.9398273386400247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 160}], {
             RGBColor[
             0.3197591214680627, 0.448058156655773, 0.9417174123832397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 174}], {
             RGBColor[
             0.3271085364710258, 0.454423850539001, 0.942185710608396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 62}], {
             RGBColor[
             0.35430836392456, 0.4813058296004574, 0.9437971935400564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 68}], {
             RGBColor[
             0.6040034340544339, 0.6836766872491769, 0.9648829517187356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 72}], {
             RGBColor[
             0.3011292819316679, 0.4298018950317811, 0.9406079602011264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 75}], {
             RGBColor[
             0.3182717437982659, 0.44781970934843396`, 0.9415841980444295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 76}], {
             RGBColor[
             0.31436618073050393`, 0.4437147149372155, 0.9413617820054831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 96}], {
             RGBColor[
             0.32928937279498216`, 0.459399935982008, 0.942211635716671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 107}], {
             RGBColor[
             0.5098065457970684, 0.609801290788619, 0.955570731517623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 111}], {
             RGBColor[
             0.40643893320785657`, 0.5262638141229958, 0.9471727572298012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 139}], {
             RGBColor[
             0.3007701310464627, 0.42942440467994913`, 0.9405875070895301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 147}], {
             RGBColor[
             0.41653896028796467`, 0.5344634711076623, 0.9479678683591656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 157}], {
             RGBColor[
             0.4550334300726567, 0.5657150158349769, 0.9509982940305055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 182}], {
             RGBColor[
             0.30875284137949693`, 0.43781473937303605`, 0.9410421106336347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 185}], {
             RGBColor[
             0.5609776882411449, 0.6497765761810184, 0.9606709927749343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 191}], {
             RGBColor[
             0.31630641834476525`, 0.445754027687974, 0.9414722756672911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 79}], {
             RGBColor[
             0.1914475761291835, 0.31855391936214905`, 0.9342140282880245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 118}], {
             RGBColor[
             0.5461172634712221, 0.619552323592125, 0.9625471406553332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 119}], {
             RGBColor[
             0.37190268566599016`, 0.4815133675923786, 0.9461947205451795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 125}], {
             RGBColor[
             0.17894341419620807`, 0.3054112523609348, 0.9335019347641915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 129}], {
             RGBColor[
             0.5845933454317087, 0.6420998957641366, 0.6750810838088802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 149}], {
             RGBColor[
             0.2062475040297809, 0.3341095819553035, 0.9350568622874322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 170}], {
             RGBColor[
             0.1806461819290649, 0.30720096920987716`, 0.9335989048675586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 190}], {
             RGBColor[
             0.1793170310330229, 0.30580394734510286`, 0.9335232116903315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 195}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 197}], {
             RGBColor[
             0.5339219968548683, 0.6098281490239381, 0.9613839452386224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 66}], {
             RGBColor[
             0.5260989516337345, 0.6228771288818142, 0.9570472794276266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 71}], {
             RGBColor[
             0.32543061952646807`, 0.4545863786212526, 0.9420196308425695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 81}], {
             RGBColor[
             0.4684558639722499, 0.5768344890925647, 0.951993469629622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 90}], {
             RGBColor[
             0.37426337273503046`, 0.49858985526418154`, 0.9450687090559382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 141}], {
             RGBColor[
             0.35995825064388254`, 0.48619947750517123`, 0.9441571993258131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 198}], {
             RGBColor[
             0.528369365099485, 0.6246507931370399, 0.9572735730236723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 61}], {
             RGBColor[
             0.26897522612323943`, 0.4000403950428194, 0.9386291132633059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 73}], {
             RGBColor[
             0.2786440888438728, 0.4102029828035092, 0.9391797406914454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 92}], {
             RGBColor[
             0.24643437763355744`, 0.3763485341078243, 0.9373454452880156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 115}], {
             RGBColor[
             0.2648536806612042, 0.3957083894411449, 0.9383943973465231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 155}], {
             RGBColor[
             0.25688825427596124`, 0.3873362212730521, 0.9379407780976758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 154}], {
             RGBColor[
             0.7176662191262557, 0.7759253920834623, 0.911377748265729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 186}], {
             RGBColor[
             0.36541764511564734`, 0.4884580900498052, 0.9445955073983169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 193}], {
             RGBColor[
             0.38274569330621644`, 0.5059368150091147, 0.9456091950221126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.2862778470683244, 0.4173156224381487, 0.9396478253289002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 104}], {
             RGBColor[
             0.23644603942151277`, 0.3658501573497452, 0.9367766242032618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 123}], {
             RGBColor[
             0.252194354195388, 0.3824026346779154, 0.9376734674320901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 130}], {
             RGBColor[
             0.2455906790412874, 0.3754617533937681, 0.9372973979013259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 163}], {
             RGBColor[
             0.24348971297155947`, 0.37325350484554143`, 0.9371777509917558]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 177}], {
             RGBColor[
             0.273782020378095, 0.40509264057303096`, 0.9389028530851051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 73}], {
             RGBColor[
             0.28346587285648317`, 0.41527098351952657`, 0.9394543341577734]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 94}], {
             RGBColor[
             0.34596223015857974`, 0.47084555511717463`, 0.9433836980064841]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 105}], {
             RGBColor[
             0.30850366715074595`, 0.4384008305619083, 0.9409968714949317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 115}], {
             RGBColor[
             0.2696754646738146, 0.40077639015716227`, 0.938668990812851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 116}], {
             RGBColor[
             0.3316898960628568, 0.4584835766718288, 0.9424742774984342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 160}], {
             RGBColor[
             0.3202543943304065, 0.44857871983620956`, 0.9417456174400596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 174}], {
             RGBColor[
             0.3276038093333696, 0.4549444137194375, 0.9422139156652158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 68}], {
             RGBColor[
             0.6059297438464823, 0.6853451599719039, 0.965005694475316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 75}], {
             RGBColor[
             0.3201980535903144, 0.44948818207116104`, 0.9417069408010099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 76}], {
             RGBColor[
             0.3162924905225524, 0.44538318765994256`, 0.9414845247620637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 96}], {
             RGBColor[
             0.33121568258703066`, 0.4610684087047351, 0.9423343784732514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 105}], {
             RGBColor[
             0.3497224989411253, 0.4773337838440822, 0.9435049862784333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 107}], {
             RGBColor[
             0.5117328555891169, 0.611469763511346, 0.9556934742742034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 111}], {
             RGBColor[
             0.40836524299990506`, 0.527932286845723, 0.9472954999863816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 116}], {
             RGBColor[
             0.37290872785323614`, 0.4974165299540027, 0.9449823922819357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 126}], {
             RGBColor[
             0.33172983127376465`, 0.4616088115734021, 0.9423636584803461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 157}], {
             RGBColor[
             0.4569597398647052, 0.567383488557704, 0.951121036787086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 174}], {
             RGBColor[
             0.36882264112374896`, 0.4938773670016114, 0.9447220304487174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 182}], {
             RGBColor[
             0.31067915117154543`, 0.43948321209576313`, 0.9411648533902153]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 185}], {
             RGBColor[
             0.5629039980331934, 0.6514450489037454, 0.9607937355315148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 191}], {
             RGBColor[
             0.3182327281368137, 0.4474225004107011, 0.9415950184238715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 77}], {
             RGBColor[
             0.3266232709961202, 0.4565542003312445, 0.9420613976778401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 91}], {
             RGBColor[
             0.5953350475574752, 0.6767809281925967, 0.9640487060966569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 102}], {
             RGBColor[
             0.3633436999904507, 0.48913178357153686`, 0.9443729171645411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 106}], {
             RGBColor[
             0.3139521958632445, 0.44323609697402705`, 0.9413397986941987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 112}], {
             RGBColor[
             0.32715088352733546`, 0.45710875455411837`, 0.94209144443096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 140}], {
             RGBColor[
             0.32917806589633525`, 0.4592394517547229, 0.942206889467927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 69}], {
             RGBColor[
             0.512094113243802, 0.613375440560194, 0.9551211815778647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 82}], {
             RGBColor[
             0.4706005281918093, 0.5774357827163821, 0.9524772470296884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 86}], {
             RGBColor[
             0.5072811113074129, 0.6092066601914048, 0.9548145013504485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 87}], {
             RGBColor[
             0.8052886005993835, 0.8468955393268014, 0.9061943444225835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 108}], {
             RGBColor[
             0.7019176077126746, 0.7667599945944428, 0.9711311636805353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 110}], {
             RGBColor[
             0.6138148271599528, 0.6973615545881173, 0.9627408981532811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 127}], {
             RGBColor[
             0.4720951346225606, 0.5787303356855954, 0.9525724820298272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 154}], {
             RGBColor[
             0.8045650840099676, 0.8465963466235498, 0.9181848867101159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 161}], {
             RGBColor[
             0.4656307978135873, 0.573123205257251, 0.9521608748370004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 162}], {
             RGBColor[
             0.8027519456818715, 0.845632128982279, 0.9386302937530759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 175}], {
             RGBColor[
             0.4715002623045349, 0.5782150871828736, 0.9525345772917476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 176}], {
             RGBColor[
             0.45839978276888355`, 0.5655229499724335, 0.9517490792275327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 180}], {
             RGBColor[
             0.6733354003460714, 0.7444313569668306, 0.9682823563661463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 66}], {
             RGBColor[
             0.8068568184878835, 0.8498672602817441, 0.9811645922016861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 69}], {
             RGBColor[
             0.6618396215787897, 0.7314857264416685, 0.9696204831011173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 87}], {
             RGBColor[
             0.9550341089343712, 0.965005825208276, 0.9206936459458361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 90}], {
             RGBColor[
             0.6550212395891795, 0.7255799866641114, 0.9691860218299977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 110}], {
             RGBColor[
             0.7635603354949406, 0.815471840469592, 0.9772401996765336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 131}], {
             RGBColor[
             0.9106761538385292, 0.7880776994423069, 0.6150413032300603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 133}], {
             RGBColor[
             0.872760744533954, 0.5608993549530209, 0.5812495724273461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 162}], {
             RGBColor[
             0.9524974540168591, 0.9637424148637534, 0.9531295952763283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 180}], {
             RGBColor[
             0.8230809086810591, 0.8625416428483053, 0.9827816578893989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 198}], {
             RGBColor[
             0.809127231953634, 0.8516409245369697, 0.9813908857977319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 81}], {
             RGBColor[
             0.633976904061278, 0.7129754213419766, 0.9648440654867796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 90}], {
             RGBColor[
             0.5397844128240585, 0.6347307875135932, 0.9579193049130958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 141}], {
             RGBColor[
             0.5254792907329107, 0.622340409754583, 0.9570077951829706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 168}], {
             RGBColor[
             0.8151061747990456, 0.8563704613486036, 0.9793645875552226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 172}], {
             RGBColor[
             0.8427983522117647, 0.874271591791478, 0.7778392040313489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 198}], {
             RGBColor[
             0.6938904051885131, 0.7607917253864516, 0.97012416888083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 87}], {
             RGBColor[
             0.9030901336605541, 0.565118857520931, 0.5070115413121625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 103}], {
             RGBColor[
             0.8412482263097689, 0.30880018804606046`, 0.1867701602639753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 129}], {
             RGBColor[
             0.9042326927843938, 0.5598741577929227, 0.2908641337345006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 131}], {
             RGBColor[
             0.8587321785647122, 0.38819073175496194`, 0.20135919859638673`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 133}], {
             RGBColor[
             0.820816769260137, 0.16101238726567596`, 0.16756746779367254`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 143}], {
             RGBColor[
             0.8195020684542436, 0.15090702076601228`, 0.16630850881720677`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 162}], {
             RGBColor[
             0.9005534787430421, 0.5638554471764086, 0.5394474906426548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 107}], {
             RGBColor[
             0.7614279257189907, 0.8138406211600655, 0.9767792324528825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 111}], {
             RGBColor[
             0.6580603131297789, 0.7303031444944423, 0.9683812581650608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 122}], {
             RGBColor[
             0.924281570863012, 0.9375100698293877, 0.7294250958369339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 138}], {
             RGBColor[
             0.8842002449557951, 0.7898038345132208, 0.6173834589873493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 142}], {
             RGBColor[
             0.7482569303671527, 0.8035288216790438, 0.9754818662750824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 147}], {
             RGBColor[
             0.668160340209887, 0.7385028014791089, 0.9691763692944251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 156}], {
             RGBColor[
             0.8882342803358891, 0.9137179209353309, 0.9892017726661817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 157}], {
             RGBColor[
             0.7066548099945791, 0.7697543462064234, 0.9722067949657651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 179}], {
             RGBColor[
             0.8317792747849202, 0.8687996297404257, 0.9837911974570385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 181}], {
             RGBColor[
             0.9199773592711327, 0.9377520223513063, 0.9477245085556535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 185}], {
             RGBColor[
             0.8125990681630673, 0.8538159065524649, 0.9818794937101938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 82}], {
             RGBColor[
             0.3600920128525825, 0.48631533560726303`, 0.9441657225354702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 86}], {
             RGBColor[
             0.39677259596818604`, 0.5180862130822859, 0.9465029768562303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 90}], {
             RGBColor[
             0.3947672159149649, 0.5163492536735178, 0.946375195812527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 110}], {
             RGBColor[
             0.503306311820726, 0.6062411074789984, 0.9544293736590629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 123}], {
             RGBColor[
             0.3260085199796461, 0.4514023478470298, 0.9421913646386602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 127}], {
             RGBColor[
             0.3615866192833338, 0.48760988857647636`, 0.944260957535609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 177}], {
             RGBColor[
             0.3475961861623531, 0.47409235374214537`, 0.9434207502916752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 180}], {
             RGBColor[
             0.5628268850068445, 0.6533109098577117, 0.9599708318719281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 72}], {
             RGBColor[
             0.23177582019152226`, 0.36094146083002354`, 0.936510662127084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 93}], {
             RGBColor[
             0.21891136206643785`, 0.34742009968680476`, 0.9357780502681208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 134}], {
             RGBColor[
             0.2222636314959646, 0.3509435474033953, 0.9359689570528942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 139}], {
             RGBColor[
             0.23141666930631707`, 0.36056397047819155`, 0.9364902090154877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.2107154956867174, 0.33880572447377666`, 0.9353113078024935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 81}], {
             RGBColor[
             0.43330857195401157`, 0.5446846710814149, 0.9498164169017225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 164}], {
             RGBColor[
             0.2925031947568016, 0.42476978183606456`, 0.9399689962704769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 184}], {
             RGBColor[
             0.3307081584442233, 0.45915751757499346`, 0.9423559109556644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 75}], {
             RGBColor[
             0.26701897159742227`, 0.39798424750248473`, 0.9385177074620799]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 84}], {
             RGBColor[
             0.256326539038239, 0.386745822943403, 0.9379087892458708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 93}], {
             RGBColor[
             0.23701205160573985`, 0.3664450720426131, 0.9368088577598136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 134}], {
             RGBColor[
             0.2403643210352666, 0.36996851975920364`, 0.9369997645445869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 139}], {
             RGBColor[
             0.24951735884561907`, 0.3795889428339999, 0.9375210165071806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 152}], {
             RGBColor[
             0.2658080334878341, 0.396711474771397, 0.9384487463281612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 191}], {
             RGBColor[
             0.2650536461439216, 0.3959185658420248, 0.9384057850849414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 94}], {
             RGBColor[
             0.35563109287921313`, 0.4810081428778644, 0.9439343254346236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 115}], {
             RGBColor[
             0.27934432739444803`, 0.41093897791785206`, 0.9392196182409905]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 153}], {
             RGBColor[
             0.4395524049734263, 0.5500947505807087, 0.9502769094004289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 160}], {
             RGBColor[
             0.3299232570510399, 0.45874130759689935`, 0.9422962448681991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 80}], {
             RGBColor[
             0.46133983359188224`, 0.5689367397653611, 0.9518870537804123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 158}], {
             RGBColor[
             0.2780238238703263, 0.40955104498924105`, 0.9391444175188017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 164}], {
             RGBColor[
             0.29875283098362904`, 0.4313385457602833, 0.9403249038080864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 166}], {
             RGBColor[
             0.34685352759081295`, 0.47429746798031186`, 0.9433423658444682]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 169}], {
             RGBColor[
             0.28768269698087445`, 0.4197031330363533, 0.9396944760534252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 184}], {
             RGBColor[
             0.3369577946710508, 0.46572628149921225`, 0.9427118184932739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 76}], {
             RGBColor[
             0.2802558703962583, 0.4118970674079191, 0.9392715292664366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 96}], {
             RGBColor[
             0.29517906246073655`, 0.4275822884527116, 0.9401213829776245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 134}], {
             RGBColor[
             0.2575067829018646, 0.3879863340758565, 0.93797600238789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 139}], {
             RGBColor[
             0.26665982071221705`, 0.39760675715065275`, 0.9384972543504835]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 182}], {
             RGBColor[
             0.27464253104525127`, 0.40599709184373967`, 0.9389518578945881]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 191}], {
             RGBColor[
             0.2821961080105196, 0.4139363801586776, 0.9393820229282445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.2912734993929746, 0.42347729404149315`, 0.9398989669386781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 105}], {
             RGBColor[
             0.3097803157470692, 0.4397426691808402, 0.94106957474386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 111}], {
             RGBColor[
             0.368423059805849, 0.49034117218248097`, 0.9448600884518084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 116}], {
             RGBColor[
             0.3329665446591801, 0.4598254152907607, 0.9425469807473624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 126}], {
             RGBColor[
             0.2917876480797086, 0.4240176969101601, 0.9399282469457728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 174}], {
             RGBColor[
             0.3288804579296929, 0.4562862523383694, 0.9422866189141441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.27073696797748936`, 0.4018920974325212, 0.938729441855642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 191}], {
             RGBColor[
             0.2782905449427576, 0.40983138574745914`, 0.9391596068892982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 102}], {
             RGBColor[
             0.33711449602806876`, 0.4656411721496162, 0.9427298892598499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 106}], {
             RGBColor[
             0.2877229919008626, 0.4197454855521064, 0.9396967707895075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 112}], {
             RGBColor[
             0.3009216795649535, 0.4336181431321977, 0.9404484165262689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 140}], {
             RGBColor[
             0.3029488619339533, 0.43574884033280226`, 0.9405638615632359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 189}], {
             RGBColor[
             0.2658927211222934, 0.3968004868447199, 0.9384535691636595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 91}], {
             RGBColor[
             0.8828910750951913, 0.909457394113841, 0.9886921329803882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 95}], {
             RGBColor[
             0.9537951709684989, 0.944166482218568, 0.6841709176231596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 113}], {
             RGBColor[
             0.9141333132318434, 0.7927873365838396, 0.6157566218013946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 136}], {
             RGBColor[
             0.9179856014839756, 0.8091909436388446, 0.6189147464565151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 89}], {
             RGBColor[
             0.5289801926935428, 0.3738636894324282, 0.5671316930183012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 118}], {
             RGBColor[
             0.5586378396004057, 0.632712242954274, 0.9632601689433578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 119}], {
             RGBColor[
             0.3844232617951737, 0.4946732869545277, 0.9469077488332039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 125}], {
             RGBColor[
             0.19146399032539158`, 0.3185711717230839, 0.934214963052216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 128}], {
             RGBColor[
             0.5467748334649722, 0.46160555519396695`, 0.5822517523121589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 144}], {
             RGBColor[
             0.5302420239491671, 0.38356267740113825`, 0.5683400240537216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 149}], {
             RGBColor[
             0.21876808015896437`, 0.34726950131745254`, 0.9357698905754568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 159}], {
             RGBColor[
             0.5133063068014707, 0.25338733412536907`, 0.5521223621869309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 170}], {
             RGBColor[
             0.1931667580582484, 0.32036088857202627`, 0.934311933155583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 190}], {
             RGBColor[
             0.19183760716220638`, 0.3189638667072519, 0.9342362399783559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 192}], {
             RGBColor[
             0.5106435761291835, 0.23292041936214905`, 0.5495725282880245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 195}], {
             RGBColor[
             0.1914475761291835, 0.31855391936214905`, 0.9342140282880245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 197}], {
             RGBColor[
             0.5464425729840517, 0.6229880683860871, 0.9620969735266468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 81}], {
             RGBColor[
             0.5981154418108365, 0.6846160863124545, 0.9615049850298553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 117}], {
             RGBColor[
             0.699447709361209, 0.7647890454809683, 0.9709133239805854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 120}], {
             RGBColor[
             0.7883329572883422, 0.7840663517109472, 0.6248876395864237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 121}], {
             RGBColor[
             0.5812862861253769, 0.6709534195821745, 0.9601801322470673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 166}], {
             RGBColor[
             0.5054107612208105, 0.6076601192871327, 0.9546750264349914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 168}], {
             RGBColor[
             0.7792447125486042, 0.8280111263190817, 0.9760255070982982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 172}], {
             RGBColor[
             0.8069368899613232, 0.8459122567619559, 0.7745001235744244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 173}], {
             RGBColor[
             0.807519241461194, 0.8471578477354111, 0.8378854904784999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 184}], {
             RGBColor[
             0.4955150283010483, 0.599088932806033, 0.9540444790837972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 164}], {
             RGBColor[
             0.43552843920258344`, 0.5470178923073767, 0.9499428350575294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 166}], {
             RGBColor[
             0.4836291358097673, 0.5899768145274054, 0.9529602970939112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 168}], {
             RGBColor[
             0.7574630871375609, 0.8103278215593543, 0.974310777757218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 172}], {
             RGBColor[
             0.7851552645502801, 0.8282289520022286, 0.7727853942333442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 173}], {
             RGBColor[
             0.7857376160501509, 0.8294745429756838, 0.8361707611374197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 184}], {
             RGBColor[
             0.47373340289000515`, 0.5814056280463057, 0.952329749742717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 198}], {
             RGBColor[
             0.6362473175270285, 0.7147490855972023, 0.9650703590828255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 86}], {
             RGBColor[
             0.3552790109161934, 0.48214655523847394`, 0.943859042308054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 101}], {
             RGBColor[
             0.2852213829706352, 0.4162052116877847, 0.9395876612614353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 110}], {
             RGBColor[
             0.4618127267687334, 0.5703014496351865, 0.9517854391108865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 123}], {
             RGBColor[
             0.28451493492765345`, 0.4154626900032179, 0.9395474300904838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 127}], {
             RGBColor[
             0.32009303423134106`, 0.45167023073266444`, 0.9416170229874327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 130}], {
             RGBColor[
             0.27791125977355285`, 0.4085218087190706, 0.9391713605597196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 163}], {
             RGBColor[
             0.2758102937038249, 0.40631356017084397`, 0.9390517136501494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 176}], {
             RGBColor[
             0.30639768237766407`, 0.4384628450195025, 0.9407936201851381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 177}], {
             RGBColor[
             0.3061026011103605, 0.4381526958983335, 0.9407768157434988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 180}], {
             RGBColor[
             0.5213332999548519, 0.6173712520138998, 0.9573268973237518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 187}], {
             RGBColor[
             0.3007127795635599, 0.4324876517182224, 0.9404698733799348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 86}], {
             RGBColor[
             0.32390396973941904`, 0.450080321936663, 0.9420389267285452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 101}], {
             RGBColor[
             0.2538463417938609, 0.3841389783859738, 0.9377675456819266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 124}], {
             RGBColor[
             0.2734514125634414, 0.4047451507980839, 0.9388840254591511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 135}], {
             RGBColor[
             0.244563666934011, 0.3743822985526921, 0.9372389110811449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 137}], {
             RGBColor[
             0.2530177140174724, 0.383268038054954, 0.9377203565559061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 161}], {
             RGBColor[
             0.28225365624559345`, 0.41399686700250915`, 0.9393853002150969]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 165}], {
             RGBColor[
             0.2373756354905151, 0.36682722175806165`, 0.9368295633241774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 175}], {
             RGBColor[
             0.2881231207365411, 0.41908874892813175`, 0.9397590026698441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 176}], {
             RGBColor[
             0.2750226412008897, 0.4063966117176916, 0.9389735046056292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 187}], {
             RGBColor[
             0.26933773838678554`, 0.40042141841641143`, 0.938649757800426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 199}], {
             RGBColor[
             0.2640684264301843, 0.3948830374563491, 0.938349678279746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 93}], {
             RGBColor[
             0.24346208091315458`, 0.3732244618001842, 0.9371761773869076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 139}], {
             RGBColor[
             0.25596738815303377`, 0.386368332591571, 0.9378883361342745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 152}], {
             RGBColor[
             0.2722580627952489, 0.4034908645289682, 0.9388160659552552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 194}], {
             RGBColor[
             0.30565287667395435`, 0.4349127039944547, 0.9408525291212098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 99}], {
             RGBColor[
             0.4621252914114974, 0.5716835642651686, 0.9514982759565006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 109}], {
             RGBColor[
             0.34884904242599657`, 0.47657723971187865`, 0.9434493304016565]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 132}], {
             RGBColor[
             0.3061847210307328, 0.43439681259051416`, 0.9409221739886695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 146}], {
             RGBColor[
             0.578124805971577, 0.6635021636474746, 0.9622403310784291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 150}], {
             RGBColor[
             0.3215409260409259, 0.45053715769585945`, 0.9417966871465304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 151}], {
             RGBColor[
             0.35601576258697687`, 0.48278469250549083`, 0.9439059874730323]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 152}], {
             RGBColor[
             0.320947319253029, 0.44991323932493577`, 0.9417628821181223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 194}], {
             RGBColor[
             0.35434213313173446`, 0.48133507879042225`, 0.9437993452840767]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 196}], {
             RGBColor[
             0.42766426196123664`, 0.5437065481057618, 0.9487853774832657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 101}], {
             RGBColor[
             0.3219019660862388, 0.44797608916280746`, 0.9419249155821955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 108}], {
             RGBColor[
             0.5865960904370586, 0.6714707671165345, 0.9625129589589009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 110}], {
             RGBColor[
             0.49849330988433693`, 0.6020723271102092, 0.9541226934316467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 124}], {
             RGBColor[
             0.3415070368558193, 0.46858226157491756`, 0.94304139535942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 127}], {
             RGBColor[
             0.3567736173469446, 0.48344110820768715`, 0.9439542773081928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 161}], {
             RGBColor[
             0.35030928053797133`, 0.47783397777934283`, 0.943542670115366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 175}], {
             RGBColor[
             0.356178745028919, 0.4829258597049654, 0.9439163725701132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 176}], {
             RGBColor[
             0.3430782654932676, 0.4702337224945253, 0.9431308745058982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 180}], {
             RGBColor[
             0.5580138830704554, 0.6491421294889225, 0.9596641516445119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 187}], {
             RGBColor[
             0.3373933626791634, 0.4642585291932452, 0.9428071277006951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 199}], {
             RGBColor[
             0.3321240507225622, 0.4587201482331828, 0.9425070481800151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 95}], {
             RGBColor[
             0.9838001922594006, 0.9661152059128862, 0.6121532693347048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 103}], {
             RGBColor[
             0.9261326652649529, 0.7329765215094193, 0.5287146017248969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 108}], {
             RGBColor[
             0.8846035797290293, 0.9091596462519311, 0.913892802031036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 110}], {
             RGBColor[
             0.7965007991763076, 0.8397612062456058, 0.9055025365037817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 131}], {
             RGBColor[
             0.9436166175198961, 0.8123670652183208, 0.5433036400573084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 143}], {
             RGBColor[
             0.9043865074094275, 0.5750833542293711, 0.5082529502781284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[
             0.9872510560263222, 0.9889959982810382, 0.8609465250606165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 162}], {
             RGBColor[
             0.9854379176982261, 0.9880317806397674, 0.8813919321035765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 180}], {
             RGBColor[
             0.8560213723624259, 0.8868310086243191, 0.9110439947166469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 94}], {
             RGBColor[
             0.5651610277683712, 0.6558369100747177, 0.9599061248871635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 102}], {
             RGBColor[
             0.5430147651889159, 0.6366549305319157, 0.9584949846187718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[
             0.8062483508925926, 0.7076340176229743, 0.6052352623718941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 122}], {
             RGBColor[
             0.8525664665525501, 0.8811976138560375, 0.7223536497554326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 136}], {
             RGBColor[
             0.8101006391447247, 0.7240376246779792, 0.6083933870270145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 142}], {
             RGBColor[
             0.6765418260566909, 0.7472163657056936, 0.968410420193581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 153}], {
             RGBColor[
             0.6490823398625842, 0.7249235177775619, 0.9662487088529688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 167}], {
             RGBColor[
             0.8137351892886164, 0.8551855895073546, 0.9818647874444291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 188}], {
             RGBColor[
             0.688424300235651, 0.7565215626533395, 0.9695793586227837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 113}], {
             RGBColor[
             0.8771471647792357, 0.528095234856292, 0.21892914685667453`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 118}], {
             RGBColor[
             0.8836498800355815, 0.6748620936624041, 0.59546480538561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 122}], {
             RGBColor[
             0.9234652804391932, 0.7016588310893552, 0.3360475342402131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 136}], {
             RGBColor[
             0.8809994530313677, 0.5444988419112969, 0.222087271511795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 138}], {
             RGBColor[
             0.8833839545319762, 0.5539525957731882, 0.22400589739062848`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 144}], {
             RGBColor[
             0.8552540643843429, 0.4257125281092684, 0.20054466049597394`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 149}], {
             RGBColor[
             0.5437801205941402, 0.38941935202558264`, 0.567974527017709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 159}], {
             RGBColor[
             0.8383183472366464, 0.29553718483349917`, 0.18432699862918317`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 170}], {
             RGBColor[
             0.5181787984934242, 0.3625107392801563, 0.5665165695978354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 192}], {
             RGBColor[
             0.8356556165643594, 0.2750702700702792, 0.18177716473027677`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 197}], {
             RGBColor[
             0.8714546134192276, 0.6651379190942172, 0.5943016099688991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 141}], {
             RGBColor[
             0.37364371183420664`, 0.49805313613695035`, 0.9450292248112824]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 177}], {
             RGBColor[
             0.3407778041727428, 0.4681866139645882, 0.9429862890205556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 198}], {
             RGBColor[
             0.542054826289809, 0.636504451768819, 0.9581455985091416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 95}], {
             RGBColor[
             0.9087217160297558, 0.9082261327367556, 0.679871771253554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 136}], {
             RGBColor[
             0.8729121465452325, 0.773250594157032, 0.6146156000869095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 97}], {
             RGBColor[
             0.2548383832137916, 0.38518167681737986`, 0.9378240409731977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 155}], {
             RGBColor[
             0.23916918979888965`, 0.36871236105407446`, 0.9369317035887135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 134}], {
             RGBColor[
             0.2274998629101822, 0.35644715861598486`, 0.9362671526856237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 139}], {
             RGBColor[
             0.2366529007205347, 0.36606758169078113`, 0.9367884046482173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 145}], {
             RGBColor[
             0.21595172710093502`, 0.34430933568636624`, 0.935609503435223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 105}], {
             RGBColor[
             0.3806688871734759, 0.5041379899202462, 0.945476862771782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 111}], {
             RGBColor[
             0.43931163123225564`, 0.554736492921887, 0.9492673764797304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 115}], {
             RGBColor[
             0.34184068469654455`, 0.4665135495155001, 0.9431489820897013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 116}], {
             RGBColor[
             0.4038551160855868, 0.5242207360301667, 0.9469542687752844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 126}], {
             RGBColor[
             0.3626762195061153, 0.4884130176495661, 0.9443355349736948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 142}], {
             RGBColor[
             0.5295082484696294, 0.6279621701064884, 0.9563679845897519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 153}], {
             RGBColor[
             0.5020487622755229, 0.6056693221783567, 0.9542062732491396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 160}], {
             RGBColor[
             0.39241961435313644`, 0.5143158791945474, 0.9462256087169099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 167}], {
             RGBColor[
             0.666701611701555, 0.7359313939081493, 0.9698223518406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 174}], {
             RGBColor[
             0.39976902935609954`, 0.5206815730777754, 0.9466939069420661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 188}], {
             RGBColor[
             0.5413907226485897, 0.6372673670541342, 0.9575369230189545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 103}], {
             RGBColor[
             0.9219582849086154, 0.7097965364380157, 0.2919118882865176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 129}], {
             RGBColor[
             0.9849427513832404, 0.9608705061848779, 0.39600586175704294`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 131}], {
             RGBColor[
             0.9394422371635587, 0.7891870801469172, 0.306500926618929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 143}], {
             RGBColor[
             0.9002121270530901, 0.5519033691579674, 0.2714502368397491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 154}], {
             RGBColor[
             0.9830766756699849, 0.9658160132096346, 0.6241438116222372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 105}], {
             RGBColor[
             0.32470350781154744`, 0.4554278902256328, 0.9419194284550477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 111}], {
             RGBColor[
             0.3833462518703272, 0.5060263932272735, 0.9457099421629962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 116}], {
             RGBColor[
             0.3478897367236583, 0.4755106363355533, 0.9433968344585502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 126}], {
             RGBColor[
             0.3067108401441868, 0.4397029179549527, 0.9407781006569607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.43194074873512733`, 0.5454775949392545, 0.9495354789637005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 174}], {
             RGBColor[
             0.3438036499941711, 0.471971473383162, 0.943136472625332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 182}], {
             RGBColor[
             0.2856601600419676, 0.4175773184773137, 0.9395792955668297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 191}], {
             RGBColor[
             0.29321373700723585`, 0.4255166067922517, 0.9400094606004861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 102}], {
             RGBColor[
             0.3273981891467483, 0.4554287175679108, 0.9421765599569466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 112}], {
             RGBColor[
             0.2912053726836331, 0.4234056885504923, 0.9398950872233656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 140}], {
             RGBColor[
             0.29323255505263285`, 0.42553638575109687`, 0.9400105322603325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 155}], {
             RGBColor[
             0.2652922598561954, 0.3961693639826077, 0.9384193737828581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 99}], {
             RGBColor[
             0.7687919437411839, 0.8183727141912807, 0.944294118700548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 117}], {
             RGBColor[
             0.8762433687105626, 0.9035134810174441, 0.9541841801385145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 120}], {
             RGBColor[
             0.9651286166376958, 0.922790787247423, 0.6081584957443529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 121}], {
             RGBColor[
             0.7580819454747305, 0.8096778551186503, 0.9434509884049964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 146}], {
             RGBColor[
             0.8847914583012635, 0.9101913135735867, 0.9550361738224766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 156}], {
             RGBColor[
             0.9471660663080045, 0.9597340431975859, 0.961036759682581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.9239792736477469, 0.9412455241190165, 0.9588251826995514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 178}], {
             RGBColor[
             0.957960137429429, 0.968167319845601, 0.9560467009664877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 179}], {
             RGBColor[
             0.8907110607570355, 0.9148157520026807, 0.9556261844734377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 183}], {
             RGBColor[
             0.916699432634126, 0.7182581461246227, 0.5672898177785806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 196}], {
             RGBColor[
             0.7343309142909232, 0.7903956980318739, 0.9415812202273133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 107}], {
             RGBColor[
             0.615663269511703, 0.6984811954684678, 0.963146911483036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 109}], {
             RGBColor[
             0.45081925257627997`, 0.561890841684138, 0.9507778651594582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 146}], {
             RGBColor[
             0.6800950161218604, 0.7488157656197341, 0.9695688658362309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 147}], {
             RGBColor[
             0.5223956840025993, 0.6231433757875112, 0.9555440483245787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 156}], {
             RGBColor[
             0.7424696241286013, 0.7983584952437333, 0.9755694516963352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 178}], {
             RGBColor[
             0.7532636952500258, 0.8067917718917483, 0.970579392980242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 179}], {
             RGBColor[
             0.6860146185776324, 0.753440204048828, 0.970158876487192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 194}], {
             RGBColor[
             0.45631234328201786`, 0.5666486807626816, 0.9511278800418784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 104}], {
             RGBColor[
             0.21637454520909913`, 0.34475374432626316`, 0.9356335823009796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 123}], {
             RGBColor[
             0.23212285998297438`, 0.3613062216544334, 0.9365304255298079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 130}], {
             RGBColor[
             0.2255191848288738, 0.3543653403702861, 0.9361543559990437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 135}], {
             RGBColor[
             0.2235466331661063, 0.3522920635057185, 0.9360420220999779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 148}], {
             RGBColor[
             0.20930368592266696`, 0.3373218228978505, 0.9352309073250162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 163}], {
             RGBColor[
             0.22341821875914586`, 0.35215709182205945`, 0.9360347090894736]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 165}], {
             RGBColor[
             0.21635860172261037`, 0.34473698671108804`, 0.9356326743430103]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 123}], {
             RGBColor[
             0.2511378900976988, 0.38129222392755147`, 0.9376133033646252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 124}], {
             RGBColor[
             0.2714494089102611, 0.40264091802422836`, 0.9387700143128014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 127}], {
             RGBColor[
             0.28671598940138643`, 0.417499764656998, 0.9396828962615742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 135}], {
             RGBColor[
             0.2425616632808307, 0.3722780657788366, 0.9371248999347952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 137}], {
             RGBColor[
             0.25101571036429215`, 0.3811638052810985, 0.9376063454095565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 161}], {
             RGBColor[
             0.28025165259241314`, 0.41189263422865363`, 0.9392712890687474]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 165}], {
             RGBColor[
             0.23537363183733478`, 0.36472298898420613`, 0.9367155521778278]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 175}], {
             RGBColor[
             0.2861211170833608, 0.41698451615427623`, 0.9396449915234946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 176}], {
             RGBColor[
             0.27302063754770944`, 0.4042923789438361, 0.9388594934592795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 187}], {
             RGBColor[
             0.2673357347336053, 0.3983171856425559, 0.9385357466540765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 199}], {
             RGBColor[
             0.262066422777004, 0.3927788046824936, 0.9382356671333965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 106}], {
             RGBColor[
             0.32444342089519307`, 0.4523230687923987, 0.9420082902762085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 112}], {
             RGBColor[
             0.337642108559284, 0.46619572637249007`, 0.9427599360129698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 140}], {
             RGBColor[
             0.3396692909282838, 0.4683264235730946, 0.9428753810499368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 108}], {
             RGBColor[
             0.822761672378244, 0.6528409767770607, 0.5936514209828487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 129}], {
             RGBColor[
             0.9272752243887925, 0.727731821781411, 0.3125671941472351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 131}], {
             RGBColor[
             0.8817747101691108, 0.5560483957434501, 0.2230622590091212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 133}], {
             RGBColor[
             0.8438593008645356, 0.3288700512541642, 0.189270528206407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 143}], {
             RGBColor[
             0.8425446000586423, 0.3187646847545005, 0.18801156922994122`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 154}], {
             RGBColor[
             0.9254091486755369, 0.7326773288061676, 0.5407051440124293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 162}], {
             RGBColor[
             0.9235960103474408, 0.7317131111648968, 0.5611505510553894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 123}], {
             RGBColor[
             0.23468312728084179`, 0.36399722491481445`, 0.9366762289648454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 130}], {
             RGBColor[
             0.2280794521267412, 0.3570563436306672, 0.9363001594340813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 163}], {
             RGBColor[
             0.22597848605701326`, 0.35484809508244053`, 0.9361805125245111]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 111}], {
             RGBColor[
             0.4018530682244218, 0.5222917683666206, 0.9468805499681779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 116}], {
             RGBColor[
             0.36639655307775293`, 0.49177601147490035`, 0.944567442263732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 126}], {
             RGBColor[
             0.3252176564982815, 0.45596829309429976`, 0.9419487084621424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 142}], {
             RGBColor[
             0.4920496854617956, 0.5955174455512221, 0.9539811580781995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 157}], {
             RGBColor[
             0.4504475650892219, 0.5617429700786016, 0.9507060867688824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 160}], {
             RGBColor[
             0.35496105134530265`, 0.4818711546392811, 0.9438387822053573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 174}], {
             RGBColor[
             0.3623104663482657, 0.48823684852250904`, 0.9443070804305137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 182}], {
             RGBColor[
             0.30416697639606216`, 0.43384269361666083`, 0.9407499033720115]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 112}], {
             RGBColor[
             0.2882506044320779, 0.42030003977498026`, 0.9397268175426274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 140}], {
             RGBColor[
             0.29027778680107763`, 0.4224307369755848, 0.9398422625795944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 189}], {
             RGBColor[
             0.25322164598941777`, 0.3834823834875024, 0.9377319701800181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 111}], {
             RGBColor[
             0.5638634248724134, 0.6564277480338845, 0.9590690379639482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 142}], {
             RGBColor[
             0.6540600421097872, 0.7296534252184859, 0.9661696460739697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[
             0.5739634519525214, 0.664627405018551, 0.9598641490933124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.7940373920785235, 0.8398425244747729, 0.979889552465069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.6124579217372135, 0.6958789497458655, 0.9628945747646525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.7375823865275546, 0.7949242332798678, 0.9744789772559258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 181}], {
             RGBColor[
             0.8257804710137671, 0.8638766258907483, 0.9384122883545408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 185}], {
             RGBColor[
             0.7184021799057017, 0.779940510091907, 0.9725672735090811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 110}], {
             RGBColor[
             0.6931298062895987, 0.7596256615132471, 0.9704393557617335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 131}], {
             RGBColor[
             0.8402456246331873, 0.7322315204859621, 0.6082404593152602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 154}], {
             RGBColor[
             0.8838800631396134, 0.9088604535486795, 0.9258833443185683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 162}], {
             RGBColor[
             0.8820669248115173, 0.9078962359074088, 0.9463287513615282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 180}], {
             RGBColor[
             0.7526503794757171, 0.8066954638919603, 0.9759808139745987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 132}], {
             RGBColor[
             0.2948786821955154, 0.42460409000948357`, 0.9402017631916271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 146}], {
             RGBColor[
             0.5668187671363596, 0.653709441066444, 0.9615199202813867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 150}], {
             RGBColor[
             0.31023488720570846`, 0.44074443511482886`, 0.941076276349488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 151}], {
             RGBColor[
             0.34470972375175946`, 0.47299196992446024`, 0.9431855766759899]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 152}], {
             RGBColor[
             0.3096412804178116, 0.4401205167439052, 0.9410424713210799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 194}], {
             RGBColor[
             0.3430360942965171, 0.47154235620939167`, 0.9430789344870343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 196}], {
             RGBColor[
             0.4163582231260193, 0.5339138255247312, 0.9480649666862233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 127}], {
             RGBColor[
             0.46330733319948464`, 0.5715960026043997, 0.9518806741110254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 162}], {
             RGBColor[
             0.7939641442587955, 0.8384977959010833, 0.9379384858342741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 180}], {
             RGBColor[
             0.6645475989229954, 0.737297023885635, 0.9675905484473445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 116}], {
             RGBColor[
             0.42503929713653266`, 0.5423745144765412, 0.9483579559716804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 126}], {
             RGBColor[
             0.3838604005570612, 0.5065667960959406, 0.9457392221700909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 142}], {
             RGBColor[
             0.5506924295205754, 0.6461159485528629, 0.957771671786148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 157}], {
             RGBColor[
             0.5090903091480017, 0.6123414730802424, 0.9544966004768307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 160}], {
             RGBColor[
             0.41360379540408243`, 0.5324696576409218, 0.9476292959133059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 167}], {
             RGBColor[
             0.687885792752501, 0.7540851723545239, 0.971226039036996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 174}], {
             RGBColor[
             0.4209532104070455, 0.5388353515241499, 0.9480975941384622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 181}], {
             RGBColor[
             0.7224128584245553, 0.7803391492251253, 0.9300143140667192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.6150345673164899, 0.6964030334262838, 0.9641692992212595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 188}], {
             RGBColor[
             0.5625749036995356, 0.6554211455005088, 0.9589406102153506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 140}], {
             RGBColor[
             0.30347647446516857`, 0.4363033945556761, 0.9405939083163557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 122}], {
             RGBColor[
             0.9466202120897103, 0.8137405258050889, 0.35564035163633406`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 136}], {
             RGBColor[
             0.9041543846818847, 0.6565805366270306, 0.24168008890791598`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 138}], {
             RGBColor[
             0.9065388861824932, 0.6660342904889218, 0.24359871478674944`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 144}], {
             RGBColor[
             0.8784089960348599, 0.5377942228250021, 0.22013747789209492`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 159}], {
             RGBColor[
             0.8614732788871635, 0.4076188795492328, 0.20391981602530412`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 167}], {
             RGBColor[
             0.9077889348257765, 0.7877285014564059, 0.6151514893253305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 197}], {
             RGBColor[
             0.8946095450697447, 0.7772196138099509, 0.6138944273650201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 158}], {
             RGBColor[
             0.23522624458781927`, 0.364568075640074, 0.9367071586920077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 160}], {
             RGBColor[
             0.31613284886837134`, 0.44424671423453505`, 0.9415109015232768]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 126}], {
             RGBColor[
             0.34840388541039236`, 0.4760510392042203, 0.9434261144656448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 142}], {
             RGBColor[
             0.5152359143739065, 0.6156001916611427, 0.9554585640817019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 153}], {
             RGBColor[
             0.48777642817979994`, 0.593307343733011, 0.9532968527410897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 157}], {
             RGBColor[
             0.47363379400133276`, 0.5818257161885222, 0.9521834927723848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 160}], {
             RGBColor[
             0.3781472802574135, 0.5019539007492015, 0.9453161882088599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 167}], {
             RGBColor[
             0.652429277605832, 0.7235694154628036, 0.96891293133255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 174}], {
             RGBColor[
             0.38549669526037655`, 0.5083195946324296, 0.9457844864340161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 188}], {
             RGBColor[
             0.5271183885528666, 0.6249053886087885, 0.9566275025109046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 120}], {
             RGBColor[
             0.8678835994276715, 0.8465560061197337, 0.6325812491960736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 121}], {
             RGBColor[
             0.6608369282647062, 0.733443073990961, 0.9678737418567172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 146}], {
             RGBColor[
             0.7875464410912392, 0.8339565324458974, 0.9794589272741974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 151}], {
             RGBColor[
             0.565437397706639, 0.6532390613039136, 0.9611245836688005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 171}], {
             RGBColor[
             0.8267342564377225, 0.8650107429913272, 0.9832479361512722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 173}], {
             RGBColor[
             0.8870698836005233, 0.9096475021441977, 0.8455791000881498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 196}], {
             RGBColor[
             0.6370858970808988, 0.7141609169041846, 0.966003973679034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 119}], {
             RGBColor[
             0.7390929491372125, 0.7956716911845035, 0.9752408612005126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 125}], {
             RGBColor[
             0.5461336776674304, 0.6195695759530597, 0.9625480754195246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 128}], {
             RGBColor[
             0.901444520807011, 0.7626039594239429, 0.6105848646794676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 138}], {
             RGBColor[
             0.9130416014388392, 0.812801149295034, 0.6201343733156849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 144}], {
             RGBColor[
             0.8849117112912057, 0.6845610816311141, 0.5966731364210304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 149}], {
             RGBColor[
             0.5734377675010032, 0.6482679055474284, 0.9641030029427655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 159}], {
             RGBColor[
             0.8679759941435095, 0.5543857383553449, 0.5804554745542396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 170}], {
             RGBColor[
             0.5478364454002871, 0.6213592928020021, 0.9626450455228917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 190}], {
             RGBColor[
             0.5465072945042451, 0.6199622709372278, 0.9625693523456647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 192}], {
             RGBColor[
             0.8653132634712222, 0.5339188235921248, 0.5779056406553331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.5461172634712222, 0.6195523235921249, 0.9625471406553332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 197}], {
             RGBColor[
             0.9011122603260905, 0.9239864726160629, 0.9904300858939554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 125}], {
             RGBColor[
             0.3719190998621983, 0.4815306199533135, 0.9461956553093709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 128}], {
             RGBColor[
             0.727229943001779, 0.6245650034241965, 0.5942324445693138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 144}], {
             RGBColor[
             0.7106971334859737, 0.5465221256313679, 0.5803207163108766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 149}], {
             RGBColor[
             0.3992231896957711, 0.5102289495476822, 0.9477505828326117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 183}], {
             RGBColor[
             0.7123944253398227, 0.5572003826444346, 0.5818533249803631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 190}], {
             RGBColor[
             0.3722927166990131, 0.48192331493748153`, 0.946216932235511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 192}], {
             RGBColor[
             0.6910986856659902, 0.39587986759237864`, 0.5615532205451794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 195}], {
             RGBColor[
             0.37190268566599016`, 0.4815133675923786, 0.9461947205451795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 128}], {
             RGBColor[
             0.9231751810131911, 0.7286652920066743, 0.2580660064250903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 168}], {
             RGBColor[
             0.9476806026150666, 0.909778086957847, 0.6376934323137864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 171}], {
             RGBColor[
             0.9156195043648556, 0.8842880492213061, 0.6372222517571104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 172}], {
             RGBColor[
             0.9753727800277856, 0.9276792174007213, 0.4361680487899127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 173}], {
             RGBColor[
             0.9759551315276564, 0.9289248083741766, 0.49955341569398815`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 183}], {
             RGBColor[
             0.9083396633512348, 0.6613006712269123, 0.24568688683613962`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 151}], {
             RGBColor[
             0.4472759744708069, 0.5594034354051198, 0.9503913919352824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 171}], {
             RGBColor[
             0.7085728332018904, 0.7711751170925334, 0.9725147444177542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 196}], {
             RGBColor[
             0.5189244738450667, 0.6203252910053908, 0.955270781945516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 136}], {
             RGBColor[
             0.9504725003418423, 0.8301441328600938, 0.35879847629145456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 138}], {
             RGBColor[
             0.9528570018424507, 0.8395978867219851, 0.360717102170288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 142}], {
             RGBColor[
             0.8169136872538085, 0.8533228738878083, 0.7188155094580211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 144}], {
             RGBColor[
             0.9247271116948175, 0.7113578190580653, 0.33725586527563345`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 153}], {
             RGBColor[
             0.7894542010597019, 0.8310300259596766, 0.7166537981174088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.907791394547121, 0.5811824757822961, 0.3210382034088427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 167}], {
             RGBColor[
             0.9541070504857341, 0.9612920976894692, 0.7322698767088691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 181}], {
             RGBColor[
             0.9886341161577883, 0.9875460745600706, 0.6910581517385923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 188}], {
             RGBColor[
             0.8287961614327686, 0.8626280708354541, 0.7199844478872237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 192}], {
             RGBColor[
             0.9051286638748339, 0.560715561019076, 0.3184883695099363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 127}], {
             RGBColor[
             0.2860095413584047, 0.4167572429724312, 0.9396426650906227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 130}], {
             RGBColor[
             0.24382776690061642`, 0.3736088209588374, 0.9371970026629095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 135}], {
             RGBColor[
             0.24185521523784892`, 0.3715355440942698, 0.9370846687638437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 163}], {
             RGBColor[
             0.2417268008308885, 0.37140057241061075`, 0.9370773557533394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 165}], {
             RGBColor[
             0.23466718379435303`, 0.36398046729963934`, 0.9366753210068761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 177}], {
             RGBColor[
             0.27201910823742403`, 0.40323970813810023`, 0.9388024578466887]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 187}], {
             RGBColor[
             0.26662928669062347`, 0.3975746639579891, 0.9384955154831248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 127}], {
             RGBColor[
             0.30632106017096694`, 0.43810593706910805`, 0.9407993760387987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 135}], {
             RGBColor[
             0.26216673405041124`, 0.39288423819094664`, 0.9382413797120197]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.27062078113387267`, 0.4017699776932086, 0.938722825186781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 161}], {
             RGBColor[
             0.29985672336199365`, 0.43249880664076373`, 0.9403877688459719]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 175}], {
             RGBColor[
             0.3057261878529413, 0.4375906885663863, 0.9407614713007191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 176}], {
             RGBColor[
             0.29262570831728996`, 0.4248985513559462, 0.9399759732365041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 187}], {
             RGBColor[
             0.2869408055031858, 0.4189233580546661, 0.939652226431301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 199}], {
             RGBColor[
             0.2816714935465845, 0.4133849770946037, 0.939352146910621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 128}], {
             RGBColor[
             0.5342706715319968, 0.44846288819275276`, 0.5815396587883258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.206263918225989, 0.33412683431623835`, 0.9350577970516237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[
             0.18066259612527297`, 0.307218221570812, 0.93359983963175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 190}], {
             RGBColor[
             0.179333445229231, 0.3058211997060377, 0.933524146454523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 195}], {
             RGBColor[
             0.17894341419620807`, 0.3054112523609348, 0.9335019347641915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 142}], {
             RGBColor[
             0.47405701779443504`, 0.579792473280542, 0.9528398302801124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 157}], {
             RGBColor[
             0.43245489742186133`, 0.5460179978079216, 0.9495647589707952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 160}], {
             RGBColor[
             0.336968383677942, 0.466146182368601, 0.9426974544072704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 174}], {
             RGBColor[
             0.3443177986809051, 0.472511876251829, 0.9431657526324266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 182}], {
             RGBColor[
             0.2861743087287016, 0.41811772134598074`, 0.9396085755739244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 191}], {
             RGBColor[
             0.2937278856939699, 0.4260570096609187, 0.9400387406075807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 135}], {
             RGBColor[
             0.2774333145415366, 0.4077430848237163, 0.9391542616607926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 161}], {
             RGBColor[
             0.31512330385311904`, 0.4473576532735334, 0.9413006507947447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 175}], {
             RGBColor[
             0.32099276834406665`, 0.45244953519915593`, 0.9416743532494919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 176}], {
             RGBColor[
             0.3078922888084153, 0.4397573979887158, 0.940888855185277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 177}], {
             RGBColor[
             0.3075972075411117, 0.4394472488675467, 0.9408720507436377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 180}], {
             RGBColor[
             0.5228279063856032, 0.618665804983113, 0.9574221323238906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 187}], {
             RGBColor[
             0.3022073859943112, 0.43378220468743567`, 0.9405651083800737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 183}], {
             RGBColor[
             0.8747459970096212, 0.524132650883874, 0.217197328459318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 190}], {
             RGBColor[
             0.5346442883688116, 0.44885558317692076`, 0.5815609357144658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 192}], {
             RGBColor[
             0.8534502573357887, 0.36281213583181793`, 0.19689722402413434`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 195}], {
             RGBColor[
             0.5342542573357888, 0.44844563583181796`, 0.5815387240241343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 131}], {
             RGBColor[
             0.9447591766437358, 0.8071223654903125, 0.32715623247964654`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 133}], {
             RGBColor[
             0.9068437673391607, 0.5799440210010265, 0.2933645016769323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 143}], {
             RGBColor[
             0.9055290665332671, 0.5698386545013628, 0.2921055427004665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 170}], {
             RGBColor[
             0.5863125273607737, 0.6439068649740138, 0.6751789886764388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 197}], {
             RGBColor[
             0.939588342286577, 0.9465340447880747, 0.7029640290475025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 163}], {
             RGBColor[
             0.23512312567678792`, 0.3644596911264634, 0.9367012862225752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 177}], {
             RGBColor[
             0.26541543308332344`, 0.3962988268539529, 0.9384263883159245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 133}], {
             RGBColor[
             0.8613432531194789, 0.40826059496306566`, 0.20385956653881843`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 143}], {
             RGBColor[
             0.8600285523135855, 0.398155228463402, 0.20260060756235265`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 154}], {
             RGBColor[
             0.9428931009304802, 0.8120678725150692, 0.5552941823448407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 162}], {
             RGBColor[
             0.941079962602384, 0.8111036548737982, 0.5757395893878008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 180}], {
             RGBColor[
             0.811663417266584, 0.70990288285835, 0.6053916520008711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 150}], {
             RGBColor[
             0.2675705658104447, 0.39856400799346436`, 0.938549119936501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 151}], {
             RGBColor[
             0.3020454023564957, 0.43081154280309575`, 0.9406584202630028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 162}], {
             RGBColor[
             0.903164553297809, 0.5839253103845123, 0.5419478585850865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 139}], {
             RGBColor[
             0.2400051701500614, 0.36959102940737165`, 0.9369793114329906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 145}], {
             RGBColor[
             0.21930399653046173`, 0.34783278340295676`, 0.9358004102199964]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 191}], {
             RGBColor[
             0.25554145744836393`, 0.3859206524153965, 0.9378640800107516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 148}], {
             RGBColor[
             0.2190360411775415, 0.34755114533768694`, 0.935785150559052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 163}], {
             RGBColor[
             0.2331505740140204, 0.36238641426189583`, 0.9365889523235094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 165}], {
             RGBColor[
             0.22609095697748494`, 0.3549663091509244, 0.9361869175770461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 176}], {
             RGBColor[
             0.26373796268785954`, 0.3945356991105544, 0.938330858858498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 187}], {
             RGBColor[
             0.2580530598737554, 0.38856050580927426`, 0.9380071120532948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 143}], {
             RGBColor[
             0.8644025575685669, 0.416927830578244, 0.20619406567310455`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 159}], {
             RGBColor[
             0.8653255671392956, 0.4240224866042378, 0.2070779406804246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 197}], {
             RGBColor[
             0.8984618333218767, 0.7936232208649558, 0.6170525520201404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 161}], {
             RGBColor[
             0.2794230248160247, 0.4110216938976339, 0.939224099942727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 175}], {
             RGBColor[
             0.2852924893069724, 0.4161135758232565, 0.9395978023974743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 176}], {
             RGBColor[
             0.27219200977132096`, 0.4034214386128163, 0.9388123043332592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 186}], {
             RGBColor[
             0.2661087370017966, 0.3970275332302755, 0.9384658709484304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 187}], {
             RGBColor[
             0.2665071069572168, 0.39744624531153616`, 0.938488557528056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 199}], {
             RGBColor[
             0.26123779500061556`, 0.39190786435147384`, 0.9381884780073761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 142}], {
             RGBColor[
             0.7768323613465915, 0.7056166385716411, 0.6067738726084364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 144}], {
             RGBColor[
             0.8846457857876004, 0.5636515837418983, 0.22521422842604885`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 156}], {
             RGBColor[
             0.9168097113153278, 0.8158057378279282, 0.6204937789995357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 159}], {
             RGBColor[
             0.8677100686399041, 0.4334762404661291, 0.20899656655925808`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 167}], {
             RGBColor[
             0.914025724578517, 0.8135858623733021, 0.6202282398592844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 181}], {
             RGBColor[
             0.9485527902505714, 0.8398398392439036, 0.5790165148890076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 185}], {
             RGBColor[
             0.8411744991425061, 0.7559037234450623, 0.613171500043548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 192}], {
             RGBColor[
             0.8650473379676169, 0.41300932570290905`, 0.20644673266035168`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 145}], {
             RGBColor[
             0.2284570343408142, 0.357453206477753, 0.9363216621825899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 152}], {
             RGBColor[
             0.26544888260262894`, 0.3963339844195651, 0.9384282932165648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 182}], {
             RGBColor[
             0.2571409182934481, 0.38760178717525484`, 0.9379551669396888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 191}], {
             RGBColor[
             0.2646944952587164, 0.3955410754901928, 0.9383853319733451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 198}], {
             RGBColor[
             0.5277497041986612, 0.6241140740098087, 0.9572340887790165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 153}], {
             RGBColor[
             0.6134295605638427, 0.6970487778093326, 0.9627105685555573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 157}], {
             RGBColor[
             0.5992869263853755, 0.6855671502648439, 0.9615972085868523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 160}], {
             RGBColor[
             0.5038004126414563, 0.6056953348255233, 0.9547299040233275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 167}], {
             RGBColor[
             0.7780824099898748, 0.8273108495391253, 0.9783266471470176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 174}], {
             RGBColor[
             0.5111498276444193, 0.6120610287087513, 0.9551982022484837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 181}], {
             RGBColor[
             0.8126094756619291, 0.8535648264097266, 0.9371149221767408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 185}], {
             RGBColor[
             0.7052311845538637, 0.7696287106108853, 0.971269907331281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.6527715209369094, 0.7286468226851102, 0.9660412183253722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 154}], {
             RGBColor[
             0.9036629908200117, 0.5747841615261196, 0.5202434925656607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 159}], {
             RGBColor[
             0.8217214517738456, 0.16796617350044618`, 0.16843379279049273`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 197}], {
             RGBColor[
             0.8548577179564267, 0.5375669077611642, 0.5784084041302087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 149}], {
             RGBColor[
             0.5450419518497644, 0.3991183399942927, 0.5691828580531295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 159}], {
             RGBColor[
             0.8395801784922707, 0.30523617280220927`, 0.18553532966460354`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 170}], {
             RGBColor[
             0.5194406297490485, 0.3722097272488664, 0.5677249006332556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 181}], {
             RGBColor[
             0.920422900102938, 0.7115997715799838, 0.5555552779943531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 190}], {
             RGBColor[
             0.5181114788530065, 0.37081270538409206`, 0.5676492074560286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 192}], {
             RGBColor[
             0.8369174478199836, 0.2847692580389892, 0.18298549576569717`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 197}], {
             RGBColor[
             0.8727164446748519, 0.6748369070629272, 0.5955099410043194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 147}], {
             RGBColor[
             0.6383951985626789, 0.7149619751698173, 0.9662861034465073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 156}], {
             RGBColor[
             0.8584691386886809, 0.8901770946260392, 0.9863115068182637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 171}], {
             RGBColor[
             0.8352823460284233, 0.8716885755474699, 0.9840999298352342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 178}], {
             RGBColor[
             0.8692632098101054, 0.8986103712740543, 0.9813214481021706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 179}], {
             RGBColor[
             0.802014133137712, 0.8452588034311341, 0.9809009316091206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 183}], {
             RGBColor[
             0.8280025050148025, 0.648701197553076, 0.5925645649142633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 194}], {
             RGBColor[
             0.5723118578420975, 0.6584672801449877, 0.9618699351638069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 196}], {
             RGBColor[
             0.6456339866715997, 0.7208387494603272, 0.9668559673629961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 152}], {
             RGBColor[
             0.3812177118441309, 0.5013730508472783, 0.9458086544862003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 156}], {
             RGBColor[
             0.7007698065694198, 0.7645047047938165, 0.9722866893066117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 178}], {
             RGBColor[
             0.7115638776908443, 0.7729379814418316, 0.9672966305905184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 179}], {
             RGBColor[
             0.6443148010184508, 0.7195864135989113, 0.9668761140974684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 185}], {
             RGBColor[
             0.625134594396598, 0.7046026904109504, 0.9649644103506239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 194}], {
             RGBColor[
             0.41461252572283636`, 0.5327948903127648, 0.9478451176521548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 165}], {
             RGBColor[
             0.2118480097340456, 0.33999606854305653`, 0.9353758028020844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 159}], {
             RGBColor[
             0.5281062347020681, 0.2689429967185235, 0.5529651961863387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 170}], {
             RGBColor[
             0.2079666859588458, 0.3359165511651807, 0.9351547671549908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 190}], {
             RGBColor[
             0.2066375350628038, 0.33451952930040635`, 0.9350790739777637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 192}], {
             RGBColor[
             0.5254435040297809, 0.2484760819553035, 0.5504153622874323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 195}], {
             RGBColor[
             0.2062475040297809, 0.3341095819553035, 0.9350568622874322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.5612425008846491, 0.6385437309792414, 0.9629398075260546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 151}], {
             RGBColor[
             0.3174016073666887, 0.4469518879084411, 0.9415329334208639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 152}], {
             RGBColor[
             0.2823331640327409, 0.4140804347278859, 0.9393898280659538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 194}], {
             RGBColor[
             0.31572797791144636`, 0.44550227419337246`, 0.9414262912319082]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 171}], {
             RGBColor[
             0.6131733026438233, 0.690971104405486, 0.9657655862298374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 196}], {
             RGBColor[
             0.4235249432869995, 0.5401212783183434, 0.9485216237575993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 194}], {
             RGBColor[
             0.3151343711235495, 0.4448783558224487, 0.9413924862035001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 160}], {
             RGBColor[
             0.4763409264473496, 0.5834024868973917, 0.9525681926827152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 167}], {
             RGBColor[
             0.7506229237957682, 0.8050180016109936, 0.9761649358064053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 174}], {
             RGBColor[
             0.4836903414503127, 0.5897681807806197, 0.9530364909078715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 188}], {
             RGBColor[
             0.6253120347428027, 0.7063539747569785, 0.9638795069847599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 157}], {
             RGBColor[
             0.7392642763541118, 0.795756249521131, 0.9753171149779516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 178}], {
             RGBColor[
             0.9316378178168464, 0.9481531008980535, 0.987322033962275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.864388741144453, 0.8948015330551333, 0.986901517469225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 181}], {
             RGBColor[
             0.9525868256306654, 0.9637539256660137, 0.9508348285678401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 183}], {
             RGBColor[
             0.8903771130215434, 0.6982439271770752, 0.5985651507743678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 185}], {
             RGBColor[
             0.8452085345226001, 0.8798178098671724, 0.9849898137223804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 192}], {
             RGBColor[
             0.869081373347711, 0.5369234121250193, 0.5782650463391841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 174}], {
             RGBColor[
             0.4695477072718456, 0.5782865532361309, 0.9519231309391665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 181}], {
             RGBColor[
             0.7710073552893554, 0.8197903509371063, 0.9338398508674235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 185}], {
             RGBColor[
             0.6636290641812901, 0.7358542351382649, 0.9679948360219639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 164}], {
             RGBColor[
             0.27399405489207074`, 0.4053155022909841, 0.9389149281369991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 166}], {
             RGBColor[
             0.3220947514992546, 0.4482744245110126, 0.9419323901733808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 170}], {
             RGBColor[
             0.5025049126013521, 0.2420343839730972, 0.5515072387664649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 197}], {
             RGBColor[
             0.8557807275271554, 0.5446615637871581, 0.5792922791375287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 167}], {
             RGBColor[
             0.6409937758733817, 0.7136645586271843, 0.9681842712741754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 174}], {
             RGBColor[
             0.37406119352792633`, 0.4984147377968103, 0.9450558263756417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 188}], {
             RGBColor[
             0.5156828868204164, 0.6150005317731692, 0.9558988424525301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 175}], {
             RGBColor[
             0.31452843153509336`, 0.4468424047708116, 0.941262746056665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 176}], {
             RGBColor[
             0.301427951999442, 0.43415026756037145`, 0.9404772479924501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 187}], {
             RGBColor[
             0.2957430491853379, 0.4281750742590913, 0.9401535011872468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 193}], {
             RGBColor[
             0.31267272742048674`, 0.4452350871371401, 0.9411445022314171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 199}], {
             RGBColor[
             0.2904737372287366, 0.422636693299029, 0.9398534216665669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 180}], {
             RGBColor[
             0.853484717444914, 0.8855675982797966, 0.9434799440471393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 177}], {
             RGBColor[
             0.2633144670135955, 0.39409057830572625`, 0.9383067414063544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 166}], {
             RGBColor[
             0.3428237586125573, 0.4700619252820549, 0.9431128764626655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 184}], {
             RGBColor[
             0.33292802569279517`, 0.46149073880095526`, 0.9424823291114712]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 187}], {
             RGBColor[
             0.2508650284302595, 0.38100542901464385`, 0.9375977642963274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 184}], {
             RGBColor[
             0.3810287222999791, 0.5044496610209838, 0.9454997911478531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 181}], {
             RGBColor[
             0.9498028388938546, 0.9615340502113876, 0.9505692894275887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 188}], {
             RGBColor[
             0.7899648841688349, 0.8366160464867711, 0.9794955855762202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 172}], {
             RGBColor[
             0.9662845352880476, 0.9716239920088556, 0.7873059163017873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 173}], {
             RGBColor[
             0.9668668867879184, 0.9728695829823109, 0.8506912832058626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 184}], {
             RGBColor[
             0.6548626736277727, 0.7248006680529328, 0.9668502718111599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 198}], {
             RGBColor[
             0.8173765882647961, 0.8581441256038294, 0.9795908811512684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 200}], {
             RGBColor[
             0.2545855584826314, 0.3849159419949167, 0.9378096429787789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 190}], {
             RGBColor[
             0.1810362129620878, 0.3076109165549801, 0.93362111655789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 195}], {
             RGBColor[
             0.1806461819290649, 0.30720096920987716`, 0.9335989048675586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 197}], {
             RGBColor[
             0.5356411787839332, 0.6116351182338152, 0.9614818501061808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 173}], {
             RGBColor[
             0.9348057885377076, 0.9473795452457701, 0.8502201026491867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 178}], {
             RGBColor[
             0.9084510251565888, 0.9296645818194842, 0.9851104569792455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 183}], {
             RGBColor[
             0.8671903203612858, 0.6797554080985058, 0.5963535737913382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 196}], {
             RGBColor[
             0.6848218020180831, 0.7518929600057571, 0.9706449762400708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 173}], {
             RGBColor[
             0.9945590642006376, 0.9907707134251852, 0.6491658996819889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 198}], {
             RGBColor[
             0.8450687656775151, 0.8760452560467036, 0.7780654976273946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 188}], {
             RGBColor[
             0.5230323018233795, 0.6213662256563972, 0.9563671406776864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 176}], {
             RGBColor[
             0.30729741649038966`, 0.43924214948599405`, 0.9408509504471974]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 187}], {
             RGBColor[
             0.3016125136762855, 0.4332669561847139, 0.940527203641994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 199}], {
             RGBColor[
             0.2963432017196842, 0.4277285752246516, 0.9402271241213142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 187}], {
             RGBColor[
             0.2885120341406341, 0.42057481897427373`, 0.9397417055777791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 199}], {
             RGBColor[
             0.28324272218403285`, 0.4150364380142114, 0.9394416260570992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 179}], {
             RGBColor[
             0.8751828122658775, 0.9032348097031484, 0.9819114587531318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 183}], {
             RGBColor[
             0.9011711841429679, 0.7066772038250902, 0.5935750920582745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 183}], {
             RGBColor[
             0.8339221074705745, 0.65332563598217, 0.5931545755652246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 185}], {
             RGBColor[
             0.7887535289716312, 0.8348995186722672, 0.9795792385132371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 194}], {
             RGBColor[
             0.5782314602978695, 0.6630917185740817, 0.9624599458147682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 185}], {
             RGBColor[
             0.8769516134578437, 0.9038519112831478, 0.9435125496118522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 188}], {
             RGBColor[
             0.8244919498408892, 0.8628700233573725, 0.9382838606059434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 192}], {
             RGBColor[
             0.9008244522829545, 0.5609575135409945, 0.536787782228656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 191}], {
             RGBColor[
             0.2726772055917506, 0.4039314101832797, 0.9388399355174497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 192}], {
             RGBColor[
             0.8386147396738325, 0.29544751505205596`, 0.18451810443518368`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 193}], {
             RGBColor[
             0.29935843960625863`, 0.43124092646978174`, 0.9403862732371204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 199}], {
             RGBColor[
             0.2771594494145085, 0.4086425326316706, 0.9390951926722704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 199}], {
             RGBColor[
             0.27755781936992874`, 0.40906124471293126`, 0.9391178792518959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 192}], {
             RGBColor[
             0.4985130310330229, 0.22017044734510285`, 0.5488817116903315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 195}], {
             RGBColor[
             0.1793170310330229, 0.30580394734510286`, 0.9335232116903315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 199}], {
             RGBColor[
             0.2944874976050776, 0.4261212575909801, 0.9401088802960662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 197}], {
             RGBColor[
             0.5339219968548683, 0.6098281490239381, 0.9613839452386224]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.04749427504982855], {
             RGBColor[
             0.9583125875736904, 0.8710407105954553, 0.2925527040414048]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.04749427504982855], {
             RGBColor[
             0.377120805174838, 0.5010648196248124, 0.9452507821242745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.04749427504982855], {
             RGBColor[
             0.26366336471100654`, 0.39445729190709694`, 0.938326610614074]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.04749427504982855], {
             RGBColor[
             0.8048857220793089, 0.8475021105371937, 0.9811871447582946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.04749427504982855], {
             RGBColor[
             0.2822070658609612, 0.41394789755425965`, 0.9393826469616164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.04749427504982855], {
             RGBColor[
             0.3400518121902417, 0.46895752104331584`, 0.9428887786701194]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.04749427504982855], {
             RGBColor[
             0.350460125859892, 0.477972679206911, 0.9435519872134391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.04749427504982855], {
             RGBColor[
             0.44819737568646545`, 0.5626277725896778, 0.9497797183467319]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.04749427504982855], {
             RGBColor[
             0.2605668322464433, 0.39120263995534316`, 0.9381502676711264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.04749427504982855], {
             RGBColor[
             0.28931600419628395`, 0.4214198424774074, 0.9397874904830813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.04749427504982855], {
             RGBColor[
             0.24586228151751777`, 0.37574722481687783`, 0.9373128652605475]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.04749427504982855], {
             RGBColor[
             0.5839626349742006, 0.6731262001457912, 0.9603908242322355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.04749427504982855], {
             RGBColor[
             0.3779993100162068, 0.5018257363634689, 0.9453067596759351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.04749427504982855], {
             RGBColor[
             0.4167727741971154, 0.535409362225998, 0.9477773705275145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.04749427504982855], {
             RGBColor[
             0.32511075702074876`, 0.45601633001476893`, 0.9419367478465757]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.04749427504982855], {
             RGBColor[
             0.3229612837478847, 0.4541545643014821, 0.9417997853103334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.04749427504982855], {
             RGBColor[
             0.2388383031545141, 0.3683645782114108, 0.9369128600838192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.04749427504982855], {
             RGBColor[
             0.3183704566888478, 0.45017822064462143`, 0.9415072618696405]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.04749427504982855], {
             RGBColor[
             0.26440158051900675`, 0.3952332035268908, 0.9383686509122472]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.04749427504982855], {
             RGBColor[
             0.22540124214842158`, 0.354241375135133, 0.9361476393378726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.04749427504982855], {
             RGBColor[
             0.31620160663402885`, 0.4482996717367106, 0.9413690646619862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.04749427504982855], {
             RGBColor[
             0.8444218577904707, 0.34245144152557083`, 0.19017172722845446`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.04749427504982855], {
             RGBColor[
             0.9935791491691084, 0.9886747742573517, 0.5425081958346172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.04749427504982855], {
             RGBColor[
             0.17892700283938517`, 0.30539400298437386`, 0.9335010001616988]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.04749427504982855], {
             RGBColor[
             0.9789215033713261, 0.9405594227844256, 0.37261445024803247`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.04749427504982855], {
             RGBColor[
             0.39640287984113043`, 0.5177659835555031, 0.9464794188715415]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.04749427504982855], {
             RGBColor[
             0.2767490295536739, 0.4082111553358114, 0.9390718198683575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.04749427504982855], {
             RGBColor[
             0.29477679578460203`, 0.4271594806709139, 0.9400984744855188]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.04749427504982855], {
             RGBColor[
             0.9936430185668372, 0.9916392390574856, 0.75501516389549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.04749427504982855], {
             RGBColor[
             0.8937471851268821, 0.9181137615718546, 0.9897275984465748]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.04749427504982855], {
             RGBColor[
             0.8505083657915934, 0.8836363007203797, 0.9856034412586252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.04749427504982855], {
             RGBColor[
             0.23515166545220784`, 0.36448968823995603`, 0.9367029115205646]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.04749427504982855], {
             RGBColor[
             0.3230400522816408, 0.4542227896464, 0.941804804371652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.04749427504982855], {
             RGBColor[
             0.2517479206748871, 0.38193340474234894`, 0.9376480437035368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.04749427504982855], {
             RGBColor[
             0.8383733051460716, 0.8739601327590868, 0.9844459883411588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.04749427504982855], {
             RGBColor[
             0.24777983952010385`, 0.3777626998577953, 0.9374220673520219]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.04749427504982855], {
             RGBColor[
             0.19099374879671333`, 0.31807691806140814`, 0.9341881834928177]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.04749427504982855], {
             RGBColor[
             0.9648082727380654, 0.8929521819142981, 0.31778721429778617`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.04749427504982855], {
             RGBColor[
             0.20098973591686892`, 0.3285833343068806, 0.9347574401715728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.04749427504982855], {
             RGBColor[
             0.49158142165721236`, 0.5981269694488269, 0.9531182367163876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.04749427504982855], {
             RGBColor[
             0.5497140953330726, 0.6453216927859953, 0.9576946537351515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.04749427504982855], {
             RGBColor[
             0.5214414667269106, 0.6223686992161088, 0.9554689288452234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.04749427504982855], {
             RGBColor[
             0.8553653759675705, 0.4265681177150025, 0.20065125259378117`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.04749427504982855], {
             RGBColor[
             0.2834240796528994, 0.4152270562127178, 0.9394519540966568]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.04749427504982855], {
             RGBColor[
             0.8843599871114161, 0.5677875345316877, 0.22521947746071738`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.04749427504982855], {
             RGBColor[
             0.5977424503378598, 0.6843132750316175, 0.9614756217747897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.04749427504982855], {
             RGBColor[
             0.4515217278586501, 0.5655071593544256, 0.9499915431275343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.04749427504982855], {
             RGBColor[
             0.3171026989044469, 0.4490801525711323, 0.9414264814646527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.04749427504982855], {
             RGBColor[
             0.8347376037115143, 0.26801402100751526`, 0.1808980745856452]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.04749427504982855], {
             RGBColor[
             0.2422322948146241, 0.37193187863768656`, 0.9371061428879017]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.04749427504982855], {
             RGBColor[
             0.28213996431762406`, 0.4138773695777287, 0.9393788256279912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.04749427504982855], {
             RGBColor[
             0.21246269677098534`, 0.3406421435922893, 0.9354108083194902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.04749427504982855], {
             RGBColor[
             0.21141226994966317`, 0.3395380784021726, 0.9353509880659832]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.04749427504982855], {
             RGBColor[
             0.27280646441116213`, 0.40406726939796367`, 0.938847296615994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.04749427504982855], {
             RGBColor[
             0.35238205413251156`, 0.47963735687773035`, 0.943674450783476]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.04749427504982855], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.04749427504982855], {
             RGBColor[
             0.3605779115447064, 0.4867361966324024, 0.9441966835704689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.04749427504982855], {
             RGBColor[
             0.264153442110629, 0.394972394326802, 0.9383545197969779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.04749427504982855], {
             RGBColor[
             0.44880489881560515`, 0.5631539785891382, 0.949818429183309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.04749427504982855], {
             RGBColor[
             0.253957266336059, 0.38425556711284614`, 0.9377738626705066]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.04749427504982855], {
             RGBColor[
             0.2737970101358498, 0.4051083957588368, 0.9389037067296339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.04749427504982855], {
             RGBColor[
             0.3562346737166085, 0.4829743023231845, 0.943919936296637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.04749427504982855], {
             RGBColor[
             0.35285247495850214`, 0.48004481175316516`, 0.9437044255825313]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.04749427504982855], {
             RGBColor[
             0.6226026285830288, 0.704495887669313, 0.963432706072083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.04749427504982855], {
             RGBColor[
             0.9220936452530043, 0.9407164594322621, 0.992431309118588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.04749427504982855], {
             RGBColor[
             0.6916199917227627, 0.7590180611312259, 0.9698978752847841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.04749427504982855], {
             RGBColor[
             0.8182056947053702, 0.14094252405757224`, 0.16506709985124088`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.04749427504982855], {
             RGBColor[
             0.8556248139763563, 0.8877160176206234, 0.9860914526539951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.04749427504982855], {
             RGBColor[
             0.4015855979045752, 0.522254993451075, 0.9468096570836465]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.04749427504982855], {
             RGBColor[
             0.21367513065222027`, 0.34191648847421524`, 0.9354798546353913]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.04749427504982855], {
             RGBColor[
             0.2902833275082297, 0.42243656061010276`, 0.93984257811467]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.04749427504982855], {
             RGBColor[
             0.24987650973082426`, 0.37996643318583184`, 0.9375414696187768]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.04749427504982855], {
             RGBColor[
             0.2931347355771166, 0.42543357128021636`, 0.9400049615859128]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.04749427504982855], {
             RGBColor[
             0.30278259996188467`, 0.4355740884585403, 0.9405543931898891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.04749427504982855], {
             RGBColor[
             0.28416143346402023`, 0.4160020618191376, 0.9394939453053829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.04749427504982855], {
             RGBColor[
             0.27635030732849636`, 0.40779207299670056`, 0.9390491132274904]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.04749427504982855], {
             RGBColor[
             0.3003940670337382, 0.43306358890932384`, 0.940418369773149]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.04749427504982855], {
             RGBColor[
             0.9279645300339343, 0.9453977435956535, 0.9929912793499938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.04749427504982855], {
             RGBColor[
             0.20396815225836698`, 0.3317138387242981, 0.934927056576049]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.04749427504982855], {
             RGBColor[
             0.6198970672218798, 0.7022993910721819, 0.9632197143709355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.04749427504982855], {
             RGBColor[
             0.5763338163997934, 0.6669327815527272, 0.9597902556887751]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.04749427504982855], {
             RGBColor[
             0.31859842780058983`, 0.45037567776345117`, 0.9415217879872938]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.04749427504982855], {
             RGBColor[
             0.25584834544704116`, 0.3862432111598293, 0.9378815568282761]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.04749427504982855], {
             RGBColor[
             0.2627765683456537, 0.3935252127009741, 0.9382761088729649]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.04749427504982855], {
             RGBColor[
             0.360155081261214, 0.48636996229290924`, 0.9441697411986989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.04749427504982855], {
             RGBColor[
             0.3919595940317969, 0.5139174327134967, 0.9461962966288141]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.04749427504982855], {
             RGBColor[
             0.9879745726157381, 0.9892951909842899, 0.8489559827730842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.04749427504982855], {
             RGBColor[
             0.7121946053554326, 0.7750911056739228, 0.9719485604909927]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.04749427504982855], {
             RGBColor[
             0.8539922331287186, 0.4160135401405583, 0.19933632946055357`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.04749427504982855], {
             RGBColor[
             0.3879488339253545, 0.5104435138959607, 0.9459407345414075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.04749427504982855], {
             RGBColor[
             0.8378176201564483, 0.8735170446320284, 0.9843929866107827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.04749427504982855], {
             RGBColor[
             0.22871531315648586`, 0.35772467388884666`, 0.9363363707790532]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.04749427504982855], {
             RGBColor[
             0.22414759348065547`, 0.35292371089939434`, 0.9360762459008504]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.04749427504982855], {
             RGBColor[
             0.4181274501813097, 0.5365827144755124, 0.9478636892833344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.04749427504982855], {
             RGBColor[
             0.9796258119030633, 0.9429352208414826, 0.3753505558963255]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.04749427504982855], {
             RGBColor[
             0.3061966914574528, 0.4391625150862857, 0.940748820649866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.04749427504982855], {
             RGBColor[
             0.28096145327109734`, 0.41263867974591306`, 0.9393117111673424]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.04749427504982855], {
             RGBColor[
             0.9734883859205871, 0.9797482621451334, 0.9297614266867937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.04749427504982855], {
             RGBColor[
             0.5640955015617808, 0.656997166237428, 0.9588268107143023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.04749427504982855], {
             RGBColor[
             0.21381427791123173`, 0.3420627410658821, 0.9354877788659421]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.04749427504982855], {
             RGBColor[
             0.2518443381406806, 0.38203474561211825`, 0.9376535345355769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.04749427504982855], {
             RGBColor[
             0.37383492502239923`, 0.4982187553899085, 0.9450414087465508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.04749427504982855], {
             RGBColor[
             0.8642907579141675, 0.4766578520345487, 0.20847322067670976`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.04749427504982855], {
             RGBColor[
             0.21893481250696653`, 0.34744474758664423`, 0.9357793857360172]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.04749427504982855], {
             RGBColor[
             0.34321032416564207`, 0.47169326536497985`, 0.9430900362602295]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.04749427504982855], {
             RGBColor[
             0.27505191676798696`, 0.40642738219488894`, 0.9389751718058661]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.04749427504982855], {
             RGBColor[
             0.6672310374616252, 0.7399652246995075, 0.9674670122517698]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.04749427504982855], {
             RGBColor[
             0.7812325868423204, 0.8290241015195725, 0.9788296212889877]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.04749427504982855], {
             RGBColor[
             0.3375430035907792, 0.46678451713084806`, 0.942728919604614]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.04749427504982855], {
             RGBColor[
             0.6050270257368769, 0.6902272215069217, 0.9620490902344793]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.04749427504982855], {
             RGBColor[
             0.4604958122832016, 0.5728902713682614, 0.9506710636761264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.04749427504982855], {
             RGBColor[
             0.30144929209616883`, 0.4341726973550716, 0.9404784632793888]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.04749427504982855], {
             RGBColor[
             0.9003020964297527, 0.6401769295720257, 0.2385219642527955]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.04749427504982855], {
             RGBColor[
             0.21718744139687057`, 0.3456081497602061, 0.935679875536301]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.04749427504982855], {
             RGBColor[
             0.2655539192117794, 0.3964443845554878, 0.9384342748960682]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.04749427504982855], {
             RGBColor[
             0.3895827819898638, 0.5118587575848209, 0.9460448482672345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.04749427504982855], {
             RGBColor[
             0.7789983515005383, 0.8272786998897548, 0.9786069335902352]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.04749427504982855], {
             RGBColor[
             0.9133075269424444, 0.9337106471842498, 0.9915932813106664]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.04749427504982855], {
             RGBColor[
             0.5648783713319804, 0.6576327351847573, 0.9588884410903589]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.04749427504982855], {
             RGBColor[
             0.9567688473548046, 0.8658333123497126, 0.2865555648019119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.04749427504982855], {
             RGBColor[
             0.5426755050288741, 0.6396074480921672, 0.9571405501231992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.04749427504982855], {
             RGBColor[
             0.9929383277496677, 0.9873041220381521, 0.47275873901987264`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.04749427504982855], {
             RGBColor[
             0.250431442054717, 0.3805497022429847, 0.9375730721936737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.04749427504982855], {
             RGBColor[
             0.2910544796798416, 0.42324709043633846`, 0.9398864940900259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.04749427504982855], {
             RGBColor[
             0.17895982839241617`, 0.30542850472186966`, 0.9335028695283829]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.04749427504982855], {
             RGBColor[
             0.30722498883092086`, 0.4402433208236197, 0.9408073806640553]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.04749427504982855], {
             RGBColor[
             0.32158764066209233`, 0.4529647837018777, 0.9417122579875715]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.04749427504982855], {
             RGBColor[
             0.8895815146715775, 0.5914972716636359, 0.22957644804826868`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.04749427504982855], {
             RGBColor[
             0.9902596908634175, 0.9788057915282733, 0.4166611676177604]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.04749427504982855], {
             RGBColor[
             0.23722409174651585`, 0.3666679396746901, 0.9368209331321454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.04749427504982855], {
             RGBColor[
             0.8992586624240541, 0.6354389394523516, 0.23765129734153262`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.04749427504982855], {
             RGBColor[
             0.2522143608002516, 0.3824236628881191, 0.93767460677864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.04749427504982855], {
             RGBColor[
             0.8234278438149039, 0.18108225047377968`, 0.1700678357361042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.04749427504982855], {
             RGBColor[
             0.23085213233970892`, 0.3599706063325754, 0.9364580594703971]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.04749427504982855], {
             RGBColor[
             0.23327898842098083`, 0.3625213859455549, 0.9365962653340136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.04749427504982855], {
             RGBColor[
             0.9080066729340168, 0.6729841436820356, 0.24483821356303642`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.04749427504982855], {
             RGBColor[
             0.2501870825879037, 0.38029286495007875`, 0.9375591562835361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.04749427504982855], {
             RGBColor[
             0.9127756759352338, 0.6918916514058181, 0.2486754653207034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.04749427504982855], {
             RGBColor[
             0.24915820796041388`, 0.3792114524821679, 0.9375005633955842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.04749427504982855], {
             RGBColor[
             0.30550365683416836`, 0.4384340917562807, 0.9407093533533227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.04749427504982855], {
             RGBColor[
             0.3593385897430587, 0.4856627583779401, 0.9441177150811572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.04749427504982855], {
             RGBColor[
             0.6408890467579492, 0.7193416257374643, 0.9648722798961695]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.04749427504982855], {
             RGBColor[
             0.8207984422031169, 0.16087151747445233`, 0.16754991778317269`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.04749427504982855], {
             RGBColor[
             0.8565158956399671, 0.43541151607797846`, 0.2017529915313943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.04749427504982855], {
             RGBColor[
             0.20775586072121455`, 0.33569496047333813`, 0.9351427609695957]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.04749427504982855], {
             RGBColor[
             0.79609453068194, 0.84063436500204, 0.9803109209581594]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.04749427504982855], {
             RGBColor[
             0.4806958664434177, 0.5892895853375945, 0.9522612859348552]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.04749427504982855], {
             RGBColor[
             0.20479309393410217`, 0.332580904729819, 0.9349740357840903]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.04749427504982855], {
             RGBColor[
             0.2335680080595618, 0.362825163910607, 0.9366127245748646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.04749427504982855], {
             RGBColor[
             0.2829267708206377, 0.41470435309880965`, 0.9394236330943619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.04749427504982855], {
             RGBColor[
             0.3518764439127397, 0.4791994227180725, 0.9436422337473658]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.04749427504982855], {
             RGBColor[
             0.281739557244844, 0.41345651635696223`, 0.9393560230375456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.04749427504982855], {
             RGBColor[
             0.585970074369736, 0.674755929881201, 0.960548857214945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.04749427504982855], {
             RGBColor[
             0.9865275394369064, 0.9886968055777866, 0.8729370673481489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.04749427504982855], {
             RGBColor[
             0.24962306644129345`, 0.3797000482193023, 0.9375270363983738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.04749427504982855], {
             RGBColor[
             0.9208437466954219, 0.9397198242500384, 0.9923120926783682]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.04749427504982855], {
             RGBColor[
             0.5576848060128018, 0.6517926747922235, 0.9583221372775351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.04749427504982855], {
             RGBColor[
             0.25326504777876796`, 0.3835280015199418, 0.9377344418477144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.04749427504982855], {
             RGBColor[
             0.8226444613445744, 0.17506082952644003`, 0.16931766779781277`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.04749427504982855], {
             RGBColor[
             0.36671177852496323`, 0.4920490439135823, 0.9445875281504853]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.04749427504982855], {
             RGBColor[
             0.30865896704414575`, 0.441750522845189, 0.9408890436019178]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.04749427504982855], {
             RGBColor[
             0.9829012627807141, 0.9867683702952449, 0.9138278814340688]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.04749427504982855], {
             RGBColor[
             0.23302215960706, 0.36225144257823677`, 0.936581639313005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.04749427504982855], {
             RGBColor[
             0.29472306200537346`, 0.42710300306202637`, 0.9400954144262837]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.04749427504982855], {
             RGBColor[
             0.21890292553398902`, 0.347411232356294, 0.9357775698200786]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.04749427504982855], {
             RGBColor[
             0.39092445521974123`, 0.5130208475020834, 0.9461303384990473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.04749427504982855], {
             RGBColor[
             0.9152757732218003, 0.9352800733407862, 0.9917810143978655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.04749427504982855], {
             RGBColor[
             0.9385923578753286, 0.9537228615659814, 0.988831299825661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.04749427504982855], {
             RGBColor[
             0.2725827939998642, 0.40383217761416634`, 0.9388345589169613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.04749427504982855], {
             RGBColor[
             0.1823653638581298, 0.3090079384197544, 0.933696809735117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.04749427504982855], {
             RGBColor[
             0.8744701613749067, 0.9027427860928997, 0.9878889387123091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.04749427504982855], {
             RGBColor[
             0.9939767127007667, 0.98952512245173, 0.5857805327779135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.04749427504982855], {
             RGBColor[
             0.9951414157005084, 0.9920163043986404, 0.7125512665860644]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.04749427504982855], {
             RGBColor[
             0.3814106085308894, 0.5047804316800383, 0.9455241246007979]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.04749427504982855], {
             RGBColor[
             0.320397896026041, 0.45193428669643415`, 0.9416364485114123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.04749427504982855], {
             RGBColor[
             0.29419693695473825`, 0.4265500122755539, 0.9400654523829823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.04749427504982855], {
             RGBColor[
             0.29360677442013106`, 0.4259297140332158, 0.9400318434997037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.04749427504982855], {
             RGBColor[
             0.9424318889382709, 0.9565863775460686, 0.9823319752461818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.04749427504982855], {
             RGBColor[
             0.807933735593484, 0.8498832418602281, 0.9814909422600818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.04749427504982855], {
             RGBColor[
             0.7240681721091139, 0.7843668262643483, 0.9731320066602097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.04749427504982855], {
             RGBColor[
             0.984329904565909, 0.9877880270819891, 0.9093575644573119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.04749427504982855], {
             RGBColor[
             0.2651236286264823, 0.39599212186834176`, 0.9384097704837935]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.04749427504982855], {
             RGBColor[
             0.859910479347665, 0.45676803010411193`, 0.20481820887036734`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.04749427504982855], {
             RGBColor[
             0.3711329893802169, 0.49587847453988415`, 0.9448692437966588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.04749427504982855], {
             RGBColor[
             0.7695733223497783, 0.8199157954843064, 0.9776675347663926]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.04749427504982855], {
             RGBColor[
             0.28203039141568953`, 0.41376220151047227`, 0.9393725856133247]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.04749427504982855], {
             RGBColor[
             0.28282713132653, 0.41459962567299363`, 0.939417958772576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.04749427504982855], {
             RGBColor[
             0.6646539951158695, 0.737952019632756, 0.9672101567545748]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.04749427504982855], {
             RGBColor[
             0.2313913752108486, 0.36053738478011593`, 0.9364887685541701]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.04749427504982855], {
             RGBColor[
             0.1797070620660458, 0.3062138946902057, 0.9335454233806629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.04749427504982855], {
             RGBColor[
             0.28023078255701894`, 0.41187069849821767`, 0.939270100551106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.04749427504982855], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.04749427504982855], {
             RGBColor[
             0.31668648779682773`, 0.44871965142909115`, 0.9413999608609163]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.04749427504982855], {
             RGBColor[
             0.348529185002255, 0.47630019528793527`, 0.9434289493694545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.04749427504982855], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.04749427504982855], {
             RGBColor[
             0.49517344266125934`, 0.6010431339186144, 0.9534010137678327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.04749427504982855], {
             RGBColor[
             0.8889169937097365, 0.9142622980478761, 0.9892668904772446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.04749427504982855], {
             RGBColor[
             0.6961608186542636, 0.7625653896416773, 0.9703504624768758]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.04749427504982855], {
             RGBColor[
             0.27228850741332744`, 0.40352286375286894`, 0.938817799731216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.04749427504982855], {
             RGBColor[
             0.23658832296539867`, 0.36599970637566703`, 0.9367847270405965]},
             StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{{3.8349502435193233`*^9, 3.8349502581408367`*^9}, 
   3.8349577843740606`*^9, 3.83501892289773*^9, 3.8350190217900667`*^9, 
   3.835020556050778*^9, 3.835044646730012*^9, 3.835045035421321*^9},
 CellLabel->
  "Out[272]=",ExpressionUUID->"4d1ef9e4-76e6-4328-92aa-23229c8cea6d"]
}, Open  ]],

Cell["Estimated with Max-Min Deviation v Calculated: (r = 6)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 3.8349503922098827`*^9}, {3.8349504781120467`*^9, 
  3.834950521977162*^9}},ExpressionUUID->"91af8448-7321-4995-817f-\
b1cb5dca8b2e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphinf2", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsif2", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}],
      "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"mMDi6f200", ",", "krif2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502554527807`*^9}, {3.8349505249112787`*^9, 3.834950525026289*^9}, {
   3.834957796266032*^9, 3.834957804349044*^9}, {3.835018837121126*^9, 
   3.835018838508815*^9}, {3.8350443533371973`*^9, 3.835044357496614*^9}, {
   3.8350449455086536`*^9, 3.835044948398612*^9}},
 CellLabel->
  "In[273]:=",ExpressionUUID->"40d8e244-b219-475c-a52b-0453871397c0"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
          103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
          129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 
          142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 
          155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 
          168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 
          181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 
          194, 195, 196, 197, 198, 199, 200}, {Null, CompressedData["
1:eJwVxfk/GgwDAPA5ylXk6qBcTS9j5XjImZDN1UpNhz0LEUrEK0VRaK6QloU8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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[31, 80] -> 
             RGBColor[
              0.9935693823529412, 0.9914677647058823, 0.7459845588235297], 
             UndirectedEdge[36, 132] -> 
             RGBColor[
              0.599728088235294, 0.6739238529411764, 0.9658996764705883], 
             UndirectedEdge[16, 101] -> 
             RGBColor[
              0.7682080882352942, 0.8145772941176471, 0.7802064705882357], 
             UndirectedEdge[86, 108] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.7040428823529412, 0.7682118823529411, 0.9714854705882352], 
             UndirectedEdge[29, 136] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[55, 157] -> 
             RGBColor[
              0.8324845588235295, 0.7742607058823531, 0.6178736764705883], 
             UndirectedEdge[7, 188] -> 
             RGBColor[
              0.7682080882352942, 0.8145772941176471, 0.7802064705882357], 
             UndirectedEdge[19, 141] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[62, 185] -> 
             RGBColor[0.6373225294117648, 0.7140452941176471, 0.966233], 
             UndirectedEdge[79, 144] -> 
             RGBColor[
              0.7337891764705882, 0.7880433529411764, 0.8668828529411765], 
             UndirectedEdge[47, 54] -> 
             RGBColor[
              0.7965954117647058, 0.8405913529411765, 0.9370023823529412], 
             UndirectedEdge[32, 101] -> 
             RGBColor[
              0.9615149705882353, 0.9680034705882353, 0.7981917058823533], 
             UndirectedEdge[104, 163] -> 
             RGBColor[
              0.8602938823529411, 0.8908641176470588, 0.9430018529411764], 
             UndirectedEdge[119, 125] -> 
             RGBColor[
              0.6079915294117646, 0.6921537647058823, 0.9626107647058824], 
             UndirectedEdge[9, 140] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764705, 0.8253373823529414], 
             UndirectedEdge[3, 63] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647059], 
             UndirectedEdge[50, 104] -> 
             RGBColor[
              0.8558517352941175, 0.8611832352941176, 0.6664681176470588], 
             UndirectedEdge[47, 61] -> 
             RGBColor[0.7485252352941176, 0.803512, 0.9757730588235294], 
             UndirectedEdge[149, 195] -> 
             RGBColor[
              0.7037526176470588, 0.7547356470588235, 0.6783071764705881], 
             UndirectedEdge[99, 178] -> 
             RGBColor[
              0.7523448529411765, 0.7620757647058825, 0.6327922352941178], 
             UndirectedEdge[160, 174] -> 
             RGBColor[
              0.7880378235294117, 0.8342091176470587, 0.9514881470588235], 
             UndirectedEdge[6, 124] -> 
             RGBColor[
              0.9394269411764705, 0.9541697647058823, 0.9813329117647058], 
             UndirectedEdge[24, 197] -> 
             RGBColor[
              0.9394269411764705, 0.9541697647058823, 0.9813329117647058], 
             UndirectedEdge[80, 120] -> 
             RGBColor[
              0.8971027352941177, 0.9174697058823529, 0.8453347058823532], 
             UndirectedEdge[83, 187] -> 
             RGBColor[
              0.8971027352941177, 0.9174697058823529, 0.8453347058823532], 
             UndirectedEdge[47, 167] -> 
             RGBColor[
              0.8015682647058824, 0.8416605882352941, 0.7828327058823532], 
             UndirectedEdge[132, 150] -> 
             RGBColor[
              0.579307794117647, 0.6576412647058822, 0.9639519705882353], 
             UndirectedEdge[17, 189] -> 
             RGBColor[
              0.7652413235294118, 0.8055785882352942, 0.6828925882352941], 
             UndirectedEdge[69, 180] -> 
             RGBColor[
              0.9442819411764706, 0.8005047058823529, 0.47143038235294144`], 
             UndirectedEdge[43, 95] -> 
             RGBColor[
              0.8880516470588234, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[82, 86] -> 
             RGBColor[
              0.9896552647058823, 0.9898491764705882, 0.810851617647059], 
             UndirectedEdge[7, 61] -> 
             RGBColor[
              0.7151650588235294, 0.7764287058823529, 0.9731468235294117], 
             UndirectedEdge[30, 65] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[62, 174] -> 
             RGBColor[
              0.8830818823529412, 0.908969294117647, 0.9606118529411765], 
             UndirectedEdge[18, 47] -> 
             RGBColor[
              0.7965954117647058, 0.8405913529411765, 0.9370023823529412], 
             UndirectedEdge[56, 149] -> 
             RGBColor[0.609194, 0.6902856470588234, 0.9642738235294117], 
             UndirectedEdge[82, 163] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[10, 48] -> 
             RGBColor[
              0.7677413529411765, 0.8184846470588234, 0.9774849411764706], 
             UndirectedEdge[58, 92] -> 
             RGBColor[
              0.9930789705882352, 0.9904188235294118, 0.6926062647058827], 
             UndirectedEdge[70, 72] -> 
             RGBColor[0.9083125000000001, 0.8340482352941179, 0.6252855], 
             UndirectedEdge[35, 181] -> 
             RGBColor[
              0.7040428823529412, 0.7682118823529411, 0.9714854705882352], 
             UndirectedEdge[126, 174] -> 
             RGBColor[
              0.9776404999999999, 0.9734192941176469, 0.6746452058823529], 
             UndirectedEdge[108, 154] -> 
             RGBColor[
              0.7857050294117647, 0.7891590588235295, 0.6354184705882354], 
             UndirectedEdge[63, 77] -> 
             RGBColor[
              0.4168721470588235, 0.5235019117647058, 0.9492360294117648], 
             UndirectedEdge[32, 100] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[19, 50] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[80, 81] -> 
             RGBColor[
              0.8971027352941177, 0.9174697058823529, 0.8453347058823532], 
             UndirectedEdge[34, 163] -> 
             RGBColor[
              0.9861490588235293, 0.9885402941176471, 0.8792094705882354], 
             UndirectedEdge[146, 194] -> 
             RGBColor[
              0.6561843823529412, 0.7205876470588235, 0.8257480588235296], 
             UndirectedEdge[13, 83] -> 
             RGBColor[
              0.9935693823529412, 0.9914677647058823, 0.7459845588235297], 
             UndirectedEdge[30, 41] -> 
             RGBColor[
              0.9084719411764706, 0.9298548823529411, 0.9911320588235294], 
             UndirectedEdge[35, 111] -> 
             RGBColor[
              0.8547002647058825, 0.7625511764705883, 0.613651794117647], 
             UndirectedEdge[29, 144] -> 
             RGBColor[
              0.9900631764705883, 0.9901588823529412, 0.814342411764706], 
             UndirectedEdge[6, 12] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[67, 143] -> 
             RGBColor[
              0.7461200588235294, 0.8007435882352941, 0.9633476764705882], 
             UndirectedEdge[135, 163] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117646, 0.9406145294117647], 
             UndirectedEdge[50, 60] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[25, 143] -> 
             RGBColor[
              0.8745242941176471, 0.9025870588235294, 0.9750976176470588], 
             UndirectedEdge[12, 13] -> 
             RGBColor[
              0.9604562352941176, 0.9685528235294117, 0.8874943235294117], 
             UndirectedEdge[89, 144] -> 
             RGBColor[
              0.8955535882352942, 0.9169701176470588, 0.8812590294117647], 
             UndirectedEdge[22, 24] -> 
             RGBColor[
              0.9055310294117647, 0.7121866470588236, 0.5876985882352942], 
             UndirectedEdge[107, 156] -> 
             RGBColor[
              0.6485839411764704, 0.7197705294117647, 0.9688834705882352], 
             UndirectedEdge[23, 154] -> 
             RGBColor[
              0.9688594705882354, 0.906617823529412, 0.3335253529411766], 
             UndirectedEdge[101, 135] -> 
             RGBColor[
              0.9720496764705882, 0.9760357647058824, 0.7864448529411768], 
             UndirectedEdge[7, 42] -> 
             RGBColor[
              0.6079915294117646, 0.6921537647058823, 0.9626107647058824], 
             UndirectedEdge[122, 192] -> 
             RGBColor[
              0.5422784705882353, 0.6392851176470589, 0.957109294117647], 
             UndirectedEdge[129, 133] -> 
             RGBColor[
              0.4886372352941176, 0.5934276470588236, 0.9535244705882353], 
             UndirectedEdge[40, 80] -> 
             RGBColor[
              0.9896552647058823, 0.9898491764705882, 0.810851617647059], 
             UndirectedEdge[41, 172] -> 
             RGBColor[
              0.9406042647058823, 0.9506719411764706, 0.742865705882353], 
             UndirectedEdge[94, 115] -> 
             RGBColor[
              0.9410946764705882, 0.9517208823529412, 0.7962440000000004], 
             UndirectedEdge[87, 103] -> 
             RGBColor[
              0.851736294117647, 0.884481882352941, 0.9574876176470588], 
             UndirectedEdge[142, 160] -> 
             RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             UndirectedEdge[21, 150] -> 
             RGBColor[
              0.6818048823529411, 0.7493454117647058, 0.9705205882352941], 
             UndirectedEdge[29, 142] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[67, 103] -> 
             RGBColor[0.6393371176470588, 0.7166411764705882, 0.965735], 
             UndirectedEdge[50, 163] -> 
             RGBColor[
              0.9797498529411764, 0.9580501176470588, 0.6351092647058824], 
             UndirectedEdge[21, 46] -> 
             RGBColor[0.7022251764705882, 0.765628, 0.972468294117647], 
             UndirectedEdge[43, 129] -> 
             RGBColor[
              0.7281049411764705, 0.7872294117647058, 0.9738253529411764], 
             UndirectedEdge[11, 112] -> 
             RGBColor[
              0.5422784705882353, 0.6392851176470589, 0.957109294117647], 
             UndirectedEdge[119, 195] -> 
             RGBColor[
              0.8309543823529411, 0.8584472352941175, 0.6883940588235293], 
             UndirectedEdge[99, 109] -> 
             RGBColor[
              0.42976435294117643`, 0.5442465294117647, 0.9492725882352941], 
             UndirectedEdge[45, 120] -> 
             RGBColor[
              0.8154534411764707, 0.544279823529412, 0.5793566470588235], 
             UndirectedEdge[29, 153] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[27, 125] -> 
             RGBColor[
              0.3606027352941177, 0.4723395588235294, 0.9453051470588235], 
             UndirectedEdge[35, 157] -> 
             RGBColor[
              0.7677413529411765, 0.8184846470588234, 0.9774849411764706], 
             UndirectedEdge[28, 112] -> 
             RGBColor[0.7686985, 0.8156262352941177, 0.8335847647058825], 
             UndirectedEdge[22, 89] -> 
             RGBColor[
              0.8300936764705883, 0.6525716470588236, 0.5932101470588236], 
             UndirectedEdge[96, 116] -> 
             RGBColor[
              0.6079915294117646, 0.6921537647058823, 0.9626107647058824], 
             UndirectedEdge[23, 143] -> 
             RGBColor[
              0.9626346764705882, 0.9452856470588236, 0.6640807941176471], 
             UndirectedEdge[6, 14] -> 
             RGBColor[
              0.9394269411764705, 0.9541697647058823, 0.9813329117647058], 
             UndirectedEdge[9, 112] -> 
             RGBColor[0.7686985, 0.8156262352941177, 0.8335847647058825], 
             UndirectedEdge[12, 25] -> 
             RGBColor[
              0.8639895882352941, 0.8945547647058824, 0.9868444705882353], 
             UndirectedEdge[176, 199] -> 
             RGBColor[
              0.9352148823529411, 0.7616891176470588, 0.35792644117647066`], 
             UndirectedEdge[48, 112] -> 
             RGBColor[
              0.670682705882353, 0.7411285882352942, 0.9688592352941177], 
             UndirectedEdge[79, 149] -> 
             RGBColor[
              0.4474295882352941, 0.5613588823529412, 0.9498976470588236], 
             UndirectedEdge[58, 155] -> 
             RGBColor[
              0.8005095294117647, 0.8422099411764705, 0.8721353235294118], 
             UndirectedEdge[118, 138] -> 
             RGBColor[
              0.9886744411764705, 0.9877512941176472, 0.7040950294117648], 
             UndirectedEdge[172, 173] -> 
             RGBColor[0.969995, 0.9073448235294119, 0.38631297058823544`], 
             UndirectedEdge[53, 104] -> 
             RGBColor[
              0.672697294117647, 0.7437244705882352, 0.9683612352941176], 
             UndirectedEdge[179, 185] -> 
             RGBColor[
              0.6818048823529411, 0.7493454117647058, 0.9705205882352941], 
             UndirectedEdge[82, 176] -> 
             RGBColor[
              0.9307324411764706, 0.7616688235294118, 0.5654744117647059], 
             UndirectedEdge[142, 181] -> 
             RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             UndirectedEdge[54, 160] -> 
             RGBColor[
              0.7965954117647058, 0.8405913529411765, 0.9370023823529412], 
             UndirectedEdge[121, 151] -> 
             RGBColor[
              0.9585192352941176, 0.968584294117647, 0.9551002941176471], 
             UndirectedEdge[138, 144] -> 
             RGBColor[
              0.9925885588235295, 0.9893698823529412, 0.6392279705882354], 
             UndirectedEdge[171, 196] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[120, 172] -> 
             RGBColor[
              0.8961219117647059, 0.9153718235294118, 0.7385781176470589], 
             UndirectedEdge[113, 159] -> 
             RGBColor[
              0.9152564411764705, 0.6723895882352942, 0.5518166176470588], 
             UndirectedEdge[103, 108] -> 
             RGBColor[
              0.672697294117647, 0.7437244705882352, 0.9683612352941176], 
             UndirectedEdge[64, 176] -> 
             RGBColor[
              0.9352148823529411, 0.7616891176470588, 0.3579264411764707], 
             UndirectedEdge[83, 101] -> 
             RGBColor[
              0.9946281176470588, 0.9909184117647059, 0.6566819411764712], 
             UndirectedEdge[15, 63] -> 
             RGBColor[
              0.672697294117647, 0.7437244705882352, 0.9683612352941176], 
             UndirectedEdge[55, 72] -> 
             RGBColor[0.9083125000000001, 0.8340482352941179, 0.6252855], 
             UndirectedEdge[105, 142] -> 
             RGBColor[
              0.7687860882352942, 0.7239879411764708, 0.611874205882353], 
             UndirectedEdge[96, 105] -> 
             RGBColor[
              0.735425911764706, 0.6969046470588238, 0.6092479705882353], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.7040428823529412, 0.7682118823529411, 0.9714854705882352], 
             UndirectedEdge[64, 108] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647059], 
             UndirectedEdge[56, 119] -> 
             RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 
             UndirectedEdge[68, 157] -> 
             RGBColor[
              0.7918034117647057, 0.8375021764705881, 0.9798248235294118], 
             UndirectedEdge[137, 161] -> 
             RGBColor[
              0.9881551470588235, 0.9806108235294118, 0.6277259117647059], 
             UndirectedEdge[160, 188] -> 
             RGBColor[
              0.8015682647058824, 0.8416605882352941, 0.7828327058823532], 
             UndirectedEdge[127, 187] -> 
             RGBColor[0.823149, 0.8619895882352941, 0.9829490588235295], 
             UndirectedEdge[41, 141] -> 
             RGBColor[
              0.8122237058823528, 0.8537847647058823, 0.9817725294117647], 
             UndirectedEdge[137, 175] -> 
             RGBColor[
              0.9916613529411764, 0.9819197058823529, 0.5593680588235296], 
             UndirectedEdge[1, 122] -> 
             RGBColor[
              0.7355853529411764, 0.7927112941176471, 0.9750945294117647], 
             UndirectedEdge[60, 177] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[72, 75] -> 
             RGBColor[
              0.6281636470588234, 0.7034879411764705, 0.9669357647058823], 
             UndirectedEdge[13, 69] -> 
             RGBColor[
              0.9427327941176471, 0.8000051176470587, 0.5073547058823529], 
             UndirectedEdge[48, 77] -> 
             RGBColor[
              0.511916205882353, 0.598262088235294, 0.9583597352941177], 
             UndirectedEdge[22, 183] -> 
             RGBColor[
              0.9281094705882353, 0.7270692941176471, 0.4579356764705885], 
             UndirectedEdge[16, 86] -> 
             RGBColor[0.7686985, 0.8156262352941177, 0.8335847647058825], 
             UndirectedEdge[8, 62] -> 
             RGBColor[
              0.8971027352941177, 0.9174697058823529, 0.8453347058823532], 
             UndirectedEdge[26, 51] -> 
             RGBColor[
              0.7965954117647058, 0.8405913529411765, 0.9370023823529412], 
             UndirectedEdge[117, 121] -> 
             RGBColor[
              0.9795485294117647, 0.9829673529411764, 0.861261705882353], 
             UndirectedEdge[89, 136] -> 
             RGBColor[
              0.8639895882352941, 0.8945547647058824, 0.9868444705882353], 
             UndirectedEdge[81, 168] -> 
             RGBColor[
              0.5836812941176471, 0.6681878235294118, 0.9626481764705882], 
             UndirectedEdge[172, 198] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764707, 0.37162073529411777`], 
             UndirectedEdge[55, 68] -> 
             RGBColor[
              0.887892205882353, 0.8177656470588237, 0.6233377941176471], 
             UndirectedEdge[156, 192] -> 
             RGBColor[
              0.7355853529411764, 0.7927112941176471, 0.9750945294117647], 
             UndirectedEdge[15, 112] -> 
             RGBColor[0.6393371176470588, 0.7166411764705882, 0.965735], 
             UndirectedEdge[25, 154] -> 
             RGBColor[
              0.8807490882352942, 0.8639192352941178, 0.6445421764705883], 
             UndirectedEdge[100, 135] -> 
             RGBColor[
              0.9725400882352941, 0.9770847058823529, 0.8398231470588238], 
             UndirectedEdge[37, 149] -> 
             RGBColor[
              0.7072097941176471, 0.764783294117647, 0.8289993529411768], 
             UndirectedEdge[125, 149] -> 
             RGBColor[
              0.48078976470588236`, 0.5884421764705883, 0.9525238823529412], 
             UndirectedEdge[2, 184] -> 
             RGBColor[0.9217035, 0.7856220588235293, 0.601193294117647], 
             UndirectedEdge[6, 16] -> 
             RGBColor[
              0.7355853529411764, 0.7927112941176471, 0.9750945294117647], 
             UndirectedEdge[55, 111] -> 
             RGBColor[
              0.9194434705882354, 0.7183272352941179, 0.2540405294117648], 
             UndirectedEdge[34, 50] -> 
             RGBColor[
              0.9817069117647059, 0.958859411764706, 0.6026757352941178], 
             UndirectedEdge[56, 125] -> 
             RGBColor[
              0.670682705882353, 0.7411285882352942, 0.9688592352941177], 
             UndirectedEdge[98, 196] -> 
             RGBColor[
              0.8639895882352941, 0.8945547647058824, 0.9868444705882353], 
             UndirectedEdge[160, 167] -> 
             RGBColor[
              0.8015682647058824, 0.8416605882352941, 0.7828327058823532], 
             UndirectedEdge[22, 149] -> 
             RGBColor[
              0.6402007352941177, 0.4998852352941177, 0.5768747941176471], 
             UndirectedEdge[147, 194] -> 
             RGBColor[
              0.9281094705882353, 0.7270692941176471, 0.4579356764705885], 
             UndirectedEdge[83, 161] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[34, 177] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[70, 145] -> 
             RGBColor[
              0.8638301470588237, 0.798748117647059, 0.620997911764706], 
             UndirectedEdge[125, 170] -> 
             RGBColor[
              0.7355853529411764, 0.7927112941176471, 0.9750945294117647], 
             UndirectedEdge[190, 192] -> 
             RGBColor[
              0.7546776470588235, 0.8071258235294118, 0.9488619117647059], 
             UndirectedEdge[122, 188] -> 
             RGBColor[
              0.7682080882352942, 0.8145772941176471, 0.7802064705882357], 
             UndirectedEdge[123, 130] -> 
             RGBColor[
              0.9381279117647059, 0.9427221764705882, 0.6989301176470588], 
             UndirectedEdge[94, 116] -> 
             RGBColor[
              0.8339211470588235, 0.8674459411764706, 0.7857079411764709], 
             UndirectedEdge[23, 162] -> 
             RGBColor[
              0.9836639705882353, 0.959668705882353, 0.570242205882353], 
             UndirectedEdge[116, 160] -> 
             RGBColor[
              0.6413517058823528, 0.7192370588235293, 0.9652369999999999], 
             UndirectedEdge[80, 117] -> 
             RGBColor[
              0.9935693823529412, 0.9914677647058823, 0.7459845588235297], 
             UndirectedEdge[147, 185] -> 
             RGBColor[
              0.6683292647058823, 0.5236448823529413, 0.5788339705882354], 
             UndirectedEdge[55, 107] -> 
             RGBColor[
              0.6484245000000001, 0.6239638823529414, 0.6030369117647059], 
             UndirectedEdge[111, 174] -> 
             RGBColor[
              0.938695205882353, 0.828548411764706, 0.5936544705882354], 
             UndirectedEdge[126, 142] -> 
             RGBColor[0.7986015, 0.8326618823529411, 0.6855188235294116], 
             UndirectedEdge[115, 160] -> 
             RGBColor[0.7485252352941176, 0.803512, 0.9757730588235294], 
             UndirectedEdge[74, 164] -> 
             RGBColor[
              0.9400359411764705, 0.9522702352941176, 0.8855466176470588], 
             UndirectedEdge[42, 97] -> 
             RGBColor[
              0.745511794117647, 0.43957470588235287`, 0.5661651176470588], 
             UndirectedEdge[25, 108] -> 
             RGBColor[
              0.7040428823529412, 0.7682118823529411, 0.9714854705882352], 
             UndirectedEdge[67, 133] -> 
             RGBColor[
              0.4552770588235294, 0.5663443529411765, 0.9508982352941175], 
             UndirectedEdge[38, 183] -> 
             RGBColor[
              0.8971027352941177, 0.9174697058823529, 0.8453347058823532], 
             UndirectedEdge[33, 41] -> 
             RGBColor[
              0.8676313529411763, 0.8972897058823528, 0.9872366470588235], 
             UndirectedEdge[32, 123] -> 
             RGBColor[
              0.9084719411764706, 0.9298548823529411, 0.9911320588235294], 
             UndirectedEdge[61, 116] -> 
             RGBColor[
              0.7808781176470587, 0.8292973529411763, 0.9786482941176471], 
             UndirectedEdge[93, 134] -> 
             RGBColor[0.7986015, 0.8326618823529411, 0.6855188235294116], 
             UndirectedEdge[45, 128] -> 
             RGBColor[0.8395155, 0.5632973529411767, 0.5816965294117648], 
             UndirectedEdge[29, 35] -> 
             RGBColor[
              0.8935965294117647, 0.9161608235294119, 0.9136925588235295], 
             UndirectedEdge[3, 106] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647059], 
             UndirectedEdge[77, 140] -> 
             RGBColor[
              0.5959111470588234, 0.6642593235294116, 0.9383624117647059], 
             UndirectedEdge[79, 195] -> 
             RGBColor[
              0.7318811470588236, 0.7784952941176471, 0.6802663529411764], 
             UndirectedEdge[38, 46] -> 
             RGBColor[
              0.8639895882352941, 0.8945547647058824, 0.9868444705882353], 
             UndirectedEdge[14, 59] -> 
             RGBColor[
              0.8745242941176471, 0.9025870588235294, 0.9750976176470588], 
             UndirectedEdge[126, 191] -> 
             RGBColor[
              0.9776404999999999, 0.9734192941176469, 0.6746452058823529], 
             UndirectedEdge[13, 64] -> 
             RGBColor[
              0.9925885588235295, 0.9893698823529412, 0.6392279705882354], 
             UndirectedEdge[3, 11] -> 
             RGBColor[
              0.7677176764705882, 0.8135283529411765, 0.7268281764705883], 
             UndirectedEdge[31, 98] -> 
             RGBColor[
              0.8955535882352942, 0.9169701176470588, 0.8812590294117647], 
             UndirectedEdge[25, 162] -> 
             RGBColor[
              0.8955535882352942, 0.9169701176470588, 0.8812590294117647], 
             UndirectedEdge[126, 157] -> 
             RGBColor[
              0.8622999705882353, 0.8829346470588234, 0.691518294117647], 
             UndirectedEdge[128, 183] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[22, 192] -> 
             RGBColor[
              0.7016894411764706, 0.5507281764705884, 0.5814602058823529], 
             UndirectedEdge[99, 194] -> 
             RGBColor[0.7686985, 0.8156262352941177, 0.8335847647058825], 
             UndirectedEdge[21, 151] -> 
             RGBColor[
              0.7127598823529411, 0.773660294117647, 0.9607214411764706], 
             UndirectedEdge[48, 59] -> 
             RGBColor[
              0.7990869411764707, 0.8429720588235294, 0.9806091764705882], 
             UndirectedEdge[18, 115] -> 
             RGBColor[
              0.9361218235294118, 0.9506516470588235, 0.9504136764705882], 
             UndirectedEdge[29, 89] -> 
             RGBColor[
              0.8935965294117647, 0.9161608235294119, 0.9136925588235295], 
             UndirectedEdge[15, 140] -> 
             RGBColor[
              0.851736294117647, 0.884481882352941, 0.9574876176470588], 
             UndirectedEdge[113, 136] -> 
             RGBColor[0.8876065588235293, 0.6515928235294117, 0.592535], 
             UndirectedEdge[111, 160] -> 
             RGBColor[0.7596562058823529, 0.687791, 0.6045280882352941], 
             UndirectedEdge[116, 188] -> 
             RGBColor[
              0.8339211470588235, 0.8674459411764706, 0.7857079411764709], 
             UndirectedEdge[82, 127] -> 
             RGBColor[
              0.9157015294117646, 0.9343690588235294, 0.9484659705882352], 
             UndirectedEdge[25, 95] -> 
             RGBColor[
              0.8639895882352941, 0.8945547647058824, 0.9868444705882353], 
             UndirectedEdge[62, 111] -> 
             RGBColor[
              0.8547002647058825, 0.7625511764705883, 0.613651794117647], 
             UndirectedEdge[162, 180] -> 
             RGBColor[
              0.9935693823529412, 0.9914677647058823, 0.7459845588235297], 
             UndirectedEdge[89, 159] -> 
             RGBColor[
              0.8916394705882353, 0.9153515294117647, 0.9461260882352941], 
             UndirectedEdge[7, 153] -> 
             RGBColor[
              0.7355853529411764, 0.7927112941176471, 0.9750945294117647], 
             UndirectedEdge[146, 183] -> 
             RGBColor[
              0.6561843823529412, 0.7205876470588235, 0.8257480588235296], 
             UndirectedEdge[144, 197] -> 
             RGBColor[
              0.9604562352941176, 0.9685528235294117, 0.8874943235294117], 
             UndirectedEdge[120, 128] -> 
             RGBColor[0.823149, 0.8619895882352941, 0.9829490588235295], 
             UndirectedEdge[74, 166] -> 
             RGBColor[
              0.8955535882352942, 0.9169701176470588, 0.8812590294117647], 
             UndirectedEdge[147, 152] -> 
             RGBColor[
              0.924652294117647, 0.7170216470588235, 0.30724349999999995`], 
             UndirectedEdge[22, 190] -> 
             RGBColor[
              0.9140886176470588, 0.7185688823529413, 0.5732128235294118], 
             UndirectedEdge[27, 128] -> 
             RGBColor[
              0.5130690294117646, 0.5932005588235294, 0.9593949705882353], 
             UndirectedEdge[47, 88] -> 
             RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             UndirectedEdge[69, 177] -> 
             RGBColor[
              0.911168794117647, 0.7775897647058823, 0.6129401470588235], 
             UndirectedEdge[122, 167] -> 
             RGBColor[
              0.7682080882352942, 0.8145772941176471, 0.7802064705882357], 
             UndirectedEdge[1, 78] -> 
             RGBColor[
              0.6485839411764706, 0.7197705294117647, 0.9688834705882352], 
             UndirectedEdge[138, 159] -> 
             RGBColor[
              0.9886744411764705, 0.9877512941176472, 0.7040950294117648], 
             UndirectedEdge[101, 127] -> 
             RGBColor[
              0.9206743823529411, 0.9354382941176471, 0.7942962941176475], 
             UndirectedEdge[65, 90] -> 
             RGBColor[0.9479845294117646, 0.960552, 0.9668471470588236], 
             UndirectedEdge[64, 127] -> 
             RGBColor[
              0.9201839705882353, 0.9343893529411764, 0.7409180000000001], 
             UndirectedEdge[117, 146] -> 
             RGBColor[
              0.6546352352941176, 0.7200880588235294, 0.8616723823529412], 
             UndirectedEdge[49, 103] -> 
             RGBColor[
              0.8122237058823528, 0.8537847647058823, 0.9817725294117647], 
             UndirectedEdge[88, 113] -> 
             RGBColor[
              0.7276598529411764, 0.5252499411764706, 0.5771759999999999], 
             UndirectedEdge[13, 176] -> 
             RGBColor[
              0.9346465588235294, 0.7632874117647059, 0.5006073529411765], 
             UndirectedEdge[17, 112] -> 
             RGBColor[
              0.7652413235294118, 0.8055785882352942, 0.6828925882352941], 
             UndirectedEdge[129, 170] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[35, 116] -> 
             RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 
             UndirectedEdge[69, 110] -> 
             RGBColor[
              0.9437915294117647, 0.7994557647058823, 0.4180520882352945], 
             UndirectedEdge[47, 126] -> 
             RGBColor[0.7986015, 0.8326618823529411, 0.6855188235294116], 
             UndirectedEdge[83, 137] -> 
             RGBColor[
              0.9916613529411764, 0.9819197058823529, 0.5593680588235296], 
             UndirectedEdge[72, 84] -> 
             RGBColor[
              0.9361218235294118, 0.9506516470588235, 0.9504136764705882], 
             UndirectedEdge[22, 37] -> 
             RGBColor[
              0.9281094705882353, 0.7270692941176471, 0.4579356764705885], 
             UndirectedEdge[90, 141] -> 
             RGBColor[
              0.851736294117647, 0.884481882352941, 0.9574876176470588], 
             UndirectedEdge[24, 79] -> 
             RGBColor[
              0.7127598823529411, 0.773660294117647, 0.9607214411764706], 
             UndirectedEdge[34, 130] -> 
             RGBColor[
              0.9881551470588235, 0.9806108235294118, 0.6277259117647059], 
             UndirectedEdge[157, 174] -> 
             RGBColor[
              0.851736294117647, 0.884481882352941, 0.9574876176470588], 
             UndirectedEdge[131, 180] -> 
             RGBColor[
              0.9442819411764706, 0.8005047058823529, 0.47143038235294144`], 
             UndirectedEdge[3, 48] -> 
             RGBColor[
              0.8961219117647059, 0.9153718235294118, 0.7385781176470589], 
             UndirectedEdge[49, 67] -> 
             RGBColor[
              0.7151650588235294, 0.7764287058823529, 0.9731468235294117], 
             UndirectedEdge[79, 190] -> 
             RGBColor[
              0.7213174705882353, 0.7800425294117647, 0.9462356764705883], 
             UndirectedEdge[13, 82] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352941, 0.8467759411764706], 
             UndirectedEdge[68, 138] -> 
             RGBColor[
              0.9201839705882353, 0.9343893529411764, 0.7409180000000001], 
             UndirectedEdge[153, 160] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[178, 183] -> 
             RGBColor[
              0.9787648823529412, 0.9384168823529413, 0.5092677058823533], 
             UndirectedEdge[2, 166] -> 
             RGBColor[
              0.8745242941176471, 0.9025870588235294, 0.9750976176470588], 
             UndirectedEdge[32, 53] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[26, 184] -> 
             RGBColor[
              0.751222088235294, 0.6512468823529411, 0.5975811470588235], 
             UndirectedEdge[61, 115] -> 
             RGBColor[
              0.8880516470588234, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[146, 178] -> 
             RGBColor[
              0.6398307352941177, 0.6670371764705884, 0.6249555294117648], 
             UndirectedEdge[88, 102] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[118, 159] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[62, 75] -> 
             RGBColor[
              0.5836812941176471, 0.6681878235294118, 0.9626481764705882], 
             UndirectedEdge[89, 197] -> 
             RGBColor[
              0.8639895882352941, 0.8945547647058824, 0.9868444705882353], 
             UndirectedEdge[85, 146] -> 
             RGBColor[
              0.5268229999999999, 0.621602588235294, 0.957898294117647], 
             UndirectedEdge[170, 190] -> 
             RGBColor[0.9479845294117646, 0.960552, 0.9668471470588236], 
             UndirectedEdge[82, 101] -> 
             RGBColor[
              0.9891648529411765, 0.9888002352941176, 0.7574733235294121], 
             UndirectedEdge[7, 73] -> 
             RGBColor[
              0.48078976470588236`, 0.5884421764705883, 0.9525238823529412], 
             UndirectedEdge[19, 34] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             UndirectedEdge[56, 170] -> 
             RGBColor[
              0.8639895882352941, 0.8945547647058824, 0.9868444705882353], 
             UndirectedEdge[32, 187] -> 
             RGBColor[
              0.8639895882352941, 0.8945547647058824, 0.9868444705882353], 
             UndirectedEdge[74, 169] -> 
             RGBColor[
              0.8955535882352942, 0.9169701176470588, 0.8812590294117647], 
             UndirectedEdge[55, 147] -> 
             RGBColor[
              0.8948368823529412, 0.6083477058823532, 0.23359888235294124`], 
             UndirectedEdge[49, 143] -> 
             RGBColor[
              0.9190066470588234, 0.9378871764705882, 0.9793852058823529], 
             UndirectedEdge[28, 77] -> 
             RGBColor[
              0.6099319999999999, 0.6727597352941176, 0.8230852647058826], 
             UndirectedEdge[122, 153] -> 
             RGBColor[
              0.7355853529411764, 0.7927112941176471, 0.9750945294117647], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.7355853529411764, 0.7927112941176471, 0.9750945294117647], 
             UndirectedEdge[16, 199] -> 
             RGBColor[
              0.7677176764705882, 0.8135283529411765, 0.7268281764705883], 
             UndirectedEdge[64, 180] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588239], 
             UndirectedEdge[38, 128] -> 
             RGBColor[0.823149, 0.8619895882352941, 0.9829490588235295], 
             UndirectedEdge[46, 98] -> 
             RGBColor[
              0.8639895882352941, 0.8945547647058824, 0.9868444705882353], 
             UndirectedEdge[68, 142] -> 
             RGBColor[
              0.7281049411764705, 0.7872294117647058, 0.9738253529411764], 
             UndirectedEdge[5, 20] -> 
             RGBColor[
              0.9194434705882354, 0.7183272352941179, 0.2540405294117648], 
             UndirectedEdge[169, 200] -> 
             RGBColor[
              0.7040428823529412, 0.7682118823529411, 0.9714854705882352], 
             UndirectedEdge[27, 133] -> 
             RGBColor[
              0.27360132352941174`, 0.399398794117647, 0.9390940882352941], 
             UndirectedEdge[32, 135] -> 
             RGBColor[
              0.9394269411764705, 0.9541697647058823, 0.9813329117647058], 
             UndirectedEdge[144, 190] -> 
             RGBColor[
              0.9795485294117647, 0.9829673529411764, 0.861261705882353], 
             UndirectedEdge[62, 126] -> 
             RGBColor[
              0.8936455588235295, 0.9074220588235293, 0.6946425294117646], 
             UndirectedEdge[55, 62] -> 
             RGBColor[
              0.8638301470588237, 0.798748117647059, 0.620997911764706], 
             UndirectedEdge[62, 76] -> 
             RGBColor[
              0.8435692941176471, 0.8782721764705882, 0.9848967647058824], 
             UndirectedEdge[157, 181] -> 
             RGBColor[
              0.672697294117647, 0.7437244705882352, 0.9683612352941176], 
             UndirectedEdge[64, 82] -> 
             RGBColor[
              0.9886744411764705, 0.9877512941176472, 0.7040950294117648], 
             UndirectedEdge[142, 153] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[21, 109] -> 
             RGBColor[
              0.39640417647058823`, 0.5171632352941176, 0.9466463529411765], 
             UndirectedEdge[66, 198] -> 
             RGBColor[0.7596562058823529, 0.687791, 0.6045280882352941], 
             UndirectedEdge[141, 198] -> 
             RGBColor[
              0.8233546764705881, 0.7380637647058823, 0.6105275588235294], 
             UndirectedEdge[10, 28] -> 
             RGBColor[
              0.8657571470588235, 0.892982294117647, 0.8422104705882355], 
             UndirectedEdge[31, 151] -> 
             RGBColor[
              0.9709909411764706, 0.9765851176470588, 0.8757474705882353], 
             UndirectedEdge[111, 142] -> 
             RGBColor[0.7596562058823529, 0.687791, 0.6045280882352941], 
             UndirectedEdge[111, 181] -> 
             RGBColor[0.7596562058823529, 0.687791, 0.6045280882352941], 
             UndirectedEdge[86, 101] -> 
             RGBColor[
              0.9946281176470588, 0.9909184117647059, 0.6566819411764712], 
             UndirectedEdge[119, 144] -> 
             RGBColor[
              0.8328624117647058, 0.867995294117647, 0.8750105588235294], 
             UndirectedEdge[5, 102] -> 
             RGBColor[
              0.9527160588235295, 0.8370488235294118, 0.478377323529412], 
             UndirectedEdge[157, 185] -> 
             RGBColor[
              0.6059769411764705, 0.6895578823529411, 0.9631087647058824], 
             UndirectedEdge[13, 110] -> 
             RGBColor[
              0.9930789705882352, 0.9904188235294118, 0.6926062647058827], 
             UndirectedEdge[32, 82] -> 
             RGBColor[
              0.9565421176470588, 0.9669342352941177, 0.9523613823529411], 
             UndirectedEdge[12, 23] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[53, 130] -> 
             RGBColor[0.7986015, 0.8326618823529411, 0.6855188235294116], 
             UndirectedEdge[74, 80] -> 
             RGBColor[
              0.9935693823529412, 0.9914677647058823, 0.7459845588235297], 
             UndirectedEdge[35, 185] -> 
             RGBColor[0.6373225294117648, 0.7140452941176471, 0.966233], 
             UndirectedEdge[117, 196] -> 
             RGBColor[
              0.9604562352941176, 0.9685528235294117, 0.8874943235294117], 
             UndirectedEdge[22, 181] -> 
             RGBColor[
              0.7350496176470588, 0.5778114705882353, 0.5840864411764706], 
             UndirectedEdge[143, 197] -> 
             RGBColor[
              0.9394269411764705, 0.9541697647058823, 0.9813329117647058], 
             UndirectedEdge[16, 124] -> 
             RGBColor[
              0.7461200588235294, 0.8007435882352941, 0.9633476764705882], 
             UndirectedEdge[182, 191] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117646, 0.9406145294117647], 
             UndirectedEdge[98, 146] -> 
             RGBColor[0.5581685882352941, 0.64609, 0.9610225294117647], 
             UndirectedEdge[156, 183] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[6, 13] -> 
             RGBColor[
              0.9604562352941176, 0.9685528235294117, 0.8874943235294117], 
             UndirectedEdge[50, 100] -> 
             RGBColor[
              0.9852131176470589, 0.960168294117647, 0.5343178823529414], 
             UndirectedEdge[13, 175] -> 
             RGBColor[
              0.9935693823529412, 0.9914677647058823, 0.7459845588235297], 
             UndirectedEdge[62, 116] -> 
             RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 
             UndirectedEdge[120, 171] -> 
             RGBColor[
              0.7040428823529412, 0.7682118823529411, 0.9714854705882352], 
             UndirectedEdge[72, 139] -> 
             RGBColor[
              0.8435692941176471, 0.8782721764705882, 0.9848967647058824], 
             UndirectedEdge[6, 83] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[118, 190] -> 
             RGBColor[
              0.9756344117647058, 0.9813487647058823, 0.9261287647058823], 
             UndirectedEdge[36, 200] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[16, 161] -> 
             RGBColor[
              0.765192294117647, 0.8143173529411765, 0.9019426176470589], 
             UndirectedEdge[2, 169] -> 
             RGBColor[
              0.8745242941176471, 0.9025870588235294, 0.9750976176470588], 
             UndirectedEdge[107, 111] -> 
             RGBColor[
              0.6392946176470589, 0.5877669411764707, 0.595690794117647], 
             UndirectedEdge[127, 180] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[138, 156] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.744813411764706], 
             UndirectedEdge[72, 93] -> 
             RGBColor[0.7485252352941176, 0.803512, 0.9757730588235294], 
             UndirectedEdge[137, 187] -> 
             RGBColor[
              0.8936455588235295, 0.9074220588235293, 0.6946425294117646], 
             UndirectedEdge[40, 121] -> 
             RGBColor[
              0.9756344117647058, 0.9813487647058823, 0.9261287647058823], 
             UndirectedEdge[98, 178] -> 
             RGBColor[
              0.8807490882352942, 0.8639192352941178, 0.6445421764705883], 
             UndirectedEdge[10, 186] -> 
             RGBColor[0.6393371176470588, 0.7166411764705882, 0.965735], 
             UndirectedEdge[63, 91] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[125, 195] -> 
             RGBColor[
              0.7652413235294118, 0.8055785882352942, 0.6828925882352941], 
             UndirectedEdge[86, 180] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[137, 186] -> 
             RGBColor[
              0.7652413235294118, 0.8055785882352942, 0.6828925882352941], 
             UndirectedEdge[33, 44] -> 
             RGBColor[
              0.8472110588235293, 0.8810071176470587, 0.9852889411764706], 
             UndirectedEdge[14, 193] -> 
             RGBColor[
              0.9499616470588235, 0.9622020588235294, 0.9695860588235294], 
             UndirectedEdge[11, 28] -> 
             RGBColor[0.7686985, 0.8156262352941177, 0.8335847647058825], 
             UndirectedEdge[85, 151] -> 
             RGBColor[
              0.8431787058823528, 0.8780996470588234, 0.9719733823529412], 
             UndirectedEdge[175, 199] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588239], 
             UndirectedEdge[146, 196] -> 
             RGBColor[
              0.6230712352941177, 0.6976727058823529, 0.9672578235294118], 
             UndirectedEdge[20, 77] -> 
             RGBColor[
              0.5766594117647059, 0.5540381470588237, 0.5987484705882353], 
             UndirectedEdge[27, 56] -> 
             RGBColor[
              0.48900697058823533`, 0.5741830294117647, 0.9570550882352942], 
             UndirectedEdge[101, 175] -> 
             RGBColor[
              0.9946281176470588, 0.9909184117647059, 0.6566819411764712], 
             UndirectedEdge[21, 85] -> 
             RGBColor[
              0.6059769411764705, 0.6895578823529411, 0.9631087647058824], 
             UndirectedEdge[150, 194] -> 
             RGBColor[
              0.9415850882352941, 0.9527698235294118, 0.8496222941176472], 
             UndirectedEdge[61, 160] -> 
             RGBColor[0.7485252352941176, 0.803512, 0.9757730588235294], 
             UndirectedEdge[24, 149] -> 
             RGBColor[
              0.6846313529411765, 0.7499006470588234, 0.9587622647058824], 
             UndirectedEdge[14, 186] -> 
             RGBColor[
              0.7461200588235294, 0.8007435882352941, 0.9633476764705882], 
             UndirectedEdge[111, 126] -> 
             RGBColor[
              0.9492588823529412, 0.8270011764705882, 0.32768514705882346`], 
             UndirectedEdge[35, 88] -> 
             RGBColor[
              0.7040428823529412, 0.7682118823529411, 0.9714854705882352], 
             UndirectedEdge[94, 111] -> 
             RGBColor[
              0.9522256470588235, 0.8359998823529413, 0.42499902941176504`], 
             UndirectedEdge[133, 162] -> 
             RGBColor[
              0.6801479411764706, 0.7421858823529411, 0.8632980294117647], 
             UndirectedEdge[124, 199] -> 
             RGBColor[
              0.9715592647058824, 0.9749868235294118, 0.7330665588235296], 
             UndirectedEdge[54, 105] -> 
             RGBColor[
              0.9563826764705883, 0.8711275882352943, 0.5865148235294118], 
             UndirectedEdge[64, 162] -> 
             RGBColor[
              0.9925885588235295, 0.9893698823529412, 0.6392279705882354], 
             UndirectedEdge[57, 66] -> 
             RGBColor[0.7485252352941176, 0.803512, 0.9757730588235294], 
             UndirectedEdge[16, 137] -> 
             RGBColor[
              0.7652413235294118, 0.8055785882352942, 0.6828925882352941], 
             UndirectedEdge[44, 50] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[153, 167] -> 
             RGBColor[
              0.9615149705882353, 0.9680034705882353, 0.7981917058823533], 
             UndirectedEdge[165, 187] -> 
             RGBColor[
              0.7363957647058823, 0.7939972352941176, 0.9743607058823529], 
             UndirectedEdge[32, 83] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[6, 187] -> 
             RGBColor[
              0.8639895882352941, 0.8945547647058824, 0.9868444705882353], 
             UndirectedEdge[66, 141] -> 
             RGBColor[
              0.672697294117647, 0.7437244705882352, 0.9683612352941176], 
             UndirectedEdge[23, 87] -> 
             RGBColor[
              0.9711922647058824, 0.9516678823529412, 0.6495950294117647], 
             UndirectedEdge[85, 152] -> 
             RGBColor[
              0.8622999705882353, 0.8829346470588234, 0.691518294117647], 
             UndirectedEdge[26, 74] -> 
             RGBColor[
              0.8005095294117647, 0.8422099411764705, 0.8721353235294118], 
             UndirectedEdge[81, 172] -> 
             RGBColor[
              0.8961219117647059, 0.9153718235294118, 0.7385781176470589], 
             UndirectedEdge[54, 73] -> 
             RGBColor[
              0.7017465294117646, 0.7626651176470588, 0.9297907352941177], 
             UndirectedEdge[135, 165] -> 
             RGBColor[
              0.8118331176470587, 0.8536122352941176, 0.9688491470588235], 
             UndirectedEdge[46, 109] -> 
             RGBColor[
              0.6230712352941176, 0.6976727058823529, 0.9672578235294118], 
             UndirectedEdge[40, 171] -> 
             RGBColor[
              0.7965954117647058, 0.8405913529411765, 0.9370023823529412], 
             UndirectedEdge[113, 167] -> 
             RGBColor[
              0.9202292941176471, 0.6734588235294118, 0.3976469411764709], 
             UndirectedEdge[103, 162] -> 
             RGBColor[
              0.8642079999999999, 0.8924827058823528, 0.878134794117647], 
             UndirectedEdge[37, 119] -> 
             RGBColor[
              0.8344115588235292, 0.868494882352941, 0.8390862352941179], 
             UndirectedEdge[71, 184] -> 
             RGBColor[
              0.5820046470588235, 0.5053761470588234, 0.5857600588235294], 
             UndirectedEdge[107, 142] -> 
             RGBColor[
              0.4886372352941176, 0.5934276470588236, 0.9535244705882353], 
             UndirectedEdge[136, 143] -> 
             RGBColor[
              0.9394269411764705, 0.9541697647058823, 0.9813329117647058], 
             UndirectedEdge[3, 5] -> 
             RGBColor[
              0.9517352352941177, 0.8349509411764707, 0.37162073529411777`], 
             UndirectedEdge[24, 118] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117646, 0.9406145294117647], 
             UndirectedEdge[142, 185] -> 
             RGBColor[
              0.5422784705882353, 0.6392851176470589, 0.9571092941176471], 
             UndirectedEdge[3, 28] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588239], 
             UndirectedEdge[43, 49] -> 
             RGBColor[
              0.8676313529411763, 0.8972897058823528, 0.9872366470588235], 
             UndirectedEdge[19, 60] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[87, 110] -> 
             RGBColor[0.9806072647058823, 0.982418, 0.7719590882352945], 
             UndirectedEdge[107, 185] -> 
             RGBColor[0.4219168823529411, 0.5392610588235294, 0.948272], 
             UndirectedEdge[66, 81] -> 
             RGBColor[
              0.7040428823529412, 0.7682118823529411, 0.9714854705882352], 
             UndirectedEdge[63, 112] -> 
             RGBColor[
              0.5756386470588235, 0.666368411764706, 0.9597355294117647], 
             UndirectedEdge[59, 193] -> 
             RGBColor[
              0.8745242941176471, 0.9025870588235294, 0.9750976176470588], 
             UndirectedEdge[110, 180] -> 
             RGBColor[
              0.9946281176470588, 0.9909184117647059, 0.6566819411764712], 
             UndirectedEdge[21, 196] -> 
             RGBColor[0.7022251764705882, 0.765628, 0.972468294117647], 
             UndirectedEdge[24, 190] -> 
             RGBColor[
              0.9585192352941176, 0.968584294117647, 0.9551002941176471], 
             UndirectedEdge[44, 60] -> 
             RGBColor[
              0.7281049411764705, 0.7872294117647058, 0.9738253529411764], 
             UndirectedEdge[20, 106] -> 
             RGBColor[
              0.7687860882352942, 0.7239879411764708, 0.611874205882353], 
             UndirectedEdge[75, 139] -> 
             RGBColor[
              0.5836812941176471, 0.6681878235294118, 0.9626481764705882], 
             UndirectedEdge[4, 81] -> 
             RGBColor[
              0.8639895882352941, 0.8945547647058824, 0.9868444705882353], 
             UndirectedEdge[79, 197] -> 
             RGBColor[0.7022251764705882, 0.765628, 0.972468294117647], 
             UndirectedEdge[66, 90] -> 
             RGBColor[
              0.7880378235294117, 0.8342091176470587, 0.9514881470588235], 
             UndirectedEdge[14, 15] -> 
             RGBColor[
              0.8431787058823528, 0.8780996470588234, 0.9719733823529412], 
             UndirectedEdge[14, 48] -> 
             RGBColor[
              0.8745242941176471, 0.9025870588235294, 0.9750976176470588], 
             UndirectedEdge[122, 144] -> 
             RGBColor[
              0.7671493529411765, 0.8151266470588235, 0.869509088235294], 
             UndirectedEdge[80, 121] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764705, 0.8253373823529414], 
             UndirectedEdge[79, 170] -> 
             RGBColor[0.7022251764705882, 0.765628, 0.972468294117647], 
             UndirectedEdge[91, 95] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[48, 193] -> 
             RGBColor[
              0.8745242941176471, 0.9025870588235294, 0.9750976176470588], 
             UndirectedEdge[67, 162] -> 
             RGBColor[
              0.7671493529411765, 0.8151266470588235, 0.869509088235294], 
             UndirectedEdge[65, 87] -> 
             RGBColor[0.9479845294117646, 0.960552, 0.9668471470588236], 
             UndirectedEdge[98, 121] -> 
             RGBColor[
              0.8830818823529412, 0.908969294117647, 0.9606118529411765], 
             UndirectedEdge[161, 187] -> 
             RGBColor[
              0.8935965294117647, 0.9161608235294119, 0.9136925588235295], 
             UndirectedEdge[68, 122] -> 
             RGBColor[
              0.6947447647058823, 0.7601461176470587, 0.9711991176470588], 
             UndirectedEdge[19, 90] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[80, 168] -> 
             RGBColor[
              0.6816970882352941, 0.7426854705882353, 0.8273737058823531], 
             UndirectedEdge[109, 194] -> 
             RGBColor[
              0.6561843823529412, 0.7205876470588235, 0.8257480588235296], 
             UndirectedEdge[44, 57] -> 
             RGBColor[
              0.8676313529411763, 0.8972897058823528, 0.9872366470588235], 
             UndirectedEdge[109, 151] -> 
             RGBColor[0.6336059411764705, 0.705705, 0.9555109705882353], 
             UndirectedEdge[122, 138] -> 
             RGBColor[
              0.7677176764705882, 0.8135283529411765, 0.7268281764705883], 
             UndirectedEdge[138, 192] -> 
             RGBColor[
              0.7677176764705882, 0.8135283529411765, 0.7268281764705883], 
             UndirectedEdge[31, 46] -> 
             RGBColor[
              0.9604562352941176, 0.9685528235294117, 0.8874943235294117], 
             UndirectedEdge[101, 165] -> 
             RGBColor[
              0.8339211470588235, 0.8674459411764706, 0.7857079411764709], 
             UndirectedEdge[76, 105] -> 
             RGBColor[0.9083125000000001, 0.8340482352941179, 0.6252855], 
             UndirectedEdge[6, 199] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.744813411764706], 
             UndirectedEdge[83, 175] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[139, 182] -> 
             RGBColor[
              0.8830818823529412, 0.908969294117647, 0.9606118529411765], 
             UndirectedEdge[89, 149] -> 
             RGBColor[0.609194, 0.6902856470588234, 0.9642738235294117], 
             UndirectedEdge[53, 163] -> 
             RGBColor[
              0.7965954117647058, 0.8405913529411765, 0.9370023823529412], 
             UndirectedEdge[8, 96] -> 
             RGBColor[0.7686985, 0.8156262352941177, 0.8335847647058825], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.670682705882353, 0.7411285882352942, 0.9688592352941177], 
             UndirectedEdge[55, 191] -> 
             RGBColor[
              0.9478250882352941, 0.8647453529411766, 0.6010005882352942], 
             UndirectedEdge[122, 181] -> 
             RGBColor[
              0.5756386470588235, 0.666368411764706, 0.9597355294117647], 
             UndirectedEdge[130, 177] -> 
             RGBColor[
              0.9585482058823529, 0.9590047647058824, 0.7008778235294117], 
             UndirectedEdge[25, 131] -> 
             RGBColor[
              0.8462661470588235, 0.7260070588235293, 0.6067048529411765], 
             UndirectedEdge[19, 33] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[1, 89] -> 
             RGBColor[
              0.8639895882352941, 0.8945547647058824, 0.9868444705882353], 
             UndirectedEdge[123, 127] -> 
             RGBColor[
              0.8676313529411763, 0.8972897058823528, 0.9872366470588235], 
             UndirectedEdge[40, 173] -> 
             RGBColor[
              0.9655125588235294, 0.9073245294117648, 0.5938609411764706], 
             UndirectedEdge[17, 106] -> 
             RGBColor[0.7986015, 0.8326618823529411, 0.6855188235294116], 
             UndirectedEdge[51, 158] -> 
             RGBColor[
              0.9896552647058823, 0.9898491764705882, 0.810851617647059], 
             UndirectedEdge[20, 189] -> 
             RGBColor[
              0.735425911764706, 0.6969046470588238, 0.6092479705882353], 
             UndirectedEdge[48, 140] -> 
             RGBColor[
              0.8830818823529412, 0.908969294117647, 0.9606118529411765], 
             UndirectedEdge[11, 189] -> 
             RGBColor[
              0.5422784705882353, 0.6392851176470589, 0.957109294117647], 
             UndirectedEdge[40, 169] -> 
             RGBColor[
              0.8916394705882353, 0.9153515294117647, 0.9461260882352941], 
             UndirectedEdge[94, 167] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588242], 
             UndirectedEdge[81, 198] -> 
             RGBColor[
              0.8547002647058825, 0.7625511764705883, 0.613651794117647], 
             UndirectedEdge[34, 60] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[13, 101] -> 
             RGBColor[
              0.9930789705882352, 0.9904188235294118, 0.6926062647058827], 
             UndirectedEdge[31, 117] -> 
             RGBColor[
              0.9920202352941176, 0.9909681764705882, 0.7819088823529412], 
             UndirectedEdge[94, 105] -> 
             RGBColor[
              0.9613555294117648, 0.872196823529412, 0.43234514705882393`], 
             UndirectedEdge[125, 190] -> 
             RGBColor[
              0.7546776470588235, 0.8071258235294118, 0.9488619117647059], 
             UndirectedEdge[79, 119] -> 
             RGBColor[
              0.5746313529411764, 0.6650704705882352, 0.9599845294117647], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.9618459411764706, 0.8732457647058826, 0.48572344117647087`], 
             UndirectedEdge[156, 178] -> 
             RGBColor[
              0.9456517352941176, 0.9155019411764707, 0.6507774705882354], 
             UndirectedEdge[95, 131] -> 
             RGBColor[
              0.911168794117647, 0.7775897647058823, 0.6129401470588235], 
             UndirectedEdge[49, 133] -> 
             RGBColor[
              0.6281636470588234, 0.7034879411764705, 0.9669357647058823], 
             UndirectedEdge[34, 44] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[24, 125] -> 
             RGBColor[
              0.7461200588235294, 0.8007435882352941, 0.9633476764705882], 
             UndirectedEdge[95, 129] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[13, 16] -> 
             RGBColor[
              0.7671493529411765, 0.8151266470588235, 0.869509088235294], 
             UndirectedEdge[13, 199] -> 
             RGBColor[
              0.9925885588235295, 0.9893698823529412, 0.6392279705882354], 
             UndirectedEdge[121, 196] -> 
             RGBColor[0.9479845294117646, 0.960552, 0.9668471470588236], 
             UndirectedEdge[26, 40] -> 
             RGBColor[
              0.7965954117647058, 0.8405913529411765, 0.9370023823529412], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.7632352352941176, 0.8135080588235295, 0.9343761470588234], 
             UndirectedEdge[54, 126] -> 
             RGBColor[
              0.9861980882352941, 0.9798015294117647, 0.6601594411764705], 
             UndirectedEdge[16, 193] -> 
             RGBColor[
              0.7461200588235294, 0.8007435882352941, 0.9633476764705882], 
             UndirectedEdge[85, 150] -> 
             RGBColor[
              0.8122237058823528, 0.8537847647058823, 0.9817725294117647], 
             UndirectedEdge[26, 169] -> 
             RGBColor[
              0.7040428823529412, 0.7682118823529411, 0.9714854705882352], 
             UndirectedEdge[22, 79] -> 
             RGBColor[
              0.6683292647058823, 0.5236448823529413, 0.5788339705882354], 
             UndirectedEdge[27, 67] -> 
             RGBColor[
              0.3606027352941177, 0.4723395588235294, 0.9453051470588235], 
             UndirectedEdge[49, 95] -> 
             RGBColor[
              0.9084719411764706, 0.9298548823529411, 0.9911320588235294], 
             UndirectedEdge[147, 178] -> 
             RGBColor[
              0.9117558235294119, 0.6735188235294121, 0.2571431470588237], 
             UndirectedEdge[1, 136] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[65, 110] -> 
             RGBColor[
              0.9615149705882353, 0.9680034705882353, 0.7981917058823533], 
             UndirectedEdge[77, 106] -> 
             RGBColor[
              0.4168721470588235, 0.5235019117647058, 0.9492360294117648], 
             UndirectedEdge[25, 64] -> 
             RGBColor[
              0.8961219117647059, 0.9153718235294118, 0.7385781176470589], 
             UndirectedEdge[82, 187] -> 
             RGBColor[
              0.8916394705882353, 0.9153515294117647, 0.9461260882352941], 
             UndirectedEdge[167, 188] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588242], 
             UndirectedEdge[13, 137] -> 
             RGBColor[
              0.9901122058823529, 0.9814201176470587, 0.5952923823529411], 
             UndirectedEdge[37, 125] -> 
             RGBColor[0.7686985, 0.8156262352941177, 0.8335847647058825], 
             UndirectedEdge[105, 182] -> 
             RGBColor[
              0.9478250882352941, 0.8647453529411766, 0.6010005882352942], 
             UndirectedEdge[111, 116] -> 
             RGBColor[
              0.792009088235294, 0.7135763529411765, 0.6074033235294118], 
             UndirectedEdge[146, 179] -> 
             RGBColor[
              0.6026509411764704, 0.6813901176470587, 0.9653101176470589], 
             UndirectedEdge[9, 63] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[38, 120] -> 
             RGBColor[
              0.7990869411764707, 0.8429720588235294, 0.9806091764705882], 
             UndirectedEdge[71, 81] -> 
             RGBColor[
              0.5348254411764706, 0.6223411470588235, 0.9596643823529412], 
             UndirectedEdge[68, 181] -> 
             RGBColor[
              0.7281049411764705, 0.7872294117647058, 0.9738253529411764], 
             UndirectedEdge[114, 158] -> 
             RGBColor[
              0.6561843823529412, 0.7205876470588235, 0.8257480588235296], 
             UndirectedEdge[118, 149] -> 
             RGBColor[
              0.7017465294117646, 0.7626651176470588, 0.9297907352941177], 
             UndirectedEdge[87, 162] -> 
             RGBColor[
              0.9795485294117647, 0.9829673529411764, 0.861261705882353], 
             UndirectedEdge[88, 122] -> 
             RGBColor[
              0.5756386470588235, 0.666368411764706, 0.9597355294117647], 
             UndirectedEdge[49, 162] -> 
             RGBColor[
              0.9400359411764705, 0.9522702352941176, 0.8855466176470588], 
             UndirectedEdge[47, 116] -> 
             RGBColor[
              0.6413517058823528, 0.7192370588235293, 0.9652369999999999], 
             UndirectedEdge[23, 95] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[54, 115] -> 
             RGBColor[
              0.9361218235294118, 0.9506516470588235, 0.9504136764705882], 
             UndirectedEdge[62, 105] -> 
             RGBColor[
              0.8638301470588237, 0.798748117647059, 0.620997911764706], 
             UndirectedEdge[13, 108] -> 
             RGBColor[
              0.8005095294117647, 0.8422099411764705, 0.8721353235294118], 
             UndirectedEdge[76, 182] -> 
             RGBColor[
              0.9275642352941176, 0.9442694117647058, 0.9648994411764706], 
             UndirectedEdge[117, 171] -> 
             RGBColor[
              0.8005095294117647, 0.8422099411764705, 0.8721353235294118], 
             UndirectedEdge[40, 46] -> 
             RGBColor[
              0.9565421176470588, 0.9669342352941177, 0.9523613823529411], 
             UndirectedEdge[19, 177] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[64, 87] -> 
             RGBColor[
              0.9801168529411765, 0.9813690588235294, 0.7185807941176472], 
             UndirectedEdge[62, 107] -> 
             RGBColor[
              0.5836812941176471, 0.6681878235294118, 0.9626481764705882], 
             UndirectedEdge[53, 148] -> 
             RGBColor[
              0.8015682647058824, 0.8416605882352941, 0.7828327058823532], 
             UndirectedEdge[76, 111] -> 
             RGBColor[
              0.8991826176470588, 0.7978512941176471, 0.6179393823529412], 
             UndirectedEdge[11, 48] -> 
             RGBColor[
              0.670682705882353, 0.7411285882352942, 0.9688592352941177], 
             UndirectedEdge[96, 111] -> 
             RGBColor[
              0.7262960294117647, 0.6607077058823531, 0.6019018529411765], 
             UndirectedEdge[168, 198] -> 
             RGBColor[
              0.6392946176470589, 0.5877669411764707, 0.595690794117647], 
             UndirectedEdge[118, 128] -> 
             RGBColor[
              0.9157015294117646, 0.9343690588235294, 0.9484659705882352], 
             UndirectedEdge[56, 129] -> 
             RGBColor[
              0.7040428823529412, 0.7682118823529411, 0.9714854705882352], 
             UndirectedEdge[53, 100] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[129, 143] -> 
             RGBColor[
              0.7794802352941176, 0.8278268823529411, 0.9659739117647059], 
             UndirectedEdge[18, 160] -> 
             RGBColor[
              0.7965954117647058, 0.8405913529411765, 0.9370023823529412], 
             UndirectedEdge[68, 111] -> 
             RGBColor[
              0.8787623235294117, 0.781568705882353, 0.6159916764705883], 
             UndirectedEdge[51, 166] -> 
             RGBColor[
              0.8916394705882353, 0.9153515294117647, 0.9461260882352941], 
             UndirectedEdge[107, 181] -> 
             RGBColor[
              0.4886372352941176, 0.5934276470588236, 0.9535244705882353], 
             UndirectedEdge[31, 173] -> 
             RGBColor[
              0.9694266764705883, 0.9089431176470588, 0.5289938823529412], 
             UndirectedEdge[135, 148] -> 
             RGBColor[
              0.9720496764705882, 0.9760357647058824, 0.7864448529411768], 
             UndirectedEdge[44, 177] -> 
             RGBColor[
              0.8880516470588234, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[80, 184] -> 
             RGBColor[
              0.9442819411764706, 0.8005047058823529, 0.4714303823529414], 
             UndirectedEdge[65, 162] -> 
             RGBColor[
              0.9604562352941176, 0.9685528235294117, 0.8874943235294117], 
             UndirectedEdge[5, 17] -> 
             RGBColor[
              0.9492588823529412, 0.8270011764705882, 0.32768514705882346`], 
             UndirectedEdge[44, 141] -> 
             RGBColor[
              0.7918034117647057, 0.8375021764705881, 0.9798248235294118], 
             UndirectedEdge[94, 174] -> 
             RGBColor[0.9806072647058823, 0.982418, 0.7719590882352945], 
             UndirectedEdge[161, 193] -> 
             RGBColor[
              0.9690338823529412, 0.9757758235294118, 0.9081810000000001], 
             UndirectedEdge[101, 124] -> 
             RGBColor[
              0.9720496764705882, 0.9760357647058824, 0.7864448529411768], 
             UndirectedEdge[106, 189] -> 
             RGBColor[
              0.5756386470588235, 0.666368411764706, 0.9597355294117647], 
             UndirectedEdge[2, 80] -> 
             RGBColor[
              0.9725400882352941, 0.9770847058823529, 0.8398231470588238], 
             UndirectedEdge[97, 102] -> 
             RGBColor[
              0.9062187647058824, 0.5630471764705882, 0.43713911764705904`], 
             UndirectedEdge[91, 136] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[59, 154] -> 
             RGBColor[
              0.8807490882352942, 0.8639192352941178, 0.6445421764705883], 
             UndirectedEdge[108, 162] -> 
             RGBColor[
              0.8005095294117647, 0.8422099411764705, 0.8721353235294118], 
             UndirectedEdge[146, 147] -> 
             RGBColor[
              0.5891753235294117, 0.4556895882352942, 0.5736235000000001], 
             UndirectedEdge[99, 156] -> 
             RGBColor[
              0.7355853529411764, 0.7927112941176471, 0.9750945294117647], 
             UndirectedEdge[143, 154] -> 
             RGBColor[
              0.9561864411764707, 0.9235342352941178, 0.6390306176470589], 
             UndirectedEdge[139, 145] -> 
             RGBColor[
              0.7990869411764707, 0.8429720588235294, 0.9806091764705882], 
             UndirectedEdge[104, 123] -> 
             RGBColor[
              0.8122237058823528, 0.8537847647058823, 0.9817725294117647], 
             UndirectedEdge[116, 126] -> 
             RGBColor[
              0.8309543823529411, 0.8584472352941175, 0.6883940588235293], 
             UndirectedEdge[17, 28] -> 
             RGBColor[
              0.9916613529411764, 0.9819197058823529, 0.5593680588235296], 
             UndirectedEdge[89, 118] -> 
             RGBColor[
              0.8916394705882353, 0.9153515294117647, 0.9461260882352941], 
             UndirectedEdge[123, 163] -> 
             RGBColor[
              0.9361218235294118, 0.9506516470588235, 0.9504136764705882], 
             UndirectedEdge[47, 157] -> 
             RGBColor[
              0.672697294117647, 0.7437244705882352, 0.9683612352941176], 
             UndirectedEdge[117, 151] -> 
             RGBColor[
              0.9709909411764706, 0.9765851176470588, 0.8757474705882353], 
             UndirectedEdge[69, 86] -> 
             RGBColor[
              0.9442819411764706, 0.8005047058823529, 0.47143038235294144`], 
             UndirectedEdge[73, 94] -> 
             RGBColor[
              0.7067193823529412, 0.7637343529411764, 0.7756210588235297], 
             UndirectedEdge[61, 174] -> 
             RGBColor[
              0.9275642352941176, 0.9442694117647058, 0.9648994411764706], 
             UndirectedEdge[175, 187] -> 
             RGBColor[
              0.8971027352941177, 0.9174697058823529, 0.8453347058823532], 
             UndirectedEdge[75, 134] -> 
             RGBColor[
              0.6782399117647058, 0.7326378235294118, 0.6766815294117646], 
             UndirectedEdge[38, 178] -> 
             RGBColor[
              0.8807490882352942, 0.8639192352941178, 0.6445421764705883], 
             UndirectedEdge[8, 179] -> 
             RGBColor[
              0.9415850882352941, 0.9527698235294118, 0.8496222941176472], 
             UndirectedEdge[29, 167] -> 
             RGBColor[
              0.9911219117647059, 0.9896095294117648, 0.7250397941176475], 
             UndirectedEdge[68, 185] -> 
             RGBColor[
              0.661384588235294, 0.7330628235294117, 0.9685728823529411], 
             UndirectedEdge[79, 118] -> 
             RGBColor[
              0.7298750588235294, 0.7864247647058824, 0.9317499117647059], 
             UndirectedEdge[171, 173] -> 
             RGBColor[
              0.7779159705882353, 0.7601848823529412, 0.6192203235294118], 
             UndirectedEdge[80, 166] -> 
             RGBColor[
              0.8971027352941177, 0.9174697058823529, 0.8453347058823532], 
             UndirectedEdge[109, 132] -> 
             RGBColor[
              0.2939070882352941, 0.4254590882352941, 0.9400777352941176], 
             UndirectedEdge[118, 197] -> 
             RGBColor[
              0.9565421176470588, 0.9669342352941177, 0.9523613823529411], 
             UndirectedEdge[111, 167] -> 
             RGBColor[
              0.9522256470588235, 0.8359998823529413, 0.42499902941176504`], 
             UndirectedEdge[113, 122] -> 
             RGBColor[
              0.6942996764705882, 0.4981666470588235, 0.5745497647058824], 
             UndirectedEdge[119, 190] -> 
             RGBColor[
              0.8203907058823527, 0.8599944705882352, 0.9543633823529412], 
             UndirectedEdge[19, 130] -> 
             RGBColor[
              0.9881551470588235, 0.9806108235294118, 0.6277259117647059], 
             UndirectedEdge[35, 167] -> 
             RGBColor[
              0.8966123235294119, 0.9164207647058824, 0.7919564117647062], 
             UndirectedEdge[102, 112] -> 
             RGBColor[0.7686985, 0.8156262352941177, 0.8335847647058825], 
             UndirectedEdge[134, 145] -> 
             RGBColor[
              0.8936455588235295, 0.9074220588235293, 0.6946425294117646], 
             UndirectedEdge[109, 150] -> 
             RGBColor[
              0.6026509411764704, 0.6813901176470587, 0.9653101176470589], 
             UndirectedEdge[147, 179] -> 
             RGBColor[
              0.8745760294117646, 0.6878717647058824, 0.5974977352941176], 
             UndirectedEdge[63, 102] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[62, 182] -> 
             RGBColor[
              0.8830818823529412, 0.908969294117647, 0.9606118529411765], 
             UndirectedEdge[8, 99] -> 
             RGBColor[0.7686985, 0.8156262352941177, 0.8335847647058825], 
             UndirectedEdge[60, 123] -> 
             RGBColor[0.7485252352941176, 0.803512, 0.9757730588235294], 
             UndirectedEdge[7, 97] -> 
             RGBColor[
              0.6797987352941177, 0.38670605882352943`, 0.5606636470588235], 
             UndirectedEdge[130, 163] -> 
             RGBColor[
              0.9861980882352941, 0.9798015294117647, 0.6601594411764705], 
             UndirectedEdge[127, 135] -> 
             RGBColor[0.8985863529411764, 0.9216045882352941, 0.9774375], 
             UndirectedEdge[37, 56] -> 
             RGBColor[
              0.8971027352941177, 0.9174697058823529, 0.8453347058823532], 
             UndirectedEdge[100, 148] -> 
             RGBColor[
              0.9946281176470588, 0.9909184117647059, 0.6566819411764712], 
             UndirectedEdge[53, 135] -> 
             RGBColor[
              0.7794802352941176, 0.8278268823529411, 0.9659739117647059], 
             UndirectedEdge[103, 154] -> 
             RGBColor[0.8494035, 0.8394318235294118, 0.6414179411764707], 
             UndirectedEdge[63, 140] -> 
             RGBColor[
              0.7880378235294117, 0.8342091176470587, 0.9514881470588235], 
             UndirectedEdge[8, 75] -> 
             RGBColor[
              0.6816970882352941, 0.7426854705882353, 0.8273737058823531], 
             UndirectedEdge[50, 53] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[1, 167] -> 
             RGBColor[
              0.9615149705882353, 0.9680034705882353, 0.7981917058823533], 
             UndirectedEdge[27, 119] -> 
             RGBColor[
              0.426315794117647, 0.5252082058823528, 0.9508066176470589], 
             UndirectedEdge[96, 126] -> 
             RGBColor[
              0.7652413235294118, 0.8055785882352942, 0.6828925882352941], 
             UndirectedEdge[102, 106] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[16, 176] -> 
             RGBColor[
              0.7097756764705883, 0.5874458823529412, 0.5882075588235294], 
             UndirectedEdge[40, 166] -> 
             RGBColor[
              0.8916394705882353, 0.9153515294117647, 0.9461260882352941], 
             UndirectedEdge[33, 90] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[13, 161] -> 
             RGBColor[
              0.9900631764705883, 0.9901588823529412, 0.814342411764706], 
             UndirectedEdge[11, 106] -> 
             RGBColor[
              0.5756386470588235, 0.666368411764706, 0.9597355294117647], 
             UndirectedEdge[88, 167] -> 
             RGBColor[
              0.8015682647058824, 0.8416605882352941, 0.7828327058823532], 
             UndirectedEdge[29, 159] -> 
             RGBColor[
              0.9861490588235293, 0.9885402941176471, 0.8792094705882354], 
             UndirectedEdge[156, 157] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[171, 183] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[100, 104] -> 
             RGBColor[
              0.8657571470588235, 0.892982294117647, 0.8422104705882355], 
             UndirectedEdge[108, 180] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[178, 179] -> 
             RGBColor[
              0.9252314411764706, 0.8992193529411765, 0.6488297647058825], 
             UndirectedEdge[150, 151] -> 
             RGBColor[
              0.9190066470588234, 0.9378871764705882, 0.9793852058823529], 
             UndirectedEdge[2, 121] -> 
             RGBColor[
              0.9585192352941176, 0.968584294117647, 0.9551002941176471], 
             UndirectedEdge[12, 14] -> 
             RGBColor[
              0.9394269411764705, 0.9541697647058823, 0.9813329117647058], 
             UndirectedEdge[43, 131] -> 
             RGBColor[
              0.8703282058823529, 0.7450245882352939, 0.6090447352941176], 
             UndirectedEdge[75, 76] -> 
             RGBColor[
              0.6281636470588234, 0.7034879411764705, 0.9669357647058823], 
             UndirectedEdge[113, 138] -> 
             RGBColor[
              0.9197388823529411, 0.6724098823529412, 0.34426864705882365`], 
             UndirectedEdge[17, 20] -> 
             RGBColor[
              0.9583887647058824, 0.863198117647059, 0.33503126470588235`], 
             UndirectedEdge[86, 187] -> 
             RGBColor[
              0.8971027352941177, 0.9174697058823529, 0.8453347058823532], 
             UndirectedEdge[8, 185] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.830958529411765], 
             UndirectedEdge[4, 41] -> 
             RGBColor[
              0.9084719411764706, 0.9298548823529411, 0.9911320588235294], 
             UndirectedEdge[8, 107] -> 
             RGBColor[
              0.6816970882352941, 0.7426854705882353, 0.8273737058823531], 
             UndirectedEdge[149, 192] -> 
             RGBColor[
              0.48078976470588236`, 0.5884421764705883, 0.9525238823529412], 
             UndirectedEdge[11, 140] -> 
             RGBColor[
              0.7546776470588235, 0.8071258235294118, 0.9488619117647059], 
             UndirectedEdge[94, 153] -> 
             RGBColor[
              0.9615149705882353, 0.9680034705882353, 0.7981917058823533], 
             UndirectedEdge[56, 79] -> 
             RGBColor[0.6373225294117648, 0.7140452941176471, 0.966233], 
             UndirectedEdge[5, 15] -> 
             RGBColor[
              0.8233546764705881, 0.7380637647058823, 0.6105275588235295], 
             UndirectedEdge[79, 128] -> 
             RGBColor[
              0.661384588235294, 0.7330628235294117, 0.9685728823529411], 
             UndirectedEdge[109, 152] -> 
             RGBColor[0.652727205882353, 0.71054, 0.6750558823529411], 
             UndirectedEdge[118, 192] -> 
             RGBColor[
              0.7632352352941176, 0.8135080588235295, 0.9343761470588234], 
             UndirectedEdge[99, 107] -> 
             RGBColor[
              0.4552770588235294, 0.5663443529411765, 0.9508982352941175], 
             UndirectedEdge[3, 189] -> 
             RGBColor[
              0.7677176764705882, 0.8135283529411765, 0.7268281764705883], 
             UndirectedEdge[35, 138] -> 
             RGBColor[
              0.8961219117647059, 0.9153718235294118, 0.7385781176470589], 
             UndirectedEdge[12, 86] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[16, 127] -> 
             RGBColor[
              0.6947447647058823, 0.7601461176470587, 0.9711991176470588], 
             UndirectedEdge[37, 195] -> 
             RGBColor[
              0.9916613529411764, 0.9819197058823529, 0.5593680588235296], 
             UndirectedEdge[57, 71] -> 
             RGBColor[
              0.579307794117647, 0.6576412647058822, 0.9639519705882353], 
             UndirectedEdge[58, 73] -> 
             RGBColor[
              0.7056606470588236, 0.7642837058823528, 0.8649236764705883], 
             UndirectedEdge[35, 153] -> 
             RGBColor[
              0.8639895882352941, 0.8945547647058824, 0.9868444705882353], 
             UndirectedEdge[35, 122] -> 
             RGBColor[
              0.670682705882353, 0.7411285882352942, 0.9688592352941177], 
             UndirectedEdge[19, 44] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[181, 192] -> 
             RGBColor[
              0.5756386470588235, 0.666368411764706, 0.9597355294117647], 
             UndirectedEdge[119, 128] -> 
             RGBColor[
              0.7604578235294116, 0.8130147647058823, 0.9767005882352942], 
             UndirectedEdge[116, 153] -> 
             RGBColor[0.8012984117647057, 0.8455799411764705, 0.980596], 
             UndirectedEdge[186, 193] -> 
             RGBColor[
              0.7461200588235294, 0.8007435882352941, 0.9633476764705882], 
             UndirectedEdge[22, 119] -> 
             RGBColor[
              0.7674024999999999, 0.6035968235294118, 0.5869616764705883], 
             UndirectedEdge[85, 109] -> 
             RGBColor[
              0.5268229999999999, 0.621602588235294, 0.957898294117647], 
             UndirectedEdge[98, 99] -> 
             RGBColor[
              0.670682705882353, 0.7411285882352942, 0.9688592352941177], 
             UndirectedEdge[161, 175] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[54, 61] -> 
             RGBColor[
              0.9361218235294118, 0.9506516470588235, 0.9504136764705882], 
             UndirectedEdge[43, 154] -> 
             RGBColor[
              0.9048111470588236, 0.8829367647058824, 0.6468820588235296], 
             UndirectedEdge[87, 95] -> 
             RGBColor[0.9479845294117646, 0.960552, 0.9668471470588236], 
             UndirectedEdge[12, 108] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[15, 48] -> 
             RGBColor[
              0.7677413529411765, 0.8184846470588234, 0.9774849411764706], 
             UndirectedEdge[13, 187] -> 
             RGBColor[
              0.8955535882352942, 0.9169701176470588, 0.8812590294117647], 
             UndirectedEdge[15, 28] -> 
             RGBColor[
              0.8657571470588235, 0.892982294117647, 0.8422104705882355], 
             UndirectedEdge[52, 134] -> 
             RGBColor[
              0.9585482058823529, 0.9590047647058824, 0.7008778235294117], 
             UndirectedEdge[66, 172] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647059], 
             UndirectedEdge[101, 176] -> 
             RGBColor[
              0.9357052941176471, 0.7627380588235295, 0.411304735294118], 
             UndirectedEdge[119, 192] -> 
             RGBColor[
              0.6079915294117646, 0.6921537647058823, 0.9626107647058824], 
             UndirectedEdge[168, 184] -> 
             RGBColor[0.6308605, 0.5512228235294117, 0.5887438529411764], 
             UndirectedEdge[16, 175] -> 
             RGBColor[0.7686985, 0.8156262352941177, 0.8335847647058825], 
             UndirectedEdge[60, 104] -> 
             RGBColor[
              0.672697294117647, 0.7437244705882352, 0.9683612352941176], 
             UndirectedEdge[122, 136] -> 
             RGBColor[
              0.7355853529411764, 0.7927112941176471, 0.9750945294117647], 
             UndirectedEdge[107, 157] -> 
             RGBColor[
              0.5523357058823528, 0.6437004117647058, 0.9595239411764706], 
             UndirectedEdge[86, 110] -> 
             RGBColor[
              0.9946281176470588, 0.9909184117647059, 0.6566819411764712], 
             UndirectedEdge[5, 9] -> 
             RGBColor[
              0.9527160588235295, 0.8370488235294118, 0.478377323529412], 
             UndirectedEdge[3, 77] -> 
             RGBColor[
              0.6089511764705882, 0.6706618529411765, 0.7163286764705884], 
             UndirectedEdge[84, 139] -> 
             RGBColor[
              0.8916394705882353, 0.9153515294117647, 0.9461260882352941], 
             UndirectedEdge[96, 191] -> 
             RGBColor[
              0.7546776470588235, 0.8071258235294118, 0.9488619117647059], 
             UndirectedEdge[46, 151] -> 
             RGBColor[
              0.9394269411764705, 0.9541697647058823, 0.9813329117647058], 
             UndirectedEdge[72, 191] -> 
             RGBColor[
              0.9275642352941176, 0.9442694117647058, 0.9648994411764706], 
             UndirectedEdge[111, 185] -> 
             RGBColor[
              0.6929358529411764, 0.633624411764706, 0.5992756176470588], 
             UndirectedEdge[23, 129] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[101, 123] -> 
             RGBColor[
              0.9410946764705882, 0.9517208823529412, 0.7962440000000004], 
             UndirectedEdge[122, 142] -> 
             RGBColor[
              0.5756386470588235, 0.666368411764706, 0.9597355294117647], 
             UndirectedEdge[18, 174] -> 
             RGBColor[
              0.9756344117647058, 0.9813487647058823, 0.9261287647058823], 
             UndirectedEdge[123, 135] -> 
             RGBColor[
              0.9190066470588234, 0.9378871764705882, 0.9793852058823529], 
             UndirectedEdge[171, 178] -> 
             RGBColor[
              0.7857050294117647, 0.7891590588235295, 0.6354184705882354], 
             UndirectedEdge[81, 173] -> 
             RGBColor[
              0.8729600294117648, 0.8349450588235294, 0.6283440294117647], 
             UndirectedEdge[77, 102] -> 
             RGBColor[
              0.6099319999999999, 0.6727597352941176, 0.8230852647058826], 
             UndirectedEdge[31, 171] -> 
             RGBColor[
              0.8005095294117647, 0.8422099411764705, 0.8721353235294118], 
             UndirectedEdge[109, 196] -> 
             RGBColor[
              0.6230712352941177, 0.6976727058823529, 0.9672578235294118], 
             UndirectedEdge[18, 153] -> 
             RGBColor[
              0.9565421176470588, 0.9669342352941177, 0.9523613823529411], 
             UndirectedEdge[97, 140] -> 
             RGBColor[
              0.8921979117647059, 0.5545467647058824, 0.5524162647058823], 
             UndirectedEdge[116, 167] -> 
             RGBColor[
              0.8339211470588235, 0.8674459411764706, 0.7857079411764709], 
             UndirectedEdge[128, 190] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[94, 126] -> 
             RGBColor[
              0.9911709411764706, 0.9808707647058823, 0.5059897647058826], 
             UndirectedEdge[41, 198] -> 
             RGBColor[
              0.8991826176470588, 0.7978512941176471, 0.6179393823529412], 
             UndirectedEdge[11, 77] -> 
             RGBColor[
              0.3835119705882353, 0.4964186176470588, 0.946609794117647], 
             UndirectedEdge[29, 122] -> 
             RGBColor[
              0.765192294117647, 0.8143173529411765, 0.9019426176470589], 
             UndirectedEdge[84, 152] -> 
             RGBColor[
              0.9861980882352941, 0.9798015294117647, 0.6601594411764705], 
             UndirectedEdge[16, 64] -> 
             RGBColor[
              0.7677176764705882, 0.8135283529411765, 0.7268281764705883], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.9817559411764706, 0.9501206470588235, 0.3836257058823529], 
             UndirectedEdge[26, 121] -> 
             RGBColor[
              0.7880378235294117, 0.8342091176470587, 0.9514881470588235], 
             UndirectedEdge[40, 74] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352941, 0.8467759411764706], 
             UndirectedEdge[78, 91] -> 
             RGBColor[
              0.6816970882352942, 0.7426854705882353, 0.8273737058823531], 
             UndirectedEdge[139, 152] -> 
             RGBColor[
              0.8936455588235295, 0.9074220588235293, 0.6946425294117646], 
             UndirectedEdge[40, 196] -> 
             RGBColor[
              0.9565421176470588, 0.9669342352941177, 0.9523613823529411], 
             UndirectedEdge[6, 86] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[82, 180] -> 
             RGBColor[
              0.9896552647058823, 0.9898491764705882, 0.810851617647059], 
             UndirectedEdge[44, 90] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[4, 66] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[131, 143] -> 
             RGBColor[0.9217035, 0.7856220588235293, 0.6011932941176471], 
             UndirectedEdge[22, 144] -> 
             RGBColor[
              0.9265603235294118, 0.726569705882353, 0.4938600000000001], 
             UndirectedEdge[35, 160] -> 
             RGBColor[
              0.7040428823529412, 0.7682118823529411, 0.9714854705882352], 
             UndirectedEdge[76, 174] -> 
             RGBColor[
              0.9275642352941176, 0.9442694117647058, 0.9648994411764706], 
             UndirectedEdge[85, 196] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[6, 137] -> 
             RGBColor[
              0.9585482058823529, 0.9590047647058824, 0.7008778235294117], 
             UndirectedEdge[123, 177] -> 
             RGBColor[
              0.9084719411764706, 0.9298548823529411, 0.9911320588235294], 
             UndirectedEdge[29, 113] -> 
             RGBColor[
              0.9172134999999999, 0.6731988823529411, 0.5193830882352942], 
             UndirectedEdge[96, 174] -> 
             RGBColor[
              0.7546776470588235, 0.8071258235294118, 0.9488619117647059], 
             UndirectedEdge[74, 158] -> 
             RGBColor[
              0.9935693823529412, 0.9914677647058823, 0.7459845588235297], 
             UndirectedEdge[46, 121] -> 
             RGBColor[0.9479845294117646, 0.960552, 0.9668471470588236], 
             UndirectedEdge[32, 165] -> 
             RGBColor[0.8012984117647057, 0.8455799411764705, 0.980596], 
             UndirectedEdge[32, 148] -> 
             RGBColor[
              0.9615149705882353, 0.9680034705882353, 0.7981917058823533], 
             UndirectedEdge[27, 190] -> 
             RGBColor[
              0.5730019117647058, 0.6401802647058823, 0.9370577647058824], 
             UndirectedEdge[100, 123] -> 
             RGBColor[
              0.9415850882352941, 0.9527698235294118, 0.8496222941176472], 
             UndirectedEdge[45, 172] -> 
             RGBColor[
              0.9124884117647059, 0.6166795882352945, 0.33732558823529424`], 
             UndirectedEdge[85, 99] -> 
             RGBColor[0.6393371176470588, 0.7166411764705882, 0.965735], 
             UndirectedEdge[106, 112] -> 
             RGBColor[
              0.5756386470588235, 0.666368411764706, 0.9597355294117647], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.9275642352941176, 0.9442694117647058, 0.9648994411764706], 
             UndirectedEdge[43, 197] -> 
             RGBColor[
              0.8880516470588234, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[26, 164] -> 
             RGBColor[0.7485252352941176, 0.803512, 0.9757730588235294], 
             UndirectedEdge[100, 130] -> 
             RGBColor[
              0.9916613529411764, 0.9819197058823529, 0.5593680588235296], 
             UndirectedEdge[46, 196] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[156, 181] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[62, 96] -> 
             RGBColor[
              0.670682705882353, 0.7411285882352942, 0.9688592352941177], 
             UndirectedEdge[54, 58] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352941, 0.8467759411764706], 
             UndirectedEdge[179, 183] -> 
             RGBColor[
              0.9415850882352941, 0.9527698235294118, 0.8496222941176472], 
             UndirectedEdge[65, 198] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529413, 0.6198870882352941], 
             UndirectedEdge[4, 80] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[159, 197] -> 
             RGBColor[
              0.9565421176470588, 0.9669342352941177, 0.9523613823529411], 
             UndirectedEdge[78, 136] -> 
             RGBColor[
              0.6485839411764704, 0.7197705294117647, 0.9688834705882352], 
             UndirectedEdge[153, 188] -> 
             RGBColor[
              0.9615149705882353, 0.9680034705882353, 0.7981917058823533], 
             UndirectedEdge[35, 174] -> 
             RGBColor[
              0.8830818823529412, 0.908969294117647, 0.9606118529411765], 
             UndirectedEdge[82, 130] -> 
             RGBColor[
              0.9861980882352941, 0.9798015294117647, 0.6601594411764705], 
             UndirectedEdge[124, 176] -> 
             RGBColor[
              0.9136172647058823, 0.7489043529411765, 0.5944459411764706], 
             UndirectedEdge[6, 186] -> 
             RGBColor[
              0.7355853529411764, 0.7927112941176471, 0.9750945294117647], 
             UndirectedEdge[1, 144] -> 
             RGBColor[
              0.9604562352941176, 0.9685528235294117, 0.8874943235294117], 
             UndirectedEdge[43, 67] -> 
             RGBColor[
              0.6947447647058823, 0.7601461176470587, 0.9711991176470588], 
             UndirectedEdge[24, 119] -> 
             RGBColor[
              0.8118331176470587, 0.8536122352941176, 0.9688491470588235], 
             UndirectedEdge[93, 139] -> 
             RGBColor[
              0.7040428823529412, 0.7682118823529411, 0.9714854705882352], 
             UndirectedEdge[38, 146] -> 
             RGBColor[0.5581685882352941, 0.64609, 0.9610225294117647], 
             UndirectedEdge[110, 127] -> 
             RGBColor[
              0.9206743823529411, 0.9354382941176471, 0.7942962941176475], 
             UndirectedEdge[41, 81] -> 
             RGBColor[
              0.8435692941176471, 0.8782721764705882, 0.9848967647058824], 
             UndirectedEdge[85, 194] -> 
             RGBColor[
              0.8657571470588235, 0.892982294117647, 0.8422104705882355], 
             UndirectedEdge[52, 70] -> 
             RGBColor[
              0.9287327941176471, 0.850330823529412, 0.627233205882353], 
             UndirectedEdge[149, 170] -> 
             RGBColor[
              0.6740966470588234, 0.7418683529411765, 0.9705091176470588], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.7363957647058822, 0.7939972352941175, 0.9743607058823529], 
             UndirectedEdge[92, 155] -> 
             RGBColor[
              0.8015682647058824, 0.8416605882352941, 0.7828327058823532], 
             UndirectedEdge[57, 141] -> 
             RGBColor[
              0.8122237058823528, 0.8537847647058823, 0.9817725294117647], 
             UndirectedEdge[149, 159] -> 
             RGBColor[
              0.7017465294117646, 0.7626651176470588, 0.9297907352941177], 
             UndirectedEdge[142, 167] -> 
             RGBColor[
              0.8015682647058824, 0.8416605882352941, 0.7828327058823532], 
             UndirectedEdge[117, 173] -> 
             RGBColor[
              0.9694266764705883, 0.9089431176470588, 0.5289938823529412], 
             UndirectedEdge[99, 179] -> 
             RGBColor[
              0.7151650588235294, 0.7764287058823529, 0.9731468235294117], 
             UndirectedEdge[5, 11] -> 
             RGBColor[
              0.7262960294117647, 0.6607077058823531, 0.6019018529411764], 
             UndirectedEdge[29, 188] -> 
             RGBColor[
              0.9911219117647059, 0.9896095294117648, 0.7250397941176475], 
             UndirectedEdge[46, 178] -> 
             RGBColor[
              0.9456517352941176, 0.9155019411764707, 0.6507774705882354], 
             UndirectedEdge[101, 137] -> 
             RGBColor[
              0.9911709411764706, 0.9808707647058823, 0.5059897647058826], 
             UndirectedEdge[3, 20] -> 
             RGBColor[
              0.9608651176470588, 0.8711478823529415, 0.3789668529411766], 
             UndirectedEdge[186, 199] -> 
             RGBColor[
              0.7677176764705882, 0.8135283529411765, 0.7268281764705883], 
             UndirectedEdge[156, 179] -> 
             RGBColor[
              0.9084719411764706, 0.9298548823529411, 0.9911320588235294], 
             UndirectedEdge[67, 87] -> 
             RGBColor[
              0.7546776470588235, 0.8071258235294118, 0.9488619117647059], 
             UndirectedEdge[3, 10] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529413], 
             UndirectedEdge[55, 185] -> 
             RGBColor[
              0.7020657352941178, 0.6698213529411767, 0.6066217352941177], 
             UndirectedEdge[5, 28] -> 
             RGBColor[
              0.9527160588235295, 0.8370488235294118, 0.478377323529412], 
             UndirectedEdge[37, 170] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[49, 154] -> 
             RGBColor[
              0.9252314411764706, 0.8992193529411765, 0.6488297647058825], 
             UndirectedEdge[24, 89] -> 
             RGBColor[
              0.8745242941176471, 0.9025870588235294, 0.9750976176470588], 
             UndirectedEdge[73, 115] -> 
             RGBColor[
              0.6536763529411764, 0.7255857647058823, 0.9685614117647059], 
             UndirectedEdge[153, 174] -> 
             RGBColor[0.9479845294117646, 0.960552, 0.9668471470588236], 
             UndirectedEdge[119, 183] -> 
             RGBColor[
              0.8344115588235292, 0.868494882352941, 0.8390862352941179], 
             UndirectedEdge[4, 168] -> 
             RGBColor[
              0.6485839411764706, 0.7197705294117647, 0.9688834705882352], 
             UndirectedEdge[144, 181] -> 
             RGBColor[
              0.8005095294117647, 0.8422099411764705, 0.8721353235294118], 
             UndirectedEdge[53, 123] -> 
             RGBColor[0.7485252352941176, 0.803512, 0.9757730588235294], 
             UndirectedEdge[110, 162] -> 
             RGBColor[
              0.9930789705882352, 0.9904188235294118, 0.6926062647058827], 
             UndirectedEdge[127, 176] -> 
             RGBColor[
              0.8622419705882353, 0.7083068823529411, 0.6022973823529412], 
             UndirectedEdge[9, 102] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[27, 195] -> 
             RGBColor[
              0.5835655882352941, 0.6386330294117646, 0.6710884411764706], 
             UndirectedEdge[60, 130] -> 
             RGBColor[0.7986015, 0.8326618823529411, 0.6855188235294116], 
             UndirectedEdge[89, 122] -> 
             RGBColor[
              0.670682705882353, 0.7411285882352942, 0.9688592352941177], 
             UndirectedEdge[5, 106] -> 
             RGBColor[0.7596562058823529, 0.687791, 0.6045280882352941], 
             UndirectedEdge[83, 199] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588239], 
             UndirectedEdge[118, 125] -> 
             RGBColor[
              0.7632352352941176, 0.8135080588235295, 0.9343761470588234], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[5, 112] -> 
             RGBColor[
              0.7262960294117647, 0.6607077058823531, 0.6019018529411764], 
             UndirectedEdge[109, 146] -> 
             RGBColor[
              0.3172502352941176, 0.44920794117647056`, 0.9414358823529412], 
             UndirectedEdge[164, 184] -> 
             RGBColor[
              0.8907484999999999, 0.7613071764705881, 0.6109924411764706], 
             UndirectedEdge[51, 164] -> 
             RGBColor[
              0.9361218235294118, 0.9506516470588235, 0.9504136764705882], 
             UndirectedEdge[45, 168] -> 
             RGBColor[
              0.6000477941176471, 0.36949558823529427`, 0.5613956470588235], 
             UndirectedEdge[148, 165] -> 
             RGBColor[
              0.8339211470588235, 0.8674459411764706, 0.7857079411764709], 
             UndirectedEdge[166, 184] -> 
             RGBColor[
              0.8462661470588235, 0.7260070588235293, 0.6067048529411765], 
             UndirectedEdge[21, 132] -> 
             RGBColor[
              0.37306102941176467`, 0.4934143823529411, 0.945288205882353], 
             UndirectedEdge[96, 157] -> 
             RGBColor[0.6393371176470588, 0.7166411764705882, 0.965735], 
             UndirectedEdge[42, 102] -> 
             RGBColor[
              0.8344115588235292, 0.868494882352941, 0.8390862352941179], 
             UndirectedEdge[117, 120] -> 
             RGBColor[
              0.8955535882352942, 0.9169701176470588, 0.8812590294117647], 
             UndirectedEdge[25, 129] -> 
             RGBColor[
              0.7040428823529412, 0.7682118823529411, 0.9714854705882352], 
             UndirectedEdge[57, 90] -> 
             RGBColor[
              0.9275642352941176, 0.9442694117647058, 0.9648994411764706], 
             UndirectedEdge[51, 184] -> 
             RGBColor[
              0.9388186764705881, 0.7983865294117647, 0.5722217647058823], 
             UndirectedEdge[95, 103] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[47, 105] -> 
             RGBColor[
              0.7687860882352942, 0.7239879411764708, 0.611874205882353], 
             UndirectedEdge[127, 177] -> 
             RGBColor[
              0.8880516470588234, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[73, 153] -> 
             RGBColor[
              0.6740966470588234, 0.7418683529411765, 0.9705091176470588], 
             UndirectedEdge[137, 199] -> 
             RGBColor[
              0.9906805294117647, 0.9798218235294118, 0.45261147058823537`], 
             UndirectedEdge[138, 185] -> 
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764707], 
             UndirectedEdge[88, 136] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[55, 76] -> 
             RGBColor[0.9083125000000001, 0.8340482352941179, 0.6252855], 
             UndirectedEdge[135, 176] -> 
             RGBColor[
              0.9136172647058823, 0.7489043529411765, 0.5944459411764706], 
             UndirectedEdge[69, 123] -> 
             RGBColor[
              0.8907484999999999, 0.7613071764705881, 0.6109924411764706], 
             UndirectedEdge[2, 40] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117646, 0.9406145294117647], 
             UndirectedEdge[105, 174] -> 
             RGBColor[
              0.9478250882352941, 0.8647453529411766, 0.6010005882352942], 
             UndirectedEdge[89, 138] -> 
             RGBColor[
              0.8961219117647059, 0.9153718235294118, 0.7385781176470589], 
             UndirectedEdge[37, 128] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[88, 153] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[113, 197] -> 
             RGBColor[0.8876065588235293, 0.6515928235294117, 0.592535], 
             UndirectedEdge[31, 178] -> 
             RGBColor[
              0.9772157352941178, 0.9379172941176472, 0.5451920294117648], 
             UndirectedEdge[82, 177] -> 
             RGBColor[
              0.9565421176470588, 0.9669342352941177, 0.9523613823529411], 
             UndirectedEdge[87, 108] -> 
             RGBColor[
              0.7880378235294117, 0.8342091176470587, 0.9514881470588235], 
             UndirectedEdge[64, 86] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588239], 
             UndirectedEdge[116, 157] -> 
             RGBColor[
              0.7050501764705881, 0.7695098235294116, 0.9712364705882353], 
             UndirectedEdge[120, 168] -> 
             RGBColor[
              0.5836812941176471, 0.6681878235294118, 0.9626481764705882], 
             UndirectedEdge[18, 54] -> RGBColor[0.984192, 0.987731, 0.911643],
              UndirectedEdge[161, 176] -> 
             RGBColor[0.9326895, 0.7624781176470589, 0.5330408823529413], 
             UndirectedEdge[168, 172] -> 
             RGBColor[
              0.6807162647058824, 0.7405875882352941, 0.7206171176470589], 
             UndirectedEdge[142, 157] -> 
             RGBColor[
              0.672697294117647, 0.7437244705882352, 0.9683612352941176], 
             UndirectedEdge[121, 171] -> 
             RGBColor[
              0.7880378235294117, 0.8342091176470587, 0.9514881470588235], 
             UndirectedEdge[47, 94] -> 
             RGBColor[
              0.8015682647058824, 0.8416605882352941, 0.7828327058823532], 
             UndirectedEdge[70, 93] -> 
             RGBColor[
              0.7687860882352942, 0.7239879411764708, 0.611874205882353], 
             UndirectedEdge[32, 163] -> 
             RGBColor[
              0.9565421176470588, 0.9669342352941177, 0.9523613823529411], 
             UndirectedEdge[35, 142] -> 
             RGBColor[
              0.7040428823529412, 0.7682118823529411, 0.9714854705882352], 
             UndirectedEdge[12, 193] -> 
             RGBColor[
              0.9394269411764705, 0.9541697647058823, 0.9813329117647058], 
             UndirectedEdge[35, 94] -> 
             RGBColor[
              0.8966123235294119, 0.9164207647058824, 0.7919564117647062], 
             UndirectedEdge[116, 174] -> 
             RGBColor[
              0.8203907058823527, 0.8599944705882352, 0.9543633823529412], 
             UndirectedEdge[112, 140] -> 
             RGBColor[
              0.7546776470588235, 0.8071258235294118, 0.9488619117647059], 
             UndirectedEdge[86, 176] -> 
             RGBColor[0.9361957058823529, 0.763787, 0.4646830294117649], 
             UndirectedEdge[61, 73] -> 
             RGBColor[
              0.6536763529411764, 0.7255857647058823, 0.9685614117647059], 
             UndirectedEdge[33, 66] -> 
             RGBColor[
              0.7281049411764705, 0.7872294117647058, 0.9738253529411764], 
             UndirectedEdge[48, 106] -> 
             RGBColor[
              0.7040428823529412, 0.7682118823529411, 0.9714854705882352], 
             UndirectedEdge[86, 199] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588239], 
             UndirectedEdge[10, 59] -> 
             RGBColor[
              0.7677413529411765, 0.8184846470588234, 0.9774849411764706], 
             UndirectedEdge[1, 113] -> 
             RGBColor[0.8876065588235293, 0.6515928235294117, 0.592535], 
             UndirectedEdge[125, 128] -> 
             RGBColor[
              0.6947447647058823, 0.7601461176470587, 0.9711991176470588], 
             UndirectedEdge[53, 165] -> 
             RGBColor[
              0.6413517058823528, 0.7192370588235293, 0.9652369999999999], 
             UndirectedEdge[87, 143] -> 
             RGBColor[
              0.9585192352941176, 0.968584294117647, 0.9551002941176471], 
             UndirectedEdge[61, 105] -> 
             RGBColor[0.9083125000000001, 0.8340482352941179, 0.6252855], 
             UndirectedEdge[29, 47] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[24, 27] -> 
             RGBColor[
              0.5644443235294118, 0.6337980294117647, 0.9515435294117647], 
             UndirectedEdge[98, 117] -> 
             RGBColor[
              0.8955535882352942, 0.9169701176470588, 0.8812590294117647], 
             UndirectedEdge[1, 88] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[190, 195] -> 
             RGBColor[
              0.9776404999999999, 0.9734192941176469, 0.6746452058823529], 
             UndirectedEdge[4, 173] -> 
             RGBColor[
              0.9378626764705882, 0.8865277647058825, 0.6345793235294117], 
             UndirectedEdge[81, 164] -> 
             RGBColor[
              0.8435692941176471, 0.8782721764705882, 0.9848967647058824], 
             UndirectedEdge[82, 123] -> 
             RGBColor[
              0.9361218235294118, 0.9506516470588235, 0.9504136764705882], 
             UndirectedEdge[43, 87] -> 
             RGBColor[
              0.9071439411764706, 0.9279868235294118, 0.9629517352941177], 
             UndirectedEdge[38, 171] -> 
             RGBColor[
              0.7040428823529412, 0.7682118823529411, 0.9714854705882352], 
             UndirectedEdge[46, 85] -> 
             RGBColor[
              0.8326439999999999, 0.8700673529411764, 0.9837202352941177], 
             UndirectedEdge[64, 69] -> 
             RGBColor[
              0.9433011176470588, 0.7984068235294117, 0.36467379411764717`], 
             UndirectedEdge[60, 82] -> 
             RGBColor[
              0.7965954117647058, 0.8405913529411765, 0.9370023823529412], 
             UndirectedEdge[77, 189] -> 
             RGBColor[
              0.3835119705882353, 0.4964186176470588, 0.946609794117647], 
             UndirectedEdge[101, 187] -> 
             RGBColor[
              0.8966123235294119, 0.9164207647058824, 0.7919564117647062], 
             UndirectedEdge[64, 161] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000002], 
             UndirectedEdge[7, 160] -> 
             RGBColor[
              0.5756386470588235, 0.666368411764706, 0.9597355294117647], 
             UndirectedEdge[16, 83] -> 
             RGBColor[0.7686985, 0.8156262352941177, 0.8335847647058825], 
             UndirectedEdge[13, 124] -> 
             RGBColor[
              0.9709909411764706, 0.9765851176470588, 0.8757474705882353], 
             UndirectedEdge[46, 171] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[1, 197] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[26, 80] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[23, 43] -> 
             RGBColor[
              0.9112593823529411, 0.9046881764705883, 0.6719322352941177], 
             UndirectedEdge[13, 86] -> 
             RGBColor[
              0.9935693823529412, 0.9914677647058823, 0.7459845588235297], 
             UndirectedEdge[31, 146] -> 
             RGBColor[
              0.6546352352941176, 0.7200880588235294, 0.8616723823529412], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.8015682647058824, 0.8416605882352941, 0.7828327058823532], 
             UndirectedEdge[124, 127] -> 
             RGBColor[0.8985863529411764, 0.9216045882352941, 0.9774375], 
             UndirectedEdge[60, 163] -> 
             RGBColor[
              0.7965954117647058, 0.8405913529411765, 0.9370023823529412], 
             UndirectedEdge[4, 184] -> 
             RGBColor[
              0.911168794117647, 0.7775897647058823, 0.6129401470588235], 
             UndirectedEdge[144, 192] -> 
             RGBColor[
              0.7671493529411765, 0.8151266470588235, 0.869509088235294], 
             UndirectedEdge[38, 192] -> 
             RGBColor[
              0.670682705882353, 0.7411285882352942, 0.9688592352941177], 
             UndirectedEdge[49, 108] -> 
             RGBColor[0.7485252352941176, 0.803512, 0.9757730588235294], 
             UndirectedEdge[83, 165] -> 
             RGBColor[
              0.8344115588235292, 0.868494882352941, 0.8390862352941179], 
             UndirectedEdge[183, 192] -> 
             RGBColor[0.7686985, 0.8156262352941177, 0.8335847647058825], 
             UndirectedEdge[79, 159] -> 
             RGBColor[
              0.7298750588235294, 0.7864247647058824, 0.9317499117647059], 
             UndirectedEdge[81, 166] -> 
             RGBColor[
              0.7990869411764707, 0.8429720588235294, 0.9806091764705882], 
             UndirectedEdge[118, 119] -> 
             RGBColor[
              0.8289482941176469, 0.8663767058823528, 0.9398776176470588], 
             UndirectedEdge[47, 153] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[74, 184] -> 
             RGBColor[
              0.9427327941176471, 0.8000051176470587, 0.5073547058823529], 
             UndirectedEdge[149, 190] -> 
             RGBColor[0.6931889411764706, 0.756282882352941, 0.9442765], 
             UndirectedEdge[55, 139] -> 
             RGBColor[
              0.8638301470588237, 0.798748117647059, 0.620997911764706], 
             UndirectedEdge[22, 138] -> 
             RGBColor[
              0.9271286470588236, 0.724971411764706, 0.3511790882352942], 
             UndirectedEdge[113, 144] -> 
             RGBColor[
              0.9191705588235294, 0.6740081764705882, 0.4869495588235294], 
             UndirectedEdge[80, 172] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588239], 
             UndirectedEdge[8, 156] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[22, 118] -> 
             RGBColor[
              0.9226462058823529, 0.7249511176470589, 0.5587270588235295], 
             UndirectedEdge[100, 163] -> 
             RGBColor[
              0.9896552647058823, 0.9898491764705882, 0.810851617647059], 
             UndirectedEdge[12, 154] -> 
             RGBColor[
              0.9456517352941176, 0.9155019411764707, 0.6507774705882354], 
             UndirectedEdge[67, 129] -> 
             RGBColor[
              0.5756386470588235, 0.666368411764706, 0.9597355294117647], 
             UndirectedEdge[49, 129] -> 
             RGBColor[0.7485252352941176, 0.803512, 0.9757730588235294], 
             UndirectedEdge[127, 175] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[30, 198] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529413, 0.6198870882352941], 
             UndirectedEdge[5, 140] -> 
             RGBColor[
              0.938695205882353, 0.828548411764706, 0.5936544705882354], 
             UndirectedEdge[147, 156] -> 
             RGBColor[
              0.8949963235294117, 0.7041543529411766, 0.5994454411764706], 
             UndirectedEdge[122, 159] -> 
             RGBColor[
              0.7632352352941176, 0.8135080588235295, 0.9343761470588234], 
             UndirectedEdge[82, 110] -> 
             RGBColor[
              0.9891648529411765, 0.9888002352941176, 0.7574733235294121], 
             UndirectedEdge[83, 176] -> 
             RGBColor[0.9361957058823529, 0.763787, 0.4646830294117649], 
             UndirectedEdge[10, 77] -> 
             RGBColor[0.4805706176470587, 0.5737746764705881, 0.9552355], 
             UndirectedEdge[104, 130] -> 
             RGBColor[
              0.8622999705882353, 0.8829346470588234, 0.691518294117647], 
             UndirectedEdge[30, 66] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[85, 132] -> 
             RGBColor[
              0.5034798529411764, 0.5978537352941176, 0.9565401470588235], 
             UndirectedEdge[24, 195] -> 
             RGBColor[
              0.9690829117647058, 0.9670370588235293, 0.6891309705882352], 
             UndirectedEdge[50, 123] -> 
             RGBColor[
              0.9316796764705881, 0.9209707647058823, 0.6738799411764707], 
             UndirectedEdge[42, 153] -> 
             RGBColor[0.8012984117647057, 0.8455799411764705, 0.980596], 
             UndirectedEdge[127, 161] -> 
             RGBColor[
              0.9176585882352941, 0.9351783529411765, 0.9160324411764706], 
             UndirectedEdge[7, 18] -> 
             RGBColor[
              0.7632352352941176, 0.8135080588235295, 0.9343761470588234], 
             UndirectedEdge[65, 66] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[150, 152] -> 
             RGBColor[
              0.9381279117647059, 0.9427221764705882, 0.6989301176470588], 
             UndirectedEdge[25, 87] -> 
             RGBColor[
              0.8830818823529412, 0.908969294117647, 0.9606118529411765], 
             UndirectedEdge[69, 82] -> 
             RGBColor[
              0.9388186764705881, 0.7983865294117647, 0.5722217647058824], 
             UndirectedEdge[1, 159] -> 
             RGBColor[
              0.9565421176470588, 0.9669342352941177, 0.9523613823529411], 
             UndirectedEdge[23, 131] -> 
             RGBColor[
              0.9343765294117647, 0.7687056470588235, 0.2956880294117647], 
             UndirectedEdge[126, 160] -> 
             RGBColor[0.7986015, 0.8326618823529411, 0.6855188235294116], 
             UndirectedEdge[67, 131] -> 
             RGBColor[
              0.7178619117647058, 0.624163588235294, 0.5949549117647058], 
             UndirectedEdge[142, 174] -> 
             RGBColor[
              0.7880378235294117, 0.8342091176470587, 0.9514881470588235], 
             UndirectedEdge[22, 122] -> 
             RGBColor[
              0.7016894411764706, 0.5507281764705884, 0.5814602058823529], 
             UndirectedEdge[32, 176] -> 
             RGBColor[
              0.9030825588235294, 0.7408720588235294, 0.606192794117647], 
             UndirectedEdge[47, 160] -> 
             RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             UndirectedEdge[79, 125] -> 
             RGBColor[
              0.5089182941176471, 0.6122018235294118, 0.9544830588235294], 
             UndirectedEdge[47, 111] -> 
             RGBColor[0.7596562058823529, 0.687791, 0.6045280882352941], 
             UndirectedEdge[3, 186] -> 
             RGBColor[
              0.7677176764705882, 0.8135283529411765, 0.7268281764705883], 
             UndirectedEdge[105, 160] -> 
             RGBColor[
              0.7687860882352942, 0.7239879411764708, 0.611874205882353], 
             UndirectedEdge[9, 189] -> 
             RGBColor[0.7686985, 0.8156262352941177, 0.8335847647058825], 
             UndirectedEdge[64, 175] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588239], 
             UndirectedEdge[100, 165] -> 
             RGBColor[
              0.8344115588235292, 0.868494882352941, 0.8390862352941179], 
             UndirectedEdge[101, 161] -> 
             RGBColor[
              0.9911219117647059, 0.9896095294117648, 0.7250397941176475], 
             UndirectedEdge[123, 187] -> 
             RGBColor[
              0.8435692941176471, 0.8782721764705882, 0.9848967647058824], 
             UndirectedEdge[90, 198] -> 
             RGBColor[
              0.938695205882353, 0.828548411764706, 0.5936544705882353], 
             UndirectedEdge[146, 171] -> 
             RGBColor[
              0.46312452941176463`, 0.5713298235294118, 0.9518988235294117], 
             UndirectedEdge[62, 157] -> 
             RGBColor[
              0.7677413529411765, 0.8184846470588234, 0.9774849411764706], 
             UndirectedEdge[2, 164] -> 
             RGBColor[
              0.9190066470588234, 0.9378871764705882, 0.9793852058823529], 
             UndirectedEdge[94, 142] -> 
             RGBColor[
              0.8015682647058824, 0.8416605882352941, 0.7828327058823532], 
             UndirectedEdge[12, 175] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[23, 64] -> 
             RGBColor[
              0.9842322941176471, 0.958070411764706, 0.4275612941176472], 
             UndirectedEdge[73, 160] -> 
             RGBColor[
              0.5141499411764705, 0.6155254705882353, 0.9551501176470588], 
             UndirectedEdge[47, 142] -> 
             RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             UndirectedEdge[31, 120] -> 
             RGBColor[
              0.8955535882352942, 0.9169701176470588, 0.8812590294117647], 
             UndirectedEdge[9, 20] -> 
             RGBColor[
              0.9618459411764706, 0.8732457647058826, 0.48572344117647087`], 
             UndirectedEdge[174, 188] -> 
             RGBColor[0.9806072647058823, 0.982418, 0.7719590882352945], 
             UndirectedEdge[45, 173] -> 
             RGBColor[
              0.8893265294117647, 0.536252823529412, 0.22709150000000006`], 
             UndirectedEdge[139, 191] -> 
             RGBColor[
              0.8830818823529412, 0.908969294117647, 0.9606118529411765], 
             UndirectedEdge[24, 170] -> 
             RGBColor[
              0.9394269411764705, 0.9541697647058823, 0.9813329117647058], 
             UndirectedEdge[118, 195] -> 
             RGBColor[
              0.9861980882352941, 0.9798015294117647, 0.6601594411764705], 
             UndirectedEdge[124, 137] -> 
             RGBColor[
              0.9690829117647058, 0.9670370588235293, 0.6891309705882352], 
             UndirectedEdge[28, 63] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[7, 94] -> 
             RGBColor[
              0.7682080882352942, 0.8145772941176471, 0.7802064705882357], 
             UndirectedEdge[37, 190] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764705, 0.8253373823529414], 
             UndirectedEdge[31, 40] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352941, 0.8467759411764706], 
             UndirectedEdge[18, 73] -> 
             RGBColor[
              0.7017465294117646, 0.7626651176470588, 0.9297907352941177], 
             UndirectedEdge[170, 195] -> 
             RGBColor[
              0.9585482058823529, 0.9590047647058824, 0.7008778235294117], 
             UndirectedEdge[62, 191] -> 
             RGBColor[
              0.8830818823529412, 0.908969294117647, 0.9606118529411765], 
             UndirectedEdge[152, 194] -> 
             RGBColor[
              0.9916613529411764, 0.9819197058823529, 0.5593680588235296], 
             UndirectedEdge[24, 37] -> 
             RGBColor[
              0.9725400882352941, 0.9770847058823529, 0.8398231470588238], 
             UndirectedEdge[90, 177] -> 
             RGBColor[0.9479845294117646, 0.960552, 0.9668471470588236], 
             UndirectedEdge[94, 188] -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588242], 
             UndirectedEdge[103, 133] -> 
             RGBColor[
              0.5523357058823528, 0.6437004117647058, 0.9595239411764706], 
             UndirectedEdge[38, 179] -> 
             RGBColor[
              0.8435692941176471, 0.8782721764705882, 0.9848967647058824], 
             UndirectedEdge[54, 116] -> 
             RGBColor[
              0.8289482941176469, 0.8663767058823528, 0.9398776176470588], 
             UndirectedEdge[4, 198] -> 
             RGBColor[
              0.9196029117647059, 0.8141338823529413, 0.6198870882352941], 
             UndirectedEdge[31, 38] -> 
             RGBColor[
              0.8955535882352942, 0.9169701176470588, 0.8812590294117647], 
             UndirectedEdge[35, 47] -> 
             RGBColor[
              0.7040428823529412, 0.7682118823529411, 0.9714854705882352], 
             UndirectedEdge[132, 151] -> 
             RGBColor[
              0.6102627941176471, 0.6819561470588236, 0.9541528235294118], 
             UndirectedEdge[124, 135] -> 
             RGBColor[
              0.9499616470588235, 0.9622020588235294, 0.9695860588235294], 
             UndirectedEdge[32, 127] -> 
             RGBColor[
              0.8880516470588234, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[187, 199] -> 
             RGBColor[
              0.8961219117647059, 0.9153718235294118, 0.7385781176470589], 
             UndirectedEdge[2, 51] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117646, 0.9406145294117647], 
             UndirectedEdge[40, 117] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352941, 0.8467759411764706], 
             UndirectedEdge[9, 17] -> 
             RGBColor[
              0.9916613529411764, 0.9819197058823529, 0.5593680588235296], 
             UndirectedEdge[33, 57] -> 
             RGBColor[
              0.8676313529411763, 0.8972897058823528, 0.9872366470588235], 
             UndirectedEdge[124, 175] -> 
             RGBColor[
              0.9725400882352941, 0.9770847058823529, 0.8398231470588238], 
             UndirectedEdge[8, 147] -> 
             RGBColor[
              0.9281094705882353, 0.7270692941176471, 0.45793567647058847`], 
             UndirectedEdge[108, 110] -> 
             RGBColor[
              0.8015682647058824, 0.8416605882352941, 0.7828327058823532], 
             UndirectedEdge[68, 107] -> 
             RGBColor[
              0.6077433529411764, 0.6872053529411764, 0.9649880588235293], 
             UndirectedEdge[1, 138] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.744813411764706], 
             UndirectedEdge[94, 160] -> 
             RGBColor[
              0.8015682647058824, 0.8416605882352941, 0.7828327058823532], 
             UndirectedEdge[138, 142] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647059], 
             UndirectedEdge[6, 175] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[34, 104] -> 
             RGBColor[
              0.8622509411764705, 0.8916734117647058, 0.9105683235294119], 
             UndirectedEdge[15, 106] -> 
             RGBColor[
              0.672697294117647, 0.7437244705882352, 0.9683612352941176], 
             UndirectedEdge[61, 94] -> 
             RGBColor[
              0.9410946764705882, 0.9517208823529412, 0.7962440000000004], 
             UndirectedEdge[144, 159] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352941, 0.8467759411764706], 
             UndirectedEdge[83, 86] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[137, 176] -> 
             RGBColor[
              0.9327385294117647, 0.7537393529411764, 0.3139908529411764], 
             UndirectedEdge[143, 159] -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117646, 0.9406145294117647], 
             UndirectedEdge[24, 144] -> 
             RGBColor[
              0.9709909411764706, 0.9765851176470588, 0.8757474705882353], 
             UndirectedEdge[76, 96] -> 
             RGBColor[
              0.7151650588235294, 0.7764287058823529, 0.9731468235294117], 
             UndirectedEdge[98, 120] -> 
             RGBColor[
              0.7990869411764707, 0.8429720588235294, 0.9806091764705882], 
             UndirectedEdge[98, 183] -> 
             RGBColor[
              0.8971027352941177, 0.9174697058823529, 0.8453347058823532], 
             UndirectedEdge[55, 75] -> 
             RGBColor[
              0.6484245000000001, 0.6239638823529414, 0.6030369117647059], 
             UndirectedEdge[35, 68] -> 
             RGBColor[0.823149, 0.8619895882352941, 0.9829490588235295], 
             UndirectedEdge[25, 43] -> 
             RGBColor[0.823149, 0.8619895882352941, 0.9829490588235295], 
             UndirectedEdge[47, 174] -> 
             RGBColor[
              0.7880378235294117, 0.8342091176470587, 0.9514881470588235], 
             UndirectedEdge[29, 88] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[17, 140] -> 
             RGBColor[
              0.9776404999999999, 0.9734192941176469, 0.6746452058823529], 
             UndirectedEdge[41, 90] -> 
             RGBColor[
              0.9275642352941176, 0.9442694117647058, 0.9648994411764706], 
             UndirectedEdge[151, 196] -> 
             RGBColor[
              0.9394269411764705, 0.9541697647058823, 0.9813329117647058], 
             UndirectedEdge[88, 94] -> 
             RGBColor[
              0.8015682647058824, 0.8416605882352941, 0.7828327058823532], 
             UndirectedEdge[57, 198] -> 
             RGBColor[
              0.8991826176470588, 0.7978512941176471, 0.6179393823529412], 
             UndirectedEdge[71, 164] -> 
             RGBColor[
              0.579307794117647, 0.6576412647058822, 0.9639519705882353], 
             UndirectedEdge[95, 154] -> 
             RGBColor[
              0.9456517352941176, 0.9155019411764707, 0.6507774705882354], 
             UndirectedEdge[69, 90] -> 
             RGBColor[
              0.9302610882352941, 0.792004294117647, 0.5867075294117647], 
             UndirectedEdge[175, 176] -> 
             RGBColor[0.9361957058823529, 0.763787, 0.4646830294117649], 
             UndirectedEdge[58, 115] -> 
             RGBColor[
              0.9400359411764705, 0.9522702352941176, 0.8855466176470588], 
             UndirectedEdge[42, 88] -> 
             RGBColor[
              0.6413517058823528, 0.7192370588235293, 0.9652369999999999], 
             UndirectedEdge[72, 134] -> 
             RGBColor[
              0.9381279117647059, 0.9427221764705882, 0.6989301176470588], 
             UndirectedEdge[25, 49] -> 
             RGBColor[
              0.8435692941176471, 0.8782721764705882, 0.9848967647058824], 
             UndirectedEdge[23, 103] -> 
             RGBColor[
              0.8558517352941175, 0.8611832352941176, 0.6664681176470588], 
             UndirectedEdge[79, 192] -> 
             RGBColor[
              0.5089182941176471, 0.6122018235294118, 0.9544830588235294], 
             UndirectedEdge[89, 170] -> 
             RGBColor[
              0.8639895882352941, 0.8945547647058824, 0.9868444705882353], 
             UndirectedEdge[41, 57] -> 
             RGBColor[
              0.8880516470588234, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[10, 14] -> 
             RGBColor[
              0.8431787058823528, 0.8780996470588234, 0.9719733823529412], 
             UndirectedEdge[6, 59] -> 
             RGBColor[
              0.8639895882352941, 0.8945547647058824, 0.9868444705882353], 
             UndirectedEdge[120, 183] -> 
             RGBColor[
              0.8971027352941177, 0.9174697058823529, 0.8453347058823532], 
             UndirectedEdge[8, 194] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[63, 106] -> 
             RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             UndirectedEdge[129, 131] -> 
             RGBColor[
              0.751222088235294, 0.6512468823529411, 0.5975811470588235], 
             UndirectedEdge[22, 38] -> 
             RGBColor[
              0.8300936764705883, 0.6525716470588236, 0.5932101470588236], 
             UndirectedEdge[38, 117] -> 
             RGBColor[
              0.8955535882352942, 0.9169701176470588, 0.8812590294117647], 
             UndirectedEdge[136, 159] -> 
             RGBColor[
              0.9565421176470588, 0.9669342352941177, 0.9523613823529411], 
             UndirectedEdge[158, 166] -> 
             RGBColor[
              0.8971027352941177, 0.9174697058823529, 0.8453347058823532], 
             UndirectedEdge[75, 96] -> 
             RGBColor[
              0.4552770588235294, 0.5663443529411765, 0.9508982352941175], 
             UndirectedEdge[118, 170] -> 
             RGBColor[
              0.9565421176470588, 0.9669342352941177, 0.9523613823529411], 
             UndirectedEdge[7, 58] -> 
             RGBColor[
              0.7671493529411765, 0.8151266470588235, 0.869509088235294], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.6281636470588234, 0.7034879411764705, 0.9669357647058823], 
             UndirectedEdge[65, 180] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[151, 171] -> 
             RGBColor[
              0.7794802352941176, 0.8278268823529411, 0.9659739117647059], 
             UndirectedEdge[37, 118] -> 
             RGBColor[
              0.9896552647058823, 0.9898491764705882, 0.810851617647059], 
             UndirectedEdge[7, 47] -> 
             RGBColor[
              0.5756386470588235, 0.666368411764706, 0.9597355294117647], 
             UndirectedEdge[46, 99] -> 
             RGBColor[
              0.7355853529411764, 0.7927112941176471, 0.9750945294117647], 
             UndirectedEdge[195, 197] -> 
             RGBColor[
              0.9585482058823529, 0.9590047647058824, 0.7008778235294117], 
             UndirectedEdge[5, 63] -> 
             RGBColor[0.7596562058823529, 0.687791, 0.6045280882352941], 
             UndirectedEdge[11, 63] -> 
             RGBColor[
              0.5756386470588235, 0.666368411764706, 0.9597355294117647], 
             UndirectedEdge[10, 193] -> 
             RGBColor[
              0.8431787058823528, 0.8780996470588234, 0.9719733823529412], 
             UndirectedEdge[99, 147] -> 
             RGBColor[
              0.7016894411764706, 0.5507281764705884, 0.5814602058823529], 
             UndirectedEdge[9, 77] -> 
             RGBColor[
              0.6099319999999999, 0.6727597352941176, 0.8230852647058826], 
             UndirectedEdge[43, 103] -> 
             RGBColor[
              0.7918034117647057, 0.8375021764705881, 0.9798248235294118], 
             UndirectedEdge[54, 174] -> 
             RGBColor[
              0.9756344117647058, 0.9813487647058823, 0.9261287647058823], 
             UndirectedEdge[149, 197] -> 
             RGBColor[
              0.6740966470588234, 0.7418683529411765, 0.9705091176470588], 
             UndirectedEdge[87, 180] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764705, 0.8253373823529414], 
             UndirectedEdge[134, 191] -> 
             RGBColor[
              0.9776404999999999, 0.9734192941176469, 0.6746452058823529], 
             UndirectedEdge[65, 131] -> 
             RGBColor[
              0.911168794117647, 0.7775897647058823, 0.6129401470588235], 
             UndirectedEdge[107, 147] -> 
             RGBColor[
              0.6146880294117647, 0.47778741176470596`, 0.5752491470588235], 
             UndirectedEdge[50, 82] -> 
             RGBColor[
              0.9797498529411764, 0.9580501176470588, 0.6351092647058824], 
             UndirectedEdge[30, 162] -> 
             RGBColor[
              0.9604562352941176, 0.9685528235294117, 0.8874943235294117], 
             UndirectedEdge[51, 74] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352941, 0.8467759411764706], 
             UndirectedEdge[12, 161] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[78, 113] -> 
             RGBColor[
              0.6072982647058823, 0.4252258823529411, 0.5683387058823529], 
             UndirectedEdge[131, 133] -> 
             RGBColor[
              0.6308604999999999, 0.5512228235294117, 0.5887438529411765], 
             UndirectedEdge[35, 188] -> 
             RGBColor[
              0.8966123235294119, 0.9164207647058824, 0.7919564117647062], 
             UndirectedEdge[181, 185] -> 
             RGBColor[
              0.5422784705882353, 0.6392851176470589, 0.9571092941176471], 
             UndirectedEdge[111, 188] -> 
             RGBColor[
              0.9522256470588235, 0.8359998823529413, 0.42499902941176504`], 
             UndirectedEdge[41, 184] -> 
             RGBColor[
              0.8907484999999999, 0.7613071764705881, 0.6109924411764706], 
             UndirectedEdge[135, 187] -> 
             RGBColor[
              0.8745242941176471, 0.9025870588235294, 0.9750976176470588], 
             UndirectedEdge[51, 71] -> 
             RGBColor[
              0.6273779705882352, 0.6947206176470588, 0.925181294117647], 
             UndirectedEdge[9, 11] -> 
             RGBColor[0.7686985, 0.8156262352941177, 0.8335847647058825], 
             UndirectedEdge[26, 158] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[101, 199] -> 
             RGBColor[
              0.9936472941176471, 0.9888205294117648, 0.549925352941177], 
             UndirectedEdge[84, 194] -> 
             RGBColor[
              0.9896552647058823, 0.9898491764705882, 0.810851617647059], 
             UndirectedEdge[6, 176] -> 
             RGBColor[
              0.9030825588235294, 0.7408720588235294, 0.606192794117647], 
             UndirectedEdge[18, 116] -> 
             RGBColor[
              0.8289482941176469, 0.8663767058823528, 0.9398776176470588], 
             UndirectedEdge[98, 179] -> 
             RGBColor[
              0.8435692941176471, 0.8782721764705882, 0.9848967647058824], 
             UndirectedEdge[116, 142] -> 
             RGBColor[
              0.6413517058823528, 0.7192370588235293, 0.9652369999999999], 
             UndirectedEdge[77, 112] -> 
             RGBColor[
              0.3835119705882353, 0.4964186176470588, 0.946609794117647], 
             UndirectedEdge[56, 190] -> 
             RGBColor[
              0.8830818823529412, 0.908969294117647, 0.9606118529411765], 
             UndirectedEdge[76, 126] -> 
             RGBColor[
              0.9381279117647059, 0.9427221764705882, 0.6989301176470588], 
             UndirectedEdge[168, 173] -> 
             RGBColor[
              0.6575543823529413, 0.6601608235294119, 0.6103830294117647], 
             UndirectedEdge[158, 164] -> 
             RGBColor[
              0.9415850882352941, 0.9527698235294118, 0.8496222941176472], 
             UndirectedEdge[46, 146] -> 
             RGBColor[
              0.6230712352941176, 0.6976727058823529, 0.9672578235294118], 
             UndirectedEdge[23, 25] -> 
             RGBColor[
              0.8871973235294118, 0.8856706470588236, 0.6695923529411765], 
             UndirectedEdge[9, 28] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.7040428823529412, 0.7682118823529411, 0.9714854705882352], 
             UndirectedEdge[103, 129] -> 
             RGBColor[
              0.672697294117647, 0.7437244705882352, 0.9683612352941176], 
             UndirectedEdge[5, 48] -> 
             RGBColor[
              0.8547002647058825, 0.7625511764705883, 0.6136517941176471], 
             UndirectedEdge[36, 169] -> 
             RGBColor[
              0.8639895882352941, 0.8945547647058824, 0.9868444705882353], 
             UndirectedEdge[159, 170] -> 
             RGBColor[
              0.9565421176470588, 0.9669342352941177, 0.9523613823529411], 
             UndirectedEdge[86, 175] -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             UndirectedEdge[9, 97] -> 
             RGBColor[
              0.9062187647058824, 0.5630471764705882, 0.43713911764705904`], 
             UndirectedEdge[7, 88] -> 
             RGBColor[
              0.5756386470588235, 0.666368411764706, 0.9597355294117647], 
             UndirectedEdge[5, 77] -> 
             RGBColor[
              0.5675295294117647, 0.5178412058823529, 0.5914023529411765], 
             UndirectedEdge[103, 131] -> 
             RGBColor[
              0.8149205588235293, 0.7015196470588234, 0.6035806176470588], 
             UndirectedEdge[15, 193] -> 
             RGBColor[
              0.8431787058823528, 0.8780996470588234, 0.9719733823529412], 
             UndirectedEdge[167, 181] -> 
             RGBColor[
              0.8015682647058824, 0.8416605882352941, 0.7828327058823532], 
             UndirectedEdge[99, 146] -> 
             RGBColor[
              0.42976435294117643`, 0.5442465294117647, 0.9492725882352941], 
             UndirectedEdge[163, 177] -> 
             RGBColor[
              0.9565421176470588, 0.9669342352941177, 0.9523613823529411], 
             UndirectedEdge[76, 116] -> 
             RGBColor[
              0.7808781176470587, 0.8292973529411763, 0.9786482941176471], 
             UndirectedEdge[15, 59] -> 
             RGBColor[
              0.7677413529411765, 0.8184846470588234, 0.9774849411764706], 
             UndirectedEdge[36, 151] -> 
             RGBColor[
              0.9394269411764705, 0.9541697647058823, 0.9813329117647058], 
             UndirectedEdge[38, 98] -> 
             RGBColor[
              0.7990869411764707, 0.8429720588235294, 0.9806091764705882], 
             UndirectedEdge[70, 139] -> 
             RGBColor[
              0.8638301470588237, 0.798748117647059, 0.620997911764706], 
             UndirectedEdge[56, 195] -> 
             RGBColor[
              0.8936455588235295, 0.9074220588235293, 0.6946425294117646], 
             UndirectedEdge[66, 168] -> 
             RGBColor[
              0.4886372352941176, 0.5934276470588236, 0.9535244705882353], 
             UndirectedEdge[6, 161] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[56, 118] -> 
             RGBColor[
              0.8916394705882353, 0.9153515294117647, 0.9461260882352941], 
             UndirectedEdge[46, 117] -> 
             RGBColor[
              0.9604562352941176, 0.9685528235294117, 0.8874943235294117], 
             UndirectedEdge[79, 89] -> 
             RGBColor[0.6373225294117648, 0.7140452941176471, 0.966233], 
             UndirectedEdge[102, 140] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764705, 0.8253373823529414], 
             UndirectedEdge[32, 130] -> 
             RGBColor[
              0.9585482058823529, 0.9590047647058824, 0.7008778235294117], 
             UndirectedEdge[105, 126] -> 
             RGBColor[
              0.9583887647058824, 0.863198117647059, 0.33503126470588235`], 
             UndirectedEdge[86, 124] -> 
             RGBColor[
              0.9725400882352941, 0.9770847058823529, 0.8398231470588238], 
             UndirectedEdge[41, 168] -> 
             RGBColor[
              0.6281636470588234, 0.7034879411764705, 0.9669357647058823], 
             UndirectedEdge[43, 143] -> 
             RGBColor[0.8985863529411764, 0.9216045882352941, 0.9774375], 
             UndirectedEdge[56, 197] -> 
             RGBColor[
              0.8639895882352941, 0.8945547647058824, 0.9868444705882353], 
             UndirectedEdge[47, 73] -> 
             RGBColor[
              0.5141499411764705, 0.6155254705882353, 0.9551501176470588], 
             UndirectedEdge[23, 108] -> 
             RGBColor[
              0.7921532647058823, 0.8109104705882353, 0.6604686470588235], 
             UndirectedEdge[97, 155] -> 
             RGBColor[
              0.7131589117647059, 0.41378935294117647`, 0.5632898823529412], 
             UndirectedEdge[86, 161] -> 
             RGBColor[
              0.9916123235294118, 0.9906584705882353, 0.7784180882352945], 
             UndirectedEdge[88, 188] -> 
             RGBColor[
              0.8015682647058824, 0.8416605882352941, 0.7828327058823532], 
             UndirectedEdge[136, 197] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[65, 69] -> 
             RGBColor[
              0.911168794117647, 0.7775897647058823, 0.6129401470588235], 
             UndirectedEdge[23, 67] -> 
             RGBColor[
              0.7587930882352941, 0.7838271764705883, 0.6578424117647059], 
             UndirectedEdge[31, 121] -> 
             RGBColor[
              0.9795485294117647, 0.9829673529411764, 0.861261705882353], 
             UndirectedEdge[52, 145] -> 
             RGBColor[
              0.8639895882352941, 0.8945547647058824, 0.9868444705882353], 
             UndirectedEdge[12, 87] -> 
             RGBColor[0.9479845294117646, 0.960552, 0.9668471470588236], 
             UndirectedEdge[128, 192] -> 
             RGBColor[
              0.6947447647058823, 0.7601461176470587, 0.9711991176470588], 
             UndirectedEdge[78, 95] -> 
             RGBColor[
              0.6485839411764704, 0.7197705294117647, 0.9688834705882352], 
             UndirectedEdge[123, 165] -> 
             RGBColor[
              0.7808781176470587, 0.8292973529411763, 0.9786482941176471], 
             UndirectedEdge[24, 56] -> 
             RGBColor[
              0.8745242941176471, 0.9025870588235294, 0.9750976176470588], 
             UndirectedEdge[50, 177] -> 
             RGBColor[
              0.9520999705882353, 0.9372533529411765, 0.6758276470588236], 
             UndirectedEdge[18, 58] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352941, 0.8467759411764706], 
             UndirectedEdge[96, 182] -> 
             RGBColor[
              0.7546776470588235, 0.8071258235294118, 0.9488619117647059], 
             UndirectedEdge[49, 131] -> 
             RGBColor[
              0.8907484999999999, 0.7613071764705881, 0.6109924411764706], 
             UndirectedEdge[28, 106] -> 
             RGBColor[
              0.8020586764705881, 0.8427095294117647, 0.8362110000000003], 
             UndirectedEdge[57, 81] -> 
             RGBColor[
              0.8435692941176471, 0.8782721764705882, 0.9848967647058824], 
             UndirectedEdge[7, 115] -> 
             RGBColor[
              0.7151650588235294, 0.7764287058823529, 0.9731468235294117], 
             UndirectedEdge[54, 94] -> 
             RGBColor[
              0.9891648529411765, 0.9888002352941176, 0.7574733235294121], 
             UndirectedEdge[138, 181] -> 
             RGBColor[
              0.8010778529411764, 0.8406116470588236, 0.7294544117647059], 
             UndirectedEdge[55, 182] -> 
             RGBColor[
              0.9478250882352941, 0.8647453529411766, 0.6010005882352942], 
             UndirectedEdge[17, 77] -> 
             RGBColor[
              0.6064748235294117, 0.662712088235294, 0.6723930882352941], 
             UndirectedEdge[144, 149] -> 
             RGBColor[
              0.7056606470588236, 0.7642837058823528, 0.8649236764705883], 
             UndirectedEdge[68, 179] -> 
             RGBColor[
              0.8676313529411763, 0.8972897058823528, 0.9872366470588235], 
             UndirectedEdge[103, 143] -> 
             RGBColor[
              0.8431787058823528, 0.8780996470588234, 0.9719733823529412], 
             UndirectedEdge[80, 173] -> 
             RGBColor[
              0.9709758235294118, 0.909442705882353, 0.49306955882352965`], 
             UndirectedEdge[161, 199] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000002], 
             UndirectedEdge[43, 133] -> 
             RGBColor[
              0.6077433529411764, 0.6872053529411764, 0.9649880588235293], 
             UndirectedEdge[6, 193] -> 
             RGBColor[
              0.9394269411764705, 0.9541697647058823, 0.9813329117647058], 
             UndirectedEdge[181, 188] -> 
             RGBColor[
              0.8015682647058824, 0.8416605882352941, 0.7828327058823532], 
             UndirectedEdge[120, 173] -> 
             RGBColor[
              0.8729600294117648, 0.8349450588235294, 0.6283440294117647], 
             UndirectedEdge[2, 158] -> 
             RGBColor[
              0.9725400882352941, 0.9770847058823529, 0.8398231470588238], 
             UndirectedEdge[95, 143] -> 
             RGBColor[
              0.9394269411764705, 0.9541697647058823, 0.9813329117647058], 
             UndirectedEdge[4, 172] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.744813411764706], 
             UndirectedEdge[89, 113] -> 
             RGBColor[
              0.8227039117647059, 0.6000101176470588, 0.5862997058823529], 
             UndirectedEdge[34, 90] -> 
             RGBColor[
              0.9775914705882353, 0.9821580588235295, 0.8936952352941178], 
             UndirectedEdge[28, 48] -> 
             RGBColor[
              0.8971027352941177, 0.9174697058823529, 0.8453347058823532], 
             UndirectedEdge[5, 189] -> 
             RGBColor[
              0.7262960294117647, 0.6607077058823531, 0.6019018529411764], 
             UndirectedEdge[8, 55] -> 
             RGBColor[
              0.9618459411764706, 0.8732457647058826, 0.48572344117647087`], 
             UndirectedEdge[29, 138] -> 
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000002], 
             UndirectedEdge[8, 68] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[176, 187] -> 
             RGBColor[0.838179911764706, 0.6892893529411765, 0.5999575], 
             UndirectedEdge[65, 133] -> 
             RGBColor[
              0.6485839411764706, 0.7197705294117647, 0.9688834705882352], 
             UndirectedEdge[68, 147] -> 
             RGBColor[
              0.8541557352941176, 0.6715891764705884, 0.5955500294117647], 
             UndirectedEdge[89, 192] -> 
             RGBColor[
              0.670682705882353, 0.7411285882352942, 0.9688592352941177], 
             UndirectedEdge[2, 74] -> 
             RGBColor[
              0.9709909411764706, 0.9765851176470588, 0.8757474705882353], 
             UndirectedEdge[156, 185] -> 
             RGBColor[0.7022251764705882, 0.765628, 0.972468294117647], 
             UndirectedEdge[126, 182] -> 
             RGBColor[
              0.9776404999999999, 0.9734192941176469, 0.6746452058823529], 
             UndirectedEdge[18, 188] -> 
             RGBColor[
              0.9891648529411765, 0.9888002352941176, 0.7574733235294121], 
             UndirectedEdge[68, 156] -> 
             RGBColor[
              0.8880516470588234, 0.913572294117647, 0.9891843529411765], 
             UndirectedEdge[29, 181] -> 
             RGBColor[
              0.7985524705882352, 0.8414006470588236, 0.9045688529411766], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.9584991764705881, 0.9677435294117647, 0.9199278529411765], 
             UndirectedEdge[30, 180] -> 
             RGBColor[
              0.9620053823529411, 0.9690524117647059, 0.8515700000000002], 
             UndirectedEdge[31, 196] -> 
             RGBColor[
              0.9604562352941176, 0.9685528235294117, 0.8874943235294117], 
             UndirectedEdge[193, 199] -> 
             RGBColor[
              0.9715592647058824, 0.9749868235294118, 0.7330665588235296], 
             UndirectedEdge[30, 110] -> 
             RGBColor[
              0.9615149705882353, 0.9680034705882353, 0.7981917058823533], 
             UndirectedEdge[12, 59] -> 
             RGBColor[
              0.8639895882352941, 0.8945547647058824, 0.9868444705882353], 
             UndirectedEdge[38, 156] -> 
             RGBColor[
              0.8639895882352941, 0.8945547647058824, 0.9868444705882353], 
             UndirectedEdge[72, 152] -> 
             RGBColor[
              0.9381279117647059, 0.9427221764705882, 0.6989301176470588], 
             UndirectedEdge[37, 79] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.830958529411765], 
             UndirectedEdge[170, 197] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[86, 127] -> 
             RGBColor[
              0.9211647941176471, 0.9364872352941176, 0.8476745882352943], 
             UndirectedEdge[69, 127] -> 
             RGBColor[
              0.8703282058823529, 0.7450245882352939, 0.6090447352941176], 
             UndirectedEdge[58, 61] -> 
             RGBColor[
              0.9400359411764705, 0.9522702352941176, 0.8855466176470588], 
             UndirectedEdge[11, 17] -> 
             RGBColor[
              0.7652413235294118, 0.8055785882352942, 0.6828925882352941], 
             UndirectedEdge[11, 15] -> 
             RGBColor[0.6393371176470588, 0.7166411764705882, 0.965735], 
             UndirectedEdge[111, 157] -> 
             RGBColor[
              0.8233546764705881, 0.7380637647058823, 0.6105275588235295], 
             UndirectedEdge[75, 191] -> 
             RGBColor[
              0.6676762352941177, 0.7341850588235294, 0.9426508529411765], 
             UndirectedEdge[98, 156] -> 
             RGBColor[
              0.8639895882352941, 0.8945547647058824, 0.9868444705882353], 
             UndirectedEdge[28, 140] -> 
             RGBColor[
              0.9810976764705882, 0.9834669411764705, 0.8253373823529414], 
             UndirectedEdge[105, 157] -> 
             RGBColor[
              0.8324845588235295, 0.7742607058823531, 0.6178736764705883], 
             UndirectedEdge[3, 15] -> 
             RGBColor[
              0.8647763235294117, 0.8908844117647059, 0.7354538823529413], 
             UndirectedEdge[55, 96] -> 
             RGBColor[
              0.735425911764706, 0.6969046470588238, 0.6092479705882353], 
             UndirectedEdge[6, 64] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.744813411764706], 
             UndirectedEdge[70, 134] -> 
             RGBColor[
              0.9583887647058824, 0.863198117647059, 0.33503126470588235`], 
             UndirectedEdge[106, 140] -> 
             RGBColor[
              0.7880378235294117, 0.8342091176470587, 0.9514881470588235], 
             UndirectedEdge[64, 154] -> 
             RGBColor[
              0.9777840588235295, 0.9363190000000001, 0.40251111764705905`], 
             UndirectedEdge[8, 157] -> 
             RGBColor[
              0.8657571470588235, 0.892982294117647, 0.8422104705882355], 
             UndirectedEdge[83, 124] -> 
             RGBColor[
              0.9725400882352941, 0.9770847058823529, 0.8398231470588238], 
             UndirectedEdge[22, 128] -> 
             RGBColor[
              0.8541557352941176, 0.6715891764705884, 0.5955500294117647], 
             UndirectedEdge[83, 135] -> 
             RGBColor[
              0.9725400882352941, 0.9770847058823529, 0.8398231470588238], 
             UndirectedEdge[62, 68] -> 
             RGBColor[0.823149, 0.8619895882352941, 0.9829490588235295], 
             UndirectedEdge[105, 116] -> 
             RGBColor[
              0.8011389705882352, 0.7497732941176471, 0.6147494411764707], 
             UndirectedEdge[93, 145] -> 
             RGBColor[
              0.7040428823529412, 0.7682118823529411, 0.9714854705882352], 
             UndirectedEdge[128, 195] -> 
             RGBColor[
              0.9177076176470588, 0.926439588235294, 0.6969824117647059], 
             UndirectedEdge[87, 154] -> 
             RGBColor[
              0.9647440294117647, 0.9299164705882355, 0.6245448529411766], 
             UndirectedEdge[138, 167] -> 
             RGBColor[
              0.9936472941176471, 0.9888205294117648, 0.549925352941177], 
             UndirectedEdge[179, 194] -> 
             RGBColor[
              0.9415850882352941, 0.9527698235294118, 0.8496222941176472], 
             UndirectedEdge[118, 144] -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352941, 0.8467759411764706], 
             UndirectedEdge[47, 188] -> 
             RGBColor[
              0.8015682647058824, 0.8416605882352941, 0.7828327058823532], 
             UndirectedEdge[11, 20] -> 
             RGBColor[
              0.735425911764706, 0.6969046470588238, 0.6092479705882353], 
             UndirectedEdge[124, 187] -> 
             RGBColor[
              0.8745242941176471, 0.9025870588235294, 0.9750976176470588], 
             UndirectedEdge[28, 189] -> 
             RGBColor[0.7686985, 0.8156262352941177, 0.8335847647058825], 
             UndirectedEdge[84, 93] -> 
             RGBColor[
              0.7965954117647058, 0.8405913529411765, 0.9370023823529412], 
             UndirectedEdge[18, 94] -> 
             RGBColor[
              0.9891648529411765, 0.9888002352941176, 0.7574733235294121], 
             UndirectedEdge[146, 156] -> 
             RGBColor[
              0.6230712352941177, 0.6976727058823529, 0.9672578235294118], 
             UndirectedEdge[2, 26] -> 
             RGBColor[
              0.7794802352941176, 0.8278268823529411, 0.9659739117647059], 
             UndirectedEdge[124, 161] -> 
             RGBColor[
              0.9690338823529412, 0.9757758235294118, 0.9081810000000001], 
             UndirectedEdge[25, 67] -> 
             RGBColor[
              0.670682705882353, 0.7411285882352942, 0.9688592352941177], 
             UndirectedEdge[15, 77] -> 
             RGBColor[0.4805706176470587, 0.5737746764705881, 0.9552355], 
             UndirectedEdge[23, 49] -> 
             RGBColor[
              0.9316796764705881, 0.9209707647058823, 0.6738799411764707], 
             UndirectedEdge[27, 37] -> 
             RGBColor[
              0.5870227647058823, 0.6486806764705881, 0.821780617647059], 
             UndirectedEdge[21, 36] -> 
             RGBColor[0.7022251764705882, 0.765628, 0.972468294117647], 
             UndirectedEdge[134, 139] -> 
             RGBColor[
              0.8936455588235295, 0.9074220588235293, 0.6946425294117646], 
             UndirectedEdge[13, 127] -> 
             RGBColor[
              0.9196156470588235, 0.9359876470588235, 0.8835989117647058], 
             UndirectedEdge[59, 186] -> 
             RGBColor[
              0.670682705882353, 0.7411285882352942, 0.9688592352941177], 
             UndirectedEdge[119, 149] -> 
             RGBColor[
              0.5465028235294116, 0.6413108235294116, 0.9580253529411764], 
             UndirectedEdge[41, 66] -> 
             RGBColor[0.7485252352941176, 0.803512, 0.9757730588235294], 
             UndirectedEdge[25, 103] -> 
             RGBColor[
              0.7677413529411765, 0.8184846470588234, 0.9774849411764706], 
             UndirectedEdge[164, 166] -> 
             RGBColor[
              0.8435692941176471, 0.8782721764705882, 0.9848967647058824], 
             UndirectedEdge[30, 90] -> 
             RGBColor[0.9479845294117646, 0.960552, 0.9668471470588236], 
             UndirectedEdge[75, 182] -> 
             RGBColor[
              0.6676762352941177, 0.7341850588235294, 0.9426508529411765], 
             UndirectedEdge[92, 97] -> 
             RGBColor[
              0.9057283529411765, 0.5619982352941177, 0.3837608235294121], 
             UndirectedEdge[18, 61] -> 
             RGBColor[
              0.9361218235294118, 0.9506516470588235, 0.9504136764705882], 
             UndirectedEdge[76, 191] -> 
             RGBColor[
              0.9275642352941176, 0.9442694117647058, 0.9648994411764706], 
             UndirectedEdge[129, 197] -> 
             RGBColor[
              0.7689455294117646, 0.8197945882352942, 0.9777207647058823], 
             UndirectedEdge[97, 112] -> 
             RGBColor[
              0.6797987352941177, 0.38670605882352943`, 0.5606636470588235], 
             UndirectedEdge[87, 131] -> 
             RGBColor[
              0.9302610882352941, 0.792004294117647, 0.5867075294117647], 
             UndirectedEdge[33, 198] -> 
             RGBColor[
              0.8787623235294117, 0.781568705882353, 0.6159916764705883], 
             UndirectedEdge[39, 114] -> 
             RGBColor[
              0.5822306470588234, 0.6651075294117647, 0.9633624117647059], 
             UndirectedEdge[144, 170] -> 
             RGBColor[
              0.9604562352941176, 0.9685528235294117, 0.8874943235294117], 
             UndirectedEdge[64, 110] -> 
             RGBColor[
              0.9936472941176471, 0.9888205294117648, 0.549925352941177], 
             UndirectedEdge[108, 131] -> 
             RGBColor[
              0.751222088235294, 0.6512468823529411, 0.5975811470588235], 
             UndirectedEdge[33, 141] -> 
             RGBColor[
              0.7918034117647057, 0.8375021764705881, 0.9798248235294118], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.9610245588235293, 0.9669545294117647, 0.744813411764706], 
             UndirectedEdge[88, 142] -> 
             RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             UndirectedEdge[12, 95] -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             UndirectedEdge[131, 162] -> 
             RGBColor[
              0.9427327941176471, 0.8000051176470587, 0.507354705882353], 
             UndirectedEdge[21, 194] -> 
             RGBColor[
              0.7353383235294118, 0.7885429411764706, 0.830958529411765], 
             UndirectedEdge[131, 154] -> 
             RGBColor[
              0.9279282941176471, 0.7469542352941176, 0.2706378529411766], 
             UndirectedEdge[81, 184] -> 
             RGBColor[
              0.8462661470588235, 0.7260070588235293, 0.6067048529411765], 
             UndirectedEdge[105, 111] -> 
             RGBColor[
              0.9194434705882354, 0.7183272352941179, 0.2540405294117648]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 71 -> 
             RGBColor[
              0.27056394117647053`, 0.4017102352941176, 0.9387195882352941], 
             10 -> RGBColor[
              0.7363957647058822, 0.7939972352941175, 0.9743607058823529], 68 -> 
             RGBColor[
              0.8472110588235293, 0.8810071176470587, 0.9852889411764706], 
             155 -> RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             132 -> RGBColor[
              0.27056394117647053`, 0.4017102352941176, 0.9387195882352941], 
             26 -> RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 29 -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             113 -> RGBColor[
              0.8463208823529411, 0.3570481764705882, 0.19199023529411763`], 
             50 -> RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             173 -> RGBColor[
              0.9468331176470589, 0.8269180588235295, 0.2760788823529412], 
             192 -> RGBColor[
              0.5422784705882353, 0.6392851176470589, 0.957109294117647], 165 -> 
             RGBColor[
              0.6737045882352939, 0.7450224117647057, 0.9681122352941176], 92 -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588242], 11 -> 
             RGBColor[
              0.5422784705882353, 0.6392851176470589, 0.957109294117647], 137 -> 
             RGBColor[
              0.9882041764705882, 0.9718720588235293, 0.40867588235294106`], 
             120 -> RGBColor[
              0.7990869411764707, 0.8429720588235294, 0.9806091764705882], 51 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 72 -> 
             RGBColor[
              0.8880516470588234, 0.913572294117647, 0.9891843529411765], 64 -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 41 -> 
             RGBColor[
              0.8880516470588234, 0.913572294117647, 0.9891843529411765], 103 -> 
             RGBColor[
              0.7363957647058822, 0.7939972352941175, 0.9743607058823529], 
             162 -> RGBColor[
              0.9920202352941176, 0.9909681764705882, 0.7819088823529412], 
             196 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             179 -> RGBColor[
              0.8880516470588234, 0.913572294117647, 0.9891843529411765], 160 -> 
             RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             123 -> 
             RGBColor[
              0.8880516470588234, 0.913572294117647, 0.9891843529411765], 150 -> 
             RGBColor[
              0.8880516470588234, 0.913572294117647, 0.9891843529411765], 188 -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588242], 46 -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             182 -> RGBColor[
              0.9670768235294117, 0.9749665294117646, 0.9406145294117647], 6 -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             131 -> RGBColor[
              0.8934453529411764, 0.6090420588235292, 0.23280052941176468`], 
             45 -> RGBColor[
              0.8318199411764706, 0.24558758823529453`, 0.17810411764705888`],
              195 -> RGBColor[
              0.9882041764705882, 0.9718720588235293, 0.40867588235294106`], 
             148 -> RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588242], 161 -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 1 -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             101 -> RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588242], 12 -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 39 -> 
             RGBColor[
              0.8472110588235293, 0.8810071176470587, 0.9852889411764706], 48 -> 
             RGBColor[
              0.7990869411764707, 0.8429720588235294, 0.9806091764705882], 77 -> 
             RGBColor[
              0.22474547058823524`, 0.35355211764705874`, 0.9361102941176471],
              56 -> RGBColor[
              0.7990869411764707, 0.8429720588235294, 0.9806091764705882], 
             110 -> RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588242], 73 -> 
             RGBColor[
              0.4193010588235294, 0.5375992352941176, 0.9479384705882353], 37 -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             130 -> RGBColor[
              0.9882041764705882, 0.9718720588235293, 0.40867588235294106`], 
             107 -> RGBColor[
              0.3682756470588235, 0.49340358823529407`, 0.9446871764705882], 
             59 -> RGBColor[
              0.7990869411764707, 0.8429720588235294, 0.9806091764705882], 47 -> 
             RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             159 -> RGBColor[0.984192, 0.987731, 0.911643], 55 -> 
             RGBColor[
              0.9285733529411766, 0.7545241764705887, 0.26138664705882364`], 
             49 -> RGBColor[
              0.8880516470588234, 0.913572294117647, 0.9891843529411765], 82 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 199 -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 89 -> 
             RGBColor[
              0.7990869411764707, 0.8429720588235294, 0.9806091764705882], 
             144 -> RGBColor[
              0.9920202352941176, 0.9909681764705882, 0.7819088823529412], 78 -> 
             RGBColor[
              0.3682756470588235, 0.49340358823529407`, 0.9446871764705882], 
             42 -> RGBColor[
              0.6737045882352939, 0.7450224117647057, 0.9681122352941176], 
             154 -> RGBColor[
              0.9624112352941178, 0.8848664117647062, 0.3084751764705885], 
             168 -> RGBColor[
              0.3682756470588235, 0.49340358823529407`, 0.9446871764705882], 
             121 -> RGBColor[
              0.9670768235294117, 0.9749665294117646, 0.9406145294117647], 
             128 -> RGBColor[
              0.8472110588235293, 0.8810071176470587, 0.9852889411764706], 
             115 -> RGBColor[
              0.8880516470588234, 0.913572294117647, 0.9891843529411765], 61 -> 
             RGBColor[
              0.8880516470588234, 0.913572294117647, 0.9891843529411765], 93 -> 
             RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 88 -> 
             RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 21 -> 
             RGBColor[
              0.4755581176470588, 0.5851185294117647, 0.9518568235294118], 62 -> 
             RGBColor[
              0.7990869411764707, 0.8429720588235294, 0.9806091764705882], 
             136 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             190 -> RGBColor[
              0.9670768235294117, 0.9749665294117646, 0.9406145294117647], 57 -> 
             RGBColor[
              0.8880516470588234, 0.913572294117647, 0.9891843529411765], 111 -> 
             RGBColor[
              0.9103135882352942, 0.6821302941176473, 0.2466944117647059], 63 -> 
             RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 75 -> 
             RGBColor[
              0.3682756470588235, 0.49340358823529407`, 0.9446871764705882], 
             30 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 5 -> 
             RGBColor[
              0.9103135882352942, 0.6821302941176473, 0.2466944117647059], 
             171 -> RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             102 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 31 -> 
             RGBColor[
              0.9920202352941176, 0.9909681764705882, 0.7819088823529412], 96 -> 
             RGBColor[
              0.5422784705882353, 0.6392851176470589, 0.957109294117647], 70 -> 
             RGBColor[
              0.9285733529411766, 0.7545241764705887, 0.26138664705882364`], 
             52 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             183 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             158 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 13 -> 
             RGBColor[
              0.9920202352941176, 0.9909681764705882, 0.7819088823529412], 
             170 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 86 -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 18 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 153 -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 58 -> 
             RGBColor[
              0.9920202352941176, 0.9909681764705882, 0.7819088823529412], 22 -> 
             RGBColor[
              0.8611004117647059, 0.46217123529411785`, 0.20581111764705887`],
              66 -> RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             143 -> RGBColor[
              0.9499616470588235, 0.9622020588235294, 0.9695860588235294], 
             119 -> RGBColor[
              0.6737045882352939, 0.7450224117647057, 0.9681122352941176], 
             145 -> RGBColor[
              0.7990869411764707, 0.8429720588235294, 0.9806091764705882], 91 -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             177 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             200 -> RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             114 -> 
             RGBColor[
              0.3172502352941176, 0.44920794117647056`, 0.9414358823529412], 
             24 -> RGBColor[
              0.9499616470588235, 0.9622020588235294, 0.9695860588235294], 
             176 -> RGBColor[
              0.8772728823529412, 0.5356066470588235, 0.21930582352941178`], 
             79 -> RGBColor[
              0.4755581176470588, 0.5851185294117647, 0.9518568235294118], 
             109 -> RGBColor[
              0.3172502352941176, 0.44920794117647056`, 0.9414358823529412], 
             135 -> RGBColor[
              0.9499616470588235, 0.9622020588235294, 0.9695860588235294], 
             108 -> RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             191 -> RGBColor[
              0.9670768235294117, 0.9749665294117646, 0.9406145294117647], 14 -> 
             RGBColor[
              0.9499616470588235, 0.9622020588235294, 0.9695860588235294], 
             185 -> RGBColor[
              0.4755581176470588, 0.5851185294117647, 0.9518568235294118], 32 -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             122 -> RGBColor[
              0.5422784705882353, 0.6392851176470589, 0.957109294117647], 187 -> 
             RGBColor[
              0.7990869411764707, 0.8429720588235294, 0.9806091764705882], 
             193 -> RGBColor[
              0.9499616470588235, 0.9622020588235294, 0.9695860588235294], 
             100 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             180 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 7 -> 
             RGBColor[
              0.5422784705882353, 0.6392851176470589, 0.957109294117647], 175 -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 9 -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 90 -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117646, 0.9406145294117647], 
             174 -> RGBColor[
              0.9670768235294117, 0.9749665294117646, 0.9406145294117647], 
             142 -> RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             134 -> RGBColor[
              0.9882041764705882, 0.9718720588235293, 0.40867588235294106`], 
             105 -> RGBColor[
              0.9285733529411766, 0.7545241764705887, 0.26138664705882364`], 
             16 -> RGBColor[
              0.5422784705882353, 0.6392851176470589, 0.957109294117647], 139 -> 
             RGBColor[
              0.7990869411764707, 0.8429720588235294, 0.9806091764705882], 
             146 -> RGBColor[
              0.3172502352941176, 0.44920794117647056`, 0.9414358823529412], 
             126 -> RGBColor[
              0.9882041764705882, 0.9718720588235293, 0.40867588235294106`], 
             198 -> RGBColor[
              0.9103135882352942, 0.6821302941176473, 0.2466944117647059], 40 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 104 -> 
             RGBColor[
              0.7363957647058822, 0.7939972352941175, 0.9743607058823529], 
             181 -> RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 
             127 -> RGBColor[
              0.8472110588235293, 0.8810071176470587, 0.9852889411764706], 76 -> 
             RGBColor[
              0.8880516470588234, 0.913572294117647, 0.9891843529411765], 172 -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 84 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 184 -> 
             RGBColor[
              0.8934453529411764, 0.6090420588235292, 0.23280052941176468`], 
             151 -> RGBColor[
              0.9499616470588235, 0.9622020588235294, 0.9695860588235294], 35 -> 
             RGBColor[
              0.7990869411764707, 0.8429720588235294, 0.9806091764705882], 36 -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 34 -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 38 -> 
             RGBColor[
              0.7990869411764707, 0.8429720588235294, 0.9806091764705882], 54 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 60 -> 
             RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 87 -> 
             RGBColor[
              0.9670768235294117, 0.9749665294117646, 0.9406145294117647], 
             141 -> RGBColor[
              0.7363957647058822, 0.7939972352941175, 0.9743607058823529], 67 -> 
             RGBColor[
              0.5422784705882353, 0.6392851176470589, 0.957109294117647], 133 -> 
             RGBColor[
              0.3682756470588235, 0.49340358823529407`, 0.9446871764705882], 
             98 -> RGBColor[
              0.7990869411764707, 0.8429720588235294, 0.9806091764705882], 3 -> 
             RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 27 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 163 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 85 -> 
             RGBColor[
              0.7363957647058822, 0.7939972352941175, 0.9743607058823529], 83 -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 28 -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 44 -> 
             RGBColor[
              0.8472110588235293, 0.8810071176470587, 0.9852889411764706], 
             189 -> RGBColor[
              0.5422784705882353, 0.6392851176470589, 0.957109294117647], 15 -> 
             RGBColor[
              0.7363957647058822, 0.7939972352941175, 0.9743607058823529], 80 -> 
             RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             112 -> RGBColor[
              0.5422784705882353, 0.6392851176470589, 0.957109294117647], 169 -> 
             RGBColor[
              0.7990869411764707, 0.8429720588235294, 0.9806091764705882], 69 -> 
             RGBColor[
              0.8934453529411764, 0.6090420588235292, 0.23280052941176468`], 
             20 -> RGBColor[
              0.9285733529411766, 0.7545241764705887, 0.26138664705882364`], 
             8 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             116 -> RGBColor[
              0.6737045882352939, 0.7450224117647057, 0.9681122352941176], 97 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 118 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 178 -> 
             RGBColor[
              0.9624112352941178, 0.8848664117647062, 0.3084751764705885], 81 -> 
             RGBColor[
              0.7990869411764707, 0.8429720588235294, 0.9806091764705882], 
             166 -> RGBColor[
              0.7990869411764707, 0.8429720588235294, 0.9806091764705882], 
             125 -> RGBColor[
              0.5422784705882353, 0.6392851176470589, 0.957109294117647], 95 -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             157 -> RGBColor[
              0.7363957647058822, 0.7939972352941175, 0.9743607058823529], 74 -> 
             RGBColor[
              0.9920202352941176, 0.9909681764705882, 0.7819088823529412], 19 -> 
             RGBColor[
              0.9881061176470588, 0.9893495882352942, 0.8467759411764708], 
             156 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             167 -> 
             RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588242], 33 -> 
             RGBColor[
              0.8472110588235293, 0.8810071176470587, 0.9852889411764706], 43 -> 
             RGBColor[
              0.8472110588235293, 0.8810071176470587, 0.9852889411764706], 
             140 -> RGBColor[
              0.9670768235294117, 0.9749665294117646, 0.9406145294117647], 
             186 -> RGBColor[
              0.5422784705882353, 0.6392851176470589, 0.957109294117647], 117 -> 
             RGBColor[
              0.9920202352941176, 0.9909681764705882, 0.7819088823529412], 4 -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             106 -> RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 65 -> 
             RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 53 -> 
             RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 2 -> 
             RGBColor[
              0.9499616470588235, 0.9622020588235294, 0.9695860588235294], 
             147 -> RGBColor[
              0.8611004117647059, 0.46217123529411785`, 0.20581111764705887`],
              94 -> RGBColor[
              0.994137705882353, 0.9898694705882354, 0.6033036470588242], 23 -> 
             RGBColor[
              0.9753077058823529, 0.9283692352941177, 0.35857552941176474`], 
             194 -> RGBColor[
              0.9951185294117647, 0.9919673529411764, 0.7100602352941181], 
             129 -> RGBColor[
              0.6089988235294117, 0.6934517058823529, 0.9623617647058823], 99 -> 
             RGBColor[
              0.5422784705882353, 0.6392851176470589, 0.957109294117647], 25 -> 
             RGBColor[
              0.7990869411764707, 0.8429720588235294, 0.9806091764705882], 
             138 -> RGBColor[
              0.9931568823529412, 0.9877715882352942, 0.4965470588235296], 
             124 -> RGBColor[
              0.9499616470588235, 0.9622020588235294, 0.9695860588235294], 
             197 -> RGBColor[
              0.9288922352941176, 0.9461374705882353, 0.9930797647058823], 
             164 -> RGBColor[
              0.8880516470588234, 0.913572294117647, 0.9891843529411765], 152 -> 
             RGBColor[
              0.9882041764705882, 0.9718720588235293, 0.40867588235294106`], 
             17 -> RGBColor[
              0.9882041764705882, 0.9718720588235293, 0.40867588235294106`], 
             149 -> RGBColor[
              0.4193010588235294, 0.5375992352941176, 
               0.9479384705882353]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9lnk01I33xy0ZCmPGjGUM5jOLCfGgkIjPm8rSZv1l6yGUlK0nopQSkiYJ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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 78}], {
             RGBColor[
             0.6485839411764706, 0.7197705294117647, 0.9688834705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 88}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 89}], {
             RGBColor[
             0.8639895882352941, 0.8945547647058824, 0.9868444705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[0.8876065588235293, 0.6515928235294117, 0.592535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 122}], {
             RGBColor[
             0.7355853529411764, 0.7927112941176471, 0.9750945294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 136}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 138}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.744813411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 144}], {
             RGBColor[
             0.9604562352941176, 0.9685528235294117, 0.8874943235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 159}], {
             RGBColor[
             0.9565421176470588, 0.9669342352941177, 0.9523613823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 167}], {
             RGBColor[
             0.9615149705882353, 0.9680034705882353, 0.7981917058823533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 197}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 26}], {
             RGBColor[
             0.7794802352941176, 0.8278268823529411, 0.9659739117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 40}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117646, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 51}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117646, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 74}], {
             RGBColor[
             0.9709909411764706, 0.9765851176470588, 0.8757474705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 80}], {
             RGBColor[
             0.9725400882352941, 0.9770847058823529, 0.8398231470588238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 121}], {
             RGBColor[
             0.9585192352941176, 0.968584294117647, 0.9551002941176471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 158}], {
             RGBColor[
             0.9725400882352941, 0.9770847058823529, 0.8398231470588238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 164}], {
             RGBColor[
             0.9190066470588234, 0.9378871764705882, 0.9793852058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 166}], {
             RGBColor[
             0.8745242941176471, 0.9025870588235294, 0.9750976176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 169}], {
             RGBColor[
             0.8745242941176471, 0.9025870588235294, 0.9750976176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 184}], {
             RGBColor[0.9217035, 0.7856220588235293, 0.601193294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 5}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764707, 0.37162073529411777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 10}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 11}], {
             RGBColor[
             0.7677176764705882, 0.8135283529411765, 0.7268281764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 15}], {
             RGBColor[
             0.8647763235294117, 0.8908844117647059, 0.7354538823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 20}], {
             RGBColor[
             0.9608651176470588, 0.8711478823529415, 0.3789668529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 28}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 48}], {
             RGBColor[
             0.8961219117647059, 0.9153718235294118, 0.7385781176470589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 63}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 77}], {
             RGBColor[
             0.6089511764705882, 0.6706618529411765, 0.7163286764705884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 106}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 186}], {
             RGBColor[
             0.7677176764705882, 0.8135283529411765, 0.7268281764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 189}], {
             RGBColor[
             0.7677176764705882, 0.8135283529411765, 0.7268281764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 41}], {
             RGBColor[
             0.9084719411764706, 0.9298548823529411, 0.9911320588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 66}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 80}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 81}], {
             RGBColor[
             0.8639895882352941, 0.8945547647058824, 0.9868444705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 168}], {
             RGBColor[
             0.6485839411764706, 0.7197705294117647, 0.9688834705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 172}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.744813411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 173}], {
             RGBColor[
             0.9378626764705882, 0.8865277647058825, 0.6345793235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 184}], {
             RGBColor[
             0.911168794117647, 0.7775897647058823, 0.6129401470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 198}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529413, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 9}], {
             RGBColor[
             0.9527160588235295, 0.8370488235294118, 0.478377323529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.7262960294117647, 0.6607077058823531, 0.6019018529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 15}], {
             RGBColor[
             0.8233546764705881, 0.7380637647058823, 0.6105275588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 17}], {
             RGBColor[
             0.9492588823529412, 0.8270011764705882, 0.32768514705882346`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 20}], {
             RGBColor[
             0.9194434705882354, 0.7183272352941179, 0.2540405294117648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 28}], {
             RGBColor[
             0.9527160588235295, 0.8370488235294118, 0.478377323529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 48}], {
             RGBColor[
             0.8547002647058825, 0.7625511764705883, 0.6136517941176471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 63}], {
             RGBColor[0.7596562058823529, 0.687791, 0.6045280882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[
             0.5675295294117647, 0.5178412058823529, 0.5914023529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 102}], {
             RGBColor[
             0.9527160588235295, 0.8370488235294118, 0.478377323529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 106}], {
             RGBColor[0.7596562058823529, 0.687791, 0.6045280882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 112}], {
             RGBColor[
             0.7262960294117647, 0.6607077058823531, 0.6019018529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 140}], {
             RGBColor[
             0.938695205882353, 0.828548411764706, 0.5936544705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 189}], {
             RGBColor[
             0.7262960294117647, 0.6607077058823531, 0.6019018529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 12}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 13}], {
             RGBColor[
             0.9604562352941176, 0.9685528235294117, 0.8874943235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 14}], {
             RGBColor[
             0.9394269411764705, 0.9541697647058823, 0.9813329117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 16}], {
             RGBColor[
             0.7355853529411764, 0.7927112941176471, 0.9750945294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 59}], {
             RGBColor[
             0.8639895882352941, 0.8945547647058824, 0.9868444705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 64}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.744813411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 83}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 86}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 124}], {
             RGBColor[
             0.9394269411764705, 0.9541697647058823, 0.9813329117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 137}], {
             RGBColor[
             0.9585482058823529, 0.9590047647058824, 0.7008778235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 161}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 175}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 176}], {
             RGBColor[
             0.9030825588235294, 0.7408720588235294, 0.606192794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 186}], {
             RGBColor[
             0.7355853529411764, 0.7927112941176471, 0.9750945294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 187}], {
             RGBColor[
             0.8639895882352941, 0.8945547647058824, 0.9868444705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 193}], {
             RGBColor[
             0.9394269411764705, 0.9541697647058823, 0.9813329117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 199}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.744813411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 18}], {
             RGBColor[
             0.7632352352941176, 0.8135080588235295, 0.9343761470588234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 42}], {
             RGBColor[
             0.6079915294117646, 0.6921537647058823, 0.9626107647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 47}], {
             RGBColor[
             0.5756386470588235, 0.666368411764706, 0.9597355294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.7632352352941176, 0.8135080588235295, 0.9343761470588234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 58}], {
             RGBColor[
             0.7671493529411765, 0.8151266470588235, 0.869509088235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.7151650588235294, 0.7764287058823529, 0.9731468235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 73}], {
             RGBColor[
             0.48078976470588236`, 0.5884421764705883, 0.9525238823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 88}], {
             RGBColor[
             0.5756386470588235, 0.666368411764706, 0.9597355294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 94}], {
             RGBColor[
             0.7682080882352942, 0.8145772941176471, 0.7802064705882357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 97}], {
             RGBColor[
             0.6797987352941177, 0.38670605882352943`, 0.5606636470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 115}], {
             RGBColor[
             0.7151650588235294, 0.7764287058823529, 0.9731468235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 153}], {
             RGBColor[
             0.7355853529411764, 0.7927112941176471, 0.9750945294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 160}], {
             RGBColor[
             0.5756386470588235, 0.666368411764706, 0.9597355294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 188}], {
             RGBColor[
             0.7682080882352942, 0.8145772941176471, 0.7802064705882357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 55}], {
             RGBColor[
             0.9618459411764706, 0.8732457647058826, 0.48572344117647087`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 62}], {
             RGBColor[
             0.8971027352941177, 0.9174697058823529, 0.8453347058823532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 68}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 75}], {
             RGBColor[
             0.6816970882352941, 0.7426854705882353, 0.8273737058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 96}], {
             RGBColor[0.7686985, 0.8156262352941177, 0.8335847647058825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 99}], {
             RGBColor[0.7686985, 0.8156262352941177, 0.8335847647058825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 107}], {
             RGBColor[
             0.6816970882352941, 0.7426854705882353, 0.8273737058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 147}], {
             RGBColor[
             0.9281094705882353, 0.7270692941176471, 0.45793567647058847`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 156}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 157}], {
             RGBColor[
             0.8657571470588235, 0.892982294117647, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 179}], {
             RGBColor[
             0.9415850882352941, 0.9527698235294118, 0.8496222941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 185}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.830958529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 194}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[0.7686985, 0.8156262352941177, 0.8335847647058825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 17}], {
             RGBColor[
             0.9916613529411764, 0.9819197058823529, 0.5593680588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 20}], {
             RGBColor[
             0.9618459411764706, 0.8732457647058826, 0.48572344117647087`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 28}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 63}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 77}], {
             RGBColor[
             0.6099319999999999, 0.6727597352941176, 0.8230852647058826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 97}], {
             RGBColor[
             0.9062187647058824, 0.5630471764705882, 0.43713911764705904`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 102}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 112}], {
             RGBColor[0.7686985, 0.8156262352941177, 0.8335847647058825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 140}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764705, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 189}], {
             RGBColor[0.7686985, 0.8156262352941177, 0.8335847647058825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 14}], {
             RGBColor[
             0.8431787058823528, 0.8780996470588234, 0.9719733823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.7363957647058822, 0.7939972352941175, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 28}], {
             RGBColor[
             0.8657571470588235, 0.892982294117647, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 48}], {
             RGBColor[
             0.7677413529411765, 0.8184846470588234, 0.9774849411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 59}], {
             RGBColor[
             0.7677413529411765, 0.8184846470588234, 0.9774849411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 77}], {
             RGBColor[0.4805706176470587, 0.5737746764705881, 0.9552355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 186}], {
             RGBColor[0.6393371176470588, 0.7166411764705882, 0.965735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 193}], {
             RGBColor[
             0.8431787058823528, 0.8780996470588234, 0.9719733823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 15}], {
             RGBColor[0.6393371176470588, 0.7166411764705882, 0.965735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 17}], {
             RGBColor[
             0.7652413235294118, 0.8055785882352942, 0.6828925882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 20}], {
             RGBColor[
             0.735425911764706, 0.6969046470588238, 0.6092479705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 28}], {
             RGBColor[0.7686985, 0.8156262352941177, 0.8335847647058825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 48}], {
             RGBColor[
             0.670682705882353, 0.7411285882352942, 0.9688592352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 63}], {
             RGBColor[
             0.5756386470588235, 0.666368411764706, 0.9597355294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 77}], {
             RGBColor[
             0.3835119705882353, 0.4964186176470588, 0.946609794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 106}], {
             RGBColor[
             0.5756386470588235, 0.666368411764706, 0.9597355294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 112}], {
             RGBColor[
             0.5422784705882353, 0.6392851176470589, 0.957109294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 140}], {
             RGBColor[
             0.7546776470588235, 0.8071258235294118, 0.9488619117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 189}], {
             RGBColor[
             0.5422784705882353, 0.6392851176470589, 0.957109294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 13}], {
             RGBColor[
             0.9604562352941176, 0.9685528235294117, 0.8874943235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 14}], {
             RGBColor[
             0.9394269411764705, 0.9541697647058823, 0.9813329117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.7355853529411764, 0.7927112941176471, 0.9750945294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 23}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 25}], {
             RGBColor[
             0.8639895882352941, 0.8945547647058824, 0.9868444705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 59}], {
             RGBColor[
             0.8639895882352941, 0.8945547647058824, 0.9868444705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.744813411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 86}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 87}], {
             RGBColor[0.9479845294117646, 0.960552, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 95}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 108}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 154}], {
             RGBColor[
             0.9456517352941176, 0.9155019411764707, 0.6507774705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 161}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 175}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 193}], {
             RGBColor[
             0.9394269411764705, 0.9541697647058823, 0.9813329117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 16}], {
             RGBColor[
             0.7671493529411765, 0.8151266470588235, 0.869509088235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 64}], {
             RGBColor[
             0.9925885588235295, 0.9893698823529412, 0.6392279705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 69}], {
             RGBColor[
             0.9427327941176471, 0.8000051176470587, 0.5073547058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 82}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352941, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 83}], {
             RGBColor[
             0.9935693823529412, 0.9914677647058823, 0.7459845588235297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 86}], {
             RGBColor[
             0.9935693823529412, 0.9914677647058823, 0.7459845588235297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 101}], {
             RGBColor[
             0.9930789705882352, 0.9904188235294118, 0.6926062647058827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 108}], {
             RGBColor[
             0.8005095294117647, 0.8422099411764705, 0.8721353235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 110}], {
             RGBColor[
             0.9930789705882352, 0.9904188235294118, 0.6926062647058827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 124}], {
             RGBColor[
             0.9709909411764706, 0.9765851176470588, 0.8757474705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 127}], {
             RGBColor[
             0.9196156470588235, 0.9359876470588235, 0.8835989117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 137}], {
             RGBColor[
             0.9901122058823529, 0.9814201176470587, 0.5952923823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 161}], {
             RGBColor[
             0.9900631764705883, 0.9901588823529412, 0.814342411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 175}], {
             RGBColor[
             0.9935693823529412, 0.9914677647058823, 0.7459845588235297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 176}], {
             RGBColor[
             0.9346465588235294, 0.7632874117647059, 0.5006073529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 187}], {
             RGBColor[
             0.8955535882352942, 0.9169701176470588, 0.8812590294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 199}], {
             RGBColor[
             0.9925885588235295, 0.9893698823529412, 0.6392279705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 15}], {
             RGBColor[
             0.8431787058823528, 0.8780996470588234, 0.9719733823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 48}], {
             RGBColor[
             0.8745242941176471, 0.9025870588235294, 0.9750976176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 59}], {
             RGBColor[
             0.8745242941176471, 0.9025870588235294, 0.9750976176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 186}], {
             RGBColor[
             0.7461200588235294, 0.8007435882352941, 0.9633476764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 193}], {
             RGBColor[
             0.9499616470588235, 0.9622020588235294, 0.9695860588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 28}], {
             RGBColor[
             0.8657571470588235, 0.892982294117647, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 48}], {
             RGBColor[
             0.7677413529411765, 0.8184846470588234, 0.9774849411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 59}], {
             RGBColor[
             0.7677413529411765, 0.8184846470588234, 0.9774849411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 63}], {
             RGBColor[
             0.672697294117647, 0.7437244705882352, 0.9683612352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 77}], {
             RGBColor[0.4805706176470587, 0.5737746764705881, 0.9552355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 106}], {
             RGBColor[
             0.672697294117647, 0.7437244705882352, 0.9683612352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[0.6393371176470588, 0.7166411764705882, 0.965735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 140}], {
             RGBColor[
             0.851736294117647, 0.884481882352941, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 193}], {
             RGBColor[
             0.8431787058823528, 0.8780996470588234, 0.9719733823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 64}], {
             RGBColor[
             0.7677176764705882, 0.8135283529411765, 0.7268281764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 83}], {
             RGBColor[0.7686985, 0.8156262352941177, 0.8335847647058825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 86}], {
             RGBColor[0.7686985, 0.8156262352941177, 0.8335847647058825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 101}], {
             RGBColor[
             0.7682080882352942, 0.8145772941176471, 0.7802064705882357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 124}], {
             RGBColor[
             0.7461200588235294, 0.8007435882352941, 0.9633476764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 127}], {
             RGBColor[
             0.6947447647058823, 0.7601461176470587, 0.9711991176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 137}], {
             RGBColor[
             0.7652413235294118, 0.8055785882352942, 0.6828925882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 161}], {
             RGBColor[
             0.765192294117647, 0.8143173529411765, 0.9019426176470589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 175}], {
             RGBColor[0.7686985, 0.8156262352941177, 0.8335847647058825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 176}], {
             RGBColor[
             0.7097756764705883, 0.5874458823529412, 0.5882075588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.670682705882353, 0.7411285882352942, 0.9688592352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 193}], {
             RGBColor[
             0.7461200588235294, 0.8007435882352941, 0.9633476764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 199}], {
             RGBColor[
             0.7677176764705882, 0.8135283529411765, 0.7268281764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 20}], {
             RGBColor[
             0.9583887647058824, 0.863198117647059, 0.33503126470588235`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 28}], {
             RGBColor[
             0.9916613529411764, 0.9819197058823529, 0.5593680588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 77}], {
             RGBColor[
             0.6064748235294117, 0.662712088235294, 0.6723930882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 106}], {
             RGBColor[0.7986015, 0.8326618823529411, 0.6855188235294116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 112}], {
             RGBColor[
             0.7652413235294118, 0.8055785882352942, 0.6828925882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 140}], {
             RGBColor[
             0.9776404999999999, 0.9734192941176469, 0.6746452058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 189}], {
             RGBColor[
             0.7652413235294118, 0.8055785882352942, 0.6828925882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 47}], {
             RGBColor[
             0.7965954117647058, 0.8405913529411765, 0.9370023823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 54}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 58}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352941, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 61}], {
             RGBColor[
             0.9361218235294118, 0.9506516470588235, 0.9504136764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 73}], {
             RGBColor[
             0.7017465294117646, 0.7626651176470588, 0.9297907352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 94}], {
             RGBColor[
             0.9891648529411765, 0.9888002352941176, 0.7574733235294121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 115}], {
             RGBColor[
             0.9361218235294118, 0.9506516470588235, 0.9504136764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 116}], {
             RGBColor[
             0.8289482941176469, 0.8663767058823528, 0.9398776176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 153}], {
             RGBColor[
             0.9565421176470588, 0.9669342352941177, 0.9523613823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 160}], {
             RGBColor[
             0.7965954117647058, 0.8405913529411765, 0.9370023823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 174}], {
             RGBColor[
             0.9756344117647058, 0.9813487647058823, 0.9261287647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 188}], {
             RGBColor[
             0.9891648529411765, 0.9888002352941176, 0.7574733235294121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 33}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 34}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 44}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 50}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 60}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 90}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 130}], {
             RGBColor[
             0.9881551470588235, 0.9806108235294118, 0.6277259117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 141}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 177}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.9618459411764706, 0.8732457647058826, 0.48572344117647087`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 77}], {
             RGBColor[
             0.5766594117647059, 0.5540381470588237, 0.5987484705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 106}], {
             RGBColor[
             0.7687860882352942, 0.7239879411764708, 0.611874205882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 189}], {
             RGBColor[
             0.735425911764706, 0.6969046470588238, 0.6092479705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[0.7022251764705882, 0.765628, 0.972468294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 46}], {
             RGBColor[0.7022251764705882, 0.765628, 0.972468294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 85}], {
             RGBColor[
             0.6059769411764705, 0.6895578823529411, 0.9631087647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 109}], {
             RGBColor[
             0.39640417647058823`, 0.5171632352941176, 0.9466463529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 132}], {
             RGBColor[
             0.37306102941176467`, 0.4934143823529411, 0.945288205882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 150}], {
             RGBColor[
             0.6818048823529411, 0.7493454117647058, 0.9705205882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 151}], {
             RGBColor[
             0.7127598823529411, 0.773660294117647, 0.9607214411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 194}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.830958529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 196}], {
             RGBColor[0.7022251764705882, 0.765628, 0.972468294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 24}], {
             RGBColor[
             0.9055310294117647, 0.7121866470588236, 0.5876985882352942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 37}], {
             RGBColor[
             0.9281094705882353, 0.7270692941176471, 0.4579356764705885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 38}], {
             RGBColor[
             0.8300936764705883, 0.6525716470588236, 0.5932101470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 79}], {
             RGBColor[
             0.6683292647058823, 0.5236448823529413, 0.5788339705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 89}], {
             RGBColor[
             0.8300936764705883, 0.6525716470588236, 0.5932101470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 118}], {
             RGBColor[
             0.9226462058823529, 0.7249511176470589, 0.5587270588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 119}], {
             RGBColor[
             0.7674024999999999, 0.6035968235294118, 0.5869616764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 122}], {
             RGBColor[
             0.7016894411764706, 0.5507281764705884, 0.5814602058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 128}], {
             RGBColor[
             0.8541557352941176, 0.6715891764705884, 0.5955500294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 138}], {
             RGBColor[
             0.9271286470588236, 0.724971411764706, 0.3511790882352942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 144}], {
             RGBColor[
             0.9265603235294118, 0.726569705882353, 0.4938600000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 149}], {
             RGBColor[
             0.6402007352941177, 0.4998852352941177, 0.5768747941176471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 181}], {
             RGBColor[
             0.7350496176470588, 0.5778114705882353, 0.5840864411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 183}], {
             RGBColor[
             0.9281094705882353, 0.7270692941176471, 0.4579356764705885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 190}], {
             RGBColor[
             0.9140886176470588, 0.7185688823529413, 0.5732128235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 192}], {
             RGBColor[
             0.7016894411764706, 0.5507281764705884, 0.5814602058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 25}], {
             RGBColor[
             0.8871973235294118, 0.8856706470588236, 0.6695923529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 43}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 49}], {
             RGBColor[
             0.9316796764705881, 0.9209707647058823, 0.6738799411764707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 64}], {
             RGBColor[
             0.9842322941176471, 0.958070411764706, 0.4275612941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 67}], {
             RGBColor[
             0.7587930882352941, 0.7838271764705883, 0.6578424117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 87}], {
             RGBColor[
             0.9711922647058824, 0.9516678823529412, 0.6495950294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 95}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 103}], {
             RGBColor[
             0.8558517352941175, 0.8611832352941176, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 108}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 129}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 131}], {
             RGBColor[
             0.9343765294117647, 0.7687056470588235, 0.2956880294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 143}], {
             RGBColor[
             0.9626346764705882, 0.9452856470588236, 0.6640807941176471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 154}], {
             RGBColor[
             0.9688594705882354, 0.906617823529412, 0.3335253529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 162}], {
             RGBColor[
             0.9836639705882353, 0.959668705882353, 0.570242205882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.5644443235294118, 0.6337980294117647, 0.9515435294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 37}], {
             RGBColor[
             0.9725400882352941, 0.9770847058823529, 0.8398231470588238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 56}], {
             RGBColor[
             0.8745242941176471, 0.9025870588235294, 0.9750976176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 79}], {
             RGBColor[
             0.7127598823529411, 0.773660294117647, 0.9607214411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 89}], {
             RGBColor[
             0.8745242941176471, 0.9025870588235294, 0.9750976176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 118}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117646, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 119}], {
             RGBColor[
             0.8118331176470587, 0.8536122352941176, 0.9688491470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 125}], {
             RGBColor[
             0.7461200588235294, 0.8007435882352941, 0.9633476764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 144}], {
             RGBColor[
             0.9709909411764706, 0.9765851176470588, 0.8757474705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 149}], {
             RGBColor[
             0.6846313529411765, 0.7499006470588234, 0.9587622647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 170}], {
             RGBColor[
             0.9394269411764705, 0.9541697647058823, 0.9813329117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 190}], {
             RGBColor[
             0.9585192352941176, 0.968584294117647, 0.9551002941176471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 195}], {
             RGBColor[
             0.9690829117647058, 0.9670370588235293, 0.6891309705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 197}], {
             RGBColor[
             0.9394269411764705, 0.9541697647058823, 0.9813329117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[0.823149, 0.8619895882352941, 0.9829490588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 49}], {
             RGBColor[
             0.8435692941176471, 0.8782721764705882, 0.9848967647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 64}], {
             RGBColor[
             0.8961219117647059, 0.9153718235294118, 0.7385781176470589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 67}], {
             RGBColor[
             0.670682705882353, 0.7411285882352942, 0.9688592352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 87}], {
             RGBColor[
             0.8830818823529412, 0.908969294117647, 0.9606118529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 95}], {
             RGBColor[
             0.8639895882352941, 0.8945547647058824, 0.9868444705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 103}], {
             RGBColor[
             0.7677413529411765, 0.8184846470588234, 0.9774849411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 108}], {
             RGBColor[
             0.7040428823529412, 0.7682118823529411, 0.9714854705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 129}], {
             RGBColor[
             0.7040428823529412, 0.7682118823529411, 0.9714854705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 131}], {
             RGBColor[
             0.8462661470588235, 0.7260070588235293, 0.6067048529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 143}], {
             RGBColor[
             0.8745242941176471, 0.9025870588235294, 0.9750976176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 154}], {
             RGBColor[
             0.8807490882352942, 0.8639192352941178, 0.6445421764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 162}], {
             RGBColor[
             0.8955535882352942, 0.9169701176470588, 0.8812590294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 40}], {
             RGBColor[
             0.7965954117647058, 0.8405913529411765, 0.9370023823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 51}], {
             RGBColor[
             0.7965954117647058, 0.8405913529411765, 0.9370023823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 74}], {
             RGBColor[
             0.8005095294117647, 0.8422099411764705, 0.8721353235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 80}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 121}], {
             RGBColor[
             0.7880378235294117, 0.8342091176470587, 0.9514881470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 158}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 164}], {
             RGBColor[0.7485252352941176, 0.803512, 0.9757730588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.7040428823529412, 0.7682118823529411, 0.9714854705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 169}], {
             RGBColor[
             0.7040428823529412, 0.7682118823529411, 0.9714854705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 184}], {
             RGBColor[
             0.751222088235294, 0.6512468823529411, 0.5975811470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 37}], {
             RGBColor[
             0.5870227647058823, 0.6486806764705881, 0.821780617647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 56}], {
             RGBColor[
             0.48900697058823533`, 0.5741830294117647, 0.9570550882352942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 67}], {
             RGBColor[
             0.3606027352941177, 0.4723395588235294, 0.9453051470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 119}], {
             RGBColor[
             0.426315794117647, 0.5252082058823528, 0.9508066176470589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 125}], {
             RGBColor[
             0.3606027352941177, 0.4723395588235294, 0.9453051470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 128}], {
             RGBColor[
             0.5130690294117646, 0.5932005588235294, 0.9593949705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 133}], {
             RGBColor[
             0.27360132352941174`, 0.399398794117647, 0.9390940882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 190}], {
             RGBColor[
             0.5730019117647058, 0.6401802647058823, 0.9370577647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 195}], {
             RGBColor[
             0.5835655882352941, 0.6386330294117646, 0.6710884411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 48}], {
             RGBColor[
             0.8971027352941177, 0.9174697058823529, 0.8453347058823532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 63}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 77}], {
             RGBColor[
             0.6099319999999999, 0.6727597352941176, 0.8230852647058826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 106}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 112}], {
             RGBColor[0.7686985, 0.8156262352941177, 0.8335847647058825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 140}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764705, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 189}], {
             RGBColor[0.7686985, 0.8156262352941177, 0.8335847647058825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 35}], {
             RGBColor[
             0.8935965294117647, 0.9161608235294119, 0.9136925588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 47}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 88}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 89}], {
             RGBColor[
             0.8935965294117647, 0.9161608235294119, 0.9136925588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 113}], {
             RGBColor[
             0.9172134999999999, 0.6731988823529411, 0.5193830882352942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 122}], {
             RGBColor[
             0.765192294117647, 0.8143173529411765, 0.9019426176470589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 136}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 138}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 142}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 144}], {
             RGBColor[
             0.9900631764705883, 0.9901588823529412, 0.814342411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 153}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 159}], {
             RGBColor[
             0.9861490588235293, 0.9885402941176471, 0.8792094705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 167}], {
             RGBColor[
             0.9911219117647059, 0.9896095294117648, 0.7250397941176475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 181}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 188}], {
             RGBColor[
             0.9911219117647059, 0.9896095294117648, 0.7250397941176475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 41}], {
             RGBColor[
             0.9084719411764706, 0.9298548823529411, 0.9911320588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 65}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 66}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 90}], {
             RGBColor[0.9479845294117646, 0.960552, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 110}], {
             RGBColor[
             0.9615149705882353, 0.9680034705882353, 0.7981917058823533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 162}], {
             RGBColor[
             0.9604562352941176, 0.9685528235294117, 0.8874943235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 180}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 198}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529413, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 38}], {
             RGBColor[
             0.8955535882352942, 0.9169701176470588, 0.8812590294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352941, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 46}], {
             RGBColor[
             0.9604562352941176, 0.9685528235294117, 0.8874943235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 80}], {
             RGBColor[
             0.9935693823529412, 0.9914677647058823, 0.7459845588235297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 98}], {
             RGBColor[
             0.8955535882352942, 0.9169701176470588, 0.8812590294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 117}], {
             RGBColor[
             0.9920202352941176, 0.9909681764705882, 0.7819088823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 120}], {
             RGBColor[
             0.8955535882352942, 0.9169701176470588, 0.8812590294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 121}], {
             RGBColor[
             0.9795485294117647, 0.9829673529411764, 0.861261705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 146}], {
             RGBColor[
             0.6546352352941176, 0.7200880588235294, 0.8616723823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 151}], {
             RGBColor[
             0.9709909411764706, 0.9765851176470588, 0.8757474705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 171}], {
             RGBColor[
             0.8005095294117647, 0.8422099411764705, 0.8721353235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 173}], {
             RGBColor[
             0.9694266764705883, 0.9089431176470588, 0.5289938823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 178}], {
             RGBColor[
             0.9772157352941178, 0.9379172941176472, 0.5451920294117648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 196}], {
             RGBColor[
             0.9604562352941176, 0.9685528235294117, 0.8874943235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 53}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 82}], {
             RGBColor[
             0.9565421176470588, 0.9669342352941177, 0.9523613823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 83}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 100}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 101}], {
             RGBColor[
             0.9615149705882353, 0.9680034705882353, 0.7981917058823533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 123}], {
             RGBColor[
             0.9084719411764706, 0.9298548823529411, 0.9911320588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 127}], {
             RGBColor[
             0.8880516470588234, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 130}], {
             RGBColor[
             0.9585482058823529, 0.9590047647058824, 0.7008778235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 135}], {
             RGBColor[
             0.9394269411764705, 0.9541697647058823, 0.9813329117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 148}], {
             RGBColor[
             0.9615149705882353, 0.9680034705882353, 0.7981917058823533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 163}], {
             RGBColor[
             0.9565421176470588, 0.9669342352941177, 0.9523613823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 165}], {
             RGBColor[0.8012984117647057, 0.8455799411764705, 0.980596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 176}], {
             RGBColor[
             0.9030825588235294, 0.7408720588235294, 0.606192794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 187}], {
             RGBColor[
             0.8639895882352941, 0.8945547647058824, 0.9868444705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 41}], {
             RGBColor[
             0.8676313529411763, 0.8972897058823528, 0.9872366470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 44}], {
             RGBColor[
             0.8472110588235293, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 57}], {
             RGBColor[
             0.8676313529411763, 0.8972897058823528, 0.9872366470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 66}], {
             RGBColor[
             0.7281049411764705, 0.7872294117647058, 0.9738253529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 90}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 141}], {
             RGBColor[
             0.7918034117647057, 0.8375021764705881, 0.9798248235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 198}], {
             RGBColor[
             0.8787623235294117, 0.781568705882353, 0.6159916764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 44}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 50}], {
             RGBColor[
             0.9817069117647059, 0.958859411764706, 0.6026757352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 60}], {
             RGBColor[
             0.7985524705882352, 0.8414006470588236, 0.9045688529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 90}], {
             RGBColor[
             0.9775914705882353, 0.9821580588235295, 0.8936952352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 104}], {
             RGBColor[
             0.8622509411764705, 0.8916734117647058, 0.9105683235294119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 130}], {
             RGBColor[
             0.9881551470588235, 0.9806108235294118, 0.6277259117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 163}], {
             RGBColor[
             0.9861490588235293, 0.9885402941176471, 0.8792094705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 177}], {
             RGBColor[
             0.9584991764705881, 0.9677435294117647, 0.9199278529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 47}], {
             RGBColor[
             0.7040428823529412, 0.7682118823529411, 0.9714854705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 68}], {
             RGBColor[0.823149, 0.8619895882352941, 0.9829490588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 88}], {
             RGBColor[
             0.7040428823529412, 0.7682118823529411, 0.9714854705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.8966123235294119, 0.9164207647058824, 0.7919564117647062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 111}], {
             RGBColor[
             0.8547002647058825, 0.7625511764705883, 0.613651794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 116}], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 122}], {
             RGBColor[
             0.670682705882353, 0.7411285882352942, 0.9688592352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 138}], {
             RGBColor[
             0.8961219117647059, 0.9153718235294118, 0.7385781176470589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 142}], {
             RGBColor[
             0.7040428823529412, 0.7682118823529411, 0.9714854705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 153}], {
             RGBColor[
             0.8639895882352941, 0.8945547647058824, 0.9868444705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 157}], {
             RGBColor[
             0.7677413529411765, 0.8184846470588234, 0.9774849411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 160}], {
             RGBColor[
             0.7040428823529412, 0.7682118823529411, 0.9714854705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 167}], {
             RGBColor[
             0.8966123235294119, 0.9164207647058824, 0.7919564117647062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 174}], {
             RGBColor[
             0.8830818823529412, 0.908969294117647, 0.9606118529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 181}], {
             RGBColor[
             0.7040428823529412, 0.7682118823529411, 0.9714854705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 185}], {
             RGBColor[0.6373225294117648, 0.7140452941176471, 0.966233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 188}], {
             RGBColor[
             0.8966123235294119, 0.9164207647058824, 0.7919564117647062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 132}], {
             RGBColor[
             0.599728088235294, 0.6739238529411764, 0.9658996764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 151}], {
             RGBColor[
             0.9394269411764705, 0.9541697647058823, 0.9813329117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 169}], {
             RGBColor[
             0.8639895882352941, 0.8945547647058824, 0.9868444705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 200}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 56}], {
             RGBColor[
             0.8971027352941177, 0.9174697058823529, 0.8453347058823532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 79}], {
             RGBColor[
             0.7353383235294118, 0.7885429411764706, 0.830958529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 118}], {
             RGBColor[
             0.9896552647058823, 0.9898491764705882, 0.810851617647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 119}], {
             RGBColor[
             0.8344115588235292, 0.868494882352941, 0.8390862352941179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 125}], {
             RGBColor[0.7686985, 0.8156262352941177, 0.8335847647058825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 128}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 149}], {
             RGBColor[
             0.7072097941176471, 0.764783294117647, 0.8289993529411768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 170}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 190}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764705, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 195}], {
             RGBColor[
             0.9916613529411764, 0.9819197058823529, 0.5593680588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 46}], {
             RGBColor[
             0.8639895882352941, 0.8945547647058824, 0.9868444705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 98}], {
             RGBColor[
             0.7990869411764707, 0.8429720588235294, 0.9806091764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 117}], {
             RGBColor[
             0.8955535882352942, 0.9169701176470588, 0.8812590294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 120}], {
             RGBColor[
             0.7990869411764707, 0.8429720588235294, 0.9806091764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 128}], {
             RGBColor[0.823149, 0.8619895882352941, 0.9829490588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 146}], {
             RGBColor[0.5581685882352941, 0.64609, 0.9610225294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 156}], {
             RGBColor[
             0.8639895882352941, 0.8945547647058824, 0.9868444705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 171}], {
             RGBColor[
             0.7040428823529412, 0.7682118823529411, 0.9714854705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 178}], {
             RGBColor[
             0.8807490882352942, 0.8639192352941178, 0.6445421764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 179}], {
             RGBColor[
             0.8435692941176471, 0.8782721764705882, 0.9848967647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 183}], {
             RGBColor[
             0.8971027352941177, 0.9174697058823529, 0.8453347058823532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 192}], {
             RGBColor[
             0.670682705882353, 0.7411285882352942, 0.9688592352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 114}], {
             RGBColor[
             0.5822306470588234, 0.6651075294117647, 0.9633624117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 46}], {
             RGBColor[
             0.9565421176470588, 0.9669342352941177, 0.9523613823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 74}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352941, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.9896552647058823, 0.9898491764705882, 0.810851617647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 117}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352941, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 121}], {
             RGBColor[
             0.9756344117647058, 0.9813487647058823, 0.9261287647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 166}], {
             RGBColor[
             0.8916394705882353, 0.9153515294117647, 0.9461260882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 169}], {
             RGBColor[
             0.8916394705882353, 0.9153515294117647, 0.9461260882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 171}], {
             RGBColor[
             0.7965954117647058, 0.8405913529411765, 0.9370023823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 173}], {
             RGBColor[
             0.9655125588235294, 0.9073245294117648, 0.5938609411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 196}], {
             RGBColor[
             0.9565421176470588, 0.9669342352941177, 0.9523613823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 57}], {
             RGBColor[
             0.8880516470588234, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 66}], {
             RGBColor[0.7485252352941176, 0.803512, 0.9757730588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 81}], {
             RGBColor[
             0.8435692941176471, 0.8782721764705882, 0.9848967647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 90}], {
             RGBColor[
             0.9275642352941176, 0.9442694117647058, 0.9648994411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 141}], {
             RGBColor[
             0.8122237058823528, 0.8537847647058823, 0.9817725294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 168}], {
             RGBColor[
             0.6281636470588234, 0.7034879411764705, 0.9669357647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 172}], {
             RGBColor[
             0.9406042647058823, 0.9506719411764706, 0.742865705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 184}], {
             RGBColor[
             0.8907484999999999, 0.7613071764705881, 0.6109924411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 198}], {
             RGBColor[
             0.8991826176470588, 0.7978512941176471, 0.6179393823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 88}], {
             RGBColor[
             0.6413517058823528, 0.7192370588235293, 0.9652369999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[
             0.745511794117647, 0.43957470588235287`, 0.5661651176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 102}], {
             RGBColor[
             0.8344115588235292, 0.868494882352941, 0.8390862352941179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 153}], {
             RGBColor[0.8012984117647057, 0.8455799411764705, 0.980596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 49}], {
             RGBColor[
             0.8676313529411763, 0.8972897058823528, 0.9872366470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 67}], {
             RGBColor[
             0.6947447647058823, 0.7601461176470587, 0.9711991176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 87}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 95}], {
             RGBColor[
             0.8880516470588234, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 103}], {
             RGBColor[
             0.7918034117647057, 0.8375021764705881, 0.9798248235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 129}], {
             RGBColor[
             0.7281049411764705, 0.7872294117647058, 0.9738253529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 131}], {
             RGBColor[
             0.8703282058823529, 0.7450245882352939, 0.6090447352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 133}], {
             RGBColor[
             0.6077433529411764, 0.6872053529411764, 0.9649880588235293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 143}], {
             RGBColor[0.8985863529411764, 0.9216045882352941, 0.9774375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 154}], {
             RGBColor[
             0.9048111470588236, 0.8829367647058824, 0.6468820588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 197}], {
             RGBColor[
             0.8880516470588234, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 50}], {
             RGBColor[
             0.9112593823529411, 0.9046881764705883, 0.6719322352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 57}], {
             RGBColor[
             0.8676313529411763, 0.8972897058823528, 0.9872366470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 60}], {
             RGBColor[
             0.7281049411764705, 0.7872294117647058, 0.9738253529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 90}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 141}], {
             RGBColor[
             0.7918034117647057, 0.8375021764705881, 0.9798248235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 177}], {
             RGBColor[
             0.8880516470588234, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 120}], {
             RGBColor[
             0.8154534411764707, 0.544279823529412, 0.5793566470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 128}], {
             RGBColor[0.8395155, 0.5632973529411767, 0.5816965294117648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 168}], {
             RGBColor[
             0.6000477941176471, 0.36949558823529427`, 0.5613956470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 172}], {
             RGBColor[
             0.9124884117647059, 0.6166795882352945, 0.33732558823529424`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 173}], {
             RGBColor[
             0.8893265294117647, 0.536252823529412, 0.22709150000000006`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 85}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 98}], {
             RGBColor[
             0.8639895882352941, 0.8945547647058824, 0.9868444705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 99}], {
             RGBColor[
             0.7355853529411764, 0.7927112941176471, 0.9750945294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 109}], {
             RGBColor[
             0.6230712352941176, 0.6976727058823529, 0.9672578235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 117}], {
             RGBColor[
             0.9604562352941176, 0.9685528235294117, 0.8874943235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 121}], {
             RGBColor[0.9479845294117646, 0.960552, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 146}], {
             RGBColor[
             0.6230712352941176, 0.6976727058823529, 0.9672578235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 151}], {
             RGBColor[
             0.9394269411764705, 0.9541697647058823, 0.9813329117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 171}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 178}], {
             RGBColor[
             0.9456517352941176, 0.9155019411764707, 0.6507774705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 196}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 54}], {
             RGBColor[
             0.7965954117647058, 0.8405913529411765, 0.9370023823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 61}], {
             RGBColor[0.7485252352941176, 0.803512, 0.9757730588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 73}], {
             RGBColor[
             0.5141499411764705, 0.6155254705882353, 0.9551501176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 88}], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 94}], {
             RGBColor[
             0.8015682647058824, 0.8416605882352941, 0.7828327058823532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 105}], {
             RGBColor[
             0.7687860882352942, 0.7239879411764708, 0.611874205882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 111}], {
             RGBColor[0.7596562058823529, 0.687791, 0.6045280882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 116}], {
             RGBColor[
             0.6413517058823528, 0.7192370588235293, 0.9652369999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 126}], {
             RGBColor[0.7986015, 0.8326618823529411, 0.6855188235294116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 142}], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 153}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 157}], {
             RGBColor[
             0.672697294117647, 0.7437244705882352, 0.9683612352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 160}], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 167}], {
             RGBColor[
             0.8015682647058824, 0.8416605882352941, 0.7828327058823532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 174}], {
             RGBColor[
             0.7880378235294117, 0.8342091176470587, 0.9514881470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 188}], {
             RGBColor[
             0.8015682647058824, 0.8416605882352941, 0.7828327058823532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 59}], {
             RGBColor[
             0.7990869411764707, 0.8429720588235294, 0.9806091764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.7040428823529412, 0.7682118823529411, 0.9714854705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 77}], {
             RGBColor[
             0.511916205882353, 0.598262088235294, 0.9583597352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 106}], {
             RGBColor[
             0.7040428823529412, 0.7682118823529411, 0.9714854705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 112}], {
             RGBColor[
             0.670682705882353, 0.7411285882352942, 0.9688592352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 140}], {
             RGBColor[
             0.8830818823529412, 0.908969294117647, 0.9606118529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 193}], {
             RGBColor[
             0.8745242941176471, 0.9025870588235294, 0.9750976176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 67}], {
             RGBColor[
             0.7151650588235294, 0.7764287058823529, 0.9731468235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.9275642352941176, 0.9442694117647058, 0.9648994411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 95}], {
             RGBColor[
             0.9084719411764706, 0.9298548823529411, 0.9911320588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 103}], {
             RGBColor[
             0.8122237058823528, 0.8537847647058823, 0.9817725294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 108}], {
             RGBColor[0.7485252352941176, 0.803512, 0.9757730588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[0.7485252352941176, 0.803512, 0.9757730588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 131}], {
             RGBColor[
             0.8907484999999999, 0.7613071764705881, 0.6109924411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 133}], {
             RGBColor[
             0.6281636470588234, 0.7034879411764705, 0.9669357647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 143}], {
             RGBColor[
             0.9190066470588234, 0.9378871764705882, 0.9793852058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 154}], {
             RGBColor[
             0.9252314411764706, 0.8992193529411765, 0.6488297647058825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 162}], {
             RGBColor[
             0.9400359411764705, 0.9522702352941176, 0.8855466176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 53}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 60}], {
             RGBColor[
             0.7921532647058823, 0.8109104705882353, 0.6604686470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 82}], {
             RGBColor[
             0.9797498529411764, 0.9580501176470588, 0.6351092647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 100}], {
             RGBColor[
             0.9852131176470589, 0.960168294117647, 0.5343178823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 104}], {
             RGBColor[
             0.8558517352941175, 0.8611832352941176, 0.6664681176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 123}], {
             RGBColor[
             0.9316796764705881, 0.9209707647058823, 0.6738799411764707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.9817559411764706, 0.9501206470588235, 0.3836257058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 163}], {
             RGBColor[
             0.9797498529411764, 0.9580501176470588, 0.6351092647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 177}], {
             RGBColor[
             0.9520999705882353, 0.9372533529411765, 0.6758276470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 71}], {
             RGBColor[
             0.6273779705882352, 0.6947206176470588, 0.925181294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 74}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352941, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 158}], {
             RGBColor[
             0.9896552647058823, 0.9898491764705882, 0.810851617647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 164}], {
             RGBColor[
             0.9361218235294118, 0.9506516470588235, 0.9504136764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 166}], {
             RGBColor[
             0.8916394705882353, 0.9153515294117647, 0.9461260882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 184}], {
             RGBColor[
             0.9388186764705881, 0.7983865294117647, 0.5722217647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 70}], {
             RGBColor[
             0.9287327941176471, 0.850330823529412, 0.627233205882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 134}], {
             RGBColor[
             0.9585482058823529, 0.9590047647058824, 0.7008778235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 145}], {
             RGBColor[
             0.8639895882352941, 0.8945547647058824, 0.9868444705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 100}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 104}], {
             RGBColor[
             0.672697294117647, 0.7437244705882352, 0.9683612352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 123}], {
             RGBColor[0.7485252352941176, 0.803512, 0.9757730588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 130}], {
             RGBColor[0.7986015, 0.8326618823529411, 0.6855188235294116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 135}], {
             RGBColor[
             0.7794802352941176, 0.8278268823529411, 0.9659739117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 148}], {
             RGBColor[
             0.8015682647058824, 0.8416605882352941, 0.7828327058823532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 163}], {
             RGBColor[
             0.7965954117647058, 0.8405913529411765, 0.9370023823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 165}], {
             RGBColor[
             0.6413517058823528, 0.7192370588235293, 0.9652369999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 58}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352941, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 61}], {
             RGBColor[
             0.9361218235294118, 0.9506516470588235, 0.9504136764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 73}], {
             RGBColor[
             0.7017465294117646, 0.7626651176470588, 0.9297907352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 94}], {
             RGBColor[
             0.9891648529411765, 0.9888002352941176, 0.7574733235294121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 105}], {
             RGBColor[
             0.9563826764705883, 0.8711275882352943, 0.5865148235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 115}], {
             RGBColor[
             0.9361218235294118, 0.9506516470588235, 0.9504136764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 116}], {
             RGBColor[
             0.8289482941176469, 0.8663767058823528, 0.9398776176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 126}], {
             RGBColor[
             0.9861980882352941, 0.9798015294117647, 0.6601594411764705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 160}], {
             RGBColor[
             0.7965954117647058, 0.8405913529411765, 0.9370023823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 174}], {
             RGBColor[
             0.9756344117647058, 0.9813487647058823, 0.9261287647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 62}], {
             RGBColor[
             0.8638301470588237, 0.798748117647059, 0.620997911764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 68}], {
             RGBColor[
             0.887892205882353, 0.8177656470588237, 0.6233377941176471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 72}], {
             RGBColor[0.9083125000000001, 0.8340482352941179, 0.6252855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 75}], {
             RGBColor[
             0.6484245000000001, 0.6239638823529414, 0.6030369117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 76}], {
             RGBColor[0.9083125000000001, 0.8340482352941179, 0.6252855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 96}], {
             RGBColor[
             0.735425911764706, 0.6969046470588238, 0.6092479705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 107}], {
             RGBColor[
             0.6484245000000001, 0.6239638823529414, 0.6030369117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 111}], {
             RGBColor[
             0.9194434705882354, 0.7183272352941179, 0.2540405294117648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 139}], {
             RGBColor[
             0.8638301470588237, 0.798748117647059, 0.620997911764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 147}], {
             RGBColor[
             0.8948368823529412, 0.6083477058823532, 0.23359888235294124`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 157}], {
             RGBColor[
             0.8324845588235295, 0.7742607058823531, 0.6178736764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 182}], {
             RGBColor[
             0.9478250882352941, 0.8647453529411766, 0.6010005882352942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 185}], {
             RGBColor[
             0.7020657352941178, 0.6698213529411767, 0.6066217352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 191}], {
             RGBColor[
             0.9478250882352941, 0.8647453529411766, 0.6010005882352942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 79}], {
             RGBColor[0.6373225294117648, 0.7140452941176471, 0.966233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 118}], {
             RGBColor[
             0.8916394705882353, 0.9153515294117647, 0.9461260882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 119}], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 125}], {
             RGBColor[
             0.670682705882353, 0.7411285882352942, 0.9688592352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 129}], {
             RGBColor[
             0.7040428823529412, 0.7682118823529411, 0.9714854705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 149}], {
             RGBColor[0.609194, 0.6902856470588234, 0.9642738235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 170}], {
             RGBColor[
             0.8639895882352941, 0.8945547647058824, 0.9868444705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 190}], {
             RGBColor[
             0.8830818823529412, 0.908969294117647, 0.9606118529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 195}], {
             RGBColor[
             0.8936455588235295, 0.9074220588235293, 0.6946425294117646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 197}], {
             RGBColor[
             0.8639895882352941, 0.8945547647058824, 0.9868444705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 66}], {
             RGBColor[0.7485252352941176, 0.803512, 0.9757730588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 71}], {
             RGBColor[
             0.579307794117647, 0.6576412647058822, 0.9639519705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 81}], {
             RGBColor[
             0.8435692941176471, 0.8782721764705882, 0.9848967647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 90}], {
             RGBColor[
             0.9275642352941176, 0.9442694117647058, 0.9648994411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 141}], {
             RGBColor[
             0.8122237058823528, 0.8537847647058823, 0.9817725294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 198}], {
             RGBColor[
             0.8991826176470588, 0.7978512941176471, 0.6179393823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 61}], {
             RGBColor[
             0.9400359411764705, 0.9522702352941176, 0.8855466176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 73}], {
             RGBColor[
             0.7056606470588236, 0.7642837058823528, 0.8649236764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 92}], {
             RGBColor[
             0.9930789705882352, 0.9904188235294118, 0.6926062647058827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 115}], {
             RGBColor[
             0.9400359411764705, 0.9522702352941176, 0.8855466176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 155}], {
             RGBColor[
             0.8005095294117647, 0.8422099411764705, 0.8721353235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 154}], {
             RGBColor[
             0.8807490882352942, 0.8639192352941178, 0.6445421764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 186}], {
             RGBColor[
             0.670682705882353, 0.7411285882352942, 0.9688592352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 193}], {
             RGBColor[
             0.8745242941176471, 0.9025870588235294, 0.9750976176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.7965954117647058, 0.8405913529411765, 0.9370023823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 104}], {
             RGBColor[
             0.672697294117647, 0.7437244705882352, 0.9683612352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 123}], {
             RGBColor[0.7485252352941176, 0.803512, 0.9757730588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 130}], {
             RGBColor[0.7986015, 0.8326618823529411, 0.6855188235294116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 163}], {
             RGBColor[
             0.7965954117647058, 0.8405913529411765, 0.9370023823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 177}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 73}], {
             RGBColor[
             0.6536763529411764, 0.7255857647058823, 0.9685614117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 94}], {
             RGBColor[
             0.9410946764705882, 0.9517208823529412, 0.7962440000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 105}], {
             RGBColor[0.9083125000000001, 0.8340482352941179, 0.6252855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 115}], {
             RGBColor[
             0.8880516470588234, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 116}], {
             RGBColor[
             0.7808781176470587, 0.8292973529411763, 0.9786482941176471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 160}], {
             RGBColor[0.7485252352941176, 0.803512, 0.9757730588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 174}], {
             RGBColor[
             0.9275642352941176, 0.9442694117647058, 0.9648994411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 68}], {
             RGBColor[0.823149, 0.8619895882352941, 0.9829490588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 75}], {
             RGBColor[
             0.5836812941176471, 0.6681878235294118, 0.9626481764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 76}], {
             RGBColor[
             0.8435692941176471, 0.8782721764705882, 0.9848967647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 96}], {
             RGBColor[
             0.670682705882353, 0.7411285882352942, 0.9688592352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 105}], {
             RGBColor[
             0.8638301470588237, 0.798748117647059, 0.620997911764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 107}], {
             RGBColor[
             0.5836812941176471, 0.6681878235294118, 0.9626481764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 111}], {
             RGBColor[
             0.8547002647058825, 0.7625511764705883, 0.613651794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 116}], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 126}], {
             RGBColor[
             0.8936455588235295, 0.9074220588235293, 0.6946425294117646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 157}], {
             RGBColor[
             0.7677413529411765, 0.8184846470588234, 0.9774849411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 174}], {
             RGBColor[
             0.8830818823529412, 0.908969294117647, 0.9606118529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 182}], {
             RGBColor[
             0.8830818823529412, 0.908969294117647, 0.9606118529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 185}], {
             RGBColor[0.6373225294117648, 0.7140452941176471, 0.966233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 191}], {
             RGBColor[
             0.8830818823529412, 0.908969294117647, 0.9606118529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 77}], {
             RGBColor[
             0.4168721470588235, 0.5235019117647058, 0.9492360294117648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 91}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 102}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 106}], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 112}], {
             RGBColor[
             0.5756386470588235, 0.666368411764706, 0.9597355294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 140}], {
             RGBColor[
             0.7880378235294117, 0.8342091176470587, 0.9514881470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 69}], {
             RGBColor[
             0.9433011176470588, 0.7984068235294117, 0.36467379411764717`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 82}], {
             RGBColor[
             0.9886744411764705, 0.9877512941176472, 0.7040950294117648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 86}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 87}], {
             RGBColor[
             0.9801168529411765, 0.9813690588235294, 0.7185807941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 108}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 110}], {
             RGBColor[
             0.9936472941176471, 0.9888205294117648, 0.549925352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 127}], {
             RGBColor[
             0.9201839705882353, 0.9343893529411764, 0.7409180000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 154}], {
             RGBColor[
             0.9777840588235295, 0.9363190000000001, 0.40251111764705905`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 161}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 162}], {
             RGBColor[
             0.9925885588235295, 0.9893698823529412, 0.6392279705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 175}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 176}], {
             RGBColor[
             0.9352148823529411, 0.7616891176470588, 0.3579264411764707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 180}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 66}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 69}], {
             RGBColor[
             0.911168794117647, 0.7775897647058823, 0.6129401470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 87}], {
             RGBColor[0.9479845294117646, 0.960552, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 90}], {
             RGBColor[0.9479845294117646, 0.960552, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 110}], {
             RGBColor[
             0.9615149705882353, 0.9680034705882353, 0.7981917058823533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 131}], {
             RGBColor[
             0.911168794117647, 0.7775897647058823, 0.6129401470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 133}], {
             RGBColor[
             0.6485839411764706, 0.7197705294117647, 0.9688834705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 162}], {
             RGBColor[
             0.9604562352941176, 0.9685528235294117, 0.8874943235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 180}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 198}], {
             RGBColor[
             0.9196029117647059, 0.8141338823529413, 0.6198870882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 81}], {
             RGBColor[
             0.7040428823529412, 0.7682118823529411, 0.9714854705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 90}], {
             RGBColor[
             0.7880378235294117, 0.8342091176470587, 0.9514881470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 141}], {
             RGBColor[
             0.672697294117647, 0.7437244705882352, 0.9683612352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 168}], {
             RGBColor[
             0.4886372352941176, 0.5934276470588236, 0.9535244705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 172}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 198}], {
             RGBColor[0.7596562058823529, 0.687791, 0.6045280882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 87}], {
             RGBColor[
             0.7546776470588235, 0.8071258235294118, 0.9488619117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 103}], {
             RGBColor[0.6393371176470588, 0.7166411764705882, 0.965735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 129}], {
             RGBColor[
             0.5756386470588235, 0.666368411764706, 0.9597355294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 131}], {
             RGBColor[
             0.7178619117647058, 0.624163588235294, 0.5949549117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 133}], {
             RGBColor[
             0.4552770588235294, 0.5663443529411765, 0.9508982352941175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 143}], {
             RGBColor[
             0.7461200588235294, 0.8007435882352941, 0.9633476764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 162}], {
             RGBColor[
             0.7671493529411765, 0.8151266470588235, 0.869509088235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 107}], {
             RGBColor[
             0.6077433529411764, 0.6872053529411764, 0.9649880588235293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 111}], {
             RGBColor[
             0.8787623235294117, 0.781568705882353, 0.6159916764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 122}], {
             RGBColor[
             0.6947447647058823, 0.7601461176470587, 0.9711991176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 138}], {
             RGBColor[
             0.9201839705882353, 0.9343893529411764, 0.7409180000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 142}], {
             RGBColor[
             0.7281049411764705, 0.7872294117647058, 0.9738253529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 147}], {
             RGBColor[
             0.8541557352941176, 0.6715891764705884, 0.5955500294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 156}], {
             RGBColor[
             0.8880516470588234, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 157}], {
             RGBColor[
             0.7918034117647057, 0.8375021764705881, 0.9798248235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 179}], {
             RGBColor[
             0.8676313529411763, 0.8972897058823528, 0.9872366470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 181}], {
             RGBColor[
             0.7281049411764705, 0.7872294117647058, 0.9738253529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 185}], {
             RGBColor[
             0.661384588235294, 0.7330628235294117, 0.9685728823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 82}], {
             RGBColor[
             0.9388186764705881, 0.7983865294117647, 0.5722217647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 86}], {
             RGBColor[
             0.9442819411764706, 0.8005047058823529, 0.47143038235294144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 90}], {
             RGBColor[
             0.9302610882352941, 0.792004294117647, 0.5867075294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 110}], {
             RGBColor[
             0.9437915294117647, 0.7994557647058823, 0.4180520882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 123}], {
             RGBColor[
             0.8907484999999999, 0.7613071764705881, 0.6109924411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 127}], {
             RGBColor[
             0.8703282058823529, 0.7450245882352939, 0.6090447352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 177}], {
             RGBColor[
             0.911168794117647, 0.7775897647058823, 0.6129401470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 180}], {
             RGBColor[
             0.9442819411764706, 0.8005047058823529, 0.47143038235294144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 72}], {
             RGBColor[0.9083125000000001, 0.8340482352941179, 0.6252855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 93}], {
             RGBColor[
             0.7687860882352942, 0.7239879411764708, 0.611874205882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 134}], {
             RGBColor[
             0.9583887647058824, 0.863198117647059, 0.33503126470588235`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 139}], {
             RGBColor[
             0.8638301470588237, 0.798748117647059, 0.620997911764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.8638301470588237, 0.798748117647059, 0.620997911764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 81}], {
             RGBColor[
             0.5348254411764706, 0.6223411470588235, 0.9596643823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 164}], {
             RGBColor[
             0.579307794117647, 0.6576412647058822, 0.9639519705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 184}], {
             RGBColor[
             0.5820046470588235, 0.5053761470588234, 0.5857600588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 75}], {
             RGBColor[
             0.6281636470588234, 0.7034879411764705, 0.9669357647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 84}], {
             RGBColor[
             0.9361218235294118, 0.9506516470588235, 0.9504136764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 93}], {
             RGBColor[0.7485252352941176, 0.803512, 0.9757730588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 134}], {
             RGBColor[
             0.9381279117647059, 0.9427221764705882, 0.6989301176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 139}], {
             RGBColor[
             0.8435692941176471, 0.8782721764705882, 0.9848967647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 152}], {
             RGBColor[
             0.9381279117647059, 0.9427221764705882, 0.6989301176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 191}], {
             RGBColor[
             0.9275642352941176, 0.9442694117647058, 0.9648994411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 94}], {
             RGBColor[
             0.7067193823529412, 0.7637343529411764, 0.7756210588235297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 115}], {
             RGBColor[
             0.6536763529411764, 0.7255857647058823, 0.9685614117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 153}], {
             RGBColor[
             0.6740966470588234, 0.7418683529411765, 0.9705091176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 160}], {
             RGBColor[
             0.5141499411764705, 0.6155254705882353, 0.9551501176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 80}], {
             RGBColor[
             0.9935693823529412, 0.9914677647058823, 0.7459845588235297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 158}], {
             RGBColor[
             0.9935693823529412, 0.9914677647058823, 0.7459845588235297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 164}], {
             RGBColor[
             0.9400359411764705, 0.9522702352941176, 0.8855466176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 166}], {
             RGBColor[
             0.8955535882352942, 0.9169701176470588, 0.8812590294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 169}], {
             RGBColor[
             0.8955535882352942, 0.9169701176470588, 0.8812590294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 184}], {
             RGBColor[
             0.9427327941176471, 0.8000051176470587, 0.5073547058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 76}], {
             RGBColor[
             0.6281636470588234, 0.7034879411764705, 0.9669357647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 96}], {
             RGBColor[
             0.4552770588235294, 0.5663443529411765, 0.9508982352941175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 134}], {
             RGBColor[
             0.6782399117647058, 0.7326378235294118, 0.6766815294117646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 139}], {
             RGBColor[
             0.5836812941176471, 0.6681878235294118, 0.9626481764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 182}], {
             RGBColor[
             0.6676762352941177, 0.7341850588235294, 0.9426508529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 191}], {
             RGBColor[
             0.6676762352941177, 0.7341850588235294, 0.9426508529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.7151650588235294, 0.7764287058823529, 0.9731468235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 105}], {
             RGBColor[0.9083125000000001, 0.8340482352941179, 0.6252855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 111}], {
             RGBColor[
             0.8991826176470588, 0.7978512941176471, 0.6179393823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 116}], {
             RGBColor[
             0.7808781176470587, 0.8292973529411763, 0.9786482941176471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 126}], {
             RGBColor[
             0.9381279117647059, 0.9427221764705882, 0.6989301176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 174}], {
             RGBColor[
             0.9275642352941176, 0.9442694117647058, 0.9648994411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.9275642352941176, 0.9442694117647058, 0.9648994411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 191}], {
             RGBColor[
             0.9275642352941176, 0.9442694117647058, 0.9648994411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 102}], {
             RGBColor[
             0.6099319999999999, 0.6727597352941176, 0.8230852647058826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 106}], {
             RGBColor[
             0.4168721470588235, 0.5235019117647058, 0.9492360294117648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 112}], {
             RGBColor[
             0.3835119705882353, 0.4964186176470588, 0.946609794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 140}], {
             RGBColor[
             0.5959111470588234, 0.6642593235294116, 0.9383624117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 189}], {
             RGBColor[
             0.3835119705882353, 0.4964186176470588, 0.946609794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 91}], {
             RGBColor[
             0.6816970882352942, 0.7426854705882353, 0.8273737058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 95}], {
             RGBColor[
             0.6485839411764704, 0.7197705294117647, 0.9688834705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 113}], {
             RGBColor[
             0.6072982647058823, 0.4252258823529411, 0.5683387058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 136}], {
             RGBColor[
             0.6485839411764704, 0.7197705294117647, 0.9688834705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 89}], {
             RGBColor[0.6373225294117648, 0.7140452941176471, 0.966233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 118}], {
             RGBColor[
             0.7298750588235294, 0.7864247647058824, 0.9317499117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 119}], {
             RGBColor[
             0.5746313529411764, 0.6650704705882352, 0.9599845294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 125}], {
             RGBColor[
             0.5089182941176471, 0.6122018235294118, 0.9544830588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 128}], {
             RGBColor[
             0.661384588235294, 0.7330628235294117, 0.9685728823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 144}], {
             RGBColor[
             0.7337891764705882, 0.7880433529411764, 0.8668828529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 149}], {
             RGBColor[
             0.4474295882352941, 0.5613588823529412, 0.9498976470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 159}], {
             RGBColor[
             0.7298750588235294, 0.7864247647058824, 0.9317499117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 170}], {
             RGBColor[0.7022251764705882, 0.765628, 0.972468294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 190}], {
             RGBColor[
             0.7213174705882353, 0.7800425294117647, 0.9462356764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 192}], {
             RGBColor[
             0.5089182941176471, 0.6122018235294118, 0.9544830588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 195}], {
             RGBColor[
             0.7318811470588236, 0.7784952941176471, 0.6802663529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 197}], {
             RGBColor[0.7022251764705882, 0.765628, 0.972468294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 81}], {
             RGBColor[
             0.8971027352941177, 0.9174697058823529, 0.8453347058823532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 117}], {
             RGBColor[
             0.9935693823529412, 0.9914677647058823, 0.7459845588235297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 120}], {
             RGBColor[
             0.8971027352941177, 0.9174697058823529, 0.8453347058823532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 121}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764705, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 166}], {
             RGBColor[
             0.8971027352941177, 0.9174697058823529, 0.8453347058823532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 168}], {
             RGBColor[
             0.6816970882352941, 0.7426854705882353, 0.8273737058823531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 172}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 173}], {
             RGBColor[
             0.9709758235294118, 0.909442705882353, 0.49306955882352965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 184}], {
             RGBColor[
             0.9442819411764706, 0.8005047058823529, 0.4714303823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 164}], {
             RGBColor[
             0.8435692941176471, 0.8782721764705882, 0.9848967647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 166}], {
             RGBColor[
             0.7990869411764707, 0.8429720588235294, 0.9806091764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 168}], {
             RGBColor[
             0.5836812941176471, 0.6681878235294118, 0.9626481764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 172}], {
             RGBColor[
             0.8961219117647059, 0.9153718235294118, 0.7385781176470589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 173}], {
             RGBColor[
             0.8729600294117648, 0.8349450588235294, 0.6283440294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 184}], {
             RGBColor[
             0.8462661470588235, 0.7260070588235293, 0.6067048529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 198}], {
             RGBColor[
             0.8547002647058825, 0.7625511764705883, 0.613651794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 86}], {
             RGBColor[
             0.9896552647058823, 0.9898491764705882, 0.810851617647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 101}], {
             RGBColor[
             0.9891648529411765, 0.9888002352941176, 0.7574733235294121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 110}], {
             RGBColor[
             0.9891648529411765, 0.9888002352941176, 0.7574733235294121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 123}], {
             RGBColor[
             0.9361218235294118, 0.9506516470588235, 0.9504136764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 127}], {
             RGBColor[
             0.9157015294117646, 0.9343690588235294, 0.9484659705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 130}], {
             RGBColor[
             0.9861980882352941, 0.9798015294117647, 0.6601594411764705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 163}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 176}], {
             RGBColor[
             0.9307324411764706, 0.7616688235294118, 0.5654744117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 177}], {
             RGBColor[
             0.9565421176470588, 0.9669342352941177, 0.9523613823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 180}], {
             RGBColor[
             0.9896552647058823, 0.9898491764705882, 0.810851617647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 187}], {
             RGBColor[
             0.8916394705882353, 0.9153515294117647, 0.9461260882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 86}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 101}], {
             RGBColor[
             0.9946281176470588, 0.9909184117647059, 0.6566819411764712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 124}], {
             RGBColor[
             0.9725400882352941, 0.9770847058823529, 0.8398231470588238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 135}], {
             RGBColor[
             0.9725400882352941, 0.9770847058823529, 0.8398231470588238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 137}], {
             RGBColor[
             0.9916613529411764, 0.9819197058823529, 0.5593680588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 161}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 165}], {
             RGBColor[
             0.8344115588235292, 0.868494882352941, 0.8390862352941179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 175}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 176}], {
             RGBColor[0.9361957058823529, 0.763787, 0.4646830294117649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 187}], {
             RGBColor[
             0.8971027352941177, 0.9174697058823529, 0.8453347058823532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 199}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 93}], {
             RGBColor[
             0.7965954117647058, 0.8405913529411765, 0.9370023823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 139}], {
             RGBColor[
             0.8916394705882353, 0.9153515294117647, 0.9461260882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 152}], {
             RGBColor[
             0.9861980882352941, 0.9798015294117647, 0.6601594411764705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 194}], {
             RGBColor[
             0.9896552647058823, 0.9898491764705882, 0.810851617647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 99}], {
             RGBColor[0.6393371176470588, 0.7166411764705882, 0.965735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 109}], {
             RGBColor[
             0.5268229999999999, 0.621602588235294, 0.957898294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 132}], {
             RGBColor[
             0.5034798529411764, 0.5978537352941176, 0.9565401470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 146}], {
             RGBColor[
             0.5268229999999999, 0.621602588235294, 0.957898294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 150}], {
             RGBColor[
             0.8122237058823528, 0.8537847647058823, 0.9817725294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 151}], {
             RGBColor[
             0.8431787058823528, 0.8780996470588234, 0.9719733823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 152}], {
             RGBColor[
             0.8622999705882353, 0.8829346470588234, 0.691518294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 194}], {
             RGBColor[
             0.8657571470588235, 0.892982294117647, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 196}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 101}], {
             RGBColor[
             0.9946281176470588, 0.9909184117647059, 0.6566819411764712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 108}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 110}], {
             RGBColor[
             0.9946281176470588, 0.9909184117647059, 0.6566819411764712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 124}], {
             RGBColor[
             0.9725400882352941, 0.9770847058823529, 0.8398231470588238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 127}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 161}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 175}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 176}], {
             RGBColor[0.9361957058823529, 0.763787, 0.4646830294117649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 180}], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 187}], {
             RGBColor[
             0.8971027352941177, 0.9174697058823529, 0.8453347058823532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 199}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 95}], {
             RGBColor[0.9479845294117646, 0.960552, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 103}], {
             RGBColor[
             0.851736294117647, 0.884481882352941, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 108}], {
             RGBColor[
             0.7880378235294117, 0.8342091176470587, 0.9514881470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 110}], {
             RGBColor[0.9806072647058823, 0.982418, 0.7719590882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 131}], {
             RGBColor[
             0.9302610882352941, 0.792004294117647, 0.5867075294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 143}], {
             RGBColor[
             0.9585192352941176, 0.968584294117647, 0.9551002941176471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[
             0.9647440294117647, 0.9299164705882355, 0.6245448529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 162}], {
             RGBColor[
             0.9795485294117647, 0.9829673529411764, 0.861261705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 180}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764705, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 94}], {
             RGBColor[
             0.8015682647058824, 0.8416605882352941, 0.7828327058823532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 102}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[
             0.7276598529411764, 0.5252499411764706, 0.5771759999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 122}], {
             RGBColor[
             0.5756386470588235, 0.666368411764706, 0.9597355294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 136}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 142}], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 153}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 167}], {
             RGBColor[
             0.8015682647058824, 0.8416605882352941, 0.7828327058823532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 188}], {
             RGBColor[
             0.8015682647058824, 0.8416605882352941, 0.7828327058823532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 113}], {
             RGBColor[
             0.8227039117647059, 0.6000101176470588, 0.5862997058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 118}], {
             RGBColor[
             0.8916394705882353, 0.9153515294117647, 0.9461260882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 122}], {
             RGBColor[
             0.670682705882353, 0.7411285882352942, 0.9688592352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 136}], {
             RGBColor[
             0.8639895882352941, 0.8945547647058824, 0.9868444705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 138}], {
             RGBColor[
             0.8961219117647059, 0.9153718235294118, 0.7385781176470589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 144}], {
             RGBColor[
             0.8955535882352942, 0.9169701176470588, 0.8812590294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 149}], {
             RGBColor[0.609194, 0.6902856470588234, 0.9642738235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 159}], {
             RGBColor[
             0.8916394705882353, 0.9153515294117647, 0.9461260882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 170}], {
             RGBColor[
             0.8639895882352941, 0.8945547647058824, 0.9868444705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 192}], {
             RGBColor[
             0.670682705882353, 0.7411285882352942, 0.9688592352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 197}], {
             RGBColor[
             0.8639895882352941, 0.8945547647058824, 0.9868444705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 141}], {
             RGBColor[
             0.851736294117647, 0.884481882352941, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 177}], {
             RGBColor[0.9479845294117646, 0.960552, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 198}], {
             RGBColor[
             0.938695205882353, 0.828548411764706, 0.5936544705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 95}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 136}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 97}], {
             RGBColor[
             0.9057283529411765, 0.5619982352941177, 0.3837608235294121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 155}], {
             RGBColor[
             0.8015682647058824, 0.8416605882352941, 0.7828327058823532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 134}], {
             RGBColor[0.7986015, 0.8326618823529411, 0.6855188235294116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 139}], {
             RGBColor[
             0.7040428823529412, 0.7682118823529411, 0.9714854705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 145}], {
             RGBColor[
             0.7040428823529412, 0.7682118823529411, 0.9714854705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 105}], {
             RGBColor[
             0.9613555294117648, 0.872196823529412, 0.43234514705882393`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 111}], {
             RGBColor[
             0.9522256470588235, 0.8359998823529413, 0.42499902941176504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 115}], {
             RGBColor[
             0.9410946764705882, 0.9517208823529412, 0.7962440000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 116}], {
             RGBColor[
             0.8339211470588235, 0.8674459411764706, 0.7857079411764709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 126}], {
             RGBColor[
             0.9911709411764706, 0.9808707647058823, 0.5059897647058826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 142}], {
             RGBColor[
             0.8015682647058824, 0.8416605882352941, 0.7828327058823532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 153}], {
             RGBColor[
             0.9615149705882353, 0.9680034705882353, 0.7981917058823533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 160}], {
             RGBColor[
             0.8015682647058824, 0.8416605882352941, 0.7828327058823532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 167}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 174}], {
             RGBColor[0.9806072647058823, 0.982418, 0.7719590882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 188}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 103}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 129}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 131}], {
             RGBColor[
             0.911168794117647, 0.7775897647058823, 0.6129401470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 143}], {
             RGBColor[
             0.9394269411764705, 0.9541697647058823, 0.9813329117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 154}], {
             RGBColor[
             0.9456517352941176, 0.9155019411764707, 0.6507774705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 105}], {
             RGBColor[
             0.735425911764706, 0.6969046470588238, 0.6092479705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 111}], {
             RGBColor[
             0.7262960294117647, 0.6607077058823531, 0.6019018529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 116}], {
             RGBColor[
             0.6079915294117646, 0.6921537647058823, 0.9626107647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 126}], {
             RGBColor[
             0.7652413235294118, 0.8055785882352942, 0.6828925882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[0.6393371176470588, 0.7166411764705882, 0.965735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 174}], {
             RGBColor[
             0.7546776470588235, 0.8071258235294118, 0.9488619117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 182}], {
             RGBColor[
             0.7546776470588235, 0.8071258235294118, 0.9488619117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 191}], {
             RGBColor[
             0.7546776470588235, 0.8071258235294118, 0.9488619117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 102}], {
             RGBColor[
             0.9062187647058824, 0.5630471764705882, 0.43713911764705904`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 112}], {
             RGBColor[
             0.6797987352941177, 0.38670605882352943`, 0.5606636470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 140}], {
             RGBColor[
             0.8921979117647059, 0.5545467647058824, 0.5524162647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 155}], {
             RGBColor[
             0.7131589117647059, 0.41378935294117647`, 0.5632898823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 99}], {
             RGBColor[
             0.670682705882353, 0.7411285882352942, 0.9688592352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 117}], {
             RGBColor[
             0.8955535882352942, 0.9169701176470588, 0.8812590294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 120}], {
             RGBColor[
             0.7990869411764707, 0.8429720588235294, 0.9806091764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 121}], {
             RGBColor[
             0.8830818823529412, 0.908969294117647, 0.9606118529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 146}], {
             RGBColor[0.5581685882352941, 0.64609, 0.9610225294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 156}], {
             RGBColor[
             0.8639895882352941, 0.8945547647058824, 0.9868444705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.7040428823529412, 0.7682118823529411, 0.9714854705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 178}], {
             RGBColor[
             0.8807490882352942, 0.8639192352941178, 0.6445421764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 179}], {
             RGBColor[
             0.8435692941176471, 0.8782721764705882, 0.9848967647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 183}], {
             RGBColor[
             0.8971027352941177, 0.9174697058823529, 0.8453347058823532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 196}], {
             RGBColor[
             0.8639895882352941, 0.8945547647058824, 0.9868444705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 107}], {
             RGBColor[
             0.4552770588235294, 0.5663443529411765, 0.9508982352941175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 109}], {
             RGBColor[
             0.42976435294117643`, 0.5442465294117647, 0.9492725882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 146}], {
             RGBColor[
             0.42976435294117643`, 0.5442465294117647, 0.9492725882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 147}], {
             RGBColor[
             0.7016894411764706, 0.5507281764705884, 0.5814602058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 156}], {
             RGBColor[
             0.7355853529411764, 0.7927112941176471, 0.9750945294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 178}], {
             RGBColor[
             0.7523448529411765, 0.7620757647058825, 0.6327922352941178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 179}], {
             RGBColor[
             0.7151650588235294, 0.7764287058823529, 0.9731468235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 194}], {
             RGBColor[0.7686985, 0.8156262352941177, 0.8335847647058825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 104}], {
             RGBColor[
             0.8657571470588235, 0.892982294117647, 0.8422104705882355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 123}], {
             RGBColor[
             0.9415850882352941, 0.9527698235294118, 0.8496222941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 130}], {
             RGBColor[
             0.9916613529411764, 0.9819197058823529, 0.5593680588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 135}], {
             RGBColor[
             0.9725400882352941, 0.9770847058823529, 0.8398231470588238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 148}], {
             RGBColor[
             0.9946281176470588, 0.9909184117647059, 0.6566819411764712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 163}], {
             RGBColor[
             0.9896552647058823, 0.9898491764705882, 0.810851617647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 165}], {
             RGBColor[
             0.8344115588235292, 0.868494882352941, 0.8390862352941179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 123}], {
             RGBColor[
             0.9410946764705882, 0.9517208823529412, 0.7962440000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 124}], {
             RGBColor[
             0.9720496764705882, 0.9760357647058824, 0.7864448529411768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 127}], {
             RGBColor[
             0.9206743823529411, 0.9354382941176471, 0.7942962941176475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 135}], {
             RGBColor[
             0.9720496764705882, 0.9760357647058824, 0.7864448529411768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 137}], {
             RGBColor[
             0.9911709411764706, 0.9808707647058823, 0.5059897647058826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 161}], {
             RGBColor[
             0.9911219117647059, 0.9896095294117648, 0.7250397941176475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 165}], {
             RGBColor[
             0.8339211470588235, 0.8674459411764706, 0.7857079411764709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 175}], {
             RGBColor[
             0.9946281176470588, 0.9909184117647059, 0.6566819411764712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 176}], {
             RGBColor[
             0.9357052941176471, 0.7627380588235295, 0.411304735294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 187}], {
             RGBColor[
             0.8966123235294119, 0.9164207647058824, 0.7919564117647062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 199}], {
             RGBColor[
             0.9936472941176471, 0.9888205294117648, 0.549925352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 106}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 112}], {
             RGBColor[0.7686985, 0.8156262352941177, 0.8335847647058825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 140}], {
             RGBColor[
             0.9810976764705882, 0.9834669411764705, 0.8253373823529414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 108}], {
             RGBColor[
             0.672697294117647, 0.7437244705882352, 0.9683612352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 129}], {
             RGBColor[
             0.672697294117647, 0.7437244705882352, 0.9683612352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 131}], {
             RGBColor[
             0.8149205588235293, 0.7015196470588234, 0.6035806176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 133}], {
             RGBColor[
             0.5523357058823528, 0.6437004117647058, 0.9595239411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 143}], {
             RGBColor[
             0.8431787058823528, 0.8780996470588234, 0.9719733823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 154}], {
             RGBColor[0.8494035, 0.8394318235294118, 0.6414179411764707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 162}], {
             RGBColor[
             0.8642079999999999, 0.8924827058823528, 0.878134794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 123}], {
             RGBColor[
             0.8122237058823528, 0.8537847647058823, 0.9817725294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 130}], {
             RGBColor[
             0.8622999705882353, 0.8829346470588234, 0.691518294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 163}], {
             RGBColor[
             0.8602938823529411, 0.8908641176470588, 0.9430018529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 111}], {
             RGBColor[
             0.9194434705882354, 0.7183272352941179, 0.2540405294117648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 116}], {
             RGBColor[
             0.8011389705882352, 0.7497732941176471, 0.6147494411764707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 126}], {
             RGBColor[
             0.9583887647058824, 0.863198117647059, 0.33503126470588235`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 142}], {
             RGBColor[
             0.7687860882352942, 0.7239879411764708, 0.611874205882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 157}], {
             RGBColor[
             0.8324845588235295, 0.7742607058823531, 0.6178736764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 160}], {
             RGBColor[
             0.7687860882352942, 0.7239879411764708, 0.611874205882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 174}], {
             RGBColor[
             0.9478250882352941, 0.8647453529411766, 0.6010005882352942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 182}], {
             RGBColor[
             0.9478250882352941, 0.8647453529411766, 0.6010005882352942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 112}], {
             RGBColor[
             0.5756386470588235, 0.666368411764706, 0.9597355294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 140}], {
             RGBColor[
             0.7880378235294117, 0.8342091176470587, 0.9514881470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 189}], {
             RGBColor[
             0.5756386470588235, 0.666368411764706, 0.9597355294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 111}], {
             RGBColor[
             0.6392946176470589, 0.5877669411764707, 0.595690794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 142}], {
             RGBColor[
             0.4886372352941176, 0.5934276470588236, 0.9535244705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[
             0.6146880294117647, 0.47778741176470596`, 0.5752491470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.6485839411764704, 0.7197705294117647, 0.9688834705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.5523357058823528, 0.6437004117647058, 0.9595239411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.6281636470588234, 0.7034879411764705, 0.9669357647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 181}], {
             RGBColor[
             0.4886372352941176, 0.5934276470588236, 0.9535244705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 185}], {
             RGBColor[0.4219168823529411, 0.5392610588235294, 0.948272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 110}], {
             RGBColor[
             0.8015682647058824, 0.8416605882352941, 0.7828327058823532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 131}], {
             RGBColor[
             0.751222088235294, 0.6512468823529411, 0.5975811470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 154}], {
             RGBColor[
             0.7857050294117647, 0.7891590588235295, 0.6354184705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 162}], {
             RGBColor[
             0.8005095294117647, 0.8422099411764705, 0.8721353235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 180}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 132}], {
             RGBColor[
             0.2939070882352941, 0.4254590882352941, 0.9400777352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 146}], {
             RGBColor[
             0.3172502352941176, 0.44920794117647056`, 0.9414358823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 150}], {
             RGBColor[
             0.6026509411764704, 0.6813901176470587, 0.9653101176470589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 151}], {
             RGBColor[0.6336059411764705, 0.705705, 0.9555109705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 152}], {
             RGBColor[0.652727205882353, 0.71054, 0.6750558823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 194}], {
             RGBColor[
             0.6561843823529412, 0.7205876470588235, 0.8257480588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 196}], {
             RGBColor[
             0.6230712352941177, 0.6976727058823529, 0.9672578235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 127}], {
             RGBColor[
             0.9206743823529411, 0.9354382941176471, 0.7942962941176475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 162}], {
             RGBColor[
             0.9930789705882352, 0.9904188235294118, 0.6926062647058827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 180}], {
             RGBColor[
             0.9946281176470588, 0.9909184117647059, 0.6566819411764712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 116}], {
             RGBColor[
             0.792009088235294, 0.7135763529411765, 0.6074033235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 126}], {
             RGBColor[
             0.9492588823529412, 0.8270011764705882, 0.32768514705882346`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 142}], {
             RGBColor[0.7596562058823529, 0.687791, 0.6045280882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 157}], {
             RGBColor[
             0.8233546764705881, 0.7380637647058823, 0.6105275588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 160}], {
             RGBColor[0.7596562058823529, 0.687791, 0.6045280882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 167}], {
             RGBColor[
             0.9522256470588235, 0.8359998823529413, 0.42499902941176504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 174}], {
             RGBColor[
             0.938695205882353, 0.828548411764706, 0.5936544705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 181}], {
             RGBColor[0.7596562058823529, 0.687791, 0.6045280882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.6929358529411764, 0.633624411764706, 0.5992756176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 188}], {
             RGBColor[
             0.9522256470588235, 0.8359998823529413, 0.42499902941176504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 140}], {
             RGBColor[
             0.7546776470588235, 0.8071258235294118, 0.9488619117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 122}], {
             RGBColor[
             0.6942996764705882, 0.4981666470588235, 0.5745497647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 136}], {
             RGBColor[0.8876065588235293, 0.6515928235294117, 0.592535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 138}], {
             RGBColor[
             0.9197388823529411, 0.6724098823529412, 0.34426864705882365`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 144}], {
             RGBColor[
             0.9191705588235294, 0.6740081764705882, 0.4869495588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 159}], {
             RGBColor[
             0.9152564411764705, 0.6723895882352942, 0.5518166176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 167}], {
             RGBColor[
             0.9202292941176471, 0.6734588235294118, 0.3976469411764709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 197}], {
             RGBColor[0.8876065588235293, 0.6515928235294117, 0.592535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 158}], {
             RGBColor[
             0.6561843823529412, 0.7205876470588235, 0.8257480588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 160}], {
             RGBColor[0.7485252352941176, 0.803512, 0.9757730588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 126}], {
             RGBColor[
             0.8309543823529411, 0.8584472352941175, 0.6883940588235293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 142}], {
             RGBColor[
             0.6413517058823528, 0.7192370588235293, 0.9652369999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 153}], {
             RGBColor[0.8012984117647057, 0.8455799411764705, 0.980596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 157}], {
             RGBColor[
             0.7050501764705881, 0.7695098235294116, 0.9712364705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 160}], {
             RGBColor[
             0.6413517058823528, 0.7192370588235293, 0.9652369999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 167}], {
             RGBColor[
             0.8339211470588235, 0.8674459411764706, 0.7857079411764709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 174}], {
             RGBColor[
             0.8203907058823527, 0.8599944705882352, 0.9543633823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 188}], {
             RGBColor[
             0.8339211470588235, 0.8674459411764706, 0.7857079411764709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 120}], {
             RGBColor[
             0.8955535882352942, 0.9169701176470588, 0.8812590294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 121}], {
             RGBColor[
             0.9795485294117647, 0.9829673529411764, 0.861261705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 146}], {
             RGBColor[
             0.6546352352941176, 0.7200880588235294, 0.8616723823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 151}], {
             RGBColor[
             0.9709909411764706, 0.9765851176470588, 0.8757474705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 171}], {
             RGBColor[
             0.8005095294117647, 0.8422099411764705, 0.8721353235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 173}], {
             RGBColor[
             0.9694266764705883, 0.9089431176470588, 0.5289938823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 196}], {
             RGBColor[
             0.9604562352941176, 0.9685528235294117, 0.8874943235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 119}], {
             RGBColor[
             0.8289482941176469, 0.8663767058823528, 0.9398776176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 125}], {
             RGBColor[
             0.7632352352941176, 0.8135080588235295, 0.9343761470588234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 128}], {
             RGBColor[
             0.9157015294117646, 0.9343690588235294, 0.9484659705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 138}], {
             RGBColor[
             0.9886744411764705, 0.9877512941176472, 0.7040950294117648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 144}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352941, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 149}], {
             RGBColor[
             0.7017465294117646, 0.7626651176470588, 0.9297907352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 159}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 170}], {
             RGBColor[
             0.9565421176470588, 0.9669342352941177, 0.9523613823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 190}], {
             RGBColor[
             0.9756344117647058, 0.9813487647058823, 0.9261287647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 192}], {
             RGBColor[
             0.7632352352941176, 0.8135080588235295, 0.9343761470588234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.9861980882352941, 0.9798015294117647, 0.6601594411764705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 197}], {
             RGBColor[
             0.9565421176470588, 0.9669342352941177, 0.9523613823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 125}], {
             RGBColor[
             0.6079915294117646, 0.6921537647058823, 0.9626107647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 128}], {
             RGBColor[
             0.7604578235294116, 0.8130147647058823, 0.9767005882352942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 144}], {
             RGBColor[
             0.8328624117647058, 0.867995294117647, 0.8750105588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 149}], {
             RGBColor[
             0.5465028235294116, 0.6413108235294116, 0.9580253529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 183}], {
             RGBColor[
             0.8344115588235292, 0.868494882352941, 0.8390862352941179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 190}], {
             RGBColor[
             0.8203907058823527, 0.8599944705882352, 0.9543633823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 192}], {
             RGBColor[
             0.6079915294117646, 0.6921537647058823, 0.9626107647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 195}], {
             RGBColor[
             0.8309543823529411, 0.8584472352941175, 0.6883940588235293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 128}], {
             RGBColor[0.823149, 0.8619895882352941, 0.9829490588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 168}], {
             RGBColor[
             0.5836812941176471, 0.6681878235294118, 0.9626481764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 171}], {
             RGBColor[
             0.7040428823529412, 0.7682118823529411, 0.9714854705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 172}], {
             RGBColor[
             0.8961219117647059, 0.9153718235294118, 0.7385781176470589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 173}], {
             RGBColor[
             0.8729600294117648, 0.8349450588235294, 0.6283440294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 183}], {
             RGBColor[
             0.8971027352941177, 0.9174697058823529, 0.8453347058823532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 151}], {
             RGBColor[
             0.9585192352941176, 0.968584294117647, 0.9551002941176471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 171}], {
             RGBColor[
             0.7880378235294117, 0.8342091176470587, 0.9514881470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 196}], {
             RGBColor[0.9479845294117646, 0.960552, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 136}], {
             RGBColor[
             0.7355853529411764, 0.7927112941176471, 0.9750945294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 138}], {
             RGBColor[
             0.7677176764705882, 0.8135283529411765, 0.7268281764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 142}], {
             RGBColor[
             0.5756386470588235, 0.666368411764706, 0.9597355294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 144}], {
             RGBColor[
             0.7671493529411765, 0.8151266470588235, 0.869509088235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 153}], {
             RGBColor[
             0.7355853529411764, 0.7927112941176471, 0.9750945294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.7632352352941176, 0.8135080588235295, 0.9343761470588234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 167}], {
             RGBColor[
             0.7682080882352942, 0.8145772941176471, 0.7802064705882357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 181}], {
             RGBColor[
             0.5756386470588235, 0.666368411764706, 0.9597355294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 188}], {
             RGBColor[
             0.7682080882352942, 0.8145772941176471, 0.7802064705882357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 192}], {
             RGBColor[
             0.5422784705882353, 0.6392851176470589, 0.957109294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 127}], {
             RGBColor[
             0.8676313529411763, 0.8972897058823528, 0.9872366470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 130}], {
             RGBColor[
             0.9381279117647059, 0.9427221764705882, 0.6989301176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 135}], {
             RGBColor[
             0.9190066470588234, 0.9378871764705882, 0.9793852058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 163}], {
             RGBColor[
             0.9361218235294118, 0.9506516470588235, 0.9504136764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 165}], {
             RGBColor[
             0.7808781176470587, 0.8292973529411763, 0.9786482941176471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 177}], {
             RGBColor[
             0.9084719411764706, 0.9298548823529411, 0.9911320588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 187}], {
             RGBColor[
             0.8435692941176471, 0.8782721764705882, 0.9848967647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 127}], {
             RGBColor[0.8985863529411764, 0.9216045882352941, 0.9774375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 135}], {
             RGBColor[
             0.9499616470588235, 0.9622020588235294, 0.9695860588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.9690829117647058, 0.9670370588235293, 0.6891309705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 161}], {
             RGBColor[
             0.9690338823529412, 0.9757758235294118, 0.9081810000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 175}], {
             RGBColor[
             0.9725400882352941, 0.9770847058823529, 0.8398231470588238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 176}], {
             RGBColor[
             0.9136172647058823, 0.7489043529411765, 0.5944459411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 187}], {
             RGBColor[
             0.8745242941176471, 0.9025870588235294, 0.9750976176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 199}], {
             RGBColor[
             0.9715592647058824, 0.9749868235294118, 0.7330665588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 128}], {
             RGBColor[
             0.6947447647058823, 0.7601461176470587, 0.9711991176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.48078976470588236`, 0.5884421764705883, 0.9525238823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[
             0.7355853529411764, 0.7927112941176471, 0.9750945294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 190}], {
             RGBColor[
             0.7546776470588235, 0.8071258235294118, 0.9488619117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 195}], {
             RGBColor[
             0.7652413235294118, 0.8055785882352942, 0.6828925882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 142}], {
             RGBColor[0.7986015, 0.8326618823529411, 0.6855188235294116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 157}], {
             RGBColor[
             0.8622999705882353, 0.8829346470588234, 0.691518294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 160}], {
             RGBColor[0.7986015, 0.8326618823529411, 0.6855188235294116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 174}], {
             RGBColor[
             0.9776404999999999, 0.9734192941176469, 0.6746452058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 182}], {
             RGBColor[
             0.9776404999999999, 0.9734192941176469, 0.6746452058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 191}], {
             RGBColor[
             0.9776404999999999, 0.9734192941176469, 0.6746452058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 135}], {
             RGBColor[0.8985863529411764, 0.9216045882352941, 0.9774375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 161}], {
             RGBColor[
             0.9176585882352941, 0.9351783529411765, 0.9160324411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 175}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 176}], {
             RGBColor[
             0.8622419705882353, 0.7083068823529411, 0.6022973823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 177}], {
             RGBColor[
             0.8880516470588234, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 180}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 187}], {
             RGBColor[0.823149, 0.8619895882352941, 0.9829490588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 183}], {
             RGBColor[
             0.9211647941176471, 0.9364872352941176, 0.8476745882352943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 190}], {
             RGBColor[
             0.9071439411764706, 0.9279868235294118, 0.9629517352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 192}], {
             RGBColor[
             0.6947447647058823, 0.7601461176470587, 0.9711991176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 195}], {
             RGBColor[
             0.9177076176470588, 0.926439588235294, 0.6969824117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 131}], {
             RGBColor[
             0.751222088235294, 0.6512468823529411, 0.5975811470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 133}], {
             RGBColor[
             0.4886372352941176, 0.5934276470588236, 0.9535244705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 143}], {
             RGBColor[
             0.7794802352941176, 0.8278268823529411, 0.9659739117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 170}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 197}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 163}], {
             RGBColor[
             0.9861980882352941, 0.9798015294117647, 0.6601594411764705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 177}], {
             RGBColor[
             0.9585482058823529, 0.9590047647058824, 0.7008778235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 133}], {
             RGBColor[
             0.6308604999999999, 0.5512228235294117, 0.5887438529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 143}], {
             RGBColor[0.9217035, 0.7856220588235293, 0.6011932941176471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 154}], {
             RGBColor[
             0.9279282941176471, 0.7469542352941176, 0.2706378529411766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 162}], {
             RGBColor[
             0.9427327941176471, 0.8000051176470587, 0.507354705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 180}], {
             RGBColor[
             0.9442819411764706, 0.8005047058823529, 0.47143038235294144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 150}], {
             RGBColor[
             0.579307794117647, 0.6576412647058822, 0.9639519705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 151}], {
             RGBColor[
             0.6102627941176471, 0.6819561470588236, 0.9541528235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 162}], {
             RGBColor[
             0.6801479411764706, 0.7421858823529411, 0.8632980294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 139}], {
             RGBColor[
             0.8936455588235295, 0.9074220588235293, 0.6946425294117646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 145}], {
             RGBColor[
             0.8936455588235295, 0.9074220588235293, 0.6946425294117646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 191}], {
             RGBColor[
             0.9776404999999999, 0.9734192941176469, 0.6746452058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 148}], {
             RGBColor[
             0.9720496764705882, 0.9760357647058824, 0.7864448529411768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 163}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117646, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 165}], {
             RGBColor[
             0.8118331176470587, 0.8536122352941176, 0.9688491470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 176}], {
             RGBColor[
             0.9136172647058823, 0.7489043529411765, 0.5944459411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 187}], {
             RGBColor[
             0.8745242941176471, 0.9025870588235294, 0.9750976176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 143}], {
             RGBColor[
             0.9394269411764705, 0.9541697647058823, 0.9813329117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 159}], {
             RGBColor[
             0.9565421176470588, 0.9669342352941177, 0.9523613823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 197}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 161}], {
             RGBColor[
             0.9881551470588235, 0.9806108235294118, 0.6277259117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 175}], {
             RGBColor[
             0.9916613529411764, 0.9819197058823529, 0.5593680588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 176}], {
             RGBColor[
             0.9327385294117647, 0.7537393529411764, 0.3139908529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 186}], {
             RGBColor[
             0.7652413235294118, 0.8055785882352942, 0.6828925882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 187}], {
             RGBColor[
             0.8936455588235295, 0.9074220588235293, 0.6946425294117646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 199}], {
             RGBColor[
             0.9906805294117647, 0.9798218235294118, 0.45261147058823537`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 142}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 144}], {
             RGBColor[
             0.9925885588235295, 0.9893698823529412, 0.6392279705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 156}], {
             RGBColor[
             0.9610245588235293, 0.9669545294117647, 0.744813411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 159}], {
             RGBColor[
             0.9886744411764705, 0.9877512941176472, 0.7040950294117648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 167}], {
             RGBColor[
             0.9936472941176471, 0.9888205294117648, 0.549925352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 181}], {
             RGBColor[
             0.8010778529411764, 0.8406116470588236, 0.7294544117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 185}], {
             RGBColor[0.7343575, 0.7864450588235294, 0.7242019411764707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 192}], {
             RGBColor[
             0.7677176764705882, 0.8135283529411765, 0.7268281764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 145}], {
             RGBColor[
             0.7990869411764707, 0.8429720588235294, 0.9806091764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 152}], {
             RGBColor[
             0.8936455588235295, 0.9074220588235293, 0.6946425294117646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 182}], {
             RGBColor[
             0.8830818823529412, 0.908969294117647, 0.9606118529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 191}], {
             RGBColor[
             0.8830818823529412, 0.908969294117647, 0.9606118529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 198}], {
             RGBColor[
             0.8233546764705881, 0.7380637647058823, 0.6105275588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 153}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 157}], {
             RGBColor[
             0.672697294117647, 0.7437244705882352, 0.9683612352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 160}], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 167}], {
             RGBColor[
             0.8015682647058824, 0.8416605882352941, 0.7828327058823532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 174}], {
             RGBColor[
             0.7880378235294117, 0.8342091176470587, 0.9514881470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 181}], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 185}], {
             RGBColor[
             0.5422784705882353, 0.6392851176470589, 0.9571092941176471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.8015682647058824, 0.8416605882352941, 0.7828327058823532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 154}], {
             RGBColor[
             0.9561864411764707, 0.9235342352941178, 0.6390306176470589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 159}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117646, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 197}], {
             RGBColor[
             0.9394269411764705, 0.9541697647058823, 0.9813329117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 149}], {
             RGBColor[
             0.7056606470588236, 0.7642837058823528, 0.8649236764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 159}], {
             RGBColor[
             0.9881061176470588, 0.9893495882352941, 0.8467759411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 170}], {
             RGBColor[
             0.9604562352941176, 0.9685528235294117, 0.8874943235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 181}], {
             RGBColor[
             0.8005095294117647, 0.8422099411764705, 0.8721353235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 190}], {
             RGBColor[
             0.9795485294117647, 0.9829673529411764, 0.861261705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 192}], {
             RGBColor[
             0.7671493529411765, 0.8151266470588235, 0.869509088235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 197}], {
             RGBColor[
             0.9604562352941176, 0.9685528235294117, 0.8874943235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 147}], {
             RGBColor[
             0.5891753235294117, 0.4556895882352942, 0.5736235000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 156}], {
             RGBColor[
             0.6230712352941177, 0.6976727058823529, 0.9672578235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 171}], {
             RGBColor[
             0.46312452941176463`, 0.5713298235294118, 0.9518988235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 178}], {
             RGBColor[
             0.6398307352941177, 0.6670371764705884, 0.6249555294117648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 179}], {
             RGBColor[
             0.6026509411764704, 0.6813901176470587, 0.9653101176470589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 183}], {
             RGBColor[
             0.6561843823529412, 0.7205876470588235, 0.8257480588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 194}], {
             RGBColor[
             0.6561843823529412, 0.7205876470588235, 0.8257480588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 196}], {
             RGBColor[
             0.6230712352941177, 0.6976727058823529, 0.9672578235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 152}], {
             RGBColor[
             0.924652294117647, 0.7170216470588235, 0.30724349999999995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 156}], {
             RGBColor[
             0.8949963235294117, 0.7041543529411766, 0.5994454411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 178}], {
             RGBColor[
             0.9117558235294119, 0.6735188235294121, 0.2571431470588237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 179}], {
             RGBColor[
             0.8745760294117646, 0.6878717647058824, 0.5974977352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 185}], {
             RGBColor[
             0.6683292647058823, 0.5236448823529413, 0.5788339705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 194}], {
             RGBColor[
             0.9281094705882353, 0.7270692941176471, 0.4579356764705885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 165}], {
             RGBColor[
             0.8339211470588235, 0.8674459411764706, 0.7857079411764709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 159}], {
             RGBColor[
             0.7017465294117646, 0.7626651176470588, 0.9297907352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 170}], {
             RGBColor[
             0.6740966470588234, 0.7418683529411765, 0.9705091176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 190}], {
             RGBColor[0.6931889411764706, 0.756282882352941, 0.9442765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 192}], {
             RGBColor[
             0.48078976470588236`, 0.5884421764705883, 0.9525238823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 195}], {
             RGBColor[
             0.7037526176470588, 0.7547356470588235, 0.6783071764705881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.6740966470588234, 0.7418683529411765, 0.9705091176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 151}], {
             RGBColor[
             0.9190066470588234, 0.9378871764705882, 0.9793852058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 152}], {
             RGBColor[
             0.9381279117647059, 0.9427221764705882, 0.6989301176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 194}], {
             RGBColor[
             0.9415850882352941, 0.9527698235294118, 0.8496222941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 171}], {
             RGBColor[
             0.7794802352941176, 0.8278268823529411, 0.9659739117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 196}], {
             RGBColor[
             0.9394269411764705, 0.9541697647058823, 0.9813329117647058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 194}], {
             RGBColor[
             0.9916613529411764, 0.9819197058823529, 0.5593680588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 160}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 167}], {
             RGBColor[
             0.9615149705882353, 0.9680034705882353, 0.7981917058823533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 174}], {
             RGBColor[0.9479845294117646, 0.960552, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 188}], {
             RGBColor[
             0.9615149705882353, 0.9680034705882353, 0.7981917058823533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 157}], {
             RGBColor[
             0.8326439999999999, 0.8700673529411764, 0.9837202352941177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 178}], {
             RGBColor[
             0.9456517352941176, 0.9155019411764707, 0.6507774705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.9084719411764706, 0.9298548823529411, 0.9911320588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 181}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 183}], {
             RGBColor[
             0.9620053823529411, 0.9690524117647059, 0.8515700000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 185}], {
             RGBColor[0.7022251764705882, 0.765628, 0.972468294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 192}], {
             RGBColor[
             0.7355853529411764, 0.7927112941176471, 0.9750945294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 174}], {
             RGBColor[
             0.851736294117647, 0.884481882352941, 0.9574876176470588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 181}], {
             RGBColor[
             0.672697294117647, 0.7437244705882352, 0.9683612352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 185}], {
             RGBColor[
             0.6059769411764705, 0.6895578823529411, 0.9631087647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 164}], {
             RGBColor[
             0.9415850882352941, 0.9527698235294118, 0.8496222941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 166}], {
             RGBColor[
             0.8971027352941177, 0.9174697058823529, 0.8453347058823532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 170}], {
             RGBColor[
             0.9565421176470588, 0.9669342352941177, 0.9523613823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 197}], {
             RGBColor[
             0.9565421176470588, 0.9669342352941177, 0.9523613823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 167}], {
             RGBColor[
             0.8015682647058824, 0.8416605882352941, 0.7828327058823532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 174}], {
             RGBColor[
             0.7880378235294117, 0.8342091176470587, 0.9514881470588235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 188}], {
             RGBColor[
             0.8015682647058824, 0.8416605882352941, 0.7828327058823532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 175}], {
             RGBColor[
             0.9916123235294118, 0.9906584705882353, 0.7784180882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 176}], {
             RGBColor[0.9326895, 0.7624781176470589, 0.5330408823529413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 187}], {
             RGBColor[
             0.8935965294117647, 0.9161608235294119, 0.9136925588235295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 193}], {
             RGBColor[
             0.9690338823529412, 0.9757758235294118, 0.9081810000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 199}], {
             RGBColor[0.9906315, 0.9885605882352941, 0.6716615000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 180}], {
             RGBColor[
             0.9935693823529412, 0.9914677647058823, 0.7459845588235297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 177}], {
             RGBColor[
             0.9565421176470588, 0.9669342352941177, 0.9523613823529411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 166}], {
             RGBColor[
             0.8435692941176471, 0.8782721764705882, 0.9848967647058824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 184}], {
             RGBColor[
             0.8907484999999999, 0.7613071764705881, 0.6109924411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 187}], {
             RGBColor[
             0.7363957647058823, 0.7939972352941176, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 184}], {
             RGBColor[
             0.8462661470588235, 0.7260070588235293, 0.6067048529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 181}], {
             RGBColor[
             0.8015682647058824, 0.8416605882352941, 0.7828327058823532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 188}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 172}], {
             RGBColor[
             0.6807162647058824, 0.7405875882352941, 0.7206171176470589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 173}], {
             RGBColor[
             0.6575543823529413, 0.6601608235294119, 0.6103830294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 184}], {
             RGBColor[0.6308605, 0.5512228235294117, 0.5887438529411764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 198}], {
             RGBColor[
             0.6392946176470589, 0.5877669411764707, 0.595690794117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 200}], {
             RGBColor[
             0.7040428823529412, 0.7682118823529411, 0.9714854705882352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 190}], {
             RGBColor[0.9479845294117646, 0.960552, 0.9668471470588236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 195}], {
             RGBColor[
             0.9585482058823529, 0.9590047647058824, 0.7008778235294117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 197}], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 173}], {
             RGBColor[
             0.7779159705882353, 0.7601848823529412, 0.6192203235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 178}], {
             RGBColor[
             0.7857050294117647, 0.7891590588235295, 0.6354184705882354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 183}], {
             RGBColor[
             0.8020586764705881, 0.8427095294117647, 0.8362110000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 196}], {
             RGBColor[
             0.7689455294117646, 0.8197945882352942, 0.9777207647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 173}], {
             RGBColor[0.969995, 0.9073448235294119, 0.38631297058823544`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 198}], {
             RGBColor[
             0.9517352352941177, 0.8349509411764707, 0.37162073529411777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 188}], {
             RGBColor[0.9806072647058823, 0.982418, 0.7719590882352945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 176}], {
             RGBColor[0.9361957058823529, 0.763787, 0.4646830294117649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 187}], {
             RGBColor[
             0.8971027352941177, 0.9174697058823529, 0.8453347058823532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 199}], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 187}], {
             RGBColor[0.838179911764706, 0.6892893529411765, 0.5999575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 199}], {
             RGBColor[
             0.9352148823529411, 0.7616891176470588, 0.35792644117647066`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 179}], {
             RGBColor[
             0.9252314411764706, 0.8992193529411765, 0.6488297647058825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 183}], {
             RGBColor[
             0.9787648823529412, 0.9384168823529413, 0.5092677058823533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 183}], {
             RGBColor[
             0.9415850882352941, 0.9527698235294118, 0.8496222941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 185}], {
             RGBColor[
             0.6818048823529411, 0.7493454117647058, 0.9705205882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 194}], {
             RGBColor[
             0.9415850882352941, 0.9527698235294118, 0.8496222941176472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 185}], {
             RGBColor[
             0.5422784705882353, 0.6392851176470589, 0.9571092941176471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 188}], {
             RGBColor[
             0.8015682647058824, 0.8416605882352941, 0.7828327058823532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 192}], {
             RGBColor[
             0.5756386470588235, 0.666368411764706, 0.9597355294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 191}], {
             RGBColor[
             0.9670768235294117, 0.9749665294117646, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 192}], {
             RGBColor[0.7686985, 0.8156262352941177, 0.8335847647058825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 193}], {
             RGBColor[
             0.7461200588235294, 0.8007435882352941, 0.9633476764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 199}], {
             RGBColor[
             0.7677176764705882, 0.8135283529411765, 0.7268281764705883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 199}], {
             RGBColor[
             0.8961219117647059, 0.9153718235294118, 0.7385781176470589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 192}], {
             RGBColor[
             0.7546776470588235, 0.8071258235294118, 0.9488619117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 195}], {
             RGBColor[
             0.9776404999999999, 0.9734192941176469, 0.6746452058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 199}], {
             RGBColor[
             0.9715592647058824, 0.9749868235294118, 0.7330665588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 197}], {
             RGBColor[
             0.9585482058823529, 0.9590047647058824, 0.7008778235294117]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.04749427504982855], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.04749427504982855], {
             RGBColor[
             0.9499616470588235, 0.9622020588235294, 0.9695860588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.04749427504982855], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.04749427504982855], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.04749427504982855], {
             RGBColor[
             0.9103135882352942, 0.6821302941176473, 0.2466944117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.04749427504982855], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.04749427504982855], {
             RGBColor[
             0.5422784705882353, 0.6392851176470589, 0.957109294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.04749427504982855], {
             RGBColor[
             0.7363957647058822, 0.7939972352941175, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.04749427504982855], {
             RGBColor[
             0.5422784705882353, 0.6392851176470589, 0.957109294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.04749427504982855], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.04749427504982855], {
             RGBColor[
             0.9920202352941176, 0.9909681764705882, 0.7819088823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.04749427504982855], {
             RGBColor[
             0.9499616470588235, 0.9622020588235294, 0.9695860588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.04749427504982855], {
             RGBColor[
             0.7363957647058822, 0.7939972352941175, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.04749427504982855], {
             RGBColor[
             0.5422784705882353, 0.6392851176470589, 0.957109294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.04749427504982855], {
             RGBColor[
             0.9882041764705882, 0.9718720588235293, 0.40867588235294106`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.04749427504982855], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.04749427504982855], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.04749427504982855], {
             RGBColor[
             0.9285733529411766, 0.7545241764705887, 0.26138664705882364`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.04749427504982855], {
             RGBColor[
             0.4755581176470588, 0.5851185294117647, 0.9518568235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.04749427504982855], {
             RGBColor[
             0.8611004117647059, 0.46217123529411785`, 0.20581111764705887`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.04749427504982855], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.04749427504982855], {
             RGBColor[
             0.9499616470588235, 0.9622020588235294, 0.9695860588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.04749427504982855], {
             RGBColor[
             0.7990869411764707, 0.8429720588235294, 0.9806091764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.04749427504982855], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.04749427504982855], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.04749427504982855], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.04749427504982855], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.04749427504982855], {
             RGBColor[
             0.9920202352941176, 0.9909681764705882, 0.7819088823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.04749427504982855], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.04749427504982855], {
             RGBColor[
             0.8472110588235293, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.04749427504982855], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.04749427504982855], {
             RGBColor[
             0.7990869411764707, 0.8429720588235294, 0.9806091764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.04749427504982855], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.04749427504982855], {
             RGBColor[
             0.7990869411764707, 0.8429720588235294, 0.9806091764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.04749427504982855], {
             RGBColor[
             0.8472110588235293, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.04749427504982855], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.04749427504982855], {
             RGBColor[
             0.8880516470588234, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.04749427504982855], {
             RGBColor[
             0.6737045882352939, 0.7450224117647057, 0.9681122352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.04749427504982855], {
             RGBColor[
             0.8472110588235293, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.04749427504982855], {
             RGBColor[
             0.8472110588235293, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.04749427504982855], {
             RGBColor[
             0.8318199411764706, 0.24558758823529453`, 0.17810411764705888`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.04749427504982855], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.04749427504982855], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.04749427504982855], {
             RGBColor[
             0.7990869411764707, 0.8429720588235294, 0.9806091764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.04749427504982855], {
             RGBColor[
             0.8880516470588234, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.04749427504982855], {
             RGBColor[
             0.9753077058823529, 0.9283692352941177, 0.35857552941176474`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.04749427504982855], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.04749427504982855], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.04749427504982855], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.04749427504982855], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.04749427504982855], {
             RGBColor[
             0.9285733529411766, 0.7545241764705887, 0.26138664705882364`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.04749427504982855], {
             RGBColor[
             0.7990869411764707, 0.8429720588235294, 0.9806091764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.04749427504982855], {
             RGBColor[
             0.8880516470588234, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.04749427504982855], {
             RGBColor[
             0.9920202352941176, 0.9909681764705882, 0.7819088823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.04749427504982855], {
             RGBColor[
             0.7990869411764707, 0.8429720588235294, 0.9806091764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.04749427504982855], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.04749427504982855], {
             RGBColor[
             0.8880516470588234, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.04749427504982855], {
             RGBColor[
             0.7990869411764707, 0.8429720588235294, 0.9806091764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.04749427504982855], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.04749427504982855], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.04749427504982855], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.04749427504982855], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.04749427504982855], {
             RGBColor[
             0.5422784705882353, 0.6392851176470589, 0.957109294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.04749427504982855], {
             RGBColor[
             0.8472110588235293, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.04749427504982855], {
             RGBColor[
             0.8934453529411764, 0.6090420588235292, 0.23280052941176468`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.04749427504982855], {
             RGBColor[
             0.9285733529411766, 0.7545241764705887, 0.26138664705882364`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.04749427504982855], {
             RGBColor[
             0.27056394117647053`, 0.4017102352941176, 0.9387195882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.04749427504982855], {
             RGBColor[
             0.8880516470588234, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.04749427504982855], {
             RGBColor[
             0.4193010588235294, 0.5375992352941176, 0.9479384705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.04749427504982855], {
             RGBColor[
             0.9920202352941176, 0.9909681764705882, 0.7819088823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.04749427504982855], {
             RGBColor[
             0.3682756470588235, 0.49340358823529407`, 0.9446871764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.04749427504982855], {
             RGBColor[
             0.8880516470588234, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.04749427504982855], {
             RGBColor[
             0.22474547058823524`, 0.35355211764705874`, 0.9361102941176471]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.04749427504982855], {
             RGBColor[
             0.3682756470588235, 0.49340358823529407`, 0.9446871764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.04749427504982855], {
             RGBColor[
             0.4755581176470588, 0.5851185294117647, 0.9518568235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.04749427504982855], {
             RGBColor[
             0.7990869411764707, 0.8429720588235294, 0.9806091764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.04749427504982855], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.04749427504982855], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.04749427504982855], {
             RGBColor[
             0.7363957647058822, 0.7939972352941175, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.04749427504982855], {
             RGBColor[
             0.9670768235294117, 0.9749665294117646, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.04749427504982855], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.04749427504982855], {
             RGBColor[
             0.7990869411764707, 0.8429720588235294, 0.9806091764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.04749427504982855], {
             RGBColor[
             0.9670768235294117, 0.9749665294117646, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.04749427504982855], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.04749427504982855], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.04749427504982855], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.04749427504982855], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.04749427504982855], {
             RGBColor[
             0.5422784705882353, 0.6392851176470589, 0.957109294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.04749427504982855], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.04749427504982855], {
             RGBColor[
             0.7990869411764707, 0.8429720588235294, 0.9806091764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.04749427504982855], {
             RGBColor[
             0.5422784705882353, 0.6392851176470589, 0.957109294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.04749427504982855], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.04749427504982855], {
             RGBColor[
             0.7363957647058822, 0.7939972352941175, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.04749427504982855], {
             RGBColor[
             0.7363957647058822, 0.7939972352941175, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.04749427504982855], {
             RGBColor[
             0.9285733529411766, 0.7545241764705887, 0.26138664705882364`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.04749427504982855], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.04749427504982855], {
             RGBColor[
             0.3682756470588235, 0.49340358823529407`, 0.9446871764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.04749427504982855], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.04749427504982855], {
             RGBColor[
             0.3172502352941176, 0.44920794117647056`, 0.9414358823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.04749427504982855], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.04749427504982855], {
             RGBColor[
             0.9103135882352942, 0.6821302941176473, 0.2466944117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.04749427504982855], {
             RGBColor[
             0.5422784705882353, 0.6392851176470589, 0.957109294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.04749427504982855], {
             RGBColor[
             0.8463208823529411, 0.3570481764705882, 0.19199023529411763`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.04749427504982855], {
             RGBColor[
             0.3172502352941176, 0.44920794117647056`, 0.9414358823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.04749427504982855], {
             RGBColor[
             0.8880516470588234, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.04749427504982855], {
             RGBColor[
             0.6737045882352939, 0.7450224117647057, 0.9681122352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.04749427504982855], {
             RGBColor[
             0.9920202352941176, 0.9909681764705882, 0.7819088823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.04749427504982855], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.04749427504982855], {
             RGBColor[
             0.6737045882352939, 0.7450224117647057, 0.9681122352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.04749427504982855], {
             RGBColor[
             0.7990869411764707, 0.8429720588235294, 0.9806091764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.04749427504982855], {
             RGBColor[
             0.9670768235294117, 0.9749665294117646, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.04749427504982855], {
             RGBColor[
             0.5422784705882353, 0.6392851176470589, 0.957109294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.04749427504982855], {
             RGBColor[
             0.8880516470588234, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.04749427504982855], {
             RGBColor[
             0.9499616470588235, 0.9622020588235294, 0.9695860588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.04749427504982855], {
             RGBColor[
             0.5422784705882353, 0.6392851176470589, 0.957109294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.04749427504982855], {
             RGBColor[
             0.9882041764705882, 0.9718720588235293, 0.40867588235294106`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.04749427504982855], {
             RGBColor[
             0.8472110588235293, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.04749427504982855], {
             RGBColor[
             0.8472110588235293, 0.8810071176470587, 0.9852889411764706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.04749427504982855], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.04749427504982855], {
             RGBColor[
             0.9882041764705882, 0.9718720588235293, 0.40867588235294106`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.04749427504982855], {
             RGBColor[
             0.8934453529411764, 0.6090420588235292, 0.23280052941176468`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.04749427504982855], {
             RGBColor[
             0.27056394117647053`, 0.4017102352941176, 0.9387195882352941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.04749427504982855], {
             RGBColor[
             0.3682756470588235, 0.49340358823529407`, 0.9446871764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.04749427504982855], {
             RGBColor[
             0.9882041764705882, 0.9718720588235293, 0.40867588235294106`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.04749427504982855], {
             RGBColor[
             0.9499616470588235, 0.9622020588235294, 0.9695860588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.04749427504982855], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.04749427504982855], {
             RGBColor[
             0.9882041764705882, 0.9718720588235293, 0.40867588235294106`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.04749427504982855], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.04749427504982855], {
             RGBColor[
             0.7990869411764707, 0.8429720588235294, 0.9806091764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.04749427504982855], {
             RGBColor[
             0.9670768235294117, 0.9749665294117646, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.04749427504982855], {
             RGBColor[
             0.7363957647058822, 0.7939972352941175, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.04749427504982855], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.04749427504982855], {
             RGBColor[
             0.9499616470588235, 0.9622020588235294, 0.9695860588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.04749427504982855], {
             RGBColor[
             0.9920202352941176, 0.9909681764705882, 0.7819088823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.04749427504982855], {
             RGBColor[
             0.7990869411764707, 0.8429720588235294, 0.9806091764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.04749427504982855], {
             RGBColor[
             0.3172502352941176, 0.44920794117647056`, 0.9414358823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.04749427504982855], {
             RGBColor[
             0.8611004117647059, 0.46217123529411785`, 0.20581111764705887`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.04749427504982855], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.04749427504982855], {
             RGBColor[
             0.4193010588235294, 0.5375992352941176, 0.9479384705882353]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.04749427504982855], {
             RGBColor[
             0.8880516470588234, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.04749427504982855], {
             RGBColor[
             0.9499616470588235, 0.9622020588235294, 0.9695860588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.04749427504982855], {
             RGBColor[
             0.9882041764705882, 0.9718720588235293, 0.40867588235294106`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.04749427504982855], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.04749427504982855], {
             RGBColor[
             0.9624112352941178, 0.8848664117647062, 0.3084751764705885]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.04749427504982855], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.04749427504982855], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.04749427504982855], {
             RGBColor[
             0.7363957647058822, 0.7939972352941175, 0.9743607058823529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.04749427504982855], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.04749427504982855], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.04749427504982855], {
             RGBColor[
             0.9881061176470588, 0.9893495882352942, 0.8467759411764708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.04749427504982855], {
             RGBColor[
             0.9920202352941176, 0.9909681764705882, 0.7819088823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.04749427504982855], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.04749427504982855], {
             RGBColor[
             0.8880516470588234, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.04749427504982855], {
             RGBColor[
             0.6737045882352939, 0.7450224117647057, 0.9681122352941176]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.04749427504982855], {
             RGBColor[
             0.7990869411764707, 0.8429720588235294, 0.9806091764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.04749427504982855], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.04749427504982855], {
             RGBColor[
             0.3682756470588235, 0.49340358823529407`, 0.9446871764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.04749427504982855], {
             RGBColor[
             0.7990869411764707, 0.8429720588235294, 0.9806091764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.04749427504982855], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.04749427504982855], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.04749427504982855], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.04749427504982855], {
             RGBColor[
             0.9468331176470589, 0.8269180588235295, 0.2760788823529412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.04749427504982855], {
             RGBColor[
             0.9670768235294117, 0.9749665294117646, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.04749427504982855], {
             RGBColor[
             0.8772728823529412, 0.5356066470588235, 0.21930582352941178`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.04749427504982855], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.04749427504982855], {
             RGBColor[
             0.9624112352941178, 0.8848664117647062, 0.3084751764705885]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.04749427504982855], {
             RGBColor[
             0.8880516470588234, 0.913572294117647, 0.9891843529411765]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.04749427504982855], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.04749427504982855], {
             RGBColor[
             0.9670768235294117, 0.9749665294117646, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.04749427504982855], {
             RGBColor[
             0.8934453529411764, 0.6090420588235292, 0.23280052941176468`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.04749427504982855], {
             RGBColor[
             0.4755581176470588, 0.5851185294117647, 0.9518568235294118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.04749427504982855], {
             RGBColor[
             0.5422784705882353, 0.6392851176470589, 0.957109294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.04749427504982855], {
             RGBColor[
             0.7990869411764707, 0.8429720588235294, 0.9806091764705882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.04749427504982855], {
             RGBColor[
             0.994137705882353, 0.9898694705882354, 0.6033036470588242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.04749427504982855], {
             RGBColor[
             0.5422784705882353, 0.6392851176470589, 0.957109294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.04749427504982855], {
             RGBColor[
             0.9670768235294117, 0.9749665294117646, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.04749427504982855], {
             RGBColor[
             0.9670768235294117, 0.9749665294117646, 0.9406145294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.04749427504982855], {
             RGBColor[
             0.5422784705882353, 0.6392851176470589, 0.957109294117647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.04749427504982855], {
             RGBColor[
             0.9499616470588235, 0.9622020588235294, 0.9695860588235294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.04749427504982855], {
             RGBColor[
             0.9951185294117647, 0.9919673529411764, 0.7100602352941181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.04749427504982855], {
             RGBColor[
             0.9882041764705882, 0.9718720588235293, 0.40867588235294106`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.04749427504982855], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.04749427504982855], {
             RGBColor[
             0.9288922352941176, 0.9461374705882353, 0.9930797647058823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.04749427504982855], {
             RGBColor[
             0.9103135882352942, 0.6821302941176473, 0.2466944117647059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.04749427504982855], {
             RGBColor[
             0.9931568823529412, 0.9877715882352942, 0.4965470588235296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.04749427504982855], {
             RGBColor[
             0.6089988235294117, 0.6934517058823529, 0.9623617647058823]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
           19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
           36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
           53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
           70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86,
           87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
          103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
          129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 
          142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 
          155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 
          168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 
          181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 
          194, 195, 196, 197, 198, 199, 200}, {Null, CompressedData["
1:eJwVxfk/GgwDAPA5ylXk6qBcTS9j5XjImZDN1UpNhz0LEUrEK0VRaK6QloU8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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[31, 80] -> 
             RGBColor[
              0.7352027165067365, 0.7929678458962808, 0.9744115778147804], 
             UndirectedEdge[36, 132] -> 
             RGBColor[
              0.24999710016017773`, 0.3800931813729572, 0.937548337065331], 
             UndirectedEdge[16, 101] -> 
             RGBColor[
              0.28740281094428266`, 0.4180946549568002, 0.9397266599229551], 
             UndirectedEdge[86, 108] -> 
             RGBColor[
              0.5865960904370586, 0.6714707671165345, 0.9625129589589009], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.3936636675304358, 0.5153934155287933, 0.9463048786852943], 
             UndirectedEdge[29, 136] -> 
             RGBColor[
              0.950824845750427, 0.8323116913697606, 0.49992668872926316`], 
             UndirectedEdge[55, 157] -> 
             RGBColor[
              0.4550334300726567, 0.5657150158349769, 0.9509982940305055], 
             UndirectedEdge[7, 188] -> 
             RGBColor[
              0.5075570604878807, 0.6079623494198335, 0.955381071984007], 
             UndirectedEdge[19, 141] -> 
             RGBColor[
              0.31187008513103276`, 0.44044798095241544`, 0.9412431829967022],
              UndirectedEdge[62, 185] -> 
             RGBColor[
              0.5629039980331934, 0.6514450489037454, 0.9607937355315148], 
             UndirectedEdge[79, 144] -> 
             RGBColor[
              0.5302420239491671, 0.38356267740113825`, 0.5683400240537216], 
             UndirectedEdge[47, 54] -> 
             RGBColor[
              0.3621640961349061, 0.48478721437619465`, 0.9444194198717641], 
             UndirectedEdge[32, 101] -> 
             RGBColor[
              0.2434980017964442, 0.3732622169260371, 0.9371782230280707], 
             UndirectedEdge[104, 163] -> 
             RGBColor[
              0.22597848605701326`, 0.35484809508244053`, 0.9361805125245111],
              UndirectedEdge[119, 125] -> 
             RGBColor[
              0.3719190998621983, 0.4815306199533135, 0.9461956553093709], 
             UndirectedEdge[9, 140] -> 
             RGBColor[
              0.2830352445403058, 0.4148183658558119, 0.9394298105122245], 
             UndirectedEdge[3, 63] -> 
             RGBColor[
              0.30825791983475437`, 0.437251051830131, 0.9410155180983026], 
             UndirectedEdge[50, 104] -> 
             RGBColor[
              0.2305835536607953, 0.3596883131121654, 0.9364427643119595], 
             UndirectedEdge[47, 61] -> 
             RGBColor[
              0.36265936899724993`, 0.48530777755663124`, 0.944447624928584], 
             UndirectedEdge[149, 195] -> 
             RGBColor[
              0.2062475040297809, 0.3341095819553035, 0.9350568622874322], 
             UndirectedEdge[99, 178] -> 
             RGBColor[
              0.7532636952500258, 0.8067917718917483, 0.970579392980242], 
             UndirectedEdge[160, 174] -> 
             RGBColor[
              0.37406119352792633`, 0.4984147377968103, 0.9450558263756417], 
             UndirectedEdge[6, 124] -> 
             RGBColor[
              0.3155531459350417, 0.4461023057398271, 0.9413876363800726], 
             UndirectedEdge[24, 197] -> 
             RGBColor[
              0.5339219982745609, 0.6098281505161249, 0.9613839453194717], 
             UndirectedEdge[80, 120] -> 
             RGBColor[
              0.7883329572883422, 0.7840663517109472, 0.6248876395864237], 
             UndirectedEdge[83, 187] -> 
             RGBColor[
              0.26933773838678554`, 0.40042141841641143`, 0.938649757800426], 
             UndirectedEdge[47, 167] -> 
             RGBColor[
              0.6833987505402253, 0.7503936163476059, 0.9708862787627], 
             UndirectedEdge[132, 150] -> 
             RGBColor[
              0.2675705658104447, 0.39856400799346436`, 0.938549119936501], 
             UndirectedEdge[17, 189] -> 
             RGBColor[
              0.23511483918268133`, 0.3644509814957634, 0.9367008143189947], 
             UndirectedEdge[69, 180] -> 
             RGBColor[
              0.5628268850068445, 0.6533109098577117, 0.9599708318719281], 
             UndirectedEdge[43, 95] -> 
             RGBColor[
              0.9174955939353169, 0.6847516692782425, 0.2880009042450533], 
             UndirectedEdge[82, 86] -> 
             RGBColor[
              0.3552790109161934, 0.48214655523847394`, 0.943859042308054], 
             UndirectedEdge[7, 61] -> 
             RGBColor[
              0.3121285679978709, 0.4415405374828739, 0.9412278469715365], 
             UndirectedEdge[30, 65] -> 
             RGBColor[
              0.9079204151899432, 0.9294151105020584, 0.9910794537825813], 
             UndirectedEdge[62, 174] -> 
             RGBColor[
              0.36882264112374896`, 0.4938773670016114, 0.9447220304487174], 
             UndirectedEdge[18, 47] -> 
             RGBColor[
              0.38494609227374893`, 0.5078426899995235, 0.9457494024985874], 
             UndirectedEdge[56, 149] -> 
             RGBColor[
              0.2062475040297809, 0.3341095819553035, 0.9350568622874322], 
             UndirectedEdge[82, 163] -> 
             RGBColor[
              0.2758102937038249, 0.40631356017084397`, 0.9390517136501494], 
             UndirectedEdge[10, 48] -> 
             RGBColor[
              0.30320935155036544`, 0.43524999752426985`, 0.940606985973867], 
             UndirectedEdge[58, 92] -> 
             RGBColor[
              0.24643437763355744`, 0.3763485341078243, 0.9373454452880156], 
             UndirectedEdge[70, 72] -> 
             RGBColor[
              0.23177582019152226`, 0.36094146083002354`, 0.936510662127084], 
             UndirectedEdge[35, 181] -> 
             RGBColor[
              0.9113516048559902, 0.930874079920538, 0.9469017763992353], 
             UndirectedEdge[126, 174] -> 
             RGBColor[
              0.3443177986809051, 0.472511876251829, 0.9431657526324266], 
             UndirectedEdge[108, 154] -> 
             RGBColor[
              0.8838800631396134, 0.9088604535486795, 0.9258833443185683], 
             UndirectedEdge[63, 77] -> 
             RGBColor[
              0.3266232709961202, 0.4565542003312445, 0.9420613976778401], 
             UndirectedEdge[32, 100] -> 
             RGBColor[
              0.22448297168171977`, 0.35327621465291903`, 0.9360953451932534],
              UndirectedEdge[19, 50] -> 
             RGBColor[
              0.2533169376668154, 0.3835825410822887, 0.9377373969000744], 
             UndirectedEdge[80, 81] -> 
             RGBColor[
              0.5981154418108365, 0.6846160863124545, 0.9615049850298553], 
             UndirectedEdge[34, 163] -> 
             RGBColor[
              0.24238504014097356`, 0.3720924236602928, 0.9371148415082708], 
             UndirectedEdge[146, 194] -> 
             RGBColor[
              0.5723118578420975, 0.6584672801449877, 0.9618699351638069], 
             UndirectedEdge[13, 83] -> 
             RGBColor[
              0.316923827731624, 0.4440344737616491, 0.9415941582521057], 
             UndirectedEdge[30, 41] -> 
             RGBColor[
              0.7217306402299773, 0.781717727178925, 0.9737111260908631], 
             UndirectedEdge[35, 111] -> 
             RGBColor[
              0.6494345587146366, 0.7234252020636741, 0.9675585260086426], 
             UndirectedEdge[29, 144] -> 
             RGBColor[
              0.9250794571034022, 0.713525377567732, 0.47838407771344216`], 
             UndirectedEdge[6, 12] -> 
             RGBColor[
              0.4620072235822212, 0.5710418605945535, 0.9516398014511775], 
             UndirectedEdge[67, 143] -> 
             RGBColor[
              0.8195020684542436, 0.15090702076601228`, 0.16630850881720677`],
              UndirectedEdge[135, 163] -> 
             RGBColor[
              0.2331505740140204, 0.36238641426189583`, 0.9365889523235094], 
             UndirectedEdge[50, 60] -> 
             RGBColor[
              0.24809478057534154`, 0.3780937228752663, 0.9374400027792041], 
             UndirectedEdge[25, 143] -> 
             RGBColor[
              0.8998599727872215, 0.550715470129439, 0.2700821840156026], 
             UndirectedEdge[12, 13] -> 
             RGBColor[
              0.4809809724952037, 0.58747596825463, 0.9528487919540853], 
             UndirectedEdge[89, 144] -> 
             RGBColor[
              0.8552540643843429, 0.4257125281092684, 0.20054466049597394`], 
             UndirectedEdge[22, 24] -> 
             RGBColor[
              0.511674430314928, 0.3239227222549723, 0.5618363636950766], 
             UndirectedEdge[107, 156] -> 
             RGBColor[
              0.7940373920785235, 0.8398425244747729, 0.979889552465069], 
             UndirectedEdge[23, 154] -> 
             RGBColor[
              0.9900533443030074, 0.9886857899175692, 0.707722631591383], 
             UndirectedEdge[101, 135] -> 
             RGBColor[
              0.2425616632808307, 0.3722780657788366, 0.9371248999347952], 
             UndirectedEdge[7, 42] -> 
             RGBColor[
              0.4359507962934013, 0.5501706892115099, 0.9495104580293312], 
             UndirectedEdge[122, 192] -> 
             RGBColor[
              0.9051286638748339, 0.560715561019076, 0.3184883695099363], 
             UndirectedEdge[129, 133] -> 
             RGBColor[
              0.9068437673391607, 0.5799440210010265, 0.2933645016769323], 
             UndirectedEdge[40, 80] -> 
             RGBColor[
              0.555739244439546, 0.6502131802605045, 0.9581689755436615], 
             UndirectedEdge[41, 172] -> 
             RGBColor[
              0.7718454040169196, 0.8174234076188627, 0.7717375932565325], 
             UndirectedEdge[94, 115] -> 
             RGBColor[
              0.34184068469654455`, 0.4665135495155001, 0.9431489820897013], 
             UndirectedEdge[87, 103] -> 
             RGBColor[
              0.9261326652649529, 0.7329765215094193, 0.5287146017248969], 
             UndirectedEdge[142, 160] -> 
             RGBColor[
              0.5038004126414563, 0.6056953348255233, 0.9547299040233275], 
             UndirectedEdge[21, 150] -> 
             RGBColor[
              0.29956418872733326`, 0.4315020124177601, 0.9403963488781741], 
             UndirectedEdge[29, 142] -> 
             RGBColor[
              0.8172660326623933, 0.855490432397475, 0.8599437218958297], 
             UndirectedEdge[67, 103] -> 
             RGBColor[
              0.8412482263097689, 0.30880018804606046`, 0.1867701602639753], 
             UndirectedEdge[50, 163] -> 
             RGBColor[
              0.23762722721084206`, 0.36709166060796167`, 0.9368438911004533],
              UndirectedEdge[21, 46] -> 
             RGBColor[
              0.4569720284859443, 0.5663064733841641, 0.9514223432183879], 
             UndirectedEdge[43, 129] -> 
             RGBColor[
              0.922812533415494, 0.7026869546216379, 0.30865621010577077`], 
             UndirectedEdge[11, 112] -> 
             RGBColor[
              0.2736557868068433, 0.4049599610859747, 0.9388956642699682], 
             UndirectedEdge[119, 195] -> 
             RGBColor[
              0.37190268566599016`, 0.4815133675923786, 0.9461947205451795], 
             UndirectedEdge[99, 109] -> 
             RGBColor[
              0.45081925257627997`, 0.561890841684138, 0.9507778651594582], 
             UndirectedEdge[45, 120] -> 
             RGBColor[
              0.9205644172331103, 0.7168104234407002, 0.25588752113131463`], 
             UndirectedEdge[29, 153] -> 
             RGBColor[
              0.7898065464682866, 0.8331975844693433, 0.8577820105552174], 
             UndirectedEdge[27, 125] -> 
             RGBColor[
              0.22785442897304503`, 0.35681983002884055`, 0.9362873446983702],
              UndirectedEdge[35, 157] -> 
             RGBColor[
              0.6980290555794366, 0.7628764037756551, 0.971384062809347], 
             UndirectedEdge[28, 112] -> 
             RGBColor[
              0.2981130439403854, 0.43066608901299275`, 0.9402884688824538], 
             UndirectedEdge[22, 89] -> 
             RGBColor[
              0.8492070454595947, 0.37923249083306454`, 0.194754028344504], 
             UndirectedEdge[96, 116] -> 
             RGBColor[
              0.3478897367236583, 0.4755106363355533, 0.9433968344585502], 
             UndirectedEdge[23, 143] -> 
             RGBColor[
              0.9071887956861127, 0.574773145865902, 0.35502905680889496`], 
             UndirectedEdge[6, 14] -> 
             RGBColor[
              0.37841229319367853`, 0.5021834416346569, 0.945333074598817], 
             UndirectedEdge[9, 112] -> 
             RGBColor[
              0.28100806217130603`, 0.41268766865520734`, 0.9393143654752576],
              UndirectedEdge[12, 25] -> 
             RGBColor[
              0.7814420691727634, 0.8068428114651084, 0.666502637240134], 
             UndirectedEdge[176, 199] -> 
             RGBColor[
              0.28324272218403285`, 0.4150364380142114, 0.9394416260570992], 
             UndirectedEdge[48, 112] -> 
             RGBColor[
              0.3092759955003079, 0.44162642496310195`, 0.9409524723720207], 
             UndirectedEdge[79, 149] -> 
             RGBColor[
              0.21876808015896437`, 0.34726950131745254`, 0.9357698905754568],
              UndirectedEdge[58, 155] -> 
             RGBColor[
              0.25688825427596124`, 0.3873362212730521, 0.9379407780976758], 
             UndirectedEdge[118, 138] -> 
             RGBColor[
              0.9130416014388392, 0.812801149295034, 0.6201343733156849], 
             UndirectedEdge[172, 173] -> 
             RGBColor[
              0.9945590642006376, 0.9907707134251852, 0.6491658996819889], 
             UndirectedEdge[53, 104] -> 
             RGBColor[
              0.21517354122831484`, 0.34349141299440844`, 0.9355651869010002],
              UndirectedEdge[179, 185] -> 
             RGBColor[
              0.7887535289716312, 0.8348995186722672, 0.9795792385132371], 
             UndirectedEdge[82, 176] -> 
             RGBColor[
              0.30639768237766407`, 0.4384628450195025, 0.9407936201851381], 
             UndirectedEdge[142, 181] -> 
             RGBColor[
              0.8126094756619291, 0.8535648264097266, 0.9371149221767408], 
             UndirectedEdge[54, 160] -> 
             RGBColor[
              0.3197591214680627, 0.448058156655773, 0.9417174123832397], 
             UndirectedEdge[121, 151] -> 
             RGBColor[
              0.4472759744708069, 0.5594034354051198, 0.9503913919352824], 
             UndirectedEdge[138, 144] -> 
             RGBColor[
              0.8846457857876004, 0.5636515837418983, 0.22521422842604885`], 
             UndirectedEdge[171, 196] -> 
             RGBColor[
              0.6848218020180831, 0.7518929600057571, 0.9706449762400708], 
             UndirectedEdge[120, 172] -> 
             RGBColor[
              0.9753727800277856, 0.9276792174007213, 0.4361680487899127], 
             UndirectedEdge[113, 159] -> 
             RGBColor[
              0.8614732788871635, 0.4076188795492328, 0.20391981602530412`], 
             UndirectedEdge[103, 108] -> 
             RGBColor[
              0.822761672378244, 0.6528409767770607, 0.5936514209828487], 
             UndirectedEdge[64, 176] -> 
             RGBColor[
              0.45839978276888355`, 0.5655229499724335, 0.9517490792275327], 
             UndirectedEdge[83, 101] -> 
             RGBColor[
              0.2538463417938609, 0.3841389783859738, 0.9377675456819266], 
             UndirectedEdge[15, 63] -> 
             RGBColor[
              0.33898161598962545`, 0.46803057088396705`, 0.9428205867145535],
              UndirectedEdge[55, 72] -> 
             RGBColor[
              0.3011292819316679, 0.4298018950317811, 0.9406079602011264], 
             UndirectedEdge[105, 142] -> 
             RGBColor[
              0.4920496854617956, 0.5955174455512221, 0.9539811580781995], 
             UndirectedEdge[96, 105] -> 
             RGBColor[
              0.32470350781154744`, 0.4554278902256328, 0.9419194284550477], 
             UndirectedEdge[48, 63] -> 
             RGBColor[
              0.3349775869314745, 0.46456248216214874`, 0.942565453523592], 
             UndirectedEdge[64, 108] -> 
             RGBColor[
              0.7019176077126746, 0.7667599945944428, 0.9711311636805353], 
             UndirectedEdge[56, 119] -> 
             RGBColor[
              0.37190268566599016`, 0.4815133675923786, 0.9461947205451795], 
             UndirectedEdge[68, 157] -> 
             RGBColor[
              0.7066548099945791, 0.7697543462064234, 0.9722067949657651], 
             UndirectedEdge[137, 161] -> 
             RGBColor[
              0.2794230248160247, 0.4110216938976339, 0.939224099942727], 
             UndirectedEdge[160, 188] -> 
             RGBColor[
              0.5156828868204164, 0.6150005317731692, 0.9558988424525301], 
             UndirectedEdge[127, 187] -> 
             RGBColor[
              0.3022073859943112, 0.43378220468743567`, 0.9405651083800737], 
             UndirectedEdge[41, 141] -> 
             RGBColor[
              0.4545263425380657, 0.5654922255819677, 0.9509061844081543], 
             UndirectedEdge[137, 175] -> 
             RGBColor[
              0.2852924893069724, 0.4161135758232565, 0.9395978023974743], 
             UndirectedEdge[1, 122] -> 
             RGBColor[
              0.9756254576616791, 0.9291724163168037, 0.38265572153063876`], 
             UndirectedEdge[60, 177] -> 
             RGBColor[
              0.273782020378095, 0.40509264057303096`, 0.9389028530851051], 
             UndirectedEdge[72, 75] -> 
             RGBColor[
              0.26701897159742227`, 0.39798424750248473`, 0.9385177074620799],
              UndirectedEdge[13, 69] -> 
             RGBColor[
              0.38979245396039097`, 0.512040364907272, 0.9460582083797908], 
             UndirectedEdge[48, 77] -> 
             RGBColor[
              0.30874838296909257`, 0.4410718707402281, 0.9409224256189008], 
             UndirectedEdge[22, 183] -> 
             RGBColor[
              0.8521661685690678, 0.3996097358148414, 0.1974949680494109], 
             UndirectedEdge[16, 86] -> 
             RGBColor[
              0.3574604388898408, 0.48403599850748935`, 0.9439980409695737], 
             UndirectedEdge[8, 62] -> 
             RGBColor[
              0.40221602470153694`, 0.5228010374564311, 0.9468498273216844], 
             UndirectedEdge[26, 51] -> 
             RGBColor[
              0.3392714220793772, 0.4658216765666159, 0.9429291222497664], 
             UndirectedEdge[117, 121] -> 
             RGBColor[
              0.6608369282647062, 0.733443073990961, 0.9678737418567172], 
             UndirectedEdge[89, 136] -> 
             RGBColor[
              0.8809994530313677, 0.5444988419112969, 0.222087271511795], 
             UndirectedEdge[81, 168] -> 
             RGBColor[
              0.7574630871375609, 0.8103278215593543, 0.974310777757218], 
             UndirectedEdge[172, 198] -> 
             RGBColor[
              0.8450687656775151, 0.8760452560467036, 0.7780654976273946], 
             UndirectedEdge[55, 68] -> 
             RGBColor[
              0.6040034340544339, 0.6836766872491769, 0.9648829517187356], 
             UndirectedEdge[156, 192] -> 
             RGBColor[
              0.869081373347711, 0.5369234121250193, 0.5782650463391841], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.3132800245584588, 0.44509451368492026`, 0.9412076055629822], 
             UndirectedEdge[25, 154] -> 
             RGBColor[
              0.9827245214041163, 0.9646281141811062, 0.6227757587980907], 
             UndirectedEdge[100, 135] -> 
             RGBColor[
              0.2235466331661063, 0.3522920635057185, 0.9360420220999779], 
             UndirectedEdge[37, 149] -> 
             RGBColor[
              0.21228087842813756`, 0.34045104098600754`, 0.9354004540338412],
              UndirectedEdge[125, 149] -> 
             RGBColor[
              0.206263918225989, 0.33412683431623835`, 0.9350577970516237], 
             UndirectedEdge[2, 184] -> 
             RGBColor[
              0.37412689727752746`, 0.49847164708234826`, 0.9450600129604667],
              UndirectedEdge[6, 16] -> 
             RGBColor[
              0.3315065479690632, 0.46155604267239897`, 0.9423442819902264], 
             UndirectedEdge[55, 111] -> 
             RGBColor[
              0.40643893320785657`, 0.5262638141229958, 0.9471727572298012], 
             UndirectedEdge[34, 50] -> 
             RGBColor[
              0.2469901077447556, 0.3769326416900177, 0.9373770932957193], 
             UndirectedEdge[56, 125] -> 
             RGBColor[
              0.17894341419620807`, 0.3054112523609348, 0.9335019347641915], 
             UndirectedEdge[98, 196] -> 
             RGBColor[
              0.7343309142909232, 0.7903956980318739, 0.9415812202273133], 
             UndirectedEdge[160, 167] -> 
             RGBColor[
              0.6409937758733817, 0.7136645586271843, 0.9681842712741754], 
             UndirectedEdge[22, 149] -> 
             RGBColor[
              0.5389949329250163, 0.35263830271808894`, 0.5633922259016595], 
             UndirectedEdge[147, 194] -> 
             RGBColor[
              0.41461252572283636`, 0.5327948903127648, 0.9478451176521548], 
             UndirectedEdge[83, 161] -> 
             RGBColor[
              0.28225365624559345`, 0.41399686700250915`, 0.9393853002150969],
              UndirectedEdge[34, 177] -> 
             RGBColor[
              0.27267734754750905`, 0.40393155938778236`, 0.9388399436016203],
              UndirectedEdge[70, 145] -> 
             RGBColor[
              0.2107154956867174, 0.33880572447377666`, 0.9353113078024935], 
             UndirectedEdge[125, 170] -> 
             RGBColor[
              0.18066259612527297`, 0.307218221570812, 0.93359983963175], 
             UndirectedEdge[190, 192] -> 
             RGBColor[
              0.4985130310330229, 0.22017044734510285`, 0.5488817116903315], 
             UndirectedEdge[122, 188] -> 
             RGBColor[
              0.8287961614327686, 0.8626280708354541, 0.7199844478872237], 
             UndirectedEdge[123, 130] -> 
             RGBColor[
              0.24382776690061642`, 0.3736088209588374, 0.9371970026629095], 
             UndirectedEdge[94, 116] -> 
             RGBColor[
              0.4038551160855868, 0.5242207360301667, 0.9469542687752844], 
             UndirectedEdge[23, 162] -> 
             RGBColor[
              0.9882402059749112, 0.9877215722762983, 0.728168038634343], 
             UndirectedEdge[116, 160] -> 
             RGBColor[
              0.3781472802574135, 0.5019539007492015, 0.9453161882088599], 
             UndirectedEdge[80, 117] -> 
             RGBColor[
              0.699447709361209, 0.7647890454809683, 0.9709133239805854], 
             UndirectedEdge[147, 185] -> 
             RGBColor[
              0.625134594396598, 0.7046026904109504, 0.9649644103506239], 
             UndirectedEdge[55, 107] -> 
             RGBColor[
              0.5098065457970684, 0.609801290788619, 0.955570731517623], 
             UndirectedEdge[111, 174] -> 
             RGBColor[
              0.4209532104070455, 0.5388353515241499, 0.9480975941384622], 
             UndirectedEdge[126, 142] -> 
             RGBColor[
              0.47405701779443504`, 0.579792473280542, 0.9528398302801124], 
             UndirectedEdge[115, 160] -> 
             RGBColor[
              0.31613284886837134`, 0.44424671423453505`, 0.9415109015232768],
              UndirectedEdge[74, 164] -> 
             RGBColor[
              0.29875283098362904`, 0.4313385457602833, 0.9403249038080864], 
             UndirectedEdge[42, 97] -> 
             RGBColor[
              0.401201459999004, 0.517503689481011, 0.9473903200062829], 
             UndirectedEdge[25, 108] -> 
             RGBColor[
              0.8800770451068233, 0.8847917621519991, 0.6757220357685101], 
             UndirectedEdge[67, 133] -> 
             RGBColor[
              0.820816769260137, 0.16101238726567596`, 0.16756746779367254`], 
             UndirectedEdge[38, 183] -> 
             RGBColor[
              0.9123593760428652, 0.674860106009205, 0.26130271158407675`], 
             UndirectedEdge[33, 41] -> 
             RGBColor[
              0.4363770738073567, 0.5497722412161976, 0.9497497290534018], 
             UndirectedEdge[32, 123] -> 
             RGBColor[
              0.24279155375346242`, 0.3725196952414703, 0.9371379918571192], 
             UndirectedEdge[61, 116] -> 
             RGBColor[
              0.3316898960628568, 0.4584835766718288, 0.9424742774984342], 
             UndirectedEdge[93, 134] -> 
             RGBColor[
              0.2274998629101822, 0.35644715861598486`, 0.9362671526856237], 
             UndirectedEdge[45, 128] -> 
             RGBColor[
              0.8869707508914968, 0.5796424030976618, 0.22739796275449303`], 
             UndirectedEdge[29, 35] -> 
             RGBColor[
              0.9160081618564544, 0.9327996859082862, 0.8697305761183244], 
             UndirectedEdge[3, 106] -> 
             RGBColor[
              0.26935764073949675`, 0.40044233705099297`, 0.93865089120997], 
             UndirectedEdge[77, 140] -> 
             RGBColor[
              0.3029488619339533, 0.43574884033280226`, 0.9405638615632359], 
             UndirectedEdge[79, 195] -> 
             RGBColor[
              0.1914475761291835, 0.31855391936214905`, 0.9342140282880245], 
             UndirectedEdge[38, 46] -> 
             RGBColor[
              0.7812753615379626, 0.7886327284729578, 0.6396314180362879], 
             UndirectedEdge[14, 59] -> 
             RGBColor[
              0.43278883650636024`, 0.549281670407568, 0.9487978998554119], 
             UndirectedEdge[126, 191] -> 
             RGBColor[
              0.2937278856939699, 0.4260570096609187, 0.9400387406075807], 
             UndirectedEdge[13, 64] -> 
             RGBColor[
              0.5003009692996179, 0.6031608120163909, 0.9543697328740091], 
             UndirectedEdge[3, 11] -> 
             RGBColor[
              0.2547628231142621, 0.3851022583619874, 0.9378197379373108], 
             UndirectedEdge[31, 98] -> 
             RGBColor[
              0.9119983758560902, 0.9316922814327566, 0.9576824339727095], 
             UndirectedEdge[25, 162] -> 
             RGBColor[
              0.9809113830760201, 0.9636638965398352, 0.6432211658410507], 
             UndirectedEdge[126, 157] -> 
             RGBColor[
              0.43245489742186133`, 0.5460179978079216, 0.9495647589707952], 
             UndirectedEdge[128, 183] -> 
             RGBColor[
              0.8747459970096212, 0.524132650883874, 0.217197328459318], 
             UndirectedEdge[22, 192] -> 
             RGBColor[
              0.8308704288952353, 0.23828922076278541`, 0.17719486361422723`],
              UndirectedEdge[99, 194] -> 
             RGBColor[
              0.45631234328201786`, 0.5666486807626816, 0.9511278800418784], 
             UndirectedEdge[21, 151] -> 
             RGBColor[
              0.33403902527338425`, 0.46374954722739153`, 0.9425056492046759],
              UndirectedEdge[48, 59] -> 
             RGBColor[
              0.382953798860026, 0.5061170655801353, 0.9456224553239809], 
             UndirectedEdge[18, 115] -> 
             RGBColor[
              0.2919621879503136, 0.4233113026000546, 0.9399707683828544], 
             UndirectedEdge[29, 89] -> 
             RGBColor[
              0.9238176258477779, 0.703826389599022, 0.47717574667802176`], 
             UndirectedEdge[15, 140] -> 
             RGBColor[
              0.31530720692745856`, 0.4472252108855248, 0.9413230505999493], 
             UndirectedEdge[113, 136] -> 
             RGBColor[
              0.9041543846818847, 0.6565805366270306, 0.24168008890791598`], 
             UndirectedEdge[111, 160] -> 
             RGBColor[
              0.41360379540408243`, 0.5324696576409218, 0.9476292959133059], 
             UndirectedEdge[116, 188] -> 
             RGBColor[
              0.5271183885528666, 0.6249053886087885, 0.9566275025109046], 
             UndirectedEdge[82, 127] -> 
             RGBColor[
              0.32009303423134106`, 0.45167023073266444`, 0.9416170229874327],
              UndirectedEdge[25, 95] -> 
             RGBColor[
              0.9792736576371948, 0.9417473218129542, 0.37398250307217895`], 
             UndirectedEdge[62, 111] -> 
             RGBColor[
              0.40836524299990506`, 0.527932286845723, 0.9472954999863816], 
             UndirectedEdge[162, 180] -> 
             RGBColor[
              0.853484717444914, 0.8855675982797966, 0.9434799440471393], 
             UndirectedEdge[89, 159] -> 
             RGBColor[
              0.8383183472366464, 0.29553718483349917`, 0.18432699862918317`],
              UndirectedEdge[7, 153] -> 
             RGBColor[
              0.46821510011481404`, 0.5763643045440561, 0.9520504222141921], 
             UndirectedEdge[146, 183] -> 
             RGBColor[
              0.8280025050148025, 0.648701197553076, 0.5925645649142633], 
             UndirectedEdge[144, 197] -> 
             RGBColor[
              0.8727164446748519, 0.6748369070629272, 0.5955099410043194], 
             UndirectedEdge[120, 128] -> 
             RGBColor[
              0.9231751810131911, 0.7286652920066743, 0.2580660064250903], 
             UndirectedEdge[74, 166] -> 
             RGBColor[
              0.34685352759081295`, 0.47429746798031186`, 0.9433423658444682],
              UndirectedEdge[147, 152] -> 
             RGBColor[
              0.3812177118441309, 0.5013730508472783, 0.9458086544862003], 
             UndirectedEdge[22, 190] -> 
             RGBColor[
              0.5120644599282582, 0.3243326681078883, 0.5618585753045587], 
             UndirectedEdge[27, 128] -> 
             RGBColor[
              0.5831652721126257, 0.49985421349972364`, 0.5843241339583132], 
             UndirectedEdge[47, 88] -> 
             RGBColor[
              0.5818581666070413, 0.6702991325141743, 0.9609700518092634], 
             UndirectedEdge[69, 177] -> 
             RGBColor[
              0.3475961861623531, 0.47409235374214537`, 0.9434207502916752], 
             UndirectedEdge[122, 167] -> 
             RGBColor[
              0.9541070504857341, 0.9612920976894692, 0.7322698767088691], 
             UndirectedEdge[1, 78] -> 
             RGBColor[
              0.9431385588038124, 0.9082192270955545, 0.6427719916956993], 
             UndirectedEdge[138, 159] -> 
             RGBColor[
              0.8677100686399041, 0.4334762404661291, 0.20899656655925808`], 
             UndirectedEdge[101, 127] -> 
             RGBColor[
              0.28671598940138643`, 0.417499764656998, 0.9396828962615742], 
             UndirectedEdge[65, 90] -> 
             RGBColor[
              0.6550212395891795, 0.7255799866641114, 0.9691860218299977], 
             UndirectedEdge[64, 127] -> 
             RGBColor[
              0.4720951346225606, 0.5787303356855954, 0.9525724820298272], 
             UndirectedEdge[117, 146] -> 
             RGBColor[
              0.7875464410912392, 0.8339565324458974, 0.9794589272741974], 
             UndirectedEdge[49, 103] -> 
             RGBColor[
              0.8495141808128409, 0.372335936521032, 0.19468564763117746`], 
             UndirectedEdge[88, 113] -> 
             RGBColor[
              0.8062483508925926, 0.7076340176229743, 0.6052352623718941], 
             UndirectedEdge[13, 176] -> 
             RGBColor[
              0.3360981234854725, 0.4641878743195114, 0.9426861060294587], 
             UndirectedEdge[17, 112] -> 
             RGBColor[
              0.27014379762534146`, 0.4012686377832412, 0.938695661681604], 
             UndirectedEdge[129, 170] -> 
             RGBColor[
              0.5863125273607737, 0.6439068649740138, 0.6751789886764388], 
             UndirectedEdge[35, 116] -> 
             RGBColor[
              0.6139780435679677, 0.6929094451719539, 0.9652454183041966], 
             UndirectedEdge[69, 110] -> 
             RGBColor[
              0.503306311820726, 0.6062411074789984, 0.9544293736590629], 
             UndirectedEdge[47, 126] -> 
             RGBColor[
              0.37937335834478547`, 0.5028752400890226, 0.9453994618957948], 
             UndirectedEdge[83, 137] -> 
             RGBColor[
              0.2530177140174724, 0.383268038054954, 0.9377203565559061], 
             UndirectedEdge[72, 84] -> 
             RGBColor[
              0.256326539038239, 0.386745822943403, 0.9379087892458708], 
             UndirectedEdge[22, 37] -> 
             RGBColor[
              0.517707803293592, 0.3302641797934895, 0.5621799553606361], 
             UndirectedEdge[90, 141] -> 
             RGBColor[
              0.37364371183420664`, 0.49805313613695035`, 0.9450292248112824],
              UndirectedEdge[24, 79] -> 
             RGBColor[
              0.1914475775488761, 0.318553920854336, 0.9342140283688739], 
             UndirectedEdge[34, 130] -> 
             RGBColor[
              0.2444860062107015, 0.3743006722085195, 0.9372344884178412], 
             UndirectedEdge[157, 174] -> 
             RGBColor[
              0.4695477072718456, 0.5782865532361309, 0.9519231309391665], 
             UndirectedEdge[131, 180] -> 
             RGBColor[
              0.811663417266584, 0.70990288285835, 0.6053916520008711], 
             UndirectedEdge[3, 48] -> 
             RGBColor[
              0.29038303180772673`, 0.42176872223911466`, 0.9398765460393633],
              UndirectedEdge[49, 67] -> 
             RGBColor[
              0.8264716492084423, 0.20447827253254375`, 0.17298258721844303`],
              UndirectedEdge[79, 190] -> 
             RGBColor[
              0.19183760716220638`, 0.3189638667072519, 0.9342362399783559], 
             UndirectedEdge[13, 82] -> 
             RGBColor[
              0.34829886890839834`, 0.4761007070634601, 0.9434142738316145], 
             UndirectedEdge[68, 138] -> 
             RGBColor[
              0.8842002449557951, 0.7898038345132208, 0.6173834589873493], 
             UndirectedEdge[153, 160] -> 
             RGBColor[
              0.4763409264473496, 0.5834024868973917, 0.9525681926827152], 
             UndirectedEdge[178, 183] -> 
             RGBColor[
              0.9011711841429679, 0.7066772038250902, 0.5935750920582745], 
             UndirectedEdge[2, 166] -> 
             RGBColor[
              0.3840226301972896, 0.5070428335634479, 0.9456905603116609], 
             UndirectedEdge[32, 53] -> 
             RGBColor[
              0.2232819677009355, 0.3520138833210643, 0.9360269497932738], 
             UndirectedEdge[26, 184] -> 
             RGBColor[
              0.38376793461067366`, 0.5068222290476936, 0.9456743313341002], 
             UndirectedEdge[61, 115] -> 
             RGBColor[
              0.2696754646738146, 0.40077639015716227`, 0.938668990812851], 
             UndirectedEdge[146, 178] -> 
             RGBColor[
              0.8692632098101054, 0.8986103712740543, 0.9813214481021706], 
             UndirectedEdge[88, 102] -> 
             RGBColor[
              0.5430147651889159, 0.6366549305319157, 0.9584949846187718], 
             UndirectedEdge[118, 159] -> 
             RGBColor[
              0.8679759941435095, 0.5543857383553449, 0.5804554745542396], 
             UndirectedEdge[62, 75] -> 
             RGBColor[
              0.3201980535903144, 0.44948818207116104`, 0.9417069408010099], 
             UndirectedEdge[89, 197] -> 
             RGBColor[
              0.8714546134192276, 0.6651379190942172, 0.5943016099688991], 
             UndirectedEdge[85, 146] -> 
             RGBColor[
              0.578124805971577, 0.6635021636474746, 0.9622403310784291], 
             UndirectedEdge[170, 190] -> 
             RGBColor[
              0.1810362129620878, 0.3076109165549801, 0.93362111655789], 
             UndirectedEdge[82, 101] -> 
             RGBColor[
              0.2852213829706352, 0.4162052116877847, 0.9395876612614353], 
             UndirectedEdge[7, 73] -> 
             RGBColor[
              0.3217974307185043, 0.4517031252435637, 0.941778474399676], 
             UndirectedEdge[19, 34] -> 
             RGBColor[
              0.25807475059694696`, 0.38858330413461983`, 0.938008347307892], 
             UndirectedEdge[56, 170] -> 
             RGBColor[
              0.1806461819290649, 0.30720096920987716`, 0.9335989048675586], 
             UndirectedEdge[32, 187] -> 
             RGBColor[
              0.2589893983893689, 0.38954465695647483`, 0.9380604351465702], 
             UndirectedEdge[74, 169] -> 
             RGBColor[
              0.28768269698087445`, 0.4197031330363533, 0.9396944760534252], 
             UndirectedEdge[55, 147] -> 
             RGBColor[
              0.41653896028796467`, 0.5344634711076623, 0.9479678683591656], 
             UndirectedEdge[49, 143] -> 
             RGBColor[
              0.8277680229573157, 0.2144427692409838, 0.17422399618440892`], 
             UndirectedEdge[28, 77] -> 
             RGBColor[
              0.29758543140917015`, 0.4301115347901189, 0.9402584221293339], 
             UndirectedEdge[122, 153] -> 
             RGBColor[
              0.7894542010597019, 0.8310300259596766, 0.7166537981174088], 
             UndirectedEdge[12, 16] -> 
             RGBColor[
              0.45346195936104267`, 0.5636403822236367, 0.9510953047712845], 
             UndirectedEdge[16, 199] -> 
             RGBColor[
              0.29762489558060606`, 0.42883871402717555`, 0.9403087925207747],
              UndirectedEdge[64, 180] -> 
             RGBColor[
              0.6733354003460714, 0.7444313569668306, 0.9682823563661463], 
             UndirectedEdge[38, 128] -> 
             RGBColor[
              0.9271948937048214, 0.742224726788967, 0.2736818311730274], 
             UndirectedEdge[46, 98] -> 
             RGBColor[
              0.7856154181292234, 0.8320307685883754, 0.9456185242307917], 
             UndirectedEdge[68, 142] -> 
             RGBColor[
              0.7482569303671527, 0.8035288216790438, 0.9754818662750824], 
             UndirectedEdge[5, 20] -> 
             RGBColor[
              0.2538041540046914, 0.3840946363446963, 0.9377651431497445], 
             UndirectedEdge[169, 200] -> 
             RGBColor[
              0.2545855584826314, 0.3849159419949167, 0.9378096429787789], 
             UndirectedEdge[27, 133] -> 
             RGBColor[
              0.5500884366842889, 0.29464670290479555`, 0.5545698278022309], 
             UndirectedEdge[32, 135] -> 
             RGBColor[
              0.23421532693659433`, 0.36350553709275546`, 0.9366495884272892],
              UndirectedEdge[144, 190] -> 
             RGBColor[
              0.5181114788530065, 0.37081270538409206`, 0.5676492074560286], 
             UndirectedEdge[62, 126] -> 
             RGBColor[
              0.33172983127376465`, 0.4616088115734021, 0.9423636584803461], 
             UndirectedEdge[55, 62] -> 
             RGBColor[
              0.35430836392456, 0.4813058296004574, 0.9437971935400564], 
             UndirectedEdge[62, 76] -> 
             RGBColor[
              0.3162924905225524, 0.44538318765994256`, 0.9414845247620637], 
             UndirectedEdge[157, 181] -> 
             RGBColor[
              0.7710073552893554, 0.8197903509371063, 0.9338398508674235], 
             UndirectedEdge[64, 82] -> 
             RGBColor[
              0.4706005281918093, 0.5774357827163821, 0.9524772470296884], 
             UndirectedEdge[142, 153] -> 
             RGBColor[
              0.6134295605638427, 0.6970487778093326, 0.9627105685555573], 
             UndirectedEdge[21, 109] -> 
             RGBColor[
              0.32687230511240406`, 0.45754209443377936`, 0.9420489921333002],
              UndirectedEdge[66, 198] -> 
             RGBColor[
              0.6938904051885131, 0.7607917253864516, 0.97012416888083], 
             UndirectedEdge[141, 198] -> 
             RGBColor[
              0.5277497041986612, 0.6241140740098087, 0.9572340887790165], 
             UndirectedEdge[10, 28] -> 
             RGBColor[
              0.292046399990443, 0.42428966157416065`, 0.9399429824843], 
             UndirectedEdge[31, 151] -> 
             RGBColor[
              0.6011924048521665, 0.6814178617192261, 0.9646228375029955], 
             UndirectedEdge[111, 142] -> 
             RGBColor[
              0.5506924295205754, 0.6461159485528629, 0.957771671786148], 
             UndirectedEdge[111, 181] -> 
             RGBColor[
              0.7224128584245553, 0.7803391492251253, 0.9300143140667192], 
             UndirectedEdge[86, 101] -> 
             RGBColor[
              0.3219019660862388, 0.44797608916280746`, 0.9419249155821955], 
             UndirectedEdge[119, 144] -> 
             RGBColor[
              0.7106971334859737, 0.5465221256313679, 0.5803207163108766], 
             UndirectedEdge[5, 102] -> 
             RGBColor[
              0.32802099544168023`, 0.45608332647208405`, 0.9422120278540836],
              UndirectedEdge[157, 185] -> 
             RGBColor[
              0.6636290641812901, 0.7358542351382649, 0.9679948360219639], 
             UndirectedEdge[13, 110] -> 
             RGBColor[
              0.49151316787654187`, 0.5960264789351953, 0.9536779249552072], 
             UndirectedEdge[32, 82] -> 
             RGBColor[
              0.27687504662639884`, 0.4074326830017036, 0.9391123497539292], 
             UndirectedEdge[12, 23] -> 
             RGBColor[
              0.7887708920716545, 0.8309004872015715, 0.7514495100334264], 
             UndirectedEdge[53, 130] -> 
             RGBColor[
              0.22431818084808952`, 0.35310300903843134`, 0.9360859605990643],
              UndirectedEdge[74, 80] -> 
             RGBColor[
              0.46133983359188224`, 0.5689367397653611, 0.9518870537804123], 
             UndirectedEdge[35, 185] -> 
             RGBColor[
              0.8039733137479249, 0.8469379641216965, 0.9810567615537757], 
             UndirectedEdge[117, 196] -> 
             RGBColor[
              0.6370858970808988, 0.7141609169041846, 0.966003973679034], 
             UndirectedEdge[22, 181] -> 
             RGBColor[
              0.9143758811781899, 0.66511973430378, 0.5497646458428832], 
             UndirectedEdge[143, 197] -> 
             RGBColor[
              0.8548577179564267, 0.5375669077611642, 0.5784084041302087], 
             UndirectedEdge[16, 124] -> 
             RGBColor[
              0.3070078817138632, 0.43870082736891025`, 0.9408431397001796], 
             UndirectedEdge[182, 191] -> 
             RGBColor[
              0.2726772055917506, 0.4039314101832797, 0.9388399355174497], 
             UndirectedEdge[98, 146] -> 
             RGBColor[
              0.8847914583012635, 0.9101913135735867, 0.9550361738224766], 
             UndirectedEdge[156, 183] -> 
             RGBColor[
              0.8903771130215434, 0.6982439271770752, 0.5985651507743678], 
             UndirectedEdge[6, 13] -> 
             RGBColor[
              0.35902556110322426`, 0.48539162870339236`, 0.9440977691730272],
              UndirectedEdge[50, 100] -> 
             RGBColor[
              0.2280232863629279, 0.35699730985178435`, 0.9362969608769219], 
             UndirectedEdge[13, 175] -> 
             RGBColor[
              0.34919860302112393`, 0.4768800115299515, 0.9434716040936737], 
             UndirectedEdge[62, 116] -> 
             RGBColor[
              0.37290872785323614`, 0.4974165299540027, 0.9449823922819357], 
             UndirectedEdge[120, 171] -> 
             RGBColor[
              0.9156195043648556, 0.8842880492213061, 0.6372222517571104], 
             UndirectedEdge[72, 139] -> 
             RGBColor[
              0.24951735884561907`, 0.3795889428339999, 0.9375210165071806], 
             UndirectedEdge[6, 83] -> 
             RGBColor[
              0.29795007881864144`, 0.4276003661015726, 0.9403851677491978], 
             UndirectedEdge[118, 190] -> 
             RGBColor[
              0.5465072945042451, 0.6199622709372278, 0.9625693523456647], 
             UndirectedEdge[36, 200] -> 
             RGBColor[
              0.24218408124275126`, 0.3718812031167312, 0.9371033971963092], 
             UndirectedEdge[16, 161] -> 
             RGBColor[
              0.3158101253960152, 0.4479525435733356, 0.9413444144561256], 
             UndirectedEdge[2, 169] -> 
             RGBColor[
              0.3248517995873511, 0.4524484986194894, 0.942042670520618], 
             UndirectedEdge[107, 111] -> 
             RGBColor[
              0.5638634248724134, 0.6564277480338845, 0.9590690379639482], 
             UndirectedEdge[127, 180] -> 
             RGBColor[
              0.5228279063856032, 0.618665804983113, 0.9574221323238906], 
             UndirectedEdge[138, 156] -> 
             RGBColor[
              0.9168097113153278, 0.8158057378279282, 0.6204937789995357], 
             UndirectedEdge[72, 93] -> 
             RGBColor[
              0.23701205160573985`, 0.3664450720426131, 0.9368088577598136], 
             UndirectedEdge[137, 187] -> 
             RGBColor[
              0.2665071069572168, 0.39744624531153616`, 0.938488557528056], 
             UndirectedEdge[40, 121] -> 
             RGBColor[
              0.5171284633430432, 0.6188672087704971, 0.9551293934197934], 
             UndirectedEdge[98, 178] -> 
             RGBColor[
              0.957960137429429, 0.968167319845601, 0.9560467009664877], 
             UndirectedEdge[10, 186] -> 
             RGBColor[
              0.28567319780598677`, 0.4175910219939398, 0.939580038048203], 
             UndirectedEdge[63, 91] -> 
             RGBColor[
              0.5953350475574752, 0.6767809281925967, 0.9640487060966569], 
             UndirectedEdge[125, 195] -> 
             RGBColor[
              0.17894341419620807`, 0.3054112523609348, 0.9335019347641915], 
             UndirectedEdge[86, 180] -> 
             RGBColor[
              0.5580138830704554, 0.6491421294889225, 0.9596641516445119], 
             UndirectedEdge[137, 186] -> 
             RGBColor[
              0.2661087370017966, 0.3970275332302755, 0.9384658709484304], 
             UndirectedEdge[33, 44] -> 
             RGBColor[
              0.3032320659672701, 0.4347249229295589, 0.9406283792341544], 
             UndirectedEdge[14, 193] -> 
             RGBColor[
              0.36672963099697153`, 0.49206450682754455`, 0.9445886656942154],
              UndirectedEdge[11, 28] -> 
             RGBColor[
              0.2703195386510599, 0.4014533527438959, 0.9387056698730332], 
             UndirectedEdge[85, 151] -> 
             RGBColor[
              0.35601576258697687`, 0.48278469250549083`, 0.9439059874730323],
              UndirectedEdge[175, 199] -> 
             RGBColor[
              0.2963432017196842, 0.4277285752246516, 0.9402271241213142], 
             UndirectedEdge[146, 196] -> 
             RGBColor[
              0.6456339866715997, 0.7208387494603272, 0.9668559673629961], 
             UndirectedEdge[20, 77] -> 
             RGBColor[
              0.2628976545910799, 0.3936524820222284, 0.9382830045555108], 
             UndirectedEdge[27, 56] -> 
             RGBColor[
              0.22783801477683696`, 0.3568025776679057, 0.9362864099341788], 
             UndirectedEdge[101, 175] -> 
             RGBColor[
              0.2861211170833608, 0.41698451615427623`, 0.9396449915234946], 
             UndirectedEdge[21, 85] -> 
             RGBColor[
              0.3381783439476214, 0.46733481701480994`, 0.9427694029303426], 
             UndirectedEdge[150, 194] -> 
             RGBColor[
              0.31572797791144636`, 0.44550227419337246`, 0.9414262912319082],
              UndirectedEdge[61, 160] -> 
             RGBColor[
              0.3202543943304065, 0.44857871983620956`, 0.9417456174400596], 
             UndirectedEdge[24, 149] -> 
             RGBColor[
              0.20624750544947348`, 0.3341095834474904, 0.9350568623682817], 
             UndirectedEdge[14, 186] -> 
             RGBColor[
              0.34940158280640243`, 0.47458578186823513`, 0.9435749780704197],
              UndirectedEdge[111, 126] -> 
             RGBColor[
              0.3838604005570612, 0.5065667960959406, 0.9457392221700909], 
             UndirectedEdge[35, 88] -> 
             RGBColor[
              0.775283955250752, 0.8245256192165048, 0.9781972744160757], 
             UndirectedEdge[94, 111] -> 
             RGBColor[
              0.43931163123225564`, 0.554736492921887, 0.9492673764797304], 
             UndirectedEdge[133, 162] -> 
             RGBColor[
              0.903164553297809, 0.5839253103845123, 0.5419478585850865], 
             UndirectedEdge[124, 199] -> 
             RGBColor[
              0.2816714935465845, 0.4133849770946037, 0.939352146910621], 
             UndirectedEdge[54, 105] -> 
             RGBColor[
              0.3080083942884021, 0.4378802673814718, 0.9409686664381117], 
             UndirectedEdge[64, 162] -> 
             RGBColor[
              0.8027519456818715, 0.845632128982279, 0.9386302937530759], 
             UndirectedEdge[57, 66] -> 
             RGBColor[
              0.5260989516337345, 0.6228771288818142, 0.9570472794276266], 
             UndirectedEdge[16, 137] -> 
             RGBColor[
              0.2865741831678942, 0.41722371462578045`, 0.9396794707969347], 
             UndirectedEdge[44, 50] -> 
             RGBColor[
              0.2628281872337618, 0.3935794674252022, 0.9382790484922793], 
             UndirectedEdge[153, 167] -> 
             RGBColor[
              0.7506229237957682, 0.8050180016109936, 0.9761649358064053], 
             UndirectedEdge[165, 187] -> 
             RGBColor[
              0.2508650284302595, 0.38100542901464385`, 0.9375977642963274], 
             UndirectedEdge[32, 83] -> 
             RGBColor[
              0.2455000054496245, 0.37536644969989263`, 0.9372922341744203], 
             UndirectedEdge[6, 187] -> 
             RGBColor[
              0.3114394717583858, 0.44177857335815474`, 0.9411533687213477], 
             UndirectedEdge[66, 141] -> 
             RGBColor[
              0.5254792907329107, 0.622340409754583, 0.9570077951829706], 
             UndirectedEdge[23, 87] -> 
             RGBColor[
              0.9907768608924232, 0.9889849826208208, 0.6957320893038507], 
             UndirectedEdge[85, 152] -> 
             RGBColor[
              0.320947319253029, 0.44991323932493577`, 0.9417628821181223], 
             UndirectedEdge[26, 74] -> 
             RGBColor[
              0.3495927399015075, 0.4766700360070217, 0.9435169060307154], 
             UndirectedEdge[81, 172] -> 
             RGBColor[
              0.7851552645502801, 0.8282289520022286, 0.7727853942333442], 
             UndirectedEdge[54, 73] -> 
             RGBColor[
              0.28297059999413937`, 0.41475042033909004`, 0.9394261291009534],
              UndirectedEdge[135, 165] -> 
             RGBColor[
              0.22609095697748494`, 0.3549663091509244, 0.9361869175770461], 
             UndirectedEdge[46, 109] -> 
             RGBColor[
              0.4676427269643195, 0.5755488960812328, 0.9521022706897019], 
             UndirectedEdge[40, 171] -> 
             RGBColor[
              0.6830257915160596, 0.7504348777708634, 0.9705035877143484], 
             UndirectedEdge[113, 167] -> 
             RGBColor[
              0.9077889348257765, 0.7877285014564059, 0.6151514893253305], 
             UndirectedEdge[103, 162] -> 
             RGBColor[
              0.9235960103474408, 0.7317131111648968, 0.5611505510553894], 
             UndirectedEdge[37, 119] -> 
             RGBColor[
              0.3779360600643469, 0.4878548266230827, 0.9465383122915882], 
             UndirectedEdge[71, 184] -> 
             RGBColor[
              0.3307081584442233, 0.45915751757499346`, 0.9423559109556644], 
             UndirectedEdge[107, 142] -> 
             RGBColor[
              0.6540600421097872, 0.7296534252184859, 0.9661696460739697], 
             UndirectedEdge[136, 143] -> 
             RGBColor[
              0.8644025575685669, 0.416927830578244, 0.20619406567310455`], 
             UndirectedEdge[3, 5] -> 
             RGBColor[
              0.27293521528598386`, 0.4042025947306783, 0.9388546287878452], 
             UndirectedEdge[24, 118] -> 
             RGBColor[
              0.5461172648909147, 0.6195523250843118, 0.9625471407361825], 
             UndirectedEdge[142, 185] -> 
             RGBColor[
              0.7052311845538637, 0.7696287106108853, 0.971269907331281], 
             UndirectedEdge[3, 28] -> 
             RGBColor[
              0.2792200802478043, 0.4108083862890054, 0.9392125425497964], 
             UndirectedEdge[43, 49] -> 
             RGBColor[
              0.8450514898395424, 0.34729106936125886`, 0.19077466358971318`],
              UndirectedEdge[19, 60] -> 
             RGBColor[
              0.25917942342753286`, 0.38974438531986844`, 0.9380712567913769],
              UndirectedEdge[87, 110] -> 
             RGBColor[
              0.7965007991763076, 0.8397612062456058, 0.9055025365037817], 
             UndirectedEdge[107, 185] -> 
             RGBColor[
              0.7184021799057017, 0.779940510091907, 0.9725672735090811], 
             UndirectedEdge[66, 81] -> 
             RGBColor[
              0.633976904061278, 0.7129754213419766, 0.9648440654867796], 
             UndirectedEdge[63, 112] -> 
             RGBColor[
              0.32715088352733546`, 0.45710875455411837`, 0.94209144443096], 
             UndirectedEdge[59, 193] -> 
             RGBColor[
              0.38274569330621644`, 0.5059368150091147, 0.9456091950221126], 
             UndirectedEdge[110, 180] -> 
             RGBColor[
              0.6645475989229954, 0.737297023885635, 0.9675905484473445], 
             UndirectedEdge[21, 196] -> 
             RGBColor[
              0.4056875246476441, 0.5246714028276624, 0.9473850392149095], 
             UndirectedEdge[24, 190] -> 
             RGBColor[
              0.1793170324527155, 0.3058039488372898, 0.9335232117711809], 
             UndirectedEdge[44, 60] -> 
             RGBColor[
              0.2686906729944792, 0.399741311662782, 0.9386129083835817], 
             UndirectedEdge[20, 106] -> 
             RGBColor[
              0.25022657945820426`, 0.38033437866501096`, 0.9375614055718693],
              UndirectedEdge[75, 139] -> 
             RGBColor[
              0.26665982071221705`, 0.39760675715065275`, 0.9384972543504835],
              UndirectedEdge[4, 81] -> 
             RGBColor[
              0.6906097692395512, 0.7572174460449604, 0.9704887002235348], 
             UndirectedEdge[79, 197] -> 
             RGBColor[
              0.5464425729840517, 0.6229880683860871, 0.9620969735266468], 
             UndirectedEdge[66, 90] -> 
             RGBColor[
              0.5397844128240585, 0.6347307875135932, 0.9579193049130958], 
             UndirectedEdge[14, 15] -> 
             RGBColor[
              0.3709417656089321, 0.49571284612038347`, 0.9448570591870451], 
             UndirectedEdge[14, 48] -> 
             RGBColor[
              0.36693773655078116`, 0.49224475739856516`, 0.9446019259960836],
              UndirectedEdge[122, 144] -> 
             RGBColor[
              0.9247271116948175, 0.7113578190580653, 0.33725586527563345`], 
             UndirectedEdge[80, 121] -> 
             RGBColor[
              0.5812862861253769, 0.6709534195821745, 0.9601801322470673], 
             UndirectedEdge[79, 170] -> 
             RGBColor[
              0.1931667580582484, 0.32036088857202627`, 0.934311933155583], 
             UndirectedEdge[91, 95] -> 
             RGBColor[
              0.9087217160297558, 0.9082261327367556, 0.679871771253554], 
             UndirectedEdge[48, 193] -> 
             RGBColor[
              0.3168945933506373, 0.44889990200011176`, 0.9414132211627845], 
             UndirectedEdge[67, 162] -> 
             RGBColor[
              0.9005534787430421, 0.5638554471764086, 0.5394474906426548], 
             UndirectedEdge[65, 87] -> 
             RGBColor[
              0.9550341089343712, 0.965005825208276, 0.9206936459458361], 
             UndirectedEdge[98, 121] -> 
             RGBColor[
              0.7580819454747305, 0.8096778551186503, 0.9434509884049964], 
             UndirectedEdge[161, 187] -> 
             RGBColor[
              0.2957430491853379, 0.4281750742590913, 0.9401535011872468], 
             UndirectedEdge[68, 122] -> 
             RGBColor[
              0.924281570863012, 0.9375100698293877, 0.7294250958369339], 
             UndirectedEdge[19, 90] -> 
             RGBColor[
              0.32617520722218063`, 0.45283835871142575`, 0.9421546927268274],
              UndirectedEdge[80, 168] -> 
             RGBColor[
              0.7792447125486042, 0.8280111263190817, 0.9760255070982982], 
             UndirectedEdge[109, 194] -> 
             RGBColor[
              0.3430360942965171, 0.47154235620939167`, 0.9430789344870343], 
             UndirectedEdge[44, 57] -> 
             RGBColor[
              0.3220009955988029, 0.4509816264225601, 0.9418243188335629], 
             UndirectedEdge[109, 151] -> 
             RGBColor[
              0.34470972375175946`, 0.47299196992446024`, 0.9431855766759899],
              UndirectedEdge[122, 138] -> 
             RGBColor[
              0.9528570018424507, 0.8395978867219851, 0.360717102170288], 
             UndirectedEdge[138, 192] -> 
             RGBColor[
              0.8650473379676169, 0.41300932570290905`, 0.20644673266035168`],
              UndirectedEdge[31, 46] -> 
             RGBColor[
              0.7241254080647266, 0.7839747878759986, 0.9735395315167075], 
             UndirectedEdge[101, 165] -> 
             RGBColor[
              0.23537363183733478`, 0.36472298898420613`, 0.9367155521778278],
              UndirectedEdge[76, 105] -> 
             RGBColor[
              0.3097803157470692, 0.4397426691808402, 0.94106957474386], 
             UndirectedEdge[6, 199] -> 
             RGBColor[
              0.3061701598017846, 0.4362401923980924, 0.9408532892006678], 
             UndirectedEdge[83, 175] -> 
             RGBColor[
              0.2881231207365411, 0.41908874892813175`, 0.9397590026698441], 
             UndirectedEdge[139, 182] -> 
             RGBColor[
              0.2571409182934481, 0.38760178717525484`, 0.9379551669396888], 
             UndirectedEdge[89, 149] -> 
             RGBColor[
              0.5437801205941402, 0.38941935202558264`, 0.567974527017709], 
             UndirectedEdge[53, 163] -> 
             RGBColor[
              0.2222172147783616, 0.3508947604902047, 0.935966313689494], 
             UndirectedEdge[8, 96] -> 
             RGBColor[
              0.3771970335719591, 0.5008951438379817, 0.9452642694982989], 
             UndirectedEdge[16, 187] -> 
             RGBColor[
              0.3028942075372073, 0.43437709498723787`, 0.9406088720414547], 
             UndirectedEdge[55, 191] -> 
             RGBColor[
              0.31630641834476525`, 0.445754027687974, 0.9414722756672911], 
             UndirectedEdge[122, 181] -> 
             RGBColor[
              0.9886341161577883, 0.9875460745600706, 0.6910581517385923], 
             UndirectedEdge[130, 177] -> 
             RGBColor[
              0.26541543308332344`, 0.3962988268539529, 0.9384263883159245], 
             UndirectedEdge[25, 131] -> 
             RGBColor[
              0.93909008289769, 0.7879991811183886, 0.30513287379478254`], 
             UndirectedEdge[19, 33] -> 
             RGBColor[
              0.29372081640032377`, 0.4247279965866454, 0.9400867276419496], 
             UndirectedEdge[1, 89] -> 
             RGBColor[
              0.9061524103512045, 0.6435271253680068, 0.2459445167509792], 
             UndirectedEdge[123, 127] -> 
             RGBColor[
              0.2860095413584047, 0.4167572429724312, 0.9396426650906227], 
             UndirectedEdge[40, 173] -> 
             RGBColor[
              0.7433614186788604, 0.7950716369237336, 0.832834751651226], 
             UndirectedEdge[17, 106] -> 
             RGBColor[
              0.25694510996125053`, 0.38739598020314986`, 0.9379440159448427],
              UndirectedEdge[51, 158] -> 
             RGBColor[
              0.267702506048196, 0.39870268554883526`, 0.9385566337378528], 
             UndirectedEdge[20, 189] -> 
             RGBColor[
              0.2283963086796351, 0.35738937995762443`, 0.9363182039460214], 
             UndirectedEdge[48, 140] -> 
             RGBColor[
              0.3113031778693076, 0.4437571221637065, 0.9410679174089878], 
             UndirectedEdge[11, 189] -> 
             RGBColor[
              0.2386268283641832, 0.36814230479849686`, 0.9369008169073587], 
             UndirectedEdge[40, 169] -> 
             RGBColor[
              0.38208210782853824`, 0.5009795735314966, 0.9459763978166744], 
             UndirectedEdge[94, 167] -> 
             RGBColor[0.666701611701555, 0.7359313939081493, 0.9698223518406],
              UndirectedEdge[81, 198] -> 
             RGBColor[
              0.6362473175270285, 0.7147490855972023, 0.9650703590828255], 
             UndirectedEdge[34, 60] -> 
             RGBColor[
              0.25285259350547307`, 0.38309448592759754`, 0.9377109531870217],
              UndirectedEdge[13, 101] -> 
             RGBColor[
              0.3149218240784437, 0.4419302409877936, 0.941480147105756], 
             UndirectedEdge[31, 117] -> 
             RGBColor[
              0.8147533586460658, 0.8554575003050673, 0.9821051874244302], 
             UndirectedEdge[94, 105] -> 
             RGBColor[
              0.3806688871734759, 0.5041379899202462, 0.945476862771782], 
             UndirectedEdge[125, 190] -> 
             RGBColor[
              0.179333445229231, 0.3058211997060377, 0.933524146454523], 
             UndirectedEdge[79, 119] -> 
             RGBColor[
              0.3844232617951737, 0.4946732869545277, 0.9469077488332039], 
             UndirectedEdge[20, 28] -> 
             RGBColor[
              0.2600890189665118, 0.39070042790302345`, 0.9381230569116956], 
             UndirectedEdge[156, 178] -> 
             RGBColor[
              0.9316378178168464, 0.9481531008980535, 0.987322033962275], 
             UndirectedEdge[95, 131] -> 
             RGBColor[
              0.9394422371635587, 0.7891870801469172, 0.306500926618929], 
             UndirectedEdge[49, 133] -> 
             RGBColor[
              0.829082723763209, 0.22454813574064747`, 0.1754829551608747], 
             UndirectedEdge[34, 44] -> 
             RGBColor[
              0.2675860001638932, 0.3985802304775334, 0.9385499989000968], 
             UndirectedEdge[24, 125] -> 
             RGBColor[
              0.17894341561590066`, 0.30541125385312173`, 0.9335019348450408],
              UndirectedEdge[95, 129] -> 
             RGBColor[
              0.9849427513832404, 0.9608705061848779, 0.39600586175704294`], 
             UndirectedEdge[13, 16] -> 
             RGBColor[
              0.35048029688204574`, 0.4779901503324755, 0.9435532724931343], 
             UndirectedEdge[13, 199] -> 
             RGBColor[
              0.3251439087147671, 0.45267430005816894`, 0.9420622797035756], 
             UndirectedEdge[121, 196] -> 
             RGBColor[
              0.5189244738450667, 0.6203252910053908, 0.955270781945516], 
             UndirectedEdge[26, 40] -> 
             RGBColor[
              0.4439921507491714, 0.557946476502165, 0.9497988277939646], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.31163329513552707`, 0.44101997430243733`, 0.9411996419147166],
              UndirectedEdge[54, 126] -> 
             RGBColor[
              0.29001572662104147`, 0.4221552951107917, 0.9398273386400247], 
             UndirectedEdge[16, 193] -> 
             RGBColor[
              0.3198238857723562, 0.4514371078652866, 0.9415998730856248], 
             UndirectedEdge[85, 150] -> 
             RGBColor[
              0.3215409260409259, 0.45053715769585945`, 0.9417966871465304], 
             UndirectedEdge[26, 169] -> 
             RGBColor[
              0.3344928369204973, 0.4607990805848347, 0.9426569888942514], 
             UndirectedEdge[22, 79] -> 
             RGBColor[
              0.5241950050244188, 0.3370826401249345, 0.5625493919022517], 
             UndirectedEdge[27, 67] -> 
             RGBColor[
              0.5474773621295221, 0.27457683969669183`, 0.5520694598597993], 
             UndirectedEdge[49, 95] -> 
             RGBColor[
              0.9071817078072888, 0.605474620924499, 0.27812431524098535`], 
             UndirectedEdge[147, 178] -> 
             RGBColor[
              0.7115638776908443, 0.7729379814418316, 0.9672966305905184], 
             UndirectedEdge[1, 136] -> 
             RGBColor[
              0.9331596302538536, 0.7720124271387454, 0.2686954588022206], 
             UndirectedEdge[65, 110] -> 
             RGBColor[
              0.7635603354949406, 0.815471840469592, 0.9772401996765336], 
             UndirectedEdge[77, 106] -> 
             RGBColor[
              0.2877229919008626, 0.4197454855521064, 0.9396967707895075], 
             UndirectedEdge[25, 64] -> 
             RGBColor[
              0.8007620659771775, 0.8225276552268693, 0.6680235781600576], 
             UndirectedEdge[82, 187] -> 
             RGBColor[
              0.3007127795635599, 0.4324876517182224, 0.9404698733799348], 
             UndirectedEdge[167, 188] -> 
             RGBColor[
              0.7899648841688349, 0.8366160464867711, 0.9794955855762202], 
             UndirectedEdge[13, 137] -> 
             RGBColor[
              0.31409319630205523`, 0.44105930065677384`, 0.9414329579797356],
              UndirectedEdge[37, 125] -> 
             RGBColor[
              0.18497678859456473`, 0.3117527113916389, 0.9338455265106003], 
             UndirectedEdge[105, 182] -> 
             RGBColor[
              0.30416697639606216`, 0.43384269361666083`, 0.9407499033720115],
              UndirectedEdge[111, 116] -> 
             RGBColor[
              0.42503929713653266`, 0.5423745144765412, 0.9483579559716804], 
             UndirectedEdge[146, 179] -> 
             RGBColor[
              0.802014133137712, 0.8452588034311341, 0.9809009316091206], 
             UndirectedEdge[9, 63] -> 
             RGBColor[
              0.3067096536024727, 0.43562372585425413`, 0.9409273466268289], 
             UndirectedEdge[38, 120] -> 
             RGBColor[
              0.960788560046435, 0.8793927471320053, 0.302171389549849], 
             UndirectedEdge[71, 81] -> 
             RGBColor[
              0.43330857195401157`, 0.5446846710814149, 0.9498164169017225], 
             UndirectedEdge[68, 181] -> 
             RGBColor[
              0.9199773592711327, 0.9377520223513063, 0.9477245085556535], 
             UndirectedEdge[114, 158] -> 
             RGBColor[
              0.23522624458781927`, 0.364568075640074, 0.9367071586920077], 
             UndirectedEdge[118, 149] -> 
             RGBColor[
              0.5734377675010032, 0.6482679055474284, 0.9641030029427655], 
             UndirectedEdge[87, 162] -> 
             RGBColor[
              0.9854379176982261, 0.9880317806397674, 0.8813919321035765], 
             UndirectedEdge[88, 122] -> 
             RGBColor[
              0.8525664665525501, 0.8811976138560375, 0.7223536497554326], 
             UndirectedEdge[49, 162] -> 
             RGBColor[
              0.9088194332461141, 0.62739119565138, 0.547362978009857], 
             UndirectedEdge[47, 116] -> 
             RGBColor[
              0.42055225492425696`, 0.5386829584696233, 0.9480181956973843], 
             UndirectedEdge[23, 95] -> 
             RGBColor[
              0.9866024805360858, 0.9658049975494172, 0.45892937586547133`], 
             UndirectedEdge[54, 115] -> 
             RGBColor[
              0.2691801918114708, 0.40025582697672574`, 0.938640785756031], 
             UndirectedEdge[62, 105] -> 
             RGBColor[
              0.3497224989411253, 0.4773337838440822, 0.9435049862784333], 
             UndirectedEdge[13, 108] -> 
             RGBColor[
              0.5796159484292636, 0.6654249189415207, 0.9620681904824614], 
             UndirectedEdge[76, 182] -> 
             RGBColor[
              0.27073696797748936`, 0.4018920974325212, 0.938729441855642], 
             UndirectedEdge[117, 171] -> 
             RGBColor[
              0.8267342564377225, 0.8650107429913272, 0.9832479361512722], 
             UndirectedEdge[40, 46] -> 
             RGBColor[
              0.5446619359975361, 0.6412201222402223, 0.9572969292455886], 
             UndirectedEdge[19, 177] -> 
             RGBColor[
              0.2790041774695689, 0.41058145878005325`, 0.9392002472059755], 
             UndirectedEdge[64, 87] -> 
             RGBColor[
              0.8052886005993835, 0.8468955393268014, 0.9061943444225835], 
             UndirectedEdge[62, 107] -> 
             RGBColor[
              0.5117328555891169, 0.611469763511346, 0.9556934742742034], 
             UndirectedEdge[53, 148] -> 
             RGBColor[
              0.20810268194188267`, 0.3360594915659958, 0.9351625119250367], 
             UndirectedEdge[76, 111] -> 
             RGBColor[
              0.368423059805849, 0.49034117218248097`, 0.9448600884518084], 
             UndirectedEdge[11, 48] -> 
             RGBColor[
              0.2814824902109824, 0.4124136886940051, 0.9393696733626], 
             UndirectedEdge[96, 111] -> 
             RGBColor[
              0.3833462518703272, 0.5060263932272735, 0.9457099421629962], 
             UndirectedEdge[168, 198] -> 
             RGBColor[
              0.8173765882647961, 0.8581441256038294, 0.9795908811512684], 
             UndirectedEdge[118, 128] -> 
             RGBColor[
              0.901444520807011, 0.7626039594239429, 0.6105848646794676], 
             UndirectedEdge[56, 129] -> 
             RGBColor[
              0.5845933454317087, 0.6420998957641366, 0.6750810838088802], 
             UndirectedEdge[53, 100] -> 
             RGBColor[
              0.21261327393044743`, 0.34080040973402737`, 0.9354193834659627],
              UndirectedEdge[129, 143] -> 
             RGBColor[
              0.9055290665332671, 0.5698386545013628, 0.2921055427004665], 
             UndirectedEdge[18, 160] -> 
             RGBColor[
              0.34254111760690553`, 0.47111363227910186`, 0.9430473950100628],
              UndirectedEdge[68, 111] -> 
             RGBColor[
              0.6580603131297789, 0.7303031444944423, 0.9683812581650608], 
             UndirectedEdge[51, 166] -> 
             RGBColor[
              0.33653220976868264`, 0.46344910853990606`, 0.9427545820635193],
              UndirectedEdge[107, 181] -> 
             RGBColor[
              0.8257804710137671, 0.8638766258907483, 0.9384122883545408], 
             UndirectedEdge[31, 173] -> 
             RGBColor[
              0.9228248907460509, 0.93782630255951, 0.8490773539223448], 
             UndirectedEdge[135, 148] -> 
             RGBColor[
              0.2190360411775415, 0.34755114533768694`, 0.935785150559052], 
             UndirectedEdge[44, 177] -> 
             RGBColor[
              0.2885154270365152, 0.4205783851229668, 0.9397418987981803], 
             UndirectedEdge[80, 184] -> 
             RGBColor[
              0.4955150283010483, 0.599088932806033, 0.9540444790837972], 
             UndirectedEdge[65, 162] -> 
             RGBColor[
              0.9524974540168591, 0.9637424148637534, 0.9531295952763283], 
             UndirectedEdge[5, 17] -> 
             RGBColor[
              0.26052268450773763`, 0.3911562378828352, 0.9381477535227178], 
             UndirectedEdge[44, 141] -> 
             RGBColor[
              0.321381334697979, 0.45044490729532893`, 0.941784834588907], 
             UndirectedEdge[94, 174] -> 
             RGBColor[
              0.39976902935609954`, 0.5206815730777754, 0.9466939069420661], 
             UndirectedEdge[161, 193] -> 
             RGBColor[
              0.31267272742048674`, 0.4452350871371401, 0.9411445022314171], 
             UndirectedEdge[101, 124] -> 
             RGBColor[
              0.2714494089102611, 0.40264091802422836`, 0.9387700143128014], 
             UndirectedEdge[106, 189] -> 
             RGBColor[
              0.25322164598941777`, 0.3834823834875024, 0.9377319701800181], 
             UndirectedEdge[2, 80] -> 
             RGBColor[
              0.4985089361983589, 0.6016821053484971, 0.954235248247605], 
             UndirectedEdge[97, 102] -> 
             RGBColor[
              0.3273981891467483, 0.4554287175679108, 0.9421765599569466], 
             UndirectedEdge[91, 136] -> 
             RGBColor[
              0.8729121465452325, 0.773250594157032, 0.6146156000869095], 
             UndirectedEdge[59, 154] -> 
             RGBColor[
              0.7176662191262557, 0.7759253920834623, 0.911377748265729], 
             UndirectedEdge[108, 162] -> 
             RGBColor[
              0.8820669248115173, 0.9078962359074088, 0.9463287513615282], 
             UndirectedEdge[146, 147] -> 
             RGBColor[
              0.6383951985626789, 0.7149619751698173, 0.9662861034465073], 
             UndirectedEdge[99, 156] -> 
             RGBColor[
              0.7424696241286013, 0.7983584952437333, 0.9755694516963352], 
             UndirectedEdge[143, 154] -> 
             RGBColor[
              0.9036629908200117, 0.5747841615261196, 0.5202434925656607], 
             UndirectedEdge[139, 145] -> 
             RGBColor[
              0.2284570343408142, 0.357453206477753, 0.9363216621825899], 
             UndirectedEdge[104, 123] -> 
             RGBColor[
              0.23468312728084179`, 0.36399722491481445`, 0.9366762289648454],
              UndirectedEdge[116, 126] -> 
             RGBColor[
              0.34840388541039236`, 0.4760510392042203, 0.9434261144656448], 
             UndirectedEdge[17, 28] -> 
             RGBColor[
              0.2668075494695581, 0.39776202944116235`, 0.938505667284669], 
             UndirectedEdge[89, 118] -> 
             RGBColor[
              0.8836498800355815, 0.6748620936624041, 0.59546480538561], 
             UndirectedEdge[123, 163] -> 
             RGBColor[
              0.2417268008308885, 0.37140057241061075`, 0.9370773557533394], 
             UndirectedEdge[47, 157] -> 
             RGBColor[
              0.5046032669357259, 0.6086499170733246, 0.9541568402025347], 
             UndirectedEdge[117, 151] -> 
             RGBColor[
              0.565437397706639, 0.6532390613039136, 0.9611245836688005], 
             UndirectedEdge[69, 86] -> 
             RGBColor[
              0.39677259596818604`, 0.5180862130822859, 0.9465029768562303], 
             UndirectedEdge[73, 94] -> 
             RGBColor[
              0.35563109287921313`, 0.4810081428778644, 0.9439343254346236], 
             UndirectedEdge[61, 174] -> 
             RGBColor[
              0.3276038093333696, 0.4549444137194375, 0.9422139156652158], 
             UndirectedEdge[175, 187] -> 
             RGBColor[
              0.3016125136762855, 0.4332669561847139, 0.940527203641994], 
             UndirectedEdge[75, 134] -> 
             RGBColor[
              0.2575067829018646, 0.3879863340758565, 0.93797600238789], 
             UndirectedEdge[38, 178] -> 
             RGBColor[
              0.9536200808381681, 0.9247692797301834, 0.650059594771984], 
             UndirectedEdge[8, 179] -> 
             RGBColor[
              0.6280655556399748, 0.706255507224953, 0.9656353303034069], 
             UndirectedEdge[29, 167] -> 
             RGBColor[
              0.9544593958943188, 0.963459656199136, 0.8733980891466777], 
             UndirectedEdge[68, 185] -> 
             RGBColor[
              0.8125990681630673, 0.8538159065524649, 0.9818794937101938], 
             UndirectedEdge[79, 118] -> 
             RGBColor[
              0.5586378396004057, 0.632712242954274, 0.9632601689433578], 
             UndirectedEdge[171, 173] -> 
             RGBColor[
              0.9348057885377076, 0.9473795452457701, 0.8502201026491867], 
             UndirectedEdge[80, 166] -> 
             RGBColor[
              0.5054107612208105, 0.6076601192871327, 0.9546750264349914], 
             UndirectedEdge[109, 132] -> 
             RGBColor[
              0.2948786821955154, 0.42460409000948357`, 0.9402017631916271], 
             UndirectedEdge[118, 197] -> 
             RGBColor[
              0.9011122603260905, 0.9239864726160629, 0.9904300858939554], 
             UndirectedEdge[111, 167] -> 
             RGBColor[
              0.687885792752501, 0.7540851723545239, 0.971226039036996], 
             UndirectedEdge[113, 122] -> 
             RGBColor[
              0.9466202120897103, 0.8137405258050889, 0.35564035163633406`], 
             UndirectedEdge[119, 190] -> 
             RGBColor[
              0.3722927166990131, 0.48192331493748153`, 0.946216932235511], 
             UndirectedEdge[19, 130] -> 
             RGBColor[
              0.2508128361327613, 0.38095057160079043`, 0.9375947920221963], 
             UndirectedEdge[35, 167] -> 
             RGBColor[
              0.876824539183936, 0.9046201030499366, 0.9881135013695121], 
             UndirectedEdge[102, 112] -> 
             RGBColor[
              0.337642108559284, 0.46619572637249007`, 0.9427599360129698], 
             UndirectedEdge[134, 145] -> 
             RGBColor[
              0.21930399653046173`, 0.34783278340295676`, 0.9358004102199964],
              UndirectedEdge[109, 150] -> 
             RGBColor[
              0.31023488720570846`, 0.44074443511482886`, 0.941076276349488], 
             UndirectedEdge[147, 179] -> 
             RGBColor[
              0.6443148010184508, 0.7195864135989113, 0.9668761140974684], 
             UndirectedEdge[63, 102] -> 
             RGBColor[
              0.3633436999904507, 0.48913178357153686`, 0.9443729171645411], 
             UndirectedEdge[62, 182] -> 
             RGBColor[
              0.31067915117154543`, 0.43948321209576313`, 0.9411648533902153],
              UndirectedEdge[8, 99] -> 
             RGBColor[
              0.5061464386241231, 0.6098124694135529, 0.9543032645305172], 
             UndirectedEdge[60, 123] -> 
             RGBColor[
              0.252194354195388, 0.3824026346779154, 0.9376734674320901], 
             UndirectedEdge[7, 97] -> 
             RGBColor[
              0.3157107895654947, 0.44530567947641203`, 0.9414318491903908], 
             UndirectedEdge[130, 163] -> 
             RGBColor[
              0.23512312567678792`, 0.3644596911264634, 0.9367012862225752], 
             UndirectedEdge[127, 135] -> 
             RGBColor[
              0.2774333145415366, 0.4077430848237163, 0.9391542616607926], 
             UndirectedEdge[37, 56] -> 
             RGBColor[
              0.18496037439835666`, 0.3117354590307041, 0.9338445917464089], 
             UndirectedEdge[100, 148] -> 
             RGBColor[
              0.20930368592266696`, 0.3373218228978505, 0.9352309073250162], 
             UndirectedEdge[53, 135] -> 
             RGBColor[
              0.222345629185322, 0.35102973217386374`, 0.9359736266999984], 
             UndirectedEdge[103, 154] -> 
             RGBColor[
              0.9254091486755369, 0.7326773288061676, 0.5407051440124293], 
             UndirectedEdge[63, 140] -> 
             RGBColor[
              0.32917806589633525`, 0.4592394517547229, 0.942206889467927], 
             UndirectedEdge[8, 75] -> 
             RGBColor[
              0.36617940457524284`, 0.4893149172044077, 0.9446368318260574], 
             UndirectedEdge[50, 53] -> 
             RGBColor[
              0.22682228238214364`, 0.3557349785199296, 0.9362285654769424], 
             UndirectedEdge[1, 167] -> 
             RGBColor[
              0.9367941803977453, 0.9031603919681208, 0.6421668592196352], 
             UndirectedEdge[27, 119] -> 
             RGBColor[
              0.4208137004428272, 0.5329219452602844, 0.9489801304793581], 
             UndirectedEdge[96, 126] -> 
             RGBColor[
              0.3067108401441868, 0.4397029179549527, 0.9407781006569607], 
             UndirectedEdge[102, 106] -> 
             RGBColor[
              0.32444342089519307`, 0.4523230687923987, 0.9420082902762085], 
             UndirectedEdge[16, 176] -> 
             RGBColor[
              0.30857911035131147`, 0.440352288288518, 0.9409326188466578], 
             UndirectedEdge[40, 166] -> 
             RGBColor[
              0.4412529384384768, 0.5555739084754552, 0.9496242876077174], 
             UndirectedEdge[33, 90] -> 
             RGBColor[
              0.35549444310349765`, 0.4823331517711803, 0.9438727694565298], 
             UndirectedEdge[13, 161] -> 
             RGBColor[
              0.34332913853017627`, 0.471788129604329, 0.9430979016389265], 
             UndirectedEdge[11, 106] -> 
             RGBColor[
              0.2604570991427524, 0.3910873035058834, 0.9381440185332068], 
             UndirectedEdge[88, 167] -> 
             RGBColor[
              0.8137351892886164, 0.8551855895073546, 0.9818647874444291], 
             UndirectedEdge[29, 159] -> 
             RGBColor[
              0.9081437399557057, 0.5833500342919629, 0.46216641584665136`], 
             UndirectedEdge[156, 157] -> 
             RGBColor[
              0.7392642763541118, 0.795756249521131, 0.9753171149779516], 
             UndirectedEdge[171, 183] -> 
             RGBColor[
              0.8671903203612858, 0.6797554080985058, 0.5963535737913382], 
             UndirectedEdge[100, 104] -> 
             RGBColor[
              0.21637454520909913`, 0.34475374432626316`, 0.9356335823009796],
              UndirectedEdge[108, 180] -> 
             RGBColor[
              0.7526503794757171, 0.8066954638919603, 0.9759808139745987], 
             UndirectedEdge[178, 179] -> 
             RGBColor[
              0.8751828122658775, 0.9032348097031484, 0.9819114587531318], 
             UndirectedEdge[150, 151] -> 
             RGBColor[
              0.3174016073666887, 0.4469518879084411, 0.9415329334208639], 
             UndirectedEdge[2, 121] -> 
             RGBColor[
              0.45989815510185605`, 0.5703361338584898, 0.9511956661237368], 
             UndirectedEdge[12, 14] -> 
             RGBColor[
              0.500367704585658, 0.6042677811858945, 0.954084097379875], 
             UndirectedEdge[43, 131] -> 
             RGBColor[
              0.8773120191958123, 0.531003528583677, 0.2191512749676569], 
             UndirectedEdge[75, 76] -> 
             RGBColor[
              0.2802558703962583, 0.4118970674079191, 0.9392715292664366], 
             UndirectedEdge[113, 138] -> 
             RGBColor[
              0.9065388861824932, 0.6660342904889218, 0.24359871478674944`], 
             UndirectedEdge[17, 20] -> 
             RGBColor[
              0.23211977265146783`, 0.3613029766732719, 0.9365302497108459], 
             UndirectedEdge[86, 187] -> 
             RGBColor[
              0.3373933626791634, 0.4642585291932452, 0.9428071277006951], 
             UndirectedEdge[8, 185] -> 
             RGBColor[
              0.6088853490181219, 0.6912717840369921, 0.9637236265565623], 
             UndirectedEdge[4, 41] -> 
             RGBColor[
              0.6772999087061907, 0.7464119016615944, 0.969440899246723], 
             UndirectedEdge[8, 107] -> 
             RGBColor[
              0.5577142065740452, 0.6512964986445926, 0.9586233652992509], 
             UndirectedEdge[149, 192] -> 
             RGBColor[
              0.5254435040297809, 0.2484760819553035, 0.5504153622874323], 
             UndirectedEdge[11, 140] -> 
             RGBColor[
              0.27568296917584306`, 0.40709065828657925`, 0.9390111093069351],
              UndirectedEdge[94, 153] -> 
             RGBColor[
              0.5020487622755229, 0.6056693221783567, 0.9542062732491396], 
             UndirectedEdge[56, 79] -> 
             RGBColor[
              0.1914475761291835, 0.31855391936214905`, 0.9342140282880245], 
             UndirectedEdge[5, 15] -> 
             RGBColor[
              0.303658911440855, 0.4349821137845143, 0.940659697404096], 
             UndirectedEdge[79, 128] -> 
             RGBColor[
              0.5467748334649722, 0.46160555519396695`, 0.5822517523121589], 
             UndirectedEdge[109, 152] -> 
             RGBColor[
              0.3096412804178116, 0.4401205167439052, 0.9410424713210799], 
             UndirectedEdge[118, 192] -> 
             RGBColor[
              0.8653132634712222, 0.5339188235921248, 0.5779056406553331], 
             UndirectedEdge[99, 107] -> 
             RGBColor[
              0.615663269511703, 0.6984811954684678, 0.963146911483036], 
             UndirectedEdge[3, 189] -> 
             RGBColor[
              0.24752736996092756`, 0.37749733834360644`, 0.937407689584122], 
             UndirectedEdge[35, 138] -> 
             RGBColor[
              0.8755744905406526, 0.7829258920824524, 0.6165607268309311], 
             UndirectedEdge[12, 86] -> 
             RGBColor[
              0.4879611145029988, 0.5935218164296439, 0.9532935604305248], 
             UndirectedEdge[16, 127] -> 
             RGBColor[
              0.3222744622049885, 0.4535596740016799, 0.9417560216489524], 
             UndirectedEdge[37, 195] -> 
             RGBColor[
              0.18496037439835666`, 0.3117354590307041, 0.9338445917464089], 
             UndirectedEdge[57, 71] -> 
             RGBColor[
              0.32543061952646807`, 0.4545863786212526, 0.9420196308425695], 
             UndirectedEdge[58, 73] -> 
             RGBColor[
              0.2786440888438728, 0.4102029828035092, 0.9391797406914454], 
             UndirectedEdge[35, 153] -> 
             RGBColor[
              0.7121716897579038, 0.7743580313201439, 0.9724974227780518], 
             UndirectedEdge[35, 122] -> 
             RGBColor[
              0.9156558164478696, 0.9306321273986194, 0.7286023636805157], 
             UndirectedEdge[19, 44] -> 
             RGBColor[
              0.2739128300859531, 0.40523012986980433`, 0.9389103025044521], 
             UndirectedEdge[181, 192] -> 
             RGBColor[
              0.9008244522829545, 0.5609575135409945, 0.536787782228656], 
             UndirectedEdge[119, 128] -> 
             RGBColor[
              0.727229943001779, 0.6245650034241965, 0.5942324445693138], 
             UndirectedEdge[116, 153] -> 
             RGBColor[
              0.48777642817979994`, 0.593307343733011, 0.9532968527410897], 
             UndirectedEdge[186, 193] -> 
             RGBColor[
              0.29935843960625863`, 0.43124092646978174`, 0.9403862732371204],
              UndirectedEdge[22, 119] -> 
             RGBColor[
              0.7046501145612256, 0.5000420883551641, 0.5745300841594067], 
             UndirectedEdge[85, 109] -> 
             RGBColor[
              0.34884904242599657`, 0.47657723971187865`, 0.9434493304016565],
              UndirectedEdge[98, 99] -> 
             RGBColor[
              0.7687919437411839, 0.8183727141912807, 0.944294118700548], 
             UndirectedEdge[161, 175] -> 
             RGBColor[
              0.31452843153509336`, 0.4468424047708116, 0.941262746056665], 
             UndirectedEdge[54, 61] -> 
             RGBColor[
              0.27330173727350593`, 0.40458783257840025`, 0.9388755016728139],
              UndirectedEdge[43, 154] -> 
             RGBColor[
              0.9209464577022384, 0.7076324616463945, 0.536794159970965], 
             UndirectedEdge[87, 95] -> 
             RGBColor[
              0.9838001922594006, 0.9661152059128862, 0.6121532693347048], 
             UndirectedEdge[12, 108] -> 
             RGBColor[
              0.6825976109082605, 0.7510751508326818, 0.9696102227606116], 
             UndirectedEdge[15, 48] -> 
             RGBColor[
              0.32110672796259787`, 0.4525482412929506, 0.9416816146556142], 
             UndirectedEdge[13, 187] -> 
             RGBColor[
              0.33041322067136836`, 0.4582126810182313, 0.9423623592242556], 
             UndirectedEdge[15, 28] -> 
             RGBColor[
              0.3099437764026754, 0.4415879053428414, 0.9410176111660472], 
             UndirectedEdge[52, 134] -> 
             RGBColor[
              0.22165741455534713`, 0.35030637496243233`, 0.9359344338949436],
              UndirectedEdge[66, 172] -> 
             RGBColor[
              0.8427983522117647, 0.874271591791478, 0.7778392040313489], 
             UndirectedEdge[101, 176] -> 
             RGBColor[
              0.27302063754770944`, 0.4042923789438361, 0.9388594934592795], 
             UndirectedEdge[119, 192] -> 
             RGBColor[
              0.6910986856659902, 0.39587986759237864`, 0.5615532205451794], 
             UndirectedEdge[168, 184] -> 
             RGBColor[
              0.6548626736277727, 0.7248006680529328, 0.9668502718111599], 
             UndirectedEdge[16, 175] -> 
             RGBColor[
              0.3216795898869629, 0.4530444254989581, 0.9417181169108728], 
             UndirectedEdge[60, 104] -> 
             RGBColor[
              0.23644603942151277`, 0.3658501573497452, 0.9367766242032618], 
             UndirectedEdge[122, 136] -> 
             RGBColor[
              0.9504725003418423, 0.8301441328600938, 0.35879847629145456`], 
             UndirectedEdge[107, 157] -> 
             RGBColor[
              0.6124579217372135, 0.6958789497458655, 0.9628945747646525], 
             UndirectedEdge[86, 110] -> 
             RGBColor[
              0.49849330988433693`, 0.6020723271102092, 0.9541226934316467], 
             UndirectedEdge[5, 9] -> 
             RGBColor[
              0.27138694905370225`, 0.40257526875480143`, 0.9387664573163714],
              UndirectedEdge[3, 77] -> 
             RGBColor[
              0.2820287158723724, 0.41376044040821036`, 0.9393724901936115], 
             UndirectedEdge[84, 139] -> 
             RGBColor[
              0.25596738815303377`, 0.386368332591571, 0.9378883361342745], 
             UndirectedEdge[96, 191] -> 
             RGBColor[
              0.29321373700723585`, 0.4255166067922517, 0.9400094606004861], 
             UndirectedEdge[46, 151] -> 
             RGBColor[
              0.4748094471252997, 0.581756348874845, 0.9525589277610778], 
             UndirectedEdge[72, 191] -> 
             RGBColor[
              0.2650536461439216, 0.3959185658420248, 0.9384057850849414], 
             UndirectedEdge[111, 185] -> 
             RGBColor[
              0.6150345673164899, 0.6964030334262838, 0.9641692992212595], 
             UndirectedEdge[23, 129] -> 
             RGBColor[
              0.9919194200162629, 0.9837402828928126, 0.4795846817261888], 
             UndirectedEdge[101, 123] -> 
             RGBColor[
              0.2511378900976988, 0.38129222392755147`, 0.9376133033646252], 
             UndirectedEdge[122, 142] -> 
             RGBColor[
              0.8169136872538085, 0.8533228738878083, 0.7188155094580211], 
             UndirectedEdge[18, 174] -> 
             RGBColor[
              0.3498905326098686, 0.47747932616232985`, 0.9435156932352192], 
             UndirectedEdge[123, 135] -> 
             RGBColor[
              0.24185521523784892`, 0.3715355440942698, 0.9370846687638437], 
             UndirectedEdge[171, 178] -> 
             RGBColor[
              0.9084510251565888, 0.9296645818194842, 0.9851104569792455], 
             UndirectedEdge[81, 173] -> 
             RGBColor[
              0.7857376160501509, 0.8294745429756838, 0.8361707611374197], 
             UndirectedEdge[77, 102] -> 
             RGBColor[
              0.33711449602806876`, 0.4656411721496162, 0.9427298892598499], 
             UndirectedEdge[31, 171] -> 
             RGBColor[
              0.8624892635832501, 0.8931895434066397, 0.9867461899854671], 
             UndirectedEdge[109, 196] -> 
             RGBColor[
              0.4163582231260193, 0.5339138255247312, 0.9480649666862233], 
             UndirectedEdge[18, 153] -> 
             RGBColor[
              0.4521702655292919, 0.5624670752629113, 0.9510280595422927], 
             UndirectedEdge[97, 140] -> 
             RGBColor[
              0.29323255505263285`, 0.42553638575109687`, 0.9400105322603325],
              UndirectedEdge[116, 167] -> 
             RGBColor[
              0.652429277605832, 0.7235694154628036, 0.96891293133255], 
             UndirectedEdge[128, 190] -> 
             RGBColor[
              0.5346442883688116, 0.44885558317692076`, 0.5815609357144658], 
             UndirectedEdge[94, 126] -> 
             RGBColor[
              0.3626762195061153, 0.4884130176495661, 0.9443355349736948], 
             UndirectedEdge[41, 198] -> 
             RGBColor[
              0.6229374569936681, 0.7039435412138363, 0.9640225581060137], 
             UndirectedEdge[11, 77] -> 
             RGBColor[
              0.27312817427562797`, 0.40440540686310084`, 0.9388656175168482],
              UndirectedEdge[29, 122] -> 
             RGBColor[
              0.9932906731582525, 0.9894716805478189, 0.6138869514576812], 
             UndirectedEdge[84, 152] -> 
             RGBColor[
              0.2722580627952489, 0.4034908645289682, 0.9388160659552552], 
             UndirectedEdge[16, 64] -> 
             RGBColor[
              0.47278195616545676`, 0.5793252259853976, 0.9526162456912082], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.23972819328057, 0.3692999091561883, 0.9369635380100236], 
             UndirectedEdge[26, 121] -> 
             RGBColor[
              0.46953919243500225`, 0.5786867158238351, 0.9518099844973704], 
             UndirectedEdge[40, 74] -> 
             RGBColor[
              0.3971820108095485, 0.5168505289536836, 0.9468363149531384], 
             UndirectedEdge[78, 91] -> 
             RGBColor[
              0.8828910750951913, 0.909457394113841, 0.9886921329803882], 
             UndirectedEdge[139, 152] -> 
             RGBColor[
              0.26544888260262894`, 0.3963339844195651, 0.9384282932165648], 
             UndirectedEdge[40, 196] -> 
             RGBColor[
              0.49337743215923585`, 0.5995850516837207, 0.9532596252421102], 
             UndirectedEdge[6, 86] -> 
             RGBColor[
              0.3660057031110193, 0.4914374768784062, 0.9445425376494667], 
             UndirectedEdge[82, 180] -> 
             RGBColor[
              0.5213332999548519, 0.6173712520138998, 0.9573268973237518], 
             UndirectedEdge[44, 90] -> 
             RGBColor[
              0.33568645678912695`, 0.46283528505433924`, 0.9426963443190322],
              UndirectedEdge[4, 66] -> 
             RGBColor[
              0.7482528569010358, 0.8032600858342098, 0.9755425100215394], 
             UndirectedEdge[131, 143] -> 
             RGBColor[
              0.8600285523135855, 0.398155228463402, 0.20260060756235265`], 
             UndirectedEdge[22, 144] -> 
             RGBColor[
              0.8504688767152189, 0.38893147880177464`, 0.1959623593799244], 
             UndirectedEdge[35, 160] -> 
             RGBColor[
              0.6025425418355174, 0.6830045883363345, 0.9645167582458221], 
             UndirectedEdge[76, 174] -> 
             RGBColor[
              0.3288804579296929, 0.4562862523383694, 0.9422866189141441], 
             UndirectedEdge[85, 196] -> 
             RGBColor[
              0.42766426196123664`, 0.5437065481057618, 0.9487853774832657], 
             UndirectedEdge[6, 137] -> 
             RGBColor[
              0.2951194473890727, 0.4246251929966973, 0.9402239674768278], 
             UndirectedEdge[123, 177] -> 
             RGBColor[
              0.27201910823742403`, 0.40323970813810023`, 0.9388024578466887],
              UndirectedEdge[29, 113] -> 
             RGBColor[
              0.946972557498295, 0.8159080843147557, 0.4967685640741427], 
             UndirectedEdge[96, 174] -> 
             RGBColor[
              0.3438036499941711, 0.471971473383162, 0.943136472625332], 
             UndirectedEdge[74, 158] -> 
             RGBColor[
              0.2780238238703263, 0.40955104498924105`, 0.9391444175188017], 
             UndirectedEdge[46, 121] -> 
             RGBColor[
              0.570208977683367, 0.6619603615618923, 0.9593080859489944], 
             UndirectedEdge[32, 165] -> 
             RGBColor[
              0.2270272954930984, 0.35595046029812505`, 0.9362402406703216], 
             UndirectedEdge[32, 148] -> 
             RGBColor[
              0.219972379693155, 0.3485352964848875, 0.9358384736523275], 
             UndirectedEdge[27, 190] -> 
             RGBColor[
              0.22822804580985986`, 0.3572125250130086, 0.9363086216245102], 
             UndirectedEdge[100, 123] -> 
             RGBColor[
              0.23212285998297438`, 0.3613062216544334, 0.9365304255298079], 
             UndirectedEdge[45, 172] -> 
             RGBColor[
              0.9391683499060914, 0.7786563284917088, 0.4055000051193155], 
             UndirectedEdge[85, 99] -> 
             RGBColor[
              0.4621252914114974, 0.5716835642651686, 0.9514982759565006], 
             UndirectedEdge[106, 112] -> 
             RGBColor[
              0.2882506044320779, 0.42030003977498026`, 0.9397268175426274], 
             UndirectedEdge[49, 87] -> 
             RGBColor[
              0.9113560881636262, 0.6286546059959026, 0.5149270286793647], 
             UndirectedEdge[43, 197] -> 
             RGBColor[
              0.8721411848386535, 0.6704152078814393, 0.5949590715355129], 
             UndirectedEdge[26, 164] -> 
             RGBColor[
              0.34556297092325194`, 0.47243449330876475`, 0.9432874166489127],
              UndirectedEdge[100, 130] -> 
             RGBColor[
              0.2255191848288738, 0.3543653403702861, 0.9361543559990437], 
             UndirectedEdge[46, 196] -> 
             RGBColor[
              0.5464579464995596, 0.642678204475116, 0.9574383177713113], 
             UndirectedEdge[156, 181] -> 
             RGBColor[
              0.9525868256306654, 0.9637539256660137, 0.9508348285678401], 
             UndirectedEdge[62, 96] -> 
             RGBColor[
              0.33121568258703066`, 0.4610684087047351, 0.9423343784732514], 
             UndirectedEdge[54, 58] -> 
             RGBColor[
              0.2684799532608956, 0.3995198318623828, 0.9386009082064859], 
             UndirectedEdge[179, 183] -> 
             RGBColor[
              0.8339221074705745, 0.65332563598217, 0.5931545755652246], 
             UndirectedEdge[65, 198] -> 
             RGBColor[
              0.809127231953634, 0.8516409245369697, 0.9813908857977319], 
             UndirectedEdge[4, 80] -> 
             RGBColor[
              0.7123913946505943, 0.7749007508046878, 0.972203429564615], 
             UndirectedEdge[159, 197] -> 
             RGBColor[
              0.8557807275271554, 0.5446615637871581, 0.5792922791375287], 
             UndirectedEdge[78, 136] -> 
             RGBColor[
              0.9179856014839756, 0.8091909436388446, 0.6189147464565151], 
             UndirectedEdge[153, 188] -> 
             RGBColor[
              0.6253120347428027, 0.7063539747569785, 0.9638795069847599], 
             UndirectedEdge[35, 174] -> 
             RGBColor[
              0.6098919568384804, 0.6893702822195625, 0.9649850564709783], 
             UndirectedEdge[82, 130] -> 
             RGBColor[
              0.27791125977355285`, 0.4085218087190706, 0.9391713605597196], 
             UndirectedEdge[124, 176] -> 
             RGBColor[
              0.29262570831728996`, 0.4248985513559462, 0.9399759732365041], 
             UndirectedEdge[6, 186] -> 
             RGBColor[
              0.3110411018029656, 0.4413598612768941, 0.941130682141722], 
             UndirectedEdge[1, 144] -> 
             RGBColor[
              0.9074142416068287, 0.6532261133367169, 0.24715284778639957`], 
             UndirectedEdge[43, 67] -> 
             RGBColor[
              0.8367855353364704, 0.2837553208862874, 0.18285917622251102`], 
             UndirectedEdge[24, 119] -> 
             RGBColor[
              0.37190268708568275`, 0.48151336908456555`, 0.9461947206260288],
              UndirectedEdge[93, 139] -> 
             RGBColor[
              0.2366529007205347, 0.36606758169078113`, 0.9367884046482173], 
             UndirectedEdge[38, 146] -> 
             RGBColor[
              0.8804514017100027, 0.8667932734581691, 0.6490490676279728], 
             UndirectedEdge[110, 127] -> 
             RGBColor[
              0.46330733319948464`, 0.5715960026043997, 0.9518806741110254], 
             UndirectedEdge[41, 81] -> 
             RGBColor[
              0.563023955866433, 0.6561272371693612, 0.9587424547119633], 
             UndirectedEdge[85, 194] -> 
             RGBColor[
              0.35434213313173446`, 0.48133507879042225`, 0.9437993452840767],
              UndirectedEdge[52, 70] -> 
             RGBColor[
              0.2130689137116028, 0.34127931603325223`, 0.9354453314774407], 
             UndirectedEdge[149, 170] -> 
             RGBColor[
              0.2079666859588458, 0.3359165511651807, 0.9351547671549908], 
             UndirectedEdge[10, 15] -> 
             RGBColor[
              0.30721338060851633`, 0.43871808624608816`, 0.9408621191648285],
              UndirectedEdge[92, 155] -> 
             RGBColor[
              0.23916918979888965`, 0.36871236105407446`, 0.9369317035887135],
              UndirectedEdge[57, 141] -> 
             RGBColor[
              0.35995825064388254`, 0.48619947750517123`, 0.9441571993258131],
              UndirectedEdge[149, 159] -> 
             RGBColor[
              0.5281062347020681, 0.2689429967185235, 0.5529651961863387], 
             UndirectedEdge[142, 167] -> 
             RGBColor[
              0.7780824099898748, 0.8273108495391253, 0.9783266471470176], 
             UndirectedEdge[117, 173] -> 
             RGBColor[
              0.8870698836005233, 0.9096475021441977, 0.8455791000881498], 
             UndirectedEdge[99, 179] -> 
             RGBColor[
              0.6860146185776324, 0.753440204048828, 0.970158876487192], 
             UndirectedEdge[5, 11] -> 
             RGBColor[
              0.2640346736892395, 0.39484756118556874`, 0.938347756111082], 
             UndirectedEdge[29, 188] -> 
             RGBColor[
              0.8291485068413533, 0.8647956293451209, 0.8611126603250323], 
             UndirectedEdge[46, 178] -> 
             RGBColor[
              0.7700871696380653, 0.8204498262888431, 0.9719037985104857], 
             UndirectedEdge[101, 137] -> 
             RGBColor[
              0.25101571036429215`, 0.3811638052810985, 0.9376063454095565], 
             UndirectedEdge[3, 20] -> 
             RGBColor[
              0.24453230342971405`, 0.374349333521115, 0.9372371249759732], 
             UndirectedEdge[186, 199] -> 
             RGBColor[
              0.2771594494145085, 0.4086425326316706, 0.9390951926722704], 
             UndirectedEdge[156, 179] -> 
             RGBColor[
              0.864388741144453, 0.8948015330551333, 0.986901517469225], 
             UndirectedEdge[67, 87] -> 
             RGBColor[
              0.9030901336605541, 0.565118857520931, 0.5070115413121625], 
             UndirectedEdge[3, 10] -> 
             RGBColor[
              0.27648968445364525`, 0.4079385671922522, 0.9390570505485776], 
             UndirectedEdge[55, 185] -> 
             RGBColor[
              0.5609776882411449, 0.6497765761810184, 0.9606709927749343], 
             UndirectedEdge[5, 28] -> 
             RGBColor[
              0.28849193082278163`, 0.4205536891125868, 0.9397405607235676], 
             UndirectedEdge[37, 170] -> 
             RGBColor[
              0.18667955632742156`, 0.31354242824058126`, 0.9339424966139673],
              UndirectedEdge[49, 154] -> 
             RGBColor[
              0.9106325715742103, 0.628355413292651, 0.5269175709668971], 
             UndirectedEdge[24, 89] -> 
             RGBColor[
              0.5164596179840519, 0.3607037715624661, 0.5664186648111262], 
             UndirectedEdge[73, 115] -> 
             RGBColor[
              0.27934432739444803`, 0.41093897791785206`, 0.9392196182409905],
              UndirectedEdge[153, 174] -> 
             RGBColor[
              0.4836903414503127, 0.5897681807806197, 0.9530364909078715], 
             UndirectedEdge[119, 183] -> 
             RGBColor[
              0.7123944253398227, 0.5572003826444346, 0.5818533249803631], 
             UndirectedEdge[4, 168] -> 
             RGBColor[
              0.8717390399773187, 0.9006124860515876, 0.9850092222919777], 
             UndirectedEdge[144, 181] -> 
             RGBColor[
              0.920422900102938, 0.7115997715799838, 0.5555552779943531], 
             UndirectedEdge[53, 123] -> 
             RGBColor[
              0.2309218560021901, 0.36004389032257866`, 0.9364620301298284], 
             UndirectedEdge[110, 162] -> 
             RGBColor[
              0.7939641442587955, 0.8384977959010833, 0.9379384858342741], 
             UndirectedEdge[127, 176] -> 
             RGBColor[
              0.3078922888084153, 0.4397573979887158, 0.940888855185277], 
             UndirectedEdge[9, 102] -> 
             RGBColor[
              0.31720087863442126`, 0.44471069767262583`, 0.9415958382088386],
              UndirectedEdge[27, 195] -> 
             RGBColor[
              0.22783801477683696`, 0.3568025776679057, 0.9362864099341788], 
             UndirectedEdge[60, 130] -> 
             RGBColor[
              0.2455906790412874, 0.3754617533937681, 0.9372973979013259], 
             UndirectedEdge[89, 122] -> 
             RGBColor[
              0.9234652804391932, 0.7016588310893552, 0.3360475342402131], 
             UndirectedEdge[5, 106] -> 
             RGBColor[
              0.2786294913144741, 0.4101876398745743, 0.9391789093837413], 
             UndirectedEdge[83, 199] -> 
             RGBColor[
              0.2640684264301843, 0.3948830374563491, 0.938349678279746], 
             UndirectedEdge[118, 125] -> 
             RGBColor[
              0.5461336776674304, 0.6195695759530597, 0.9625480754195246], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.2678093745072151, 0.3988150110751161, 0.9385627197384963], 
             UndirectedEdge[5, 112] -> 
             RGBColor[
              0.29182817897856506`, 0.4240602974546656, 0.9399305551205026], 
             UndirectedEdge[109, 146] -> 
             RGBColor[
              0.5668187671363596, 0.653709441066444, 0.9615199202813867], 
             UndirectedEdge[164, 184] -> 
             RGBColor[
              0.33292802569279517`, 0.46149073880095526`, 0.9424823291114712],
              UndirectedEdge[51, 164] -> 
             RGBColor[
              0.28843151316149873`, 0.42049018631987756`, 0.9397371200271375],
              UndirectedEdge[45, 168] -> 
             RGBColor[
              0.9114761724933723, 0.7607551980488345, 0.6070253886431892], 
             UndirectedEdge[148, 165] -> 
             RGBColor[
              0.2118480097340456, 0.33999606854305653`, 0.9353758028020844], 
             UndirectedEdge[166, 184] -> 
             RGBColor[
              0.3810287222999791, 0.5044496610209838, 0.9454997911478531], 
             UndirectedEdge[21, 132] -> 
             RGBColor[
              0.28420798371714023`, 0.41536166731241486`, 0.9395218357203131],
              UndirectedEdge[96, 157] -> 
             RGBColor[
              0.43194074873512733`, 0.5454775949392545, 0.9495354789637005], 
             UndirectedEdge[42, 102] -> 
             RGBColor[
              0.4476381958746549, 0.5602937273030086, 0.9502551687958871], 
             UndirectedEdge[117, 120] -> 
             RGBColor[
              0.8678835994276715, 0.8465560061197337, 0.6325812491960736], 
             UndirectedEdge[25, 129] -> 
             RGBColor[
              0.9845905971173718, 0.9596826071563495, 0.39463780893289646`], 
             UndirectedEdge[57, 90] -> 
             RGBColor[
              0.37426337273503046`, 0.49858985526418154`, 0.9450687090559382],
              UndirectedEdge[51, 184] -> 
             RGBColor[
              0.3266364768489205, 0.4548779220588064, 0.942124034712325], 
             UndirectedEdge[95, 103] -> 
             RGBColor[
              0.9219582849086154, 0.7097965364380157, 0.2919118882865176], 
             UndirectedEdge[47, 105] -> 
             RGBColor[
              0.3973660260121461, 0.5186002123597028, 0.9465407896938819], 
             UndirectedEdge[127, 177] -> 
             RGBColor[
              0.3075972075411117, 0.4394472488675467, 0.9408720507436377], 
             UndirectedEdge[73, 153] -> 
             RGBColor[
              0.4395524049734263, 0.5500947505807087, 0.9502769094004289], 
             UndirectedEdge[137, 199] -> 
             RGBColor[
              0.26123779500061556`, 0.39190786435147384`, 0.9381884780073761],
              UndirectedEdge[138, 185] -> 
             RGBColor[
              0.8411744991425061, 0.7559037234450623, 0.613171500043548], 
             UndirectedEdge[88, 136] -> 
             RGBColor[
              0.8101006391447247, 0.7240376246779792, 0.6083933870270145], 
             UndirectedEdge[55, 76] -> 
             RGBColor[
              0.31436618073050393`, 0.4437147149372155, 0.9413617820054831], 
             UndirectedEdge[135, 176] -> 
             RGBColor[
              0.26373796268785954`, 0.3945356991105544, 0.938330858858498], 
             UndirectedEdge[69, 123] -> 
             RGBColor[
              0.3260085199796461, 0.4514023478470298, 0.9421913646386602], 
             UndirectedEdge[2, 40] -> 
             RGBColor[
              0.43435111341602517`, 0.5495958945368197, 0.9491845094203311], 
             UndirectedEdge[105, 174] -> 
             RGBColor[
              0.3623104663482657, 0.48823684852250904`, 0.9443070804305137], 
             UndirectedEdge[89, 138] -> 
             RGBColor[
              0.8833839545319762, 0.5539525957731882, 0.22400589739062848`], 
             UndirectedEdge[37, 128] -> 
             RGBColor[
              0.5402876317341454, 0.454787094862522, 0.5818823157705433], 
             UndirectedEdge[88, 153] -> 
             RGBColor[
              0.6490823398625842, 0.7249235177775619, 0.9662487088529688], 
             UndirectedEdge[113, 197] -> 
             RGBColor[
              0.8946095450697447, 0.7772196138099509, 0.6138944273650201], 
             UndirectedEdge[31, 178] -> 
             RGBColor[
              0.8964701273649321, 0.9201113391332241, 0.9839677082524034], 
             UndirectedEdge[82, 177] -> 
             RGBColor[
              0.3061026011103605, 0.4381526958983335, 0.9407768157434988], 
             UndirectedEdge[87, 108] -> 
             RGBColor[
              0.8846035797290293, 0.9091596462519311, 0.913892802031036], 
             UndirectedEdge[64, 86] -> 
             RGBColor[
              0.5072811113074129, 0.6092066601914048, 0.9548145013504485], 
             UndirectedEdge[116, 157] -> 
             RGBColor[
              0.47363379400133276`, 0.5818257161885222, 0.9521834927723848], 
             UndirectedEdge[120, 168] -> 
             RGBColor[
              0.9476806026150666, 0.909778086957847, 0.6376934323137864], 
             UndirectedEdge[18, 54] -> 
             RGBColor[
              0.295588460550005, 0.42712274502129255`, 0.9401772792428172], 
             UndirectedEdge[161, 176] -> 
             RGBColor[
              0.301427951999442, 0.43415026756037145`, 0.9404772479924501], 
             UndirectedEdge[168, 172] -> 
             RGBColor[
              0.9662845352880476, 0.9716239920088556, 0.7873059163017873], 
             UndirectedEdge[142, 157] -> 
             RGBColor[
              0.5992869263853755, 0.6855671502648439, 0.9615972085868523], 
             UndirectedEdge[121, 171] -> 
             RGBColor[
              0.7085728332018904, 0.7711751170925334, 0.9725147444177542], 
             UndirectedEdge[47, 94] -> 
             RGBColor[
              0.4348245890199799, 0.551044936914969, 0.9489276162054343], 
             UndirectedEdge[70, 93] -> 
             RGBColor[
              0.21891136206643785`, 0.34742009968680476`, 0.9357780502681208],
              UndirectedEdge[32, 163] -> 
             RGBColor[
              0.23408691252963393`, 0.3633705654090964, 0.9366422754167848], 
             UndirectedEdge[35, 142] -> 
             RGBColor[
              0.7396311759520104, 0.7966508792482756, 0.9746591341186641], 
             UndirectedEdge[12, 193] -> 
             RGBColor[
              0.4503245613855142, 0.5609229257874412, 0.950895392546576], 
             UndirectedEdge[35, 94] -> 
             RGBColor[
              0.6282503776636906, 0.7052714236172997, 0.9661548388122466], 
             UndirectedEdge[116, 174] -> 
             RGBColor[
              0.38549669526037655`, 0.5083195946324296, 0.9457844864340161], 
             UndirectedEdge[112, 140] -> 
             RGBColor[
              0.30347647446516857`, 0.4363033945556761, 0.9405939083163557], 
             UndirectedEdge[86, 176] -> 
             RGBColor[
              0.3430782654932676, 0.4702337224945253, 0.9431308745058982], 
             UndirectedEdge[61, 73] -> 
             RGBColor[
              0.28346587285648317`, 0.41527098351952657`, 0.9394543341577734],
              UndirectedEdge[33, 66] -> 
             RGBColor[
              0.5073300220022017, 0.606620425388813, 0.955851339828218], 
             UndirectedEdge[48, 106] -> 
             RGBColor[
              0.29607730783621694`, 0.42775376738301063`, 0.9402008266352594],
              UndirectedEdge[86, 199] -> 
             RGBColor[
              0.3321240507225622, 0.4587201482331828, 0.9425070481800151], 
             UndirectedEdge[10, 59] -> 
             RGBColor[
              0.3690604515059446, 0.4922869105332728, 0.9448029598331952], 
             UndirectedEdge[1, 113] -> 
             RGBColor[
              0.9293073420017215, 0.7556088200837405, 0.2655373341471002], 
             UndirectedEdge[125, 128] -> 
             RGBColor[
              0.5342706715319968, 0.44846288819275276`, 0.5815396587883258], 
             UndirectedEdge[53, 165] -> 
             RGBColor[
              0.21515759774182608`, 0.3434746553792333, 0.935564278943031], 
             UndirectedEdge[87, 143] -> 
             RGBColor[
              0.9043865074094275, 0.5750833542293711, 0.5082529502781284], 
             UndirectedEdge[61, 105] -> 
             RGBColor[
              0.30850366715074595`, 0.4384008305619083, 0.9409968714949317], 
             UndirectedEdge[29, 47] -> 
             RGBColor[
              0.7225823732127437, 0.7785731992059557, 0.8525033535115121], 
             UndirectedEdge[24, 27] -> 
             RGBColor[
              0.22783801619652955`, 0.3568025791600926, 0.9362864100150281], 
             UndirectedEdge[98, 117] -> 
             RGBColor[
              0.8762433687105626, 0.9035134810174441, 0.9541841801385145], 
             UndirectedEdge[1, 88] -> 
             RGBColor[
              0.8352535964645615, 0.823065908134689, 0.6322506322661987], 
             UndirectedEdge[190, 195] -> 
             RGBColor[
              0.1793170310330229, 0.30580394734510286`, 0.9335232116903315], 
             UndirectedEdge[4, 173] -> 
             RGBColor[
              0.9000135688899087, 0.9197592074679171, 0.8468692056721795], 
             UndirectedEdge[81, 164] -> 
             RGBColor[
              0.43552843920258344`, 0.5470178923073767, 0.9499428350575294], 
             UndirectedEdge[82, 123] -> 
             RGBColor[
              0.28451493492765345`, 0.4154626900032179, 0.9395474300904838], 
             UndirectedEdge[43, 87] -> 
             RGBColor[
              0.9216699742916543, 0.7079316543496461, 0.5248036176834326], 
             UndirectedEdge[38, 171] -> 
             RGBColor[
              0.919639217056486, 0.8978474840035989, 0.6528380765050477], 
             UndirectedEdge[46, 85] -> 
             RGBColor[
              0.4789487657995369, 0.5853416186622634, 0.9528226814867443], 
             UndirectedEdge[64, 69] -> 
             RGBColor[
              0.512094113243802, 0.613375440560194, 0.9551211815778647], 
             UndirectedEdge[60, 82] -> 
             RGBColor[
              0.2862778470683244, 0.4173156224381487, 0.9396478253289002], 
             UndirectedEdge[77, 189] -> 
             RGBColor[
              0.2658927211222934, 0.3968004868447199, 0.9384535691636595], 
             UndirectedEdge[101, 187] -> 
             RGBColor[
              0.2673357347336053, 0.3983171856425559, 0.9385357466540765], 
             UndirectedEdge[64, 161] -> 
             RGBColor[
              0.4656307978135873, 0.573123205257251, 0.9521608748370004], 
             UndirectedEdge[7, 160] -> 
             RGBColor[
              0.3585859521924276, 0.48501086156024664`, 0.9440697576819622], 
             UndirectedEdge[16, 83] -> 
             RGBColor[
              0.2894048145974629, 0.4201988877306557, 0.9398406710693048], 
             UndirectedEdge[13, 124] -> 
             RGBColor[
              0.3345268948480242, 0.4625364133999037, 0.9425966268829805], 
             UndirectedEdge[46, 171] -> 
             RGBColor[
              0.7361063058563833, 0.7935280305622586, 0.9746822802435494], 
             UndirectedEdge[1, 197] -> 
             RGBColor[
              0.9236147906417135, 0.8926515043216656, 0.6409097972593247], 
             UndirectedEdge[26, 80] -> 
             RGBColor[
              0.5081499735315052, 0.6100326873138424, 0.9548495666212384], 
             UndirectedEdge[23, 43] -> 
             RGBColor[
              0.9244722625683395, 0.7076214459861772, 0.37157972421419916`], 
             UndirectedEdge[13, 86] -> 
             RGBColor[
              0.38497945202400186`, 0.5078715845384828, 0.9457515281523746], 
             UndirectedEdge[31, 146] -> 
             RGBColor[
              0.8233014482367667, 0.8621353328612098, 0.9829571811083924], 
             UndirectedEdge[142, 188] -> 
             RGBColor[
              0.6527715209369094, 0.7286468226851102, 0.9660412183253722], 
             UndirectedEdge[124, 127] -> 
             RGBColor[
              0.30632106017096694`, 0.43810593706910805`, 0.9407993760387987],
              UndirectedEdge[60, 163] -> 
             RGBColor[
              0.24348971297155947`, 0.37325350484554143`, 0.9371777509917558],
              UndirectedEdge[4, 184] -> 
             RGBColor[
              0.5880093557297629, 0.671690292538539, 0.9630281942774768], 
             UndirectedEdge[144, 192] -> 
             RGBColor[
              0.8369174478199836, 0.2847692580389892, 0.18298549576569717`], 
             UndirectedEdge[38, 192] -> 
             RGBColor[
              0.8910636363690327, 0.5135395909571491, 0.2410026071488931], 
             UndirectedEdge[49, 108] -> 
             RGBColor[
              0.8079850952769174, 0.5485190612635439, 0.5798638479373164], 
             UndirectedEdge[83, 165] -> 
             RGBColor[
              0.2373756354905151, 0.36682722175806165`, 0.9368295633241774], 
             UndirectedEdge[183, 192] -> 
             RGBColor[
              0.8386147396738325, 0.29544751505205596`, 0.18451810443518368`],
              UndirectedEdge[79, 159] -> 
             RGBColor[
              0.5133063068014707, 0.25338733412536907`, 0.5521223621869309], 
             UndirectedEdge[81, 166] -> 
             RGBColor[
              0.4836291358097673, 0.5899768145274054, 0.9529602970939112], 
             UndirectedEdge[118, 119] -> 
             RGBColor[
              0.7390929491372125, 0.7956716911845035, 0.9752408612005126], 
             UndirectedEdge[47, 153] -> 
             RGBColor[
              0.518745901114193, 0.6201315446178133, 0.9552702001712396], 
             UndirectedEdge[74, 184] -> 
             RGBColor[
              0.3369577946710508, 0.46572628149921225`, 0.9427118184932739], 
             UndirectedEdge[149, 190] -> 
             RGBColor[
              0.2066375350628038, 0.33451952930040635`, 0.9350790739777637], 
             UndirectedEdge[55, 139] -> 
             RGBColor[
              0.3007701310464627, 0.42942440467994913`, 0.9405875070895301], 
             UndirectedEdge[22, 138] -> 
             RGBColor[
              0.8785987668628523, 0.5171715464656945, 0.2194235962745789], 
             UndirectedEdge[113, 144] -> 
             RGBColor[
              0.8784089960348599, 0.5377942228250021, 0.22013747789209492`], 
             UndirectedEdge[80, 172] -> 
             RGBColor[
              0.8069368899613232, 0.8459122567619559, 0.7745001235744244], 
             UndirectedEdge[8, 156] -> 
             RGBColor[
              0.6845205611909437, 0.7511737984198581, 0.97104590551255], 
             UndirectedEdge[22, 118] -> 
             RGBColor[
              0.8788646923664576, 0.6380810443549103, 0.5908825042695605], 
             UndirectedEdge[100, 163] -> 
             RGBColor[
              0.22341821875914586`, 0.35215709182205945`, 0.9360347090894736],
              UndirectedEdge[12, 154] -> 
             RGBColor[
              0.7852450872055535, 0.8309115028617888, 0.9166639457901922], 
             UndirectedEdge[67, 129] -> 
             RGBColor[
              0.9042326927843938, 0.5598741577929227, 0.2908641337345006], 
             UndirectedEdge[49, 129] -> 
             RGBColor[
              0.9124986472874659, 0.6234099062678943, 0.2987796211017028], 
             UndirectedEdge[127, 175] -> 
             RGBColor[
              0.32099276834406665`, 0.45244953519915593`, 0.9416743532494919],
              UndirectedEdge[30, 198] -> 
             RGBColor[
              0.7949540018905729, 0.840339575606766, 0.9800390304617252], 
             UndirectedEdge[5, 140] -> 
             RGBColor[
              0.2938553613475648, 0.42619099465527016`, 0.9400460001574695], 
             UndirectedEdge[147, 156] -> 
             RGBColor[
              0.7007698065694198, 0.7645047047938165, 0.9722866893066117], 
             UndirectedEdge[122, 159] -> 
             RGBColor[
              0.907791394547121, 0.5811824757822961, 0.3210382034088427], 
             UndirectedEdge[82, 110] -> 
             RGBColor[
              0.4618127267687334, 0.5703014496351865, 0.9517854391108865], 
             UndirectedEdge[83, 176] -> 
             RGBColor[
              0.2750226412008897, 0.4063966117176916, 0.9389735046056292], 
             UndirectedEdge[10, 77] -> 
             RGBColor[
              0.2948550356150111, 0.4272417156933656, 0.9401029301281152], 
             UndirectedEdge[104, 130] -> 
             RGBColor[
              0.2280794521267412, 0.3570563436306672, 0.9363001594340813], 
             UndirectedEdge[30, 66] -> 
             RGBColor[
              0.7926835884248224, 0.8385659113515402, 0.9798127368656795], 
             UndirectedEdge[85, 132] -> 
             RGBColor[
              0.3061847210307328, 0.43439681259051416`, 0.9409221739886695], 
             UndirectedEdge[24, 195] -> 
             RGBColor[
              0.1789270014196926, 0.30539400149218693`, 0.9335010000808495], 
             UndirectedEdge[50, 123] -> 
             RGBColor[
              0.24633186843467056`, 0.37624079044033565`, 0.9373396075407877],
              UndirectedEdge[42, 153] -> 
             RGBColor[
              0.5537057705483233, 0.648562314548655, 0.9580088930300842], 
             UndirectedEdge[127, 161] -> 
             RGBColor[
              0.31512330385311904`, 0.4473576532735334, 0.9413006507947447], 
             UndirectedEdge[7, 18] -> 
             RGBColor[
              0.33441529127436986`, 0.4640754499257662, 0.9425296245415398], 
             UndirectedEdge[65, 66] -> 
             RGBColor[
              0.8068568184878835, 0.8498672602817441, 0.9811645922016861], 
             UndirectedEdge[150, 152] -> 
             RGBColor[
              0.2823331640327409, 0.4140804347278859, 0.9393898280659538], 
             UndirectedEdge[25, 87] -> 
             RGBColor[
              0.9834480379935321, 0.9649273068843578, 0.6107852165105583], 
             UndirectedEdge[69, 82] -> 
             RGBColor[
              0.3600920128525825, 0.48631533560726303`, 0.9441657225354702], 
             UndirectedEdge[1, 159] -> 
             RGBColor[
              0.8904785244591324, 0.5230507700609477, 0.2309351859196088], 
             UndirectedEdge[23, 131] -> 
             RGBColor[
              0.9464189057965813, 0.8120568568548516, 0.39007974658807487`], 
             UndirectedEdge[126, 160] -> 
             RGBColor[
              0.336968383677942, 0.466146182368601, 0.9426974544072704], 
             UndirectedEdge[67, 131] -> 
             RGBColor[
              0.8587321785647122, 0.38819073175496194`, 0.20135919859638673`],
              UndirectedEdge[142, 174] -> 
             RGBColor[
              0.5111498276444193, 0.6120610287087513, 0.9551982022484837], 
             UndirectedEdge[22, 122] -> 
             RGBColor[
              0.9186800927700692, 0.6648777817818614, 0.33146523312416354`], 
             UndirectedEdge[32, 176] -> 
             RGBColor[
              0.264674301203473, 0.39551985025775493`, 0.9383841819517735], 
             UndirectedEdge[47, 160] -> 
             RGBColor[
              0.4091167531918066, 0.528778101634004, 0.9472895356390099], 
             UndirectedEdge[79, 125] -> 
             RGBColor[
              0.19146399032539158`, 0.3185711717230839, 0.934214963052216], 
             UndirectedEdge[47, 111] -> 
             RGBColor[
              0.45600877007092583`, 0.5691987153613436, 0.9503313034018304], 
             UndirectedEdge[3, 186] -> 
             RGBColor[
              0.27284687806334806`, 0.40410974670878463`, 0.9388495981136993],
              UndirectedEdge[105, 160] -> 
             RGBColor[
              0.35496105134530265`, 0.4818711546392811, 0.9438387822053573], 
             UndirectedEdge[9, 189] -> 
             RGBColor[
              0.24597910372864595`, 0.37587001236772954`, 0.9373195181126482],
              UndirectedEdge[64, 175] -> 
             RGBColor[
              0.4715002623045349, 0.5782150871828736, 0.9525345772917476], 
             UndirectedEdge[100, 165] -> 
             RGBColor[
              0.21635860172261037`, 0.34473698671108804`, 0.9356326743430103],
              UndirectedEdge[101, 161] -> 
             RGBColor[
              0.28025165259241314`, 0.41189263422865363`, 0.9392712890687474],
              UndirectedEdge[123, 187] -> 
             RGBColor[
              0.26662928669062347`, 0.3975746639579891, 0.9384955154831248], 
             UndirectedEdge[90, 198] -> 
             RGBColor[
              0.542054826289809, 0.636504451768819, 0.9581455985091416], 
             UndirectedEdge[146, 171] -> 
             RGBColor[
              0.8352823460284233, 0.8716885755474699, 0.9840999298352342], 
             UndirectedEdge[62, 157] -> 
             RGBColor[
              0.4569597398647052, 0.567383488557704, 0.951121036787086], 
             UndirectedEdge[2, 164] -> 
             RGBColor[
              0.3359219335901057, 0.4640839113434194, 0.9426730982752791], 
             UndirectedEdge[94, 142] -> 
             RGBColor[
              0.5295082484696294, 0.6279621701064884, 0.9563679845897519], 
             UndirectedEdge[12, 175] -> 
             RGBColor[
              0.4521802655001208, 0.5625302434211127, 0.9510136363718239], 
             UndirectedEdge[23, 64] -> 
             RGBColor[
              0.8080908888760686, 0.8465853309633324, 0.7529704509533501], 
             UndirectedEdge[73, 160] -> 
             RGBColor[
              0.3299232570510399, 0.45874130759689935`, 0.9422962448681991], 
             UndirectedEdge[47, 142] -> 
             RGBColor[
              0.5462053873082997, 0.642424392545945, 0.9574319115118519], 
             UndirectedEdge[31, 120] -> 
             RGBColor[
              0.9036386065731989, 0.8747348065350462, 0.6360795030302686], 
             UndirectedEdge[9, 20] -> 
             RGBColor[
              0.24298403719743245`, 0.3727220075452381, 0.9371489535044994], 
             UndirectedEdge[174, 188] -> 
             RGBColor[
              0.5230323018233795, 0.6213662256563972, 0.9563671406776864], 
             UndirectedEdge[45, 173] -> 
             RGBColor[
              0.9397507014059623, 0.7799019194651641, 0.46888537202339087`], 
             UndirectedEdge[139, 191] -> 
             RGBColor[
              0.2646944952587164, 0.3955410754901928, 0.9383853319733451], 
             UndirectedEdge[24, 170] -> 
             RGBColor[
              0.18064618334875748`, 0.3072009707020641, 0.9335989049484079], 
             UndirectedEdge[118, 195] -> 
             RGBColor[
              0.5461172634712222, 0.6195523235921249, 0.9625471406553332], 
             UndirectedEdge[124, 137] -> 
             RGBColor[
              0.27062078113387267`, 0.4017699776932086, 0.938722825186781], 
             UndirectedEdge[28, 63] -> 
             RGBColor[
              0.3238146353715521, 0.45360214621203954`, 0.941901450034025], 
             UndirectedEdge[7, 94] -> 
             RGBColor[
              0.3842937880206009, 0.5072776968412117, 0.9457078382483868], 
             UndirectedEdge[37, 190] -> 
             RGBColor[
              0.18535040543137957`, 0.3121454063758069, 0.9338668034367403], 
             UndirectedEdge[31, 40] -> 
             RGBColor[
              0.6710448937244029, 0.7408816350846033, 0.9693608389875064], 
             UndirectedEdge[18, 73] -> 
             RGBColor[
              0.3057525961329822, 0.4378058959624189, 0.9407561117277767], 
             UndirectedEdge[170, 195] -> 
             RGBColor[
              0.1806461819290649, 0.30720096920987716`, 0.9335989048675586], 
             UndirectedEdge[62, 191] -> 
             RGBColor[
              0.3182327281368137, 0.4474225004107011, 0.9415950184238715], 
             UndirectedEdge[152, 194] -> 
             RGBColor[
              0.3151343711235495, 0.4448783558224487, 0.9413924862035001], 
             UndirectedEdge[24, 37] -> 
             RGBColor[
              0.18496037581804925`, 0.31173546052289103`, 0.9338445918272582],
              UndirectedEdge[90, 177] -> 
             RGBColor[
              0.3407778041727428, 0.4681866139645882, 0.9429862890205556], 
             UndirectedEdge[94, 188] -> 
             RGBColor[
              0.5413907226485897, 0.6372673670541342, 0.9575369230189545], 
             UndirectedEdge[103, 133] -> 
             RGBColor[
              0.8438593008645356, 0.3288700512541642, 0.189270528206407], 
             UndirectedEdge[38, 179] -> 
             RGBColor[
              0.8863710041657746, 0.8714177118872631, 0.6496390782789341], 
             UndirectedEdge[54, 116] -> 
             RGBColor[
              0.33119462320051296`, 0.4579630134913923, 0.9424460724416142], 
             UndirectedEdge[4, 198] -> 
             RGBColor[
              0.7505232703667862, 0.8050337500894356, 0.9757688036175852], 
             UndirectedEdge[31, 38] -> 
             RGBColor[
              0.9076583192648293, 0.8882942413173389, 0.6516953277782057], 
             UndirectedEdge[35, 47] -> 
             RGBColor[
              0.6449475165023608, 0.7197336460567563, 0.9672187657343465], 
             UndirectedEdge[132, 151] -> 
             RGBColor[
              0.3020454023564957, 0.43081154280309575`, 0.9406584202630028], 
             UndirectedEdge[124, 135] -> 
             RGBColor[
              0.26216673405041124`, 0.39288423819094664`, 0.9382413797120197],
              UndirectedEdge[32, 127] -> 
             RGBColor[
              0.2783696530571501, 0.40872723597091687`, 0.9392075847540681], 
             UndirectedEdge[187, 199] -> 
             RGBColor[
              0.27755781936992874`, 0.40906124471293126`, 0.9391178792518959],
              UndirectedEdge[2, 51] -> 
             RGBColor[
              0.329630384746231, 0.45747109460127056`, 0.9423148038761329], 
             UndirectedEdge[40, 117] -> 
             RGBColor[
              0.6352898865788753, 0.7127028346692909, 0.9658625851533114], 
             UndirectedEdge[9, 17] -> 
             RGBColor[
              0.2497025677004787, 0.37978360908337694`, 0.9375315638774728], 
             UndirectedEdge[33, 57] -> 
             RGBColor[
              0.3418089819131736, 0.4704794931394012, 0.9430007439710605], 
             UndirectedEdge[124, 175] -> 
             RGBColor[
              0.3057261878529413, 0.4375906885663863, 0.9407614713007191], 
             UndirectedEdge[8, 147] -> 
             RGBColor[
              0.4644466210649416, 0.5759586789636362, 0.9510205021407936], 
             UndirectedEdge[108, 110] -> 
             RGBColor[
              0.6931298062895987, 0.7596256615132471, 0.9704393557617335], 
             UndirectedEdge[68, 107] -> 
             RGBColor[
              0.7614279257189907, 0.8138406211600655, 0.9767792324528825], 
             UndirectedEdge[1, 138] -> 
             RGBColor[
              0.9355441317544622, 0.7814661810006367, 0.2706140846810541], 
             UndirectedEdge[94, 160] -> 
             RGBColor[
              0.39241961435313644`, 0.5143158791945474, 0.9462256087169099], 
             UndirectedEdge[138, 142] -> 
             RGBColor[
              0.7768323613465915, 0.7056166385716411, 0.6067738726084364], 
             UndirectedEdge[6, 175] -> 
             RGBColor[
              0.3302248541081414, 0.460445903869875, 0.9422626135907659], 
             UndirectedEdge[34, 104] -> 
             RGBColor[
              0.2353413665909268, 0.3646890761644966, 0.936713714719777], 
             UndirectedEdge[15, 106] -> 
             RGBColor[
              0.3000813368943679, 0.43122185610482894`, 0.9404559598262209], 
             UndirectedEdge[61, 94] -> 
             RGBColor[
              0.34596223015857974`, 0.47084555511717463`, 0.9433836980064841],
              UndirectedEdge[144, 159] -> 
             RGBColor[
              0.8395801784922707, 0.30523617280220927`, 0.18553532966460354`],
              UndirectedEdge[83, 86] -> 
             RGBColor[
              0.32390396973941904`, 0.450080321936663, 0.9420389267285452], 
             UndirectedEdge[137, 176] -> 
             RGBColor[
              0.27219200977132096`, 0.4034214386128163, 0.9388123043332592], 
             UndirectedEdge[143, 159] -> 
             RGBColor[
              0.8217214517738456, 0.16796617350044618`, 0.16843379279049273`],
              UndirectedEdge[24, 144] -> 
             RGBColor[
              0.5177214492396762, 0.3704027595311762, 0.5676269958465465], 
             UndirectedEdge[76, 96] -> 
             RGBColor[
              0.2912734993929746, 0.42347729404149315`, 0.9398989669386781], 
             UndirectedEdge[98, 120] -> 
             RGBColor[
              0.9651286166376958, 0.922790787247423, 0.6081584957443529], 
             UndirectedEdge[98, 183] -> 
             RGBColor[
              0.916699432634126, 0.7182581461246227, 0.5672898177785806], 
             UndirectedEdge[55, 75] -> 
             RGBColor[
              0.3182717437982659, 0.44781970934843396`, 0.9415841980444295], 
             UndirectedEdge[35, 68] -> 
             RGBColor[
              0.8469990595612139, 0.880838075189855, 0.985268720497577], 
             UndirectedEdge[25, 43] -> 
             RGBColor[
              0.9171434396694482, 0.683563770249714, 0.28663285142090683`], 
             UndirectedEdge[47, 174] -> 
             RGBColor[
              0.4164661681947697, 0.535143795517232, 0.9477578338641661], 
             UndirectedEdge[29, 88] -> 
             RGBColor[
              0.8529188119611348, 0.8833651723657042, 0.8634818621932413], 
             UndirectedEdge[17, 140] -> 
             RGBColor[
              0.27217097999434126`, 0.4033993349838457, 0.9388111067185709], 
             UndirectedEdge[41, 90] -> 
             RGBColor[
              0.46883146462921355`, 0.577882603340978, 0.9518176941382794], 
             UndirectedEdge[151, 196] -> 
             RGBColor[
              0.4235249432869995, 0.5401212783183434, 0.9485216237575993], 
             UndirectedEdge[88, 94] -> 
             RGBColor[
              0.5651610277683712, 0.6558369100747177, 0.9599061248871635], 
             UndirectedEdge[57, 198] -> 
             RGBColor[
              0.528369365099485, 0.6246507931370399, 0.9572735730236723], 
             UndirectedEdge[71, 164] -> 
             RGBColor[
              0.2925031947568016, 0.42476978183606456`, 0.9399689962704769], 
             UndirectedEdge[95, 154] -> 
             RGBColor[
              0.9830766756699849, 0.9658160132096346, 0.6241438116222372], 
             UndirectedEdge[69, 90] -> 
             RGBColor[
              0.3947672159149649, 0.5163492536735178, 0.946375195812527], 
             UndirectedEdge[175, 176] -> 
             RGBColor[
              0.30729741649038966`, 0.43924214948599405`, 0.9408509504471974],
              UndirectedEdge[58, 115] -> 
             RGBColor[
              0.2648536806612042, 0.3957083894411449, 0.9383943973465231], 
             UndirectedEdge[42, 88] -> 
             RGBColor[
              0.6168180360411716, 0.6987299024450158, 0.9637087446681081], 
             UndirectedEdge[72, 134] -> 
             RGBColor[
              0.2403643210352666, 0.36996851975920364`, 0.9369997645445869], 
             UndirectedEdge[25, 49] -> 
             RGBColor[
              0.9068295535414201, 0.6042867218959704, 0.2767562624168388], 
             UndirectedEdge[23, 103] -> 
             RGBColor[
              0.928934953541638, 0.7326663131459502, 0.37549070825566344`], 
             UndirectedEdge[79, 192] -> 
             RGBColor[
              0.5106435761291835, 0.23292041936214905`, 0.5495725282880245], 
             UndirectedEdge[89, 170] -> 
             RGBColor[
              0.5181787984934242, 0.3625107392801563, 0.5665165695978354], 
             UndirectedEdge[41, 57] -> 
             RGBColor[
              0.4551460034388895, 0.5660289447091988, 0.9509456686528102], 
             UndirectedEdge[10, 14] -> 
             RGBColor[
              0.35304438919669967`, 0.4784146023517027, 0.943782430505298], 
             UndirectedEdge[6, 59] -> 
             RGBColor[
              0.39442835550292343`, 0.516055749816227, 0.9463536039267142], 
             UndirectedEdge[120, 183] -> 
             RGBColor[
              0.9083396633512348, 0.6613006712269123, 0.24568688683613962`], 
             UndirectedEdge[8, 194] -> 
             RGBColor[
              0.3983632803443602, 0.5194639839388066, 0.9466043338580932], 
             UndirectedEdge[63, 106] -> 
             RGBColor[
              0.3139521958632445, 0.44323609697402705`, 0.9413397986941987], 
             UndirectedEdge[129, 131] -> 
             RGBColor[
              0.9447591766437358, 0.8071223654903125, 0.32715623247964654`], 
             UndirectedEdge[22, 38] -> 
             RGBColor[
              0.904615065264268, 0.6177018117199344, 0.25397947076312033`], 
             UndirectedEdge[38, 117] -> 
             RGBColor[
              0.8719033121193018, 0.8601154409020264, 0.6481970739440106], 
             UndirectedEdge[136, 159] -> 
             RGBColor[
              0.8653255671392956, 0.4240224866042378, 0.2070779406804246], 
             UndirectedEdge[158, 166] -> 
             RGBColor[
              0.3220947514992546, 0.4482744245110126, 0.9419323901733808], 
             UndirectedEdge[75, 96] -> 
             RGBColor[
              0.29517906246073655`, 0.4275822884527116, 0.9401213829776245], 
             UndirectedEdge[118, 170] -> 
             RGBColor[
              0.5478364454002871, 0.6213592928020021, 0.9626450455228917], 
             UndirectedEdge[7, 58] -> 
             RGBColor[
              0.3073067839852605, 0.4364725367668565, 0.9409532535052085], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.7375823865275546, 0.7949242332798678, 0.9744789772559258], 
             UndirectedEdge[65, 180] -> 
             RGBColor[
              0.8230809086810591, 0.8625416428483053, 0.9827816578893989], 
             UndirectedEdge[151, 171] -> 
             RGBColor[
              0.6131733026438233, 0.690971104405486, 0.9657655862298374], 
             UndirectedEdge[37, 118] -> 
             RGBColor[
              0.5521506378695789, 0.625893782622829, 0.962890732401742], 
             UndirectedEdge[7, 47] -> 
             RGBColor[
              0.40099092685927107`, 0.5217399192806683, 0.9467717651704868], 
             UndirectedEdge[46, 99] -> 
             RGBColor[
              0.5809189759498203, 0.6706552206345228, 0.960151216244546], 
             UndirectedEdge[195, 197] -> 
             RGBColor[
              0.5339219968548683, 0.6098281490239381, 0.9613839452386224], 
             UndirectedEdge[5, 63] -> 
             RGBColor[
              0.3175297704097317, 0.4469963546537124, 0.9415435362720739], 
             UndirectedEdge[11, 63] -> 
             RGBColor[
              0.29935737823800995`, 0.4278960182850215, 0.9405086454215394], 
             UndirectedEdge[10, 193] -> 
             RGBColor[
              0.30300124599655587`, 0.4350697469532493, 0.9405937256719987], 
             UndirectedEdge[99, 147] -> 
             RGBColor[
              0.5223956840025993, 0.6231433757875112, 0.9555440483245787], 
             UndirectedEdge[9, 77] -> 
             RGBColor[
              0.2804804496400908, 0.41213311443233347`, 0.9392843187221377], 
             UndirectedEdge[43, 103] -> 
             RGBColor[
              0.859828066940869, 0.45161298487477564`, 0.20456223663524548`], 
             UndirectedEdge[54, 174] -> 
             RGBColor[
              0.3271085364710258, 0.454423850539001, 0.942185710608396], 
             UndirectedEdge[149, 197] -> 
             RGBColor[
              0.5612425008846491, 0.6385437309792414, 0.9629398075260546], 
             UndirectedEdge[87, 180] -> 
             RGBColor[
              0.8560213723624259, 0.8868310086243191, 0.9110439947166469], 
             UndirectedEdge[134, 191] -> 
             RGBColor[
              0.25554145744836393`, 0.3859206524153965, 0.9378640800107516], 
             UndirectedEdge[65, 131] -> 
             RGBColor[
              0.9106761538385292, 0.7880776994423069, 0.6150413032300603], 
             UndirectedEdge[107, 147] -> 
             RGBColor[
              0.5739634519525214, 0.664627405018551, 0.9598641490933124], 
             UndirectedEdge[50, 82] -> 
             RGBColor[
              0.28041536130760697`, 0.41115377820056886`, 0.9393139654375977],
              UndirectedEdge[30, 162] -> 
             RGBColor[
              0.9383242239537981, 0.9524410659335498, 0.9517777399403218], 
             UndirectedEdge[51, 74] -> 
             RGBColor[
              0.29246128213975436`, 0.4247257290181345, 0.9399666094089402], 
             UndirectedEdge[12, 161] -> 
             RGBColor[
              0.4463108010091732, 0.5574383614954901, 0.9506399339170767], 
             UndirectedEdge[78, 113] -> 
             RGBColor[
              0.9141333132318434, 0.7927873365838396, 0.6157566218013946], 
             UndirectedEdge[131, 133] -> 
             RGBColor[
              0.8613432531194789, 0.40826059496306566`, 0.20385956653881843`],
              UndirectedEdge[35, 188] -> 
             RGBColor[
              0.7515136501309705, 0.8059560761959215, 0.9758280725478667], 
             UndirectedEdge[181, 185] -> 
             RGBColor[
              0.8769516134578437, 0.9038519112831478, 0.9435125496118522], 
             UndirectedEdge[111, 188] -> 
             RGBColor[
              0.5625749036995356, 0.6554211455005088, 0.9589406102153506], 
             UndirectedEdge[41, 184] -> 
             RGBColor[
              0.46042354235664473`, 0.5706000836629397, 0.9512819487659052], 
             UndirectedEdge[135, 187] -> 
             RGBColor[
              0.2580530598737554, 0.38856050580927426`, 0.9380071120532948], 
             UndirectedEdge[51, 71] -> 
             RGBColor[
              0.2862116459129269, 0.41815696509391576`, 0.9396107018713307], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.2532145568819805, 0.3834749323861105, 0.937731566465837], 
             UndirectedEdge[26, 158] -> 
             RGBColor[
              0.3248339638099492, 0.45064699253772245`, 0.9421069303596279], 
             UndirectedEdge[101, 199] -> 
             RGBColor[
              0.262066422777004, 0.3927788046824936, 0.9382356671333965], 
             UndirectedEdge[84, 194] -> 
             RGBColor[
              0.30565287667395435`, 0.4349127039944547, 0.9408525291212098], 
             UndirectedEdge[6, 176] -> 
             RGBColor[
              0.31712437457249, 0.4477537666594349, 0.9414771155265509], 
             UndirectedEdge[18, 116] -> 
             RGBColor[
              0.35397661933935576`, 0.48101848911472117`, 0.9437760550684375],
              UndirectedEdge[98, 179] -> 
             RGBColor[
              0.8907110607570355, 0.9148157520026807, 0.9556261844734377], 
             UndirectedEdge[116, 142] -> 
             RGBColor[
              0.5152359143739065, 0.6156001916611427, 0.9554585640817019], 
             UndirectedEdge[77, 112] -> 
             RGBColor[
              0.3009216795649535, 0.4336181431321977, 0.9404484165262689], 
             UndirectedEdge[56, 190] -> 
             RGBColor[
              0.1793170310330229, 0.30580394734510286`, 0.9335232116903315], 
             UndirectedEdge[76, 126] -> 
             RGBColor[
              0.2917876480797086, 0.4240176969101601, 0.9399282469457728], 
             UndirectedEdge[168, 173] -> 
             RGBColor[
              0.9668668867879184, 0.9728695829823109, 0.8506912832058626], 
             UndirectedEdge[158, 164] -> 
             RGBColor[
              0.27399405489207074`, 0.4053155022909841, 0.9389149281369991], 
             UndirectedEdge[46, 146] -> 
             RGBColor[
              0.6969184905099, 0.7624738200168288, 0.9708932713664746], 
             UndirectedEdge[23, 25] -> 
             RGBColor[
              0.9862503262702172, 0.9646170985208886, 0.4575613230413248], 
             UndirectedEdge[9, 28] -> 
             RGBColor[
              0.27767181401552266`, 0.4091810603131285, 0.9391243710783226], 
             UndirectedEdge[98, 171] -> 
             RGBColor[
              0.9239792736477469, 0.9412455241190165, 0.9588251826995514], 
             UndirectedEdge[103, 129] -> 
             RGBColor[
              0.9272752243887925, 0.727731821781411, 0.3125671941472351], 
             UndirectedEdge[5, 48] -> 
             RGBColor[
              0.2996548823827041, 0.431514025062696, 0.9404045642131346], 
             UndirectedEdge[36, 169] -> 
             RGBColor[
              0.260181316759984, 0.39079743873598083`, 0.9381283131344916], 
             UndirectedEdge[159, 170] -> 
             RGBColor[
              0.5025049126013521, 0.2420343839730972, 0.5515072387664649], 
             UndirectedEdge[86, 175] -> 
             RGBColor[
              0.356178745028919, 0.4829258597049654, 0.9439163725701132], 
             UndirectedEdge[9, 97] -> 
             RGBColor[
              0.2707641427587703, 0.4019206598506281, 0.9387309894192344], 
             UndirectedEdge[7, 88] -> 
             RGBColor[
              0.5313273656076622, 0.6265318924404168, 0.9577502738522159], 
             UndirectedEdge[5, 77] -> 
             RGBColor[
              0.2913005664473497, 0.42350574323179174`, 0.9399005083673827], 
             UndirectedEdge[103, 131] -> 
             RGBColor[
              0.8817747101691108, 0.5560483957434501, 0.2230622590091212], 
             UndirectedEdge[15, 193] -> 
             RGBColor[
              0.32089862240878825`, 0.45236799072193, 0.941668354353746], 
             UndirectedEdge[167, 181] -> 
             RGBColor[
              0.9498028388938546, 0.9615340502113876, 0.9505692894275887], 
             UndirectedEdge[99, 146] -> 
             RGBColor[
              0.6800950161218604, 0.7488157656197341, 0.9695688658362309], 
             UndirectedEdge[163, 177] -> 
             RGBColor[
              0.2633144670135955, 0.39409057830572625`, 0.9383067414063544], 
             UndirectedEdge[76, 116] -> 
             RGBColor[
              0.3329665446591801, 0.4598254152907607, 0.9425469807473624], 
             UndirectedEdge[15, 59] -> 
             RGBColor[
              0.38695782791817696`, 0.5095851543019536, 0.9458775885149424], 
             UndirectedEdge[36, 151] -> 
             RGBColor[
              0.2998281417164218, 0.4284810612879339, 0.9405321505496939], 
             UndirectedEdge[38, 98] -> 
             RGBColor[
              0.9691483293293262, 0.9363502220297157, 0.6237743204922899], 
             UndirectedEdge[70, 139] -> 
             RGBColor[
              0.23141666930631707`, 0.36056397047819155`, 0.9364902090154877],
              UndirectedEdge[56, 195] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[66, 168] -> 
             RGBColor[
              0.8151061747990456, 0.8563704613486036, 0.9793645875552226], 
             UndirectedEdge[6, 161] -> 
             RGBColor[
              0.32435538961719373`, 0.45535402194425245`, 0.9418889111360187],
              UndirectedEdge[56, 118] -> 
             RGBColor[
              0.5461172634712221, 0.619552323592125, 0.9625471406553332], 
             UndirectedEdge[46, 117] -> 
             RGBColor[
              0.6883704009191991, 0.7557959874606861, 0.9700412776825125], 
             UndirectedEdge[79, 89] -> 
             RGBColor[
              0.5289801926935428, 0.3738636894324282, 0.5671316930183012], 
             UndirectedEdge[102, 140] -> 
             RGBColor[
              0.3396692909282838, 0.4683264235730946, 0.9428753810499368], 
             UndirectedEdge[32, 130] -> 
             RGBColor[
              0.23618787859936186`, 0.36557881395732306`, 0.936761922326355], 
             UndirectedEdge[105, 126] -> 
             RGBColor[
              0.3252176564982815, 0.45596829309429976`, 0.9419487084621424], 
             UndirectedEdge[86, 124] -> 
             RGBColor[
              0.3415070368558193, 0.46858226157491756`, 0.94304139535942], 
             UndirectedEdge[41, 168] -> 
             RGBColor[
              0.7441532266042006, 0.7995222771759883, 0.9732629767804062], 
             UndirectedEdge[43, 143] -> 
             RGBColor[
              0.8380819090853437, 0.29371981759472743`, 0.18410058518847694`],
              UndirectedEdge[56, 197] -> 
             RGBColor[
              0.5339219968548683, 0.6098281490239381, 0.9613839452386224], 
             UndirectedEdge[47, 73] -> 
             RGBColor[
              0.3723282317178833, 0.495470365317321, 0.9449982523567235], 
             UndirectedEdge[23, 108] -> 
             RGBColor[
              0.8874058680057144, 0.9088494378884622, 0.7606689085618024], 
             UndirectedEdge[97, 155] -> 
             RGBColor[
              0.2652922598561954, 0.3961693639826077, 0.9384193737828581], 
             UndirectedEdge[86, 161] -> 
             RGBColor[
              0.35030928053797133`, 0.47783397777934283`, 0.943542670115366], 
             UndirectedEdge[88, 188] -> 
             RGBColor[
              0.688424300235651, 0.7565215626533395, 0.9695793586227837], 
             UndirectedEdge[136, 197] -> 
             RGBColor[
              0.8984618333218767, 0.7936232208649558, 0.6170525520201404], 
             UndirectedEdge[65, 69] -> 
             RGBColor[
              0.6618396215787897, 0.7314857264416685, 0.9696204831011173], 
             UndirectedEdge[23, 67] -> 
             RGBColor[
              0.9058924219372393, 0.564808649157462, 0.35378764784292904`], 
             UndirectedEdge[31, 121] -> 
             RGBColor[
              0.6965919354102337, 0.7616218744062735, 0.9713719956909121], 
             UndirectedEdge[52, 145] -> 
             RGBColor[
              0.21010927874609994`, 0.3381685520328137, 0.9352767846445429], 
             UndirectedEdge[12, 87] -> 
             RGBColor[
              0.7859686037949694, 0.8312106955650405, 0.9046734035026598], 
             UndirectedEdge[128, 192] -> 
             RGBColor[
              0.8534502573357887, 0.36281213583181793`, 0.19689722402413434`],
              UndirectedEdge[78, 95] -> 
             RGBColor[
              0.9537951709684989, 0.944166482218568, 0.6841709176231596], 
             UndirectedEdge[123, 165] -> 
             RGBColor[
              0.23466718379435303`, 0.36398046729963934`, 0.9366753210068761],
              UndirectedEdge[24, 56] -> 
             RGBColor[
              0.1789270014196926, 0.30539400149218693`, 0.9335010000808495], 
             UndirectedEdge[50, 177] -> 
             RGBColor[
              0.2679195346173776, 0.39893079633545114`, 0.9385689931938027], 
             UndirectedEdge[18, 58] -> 
             RGBColor[
              0.2912619493997384, 0.4225753074857117, 0.9399308908333093], 
             UndirectedEdge[96, 182] -> 
             RGBColor[
              0.2856601600419676, 0.4175773184773137, 0.9395792955668297], 
             UndirectedEdge[49, 131] -> 
             RGBColor[
              0.8669981330677842, 0.45172648022993345`, 0.2092746859635889], 
             UndirectedEdge[28, 106] -> 
             RGBColor[
              0.28491435627629447`, 0.41679343143290143`, 0.9395368231456924],
              UndirectedEdge[57, 81] -> 
             RGBColor[
              0.4684558639722499, 0.5768344890925647, 0.951993469629622], 
             UndirectedEdge[7, 115] -> 
             RGBColor[
              0.3080070225358357, 0.4372085318811994, 0.9409931310547537], 
             UndirectedEdge[54, 94] -> 
             RGBColor[
              0.3454669572962359, 0.47032499193673805`, 0.9433554929496641], 
             UndirectedEdge[138, 181] -> 
             RGBColor[
              0.9485527902505714, 0.8398398392439036, 0.5790165148890076], 
             UndirectedEdge[55, 182] -> 
             RGBColor[
              0.30875284137949693`, 0.43781473937303605`, 0.9410421106336347],
              UndirectedEdge[17, 77] -> 
             RGBColor[
              0.26961618509412616`, 0.4007140835603673, 0.9386656149284841], 
             UndirectedEdge[144, 149] -> 
             RGBColor[
              0.5450419518497644, 0.3991183399942927, 0.5691828580531295], 
             UndirectedEdge[68, 179] -> 
             RGBColor[
              0.8317792747849202, 0.8687996297404257, 0.9837911974570385], 
             UndirectedEdge[103, 143] -> 
             RGBColor[
              0.8425446000586423, 0.3187646847545005, 0.18801156922994122`], 
             UndirectedEdge[80, 173] -> 
             RGBColor[
              0.807519241461194, 0.8471578477354111, 0.8378854904784999], 
             UndirectedEdge[161, 199] -> 
             RGBColor[
              0.2904737372287366, 0.422636693299029, 0.9398534216665669], 
             UndirectedEdge[43, 133] -> 
             RGBColor[
              0.8393966098912371, 0.3038251840943911, 0.18535954416494269`], 
             UndirectedEdge[6, 193] -> 
             RGBColor[
              0.3283691499935347, 0.4588385862362035, 0.9421443697655179], 
             UndirectedEdge[181, 188] -> 
             RGBColor[
              0.8244919498408892, 0.8628700233573725, 0.9382838606059434], 
             UndirectedEdge[120, 173] -> 
             RGBColor[
              0.9759551315276564, 0.9289248083741766, 0.49955341569398815`], 
             UndirectedEdge[2, 158] -> 
             RGBColor[
              0.31519292647680297`, 0.4422964105723771, 0.9414926119859944], 
             UndirectedEdge[95, 143] -> 
             RGBColor[
              0.9002121270530901, 0.5519033691579674, 0.2714502368397491], 
             UndirectedEdge[4, 172] -> 
             RGBColor[
              0.8994312173900378, 0.9185136164944618, 0.783483838768104], 
             UndirectedEdge[89, 113] -> 
             RGBColor[
              0.8771471647792357, 0.528095234856292, 0.21892914685667453`], 
             UndirectedEdge[34, 90] -> 
             RGBColor[
              0.31984837730012083`, 0.4461884593191548, 0.9417943891224722], 
             UndirectedEdge[28, 48] -> 
             RGBColor[
              0.30593974734452445`, 0.4381198166210231, 0.9407624779750857], 
             UndirectedEdge[5, 189] -> 
             RGBColor[
              0.2567992205359049, 0.38724264116718776`, 0.9379357077578933], 
             UndirectedEdge[8, 55] -> 
             RGBColor[
              0.4002897149094885, 0.5211325647337041, 0.9467270845651039], 
             UndirectedEdge[29, 138] -> 
             RGBColor[
              0.9532093472510355, 0.8417654452316519, 0.5018453146080967], 
             UndirectedEdge[8, 68] -> 
             RGBColor[
              0.6519110948314109, 0.7251718951051506, 0.9679355855003635], 
             UndirectedEdge[176, 187] -> 
             RGBColor[
              0.2885120341406341, 0.42057481897427373`, 0.9397417055777791], 
             UndirectedEdge[65, 133] -> 
             RGBColor[
              0.872760744533954, 0.5608993549530209, 0.5812495724273461], 
             UndirectedEdge[68, 147] -> 
             RGBColor[
              0.668160340209887, 0.7385028014791089, 0.9691763692944251], 
             UndirectedEdge[89, 192] -> 
             RGBColor[
              0.8356556165643594, 0.2750702700702792, 0.18177716473027677`], 
             UndirectedEdge[2, 74] -> 
             RGBColor[
              0.3399517025683613, 0.46831945404167635`, 0.9429025876570818], 
             UndirectedEdge[156, 185] -> 
             RGBColor[
              0.8452085345226001, 0.8798178098671724, 0.9849898137223804], 
             UndirectedEdge[126, 182] -> 
             RGBColor[
              0.2861743087287016, 0.41811772134598074`, 0.9396085755739244], 
             UndirectedEdge[18, 188] -> 
             RGBColor[
              0.49151222590235866`, 0.5940651201386887, 0.9543587093121076], 
             UndirectedEdge[68, 156] -> 
             RGBColor[
              0.8882342803358891, 0.9137179209353309, 0.9892017726661817], 
             UndirectedEdge[29, 181] -> 
             RGBColor[
              0.988986461566373, 0.9897136330697374, 0.8321863641764009], 
             UndirectedEdge[1, 29] -> 
             RGBColor[
              0.9759778030702638, 0.9313399748264705, 0.5237839339684474], 
             UndirectedEdge[30, 180] -> 
             RGBColor[
              0.8089076786179981, 0.8512402939181014, 0.9814298025533923], 
             UndirectedEdge[31, 196] -> 
             RGBColor[
              0.6728409042264264, 0.742339717319497, 0.969502227513229], 
             UndirectedEdge[193, 199] -> 
             RGBColor[
              0.2944874976050776, 0.4261212575909801, 0.9401088802960662], 
             UndirectedEdge[30, 110] -> 
             RGBColor[
              0.7493871054318795, 0.8041704915393881, 0.9758883443405271], 
             UndirectedEdge[12, 59] -> 
             RGBColor[
              0.516383766894903, 0.6181400893674647, 0.9551046267077723], 
             UndirectedEdge[38, 156] -> 
             RGBColor[
              0.9428260097167436, 0.9163360030821683, 0.6550496534880772], 
             UndirectedEdge[72, 152] -> 
             RGBColor[
              0.2658080334878341, 0.396711474771397, 0.9384487463281612], 
             UndirectedEdge[37, 79] -> 
             RGBColor[
              0.19748095052754017`, 0.3248953783928531, 0.9345576200344334], 
             UndirectedEdge[170, 197] -> 
             RGBColor[
              0.5356411787839332, 0.6116351182338152, 0.9614818501061808], 
             UndirectedEdge[86, 127] -> 
             RGBColor[
              0.3567736173469446, 0.48344110820768715`, 0.9439542773081928], 
             UndirectedEdge[69, 127] -> 
             RGBColor[
              0.3615866192833338, 0.48760988857647636`, 0.944260957535609], 
             UndirectedEdge[58, 61] -> 
             RGBColor[
              0.26897522612323943`, 0.4000403950428194, 0.9386291132633059], 
             UndirectedEdge[11, 17] -> 
             RGBColor[
              0.24235029233601593`, 0.3720559015141443, 0.9371128626721834], 
             UndirectedEdge[11, 15] -> 
             RGBColor[
              0.28548651926913327`, 0.4158817774158234, 0.9396248065535615], 
             UndirectedEdge[111, 157] -> 
             RGBColor[
              0.5090903091480017, 0.6123414730802424, 0.9544966004768307], 
             UndirectedEdge[75, 191] -> 
             RGBColor[
              0.2821961080105196, 0.4139363801586776, 0.9393820229282445], 
             UndirectedEdge[98, 156] -> 
             RGBColor[
              0.9471660663080045, 0.9597340431975859, 0.961036759682581], 
             UndirectedEdge[28, 140] -> 
             RGBColor[
              0.3001402263093852, 0.4327967862135973, 0.9404039139194207], 
             UndirectedEdge[105, 157] -> 
             RGBColor[
              0.4504475650892219, 0.5617429700786016, 0.9507060867688824], 
             UndirectedEdge[3, 15] -> 
             RGBColor[
              0.2943870608658776, 0.4252368109609329, 0.9401316792303248], 
             UndirectedEdge[55, 96] -> 
             RGBColor[
              0.32928937279498216`, 0.459399935982008, 0.942211635716671], 
             UndirectedEdge[6, 64] -> 
             RGBColor[
              0.4813272203866353, 0.5867267043563145, 0.9531607423711013], 
             UndirectedEdge[70, 134] -> 
             RGBColor[
              0.2222636314959646, 0.3509435474033953, 0.9359689570528942], 
             UndirectedEdge[106, 140] -> 
             RGBColor[
              0.29027778680107763`, 0.4224307369755848, 0.9398422625795944], 
             UndirectedEdge[64, 154] -> 
             RGBColor[
              0.8045650840099676, 0.8465963466235498, 0.9181848867101159], 
             UndirectedEdge[8, 157] -> 
             RGBColor[
              0.5029410908496337, 0.6072102236909507, 0.9540509278121335], 
             UndirectedEdge[83, 124] -> 
             RGBColor[
              0.2734514125634414, 0.4047451507980839, 0.9388840254591511], 
             UndirectedEdge[22, 128] -> 
             RGBColor[
              0.8670016862310241, 0.46697435659460335`, 0.20987408763836157`],
              UndirectedEdge[83, 135] -> 
             RGBColor[
              0.244563666934011, 0.3743822985526921, 0.9372389110811449], 
             UndirectedEdge[62, 68] -> 
             RGBColor[
              0.6059297438464823, 0.6853451599719039, 0.965005694475316], 
             UndirectedEdge[105, 116] -> 
             RGBColor[
              0.36639655307775293`, 0.49177601147490035`, 0.944567442263732], 
             UndirectedEdge[93, 145] -> 
             RGBColor[
              0.21595172710093502`, 0.34430933568636624`, 0.935609503435223], 
             UndirectedEdge[128, 195] -> 
             RGBColor[
              0.5342542573357888, 0.44844563583181796`, 0.5815387240241343], 
             UndirectedEdge[87, 154] -> 
             RGBColor[
              0.9872510560263222, 0.9889959982810382, 0.8609465250606165], 
             UndirectedEdge[138, 167] -> 
             RGBColor[
              0.914025724578517, 0.8135858623733021, 0.6202282398592844], 
             UndirectedEdge[179, 194] -> 
             RGBColor[
              0.5782314602978695, 0.6630917185740817, 0.9624599458147682], 
             UndirectedEdge[118, 144] -> 
             RGBColor[
              0.8849117112912057, 0.6845610816311141, 0.5966731364210304], 
             UndirectedEdge[47, 188] -> 
             RGBColor[
              0.5580878614872598, 0.6517295894935908, 0.9586008499410545], 
             UndirectedEdge[11, 20] -> 
             RGBColor[
              0.2356317618329697, 0.3649942999760054, 0.93673025229921], 
             UndirectedEdge[124, 187] -> 
             RGBColor[
              0.2869408055031858, 0.4189233580546661, 0.939652226431301], 
             UndirectedEdge[28, 189] -> 
             RGBColor[
              0.26308408549772533`, 0.39384843272551495`, 0.9382936215198444],
              UndirectedEdge[84, 93] -> 
             RGBColor[
              0.24346208091315458`, 0.3732244618001842, 0.9371761773869076], 
             UndirectedEdge[18, 94] -> 
             RGBColor[
              0.36824895343507874`, 0.4933804675600669, 0.9446854755764875], 
             UndirectedEdge[146, 156] -> 
             RGBColor[
              0.8584691386886809, 0.8901770946260392, 0.9863115068182637], 
             UndirectedEdge[2, 26] -> 
             RGBColor[
              0.3867618425079842, 0.5094154015901577, 0.945865100497908], 
             UndirectedEdge[124, 161] -> 
             RGBColor[
              0.29985672336199365`, 0.43249880664076373`, 0.9403877688459719],
              UndirectedEdge[25, 67] -> 
             RGBColor[
              0.8985635990383481, 0.540750973420999, 0.26884077504963666`], 
             UndirectedEdge[15, 77] -> 
             RGBColor[
              0.31275241202724346`, 0.4445399594620464, 0.9411775588098623], 
             UndirectedEdge[23, 49] -> 
             RGBColor[
              0.9141583764403114, 0.6283443976324334, 0.3617031352101312], 
             UndirectedEdge[27, 37] -> 
             RGBColor[
              0.23387138917519362`, 0.3631440366986098, 0.9366300016805876], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.28199072307706635`, 0.41303118579725295`, 0.9393955660070041],
              UndirectedEdge[134, 139] -> 
             RGBColor[
              0.2400051701500614, 0.36959102940737165`, 0.9369793114329906], 
             UndirectedEdge[13, 127] -> 
             RGBColor[
              0.34979347533914956`, 0.4773952600326733, 0.9435095088317533], 
             UndirectedEdge[59, 186] -> 
             RGBColor[
              0.36541764511564734`, 0.4884580900498052, 0.9445955073983169], 
             UndirectedEdge[119, 149] -> 
             RGBColor[
              0.3992231896957711, 0.5102289495476822, 0.9477505828326117], 
             UndirectedEdge[41, 66] -> 
             RGBColor[
              0.6206670435279176, 0.7021698769586107, 0.9637962645099678], 
             UndirectedEdge[25, 103] -> 
             RGBColor[
              0.9216061306427468, 0.7086086374094871, 0.2905438354623711], 
             UndirectedEdge[164, 166] -> 
             RGBColor[
              0.3428237586125573, 0.4700619252820549, 0.9431128764626655], 
             UndirectedEdge[30, 90] -> 
             RGBColor[
              0.6408480095261183, 0.7142786377339077, 0.9678341664939911], 
             UndirectedEdge[75, 182] -> 
             RGBColor[
              0.27464253104525127`, 0.40599709184373967`, 0.9389518578945881],
              UndirectedEdge[92, 97] -> 
             RGBColor[
              0.2548383832137916, 0.38518167681737986`, 0.9378240409731977], 
             UndirectedEdge[18, 61] -> 
             RGBColor[
              0.2960837334123488, 0.42764330820172913`, 0.9402054842996372], 
             UndirectedEdge[76, 191] -> 
             RGBColor[
              0.2782905449427576, 0.40983138574745914`, 0.9391596068892982], 
             UndirectedEdge[129, 197] -> 
             RGBColor[
              0.939588342286577, 0.9465340447880747, 0.7029640290475025], 
             UndirectedEdge[97, 112] -> 
             RGBColor[
              0.2912053726836331, 0.4234056885504923, 0.9398950872233656], 
             UndirectedEdge[87, 131] -> 
             RGBColor[
              0.9436166175198961, 0.8123670652183208, 0.5433036400573084], 
             UndirectedEdge[33, 198] -> 
             RGBColor[
              0.5096004354679522, 0.6083940896440386, 0.956077633424264], 
             UndirectedEdge[39, 114] -> 
             RGBColor[
              0.20908858865686974`, 0.3370957420335433, 0.935218657853937], 
             UndirectedEdge[144, 170] -> 
             RGBColor[
              0.5194406297490485, 0.3722097272488664, 0.5677249006332556], 
             UndirectedEdge[64, 110] -> 
             RGBColor[
              0.6138148271599528, 0.6973615545881173, 0.9627408981532811], 
             UndirectedEdge[108, 131] -> 
             RGBColor[
              0.8402456246331873, 0.7322315204859621, 0.6082404593152602], 
             UndirectedEdge[33, 141] -> 
             RGBColor[
              0.3411893210123498, 0.46994277401217005`, 0.9429612597264045], 
             UndirectedEdge[12, 64] -> 
             RGBColor[
              0.6032826317786147, 0.6888110439075521, 0.9619117651521593], 
             UndirectedEdge[88, 142] -> 
             RGBColor[
              0.6765418260566909, 0.7472163657056936, 0.968410420193581], 
             UndirectedEdge[12, 95] -> 
             RGBColor[
              0.7817942234386319, 0.8080307104936368, 0.6678706900642806], 
             UndirectedEdge[131, 162] -> 
             RGBColor[
              0.941079962602384, 0.8111036548737982, 0.5757395893878008], 
             UndirectedEdge[21, 194] -> 
             RGBColor[
              0.33236539581814195`, 0.4622999335123229, 0.9423990070157204], 
             UndirectedEdge[131, 154] -> 
             RGBColor[
              0.9428931009304802, 0.8120678725150692, 0.5552941823448407], 
             UndirectedEdge[81, 184] -> 
             RGBColor[
              0.47373340289000515`, 0.5814056280463057, 0.952329749742717], 
             UndirectedEdge[105, 111] -> 
             RGBColor[
              0.4018530682244218, 0.5222917683666206, 0.9468805499681779]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 71 -> 
             RGBColor[
              0.2902833275082297, 0.42243656061010276`, 0.93984257811467], 10 -> 
             RGBColor[
              0.28931600419628395`, 0.4214198424774074, 0.9397874904830813], 
             68 -> RGBColor[
              0.8556248139763563, 0.8877160176206234, 0.9860914526539951], 
             155 -> RGBColor[
              0.24962306644129345`, 0.3797000482193023, 0.9375270363983738], 
             132 -> RGBColor[
              0.2522143608002516, 0.3824236628881191, 0.93767460677864], 26 -> 
             RGBColor[
              0.39640287984113043`, 0.5177659835555031, 0.9464794188715415], 
             29 -> RGBColor[
              0.9936430185668372, 0.9916392390574856, 0.75501516389549], 113 -> 
             RGBColor[
              0.9003020964297527, 0.6401769295720257, 0.2385219642527955], 50 -> 
             RGBColor[
              0.2422322948146241, 0.37193187863768656`, 0.9371061428879017], 
             173 -> RGBColor[
              0.9951414157005084, 0.9920163043986404, 0.7125512665860644], 
             192 -> RGBColor[0.817319, 0.134127, 0.164218], 165 -> 
             RGBColor[
              0.21890292553398902`, 0.347411232356294, 0.9357775698200786], 
             92 -> RGBColor[
              0.22871531315648586`, 0.35772467388884666`, 0.9363363707790532],
              11 -> RGBColor[
              0.24586228151751777`, 0.37574722481687783`, 0.9373128652605475],
              137 -> RGBColor[
              0.2501870825879037, 0.38029286495007875`, 0.9375591562835361], 
             120 -> RGBColor[
              0.9567688473548046, 0.8658333123497126, 0.2865555648019119], 51 -> 
             RGBColor[
              0.28213996431762406`, 0.4138773695777287, 0.9393788256279912], 
             72 -> RGBColor[
              0.24987650973082426`, 0.37996643318583184`, 0.9375414696187768],
              64 -> 
             RGBColor[
              0.6226026285830288, 0.704495887669313, 0.963432706072083], 41 -> 
             RGBColor[
              0.5497140953330726, 0.6453216927859953, 0.9576946537351515], 
             103 -> RGBColor[
              0.8642907579141675, 0.4766578520345487, 0.20847322067670976`], 
             162 -> RGBColor[
              0.9829012627807141, 0.9867683702952449, 0.9138278814340688], 
             196 -> RGBColor[
              0.49517344266125934`, 0.6010431339186144, 0.9534010137678327], 
             179 -> RGBColor[
              0.807933735593484, 0.8498832418602281, 0.9814909422600818], 160 -> 
             RGBColor[
              0.36671177852496323`, 0.4920490439135823, 0.9445875281504853], 
             123 -> RGBColor[
              0.250431442054717, 0.3805497022429847, 0.9375730721936737], 150 -> 
             RGBColor[
              0.2829267708206377, 0.41470435309880965`, 0.9394236330943619], 
             188 -> RGBColor[
              0.6646539951158695, 0.737952019632756, 0.9672101567545748], 46 -> 
             RGBColor[
              0.5977424503378598, 0.6843132750316175, 0.9614756217747897], 
             182 -> RGBColor[
              0.2651236286264823, 0.39599212186834176`, 0.9384097704837935], 
             6 -> RGBColor[
              0.3400518121902417, 0.46895752104331584`, 0.9428887786701194], 
             131 -> RGBColor[
              0.8992586624240541, 0.6354389394523516, 0.23765129734153262`], 
             45 -> RGBColor[
              0.8843599871114161, 0.5677875345316877, 0.22521947746071738`], 
             195 -> RGBColor[0.178927, 0.305394, 0.933501], 148 -> 
             RGBColor[
              0.20479309393410217`, 0.332580904729819, 0.9349740357840903], 
             161 -> RGBColor[
              0.30865896704414575`, 0.441750522845189, 0.9408890436019178], 1 -> 
             RGBColor[
              0.9583125875736904, 0.8710407105954553, 0.2925527040414048], 
             101 -> RGBColor[
              0.2518443381406806, 0.38203474561211825`, 0.9376535345355769], 
             12 -> RGBColor[
              0.5839626349742006, 0.6731262001457912, 0.9603908242322355], 39 -> 
             RGBColor[
              0.20098973591686892`, 0.3285833343068806, 0.9347574401715728], 
             48 -> RGBColor[
              0.3171026989044469, 0.4490801525711323, 0.9414264814646527], 77 -> 
             RGBColor[
              0.3003940670337382, 0.43306358890932384`, 0.940418369773149], 
             56 -> RGBColor[0.178927, 0.305394, 0.933501], 110 -> 
             RGBColor[
              0.6050270257368769, 0.6902272215069217, 0.9620490902344793], 73 -> 
             RGBColor[
              0.2931347355771166, 0.42543357128021636`, 0.9400049615859128], 
             37 -> RGBColor[
              0.19099374879671333`, 0.31807691806140814`, 0.9341881834928177],
              130 -> RGBColor[
              0.23722409174651585`, 0.3666679396746901, 0.9368209331321454], 
             107 -> RGBColor[
              0.6672310374616252, 0.7399652246995075, 0.9674670122517698], 59 -> 
             RGBColor[
              0.44880489881560515`, 0.5631539785891382, 0.949818429183309], 
             47 -> RGBColor[
              0.4515217278586501, 0.5655071593544256, 0.9499915431275343], 
             159 -> RGBColor[
              0.8226444613445744, 0.17506082952644003`, 0.16931766779781277`],
              55 -> RGBColor[
              0.35238205413251156`, 0.47963735687773035`, 0.943674450783476], 
             49 -> RGBColor[
              0.8347376037115143, 0.26801402100751526`, 0.1808980745856452], 
             82 -> RGBColor[
              0.31859842780058983`, 0.45037567776345117`, 0.9415217879872938],
              199 -> RGBColor[
              0.27228850741332744`, 0.40352286375286894`, 0.938817799731216], 
             89 -> RGBColor[
              0.8539922331287186, 0.4160135401405583, 0.19933632946055357`], 
             144 -> RGBColor[
              0.8565158956399671, 0.43541151607797846`, 0.2017529915313943], 
             78 -> RGBColor[
              0.9279645300339343, 0.9453977435956535, 0.9929912793499938], 42 -> 
             RGBColor[
              0.5214414667269106, 0.6223686992161088, 0.9554689288452234], 
             154 -> RGBColor[
              0.9865275394369064, 0.9886968055777866, 0.8729370673481489], 
             168 -> RGBColor[
              0.9385923578753286, 0.9537228615659814, 0.988831299825661], 121 -> 
             RGBColor[
              0.5426755050288741, 0.6396074480921672, 0.9571405501231992], 
             128 -> RGBColor[
              0.8895815146715775, 0.5914972716636359, 0.22957644804826868`], 
             115 -> RGBColor[
              0.2655539192117794, 0.3964443845554878, 0.9384342748960682], 61 -> 
             RGBColor[
              0.2737970101358498, 0.4051083957588368, 0.9389037067296339], 93 -> 
             RGBColor[
              0.22414759348065547`, 0.35292371089939434`, 0.9360762459008504],
              88 -> RGBColor[
              0.7121946053554326, 0.7750911056739228, 0.9719485604909927], 21 -> 
             RGBColor[
              0.31620160663402885`, 0.4482996717367106, 0.9413690646619862], 
             62 -> RGBColor[
              0.3562346737166085, 0.4829743023231845, 0.943919936296637], 136 -> 
             RGBColor[
              0.9080066729340168, 0.6729841436820356, 0.24483821356303642`], 
             190 -> RGBColor[
              0.1797070620660458, 0.3062138946902057, 0.9335454233806629], 57 -> 
             RGBColor[
              0.3605779115447064, 0.4867361966324024, 0.9441966835704689], 
             111 -> RGBColor[
              0.4604958122832016, 0.5728902713682614, 0.9506710636761264], 63 -> 
             RGBColor[
              0.35285247495850214`, 0.48004481175316516`, 0.9437044255825313],
              75 -> RGBColor[
              0.28416143346402023`, 0.4160020618191376, 0.9394939453053829], 
             30 -> RGBColor[
              0.8937471851268821, 0.9181137615718546, 0.9897275984465748], 5 -> 
             RGBColor[
              0.2822070658609612, 0.41394789755425965`, 0.9393826469616164], 
             171 -> RGBColor[
              0.8744701613749067, 0.9027427860928997, 0.9878889387123091], 
             102 -> RGBColor[
              0.37383492502239923`, 0.4982187553899085, 0.9450414087465508], 
             31 -> RGBColor[
              0.8505083657915934, 0.8836363007203797, 0.9856034412586252], 96 -> 
             RGBColor[
              0.3061966914574528, 0.4391625150862857, 0.940748820649866], 70 -> 
             RGBColor[
              0.21367513065222027`, 0.34191648847421524`, 0.9354798546353913],
              52 -> RGBColor[
              0.21246269677098534`, 0.3406421435922893, 0.9354108083194902], 
             183 -> RGBColor[
              0.859910479347665, 0.45676803010411193`, 0.20481820887036734`], 
             158 -> RGBColor[
              0.25326504777876796`, 0.3835280015199418, 0.9377344418477144], 
             13 -> RGBColor[
              0.3779993100162068, 0.5018257363634689, 0.9453067596759351], 
             170 -> RGBColor[
              0.1823653638581298, 0.3090079384197544, 0.933696809735117], 86 -> 
             RGBColor[
              0.3919595940317969, 0.5139174327134967, 0.9461962966288141], 18 -> 
             RGBColor[
              0.3183704566888478, 0.45017822064462143`, 0.9415072618696405], 
             153 -> RGBColor[
              0.585970074369736, 0.674755929881201, 0.960548857214945], 58 -> 
             RGBColor[
              0.264153442110629, 0.394972394326802, 0.9383545197969779], 22 -> 
             RGBColor[
              0.8444218577904707, 0.34245144152557083`, 0.19017172722845446`],
              66 -> RGBColor[
              0.6916199917227627, 0.7590180611312259, 0.9698978752847841], 
             143 -> RGBColor[
              0.8207984422031169, 0.16087151747445233`, 0.16754991778317269`],
              119 -> RGBColor[
              0.5648783713319804, 0.6576327351847573, 0.9588884410903589], 
             145 -> RGBColor[
              0.20775586072121455`, 0.33569496047333813`, 0.9351427609695957],
              91 -> RGBColor[
              0.8378176201564483, 0.8735170446320284, 0.9843929866107827], 
             177 -> RGBColor[
              0.29360677442013106`, 0.4259297140332158, 0.9400318434997037], 
             200 -> RGBColor[
              0.23658832296539867`, 0.36599970637566703`, 0.9367847270405965],
              114 -> RGBColor[
              0.21718744139687057`, 0.3456081497602061, 0.935679875536301], 
             24 -> RGBColor[
              0.17892700283938517`, 0.30539400298437386`, 0.9335010001616988],
              176 -> RGBColor[
              0.29419693695473825`, 0.4265500122755539, 0.9400654523829823], 
             79 -> RGBColor[
              0.20396815225836698`, 0.3317138387242981, 0.934927056576049], 
             109 -> RGBColor[
              0.3375430035907792, 0.46678451713084806`, 0.942728919604614], 
             135 -> RGBColor[
              0.23327898842098083`, 0.3625213859455549, 0.9365962653340136], 
             108 -> RGBColor[
              0.7812325868423204, 0.8290241015195725, 0.9788296212889877], 
             191 -> RGBColor[
              0.28023078255701894`, 0.41187069849821767`, 0.939270100551106], 
             14 -> RGBColor[
              0.4167727741971154, 0.535409362225998, 0.9477773705275145], 185 -> 
             RGBColor[
              0.7695733223497783, 0.8199157954843064, 0.9776675347663926], 32 -> 
             RGBColor[
              0.23515166545220784`, 0.36448968823995603`, 0.9367029115205646],
              122 -> RGBColor[
              0.9929383277496677, 0.9873041220381521, 0.47275873901987264`], 
             187 -> RGBColor[
              0.28282713132653, 0.41459962567299363`, 0.939417958772576], 193 -> 
             RGBColor[
              0.31668648779682773`, 0.44871965142909115`, 0.9413999608609163],
              100 -> RGBColor[
              0.21381427791123173`, 0.3420627410658821, 0.9354877788659421], 
             180 -> RGBColor[
              0.7240681721091139, 0.7843668262643483, 0.9731320066602097], 7 -> 
             RGBColor[
              0.350460125859892, 0.477972679206911, 0.9435519872134391], 175 -> 
             RGBColor[
              0.320397896026041, 0.45193428669643415`, 0.9416364485114123], 9 -> 
             RGBColor[
              0.2605668322464433, 0.39120263995534316`, 0.9381502676711264], 
             90 -> RGBColor[
              0.3879488339253545, 0.5104435138959607, 0.9459407345414075], 
             174 -> RGBColor[
              0.3814106085308894, 0.5047804316800383, 0.9455241246007979], 
             142 -> RGBColor[
              0.6408890467579492, 0.7193416257374643, 0.9648722798961695], 
             134 -> RGBColor[
              0.23085213233970892`, 0.3599706063325754, 0.9364580594703971], 
             105 -> RGBColor[
              0.34321032416564207`, 0.47169326536497985`, 0.9430900362602295],
              16 -> RGBColor[
              0.3229612837478847, 0.4541545643014821, 0.9417997853103334], 
             139 -> RGBColor[
              0.24915820796041388`, 0.3792114524821679, 0.9375005633955842], 
             146 -> RGBColor[
              0.79609453068194, 0.84063436500204, 0.9803109209581594], 126 -> 
             RGBColor[
              0.30722498883092086`, 0.4402433208236197, 0.9408073806640553], 
             198 -> RGBColor[
              0.6961608186542636, 0.7625653896416773, 0.9703504624768758], 40 -> 
             RGBColor[
              0.49158142165721236`, 0.5981269694488269, 0.9531182367163876], 
             104 -> RGBColor[
              0.21893481250696653`, 0.34744474758664423`, 0.9357793857360172],
              181 -> RGBColor[
              0.984329904565909, 0.9877880270819891, 0.9093575644573119], 127 -> 
             RGBColor[
              0.32158764066209233`, 0.4529647837018777, 0.9417122579875715], 
             76 -> RGBColor[
              0.27635030732849636`, 0.40779207299670056`, 0.9390491132274904],
              172 -> RGBColor[
              0.9939767127007667, 0.98952512245173, 0.5857805327779135], 84 -> 
             RGBColor[
              0.2627765683456537, 0.3935252127009741, 0.9382761088729649], 
             184 -> RGBColor[
              0.3711329893802169, 0.49587847453988415`, 0.9448692437966588], 
             151 -> RGBColor[
              0.3518764439127397, 0.4791994227180725, 0.9436422337473658], 35 -> 
             RGBColor[
              0.8383733051460716, 0.8739601327590868, 0.9844459883411588], 36 -> 
             RGBColor[
              0.24777983952010385`, 0.3777626998577953, 0.9374220673520219], 
             34 -> 
             RGBColor[
              0.2517479206748871, 0.38193340474234894`, 0.9376480437035368], 
             38 -> RGBColor[
              0.9648082727380654, 0.8929521819142981, 0.31778721429778617`], 
             54 -> RGBColor[
              0.27280646441116213`, 0.40406726939796367`, 0.938847296615994], 
             60 -> RGBColor[
              0.253957266336059, 0.38425556711284614`, 0.9377738626705066], 
             87 -> RGBColor[
              0.9879745726157381, 0.9892951909842899, 0.8489559827730842], 
             141 -> RGBColor[
              0.3593385897430587, 0.4856627583779401, 0.9441177150811572], 67 -> 
             RGBColor[
              0.8182056947053702, 0.14094252405757224`, 0.16506709985124088`],
              133 -> RGBColor[
              0.8234278438149039, 0.18108225047377968`, 0.1700678357361042], 
             98 -> RGBColor[
              0.9734883859205871, 0.9797482621451334, 0.9297614266867937], 3 -> 
             RGBColor[
              0.26366336471100654`, 0.39445729190709694`, 0.938326610614074], 
             27 -> RGBColor[
              0.2767490295536739, 0.4082111553358114, 0.9390718198683575], 
             163 -> RGBColor[
              0.23302215960706, 0.36225144257823677`, 0.936581639313005], 85 -> 
             RGBColor[
              0.360155081261214, 0.48636996229290924`, 0.9441697411986989], 
             83 -> RGBColor[
              0.25584834544704116`, 0.3862432111598293, 0.9378815568282761], 
             28 -> RGBColor[
              0.29477679578460203`, 0.4271594806709139, 0.9400984744855188], 
             44 -> RGBColor[
              0.2834240796528994, 0.4152270562127178, 0.9394519540966568], 
             189 -> RGBColor[
              0.2313913752108486, 0.36053738478011593`, 0.9364887685541701], 
             15 -> RGBColor[
              0.32511075702074876`, 0.45601633001476893`, 0.9419367478465757],
              80 -> RGBColor[
              0.6198970672218798, 0.7022993910721819, 0.9632197143709355], 
             112 -> RGBColor[
              0.30144929209616883`, 0.4341726973550716, 0.9404784632793888], 
             169 -> RGBColor[
              0.2725827939998642, 0.40383217761416634`, 0.9388345589169613], 
             69 -> RGBColor[
              0.4015855979045752, 0.522254993451075, 0.9468096570836465], 20 -> 
             RGBColor[
              0.22540124214842158`, 0.354241375135133, 0.9361476393378726], 8 -> 
             RGBColor[
              0.44819737568646545`, 0.5626277725896778, 0.9497797183467319], 
             116 -> 
             RGBColor[
              0.3895827819898638, 0.5118587575848209, 0.9460448482672345], 97 -> 
             RGBColor[
              0.28096145327109734`, 0.41263867974591306`, 0.9393117111673424],
              118 -> RGBColor[
              0.9133075269424444, 0.9337106471842498, 0.9915932813106664], 
             178 -> RGBColor[
              0.9424318889382709, 0.9565863775460686, 0.9823319752461818], 81 -> 
             RGBColor[
              0.5763338163997934, 0.6669327815527272, 0.9597902556887751], 
             166 -> RGBColor[
              0.39092445521974123`, 0.5130208475020834, 0.9461303384990473], 
             125 -> RGBColor[
              0.17895982839241617`, 0.30542850472186966`, 0.9335028695283829],
              95 -> RGBColor[
              0.9796258119030633, 0.9429352208414826, 0.3753505558963255], 
             157 -> RGBColor[
              0.5576848060128018, 0.6517926747922235, 0.9583221372775351], 74 -> 
             RGBColor[
              0.30278259996188467`, 0.4355740884585403, 0.9405543931898891], 
             19 -> RGBColor[
              0.26440158051900675`, 0.3952332035268908, 0.9383686509122472], 
             156 -> RGBColor[
              0.9208437466954219, 0.9397198242500384, 0.9923120926783682], 
             167 -> RGBColor[
              0.9152757732218003, 0.9352800733407862, 0.9917810143978655], 33 -> 
             RGBColor[0.3230400522816408, 0.4542227896464, 0.941804804371652],
              43 -> RGBColor[
              0.8553653759675705, 0.4265681177150025, 0.20065125259378117`], 
             140 -> RGBColor[
              0.30550365683416836`, 0.4384340917562807, 0.9407093533533227], 
             186 -> RGBColor[
              0.28203039141568953`, 0.41376220151047227`, 0.9393725856133247],
              117 -> RGBColor[
              0.7789983515005383, 0.8272786998897548, 0.9786069335902352], 4 -> 
             RGBColor[
              0.8048857220793089, 0.8475021105371937, 0.9811871447582946], 
             106 -> RGBColor[
              0.27505191676798696`, 0.40642738219488894`, 0.9389751718058661],
              65 -> RGBColor[
              0.9220936452530043, 0.9407164594322621, 0.992431309118588], 53 -> 
             RGBColor[
              0.21141226994966317`, 0.3395380784021726, 0.9353509880659832], 
             2 -> RGBColor[
              0.377120805174838, 0.5010648196248124, 0.9452507821242745], 147 -> 
             RGBColor[
              0.4806958664434177, 0.5892895853375945, 0.9522612859348552], 94 -> 
             RGBColor[
              0.4181274501813097, 0.5365827144755124, 0.9478636892833344], 23 -> 
             RGBColor[
              0.9935791491691084, 0.9886747742573517, 0.5425081958346172], 
             194 -> RGBColor[
              0.348529185002255, 0.47630019528793527`, 0.9434289493694545], 
             129 -> RGBColor[
              0.9902596908634175, 0.9788057915282733, 0.4166611676177604], 99 -> 
             RGBColor[
              0.5640955015617808, 0.656997166237428, 0.9588268107143023], 25 -> 
             RGBColor[
              0.9789215033713261, 0.9405594227844256, 0.37261445024803247`], 
             138 -> RGBColor[
              0.9127756759352338, 0.6918916514058181, 0.2486754653207034], 
             124 -> RGBColor[
              0.2910544796798416, 0.42324709043633846`, 0.9398864940900259], 
             197 -> RGBColor[
              0.8889169937097365, 0.9142622980478761, 0.9892668904772446], 
             164 -> RGBColor[
              0.29472306200537346`, 0.42710300306202637`, 0.9400954144262837],
              152 -> RGBColor[
              0.281739557244844, 0.41345651635696223`, 0.9393560230375456], 
             17 -> RGBColor[
              0.2388383031545141, 0.3683645782114108, 0.9369128600838192], 
             149 -> RGBColor[
              0.2335680080595618, 0.362825163910607, 0.9366127245748646]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9lnk01I33xy0ZCmPGjGUM5jOLCfGgkIjPm8rSZv1l6yGUlK0nopQSkiYJ
LahIHqLta6lHok2FUhGiHm2iRUpCWSbL1++c3/ndc+65/9x/7rn3/bpvbmCk
2yYpCQmJh7P5v/VBawZ55xUHYW8zjtTbKsDaIH7bZwcCjpXZ32wt+Rjd7Lo7
tnseOvea6x/0HSa9rxx+IbmQhZy6z0cn7biwOZpxc1cVDS5hLi4Ldn8ic2o8
VUdXzJDjpy6p9EbQIJlfdrxXgYfJ2tv17DYxaTyjcbX3tQ7WSS68vkvIAC/w
UtnPR8ogRussGh69I4XBY/mqVbIgChKbi4qmyGiHwf5mUyU83PrZ1SjlI5mX
sKKu9CoFrPY7E5lTNHjZt/IvcmfIvvG49CY9JhydAwqLkmWQvJzdfNZDBkZ7
OPM+TspDoyrGRM5qnBxf0rVitPw32d1TPLVPRxl7HG983Z1CA7H64gUfbjNp
5+Wsl13Kx8ZD7XutgqfJynjmk8//SiPL7GpuXjgHBb4pBTJnqCCkP+YWW7SQ
qg4fXg016qAr7fejvW4cHFw5ErXvOYH08glrVjcDZ1Tb/r4tT0PM3UMv5lEY
+Ct0+59aT7WQlagpOkYwYJBc2qNLpSFoQWHZ2hxltOn8dehBJAFKFVH3PYiP
xze/qjdEaqCcGxuYYKCCbyyZC5k2VDj2gh3wbz+Zpr7vpnEgF81PDJfHJc9D
ddJig61sGvpXhrtI+muivSni5Zk1PKz3KG9xnMOBuuIAc3H8AHnSqfLJGUId
377rG8kkKaHI5G1p20kCPyof2DuumibFa3rFo5e1Edx6Yey4Ix8PunSawzLn
QoZv3ezH10FPFWm+YzkPPvyvd5So2vCsia1X6mBiWkM0ucCThz47abmlczXg
pU+4Gj8l0GPX+MGjcQHY+uacvONcdC01zP7jCBd3ha7O5GcmGl7LXKn6TOCY
U9gT07fa6C5fFDbTN0oq2oQPhNsyYJXW6uJ0VBm5Vt9zLiRSIFEoOZGoSMDy
+UwrJVkLE/faU/sCtGEsHdwz3cTH1q2vKzrVtCGusDg/mMfHRKQSLSZ/Dji6
YoyeVcBSlyK/EHKC3CQxtkJ1Ex3Jk7GrK+IZKFielBuAMfLkz6DUnQwtmC1D
2Y0mLbit6JKkhAhgff3D4JiuITZzmyUEkTTo/g8j2f9lN/lyLJ9lItZAnT3p
PL5egLutZ8ul5WdI1S1pKd/vCXFxS55qy1EaljwZ1GvuYkOsre/HvcJAr/9m
2rI4ZVScGymxiOCiY7pEiHM8jIvaGAXFA6RabCglbqUsPP/QWltiJAsJi1sd
zx3EZNXlqwfebNNCgO/QU5GuAOWTW05cYEyR2zL+PO5BFaI27HhSu7oiMuwX
l1zOoyOLff56L/Unec/ok06UtQzes36+r7dhokZsz02IVEIcPYUwY2uAaihr
WDjMgFStNE3oSkAZvm53ZnU6N7F90RNtJmxfr7WjrhXgoSjeuuYXDdtGJIML
iqSRf6OWbvpFHcPnfS/HX1qAxSZDce4n6PjuzckX16tj5XQhczKRD92Dczf0
bNfD+7HR9JBryugi3H/4J/Hxoy3Vgng2QfaLKpTC1AiUlNPZ2Xf4sMsLtc0X
6mLHikU3aiaVkHxc5d3QJSHE8qW6FgfmwnvOoeb1ejTkVNWvkPw9QAY71FdI
XWIh2uz0/jPieWDU+kyGPtZG/YGN07qBDCzcs9tUbMrB82dpTel7ubgi1eAx
BBb+5m3eurqLC3XtcL8gcpKU8o8KMFuvjsnj0rZFzsMkNddEpewTA6rZLzfc
26CHWsn4WxVTKigdDPLou6MDmcQro8cfaULCmTnhFyGBPbuda0LTmMj9MlbS
m0tF4bFo8yxTJnxoD2ui2wm8d9cLfaExB1TPln2+rRxYRuxfdz2Dhq9FTUeD
ExRgoPzQy2dWr0Ur2s/fnVBBVZZ8rOcqCkL0NWlP2AQk/i98d1UbJestQBZT
KrZJhoEYJw+X7WV8IHwy1WxYCkXeUtpLViojYj9l7fJiGuqzn2Wd2izE4u9a
b9pPyeN+ZU2Nd7AG5BJur/bM/0QmdmKZqTYfnekDO178ZCPHTuackpwOKIVi
jfBn6iD+sVrfXNlLOn44qR73twZKx8ujQ4pGyEtjj7t/zfKpZ5354PzXqrht
usCLNTpE6t97dsfMnY6Wnwc4SdIMlAduFCUPfSUn79nLRjloAW3mw7cCdLDT
5XznGlUKspOSD1IbaZDgdCTsX9BP1tp2jGbMCJCWVcAc1lPGydQvse7EPNyU
97YLlWFCTmWk+vdnHThwzMWWdC3EHBUNLuumoLV6pMbdTg3X9gY5qN0Q4IjZ
5otLZvno/93fL1OkjJ00yzcL+d/IAF5c741qDgxYtKOJcfJoeDcTs24LATnr
bMLaSg/rOsJ/HXzDR/O7w0nC4V+k4wv21uCjAuzWuG7KNaJgjXEzb8CUhwcC
hcVHDnMwKSUyjPfnIPlTivIWydl5Lern/N7FgeQy+Yg+RRV0/jb2HvCb5daS
sjDDWW5OpL0KrbbmYW6I1WHKBwL717W0L47jIvWrp02BsiLkTkoN5CSOkBt/
u9b1Xp696w/JA5NlP0kZ8eqYEU8GfALGXtjPcmC1nF7WEbYKmrqu/hZd0IGi
kZP+mL8sDJrmbhrYMElyKGe6AyNVseZOwnrRdQ4e1h+MiElTA/HmP1eCV6vg
gqtC/I1BZYQZL9y7VfST7IqYOTbHThNe2+tadnfQwOu+5v92DxO6WQoKLr5C
xA+9CtvpRYAavFn/01oGVK7Jv9lVrILD73qq0+/r41x7x1wr0SwfrAb/pBP9
5IMav4RSDzWsZctc3FmniZtaf2anpshj/K5xRUjGL/LOsGwTw4UOCo3wz/2X
CwVWgskpOxpe/vNaySFVD/b7z+Wu/kaH3EDt/lN7lPFMw3t8PLuP/CVfvtHT
Vgmf3rt+DH5FoLMuPUkznw+3hZGLzSXnYVX506iLsipYKbNdQr2Qji+vmDFY
SuBi0N9nrhvR4amtltJjbIDG7UqOAkc6TA6dHl+iJkDlnOApZ102LnsFtQxE
6cA5nKXk3qby/7rT2ffUJsWOBcnSs3ox57SRMVIc86lYGW8cfEy29Aixg/D/
ErFLC7fParK+ZwkgG+Bs81iaQH7Oj2JG83zEG3ZxC83UUVp+o3VHJg8d2Zan
522QxqzNobItqLgOi1FuFB3TYitfIZVAd2r1Nf7jRjLwPWF69SEft/7dPXnP
SQW8RcGRGZ8FaE4aq3iSpoiXB7kPQ+5zEFWp53zisA5ynRUoblxt3PO0jCqc
9SE5bf3IlxPAxDx2q9Njqdn+5yUjjlNkfYnTHHfnWdqLNFyu7aBicN2Pdw6E
KjKC/9kUeG6ITFsRPZwZzUbWqrTR05paMBZ63Eoc4mMngsuoDt3k89b8/Ip0
NTS0HPjPm2Pa4E/Ns6z04aN0/a1i9V08DJ6/vcgkSQ4NlIKo5+4aSLT4+mHL
IwL7pBv7XffxcPRmSqV6MR/r1p4POBGvCZuR6k7beGX8tumtub+HB+uJaItR
M230qq9daKGjgVQ71Q2COAJJRb8++GpxsOfwgHAqncDIEjfLskYBukWi20uK
ZWBaQoZlvhWTrLqwnUlqDLyM8cp+3DxGisMtlrK9mEgo7G8S60pgRPSX+bJV
mkhbU77Y9hYfR7YG8MTLNXDY//EW+80CmF7Lz6t+qQqdKT5rPEQOyb9YXQaW
aihNVDxNHeahqbE4IlaKhmmW4knVY/PR9O2vNIVCeZChFvqHVHiIuDwS//CW
Oh7IfpGM6GOjR6fjincjDy/PmGcoFwiwsLmgajuPDt7yhMgyH0l8bYqfb981
y3vb+31mXT/Jpmd+Vi8amTAcr9XaTuEj9N3e3PkKFJw4VRmz6NTsn6dEmNYs
7CAf8QuG06q0Ee4hK4x2Y0K1uV6ywFIXz0oz3weVKkJ9tOGLgg0XCekN+z6O
MJAYML5aslAalXqSTg2P5LCySzcoeZsQGdv+SCyKZsHQ8Bw1aHbflp+8ar+4
M5HseaGrs4uP16+HMo2COfCmT6m4RbChKCSn5a3paMiT3vVFlYlozzwtioBA
aZxX/26rCbLAsiPWj05HTnh7S9tdARQDOdF7RQL8F8y1UMw=
         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 29}], {
             RGBColor[
             0.9759778030702638, 0.9313399748264705, 0.5237839339684474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 78}], {
             RGBColor[
             0.9431385588038124, 0.9082192270955545, 0.6427719916956993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 88}], {
             RGBColor[
             0.8352535964645615, 0.823065908134689, 0.6322506322661987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 89}], {
             RGBColor[
             0.9061524103512045, 0.6435271253680068, 0.2459445167509792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 113}], {
             RGBColor[
             0.9293073420017215, 0.7556088200837405, 0.2655373341471002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 122}], {
             RGBColor[
             0.9756254576616791, 0.9291724163168037, 0.38265572153063876`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 136}], {
             RGBColor[
             0.9331596302538536, 0.7720124271387454, 0.2686954588022206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 138}], {
             RGBColor[
             0.9355441317544622, 0.7814661810006367, 0.2706140846810541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 144}], {
             RGBColor[
             0.9074142416068287, 0.6532261133367169, 0.24715284778639957`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 159}], {
             RGBColor[
             0.8904785244591324, 0.5230507700609477, 0.2309351859196088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 167}], {
             RGBColor[
             0.9367941803977453, 0.9031603919681208, 0.6421668592196352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 197}], {
             RGBColor[
             0.9236147906417135, 0.8926515043216656, 0.6409097972593247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 26}], {
             RGBColor[
             0.3867618425079842, 0.5094154015901577, 0.945865100497908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 40}], {
             RGBColor[
             0.43435111341602517`, 0.5495958945368197, 0.9491845094203311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 51}], {
             RGBColor[
             0.329630384746231, 0.45747109460127056`, 0.9423148038761329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 74}], {
             RGBColor[
             0.3399517025683613, 0.46831945404167635`, 0.9429025876570818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 80}], {
             RGBColor[
             0.4985089361983589, 0.6016821053484971, 0.954235248247605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 121}], {
             RGBColor[
             0.45989815510185605`, 0.5703361338584898, 0.9511956661237368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 158}], {
             RGBColor[
             0.31519292647680297`, 0.4422964105723771, 0.9414926119859944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 164}], {
             RGBColor[
             0.3359219335901057, 0.4640839113434194, 0.9426730982752791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 166}], {
             RGBColor[
             0.3840226301972896, 0.5070428335634479, 0.9456905603116609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 169}], {
             RGBColor[
             0.3248517995873511, 0.4524484986194894, 0.942042670520618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 184}], {
             RGBColor[
             0.37412689727752746`, 0.49847164708234826`, 0.9450600129604667]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 5}], {
             RGBColor[
             0.27293521528598386`, 0.4042025947306783, 0.9388546287878452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 10}], {
             RGBColor[
             0.27648968445364525`, 0.4079385671922522, 0.9390570505485776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 11}], {
             RGBColor[
             0.2547628231142621, 0.3851022583619874, 0.9378197379373108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 15}], {
             RGBColor[
             0.2943870608658776, 0.4252368109609329, 0.9401316792303248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 20}], {
             RGBColor[
             0.24453230342971405`, 0.374349333521115, 0.9372371249759732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 28}], {
             RGBColor[
             0.2792200802478043, 0.4108083862890054, 0.9392125425497964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 48}], {
             RGBColor[
             0.29038303180772673`, 0.42176872223911466`, 0.9398765460393633]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 63}], {
             RGBColor[
             0.30825791983475437`, 0.437251051830131, 0.9410155180983026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 77}], {
             RGBColor[
             0.2820287158723724, 0.41376044040821036`, 0.9393724901936115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 106}], {
             RGBColor[
             0.26935764073949675`, 0.40044233705099297`, 0.93865089120997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 186}], {
             RGBColor[
             0.27284687806334806`, 0.40410974670878463`, 0.9388495981136993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 189}], {
             RGBColor[
             0.24752736996092756`, 0.37749733834360644`, 0.937407689584122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 41}], {
             RGBColor[
             0.6772999087061907, 0.7464119016615944, 0.969440899246723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 66}], {
             RGBColor[
             0.7482528569010358, 0.8032600858342098, 0.9755425100215394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 80}], {
             RGBColor[
             0.7123913946505943, 0.7749007508046878, 0.972203429564615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 81}], {
             RGBColor[
             0.6906097692395512, 0.7572174460449604, 0.9704887002235348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 168}], {
             RGBColor[
             0.8717390399773187, 0.9006124860515876, 0.9850092222919777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 172}], {
             RGBColor[
             0.8994312173900378, 0.9185136164944618, 0.783483838768104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 173}], {
             RGBColor[
             0.9000135688899087, 0.9197592074679171, 0.8468692056721795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 184}], {
             RGBColor[
             0.5880093557297629, 0.671690292538539, 0.9630281942774768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 198}], {
             RGBColor[
             0.7505232703667862, 0.8050337500894356, 0.9757688036175852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 9}], {
             RGBColor[
             0.27138694905370225`, 0.40257526875480143`, 0.9387664573163714]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.2640346736892395, 0.39484756118556874`, 0.938347756111082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 15}], {
             RGBColor[
             0.303658911440855, 0.4349821137845143, 0.940659697404096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 17}], {
             RGBColor[
             0.26052268450773763`, 0.3911562378828352, 0.9381477535227178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 20}], {
             RGBColor[
             0.2538041540046914, 0.3840946363446963, 0.9377651431497445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 28}], {
             RGBColor[
             0.28849193082278163`, 0.4205536891125868, 0.9397405607235676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 48}], {
             RGBColor[
             0.2996548823827041, 0.431514025062696, 0.9404045642131346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 63}], {
             RGBColor[
             0.3175297704097317, 0.4469963546537124, 0.9415435362720739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[
             0.2913005664473497, 0.42350574323179174`, 0.9399005083673827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 102}], {
             RGBColor[
             0.32802099544168023`, 0.45608332647208405`, 0.9422120278540836]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 106}], {
             RGBColor[
             0.2786294913144741, 0.4101876398745743, 0.9391789093837413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 112}], {
             RGBColor[
             0.29182817897856506`, 0.4240602974546656, 0.9399305551205026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 140}], {
             RGBColor[
             0.2938553613475648, 0.42619099465527016`, 0.9400460001574695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 189}], {
             RGBColor[
             0.2567992205359049, 0.38724264116718776`, 0.9379357077578933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 12}], {
             RGBColor[
             0.4620072235822212, 0.5710418605945535, 0.9516398014511775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 13}], {
             RGBColor[
             0.35902556110322426`, 0.48539162870339236`, 0.9440977691730272]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 14}], {
             RGBColor[
             0.37841229319367853`, 0.5021834416346569, 0.945333074598817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 16}], {
             RGBColor[
             0.3315065479690632, 0.46155604267239897`, 0.9423442819902264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 59}], {
             RGBColor[
             0.39442835550292343`, 0.516055749816227, 0.9463536039267142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 64}], {
             RGBColor[
             0.4813272203866353, 0.5867267043563145, 0.9531607423711013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 83}], {
             RGBColor[
             0.29795007881864144`, 0.4276003661015726, 0.9403851677491978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 86}], {
             RGBColor[
             0.3660057031110193, 0.4914374768784062, 0.9445425376494667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 124}], {
             RGBColor[
             0.3155531459350417, 0.4461023057398271, 0.9413876363800726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 137}], {
             RGBColor[
             0.2951194473890727, 0.4246251929966973, 0.9402239674768278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 161}], {
             RGBColor[
             0.32435538961719373`, 0.45535402194425245`, 0.9418889111360187]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 175}], {
             RGBColor[
             0.3302248541081414, 0.460445903869875, 0.9422626135907659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 176}], {
             RGBColor[
             0.31712437457249, 0.4477537666594349, 0.9414771155265509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 186}], {
             RGBColor[
             0.3110411018029656, 0.4413598612768941, 0.941130682141722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 187}], {
             RGBColor[
             0.3114394717583858, 0.44177857335815474`, 0.9411533687213477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 193}], {
             RGBColor[
             0.3283691499935347, 0.4588385862362035, 0.9421443697655179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 199}], {
             RGBColor[
             0.3061701598017846, 0.4362401923980924, 0.9408532892006678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 18}], {
             RGBColor[
             0.33441529127436986`, 0.4640754499257662, 0.9425296245415398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 42}], {
             RGBColor[
             0.4359507962934013, 0.5501706892115099, 0.9495104580293312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 47}], {
             RGBColor[
             0.40099092685927107`, 0.5217399192806683, 0.9467717651704868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.31163329513552707`, 0.44101997430243733`, 0.9411996419147166]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 58}], {
             RGBColor[
             0.3073067839852605, 0.4364725367668565, 0.9409532535052085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 61}], {
             RGBColor[
             0.3121285679978709, 0.4415405374828739, 0.9412278469715365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 73}], {
             RGBColor[
             0.3217974307185043, 0.4517031252435637, 0.941778474399676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 88}], {
             RGBColor[
             0.5313273656076622, 0.6265318924404168, 0.9577502738522159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 94}], {
             RGBColor[
             0.3842937880206009, 0.5072776968412117, 0.9457078382483868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 97}], {
             RGBColor[
             0.3157107895654947, 0.44530567947641203`, 0.9414318491903908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 115}], {
             RGBColor[
             0.3080070225358357, 0.4372085318811994, 0.9409931310547537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 153}], {
             RGBColor[
             0.46821510011481404`, 0.5763643045440561, 0.9520504222141921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 160}], {
             RGBColor[
             0.3585859521924276, 0.48501086156024664`, 0.9440697576819622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 188}], {
             RGBColor[
             0.5075570604878807, 0.6079623494198335, 0.955381071984007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 55}], {
             RGBColor[
             0.4002897149094885, 0.5211325647337041, 0.9467270845651039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 62}], {
             RGBColor[
             0.40221602470153694`, 0.5228010374564311, 0.9468498273216844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 68}], {
             RGBColor[
             0.6519110948314109, 0.7251718951051506, 0.9679355855003635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 75}], {
             RGBColor[
             0.36617940457524284`, 0.4893149172044077, 0.9446368318260574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 96}], {
             RGBColor[
             0.3771970335719591, 0.5008951438379817, 0.9452642694982989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 99}], {
             RGBColor[
             0.5061464386241231, 0.6098124694135529, 0.9543032645305172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 107}], {
             RGBColor[
             0.5577142065740452, 0.6512964986445926, 0.9586233652992509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 147}], {
             RGBColor[
             0.4644466210649416, 0.5759586789636362, 0.9510205021407936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 156}], {
             RGBColor[
             0.6845205611909437, 0.7511737984198581, 0.97104590551255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 157}], {
             RGBColor[
             0.5029410908496337, 0.6072102236909507, 0.9540509278121335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 179}], {
             RGBColor[
             0.6280655556399748, 0.706255507224953, 0.9656353303034069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 185}], {
             RGBColor[
             0.6088853490181219, 0.6912717840369921, 0.9637236265565623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 194}], {
             RGBColor[
             0.3983632803443602, 0.5194639839388066, 0.9466043338580932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.2532145568819805, 0.3834749323861105, 0.937731566465837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 17}], {
             RGBColor[
             0.2497025677004787, 0.37978360908337694`, 0.9375315638774728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 20}], {
             RGBColor[
             0.24298403719743245`, 0.3727220075452381, 0.9371489535044994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 28}], {
             RGBColor[
             0.27767181401552266`, 0.4091810603131285, 0.9391243710783226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 63}], {
             RGBColor[
             0.3067096536024727, 0.43562372585425413`, 0.9409273466268289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 77}], {
             RGBColor[
             0.2804804496400908, 0.41213311443233347`, 0.9392843187221377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 97}], {
             RGBColor[
             0.2707641427587703, 0.4019206598506281, 0.9387309894192344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 102}], {
             RGBColor[
             0.31720087863442126`, 0.44471069767262583`, 0.9415958382088386]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.2678093745072151, 0.3988150110751161, 0.9385627197384963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 112}], {
             RGBColor[
             0.28100806217130603`, 0.41268766865520734`, 0.9393143654752576]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 140}], {
             RGBColor[
             0.2830352445403058, 0.4148183658558119, 0.9394298105122245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 189}], {
             RGBColor[
             0.24597910372864595`, 0.37587001236772954`, 0.9373195181126482]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 14}], {
             RGBColor[
             0.35304438919669967`, 0.4784146023517027, 0.943782430505298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 15}], {
             RGBColor[
             0.30721338060851633`, 0.43871808624608816`, 0.9408621191648285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 28}], {
             RGBColor[
             0.292046399990443, 0.42428966157416065`, 0.9399429824843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 48}], {
             RGBColor[
             0.30320935155036544`, 0.43524999752426985`, 0.940606985973867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 59}], {
             RGBColor[
             0.3690604515059446, 0.4922869105332728, 0.9448029598331952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 77}], {
             RGBColor[
             0.2948550356150111, 0.4272417156933656, 0.9401029301281152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 186}], {
             RGBColor[
             0.28567319780598677`, 0.4175910219939398, 0.939580038048203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 193}], {
             RGBColor[
             0.30300124599655587`, 0.4350697469532493, 0.9405937256719987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 15}], {
             RGBColor[
             0.28548651926913327`, 0.4158817774158234, 0.9396248065535615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 17}], {
             RGBColor[
             0.24235029233601593`, 0.3720559015141443, 0.9371128626721834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 20}], {
             RGBColor[
             0.2356317618329697, 0.3649942999760054, 0.93673025229921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 28}], {
             RGBColor[
             0.2703195386510599, 0.4014533527438959, 0.9387056698730332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 48}], {
             RGBColor[
             0.2814824902109824, 0.4124136886940051, 0.9393696733626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 63}], {
             RGBColor[
             0.29935737823800995`, 0.4278960182850215, 0.9405086454215394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 77}], {
             RGBColor[
             0.27312817427562797`, 0.40440540686310084`, 0.9388656175168482]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 106}], {
             RGBColor[
             0.2604570991427524, 0.3910873035058834, 0.9381440185332068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 112}], {
             RGBColor[
             0.2736557868068433, 0.4049599610859747, 0.9388956642699682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 140}], {
             RGBColor[
             0.27568296917584306`, 0.40709065828657925`, 0.9390111093069351]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 189}], {
             RGBColor[
             0.2386268283641832, 0.36814230479849686`, 0.9369008169073587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 13}], {
             RGBColor[
             0.4809809724952037, 0.58747596825463, 0.9528487919540853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 14}], {
             RGBColor[
             0.500367704585658, 0.6042677811858945, 0.954084097379875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 16}], {
             RGBColor[
             0.45346195936104267`, 0.5636403822236367, 0.9510953047712845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 23}], {
             RGBColor[
             0.7887708920716545, 0.8309004872015715, 0.7514495100334264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 25}], {
             RGBColor[
             0.7814420691727634, 0.8068428114651084, 0.666502637240134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 59}], {
             RGBColor[
             0.516383766894903, 0.6181400893674647, 0.9551046267077723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 64}], {
             RGBColor[
             0.6032826317786147, 0.6888110439075521, 0.9619117651521593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 86}], {
             RGBColor[
             0.4879611145029988, 0.5935218164296439, 0.9532935604305248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 87}], {
             RGBColor[
             0.7859686037949694, 0.8312106955650405, 0.9046734035026598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 95}], {
             RGBColor[
             0.7817942234386319, 0.8080307104936368, 0.6678706900642806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 108}], {
             RGBColor[
             0.6825976109082605, 0.7510751508326818, 0.9696102227606116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 154}], {
             RGBColor[
             0.7852450872055535, 0.8309115028617888, 0.9166639457901922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 161}], {
             RGBColor[
             0.4463108010091732, 0.5574383614954901, 0.9506399339170767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 175}], {
             RGBColor[
             0.4521802655001208, 0.5625302434211127, 0.9510136363718239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 193}], {
             RGBColor[
             0.4503245613855142, 0.5609229257874412, 0.950895392546576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 16}], {
             RGBColor[
             0.35048029688204574`, 0.4779901503324755, 0.9435532724931343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 64}], {
             RGBColor[
             0.5003009692996179, 0.6031608120163909, 0.9543697328740091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 69}], {
             RGBColor[
             0.38979245396039097`, 0.512040364907272, 0.9460582083797908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 82}], {
             RGBColor[
             0.34829886890839834`, 0.4761007070634601, 0.9434142738316145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 83}], {
             RGBColor[
             0.316923827731624, 0.4440344737616491, 0.9415941582521057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 86}], {
             RGBColor[
             0.38497945202400186`, 0.5078715845384828, 0.9457515281523746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 101}], {
             RGBColor[
             0.3149218240784437, 0.4419302409877936, 0.941480147105756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 108}], {
             RGBColor[
             0.5796159484292636, 0.6654249189415207, 0.9620681904824614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 110}], {
             RGBColor[
             0.49151316787654187`, 0.5960264789351953, 0.9536779249552072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 124}], {
             RGBColor[
             0.3345268948480242, 0.4625364133999037, 0.9425966268829805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 127}], {
             RGBColor[
             0.34979347533914956`, 0.4773952600326733, 0.9435095088317533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 137}], {
             RGBColor[
             0.31409319630205523`, 0.44105930065677384`, 0.9414329579797356]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 161}], {
             RGBColor[
             0.34332913853017627`, 0.471788129604329, 0.9430979016389265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 175}], {
             RGBColor[
             0.34919860302112393`, 0.4768800115299515, 0.9434716040936737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 176}], {
             RGBColor[
             0.3360981234854725, 0.4641878743195114, 0.9426861060294587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 187}], {
             RGBColor[
             0.33041322067136836`, 0.4582126810182313, 0.9423623592242556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 199}], {
             RGBColor[
             0.3251439087147671, 0.45267430005816894`, 0.9420622797035756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 15}], {
             RGBColor[
             0.3709417656089321, 0.49571284612038347`, 0.9448570591870451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 48}], {
             RGBColor[
             0.36693773655078116`, 0.49224475739856516`, 0.9446019259960836]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 59}], {
             RGBColor[
             0.43278883650636024`, 0.549281670407568, 0.9487978998554119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 186}], {
             RGBColor[
             0.34940158280640243`, 0.47458578186823513`, 0.9435749780704197]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 193}], {
             RGBColor[
             0.36672963099697153`, 0.49206450682754455`, 0.9445886656942154]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 28}], {
             RGBColor[
             0.3099437764026754, 0.4415879053428414, 0.9410176111660472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 48}], {
             RGBColor[
             0.32110672796259787`, 0.4525482412929506, 0.9416816146556142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 59}], {
             RGBColor[
             0.38695782791817696`, 0.5095851543019536, 0.9458775885149424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 63}], {
             RGBColor[
             0.33898161598962545`, 0.46803057088396705`, 0.9428205867145535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 77}], {
             RGBColor[
             0.31275241202724346`, 0.4445399594620464, 0.9411775588098623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 106}], {
             RGBColor[
             0.3000813368943679, 0.43122185610482894`, 0.9404559598262209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.3132800245584588, 0.44509451368492026`, 0.9412076055629822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 140}], {
             RGBColor[
             0.31530720692745856`, 0.4472252108855248, 0.9413230505999493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 193}], {
             RGBColor[
             0.32089862240878825`, 0.45236799072193, 0.941668354353746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 64}], {
             RGBColor[
             0.47278195616545676`, 0.5793252259853976, 0.9526162456912082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 83}], {
             RGBColor[
             0.2894048145974629, 0.4201988877306557, 0.9398406710693048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 86}], {
             RGBColor[
             0.3574604388898408, 0.48403599850748935`, 0.9439980409695737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 101}], {
             RGBColor[
             0.28740281094428266`, 0.4180946549568002, 0.9397266599229551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 124}], {
             RGBColor[
             0.3070078817138632, 0.43870082736891025`, 0.9408431397001796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 127}], {
             RGBColor[
             0.3222744622049885, 0.4535596740016799, 0.9417560216489524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 137}], {
             RGBColor[
             0.2865741831678942, 0.41722371462578045`, 0.9396794707969347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 161}], {
             RGBColor[
             0.3158101253960152, 0.4479525435733356, 0.9413444144561256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 175}], {
             RGBColor[
             0.3216795898869629, 0.4530444254989581, 0.9417181169108728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 176}], {
             RGBColor[
             0.30857911035131147`, 0.440352288288518, 0.9409326188466578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 187}], {
             RGBColor[
             0.3028942075372073, 0.43437709498723787`, 0.9406088720414547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 193}], {
             RGBColor[
             0.3198238857723562, 0.4514371078652866, 0.9415998730856248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 199}], {
             RGBColor[
             0.29762489558060606`, 0.42883871402717555`, 0.9403087925207747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 20}], {
             RGBColor[
             0.23211977265146783`, 0.3613029766732719, 0.9365302497108459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 28}], {
             RGBColor[
             0.2668075494695581, 0.39776202944116235`, 0.938505667284669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 77}], {
             RGBColor[
             0.26961618509412616`, 0.4007140835603673, 0.9386656149284841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 106}], {
             RGBColor[
             0.25694510996125053`, 0.38739598020314986`, 0.9379440159448427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 112}], {
             RGBColor[
             0.27014379762534146`, 0.4012686377832412, 0.938695661681604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 140}], {
             RGBColor[
             0.27217097999434126`, 0.4033993349838457, 0.9388111067185709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 189}], {
             RGBColor[
             0.23511483918268133`, 0.3644509814957634, 0.9367008143189947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 47}], {
             RGBColor[
             0.38494609227374893`, 0.5078426899995235, 0.9457494024985874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 54}], {
             RGBColor[
             0.295588460550005, 0.42712274502129255`, 0.9401772792428172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 58}], {
             RGBColor[
             0.2912619493997384, 0.4225753074857117, 0.9399308908333093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 61}], {
             RGBColor[
             0.2960837334123488, 0.42764330820172913`, 0.9402054842996372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 73}], {
             RGBColor[
             0.3057525961329822, 0.4378058959624189, 0.9407561117277767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 94}], {
             RGBColor[
             0.36824895343507874`, 0.4933804675600669, 0.9446854755764875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 115}], {
             RGBColor[
             0.2919621879503136, 0.4233113026000546, 0.9399707683828544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 116}], {
             RGBColor[
             0.35397661933935576`, 0.48101848911472117`, 0.9437760550684375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 153}], {
             RGBColor[
             0.4521702655292919, 0.5624670752629113, 0.9510280595422927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 160}], {
             RGBColor[
             0.34254111760690553`, 0.47111363227910186`, 0.9430473950100628]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 174}], {
             RGBColor[
             0.3498905326098686, 0.47747932616232985`, 0.9435156932352192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 188}], {
             RGBColor[
             0.49151222590235866`, 0.5940651201386887, 0.9543587093121076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 33}], {
             RGBColor[
             0.29372081640032377`, 0.4247279965866454, 0.9400867276419496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 34}], {
             RGBColor[
             0.25807475059694696`, 0.38858330413461983`, 0.938008347307892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 44}], {
             RGBColor[
             0.2739128300859531, 0.40523012986980433`, 0.9389103025044521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 50}], {
             RGBColor[
             0.2533169376668154, 0.3835825410822887, 0.9377373969000744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 60}], {
             RGBColor[
             0.25917942342753286`, 0.38974438531986844`, 0.9380712567913769]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 90}], {
             RGBColor[
             0.32617520722218063`, 0.45283835871142575`, 0.9421546927268274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 130}], {
             RGBColor[
             0.2508128361327613, 0.38095057160079043`, 0.9375947920221963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 141}], {
             RGBColor[
             0.31187008513103276`, 0.44044798095241544`, 0.9412431829967022]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 177}], {
             RGBColor[
             0.2790041774695689, 0.41058145878005325`, 0.9392002472059755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 28}], {
             RGBColor[
             0.2600890189665118, 0.39070042790302345`, 0.9381230569116956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 77}], {
             RGBColor[
             0.2628976545910799, 0.3936524820222284, 0.9382830045555108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 106}], {
             RGBColor[
             0.25022657945820426`, 0.38033437866501096`, 0.9375614055718693]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 189}], {
             RGBColor[
             0.2283963086796351, 0.35738937995762443`, 0.9363182039460214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.28199072307706635`, 0.41303118579725295`, 0.9393955660070041]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 46}], {
             RGBColor[
             0.4569720284859443, 0.5663064733841641, 0.9514223432183879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 85}], {
             RGBColor[
             0.3381783439476214, 0.46733481701480994`, 0.9427694029303426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 109}], {
             RGBColor[
             0.32687230511240406`, 0.45754209443377936`, 0.9420489921333002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 132}], {
             RGBColor[
             0.28420798371714023`, 0.41536166731241486`, 0.9395218357203131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 150}], {
             RGBColor[
             0.29956418872733326`, 0.4315020124177601, 0.9403963488781741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 151}], {
             RGBColor[
             0.33403902527338425`, 0.46374954722739153`, 0.9425056492046759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 194}], {
             RGBColor[
             0.33236539581814195`, 0.4622999335123229, 0.9423990070157204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 196}], {
             RGBColor[
             0.4056875246476441, 0.5246714028276624, 0.9473850392149095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 24}], {
             RGBColor[
             0.511674430314928, 0.3239227222549723, 0.5618363636950766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 37}], {
             RGBColor[
             0.517707803293592, 0.3302641797934895, 0.5621799553606361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 38}], {
             RGBColor[
             0.904615065264268, 0.6177018117199344, 0.25397947076312033`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 79}], {
             RGBColor[
             0.5241950050244188, 0.3370826401249345, 0.5625493919022517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 89}], {
             RGBColor[
             0.8492070454595947, 0.37923249083306454`, 0.194754028344504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 118}], {
             RGBColor[
             0.8788646923664576, 0.6380810443549103, 0.5908825042695605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 119}], {
             RGBColor[
             0.7046501145612256, 0.5000420883551641, 0.5745300841594067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 122}], {
             RGBColor[
             0.9186800927700692, 0.6648777817818614, 0.33146523312416354`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 128}], {
             RGBColor[
             0.8670016862310241, 0.46697435659460335`, 0.20987408763836157`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 138}], {
             RGBColor[
             0.8785987668628523, 0.5171715464656945, 0.2194235962745789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 144}], {
             RGBColor[
             0.8504688767152189, 0.38893147880177464`, 0.1959623593799244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 149}], {
             RGBColor[
             0.5389949329250163, 0.35263830271808894`, 0.5633922259016595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 181}], {
             RGBColor[
             0.9143758811781899, 0.66511973430378, 0.5497646458428832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 183}], {
             RGBColor[
             0.8521661685690678, 0.3996097358148414, 0.1974949680494109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 190}], {
             RGBColor[
             0.5120644599282582, 0.3243326681078883, 0.5618585753045587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 192}], {
             RGBColor[
             0.8308704288952353, 0.23828922076278541`, 0.17719486361422723`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 25}], {
             RGBColor[
             0.9862503262702172, 0.9646170985208886, 0.4575613230413248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 43}], {
             RGBColor[
             0.9244722625683395, 0.7076214459861772, 0.37157972421419916`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 49}], {
             RGBColor[
             0.9141583764403114, 0.6283443976324334, 0.3617031352101312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 64}], {
             RGBColor[
             0.8080908888760686, 0.8465853309633324, 0.7529704509533501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 67}], {
             RGBColor[
             0.9058924219372393, 0.564808649157462, 0.35378764784292904`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 87}], {
             RGBColor[
             0.9907768608924232, 0.9889849826208208, 0.6957320893038507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 95}], {
             RGBColor[
             0.9866024805360858, 0.9658049975494172, 0.45892937586547133`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 103}], {
             RGBColor[
             0.928934953541638, 0.7326663131459502, 0.37549070825566344`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 108}], {
             RGBColor[
             0.8874058680057144, 0.9088494378884622, 0.7606689085618024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 129}], {
             RGBColor[
             0.9919194200162629, 0.9837402828928126, 0.4795846817261888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 131}], {
             RGBColor[
             0.9464189057965813, 0.8120568568548516, 0.39007974658807487`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 143}], {
             RGBColor[
             0.9071887956861127, 0.574773145865902, 0.35502905680889496`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 154}], {
             RGBColor[
             0.9900533443030074, 0.9886857899175692, 0.707722631591383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 162}], {
             RGBColor[
             0.9882402059749112, 0.9877215722762983, 0.728168038634343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 27}], {
             RGBColor[
             0.22783801619652955`, 0.3568025791600926, 0.9362864100150281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 37}], {
             RGBColor[
             0.18496037581804925`, 0.31173546052289103`, 0.9338445918272582]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 56}], {
             RGBColor[
             0.1789270014196926, 0.30539400149218693`, 0.9335010000808495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 79}], {
             RGBColor[
             0.1914475775488761, 0.318553920854336, 0.9342140283688739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 89}], {
             RGBColor[
             0.5164596179840519, 0.3607037715624661, 0.5664186648111262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 118}], {
             RGBColor[
             0.5461172648909147, 0.6195523250843118, 0.9625471407361825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 119}], {
             RGBColor[
             0.37190268708568275`, 0.48151336908456555`, 0.9461947206260288]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 125}], {
             RGBColor[
             0.17894341561590066`, 0.30541125385312173`, 0.9335019348450408]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 144}], {
             RGBColor[
             0.5177214492396762, 0.3704027595311762, 0.5676269958465465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 149}], {
             RGBColor[
             0.20624750544947348`, 0.3341095834474904, 0.9350568623682817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 170}], {
             RGBColor[
             0.18064618334875748`, 0.3072009707020641, 0.9335989049484079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 190}], {
             RGBColor[
             0.1793170324527155, 0.3058039488372898, 0.9335232117711809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 195}], {
             RGBColor[
             0.1789270014196926, 0.30539400149218693`, 0.9335010000808495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 197}], {
             RGBColor[
             0.5339219982745609, 0.6098281505161249, 0.9613839453194717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[
             0.9171434396694482, 0.683563770249714, 0.28663285142090683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 49}], {
             RGBColor[
             0.9068295535414201, 0.6042867218959704, 0.2767562624168388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 64}], {
             RGBColor[
             0.8007620659771775, 0.8225276552268693, 0.6680235781600576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 67}], {
             RGBColor[
             0.8985635990383481, 0.540750973420999, 0.26884077504963666`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 87}], {
             RGBColor[
             0.9834480379935321, 0.9649273068843578, 0.6107852165105583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 95}], {
             RGBColor[
             0.9792736576371948, 0.9417473218129542, 0.37398250307217895`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 103}], {
             RGBColor[
             0.9216061306427468, 0.7086086374094871, 0.2905438354623711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 108}], {
             RGBColor[
             0.8800770451068233, 0.8847917621519991, 0.6757220357685101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 129}], {
             RGBColor[
             0.9845905971173718, 0.9596826071563495, 0.39463780893289646`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 131}], {
             RGBColor[
             0.93909008289769, 0.7879991811183886, 0.30513287379478254`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 143}], {
             RGBColor[
             0.8998599727872215, 0.550715470129439, 0.2700821840156026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 154}], {
             RGBColor[
             0.9827245214041163, 0.9646281141811062, 0.6227757587980907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 162}], {
             RGBColor[
             0.9809113830760201, 0.9636638965398352, 0.6432211658410507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 40}], {
             RGBColor[
             0.4439921507491714, 0.557946476502165, 0.9497988277939646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 51}], {
             RGBColor[
             0.3392714220793772, 0.4658216765666159, 0.9429291222497664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 74}], {
             RGBColor[
             0.3495927399015075, 0.4766700360070217, 0.9435169060307154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 80}], {
             RGBColor[
             0.5081499735315052, 0.6100326873138424, 0.9548495666212384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 121}], {
             RGBColor[
             0.46953919243500225`, 0.5786867158238351, 0.9518099844973704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 158}], {
             RGBColor[
             0.3248339638099492, 0.45064699253772245`, 0.9421069303596279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 164}], {
             RGBColor[
             0.34556297092325194`, 0.47243449330876475`, 0.9432874166489127]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.3936636675304358, 0.5153934155287933, 0.9463048786852943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 169}], {
             RGBColor[
             0.3344928369204973, 0.4607990805848347, 0.9426569888942514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 184}], {
             RGBColor[
             0.38376793461067366`, 0.5068222290476936, 0.9456743313341002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 37}], {
             RGBColor[
             0.23387138917519362`, 0.3631440366986098, 0.9366300016805876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 56}], {
             RGBColor[
             0.22783801477683696`, 0.3568025776679057, 0.9362864099341788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 67}], {
             RGBColor[
             0.5474773621295221, 0.27457683969669183`, 0.5520694598597993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 119}], {
             RGBColor[
             0.4208137004428272, 0.5329219452602844, 0.9489801304793581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 125}], {
             RGBColor[
             0.22785442897304503`, 0.35681983002884055`, 0.9362873446983702]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 128}], {
             RGBColor[
             0.5831652721126257, 0.49985421349972364`, 0.5843241339583132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 133}], {
             RGBColor[
             0.5500884366842889, 0.29464670290479555`, 0.5545698278022309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 190}], {
             RGBColor[
             0.22822804580985986`, 0.3572125250130086, 0.9363086216245102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 195}], {
             RGBColor[
             0.22783801477683696`, 0.3568025776679057, 0.9362864099341788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 48}], {
             RGBColor[
             0.30593974734452445`, 0.4381198166210231, 0.9407624779750857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 63}], {
             RGBColor[
             0.3238146353715521, 0.45360214621203954`, 0.941901450034025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 77}], {
             RGBColor[
             0.29758543140917015`, 0.4301115347901189, 0.9402584221293339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 106}], {
             RGBColor[
             0.28491435627629447`, 0.41679343143290143`, 0.9395368231456924]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 112}], {
             RGBColor[
             0.2981130439403854, 0.43066608901299275`, 0.9402884688824538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 140}], {
             RGBColor[
             0.3001402263093852, 0.4327967862135973, 0.9404039139194207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 189}], {
             RGBColor[
             0.26308408549772533`, 0.39384843272551495`, 0.9382936215198444]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 35}], {
             RGBColor[
             0.9160081618564544, 0.9327996859082862, 0.8697305761183244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 47}], {
             RGBColor[
             0.7225823732127437, 0.7785731992059557, 0.8525033535115121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 88}], {
             RGBColor[
             0.8529188119611348, 0.8833651723657042, 0.8634818621932413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 89}], {
             RGBColor[
             0.9238176258477779, 0.703826389599022, 0.47717574667802176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 113}], {
             RGBColor[
             0.946972557498295, 0.8159080843147557, 0.4967685640741427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 122}], {
             RGBColor[
             0.9932906731582525, 0.9894716805478189, 0.6138869514576812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 136}], {
             RGBColor[
             0.950824845750427, 0.8323116913697606, 0.49992668872926316`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 138}], {
             RGBColor[
             0.9532093472510355, 0.8417654452316519, 0.5018453146080967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 142}], {
             RGBColor[
             0.8172660326623933, 0.855490432397475, 0.8599437218958297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 144}], {
             RGBColor[
             0.9250794571034022, 0.713525377567732, 0.47838407771344216`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 153}], {
             RGBColor[
             0.7898065464682866, 0.8331975844693433, 0.8577820105552174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 159}], {
             RGBColor[
             0.9081437399557057, 0.5833500342919629, 0.46216641584665136`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 167}], {
             RGBColor[
             0.9544593958943188, 0.963459656199136, 0.8733980891466777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 181}], {
             RGBColor[
             0.988986461566373, 0.9897136330697374, 0.8321863641764009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 188}], {
             RGBColor[
             0.8291485068413533, 0.8647956293451209, 0.8611126603250323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 41}], {
             RGBColor[
             0.7217306402299773, 0.781717727178925, 0.9737111260908631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 65}], {
             RGBColor[
             0.9079204151899432, 0.9294151105020584, 0.9910794537825813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 66}], {
             RGBColor[
             0.7926835884248224, 0.8385659113515402, 0.9798127368656795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 90}], {
             RGBColor[
             0.6408480095261183, 0.7142786377339077, 0.9678341664939911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 110}], {
             RGBColor[
             0.7493871054318795, 0.8041704915393881, 0.9758883443405271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 162}], {
             RGBColor[
             0.9383242239537981, 0.9524410659335498, 0.9517777399403218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 180}], {
             RGBColor[
             0.8089076786179981, 0.8512402939181014, 0.9814298025533923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 198}], {
             RGBColor[
             0.7949540018905729, 0.840339575606766, 0.9800390304617252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 38}], {
             RGBColor[
             0.9076583192648293, 0.8882942413173389, 0.6516953277782057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[
             0.6710448937244029, 0.7408816350846033, 0.9693608389875064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 46}], {
             RGBColor[
             0.7241254080647266, 0.7839747878759986, 0.9735395315167075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 80}], {
             RGBColor[
             0.7352027165067365, 0.7929678458962808, 0.9744115778147804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 98}], {
             RGBColor[
             0.9119983758560902, 0.9316922814327566, 0.9576824339727095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 117}], {
             RGBColor[
             0.8147533586460658, 0.8554575003050673, 0.9821051874244302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 120}], {
             RGBColor[
             0.9036386065731989, 0.8747348065350462, 0.6360795030302686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 121}], {
             RGBColor[
             0.6965919354102337, 0.7616218744062735, 0.9713719956909121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 146}], {
             RGBColor[
             0.8233014482367667, 0.8621353328612098, 0.9829571811083924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 151}], {
             RGBColor[
             0.6011924048521665, 0.6814178617192261, 0.9646228375029955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 171}], {
             RGBColor[
             0.8624892635832501, 0.8931895434066397, 0.9867461899854671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 173}], {
             RGBColor[
             0.9228248907460509, 0.93782630255951, 0.8490773539223448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 178}], {
             RGBColor[
             0.8964701273649321, 0.9201113391332241, 0.9839677082524034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 196}], {
             RGBColor[
             0.6728409042264264, 0.742339717319497, 0.969502227513229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 53}], {
             RGBColor[
             0.2232819677009355, 0.3520138833210643, 0.9360269497932738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 82}], {
             RGBColor[
             0.27687504662639884`, 0.4074326830017036, 0.9391123497539292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 83}], {
             RGBColor[
             0.2455000054496245, 0.37536644969989263`, 0.9372922341744203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 100}], {
             RGBColor[
             0.22448297168171977`, 0.35327621465291903`, 0.9360953451932534]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 101}], {
             RGBColor[
             0.2434980017964442, 0.3732622169260371, 0.9371782230280707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 123}], {
             RGBColor[
             0.24279155375346242`, 0.3725196952414703, 0.9371379918571192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 127}], {
             RGBColor[
             0.2783696530571501, 0.40872723597091687`, 0.9392075847540681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 130}], {
             RGBColor[
             0.23618787859936186`, 0.36557881395732306`, 0.936761922326355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 135}], {
             RGBColor[
             0.23421532693659433`, 0.36350553709275546`, 0.9366495884272892]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 148}], {
             RGBColor[
             0.219972379693155, 0.3485352964848875, 0.9358384736523275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 163}], {
             RGBColor[
             0.23408691252963393`, 0.3633705654090964, 0.9366422754167848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 165}], {
             RGBColor[
             0.2270272954930984, 0.35595046029812505`, 0.9362402406703216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 176}], {
             RGBColor[
             0.264674301203473, 0.39551985025775493`, 0.9383841819517735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 187}], {
             RGBColor[
             0.2589893983893689, 0.38954465695647483`, 0.9380604351465702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 41}], {
             RGBColor[
             0.4363770738073567, 0.5497722412161976, 0.9497497290534018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 44}], {
             RGBColor[
             0.3032320659672701, 0.4347249229295589, 0.9406283792341544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 57}], {
             RGBColor[
             0.3418089819131736, 0.4704794931394012, 0.9430007439710605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 66}], {
             RGBColor[
             0.5073300220022017, 0.606620425388813, 0.955851339828218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 90}], {
             RGBColor[
             0.35549444310349765`, 0.4823331517711803, 0.9438727694565298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 141}], {
             RGBColor[
             0.3411893210123498, 0.46994277401217005`, 0.9429612597264045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 198}], {
             RGBColor[
             0.5096004354679522, 0.6083940896440386, 0.956077633424264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 44}], {
             RGBColor[
             0.2675860001638932, 0.3985802304775334, 0.9385499989000968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 50}], {
             RGBColor[
             0.2469901077447556, 0.3769326416900177, 0.9373770932957193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 60}], {
             RGBColor[
             0.25285259350547307`, 0.38309448592759754`, 0.9377109531870217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 90}], {
             RGBColor[
             0.31984837730012083`, 0.4461884593191548, 0.9417943891224722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 104}], {
             RGBColor[
             0.2353413665909268, 0.3646890761644966, 0.936713714719777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 130}], {
             RGBColor[
             0.2444860062107015, 0.3743006722085195, 0.9372344884178412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 163}], {
             RGBColor[
             0.24238504014097356`, 0.3720924236602928, 0.9371148415082708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 177}], {
             RGBColor[
             0.27267734754750905`, 0.40393155938778236`, 0.9388399436016203]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 47}], {
             RGBColor[
             0.6449475165023608, 0.7197336460567563, 0.9672187657343465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 68}], {
             RGBColor[
             0.8469990595612139, 0.880838075189855, 0.985268720497577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 88}], {
             RGBColor[
             0.775283955250752, 0.8245256192165048, 0.9781972744160757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 94}], {
             RGBColor[
             0.6282503776636906, 0.7052714236172997, 0.9661548388122466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 111}], {
             RGBColor[
             0.6494345587146366, 0.7234252020636741, 0.9675585260086426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 116}], {
             RGBColor[
             0.6139780435679677, 0.6929094451719539, 0.9652454183041966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 122}], {
             RGBColor[
             0.9156558164478696, 0.9306321273986194, 0.7286023636805157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 138}], {
             RGBColor[
             0.8755744905406526, 0.7829258920824524, 0.6165607268309311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 142}], {
             RGBColor[
             0.7396311759520104, 0.7966508792482756, 0.9746591341186641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 153}], {
             RGBColor[
             0.7121716897579038, 0.7743580313201439, 0.9724974227780518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 157}], {
             RGBColor[
             0.6980290555794366, 0.7628764037756551, 0.971384062809347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 160}], {
             RGBColor[
             0.6025425418355174, 0.6830045883363345, 0.9645167582458221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 167}], {
             RGBColor[
             0.876824539183936, 0.9046201030499366, 0.9881135013695121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 174}], {
             RGBColor[
             0.6098919568384804, 0.6893702822195625, 0.9649850564709783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 181}], {
             RGBColor[
             0.9113516048559902, 0.930874079920538, 0.9469017763992353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 185}], {
             RGBColor[
             0.8039733137479249, 0.8469379641216965, 0.9810567615537757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 188}], {
             RGBColor[
             0.7515136501309705, 0.8059560761959215, 0.9758280725478667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 132}], {
             RGBColor[
             0.24999710016017773`, 0.3800931813729572, 0.937548337065331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 151}], {
             RGBColor[
             0.2998281417164218, 0.4284810612879339, 0.9405321505496939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 169}], {
             RGBColor[
             0.260181316759984, 0.39079743873598083`, 0.9381283131344916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 200}], {
             RGBColor[
             0.24218408124275126`, 0.3718812031167312, 0.9371033971963092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 56}], {
             RGBColor[
             0.18496037439835666`, 0.3117354590307041, 0.9338445917464089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 79}], {
             RGBColor[
             0.19748095052754017`, 0.3248953783928531, 0.9345576200344334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 118}], {
             RGBColor[
             0.5521506378695789, 0.625893782622829, 0.962890732401742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 119}], {
             RGBColor[
             0.3779360600643469, 0.4878548266230827, 0.9465383122915882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 125}], {
             RGBColor[
             0.18497678859456473`, 0.3117527113916389, 0.9338455265106003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 128}], {
             RGBColor[
             0.5402876317341454, 0.454787094862522, 0.5818823157705433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 149}], {
             RGBColor[
             0.21228087842813756`, 0.34045104098600754`, 0.9354004540338412]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 170}], {
             RGBColor[
             0.18667955632742156`, 0.31354242824058126`, 0.9339424966139673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 190}], {
             RGBColor[
             0.18535040543137957`, 0.3121454063758069, 0.9338668034367403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 195}], {
             RGBColor[
             0.18496037439835666`, 0.3117354590307041, 0.9338445917464089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 46}], {
             RGBColor[
             0.7812753615379626, 0.7886327284729578, 0.6396314180362879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 98}], {
             RGBColor[
             0.9691483293293262, 0.9363502220297157, 0.6237743204922899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 117}], {
             RGBColor[
             0.8719033121193018, 0.8601154409020264, 0.6481970739440106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 120}], {
             RGBColor[
             0.960788560046435, 0.8793927471320053, 0.302171389549849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 128}], {
             RGBColor[
             0.9271948937048214, 0.742224726788967, 0.2736818311730274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 146}], {
             RGBColor[
             0.8804514017100027, 0.8667932734581691, 0.6490490676279728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 156}], {
             RGBColor[
             0.9428260097167436, 0.9163360030821683, 0.6550496534880772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 171}], {
             RGBColor[
             0.919639217056486, 0.8978474840035989, 0.6528380765050477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 178}], {
             RGBColor[
             0.9536200808381681, 0.9247692797301834, 0.650059594771984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 179}], {
             RGBColor[
             0.8863710041657746, 0.8714177118872631, 0.6496390782789341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 183}], {
             RGBColor[
             0.9123593760428652, 0.674860106009205, 0.26130271158407675`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 192}], {
             RGBColor[
             0.8910636363690327, 0.5135395909571491, 0.2410026071488931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 114}], {
             RGBColor[
             0.20908858865686974`, 0.3370957420335433, 0.935218657853937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 46}], {
             RGBColor[
             0.5446619359975361, 0.6412201222402223, 0.9572969292455886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 74}], {
             RGBColor[
             0.3971820108095485, 0.5168505289536836, 0.9468363149531384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.555739244439546, 0.6502131802605045, 0.9581689755436615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 117}], {
             RGBColor[
             0.6352898865788753, 0.7127028346692909, 0.9658625851533114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 121}], {
             RGBColor[
             0.5171284633430432, 0.6188672087704971, 0.9551293934197934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 166}], {
             RGBColor[
             0.4412529384384768, 0.5555739084754552, 0.9496242876077174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 169}], {
             RGBColor[
             0.38208210782853824`, 0.5009795735314966, 0.9459763978166744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 171}], {
             RGBColor[
             0.6830257915160596, 0.7504348777708634, 0.9705035877143484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 173}], {
             RGBColor[
             0.7433614186788604, 0.7950716369237336, 0.832834751651226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 196}], {
             RGBColor[
             0.49337743215923585`, 0.5995850516837207, 0.9532596252421102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 57}], {
             RGBColor[
             0.4551460034388895, 0.5660289447091988, 0.9509456686528102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 66}], {
             RGBColor[
             0.6206670435279176, 0.7021698769586107, 0.9637962645099678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 81}], {
             RGBColor[
             0.563023955866433, 0.6561272371693612, 0.9587424547119633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 90}], {
             RGBColor[
             0.46883146462921355`, 0.577882603340978, 0.9518176941382794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 141}], {
             RGBColor[
             0.4545263425380657, 0.5654922255819677, 0.9509061844081543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 168}], {
             RGBColor[
             0.7441532266042006, 0.7995222771759883, 0.9732629767804062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 172}], {
             RGBColor[
             0.7718454040169196, 0.8174234076188627, 0.7717375932565325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 184}], {
             RGBColor[
             0.46042354235664473`, 0.5706000836629397, 0.9512819487659052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 198}], {
             RGBColor[
             0.6229374569936681, 0.7039435412138363, 0.9640225581060137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 88}], {
             RGBColor[
             0.6168180360411716, 0.6987299024450158, 0.9637087446681081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[
             0.401201459999004, 0.517503689481011, 0.9473903200062829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 102}], {
             RGBColor[
             0.4476381958746549, 0.5602937273030086, 0.9502551687958871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 153}], {
             RGBColor[
             0.5537057705483233, 0.648562314548655, 0.9580088930300842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 49}], {
             RGBColor[
             0.8450514898395424, 0.34729106936125886`, 0.19077466358971318`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 67}], {
             RGBColor[
             0.8367855353364704, 0.2837553208862874, 0.18285917622251102`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 87}], {
             RGBColor[
             0.9216699742916543, 0.7079316543496461, 0.5248036176834326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 95}], {
             RGBColor[
             0.9174955939353169, 0.6847516692782425, 0.2880009042450533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 103}], {
             RGBColor[
             0.859828066940869, 0.45161298487477564`, 0.20456223663524548`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 129}], {
             RGBColor[
             0.922812533415494, 0.7026869546216379, 0.30865621010577077`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 131}], {
             RGBColor[
             0.8773120191958123, 0.531003528583677, 0.2191512749676569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 133}], {
             RGBColor[
             0.8393966098912371, 0.3038251840943911, 0.18535954416494269`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 143}], {
             RGBColor[
             0.8380819090853437, 0.29371981759472743`, 0.18410058518847694`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 154}], {
             RGBColor[
             0.9209464577022384, 0.7076324616463945, 0.536794159970965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 197}], {
             RGBColor[
             0.8721411848386535, 0.6704152078814393, 0.5949590715355129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 50}], {
             RGBColor[
             0.2628281872337618, 0.3935794674252022, 0.9382790484922793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 57}], {
             RGBColor[
             0.3220009955988029, 0.4509816264225601, 0.9418243188335629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 60}], {
             RGBColor[
             0.2686906729944792, 0.399741311662782, 0.9386129083835817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 90}], {
             RGBColor[
             0.33568645678912695`, 0.46283528505433924`, 0.9426963443190322]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 141}], {
             RGBColor[
             0.321381334697979, 0.45044490729532893`, 0.941784834588907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 177}], {
             RGBColor[
             0.2885154270365152, 0.4205783851229668, 0.9397418987981803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 120}], {
             RGBColor[
             0.9205644172331103, 0.7168104234407002, 0.25588752113131463`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 128}], {
             RGBColor[
             0.8869707508914968, 0.5796424030976618, 0.22739796275449303`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 168}], {
             RGBColor[
             0.9114761724933723, 0.7607551980488345, 0.6070253886431892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 172}], {
             RGBColor[
             0.9391683499060914, 0.7786563284917088, 0.4055000051193155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 173}], {
             RGBColor[
             0.9397507014059623, 0.7799019194651641, 0.46888537202339087`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 85}], {
             RGBColor[
             0.4789487657995369, 0.5853416186622634, 0.9528226814867443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 98}], {
             RGBColor[
             0.7856154181292234, 0.8320307685883754, 0.9456185242307917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 99}], {
             RGBColor[
             0.5809189759498203, 0.6706552206345228, 0.960151216244546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 109}], {
             RGBColor[
             0.4676427269643195, 0.5755488960812328, 0.9521022706897019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 117}], {
             RGBColor[
             0.6883704009191991, 0.7557959874606861, 0.9700412776825125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 121}], {
             RGBColor[
             0.570208977683367, 0.6619603615618923, 0.9593080859489944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 146}], {
             RGBColor[
             0.6969184905099, 0.7624738200168288, 0.9708932713664746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 151}], {
             RGBColor[
             0.4748094471252997, 0.581756348874845, 0.9525589277610778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 171}], {
             RGBColor[
             0.7361063058563833, 0.7935280305622586, 0.9746822802435494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 178}], {
             RGBColor[
             0.7700871696380653, 0.8204498262888431, 0.9719037985104857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 196}], {
             RGBColor[
             0.5464579464995596, 0.642678204475116, 0.9574383177713113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 54}], {
             RGBColor[
             0.3621640961349061, 0.48478721437619465`, 0.9444194198717641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 61}], {
             RGBColor[
             0.36265936899724993`, 0.48530777755663124`, 0.944447624928584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 73}], {
             RGBColor[
             0.3723282317178833, 0.495470365317321, 0.9449982523567235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 88}], {
             RGBColor[
             0.5818581666070413, 0.6702991325141743, 0.9609700518092634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 94}], {
             RGBColor[
             0.4348245890199799, 0.551044936914969, 0.9489276162054343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 105}], {
             RGBColor[
             0.3973660260121461, 0.5186002123597028, 0.9465407896938819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 111}], {
             RGBColor[
             0.45600877007092583`, 0.5691987153613436, 0.9503313034018304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 116}], {
             RGBColor[
             0.42055225492425696`, 0.5386829584696233, 0.9480181956973843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 126}], {
             RGBColor[
             0.37937335834478547`, 0.5028752400890226, 0.9453994618957948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 142}], {
             RGBColor[
             0.5462053873082997, 0.642424392545945, 0.9574319115118519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 153}], {
             RGBColor[
             0.518745901114193, 0.6201315446178133, 0.9552702001712396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 157}], {
             RGBColor[
             0.5046032669357259, 0.6086499170733246, 0.9541568402025347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 160}], {
             RGBColor[
             0.4091167531918066, 0.528778101634004, 0.9472895356390099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 167}], {
             RGBColor[
             0.6833987505402253, 0.7503936163476059, 0.9708862787627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 174}], {
             RGBColor[
             0.4164661681947697, 0.535143795517232, 0.9477578338641661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 188}], {
             RGBColor[
             0.5580878614872598, 0.6517295894935908, 0.9586008499410545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 59}], {
             RGBColor[
             0.382953798860026, 0.5061170655801353, 0.9456224553239809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 63}], {
             RGBColor[
             0.3349775869314745, 0.46456248216214874`, 0.942565453523592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 77}], {
             RGBColor[
             0.30874838296909257`, 0.4410718707402281, 0.9409224256189008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 106}], {
             RGBColor[
             0.29607730783621694`, 0.42775376738301063`, 0.9402008266352594]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 112}], {
             RGBColor[
             0.3092759955003079, 0.44162642496310195`, 0.9409524723720207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 140}], {
             RGBColor[
             0.3113031778693076, 0.4437571221637065, 0.9410679174089878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 193}], {
             RGBColor[
             0.3168945933506373, 0.44889990200011176`, 0.9414132211627845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 67}], {
             RGBColor[
             0.8264716492084423, 0.20447827253254375`, 0.17298258721844303`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 87}], {
             RGBColor[
             0.9113560881636262, 0.6286546059959026, 0.5149270286793647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 95}], {
             RGBColor[
             0.9071817078072888, 0.605474620924499, 0.27812431524098535`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 103}], {
             RGBColor[
             0.8495141808128409, 0.372335936521032, 0.19468564763117746`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 108}], {
             RGBColor[
             0.8079850952769174, 0.5485190612635439, 0.5798638479373164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 129}], {
             RGBColor[
             0.9124986472874659, 0.6234099062678943, 0.2987796211017028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 131}], {
             RGBColor[
             0.8669981330677842, 0.45172648022993345`, 0.2092746859635889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 133}], {
             RGBColor[
             0.829082723763209, 0.22454813574064747`, 0.1754829551608747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 143}], {
             RGBColor[
             0.8277680229573157, 0.2144427692409838, 0.17422399618440892`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 154}], {
             RGBColor[
             0.9106325715742103, 0.628355413292651, 0.5269175709668971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 162}], {
             RGBColor[
             0.9088194332461141, 0.62739119565138, 0.547362978009857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 53}], {
             RGBColor[
             0.22682228238214364`, 0.3557349785199296, 0.9362285654769424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 60}], {
             RGBColor[
             0.24809478057534154`, 0.3780937228752663, 0.9374400027792041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 82}], {
             RGBColor[
             0.28041536130760697`, 0.41115377820056886`, 0.9393139654375977]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 100}], {
             RGBColor[
             0.2280232863629279, 0.35699730985178435`, 0.9362969608769219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 104}], {
             RGBColor[
             0.2305835536607953, 0.3596883131121654, 0.9364427643119595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 123}], {
             RGBColor[
             0.24633186843467056`, 0.37624079044033565`, 0.9373396075407877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.23972819328057, 0.3692999091561883, 0.9369635380100236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 163}], {
             RGBColor[
             0.23762722721084206`, 0.36709166060796167`, 0.9368438911004533]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 177}], {
             RGBColor[
             0.2679195346173776, 0.39893079633545114`, 0.9385689931938027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 71}], {
             RGBColor[
             0.2862116459129269, 0.41815696509391576`, 0.9396107018713307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 74}], {
             RGBColor[
             0.29246128213975436`, 0.4247257290181345, 0.9399666094089402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 158}], {
             RGBColor[
             0.267702506048196, 0.39870268554883526`, 0.9385566337378528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 164}], {
             RGBColor[
             0.28843151316149873`, 0.42049018631987756`, 0.9397371200271375]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 166}], {
             RGBColor[
             0.33653220976868264`, 0.46344910853990606`, 0.9427545820635193]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 184}], {
             RGBColor[
             0.3266364768489205, 0.4548779220588064, 0.942124034712325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 70}], {
             RGBColor[
             0.2130689137116028, 0.34127931603325223`, 0.9354453314774407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 134}], {
             RGBColor[
             0.22165741455534713`, 0.35030637496243233`, 0.9359344338949436]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 145}], {
             RGBColor[
             0.21010927874609994`, 0.3381685520328137, 0.9352767846445429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 100}], {
             RGBColor[
             0.21261327393044743`, 0.34080040973402737`, 0.9354193834659627]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 104}], {
             RGBColor[
             0.21517354122831484`, 0.34349141299440844`, 0.9355651869010002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 123}], {
             RGBColor[
             0.2309218560021901, 0.36004389032257866`, 0.9364620301298284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 130}], {
             RGBColor[
             0.22431818084808952`, 0.35310300903843134`, 0.9360859605990643]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 135}], {
             RGBColor[
             0.222345629185322, 0.35102973217386374`, 0.9359736266999984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 148}], {
             RGBColor[
             0.20810268194188267`, 0.3360594915659958, 0.9351625119250367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 163}], {
             RGBColor[
             0.2222172147783616, 0.3508947604902047, 0.935966313689494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 165}], {
             RGBColor[
             0.21515759774182608`, 0.3434746553792333, 0.935564278943031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 58}], {
             RGBColor[
             0.2684799532608956, 0.3995198318623828, 0.9386009082064859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 61}], {
             RGBColor[
             0.27330173727350593`, 0.40458783257840025`, 0.9388755016728139]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 73}], {
             RGBColor[
             0.28297059999413937`, 0.41475042033909004`, 0.9394261291009534]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 94}], {
             RGBColor[
             0.3454669572962359, 0.47032499193673805`, 0.9433554929496641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 105}], {
             RGBColor[
             0.3080083942884021, 0.4378802673814718, 0.9409686664381117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 115}], {
             RGBColor[
             0.2691801918114708, 0.40025582697672574`, 0.938640785756031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 116}], {
             RGBColor[
             0.33119462320051296`, 0.4579630134913923, 0.9424460724416142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 126}], {
             RGBColor[
             0.29001572662104147`, 0.4221552951107917, 0.9398273386400247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 160}], {
             RGBColor[
             0.3197591214680627, 0.448058156655773, 0.9417174123832397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 174}], {
             RGBColor[
             0.3271085364710258, 0.454423850539001, 0.942185710608396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 62}], {
             RGBColor[
             0.35430836392456, 0.4813058296004574, 0.9437971935400564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 68}], {
             RGBColor[
             0.6040034340544339, 0.6836766872491769, 0.9648829517187356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 72}], {
             RGBColor[
             0.3011292819316679, 0.4298018950317811, 0.9406079602011264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 75}], {
             RGBColor[
             0.3182717437982659, 0.44781970934843396`, 0.9415841980444295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 76}], {
             RGBColor[
             0.31436618073050393`, 0.4437147149372155, 0.9413617820054831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 96}], {
             RGBColor[
             0.32928937279498216`, 0.459399935982008, 0.942211635716671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 107}], {
             RGBColor[
             0.5098065457970684, 0.609801290788619, 0.955570731517623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 111}], {
             RGBColor[
             0.40643893320785657`, 0.5262638141229958, 0.9471727572298012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 139}], {
             RGBColor[
             0.3007701310464627, 0.42942440467994913`, 0.9405875070895301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 147}], {
             RGBColor[
             0.41653896028796467`, 0.5344634711076623, 0.9479678683591656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 157}], {
             RGBColor[
             0.4550334300726567, 0.5657150158349769, 0.9509982940305055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 182}], {
             RGBColor[
             0.30875284137949693`, 0.43781473937303605`, 0.9410421106336347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 185}], {
             RGBColor[
             0.5609776882411449, 0.6497765761810184, 0.9606709927749343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 191}], {
             RGBColor[
             0.31630641834476525`, 0.445754027687974, 0.9414722756672911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 79}], {
             RGBColor[
             0.1914475761291835, 0.31855391936214905`, 0.9342140282880245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 118}], {
             RGBColor[
             0.5461172634712221, 0.619552323592125, 0.9625471406553332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 119}], {
             RGBColor[
             0.37190268566599016`, 0.4815133675923786, 0.9461947205451795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 125}], {
             RGBColor[
             0.17894341419620807`, 0.3054112523609348, 0.9335019347641915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 129}], {
             RGBColor[
             0.5845933454317087, 0.6420998957641366, 0.6750810838088802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 149}], {
             RGBColor[
             0.2062475040297809, 0.3341095819553035, 0.9350568622874322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 170}], {
             RGBColor[
             0.1806461819290649, 0.30720096920987716`, 0.9335989048675586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 190}], {
             RGBColor[
             0.1793170310330229, 0.30580394734510286`, 0.9335232116903315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 195}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 197}], {
             RGBColor[
             0.5339219968548683, 0.6098281490239381, 0.9613839452386224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 66}], {
             RGBColor[
             0.5260989516337345, 0.6228771288818142, 0.9570472794276266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 71}], {
             RGBColor[
             0.32543061952646807`, 0.4545863786212526, 0.9420196308425695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 81}], {
             RGBColor[
             0.4684558639722499, 0.5768344890925647, 0.951993469629622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 90}], {
             RGBColor[
             0.37426337273503046`, 0.49858985526418154`, 0.9450687090559382]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 141}], {
             RGBColor[
             0.35995825064388254`, 0.48619947750517123`, 0.9441571993258131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 198}], {
             RGBColor[
             0.528369365099485, 0.6246507931370399, 0.9572735730236723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 61}], {
             RGBColor[
             0.26897522612323943`, 0.4000403950428194, 0.9386291132633059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 73}], {
             RGBColor[
             0.2786440888438728, 0.4102029828035092, 0.9391797406914454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 92}], {
             RGBColor[
             0.24643437763355744`, 0.3763485341078243, 0.9373454452880156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 115}], {
             RGBColor[
             0.2648536806612042, 0.3957083894411449, 0.9383943973465231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 155}], {
             RGBColor[
             0.25688825427596124`, 0.3873362212730521, 0.9379407780976758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 154}], {
             RGBColor[
             0.7176662191262557, 0.7759253920834623, 0.911377748265729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 186}], {
             RGBColor[
             0.36541764511564734`, 0.4884580900498052, 0.9445955073983169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 193}], {
             RGBColor[
             0.38274569330621644`, 0.5059368150091147, 0.9456091950221126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.2862778470683244, 0.4173156224381487, 0.9396478253289002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 104}], {
             RGBColor[
             0.23644603942151277`, 0.3658501573497452, 0.9367766242032618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 123}], {
             RGBColor[
             0.252194354195388, 0.3824026346779154, 0.9376734674320901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 130}], {
             RGBColor[
             0.2455906790412874, 0.3754617533937681, 0.9372973979013259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 163}], {
             RGBColor[
             0.24348971297155947`, 0.37325350484554143`, 0.9371777509917558]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 177}], {
             RGBColor[
             0.273782020378095, 0.40509264057303096`, 0.9389028530851051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 73}], {
             RGBColor[
             0.28346587285648317`, 0.41527098351952657`, 0.9394543341577734]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 94}], {
             RGBColor[
             0.34596223015857974`, 0.47084555511717463`, 0.9433836980064841]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 105}], {
             RGBColor[
             0.30850366715074595`, 0.4384008305619083, 0.9409968714949317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 115}], {
             RGBColor[
             0.2696754646738146, 0.40077639015716227`, 0.938668990812851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 116}], {
             RGBColor[
             0.3316898960628568, 0.4584835766718288, 0.9424742774984342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 160}], {
             RGBColor[
             0.3202543943304065, 0.44857871983620956`, 0.9417456174400596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 174}], {
             RGBColor[
             0.3276038093333696, 0.4549444137194375, 0.9422139156652158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 68}], {
             RGBColor[
             0.6059297438464823, 0.6853451599719039, 0.965005694475316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 75}], {
             RGBColor[
             0.3201980535903144, 0.44948818207116104`, 0.9417069408010099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 76}], {
             RGBColor[
             0.3162924905225524, 0.44538318765994256`, 0.9414845247620637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 96}], {
             RGBColor[
             0.33121568258703066`, 0.4610684087047351, 0.9423343784732514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 105}], {
             RGBColor[
             0.3497224989411253, 0.4773337838440822, 0.9435049862784333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 107}], {
             RGBColor[
             0.5117328555891169, 0.611469763511346, 0.9556934742742034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 111}], {
             RGBColor[
             0.40836524299990506`, 0.527932286845723, 0.9472954999863816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 116}], {
             RGBColor[
             0.37290872785323614`, 0.4974165299540027, 0.9449823922819357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 126}], {
             RGBColor[
             0.33172983127376465`, 0.4616088115734021, 0.9423636584803461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 157}], {
             RGBColor[
             0.4569597398647052, 0.567383488557704, 0.951121036787086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 174}], {
             RGBColor[
             0.36882264112374896`, 0.4938773670016114, 0.9447220304487174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 182}], {
             RGBColor[
             0.31067915117154543`, 0.43948321209576313`, 0.9411648533902153]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 185}], {
             RGBColor[
             0.5629039980331934, 0.6514450489037454, 0.9607937355315148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 191}], {
             RGBColor[
             0.3182327281368137, 0.4474225004107011, 0.9415950184238715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 77}], {
             RGBColor[
             0.3266232709961202, 0.4565542003312445, 0.9420613976778401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 91}], {
             RGBColor[
             0.5953350475574752, 0.6767809281925967, 0.9640487060966569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 102}], {
             RGBColor[
             0.3633436999904507, 0.48913178357153686`, 0.9443729171645411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 106}], {
             RGBColor[
             0.3139521958632445, 0.44323609697402705`, 0.9413397986941987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 112}], {
             RGBColor[
             0.32715088352733546`, 0.45710875455411837`, 0.94209144443096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 140}], {
             RGBColor[
             0.32917806589633525`, 0.4592394517547229, 0.942206889467927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 69}], {
             RGBColor[
             0.512094113243802, 0.613375440560194, 0.9551211815778647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 82}], {
             RGBColor[
             0.4706005281918093, 0.5774357827163821, 0.9524772470296884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 86}], {
             RGBColor[
             0.5072811113074129, 0.6092066601914048, 0.9548145013504485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 87}], {
             RGBColor[
             0.8052886005993835, 0.8468955393268014, 0.9061943444225835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 108}], {
             RGBColor[
             0.7019176077126746, 0.7667599945944428, 0.9711311636805353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 110}], {
             RGBColor[
             0.6138148271599528, 0.6973615545881173, 0.9627408981532811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 127}], {
             RGBColor[
             0.4720951346225606, 0.5787303356855954, 0.9525724820298272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 154}], {
             RGBColor[
             0.8045650840099676, 0.8465963466235498, 0.9181848867101159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 161}], {
             RGBColor[
             0.4656307978135873, 0.573123205257251, 0.9521608748370004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 162}], {
             RGBColor[
             0.8027519456818715, 0.845632128982279, 0.9386302937530759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 175}], {
             RGBColor[
             0.4715002623045349, 0.5782150871828736, 0.9525345772917476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 176}], {
             RGBColor[
             0.45839978276888355`, 0.5655229499724335, 0.9517490792275327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 180}], {
             RGBColor[
             0.6733354003460714, 0.7444313569668306, 0.9682823563661463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 66}], {
             RGBColor[
             0.8068568184878835, 0.8498672602817441, 0.9811645922016861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 69}], {
             RGBColor[
             0.6618396215787897, 0.7314857264416685, 0.9696204831011173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 87}], {
             RGBColor[
             0.9550341089343712, 0.965005825208276, 0.9206936459458361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 90}], {
             RGBColor[
             0.6550212395891795, 0.7255799866641114, 0.9691860218299977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 110}], {
             RGBColor[
             0.7635603354949406, 0.815471840469592, 0.9772401996765336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 131}], {
             RGBColor[
             0.9106761538385292, 0.7880776994423069, 0.6150413032300603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 133}], {
             RGBColor[
             0.872760744533954, 0.5608993549530209, 0.5812495724273461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 162}], {
             RGBColor[
             0.9524974540168591, 0.9637424148637534, 0.9531295952763283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 180}], {
             RGBColor[
             0.8230809086810591, 0.8625416428483053, 0.9827816578893989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 198}], {
             RGBColor[
             0.809127231953634, 0.8516409245369697, 0.9813908857977319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 81}], {
             RGBColor[
             0.633976904061278, 0.7129754213419766, 0.9648440654867796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 90}], {
             RGBColor[
             0.5397844128240585, 0.6347307875135932, 0.9579193049130958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 141}], {
             RGBColor[
             0.5254792907329107, 0.622340409754583, 0.9570077951829706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 168}], {
             RGBColor[
             0.8151061747990456, 0.8563704613486036, 0.9793645875552226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 172}], {
             RGBColor[
             0.8427983522117647, 0.874271591791478, 0.7778392040313489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 198}], {
             RGBColor[
             0.6938904051885131, 0.7607917253864516, 0.97012416888083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 87}], {
             RGBColor[
             0.9030901336605541, 0.565118857520931, 0.5070115413121625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 103}], {
             RGBColor[
             0.8412482263097689, 0.30880018804606046`, 0.1867701602639753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 129}], {
             RGBColor[
             0.9042326927843938, 0.5598741577929227, 0.2908641337345006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 131}], {
             RGBColor[
             0.8587321785647122, 0.38819073175496194`, 0.20135919859638673`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 133}], {
             RGBColor[
             0.820816769260137, 0.16101238726567596`, 0.16756746779367254`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 143}], {
             RGBColor[
             0.8195020684542436, 0.15090702076601228`, 0.16630850881720677`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 162}], {
             RGBColor[
             0.9005534787430421, 0.5638554471764086, 0.5394474906426548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 107}], {
             RGBColor[
             0.7614279257189907, 0.8138406211600655, 0.9767792324528825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 111}], {
             RGBColor[
             0.6580603131297789, 0.7303031444944423, 0.9683812581650608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 122}], {
             RGBColor[
             0.924281570863012, 0.9375100698293877, 0.7294250958369339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 138}], {
             RGBColor[
             0.8842002449557951, 0.7898038345132208, 0.6173834589873493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 142}], {
             RGBColor[
             0.7482569303671527, 0.8035288216790438, 0.9754818662750824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 147}], {
             RGBColor[
             0.668160340209887, 0.7385028014791089, 0.9691763692944251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 156}], {
             RGBColor[
             0.8882342803358891, 0.9137179209353309, 0.9892017726661817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 157}], {
             RGBColor[
             0.7066548099945791, 0.7697543462064234, 0.9722067949657651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 179}], {
             RGBColor[
             0.8317792747849202, 0.8687996297404257, 0.9837911974570385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 181}], {
             RGBColor[
             0.9199773592711327, 0.9377520223513063, 0.9477245085556535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 185}], {
             RGBColor[
             0.8125990681630673, 0.8538159065524649, 0.9818794937101938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 82}], {
             RGBColor[
             0.3600920128525825, 0.48631533560726303`, 0.9441657225354702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 86}], {
             RGBColor[
             0.39677259596818604`, 0.5180862130822859, 0.9465029768562303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 90}], {
             RGBColor[
             0.3947672159149649, 0.5163492536735178, 0.946375195812527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 110}], {
             RGBColor[
             0.503306311820726, 0.6062411074789984, 0.9544293736590629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 123}], {
             RGBColor[
             0.3260085199796461, 0.4514023478470298, 0.9421913646386602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 127}], {
             RGBColor[
             0.3615866192833338, 0.48760988857647636`, 0.944260957535609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 177}], {
             RGBColor[
             0.3475961861623531, 0.47409235374214537`, 0.9434207502916752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 180}], {
             RGBColor[
             0.5628268850068445, 0.6533109098577117, 0.9599708318719281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 72}], {
             RGBColor[
             0.23177582019152226`, 0.36094146083002354`, 0.936510662127084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 93}], {
             RGBColor[
             0.21891136206643785`, 0.34742009968680476`, 0.9357780502681208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 134}], {
             RGBColor[
             0.2222636314959646, 0.3509435474033953, 0.9359689570528942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 139}], {
             RGBColor[
             0.23141666930631707`, 0.36056397047819155`, 0.9364902090154877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.2107154956867174, 0.33880572447377666`, 0.9353113078024935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 81}], {
             RGBColor[
             0.43330857195401157`, 0.5446846710814149, 0.9498164169017225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 164}], {
             RGBColor[
             0.2925031947568016, 0.42476978183606456`, 0.9399689962704769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 184}], {
             RGBColor[
             0.3307081584442233, 0.45915751757499346`, 0.9423559109556644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 75}], {
             RGBColor[
             0.26701897159742227`, 0.39798424750248473`, 0.9385177074620799]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 84}], {
             RGBColor[
             0.256326539038239, 0.386745822943403, 0.9379087892458708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 93}], {
             RGBColor[
             0.23701205160573985`, 0.3664450720426131, 0.9368088577598136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 134}], {
             RGBColor[
             0.2403643210352666, 0.36996851975920364`, 0.9369997645445869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 139}], {
             RGBColor[
             0.24951735884561907`, 0.3795889428339999, 0.9375210165071806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 152}], {
             RGBColor[
             0.2658080334878341, 0.396711474771397, 0.9384487463281612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 191}], {
             RGBColor[
             0.2650536461439216, 0.3959185658420248, 0.9384057850849414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 94}], {
             RGBColor[
             0.35563109287921313`, 0.4810081428778644, 0.9439343254346236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 115}], {
             RGBColor[
             0.27934432739444803`, 0.41093897791785206`, 0.9392196182409905]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 153}], {
             RGBColor[
             0.4395524049734263, 0.5500947505807087, 0.9502769094004289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 160}], {
             RGBColor[
             0.3299232570510399, 0.45874130759689935`, 0.9422962448681991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 80}], {
             RGBColor[
             0.46133983359188224`, 0.5689367397653611, 0.9518870537804123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 158}], {
             RGBColor[
             0.2780238238703263, 0.40955104498924105`, 0.9391444175188017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 164}], {
             RGBColor[
             0.29875283098362904`, 0.4313385457602833, 0.9403249038080864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 166}], {
             RGBColor[
             0.34685352759081295`, 0.47429746798031186`, 0.9433423658444682]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 169}], {
             RGBColor[
             0.28768269698087445`, 0.4197031330363533, 0.9396944760534252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 184}], {
             RGBColor[
             0.3369577946710508, 0.46572628149921225`, 0.9427118184932739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 76}], {
             RGBColor[
             0.2802558703962583, 0.4118970674079191, 0.9392715292664366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 96}], {
             RGBColor[
             0.29517906246073655`, 0.4275822884527116, 0.9401213829776245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 134}], {
             RGBColor[
             0.2575067829018646, 0.3879863340758565, 0.93797600238789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 139}], {
             RGBColor[
             0.26665982071221705`, 0.39760675715065275`, 0.9384972543504835]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 182}], {
             RGBColor[
             0.27464253104525127`, 0.40599709184373967`, 0.9389518578945881]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 191}], {
             RGBColor[
             0.2821961080105196, 0.4139363801586776, 0.9393820229282445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.2912734993929746, 0.42347729404149315`, 0.9398989669386781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 105}], {
             RGBColor[
             0.3097803157470692, 0.4397426691808402, 0.94106957474386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 111}], {
             RGBColor[
             0.368423059805849, 0.49034117218248097`, 0.9448600884518084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 116}], {
             RGBColor[
             0.3329665446591801, 0.4598254152907607, 0.9425469807473624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 126}], {
             RGBColor[
             0.2917876480797086, 0.4240176969101601, 0.9399282469457728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 174}], {
             RGBColor[
             0.3288804579296929, 0.4562862523383694, 0.9422866189141441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 182}], {
             RGBColor[
             0.27073696797748936`, 0.4018920974325212, 0.938729441855642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 191}], {
             RGBColor[
             0.2782905449427576, 0.40983138574745914`, 0.9391596068892982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 102}], {
             RGBColor[
             0.33711449602806876`, 0.4656411721496162, 0.9427298892598499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 106}], {
             RGBColor[
             0.2877229919008626, 0.4197454855521064, 0.9396967707895075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 112}], {
             RGBColor[
             0.3009216795649535, 0.4336181431321977, 0.9404484165262689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 140}], {
             RGBColor[
             0.3029488619339533, 0.43574884033280226`, 0.9405638615632359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 189}], {
             RGBColor[
             0.2658927211222934, 0.3968004868447199, 0.9384535691636595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 91}], {
             RGBColor[
             0.8828910750951913, 0.909457394113841, 0.9886921329803882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 95}], {
             RGBColor[
             0.9537951709684989, 0.944166482218568, 0.6841709176231596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 113}], {
             RGBColor[
             0.9141333132318434, 0.7927873365838396, 0.6157566218013946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 136}], {
             RGBColor[
             0.9179856014839756, 0.8091909436388446, 0.6189147464565151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 89}], {
             RGBColor[
             0.5289801926935428, 0.3738636894324282, 0.5671316930183012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 118}], {
             RGBColor[
             0.5586378396004057, 0.632712242954274, 0.9632601689433578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 119}], {
             RGBColor[
             0.3844232617951737, 0.4946732869545277, 0.9469077488332039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 125}], {
             RGBColor[
             0.19146399032539158`, 0.3185711717230839, 0.934214963052216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 128}], {
             RGBColor[
             0.5467748334649722, 0.46160555519396695`, 0.5822517523121589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 144}], {
             RGBColor[
             0.5302420239491671, 0.38356267740113825`, 0.5683400240537216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 149}], {
             RGBColor[
             0.21876808015896437`, 0.34726950131745254`, 0.9357698905754568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 159}], {
             RGBColor[
             0.5133063068014707, 0.25338733412536907`, 0.5521223621869309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 170}], {
             RGBColor[
             0.1931667580582484, 0.32036088857202627`, 0.934311933155583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 190}], {
             RGBColor[
             0.19183760716220638`, 0.3189638667072519, 0.9342362399783559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 192}], {
             RGBColor[
             0.5106435761291835, 0.23292041936214905`, 0.5495725282880245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 195}], {
             RGBColor[
             0.1914475761291835, 0.31855391936214905`, 0.9342140282880245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 197}], {
             RGBColor[
             0.5464425729840517, 0.6229880683860871, 0.9620969735266468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 81}], {
             RGBColor[
             0.5981154418108365, 0.6846160863124545, 0.9615049850298553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 117}], {
             RGBColor[
             0.699447709361209, 0.7647890454809683, 0.9709133239805854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 120}], {
             RGBColor[
             0.7883329572883422, 0.7840663517109472, 0.6248876395864237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 121}], {
             RGBColor[
             0.5812862861253769, 0.6709534195821745, 0.9601801322470673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 166}], {
             RGBColor[
             0.5054107612208105, 0.6076601192871327, 0.9546750264349914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 168}], {
             RGBColor[
             0.7792447125486042, 0.8280111263190817, 0.9760255070982982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 172}], {
             RGBColor[
             0.8069368899613232, 0.8459122567619559, 0.7745001235744244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 173}], {
             RGBColor[
             0.807519241461194, 0.8471578477354111, 0.8378854904784999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 184}], {
             RGBColor[
             0.4955150283010483, 0.599088932806033, 0.9540444790837972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 164}], {
             RGBColor[
             0.43552843920258344`, 0.5470178923073767, 0.9499428350575294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 166}], {
             RGBColor[
             0.4836291358097673, 0.5899768145274054, 0.9529602970939112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 168}], {
             RGBColor[
             0.7574630871375609, 0.8103278215593543, 0.974310777757218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 172}], {
             RGBColor[
             0.7851552645502801, 0.8282289520022286, 0.7727853942333442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 173}], {
             RGBColor[
             0.7857376160501509, 0.8294745429756838, 0.8361707611374197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 184}], {
             RGBColor[
             0.47373340289000515`, 0.5814056280463057, 0.952329749742717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 198}], {
             RGBColor[
             0.6362473175270285, 0.7147490855972023, 0.9650703590828255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 86}], {
             RGBColor[
             0.3552790109161934, 0.48214655523847394`, 0.943859042308054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 101}], {
             RGBColor[
             0.2852213829706352, 0.4162052116877847, 0.9395876612614353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 110}], {
             RGBColor[
             0.4618127267687334, 0.5703014496351865, 0.9517854391108865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 123}], {
             RGBColor[
             0.28451493492765345`, 0.4154626900032179, 0.9395474300904838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 127}], {
             RGBColor[
             0.32009303423134106`, 0.45167023073266444`, 0.9416170229874327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 130}], {
             RGBColor[
             0.27791125977355285`, 0.4085218087190706, 0.9391713605597196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 163}], {
             RGBColor[
             0.2758102937038249, 0.40631356017084397`, 0.9390517136501494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 176}], {
             RGBColor[
             0.30639768237766407`, 0.4384628450195025, 0.9407936201851381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 177}], {
             RGBColor[
             0.3061026011103605, 0.4381526958983335, 0.9407768157434988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 180}], {
             RGBColor[
             0.5213332999548519, 0.6173712520138998, 0.9573268973237518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 187}], {
             RGBColor[
             0.3007127795635599, 0.4324876517182224, 0.9404698733799348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 86}], {
             RGBColor[
             0.32390396973941904`, 0.450080321936663, 0.9420389267285452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 101}], {
             RGBColor[
             0.2538463417938609, 0.3841389783859738, 0.9377675456819266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 124}], {
             RGBColor[
             0.2734514125634414, 0.4047451507980839, 0.9388840254591511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 135}], {
             RGBColor[
             0.244563666934011, 0.3743822985526921, 0.9372389110811449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 137}], {
             RGBColor[
             0.2530177140174724, 0.383268038054954, 0.9377203565559061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 161}], {
             RGBColor[
             0.28225365624559345`, 0.41399686700250915`, 0.9393853002150969]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 165}], {
             RGBColor[
             0.2373756354905151, 0.36682722175806165`, 0.9368295633241774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 175}], {
             RGBColor[
             0.2881231207365411, 0.41908874892813175`, 0.9397590026698441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 176}], {
             RGBColor[
             0.2750226412008897, 0.4063966117176916, 0.9389735046056292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 187}], {
             RGBColor[
             0.26933773838678554`, 0.40042141841641143`, 0.938649757800426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 199}], {
             RGBColor[
             0.2640684264301843, 0.3948830374563491, 0.938349678279746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 93}], {
             RGBColor[
             0.24346208091315458`, 0.3732244618001842, 0.9371761773869076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 139}], {
             RGBColor[
             0.25596738815303377`, 0.386368332591571, 0.9378883361342745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 152}], {
             RGBColor[
             0.2722580627952489, 0.4034908645289682, 0.9388160659552552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 194}], {
             RGBColor[
             0.30565287667395435`, 0.4349127039944547, 0.9408525291212098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 99}], {
             RGBColor[
             0.4621252914114974, 0.5716835642651686, 0.9514982759565006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 109}], {
             RGBColor[
             0.34884904242599657`, 0.47657723971187865`, 0.9434493304016565]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 132}], {
             RGBColor[
             0.3061847210307328, 0.43439681259051416`, 0.9409221739886695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 146}], {
             RGBColor[
             0.578124805971577, 0.6635021636474746, 0.9622403310784291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 150}], {
             RGBColor[
             0.3215409260409259, 0.45053715769585945`, 0.9417966871465304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 151}], {
             RGBColor[
             0.35601576258697687`, 0.48278469250549083`, 0.9439059874730323]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 152}], {
             RGBColor[
             0.320947319253029, 0.44991323932493577`, 0.9417628821181223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 194}], {
             RGBColor[
             0.35434213313173446`, 0.48133507879042225`, 0.9437993452840767]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 196}], {
             RGBColor[
             0.42766426196123664`, 0.5437065481057618, 0.9487853774832657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 101}], {
             RGBColor[
             0.3219019660862388, 0.44797608916280746`, 0.9419249155821955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 108}], {
             RGBColor[
             0.5865960904370586, 0.6714707671165345, 0.9625129589589009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 110}], {
             RGBColor[
             0.49849330988433693`, 0.6020723271102092, 0.9541226934316467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 124}], {
             RGBColor[
             0.3415070368558193, 0.46858226157491756`, 0.94304139535942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 127}], {
             RGBColor[
             0.3567736173469446, 0.48344110820768715`, 0.9439542773081928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 161}], {
             RGBColor[
             0.35030928053797133`, 0.47783397777934283`, 0.943542670115366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 175}], {
             RGBColor[
             0.356178745028919, 0.4829258597049654, 0.9439163725701132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 176}], {
             RGBColor[
             0.3430782654932676, 0.4702337224945253, 0.9431308745058982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 180}], {
             RGBColor[
             0.5580138830704554, 0.6491421294889225, 0.9596641516445119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 187}], {
             RGBColor[
             0.3373933626791634, 0.4642585291932452, 0.9428071277006951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 199}], {
             RGBColor[
             0.3321240507225622, 0.4587201482331828, 0.9425070481800151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 95}], {
             RGBColor[
             0.9838001922594006, 0.9661152059128862, 0.6121532693347048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 103}], {
             RGBColor[
             0.9261326652649529, 0.7329765215094193, 0.5287146017248969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 108}], {
             RGBColor[
             0.8846035797290293, 0.9091596462519311, 0.913892802031036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 110}], {
             RGBColor[
             0.7965007991763076, 0.8397612062456058, 0.9055025365037817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 131}], {
             RGBColor[
             0.9436166175198961, 0.8123670652183208, 0.5433036400573084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 143}], {
             RGBColor[
             0.9043865074094275, 0.5750833542293711, 0.5082529502781284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 154}], {
             RGBColor[
             0.9872510560263222, 0.9889959982810382, 0.8609465250606165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 162}], {
             RGBColor[
             0.9854379176982261, 0.9880317806397674, 0.8813919321035765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 180}], {
             RGBColor[
             0.8560213723624259, 0.8868310086243191, 0.9110439947166469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 94}], {
             RGBColor[
             0.5651610277683712, 0.6558369100747177, 0.9599061248871635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 102}], {
             RGBColor[
             0.5430147651889159, 0.6366549305319157, 0.9584949846187718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[
             0.8062483508925926, 0.7076340176229743, 0.6052352623718941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 122}], {
             RGBColor[
             0.8525664665525501, 0.8811976138560375, 0.7223536497554326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 136}], {
             RGBColor[
             0.8101006391447247, 0.7240376246779792, 0.6083933870270145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 142}], {
             RGBColor[
             0.6765418260566909, 0.7472163657056936, 0.968410420193581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 153}], {
             RGBColor[
             0.6490823398625842, 0.7249235177775619, 0.9662487088529688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 167}], {
             RGBColor[
             0.8137351892886164, 0.8551855895073546, 0.9818647874444291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 188}], {
             RGBColor[
             0.688424300235651, 0.7565215626533395, 0.9695793586227837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 113}], {
             RGBColor[
             0.8771471647792357, 0.528095234856292, 0.21892914685667453`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 118}], {
             RGBColor[
             0.8836498800355815, 0.6748620936624041, 0.59546480538561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 122}], {
             RGBColor[
             0.9234652804391932, 0.7016588310893552, 0.3360475342402131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 136}], {
             RGBColor[
             0.8809994530313677, 0.5444988419112969, 0.222087271511795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 138}], {
             RGBColor[
             0.8833839545319762, 0.5539525957731882, 0.22400589739062848`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 144}], {
             RGBColor[
             0.8552540643843429, 0.4257125281092684, 0.20054466049597394`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 149}], {
             RGBColor[
             0.5437801205941402, 0.38941935202558264`, 0.567974527017709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 159}], {
             RGBColor[
             0.8383183472366464, 0.29553718483349917`, 0.18432699862918317`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 170}], {
             RGBColor[
             0.5181787984934242, 0.3625107392801563, 0.5665165695978354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 192}], {
             RGBColor[
             0.8356556165643594, 0.2750702700702792, 0.18177716473027677`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 197}], {
             RGBColor[
             0.8714546134192276, 0.6651379190942172, 0.5943016099688991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 141}], {
             RGBColor[
             0.37364371183420664`, 0.49805313613695035`, 0.9450292248112824]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 177}], {
             RGBColor[
             0.3407778041727428, 0.4681866139645882, 0.9429862890205556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 198}], {
             RGBColor[
             0.542054826289809, 0.636504451768819, 0.9581455985091416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 95}], {
             RGBColor[
             0.9087217160297558, 0.9082261327367556, 0.679871771253554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 136}], {
             RGBColor[
             0.8729121465452325, 0.773250594157032, 0.6146156000869095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 97}], {
             RGBColor[
             0.2548383832137916, 0.38518167681737986`, 0.9378240409731977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 155}], {
             RGBColor[
             0.23916918979888965`, 0.36871236105407446`, 0.9369317035887135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 134}], {
             RGBColor[
             0.2274998629101822, 0.35644715861598486`, 0.9362671526856237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 139}], {
             RGBColor[
             0.2366529007205347, 0.36606758169078113`, 0.9367884046482173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 145}], {
             RGBColor[
             0.21595172710093502`, 0.34430933568636624`, 0.935609503435223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 105}], {
             RGBColor[
             0.3806688871734759, 0.5041379899202462, 0.945476862771782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 111}], {
             RGBColor[
             0.43931163123225564`, 0.554736492921887, 0.9492673764797304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 115}], {
             RGBColor[
             0.34184068469654455`, 0.4665135495155001, 0.9431489820897013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 116}], {
             RGBColor[
             0.4038551160855868, 0.5242207360301667, 0.9469542687752844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 126}], {
             RGBColor[
             0.3626762195061153, 0.4884130176495661, 0.9443355349736948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 142}], {
             RGBColor[
             0.5295082484696294, 0.6279621701064884, 0.9563679845897519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 153}], {
             RGBColor[
             0.5020487622755229, 0.6056693221783567, 0.9542062732491396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 160}], {
             RGBColor[
             0.39241961435313644`, 0.5143158791945474, 0.9462256087169099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 167}], {
             RGBColor[
             0.666701611701555, 0.7359313939081493, 0.9698223518406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 174}], {
             RGBColor[
             0.39976902935609954`, 0.5206815730777754, 0.9466939069420661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 188}], {
             RGBColor[
             0.5413907226485897, 0.6372673670541342, 0.9575369230189545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 103}], {
             RGBColor[
             0.9219582849086154, 0.7097965364380157, 0.2919118882865176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 129}], {
             RGBColor[
             0.9849427513832404, 0.9608705061848779, 0.39600586175704294`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 131}], {
             RGBColor[
             0.9394422371635587, 0.7891870801469172, 0.306500926618929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 143}], {
             RGBColor[
             0.9002121270530901, 0.5519033691579674, 0.2714502368397491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 154}], {
             RGBColor[
             0.9830766756699849, 0.9658160132096346, 0.6241438116222372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 105}], {
             RGBColor[
             0.32470350781154744`, 0.4554278902256328, 0.9419194284550477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 111}], {
             RGBColor[
             0.3833462518703272, 0.5060263932272735, 0.9457099421629962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 116}], {
             RGBColor[
             0.3478897367236583, 0.4755106363355533, 0.9433968344585502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 126}], {
             RGBColor[
             0.3067108401441868, 0.4397029179549527, 0.9407781006569607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.43194074873512733`, 0.5454775949392545, 0.9495354789637005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 174}], {
             RGBColor[
             0.3438036499941711, 0.471971473383162, 0.943136472625332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 182}], {
             RGBColor[
             0.2856601600419676, 0.4175773184773137, 0.9395792955668297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 191}], {
             RGBColor[
             0.29321373700723585`, 0.4255166067922517, 0.9400094606004861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 102}], {
             RGBColor[
             0.3273981891467483, 0.4554287175679108, 0.9421765599569466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 112}], {
             RGBColor[
             0.2912053726836331, 0.4234056885504923, 0.9398950872233656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 140}], {
             RGBColor[
             0.29323255505263285`, 0.42553638575109687`, 0.9400105322603325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 155}], {
             RGBColor[
             0.2652922598561954, 0.3961693639826077, 0.9384193737828581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 99}], {
             RGBColor[
             0.7687919437411839, 0.8183727141912807, 0.944294118700548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 117}], {
             RGBColor[
             0.8762433687105626, 0.9035134810174441, 0.9541841801385145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 120}], {
             RGBColor[
             0.9651286166376958, 0.922790787247423, 0.6081584957443529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 121}], {
             RGBColor[
             0.7580819454747305, 0.8096778551186503, 0.9434509884049964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 146}], {
             RGBColor[
             0.8847914583012635, 0.9101913135735867, 0.9550361738224766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 156}], {
             RGBColor[
             0.9471660663080045, 0.9597340431975859, 0.961036759682581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 171}], {
             RGBColor[
             0.9239792736477469, 0.9412455241190165, 0.9588251826995514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 178}], {
             RGBColor[
             0.957960137429429, 0.968167319845601, 0.9560467009664877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 179}], {
             RGBColor[
             0.8907110607570355, 0.9148157520026807, 0.9556261844734377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 183}], {
             RGBColor[
             0.916699432634126, 0.7182581461246227, 0.5672898177785806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 196}], {
             RGBColor[
             0.7343309142909232, 0.7903956980318739, 0.9415812202273133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 107}], {
             RGBColor[
             0.615663269511703, 0.6984811954684678, 0.963146911483036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 109}], {
             RGBColor[
             0.45081925257627997`, 0.561890841684138, 0.9507778651594582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 146}], {
             RGBColor[
             0.6800950161218604, 0.7488157656197341, 0.9695688658362309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 147}], {
             RGBColor[
             0.5223956840025993, 0.6231433757875112, 0.9555440483245787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 156}], {
             RGBColor[
             0.7424696241286013, 0.7983584952437333, 0.9755694516963352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 178}], {
             RGBColor[
             0.7532636952500258, 0.8067917718917483, 0.970579392980242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 179}], {
             RGBColor[
             0.6860146185776324, 0.753440204048828, 0.970158876487192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 194}], {
             RGBColor[
             0.45631234328201786`, 0.5666486807626816, 0.9511278800418784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 104}], {
             RGBColor[
             0.21637454520909913`, 0.34475374432626316`, 0.9356335823009796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 123}], {
             RGBColor[
             0.23212285998297438`, 0.3613062216544334, 0.9365304255298079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 130}], {
             RGBColor[
             0.2255191848288738, 0.3543653403702861, 0.9361543559990437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 135}], {
             RGBColor[
             0.2235466331661063, 0.3522920635057185, 0.9360420220999779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 148}], {
             RGBColor[
             0.20930368592266696`, 0.3373218228978505, 0.9352309073250162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 163}], {
             RGBColor[
             0.22341821875914586`, 0.35215709182205945`, 0.9360347090894736]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 165}], {
             RGBColor[
             0.21635860172261037`, 0.34473698671108804`, 0.9356326743430103]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 123}], {
             RGBColor[
             0.2511378900976988, 0.38129222392755147`, 0.9376133033646252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 124}], {
             RGBColor[
             0.2714494089102611, 0.40264091802422836`, 0.9387700143128014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 127}], {
             RGBColor[
             0.28671598940138643`, 0.417499764656998, 0.9396828962615742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 135}], {
             RGBColor[
             0.2425616632808307, 0.3722780657788366, 0.9371248999347952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 137}], {
             RGBColor[
             0.25101571036429215`, 0.3811638052810985, 0.9376063454095565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 161}], {
             RGBColor[
             0.28025165259241314`, 0.41189263422865363`, 0.9392712890687474]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 165}], {
             RGBColor[
             0.23537363183733478`, 0.36472298898420613`, 0.9367155521778278]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 175}], {
             RGBColor[
             0.2861211170833608, 0.41698451615427623`, 0.9396449915234946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 176}], {
             RGBColor[
             0.27302063754770944`, 0.4042923789438361, 0.9388594934592795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 187}], {
             RGBColor[
             0.2673357347336053, 0.3983171856425559, 0.9385357466540765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 199}], {
             RGBColor[
             0.262066422777004, 0.3927788046824936, 0.9382356671333965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 106}], {
             RGBColor[
             0.32444342089519307`, 0.4523230687923987, 0.9420082902762085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 112}], {
             RGBColor[
             0.337642108559284, 0.46619572637249007`, 0.9427599360129698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 140}], {
             RGBColor[
             0.3396692909282838, 0.4683264235730946, 0.9428753810499368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 108}], {
             RGBColor[
             0.822761672378244, 0.6528409767770607, 0.5936514209828487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 129}], {
             RGBColor[
             0.9272752243887925, 0.727731821781411, 0.3125671941472351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 131}], {
             RGBColor[
             0.8817747101691108, 0.5560483957434501, 0.2230622590091212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 133}], {
             RGBColor[
             0.8438593008645356, 0.3288700512541642, 0.189270528206407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 143}], {
             RGBColor[
             0.8425446000586423, 0.3187646847545005, 0.18801156922994122`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 154}], {
             RGBColor[
             0.9254091486755369, 0.7326773288061676, 0.5407051440124293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 162}], {
             RGBColor[
             0.9235960103474408, 0.7317131111648968, 0.5611505510553894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 123}], {
             RGBColor[
             0.23468312728084179`, 0.36399722491481445`, 0.9366762289648454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 130}], {
             RGBColor[
             0.2280794521267412, 0.3570563436306672, 0.9363001594340813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 163}], {
             RGBColor[
             0.22597848605701326`, 0.35484809508244053`, 0.9361805125245111]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 111}], {
             RGBColor[
             0.4018530682244218, 0.5222917683666206, 0.9468805499681779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 116}], {
             RGBColor[
             0.36639655307775293`, 0.49177601147490035`, 0.944567442263732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 126}], {
             RGBColor[
             0.3252176564982815, 0.45596829309429976`, 0.9419487084621424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 142}], {
             RGBColor[
             0.4920496854617956, 0.5955174455512221, 0.9539811580781995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 157}], {
             RGBColor[
             0.4504475650892219, 0.5617429700786016, 0.9507060867688824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 160}], {
             RGBColor[
             0.35496105134530265`, 0.4818711546392811, 0.9438387822053573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 174}], {
             RGBColor[
             0.3623104663482657, 0.48823684852250904`, 0.9443070804305137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 182}], {
             RGBColor[
             0.30416697639606216`, 0.43384269361666083`, 0.9407499033720115]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 112}], {
             RGBColor[
             0.2882506044320779, 0.42030003977498026`, 0.9397268175426274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 140}], {
             RGBColor[
             0.29027778680107763`, 0.4224307369755848, 0.9398422625795944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 189}], {
             RGBColor[
             0.25322164598941777`, 0.3834823834875024, 0.9377319701800181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 111}], {
             RGBColor[
             0.5638634248724134, 0.6564277480338845, 0.9590690379639482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 142}], {
             RGBColor[
             0.6540600421097872, 0.7296534252184859, 0.9661696460739697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 147}], {
             RGBColor[
             0.5739634519525214, 0.664627405018551, 0.9598641490933124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 156}], {
             RGBColor[
             0.7940373920785235, 0.8398425244747729, 0.979889552465069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 157}], {
             RGBColor[
             0.6124579217372135, 0.6958789497458655, 0.9628945747646525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.7375823865275546, 0.7949242332798678, 0.9744789772559258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 181}], {
             RGBColor[
             0.8257804710137671, 0.8638766258907483, 0.9384122883545408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 185}], {
             RGBColor[
             0.7184021799057017, 0.779940510091907, 0.9725672735090811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 110}], {
             RGBColor[
             0.6931298062895987, 0.7596256615132471, 0.9704393557617335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 131}], {
             RGBColor[
             0.8402456246331873, 0.7322315204859621, 0.6082404593152602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 154}], {
             RGBColor[
             0.8838800631396134, 0.9088604535486795, 0.9258833443185683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 162}], {
             RGBColor[
             0.8820669248115173, 0.9078962359074088, 0.9463287513615282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 180}], {
             RGBColor[
             0.7526503794757171, 0.8066954638919603, 0.9759808139745987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 132}], {
             RGBColor[
             0.2948786821955154, 0.42460409000948357`, 0.9402017631916271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 146}], {
             RGBColor[
             0.5668187671363596, 0.653709441066444, 0.9615199202813867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 150}], {
             RGBColor[
             0.31023488720570846`, 0.44074443511482886`, 0.941076276349488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 151}], {
             RGBColor[
             0.34470972375175946`, 0.47299196992446024`, 0.9431855766759899]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 152}], {
             RGBColor[
             0.3096412804178116, 0.4401205167439052, 0.9410424713210799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 194}], {
             RGBColor[
             0.3430360942965171, 0.47154235620939167`, 0.9430789344870343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 196}], {
             RGBColor[
             0.4163582231260193, 0.5339138255247312, 0.9480649666862233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 127}], {
             RGBColor[
             0.46330733319948464`, 0.5715960026043997, 0.9518806741110254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 162}], {
             RGBColor[
             0.7939641442587955, 0.8384977959010833, 0.9379384858342741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 180}], {
             RGBColor[
             0.6645475989229954, 0.737297023885635, 0.9675905484473445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 116}], {
             RGBColor[
             0.42503929713653266`, 0.5423745144765412, 0.9483579559716804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 126}], {
             RGBColor[
             0.3838604005570612, 0.5065667960959406, 0.9457392221700909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 142}], {
             RGBColor[
             0.5506924295205754, 0.6461159485528629, 0.957771671786148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 157}], {
             RGBColor[
             0.5090903091480017, 0.6123414730802424, 0.9544966004768307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 160}], {
             RGBColor[
             0.41360379540408243`, 0.5324696576409218, 0.9476292959133059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 167}], {
             RGBColor[
             0.687885792752501, 0.7540851723545239, 0.971226039036996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 174}], {
             RGBColor[
             0.4209532104070455, 0.5388353515241499, 0.9480975941384622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 181}], {
             RGBColor[
             0.7224128584245553, 0.7803391492251253, 0.9300143140667192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.6150345673164899, 0.6964030334262838, 0.9641692992212595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 188}], {
             RGBColor[
             0.5625749036995356, 0.6554211455005088, 0.9589406102153506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 140}], {
             RGBColor[
             0.30347647446516857`, 0.4363033945556761, 0.9405939083163557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 122}], {
             RGBColor[
             0.9466202120897103, 0.8137405258050889, 0.35564035163633406`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 136}], {
             RGBColor[
             0.9041543846818847, 0.6565805366270306, 0.24168008890791598`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 138}], {
             RGBColor[
             0.9065388861824932, 0.6660342904889218, 0.24359871478674944`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 144}], {
             RGBColor[
             0.8784089960348599, 0.5377942228250021, 0.22013747789209492`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 159}], {
             RGBColor[
             0.8614732788871635, 0.4076188795492328, 0.20391981602530412`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 167}], {
             RGBColor[
             0.9077889348257765, 0.7877285014564059, 0.6151514893253305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 197}], {
             RGBColor[
             0.8946095450697447, 0.7772196138099509, 0.6138944273650201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 158}], {
             RGBColor[
             0.23522624458781927`, 0.364568075640074, 0.9367071586920077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 160}], {
             RGBColor[
             0.31613284886837134`, 0.44424671423453505`, 0.9415109015232768]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 126}], {
             RGBColor[
             0.34840388541039236`, 0.4760510392042203, 0.9434261144656448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 142}], {
             RGBColor[
             0.5152359143739065, 0.6156001916611427, 0.9554585640817019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 153}], {
             RGBColor[
             0.48777642817979994`, 0.593307343733011, 0.9532968527410897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 157}], {
             RGBColor[
             0.47363379400133276`, 0.5818257161885222, 0.9521834927723848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 160}], {
             RGBColor[
             0.3781472802574135, 0.5019539007492015, 0.9453161882088599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 167}], {
             RGBColor[
             0.652429277605832, 0.7235694154628036, 0.96891293133255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 174}], {
             RGBColor[
             0.38549669526037655`, 0.5083195946324296, 0.9457844864340161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 188}], {
             RGBColor[
             0.5271183885528666, 0.6249053886087885, 0.9566275025109046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 120}], {
             RGBColor[
             0.8678835994276715, 0.8465560061197337, 0.6325812491960736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 121}], {
             RGBColor[
             0.6608369282647062, 0.733443073990961, 0.9678737418567172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 146}], {
             RGBColor[
             0.7875464410912392, 0.8339565324458974, 0.9794589272741974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 151}], {
             RGBColor[
             0.565437397706639, 0.6532390613039136, 0.9611245836688005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 171}], {
             RGBColor[
             0.8267342564377225, 0.8650107429913272, 0.9832479361512722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 173}], {
             RGBColor[
             0.8870698836005233, 0.9096475021441977, 0.8455791000881498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 196}], {
             RGBColor[
             0.6370858970808988, 0.7141609169041846, 0.966003973679034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 119}], {
             RGBColor[
             0.7390929491372125, 0.7956716911845035, 0.9752408612005126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 125}], {
             RGBColor[
             0.5461336776674304, 0.6195695759530597, 0.9625480754195246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 128}], {
             RGBColor[
             0.901444520807011, 0.7626039594239429, 0.6105848646794676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 138}], {
             RGBColor[
             0.9130416014388392, 0.812801149295034, 0.6201343733156849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 144}], {
             RGBColor[
             0.8849117112912057, 0.6845610816311141, 0.5966731364210304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 149}], {
             RGBColor[
             0.5734377675010032, 0.6482679055474284, 0.9641030029427655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 159}], {
             RGBColor[
             0.8679759941435095, 0.5543857383553449, 0.5804554745542396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 170}], {
             RGBColor[
             0.5478364454002871, 0.6213592928020021, 0.9626450455228917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 190}], {
             RGBColor[
             0.5465072945042451, 0.6199622709372278, 0.9625693523456647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 192}], {
             RGBColor[
             0.8653132634712222, 0.5339188235921248, 0.5779056406553331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 195}], {
             RGBColor[
             0.5461172634712222, 0.6195523235921249, 0.9625471406553332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 197}], {
             RGBColor[
             0.9011122603260905, 0.9239864726160629, 0.9904300858939554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 125}], {
             RGBColor[
             0.3719190998621983, 0.4815306199533135, 0.9461956553093709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 128}], {
             RGBColor[
             0.727229943001779, 0.6245650034241965, 0.5942324445693138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 144}], {
             RGBColor[
             0.7106971334859737, 0.5465221256313679, 0.5803207163108766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 149}], {
             RGBColor[
             0.3992231896957711, 0.5102289495476822, 0.9477505828326117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 183}], {
             RGBColor[
             0.7123944253398227, 0.5572003826444346, 0.5818533249803631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 190}], {
             RGBColor[
             0.3722927166990131, 0.48192331493748153`, 0.946216932235511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 192}], {
             RGBColor[
             0.6910986856659902, 0.39587986759237864`, 0.5615532205451794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 195}], {
             RGBColor[
             0.37190268566599016`, 0.4815133675923786, 0.9461947205451795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 128}], {
             RGBColor[
             0.9231751810131911, 0.7286652920066743, 0.2580660064250903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 168}], {
             RGBColor[
             0.9476806026150666, 0.909778086957847, 0.6376934323137864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 171}], {
             RGBColor[
             0.9156195043648556, 0.8842880492213061, 0.6372222517571104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 172}], {
             RGBColor[
             0.9753727800277856, 0.9276792174007213, 0.4361680487899127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 173}], {
             RGBColor[
             0.9759551315276564, 0.9289248083741766, 0.49955341569398815`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 183}], {
             RGBColor[
             0.9083396633512348, 0.6613006712269123, 0.24568688683613962`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 151}], {
             RGBColor[
             0.4472759744708069, 0.5594034354051198, 0.9503913919352824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 171}], {
             RGBColor[
             0.7085728332018904, 0.7711751170925334, 0.9725147444177542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 196}], {
             RGBColor[
             0.5189244738450667, 0.6203252910053908, 0.955270781945516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 136}], {
             RGBColor[
             0.9504725003418423, 0.8301441328600938, 0.35879847629145456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 138}], {
             RGBColor[
             0.9528570018424507, 0.8395978867219851, 0.360717102170288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 142}], {
             RGBColor[
             0.8169136872538085, 0.8533228738878083, 0.7188155094580211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 144}], {
             RGBColor[
             0.9247271116948175, 0.7113578190580653, 0.33725586527563345`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 153}], {
             RGBColor[
             0.7894542010597019, 0.8310300259596766, 0.7166537981174088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.907791394547121, 0.5811824757822961, 0.3210382034088427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 167}], {
             RGBColor[
             0.9541070504857341, 0.9612920976894692, 0.7322698767088691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 181}], {
             RGBColor[
             0.9886341161577883, 0.9875460745600706, 0.6910581517385923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 188}], {
             RGBColor[
             0.8287961614327686, 0.8626280708354541, 0.7199844478872237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 192}], {
             RGBColor[
             0.9051286638748339, 0.560715561019076, 0.3184883695099363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 127}], {
             RGBColor[
             0.2860095413584047, 0.4167572429724312, 0.9396426650906227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 130}], {
             RGBColor[
             0.24382776690061642`, 0.3736088209588374, 0.9371970026629095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 135}], {
             RGBColor[
             0.24185521523784892`, 0.3715355440942698, 0.9370846687638437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 163}], {
             RGBColor[
             0.2417268008308885, 0.37140057241061075`, 0.9370773557533394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 165}], {
             RGBColor[
             0.23466718379435303`, 0.36398046729963934`, 0.9366753210068761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 177}], {
             RGBColor[
             0.27201910823742403`, 0.40323970813810023`, 0.9388024578466887]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 187}], {
             RGBColor[
             0.26662928669062347`, 0.3975746639579891, 0.9384955154831248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 127}], {
             RGBColor[
             0.30632106017096694`, 0.43810593706910805`, 0.9407993760387987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 135}], {
             RGBColor[
             0.26216673405041124`, 0.39288423819094664`, 0.9382413797120197]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.27062078113387267`, 0.4017699776932086, 0.938722825186781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 161}], {
             RGBColor[
             0.29985672336199365`, 0.43249880664076373`, 0.9403877688459719]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 175}], {
             RGBColor[
             0.3057261878529413, 0.4375906885663863, 0.9407614713007191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 176}], {
             RGBColor[
             0.29262570831728996`, 0.4248985513559462, 0.9399759732365041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 187}], {
             RGBColor[
             0.2869408055031858, 0.4189233580546661, 0.939652226431301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 199}], {
             RGBColor[
             0.2816714935465845, 0.4133849770946037, 0.939352146910621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 128}], {
             RGBColor[
             0.5342706715319968, 0.44846288819275276`, 0.5815396587883258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 149}], {
             RGBColor[
             0.206263918225989, 0.33412683431623835`, 0.9350577970516237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[
             0.18066259612527297`, 0.307218221570812, 0.93359983963175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 190}], {
             RGBColor[
             0.179333445229231, 0.3058211997060377, 0.933524146454523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 195}], {
             RGBColor[
             0.17894341419620807`, 0.3054112523609348, 0.9335019347641915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 142}], {
             RGBColor[
             0.47405701779443504`, 0.579792473280542, 0.9528398302801124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 157}], {
             RGBColor[
             0.43245489742186133`, 0.5460179978079216, 0.9495647589707952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 160}], {
             RGBColor[
             0.336968383677942, 0.466146182368601, 0.9426974544072704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 174}], {
             RGBColor[
             0.3443177986809051, 0.472511876251829, 0.9431657526324266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 182}], {
             RGBColor[
             0.2861743087287016, 0.41811772134598074`, 0.9396085755739244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 191}], {
             RGBColor[
             0.2937278856939699, 0.4260570096609187, 0.9400387406075807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 135}], {
             RGBColor[
             0.2774333145415366, 0.4077430848237163, 0.9391542616607926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 161}], {
             RGBColor[
             0.31512330385311904`, 0.4473576532735334, 0.9413006507947447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 175}], {
             RGBColor[
             0.32099276834406665`, 0.45244953519915593`, 0.9416743532494919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 176}], {
             RGBColor[
             0.3078922888084153, 0.4397573979887158, 0.940888855185277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 177}], {
             RGBColor[
             0.3075972075411117, 0.4394472488675467, 0.9408720507436377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 180}], {
             RGBColor[
             0.5228279063856032, 0.618665804983113, 0.9574221323238906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 187}], {
             RGBColor[
             0.3022073859943112, 0.43378220468743567`, 0.9405651083800737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 183}], {
             RGBColor[
             0.8747459970096212, 0.524132650883874, 0.217197328459318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 190}], {
             RGBColor[
             0.5346442883688116, 0.44885558317692076`, 0.5815609357144658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 192}], {
             RGBColor[
             0.8534502573357887, 0.36281213583181793`, 0.19689722402413434`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 195}], {
             RGBColor[
             0.5342542573357888, 0.44844563583181796`, 0.5815387240241343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 131}], {
             RGBColor[
             0.9447591766437358, 0.8071223654903125, 0.32715623247964654`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 133}], {
             RGBColor[
             0.9068437673391607, 0.5799440210010265, 0.2933645016769323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 143}], {
             RGBColor[
             0.9055290665332671, 0.5698386545013628, 0.2921055427004665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 170}], {
             RGBColor[
             0.5863125273607737, 0.6439068649740138, 0.6751789886764388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 197}], {
             RGBColor[
             0.939588342286577, 0.9465340447880747, 0.7029640290475025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 163}], {
             RGBColor[
             0.23512312567678792`, 0.3644596911264634, 0.9367012862225752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 177}], {
             RGBColor[
             0.26541543308332344`, 0.3962988268539529, 0.9384263883159245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 133}], {
             RGBColor[
             0.8613432531194789, 0.40826059496306566`, 0.20385956653881843`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 143}], {
             RGBColor[
             0.8600285523135855, 0.398155228463402, 0.20260060756235265`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 154}], {
             RGBColor[
             0.9428931009304802, 0.8120678725150692, 0.5552941823448407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 162}], {
             RGBColor[
             0.941079962602384, 0.8111036548737982, 0.5757395893878008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 180}], {
             RGBColor[
             0.811663417266584, 0.70990288285835, 0.6053916520008711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 150}], {
             RGBColor[
             0.2675705658104447, 0.39856400799346436`, 0.938549119936501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 151}], {
             RGBColor[
             0.3020454023564957, 0.43081154280309575`, 0.9406584202630028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 162}], {
             RGBColor[
             0.903164553297809, 0.5839253103845123, 0.5419478585850865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 139}], {
             RGBColor[
             0.2400051701500614, 0.36959102940737165`, 0.9369793114329906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 145}], {
             RGBColor[
             0.21930399653046173`, 0.34783278340295676`, 0.9358004102199964]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 191}], {
             RGBColor[
             0.25554145744836393`, 0.3859206524153965, 0.9378640800107516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 148}], {
             RGBColor[
             0.2190360411775415, 0.34755114533768694`, 0.935785150559052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 163}], {
             RGBColor[
             0.2331505740140204, 0.36238641426189583`, 0.9365889523235094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 165}], {
             RGBColor[
             0.22609095697748494`, 0.3549663091509244, 0.9361869175770461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 176}], {
             RGBColor[
             0.26373796268785954`, 0.3945356991105544, 0.938330858858498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 187}], {
             RGBColor[
             0.2580530598737554, 0.38856050580927426`, 0.9380071120532948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 143}], {
             RGBColor[
             0.8644025575685669, 0.416927830578244, 0.20619406567310455`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 159}], {
             RGBColor[
             0.8653255671392956, 0.4240224866042378, 0.2070779406804246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 197}], {
             RGBColor[
             0.8984618333218767, 0.7936232208649558, 0.6170525520201404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 161}], {
             RGBColor[
             0.2794230248160247, 0.4110216938976339, 0.939224099942727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 175}], {
             RGBColor[
             0.2852924893069724, 0.4161135758232565, 0.9395978023974743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 176}], {
             RGBColor[
             0.27219200977132096`, 0.4034214386128163, 0.9388123043332592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 186}], {
             RGBColor[
             0.2661087370017966, 0.3970275332302755, 0.9384658709484304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 187}], {
             RGBColor[
             0.2665071069572168, 0.39744624531153616`, 0.938488557528056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 199}], {
             RGBColor[
             0.26123779500061556`, 0.39190786435147384`, 0.9381884780073761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 142}], {
             RGBColor[
             0.7768323613465915, 0.7056166385716411, 0.6067738726084364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 144}], {
             RGBColor[
             0.8846457857876004, 0.5636515837418983, 0.22521422842604885`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 156}], {
             RGBColor[
             0.9168097113153278, 0.8158057378279282, 0.6204937789995357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 159}], {
             RGBColor[
             0.8677100686399041, 0.4334762404661291, 0.20899656655925808`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 167}], {
             RGBColor[
             0.914025724578517, 0.8135858623733021, 0.6202282398592844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 181}], {
             RGBColor[
             0.9485527902505714, 0.8398398392439036, 0.5790165148890076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 185}], {
             RGBColor[
             0.8411744991425061, 0.7559037234450623, 0.613171500043548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 192}], {
             RGBColor[
             0.8650473379676169, 0.41300932570290905`, 0.20644673266035168`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 145}], {
             RGBColor[
             0.2284570343408142, 0.357453206477753, 0.9363216621825899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 152}], {
             RGBColor[
             0.26544888260262894`, 0.3963339844195651, 0.9384282932165648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 182}], {
             RGBColor[
             0.2571409182934481, 0.38760178717525484`, 0.9379551669396888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 191}], {
             RGBColor[
             0.2646944952587164, 0.3955410754901928, 0.9383853319733451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 198}], {
             RGBColor[
             0.5277497041986612, 0.6241140740098087, 0.9572340887790165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 153}], {
             RGBColor[
             0.6134295605638427, 0.6970487778093326, 0.9627105685555573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 157}], {
             RGBColor[
             0.5992869263853755, 0.6855671502648439, 0.9615972085868523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 160}], {
             RGBColor[
             0.5038004126414563, 0.6056953348255233, 0.9547299040233275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 167}], {
             RGBColor[
             0.7780824099898748, 0.8273108495391253, 0.9783266471470176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 174}], {
             RGBColor[
             0.5111498276444193, 0.6120610287087513, 0.9551982022484837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 181}], {
             RGBColor[
             0.8126094756619291, 0.8535648264097266, 0.9371149221767408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 185}], {
             RGBColor[
             0.7052311845538637, 0.7696287106108853, 0.971269907331281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 188}], {
             RGBColor[
             0.6527715209369094, 0.7286468226851102, 0.9660412183253722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 154}], {
             RGBColor[
             0.9036629908200117, 0.5747841615261196, 0.5202434925656607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 159}], {
             RGBColor[
             0.8217214517738456, 0.16796617350044618`, 0.16843379279049273`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 197}], {
             RGBColor[
             0.8548577179564267, 0.5375669077611642, 0.5784084041302087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 149}], {
             RGBColor[
             0.5450419518497644, 0.3991183399942927, 0.5691828580531295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 159}], {
             RGBColor[
             0.8395801784922707, 0.30523617280220927`, 0.18553532966460354`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 170}], {
             RGBColor[
             0.5194406297490485, 0.3722097272488664, 0.5677249006332556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 181}], {
             RGBColor[
             0.920422900102938, 0.7115997715799838, 0.5555552779943531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 190}], {
             RGBColor[
             0.5181114788530065, 0.37081270538409206`, 0.5676492074560286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 192}], {
             RGBColor[
             0.8369174478199836, 0.2847692580389892, 0.18298549576569717`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 197}], {
             RGBColor[
             0.8727164446748519, 0.6748369070629272, 0.5955099410043194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 147}], {
             RGBColor[
             0.6383951985626789, 0.7149619751698173, 0.9662861034465073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 156}], {
             RGBColor[
             0.8584691386886809, 0.8901770946260392, 0.9863115068182637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 171}], {
             RGBColor[
             0.8352823460284233, 0.8716885755474699, 0.9840999298352342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 178}], {
             RGBColor[
             0.8692632098101054, 0.8986103712740543, 0.9813214481021706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 179}], {
             RGBColor[
             0.802014133137712, 0.8452588034311341, 0.9809009316091206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 183}], {
             RGBColor[
             0.8280025050148025, 0.648701197553076, 0.5925645649142633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 194}], {
             RGBColor[
             0.5723118578420975, 0.6584672801449877, 0.9618699351638069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 196}], {
             RGBColor[
             0.6456339866715997, 0.7208387494603272, 0.9668559673629961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 152}], {
             RGBColor[
             0.3812177118441309, 0.5013730508472783, 0.9458086544862003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 156}], {
             RGBColor[
             0.7007698065694198, 0.7645047047938165, 0.9722866893066117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 178}], {
             RGBColor[
             0.7115638776908443, 0.7729379814418316, 0.9672966305905184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 179}], {
             RGBColor[
             0.6443148010184508, 0.7195864135989113, 0.9668761140974684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 185}], {
             RGBColor[
             0.625134594396598, 0.7046026904109504, 0.9649644103506239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 194}], {
             RGBColor[
             0.41461252572283636`, 0.5327948903127648, 0.9478451176521548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 165}], {
             RGBColor[
             0.2118480097340456, 0.33999606854305653`, 0.9353758028020844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 159}], {
             RGBColor[
             0.5281062347020681, 0.2689429967185235, 0.5529651961863387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 170}], {
             RGBColor[
             0.2079666859588458, 0.3359165511651807, 0.9351547671549908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 190}], {
             RGBColor[
             0.2066375350628038, 0.33451952930040635`, 0.9350790739777637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 192}], {
             RGBColor[
             0.5254435040297809, 0.2484760819553035, 0.5504153622874323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 195}], {
             RGBColor[
             0.2062475040297809, 0.3341095819553035, 0.9350568622874322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 197}], {
             RGBColor[
             0.5612425008846491, 0.6385437309792414, 0.9629398075260546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 151}], {
             RGBColor[
             0.3174016073666887, 0.4469518879084411, 0.9415329334208639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 152}], {
             RGBColor[
             0.2823331640327409, 0.4140804347278859, 0.9393898280659538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 194}], {
             RGBColor[
             0.31572797791144636`, 0.44550227419337246`, 0.9414262912319082]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 171}], {
             RGBColor[
             0.6131733026438233, 0.690971104405486, 0.9657655862298374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 196}], {
             RGBColor[
             0.4235249432869995, 0.5401212783183434, 0.9485216237575993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 194}], {
             RGBColor[
             0.3151343711235495, 0.4448783558224487, 0.9413924862035001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 160}], {
             RGBColor[
             0.4763409264473496, 0.5834024868973917, 0.9525681926827152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 167}], {
             RGBColor[
             0.7506229237957682, 0.8050180016109936, 0.9761649358064053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 174}], {
             RGBColor[
             0.4836903414503127, 0.5897681807806197, 0.9530364909078715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 188}], {
             RGBColor[
             0.6253120347428027, 0.7063539747569785, 0.9638795069847599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 157}], {
             RGBColor[
             0.7392642763541118, 0.795756249521131, 0.9753171149779516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 178}], {
             RGBColor[
             0.9316378178168464, 0.9481531008980535, 0.987322033962275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 179}], {
             RGBColor[
             0.864388741144453, 0.8948015330551333, 0.986901517469225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 181}], {
             RGBColor[
             0.9525868256306654, 0.9637539256660137, 0.9508348285678401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 183}], {
             RGBColor[
             0.8903771130215434, 0.6982439271770752, 0.5985651507743678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 185}], {
             RGBColor[
             0.8452085345226001, 0.8798178098671724, 0.9849898137223804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 192}], {
             RGBColor[
             0.869081373347711, 0.5369234121250193, 0.5782650463391841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 174}], {
             RGBColor[
             0.4695477072718456, 0.5782865532361309, 0.9519231309391665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 181}], {
             RGBColor[
             0.7710073552893554, 0.8197903509371063, 0.9338398508674235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 185}], {
             RGBColor[
             0.6636290641812901, 0.7358542351382649, 0.9679948360219639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 164}], {
             RGBColor[
             0.27399405489207074`, 0.4053155022909841, 0.9389149281369991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 166}], {
             RGBColor[
             0.3220947514992546, 0.4482744245110126, 0.9419323901733808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 170}], {
             RGBColor[
             0.5025049126013521, 0.2420343839730972, 0.5515072387664649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 197}], {
             RGBColor[
             0.8557807275271554, 0.5446615637871581, 0.5792922791375287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 167}], {
             RGBColor[
             0.6409937758733817, 0.7136645586271843, 0.9681842712741754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 174}], {
             RGBColor[
             0.37406119352792633`, 0.4984147377968103, 0.9450558263756417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 188}], {
             RGBColor[
             0.5156828868204164, 0.6150005317731692, 0.9558988424525301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 175}], {
             RGBColor[
             0.31452843153509336`, 0.4468424047708116, 0.941262746056665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 176}], {
             RGBColor[
             0.301427951999442, 0.43415026756037145`, 0.9404772479924501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 187}], {
             RGBColor[
             0.2957430491853379, 0.4281750742590913, 0.9401535011872468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 193}], {
             RGBColor[
             0.31267272742048674`, 0.4452350871371401, 0.9411445022314171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 199}], {
             RGBColor[
             0.2904737372287366, 0.422636693299029, 0.9398534216665669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 180}], {
             RGBColor[
             0.853484717444914, 0.8855675982797966, 0.9434799440471393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 177}], {
             RGBColor[
             0.2633144670135955, 0.39409057830572625`, 0.9383067414063544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 166}], {
             RGBColor[
             0.3428237586125573, 0.4700619252820549, 0.9431128764626655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 184}], {
             RGBColor[
             0.33292802569279517`, 0.46149073880095526`, 0.9424823291114712]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 187}], {
             RGBColor[
             0.2508650284302595, 0.38100542901464385`, 0.9375977642963274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 184}], {
             RGBColor[
             0.3810287222999791, 0.5044496610209838, 0.9454997911478531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 181}], {
             RGBColor[
             0.9498028388938546, 0.9615340502113876, 0.9505692894275887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 188}], {
             RGBColor[
             0.7899648841688349, 0.8366160464867711, 0.9794955855762202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 172}], {
             RGBColor[
             0.9662845352880476, 0.9716239920088556, 0.7873059163017873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 173}], {
             RGBColor[
             0.9668668867879184, 0.9728695829823109, 0.8506912832058626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 184}], {
             RGBColor[
             0.6548626736277727, 0.7248006680529328, 0.9668502718111599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 198}], {
             RGBColor[
             0.8173765882647961, 0.8581441256038294, 0.9795908811512684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 200}], {
             RGBColor[
             0.2545855584826314, 0.3849159419949167, 0.9378096429787789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 190}], {
             RGBColor[
             0.1810362129620878, 0.3076109165549801, 0.93362111655789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 195}], {
             RGBColor[
             0.1806461819290649, 0.30720096920987716`, 0.9335989048675586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 197}], {
             RGBColor[
             0.5356411787839332, 0.6116351182338152, 0.9614818501061808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 173}], {
             RGBColor[
             0.9348057885377076, 0.9473795452457701, 0.8502201026491867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 178}], {
             RGBColor[
             0.9084510251565888, 0.9296645818194842, 0.9851104569792455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 183}], {
             RGBColor[
             0.8671903203612858, 0.6797554080985058, 0.5963535737913382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 196}], {
             RGBColor[
             0.6848218020180831, 0.7518929600057571, 0.9706449762400708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 173}], {
             RGBColor[
             0.9945590642006376, 0.9907707134251852, 0.6491658996819889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 198}], {
             RGBColor[
             0.8450687656775151, 0.8760452560467036, 0.7780654976273946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 188}], {
             RGBColor[
             0.5230323018233795, 0.6213662256563972, 0.9563671406776864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 176}], {
             RGBColor[
             0.30729741649038966`, 0.43924214948599405`, 0.9408509504471974]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 187}], {
             RGBColor[
             0.3016125136762855, 0.4332669561847139, 0.940527203641994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 199}], {
             RGBColor[
             0.2963432017196842, 0.4277285752246516, 0.9402271241213142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 187}], {
             RGBColor[
             0.2885120341406341, 0.42057481897427373`, 0.9397417055777791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 199}], {
             RGBColor[
             0.28324272218403285`, 0.4150364380142114, 0.9394416260570992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 179}], {
             RGBColor[
             0.8751828122658775, 0.9032348097031484, 0.9819114587531318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 183}], {
             RGBColor[
             0.9011711841429679, 0.7066772038250902, 0.5935750920582745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 183}], {
             RGBColor[
             0.8339221074705745, 0.65332563598217, 0.5931545755652246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 185}], {
             RGBColor[
             0.7887535289716312, 0.8348995186722672, 0.9795792385132371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 194}], {
             RGBColor[
             0.5782314602978695, 0.6630917185740817, 0.9624599458147682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 185}], {
             RGBColor[
             0.8769516134578437, 0.9038519112831478, 0.9435125496118522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 188}], {
             RGBColor[
             0.8244919498408892, 0.8628700233573725, 0.9382838606059434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 192}], {
             RGBColor[
             0.9008244522829545, 0.5609575135409945, 0.536787782228656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 191}], {
             RGBColor[
             0.2726772055917506, 0.4039314101832797, 0.9388399355174497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 192}], {
             RGBColor[
             0.8386147396738325, 0.29544751505205596`, 0.18451810443518368`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 193}], {
             RGBColor[
             0.29935843960625863`, 0.43124092646978174`, 0.9403862732371204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 199}], {
             RGBColor[
             0.2771594494145085, 0.4086425326316706, 0.9390951926722704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 199}], {
             RGBColor[
             0.27755781936992874`, 0.40906124471293126`, 0.9391178792518959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 192}], {
             RGBColor[
             0.4985130310330229, 0.22017044734510285`, 0.5488817116903315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 195}], {
             RGBColor[
             0.1793170310330229, 0.30580394734510286`, 0.9335232116903315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 199}], {
             RGBColor[
             0.2944874976050776, 0.4261212575909801, 0.9401088802960662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 197}], {
             RGBColor[
             0.5339219968548683, 0.6098281490239381, 0.9613839452386224]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.04749427504982855], {
             RGBColor[
             0.9583125875736904, 0.8710407105954553, 0.2925527040414048]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.04749427504982855], {
             RGBColor[
             0.377120805174838, 0.5010648196248124, 0.9452507821242745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.04749427504982855], {
             RGBColor[
             0.26366336471100654`, 0.39445729190709694`, 0.938326610614074]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.04749427504982855], {
             RGBColor[
             0.8048857220793089, 0.8475021105371937, 0.9811871447582946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.04749427504982855], {
             RGBColor[
             0.2822070658609612, 0.41394789755425965`, 0.9393826469616164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.04749427504982855], {
             RGBColor[
             0.3400518121902417, 0.46895752104331584`, 0.9428887786701194]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.04749427504982855], {
             RGBColor[
             0.350460125859892, 0.477972679206911, 0.9435519872134391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.04749427504982855], {
             RGBColor[
             0.44819737568646545`, 0.5626277725896778, 0.9497797183467319]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.04749427504982855], {
             RGBColor[
             0.2605668322464433, 0.39120263995534316`, 0.9381502676711264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.04749427504982855], {
             RGBColor[
             0.28931600419628395`, 0.4214198424774074, 0.9397874904830813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.04749427504982855], {
             RGBColor[
             0.24586228151751777`, 0.37574722481687783`, 0.9373128652605475]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.04749427504982855], {
             RGBColor[
             0.5839626349742006, 0.6731262001457912, 0.9603908242322355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.04749427504982855], {
             RGBColor[
             0.3779993100162068, 0.5018257363634689, 0.9453067596759351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.04749427504982855], {
             RGBColor[
             0.4167727741971154, 0.535409362225998, 0.9477773705275145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.04749427504982855], {
             RGBColor[
             0.32511075702074876`, 0.45601633001476893`, 0.9419367478465757]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.04749427504982855], {
             RGBColor[
             0.3229612837478847, 0.4541545643014821, 0.9417997853103334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.04749427504982855], {
             RGBColor[
             0.2388383031545141, 0.3683645782114108, 0.9369128600838192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.04749427504982855], {
             RGBColor[
             0.3183704566888478, 0.45017822064462143`, 0.9415072618696405]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.04749427504982855], {
             RGBColor[
             0.26440158051900675`, 0.3952332035268908, 0.9383686509122472]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.04749427504982855], {
             RGBColor[
             0.22540124214842158`, 0.354241375135133, 0.9361476393378726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.04749427504982855], {
             RGBColor[
             0.31620160663402885`, 0.4482996717367106, 0.9413690646619862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.04749427504982855], {
             RGBColor[
             0.8444218577904707, 0.34245144152557083`, 0.19017172722845446`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.04749427504982855], {
             RGBColor[
             0.9935791491691084, 0.9886747742573517, 0.5425081958346172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.04749427504982855], {
             RGBColor[
             0.17892700283938517`, 0.30539400298437386`, 0.9335010001616988]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.04749427504982855], {
             RGBColor[
             0.9789215033713261, 0.9405594227844256, 0.37261445024803247`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.04749427504982855], {
             RGBColor[
             0.39640287984113043`, 0.5177659835555031, 0.9464794188715415]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.04749427504982855], {
             RGBColor[
             0.2767490295536739, 0.4082111553358114, 0.9390718198683575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.04749427504982855], {
             RGBColor[
             0.29477679578460203`, 0.4271594806709139, 0.9400984744855188]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.04749427504982855], {
             RGBColor[
             0.9936430185668372, 0.9916392390574856, 0.75501516389549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.04749427504982855], {
             RGBColor[
             0.8937471851268821, 0.9181137615718546, 0.9897275984465748]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.04749427504982855], {
             RGBColor[
             0.8505083657915934, 0.8836363007203797, 0.9856034412586252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.04749427504982855], {
             RGBColor[
             0.23515166545220784`, 0.36448968823995603`, 0.9367029115205646]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.04749427504982855], {
             RGBColor[
             0.3230400522816408, 0.4542227896464, 0.941804804371652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.04749427504982855], {
             RGBColor[
             0.2517479206748871, 0.38193340474234894`, 0.9376480437035368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.04749427504982855], {
             RGBColor[
             0.8383733051460716, 0.8739601327590868, 0.9844459883411588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.04749427504982855], {
             RGBColor[
             0.24777983952010385`, 0.3777626998577953, 0.9374220673520219]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.04749427504982855], {
             RGBColor[
             0.19099374879671333`, 0.31807691806140814`, 0.9341881834928177]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.04749427504982855], {
             RGBColor[
             0.9648082727380654, 0.8929521819142981, 0.31778721429778617`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.04749427504982855], {
             RGBColor[
             0.20098973591686892`, 0.3285833343068806, 0.9347574401715728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.04749427504982855], {
             RGBColor[
             0.49158142165721236`, 0.5981269694488269, 0.9531182367163876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.04749427504982855], {
             RGBColor[
             0.5497140953330726, 0.6453216927859953, 0.9576946537351515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.04749427504982855], {
             RGBColor[
             0.5214414667269106, 0.6223686992161088, 0.9554689288452234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.04749427504982855], {
             RGBColor[
             0.8553653759675705, 0.4265681177150025, 0.20065125259378117`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.04749427504982855], {
             RGBColor[
             0.2834240796528994, 0.4152270562127178, 0.9394519540966568]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.04749427504982855], {
             RGBColor[
             0.8843599871114161, 0.5677875345316877, 0.22521947746071738`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.04749427504982855], {
             RGBColor[
             0.5977424503378598, 0.6843132750316175, 0.9614756217747897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.04749427504982855], {
             RGBColor[
             0.4515217278586501, 0.5655071593544256, 0.9499915431275343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.04749427504982855], {
             RGBColor[
             0.3171026989044469, 0.4490801525711323, 0.9414264814646527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.04749427504982855], {
             RGBColor[
             0.8347376037115143, 0.26801402100751526`, 0.1808980745856452]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.04749427504982855], {
             RGBColor[
             0.2422322948146241, 0.37193187863768656`, 0.9371061428879017]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.04749427504982855], {
             RGBColor[
             0.28213996431762406`, 0.4138773695777287, 0.9393788256279912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.04749427504982855], {
             RGBColor[
             0.21246269677098534`, 0.3406421435922893, 0.9354108083194902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.04749427504982855], {
             RGBColor[
             0.21141226994966317`, 0.3395380784021726, 0.9353509880659832]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.04749427504982855], {
             RGBColor[
             0.27280646441116213`, 0.40406726939796367`, 0.938847296615994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.04749427504982855], {
             RGBColor[
             0.35238205413251156`, 0.47963735687773035`, 0.943674450783476]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.04749427504982855], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.04749427504982855], {
             RGBColor[
             0.3605779115447064, 0.4867361966324024, 0.9441966835704689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.04749427504982855], {
             RGBColor[
             0.264153442110629, 0.394972394326802, 0.9383545197969779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.04749427504982855], {
             RGBColor[
             0.44880489881560515`, 0.5631539785891382, 0.949818429183309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.04749427504982855], {
             RGBColor[
             0.253957266336059, 0.38425556711284614`, 0.9377738626705066]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.04749427504982855], {
             RGBColor[
             0.2737970101358498, 0.4051083957588368, 0.9389037067296339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.04749427504982855], {
             RGBColor[
             0.3562346737166085, 0.4829743023231845, 0.943919936296637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.04749427504982855], {
             RGBColor[
             0.35285247495850214`, 0.48004481175316516`, 0.9437044255825313]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.04749427504982855], {
             RGBColor[
             0.6226026285830288, 0.704495887669313, 0.963432706072083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.04749427504982855], {
             RGBColor[
             0.9220936452530043, 0.9407164594322621, 0.992431309118588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.04749427504982855], {
             RGBColor[
             0.6916199917227627, 0.7590180611312259, 0.9698978752847841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.04749427504982855], {
             RGBColor[
             0.8182056947053702, 0.14094252405757224`, 0.16506709985124088`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.04749427504982855], {
             RGBColor[
             0.8556248139763563, 0.8877160176206234, 0.9860914526539951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.04749427504982855], {
             RGBColor[
             0.4015855979045752, 0.522254993451075, 0.9468096570836465]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.04749427504982855], {
             RGBColor[
             0.21367513065222027`, 0.34191648847421524`, 0.9354798546353913]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.04749427504982855], {
             RGBColor[
             0.2902833275082297, 0.42243656061010276`, 0.93984257811467]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.04749427504982855], {
             RGBColor[
             0.24987650973082426`, 0.37996643318583184`, 0.9375414696187768]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.04749427504982855], {
             RGBColor[
             0.2931347355771166, 0.42543357128021636`, 0.9400049615859128]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.04749427504982855], {
             RGBColor[
             0.30278259996188467`, 0.4355740884585403, 0.9405543931898891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.04749427504982855], {
             RGBColor[
             0.28416143346402023`, 0.4160020618191376, 0.9394939453053829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.04749427504982855], {
             RGBColor[
             0.27635030732849636`, 0.40779207299670056`, 0.9390491132274904]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.04749427504982855], {
             RGBColor[
             0.3003940670337382, 0.43306358890932384`, 0.940418369773149]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.04749427504982855], {
             RGBColor[
             0.9279645300339343, 0.9453977435956535, 0.9929912793499938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.04749427504982855], {
             RGBColor[
             0.20396815225836698`, 0.3317138387242981, 0.934927056576049]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.04749427504982855], {
             RGBColor[
             0.6198970672218798, 0.7022993910721819, 0.9632197143709355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.04749427504982855], {
             RGBColor[
             0.5763338163997934, 0.6669327815527272, 0.9597902556887751]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.04749427504982855], {
             RGBColor[
             0.31859842780058983`, 0.45037567776345117`, 0.9415217879872938]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.04749427504982855], {
             RGBColor[
             0.25584834544704116`, 0.3862432111598293, 0.9378815568282761]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.04749427504982855], {
             RGBColor[
             0.2627765683456537, 0.3935252127009741, 0.9382761088729649]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.04749427504982855], {
             RGBColor[
             0.360155081261214, 0.48636996229290924`, 0.9441697411986989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.04749427504982855], {
             RGBColor[
             0.3919595940317969, 0.5139174327134967, 0.9461962966288141]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.04749427504982855], {
             RGBColor[
             0.9879745726157381, 0.9892951909842899, 0.8489559827730842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.04749427504982855], {
             RGBColor[
             0.7121946053554326, 0.7750911056739228, 0.9719485604909927]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.04749427504982855], {
             RGBColor[
             0.8539922331287186, 0.4160135401405583, 0.19933632946055357`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.04749427504982855], {
             RGBColor[
             0.3879488339253545, 0.5104435138959607, 0.9459407345414075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.04749427504982855], {
             RGBColor[
             0.8378176201564483, 0.8735170446320284, 0.9843929866107827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.04749427504982855], {
             RGBColor[
             0.22871531315648586`, 0.35772467388884666`, 0.9363363707790532]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.04749427504982855], {
             RGBColor[
             0.22414759348065547`, 0.35292371089939434`, 0.9360762459008504]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.04749427504982855], {
             RGBColor[
             0.4181274501813097, 0.5365827144755124, 0.9478636892833344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.04749427504982855], {
             RGBColor[
             0.9796258119030633, 0.9429352208414826, 0.3753505558963255]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.04749427504982855], {
             RGBColor[
             0.3061966914574528, 0.4391625150862857, 0.940748820649866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.04749427504982855], {
             RGBColor[
             0.28096145327109734`, 0.41263867974591306`, 0.9393117111673424]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.04749427504982855], {
             RGBColor[
             0.9734883859205871, 0.9797482621451334, 0.9297614266867937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.04749427504982855], {
             RGBColor[
             0.5640955015617808, 0.656997166237428, 0.9588268107143023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.04749427504982855], {
             RGBColor[
             0.21381427791123173`, 0.3420627410658821, 0.9354877788659421]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.04749427504982855], {
             RGBColor[
             0.2518443381406806, 0.38203474561211825`, 0.9376535345355769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.04749427504982855], {
             RGBColor[
             0.37383492502239923`, 0.4982187553899085, 0.9450414087465508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.04749427504982855], {
             RGBColor[
             0.8642907579141675, 0.4766578520345487, 0.20847322067670976`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.04749427504982855], {
             RGBColor[
             0.21893481250696653`, 0.34744474758664423`, 0.9357793857360172]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.04749427504982855], {
             RGBColor[
             0.34321032416564207`, 0.47169326536497985`, 0.9430900362602295]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.04749427504982855], {
             RGBColor[
             0.27505191676798696`, 0.40642738219488894`, 0.9389751718058661]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.04749427504982855], {
             RGBColor[
             0.6672310374616252, 0.7399652246995075, 0.9674670122517698]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.04749427504982855], {
             RGBColor[
             0.7812325868423204, 0.8290241015195725, 0.9788296212889877]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.04749427504982855], {
             RGBColor[
             0.3375430035907792, 0.46678451713084806`, 0.942728919604614]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.04749427504982855], {
             RGBColor[
             0.6050270257368769, 0.6902272215069217, 0.9620490902344793]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.04749427504982855], {
             RGBColor[
             0.4604958122832016, 0.5728902713682614, 0.9506710636761264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.04749427504982855], {
             RGBColor[
             0.30144929209616883`, 0.4341726973550716, 0.9404784632793888]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.04749427504982855], {
             RGBColor[
             0.9003020964297527, 0.6401769295720257, 0.2385219642527955]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.04749427504982855], {
             RGBColor[
             0.21718744139687057`, 0.3456081497602061, 0.935679875536301]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.04749427504982855], {
             RGBColor[
             0.2655539192117794, 0.3964443845554878, 0.9384342748960682]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.04749427504982855], {
             RGBColor[
             0.3895827819898638, 0.5118587575848209, 0.9460448482672345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.04749427504982855], {
             RGBColor[
             0.7789983515005383, 0.8272786998897548, 0.9786069335902352]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.04749427504982855], {
             RGBColor[
             0.9133075269424444, 0.9337106471842498, 0.9915932813106664]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.04749427504982855], {
             RGBColor[
             0.5648783713319804, 0.6576327351847573, 0.9588884410903589]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.04749427504982855], {
             RGBColor[
             0.9567688473548046, 0.8658333123497126, 0.2865555648019119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.04749427504982855], {
             RGBColor[
             0.5426755050288741, 0.6396074480921672, 0.9571405501231992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.04749427504982855], {
             RGBColor[
             0.9929383277496677, 0.9873041220381521, 0.47275873901987264`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.04749427504982855], {
             RGBColor[
             0.250431442054717, 0.3805497022429847, 0.9375730721936737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.04749427504982855], {
             RGBColor[
             0.2910544796798416, 0.42324709043633846`, 0.9398864940900259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.04749427504982855], {
             RGBColor[
             0.17895982839241617`, 0.30542850472186966`, 0.9335028695283829]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.04749427504982855], {
             RGBColor[
             0.30722498883092086`, 0.4402433208236197, 0.9408073806640553]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.04749427504982855], {
             RGBColor[
             0.32158764066209233`, 0.4529647837018777, 0.9417122579875715]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.04749427504982855], {
             RGBColor[
             0.8895815146715775, 0.5914972716636359, 0.22957644804826868`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.04749427504982855], {
             RGBColor[
             0.9902596908634175, 0.9788057915282733, 0.4166611676177604]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.04749427504982855], {
             RGBColor[
             0.23722409174651585`, 0.3666679396746901, 0.9368209331321454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.04749427504982855], {
             RGBColor[
             0.8992586624240541, 0.6354389394523516, 0.23765129734153262`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.04749427504982855], {
             RGBColor[
             0.2522143608002516, 0.3824236628881191, 0.93767460677864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.04749427504982855], {
             RGBColor[
             0.8234278438149039, 0.18108225047377968`, 0.1700678357361042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.04749427504982855], {
             RGBColor[
             0.23085213233970892`, 0.3599706063325754, 0.9364580594703971]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.04749427504982855], {
             RGBColor[
             0.23327898842098083`, 0.3625213859455549, 0.9365962653340136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.04749427504982855], {
             RGBColor[
             0.9080066729340168, 0.6729841436820356, 0.24483821356303642`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.04749427504982855], {
             RGBColor[
             0.2501870825879037, 0.38029286495007875`, 0.9375591562835361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.04749427504982855], {
             RGBColor[
             0.9127756759352338, 0.6918916514058181, 0.2486754653207034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.04749427504982855], {
             RGBColor[
             0.24915820796041388`, 0.3792114524821679, 0.9375005633955842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.04749427504982855], {
             RGBColor[
             0.30550365683416836`, 0.4384340917562807, 0.9407093533533227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.04749427504982855], {
             RGBColor[
             0.3593385897430587, 0.4856627583779401, 0.9441177150811572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.04749427504982855], {
             RGBColor[
             0.6408890467579492, 0.7193416257374643, 0.9648722798961695]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.04749427504982855], {
             RGBColor[
             0.8207984422031169, 0.16087151747445233`, 0.16754991778317269`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.04749427504982855], {
             RGBColor[
             0.8565158956399671, 0.43541151607797846`, 0.2017529915313943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.04749427504982855], {
             RGBColor[
             0.20775586072121455`, 0.33569496047333813`, 0.9351427609695957]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.04749427504982855], {
             RGBColor[
             0.79609453068194, 0.84063436500204, 0.9803109209581594]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.04749427504982855], {
             RGBColor[
             0.4806958664434177, 0.5892895853375945, 0.9522612859348552]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.04749427504982855], {
             RGBColor[
             0.20479309393410217`, 0.332580904729819, 0.9349740357840903]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.04749427504982855], {
             RGBColor[
             0.2335680080595618, 0.362825163910607, 0.9366127245748646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.04749427504982855], {
             RGBColor[
             0.2829267708206377, 0.41470435309880965`, 0.9394236330943619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.04749427504982855], {
             RGBColor[
             0.3518764439127397, 0.4791994227180725, 0.9436422337473658]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.04749427504982855], {
             RGBColor[
             0.281739557244844, 0.41345651635696223`, 0.9393560230375456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.04749427504982855], {
             RGBColor[
             0.585970074369736, 0.674755929881201, 0.960548857214945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.04749427504982855], {
             RGBColor[
             0.9865275394369064, 0.9886968055777866, 0.8729370673481489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.04749427504982855], {
             RGBColor[
             0.24962306644129345`, 0.3797000482193023, 0.9375270363983738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.04749427504982855], {
             RGBColor[
             0.9208437466954219, 0.9397198242500384, 0.9923120926783682]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.04749427504982855], {
             RGBColor[
             0.5576848060128018, 0.6517926747922235, 0.9583221372775351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.04749427504982855], {
             RGBColor[
             0.25326504777876796`, 0.3835280015199418, 0.9377344418477144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.04749427504982855], {
             RGBColor[
             0.8226444613445744, 0.17506082952644003`, 0.16931766779781277`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.04749427504982855], {
             RGBColor[
             0.36671177852496323`, 0.4920490439135823, 0.9445875281504853]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.04749427504982855], {
             RGBColor[
             0.30865896704414575`, 0.441750522845189, 0.9408890436019178]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.04749427504982855], {
             RGBColor[
             0.9829012627807141, 0.9867683702952449, 0.9138278814340688]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.04749427504982855], {
             RGBColor[
             0.23302215960706, 0.36225144257823677`, 0.936581639313005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.04749427504982855], {
             RGBColor[
             0.29472306200537346`, 0.42710300306202637`, 0.9400954144262837]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.04749427504982855], {
             RGBColor[
             0.21890292553398902`, 0.347411232356294, 0.9357775698200786]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.04749427504982855], {
             RGBColor[
             0.39092445521974123`, 0.5130208475020834, 0.9461303384990473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.04749427504982855], {
             RGBColor[
             0.9152757732218003, 0.9352800733407862, 0.9917810143978655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.04749427504982855], {
             RGBColor[
             0.9385923578753286, 0.9537228615659814, 0.988831299825661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.04749427504982855], {
             RGBColor[
             0.2725827939998642, 0.40383217761416634`, 0.9388345589169613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.04749427504982855], {
             RGBColor[
             0.1823653638581298, 0.3090079384197544, 0.933696809735117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.04749427504982855], {
             RGBColor[
             0.8744701613749067, 0.9027427860928997, 0.9878889387123091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.04749427504982855], {
             RGBColor[
             0.9939767127007667, 0.98952512245173, 0.5857805327779135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.04749427504982855], {
             RGBColor[
             0.9951414157005084, 0.9920163043986404, 0.7125512665860644]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.04749427504982855], {
             RGBColor[
             0.3814106085308894, 0.5047804316800383, 0.9455241246007979]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.04749427504982855], {
             RGBColor[
             0.320397896026041, 0.45193428669643415`, 0.9416364485114123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.04749427504982855], {
             RGBColor[
             0.29419693695473825`, 0.4265500122755539, 0.9400654523829823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.04749427504982855], {
             RGBColor[
             0.29360677442013106`, 0.4259297140332158, 0.9400318434997037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.04749427504982855], {
             RGBColor[
             0.9424318889382709, 0.9565863775460686, 0.9823319752461818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.04749427504982855], {
             RGBColor[
             0.807933735593484, 0.8498832418602281, 0.9814909422600818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.04749427504982855], {
             RGBColor[
             0.7240681721091139, 0.7843668262643483, 0.9731320066602097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.04749427504982855], {
             RGBColor[
             0.984329904565909, 0.9877880270819891, 0.9093575644573119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.04749427504982855], {
             RGBColor[
             0.2651236286264823, 0.39599212186834176`, 0.9384097704837935]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.04749427504982855], {
             RGBColor[
             0.859910479347665, 0.45676803010411193`, 0.20481820887036734`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.04749427504982855], {
             RGBColor[
             0.3711329893802169, 0.49587847453988415`, 0.9448692437966588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.04749427504982855], {
             RGBColor[
             0.7695733223497783, 0.8199157954843064, 0.9776675347663926]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.04749427504982855], {
             RGBColor[
             0.28203039141568953`, 0.41376220151047227`, 0.9393725856133247]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.04749427504982855], {
             RGBColor[
             0.28282713132653, 0.41459962567299363`, 0.939417958772576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.04749427504982855], {
             RGBColor[
             0.6646539951158695, 0.737952019632756, 0.9672101567545748]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.04749427504982855], {
             RGBColor[
             0.2313913752108486, 0.36053738478011593`, 0.9364887685541701]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.04749427504982855], {
             RGBColor[
             0.1797070620660458, 0.3062138946902057, 0.9335454233806629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.04749427504982855], {
             RGBColor[
             0.28023078255701894`, 0.41187069849821767`, 0.939270100551106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.04749427504982855], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.04749427504982855], {
             RGBColor[
             0.31668648779682773`, 0.44871965142909115`, 0.9413999608609163]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.04749427504982855], {
             RGBColor[
             0.348529185002255, 0.47630019528793527`, 0.9434289493694545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.04749427504982855], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.04749427504982855], {
             RGBColor[
             0.49517344266125934`, 0.6010431339186144, 0.9534010137678327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.04749427504982855], {
             RGBColor[
             0.8889169937097365, 0.9142622980478761, 0.9892668904772446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.04749427504982855], {
             RGBColor[
             0.6961608186542636, 0.7625653896416773, 0.9703504624768758]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.04749427504982855], {
             RGBColor[
             0.27228850741332744`, 0.40352286375286894`, 0.938817799731216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.04749427504982855], {
             RGBColor[
             0.23658832296539867`, 0.36599970637566703`, 0.9367847270405965]},
             StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{{3.8349502435193233`*^9, 3.8349502581408367`*^9}, 
   3.834950528174912*^9, 3.8349578088972807`*^9, 3.835018923470682*^9, 
   3.835019026079196*^9, 3.8350205603927774`*^9, 3.835044649527498*^9, 
   3.835045037805329*^9},
 CellLabel->
  "Out[273]=",ExpressionUUID->"3ef8a954-1880-49b8-8747-538b684f5a3e"]
}, Open  ]],

Cell["r = 3 :", "Text",
 CellChangeTimes->{{3.834793779215767*^9, 3.8347938725231647`*^9}, {
  3.8347953347101345`*^9, 3.8347953431477337`*^9}, {3.8348851911359825`*^9, 
  3.83488519180678*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"be83a52e-2012-4715-a6dd-47e745341e26"],

Cell["Cubic Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.834795179278664*^9}},ExpressionUUID->"b8eb9a61-f178-41c7-bc62-\
556a7de813a9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c\[Rho]3if2", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"CMDi3f200", ",", "krif2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.834947911760502*^9, 
   3.834947914304406*^9}, {3.834947957535968*^9, 3.8349479704802837`*^9}, {
   3.8349480487781425`*^9, 3.834948105065866*^9}, {3.8349497992119355`*^9, 
   3.83494980454772*^9}, {3.8349578354451995`*^9, 3.83495784069214*^9}, {
   3.835018838991932*^9, 3.8350188405169106`*^9}, {3.8350443590646524`*^9, 
   3.8350443609005165`*^9}, {3.835044949683157*^9, 3.8350449510226583`*^9}},
 CellLabel->
  "In[274]:=",ExpressionUUID->"5a134436-27d9-4446-ab53-2ec1a81d9e29"],

Cell[BoxData["0.011600088329644589`"], "Output",
 CellChangeTimes->{
  3.834948013482303*^9, {3.834948049945756*^9, 3.834948058990469*^9}, 
   3.8349481059508953`*^9, 3.8349499476386404`*^9, 3.834957841643118*^9, 
   3.8350189236386824`*^9, 3.8350190270322647`*^9, 3.8350204164650445`*^9, 
   3.8350205609787445`*^9, 3.8350446521595054`*^9, 3.835045038186325*^9},
 CellLabel->
  "Out[274]=",ExpressionUUID->"fb542281-fc39-4c15-8402-ac9dedd43858"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CP3if2", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"CMDi3f200", ",", "krif2"}], "}"}], "]"}], ",", "c\[Rho]3if2"}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.8349481210775223`*^9, 3.834948150679065*^9}, {
  3.8349481924167476`*^9, 3.8349481986802473`*^9}, {3.834949807949147*^9, 
  3.834949815491851*^9}, {3.8349578438231587`*^9, 3.8349578533989754`*^9}, {
  3.835018846742407*^9, 3.835018849961266*^9}, {3.835044361707146*^9, 
  3.835044363446494*^9}, {3.835044955607832*^9, 3.835044963462711*^9}},
 CellLabel->
  "In[275]:=",ExpressionUUID->"f5dfedcc-774d-4aae-833a-5374a95d972d"],

Cell[BoxData["0.24335597605027323`"], "Output",
 CellChangeTimes->{3.8349481513130674`*^9, 3.8349482002632475`*^9, 
  3.8349499490044084`*^9, 3.8349578559445095`*^9, 3.83501892389968*^9, 
  3.8350190272812295`*^9, 3.8350205613687525`*^9, 3.8350446533657885`*^9, 
  3.835045038277321*^9},
 CellLabel->
  "Out[275]=",ExpressionUUID->"a42f2c11-87a2-477f-af88-68226e30ceaa"]
}, Open  ]],

Cell["Absolute Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.8347951985065947`*^9}},ExpressionUUID->"b81a236b-30f6-4732-a775-\
3078aa5ef218"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a\[Rho]3if2", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"AMDi3f200", ",", "krif2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.8348873709111376`*^9, 
   3.8348873755217657`*^9}, {3.8349481641806583`*^9, 
   3.8349481824982553`*^9}, {3.834949818653184*^9, 3.8349498238056817`*^9}, {
   3.834957866337153*^9, 3.834957872254816*^9}, {3.8350188531986103`*^9, 
   3.8350188546829796`*^9}, {3.8350443646261296`*^9, 3.835044365855239*^9}, {
   3.8350449644881577`*^9, 3.8350449665516605`*^9}},
 CellLabel->
  "In[276]:=",ExpressionUUID->"e04a8e28-1a0e-4530-a6d8-0fa0b908c171"],

Cell[BoxData["0.0012714995242660203`"], "Output",
 CellChangeTimes->{3.834948182946122*^9, 3.83494995054953*^9, 
  3.834957874365346*^9, 3.835018924320698*^9, 3.8350190275072393`*^9, 
  3.8350205614078007`*^9, 3.835044655427159*^9, 3.8350450383643217`*^9},
 CellLabel->
  "Out[276]=",ExpressionUUID->"9ab8e16d-08f8-4fcf-9a88-2cc0f7ca6017"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"aP3if2", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"AMDi3f200", ",", "krif2"}], "}"}], "]"}], ",", "a\[Rho]3if2"}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8349482041094093`*^9, 
  3.8349482202691827`*^9}, {3.8349498269490285`*^9, 3.8349498405604887`*^9}, {
  3.8349578796796703`*^9, 3.834957886620027*^9}, {3.8350188593392305`*^9, 
  3.835018861313801*^9}, {3.8350443665470304`*^9, 3.835044368736087*^9}, {
  3.835044972843706*^9, 3.835044975243416*^9}},
 CellLabel->
  "In[277]:=",ExpressionUUID->"c7373dd7-f896-441e-88df-49ca59d0e4bd"],

Cell[BoxData["0.29712466044486274`"], "Output",
 CellChangeTimes->{3.834887440036944*^9, 3.8349482220989213`*^9, 
  3.8349499520491343`*^9, 3.8349578874036503`*^9, 3.83501892439668*^9, 
  3.8350190277232385`*^9, 3.8350205614517555`*^9, 3.8350446570245705`*^9, 
  3.8350450384513245`*^9},
 CellLabel->
  "Out[277]=",ExpressionUUID->"32740761-e67e-4461-b0eb-8274ad310349"]
}, Open  ]],

Cell["Max-min Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 3.8347951985065947`*^9}, {
  3.8348543263190746`*^9, 
  3.834854330052075*^9}},ExpressionUUID->"2c16078e-ff5d-40c9-92a5-\
6b2b53ac45fc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mM\[Rho]3if2", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"mMDi3f200", ",", "krif2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8348874651734295`*^9, 3.8348874872060013`*^9}, {
  3.8349482319487157`*^9, 3.834948245258479*^9}, {3.834949844516972*^9, 
  3.8349498489188633`*^9}, {3.834957895209076*^9, 3.834957899999796*^9}, {
  3.83501886583329*^9, 3.835018866821826*^9}, {3.835044369483486*^9, 
  3.835044370515362*^9}, {3.8350449764211473`*^9, 3.835044978468176*^9}},
 CellLabel->
  "In[278]:=",ExpressionUUID->"4198ec48-8b1b-48b2-b16b-011aa0d688b3"],

Cell[BoxData["0.05550253419622399`"], "Output",
 CellChangeTimes->{3.834948246413353*^9, 3.834949953689977*^9, 
  3.834957900696502*^9, 3.835018924463678*^9, 3.835019027994238*^9, 
  3.835020561490786*^9, 3.8350446585457473`*^9, 3.8350450385433226`*^9},
 CellLabel->
  "Out[278]=",ExpressionUUID->"4d035f0c-7fba-4134-b9fb-c69436e71a89"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mMP3if2", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"mMDi3f200", ",", "krif2"}], "}"}], "]"}], ",", 
    "mM\[Rho]3if2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8348875260806427`*^9, 
  3.8348875488478312`*^9}, {3.8349482525846663`*^9, 3.8349482707073736`*^9}, {
  3.8349498532537427`*^9, 3.834949860995207*^9}, {3.834957902898573*^9, 
  3.8349579090270967`*^9}, {3.8350188699780455`*^9, 3.835018871634328*^9}, {
  3.835044378315168*^9, 3.8350443808084726`*^9}, {3.8350449818572917`*^9, 
  3.835044984227113*^9}},
 CellLabel->
  "In[279]:=",ExpressionUUID->"d17bc570-1013-457b-b343-bf6dc6356c25"],

Cell[BoxData["0.5300030549859723`"], "Output",
 CellChangeTimes->{3.834887440036944*^9, 3.8348875533996215`*^9, 
  3.834948277702903*^9, 3.834949955989804*^9, 3.834957909480212*^9, 
  3.835018924542716*^9, 3.835019028341303*^9, 3.8350205615287514`*^9, 
  3.835044659514542*^9, 3.835045038636324*^9},
 CellLabel->
  "Out[279]=",ExpressionUUID->"bab25f0b-c502-4b27-8e3c-650a2125fe62"]
}, Open  ]],

Cell["r = 6 :", "Text",
 CellChangeTimes->{{3.834793779215767*^9, 3.8347938725231647`*^9}, {
  3.8347953347101345`*^9, 3.8347953431477337`*^9}, {3.8348851911359825`*^9, 
  3.83488519180678*^9}, {3.834948305866973*^9, 3.8349483068980722`*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"d8794f78-2e6f-4e22-ae76-b4f5c0b2c486"],

Cell["Cubic Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.834795179278664*^9}},ExpressionUUID->"e4fbeb5f-05ab-4566-8a3e-\
025a533a9cff"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c\[Rho]6if2", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"CMDi6f200", ",", "krif2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.834947911760502*^9, 
   3.834947914304406*^9}, {3.834947957535968*^9, 3.8349479704802837`*^9}, {
   3.8349480487781425`*^9, 3.834948105065866*^9}, {3.8349483158342133`*^9, 
   3.8349483193845987`*^9}, {3.834949864783629*^9, 3.834949869574106*^9}, {
   3.834957963470776*^9, 3.834957967378231*^9}, {3.835018875109179*^9, 
   3.8350188762029247`*^9}, {3.83504438203627*^9, 3.8350443836235657`*^9}, {
   3.8350449852346697`*^9, 3.8350449865535607`*^9}},
 CellLabel->
  "In[280]:=",ExpressionUUID->"201acab1-f393-473c-801f-7a9db8790d71"],

Cell[BoxData["0.0702541433812077`"], "Output",
 CellChangeTimes->{
  3.834948013482303*^9, {3.834948049945756*^9, 3.834948058990469*^9}, 
   3.8349481059508953`*^9, 3.834948360850016*^9, 3.8349499580565577`*^9, 
   3.834957967763415*^9, 3.835018924610717*^9, 3.835019028526283*^9, 
   3.8350205615657897`*^9, 3.835044661527397*^9, 3.8350450387243443`*^9},
 CellLabel->
  "Out[280]=",ExpressionUUID->"e371ba5b-08da-4f15-af27-4c37f34f5723"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CP6if2", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"CMDi6f200", ",", "krif2"}], "}"}], "]"}], ",", "c\[Rho]6if2"}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.8349481210775223`*^9, 3.834948150679065*^9}, {
  3.8349481924167476`*^9, 3.8349481986802473`*^9}, {3.8349483230197706`*^9, 
  3.834948338654296*^9}, {3.8349498724373255`*^9, 3.8349498802583637`*^9}, {
  3.8349579696959915`*^9, 3.834957975592292*^9}, {3.8350188769841766`*^9, 
  3.835018878671647*^9}, {3.835044384544117*^9, 3.8350443867509155`*^9}, {
  3.8350449903821464`*^9, 3.83504499270442*^9}},
 CellLabel->
  "In[281]:=",ExpressionUUID->"596dc53c-3d95-40ac-8b69-4d08f60c0197"],

Cell[BoxData["0.6093067282426914`"], "Output",
 CellChangeTimes->{3.8350446625455046`*^9, 3.8350450388173184`*^9},
 CellLabel->
  "Out[281]=",ExpressionUUID->"fb9cbb82-28a7-433e-a0f1-1285c99f3408"]
}, Open  ]],

Cell["Absolute Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.8347951985065947`*^9}},ExpressionUUID->"0cd2f5cd-9f17-4a4d-b1a2-\
ff1ab60250c9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a\[Rho]6if2", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"AMDi6f200", ",", "krif2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.8348873709111376`*^9, 
   3.8348873755217657`*^9}, {3.8349481641806583`*^9, 
   3.8349481824982553`*^9}, {3.834948329127375*^9, 3.834948332212267*^9}, {
   3.834949883458797*^9, 3.8349498875077024`*^9}, {3.834957978394422*^9, 
   3.8349579827581863`*^9}, {3.8350188795779624`*^9, 3.83501888042175*^9}, {
   3.8350443900912123`*^9, 3.835044391591655*^9}, {3.8350449954828196`*^9, 
   3.835044996992873*^9}},
 CellLabel->
  "In[282]:=",ExpressionUUID->"58ca0f15-aa25-4ac7-a627-0aad6f193b5a"],

Cell[BoxData["0.016442834562970444`"], "Output",
 CellChangeTimes->{3.8350446642338314`*^9, 3.8350450389033237`*^9},
 CellLabel->
  "Out[282]=",ExpressionUUID->"31aef872-43da-4388-8c2d-efbc384273bb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"aP6if2", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"AMDi6f200", ",", "krif2"}], "}"}], "]"}], ",", "a\[Rho]6if2"}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8349482041094093`*^9, 
  3.8349482202691827`*^9}, {3.834948340881687*^9, 3.834948354997751*^9}, {
  3.8349498907390194`*^9, 3.8349498979971194`*^9}, {3.8349579853563895`*^9, 
  3.8349579919125147`*^9}, {3.8350188832810483`*^9, 3.83501888448921*^9}, {
  3.835044392264258*^9, 3.835044393785404*^9}, {3.835044997778226*^9, 
  3.835044999929602*^9}},
 CellLabel->
  "In[283]:=",ExpressionUUID->"4b160daf-3940-4e12-9fca-7ec4069394ff"],

Cell[BoxData["0.8783225158046581`"], "Output",
 CellChangeTimes->{3.835044665314339*^9, 3.8350450390013194`*^9},
 CellLabel->
  "Out[283]=",ExpressionUUID->"224f6f29-c030-496f-bce5-ce905d448f14"]
}, Open  ]],

Cell["Max-min Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 3.8347951985065947`*^9}, {
  3.8348543263190746`*^9, 
  3.834854330052075*^9}},ExpressionUUID->"867e3058-47fb-4ef3-a09b-\
1954aa6ab787"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mM\[Rho]6if2", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"mMDi6f200", ",", "krif2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8348874651734295`*^9, 3.8348874872060013`*^9}, {
   3.8349482319487157`*^9, 3.834948245258479*^9}, 3.8349483527075925`*^9, {
   3.8349499042423377`*^9, 3.8349499090679235`*^9}, {3.834949978751977*^9, 
   3.8349499794842105`*^9}, {3.834957994342047*^9, 3.834957998175455*^9}, {
   3.835018886286111*^9, 3.8350188870361056`*^9}, {3.835044395189496*^9, 
   3.835044396222158*^9}, {3.8350450026406775`*^9, 3.8350450038650913`*^9}},
 CellLabel->
  "In[284]:=",ExpressionUUID->"6401bce2-abe5-4927-9b18-c216607a298c"],

Cell[BoxData["0.060551583504860416`"], "Output",
 CellChangeTimes->{3.835044666861985*^9, 3.835045039089321*^9},
 CellLabel->
  "Out[284]=",ExpressionUUID->"93a323bc-2665-4205-aed0-d69bba00f2b2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mMP6if2", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"mMDi6f200", ",", "krif2"}], "}"}], "]"}], ",", 
    "mM\[Rho]6if2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8348875260806427`*^9, 
  3.8348875488478312`*^9}, {3.8349482525846663`*^9, 3.8349482707073736`*^9}, {
  3.83494834565068*^9, 3.8349483504716325`*^9}, {3.8349499122654495`*^9, 
  3.83494991854418*^9}, {3.834958000997678*^9, 3.8349580074869604`*^9}, {
  3.8350188877705455`*^9, 3.8350189082569094`*^9}, {3.8350443974385123`*^9, 
  3.8350443985852137`*^9}, {3.8350450046283274`*^9, 3.835045006371921*^9}},
 CellLabel->
  "In[285]:=",ExpressionUUID->"663bba6f-2e80-434d-8929-84f62ee4b243"],

Cell[BoxData["0.505681681498459`"], "Output",
 CellChangeTimes->{
  3.834887440036944*^9, 3.8348875533996215`*^9, 3.834948277702903*^9, 
   3.8349483617580156`*^9, {3.834949965578516*^9, 3.8349499927811513`*^9}, 
   3.834958007945059*^9, 3.8350189249776793`*^9, 3.835019029685795*^9, 
   3.835020561757756*^9, 3.835044668294428*^9, 3.835045039206321*^9},
 CellLabel->
  "Out[285]=",ExpressionUUID->"9cd8dbbf-5c54-4a14-91c5-b37efedb7e0c"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3rd imported file", "Subsubsection",
 CellChangeTimes->{{3.834947473073307*^9, 3.8349474798089457`*^9}, {
   3.8349497159535103`*^9, 3.8349497173354855`*^9}, {3.834956622993673*^9, 
   3.834956623710862*^9}, {3.8350187834860272`*^9, 3.835018783813758*^9}, {
   3.835044179773861*^9, 3.8350441837622757`*^9}, {3.8350447472475395`*^9, 
   3.8350447488425937`*^9}, {3.8350451846795616`*^9, 3.835045185196628*^9}, 
   3.8352016994485598`*^9},
 Background->RGBColor[
  1, 1, 0],ExpressionUUID->"a4db78ef-7a58-4f88-a8b2-c5287bac2b38"],

Cell["Dividing stuff", "Text",
 CellChangeTimes->{{3.83494752022309*^9, 
  3.834947523245259*^9}},ExpressionUUID->"4c8747e8-bb53-4d55-b21a-\
5f5bc25b12b8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dataf3", "=", 
   RowBox[{"StringSplit", "[", 
    RowBox[{
     RowBox[{"Import", "[", "\"\<ariadnaComputationf3.txt\>\"", "]"}], ",", 
     "\"\<]\n{\>\""}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8349434033501863`*^9, 3.834943479535334*^9}, {
   3.834943567297134*^9, 3.8349435736474867`*^9}, {3.8349441109152327`*^9, 
   3.8349441401892223`*^9}, 3.834944204627252*^9, {3.834949720382628*^9, 
   3.8349497230261507`*^9}, {3.834956627593688*^9, 3.834956631231691*^9}, {
   3.8350187858989725`*^9, 3.8350187908769827`*^9}, {3.835044188339929*^9, 
   3.835044192375786*^9}, {3.835044770661966*^9, 3.8350447715129805`*^9}, {
   3.835045243977708*^9, 3.8350452450764666`*^9}},
 CellLabel->
  "In[288]:=",ExpressionUUID->"3ed41cb5-e6f4-469a-962f-97293fe28eed"],

Cell[BoxData[
 RowBox[{
  RowBox[{"graphif3", "=", 
   RowBox[{"ToExpression", "@", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
      "dataf3", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "<>", 
      "\"\<]\>\""}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834944474381714*^9, 3.83494454689666*^9}, 
   3.8349475108233376`*^9, {3.834949726505718*^9, 3.8349497324197383`*^9}, {
   3.8349566345564103`*^9, 3.834956636582815*^9}, {3.8350188037132354`*^9, 
   3.8350188065525265`*^9}, {3.835044199446479*^9, 3.8350442063533845`*^9}, {
   3.8350447722871337`*^9, 3.835044772707575*^9}, {3.8350452457007685`*^9, 
   3.8350452463674507`*^9}},
 CellLabel->
  "In[289]:=",ExpressionUUID->"0a4754dc-d319-4850-9462-1ede3427b644"],

Cell[BoxData[
 RowBox[{
  RowBox[{"otherif3", "=", 
   RowBox[{"ToExpression", "@", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "<>", "\"\<}}\>\""}], "&"}], ",", 
      RowBox[{"StringSplit", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\"\<{\>\"", "<>", 
          RowBox[{
          "dataf3", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
         ")"}], ",", "\"\<}}\>\""}], "]"}]}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834944518155362*^9, 3.8349445533517303`*^9}, 
   3.8349446259294133`*^9, {3.8349447635371876`*^9, 3.8349447780382657`*^9}, {
   3.834944820013957*^9, 3.8349448816359477`*^9}, {3.834944915595456*^9, 
   3.834944918286141*^9}, {3.8349449615053425`*^9, 3.834944967406804*^9}, {
   3.834945029266304*^9, 3.834945031628281*^9}, {3.834945108799203*^9, 
   3.8349451822852197`*^9}, 3.834945584171259*^9, {3.834949734758335*^9, 
   3.8349497379503355`*^9}, {3.834956638769047*^9, 3.8349566423540664`*^9}, {
   3.8350188094708586`*^9, 3.8350188125204616`*^9}, {3.8350442096862793`*^9, 
   3.835044210497281*^9}, 3.8350442469097853`*^9, {3.835044779420373*^9, 
   3.835044781545072*^9}, {3.8350452471957273`*^9, 3.835045248293028*^9}},
 CellLabel->
  "In[290]:=",ExpressionUUID->"d2eeba59-cb45-4f7f-8cbf-c75c728a7706"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "CMDi3f300", "}"}], ",", 
     RowBox[{"{", "AMDi3f300", "}"}], ",", 
     RowBox[{"{", "mMDi3f300", "}"}], ",", 
     RowBox[{"{", "CMDi6f300", "}"}], ",", 
     RowBox[{"{", "AMDi6f300", "}"}], ",", 
     RowBox[{"{", "mMDi6f300", "}"}]}], "}"}], "=", "otherif3"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.834945694541313*^9, 3.834945753140644*^9}, {
  3.8349459487260857`*^9, 3.8349459670133495`*^9}, {3.8349471029719105`*^9, 
  3.8349471182020655`*^9}, {3.83494974203613*^9, 3.8349497544188104`*^9}, {
  3.834956647753375*^9, 3.8349566844693546`*^9}, {3.8350188134722548`*^9, 
  3.835018816812196*^9}, {3.835044228572632*^9, 3.835044233700058*^9}, {
  3.8350447829709044`*^9, 3.835044786739727*^9}, {3.8350452514598837`*^9, 
  3.8350452559323916`*^9}},
 CellLabel->
  "In[291]:=",ExpressionUUID->"2676c9bc-ccd7-4d51-bac5-996823ad4016"],

Cell["\[OpenCurlyDoubleQuote]Cleaning\[CloseCurlyDoubleQuote] the graph:", \
"Text",
 CellChangeTimes->{{3.8349477786156034`*^9, 
  3.8349478283202667`*^9}},ExpressionUUID->"63dcfffe-bcaa-44c3-8d6a-\
85f185bf79c5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"graphinf3", "=", 
   RowBox[{"IndexGraph", "@", "graphif3"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834946654863307*^9, 3.834946693639777*^9}, {
  3.834949757637121*^9, 3.834949759707878*^9}, {3.8349566892836237`*^9, 
  3.834956691608691*^9}, {3.83501881773997*^9, 3.8350188182388163`*^9}, {
  3.8350442520120163`*^9, 3.8350442531771507`*^9}, {3.835044787881835*^9, 
  3.8350447894788456`*^9}, {3.835045256900613*^9, 3.8350452582320957`*^9}},
 CellLabel->
  "In[292]:=",ExpressionUUID->"630b6a06-f5b3-48e5-abf3-95f048802efc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pointsif3", "=", 
   RowBox[{"VertexList", "@", "graphinf3"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834784420352569*^9, 3.8347844264642625`*^9}, {
  3.8348756828269844`*^9, 3.8348756865131674`*^9}, {3.834878831782991*^9, 
  3.8348788488376627`*^9}, {3.8349467020325813`*^9, 3.834946739879963*^9}, {
  3.8349497621629615`*^9, 3.8349497641865125`*^9}, {3.834956695197647*^9, 
  3.834956697830969*^9}, {3.835018818796376*^9, 3.8350188192932053`*^9}, {
  3.835044292816033*^9, 3.8350442934580317`*^9}, {3.835044790599271*^9, 
  3.835044791093337*^9}, {3.8350452587495804`*^9, 3.8350452594068327`*^9}},
 CellLabel->
  "In[293]:=",ExpressionUUID->"66fd5685-8711-4c8b-994a-b67b1c93b114"],

Cell[BoxData[
 RowBox[{
  RowBox[{"coordpointsif3", "=", 
   RowBox[{"VertexList", "@", "graphif3"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834879134322084*^9, 3.834879146224797*^9}, {
  3.834946724882841*^9, 3.834946736706849*^9}, {3.834949767417904*^9, 
  3.8349497706963253`*^9}, {3.8349567000470257`*^9, 3.8349567019660654`*^9}, {
  3.835018819834511*^9, 3.835018820572505*^9}, {3.835044294376539*^9, 
  3.8350442977248926`*^9}, {3.835044791824248*^9, 3.8350447923863506`*^9}, {
  3.835045259937583*^9, 3.835045260469215*^9}},
 CellLabel->
  "In[294]:=",ExpressionUUID->"ecfee441-d4ab-4491-8d4c-e040b4f87942"],

Cell["Kretchmann \[OpenCurlyDoubleQuote]real\[CloseCurlyDoubleQuote] \
values:", "Text",
 CellChangeTimes->{
  3.8347933561184683`*^9, {3.8347935444076195`*^9, 
   3.834793546974228*^9}},ExpressionUUID->"86141401-c6e6-4cbc-8159-\
b75ac2db0b11"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rvalif3", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1"}], "+", "r"}]]}], "\[Equal]", "#"}], ",", 
       RowBox[{"{", "r", "}"}]}], "]"}], "&"}], "/@", 
    RowBox[{"coordpointsif3", "\[LeftDoubleBracket]", 
     RowBox[{";;", ",", "3"}], "\[RightDoubleBracket]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834105426841242*^9, 3.8341054487325706`*^9}, {
   3.8341407674337025`*^9, 3.834140799285215*^9}, {3.8341408938375945`*^9, 
   3.834140946496229*^9}, {3.8341410168099756`*^9, 3.8341410671886864`*^9}, {
   3.8341411610986195`*^9, 3.834141210381962*^9}, {3.834141332672348*^9, 
   3.834141336755044*^9}, {3.834141461053176*^9, 3.834141468978607*^9}, {
   3.834141967115094*^9, 3.8341420256686225`*^9}, {3.8341640069512*^9, 
   3.834164012603241*^9}, {3.834164792400744*^9, 3.8341647947633886`*^9}, {
   3.83466546628111*^9, 3.834665483801684*^9}, {3.8347933895124626`*^9, 
   3.834793417249506*^9}, 3.8347960586942053`*^9, 3.834879156483405*^9, {
   3.8348862453609915`*^9, 3.8348862641404076`*^9}, 3.834886374221485*^9, {
   3.834946768449996*^9, 3.8349467823353415`*^9}, {3.8349468446168528`*^9, 
   3.834946857637892*^9}, 3.8349474594107084`*^9, {3.834949773350379*^9, 
   3.8349497766098785`*^9}, {3.8349567056279964`*^9, 
   3.8349567091770997`*^9}, {3.8350188215027976`*^9, 3.835018822410869*^9}, {
   3.835044298874358*^9, 3.8350443004592457`*^9}, 3.8350444868602533`*^9, {
   3.835044793477209*^9, 3.8350448005204644`*^9}, {3.835045261293483*^9, 
   3.8350452650936923`*^9}},
 CellLabel->
  "In[295]:=",ExpressionUUID->"efe6f09e-4864-423a-b56d-fcbfddcdaadd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"krif3", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"KHFlamm", "/.", "rvalif3"}], ")"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834792366597866*^9, 3.834792376019791*^9}, {
   3.834793346399704*^9, 3.8347933590872536`*^9}, {3.834793445378667*^9, 
   3.8347934527754736`*^9}, {3.834793487784485*^9, 3.834793489659489*^9}, 
   3.8348550102643666`*^9, {3.8348863808528233`*^9, 3.83488645374378*^9}, {
   3.834886485165092*^9, 3.834886521271514*^9}, 3.8348865820814276`*^9, {
   3.83494679091998*^9, 3.8349467979310513`*^9}, {3.8349468742957215`*^9, 
   3.834946904080855*^9}, 3.8349474644429636`*^9, {3.834949779141443*^9, 
   3.834949781745859*^9}, {3.8349567110647635`*^9, 3.8349567138998594`*^9}, {
   3.8350188233356256`*^9, 3.8350188239955263`*^9}, {3.8350443047283278`*^9, 
   3.8350443056932993`*^9}, {3.835044525959175*^9, 3.835044526610751*^9}, {
   3.8350448048490252`*^9, 3.835044806579857*^9}, {3.8350452660514517`*^9, 
   3.8350452674885726`*^9}},
 CellLabel->
  "In[296]:=",ExpressionUUID->"b26f82c0-ef37-4132-9351-9fbba83ba614"],

Cell["Estimated with cubic Mean Deviation v Calculated: (r=3)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 
  3.8349503319477153`*^9}},ExpressionUUID->"89229ce0-630a-47d3-a89e-\
55d49d93217b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraphb", "[", 
     RowBox[{"graphinf3", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsif3", ",", "#"}], "}"}], "]"}], ",", "500", ",", "3"}],
      "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"CMDi3f300", ",", "krif3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349567344957485`*^9, 3.834956749729442*^9}, {
   3.8349587420893497`*^9, 3.834958755264699*^9}, {3.835018825281867*^9, 
   3.835018828052806*^9}, {3.835044306768691*^9, 3.8350443152608557`*^9}, {
   3.8350445713666224`*^9, 3.835044576386869*^9}, {3.8350448259670086`*^9, 
   3.8350448323754845`*^9}, {3.8350452710343122`*^9, 
   3.8350452736428137`*^9}, {3.835051981091106*^9, 3.8350519936959486`*^9}},
 Background->RGBColor[1, 1, 0.85],
 CellLabel->
  "In[412]:=",ExpressionUUID->"d0f2b8b8-6d39-48d5-9d8c-c672d3b622eb"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1FO4EAYYBuBzsm2dTrZdW7WsZbtVy3bLtWxr2bat5WVjyzZXrfc8u3i/
//a7+f7gJu2rtAsMCAjIJEJuKEIThrCEIzwRiEgkIhOFqEQjOjGISSxiE4e4
xCM+CUhIIhKThKQkI4jkBJOClKQiNWlISzrSk4GMIX3JTBayko3s5CAnuchN
HvKSj/wUoCCF+IEfKUwRivITxShOCUpSitKUoSzlKE8FfqYilahMFapSjerU
oCa1qE0d6lKP+jSgIY1oTBN+oSnNaM6vtKAlrWhNG9rSjvZ0oCOd6EwXutKN
7vSgJ73ozW/0oS/96M8ABjKIwQzhd4YyjOGMYCSjGM0YxjKO8UxgIpOYzBSm
Mo3pzGAms5jNH8xhLvOYzwIWsojFLGEpy1jOClayitWsYS3rWM8GNrKJzWxh
K9vYzg52sovd7GEv+9jPAQ5yiMMc4U+OcozjnOAkpzjNX5zhLOc4zwUuconL
XOEq17jODW5yi9v8zT/c4S73uM8DHvKIxzzhKc94zgte8orXvOEt73jPBz7y
ic/8yxe+8o3/CBl/IKEITRjCEo7wRCAikYhMFKISjejEICaxiE0c4hKP+CQg
IYlITBKSkowgkhNMClKSitSkIS3pSE8GMgb+/6++Az6VhWw=
          "], {Null, CompressedData["
1:eJxN2nu4llWZB+C1RcxDZpqQRxAUUVHStBgOUSMyo5BNY0aKowyCpqCIyVg4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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[57, 280] -> 
             RGBColor[
              0.3947078663095075, 0.5035908268593602, 0.9476656845279645], 
             UndirectedEdge[46, 187] -> 
             RGBColor[
              0.2920951046698944, 0.4208156379248244, 0.9400748315466017], 
             UndirectedEdge[96, 298] -> 
             RGBColor[
              0.2693381716530716, 0.3997079803501359, 0.9386759216108402], 
             UndirectedEdge[165, 207] -> 
             RGBColor[
              0.3857065914453271, 0.5008459291732348, 0.9465417419733033], 
             UndirectedEdge[69, 224] -> 
             RGBColor[
              0.44648794089269533`, 0.5592095072017523, 0.9502061700712895], 
             UndirectedEdge[51, 110] -> 
             RGBColor[
              0.6137262303624856, 0.6962090657758122, 0.9634727095893134], 
             UndirectedEdge[122, 231] -> 
             RGBColor[
              0.2986290884990374, 0.42444170804555137`, 0.9405656216928366], 
             UndirectedEdge[71, 246] -> 
             RGBColor[
              0.7862977357044291, 0.8338090129067377, 0.978509864906552], 
             UndirectedEdge[9, 239] -> 
             RGBColor[
              0.600752361332738, 0.6819297737402797, 0.9641836757719431], 
             UndirectedEdge[99, 229] -> 
             RGBColor[
              0.3549843796301859, 0.4768990952242793, 0.9440326202478512], 
             UndirectedEdge[49, 112] -> 
             RGBColor[
              0.7588323142549476, 0.8119443931323115, 0.9765100679600983], 
             UndirectedEdge[115, 243] -> 
             RGBColor[
              0.5510038473737897, 0.6463687715953166, 0.9577961877403143], 
             UndirectedEdge[58, 95] -> 
             RGBColor[
              0.2553941066317537, 0.38576577736455786`, 0.9378556885997316], 
             UndirectedEdge[210, 239] -> 
             RGBColor[
              0.7840688279920759, 0.8312766087780746, 0.979102541966137], 
             UndirectedEdge[94, 150] -> 
             RGBColor[
              0.6071127739728424, 0.675334699344025, 0.93499820091465], 
             UndirectedEdge[21, 108] -> 
             RGBColor[
              0.6533585173899008, 0.7216960825317094, 0.9404587754841933], 
             UndirectedEdge[83, 202] -> 
             RGBColor[
              0.35185100610713066`, 0.47024602582307834`, 0.9441599996113311],
              UndirectedEdge[172, 174] -> 
             RGBColor[
              0.2502142251574948, 0.3803213935116574, 0.9375607020127205], 
             UndirectedEdge[3, 157] -> 
             RGBColor[
              0.27244420405209235`, 0.403686510791948, 0.9388266664244611], 
             UndirectedEdge[181, 246] -> 
             RGBColor[
              0.4937982857471778, 0.5971598268101136, 0.9540572570960333], 
             UndirectedEdge[159, 253] -> 
             RGBColor[
              0.24206745746015834`, 0.3717586241268511, 0.93709675564442], 
             UndirectedEdge[170, 228] -> 
             RGBColor[
              0.5933023877740102, 0.6725144498706871, 0.9647241001639453], 
             UndirectedEdge[151, 194] -> 
             RGBColor[
              0.27022578153527044`, 0.4013548080706567, 0.93870033054399], 
             UndirectedEdge[62, 100] -> 
             RGBColor[
              0.7495683366129122, 0.8000142609033352, 0.8254198640930855], 
             UndirectedEdge[76, 99] -> 
             RGBColor[
              0.47979255023969725`, 0.5772735507013926, 0.9545077976223697], 
             UndirectedEdge[131, 283] -> 
             RGBColor[
              0.7007241194181035, 0.3317918846806034, 0.43293721980795985`], 
             UndirectedEdge[173, 263] -> 
             RGBColor[
              0.6395136453604304, 0.7098608757571676, 0.9418609912418849], 
             UndirectedEdge[20, 75] -> 
             RGBColor[
              0.2688305676781513, 0.39988834984515664`, 0.9386208751788612], 
             UndirectedEdge[175, 253] -> 
             RGBColor[
              0.5649091068248269, 0.6505250860927068, 0.9619173519960432], 
             UndirectedEdge[52, 193] -> 
             RGBColor[
              0.24870058515996415`, 0.3787304619039339, 0.9374745024540908], 
             UndirectedEdge[282, 283] -> 
             RGBColor[
              0.5121559120405967, 0.6146280847778883, 0.9547937996857578], 
             UndirectedEdge[173, 279] -> 
             RGBColor[
              0.6292462795766527, 0.699471262463136, 0.9412615593275975], 
             UndirectedEdge[95, 198] -> 
             RGBColor[
              0.2183415117970935, 0.34682115092312993`, 0.9357455981382996], 
             UndirectedEdge[18, 288] -> 
             RGBColor[
              0.39750440402808424`, 0.5026187889325012, 0.9481809810200128], 
             UndirectedEdge[29, 91] -> 
             RGBColor[
              0.8213259068771428, 0.8611770367190343, 0.9773357483603935], 
             UndirectedEdge[46, 169] -> 
             RGBColor[
              0.46695856053625706`, 0.5752468236215874, 0.9519784051896312], 
             UndirectedEdge[34, 264] -> 
             RGBColor[
              0.5064482126074502, 0.6088903436047607, 0.9546494998856196], 
             UndirectedEdge[116, 277] -> 
             RGBColor[
              0.302118888840783, 0.4266542723634544, 0.9408176513417386], 
             UndirectedEdge[60, 299] -> 
             RGBColor[
              0.732492470309967, 0.7888114203305658, 0.938975735979429], 
             UndirectedEdge[205, 213] -> 
             RGBColor[
              0.7326881838398728, 0.7907808915586139, 0.9743811424226083], 
             UndirectedEdge[240, 299] -> 
             RGBColor[
              0.7407314331453869, 0.7955001815214058, 0.9396243373141485], 
             UndirectedEdge[184, 214] -> 
             RGBColor[
              0.4216818741613973, 0.5394274210208125, 0.9481548170125988], 
             UndirectedEdge[39, 59] -> 
             RGBColor[
              0.5840766088448872, 0.6510085776960703, 0.9330349089491223], 
             UndirectedEdge[246, 299] -> 
             RGBColor[
              0.8062238560354191, 0.8486698808235625, 0.9447801407507017], 
             UndirectedEdge[21, 114] -> 
             RGBColor[
              0.5226189969340207, 0.619207425997318, 0.9571029958250703], 
             UndirectedEdge[204, 253] -> 
             RGBColor[
              0.3632661135907588, 0.4887159737797495, 0.944380737687226], 
             UndirectedEdge[202, 214] -> 
             RGBColor[
              0.34138026791224807`, 0.46174540885509247`, 0.9433357047450521],
              UndirectedEdge[26, 39] -> 
             RGBColor[
              0.6280283315409714, 0.6972046249498258, 0.9355378945359174], 
             UndirectedEdge[118, 220] -> 
             RGBColor[
              0.7727494593424851, 0.8226403855483192, 0.9728963677826209], 
             UndirectedEdge[28, 126] -> 
             RGBColor[
              0.9595539113698628, 0.9685420965006742, 0.9181851337232269], 
             UndirectedEdge[9, 237] -> 
             RGBColor[
              0.5021260884396773, 0.6046144692043592, 0.9545211651021356], 
             UndirectedEdge[174, 297] -> 
             RGBColor[
              0.49266861807233453`, 0.5846627307841268, 0.956213816730205], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.36204530696515597`, 0.476278990455697, 0.9451667248875545], 
             UndirectedEdge[63, 139] -> 
             RGBColor[
              0.25720634182267227`, 0.38767055145256074`, 0.9379588927128928],
              UndirectedEdge[124, 150] -> 
             RGBColor[
              0.7777733737625578, 0.8257249038285241, 0.9466281579331988], 
             UndirectedEdge[127, 165] -> 
             RGBColor[
              0.4012965744630507, 0.5172319897868765, 0.9474295684428495], 
             UndirectedEdge[8, 22] -> 
             RGBColor[
              0.691878504487605, 0.757227280857681, 0.9716547154290397], 
             UndirectedEdge[127, 137] -> 
             RGBColor[
              0.258493780684348, 0.3890237313245204, 0.93803221045147], 
             UndirectedEdge[21, 213] -> 
             RGBColor[
              0.6044024472472698, 0.6835065662067726, 0.965145793591442], 
             UndirectedEdge[41, 278] -> 
             RGBColor[
              0.4784979802348863, 0.5862126578814096, 0.9524454052074735], 
             UndirectedEdge[69, 249] -> 
             RGBColor[
              0.4334748384171492, 0.5479382118949823, 0.9493769866885824], 
             UndirectedEdge[100, 136] -> 
             RGBColor[
              0.5294820446640649, 0.6288964026093988, 0.9561019125940436], 
             UndirectedEdge[88, 222] -> 
             RGBColor[
              0.6277320620464115, 0.7002393785089549, 0.9547001599263796], 
             UndirectedEdge[153, 216] -> 
             RGBColor[
              0.3164460245855546, 0.44159439105824516`, 0.9416379033972111], 
             UndirectedEdge[60, 121] -> 
             RGBColor[
              0.440374721838486, 0.5548909808739919, 0.9495468487734228], 
             UndirectedEdge[203, 206] -> 
             RGBColor[
              0.8864133843542865, 0.9119161235033522, 0.9768980754957435], 
             UndirectedEdge[50, 108] -> 
             RGBColor[
              0.8677240114998812, 0.4147691049891332, 0.42219461711355066`], 
             UndirectedEdge[98, 181] -> 
             RGBColor[
              0.419819315863012, 0.5371003663435339, 0.948233361592856], 
             UndirectedEdge[267, 285] -> 
             RGBColor[
              0.7534209554942153, 0.8030959088214147, 0.8219463123639406], 
             UndirectedEdge[156, 178] -> 
             RGBColor[
              0.8973766440839552, 0.9154914124530772, 0.7025416799580892], 
             UndirectedEdge[185, 295] -> 
             RGBColor[
              0.27732932483543243`, 0.40462108470900304`, 0.9392586493184036],
              UndirectedEdge[83, 156] -> 
             RGBColor[
              0.737528689202848, 0.7881738979478126, 0.6882798749469776], 
             UndirectedEdge[44, 150] -> 
             RGBColor[
              0.6255201738943952, 0.6946820437581405, 0.9360464751088746], 
             UndirectedEdge[223, 274] -> 
             RGBColor[
              0.5445356764395046, 0.6411176190430841, 0.9572869896306764], 
             UndirectedEdge[20, 142] -> 
             RGBColor[
              0.4844225303394848, 0.5787044354390799, 0.9553153610405235], 
             UndirectedEdge[87, 264] -> 
             RGBColor[
              0.3136752531508944, 0.4381039003056607, 0.9415012840531858], 
             UndirectedEdge[16, 192] -> 
             RGBColor[
              0.8046735454166607, 0.848247757374639, 0.9809241392065199], 
             UndirectedEdge[75, 143] -> 
             RGBColor[
              0.2594218947519811, 0.38999923805543346`, 0.9380850651746], 
             UndirectedEdge[230, 263] -> 
             RGBColor[
              0.5088728914924766, 0.6074033242029714, 0.9561838994222953], 
             UndirectedEdge[52, 82] -> 
             RGBColor[
              0.592397947021208, 0.664917765582304, 0.9631011855832969], 
             UndirectedEdge[34, 213] -> 
             RGBColor[
              0.7391525298059147, 0.7960289388293138, 0.9748900394167346], 
             UndirectedEdge[145, 219] -> 
             RGBColor[
              0.30377356284579343`, 0.42570618169391605`, 0.9410102762562711],
              UndirectedEdge[237, 295] -> 
             RGBColor[
              0.4907293780462085, 0.5947432114768563, 0.953794976793579], 
             UndirectedEdge[257, 259] -> 
             RGBColor[
              0.7074614149039811, 0.7684325994777599, 0.9420863339119094], 
             UndirectedEdge[116, 241] -> 
             RGBColor[
              0.486602850002041, 0.5925743380206141, 0.9531437445995254], 
             UndirectedEdge[95, 105] -> 
             RGBColor[
              0.21903698377507214`, 0.34755213606745583`, 0.9357852042385869],
              UndirectedEdge[115, 146] -> 
             RGBColor[
              0.3631881830826408, 0.48199657541938223`, 0.9448207037510586], 
             UndirectedEdge[16, 170] -> 
             RGBColor[
              0.9097516782064778, 0.9308753099231326, 0.9912541212838862], 
             UndirectedEdge[199, 226] -> 
             RGBColor[
              0.8645846146328022, 0.603060253290456, 0.46538578073819725`], 
             UndirectedEdge[78, 130] -> 
             RGBColor[
              0.4750596816535735, 0.5834337430553026, 0.9521712895396981], 
             UndirectedEdge[155, 214] -> 
             RGBColor[
              0.6720276919466803, 0.7414507633603233, 0.9697014973548079], 
             UndirectedEdge[185, 297] -> 
             RGBColor[
              0.47521383472687717`, 0.5663166467908672, 0.9552197926407192], 
             UndirectedEdge[45, 53] -> 
             RGBColor[
              0.85020270935025, 0.5662319904543961, 0.46072910655553023`], 
             UndirectedEdge[49, 204] -> 
             RGBColor[
              0.5300514952257086, 0.6284963151669423, 0.9563850236007145], 
             UndirectedEdge[69, 254] -> 
             RGBColor[
              0.7447293249695612, 0.7991252126910227, 0.9501140886731501], 
             UndirectedEdge[102, 295] -> 
             RGBColor[
              0.6040196308869267, 0.6837511755799068, 0.9648561509614835], 
             UndirectedEdge[14, 254] -> 
             RGBColor[
              0.7193398044969648, 0.7785128561865061, 0.9481153326166694], 
             UndirectedEdge[125, 299] -> 
             RGBColor[
              0.983978839989595, 0.9863261566719803, 0.8562112676467464], 
             UndirectedEdge[16, 44] -> 
             RGBColor[
              0.6060666566539578, 0.6800974531258008, 0.9663346737245326], 
             UndirectedEdge[49, 84] -> 
             RGBColor[
              0.5802827212543641, 0.6701386804098041, 0.960101127944242], 
             UndirectedEdge[186, 230] -> 
             RGBColor[
              0.49790634307177006`, 0.5962788256267879, 0.9555446500911828], 
             UndirectedEdge[215, 282] -> 
             RGBColor[
              0.75871324812611, 0.4738721489586602, 0.4495933349236294], 
             UndirectedEdge[134, 159] -> 
             RGBColor[
              0.44488559238175496`, 0.5397464324821911, 0.9526525169939632], 
             UndirectedEdge[26, 266] -> 
             RGBColor[
              0.346050041248278, 0.47183356478014066`, 0.9433559022173952], 
             UndirectedEdge[142, 150] -> 
             RGBColor[
              0.8507583529544813, 0.883636914392597, 0.9532902987241476], 
             UndirectedEdge[114, 221] -> 
             RGBColor[
              0.8180306005680308, 0.858652175434273, 0.9822634637518125], 
             UndirectedEdge[147, 172] -> 
             RGBColor[
              0.3006427090185608, 0.43078175397192797`, 0.9405256476036032], 
             UndirectedEdge[35, 211] -> 
             RGBColor[
              0.8337918110540588, 0.8703069737314599, 0.9840090013447146], 
             UndirectedEdge[124, 295] -> 
             RGBColor[
              0.46903391442707987`, 0.5771298567413496, 0.9520870304243794], 
             UndirectedEdge[166, 233] -> 
             RGBColor[
              0.44110848224427723`, 0.5529420698882175, 0.9502552216336996], 
             UndirectedEdge[88, 290] -> 
             RGBColor[
              0.3320131853713614, 0.4616476858316789, 0.9423892764634223], 
             UndirectedEdge[134, 235] -> 
             RGBColor[
              0.44476938565271584`, 0.5396242918420389, 0.952645899192657], 
             UndirectedEdge[185, 239] -> 
             RGBColor[
              0.512512395127146, 0.5954913797711976, 0.9589275952320759], 
             UndirectedEdge[260, 278] -> 
             RGBColor[
              0.40481043097600505`, 0.5177276432531178, 0.947920745773615], 
             UndirectedEdge[15, 242] -> 
             RGBColor[
              0.29835142625391187`, 0.4285848610805725, 0.9403874223955152], 
             UndirectedEdge[4, 266] -> 
             RGBColor[
              0.34642322061652014`, 0.4722257999571017, 0.9433771542303471], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.6065422983813058, 0.6850678173612766, 0.9654166496757054], 
             UndirectedEdge[3, 123] -> 
             RGBColor[
              0.3099687034431113, 0.43915848621124187`, 0.9411089429660164], 
             UndirectedEdge[28, 184] -> 
             RGBColor[
              0.6848782979149605, 0.7471188355089193, 0.8943178557505845], 
             UndirectedEdge[116, 210] -> 
             RGBColor[
              0.5706376161237237, 0.6592466802020027, 0.9608196052367881], 
             UndirectedEdge[118, 120] -> 
             RGBColor[
              0.4991483788086781, 0.602668930778001, 0.9541563614067264], 
             UndirectedEdge[15, 89] -> 
             RGBColor[
              0.6614635219707092, 0.7266947620445523, 0.8875562360534994], 
             UndirectedEdge[11, 283] -> 
             RGBColor[
              0.3265670234368657, 0.44789481198355907`, 0.9423730924253303], 
             UndirectedEdge[157, 201] -> 
             RGBColor[
              0.6358824829192178, 0.7000489637179603, 0.8259257000633491], 
             UndirectedEdge[196, 279] -> 
             RGBColor[
              0.3875807468608133, 0.5078330337168003, 0.9461917711983907], 
             UndirectedEdge[7, 11] -> 
             RGBColor[
              0.35428096798109643`, 0.47059642349793884`, 0.9444989719398273],
              UndirectedEdge[76, 284] -> 
             RGBColor[
              0.8327519145667567, 0.8247247496416221, 0.6372776110244787], 
             UndirectedEdge[34, 108] -> 
             RGBColor[
              0.7881085999485458, 0.8342184551542504, 0.9502030213094859], 
             UndirectedEdge[46, 213] -> 
             RGBColor[
              0.6087480619909744, 0.6872705192808218, 0.9654226923202346], 
             UndirectedEdge[261, 278] -> 
             RGBColor[
              0.46176309066057986`, 0.5717177376521521, 0.9513790728418805], 
             UndirectedEdge[58, 66] -> 
             RGBColor[
              0.27567525202146226`, 0.40708254706802915`, 0.9390106698264096],
              UndirectedEdge[194, 297] -> 
             RGBColor[
              0.5050807430167377, 0.5977086610748695, 0.9569206688836955], 
             UndirectedEdge[283, 297] -> 
             RGBColor[
              0.5979066809426705, 0.6825963937726863, 0.9626711802293508], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.24342934268547997`, 0.3731900518471747, 0.9371743129932734], 
             UndirectedEdge[6, 169] -> 
             RGBColor[
              0.7905447017646052, 0.8326506537868661, 0.7770055467258628], 
             UndirectedEdge[11, 172] -> 
             RGBColor[
              0.2361475500098006, 0.36553642605271397`, 0.9367596256728403], 
             UndirectedEdge[4, 82] -> 
             RGBColor[
              0.6114885560471186, 0.6849832060830585, 0.9641883675252974], 
             UndirectedEdge[140, 230] -> 
             RGBColor[
              0.4692921371350496, 0.5662034809418525, 0.9539151133940107], 
             UndirectedEdge[207, 232] -> 
             RGBColor[
              0.3190851849816595, 0.44507589984347984`, 0.9417622915655776], 
             UndirectedEdge[147, 244] -> 
             RGBColor[
              0.39985922884287856`, 0.5204841613048861, 0.9467757863535791], 
             UndirectedEdge[56, 296] -> 
             RGBColor[
              0.2769179704014046, 0.4066056603189617, 0.9391467274545535], 
             UndirectedEdge[243, 294] -> 
             RGBColor[
              0.5034698459194209, 0.6060373552550857, 0.9545352281939522], 
             UndirectedEdge[211, 216] -> 
             RGBColor[
              0.6141597590771726, 0.693376779198122, 0.9651143141035009], 
             UndirectedEdge[107, 141] -> 
             RGBColor[
              0.39992932843932827`, 0.5161562402578621, 0.9473188168724498], 
             UndirectedEdge[19, 175] -> 
             RGBColor[
              0.5515834164979734, 0.6365189406616182, 0.9611584736455212], 
             UndirectedEdge[17, 158] -> 
             RGBColor[
              0.3494950828464679, 0.4728829258661219, 0.9436462509690331], 
             UndirectedEdge[115, 242] -> 
             RGBColor[
              0.37349828668503027`, 0.49283314800381783`, 0.9454078488987833],
              UndirectedEdge[159, 292] -> 
             RGBColor[
              0.27105807636590074`, 0.39721744946411164`, 0.93893124798623], 
             UndirectedEdge[34, 205] -> 
             RGBColor[
              0.6012188194314059, 0.6871355480704013, 0.9617492942841932], 
             UndirectedEdge[23, 180] -> 
             RGBColor[
              0.6081546479248325, 0.6755261609032095, 0.9298782894712244], 
             UndirectedEdge[47, 158] -> 
             RGBColor[
              0.3800464113222206, 0.5035988326244347, 0.9454371991609738], 
             UndirectedEdge[130, 199] -> 
             RGBColor[
              0.6409431342216485, 0.7149811423026946, 0.9675547559841214], 
             UndirectedEdge[112, 204] -> 
             RGBColor[
              0.6503375447485182, 0.7230010585514706, 0.9682072440476084], 
             UndirectedEdge[217, 247] -> 
             RGBColor[
              0.3030158026191989, 0.43555077279692944`, 0.9405775021431313], 
             UndirectedEdge[102, 185] -> 
             RGBColor[
              0.5271763750748035, 0.6071840393383277, 0.9603262587301729], 
             UndirectedEdge[136, 137] -> 
             RGBColor[
              0.3968833789657082, 0.5089723150133991, 0.9475078609441018], 
             UndirectedEdge[138, 258] -> 
             RGBColor[
              0.39685324183851367`, 0.5034515601671051, 0.9480057947740057], 
             UndirectedEdge[79, 277] -> 
             RGBColor[
              0.3195408557115598, 0.4417443044134056, 0.9419277636651041], 
             UndirectedEdge[41, 259] -> 
             RGBColor[
              0.4250148723712446, 0.5425482534045294, 0.9483025497349687], 
             UndirectedEdge[225, 287] -> 
             RGBColor[
              0.6594201782844655, 0.7304412091352559, 0.9689824471341193], 
             UndirectedEdge[167, 194] -> 
             RGBColor[
              0.4796931178074061, 0.5778756553082416, 0.9543902676636757], 
             UndirectedEdge[64, 219] -> 
             RGBColor[
              0.49352130621784085`, 0.5989802353792091, 0.9534703372211231], 
             UndirectedEdge[83, 293] -> 
             RGBColor[
              0.5227841698996936, 0.6234587661398625, 0.9555746313574687], 
             UndirectedEdge[31, 95] -> 
             RGBColor[
              0.5511041961945649, 0.6304306336598455, 0.9619772136599583], 
             UndirectedEdge[256, 299] -> 
             RGBColor[
              0.624830419776828, 0.6932526533558918, 0.9319696985509995], 
             UndirectedEdge[129, 269] -> 
             RGBColor[
              0.6432126127792965, 0.7212018487908839, 0.9650730801443752], 
             UndirectedEdge[83, 126] -> 
             RGBColor[
              0.7068282258111822, 0.7693512989805533, 0.9728463898515202], 
             UndirectedEdge[23, 81] -> 
             RGBColor[
              0.6072942706481252, 0.67462184983432, 0.9298292922581302], 
             UndirectedEdge[235, 252] -> 
             RGBColor[
              0.5152195552594221, 0.5949153297599825, 0.959600089663382], 
             UndirectedEdge[6, 264] -> 
             RGBColor[
              0.699629886020858, 0.7575357542215474, 0.7702092943253513], 
             UndirectedEdge[167, 215] -> 
             RGBColor[
              0.7989553439212713, 0.5059623511107736, 0.4531579878060116], 
             UndirectedEdge[273, 285] -> 
             RGBColor[
              0.9218714477784803, 0.9369219855723967, 0.83730783963813], 
             UndirectedEdge[267, 273] -> 
             RGBColor[
              0.6803657690109413, 0.7484609857749316, 0.9700805195470108], 
             UndirectedEdge[66, 109] -> 
             RGBColor[
              0.6341152141163, 0.6977486328642946, 0.7815417712862271], 
             UndirectedEdge[104, 173] -> 
             RGBColor[
              0.8423027965251915, 0.8771326152006627, 0.9575725714379077], 
             UndirectedEdge[9, 185] -> 
             RGBColor[
              0.28872603522890133`, 0.414492342436506, 0.9399848376269602], 
             UndirectedEdge[233, 288] -> 
             RGBColor[
              0.3787239467017815, 0.48737196762504764`, 0.9467025146242043], 
             UndirectedEdge[139, 147] -> 
             RGBColor[
              0.2894133260317646, 0.41897896046880156`, 0.9398861508548886], 
             UndirectedEdge[65, 103] -> 
             RGBColor[
              0.2527067463322664, 0.38294119130131254`, 0.9377026474062691], 
             UndirectedEdge[33, 124] -> 
             RGBColor[
              0.4140157167260182, 0.5235022403631042, 0.9488000429652137], 
             UndirectedEdge[82, 226] -> 
             RGBColor[
              0.8855364792356787, 0.6197173412006365, 0.46567283913533664`], 
             UndirectedEdge[6, 221] -> 
             RGBColor[
              0.9615263598862207, 0.9679513827723016, 0.7932342078195009], 
             UndirectedEdge[125, 136] -> 
             RGBColor[
              0.773257287844238, 0.8201508990762657, 0.8727303961365369], 
             UndirectedEdge[112, 292] -> 
             RGBColor[
              0.6210375515257403, 0.6976228770823791, 0.9663402743884197], 
             UndirectedEdge[58, 67] -> 
             RGBColor[
              0.3147859503839303, 0.4441799286603366, 0.9413848081717391], 
             UndirectedEdge[73, 105] -> 
             RGBColor[
              0.5742261751712128, 0.645032501337024, 0.9575636217836341], 
             UndirectedEdge[263, 298] -> 
             RGBColor[
              0.2676516855672763, 0.39824723086787533`, 0.9385684602087545], 
             UndirectedEdge[60, 170] -> 
             RGBColor[
              0.6877386139934073, 0.7541720369259235, 0.9709769464635607], 
             UndirectedEdge[10, 129] -> 
             RGBColor[
              0.5142087229014761, 0.6146251551622546, 0.9554233651673703], 
             UndirectedEdge[53, 234] -> 
             RGBColor[
              0.595460786549799, 0.6766712510945437, 0.964157345167394], 
             UndirectedEdge[51, 154] -> 
             RGBColor[
              0.4242605287845259, 0.5402321555453374, 0.9487138990467832], 
             UndirectedEdge[17, 84] -> 
             RGBColor[
              0.39237789864977984`, 0.5081604675136281, 0.9468941211109456], 
             UndirectedEdge[98, 160] -> 
             RGBColor[
              0.44983507810882917`, 0.5630985109647846, 0.950145939421263], 
             UndirectedEdge[25, 147] -> 
             RGBColor[
              0.6779840950627961, 0.40621351904191677`, 0.44382354470385293`],
              UndirectedEdge[159, 204] -> 
             RGBColor[
              0.3003580695886787, 0.42259563093320296`, 0.9407982176454186], 
             UndirectedEdge[37, 94] -> 
             RGBColor[
              0.26220029554884755`, 0.3929195134537252, 0.9382432909897059], 
             UndirectedEdge[37, 283] -> 
             RGBColor[
              0.36384915196270884`, 0.48708069288769673`, 0.9444962544909106],
              UndirectedEdge[9, 142] -> 
             RGBColor[
              0.5534156040124721, 0.6449131250329254, 0.9594753595238847], 
             UndirectedEdge[51, 109] -> 
             RGBColor[
              0.7544421377703565, 0.8035287033992147, 0.7895503511085686], 
             UndirectedEdge[123, 257] -> 
             RGBColor[
              0.661138288975925, 0.7283098360668843, 0.9391346652897057], 
             UndirectedEdge[212, 294] -> 
             RGBColor[
              0.5482120911949048, 0.6413673504182201, 0.9587369511472479], 
             UndirectedEdge[237, 297] -> 
             RGBColor[
              0.6886138879376532, 0.7564387735587205, 0.9697561201158946], 
             UndirectedEdge[163, 197] -> 
             RGBColor[
              0.2489547857174178, 0.3789976428070639, 0.9374889787997818], 
             UndirectedEdge[76, 229] -> 
             RGBColor[
              0.5795951569933805, 0.6686300448006206, 0.9606968213637311], 
             UndirectedEdge[18, 24] -> 
             RGBColor[
              0.4680242373596165, 0.5754542075154042, 0.9522440459013393], 
             UndirectedEdge[44, 124] -> 
             RGBColor[
              0.4316420483384415, 0.5420286324617334, 0.9498038364747203], 
             UndirectedEdge[26, 82] -> 
             RGBColor[
              0.6111153766788764, 0.6845909709060974, 0.9641671155123455], 
             UndirectedEdge[7, 106] -> 
             RGBColor[
              0.6114976692593893, 0.694265044543691, 0.9633894154536191], 
             UndirectedEdge[53, 255] -> 
             RGBColor[
              0.6694782306783149, 0.7396555835525306, 0.9691847490161849], 
             UndirectedEdge[89, 242] -> 
             RGBColor[
              0.6258487152397669, 0.6915931249194112, 0.885442647504596], 
             UndirectedEdge[121, 181] -> 
             RGBColor[
              0.37172328544871613`, 0.4963897593252752, 0.9449068569401653], 
             UndirectedEdge[217, 273] -> 
             RGBColor[
              0.5715993020951882, 0.6545159741001383, 0.9627590288991033], 
             UndirectedEdge[141, 240] -> 
             RGBColor[
              0.5133621649956918, 0.6158095581023102, 0.9548328966174845], 
             UndirectedEdge[42, 159] -> 
             RGBColor[
              0.38431906637867186`, 0.4916213435889752, 0.9471696530995], 
             UndirectedEdge[51, 52] -> 
             RGBColor[
              0.38039026010529997`, 0.4964535044860311, 0.9461301741527866], 
             UndirectedEdge[170, 225] -> 
             RGBColor[
              0.8891437661060049, 0.9144431202010876, 0.9892885202308428], 
             UndirectedEdge[51, 179] -> 
             RGBColor[
              0.4809440485149273, 0.5893285713392712, 0.9523257228007358], 
             UndirectedEdge[36, 198] -> 
             RGBColor[
              0.20307971734591004`, 0.3307800373012789, 0.9348764615221064], 
             UndirectedEdge[150, 295] -> 
             RGBColor[
              0.6629120399830336, 0.7297832680377567, 0.9383296690585337], 
             UndirectedEdge[140, 196] -> 
             RGBColor[
              0.35826735828716394`, 0.47702280374971306`, 0.9445224170843936],
              UndirectedEdge[31, 73] -> 
             RGBColor[
              0.9062933875907055, 0.9279109989294136, 0.9837556312050053], 
             UndirectedEdge[188, 212] -> 
             RGBColor[
              0.7105367433329086, 0.7737959712617091, 0.9717833202981889], 
             UndirectedEdge[172, 244] -> 
             RGBColor[
              0.36424933442508334`, 0.48559907790232987`, 0.944654737509352], 
             UndirectedEdge[7, 63] -> 
             RGBColor[
              0.38656914278076426`, 0.5045333424009121, 0.9463377357285945], 
             UndirectedEdge[128, 218] -> 
             RGBColor[
              0.6082185821379398, 0.6761154531939055, 0.9328744131248654], 
             UndirectedEdge[138, 154] -> 
             RGBColor[
              0.46734075968648614`, 0.5752066277338344, 0.9521053326314709], 
             UndirectedEdge[1, 297] -> 
             RGBColor[
              0.5232962453503284, 0.6168543089570268, 0.9579580147941726], 
             UndirectedEdge[90, 123] -> 
             RGBColor[
              0.2768709103312551, 0.4043706071293929, 0.9392240726120933], 
             UndirectedEdge[8, 61] -> 
             RGBColor[
              0.9514523784551627, 0.9631412551690983, 0.9610788812246047], 
             UndirectedEdge[201, 209] -> 
             RGBColor[
              0.8960250127664977, 0.5694479992810145, 0.3656815769263804], 
             UndirectedEdge[44, 94] -> 
             RGBColor[
              0.26098144854872607`, 0.39163842797723425`, 0.9381738794561716],
              UndirectedEdge[114, 213] -> 
             RGBColor[
              0.7888384439011327, 0.8353751421080718, 0.9794790897887778], 
             UndirectedEdge[82, 107] -> 
             RGBColor[
              0.6084503936928111, 0.6817899048180622, 0.964015348673778], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.5988390261774295, 0.6632042292016977, 0.8839044856697502], 
             UndirectedEdge[182, 268] -> 
             RGBColor[
              0.7346201961047268, 0.7896031786386304, 0.9039517072132309], 
             UndirectedEdge[157, 229] -> 
             RGBColor[
              0.3657041860553098, 0.48816629145206814`, 0.9446430973652296], 
             UndirectedEdge[99, 157] -> 
             RGBColor[
              0.2659015793016266, 0.39680979735284005`, 0.938454073623868], 
             UndirectedEdge[249, 288] -> 
             RGBColor[
              0.2619394672822573, 0.3895458505436177, 0.9383419256649359], 
             UndirectedEdge[66, 138] -> 
             RGBColor[
              0.43730813183210127`, 0.545972214538538, 0.950309640911494], 
             UndirectedEdge[215, 286] -> 
             RGBColor[
              0.6432263500278798, 0.371376374194072, 0.4417820638520893], 
             UndirectedEdge[83, 275] -> 
             RGBColor[
              0.7059410676451032, 0.7686439031401888, 0.9727617719136641], 
             UndirectedEdge[95, 289] -> 
             RGBColor[
              0.37895689979684066`, 0.4937484334583484, 0.9461576430087557], 
             UndirectedEdge[37, 75] -> 
             RGBColor[
              0.2902539118691529, 0.4224056429083738, 0.9398409029375412], 
             UndirectedEdge[88, 260] -> 
             RGBColor[
              0.28166447633286396`, 0.41337760155806647`, 0.9393517472906805],
              UndirectedEdge[60, 82] -> 
             RGBColor[
              0.7136442674137546, 0.7747544614716704, 0.9708808270840932], 
             UndirectedEdge[50, 227] -> 
             RGBColor[
              0.6313763031600801, 0.21944192563687334`, 0.42217499848709206`],
              UndirectedEdge[12, 248] -> 
             RGBColor[
              0.6522441981009914, 0.7245492521942082, 0.9683762676445103], 
             UndirectedEdge[103, 164] -> 
             RGBColor[
              0.2208057289424365, 0.3494111993832765, 0.9358859316592443], 
             UndirectedEdge[127, 228] -> 
             RGBColor[
              0.2889450936638527, 0.4210299919907361, 0.9397663676769723], 
             UndirectedEdge[163, 184] -> 
             RGBColor[
              0.33522720785912663`, 0.46295536104745694`, 0.9426481201993793],
              UndirectedEdge[11, 183] -> 
             RGBColor[
              0.22800881920909558`, 0.35698210395583596`, 0.9362961369939133],
              UndirectedEdge[226, 266] -> 
             RGBColor[
              0.7088262556152798, 0.4778790704499986, 0.45179869693870306`], 
             UndirectedEdge[98, 178] -> 
             RGBColor[
              0.6453975027991554, 0.7205475371198228, 0.9669051905312708], 
             UndirectedEdge[200, 255] -> 
             RGBColor[
              0.4001439971721491, 0.5195808903409929, 0.9470398472748369], 
             UndirectedEdge[223, 234] -> 
             RGBColor[
              0.4512533277794971, 0.5624931692123734, 0.9507429819274961], 
             UndirectedEdge[111, 190] -> 
             RGBColor[
              0.5789734619268443, 0.5951607891275901, 0.6088088049584353], 
             UndirectedEdge[85, 181] -> 
             RGBColor[
              0.5728457505794207, 0.6590069445483258, 0.9618712655233757], 
             UndirectedEdge[57, 134] -> 
             RGBColor[
              0.645655131263076, 0.7221654024413966, 0.9659623286321615], 
             UndirectedEdge[9, 131] -> 
             RGBColor[
              0.6777555327446361, 0.3118976493387788, 0.4314736817754503], 
             UndirectedEdge[184, 189] -> 
             RGBColor[
              0.28963143179688483`, 0.4150313094668657, 0.9400515082055405], 
             UndirectedEdge[194, 286] -> 
             RGBColor[
              0.24609962696731857`, 0.3759966899331892, 0.9373263817327925], 
             UndirectedEdge[171, 298] -> 
             RGBColor[
              0.6521827783011305, 0.4434489455814107, 0.45257225790510297`], 
             UndirectedEdge[108, 213] -> 
             RGBColor[
              0.9195779643570127, 0.937863798642463, 0.9628348694479009], 
             UndirectedEdge[158, 175] -> 
             RGBColor[
              0.6305481291786907, 0.7077269164944142, 0.9660870481986568], 
             UndirectedEdge[37, 297] -> 
             RGBColor[
              0.5158840714504834, 0.609063644229321, 0.9575359024559051], 
             UndirectedEdge[68, 234] -> 
             RGBColor[
              0.5849966583460661, 0.6683274393060804, 0.9631592672778845], 
             UndirectedEdge[38, 252] -> 
             RGBColor[
              0.9221033741881919, 0.935609776759841, 0.7159668887340787], 
             UndirectedEdge[42, 252] -> 
             RGBColor[
              0.7204954149090549, 0.7810205327088053, 0.9732621249615756], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.3468400683159113, 0.4700814550677808, 0.9434954502695099], 
             UndirectedEdge[184, 216] -> 
             RGBColor[
              0.39019422827946965`, 0.5123883616286934, 0.9460838090841275], 
             UndirectedEdge[16, 59] -> 
             RGBColor[
              0.5642507871936038, 0.6361463230437143, 0.9639533218198006], 
             UndirectedEdge[7, 185] -> 
             RGBColor[
              0.3508928597833333, 0.4670353069636227, 0.9443060241902217], 
             UndirectedEdge[127, 299] -> 
             RGBColor[
              0.627155453781721, 0.6956964115107047, 0.9321021057979987], 
             UndirectedEdge[166, 217] -> 
             RGBColor[
              0.3003802120756296, 0.43304902646989657`, 0.9404175807537812], 
             UndirectedEdge[101, 207] -> 
             RGBColor[
              0.28323507518726165`, 0.41402433661848265`, 0.9394779542704859],
              UndirectedEdge[14, 69] -> 
             RGBColor[
              0.4992902319682852, 0.6043853289373028, 0.9537251025023779], 
             UndirectedEdge[51, 107] -> 
             RGBColor[
              0.396442706776903, 0.5133256437217892, 0.9470443372432676], 
             UndirectedEdge[74, 233] -> 
             RGBColor[
              0.3864724200438864, 0.4955161043891848, 0.9471437787181981], 
             UndirectedEdge[158, 252] -> 
             RGBColor[
              0.6438828283444054, 0.7183596436483887, 0.9673589237091091], 
             UndirectedEdge[86, 110] -> 
             RGBColor[
              0.7706157051818607, 0.820797600991729, 0.9777535204743977], 
             UndirectedEdge[58, 73] -> 
             RGBColor[
              0.6105832980278945, 0.6832461426341261, 0.9596341061447787], 
             UndirectedEdge[13, 96] -> 
             RGBColor[
              0.6555945524961285, 0.7203075894200754, 0.8392620238855927], 
             UndirectedEdge[16, 53] -> 
             RGBColor[
              0.8884592309294101, 0.9138972904324834, 0.9892232286546074], 
             UndirectedEdge[44, 170] -> 
             RGBColor[
              0.5830738700227989, 0.6617636291886815, 0.9641416012097497], 
             UndirectedEdge[27, 32] -> 
             RGBColor[
              0.4791409611600342, 0.5707841640197405, 0.9553896321166214], 
             UndirectedEdge[116, 164] -> 
             RGBColor[
              0.2955915764806756, 0.41979365321747464`, 0.9404459305591237], 
             UndirectedEdge[70, 300] -> 
             RGBColor[
              0.2104636493548522, 0.33854101801100667`, 0.9352969655264671], 
             UndirectedEdge[79, 116] -> 
             RGBColor[
              0.41509826436505515`, 0.5339589859727787, 0.9476706722417265], 
             UndirectedEdge[137, 195] -> 
             RGBColor[
              0.5839747327809351, 0.657351620696429, 0.9650047362945007], 
             UndirectedEdge[156, 214] -> 
             RGBColor[
              0.7270579510079653, 0.7796732809798268, 0.6874555800806986], 
             UndirectedEdge[14, 249] -> 
             RGBColor[
              0.4080853179445528, 0.5273258553904656, 0.9473782306321017], 
             UndirectedEdge[84, 89] -> 
             RGBColor[
              0.7554899943665773, 0.8062703684776078, 0.8940629347689298], 
             UndirectedEdge[98, 246] -> 
             RGBColor[
              0.562202137978234, 0.6554600483852473, 0.9586777581973862], 
             UndirectedEdge[4, 107] -> 
             RGBColor[
              0.281368751323916, 0.41306677582361356`, 0.9393349061889069], 
             UndirectedEdge[20, 295] -> 
             RGBColor[
              0.29657621736803713`, 0.4248507890842397, 0.9403547313749097], 
             UndirectedEdge[57, 175] -> 
             RGBColor[
              0.7027706017040678, 0.7668237132053658, 0.9716446435924342], 
             UndirectedEdge[93, 160] -> 
             RGBColor[
              0.5504256506756485, 0.6440417951310049, 0.9585575266537034], 
             UndirectedEdge[13, 149] -> 
             RGBColor[
              0.6703059364573243, 0.7330498507916058, 0.840199420262834], 
             UndirectedEdge[230, 298] -> 
             RGBColor[
              0.46343017876219733`, 0.5600421910223573, 0.953581283536667], 
             UndirectedEdge[96, 198] -> 
             RGBColor[
              0.2599058537833329, 0.3897940162255462, 0.9381387650620224], 
             UndirectedEdge[32, 182] -> 
             RGBColor[
              0.6145437248048833, 0.6963438633301604, 0.9638986647535059], 
             UndirectedEdge[80, 241] -> 
             RGBColor[
              0.5544208379541165, 0.6491428384820974, 0.9580651857556465], 
             UndirectedEdge[55, 292] -> 
             RGBColor[
              0.29746805380266506`, 0.4249760102394343, 0.9404352571311932], 
             UndirectedEdge[121, 160] -> 
             RGBColor[
              0.4017390476945333, 0.522387903946526, 0.9468194347685723], 
             UndirectedEdge[62, 220] -> 
             RGBColor[
              0.9682719877839994, 0.9738162740420673, 0.840280569838335], 
             UndirectedEdge[28, 189] -> 
             RGBColor[
              0.5930804327413137, 0.6573535263086372, 0.8888440485444786], 
             UndirectedEdge[25, 91] -> 
             RGBColor[
              0.799601201251246, 0.5064668997656473, 0.4532223608287834], 
             UndirectedEdge[41, 99] -> 
             RGBColor[
              0.3304474406270457, 0.45568631834657103`, 0.9424581274538313], 
             UndirectedEdge[148, 206] -> 
             RGBColor[
              0.8167935720365926, 0.8568335203493086, 0.9823663369484341], 
             UndirectedEdge[3, 90] -> 
             RGBColor[
              0.23516922926557804`, 0.3645081489214182, 0.9367039117537527], 
             UndirectedEdge[99, 104] -> 
             RGBColor[
              0.48692723675179017`, 0.5828472220302654, 0.9552189164964588], 
             UndirectedEdge[193, 266] -> 
             RGBColor[
              0.32980750112417134`, 0.4547616252731802, 0.942430913586012], 
             UndirectedEdge[275, 293] -> 
             RGBColor[
              0.7458493098027684, 0.8010432119696025, 0.9759034949250234], 
             UndirectedEdge[229, 257] -> 
             RGBColor[
              0.7126965899134654, 0.7729271585190296, 0.9424309353721334], 
             UndirectedEdge[90, 144] -> 
             RGBColor[
              0.4916646659791569, 0.5793820714564117, 0.9568255926248254], 
             UndirectedEdge[49, 115] -> 
             RGBColor[
              0.5614031092896146, 0.6548113608999937, 0.9586148557320795], 
             UndirectedEdge[77, 244] -> 
             RGBColor[
              0.6442282599009261, 0.7192953322222482, 0.9670372082446119], 
             UndirectedEdge[66, 95] -> 
             RGBColor[
              0.2536198318863759, 0.3839009021116494, 0.9377546462777866], 
             UndirectedEdge[94, 125] -> 
             RGBColor[
              0.6171325621989625, 0.6815615720558907, 0.8622447563772999], 
             UndirectedEdge[196, 230] -> 
             RGBColor[
              0.5936266058395121, 0.680017607165314, 0.9618040264405908], 
             UndirectedEdge[138, 245] -> 
             RGBColor[
              0.42130956036582856`, 0.5291567015594674, 0.9493985459342552], 
             UndirectedEdge[100, 127] -> 
             RGBColor[
              0.39109244638270463`, 0.5089478189205201, 0.9466262621014119], 
             UndirectedEdge[24, 288] -> 
             RGBColor[
              0.2521288435026302, 0.38104838132199326`, 0.937716801392892], 
             UndirectedEdge[224, 258] -> 
             RGBColor[
              0.28064366331670915`, 0.40679884601697025`, 0.9394952084066042],
              UndirectedEdge[25, 203] -> 
             RGBColor[
              0.8823220080486189, 0.5715524071646987, 0.45319565530686706`], 
             UndirectedEdge[143, 239] -> 
             RGBColor[
              0.5223506147335805, 0.6058319723567109, 0.9594878672843207], 
             UndirectedEdge[142, 282] -> 
             RGBColor[
              0.6541526346083744, 0.7287691203924886, 0.9668329339940509], 
             UndirectedEdge[57, 242] -> 
             RGBColor[
              0.421717555371845, 0.5319797225770735, 0.9492038463628105], 
             UndirectedEdge[47, 177] -> 
             RGBColor[
              0.32722110314454267`, 0.457844205758119, 0.9420712172354779], 
             UndirectedEdge[43, 174] -> 
             RGBColor[
              0.5062228974401045, 0.5952514368425674, 0.957564780625642], 
             UndirectedEdge[5, 29] -> 
             RGBColor[
              0.7838747405675597, 0.8316723900350425, 0.9737721906739067], 
             UndirectedEdge[167, 282] -> 
             RGBColor[
              0.6388032063190399, 0.7167780303528848, 0.9653030464307328], 
             UndirectedEdge[131, 172] -> 
             RGBColor[
              0.6404444704667268, 0.27688629406003995`, 0.42919490863963317`],
              UndirectedEdge[21, 101] -> 
             RGBColor[
              0.3288944066675623, 0.4592935371670781, 0.9421778386563207], 
             UndirectedEdge[251, 300] -> 
             RGBColor[
              0.4568416051889599, 0.550626939346668, 0.9536003160475557], 
             UndirectedEdge[75, 167] -> 
             RGBColor[
              0.49892381563978294`, 0.5980883380267354, 0.9554854274559617], 
             UndirectedEdge[165, 281] -> 
             RGBColor[
              0.4734581546159915, 0.5825733051949442, 0.9519237061417489], 
             UndirectedEdge[63, 174] -> 
             RGBColor[
              0.2536171353661976, 0.38389806789797276`, 0.9377544927149516], 
             UndirectedEdge[64, 211] -> 
             RGBColor[
              0.6948308360896345, 0.7603451636703316, 0.9710572218954125], 
             UndirectedEdge[124, 237] -> 
             RGBColor[
              0.6055907118257327, 0.6906848472676237, 0.9620934656682442], 
             UndirectedEdge[127, 192] -> 
             RGBColor[
              0.4773234646753443, 0.5784294755575686, 0.9537733342047641], 
             UndirectedEdge[62, 228] -> 
             RGBColor[
              0.6474209838940603, 0.7120964339735513, 0.818559969668646], 
             UndirectedEdge[152, 277] -> 
             RGBColor[
              0.27288106831362346`, 0.4013299417584172, 0.9389546432717375], 
             UndirectedEdge[76, 157] -> 
             RGBColor[
              0.4905123566648212, 0.5885407469291813, 0.955118274739748], 
             UndirectedEdge[106, 297] -> 
             RGBColor[
              0.7358186442029332, 0.7935463843709355, 0.9743031839041167], 
             UndirectedEdge[91, 203] -> 
             RGBColor[
              0.825185132197765, 0.864055240644253, 0.9708030865397472], 
             UndirectedEdge[215, 271] -> 
             RGBColor[
              0.705716084254207, 0.43023357422921205`, 0.44559060253269445`], 
             UndirectedEdge[181, 296] -> 
             RGBColor[
              0.28861002622535814`, 0.41673273141385764`, 0.9398917349127768],
              UndirectedEdge[27, 119] -> 
             RGBColor[
              0.21309140870023396`, 0.3413029596925683, 0.9354466125337649], 
             UndirectedEdge[100, 170] -> 
             RGBColor[
              0.6954497404928622, 0.760432276800471, 0.9715839945883848], 
             UndirectedEdge[112, 115] -> 
             RGBColor[
              0.6816891588124241, 0.749316104284522, 0.9704370761789735], 
             UndirectedEdge[75, 282] -> 
             RGBColor[
              0.43856067194704085`, 0.5499530347985654, 0.9501384481323885], 
             UndirectedEdge[234, 255] -> 
             RGBColor[
              0.4207650202069303, 0.5377413876423596, 0.948342830673033], 
             UndirectedEdge[29, 77] -> 
             RGBColor[
              0.8832692786525156, 0.9096081365508006, 0.9834989460640305], 
             UndirectedEdge[44, 192] -> 
             RGBColor[
              0.4779957372329819, 0.5791360766401877, 0.9538116191323833], 
             UndirectedEdge[49, 57] -> 
             RGBColor[
              0.6096223779764293, 0.6939579354732495, 0.9624108531961066], 
             UndirectedEdge[4, 281] -> 
             RGBColor[
              0.3533871886695544, 0.47825763906542834`, 0.9438208921166913], 
             UndirectedEdge[23, 285] -> 
             RGBColor[
              0.9862491634326644, 0.9871752471011921, 0.806011543012251], 
             UndirectedEdge[86, 109] -> 
             RGBColor[
              0.9113316125897315, 0.9281172386151315, 0.8038311619936529], 
             UndirectedEdge[276, 279] -> 
             RGBColor[
              0.39056131132250815`, 0.510252790219703, 0.9464264121509827], 
             UndirectedEdge[139, 183] -> 
             RGBColor[
              0.24566470081326444`, 0.3755395549693674, 0.9373016133317347], 
             UndirectedEdge[234, 287] -> 
             RGBColor[
              0.3870296460053274, 0.5096473595193614, 0.9458821646999493], 
             UndirectedEdge[160, 181] -> 
             RGBColor[
              0.3814312258777729, 0.5047982893896508, 0.9455254383199101], 
             UndirectedEdge[196, 298] -> 
             RGBColor[
              0.35240539991431175`, 0.4708615138302179, 0.9441885872270499], 
             UndirectedEdge[255, 287] -> 
             RGBColor[
              0.46104709013384326`, 0.5726316919773482, 0.9509095685487401], 
             UndirectedEdge[126, 216] -> 
             RGBColor[
              0.6648698417343719, 0.7338116226204483, 0.9699510870567698], 
             UndirectedEdge[190, 212] -> 
             RGBColor[
              0.8311820288554221, 0.815517067277701, 0.6271050877672069], 
             UndirectedEdge[39, 137] -> 
             RGBColor[
              0.6056696830769479, 0.6737042677939467, 0.9342646025825475], 
             UndirectedEdge[170, 195] -> 
             RGBColor[
              0.9078825495617485, 0.9293849174779709, 0.9910758421251611], 
             UndirectedEdge[69, 288] -> 
             RGBColor[
              0.35314438130598974`, 0.46660532409045485`, 0.9446887975352121],
              UndirectedEdge[101, 231] -> 
             RGBColor[
              0.3507701545144143, 0.4782412104449649, 0.9435717419651577], 
             UndirectedEdge[57, 253] -> 
             RGBColor[
              0.44283699634147944`, 0.5541775940860567, 0.9504065672826181], 
             UndirectedEdge[52, 266] -> 
             RGBColor[
              0.3273326115906096, 0.45216035945634725`, 0.9422899722883467], 
             UndirectedEdge[28, 275] -> 
             RGBColor[
              0.9586667532037838, 0.9678347006603097, 0.9181005157853708], 
             UndirectedEdge[4, 226] -> 
             RGBColor[
              0.6674820509897486, 0.44056858853767067`, 0.44921921081208926`],
              UndirectedEdge[104, 229] -> 
             RGBColor[
              0.5867298435054734, 0.6742037161294935, 0.9614079402378204], 
             UndirectedEdge[189, 293] -> 
             RGBColor[
              0.38026298934029845`, 0.4905620376179299, 0.9466470276841312], 
             UndirectedEdge[155, 156] -> 
             RGBColor[
              0.9371511916023827, 0.9470658209656729, 0.706372758821955], 
             UndirectedEdge[107, 281] -> 
             RGBColor[
              0.3503490263152469, 0.4750643378004321, 0.9436478732651719], 
             UndirectedEdge[107, 240] -> 
             RGBColor[
              0.391763425525972, 0.5095267924030654, 0.9466759670824223], 
             UndirectedEdge[13, 105] -> 
             RGBColor[
              0.5997285077882939, 0.6623027277769369, 0.8360543961493482], 
             UndirectedEdge[96, 138] -> 
             RGBColor[
              0.45859132842863215`, 0.5676283101374828, 0.9515478266085388], 
             UndirectedEdge[254, 260] -> 
             RGBColor[
              0.6115584536790335, 0.6810563731258666, 0.9412638291604487], 
             UndirectedEdge[120, 176] -> 
             RGBColor[
              0.4039622829058575, 0.5243135585435241, 0.9469610973503082], 
             UndirectedEdge[59, 125] -> 
             RGBColor[
              0.5937240926601612, 0.6569577863879197, 0.8609116786667925], 
             UndirectedEdge[22, 267] -> 
             RGBColor[
              0.4833330390768541, 0.5914305608846915, 0.9524688938248409], 
             UndirectedEdge[28, 197] -> 
             RGBColor[
              0.5986058757732516, 0.6631611172685263, 0.8891587143509871], 
             UndirectedEdge[245, 298] -> 
             RGBColor[
              0.23205640359026802`, 0.3612363717721203, 0.9365266409365567], 
             UndirectedEdge[193, 199] -> 
             RGBColor[
              0.5634450396504551, 0.6425333995338662, 0.9628115392852533], 
             UndirectedEdge[22, 274] -> 
             RGBColor[
              0.49403153741273065`, 0.6001160837956137, 0.9533111188037318], 
             UndirectedEdge[76, 201] -> 
             RGBColor[
              0.8497734538572885, 0.8805127170665129, 0.8419794240618508], 
             UndirectedEdge[19, 158] -> 
             RGBColor[
              0.3572888334892489, 0.48107465194401644`, 0.9440900935383187], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.7098311520393092, 0.7721876720995737, 0.9726241683743271], 
             UndirectedEdge[61, 267] -> 
             RGBColor[
              0.7429069130444117, 0.7973445351961088, 0.9418930596204059], 
             UndirectedEdge[106, 283] -> 
             RGBColor[
              0.5837837247151585, 0.6715634330293112, 0.9612635359391221], 
             UndirectedEdge[174, 283] -> 
             RGBColor[
              0.3406336985845599, 0.46267977944250255`, 0.9431741687652104], 
             UndirectedEdge[19, 242] -> 
             RGBColor[
              0.27053037016575054`, 0.4016749500333259, 0.9387176764158975], 
             UndirectedEdge[125, 195] -> 
             RGBColor[
              0.9603486416594649, 0.9685302047592956, 0.8902272714869359], 
             UndirectedEdge[115, 159] -> 
             RGBColor[
              0.33170968365258463`, 0.4489106766662544, 0.9430280497767837], 
             UndirectedEdge[158, 177] -> 
             RGBColor[
              0.3834282379922883, 0.5065280009104967, 0.9456526861659585], 
             UndirectedEdge[42, 134] -> 
             RGBColor[
              0.6500452453023485, 0.7257294947908617, 0.9663079344908505], 
             UndirectedEdge[165, 179] -> 
             RGBColor[
              0.48594105900837736`, 0.5933853695706113, 0.9527191057714328], 
             UndirectedEdge[108, 145] -> 
             RGBColor[
              0.5746699306844403, 0.6417110405657357, 0.93587792387569], 
             UndirectedEdge[44, 125] -> 
             RGBColor[
              0.6355399621205153, 0.7009089164700061, 0.8632930305715245], 
             UndirectedEdge[39, 141] -> 
             RGBColor[
              0.7469620880246257, 0.8006863245610354, 0.9435430572324122], 
             UndirectedEdge[50, 87] -> 
             RGBColor[
              0.6189250821614454, 0.20635490291430042`, 0.42146591987115056`],
              UndirectedEdge[26, 226] -> 
             RGBColor[
              0.6672332647442538, 0.4403070984196967, 0.4492050428034546], 
             UndirectedEdge[9, 143] -> 
             RGBColor[
              0.2985642548353358, 0.42483293502201946`, 0.940545109679205], 
             UndirectedEdge[136, 299] -> 
             RGBColor[
              0.7655450520630813, 0.8156449951995834, 0.9415777562906305], 
             UndirectedEdge[134, 144] -> 
             RGBColor[
              0.7459348335550118, 0.801449228378666, 0.9753114711175674], 
             UndirectedEdge[240, 281] -> 
             RGBColor[
              0.4637818628716104, 0.5747176556448802, 0.9511619530102067], 
             UndirectedEdge[257, 261] -> 
             RGBColor[
              0.6714247613360187, 0.7372194614120637, 0.9397901102125205], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.5513588344986553, 0.6466569661352702, 0.9578241336271442], 
             UndirectedEdge[135, 254] -> 
             RGBColor[
              0.6000872666062324, 0.6689994281970846, 0.9406105620267531], 
             UndirectedEdge[14, 224] -> 
             RGBColor[
              0.42109842042009893`, 0.5385971506972358, 0.9482074140148087], 
             UndirectedEdge[96, 289] -> 
             RGBColor[
              0.42052124178308004`, 0.5367212987607647, 0.9485508099324785], 
             UndirectedEdge[92, 189] -> 
             RGBColor[
              0.6164028301748388, 0.24072244384620892`, 0.42634699940965015`],
              UndirectedEdge[107, 127] -> 
             RGBColor[
              0.2781874461623061, 0.40972302239236436`, 0.9391537355662725], 
             UndirectedEdge[172, 270] -> 
             RGBColor[
              0.22336130462471754`, 0.3520972714582107, 0.9360314679137147], 
             UndirectedEdge[48, 84] -> 
             RGBColor[
              0.3528999263955038, 0.4666666156263739, 0.9446459089934909], 
             UndirectedEdge[149, 289] -> 
             RGBColor[
              0.4352326257442758, 0.549463560132295, 0.9494882063097199], 
             UndirectedEdge[1, 102] -> 
             RGBColor[
              0.5752587856982547, 0.6577217015044872, 0.9630644808836264], 
             UndirectedEdge[33, 297] -> 
             RGBColor[
              0.49703889283793873`, 0.589256166654201, 0.956462697412864], 
             UndirectedEdge[18, 135] -> 
             RGBColor[
              0.4243977167996473, 0.5308853657899276, 0.9497125153972623], 
             UndirectedEdge[60, 137] -> 
             RGBColor[
              0.3638307972125939, 0.4821387401443815, 0.9449058406329003], 
             UndirectedEdge[156, 208] -> 
             RGBColor[
              0.663073841824261, 0.7244874183954451, 0.6833139262461321], 
             UndirectedEdge[104, 279] -> 
             RGBColor[
              0.5056161836785389, 0.6024904901979529, 0.9562832243761179], 
             UndirectedEdge[74, 158] -> 
             RGBColor[
              0.31667975151263694`, 0.4383919320220886, 0.9417774663955037], 
             UndirectedEdge[80, 277] -> 
             RGBColor[
              0.36993687679285847`, 0.48322277282493764`, 0.9457390924978596],
              UndirectedEdge[223, 291] -> 
             RGBColor[
              0.6764433123028182, 0.7458353234882886, 0.9692922096072651], 
             UndirectedEdge[114, 264] -> 
             RGBColor[
              0.556134126702668, 0.6482365468835187, 0.9592385502576628], 
             UndirectedEdge[1, 237] -> 
             RGBColor[
              0.4619685328575365, 0.5687137374014366, 0.9520033067157219], 
             UndirectedEdge[84, 292] -> 
             RGBColor[
              0.44248795852515665`, 0.5558171643598717, 0.9499313343725633], 
             UndirectedEdge[103, 152] -> 
             RGBColor[
              0.2936526294288798, 0.4231621694835922, 0.9401375529484806], 
             UndirectedEdge[10, 269] -> 
             RGBColor[
              0.5139928500831604, 0.6144565136758922, 0.9554018489822867], 
             UndirectedEdge[109, 138] -> 
             RGBColor[
              0.7975223686723167, 0.8385031755877117, 0.7929417846932565], 
             UndirectedEdge[165, 240] -> 
             RGBColor[
              0.5148725538267166, 0.6170357597975775, 0.9549517999589994], 
             UndirectedEdge[249, 254] -> 
             RGBColor[
              0.6535244109458287, 0.7220657391441856, 0.9437672168028739], 
             UndirectedEdge[2, 155] -> 
             RGBColor[
              0.6382333316130319, 0.7124137438489629, 0.9674835076212204], 
             UndirectedEdge[117, 161] -> 
             RGBColor[
              0.8886893577393563, 0.8483194140812368, 0.6301133060421726], 
             UndirectedEdge[169, 264] -> 
             RGBColor[
              0.49612807556119987`, 0.6005119914337389, 0.9538370608934311], 
             UndirectedEdge[3, 229] -> 
             RGBColor[
              0.36152700438065166`, 0.4837758086633873, 0.9444052130484442], 
             UndirectedEdge[55, 90] -> 
             RGBColor[
              0.21702540224266437`, 0.3454378363352596, 0.9356706476461845], 
             UndirectedEdge[3, 259] -> 
             RGBColor[
              0.3562918293711673, 0.4792812496221175, 0.9440606115882203], 
             UndirectedEdge[113, 254] -> 
             RGBColor[
              0.7094267865796675, 0.7704650216648762, 0.9473349435336387], 
             UndirectedEdge[6, 205] -> 
             RGBColor[
              0.7944004928448136, 0.835780958687188, 0.7773090887239249], 
             UndirectedEdge[120, 287] -> 
             RGBColor[
              0.4108287233086032, 0.5302609241030531, 0.9473986208610163], 
             UndirectedEdge[31, 67] -> 
             RGBColor[
              0.6104960399467415, 0.6888447849556243, 0.9655063332319658], 
             UndirectedEdge[141, 232] -> 
             RGBColor[
              0.4564170502764052, 0.5678951783226193, 0.950815199341301], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.3553520255917452, 0.48186261618635823`, 0.9438764067245391], 
             UndirectedEdge[71, 122] -> 
             RGBColor[
              0.5758690222853357, 0.6478738682004793, 0.9640459066264025], 
             UndirectedEdge[78, 120] -> 
             RGBColor[
              0.46914671507810013`, 0.5783122286019691, 0.95179452053814], 
             UndirectedEdge[177, 247] -> 
             RGBColor[
              0.32112609607891923`, 0.45256501698183843`, 0.9416828487748596],
              UndirectedEdge[168, 182] -> 
             RGBColor[
              0.39375623851921004`, 0.5144359603327417, 0.9465332528800395], 
             UndirectedEdge[26, 228] -> 
             RGBColor[
              0.29175321945722044`, 0.4239815102450243, 0.9399262862866548], 
             UndirectedEdge[7, 194] -> 
             RGBColor[
              0.3807597680731938, 0.498427321247625, 0.9460069004331979], 
             UndirectedEdge[206, 244] -> 
             RGBColor[
              0.6435131402820748, 0.7187251152495812, 0.966968999496971], 
             UndirectedEdge[31, 109] -> 
             RGBColor[
              0.931599578424489, 0.9442783644124906, 0.8057643386683988], 
             UndirectedEdge[57, 235] -> 
             RGBColor[
              0.37981274561036027`, 0.4879351105993578, 0.9468174294395045], 
             UndirectedEdge[24, 135] -> 
             RGBColor[
              0.27902215627419324`, 0.40931495817941965`, 0.9392483357701416],
              UndirectedEdge[130, 220] -> 
             RGBColor[
              0.6738597777942463, 0.7410771535754082, 0.9654651145238289], 
             UndirectedEdge[84, 112] -> 
             RGBColor[
              0.7005687707771737, 0.7646434237943323, 0.9719233483911358], 
             UndirectedEdge[76, 104] -> 
             RGBColor[
              0.7115380141149847, 0.7745781716066067, 0.9718831176123388], 
             UndirectedEdge[21, 87] -> 
             RGBColor[
              0.28016012338224705`, 0.40907477941946013`, 0.9393657296205931],
              UndirectedEdge[43, 183] -> 
             RGBColor[
              0.5129027560826703, 0.6022723918034038, 0.9579451886933709], 
             UndirectedEdge[11, 131] -> 
             RGBColor[
              0.6211876274060835, 0.25664613104893474`, 0.42809825991527595`],
              UndirectedEdge[21, 187] -> 
             RGBColor[
              0.28774948992618976`, 0.41705168485077526`, 0.939797932817809], 
             UndirectedEdge[36, 66] -> 
             RGBColor[
              0.23835803743519246`, 0.3678597884897984, 0.9368855096615933], 
             UndirectedEdge[124, 125] -> 
             RGBColor[
              0.787793161988678, 0.8319517765403899, 0.8738747133958487], 
             UndirectedEdge[232, 296] -> 
             RGBColor[
              0.3085553107312615, 0.4340083343737235, 0.9411626308045704], 
             UndirectedEdge[75, 239] -> 
             RGBColor[
              0.5616100012493834, 0.6470960767736937, 0.9617236312673381], 
             UndirectedEdge[108, 114] -> 
             RGBColor[
              0.8377945140437635, 0.8735646584330085, 0.9547920716815291], 
             UndirectedEdge[137, 266] -> 
             RGBColor[
              0.3236913927842545, 0.4483332076242615, 0.9420826102640252], 
             UndirectedEdge[74, 262] -> 
             RGBColor[
              0.5809424271767742, 0.6488769881037952, 0.9395202917434974], 
             UndirectedEdge[48, 90] -> 
             RGBColor[
              0.19292605558406964`, 0.32010789501024606`, 0.9342982255057659],
              UndirectedEdge[125, 150] -> 
             RGBColor[
              0.9816712875446316, 0.984605187836797, 0.860117352030003], 
             UndirectedEdge[38, 55] -> 
             RGBColor[
              0.6123370030945732, 0.6739691484153336, 0.6913784260169663], 
             UndirectedEdge[110, 165] -> 
             RGBColor[
              0.6187232408559358, 0.7002658640071524, 0.9638660925600104], 
             UndirectedEdge[114, 145] -> 
             RGBColor[
              0.44393041022856017`, 0.5392223840313445, 0.952522144216567], 
             UndirectedEdge[222, 290] -> 
             RGBColor[
              0.654754304611871, 0.7239918675360083, 0.9564092813418965], 
             UndirectedEdge[267, 286] -> 
             RGBColor[
              0.37194732252914153`, 0.4878951559274498, 0.9456206230826802], 
             UndirectedEdge[6, 187] -> 
             RGBColor[
              0.6156812458982426, 0.6782194680901031, 0.7651019730828332], 
             UndirectedEdge[221, 231] -> 
             RGBColor[
              0.6554703517610199, 0.7257312728108606, 0.9693240708633137], 
             UndirectedEdge[106, 286] -> 
             RGBColor[
              0.4768375281535141, 0.5718344132292552, 0.9547088967532137], 
             UndirectedEdge[67, 154] -> 
             RGBColor[
              0.34304430349293735`, 0.4715494666027247, 0.943079457569771], 
             UndirectedEdge[85, 296] -> 
             RGBColor[
              0.5100403131728231, 0.5969395311937834, 0.9581501399446495], 
             UndirectedEdge[41, 201] -> 
             RGBColor[
              0.7004283442446368, 0.7589254847116913, 0.8299297538933122], 
             UndirectedEdge[42, 235] -> 
             RGBColor[
              0.38420285964963274`, 0.4914992029488229, 0.9471630352981937], 
             UndirectedEdge[44, 60] -> 
             RGBColor[
              0.3840535924408872, 0.5033941801285916, 0.946057498904207], 
             UndirectedEdge[199, 228] -> 
             RGBColor[
              0.587780244290043, 0.6681112425511633, 0.9641973931887688], 
             UndirectedEdge[39, 62] -> 
             RGBColor[
              0.9836960959778112, 0.9853195486783528, 0.8141715779179086], 
             UndirectedEdge[48, 144] -> 
             RGBColor[
              0.48251928540950473`, 0.5697696966270887, 0.9563047767307618], 
             UndirectedEdge[68, 215] -> 
             RGBColor[
              0.8403151407885833, 0.5382905143930181, 0.4572756817984185], 
             UndirectedEdge[127, 240] -> 
             RGBColor[
              0.3916202827186696, 0.5093763402368124, 0.9466678153113073], 
             UndirectedEdge[4, 26] -> 
             RGBColor[
              0.28403373430998136`, 0.4158678419116488, 0.9394866730274744], 
             UndirectedEdge[8, 47] -> 
             RGBColor[
              0.6264227420113265, 0.7005716932209929, 0.967473182855856], 
             UndirectedEdge[112, 175] -> 
             RGBColor[
              0.8519805379825862, 0.8848101708644278, 0.9857438583564258], 
             UndirectedEdge[162, 203] -> 
             RGBColor[
              0.8922542501933584, 0.9165734713773483, 0.9774551824936766], 
             UndirectedEdge[6, 50] -> 
             RGBColor[
              0.8762281707414211, 0.41930947219155823`, 0.3072712600525943], 
             UndirectedEdge[15, 294] -> 
             RGBColor[
              0.36157909196160376`, 0.487603368788728, 0.9442604779013246], 
             UndirectedEdge[6, 219] -> 
             RGBColor[
              0.7103939055233066, 0.7668590068992176, 0.7708951681297986], 
             UndirectedEdge[110, 281] -> 
             RGBColor[
              0.5676325499008295, 0.657947759854455, 0.9600762456112177], 
             UndirectedEdge[167, 297] -> 
             RGBColor[
              0.7245539752211134, 0.7847463393476828, 0.9731804269743256], 
             UndirectedEdge[122, 246] -> 
             RGBColor[
              0.4257523944433065, 0.5295843641455688, 0.950037695420414], 
             UndirectedEdge[210, 277] -> 
             RGBColor[
              0.4750802074702284, 0.5670319986426295, 0.9550766966601657], 
             UndirectedEdge[225, 234] -> 
             RGBColor[
              0.6191381083575526, 0.6955509048002673, 0.9664157092584122], 
             UndirectedEdge[84, 280] -> 
             RGBColor[
              0.3653682095874423, 0.4797715717959148, 0.9453559592760998], 
             UndirectedEdge[67, 95] -> 
             RGBColor[
              0.29273053024884393`, 0.42099828370395687`, 0.9401287846231161],
              UndirectedEdge[81, 285] -> 
             RGBColor[
              0.615971741477215, 0.6790035113520076, 0.8129913817009389], 
             UndirectedEdge[79, 164] -> 
             RGBColor[
              0.3130135433514524, 0.43488368526742593`, 0.9415560428824893], 
             UndirectedEdge[123, 157] -> 
             RGBColor[
              0.3141458851177694, 0.4435489689999227, 0.9413468272828018], 
             UndirectedEdge[85, 165] -> 
             RGBColor[
              0.6594124415489917, 0.7320525768379466, 0.967921611822895], 
             UndirectedEdge[59, 62] -> 
             RGBColor[
              0.5953765966824949, 0.6573944832094591, 0.8155961188097185], 
             UndirectedEdge[38, 48] -> 
             RGBColor[
              0.5882376564359784, 0.6486392070903201, 0.6900060038765479], 
             UndirectedEdge[262, 291] -> 
             RGBColor[
              0.8809532213116487, 0.9073470518382145, 0.962459100485611], 
             UndirectedEdge[26, 170] -> 
             RGBColor[
              0.5852097232585292, 0.6640085463603504, 0.9642632348918129], 
             UndirectedEdge[43, 139] -> 
             RGBColor[
              0.5098121038965792, 0.5990239203971554, 0.9577691806235832], 
             UndirectedEdge[52, 281] -> 
             RGBColor[
              0.33429657964364384`, 0.4581921985646739, 0.9427337101746909], 
             UndirectedEdge[124, 142] -> 
             RGBColor[
              0.6568802273985275, 0.7309835030961899, 0.9670476600899933], 
             UndirectedEdge[166, 271] -> 
             RGBColor[
              0.36291332613333893`, 0.48854008510090013`, 0.9443535102324554],
              UndirectedEdge[37, 150] -> 
             RGBColor[
              0.6267390208945167, 0.6959631292346313, 0.9361158866424091], 
             UndirectedEdge[51, 66] -> 
             RGBColor[
              0.394227900930141, 0.510997742350041, 0.9469182073268061], 
             UndirectedEdge[60, 125] -> 
             RGBColor[
              0.7402047060911237, 0.7933173242072481, 0.8701283758253354], 
             UndirectedEdge[215, 223] -> 
             RGBColor[
              0.7511529204108707, 0.4677343343305467, 0.4489981582314928], 
             UndirectedEdge[237, 282] -> 
             RGBColor[
              0.6028631190355795, 0.6884704645639225, 0.9618787395723017], 
             UndirectedEdge[143, 172] -> 
             RGBColor[
              0.2425976614184719, 0.3723159021039112, 0.9371269499754794], 
             UndirectedEdge[177, 285] -> 
             RGBColor[
              0.6627647820381823, 0.7261651413315303, 0.8157301683477614], 
             UndirectedEdge[244, 270] -> 
             RGBColor[
              0.32257782444903527`, 0.4417996787911689, 0.9422816066636905], 
             UndirectedEdge[147, 272] -> 
             RGBColor[
              0.3874659025210086, 0.5100252229863543, 0.9459099625793621], 
             UndirectedEdge[46, 114] -> 
             RGBColor[
              0.5269646116777252, 0.6229713790713672, 0.9573798945538629], 
             UndirectedEdge[104, 128] -> 
             RGBColor[
              0.48047938149607783`, 0.5760701173388764, 0.9548517206783931], 
             UndirectedEdge[199, 220] -> 
             RGBColor[
              0.9086312481799821, 0.9298310826196793, 0.9859179933584579], 
             UndirectedEdge[112, 146] -> 
             RGBColor[
              0.5606173880479739, 0.6391296076516999, 0.9627159159790775], 
             UndirectedEdge[191, 203] -> 
             RGBColor[
              0.6623867498790517, 0.7306753303692166, 0.9579554950847755], 
             UndirectedEdge[31, 96] -> 
             RGBColor[
              0.5926685381808043, 0.6734034989622617, 0.9643703805836811], 
             UndirectedEdge[59, 228] -> 
             RGBColor[
              0.24780149676113625`, 0.3777854629912688, 0.9374233006998597], 
             UndirectedEdge[129, 289] -> 
             RGBColor[
              0.584001799347313, 0.6731416123928826, 0.9604051086479308], 
             UndirectedEdge[54, 106] -> 
             RGBColor[
              0.594262864744407, 0.6802730538193331, 0.9620326285090306], 
             UndirectedEdge[102, 142] -> 
             RGBColor[
              0.7918659438583744, 0.8376048219347472, 0.9798167806270974], 
             UndirectedEdge[74, 90] -> 
             RGBColor[
              0.19958869650451472`, 0.32711075305346693`, 0.9346776530496914],
              UndirectedEdge[143, 174] -> 
             RGBColor[
              0.22777907197520106`, 0.35674062504619686`, 0.9362830532288237],
              UndirectedEdge[144, 292] -> 
             RGBColor[
              0.5721073175391576, 0.6589202453605865, 0.9615902021098341], 
             UndirectedEdge[59, 255] -> 
             RGBColor[
              0.34526978694250854`, 0.46190461616376155`, 0.9439148421813781],
              UndirectedEdge[254, 258] -> 
             RGBColor[
              0.5788850473935749, 0.6467145515062406, 0.9394031270084648], 
             UndirectedEdge[46, 108] -> 
             RGBColor[
              0.6577041321336052, 0.7254600356057583, 0.9407356742129859], 
             UndirectedEdge[222, 278] -> 
             RGBColor[
              0.7508780166895526, 0.8045894202040064, 0.963269158409314], 
             UndirectedEdge[115, 294] -> 
             RGBColor[
              0.43672595239272216`, 0.5518516557119733, 0.9492809044045927], 
             UndirectedEdge[89, 177] -> 
             RGBColor[
              0.6597818703855873, 0.7252381999637859, 0.8874490827015216], 
             UndirectedEdge[45, 195] -> 
             RGBColor[
              0.8784801128592482, 0.5887796244428007, 0.4634262305457546], 
             UndirectedEdge[205, 231] -> 
             RGBColor[
              0.4883444847196128, 0.5935608487257469, 0.9533989517677377], 
             UndirectedEdge[148, 244] -> 
             RGBColor[
              0.636746286003919, 0.7134098903350155, 0.966302213710791], 
             UndirectedEdge[20, 297] -> 
             RGBColor[
              0.49446072725948187`, 0.5865463511661039, 0.9563158746972251], 
             UndirectedEdge[6, 34] -> 
             RGBColor[
              0.8008648388108556, 0.841029005957888, 0.7778179857180513], 
             UndirectedEdge[13, 245] -> 
             RGBColor[
              0.6183127844333249, 0.6818359808420599, 0.8371127432113091], 
             UndirectedEdge[104, 201] -> 
             RGBColor[
              0.8569081403693815, 0.8860863883953858, 0.8426905429359399], 
             UndirectedEdge[55, 253] -> 
             RGBColor[
              0.26847743489692266`, 0.3995171849021738, 0.9386007647893833], 
             UndirectedEdge[52, 141] -> 
             RGBColor[
              0.3838768817677252, 0.49928410102210385`, 0.9464046537819686], 
             UndirectedEdge[160, 299] -> 
             RGBColor[
              0.6938567961660143, 0.7563083434030997, 0.9362483219745785], 
             UndirectedEdge[229, 284] -> 
             RGBColor[
              0.7079437439572454, 0.7243502941645088, 0.62680243364996], 
             UndirectedEdge[27, 268] -> 
             RGBColor[
              0.5992174324598778, 0.6640434793282104, 0.8954426745763464], 
             UndirectedEdge[193, 236] -> 
             RGBColor[
              0.24471141445461034`, 0.3745375905645758, 0.9372473250838702], 
             UndirectedEdge[78, 193] -> 
             RGBColor[
              0.3975615870823801, 0.5109860002864742, 0.94742807284083], 
             UndirectedEdge[175, 177] -> 
             RGBColor[
              0.5777228210010128, 0.6619722896280984, 0.962721066273161], 
             UndirectedEdge[36, 67] -> 
             RGBColor[
              0.2774687357976605, 0.40495717008210586`, 0.9392596480069227], 
             UndirectedEdge[37, 239] -> 
             RGBColor[
              0.5531826318507522, 0.6382383772096514, 0.9612437050472618], 
             UndirectedEdge[49, 280] -> 
             RGBColor[
              0.4236317530652163, 0.527072541133894, 0.9499426788450622], 
             UndirectedEdge[263, 276] -> 
             RGBColor[
              0.4008286771062859, 0.5206424035137347, 0.9470258440652701], 
             UndirectedEdge[13, 73] -> 
             RGBColor[
              0.9692194019060297, 0.9748150893872274, 0.8586472745069169], 
             UndirectedEdge[136, 240] -> 
             RGBColor[
              0.5300098810000298, 0.6293249239256912, 0.956143465803939], 
             UndirectedEdge[79, 241] -> 
             RGBColor[
              0.5040248168728179, 0.6076643700705653, 0.954253856922891], 
             UndirectedEdge[78, 226] -> 
             RGBColor[
              0.7539956462540855, 0.5153619871255279, 0.455130136441915], 
             UndirectedEdge[3, 74] -> 
             RGBColor[
              0.23268648961637092`, 0.3618986321353159, 0.9365625234036146], 
             UndirectedEdge[148, 203] -> 
             RGBColor[
              0.8796465300761307, 0.9066008985887865, 0.9762312897095633], 
             UndirectedEdge[90, 257] -> 
             RGBColor[
              0.5863388147983917, 0.6536594987770605, 0.9347296340774418], 
             UndirectedEdge[34, 87] -> 
             RGBColor[
              0.414910205940892, 0.5215971520420013, 0.9491099754458857], 
             UndirectedEdge[146, 235] -> 
             RGBColor[
              0.21052170615909527`, 0.33860203939328015`, 0.9353002717755814],
              UndirectedEdge[181, 256] -> 
             RGBColor[
              0.31240484948858666`, 0.44174259934244287`, 0.9412468148963311],
              UndirectedEdge[68, 287] -> 
             RGBColor[
              0.625278728272979, 0.7032177436410689, 0.9657260051535915], 
             UndirectedEdge[17, 144] -> 
             RGBColor[
              0.5219972576637808, 0.6112635485143428, 0.9585529888482165], 
             UndirectedEdge[163, 216] -> 
             RGBColor[
              0.3439921391680648, 0.47054710400900235`, 0.9432066138718603], 
             UndirectedEdge[67, 258] -> 
             RGBColor[
              0.2725567856449648, 0.3997943990359954, 0.9389799197123058], 
             UndirectedEdge[232, 240] -> 
             RGBColor[
              0.44825114736304894`, 0.5612657304678226, 0.9501723495512737], 
             UndirectedEdge[133, 210] -> 
             RGBColor[
              0.5108216190540864, 0.6045984883536446, 0.9571121171751864], 
             UndirectedEdge[58, 154] -> 
             RGBColor[
              0.30570787987584713`, 0.4363169602633256, 0.9408063615463866], 
             UndirectedEdge[94, 124] -> 
             RGBColor[
              0.41323464841688873`, 0.522681288047618, 0.9487555622804957], 
             UndirectedEdge[50, 213] -> 
             RGBColor[
              0.8350866314047939, 0.38930942743917546`, 0.4386526291850499], 
             UndirectedEdge[15, 212] -> 
             RGBColor[
              0.5205992322181552, 0.6174504798352057, 0.9569774841903418], 
             UndirectedEdge[11, 139] -> 
             RGBColor[
              0.22491816702300443`, 0.35373363254958756`, 0.9361201289241257],
              UndirectedEdge[167, 286] -> 
             RGBColor[
              0.46557285917169433`, 0.5630343682060024, 0.9535861398234227], 
             UndirectedEdge[113, 288] -> 
             RGBColor[
              0.3178418429160961, 0.4379451330643084, 0.9419096523957007], 
             UndirectedEdge[73, 171] -> 
             RGBColor[
              0.8926854771184477, 0.6456685340014284, 0.46730247651112855`], 
             UndirectedEdge[31, 110] -> 
             RGBColor[
              0.790883671016618, 0.8369587267890881, 0.9796866971491436], 
             UndirectedEdge[202, 275] -> 
             RGBColor[
              0.5749161460102056, 0.6478304716528183, 0.9644888631788859], 
             UndirectedEdge[103, 241] -> 
             RGBColor[
              0.41181700246380193`, 0.5221918841864159, 0.948583745699646], 
             UndirectedEdge[9, 20] -> 
             RGBColor[
              0.307972927761506, 0.43472204681174265`, 0.9410809196834662], 
             UndirectedEdge[71, 207] -> 
             RGBColor[
              0.5916393504330073, 0.6644494829802381, 0.9649440034843026], 
             UndirectedEdge[160, 168] -> 
             RGBColor[
              0.3586474007480286, 0.48479612805485955`, 0.9440834843536811], 
             UndirectedEdge[6, 114] -> 
             RGBColor[
              0.8505507529060734, 0.8803752092366459, 0.7824070360900945], 
             UndirectedEdge[95, 96] -> 
             RGBColor[
              0.2749030284829068, 0.4055569977105943, 0.9389928319748314], 
             UndirectedEdge[198, 278] -> 
             RGBColor[
              0.3773135945948518, 0.48882672481640516`, 0.9463548416196323], 
             UndirectedEdge[86, 281] -> 
             RGBColor[
              0.6253506189419165, 0.7031050421795209, 0.9658111340561362], 
             UndirectedEdge[107, 165] -> 
             RGBColor[
              0.4014397172703531, 0.5173824419531294, 0.9474377202139646], 
             UndirectedEdge[155, 184] -> 
             RGBColor[
              0.6317751147558146, 0.7068199610066588, 0.9670719957538554], 
             UndirectedEdge[247, 285] -> 
             RGBColor[
              0.6532879483024912, 0.7179567842691879, 0.8151263128821581], 
             UndirectedEdge[34, 227] -> 
             RGBColor[
              0.4335870374388439, 0.5412276861258607, 0.9501735933697979], 
             UndirectedEdge[116, 152] -> 
             RGBColor[
              0.36843847696711884`, 0.4935446233177903, 0.94469755184836], 
             UndirectedEdge[146, 204] -> 
             RGBColor[
              0.3318365690187349, 0.4556815296863308, 0.9425908716196936], 
             UndirectedEdge[36, 58] -> 
             RGBColor[
              0.2401323121805703, 0.36972466374270685`, 0.9369865519835383], 
             UndirectedEdge[105, 129] -> 
             RGBColor[
              0.4240818833255446, 0.5269453150019899, 0.950032669877762], 
             UndirectedEdge[87, 187] -> 
             RGBColor[
              0.22972661302827896`, 0.35878761417421645`, 0.9363939628106677],
              UndirectedEdge[119, 168] -> 
             RGBColor[
              0.2605857471983401, 0.39122252076906394`, 0.9381513448496548], 
             UndirectedEdge[20, 37] -> 
             RGBColor[
              0.2604031982795202, 0.3910306502811143, 0.9381409489587849], 
             UndirectedEdge[150, 200] -> 
             RGBColor[
              0.6385785146636818, 0.7084071878532854, 0.9367901282976014], 
             UndirectedEdge[1, 43] -> 
             RGBColor[
              0.5368505247180984, 0.6274430150154673, 0.9593089786896096], 
             UndirectedEdge[187, 213] -> 
             RGBColor[
              0.5539689368933017, 0.6332194009615291, 0.9621740267815166], 
             UndirectedEdge[41, 222] -> 
             RGBColor[
              0.6780931448322549, 0.7442067978906876, 0.9578964116030133], 
             UndirectedEdge[196, 263] -> 
             RGBColor[
              0.3978481126445911, 0.518222647010832, 0.9467912031126782], 
             UndirectedEdge[148, 172] -> 
             RGBColor[
              0.5375297661796012, 0.6237074830020573, 0.9600520749608151], 
             UndirectedEdge[96, 171] -> 
             RGBColor[
              0.6836022441785135, 0.4759968673566604, 0.4543789760969123], 
             UndirectedEdge[178, 208] -> 
             RGBColor[
              0.5682690352445484, 0.6546904922633459, 0.9617287646563757], 
             UndirectedEdge[25, 270] -> 
             RGBColor[
              0.6264631588002338, 0.3537571973661052, 0.44082742491059396`], 
             UndirectedEdge[47, 217] -> 
             RGBColor[
              0.3091108096848224, 0.44082996157320997`, 0.9409658706037498], 
             UndirectedEdge[33, 142] -> 
             RGBColor[
              0.48700069591794165`, 0.581414250927177, 0.9554621837561624], 
             UndirectedEdge[26, 62] -> 
             RGBColor[
              0.639328319378579, 0.7035905304632146, 0.8180991043965136], 
             UndirectedEdge[48, 177] -> 
             RGBColor[
              0.2571918024145139, 0.3856344471125519, 0.9380320569260826], 
             UndirectedEdge[238, 300] -> 
             RGBColor[
              0.5079628538472739, 0.5906066185851409, 0.9586840949621895], 
             UndirectedEdge[25, 139] -> 
             RGBColor[
              0.6467579101264018, 0.37508826777146165`, 0.44198318097522515`],
              UndirectedEdge[3, 30] -> 
             RGBColor[
              0.3651413975797341, 0.4867101358889605, 0.9446897513210346], 
             UndirectedEdge[95, 171] -> 
             RGBColor[
              0.655892682854354, 0.4473482904883829, 0.45278353148109707`], 
             UndirectedEdge[21, 50] -> 
             RGBColor[
              0.657607000093386, 0.24519761669867296`, 0.4237352332092448], 
             UndirectedEdge[122, 232] -> 
             RGBColor[
              0.3033148568339878, 0.42850028506372106`, 0.9408641947076775], 
             UndirectedEdge[127, 136] -> 
             RGBColor[
              0.41643390163636396`, 0.5295211539149901, 0.9486212342877892], 
             UndirectedEdge[41, 290] -> 
             RGBColor[
              0.38237426815720477`, 0.5056151052134116, 0.9455855281400559], 
             UndirectedEdge[123, 259] -> 
             RGBColor[
              0.3979935104368444, 0.5191437078300922, 0.9465807724465609], 
             UndirectedEdge[20, 185] -> 
             RGBColor[
              0.21973296155591393`, 0.3482836528426605, 0.935824839143599], 
             UndirectedEdge[163, 211] -> 
             RGBColor[
              0.5591927386568296, 0.6439437786168856, 0.9616786252187527], 
             UndirectedEdge[33, 37] -> 
             RGBColor[
              0.2629813638579771, 0.3937404657692114, 0.9382877716744238], 
             UndirectedEdge[7, 9] -> 
             RGBColor[
              0.43913282598892533`, 0.5534737009327049, 0.9495621047300888], 
             UndirectedEdge[105, 263] -> 
             RGBColor[
              0.2589148396755163, 0.3890642518876115, 0.938070909760224], 
             UndirectedEdge[15, 49] -> 
             RGBColor[
              0.48625624885849617`, 0.5905630739767485, 0.9535944292288114], 
             UndirectedEdge[20, 237] -> 
             RGBColor[
              0.43313301476668997`, 0.5384057796105137, 0.9503611666187743], 
             UndirectedEdge[26, 220] -> 
             RGBColor[
              0.6126042233471596, 0.6857013503135403, 0.9616468864563438], 
             UndirectedEdge[101, 187] -> 
             RGBColor[
              0.2784608963135943, 0.40900637192183453`, 0.9392060718463953], 
             UndirectedEdge[93, 94] -> 
             RGBColor[
              0.4659891809274401, 0.5647891199071136, 0.9534013212105183], 
             UndirectedEdge[143, 297] -> 
             RGBColor[
              0.48505205433331167`, 0.5766572393763807, 0.955780064692964], 
             UndirectedEdge[208, 268] -> 
             RGBColor[
              0.6607709807641775, 0.7264083784581541, 0.899033436084923], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.5884403250415344, 0.6615710610271717, 0.965330880215026], 
             UndirectedEdge[224, 288] -> 
             RGBColor[
              0.27495256975780347`, 0.40081714585038786`, 0.9391711090476429],
              UndirectedEdge[1, 75] -> 
             RGBColor[
              0.2976660857689978, 0.4301963076360795, 0.9402630152758087], 
             UndirectedEdge[36, 113] -> 
             RGBColor[
              0.32844488662769733`, 0.4490896042770012, 0.9425134800492788], 
             UndirectedEdge[29, 244] -> 
             RGBColor[
              0.7025068730009905, 0.7656142895638405, 0.9673666140787465], 
             UndirectedEdge[36, 96] -> 
             RGBColor[
              0.25964123403172334`, 0.38951588408874327`, 0.938123695358638], 
             UndirectedEdge[58, 138] -> 
             RGBColor[
              0.4390824065774791, 0.5478370897914464, 0.9504106832334389], 
             UndirectedEdge[71, 136] -> 
             RGBColor[
              0.7456189317320912, 0.8007841272827585, 0.9753074804464807], 
             UndirectedEdge[144, 252] -> 
             RGBColor[
              0.8163850031617181, 0.8567402662966095, 0.9822656615882925], 
             UndirectedEdge[58, 198] -> 
             RGBColor[
              0.24039693193217984`, 0.37000279587950974`, 0.9370016216869226],
              UndirectedEdge[110, 154] -> 
             RGBColor[
              0.523431934562814, 0.6196634084361884, 0.9572598214869489], 
             UndirectedEdge[119, 152] -> 
             RGBColor[
              0.2772621687320862, 0.4059347560760317, 0.9392041404593118], 
             UndirectedEdge[38, 90] -> 
             RGBColor[
              0.5973830370056306, 0.6582515819196432, 0.6905268197706114], 
             UndirectedEdge[66, 179] -> 
             RGBColor[
              0.3606171248608707, 0.48354850080435097`, 0.9443171429783943], 
             UndirectedEdge[6, 21] -> 
             RGBColor[
              0.6661147562522106, 0.7285066333353468, 0.7680737398927586], 
             UndirectedEdge[176, 287] -> 
             RGBColor[
              0.4204452755294947, 0.538590298294821, 0.9480113790649483], 
             UndirectedEdge[142, 237] -> 
             RGBColor[
              0.6785756910176561, 0.7485968578316965, 0.9687556064591929], 
             UndirectedEdge[108, 221] -> 
             RGBColor[
              0.9487701210239108, 0.9611408319686642, 0.9656192434109355], 
             UndirectedEdge[44, 256] -> 
             RGBColor[
              0.27639154190774823`, 0.4078354131539176, 0.9390514614757777], 
             UndirectedEdge[89, 112] -> 
             RGBColor[
              0.9340395873671608, 0.9480760812001152, 0.9104718747847862], 
             UndirectedEdge[83, 184] -> 
             RGBColor[
              0.4321526123562799, 0.5479280379887984, 0.9489791118788778], 
             UndirectedEdge[259, 261] -> 
             RGBColor[
              0.4082799827969381, 0.5280533331752717, 0.9472362173693758], 
             UndirectedEdge[207, 231] -> 
             RGBColor[
              0.3143994166467091, 0.4410173228253102, 0.9414637185507367], 
             UndirectedEdge[112, 280] -> 
             RGBColor[
              0.5439178025880259, 0.6215772845184222, 0.9617648992919562], 
             UndirectedEdge[174, 194] -> 
             RGBColor[
              0.24780776065862714`, 0.3777920467446857, 0.9374236574195551], 
             UndirectedEdge[125, 200] -> 
             RGBColor[
              0.6485983028898019, 0.714634060565151, 0.8640366837602513], 
             UndirectedEdge[99, 222] -> 
             RGBColor[
              0.6028274770817119, 0.6740630806691679, 0.9532818806556718], 
             UndirectedEdge[108, 169] -> 
             RGBColor[
              0.7777884629022953, 0.8258401029832286, 0.9493905823172974], 
             UndirectedEdge[15, 57] -> 
             RGBColor[
              0.4573323621027874, 0.5670813597022146, 0.9513174349117137], 
             UndirectedEdge[4, 78] -> 
             RGBColor[
              0.41417730657472884`, 0.5284501749703957, 0.948374313485165], 
             UndirectedEdge[52, 86] -> 
             RGBColor[
              0.537279734924675, 0.6210420397019479, 0.9604109850378708], 
             UndirectedEdge[20, 282] -> 
             RGBColor[
              0.4087099583574082, 0.5185780421713059, 0.9484384941536323], 
             UndirectedEdge[42, 55] -> 
             RGBColor[
              0.4107290438154362, 0.5193799043642979, 0.9486736622444634], 
             UndirectedEdge[136, 165] -> 
             RGBColor[
              0.5396861727444109, 0.6371805734757552, 0.9569052189354813], 
             UndirectedEdge[161, 269] -> 
             RGBColor[
              0.73645508867622, 0.7941238355765365, 0.9743453212809012], 
             UndirectedEdge[57, 243] -> 
             RGBColor[
              0.5992231160606044, 0.6855153461685723, 0.9615921852043414], 
             UndirectedEdge[57, 146] -> 
             RGBColor[
              0.41140745176945553`, 0.521143149992638, 0.9486167012150859], 
             UndirectedEdge[4, 130] -> 
             RGBColor[
              0.3452892887570681, 0.4712436451735167, 0.9433049010949595], 
             UndirectedEdge[31, 58] -> 
             RGBColor[
              0.5731596163296513, 0.6536122786162253, 0.9632332372085812], 
             UndirectedEdge[95, 140] -> 
             RGBColor[
              0.23363578803968443`, 0.3628964049672148, 0.9366165845444611], 
             UndirectedEdge[58, 96] -> 
             RGBColor[
              0.29695844861799314`, 0.4287386426669741, 0.9402488555234545], 
             UndirectedEdge[16, 94] -> 
             RGBColor[
              0.5876592567324049, 0.6607501087116855, 0.965286399530308], 
             UndirectedEdge[113, 135] -> 
             RGBColor[
              0.3447351556876591, 0.4662117099217347, 0.9434411867729502], 
             UndirectedEdge[47, 262] -> 
             RGBColor[
              0.6443090869863579, 0.7140838887061416, 0.9431800245089674], 
             UndirectedEdge[153, 211] -> 
             RGBColor[
              0.5316466240743194, 0.6149910656661284, 0.9601099147441035], 
             UndirectedEdge[89, 111] -> 
             RGBColor[
              0.5958879542754325, 0.6601024655239335, 0.8837364264906511], 
             UndirectedEdge[137, 256] -> 
             RGBColor[
              0.2561687466794549, 0.3865799731697075, 0.937899803204471], 
             UndirectedEdge[136, 181] -> 
             RGBColor[
              0.45311948177483996`, 0.5641349411861345, 0.950854872635962], 
             UndirectedEdge[288, 291] -> 
             RGBColor[
              0.4893682776480772, 0.5748271632376467, 0.957033809347673], 
             UndirectedEdge[121, 296] -> 
             RGBColor[
              0.3089178480421185, 0.43432234597073277`, 0.941185731361439], 
             UndirectedEdge[241, 277] -> 
             RGBColor[
              0.3910454413485457, 0.5003596564612409, 0.947400836022903], 
             UndirectedEdge[217, 262] -> 
             RGBColor[
              0.6295806201967054, 0.6999988128072945, 0.942290164882224], 
             UndirectedEdge[75, 142] -> 
             RGBColor[
              0.5142732439291174, 0.6100794280663394, 0.9570153150192797], 
             UndirectedEdge[57, 112] -> 
             RGBColor[
              0.7299084274992389, 0.7884626788577777, 0.9742330736430007], 
             UndirectedEdge[274, 287] -> 
             RGBColor[
              0.48031199466533486`, 0.588271809350072, 0.9524261724031298], 
             UndirectedEdge[97, 252] -> 
             RGBColor[
              0.7031678052182843, 0.7669531985619169, 0.9718980320535924], 
             UndirectedEdge[18, 69] -> 
             RGBColor[
              0.5690397751629761, 0.6610111502838658, 0.9592160420436593], 
             UndirectedEdge[106, 167] -> 
             RGBColor[
              0.7104310189936016, 0.7737133786043076, 0.971772782684097], 
             UndirectedEdge[256, 296] -> 
             RGBColor[
              0.24959941208198907`, 0.3796751859879004, 0.9375256893176049], 
             UndirectedEdge[131, 183] -> 
             RGBColor[
              0.6350186499329236, 0.2711834126621213, 0.4288859161870152], 
             UndirectedEdge[172, 183] -> 
             RGBColor[
              0.2568940838000606, 0.38734234847249377`, 0.9379411100804493], 
             UndirectedEdge[1, 143] -> 
             RGBColor[
              0.25840669925319487`, 0.38893220321909683`, 0.9380272512927912],
              UndirectedEdge[17, 252] -> 
             RGBColor[
              0.557124365020907, 0.6389599417376981, 0.9619865065866879], 
             UndirectedEdge[126, 214] -> 
             RGBColor[
              0.6963574876162997, 0.7608506820125673, 0.9720220949852412], 
             UndirectedEdge[84, 134] -> 
             RGBColor[
              0.6163154745410109, 0.6983461473779513, 0.9636526033802966], 
             UndirectedEdge[45, 234] -> 
             RGBColor[
              0.6843939023693271, 0.43162252651428207`, 0.44683449432676237`],
              UndirectedEdge[32, 156] -> 
             RGBColor[
              0.8698021183037405, 0.8939499833394156, 0.6997933089269117], 
             UndirectedEdge[140, 149] -> 
             RGBColor[
              0.28991151398711956`, 0.41861153164116144`, 0.9399471478454252],
              UndirectedEdge[16, 150] -> 
             RGBColor[
              0.9521979820780742, 0.9637937244925916, 0.9631589951830111], 
             UndirectedEdge[209, 218] -> 
             RGBColor[
              0.8890275200328699, 0.5655218595444298, 0.4376325009243541], 
             UndirectedEdge[82, 281] -> 
             RGBColor[
              0.6804688310384495, 0.746980768059877, 0.9685013346015623], 
             UndirectedEdge[178, 182] -> 
             RGBColor[
              0.6421182505850977, 0.717885292443822, 0.9666470357846835], 
             UndirectedEdge[41, 157] -> 
             RGBColor[
              0.34116724705216955`, 0.46695351457435985`, 0.9430686045712096],
              UndirectedEdge[254, 288] -> 
             RGBColor[
              0.5731939538346693, 0.6407328513396582, 0.9390790276495036], 
             UndirectedEdge[129, 161] -> 
             RGBColor[
              0.7366709614945357, 0.794292477062899, 0.9743668374659848], 
             UndirectedEdge[20, 283] -> 
             RGBColor[
              0.3424258077717072, 0.4645633998244796, 0.9432762267322305], 
             UndirectedEdge[162, 210] -> 
             RGBColor[
              0.7894205463730306, 0.8355439237465223, 0.9796129936428479], 
             UndirectedEdge[203, 244] -> 
             RGBColor[
              0.7063660983216128, 0.768492493489059, 0.9608339522581002], 
             UndirectedEdge[121, 246] -> 
             RGBColor[
              0.5141061075639382, 0.6147494413669887, 0.9553512535446955], 
             UndirectedEdge[24, 259] -> 
             RGBColor[
              0.3834826565995315, 0.506575135572932, 0.9456561536714916], 
             UndirectedEdge[141, 281] -> 
             RGBColor[
              0.47194776578496667`, 0.5813471034996769, 0.951804802800234], 
             UndirectedEdge[110, 138] -> 
             RGBColor[
              0.656806461264446, 0.7311835379643092, 0.9668641431740013], 
             UndirectedEdge[67, 109] -> 
             RGBColor[
              0.6732259124787681, 0.734846014456602, 0.7839159096315567], 
             UndirectedEdge[154, 245] -> 
             RGBColor[
              0.2879350336641966, 0.4176365720313465, 0.9397942242472028], 
             UndirectedEdge[193, 249] -> 
             RGBColor[
              0.2967226995434713, 0.4261052330344559, 0.9403227792850312], 
             UndirectedEdge[82, 137] -> 
             RGBColor[
              0.5887567282148529, 0.6610906137502183, 0.9628938235589755], 
             UndirectedEdge[100, 125] -> 
             RGBColor[
              0.7479158325905786, 0.7995775640817957, 0.8707354239501596], 
             UndirectedEdge[104, 218] -> 
             RGBColor[
              0.8464119012689397, 0.8801971787905086, 0.9506169289329005], 
             UndirectedEdge[73, 149] -> 
             RGBColor[
              0.6448036038402432, 0.7157796243516928, 0.9617086458971198], 
             UndirectedEdge[108, 219] -> 
             RGBColor[
              0.6976376666609968, 0.76004845609558, 0.9432802037212332], 
             UndirectedEdge[58, 140] -> 
             RGBColor[
              0.25569120817477076`, 0.3860780499235946, 0.9378726080930841], 
             UndirectedEdge[9, 63] -> 
             RGBColor[
              0.3244023182263323, 0.45199037787379537`, 0.942016549165333], 
             UndirectedEdge[48, 217] -> 
             RGBColor[
              0.23908150895479363`, 0.36862020292764297`, 0.9369267102943544],
              UndirectedEdge[8, 271] -> 
             RGBColor[
              0.6742273892793833, 0.7419776759531493, 0.9705192527077868], 
             UndirectedEdge[18, 222] -> 
             RGBColor[
              0.7819364895859959, 0.8298040876695982, 0.965714195166657], 
             UndirectedEdge[215, 234] -> 
             RGBColor[
              0.6814824192768156, 0.4092435916452129, 0.4440464548293236], 
             UndirectedEdge[15, 146] -> 
             RGBColor[
              0.2880413226515224, 0.41774828849613693`, 0.9398002772477906], 
             UndirectedEdge[54, 151] -> 
             RGBColor[
              0.3735308594904517, 0.49495216155849536`, 0.945219934459554], 
             UndirectedEdge[195, 255] -> 
             RGBColor[
              0.7118943359418122, 0.7734770345351376, 0.9732304350015214], 
             UndirectedEdge[1, 11] -> 
             RGBColor[
              0.25195658784452357`, 0.3821527271678995, 0.9376599269901522], 
             UndirectedEdge[32, 178] -> 
             RGBColor[
              0.7749973117240281, 0.8241530572073164, 0.9782081473371551], 
             UndirectedEdge[126, 189] -> 
             RGBColor[
              0.5643070452517871, 0.6364545704586206, 0.9639187861781828], 
             UndirectedEdge[61, 273] -> 
             RGBColor[
              0.9113574053286768, 0.9311706119470908, 0.9572545868945954], 
             UndirectedEdge[54, 194] -> 
             RGBColor[
              0.3635249635582116, 0.48443533052326704`, 0.9446501134886094], 
             UndirectedEdge[38, 144] -> 
             RGBColor[
              0.8869762668310657, 0.9079133835364857, 0.7125333709956072], 
             UndirectedEdge[4, 220] -> 
             RGBColor[
              0.6129774027154017, 0.6860935854905013, 0.9616681384692958], 
             UndirectedEdge[45, 200] -> 
             RGBColor[
              0.6706465536794729, 0.41951552831337097`, 0.4459658387279649], 
             UndirectedEdge[2, 202] -> 
             RGBColor[
              0.30758590757859955`, 0.4327083893437321, 0.9411177150114646], 
             UndirectedEdge[17, 175] -> 
             RGBColor[
              0.5437896658551924, 0.6283272145837236, 0.9607146310762356], 
             UndirectedEdge[233, 262] -> 
             RGBColor[
              0.770308890365353, 0.8198918562256154, 0.9521278057621423], 
             UndirectedEdge[67, 138] -> 
             RGBColor[
              0.4764188301945693, 0.5830695961308454, 0.9526837792568235], 
             UndirectedEdge[39, 192] -> 
             RGBColor[
              0.8244993670679441, 0.863110012026995, 0.9500057263358416], 
             UndirectedEdge[164, 168] -> 
             RGBColor[
              0.24967733441976991`, 0.37975708730546964`, 0.9375301268794657],
              UndirectedEdge[19, 253] -> 
             RGBColor[
              0.291649811135385, 0.423872821542309, 0.9399203973357051], 
             UndirectedEdge[24, 74] -> 
             RGBColor[
              0.25987731684473503`, 0.3891925180861304, 0.9381580654868857], 
             UndirectedEdge[80, 133] -> 
             RGBColor[
              0.40567828837671654`, 0.5207892625359527, 0.9477745130128803], 
             UndirectedEdge[198, 222] -> 
             RGBColor[
              0.5769087591922204, 0.646820864825683, 0.9518058480151723], 
             UndirectedEdge[111, 212] -> 
             RGBColor[
              0.45502366452287835`, 0.5508581833145869, 0.9531576746274935], 
             UndirectedEdge[126, 184] -> 
             RGBColor[
              0.6561049104254338, 0.7262198796589028, 0.9693925933842886], 
             UndirectedEdge[132, 294] -> 
             RGBColor[
              0.6921519229988375, 0.7517367010519397, 0.8276790359157068], 
             UndirectedEdge[39, 136] -> 
             RGBColor[
              0.7636098040289638, 0.8142016903844165, 0.9448536264188667], 
             UndirectedEdge[133, 162] -> 
             RGBColor[
              0.5566432306739479, 0.6405180056189891, 0.961646460262819], 
             UndirectedEdge[22, 271] -> 
             RGBColor[
              0.43709968621881023`, 0.5529766078409017, 0.9490833326556076], 
             UndirectedEdge[107, 110] -> 
             RGBColor[
              0.4956141125551911, 0.5927568966126402, 0.9555902596834334], 
             UndirectedEdge[40, 191] -> 
             RGBColor[
              0.4059392018746844, 0.5260258663914856, 0.9470870648788811], 
             UndirectedEdge[143, 237] -> 
             RGBColor[
              0.42372434184051977`, 0.5285166678207905, 0.9498253566145132], 
             UndirectedEdge[157, 261] -> 
             RGBColor[
              0.32443235747786314`, 0.45245859434510227`, 0.9420022722056165],
              UndirectedEdge[35, 163] -> 
             RGBColor[
              0.563624191144951, 0.6474772985423403, 0.962101301113074], 
             UndirectedEdge[89, 175] -> 
             RGBColor[
              0.9069017615719899, 0.9264371155477034, 0.9078834447342197], 
             UndirectedEdge[16, 200] -> 
             RGBColor[
              0.6191249974232443, 0.6938225972209457, 0.9670783269132595], 
             UndirectedEdge[35, 189] -> 
             RGBColor[
              0.5180284150827091, 0.599553246961749, 0.9595046891192353], 
             UndirectedEdge[233, 291] -> 
             RGBColor[
              0.6864832141787608, 0.753986168123604, 0.9700825874603117], 
             UndirectedEdge[258, 290] -> 
             RGBColor[
              0.27601331261286505`, 0.4027882689654937, 0.9392001665542136], 
             UndirectedEdge[157, 259] -> 
             RGBColor[
              0.3604690110458255, 0.4836717324107983, 0.9442984959050056], 
             UndirectedEdge[105, 245] -> 
             RGBColor[
              0.22331955769850798`, 0.3520533927918565, 0.9360290904880262], 
             UndirectedEdge[100, 192] -> 
             RGBColor[
              0.5903716077030452, 0.6778047242519774, 0.9612540125110185], 
             UndirectedEdge[258, 278] -> 
             RGBColor[
              0.37213702469054655`, 0.48338582163349175`, 0.9460600436216311],
              UndirectedEdge[99, 201] -> 
             RGBColor[
              0.6251626764940938, 0.6887817674901715, 0.8253152229459708], 
             UndirectedEdge[9, 282] -> 
             RGBColor[
              0.47770303203039555`, 0.5847867317651514, 0.9525984926369935], 
             UndirectedEdge[84, 175] -> 
             RGBColor[
              0.6734309449820026, 0.7430044581419204, 0.9693349183405693], 
             UndirectedEdge[271, 291] -> 
             RGBColor[
              0.6082880580678225, 0.6895841833362866, 0.9641808760590675], 
             UndirectedEdge[127, 256] -> 
             RGBColor[
              0.27571926935011065`, 0.4071288120712985, 0.9390131765481584], 
             UndirectedEdge[80, 116] -> 
             RGBColor[
              0.46549428544635385`, 0.5754374543843108, 0.951482001074482], 
             UndirectedEdge[202, 268] -> 
             RGBColor[
              0.6042009065078668, 0.6692814265231513, 0.8957264760509902], 
             UndirectedEdge[161, 265] -> 
             RGBColor[
              0.90874458296748, 0.9281723612795731, 0.9196024699139692], 
             UndirectedEdge[22, 72] -> 
             RGBColor[
              0.5255684695834887, 0.6257191860544389, 0.9557938216278028], 
             UndirectedEdge[77, 162] -> 
             RGBColor[
              0.8301164117726716, 0.8673763101105376, 0.9836584384801882], 
             UndirectedEdge[93, 164] -> 
             RGBColor[
              0.4414555843473899, 0.5390027543816149, 0.952004169179488], 
             UndirectedEdge[19, 111] -> 
             RGBColor[
              0.240569609201416, 0.3701842906378482, 0.9370114554019525], 
             UndirectedEdge[37, 142] -> 
             RGBColor[
              0.5058458745304864, 0.601221728502297, 0.9565353887992034], 
             UndirectedEdge[43, 172] -> 
             RGBColor[
              0.5210414868833754, 0.6108267139002816, 0.9584086773722977], 
             UndirectedEdge[61, 285] -> 
             RGBColor[
              0.9844125918119507, 0.9858055349935739, 0.8091203797115252], 
             UndirectedEdge[38, 257] -> 
             RGBColor[
              0.9816504156503005, 0.9821908108571346, 0.6904374124482238], 
             UndirectedEdge[174, 185] -> 
             RGBColor[
              0.21794085236876662`, 0.34640003246068346`, 0.9357227811765789],
              UndirectedEdge[75, 237] -> 
             RGBColor[
              0.4629837283563226, 0.5697807722377732, 0.9520611205975307], 
             UndirectedEdge[30, 48] -> 
             RGBColor[
              0.3228982238982257, 0.4423098819777883, 0.9422840650730478], 
             UndirectedEdge[289, 298] -> 
             RGBColor[
              0.37339204296700546`, 0.48789941609789, 0.9458407326447645], 
             UndirectedEdge[123, 261] -> 
             RGBColor[
              0.36195685686888207`, 0.48793056976439614`, 0.9442845487471719],
              UndirectedEdge[77, 206] -> 
             RGBColor[
              0.8242755459335999, 0.8627189622365414, 0.983101331482255], 
             UndirectedEdge[121, 137] -> 
             RGBColor[
              0.31548718263958436`, 0.44122713315253986`, 0.941559845248305], 
             UndirectedEdge[87, 227] -> 
             RGBColor[
              0.2408140779822881, 0.3704412428267607, 0.937025377537364], 
             UndirectedEdge[123, 144] -> 
             RGBColor[
              0.5664641401566901, 0.6540324087462355, 0.9612306238370891], 
             UndirectedEdge[9, 37] -> 
             RGBColor[
              0.3293962719525076, 0.4572393398749598, 0.9423009474421461], 
             UndirectedEdge[178, 268] -> 
             RGBColor[
              0.8950737830238717, 0.9174123725157863, 0.9182611897968802], 
             UndirectedEdge[112, 253] -> 
             RGBColor[
              0.5920469326199979, 0.6721640517451186, 0.9645057820466097], 
             UndirectedEdge[78, 220] -> 
             RGBColor[
              0.7427477956119071, 0.7982836833722873, 0.9705345269140344], 
             UndirectedEdge[66, 67] -> 
             RGBColor[
              0.3130116756385525, 0.4423150534074282, 0.9412837658497941], 
             UndirectedEdge[20, 124] -> 
             RGBColor[
              0.41143755114756136`, 0.5207924248750071, 0.9486532202495748], 
             UndirectedEdge[18, 224] -> 
             RGBColor[
              0.49084796361478983`, 0.5952229720437987, 0.9536983535560901], 
             UndirectedEdge[72, 151] -> 
             RGBColor[
              0.438308907603728, 0.5475418992346647, 0.9503194996968398], 
             UndirectedEdge[25, 29] -> 
             RGBColor[
              0.879749191168204, 0.5696336045478863, 0.4575507631872979], 
             UndirectedEdge[135, 258] -> 
             RGBColor[
              0.2141934165015666, 0.34246123976309906`, 0.9355093702477764], 
             UndirectedEdge[130, 176] -> 
             RGBColor[
              0.4098752494813308, 0.5294350729968578, 0.9473378663518663], 
             UndirectedEdge[31, 245] -> 
             RGBColor[
              0.5553867701180007, 0.6349318903842462, 0.9622210999093975], 
             UndirectedEdge[295, 297] -> 
             RGBColor[
              0.5520570905390003, 0.6428837830324464, 0.9597496848720298], 
             UndirectedEdge[17, 30] -> 
             RGBColor[
              0.3623761961525018, 0.4838037338650426, 0.9445322771905026], 
             UndirectedEdge[22, 273] -> 
             RGBColor[
              0.6517835313611192, 0.7252566376356735, 0.9678304210990304], 
             UndirectedEdge[86, 165] -> 
             RGBColor[
              0.6764413098970227, 0.7454231463322183, 0.9696009810049289], 
             UndirectedEdge[124, 200] -> 
             RGBColor[
              0.4447003891077281, 0.5557537765568783, 0.9505474896634472], 
             UndirectedEdge[198, 258] -> 
             RGBColor[
              0.19816776719321438`, 0.3256172662551685, 0.9345967332274894], 
             UndirectedEdge[177, 217] -> 
             RGBColor[
              0.3124926363548901, 0.44375912985927196`, 0.9411813576087346], 
             UndirectedEdge[52, 110] -> 
             RGBColor[
              0.47956166588358806`, 0.575884757376882, 0.9546760965929524], 
             UndirectedEdge[121, 299] -> 
             RGBColor[
              0.6841488557369575, 0.7478998133387241, 0.9356297405948337], 
             UndirectedEdge[173, 196] -> 
             RGBColor[
              0.7242673597074658, 0.7824751587195102, 0.9474811182601806], 
             UndirectedEdge[238, 251] -> 
             RGBColor[
              0.7742287353033428, 0.8235960107167979, 0.9781200334258995], 
             UndirectedEdge[218, 284] -> 
             RGBColor[
              0.9676258017207116, 0.930343756825524, 0.6160114223450401], 
             UndirectedEdge[209, 276] -> 
             RGBColor[
              0.7271648047009415, 0.4373331689889105, 0.4457128311432823], 
             UndirectedEdge[8, 72] -> 
             RGBColor[
              0.7626961726440618, 0.8147202541666865, 0.977229741679982], 
             UndirectedEdge[56, 168] -> 
             RGBColor[
              0.31693958267825784`, 0.44867091233871287`, 0.9414258990670507],
              UndirectedEdge[201, 257] -> 
             RGBColor[
              0.9828748867773733, 0.9848098307849219, 0.8237135380702529], 
             UndirectedEdge[31, 51] -> 
             RGBColor[
              0.6917122652383301, 0.7575274738982372, 0.9711407747089777], 
             UndirectedEdge[53, 282] -> 
             RGBColor[
              0.7113070298237407, 0.7736140870647147, 0.9724776653088527], 
             UndirectedEdge[17, 97] -> 
             RGBColor[
              0.40878005972034687`, 0.5214764807796501, 0.9481853593135164], 
             UndirectedEdge[102, 162] -> 
             RGBColor[
              0.8445544195595949, 0.8788887856105492, 0.9850355485518667], 
             UndirectedEdge[36, 260] -> 
             RGBColor[
              0.23057655372706332`, 0.35968095573799164`, 0.9364423656760889],
              UndirectedEdge[79, 168] -> 
             RGBColor[
              0.36918402230414954`, 0.49392242006077375`, 0.9447548685620685],
              UndirectedEdge[142, 297] -> 
             RGBColor[
              0.739903403510448, 0.7967374293872866, 0.9747103145376437], 
             UndirectedEdge[232, 299] -> 
             RGBColor[
              0.6837863184261004, 0.7475858017417149, 0.935606640037965], 
             UndirectedEdge[50, 169] -> 
             RGBColor[
              0.7405602971016491, 0.3146269636663525, 0.4296897710979809], 
             UndirectedEdge[92, 153] -> 
             RGBColor[
              0.6284359378279933, 0.25337000293276496`, 0.4270322670891098], 
             UndirectedEdge[44, 299] -> 
             RGBColor[
              0.6278277263393586, 0.6964030125933238, 0.932140390725618], 
             UndirectedEdge[90, 252] -> 
             RGBColor[
              0.5267917733362831, 0.6070784646797671, 0.9602591103632967], 
             UndirectedEdge[7, 283] -> 
             RGBColor[
              0.4735857059991266, 0.5833150539454418, 0.9517574117788532], 
             UndirectedEdge[52, 179] -> 
             RGBColor[
              0.3467794840360297, 0.46900426294034103`, 0.9435291098043748], 
             UndirectedEdge[98, 296] -> 
             RGBColor[
              0.3570138784564144, 0.4750329529889914, 0.9445122360141296], 
             UndirectedEdge[18, 88] -> 
             RGBColor[
              0.4591953703454862, 0.567459905965269, 0.9516941902881827], 
             UndirectedEdge[100, 240] -> 
             RGBColor[
              0.5046684257463705, 0.6087515889312212, 0.9541484936175617], 
             UndirectedEdge[2, 214] -> 
             RGBColor[
              0.42814009101861455`, 0.5450212038631168, 0.948566328879964], 
             UndirectedEdge[114, 169] -> 
             RGBColor[
              0.6470489424464152, 0.7233514464488374, 0.9660348026581744], 
             UndirectedEdge[37, 295] -> 
             RGBColor[
              0.31799956155903875`, 0.4473680821474568, 0.9415747591335896], 
             UndirectedEdge[45, 225] -> 
             RGBColor[
              0.8659875905554191, 0.5788184262582119, 0.46223468261620904`], 
             UndirectedEdge[38, 74] -> 
             RGBColor[
              0.5949002973564235, 0.655642065133541, 0.6903854314204733], 
             UndirectedEdge[38, 158] -> 
             RGBColor[
              0.7144740920137529, 0.7695327608882648, 0.6976266331164238], 
             UndirectedEdge[69, 135] -> 
             RGBColor[
              0.3800376940775528, 0.4948719009478812, 0.9462203319124617], 
             UndirectedEdge[113, 224] -> 
             RGBColor[
              0.41118540250280167`, 0.5305493161756059, 0.947427024931778], 
             UndirectedEdge[124, 282] -> 
             RGBColor[
              0.5811676554164509, 0.6708571098284158, 0.9601707932031021], 
             UndirectedEdge[56, 79] -> 
             RGBColor[
              0.3802757916099403, 0.5037975103006691, 0.9454518150700743], 
             UndirectedEdge[49, 146] -> 
             RGBColor[
              0.4403313385251643, 0.5446248642671718, 0.9508936955321835], 
             UndirectedEdge[47, 166] -> 
             RGBColor[
              0.31510867886528215`, 0.4471341023687436, 0.9413074403805246], 
             UndirectedEdge[189, 197] -> 
             RGBColor[
              0.203359009655176, 0.3310735912264727, 0.934892366805943], 
             UndirectedEdge[125, 256] -> 
             RGBColor[
              0.6325426555579847, 0.6977585572325741, 0.863122338396906], 
             UndirectedEdge[69, 138] -> 
             RGBColor[
              0.5626975194144999, 0.6558622213518872, 0.9587167564386909], 
             UndirectedEdge[170, 255] -> 
             RGBColor[
              0.6907706779553826, 0.7566336030431798, 0.9712156416454636], 
             UndirectedEdge[41, 104] -> 
             RGBColor[
              0.5621929045023332, 0.6529909392517852, 0.9598334474438004], 
             UndirectedEdge[185, 283] -> 
             RGBColor[
              0.3231789152391025, 0.44433369544924295`, 0.9421801446757245], 
             UndirectedEdge[103, 277] -> 
             RGBColor[
              0.22733304130254395`, 0.35627181852925627`, 0.9362576524418591],
              UndirectedEdge[45, 282] -> 
             RGBColor[
              0.7616247312186214, 0.49625108382772937`, 0.4523813744210682], 
             UndirectedEdge[222, 245] -> 
             RGBColor[
              0.59618850781523, 0.6670851030351319, 0.9529038011774205], 
             UndirectedEdge[53, 195] -> 
             RGBColor[
              0.8865901022846808, 0.9124068979873217, 0.9890449494958824], 
             UndirectedEdge[121, 136] -> 
             RGBColor[
              0.47342730359160035`, 0.5817245557430095, 0.9521488690846243], 
             UndirectedEdge[92, 211] -> 
             RGBColor[
              0.8269117608224053, 0.42122492835934955`, 0.4426832075599697], 
             UndirectedEdge[26, 137] -> 
             RGBColor[
              0.26130190647771573`, 0.3919752495788086, 0.9381921290611525], 
             UndirectedEdge[139, 148] -> 
             RGBColor[
              0.526300383192805, 0.611904689498931, 0.9594125782121006], 
             UndirectedEdge[69, 258] -> 
             RGBColor[
              0.3588354748648954, 0.47258702425703725`, 0.9450128968941733], 
             UndirectedEdge[244, 272] -> 
             RGBColor[
              0.45107252792753116`, 0.5648425469167562, 0.9500390524851109], 
             UndirectedEdge[100, 256] -> 
             RGBColor[
              0.38876741237781154`, 0.5065040607657072, 0.9464938548544128], 
             UndirectedEdge[29, 206] -> 
             RGBColor[
              0.8825541590336643, 0.9090379195781335, 0.9834307373163897], 
             UndirectedEdge[101, 213] -> 
             RGBColor[
              0.5951138536346743, 0.6754612532778319, 0.9645539326200282], 
             UndirectedEdge[39, 107] -> 
             RGBColor[
              0.6253633485549059, 0.6944035588617907, 0.9353861276973501], 
             UndirectedEdge[134, 252] -> 
             RGBColor[
              0.781061940912138, 0.8291456216020212, 0.9787449888560389], 
             UndirectedEdge[14, 288] -> 
             RGBColor[
              0.32775486083339334`, 0.4459929675859383, 0.9426900414787314], 
             UndirectedEdge[155, 202] -> 
             RGBColor[
              0.5514735085066653, 0.6291379488409387, 0.9622528834863087], 
             UndirectedEdge[220, 228] -> 
             RGBColor[
              0.6206968878626408, 0.6942072538238768, 0.9621077517284762], 
             UndirectedEdge[228, 266] -> 
             RGBColor[
              0.3541427057637592, 0.48033946829047725`, 0.9438167674895275], 
             UndirectedEdge[113, 249] -> 
             RGBColor[
              0.39817230002725545`, 0.5192780208688357, 0.9465978415490709], 
             UndirectedEdge[109, 179] -> 
             RGBColor[
              0.7208313617010862, 0.7760794618535247, 0.7869492867601569], 
             UndirectedEdge[41, 209] -> 
             RGBColor[
              0.6995481888551323, 0.4140510331852808, 0.4437768465982874], 
             UndirectedEdge[76, 261] -> 
             RGBColor[
              0.5383233284159338, 0.6329223476936547, 0.9580559962041182], 
             UndirectedEdge[114, 219] -> 
             RGBColor[
              0.5668981462051167, 0.6575597995611888, 0.9599244240621102], 
             UndirectedEdge[130, 266] -> 
             RGBColor[
              0.40730559569536473`, 0.5272093680420086, 0.9471741302848802], 
             UndirectedEdge[1, 185] -> 
             RGBColor[
              0.24856847964676043`, 0.3785916106335834, 0.9374669792405464], 
             UndirectedEdge[202, 208] -> 
             RGBColor[
              0.2773961587285436, 0.4065595462707107, 0.9391940509104857], 
             UndirectedEdge[8, 285] -> 
             RGBColor[
              0.9619664209049661, 0.9688926287944042, 0.8411321339681394], 
             UndirectedEdge[65, 210] -> 
             RGBColor[
              0.5004539124999509, 0.5937013714146859, 0.9565216916245757], 
             UndirectedEdge[63, 183] -> 
             RGBColor[
              0.2602969940087634, 0.3909190228588092, 0.9381349007826805], 
             UndirectedEdge[51, 86] -> 
             RGBColor[
              0.6714442994035725, 0.7413663481008781, 0.969207598034232], 
             UndirectedEdge[91, 191] -> 
             RGBColor[
              0.5383055396829923, 0.6330470692706396, 0.9579955533676501], 
             UndirectedEdge[122, 181] -> 
             RGBColor[
              0.2833695723280844, 0.4112246821038552, 0.9395932988158838], 
             UndirectedEdge[17, 42] -> 
             RGBColor[
              0.4261076694111175, 0.5355438149265386, 0.9495494522214996], 
             UndirectedEdge[90, 253] -> 
             RGBColor[
              0.25352346880798016`, 0.38379961840648347`, 0.9377491585430284],
              UndirectedEdge[60, 136] -> 
             RGBColor[
              0.5217709181646099, 0.6226361627348512, 0.9554948644692195], 
             UndirectedEdge[80, 210] -> 
             RGBColor[
              0.6384556040757992, 0.715815180663486, 0.9657410463929091], 
             UndirectedEdge[229, 259] -> 
             RGBColor[
              0.4495518113743848, 0.5637610302822376, 0.9498770425289886], 
             UndirectedEdge[97, 159] -> 
             RGBColor[
              0.36699145668790123`, 0.4775540094420867, 0.9458055601915168], 
             UndirectedEdge[242, 280] -> 
             RGBColor[
              0.23572693046063206`, 0.36509432823771804`, 0.936735672011766], 
             UndirectedEdge[88, 99] -> 
             RGBColor[
              0.2800863578412023, 0.4117188989648385, 0.9392618757771976], 
             UndirectedEdge[21, 46] -> 
             RGBColor[
              0.34252861502386245`, 0.47110280317006803`, 0.943046598356527], 
             UndirectedEdge[246, 256] -> 
             RGBColor[
              0.45478767160380873`, 0.5601022813841564, 0.9516912115008613], 
             UndirectedEdge[14, 135] -> 
             RGBColor[
              0.3546481736049564, 0.47425954444336466`, 0.9442215758559809], 
             UndirectedEdge[67, 179] -> 
             RGBColor[
              0.3997278232233388, 0.5206458823966584, 0.9466912813237238], 
             UndirectedEdge[66, 69] -> 
             RGBColor[
              0.399290364858483, 0.5151076786284701, 0.9473167430316616], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.4349301120360173, 0.5402946427831247, 0.9504635086496954], 
             UndirectedEdge[116, 133] -> 
             RGBColor[
              0.33786030042464105`, 0.46422076207446944`, 0.9428530718567593],
              UndirectedEdge[2, 83] -> 
             RGBColor[
              0.43861082921349714`, 0.5535218208311026, 0.9493906237462428], 
             UndirectedEdge[103, 168] -> 
             RGBColor[
              0.27697620789513366`, 0.40844993417662434`, 0.9390847573388235],
              UndirectedEdge[26, 199] -> 
             RGBColor[
              0.5796875797745618, 0.6596053390408267, 0.9637365279166363], 
             UndirectedEdge[91, 239] -> 
             RGBColor[
              0.7628213216163442, 0.8146778953103236, 0.9769847890998402], 
             UndirectedEdge[13, 298] -> 
             RGBColor[
              0.6084653536800539, 0.6714857067572008, 0.8365519465978787], 
             UndirectedEdge[229, 261] -> 
             RGBColor[
              0.41351515780642245`, 0.5325478922165415, 0.9475808188295997], 
             UndirectedEdge[141, 179] -> 
             RGBColor[
              0.48443067017735253`, 0.592159167875344, 0.9526002024299179], 
             UndirectedEdge[59, 195] -> 
             RGBColor[
              0.5623816585488746, 0.6346559305985526, 0.9637750426610756], 
             UndirectedEdge[134, 253] -> 
             RGBColor[
              0.507793636383835, 0.6058667753287377, 0.9562350370357705], 
             UndirectedEdge[42, 292] -> 
             RGBColor[
              0.4762177292864943, 0.5832005117727823, 0.9525866654831172], 
             UndirectedEdge[70, 238] -> 
             RGBColor[
              0.5278507794692352, 0.6115100893811366, 0.9598166829048108], 
             UndirectedEdge[178, 202] -> 
             RGBColor[
              0.5116989609882379, 0.5975635403283429, 0.9584218046224429], 
             UndirectedEdge[29, 191] -> 
             RGBColor[
              0.6585275245584294, 0.7277971264439981, 0.9644881569054218], 
             UndirectedEdge[17, 38] -> 
             RGBColor[
              0.6277156286902545, 0.6901330589775743, 0.6922542159940026], 
             UndirectedEdge[40, 162] -> 
             RGBColor[
              0.635806702188991, 0.7119240073996174, 0.9665867522877821], 
             UndirectedEdge[13, 95] -> 
             RGBColor[
              0.614030210509889, 0.6773347241176592, 0.8368688569618699], 
             UndirectedEdge[206, 270] -> 
             RGBColor[
              0.502625110481709, 0.585223308805462, 0.9583457299013338], 
             UndirectedEdge[16, 295] -> 
             RGBColor[
              0.6434585227425962, 0.7151986774054171, 0.9686178676741917], 
             UndirectedEdge[37, 124] -> 
             RGBColor[
              0.432860895338563, 0.5433097179382242, 0.9498732480082547], 
             UndirectedEdge[22, 177] -> 
             RGBColor[
              0.39267686562082116`, 0.5144997933948071, 0.9462527498086617], 
             UndirectedEdge[115, 204] -> 
             RGBColor[
              0.45290833978318507`, 0.5658680263191528, 0.9503120318195897], 
             UndirectedEdge[192, 200] -> 
             RGBColor[
              0.49105407800226847`, 0.5928612207353327, 0.9545552723211103], 
             UndirectedEdge[13, 171] -> 
             RGBColor[
              0.9096870321965017, 0.6571820182947037, 0.38629632608827125`], 
             UndirectedEdge[39, 52] -> 
             RGBColor[
              0.609310901883303, 0.6775314196260325, 0.9344719646068689], 
             UndirectedEdge[92, 216] -> 
             RGBColor[
              0.683444694496562, 0.30562714528742735`, 0.43036853332870817`], 
             UndirectedEdge[82, 127] -> 
             RGBColor[
              0.6083072508855087, 0.6816394526518093, 0.9640071969026629], 
             UndirectedEdge[53, 150] -> 
             RGBColor[
              0.9079127481698476, 0.928481881064823, 0.9589350300389494], 
             UndirectedEdge[18, 66] -> 
             RGBColor[
              0.4436503875805775, 0.5511211434705164, 0.9508089265164623], 
             UndirectedEdge[31, 36] -> 
             RGBColor[
              0.5358424017433815, 0.6143895200379945, 0.961108077043765], 
             UndirectedEdge[71, 181] -> 
             RGBColor[
              0.643914913589207, 0.7154493308650242, 0.9680654683020218], 
             UndirectedEdge[43, 143] -> 
             RGBColor[
              0.4986063337010816, 0.5872459454348212, 0.9571310285884009], 
             UndirectedEdge[75, 185] -> 
             RGBColor[
              0.24958367514554664`, 0.37965864546992, 0.9375247931223551], 
             UndirectedEdge[46, 145] -> 
             RGBColor[
              0.263840028318402, 0.39111776120409447`, 0.9384657467480237], 
             UndirectedEdge[62, 255] -> 
             RGBColor[
              0.7448892740754325, 0.796215587146044, 0.8250515111501644], 
             UndirectedEdge[111, 242] -> 
             RGBColor[
              0.23277585855863503`, 0.3619925645599537, 0.936567612832667], 
             UndirectedEdge[4, 193] -> 
             RGBColor[
              0.2677911941858747, 0.3987959024046883, 0.9385616843960913], 
             UndirectedEdge[18, 258] -> 
             RGBColor[
              0.4031954975869899, 0.5086004890990836, 0.9485050803789741], 
             UndirectedEdge[81, 267] -> 
             RGBColor[
              0.374466062709676, 0.49054251155454265`, 0.9457640616098195], 
             UndirectedEdge[75, 124] -> 
             RGBColor[
              0.44128826473719407`, 0.5521674175022666, 0.9503531742283309], 
             UndirectedEdge[72, 106] -> 
             RGBColor[
              0.6590409128576833, 0.7328627914955024, 0.9671321937463165], 
             UndirectedEdge[262, 271] -> 
             RGBColor[
              0.6921137342544146, 0.755489871438298, 0.9462260943608982], 
             UndirectedEdge[17, 235] -> 
             RGBColor[
              0.22083180976148478`, 0.3494386119777157, 0.935887416923306], 
             UndirectedEdge[263, 279] -> 
             RGBColor[
              0.30282703251377785`, 0.43521875075445776`, 0.9405716441800952],
              UndirectedEdge[3, 252] -> 
             RGBColor[
              0.5598895664481394, 0.641866343761616, 0.9621439807172198], 
             UndirectedEdge[48, 158] -> 
             RGBColor[
              0.31001711059219184`, 0.4313890739788677, 0.9413980388515784], 
             UndirectedEdge[18, 36] -> 
             RGBColor[
              0.40810744773968555`, 0.5137632601451941, 0.948784808673591], 
             UndirectedEdge[105, 196] -> 
             RGBColor[
              0.3436685540225517, 0.4616785348499541, 0.9436910367785194], 
             UndirectedEdge[269, 298] -> 
             RGBColor[
              0.43260285639898893`, 0.5359596524958914, 0.950508704141209], 
             UndirectedEdge[85, 207] -> 
             RGBColor[
              0.520570187423221, 0.6080070966635398, 0.9587498007056566], 
             UndirectedEdge[79, 103] -> 
             RGBColor[
              0.3403124168268161, 0.46357653213858063`, 0.9431106733418471], 
             UndirectedEdge[76, 128] -> 
             RGBColor[
              0.4733446949839849, 0.5704964460100036, 0.9541406018043039], 
             UndirectedEdge[10, 265] -> 
             RGBColor[
              0.6862823443744204, 0.7485050393789288, 0.9006589976153547], 
             UndirectedEdge[88, 198] -> 
             RGBColor[
              0.2541676399517107, 0.38447668312135375`, 0.937785843136698], 
             UndirectedEdge[63, 143] -> 
             RGBColor[
              0.2460005716271747, 0.3758925764902266, 0.9373207406777105], 
             UndirectedEdge[49, 242] -> 
             RGBColor[
              0.4506414421275538, 0.5554614368516073, 0.9514808406799081], 
             UndirectedEdge[252, 253] -> 
             RGBColor[
              0.5782438059905414, 0.6611578132466813, 0.9631892275064955], 
             UndirectedEdge[16, 125] -> 
             RGBColor[
              0.9622177703041942, 0.9700205972044573, 0.890405550645661], 
             UndirectedEdge[59, 100] -> 
             RGBColor[
              0.34994884947998817`, 0.46570328992105275`, 0.9442831951242993],
              UndirectedEdge[75, 295] -> 
             RGBColor[
              0.32642693095766984`, 0.4562257817114992, 0.9420546853536658], 
             UndirectedEdge[94, 295] -> 
             RGBColor[
              0.2983733146373645, 0.42673965225685057`, 0.9404570734058306], 
             UndirectedEdge[26, 192] -> 
             RGBColor[
              0.480131590468712, 0.5813809938118568, 0.9539332528144465], 
             UndirectedEdge[132, 188] -> 
             RGBColor[
              0.8544765751368415, 0.8841653218954286, 0.840725405066648], 
             UndirectedEdge[186, 196] -> 
             RGBColor[
              0.3868815642238844, 0.5070981484346485, 0.9461519537815657], 
             UndirectedEdge[110, 179] -> 
             RGBColor[
              0.5801154542932154, 0.6687598242301221, 0.9608716452409016], 
             UndirectedEdge[61, 177] -> 
             RGBColor[
              0.6522507395883788, 0.7204137677062246, 0.9356769156042267], 
             UndirectedEdge[21, 264] -> 
             RGBColor[
              0.37169813004880525`, 0.4963679709822195, 0.944905254060327], 
             UndirectedEdge[200, 225] -> 
             RGBColor[
              0.5985170853227714, 0.6773904074989007, 0.965112725860216], 
             UndirectedEdge[83, 197] -> 
             RGBColor[
              0.34588019021457106`, 0.46397031974840536`, 0.9438199704792805],
              UndirectedEdge[220, 226] -> 
             RGBColor[
              0.8865290436812008, 0.6204575941389316, 0.4639926864313355], 
             UndirectedEdge[13, 140] -> 
             RGBColor[
              0.6143273120529061, 0.6776469966766959, 0.8368857764552223], 
             UndirectedEdge[144, 158] -> 
             RGBColor[
              0.6087557209872791, 0.6906632504250334, 0.9639254059706377], 
             UndirectedEdge[62, 225] -> 
             RGBColor[
              0.9432623622260548, 0.9540251043039518, 0.8431243897355435], 
             UndirectedEdge[65, 277] -> 
             RGBColor[
              0.23193518521701015`, 0.36110896357613753`, 0.9365197377295261],
              UndirectedEdge[99, 261] -> 
             RGBColor[
              0.3137125510527392, 0.44119139811731345`, 0.9413917950882382], 
             UndirectedEdge[260, 290] -> 
             RGBColor[
              0.3086867188983235, 0.43713009058511976`, 0.9410608687061974], 
             UndirectedEdge[72, 267] -> 
             RGBColor[
              0.5541507072333107, 0.648923534193697, 0.9580439200757831], 
             UndirectedEdge[39, 170] -> 
             RGBColor[
              0.9295774998577613, 0.9457375645754886, 0.9603357084132079], 
             UndirectedEdge[92, 163] -> 
             RGBColor[
              0.6468000142163334, 0.27267181156660303`, 0.4280780740722093], 
             UndirectedEdge[102, 133] -> 
             RGBColor[
              0.5659554922406507, 0.6479433502176715, 0.9625346720842052], 
             UndirectedEdge[184, 197] -> 
             RGBColor[
              0.2951568748288227, 0.4208389004267549, 0.9403661740120488], 
             UndirectedEdge[44, 200] -> 
             RGBColor[
              0.2924471892395655, 0.4247109164864945, 0.939965806839123], 
             UndirectedEdge[115, 132] -> 
             RGBColor[
              0.7396859244532064, 0.7920681173921706, 0.8309399954620689], 
             UndirectedEdge[9, 283] -> 
             RGBColor[
              0.41141888144469463`, 0.5307720894183251, 0.9474362252155917], 
             UndirectedEdge[52, 165] -> 
             RGBColor[
              0.38538727059875005`, 0.5005103027173712, 0.9465235571234836], 
             UndirectedEdge[160, 256] -> 
             RGBColor[
              0.3424206117344038, 0.4677407439636936, 0.9431593927247383], 
             UndirectedEdge[45, 215] -> 
             RGBColor[
              0.8517613239685276, 0.3988657947447022, 0.1972000083293031], 
             UndirectedEdge[16, 124] -> 
             RGBColor[
              0.7583198565221203, 0.8111403131961845, 0.9769163565488568], 
             UndirectedEdge[160, 246] -> 
             RGBColor[
              0.5238140479929949, 0.6231579714313644, 0.9559698349244403], 
             UndirectedEdge[57, 204] -> 
             RGBColor[
              0.5011276084699998, 0.6050146008924084, 0.9541080292836168], 
             UndirectedEdge[112, 252] -> 
             RGBColor[
              0.8653152371483008, 0.8954428980184023, 0.9870157338668781], 
             UndirectedEdge[5, 248] -> 
             RGBColor[
              0.7541612609618186, 0.8081304947619308, 0.9761673527728563], 
             UndirectedEdge[186, 276] -> 
             RGBColor[
              0.38986212868557935`, 0.5095179049375512, 0.9463865947341576], 
             UndirectedEdge[95, 154] -> 
             RGBColor[
              0.2836524597407608, 0.4131353153069458, 0.9395503379977636], 
             UndirectedEdge[198, 290] -> 
             RGBColor[
              0.28118988251717025`, 0.40822917214840704`, 0.9394949645522148],
              UndirectedEdge[77, 191] -> 
             RGBColor[
              0.600248911458365, 0.6814781691024059, 0.9641587510712871], 
             UndirectedEdge[36, 224] -> 
             RGBColor[
              0.2855556134694048, 0.41196161706308065`, 0.9397749367012211], 
             UndirectedEdge[29, 203] -> 
             RGBColor[
              0.9454071170732021, 0.9588052978176114, 0.9772956900775189], 
             UndirectedEdge[25, 172] -> 
             RGBColor[
              0.6542441654509327, 0.38295679677354594`, 0.4424095121410349], 
             UndirectedEdge[224, 260] -> 
             RGBColor[
              0.3133170696021676, 0.4411406676365963, 0.941355910558588], 
             UndirectedEdge[45, 255] -> 
             RGBColor[
              0.7337388651216709, 0.4736120814862733, 0.4501860968926229], 
             UndirectedEdge[102, 239] -> 
             RGBColor[
              0.8392027011786403, 0.8746214706421014, 0.9845250968751558], 
             UndirectedEdge[33, 239] -> 
             RGBColor[
              0.5343374532382075, 0.6184308996345314, 0.9601705000042208], 
             UndirectedEdge[64, 92] -> 
             RGBColor[
              0.73722541250487, 0.35027273493556704`, 0.4343304718566493], 
             UndirectedEdge[32, 268] -> 
             RGBColor[
              0.8674992572436571, 0.8958709434021248, 0.9155128187657027], 
             UndirectedEdge[85, 240] -> 
             RGBColor[
              0.6497361498046106, 0.7241969272878825, 0.9671598586913528], 
             UndirectedEdge[1, 174] -> 
             RGBColor[
              0.2660232629922178, 0.396937694626843, 0.9384610033300322], 
             UndirectedEdge[2, 184] -> 
             RGBColor[
              0.3878875138277488, 0.5103904015094523, 0.9459368272790113], 
             UndirectedEdge[60, 85] -> 
             RGBColor[
              0.6414971869691906, 0.7175081660970426, 0.9665112573566332], 
             UndirectedEdge[121, 127] -> 
             RGBColor[
              0.33503770531024013`, 0.46177597205413085`, 0.9426732185919925],
              UndirectedEdge[132, 212] -> 
             RGBColor[
              0.851172063255389, 0.8815838120984174, 0.8403960422047241], 
             UndirectedEdge[172, 206] -> 
             RGBColor[
              0.5442966204577571, 0.6290227079166231, 0.9607188607469952], 
             UndirectedEdge[147, 148] -> 
             RGBColor[
              0.5731396605973964, 0.6585925664046135, 0.9621731238050422], 
             UndirectedEdge[118, 226] -> 
             RGBColor[
              0.7739967554078042, 0.5315997885762159, 0.4567046970209727], 
             UndirectedEdge[75, 283] -> 
             RGBColor[
              0.37227652136133993`, 0.4959383924517391, 0.9449761807109868], 
             UndirectedEdge[188, 243] -> 
             RGBColor[
              0.6657944980574247, 0.7384659760985746, 0.9675815973448934], 
             UndirectedEdge[88, 258] -> 
             RGBColor[
              0.2489910700474055, 0.3790357799384404, 0.9374910451386966], 
             UndirectedEdge[197, 293] -> 
             RGBColor[
              0.38578843237223626`, 0.4963696285778191, 0.9469616934906397], 
             UndirectedEdge[86, 179] -> 
             RGBColor[
              0.6378335233343023, 0.713917106555188, 0.9666065336858201], 
             UndirectedEdge[41, 76] -> 
             RGBColor[
              0.5550582179902402, 0.6474172679229124, 0.9591223285697112], 
             UndirectedEdge[175, 242] -> 
             RGBColor[
              0.5437896658551924, 0.6283272145837236, 0.9607146310762356], 
             UndirectedEdge[89, 285] -> 
             RGBColor[
              0.9919437226091593, 0.9906299672511353, 0.76089254680882], 
             UndirectedEdge[138, 171] -> 
             RGBColor[
              0.7783515494848375, 0.5553958321063086, 0.46115352790356867`], 
             UndirectedEdge[181, 207] -> 
             RGBColor[
              0.2991399004757561, 0.427800296883614, 0.9404913956737839], 
             UndirectedEdge[17, 55] -> 
             RGBColor[
              0.24735799392728822`, 0.3773193133931907, 0.9373980438695757], 
             UndirectedEdge[142, 295] -> 
             RGBColor[
              0.5420188936190034, 0.6350418673054224, 0.9587491712153282], 
             UndirectedEdge[53, 200] -> 
             RGBColor[
              0.5748397635150178, 0.6585107537931771, 0.9628543617691978], 
             UndirectedEdge[33, 237] -> 
             RGBColor[
              0.43571118034514683`, 0.5411155950986108, 0.9505079893344133], 
             UndirectedEdge[51, 67] -> 
             RGBColor[
              0.433338599292609, 0.5480951239423485, 0.9492923456721356], 
             UndirectedEdge[47, 48] -> 
             RGBColor[
              0.2538099757444462, 0.38270527882648997`, 0.9378165699210979], 
             UndirectedEdge[102, 237] -> 
             RGBColor[
              0.7405764282855796, 0.7973061661061809, 0.9748625862053484], 
             UndirectedEdge[150, 282] -> 
             RGBColor[
              0.7750457809724047, 0.8235105211248229, 0.9464134318372563], 
             UndirectedEdge[214, 293] -> 
             RGBColor[
              0.5123134317048109, 0.6149581491718767, 0.9547503364911898], 
             UndirectedEdge[73, 245] -> 
             RGBColor[
              0.5928104518162438, 0.6645657544021469, 0.958621968845595], 
             UndirectedEdge[82, 192] -> 
             RGBColor[
              0.8075864122058493, 0.8504963579832665, 0.9786349473122695], 
             UndirectedEdge[82, 266] -> 
             RGBColor[
              0.6735048629854152, 0.7409489289515503, 0.9680575967152182], 
             UndirectedEdge[30, 38] -> 
             RGBColor[
              0.7273552053197867, 0.7804535688871854, 0.6985126593378933], 
             UndirectedEdge[146, 242] -> 
             RGBColor[
              0.2524265159205801, 0.38264665137099585`, 0.9376866886988873], 
             UndirectedEdge[25, 77] -> 
             RGBColor[
              0.8408967824348278, 0.5387542996534915, 0.4573311592978748], 
             UndirectedEdge[68, 271] -> 
             RGBColor[
              0.621347155812153, 0.6998124131820791, 0.9654754888329407], 
             UndirectedEdge[23, 267] -> 
             RGBColor[
              0.7447434846651255, 0.7987142473037271, 0.9387842229211317], 
             UndirectedEdge[10, 161] -> 
             RGBColor[
              0.6074511987983996, 0.6875471419479072, 0.9646956063038963], 
             UndirectedEdge[223, 287] -> 
             RGBColor[
              0.4915353977064101, 0.597383473547362, 0.9533097198032031], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.2921141434266645, 0.41805345897082213`, 0.9401777853765658], 
             UndirectedEdge[218, 229] -> 
             RGBColor[
              0.7144690441473354, 0.7742490519845225, 0.9394306326842927], 
             UndirectedEdge[62, 170] -> 
             RGBColor[
              0.9408774876953689, 0.9521234700888774, 0.8428969182738041], 
             UndirectedEdge[188, 294] -> 
             RGBColor[
              0.5515166030763572, 0.6439488602152313, 0.9590663140091717], 
             UndirectedEdge[181, 299] -> 
             RGBColor[
              0.663841033920197, 0.730310198781849, 0.9343357441461715], 
             UndirectedEdge[69, 109] -> 
             RGBColor[
              0.7595046016986986, 0.8076386396776438, 0.7899488868134241], 
             UndirectedEdge[48, 175] -> 
             RGBColor[
              0.5043116936009163, 0.5868333626964695, 0.9584664189587808], 
             UndirectedEdge[248, 270] -> 
             RGBColor[
              0.5319053635948836, 0.6085705878466096, 0.9611385065820589], 
             UndirectedEdge[85, 232] -> 
             RGBColor[
              0.592791035085324, 0.6762825475081917, 0.9631421614151693], 
             UndirectedEdge[65, 152] -> 
             RGBColor[
              0.298254773343346, 0.42799931453047346`, 0.9403996382361475], 
             UndirectedEdge[43, 63] -> 
             RGBColor[
              0.5244443970920781, 0.6144033882865971, 0.9586024680745289], 
             UndirectedEdge[184, 293] -> 
             RGBColor[
              0.47206085451394514`, 0.5803273468182122, 0.9521208348902371], 
             UndirectedEdge[24, 260] -> 
             RGBColor[
              0.2904933433469943, 0.4213719031082017, 0.9399016029038371], 
             UndirectedEdge[201, 229] -> 
             RGBColor[
              0.7249652832477771, 0.7801382615893997, 0.8315042466873321], 
             UndirectedEdge[17, 48] -> 
             RGBColor[
              0.2232586472686935, 0.35198937206817715`, 0.9360256217291572], 
             UndirectedEdge[153, 163] -> 
             RGBColor[
              0.26147900416521164`, 0.3921613904770087, 0.9382022145124629], 
             UndirectedEdge[33, 200] -> 
             RGBColor[
              0.2748208576271422, 0.4061845243878654, 0.9389620133296164], 
             UndirectedEdge[33, 282] -> 
             RGBColor[
              0.41128812393586506`, 0.521287857659403, 0.9485853168692713], 
             UndirectedEdge[150, 237] -> 
             RGBColor[
              0.7994688373816865, 0.8433382585640308, 0.9483361043023986], 
             UndirectedEdge[172, 203] -> 
             RGBColor[
              0.6071495784972951, 0.6787900861561009, 0.9545838135081244], 
             UndirectedEdge[56, 93] -> 
             RGBColor[
              0.5087178326058778, 0.6079165794148582, 0.955899941367073], 
             UndirectedEdge[122, 299] -> 
             RGBColor[
              0.5957951426163257, 0.6627347361173042, 0.9303161824705523], 
             UndirectedEdge[44, 100] -> 
             RGBColor[
              0.3917647189403422, 0.5096544200031392, 0.9466645470290311], 
             UndirectedEdge[31, 171] -> 
             RGBColor[
              0.8677363559862856, 0.6259126246561613, 0.4697018972203302], 
             UndirectedEdge[136, 256] -> 
             RGBColor[
              0.41410886763147087`, 0.5270773957601772, 0.9484888270407901], 
             UndirectedEdge[146, 159] -> 
             RGBColor[
              0.2106379128881344, 0.3387241800334324, 0.9353068895768877], 
             UndirectedEdge[65, 133] -> 
             RGBColor[
              0.2676765968008682, 0.3986754532871526, 0.9385551582445468], 
             UndirectedEdge[58, 245] -> 
             RGBColor[
              0.25967668055518955`, 0.3902670340889585, 0.938099574849171], 
             UndirectedEdge[172, 272] -> 
             RGBColor[
              0.3518560081032134, 0.4751401395837981, 0.9437889137351351], 
             UndirectedEdge[99, 218] -> 
             RGBColor[
              0.6146664373936521, 0.6828925578852945, 0.9332416089429313], 
             UndirectedEdge[18, 113] -> 
             RGBColor[
              0.5337372367730824, 0.6323509592577192, 0.9564368969041479], 
             UndirectedEdge[43, 131] -> 
             RGBColor[
              0.8111169186551334, 0.42017298961398, 0.44253096104824763`], 
             UndirectedEdge[2, 156] -> 
             RGBColor[
              0.6932635906743169, 0.7506362614684664, 0.6852375903471111], 
             UndirectedEdge[165, 232] -> 
             RGBColor[
              0.45792743910743006`, 0.5691213800178867, 0.950934102682816], 
             UndirectedEdge[173, 186] -> 
             RGBColor[
              0.6285470969397239, 0.6987363771809841, 0.9412217419107725], 
             UndirectedEdge[39, 281] -> 
             RGBColor[
              0.6973817859005444, 0.7595944221036055, 0.9398721136251343], 
             UndirectedEdge[77, 91] -> 
             RGBColor[
              0.7630472937770785, 0.8148580793774423, 0.9770063425262588], 
             UndirectedEdge[15, 19] -> 
             RGBColor[
              0.30614517689669285`, 0.436776587158467, 0.9408312649648007], 
             UndirectedEdge[119, 241] -> 
             RGBColor[
              0.3954265417670084, 0.5049644707788555, 0.9476503332104773], 
             UndirectedEdge[103, 116] -> 
             RGBColor[
              0.3228904499560393, 0.44848650008862934`, 0.9420005610184816], 
             UndirectedEdge[99, 257] -> 
             RGBColor[
              0.6128939831597822, 0.6815706644198016, 0.936241911630772], 
             UndirectedEdge[17, 253] -> 
             RGBColor[
              0.28385606049260403`, 0.41568109546441456`, 0.9394765547664196],
              UndirectedEdge[204, 292] -> 
             RGBColor[
              0.39225673249650117`, 0.51417479911701, 0.9462152300290358], 
             UndirectedEdge[65, 241] -> 
             RGBColor[
              0.41641914637826816`, 0.5270290292332973, 0.948845830987313], 
             UndirectedEdge[71, 256] -> 
             RGBColor[
              0.6049042994458379, 0.678391785439067, 0.9656994227068498], 
             UndirectedEdge[37, 102] -> 
             RGBColor[
              0.5678466117984098, 0.6499310367767814, 0.9626423685453589], 
             UndirectedEdge[61, 217] -> 
             RGBColor[
              0.6341404461286585, 0.7033995235213155, 0.9345715689724985], 
             UndirectedEdge[35, 184] -> 
             RGBColor[
              0.6098262802563559, 0.6893185561620313, 0.9649784963253412], 
             UndirectedEdge[164, 241] -> 
             RGBColor[
              0.3845181289884382, 0.49349903731526124`, 0.9470291152402882], 
             UndirectedEdge[192, 255] -> 
             RGBColor[
              0.5856925451655655, 0.6740060504946861, 0.9608856595680972], 
             UndirectedEdge[112, 134] -> 
             RGBColor[
              0.7948650675415945, 0.8401518601004587, 0.980061543396153], 
             UndirectedEdge[44, 195] -> 
             RGBColor[
              0.6041975280092284, 0.6786070606806391, 0.9661563945658075], 
             UndirectedEdge[127, 281] -> 
             RGBColor[
              0.3502058835079445, 0.47491388563417913`, 0.9436397214940568], 
             UndirectedEdge[59, 192] -> 
             RGBColor[
              0.43617986777262785`, 0.5351849465581013, 0.9514302672276514], 
             UndirectedEdge[108, 264] -> 
             RGBColor[
              0.6868736471585482, 0.7507252034179099, 0.9425943299167858], 
             UndirectedEdge[136, 296] -> 
             RGBColor[
              0.39031404436824235`, 0.502067527831592, 0.9471337470572357], 
             UndirectedEdge[118, 130] -> 
             RGBColor[
              0.5050613453841514, 0.6077904452313345, 0.9545331304082845], 
             UndirectedEdge[85, 136] -> 
             RGBColor[
              0.6745497687223049, 0.7443417409660602, 0.9691132776678346], 
             UndirectedEdge[104, 157] -> 
             RGBColor[
              0.4976470431769141, 0.5941144182580542, 0.9558293936138372], 
             UndirectedEdge[158, 217] -> 
             RGBColor[
              0.36531794453256805`, 0.4895137567255877, 0.9445473395342303], 
             UndirectedEdge[11, 174] -> 
             RGBColor[
              0.2213289605665298, 0.34996114899499964`, 0.9359157289261846], 
             UndirectedEdge[39, 220] -> 
             RGBColor[
              0.9569719999463917, 0.9674303685286785, 0.9577193599777388], 
             UndirectedEdge[32, 208] -> 
             RGBColor[
              0.5406945094643338, 0.6331490631496842, 0.958980393625198], 
             UndirectedEdge[27, 103] -> 
             RGBColor[
              0.22948186939702753`, 0.3585303731001287, 0.9363800250229337], 
             UndirectedEdge[212, 250] -> 
             RGBColor[
              0.682713151645127, 0.752059969968085, 0.9690101247049983], 
             UndirectedEdge[129, 298] -> 
             RGBColor[
              0.43281872921730463`, 0.5361282939822538, 0.9505302203262925], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.36283193070763275`, 0.48587640217609923`, 0.9444432728948557],
              UndirectedEdge[261, 290] -> 
             RGBColor[
              0.3656393785828983, 0.491120184984154, 0.944519195774463], 
             UndirectedEdge[24, 113] -> 
             RGBColor[
              0.38836167624762835`, 0.5107805516472113, 0.945972717277027], 
             UndirectedEdge[15, 243] -> 
             RGBColor[
              0.4758569869426713, 0.5821204846720713, 0.9527757612370462], 
             UndirectedEdge[246, 296] -> 
             RGBColor[
              0.43099284834058027`, 0.5350924134555712, 0.950336131517307], 
             UndirectedEdge[131, 174] -> 
             RGBColor[
              0.6305654108378796, 0.2665027760215637, 0.42863231080852937`], 
             UndirectedEdge[44, 121] -> 
             RGBColor[
              0.3357099778678777, 0.46248257313674995`, 0.9427115035196119], 
             UndirectedEdge[155, 293] -> 
             RGBColor[
              0.7224066722992282, 0.7823506891577229, 0.9736675152324462], 
             UndirectedEdge[105, 140] -> 
             RGBColor[
              0.2193340853180892, 0.3478644086264926, 0.9358021237319394], 
             UndirectedEdge[51, 138] -> 
             RGBColor[
              0.5576350554861578, 0.6517522850734583, 0.9583182207338354], 
             UndirectedEdge[133, 277] -> 
             RGBColor[
              0.2423028917711457, 0.3720060805150963, 0.9371101632801369], 
             UndirectedEdge[201, 261] -> 
             RGBColor[
              0.6836934546703305, 0.7444305644824338, 0.8288634215277193], 
             UndirectedEdge[19, 57] -> 
             RGBColor[
              0.429511306014626, 0.540171448654968, 0.9496476889320961], 
             UndirectedEdge[104, 261] -> 
             RGBColor[
              0.5454580149280267, 0.6384960190225276, 0.9587671150782073], 
             UndirectedEdge[15, 111] -> 
             RGBColor[
              0.26839066528957733`, 0.3970942016850948, 0.9386812013815702], 
             UndirectedEdge[71, 85] -> 
             RGBColor[
              0.865345200536672, 0.89565613064495, 0.9863238733338944], 
             UndirectedEdge[84, 158] -> 
             RGBColor[
              0.4791363619732782, 0.5875601694243187, 0.9522665382333668], 
             UndirectedEdge[65, 162] -> 
             RGBColor[
              0.5462755241198124, 0.6296208886800303, 0.9610560347122084], 
             UndirectedEdge[156, 268] -> 
             RGBColor[
              0.9898785896035842, 0.9872092986478855, 0.6398463513866367], 
             UndirectedEdge[48, 252] -> 
             RGBColor[
              0.5176463927666309, 0.5974660898504438, 0.9597382944692332], 
             UndirectedEdge[204, 235] -> 
             RGBColor[
              0.3002418628596396, 0.4224734902930507, 0.9407915998441123], 
             UndirectedEdge[62, 130] -> 
             RGBColor[
              0.7005838738256658, 0.7589663337250826, 0.8219173324639986], 
             UndirectedEdge[142, 283] -> 
             RGBColor[
              0.5878684840226733, 0.6747544780456624, 0.9616706665726491], 
             UndirectedEdge[99, 259] -> 
             RGBColor[
              0.3497492046207016, 0.4724045361830096, 0.9436880187876273], 
             UndirectedEdge[43, 244] -> 
             RGBColor[
              0.620258006707693, 0.7005291212332398, 0.9646588161222736], 
             UndirectedEdge[36, 154] -> 
             RGBColor[
              0.26839066528957733`, 0.3970942016850948, 0.9386812013815702], 
             UndirectedEdge[11, 185] -> 
             RGBColor[
              0.20387417722107243`, 0.33161506500174, 0.9349217048366987], 
             UndirectedEdge[20, 150] -> 
             RGBColor[
              0.605315676703515, 0.6734458361714142, 0.9348958588837291], 
             UndirectedEdge[175, 252] -> 
             RGBColor[
              0.8381774113531297, 0.8738039323659904, 0.9844273038163116], 
             UndirectedEdge[97, 292] -> 
             RGBColor[
              0.4588901195957237, 0.5691331776258938, 0.951222572575134], 
             UndirectedEdge[176, 226] -> 
             RGBColor[
              0.7105393581392572, 0.4793628737532314, 0.4519078543166939], 
             UndirectedEdge[80, 103] -> 
             RGBColor[
              0.3907084379081148, 0.5050550005501127, 0.9469220021746025], 
             UndirectedEdge[137, 220] -> 
             RGBColor[
              0.5902455748831361, 0.6622009931576611, 0.9603735945029739], 
             UndirectedEdge[20, 167] -> 
             RGBColor[
              0.46907310205015024`, 0.5667133453994759, 0.9537854734772054], 
             UndirectedEdge[240, 256] -> 
             RGBColor[
              0.3892952487137765, 0.5069325820819995, 0.9465354080643082], 
             UndirectedEdge[113, 278] -> 
             RGBColor[
              0.5026787638766391, 0.6071362917921275, 0.9539918601468049], 
             UndirectedEdge[181, 240] -> 
             RGBColor[
              0.4283058628571456, 0.5439901275079568, 0.9489014536594801], 
             UndirectedEdge[7, 151] -> 
             RGBColor[
              0.390765664005434, 0.5089441522828533, 0.9465767214041425], 
             UndirectedEdge[6, 101] -> 
             RGBColor[
              0.656826162639615, 0.7204613204064061, 0.7674818789213449], 
             UndirectedEdge[65, 116] -> 
             RGBColor[
              0.3274925938705055, 0.45332364513551066`, 0.9422626463061485], 
             UndirectedEdge[50, 264] -> 
             RGBColor[
              0.6799504199391508, 0.26455036395614, 0.42515893616430656`], 
             UndirectedEdge[55, 235] -> 
             RGBColor[
              0.20545318416580344`, 0.333274701415475, 0.9350116269462697], 
             UndirectedEdge[100, 232] -> 
             RGBColor[
              0.44772331102708396`, 0.5608372091515303, 0.9501307963413783], 
             UndirectedEdge[28, 163] -> 
             RGBColor[
              0.6386762088035556, 0.7052775778892284, 0.8914406605383174], 
             UndirectedEdge[11, 63] -> 
             RGBColor[
              0.2395504602185034, 0.36911310043902934`, 0.9369534163750715], 
             UndirectedEdge[234, 274] -> 
             RGBColor[
              0.4400299247384219, 0.5533815050150834, 0.9498594345274227], 
             UndirectedEdge[148, 270] -> 
             RGBColor[
              0.4958582562035531, 0.5799080838908963, 0.9576789441151536], 
             UndirectedEdge[96, 245] -> 
             RGBColor[
              0.2791856024063426, 0.410058254434995, 0.9392367182242707], 
             UndirectedEdge[159, 235] -> 
             RGBColor[
              0.17904320672903912`, 0.3055161406401523, 0.9335076178013064], 
             UndirectedEdge[53, 287] -> 
             RGBColor[
              0.635742856476712, 0.7115615554295323, 0.9667240830431011], 
             UndirectedEdge[105, 289] -> 
             RGBColor[
              0.3646551970752454, 0.4787164371176262, 0.945343182196234], 
             UndirectedEdge[56, 164] -> 
             RGBColor[
              0.26076910372556067`, 0.38963217754536505`, 0.9382270733874715],
              UndirectedEdge[112, 235] -> 
             RGBColor[
              0.5290226818888786, 0.6059215682584198, 0.9609166442034962], 
             UndirectedEdge[7, 43] -> 
             RGBColor[
              0.6391749048546712, 0.7158867113455066, 0.9661480236392849], 
             UndirectedEdge[242, 243] -> 
             RGBColor[
              0.44024218021172895`, 0.5470188475469302, 0.9506621726881428], 
             UndirectedEdge[151, 286] -> 
             RGBColor[
              0.25610552289955874`, 0.3865135209684175, 0.937896202703737], 
             UndirectedEdge[126, 163] -> 
             RGBColor[
              0.609902821314029, 0.6843786220392118, 0.9665153981720216], 
             UndirectedEdge[31, 138] -> 
             RGBColor[
              0.7347924961402903, 0.7925019460867341, 0.9745322082936656], 
             UndirectedEdge[95, 138] -> 
             RGBColor[
              0.4170269864423928, 0.5246554448350667, 0.9491546596848159], 
             UndirectedEdge[197, 275] -> 
             RGBColor[
              0.5689453301176459, 0.6415547655781453, 0.9641488340468352], 
             UndirectedEdge[198, 245] -> 
             RGBColor[
              0.2226240857205293, 0.35132240764753064`, 0.9359894843877389], 
             UndirectedEdge[187, 264] -> 
             RGBColor[
              0.3212646196948372, 0.44608080573697584`, 0.9419334872504016], 
             UndirectedEdge[62, 195] -> 
             RGBColor[
              0.9620011456817985, 0.9689669015808351, 0.8449117116298619], 
             UndirectedEdge[169, 187] -> 
             RGBColor[
              0.4121794354385844, 0.5211957053022946, 0.9487297396509131], 
             UndirectedEdge[82, 199] -> 
             RGBColor[
              0.907142401511699, 0.9287207032122364, 0.9884382224144594], 
             UndirectedEdge[126, 155] -> 
             RGBColor[
              0.9064507282107169, 0.9282432219984136, 0.9909392737264977], 
             UndirectedEdge[82, 220] -> 
             RGBColor[
              0.9400590450842967, 0.95481671448495, 0.9863485809541668], 
             UndirectedEdge[32, 202] -> 
             RGBColor[
              0.4841244352080233, 0.5760221112146813, 0.9556734335912652], 
             UndirectedEdge[113, 260] -> 
             RGBColor[
              0.35620634276046015`, 0.47826865485051684`, 0.9440944539066457],
              UndirectedEdge[105, 230] -> 
             RGBColor[
              0.4546933328704373, 0.5508592120420934, 0.9530837330881365], 
             UndirectedEdge[245, 289] -> 
             RGBColor[
              0.38323947372027645`, 0.4982496901827491, 0.946401529258195], 
             UndirectedEdge[108, 187] -> 
             RGBColor[
              0.6029250070359327, 0.6714089172864657, 0.9374870086742679], 
             UndirectedEdge[137, 228] -> 
             RGBColor[
              0.2693945709931969, 0.4004811530891451, 0.9386529943332849], 
             UndirectedEdge[88, 261] -> 
             RGBColor[
              0.3386171360174388, 0.46736769595710065`, 0.942810074358946], 
             UndirectedEdge[192, 228] -> 
             RGBColor[
              0.48822425498419325`, 0.5898868973221933, 0.9543941180865789], 
             UndirectedEdge[42, 97] -> 
             RGBColor[
              0.5721511096084948, 0.6635370717507574, 0.9594609776884042], 
             UndirectedEdge[121, 240] -> 
             RGBColor[
              0.448613684673906, 0.5615797420648319, 0.9501954501081423], 
             UndirectedEdge[25, 43] -> 
             RGBColor[
              0.8249166136393391, 0.5262434923274859, 0.4557455645496493], 
             UndirectedEdge[77, 270] -> 
             RGBColor[
              0.5033402301005603, 0.585793525778129, 0.9584139386489746], 
             UndirectedEdge[225, 255] -> 
             RGBColor[
              0.6931555524860684, 0.7585352372582541, 0.971443113107203], 
             UndirectedEdge[2, 275] -> 
             RGBColor[
              0.6616759691165721, 0.7311062666608426, 0.9697194873137975], 
             UndirectedEdge[235, 253] -> 
             RGBColor[
              0.24195125073111923`, 0.37163648348669887`, 0.9370901378431136],
              UndirectedEdge[73, 95] -> 
             RGBColor[
              0.588527877892808, 0.6600644976777462, 0.9583780825961556], 
             UndirectedEdge[49, 175] -> 
             RGBColor[
              0.7316944884597767, 0.7903054274798996, 0.9739216379095318], 
             UndirectedEdge[153, 219] -> 
             RGBColor[
              0.3303370942025257, 0.453626137375006, 0.942523030069814], 
             UndirectedEdge[54, 167] -> 
             RGBColor[
              0.5829981957625874, 0.6714730087960803, 0.9609098715792396], 
             UndirectedEdge[56, 246] -> 
             RGBColor[
              0.48210622992322427`, 0.5870327557152177, 0.9533122496378099], 
             UndirectedEdge[192, 225] -> 
             RGBColor[
              0.7840656333161877, 0.8318155676525939, 0.9789585381534764], 
             UndirectedEdge[84, 252] -> 
             RGBColor[
              0.6867656441477172, 0.7536371852958949, 0.9706067938510217], 
             UndirectedEdge[119, 164] -> 
             RGBColor[
              0.20441526824564293`, 0.3321837859757161, 0.9349525191700756], 
             UndirectedEdge[93, 168] -> 
             RGBColor[
              0.4976260633000871, 0.5980414891749628, 0.9552029948590672], 
             UndirectedEdge[111, 250] -> 
             RGBColor[
              0.4305045847165491, 0.5317036918179742, 0.9507138418962268], 
             UndirectedEdge[54, 286] -> 
             RGBColor[
              0.34940470492249986`, 0.46959404342102784`, 0.9438459856483563],
              UndirectedEdge[74, 257] -> 
             RGBColor[
              0.5838560751491846, 0.6510499819909583, 0.9345882457273037], 
             UndirectedEdge[220, 236] -> 
             RGBColor[
              0.5898976229841373, 0.6618352736503889, 0.9603537791570746], 
             UndirectedEdge[130, 228] -> 
             RGBColor[
              0.3530087739043072, 0.47935731350689226`, 0.9437445143541399], 
             UndirectedEdge[1, 142] -> 
             RGBColor[
              0.5132580484303313, 0.6090123932300028, 0.9569575011374709], 
             UndirectedEdge[101, 114] -> 
             RGBColor[
              0.5133304033214252, 0.6111621130683773, 0.9565111348536565], 
             UndirectedEdge[199, 266] -> 
             RGBColor[
              0.6420770660811006, 0.7159632970862797, 0.9676270091195092], 
             UndirectedEdge[93, 277] -> 
             RGBColor[
              0.44798289670749736`, 0.5458633735275946, 0.9523758899621029], 
             UndirectedEdge[19, 112] -> 
             RGBColor[
              0.5787212422931444, 0.65815790631403, 0.9637469036960877], 
             UndirectedEdge[77, 203] -> 
             RGBColor[
              0.8871285039731378, 0.9124863404760193, 0.9769662842433843], 
             UndirectedEdge[26, 60] -> 
             RGBColor[
              0.3861894456766174, 0.5056390973002607, 0.9461791325862702], 
             UndirectedEdge[186, 263] -> 
             RGBColor[
              0.30212784987684904`, 0.43448386547230594`, 0.9405318267632701],
              UndirectedEdge[167, 283] -> 
             RGBColor[
              0.5725190557333388, 0.6627633880060584, 0.960140779009331], 
             UndirectedEdge[170, 200] -> 
             RGBColor[
              0.5961322107920854, 0.6754887732838264, 0.9648852543984766], 
             UndirectedEdge[17, 292] -> 
             RGBColor[
              0.31284667939834643`, 0.4411399208016751, 0.9413110471082295], 
             UndirectedEdge[106, 215] -> 
             RGBColor[
              0.8064651232424845, 0.5118290477929421, 0.4539064924258722], 
             UndirectedEdge[123, 229] -> 
             RGBColor[
              0.4032286854463287, 0.523638266871362, 0.9469253739067849], 
             UndirectedEdge[105, 149] -> 
             RGBColor[
              0.2753127097225073, 0.40326726274140245`, 0.9391157675395511], 
             UndirectedEdge[68, 274] -> 
             RGBColor[
              0.6782790070060736, 0.746951889136791, 0.9697032749810648], 
             UndirectedEdge[149, 171] -> 
             RGBColor[
              0.6934098334859774, 0.484491708271014, 0.4550039070150732], 
             UndirectedEdge[29, 172] -> 
             RGBColor[
              0.6032903531766728, 0.6759118822308823, 0.9611164753287706], 
             UndirectedEdge[76, 209] -> 
             RGBColor[
              0.7991115952635667, 0.4951091880884952, 0.4518099600439798], 
             UndirectedEdge[247, 267] -> 
             RGBColor[
              0.41178226953495217`, 0.5294957844717227, 0.9478989927910388], 
             UndirectedEdge[164, 210] -> 
             RGBColor[
              0.4685528951101209, 0.5601713794966499, 0.9547049758775509], 
             UndirectedEdge[258, 260] -> 
             RGBColor[
              0.22566460357436768`, 0.3545181846918812, 0.9361626373814719], 
             UndirectedEdge[62, 137] -> 
             RGBColor[
              0.6169696709145556, 0.6800901733073355, 0.8168258124431437], 
             UndirectedEdge[175, 280] -> 
             RGBColor[
              0.5167799767928549, 0.5999383188660103, 0.9591764692413897], 
             UndirectedEdge[72, 194] -> 
             RGBColor[
              0.42830301167148777`, 0.5370250681994364, 0.9497496787258953], 
             UndirectedEdge[3, 257] -> 
             RGBColor[
              0.6194366079102478, 0.6884473778589095, 0.936614504431365], 
             UndirectedEdge[154, 171] -> 
             RGBColor[
              0.6894351983504161, 0.48104907908756145`, 0.45475064677886706`],
              UndirectedEdge[168, 277] -> 
             RGBColor[
              0.25620464677987737`, 0.3866177064514494, 0.9379018476620805], 
             UndirectedEdge[146, 243] -> 
             RGBColor[
              0.4299320766093394, 0.5361822749624946, 0.9500750275404182], 
             UndirectedEdge[98, 122] -> 
             RGBColor[
              0.3517734245591407, 0.4695249036789889, 0.9442137999172366], 
             UndirectedEdge[142, 210] -> 
             RGBColor[
              0.73673207067181, 0.7942599600707203, 0.9743942257180787], 
             UndirectedEdge[3, 38] -> 
             RGBColor[
              0.6304808301174869, 0.6930394610014923, 0.6924116901245345], 
             UndirectedEdge[21, 205] -> 
             RGBColor[
              0.4664687368727608, 0.5746131754478601, 0.9520050484589007], 
             UndirectedEdge[153, 221] -> 
             RGBColor[
              0.5814695485654398, 0.6547185132480902, 0.9648620697595163], 
             UndirectedEdge[55, 159] -> 
             RGBColor[
              0.20556939089484255`, 0.33339684205562725`, 0.9350182447475761],
              UndirectedEdge[149, 298] -> 
             RGBColor[
              0.28404955561426737`, 0.4124502417216663, 0.9396133179880816], 
             UndirectedEdge[22, 247] -> 
             RGBColor[
              0.3832000318851301, 0.5062914363324647, 0.9456488943430584], 
             UndirectedEdge[105, 298] -> 
             RGBColor[
              0.21347212694523698`, 0.34170311870699743`, 0.9354682938745957],
              UndirectedEdge[169, 219] -> 
             RGBColor[
              0.5068920950636485, 0.609835244111409, 0.9545229346978785], 
             UndirectedEdge[53, 225] -> 
             RGBColor[
              0.8678513188289372, 0.8974651007104384, 0.987257627601564], 
             UndirectedEdge[47, 90] -> 
             RGBColor[
              0.2629553563140984, 0.3923176536558131, 0.9383373858151614], 
             UndirectedEdge[100, 137] -> 
             RGBColor[
              0.37154192371204886`, 0.4883989800189291, 0.9455128887577244], 
             UndirectedEdge[15, 175] -> 
             RGBColor[
              0.5794044725861347, 0.6634288517088648, 0.9628282196251389], 
             UndirectedEdge[49, 253] -> 
             RGBColor[
              0.4717608830971882, 0.5776593083605905, 0.9526835615997158], 
             UndirectedEdge[166, 291] -> 
             RGBColor[
              0.5517528131905729, 0.6403972655008167, 0.9605865163571683], 
             UndirectedEdge[161, 230] -> 
             RGBColor[
              0.7672824110394284, 0.8182063741030026, 0.9774179006763594], 
             UndirectedEdge[263, 269] -> 
             RGBColor[
              0.4780455691292682, 0.5833207856765055, 0.9531113200268372], 
             UndirectedEdge[122, 160] -> 
             RGBColor[
              0.31338533457390155`, 0.43722282672510593`, 0.941505876644291], 
             UndirectedEdge[196, 289] -> 
             RGBColor[
              0.5035884700443202, 0.6078748322408467, 0.9540634755486883], 
             UndirectedEdge[30, 158] -> 
             RGBColor[
              0.4491346594760001, 0.5632034357757332, 0.9499046943129238], 
             UndirectedEdge[114, 187] -> 
             RGBColor[
              0.4721854865800526, 0.5689202607520745, 0.9541312290151449], 
             UndirectedEdge[49, 159] -> 
             RGBColor[
              0.40885283909510817`, 0.5115389655140439, 0.9491010415579085], 
             UndirectedEdge[33, 94] -> 
             RGBColor[
              0.24335511693630282`, 0.3731120358786052, 0.937170085946665], 
             UndirectedEdge[193, 220] -> 
             RGBColor[
              0.5963616832230529, 0.6686294108065798, 0.9607218978249608], 
             UndirectedEdge[60, 127] -> 
             RGBColor[
              0.38338131988324964`, 0.5026875790459725, 0.9460192139765877], 
             UndirectedEdge[282, 297] -> 
             RGBColor[
              0.6641908315283714, 0.7366110361195126, 0.9678334476507525], 
             UndirectedEdge[97, 235] -> 
             RGBColor[
              0.3668752499588621, 0.47743186880193444`, 0.9457989423902105], 
             UndirectedEdge[50, 187] -> 
             RGBColor[
              0.6239846598574073, 0.21167283986851054`, 0.4217540553359612], 
             UndirectedEdge[271, 274] -> 
             RGBColor[
              0.47638042220450894`, 0.584866478891082, 0.9521756560824789], 
             UndirectedEdge[137, 170] -> 
             RGBColor[
              0.5628510747945056, 0.6405081892044713, 0.962989942938443], 
             UndirectedEdge[84, 253] -> 
             RGBColor[
              0.41349733961941426`, 0.5303583390226112, 0.9480968420307534], 
             UndirectedEdge[33, 185] -> 
             RGBColor[
              0.2223111271343708, 0.3509934683307576, 0.935971661859238], 
             UndirectedEdge[3, 144] -> 
             RGBColor[
              0.5247624590910132, 0.6141699505382607, 0.9587104629787485], 
             UndirectedEdge[11, 43] -> 
             RGBColor[
              0.49215622229241035`, 0.5804664693836239, 0.956763704285762], 
             UndirectedEdge[29, 272] -> 
             RGBColor[
              0.6901135466791206, 0.7551553512453086, 0.9665007903045295], 
             UndirectedEdge[70, 251] -> 
             RGBColor[
              0.4767295308109211, 0.5715304101426637, 0.9547329039901771], 
             UndirectedEdge[99, 123] -> 
             RGBColor[
              0.3034260786926455, 0.432281772772134, 0.9407363501654235], 
             UndirectedEdge[133, 239] -> 
             RGBColor[
              0.5512915122929932, 0.6362506906505414, 0.961136008586108], 
             UndirectedEdge[259, 260] -> 
             RGBColor[
              0.3513273231123633, 0.47406323877623757`, 0.9437778903011103], 
             UndirectedEdge[125, 192] -> 
             RGBColor[
              0.8341468508832184, 0.8690592207188442, 0.8778824960535118], 
             UndirectedEdge[213, 264] -> 
             RGBColor[
              0.6379175770159172, 0.7125356870929733, 0.9672813480240345], 
             UndirectedEdge[134, 204] -> 
             RGBColor[
              0.5660842485123554, 0.6567037821350895, 0.9599364990367691], 
             UndirectedEdge[94, 142] -> 
             RGBColor[
              0.4862196276088121, 0.5805932986116908, 0.9554177030714446], 
             UndirectedEdge[134, 175] -> 
             RGBColor[
              0.7677272417464234, 0.8185128944480469, 0.9774731133455865], 
             UndirectedEdge[8, 267] -> 
             RGBColor[
              0.7204607421374272, 0.7804316289969392, 0.9739048138770201], 
             UndirectedEdge[195, 225] -> 
             RGBColor[
              0.9102674240924344, 0.9312865516930453, 0.9913033135869005], 
             UndirectedEdge[51, 281] -> 
             RGBColor[
              0.4684611441225414, 0.578516506963604, 0.9515303231710519], 
             UndirectedEdge[49, 243] -> 
             RGBColor[
              0.6281470028163132, 0.7089970604431062, 0.9638691795214391], 
             UndirectedEdge[212, 243] -> 
             RGBColor[
              0.6624899861759723, 0.7358844663015633, 0.9672522344829695], 
             UndirectedEdge[22, 285] -> 
             RGBColor[
              0.7248387178443931, 0.7798915606821565, 0.8196962139159601], 
             UndirectedEdge[20, 33] -> 
             RGBColor[
              0.2415580196669755, 0.37122317270599425`, 0.9370677439157439], 
             UndirectedEdge[9, 174] -> 
             RGBColor[
              0.3061808185743587, 0.4328384264297656, 0.9409788617164461], 
             UndirectedEdge[180, 250] -> 
             RGBColor[
              0.44846583754244407`, 0.5505821073471934, 0.951736708673369], 
             UndirectedEdge[92, 221] -> 
             RGBColor[
              0.8601270438164854, 0.44770989341399064`, 0.4458513109035782], 
             UndirectedEdge[71, 232] -> 
             RGBColor[
              0.6638601980951103, 0.73272493382489, 0.9693363641938153], 
             UndirectedEdge[25, 148] -> 
             RGBColor[
              0.835908799836823, 0.5348306717286696, 0.45684116294199417`], 
             UndirectedEdge[76, 218] -> 
             RGBColor[
              0.8392772147568468, 0.8746235074616358, 0.9499058100588113], 
             UndirectedEdge[20, 200] -> 
             RGBColor[
              0.27224269204868534`, 0.4034747088997683, 0.9388151906139774], 
             UndirectedEdge[68, 255] -> 
             RGBColor[
              0.6590141024745819, 0.7313117717640673, 0.9681866711266753], 
             UndirectedEdge[30, 123] -> 
             RGBColor[
              0.40684307864541114`, 0.5265725940969352, 0.9472099121793752], 
             UndirectedEdge[113, 290] -> 
             RGBColor[
              0.40655505179895757`, 0.5265387391241293, 0.9471319830793874], 
             UndirectedEdge[230, 269] -> 
             RGBColor[
              0.6738240623241892, 0.7451157458309874, 0.9681241433547498], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.48406484602837513`, 0.5920246747354636, 0.9525265043487618], 
             UndirectedEdge[71, 296] -> 
             RGBColor[
              0.5811094761826094, 0.6533819175104818, 0.9643443427232955], 
             UndirectedEdge[37, 237] -> 
             RGBColor[
              0.45455635895769153`, 0.5609230726737309, 0.9515811943774544], 
             UndirectedEdge[8, 217] -> 
             RGBColor[
              0.611694275221674, 0.6864866173221458, 0.9665833232291126], 
             UndirectedEdge[39, 100] -> 
             RGBColor[
              0.7382683487753046, 0.7936283553899464, 0.9428586542324894], 
             UndirectedEdge[35, 216] -> 
             RGBColor[
              0.618591211565294, 0.6969102991235767, 0.9655369899978222], 
             UndirectedEdge[48, 253] -> 
             RGBColor[
              0.24437808823832796`, 0.37418724357716027`, 0.9372283426489648],
              UndirectedEdge[72, 247] -> 
             RGBColor[
              0.4540177000415867, 0.5637844096414701, 0.9512239205940007], 
             UndirectedEdge[24, 254] -> 
             RGBColor[
              0.6437137871662015, 0.7135682699225612, 0.94314209253083], 
             UndirectedEdge[247, 273] -> 
             RGBColor[
              0.5802327618192172, 0.6633218612227048, 0.9632605200652283], 
             UndirectedEdge[80, 152] -> 
             RGBColor[
              0.43625646491919434`, 0.5501131237792736, 0.9496189930044809], 
             UndirectedEdge[121, 125] -> 
             RGBColor[
              0.6918610915181141, 0.7524057172154064, 0.8667823804407402], 
             UndirectedEdge[8, 177] -> 
             RGBColor[
              0.6298045686813942, 0.7035008615070548, 0.9676886698608409], 
             UndirectedEdge[38, 253] -> 
             RGBColor[
              0.6488350696598889, 0.7123309304865575, 0.6934569369138103], 
             UndirectedEdge[134, 292] -> 
             RGBColor[
              0.5367842552895774, 0.6313256006659982, 0.9580695293775805], 
             UndirectedEdge[19, 177] -> 
             RGBColor[
              0.30446352531157095`, 0.4353200250777006, 0.9407241116128229], 
             UndirectedEdge[219, 221] -> 
             RGBColor[
              0.6778737531852641, 0.7451359730968445, 0.9707515957915166], 
             UndirectedEdge[37, 185] -> 
             RGBColor[
              0.24115630574691554`, 0.37080094590587764`, 0.937044866902279], 
             UndirectedEdge[15, 280] -> 
             RGBColor[
              0.2713417371915744, 0.4001959653628592, 0.9388492605606693], 
             UndirectedEdge[140, 171] -> 
             RGBColor[
              0.6560907505496987, 0.4475564721944074, 0.4527948111433321], 
             UndirectedEdge[211, 221] -> 
             RGBColor[
              0.8791832830570577, 0.906500901387967, 0.9883384804658061], 
             UndirectedEdge[47, 273] -> 
             RGBColor[
              0.5863277688848407, 0.6686010499989853, 0.9636488885258467], 
             UndirectedEdge[58, 171] -> 
             RGBColor[
              0.6705962962777449, 0.46280272045930276`, 0.45362088051351246`],
              UndirectedEdge[75, 150] -> 
             RGBColor[
              0.6351663902931477, 0.7048208287986737, 0.9365958128624853], 
             UndirectedEdge[9, 167] -> 
             RGBColor[
              0.5380661757231376, 0.6329220349933216, 0.9579454719605667], 
             UndirectedEdge[135, 260] -> 
             RGBColor[
              0.24686682278702504`, 0.3768030613827251, 0.9373700723997602], 
             UndirectedEdge[184, 202] -> 
             RGBColor[
              0.3011276907213823, 0.4271146065014279, 0.9407062031440996], 
             UndirectedEdge[166, 262] -> 
             RGBColor[
              0.635578489377165, 0.706302953602828, 0.9426317346589989], 
             UndirectedEdge[173, 276] -> 
             RGBColor[
              0.7272479241691607, 0.784894915222413, 0.9477157592127725], 
             UndirectedEdge[67, 86] -> 
             RGBColor[
              0.5902280741119841, 0.6726836591582653, 0.9635731565572199], 
             UndirectedEdge[25, 272] -> 
             RGBColor[
              0.7121262944525645, 0.4357857761164968, 0.4459990554582075], 
             UndirectedEdge[7, 174] -> 
             RGBColor[
              0.36834764312879065`, 0.4853813909568823, 0.9453000482797076], 
             UndirectedEdge[88, 113] -> 
             RGBColor[
              0.379532809233498, 0.502786250097076, 0.9454228616638705], 
             UndirectedEdge[147, 206] -> 
             RGBColor[
              0.5799065148755522, 0.6639077913191793, 0.9628399095912222], 
             UndirectedEdge[189, 211] -> 
             RGBColor[
              0.5135969625945878, 0.5960197270362944, 0.9590820132249139], 
             UndirectedEdge[104, 209] -> 
             RGBColor[
              0.8038680529382952, 0.4988249689744104, 0.4522840392933726], 
             UndirectedEdge[151, 167] -> 
             RGBColor[
              0.4896990137396462, 0.58839248634347, 0.9549600886346203], 
             UndirectedEdge[215, 274] -> 
             RGBColor[
              0.7436706517168206, 0.4616598915323533, 0.44840912663144383`], 
             UndirectedEdge[41, 261] -> 
             RGBColor[
              0.3889782188032822, 0.5113351153388332, 0.9460063260355798], 
             UndirectedEdge[157, 218] -> 
             RGBColor[
              0.625386243818776, 0.6941597541130833, 0.9338520860603097], 
             UndirectedEdge[187, 205] -> 
             RGBColor[
              0.41603522651879277`, 0.5243260102026165, 0.9490332816489753], 
             UndirectedEdge[62, 82] -> 
             RGBColor[
              0.9667831411157163, 0.9727058946346243, 0.8428007988943367], 
             UndirectedEdge[42, 144] -> 
             RGBColor[
              0.6853683075519287, 0.75332413948545, 0.9698286072231043], 
             UndirectedEdge[33, 150] -> 
             RGBColor[
              0.607893842281972, 0.6761556516595113, 0.935042681599368], 
             UndirectedEdge[34, 46] -> 
             RGBColor[
              0.4772786975825074, 0.5836251757926092, 0.9527908441818196], 
             UndirectedEdge[220, 266] -> 
             RGBColor[
              0.6749937096536984, 0.7420593083589933, 0.9655373676592165], 
             UndirectedEdge[128, 279] -> 
             RGBColor[
              0.26742286454753905`, 0.39840876460134966`, 0.9385407085680829],
              UndirectedEdge[147, 270] -> 
             RGBColor[
              0.2589711990425127, 0.38698235486076693`, 0.9381525167579419], 
             UndirectedEdge[30, 90] -> 
             RGBColor[
              0.3320436044678779, 0.4519222568071115, 0.9428048809671115], 
             UndirectedEdge[36, 222] -> 
             RGBColor[
              0.5766441394406108, 0.6465427326888802, 0.9517907783117879], 
             UndirectedEdge[127, 170] -> 
             RGBColor[
              0.5824015974651613, 0.6610570281060624, 0.9641033162821304], 
             UndirectedEdge[1, 295] -> 
             RGBColor[
              0.3254117354588836, 0.45515874687516256`, 0.9419968714718571], 
             UndirectedEdge[96, 140] -> 
             RGBColor[
              0.27520013002592386`, 0.40586927026963104`, 0.9390097514681839],
              UndirectedEdge[206, 272] -> 
             RGBColor[
              0.6311198139602049, 0.7082661769310494, 0.9661031757227541], 
             UndirectedEdge[129, 265] -> 
             RGBColor[
              0.8155021070705565, 0.8552503744939205, 0.9103302287774433], 
             UndirectedEdge[39, 60] -> 
             RGBColor[
              0.7305572222758495, 0.7873681155153989, 0.9422516061076652], 
             UndirectedEdge[71, 240] -> 
             RGBColor[
              0.7208053128143969, 0.7806393136045808, 0.9733540614699988], 
             UndirectedEdge[30, 144] -> 
             RGBColor[
              0.621636834293313, 0.701584058423954, 0.9648114321921073], 
             UndirectedEdge[26, 59] -> 
             RGBColor[
              0.23970883224565503`, 0.3692795594809322, 0.9369624354277273], 
             UndirectedEdge[133, 241] -> 
             RGBColor[
              0.4267868529324037, 0.537926146172256, 0.9494362565379237], 
             UndirectedEdge[236, 266] -> 
             RGBColor[
              0.3233434408852558, 0.4479674881169892, 0.942062794918126], 
             UndirectedEdge[28, 216] -> 
             RGBColor[
              0.6936432292238985, 0.7547105784704649, 0.8948763494230656], 
             UndirectedEdge[173, 230] -> 
             RGBColor[
              0.8352921385553514, 0.8716558359116496, 0.9568738145697977], 
             UndirectedEdge[39, 266] -> 
             RGBColor[
              0.6904178178475102, 0.7535625829952788, 0.9394283757387902], 
             UndirectedEdge[86, 141] -> 
             RGBColor[
              0.6749309210659978, 0.7441969446369509, 0.9694820776634141], 
             UndirectedEdge[25, 206] -> 
             RGBColor[
              0.8404200360222602, 0.5383741550050467, 0.4572856867994476], 
             UndirectedEdge[141, 165] -> 
             RGBColor[
              0.5230384567400729, 0.6236652076523741, 0.9555946497490267], 
             UndirectedEdge[152, 241] -> 
             RGBColor[
              0.4573650294748815, 0.5672500074155769, 0.9512807365295244], 
             UndirectedEdge[110, 141] -> 
             RGBColor[
              0.6172128520249109, 0.699039662311885, 0.9637471892184956], 
             UndirectedEdge[97, 134] -> 
             RGBColor[
              0.6327176356115779, 0.7116621606439733, 0.9649438415828674], 
             UndirectedEdge[103, 119] -> 
             RGBColor[
              0.23171414172100668`, 0.36087663284687077`, 0.9365071496294333],
              UndirectedEdge[3, 17] -> 
             RGBColor[
              0.2655018209502019, 0.3963896259793493, 0.9384313079771438], 
             UndirectedEdge[203, 270] -> 
             RGBColor[
              0.5654780685212469, 0.6349906870449399, 0.952210682662463], 
             UndirectedEdge[51, 141] -> 
             RGBColor[
              0.5180414462466227, 0.619608409421034, 0.9552012667783298], 
             UndirectedEdge[184, 275] -> 
             RGBColor[
              0.6552177522593547, 0.7255124838185383, 0.9693079754464327], 
             UndirectedEdge[58, 109] -> 
             RGBColor[
              0.6358894888616777, 0.6996135081172029, 0.7816428136081721], 
             UndirectedEdge[179, 281] -> 
             RGBColor[
              0.43485036805327115`, 0.5510672654179141, 0.9489292588226401], 
             UndirectedEdge[31, 154] -> 
             RGBColor[
              0.6014179694386583, 0.6809818165586132, 0.9649278866066132], 
             UndirectedEdge[122, 296] -> 
             RGBColor[
              0.22056413492148685`, 0.34915726874931274`, 0.9358721732371575],
              UndirectedEdge[96, 290] -> 
             RGBColor[
              0.3377513992029836, 0.4669650189358714, 0.9427421983887467], 
             UndirectedEdge[122, 240] -> 
             RGBColor[
              0.36025997155327427`, 0.4764146648434119, 0.9448818919838609], 
             UndirectedEdge[97, 144] -> 
             RGBColor[
              0.668040697861158, 0.7392568053385615, 0.9684645143151211], 
             UndirectedEdge[61, 247] -> 
             RGBColor[
              0.6427739058526877, 0.712205410643882, 0.9350730601386235], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.5493308447049573, 0.6417220800165743, 0.9590682288903576], 
             UndirectedEdge[45, 287] -> 
             RGBColor[
              0.7112486156539357, 0.4548827294042745, 0.44854565291056714`], 
             UndirectedEdge[278, 290] -> 
             RGBColor[
              0.4551591400145024, 0.5659977275267304, 0.9509582749463567], 
             UndirectedEdge[109, 110] -> 
             RGBColor[
              0.8536135435486446, 0.8829599562900656, 0.7980962735487345], 
             UndirectedEdge[56, 160] -> 
             RGBColor[
              0.3697391700538193, 0.4946712182947549, 0.9447804308616868], 
             UndirectedEdge[146, 292] -> 
             RGBColor[
              0.3025365757959569, 0.4303033482172395, 0.9407239019605049], 
             UndirectedEdge[131, 139] -> 
             RGBColor[
              0.6329582151421961, 0.26901776505795566`, 0.42876857747382346`],
              UndirectedEdge[47, 74] -> 
             RGBColor[
              0.2604726166648913, 0.38970813686971084`, 0.9381959974650231], 
             UndirectedEdge[46, 221] -> 
             RGBColor[
              0.6379402186578726, 0.710547552607023, 0.9682070662832692], 
             UndirectedEdge[48, 74] -> 
             RGBColor[
              0.19044331593486252`, 0.3174983782241438, 0.9341568371556278], 
             UndirectedEdge[90, 134] -> 
             RGBColor[
              0.4563416037295768, 0.5517874267618235, 0.9533049198925716], 
             UndirectedEdge[1, 37] -> 
             RGBColor[
              0.2892387163703667, 0.42133860807203716`, 0.9397830890557324], 
             UndirectedEdge[33, 295] -> 
             RGBColor[
              0.299154382946494, 0.4275606045723368, 0.9405015540905486], 
             UndirectedEdge[28, 35] -> 
             RGBColor[
              0.9132752812007847, 0.9316407730038028, 0.9137710366642793], 
             UndirectedEdge[21, 169] -> 
             RGBColor[
              0.4626129457925524, 0.5714828705475382, 0.9517015064608385], 
             UndirectedEdge[100, 228] -> 
             RGBColor[
              0.40199323669155357`, 0.5204052406851448, 0.9472470459832267], 
             UndirectedEdge[190, 250] -> 
             RGBColor[
              0.806662949049093, 0.7963625757810883, 0.62466125503594], 
             UndirectedEdge[81, 180] -> 
             RGBColor[
              0.237877225969383, 0.367354425154025, 0.9368581281599122], 
             UndirectedEdge[127, 141] -> 
             RGBColor[
              0.3997861856320259, 0.5160057880916091, 0.9473106651013347], 
             UndirectedEdge[143, 185] -> 
             RGBColor[
              0.2103242886297437, 0.3383945410529373, 0.9352890291393379], 
             UndirectedEdge[283, 295] -> 
             RGBColor[
              0.40002217105122573`, 0.5209008316908221, 0.9467100369070351], 
             UndirectedEdge[26, 100] -> 
             RGBColor[
              0.39390057217607233`, 0.5118993371748083, 0.9467861807110943], 
             UndirectedEdge[242, 294] -> 
             RGBColor[
              0.32596428523066145`, 0.45250173166358687`, 0.9421468893524212],
              UndirectedEdge[39, 228] -> 
             RGBColor[
              0.6361209960564526, 0.7057105284601625, 0.9359987598080498], 
             UndirectedEdge[39, 82] -> 
             RGBColor[
              0.9554831532781085, 0.9663199891212355, 0.9602395890337405], 
             UndirectedEdge[109, 258] -> 
             RGBColor[
              0.5936603241227123, 0.6552279784928616, 0.7792379251487389], 
             UndirectedEdge[118, 199] -> 
             RGBColor[
              0.7398328157698872, 0.7965443742756056, 0.9749860092429135], 
             UndirectedEdge[57, 115] -> 
             RGBColor[
              0.5324792225339057, 0.6313296466254599, 0.9563378614149818], 
             UndirectedEdge[96, 222] -> 
             RGBColor[
              0.6334702758780337, 0.7055567116131474, 0.955053081851704], 
             UndirectedEdge[6, 108] -> 
             RGBColor[
              0.9812902733619535, 0.9828638657710371, 0.7657628157492176], 
             UndirectedEdge[1, 9] -> 
             RGBColor[
              0.3368084458523525, 0.4650300046026655, 0.9427230597804136], 
             UndirectedEdge[180, 190] -> 
             RGBColor[
              0.5969347147527393, 0.6140392046568094, 0.6098316717355776], 
             UndirectedEdge[144, 253] -> 
             RGBColor[
              0.5431166986334152, 0.633461420023326, 0.9597557097680243], 
             UndirectedEdge[53, 192] -> 
             RGBColor[
              0.7603883115084342, 0.8129359139468704, 0.9767001740624582], 
             UndirectedEdge[85, 121] -> 
             RGBColor[
              0.593153572396181, 0.676596559105201, 0.9631652619720379], 
             UndirectedEdge[36, 278] -> 
             RGBColor[
              0.37704897484324223`, 0.48854859267960227`, 0.9463397719162481],
              UndirectedEdge[122, 207] -> 
             RGBColor[
              0.23109400917188477`, 0.36022483421906915`, 0.9364718339981648],
              UndirectedEdge[226, 228] -> 
             RGBColor[
              0.6726283744212413, 0.44597770075992105`, 0.4495122863182095], 
             UndirectedEdge[7, 143] -> 
             RGBColor[
              0.36073107938976773`, 0.4773758995491362, 0.9448662962424665], 
             UndirectedEdge[133, 164] -> 
             RGBColor[
              0.23577557941103827`, 0.36514546136911663`, 0.936738442497522], 
             UndirectedEdge[7, 131] -> 
             RGBColor[
              0.7192000824475907, 0.34692629235685657`, 0.4343544728176246], 
             UndirectedEdge[111, 280] -> 
             RGBColor[
              0.20576616949629753`, 0.33360366884224035`, 0.935029450997821], 
             UndirectedEdge[135, 224] -> 
             RGBColor[
              0.3018458825293665, 0.4290837227078142, 0.9407026434248925], 
             UndirectedEdge[91, 102] -> 
             RGBColor[
              0.7774853015640018, 0.8263705548774538, 0.9783834525979374], 
             UndirectedEdge[200, 282] -> 
             RGBColor[
              0.4419727963175749, 0.553539393853177, 0.9503327635675047], 
             UndirectedEdge[106, 194] -> 
             RGBColor[
              0.49095778678922575`, 0.5866757003314944, 0.9555130245934668], 
             UndirectedEdge[38, 259] -> 
             RGBColor[
              0.71850563711122, 0.7730246826203425, 0.697883519605079], 
             UndirectedEdge[36, 69] -> 
             RGBColor[
              0.36374742501759105`, 0.47774979530314765`, 0.9452926251887903],
              UndirectedEdge[64, 153] -> 
             RGBColor[
              0.3971171015980166, 0.5085627755304547, 0.9475808111891227], 
             UndirectedEdge[159, 175] -> 
             RGBColor[
              0.5020010628227467, 0.5844047432461603, 0.958334831954236], 
             UndirectedEdge[94, 200] -> 
             RGBColor[
              0.27403978931801265`, 0.40536357207237916`, 0.9389175326448984],
              UndirectedEdge[88, 201] -> 
             RGBColor[
              0.6500672614587935, 0.7149580653299588, 0.8267335022166786], 
             UndirectedEdge[121, 232] -> 
             RGBColor[
              0.3916685699546195, 0.513665362285141, 0.9461777528319588], 
             UndirectedEdge[140, 289] -> 
             RGBColor[
              0.37925400133985765`, 0.49406070601738517`, 0.9461745625021082],
              UndirectedEdge[139, 244] -> 
             RGBColor[
              0.35301995143828724`, 0.4737962843992035, 0.9440152407606375], 
             UndirectedEdge[167, 174] -> 
             RGBColor[
              0.4672809928630029, 0.564829725017499, 0.9536834155101853], 
             UndirectedEdge[185, 282] -> 
             RGBColor[
              0.3894630658248035, 0.49834833779606924`, 0.9473424120971263], 
             UndirectedEdge[236, 249] -> 
             RGBColor[
              0.29025863930455575`, 0.419311095878265, 0.9399546606171452], 
             UndirectedEdge[137, 299] -> 
             RGBColor[
              0.6076049311110653, 0.6751475726091136, 0.9309887324543112], 
             UndirectedEdge[201, 218] -> 
             RGBColor[
              0.9846473410112434, 0.9861317242504148, 0.8207132353824123], 
             UndirectedEdge[36, 109] -> 
             RGBColor[
              0.598572274275408, 0.660390749538972, 0.7795176534433559], 
             UndirectedEdge[4, 52] -> 
             RGBColor[
              0.26531630465231293`, 0.39619463658785536`, 0.9384207430984259],
              UndirectedEdge[5, 191] -> 
             RGBColor[
              0.5008543733734092, 0.6035424225866477, 0.9544319956811633], 
             UndirectedEdge[55, 134] -> 
             RGBColor[
              0.4712955698185193, 0.5675049932575138, 0.9541565261389267], 
             UndirectedEdge[67, 69] -> 
             RGBColor[
              0.43840106322095107`, 0.5522050602207775, 0.9496908813769911], 
             UndirectedEdge[232, 256] -> 
             RGBColor[
              0.33235013399449, 0.4590182023023087, 0.9425177107881247], 
             UndirectedEdge[185, 237] -> 
             RGBColor[
              0.4138861222340853, 0.5181760752352771, 0.9492650845622684], 
             UndirectedEdge[28, 211] -> 
             RGBColor[
              0.9088438287126634, 0.9281072530783481, 0.913348360769958], 
             UndirectedEdge[85, 246] -> 
             RGBColor[
              0.7152285726946428, 0.7773666265900394, 0.9723156621279059], 
             UndirectedEdge[26, 127] -> 
             RGBColor[
              0.2808524291483715, 0.41252408848039956`, 0.9393055024048399], 
             UndirectedEdge[91, 162] -> 
             RGBColor[
              0.7681730399972989, 0.8189452102787713, 0.9774952407765511], 
             UndirectedEdge[112, 242] -> 
             RGBColor[
              0.5709274916503634, 0.6499661802361355, 0.9633030611268021], 
             UndirectedEdge[85, 122] -> 
             RGBColor[
              0.5047998592755494, 0.5914314818837809, 0.9578517038477565], 
             UndirectedEdge[63, 131] -> 
             RGBColor[
              0.6427130772725287, 0.27927074365091686`, 0.4293241024411206], 
             UndirectedEdge[140, 222] -> 
             RGBColor[
              0.5922030354348113, 0.662896118869768, 0.9526768344213337], 
             UndirectedEdge[121, 256] -> 
             RGBColor[
              0.33271267130534704`, 0.459332213899318, 0.9425408113449933], 
             UndirectedEdge[171, 198] -> 
             RGBColor[
              0.6458945663879714, 0.43683963616501753`, 0.45221415353922445`],
              UndirectedEdge[10, 117] -> 
             RGBColor[
              0.6662271191462967, 0.6686520921805924, 0.611169833743558], 
             UndirectedEdge[18, 290] -> 
             RGBColor[
              0.48621761291094573`, 0.5912123949923223, 0.9534033117036995], 
             UndirectedEdge[207, 240] -> 
             RGBColor[
              0.376030299700946, 0.4929902796231707, 0.9457799888417611], 
             UndirectedEdge[219, 264] -> 
             RGBColor[
              0.4159772793199013, 0.5347203445460902, 0.9477266822973669], 
             UndirectedEdge[78, 118] -> 
             RGBColor[
              0.5739493632018122, 0.6649969750282136, 0.9596025427984901], 
             UndirectedEdge[2, 208] -> 
             RGBColor[
              0.36415598183491016`, 0.489835341278735, 0.9444246750453974], 
             UndirectedEdge[34, 169] -> 
             RGBColor[
              0.5973630283511975, 0.6840052431700794, 0.961445752286131], 
             UndirectedEdge[35, 275] -> 
             RGBColor[
              0.8836147355451791, 0.9100344213134217, 0.9887611563601274], 
             UndirectedEdge[157, 284] -> 
             RGBColor[
              0.618860943628686, 0.6442609962930695, 0.621223887025977], 
             UndirectedEdge[30, 259] -> 
             RGBColor[
              0.45316620457346724`, 0.5666953575078109, 0.9501615808015791], 
             UndirectedEdge[62, 192] -> 
             RGBColor[
              0.8357993549055519, 0.8694959175403838, 0.8325669361964377], 
             UndirectedEdge[95, 245] -> 
             RGBColor[
              0.23762126042010318`, 0.3670853891325787, 0.9368435513005479], 
             UndirectedEdge[129, 230] -> 
             RGBColor[
              0.6740399351425049, 0.7452843873173498, 0.9681456595398334], 
             UndirectedEdge[35, 92] -> 
             RGBColor[
              0.8298660624811528, 0.42358060830965266`, 0.4429649914895173], 
             UndirectedEdge[186, 279] -> 
             RGBColor[
              0.2918604840930713, 0.4240942521782743, 0.9399323948489826], 
             UndirectedEdge[217, 233] -> 
             RGBColor[
              0.4351106130638175, 0.5466379290926839, 0.9499136518569247], 
             UndirectedEdge[28, 293] -> 
             RGBColor[
              0.7755098554583741, 0.8226495636599835, 0.9009133752291754], 
             UndirectedEdge[24, 233] -> 
             RGBColor[
              0.4492437800333138, 0.5602073862079506, 0.9507655795055308], 
             UndirectedEdge[41, 229] -> 
             RGBColor[
              0.43025004738072886`, 0.5470428124457991, 0.9486471511951926], 
             UndirectedEdge[197, 214] -> 
             RGBColor[
              0.3354094520196884, 0.4554697027804195, 0.9429956756130015], 
             UndirectedEdge[84, 144] -> 
             RGBColor[
              0.651638536790591, 0.7259407920725396, 0.9671732761125503], 
             UndirectedEdge[101, 205] -> 
             RGBColor[
              0.4571801432601653, 0.5665678625189193, 0.9514131874874869], 
             UndirectedEdge[7, 297] -> 
             RGBColor[
              0.6256206254869012, 0.7052980052870661, 0.9647970597438479], 
             UndirectedEdge[30, 47] -> 
             RGBColor[
              0.3929275246282545, 0.5145196406233554, 0.9463232253824432], 
             UndirectedEdge[140, 298] -> 
             RGBColor[
              0.22807093120984923`, 0.3570473876067564, 0.9362996741804699], 
             UndirectedEdge[159, 252] -> 
             RGBColor[
              0.5153357619884613, 0.5950374704001347, 0.9596067074646883], 
             UndirectedEdge[26, 195] -> 
             RGBColor[
              0.6063333812449587, 0.6808519778523082, 0.9662780282478707], 
             UndirectedEdge[43, 185] -> 
             RGBColor[
              0.48876811409464715`, 0.5769053528493078, 0.9565707565361562], 
             UndirectedEdge[36, 95] -> 
             RGBColor[
              0.21807689204548392`, 0.34654301878632704`, 0.9357305284349153],
              UndirectedEdge[6, 46] -> 
             RGBColor[
              0.6704603709959152, 0.7322705864093959, 0.7683506386215513], 
             UndirectedEdge[148, 183] -> 
             RGBColor[
              0.5293910353788962, 0.6151531609051794, 0.9595885862818883], 
             UndirectedEdge[222, 261] -> 
             RGBColor[
              0.6613582552579484, 0.72971187766143, 0.9568300792374203], 
             UndirectedEdge[64, 145] -> 
             RGBColor[
              0.37055357024128427`, 0.48064281984936474`, 0.9460680573755799],
              UndirectedEdge[8, 247] -> 
             RGBColor[
              0.620327734945703, 0.6952925044447122, 0.9670848143952376], 
             UndirectedEdge[122, 136] -> 
             RGBColor[
              0.3850735904709687, 0.49655947852158955`, 0.9468353109603428], 
             UndirectedEdge[139, 206] -> 
             RGBColor[
              0.5330672374709609, 0.6172199144134967, 0.9600793639982805], 
             UndirectedEdge[65, 80] -> 
             RGBColor[
              0.395310581822581, 0.5098921455969939, 0.9471840874622696], 
             UndirectedEdge[171, 245] -> 
             RGBColor[
              0.6587477321366445, 0.45034912830465007`, 0.4529461223140566], 
             UndirectedEdge[137, 232] -> 
             RGBColor[
              0.31512464532872736`, 0.4409131215555306, 0.9415367446914364], 
             UndirectedEdge[64, 221] -> 
             RGBColor[
              0.7446537605807548, 0.8000726112522932, 0.9758093769108254], 
             UndirectedEdge[140, 263] -> 
             RGBColor[
              0.27351364394012856`, 0.4044085207873705, 0.9389022900660982], 
             UndirectedEdge[200, 295] -> 
             RGBColor[
              0.32983905532820385`, 0.45981214076611077`, 0.942249000788782], 
             UndirectedEdge[136, 232] -> 
             RGBColor[
              0.47306476628074334`, 0.5814105441460002, 0.9521257685277555], 
             UndirectedEdge[45, 68] -> 
             RGBColor[
              0.8432266238810947, 0.5606694492620872, 0.46006372129585715`], 
             UndirectedEdge[224, 254] -> 
             RGBColor[
              0.6665375134213749, 0.7333370344509557, 0.9445964001855809], 
             UndirectedEdge[148, 272] -> 
             RGBColor[
              0.624352959682049, 0.7029509520164836, 0.965436389936574], 
             UndirectedEdge[167, 185] -> 
             RGBColor[
              0.44982620951754554`, 0.5464836410242393, 0.9526893914206995], 
             UndirectedEdge[59, 137] -> 
             RGBColor[
              0.21735018378163157`, 0.34577920232505305`, 0.9356891434743574],
              UndirectedEdge[55, 97] -> 
             RGBColor[
              0.39340143412466555`, 0.5053125702174094, 0.9473095693364801], 
             UndirectedEdge[156, 202] -> 
             RGBColor[
              0.6065037675679503, 0.6673604664604421, 0.6800069662121992], 
             UndirectedEdge[78, 176] -> 
             RGBColor[
              0.4787632672989916, 0.5866416027937368, 0.9524072787420719], 
             UndirectedEdge[131, 143] -> 
             RGBColor[
              0.625487701678531, 0.26116578174973293`, 0.428343142783702], 
             UndirectedEdge[230, 289] -> 
             RGBColor[
              0.6146132488922058, 0.6970555094329861, 0.9634561718583055], 
             UndirectedEdge[35, 126] -> 
             RGBColor[
              0.8845018937112581, 0.9107418171537862, 0.9888457742979835], 
             UndirectedEdge[147, 183] -> 
             RGBColor[
              0.2925039782178558, 0.42222743187505, 0.9400621589246763], 
             UndirectedEdge[66, 258] -> 
             RGBColor[
              0.23344608728249683`, 0.36269701744368793`, 0.9366057813669764],
              UndirectedEdge[60, 232] -> 
             RGBColor[
              0.440012184527629, 0.5545769692769826, 0.9495237482165542], 
             UndirectedEdge[39, 127] -> 
             RGBColor[
              0.6252202057476036, 0.6942531066955377, 0.935377975926235], 
             UndirectedEdge[113, 258] -> 
             RGBColor[
              0.3235329364750017, 0.44392683323089077`, 0.9422337517546618], 
             UndirectedEdge[45, 223] -> 
             RGBColor[
              0.7540644035033821, 0.49011326919961584`, 0.4517861977289316], 
             UndirectedEdge[40, 80] -> 
             RGBColor[
              0.48484175989175965`, 0.5921952643165809, 0.9527148050378433], 
             UndirectedEdge[18, 198] -> 
             RGBColor[
              0.40837206749129507`, 0.5140413922819971, 0.9487998783769753], 
             UndirectedEdge[13, 58] -> 
             RGBColor[
              0.6360856306449754, 0.700516369074039, 0.8381248805104928], 
             UndirectedEdge[16, 195] -> 
             RGBColor[
              0.9308753361929074, 0.9477187414150903, 0.993268914639944], 
             UndirectedEdge[17, 90] -> 
             RGBColor[
              0.23240402783834568`, 0.3616017468975003, 0.9365464376232207], 
             UndirectedEdge[8, 273] -> 
             RGBColor[
              0.8889112344216923, 0.9142577057479211, 0.9892663411512096], 
             UndirectedEdge[85, 256] -> 
             RGBColor[
              0.5338351364360516, 0.6219493991223686, 0.9595052199282038], 
             UndirectedEdge[149, 227] -> 
             RGBColor[
              0.30269052393588886`, 0.4320430813333457, 0.9406748935571565], 
             UndirectedEdge[182, 208] -> 
             RGBColor[
              0.4078154483254036, 0.5268812983861899, 0.9474192820727263], 
             UndirectedEdge[82, 100] -> 
             RGBColor[
              0.7213553939132096, 0.781014701346218, 0.9714878752089173], 
             UndirectedEdge[227, 264] -> 
             RGBColor[
              0.33235208464884636`, 0.4577344343895201, 0.9425649019770979], 
             UndirectedEdge[74, 259] -> 
             RGBColor[
              0.32071129661010406`, 0.4418838537541663, 0.942034352884159], 
             UndirectedEdge[96, 105] -> 
             RGBColor[
              0.26060132576131156`, 0.39052500136987206`, 0.9381783711623097],
              UndirectedEdge[60, 100] -> 
             RGBColor[
              0.4964294629109506, 0.6020628277403812, 0.9534998922828422], 
             UndirectedEdge[73, 87] -> 
             RGBColor[
              0.5829271578866424, 0.6541777858451079, 0.9580591298773273], 
             UndirectedEdge[68, 223] -> 
             RGBColor[
              0.6895024100471487, 0.756063553334081, 0.9705868223811382], 
             UndirectedEdge[162, 191] -> 
             RGBColor[
              0.6053746576785854, 0.6855653000037351, 0.9646476493215794], 
             UndirectedEdge[87, 149] -> 
             RGBColor[
              0.28401369243793695`, 0.4124125472494863, 0.9396112756332444], 
             UndirectedEdge[60, 256] -> 
             RGBColor[
              0.3810562858783566, 0.5002438208911596, 0.9458868067295887], 
             UndirectedEdge[145, 169] -> 
             RGBColor[
              0.383924359087092, 0.49149782858156466`, 0.9471206548523352], 
             UndirectedEdge[144, 235] -> 
             RGBColor[
              0.480092447902296, 0.5672189365366271, 0.9561665719249106], 
             UndirectedEdge[36, 88] -> 
             RGBColor[
              0.25390302020010114`, 0.3841985509845508, 0.9377707734333136], 
             UndirectedEdge[38, 123] -> 
             RGBColor[
              0.6721825111831639, 0.7329019192094669, 0.6949318509828752], 
             UndirectedEdge[183, 244] -> 
             RGBColor[
              0.35611060362437835`, 0.4770447558054519, 0.9441912488304252], 
             UndirectedEdge[2, 32] -> 
             RGBColor[
              0.5708842583143898, 0.6592979062227056, 0.9609040577261769], 
             UndirectedEdge[106, 151] -> 
             RGBColor[
              0.500963682721466, 0.5971925313667227, 0.9560828455644113], 
             UndirectedEdge[164, 277] -> 
             RGBColor[
              0.2000341678271802, 0.32757897165810157`, 0.9347030219825013], 
             UndirectedEdge[296, 299] -> 
             RGBColor[
              0.6010355965135994, 0.6682427854273065, 0.9306146185674452], 
             UndirectedEdge[75, 174] -> 
             RGBColor[
              0.267038458491004, 0.3980047294631796, 0.938518817211841], 
             UndirectedEdge[31, 66] -> 
             RGBColor[
              0.5713853415842735, 0.6517474033633168, 0.9631321948866363], 
             UndirectedEdge[2, 268] -> 
             RGBColor[
              0.6909607296142334, 0.7525572215311755, 0.900957100185902], 
             UndirectedEdge[46, 264] -> 
             RGBColor[
              0.37604374479250985`, 0.5001319240562686, 0.9451821527891195], 
             UndirectedEdge[71, 160] -> 
             RGBColor[
              0.6739306758350241, 0.741447475486275, 0.9699780461304288], 
             UndirectedEdge[50, 114] -> 
             RGBColor[
              0.7805643311959611, 0.34644333396620575`, 0.4332907640074687], 
             UndirectedEdge[126, 197] -> 
             RGBColor[
              0.569832488283725, 0.6422621614185098, 0.9642334519846911], 
             UndirectedEdge[265, 269] -> 
             RGBColor[
              0.8152862342522408, 0.8550817330075581, 0.9103087125923597], 
             UndirectedEdge[144, 257] -> 
             RGBColor[
              0.8759320446238268, 0.9033213003939031, 0.9567361853024376], 
             UndirectedEdge[86, 107] -> 
             RGBColor[
              0.5533321815962781, 0.6379141789377061, 0.9613251481283519], 
             UndirectedEdge[149, 245] -> 
             RGBColor[
              0.29389698636753836`, 0.42280051580652533`, 0.940174114601512], 
             UndirectedEdge[143, 283] -> 
             RGBColor[
              0.33301713484553697`, 0.4546742880347564, 0.9427404167279694], 
             UndirectedEdge[66, 154] -> 
             RGBColor[
              0.3039336051304693, 0.4344520850104172, 0.9407053192244416], 
             UndirectedEdge[57, 159] -> 
             RGBColor[
              0.3799289523393994, 0.4880572512395101, 0.9468240472408109], 
             UndirectedEdge[7, 167] -> 
             RGBColor[
              0.6002330002775695, 0.6854649995204383, 0.9622666585238282], 
             UndirectedEdge[57, 89] -> 
             RGBColor[
              0.7848296510886424, 0.8300896235410533, 0.8963726600207946], 
             UndirectedEdge[122, 256] -> 
             RGBColor[
              0.2443589581847153, 0.37416713667789797`, 0.937227253220712], 
             UndirectedEdge[39, 232] -> 
             RGBColor[
              0.681851070391983, 0.7461424969265479, 0.9388825101662013], 
             UndirectedEdge[72, 286] -> 
             RGBColor[
              0.4141827530357761, 0.5221837810971972, 0.9489455508856423], 
             UndirectedEdge[71, 299] -> 
             RGBColor[
              0.9563404838774483, 0.9669593848784731, 0.9587883519566902], 
             UndirectedEdge[90, 158] -> 
             RGBColor[
              0.31916249116184403`, 0.4410014488081908, 0.9419188547456419], 
             UndirectedEdge[52, 236] -> 
             RGBColor[
              0.24223652492104858`, 0.3719363247477429, 0.9371063837862048], 
             UndirectedEdge[17, 134] -> 
             RGBColor[
              0.4866741954142006, 0.5836689038197546, 0.9550323161159628], 
             UndirectedEdge[54, 72] -> 
             RGBColor[
              0.5316080896266691, 0.6306224216872751, 0.9562692826414592], 
             UndirectedEdge[170, 192] -> 
             RGBColor[
              0.7816807587855019, 0.8299139334375196, 0.978731066691737], 
             UndirectedEdge[140, 198] -> 
             RGBColor[
              0.21863861334011053`, 0.3471334234821667, 0.9357625176316521], 
             UndirectedEdge[19, 89] -> 
             RGBColor[
              0.6336424658825479, 0.6997848509973057, 0.8858864900738816], 
             UndirectedEdge[239, 295] -> 
             RGBColor[
              0.5893556509392692, 0.6720585160127768, 0.9634574874633866], 
             UndirectedEdge[51, 69] -> 
             RGBColor[
              0.5196172885125396, 0.6208877491633903, 0.9553253228540032], 
             UndirectedEdge[186, 269] -> 
             RGBColor[
              0.46707902070856167`, 0.572196287100322, 0.9524720706957246], 
             UndirectedEdge[37, 282] -> 
             RGBColor[
              0.43013330254840976`, 0.541095335234523, 0.9496585219123123], 
             UndirectedEdge[1, 239] -> 
             RGBColor[
              0.5605948057505972, 0.6460290419373571, 0.9616658173855293], 
             UndirectedEdge[59, 200] -> 
             RGBColor[
              0.2506313197792115, 0.38075978640440805`, 0.937584454934391], 
             UndirectedEdge[145, 221] -> 
             RGBColor[
              0.5549060172087075, 0.6267985575670003, 0.9633493159459734], 
             UndirectedEdge[75, 297] -> 
             RGBColor[
              0.5243114408491145, 0.6179213437933634, 0.9580158286759815], 
             UndirectedEdge[142, 185] -> 
             RGBColor[
              0.4651756378068801, 0.5584747310638433, 0.9542192789840176], 
             UndirectedEdge[36, 258] -> 
             RGBColor[
              0.19790314744160487`, 0.32533913411836557`, 0.934581663524105], 
             UndirectedEdge[13, 289] -> 
             RGBColor[
              0.7596484238100623, 0.8084990251678296, 0.846426834919517], 
             UndirectedEdge[53, 170] -> 
             RGBColor[
              0.8654664442982513, 0.895563466495364, 0.9870301561398246], 
             UndirectedEdge[130, 226] -> 
             RGBColor[
              0.7080703010423117, 0.4772243005942753, 0.45175052818177797`], 
             UndirectedEdge[224, 249] -> 
             RGBColor[
              0.3552830268689629, 0.4821500336549152, 0.9438592982010132], 
             UndirectedEdge[234, 271] -> 
             RGBColor[
              0.3830980735445015, 0.5062420290603714, 0.9456316483792986], 
             UndirectedEdge[78, 266] -> 
             RGBColor[
              0.4761936135130255, 0.5844158978388876, 0.9522435426750857], 
             UndirectedEdge[127, 232] -> 
             RGBColor[
              0.3346751679993831, 0.46146196045712157`, 0.9426501180351239], 
             UndirectedEdge[57, 292] -> 
             RGBColor[
              0.47182761524722183`, 0.5796364194233172, 0.9522410596244281], 
             UndirectedEdge[52, 107] -> 
             RGBColor[
              0.26227814229800545`, 0.39300133532285914`, 0.9382477242469065],
              UndirectedEdge[26, 130] -> 
             RGBColor[
              0.34491610938882594`, 0.47085140999655567`, 0.9432836490820073],
              UndirectedEdge[51, 58] -> 
             RGBColor[
              0.3960021756755188, 0.5128626176029494, 0.9470192496487512], 
             UndirectedEdge[192, 195] -> 
             RGBColor[
              0.8028044167719315, 0.8467573649294773, 0.9807458600477947], 
             UndirectedEdge[118, 266] -> 
             RGBColor[
              0.5061952772436035, 0.6087726000149196, 0.9546053835436723], 
             UndirectedEdge[171, 289] -> 
             RGBColor[
              0.7529714917211361, 0.5347911578551632, 0.45915551678619515`], 
             UndirectedEdge[1, 283] -> 
             RGBColor[
              0.37126132586255367`, 0.49487135761540246`, 0.9449183668291781],
              UndirectedEdge[44, 59] -> 
             RGBColor[
              0.23757297900992488`, 0.36703464230926314`, 0.9368408017456642],
              UndirectedEdge[62, 127] -> 
             RGBColor[
              0.6365201935852114, 0.7006390122089265, 0.8179391857868311], 
             UndirectedEdge[46, 219] -> 
             RGBColor[
              0.3868077642949585, 0.5094551767339388, 0.945868026593567], 
             UndirectedEdge[55, 252] -> 
             RGBColor[
              0.5417457394252256, 0.6227960311754575, 0.9611107166096516], 
             UndirectedEdge[55, 144] -> 
             RGBColor[
              0.5066186320680994, 0.5950996379521021, 0.9576771988711803], 
             UndirectedEdge[160, 296] -> 
             RGBColor[
              0.3186257884711753, 0.4427308760351084, 0.9418043127411839], 
             UndirectedEdge[154, 179] -> 
             RGBColor[
              0.3906497527152556, 0.5127829139996474, 0.9461128346983713], 
             UndirectedEdge[6, 145] -> 
             RGBColor[
              0.5874261695467501, 0.6485215913693733, 0.7634928882842553], 
             UndirectedEdge[132, 243] -> 
             RGBColor[
              0.806429817979905, 0.8462538169352829, 0.8361943192514284], 
             UndirectedEdge[53, 59] -> 
             RGBColor[
              0.5199655532853772, 0.6008344796159457, 0.959729356675739], 
             UndirectedEdge[4, 228] -> 
             RGBColor[
              0.29212639882546254`, 0.42437374542198536`, 0.9399475382996068],
              UndirectedEdge[71, 98] -> 
             RGBColor[
              0.7123187658202632, 0.7737495524401579, 0.9726859694033747], 
             UndirectedEdge[201, 259] -> 
             RGBColor[
              0.7197301082382928, 0.7756437025481299, 0.8311596452271083], 
             UndirectedEdge[34, 187] -> 
             RGBColor[
              0.4224995724848348, 0.5295740574733164, 0.9495421786431015], 
             UndirectedEdge[18, 260] -> 
             RGBColor[
              0.43586890387244837`, 0.5429423107187097, 0.9503657825309579], 
             UndirectedEdge[263, 289] -> 
             RGBColor[
              0.4188347556972848, 0.5352605492785041, 0.9484433485303927], 
             UndirectedEdge[173, 209] -> 
             RGBColor[
              0.8862881168703711, 0.5634788171511992, 0.4422695959276923], 
             UndirectedEdge[4, 199] -> 
             RGBColor[
              0.580060759142804, 0.6599975742177877, 0.9637577799295884], 
             UndirectedEdge[253, 292] -> 
             RGBColor[
              0.33396612036798085`, 0.4633377923106582, 0.9425137680280371], 
             UndirectedEdge[128, 209] -> 
             RGBColor[
              0.645072506850962, 0.3627704852433416, 0.4404556954213492], 
             UndirectedEdge[44, 137] -> 
             RGBColor[
              0.25916605324198555`, 0.3897303324071395, 0.9380704953790893], 
             UndirectedEdge[129, 263] -> 
             RGBColor[
              0.4782614419475839, 0.5834894271628679, 0.9531328362119207], 
             UndirectedEdge[73, 289] -> 
             RGBColor[
              0.7341460911929814, 0.7912287987279166, 0.9679360605538028], 
             UndirectedEdge[128, 276] -> 
             RGBColor[
              0.3654245091400471, 0.48383241736062665`, 0.9449949084532578], 
             UndirectedEdge[96, 196] -> 
             RGBColor[
              0.3995345987303863, 0.5196833964930926, 0.9468986645147639], 
             UndirectedEdge[24, 224] -> 
             RGBColor[
              0.3454724030893358, 0.4736525644332908, 0.9432341739289694], 
             UndirectedEdge[88, 278] -> 
             RGBColor[
              0.42813689744904293`, 0.542245238499677, 0.9492491535308398], 
             UndirectedEdge[158, 253] -> 
             RGBColor[
              0.3706145238161024, 0.4950807973751051, 0.9448489718888408], 
             UndirectedEdge[67, 110] -> 
             RGBColor[
              0.5325100050708971, 0.6275263768331995, 0.9578382681123014], 
             UndirectedEdge[155, 275] -> 
             RGBColor[
              0.9055635700446378, 0.9275358261580491, 0.9908546557886417], 
             UndirectedEdge[101, 108] -> 
             RGBColor[
              0.6440699237773052, 0.7136507696027685, 0.9398669145127795], 
             UndirectedEdge[102, 210] -> 
             RGBColor[
              0.7987328079397333, 0.8429692683452048, 0.980501205464234], 
             UndirectedEdge[176, 199] -> 
             RGBColor[
              0.6446467198670667, 0.7181890020411288, 0.9677907451864953], 
             UndirectedEdge[62, 226] -> 
             RGBColor[
              0.9043451077021472, 0.6323837142387146, 0.3682941650581154], 
             UndirectedEdge[69, 113] -> 
             RGBColor[
              0.4893772140509879, 0.5963374944156729, 0.9529447134193472], 
             UndirectedEdge[51, 258] -> 
             RGBColor[
              0.3537730109365534, 0.4684770879786082, 0.9446143611893179], 
             UndirectedEdge[30, 74] -> 
             RGBColor[
              0.3295608648186708, 0.4493127400210092, 0.9426634926169732], 
             UndirectedEdge[118, 228] -> 
             RGBColor[
              0.45189845545254587`, 0.5609205454798032, 0.9511757676129319], 
             UndirectedEdge[71, 121] -> 
             RGBColor[
              0.6642227354059673, 0.7330389454218993, 0.969359464750684], 
             UndirectedEdge[1, 20] -> 
             RGBColor[
              0.26781537217936513`, 0.39882131500882, 0.9385630612970524], 
             UndirectedEdge[126, 293] -> 
             RGBColor[
              0.7467364679688475, 0.801750607809967, 0.9759881128628795], 
             UndirectedEdge[112, 159] -> 
             RGBColor[
              0.5291388886179178, 0.6060437088985722, 0.9609232620048025], 
             UndirectedEdge[17, 159] -> 
             RGBColor[
              0.22094801649052392`, 0.349560752617868, 0.9358940347246123], 
             UndirectedEdge[139, 172] -> 
             RGBColor[
              0.25380343161396945`, 0.3840938770662453, 0.9377651020106617], 
             UndirectedEdge[47, 233] -> 
             RGBColor[
              0.44983907985347005`, 0.5607230049915309, 0.9508035114836682], 
             UndirectedEdge[98, 182] -> 
             RGBColor[
              0.4849439158800106, 0.5927383432426668, 0.9525957079476215], 
             UndirectedEdge[84, 159] -> 
             RGBColor[
              0.3505892956173342, 0.4642379961760647, 0.944514321988946], 
             UndirectedEdge[118, 176] -> 
             RGBColor[
              0.5087649310295695, 0.6109983049697687, 0.9547691196106585], 
             UndirectedEdge[18, 278] -> 
             RGBColor[
              0.5823413249886273, 0.6718099476603203, 0.960263188771117], 
             UndirectedEdge[155, 197] -> 
             RGBColor[
              0.5455026926141058, 0.6228622427662657, 0.9619128543542579], 
             UndirectedEdge[72, 215] -> 
             RGBColor[
              0.7646952731639924, 0.47872862637157015`, 0.45006426184749126`],
              UndirectedEdge[162, 239] -> 
             RGBColor[
              0.8298904396119374, 0.8671961260434191, 0.9836368850537696], 
             UndirectedEdge[139, 272] -> 
             RGBColor[
              0.3406266251164173, 0.4633373460806717, 0.9431494169864205], 
             UndirectedEdge[9, 75] -> 
             RGBColor[
              0.3378236413511387, 0.46609703943900216`, 0.9427808736622223], 
             UndirectedEdge[18, 254] -> 
             RGBColor[
              0.7890893476916556, 0.8351386775330691, 0.9536062721579508], 
             UndirectedEdge[25, 244] -> 
             RGBColor[
              0.7203885120004778, 0.44275840166218466`, 0.44657627130768546`],
              UndirectedEdge[30, 257] -> 
             RGBColor[
              0.7163109831125478, 0.7758614857446029, 0.9427154736447237], 
             UndirectedEdge[29, 270] -> 
             RGBColor[
              0.5616188432006246, 0.6321124831197212, 0.9587433444831093], 
             UndirectedEdge[73, 298] -> 
             RGBColor[
              0.5829630210629728, 0.6542154803172878, 0.9580611722321646], 
             UndirectedEdge[73, 96] -> 
             RGBColor[
              0.6300922198790475, 0.7030373629801625, 0.9607712495198786], 
             UndirectedEdge[108, 205] -> 
             RGBColor[
              0.7816442539825037, 0.8289704078835505, 0.9496941243153596], 
             UndirectedEdge[9, 43] -> 
             RGBColor[
              0.5770080803002392, 0.6633437468183899, 0.9618268370760233], 
             UndirectedEdge[151, 251] -> 
             RGBColor[
              0.5016695820562697, 0.5977439852921049, 0.9561532030131001], 
             UndirectedEdge[209, 279] -> 
             RGBColor[
              0.6618303749726028, 0.38038406714939255`, 0.44141003121983236`],
              UndirectedEdge[53, 68] -> 
             RGBColor[
              0.8337098688174507, 0.8702416352162514, 0.9840011856210362], 
             UndirectedEdge[282, 295] -> 
             RGBColor[
              0.4663063216369267, 0.5749154740376484, 0.951872304328437], 
             UndirectedEdge[35, 197] -> 
             RGBColor[
              0.523553858114647, 0.6053608379216382, 0.9598193549257437], 
             UndirectedEdge[116, 168] -> 
             RGBColor[
              0.3517620554333727, 0.4788323880108225, 0.9436447562387029], 
             UndirectedEdge[27, 152] -> 
             RGBColor[
              0.27502989640810704`, 0.40358849632928967`, 0.9390770158528121],
              UndirectedEdge[114, 231] -> 
             RGBColor[
              0.5444947447808726, 0.6381550992752049, 0.9584968991339073], 
             UndirectedEdge[83, 155] -> 
             RGBColor[
              0.682498430141563, 0.7499513803283091, 0.9705257922210869], 
             UndirectedEdge[62, 199] -> 
             RGBColor[
              0.9353553442114017, 0.9477202627693537, 0.8423702112986275], 
             UndirectedEdge[96, 278] -> 
             RGBColor[
              0.43387511128066514`, 0.5475625716038695, 0.9496020754561643], 
             UndirectedEdge[2, 178] -> 
             RGBColor[
              0.5984587840946043, 0.6808393353363672, 0.9636524287573545], 
             UndirectedEdge[6, 213] -> 
             RGBColor[
              0.9323342032193225, 0.9446743494461005, 0.7904498338564663], 
             UndirectedEdge[79, 93] -> 
             RGBColor[
              0.5609622722317695, 0.653168087136919, 0.9592289108620908], 
             UndirectedEdge[270, 272] -> 
             RGBColor[
              0.3101844981271653, 0.43134074047263704`, 0.9414157828894736], 
             UndirectedEdge[161, 186] -> 
             RGBColor[
              0.5605373694238008, 0.6452869153723371, 0.9617658280173342], 
             UndirectedEdge[189, 275] -> 
             RGBColor[
              0.5634198870857081, 0.6357471746182561, 0.9638341682403267], 
             UndirectedEdge[260, 261] -> 
             RGBColor[
              0.315290669544401, 0.44285010071054143`, 0.9414816666017212], 
             UndirectedEdge[195, 200] -> 
             RGBColor[
              0.617255868778515, 0.692332204775784, 0.9669000477545344], 
             UndirectedEdge[66, 110] -> 
             RGBColor[
              0.4933993067084291, 0.590428995240892, 0.9554641297669719], 
             UndirectedEdge[63, 172] -> 
             RGBColor[
              0.2684357248094684, 0.3994733449556871, 0.9385983894616073], 
             UndirectedEdge[4, 236] -> 
             RGBColor[
              0.2613271339469591, 0.39200176524849734`, 0.9381935657282052], 
             UndirectedEdge[143, 167] -> 
             RGBColor[
              0.45966442912398, 0.5568242336097528, 0.9532496634729443], 
             UndirectedEdge[135, 249] -> 
             RGBColor[
              0.28883278005382035`, 0.4178124274010441, 0.9398734600421854], 
             UndirectedEdge[135, 288] -> 
             RGBColor[
              0.20850232294266094`, 0.33647953959651666`, 0.9351852708888151],
              UndirectedEdge[83, 214] -> 
             RGBColor[
              0.47240518954714567`, 0.582558840342463, 0.9516086134798305], 
             UndirectedEdge[36, 290] -> 
             RGBColor[
              0.2809252627655607, 0.40795104001160415`, 0.9394798948488305], 
             UndirectedEdge[79, 119] -> 
             RGBColor[
              0.32392195613002256`, 0.4463491187310201, 0.9421772608526784], 
             UndirectedEdge[145, 264] -> 
             RGBColor[
              0.2930095433433448, 0.41638292901624596`, 0.9403244024518237], 
             UndirectedEdge[54, 238] -> 
             RGBColor[
              0.6460900127375249, 0.7208041869831883, 0.9671867648723532], 
             UndirectedEdge[177, 273] -> 
             RGBColor[
              0.5897095955549083, 0.6715302182850473, 0.9638643755308316], 
             UndirectedEdge[98, 208] -> 
             RGBColor[
              0.41109470053946123`, 0.5295435430621906, 0.9476774368193137], 
             UndirectedEdge[125, 170] -> 
             RGBColor[
              0.9392249836730353, 0.951686773267338, 0.8882124781308781], 
             UndirectedEdge[22, 217] -> 
             RGBColor[
              0.3745665721611009, 0.4974855492098981, 0.9451474031769334], 
             UndirectedEdge[78, 236] -> 
             RGBColor[
              0.3910975268434645, 0.5041918631302833, 0.9470599541729439], 
             UndirectedEdge[86, 240] -> 
             RGBColor[
              0.6667650181526416, 0.7375674967821542, 0.9688392278733866], 
             UndirectedEdge[59, 170] -> 
             RGBColor[
              0.541258000562445, 0.617812499106595, 0.9617602493050178], 
             UndirectedEdge[95, 109] -> 
             RGBColor[
              0.6138340687265914, 0.676431863160823, 0.7803867900595491], 
             UndirectedEdge[30, 252] -> 
             RGBColor[
              0.6567639416504392, 0.7292804516473093, 0.9682449499305785], 
             UndirectedEdge[116, 119] -> 
             RGBColor[
              0.3064999892592457, 0.43125908668106894`, 0.9410671485293128], 
             UndirectedEdge[6, 231] -> 
             RGBColor[
              0.6879905040990625, 0.7474543066132335, 0.7694676432015958], 
             UndirectedEdge[214, 275] -> 
             RGBColor[
              0.6954703294502206, 0.7601432861722028, 0.9719374770473852], 
             UndirectedEdge[157, 257] -> 
             RGBColor[
              0.6236137895849061, 0.6928378606475905, 0.9368523887481504], 
             UndirectedEdge[128, 173] -> 
             RGBColor[
              0.6041094773941917, 0.6730508896040595, 0.9398300556298727], 
             UndirectedEdge[14, 113] -> 
             RGBColor[
              0.46398769357839154`, 0.5757251379111563, 0.9509459573628665], 
             UndirectedEdge[213, 231] -> 
             RGBColor[
              0.6262781950941217, 0.7024542394846595, 0.9665396969002791], 
             UndirectedEdge[29, 148] -> 
             RGBColor[
              0.8757873047555084, 0.9037226946635679, 0.9827639515302096], 
             UndirectedEdge[109, 154] -> 
             RGBColor[
              0.6641478419706849, 0.726983046059591, 0.7833374630062041], 
             UndirectedEdge[74, 123] -> 
             RGBColor[
              0.274388170682048, 0.40176109034329066`, 0.9390826842619552], 
             UndirectedEdge[189, 216] -> 
             RGBColor[
              0.29839636310582296`, 0.42262305242841114`, 0.9406100018780216],
              UndirectedEdge[29, 162] -> 
             RGBColor[
              0.888395024872736, 0.9136952674521298, 0.9839878443143228], 
             UndirectedEdge[73, 140] -> 
             RGBColor[
              0.5888249794358251, 0.660376770236783, 0.9583950020895082], 
             UndirectedEdge[9, 295] -> 
             RGBColor[
              0.36556929104102454`, 0.4910594786780852, 0.9445147298582708], 
             UndirectedEdge[169, 221] -> 
             RGBColor[
              0.7580245494265625, 0.8109276199844931, 0.9768619743875808], 
             UndirectedEdge[22, 61] -> 
             RGBColor[
              0.7143246753945895, 0.7741401870568507, 0.9396429611724255], 
             UndirectedEdge[11, 143] -> 
             RGBColor[
              0.21371239682750687`, 0.34195565758725344`, 0.9354819768889435],
              UndirectedEdge[100, 299] -> 
             RGBColor[
              0.7402035968094219, 0.7950716602051133, 0.9395827841042531], 
             UndirectedEdge[181, 232] -> 
             RGBColor[
              0.37136074813785913`, 0.4960757477282659, 0.9448837563832966], 
             UndirectedEdge[49, 292] -> 
             RGBColor[
              0.5007515020029306, 0.603118133697851, 0.9545180539415257], 
             UndirectedEdge[4, 39] -> 
             RGBColor[
              0.6284015109092135, 0.6975968601267869, 0.9355591465488694], 
             UndirectedEdge[33, 75] -> 
             RGBColor[
              0.2714087332566082, 0.40259816533325377`, 0.9387676978945001], 
             UndirectedEdge[223, 271] -> 
             RGBColor[
              0.48760382524558415`, 0.593978143088372, 0.9530592034825522], 
             UndirectedEdge[21, 34] -> 
             RGBColor[
              0.47293308283880287`, 0.5798612227185601, 0.9525139454530269], 
             UndirectedEdge[51, 165] -> 
             RGBColor[
              0.5195518350776476, 0.6208346111163014, 0.9553201701198446], 
             UndirectedEdge[36, 138] -> 
             RGBColor[
              0.4017651919912093, 0.5086143312132156, 0.9482855230686227], 
             UndirectedEdge[50, 205] -> 
             RGBColor[
              0.7431308244884546, 0.3167138335999004, 0.42989213243002233`], 
             UndirectedEdge[237, 283] -> 
             RGBColor[
              0.5365789684498785, 0.6344558222170962, 0.9567164721509], 
             UndirectedEdge[140, 245] -> 
             RGBColor[
              0.23791836196312025`, 0.3673976616916155, 0.9368604707939003], 
             UndirectedEdge[19, 49] -> 
             RGBColor[
              0.4584351927703348, 0.5636531629295018, 0.9519246832491937], 
             UndirectedEdge[235, 292] -> 
             RGBColor[
              0.2709418696368616, 0.3970953088239594, 0.9389246301849236], 
             UndirectedEdge[15, 115] -> 
             RGBColor[
              0.4091130934159726, 0.5279347851289589, 0.9475214374476866], 
             UndirectedEdge[69, 110] -> 
             RGBColor[
              0.6187886942908276, 0.7003190020542412, 0.9638712452941689], 
             UndirectedEdge[34, 50] -> 
             RGBColor[
              0.747440388465816, 0.3202125317803671, 0.43023139709277325`], 
             UndirectedEdge[126, 275] -> 
             RGBColor[
              0.9298933657142572, 0.9469357448102932, 0.993175253419075], 
             UndirectedEdge[59, 225] -> 
             RGBColor[
              0.5436428750931308, 0.6197141333216694, 0.9619877207667572], 
             UndirectedEdge[82, 228] -> 
             RGBColor[
              0.6192080411943577, 0.693096874416434, 0.9646279807844778], 
             UndirectedEdge[19, 280] -> 
             RGBColor[
              0.24352068110341304`, 0.37328605431561257`, 0.9371795145810515],
              UndirectedEdge[194, 283] -> 
             RGBColor[
              0.3530458235289631, 0.47572570973324524`, 0.9438810209187009], 
             UndirectedEdge[63, 283] -> 
             RGBColor[
              0.35885519823653356`, 0.4818317308865323, 0.9442118562140973], 
             UndirectedEdge[36, 245] -> 
             RGBColor[
              0.22235946596891976`, 0.3510442755107277, 0.9359744146843545], 
             UndirectedEdge[3, 55] -> 
             RGBColor[
              0.25012319535452054`, 0.3802257154171086, 0.9375555180001076], 
             UndirectedEdge[137, 192] -> 
             RGBColor[
              0.45777294200468854`, 0.5578806366559776, 0.9526599608610766], 
             UndirectedEdge[54, 251] -> 
             RGBColor[
              0.5949687640792108, 0.6808245077447154, 0.9621029859577195], 
             UndirectedEdge[252, 292] -> 
             RGBColor[
              0.6072344248962838, 0.6866166385839418, 0.9650237198483055], 
             UndirectedEdge[100, 121] -> 
             RGBColor[
              0.448085848337941, 0.5611512207485396, 0.9501538968982469], 
             UndirectedEdge[142, 239] -> 
             RGBColor[
              0.7772019639107168, 0.825912162367617, 0.9784181171290004], 
             UndirectedEdge[85, 299] -> 
             RGBColor[
              0.8852713208676619, 0.9105169985617747, 0.9525941491780441], 
             UndirectedEdge[120, 130] -> 
             RGBColor[
              0.4002586972604394, 0.52110569880509, 0.9467251081479344], 
             UndirectedEdge[9, 297] -> 
             RGBColor[
              0.5634538009324692, 0.6527550407599494, 0.9604758731805864], 
             UndirectedEdge[237, 239] -> 
             RGBColor[
              0.725912448337922, 0.7856135065390508, 0.9734639227072512], 
             UndirectedEdge[169, 213] -> 
             RGBColor[
              0.7288323927596644, 0.787650586658292, 0.9740776004245462], 
             UndirectedEdge[46, 50] -> 
             RGBColor[
              0.660504076589189, 0.24770691874803907`, 0.4239198323617732], 
             UndirectedEdge[105, 171] -> 
             RGBColor[
              0.6463582143732904, 0.4373269595945681, 0.4522405576060826], 
             UndirectedEdge[34, 114] -> 
             RGBColor[
              0.6573690794926657, 0.7317297986198592, 0.9668472416503628], 
             UndirectedEdge[60, 240] -> 
             RGBColor[
              0.49695729924691556`, 0.6024913490566736, 0.9535414454927376], 
             UndirectedEdge[19, 84] -> 
             RGBColor[
              0.4001716492925608, 0.5163521935915226, 0.9473379636802313], 
             UndirectedEdge[19, 48] -> 
             RGBColor[
              0.23105239791147447`, 0.36018109814607163`, 0.9364694642984428],
              UndirectedEdge[5, 77] -> 
             RGBColor[
              0.7255961274674954, 0.7853534326934504, 0.973442784839772]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {3}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.18080582686923688`, 0.30736876616407177`, 0.9336079964107278],
              160 -> RGBColor[
              0.41144698812359004`, 0.5307964340109016, 0.9474380161483172], 
             245 -> RGBColor[
              0.24190383434353901`, 0.3715866458569794, 0.9370874375499871], 
             155 -> RGBColor[
              0.8821209325410977, 0.9088433033461695, 0.9886186760960645], 
             213 -> RGBColor[
              0.8706218942143817, 0.8996742823175264, 0.9875218875551496], 27 -> 
             RGBColor[
              0.2108591363762548, 0.3389566999458262, 0.9353194879272653], 19 -> 
             RGBColor[
              0.2783241208085315, 0.40986667611122035`, 0.9391615189851831], 
             164 -> RGBColor[
              0.19350685546707277`, 0.32071835251212183`, 0.9343313011998865],
              190 -> RGBColor[
              0.9551318262593882, 0.8598196730907043, 0.28275621809814855`], 
             103 -> RGBColor[
              0.24810460241780025`, 0.3781040462544312, 0.937440562118602], 
             138 -> RGBColor[
              0.6007152863881181, 0.6867267572619552, 0.9617096543185233], 
             291 -> RGBColor[
              0.7971275451250565, 0.8414413637362032, 0.9804138821837804], 28 -> 
             RGBColor[
              0.9883272988593894, 0.9894410523506908, 0.8431103960895228], 
             114 -> RGBColor[
              0.7070549935878835, 0.7710760018986172, 0.9714362920224061], 
             195 -> RGBColor[
              0.9290062075481781, 0.9462283489699287, 0.9930906354812189], 93 -> 
             RGBColor[
              0.689404313227707, 0.7572871562511081, 0.9696770371590897], 34 -> 
             RGBColor[
              0.6076831653974478, 0.6923835953411013, 0.9622581912783196], 
             161 -> RGBColor[
              0.8299134373914592, 0.8672144638485516, 0.9836390786025108], 22 -> 
             RGBColor[
              0.454750801427032, 0.5682262127454333, 0.9502187953768605], 124 -> 
             RGBColor[
              0.5838952482066041, 0.6730714925321171, 0.9603855192990445], 84 -> 
             RGBColor[
              0.5220191777765901, 0.6228377110718248, 0.9555144083752795], 46 -> 
             RGBColor[
              0.34687422976756704`, 0.47486675624411717`, 0.9433234970853196],
              241 -> RGBColor[
              0.5755294025098037, 0.6662797221184007, 0.9597269292806899], 
             185 -> RGBColor[
              0.20048606902330926`, 0.32805394846742386`, 0.934728757087093], 
             121 -> 
             RGBColor[
              0.3920311072654765, 0.5139793738821503, 0.9462008533888275], 
             126 -> RGBColor[
              0.9307805238803362, 0.9476431406506577, 0.993259871356931], 236 -> 
             RGBColor[
              0.23824735421569476`, 0.3677434534083849, 0.9368792064159841], 
             78 -> RGBColor[
              0.5439476994712342, 0.6406402728521816, 0.9572407019299036], 
             254 -> RGBColor[
              0.9647788974982408, 0.973252739940226, 0.9445043187874416], 290 -> 
             RGBColor[
              0.35903542793682086`, 0.48540017485873227`, 0.9440983978789391],
              251 -> RGBColor[
              0.7231074866450288, 0.783616331478325, 0.9730362545112657], 165 -> 
             RGBColor[
              0.5245488455710977, 0.6248914093476415, 0.9557135530905416], 
             100 -> RGBColor[
              0.5041405894104055, 0.6083230676149288, 0.9541069404076663], 
             235 -> RGBColor[0.178927, 0.305394, 0.933501], 70 -> 
             RGBColor[
              0.23035157497681347`, 0.3594444888070024, 0.9364295534690884], 
             234 -> RGBColor[
              0.34674757607841444`, 0.4747570551843727, 0.9433154268242423], 
             257 -> RGBColor[
              0.9706061934430615, 0.9775987277145519, 0.9346402267550542], 
             135 -> RGBColor[
              0.23539563571422398`, 0.36474611645394306`, 0.9367168052660647],
              265 -> RGBColor[
              0.9875757285435007, 0.9891302587105947, 0.8555658612254277], 
             111 -> RGBColor[
              0.2028150975943005, 0.33050190516447603`, 0.934861391818722], 
             182 -> RGBColor[
              0.48166466366595295`, 0.5900760985666661, 0.9523375532010342], 
             188 -> RGBColor[
              0.7138412552143611, 0.7763774810587203, 0.9721126831601129], 
             154 -> RGBColor[
              0.3339662329848542, 0.4636864982057136, 0.9425010109444185], 
             269 -> RGBColor[
              0.6429967399609808, 0.7210332073045215, 0.9650515639592917], 
             208 -> RGBColor[
              0.3339662329848542, 0.4636864982057136, 0.9425010109444185], 86 -> 
             RGBColor[
              0.8283337742229476, 0.8659548833167949, 0.9834884089193162], 
             119 -> RGBColor[
              0.2153236810242131, 0.3436492194393103, 0.9355737371402646], 
             140 -> RGBColor[
              0.23393288958270148`, 0.3632086775262516, 0.9366335040378135], 
             85 -> RGBColor[
              0.7942760375268856, 0.8392137443282516, 0.9801296705552484], 
             242 -> 
             RGBColor[
              0.26273661952296956`, 0.3934832239554314, 0.9382738338466119], 
             117 -> RGBColor[
              0.9474652780872534, 0.829424364313922, 0.2765875334818344], 47 -> 
             RGBColor[
              0.32383927647447497`, 0.454915037472057, 0.9418557302304932], 
             81 -> RGBColor[
              0.2370168486926757, 0.36645011408513556`, 0.936809130946818], 
             275 -> RGBColor[
              0.9290062075481781, 0.9462283489699287, 0.9930906354812189], 23 -> 
             RGBColor[
              0.9775716926035747, 0.9827935855835045, 0.9228494535694423], 
             110 -> RGBColor[
              0.7128976361407737, 0.7756403186666632, 0.9720186320294792], 6 -> 
             RGBColor[
              0.9940465122242633, 0.9896744165746747, 0.593377780157783], 218 -> 
             RGBColor[
              0.9741511019108017, 0.9802425146455377, 0.9286396213793728], 
             108 -> RGBColor[
              0.9685340344996436, 0.9760533149673997, 0.9381478513406522], 
             297 -> RGBColor[
              0.7499416004304451, 0.8045793451143106, 0.9757108281943454], 
             157 -> RGBColor[
              0.2766213857267505, 0.4080769935806288, 0.9390645507412464], 
             270 -> RGBColor[
              0.18168979464866944`, 0.3082978723470497, 0.9336583370680533], 
             33 -> RGBColor[
              0.24413618524543235`, 0.3739329881940914, 0.9372145666313828], 
             252 -> RGBColor[
              0.8515121105188443, 0.8844366595199649, 0.9856991793267639], 
             260 -> RGBColor[
              0.25833800985982613`, 0.38886000631150724`, 0.9380233395334557],
              159 -> RGBColor[
              0.17915941345807826`, 0.30563828128030457`, 0.9335142356026127],
              183 -> RGBColor[
              0.24875535299935558`, 0.3787880263756158, 0.9374776214015224], 
             99 -> RGBColor[
              0.2551817728765027, 0.3855426011250513, 0.9378435965064897], 17 -> 
             RGBColor[
              0.26273661952296956`, 0.3934832239554314, 0.9382738338466119], 
             277 -> RGBColor[
              0.20656148018728765`, 0.33443959080408125`, 0.9350747427651162],
              104 -> RGBColor[
              0.7186727006270777, 0.7801518429354796, 0.9725942364864281], 79 -> 
             RGBColor[
              0.432520231235832, 0.54904901802273, 0.9487807845650921], 191 -> 
             RGBColor[
              0.37550715736427887`, 0.4996671589956033, 0.9451479619126784], 
             50 -> RGBColor[0.817319, 0.134127, 0.164218], 225 -> 
             RGBColor[
              0.8915286406366907, 0.9163447544161619, 0.9895159916925822], 61 -> 
             RGBColor[
              0.9738985493621473, 0.9800541613682681, 0.9290671269679907], 
             196 -> RGBColor[
              0.48260182699162646`, 0.5908369299731746, 0.9524113301309737], 
             1 -> RGBColor[
              0.2966508902702116, 0.4291292727997429, 0.9402052013939999], 
             263 -> RGBColor[
              0.31309439829755564`, 0.4456083640484894, 0.9411710760943827], 
             201 -> RGBColor[
              0.9951435801116851, 0.9920209338552919, 0.7127868493854518], 
             293 -> RGBColor[
              0.5626924120573588, 0.6558580749692763, 0.958716354368828], 184 -> 
             RGBColor[
              0.3814292969705315, 0.504796618667148, 0.9455253154116463], 106 -> 
             RGBColor[
              0.7216956879754213, 0.7825134236275604, 0.972895539613888], 206 -> 
             RGBColor[
              0.8235604263147486, 0.8621487452638743, 0.9830331227346142], 
             247 -> RGBColor[
              0.3116492623432281, 0.4443566599194959, 0.9410789933092564], 
             220 -> RGBColor[
              0.9415478917525799, 0.9559270938923928, 0.9838283518981652], 
             107 -> RGBColor[
              0.2783305889696085, 0.40987347455861733`, 0.9391618873373876], 
             131 -> RGBColor[
              0.8281502983997074, 0.21738110580537404`, 0.17459006357976167`],
              127 -> RGBColor[
              0.27804430335500374`, 0.4095725702261114, 0.9391455837951574], 
             210 -> RGBColor[
              0.7435989347531691, 0.7996244064811779, 0.9750786505552153], 
             181 -> RGBColor[
              0.35141546363195575`, 0.47880014476840005`, 0.9436128604915031],
              194 -> RGBColor[
              0.2602198856030303, 0.3908379770354284, 0.9381305095730456], 
             118 -> RGBColor[
              0.6039510269323901, 0.6893536772042456, 0.9619643836670766], 
             276 -> RGBColor[
              0.4885629559150162, 0.59567644297898, 0.9528806120361576], 280 -> 
             RGBColor[
              0.20871724139829456`, 0.33670543252000473`, 0.9351975101769201],
              189 -> RGBColor[
              0.19783356662323814`, 0.3252660002665835, 0.9345777009994346], 
             168 -> RGBColor[
              0.3058478133724671, 0.4387958220988175, 0.9407289525590449], 41 -> 
             RGBColor[
              0.4057131083775886, 0.5258300355680908, 0.9470726584011727], 14 -> R\
GBColor[0.4739007114956888, 0.5837729724327863, 0.9517263464458972], 77 -> 
             RGBColor[
              0.8249906655524512, 0.8632891792092084, 0.9831695402298959], 51 -> 
             RGBColor[
              0.5145548245841975, 0.6167778128849613, 0.9549267871491477], 
             179 -> RGBColor[
              0.447333272445657, 0.5618793297935811, 0.949724658452324], 223 -> 
             RGBColor[
              0.5557590794805798, 0.650229283240374, 0.9581705370307498], 292 -> 
             RGBColor[
              0.36295673927372324`, 0.4887966176479187, 0.9443482603698471], 
             143 -> RGBColor[
              0.22016250823617814`, 0.3487351336384507, 0.9358493011915826], 
             112 -> RGBColor[
              0.8791183637777572, 0.9064491365168397, 0.9883322884069923], 
             197 -> RGBColor[
              0.20888445268711384`, 0.33688118218636187`, 0.9352070326124514],
              54 -> RGBColor[
              0.4668300415133929, 0.5780326840111057, 0.9511697174041732], 71 -> 
             RGBColor[
              0.9364143635464582, 0.9520985169616483, 0.9925180761125405], 
             177 -> RGBColor[
              0.33060292981461037`, 0.46077337404418095`, 0.9422867042404628],
              158 -> RGBColor[
              0.43625354616996626`, 0.5522826277768125, 0.9490186680914543], 
             226 -> RGBColor[
              0.8590196196455112, 0.4527228442622011, 0.20407485369792067`], 
             203 -> RGBColor[
              0.9492663423938245, 0.96168350174283, 0.9707630282568727], 115 -> 
             RGBColor[
              0.484259953847091, 0.5921830720522042, 0.9525418639509546], 173 -> 
             RGBColor[
              0.9659328924233053, 0.9741133874658459, 0.9425509063893873], 
             212 -> RGBColor[
              0.7072322314514562, 0.7712144614646979, 0.9714539574362651], 
             129 -> RGBColor[
              0.6434284855976122, 0.7213704902772463, 0.9650945963294588], 
             279 -> RGBColor[
              0.2925596667300001, 0.4248291374604261, 0.9399722122658077], 26 -> 
             RGBColor[
              0.2836605549417392, 0.41547560673468775`, 0.9394654210145224], 
             40 -> RGBColor[
              0.43637124638508995`, 0.5523845737873678, 0.9490261678450838], 
             146 -> RGBColor[
              0.24211641231819056`, 0.37181007878656025`, 0.9370995435511627],
              192 -> RGBColor[
              0.6766026259956849, 0.7472863808890259, 0.9684010846143707], 
             300 -> RGBColor[
              0.19057572373289094`, 0.3176375472150109, 0.9341643775838457], 
             221 -> RGBColor[
              0.9290062075481781, 0.9462283489699287, 0.9930906354812189], 62 -> 
             RGBColor[
              0.9949960838154189, 0.9917054541917416, 0.6967327877785048], 
             286 -> RGBColor[
              0.23197936833160687`, 0.36115540283095, 0.9365222538925394], 
             152 -> RGBColor[
              0.33920065643995934`, 0.4682202927127531, 0.942834543778359], 
             64 -> RGBColor[
              0.5603013136133317, 0.6539168735346578, 0.958528118340432], 37 -> 
             RGBColor[
              0.2818265424705218, 0.4135479433443314, 0.9393609767174649], 
             148 -> RGBColor[
              0.8100267177584368, 0.8515182954347429, 0.981699551162254], 261 -> 
             RGBColor[
              0.3722433292289758, 0.49684019510957567`, 0.9449399936699867], 
             15 -> RGBColor[
              0.3339662329848542, 0.4636864982057136, 0.9425010109444185], 
             136 -> RGBColor[
              0.5548234999177242, 0.6494697376038688, 0.958096884780421], 198 -> 
             RGBColor[
              0.2033443370975196, 0.33105816943808186`, 0.9348915312254906], 
             63 -> RGBColor[
              0.27183863501817124`, 0.4030500193420025, 0.9387921801638385], 
             171 -> RGBColor[
              0.8671696810331972, 0.48973036952848537`, 0.21087546469609134`],
              59 -> RGBColor[
              0.19575710954957087`, 0.3230835122271767, 0.9344594498409322], 
             229 -> RGBColor[
              0.4547869863838691, 0.5682555893235074, 0.9502216439892126], 
             102 -> RGBColor[
              0.8538666811262977, 0.8863141302092316, 0.9859237603732528], 
             299 -> RGBColor[
              0.9762666042084384, 0.9818202527952979, 0.9250586278008399], 
             128 -> RGBColor[
              0.24228606236507805`, 0.3719883917422732, 0.9371092048703581], 
             12 -> RGBColor[
              0.4223674636608853, 0.5402552010422469, 0.9481338591929562], 
             222 -> RGBColor[
              0.9504731812869212, 0.9625835602132843, 0.9687201648048539], 92 -> 
             RGBColor[
              0.8256874619506391, 0.19845066563602165`, 0.17223164861475795`],
              271 -> RGBColor[
              0.4194485710105885, 0.5377270029363701, 0.9479478699343548], 
             132 -> RGBColor[
              0.9951118950593217, 0.991953162732137, 0.709338126973183], 80 -> 
             RGBColor[
              0.5333122733984293, 0.632005954845794, 0.956403442230603], 244 -> 
             RGBColor[
              0.4634658542494011, 0.575301485235288, 0.9509048762593278], 150 -> 
             RGBColor[
              0.9716514993185116, 0.9783783151249312, 0.9328707965673532], 
             125 -> RGBColor[
              0.9916910757707518, 0.9908320605486626, 0.7873639074926528], 
             133 -> RGBColor[
              0.27804430335500374`, 0.4095725702261114, 0.9391455837951574], 
             258 -> RGBColor[
              0.1929911972889092, 0.3201763630722551, 0.934301935229488], 255 -> 
             RGBColor[
              0.49478246433544615`, 0.6007257201003464, 0.9533702345218239], 
             176 -> RGBColor[
              0.413578835126749, 0.532642932735292, 0.9475738555542402], 230 -> 
             RGBColor[
              0.7046513846873976, 0.7691982843574534, 0.971196722750208], 274 -> 
             RGBColor[
              0.5333122733984293, 0.632005954845794, 0.956403442230603], 87 -> 
             RGBColor[
              0.2221372464843362, 0.3508107087429013, 0.9359617596134518], 
             130 -> RGBColor[
              0.4061716638359127, 0.5262272132584236, 0.9471018771494925], 35 -> 
             RGBColor[
              0.8382232635421801, 0.8738404936569146, 0.9844316772390359], 31 -> 
             RGBColor[
              0.8688697058924625, 0.898277134911513, 0.9873547622688079], 18 -> 
             RGBColor[
              0.6133997978850706, 0.6970246151259122, 0.96270822552846], 24 -> 
             RGBColor[
              0.3226486768341625, 0.45388379990489625`, 0.9417798662742184], 
             151 -> RGBColor[
              0.2802316774675106, 0.411871639105885, 0.9392701515149346], 137 -> 
             RGBColor[
              0.23894325801369223`, 0.3684748924229294, 0.9369188371077826], 
             296 -> RGBColor[
              0.2258045888187606, 0.3546653180593152, 0.9361706093340505], 
             266 -> RGBColor[
              0.40843952755481683`, 0.5281915228255936, 0.9472463834202679], 
             283 -> RGBColor[
              0.4458717614548958, 0.560613442431062, 0.9496315322643561], 284 -> 
             RGBColor[
              0.9611005015306215, 0.8804449990055103, 0.30338322331070755`], 
             238 -> RGBColor[
              0.8253499839616569, 0.8635756899552708, 0.9832038123405332], 72 -> 
             RGBColor[
              0.5963861377399453, 0.6832121593634444, 0.9613688478787451], 
             288 -> RGBColor[
              0.1816090101710979, 0.3082129627390903, 0.9336537365115656], 
             172 -> 
             RGBColor[
              0.2650328146007656, 0.3958966705693717, 0.9384045987593762], 
             243 -> RGBColor[
              0.6177477409004883, 0.700554471138429, 0.9630505115296738], 88 -> 
             RGBColor[
              0.30499094280590183`, 0.43789519680462563`, 0.9406801550479054],
              273 -> RGBColor[
              0.8488162612952064, 0.8822870625259136, 0.9854420468212003], 
             202 -> RGBColor[
              0.22082608447223304`, 0.34943259433570784`, 0.9358870908765529],
              98 -> RGBColor[
              0.48822316809406824`, 0.5954005879186676, 0.9528538626942088], 
             30 -> RGBColor[
              0.462015772782034, 0.5741242437746538, 0.9507907205343933], 116 -> 
             RGBColor[
              0.39767629749427835`, 0.5188689539228275, 0.9465605599183611], 
             240 -> RGBColor[
              0.5051962620823355, 0.6091801102475135, 0.9541900468274571], 73 -> 
             RGBColor[
              0.9437170692889487, 0.9575448629473144, 0.9801565001412028], 29 -> 
             RGBColor[
              0.9415478917525799, 0.9559270938923928, 0.9838283518981652], 75 -> 
             RGBColor[
              0.298681281267784, 0.43126334247241616`, 0.9403208291576174], 
             200 -> RGBColor[
              0.30550553000885206`, 0.4384360605816394, 0.9407094600278498], 
             156 -> RGBColor[
              0.9921814506636677, 0.9852883385851764, 0.42412684154784575`], 
             25 -> RGBColor[
              0.8488498408760161, 0.376486859875633, 0.1944119688318643], 38 -> 
             RGBColor[
              0.9926946378575394, 0.9867828939997172, 0.44623459814139327`], 
             3 -> RGBColor[
              0.2682670223774342, 0.3992960280032672, 0.9385887821076758], 57 -> 
             RGBColor[
              0.5806984912207205, 0.6704762211987156, 0.960133858879009], 227 -> 
             RGBColor[
              0.25949090948024, 0.39007177691062006`, 0.9380889954612762], 39 -> 
             RGBColor[
              0.9723961081402035, 0.978933643164964, 0.9316103680573125], 109 -> 
             RGBColor[
              0.9943294509565155, 0.9902795939134682, 0.6241739150679897], 
             256 -> RGBColor[
              0.27339423534521756`, 0.4046850539164856, 0.9388807693011593], 
             287 -> RGBColor[
              0.4273117159322404, 0.5445376638543499, 0.9484489025756564], 
             239 -> RGBColor[
              0.8245387212309827, 0.8629288110749713, 0.9831264333770587], 
             285 -> 
             RGBColor[
              0.9949266342617542, 0.9915569086188797, 0.6891736324550598], 
             216 -> RGBColor[
              0.3989591595884078, 0.5199801045902388, 0.9466423027566085], 21 -> 
             RGBColor[
              0.33818300028015785`, 0.4673388500960189, 0.9427696996277344], 
             175 -> RGBColor[
              0.8248427121874152, 0.863171205212016, 0.9831554283058592], 7 -> 
             RGBColor[
              0.5012996505433573, 0.6060166654598216, 0.9538832912933504], 13 -> 
             RGBColor[
              0.9947217345231107, 0.9920853158271403, 0.7371380488726311], 
             294 -> RGBColor[
              0.38919195093835335`, 0.5115202393717424, 0.9460199448582306], 
             193 -> RGBColor[
              0.2511754746935259, 0.3813317277207668, 0.9376154437517562], 60 -> 
             RGBColor[
              0.4887183364114956, 0.5958025878658336, 0.952892844158018], 65 -> 
             RGBColor[
              0.25730889024673265`, 0.3877783363481938, 0.9379647326939361], 
             69 -> RGBColor[
              0.5246797524408816, 0.6249976854418193, 0.9557238585588587], 
             217 -> RGBColor[
              0.2943823428951698, 0.426744885674363, 0.9400760109770063], 214 -> 
             RGBColor[
              0.4619344513522631, 0.5740582233744771, 0.9507843186135515], 
             170 -> RGBColor[
              0.886758891575319, 0.9125414859860133, 0.9890610487691034], 74 -> 
             RGBColor[
              0.19710595685530763`, 0.32450123626736466`, 0.9345362646995532],
              246 -> RGBColor[
              0.6361811078623999, 0.7155195088518271, 0.9645016537005635], 
             264 -> RGBColor[
              0.40521325981745265`, 0.5253970918684201, 0.9470408084929196], 
             278 -> RGBColor[
              0.551282852092184, 0.6465952801947285, 0.9578181520137742], 45 -> 
             RGBColor[
              0.8532170655147833, 0.41005526217923677`, 0.19859402807802248`],
              237 -> RGBColor[
              0.6272861754448613, 0.7082982020031303, 0.9638014120374438], 
             228 -> RGBColor[
              0.2998458839727016, 0.43248741375536087`, 0.9403871515587872], 
             180 -> RGBColor[
              0.2387376032460903, 0.36825873622291444`, 0.9369071253730066], 
             53 -> RGBColor[
              0.8441739970211836, 0.8785854470047147, 0.9849992635105458], 48 -> 
             RGBColor[
              0.18378067501441744`, 0.3104955201809229, 0.9337774096117024], 
             5 -> 
             RGBColor[
              0.6262015893825394, 0.7074176861776922, 0.9637160294496482], 
             101 -> RGBColor[
              0.3196058130549668, 0.4512482242381374, 0.9415859776849068], 
             267 -> RGBColor[
              0.5119152767266762, 0.6146349090239497, 0.9547189922728212], 
             120 -> RGBColor[
              0.39434573068496603`, 0.5159841843517564, 0.9463483391463763], 
             147 -> RGBColor[
              0.336252603436356, 0.4656668373744842, 0.9426466964478303], 89 -> 
             RGBColor[
              0.9889608109565644, 0.9897030258833909, 0.8326114611625802], 43 -> 
             RGBColor[
              0.7770501591659851, 0.8257567572311917, 0.9784127559852194], 
             199 -> RGBColor[
              0.8757146046073844, 0.9037350713469657, 0.9880076348187504], 
             268 -> RGBColor[
              0.9875757285435007, 0.9891302587105947, 0.8555658612254277], 
             169 -> RGBColor[
              0.587042891304947, 0.6756268909990576, 0.9606333132939426], 20 -> 
             RGBColor[
              0.23897985408851863`, 0.36851335721789713`, 0.936920921200105], 
             4 -> RGBColor[
              0.28440691367822346`, 0.4162600770886098, 0.9395079250404264], 
             167 -> RGBColor[
              0.6991663500117818, 0.7649133335810548, 0.9706500257543059], 
             142 -> RGBColor[
              0.729865206590451, 0.7888955136602627, 0.9737098008809421], 16 -> 
             RGBColor[
              0.9327444648376366, 0.949209133860252, 0.9934471937986691], 281 -> 
             RGBColor[
              0.4223674636608853, 0.5402552010422469, 0.9481338591929562], 
             289 -> RGBColor[
              0.5245751130970139, 0.6249127345085188, 0.9557156209664028], 
             178 -> RGBColor[
              0.8025718375042427, 0.845694486320978, 0.9809565183683328], 58 -> 
             RGBColor[
              0.2774495267668401, 0.4089474223209376, 0.9391117121483546], 
             186 -> RGBColor[
              0.29116130145614244`, 0.42335936689612247`, 0.9398925774321576],
              122 -> RGBColor[
              0.2153236810242131, 0.3436492194393103, 0.9355737371402646], 
             249 -> RGBColor[
              0.34226992439341675`, 0.4708787383481451, 0.9430301148183061], 
             113 -> RGBColor[
              0.4540746756610942, 0.5676773033895264, 0.9501655682798357], 52 -> 
             RGBColor[
              0.2462256956264024, 0.37612919608710094`, 0.9373335611564254], 
             187 -> 
             RGBColor[
              0.23731597957222172`, 0.36676451960553164`, 0.9368261660078836],
              259 -> RGBColor[
              0.4443166363649005, 0.5592664712409678, 0.9495324410687648], 42 -> 
             RGBColor[
              0.5894787192992654, 0.6776044058976458, 0.9608250705963873], 
             134 -> RGBColor[
              0.7106117713054316, 0.7738545836840777, 0.9717907983853138], 
             248 -> RGBColor[
              0.8821209325410977, 0.9088433033461695, 0.9886186760960645], 
             174 -> RGBColor[
              0.23539563571422398`, 0.36474611645394306`, 0.9367168052660647],
              215 -> RGBColor[
              0.8488498408760161, 0.376486859875633, 0.1944119688318643], 83 -> 
             RGBColor[
              0.48287592774202825`, 0.5910594573104488, 0.9524329083461094], 
             95 -> RGBColor[
              0.23333868649666736`, 0.36258413240817805`, 0.9365996650511086],
              166 -> RGBColor[
              0.30637808125608934`, 0.43935316726543017`, 0.9407591505305561],
              233 -> RGBColor[
              0.5758388832324651, 0.6665309725110049, 0.959751292736843], 295 -> 
             RGBColor[
              0.35417258064755563`, 0.48118822095058217`, 0.9437885415497143],
              141 -> RGBColor[
              0.521528067909048, 0.6224390059571068, 0.9554757464075119], 205 -> 
             RGBColor[
              0.5947544734653638, 0.6818875007997013, 0.9612403972900669], 
             224 -> RGBColor[
              0.36829612934450906`, 0.49342132896168533`, 0.9446884815837203],
              231 -> RGBColor[
              0.3819344959738617, 0.5052341966517925, 0.9455575062454086], 68 -> 
             RGBColor[
              0.8232457406137177, 0.8618978234277881, 0.9830031077315267], 10 -> 
             RGBColor[
              0.38498896020534, 0.5078798200472628, 0.9457521340052818], 250 -> 
             RGBColor[
              0.6581940718387977, 0.7329054784714722, 0.9665662919737316], 
             282 -> RGBColor[
              0.5784400626262978, 0.6686427271247146, 0.9599560671071596], 
             232 -> RGBColor[
              0.39130603264376246`, 0.5133513506881318, 0.9461546522750902], 
             253 -> RGBColor[
              0.30497550146223845`, 0.4378789669733977, 0.9406792756862272], 
             55 -> RGBColor[
              0.23197936833160687`, 0.36115540283095, 0.9365222538925394], 91 -> 
             RGBColor[
              0.7011039220017057, 0.766426979545676, 0.9708431448226218], 105 -> 
             RGBColor[
              0.20473528105347694`, 0.33252013972673355`, 0.9349707434260652],
              36 -> RGBColor[
              0.2028150975943005, 0.33050190516447603`, 0.934861391818722], 
             123 -> RGBColor[
              0.35167038450878835`, 0.4790209444192166, 0.9436291038243572], 
             94 -> RGBColor[
              0.2425740486271733, 0.37229108356311896`, 0.937125605261947], 
             96 -> RGBColor[
              0.31646737046914625`, 0.44852986301301057`, 0.9413859988985542],
              2 -> RGBColor[
              0.39434573068496603`, 0.5159841843517564, 0.9463483391463763], 
             262 -> RGBColor[
              0.9647788974982408, 0.973252739940226, 0.9445043187874416], 272 -> 
             RGBColor[
              0.4386792016056612, 0.5543836085982244, 0.9491732287108939], 97 -> 
             RGBColor[
              0.5548234999177242, 0.6494697376038688, 0.958096884780421], 209 -> 
             RGBColor[
              0.846465729093904, 0.3581615319938758, 0.19212894069684472`], 
             66 -> RGBColor[
              0.2739009772760844, 0.40521767181512075`, 0.9389096275044646], 
             139 -> RGBColor[
              0.2425740486271733, 0.37229108356311896`, 0.937125605261947], 
             56 -> RGBColor[
              0.3280313519840486, 0.4585460025786082, 0.9421228455750564], 
             144 -> RGBColor[
              0.7812578958045919, 0.8290438730732542, 0.9788321438498212], 
             298 -> RGBColor[
              0.222208972836997, 0.35088609768726126`, 0.9359658443231262], 
             204 -> RGBColor[
              0.42155672571927916`, 0.5395529805861013, 0.9480821996882246], 
             207 -> RGBColor[
              0.24686433731955648`, 0.3768004489988279, 0.9373699308560649], 
             149 -> RGBColor[
              0.3458901383915377, 0.4740143857560713, 0.9432607916530369], 
             219 -> RGBColor[
              0.42674129882234996`, 0.5440435972237604, 0.9484125561018143], 
             9 -> RGBColor[
              0.3769660014344934, 0.5009307364055882, 0.9452409181668273], 11 -> 
             RGBColor[
              0.20726228541883557`, 0.33517618153605616`, 0.9351146525863044],
              44 -> RGBColor[
              0.2793888484702789, 0.4109857723913496, 0.9392221536503961], 
             153 -> RGBColor[
              0.23393288958270148`, 0.3632086775262516, 0.9366335040378135], 
             32 -> RGBColor[
              0.7474227859438135, 0.8026116280936548, 0.9754597763059776], 
             162 -> 
             RGBColor[
              0.8352421579928921, 0.8714634410118668, 0.9841473367304805], 90 -> 
             RGBColor[
              0.20207143615372183`, 0.3297202698395692, 0.9348190413998295], 
             8 -> RGBColor[
              0.9290062075481781, 0.9462283489699287, 0.9930906354812189], 
             163 -> RGBColor[
              0.2890251187477218, 0.4211141034277659, 0.9397709249871121], 49 -> 
             RGBColor[
              0.638546264732138, 0.7174396497477833, 0.9646878475132044], 76 -> 
             RGBColor[
              0.7044033276028918, 0.7690045002777339, 0.9711719987382497], 82 -> 
             RGBColor[
              0.9385701984160136, 0.9537063350775071, 0.9888688100101685], 67 -> 
             RGBColor[
              0.3521223740010205, 0.4794124349997357, 0.9436579041951235], 
             211 -> RGBColor[
              0.8293603585659374, 0.8667734538060053, 
               0.9835863254503933]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9mHk4FFzYxsmSfR/LzGBWM2NmbHmlLHNH8aZCu0SWIkQLqbSgomQtVNoX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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 9}], {
             RGBColor[
             0.3368084458523525, 0.4650300046026655, 0.9427230597804136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 11}], {
             RGBColor[
             0.25195658784452357`, 0.3821527271678995, 0.9376599269901522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 20}], {
             RGBColor[
             0.26781537217936513`, 0.39882131500882, 0.9385630612970524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 37}], {
             RGBColor[
             0.2892387163703667, 0.42133860807203716`, 0.9397830890557324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 43}], {
             RGBColor[
             0.5368505247180984, 0.6274430150154673, 0.9593089786896096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 75}], {
             RGBColor[
             0.2976660857689978, 0.4301963076360795, 0.9402630152758087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 102}], {
             RGBColor[
             0.5752587856982547, 0.6577217015044872, 0.9630644808836264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 142}], {
             RGBColor[
             0.5132580484303313, 0.6090123932300028, 0.9569575011374709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 143}], {
             RGBColor[
             0.25840669925319487`, 0.38893220321909683`, 0.9380272512927912]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 174}], {
             RGBColor[
             0.2660232629922178, 0.396937694626843, 0.9384610033300322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 185}], {
             RGBColor[
             0.24856847964676043`, 0.3785916106335834, 0.9374669792405464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 237}], {
             RGBColor[
             0.4619685328575365, 0.5687137374014366, 0.9520033067157219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 239}], {
             RGBColor[
             0.5605948057505972, 0.6460290419373571, 0.9616658173855293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 283}], {
             RGBColor[
             0.37126132586255367`, 0.49487135761540246`, 0.9449183668291781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 295}], {
             RGBColor[
             0.3254117354588836, 0.45515874687516256`, 0.9419968714718571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 297}], {
             RGBColor[
             0.5232962453503284, 0.6168543089570268, 0.9579580147941726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 32}], {
             RGBColor[
             0.5708842583143898, 0.6592979062227056, 0.9609040577261769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 83}], {
             RGBColor[
             0.43861082921349714`, 0.5535218208311026, 0.9493906237462428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 155}], {
             RGBColor[
             0.6382333316130319, 0.7124137438489629, 0.9674835076212204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 156}], {
             RGBColor[
             0.6932635906743169, 0.7506362614684664, 0.6852375903471111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 178}], {
             RGBColor[
             0.5984587840946043, 0.6808393353363672, 0.9636524287573545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 184}], {
             RGBColor[
             0.3878875138277488, 0.5103904015094523, 0.9459368272790113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 202}], {
             RGBColor[
             0.30758590757859955`, 0.4327083893437321, 0.9411177150114646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 208}], {
             RGBColor[
             0.36415598183491016`, 0.489835341278735, 0.9444246750453974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 214}], {
             RGBColor[
             0.42814009101861455`, 0.5450212038631168, 0.948566328879964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 268}], {
             RGBColor[
             0.6909607296142334, 0.7525572215311755, 0.900957100185902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 275}], {
             RGBColor[
             0.6616759691165721, 0.7311062666608426, 0.9697194873137975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 17}], {
             RGBColor[
             0.2655018209502019, 0.3963896259793493, 0.9384313079771438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 30}], {
             RGBColor[
             0.3651413975797341, 0.4867101358889605, 0.9446897513210346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 38}], {
             RGBColor[
             0.6304808301174869, 0.6930394610014923, 0.6924116901245345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 55}], {
             RGBColor[
             0.25012319535452054`, 0.3802257154171086, 0.9375555180001076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 74}], {
             RGBColor[
             0.23268648961637092`, 0.3618986321353159, 0.9365625234036146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 90}], {
             RGBColor[
             0.23516922926557804`, 0.3645081489214182, 0.9367039117537527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[
             0.3099687034431113, 0.43915848621124187`, 0.9411089429660164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 144}], {
             RGBColor[
             0.5247624590910132, 0.6141699505382607, 0.9587104629787485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 157}], {
             RGBColor[
             0.27244420405209235`, 0.403686510791948, 0.9388266664244611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 229}], {
             RGBColor[
             0.36152700438065166`, 0.4837758086633873, 0.9444052130484442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 252}], {
             RGBColor[
             0.5598895664481394, 0.641866343761616, 0.9621439807172198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 257}], {
             RGBColor[
             0.6194366079102478, 0.6884473778589095, 0.936614504431365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 259}], {
             RGBColor[
             0.3562918293711673, 0.4792812496221175, 0.9440606115882203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 26}], {
             RGBColor[
             0.28403373430998136`, 0.4158678419116488, 0.9394866730274744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 39}], {
             RGBColor[
             0.6284015109092135, 0.6975968601267869, 0.9355591465488694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 52}], {
             RGBColor[
             0.26531630465231293`, 0.39619463658785536`, 0.9384207430984259]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 78}], {
             RGBColor[
             0.41417730657472884`, 0.5284501749703957, 0.948374313485165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 82}], {
             RGBColor[
             0.6114885560471186, 0.6849832060830585, 0.9641883675252974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 107}], {
             RGBColor[
             0.281368751323916, 0.41306677582361356`, 0.9393349061889069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 130}], {
             RGBColor[
             0.3452892887570681, 0.4712436451735167, 0.9433049010949595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 193}], {
             RGBColor[
             0.2677911941858747, 0.3987959024046883, 0.9385616843960913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 199}], {
             RGBColor[
             0.580060759142804, 0.6599975742177877, 0.9637577799295884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 220}], {
             RGBColor[
             0.6129774027154017, 0.6860935854905013, 0.9616681384692958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.6674820509897486, 0.44056858853767067`, 0.44921921081208926`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 228}], {
             RGBColor[
             0.29212639882546254`, 0.42437374542198536`, 0.9399475382996068]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 236}], {
             RGBColor[
             0.2613271339469591, 0.39200176524849734`, 0.9381935657282052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 266}], {
             RGBColor[
             0.34642322061652014`, 0.4722257999571017, 0.9433771542303471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 281}], {
             RGBColor[
             0.3533871886695544, 0.47825763906542834`, 0.9438208921166913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.7838747405675597, 0.8316723900350425, 0.9737721906739067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[
             0.7255961274674954, 0.7853534326934504, 0.973442784839772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 191}], {
             RGBColor[
             0.5008543733734092, 0.6035424225866477, 0.9544319956811633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 248}], {
             RGBColor[
             0.7541612609618186, 0.8081304947619308, 0.9761673527728563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 21}], {
             RGBColor[
             0.6661147562522106, 0.7285066333353468, 0.7680737398927586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 34}], {
             RGBColor[
             0.8008648388108556, 0.841029005957888, 0.7778179857180513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 46}], {
             RGBColor[
             0.6704603709959152, 0.7322705864093959, 0.7683506386215513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 50}], {
             RGBColor[
             0.8762281707414211, 0.41930947219155823`, 0.3072712600525943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 101}], {
             RGBColor[
             0.656826162639615, 0.7204613204064061, 0.7674818789213449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 108}], {
             RGBColor[
             0.9812902733619535, 0.9828638657710371, 0.7657628157492176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 114}], {
             RGBColor[
             0.8505507529060734, 0.8803752092366459, 0.7824070360900945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 145}], {
             RGBColor[
             0.5874261695467501, 0.6485215913693733, 0.7634928882842553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 169}], {
             RGBColor[
             0.7905447017646052, 0.8326506537868661, 0.7770055467258628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 187}], {
             RGBColor[
             0.6156812458982426, 0.6782194680901031, 0.7651019730828332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 205}], {
             RGBColor[
             0.7944004928448136, 0.835780958687188, 0.7773090887239249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 213}], {
             RGBColor[
             0.9323342032193225, 0.9446743494461005, 0.7904498338564663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 219}], {
             RGBColor[
             0.7103939055233066, 0.7668590068992176, 0.7708951681297986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 221}], {
             RGBColor[
             0.9615263598862207, 0.9679513827723016, 0.7932342078195009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 231}], {
             RGBColor[
             0.6879905040990625, 0.7474543066132335, 0.7694676432015958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 264}], {
             RGBColor[
             0.699629886020858, 0.7575357542215474, 0.7702092943253513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 9}], {
             RGBColor[
             0.43913282598892533`, 0.5534737009327049, 0.9495621047300888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 11}], {
             RGBColor[
             0.35428096798109643`, 0.47059642349793884`, 0.9444989719398273]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 43}], {
             RGBColor[
             0.6391749048546712, 0.7158867113455066, 0.9661480236392849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.48406484602837513`, 0.5920246747354636, 0.9525265043487618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 63}], {
             RGBColor[
             0.38656914278076426`, 0.5045333424009121, 0.9463377357285945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 106}], {
             RGBColor[
             0.6114976692593893, 0.694265044543691, 0.9633894154536191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 131}], {
             RGBColor[
             0.7192000824475907, 0.34692629235685657`, 0.4343544728176246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 143}], {
             RGBColor[
             0.36073107938976773`, 0.4773758995491362, 0.9448662962424665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 151}], {
             RGBColor[
             0.390765664005434, 0.5089441522828533, 0.9465767214041425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 167}], {
             RGBColor[
             0.6002330002775695, 0.6854649995204383, 0.9622666585238282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 174}], {
             RGBColor[
             0.36834764312879065`, 0.4853813909568823, 0.9453000482797076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 185}], {
             RGBColor[
             0.3508928597833333, 0.4670353069636227, 0.9443060241902217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[
             0.3807597680731938, 0.498427321247625, 0.9460069004331979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 283}], {
             RGBColor[
             0.4735857059991266, 0.5833150539454418, 0.9517574117788532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 297}], {
             RGBColor[
             0.6256206254869012, 0.7052980052870661, 0.9647970597438479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 22}], {
             RGBColor[
             0.691878504487605, 0.757227280857681, 0.9716547154290397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 47}], {
             RGBColor[
             0.6264227420113265, 0.7005716932209929, 0.967473182855856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 61}], {
             RGBColor[
             0.9514523784551627, 0.9631412551690983, 0.9610788812246047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 72}], {
             RGBColor[
             0.7626961726440618, 0.8147202541666865, 0.977229741679982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 177}], {
             RGBColor[
             0.6298045686813942, 0.7035008615070548, 0.9676886698608409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 217}], {
             RGBColor[
             0.611694275221674, 0.6864866173221458, 0.9665833232291126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 247}], {
             RGBColor[
             0.620327734945703, 0.6952925044447122, 0.9670848143952376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 267}], {
             RGBColor[
             0.7204607421374272, 0.7804316289969392, 0.9739048138770201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 271}], {
             RGBColor[
             0.6742273892793833, 0.7419776759531493, 0.9705192527077868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 273}], {
             RGBColor[
             0.8889112344216923, 0.9142577057479211, 0.9892663411512096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 285}], {
             RGBColor[
             0.9619664209049661, 0.9688926287944042, 0.8411321339681394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.2921141434266645, 0.41805345897082213`, 0.9401777853765658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 20}], {
             RGBColor[
             0.307972927761506, 0.43472204681174265`, 0.9410809196834662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 37}], {
             RGBColor[
             0.3293962719525076, 0.4572393398749598, 0.9423009474421461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 43}], {
             RGBColor[
             0.5770080803002392, 0.6633437468183899, 0.9618268370760233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 63}], {
             RGBColor[
             0.3244023182263323, 0.45199037787379537`, 0.942016549165333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 75}], {
             RGBColor[
             0.3378236413511387, 0.46609703943900216`, 0.9427808736622223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.5493308447049573, 0.6417220800165743, 0.9590682288903576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 131}], {
             RGBColor[
             0.6777555327446361, 0.3118976493387788, 0.4314736817754503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 142}], {
             RGBColor[
             0.5534156040124721, 0.6449131250329254, 0.9594753595238847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 143}], {
             RGBColor[
             0.2985642548353358, 0.42483293502201946`, 0.940545109679205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 167}], {
             RGBColor[
             0.5380661757231376, 0.6329220349933216, 0.9579454719605667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 174}], {
             RGBColor[
             0.3061808185743587, 0.4328384264297656, 0.9409788617164461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 185}], {
             RGBColor[
             0.28872603522890133`, 0.414492342436506, 0.9399848376269602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 237}], {
             RGBColor[
             0.5021260884396773, 0.6046144692043592, 0.9545211651021356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 239}], {
             RGBColor[
             0.600752361332738, 0.6819297737402797, 0.9641836757719431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 282}], {
             RGBColor[
             0.47770303203039555`, 0.5847867317651514, 0.9525984926369935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 283}], {
             RGBColor[
             0.41141888144469463`, 0.5307720894183251, 0.9474362252155917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 295}], {
             RGBColor[
             0.36556929104102454`, 0.4910594786780852, 0.9445147298582708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 297}], {
             RGBColor[
             0.5634538009324692, 0.6527550407599494, 0.9604758731805864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 117}], {
             RGBColor[
             0.6662271191462967, 0.6686520921805924, 0.611169833743558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.5142087229014761, 0.6146251551622546, 0.9554233651673703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 161}], {
             RGBColor[
             0.6074511987983996, 0.6875471419479072, 0.9646956063038963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 265}], {
             RGBColor[
             0.6862823443744204, 0.7485050393789288, 0.9006589976153547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 269}], {
             RGBColor[
             0.5139928500831604, 0.6144565136758922, 0.9554018489822867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 43}], {
             RGBColor[
             0.49215622229241035`, 0.5804664693836239, 0.956763704285762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 63}], {
             RGBColor[
             0.2395504602185034, 0.36911310043902934`, 0.9369534163750715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 131}], {
             RGBColor[
             0.6211876274060835, 0.25664613104893474`, 0.42809825991527595`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 139}], {
             RGBColor[
             0.22491816702300443`, 0.35373363254958756`, 0.9361201289241257]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 143}], {
             RGBColor[
             0.21371239682750687`, 0.34195565758725344`, 0.9354819768889435]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 172}], {
             RGBColor[
             0.2361475500098006, 0.36553642605271397`, 0.9367596256728403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 174}], {
             RGBColor[
             0.2213289605665298, 0.34996114899499964`, 0.9359157289261846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 183}], {
             RGBColor[
             0.22800881920909558`, 0.35698210395583596`, 0.9362961369939133]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 185}], {
             RGBColor[
             0.20387417722107243`, 0.33161506500174, 0.9349217048366987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 283}], {
             RGBColor[
             0.3265670234368657, 0.44789481198355907`, 0.9423730924253303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 248}], {
             RGBColor[
             0.6522441981009914, 0.7245492521942082, 0.9683762676445103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 58}], {
             RGBColor[
             0.6360856306449754, 0.700516369074039, 0.8381248805104928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 73}], {
             RGBColor[
             0.9692194019060297, 0.9748150893872274, 0.8586472745069169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 95}], {
             RGBColor[
             0.614030210509889, 0.6773347241176592, 0.8368688569618699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 96}], {
             RGBColor[
             0.6555945524961285, 0.7203075894200754, 0.8392620238855927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 105}], {
             RGBColor[
             0.5997285077882939, 0.6623027277769369, 0.8360543961493482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[
             0.6143273120529061, 0.6776469966766959, 0.8368857764552223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 149}], {
             RGBColor[
             0.6703059364573243, 0.7330498507916058, 0.840199420262834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 171}], {
             RGBColor[
             0.9096870321965017, 0.6571820182947037, 0.38629632608827125`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 245}], {
             RGBColor[
             0.6183127844333249, 0.6818359808420599, 0.8371127432113091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 289}], {
             RGBColor[
             0.7596484238100623, 0.8084990251678296, 0.846426834919517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 298}], {
             RGBColor[
             0.6084653536800539, 0.6714857067572008, 0.8365519465978787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 69}], {
             RGBColor[
             0.4992902319682852, 0.6043853289373028, 0.9537251025023779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 113}], {
             RGBColor[
             0.46398769357839154`, 0.5757251379111563, 0.9509459573628665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 135}], {
             RGBColor[
             0.3546481736049564, 0.47425954444336466`, 0.9442215758559809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 224}], {
             RGBColor[
             0.42109842042009893`, 0.5385971506972358, 0.9482074140148087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 249}], {
             RGBColor[
             0.4080853179445528, 0.5273258553904656, 0.9473782306321017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 254}], {
             RGBColor[
             0.7193398044969648, 0.7785128561865061, 0.9481153326166694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 288}], {
             RGBColor[
             0.32775486083339334`, 0.4459929675859383, 0.9426900414787314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 19}], {
             RGBColor[
             0.30614517689669285`, 0.436776587158467, 0.9408312649648007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 49}], {
             RGBColor[
             0.48625624885849617`, 0.5905630739767485, 0.9535944292288114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 57}], {
             RGBColor[
             0.4573323621027874, 0.5670813597022146, 0.9513174349117137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 89}], {
             RGBColor[
             0.6614635219707092, 0.7266947620445523, 0.8875562360534994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 111}], {
             RGBColor[
             0.26839066528957733`, 0.3970942016850948, 0.9386812013815702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.6065422983813058, 0.6850678173612766, 0.9654166496757054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 115}], {
             RGBColor[
             0.4091130934159726, 0.5279347851289589, 0.9475214374476866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 146}], {
             RGBColor[
             0.2880413226515224, 0.41774828849613693`, 0.9398002772477906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 175}], {
             RGBColor[
             0.5794044725861347, 0.6634288517088648, 0.9628282196251389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 212}], {
             RGBColor[
             0.5205992322181552, 0.6174504798352057, 0.9569774841903418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 242}], {
             RGBColor[
             0.29835142625391187`, 0.4285848610805725, 0.9403874223955152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 243}], {
             RGBColor[
             0.4758569869426713, 0.5821204846720713, 0.9527757612370462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 280}], {
             RGBColor[
             0.2713417371915744, 0.4001959653628592, 0.9388492605606693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 294}], {
             RGBColor[
             0.36157909196160376`, 0.487603368788728, 0.9442604779013246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.5884403250415344, 0.6615710610271717, 0.965330880215026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 44}], {
             RGBColor[
             0.6060666566539578, 0.6800974531258008, 0.9663346737245326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 53}], {
             RGBColor[
             0.8884592309294101, 0.9138972904324834, 0.9892232286546074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 59}], {
             RGBColor[
             0.5642507871936038, 0.6361463230437143, 0.9639533218198006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 94}], {
             RGBColor[
             0.5876592567324049, 0.6607501087116855, 0.965286399530308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 124}], {
             RGBColor[
             0.7583198565221203, 0.8111403131961845, 0.9769163565488568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 125}], {
             RGBColor[
             0.9622177703041942, 0.9700205972044573, 0.890405550645661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 150}], {
             RGBColor[
             0.9521979820780742, 0.9637937244925916, 0.9631589951830111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 170}], {
             RGBColor[
             0.9097516782064778, 0.9308753099231326, 0.9912541212838862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 192}], {
             RGBColor[
             0.8046735454166607, 0.848247757374639, 0.9809241392065199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 195}], {
             RGBColor[
             0.9308753361929074, 0.9477187414150903, 0.993268914639944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 200}], {
             RGBColor[
             0.6191249974232443, 0.6938225972209457, 0.9670783269132595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 295}], {
             RGBColor[
             0.6434585227425962, 0.7151986774054171, 0.9686178676741917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 30}], {
             RGBColor[
             0.3623761961525018, 0.4838037338650426, 0.9445322771905026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 38}], {
             RGBColor[
             0.6277156286902545, 0.6901330589775743, 0.6922542159940026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[
             0.4261076694111175, 0.5355438149265386, 0.9495494522214996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 48}], {
             RGBColor[
             0.2232586472686935, 0.35198937206817715`, 0.9360256217291572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 55}], {
             RGBColor[
             0.24735799392728822`, 0.3773193133931907, 0.9373980438695757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 84}], {
             RGBColor[
             0.39237789864977984`, 0.5081604675136281, 0.9468941211109456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 90}], {
             RGBColor[
             0.23240402783834568`, 0.3616017468975003, 0.9365464376232207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 97}], {
             RGBColor[
             0.40878005972034687`, 0.5214764807796501, 0.9481853593135164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 134}], {
             RGBColor[
             0.4866741954142006, 0.5836689038197546, 0.9550323161159628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 144}], {
             RGBColor[
             0.5219972576637808, 0.6112635485143428, 0.9585529888482165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 158}], {
             RGBColor[
             0.3494950828464679, 0.4728829258661219, 0.9436462509690331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 159}], {
             RGBColor[
             0.22094801649052392`, 0.349560752617868, 0.9358940347246123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 175}], {
             RGBColor[
             0.5437896658551924, 0.6283272145837236, 0.9607146310762356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 235}], {
             RGBColor[
             0.22083180976148478`, 0.3494386119777157, 0.935887416923306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 252}], {
             RGBColor[
             0.557124365020907, 0.6389599417376981, 0.9619865065866879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 253}], {
             RGBColor[
             0.28385606049260403`, 0.41568109546441456`, 0.9394765547664196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 292}], {
             RGBColor[
             0.31284667939834643`, 0.4411399208016751, 0.9413110471082295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 24}], {
             RGBColor[
             0.4680242373596165, 0.5754542075154042, 0.9522440459013393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 36}], {
             RGBColor[
             0.40810744773968555`, 0.5137632601451941, 0.948784808673591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 66}], {
             RGBColor[
             0.4436503875805775, 0.5511211434705164, 0.9508089265164623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 69}], {
             RGBColor[
             0.5690397751629761, 0.6610111502838658, 0.9592160420436593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 88}], {
             RGBColor[
             0.4591953703454862, 0.567459905965269, 0.9516941902881827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 113}], {
             RGBColor[
             0.5337372367730824, 0.6323509592577192, 0.9564368969041479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 135}], {
             RGBColor[
             0.4243977167996473, 0.5308853657899276, 0.9497125153972623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.40837206749129507`, 0.5140413922819971, 0.9487998783769753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 222}], {
             RGBColor[
             0.7819364895859959, 0.8298040876695982, 0.965714195166657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.49084796361478983`, 0.5952229720437987, 0.9536983535560901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 254}], {
             RGBColor[
             0.7890893476916556, 0.8351386775330691, 0.9536062721579508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 258}], {
             RGBColor[
             0.4031954975869899, 0.5086004890990836, 0.9485050803789741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 260}], {
             RGBColor[
             0.43586890387244837`, 0.5429423107187097, 0.9503657825309579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 278}], {
             RGBColor[
             0.5823413249886273, 0.6718099476603203, 0.960263188771117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 288}], {
             RGBColor[
             0.39750440402808424`, 0.5026187889325012, 0.9481809810200128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 290}], {
             RGBColor[
             0.48621761291094573`, 0.5912123949923223, 0.9534033117036995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 48}], {
             RGBColor[
             0.23105239791147447`, 0.36018109814607163`, 0.9364694642984428]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 49}], {
             RGBColor[
             0.4584351927703348, 0.5636531629295018, 0.9519246832491937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 57}], {
             RGBColor[
             0.429511306014626, 0.540171448654968, 0.9496476889320961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 84}], {
             RGBColor[
             0.4001716492925608, 0.5163521935915226, 0.9473379636802313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 89}], {
             RGBColor[
             0.6336424658825479, 0.6997848509973057, 0.8858864900738816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 111}], {
             RGBColor[
             0.240569609201416, 0.3701842906378482, 0.9370114554019525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 112}], {
             RGBColor[
             0.5787212422931444, 0.65815790631403, 0.9637469036960877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 158}], {
             RGBColor[
             0.3572888334892489, 0.48107465194401644`, 0.9440900935383187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 175}], {
             RGBColor[
             0.5515834164979734, 0.6365189406616182, 0.9611584736455212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 177}], {
             RGBColor[
             0.30446352531157095`, 0.4353200250777006, 0.9407241116128229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 242}], {
             RGBColor[
             0.27053037016575054`, 0.4016749500333259, 0.9387176764158975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 253}], {
             RGBColor[
             0.291649811135385, 0.423872821542309, 0.9399203973357051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 280}], {
             RGBColor[
             0.24352068110341304`, 0.37328605431561257`, 0.9371795145810515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 33}], {
             RGBColor[
             0.2415580196669755, 0.37122317270599425`, 0.9370677439157439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 37}], {
             RGBColor[
             0.2604031982795202, 0.3910306502811143, 0.9381409489587849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 75}], {
             RGBColor[
             0.2688305676781513, 0.39988834984515664`, 0.9386208751788612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 124}], {
             RGBColor[
             0.41143755114756136`, 0.5207924248750071, 0.9486532202495748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 142}], {
             RGBColor[
             0.4844225303394848, 0.5787044354390799, 0.9553153610405235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 150}], {
             RGBColor[
             0.605315676703515, 0.6734458361714142, 0.9348958588837291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 167}], {
             RGBColor[
             0.46907310205015024`, 0.5667133453994759, 0.9537854734772054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 185}], {
             RGBColor[
             0.21973296155591393`, 0.3482836528426605, 0.935824839143599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 200}], {
             RGBColor[
             0.27224269204868534`, 0.4034747088997683, 0.9388151906139774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 237}], {
             RGBColor[
             0.43313301476668997`, 0.5384057796105137, 0.9503611666187743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 282}], {
             RGBColor[
             0.4087099583574082, 0.5185780421713059, 0.9484384941536323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 283}], {
             RGBColor[
             0.3424258077717072, 0.4645633998244796, 0.9432762267322305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 295}], {
             RGBColor[
             0.29657621736803713`, 0.4248507890842397, 0.9403547313749097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 297}], {
             RGBColor[
             0.49446072725948187`, 0.5865463511661039, 0.9563158746972251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 34}], {
             RGBColor[
             0.47293308283880287`, 0.5798612227185601, 0.9525139454530269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 46}], {
             RGBColor[
             0.34252861502386245`, 0.47110280317006803`, 0.943046598356527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 50}], {
             RGBColor[
             0.657607000093386, 0.24519761669867296`, 0.4237352332092448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[
             0.28016012338224705`, 0.40907477941946013`, 0.9393657296205931]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 101}], {
             RGBColor[
             0.3288944066675623, 0.4592935371670781, 0.9421778386563207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 108}], {
             RGBColor[
             0.6533585173899008, 0.7216960825317094, 0.9404587754841933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[
             0.5226189969340207, 0.619207425997318, 0.9571029958250703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 169}], {
             RGBColor[
             0.4626129457925524, 0.5714828705475382, 0.9517015064608385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 187}], {
             RGBColor[
             0.28774948992618976`, 0.41705168485077526`, 0.939797932817809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 205}], {
             RGBColor[
             0.4664687368727608, 0.5746131754478601, 0.9520050484589007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 213}], {
             RGBColor[
             0.6044024472472698, 0.6835065662067726, 0.965145793591442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 264}], {
             RGBColor[
             0.37169813004880525`, 0.4963679709822195, 0.944905254060327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 61}], {
             RGBColor[
             0.7143246753945895, 0.7741401870568507, 0.9396429611724255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 72}], {
             RGBColor[
             0.5255684695834887, 0.6257191860544389, 0.9557938216278028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 177}], {
             RGBColor[
             0.39267686562082116`, 0.5144997933948071, 0.9462527498086617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 217}], {
             RGBColor[
             0.3745665721611009, 0.4974855492098981, 0.9451474031769334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 247}], {
             RGBColor[
             0.3832000318851301, 0.5062914363324647, 0.9456488943430584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 267}], {
             RGBColor[
             0.4833330390768541, 0.5914305608846915, 0.9524688938248409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 271}], {
             RGBColor[
             0.43709968621881023`, 0.5529766078409017, 0.9490833326556076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 273}], {
             RGBColor[
             0.6517835313611192, 0.7252566376356735, 0.9678304210990304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 274}], {
             RGBColor[
             0.49403153741273065`, 0.6001160837956137, 0.9533111188037318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 285}], {
             RGBColor[
             0.7248387178443931, 0.7798915606821565, 0.8196962139159601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[
             0.6072942706481252, 0.67462184983432, 0.9298292922581302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 180}], {
             RGBColor[
             0.6081546479248325, 0.6755261609032095, 0.9298782894712244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 267}], {
             RGBColor[
             0.7447434846651255, 0.7987142473037271, 0.9387842229211317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 285}], {
             RGBColor[
             0.9862491634326644, 0.9871752471011921, 0.806011543012251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.25987731684473503`, 0.3891925180861304, 0.9381580654868857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 113}], {
             RGBColor[
             0.38836167624762835`, 0.5107805516472113, 0.945972717277027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 135}], {
             RGBColor[
             0.27902215627419324`, 0.40931495817941965`, 0.9392483357701416]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 224}], {
             RGBColor[
             0.3454724030893358, 0.4736525644332908, 0.9432341739289694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 233}], {
             RGBColor[
             0.4492437800333138, 0.5602073862079506, 0.9507655795055308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 254}], {
             RGBColor[
             0.6437137871662015, 0.7135682699225612, 0.94314209253083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 259}], {
             RGBColor[
             0.3834826565995315, 0.506575135572932, 0.9456561536714916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 260}], {
             RGBColor[
             0.2904933433469943, 0.4213719031082017, 0.9399016029038371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 288}], {
             RGBColor[
             0.2521288435026302, 0.38104838132199326`, 0.937716801392892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 29}], {
             RGBColor[
             0.879749191168204, 0.5696336045478863, 0.4575507631872979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[
             0.8249166136393391, 0.5262434923274859, 0.4557455645496493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 77}], {
             RGBColor[
             0.8408967824348278, 0.5387542996534915, 0.4573311592978748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 91}], {
             RGBColor[
             0.799601201251246, 0.5064668997656473, 0.4532223608287834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 139}], {
             RGBColor[
             0.6467579101264018, 0.37508826777146165`, 0.44198318097522515`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 147}], {
             RGBColor[
             0.6779840950627961, 0.40621351904191677`, 0.44382354470385293`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 148}], {
             RGBColor[
             0.835908799836823, 0.5348306717286696, 0.45684116294199417`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 172}], {
             RGBColor[
             0.6542441654509327, 0.38295679677354594`, 0.4424095121410349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 203}], {
             RGBColor[
             0.8823220080486189, 0.5715524071646987, 0.45319565530686706`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 206}], {
             RGBColor[
             0.8404200360222602, 0.5383741550050467, 0.4572856867994476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 244}], {
             RGBColor[
             0.7203885120004778, 0.44275840166218466`, 0.44657627130768546`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 270}], {
             RGBColor[
             0.6264631588002338, 0.3537571973661052, 0.44082742491059396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 272}], {
             RGBColor[
             0.7121262944525645, 0.4357857761164968, 0.4459990554582075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 39}], {
             RGBColor[
             0.6280283315409714, 0.6972046249498258, 0.9355378945359174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 59}], {
             RGBColor[
             0.23970883224565503`, 0.3692795594809322, 0.9369624354277273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 60}], {
             RGBColor[
             0.3861894456766174, 0.5056390973002607, 0.9461791325862702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 62}], {
             RGBColor[
             0.639328319378579, 0.7035905304632146, 0.8180991043965136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 82}], {
             RGBColor[
             0.6111153766788764, 0.6845909709060974, 0.9641671155123455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[
             0.39390057217607233`, 0.5118993371748083, 0.9467861807110943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 127}], {
             RGBColor[
             0.2808524291483715, 0.41252408848039956`, 0.9393055024048399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 130}], {
             RGBColor[
             0.34491610938882594`, 0.47085140999655567`, 0.9432836490820073]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 137}], {
             RGBColor[
             0.26130190647771573`, 0.3919752495788086, 0.9381921290611525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 170}], {
             RGBColor[
             0.5852097232585292, 0.6640085463603504, 0.9642632348918129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 192}], {
             RGBColor[
             0.480131590468712, 0.5813809938118568, 0.9539332528144465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 195}], {
             RGBColor[
             0.6063333812449587, 0.6808519778523082, 0.9662780282478707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 199}], {
             RGBColor[
             0.5796875797745618, 0.6596053390408267, 0.9637365279166363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 220}], {
             RGBColor[
             0.6126042233471596, 0.6857013503135403, 0.9616468864563438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 226}], {
             RGBColor[
             0.6672332647442538, 0.4403070984196967, 0.4492050428034546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 228}], {
             RGBColor[
             0.29175321945722044`, 0.4239815102450243, 0.9399262862866548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 266}], {
             RGBColor[
             0.346050041248278, 0.47183356478014066`, 0.9433559022173952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 32}], {
             RGBColor[
             0.4791409611600342, 0.5707841640197405, 0.9553896321166214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 103}], {
             RGBColor[
             0.22948186939702753`, 0.3585303731001287, 0.9363800250229337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 119}], {
             RGBColor[
             0.21309140870023396`, 0.3413029596925683, 0.9354466125337649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 152}], {
             RGBColor[
             0.27502989640810704`, 0.40358849632928967`, 0.9390770158528121]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 268}], {
             RGBColor[
             0.5992174324598778, 0.6640434793282104, 0.8954426745763464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 35}], {
             RGBColor[
             0.9132752812007847, 0.9316407730038028, 0.9137710366642793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 126}], {
             RGBColor[
             0.9595539113698628, 0.9685420965006742, 0.9181851337232269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 163}], {
             RGBColor[
             0.6386762088035556, 0.7052775778892284, 0.8914406605383174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 184}], {
             RGBColor[
             0.6848782979149605, 0.7471188355089193, 0.8943178557505845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 189}], {
             RGBColor[
             0.5930804327413137, 0.6573535263086372, 0.8888440485444786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 197}], {
             RGBColor[
             0.5986058757732516, 0.6631611172685263, 0.8891587143509871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 211}], {
             RGBColor[
             0.9088438287126634, 0.9281072530783481, 0.913348360769958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 216}], {
             RGBColor[
             0.6936432292238985, 0.7547105784704649, 0.8948763494230656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 275}], {
             RGBColor[
             0.9586667532037838, 0.9678347006603097, 0.9181005157853708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 293}], {
             RGBColor[
             0.7755098554583741, 0.8226495636599835, 0.9009133752291754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 77}], {
             RGBColor[
             0.8832692786525156, 0.9096081365508006, 0.9834989460640305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 91}], {
             RGBColor[
             0.8213259068771428, 0.8611770367190343, 0.9773357483603935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 148}], {
             RGBColor[
             0.8757873047555084, 0.9037226946635679, 0.9827639515302096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 162}], {
             RGBColor[
             0.888395024872736, 0.9136952674521298, 0.9839878443143228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 172}], {
             RGBColor[
             0.6032903531766728, 0.6759118822308823, 0.9611164753287706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 191}], {
             RGBColor[
             0.6585275245584294, 0.7277971264439981, 0.9644881569054218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 203}], {
             RGBColor[
             0.9454071170732021, 0.9588052978176114, 0.9772956900775189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 206}], {
             RGBColor[
             0.8825541590336643, 0.9090379195781335, 0.9834307373163897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 244}], {
             RGBColor[
             0.7025068730009905, 0.7656142895638405, 0.9673666140787465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 270}], {
             RGBColor[
             0.5616188432006246, 0.6321124831197212, 0.9587433444831093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 272}], {
             RGBColor[
             0.6901135466791206, 0.7551553512453086, 0.9665007903045295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 38}], {
             RGBColor[
             0.7273552053197867, 0.7804535688871854, 0.6985126593378933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 47}], {
             RGBColor[
             0.3929275246282545, 0.5145196406233554, 0.9463232253824432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 48}], {
             RGBColor[
             0.3228982238982257, 0.4423098819777883, 0.9422840650730478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 74}], {
             RGBColor[
             0.3295608648186708, 0.4493127400210092, 0.9426634926169732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 90}], {
             RGBColor[
             0.3320436044678779, 0.4519222568071115, 0.9428048809671115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 123}], {
             RGBColor[
             0.40684307864541114`, 0.5265725940969352, 0.9472099121793752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 144}], {
             RGBColor[
             0.621636834293313, 0.701584058423954, 0.9648114321921073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 158}], {
             RGBColor[
             0.4491346594760001, 0.5632034357757332, 0.9499046943129238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 252}], {
             RGBColor[
             0.6567639416504392, 0.7292804516473093, 0.9682449499305785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 257}], {
             RGBColor[
             0.7163109831125478, 0.7758614857446029, 0.9427154736447237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 259}], {
             RGBColor[
             0.45316620457346724`, 0.5666953575078109, 0.9501615808015791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 36}], {
             RGBColor[
             0.5358424017433815, 0.6143895200379945, 0.961108077043765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 51}], {
             RGBColor[
             0.6917122652383301, 0.7575274738982372, 0.9711407747089777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 58}], {
             RGBColor[
             0.5731596163296513, 0.6536122786162253, 0.9632332372085812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 66}], {
             RGBColor[
             0.5713853415842735, 0.6517474033633168, 0.9631321948866363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 67}], {
             RGBColor[
             0.6104960399467415, 0.6888447849556243, 0.9655063332319658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 73}], {
             RGBColor[
             0.9062933875907055, 0.9279109989294136, 0.9837556312050053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 95}], {
             RGBColor[
             0.5511041961945649, 0.6304306336598455, 0.9619772136599583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 96}], {
             RGBColor[
             0.5926685381808043, 0.6734034989622617, 0.9643703805836811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 109}], {
             RGBColor[
             0.931599578424489, 0.9442783644124906, 0.8057643386683988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 110}], {
             RGBColor[
             0.790883671016618, 0.8369587267890881, 0.9796866971491436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 138}], {
             RGBColor[
             0.7347924961402903, 0.7925019460867341, 0.9745322082936656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 154}], {
             RGBColor[
             0.6014179694386583, 0.6809818165586132, 0.9649278866066132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 171}], {
             RGBColor[
             0.8677363559862856, 0.6259126246561613, 0.4697018972203302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 245}], {
             RGBColor[
             0.5553867701180007, 0.6349318903842462, 0.9622210999093975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 156}], {
             RGBColor[
             0.8698021183037405, 0.8939499833394156, 0.6997933089269117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 178}], {
             RGBColor[
             0.7749973117240281, 0.8241530572073164, 0.9782081473371551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 182}], {
             RGBColor[
             0.6145437248048833, 0.6963438633301604, 0.9638986647535059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 202}], {
             RGBColor[
             0.4841244352080233, 0.5760221112146813, 0.9556734335912652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 208}], {
             RGBColor[
             0.5406945094643338, 0.6331490631496842, 0.958980393625198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 268}], {
             RGBColor[
             0.8674992572436571, 0.8958709434021248, 0.9155128187657027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 37}], {
             RGBColor[
             0.2629813638579771, 0.3937404657692114, 0.9382877716744238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 75}], {
             RGBColor[
             0.2714087332566082, 0.40259816533325377`, 0.9387676978945001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 94}], {
             RGBColor[
             0.24335511693630282`, 0.3731120358786052, 0.937170085946665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 124}], {
             RGBColor[
             0.4140157167260182, 0.5235022403631042, 0.9488000429652137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 142}], {
             RGBColor[
             0.48700069591794165`, 0.581414250927177, 0.9554621837561624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 150}], {
             RGBColor[
             0.607893842281972, 0.6761556516595113, 0.935042681599368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 185}], {
             RGBColor[
             0.2223111271343708, 0.3509934683307576, 0.935971661859238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 200}], {
             RGBColor[
             0.2748208576271422, 0.4061845243878654, 0.9389620133296164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 237}], {
             RGBColor[
             0.43571118034514683`, 0.5411155950986108, 0.9505079893344133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 239}], {
             RGBColor[
             0.5343374532382075, 0.6184308996345314, 0.9601705000042208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 282}], {
             RGBColor[
             0.41128812393586506`, 0.521287857659403, 0.9485853168692713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 295}], {
             RGBColor[
             0.299154382946494, 0.4275606045723368, 0.9405015540905486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 297}], {
             RGBColor[
             0.49703889283793873`, 0.589256166654201, 0.956462697412864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 46}], {
             RGBColor[
             0.4772786975825074, 0.5836251757926092, 0.9527908441818196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 50}], {
             RGBColor[
             0.747440388465816, 0.3202125317803671, 0.43023139709277325`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 87}], {
             RGBColor[
             0.414910205940892, 0.5215971520420013, 0.9491099754458857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 108}], {
             RGBColor[
             0.7881085999485458, 0.8342184551542504, 0.9502030213094859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 114}], {
             RGBColor[
             0.6573690794926657, 0.7317297986198592, 0.9668472416503628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 169}], {
             RGBColor[
             0.5973630283511975, 0.6840052431700794, 0.961445752286131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 187}], {
             RGBColor[
             0.4224995724848348, 0.5295740574733164, 0.9495421786431015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 205}], {
             RGBColor[
             0.6012188194314059, 0.6871355480704013, 0.9617492942841932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 213}], {
             RGBColor[
             0.7391525298059147, 0.7960289388293138, 0.9748900394167346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 227}], {
             RGBColor[
             0.4335870374388439, 0.5412276861258607, 0.9501735933697979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 264}], {
             RGBColor[
             0.5064482126074502, 0.6088903436047607, 0.9546494998856196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 92}], {
             RGBColor[
             0.8298660624811528, 0.42358060830965266`, 0.4429649914895173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 126}], {
             RGBColor[
             0.8845018937112581, 0.9107418171537862, 0.9888457742979835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 163}], {
             RGBColor[
             0.563624191144951, 0.6474772985423403, 0.962101301113074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 184}], {
             RGBColor[
             0.6098262802563559, 0.6893185561620313, 0.9649784963253412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 189}], {
             RGBColor[
             0.5180284150827091, 0.599553246961749, 0.9595046891192353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 197}], {
             RGBColor[
             0.523553858114647, 0.6053608379216382, 0.9598193549257437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 211}], {
             RGBColor[
             0.8337918110540588, 0.8703069737314599, 0.9840090013447146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 216}], {
             RGBColor[
             0.618591211565294, 0.6969102991235767, 0.9655369899978222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 275}], {
             RGBColor[
             0.8836147355451791, 0.9100344213134217, 0.9887611563601274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 58}], {
             RGBColor[
             0.2401323121805703, 0.36972466374270685`, 0.9369865519835383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 66}], {
             RGBColor[
             0.23835803743519246`, 0.3678597884897984, 0.9368855096615933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 67}], {
             RGBColor[
             0.2774687357976605, 0.40495717008210586`, 0.9392596480069227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 69}], {
             RGBColor[
             0.36374742501759105`, 0.47774979530314765`, 0.9452926251887903]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 88}], {
             RGBColor[
             0.25390302020010114`, 0.3841985509845508, 0.9377707734333136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 95}], {
             RGBColor[
             0.21807689204548392`, 0.34654301878632704`, 0.9357305284349153]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 96}], {
             RGBColor[
             0.25964123403172334`, 0.38951588408874327`, 0.938123695358638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 109}], {
             RGBColor[
             0.598572274275408, 0.660390749538972, 0.7795176534433559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 113}], {
             RGBColor[
             0.32844488662769733`, 0.4490896042770012, 0.9425134800492788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 138}], {
             RGBColor[
             0.4017651919912093, 0.5086143312132156, 0.9482855230686227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 154}], {
             RGBColor[
             0.26839066528957733`, 0.3970942016850948, 0.9386812013815702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 198}], {
             RGBColor[
             0.20307971734591004`, 0.3307800373012789, 0.9348764615221064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 222}], {
             RGBColor[
             0.5766441394406108, 0.6465427326888802, 0.9517907783117879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 224}], {
             RGBColor[
             0.2855556134694048, 0.41196161706308065`, 0.9397749367012211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 245}], {
             RGBColor[
             0.22235946596891976`, 0.3510442755107277, 0.9359744146843545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 258}], {
             RGBColor[
             0.19790314744160487`, 0.32533913411836557`, 0.934581663524105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 260}], {
             RGBColor[
             0.23057655372706332`, 0.35968095573799164`, 0.9364423656760889]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 278}], {
             RGBColor[
             0.37704897484324223`, 0.48854859267960227`, 0.9463397719162481]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 290}], {
             RGBColor[
             0.2809252627655607, 0.40795104001160415`, 0.9394798948488305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 75}], {
             RGBColor[
             0.2902539118691529, 0.4224056429083738, 0.9398409029375412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 94}], {
             RGBColor[
             0.26220029554884755`, 0.3929195134537252, 0.9382432909897059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 102}], {
             RGBColor[
             0.5678466117984098, 0.6499310367767814, 0.9626423685453589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 124}], {
             RGBColor[
             0.432860895338563, 0.5433097179382242, 0.9498732480082547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 142}], {
             RGBColor[
             0.5058458745304864, 0.601221728502297, 0.9565353887992034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 150}], {
             RGBColor[
             0.6267390208945167, 0.6959631292346313, 0.9361158866424091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 185}], {
             RGBColor[
             0.24115630574691554`, 0.37080094590587764`, 0.937044866902279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 237}], {
             RGBColor[
             0.45455635895769153`, 0.5609230726737309, 0.9515811943774544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 239}], {
             RGBColor[
             0.5531826318507522, 0.6382383772096514, 0.9612437050472618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 282}], {
             RGBColor[
             0.43013330254840976`, 0.541095335234523, 0.9496585219123123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 283}], {
             RGBColor[
             0.36384915196270884`, 0.48708069288769673`, 0.9444962544909106]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 295}], {
             RGBColor[
             0.31799956155903875`, 0.4473680821474568, 0.9415747591335896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 297}], {
             RGBColor[
             0.5158840714504834, 0.609063644229321, 0.9575359024559051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 48}], {
             RGBColor[
             0.5882376564359784, 0.6486392070903201, 0.6900060038765479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 55}], {
             RGBColor[
             0.6123370030945732, 0.6739691484153336, 0.6913784260169663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 74}], {
             RGBColor[
             0.5949002973564235, 0.655642065133541, 0.6903854314204733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 90}], {
             RGBColor[
             0.5973830370056306, 0.6582515819196432, 0.6905268197706114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 123}], {
             RGBColor[
             0.6721825111831639, 0.7329019192094669, 0.6949318509828752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 144}], {
             RGBColor[
             0.8869762668310657, 0.9079133835364857, 0.7125333709956072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 158}], {
             RGBColor[
             0.7144740920137529, 0.7695327608882648, 0.6976266331164238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 252}], {
             RGBColor[
             0.9221033741881919, 0.935609776759841, 0.7159668887340787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 253}], {
             RGBColor[
             0.6488350696598889, 0.7123309304865575, 0.6934569369138103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 257}], {
             RGBColor[
             0.9816504156503005, 0.9821908108571346, 0.6904374124482238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 259}], {
             RGBColor[
             0.71850563711122, 0.7730246826203425, 0.697883519605079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 52}], {
             RGBColor[
             0.609310901883303, 0.6775314196260325, 0.9344719646068689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 59}], {
             RGBColor[
             0.5840766088448872, 0.6510085776960703, 0.9330349089491223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 60}], {
             RGBColor[
             0.7305572222758495, 0.7873681155153989, 0.9422516061076652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 62}], {
             RGBColor[
             0.9836960959778112, 0.9853195486783528, 0.8141715779179086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 82}], {
             RGBColor[
             0.9554831532781085, 0.9663199891212355, 0.9602395890337405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 100}], {
             RGBColor[
             0.7382683487753046, 0.7936283553899464, 0.9428586542324894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 107}], {
             RGBColor[
             0.6253633485549059, 0.6944035588617907, 0.9353861276973501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 127}], {
             RGBColor[
             0.6252202057476036, 0.6942531066955377, 0.935377975926235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 136}], {
             RGBColor[
             0.7636098040289638, 0.8142016903844165, 0.9448536264188667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 137}], {
             RGBColor[
             0.6056696830769479, 0.6737042677939467, 0.9342646025825475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 141}], {
             RGBColor[
             0.7469620880246257, 0.8006863245610354, 0.9435430572324122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 170}], {
             RGBColor[
             0.9295774998577613, 0.9457375645754886, 0.9603357084132079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 192}], {
             RGBColor[
             0.8244993670679441, 0.863110012026995, 0.9500057263358416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 220}], {
             RGBColor[
             0.9569719999463917, 0.9674303685286785, 0.9577193599777388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 228}], {
             RGBColor[
             0.6361209960564526, 0.7057105284601625, 0.9359987598080498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 232}], {
             RGBColor[
             0.681851070391983, 0.7461424969265479, 0.9388825101662013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 266}], {
             RGBColor[
             0.6904178178475102, 0.7535625829952788, 0.9394283757387902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 281}], {
             RGBColor[
             0.6973817859005444, 0.7595944221036055, 0.9398721136251343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.3468400683159113, 0.4700814550677808, 0.9434954502695099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.48484175989175965`, 0.5921952643165809, 0.9527148050378433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 162}], {
             RGBColor[
             0.635806702188991, 0.7119240073996174, 0.9665867522877821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 191}], {
             RGBColor[
             0.4059392018746844, 0.5260258663914856, 0.9470870648788811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 76}], {
             RGBColor[
             0.5550582179902402, 0.6474172679229124, 0.9591223285697112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.3553520255917452, 0.48186261618635823`, 0.9438764067245391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 99}], {
             RGBColor[
             0.3304474406270457, 0.45568631834657103`, 0.9424581274538313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 104}], {
             RGBColor[
             0.5621929045023332, 0.6529909392517852, 0.9598334474438004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 157}], {
             RGBColor[
             0.34116724705216955`, 0.46695351457435985`, 0.9430686045712096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 201}], {
             RGBColor[
             0.7004283442446368, 0.7589254847116913, 0.8299297538933122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 209}], {
             RGBColor[
             0.6995481888551323, 0.4140510331852808, 0.4437768465982874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 222}], {
             RGBColor[
             0.6780931448322549, 0.7442067978906876, 0.9578964116030133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 229}], {
             RGBColor[
             0.43025004738072886`, 0.5470428124457991, 0.9486471511951926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 259}], {
             RGBColor[
             0.4250148723712446, 0.5425482534045294, 0.9483025497349687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 261}], {
             RGBColor[
             0.3889782188032822, 0.5113351153388332, 0.9460063260355798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 278}], {
             RGBColor[
             0.4784979802348863, 0.5862126578814096, 0.9524454052074735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 290}], {
             RGBColor[
             0.38237426815720477`, 0.5056151052134116, 0.9455855281400559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 55}], {
             RGBColor[
             0.4107290438154362, 0.5193799043642979, 0.9486736622444634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[
             0.5721511096084948, 0.6635370717507574, 0.9594609776884042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 134}], {
             RGBColor[
             0.6500452453023485, 0.7257294947908617, 0.9663079344908505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 144}], {
             RGBColor[
             0.6853683075519287, 0.75332413948545, 0.9698286072231043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 159}], {
             RGBColor[
             0.38431906637867186`, 0.4916213435889752, 0.9471696530995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 235}], {
             RGBColor[
             0.38420285964963274`, 0.4914992029488229, 0.9471630352981937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 252}], {
             RGBColor[
             0.7204954149090549, 0.7810205327088053, 0.9732621249615756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 292}], {
             RGBColor[
             0.4762177292864943, 0.5832005117727823, 0.9525866654831172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 63}], {
             RGBColor[
             0.5244443970920781, 0.6144033882865971, 0.9586024680745289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 131}], {
             RGBColor[
             0.8111169186551334, 0.42017298961398, 0.44253096104824763`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 139}], {
             RGBColor[
             0.5098121038965792, 0.5990239203971554, 0.9577691806235832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 143}], {
             RGBColor[
             0.4986063337010816, 0.5872459454348212, 0.9571310285884009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 172}], {
             RGBColor[
             0.5210414868833754, 0.6108267139002816, 0.9584086773722977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 174}], {
             RGBColor[
             0.5062228974401045, 0.5952514368425674, 0.957564780625642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 183}], {
             RGBColor[
             0.5129027560826703, 0.6022723918034038, 0.9579451886933709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 185}], {
             RGBColor[
             0.48876811409464715`, 0.5769053528493078, 0.9565707565361562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 244}], {
             RGBColor[
             0.620258006707693, 0.7005291212332398, 0.9646588161222736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 59}], {
             RGBColor[
             0.23757297900992488`, 0.36703464230926314`, 0.9368408017456642]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 60}], {
             RGBColor[
             0.3840535924408872, 0.5033941801285916, 0.946057498904207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 94}], {
             RGBColor[
             0.26098144854872607`, 0.39163842797723425`, 0.9381738794561716]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 100}], {
             RGBColor[
             0.3917647189403422, 0.5096544200031392, 0.9466645470290311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 121}], {
             RGBColor[
             0.3357099778678777, 0.46248257313674995`, 0.9427115035196119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 124}], {
             RGBColor[
             0.4316420483384415, 0.5420286324617334, 0.9498038364747203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 125}], {
             RGBColor[
             0.6355399621205153, 0.7009089164700061, 0.8632930305715245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 137}], {
             RGBColor[
             0.25916605324198555`, 0.3897303324071395, 0.9380704953790893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 150}], {
             RGBColor[
             0.6255201738943952, 0.6946820437581405, 0.9360464751088746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 170}], {
             RGBColor[
             0.5830738700227989, 0.6617636291886815, 0.9641416012097497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 192}], {
             RGBColor[
             0.4779957372329819, 0.5791360766401877, 0.9538116191323833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 195}], {
             RGBColor[
             0.6041975280092284, 0.6786070606806391, 0.9661563945658075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 200}], {
             RGBColor[
             0.2924471892395655, 0.4247109164864945, 0.939965806839123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 256}], {
             RGBColor[
             0.27639154190774823`, 0.4078354131539176, 0.9390514614757777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 299}], {
             RGBColor[
             0.6278277263393586, 0.6964030125933238, 0.932140390725618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 53}], {
             RGBColor[
             0.85020270935025, 0.5662319904543961, 0.46072910655553023`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 68}], {
             RGBColor[
             0.8432266238810947, 0.5606694492620872, 0.46006372129585715`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 195}], {
             RGBColor[
             0.8784801128592482, 0.5887796244428007, 0.4634262305457546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 200}], {
             RGBColor[
             0.6706465536794729, 0.41951552831337097`, 0.4459658387279649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 215}], {
             RGBColor[
             0.8517613239685276, 0.3988657947447022, 0.1972000083293031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 223}], {
             RGBColor[
             0.7540644035033821, 0.49011326919961584`, 0.4517861977289316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 225}], {
             RGBColor[
             0.8659875905554191, 0.5788184262582119, 0.46223468261620904`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 234}], {
             RGBColor[
             0.6843939023693271, 0.43162252651428207`, 0.44683449432676237`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 255}], {
             RGBColor[
             0.7337388651216709, 0.4736120814862733, 0.4501860968926229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 282}], {
             RGBColor[
             0.7616247312186214, 0.49625108382772937`, 0.4523813744210682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 287}], {
             RGBColor[
             0.7112486156539357, 0.4548827294042745, 0.44854565291056714`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 50}], {
             RGBColor[
             0.660504076589189, 0.24770691874803907`, 0.4239198323617732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 108}], {
             RGBColor[
             0.6577041321336052, 0.7254600356057583, 0.9407356742129859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 114}], {
             RGBColor[
             0.5269646116777252, 0.6229713790713672, 0.9573798945538629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 145}], {
             RGBColor[
             0.263840028318402, 0.39111776120409447`, 0.9384657467480237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 169}], {
             RGBColor[
             0.46695856053625706`, 0.5752468236215874, 0.9519784051896312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 187}], {
             RGBColor[
             0.2920951046698944, 0.4208156379248244, 0.9400748315466017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 213}], {
             RGBColor[
             0.6087480619909744, 0.6872705192808218, 0.9654226923202346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 219}], {
             RGBColor[
             0.3868077642949585, 0.5094551767339388, 0.945868026593567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 221}], {
             RGBColor[
             0.6379402186578726, 0.710547552607023, 0.9682070662832692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 264}], {
             RGBColor[
             0.37604374479250985`, 0.5001319240562686, 0.9451821527891195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 48}], {
             RGBColor[
             0.2538099757444462, 0.38270527882648997`, 0.9378165699210979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 74}], {
             RGBColor[
             0.2604726166648913, 0.38970813686971084`, 0.9381959974650231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 90}], {
             RGBColor[
             0.2629553563140984, 0.3923176536558131, 0.9383373858151614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.3800464113222206, 0.5035988326244347, 0.9454371991609738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 166}], {
             RGBColor[
             0.31510867886528215`, 0.4471341023687436, 0.9413074403805246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 177}], {
             RGBColor[
             0.32722110314454267`, 0.457844205758119, 0.9420712172354779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 217}], {
             RGBColor[
             0.3091108096848224, 0.44082996157320997`, 0.9409658706037498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 233}], {
             RGBColor[
             0.44983907985347005`, 0.5607230049915309, 0.9508035114836682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 262}], {
             RGBColor[
             0.6443090869863579, 0.7140838887061416, 0.9431800245089674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 273}], {
             RGBColor[
             0.5863277688848407, 0.6686010499989853, 0.9636488885258467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 74}], {
             RGBColor[
             0.19044331593486252`, 0.3174983782241438, 0.9341568371556278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 84}], {
             RGBColor[
             0.3528999263955038, 0.4666666156263739, 0.9446459089934909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 90}], {
             RGBColor[
             0.19292605558406964`, 0.32010789501024606`, 0.9342982255057659]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 144}], {
             RGBColor[
             0.48251928540950473`, 0.5697696966270887, 0.9563047767307618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 158}], {
             RGBColor[
             0.31001711059219184`, 0.4313890739788677, 0.9413980388515784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 175}], {
             RGBColor[
             0.5043116936009163, 0.5868333626964695, 0.9584664189587808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 177}], {
             RGBColor[
             0.2571918024145139, 0.3856344471125519, 0.9380320569260826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 217}], {
             RGBColor[
             0.23908150895479363`, 0.36862020292764297`, 0.9369267102943544]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 252}], {
             RGBColor[
             0.5176463927666309, 0.5974660898504438, 0.9597382944692332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 253}], {
             RGBColor[
             0.24437808823832796`, 0.37418724357716027`, 0.9372283426489648]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 57}], {
             RGBColor[
             0.6096223779764293, 0.6939579354732495, 0.9624108531961066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 84}], {
             RGBColor[
             0.5802827212543641, 0.6701386804098041, 0.960101127944242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 112}], {
             RGBColor[
             0.7588323142549476, 0.8119443931323115, 0.9765100679600983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 115}], {
             RGBColor[
             0.5614031092896146, 0.6548113608999937, 0.9586148557320795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 146}], {
             RGBColor[
             0.4403313385251643, 0.5446248642671718, 0.9508936955321835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 159}], {
             RGBColor[
             0.40885283909510817`, 0.5115389655140439, 0.9491010415579085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 175}], {
             RGBColor[
             0.7316944884597767, 0.7903054274798996, 0.9739216379095318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 204}], {
             RGBColor[
             0.5300514952257086, 0.6284963151669423, 0.9563850236007145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 242}], {
             RGBColor[
             0.4506414421275538, 0.5554614368516073, 0.9514808406799081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 243}], {
             RGBColor[
             0.6281470028163132, 0.7089970604431062, 0.9638691795214391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 253}], {
             RGBColor[
             0.4717608830971882, 0.5776593083605905, 0.9526835615997158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 280}], {
             RGBColor[
             0.4236317530652163, 0.527072541133894, 0.9499426788450622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 292}], {
             RGBColor[
             0.5007515020029306, 0.603118133697851, 0.9545180539415257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 87}], {
             RGBColor[
             0.6189250821614454, 0.20635490291430042`, 0.42146591987115056`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 108}], {
             RGBColor[
             0.8677240114998812, 0.4147691049891332, 0.42219461711355066`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 114}], {
             RGBColor[
             0.7805643311959611, 0.34644333396620575`, 0.4332907640074687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 169}], {
             RGBColor[
             0.7405602971016491, 0.3146269636663525, 0.4296897710979809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 187}], {
             RGBColor[
             0.6239846598574073, 0.21167283986851054`, 0.4217540553359612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 205}], {
             RGBColor[
             0.7431308244884546, 0.3167138335999004, 0.42989213243002233`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 213}], {
             RGBColor[
             0.8350866314047939, 0.38930942743917546`, 0.4386526291850499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 227}], {
             RGBColor[
             0.6313763031600801, 0.21944192563687334`, 0.42217499848709206`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 264}], {
             RGBColor[
             0.6799504199391508, 0.26455036395614, 0.42515893616430656`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 52}], {
             RGBColor[
             0.38039026010529997`, 0.4964535044860311, 0.9461301741527866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 58}], {
             RGBColor[
             0.3960021756755188, 0.5128626176029494, 0.9470192496487512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 66}], {
             RGBColor[
             0.394227900930141, 0.510997742350041, 0.9469182073268061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 67}], {
             RGBColor[
             0.433338599292609, 0.5480951239423485, 0.9492923456721356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 69}], {
             RGBColor[
             0.5196172885125396, 0.6208877491633903, 0.9553253228540032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 86}], {
             RGBColor[
             0.6714442994035725, 0.7413663481008781, 0.969207598034232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[
             0.396442706776903, 0.5133256437217892, 0.9470443372432676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 109}], {
             RGBColor[
             0.7544421377703565, 0.8035287033992147, 0.7895503511085686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 110}], {
             RGBColor[
             0.6137262303624856, 0.6962090657758122, 0.9634727095893134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 138}], {
             RGBColor[
             0.5576350554861578, 0.6517522850734583, 0.9583182207338354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 141}], {
             RGBColor[
             0.5180414462466227, 0.619608409421034, 0.9552012667783298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 154}], {
             RGBColor[
             0.4242605287845259, 0.5402321555453374, 0.9487138990467832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 165}], {
             RGBColor[
             0.5195518350776476, 0.6208346111163014, 0.9553201701198446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 179}], {
             RGBColor[
             0.4809440485149273, 0.5893285713392712, 0.9523257228007358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 258}], {
             RGBColor[
             0.3537730109365534, 0.4684770879786082, 0.9446143611893179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 281}], {
             RGBColor[
             0.4684611441225414, 0.578516506963604, 0.9515303231710519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 82}], {
             RGBColor[
             0.592397947021208, 0.664917765582304, 0.9631011855832969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 86}], {
             RGBColor[
             0.537279734924675, 0.6210420397019479, 0.9604109850378708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 107}], {
             RGBColor[
             0.26227814229800545`, 0.39300133532285914`, 0.9382477242469065]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 110}], {
             RGBColor[
             0.47956166588358806`, 0.575884757376882, 0.9546760965929524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 141}], {
             RGBColor[
             0.3838768817677252, 0.49928410102210385`, 0.9464046537819686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 165}], {
             RGBColor[
             0.38538727059875005`, 0.5005103027173712, 0.9465235571234836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 179}], {
             RGBColor[
             0.3467794840360297, 0.46900426294034103`, 0.9435291098043748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 193}], {
             RGBColor[
             0.24870058515996415`, 0.3787304619039339, 0.9374745024540908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 236}], {
             RGBColor[
             0.24223652492104858`, 0.3719363247477429, 0.9371063837862048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 266}], {
             RGBColor[
             0.3273326115906096, 0.45216035945634725`, 0.9422899722883467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 281}], {
             RGBColor[
             0.33429657964364384`, 0.4581921985646739, 0.9427337101746909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 59}], {
             RGBColor[
             0.5199655532853772, 0.6008344796159457, 0.959729356675739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 68}], {
             RGBColor[
             0.8337098688174507, 0.8702416352162514, 0.9840011856210362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 150}], {
             RGBColor[
             0.9079127481698476, 0.928481881064823, 0.9589350300389494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 170}], {
             RGBColor[
             0.8654664442982513, 0.895563466495364, 0.9870301561398246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 192}], {
             RGBColor[
             0.7603883115084342, 0.8129359139468704, 0.9767001740624582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 195}], {
             RGBColor[
             0.8865901022846808, 0.9124068979873217, 0.9890449494958824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 200}], {
             RGBColor[
             0.5748397635150178, 0.6585107537931771, 0.9628543617691978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 225}], {
             RGBColor[
             0.8678513188289372, 0.8974651007104384, 0.987257627601564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 234}], {
             RGBColor[
             0.595460786549799, 0.6766712510945437, 0.964157345167394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 255}], {
             RGBColor[
             0.6694782306783149, 0.7396555835525306, 0.9691847490161849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 282}], {
             RGBColor[
             0.7113070298237407, 0.7736140870647147, 0.9724776653088527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 287}], {
             RGBColor[
             0.635742856476712, 0.7115615554295323, 0.9667240830431011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 72}], {
             RGBColor[
             0.5316080896266691, 0.6306224216872751, 0.9562692826414592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 106}], {
             RGBColor[
             0.594262864744407, 0.6802730538193331, 0.9620326285090306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 151}], {
             RGBColor[
             0.3735308594904517, 0.49495216155849536`, 0.945219934459554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 167}], {
             RGBColor[
             0.5829981957625874, 0.6714730087960803, 0.9609098715792396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 194}], {
             RGBColor[
             0.3635249635582116, 0.48443533052326704`, 0.9446501134886094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 238}], {
             RGBColor[
             0.6460900127375249, 0.7208041869831883, 0.9671867648723532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 251}], {
             RGBColor[
             0.5949687640792108, 0.6808245077447154, 0.9621029859577195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 286}], {
             RGBColor[
             0.34940470492249986`, 0.46959404342102784`, 0.9438459856483563]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 90}], {
             RGBColor[
             0.21702540224266437`, 0.3454378363352596, 0.9356706476461845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 97}], {
             RGBColor[
             0.39340143412466555`, 0.5053125702174094, 0.9473095693364801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 134}], {
             RGBColor[
             0.4712955698185193, 0.5675049932575138, 0.9541565261389267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 144}], {
             RGBColor[
             0.5066186320680994, 0.5950996379521021, 0.9576771988711803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 159}], {
             RGBColor[
             0.20556939089484255`, 0.33339684205562725`, 0.9350182447475761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 235}], {
             RGBColor[
             0.20545318416580344`, 0.333274701415475, 0.9350116269462697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 252}], {
             RGBColor[
             0.5417457394252256, 0.6227960311754575, 0.9611107166096516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 253}], {
             RGBColor[
             0.26847743489692266`, 0.3995171849021738, 0.9386007647893833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 292}], {
             RGBColor[
             0.29746805380266506`, 0.4249760102394343, 0.9404352571311932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 79}], {
             RGBColor[
             0.3802757916099403, 0.5037975103006691, 0.9454518150700743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 93}], {
             RGBColor[
             0.5087178326058778, 0.6079165794148582, 0.955899941367073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 160}], {
             RGBColor[
             0.3697391700538193, 0.4946712182947549, 0.9447804308616868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 164}], {
             RGBColor[
             0.26076910372556067`, 0.38963217754536505`, 0.9382270733874715]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 168}], {
             RGBColor[
             0.31693958267825784`, 0.44867091233871287`, 0.9414258990670507]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 246}], {
             RGBColor[
             0.48210622992322427`, 0.5870327557152177, 0.9533122496378099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 296}], {
             RGBColor[
             0.2769179704014046, 0.4066056603189617, 0.9391467274545535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.5513588344986553, 0.6466569661352702, 0.9578241336271442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 89}], {
             RGBColor[
             0.7848296510886424, 0.8300896235410533, 0.8963726600207946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 112}], {
             RGBColor[
             0.7299084274992389, 0.7884626788577777, 0.9742330736430007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 115}], {
             RGBColor[
             0.5324792225339057, 0.6313296466254599, 0.9563378614149818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 134}], {
             RGBColor[
             0.645655131263076, 0.7221654024413966, 0.9659623286321615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 146}], {
             RGBColor[
             0.41140745176945553`, 0.521143149992638, 0.9486167012150859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 159}], {
             RGBColor[
             0.3799289523393994, 0.4880572512395101, 0.9468240472408109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 175}], {
             RGBColor[
             0.7027706017040678, 0.7668237132053658, 0.9716446435924342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 204}], {
             RGBColor[
             0.5011276084699998, 0.6050146008924084, 0.9541080292836168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 235}], {
             RGBColor[
             0.37981274561036027`, 0.4879351105993578, 0.9468174294395045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 242}], {
             RGBColor[
             0.421717555371845, 0.5319797225770735, 0.9492038463628105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 243}], {
             RGBColor[
             0.5992231160606044, 0.6855153461685723, 0.9615921852043414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 253}], {
             RGBColor[
             0.44283699634147944`, 0.5541775940860567, 0.9504065672826181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 280}], {
             RGBColor[
             0.3947078663095075, 0.5035908268593602, 0.9476656845279645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 292}], {
             RGBColor[
             0.47182761524722183`, 0.5796364194233172, 0.9522410596244281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 66}], {
             RGBColor[
             0.27567525202146226`, 0.40708254706802915`, 0.9390106698264096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 67}], {
             RGBColor[
             0.3147859503839303, 0.4441799286603366, 0.9413848081717391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 73}], {
             RGBColor[
             0.6105832980278945, 0.6832461426341261, 0.9596341061447787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 95}], {
             RGBColor[
             0.2553941066317537, 0.38576577736455786`, 0.9378556885997316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 96}], {
             RGBColor[
             0.29695844861799314`, 0.4287386426669741, 0.9402488555234545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 109}], {
             RGBColor[
             0.6358894888616777, 0.6996135081172029, 0.7816428136081721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 138}], {
             RGBColor[
             0.4390824065774791, 0.5478370897914464, 0.9504106832334389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 140}], {
             RGBColor[
             0.25569120817477076`, 0.3860780499235946, 0.9378726080930841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 154}], {
             RGBColor[
             0.30570787987584713`, 0.4363169602633256, 0.9408063615463866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 171}], {
             RGBColor[
             0.6705962962777449, 0.46280272045930276`, 0.45362088051351246`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 198}], {
             RGBColor[
             0.24039693193217984`, 0.37000279587950974`, 0.9370016216869226]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[
             0.25967668055518955`, 0.3902670340889585, 0.938099574849171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 62}], {
             RGBColor[
             0.5953765966824949, 0.6573944832094591, 0.8155961188097185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 100}], {
             RGBColor[
             0.34994884947998817`, 0.46570328992105275`, 0.9442831951242993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 125}], {
             RGBColor[
             0.5937240926601612, 0.6569577863879197, 0.8609116786667925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 137}], {
             RGBColor[
             0.21735018378163157`, 0.34577920232505305`, 0.9356891434743574]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 170}], {
             RGBColor[
             0.541258000562445, 0.617812499106595, 0.9617602493050178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 192}], {
             RGBColor[
             0.43617986777262785`, 0.5351849465581013, 0.9514302672276514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 195}], {
             RGBColor[
             0.5623816585488746, 0.6346559305985526, 0.9637750426610756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 200}], {
             RGBColor[
             0.2506313197792115, 0.38075978640440805`, 0.937584454934391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 225}], {
             RGBColor[
             0.5436428750931308, 0.6197141333216694, 0.9619877207667572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 228}], {
             RGBColor[
             0.24780149676113625`, 0.3777854629912688, 0.9374233006998597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 255}], {
             RGBColor[
             0.34526978694250854`, 0.46190461616376155`, 0.9439148421813781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.7136442674137546, 0.7747544614716704, 0.9708808270840932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 85}], {
             RGBColor[
             0.6414971869691906, 0.7175081660970426, 0.9665112573566332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 100}], {
             RGBColor[
             0.4964294629109506, 0.6020628277403812, 0.9534998922828422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 121}], {
             RGBColor[
             0.440374721838486, 0.5548909808739919, 0.9495468487734228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 125}], {
             RGBColor[
             0.7402047060911237, 0.7933173242072481, 0.8701283758253354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 127}], {
             RGBColor[
             0.38338131988324964`, 0.5026875790459725, 0.9460192139765877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.5217709181646099, 0.6226361627348512, 0.9554948644692195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 137}], {
             RGBColor[
             0.3638307972125939, 0.4821387401443815, 0.9449058406329003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 170}], {
             RGBColor[
             0.6877386139934073, 0.7541720369259235, 0.9709769464635607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 232}], {
             RGBColor[
             0.440012184527629, 0.5545769692769826, 0.9495237482165542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 240}], {
             RGBColor[
             0.49695729924691556`, 0.6024913490566736, 0.9535414454927376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 256}], {
             RGBColor[
             0.3810562858783566, 0.5002438208911596, 0.9458868067295887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 299}], {
             RGBColor[
             0.732492470309967, 0.7888114203305658, 0.938975735979429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 177}], {
             RGBColor[
             0.6522507395883788, 0.7204137677062246, 0.9356769156042267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 217}], {
             RGBColor[
             0.6341404461286585, 0.7033995235213155, 0.9345715689724985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 247}], {
             RGBColor[
             0.6427739058526877, 0.712205410643882, 0.9350730601386235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 267}], {
             RGBColor[
             0.7429069130444117, 0.7973445351961088, 0.9418930596204059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 273}], {
             RGBColor[
             0.9113574053286768, 0.9311706119470908, 0.9572545868945954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 285}], {
             RGBColor[
             0.9844125918119507, 0.9858055349935739, 0.8091203797115252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 82}], {
             RGBColor[
             0.9667831411157163, 0.9727058946346243, 0.8428007988943367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 100}], {
             RGBColor[
             0.7495683366129122, 0.8000142609033352, 0.8254198640930855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 127}], {
             RGBColor[
             0.6365201935852114, 0.7006390122089265, 0.8179391857868311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 130}], {
             RGBColor[
             0.7005838738256658, 0.7589663337250826, 0.8219173324639986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 137}], {
             RGBColor[
             0.6169696709145556, 0.6800901733073355, 0.8168258124431437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 170}], {
             RGBColor[
             0.9408774876953689, 0.9521234700888774, 0.8428969182738041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 192}], {
             RGBColor[
             0.8357993549055519, 0.8694959175403838, 0.8325669361964377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 195}], {
             RGBColor[
             0.9620011456817985, 0.9689669015808351, 0.8449117116298619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 199}], {
             RGBColor[
             0.9353553442114017, 0.9477202627693537, 0.8423702112986275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 220}], {
             RGBColor[
             0.9682719877839994, 0.9738162740420673, 0.840280569838335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 225}], {
             RGBColor[
             0.9432623622260548, 0.9540251043039518, 0.8431243897355435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 226}], {
             RGBColor[
             0.9043451077021472, 0.6323837142387146, 0.3682941650581154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 228}], {
             RGBColor[
             0.6474209838940603, 0.7120964339735513, 0.818559969668646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 255}], {
             RGBColor[
             0.7448892740754325, 0.796215587146044, 0.8250515111501644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 131}], {
             RGBColor[
             0.6427130772725287, 0.27927074365091686`, 0.4293241024411206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 139}], {
             RGBColor[
             0.25720634182267227`, 0.38767055145256074`, 0.9379588927128928]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 143}], {
             RGBColor[
             0.2460005716271747, 0.3758925764902266, 0.9373207406777105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 172}], {
             RGBColor[
             0.2684357248094684, 0.3994733449556871, 0.9385983894616073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 174}], {
             RGBColor[
             0.2536171353661976, 0.38389806789797276`, 0.9377544927149516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 183}], {
             RGBColor[
             0.2602969940087634, 0.3909190228588092, 0.9381349007826805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 283}], {
             RGBColor[
             0.35885519823653356`, 0.4818317308865323, 0.9442118562140973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 92}], {
             RGBColor[
             0.73722541250487, 0.35027273493556704`, 0.4343304718566493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 145}], {
             RGBColor[
             0.37055357024128427`, 0.48064281984936474`, 0.9460680573755799]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 153}], {
             RGBColor[
             0.3971171015980166, 0.5085627755304547, 0.9475808111891227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 211}], {
             RGBColor[
             0.6948308360896345, 0.7603451636703316, 0.9710572218954125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 219}], {
             RGBColor[
             0.49352130621784085`, 0.5989802353792091, 0.9534703372211231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 221}], {
             RGBColor[
             0.7446537605807548, 0.8000726112522932, 0.9758093769108254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 80}], {
             RGBColor[
             0.395310581822581, 0.5098921455969939, 0.9471840874622696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 103}], {
             RGBColor[
             0.2527067463322664, 0.38294119130131254`, 0.9377026474062691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 116}], {
             RGBColor[
             0.3274925938705055, 0.45332364513551066`, 0.9422626463061485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 133}], {
             RGBColor[
             0.2676765968008682, 0.3986754532871526, 0.9385551582445468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 152}], {
             RGBColor[
             0.298254773343346, 0.42799931453047346`, 0.9403996382361475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 162}], {
             RGBColor[
             0.5462755241198124, 0.6296208886800303, 0.9610560347122084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[
             0.5004539124999509, 0.5937013714146859, 0.9565216916245757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 241}], {
             RGBColor[
             0.41641914637826816`, 0.5270290292332973, 0.948845830987313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 277}], {
             RGBColor[
             0.23193518521701015`, 0.36110896357613753`, 0.9365197377295261]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 67}], {
             RGBColor[
             0.3130116756385525, 0.4423150534074282, 0.9412837658497941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 69}], {
             RGBColor[
             0.399290364858483, 0.5151076786284701, 0.9473167430316616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 95}], {
             RGBColor[
             0.2536198318863759, 0.3839009021116494, 0.9377546462777866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 109}], {
             RGBColor[
             0.6341152141163, 0.6977486328642946, 0.7815417712862271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 110}], {
             RGBColor[
             0.4933993067084291, 0.590428995240892, 0.9554641297669719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 138}], {
             RGBColor[
             0.43730813183210127`, 0.545972214538538, 0.950309640911494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 154}], {
             RGBColor[
             0.3039336051304693, 0.4344520850104172, 0.9407053192244416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 179}], {
             RGBColor[
             0.3606171248608707, 0.48354850080435097`, 0.9443171429783943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 258}], {
             RGBColor[
             0.23344608728249683`, 0.36269701744368793`, 0.9366057813669764]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 69}], {
             RGBColor[
             0.43840106322095107`, 0.5522050602207775, 0.9496908813769911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 86}], {
             RGBColor[
             0.5902280741119841, 0.6726836591582653, 0.9635731565572199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 95}], {
             RGBColor[
             0.29273053024884393`, 0.42099828370395687`, 0.9401287846231161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 109}], {
             RGBColor[
             0.6732259124787681, 0.734846014456602, 0.7839159096315567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 110}], {
             RGBColor[
             0.5325100050708971, 0.6275263768331995, 0.9578382681123014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 138}], {
             RGBColor[
             0.4764188301945693, 0.5830695961308454, 0.9526837792568235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 154}], {
             RGBColor[
             0.34304430349293735`, 0.4715494666027247, 0.943079457569771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 179}], {
             RGBColor[
             0.3997278232233388, 0.5206458823966584, 0.9466912813237238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 258}], {
             RGBColor[
             0.2725567856449648, 0.3997943990359954, 0.9389799197123058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 215}], {
             RGBColor[
             0.8403151407885833, 0.5382905143930181, 0.4572756817984185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 223}], {
             RGBColor[
             0.6895024100471487, 0.756063553334081, 0.9705868223811382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 234}], {
             RGBColor[
             0.5849966583460661, 0.6683274393060804, 0.9631592672778845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 255}], {
             RGBColor[
             0.6590141024745819, 0.7313117717640673, 0.9681866711266753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 271}], {
             RGBColor[
             0.621347155812153, 0.6998124131820791, 0.9654754888329407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 274}], {
             RGBColor[
             0.6782790070060736, 0.746951889136791, 0.9697032749810648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 287}], {
             RGBColor[
             0.625278728272979, 0.7032177436410689, 0.9657260051535915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 109}], {
             RGBColor[
             0.7595046016986986, 0.8076386396776438, 0.7899488868134241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 110}], {
             RGBColor[
             0.6187886942908276, 0.7003190020542412, 0.9638712452941689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 113}], {
             RGBColor[
             0.4893772140509879, 0.5963374944156729, 0.9529447134193472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 135}], {
             RGBColor[
             0.3800376940775528, 0.4948719009478812, 0.9462203319124617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 138}], {
             RGBColor[
             0.5626975194144999, 0.6558622213518872, 0.9587167564386909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 224}], {
             RGBColor[
             0.44648794089269533`, 0.5592095072017523, 0.9502061700712895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 249}], {
             RGBColor[
             0.4334748384171492, 0.5479382118949823, 0.9493769866885824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 254}], {
             RGBColor[
             0.7447293249695612, 0.7991252126910227, 0.9501140886731501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 258}], {
             RGBColor[
             0.3588354748648954, 0.47258702425703725`, 0.9450128968941733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 288}], {
             RGBColor[
             0.35314438130598974`, 0.46660532409045485`, 0.9446887975352121]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[
             0.5278507794692352, 0.6115100893811366, 0.9598166829048108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 251}], {
             RGBColor[
             0.4767295308109211, 0.5715304101426637, 0.9547329039901771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 300}], {
             RGBColor[
             0.2104636493548522, 0.33854101801100667`, 0.9352969655264671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 85}], {
             RGBColor[
             0.865345200536672, 0.89565613064495, 0.9863238733338944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 98}], {
             RGBColor[
             0.7123187658202632, 0.7737495524401579, 0.9726859694033747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 121}], {
             RGBColor[
             0.6642227354059673, 0.7330389454218993, 0.969359464750684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 122}], {
             RGBColor[
             0.5758690222853357, 0.6478738682004793, 0.9640459066264025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 136}], {
             RGBColor[
             0.7456189317320912, 0.8007841272827585, 0.9753074804464807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 160}], {
             RGBColor[
             0.6739306758350241, 0.741447475486275, 0.9699780461304288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 181}], {
             RGBColor[
             0.643914913589207, 0.7154493308650242, 0.9680654683020218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 207}], {
             RGBColor[
             0.5916393504330073, 0.6644494829802381, 0.9649440034843026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 232}], {
             RGBColor[
             0.6638601980951103, 0.73272493382489, 0.9693363641938153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 240}], {
             RGBColor[
             0.7208053128143969, 0.7806393136045808, 0.9733540614699988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 246}], {
             RGBColor[
             0.7862977357044291, 0.8338090129067377, 0.978509864906552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 256}], {
             RGBColor[
             0.6049042994458379, 0.678391785439067, 0.9656994227068498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 296}], {
             RGBColor[
             0.5811094761826094, 0.6533819175104818, 0.9643443427232955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 299}], {
             RGBColor[
             0.9563404838774483, 0.9669593848784731, 0.9587883519566902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 106}], {
             RGBColor[
             0.6590409128576833, 0.7328627914955024, 0.9671321937463165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 151}], {
             RGBColor[
             0.438308907603728, 0.5475418992346647, 0.9503194996968398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 194}], {
             RGBColor[
             0.42830301167148777`, 0.5370250681994364, 0.9497496787258953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 215}], {
             RGBColor[
             0.7646952731639924, 0.47872862637157015`, 0.45006426184749126`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 247}], {
             RGBColor[
             0.4540177000415867, 0.5637844096414701, 0.9512239205940007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 267}], {
             RGBColor[
             0.5541507072333107, 0.648923534193697, 0.9580439200757831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 286}], {
             RGBColor[
             0.4141827530357761, 0.5221837810971972, 0.9489455508856423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 87}], {
             RGBColor[
             0.5829271578866424, 0.6541777858451079, 0.9580591298773273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 95}], {
             RGBColor[
             0.588527877892808, 0.6600644976777462, 0.9583780825961556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 96}], {
             RGBColor[
             0.6300922198790475, 0.7030373629801625, 0.9607712495198786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 105}], {
             RGBColor[
             0.5742261751712128, 0.645032501337024, 0.9575636217836341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 140}], {
             RGBColor[
             0.5888249794358251, 0.660376770236783, 0.9583950020895082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 149}], {
             RGBColor[
             0.6448036038402432, 0.7157796243516928, 0.9617086458971198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 171}], {
             RGBColor[
             0.8926854771184477, 0.6456685340014284, 0.46730247651112855`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 245}], {
             RGBColor[
             0.5928104518162438, 0.6645657544021469, 0.958621968845595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 289}], {
             RGBColor[
             0.7341460911929814, 0.7912287987279166, 0.9679360605538028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 298}], {
             RGBColor[
             0.5829630210629728, 0.6542154803172878, 0.9580611722321646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 90}], {
             RGBColor[
             0.19958869650451472`, 0.32711075305346693`, 0.9346776530496914]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 123}], {
             RGBColor[
             0.274388170682048, 0.40176109034329066`, 0.9390826842619552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 158}], {
             RGBColor[
             0.31667975151263694`, 0.4383919320220886, 0.9417774663955037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 233}], {
             RGBColor[
             0.3864724200438864, 0.4955161043891848, 0.9471437787181981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 257}], {
             RGBColor[
             0.5838560751491846, 0.6510499819909583, 0.9345882457273037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 259}], {
             RGBColor[
             0.32071129661010406`, 0.4418838537541663, 0.942034352884159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 262}], {
             RGBColor[
             0.5809424271767742, 0.6488769881037952, 0.9395202917434974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 124}], {
             RGBColor[
             0.44128826473719407`, 0.5521674175022666, 0.9503531742283309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 142}], {
             RGBColor[
             0.5142732439291174, 0.6100794280663394, 0.9570153150192797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 143}], {
             RGBColor[
             0.2594218947519811, 0.38999923805543346`, 0.9380850651746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 150}], {
             RGBColor[
             0.6351663902931477, 0.7048208287986737, 0.9365958128624853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 167}], {
             RGBColor[
             0.49892381563978294`, 0.5980883380267354, 0.9554854274559617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 174}], {
             RGBColor[
             0.267038458491004, 0.3980047294631796, 0.938518817211841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 185}], {
             RGBColor[
             0.24958367514554664`, 0.37965864546992, 0.9375247931223551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 237}], {
             RGBColor[
             0.4629837283563226, 0.5697807722377732, 0.9520611205975307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 239}], {
             RGBColor[
             0.5616100012493834, 0.6470960767736937, 0.9617236312673381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 282}], {
             RGBColor[
             0.43856067194704085`, 0.5499530347985654, 0.9501384481323885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 283}], {
             RGBColor[
             0.37227652136133993`, 0.4959383924517391, 0.9449761807109868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 295}], {
             RGBColor[
             0.32642693095766984`, 0.4562257817114992, 0.9420546853536658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 297}], {
             RGBColor[
             0.5243114408491145, 0.6179213437933634, 0.9580158286759815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 99}], {
             RGBColor[
             0.47979255023969725`, 0.5772735507013926, 0.9545077976223697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[
             0.7115380141149847, 0.7745781716066067, 0.9718831176123388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 128}], {
             RGBColor[
             0.4733446949839849, 0.5704964460100036, 0.9541406018043039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[
             0.4905123566648212, 0.5885407469291813, 0.955118274739748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 201}], {
             RGBColor[
             0.8497734538572885, 0.8805127170665129, 0.8419794240618508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 209}], {
             RGBColor[
             0.7991115952635667, 0.4951091880884952, 0.4518099600439798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 218}], {
             RGBColor[
             0.8392772147568468, 0.8746235074616358, 0.9499058100588113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 229}], {
             RGBColor[
             0.5795951569933805, 0.6686300448006206, 0.9606968213637311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 261}], {
             RGBColor[
             0.5383233284159338, 0.6329223476936547, 0.9580559962041182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 284}], {
             RGBColor[
             0.8327519145667567, 0.8247247496416221, 0.6372776110244787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 91}], {
             RGBColor[
             0.7630472937770785, 0.8148580793774423, 0.9770063425262588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 162}], {
             RGBColor[
             0.8301164117726716, 0.8673763101105376, 0.9836584384801882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 191}], {
             RGBColor[
             0.600248911458365, 0.6814781691024059, 0.9641587510712871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 203}], {
             RGBColor[
             0.8871285039731378, 0.9124863404760193, 0.9769662842433843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 206}], {
             RGBColor[
             0.8242755459335999, 0.8627189622365414, 0.983101331482255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 244}], {
             RGBColor[
             0.6442282599009261, 0.7192953322222482, 0.9670372082446119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 270}], {
             RGBColor[
             0.5033402301005603, 0.585793525778129, 0.9584139386489746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 118}], {
             RGBColor[
             0.5739493632018122, 0.6649969750282136, 0.9596025427984901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 120}], {
             RGBColor[
             0.46914671507810013`, 0.5783122286019691, 0.95179452053814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 130}], {
             RGBColor[
             0.4750596816535735, 0.5834337430553026, 0.9521712895396981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 176}], {
             RGBColor[
             0.4787632672989916, 0.5866416027937368, 0.9524072787420719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 193}], {
             RGBColor[
             0.3975615870823801, 0.5109860002864742, 0.94742807284083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.7098311520393092, 0.7721876720995737, 0.9726241683743271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 220}], {
             RGBColor[
             0.7427477956119071, 0.7982836833722873, 0.9705345269140344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 226}], {
             RGBColor[
             0.7539956462540855, 0.5153619871255279, 0.455130136441915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 236}], {
             RGBColor[
             0.3910975268434645, 0.5041918631302833, 0.9470599541729439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 266}], {
             RGBColor[
             0.4761936135130255, 0.5844158978388876, 0.9522435426750857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 93}], {
             RGBColor[
             0.5609622722317695, 0.653168087136919, 0.9592289108620908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 103}], {
             RGBColor[
             0.3403124168268161, 0.46357653213858063`, 0.9431106733418471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 116}], {
             RGBColor[
             0.41509826436505515`, 0.5339589859727787, 0.9476706722417265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 119}], {
             RGBColor[
             0.32392195613002256`, 0.4463491187310201, 0.9421772608526784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 164}], {
             RGBColor[
             0.3130135433514524, 0.43488368526742593`, 0.9415560428824893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 168}], {
             RGBColor[
             0.36918402230414954`, 0.49392242006077375`, 0.9447548685620685]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 241}], {
             RGBColor[
             0.5040248168728179, 0.6076643700705653, 0.954253856922891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[
             0.3195408557115598, 0.4417443044134056, 0.9419277636651041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 103}], {
             RGBColor[
             0.3907084379081148, 0.5050550005501127, 0.9469220021746025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 116}], {
             RGBColor[
             0.46549428544635385`, 0.5754374543843108, 0.951482001074482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 133}], {
             RGBColor[
             0.40567828837671654`, 0.5207892625359527, 0.9477745130128803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 152}], {
             RGBColor[
             0.43625646491919434`, 0.5501131237792736, 0.9496189930044809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 210}], {
             RGBColor[
             0.6384556040757992, 0.715815180663486, 0.9657410463929091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 241}], {
             RGBColor[
             0.5544208379541165, 0.6491428384820974, 0.9580651857556465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 277}], {
             RGBColor[
             0.36993687679285847`, 0.48322277282493764`, 0.9457390924978596]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 180}], {
             RGBColor[
             0.237877225969383, 0.367354425154025, 0.9368581281599122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[
             0.374466062709676, 0.49054251155454265`, 0.9457640616098195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 285}], {
             RGBColor[
             0.615971741477215, 0.6790035113520076, 0.8129913817009389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 100}], {
             RGBColor[
             0.7213553939132096, 0.781014701346218, 0.9714878752089173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 107}], {
             RGBColor[
             0.6084503936928111, 0.6817899048180622, 0.964015348673778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 127}], {
             RGBColor[
             0.6083072508855087, 0.6816394526518093, 0.9640071969026629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 137}], {
             RGBColor[
             0.5887567282148529, 0.6610906137502183, 0.9628938235589755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 192}], {
             RGBColor[
             0.8075864122058493, 0.8504963579832665, 0.9786349473122695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 199}], {
             RGBColor[
             0.907142401511699, 0.9287207032122364, 0.9884382224144594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 220}], {
             RGBColor[
             0.9400590450842967, 0.95481671448495, 0.9863485809541668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 226}], {
             RGBColor[
             0.8855364792356787, 0.6197173412006365, 0.46567283913533664`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 228}], {
             RGBColor[
             0.6192080411943577, 0.693096874416434, 0.9646279807844778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 266}], {
             RGBColor[
             0.6735048629854152, 0.7409489289515503, 0.9680575967152182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 281}], {
             RGBColor[
             0.6804688310384495, 0.746980768059877, 0.9685013346015623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 126}], {
             RGBColor[
             0.7068282258111822, 0.7693512989805533, 0.9728463898515202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 155}], {
             RGBColor[
             0.682498430141563, 0.7499513803283091, 0.9705257922210869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 156}], {
             RGBColor[
             0.737528689202848, 0.7881738979478126, 0.6882798749469776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 184}], {
             RGBColor[
             0.4321526123562799, 0.5479280379887984, 0.9489791118788778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[
             0.34588019021457106`, 0.46397031974840536`, 0.9438199704792805]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 202}], {
             RGBColor[
             0.35185100610713066`, 0.47024602582307834`, 0.9441599996113311]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 214}], {
             RGBColor[
             0.47240518954714567`, 0.582558840342463, 0.9516086134798305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 275}], {
             RGBColor[
             0.7059410676451032, 0.7686439031401888, 0.9727617719136641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 293}], {
             RGBColor[
             0.5227841698996936, 0.6234587661398625, 0.9555746313574687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 89}], {
             RGBColor[
             0.7554899943665773, 0.8062703684776078, 0.8940629347689298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.36204530696515597`, 0.476278990455697, 0.9451667248875545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 112}], {
             RGBColor[
             0.7005687707771737, 0.7646434237943323, 0.9719233483911358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 134}], {
             RGBColor[
             0.6163154745410109, 0.6983461473779513, 0.9636526033802966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 144}], {
             RGBColor[
             0.651638536790591, 0.7259407920725396, 0.9671732761125503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 158}], {
             RGBColor[
             0.4791363619732782, 0.5875601694243187, 0.9522665382333668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 159}], {
             RGBColor[
             0.3505892956173342, 0.4642379961760647, 0.944514321988946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 175}], {
             RGBColor[
             0.6734309449820026, 0.7430044581419204, 0.9693349183405693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 252}], {
             RGBColor[
             0.6867656441477172, 0.7536371852958949, 0.9706067938510217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 253}], {
             RGBColor[
             0.41349733961941426`, 0.5303583390226112, 0.9480968420307534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 280}], {
             RGBColor[
             0.3653682095874423, 0.4797715717959148, 0.9453559592760998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 292}], {
             RGBColor[
             0.44248795852515665`, 0.5558171643598717, 0.9499313343725633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[
             0.593153572396181, 0.676596559105201, 0.9631652619720379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 122}], {
             RGBColor[
             0.5047998592755494, 0.5914314818837809, 0.9578517038477565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 136}], {
             RGBColor[
             0.6745497687223049, 0.7443417409660602, 0.9691132776678346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 165}], {
             RGBColor[
             0.6594124415489917, 0.7320525768379466, 0.967921611822895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 181}], {
             RGBColor[
             0.5728457505794207, 0.6590069445483258, 0.9618712655233757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 207}], {
             RGBColor[
             0.520570187423221, 0.6080070966635398, 0.9587498007056566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 232}], {
             RGBColor[
             0.592791035085324, 0.6762825475081917, 0.9631421614151693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 240}], {
             RGBColor[
             0.6497361498046106, 0.7241969272878825, 0.9671598586913528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 246}], {
             RGBColor[
             0.7152285726946428, 0.7773666265900394, 0.9723156621279059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 256}], {
             RGBColor[
             0.5338351364360516, 0.6219493991223686, 0.9595052199282038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 296}], {
             RGBColor[
             0.5100403131728231, 0.5969395311937834, 0.9581501399446495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 299}], {
             RGBColor[
             0.8852713208676619, 0.9105169985617747, 0.9525941491780441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 107}], {
             RGBColor[
             0.5533321815962781, 0.6379141789377061, 0.9613251481283519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 109}], {
             RGBColor[
             0.9113316125897315, 0.9281172386151315, 0.8038311619936529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 110}], {
             RGBColor[
             0.7706157051818607, 0.820797600991729, 0.9777535204743977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 141}], {
             RGBColor[
             0.6749309210659978, 0.7441969446369509, 0.9694820776634141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 165}], {
             RGBColor[
             0.6764413098970227, 0.7454231463322183, 0.9696009810049289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 179}], {
             RGBColor[
             0.6378335233343023, 0.713917106555188, 0.9666065336858201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 240}], {
             RGBColor[
             0.6667650181526416, 0.7375674967821542, 0.9688392278733866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 281}], {
             RGBColor[
             0.6253506189419165, 0.7031050421795209, 0.9658111340561362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 149}], {
             RGBColor[
             0.28401369243793695`, 0.4124125472494863, 0.9396112756332444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 187}], {
             RGBColor[
             0.22972661302827896`, 0.35878761417421645`, 0.9363939628106677]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 227}], {
             RGBColor[
             0.2408140779822881, 0.3704412428267607, 0.937025377537364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 264}], {
             RGBColor[
             0.3136752531508944, 0.4381039003056607, 0.9415012840531858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 99}], {
             RGBColor[
             0.2800863578412023, 0.4117188989648385, 0.9392618757771976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[
             0.379532809233498, 0.502786250097076, 0.9454228616638705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 198}], {
             RGBColor[
             0.2541676399517107, 0.38447668312135375`, 0.937785843136698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 201}], {
             RGBColor[
             0.6500672614587935, 0.7149580653299588, 0.8267335022166786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 222}], {
             RGBColor[
             0.6277320620464115, 0.7002393785089549, 0.9547001599263796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 258}], {
             RGBColor[
             0.2489910700474055, 0.3790357799384404, 0.9374910451386966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 260}], {
             RGBColor[
             0.28166447633286396`, 0.41337760155806647`, 0.9393517472906805]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 261}], {
             RGBColor[
             0.3386171360174388, 0.46736769595710065`, 0.942810074358946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 278}], {
             RGBColor[
             0.42813689744904293`, 0.542245238499677, 0.9492491535308398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 290}], {
             RGBColor[
             0.3320131853713614, 0.4616476858316789, 0.9423892764634223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 111}], {
             RGBColor[
             0.5958879542754325, 0.6601024655239335, 0.8837364264906511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 112}], {
             RGBColor[
             0.9340395873671608, 0.9480760812001152, 0.9104718747847862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 175}], {
             RGBColor[
             0.9069017615719899, 0.9264371155477034, 0.9078834447342197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 177}], {
             RGBColor[
             0.6597818703855873, 0.7252381999637859, 0.8874490827015216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 242}], {
             RGBColor[
             0.6258487152397669, 0.6915931249194112, 0.885442647504596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.5988390261774295, 0.6632042292016977, 0.8839044856697502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 285}], {
             RGBColor[
             0.9919437226091593, 0.9906299672511353, 0.76089254680882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 123}], {
             RGBColor[
             0.2768709103312551, 0.4043706071293929, 0.9392240726120933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 134}], {
             RGBColor[
             0.4563416037295768, 0.5517874267618235, 0.9533049198925716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 144}], {
             RGBColor[
             0.4916646659791569, 0.5793820714564117, 0.9568255926248254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 158}], {
             RGBColor[
             0.31916249116184403`, 0.4410014488081908, 0.9419188547456419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 252}], {
             RGBColor[
             0.5267917733362831, 0.6070784646797671, 0.9602591103632967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 253}], {
             RGBColor[
             0.25352346880798016`, 0.38379961840648347`, 0.9377491585430284]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[
             0.5863388147983917, 0.6536594987770605, 0.9347296340774418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 102}], {
             RGBColor[
             0.7774853015640018, 0.8263705548774538, 0.9783834525979374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 162}], {
             RGBColor[
             0.7681730399972989, 0.8189452102787713, 0.9774952407765511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 191}], {
             RGBColor[
             0.5383055396829923, 0.6330470692706396, 0.9579955533676501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 203}], {
             RGBColor[
             0.825185132197765, 0.864055240644253, 0.9708030865397472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 239}], {
             RGBColor[
             0.7628213216163442, 0.8146778953103236, 0.9769847890998402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 153}], {
             RGBColor[
             0.6284359378279933, 0.25337000293276496`, 0.4270322670891098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 163}], {
             RGBColor[
             0.6468000142163334, 0.27267181156660303`, 0.4280780740722093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 189}], {
             RGBColor[
             0.6164028301748388, 0.24072244384620892`, 0.42634699940965015`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 211}], {
             RGBColor[
             0.8269117608224053, 0.42122492835934955`, 0.4426832075599697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 216}], {
             RGBColor[
             0.683444694496562, 0.30562714528742735`, 0.43036853332870817`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 221}], {
             RGBColor[
             0.8601270438164854, 0.44770989341399064`, 0.4458513109035782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 94}], {
             RGBColor[
             0.4659891809274401, 0.5647891199071136, 0.9534013212105183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 160}], {
             RGBColor[
             0.5504256506756485, 0.6440417951310049, 0.9585575266537034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 164}], {
             RGBColor[
             0.4414555843473899, 0.5390027543816149, 0.952004169179488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 168}], {
             RGBColor[
             0.4976260633000871, 0.5980414891749628, 0.9552029948590672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 277}], {
             RGBColor[
             0.44798289670749736`, 0.5458633735275946, 0.9523758899621029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 124}], {
             RGBColor[
             0.41323464841688873`, 0.522681288047618, 0.9487555622804957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 125}], {
             RGBColor[
             0.6171325621989625, 0.6815615720558907, 0.8622447563772999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 142}], {
             RGBColor[
             0.4862196276088121, 0.5805932986116908, 0.9554177030714446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 150}], {
             RGBColor[
             0.6071127739728424, 0.675334699344025, 0.93499820091465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 200}], {
             RGBColor[
             0.27403978931801265`, 0.40536357207237916`, 0.9389175326448984]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.4349301120360173, 0.5402946427831247, 0.9504635086496954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 295}], {
             RGBColor[
             0.2983733146373645, 0.42673965225685057`, 0.9404570734058306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 96}], {
             RGBColor[
             0.2749030284829068, 0.4055569977105943, 0.9389928319748314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 105}], {
             RGBColor[
             0.21903698377507214`, 0.34755213606745583`, 0.9357852042385869]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 109}], {
             RGBColor[
             0.6138340687265914, 0.676431863160823, 0.7803867900595491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 138}], {
             RGBColor[
             0.4170269864423928, 0.5246554448350667, 0.9491546596848159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 140}], {
             RGBColor[
             0.23363578803968443`, 0.3628964049672148, 0.9366165845444611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 154}], {
             RGBColor[
             0.2836524597407608, 0.4131353153069458, 0.9395503379977636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 171}], {
             RGBColor[
             0.655892682854354, 0.4473482904883829, 0.45278353148109707`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 198}], {
             RGBColor[
             0.2183415117970935, 0.34682115092312993`, 0.9357455981382996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 245}], {
             RGBColor[
             0.23762126042010318`, 0.3670853891325787, 0.9368435513005479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 289}], {
             RGBColor[
             0.37895689979684066`, 0.4937484334583484, 0.9461576430087557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 105}], {
             RGBColor[
             0.26060132576131156`, 0.39052500136987206`, 0.9381783711623097]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 138}], {
             RGBColor[
             0.45859132842863215`, 0.5676283101374828, 0.9515478266085388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 140}], {
             RGBColor[
             0.27520013002592386`, 0.40586927026963104`, 0.9390097514681839]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 171}], {
             RGBColor[
             0.6836022441785135, 0.4759968673566604, 0.4543789760969123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 196}], {
             RGBColor[
             0.3995345987303863, 0.5196833964930926, 0.9468986645147639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 198}], {
             RGBColor[
             0.2599058537833329, 0.3897940162255462, 0.9381387650620224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 222}], {
             RGBColor[
             0.6334702758780337, 0.7055567116131474, 0.955053081851704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 245}], {
             RGBColor[
             0.2791856024063426, 0.410058254434995, 0.9392367182242707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 278}], {
             RGBColor[
             0.43387511128066514`, 0.5475625716038695, 0.9496020754561643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 289}], {
             RGBColor[
             0.42052124178308004`, 0.5367212987607647, 0.9485508099324785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 290}], {
             RGBColor[
             0.3377513992029836, 0.4669650189358714, 0.9427421983887467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 298}], {
             RGBColor[
             0.2693381716530716, 0.3997079803501359, 0.9386759216108402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 134}], {
             RGBColor[
             0.6327176356115779, 0.7116621606439733, 0.9649438415828674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 144}], {
             RGBColor[
             0.668040697861158, 0.7392568053385615, 0.9684645143151211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 159}], {
             RGBColor[
             0.36699145668790123`, 0.4775540094420867, 0.9458055601915168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 235}], {
             RGBColor[
             0.3668752499588621, 0.47743186880193444`, 0.9457989423902105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 252}], {
             RGBColor[
             0.7031678052182843, 0.7669531985619169, 0.9718980320535924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 292}], {
             RGBColor[
             0.4588901195957237, 0.5691331776258938, 0.951222572575134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 122}], {
             RGBColor[
             0.3517734245591407, 0.4695249036789889, 0.9442137999172366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 160}], {
             RGBColor[
             0.44983507810882917`, 0.5630985109647846, 0.950145939421263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 178}], {
             RGBColor[
             0.6453975027991554, 0.7205475371198228, 0.9669051905312708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 181}], {
             RGBColor[
             0.419819315863012, 0.5371003663435339, 0.948233361592856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 182}], {
             RGBColor[
             0.4849439158800106, 0.5927383432426668, 0.9525957079476215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 208}], {
             RGBColor[
             0.41109470053946123`, 0.5295435430621906, 0.9476774368193137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 246}], {
             RGBColor[
             0.562202137978234, 0.6554600483852473, 0.9586777581973862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 296}], {
             RGBColor[
             0.3570138784564144, 0.4750329529889914, 0.9445122360141296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 104}], {
             RGBColor[
             0.48692723675179017`, 0.5828472220302654, 0.9552189164964588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 123}], {
             RGBColor[
             0.3034260786926455, 0.432281772772134, 0.9407363501654235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 157}], {
             RGBColor[
             0.2659015793016266, 0.39680979735284005`, 0.938454073623868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 201}], {
             RGBColor[
             0.6251626764940938, 0.6887817674901715, 0.8253152229459708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[
             0.6146664373936521, 0.6828925578852945, 0.9332416089429313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 222}], {
             RGBColor[
             0.6028274770817119, 0.6740630806691679, 0.9532818806556718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 229}], {
             RGBColor[
             0.3549843796301859, 0.4768990952242793, 0.9440326202478512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 257}], {
             RGBColor[
             0.6128939831597822, 0.6815706644198016, 0.936241911630772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 259}], {
             RGBColor[
             0.3497492046207016, 0.4724045361830096, 0.9436880187876273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 261}], {
             RGBColor[
             0.3137125510527392, 0.44119139811731345`, 0.9413917950882382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 121}], {
             RGBColor[
             0.448085848337941, 0.5611512207485396, 0.9501538968982469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 125}], {
             RGBColor[
             0.7479158325905786, 0.7995775640817957, 0.8707354239501596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 127}], {
             RGBColor[
             0.39109244638270463`, 0.5089478189205201, 0.9466262621014119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 136}], {
             RGBColor[
             0.5294820446640649, 0.6288964026093988, 0.9561019125940436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 137}], {
             RGBColor[
             0.37154192371204886`, 0.4883989800189291, 0.9455128887577244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 170}], {
             RGBColor[
             0.6954497404928622, 0.760432276800471, 0.9715839945883848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 192}], {
             RGBColor[
             0.5903716077030452, 0.6778047242519774, 0.9612540125110185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 228}], {
             RGBColor[
             0.40199323669155357`, 0.5204052406851448, 0.9472470459832267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 232}], {
             RGBColor[
             0.44772331102708396`, 0.5608372091515303, 0.9501307963413783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 240}], {
             RGBColor[
             0.5046684257463705, 0.6087515889312212, 0.9541484936175617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 256}], {
             RGBColor[
             0.38876741237781154`, 0.5065040607657072, 0.9464938548544128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 299}], {
             RGBColor[
             0.7402035968094219, 0.7950716602051133, 0.9395827841042531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 108}], {
             RGBColor[
             0.6440699237773052, 0.7136507696027685, 0.9398669145127795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 114}], {
             RGBColor[
             0.5133304033214252, 0.6111621130683773, 0.9565111348536565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 187}], {
             RGBColor[
             0.2784608963135943, 0.40900637192183453`, 0.9392060718463953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 205}], {
             RGBColor[
             0.4571801432601653, 0.5665678625189193, 0.9514131874874869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 207}], {
             RGBColor[
             0.28323507518726165`, 0.41402433661848265`, 0.9394779542704859]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 213}], {
             RGBColor[
             0.5951138536346743, 0.6754612532778319, 0.9645539326200282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 231}], {
             RGBColor[
             0.3507701545144143, 0.4782412104449649, 0.9435717419651577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 133}], {
             RGBColor[
             0.5659554922406507, 0.6479433502176715, 0.9625346720842052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 142}], {
             RGBColor[
             0.7918659438583744, 0.8376048219347472, 0.9798167806270974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 162}], {
             RGBColor[
             0.8445544195595949, 0.8788887856105492, 0.9850355485518667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[
             0.5271763750748035, 0.6071840393383277, 0.9603262587301729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 210}], {
             RGBColor[
             0.7987328079397333, 0.8429692683452048, 0.980501205464234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 237}], {
             RGBColor[
             0.7405764282855796, 0.7973061661061809, 0.9748625862053484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 239}], {
             RGBColor[
             0.8392027011786403, 0.8746214706421014, 0.9845250968751558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 295}], {
             RGBColor[
             0.6040196308869267, 0.6837511755799068, 0.9648561509614835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 116}], {
             RGBColor[
             0.3228904499560393, 0.44848650008862934`, 0.9420005610184816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 119}], {
             RGBColor[
             0.23171414172100668`, 0.36087663284687077`, 0.9365071496294333]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 152}], {
             RGBColor[
             0.2936526294288798, 0.4231621694835922, 0.9401375529484806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 164}], {
             RGBColor[
             0.2208057289424365, 0.3494111993832765, 0.9358859316592443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 168}], {
             RGBColor[
             0.27697620789513366`, 0.40844993417662434`, 0.9390847573388235]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 241}], {
             RGBColor[
             0.41181700246380193`, 0.5221918841864159, 0.948583745699646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 277}], {
             RGBColor[
             0.22733304130254395`, 0.35627181852925627`, 0.9362576524418591]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 128}], {
             RGBColor[
             0.48047938149607783`, 0.5760701173388764, 0.9548517206783931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 157}], {
             RGBColor[
             0.4976470431769141, 0.5941144182580542, 0.9558293936138372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 173}], {
             RGBColor[
             0.8423027965251915, 0.8771326152006627, 0.9575725714379077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 201}], {
             RGBColor[
             0.8569081403693815, 0.8860863883953858, 0.8426905429359399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 209}], {
             RGBColor[
             0.8038680529382952, 0.4988249689744104, 0.4522840392933726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 218}], {
             RGBColor[
             0.8464119012689397, 0.8801971787905086, 0.9506169289329005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 229}], {
             RGBColor[
             0.5867298435054734, 0.6742037161294935, 0.9614079402378204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 261}], {
             RGBColor[
             0.5454580149280267, 0.6384960190225276, 0.9587671150782073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 279}], {
             RGBColor[
             0.5056161836785389, 0.6024904901979529, 0.9562832243761179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 129}], {
             RGBColor[
             0.4240818833255446, 0.5269453150019899, 0.950032669877762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 140}], {
             RGBColor[
             0.2193340853180892, 0.3478644086264926, 0.9358021237319394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 149}], {
             RGBColor[
             0.2753127097225073, 0.40326726274140245`, 0.9391157675395511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 171}], {
             RGBColor[
             0.6463582143732904, 0.4373269595945681, 0.4522405576060826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 196}], {
             RGBColor[
             0.3436685540225517, 0.4616785348499541, 0.9436910367785194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 230}], {
             RGBColor[
             0.4546933328704373, 0.5508592120420934, 0.9530837330881365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 245}], {
             RGBColor[
             0.22331955769850798`, 0.3520533927918565, 0.9360290904880262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 263}], {
             RGBColor[
             0.2589148396755163, 0.3890642518876115, 0.938070909760224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 289}], {
             RGBColor[
             0.3646551970752454, 0.4787164371176262, 0.945343182196234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 298}], {
             RGBColor[
             0.21347212694523698`, 0.34170311870699743`, 0.9354682938745957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 151}], {
             RGBColor[
             0.500963682721466, 0.5971925313667227, 0.9560828455644113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 167}], {
             RGBColor[
             0.7104310189936016, 0.7737133786043076, 0.971772782684097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 194}], {
             RGBColor[
             0.49095778678922575`, 0.5866757003314944, 0.9555130245934668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 215}], {
             RGBColor[
             0.8064651232424845, 0.5118290477929421, 0.4539064924258722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 283}], {
             RGBColor[
             0.5837837247151585, 0.6715634330293112, 0.9612635359391221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 286}], {
             RGBColor[
             0.4768375281535141, 0.5718344132292552, 0.9547088967532137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 297}], {
             RGBColor[
             0.7358186442029332, 0.7935463843709355, 0.9743031839041167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 110}], {
             RGBColor[
             0.4956141125551911, 0.5927568966126402, 0.9555902596834334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 127}], {
             RGBColor[
             0.2781874461623061, 0.40972302239236436`, 0.9391537355662725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 141}], {
             RGBColor[
             0.39992932843932827`, 0.5161562402578621, 0.9473188168724498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 165}], {
             RGBColor[
             0.4014397172703531, 0.5173824419531294, 0.9474377202139646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.36283193070763275`, 0.48587640217609923`, 0.9444432728948557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 240}], {
             RGBColor[
             0.391763425525972, 0.5095267924030654, 0.9466759670824223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 281}], {
             RGBColor[
             0.3503490263152469, 0.4750643378004321, 0.9436478732651719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 114}], {
             RGBColor[
             0.8377945140437635, 0.8735646584330085, 0.9547920716815291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 145}], {
             RGBColor[
             0.5746699306844403, 0.6417110405657357, 0.93587792387569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 169}], {
             RGBColor[
             0.7777884629022953, 0.8258401029832286, 0.9493905823172974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 187}], {
             RGBColor[
             0.6029250070359327, 0.6714089172864657, 0.9374870086742679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 205}], {
             RGBColor[
             0.7816442539825037, 0.8289704078835505, 0.9496941243153596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 213}], {
             RGBColor[
             0.9195779643570127, 0.937863798642463, 0.9628348694479009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 219}], {
             RGBColor[
             0.6976376666609968, 0.76004845609558, 0.9432802037212332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 221}], {
             RGBColor[
             0.9487701210239108, 0.9611408319686642, 0.9656192434109355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 264}], {
             RGBColor[
             0.6868736471585482, 0.7507252034179099, 0.9425943299167858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 110}], {
             RGBColor[
             0.8536135435486446, 0.8829599562900656, 0.7980962735487345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 138}], {
             RGBColor[
             0.7975223686723167, 0.8385031755877117, 0.7929417846932565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 154}], {
             RGBColor[
             0.6641478419706849, 0.726983046059591, 0.7833374630062041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 179}], {
             RGBColor[
             0.7208313617010862, 0.7760794618535247, 0.7869492867601569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 258}], {
             RGBColor[
             0.5936603241227123, 0.6552279784928616, 0.7792379251487389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 138}], {
             RGBColor[
             0.656806461264446, 0.7311835379643092, 0.9668641431740013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 141}], {
             RGBColor[
             0.6172128520249109, 0.699039662311885, 0.9637471892184956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 154}], {
             RGBColor[
             0.523431934562814, 0.6196634084361884, 0.9572598214869489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 165}], {
             RGBColor[
             0.6187232408559358, 0.7002658640071524, 0.9638660925600104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 179}], {
             RGBColor[
             0.5801154542932154, 0.6687598242301221, 0.9608716452409016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 281}], {
             RGBColor[
             0.5676325499008295, 0.657947759854455, 0.9600762456112177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 190}], {
             RGBColor[
             0.5789734619268443, 0.5951607891275901, 0.6088088049584353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 212}], {
             RGBColor[
             0.45502366452287835`, 0.5508581833145869, 0.9531576746274935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 242}], {
             RGBColor[
             0.23277585855863503`, 0.3619925645599537, 0.936567612832667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 250}], {
             RGBColor[
             0.4305045847165491, 0.5317036918179742, 0.9507138418962268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 280}], {
             RGBColor[
             0.20576616949629753`, 0.33360366884224035`, 0.935029450997821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 115}], {
             RGBColor[
             0.6816891588124241, 0.749316104284522, 0.9704370761789735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 134}], {
             RGBColor[
             0.7948650675415945, 0.8401518601004587, 0.980061543396153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 146}], {
             RGBColor[
             0.5606173880479739, 0.6391296076516999, 0.9627159159790775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 159}], {
             RGBColor[
             0.5291388886179178, 0.6060437088985722, 0.9609232620048025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 175}], {
             RGBColor[
             0.8519805379825862, 0.8848101708644278, 0.9857438583564258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 204}], {
             RGBColor[
             0.6503375447485182, 0.7230010585514706, 0.9682072440476084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 235}], {
             RGBColor[
             0.5290226818888786, 0.6059215682584198, 0.9609166442034962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 242}], {
             RGBColor[
             0.5709274916503634, 0.6499661802361355, 0.9633030611268021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 252}], {
             RGBColor[
             0.8653152371483008, 0.8954428980184023, 0.9870157338668781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 253}], {
             RGBColor[
             0.5920469326199979, 0.6721640517451186, 0.9645057820466097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 280}], {
             RGBColor[
             0.5439178025880259, 0.6215772845184222, 0.9617648992919562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 292}], {
             RGBColor[
             0.6210375515257403, 0.6976228770823791, 0.9663402743884197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 135}], {
             RGBColor[
             0.3447351556876591, 0.4662117099217347, 0.9434411867729502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 224}], {
             RGBColor[
             0.41118540250280167`, 0.5305493161756059, 0.947427024931778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 249}], {
             RGBColor[
             0.39817230002725545`, 0.5192780208688357, 0.9465978415490709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 254}], {
             RGBColor[
             0.7094267865796675, 0.7704650216648762, 0.9473349435336387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 258}], {
             RGBColor[
             0.3235329364750017, 0.44392683323089077`, 0.9422337517546618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 260}], {
             RGBColor[
             0.35620634276046015`, 0.47826865485051684`, 0.9440944539066457]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 278}], {
             RGBColor[
             0.5026787638766391, 0.6071362917921275, 0.9539918601468049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 288}], {
             RGBColor[
             0.3178418429160961, 0.4379451330643084, 0.9419096523957007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 290}], {
             RGBColor[
             0.40655505179895757`, 0.5265387391241293, 0.9471319830793874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 145}], {
             RGBColor[
             0.44393041022856017`, 0.5392223840313445, 0.952522144216567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 169}], {
             RGBColor[
             0.6470489424464152, 0.7233514464488374, 0.9660348026581744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 187}], {
             RGBColor[
             0.4721854865800526, 0.5689202607520745, 0.9541312290151449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 213}], {
             RGBColor[
             0.7888384439011327, 0.8353751421080718, 0.9794790897887778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 219}], {
             RGBColor[
             0.5668981462051167, 0.6575597995611888, 0.9599244240621102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 221}], {
             RGBColor[
             0.8180306005680308, 0.858652175434273, 0.9822634637518125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 231}], {
             RGBColor[
             0.5444947447808726, 0.6381550992752049, 0.9584968991339073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 264}], {
             RGBColor[
             0.556134126702668, 0.6482365468835187, 0.9592385502576628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 132}], {
             RGBColor[
             0.7396859244532064, 0.7920681173921706, 0.8309399954620689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 146}], {
             RGBColor[
             0.3631881830826408, 0.48199657541938223`, 0.9448207037510586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 159}], {
             RGBColor[
             0.33170968365258463`, 0.4489106766662544, 0.9430280497767837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 204}], {
             RGBColor[
             0.45290833978318507`, 0.5658680263191528, 0.9503120318195897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 242}], {
             RGBColor[
             0.37349828668503027`, 0.49283314800381783`, 0.9454078488987833]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 243}], {
             RGBColor[
             0.5510038473737897, 0.6463687715953166, 0.9577961877403143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 294}], {
             RGBColor[
             0.43672595239272216`, 0.5518516557119733, 0.9492809044045927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 119}], {
             RGBColor[
             0.3064999892592457, 0.43125908668106894`, 0.9410671485293128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 133}], {
             RGBColor[
             0.33786030042464105`, 0.46422076207446944`, 0.9428530718567593]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 152}], {
             RGBColor[
             0.36843847696711884`, 0.4935446233177903, 0.94469755184836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 164}], {
             RGBColor[
             0.2955915764806756, 0.41979365321747464`, 0.9404459305591237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 168}], {
             RGBColor[
             0.3517620554333727, 0.4788323880108225, 0.9436447562387029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 210}], {
             RGBColor[
             0.5706376161237237, 0.6592466802020027, 0.9608196052367881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 241}], {
             RGBColor[
             0.486602850002041, 0.5925743380206141, 0.9531437445995254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 277}], {
             RGBColor[
             0.302118888840783, 0.4266542723634544, 0.9408176513417386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 161}], {
             RGBColor[
             0.8886893577393563, 0.8483194140812368, 0.6301133060421726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 120}], {
             RGBColor[
             0.4991483788086781, 0.602668930778001, 0.9541563614067264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 130}], {
             RGBColor[
             0.5050613453841514, 0.6077904452313345, 0.9545331304082845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 176}], {
             RGBColor[
             0.5087649310295695, 0.6109983049697687, 0.9547691196106585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[
             0.7398328157698872, 0.7965443742756056, 0.9749860092429135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 220}], {
             RGBColor[
             0.7727494593424851, 0.8226403855483192, 0.9728963677826209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 226}], {
             RGBColor[
             0.7739967554078042, 0.5315997885762159, 0.4567046970209727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 228}], {
             RGBColor[
             0.45189845545254587`, 0.5609205454798032, 0.9511757676129319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 266}], {
             RGBColor[
             0.5061952772436035, 0.6087726000149196, 0.9546053835436723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 152}], {
             RGBColor[
             0.2772621687320862, 0.4059347560760317, 0.9392041404593118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 164}], {
             RGBColor[
             0.20441526824564293`, 0.3321837859757161, 0.9349525191700756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 168}], {
             RGBColor[
             0.2605857471983401, 0.39122252076906394`, 0.9381513448496548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 241}], {
             RGBColor[
             0.3954265417670084, 0.5049644707788555, 0.9476503332104773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 130}], {
             RGBColor[
             0.4002586972604394, 0.52110569880509, 0.9467251081479344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 176}], {
             RGBColor[
             0.4039622829058575, 0.5243135585435241, 0.9469610973503082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 287}], {
             RGBColor[
             0.4108287233086032, 0.5302609241030531, 0.9473986208610163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 125}], {
             RGBColor[
             0.6918610915181141, 0.7524057172154064, 0.8667823804407402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 127}], {
             RGBColor[
             0.33503770531024013`, 0.46177597205413085`, 0.9426732185919925]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 136}], {
             RGBColor[
             0.47342730359160035`, 0.5817245557430095, 0.9521488690846243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 137}], {
             RGBColor[
             0.31548718263958436`, 0.44122713315253986`, 0.941559845248305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 160}], {
             RGBColor[
             0.4017390476945333, 0.522387903946526, 0.9468194347685723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 181}], {
             RGBColor[
             0.37172328544871613`, 0.4963897593252752, 0.9449068569401653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 232}], {
             RGBColor[
             0.3916685699546195, 0.513665362285141, 0.9461777528319588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 240}], {
             RGBColor[
             0.448613684673906, 0.5615797420648319, 0.9501954501081423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 246}], {
             RGBColor[
             0.5141061075639382, 0.6147494413669887, 0.9553512535446955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 256}], {
             RGBColor[
             0.33271267130534704`, 0.459332213899318, 0.9425408113449933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 296}], {
             RGBColor[
             0.3089178480421185, 0.43432234597073277`, 0.941185731361439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 299}], {
             RGBColor[
             0.6841488557369575, 0.7478998133387241, 0.9356297405948337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 136}], {
             RGBColor[
             0.3850735904709687, 0.49655947852158955`, 0.9468353109603428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 160}], {
             RGBColor[
             0.31338533457390155`, 0.43722282672510593`, 0.941505876644291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 181}], {
             RGBColor[
             0.2833695723280844, 0.4112246821038552, 0.9395932988158838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 207}], {
             RGBColor[
             0.23109400917188477`, 0.36022483421906915`, 0.9364718339981648]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 231}], {
             RGBColor[
             0.2986290884990374, 0.42444170804555137`, 0.9405656216928366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 232}], {
             RGBColor[
             0.3033148568339878, 0.42850028506372106`, 0.9408641947076775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 240}], {
             RGBColor[
             0.36025997155327427`, 0.4764146648434119, 0.9448818919838609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 246}], {
             RGBColor[
             0.4257523944433065, 0.5295843641455688, 0.950037695420414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 256}], {
             RGBColor[
             0.2443589581847153, 0.37416713667789797`, 0.937227253220712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 296}], {
             RGBColor[
             0.22056413492148685`, 0.34915726874931274`, 0.9358721732371575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 299}], {
             RGBColor[
             0.5957951426163257, 0.6627347361173042, 0.9303161824705523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 144}], {
             RGBColor[
             0.5664641401566901, 0.6540324087462355, 0.9612306238370891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 157}], {
             RGBColor[
             0.3141458851177694, 0.4435489689999227, 0.9413468272828018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 229}], {
             RGBColor[
             0.4032286854463287, 0.523638266871362, 0.9469253739067849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 257}], {
             RGBColor[
             0.661138288975925, 0.7283098360668843, 0.9391346652897057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 259}], {
             RGBColor[
             0.3979935104368444, 0.5191437078300922, 0.9465807724465609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 261}], {
             RGBColor[
             0.36195685686888207`, 0.48793056976439614`, 0.9442845487471719]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 125}], {
             RGBColor[
             0.787793161988678, 0.8319517765403899, 0.8738747133958487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 142}], {
             RGBColor[
             0.6568802273985275, 0.7309835030961899, 0.9670476600899933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 150}], {
             RGBColor[
             0.7777733737625578, 0.8257249038285241, 0.9466281579331988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 200}], {
             RGBColor[
             0.4447003891077281, 0.5557537765568783, 0.9505474896634472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 237}], {
             RGBColor[
             0.6055907118257327, 0.6906848472676237, 0.9620934656682442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 282}], {
             RGBColor[
             0.5811676554164509, 0.6708571098284158, 0.9601707932031021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 295}], {
             RGBColor[
             0.46903391442707987`, 0.5771298567413496, 0.9520870304243794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 136}], {
             RGBColor[
             0.773257287844238, 0.8201508990762657, 0.8727303961365369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 150}], {
             RGBColor[
             0.9816712875446316, 0.984605187836797, 0.860117352030003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[
             0.9392249836730353, 0.951686773267338, 0.8882124781308781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 192}], {
             RGBColor[
             0.8341468508832184, 0.8690592207188442, 0.8778824960535118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 195}], {
             RGBColor[
             0.9603486416594649, 0.9685302047592956, 0.8902272714869359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 200}], {
             RGBColor[
             0.6485983028898019, 0.714634060565151, 0.8640366837602513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 256}], {
             RGBColor[
             0.6325426555579847, 0.6977585572325741, 0.863122338396906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 299}], {
             RGBColor[
             0.983978839989595, 0.9863261566719803, 0.8562112676467464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 155}], {
             RGBColor[
             0.9064507282107169, 0.9282432219984136, 0.9909392737264977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 163}], {
             RGBColor[
             0.609902821314029, 0.6843786220392118, 0.9665153981720216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 184}], {
             RGBColor[
             0.6561049104254338, 0.7262198796589028, 0.9693925933842886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 189}], {
             RGBColor[
             0.5643070452517871, 0.6364545704586206, 0.9639187861781828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 197}], {
             RGBColor[
             0.569832488283725, 0.6422621614185098, 0.9642334519846911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 214}], {
             RGBColor[
             0.6963574876162997, 0.7608506820125673, 0.9720220949852412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 216}], {
             RGBColor[
             0.6648698417343719, 0.7338116226204483, 0.9699510870567698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 275}], {
             RGBColor[
             0.9298933657142572, 0.9469357448102932, 0.993175253419075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 293}], {
             RGBColor[
             0.7467364679688475, 0.801750607809967, 0.9759881128628795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 136}], {
             RGBColor[
             0.41643390163636396`, 0.5295211539149901, 0.9486212342877892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 137}], {
             RGBColor[
             0.258493780684348, 0.3890237313245204, 0.93803221045147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 141}], {
             RGBColor[
             0.3997861856320259, 0.5160057880916091, 0.9473106651013347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 165}], {
             RGBColor[
             0.4012965744630507, 0.5172319897868765, 0.9474295684428495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 170}], {
             RGBColor[
             0.5824015974651613, 0.6610570281060624, 0.9641033162821304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 192}], {
             RGBColor[
             0.4773234646753443, 0.5784294755575686, 0.9537733342047641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 228}], {
             RGBColor[
             0.2889450936638527, 0.4210299919907361, 0.9397663676769723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 232}], {
             RGBColor[
             0.3346751679993831, 0.46146196045712157`, 0.9426501180351239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 240}], {
             RGBColor[
             0.3916202827186696, 0.5093763402368124, 0.9466678153113073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 256}], {
             RGBColor[
             0.27571926935011065`, 0.4071288120712985, 0.9390131765481584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 281}], {
             RGBColor[
             0.3502058835079445, 0.47491388563417913`, 0.9436397214940568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 299}], {
             RGBColor[
             0.627155453781721, 0.6956964115107047, 0.9321021057979987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 173}], {
             RGBColor[
             0.6041094773941917, 0.6730508896040595, 0.9398300556298727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 209}], {
             RGBColor[
             0.645072506850962, 0.3627704852433416, 0.4404556954213492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 218}], {
             RGBColor[
             0.6082185821379398, 0.6761154531939055, 0.9328744131248654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 276}], {
             RGBColor[
             0.3654245091400471, 0.48383241736062665`, 0.9449949084532578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 279}], {
             RGBColor[
             0.26742286454753905`, 0.39840876460134966`, 0.9385407085680829]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 161}], {
             RGBColor[
             0.7366709614945357, 0.794292477062899, 0.9743668374659848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 230}], {
             RGBColor[
             0.6740399351425049, 0.7452843873173498, 0.9681456595398334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 263}], {
             RGBColor[
             0.4782614419475839, 0.5834894271628679, 0.9531328362119207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 265}], {
             RGBColor[
             0.8155021070705565, 0.8552503744939205, 0.9103302287774433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 269}], {
             RGBColor[
             0.6432126127792965, 0.7212018487908839, 0.9650730801443752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 289}], {
             RGBColor[
             0.584001799347313, 0.6731416123928826, 0.9604051086479308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 298}], {
             RGBColor[
             0.43281872921730463`, 0.5361282939822538, 0.9505302203262925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 176}], {
             RGBColor[
             0.4098752494813308, 0.5294350729968578, 0.9473378663518663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 199}], {
             RGBColor[
             0.6409431342216485, 0.7149811423026946, 0.9675547559841214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 220}], {
             RGBColor[
             0.6738597777942463, 0.7410771535754082, 0.9654651145238289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 226}], {
             RGBColor[
             0.7080703010423117, 0.4772243005942753, 0.45175052818177797`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 228}], {
             RGBColor[
             0.3530087739043072, 0.47935731350689226`, 0.9437445143541399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 266}], {
             RGBColor[
             0.40730559569536473`, 0.5272093680420086, 0.9471741302848802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 139}], {
             RGBColor[
             0.6329582151421961, 0.26901776505795566`, 0.42876857747382346`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 143}], {
             RGBColor[
             0.625487701678531, 0.26116578174973293`, 0.428343142783702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 172}], {
             RGBColor[
             0.6404444704667268, 0.27688629406003995`, 0.42919490863963317`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 174}], {
             RGBColor[
             0.6305654108378796, 0.2665027760215637, 0.42863231080852937`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 183}], {
             RGBColor[
             0.6350186499329236, 0.2711834126621213, 0.4288859161870152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 283}], {
             RGBColor[
             0.7007241194181035, 0.3317918846806034, 0.43293721980795985`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 188}], {
             RGBColor[
             0.8544765751368415, 0.8841653218954286, 0.840725405066648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 212}], {
             RGBColor[
             0.851172063255389, 0.8815838120984174, 0.8403960422047241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 243}], {
             RGBColor[
             0.806429817979905, 0.8462538169352829, 0.8361943192514284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 294}], {
             RGBColor[
             0.6921519229988375, 0.7517367010519397, 0.8276790359157068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 162}], {
             RGBColor[
             0.5566432306739479, 0.6405180056189891, 0.961646460262819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 164}], {
             RGBColor[
             0.23577557941103827`, 0.36514546136911663`, 0.936738442497522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 210}], {
             RGBColor[
             0.5108216190540864, 0.6045984883536446, 0.9571121171751864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 239}], {
             RGBColor[
             0.5512915122929932, 0.6362506906505414, 0.961136008586108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 241}], {
             RGBColor[
             0.4267868529324037, 0.537926146172256, 0.9494362565379237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 277}], {
             RGBColor[
             0.2423028917711457, 0.3720060805150963, 0.9371101632801369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 144}], {
             RGBColor[
             0.7459348335550118, 0.801449228378666, 0.9753114711175674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 159}], {
             RGBColor[
             0.44488559238175496`, 0.5397464324821911, 0.9526525169939632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 175}], {
             RGBColor[
             0.7677272417464234, 0.8185128944480469, 0.9774731133455865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 204}], {
             RGBColor[
             0.5660842485123554, 0.6567037821350895, 0.9599364990367691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 235}], {
             RGBColor[
             0.44476938565271584`, 0.5396242918420389, 0.952645899192657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 252}], {
             RGBColor[
             0.781061940912138, 0.8291456216020212, 0.9787449888560389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 253}], {
             RGBColor[
             0.507793636383835, 0.6058667753287377, 0.9562350370357705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 292}], {
             RGBColor[
             0.5367842552895774, 0.6313256006659982, 0.9580695293775805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 224}], {
             RGBColor[
             0.3018458825293665, 0.4290837227078142, 0.9407026434248925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 249}], {
             RGBColor[
             0.28883278005382035`, 0.4178124274010441, 0.9398734600421854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 254}], {
             RGBColor[
             0.6000872666062324, 0.6689994281970846, 0.9406105620267531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 258}], {
             RGBColor[
             0.2141934165015666, 0.34246123976309906`, 0.9355093702477764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 260}], {
             RGBColor[
             0.24686682278702504`, 0.3768030613827251, 0.9373700723997602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 288}], {
             RGBColor[
             0.20850232294266094`, 0.33647953959651666`, 0.9351852708888151]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 137}], {
             RGBColor[
             0.3968833789657082, 0.5089723150133991, 0.9475078609441018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 165}], {
             RGBColor[
             0.5396861727444109, 0.6371805734757552, 0.9569052189354813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 181}], {
             RGBColor[
             0.45311948177483996`, 0.5641349411861345, 0.950854872635962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 232}], {
             RGBColor[
             0.47306476628074334`, 0.5814105441460002, 0.9521257685277555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 240}], {
             RGBColor[
             0.5300098810000298, 0.6293249239256912, 0.956143465803939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 256}], {
             RGBColor[
             0.41410886763147087`, 0.5270773957601772, 0.9484888270407901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 296}], {
             RGBColor[
             0.39031404436824235`, 0.502067527831592, 0.9471337470572357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 299}], {
             RGBColor[
             0.7655450520630813, 0.8156449951995834, 0.9415777562906305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 170}], {
             RGBColor[
             0.5628510747945056, 0.6405081892044713, 0.962989942938443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 192}], {
             RGBColor[
             0.45777294200468854`, 0.5578806366559776, 0.9526599608610766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 195}], {
             RGBColor[
             0.5839747327809351, 0.657351620696429, 0.9650047362945007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 220}], {
             RGBColor[
             0.5902455748831361, 0.6622009931576611, 0.9603735945029739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 228}], {
             RGBColor[
             0.2693945709931969, 0.4004811530891451, 0.9386529943332849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 232}], {
             RGBColor[
             0.31512464532872736`, 0.4409131215555306, 0.9415367446914364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 256}], {
             RGBColor[
             0.2561687466794549, 0.3865799731697075, 0.937899803204471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 266}], {
             RGBColor[
             0.3236913927842545, 0.4483332076242615, 0.9420826102640252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 299}], {
             RGBColor[
             0.6076049311110653, 0.6751475726091136, 0.9309887324543112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 154}], {
             RGBColor[
             0.46734075968648614`, 0.5752066277338344, 0.9521053326314709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 171}], {
             RGBColor[
             0.7783515494848375, 0.5553958321063086, 0.46115352790356867`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 245}], {
             RGBColor[
             0.42130956036582856`, 0.5291567015594674, 0.9493985459342552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 258}], {
             RGBColor[
             0.39685324183851367`, 0.5034515601671051, 0.9480057947740057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 147}], {
             RGBColor[
             0.2894133260317646, 0.41897896046880156`, 0.9398861508548886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 148}], {
             RGBColor[
             0.526300383192805, 0.611904689498931, 0.9594125782121006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 172}], {
             RGBColor[
             0.25380343161396945`, 0.3840938770662453, 0.9377651020106617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 183}], {
             RGBColor[
             0.24566470081326444`, 0.3755395549693674, 0.9373016133317347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 206}], {
             RGBColor[
             0.5330672374709609, 0.6172199144134967, 0.9600793639982805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 244}], {
             RGBColor[
             0.35301995143828724`, 0.4737962843992035, 0.9440152407606375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 272}], {
             RGBColor[
             0.3406266251164173, 0.4633373460806717, 0.9431494169864205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 149}], {
             RGBColor[
             0.28991151398711956`, 0.41861153164116144`, 0.9399471478454252]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 171}], {
             RGBColor[
             0.6560907505496987, 0.4475564721944074, 0.4527948111433321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 196}], {
             RGBColor[
             0.35826735828716394`, 0.47702280374971306`, 0.9445224170843936]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 198}], {
             RGBColor[
             0.21863861334011053`, 0.3471334234821667, 0.9357625176316521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 222}], {
             RGBColor[
             0.5922030354348113, 0.662896118869768, 0.9526768344213337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 230}], {
             RGBColor[
             0.4692921371350496, 0.5662034809418525, 0.9539151133940107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 245}], {
             RGBColor[
             0.23791836196312025`, 0.3673976616916155, 0.9368604707939003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 263}], {
             RGBColor[
             0.27351364394012856`, 0.4044085207873705, 0.9389022900660982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 289}], {
             RGBColor[
             0.37925400133985765`, 0.49406070601738517`, 0.9461745625021082]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 298}], {
             RGBColor[
             0.22807093120984923`, 0.3570473876067564, 0.9362996741804699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 165}], {
             RGBColor[
             0.5230384567400729, 0.6236652076523741, 0.9555946497490267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 179}], {
             RGBColor[
             0.48443067017735253`, 0.592159167875344, 0.9526002024299179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 232}], {
             RGBColor[
             0.4564170502764052, 0.5678951783226193, 0.950815199341301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[
             0.5133621649956918, 0.6158095581023102, 0.9548328966174845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 281}], {
             RGBColor[
             0.47194776578496667`, 0.5813471034996769, 0.951804802800234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[
             0.8507583529544813, 0.883636914392597, 0.9532902987241476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 185}], {
             RGBColor[
             0.4651756378068801, 0.5584747310638433, 0.9542192789840176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 210}], {
             RGBColor[
             0.73673207067181, 0.7942599600707203, 0.9743942257180787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 237}], {
             RGBColor[
             0.6785756910176561, 0.7485968578316965, 0.9687556064591929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 239}], {
             RGBColor[
             0.7772019639107168, 0.825912162367617, 0.9784181171290004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 282}], {
             RGBColor[
             0.6541526346083744, 0.7287691203924886, 0.9668329339940509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 283}], {
             RGBColor[
             0.5878684840226733, 0.6747544780456624, 0.9616706665726491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 295}], {
             RGBColor[
             0.5420188936190034, 0.6350418673054224, 0.9587491712153282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 297}], {
             RGBColor[
             0.739903403510448, 0.7967374293872866, 0.9747103145376437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 167}], {
             RGBColor[
             0.45966442912398, 0.5568242336097528, 0.9532496634729443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 172}], {
             RGBColor[
             0.2425976614184719, 0.3723159021039112, 0.9371269499754794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 174}], {
             RGBColor[
             0.22777907197520106`, 0.35674062504619686`, 0.9362830532288237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 185}], {
             RGBColor[
             0.2103242886297437, 0.3383945410529373, 0.9352890291393379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 237}], {
             RGBColor[
             0.42372434184051977`, 0.5285166678207905, 0.9498253566145132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 239}], {
             RGBColor[
             0.5223506147335805, 0.6058319723567109, 0.9594878672843207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 283}], {
             RGBColor[
             0.33301713484553697`, 0.4546742880347564, 0.9427404167279694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 297}], {
             RGBColor[
             0.48505205433331167`, 0.5766572393763807, 0.955780064692964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 158}], {
             RGBColor[
             0.6087557209872791, 0.6906632504250334, 0.9639254059706377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 235}], {
             RGBColor[
             0.480092447902296, 0.5672189365366271, 0.9561665719249106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 252}], {
             RGBColor[
             0.8163850031617181, 0.8567402662966095, 0.9822656615882925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 253}], {
             RGBColor[
             0.5431166986334152, 0.633461420023326, 0.9597557097680243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 257}], {
             RGBColor[
             0.8759320446238268, 0.9033213003939031, 0.9567361853024376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 292}], {
             RGBColor[
             0.5721073175391576, 0.6589202453605865, 0.9615902021098341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 169}], {
             RGBColor[
             0.383924359087092, 0.49149782858156466`, 0.9471206548523352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 219}], {
             RGBColor[
             0.30377356284579343`, 0.42570618169391605`, 0.9410102762562711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 221}], {
             RGBColor[
             0.5549060172087075, 0.6267985575670003, 0.9633493159459734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 264}], {
             RGBColor[
             0.2930095433433448, 0.41638292901624596`, 0.9403244024518237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 159}], {
             RGBColor[
             0.2106379128881344, 0.3387241800334324, 0.9353068895768877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 204}], {
             RGBColor[
             0.3318365690187349, 0.4556815296863308, 0.9425908716196936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 235}], {
             RGBColor[
             0.21052170615909527`, 0.33860203939328015`, 0.9353002717755814]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 242}], {
             RGBColor[
             0.2524265159205801, 0.38264665137099585`, 0.9376866886988873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 243}], {
             RGBColor[
             0.4299320766093394, 0.5361822749624946, 0.9500750275404182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 292}], {
             RGBColor[
             0.3025365757959569, 0.4303033482172395, 0.9407239019605049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 148}], {
             RGBColor[
             0.5731396605973964, 0.6585925664046135, 0.9621731238050422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 172}], {
             RGBColor[
             0.3006427090185608, 0.43078175397192797`, 0.9405256476036032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 183}], {
             RGBColor[
             0.2925039782178558, 0.42222743187505, 0.9400621589246763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 206}], {
             RGBColor[
             0.5799065148755522, 0.6639077913191793, 0.9628399095912222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 244}], {
             RGBColor[
             0.39985922884287856`, 0.5204841613048861, 0.9467757863535791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 270}], {
             RGBColor[
             0.2589711990425127, 0.38698235486076693`, 0.9381525167579419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 272}], {
             RGBColor[
             0.3874659025210086, 0.5100252229863543, 0.9459099625793621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 172}], {
             RGBColor[
             0.5375297661796012, 0.6237074830020573, 0.9600520749608151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 183}], {
             RGBColor[
             0.5293910353788962, 0.6151531609051794, 0.9595885862818883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 203}], {
             RGBColor[
             0.8796465300761307, 0.9066008985887865, 0.9762312897095633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 206}], {
             RGBColor[
             0.8167935720365926, 0.8568335203493086, 0.9823663369484341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 244}], {
             RGBColor[
             0.636746286003919, 0.7134098903350155, 0.966302213710791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 270}], {
             RGBColor[
             0.4958582562035531, 0.5799080838908963, 0.9576789441151536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 272}], {
             RGBColor[
             0.624352959682049, 0.7029509520164836, 0.965436389936574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 171}], {
             RGBColor[
             0.6934098334859774, 0.484491708271014, 0.4550039070150732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 227}], {
             RGBColor[
             0.30269052393588886`, 0.4320430813333457, 0.9406748935571565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 245}], {
             RGBColor[
             0.29389698636753836`, 0.42280051580652533`, 0.940174114601512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 289}], {
             RGBColor[
             0.4352326257442758, 0.549463560132295, 0.9494882063097199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 298}], {
             RGBColor[
             0.28404955561426737`, 0.4124502417216663, 0.9396133179880816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 200}], {
             RGBColor[
             0.6385785146636818, 0.7084071878532854, 0.9367901282976014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 237}], {
             RGBColor[
             0.7994688373816865, 0.8433382585640308, 0.9483361043023986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 282}], {
             RGBColor[
             0.7750457809724047, 0.8235105211248229, 0.9464134318372563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 295}], {
             RGBColor[
             0.6629120399830336, 0.7297832680377567, 0.9383296690585337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 167}], {
             RGBColor[
             0.4896990137396462, 0.58839248634347, 0.9549600886346203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 194}], {
             RGBColor[
             0.27022578153527044`, 0.4013548080706567, 0.93870033054399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 251}], {
             RGBColor[
             0.5016695820562697, 0.5977439852921049, 0.9561532030131001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 286}], {
             RGBColor[
             0.25610552289955874`, 0.3865135209684175, 0.937896202703737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 241}], {
             RGBColor[
             0.4573650294748815, 0.5672500074155769, 0.9512807365295244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 277}], {
             RGBColor[
             0.27288106831362346`, 0.4013299417584172, 0.9389546432717375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 163}], {
             RGBColor[
             0.26147900416521164`, 0.3921613904770087, 0.9382022145124629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 211}], {
             RGBColor[
             0.5316466240743194, 0.6149910656661284, 0.9601099147441035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 216}], {
             RGBColor[
             0.3164460245855546, 0.44159439105824516`, 0.9416379033972111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 219}], {
             RGBColor[
             0.3303370942025257, 0.453626137375006, 0.942523030069814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 221}], {
             RGBColor[
             0.5814695485654398, 0.6547185132480902, 0.9648620697595163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 171}], {
             RGBColor[
             0.6894351983504161, 0.48104907908756145`, 0.45475064677886706`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 179}], {
             RGBColor[
             0.3906497527152556, 0.5127829139996474, 0.9461128346983713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 245}], {
             RGBColor[
             0.2879350336641966, 0.4176365720313465, 0.9397942242472028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 156}], {
             RGBColor[
             0.9371511916023827, 0.9470658209656729, 0.706372758821955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 184}], {
             RGBColor[
             0.6317751147558146, 0.7068199610066588, 0.9670719957538554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 197}], {
             RGBColor[
             0.5455026926141058, 0.6228622427662657, 0.9619128543542579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 202}], {
             RGBColor[
             0.5514735085066653, 0.6291379488409387, 0.9622528834863087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 214}], {
             RGBColor[
             0.6720276919466803, 0.7414507633603233, 0.9697014973548079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 275}], {
             RGBColor[
             0.9055635700446378, 0.9275358261580491, 0.9908546557886417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 293}], {
             RGBColor[
             0.7224066722992282, 0.7823506891577229, 0.9736675152324462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 178}], {
             RGBColor[
             0.8973766440839552, 0.9154914124530772, 0.7025416799580892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 202}], {
             RGBColor[
             0.6065037675679503, 0.6673604664604421, 0.6800069662121992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 208}], {
             RGBColor[
             0.663073841824261, 0.7244874183954451, 0.6833139262461321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 214}], {
             RGBColor[
             0.7270579510079653, 0.7796732809798268, 0.6874555800806986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 268}], {
             RGBColor[
             0.9898785896035842, 0.9872092986478855, 0.6398463513866367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 201}], {
             RGBColor[
             0.6358824829192178, 0.7000489637179603, 0.8259257000633491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 218}], {
             RGBColor[
             0.625386243818776, 0.6941597541130833, 0.9338520860603097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 229}], {
             RGBColor[
             0.3657041860553098, 0.48816629145206814`, 0.9446430973652296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 257}], {
             RGBColor[
             0.6236137895849061, 0.6928378606475905, 0.9368523887481504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 259}], {
             RGBColor[
             0.3604690110458255, 0.4836717324107983, 0.9442984959050056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 261}], {
             RGBColor[
             0.32443235747786314`, 0.45245859434510227`, 0.9420022722056165]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 284}], {
             RGBColor[
             0.618860943628686, 0.6442609962930695, 0.621223887025977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 175}], {
             RGBColor[
             0.6305481291786907, 0.7077269164944142, 0.9660870481986568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 177}], {
             RGBColor[
             0.3834282379922883, 0.5065280009104967, 0.9456526861659585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 217}], {
             RGBColor[
             0.36531794453256805`, 0.4895137567255877, 0.9445473395342303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 252}], {
             RGBColor[
             0.6438828283444054, 0.7183596436483887, 0.9673589237091091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 253}], {
             RGBColor[
             0.3706145238161024, 0.4950807973751051, 0.9448489718888408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 175}], {
             RGBColor[
             0.5020010628227467, 0.5844047432461603, 0.958334831954236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 204}], {
             RGBColor[
             0.3003580695886787, 0.42259563093320296`, 0.9407982176454186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 235}], {
             RGBColor[
             0.17904320672903912`, 0.3055161406401523, 0.9335076178013064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 252}], {
             RGBColor[
             0.5153357619884613, 0.5950374704001347, 0.9596067074646883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 253}], {
             RGBColor[
             0.24206745746015834`, 0.3717586241268511, 0.93709675564442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 292}], {
             RGBColor[
             0.27105807636590074`, 0.39721744946411164`, 0.93893124798623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 168}], {
             RGBColor[
             0.3586474007480286, 0.48479612805485955`, 0.9440834843536811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[
             0.3814312258777729, 0.5047982893896508, 0.9455254383199101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 246}], {
             RGBColor[
             0.5238140479929949, 0.6231579714313644, 0.9559698349244403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 256}], {
             RGBColor[
             0.3424206117344038, 0.4677407439636936, 0.9431593927247383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 296}], {
             RGBColor[
             0.3186257884711753, 0.4427308760351084, 0.9418043127411839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 299}], {
             RGBColor[
             0.6938567961660143, 0.7563083434030997, 0.9362483219745785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 186}], {
             RGBColor[
             0.5605373694238008, 0.6452869153723371, 0.9617658280173342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 230}], {
             RGBColor[
             0.7672824110394284, 0.8182063741030026, 0.9774179006763594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 265}], {
             RGBColor[
             0.90874458296748, 0.9281723612795731, 0.9196024699139692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 269}], {
             RGBColor[
             0.73645508867622, 0.7941238355765365, 0.9743453212809012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 191}], {
             RGBColor[
             0.6053746576785854, 0.6855653000037351, 0.9646476493215794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 203}], {
             RGBColor[
             0.8922542501933584, 0.9165734713773483, 0.9774551824936766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 210}], {
             RGBColor[
             0.7894205463730306, 0.8355439237465223, 0.9796129936428479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 239}], {
             RGBColor[
             0.8298904396119374, 0.8671961260434191, 0.9836368850537696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 184}], {
             RGBColor[
             0.33522720785912663`, 0.46295536104745694`, 0.9426481201993793]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.24342934268547997`, 0.3731900518471747, 0.9371743129932734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 197}], {
             RGBColor[
             0.2489547857174178, 0.3789976428070639, 0.9374889787997818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 211}], {
             RGBColor[
             0.5591927386568296, 0.6439437786168856, 0.9616786252187527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 216}], {
             RGBColor[
             0.3439921391680648, 0.47054710400900235`, 0.9432066138718603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 168}], {
             RGBColor[
             0.24967733441976991`, 0.37975708730546964`, 0.9375301268794657]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 210}], {
             RGBColor[
             0.4685528951101209, 0.5601713794966499, 0.9547049758775509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 241}], {
             RGBColor[
             0.3845181289884382, 0.49349903731526124`, 0.9470291152402882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 277}], {
             RGBColor[
             0.2000341678271802, 0.32757897165810157`, 0.9347030219825013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 179}], {
             RGBColor[
             0.48594105900837736`, 0.5933853695706113, 0.9527191057714328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 207}], {
             RGBColor[
             0.3857065914453271, 0.5008459291732348, 0.9465417419733033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 232}], {
             RGBColor[
             0.45792743910743006`, 0.5691213800178867, 0.950934102682816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 240}], {
             RGBColor[
             0.5148725538267166, 0.6170357597975775, 0.9549517999589994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 281}], {
             RGBColor[
             0.4734581546159915, 0.5825733051949442, 0.9519237061417489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 217}], {
             RGBColor[
             0.3003802120756296, 0.43304902646989657`, 0.9404175807537812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 233}], {
             RGBColor[
             0.44110848224427723`, 0.5529420698882175, 0.9502552216336996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 262}], {
             RGBColor[
             0.635578489377165, 0.706302953602828, 0.9426317346589989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 271}], {
             RGBColor[
             0.36291332613333893`, 0.48854008510090013`, 0.9443535102324554]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 291}], {
             RGBColor[
             0.5517528131905729, 0.6403972655008167, 0.9605865163571683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 174}], {
             RGBColor[
             0.4672809928630029, 0.564829725017499, 0.9536834155101853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 185}], {
             RGBColor[
             0.44982620951754554`, 0.5464836410242393, 0.9526893914206995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 194}], {
             RGBColor[
             0.4796931178074061, 0.5778756553082416, 0.9543902676636757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 215}], {
             RGBColor[
             0.7989553439212713, 0.5059623511107736, 0.4531579878060116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 282}], {
             RGBColor[
             0.6388032063190399, 0.7167780303528848, 0.9653030464307328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 283}], {
             RGBColor[
             0.5725190557333388, 0.6627633880060584, 0.960140779009331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 286}], {
             RGBColor[
             0.46557285917169433`, 0.5630343682060024, 0.9535861398234227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 297}], {
             RGBColor[
             0.7245539752211134, 0.7847463393476828, 0.9731804269743256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 182}], {
             RGBColor[
             0.39375623851921004`, 0.5144359603327417, 0.9465332528800395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 277}], {
             RGBColor[
             0.25620464677987737`, 0.3866177064514494, 0.9379018476620805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 187}], {
             RGBColor[
             0.4121794354385844, 0.5211957053022946, 0.9487297396509131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 213}], {
             RGBColor[
             0.7288323927596644, 0.787650586658292, 0.9740776004245462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 219}], {
             RGBColor[
             0.5068920950636485, 0.609835244111409, 0.9545229346978785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 221}], {
             RGBColor[
             0.7580245494265625, 0.8109276199844931, 0.9768619743875808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 264}], {
             RGBColor[
             0.49612807556119987`, 0.6005119914337389, 0.9538370608934311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[
             0.7816807587855019, 0.8299139334375196, 0.978731066691737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 195}], {
             RGBColor[
             0.9078825495617485, 0.9293849174779709, 0.9910758421251611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 200}], {
             RGBColor[
             0.5961322107920854, 0.6754887732838264, 0.9648852543984766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 225}], {
             RGBColor[
             0.8891437661060049, 0.9144431202010876, 0.9892885202308428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 228}], {
             RGBColor[
             0.5933023877740102, 0.6725144498706871, 0.9647241001639453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 255}], {
             RGBColor[
             0.6907706779553826, 0.7566336030431798, 0.9712156416454636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 198}], {
             RGBColor[
             0.6458945663879714, 0.43683963616501753`, 0.45221415353922445`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 245}], {
             RGBColor[
             0.6587477321366445, 0.45034912830465007`, 0.4529461223140566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 289}], {
             RGBColor[
             0.7529714917211361, 0.5347911578551632, 0.45915551678619515`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 298}], {
             RGBColor[
             0.6521827783011305, 0.4434489455814107, 0.45257225790510297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 174}], {
             RGBColor[
             0.2502142251574948, 0.3803213935116574, 0.9375607020127205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 183}], {
             RGBColor[
             0.2568940838000606, 0.38734234847249377`, 0.9379411100804493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 203}], {
             RGBColor[
             0.6071495784972951, 0.6787900861561009, 0.9545838135081244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 206}], {
             RGBColor[
             0.5442966204577571, 0.6290227079166231, 0.9607188607469952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 244}], {
             RGBColor[
             0.36424933442508334`, 0.48559907790232987`, 0.944654737509352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 270}], {
             RGBColor[
             0.22336130462471754`, 0.3520972714582107, 0.9360314679137147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 272}], {
             RGBColor[
             0.3518560081032134, 0.4751401395837981, 0.9437889137351351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 186}], {
             RGBColor[
             0.6285470969397239, 0.6987363771809841, 0.9412217419107725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 196}], {
             RGBColor[
             0.7242673597074658, 0.7824751587195102, 0.9474811182601806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 209}], {
             RGBColor[
             0.8862881168703711, 0.5634788171511992, 0.4422695959276923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 230}], {
             RGBColor[
             0.8352921385553514, 0.8716558359116496, 0.9568738145697977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 263}], {
             RGBColor[
             0.6395136453604304, 0.7098608757571676, 0.9418609912418849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 276}], {
             RGBColor[
             0.7272479241691607, 0.784894915222413, 0.9477157592127725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 279}], {
             RGBColor[
             0.6292462795766527, 0.699471262463136, 0.9412615593275975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 185}], {
             RGBColor[
             0.21794085236876662`, 0.34640003246068346`, 0.9357227811765789]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 194}], {
             RGBColor[
             0.24780776065862714`, 0.3777920467446857, 0.9374236574195551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 283}], {
             RGBColor[
             0.3406336985845599, 0.46267977944250255`, 0.9431741687652104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 297}], {
             RGBColor[
             0.49266861807233453`, 0.5846627307841268, 0.956213816730205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 177}], {
             RGBColor[
             0.5777228210010128, 0.6619722896280984, 0.962721066273161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 242}], {
             RGBColor[
             0.5437896658551924, 0.6283272145837236, 0.9607146310762356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 252}], {
             RGBColor[
             0.8381774113531297, 0.8738039323659904, 0.9844273038163116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 253}], {
             RGBColor[
             0.5649091068248269, 0.6505250860927068, 0.9619173519960432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 280}], {
             RGBColor[
             0.5167799767928549, 0.5999383188660103, 0.9591764692413897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 199}], {
             RGBColor[
             0.6446467198670667, 0.7181890020411288, 0.9677907451864953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 226}], {
             RGBColor[
             0.7105393581392572, 0.4793628737532314, 0.4519078543166939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 287}], {
             RGBColor[
             0.4204452755294947, 0.538590298294821, 0.9480113790649483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 217}], {
             RGBColor[
             0.3124926363548901, 0.44375912985927196`, 0.9411813576087346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 247}], {
             RGBColor[
             0.32112609607891923`, 0.45256501698183843`, 0.9416828487748596]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 273}], {
             RGBColor[
             0.5897095955549083, 0.6715302182850473, 0.9638643755308316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 285}], {
             RGBColor[
             0.6627647820381823, 0.7261651413315303, 0.8157301683477614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 182}], {
             RGBColor[
             0.6421182505850977, 0.717885292443822, 0.9666470357846835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 202}], {
             RGBColor[
             0.5116989609882379, 0.5975635403283429, 0.9584218046224429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 208}], {
             RGBColor[
             0.5682690352445484, 0.6546904922633459, 0.9617287646563757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 268}], {
             RGBColor[
             0.8950737830238717, 0.9174123725157863, 0.9182611897968802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 281}], {
             RGBColor[
             0.43485036805327115`, 0.5510672654179141, 0.9489292588226401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 190}], {
             RGBColor[
             0.5969347147527393, 0.6140392046568094, 0.6098316717355776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 250}], {
             RGBColor[
             0.44846583754244407`, 0.5505821073471934, 0.951736708673369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 207}], {
             RGBColor[
             0.2991399004757561, 0.427800296883614, 0.9404913956737839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 232}], {
             RGBColor[
             0.37136074813785913`, 0.4960757477282659, 0.9448837563832966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 240}], {
             RGBColor[
             0.4283058628571456, 0.5439901275079568, 0.9489014536594801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 246}], {
             RGBColor[
             0.4937982857471778, 0.5971598268101136, 0.9540572570960333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 256}], {
             RGBColor[
             0.31240484948858666`, 0.44174259934244287`, 0.9412468148963311]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 296}], {
             RGBColor[
             0.28861002622535814`, 0.41673273141385764`, 0.9398917349127768]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 299}], {
             RGBColor[
             0.663841033920197, 0.730310198781849, 0.9343357441461715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 208}], {
             RGBColor[
             0.4078154483254036, 0.5268812983861899, 0.9474192820727263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 268}], {
             RGBColor[
             0.7346201961047268, 0.7896031786386304, 0.9039517072132309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 244}], {
             RGBColor[
             0.35611060362437835`, 0.4770447558054519, 0.9441912488304252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 189}], {
             RGBColor[
             0.28963143179688483`, 0.4150313094668657, 0.9400515082055405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 197}], {
             RGBColor[
             0.2951568748288227, 0.4208389004267549, 0.9403661740120488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 202}], {
             RGBColor[
             0.3011276907213823, 0.4271146065014279, 0.9407062031440996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 214}], {
             RGBColor[
             0.4216818741613973, 0.5394274210208125, 0.9481548170125988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 216}], {
             RGBColor[
             0.39019422827946965`, 0.5123883616286934, 0.9460838090841275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 275}], {
             RGBColor[
             0.6552177522593547, 0.7255124838185383, 0.9693079754464327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 293}], {
             RGBColor[
             0.47206085451394514`, 0.5803273468182122, 0.9521208348902371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 237}], {
             RGBColor[
             0.4138861222340853, 0.5181760752352771, 0.9492650845622684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 239}], {
             RGBColor[
             0.512512395127146, 0.5954913797711976, 0.9589275952320759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 282}], {
             RGBColor[
             0.3894630658248035, 0.49834833779606924`, 0.9473424120971263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 283}], {
             RGBColor[
             0.3231789152391025, 0.44433369544924295`, 0.9421801446757245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 295}], {
             RGBColor[
             0.27732932483543243`, 0.40462108470900304`, 0.9392586493184036]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 297}], {
             RGBColor[
             0.47521383472687717`, 0.5663166467908672, 0.9552197926407192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 196}], {
             RGBColor[
             0.3868815642238844, 0.5070981484346485, 0.9461519537815657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 230}], {
             RGBColor[
             0.49790634307177006`, 0.5962788256267879, 0.9555446500911828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 263}], {
             RGBColor[
             0.30212784987684904`, 0.43448386547230594`, 0.9405318267632701]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 269}], {
             RGBColor[
             0.46707902070856167`, 0.572196287100322, 0.9524720706957246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 276}], {
             RGBColor[
             0.38986212868557935`, 0.5095179049375512, 0.9463865947341576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 279}], {
             RGBColor[
             0.2918604840930713, 0.4240942521782743, 0.9399323948489826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 205}], {
             RGBColor[
             0.41603522651879277`, 0.5243260102026165, 0.9490332816489753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 213}], {
             RGBColor[
             0.5539689368933017, 0.6332194009615291, 0.9621740267815166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 264}], {
             RGBColor[
             0.3212646196948372, 0.44608080573697584`, 0.9419334872504016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 212}], {
             RGBColor[
             0.7105367433329086, 0.7737959712617091, 0.9717833202981889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 243}], {
             RGBColor[
             0.6657944980574247, 0.7384659760985746, 0.9675815973448934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 294}], {
             RGBColor[
             0.5515166030763572, 0.6439488602152313, 0.9590663140091717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 197}], {
             RGBColor[
             0.203359009655176, 0.3310735912264727, 0.934892366805943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 211}], {
             RGBColor[
             0.5135969625945878, 0.5960197270362944, 0.9590820132249139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 216}], {
             RGBColor[
             0.29839636310582296`, 0.42262305242841114`, 0.9406100018780216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 275}], {
             RGBColor[
             0.5634198870857081, 0.6357471746182561, 0.9638341682403267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 293}], {
             RGBColor[
             0.38026298934029845`, 0.4905620376179299, 0.9466470276841312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 212}], {
             RGBColor[
             0.8311820288554221, 0.815517067277701, 0.6271050877672069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 250}], {
             RGBColor[
             0.806662949049093, 0.7963625757810883, 0.62466125503594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 203}], {
             RGBColor[
             0.6623867498790517, 0.7306753303692166, 0.9579554950847755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 195}], {
             RGBColor[
             0.8028044167719315, 0.8467573649294773, 0.9807458600477947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 200}], {
             RGBColor[
             0.49105407800226847`, 0.5928612207353327, 0.9545552723211103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[
             0.7840656333161877, 0.8318155676525939, 0.9789585381534764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 228}], {
             RGBColor[
             0.48822425498419325`, 0.5898868973221933, 0.9543941180865789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 255}], {
             RGBColor[
             0.5856925451655655, 0.6740060504946861, 0.9608856595680972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 199}], {
             RGBColor[
             0.5634450396504551, 0.6425333995338662, 0.9628115392852533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 220}], {
             RGBColor[
             0.5963616832230529, 0.6686294108065798, 0.9607218978249608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 236}], {
             RGBColor[
             0.24471141445461034`, 0.3745375905645758, 0.9372473250838702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 249}], {
             RGBColor[
             0.2967226995434713, 0.4261052330344559, 0.9403227792850312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 266}], {
             RGBColor[
             0.32980750112417134`, 0.4547616252731802, 0.942430913586012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 283}], {
             RGBColor[
             0.3530458235289631, 0.47572570973324524`, 0.9438810209187009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 286}], {
             RGBColor[
             0.24609962696731857`, 0.3759966899331892, 0.9373263817327925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 297}], {
             RGBColor[
             0.5050807430167377, 0.5977086610748695, 0.9569206688836955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 200}], {
             RGBColor[
             0.617255868778515, 0.692332204775784, 0.9669000477545344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 225}], {
             RGBColor[
             0.9102674240924344, 0.9312865516930453, 0.9913033135869005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.7118943359418122, 0.7734770345351376, 0.9732304350015214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 230}], {
             RGBColor[
             0.5936266058395121, 0.680017607165314, 0.9618040264405908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 263}], {
             RGBColor[
             0.3978481126445911, 0.518222647010832, 0.9467912031126782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 279}], {
             RGBColor[
             0.3875807468608133, 0.5078330337168003, 0.9461917711983907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 289}], {
             RGBColor[
             0.5035884700443202, 0.6078748322408467, 0.9540634755486883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 298}], {
             RGBColor[
             0.35240539991431175`, 0.4708615138302179, 0.9441885872270499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 214}], {
             RGBColor[
             0.3354094520196884, 0.4554697027804195, 0.9429956756130015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 275}], {
             RGBColor[
             0.5689453301176459, 0.6415547655781453, 0.9641488340468352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 293}], {
             RGBColor[
             0.38578843237223626`, 0.4963696285778191, 0.9469616934906397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 222}], {
             RGBColor[
             0.5769087591922204, 0.646820864825683, 0.9518058480151723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 245}], {
             RGBColor[
             0.2226240857205293, 0.35132240764753064`, 0.9359894843877389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 258}], {
             RGBColor[
             0.19816776719321438`, 0.3256172662551685, 0.9345967332274894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 278}], {
             RGBColor[
             0.3773135945948518, 0.48882672481640516`, 0.9463548416196323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 290}], {
             RGBColor[
             0.28118988251717025`, 0.40822917214840704`, 0.9394949645522148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 220}], {
             RGBColor[
             0.9086312481799821, 0.9298310826196793, 0.9859179933584579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 226}], {
             RGBColor[
             0.8645846146328022, 0.603060253290456, 0.46538578073819725`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 228}], {
             RGBColor[
             0.587780244290043, 0.6681112425511633, 0.9641973931887688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 266}], {
             RGBColor[
             0.6420770660811006, 0.7159632970862797, 0.9676270091195092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 225}], {
             RGBColor[
             0.5985170853227714, 0.6773904074989007, 0.965112725860216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 255}], {
             RGBColor[
             0.4001439971721491, 0.5195808903409929, 0.9470398472748369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 282}], {
             RGBColor[
             0.4419727963175749, 0.553539393853177, 0.9503327635675047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 295}], {
             RGBColor[
             0.32983905532820385`, 0.45981214076611077`, 0.942249000788782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 209}], {
             RGBColor[
             0.8960250127664977, 0.5694479992810145, 0.3656815769263804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 218}], {
             RGBColor[
             0.9846473410112434, 0.9861317242504148, 0.8207132353824123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 229}], {
             RGBColor[
             0.7249652832477771, 0.7801382615893997, 0.8315042466873321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 257}], {
             RGBColor[
             0.9828748867773733, 0.9848098307849219, 0.8237135380702529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 259}], {
             RGBColor[
             0.7197301082382928, 0.7756437025481299, 0.8311596452271083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 261}], {
             RGBColor[
             0.6836934546703305, 0.7444305644824338, 0.8288634215277193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 208}], {
             RGBColor[
             0.2773961587285436, 0.4065595462707107, 0.9391940509104857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 214}], {
             RGBColor[
             0.34138026791224807`, 0.46174540885509247`, 0.9433357047450521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 268}], {
             RGBColor[
             0.6042009065078668, 0.6692814265231513, 0.8957264760509902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 275}], {
             RGBColor[
             0.5749161460102056, 0.6478304716528183, 0.9644888631788859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 206}], {
             RGBColor[
             0.8864133843542865, 0.9119161235033522, 0.9768980754957435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 244}], {
             RGBColor[
             0.7063660983216128, 0.768492493489059, 0.9608339522581002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 270}], {
             RGBColor[
             0.5654780685212469, 0.6349906870449399, 0.952210682662463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 235}], {
             RGBColor[
             0.3002418628596396, 0.4224734902930507, 0.9407915998441123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 253}], {
             RGBColor[
             0.3632661135907588, 0.4887159737797495, 0.944380737687226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 292}], {
             RGBColor[
             0.39225673249650117`, 0.51417479911701, 0.9462152300290358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 213}], {
             RGBColor[
             0.7326881838398728, 0.7907808915586139, 0.9743811424226083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 231}], {
             RGBColor[
             0.4883444847196128, 0.5935608487257469, 0.9533989517677377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 244}], {
             RGBColor[
             0.6435131402820748, 0.7187251152495812, 0.966968999496971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 270}], {
             RGBColor[
             0.502625110481709, 0.585223308805462, 0.9583457299013338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 272}], {
             RGBColor[
             0.6311198139602049, 0.7082661769310494, 0.9661031757227541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 231}], {
             RGBColor[
             0.3143994166467091, 0.4410173228253102, 0.9414637185507367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 232}], {
             RGBColor[
             0.3190851849816595, 0.44507589984347984`, 0.9417622915655776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 240}], {
             RGBColor[
             0.376030299700946, 0.4929902796231707, 0.9457799888417611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 268}], {
             RGBColor[
             0.6607709807641775, 0.7264083784581541, 0.899033436084923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 218}], {
             RGBColor[
             0.8890275200328699, 0.5655218595444298, 0.4376325009243541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 276}], {
             RGBColor[
             0.7271648047009415, 0.4373331689889105, 0.4457128311432823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 279}], {
             RGBColor[
             0.6618303749726028, 0.38038406714939255`, 0.44141003121983236`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 239}], {
             RGBColor[
             0.7840688279920759, 0.8312766087780746, 0.979102541966137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 277}], {
             RGBColor[
             0.4750802074702284, 0.5670319986426295, 0.9550766966601657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 216}], {
             RGBColor[
             0.6141597590771726, 0.693376779198122, 0.9651143141035009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 221}], {
             RGBColor[
             0.8791832830570577, 0.906500901387967, 0.9883384804658061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 243}], {
             RGBColor[
             0.6624899861759723, 0.7358844663015633, 0.9672522344829695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 250}], {
             RGBColor[
             0.682713151645127, 0.752059969968085, 0.9690101247049983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 294}], {
             RGBColor[
             0.5482120911949048, 0.6413673504182201, 0.9587369511472479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 231}], {
             RGBColor[
             0.6262781950941217, 0.7024542394846595, 0.9665396969002791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 264}], {
             RGBColor[
             0.6379175770159172, 0.7125356870929733, 0.9672813480240345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 275}], {
             RGBColor[
             0.6954703294502206, 0.7601432861722028, 0.9719374770473852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 293}], {
             RGBColor[
             0.5123134317048109, 0.6149581491718767, 0.9547503364911898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 223}], {
             RGBColor[
             0.7511529204108707, 0.4677343343305467, 0.4489981582314928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 234}], {
             RGBColor[
             0.6814824192768156, 0.4092435916452129, 0.4440464548293236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 271}], {
             RGBColor[
             0.705716084254207, 0.43023357422921205`, 0.44559060253269445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 274}], {
             RGBColor[
             0.7436706517168206, 0.4616598915323533, 0.44840912663144383`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 282}], {
             RGBColor[
             0.75871324812611, 0.4738721489586602, 0.4495933349236294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 286}], {
             RGBColor[
             0.6432263500278798, 0.371376374194072, 0.4417820638520893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 233}], {
             RGBColor[
             0.4351106130638175, 0.5466379290926839, 0.9499136518569247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 247}], {
             RGBColor[
             0.3030158026191989, 0.43555077279692944`, 0.9405775021431313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 262}], {
             RGBColor[
             0.6295806201967054, 0.6999988128072945, 0.942290164882224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 273}], {
             RGBColor[
             0.5715993020951882, 0.6545159741001383, 0.9627590288991033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 229}], {
             RGBColor[
             0.7144690441473354, 0.7742490519845225, 0.9394306326842927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 284}], {
             RGBColor[
             0.9676258017207116, 0.930343756825524, 0.6160114223450401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 221}], {
             RGBColor[
             0.6778737531852641, 0.7451359730968445, 0.9707515957915166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 264}], {
             RGBColor[
             0.4159772793199013, 0.5347203445460902, 0.9477266822973669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 226}], {
             RGBColor[
             0.8865290436812008, 0.6204575941389316, 0.4639926864313355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 228}], {
             RGBColor[
             0.6206968878626408, 0.6942072538238768, 0.9621077517284762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 236}], {
             RGBColor[
             0.5898976229841373, 0.6618352736503889, 0.9603537791570746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 266}], {
             RGBColor[
             0.6749937096536984, 0.7420593083589933, 0.9655373676592165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 231}], {
             RGBColor[
             0.6554703517610199, 0.7257312728108606, 0.9693240708633137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 245}], {
             RGBColor[
             0.59618850781523, 0.6670851030351319, 0.9529038011774205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 261}], {
             RGBColor[
             0.6613582552579484, 0.72971187766143, 0.9568300792374203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 278}], {
             RGBColor[
             0.7508780166895526, 0.8045894202040064, 0.963269158409314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 290}], {
             RGBColor[
             0.654754304611871, 0.7239918675360083, 0.9564092813418965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 234}], {
             RGBColor[
             0.4512533277794971, 0.5624931692123734, 0.9507429819274961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 271}], {
             RGBColor[
             0.48760382524558415`, 0.593978143088372, 0.9530592034825522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 274}], {
             RGBColor[
             0.5445356764395046, 0.6411176190430841, 0.9572869896306764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 287}], {
             RGBColor[
             0.4915353977064101, 0.597383473547362, 0.9533097198032031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 291}], {
             RGBColor[
             0.6764433123028182, 0.7458353234882886, 0.9692922096072651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 249}], {
             RGBColor[
             0.3552830268689629, 0.4821500336549152, 0.9438592982010132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 254}], {
             RGBColor[
             0.6665375134213749, 0.7333370344509557, 0.9445964001855809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 258}], {
             RGBColor[
             0.28064366331670915`, 0.40679884601697025`, 0.9394952084066042]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 260}], {
             RGBColor[
             0.3133170696021676, 0.4411406676365963, 0.941355910558588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 288}], {
             RGBColor[
             0.27495256975780347`, 0.40081714585038786`, 0.9391711090476429]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 234}], {
             RGBColor[
             0.6191381083575526, 0.6955509048002673, 0.9664157092584122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 255}], {
             RGBColor[
             0.6931555524860684, 0.7585352372582541, 0.971443113107203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 287}], {
             RGBColor[
             0.6594201782844655, 0.7304412091352559, 0.9689824471341193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 228}], {
             RGBColor[
             0.6726283744212413, 0.44597770075992105`, 0.4495122863182095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 266}], {
             RGBColor[
             0.7088262556152798, 0.4778790704499986, 0.45179869693870306`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 264}], {
             RGBColor[
             0.33235208464884636`, 0.4577344343895201, 0.9425649019770979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 266}], {
             RGBColor[
             0.3541427057637592, 0.48033946829047725`, 0.9438167674895275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 257}], {
             RGBColor[
             0.7126965899134654, 0.7729271585190296, 0.9424309353721334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 259}], {
             RGBColor[
             0.4495518113743848, 0.5637610302822376, 0.9498770425289886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 261}], {
             RGBColor[
             0.41351515780642245`, 0.5325478922165415, 0.9475808188295997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 284}], {
             RGBColor[
             0.7079437439572454, 0.7243502941645088, 0.62680243364996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 263}], {
             RGBColor[
             0.5088728914924766, 0.6074033242029714, 0.9561838994222953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 269}], {
             RGBColor[
             0.6738240623241892, 0.7451157458309874, 0.9681241433547498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 289}], {
             RGBColor[
             0.6146132488922058, 0.6970555094329861, 0.9634561718583055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 298}], {
             RGBColor[
             0.46343017876219733`, 0.5600421910223573, 0.953581283536667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 240}], {
             RGBColor[
             0.44825114736304894`, 0.5612657304678226, 0.9501723495512737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 256}], {
             RGBColor[
             0.33235013399449, 0.4590182023023087, 0.9425177107881247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 296}], {
             RGBColor[
             0.3085553107312615, 0.4340083343737235, 0.9411626308045704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 299}], {
             RGBColor[
             0.6837863184261004, 0.7475858017417149, 0.935606640037965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 262}], {
             RGBColor[
             0.770308890365353, 0.8198918562256154, 0.9521278057621423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 288}], {
             RGBColor[
             0.3787239467017815, 0.48737196762504764`, 0.9467025146242043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 291}], {
             RGBColor[
             0.6864832141787608, 0.753986168123604, 0.9700825874603117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 255}], {
             RGBColor[
             0.4207650202069303, 0.5377413876423596, 0.948342830673033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 271}], {
             RGBColor[
             0.3830980735445015, 0.5062420290603714, 0.9456316483792986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 274}], {
             RGBColor[
             0.4400299247384219, 0.5533815050150834, 0.9498594345274227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 287}], {
             RGBColor[
             0.3870296460053274, 0.5096473595193614, 0.9458821646999493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 252}], {
             RGBColor[
             0.5152195552594221, 0.5949153297599825, 0.959600089663382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 253}], {
             RGBColor[
             0.24195125073111923`, 0.37163648348669887`, 0.9370901378431136]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 292}], {
             RGBColor[
             0.2709418696368616, 0.3970953088239594, 0.9389246301849236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 249}], {
             RGBColor[
             0.29025863930455575`, 0.419311095878265, 0.9399546606171452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 266}], {
             RGBColor[
             0.3233434408852558, 0.4479674881169892, 0.942062794918126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 239}], {
             RGBColor[
             0.725912448337922, 0.7856135065390508, 0.9734639227072512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 282}], {
             RGBColor[
             0.6028631190355795, 0.6884704645639225, 0.9618787395723017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 283}], {
             RGBColor[
             0.5365789684498785, 0.6344558222170962, 0.9567164721509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 295}], {
             RGBColor[
             0.4907293780462085, 0.5947432114768563, 0.953794976793579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 297}], {
             RGBColor[
             0.6886138879376532, 0.7564387735587205, 0.9697561201158946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 251}], {
             RGBColor[
             0.7742287353033428, 0.8235960107167979, 0.9781200334258995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 300}], {
             RGBColor[
             0.5079628538472739, 0.5906066185851409, 0.9586840949621895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 295}], {
             RGBColor[
             0.5893556509392692, 0.6720585160127768, 0.9634574874633866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 256}], {
             RGBColor[
             0.3892952487137765, 0.5069325820819995, 0.9465354080643082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 281}], {
             RGBColor[
             0.4637818628716104, 0.5747176556448802, 0.9511619530102067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 299}], {
             RGBColor[
             0.7407314331453869, 0.7955001815214058, 0.9396243373141485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 277}], {
             RGBColor[
             0.3910454413485457, 0.5003596564612409, 0.947400836022903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 243}], {
             RGBColor[
             0.44024218021172895`, 0.5470188475469302, 0.9506621726881428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 280}], {
             RGBColor[
             0.23572693046063206`, 0.36509432823771804`, 0.936735672011766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 294}], {
             RGBColor[
             0.32596428523066145`, 0.45250173166358687`, 0.9421468893524212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 294}], {
             RGBColor[
             0.5034698459194209, 0.6060373552550857, 0.9545352281939522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 270}], {
             RGBColor[
             0.32257782444903527`, 0.4417996787911689, 0.9422816066636905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 272}], {
             RGBColor[
             0.45107252792753116`, 0.5648425469167562, 0.9500390524851109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 289}], {
             RGBColor[
             0.38323947372027645`, 0.4982496901827491, 0.946401529258195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 298}], {
             RGBColor[
             0.23205640359026802`, 0.3612363717721203, 0.9365266409365567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 256}], {
             RGBColor[
             0.45478767160380873`, 0.5601022813841564, 0.9516912115008613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 296}], {
             RGBColor[
             0.43099284834058027`, 0.5350924134555712, 0.950336131517307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 299}], {
             RGBColor[
             0.8062238560354191, 0.8486698808235625, 0.9447801407507017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 267}], {
             RGBColor[
             0.41178226953495217`, 0.5294957844717227, 0.9478989927910388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 273}], {
             RGBColor[
             0.5802327618192172, 0.6633218612227048, 0.9632605200652283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 285}], {
             RGBColor[
             0.6532879483024912, 0.7179567842691879, 0.8151263128821581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 270}], {
             RGBColor[
             0.5319053635948836, 0.6085705878466096, 0.9611385065820589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 254}], {
             RGBColor[
             0.6535244109458287, 0.7220657391441856, 0.9437672168028739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 288}], {
             RGBColor[
             0.2619394672822573, 0.3895458505436177, 0.9383419256649359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 300}], {
             RGBColor[
             0.4568416051889599, 0.550626939346668, 0.9536003160475557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 253}], {
             RGBColor[
             0.5782438059905414, 0.6611578132466813, 0.9631892275064955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 292}], {
             RGBColor[
             0.6072344248962838, 0.6866166385839418, 0.9650237198483055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 292}], {
             RGBColor[
             0.33396612036798085`, 0.4633377923106582, 0.9425137680280371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 258}], {
             RGBColor[
             0.5788850473935749, 0.6467145515062406, 0.9394031270084648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 260}], {
             RGBColor[
             0.6115584536790335, 0.6810563731258666, 0.9412638291604487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 288}], {
             RGBColor[
             0.5731939538346693, 0.6407328513396582, 0.9390790276495036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 287}], {
             RGBColor[
             0.46104709013384326`, 0.5726316919773482, 0.9509095685487401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 296}], {
             RGBColor[
             0.24959941208198907`, 0.3796751859879004, 0.9375256893176049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 299}], {
             RGBColor[
             0.624830419776828, 0.6932526533558918, 0.9319696985509995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 259}], {
             RGBColor[
             0.7074614149039811, 0.7684325994777599, 0.9420863339119094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 261}], {
             RGBColor[
             0.6714247613360187, 0.7372194614120637, 0.9397901102125205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 260}], {
             RGBColor[
             0.22566460357436768`, 0.3545181846918812, 0.9361626373814719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 278}], {
             RGBColor[
             0.37213702469054655`, 0.48338582163349175`, 0.9460600436216311]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 290}], {
             RGBColor[
             0.27601331261286505`, 0.4027882689654937, 0.9392001665542136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 260}], {
             RGBColor[
             0.3513273231123633, 0.47406323877623757`, 0.9437778903011103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 261}], {
             RGBColor[
             0.4082799827969381, 0.5280533331752717, 0.9472362173693758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 261}], {
             RGBColor[
             0.315290669544401, 0.44285010071054143`, 0.9414816666017212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 278}], {
             RGBColor[
             0.40481043097600505`, 0.5177276432531178, 0.947920745773615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 290}], {
             RGBColor[
             0.3086867188983235, 0.43713009058511976`, 0.9410608687061974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 278}], {
             RGBColor[
             0.46176309066057986`, 0.5717177376521521, 0.9513790728418805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 290}], {
             RGBColor[
             0.3656393785828983, 0.491120184984154, 0.944519195774463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 271}], {
             RGBColor[
             0.6921137342544146, 0.755489871438298, 0.9462260943608982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 291}], {
             RGBColor[
             0.8809532213116487, 0.9073470518382145, 0.962459100485611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 269}], {
             RGBColor[
             0.4780455691292682, 0.5833207856765055, 0.9531113200268372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 276}], {
             RGBColor[
             0.4008286771062859, 0.5206424035137347, 0.9470258440652701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 279}], {
             RGBColor[
             0.30282703251377785`, 0.43521875075445776`, 0.9405716441800952]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 289}], {
             RGBColor[
             0.4188347556972848, 0.5352605492785041, 0.9484433485303927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 298}], {
             RGBColor[
             0.2676516855672763, 0.39824723086787533`, 0.9385684602087545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 269}], {
             RGBColor[
             0.8152862342522408, 0.8550817330075581, 0.9103087125923597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 273}], {
             RGBColor[
             0.6803657690109413, 0.7484609857749316, 0.9700805195470108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 285}], {
             RGBColor[
             0.7534209554942153, 0.8030959088214147, 0.8219463123639406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 286}], {
             RGBColor[
             0.37194732252914153`, 0.4878951559274498, 0.9456206230826802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 298}], {
             RGBColor[
             0.43260285639898893`, 0.5359596524958914, 0.950508704141209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 272}], {
             RGBColor[
             0.3101844981271653, 0.43134074047263704`, 0.9414157828894736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 274}], {
             RGBColor[
             0.47638042220450894`, 0.584866478891082, 0.9521756560824789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 291}], {
             RGBColor[
             0.6082880580678225, 0.6895841833362866, 0.9641808760590675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 285}], {
             RGBColor[
             0.9218714477784803, 0.9369219855723967, 0.83730783963813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 287}], {
             RGBColor[
             0.48031199466533486`, 0.588271809350072, 0.9524261724031298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 293}], {
             RGBColor[
             0.7458493098027684, 0.8010432119696025, 0.9759034949250234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 279}], {
             RGBColor[
             0.39056131132250815`, 0.510252790219703, 0.9464264121509827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 290}], {
             RGBColor[
             0.4551591400145024, 0.5659977275267304, 0.9509582749463567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 283}], {
             RGBColor[
             0.5121559120405967, 0.6146280847778883, 0.9547937996857578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 295}], {
             RGBColor[
             0.4663063216369267, 0.5749154740376484, 0.951872304328437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 297}], {
             RGBColor[
             0.6641908315283714, 0.7366110361195126, 0.9678334476507525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 295}], {
             RGBColor[
             0.40002217105122573`, 0.5209008316908221, 0.9467100369070351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 297}], {
             RGBColor[
             0.5979066809426705, 0.6825963937726863, 0.9626711802293508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 291}], {
             RGBColor[
             0.4893682776480772, 0.5748271632376467, 0.957033809347673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 298}], {
             RGBColor[
             0.37339204296700546`, 0.48789941609789, 0.9458407326447645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 297}], {
             RGBColor[
             0.5520570905390003, 0.6428837830324464, 0.9597496848720298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 299}], {
             RGBColor[
             0.6010355965135994, 0.6682427854273065, 0.9306146185674452]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.10302533798448267`], {
             RGBColor[
             0.2966508902702116, 0.4291292727997429, 0.9402052013939999]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.10302533798448267`], {
             RGBColor[
             0.39434573068496603`, 0.5159841843517564, 0.9463483391463763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.10302533798448267`], {
             RGBColor[
             0.2682670223774342, 0.3992960280032672, 0.9385887821076758]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.10302533798448267`], {
             RGBColor[
             0.28440691367822346`, 0.4162600770886098, 0.9395079250404264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.10302533798448267`], {
             RGBColor[
             0.6262015893825394, 0.7074176861776922, 0.9637160294496482]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.10302533798448267`], {
             RGBColor[
             0.9940465122242633, 0.9896744165746747, 0.593377780157783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.10302533798448267`], {
             RGBColor[
             0.5012996505433573, 0.6060166654598216, 0.9538832912933504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.10302533798448267`], {
             RGBColor[
             0.9290062075481781, 0.9462283489699287, 0.9930906354812189]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.10302533798448267`], {
             RGBColor[
             0.3769660014344934, 0.5009307364055882, 0.9452409181668273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.10302533798448267`], {
             RGBColor[
             0.38498896020534, 0.5078798200472628, 0.9457521340052818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.10302533798448267`], {
             RGBColor[
             0.20726228541883557`, 0.33517618153605616`, 0.9351146525863044]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.10302533798448267`], {
             RGBColor[
             0.4223674636608853, 0.5402552010422469, 0.9481338591929562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.10302533798448267`], {
             RGBColor[
             0.9947217345231107, 0.9920853158271403, 0.7371380488726311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.10302533798448267`], {
             RGBColor[
             0.4739007114956888, 0.5837729724327863, 0.9517263464458972]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.10302533798448267`], {
             RGBColor[
             0.3339662329848542, 0.4636864982057136, 0.9425010109444185]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.10302533798448267`], {
             RGBColor[
             0.9327444648376366, 0.949209133860252, 0.9934471937986691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.10302533798448267`], {
             RGBColor[
             0.26273661952296956`, 0.3934832239554314, 0.9382738338466119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.10302533798448267`], {
             RGBColor[
             0.6133997978850706, 0.6970246151259122, 0.96270822552846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.10302533798448267`], {
             RGBColor[
             0.2783241208085315, 0.40986667611122035`, 0.9391615189851831]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.10302533798448267`], {
             RGBColor[
             0.23897985408851863`, 0.36851335721789713`, 0.936920921200105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.10302533798448267`], {
             RGBColor[
             0.33818300028015785`, 0.4673388500960189, 0.9427696996277344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.10302533798448267`], {
             RGBColor[
             0.454750801427032, 0.5682262127454333, 0.9502187953768605]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.10302533798448267`], {
             RGBColor[
             0.9775716926035747, 0.9827935855835045, 0.9228494535694423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.10302533798448267`], {
             RGBColor[
             0.3226486768341625, 0.45388379990489625`, 0.9417798662742184]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.10302533798448267`], {
             RGBColor[
             0.8488498408760161, 0.376486859875633, 0.1944119688318643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.10302533798448267`], {
             RGBColor[
             0.2836605549417392, 0.41547560673468775`, 0.9394654210145224]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.10302533798448267`], {
             RGBColor[
             0.2108591363762548, 0.3389566999458262, 0.9353194879272653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.10302533798448267`], {
             RGBColor[
             0.9883272988593894, 0.9894410523506908, 0.8431103960895228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.10302533798448267`], {
             RGBColor[
             0.9415478917525799, 0.9559270938923928, 0.9838283518981652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.10302533798448267`], {
             RGBColor[
             0.462015772782034, 0.5741242437746538, 0.9507907205343933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.10302533798448267`], {
             RGBColor[
             0.8688697058924625, 0.898277134911513, 0.9873547622688079]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.10302533798448267`], {
             RGBColor[
             0.7474227859438135, 0.8026116280936548, 0.9754597763059776]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.10302533798448267`], {
             RGBColor[
             0.24413618524543235`, 0.3739329881940914, 0.9372145666313828]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.10302533798448267`], {
             RGBColor[
             0.6076831653974478, 0.6923835953411013, 0.9622581912783196]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.10302533798448267`], {
             RGBColor[
             0.8382232635421801, 0.8738404936569146, 0.9844316772390359]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.10302533798448267`], {
             RGBColor[
             0.2028150975943005, 0.33050190516447603`, 0.934861391818722]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.10302533798448267`], {
             RGBColor[
             0.2818265424705218, 0.4135479433443314, 0.9393609767174649]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.10302533798448267`], {
             RGBColor[
             0.9926946378575394, 0.9867828939997172, 0.44623459814139327`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.10302533798448267`], {
             RGBColor[
             0.9723961081402035, 0.978933643164964, 0.9316103680573125]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.10302533798448267`], {
             RGBColor[
             0.43637124638508995`, 0.5523845737873678, 0.9490261678450838]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.10302533798448267`], {
             RGBColor[
             0.4057131083775886, 0.5258300355680908, 0.9470726584011727]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.10302533798448267`], {
             RGBColor[
             0.5894787192992654, 0.6776044058976458, 0.9608250705963873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.10302533798448267`], {
             RGBColor[
             0.7770501591659851, 0.8257567572311917, 0.9784127559852194]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.10302533798448267`], {
             RGBColor[
             0.2793888484702789, 0.4109857723913496, 0.9392221536503961]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.10302533798448267`], {
             RGBColor[
             0.8532170655147833, 0.41005526217923677`, 0.19859402807802248`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.10302533798448267`], {
             RGBColor[
             0.34687422976756704`, 0.47486675624411717`, 0.9433234970853196]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.10302533798448267`], {
             RGBColor[
             0.32383927647447497`, 0.454915037472057, 0.9418557302304932]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.10302533798448267`], {
             RGBColor[
             0.18378067501441744`, 0.3104955201809229, 0.9337774096117024]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.10302533798448267`], {
             RGBColor[
             0.638546264732138, 0.7174396497477833, 0.9646878475132044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.10302533798448267`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.10302533798448267`], {
             RGBColor[
             0.5145548245841975, 0.6167778128849613, 0.9549267871491477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.10302533798448267`], {
             RGBColor[
             0.2462256956264024, 0.37612919608710094`, 0.9373335611564254]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.10302533798448267`], {
             RGBColor[
             0.8441739970211836, 0.8785854470047147, 0.9849992635105458]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.10302533798448267`], {
             RGBColor[
             0.4668300415133929, 0.5780326840111057, 0.9511697174041732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.10302533798448267`], {
             RGBColor[
             0.23197936833160687`, 0.36115540283095, 0.9365222538925394]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.10302533798448267`], {
             RGBColor[
             0.3280313519840486, 0.4585460025786082, 0.9421228455750564]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.10302533798448267`], {
             RGBColor[
             0.5806984912207205, 0.6704762211987156, 0.960133858879009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.10302533798448267`], {
             RGBColor[
             0.2774495267668401, 0.4089474223209376, 0.9391117121483546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.10302533798448267`], {
             RGBColor[
             0.19575710954957087`, 0.3230835122271767, 0.9344594498409322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.10302533798448267`], {
             RGBColor[
             0.4887183364114956, 0.5958025878658336, 0.952892844158018]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.10302533798448267`], {
             RGBColor[
             0.9738985493621473, 0.9800541613682681, 0.9290671269679907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.10302533798448267`], {
             RGBColor[
             0.9949960838154189, 0.9917054541917416, 0.6967327877785048]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.10302533798448267`], {
             RGBColor[
             0.27183863501817124`, 0.4030500193420025, 0.9387921801638385]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.10302533798448267`], {
             RGBColor[
             0.5603013136133317, 0.6539168735346578, 0.958528118340432]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.10302533798448267`], {
             RGBColor[
             0.25730889024673265`, 0.3877783363481938, 0.9379647326939361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.10302533798448267`], {
             RGBColor[
             0.2739009772760844, 0.40521767181512075`, 0.9389096275044646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.10302533798448267`], {
             RGBColor[
             0.3521223740010205, 0.4794124349997357, 0.9436579041951235]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.10302533798448267`], {
             RGBColor[
             0.8232457406137177, 0.8618978234277881, 0.9830031077315267]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.10302533798448267`], {
             RGBColor[
             0.5246797524408816, 0.6249976854418193, 0.9557238585588587]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.10302533798448267`], {
             RGBColor[
             0.23035157497681347`, 0.3594444888070024, 0.9364295534690884]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.10302533798448267`], {
             RGBColor[
             0.9364143635464582, 0.9520985169616483, 0.9925180761125405]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.10302533798448267`], {
             RGBColor[
             0.5963861377399453, 0.6832121593634444, 0.9613688478787451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.10302533798448267`], {
             RGBColor[
             0.9437170692889487, 0.9575448629473144, 0.9801565001412028]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.10302533798448267`], {
             RGBColor[
             0.19710595685530763`, 0.32450123626736466`, 0.9345362646995532]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.10302533798448267`], {
             RGBColor[
             0.298681281267784, 0.43126334247241616`, 0.9403208291576174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.10302533798448267`], {
             RGBColor[
             0.7044033276028918, 0.7690045002777339, 0.9711719987382497]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.10302533798448267`], {
             RGBColor[
             0.8249906655524512, 0.8632891792092084, 0.9831695402298959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.10302533798448267`], {
             RGBColor[
             0.5439476994712342, 0.6406402728521816, 0.9572407019299036]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.10302533798448267`], {
             RGBColor[
             0.432520231235832, 0.54904901802273, 0.9487807845650921]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.10302533798448267`], {
             RGBColor[
             0.5333122733984293, 0.632005954845794, 0.956403442230603]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.10302533798448267`], {
             RGBColor[
             0.2370168486926757, 0.36645011408513556`, 0.936809130946818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.10302533798448267`], {
             RGBColor[
             0.9385701984160136, 0.9537063350775071, 0.9888688100101685]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.10302533798448267`], {
             RGBColor[
             0.48287592774202825`, 0.5910594573104488, 0.9524329083461094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.10302533798448267`], {
             RGBColor[
             0.5220191777765901, 0.6228377110718248, 0.9555144083752795]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.10302533798448267`], {
             RGBColor[
             0.7942760375268856, 0.8392137443282516, 0.9801296705552484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.10302533798448267`], {
             RGBColor[
             0.8283337742229476, 0.8659548833167949, 0.9834884089193162]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.10302533798448267`], {
             RGBColor[
             0.2221372464843362, 0.3508107087429013, 0.9359617596134518]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.10302533798448267`], {
             RGBColor[
             0.30499094280590183`, 0.43789519680462563`, 0.9406801550479054]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.10302533798448267`], {
             RGBColor[
             0.9889608109565644, 0.9897030258833909, 0.8326114611625802]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.10302533798448267`], {
             RGBColor[
             0.20207143615372183`, 0.3297202698395692, 0.9348190413998295]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.10302533798448267`], {
             RGBColor[
             0.7011039220017057, 0.766426979545676, 0.9708431448226218]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.10302533798448267`], {
             RGBColor[
             0.8256874619506391, 0.19845066563602165`, 0.17223164861475795`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.10302533798448267`], {
             RGBColor[
             0.689404313227707, 0.7572871562511081, 0.9696770371590897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.10302533798448267`], {
             RGBColor[
             0.2425740486271733, 0.37229108356311896`, 0.937125605261947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.10302533798448267`], {
             RGBColor[
             0.23333868649666736`, 0.36258413240817805`, 0.9365996650511086]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.10302533798448267`], {
             RGBColor[
             0.31646737046914625`, 0.44852986301301057`, 0.9413859988985542]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.10302533798448267`], {
             RGBColor[
             0.5548234999177242, 0.6494697376038688, 0.958096884780421]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.10302533798448267`], {
             RGBColor[
             0.48822316809406824`, 0.5954005879186676, 0.9528538626942088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.10302533798448267`], {
             RGBColor[
             0.2551817728765027, 0.3855426011250513, 0.9378435965064897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.10302533798448267`], {
             RGBColor[
             0.5041405894104055, 0.6083230676149288, 0.9541069404076663]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.10302533798448267`], {
             RGBColor[
             0.3196058130549668, 0.4512482242381374, 0.9415859776849068]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.10302533798448267`], {
             RGBColor[
             0.8538666811262977, 0.8863141302092316, 0.9859237603732528]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.10302533798448267`], {
             RGBColor[
             0.24810460241780025`, 0.3781040462544312, 0.937440562118602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.10302533798448267`], {
             RGBColor[
             0.7186727006270777, 0.7801518429354796, 0.9725942364864281]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.10302533798448267`], {
             RGBColor[
             0.20473528105347694`, 0.33252013972673355`, 0.9349707434260652]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.10302533798448267`], {
             RGBColor[
             0.7216956879754213, 0.7825134236275604, 0.972895539613888]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.10302533798448267`], {
             RGBColor[
             0.2783305889696085, 0.40987347455861733`, 0.9391618873373876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.10302533798448267`], {
             RGBColor[
             0.9685340344996436, 0.9760533149673997, 0.9381478513406522]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.10302533798448267`], {
             RGBColor[
             0.9943294509565155, 0.9902795939134682, 0.6241739150679897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.10302533798448267`], {
             RGBColor[
             0.7128976361407737, 0.7756403186666632, 0.9720186320294792]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.10302533798448267`], {
             RGBColor[
             0.2028150975943005, 0.33050190516447603`, 0.934861391818722]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.10302533798448267`], {
             RGBColor[
             0.8791183637777572, 0.9064491365168397, 0.9883322884069923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.10302533798448267`], {
             RGBColor[
             0.4540746756610942, 0.5676773033895264, 0.9501655682798357]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.10302533798448267`], {
             RGBColor[
             0.7070549935878835, 0.7710760018986172, 0.9714362920224061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.10302533798448267`], {
             RGBColor[
             0.484259953847091, 0.5921830720522042, 0.9525418639509546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.10302533798448267`], {
             RGBColor[
             0.39767629749427835`, 0.5188689539228275, 0.9465605599183611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.10302533798448267`], {
             RGBColor[
             0.9474652780872534, 0.829424364313922, 0.2765875334818344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.10302533798448267`], {
             RGBColor[
             0.6039510269323901, 0.6893536772042456, 0.9619643836670766]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.10302533798448267`], {
             RGBColor[
             0.2153236810242131, 0.3436492194393103, 0.9355737371402646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.10302533798448267`], {
             RGBColor[
             0.39434573068496603`, 0.5159841843517564, 0.9463483391463763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.10302533798448267`], {
             RGBColor[
             0.3920311072654765, 0.5139793738821503, 0.9462008533888275]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.10302533798448267`], {
             RGBColor[
             0.2153236810242131, 0.3436492194393103, 0.9355737371402646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.10302533798448267`], {
             RGBColor[
             0.35167038450878835`, 0.4790209444192166, 0.9436291038243572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.10302533798448267`], {
             RGBColor[
             0.5838952482066041, 0.6730714925321171, 0.9603855192990445]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.10302533798448267`], {
             RGBColor[
             0.9916910757707518, 0.9908320605486626, 0.7873639074926528]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.10302533798448267`], {
             RGBColor[
             0.9307805238803362, 0.9476431406506577, 0.993259871356931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.10302533798448267`], {
             RGBColor[
             0.27804430335500374`, 0.4095725702261114, 0.9391455837951574]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.10302533798448267`], {
             RGBColor[
             0.24228606236507805`, 0.3719883917422732, 0.9371092048703581]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.10302533798448267`], {
             RGBColor[
             0.6434284855976122, 0.7213704902772463, 0.9650945963294588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.10302533798448267`], {
             RGBColor[
             0.4061716638359127, 0.5262272132584236, 0.9471018771494925]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.10302533798448267`], {
             RGBColor[
             0.8281502983997074, 0.21738110580537404`, 0.17459006357976167`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.10302533798448267`], {
             RGBColor[
             0.9951118950593217, 0.991953162732137, 0.709338126973183]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.10302533798448267`], {
             RGBColor[
             0.27804430335500374`, 0.4095725702261114, 0.9391455837951574]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.10302533798448267`], {
             RGBColor[
             0.7106117713054316, 0.7738545836840777, 0.9717907983853138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.10302533798448267`], {
             RGBColor[
             0.23539563571422398`, 0.36474611645394306`, 0.9367168052660647]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.10302533798448267`], {
             RGBColor[
             0.5548234999177242, 0.6494697376038688, 0.958096884780421]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.10302533798448267`], {
             RGBColor[
             0.23894325801369223`, 0.3684748924229294, 0.9369188371077826]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.10302533798448267`], {
             RGBColor[
             0.6007152863881181, 0.6867267572619552, 0.9617096543185233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.10302533798448267`], {
             RGBColor[
             0.2425740486271733, 0.37229108356311896`, 0.937125605261947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.10302533798448267`], {
             RGBColor[
             0.23393288958270148`, 0.3632086775262516, 0.9366335040378135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.10302533798448267`], {
             RGBColor[
             0.521528067909048, 0.6224390059571068, 0.9554757464075119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.10302533798448267`], {
             RGBColor[
             0.729865206590451, 0.7888955136602627, 0.9737098008809421]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.10302533798448267`], {
             RGBColor[
             0.22016250823617814`, 0.3487351336384507, 0.9358493011915826]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.10302533798448267`], {
             RGBColor[
             0.7812578958045919, 0.8290438730732542, 0.9788321438498212]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.10302533798448267`], {
             RGBColor[
             0.18080582686923688`, 0.30736876616407177`, 0.9336079964107278]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.10302533798448267`], {
             RGBColor[
             0.24211641231819056`, 0.37181007878656025`, 0.9370995435511627]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.10302533798448267`], {
             RGBColor[
             0.336252603436356, 0.4656668373744842, 0.9426466964478303]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.10302533798448267`], {
             RGBColor[
             0.8100267177584368, 0.8515182954347429, 0.981699551162254]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.10302533798448267`], {
             RGBColor[
             0.3458901383915377, 0.4740143857560713, 0.9432607916530369]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.10302533798448267`], {
             RGBColor[
             0.9716514993185116, 0.9783783151249312, 0.9328707965673532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.10302533798448267`], {
             RGBColor[
             0.2802316774675106, 0.411871639105885, 0.9392701515149346]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.10302533798448267`], {
             RGBColor[
             0.33920065643995934`, 0.4682202927127531, 0.942834543778359]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.10302533798448267`], {
             RGBColor[
             0.23393288958270148`, 0.3632086775262516, 0.9366335040378135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.10302533798448267`], {
             RGBColor[
             0.3339662329848542, 0.4636864982057136, 0.9425010109444185]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.10302533798448267`], {
             RGBColor[
             0.8821209325410977, 0.9088433033461695, 0.9886186760960645]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.10302533798448267`], {
             RGBColor[
             0.9921814506636677, 0.9852883385851764, 0.42412684154784575`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.10302533798448267`], {
             RGBColor[
             0.2766213857267505, 0.4080769935806288, 0.9390645507412464]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.10302533798448267`], {
             RGBColor[
             0.43625354616996626`, 0.5522826277768125, 0.9490186680914543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.10302533798448267`], {
             RGBColor[
             0.17915941345807826`, 0.30563828128030457`, 0.9335142356026127]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.10302533798448267`], {
             RGBColor[
             0.41144698812359004`, 0.5307964340109016, 0.9474380161483172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.10302533798448267`], {
             RGBColor[
             0.8299134373914592, 0.8672144638485516, 0.9836390786025108]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.10302533798448267`], {
             RGBColor[
             0.8352421579928921, 0.8714634410118668, 0.9841473367304805]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.10302533798448267`], {
             RGBColor[
             0.2890251187477218, 0.4211141034277659, 0.9397709249871121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.10302533798448267`], {
             RGBColor[
             0.19350685546707277`, 0.32071835251212183`, 0.9343313011998865]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.10302533798448267`], {
             RGBColor[
             0.5245488455710977, 0.6248914093476415, 0.9557135530905416]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.10302533798448267`], {
             RGBColor[
             0.30637808125608934`, 0.43935316726543017`, 0.9407591505305561]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.10302533798448267`], {
             RGBColor[
             0.6991663500117818, 0.7649133335810548, 0.9706500257543059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.10302533798448267`], {
             RGBColor[
             0.3058478133724671, 0.4387958220988175, 0.9407289525590449]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.10302533798448267`], {
             RGBColor[
             0.587042891304947, 0.6756268909990576, 0.9606333132939426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.10302533798448267`], {
             RGBColor[
             0.886758891575319, 0.9125414859860133, 0.9890610487691034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.10302533798448267`], {
             RGBColor[
             0.8671696810331972, 0.48973036952848537`, 0.21087546469609134`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.10302533798448267`], {
             RGBColor[
             0.2650328146007656, 0.3958966705693717, 0.9384045987593762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.10302533798448267`], {
             RGBColor[
             0.9659328924233053, 0.9741133874658459, 0.9425509063893873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.10302533798448267`], {
             RGBColor[
             0.23539563571422398`, 0.36474611645394306`, 0.9367168052660647]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.10302533798448267`], {
             RGBColor[
             0.8248427121874152, 0.863171205212016, 0.9831554283058592]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.10302533798448267`], {
             RGBColor[
             0.413578835126749, 0.532642932735292, 0.9475738555542402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.10302533798448267`], {
             RGBColor[
             0.33060292981461037`, 0.46077337404418095`, 0.9422867042404628]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.10302533798448267`], {
             RGBColor[
             0.8025718375042427, 0.845694486320978, 0.9809565183683328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.10302533798448267`], {
             RGBColor[
             0.447333272445657, 0.5618793297935811, 0.949724658452324]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.10302533798448267`], {
             RGBColor[
             0.2387376032460903, 0.36825873622291444`, 0.9369071253730066]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.10302533798448267`], {
             RGBColor[
             0.35141546363195575`, 0.47880014476840005`, 0.9436128604915031]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.10302533798448267`], {
             RGBColor[
             0.48166466366595295`, 0.5900760985666661, 0.9523375532010342]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.10302533798448267`], {
             RGBColor[
             0.24875535299935558`, 0.3787880263756158, 0.9374776214015224]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.10302533798448267`], {
             RGBColor[
             0.3814292969705315, 0.504796618667148, 0.9455253154116463]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.10302533798448267`], {
             RGBColor[
             0.20048606902330926`, 0.32805394846742386`, 0.934728757087093]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.10302533798448267`], {
             RGBColor[
             0.29116130145614244`, 0.42335936689612247`, 0.9398925774321576]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.10302533798448267`], {
             RGBColor[
             0.23731597957222172`, 0.36676451960553164`, 0.9368261660078836]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.10302533798448267`], {
             RGBColor[
             0.7138412552143611, 0.7763774810587203, 0.9721126831601129]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.10302533798448267`], {
             RGBColor[
             0.19783356662323814`, 0.3252660002665835, 0.9345777009994346]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.10302533798448267`], {
             RGBColor[
             0.9551318262593882, 0.8598196730907043, 0.28275621809814855`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.10302533798448267`], {
             RGBColor[
             0.37550715736427887`, 0.4996671589956033, 0.9451479619126784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.10302533798448267`], {
             RGBColor[
             0.6766026259956849, 0.7472863808890259, 0.9684010846143707]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.10302533798448267`], {
             RGBColor[
             0.2511754746935259, 0.3813317277207668, 0.9376154437517562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.10302533798448267`], {
             RGBColor[
             0.2602198856030303, 0.3908379770354284, 0.9381305095730456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.10302533798448267`], {
             RGBColor[
             0.9290062075481781, 0.9462283489699287, 0.9930906354812189]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.10302533798448267`], {
             RGBColor[
             0.48260182699162646`, 0.5908369299731746, 0.9524113301309737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.10302533798448267`], {
             RGBColor[
             0.20888445268711384`, 0.33688118218636187`, 0.9352070326124514]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.10302533798448267`], {
             RGBColor[
             0.2033443370975196, 0.33105816943808186`, 0.9348915312254906]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.10302533798448267`], {
             RGBColor[
             0.8757146046073844, 0.9037350713469657, 0.9880076348187504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.10302533798448267`], {
             RGBColor[
             0.30550553000885206`, 0.4384360605816394, 0.9407094600278498]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.10302533798448267`], {
             RGBColor[
             0.9951435801116851, 0.9920209338552919, 0.7127868493854518]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.10302533798448267`], {
             RGBColor[
             0.22082608447223304`, 0.34943259433570784`, 0.9358870908765529]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.10302533798448267`], {
             RGBColor[
             0.9492663423938245, 0.96168350174283, 0.9707630282568727]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.10302533798448267`], {
             RGBColor[
             0.42155672571927916`, 0.5395529805861013, 0.9480821996882246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.10302533798448267`], {
             RGBColor[
             0.5947544734653638, 0.6818875007997013, 0.9612403972900669]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.10302533798448267`], {
             RGBColor[
             0.8235604263147486, 0.8621487452638743, 0.9830331227346142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.10302533798448267`], {
             RGBColor[
             0.24686433731955648`, 0.3768004489988279, 0.9373699308560649]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.10302533798448267`], {
             RGBColor[
             0.3339662329848542, 0.4636864982057136, 0.9425010109444185]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.10302533798448267`], {
             RGBColor[
             0.846465729093904, 0.3581615319938758, 0.19212894069684472`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.10302533798448267`], {
             RGBColor[
             0.7435989347531691, 0.7996244064811779, 0.9750786505552153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.10302533798448267`], {
             RGBColor[
             0.8293603585659374, 0.8667734538060053, 0.9835863254503933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.10302533798448267`], {
             RGBColor[
             0.7072322314514562, 0.7712144614646979, 0.9714539574362651]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.10302533798448267`], {
             RGBColor[
             0.8706218942143817, 0.8996742823175264, 0.9875218875551496]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.10302533798448267`], {
             RGBColor[
             0.4619344513522631, 0.5740582233744771, 0.9507843186135515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.10302533798448267`], {
             RGBColor[
             0.8488498408760161, 0.376486859875633, 0.1944119688318643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.10302533798448267`], {
             RGBColor[
             0.3989591595884078, 0.5199801045902388, 0.9466423027566085]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.10302533798448267`], {
             RGBColor[
             0.2943823428951698, 0.426744885674363, 0.9400760109770063]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.10302533798448267`], {
             RGBColor[
             0.9741511019108017, 0.9802425146455377, 0.9286396213793728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.10302533798448267`], {
             RGBColor[
             0.42674129882234996`, 0.5440435972237604, 0.9484125561018143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.10302533798448267`], {
             RGBColor[
             0.9415478917525799, 0.9559270938923928, 0.9838283518981652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.10302533798448267`], {
             RGBColor[
             0.9290062075481781, 0.9462283489699287, 0.9930906354812189]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.10302533798448267`], {
             RGBColor[
             0.9504731812869212, 0.9625835602132843, 0.9687201648048539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.10302533798448267`], {
             RGBColor[
             0.5557590794805798, 0.650229283240374, 0.9581705370307498]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.10302533798448267`], {
             RGBColor[
             0.36829612934450906`, 0.49342132896168533`, 0.9446884815837203]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.10302533798448267`], {
             RGBColor[
             0.8915286406366907, 0.9163447544161619, 0.9895159916925822]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.10302533798448267`], {
             RGBColor[
             0.8590196196455112, 0.4527228442622011, 0.20407485369792067`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.10302533798448267`], {
             RGBColor[
             0.25949090948024, 0.39007177691062006`, 0.9380889954612762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.10302533798448267`], {
             RGBColor[
             0.2998458839727016, 0.43248741375536087`, 0.9403871515587872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.10302533798448267`], {
             RGBColor[
             0.4547869863838691, 0.5682555893235074, 0.9502216439892126]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.10302533798448267`], {
             RGBColor[
             0.7046513846873976, 0.7691982843574534, 0.971196722750208]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.10302533798448267`], {
             RGBColor[
             0.3819344959738617, 0.5052341966517925, 0.9455575062454086]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.10302533798448267`], {
             RGBColor[
             0.39130603264376246`, 0.5133513506881318, 0.9461546522750902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.10302533798448267`], {
             RGBColor[
             0.5758388832324651, 0.6665309725110049, 0.959751292736843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.10302533798448267`], {
             RGBColor[
             0.34674757607841444`, 0.4747570551843727, 0.9433154268242423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.10302533798448267`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.10302533798448267`], {
             RGBColor[
             0.23824735421569476`, 0.3677434534083849, 0.9368792064159841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.10302533798448267`], {
             RGBColor[
             0.6272861754448613, 0.7082982020031303, 0.9638014120374438]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.10302533798448267`], {
             RGBColor[
             0.8253499839616569, 0.8635756899552708, 0.9832038123405332]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.10302533798448267`], {
             RGBColor[
             0.8245387212309827, 0.8629288110749713, 0.9831264333770587]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.10302533798448267`], {
             RGBColor[
             0.5051962620823355, 0.6091801102475135, 0.9541900468274571]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.10302533798448267`], {
             RGBColor[
             0.5755294025098037, 0.6662797221184007, 0.9597269292806899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.10302533798448267`], {
             RGBColor[
             0.26273661952296956`, 0.3934832239554314, 0.9382738338466119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.10302533798448267`], {
             RGBColor[
             0.6177477409004883, 0.700554471138429, 0.9630505115296738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.10302533798448267`], {
             RGBColor[
             0.4634658542494011, 0.575301485235288, 0.9509048762593278]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.10302533798448267`], {
             RGBColor[
             0.24190383434353901`, 0.3715866458569794, 0.9370874375499871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.10302533798448267`], {
             RGBColor[
             0.6361811078623999, 0.7155195088518271, 0.9645016537005635]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.10302533798448267`], {
             RGBColor[
             0.3116492623432281, 0.4443566599194959, 0.9410789933092564]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.10302533798448267`], {
             RGBColor[
             0.8821209325410977, 0.9088433033461695, 0.9886186760960645]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.10302533798448267`], {
             RGBColor[
             0.34226992439341675`, 0.4708787383481451, 0.9430301148183061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.10302533798448267`], {
             RGBColor[
             0.6581940718387977, 0.7329054784714722, 0.9665662919737316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.10302533798448267`], {
             RGBColor[
             0.7231074866450288, 0.783616331478325, 0.9730362545112657]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.10302533798448267`], {
             RGBColor[
             0.8515121105188443, 0.8844366595199649, 0.9856991793267639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.10302533798448267`], {
             RGBColor[
             0.30497550146223845`, 0.4378789669733977, 0.9406792756862272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.10302533798448267`], {
             RGBColor[
             0.9647788974982408, 0.973252739940226, 0.9445043187874416]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.10302533798448267`], {
             RGBColor[
             0.49478246433544615`, 0.6007257201003464, 0.9533702345218239]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.10302533798448267`], {
             RGBColor[
             0.27339423534521756`, 0.4046850539164856, 0.9388807693011593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.10302533798448267`], {
             RGBColor[
             0.9706061934430615, 0.9775987277145519, 0.9346402267550542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.10302533798448267`], {
             RGBColor[
             0.1929911972889092, 0.3201763630722551, 0.934301935229488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.10302533798448267`], {
             RGBColor[
             0.4443166363649005, 0.5592664712409678, 0.9495324410687648]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.10302533798448267`], {
             RGBColor[
             0.25833800985982613`, 0.38886000631150724`, 0.9380233395334557]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.10302533798448267`], {
             RGBColor[
             0.3722433292289758, 0.49684019510957567`, 0.9449399936699867]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.10302533798448267`], {
             RGBColor[
             0.9647788974982408, 0.973252739940226, 0.9445043187874416]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.10302533798448267`], {
             RGBColor[
             0.31309439829755564`, 0.4456083640484894, 0.9411710760943827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.10302533798448267`], {
             RGBColor[
             0.40521325981745265`, 0.5253970918684201, 0.9470408084929196]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.10302533798448267`], {
             RGBColor[
             0.9875757285435007, 0.9891302587105947, 0.8555658612254277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.10302533798448267`], {
             RGBColor[
             0.40843952755481683`, 0.5281915228255936, 0.9472463834202679]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.10302533798448267`], {
             RGBColor[
             0.5119152767266762, 0.6146349090239497, 0.9547189922728212]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.10302533798448267`], {
             RGBColor[
             0.9875757285435007, 0.9891302587105947, 0.8555658612254277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.10302533798448267`], {
             RGBColor[
             0.6429967399609808, 0.7210332073045215, 0.9650515639592917]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.10302533798448267`], {
             RGBColor[
             0.18168979464866944`, 0.3082978723470497, 0.9336583370680533]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.10302533798448267`], {
             RGBColor[
             0.4194485710105885, 0.5377270029363701, 0.9479478699343548]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.10302533798448267`], {
             RGBColor[
             0.4386792016056612, 0.5543836085982244, 0.9491732287108939]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.10302533798448267`], {
             RGBColor[
             0.8488162612952064, 0.8822870625259136, 0.9854420468212003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.10302533798448267`], {
             RGBColor[
             0.5333122733984293, 0.632005954845794, 0.956403442230603]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.10302533798448267`], {
             RGBColor[
             0.9290062075481781, 0.9462283489699287, 0.9930906354812189]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.10302533798448267`], {
             RGBColor[
             0.4885629559150162, 0.59567644297898, 0.9528806120361576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.10302533798448267`], {
             RGBColor[
             0.20656148018728765`, 0.33443959080408125`, 0.9350747427651162]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.10302533798448267`], {
             RGBColor[
             0.551282852092184, 0.6465952801947285, 0.9578181520137742]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.10302533798448267`], {
             RGBColor[
             0.2925596667300001, 0.4248291374604261, 0.9399722122658077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.10302533798448267`], {
             RGBColor[
             0.20871724139829456`, 0.33670543252000473`, 0.9351975101769201]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.10302533798448267`], {
             RGBColor[
             0.4223674636608853, 0.5402552010422469, 0.9481338591929562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.10302533798448267`], {
             RGBColor[
             0.5784400626262978, 0.6686427271247146, 0.9599560671071596]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.10302533798448267`], {
             RGBColor[
             0.4458717614548958, 0.560613442431062, 0.9496315322643561]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.10302533798448267`], {
             RGBColor[
             0.9611005015306215, 0.8804449990055103, 0.30338322331070755`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.10302533798448267`], {
             RGBColor[
             0.9949266342617542, 0.9915569086188797, 0.6891736324550598]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.10302533798448267`], {
             RGBColor[
             0.23197936833160687`, 0.36115540283095, 0.9365222538925394]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.10302533798448267`], {
             RGBColor[
             0.4273117159322404, 0.5445376638543499, 0.9484489025756564]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.10302533798448267`], {
             RGBColor[
             0.1816090101710979, 0.3082129627390903, 0.9336537365115656]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.10302533798448267`], {
             RGBColor[
             0.5245751130970139, 0.6249127345085188, 0.9557156209664028]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.10302533798448267`], {
             RGBColor[
             0.35903542793682086`, 0.48540017485873227`, 0.9440983978789391]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.10302533798448267`], {
             RGBColor[
             0.7971275451250565, 0.8414413637362032, 0.9804138821837804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.10302533798448267`], {
             RGBColor[
             0.36295673927372324`, 0.4887966176479187, 0.9443482603698471]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.10302533798448267`], {
             RGBColor[
             0.5626924120573588, 0.6558580749692763, 0.958716354368828]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.10302533798448267`], {
             RGBColor[
             0.38919195093835335`, 0.5115202393717424, 0.9460199448582306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.10302533798448267`], {
             RGBColor[
             0.35417258064755563`, 0.48118822095058217`, 0.9437885415497143]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.10302533798448267`], {
             RGBColor[
             0.2258045888187606, 0.3546653180593152, 0.9361706093340505]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.10302533798448267`], {
             RGBColor[
             0.7499416004304451, 0.8045793451143106, 0.9757108281943454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.10302533798448267`], {
             RGBColor[
             0.222208972836997, 0.35088609768726126`, 0.9359658443231262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.10302533798448267`], {
             RGBColor[
             0.9762666042084384, 0.9818202527952979, 0.9250586278008399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.10302533798448267`], {
             RGBColor[
             0.19057572373289094`, 0.3176375472150109, 0.9341643775838457]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1FO4EAYYBuBzsm2dTrZdW7WsZbtVy3bLtWxr2bat5WVjyzZXrfc8u3i/
//a7+f7gJu2rtAsMCAjIJEJuKEIThrCEIzwRiEgkIhOFqEQjOjGISSxiE4e4
xCM+CUhIIhKThKQkI4jkBJOClKQiNWlISzrSk4GMIX3JTBayko3s5CAnuchN
HvKSj/wUoCCF+IEfKUwRivITxShOCUpSitKUoSzlKE8FfqYilahMFapSjerU
oCa1qE0d6lKP+jSgIY1oTBN+oSnNaM6vtKAlrWhNG9rSjvZ0oCOd6EwXutKN
7vSgJ73ozW/0oS/96M8ABjKIwQzhd4YyjOGMYCSjGM0YxjKO8UxgIpOYzBSm
Mo3pzGAms5jNH8xhLvOYzwIWsojFLGEpy1jOClayitWsYS3rWM8GNrKJzWxh
K9vYzg52sovd7GEv+9jPAQ5yiMMc4U+OcozjnOAkpzjNX5zhLOc4zwUuconL
XOEq17jODW5yi9v8zT/c4S73uM8DHvKIxzzhKc94zgte8orXvOEt73jPBz7y
ic/8yxe+8o3/CBl/IKEITRjCEo7wRCAikYhMFKISjejEICaxiE0c4hKP+CQg
IYlITBKSkowgkhNMClKSitSkIS3pSE8GMgb+/6++Az6VhWw=
          "], {Null, CompressedData["
1:eJxN2nu4llWZB+C1RcxDZpqQRxAUUVHStBgOUSMyo5BNY0aKowyCpqCIyVg4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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[57, 280] -> 
             RGBColor[
              0.2575556675749038, 0.38803771496668804`, 0.9379787862977012], 
             UndirectedEdge[46, 187] -> 
             RGBColor[
              0.32803381097302087`, 0.4570126210374179, 0.9421792248536764], 
             UndirectedEdge[96, 298] -> 
             RGBColor[
              0.3453589956577786, 0.4713821632368721, 0.9433064816157806], 
             UndirectedEdge[165, 207] -> 
             RGBColor[
              0.8629243195572578, 0.8731271056740303, 0.676546302374514], 
             UndirectedEdge[69, 224] -> 
             RGBColor[
              0.9812813612748328, 0.9481895871324358, 0.4098590677551779], 
             UndirectedEdge[51, 110] -> 
             RGBColor[
              0.9932540497607107, 0.99147839046011, 0.7614613836320072], 
             UndirectedEdge[122, 231] -> 
             RGBColor[
              0.5346560481729267, 0.6328742791629598, 0.9565707376227028], 
             UndirectedEdge[71, 246] -> 
             RGBColor[
              0.6142322345348998, 0.6977004246990872, 0.9627737579908505], 
             UndirectedEdge[9, 239] -> 
             RGBColor[
              0.4639819639121217, 0.5745750992225973, 0.9512619801674704], 
             UndirectedEdge[99, 229] -> 
             RGBColor[
              0.3569385719957474, 0.4835839836336185, 0.9439647880725508], 
             UndirectedEdge[49, 112] -> 
             RGBColor[
              0.24438397329964223`, 0.374193429149736, 0.9372286777945005], 
             UndirectedEdge[115, 243] -> 
             RGBColor[
              0.21987898042507611`, 0.348437127932281, 0.9358331547021821], 
             UndirectedEdge[58, 95] -> 
             RGBColor[
              0.5187848450827122, 0.6202119340859072, 0.9552597898578664], 
             UndirectedEdge[210, 239] -> 
             RGBColor[
              0.39484568065555037`, 0.5164172158880604, 0.9463801955164135], 
             UndirectedEdge[94, 150] -> 
             RGBColor[
              0.9119777121048072, 0.931971896043791, 0.9679461351700305], 
             UndirectedEdge[21, 108] -> 
             RGBColor[
              0.3636875531699619, 0.4894296119130661, 0.9443948271850822], 
             UndirectedEdge[83, 202] -> 
             RGBColor[
              0.22220476853383342`, 0.3508816786980681, 0.9359656048942807], 
             UndirectedEdge[172, 174] -> 
             RGBColor[
              0.33090944455997406`, 0.4574098756542951, 0.9424391100455509], 
             UndirectedEdge[3, 157] -> 
             RGBColor[
              0.36165267017657554`, 0.4876670985403879, 0.9442651662401199], 
             UndirectedEdge[181, 246] -> 
             RGBColor[
              0.656342497401248, 0.7307927865257904, 0.9668372480070162], 
             UndirectedEdge[159, 253] -> 
             RGBColor[
              0.27205955347524674`, 0.4032822186474281, 0.9388047611431494], 
             UndirectedEdge[170, 228] -> 
             RGBColor[
              0.8200433742052426, 0.3983430371042317, 0.4398420336296414], 
             UndirectedEdge[151, 194] -> 
             RGBColor[
              0.4795533660103779, 0.5880893214551517, 0.9522467003824877], 
             UndirectedEdge[62, 100] -> 
             RGBColor[
              0.8984031319352767, 0.588272489605711, 0.35735557216633895`], 
             UndirectedEdge[76, 99] -> 
             RGBColor[
              0.3308920068686242, 0.45968772172522177`, 0.9423540428096366], 
             UndirectedEdge[131, 283] -> 
             RGBColor[
              0.47177717102653804`, 0.5785602690993044, 0.9525231166057517], 
             UndirectedEdge[173, 263] -> 
             RGBColor[
              0.25907859446240145`, 0.3896384076845897, 0.9380655147309758], 
             UndirectedEdge[20, 75] -> 
             RGBColor[
              0.7982091276425176, 0.8426574734850338, 0.980423187310408], 
             UndirectedEdge[175, 253] -> 
             RGBColor[
              0.29561827694261666`, 0.42804393072097424`, 0.9401463955926079],
              UndirectedEdge[52, 193] -> 
             RGBColor[
              0.6783045969866766, 0.26489364797125753`, 0.42528589032272945`],
              UndirectedEdge[282, 283] -> 
             RGBColor[
              0.7911900845661439, 0.8368811978581185, 0.9547653144934332], 
             UndirectedEdge[173, 279] -> 
             RGBColor[
              0.2579831193391787, 0.3884869938729482, 0.9380031290433184], 
             UndirectedEdge[95, 198] -> 
             RGBColor[
              0.4764509321887418, 0.5858433564775396, 0.9519271091606205], 
             UndirectedEdge[18, 288] -> 
             RGBColor[
              0.890067649625568, 0.630386800626602, 0.46285742186084555`], 
             UndirectedEdge[29, 91] -> 
             RGBColor[
              0.25771769921639187`, 0.38820802049529146`, 0.9379880137599795],
              UndirectedEdge[46, 169] -> 
             RGBColor[
              0.2925815910536258, 0.4248521813146391, 0.9399734608236041], 
             UndirectedEdge[34, 264] -> 
             RGBColor[
              0.31108024849077764`, 0.44256158228500475`, 0.9410904171386354],
              UndirectedEdge[116, 277] -> 
             RGBColor[
              0.33575144742336294`, 0.46523276122486323`, 0.9426147632298372],
              UndirectedEdge[60, 299] -> 
             RGBColor[
              0.9602834986478392, 0.8683179033755875, 0.5002256256588694], 
             UndirectedEdge[205, 213] -> 
             RGBColor[
              0.4786627684820106, 0.5869482888311869, 0.9522920854283001], 
             UndirectedEdge[240, 299] -> 
             RGBColor[
              0.9947090533611671, 0.9917794762430787, 0.7154980818389891], 
             UndirectedEdge[184, 214] -> 
             RGBColor[
              0.22515962250579277`, 0.3539874175711599, 0.9361338794566691], 
             UndirectedEdge[39, 59] -> 
             RGBColor[
              0.8559585262890798, 0.41198547445132916`, 0.20046970691436952`],
              UndirectedEdge[246, 299] -> 
             RGBColor[
              0.7966762325062557, 0.8386071063469377, 0.851316533208819], 
             UndirectedEdge[21, 114] -> 
             RGBColor[
              0.3439329379247541, 0.47191837420693394`, 0.9431507551943723], 
             UndirectedEdge[204, 253] -> 
             RGBColor[
              0.26380404156370607`, 0.39460515219871184`, 0.9383346219527224],
              UndirectedEdge[202, 214] -> 
             RGBColor[
              0.22050159369132202`, 0.3490915339510665, 0.935868611606621], 
             UndirectedEdge[26, 39] -> 
             RGBColor[
              0.906966804332385, 0.6570560107325126, 0.4355903940965794], 
             UndirectedEdge[118, 220] -> 
             RGBColor[
              0.21806065403360642`, 0.34652595160629435`, 0.9357296037041608],
              UndirectedEdge[28, 126] -> 
             RGBColor[
              0.22467560955270433`, 0.3534786892692703, 0.9361063156350238], 
             UndirectedEdge[9, 237] -> 
             RGBColor[
              0.5778044829283981, 0.6681267348934206, 0.9599060319451358], 
             UndirectedEdge[174, 297] -> 
             RGBColor[
              0.5763612583921884, 0.663490693504958, 0.9614863052750408], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.35208222651696447`, 0.4786261706514128, 0.9436828617856419], 
             UndirectedEdge[63, 139] -> 
             RGBColor[
              0.28999599813964694`, 0.42067676560446166`, 0.9398795920978575],
              UndirectedEdge[124, 150] -> 
             RGBColor[
              0.9548500534233739, 0.9658478242861803, 0.9613112619489188], 
             UndirectedEdge[127, 165] -> 
             RGBColor[
              0.8819348515311312, 0.4836294110547851, 0.24528249245442546`], 
             UndirectedEdge[8, 22] -> 
             RGBColor[
              0.7346141321851996, 0.7926054104280515, 0.9741831294029938], 
             UndirectedEdge[127, 137] -> 
             RGBColor[
              0.837036798647762, 0.2856866408011604, 0.18309978625316525`], 
             UndirectedEdge[21, 213] -> 
             RGBColor[
              0.40566670523630644`, 0.5257898434994019, 0.9470697016340429], 
             UndirectedEdge[41, 278] -> 
             RGBColor[
              0.4799611412114356, 0.5860775921964064, 0.9529261189064413], 
             UndirectedEdge[69, 249] -> 
             RGBColor[
              0.8767326483234027, 0.4250520115136651, 0.27148648277790555`], 
             UndirectedEdge[100, 136] -> 
             RGBColor[
              0.8977561106780269, 0.5868885765603375, 0.28693130126704164`], 
             UndirectedEdge[88, 222] -> 
             RGBColor[
              0.47017691950032614`, 0.5802832085890723, 0.9515621248783083], 
             UndirectedEdge[153, 216] -> 
             RGBColor[
              0.2661597993989548, 0.3970812030472318, 0.9384687788764086], 
             UndirectedEdge[60, 121] -> 
             RGBColor[
              0.9603462863275016, 0.8677642487038257, 0.4570528894502983], 
             UndirectedEdge[203, 206] -> 
             RGBColor[
              0.24813385698154097`, 0.37813479465576916`, 0.9374422281227288],
              UndirectedEdge[50, 108] -> 
             RGBColor[
              0.3481847341285709, 0.4760018492537544, 0.9434070012643693], 
             UndirectedEdge[98, 181] -> 
             RGBColor[
              0.5683121366528735, 0.6584973340732392, 0.9601360759487196], 
             UndirectedEdge[267, 285] -> 
             RGBColor[
              0.42530929649653304`, 0.542408765687049, 0.9484303125609015], 
             UndirectedEdge[156, 178] -> 
             RGBColor[
              0.25237767810444756`, 0.38259531972974414`, 0.9376839074575076],
              UndirectedEdge[185, 295] -> 
             RGBColor[
              0.7026775395247731, 0.7666581291332051, 0.9717409425805205], 
             UndirectedEdge[83, 156] -> 
             RGBColor[
              0.221993745626472, 0.35065988024280614`, 0.935953587451887], 
             UndirectedEdge[44, 150] -> 
             RGBColor[
              0.9635307831976114, 0.9324851425902525, 0.6339721646328667], 
             UndirectedEdge[223, 274] -> 
             RGBColor[
              0.9259651133080155, 0.7367764933200369, 0.2723005774523107], 
             UndirectedEdge[20, 142] -> 
             RGBColor[
              0.7624648027643098, 0.8147337352232472, 0.9768605270562558], 
             UndirectedEdge[87, 264] -> 
             RGBColor[
              0.2853843000396664, 0.4172873721243609, 0.939563585747797], 
             UndirectedEdge[16, 192] -> 
             RGBColor[
              0.9078142124160141, 0.6493576356683792, 0.31625810704792], 
             UndirectedEdge[75, 143] -> 
             RGBColor[
              0.5636312232942053, 0.6537338940348352, 0.9601379235387875], 
             UndirectedEdge[230, 263] -> 
             RGBColor[
              0.2551678747286398, 0.38552799329045395`, 0.9378428050275294], 
             UndirectedEdge[52, 82] -> 
             RGBColor[
              0.8768309043529274, 0.4220373894366231, 0.3448952545426753], 
             UndirectedEdge[34, 213] -> 
             RGBColor[
              0.37768895869959807`, 0.5015569256517332, 0.9452869843644738], 
             UndirectedEdge[145, 219] -> 
             RGBColor[
              0.27171942382339986`, 0.4029247208178715, 0.9387853912626534], 
             UndirectedEdge[237, 295] -> 
             RGBColor[
              0.738032045164762, 0.7953605095140767, 0.9745241787723218], 
             UndirectedEdge[257, 259] -> 
             RGBColor[
              0.4277830853443319, 0.544648816326516, 0.9485610340700278], 
             UndirectedEdge[116, 241] -> 
             RGBColor[
              0.30074162674959204`, 0.4321657656332045, 0.9404844121827121], 
             UndirectedEdge[95, 105] -> 
             RGBColor[
              0.3889084199719124, 0.5085055030468593, 0.9463331921101534], 
             UndirectedEdge[115, 146] -> 
             RGBColor[
              0.22602095903949393`, 0.35489273687997036`, 0.9361829312980301],
              UndirectedEdge[16, 170] -> 
             RGBColor[
              0.8790857472699829, 0.44233946271991065`, 0.2892881245547241], 
             UndirectedEdge[199, 226] -> 
             RGBColor[
              0.178927005110741, 0.3053940053717128, 0.9335010002910491], 
             UndirectedEdge[78, 130] -> 
             RGBColor[
              0.17948366008578914`, 0.30597908504445237`, 0.9335327009683809],
              UndirectedEdge[155, 214] -> 
             RGBColor[
              0.21259246077095287`, 0.340778533783768, 0.9354181981873197], 
             UndirectedEdge[185, 297] -> 
             RGBColor[
              0.6642346642542716, 0.7364864270373344, 0.9679464241532377], 
             UndirectedEdge[45, 53] -> 
             RGBColor[
              0.849125567438419, 0.37860621505841235`, 0.19467600489941], 
             UndirectedEdge[49, 204] -> 
             RGBColor[
              0.23371861491604712`, 0.3629834612657993, 0.9366213014125385], 
             UndirectedEdge[69, 254] -> 
             RGBColor[
              0.9421799602264942, 0.7934586684310521, 0.3573185586987633], 
             UndirectedEdge[102, 295] -> 
             RGBColor[
              0.6113037860265932, 0.6906305704110295, 0.9650577846461873], 
             UndirectedEdge[14, 254] -> 
             RGBColor[
              0.8455724370335723, 0.3167800316408471, 0.18992199194947013`], 
             UndirectedEdge[125, 299] -> 
             RGBColor[
              0.9935548569863483, 0.9893107669044954, 0.5898709293143154], 
             UndirectedEdge[16, 44] -> 
             RGBColor[
              0.9792628131880576, 0.9411137160345208, 0.4247070629331663], 
             UndirectedEdge[49, 84] -> 
             RGBColor[
              0.2685862507813846, 0.39963155729606886`, 0.9386069616930247], 
             UndirectedEdge[186, 230] -> 
             RGBColor[
              0.23966064866834333`, 0.3692289154861624, 0.9369596914442806], 
             UndirectedEdge[215, 282] -> 
             RGBColor[
              0.97938013431987, 0.9823295669124169, 0.8386095157394571], 
             UndirectedEdge[134, 159] -> 
             RGBColor[
              0.26069725479200045`, 0.3913397223199907, 0.9381576950421531], 
             UndirectedEdge[26, 266] -> 
             RGBColor[
              0.6167344718352826, 0.6830098916954412, 0.9109140844783175], 
             UndirectedEdge[142, 150] -> 
             RGBColor[
              0.810515025857468, 0.8523692859433827, 0.9579232930155395], 
             UndirectedEdge[114, 221] -> 
             RGBColor[
              0.29951227485023835`, 0.4321367694156119, 0.9403681530127932], 
             UndirectedEdge[147, 172] -> 
             RGBColor[
              0.2478440102281372, 0.3778301473405962, 0.9374257217789124], 
             UndirectedEdge[35, 211] -> 
             RGBColor[
              0.2342952250609407, 0.36358951508727716`, 0.936654138507272], 
             UndirectedEdge[124, 295] -> 
             RGBColor[
              0.8924892919776035, 0.9168014387328876, 0.9788835440663946], 
             UndirectedEdge[166, 233] -> 
             RGBColor[
              0.9934058766223102, 0.9883041618002921, 0.5236485484298345], 
             UndirectedEdge[88, 290] -> 
             RGBColor[
              0.558574938782711, 0.6525153246748602, 0.9583922117898461], 
             UndirectedEdge[134, 235] -> 
             RGBColor[
              0.2580199713754525, 0.388525727699626, 0.9380052277122666], 
             UndirectedEdge[185, 239] -> 
             RGBColor[
              0.4896022864326819, 0.5953748312271646, 0.9532789058066227], 
             UndirectedEdge[260, 278] -> 
             RGBColor[
              0.7260426453881705, 0.7855410894217181, 0.9736791816363508], 
             UndirectedEdge[15, 242] -> 
             RGBColor[
              0.23967759230185604`, 0.3692467243192726, 0.9369606563591433], 
             UndirectedEdge[4, 266] -> 
             RGBColor[
              0.3936273469724733, 0.5073684085563466, 0.9471569136064277], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.2455681044594148, 0.3754380260769088, 0.9372961123122845], 
             UndirectedEdge[3, 123] -> 
             RGBColor[
              0.40677277394875433`, 0.5267478646254944, 0.9471401793543419], 
             UndirectedEdge[28, 184] -> 
             RGBColor[
              0.23042487690337662`, 0.35952153377943086`, 0.9364337279053656],
              UndirectedEdge[116, 210] -> 
             RGBColor[
              0.35048246477995726`, 0.4779920280566848, 0.9435534106296721], 
             UndirectedEdge[118, 120] -> 
             RGBColor[
              0.1844220718220619, 0.3111696688926636, 0.9338139362110361], 
             UndirectedEdge[15, 89] -> 
             RGBColor[
              0.2585276184343561, 0.3890592969452162, 0.9380341374612745], 
             UndirectedEdge[11, 283] -> 
             RGBColor[
              0.4811144650373824, 0.586647763865455, 0.9531180807234778], 
             UndirectedEdge[157, 201] -> 
             RGBColor[
              0.3335467378743898, 0.46332315262546664`, 0.9424742810869247], 
             UndirectedEdge[196, 279] -> 
             RGBColor[
              0.2698625176179148, 0.40097299466125325`, 0.9386796432012976], 
             UndirectedEdge[7, 11] -> 
             RGBColor[
              0.36912627592496833`, 0.4941403602052988, 0.9447413777897574], 
             UndirectedEdge[76, 284] -> 
             RGBColor[
              0.2749699198453155, 0.406341198230256, 0.9389705022024235], 
             UndirectedEdge[34, 108] -> 
             RGBColor[
              0.3357098066332535, 0.46519669406539743`, 0.9426121099155129], 
             UndirectedEdge[46, 213] -> 
             RGBColor[
              0.3600084250820952, 0.48470742468786476`, 0.9442166189906656], 
             UndirectedEdge[261, 278] -> 
             RGBColor[
              0.5017864477209948, 0.6049815757231856, 0.9543168081378697], 
             UndirectedEdge[58, 66] -> 
             RGBColor[
              0.747689528345485, 0.802133526636196, 0.966576403949817], 
             UndirectedEdge[194, 297] -> 
             RGBColor[
              0.6381161089486057, 0.715282207212687, 0.9658902758041552], 
             UndirectedEdge[283, 297] -> 
             RGBColor[
              0.6895610790338994, 0.7570475514974199, 0.9699402122984042], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.23660390230659725`, 0.366016081251054, 0.9367856142610302], 
             UndirectedEdge[6, 169] -> 
             RGBColor[
              0.299349056442051, 0.4319652165199622, 0.940358857965907], 
             UndirectedEdge[11, 172] -> 
             RGBColor[
              0.3065006008708423, 0.43626816207492447`, 0.9408838001095725], 
             UndirectedEdge[4, 82] -> 
             RGBColor[
              0.7673487077991381, 0.8145026420959148, 0.8312023909866153], 
             UndirectedEdge[140, 230] -> 
             RGBColor[
              0.2887130988150164, 0.4189991437957653, 0.9398185869899978], 
             UndirectedEdge[207, 232] -> 
             RGBColor[
              0.8698424070552139, 0.8954799573196557, 0.7870499702431855], 
             UndirectedEdge[147, 244] -> 
             RGBColor[
              0.23435191313774276`, 0.3636490978502278, 0.9366573668093834], 
             UndirectedEdge[56, 296] -> 
             RGBColor[
              0.6219639893106997, 0.70315209105388, 0.9639467061714042], 
             UndirectedEdge[243, 294] -> 
             RGBColor[
              0.21403208469402601`, 0.34229166980434655`, 0.935500182640006], 
             UndirectedEdge[211, 216] -> 
             RGBColor[
              0.2505986099544608, 0.38072540630467244`, 0.9375825921582613], 
             UndirectedEdge[107, 141] -> 
             RGBColor[
              0.8557654965670187, 0.3870748730161112, 0.19936752315815415`], 
             UndirectedEdge[19, 175] -> 
             RGBColor[
              0.2928891684678705, 0.42517546467854467`, 0.9399909769023254], 
             UndirectedEdge[17, 158] -> 
             RGBColor[
              0.34992722478314753`, 0.47635321406760484`, 0.9435604273632674],
              UndirectedEdge[115, 242] -> 
             RGBColor[
              0.23101187459031025`, 0.36013850556620103`, 0.9364671565552513],
              UndirectedEdge[159, 292] -> 
             RGBColor[
              0.24522762221879252`, 0.3750801576541939, 0.9372767223523794], 
             UndirectedEdge[34, 205] -> 
             RGBColor[
              0.4284730033611293, 0.5434764368944227, 0.9490940379758643], 
             UndirectedEdge[23, 180] -> 
             RGBColor[
              0.26520012614906696`, 0.3960725256148013, 0.9384141269045367], 
             UndirectedEdge[47, 158] -> 
             RGBColor[
              0.5238459246822951, 0.6229456026619612, 0.9560487873803941], 
             UndirectedEdge[130, 199] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[112, 204] -> 
             RGBColor[
              0.24154807064065673`, 0.37121271564852854`, 0.9370671773334133],
              UndirectedEdge[217, 247] -> 
             RGBColor[
              0.6930619732704799, 0.7591753208357144, 0.9707042644868367], 
             UndirectedEdge[102, 185] -> 
             RGBColor[
              0.4766965463107896, 0.5841965277949407, 0.9524565634581535], 
             UndirectedEdge[136, 137] -> 
             RGBColor[
              0.8946800275962575, 0.5632444540456559, 0.2839856406340002], 
             UndirectedEdge[138, 258] -> 
             RGBColor[
              0.8342254690641332, 0.8708963005189276, 0.9605009609416519], 
             UndirectedEdge[79, 277] -> 
             RGBColor[
              0.3720129129755694, 0.49664062013193266`, 0.9449253117500688], 
             UndirectedEdge[41, 259] -> 
             RGBColor[
              0.41062581045850305`, 0.5297880471701207, 0.9474677876858852], 
             UndirectedEdge[225, 287] -> 
             RGBColor[
              0.950968932525843, 0.8418366498372989, 0.2871069008798047], 
             UndirectedEdge[167, 194] -> 
             RGBColor[
              0.6348798248522232, 0.7127539974799229, 0.9655677132502221], 
             UndirectedEdge[64, 219] -> 
             RGBColor[
              0.2539451972290641, 0.384242881716169, 0.9377731753527179], 
             UndirectedEdge[83, 293] -> 
             RGBColor[
              0.21277489873276917`, 0.34097028764887183`, 0.9354285877593523],
              UndirectedEdge[31, 95] -> 
             RGBColor[
              0.5537416162054588, 0.648591415667946, 0.9580117149315208], 
             UndirectedEdge[256, 299] -> 
             RGBColor[
              0.994866261560722, 0.9921157286857396, 0.7326092241840025], 
             UndirectedEdge[129, 269] -> 
             RGBColor[
              0.23146736458154496`, 0.36061725442672216`, 0.9364930960364151],
              UndirectedEdge[83, 126] -> 
             RGBColor[
              0.22111352999763184`, 0.3497347178080009, 0.9359034604739869], 
             UndirectedEdge[23, 81] -> 
             RGBColor[
              0.29610769611833376`, 0.428558341305621, 0.9401742672906341], 
             UndirectedEdge[235, 252] -> 
             RGBColor[
              0.2712852344852127, 0.40246836029424277`, 0.9387606648221691], 
             UndirectedEdge[6, 264] -> 
             RGBColor[
              0.3001671802617, 0.4328251165264595, 0.9404054489071303], 
             UndirectedEdge[167, 215] -> 
             RGBColor[
              0.874514844691243, 0.8999677108189541, 0.8534618509904951], 
             UndirectedEdge[273, 285] -> 
             RGBColor[
              0.5003032179944051, 0.6032922095966846, 0.9543341087730001], 
             UndirectedEdge[267, 273] -> 
             RGBColor[
              0.5428411676276441, 0.6397419404528637, 0.9571535916898165], 
             UndirectedEdge[66, 109] -> 
             RGBColor[
              0.9338122663322416, 0.9497831796189251, 0.9839317503863134], 
             UndirectedEdge[104, 173] -> 
             RGBColor[
              0.2711227338075005, 0.40229756177882925`, 0.9387514106489717], 
             UndirectedEdge[9, 185] -> 
             RGBColor[
              0.5424499772884093, 0.6394243545125489, 0.9571227957533345], 
             UndirectedEdge[233, 288] -> 
             RGBColor[
              0.905963575838284, 0.6404594328305877, 0.3369687585518484], 
             UndirectedEdge[139, 147] -> 
             RGBColor[
              0.2408356632285271, 0.3704639302891415, 0.9370266067852049], 
             UndirectedEdge[65, 103] -> 
             RGBColor[
              0.2833667383517215, 0.41516678686953135`, 0.9394486885943836], 
             UndirectedEdge[33, 124] -> 
             RGBColor[
              0.931178231225007, 0.9476509487054876, 0.9825737296298357], 
             UndirectedEdge[82, 226] -> 
             RGBColor[
              0.5870018429473699, 0.648635921384999, 0.8195028573655392], 
             UndirectedEdge[6, 221] -> 
             RGBColor[
              0.3001432088118318, 0.4327999210127703, 0.9404040837685228], 
             UndirectedEdge[125, 136] -> 
             RGBColor[
              0.9927664178883965, 0.9869364242276462, 0.4540474115251879], 
             UndirectedEdge[112, 292] -> 
             RGBColor[
              0.24763746869084696`, 0.3776130590894144, 0.9374139595439145], 
             UndirectedEdge[58, 67] -> 
             RGBColor[
              0.7306207568349073, 0.7888007417215468, 0.9745656605578148], 
             UndirectedEdge[73, 105] -> 
             RGBColor[
              0.30909022810020703`, 0.4403302488400713, 0.9409822033703782], 
             UndirectedEdge[263, 298] -> 
             RGBColor[
              0.27311782288011394`, 0.40439452689009914`, 0.9388650280201871],
              UndirectedEdge[60, 170] -> 
             RGBColor[
              0.8566231096722907, 0.3610749573573675, 0.19885979502203965`], 
             UndirectedEdge[10, 129] -> 
             RGBColor[
              0.22367111540675327`, 0.3524229022332684, 0.9360491111794278], 
             UndirectedEdge[53, 234] -> 
             RGBColor[
              0.8269257463472781, 0.20796866212827195`, 0.17341743115142172`],
              UndirectedEdge[51, 154] -> 
             RGBColor[
              0.867381103025232, 0.8946780960164662, 0.8655976857489563], 
             UndirectedEdge[17, 84] -> 
             RGBColor[
              0.2984201886260963, 0.4309889175517728, 0.9403059603179251], 
             UndirectedEdge[98, 160] -> 
             RGBColor[
              0.5065135948101279, 0.6094211404266363, 0.9545226524909898], 
             UndirectedEdge[25, 147] -> 
             RGBColor[
              0.2390014851721345, 0.36853609285826733`, 0.9369221530583165], 
             UndirectedEdge[159, 204] -> 
             RGBColor[
              0.23913822416860225`, 0.3686798142133081, 0.9369299401418781], 
             UndirectedEdge[37, 94] -> 
             RGBColor[
              0.771325946499076, 0.8216241472491855, 0.9777522097744586], 
             UndirectedEdge[37, 283] -> 
             RGBColor[
              0.6497129501444403, 0.725917890351978, 0.9659685232126394], 
             UndirectedEdge[9, 142] -> 
             RGBColor[
              0.5879267021753338, 0.6760891257694337, 0.9608774283058292], 
             UndirectedEdge[51, 109] -> 
             RGBColor[
              0.9573653906056103, 0.9657923433051386, 0.8743494495449171], 
             UndirectedEdge[123, 257] -> 
             RGBColor[
              0.41376298296839165`, 0.5328024323401832, 0.9475855892918741], 
             UndirectedEdge[212, 294] -> 
             RGBColor[
              0.2108091766010912, 0.3389041890544966, 0.9353166427919786], 
             UndirectedEdge[237, 297] -> 
             RGBColor[
              0.6995891698942603, 0.7651888074182058, 0.970729660345039], 
             UndirectedEdge[163, 197] -> 
             RGBColor[
              0.22592979758927967`, 0.35479692041582533`, 0.9361777397883018],
              UndirectedEdge[76, 229] -> 
             RGBColor[
              0.32034218545595194`, 0.4505499966670069, 0.9416818175180619], 
             UndirectedEdge[18, 24] -> 
             RGBColor[
              0.9510187529148094, 0.9629904466400717, 0.9677966543467089], 
             UndirectedEdge[44, 124] -> 
             RGBColor[
              0.9563745344888678, 0.9271480240205534, 0.6460858270481826], 
             UndirectedEdge[26, 82] -> 
             RGBColor[
              0.9904558326619474, 0.9901441252350094, 0.7949595618585049], 
             UndirectedEdge[7, 106] -> 
             RGBColor[
              0.5257077598802015, 0.6240227140594248, 0.9563940779093657], 
             UndirectedEdge[53, 255] -> 
             RGBColor[
              0.8741375252514738, 0.45432815583854413`, 0.2170266905720422], 
             UndirectedEdge[89, 242] -> 
             RGBColor[
              0.2592824308416344, 0.3898526526431364, 0.9380771229112241], 
             UndirectedEdge[121, 181] -> 
             RGBColor[
              0.8542136005503994, 0.8836192586014792, 0.8134168223712162], 
             UndirectedEdge[217, 273] -> 
             RGBColor[
              0.7124353943152881, 0.7749035368025619, 0.9722294111586636], 
             UndirectedEdge[141, 240] -> 
             RGBColor[
              0.9469680026152082, 0.812923621050152, 0.46368241218848416`], 
             UndirectedEdge[42, 159] -> 
             RGBColor[
              0.2509157891435835, 0.3810587817427625, 0.9376006550438574], 
             UndirectedEdge[51, 52] -> 
             RGBColor[
              0.8763260533964058, 0.4219467076212655, 0.36184562184045305`], 
             UndirectedEdge[170, 225] -> 
             RGBColor[
              0.8682499113225608, 0.4061856602973817, 0.21334848907618564`], 
             UndirectedEdge[51, 179] -> 
             RGBColor[
              0.993604348606093, 0.9916232480349453, 0.7556560252196713], 
             UndirectedEdge[36, 198] -> 
             RGBColor[
              0.6119133130274254, 0.6940222772779814, 0.9638188261918845], 
             UndirectedEdge[150, 295] -> 
             RGBColor[
              0.8996455406863472, 0.9221385573025866, 0.9667698816510785], 
             UndirectedEdge[140, 196] -> 
             RGBColor[
              0.304503216827514, 0.4355955589782061, 0.9407178108514234], 
             UndirectedEdge[31, 73] -> 
             RGBColor[
              0.47392342433375345`, 0.580416161461158, 0.9526607261917457], 
             UndirectedEdge[188, 212] -> 
             RGBColor[
              0.20871789165381538`, 0.33670611597978567`, 0.9351975472080101],
              UndirectedEdge[172, 244] -> 
             RGBColor[
              0.2560033039447505, 0.38640608236585794`, 0.9378903814854801], 
             UndirectedEdge[7, 63] -> 
             RGBColor[
              0.3596300201933831, 0.4859151807862907, 0.94413628477175], 
             UndirectedEdge[128, 218] -> 
             RGBColor[
              0.24765166805898178`, 0.377627983525616, 0.9374147681769237], 
             UndirectedEdge[138, 154] -> 
             RGBColor[
              0.7239419932746806, 0.7842682543998942, 0.9731194303332016], 
             UndirectedEdge[1, 297] -> 
             RGBColor[
              0.5894608456272148, 0.6748368975635395, 0.9623209993901465], 
             UndirectedEdge[90, 123] -> 
             RGBColor[
              0.4198835569183708, 0.5381037658666636, 0.9479755868517558], 
             UndirectedEdge[8, 61] -> 
             RGBColor[
              0.6093443388632377, 0.6935868317074125, 0.9624883614152353], 
             UndirectedEdge[201, 209] -> 
             RGBColor[
              0.29313467956513195`, 0.424290095199951, 0.9400468245012701], 
             UndirectedEdge[44, 94] -> 
             RGBColor[
              0.9135021931703009, 0.8932720957781641, 0.6527207002692943], 
             UndirectedEdge[114, 213] -> 
             RGBColor[
              0.366144956508927, 0.49115730829602955`, 0.944566085377239], 
             UndirectedEdge[82, 107] -> 
             RGBColor[
              0.8877902396301622, 0.5062756427887904, 0.35538992638095424`], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.27309540824899353`, 0.40437096769162195`, 0.9388637515401044],
              UndirectedEdge[182, 268] -> 
             RGBColor[
              0.28484973208731645`, 0.4167255073128753, 0.939533142893733], 
             UndirectedEdge[157, 229] -> 
             RGBColor[
              0.34618459391463335`, 0.47426942833041186`, 0.9432795540985917],
              UndirectedEdge[99, 157] -> 
             RGBColor[
              0.35673441532730565`, 0.48340715338862666`, 0.9439517793901664],
              UndirectedEdge[249, 288] -> 
             RGBColor[
              0.8330203500287888, 0.2511485807700654, 0.1791100840120061], 
             UndirectedEdge[66, 138] -> 
             RGBColor[
              0.8265698887797728, 0.8651867812777139, 0.9734598614679548], 
             UndirectedEdge[215, 286] -> 
             RGBColor[
              0.7770695489362254, 0.8225663010665949, 0.8446220990398039], 
             UndirectedEdge[83, 275] -> 
             RGBColor[
              0.214533530595458, 0.34281872124025803`, 0.9355287392422698], 
             UndirectedEdge[95, 289] -> 
             RGBColor[
              0.38981488785686436`, 0.5094582582673273, 0.9463848141152024], 
             UndirectedEdge[37, 75] -> 
             RGBColor[
              0.7056075851299448, 0.7699452754105638, 0.9712920278741198], 
             UndirectedEdge[88, 260] -> 
             RGBColor[
              0.6766874696871867, 0.7454723343623321, 0.9697937614112038], 
             UndirectedEdge[60, 82] -> 
             RGBColor[
              0.9605795624965958, 0.8682632028416796, 0.48244356084256446`], 
             UndirectedEdge[50, 227] -> 
             RGBColor[
              0.30610711869793783`, 0.43502772299278125`, 0.9408916674370189],
              UndirectedEdge[12, 248] -> 
             RGBColor[
              0.20494626266410096`, 0.3327418947765061, 0.9349827585166709], 
             UndirectedEdge[103, 164] -> 
             RGBColor[
              0.33137057382359575`, 0.4586711168930102, 0.9424369368208644], 
             UndirectedEdge[127, 228] -> 
             RGBColor[
              0.8272958107858699, 0.4540884427009072, 0.44678697508970566`], 
             UndirectedEdge[163, 184] -> 
             RGBColor[
              0.23939823162616325`, 0.3689530985366296, 0.9369447471819397], 
             UndirectedEdge[11, 183] -> 
             RGBColor[
              0.29904764600234657`, 0.4284346339635039, 0.9404593653554703], 
             UndirectedEdge[226, 266] -> 
             RGBColor[
              0.21328048212070516`, 0.3415016878454308, 0.9354573799853517], 
             UndirectedEdge[98, 178] -> 
             RGBColor[
              0.34993177355877136`, 0.4745851224813026, 0.9436255999612144], 
             UndirectedEdge[200, 255] -> 
             RGBColor[
              0.9224751483252943, 0.7242107930884344, 0.2608151757752228], 
             UndirectedEdge[223, 234] -> 
             RGBColor[
              0.840664257806904, 0.28321338657069606`, 0.18538480018870795`], 
             UndirectedEdge[111, 190] -> 
             RGBColor[
              0.2355732429285669, 0.36493279289716524`, 0.9367269197341752], 
             UndirectedEdge[85, 181] -> 
             RGBColor[
              0.8167213708728744, 0.8575535758044224, 0.9821530921197811], 
             UndirectedEdge[57, 134] -> 
             RGBColor[
              0.26052687456490653`, 0.3911606418985847, 0.938147992140275], 
             UndirectedEdge[9, 131] -> 
             RGBColor[
              0.4208304337263501, 0.5371994126346513, 0.9485124028214329], 
             UndirectedEdge[184, 189] -> 
             RGBColor[
              0.2346427787554684, 0.3639548160564028, 0.9366739311760157], 
             UndirectedEdge[194, 286] -> 
             RGBColor[
              0.5374345290972057, 0.6353525877275636, 0.9567279612995309], 
             UndirectedEdge[171, 298] -> 
             RGBColor[
              0.35180269388930685`, 0.47696337077533185`, 0.9437170683691549],
              UndirectedEdge[108, 213] -> 
             RGBColor[
              0.3858995717541348, 0.5086685460021616, 0.9458101573679487], 
             UndirectedEdge[158, 175] -> 
             RGBColor[
              0.34907161965836087`, 0.47545391883295585`, 0.9435117019171652],
              UndirectedEdge[37, 297] -> 
             RGBColor[
              0.7205508998101146, 0.7816191064121104, 0.9727814378282238], 
             UndirectedEdge[68, 234] -> 
             RGBColor[
              0.8363347391748547, 0.263554053647327, 0.18177214371591305`], 
             UndirectedEdge[38, 252] -> 
             RGBColor[
              0.3592377978575069, 0.4848159523446023, 0.9441391019160659], 
             UndirectedEdge[42, 252] -> 
             RGBColor[
              0.2774845709652012, 0.40898425599534566`, 0.939113707863608], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.2625645345612948, 0.39330235174989453`, 0.9382640338626215], 
             UndirectedEdge[184, 216] -> 
             RGBColor[
              0.24813752757352578`, 0.3781386526806742, 0.9374424371575123], 
             UndirectedEdge[16, 59] -> 
             RGBColor[
              0.8863635577181508, 0.4982799029814027, 0.2962573640590009], 
             UndirectedEdge[7, 185] -> 
             RGBColor[
              0.4814085254761833, 0.5882778073170456, 0.9527568066039329], 
             UndirectedEdge[127, 299] -> 
             RGBColor[
              0.8866762458048552, 0.4992665827665768, 0.36636688189725086`], 
             UndirectedEdge[166, 217] -> 
             RGBColor[
              0.899879476841495, 0.9180128953290518, 0.7153753712159427], 
             UndirectedEdge[101, 207] -> 
             RGBColor[
              0.6460892652174881, 0.7219820565313749, 0.9663628314965813], 
             UndirectedEdge[14, 69] -> 
             RGBColor[
              0.8794778029545246, 0.44615247294289756`, 0.27411524595287656`],
              UndirectedEdge[51, 107] -> 
             RGBColor[
              0.8872853886736406, 0.5061849609734328, 0.372340293678732], 
             UndirectedEdge[74, 233] -> 
             RGBColor[
              0.8161512863791258, 0.8534670921405562, 0.7813047425304152], 
             UndirectedEdge[158, 252] -> 
             RGBColor[
              0.35208167801260865`, 0.47861768101199287`, 0.9436831202874573],
              UndirectedEdge[86, 110] -> 
             RGBColor[
              0.9839067857429666, 0.9591178157514064, 0.561716366031505], 
             UndirectedEdge[58, 73] -> 
             RGBColor[
              0.4389666532110068, 0.5520366798791193, 0.9499088011180912], 
             UndirectedEdge[13, 96] -> 
             RGBColor[
              0.3557971492753504, 0.4823533245061042, 0.9439009190224369], 
             UndirectedEdge[16, 53] -> 
             RGBColor[
              0.8856428670516149, 0.492740358709744, 0.2955672298628224], 
             UndirectedEdge[44, 170] -> 
             RGBColor[
              0.8696140479866813, 0.4107872135799805, 0.21864790242070015`], 
             UndirectedEdge[27, 32] -> 
             RGBColor[
              0.25734797909016266`, 0.3878194212010146, 0.9379669587457427], 
             UndirectedEdge[116, 164] -> 
             RGBColor[
              0.35316605540790247`, 0.4803164193774241, 0.9437244066514788], 
             UndirectedEdge[70, 300] -> 
             RGBColor[
              0.2600472811884571, 0.39065655885195993`, 0.938120680006981], 
             UndirectedEdge[79, 116] -> 
             RGBColor[
              0.3586693068574145, 0.48508305918153105`, 0.9440750689675076], 
             UndirectedEdge[137, 195] -> 
             RGBColor[
              0.836758723501432, 0.2835492333731616, 0.18283350117899866`], 
             UndirectedEdge[156, 214] -> 
             RGBColor[
              0.2202905707839606, 0.3488697354958046, 0.9358565941642273], 
             UndirectedEdge[14, 249] -> 
             RGBColor[
              0.8213251225622646, 0.16491981350766619`, 0.16805426748989288`],
              UndirectedEdge[84, 89] -> 
             RGBColor[
              0.2893752204809355, 0.4214820825471055, 0.9397908627628895], 
             UndirectedEdge[98, 246] -> 
             RGBColor[
              0.5108375562883921, 0.6129315271469358, 0.9548630505777516], 
             UndirectedEdge[4, 107] -> 
             RGBColor[
              0.735971594380749, 0.38802551616835207`, 0.43918837760604434`], 
             UndirectedEdge[20, 295] -> 
             RGBColor[
              0.851595317593189, 0.8845030065824513, 0.9857071156917947], 
             UndirectedEdge[57, 175] -> 
             RGBColor[
              0.27078207932041887`, 0.40193951231416447`, 0.9387320108798856],
              UndirectedEdge[93, 160] -> 
             RGBColor[
              0.5607147225279772, 0.6542524975154264, 0.9585606634045596], 
             UndirectedEdge[13, 149] -> 
             RGBColor[
              0.30003867844943893`, 0.43269005297428764`, 0.9403981309190235],
              UndirectedEdge[230, 298] -> 
             RGBColor[
              0.2673021323723527, 0.39828186743036675`, 0.9385338330493134], 
             UndirectedEdge[96, 198] -> 
             RGBColor[
              0.43486063371890193`, 0.5507791821456584, 0.9490119679848132], 
             UndirectedEdge[32, 182] -> 
             RGBColor[
              0.2817202883828383, 0.4134362635612778, 0.9393549257043601], 
             UndirectedEdge[80, 241] -> 
             RGBColor[
              0.27345259705009906`, 0.4047463957686619, 0.938884092913914], 
             UndirectedEdge[55, 292] -> 
             RGBColor[
              0.25987815555668636`, 0.39047879708978456`, 0.9381110485524506],
              UndirectedEdge[121, 160] -> 
             RGBColor[
              0.7924150587076538, 0.8345430649548763, 0.8078033989134862], 
             UndirectedEdge[62, 220] -> 
             RGBColor[
              0.6260202363274255, 0.6895227449727015, 0.8093263410054259], 
             UndirectedEdge[28, 189] -> 
             RGBColor[
              0.22763054758381063`, 0.35658451649385525`, 0.9362745949844562],
              UndirectedEdge[25, 91] -> 
             RGBColor[
              0.2622113968861681, 0.3929311816631146, 0.9382439231944433], 
             UndirectedEdge[41, 99] -> 
             RGBColor[
              0.362239582391498, 0.48817545240188814`, 0.9443025637674687], 
             UndirectedEdge[148, 206] -> 
             RGBColor[
              0.23774362795226284`, 0.3672140051674282, 0.9368505199504779], 
             UndirectedEdge[3, 90] -> 
             RGBColor[
              0.39043568607657597`, 0.5125975002365252, 0.9460991945614463], 
             UndirectedEdge[99, 104] -> 
             RGBColor[
              0.3262801186675095, 0.4548403348152493, 0.9420914025992604], 
             UndirectedEdge[193, 266] -> 
             RGBColor[
              0.3235658537972168, 0.4490279862889558, 0.942045190438874], 
             UndirectedEdge[275, 293] -> 
             RGBColor[
              0.21101994270665328`, 0.33912571759478527`, 0.9353286456098898],
              UndirectedEdge[229, 257] -> 
             RGBColor[
              0.3688470358646546, 0.49389849650006856`, 0.9447235848600365], 
             UndirectedEdge[90, 144] -> 
             RGBColor[
              0.35962797975699734`, 0.48591341346284866`, 0.9441361547569478],
              UndirectedEdge[49, 115] -> 
             RGBColor[
              0.22907293102325943`, 0.358100552941108, 0.9363567365875176], 
             UndirectedEdge[77, 244] -> 
             RGBColor[
              0.2442718082387917, 0.3740755365591065, 0.9372222901602183], 
             UndirectedEdge[66, 95] -> 
             RGBColor[
              0.7175511909941827, 0.7776658666577836, 0.9642038036331552], 
             UndirectedEdge[94, 125] -> 
             RGBColor[
              0.9272871440372241, 0.9396965749731525, 0.7126838428267497], 
             UndirectedEdge[196, 230] -> 
             RGBColor[
              0.2651423022333762, 0.39601174901316233`, 0.938410833918081], 
             UndirectedEdge[138, 245] -> 
             RGBColor[
              0.5655432626553039, 0.6564020281299278, 0.9598314214470098], 
             UndirectedEdge[100, 127] -> 
             RGBColor[
              0.8443775856578832, 0.3421111465143313, 0.19012933218429046`], 
             UndirectedEdge[24, 288] -> 
             RGBColor[
              0.8931463379497462, 0.6326828813378846, 0.45764600557852664`], 
             UndirectedEdge[224, 258] -> 
             RGBColor[
              0.9656458741337097, 0.9399341707856219, 0.6428561562394914], 
             UndirectedEdge[25, 203] -> 
             RGBColor[
              0.2557021473412196, 0.3860895476811155, 0.9378732310624303], 
             UndirectedEdge[143, 239] -> 
             RGBColor[
              0.4039421601527854, 0.5242961292262122, 0.9469598151462764], 
             UndirectedEdge[142, 282] -> 
             RGBColor[
              0.8113403946734408, 0.8529848446549176, 0.9565261589007614], 
             UndirectedEdge[57, 242] -> 
             RGBColor[
              0.24374269016754463`, 0.3735193999182025, 0.9371921576688209], 
             UndirectedEdge[47, 177] -> 
             RGBColor[
              0.5316337139639098, 0.6296909943120255, 0.956545018426947], 
             UndirectedEdge[43, 174] -> 
             RGBColor[
              0.35724861486395953`, 0.48385252718285615`, 0.9439845437299532],
              UndirectedEdge[5, 29] -> 
             RGBColor[
              0.23189096279390453`, 0.36106248300558996`, 0.9365172193279515],
              UndirectedEdge[167, 282] -> 
             RGBColor[
              0.8587917501354356, 0.8900542041854869, 0.9612556665550847], 
             UndirectedEdge[131, 172] -> 
             RGBColor[
              0.297163306859998, 0.4281806673087738, 0.9402888359918464], 
             UndirectedEdge[21, 101] -> 
             RGBColor[
              0.4650224715635836, 0.5746682645420044, 0.9515515525742121], 
             UndirectedEdge[251, 300] -> 
             RGBColor[
              0.27128730129384493`, 0.40247053264115845`, 0.9387607825238632],
              UndirectedEdge[75, 167] -> 
             RGBColor[
              0.7422194299230214, 0.7985467268232416, 0.9749411544059516], 
             UndirectedEdge[165, 281] -> 
             RGBColor[
              0.8841377182227066, 0.5005616097485734, 0.24739196008606018`], 
             UndirectedEdge[63, 174] -> 
             RGBColor[
              0.35841838866408615`, 0.48486572645398507`, 0.944059080682107], 
             UndirectedEdge[64, 211] -> 
             RGBColor[
              0.238007335368493, 0.36749117838190204`, 0.936865537697712], 
             UndirectedEdge[124, 237] -> 
             RGBColor[
              0.7932365579017887, 0.8390697764976703, 0.9690655590701622], 
             UndirectedEdge[127, 192] -> 
             RGBColor[
              0.8435101090021122, 0.32854264127856764`, 0.18902842147164728`],
              UndirectedEdge[62, 228] -> 
             RGBColor[
              0.90559598823519, 0.9239215498870947, 0.8315118721300905], 
             UndirectedEdge[152, 277] -> 
             RGBColor[
              0.3011955804505697, 0.43017548464198757`, 0.9406006083286469], 
             UndirectedEdge[76, 157] -> 
             RGBColor[
              0.3201380287875101, 0.4503731664220151, 0.9416688088356775], 
             UndirectedEdge[106, 297] -> 
             RGBColor[
              0.7085338986582898, 0.7722313337797134, 0.9715836954586705], 
             UndirectedEdge[91, 203] -> 
             RGBColor[
              0.2661031933042482, 0.39702170645266144`, 0.9384655552430561], 
             UndirectedEdge[215, 271] -> 
             RGBColor[
              0.9862840872732699, 0.9639445925953173, 0.5488858494022204], 
             UndirectedEdge[181, 296] -> 
             RGBColor[
              0.7050263286294778, 0.769491193414686, 0.9712340936583042], 
             UndirectedEdge[27, 119] -> 
             RGBColor[
              0.2703316084942079, 0.40146603891431676`, 0.9387063572327446], 
             UndirectedEdge[100, 170] -> 
             RGBColor[
              0.8407513673675695, 0.3142384437159935, 0.18665686145425833`], 
             UndirectedEdge[112, 115] -> 
             RGBColor[
              0.236902386747869, 0.36632980732383724`, 0.9368026125083924], 
             UndirectedEdge[75, 282] -> 
             RGBColor[
              0.8470847195516484, 0.8809085829167043, 0.9600888191549137], 
             UndirectedEdge[234, 255] -> 
             RGBColor[
              0.8645307789041956, 0.38048649371027216`, 0.20782725942062052`],
              UndirectedEdge[29, 77] -> 
             RGBColor[
              0.2444276826034072, 0.3742393703993229, 0.9372311669746878], 
             UndirectedEdge[44, 192] -> 
             RGBColor[
              0.8983425131327125, 0.6178053865284491, 0.24561788491389613`], 
             UndirectedEdge[49, 57] -> 
             RGBColor[
              0.2418037466004938, 0.3714814472931095, 0.9370817377010874], 
             UndirectedEdge[4, 281] -> 
             RGBColor[
              0.7372578431461884, 0.3979121878173214, 0.4404200908764392], 
             UndirectedEdge[23, 285] -> 
             RGBColor[
              0.33957273212272987`, 0.46739870088843105`, 0.9429001346157797],
              UndirectedEdge[86, 109] -> 
             RGBColor[
              0.9480181265878662, 0.9334317685964351, 0.674604431944415], 
             UndirectedEdge[276, 279] -> 
             RGBColor[
              0.24528708035805388`, 0.3751426519284214, 0.9372801084054498], 
             UndirectedEdge[139, 183] -> 
             RGBColor[
              0.2550340991670391, 0.38538738669335115`, 0.9378351867071995], 
             UndirectedEdge[234, 287] -> 
             RGBColor[
              0.8585376702603141, 0.3573155390659227, 0.19993377068700752`], 
             UndirectedEdge[160, 181] -> 
             RGBColor[
              0.6520185359229838, 0.7272823998054908, 0.9664968499202544], 
             UndirectedEdge[196, 298] -> 
             RGBColor[
              0.28309225038485036`, 0.4148782826128075, 0.9394330569107388], 
             UndirectedEdge[255, 287] -> 
             RGBColor[
              0.9499646737467646, 0.8384490491642924, 0.28320554516144203`], 
             UndirectedEdge[126, 216] -> 
             RGBColor[
              0.24238826022285348`, 0.3720958081705137, 0.9371150248871702], 
             UndirectedEdge[190, 212] -> 
             RGBColor[
              0.21992645288427248`, 0.3484870244968241, 0.9358358581885042], 
             UndirectedEdge[39, 137] -> 
             RGBColor[
              0.8602105432836612, 0.44466834031741015`, 0.20454144319034706`],
              UndirectedEdge[170, 195] -> 
             RGBColor[
              0.8209768790641011, 0.16224306137950753`, 0.16772078912276672`],
              UndirectedEdge[69, 288] -> 
             RGBColor[
              0.9056134125186948, 0.6397104688969287, 0.29885564217207405`], 
             UndirectedEdge[101, 231] -> 
             RGBColor[
              0.49585480302230733`, 0.6013736803735128, 0.9535161614708018], 
             UndirectedEdge[57, 253] -> 
             RGBColor[
              0.27188917324815276`, 0.40310313822602206`, 0.9387950582412713],
              UndirectedEdge[52, 266] -> 
             RGBColor[
              0.6276833304684843, 0.2172812337435776, 0.42219826962255025`], 
             UndirectedEdge[28, 275] -> 
             RGBColor[
              0.21809561015053047`, 0.3465626927015274, 0.9357315944033067], 
             UndirectedEdge[4, 226] -> 
             RGBColor[
              0.35927387507325015`, 0.47126073145434144`, 0.9452005342031744],
              UndirectedEdge[104, 229] -> 
             RGBColor[
              0.3157302972548372, 0.4457026097570346, 0.9414191773076857], 
             UndirectedEdge[189, 293] -> 
             RGBColor[
              0.2205548801399334, 0.3491475413871131, 0.9358716461910392], 
             UndirectedEdge[155, 156] -> 
             RGBColor[
              0.22000089461836236`, 0.3485652674792311, 0.935840097535134], 
             UndirectedEdge[107, 281] -> 
             RGBColor[
              0.834790145991334, 0.26841788399438415`, 0.18094838913213865`], 
             UndirectedEdge[107, 240] -> 
             RGBColor[
              0.8877425339879393, 0.506173605243856, 0.35019746163009025`], 
             UndirectedEdge[13, 105] -> 
             RGBColor[
              0.29764935998569264`, 0.4301787277773499, 0.9402620627671929], 
             UndirectedEdge[96, 138] -> 
             RGBColor[
              0.5560749070471602, 0.6482010143955439, 0.959228106200197], 
             UndirectedEdge[254, 260] -> 
             RGBColor[
              0.870237845536556, 0.7409780985202714, 0.6082514586621423], 
             UndirectedEdge[120, 176] -> 
             RGBColor[
              0.18443322649941224`, 0.31118139316580623`, 0.9338145714534094],
              UndirectedEdge[59, 125] -> 
             RGBColor[
              0.8860818256794646, 0.49767730663813153`, 0.2655925702966138], 
             UndirectedEdge[22, 267] -> 
             RGBColor[
              0.642613111904264, 0.7180602166534845, 0.966841075599027], 
             UndirectedEdge[28, 197] -> 
             RGBColor[
              0.21695644286649302`, 0.3453653556586265, 0.9356667205117277], 
             UndirectedEdge[245, 298] -> 
             RGBColor[
              0.35482735126592213`, 0.47958317697125596`, 0.9439097968625934],
              UndirectedEdge[193, 199] -> 
             RGBColor[
              0.28921237678725265`, 0.4129203038152378, 0.9400888107445714], 
             UndirectedEdge[22, 274] -> 
             RGBColor[
              0.8909772154370372, 0.8747143818458635, 0.6496575550294168], 
             UndirectedEdge[76, 201] -> 
             RGBColor[
              0.3077043294157084, 0.43960372096206174`, 0.9408765445063949], 
             UndirectedEdge[19, 158] -> 
             RGBColor[
              0.3474496051113486, 0.47374907870238386`, 0.9434193305882683], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.17948366008578914`, 0.30597908504445237`, 0.9335327009683809],
              UndirectedEdge[61, 267] -> 
             RGBColor[
              0.517343318582302, 0.6190416379328455, 0.9551463076112685], 
             UndirectedEdge[106, 283] -> 
             RGBColor[
              0.6376959489926155, 0.716530117719581, 0.9647707808430861], 
             UndirectedEdge[174, 283] -> 
             RGBColor[
              0.5055233087265141, 0.6077894774448256, 0.9546733906594562], 
             UndirectedEdge[19, 242] -> 
             RGBColor[
              0.26584977931499626`, 0.39675535228258274`, 0.9384511236912607],
              UndirectedEdge[125, 195] -> 
             RGBColor[
              0.8769708936625604, 0.4276466907203388, 0.25686793150790044`], 
             UndirectedEdge[115, 159] -> 
             RGBColor[
              0.23449254027581456`, 0.3637969058886168, 0.9366653753168572], 
             UndirectedEdge[158, 177] -> 
             RGBColor[
              0.4114198455834537, 0.5307729245068593, 0.947436286649661], 
             UndirectedEdge[42, 134] -> 
             RGBColor[
              0.26421930785544107`, 0.3950416234007289, 0.9383582707537054], 
             UndirectedEdge[165, 179] -> 
             RGBColor[
              0.986953469781533, 0.9683582137242022, 0.5663859549250714], 
             UndirectedEdge[108, 145] -> 
             RGBColor[
              0.3065621353882716, 0.43629450439653, 0.9408887080179298], 
             UndirectedEdge[44, 125] -> 
             RGBColor[
              0.9788402151300284, 0.9402098215196141, 0.37870987228958564`], 
             UndirectedEdge[39, 141] -> 
             RGBColor[
              0.8780226232767818, 0.5390110454875421, 0.21993142573409608`], 
             UndirectedEdge[50, 87] -> 
             RGBColor[
              0.314278172622923, 0.4436160187426821, 0.9413569968700557], 
             UndirectedEdge[26, 226] -> 
             RGBColor[
              0.5823809999360594, 0.646902214593436, 0.908957705075064], 
             UndirectedEdge[9, 143] -> 
             RGBColor[
              0.4567898510085129, 0.5683456525115964, 0.9508037050929882], 
             UndirectedEdge[136, 299] -> 
             RGBColor[
              0.9936961088777931, 0.9896128904175391, 0.6052453259924624], 
             UndirectedEdge[134, 144] -> 
             RGBColor[
              0.29485513198583013`, 0.42659799471298, 0.9401265091035182], 
             UndirectedEdge[240, 281] -> 
             RGBColor[
              0.8890287827533787, 0.5160602768928254, 0.3514291749004852], 
             UndirectedEdge[257, 261] -> 
             RGBColor[
              0.39597335276996437`, 0.5173939487951174, 0.9464520497863826], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.27383547980684575`, 0.4051488298221716, 0.9389058975204863], 
             UndirectedEdge[135, 254] -> 
             RGBColor[
              0.940708824154274, 0.7947861767157479, 0.5224157389136257], 
             UndirectedEdge[14, 224] -> 
             RGBColor[
              0.8716400377324648, 0.4199339774417696, 0.22494899798707987`], 
             UndirectedEdge[96, 289] -> 
             RGBColor[
              0.3482245893870246, 0.47439408393544596`, 0.9434696729393952], 
             UndirectedEdge[92, 189] -> 
             RGBColor[
              0.2464728493758267, 0.3763889703481986, 0.937347636196824], 
             UndirectedEdge[107, 127] -> 
             RGBColor[
              0.8336887126455463, 0.25995178464749, 0.1798936553163213], 
             UndirectedEdge[172, 270] -> 
             RGBColor[
              0.24887539777286288`, 0.3789142010438502, 0.9374844577737833], 
             UndirectedEdge[48, 84] -> 
             RGBColor[
              0.35715044434118537`, 0.4830160061947183, 0.9440058041437522], 
             UndirectedEdge[149, 289] -> 
             RGBColor[
              0.29246611856111315`, 0.4247308124036294, 0.9399668848359817], 
             UndirectedEdge[1, 102] -> 
             RGBColor[
              0.40192272768373283`, 0.5225469983211459, 0.9468311386950623], 
             UndirectedEdge[33, 297] -> 
             RGBColor[
              0.8375308432174786, 0.8737699796260231, 0.9842378309047126], 
             UndirectedEdge[18, 135] -> 
             RGBColor[
              0.9682482286960121, 0.9748593362633335, 0.8947082894518925], 
             UndirectedEdge[60, 137] -> 
             RGBColor[
              0.8724049541096216, 0.4823811293510216, 0.2139725070782716], 
             UndirectedEdge[156, 208] -> 
             RGBColor[
              0.2568293808226203, 0.38727434154079826`, 0.9379374253416035], 
             UndirectedEdge[104, 279] -> 
             RGBColor[
              0.27193222945827744`, 0.4031483930327844, 0.9387975102287419], 
             UndirectedEdge[74, 158] -> 
             RGBColor[
              0.5209230649967003, 0.6205987474764012, 0.9558008759103712], 
             UndirectedEdge[80, 277] -> 
             RGBColor[
              0.30846241772387, 0.4378133913603206, 0.9410144439610391], 
             UndirectedEdge[223, 291] -> 
             RGBColor[
              0.8410569337223622, 0.2862316657285906, 0.18576082708881467`], 
             UndirectedEdge[114, 264] -> 
             RGBColor[
              0.29953624630010656`, 0.4321619649293011, 0.9403695181514007], 
             UndirectedEdge[1, 237] -> 
             RGBColor[
              0.5286509868219015, 0.6272769374241931, 0.9562975328211968], 
             UndirectedEdge[84, 292] -> 
             RGBColor[
              0.2718397461725893, 0.40305118723574723`, 0.9387922434424387], 
             UndirectedEdge[103, 152] -> 
             RGBColor[
              0.26605649274810816`, 0.396972621207172, 0.9384628957154713], 
             UndirectedEdge[10, 269] -> 
             RGBColor[
              0.2192290472618576, 0.3477540069695957, 0.9357961419700269], 
             UndirectedEdge[109, 138] -> 
             RGBColor[
              0.8139262808550589, 0.8553825016885668, 0.9818711941291625], 
             UndirectedEdge[165, 240] -> 
             RGBColor[
              0.987596961950581, 0.9683237186753911, 0.533871497674751], 
             UndirectedEdge[249, 254] -> 
             RGBColor[
              0.8428272824024504, 0.2956795702116145, 0.1872932287744991], 
             UndirectedEdge[2, 155] -> 
             RGBColor[
              0.22153004206728566`, 0.3501724984015976, 0.9359271802201792], 
             UndirectedEdge[117, 161] -> 
             RGBColor[
              0.20987266837087443`, 0.33791985952648745`, 0.9352633100337076],
              UndirectedEdge[169, 264] -> 
             RGBColor[
              0.29384317958318956`, 0.42617819084854336`, 0.9400453064240097],
              UndirectedEdge[3, 229] -> 
             RGBColor[
              0.3618568268450173, 0.48784392878537974`, 0.9442781749225044], 
             UndirectedEdge[55, 90] -> 
             RGBColor[
              0.3401206359010615, 0.4660537805054501, 0.9430016668956538], 
             UndirectedEdge[3, 259] -> 
             RGBColor[
              0.42079287632469464`, 0.5385942486118271, 0.9481156241324957], 
             UndirectedEdge[113, 254] -> 
             RGBColor[
              0.925365599889266, 0.7843240503848107, 0.5923111720047104], 
             UndirectedEdge[6, 205] -> 
             RGBColor[
              0.41755993513205164`, 0.5337399711358773, 0.9484090697443592], 
             UndirectedEdge[120, 287] -> 
             RGBColor[
              0.5654447927305568, 0.5603176274195498, 0.6027460190921992], 
             UndirectedEdge[31, 67] -> 
             RGBColor[
              0.765577527957654, 0.8171802233035855, 0.9773175856314692], 
             UndirectedEdge[141, 232] -> 
             RGBColor[
              0.9465494933171561, 0.8120284719793993, 0.41813025783551805`], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.4306059655104517, 0.5460088371370204, 0.9490406986812941], 
             UndirectedEdge[71, 122] -> 
             RGBColor[
              0.6268946494046528, 0.707980343525642, 0.9637705896733515], 
             UndirectedEdge[78, 120] -> 
             RGBColor[
              0.1849774474258748, 0.3117534038651181, 0.9338455640300687], 
             UndirectedEdge[177, 247] -> 
             RGBColor[
              0.4991479409504841, 0.603343634292864, 0.9539698061272375], 
             UndirectedEdge[168, 182] -> 
             RGBColor[
              0.34652806688330007`, 0.474422427150048, 0.9433067307526943], 
             UndirectedEdge[26, 228] -> 
             RGBColor[
              0.901089116284713, 0.9224316156704129, 0.933371766463492], 
             UndirectedEdge[7, 194] -> 
             RGBColor[
              0.4552899701705174, 0.5670735874923983, 0.9507006582548503], 
             UndirectedEdge[206, 244] -> 
             RGBColor[
              0.23959248852906917`, 0.3691572748581827, 0.9369558098251829], 
             UndirectedEdge[31, 109] -> 
             RGBColor[
              0.7700026915435176, 0.8207087286290875, 0.9777396616846791], 
             UndirectedEdge[57, 235] -> 
             RGBColor[
              0.24454607243650103`, 0.3743638056202535, 0.9372379091005405], 
             UndirectedEdge[24, 135] -> 
             RGBColor[
              0.9728662611822794, 0.9783034573302576, 0.8868911650284141], 
             UndirectedEdge[130, 220] -> 
             RGBColor[
              0.21805936955163013`, 0.34652460153429643`, 0.9357295305548126],
              UndirectedEdge[84, 112] -> 
             RGBColor[
              0.2764157065059942, 0.4078608116787981, 0.9390528376138995], 
             UndirectedEdge[76, 104] -> 
             RGBColor[
              0.2896837321277139, 0.4218063478486378, 0.9398084320447715], 
             UndirectedEdge[21, 87] -> 
             RGBColor[
              0.32978099166431396`, 0.45704378140199375`, 0.9423448227907686],
              UndirectedEdge[43, 183] -> 
             RGBColor[
              0.28838161647063476`, 0.4191962552733669, 0.9397797353853092], 
             UndirectedEdge[11, 131] -> 
             RGBColor[
              0.3341685066956953, 0.46386169752747186`, 0.9425138996464097], 
             UndirectedEdge[21, 187] -> 
             RGBColor[
              0.3736920911272321, 0.49809503984895503`, 0.9450323074970538], 
             UndirectedEdge[36, 66] -> 
             RGBColor[
              0.8530135718328662, 0.8858447874582254, 0.9760955206644191], 
             UndirectedEdge[124, 125] -> 
             RGBColor[
              0.970159485355791, 0.9735725032155419, 0.706048969605638], 
             UndirectedEdge[232, 296] -> 
             RGBColor[
              0.8451660598218556, 0.8762026073137711, 0.7845904625645401], 
             UndirectedEdge[75, 239] -> 
             RGBColor[
              0.5708233361978141, 0.6599633407458361, 0.9605961986132696], 
             UndirectedEdge[108, 114] -> 
             RGBColor[
              0.32416580444258236`, 0.4547970767096937, 0.9418912109282782], 
             UndirectedEdge[137, 266] -> 
             RGBColor[
              0.6462554556762865, 0.36003472644790463`, 0.439982957695757], 
             UndirectedEdge[74, 262] -> 
             RGBColor[
              0.8160969055518104, 0.8533507770496733, 0.7753857250766871], 
             UndirectedEdge[48, 90] -> 
             RGBColor[
              0.4086146868704133, 0.5283432370210001, 0.9472575444169704], 
             UndirectedEdge[125, 150] -> 
             RGBColor[
              0.9773157340645346, 0.9789096217852411, 0.6939353071903218], 
             UndirectedEdge[38, 55] -> 
             RGBColor[
              0.34731954937378307`, 0.4722891175276097, 0.9434603752963864], 
             UndirectedEdge[110, 165] -> 
             RGBColor[
              0.9866031709361507, 0.9682133561493669, 0.5721913133374072], 
             UndirectedEdge[114, 145] -> 
             RGBColor[
              0.28680752014306377`, 0.4187832666903979, 0.9396446360272199], 
             UndirectedEdge[222, 290] -> 
             RGBColor[
              0.5245306986367102, 0.6244100551018348, 0.9558410534763778], 
             UndirectedEdge[267, 286] -> 
             RGBColor[
              0.5134415575632728, 0.6158740125652669, 0.954839146691229], 
             UndirectedEdge[6, 187] -> 
             RGBColor[
              0.3348012763614461, 0.46412565624274105`, 0.9425646219959795], 
             UndirectedEdge[221, 231] -> 
             RGBColor[
              0.3698663550363416, 0.4934747204504928, 0.9448363781661868], 
             UndirectedEdge[106, 286] -> 
             RGBColor[
              0.6078523188068897, 0.6923017142945901, 0.9624213809540463], 
             UndirectedEdge[67, 154] -> 
             RGBColor[
              0.8267592072412856, 0.8653361474156035, 0.9831692431983503], 
             UndirectedEdge[85, 296] -> 
             RGBColor[
              0.8079306217366228, 0.8506861757670146, 0.9812769124001008], 
             UndirectedEdge[41, 201] -> 
             RGBColor[
              0.3390519049385823, 0.4680914516387281, 0.942825065464227], 
             UndirectedEdge[42, 235] -> 
             RGBColor[
              0.24823850572703557`, 0.37824478712239773`, 0.9374481877139709],
              UndirectedEdge[44, 60] -> 
             RGBColor[
              0.9455688567915195, 0.8192169579907062, 0.28906456863413965`], 
             UndirectedEdge[199, 228] -> 
             RGBColor[
              0.49763512145939465`, 0.5809234064486897, 0.9579150616794772], 
             UndirectedEdge[39, 62] -> 
             RGBColor[
              0.909971385632703, 0.6580493002103005, 0.3676837978743117], 
             UndirectedEdge[48, 144] -> 
             RGBColor[
              0.3646961975812182, 0.4903032490061542, 0.9444590971150582], 
             UndirectedEdge[68, 215] -> 
             RGBColor[
              0.9347347232001206, 0.7573256172439325, 0.47384806566130333`], 
             UndirectedEdge[127, 240] -> 
             RGBColor[
              0.8868259160618033, 0.4991280781990371, 0.3493197072688504], 
             UndirectedEdge[4, 26] -> 
             RGBColor[
              0.7627278647878275, 0.8127689353043519, 0.92065723869614], 
             UndirectedEdge[8, 47] -> 
             RGBColor[
              0.6479545398771973, 0.7249062782797447, 0.9655457111216659], 
             UndirectedEdge[112, 175] -> 
             RGBColor[
              0.27336230601956724`, 0.40465149417079094`, 0.9388789509732987],
              UndirectedEdge[162, 203] -> 
             RGBColor[
              0.27206034387321254`, 0.4032830494058043, 0.9388048061551442], 
             UndirectedEdge[6, 50] -> 
             RGBColor[
              0.32906105284495657`, 0.4591537631447806, 0.9421988600293891], 
             UndirectedEdge[15, 294] -> 
             RGBColor[
              0.2244101664519819, 0.3531996917403464, 0.9360911990431254], 
             UndirectedEdge[6, 219] -> 
             RGBColor[
              0.2899540268393041, 0.4220904447281936, 0.9398238249287314], 
             UndirectedEdge[110, 281] -> 
             RGBColor[
              0.8883662554104251, 0.5159867018754759, 0.3769757186755893], 
             UndirectedEdge[167, 297] -> 
             RGBColor[
              0.7571627446031911, 0.8102205578247882, 0.9764305643600557], 
             UndirectedEdge[122, 246] -> 
             RGBColor[
              0.6115303319065195, 0.6955068984260417, 0.962561054318549], 
             UndirectedEdge[210, 277] -> 
             RGBColor[
              0.36382607089811214`, 0.48954958900708645`, 0.9444036534122333],
              UndirectedEdge[225, 234] -> 
             RGBColor[
              0.8652002847569147, 0.3827448941589432, 0.21042816323286231`], 
             UndirectedEdge[84, 280] -> 
             RGBColor[
              0.28433817175579457`, 0.41618782496964746`, 0.9395040102896386],
              UndirectedEdge[67, 95] -> 
             RGBColor[
              0.7004824194836051, 0.7643330817431344, 0.9721930602411528], 
             UndirectedEdge[81, 285] -> 
             RGBColor[
              0.33930631085889784`, 0.4671186752480599, 0.9428849623189395], 
             UndirectedEdge[79, 164] -> 
             RGBColor[
              0.38942752096010885`, 0.5117242782844935, 0.9460349551717104], 
             UndirectedEdge[123, 157] -> 
             RGBColor[
              0.3911005410183704, 0.5131733641705265, 0.9461415585304294], 
             UndirectedEdge[85, 165] -> 
             RGBColor[
              0.9499430145672961, 0.9419121380578821, 0.6850057931573457], 
             UndirectedEdge[59, 62] -> 
             RGBColor[
              0.8868230148643443, 0.4992626353588674, 0.34626643898134246`], 
             UndirectedEdge[38, 48] -> 
             RGBColor[
              0.41581360034313486`, 0.5345785740431597, 0.947716252817703], 
             UndirectedEdge[262, 291] -> 
             RGBColor[
              0.8765985883861446, 0.42228014315900764`, 0.3052246115453534], 
             UndirectedEdge[26, 170] -> 
             RGBColor[
              0.8765406231158585, 0.4423289056195874, 0.40720379569933324`], 
             UndirectedEdge[43, 139] -> 
             RGBColor[
              0.2888262243395204, 0.4196635663333328, 0.9398050551457039], 
             UndirectedEdge[52, 281] -> 
             RGBColor[
              0.8238308107140992, 0.18417963064221682`, 0.17045371729385975`],
              UndirectedEdge[124, 142] -> 
             RGBColor[
              0.8033587771487245, 0.8470321673736835, 0.9700369554308557], 
             UndirectedEdge[166, 271] -> 
             RGBColor[
              0.9850940999243964, 0.9612451065301149, 0.40815265332302325`], 
             UndirectedEdge[37, 150] -> 
             RGBColor[
              0.8213545365263866, 0.860837194061274, 0.9590036741380308], 
             UndirectedEdge[51, 66] -> 
             RGBColor[
              0.9700089985303242, 0.9755966228942858, 0.8659381168837096], 
             UndirectedEdge[60, 125] -> 
             RGBColor[
              0.9593538076584427, 0.8656414371856946, 0.3490277111915949], 
             UndirectedEdge[215, 223] -> 
             RGBColor[
              0.9412290011481947, 0.7868146166289862, 0.47926705037049566`], 
             UndirectedEdge[237, 282] -> 
             RGBColor[
              0.8012181754265049, 0.8450224537789045, 0.955554762540068], 
             UndirectedEdge[143, 172] -> 
             RGBColor[
              0.33312272414216076`, 0.4593269071857189, 0.9425801382634016], 
             UndirectedEdge[177, 285] -> 
             RGBColor[
              0.40098949086418123`, 0.5217386754938967, 0.9467716736701495], 
             UndirectedEdge[244, 270] -> 
             RGBColor[
              0.23538330068246843`, 0.36473315155348174`, 0.9367161028042543],
              UndirectedEdge[147, 272] -> 
             RGBColor[
              0.2247364657597668, 0.3535426530013993, 0.9361097813059873], 
             UndirectedEdge[46, 114] -> 
             RGBColor[
              0.29827465777054285`, 0.4308359553953969, 0.9402976725509951], 
             UndirectedEdge[104, 128] -> 
             RGBColor[
              0.26216622821870855`, 0.39288370652975557`, 0.9382413509056526],
              UndirectedEdge[199, 220] -> 
             RGBColor[
              0.21805936955163013`, 0.34652460153429643`, 0.9357295305548126],
              UndirectedEdge[112, 146] -> 
             RGBColor[
              0.24133200131587673`, 0.37098561308859834`, 0.937054872505013], 
             UndirectedEdge[191, 203] -> 
             RGBColor[
              0.2517414689713402, 0.38192662359285945`, 0.9376476762885642], 
             UndirectedEdge[31, 96] -> 
             RGBColor[
              0.512151317735619, 0.6135272413360646, 0.9550965737557137], 
             UndirectedEdge[59, 228] -> 
             RGBColor[
              0.8273211846534105, 0.45428347736572383`, 0.4468112731339182], 
             UndirectedEdge[129, 289] -> 
             RGBColor[
              0.26344635035437974`, 0.39422919605877726`, 0.9383142519675081],
              UndirectedEdge[54, 106] -> 
             RGBColor[
              0.5370375913061106, 0.6338360445866622, 0.9571160047492481], 
             UndirectedEdge[102, 142] -> 
             RGBColor[
              0.5221732711977142, 0.6208612990518254, 0.9562111960106483], 
             UndirectedEdge[74, 90] -> 
             RGBColor[
              0.5208802713688769, 0.620561681786851, 0.9557981491382472], 
             UndirectedEdge[143, 174] -> 
             RGBColor[
              0.39453676766698986`, 0.5161496509837875, 0.9463605118539434], 
             UndirectedEdge[144, 292] -> 
             RGBColor[
              0.2793854994126222, 0.4103384300471832, 0.9392455364137446], 
             UndirectedEdge[59, 255] -> 
             RGBColor[
              0.8748582159180097, 0.45986770011020284`, 0.21771682476822068`],
              UndirectedEdge[254, 258] -> 
             RGBColor[
              0.926544473085371, 0.7852032520842381, 0.5903156471830767], 
             UndirectedEdge[46, 108] -> 
             RGBColor[
              0.3180292730157506, 0.448347193101529, 0.9415417445417048], 
             UndirectedEdge[222, 278] -> 
             RGBColor[
              0.51953209520131, 0.6203519636484585, 0.9554475451034554], 
             UndirectedEdge[115, 294] -> 
             RGBColor[
              0.2157444487404361, 0.3440914729872748, 0.9355976992392334], 
             UndirectedEdge[89, 177] -> 
             RGBColor[
              0.3486700459196015, 0.47359177071300174`, 0.9435415608547846], 
             UndirectedEdge[45, 195] -> 
             RGBColor[
              0.8449304467632349, 0.34636067923534536`, 0.19065875260314252`],
              UndirectedEdge[205, 231] -> 
             RGBColor[
              0.4872830813565614, 0.5944147705735998, 0.9528413641420233], 
             UndirectedEdge[148, 244] -> 
             RGBColor[
              0.24066234627754973`, 0.37028176318473494`, 0.9370167366412461],
              UndirectedEdge[20, 297] -> 
             RGBColor[
              0.8131524423226874, 0.8543313044865806, 0.981912597264512], 
             UndirectedEdge[6, 34] -> 
             RGBColor[
              0.31658612534963915`, 0.4483486079564237, 0.9414039686805327], 
             UndirectedEdge[13, 245] -> 
             RGBColor[
              0.36526550488349396`, 0.49055433824048805`, 0.9445042342692497],
              UndirectedEdge[104, 201] -> 
             RGBColor[
              0.30309244121459367`, 0.43475633405208935`, 0.9406139042960187],
              UndirectedEdge[55, 253] -> 
             RGBColor[
              0.2867100868131406, 0.4186808580830187, 0.9396390873432205], 
             UndirectedEdge[52, 141] -> 
             RGBColor[
              0.8448061612897839, 0.30283661966394393`, 0.18887285131987525`],
              UndirectedEdge[160, 299] -> 
             RGBColor[
              0.7923522710279916, 0.8350967196266381, 0.8509761351220573], 
             UndirectedEdge[229, 284] -> 
             RGBColor[
              0.3010164849724387, 0.4302374601386527, 0.9405812474653377], 
             UndirectedEdge[27, 268] -> 
             RGBColor[
              0.2604774227946408, 0.3911086649526121, 0.9381451759351156], 
             UndirectedEdge[193, 236] -> 
             RGBColor[
              0.511354201918838, 0.6127180573453962, 0.9550785966275717], 
             UndirectedEdge[78, 193] -> 
             RGBColor[
              0.2897690368730418, 0.4135053888596902, 0.9401205117129523], 
             UndirectedEdge[175, 177] -> 
             RGBColor[
              0.3568594089399756, 0.48219931048302006`, 0.944007932963718], 
             UndirectedEdge[36, 67] -> 
             RGBColor[
              0.8359448003222887, 0.8725120025435762, 0.9840847772724168], 
             UndirectedEdge[37, 239] -> 
             RGBColor[
              0.5459185219885249, 0.6405075106019407, 0.9581139194816087], 
             UndirectedEdge[49, 280] -> 
             RGBColor[
              0.2523064385494426, 0.38252044244058536`, 0.9376798504702395], 
             UndirectedEdge[263, 276] -> 
             RGBColor[
              0.24638255548127658`, 0.37629406574006286`, 0.9373424940931072],
              UndirectedEdge[13, 73] -> 
             RGBColor[
              0.31756925587348483`, 0.44924224463119755`, 0.9414650714584689],
              UndirectedEdge[136, 240] -> 
             RGBColor[
              0.9939206142632153, 0.9894051335662295, 0.5796745640498617], 
             UndirectedEdge[79, 241] -> 
             RGBColor[
              0.3370030923017984, 0.46357362454027395`, 0.9427949607029437], 
             UndirectedEdge[78, 226] -> 
             RGBColor[
              0.17948366519653014`, 0.30597909041616517`, 0.9335327012594301],
              UndirectedEdge[3, 74] -> 
             RGBColor[
              0.5077694883992605, 0.6092057805456816, 0.9549627416408335], 
             UndirectedEdge[148, 203] -> 
             RGBColor[
              0.2492037147300215, 0.37925928298232137`, 0.9375031549387921], 
             UndirectedEdge[90, 257] -> 
             RGBColor[
              0.39742589509621323`, 0.518652067951214, 0.9465446044989785], 
             UndirectedEdge[34, 87] -> 
             RGBColor[
              0.3018032451276056, 0.4328108635543251, 0.9405621055211995], 
             UndirectedEdge[146, 235] -> 
             RGBColor[
              0.23624487142727435`, 0.3656387170330131, 0.9367651679835913], 
             UndirectedEdge[181, 256] -> 
             RGBColor[
              0.8545325264557142, 0.8843014088645924, 0.8481299389821997], 
             UndirectedEdge[68, 287] -> 
             RGBColor[
              0.9076706141527531, 0.6630503890698746, 0.24412287160438084`], 
             UndirectedEdge[17, 144] -> 
             RGBColor[
              0.3059659418661292, 0.4382761603632087, 0.940759253289231], 
             UndirectedEdge[163, 216] -> 
             RGBColor[
              0.2500986511246546, 0.3801999178753255, 0.9375541202425267], 
             UndirectedEdge[67, 258] -> 
             RGBColor[
              0.9370426830307382, 0.9519641935346369, 0.9705507738068005], 
             UndirectedEdge[232, 240] -> 
             RGBColor[
              0.9945150494485371, 0.9906765703210165, 0.6443751655434223], 
             UndirectedEdge[133, 210] -> 
             RGBColor[
              0.36435206965698563`, 0.49000518269455634`, 0.9444371695880264],
              UndirectedEdge[58, 154] -> 
             RGBColor[
              0.6450616328403926, 0.7212149997583763, 0.9662359728150638], 
             UndirectedEdge[94, 124] -> 
             RGBColor[
              0.9048214633960636, 0.926634777474092, 0.9800597975853467], 
             UndirectedEdge[50, 213] -> 
             RGBColor[
              0.3901638861949155, 0.5123620808400902, 0.94608187571333], 
             UndirectedEdge[15, 212] -> 
             RGBColor[
              0.22532179004368708`, 0.3541578659355026, 0.9361431146580468], 
             UndirectedEdge[11, 139] -> 
             RGBColor[
              0.2994922538712322, 0.4289019450234698, 0.940484685115865], 
             UndirectedEdge[167, 286] -> 
             RGBColor[
              0.6564811647517911, 0.7302909383396649, 0.9672682498554315], 
             UndirectedEdge[113, 288] -> 
             RGBColor[
              0.8944038389605427, 0.6336207235327678, 0.45551738437603884`], 
             UndirectedEdge[73, 171] -> 
             RGBColor[
              0.3736817156213931, 0.4980860531072854, 0.9450316463789965], 
             UndirectedEdge[31, 110] -> 
             RGBColor[
              0.8058913506986181, 0.8463947757840589, 0.8648515957717691], 
             UndirectedEdge[202, 275] -> 
             RGBColor[
              0.22044981250771753`, 0.3490371086439815, 0.9358656627448182], 
             UndirectedEdge[103, 241] -> 
             RGBColor[
              0.2789461451652853, 0.41052046314879065`, 0.9391969423520976], 
             UndirectedEdge[9, 20] -> 
             RGBColor[
              0.6913677553568252, 0.7572692319617951, 0.9710889688646087], 
             UndirectedEdge[71, 207] -> 
             RGBColor[
              0.6875924129964879, 0.7556761815938675, 0.9696301113207838], 
             UndirectedEdge[160, 168] -> 
             RGBColor[
              0.4880465107801085, 0.5934258804224648, 0.9533459462263981], 
             UndirectedEdge[6, 114] -> 
             RGBColor[
              0.30504212315896806`, 0.43794899060072, 0.940683069693298], 
             UndirectedEdge[95, 96] -> 
             RGBColor[
              0.44705620926157014`, 0.5606800997756136, 0.9499720483653973], 
             UndirectedEdge[198, 278] -> 
             RGBColor[
              0.5335934338471843, 0.6322342135642272, 0.9564255762110536], 
             UndirectedEdge[86, 281] -> 
             RGBColor[
              0.8823401280939172, 0.49449791614993305`, 0.24040866188212537`],
              UndirectedEdge[107, 165] -> 
             RGBColor[
              0.8828514694572672, 0.490674938099604, 0.2461602468156653], 
             UndirectedEdge[155, 184] -> 
             RGBColor[
              0.22486994634019453`, 0.35368294955458646`, 0.9361173828275757],
              UndirectedEdge[247, 285] -> 
             RGBColor[
              0.4809297969495969, 0.5875639936298371, 0.952808962101173], 
             UndirectedEdge[34, 227] -> 
             RGBColor[
              0.2936321912026204, 0.4242225678044243, 0.9400967760881624], 
             UndirectedEdge[116, 152] -> 
             RGBColor[
              0.2878519743324149, 0.4186179236915859, 0.9397503655460857], 
             UndirectedEdge[146, 204] -> 
             RGBColor[
              0.23066664293228167`, 0.35977564520466165`, 0.936447496123051], 
             UndirectedEdge[36, 58] -> 
             RGBColor[
              0.6542472259213957, 0.728390854886349, 0.9671515068891303], 
             UndirectedEdge[105, 129] -> 
             RGBColor[
              0.2625398824694277, 0.39327644083830926`, 0.9382626299624591], 
             UndirectedEdge[87, 187] -> 
             RGBColor[
              0.3200183961394125, 0.4485879118406425, 0.9417227588366461], 
             UndirectedEdge[119, 168] -> 
             RGBColor[
              0.3340488783835623, 0.46130600881057365`, 0.9425960594289393], 
             UndirectedEdge[20, 37] -> 
             RGBColor[
              0.7733043134332283, 0.8232016433411387, 0.9779409081787471], 
             UndirectedEdge[150, 200] -> 
             RGBColor[
              0.9240011310350597, 0.7732005239509658, 0.5878910864110933], 
             UndirectedEdge[1, 43] -> 
             RGBColor[
              0.370348202098986, 0.49519873124143765`, 0.944819237845059], 
             UndirectedEdge[187, 213] -> 
             RGBColor[
              0.395904109711405, 0.5173339739380506, 0.9464476376799205], 
             UndirectedEdge[41, 222] -> 
             RGBColor[
              0.3965617253644508, 0.517903567563995, 0.9464895403678258], 
             UndirectedEdge[196, 263] -> 
             RGBColor[
              0.27095799274113747`, 0.40212440847289477`, 0.9387420288889549],
              UndirectedEdge[148, 172] -> 
             RGBColor[
              0.2541544433679442, 0.3844628126751034, 0.9377850916107751], 
             UndirectedEdge[96, 171] -> 
             RGBColor[
              0.4119096090232586, 0.5311971329821921, 0.9474674939429645], 
             UndirectedEdge[178, 208] -> 
             RGBColor[
              0.2815080542956977, 0.41321319207927465`, 0.9393428392870697], 
             UndirectedEdge[25, 270] -> 
             RGBColor[
              0.24003287271686014`, 0.3696201465615213, 0.9369808890531874], 
             UndirectedEdge[47, 217] -> 
             RGBColor[
              0.7255477462839056, 0.7855226808548759, 0.9732794767865461], 
             UndirectedEdge[33, 142] -> 
             RGBColor[
              0.7868432036591011, 0.8341724103626897, 0.9791857606964562], 
             UndirectedEdge[26, 62] -> 
             RGBColor[
              0.9903418616011138, 0.9899003526601282, 0.7825545152346283], 
             UndirectedEdge[48, 177] -> 
             RGBColor[
              0.4164452697798513, 0.5351256943606145, 0.9477565022356473], 
             UndirectedEdge[238, 300] -> 
             RGBColor[
              0.2671877155710705, 0.398161608117775, 0.9385273171817448], 
             UndirectedEdge[25, 139] -> 
             RGBColor[
              0.25364452897953216`, 0.38392686032244283`, 0.9377560527407058],
              UndirectedEdge[3, 30] -> 
             RGBColor[
              0.4197616538813304, 0.5377570557762624, 0.9480344425242617], 
             UndirectedEdge[95, 171] -> 
             RGBColor[
              0.45349990749309843`, 0.5662613073140733, 0.9503826351187716], 
             UndirectedEdge[21, 50] -> 
             RGBColor[
              0.3679518676107426, 0.4931231467509946, 0.9446665455304635], 
             UndirectedEdge[122, 232] -> 
             RGBColor[
              0.8091446434633787, 0.8477841192514302, 0.781190448595753], 
             UndirectedEdge[127, 136] -> 
             RGBColor[
              0.886150619739554, 0.4976836876486773, 0.27581787003783265`], 
             UndirectedEdge[41, 290] -> 
             RGBColor[
              0.4849597446468357, 0.5901356836497829, 0.9533196272793637], 
             UndirectedEdge[123, 259] -> 
             RGBColor[
              0.4502407471664895, 0.5641005142419657, 0.9499920164228051], 
             UndirectedEdge[20, 185] -> 
             RGBColor[
              0.7169880778773853, 0.7780689639663625, 0.973105894503761], 
             UndirectedEdge[163, 211] -> 
             RGBColor[
              0.2418593140070983, 0.3715398521606279, 0.9370849021826888], 
             UndirectedEdge[33, 37] -> 
             RGBColor[
              0.7976827143280194, 0.8426403184805812, 0.9802661418189477], 
             UndirectedEdge[7, 9] -> 
             RGBColor[
              0.45578820295562306`, 0.5674780753124783, 0.9507398809647807], 
             UndirectedEdge[105, 263] -> 
             RGBColor[
              0.2750769487244079, 0.40645369236820506`, 0.9389765973387527], 
             UndirectedEdge[15, 49] -> 
             RGBColor[
              0.2377386487348052, 0.36720877169417954`, 0.9368502363914097], 
             UndirectedEdge[20, 237] -> 
             RGBColor[
              0.752342583517374, 0.8067713443472341, 0.9758891306955624], 
             UndirectedEdge[26, 220] -> 
             RGBColor[
              0.6215133643769486, 0.6880328107560196, 0.9111862353388274], 
             UndirectedEdge[101, 187] -> 
             RGBColor[
              0.4552598760386822, 0.566212394980653, 0.9509294886200896], 
             UndirectedEdge[93, 94] -> 
             RGBColor[
              0.6965792865266065, 0.7615288190518337, 0.9714662855765266], 
             UndirectedEdge[143, 297] -> 
             RGBColor[
              0.5785745379743751, 0.6654077250363819, 0.9616273334928914], 
             UndirectedEdge[208, 268] -> 
             RGBColor[
              0.274238057450941, 0.4055719644510125, 0.9389288237217572], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.9540665099241967, 0.9616166407194549, 0.7611949655148192], 
             UndirectedEdge[224, 288] -> 
             RGBColor[
              0.897775647296635, 0.6134919733958007, 0.2496893942062774], 
             UndirectedEdge[1, 75] -> 
             RGBColor[
              0.5745175309470449, 0.663163066561993, 0.9608315894360424], 
             UndirectedEdge[36, 113] -> 
             RGBColor[
              0.8594902789211216, 0.8906751050000117, 0.9651321449597499], 
             UndirectedEdge[29, 244] -> 
             RGBColor[
              0.24266708121897157`, 0.3723888667157059, 0.9371309033304205], 
             UndirectedEdge[36, 96] -> 
             RGBColor[
              0.5825185901002536, 0.6688590205760554, 0.9618637653966613], 
             UndirectedEdge[58, 138] -> 
             RGBColor[
              0.6278035428683023, 0.7077328487058376, 0.9645158476926661], 
             UndirectedEdge[71, 136] -> 
             RGBColor[
              0.8112521109064372, 0.8487062087696886, 0.716702550774494], 
             UndirectedEdge[144, 252] -> 
             RGBColor[
              0.3081203950955903, 0.44054062730759674`, 0.940881946213421], 
             UndirectedEdge[58, 198] -> 
             RGBColor[
              0.506589269540044, 0.610311016455952, 0.9542997094772824], 
             UndirectedEdge[110, 154] -> 
             RGBColor[
              0.8670730299822498, 0.8945506998960768, 0.8707032533386501], 
             UndirectedEdge[119, 152] -> 
             RGBColor[
              0.2677604183233837, 0.39876355502190786`, 0.9385599317562512], 
             UndirectedEdge[38, 90] -> 
             RGBColor[
              0.41074538251891396`, 0.5301887384998543, 0.9473933104595927], 
             UndirectedEdge[66, 179] -> 
             RGBColor[
              0.9700512243327243, 0.9756140843487318, 0.8652383260610674], 
             UndirectedEdge[6, 21] -> 
             RGBColor[
              0.3445638718863475, 0.47258152580409235`, 0.9431866859501019], 
             UndirectedEdge[176, 287] -> 
             RGBColor[
              0.5599634445497977, 0.5545563829440247, 0.6024338644222329], 
             UndirectedEdge[142, 237] -> 
             RGBColor[
              0.6489015303358828, 0.7255912381548726, 0.9656775901367828], 
             UndirectedEdge[108, 221] -> 
             RGBColor[
              0.3192668900954462, 0.449648007121744, 0.9416122250035031], 
             UndirectedEdge[44, 256] -> 
             RGBColor[
              0.9801516197044022, 0.9430147833008583, 0.5214481671592728], 
             UndirectedEdge[89, 112] -> 
             RGBColor[
              0.26517294299919314`, 0.39604395440077267`, 0.9384125788643654],
              UndirectedEdge[83, 184] -> 
             RGBColor[
              0.22686279734830417`, 0.3557775623181615, 0.9362308727443287], 
             UndirectedEdge[259, 261] -> 
             RGBColor[
              0.4324511169680622, 0.5486920306968999, 0.9488584769173136], 
             UndirectedEdge[207, 231] -> 
             RGBColor[
              0.5953538117647618, 0.6805701172311853, 0.962430259270135], 
             UndirectedEdge[112, 280] -> 
             RGBColor[
              0.2601358942740522, 0.3907496968233146, 0.9381257263911142], 
             UndirectedEdge[174, 194] -> 
             RGBColor[
              0.45407833864122044`, 0.5660241331600927, 0.9506234541652072], 
             UndirectedEdge[125, 200] -> 
             RGBColor[
              0.9393105629674767, 0.7809252028803274, 0.3326287940678124], 
             UndirectedEdge[99, 222] -> 
             RGBColor[
              0.4018105363813725, 0.5224498238539401, 0.9468239899644828], 
             UndirectedEdge[108, 169] -> 
             RGBColor[
              0.3184727377256654, 0.44881330262893604`, 0.9415669992008873], 
             UndirectedEdge[15, 57] -> 
             RGBColor[
              0.2429878777602664, 0.3727260442202823, 0.9371491722188713], 
             UndirectedEdge[4, 78] -> 
             RGBColor[
              0.3598305300482983, 0.47184581112708096`, 0.9452322348805061], 
             UndirectedEdge[52, 86] -> 
             RGBColor[
              0.8700945440512431, 0.4003729911487963, 0.2286822767734516], 
             UndirectedEdge[20, 282] -> 
             RGBColor[
              0.9147814478549319, 0.9341649508472791, 0.9667376994595409], 
             UndirectedEdge[42, 55] -> 
             RGBColor[
              0.2655663224814774, 0.39645742117835314`, 0.9384349812439285], 
             UndirectedEdge[136, 165] -> 
             RGBColor[
              0.9865840174672071, 0.9661571328498515, 0.42361874182822423`], 
             UndirectedEdge[161, 269] -> 
             RGBColor[
              0.22164816720784125`, 0.350296655413888, 0.9359339072721834], 
             UndirectedEdge[57, 243] -> 
             RGBColor[
              0.23260979600231052`, 0.3618180222842825, 0.9365581558157519], 
             UndirectedEdge[57, 146] -> 
             RGBColor[
              0.23875177461672836`, 0.3682736312319718, 0.9369079324115999], 
             UndirectedEdge[4, 130] -> 
             RGBColor[
              0.3592738699625091, 0.4712607260826286, 0.9452005339121252], 
             UndirectedEdge[31, 58] -> 
             RGBColor[
              0.583879953556761, 0.6730590756463584, 0.9603843152481828], 
             UndirectedEdge[95, 140] -> 
             RGBColor[
              0.4083602605702821, 0.527163613934152, 0.9475063767322723], 
             UndirectedEdge[58, 96] -> 
             RGBColor[
              0.47719454661287236`, 0.585147759754026, 0.9523446486820593], 
             UndirectedEdge[16, 94] -> 
             RGBColor[
              0.9277097420952534, 0.9406004694880592, 0.7586810334703302], 
             UndirectedEdge[113, 135] -> 
             RGBColor[
              0.9747525126984742, 0.9797102206225822, 0.8836982332246824], 
             UndirectedEdge[47, 262] -> 
             RGBColor[
              0.8190197652374052, 0.8556976322352333, 0.77563363654671], 
             UndirectedEdge[153, 211] -> 
             RGBColor[
              0.25792046228139853`, 0.38842113733253425`, 0.9379995608165705],
              UndirectedEdge[89, 111] -> 
             RGBColor[
              0.26057341862775985`, 0.3912095626597075, 0.9381506427557986], 
             UndirectedEdge[137, 256] -> 
             RGBColor[
              0.8954601293848767, 0.5649130128911231, 0.36889490609502695`], 
             UndirectedEdge[136, 181] -> 
             RGBColor[
              0.8533623737727853, 0.8817985705963918, 0.7207660407906598], 
             UndirectedEdge[288, 291] -> 
             RGBColor[
              0.8472367474404496, 0.3567561650145, 0.19258017572083644`], 
             UndirectedEdge[121, 296] -> 
             RGBColor[
              0.8454228514141477, 0.8767518585640715, 0.8125406426515358], 
             UndirectedEdge[241, 277] -> 
             RGBColor[
              0.3140852328677468, 0.44372332658360614`, 0.9413346549652732], 
             UndirectedEdge[217, 262] -> 
             RGBColor[
              0.9005077184585596, 0.9193566406229818, 0.783755594175576], 
             UndirectedEdge[75, 142] -> 
             RGBColor[
              0.6947680744610263, 0.7614773672926725, 0.9702116467516284], 
             UndirectedEdge[57, 112] -> 
             RGBColor[
              0.24963320232510341`, 0.37971070167583876`, 0.9375276136219621],
              UndirectedEdge[274, 287] -> 
             RGBColor[
              0.9527752319881305, 0.8479297220628771, 0.29412403319976], 
             UndirectedEdge[97, 252] -> 
             RGBColor[
              0.2790058648824081, 0.41058323235793537`, 0.9392003433016403], 
             UndirectedEdge[18, 69] -> 
             RGBColor[
              0.9697193647682323, 0.9735318279786378, 0.7296111092370301], 
             UndirectedEdge[106, 167] -> 
             RGBColor[
              0.7052976145619072, 0.7697031240469493, 0.9712611329047376], 
             UndirectedEdge[256, 296] -> 
             RGBColor[
              0.8457417773194627, 0.8774340088271846, 0.8472537592625196], 
             UndirectedEdge[131, 183] -> 
             RGBColor[
              0.2897103519915022, 0.4203471391973532, 0.9398644012377442], 
             UndirectedEdge[172, 183] -> 
             RGBColor[
              0.2620424461666492, 0.39275360374480583`, 0.9382343017009069], 
             UndirectedEdge[1, 143] -> 
             RGBColor[
              0.4076363549020162, 0.5274958550423691, 0.9471952059690492], 
             UndirectedEdge[17, 252] -> 
             RGBColor[
              0.29837684649391727`, 0.43094336222280266`, 0.9403034920476165],
              UndirectedEdge[126, 214] -> 
             RGBColor[
              0.21941035515512047`, 0.34794457306099935`, 0.9358064671863272],
              UndirectedEdge[84, 134] -> 
             RGBColor[
              0.2873093787457973, 0.41931075190154404`, 0.9396732161322123], 
             UndirectedEdge[45, 234] -> 
             RGBColor[
              0.84432219426478, 0.3416853839942764, 0.19007628932369913`], 
             UndirectedEdge[32, 156] -> 
             RGBColor[
              0.24197823755521267`, 0.3716648483498845, 0.9370916747028223], 
             UndirectedEdge[140, 149] -> 
             RGBColor[
              0.3110114912745308, 0.4424361680704541, 0.9410884474530516], 
             UndirectedEdge[16, 150] -> 
             RGBColor[
              0.9777383321225639, 0.9798135163001478, 0.7399324978339024], 
             UndirectedEdge[209, 218] -> 
             RGBColor[
              0.2605995221174108, 0.3912369990823875, 0.9381521293109176], 
             UndirectedEdge[82, 281] -> 
             RGBColor[
              0.8890764883956016, 0.5161623144377598, 0.3566216396513491], 
             UndirectedEdge[178, 182] -> 
             RGBColor[
              0.29211972893207316`, 0.4243667349411374, 0.9399471584590454], 
             UndirectedEdge[41, 157] -> 
             RGBColor[
              0.35148560431038395`, 0.4788608970986815, 0.9436173297935095], 
             UndirectedEdge[254, 288] -> 
             RGBColor[
              0.8717080465977426, 0.5103380275948782, 0.21466238816866762`], 
             UndirectedEdge[129, 161] -> 
             RGBColor[
              0.22609023535273692`, 0.35496555067756064`, 0.9361868764815843],
              UndirectedEdge[20, 283] -> 
             RGBColor[
              0.7423144926570131, 0.7986300884264481, 0.9750996826489275], 
             UndirectedEdge[162, 210] -> 
             RGBColor[
              0.33154191612091594`, 0.45934744108992703`, 0.9424285250056568],
              UndirectedEdge[203, 244] -> 
             RGBColor[
              0.2510525753068279, 0.38120255267307596`, 0.9376084448134971], 
             UndirectedEdge[121, 246] -> 
             RGBColor[
              0.796739020185918, 0.8380534516751759, 0.8081437970002479], 
             UndirectedEdge[24, 259] -> 
             RGBColor[
              0.7099488174717532, 0.7711907329676471, 0.9554734955620947], 
             UndirectedEdge[141, 281] -> 
             RGBColor[
              0.857051745332458, 0.3969615446650806, 0.200599236428549], 
             UndirectedEdge[110, 138] -> 
             RGBColor[
              0.8498149400101593, 0.8810685488435381, 0.8689831282162525], 
             UndirectedEdge[67, 109] -> 
             RGBColor[
              0.916743494821664, 0.9364503947042759, 0.9919210069943111], 
             UndirectedEdge[154, 245] -> 
             RGBColor[
              0.5828013526273942, 0.6698841791824666, 0.9615515465694076], 
             UndirectedEdge[193, 249] -> 
             RGBColor[
              0.6788858964789302, 0.269361770595781, 0.42584254337299554`], 
             UndirectedEdge[82, 137] -> 
             RGBColor[
              0.8954030295607297, 0.5647908821409502, 0.362679942615882], 
             UndirectedEdge[100, 125] -> 
             RGBColor[
              0.897661942750397, 0.5866871608849751, 0.27668170348161025`], 
             UndirectedEdge[104, 218] -> 
             RGBColor[
              0.2705572837668725, 0.40170323793452584`, 0.9387192091056663], 
             UndirectedEdge[73, 149] -> 
             RGBColor[
              0.3114795465639533, 0.4428415740370091, 0.9411182715222086], 
             UndirectedEdge[108, 219] -> 
             RGBColor[
              0.30907770812291846`, 0.4389385308371674, 0.9410319661637115], 
             UndirectedEdge[58, 140] -> 
             RGBColor[
              0.4384985979215843, 0.5516312739125644, 0.9498789770489342], 
             UndirectedEdge[9, 63] -> 
             RGBColor[
              0.42067147200560917`, 0.537061727981794, 0.9485022739211517], 
             UndirectedEdge[48, 217] -> 
             RGBColor[
              0.6103593020998471, 0.6909573809034649, 0.9644909605952465], 
             UndirectedEdge[8, 271] -> 
             RGBColor[
              0.814657116181253, 0.8317974978685563, 0.6664449508576125], 
             UndirectedEdge[18, 222] -> 
             RGBColor[
              0.6912666998914337, 0.7558621322945974, 0.9623123726675136], 
             UndirectedEdge[215, 234] -> 
             RGBColor[
              0.8765804096252258, 0.42016569118196145`, 0.35308390005828916`],
              UndirectedEdge[15, 146] -> 
             RGBColor[
              0.2346866767510397, 0.3640009556330419, 0.9366764311019222], 
             UndirectedEdge[54, 151] -> 
             RGBColor[
              0.4303399784091667, 0.5471605926069658, 0.9486418607828988], 
             UndirectedEdge[195, 255] -> 
             RGBColor[
              0.8657472839011056, 0.38983708419241014`, 0.20899218597950728`],
              UndirectedEdge[1, 11] -> 
             RGBColor[
              0.3810142316306978, 0.5044371099315746, 0.9454988678152201], 
             UndirectedEdge[32, 178] -> 
             RGBColor[
              0.2666569110282901, 0.3976036988883609, 0.9384970886482884], 
             UndirectedEdge[126, 189] -> 
             RGBColor[
              0.22889351140479614`, 0.3579119715462422, 0.9363465189056738], 
             UndirectedEdge[61, 273] -> 
             RGBColor[
              0.5923372400801741, 0.6799250818424811, 0.9610501038233672], 
             UndirectedEdge[54, 194] -> 
             RGBColor[
              0.4666198015964266, 0.5768869180196359, 0.9514225850947327], 
             UndirectedEdge[38, 144] -> 
             RGBColor[
              0.36682689322971884`, 0.49214875048500833`, 0.9445948631576804],
              UndirectedEdge[4, 220] -> 
             RGBColor[
              0.3984062395141392, 0.5123913276169251, 0.9474290644669376], 
             UndirectedEdge[45, 200] -> 
             RGBColor[
              0.8672145142441139, 0.4887150856762938, 0.21086514708656048`], 
             UndirectedEdge[2, 202] -> 
             RGBColor[
              0.22943917498765481`, 0.3584854985688961, 0.9363775936394806], 
             UndirectedEdge[17, 175] -> 
             RGBColor[
              0.29536678813966943`, 0.42777960004376564`, 0.9401320736773244],
              UndirectedEdge[233, 262] -> 
             RGBColor[
              0.9940341182393746, 0.9896479070942221, 0.5920287713894679], 
             UndirectedEdge[67, 138] -> 
             RGBColor[
              0.8095011172691953, 0.8518539963630647, 0.9814491180759526], 
             UndirectedEdge[39, 192] -> 
             RGBColor[
              0.8666838536380115, 0.4875243407948174, 0.2104700784088291], 
             UndirectedEdge[164, 168] -> 
             RGBColor[
              0.38489864849528777`, 0.5078015965832141, 0.9457463794229767], 
             UndirectedEdge[19, 253] -> 
             RGBColor[
              0.2939962623956044, 0.42633909059040226`, 0.940054024263711], 
             UndirectedEdge[24, 74] -> 
             RGBColor[
              0.7969254295463191, 0.8418022649015016, 0.9623206130704325], 
             UndirectedEdge[80, 133] -> 
             RGBColor[
              0.30898841648274356`, 0.43826898504779055`, 0.941047960136832], 
             UndirectedEdge[198, 222] -> 
             RGBColor[
              0.4501940180001994, 0.5640601889318158, 0.9499889976724383], 
             UndirectedEdge[111, 212] -> 
             RGBColor[
              0.2273675902370908, 0.3563081316499939, 0.936259619952571], 
             UndirectedEdge[126, 184] -> 
             RGBColor[
              0.23168784072436213`, 0.3608489888318178, 0.9365056518265833], 
             UndirectedEdge[132, 294] -> 
             RGBColor[
              0.2083047996307834, 0.33627193007203204`, 0.9351740222284133], 
             UndirectedEdge[39, 136] -> 
             RGBColor[
              0.9093243643754532, 0.6566653871649271, 0.29725952697501445`], 
             UndirectedEdge[133, 162] -> 
             RGBColor[
              0.31733689752319516`, 0.44704376794557543`, 0.9415233937816148],
              UndirectedEdge[22, 271] -> 
             RGBColor[
              0.8974219616748091, 0.8964540242042457, 0.6746941771749546], 
             UndirectedEdge[107, 110] -> 
             RGBColor[
              0.8870800066449858, 0.5061000302265065, 0.3757440054051945], 
             UndirectedEdge[40, 191] -> 
             RGBColor[
              0.24055073236956107`, 0.37016444989070835`, 0.9370103803943042],
              UndirectedEdge[143, 237] -> 
             RGBColor[
              0.5177646791690618, 0.6178477648970354, 0.9556038669239417], 
             UndirectedEdge[157, 261] -> 
             RGBColor[
              0.3733109108199431, 0.49776488062546065`, 0.9450080190249379], 
             UndirectedEdge[35, 163] -> 
             RGBColor[
              0.23379526623113445`, 0.36306402665793014`, 0.9366256665915373],
              UndirectedEdge[89, 175] -> 
             RGBColor[
              0.28632181999450856`, 0.4182727650390983, 0.9396169761222888], 
             UndirectedEdge[16, 200] -> 
             RGBColor[
              0.939733161025506, 0.7818290973952341, 0.3786259847113931], 
             UndirectedEdge[35, 189] -> 
             RGBColor[
              0.2290398133604396, 0.3580657441777033, 0.9363548505856133], 
             UndirectedEdge[233, 291] -> 
             RGBColor[
              0.8766348422710215, 0.4223576865529295, 0.30917062318117206`], 
             UndirectedEdge[258, 290] -> 
             RGBColor[
              0.7873478763723856, 0.8338243344390612, 0.9561368785302078], 
             UndirectedEdge[157, 259] -> 
             RGBColor[
              0.40512064339431064`, 0.5250197481568593, 0.947117003308583], 
             UndirectedEdge[105, 245] -> 
             RGBColor[
              0.35678647711021616`, 0.4816423424493619, 0.944021366181159], 
             UndirectedEdge[100, 192] -> 
             RGBColor[
              0.8551155999405852, 0.4177475301902278, 0.2001418527008563], 
             UndirectedEdge[258, 278] -> 
             RGBColor[
              0.7823492729369855, 0.8297662429856849, 0.9557433701572854], 
             UndirectedEdge[99, 201] -> 
             RGBColor[
              0.34430071595550393`, 0.4726377079286733, 0.9431595150608838], 
             UndirectedEdge[9, 282] -> 
             RGBColor[
              0.740243347265956, 0.7955203413934655, 0.9507546007091144], 
             UndirectedEdge[84, 175] -> 
             RGBColor[
              0.29756458350130965`, 0.4300896223171238, 0.940257234871823], 
             UndirectedEdge[271, 291] -> 
             RGBColor[
              0.8710936578057457, 0.40431831637281135`, 0.23217335977663117`],
              UndirectedEdge[127, 256] -> 
             RGBColor[
              0.8869307215281732, 0.49935224649414445`, 0.36072713549885926`],
              UndirectedEdge[80, 116] -> 
             RGBColor[
              0.2951188116057152, 0.426255830409919, 0.9401642011784779], 
             UndirectedEdge[202, 268] -> 
             RGBColor[
              0.2453187041670522, 0.37517589055674394`, 0.937281909334589], 
             UndirectedEdge[161, 265] -> 
             RGBColor[
              0.21936843133233605`, 0.34790050846512904`, 0.9358040796866404],
              UndirectedEdge[22, 72] -> 
             RGBColor[
              0.7345932590636062, 0.7925891041868212, 0.9741810489653038], 
             UndirectedEdge[77, 162] -> 
             RGBColor[
              0.26527957680517633`, 0.3961560332918348, 0.9384186515018654], 
             UndirectedEdge[93, 164] -> 
             RGBColor[
              0.45756686024315646`, 0.5686282136761757, 0.9509610966011381], 
             UndirectedEdge[19, 111] -> 
             RGBColor[
              0.2671407671011217, 0.39811226229915386`, 0.9385246435358352], 
             UndirectedEdge[37, 142] -> 
             RGBColor[
              0.669863260251737, 0.742021537148777, 0.9677293676199676], 
             UndirectedEdge[43, 172] -> 
             RGBColor[
              0.2958345713391305, 0.4270297833847875, 0.9402041701394114], 
             UndirectedEdge[61, 285] -> 
             RGBColor[
              0.474805368949063, 0.5825919070766665, 0.9523268246944521], 
             UndirectedEdge[38, 257] -> 
             RGBColor[
              0.4046248085689348, 0.5248874049733736, 0.9470033128997111], 
             UndirectedEdge[174, 185] -> 
             RGBColor[
              0.4801968939468863, 0.58722835298474, 0.9526796025142897], 
             UndirectedEdge[75, 237] -> 
             RGBColor[
              0.6846458552140906, 0.7535149764166593, 0.969240250390935], 
             UndirectedEdge[30, 48] -> 
             RGBColor[
              0.43794065467516774`, 0.5535027925607373, 0.9491927923797858], 
             UndirectedEdge[289, 298] -> 
             RGBColor[
              0.28811767425307283`, 0.4201603217285858, 0.9397192473655857], 
             UndirectedEdge[123, 261] -> 
             RGBColor[
              0.41843101459212195`, 0.5368456467105671, 0.9478830321391599], 
             UndirectedEdge[77, 206] -> 
             RGBColor[
              0.2413530899135048, 0.3710077785417997, 0.9370560734694501], 
             UndirectedEdge[121, 137] -> 
             RGBColor[
              0.8952475121146669, 0.5644582460490475, 0.34575282835437127`], 
             UndirectedEdge[87, 227] -> 
             RGBColor[
              0.2679362427515092, 0.39894835764378045`, 0.938569944697324], 
             UndirectedEdge[123, 144] -> 
             RGBColor[
              0.3759650676291757, 0.5000637778518178, 0.9451771395498434], 
             UndirectedEdge[9, 37] -> 
             RGBColor[
              0.5987662128442524, 0.684557033887325, 0.9619578094283205], 
             UndirectedEdge[178, 268] -> 
             RGBColor[
              0.26978635473276824`, 0.4008929426399584, 0.9386753058376613], 
             UndirectedEdge[112, 253] -> 
             RGBColor[
              0.2744693999473012, 0.40581512008264853`, 0.9389419983346845], 
             UndirectedEdge[78, 220] -> 
             RGBColor[
              0.21861602963741927`, 0.34710968657874874`, 0.9357612315231933],
              UndirectedEdge[66, 67] -> 
             RGBColor[
              0.9293871027463778, 0.9462546742934231, 0.9835096743331035], 
             UndirectedEdge[20, 124] -> 
             RGBColor[
              0.9067998303302157, 0.928212273566045, 0.9802484959896351], 
             UndirectedEdge[18, 224] -> 
             RGBColor[
              0.9579627169351427, 0.9342040847269458, 0.6558617372883351], 
             UndirectedEdge[72, 151] -> 
             RGBColor[
              0.5475405416357872, 0.6431396338261914, 0.9576978591404627], 
             UndirectedEdge[25, 29] -> 
             RGBColor[
              0.24731665325336327`, 0.3772758617237455, 0.9373956895793536], 
             UndirectedEdge[135, 258] -> 
             RGBColor[
              0.9759313858945792, 0.9805894223220096, 0.8817027084030489], 
             UndirectedEdge[130, 176] -> 
             RGBColor[
              0.17893943915932659`, 0.3054070743451405, 0.9335017083917216], 
             UndirectedEdge[31, 245] -> 
             RGBColor[
              0.5216196733437626, 0.6217282550704486, 0.9556998890025264], 
             UndirectedEdge[295, 297] -> 
             RGBColor[
              0.7988419039700752, 0.8429204696534232, 0.9805476453412715], 
             UndirectedEdge[17, 30] -> 
             RGBColor[
              0.37921039896007874`, 0.5014757039177918, 0.9454929485539587], 
             UndirectedEdge[22, 273] -> 
             RGBColor[
              0.717607033402136, 0.7789436605631201, 0.9727448718111256], 
             UndirectedEdge[86, 165] -> 
             RGBColor[
              0.9775639799613888, 0.9359801775610526, 0.3673407281472113], 
             UndirectedEdge[124, 200] -> 
             RGBColor[
              0.916844882326316, 0.7678634053812667, 0.6000047488264095], 
             UndirectedEdge[198, 258] -> 
             RGBColor[
              0.7130111957358749, 0.7734744682690422, 0.9502848227262681], 
             UndirectedEdge[177, 217] -> 
             RGBColor[
              0.6131216671850642, 0.6933500026997739, 0.964666976055813], 
             UndirectedEdge[52, 110] -> 
             RGBColor[
              0.876120671367751, 0.4218617768743392, 0.3652493335669156], 
             UndirectedEdge[121, 299] -> 
             RGBColor[
              0.9945473356554072, 0.9914335784226265, 0.6978961075730188], 
             UndirectedEdge[173, 196] -> 
             RGBColor[
              0.2690530219671379, 0.40012216340729806`, 0.9386335436215274], 
             UndirectedEdge[238, 251] -> 
             RGBColor[
              0.2826141781107905, 0.4143757983412377, 0.9394058314019756], 
             UndirectedEdge[218, 284] -> 
             RGBColor[
              0.25584347148447395`, 0.38623808831614403`, 0.9378812792633183],
              UndirectedEdge[209, 276] -> 
             RGBColor[
              0.24846893317691396`, 0.37848698098216405`, 0.9374613102163545],
              UndirectedEdge[8, 72] -> 
             RGBColor[
              0.6518284135700501, 0.7279325778511317, 0.9659318226479615], 
             UndirectedEdge[56, 168] -> 
             RGBColor[
              0.46678271330407606`, 0.5761629717082618, 0.9516719821972282], 
             UndirectedEdge[201, 257] -> 
             RGBColor[
              0.35620917982441114`, 0.48295222079512334`, 0.9439183118483695],
              UndirectedEdge[31, 51] -> 
             RGBColor[
              0.8061994237416004, 0.8465221719044482, 0.8597460281820752], 
             UndirectedEdge[53, 282] -> 
             RGBColor[
              0.8757050929352991, 0.4873983488879218, 0.43414587491943724`], 
             UndirectedEdge[17, 97] -> 
             RGBColor[
              0.27685141165294697`, 0.4083187654135474, 0.9390776503774505], 
             UndirectedEdge[102, 162] -> 
             RGBColor[
              0.3349247683998675, 0.4622774977068556, 0.9426440773615328], 
             UndirectedEdge[36, 260] -> 
             RGBColor[
              0.8043625245684116, 0.8473291531354724, 0.9810724316171817], 
             UndirectedEdge[79, 168] -> 
             RGBColor[
              0.3904018999447999, 0.5125682363873212, 0.9460970417390054], 
             UndirectedEdge[142, 297] -> 
             RGBColor[
              0.7097113891411961, 0.773151198294219, 0.9717010567057325], 
             UndirectedEdge[232, 299] -> 
             RGBColor[
              0.994290544063115, 0.9908843271723261, 0.6699459274860231], 
             UndirectedEdge[50, 169] -> 
             RGBColor[
              0.3227370521664461, 0.4525068374668645, 0.9418387175462686], 
             UndirectedEdge[92, 153] -> 
             RGBColor[
              0.26728945052082176`, 0.3982685380003319, 0.9385331108366297], 
             UndirectedEdge[44, 299] -> 
             RGBColor[
              0.979769906119425, 0.942886287709507, 0.5299077867568601], 
             UndirectedEdge[90, 252] -> 
             RGBColor[
              0.35203888438478537`, 0.4785806153224426, 0.9436803935153333], 
             UndirectedEdge[7, 283] -> 
             RGBColor[
              0.5067349402558111, 0.6088389317771312, 0.9547505947490993], 
             UndirectedEdge[52, 179] -> 
             RGBColor[
              0.8763542039313392, 0.42195834859089604`, 0.36137909462535833`],
              UndirectedEdge[98, 296] -> 
             RGBColor[
              0.559521387516622, 0.6516299340358314, 0.9592598962290395], 
             UndirectedEdge[18, 88] -> 
             RGBColor[
              0.7253109400374347, 0.7839674018676228, 0.9648635309809819], 
             UndirectedEdge[100, 240] -> 
             RGBColor[
              0.8984314070002761, 0.5883329671106973, 0.36043313849805947`], 
             UndirectedEdge[2, 214] -> 
             RGBColor[
              0.2218197182328839, 0.35047696641817105`, 0.9359436768492726], 
             UndirectedEdge[114, 169] -> 
             RGBColor[
              0.2987181224804576, 0.4313020649228039, 0.9403229272101774], 
             UndirectedEdge[37, 295] -> 
             RGBColor[
              0.7589937750806162, 0.8117908085079812, 0.9765759562555065], 
             UndirectedEdge[45, 225] -> 
             RGBColor[
              0.8922034790216946, 0.5903032781532196, 0.23628645255656144`], 
             UndirectedEdge[38, 74] -> 
             RGBColor[
              0.5280791848415985, 0.6267970188090106, 0.9562568575389798], 
             UndirectedEdge[38, 158] -> 
             RGBColor[
              0.41078817614673724`, 0.5302258041894045, 0.9473960372317167], 
             UndirectedEdge[69, 135] -> 
             RGBColor[
              0.9915668730357023, 0.9888448386688236, 0.6487056199187353], 
             UndirectedEdge[113, 224] -> 
             RGBColor[
              0.9644670009376046, 0.9390549690861945, 0.644851681061125], 
             UndirectedEdge[124, 282] -> 
             RGBColor[
              0.9556754222393467, 0.9664633829977154, 0.9599141278341408], 
             UndirectedEdge[56, 79] -> 
             RGBColor[
              0.47131158576889715`, 0.5800856534095411, 0.9519605579459619], 
             UndirectedEdge[49, 146] -> 
             RGBColor[
              0.23350254559126715`, 0.3627563587058691, 0.9366089965841382], 
             UndirectedEdge[47, 166] -> 
             RGBColor[
              0.8183915236203407, 0.8543538869413033, 0.7072534135870767], 
             UndirectedEdge[189, 197] -> 
             RGBColor[
              0.22117434471858483`, 0.3497986379355985, 0.9359069237823778], 
             UndirectedEdge[125, 256] -> 
             RGBColor[
              0.9939365705713255, 0.9894392624958468, 0.5814113097167279], 
             UndirectedEdge[69, 138] -> 
             RGBColor[
              0.8498609562052564, 0.8791517168657417, 0.7275038724573385], 
             UndirectedEdge[170, 255] -> 
             RGBColor[
              0.8675804054698418, 0.4039272598487107, 0.21074758526394385`], 
             UndirectedEdge[41, 104] -> 
             RGBColor[
              0.3210313076505878, 0.45029407852530423`, 0.9417569530026035], 
             UndirectedEdge[185, 283] -> 
             RGBColor[
              0.5933967145885973, 0.6807852109772019, 0.9611335095376532], 
             UndirectedEdge[103, 277] -> 
             RGBColor[
              0.3139559658390563, 0.44358745874044936`, 0.9413272933992227], 
             UndirectedEdge[45, 282] -> 
             RGBColor[
              0.8931015408528009, 0.6211150707539262, 0.45080473309171465`], 
             UndirectedEdge[222, 245] -> 
             RGBColor[
              0.43026765068117134`, 0.5470979459642735, 0.9486372521240278], 
             UndirectedEdge[53, 195] -> 
             RGBColor[
              0.8275339988457331, 0.2126439573693409, 0.17399989443086508`], 
             UndirectedEdge[121, 136] -> 
             RGBColor[
              0.9937588965574554, 0.9890592357457773, 0.5620725897838914], 
             UndirectedEdge[92, 211] -> 
             RGBColor[
              0.2517282610763278, 0.3819127412577725, 0.9376469241184826], 
             UndirectedEdge[26, 137] -> 
             RGBColor[
              0.8923224675531893, 0.5636350776132415, 0.42231650775556523`], 
             UndirectedEdge[139, 148] -> 
             RGBColor[
              0.24714609636833407`, 0.37709659562364867`, 0.9373859766170676],
              UndirectedEdge[69, 258] -> 
             RGBColor[
              0.9774025219667993, 0.9792619140373138, 0.7166055281881865], 
             UndirectedEdge[244, 272] -> 
             RGBColor[
              0.23289575947638014`, 0.3621185880266611, 0.936574441012555], 
             UndirectedEdge[100, 256] -> 
             RGBColor[
              0.8985362124666462, 0.5885571354058046, 0.3718405667280683], 
             UndirectedEdge[29, 206] -> 
             RGBColor[
              0.23974836289368467`, 0.3693211086983992, 0.9369646866396522], 
             UndirectedEdge[101, 213] -> 
             RGBColor[
              0.48723449014775655`, 0.5939071986311, 0.9529668827570787], 
             UndirectedEdge[39, 107] -> 
             RGBColor[
              0.8564041483183775, 0.41541072064133033`, 0.20089643507288318`],
              UndirectedEdge[134, 252] -> 
             RGBColor[
              0.28726603661361816`, 0.4192651965725739, 0.9396707478619037], 
             UndirectedEdge[14, 288] -> 
             RGBColor[
              0.8357655046599107, 0.272249042199298, 0.18173884718697714`], 
             UndirectedEdge[155, 202] -> 
             RGBColor[
              0.22021191752572378`, 0.34878706593449305`, 0.9358521149775277],
              UndirectedEdge[220, 228] -> 
             RGBColor[
              0.5367674910110247, 0.6220540079829862, 0.9601435922342896], 
             UndirectedEdge[228, 266] -> 
             RGBColor[
              0.5319885984693589, 0.6170310889224077, 0.9598714413737797], 
             UndirectedEdge[113, 249] -> 
             RGBColor[
              0.8655230747652505, 0.41896226614950405`, 0.42814822498187033`],
              UndirectedEdge[109, 179] -> 
             RGBColor[
              0.9574076164080104, 0.9658098047595847, 0.8736496587222751], 
             UndirectedEdge[41, 209] -> 
             RGBColor[
              0.3110735460011261, 0.43982783967316585`, 0.9411898732078549], 
             UndirectedEdge[76, 261] -> 
             RGBColor[
              0.3474685023612617, 0.4740454489620557, 0.9434102824444082], 
             UndirectedEdge[114, 219] -> 
             RGBColor[
              0.28932309287771063`, 0.4214272931310352, 0.9397878941730018], 
             UndirectedEdge[130, 266] -> 
             RGBColor[
              0.21328047700996416`, 0.3415016824737179, 0.9354573796943026], 
             UndirectedEdge[1, 185] -> 
             RGBColor[
              0.4932964811819127, 0.5985745570433215, 0.9535142966293955], 
             UndirectedEdge[202, 208] -> 
             RGBColor[
              0.2570404037299817, 0.3874961399960602, 0.9379494427839974], 
             UndirectedEdge[8, 285] -> 
             RGBColor[
              0.5173103167774687, 0.616953959461616, 0.9557723663648683], 
             UndirectedEdge[65, 210] -> 
             RGBColor[
              0.33323684341077736`, 0.46112891713616844`, 0.9425250486073942],
              UndirectedEdge[63, 183] -> 
             RGBColor[
              0.28955139027076127`, 0.4202094545444958, 0.939854272337463], 
             UndirectedEdge[51, 86] -> 
             RGBColor[
              0.9842148587859489, 0.9592452118717956, 0.5566107984418112], 
             UndirectedEdge[91, 191] -> 
             RGBColor[
              0.2582507185162887, 0.38876825757485856`, 0.9380183684205773], 
             UndirectedEdge[122, 181] -> 
             RGBColor[
              0.6690049122710009, 0.741072705352345, 0.9678340796895172], 
             UndirectedEdge[17, 42] -> 
             RGBColor[
              0.2753301177357401, 0.4067197890509576, 0.9389910149394182], 
             UndirectedEdge[90, 253] -> 
             RGBColor[
              0.3501359199582715, 0.4765804790552632, 0.9435720225064269], 
             UndirectedEdge[60, 136] -> 
             RGBColor[
              0.9594950595498875, 0.8659435606987382, 0.3644021078697419], 
             UndirectedEdge[80, 210] -> 
             RGBColor[
              0.3231934350804644, 0.45057265819214215`, 0.941953091360874], 
             UndirectedEdge[229, 259] -> 
             RGBColor[
              0.40532480006275245`, 0.5251965784018511, 0.9471300119909675], 
             UndirectedEdge[97, 159] -> 
             RGBColor[
              0.2524370830607903, 0.3826577581053522, 0.9376872904818896], 
             UndirectedEdge[242, 280] -> 
             RGBColor[
              0.25424538211649345`, 0.38455839506567835`, 0.9377902704379731],
              UndirectedEdge[88, 99] -> 
             RGBColor[
              0.43585477652737337`, 0.5505550934269655, 0.9493751482779511], 
             UndirectedEdge[21, 46] -> 
             RGBColor[
              0.3377964064979223, 0.4654684905987692, 0.942801288807799], 
             UndirectedEdge[246, 256] -> 
             RGBColor[
              0.7970579460912328, 0.838735601938289, 0.8428569136112316], 
             UndirectedEdge[14, 135] -> 
             RGBColor[
              0.8784970455730444, 0.4470374784660281, 0.38418003276278484`], 
             UndirectedEdge[67, 179] -> 
             RGBColor[
              0.9529824528221467, 0.9622812994340826, 0.8732275826690652], 
             UndirectedEdge[66, 69] -> 
             RGBColor[
              0.9697469416824389, 0.9735523947961, 0.7295644287144893], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.7503642165832218, 0.805193848255281, 0.9757004322912739], 
             UndirectedEdge[116, 133] -> 
             RGBColor[
              0.3362774461822365, 0.4656883549123332, 0.9426482794056301], 
             UndirectedEdge[2, 83] -> 
             RGBColor[
              0.2235228930753953, 0.35226711116517256`, 0.9360406701369322], 
             UndirectedEdge[103, 168] -> 
             RGBColor[
              0.3323449528082868, 0.45951507499583777`, 0.9424990233881594], 
             UndirectedEdge[26, 199] -> 
             RGBColor[
              0.5823809948253185, 0.6469022092217233, 0.9089577047840149], 
             UndirectedEdge[91, 239] -> 
             RGBColor[
              0.3418733579527955, 0.46719445818593675`, 0.9431271687979139], 
             UndirectedEdge[13, 298] -> 
             RGBColor[
              0.2956902341413986, 0.428119562299244, 0.9401504934486273], 
             UndirectedEdge[229, 261] -> 
             RGBColor[
              0.3735150674883849, 0.49794171087045247`, 0.9450210277073223], 
             UndirectedEdge[141, 179] -> 
             RGBColor[
              0.9463245104461602, 0.8129581160989631, 0.4961968694388046], 
             UndirectedEdge[59, 195] -> 
             RGBColor[
              0.828254689512269, 0.21818350164099967`, 0.17469002862704355`], 
             UndirectedEdge[134, 253] -> 
             RGBColor[
              0.2853630721871043, 0.41726506030539445`, 0.9395623768529974], 
             UndirectedEdge[42, 292] -> 
             RGBColor[
              0.24874967528223313`, 0.3787820587349321, 0.9374772980639317], 
             UndirectedEdge[70, 238] -> 
             RGBColor[
              0.27137415800540265`, 0.40256182455203926`, 0.9387657288850935],
              UndirectedEdge[178, 202] -> 
             RGBColor[
              0.25258870101180897`, 0.3828171181850061, 0.9376959248999015], 
             UndirectedEdge[29, 191] -> 
             RGBColor[
              0.24335597488348387`, 0.37311293763548947`, 0.9371701348054876],
              UndirectedEdge[17, 38] -> 
             RGBColor[
              0.3570833446280458, 0.48255148540021425`, 0.944016408991876], 
             UndirectedEdge[40, 162] -> 
             RGBColor[
              0.2608696072714334, 0.3915208757036531, 0.9381675102608841], 
             UndirectedEdge[13, 95] -> 
             RGBColor[
              0.3973874477451902, 0.5174174988379855, 0.946816060198244], 
             UndirectedEdge[206, 270] -> 
             RGBColor[
              0.23246458235718154`, 0.361665393536175, 0.936549886113486], 
             UndirectedEdge[16, 295] -> 
             RGBColor[
              0.9153775706767935, 0.9307671307468549, 0.7575047799513781], 
             UndirectedEdge[37, 124] -> 
             RGBColor[
              0.8141982878176429, 0.8555000754915749, 0.971117336553347], 
             UndirectedEdge[22, 177] -> 
             RGBColor[
              0.6182933062719121, 0.6973901264603323, 0.9651824367082749], 
             UndirectedEdge[115, 204] -> 
             RGBColor[
              0.22623702836427392`, 0.35511983943990055`, 0.9361952361264305],
              UndirectedEdge[192, 200] -> 
             RGBColor[
              0.8719894116910114, 0.5116156407689246, 0.21489716609938064`], 
             UndirectedEdge[13, 171] -> 
             RGBColor[
              0.3622408475068787, 0.48793453204456394`, 0.9443115057758112], 
             UndirectedEdge[39, 52] -> 
             RGBColor[
              0.8509244806797601, 0.37329159396524664`, 0.19564909915374373`],
              UndirectedEdge[92, 216] -> 
             RGBColor[
              0.25996759819388404`, 0.3905728069724701, 0.9381161421783205], 
             UndirectedEdge[82, 127] -> 
             RGBColor[
              0.8868736217040262, 0.4992301157439715, 0.35451217201971436`], 
             UndirectedEdge[53, 150] -> 
             RGBColor[
              0.875154847057984, 0.48698797641356506`, 0.4350772976626226], 
             UndirectedEdge[18, 66] -> 
             RGBColor[
              0.9464282973427488, 0.95956689239061, 0.9755670982476465], 
             UndirectedEdge[31, 36] -> 
             RGBColor[
              0.6892039970441424, 0.7567703364683878, 0.9699034319627848], 
             UndirectedEdge[71, 181] -> 
             RGBColor[
              0.6717068148993812, 0.7432662316253906, 0.9680467833618187], 
             UndirectedEdge[43, 143] -> 
             RGBColor[
              0.3594618944461463, 0.48576955871427996`, 0.9441255719478039], 
             UndirectedEdge[75, 185] -> 
             RGBColor[
              0.6492913495741017, 0.7248125960357876, 0.9664570141991338], 
             UndirectedEdge[46, 145] -> 
             RGBColor[
              0.280670988716232, 0.4123333830822331, 0.9392951696406466], 
             UndirectedEdge[62, 255] -> 
             RGBColor[
              0.9769015351320889, 0.9322978840038133, 0.4878701995815442], 
             UndirectedEdge[111, 242] -> 
             RGBColor[
              0.24172339249525976`, 0.3713969900337639, 0.9370771616536675], 
             UndirectedEdge[4, 193] -> 
             RGBColor[
              0.46955924674976174`, 0.5787870298978665, 0.9517883446566966], 
             UndirectedEdge[18, 258] -> 
             RGBColor[
              0.9540838776271092, 0.9652764116318238, 0.9626081977213435], 
             UndirectedEdge[81, 267] -> 
             RGBColor[
              0.3818442604921369, 0.5035684061042389, 0.9457044452357559], 
             UndirectedEdge[75, 124] -> 
             RGBColor[
              0.8391031020269322, 0.8749559056354701, 0.9735996156850079], 
             UndirectedEdge[72, 106] -> 
             RGBColor[
              0.6542381545327312, 0.7298150858058879, 0.966172003106812], 
             UndirectedEdge[262, 271] -> 
             RGBColor[
              0.9857223415414609, 0.9625888518240449, 0.4765328762826566], 
             UndirectedEdge[17, 235] -> 
             RGBColor[
              0.2691307812557516, 0.40020389334985473`, 0.9386379718979794], 
             UndirectedEdge[263, 279] -> 
             RGBColor[
              0.25988809011317837`, 0.3904892389385449, 0.938111614310746], 
             UndirectedEdge[3, 252] -> 
             RGBColor[
              0.33892810141516894`, 0.46722471408127325`, 0.9428449860179196],
              UndirectedEdge[48, 158] -> 
             RGBColor[
              0.4086574804982366, 0.5283803027105503, 0.9472602711890945], 
             UndirectedEdge[18, 36] -> 
             RGBColor[
              0.8529859949186596, 0.8858242206407632, 0.9761422011869598], 
             UndirectedEdge[105, 196] -> 
             RGBColor[
              0.28505137622914434`, 0.4169374480909134, 0.9395446262293043], 
             UndirectedEdge[269, 298] -> 
             RGBColor[
              0.2561386884802381, 0.3865483800965307, 0.9378980914344927], 
             UndirectedEdge[85, 207] -> 
             RGBColor[
              0.8326069689699811, 0.8699635257728993, 0.9837364200787462], 
             UndirectedEdge[79, 103] -> 
             RGBColor[
              0.33687382527310783`, 0.4634377566971172, 0.9427875991368931], 
             UndirectedEdge[76, 128] -> 
             RGBColor[
              0.2667781164198233, 0.397731093439728, 0.9385039911160289], 
             UndirectedEdge[10, 265] -> 
             RGBColor[
              0.21694931138635237`, 0.3453578600208368, 0.9356663143844839], 
             UndirectedEdge[88, 198] -> 
             RGBColor[
              0.48423825814620036`, 0.592165458504841, 0.9525401559859066], 
             UndirectedEdge[63, 143] -> 
             RGBColor[
              0.36063166824627285`, 0.4867827579854089, 0.9442001088999576], 
             UndirectedEdge[49, 242] -> 
             RGBColor[
              0.23849346114208345`, 0.3680021273920998, 0.9368932218413593], 
             UndirectedEdge[252, 253] -> 
             RGBColor[
              0.29862833529686444`, 0.43120769290001126`, 0.9403178139629], 
             UndirectedEdge[16, 125] -> 
             RGBColor[
              0.9930477640549809, 0.9875381952295093, 0.4846702054906215], 
             UndirectedEdge[59, 100] -> 
             RGBColor[
              0.8386002140561873, 0.2977037367233178, 0.18459691461389852`], 
             UndirectedEdge[75, 295] -> 
             RGBColor[
              0.7838985892899054, 0.8312466386518764, 0.9790582353871675], 
             UndirectedEdge[94, 295] -> 
             RGBColor[
              0.8496169506590368, 0.8829255104904983, 0.9855184172875062], 
             UndirectedEdge[26, 192] -> 
             RGBColor[
              0.9052690882618898, 0.649347078568056, 0.4341737781925292], 
             UndirectedEdge[132, 188] -> 
             RGBColor[
              0.20621351468350757`, 0.3340738569973212, 0.9350549266444448], 
             UndirectedEdge[186, 196] -> 
             RGBColor[
              0.255450766680841, 0.38582533066860314`, 0.9378589153057062], 
             UndirectedEdge[110, 179] -> 
             RGBColor[
              0.9932962755631108, 0.991495851914556, 0.7607615928093651], 
             UndirectedEdge[61, 177] -> 
             RGBColor[
              0.49302351294995017`, 0.5983715477396933, 0.9534876687205165], 
             UndirectedEdge[21, 264] -> 
             RGBColor[
              0.339057995027486, 0.46679450013267343`, 0.9428731344082046], 
             UndirectedEdge[200, 225] -> 
             RGBColor[
              0.9234794071043728, 0.7275983937614409, 0.2647165314935854], 
             UndirectedEdge[83, 197] -> 
             RGBColor[
              0.21339436331142053`, 0.34162138419735716`, 0.9354638653506908],
              UndirectedEdge[220, 226] -> 
             RGBColor[
              0.21805937466237113`, 0.3465246069060093, 0.9357295308458616], 
             UndirectedEdge[13, 140] -> 
             RGBColor[
              0.3171012005840623, 0.44883683866464263`, 0.941435247389312], 
             UndirectedEdge[144, 158] -> 
             RGBColor[
              0.35967077338482056`, 0.4859504791523989, 0.9441388815290719], 
             UndirectedEdge[62, 225] -> 
             RGBColor[
              0.9779057939111673, 0.9356854846768198, 0.49177155529990685`], 
             UndirectedEdge[65, 277] -> 
             RGBColor[
              0.318505826054183, 0.44836965030434695`, 0.9415864012075592], 
             UndirectedEdge[99, 261] -> 
             RGBColor[
              0.38406488890105717`, 0.5070794359286672, 0.9456932529988971], 
             UndirectedEdge[260, 290] -> 
             RGBColor[
              0.7310412488235707, 0.7895991808750945, 0.9740726900092733], 
             UndirectedEdge[72, 267] -> 
             RGBColor[
              0.5598273932891142, 0.6533873840765647, 0.9585897688439947], 
             UndirectedEdge[39, 170] -> 
             RGBColor[
              0.8523196210649958, 0.3840152543205831, 0.1969850871622311], 
             UndirectedEdge[92, 163] -> 
             RGBColor[
              0.25122830224652154`, 0.3813872528284255, 0.937618452202748], 
             UndirectedEdge[102, 133] -> 
             RGBColor[
              0.36773492193593726`, 0.4929352393114849, 0.9446527219439024], 
             UndirectedEdge[184, 197] -> 
             RGBColor[
              0.22396867403815082`, 0.3527356552211741, 0.9360660567032872], 
             UndirectedEdge[44, 200] -> 
             RGBColor[
              0.9255256121005535, 0.7345007236853389, 0.2726656515103572], 
             UndirectedEdge[115, 132] -> 
             RGBColor[
              0.21415169536183348`, 0.34241738819996653`, 0.9355069942905895],
              UndirectedEdge[9, 283] -> 
             RGBColor[
              0.5677763920680372, 0.6599854789726345, 0.959116583898501], 
             UndirectedEdge[52, 165] -> 
             RGBColor[
              0.8718921341800324, 0.4064366847474367, 0.2356655749773864], 
             UndirectedEdge[160, 256] -> 
             RGBColor[
              0.7927339846129686, 0.8352252152179895, 0.8425165155244698], 
             UndirectedEdge[45, 215] -> 
             RGBColor[
              0.9035836038900057, 0.6277240751762379, 0.3789421893819883], 
             UndirectedEdge[16, 124] -> 
             RGBColor[
              0.9705820834138202, 0.9744763977304486, 0.7520461602492186], 
             UndirectedEdge[160, 246] -> 
             RGBColor[
              0.5945439555585024, 0.6817165928791875, 0.9612238245492863], 
             UndirectedEdge[57, 204] -> 
             RGBColor[
              0.23896784394150833`, 0.36850073379190207`, 0.9369202372400001],
              UndirectedEdge[112, 252] -> 
             RGBColor[
              0.27637236437381507`, 0.40781525634982796`, 0.9390503693435908],
              UndirectedEdge[5, 248] -> 
             RGBColor[
              0.21465495916745328`, 0.3429463503684412, 0.9355356544198075], 
             UndirectedEdge[186, 276] -> 
             RGBColor[
              0.2308753294209801, 0.3599949879357713, 0.9364593805098584], 
             UndirectedEdge[95, 154] -> 
             RGBColor[
              0.6149232954890904, 0.696747339779964, 0.9638633724984019], 
             UndirectedEdge[198, 290] -> 
             RGBColor[
              0.5385920372825843, 0.6362923050176035, 0.9568190845839761], 
             UndirectedEdge[77, 191] -> 
             RGBColor[
              0.24496070190330402`, 0.37479960747889, 0.9372615216352855], 
             UndirectedEdge[36, 224] -> 
             RGBColor[
              0.8645479914252601, 0.8604819797945611, 0.6563901597051076], 
             UndirectedEdge[29, 203] -> 
             RGBColor[
              0.25120844967144335`, 0.38136638651329235`, 0.9376173216279664],
              UndirectedEdge[25, 172] -> 
             RGBColor[
              0.2606528759791422, 0.3912930773738975, 0.9381551677344133], 
             UndirectedEdge[224, 260] -> 
             RGBColor[
              0.9093392465848947, 0.8957090172216551, 0.6607919677185569], 
             UndirectedEdge[45, 255] -> 
             RGBColor[
              0.8915339731689755, 0.5880448777045486, 0.23368554874431965`], 
             UndirectedEdge[102, 239] -> 
             RGBColor[
              0.398228532934502, 0.519347272504989, 0.9465957478722895], 
             UndirectedEdge[33, 239] -> 
             RGBColor[
              0.6628984653958889, 0.7326583838158534, 0.9695703125580974], 
             UndirectedEdge[64, 92] -> 
             RGBColor[
              0.24737632360791623`, 0.3773385790496996, 0.9373990877177711], 
             UndirectedEdge[32, 268] -> 
             RGBColor[
              0.2593869141835333, 0.38996247126009875`, 0.938083073082976], 
             UndirectedEdge[85, 240] -> 
             RGBColor[
              0.9572796113633043, 0.9651601387742601, 0.8410616153789832], 
             UndirectedEdge[1, 174] -> 
             RGBColor[
              0.4054230753198295, 0.5255788235109453, 0.9470541777511985], 
             UndirectedEdge[2, 184] -> 
             RGBColor[
              0.23409720380212556`, 0.3633813821889895, 0.9366428614895286], 
             UndirectedEdge[60, 85] -> 
             RGBColor[
              0.9228540566499766, 0.8416985659067688, 0.6257891591988634], 
             UndirectedEdge[121, 127] -> 
             RGBColor[
              0.8867181042579634, 0.498897479652069, 0.3375850577582036], 
             UndirectedEdge[132, 212] -> 
             RGBColor[
              0.20921642322248857`, 0.3372301042671883, 0.9352259378433346], 
             UndirectedEdge[172, 206] -> 
             RGBColor[
              0.2530845856194636, 0.3833383243485512, 0.9377241647947119], 
             UndirectedEdge[147, 148] -> 
             RGBColor[
              0.2325030525609364, 0.36170582815947316`, 0.9365520769346783], 
             UndirectedEdge[118, 226] -> 
             RGBColor[
              0.17892828959271728`, 0.30539535544371077`, 0.9335010734403975],
              UndirectedEdge[75, 283] -> 
             RGBColor[
              0.6746177643537297, 0.7453737204958732, 0.9684508023443001], 
             UndirectedEdge[188, 243] -> 
             RGBColor[
              0.21194079974675017`, 0.3400935967296356, 0.9353810870560375], 
             UndirectedEdge[88, 258] -> 
             RGBColor[
              0.7329940972360016, 0.7896974879262988, 0.9518579499321382], 
             UndirectedEdge[197, 293] -> 
             RGBColor[
              0.20988077542261582`, 0.33792838055188446`, 0.9352637717183109],
              UndirectedEdge[86, 179] -> 
             RGBColor[
              0.9842570845883489, 0.9592626733262417, 0.5559110076191691], 
             UndirectedEdge[41, 76] -> 
             RGBColor[
              0.32564319585170254`, 0.45514146543527656`, 0.9420195932129798],
              UndirectedEdge[175, 242] -> 
             RGBColor[
              0.2674717938620085, 0.3984601924131547, 0.9385434950201575], 
             UndirectedEdge[89, 285] -> 
             RGBColor[
              0.3304519019187142, 0.457812130049975, 0.9423807168287202], 
             UndirectedEdge[138, 171] -> 
             RGBColor[
              0.5625186052786886, 0.6537822219340037, 0.9596386929535714], 
             UndirectedEdge[181, 207] -> 
             RGBColor[
              0.729702675862836, 0.7887685434205706, 0.9736936013369495], 
             UndirectedEdge[17, 55] -> 
             RGBColor[
              0.28645859801019335`, 0.41841652740581015`, 0.939624765427937], 
             UndirectedEdge[142, 295] -> 
             RGBColor[
              0.7481542644116976, 0.8033229003900898, 0.9754955751330152], 
             UndirectedEdge[53, 200] -> 
             RGBColor[
              0.849818066326612, 0.3549983638102894, 0.19420628891428304`], 
             UndirectedEdge[33, 237] -> 
             RGBColor[
              0.7767209844121652, 0.8262100194866766, 0.9782143643357628], 
             UndirectedEdge[51, 67] -> 
             RGBColor[
              0.9529402270197467, 0.9622638379796367, 0.8739273734917072], 
             UndirectedEdge[47, 48] -> 
             RGBColor[
              0.5288713488786927, 0.6272983725157164, 0.9563690029663805], 
             UndirectedEdge[102, 237] -> 
             RGBColor[
              0.5120510519507784, 0.6128989081758123, 0.9552397996499549], 
             UndirectedEdge[150, 282] -> 
             RGBColor[
              0.9628316709480902, 0.9718005015674145, 0.9478004654188247], 
             UndirectedEdge[214, 293] -> 
             RGBColor[
              0.21107172389025777`, 0.33918014290187026`, 0.9353315944716927],
              UndirectedEdge[73, 245] -> 
             RGBColor[
              0.37670637299800835`, 0.5007058593032094, 0.9452243748724349], 
             UndirectedEdge[82, 192] -> 
             RGBColor[
              0.90834965026943, 0.6505028830957647, 0.37453721305284604`], 
             UndirectedEdge[82, 266] -> 
             RGBColor[
              0.6213553148465931, 0.6847435984870042, 0.8214592367687926], 
             UndirectedEdge[30, 38] -> 
             RGBColor[
              0.4400713503236684, 0.5553482940395915, 0.949328558422408], 
             UndirectedEdge[146, 242] -> 
             RGBColor[
              0.23544148915831797`, 0.3647943113309621, 0.9367194165518717], 
             UndirectedEdge[25, 77] -> 
             RGBColor[
              0.24892138027318342`, 0.37896253156714604`, 0.9374870764091515],
              UndirectedEdge[68, 271] -> 
             RGBColor[
              0.9259155815977133, 0.7290271362933656, 0.2919182148886562], 
             UndirectedEdge[23, 267] -> 
             RGBColor[
              0.3821106817559689, 0.50384843174461, 0.9457196175325961], 
             UndirectedEdge[10, 161] -> 
             RGBColor[
              0.21385191803304957`, 0.3421023032204342, 0.935489922415196], 
             UndirectedEdge[223, 287] -> 
             RGBColor[
              0.9141648921008272, 0.6925393884549282, 0.24954185631357317`], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.43016772773719436`, 0.545286907400802, 0.949107366939159], 
             UndirectedEdge[218, 229] -> 
             RGBColor[
              0.3012157370951104, 0.430446886752895, 0.9405925945789568], 
             UndirectedEdge[62, 170] -> 
             RGBColor[
              0.8795452044161765, 0.44332219509737536`, 0.3392971994770656], 
             UndirectedEdge[188, 294] -> 
             RGBColor[
              0.20780626806211017`, 0.3357479417846294, 0.9351456315930887], 
             UndirectedEdge[181, 299] -> 
             RGBColor[
              0.8541508128707371, 0.884172913273241, 0.8565895585797871], 
             UndirectedEdge[69, 109] -> 
             RGBColor[
              0.957103333757725, 0.9637481152069529, 0.737975761375697], 
             UndirectedEdge[48, 175] -> 
             RGBColor[
              0.3540970438547585, 0.4798066886867111, 0.9438319175031515], 
             UndirectedEdge[248, 270] -> 
             RGBColor[
              0.21830317142063266`, 0.3467808527565494, 0.9357434147105796], 
             UndirectedEdge[85, 232] -> 
             RGBColor[
              0.9568611020652522, 0.9642649897035074, 0.7955094610260169], 
             UndirectedEdge[65, 152] -> 
             RGBColor[
              0.270606352963235, 0.4017548127710696, 0.9387220035238077], 
             UndirectedEdge[43, 63] -> 
             RGBColor[
              0.3233435154432426, 0.45448563418447746`, 0.9418241407759673], 
             UndirectedEdge[184, 293] -> 
             RGBColor[
              0.22334920945949943`, 0.35208455867268873`, 0.9360307791119489],
              UndirectedEdge[24, 260] -> 
             RGBColor[
              0.9023952825645615, 0.924495379134781, 0.9727268847769307], 
             UndirectedEdge[201, 229] -> 
             RGBColor[
              0.3337508945428317, 0.46349998287045846`, 0.9424872897693092], 
             UndirectedEdge[17, 48] -> 
             RGBColor[
              0.35495264897954515`, 0.4807059839213601, 0.9438806429492537], 
             UndirectedEdge[153, 163] -> 
             RGBColor[
              0.2574205034515923, 0.3878956489031873, 0.9379710889008359], 
             UndirectedEdge[33, 200] -> 
             RGBColor[
              0.9003293088366926, 0.7550036483702731, 0.6091535540920102], 
             UndirectedEdge[33, 282] -> 
             RGBColor[
              0.9391598487497231, 0.9536036259867218, 0.9690629330997416], 
             UndirectedEdge[150, 237] -> 
             RGBColor[
              0.8003928066105324, 0.8444068950673695, 0.956951896654846], 
             UndirectedEdge[172, 203] -> 
             RGBColor[
              0.26454467239722235`, 0.39538360216344437`, 0.9383767997830261],
              UndirectedEdge[56, 93] -> 
             RGBColor[
              0.5394509250519448, 0.6369895888012234, 0.9568866993753897], 
             UndirectedEdge[122, 299] -> 
             RGBColor[
              0.8093386473760087, 0.8488870251734923, 0.8523133648913199], 
             UndirectedEdge[44, 100] -> 
             RGBColor[
              0.8884719755057815, 0.5557375080883161, 0.23670627510997347`], 
             UndirectedEdge[31, 171] -> 
             RGBColor[
              0.5185950159671473, 0.6191084488745244, 0.955507160509088], 
             UndirectedEdge[136, 256] -> 
             RGBColor[
              0.9940778224627702, 0.9897413860088904, 0.596785706394875], 
             UndirectedEdge[146, 159] -> 
             RGBColor[
              0.2389221548438223, 0.3684527116533779, 0.9369176353134778], 
             UndirectedEdge[65, 133] -> 
             RGBColor[
              0.3190318248130566, 0.44882524399181684`, 0.9416199173833522], 
             UndirectedEdge[58, 245] -> 
             RGBColor[
              0.48666290222101594`, 0.5933487734884098, 0.952947963928872], 
             UndirectedEdge[172, 272] -> 
             RGBColor[
              0.2463878565667746, 0.37629963751702955`, 0.937342795982084], 
             UndirectedEdge[99, 218] -> 
             RGBColor[
              0.3117655585077827, 0.43958461181110975`, 0.9412648198705315], 
             UndirectedEdge[18, 113] -> 
             RGBColor[
              0.9529050044310041, 0.9643972099323963, 0.9646037225429771], 
             UndirectedEdge[43, 131] -> 
             RGBColor[
              0.3235024771639835, 0.45462331883733487`, 0.9418342696762487], 
             UndirectedEdge[2, 156] -> 
             RGBColor[
              0.2292281520802934, 0.3582637001136342, 0.9363655761970868], 
             UndirectedEdge[165, 232] -> 
             RGBColor[
              0.9871784526525289, 0.9674285696046385, 0.48831934332178484`], 
             UndirectedEdge[173, 186] -> 
             RGBColor[
              0.24357136840210497`, 0.3733393298802981, 0.937182401147727], 
             UndirectedEdge[39, 281] -> 
             RGBColor[
              0.8570472727010972, 0.420354056465815, 0.2015122917080806], 
             UndirectedEdge[77, 91] -> 
             RGBColor[
              0.25932242623621204`, 0.38989469033869195`, 0.9380794005897775],
              UndirectedEdge[15, 19] -> 
             RGBColor[
              0.265094966907718, 0.3959619965846625, 0.938408138241311], 
             UndirectedEdge[119, 241] -> 
             RGBColor[
              0.2806500707405608, 0.4123113969635265, 0.9392939783928775], 
             UndirectedEdge[103, 116] -> 
             RGBColor[
              0.3006123597209014, 0.43202989779004775`, 0.9404770506166615], 
             UndirectedEdge[99, 257] -> 
             RGBColor[
              0.37939685727732686`, 0.5030362215582833, 0.9453958101516111], 
             UndirectedEdge[17, 253] -> 
             RGBColor[
              0.2964738820674033, 0.42894322595562323`, 0.9401951210387102], 
             UndirectedEdge[204, 292] -> 
             RGBColor[
              0.2369721103072519, 0.36640309120547765`, 0.9368065831619525], 
             UndirectedEdge[65, 241] -> 
             RGBColor[
              0.2834960053804121, 0.4153026547126882, 0.9394560501604341], 
             UndirectedEdge[71, 256] -> 
             RGBColor[
              0.8124222635893662, 0.8512090470378892, 0.8440664489660341], 
             UndirectedEdge[37, 102] -> 
             RGBColor[
              0.5330127818666326, 0.6293292071697167, 0.9572915771331396], 
             UndirectedEdge[61, 217] -> 
             RGBColor[
              0.686937545269946, 0.7542032342825437, 0.9702221270801157], 
             UndirectedEdge[35, 184] -> 
             RGBColor[
              0.23183414268000563`, 0.3610027614632789, 0.9365139835065228], 
             UndirectedEdge[164, 241] -> 
             RGBColor[
              0.33149984085228634`, 0.458806984736167, 0.9424442983869149], 
             UndirectedEdge[192, 255] -> 
             RGBColor[
              0.896308870615873, 0.6109454327971793, 0.23771756775713984`], 
             UndirectedEdge[112, 134] -> 
             RGBColor[
              0.2631071012640549, 0.3938726237552112, 0.9382949322336882], 
             UndirectedEdge[44, 195] -> 
             RGBColor[
              0.8677809264179449, 0.3966970379236798, 0.21689250313626357`], 
             UndirectedEdge[127, 281] -> 
             RGBColor[
              0.833873528065198, 0.26137235694956523`, 0.1800706347708988], 
             UndirectedEdge[59, 192] -> 
             RGBColor[
              0.8435354828696529, 0.32873767594338427`, 0.18905271951585984`],
              UndirectedEdge[108, 264] -> 
             RGBColor[
              0.3192908615453144, 0.4496732026354332, 0.9416135901421105], 
             UndirectedEdge[136, 296] -> 
             RGBColor[
              0.8445716246365338, 0.8749311705589841, 0.7198898610709794], 
             UndirectedEdge[118, 130] -> 
             RGBColor[
              0.17892828448197629`, 0.3053953500719979, 0.9335010731493483], 
             UndirectedEdge[85, 136] -> 
             RGBColor[
              0.9562666668799304, 0.9629935529487204, 0.7308088595324563], 
             UndirectedEdge[104, 157] -> 
             RGBColor[
              0.3155261405863954, 0.44552577951204275`, 0.9414061686253012], 
             UndirectedEdge[158, 217] -> 
             RGBColor[
              0.6053338779034495, 0.6866046110497097, 0.9641707450092601], 
             UndirectedEdge[11, 174] -> 
             RGBColor[
              0.36791464439567134`, 0.49309090587299315`, 0.9446641737001142],
              UndirectedEdge[39, 220] -> 
             RGBColor[
              0.6640857208165928, 0.4568042722742281, 0.4534382779437778], 
             UndirectedEdge[32, 208] -> 
             RGBColor[
              0.27110861374646283`, 0.402282720699415, 0.9387506065323843], 
             UndirectedEdge[27, 103] -> 
             RGBColor[
              0.2686276829189324, 0.3996751050995809, 0.9386093211919647], 
             UndirectedEdge[212, 250] -> 
             RGBColor[
              0.21715203202826977`, 0.34557093226872304`, 0.9356778590251427],
              UndirectedEdge[129, 298] -> 
             RGBColor[
              0.26058075662513375`, 0.3912172753602034, 0.9381510606438935], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.887313539208574, 0.5061966019430634, 0.37187376646363723`], 
             UndirectedEdge[261, 290] -> 
             RGBColor[
              0.5067850511563949, 0.6090396671765619, 0.9547103165107921], 
             UndirectedEdge[24, 113] -> 
             RGBColor[
              0.9575230369172714, 0.9678413309993203, 0.9567865981194988], 
             UndirectedEdge[15, 243] -> 
             RGBColor[
              0.2285446981366219, 0.35754534668535254`, 0.9363266545060742], 
             UndirectedEdge[246, 296] -> 
             RGBColor[
              0.6475517482649964, 0.7239253864883827, 0.965961068287336], 
             UndirectedEdge[131, 174] -> 
             RGBColor[
              0.3585773503848271, 0.4850034111068425, 0.9440692095823882], 
             UndirectedEdge[44, 121] -> 
             RGBColor[
              0.9798326937990873, 0.9423326330377451, 0.48673505054828914`], 
             UndirectedEdge[155, 293] -> 
             RGBColor[
              0.21078204772465953`, 0.3388756748852968, 0.9353150978425994], 
             UndirectedEdge[105, 140] -> 
             RGBColor[
              0.3086221728107845, 0.4399248428735164, 0.9409523793012212], 
             UndirectedEdge[51, 138] -> 
             RGBColor[
              0.8501230130531416, 0.8811959449639274, 0.8638775606265587], 
             UndirectedEdge[133, 277] -> 
             RGBColor[
              0.3496210523003913, 0.4772459158627348, 0.9434985221881913], 
             UndirectedEdge[201, 261] -> 
             RGBColor[
              0.36087721144814144`, 0.48699543516550725`, 0.9442157546956553],
              UndirectedEdge[19, 57] -> 
             RGBColor[
              0.2691600647734066, 0.40023467218359243`, 0.9386396395509886], 
             UndirectedEdge[104, 261] -> 
             RGBColor[
              0.34285661416014696`, 0.46919806205208336`, 0.9431476422340319],
              UndirectedEdge[15, 111] -> 
             RGBColor[
              0.2409685800879815, 0.3706036343358437, 0.9370341762037178], 
             UndirectedEdge[71, 85] -> 
             RGBColor[
              0.7746111080065263, 0.8244612139777192, 0.9780896021036154], 
             UndirectedEdge[84, 158] -> 
             RGBColor[
              0.35212502014478775`, 0.47866323634096297`, 0.943685588557766], 
             UndirectedEdge[65, 162] -> 
             RGBColor[
              0.28622167127698683`, 0.41816750238718753`, 0.9396112728009827],
              UndirectedEdge[156, 268] -> 
             RGBColor[
              0.2451076812596908, 0.374954092101482, 0.9372698918921952], 
             UndirectedEdge[48, 252] -> 
             RGBColor[
              0.35710710220900627`, 0.48297045086574814`, 0.9440033358734436],
              UndirectedEdge[204, 235] -> 
             RGBColor[
              0.23646094075205434`, 0.36586581959294334`, 0.9367774728119916],
              UndirectedEdge[62, 130] -> 
             RGBColor[
              0.5868878667757954, 0.648392143438405, 0.8070978104506135], 
             UndirectedEdge[142, 283] -> 
             RGBColor[
              0.6388734394755219, 0.7174499822340865, 0.964888142090148], 
             UndirectedEdge[99, 259] -> 
             RGBColor[
              0.41587462147542475`, 0.5343343034600658, 0.9478022372825421], 
             UndirectedEdge[43, 244] -> 
             RGBColor[
              0.28234247424873604`, 0.412848733894419, 0.9394358151698824], 
             UndirectedEdge[36, 154] -> 
             RGBColor[
              0.750385676327774, 0.8049262605804057, 0.9757550895296658], 
             UndirectedEdge[11, 185] -> 
             RGBColor[
              0.4557880502577546, 0.5660866394053694, 0.9511242925783112], 
             UndirectedEdge[20, 150] -> 
             RGBColor[
              0.9139560790389594, 0.9335493921357441, 0.968134833574319], 
             UndirectedEdge[175, 252] -> 
             RGBColor[
              0.2975212413691305, 0.4300440669881537, 0.9402547666015143], 
             UndirectedEdge[97, 292] -> 
             RGBColor[
              0.25027096919944, 0.3803810350975218, 0.937563933501964], 
             UndirectedEdge[176, 226] -> 
             RGBColor[
              0.17893944427006758`, 0.3054070797168533, 0.9335017086827707], 
             UndirectedEdge[80, 103] -> 
             RGBColor[
              0.2733233300214085, 0.4046105279255051, 0.9388767313478634], 
             UndirectedEdge[137, 220] -> 
             RGBColor[
              0.6494413840373972, 0.36338333915495696`, 0.44016439160276355`],
              UndirectedEdge[20, 167] -> 
             RGBColor[
              0.8099161582263048, 0.8518030947538164, 0.981590034710579], 
             UndirectedEdge[240, 256] -> 
             RGBColor[
              0.9950907669461442, 0.9919079718344301, 0.7070384622414018], 
             UndirectedEdge[113, 278] -> 
             RGBColor[
              0.7811703997408805, 0.8288870412862575, 0.957738894978919], 
             UndirectedEdge[181, 240] -> 
             RGBColor[
              0.8543753182561593, 0.8839651564219314, 0.8310187966371865], 
             UndirectedEdge[7, 151] -> 
             RGBColor[
              0.4190101469832575, 0.5373472620797284, 0.9479199339430164], 
             UndirectedEdge[6, 101] -> 
             RGBColor[
              0.4261316567977976, 0.5406988809357904, 0.9490838670731377], 
             UndirectedEdge[65, 116] -> 
             RGBColor[
              0.3051622199360282, 0.4368120893539453, 0.940736158424998], 
             UndirectedEdge[50, 264] -> 
             RGBColor[
              0.32355517598609507`, 0.45336673747336176`, 0.9418853084874919],
              UndirectedEdge[55, 235] -> 
             RGBColor[
              0.25936698600148883`, 0.38994152547725025`, 0.9380819382024896],
              UndirectedEdge[100, 232] -> 
             RGBColor[
              0.8981524008015748, 0.5877362010635289, 0.330065035596082], 
             UndirectedEdge[28, 163] -> 
             RGBColor[
              0.23238600045450547`, 0.3615827989740821, 0.9365454109903801], 
             UndirectedEdge[11, 63] -> 
             RGBColor[
              0.3340095449749544, 0.46372401287461446`, 0.9425037707461285], 
             UndirectedEdge[234, 274] -> 
             RGBColor[
              0.8664044843984396, 0.3868069423093286, 0.21510625144616582`], 
             UndirectedEdge[148, 270] -> 
             RGBColor[
              0.23353444010566207`, 0.3627898818627272, 0.9366108129295494], 
             UndirectedEdge[96, 245] -> 
             RGBColor[
              0.41493426639987385`, 0.5338169391781161, 0.9476602224364029], 
             UndirectedEdge[159, 235] -> 
             RGBColor[
              0.24471645266359499`, 0.3745428860416596, 0.9372476120024185], 
             UndirectedEdge[53, 287] -> 
             RGBColor[
              0.8681444166075922, 0.43115720119419465`, 0.20913320183842923`],
              UndirectedEdge[105, 289] -> 
             RGBColor[
              0.2900768000973668, 0.42221948720669167`, 0.9398308166841512], 
             UndirectedEdge[56, 164] -> 
             RGBColor[
              0.46580833431938506`, 0.5753190136054342, 0.9516098956299331], 
             UndirectedEdge[112, 235] -> 
             RGBColor[
              0.24712629913564943`, 0.3770757874768801, 0.9373848491939536], 
             UndirectedEdge[7, 43] -> 
             RGBColor[
              0.3584602463932565, 0.4849019815151618, 0.9440617478195963], 
             UndirectedEdge[242, 243] -> 
             RGBColor[
              0.22929951054390013`, 0.35833870238327276`, 0.9363696399560237],
              UndirectedEdge[151, 286] -> 
             RGBColor[
              0.5011547059099458, 0.6056262623148936, 0.953947236987697], 
             UndirectedEdge[126, 163] -> 
             RGBColor[
              0.23364896427549098`, 0.3629102540264691, 0.9366173349115978], 
             UndirectedEdge[31, 138] -> 
             RGBColor[
              0.662760313991049, 0.7361123302878763, 0.9672677727663206], 
             UndirectedEdge[95, 138] -> 
             RGBColor[
              0.5976652055170001, 0.6832651887274253, 0.9621432473760043], 
             UndirectedEdge[197, 275] -> 
             RGBColor[
              0.21163940728530467`, 0.33977681414327066`, 0.9353639232012283],
              UndirectedEdge[198, 245] -> 
             RGBColor[
              0.4443289893270455, 0.5589801958800422, 0.949615283231626], 
             UndirectedEdge[187, 264] -> 
             RGBColor[
              0.3292953995025846, 0.4583386305713222, 0.9422510704540822], 
             UndirectedEdge[62, 195] -> 
             RGBColor[
              0.8777120828474402, 0.4292320194410746, 0.3375418001926291], 
             UndirectedEdge[169, 187] -> 
             RGBColor[
              0.3284772756829356, 0.4574787305648249, 0.9422044795128589], 
             UndirectedEdge[82, 199] -> 
             RGBColor[
              0.587001837836629, 0.6486359160132862, 0.81950285707449], 
             UndirectedEdge[126, 155] -> 
             RGBColor[
              0.21912067898952223`, 0.3476401050444259, 0.9357899705572339], 
             UndirectedEdge[82, 220] -> 
             RGBColor[
              0.6261342073882591, 0.6897665175475827, 0.8217313876293025], 
             UndirectedEdge[32, 202] -> 
             RGBColor[
              0.24218926046257408`, 0.37188664680514644`, 0.937103692145216], 
             UndirectedEdge[113, 260] -> 
             RGBColor[
              0.9042815340807562, 0.9259021424271057, 0.969533952973199], 
             UndirectedEdge[105, 230] -> 
             RGBColor[
              0.2692612582166467, 0.40034103290847267`, 0.938645402367879], 
             UndirectedEdge[245, 289] -> 
             RGBColor[
              0.3576929449951681, 0.48259509766982983`, 0.944072988186208], 
             UndirectedEdge[108, 187] -> 
             RGBColor[
              0.35392495764506043`, 0.4809737423517148, 0.9437727632309596], 
             UndirectedEdge[137, 228] -> 
             RGBColor[
              0.8358252186425734, 0.5196492090978858, 0.45495474568587335`], 
             UndirectedEdge[88, 261] -> 
             RGBColor[
              0.4524312720200109, 0.5649128206637994, 0.9504313879127225], 
             UndirectedEdge[192, 228] -> 
             RGBColor[
              0.8487718393512739, 0.6053612100527003, 0.4668120161228374], 
             UndirectedEdge[42, 97] -> 
             RGBColor[
              0.25595913612423093`, 0.3863596591860904, 0.937887866193442], 
             UndirectedEdge[121, 240] -> 
             RGBColor[
              0.9947718410408293, 0.9912258215713169, 0.6723253456304181], 
             UndirectedEdge[25, 43] -> 
             RGBColor[
              0.2869920462831278, 0.4177357289024586, 0.9397006014188156], 
             UndirectedEdge[77, 270] -> 
             RGBColor[
              0.23714390206690406`, 0.36658365523709874`, 0.9368163664485216],
              UndirectedEdge[225, 255] -> 
             RGBColor[
              0.9599585954916654, 0.876593081803823, 0.2989471339802242], 
             UndirectedEdge[2, 275] -> 
             RGBColor[
              0.2217679370492794, 0.35042254111108606`, 0.9359407279874696], 
             UndirectedEdge[235, 253] -> 
             RGBColor[
              0.2693822700586988, 0.40046822402706334`, 0.9386522938132629], 
             UndirectedEdge[73, 95] -> 
             RGBColor[
              0.4088283158597046, 0.5275690199007069, 0.9475362008014293], 
             UndirectedEdge[49, 175] -> 
             RGBColor[
              0.26553285029495766`, 0.3964222397880617, 0.9384330750524239], 
             UndirectedEdge[153, 219] -> 
             RGBColor[
              0.2738583241419696, 0.40517284066680126`, 0.9389071984715764], 
             UndirectedEdge[54, 167] -> 
             RGBColor[
              0.585666437251012, 0.671825268631737, 0.9619628736506332], 
             UndirectedEdge[56, 246] -> 
             RGBColor[
              0.57328015808247, 0.6644536841649844, 0.9595498605201163], 
             UndirectedEdge[192, 225] -> 
             RGBColor[
              0.8969783764685921, 0.6132038332458503, 0.2403184715693816], 
             UndirectedEdge[84, 252] -> 
             RGBColor[
              0.30057464185555743`, 0.4332533844961608, 0.9404286532421151], 
             UndirectedEdge[119, 164] -> 
             RGBColor[
              0.33307449939887124`, 0.46046205070774604`, 0.9425339728616443],
              UndirectedEdge[93, 168] -> 
             RGBColor[
              0.4585412392278475, 0.5694721717790032, 0.9510231831684333], 
             UndirectedEdge[111, 250] -> 
             RGBColor[
              0.2327988220725642, 0.3620167006690641, 0.9365689205708136], 
             UndirectedEdge[54, 286] -> 
             RGBColor[
              0.4882211414959945, 0.5944238588793778, 0.953123121699942], 
             UndirectedEdge[74, 257] -> 
             RGBColor[
              0.5147596974188978, 0.6152603482603705, 0.9554081515783656], 
             UndirectedEdge[220, 236] -> 
             RGBColor[
              0.4402011946832155, 0.5463223550644548, 0.9507193164378127], 
             UndirectedEdge[130, 228] -> 
             RGBColor[
              0.49763512145939465`, 0.5809234064486897, 0.9579150616794772], 
             UndirectedEdge[1, 142] -> 
             RGBColor[
              0.5387732060688373, 0.6352393283002062, 0.9572689291818902], 
             UndirectedEdge[101, 114] -> 
             RGBColor[
              0.4255007228362041, 0.540035729338632, 0.9490479363174081], 
             UndirectedEdge[199, 266] -> 
             RGBColor[
              0.21328047700996416`, 0.3415016824737179, 0.9354573796943026], 
             UndirectedEdge[93, 277] -> 
             RGBColor[
              0.440152252258617, 0.5535445555236148, 0.9498514531794966], 
             UndirectedEdge[19, 112] -> 
             RGBColor[
              0.271740291472555, 0.402946654040219, 0.9387865796444018], 
             UndirectedEdge[77, 203] -> 
             RGBColor[
              0.25281317669126346`, 0.38305305635669296`, 0.9377087084577643],
              UndirectedEdge[26, 60] -> 
             RGBColor[
              0.9559587194852852, 0.8665294960501166, 0.5718984085520893], 
             UndirectedEdge[186, 263] -> 
             RGBColor[
              0.24547633917610456`, 0.3753415749458948, 0.9372908864151546], 
             UndirectedEdge[167, 283] -> 
             RGBColor[
              0.6863247949375169, 0.7545193417646557, 0.9696176497444712], 
             UndirectedEdge[170, 200] -> 
             RGBColor[
              0.8432609465449801, 0.30459746782045594`, 0.18792718360618468`],
              UndirectedEdge[17, 292] -> 
             RGBColor[
              0.26964195081094916`, 0.4007411649623891, 0.9386670822479402], 
             UndirectedEdge[106, 215] -> 
             RGBColor[
              0.8258859987463416, 0.8619784867738793, 0.84861498208911], 
             UndirectedEdge[123, 229] -> 
             RGBColor[
              0.3913046976868122, 0.5133501944155183, 0.9461545672128138], 
             UndirectedEdge[105, 149] -> 
             RGBColor[
              0.29155965067616113`, 0.4237780571831614, 0.9399152628309327], 
             UndirectedEdge[68, 274] -> 
             RGBColor[
              0.9194708353599413, 0.7072874939349834, 0.2668815927431183], 
             UndirectedEdge[149, 171] -> 
             RGBColor[
              0.3561511381973472, 0.48153386145037547`, 0.943964705839551], 
             UndirectedEdge[29, 172] -> 
             RGBColor[
              0.256159178309366, 0.3865699162060744, 0.9378992582999495], 
             UndirectedEdge[76, 209] -> 
             RGBColor[
              0.2797259704782522, 0.4113401089964994, 0.9392413522500229], 
             UndirectedEdge[247, 267] -> 
             RGBColor[
              0.5234677465828359, 0.6240137244860162, 0.9556284450179895], 
             UndirectedEdge[164, 210] -> 
             RGBColor[
              0.3812406788826516, 0.5046332471596473, 0.9455132968338751], 
             UndirectedEdge[258, 260] -> 
             RGBColor[
              0.9054604072768613, 0.9267813441265331, 0.9675384281515653], 
             UndirectedEdge[62, 137] -> 
             RGBColor[
              0.8953270488535073, 0.5646283670910295, 0.3544099115332976], 
             UndirectedEdge[175, 280] -> 
             RGBColor[
              0.2812847712693677, 0.4129785074616403, 0.9393301236490378], 
             UndirectedEdge[72, 194] -> 
             RGBColor[
              0.5838203648230471, 0.6728659592388615, 0.9604785834522965], 
             UndirectedEdge[3, 257] -> 
             RGBColor[
              0.38431511212659675`, 0.5072961667100446, 0.9457091970015647], 
             UndirectedEdge[154, 171] -> 
             RGBColor[
              0.5797766952507789, 0.6672643729865424, 0.9613588180759691], 
             UndirectedEdge[168, 277] -> 
             RGBColor[
              0.3674840405107483, 0.49271793843065337`, 0.944636736001335], 
             UndirectedEdge[146, 243] -> 
             RGBColor[
              0.22430859499308387`, 0.3530929336970421, 0.9360854146988027], 
             UndirectedEdge[98, 122] -> 
             RGBColor[
              0.5234999711581451, 0.6232114459734905, 0.9558598822602524], 
             UndirectedEdge[142, 210] -> 
             RGBColor[
              0.5187904189187625, 0.6179312424348968, 0.9559956436547723], 
             UndirectedEdge[3, 38] -> 
             RGBColor[
              0.3976345995492975, 0.5188328372586848, 0.9465579029621789], 
             UndirectedEdge[21, 205] -> 
             RGBColor[
              0.4564507498978377, 0.5677093547420913, 0.9508767552454336], 
             UndirectedEdge[153, 221] -> 
             RGBColor[
              0.2840475061144973, 0.4158823169513779, 0.939487457311368], 
             UndirectedEdge[55, 159] -> 
             RGBColor[
              0.26204426941803677`, 0.39275552009761494`, 0.9382344055323761],
              UndirectedEdge[149, 298] -> 
             RGBColor[
              0.28960052483186716`, 0.4217188917050555, 0.9398036935123671], 
             UndirectedEdge[22, 247] -> 
             RGBColor[
              0.6982336123573278, 0.7632154445962727, 0.9712197251392987], 
             UndirectedEdge[105, 298] -> 
             RGBColor[
              0.2872112063681208, 0.41920756650811786`, 0.9396676253605367], 
             UndirectedEdge[169, 219] -> 
             RGBColor[
              0.2836300261607937, 0.41544351905027754`, 0.9394636824456108], 
             UndirectedEdge[53, 225] -> 
             RGBColor[
              0.8748070311041928, 0.4565865562872151, 0.219627594384284], 
             UndirectedEdge[47, 90] -> 
             RGBColor[
              0.5238031310544717, 0.622908536972411, 0.9560460606082701], 
             UndirectedEdge[100, 137] -> 
             RGBColor[
              0.848642289586235, 0.3748915297128206, 0.1942132174823743], 
             UndirectedEdge[15, 175] -> 
             RGBColor[
              0.2667169814547302, 0.3976668367152345, 0.9385005095702079], 
             UndirectedEdge[49, 253] -> 
             RGBColor[
              0.2666399442226916, 0.39758586569991927`, 0.9384961224138098], 
             UndirectedEdge[166, 291] -> 
             RGBColor[
              0.8761797606414349, 0.42138431296305434`, 0.25963779623893113`],
              UndirectedEdge[161, 230] -> 
             RGBColor[
              0.2328116110999559, 0.36203014274772405`, 0.9365696488870041], 
             UndirectedEdge[263, 269] -> 
             RGBColor[
              0.24400443083652518`, 0.3737945059566179, 0.9372070634127088], 
             UndirectedEdge[122, 160] -> 
             RGBColor[
              0.6072063704282553, 0.6919965117057422, 0.9622206562317872], 
             UndirectedEdge[196, 289] -> 
             RGBColor[
              0.28595784411409636`, 0.4178902033113814, 0.9395962482343534], 
             UndirectedEdge[30, 158] -> 
             RGBColor[
              0.4329152304787701, 0.5491500227069821, 0.9488725767937995], 
             UndirectedEdge[114, 187] -> 
             RGBColor[
              0.33417034239985266`, 0.4634625046455827, 0.9425286912402498], 
             UndirectedEdge[49, 159] -> 
             RGBColor[
              0.24197412682758776`, 0.3716605277145155, 0.9370914406029653], 
             UndirectedEdge[33, 94] -> 
             RGBColor[
              0.8883058899064401, 0.9137750204630982, 0.9892086028509474], 
             UndirectedEdge[193, 220] -> 
             RGBColor[
              0.3283447463388828, 0.4540509053495343, 0.9423173412993839], 
             UndirectedEdge[60, 127] -> 
             RGBColor[
              0.8638755462529181, 0.416820362954043, 0.20580473648210393`], 
             UndirectedEdge[282, 297] -> 
             RGBColor[
              0.8620280342318183, 0.892582413918251, 0.9615782291090177], 
             UndirectedEdge[97, 235] -> 
             RGBColor[
              0.24975979964424241`, 0.3798437634849875, 0.9375348231520031], 
             UndirectedEdge[50, 187] -> 
             RGBColor[
              0.35818927208584117`, 0.4846672771896433, 0.9440444815763409], 
             UndirectedEdge[271, 274] -> 
             RGBColor[
              0.9710201994330907, 0.9139064692863681, 0.34191937648403536`], 
             UndirectedEdge[137, 170] -> 
             RGBColor[
              0.8376752842858002, 0.29059432120131196`, 0.18371120082121695`],
              UndirectedEdge[84, 253] -> 
             RGBColor[
              0.29867167742904355`, 0.43125324822898137`, 0.9403202822332086],
              UndirectedEdge[33, 185] -> 
             RGBColor[
              0.7413664787721765, 0.7975076391058051, 0.9754311281439616], 
             UndirectedEdge[3, 144] -> 
             RGBColor[
              0.34651719678738085`, 0.4745575122216793, 0.9433007472595341], 
             UndirectedEdge[11, 43] -> 
             RGBColor[
              0.3328397711748278, 0.46271081360348554`, 0.9424292337939748], 
             UndirectedEdge[29, 272] -> 
             RGBColor[
              0.23305163384099561`, 0.36228242186687754`, 0.9365833178270244],
              UndirectedEdge[70, 251] -> 
             RGBColor[
              0.27547374372817707`, 0.40687074907542276`, 0.9389991942272118],
              UndirectedEdge[99, 123] -> 
             RGBColor[
              0.40185451909948444`, 0.5224879194737331, 0.9468267925043885], 
             UndirectedEdge[133, 239] -> 
             RGBColor[
              0.38064066205782954`, 0.5041135427437089, 0.9454750642923715], 
             UndirectedEdge[259, 260] -> 
             RGBColor[
              0.656707314635238, 0.7292515443954324, 0.9682208504157948], 
             UndirectedEdge[125, 192] -> 
             RGBColor[
              0.907532480377328, 0.648755039325108, 0.28559331328553295`], 
             UndirectedEdge[213, 264] -> 
             RGBColor[
              0.36127001361165895`, 0.48603343422176903`, 0.9442884645910713],
              UndirectedEdge[134, 204] -> 
             RGBColor[
              0.25244174288045984`, 0.38266265587127446`, 0.9376875558517261],
              UndirectedEdge[94, 142] -> 
             RGBColor[
              0.7604864358301577, 0.8131562391312941, 0.9766718286519673], 
             UndirectedEdge[134, 175] -> 
             RGBColor[
              0.2842559782593704, 0.41610143439353686`, 0.9394993294916116], 
             UndirectedEdge[8, 267] -> 
             RGBColor[
              0.5598482664107077, 0.6534036903177951, 0.9585918492816847], 
             UndirectedEdge[195, 225] -> 
             RGBColor[
              0.8664167897538245, 0.3920954846410811, 0.21159308979174907`], 
             UndirectedEdge[51, 281] -> 
             RGBColor[
              0.88857163743908, 0.5160716326224021, 0.37357200694912684`], 
             UndirectedEdge[49, 243] -> 
             RGBColor[
              0.2273605669768493, 0.3563007497581797, 0.9362592199882902], 
             UndirectedEdge[212, 243] -> 
             RGBColor[
              0.2149437082857312, 0.34324984399950276`, 0.9355520982549272], 
             UndirectedEdge[22, 285] -> 
             RGBColor[
              0.6000751622710249, 0.6816104857973055, 0.9640215926822105], 
             UndirectedEdge[20, 33] -> 
             RGBColor[
              0.8902842568405922, 0.9153525165550513, 0.9893973012552358], 
             UndirectedEdge[9, 174] -> 
             RGBColor[
              0.4545765714263261, 0.5664286209801727, 0.9506626768751375], 
             UndirectedEdge[180, 250] -> 
             RGBColor[
              0.22830469938985565`, 0.3572930927857018, 0.9363129869324922], 
             UndirectedEdge[92, 221] -> 
             RGBColor[
              0.27785530490942656`, 0.40937392087661617`, 0.9391348206132799],
              UndirectedEdge[71, 232] -> 
             RGBColor[
              0.8118465460917592, 0.8499776455244756, 0.7814031522680547], 
             UndirectedEdge[25, 148] -> 
             RGBColor[
              0.24531191831194143`, 0.3751687581927745, 0.9372815228901793], 
             UndirectedEdge[76, 218] -> 
             RGBColor[
              0.2751691719679872, 0.4065506248444982, 0.9389818493160426], 
             UndirectedEdge[20, 200] -> 
             RGBColor[
              0.8759509079419014, 0.7355649732308305, 0.6068283204518097], 
             UndirectedEdge[68, 255] -> 
             RGBColor[
              0.9166602771185755, 0.6978068210363987, 0.2559631047048003], 
             UndirectedEdge[30, 123] -> 
             RGBColor[
              0.44920952472312525`, 0.5632633214064009, 0.9499108348145711], 
             UndirectedEdge[113, 290] -> 
             RGBColor[
              0.7861690031762806, 0.8329451327396338, 0.9581324033518415], 
             UndirectedEdge[230, 269] -> 
             RGBColor[
              0.23818874032876391`, 0.3676818464968855, 0.9368758684418348], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.40607658256930623`, 0.5261448586442126, 0.9470958186552614], 
             UndirectedEdge[71, 296] -> 
             RGBColor[
              0.6629160657631297, 0.7363988315879828, 0.9671706036421385], 
             UndirectedEdge[37, 237] -> 
             RGBColor[
              0.6597410410048012, 0.7340591462727639, 0.9667579712592742], 
             UndirectedEdge[8, 217] -> 
             RGBColor[
              0.7294424930983517, 0.7885652866674933, 0.9736676687505319], 
             UndirectedEdge[39, 100] -> 
             RGBColor[
              0.861748584824546, 0.4564904015747509, 0.20601427350686777`], 
             UndirectedEdge[35, 216] -> 
             RGBColor[
              0.24253456217849695`, 0.3722495808019747, 0.9371233565671098], 
             UndirectedEdge[48, 253] -> 
             RGBColor[
              0.3552041377824924, 0.4809703145985687, 0.9438949648645372], 
             UndirectedEdge[72, 247] -> 
             RGBColor[
              0.6154478937421781, 0.6985426120193529, 0.9629684183842664], 
             UndirectedEdge[24, 254] -> 
             RGBColor[
              0.9234793483730712, 0.7829172870924861, 0.5955041038084421], 
             UndirectedEdge[247, 273] -> 
             RGBColor[
              0.598461668080708, 0.6848971683956518, 0.9615322412300882], 
             UndirectedEdge[80, 152] -> 
             RGBColor[
              0.26056294463292196`, 0.39119855382704327`, 0.9381500462772876],
              UndirectedEdge[121, 125] -> 
             RGBColor[
              0.9936176446660105, 0.9887571122327337, 0.5466981931057444], 
             UndirectedEdge[8, 177] -> 
             RGBColor[
              0.5355284607783559, 0.6327336001246429, 0.9569332103909327], 
             UndirectedEdge[38, 253] -> 
             RGBColor[
              0.35733483343099304`, 0.48281581607742285`, 0.9440307309071595],
              UndirectedEdge[134, 292] -> 
             RGBColor[
              0.2585311409306501, 0.3890629993121603, 0.9380343380622274], 
             UndirectedEdge[19, 177] -> 
             RGBColor[
              0.3552373943929633, 0.4804944703524481, 0.9439155616348212], 
             UndirectedEdge[219, 221] -> 
             RGBColor[
              0.28442417853057445`, 0.4162782235430855, 0.9395089082482266], 
             UndirectedEdge[37, 185] -> 
             RGBColor[
              0.6243865353648125, 0.7053567658918924, 0.9639747350674728], 
             UndirectedEdge[15, 280] -> 
             RGBColor[
              0.2534905697092152, 0.38376503936775813`, 0.9377472849880235], 
             UndirectedEdge[140, 171] -> 
             RGBColor[
              0.37321366033197056`, 0.49768064714073046`, 0.9450018223098395],
              UndirectedEdge[211, 221] -> 
             RGBColor[
              0.26848631667000333`, 0.39952652020881857`, 0.9386012705932207],
              UndirectedEdge[47, 273] -> 
             RGBColor[
              0.6309474410941337, 0.7112445284148133, 0.9641074535297975], 
             UndirectedEdge[58, 171] -> 
             RGBColor[
              0.48363824484440066`, 0.5907289672924857, 0.9527552354354336], 
             UndirectedEdge[75, 150] -> 
             RGBColor[
              0.8462593507356758, 0.8802930242051693, 0.9614859532696918], 
             UndirectedEdge[9, 167] -> 
             RGBColor[
              0.6353780576373289, 0.7131584853000028, 0.9656069359601525], 
             UndirectedEdge[135, 260] -> 
             RGBColor[
              0.9196247583457642, 0.9363642687580429, 0.8996385198821143], 
             UndirectedEdge[184, 202] -> 
             RGBColor[
              0.23277907926056368`, 0.361995949721885, 0.9365677962468772], 
             UndirectedEdge[166, 262] -> 
             RGBColor[
              0.9933514957949947, 0.9881878467094093, 0.5177295309761065], 
             UndirectedEdge[173, 276] -> 
             RGBColor[
              0.24447758470727698`, 0.3742918206744662, 0.9372340088256796], 
             UndirectedEdge[67, 86] -> 
             RGBColor[
              0.9435929630020026, 0.929903263270933, 0.6741823558912051], 
             UndirectedEdge[25, 272] -> 
             RGBColor[
              0.23754533151077184`, 0.36700558303470066`, 0.9368392272614883],
              UndirectedEdge[7, 174] -> 
             RGBColor[
              0.39353511961410004`, 0.5152820737846694, 0.9462966877257359], 
             UndirectedEdge[88, 113] -> 
             RGBColor[
              0.7318152240398965, 0.7888182862268713, 0.9538534747537719], 
             UndirectedEdge[147, 206] -> 
             RGBColor[
              0.23143319481245586`, 0.360581339832921, 0.9364911501186151], 
             UndirectedEdge[189, 211] -> 
             RGBColor[
              0.23710386113640347`, 0.3665415696804011, 0.9368140861767649], 
             UndirectedEdge[104, 209] -> 
             RGBColor[
              0.2751140822771375, 0.4064927220865271, 0.9389787120396467], 
             UndirectedEdge[151, 167] -> 
             RGBColor[
              0.5986000016649633, 0.6830276720672528, 0.9627869889383882], 
             UndirectedEdge[215, 274] -> 
             RGBColor[
              0.979839341035498, 0.9422049502369351, 0.5238492272566825], 
             UndirectedEdge[41, 261] -> 
             RGBColor[
              0.3788160778841355, 0.5025331796387221, 0.9453588034022401], 
             UndirectedEdge[157, 218] -> 
             RGBColor[
              0.30101158042666865`, 0.4302700565079032, 0.9405795858965723], 
             UndirectedEdge[187, 205] -> 
             RGBColor[
              0.44668815437293624`, 0.55925348518074, 0.950254691291311], 
             UndirectedEdge[62, 82] -> 
             RGBColor[
              0.9949627046124243, 0.9916340594516913, 0.6930996675251034], 
             UndirectedEdge[42, 144] -> 
             RGBColor[
              0.28507366633741316`, 0.4163170541357517, 0.9395694691052225], 
             UndirectedEdge[33, 150] -> 
             RGBColor[
              0.9383344799337505, 0.9529880672751867, 0.9704600672145196], 
             UndirectedEdge[34, 46] -> 
             RGBColor[
              0.30981865996121394`, 0.44123557275110054`, 0.9410185715382298],
              UndirectedEdge[220, 266] -> 
             RGBColor[
              0.2524128465615943, 0.3826322840080144, 0.9376859102491151], 
             UndirectedEdge[128, 279] -> 
             RGBColor[
              0.24902661375038676`, 0.3790731386238746, 0.9374930692999993], 
             UndirectedEdge[147, 270] -> 
             RGBColor[
              0.2272240069658551, 0.35615721652822, 0.9362514430976865], 
             UndirectedEdge[30, 90] -> 
             RGBColor[
              0.4328724368509469, 0.5491129570174318, 0.9488698500216755], 
             UndirectedEdge[36, 222] -> 
             RGBColor[
              0.5978519743815511, 0.6821400273622127, 0.9628407950842862], 
             UndirectedEdge[127, 170] -> 
             RGBColor[
              0.8291458764290967, 0.22503355480433335`, 0.17554343022504929`],
              UndirectedEdge[1, 295] -> 
             RGBColor[
              0.6279037208977163, 0.7050085996594103, 0.9661155178174292], 
             UndirectedEdge[96, 140] -> 
             RGBColor[
              0.36676996210044227`, 0.49209943960227065`, 0.9445912355564652],
              UndirectedEdge[206, 272] -> 
             RGBColor[
              0.22997704115109324`, 0.35905083000935434`, 0.9364082243217868],
              UndirectedEdge[129, 265] -> 
             RGBColor[
              0.22918762870603976`, 0.3582211074779632, 0.936363268450872], 
             UndirectedEdge[39, 60] -> 
             RGBColor[
              0.8870492908888172, 0.5758020624702928, 0.22724639341928574`], 
             UndirectedEdge[71, 240] -> 
             RGBColor[
              0.8122650553898112, 0.8508727945952284, 0.8269553066210207], 
             UndirectedEdge[30, 144] -> 
             RGBColor[
              0.3889539475617518, 0.5110729690025859, 0.9460714027197632], 
             UndirectedEdge[26, 59] -> 
             RGBColor[
              0.8838184335640263, 0.4982693458810795, 0.4141730352036101], 
             UndirectedEdge[133, 241] -> 
             RGBColor[
              0.3146112316266204, 0.4441789202710761, 0.9413681711410662], 
             UndirectedEdge[236, 266] -> 
             RGBColor[
              0.43542230214154953`, 0.5412994360038763, 0.9504471655773028], 
             UndirectedEdge[28, 216] -> 
             RGBColor[
              0.24112529640186797`, 0.3707683531181266, 0.9370431009659527], 
             UndirectedEdge[173, 230] -> 
             RGBColor[
              0.25326290395464024`, 0.3835257482248573, 0.9377343197601018], 
             UndirectedEdge[39, 266] -> 
             RGBColor[
              0.6608997924554822, 0.45345565956717576`, 0.45325684403677113`],
              UndirectedEdge[86, 141] -> 
             RGBColor[
              0.936935020626016, 0.7805800799358134, 0.2971516426609445], 
             UndirectedEdge[25, 206] -> 
             RGBColor[
              0.2442420605634609, 0.3740442698662223, 0.937220596074116], 
             UndirectedEdge[141, 165] -> 
             RGBColor[0.9396314058192, 0.789675620333774, 0.3076265899668467],
              UndirectedEdge[152, 241] -> 
             RGBColor[
              0.2661857597767988, 0.3971084890503288, 0.9384702572815218], 
             UndirectedEdge[110, 141] -> 
             RGBColor[
              0.9459742116007779, 0.8128132585241278, 0.5020022278511405], 
             UndirectedEdge[97, 134] -> 
             RGBColor[
              0.2657406017726479, 0.3966405997633186, 0.9384449061917377], 
             UndirectedEdge[103, 119] -> 
             RGBColor[
              0.28052080371187027`, 0.4121755291203697, 0.939286616826827], 
             UndirectedEdge[3, 17] -> 
             RGBColor[
              0.3367736481857078, 0.4649602471368852, 0.9427222930937296], 
             UndirectedEdge[203, 270] -> 
             RGBColor[
              0.2439246691349402, 0.37371067135106817`, 0.9372025211018002], 
             UndirectedEdge[51, 141] -> 
             RGBColor[
              0.9462822846437602, 0.812940654644517, 0.4968966602614467], 
             UndirectedEdge[184, 275] -> 
             RGBColor[
              0.22510784132218828`, 0.35393299226407493`, 0.9361309305948662],
              UndirectedEdge[58, 109] -> 
             RGBColor[
              0.7350459204207711, 0.7923292470470489, 0.9749877366110247], 
             UndirectedEdge[179, 281] -> 
             RGBColor[
              0.8885997879740133, 0.5160832735920328, 0.3731054797340321], 
             UndirectedEdge[31, 154] -> 
             RGBColor[
              0.6800184039631393, 0.7495944813404151, 0.9689878978887183], 
             UndirectedEdge[122, 296] -> 
             RGBColor[
              0.6602141631347492, 0.7342053053149373, 0.9669578999698369], 
             UndirectedEdge[96, 290] -> 
             RGBColor[
              0.5091973143554127, 0.6111290483156775, 0.9548640237887529], 
             UndirectedEdge[122, 240] -> 
             RGBColor[
              0.8095631527614308, 0.8486792683221828, 0.8267426029487193], 
             UndirectedEdge[97, 144] -> 
             RGBColor[
              0.28659496025462, 0.4179160304983415, 0.9396561045432549], 
             UndirectedEdge[61, 247] -> 
             RGBColor[
              0.5729638190353659, 0.6641968658756336, 0.9595249571515402], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.5867492116924276, 0.675169261254928, 0.9607600670587673], 
             UndirectedEdge[45, 287] -> 
             RGBColor[
              0.8855408645250941, 0.5648739230601991, 0.22579206001070665`], 
             UndirectedEdge[278, 290] -> 
             RGBColor[
              0.607930114483695, 0.6925840797342462, 0.9622776320149933], 
             UndirectedEdge[109, 110] -> 
             RGBColor[
              0.9570573175626281, 0.9656649471847494, 0.8794550171346109], 
             UndirectedEdge[56, 160] -> 
             RGBColor[
              0.5689561966042058, 0.6609432974446849, 0.9592094624333546], 
             UndirectedEdge[146, 292] -> 
             RGBColor[
              0.2367560409824719, 0.36617598864554746`, 0.9367942783335522], 
             UndirectedEdge[131, 139] -> 
             RGBColor[
              0.29015495986038786`, 0.4208144502573191, 0.9398897209981389], 
             UndirectedEdge[47, 74] -> 
             RGBColor[
              0.6411369333771564, 0.7195168172815674, 0.9649096076876572], 
             UndirectedEdge[46, 221] -> 
             RGBColor[
              0.2933757434234066, 0.4256868858074472, 0.9400186866262199], 
             UndirectedEdge[48, 74] -> 
             RGBColor[
              0.5259484891930979, 0.6249515173301565, 0.9561210914963576], 
             UndirectedEdge[90, 134] -> 
             RGBColor[
              0.3387736212750252, 0.46463798272782586`, 0.9429249564054306], 
             UndirectedEdge[1, 37] -> 
             RGBColor[
              0.5496127167377557, 0.6437072364180976, 0.9583493103043816], 
             UndirectedEdge[33, 295] -> 
             RGBColor[
              0.8759737184879801, 0.9039416817218939, 0.9880323493319954], 
             UndirectedEdge[28, 35] -> 
             RGBColor[
              0.2248219115083478, 0.35363246190073133`, 0.9361146473149633], 
             UndirectedEdge[21, 169] -> 
             RGBColor[
              0.33823987120783705`, 0.46593460012617627`, 0.9428265434669814],
              UndirectedEdge[100, 228] -> 
             RGBColor[
              0.8389013017243429, 0.5432933316125673, 0.4579004063189147], 
             UndirectedEdge[190, 250] -> 
             RGBColor[
              0.22535768471974588`, 0.35419559351589436`, 0.9361451588067469],
              UndirectedEdge[81, 180] -> 
             RGBColor[
              0.26493370488523493`, 0.3957924999744301, 0.9383989546076965], 
             UndirectedEdge[127, 141] -> 
             RGBColor[
              0.8548488786408825, 0.38002934597129234`, 0.19848976879691427`],
              UndirectedEdge[143, 185] -> 
             RGBColor[
              0.482410173529073, 0.5891453845161638, 0.9528206307321404], 
             UndirectedEdge[283, 295] -> 
             RGBColor[
              0.728003954304401, 0.7872192535932907, 0.973734730725687], 
             UndirectedEdge[26, 100] -> 
             RGBColor[
              0.8953985506349588, 0.587279200127923, 0.4252621683886066], 
             UndirectedEdge[242, 294] -> 
             RGBColor[
              0.22516497885926012`, 0.35399304743826654`, 0.9361341844930751],
              UndirectedEdge[39, 228] -> 
             RGBColor[
              0.8504695554217692, 0.6130701422171569, 0.46822863202688747`], 
             UndirectedEdge[39, 82] -> 
             RGBColor[
              0.9100473663399253, 0.6582118152602212, 0.3759538289568961], 
             UndirectedEdge[109, 258] -> 
             RGBColor[
              0.941467846616602, 0.9554926988601389, 0.9709728498600104], 
             UndirectedEdge[118, 199] -> 
             RGBColor[
              0.17892828448197629`, 0.3053953500719979, 0.9335010731493483], 
             UndirectedEdge[57, 115] -> 
             RGBColor[
              0.2343221600487206, 0.3636178254672108, 0.9366556724149793], 
             UndirectedEdge[96, 222] -> 
             RGBColor[
              0.4207992950730278, 0.5388969322298897, 0.948033936877215], 
             UndirectedEdge[6, 108] -> 
             RGBColor[
              0.32479673840417583`, 0.4554602283068521, 0.9419271416840078], 
             UndirectedEdge[1, 9] -> 
             RGBColor[
              0.46767615866135254`, 0.5777748250387542, 0.9514973709902432], 
             UndirectedEdge[180, 190] -> 
             RGBColor[
              0.23107912024585836`, 0.36020918501380295`, 0.9364709860958538],
              UndirectedEdge[144, 253] -> 
             RGBColor[
              0.30621743066907636`, 0.4385404910404173, 0.9407735752045145], 
             UndirectedEdge[53, 192] -> 
             RGBColor[
              0.8428147922031168, 0.3231981316717255, 0.18836258531968136`], 
             UndirectedEdge[85, 121] -> 
             RGBColor[
              0.9571178936575444, 0.9648142409538079, 0.8234596411130128], 
             UndirectedEdge[36, 278] -> 
             RGBColor[
              0.681251390228536, 0.7503140519946241, 0.9692773736229017], 
             UndirectedEdge[122, 207] -> 
             RGBColor[
              0.6848905103681076, 0.7534826553208219, 0.9694174076484823], 
             UndirectedEdge[226, 228] -> 
             RGBColor[
              0.4976351265701356, 0.5809234118204025, 0.9579150619705263], 
             UndirectedEdge[7, 143] -> 
             RGBColor[
              0.3957483991962868, 0.5171991053160931, 0.9464377159435866], 
             UndirectedEdge[133, 164] -> 
             RGBColor[
              0.36703566028493084`, 0.49232957401529565`, 0.9446081656098331],
              UndirectedEdge[7, 131] -> 
             RGBColor[
              0.359788981914124, 0.4860528654391481, 0.9441464136720313], 
             UndirectedEdge[111, 280] -> 
             RGBColor[
              0.2555363699026189, 0.38591530508224947`, 0.9378637902825477], 
             UndirectedEdge[135, 224] -> 
             RGBColor[
              0.9798102252026126, 0.9495170954171317, 0.5749562479700403], 
             UndirectedEdge[91, 102] -> 
             RGBColor[
              0.3289676178309032, 0.4560161547537128, 0.9423048264494448], 
             UndirectedEdge[200, 282] -> 
             RGBColor[
              0.9248264998510323, 0.7738160826625009, 0.5864939522963153], 
             UndirectedEdge[106, 194] -> 
             RGBColor[
              0.5862509789073218, 0.6747647734348481, 0.960720844348837], 
             UndirectedEdge[38, 259] -> 
             RGBColor[
              0.44110257276703263`, 0.5561854868751561, 0.949409740030642], 
             UndirectedEdge[36, 69] -> 
             RGBColor[
              0.8763046392583498, 0.8998097230462532, 0.7301395316538027], 
             UndirectedEdge[64, 153] -> 
             RGBColor[
              0.253568524812987, 0.38384697512446136`, 0.9377517244158591], 
             UndirectedEdge[159, 175] -> 
             RGBColor[
              0.2709524595475128, 0.4021185927355705, 0.9387417137817635], 
             UndirectedEdge[94, 200] -> 
             RGBColor[
              0.8739725410077492, 0.7339874771388775, 0.6066396220475212], 
             UndirectedEdge[88, 201] -> 
             RGBColor[
              0.41266709907445764`, 0.5304710926638055, 0.9478976499747094], 
             UndirectedEdge[121, 232] -> 
             RGBColor[
              0.9943533317427773, 0.9903306725005643, 0.626773191277452], 
             UndirectedEdge[140, 289] -> 
             RGBColor[
              0.3095286406957365, 0.4408775980939844, 0.9410040013062702], 
             UndirectedEdge[139, 244] -> 
             RGBColor[
              0.2489949569451404, 0.37903986531440326`, 0.9374912664917726], 
             UndirectedEdge[167, 174] -> 
             RGBColor[
              0.5731249742958058, 0.6609624837721939, 0.9611637427211077], 
             UndirectedEdge[185, 282] -> 
             RGBColor[
              0.7658636697865162, 0.8163200733980329, 0.9527715263482667], 
             UndirectedEdge[236, 249] -> 
             RGBColor[
              0.7534568620418187, 0.33087607040572803`, 0.43144386013194813`],
              UndirectedEdge[137, 299] -> 
             RGBColor[
              0.8952056536615587, 0.5648273491635555, 0.37453465249341855`], 
             UndirectedEdge[201, 218] -> 
             RGBColor[
              0.2885778810548669, 0.4195006110479498, 0.9397873215672898], 
             UndirectedEdge[36, 109] -> 
             RGBColor[
              0.8403699639081523, 0.8760405078690783, 0.9845068533256267], 
             UndirectedEdge[4, 52] -> 
             RGBColor[
              0.7250122591035142, 0.3037872628161848, 0.42869370576776544`], 
             UndirectedEdge[5, 191] -> 
             RGBColor[
              0.23242398209380136`, 0.36162272008515706`, 0.9365475739885493],
              UndirectedEdge[55, 134] -> 
             RGBColor[
              0.27534778812989436`, 0.40673836175558137`, 0.9389920212422243],
              UndirectedEdge[67, 69] -> 
             RGBColor[
              0.9526781701718614, 0.9602196098814508, 0.7375536853224871], 
             UndirectedEdge[232, 256] -> 
             RGBColor[
              0.9946722576480922, 0.9910128227636774, 0.6614863078884357], 
             UndirectedEdge[185, 237] -> 
             RGBColor[
              0.6034248054489583, 0.6889264668979879, 0.961922957584288], 
             UndirectedEdge[28, 211] -> 
             RGBColor[
              0.2328859592843117, 0.3621082874034291, 0.9365738829061148], 
             UndirectedEdge[85, 246] -> 
             RGBColor[
              0.759246790508393, 0.811987768878119, 0.9768800667488129], 
             UndirectedEdge[26, 127] -> 
             RGBColor[
              0.8837930596964858, 0.49807431121626294`, 0.4141487371593976], 
             UndirectedEdge[91, 162] -> 
             RGBColor[
              0.27856959341816107`, 0.4101246833878033, 0.9391754982871572], 
             UndirectedEdge[112, 242] -> 
             RGBColor[
              0.24632291686669305`, 0.37623138177482907`, 0.937339097762234], 
             UndirectedEdge[85, 122] -> 
             RGBColor[
              0.7719092053781459, 0.8222676877046737, 0.9778768984313139], 
             UndirectedEdge[63, 131] -> 
             RGBColor[
              0.32467225096411007`, 0.4556365181084638, 0.9419088066284024], 
             UndirectedEdge[140, 222] -> 
             RGBColor[
              0.3821033463817397, 0.505380446388428, 0.94556826524409], 
             UndirectedEdge[121, 256] -> 
             RGBColor[
              0.9949290492403844, 0.9915620740139779, 0.6894364879754314], 
             UndirectedEdge[171, 198] -> 
             RGBColor[
              0.4413043319504303, 0.556360389684118, 0.9494225547381876], 
             UndirectedEdge[10, 117] -> 
             RGBColor[
              0.20745354842489078`, 0.3353772110821952, 0.935125544731551], 
             UndirectedEdge[18, 290] -> 
             RGBColor[
              0.7796647191738186, 0.8280942483803853, 0.9691424595790514], 
             UndirectedEdge[207, 240] -> 
             RGBColor[
              0.870260916353266, 0.8963751063904083, 0.8326021245961515], 
             UndirectedEdge[219, 264] -> 
             RGBColor[
              0.28444814998044265`, 0.4163034190567747, 0.9395102733868341], 
             UndirectedEdge[78, 118] -> 
             RGBColor[
              0.17948494456776543`, 0.30598043511645023`, 0.9335327741177293],
              UndirectedEdge[2, 208] -> 
             RGBColor[
              0.2583585282715436, 0.3888815724631647, 0.9380245080266488], 
             UndirectedEdge[34, 169] -> 
             RGBColor[
              0.3102621246711287, 0.4417016822785076, 0.9410438261974121], 
             UndirectedEdge[35, 275] -> 
             RGBColor[
              0.21950487592715945`, 0.34804392038537546`, 0.9358118500044639],
              UndirectedEdge[157, 284] -> 
             RGBColor[
              0.3008123283039969, 0.4300606298936609, 0.9405682387829533], 
             UndirectedEdge[30, 259] -> 
             RGBColor[
              0.46322962709906557`, 0.5751097053927338, 0.9508862795927249], 
             UndirectedEdge[62, 192] -> 
             RGBColor[
              0.9082736695622077, 0.6503403680458439, 0.3662671819702616], 
             UndirectedEdge[95, 245] -> 
             RGBColor[
              0.4565245648697137, 0.5688811135099974, 0.9505753636122101], 
             UndirectedEdge[129, 230] -> 
             RGBColor[
              0.2426308084736596, 0.3723507417605582, 0.9371288376512357], 
             UndirectedEdge[35, 92] -> 
             RGBColor[
              0.24366421330036392`, 0.37343691575507476`, 0.9371876885273311],
              UndirectedEdge[186, 279] -> 
             RGBColor[
              0.24438086405288187`, 0.3741901611342533, 0.9372285007274972], 
             UndirectedEdge[217, 233] -> 
             RGBColor[
              0.9005620992858752, 0.9194729557138646, 0.7896746116293041], 
             UndirectedEdge[28, 293] -> 
             RGBColor[
              0.21633697828784162`, 0.3447142591101412, 0.9356314429203892], 
             UndirectedEdge[24, 233] -> 
             RGBColor[
              0.9748626422338834, 0.9780993949460502, 0.7789636593832132], 
             UndirectedEdge[41, 229] -> 
             RGBColor[
              0.35168976097882576`, 0.47903772734367334`, 0.943630338475894], 
             UndirectedEdge[197, 214] -> 
             RGBColor[
              0.21169118846890916`, 0.33983123945035565`, 0.9353668720630313],
              UndirectedEdge[84, 144] -> 
             RGBColor[
              0.30816373722776935`, 0.4405861826365669, 0.9408844144837296], 
             UndirectedEdge[101, 205] -> 
             RGBColor[
              0.5380185348092877, 0.6358267098737893, 0.9567739363684693], 
             UndirectedEdge[7, 297] -> 
             RGBColor[
              0.5775728899214854, 0.6645401478372637, 0.9615635093646839], 
             UndirectedEdge[30, 47] -> 
             RGBColor[
              0.5531290988592262, 0.6480680925121483, 0.9579813085710855], 
             UndirectedEdge[140, 298] -> 
             RGBColor[
              0.3066630469664905, 0.4378656773954105, 0.9408408099826556], 
             UndirectedEdge[159, 252] -> 
             RGBColor[
              0.2739625179017606, 0.4052823549146075, 0.9389131321520556], 
             UndirectedEdge[26, 195] -> 
             RGBColor[
              0.8747075015471222, 0.4282387299632868, 0.4054483964148967], 
             UndirectedEdge[43, 185] -> 
             RGBColor[
              0.4451220207260428, 0.5568482607152324, 0.9504446626081502], 
             UndirectedEdge[36, 95] -> 
             RGBColor[
              0.6241088885700935, 0.7039231949079366, 0.9647789065724686], 
             UndirectedEdge[6, 46] -> 
             RGBColor[
              0.29890559173213627`, 0.4314991069925552, 0.9403336033067247], 
             UndirectedEdge[148, 183] -> 
             RGBColor[
              0.2467014884994484, 0.37662928456368283`, 0.937360656856673], 
             UndirectedEdge[222, 261] -> 
             RGBColor[
              0.41838703187400994`, 0.5368075510907742, 0.9478802295992542], 
             UndirectedEdge[64, 145] -> 
             RGBColor[
              0.2514296244944172, 0.3815988552755316, 0.937629917206936], 
             UndirectedEdge[8, 247] -> 
             RGBColor[
              0.6154687668637716, 0.6985589182605833, 0.9629704988219563], 
             UndirectedEdge[122, 136] -> 
             RGBColor[
              0.8085502082780569, 0.8465126824966431, 0.7164898471021924], 
             UndirectedEdge[139, 206] -> 
             RGBColor[
              0.2460762386198535, 0.3759721072970965, 0.9373250498010044], 
             UndirectedEdge[65, 80] -> 
             RGBColor[
              0.27787319023653523`, 0.40939271948940265`, 0.9391358391561999],
              UndirectedEdge[171, 245] -> 
             RGBColor[
              0.4213779646314022, 0.5393981467165758, 0.9480708091897773], 
             UndirectedEdge[137, 232] -> 
             RGBColor[
              0.8950763177198054, 0.5640920785488474, 0.32711937496304067`], 
             UndirectedEdge[64, 221] -> 
             RGBColor[
              0.26413437920159183`, 0.3949523580007457, 0.9383534341925093], 
             UndirectedEdge[140, 263] -> 
             RGBColor[
              0.2945287893227776, 0.42511180325549774`, 0.9401497819608717], 
             UndirectedEdge[200, 295] -> 
             RGBColor[
              0.8616403695892892, 0.7241541383976731, 0.6054633685285691], 
             UndirectedEdge[136, 232] -> 
             RGBColor[
              0.9935021049651632, 0.9885099844954769, 0.5341224096968956], 
             UndirectedEdge[45, 68] -> 
             RGBColor[
              0.8633379334396346, 0.4711124376416033, 0.20763043303961218`], 
             UndirectedEdge[224, 254] -> 
             RGBColor[
              0.9304233123934045, 0.7541309251793602, 0.28356918675006826`], 
             UndirectedEdge[148, 272] -> 
             RGBColor[
              0.23104689889957378`, 0.3601753183359065, 0.93646915113785], 
             UndirectedEdge[167, 185] -> 
             RGBColor[
              0.660998380157889, 0.7339582173045702, 0.9676238615993047], 
             UndirectedEdge[59, 137] -> 
             RGBColor[
              0.8370621725153026, 0.28588167546597704`, 0.1831240842973778], 
             UndirectedEdge[55, 97] -> 
             RGBColor[
              0.26708761639868417`, 0.39805639754094285`, 0.9385216166819608],
              UndirectedEdge[156, 202] -> 
             RGBColor[
              0.22791002753873152`, 0.3568782676465297, 0.9362905109544353], 
             UndirectedEdge[78, 176] -> 
             RGBColor[
              0.17949609924511575`, 0.30599215938959284`, 0.9335334093601024],
              UndirectedEdge[131, 143] -> 
             RGBColor[
              0.3607906299670138, 0.4869204426382663, 0.9442102378002388], 
             UndirectedEdge[230, 289] -> 
             RGBColor[
              0.27016772610159867`, 0.4012937881289406, 0.9386970243729278], 
             UndirectedEdge[35, 126] -> 
             RGBColor[
              0.2260848753293333, 0.35495991695311835`, 0.9361865712361809], 
             UndirectedEdge[147, 183] -> 
             RGBColor[
              0.24039105535964145`, 0.36999661922917565`, 0.9370012870248101],
              UndirectedEdge[66, 258] -> 
             RGBColor[
              0.9541114545413159, 0.9652969784492861, 0.9625615171988029], 
             UndirectedEdge[60, 232] -> 
             RGBColor[
              0.9600894947352094, 0.8672149974535253, 0.4291027093633025], 
             UndirectedEdge[39, 127] -> 
             RGBColor[
              0.8559458393553094, 0.41188795711892084`, 0.20045755789226324`],
              UndirectedEdge[113, 258] -> 
             RGBColor[
              0.9605881616295711, 0.9701272959910724, 0.9515981414941335], 
             UndirectedEdge[45, 223] -> 
             RGBColor[
              0.8676674520716839, 0.4907717705649724, 0.21124308951240708`], 
             UndirectedEdge[40, 80] -> 
             RGBColor[
              0.25252112623098183`, 0.38274609280586824`, 0.9376920766161012],
              UndirectedEdge[18, 198] -> 
             RGBColor[
              0.7053280385373079, 0.7677443822103661, 0.9632904037751118], 
             UndirectedEdge[13, 58] -> 
             RGBColor[
              0.4275257850964924, 0.5418851588163979, 0.949188660514906], 
             UndirectedEdge[16, 195] -> 
             RGBColor[
              0.8772526257012466, 0.4282492870636099, 0.2875327252702875], 
             UndirectedEdge[17, 90] -> 
             RGBColor[
              0.3498844311553243, 0.4763161483780546, 0.9435577005911434], 
             UndirectedEdge[8, 273] -> 
             RGBColor[
              0.6348421879085798, 0.7142871342274307, 0.9644956454937833], 
             UndirectedEdge[85, 256] -> 
             RGBColor[
              0.9574368195628593, 0.965496391216921, 0.8581727577239964], 
             UndirectedEdge[149, 227] -> 
             RGBColor[
              0.27685707898321577`, 0.40832472213698934`, 0.9390779731235251],
              UndirectedEdge[182, 208] -> 
             RGBColor[
              0.2965714316502459, 0.42904575675219153`, 0.9402006763431414], 
             UndirectedEdge[82, 100] -> 
             RGBColor[
              0.898479112642499, 0.5884350046556317, 0.36562560324892335`], 
             UndirectedEdge[227, 264] -> 
             RGBColor[
              0.2772132461146813, 0.4086990763744601, 0.9390982563147601], 
             UndirectedEdge[74, 259] -> 
             RGBColor[
              0.5512374616169957, 0.646558430162153, 0.9578145787092965], 
             UndirectedEdge[96, 105] -> 
             RGBColor[
              0.3473181215020726, 0.473441328714978, 0.9434180509343462], 
             UndirectedEdge[60, 100] -> 
             RGBColor[
              0.875481037191391, 0.5060252518657031, 0.21691816771131295`], 
             UndirectedEdge[73, 87] -> 
             RGBColor[
              0.3025587103322468, 0.4334652095438001, 0.9406102430960075], 
             UndirectedEdge[68, 223] -> 
             RGBColor[
              0.880860495472638, 0.5518971603270344, 0.22229941585693147`], 
             UndirectedEdge[162, 191] -> 
             RGBColor[
              0.26420786908525307`, 0.39502960052800135`, 0.9383576193326653],
              UndirectedEdge[87, 149] -> 
             RGBColor[
              0.2850281329082009, 0.41691301788689017`, 0.939543302556562], 
             UndirectedEdge[60, 256] -> 
             RGBColor[
              0.9606652122328164, 0.8684463989669389, 0.49176600606128196`], 
             UndirectedEdge[145, 169] -> 
             RGBColor[
              0.28111445342614677`, 0.4127994926096401, 0.939320424299829], 
             UndirectedEdge[144, 235] -> 
             RGBColor[
              0.27887432985742466`, 0.4098011584346488, 0.9392164260637837], 
             UndirectedEdge[36, 88] -> 
             RGBColor[
              0.6318962145275521, 0.7102452969352381, 0.9653919533977545], 
             UndirectedEdge[38, 123] -> 
             RGBColor[
              0.4270824703910924, 0.5443391028888234, 0.9484342952524883], 
             UndirectedEdge[183, 244] -> 
             RGBColor[
              0.24855034907625476`, 0.37857255425443737`, 0.937465946731378], 
             UndirectedEdge[2, 32] -> 
             RGBColor[
              0.24350738500413596`, 0.3732720792722509, 0.9371787573878676], 
             UndirectedEdge[106, 151] -> 
             RGBColor[
              0.5499711557200619, 0.645038448022178, 0.9579401200370031], 
             UndirectedEdge[164, 277] -> 
             RGBColor[
              0.36650966152605724`, 0.4918739803278257, 0.94457464943404], 
             UndirectedEdge[296, 299] -> 
             RGBColor[
              0.8453600637344856, 0.8773055132358333, 0.8557133788601069], 
             UndirectedEdge[75, 174] -> 
             RGBColor[
              0.5614179437120186, 0.6518168625034114, 0.9599968953209368], 
             UndirectedEdge[31, 66] -> 
             RGBColor[
              0.7826462994682315, 0.8305130082182347, 0.9693283290234715], 
             UndirectedEdge[2, 268] -> 
             RGBColor[
              0.2466368287086141, 0.37656132302384837`, 0.9373569745772405], 
             UndirectedEdge[46, 264] -> 
             RGBColor[
              0.29339971487327476`, 0.42571208132113636`, 0.9400200517648274],
              UndirectedEdge[71, 160] -> 
             RGBColor[
              0.6099082730566356, 0.6941900379787878, 0.9624333599040888], 
             UndirectedEdge[50, 114] -> 
             RGBColor[
              0.32843011888336315`, 0.4584906115476223, 0.9421629292736595], 
             UndirectedEdge[126, 197] -> 
             RGBColor[
              0.21821940668747852`, 0.34669281071101354`, 0.9357386444329454],
              UndirectedEdge[265, 269] -> 
             RGBColor[
              0.2247455605611441, 0.35355221221429056`, 0.9361102992414712], 
             UndirectedEdge[144, 257] -> 
             RGBColor[
              0.3535074058070181, 0.4806120799363681, 0.9437461571970662], 
             UndirectedEdge[86, 107] -> 
             RGBColor[
              0.8810538793284779, 0.48461124450096366`, 0.2391769486117305], 
             UndirectedEdge[149, 245] -> 
             RGBColor[
              0.3591757955739624, 0.4841536676462995, 0.9441574343329895], 
             UndirectedEdge[143, 283] -> 
             RGBColor[
              0.5077365883087008, 0.6097065089762495, 0.9548144188773069], 
             UndirectedEdge[66, 154] -> 
             RGBColor[
              0.8438279787518632, 0.8786689323302527, 0.9751799865903525], 
             UndirectedEdge[57, 159] -> 
             RGBColor[
              0.24722335585304894`, 0.3771778002406183, 0.937390376430427], 
             UndirectedEdge[7, 167] -> 
             RGBColor[
              0.5743366058251028, 0.6620119381044995, 0.9612409468107508], 
             UndirectedEdge[57, 89] -> 
             RGBColor[
              0.26259271630004477`, 0.3933319725441461, 0.9382656387709521], 
             UndirectedEdge[122, 256] -> 
             RGBColor[
              0.8097203609609858, 0.8490155207648438, 0.8438537452937325], 
             UndirectedEdge[39, 232] -> 
             RGBColor[
              0.9097206544990011, 0.6575130116681185, 0.3403932613040548], 
             UndirectedEdge[72, 286] -> 
             RGBColor[
              0.6054217047226151, 0.6904029000986035, 0.9621791200575058], 
             UndirectedEdge[71, 299] -> 
             RGBColor[
              0.812040550004389, 0.8510805514465378, 0.8525260685636215], 
             UndirectedEdge[90, 158] -> 
             RGBColor[
              0.4035892626740157, 0.5239904671672448, 0.9469373288309841], 
             UndirectedEdge[52, 236] -> 
             RGBColor[
              0.752875562549565, 0.3264079477812045, 0.43088720708168204`], 
             UndirectedEdge[17, 134] -> 
             RGBColor[
              0.2851115833841571, 0.4170007296281859, 0.9395480549377139], 
             UndirectedEdge[54, 72] -> 
             RGBColor[
              0.534606977221836, 0.6319372303906756, 0.9568737438527076], 
             UndirectedEdge[170, 192] -> 
             RGBColor[
              0.836257672421485, 0.2727972356818921, 0.182083480011583], 
             UndirectedEdge[140, 198] -> 
             RGBColor[
              0.3961646850276139, 0.5172626963041967, 0.9465462963516883], 
             UndirectedEdge[19, 89] -> 
             RGBColor[
              0.28469980544749635`, 0.41656792490852634`, 0.9395246047933918],
              UndirectedEdge[239, 295] -> 
             RGBColor[
              0.6242095261484855, 0.7018088738432534, 0.9658801269946564], 
             UndirectedEdge[51, 69] -> 
             RGBColor[
              0.9933000659558078, 0.9895615584823135, 0.6199821278730931], 
             UndirectedEdge[186, 269] -> 
             RGBColor[
              0.2284972047762287, 0.3574954281523263, 0.93632394982946], 
             UndirectedEdge[37, 282] -> 
             RGBColor[
              0.8221799053423591, 0.8614527527728091, 0.9576065400232527], 
             UndirectedEdge[1, 239] -> 
             RGBColor[
              0.4148284678056251, 0.5337253017533699, 0.9476534810435313], 
             UndirectedEdge[59, 200] -> 
             RGBColor[
              0.850538756993148, 0.3605379080819481, 0.19489642311046151`], 
             UndirectedEdge[145, 221] -> 
             RGBColor[
              0.2819086057959276, 0.4136341971024482, 0.9393656501024449], 
             UndirectedEdge[75, 297] -> 
             RGBColor[
              0.7454557140194038, 0.8010749365560057, 0.9752637169598848], 
             UndirectedEdge[142, 185] -> 
             RGBColor[
              0.6135470246958941, 0.696888857774001, 0.9628943539449815], 
             UndirectedEdge[36, 258] -> 
             RGBColor[
              0.8606691521172266, 0.8915543066994391, 0.9631366201381162], 
             UndirectedEdge[13, 289] -> 
             RGBColor[
              0.2985558278706446, 0.4311314829978179, 0.940313684772242], 
             UndirectedEdge[53, 170] -> 
             RGBColor[
              0.8284505596301013, 0.21968904519749122`, 0.17487759407308337`],
              UndirectedEdge[130, 226] -> 
             RGBColor[
              0.178927005110741, 0.3053940053717128, 0.9335010002910491], 
             UndirectedEdge[224, 249] -> 
             RGBColor[
              0.8688948831013429, 0.39883351601253714`, 0.22232023481210886`],
              UndirectedEdge[234, 271] -> 
             RGBColor[
              0.8707009818902876, 0.40130003721491675`, 0.23179733287652443`],
              UndirectedEdge[78, 266] -> 
             RGBColor[
              0.21383713709575333`, 0.3420867675181703, 0.9354890806626834], 
             UndirectedEdge[127, 232] -> 
             RGBColor[
              0.8865469098631019, 0.4985313121518687, 0.318951604366873], 
             UndirectedEdge[57, 292] -> 
             RGBColor[
              0.2450572419916986, 0.37490107723278787`, 0.9372670194505013], 
             UndirectedEdge[52, 107] -> 
             RGBColor[
              0.8231876863313796, 0.17923629481773212`, 0.16983786065866233`],
              UndirectedEdge[26, 130] -> 
             RGBColor[
              0.5823809948253185, 0.6469022092217233, 0.9089577047840149], 
             UndirectedEdge[51, 58] -> 
             RGBColor[
              0.7712426526188537, 0.8181426903224094, 0.8569941031084208], 
             UndirectedEdge[192, 195] -> 
             RGBColor[
              0.8497053442101324, 0.36926123432797614`, 0.19469077161596268`],
              UndirectedEdge[118, 266] -> 
             RGBColor[
              0.21328176149194045`, 0.3415030325457159, 0.9354574528436509], 
             UndirectedEdge[171, 289] -> 
             RGBColor[
              0.35466828761855285`, 0.4799752914739057, 0.9438802596927696], 
             UndirectedEdge[1, 283] -> 
             RGBColor[
              0.5186228959615405, 0.619135681503407, 0.955508084774562], 
             UndirectedEdge[44, 59] -> 
             RGBColor[
              0.8768918584348492, 0.4667276538414726, 0.225617141924977], 
             UndirectedEdge[62, 127] -> 
             RGBColor[
              0.8867976409968038, 0.49906760069405076`, 0.3462421409371299], 
             UndirectedEdge[46, 219] -> 
             RGBColor[
              0.2831865614508789, 0.4149774095228705, 0.9394384277864284], 
             UndirectedEdge[55, 252] -> 
             RGBColor[
              0.2886130512396545, 0.4206809943501981, 0.9397474583521269], 
             UndirectedEdge[55, 144] -> 
             RGBColor[
              0.2962021466118664, 0.42801379249060423`, 0.9402032195937415], 
             UndirectedEdge[160, 296] -> 
             RGBColor[
              0.6432277867867322, 0.7204149997680831, 0.9656206702005743], 
             UndirectedEdge[154, 179] -> 
             RGBColor[
              0.8674233288276321, 0.8946955574709121, 0.8648978949263142], 
             UndirectedEdge[6, 145] -> 
             RGBColor[
              0.2874384541046572, 0.41944641828755624`, 0.9396805667829495], 
             UndirectedEdge[132, 243] -> 
             RGBColor[
              0.21243933131542342`, 0.34061758501703826`, 0.935409477691362], 
             UndirectedEdge[53, 59] -> 
             RGBColor[
              0.8320894648541852, 0.2476592653282373, 0.1783622138252218], 
             UndirectedEdge[4, 228] -> 
             RGBColor[
              0.6779819914219037, 0.7467901325313183, 0.9696145955916023], 
             UndirectedEdge[71, 98] -> 
             RGBColor[
              0.5262018737865255, 0.625404972246536, 0.9560725859325541], 
             UndirectedEdge[201, 259] -> 
             RGBColor[
              0.3926869440225089, 0.5142503026969059, 0.9463247389793005], 
             UndirectedEdge[34, 187] -> 
             RGBColor[
              0.34571434459052375`, 0.47386212200128636`, 0.9432495902274847],
              UndirectedEdge[18, 260] -> 
             RGBColor[
              0.8977772500782942, 0.9210512580678571, 0.980544009200409], 
             UndirectedEdge[263, 289] -> 
             RGBColor[
              0.27598341660935993`, 0.40740644758867306`, 0.9390282193438018],
              UndirectedEdge[173, 209] -> 
             RGBColor[
              0.2611649721580388, 0.3918313229266909, 0.938184330854223], 
             UndirectedEdge[4, 199] -> 
             RGBColor[
              0.3592738699625091, 0.4712607260826286, 0.9452005339121252], 
             UndirectedEdge[253, 292] -> 
             RGBColor[
              0.26989343961389634`, 0.40100549563959764`, 0.9386814041632237],
              UndirectedEdge[128, 209] -> 
             RGBColor[
              0.25220846656924684`, 0.38241746767761725`, 0.9376742711109041],
              UndirectedEdge[44, 137] -> 
             RGBColor[
              0.8853958924240121, 0.5320933855736346, 0.23376061447693208`], 
             UndirectedEdge[129, 263] -> 
             RGBColor[
              0.24844649898142085`, 0.37846340122029065`, 0.9374600326221096],
              UndirectedEdge[73, 289] -> 
             RGBColor[
              0.309996695985159, 0.44128300406053933`, 0.9410338253754271], 
             UndirectedEdge[128, 276] -> 
             RGBColor[
              0.235521079118485, 0.3648779654253926, 0.9367239490823606], 
             UndirectedEdge[96, 196] -> 
             RGBColor[
              0.34319916551880214`, 0.4691120448196677, 0.9431834824845483], 
             UndirectedEdge[24, 224] -> 
             RGBColor[
              0.9625807494214099, 0.9376482057938698, 0.6480446128648567], 
             UndirectedEdge[88, 278] -> 
             RGBColor[
              0.553576335347311, 0.6484572332214837, 0.9579987034169237], 
             UndirectedEdge[158, 253] -> 
             RGBColor[
              0.35017871358609476`, 0.47661754474481344`, 0.9435747492785509],
              UndirectedEdge[67, 110] -> 
             RGBColor[
              0.9526321539767644, 0.9621364418592473, 0.8790329410814011], 
             UndirectedEdge[155, 275] -> 
             RGBColor[
              0.21254067958734837`, 0.340724108476683, 0.9354152493255168], 
             UndirectedEdge[101, 108] -> 
             RGBColor[
              0.44525533808141193`, 0.5575469670447641, 0.9502920083081179], 
             UndirectedEdge[102, 210] -> 
             RGBColor[
              0.3819399405336581, 0.5052389124558365, 0.9455578531679444], 
             UndirectedEdge[176, 199] -> 
             RGBColor[
              0.17893943915932659`, 0.3054070743451405, 0.9335017083917216], 
             UndirectedEdge[62, 226] -> 
             RGBColor[
              0.5868878718865363, 0.6483921488101179, 0.8070978107416625], 
             UndirectedEdge[69, 113] -> 
             RGBColor[
              0.9762236487706943, 0.9783827123378863, 0.71860105300982], 
             UndirectedEdge[51, 258] -> 
             RGBColor[
              0.9776645788146846, 0.9813061421354996, 0.8529792163574066], 
             UndirectedEdge[30, 74] -> 
             RGBColor[
              0.5502062391736314, 0.6457212373265883, 0.9577333971010626], 
             UndirectedEdge[118, 228] -> 
             RGBColor[
              0.49763640594137093`, 0.5809247565206876, 0.9579151348288255], 
             UndirectedEdge[71, 121] -> 
             RGBColor[
              0.8121033376840514, 0.8505268967747761, 0.8093533323550504], 
             UndirectedEdge[1, 20] -> 
             RGBColor[
              0.6422142592503285, 0.7164194344925677, 0.9674804697406698], 
             UndirectedEdge[126, 293] -> 
             RGBColor[
              0.21759994210882713`, 0.34604171416252816`, 0.9357033668416068],
              UndirectedEdge[112, 159] -> 
             RGBColor[
              0.24980358255219737`, 0.3798897820972448, 0.9375373165238401], 
             UndirectedEdge[17, 159] -> 
             RGBColor[
              0.2718080646722995, 0.4030178879702195, 0.9387904392278659], 
             UndirectedEdge[139, 172] -> 
             RGBColor[
              0.26248705403553485`, 0.3932209148047717, 0.9382596214613016], 
             UndirectedEdge[47, 233] -> 
             RGBColor[
              0.8190741460647206, 0.8558139473261162, 0.781552654000438], 
             UndirectedEdge[98, 182] -> 
             RGBColor[
              0.3649951509133196, 0.4904176871542194, 0.9444834370172861], 
             UndirectedEdge[84, 159] -> 
             RGBColor[
              0.27400586003393973`, 0.4053279102435776, 0.9389156004223643], 
             UndirectedEdge[118, 176] -> 
             RGBColor[
              0.17894072364130287`, 0.30540842441713845`, 0.9335017815410699],
              UndirectedEdge[18, 278] -> 
             RGBColor[
              0.7746661157384185, 0.8240361569270088, 0.968748951206129], 
             UndirectedEdge[155, 197] -> 
             RGBColor[
              0.21140151230331092`, 0.3395267714337822, 0.9353503754339378], 
             UndirectedEdge[72, 215] -> 
             RGBColor[
              0.8234553846620669, 0.8600796725778928, 0.8483727211925696], 
             UndirectedEdge[162, 239] -> 
             RGBColor[
              0.34783050852175984`, 0.47345580113907954`, 0.9434664197100019],
              UndirectedEdge[139, 272] -> 
             RGBColor[
              0.23937950956716447`, 0.3689334204655748, 0.9369436809883765], 
             UndirectedEdge[9, 75] -> 
             RGBColor[
              0.6236710270535416, 0.7040128640312203, 0.9644400885599815], 
             UndirectedEdge[18, 254] -> 
             RGBColor[
              0.918861315886804, 0.779473166025562, 0.6033212282319205], 
             UndirectedEdge[25, 244] -> 
             RGBColor[
              0.2471607788887478, 0.37711202788352904`, 0.9373868127648843], 
             UndirectedEdge[30, 257] -> 
             RGBColor[
              0.42675186290096767`, 0.5438116234909512, 0.9484798524617939], 
             UndirectedEdge[29, 270] -> 
             RGBColor[
              0.2355391750470839, 0.3648969853936982, 0.9367249796187237], 
             UndirectedEdge[73, 298] -> 
             RGBColor[
              0.307131102255913, 0.43827108336196546`, 0.9408706340518126], 
             UndirectedEdge[73, 96] -> 
             RGBColor[
              0.3672380173898648, 0.4925048455688256, 0.9446210596256222], 
             UndirectedEdge[108, 205] -> 
             RGBColor[
              0.436683616415666, 0.5505880572448512, 0.9496172109793394], 
             UndirectedEdge[9, 43] -> 
             RGBColor[
              0.41950169820548255`, 0.5360485287106651, 0.948427736968998], 
             UndirectedEdge[151, 251] -> 
             RGBColor[
              0.36499365332834144`, 0.4885238594535514, 0.944552636407374], 
             UndirectedEdge[209, 279] -> 
             RGBColor[
              0.2619744678088157, 0.39268215418064606`, 0.9382304304339932], 
             UndirectedEdge[53, 68] -> 
             RGBColor[
              0.8459414855221328, 0.3373957157755989, 0.19097157486733474`], 
             UndirectedEdge[282, 295] -> 
             RGBColor[
              0.9004709095023198, 0.9227541160141217, 0.9653727475363004], 
             UndirectedEdge[35, 197] -> 
             RGBColor[
              0.218365708643122, 0.3468465833424746, 0.9357469761128849], 
             UndirectedEdge[116, 168] -> 
             RGBColor[
              0.35414043439259346`, 0.4811603774802517, 0.9437864932187738], 
             UndirectedEdge[27, 152] -> 
             RGBColor[
              0.2558672975304459, 0.3862631310011191, 0.9378826361213889], 
             UndirectedEdge[114, 231] -> 
             RGBColor[
              0.37476526938347776`, 0.4986237900384425, 0.945115364090962], 
             UndirectedEdge[83, 155] -> 
             RGBColor[
              0.21429563561346426`, 0.34256867853076955`, 0.9355151914749793],
              UndirectedEdge[62, 199] -> 
             RGBColor[
              0.5868878667757954, 0.648392143438405, 0.8070978104506135], 
             UndirectedEdge[96, 278] -> 
             RGBColor[
              0.5041987109200126, 0.6070709568623011, 0.9544705154158305], 
             UndirectedEdge[2, 178] -> 
             RGBColor[
              0.25390682555337085`, 0.3842025506521106, 0.9377709901425528], 
             UndirectedEdge[6, 213] -> 
             RGBColor[
              0.3667758904705204, 0.4918204598931879, 0.9446020161329686], 
             UndirectedEdge[79, 93] -> 
             RGBColor[
              0.46307011169266854`, 0.5733948534802826, 0.9513117589171669], 
             UndirectedEdge[270, 272] -> 
             RGBColor[
              0.22576785330449248`, 0.35462670670465335`, 0.9361685173008583],
              UndirectedEdge[161, 186] -> 
             RGBColor[
              0.22312007554742067`, 0.3518437244031648, 0.9360177302746292], 
             UndirectedEdge[189, 275] -> 
             RGBColor[
              0.22231351200262228`, 0.3509959749784993, 0.9359717976739568], 
             UndirectedEdge[260, 261] -> 
             RGBColor[
              0.6248975820608704, 0.7019966768640338, 0.9661118661321497], 
             UndirectedEdge[195, 200] -> 
             RGBColor[
              0.8414278249762438, 0.29050729216415533`, 0.1861717843217481], 
             UndirectedEdge[66, 110] -> 
             RGBColor[
              0.969700925487342, 0.9754692267738965, 0.8710436844734033], 
             UndirectedEdge[63, 172] -> 
             RGBColor[
              0.29700434513925705`, 0.4280429826559164, 0.940278707091565], 
             UndirectedEdge[4, 236] -> 
             RGBColor[
              0.5814156950940945, 0.671058479612787, 0.9601903197951254], 
             UndirectedEdge[143, 167] -> 
             RGBColor[
              0.5753382538779925, 0.6628795153036178, 0.9613047709389584], 
             UndirectedEdge[135, 249] -> 
             RGBColor[
              0.8757518909419225, 0.42593701703679554`, 0.3815512695878138], 
             UndirectedEdge[135, 288] -> 
             RGBColor[
              0.9046326551372147, 0.6405954744200593, 0.40892042898198233`], 
             UndirectedEdge[83, 214] -> 
             RGBColor[
              0.21458531177906248`, 0.342873146547343, 0.9355316881040727], 
             UndirectedEdge[36, 290] -> 
             RGBColor[
              0.6862499936639361, 0.7543721434480005, 0.9696708819958241], 
             UndirectedEdge[79, 119] -> 
             RGBColor[
              0.3385777508483834, 0.465228690511853, 0.9428846351776731], 
             UndirectedEdge[145, 264] -> 
             RGBColor[
              0.28193257724579573`, 0.4136593926161374, 0.9393670152410523], 
             UndirectedEdge[54, 238] -> 
             RGBColor[
              0.34796050319161576`, 0.47301253149465217`, 0.9434950557775005],
              UndirectedEdge[177, 273] -> 
             RGBColor[
              0.5185213619952923, 0.6190718502597115, 0.9554949527990644], 
             UndirectedEdge[98, 208] -> 
             RGBColor[
              0.3543834762769441, 0.47926414429235664`, 0.9438791178453103], 
             UndirectedEdge[125, 170] -> 
             RGBColor[
              0.8788040152312967, 0.44173686637663945`, 0.258623330792337], 
             UndirectedEdge[22, 217] -> 
             RGBColor[
              0.812207338591908, 0.8532218130031827, 0.981916895067874], 
             UndirectedEdge[78, 236] -> 
             RGBColor[
              0.4016254852173745, 0.5057768385746106, 0.9485224868513811], 
             UndirectedEdge[86, 240] -> 
             RGBColor[
              0.984900576757397, 0.9592281782774306, 0.5233965503688487], 
             UndirectedEdge[59, 170] -> 
             RGBColor[
              0.8291712502966372, 0.22522858946914998`, 0.17556772826926184`],
              UndirectedEdge[95, 109] -> 
             RGBColor[
              0.7049075830694689, 0.7678615870686365, 0.9726151362943627], 
             UndirectedEdge[30, 252] -> 
             RGBColor[
              0.38136485218953986`, 0.5037401708621798, 0.9456156414781487], 
             UndirectedEdge[116, 119] -> 
             RGBColor[
              0.30231628529617693`, 0.4338208316047836, 0.9405740866574415], 
             UndirectedEdge[6, 231] -> 
             RGBColor[
              0.3753962033450712, 0.49928694163560083`, 0.9451512948466916], 
             UndirectedEdge[214, 275] -> 
             RGBColor[
              0.21283035575294662`, 0.34102857649325646`, 0.9354317459546102],
              UndirectedEdge[157, 257] -> 
             RGBColor[
              0.3686428791962128, 0.49372166625507674`, 0.944710576177652], 
             UndirectedEdge[128, 173] -> 
             RGBColor[
              0.24821711809960986`, 0.3782223073699194, 0.9374469697202291], 
             UndirectedEdge[14, 113] -> 
             RGBColor[
              0.8682682293963724, 0.4400627275787366, 0.4307769881568413], 
             UndirectedEdge[213, 231] -> 
             RGBColor[
              0.43649903669503015`, 0.5524952593309104, 0.9490343105306326], 
             UndirectedEdge[29, 148] -> 
             RGBColor[
              0.2408182206421652, 0.3704455970249514, 0.9370256134557156], 
             UndirectedEdge[109, 154] -> 
             RGBColor[
              0.8311843708271494, 0.8688646527411055, 0.9835913192515602], 
             UndirectedEdge[74, 123] -> 
             RGBColor[
              0.5372173592410554, 0.6347120461758202, 0.9568391339311428], 
             UndirectedEdge[189, 216] -> 
             RGBColor[
              0.24534319825395978`, 0.3752016353950986, 0.9372833042366027], 
             UndirectedEdge[29, 162] -> 
             RGBColor[
              0.2636748497853562, 0.39446936344843425`, 0.9383272646720675], 
             UndirectedEdge[73, 140] -> 
             RGBColor[
              0.3285420686985767, 0.45898835972736407`, 0.9421553879924971], 
             UndirectedEdge[9, 295] -> 
             RGBColor[
              0.677057217004213, 0.7458583971286377, 0.9697240169413682], 
             UndirectedEdge[169, 221] -> 
             RGBColor[
              0.2938192081333214, 0.4261529953348542, 0.9400439412854023], 
             UndirectedEdge[22, 61] -> 
             RGBColor[
              0.6921091843567939, 0.7582433580431021, 0.9707375877325777], 
             UndirectedEdge[11, 143] -> 
             RGBColor[
              0.3701279239778581, 0.49500793740441695`, 0.9448052019179649], 
             UndirectedEdge[100, 299] -> 
             RGBColor[
              0.8982817367433281, 0.588471471678237, 0.3774803131264599], 
             UndirectedEdge[181, 232] -> 
             RGBColor[
              0.8539568089581072, 0.8830700073511788, 0.7854666422842203], 
             UndirectedEdge[49, 292] -> 
             RGBColor[
              0.23980801296623738`, 0.36938380470668514`, 0.9369680836230397],
              UndirectedEdge[4, 39] -> 
             RGBColor[
              0.7582287210905121, 0.5399616886397829, 0.4597522801819863], 
             UndirectedEdge[33, 75] -> 
             RGBColor[
              0.8225875285373088, 0.8620961486244765, 0.9827484209506085], 
             UndirectedEdge[223, 271] -> 
             RGBColor[
              0.9324098595457874, 0.7585161356784191, 0.29733719959784854`], 
             UndirectedEdge[21, 34] -> 
             RGBColor[
              0.3554769401154252, 0.48231799156263766`, 0.943871654181607], 
             UndirectedEdge[51, 165] -> 
             RGBColor[
              0.986911243979133, 0.9683407522697562, 0.5670857457477134], 
             UndirectedEdge[36, 138] -> 
             RGBColor[
              0.7331275863556836, 0.791444109527867, 0.9740349644072682], 
             UndirectedEdge[50, 205] -> 
             RGBColor[
              0.44094793085644673`, 0.5542815920827796, 0.9498889293247207], 
             UndirectedEdge[237, 283] -> 
             RGBColor[
              0.6287512202285861, 0.7094875913580734, 0.9639167457294545], 
             UndirectedEdge[140, 245] -> 
             RGBColor[
              0.37623831770858585`, 0.5003004533366545, 0.945194550803278], 
             UndirectedEdge[19, 49] -> 
             RGBColor[
              0.26391083574794544`, 0.39471739965748975`, 0.9383407037235271],
              UndirectedEdge[235, 292] -> 
             RGBColor[
              0.24255033880224458`, 0.3722661630338292, 0.9371242550224929], 
             UndirectedEdge[15, 115] -> 
             RGBColor[
              0.230257062183032, 0.3593451498682808, 0.9364241711053016], 
             UndirectedEdge[69, 110] -> 
             RGBColor[
              0.9929919929128255, 0.9894341623619243, 0.625087695462787], 
             UndirectedEdge[34, 50] -> 
             RGBColor[
              0.33997412107403424`, 0.46889022890332593`, 0.9428838282608942],
              UndirectedEdge[126, 275] -> 
             RGBColor[
              0.21935857397151598`, 0.34789014775391436`, 0.9358035183245244],
              UndirectedEdge[59, 225] -> 
             RGBColor[
              0.8755277217707287, 0.4621261005588738, 0.22031772858046247`], 
             UndirectedEdge[82, 228] -> 
             RGBColor[
              0.9057099592960236, 0.9241653224619759, 0.8439169187539672], 
             UndirectedEdge[19, 280] -> 
             RGBColor[
              0.2796627567223554, 0.4112736673310683, 0.939237752320141], 
             UndirectedEdge[194, 283] -> 
             RGBColor[
              0.5672781592829315, 0.6595809911525545, 0.9590773611885706], 
             UndirectedEdge[63, 283] -> 
             RGBColor[
              0.4716182093057971, 0.5784225844464469, 0.9525129877054703], 
             UndirectedEdge[36, 245] -> 
             RGBColor[
              0.5919869457083973, 0.6770600343104392, 0.9624670806434741], 
             UndirectedEdge[3, 55] -> 
             RGBColor[
              0.327009852931445, 0.45469787926428074`, 0.9421662593982401], 
             UndirectedEdge[137, 192] -> 
             RGBColor[
              0.8520395168588157, 0.39410340767554625`, 0.19719619206781494`],
              UndirectedEdge[54, 251] -> 
             RGBColor[
              0.3520600889143901, 0.4773214560180356, 0.9437285211196189], 
             UndirectedEdge[252, 292] -> 
             RGBColor[
              0.2717964040404102, 0.4030056319067771, 0.9387897751721301], 
             UndirectedEdge[100, 121] -> 
             RGBColor[
              0.8983235951964362, 0.5881023685637291, 0.34869848898741257`], 
             UndirectedEdge[142, 239] -> 
             RGBColor[
              0.5350790113196064, 0.6320396024840493, 0.9570335383591173], 
             UndirectedEdge[85, 299] -> 
             RGBColor[
              0.9570551059778822, 0.9653678956255696, 0.8666323773215838], 
             UndirectedEdge[120, 130] -> 
             RGBColor[
              0.18442078734008566`, 0.31116831882066576`, 0.9338138630616879],
              UndirectedEdge[9, 297] -> 
             RGBColor[
              0.6386143417337113, 0.7156866950327669, 0.9659294985140855], 
             UndirectedEdge[237, 239] -> 
             RGBColor[
              0.5249567920726707, 0.6240772116080362, 0.9560621419984239], 
             UndirectedEdge[169, 213] -> 
             RGBColor[
              0.36045188979201, 0.48517353421527176`, 0.944241873649848], 
             UndirectedEdge[46, 50] -> 
             RGBColor[
              0.32229358745653136`, 0.4520407279394575, 0.9418134628870861], 
             UndirectedEdge[105, 171] -> 
             RGBColor[
              0.3537618197336009, 0.4790225362534377, 0.9438286376877205], 
             UndirectedEdge[34, 114] -> 
             RGBColor[
              0.31595519138804573`, 0.44768545635926527`, 0.9413680379248031],
              UndirectedEdge[60, 240] -> 
             RGBColor[
              0.9605080040332614, 0.868110146524278, 0.47465486371626864`], 
             UndirectedEdge[19, 84] -> 
             RGBColor[
              0.2959425689542974, 0.42838478218655185`, 0.940164863542926], 
             UndirectedEdge[19, 48] -> 
             RGBColor[
              0.3524750293077462, 0.47810184855613913`, 0.9437395461742546], 
             UndirectedEdge[5, 77] -> 
             RGBColor[
              0.23349568981372465`, 0.3627491528489905, 0.9366086061577494]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {3}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.26920385108875294`, 0.4002806943772341, 0.9386421331168716], 
             160 -> 
             RGBColor[
              0.5902199940802382, 0.6782062061588879, 0.9608834264625246], 
             245 -> RGBColor[
              0.4244026220080174, 0.5420179529125, 0.9482635376832157], 155 -> 
             RGBColor[
              0.21230278460535462`, 0.3404740657671945, 0.9354017015582263], 
             213 -> RGBColor[
              0.42787872382047937`, 0.5450287775884974, 0.9484850318169096], 
             27 -> RGBColor[
              0.2584384877012701, 0.38896561489352793`, 0.9380290615978824], 
             19 -> RGBColor[
              0.2912671539208582, 0.4234706245479727, 0.9398986055734284], 
             164 -> RGBColor[
              0.38392426951059677`, 0.5069576384803866, 0.9456842928556817], 
             190 -> RGBColor[
              0.22813210557574862`, 0.35711168574399543`, 0.9363031579701084],
              103 -> RGBColor[
              0.2788168781365947, 0.4103845953056338, 0.9391895807860471], 
             138 -> RGBColor[
              0.7066839033025902, 0.7707861033473555, 0.971399305210804], 291 -> 
             RGBColor[
              0.8179080138731872, 0.1386544187368418, 0.16478204035016009`], 
             28 -> RGBColor[
              0.22341264573171882`, 0.35215123421688327`, 0.9360343917138061],
              114 -> RGBColor[
              0.3044111891973746, 0.4372858390035616, 0.9406471389375684], 
             195 -> RGBColor[
              0.8191437574953648, 0.1481528857232069, 0.16596538983833015`], 
             93 -> RGBColor[
              0.5312094509757161, 0.6302987888719648, 0.9562379003465947], 34 -> 
             RGBColor[
              0.3274991935787168, 0.458085073714969, 0.9420889369120379], 161 -> 
             RGBColor[
              0.21627103797903324`, 0.3446449516647265, 0.9356276877173526], 
             22 -> RGBColor[
              0.8173789776787558, 0.8572619367637411, 0.982432355720336], 124 -> 
             RGBColor[
              0.9476938047146304, 0.9605107057164812, 0.973424924364235], 84 -> 
             RGBColor[
              0.30061798398773654`, 0.43329893982513096`, 0.9404311215124237],
              46 -> RGBColor[
              0.29213812634371106`, 0.4243860717872321, 0.9399482061644217], 
             241 -> RGBColor[
              0.2790754121939759, 0.4106563309919474, 0.9392043039181481], 
             185 -> RGBColor[
              0.5680702998089695, 0.6602240865171163, 0.9591397213924867], 
             121 -> RGBColor[
              0.9946101233350695, 0.9908799237508646, 0.6547233713644478], 
             126 -> 
             RGBColor[
              0.22593857337368983`, 0.3548061443216573, 0.9361782395562414], 
             236 -> RGBColor[
              0.6232106502631707, 0.7049895070603167, 0.9634805717660004], 78 -> 
             RGBColor[
              0.1800403201715783, 0.3065641700889047, 0.9335644019367618], 
             254 -> RGBColor[
              0.8913219113450659, 0.5994000064779764, 0.23102867769365362`], 
             290 -> RGBColor[
              0.6129287179190951, 0.6966421711876226, 0.9626711403879157], 
             251 -> RGBColor[
              0.2867137638335649, 0.4186847228646212, 0.9396392967440941], 
             165 -> RGBColor[
              0.9802603651545728, 0.9450757179590131, 0.3778156754531135], 
             100 -> RGBColor[
              0.8501803311271197, 0.38671359097016134`, 0.19568604779889498`],
              235 -> RGBColor[
              0.24203916924704705`, 0.37172889142129484`, 0.937095144672532], 
             70 -> RGBColor[
              0.26423372362278924`, 0.39505677528622424`, 0.9383590917103296],
              234 -> RGBColor[0.817319, 0.134127, 0.164218], 257 -> 
             RGBColor[
              0.39130532114623406`, 0.5133507344247334, 0.9461546069390968], 
             135 -> RGBColor[
              0.9900957369634822, 0.9901723469535194, 0.8138028001335977], 
             265 -> RGBColor[
              0.22246582468563886`, 0.3511560652655316, 0.9359804716559281], 
             111 -> RGBColor[
              0.24301438028138522`, 0.37275390005033504`, 0.937150681498242], 
             182 -> RGBColor[
              0.3071831062866214, 0.4401992996140543, 0.9408049955151171], 
             188 -> RGBColor[
              0.20571498311483435`, 0.33354986870991854`, 0.9350265360091202],
              154 -> RGBColor[
              0.7412000832467709, 0.797750405452433, 0.9748395554555993], 269 -> 
             RGBColor[
              0.2270252964366493, 0.35594835916304945`, 0.9362401268270142], 
             208 -> RGBColor[
              0.28595975701387044`, 0.41789221389032877`, 0.9395963571711656],
              86 -> RGBColor[
              0.9748675947682047, 0.926884637163092, 0.35686578084130904`], 
             119 -> RGBColor[
              0.28222472928714576`, 0.41396646293510553`, 0.9393836528676069],
              140 -> RGBColor[
              0.3280740134091542, 0.4585829537608091, 0.9421255639233401], 85 -> 
             RGBColor[
              0.9196256639800194, 0.938748558156751, 0.9921959108615778], 242 -> 
             RGBColor[
              0.24043240470913427`, 0.3700400800171928, 0.9370036418090929], 
             117 -> RGBColor[
              0.20347429876271564`, 0.33119476738824843`, 0.9348989323500625],
              47 -> RGBColor[
              0.6440597930627512, 0.7218636724671273, 0.9651575191576801], 81 -> 
             RGBColor[
              0.29584127485450173`, 0.42827831566524976`, 0.9401590949937939],
              275 -> RGBColor[
              0.21277857456934213`, 0.34097415118617147`, 0.9354287970928072],
              23 -> RGBColor[
              0.2963741173821658, 0.42883836694599214`, 0.9401894395874745], 
             110 -> RGBColor[
              0.9929459767177286, 0.9913509943397207, 0.7665669512217009], 6 -> 
             RGBColor[
              0.3056730571205615, 0.43861214219787836`, 0.9407190004490276], 
             218 -> RGBColor[
              0.2560427236071457, 0.38644751493038626`, 0.9378926263769374], 
             108 -> RGBColor[
              0.3439204196877902, 0.4723083144158259, 0.943135282918988], 297 -> 
             RGBColor[
              0.7603990286995737, 0.8127487675575523, 0.9767531269139887], 
             157 -> RGBColor[
              0.34598043724619154`, 0.47409259808542004`, 0.9432665454162072],
              270 -> RGBColor[
              0.22825539451058077`, 0.357241270231474, 0.9363101790925575], 
             33 -> RGBColor[
              0.9146626577353835, 0.9347911916944939, 0.9917225348954364], 
             252 -> RGBColor[
              0.30053129972337833`, 0.4332078291671907, 0.9404261849718064], 
             260 -> RGBColor[
              0.8491537797280463, 0.8825561905625664, 0.9854742396306309], 
             159 -> RGBColor[
              0.2473937360801429, 0.37735688066202433`, 0.937400079332305], 
             183 -> RGBColor[
              0.25458949129815345`, 0.38492007563338526`, 0.9378098669468048],
              99 -> RGBColor[
              0.3674883934084197, 0.4927217086918333, 0.9446370133641255], 17 -> 
             RGBColor[
              0.29622239326445615`, 0.42867889527841463`, 0.9401807991234267],
              277 -> RGBColor[
              0.34909505354151776`, 0.4767903221752649, 0.9434650060123984], 
             104 -> RGBColor[
              0.28507184392659923`, 0.4169589609386654, 0.9395457918343952], 
             79 -> RGBColor[
              0.39493077240962093`, 0.5164909180886005, 0.9463856174877392], 
             191 -> RGBColor[
              0.24388899418338073`, 0.37367317471505657`, 0.9372004894660854],
              50 -> 
             RGBColor[
              0.35244904856935166`, 0.4796953840916829, 0.9436787196097506], 
             225 -> RGBColor[
              0.9609628542707439, 0.8799806824768295, 0.3028484896985869], 61 -> 
             RGBColor[
              0.5668393910348319, 0.659224779322463, 0.9590428197448192], 196 -> 
             RGBColor[
              0.2809324202458739, 0.4126081641956031, 0.9393100577795065], 1 -> 
             RGBColor[
              0.41852266255485593`, 0.5369250275695268, 0.9478888718663042], 
             263 -> RGBColor[
              0.26098356523640104`, 0.3916406527501864, 0.9381739999984032], 
             201 -> RGBColor[
              0.32111303850258816`, 0.4525537071655133, 0.9416820167576422], 
             293 -> RGBColor[
              0.20926131084396443`, 0.33727728400339907`, 0.9352284941269724],
              184 -> RGBColor[
              0.23743710807503443`, 0.3668918333419784, 0.9368330640969252], 
             106 -> RGBColor[
              0.6566687686170058, 0.7317139000018745, 0.9664142640033524], 
             206 -> RGBColor[
              0.23667377020378227`, 0.366089516840876, 0.9367895931344146], 
             247 -> RGBColor[
              0.5790882470358998, 0.6691689524288044, 0.9600070945582612], 
             220 -> RGBColor[
              0.25719173910326026`, 0.38765520306859286`, 0.937958061109625], 
             107 -> RGBColor[
              0.8341470216086144, 0.26347454816989946`, 0.18033253249694123`],
              131 -> RGBColor[
              0.324831212684851, 0.4557742027613212, 0.9419189355286837], 127 -> 
             RGBColor[
              0.8327720947194103, 0.2529062576026711, 0.17901590095508144`], 
             210 -> RGBColor[
              0.37855708825470646`, 0.5023088558389079, 0.9453423008120684], 
             181 -> RGBColor[
              0.7138170777657293, 0.7763585934520937, 0.9721102733779844], 
             194 -> RGBColor[
              0.5158331891976378, 0.6178156468678216, 0.9550274246943216], 
             118 -> RGBColor[
              0.17892956896395254`, 0.30539670014399584`, 0.9335011462986966],
              276 -> RGBColor[
              0.23178154572615212`, 0.3609474787299394, 0.9365109881878111], 
             280 -> RGBColor[
              0.2680583595238526, 0.3990767101141639, 0.9385768990668534], 
             189 -> RGBColor[
              0.2318484494359024, 0.3610177987708272, 0.9365147982551062], 
             168 -> RGBColor[
              0.3858730274799788, 0.5086455546860418, 0.9458084659902717], 41 -> 
             RGBColor[
              0.35699077137457635`, 0.483629196111943, 0.9439681141708117], 
             14 -> RGBColor[
              0.8226976998778256, 0.17547004422228246`, 0.1693686490773784], 
             77 -> RGBColor[
              0.2460324096232273, 0.37592604024272347`, 0.9373225538044856], 
             51 -> RGBColor[
              0.993562122803693, 0.9916057865804992, 0.7563558160423134], 179 -> 
             RGBColor[
              0.9936465744084931, 0.9916407094893913, 0.7549562343970292], 
             223 -> RGBColor[
              0.8873547734207121, 0.5813861597120881, 0.22771840056612383`], 
             292 -> RGBColor[
              0.24306150835744214`, 0.3728034346463635, 0.9371533653724538], 
             143 -> RGBColor[
              0.39675004724917656`, 0.5180666825152114, 0.9465015400717941], 
             112 -> RGBColor[
              0.2522134290242518, 0.3824226835324653, 0.9376745537153752], 
             197 -> RGBColor[
              0.2105002400012672, 0.3385794771003698, 0.9352990493096494], 54 -> 
             RGBColor[
              0.4174064139952154, 0.53595818917145, 0.9478177454951437], 71 -> 
             RGBColor[
              0.6295965520330332, 0.7101738697986875, 0.963983293345653], 177 -> 
             RGBColor[
              0.41920763486506846`, 0.5375183161569235, 0.9479325176962138], 
             158 -> RGBColor[
              0.40363205630183896`, 0.524027532856795, 0.9469400556031081], 
             226 -> RGBColor[
              0.178927010221482, 0.30539401074342565`, 0.9335010005820983], 
             203 -> RGBColor[
              0.2595939437592997, 0.3901800724706624, 0.9380948631110431], 
             115 -> RGBColor[
              0.2215913444714862, 0.35023693111520926`, 0.9359306713014096], 
             173 -> RGBColor[
              0.25717362368840185`, 0.38763616261899303`, 0.9379570294635482],
              212 -> RGBColor[
              0.21172080019279638`, 0.3398623632496528, 0.9353685584068999], 
             129 -> RGBColor[
              0.23590943272644063`, 0.36528614969039486`, 0.9367460652458159],
              279 -> RGBColor[
              0.25879261498995565`, 0.3893378251269034, 0.9380492286230886], 
             26 -> RGBColor[
              0.9858349896506369, 0.9884104184434465, 0.8844144095680297], 40 -> 
             RGBColor[
              0.2372124705557414, 0.3666557250663601, 0.9368202713225229], 
             146 -> RGBColor[
              0.23045057360750168`, 0.3595485426447314, 0.9364351912946507], 
             192 -> 
             RGBColor[
              0.8649861375675162, 0.47981540863036076`, 0.20905346250477896`],
              300 -> RGBColor[
              0.2558608387541249, 0.3862563424176957, 0.9378822683036323], 
             221 -> RGBColor[
              0.29461336050310216`, 0.4269876998276622, 0.9400891670880182], 
             62 -> RGBColor[
              0.9948487335515908, 0.9913902868768101, 0.6806946209012268], 
             286 -> RGBColor[
              0.5590358689967736, 0.6528895285873056, 0.9584284979047402], 
             152 -> RGBColor[
              0.25329610735962166`, 0.38356064710871024`, 0.9377362106448954],
              64 -> RGBColor[
              0.23365539790008147`, 0.3629170161738291, 0.9366177012970005], 
             37 -> RGBColor[
              0.6807027709206555, 0.7504894452666685, 0.968809748742459], 148 -> 
             RGBColor[
              0.23881348570074337`, 0.36833849349398035`, 0.9369114467665411],
              261 -> RGBColor[
              0.4006413843936947, 0.5214371631655013, 0.9467494926336685], 15 -> 
             RGBColor[
              0.23892277989457777`, 0.36845336862135236`, 0.9369176709091936],
              136 -> RGBColor[
              0.9929076697798414, 0.9872385477406899, 0.46942180820333496`], 
             198 -> RGBColor[
              0.4642553566460736, 0.5759424388475844, 0.9509670287800365], 63 -> 
             RGBColor[
              0.32451328924336914`, 0.4554988334556064, 0.9418986777281211], 
             171 -> RGBColor[
              0.4183533072547869, 0.5367783405206518, 0.9478780806963388], 59 -> 
             RGBColor[
              0.8328101555207211, 0.25319880959989605`, 0.17905234802140027`],
              229 -> RGBColor[
              0.34638875058307517`, 0.4744462585754037, 0.9432925627809762], 
             102 -> RGBColor[
              0.38532279281260967`, 0.5081689690727651, 0.9457734055238204], 
             299 -> RGBColor[
              0.9944845479757449, 0.9919872330943883, 0.7410688437815899], 
             128 -> RGBColor[
              0.23926061251081787`, 0.3688084521208458, 0.93693690997691], 12 -> 
             RGBColor[
              0.20154157699751735`, 0.32916335427138743`, 0.93478886670474], 
             222 -> RGBColor[
              0.43613267935432526`, 0.5521779390160471, 0.94901096656484], 92 -> 
             RGBColor[
              0.261097249315751, 0.3917601419255701, 0.9381804741385418], 271 -> 
             RGBColor[
              0.9774649456708626, 0.9356461116447503, 0.3669559986295733], 
             132 -> 
             RGBColor[
              0.2067120462521808, 0.3345978452847238, 0.9350833172797693], 80 -> 
             RGBColor[
              0.26782978190622225`, 0.39883646054537636`, 0.9385638819096797],
              244 -> RGBColor[
              0.24251120685435607`, 0.3722250328754895, 0.9371220265159511], 
             150 -> RGBColor[
              0.9620063021321176, 0.9711849428558795, 0.9491975995336027], 
             125 -> RGBColor[
              0.9926251659969516, 0.9866343007146026, 0.4386730148470409], 
             133 -> RGBColor[
              0.35014705105926486`, 0.47770150955020474`, 0.9435320383639844],
              258 -> RGBColor[
              0.9617670348256762, 0.9710064976904998, 0.9496026166724999], 
             255 -> RGBColor[
              0.9589543367125869, 0.8732054811308165, 0.29504577826186157`], 
             176 -> RGBColor[
              0.1789518783186532, 0.305420148690281, 0.9335024167834431], 230 -> 
             RGBColor[
              0.24935218422087857`, 0.37941533383072157`, 0.9375116100566555],
              274 -> RGBColor[
              0.9645754531953188, 0.8921668269279859, 0.3168827543384975], 87 -> 
             RGBColor[
              0.27610729667649436`, 0.4075366533936812, 0.9390352741303609], 
             130 -> RGBColor[0.178927, 0.305394, 0.933501], 35 -> 
             RGBColor[
              0.2262311772849768, 0.3551136895845794, 0.9361949029161204], 31 -> 
             RGBColor[
              0.6188367246795077, 0.7014385572283971, 0.9631362403218372], 18 -> 
             RGBColor[
              0.9464007204285422, 0.9595463255731478, 0.9756137787701872], 24 -> 
             RGBColor[
              0.9556367854010767, 0.9664345677069957, 0.9599795299232305], 
             151 -> RGBColor[
              0.443273542823118, 0.5583629960424816, 0.9494659760706539], 137 -> 
             RGBColor[
              0.8455662065044656, 0.351247407198139, 0.19126755684933291`], 
             296 -> RGBColor[
              0.6962355794932261, 0.7626237933772783, 0.9703579139386239], 
             266 -> RGBColor[
              0.24763395401992835`, 0.3776093649474359, 0.9374137593886052], 
             283 -> RGBColor[
              0.6187231293682252, 0.7013463354372874, 0.9631272976828197], 
             284 -> RGBColor[
              0.25564421936180226`, 0.3860286617019018, 0.9378699321496993], 
             238 -> RGBColor[
              0.2785145923880161, 0.4100668738178543, 0.9391723660598572], 72 -> 
             RGBColor[
              0.6518075404484566, 0.7279162716099014, 0.9659297422102715], 
             288 -> 
             RGBColor[
              0.8619011142240809, 0.46580703815332913`, 0.20647924340617463`],
              172 -> RGBColor[
              0.26949540103514497`, 0.4005871318562264, 0.9386587364550091], 
             243 -> RGBColor[
              0.21816661637866602`, 0.3466373247493527, 0.9357356381029547], 
             88 -> RGBColor[
              0.5042211596463271, 0.6083884781620977, 0.9541132831917766], 
             273 -> RGBColor[
              0.6178350891255162, 0.7006253843624993, 0.9630573879019151], 
             202 -> RGBColor[
              0.22812105044609293`, 0.3571000661017916, 0.9363025283968291], 
             98 -> RGBColor[
              0.4228071955400177, 0.5406360746943846, 0.948161878519455], 30 -> 
             RGBColor[
              0.46219840465570133`, 0.574272512557169, 0.9508050979844909], 
             116 -> RGBColor[
              0.3224078413052081, 0.4536752002744616, 0.941764520447276], 240 -> 
             RGBColor[
              0.9949335587465892, 0.9915717193917691, 0.6899273198963884], 73 -> 
             RGBColor[
              0.3290101239879992, 0.459393765693919, 0.9421852120616541], 29 -> 
             RGBColor[
              0.24282295558358705`, 0.3725527005559224, 0.9371397801448899], 
             75 -> RGBColor[
              0.7305123993392341, 0.7894011055544591, 0.9737743070057807], 
             200 -> RGBColor[
              0.8859959599380017, 0.5752161050460523, 0.226584573288584], 156 -> 
             RGBColor[
              0.2276990046313701, 0.35665646919126776`, 0.9362784935120415], 
             25 -> RGBColor[
              0.2518103509231395, 0.3819990228915686, 0.9376515990138174], 38 -> 
             RGBColor[
              0.4179442959916355, 0.5364240755220139, 0.9478520188603253], 3 -> 
             RGBColor[
              0.3773249031069595, 0.5012415989953558, 0.9452637870640326], 57 -> 
             RGBColor[
              0.24705297562595502`, 0.37699871981921224`, 0.9373806735285489],
              227 -> RGBColor[
              0.25976518882652405`, 0.3903600618938796, 0.9381046152642871], 
             39 -> RGBColor[
              0.8675327116732591, 0.4913788068770457, 0.21117838636085415`], 
             109 -> RGBColor[
              0.9211686584075277, 0.939978900029778, 0.992343083047521], 256 -> 
             RGBColor[
              0.9952479751456992, 0.992244224277091, 0.7241496045864151], 287 -> 
             RGBColor[
              0.9409750107809423, 0.8036926171977683, 0.27136531206102255`], 
             239 -> 
             RGBColor[
              0.4111342730563943, 0.530525575937213, 0.9474180902207585], 285 -> 
             RGBColor[0.382771346863294, 0.50595903483087, 0.945610829644085],
              216 -> RGBColor[
              0.2588379470720171, 0.38938547201937, 0.9380518102180992], 21 -> 
             RGBColor[
              0.38345468665213356`, 0.5065509094103063, 0.9456543714511763], 
             175 -> RGBColor[
              0.2945111830148827, 0.42688030480911665`, 0.9400833482312222], 
             7 -> RGBColor[
              0.394746751143397, 0.516331528116975, 0.946373891815379], 13 -> 
             RGBColor[
              0.30612838775897044`, 0.4390907235684761, 0.9407449308552837], 
             294 -> RGBColor[
              0.209897553009386, 0.33794601485934034`, 0.9352647271770572], 
             193 -> RGBColor[
              0.39949775357450523`, 0.5204466076304757, 0.9466766214891428], 
             60 -> RGBColor[
              0.9260824493199337, 0.7446485736567867, 0.2593824075361489], 65 -> 
             RGBColor[
              0.28791659856684826`, 0.41994897843342893`, 0.9397077964027201],
              69 -> RGBColor[
              0.9930380091079225, 0.9875173303841278, 0.48360843970387296`], 
             217 -> RGBColor[
              0.80703569950506, 0.8491816892426243, 0.9814014344154122], 214 -> 
             RGBColor[
              0.21288213693655111`, 0.34108300180034146`, 0.9354346948164131],
              170 -> RGBColor[
              0.8218934398484693, 0.16928814920765783`, 0.168598488764985], 
             74 -> RGBColor[
              0.6382140736915616, 0.7171699620960075, 0.9646616962176343], 
             246 -> RGBColor[
              0.5988679170367666, 0.6852269795994871, 0.961564222636048], 264 -> 
             RGBColor[
              0.2946613034028385, 0.4270380908550406, 0.940091897365233], 278 -> 
             RGBColor[
              0.6029315110482949, 0.6885259882808699, 0.9618841236420709], 45 -> 
             RGBColor[
              0.8578237913971699, 0.4454645759914146, 0.2030054339855487], 
             237 -> RGBColor[
              0.638779311088947, 0.7176288472788594, 0.9647061937760893], 228 -> 
             RGBColor[
              0.8163432429187892, 0.8564528128973794, 0.9823291233589543], 
             180 -> RGBColor[
              0.23402613491596813`, 0.3633066842836104, 0.936638814221599], 
             53 -> RGBColor[
              0.8317291195209172, 0.2448894931924079, 0.17801714672713256`], 
             48 -> RGBColor[
              0.4136829046946342, 0.5327330725643056, 0.9475804867750808], 5 -> 
             RGBColor[
              0.220958970004222, 0.34957226545525755`, 0.9358946585110132], 
             101 -> RGBColor[
              0.5465902564750337, 0.6427856196737024, 0.9574487336972479], 
             267 -> RGBColor[
              0.467847246129772, 0.578858496543228, 0.9512497954777179], 120 -> 
             RGBColor[
              0.18991457468017128`, 0.31694263764133146`, 0.9341267261233757],
              147 -> RGBColor[
              0.22619261942112945`, 0.35507316282496604`, 0.9361927071028155],
              89 -> RGBColor[
              0.27813245697413447`, 0.40966522526908, 0.9391506040133554], 43 -> 
             RGBColor[
              0.322173741643116, 0.45347243491334854`, 0.9417496038238137], 
             199 -> RGBColor[0.178927, 0.305394, 0.933501], 268 -> 
             RGBColor[
              0.2625163578880115, 0.3932517150116962, 0.938261290272349], 169 -> 
             RGBColor[
              0.2930250557635406, 0.42531829084204614`, 0.9399987154827865], 
             20 -> RGBColor[
              0.865905855945801, 0.8959138414156087, 0.9870720676150353], 4 -> 
             RGBColor[
              0.5396207399250182, 0.6371274521652572, 0.9569000678242504], 
             167 -> RGBColor[
              0.7539264605068086, 0.8076923480920241, 0.9761080018061227], 
             142 -> RGBColor[
              0.6590237495828186, 0.7335536290308857, 0.9666489864974762], 16 -> 
             RGBColor[
              0.9934703621130101, 0.9884420897444159, 0.5306673961342021], 
             281 -> RGBColor[
              0.8360763947567734, 0.2783045556433535, 0.18218010240253352`], 
             289 -> RGBColor[
              0.2909832679823188, 0.4231722424271597, 0.9398824386892002], 
             178 -> RGBColor[
              0.27705635157752495`, 0.4085341702682206, 0.9390893214029737], 
             58 -> RGBColor[
              0.5489231824340144, 0.6446795940643196, 0.9576323901745283], 
             186 -> RGBColor[
              0.2299691131158081, 0.3590424971416032, 0.9364077728319058], 
             122 -> RGBColor[
              0.6241927467762723, 0.7057868172525964, 0.96355788600105], 249 -> 
             RGBColor[
              0.8185799679311427, 0.1438193520784336, 0.16542550431492184`], 
             113 -> RGBColor[
              0.9594092884334661, 0.9692480942916449, 0.9535936663157671], 52 -> 
             RGBColor[
              0.8177080186927622, 0.13711716814164848`, 0.16459052473952288`],
              187 -> 
             RGBColor[
              0.3639294956023307, 0.48963917028760373`, 0.9444102435429313], 
             259 -> RGBColor[
              0.46426084954242974`, 0.5759468982282985, 0.9509674612009588], 
             42 -> RGBColor[
              0.2544378422070241, 0.3847606828235006, 0.9378012307554097], 
             134 -> RGBColor[
              0.27400077350385804`, 0.40532256397795713`, 0.9389153107520011],
              248 -> RGBColor[
              0.20835094833068457`, 0.3363204352816248, 0.9351766503286018], 
             174 -> RGBColor[
              0.3923234880848031, 0.5142326194523638, 0.9462194836360928], 
             215 -> RGBColor[
              0.9951032288756773, 0.9922430735458843, 0.7308157001748675], 83 -> 
             RGBColor[
              0.21628848662157388`, 0.34466329129434453`, 0.9356286813917323],
              95 -> RGBColor[
              0.48864650773140994`, 0.5957442741074949, 0.9528871895412045], 
             166 -> RGBColor[
              0.9927232541779302, 0.9868441014154793, 0.4493493080164732], 
             233 -> RGBColor[
              0.9940884990666902, 0.9897642221851048, 0.5979477888431959], 
             295 -> RGBColor[
              0.8372847792405768, 0.8730921717492939, 0.9843421637685542], 
             141 -> RGBColor[
              0.8990024464838272, 0.6342755227085348, 0.23743750448057996`], 
             205 -> RGBColor[
              0.5294468131435418, 0.6288678000738763, 0.9560991390396908], 
             224 -> RGBColor[
              0.9695247134417432, 0.9088618438807439, 0.33610969580648287`], 
             231 -> RGBColor[
              0.44511934956958094`, 0.5599617410733233, 0.9495835892443556], 
             68 -> RGBColor[
              0.8743662175245639, 0.5224081609419808, 0.2168804311477391], 10 -> 
             RGBColor[
              0.2114327980870659, 0.3395596547761419, 0.9353521571130395], 
             250 -> RGBColor[
              0.22258326386374316`, 0.3512795012877932, 0.9359871596433854], 
             282 -> RGBColor[
              0.9636570397640628, 0.9724160602789496, 0.9464033313040466], 
             232 -> RGBColor[
              0.9940965401504851, 0.9897814212502639, 0.5988230111904562], 
             253 -> RGBColor[
              0.29672537087035056`, 0.42920755663283183`, 0.9402094429539937],
              55 -> RGBColor[
              0.2766948027559306, 0.4081541595332056, 0.9390687317324474], 91 -> 
             RGBColor[
              0.2726124428491967, 0.4038633404346605, 0.9388362473750692], 
             105 -> 
             RGBColor[
              0.28917033221241484`, 0.4212667319862237, 0.9397791946791023], 
             36 -> RGBColor[
              0.7595712694087771, 0.8121021157083784, 0.9766706236037325], 
             123 -> RGBColor[
              0.43622064479054923`, 0.5522541302556329, 0.9490165716446514], 
             94 -> RGBColor[
              0.8619491220774967, 0.8927588492317026, 0.9866946708064583], 96 -> 
             RGBColor[
              0.40546591079173033`, 0.5256159254437323, 0.9470569071895901], 
             2 -> RGBColor[
              0.2307572995292167, 0.3598709310360006, 0.936452658882132], 262 -> 
             RGBColor[
              0.9939797374120591, 0.9895315920033393, 0.5861097539357399], 
             272 -> RGBColor[
              0.22328031209840418`, 0.35201214317783264`, 0.936026855509159], 
             97 -> RGBColor[
              0.2574804300414378, 0.3879586355486801, 0.9379745016314742], 
             209 -> RGBColor[
              0.2651563206276758, 0.3960264832343887, 0.938411632244898], 66 -> 
             RGBColor[
              0.9464558742569554, 0.9595874592080723, 0.9755204177251058], 
             139 -> RGBColor[
              0.25547870703592473`, 0.385854697753317, 0.9378605064675941], 
             56 -> RGBColor[
              0.5476923991281734, 0.6436803887304818, 0.9575354984041846], 
             144 -> RGBColor[
              0.3157094904678022, 0.4478734254480028, 0.9413377074550355], 
             298 -> RGBColor[
              0.28525208052382683`, 0.41714840103001194`, 0.9395560560419711],
              204 -> RGBColor[
              0.23088271225706164`, 0.36000274776459185`, 0.9364598009514513],
              207 -> RGBColor[
              0.7455882739599426, 0.8011784933890475, 0.9752769292959146], 
             149 -> RGBColor[
              0.2939489691399074, 0.4262893823800991, 0.9400513309827632], 
             219 -> RGBColor[
              0.27423499655804673`, 0.4055687472585089, 0.9389286494084351], 
             9 -> RGBColor[
              0.5168296547678491, 0.6186246225079816, 0.9551058701141822], 11 -> 
             RGBColor[
              0.34350580070653963`, 0.47194919229362253`, 0.9431088637641358],
              44 -> RGBColor[
              0.9650552642631052, 0.8937853423246256, 0.3187467297321304], 
             153 -> RGBColor[
              0.27348165172589245`, 0.40477693407509363`, 0.9388857475347178],
              32 -> RGBColor[
              0.2562574704790552, 0.38667322750850125`, 0.9379048558936031], 
             162 -> 
             RGBColor[
              0.2845267439871254, 0.4163860263409461, 0.9395147491992453], 90 -> 
             RGBColor[
              0.4035464690461924, 0.5239534014776945, 0.9469346020588602], 8 -> 
             RGBColor[
              0.6518492866916434, 0.7279488840923621, 0.9659339030856515], 
             163 -> RGBColor[
              0.2413593551772921, 0.3710143637312809, 0.9370564302669542], 49 -> 
             RGBColor[
              0.23655451757503262`, 0.36596417476700677`, 0.9367828018736257],
              76 -> RGBColor[
              0.29429562032882867`, 0.4266537347586102, 0.9400710722551477], 
             82 -> RGBColor[
              0.9950766756732579, 0.9918778320265724, 0.7055047141489801], 67 -> 
             RGBColor[
              0.9123183312358003, 0.932921889378774, 0.9914989309411012], 211 -> 
             RGBColor[
              0.24235927283690456`, 0.3720653405899749, 
               0.9371133740984234]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9mHk4FFzYxsmSfR/LzGBWM2NmbHmlLHNH8aZCu0SWIkQLqbSgomQtVNoX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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 9}], {
             RGBColor[
             0.46767615866135254`, 0.5777748250387542, 0.9514973709902432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 11}], {
             RGBColor[
             0.3810142316306978, 0.5044371099315746, 0.9454988678152201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 20}], {
             RGBColor[
             0.6422142592503285, 0.7164194344925677, 0.9674804697406698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 37}], {
             RGBColor[
             0.5496127167377557, 0.6437072364180976, 0.9583493103043816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 43}], {
             RGBColor[
             0.370348202098986, 0.49519873124143765`, 0.944819237845059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 75}], {
             RGBColor[
             0.5745175309470449, 0.663163066561993, 0.9608315894360424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 102}], {
             RGBColor[
             0.40192272768373283`, 0.5225469983211459, 0.9468311386950623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 142}], {
             RGBColor[
             0.5387732060688373, 0.6352393283002062, 0.9572689291818902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 143}], {
             RGBColor[
             0.4076363549020162, 0.5274958550423691, 0.9471952059690492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 174}], {
             RGBColor[
             0.4054230753198295, 0.5255788235109453, 0.9470541777511985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 185}], {
             RGBColor[
             0.4932964811819127, 0.5985745570433215, 0.9535142966293955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 237}], {
             RGBColor[
             0.5286509868219015, 0.6272769374241931, 0.9562975328211968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 239}], {
             RGBColor[
             0.4148284678056251, 0.5337253017533699, 0.9476534810435313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 283}], {
             RGBColor[
             0.5186228959615405, 0.619135681503407, 0.955508084774562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 295}], {
             RGBColor[
             0.6279037208977163, 0.7050085996594103, 0.9661155178174292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 297}], {
             RGBColor[
             0.5894608456272148, 0.6748368975635395, 0.9623209993901465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 32}], {
             RGBColor[
             0.24350738500413596`, 0.3732720792722509, 0.9371787573878676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 83}], {
             RGBColor[
             0.2235228930753953, 0.35226711116517256`, 0.9360406701369322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 155}], {
             RGBColor[
             0.22153004206728566`, 0.3501724984015976, 0.9359271802201792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 156}], {
             RGBColor[
             0.2292281520802934, 0.3582637001136342, 0.9363655761970868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 178}], {
             RGBColor[
             0.25390682555337085`, 0.3842025506521106, 0.9377709901425528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 184}], {
             RGBColor[
             0.23409720380212556`, 0.3633813821889895, 0.9366428614895286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 202}], {
             RGBColor[
             0.22943917498765481`, 0.3584854985688961, 0.9363775936394806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 208}], {
             RGBColor[
             0.2583585282715436, 0.3888815724631647, 0.9380245080266488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 214}], {
             RGBColor[
             0.2218197182328839, 0.35047696641817105`, 0.9359436768492726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 268}], {
             RGBColor[
             0.2466368287086141, 0.37656132302384837`, 0.9373569745772405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 275}], {
             RGBColor[
             0.2217679370492794, 0.35042254111108606`, 0.9359407279874696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 17}], {
             RGBColor[
             0.3367736481857078, 0.4649602471368852, 0.9427222930937296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 30}], {
             RGBColor[
             0.4197616538813304, 0.5377570557762624, 0.9480344425242617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 38}], {
             RGBColor[
             0.3976345995492975, 0.5188328372586848, 0.9465579029621789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 55}], {
             RGBColor[
             0.327009852931445, 0.45469787926428074`, 0.9421662593982401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 74}], {
             RGBColor[
             0.5077694883992605, 0.6092057805456816, 0.9549627416408335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 90}], {
             RGBColor[
             0.39043568607657597`, 0.5125975002365252, 0.9460991945614463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[
             0.40677277394875433`, 0.5267478646254944, 0.9471401793543419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 144}], {
             RGBColor[
             0.34651719678738085`, 0.4745575122216793, 0.9433007472595341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 157}], {
             RGBColor[
             0.36165267017657554`, 0.4876670985403879, 0.9442651662401199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 229}], {
             RGBColor[
             0.3618568268450173, 0.48784392878537974`, 0.9442781749225044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 252}], {
             RGBColor[
             0.33892810141516894`, 0.46722471408127325`, 0.9428449860179196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 257}], {
             RGBColor[
             0.38431511212659675`, 0.5072961667100446, 0.9457091970015647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 259}], {
             RGBColor[
             0.42079287632469464`, 0.5385942486118271, 0.9481156241324957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 26}], {
             RGBColor[
             0.7627278647878275, 0.8127689353043519, 0.92065723869614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 39}], {
             RGBColor[
             0.7582287210905121, 0.5399616886397829, 0.4597522801819863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 52}], {
             RGBColor[
             0.7250122591035142, 0.3037872628161848, 0.42869370576776544`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 78}], {
             RGBColor[
             0.3598305300482983, 0.47184581112708096`, 0.9452322348805061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 82}], {
             RGBColor[
             0.7673487077991381, 0.8145026420959148, 0.8312023909866153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 107}], {
             RGBColor[
             0.735971594380749, 0.38802551616835207`, 0.43918837760604434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 130}], {
             RGBColor[
             0.3592738699625091, 0.4712607260826286, 0.9452005339121252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 193}], {
             RGBColor[
             0.46955924674976174`, 0.5787870298978665, 0.9517883446566966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 199}], {
             RGBColor[
             0.3592738699625091, 0.4712607260826286, 0.9452005339121252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 220}], {
             RGBColor[
             0.3984062395141392, 0.5123913276169251, 0.9474290644669376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.35927387507325015`, 0.47126073145434144`, 0.9452005342031744]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 228}], {
             RGBColor[
             0.6779819914219037, 0.7467901325313183, 0.9696145955916023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 236}], {
             RGBColor[
             0.5814156950940945, 0.671058479612787, 0.9601903197951254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 266}], {
             RGBColor[
             0.3936273469724733, 0.5073684085563466, 0.9471569136064277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 281}], {
             RGBColor[
             0.7372578431461884, 0.3979121878173214, 0.4404200908764392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.23189096279390453`, 0.36106248300558996`, 0.9365172193279515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[
             0.23349568981372465`, 0.3627491528489905, 0.9366086061577494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 191}], {
             RGBColor[
             0.23242398209380136`, 0.36162272008515706`, 0.9365475739885493]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 248}], {
             RGBColor[
             0.21465495916745328`, 0.3429463503684412, 0.9355356544198075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 21}], {
             RGBColor[
             0.3445638718863475, 0.47258152580409235`, 0.9431866859501019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 34}], {
             RGBColor[
             0.31658612534963915`, 0.4483486079564237, 0.9414039686805327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 46}], {
             RGBColor[
             0.29890559173213627`, 0.4314991069925552, 0.9403336033067247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 50}], {
             RGBColor[
             0.32906105284495657`, 0.4591537631447806, 0.9421988600293891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 101}], {
             RGBColor[
             0.4261316567977976, 0.5406988809357904, 0.9490838670731377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 108}], {
             RGBColor[
             0.32479673840417583`, 0.4554602283068521, 0.9419271416840078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 114}], {
             RGBColor[
             0.30504212315896806`, 0.43794899060072, 0.940683069693298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 145}], {
             RGBColor[
             0.2874384541046572, 0.41944641828755624`, 0.9396805667829495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 169}], {
             RGBColor[
             0.299349056442051, 0.4319652165199622, 0.940358857965907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 187}], {
             RGBColor[
             0.3348012763614461, 0.46412565624274105`, 0.9425646219959795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 205}], {
             RGBColor[
             0.41755993513205164`, 0.5337399711358773, 0.9484090697443592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 213}], {
             RGBColor[
             0.3667758904705204, 0.4918204598931879, 0.9446020161329686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 219}], {
             RGBColor[
             0.2899540268393041, 0.4220904447281936, 0.9398238249287314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 221}], {
             RGBColor[
             0.3001432088118318, 0.4327999210127703, 0.9404040837685228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 231}], {
             RGBColor[
             0.3753962033450712, 0.49928694163560083`, 0.9451512948466916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 264}], {
             RGBColor[
             0.3001671802617, 0.4328251165264595, 0.9404054489071303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 9}], {
             RGBColor[
             0.45578820295562306`, 0.5674780753124783, 0.9507398809647807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 11}], {
             RGBColor[
             0.36912627592496833`, 0.4941403602052988, 0.9447413777897574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 43}], {
             RGBColor[
             0.3584602463932565, 0.4849019815151618, 0.9440617478195963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.40607658256930623`, 0.5261448586442126, 0.9470958186552614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 63}], {
             RGBColor[
             0.3596300201933831, 0.4859151807862907, 0.94413628477175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 106}], {
             RGBColor[
             0.5257077598802015, 0.6240227140594248, 0.9563940779093657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 131}], {
             RGBColor[
             0.359788981914124, 0.4860528654391481, 0.9441464136720313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 143}], {
             RGBColor[
             0.3957483991962868, 0.5171991053160931, 0.9464377159435866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 151}], {
             RGBColor[
             0.4190101469832575, 0.5373472620797284, 0.9479199339430164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 167}], {
             RGBColor[
             0.5743366058251028, 0.6620119381044995, 0.9612409468107508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 174}], {
             RGBColor[
             0.39353511961410004`, 0.5152820737846694, 0.9462966877257359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 185}], {
             RGBColor[
             0.4814085254761833, 0.5882778073170456, 0.9527568066039329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[
             0.4552899701705174, 0.5670735874923983, 0.9507006582548503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 283}], {
             RGBColor[
             0.5067349402558111, 0.6088389317771312, 0.9547505947490993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 297}], {
             RGBColor[
             0.5775728899214854, 0.6645401478372637, 0.9615635093646839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 22}], {
             RGBColor[
             0.7346141321851996, 0.7926054104280515, 0.9741831294029938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 47}], {
             RGBColor[
             0.6479545398771973, 0.7249062782797447, 0.9655457111216659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 61}], {
             RGBColor[
             0.6093443388632377, 0.6935868317074125, 0.9624883614152353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 72}], {
             RGBColor[
             0.6518284135700501, 0.7279325778511317, 0.9659318226479615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 177}], {
             RGBColor[
             0.5355284607783559, 0.6327336001246429, 0.9569332103909327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 217}], {
             RGBColor[
             0.7294424930983517, 0.7885652866674933, 0.9736676687505319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 247}], {
             RGBColor[
             0.6154687668637716, 0.6985589182605833, 0.9629704988219563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 267}], {
             RGBColor[
             0.5598482664107077, 0.6534036903177951, 0.9585918492816847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 271}], {
             RGBColor[
             0.814657116181253, 0.8317974978685563, 0.6664449508576125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 273}], {
             RGBColor[
             0.6348421879085798, 0.7142871342274307, 0.9644956454937833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 285}], {
             RGBColor[
             0.5173103167774687, 0.616953959461616, 0.9557723663648683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.43016772773719436`, 0.545286907400802, 0.949107366939159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 20}], {
             RGBColor[
             0.6913677553568252, 0.7572692319617951, 0.9710889688646087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 37}], {
             RGBColor[
             0.5987662128442524, 0.684557033887325, 0.9619578094283205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 43}], {
             RGBColor[
             0.41950169820548255`, 0.5360485287106651, 0.948427736968998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 63}], {
             RGBColor[
             0.42067147200560917`, 0.537061727981794, 0.9485022739211517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 75}], {
             RGBColor[
             0.6236710270535416, 0.7040128640312203, 0.9644400885599815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.5867492116924276, 0.675169261254928, 0.9607600670587673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 131}], {
             RGBColor[
             0.4208304337263501, 0.5371994126346513, 0.9485124028214329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 142}], {
             RGBColor[
             0.5879267021753338, 0.6760891257694337, 0.9608774283058292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 143}], {
             RGBColor[
             0.4567898510085129, 0.5683456525115964, 0.9508037050929882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 167}], {
             RGBColor[
             0.6353780576373289, 0.7131584853000028, 0.9656069359601525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 174}], {
             RGBColor[
             0.4545765714263261, 0.5664286209801727, 0.9506626768751375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 185}], {
             RGBColor[
             0.5424499772884093, 0.6394243545125489, 0.9571227957533345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 237}], {
             RGBColor[
             0.5778044829283981, 0.6681267348934206, 0.9599060319451358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 239}], {
             RGBColor[
             0.4639819639121217, 0.5745750992225973, 0.9512619801674704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 282}], {
             RGBColor[
             0.740243347265956, 0.7955203413934655, 0.9507546007091144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 283}], {
             RGBColor[
             0.5677763920680372, 0.6599854789726345, 0.959116583898501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 295}], {
             RGBColor[
             0.677057217004213, 0.7458583971286377, 0.9697240169413682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 297}], {
             RGBColor[
             0.6386143417337113, 0.7156866950327669, 0.9659294985140855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 117}], {
             RGBColor[
             0.20745354842489078`, 0.3353772110821952, 0.935125544731551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.22367111540675327`, 0.3524229022332684, 0.9360491111794278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 161}], {
             RGBColor[
             0.21385191803304957`, 0.3421023032204342, 0.935489922415196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 265}], {
             RGBColor[
             0.21694931138635237`, 0.3453578600208368, 0.9356663143844839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 269}], {
             RGBColor[
             0.2192290472618576, 0.3477540069695957, 0.9357961419700269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 43}], {
             RGBColor[
             0.3328397711748278, 0.46271081360348554`, 0.9424292337939748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 63}], {
             RGBColor[
             0.3340095449749544, 0.46372401287461446`, 0.9425037707461285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 131}], {
             RGBColor[
             0.3341685066956953, 0.46386169752747186`, 0.9425138996464097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 139}], {
             RGBColor[
             0.2994922538712322, 0.4289019450234698, 0.940484685115865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 143}], {
             RGBColor[
             0.3701279239778581, 0.49500793740441695`, 0.9448052019179649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 172}], {
             RGBColor[
             0.3065006008708423, 0.43626816207492447`, 0.9408838001095725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 174}], {
             RGBColor[
             0.36791464439567134`, 0.49309090587299315`, 0.9446641737001142]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 183}], {
             RGBColor[
             0.29904764600234657`, 0.4284346339635039, 0.9404593653554703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 185}], {
             RGBColor[
             0.4557880502577546, 0.5660866394053694, 0.9511242925783112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 283}], {
             RGBColor[
             0.4811144650373824, 0.586647763865455, 0.9531180807234778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 248}], {
             RGBColor[
             0.20494626266410096`, 0.3327418947765061, 0.9349827585166709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 58}], {
             RGBColor[
             0.4275257850964924, 0.5418851588163979, 0.949188660514906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 73}], {
             RGBColor[
             0.31756925587348483`, 0.44924224463119755`, 0.9414650714584689]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 95}], {
             RGBColor[
             0.3973874477451902, 0.5174174988379855, 0.946816060198244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 96}], {
             RGBColor[
             0.3557971492753504, 0.4823533245061042, 0.9439009190224369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 105}], {
             RGBColor[
             0.29764935998569264`, 0.4301787277773499, 0.9402620627671929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[
             0.3171012005840623, 0.44883683866464263`, 0.941435247389312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 149}], {
             RGBColor[
             0.30003867844943893`, 0.43269005297428764`, 0.9403981309190235]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 171}], {
             RGBColor[
             0.3622408475068787, 0.48793453204456394`, 0.9443115057758112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 245}], {
             RGBColor[
             0.36526550488349396`, 0.49055433824048805`, 0.9445042342692497]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 289}], {
             RGBColor[
             0.2985558278706446, 0.4311314829978179, 0.940313684772242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 298}], {
             RGBColor[
             0.2956902341413986, 0.428119562299244, 0.9401504934486273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 69}], {
             RGBColor[
             0.8794778029545246, 0.44615247294289756`, 0.27411524595287656`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 113}], {
             RGBColor[
             0.8682682293963724, 0.4400627275787366, 0.4307769881568413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 135}], {
             RGBColor[
             0.8784970455730444, 0.4470374784660281, 0.38418003276278484`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 224}], {
             RGBColor[
             0.8716400377324648, 0.4199339774417696, 0.22494899798707987`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 249}], {
             RGBColor[
             0.8213251225622646, 0.16491981350766619`, 0.16805426748989288`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 254}], {
             RGBColor[
             0.8455724370335723, 0.3167800316408471, 0.18992199194947013`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 288}], {
             RGBColor[
             0.8357655046599107, 0.272249042199298, 0.18173884718697714`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 19}], {
             RGBColor[
             0.265094966907718, 0.3959619965846625, 0.938408138241311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 49}], {
             RGBColor[
             0.2377386487348052, 0.36720877169417954`, 0.9368502363914097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 57}], {
             RGBColor[
             0.2429878777602664, 0.3727260442202823, 0.9371491722188713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 89}], {
             RGBColor[
             0.2585276184343561, 0.3890592969452162, 0.9380341374612745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 111}], {
             RGBColor[
             0.2409685800879815, 0.3706036343358437, 0.9370341762037178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.2455681044594148, 0.3754380260769088, 0.9372961123122845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 115}], {
             RGBColor[
             0.230257062183032, 0.3593451498682808, 0.9364241711053016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 146}], {
             RGBColor[
             0.2346866767510397, 0.3640009556330419, 0.9366764311019222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 175}], {
             RGBColor[
             0.2667169814547302, 0.3976668367152345, 0.9385005095702079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 212}], {
             RGBColor[
             0.22532179004368708`, 0.3541578659355026, 0.9361431146580468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 242}], {
             RGBColor[
             0.23967759230185604`, 0.3692467243192726, 0.9369606563591433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 243}], {
             RGBColor[
             0.2285446981366219, 0.35754534668535254`, 0.9363266545060742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 280}], {
             RGBColor[
             0.2534905697092152, 0.38376503936775813`, 0.9377472849880235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 294}], {
             RGBColor[
             0.2244101664519819, 0.3531996917403464, 0.9360911990431254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.9540665099241967, 0.9616166407194549, 0.7611949655148192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 44}], {
             RGBColor[
             0.9792628131880576, 0.9411137160345208, 0.4247070629331663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 53}], {
             RGBColor[
             0.8856428670516149, 0.492740358709744, 0.2955672298628224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 59}], {
             RGBColor[
             0.8863635577181508, 0.4982799029814027, 0.2962573640590009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 94}], {
             RGBColor[
             0.9277097420952534, 0.9406004694880592, 0.7586810334703302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 124}], {
             RGBColor[
             0.9705820834138202, 0.9744763977304486, 0.7520461602492186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 125}], {
             RGBColor[
             0.9930477640549809, 0.9875381952295093, 0.4846702054906215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 150}], {
             RGBColor[
             0.9777383321225639, 0.9798135163001478, 0.7399324978339024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 170}], {
             RGBColor[
             0.8790857472699829, 0.44233946271991065`, 0.2892881245547241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 192}], {
             RGBColor[
             0.9078142124160141, 0.6493576356683792, 0.31625810704792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 195}], {
             RGBColor[
             0.8772526257012466, 0.4282492870636099, 0.2875327252702875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 200}], {
             RGBColor[
             0.939733161025506, 0.7818290973952341, 0.3786259847113931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 295}], {
             RGBColor[
             0.9153775706767935, 0.9307671307468549, 0.7575047799513781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 30}], {
             RGBColor[
             0.37921039896007874`, 0.5014757039177918, 0.9454929485539587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 38}], {
             RGBColor[
             0.3570833446280458, 0.48255148540021425`, 0.944016408991876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[
             0.2753301177357401, 0.4067197890509576, 0.9389910149394182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 48}], {
             RGBColor[
             0.35495264897954515`, 0.4807059839213601, 0.9438806429492537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 55}], {
             RGBColor[
             0.28645859801019335`, 0.41841652740581015`, 0.939624765427937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 84}], {
             RGBColor[
             0.2984201886260963, 0.4309889175517728, 0.9403059603179251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 90}], {
             RGBColor[
             0.3498844311553243, 0.4763161483780546, 0.9435577005911434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 97}], {
             RGBColor[
             0.27685141165294697`, 0.4083187654135474, 0.9390776503774505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 134}], {
             RGBColor[
             0.2851115833841571, 0.4170007296281859, 0.9395480549377139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 144}], {
             RGBColor[
             0.3059659418661292, 0.4382761603632087, 0.940759253289231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 158}], {
             RGBColor[
             0.34992722478314753`, 0.47635321406760484`, 0.9435604273632674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 159}], {
             RGBColor[
             0.2718080646722995, 0.4030178879702195, 0.9387904392278659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 175}], {
             RGBColor[
             0.29536678813966943`, 0.42777960004376564`, 0.9401320736773244]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 235}], {
             RGBColor[
             0.2691307812557516, 0.40020389334985473`, 0.9386379718979794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 252}], {
             RGBColor[
             0.29837684649391727`, 0.43094336222280266`, 0.9403034920476165]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 253}], {
             RGBColor[
             0.2964738820674033, 0.42894322595562323`, 0.9401951210387102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 292}], {
             RGBColor[
             0.26964195081094916`, 0.4007411649623891, 0.9386670822479402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 24}], {
             RGBColor[
             0.9510187529148094, 0.9629904466400717, 0.9677966543467089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 36}], {
             RGBColor[
             0.8529859949186596, 0.8858242206407632, 0.9761422011869598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 66}], {
             RGBColor[
             0.9464282973427488, 0.95956689239061, 0.9755670982476465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 69}], {
             RGBColor[
             0.9697193647682323, 0.9735318279786378, 0.7296111092370301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 88}], {
             RGBColor[
             0.7253109400374347, 0.7839674018676228, 0.9648635309809819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 113}], {
             RGBColor[
             0.9529050044310041, 0.9643972099323963, 0.9646037225429771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 135}], {
             RGBColor[
             0.9682482286960121, 0.9748593362633335, 0.8947082894518925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.7053280385373079, 0.7677443822103661, 0.9632904037751118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 222}], {
             RGBColor[
             0.6912666998914337, 0.7558621322945974, 0.9623123726675136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.9579627169351427, 0.9342040847269458, 0.6558617372883351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 254}], {
             RGBColor[
             0.918861315886804, 0.779473166025562, 0.6033212282319205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 258}], {
             RGBColor[
             0.9540838776271092, 0.9652764116318238, 0.9626081977213435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 260}], {
             RGBColor[
             0.8977772500782942, 0.9210512580678571, 0.980544009200409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 278}], {
             RGBColor[
             0.7746661157384185, 0.8240361569270088, 0.968748951206129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 288}], {
             RGBColor[
             0.890067649625568, 0.630386800626602, 0.46285742186084555`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 290}], {
             RGBColor[
             0.7796647191738186, 0.8280942483803853, 0.9691424595790514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 48}], {
             RGBColor[
             0.3524750293077462, 0.47810184855613913`, 0.9437395461742546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 49}], {
             RGBColor[
             0.26391083574794544`, 0.39471739965748975`, 0.9383407037235271]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 57}], {
             RGBColor[
             0.2691600647734066, 0.40023467218359243`, 0.9386396395509886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 84}], {
             RGBColor[
             0.2959425689542974, 0.42838478218655185`, 0.940164863542926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 89}], {
             RGBColor[
             0.28469980544749635`, 0.41656792490852634`, 0.9395246047933918]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 111}], {
             RGBColor[
             0.2671407671011217, 0.39811226229915386`, 0.9385246435358352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 112}], {
             RGBColor[
             0.271740291472555, 0.402946654040219, 0.9387865796444018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 158}], {
             RGBColor[
             0.3474496051113486, 0.47374907870238386`, 0.9434193305882683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 175}], {
             RGBColor[
             0.2928891684678705, 0.42517546467854467`, 0.9399909769023254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 177}], {
             RGBColor[
             0.3552373943929633, 0.4804944703524481, 0.9439155616348212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 242}], {
             RGBColor[
             0.26584977931499626`, 0.39675535228258274`, 0.9384511236912607]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 253}], {
             RGBColor[
             0.2939962623956044, 0.42633909059040226`, 0.940054024263711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 280}], {
             RGBColor[
             0.2796627567223554, 0.4112736673310683, 0.939237752320141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 33}], {
             RGBColor[
             0.8902842568405922, 0.9153525165550513, 0.9893973012552358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 37}], {
             RGBColor[
             0.7733043134332283, 0.8232016433411387, 0.9779409081787471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 75}], {
             RGBColor[
             0.7982091276425176, 0.8426574734850338, 0.980423187310408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 124}], {
             RGBColor[
             0.9067998303302157, 0.928212273566045, 0.9802484959896351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 142}], {
             RGBColor[
             0.7624648027643098, 0.8147337352232472, 0.9768605270562558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 150}], {
             RGBColor[
             0.9139560790389594, 0.9335493921357441, 0.968134833574319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 167}], {
             RGBColor[
             0.8099161582263048, 0.8518030947538164, 0.981590034710579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 185}], {
             RGBColor[
             0.7169880778773853, 0.7780689639663625, 0.973105894503761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 200}], {
             RGBColor[
             0.8759509079419014, 0.7355649732308305, 0.6068283204518097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 237}], {
             RGBColor[
             0.752342583517374, 0.8067713443472341, 0.9758891306955624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 282}], {
             RGBColor[
             0.9147814478549319, 0.9341649508472791, 0.9667376994595409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 283}], {
             RGBColor[
             0.7423144926570131, 0.7986300884264481, 0.9750996826489275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 295}], {
             RGBColor[
             0.851595317593189, 0.8845030065824513, 0.9857071156917947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 297}], {
             RGBColor[
             0.8131524423226874, 0.8543313044865806, 0.981912597264512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 34}], {
             RGBColor[
             0.3554769401154252, 0.48231799156263766`, 0.943871654181607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 46}], {
             RGBColor[
             0.3377964064979223, 0.4654684905987692, 0.942801288807799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 50}], {
             RGBColor[
             0.3679518676107426, 0.4931231467509946, 0.9446665455304635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[
             0.32978099166431396`, 0.45704378140199375`, 0.9423448227907686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 101}], {
             RGBColor[
             0.4650224715635836, 0.5746682645420044, 0.9515515525742121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 108}], {
             RGBColor[
             0.3636875531699619, 0.4894296119130661, 0.9443948271850822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[
             0.3439329379247541, 0.47191837420693394`, 0.9431507551943723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 169}], {
             RGBColor[
             0.33823987120783705`, 0.46593460012617627`, 0.9428265434669814]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 187}], {
             RGBColor[
             0.3736920911272321, 0.49809503984895503`, 0.9450323074970538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 205}], {
             RGBColor[
             0.4564507498978377, 0.5677093547420913, 0.9508767552454336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 213}], {
             RGBColor[
             0.40566670523630644`, 0.5257898434994019, 0.9470697016340429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 264}], {
             RGBColor[
             0.339057995027486, 0.46679450013267343`, 0.9428731344082046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 61}], {
             RGBColor[
             0.6921091843567939, 0.7582433580431021, 0.9707375877325777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 72}], {
             RGBColor[
             0.7345932590636062, 0.7925891041868212, 0.9741810489653038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 177}], {
             RGBColor[
             0.6182933062719121, 0.6973901264603323, 0.9651824367082749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 217}], {
             RGBColor[
             0.812207338591908, 0.8532218130031827, 0.981916895067874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 247}], {
             RGBColor[
             0.6982336123573278, 0.7632154445962727, 0.9712197251392987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 267}], {
             RGBColor[
             0.642613111904264, 0.7180602166534845, 0.966841075599027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 271}], {
             RGBColor[
             0.8974219616748091, 0.8964540242042457, 0.6746941771749546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 273}], {
             RGBColor[
             0.717607033402136, 0.7789436605631201, 0.9727448718111256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 274}], {
             RGBColor[
             0.8909772154370372, 0.8747143818458635, 0.6496575550294168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 285}], {
             RGBColor[
             0.6000751622710249, 0.6816104857973055, 0.9640215926822105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[
             0.29610769611833376`, 0.428558341305621, 0.9401742672906341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 180}], {
             RGBColor[
             0.26520012614906696`, 0.3960725256148013, 0.9384141269045367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 267}], {
             RGBColor[
             0.3821106817559689, 0.50384843174461, 0.9457196175325961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 285}], {
             RGBColor[
             0.33957273212272987`, 0.46739870088843105`, 0.9429001346157797]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.7969254295463191, 0.8418022649015016, 0.9623206130704325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 113}], {
             RGBColor[
             0.9575230369172714, 0.9678413309993203, 0.9567865981194988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 135}], {
             RGBColor[
             0.9728662611822794, 0.9783034573302576, 0.8868911650284141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 224}], {
             RGBColor[
             0.9625807494214099, 0.9376482057938698, 0.6480446128648567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 233}], {
             RGBColor[
             0.9748626422338834, 0.9780993949460502, 0.7789636593832132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 254}], {
             RGBColor[
             0.9234793483730712, 0.7829172870924861, 0.5955041038084421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 259}], {
             RGBColor[
             0.7099488174717532, 0.7711907329676471, 0.9554734955620947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 260}], {
             RGBColor[
             0.9023952825645615, 0.924495379134781, 0.9727268847769307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 288}], {
             RGBColor[
             0.8931463379497462, 0.6326828813378846, 0.45764600557852664`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 29}], {
             RGBColor[
             0.24731665325336327`, 0.3772758617237455, 0.9373956895793536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[
             0.2869920462831278, 0.4177357289024586, 0.9397006014188156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 77}], {
             RGBColor[
             0.24892138027318342`, 0.37896253156714604`, 0.9374870764091515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 91}], {
             RGBColor[
             0.2622113968861681, 0.3929311816631146, 0.9382439231944433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 139}], {
             RGBColor[
             0.25364452897953216`, 0.38392686032244283`, 0.9377560527407058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 147}], {
             RGBColor[
             0.2390014851721345, 0.36853609285826733`, 0.9369221530583165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 148}], {
             RGBColor[
             0.24531191831194143`, 0.3751687581927745, 0.9372815228901793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 172}], {
             RGBColor[
             0.2606528759791422, 0.3912930773738975, 0.9381551677344133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 203}], {
             RGBColor[
             0.2557021473412196, 0.3860895476811155, 0.9378732310624303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 206}], {
             RGBColor[
             0.2442420605634609, 0.3740442698662223, 0.937220596074116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 244}], {
             RGBColor[
             0.2471607788887478, 0.37711202788352904`, 0.9373868127648843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 270}], {
             RGBColor[
             0.24003287271686014`, 0.3696201465615213, 0.9369808890531874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 272}], {
             RGBColor[
             0.23754533151077184`, 0.36700558303470066`, 0.9368392272614883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 39}], {
             RGBColor[
             0.906966804332385, 0.6570560107325126, 0.4355903940965794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 59}], {
             RGBColor[
             0.8838184335640263, 0.4982693458810795, 0.4141730352036101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 60}], {
             RGBColor[
             0.9559587194852852, 0.8665294960501166, 0.5718984085520893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 62}], {
             RGBColor[
             0.9903418616011138, 0.9899003526601282, 0.7825545152346283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 82}], {
             RGBColor[
             0.9904558326619474, 0.9901441252350094, 0.7949595618585049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[
             0.8953985506349588, 0.587279200127923, 0.4252621683886066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 127}], {
             RGBColor[
             0.8837930596964858, 0.49807431121626294`, 0.4141487371593976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 130}], {
             RGBColor[
             0.5823809948253185, 0.6469022092217233, 0.9089577047840149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 137}], {
             RGBColor[
             0.8923224675531893, 0.5636350776132415, 0.42231650775556523`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 170}], {
             RGBColor[
             0.8765406231158585, 0.4423289056195874, 0.40720379569933324`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 192}], {
             RGBColor[
             0.9052690882618898, 0.649347078568056, 0.4341737781925292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 195}], {
             RGBColor[
             0.8747075015471222, 0.4282387299632868, 0.4054483964148967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 199}], {
             RGBColor[
             0.5823809948253185, 0.6469022092217233, 0.9089577047840149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 220}], {
             RGBColor[
             0.6215133643769486, 0.6880328107560196, 0.9111862353388274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 226}], {
             RGBColor[
             0.5823809999360594, 0.646902214593436, 0.908957705075064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 228}], {
             RGBColor[
             0.901089116284713, 0.9224316156704129, 0.933371766463492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 266}], {
             RGBColor[
             0.6167344718352826, 0.6830098916954412, 0.9109140844783175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 32}], {
             RGBColor[
             0.25734797909016266`, 0.3878194212010146, 0.9379669587457427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 103}], {
             RGBColor[
             0.2686276829189324, 0.3996751050995809, 0.9386093211919647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 119}], {
             RGBColor[
             0.2703316084942079, 0.40146603891431676`, 0.9387063572327446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 152}], {
             RGBColor[
             0.2558672975304459, 0.3862631310011191, 0.9378826361213889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 268}], {
             RGBColor[
             0.2604774227946408, 0.3911086649526121, 0.9381451759351156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 35}], {
             RGBColor[
             0.2248219115083478, 0.35363246190073133`, 0.9361146473149633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 126}], {
             RGBColor[
             0.22467560955270433`, 0.3534786892692703, 0.9361063156350238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 163}], {
             RGBColor[
             0.23238600045450547`, 0.3615827989740821, 0.9365454109903801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 184}], {
             RGBColor[
             0.23042487690337662`, 0.35952153377943086`, 0.9364337279053656]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 189}], {
             RGBColor[
             0.22763054758381063`, 0.35658451649385525`, 0.9362745949844562]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 197}], {
             RGBColor[
             0.21695644286649302`, 0.3453653556586265, 0.9356667205117277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 211}], {
             RGBColor[
             0.2328859592843117, 0.3621082874034291, 0.9365738829061148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 216}], {
             RGBColor[
             0.24112529640186797`, 0.3707683531181266, 0.9370431009659527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 275}], {
             RGBColor[
             0.21809561015053047`, 0.3465626927015274, 0.9357315944033067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 293}], {
             RGBColor[
             0.21633697828784162`, 0.3447142591101412, 0.9356314429203892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 77}], {
             RGBColor[
             0.2444276826034072, 0.3742393703993229, 0.9372311669746878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 91}], {
             RGBColor[
             0.25771769921639187`, 0.38820802049529146`, 0.9379880137599795]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 148}], {
             RGBColor[
             0.2408182206421652, 0.3704455970249514, 0.9370256134557156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 162}], {
             RGBColor[
             0.2636748497853562, 0.39446936344843425`, 0.9383272646720675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 172}], {
             RGBColor[
             0.256159178309366, 0.3865699162060744, 0.9378992582999495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 191}], {
             RGBColor[
             0.24335597488348387`, 0.37311293763548947`, 0.9371701348054876]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 203}], {
             RGBColor[
             0.25120844967144335`, 0.38136638651329235`, 0.9376173216279664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 206}], {
             RGBColor[
             0.23974836289368467`, 0.3693211086983992, 0.9369646866396522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 244}], {
             RGBColor[
             0.24266708121897157`, 0.3723888667157059, 0.9371309033304205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 270}], {
             RGBColor[
             0.2355391750470839, 0.3648969853936982, 0.9367249796187237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 272}], {
             RGBColor[
             0.23305163384099561`, 0.36228242186687754`, 0.9365833178270244]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 38}], {
             RGBColor[
             0.4400713503236684, 0.5553482940395915, 0.949328558422408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 47}], {
             RGBColor[
             0.5531290988592262, 0.6480680925121483, 0.9579813085710855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 48}], {
             RGBColor[
             0.43794065467516774`, 0.5535027925607373, 0.9491927923797858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 74}], {
             RGBColor[
             0.5502062391736314, 0.6457212373265883, 0.9577333971010626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 90}], {
             RGBColor[
             0.4328724368509469, 0.5491129570174318, 0.9488698500216755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 123}], {
             RGBColor[
             0.44920952472312525`, 0.5632633214064009, 0.9499108348145711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 144}], {
             RGBColor[
             0.3889539475617518, 0.5110729690025859, 0.9460714027197632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 158}], {
             RGBColor[
             0.4329152304787701, 0.5491500227069821, 0.9488725767937995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 252}], {
             RGBColor[
             0.38136485218953986`, 0.5037401708621798, 0.9456156414781487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 257}], {
             RGBColor[
             0.42675186290096767`, 0.5438116234909512, 0.9484798524617939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 259}], {
             RGBColor[
             0.46322962709906557`, 0.5751097053927338, 0.9508862795927249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 36}], {
             RGBColor[
             0.6892039970441424, 0.7567703364683878, 0.9699034319627848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 51}], {
             RGBColor[
             0.8061994237416004, 0.8465221719044482, 0.8597460281820752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 58}], {
             RGBColor[
             0.583879953556761, 0.6730590756463584, 0.9603843152481828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 66}], {
             RGBColor[
             0.7826462994682315, 0.8305130082182347, 0.9693283290234715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 67}], {
             RGBColor[
             0.765577527957654, 0.8171802233035855, 0.9773175856314692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 73}], {
             RGBColor[
             0.47392342433375345`, 0.580416161461158, 0.9526607261917457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 95}], {
             RGBColor[
             0.5537416162054588, 0.648591415667946, 0.9580117149315208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 96}], {
             RGBColor[
             0.512151317735619, 0.6135272413360646, 0.9550965737557137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 109}], {
             RGBColor[
             0.7700026915435176, 0.8207087286290875, 0.9777396616846791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 110}], {
             RGBColor[
             0.8058913506986181, 0.8463947757840589, 0.8648515957717691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 138}], {
             RGBColor[
             0.662760313991049, 0.7361123302878763, 0.9672677727663206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 154}], {
             RGBColor[
             0.6800184039631393, 0.7495944813404151, 0.9689878978887183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 171}], {
             RGBColor[
             0.5185950159671473, 0.6191084488745244, 0.955507160509088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 245}], {
             RGBColor[
             0.5216196733437626, 0.6217282550704486, 0.9556998890025264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 156}], {
             RGBColor[
             0.24197823755521267`, 0.3716648483498845, 0.9370916747028223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 178}], {
             RGBColor[
             0.2666569110282901, 0.3976036988883609, 0.9384970886482884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 182}], {
             RGBColor[
             0.2817202883828383, 0.4134362635612778, 0.9393549257043601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 202}], {
             RGBColor[
             0.24218926046257408`, 0.37188664680514644`, 0.937103692145216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 208}], {
             RGBColor[
             0.27110861374646283`, 0.402282720699415, 0.9387506065323843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 268}], {
             RGBColor[
             0.2593869141835333, 0.38996247126009875`, 0.938083073082976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 37}], {
             RGBColor[
             0.7976827143280194, 0.8426403184805812, 0.9802661418189477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 75}], {
             RGBColor[
             0.8225875285373088, 0.8620961486244765, 0.9827484209506085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 94}], {
             RGBColor[
             0.8883058899064401, 0.9137750204630982, 0.9892086028509474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 124}], {
             RGBColor[
             0.931178231225007, 0.9476509487054876, 0.9825737296298357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 142}], {
             RGBColor[
             0.7868432036591011, 0.8341724103626897, 0.9791857606964562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 150}], {
             RGBColor[
             0.9383344799337505, 0.9529880672751867, 0.9704600672145196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 185}], {
             RGBColor[
             0.7413664787721765, 0.7975076391058051, 0.9754311281439616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 200}], {
             RGBColor[
             0.9003293088366926, 0.7550036483702731, 0.6091535540920102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 237}], {
             RGBColor[
             0.7767209844121652, 0.8262100194866766, 0.9782143643357628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 239}], {
             RGBColor[
             0.6628984653958889, 0.7326583838158534, 0.9695703125580974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 282}], {
             RGBColor[
             0.9391598487497231, 0.9536036259867218, 0.9690629330997416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 295}], {
             RGBColor[
             0.8759737184879801, 0.9039416817218939, 0.9880323493319954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 297}], {
             RGBColor[
             0.8375308432174786, 0.8737699796260231, 0.9842378309047126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 46}], {
             RGBColor[
             0.30981865996121394`, 0.44123557275110054`, 0.9410185715382298]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 50}], {
             RGBColor[
             0.33997412107403424`, 0.46889022890332593`, 0.9428838282608942]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 87}], {
             RGBColor[
             0.3018032451276056, 0.4328108635543251, 0.9405621055211995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 108}], {
             RGBColor[
             0.3357098066332535, 0.46519669406539743`, 0.9426121099155129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 114}], {
             RGBColor[
             0.31595519138804573`, 0.44768545635926527`, 0.9413680379248031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 169}], {
             RGBColor[
             0.3102621246711287, 0.4417016822785076, 0.9410438261974121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 187}], {
             RGBColor[
             0.34571434459052375`, 0.47386212200128636`, 0.9432495902274847]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 205}], {
             RGBColor[
             0.4284730033611293, 0.5434764368944227, 0.9490940379758643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 213}], {
             RGBColor[
             0.37768895869959807`, 0.5015569256517332, 0.9452869843644738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 227}], {
             RGBColor[
             0.2936321912026204, 0.4242225678044243, 0.9400967760881624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 264}], {
             RGBColor[
             0.31108024849077764`, 0.44256158228500475`, 0.9410904171386354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 92}], {
             RGBColor[
             0.24366421330036392`, 0.37343691575507476`, 0.9371876885273311]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 126}], {
             RGBColor[
             0.2260848753293333, 0.35495991695311835`, 0.9361865712361809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 163}], {
             RGBColor[
             0.23379526623113445`, 0.36306402665793014`, 0.9366256665915373]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 184}], {
             RGBColor[
             0.23183414268000563`, 0.3610027614632789, 0.9365139835065228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 189}], {
             RGBColor[
             0.2290398133604396, 0.3580657441777033, 0.9363548505856133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 197}], {
             RGBColor[
             0.218365708643122, 0.3468465833424746, 0.9357469761128849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 211}], {
             RGBColor[
             0.2342952250609407, 0.36358951508727716`, 0.936654138507272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 216}], {
             RGBColor[
             0.24253456217849695`, 0.3722495808019747, 0.9371233565671098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 275}], {
             RGBColor[
             0.21950487592715945`, 0.34804392038537546`, 0.9358118500044639]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 58}], {
             RGBColor[
             0.6542472259213957, 0.728390854886349, 0.9671515068891303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 66}], {
             RGBColor[
             0.8530135718328662, 0.8858447874582254, 0.9760955206644191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 67}], {
             RGBColor[
             0.8359448003222887, 0.8725120025435762, 0.9840847772724168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 69}], {
             RGBColor[
             0.8763046392583498, 0.8998097230462532, 0.7301395316538027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 88}], {
             RGBColor[
             0.6318962145275521, 0.7102452969352381, 0.9653919533977545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 95}], {
             RGBColor[
             0.6241088885700935, 0.7039231949079366, 0.9647789065724686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 96}], {
             RGBColor[
             0.5825185901002536, 0.6688590205760554, 0.9618637653966613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 109}], {
             RGBColor[
             0.8403699639081523, 0.8760405078690783, 0.9845068533256267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 113}], {
             RGBColor[
             0.8594902789211216, 0.8906751050000117, 0.9651321449597499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 138}], {
             RGBColor[
             0.7331275863556836, 0.791444109527867, 0.9740349644072682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 154}], {
             RGBColor[
             0.750385676327774, 0.8049262605804057, 0.9757550895296658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 198}], {
             RGBColor[
             0.6119133130274254, 0.6940222772779814, 0.9638188261918845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 222}], {
             RGBColor[
             0.5978519743815511, 0.6821400273622127, 0.9628407950842862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 224}], {
             RGBColor[
             0.8645479914252601, 0.8604819797945611, 0.6563901597051076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 245}], {
             RGBColor[
             0.5919869457083973, 0.6770600343104392, 0.9624670806434741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 258}], {
             RGBColor[
             0.8606691521172266, 0.8915543066994391, 0.9631366201381162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 260}], {
             RGBColor[
             0.8043625245684116, 0.8473291531354724, 0.9810724316171817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 278}], {
             RGBColor[
             0.681251390228536, 0.7503140519946241, 0.9692773736229017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 290}], {
             RGBColor[
             0.6862499936639361, 0.7543721434480005, 0.9696708819958241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 75}], {
             RGBColor[
             0.7056075851299448, 0.7699452754105638, 0.9712920278741198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 94}], {
             RGBColor[
             0.771325946499076, 0.8216241472491855, 0.9777522097744586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 102}], {
             RGBColor[
             0.5330127818666326, 0.6293292071697167, 0.9572915771331396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 124}], {
             RGBColor[
             0.8141982878176429, 0.8555000754915749, 0.971117336553347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 142}], {
             RGBColor[
             0.669863260251737, 0.742021537148777, 0.9677293676199676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 150}], {
             RGBColor[
             0.8213545365263866, 0.860837194061274, 0.9590036741380308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 185}], {
             RGBColor[
             0.6243865353648125, 0.7053567658918924, 0.9639747350674728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 237}], {
             RGBColor[
             0.6597410410048012, 0.7340591462727639, 0.9667579712592742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 239}], {
             RGBColor[
             0.5459185219885249, 0.6405075106019407, 0.9581139194816087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 282}], {
             RGBColor[
             0.8221799053423591, 0.8614527527728091, 0.9576065400232527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 283}], {
             RGBColor[
             0.6497129501444403, 0.725917890351978, 0.9659685232126394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 295}], {
             RGBColor[
             0.7589937750806162, 0.8117908085079812, 0.9765759562555065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 297}], {
             RGBColor[
             0.7205508998101146, 0.7816191064121104, 0.9727814378282238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 48}], {
             RGBColor[
             0.41581360034313486`, 0.5345785740431597, 0.947716252817703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 55}], {
             RGBColor[
             0.34731954937378307`, 0.4722891175276097, 0.9434603752963864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 74}], {
             RGBColor[
             0.5280791848415985, 0.6267970188090106, 0.9562568575389798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 90}], {
             RGBColor[
             0.41074538251891396`, 0.5301887384998543, 0.9473933104595927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 123}], {
             RGBColor[
             0.4270824703910924, 0.5443391028888234, 0.9484342952524883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 144}], {
             RGBColor[
             0.36682689322971884`, 0.49214875048500833`, 0.9445948631576804]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 158}], {
             RGBColor[
             0.41078817614673724`, 0.5302258041894045, 0.9473960372317167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 252}], {
             RGBColor[
             0.3592377978575069, 0.4848159523446023, 0.9441391019160659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 253}], {
             RGBColor[
             0.35733483343099304`, 0.48281581607742285`, 0.9440307309071595]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 257}], {
             RGBColor[
             0.4046248085689348, 0.5248874049733736, 0.9470033128997111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 259}], {
             RGBColor[
             0.44110257276703263`, 0.5561854868751561, 0.949409740030642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 52}], {
             RGBColor[
             0.8509244806797601, 0.37329159396524664`, 0.19564909915374373`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 59}], {
             RGBColor[
             0.8559585262890798, 0.41198547445132916`, 0.20046970691436952`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 60}], {
             RGBColor[
             0.8870492908888172, 0.5758020624702928, 0.22724639341928574`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 62}], {
             RGBColor[
             0.909971385632703, 0.6580493002103005, 0.3676837978743117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 82}], {
             RGBColor[
             0.9100473663399253, 0.6582118152602212, 0.3759538289568961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 100}], {
             RGBColor[
             0.861748584824546, 0.4564904015747509, 0.20601427350686777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 107}], {
             RGBColor[
             0.8564041483183775, 0.41541072064133033`, 0.20089643507288318`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 127}], {
             RGBColor[
             0.8559458393553094, 0.41188795711892084`, 0.20045755789226324`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 136}], {
             RGBColor[
             0.9093243643754532, 0.6566653871649271, 0.29725952697501445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 137}], {
             RGBColor[
             0.8602105432836612, 0.44466834031741015`, 0.20454144319034706`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 141}], {
             RGBColor[
             0.8780226232767818, 0.5390110454875421, 0.21993142573409608`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 170}], {
             RGBColor[
             0.8523196210649958, 0.3840152543205831, 0.1969850871622311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 192}], {
             RGBColor[
             0.8666838536380115, 0.4875243407948174, 0.2104700784088291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 220}], {
             RGBColor[
             0.6640857208165928, 0.4568042722742281, 0.4534382779437778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 228}], {
             RGBColor[
             0.8504695554217692, 0.6130701422171569, 0.46822863202688747`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 232}], {
             RGBColor[
             0.9097206544990011, 0.6575130116681185, 0.3403932613040548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 266}], {
             RGBColor[
             0.6608997924554822, 0.45345565956717576`, 0.45325684403677113`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 281}], {
             RGBColor[
             0.8570472727010972, 0.420354056465815, 0.2015122917080806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.2625645345612948, 0.39330235174989453`, 0.9382640338626215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.25252112623098183`, 0.38274609280586824`, 0.9376920766161012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 162}], {
             RGBColor[
             0.2608696072714334, 0.3915208757036531, 0.9381675102608841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 191}], {
             RGBColor[
             0.24055073236956107`, 0.37016444989070835`, 0.9370103803943042]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 76}], {
             RGBColor[
             0.32564319585170254`, 0.45514146543527656`, 0.9420195932129798]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.4306059655104517, 0.5460088371370204, 0.9490406986812941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 99}], {
             RGBColor[
             0.362239582391498, 0.48817545240188814`, 0.9443025637674687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 104}], {
             RGBColor[
             0.3210313076505878, 0.45029407852530423`, 0.9417569530026035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 157}], {
             RGBColor[
             0.35148560431038395`, 0.4788608970986815, 0.9436173297935095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 201}], {
             RGBColor[
             0.3390519049385823, 0.4680914516387281, 0.942825065464227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 209}], {
             RGBColor[
             0.3110735460011261, 0.43982783967316585`, 0.9411898732078549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 222}], {
             RGBColor[
             0.3965617253644508, 0.517903567563995, 0.9464895403678258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 229}], {
             RGBColor[
             0.35168976097882576`, 0.47903772734367334`, 0.943630338475894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 259}], {
             RGBColor[
             0.41062581045850305`, 0.5297880471701207, 0.9474677876858852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 261}], {
             RGBColor[
             0.3788160778841355, 0.5025331796387221, 0.9453588034022401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 278}], {
             RGBColor[
             0.4799611412114356, 0.5860775921964064, 0.9529261189064413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 290}], {
             RGBColor[
             0.4849597446468357, 0.5901356836497829, 0.9533196272793637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 55}], {
             RGBColor[
             0.2655663224814774, 0.39645742117835314`, 0.9384349812439285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[
             0.25595913612423093`, 0.3863596591860904, 0.937887866193442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 134}], {
             RGBColor[
             0.26421930785544107`, 0.3950416234007289, 0.9383582707537054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 144}], {
             RGBColor[
             0.28507366633741316`, 0.4163170541357517, 0.9395694691052225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 159}], {
             RGBColor[
             0.2509157891435835, 0.3810587817427625, 0.9376006550438574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 235}], {
             RGBColor[
             0.24823850572703557`, 0.37824478712239773`, 0.9374481877139709]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 252}], {
             RGBColor[
             0.2774845709652012, 0.40898425599534566`, 0.939113707863608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 292}], {
             RGBColor[
             0.24874967528223313`, 0.3787820587349321, 0.9374772980639317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 63}], {
             RGBColor[
             0.3233435154432426, 0.45448563418447746`, 0.9418241407759673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 131}], {
             RGBColor[
             0.3235024771639835, 0.45462331883733487`, 0.9418342696762487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 139}], {
             RGBColor[
             0.2888262243395204, 0.4196635663333328, 0.9398050551457039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 143}], {
             RGBColor[
             0.3594618944461463, 0.48576955871427996`, 0.9441255719478039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 172}], {
             RGBColor[
             0.2958345713391305, 0.4270297833847875, 0.9402041701394114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 174}], {
             RGBColor[
             0.35724861486395953`, 0.48385252718285615`, 0.9439845437299532]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 183}], {
             RGBColor[
             0.28838161647063476`, 0.4191962552733669, 0.9397797353853092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 185}], {
             RGBColor[
             0.4451220207260428, 0.5568482607152324, 0.9504446626081502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 244}], {
             RGBColor[
             0.28234247424873604`, 0.412848733894419, 0.9394358151698824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 59}], {
             RGBColor[
             0.8768918584348492, 0.4667276538414726, 0.225617141924977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 60}], {
             RGBColor[
             0.9455688567915195, 0.8192169579907062, 0.28906456863413965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 94}], {
             RGBColor[
             0.9135021931703009, 0.8932720957781641, 0.6527207002692943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 100}], {
             RGBColor[
             0.8884719755057815, 0.5557375080883161, 0.23670627510997347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 121}], {
             RGBColor[
             0.9798326937990873, 0.9423326330377451, 0.48673505054828914`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 124}], {
             RGBColor[
             0.9563745344888678, 0.9271480240205534, 0.6460858270481826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 125}], {
             RGBColor[
             0.9788402151300284, 0.9402098215196141, 0.37870987228958564`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 137}], {
             RGBColor[
             0.8853958924240121, 0.5320933855736346, 0.23376061447693208`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 150}], {
             RGBColor[
             0.9635307831976114, 0.9324851425902525, 0.6339721646328667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 170}], {
             RGBColor[
             0.8696140479866813, 0.4107872135799805, 0.21864790242070015`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 192}], {
             RGBColor[
             0.8983425131327125, 0.6178053865284491, 0.24561788491389613`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 195}], {
             RGBColor[
             0.8677809264179449, 0.3966970379236798, 0.21689250313626357`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 200}], {
             RGBColor[
             0.9255256121005535, 0.7345007236853389, 0.2726656515103572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 256}], {
             RGBColor[
             0.9801516197044022, 0.9430147833008583, 0.5214481671592728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 299}], {
             RGBColor[
             0.979769906119425, 0.942886287709507, 0.5299077867568601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 53}], {
             RGBColor[
             0.849125567438419, 0.37860621505841235`, 0.19467600489941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 68}], {
             RGBColor[
             0.8633379334396346, 0.4711124376416033, 0.20763043303961218`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 195}], {
             RGBColor[
             0.8449304467632349, 0.34636067923534536`, 0.19065875260314252`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 200}], {
             RGBColor[
             0.8672145142441139, 0.4887150856762938, 0.21086514708656048`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 215}], {
             RGBColor[
             0.9035836038900057, 0.6277240751762379, 0.3789421893819883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 223}], {
             RGBColor[
             0.8676674520716839, 0.4907717705649724, 0.21124308951240708`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 225}], {
             RGBColor[
             0.8922034790216946, 0.5903032781532196, 0.23628645255656144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 234}], {
             RGBColor[
             0.84432219426478, 0.3416853839942764, 0.19007628932369913`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 255}], {
             RGBColor[
             0.8915339731689755, 0.5880448777045486, 0.23368554874431965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 282}], {
             RGBColor[
             0.8931015408528009, 0.6211150707539262, 0.45080473309171465`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 287}], {
             RGBColor[
             0.8855408645250941, 0.5648739230601991, 0.22579206001070665`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 50}], {
             RGBColor[
             0.32229358745653136`, 0.4520407279394575, 0.9418134628870861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 108}], {
             RGBColor[
             0.3180292730157506, 0.448347193101529, 0.9415417445417048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 114}], {
             RGBColor[
             0.29827465777054285`, 0.4308359553953969, 0.9402976725509951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 145}], {
             RGBColor[
             0.280670988716232, 0.4123333830822331, 0.9392951696406466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 169}], {
             RGBColor[
             0.2925815910536258, 0.4248521813146391, 0.9399734608236041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 187}], {
             RGBColor[
             0.32803381097302087`, 0.4570126210374179, 0.9421792248536764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 213}], {
             RGBColor[
             0.3600084250820952, 0.48470742468786476`, 0.9442166189906656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 219}], {
             RGBColor[
             0.2831865614508789, 0.4149774095228705, 0.9394384277864284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 221}], {
             RGBColor[
             0.2933757434234066, 0.4256868858074472, 0.9400186866262199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 264}], {
             RGBColor[
             0.29339971487327476`, 0.42571208132113636`, 0.9400200517648274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 48}], {
             RGBColor[
             0.5288713488786927, 0.6272983725157164, 0.9563690029663805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 74}], {
             RGBColor[
             0.6411369333771564, 0.7195168172815674, 0.9649096076876572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 90}], {
             RGBColor[
             0.5238031310544717, 0.622908536972411, 0.9560460606082701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.5238459246822951, 0.6229456026619612, 0.9560487873803941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 166}], {
             RGBColor[
             0.8183915236203407, 0.8543538869413033, 0.7072534135870767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 177}], {
             RGBColor[
             0.5316337139639098, 0.6296909943120255, 0.956545018426947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 217}], {
             RGBColor[
             0.7255477462839056, 0.7855226808548759, 0.9732794767865461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 233}], {
             RGBColor[
             0.8190741460647206, 0.8558139473261162, 0.781552654000438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 262}], {
             RGBColor[
             0.8190197652374052, 0.8556976322352333, 0.77563363654671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 273}], {
             RGBColor[
             0.6309474410941337, 0.7112445284148133, 0.9641074535297975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 74}], {
             RGBColor[
             0.5259484891930979, 0.6249515173301565, 0.9561210914963576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 84}], {
             RGBColor[
             0.35715044434118537`, 0.4830160061947183, 0.9440058041437522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 90}], {
             RGBColor[
             0.4086146868704133, 0.5283432370210001, 0.9472575444169704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 144}], {
             RGBColor[
             0.3646961975812182, 0.4903032490061542, 0.9444590971150582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 158}], {
             RGBColor[
             0.4086574804982366, 0.5283803027105503, 0.9472602711890945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 175}], {
             RGBColor[
             0.3540970438547585, 0.4798066886867111, 0.9438319175031515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 177}], {
             RGBColor[
             0.4164452697798513, 0.5351256943606145, 0.9477565022356473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 217}], {
             RGBColor[
             0.6103593020998471, 0.6909573809034649, 0.9644909605952465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 252}], {
             RGBColor[
             0.35710710220900627`, 0.48297045086574814`, 0.9440033358734436]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 253}], {
             RGBColor[
             0.3552041377824924, 0.4809703145985687, 0.9438949648645372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 57}], {
             RGBColor[
             0.2418037466004938, 0.3714814472931095, 0.9370817377010874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 84}], {
             RGBColor[
             0.2685862507813846, 0.39963155729606886`, 0.9386069616930247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 112}], {
             RGBColor[
             0.24438397329964223`, 0.374193429149736, 0.9372286777945005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 115}], {
             RGBColor[
             0.22907293102325943`, 0.358100552941108, 0.9363567365875176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 146}], {
             RGBColor[
             0.23350254559126715`, 0.3627563587058691, 0.9366089965841382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 159}], {
             RGBColor[
             0.24197412682758776`, 0.3716605277145155, 0.9370914406029653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 175}], {
             RGBColor[
             0.26553285029495766`, 0.3964222397880617, 0.9384330750524239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 204}], {
             RGBColor[
             0.23371861491604712`, 0.3629834612657993, 0.9366213014125385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 242}], {
             RGBColor[
             0.23849346114208345`, 0.3680021273920998, 0.9368932218413593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 243}], {
             RGBColor[
             0.2273605669768493, 0.3563007497581797, 0.9362592199882902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 253}], {
             RGBColor[
             0.2666399442226916, 0.39758586569991927`, 0.9384961224138098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 280}], {
             RGBColor[
             0.2523064385494426, 0.38252044244058536`, 0.9376798504702395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 292}], {
             RGBColor[
             0.23980801296623738`, 0.36938380470668514`, 0.9369680836230397]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 87}], {
             RGBColor[
             0.314278172622923, 0.4436160187426821, 0.9413569968700557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 108}], {
             RGBColor[
             0.3481847341285709, 0.4760018492537544, 0.9434070012643693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 114}], {
             RGBColor[
             0.32843011888336315`, 0.4584906115476223, 0.9421629292736595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 169}], {
             RGBColor[
             0.3227370521664461, 0.4525068374668645, 0.9418387175462686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 187}], {
             RGBColor[
             0.35818927208584117`, 0.4846672771896433, 0.9440444815763409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 205}], {
             RGBColor[
             0.44094793085644673`, 0.5542815920827796, 0.9498889293247207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 213}], {
             RGBColor[
             0.3901638861949155, 0.5123620808400902, 0.94608187571333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 227}], {
             RGBColor[
             0.30610711869793783`, 0.43502772299278125`, 0.9408916674370189]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 264}], {
             RGBColor[
             0.32355517598609507`, 0.45336673747336176`, 0.9418853084874919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 52}], {
             RGBColor[
             0.8763260533964058, 0.4219467076212655, 0.36184562184045305`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 58}], {
             RGBColor[
             0.7712426526188537, 0.8181426903224094, 0.8569941031084208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 66}], {
             RGBColor[
             0.9700089985303242, 0.9755966228942858, 0.8659381168837096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 67}], {
             RGBColor[
             0.9529402270197467, 0.9622638379796367, 0.8739273734917072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 69}], {
             RGBColor[
             0.9933000659558078, 0.9895615584823135, 0.6199821278730931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 86}], {
             RGBColor[
             0.9842148587859489, 0.9592452118717956, 0.5566107984418112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[
             0.8872853886736406, 0.5061849609734328, 0.372340293678732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 109}], {
             RGBColor[
             0.9573653906056103, 0.9657923433051386, 0.8743494495449171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 110}], {
             RGBColor[
             0.9932540497607107, 0.99147839046011, 0.7614613836320072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 138}], {
             RGBColor[
             0.8501230130531416, 0.8811959449639274, 0.8638775606265587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 141}], {
             RGBColor[
             0.9462822846437602, 0.812940654644517, 0.4968966602614467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 154}], {
             RGBColor[
             0.867381103025232, 0.8946780960164662, 0.8655976857489563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 165}], {
             RGBColor[
             0.986911243979133, 0.9683407522697562, 0.5670857457477134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 179}], {
             RGBColor[
             0.993604348606093, 0.9916232480349453, 0.7556560252196713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 258}], {
             RGBColor[
             0.9776645788146846, 0.9813061421354996, 0.8529792163574066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 281}], {
             RGBColor[
             0.88857163743908, 0.5160716326224021, 0.37357200694912684`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 82}], {
             RGBColor[
             0.8768309043529274, 0.4220373894366231, 0.3448952545426753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 86}], {
             RGBColor[
             0.8700945440512431, 0.4003729911487963, 0.2286822767734516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 107}], {
             RGBColor[
             0.8231876863313796, 0.17923629481773212`, 0.16983786065866233`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 110}], {
             RGBColor[
             0.876120671367751, 0.4218617768743392, 0.3652493335669156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 141}], {
             RGBColor[
             0.8448061612897839, 0.30283661966394393`, 0.18887285131987525`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 165}], {
             RGBColor[
             0.8718921341800324, 0.4064366847474367, 0.2356655749773864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 179}], {
             RGBColor[
             0.8763542039313392, 0.42195834859089604`, 0.36137909462535833`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 193}], {
             RGBColor[
             0.6783045969866766, 0.26489364797125753`, 0.42528589032272945`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 236}], {
             RGBColor[
             0.752875562549565, 0.3264079477812045, 0.43088720708168204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 266}], {
             RGBColor[
             0.6276833304684843, 0.2172812337435776, 0.42219826962255025`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 281}], {
             RGBColor[
             0.8238308107140992, 0.18417963064221682`, 0.17045371729385975`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 59}], {
             RGBColor[
             0.8320894648541852, 0.2476592653282373, 0.1783622138252218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 68}], {
             RGBColor[
             0.8459414855221328, 0.3373957157755989, 0.19097157486733474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 150}], {
             RGBColor[
             0.875154847057984, 0.48698797641356506`, 0.4350772976626226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 170}], {
             RGBColor[
             0.8284505596301013, 0.21968904519749122`, 0.17487759407308337`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 192}], {
             RGBColor[
             0.8428147922031168, 0.3231981316717255, 0.18836258531968136`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 195}], {
             RGBColor[
             0.8275339988457331, 0.2126439573693409, 0.17399989443086508`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 200}], {
             RGBColor[
             0.849818066326612, 0.3549983638102894, 0.19420628891428304`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 225}], {
             RGBColor[
             0.8748070311041928, 0.4565865562872151, 0.219627594384284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 234}], {
             RGBColor[
             0.8269257463472781, 0.20796866212827195`, 0.17341743115142172`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 255}], {
             RGBColor[
             0.8741375252514738, 0.45432815583854413`, 0.2170266905720422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 282}], {
             RGBColor[
             0.8757050929352991, 0.4873983488879218, 0.43414587491943724`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 287}], {
             RGBColor[
             0.8681444166075922, 0.43115720119419465`, 0.20913320183842923`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 72}], {
             RGBColor[
             0.534606977221836, 0.6319372303906756, 0.9568737438527076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 106}], {
             RGBColor[
             0.5370375913061106, 0.6338360445866622, 0.9571160047492481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 151}], {
             RGBColor[
             0.4303399784091667, 0.5471605926069658, 0.9486418607828988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 167}], {
             RGBColor[
             0.585666437251012, 0.671825268631737, 0.9619628736506332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 194}], {
             RGBColor[
             0.4666198015964266, 0.5768869180196359, 0.9514225850947327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 238}], {
             RGBColor[
             0.34796050319161576`, 0.47301253149465217`, 0.9434950557775005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 251}], {
             RGBColor[
             0.3520600889143901, 0.4773214560180356, 0.9437285211196189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 286}], {
             RGBColor[
             0.4882211414959945, 0.5944238588793778, 0.953123121699942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 90}], {
             RGBColor[
             0.3401206359010615, 0.4660537805054501, 0.9430016668956538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 97}], {
             RGBColor[
             0.26708761639868417`, 0.39805639754094285`, 0.9385216166819608]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 134}], {
             RGBColor[
             0.27534778812989436`, 0.40673836175558137`, 0.9389920212422243]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 144}], {
             RGBColor[
             0.2962021466118664, 0.42801379249060423`, 0.9402032195937415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 159}], {
             RGBColor[
             0.26204426941803677`, 0.39275552009761494`, 0.9382344055323761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 235}], {
             RGBColor[
             0.25936698600148883`, 0.38994152547725025`, 0.9380819382024896]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 252}], {
             RGBColor[
             0.2886130512396545, 0.4206809943501981, 0.9397474583521269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 253}], {
             RGBColor[
             0.2867100868131406, 0.4186808580830187, 0.9396390873432205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 292}], {
             RGBColor[
             0.25987815555668636`, 0.39047879708978456`, 0.9381110485524506]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 79}], {
             RGBColor[
             0.47131158576889715`, 0.5800856534095411, 0.9519605579459619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 93}], {
             RGBColor[
             0.5394509250519448, 0.6369895888012234, 0.9568866993753897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 160}], {
             RGBColor[
             0.5689561966042058, 0.6609432974446849, 0.9592094624333546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 164}], {
             RGBColor[
             0.46580833431938506`, 0.5753190136054342, 0.9516098956299331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 168}], {
             RGBColor[
             0.46678271330407606`, 0.5761629717082618, 0.9516719821972282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 246}], {
             RGBColor[
             0.57328015808247, 0.6644536841649844, 0.9595498605201163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 296}], {
             RGBColor[
             0.6219639893106997, 0.70315209105388, 0.9639467061714042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.27383547980684575`, 0.4051488298221716, 0.9389058975204863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 89}], {
             RGBColor[
             0.26259271630004477`, 0.3933319725441461, 0.9382656387709521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 112}], {
             RGBColor[
             0.24963320232510341`, 0.37971070167583876`, 0.9375276136219621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 115}], {
             RGBColor[
             0.2343221600487206, 0.3636178254672108, 0.9366556724149793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 134}], {
             RGBColor[
             0.26052687456490653`, 0.3911606418985847, 0.938147992140275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 146}], {
             RGBColor[
             0.23875177461672836`, 0.3682736312319718, 0.9369079324115999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 159}], {
             RGBColor[
             0.24722335585304894`, 0.3771778002406183, 0.937390376430427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 175}], {
             RGBColor[
             0.27078207932041887`, 0.40193951231416447`, 0.9387320108798856]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 204}], {
             RGBColor[
             0.23896784394150833`, 0.36850073379190207`, 0.9369202372400001]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 235}], {
             RGBColor[
             0.24454607243650103`, 0.3743638056202535, 0.9372379091005405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 242}], {
             RGBColor[
             0.24374269016754463`, 0.3735193999182025, 0.9371921576688209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 243}], {
             RGBColor[
             0.23260979600231052`, 0.3618180222842825, 0.9365581558157519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 253}], {
             RGBColor[
             0.27188917324815276`, 0.40310313822602206`, 0.9387950582412713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 280}], {
             RGBColor[
             0.2575556675749038, 0.38803771496668804`, 0.9379787862977012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 292}], {
             RGBColor[
             0.2450572419916986, 0.37490107723278787`, 0.9372670194505013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 66}], {
             RGBColor[
             0.747689528345485, 0.802133526636196, 0.966576403949817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 67}], {
             RGBColor[
             0.7306207568349073, 0.7888007417215468, 0.9745656605578148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 73}], {
             RGBColor[
             0.4389666532110068, 0.5520366798791193, 0.9499088011180912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 95}], {
             RGBColor[
             0.5187848450827122, 0.6202119340859072, 0.9552597898578664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 96}], {
             RGBColor[
             0.47719454661287236`, 0.585147759754026, 0.9523446486820593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 109}], {
             RGBColor[
             0.7350459204207711, 0.7923292470470489, 0.9749877366110247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 138}], {
             RGBColor[
             0.6278035428683023, 0.7077328487058376, 0.9645158476926661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 140}], {
             RGBColor[
             0.4384985979215843, 0.5516312739125644, 0.9498789770489342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 154}], {
             RGBColor[
             0.6450616328403926, 0.7212149997583763, 0.9662359728150638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 171}], {
             RGBColor[
             0.48363824484440066`, 0.5907289672924857, 0.9527552354354336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 198}], {
             RGBColor[
             0.506589269540044, 0.610311016455952, 0.9542997094772824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[
             0.48666290222101594`, 0.5933487734884098, 0.952947963928872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 62}], {
             RGBColor[
             0.8868230148643443, 0.4992626353588674, 0.34626643898134246`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 100}], {
             RGBColor[
             0.8386002140561873, 0.2977037367233178, 0.18459691461389852`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 125}], {
             RGBColor[
             0.8860818256794646, 0.49767730663813153`, 0.2655925702966138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 137}], {
             RGBColor[
             0.8370621725153026, 0.28588167546597704`, 0.1831240842973778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 170}], {
             RGBColor[
             0.8291712502966372, 0.22522858946914998`, 0.17556772826926184`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 192}], {
             RGBColor[
             0.8435354828696529, 0.32873767594338427`, 0.18905271951585984`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 195}], {
             RGBColor[
             0.828254689512269, 0.21818350164099967`, 0.17469002862704355`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 200}], {
             RGBColor[
             0.850538756993148, 0.3605379080819481, 0.19489642311046151`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 225}], {
             RGBColor[
             0.8755277217707287, 0.4621261005588738, 0.22031772858046247`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 228}], {
             RGBColor[
             0.8273211846534105, 0.45428347736572383`, 0.4468112731339182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 255}], {
             RGBColor[
             0.8748582159180097, 0.45986770011020284`, 0.21771682476822068`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.9605795624965958, 0.8682632028416796, 0.48244356084256446`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 85}], {
             RGBColor[
             0.9228540566499766, 0.8416985659067688, 0.6257891591988634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 100}], {
             RGBColor[
             0.875481037191391, 0.5060252518657031, 0.21691816771131295`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 121}], {
             RGBColor[
             0.9603462863275016, 0.8677642487038257, 0.4570528894502983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 125}], {
             RGBColor[
             0.9593538076584427, 0.8656414371856946, 0.3490277111915949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 127}], {
             RGBColor[
             0.8638755462529181, 0.416820362954043, 0.20580473648210393`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.9594950595498875, 0.8659435606987382, 0.3644021078697419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 137}], {
             RGBColor[
             0.8724049541096216, 0.4823811293510216, 0.2139725070782716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 170}], {
             RGBColor[
             0.8566231096722907, 0.3610749573573675, 0.19885979502203965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 232}], {
             RGBColor[
             0.9600894947352094, 0.8672149974535253, 0.4291027093633025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 240}], {
             RGBColor[
             0.9605080040332614, 0.868110146524278, 0.47465486371626864`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 256}], {
             RGBColor[
             0.9606652122328164, 0.8684463989669389, 0.49176600606128196`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 299}], {
             RGBColor[
             0.9602834986478392, 0.8683179033755875, 0.5002256256588694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 177}], {
             RGBColor[
             0.49302351294995017`, 0.5983715477396933, 0.9534876687205165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 217}], {
             RGBColor[
             0.686937545269946, 0.7542032342825437, 0.9702221270801157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 247}], {
             RGBColor[
             0.5729638190353659, 0.6641968658756336, 0.9595249571515402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 267}], {
             RGBColor[
             0.517343318582302, 0.6190416379328455, 0.9551463076112685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 273}], {
             RGBColor[
             0.5923372400801741, 0.6799250818424811, 0.9610501038233672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 285}], {
             RGBColor[
             0.474805368949063, 0.5825919070766665, 0.9523268246944521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 82}], {
             RGBColor[
             0.9949627046124243, 0.9916340594516913, 0.6930996675251034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 100}], {
             RGBColor[
             0.8984031319352767, 0.588272489605711, 0.35735557216633895`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 127}], {
             RGBColor[
             0.8867976409968038, 0.49906760069405076`, 0.3462421409371299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 130}], {
             RGBColor[
             0.5868878667757954, 0.648392143438405, 0.8070978104506135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 137}], {
             RGBColor[
             0.8953270488535073, 0.5646283670910295, 0.3544099115332976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 170}], {
             RGBColor[
             0.8795452044161765, 0.44332219509737536`, 0.3392971994770656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 192}], {
             RGBColor[
             0.9082736695622077, 0.6503403680458439, 0.3662671819702616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 195}], {
             RGBColor[
             0.8777120828474402, 0.4292320194410746, 0.3375418001926291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 199}], {
             RGBColor[
             0.5868878667757954, 0.648392143438405, 0.8070978104506135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 220}], {
             RGBColor[
             0.6260202363274255, 0.6895227449727015, 0.8093263410054259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 225}], {
             RGBColor[
             0.9779057939111673, 0.9356854846768198, 0.49177155529990685`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 226}], {
             RGBColor[
             0.5868878718865363, 0.6483921488101179, 0.8070978107416625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 228}], {
             RGBColor[
             0.90559598823519, 0.9239215498870947, 0.8315118721300905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 255}], {
             RGBColor[
             0.9769015351320889, 0.9322978840038133, 0.4878701995815442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 131}], {
             RGBColor[
             0.32467225096411007`, 0.4556365181084638, 0.9419088066284024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 139}], {
             RGBColor[
             0.28999599813964694`, 0.42067676560446166`, 0.9398795920978575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 143}], {
             RGBColor[
             0.36063166824627285`, 0.4867827579854089, 0.9442001088999576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 172}], {
             RGBColor[
             0.29700434513925705`, 0.4280429826559164, 0.940278707091565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 174}], {
             RGBColor[
             0.35841838866408615`, 0.48486572645398507`, 0.944059080682107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 183}], {
             RGBColor[
             0.28955139027076127`, 0.4202094545444958, 0.939854272337463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 283}], {
             RGBColor[
             0.4716182093057971, 0.5784225844464469, 0.9525129877054703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 92}], {
             RGBColor[
             0.24737632360791623`, 0.3773385790496996, 0.9373990877177711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 145}], {
             RGBColor[
             0.2514296244944172, 0.3815988552755316, 0.937629917206936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 153}], {
             RGBColor[
             0.253568524812987, 0.38384697512446136`, 0.9377517244158591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 211}], {
             RGBColor[
             0.238007335368493, 0.36749117838190204`, 0.936865537697712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 219}], {
             RGBColor[
             0.2539451972290641, 0.384242881716169, 0.9377731753527179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 221}], {
             RGBColor[
             0.26413437920159183`, 0.3949523580007457, 0.9383534341925093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 80}], {
             RGBColor[
             0.27787319023653523`, 0.40939271948940265`, 0.9391358391561999]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 103}], {
             RGBColor[
             0.2833667383517215, 0.41516678686953135`, 0.9394486885943836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 116}], {
             RGBColor[
             0.3051622199360282, 0.4368120893539453, 0.940736158424998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 133}], {
             RGBColor[
             0.3190318248130566, 0.44882524399181684`, 0.9416199173833522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 152}], {
             RGBColor[
             0.270606352963235, 0.4017548127710696, 0.9387220035238077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 162}], {
             RGBColor[
             0.28622167127698683`, 0.41816750238718753`, 0.9396112728009827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[
             0.33323684341077736`, 0.46112891713616844`, 0.9425250486073942]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 241}], {
             RGBColor[
             0.2834960053804121, 0.4153026547126882, 0.9394560501604341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 277}], {
             RGBColor[
             0.318505826054183, 0.44836965030434695`, 0.9415864012075592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 67}], {
             RGBColor[
             0.9293871027463778, 0.9462546742934231, 0.9835096743331035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 69}], {
             RGBColor[
             0.9697469416824389, 0.9735523947961, 0.7295644287144893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 95}], {
             RGBColor[
             0.7175511909941827, 0.7776658666577836, 0.9642038036331552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 109}], {
             RGBColor[
             0.9338122663322416, 0.9497831796189251, 0.9839317503863134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 110}], {
             RGBColor[
             0.969700925487342, 0.9754692267738965, 0.8710436844734033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 138}], {
             RGBColor[
             0.8265698887797728, 0.8651867812777139, 0.9734598614679548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 154}], {
             RGBColor[
             0.8438279787518632, 0.8786689323302527, 0.9751799865903525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 179}], {
             RGBColor[
             0.9700512243327243, 0.9756140843487318, 0.8652383260610674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 258}], {
             RGBColor[
             0.9541114545413159, 0.9652969784492861, 0.9625615171988029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 69}], {
             RGBColor[
             0.9526781701718614, 0.9602196098814508, 0.7375536853224871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 86}], {
             RGBColor[
             0.9435929630020026, 0.929903263270933, 0.6741823558912051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 95}], {
             RGBColor[
             0.7004824194836051, 0.7643330817431344, 0.9721930602411528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 109}], {
             RGBColor[
             0.916743494821664, 0.9364503947042759, 0.9919210069943111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 110}], {
             RGBColor[
             0.9526321539767644, 0.9621364418592473, 0.8790329410814011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 138}], {
             RGBColor[
             0.8095011172691953, 0.8518539963630647, 0.9814491180759526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 154}], {
             RGBColor[
             0.8267592072412856, 0.8653361474156035, 0.9831692431983503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 179}], {
             RGBColor[
             0.9529824528221467, 0.9622812994340826, 0.8732275826690652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 258}], {
             RGBColor[
             0.9370426830307382, 0.9519641935346369, 0.9705507738068005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 215}], {
             RGBColor[
             0.9347347232001206, 0.7573256172439325, 0.47384806566130333`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 223}], {
             RGBColor[
             0.880860495472638, 0.5518971603270344, 0.22229941585693147`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 234}], {
             RGBColor[
             0.8363347391748547, 0.263554053647327, 0.18177214371591305`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 255}], {
             RGBColor[
             0.9166602771185755, 0.6978068210363987, 0.2559631047048003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 271}], {
             RGBColor[
             0.9259155815977133, 0.7290271362933656, 0.2919182148886562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 274}], {
             RGBColor[
             0.9194708353599413, 0.7072874939349834, 0.2668815927431183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 287}], {
             RGBColor[
             0.9076706141527531, 0.6630503890698746, 0.24412287160438084`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 109}], {
             RGBColor[
             0.957103333757725, 0.9637481152069529, 0.737975761375697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 110}], {
             RGBColor[
             0.9929919929128255, 0.9894341623619243, 0.625087695462787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 113}], {
             RGBColor[
             0.9762236487706943, 0.9783827123378863, 0.71860105300982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 135}], {
             RGBColor[
             0.9915668730357023, 0.9888448386688236, 0.6487056199187353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 138}], {
             RGBColor[
             0.8498609562052564, 0.8791517168657417, 0.7275038724573385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 224}], {
             RGBColor[
             0.9812813612748328, 0.9481895871324358, 0.4098590677551779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 249}], {
             RGBColor[
             0.8767326483234027, 0.4250520115136651, 0.27148648277790555`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 254}], {
             RGBColor[
             0.9421799602264942, 0.7934586684310521, 0.3573185586987633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 258}], {
             RGBColor[
             0.9774025219667993, 0.9792619140373138, 0.7166055281881865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 288}], {
             RGBColor[
             0.9056134125186948, 0.6397104688969287, 0.29885564217207405`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[
             0.27137415800540265`, 0.40256182455203926`, 0.9387657288850935]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 251}], {
             RGBColor[
             0.27547374372817707`, 0.40687074907542276`, 0.9389991942272118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 300}], {
             RGBColor[
             0.2600472811884571, 0.39065655885195993`, 0.938120680006981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 85}], {
             RGBColor[
             0.7746111080065263, 0.8244612139777192, 0.9780896021036154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 98}], {
             RGBColor[
             0.5262018737865255, 0.625404972246536, 0.9560725859325541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 121}], {
             RGBColor[
             0.8121033376840514, 0.8505268967747761, 0.8093533323550504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 122}], {
             RGBColor[
             0.6268946494046528, 0.707980343525642, 0.9637705896733515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 136}], {
             RGBColor[
             0.8112521109064372, 0.8487062087696886, 0.716702550774494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 160}], {
             RGBColor[
             0.6099082730566356, 0.6941900379787878, 0.9624333599040888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 181}], {
             RGBColor[
             0.6717068148993812, 0.7432662316253906, 0.9680467833618187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 207}], {
             RGBColor[
             0.6875924129964879, 0.7556761815938675, 0.9696301113207838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 232}], {
             RGBColor[
             0.8118465460917592, 0.8499776455244756, 0.7814031522680547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 240}], {
             RGBColor[
             0.8122650553898112, 0.8508727945952284, 0.8269553066210207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 246}], {
             RGBColor[
             0.6142322345348998, 0.6977004246990872, 0.9627737579908505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 256}], {
             RGBColor[
             0.8124222635893662, 0.8512090470378892, 0.8440664489660341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 296}], {
             RGBColor[
             0.6629160657631297, 0.7363988315879828, 0.9671706036421385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 299}], {
             RGBColor[
             0.812040550004389, 0.8510805514465378, 0.8525260685636215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 106}], {
             RGBColor[
             0.6542381545327312, 0.7298150858058879, 0.966172003106812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 151}], {
             RGBColor[
             0.5475405416357872, 0.6431396338261914, 0.9576978591404627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 194}], {
             RGBColor[
             0.5838203648230471, 0.6728659592388615, 0.9604785834522965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 215}], {
             RGBColor[
             0.8234553846620669, 0.8600796725778928, 0.8483727211925696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 247}], {
             RGBColor[
             0.6154478937421781, 0.6985426120193529, 0.9629684183842664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 267}], {
             RGBColor[
             0.5598273932891142, 0.6533873840765647, 0.9585897688439947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 286}], {
             RGBColor[
             0.6054217047226151, 0.6904029000986035, 0.9621791200575058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 87}], {
             RGBColor[
             0.3025587103322468, 0.4334652095438001, 0.9406102430960075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 95}], {
             RGBColor[
             0.4088283158597046, 0.5275690199007069, 0.9475362008014293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 96}], {
             RGBColor[
             0.3672380173898648, 0.4925048455688256, 0.9446210596256222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 105}], {
             RGBColor[
             0.30909022810020703`, 0.4403302488400713, 0.9409822033703782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 140}], {
             RGBColor[
             0.3285420686985767, 0.45898835972736407`, 0.9421553879924971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 149}], {
             RGBColor[
             0.3114795465639533, 0.4428415740370091, 0.9411182715222086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 171}], {
             RGBColor[
             0.3736817156213931, 0.4980860531072854, 0.9450316463789965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 245}], {
             RGBColor[
             0.37670637299800835`, 0.5007058593032094, 0.9452243748724349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 289}], {
             RGBColor[
             0.309996695985159, 0.44128300406053933`, 0.9410338253754271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 298}], {
             RGBColor[
             0.307131102255913, 0.43827108336196546`, 0.9408706340518126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 90}], {
             RGBColor[
             0.5208802713688769, 0.620561681786851, 0.9557981491382472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 123}], {
             RGBColor[
             0.5372173592410554, 0.6347120461758202, 0.9568391339311428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 158}], {
             RGBColor[
             0.5209230649967003, 0.6205987474764012, 0.9558008759103712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 233}], {
             RGBColor[
             0.8161512863791258, 0.8534670921405562, 0.7813047425304152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 257}], {
             RGBColor[
             0.5147596974188978, 0.6152603482603705, 0.9554081515783656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 259}], {
             RGBColor[
             0.5512374616169957, 0.646558430162153, 0.9578145787092965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 262}], {
             RGBColor[
             0.8160969055518104, 0.8533507770496733, 0.7753857250766871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 124}], {
             RGBColor[
             0.8391031020269322, 0.8749559056354701, 0.9735996156850079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 142}], {
             RGBColor[
             0.6947680744610263, 0.7614773672926725, 0.9702116467516284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 143}], {
             RGBColor[
             0.5636312232942053, 0.6537338940348352, 0.9601379235387875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 150}], {
             RGBColor[
             0.8462593507356758, 0.8802930242051693, 0.9614859532696918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 167}], {
             RGBColor[
             0.7422194299230214, 0.7985467268232416, 0.9749411544059516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 174}], {
             RGBColor[
             0.5614179437120186, 0.6518168625034114, 0.9599968953209368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 185}], {
             RGBColor[
             0.6492913495741017, 0.7248125960357876, 0.9664570141991338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 237}], {
             RGBColor[
             0.6846458552140906, 0.7535149764166593, 0.969240250390935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 239}], {
             RGBColor[
             0.5708233361978141, 0.6599633407458361, 0.9605961986132696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 282}], {
             RGBColor[
             0.8470847195516484, 0.8809085829167043, 0.9600888191549137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 283}], {
             RGBColor[
             0.6746177643537297, 0.7453737204958732, 0.9684508023443001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 295}], {
             RGBColor[
             0.7838985892899054, 0.8312466386518764, 0.9790582353871675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 297}], {
             RGBColor[
             0.7454557140194038, 0.8010749365560057, 0.9752637169598848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 99}], {
             RGBColor[
             0.3308920068686242, 0.45968772172522177`, 0.9423540428096366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[
             0.2896837321277139, 0.4218063478486378, 0.9398084320447715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 128}], {
             RGBColor[
             0.2667781164198233, 0.397731093439728, 0.9385039911160289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[
             0.3201380287875101, 0.4503731664220151, 0.9416688088356775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 201}], {
             RGBColor[
             0.3077043294157084, 0.43960372096206174`, 0.9408765445063949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 209}], {
             RGBColor[
             0.2797259704782522, 0.4113401089964994, 0.9392413522500229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 218}], {
             RGBColor[
             0.2751691719679872, 0.4065506248444982, 0.9389818493160426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 229}], {
             RGBColor[
             0.32034218545595194`, 0.4505499966670069, 0.9416818175180619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 261}], {
             RGBColor[
             0.3474685023612617, 0.4740454489620557, 0.9434102824444082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 284}], {
             RGBColor[
             0.2749699198453155, 0.406341198230256, 0.9389705022024235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 91}], {
             RGBColor[
             0.25932242623621204`, 0.38989469033869195`, 0.9380794005897775]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 162}], {
             RGBColor[
             0.26527957680517633`, 0.3961560332918348, 0.9384186515018654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 191}], {
             RGBColor[
             0.24496070190330402`, 0.37479960747889, 0.9372615216352855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 203}], {
             RGBColor[
             0.25281317669126346`, 0.38305305635669296`, 0.9377087084577643]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 206}], {
             RGBColor[
             0.2413530899135048, 0.3710077785417997, 0.9370560734694501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 244}], {
             RGBColor[
             0.2442718082387917, 0.3740755365591065, 0.9372222901602183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 270}], {
             RGBColor[
             0.23714390206690406`, 0.36658365523709874`, 0.9368163664485216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 118}], {
             RGBColor[
             0.17948494456776543`, 0.30598043511645023`, 0.9335327741177293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 120}], {
             RGBColor[
             0.1849774474258748, 0.3117534038651181, 0.9338455640300687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 130}], {
             RGBColor[
             0.17948366008578914`, 0.30597908504445237`, 0.9335327009683809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 176}], {
             RGBColor[
             0.17949609924511575`, 0.30599215938959284`, 0.9335334093601024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 193}], {
             RGBColor[
             0.2897690368730418, 0.4135053888596902, 0.9401205117129523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.17948366008578914`, 0.30597908504445237`, 0.9335327009683809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 220}], {
             RGBColor[
             0.21861602963741927`, 0.34710968657874874`, 0.9357612315231933]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 226}], {
             RGBColor[
             0.17948366519653014`, 0.30597909041616517`, 0.9335327012594301]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 236}], {
             RGBColor[
             0.4016254852173745, 0.5057768385746106, 0.9485224868513811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 266}], {
             RGBColor[
             0.21383713709575333`, 0.3420867675181703, 0.9354890806626834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 93}], {
             RGBColor[
             0.46307011169266854`, 0.5733948534802826, 0.9513117589171669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 103}], {
             RGBColor[
             0.33687382527310783`, 0.4634377566971172, 0.9427875991368931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 116}], {
             RGBColor[
             0.3586693068574145, 0.48508305918153105`, 0.9440750689675076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 119}], {
             RGBColor[
             0.3385777508483834, 0.465228690511853, 0.9428846351776731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 164}], {
             RGBColor[
             0.38942752096010885`, 0.5117242782844935, 0.9460349551717104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 168}], {
             RGBColor[
             0.3904018999447999, 0.5125682363873212, 0.9460970417390054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 241}], {
             RGBColor[
             0.3370030923017984, 0.46357362454027395`, 0.9427949607029437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[
             0.3720129129755694, 0.49664062013193266`, 0.9449253117500688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 103}], {
             RGBColor[
             0.2733233300214085, 0.4046105279255051, 0.9388767313478634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 116}], {
             RGBColor[
             0.2951188116057152, 0.426255830409919, 0.9401642011784779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 133}], {
             RGBColor[
             0.30898841648274356`, 0.43826898504779055`, 0.941047960136832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 152}], {
             RGBColor[
             0.26056294463292196`, 0.39119855382704327`, 0.9381500462772876]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 210}], {
             RGBColor[
             0.3231934350804644, 0.45057265819214215`, 0.941953091360874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 241}], {
             RGBColor[
             0.27345259705009906`, 0.4047463957686619, 0.938884092913914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 277}], {
             RGBColor[
             0.30846241772387, 0.4378133913603206, 0.9410144439610391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 180}], {
             RGBColor[
             0.26493370488523493`, 0.3957924999744301, 0.9383989546076965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[
             0.3818442604921369, 0.5035684061042389, 0.9457044452357559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 285}], {
             RGBColor[
             0.33930631085889784`, 0.4671186752480599, 0.9428849623189395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 100}], {
             RGBColor[
             0.898479112642499, 0.5884350046556317, 0.36562560324892335`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 107}], {
             RGBColor[
             0.8877902396301622, 0.5062756427887904, 0.35538992638095424`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 127}], {
             RGBColor[
             0.8868736217040262, 0.4992301157439715, 0.35451217201971436`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 137}], {
             RGBColor[
             0.8954030295607297, 0.5647908821409502, 0.362679942615882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 192}], {
             RGBColor[
             0.90834965026943, 0.6505028830957647, 0.37453721305284604`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 199}], {
             RGBColor[
             0.587001837836629, 0.6486359160132862, 0.81950285707449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 220}], {
             RGBColor[
             0.6261342073882591, 0.6897665175475827, 0.8217313876293025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 226}], {
             RGBColor[
             0.5870018429473699, 0.648635921384999, 0.8195028573655392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 228}], {
             RGBColor[
             0.9057099592960236, 0.9241653224619759, 0.8439169187539672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 266}], {
             RGBColor[
             0.6213553148465931, 0.6847435984870042, 0.8214592367687926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 281}], {
             RGBColor[
             0.8890764883956016, 0.5161623144377598, 0.3566216396513491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 126}], {
             RGBColor[
             0.22111352999763184`, 0.3497347178080009, 0.9359034604739869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 155}], {
             RGBColor[
             0.21429563561346426`, 0.34256867853076955`, 0.9355151914749793]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 156}], {
             RGBColor[
             0.221993745626472, 0.35065988024280614`, 0.935953587451887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 184}], {
             RGBColor[
             0.22686279734830417`, 0.3557775623181615, 0.9362308727443287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[
             0.21339436331142053`, 0.34162138419735716`, 0.9354638653506908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 202}], {
             RGBColor[
             0.22220476853383342`, 0.3508816786980681, 0.9359656048942807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 214}], {
             RGBColor[
             0.21458531177906248`, 0.342873146547343, 0.9355316881040727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 275}], {
             RGBColor[
             0.214533530595458, 0.34281872124025803`, 0.9355287392422698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 293}], {
             RGBColor[
             0.21277489873276917`, 0.34097028764887183`, 0.9354285877593523]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 89}], {
             RGBColor[
             0.2893752204809355, 0.4214820825471055, 0.9397908627628895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.35208222651696447`, 0.4786261706514128, 0.9436828617856419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 112}], {
             RGBColor[
             0.2764157065059942, 0.4078608116787981, 0.9390528376138995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 134}], {
             RGBColor[
             0.2873093787457973, 0.41931075190154404`, 0.9396732161322123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 144}], {
             RGBColor[
             0.30816373722776935`, 0.4405861826365669, 0.9408844144837296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 158}], {
             RGBColor[
             0.35212502014478775`, 0.47866323634096297`, 0.943685588557766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 159}], {
             RGBColor[
             0.27400586003393973`, 0.4053279102435776, 0.9389156004223643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 175}], {
             RGBColor[
             0.29756458350130965`, 0.4300896223171238, 0.940257234871823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 252}], {
             RGBColor[
             0.30057464185555743`, 0.4332533844961608, 0.9404286532421151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 253}], {
             RGBColor[
             0.29867167742904355`, 0.43125324822898137`, 0.9403202822332086]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 280}], {
             RGBColor[
             0.28433817175579457`, 0.41618782496964746`, 0.9395040102896386]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 292}], {
             RGBColor[
             0.2718397461725893, 0.40305118723574723`, 0.9387922434424387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[
             0.9571178936575444, 0.9648142409538079, 0.8234596411130128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 122}], {
             RGBColor[
             0.7719092053781459, 0.8222676877046737, 0.9778768984313139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 136}], {
             RGBColor[
             0.9562666668799304, 0.9629935529487204, 0.7308088595324563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 165}], {
             RGBColor[
             0.9499430145672961, 0.9419121380578821, 0.6850057931573457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 181}], {
             RGBColor[
             0.8167213708728744, 0.8575535758044224, 0.9821530921197811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 207}], {
             RGBColor[
             0.8326069689699811, 0.8699635257728993, 0.9837364200787462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 232}], {
             RGBColor[
             0.9568611020652522, 0.9642649897035074, 0.7955094610260169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 240}], {
             RGBColor[
             0.9572796113633043, 0.9651601387742601, 0.8410616153789832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 246}], {
             RGBColor[
             0.759246790508393, 0.811987768878119, 0.9768800667488129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 256}], {
             RGBColor[
             0.9574368195628593, 0.965496391216921, 0.8581727577239964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 296}], {
             RGBColor[
             0.8079306217366228, 0.8506861757670146, 0.9812769124001008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 299}], {
             RGBColor[
             0.9570551059778822, 0.9653678956255696, 0.8666323773215838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 107}], {
             RGBColor[
             0.8810538793284779, 0.48461124450096366`, 0.2391769486117305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 109}], {
             RGBColor[
             0.9480181265878662, 0.9334317685964351, 0.674604431944415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 110}], {
             RGBColor[
             0.9839067857429666, 0.9591178157514064, 0.561716366031505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 141}], {
             RGBColor[
             0.936935020626016, 0.7805800799358134, 0.2971516426609445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 165}], {
             RGBColor[
             0.9775639799613888, 0.9359801775610526, 0.3673407281472113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 179}], {
             RGBColor[
             0.9842570845883489, 0.9592626733262417, 0.5559110076191691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 240}], {
             RGBColor[
             0.984900576757397, 0.9592281782774306, 0.5233965503688487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 281}], {
             RGBColor[
             0.8823401280939172, 0.49449791614993305`, 0.24040866188212537`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 149}], {
             RGBColor[
             0.2850281329082009, 0.41691301788689017`, 0.939543302556562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 187}], {
             RGBColor[
             0.3200183961394125, 0.4485879118406425, 0.9417227588366461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 227}], {
             RGBColor[
             0.2679362427515092, 0.39894835764378045`, 0.938569944697324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 264}], {
             RGBColor[
             0.2853843000396664, 0.4172873721243609, 0.939563585747797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 99}], {
             RGBColor[
             0.43585477652737337`, 0.5505550934269655, 0.9493751482779511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[
             0.7318152240398965, 0.7888182862268713, 0.9538534747537719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 198}], {
             RGBColor[
             0.48423825814620036`, 0.592165458504841, 0.9525401559859066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 201}], {
             RGBColor[
             0.41266709907445764`, 0.5304710926638055, 0.9478976499747094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 222}], {
             RGBColor[
             0.47017691950032614`, 0.5802832085890723, 0.9515621248783083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 258}], {
             RGBColor[
             0.7329940972360016, 0.7896974879262988, 0.9518579499321382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 260}], {
             RGBColor[
             0.6766874696871867, 0.7454723343623321, 0.9697937614112038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 261}], {
             RGBColor[
             0.4524312720200109, 0.5649128206637994, 0.9504313879127225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 278}], {
             RGBColor[
             0.553576335347311, 0.6484572332214837, 0.9579987034169237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 290}], {
             RGBColor[
             0.558574938782711, 0.6525153246748602, 0.9583922117898461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 111}], {
             RGBColor[
             0.26057341862775985`, 0.3912095626597075, 0.9381506427557986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 112}], {
             RGBColor[
             0.26517294299919314`, 0.39604395440077267`, 0.9384125788643654]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 175}], {
             RGBColor[
             0.28632181999450856`, 0.4182727650390983, 0.9396169761222888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 177}], {
             RGBColor[
             0.3486700459196015, 0.47359177071300174`, 0.9435415608547846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 242}], {
             RGBColor[
             0.2592824308416344, 0.3898526526431364, 0.9380771229112241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.27309540824899353`, 0.40437096769162195`, 0.9388637515401044]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 285}], {
             RGBColor[
             0.3304519019187142, 0.457812130049975, 0.9423807168287202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 123}], {
             RGBColor[
             0.4198835569183708, 0.5381037658666636, 0.9479755868517558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 134}], {
             RGBColor[
             0.3387736212750252, 0.46463798272782586`, 0.9429249564054306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 144}], {
             RGBColor[
             0.35962797975699734`, 0.48591341346284866`, 0.9441361547569478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 158}], {
             RGBColor[
             0.4035892626740157, 0.5239904671672448, 0.9469373288309841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 252}], {
             RGBColor[
             0.35203888438478537`, 0.4785806153224426, 0.9436803935153333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 253}], {
             RGBColor[
             0.3501359199582715, 0.4765804790552632, 0.9435720225064269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[
             0.39742589509621323`, 0.518652067951214, 0.9465446044989785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 102}], {
             RGBColor[
             0.3289676178309032, 0.4560161547537128, 0.9423048264494448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 162}], {
             RGBColor[
             0.27856959341816107`, 0.4101246833878033, 0.9391754982871572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 191}], {
             RGBColor[
             0.2582507185162887, 0.38876825757485856`, 0.9380183684205773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 203}], {
             RGBColor[
             0.2661031933042482, 0.39702170645266144`, 0.9384655552430561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 239}], {
             RGBColor[
             0.3418733579527955, 0.46719445818593675`, 0.9431271687979139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 153}], {
             RGBColor[
             0.26728945052082176`, 0.3982685380003319, 0.9385331108366297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 163}], {
             RGBColor[
             0.25122830224652154`, 0.3813872528284255, 0.937618452202748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 189}], {
             RGBColor[
             0.2464728493758267, 0.3763889703481986, 0.937347636196824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 211}], {
             RGBColor[
             0.2517282610763278, 0.3819127412577725, 0.9376469241184826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 216}], {
             RGBColor[
             0.25996759819388404`, 0.3905728069724701, 0.9381161421783205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 221}], {
             RGBColor[
             0.27785530490942656`, 0.40937392087661617`, 0.9391348206132799]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 94}], {
             RGBColor[
             0.6965792865266065, 0.7615288190518337, 0.9714662855765266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 160}], {
             RGBColor[
             0.5607147225279772, 0.6542524975154264, 0.9585606634045596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 164}], {
             RGBColor[
             0.45756686024315646`, 0.5686282136761757, 0.9509610966011381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 168}], {
             RGBColor[
             0.4585412392278475, 0.5694721717790032, 0.9510231831684333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 277}], {
             RGBColor[
             0.440152252258617, 0.5535445555236148, 0.9498514531794966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 124}], {
             RGBColor[
             0.9048214633960636, 0.926634777474092, 0.9800597975853467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 125}], {
             RGBColor[
             0.9272871440372241, 0.9396965749731525, 0.7126838428267497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 142}], {
             RGBColor[
             0.7604864358301577, 0.8131562391312941, 0.9766718286519673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 150}], {
             RGBColor[
             0.9119777121048072, 0.931971896043791, 0.9679461351700305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 200}], {
             RGBColor[
             0.8739725410077492, 0.7339874771388775, 0.6066396220475212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.7503642165832218, 0.805193848255281, 0.9757004322912739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 295}], {
             RGBColor[
             0.8496169506590368, 0.8829255104904983, 0.9855184172875062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 96}], {
             RGBColor[
             0.44705620926157014`, 0.5606800997756136, 0.9499720483653973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 105}], {
             RGBColor[
             0.3889084199719124, 0.5085055030468593, 0.9463331921101534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 109}], {
             RGBColor[
             0.7049075830694689, 0.7678615870686365, 0.9726151362943627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 138}], {
             RGBColor[
             0.5976652055170001, 0.6832651887274253, 0.9621432473760043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 140}], {
             RGBColor[
             0.4083602605702821, 0.527163613934152, 0.9475063767322723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 154}], {
             RGBColor[
             0.6149232954890904, 0.696747339779964, 0.9638633724984019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 171}], {
             RGBColor[
             0.45349990749309843`, 0.5662613073140733, 0.9503826351187716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 198}], {
             RGBColor[
             0.4764509321887418, 0.5858433564775396, 0.9519271091606205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 245}], {
             RGBColor[
             0.4565245648697137, 0.5688811135099974, 0.9505753636122101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 289}], {
             RGBColor[
             0.38981488785686436`, 0.5094582582673273, 0.9463848141152024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 105}], {
             RGBColor[
             0.3473181215020726, 0.473441328714978, 0.9434180509343462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 138}], {
             RGBColor[
             0.5560749070471602, 0.6482010143955439, 0.959228106200197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 140}], {
             RGBColor[
             0.36676996210044227`, 0.49209943960227065`, 0.9445912355564652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 171}], {
             RGBColor[
             0.4119096090232586, 0.5311971329821921, 0.9474674939429645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 196}], {
             RGBColor[
             0.34319916551880214`, 0.4691120448196677, 0.9431834824845483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 198}], {
             RGBColor[
             0.43486063371890193`, 0.5507791821456584, 0.9490119679848132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 222}], {
             RGBColor[
             0.4207992950730278, 0.5388969322298897, 0.948033936877215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 245}], {
             RGBColor[
             0.41493426639987385`, 0.5338169391781161, 0.9476602224364029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 278}], {
             RGBColor[
             0.5041987109200126, 0.6070709568623011, 0.9544705154158305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 289}], {
             RGBColor[
             0.3482245893870246, 0.47439408393544596`, 0.9434696729393952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 290}], {
             RGBColor[
             0.5091973143554127, 0.6111290483156775, 0.9548640237887529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 298}], {
             RGBColor[
             0.3453589956577786, 0.4713821632368721, 0.9433064816157806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 134}], {
             RGBColor[
             0.2657406017726479, 0.3966405997633186, 0.9384449061917377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 144}], {
             RGBColor[
             0.28659496025462, 0.4179160304983415, 0.9396561045432549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 159}], {
             RGBColor[
             0.2524370830607903, 0.3826577581053522, 0.9376872904818896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 235}], {
             RGBColor[
             0.24975979964424241`, 0.3798437634849875, 0.9375348231520031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 252}], {
             RGBColor[
             0.2790058648824081, 0.41058323235793537`, 0.9392003433016403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 292}], {
             RGBColor[
             0.25027096919944, 0.3803810350975218, 0.937563933501964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 122}], {
             RGBColor[
             0.5234999711581451, 0.6232114459734905, 0.9558598822602524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 160}], {
             RGBColor[
             0.5065135948101279, 0.6094211404266363, 0.9545226524909898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 178}], {
             RGBColor[
             0.34993177355877136`, 0.4745851224813026, 0.9436255999612144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 181}], {
             RGBColor[
             0.5683121366528735, 0.6584973340732392, 0.9601360759487196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 182}], {
             RGBColor[
             0.3649951509133196, 0.4904176871542194, 0.9444834370172861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 208}], {
             RGBColor[
             0.3543834762769441, 0.47926414429235664`, 0.9438791178453103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 246}], {
             RGBColor[
             0.5108375562883921, 0.6129315271469358, 0.9548630505777516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 296}], {
             RGBColor[
             0.559521387516622, 0.6516299340358314, 0.9592598962290395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 104}], {
             RGBColor[
             0.3262801186675095, 0.4548403348152493, 0.9420914025992604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 123}], {
             RGBColor[
             0.40185451909948444`, 0.5224879194737331, 0.9468267925043885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 157}], {
             RGBColor[
             0.35673441532730565`, 0.48340715338862666`, 0.9439517793901664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 201}], {
             RGBColor[
             0.34430071595550393`, 0.4726377079286733, 0.9431595150608838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[
             0.3117655585077827, 0.43958461181110975`, 0.9412648198705315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 222}], {
             RGBColor[
             0.4018105363813725, 0.5224498238539401, 0.9468239899644828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 229}], {
             RGBColor[
             0.3569385719957474, 0.4835839836336185, 0.9439647880725508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 257}], {
             RGBColor[
             0.37939685727732686`, 0.5030362215582833, 0.9453958101516111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 259}], {
             RGBColor[
             0.41587462147542475`, 0.5343343034600658, 0.9478022372825421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 261}], {
             RGBColor[
             0.38406488890105717`, 0.5070794359286672, 0.9456932529988971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 121}], {
             RGBColor[
             0.8983235951964362, 0.5881023685637291, 0.34869848898741257`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 125}], {
             RGBColor[
             0.897661942750397, 0.5866871608849751, 0.27668170348161025`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 127}], {
             RGBColor[
             0.8443775856578832, 0.3421111465143313, 0.19012933218429046`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 136}], {
             RGBColor[
             0.8977561106780269, 0.5868885765603375, 0.28693130126704164`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 137}], {
             RGBColor[
             0.848642289586235, 0.3748915297128206, 0.1942132174823743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 170}], {
             RGBColor[
             0.8407513673675695, 0.3142384437159935, 0.18665686145425833`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 192}], {
             RGBColor[
             0.8551155999405852, 0.4177475301902278, 0.2001418527008563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 228}], {
             RGBColor[
             0.8389013017243429, 0.5432933316125673, 0.4579004063189147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 232}], {
             RGBColor[
             0.8981524008015748, 0.5877362010635289, 0.330065035596082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 240}], {
             RGBColor[
             0.8984314070002761, 0.5883329671106973, 0.36043313849805947`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 256}], {
             RGBColor[
             0.8985362124666462, 0.5885571354058046, 0.3718405667280683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 299}], {
             RGBColor[
             0.8982817367433281, 0.588471471678237, 0.3774803131264599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 108}], {
             RGBColor[
             0.44525533808141193`, 0.5575469670447641, 0.9502920083081179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 114}], {
             RGBColor[
             0.4255007228362041, 0.540035729338632, 0.9490479363174081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 187}], {
             RGBColor[
             0.4552598760386822, 0.566212394980653, 0.9509294886200896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 205}], {
             RGBColor[
             0.5380185348092877, 0.6358267098737893, 0.9567739363684693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 207}], {
             RGBColor[
             0.6460892652174881, 0.7219820565313749, 0.9663628314965813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 213}], {
             RGBColor[
             0.48723449014775655`, 0.5939071986311, 0.9529668827570787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 231}], {
             RGBColor[
             0.49585480302230733`, 0.6013736803735128, 0.9535161614708018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 133}], {
             RGBColor[
             0.36773492193593726`, 0.4929352393114849, 0.9446527219439024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 142}], {
             RGBColor[
             0.5221732711977142, 0.6208612990518254, 0.9562111960106483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 162}], {
             RGBColor[
             0.3349247683998675, 0.4622774977068556, 0.9426440773615328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[
             0.4766965463107896, 0.5841965277949407, 0.9524565634581535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 210}], {
             RGBColor[
             0.3819399405336581, 0.5052389124558365, 0.9455578531679444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 237}], {
             RGBColor[
             0.5120510519507784, 0.6128989081758123, 0.9552397996499549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 239}], {
             RGBColor[
             0.398228532934502, 0.519347272504989, 0.9465957478722895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 295}], {
             RGBColor[
             0.6113037860265932, 0.6906305704110295, 0.9650577846461873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 116}], {
             RGBColor[
             0.3006123597209014, 0.43202989779004775`, 0.9404770506166615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 119}], {
             RGBColor[
             0.28052080371187027`, 0.4121755291203697, 0.939286616826827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 152}], {
             RGBColor[
             0.26605649274810816`, 0.396972621207172, 0.9384628957154713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 164}], {
             RGBColor[
             0.33137057382359575`, 0.4586711168930102, 0.9424369368208644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 168}], {
             RGBColor[
             0.3323449528082868, 0.45951507499583777`, 0.9424990233881594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 241}], {
             RGBColor[
             0.2789461451652853, 0.41052046314879065`, 0.9391969423520976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 277}], {
             RGBColor[
             0.3139559658390563, 0.44358745874044936`, 0.9413272933992227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 128}], {
             RGBColor[
             0.26216622821870855`, 0.39288370652975557`, 0.9382413509056526]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 157}], {
             RGBColor[
             0.3155261405863954, 0.44552577951204275`, 0.9414061686253012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 173}], {
             RGBColor[
             0.2711227338075005, 0.40229756177882925`, 0.9387514106489717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 201}], {
             RGBColor[
             0.30309244121459367`, 0.43475633405208935`, 0.9406139042960187]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 209}], {
             RGBColor[
             0.2751140822771375, 0.4064927220865271, 0.9389787120396467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 218}], {
             RGBColor[
             0.2705572837668725, 0.40170323793452584`, 0.9387192091056663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 229}], {
             RGBColor[
             0.3157302972548372, 0.4457026097570346, 0.9414191773076857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 261}], {
             RGBColor[
             0.34285661416014696`, 0.46919806205208336`, 0.9431476422340319]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 279}], {
             RGBColor[
             0.27193222945827744`, 0.4031483930327844, 0.9387975102287419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 129}], {
             RGBColor[
             0.2625398824694277, 0.39327644083830926`, 0.9382626299624591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 140}], {
             RGBColor[
             0.3086221728107845, 0.4399248428735164, 0.9409523793012212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 149}], {
             RGBColor[
             0.29155965067616113`, 0.4237780571831614, 0.9399152628309327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 171}], {
             RGBColor[
             0.3537618197336009, 0.4790225362534377, 0.9438286376877205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 196}], {
             RGBColor[
             0.28505137622914434`, 0.4169374480909134, 0.9395446262293043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 230}], {
             RGBColor[
             0.2692612582166467, 0.40034103290847267`, 0.938645402367879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 245}], {
             RGBColor[
             0.35678647711021616`, 0.4816423424493619, 0.944021366181159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 263}], {
             RGBColor[
             0.2750769487244079, 0.40645369236820506`, 0.9389765973387527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 289}], {
             RGBColor[
             0.2900768000973668, 0.42221948720669167`, 0.9398308166841512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 298}], {
             RGBColor[
             0.2872112063681208, 0.41920756650811786`, 0.9396676253605367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 151}], {
             RGBColor[
             0.5499711557200619, 0.645038448022178, 0.9579401200370031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 167}], {
             RGBColor[
             0.7052976145619072, 0.7697031240469493, 0.9712611329047376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 194}], {
             RGBColor[
             0.5862509789073218, 0.6747647734348481, 0.960720844348837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 215}], {
             RGBColor[
             0.8258859987463416, 0.8619784867738793, 0.84861498208911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 283}], {
             RGBColor[
             0.6376959489926155, 0.716530117719581, 0.9647707808430861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 286}], {
             RGBColor[
             0.6078523188068897, 0.6923017142945901, 0.9624213809540463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 297}], {
             RGBColor[
             0.7085338986582898, 0.7722313337797134, 0.9715836954586705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 110}], {
             RGBColor[
             0.8870800066449858, 0.5061000302265065, 0.3757440054051945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 127}], {
             RGBColor[
             0.8336887126455463, 0.25995178464749, 0.1798936553163213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 141}], {
             RGBColor[
             0.8557654965670187, 0.3870748730161112, 0.19936752315815415`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 165}], {
             RGBColor[
             0.8828514694572672, 0.490674938099604, 0.2461602468156653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.887313539208574, 0.5061966019430634, 0.37187376646363723`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 240}], {
             RGBColor[
             0.8877425339879393, 0.506173605243856, 0.35019746163009025`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 281}], {
             RGBColor[
             0.834790145991334, 0.26841788399438415`, 0.18094838913213865`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 114}], {
             RGBColor[
             0.32416580444258236`, 0.4547970767096937, 0.9418912109282782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 145}], {
             RGBColor[
             0.3065621353882716, 0.43629450439653, 0.9408887080179298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 169}], {
             RGBColor[
             0.3184727377256654, 0.44881330262893604`, 0.9415669992008873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 187}], {
             RGBColor[
             0.35392495764506043`, 0.4809737423517148, 0.9437727632309596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 205}], {
             RGBColor[
             0.436683616415666, 0.5505880572448512, 0.9496172109793394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 213}], {
             RGBColor[
             0.3858995717541348, 0.5086685460021616, 0.9458101573679487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 219}], {
             RGBColor[
             0.30907770812291846`, 0.4389385308371674, 0.9410319661637115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 221}], {
             RGBColor[
             0.3192668900954462, 0.449648007121744, 0.9416122250035031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 264}], {
             RGBColor[
             0.3192908615453144, 0.4496732026354332, 0.9416135901421105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 110}], {
             RGBColor[
             0.9570573175626281, 0.9656649471847494, 0.8794550171346109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 138}], {
             RGBColor[
             0.8139262808550589, 0.8553825016885668, 0.9818711941291625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 154}], {
             RGBColor[
             0.8311843708271494, 0.8688646527411055, 0.9835913192515602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 179}], {
             RGBColor[
             0.9574076164080104, 0.9658098047595847, 0.8736496587222751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 258}], {
             RGBColor[
             0.941467846616602, 0.9554926988601389, 0.9709728498600104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 138}], {
             RGBColor[
             0.8498149400101593, 0.8810685488435381, 0.8689831282162525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 141}], {
             RGBColor[
             0.9459742116007779, 0.8128132585241278, 0.5020022278511405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 154}], {
             RGBColor[
             0.8670730299822498, 0.8945506998960768, 0.8707032533386501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 165}], {
             RGBColor[
             0.9866031709361507, 0.9682133561493669, 0.5721913133374072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 179}], {
             RGBColor[
             0.9932962755631108, 0.991495851914556, 0.7607615928093651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 281}], {
             RGBColor[
             0.8883662554104251, 0.5159867018754759, 0.3769757186755893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 190}], {
             RGBColor[
             0.2355732429285669, 0.36493279289716524`, 0.9367269197341752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 212}], {
             RGBColor[
             0.2273675902370908, 0.3563081316499939, 0.936259619952571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 242}], {
             RGBColor[
             0.24172339249525976`, 0.3713969900337639, 0.9370771616536675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 250}], {
             RGBColor[
             0.2327988220725642, 0.3620167006690641, 0.9365689205708136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 280}], {
             RGBColor[
             0.2555363699026189, 0.38591530508224947`, 0.9378637902825477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 115}], {
             RGBColor[
             0.236902386747869, 0.36632980732383724`, 0.9368026125083924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 134}], {
             RGBColor[
             0.2631071012640549, 0.3938726237552112, 0.9382949322336882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 146}], {
             RGBColor[
             0.24133200131587673`, 0.37098561308859834`, 0.937054872505013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 159}], {
             RGBColor[
             0.24980358255219737`, 0.3798897820972448, 0.9375373165238401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 175}], {
             RGBColor[
             0.27336230601956724`, 0.40465149417079094`, 0.9388789509732987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 204}], {
             RGBColor[
             0.24154807064065673`, 0.37121271564852854`, 0.9370671773334133]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 235}], {
             RGBColor[
             0.24712629913564943`, 0.3770757874768801, 0.9373848491939536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 242}], {
             RGBColor[
             0.24632291686669305`, 0.37623138177482907`, 0.937339097762234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 252}], {
             RGBColor[
             0.27637236437381507`, 0.40781525634982796`, 0.9390503693435908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 253}], {
             RGBColor[
             0.2744693999473012, 0.40581512008264853`, 0.9389419983346845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 280}], {
             RGBColor[
             0.2601358942740522, 0.3907496968233146, 0.9381257263911142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 292}], {
             RGBColor[
             0.24763746869084696`, 0.3776130590894144, 0.9374139595439145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 135}], {
             RGBColor[
             0.9747525126984742, 0.9797102206225822, 0.8836982332246824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 224}], {
             RGBColor[
             0.9644670009376046, 0.9390549690861945, 0.644851681061125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 249}], {
             RGBColor[
             0.8655230747652505, 0.41896226614950405`, 0.42814822498187033`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 254}], {
             RGBColor[
             0.925365599889266, 0.7843240503848107, 0.5923111720047104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 258}], {
             RGBColor[
             0.9605881616295711, 0.9701272959910724, 0.9515981414941335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 260}], {
             RGBColor[
             0.9042815340807562, 0.9259021424271057, 0.969533952973199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 278}], {
             RGBColor[
             0.7811703997408805, 0.8288870412862575, 0.957738894978919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 288}], {
             RGBColor[
             0.8944038389605427, 0.6336207235327678, 0.45551738437603884`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 290}], {
             RGBColor[
             0.7861690031762806, 0.8329451327396338, 0.9581324033518415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 145}], {
             RGBColor[
             0.28680752014306377`, 0.4187832666903979, 0.9396446360272199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 169}], {
             RGBColor[
             0.2987181224804576, 0.4313020649228039, 0.9403229272101774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 187}], {
             RGBColor[
             0.33417034239985266`, 0.4634625046455827, 0.9425286912402498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 213}], {
             RGBColor[
             0.366144956508927, 0.49115730829602955`, 0.944566085377239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 219}], {
             RGBColor[
             0.28932309287771063`, 0.4214272931310352, 0.9397878941730018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 221}], {
             RGBColor[
             0.29951227485023835`, 0.4321367694156119, 0.9403681530127932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 231}], {
             RGBColor[
             0.37476526938347776`, 0.4986237900384425, 0.945115364090962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 264}], {
             RGBColor[
             0.29953624630010656`, 0.4321619649293011, 0.9403695181514007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 132}], {
             RGBColor[
             0.21415169536183348`, 0.34241738819996653`, 0.9355069942905895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 146}], {
             RGBColor[
             0.22602095903949393`, 0.35489273687997036`, 0.9361829312980301]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 159}], {
             RGBColor[
             0.23449254027581456`, 0.3637969058886168, 0.9366653753168572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 204}], {
             RGBColor[
             0.22623702836427392`, 0.35511983943990055`, 0.9361952361264305]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 242}], {
             RGBColor[
             0.23101187459031025`, 0.36013850556620103`, 0.9364671565552513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 243}], {
             RGBColor[
             0.21987898042507611`, 0.348437127932281, 0.9358331547021821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 294}], {
             RGBColor[
             0.2157444487404361, 0.3440914729872748, 0.9355976992392334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 119}], {
             RGBColor[
             0.30231628529617693`, 0.4338208316047836, 0.9405740866574415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 133}], {
             RGBColor[
             0.3362774461822365, 0.4656883549123332, 0.9426482794056301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 152}], {
             RGBColor[
             0.2878519743324149, 0.4186179236915859, 0.9397503655460857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 164}], {
             RGBColor[
             0.35316605540790247`, 0.4803164193774241, 0.9437244066514788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 168}], {
             RGBColor[
             0.35414043439259346`, 0.4811603774802517, 0.9437864932187738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 210}], {
             RGBColor[
             0.35048246477995726`, 0.4779920280566848, 0.9435534106296721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 241}], {
             RGBColor[
             0.30074162674959204`, 0.4321657656332045, 0.9404844121827121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 277}], {
             RGBColor[
             0.33575144742336294`, 0.46523276122486323`, 0.9426147632298372]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 161}], {
             RGBColor[
             0.20987266837087443`, 0.33791985952648745`, 0.9352633100337076]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 120}], {
             RGBColor[
             0.1844220718220619, 0.3111696688926636, 0.9338139362110361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 130}], {
             RGBColor[
             0.17892828448197629`, 0.3053953500719979, 0.9335010731493483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 176}], {
             RGBColor[
             0.17894072364130287`, 0.30540842441713845`, 0.9335017815410699]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[
             0.17892828448197629`, 0.3053953500719979, 0.9335010731493483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 220}], {
             RGBColor[
             0.21806065403360642`, 0.34652595160629435`, 0.9357296037041608]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 226}], {
             RGBColor[
             0.17892828959271728`, 0.30539535544371077`, 0.9335010734403975]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 228}], {
             RGBColor[
             0.49763640594137093`, 0.5809247565206876, 0.9579151348288255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 266}], {
             RGBColor[
             0.21328176149194045`, 0.3415030325457159, 0.9354574528436509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 152}], {
             RGBColor[
             0.2677604183233837, 0.39876355502190786`, 0.9385599317562512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 164}], {
             RGBColor[
             0.33307449939887124`, 0.46046205070774604`, 0.9425339728616443]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 168}], {
             RGBColor[
             0.3340488783835623, 0.46130600881057365`, 0.9425960594289393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 241}], {
             RGBColor[
             0.2806500707405608, 0.4123113969635265, 0.9392939783928775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 130}], {
             RGBColor[
             0.18442078734008566`, 0.31116831882066576`, 0.9338138630616879]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 176}], {
             RGBColor[
             0.18443322649941224`, 0.31118139316580623`, 0.9338145714534094]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 287}], {
             RGBColor[
             0.5654447927305568, 0.5603176274195498, 0.6027460190921992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 125}], {
             RGBColor[
             0.9936176446660105, 0.9887571122327337, 0.5466981931057444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 127}], {
             RGBColor[
             0.8867181042579634, 0.498897479652069, 0.3375850577582036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 136}], {
             RGBColor[
             0.9937588965574554, 0.9890592357457773, 0.5620725897838914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 137}], {
             RGBColor[
             0.8952475121146669, 0.5644582460490475, 0.34575282835437127`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 160}], {
             RGBColor[
             0.7924150587076538, 0.8345430649548763, 0.8078033989134862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 181}], {
             RGBColor[
             0.8542136005503994, 0.8836192586014792, 0.8134168223712162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 232}], {
             RGBColor[
             0.9943533317427773, 0.9903306725005643, 0.626773191277452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 240}], {
             RGBColor[
             0.9947718410408293, 0.9912258215713169, 0.6723253456304181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 246}], {
             RGBColor[
             0.796739020185918, 0.8380534516751759, 0.8081437970002479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 256}], {
             RGBColor[
             0.9949290492403844, 0.9915620740139779, 0.6894364879754314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 296}], {
             RGBColor[
             0.8454228514141477, 0.8767518585640715, 0.8125406426515358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 299}], {
             RGBColor[
             0.9945473356554072, 0.9914335784226265, 0.6978961075730188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 136}], {
             RGBColor[
             0.8085502082780569, 0.8465126824966431, 0.7164898471021924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 160}], {
             RGBColor[
             0.6072063704282553, 0.6919965117057422, 0.9622206562317872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 181}], {
             RGBColor[
             0.6690049122710009, 0.741072705352345, 0.9678340796895172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 207}], {
             RGBColor[
             0.6848905103681076, 0.7534826553208219, 0.9694174076484823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 231}], {
             RGBColor[
             0.5346560481729267, 0.6328742791629598, 0.9565707376227028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 232}], {
             RGBColor[
             0.8091446434633787, 0.8477841192514302, 0.781190448595753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 240}], {
             RGBColor[
             0.8095631527614308, 0.8486792683221828, 0.8267426029487193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 246}], {
             RGBColor[
             0.6115303319065195, 0.6955068984260417, 0.962561054318549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 256}], {
             RGBColor[
             0.8097203609609858, 0.8490155207648438, 0.8438537452937325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 296}], {
             RGBColor[
             0.6602141631347492, 0.7342053053149373, 0.9669578999698369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 299}], {
             RGBColor[
             0.8093386473760087, 0.8488870251734923, 0.8523133648913199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 144}], {
             RGBColor[
             0.3759650676291757, 0.5000637778518178, 0.9451771395498434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 157}], {
             RGBColor[
             0.3911005410183704, 0.5131733641705265, 0.9461415585304294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 229}], {
             RGBColor[
             0.3913046976868122, 0.5133501944155183, 0.9461545672128138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 257}], {
             RGBColor[
             0.41376298296839165`, 0.5328024323401832, 0.9475855892918741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 259}], {
             RGBColor[
             0.4502407471664895, 0.5641005142419657, 0.9499920164228051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 261}], {
             RGBColor[
             0.41843101459212195`, 0.5368456467105671, 0.9478830321391599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 125}], {
             RGBColor[
             0.970159485355791, 0.9735725032155419, 0.706048969605638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 142}], {
             RGBColor[
             0.8033587771487245, 0.8470321673736835, 0.9700369554308557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 150}], {
             RGBColor[
             0.9548500534233739, 0.9658478242861803, 0.9613112619489188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 200}], {
             RGBColor[
             0.916844882326316, 0.7678634053812667, 0.6000047488264095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 237}], {
             RGBColor[
             0.7932365579017887, 0.8390697764976703, 0.9690655590701622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 282}], {
             RGBColor[
             0.9556754222393467, 0.9664633829977154, 0.9599141278341408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 295}], {
             RGBColor[
             0.8924892919776035, 0.9168014387328876, 0.9788835440663946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 136}], {
             RGBColor[
             0.9927664178883965, 0.9869364242276462, 0.4540474115251879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 150}], {
             RGBColor[
             0.9773157340645346, 0.9789096217852411, 0.6939353071903218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[
             0.8788040152312967, 0.44173686637663945`, 0.258623330792337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 192}], {
             RGBColor[
             0.907532480377328, 0.648755039325108, 0.28559331328553295`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 195}], {
             RGBColor[
             0.8769708936625604, 0.4276466907203388, 0.25686793150790044`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 200}], {
             RGBColor[
             0.9393105629674767, 0.7809252028803274, 0.3326287940678124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 256}], {
             RGBColor[
             0.9939365705713255, 0.9894392624958468, 0.5814113097167279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 299}], {
             RGBColor[
             0.9935548569863483, 0.9893107669044954, 0.5898709293143154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 155}], {
             RGBColor[
             0.21912067898952223`, 0.3476401050444259, 0.9357899705572339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 163}], {
             RGBColor[
             0.23364896427549098`, 0.3629102540264691, 0.9366173349115978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 184}], {
             RGBColor[
             0.23168784072436213`, 0.3608489888318178, 0.9365056518265833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 189}], {
             RGBColor[
             0.22889351140479614`, 0.3579119715462422, 0.9363465189056738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 197}], {
             RGBColor[
             0.21821940668747852`, 0.34669281071101354`, 0.9357386444329454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 214}], {
             RGBColor[
             0.21941035515512047`, 0.34794457306099935`, 0.9358064671863272]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 216}], {
             RGBColor[
             0.24238826022285348`, 0.3720958081705137, 0.9371150248871702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 275}], {
             RGBColor[
             0.21935857397151598`, 0.34789014775391436`, 0.9358035183245244]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 293}], {
             RGBColor[
             0.21759994210882713`, 0.34604171416252816`, 0.9357033668416068]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 136}], {
             RGBColor[
             0.886150619739554, 0.4976836876486773, 0.27581787003783265`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 137}], {
             RGBColor[
             0.837036798647762, 0.2856866408011604, 0.18309978625316525`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 141}], {
             RGBColor[
             0.8548488786408825, 0.38002934597129234`, 0.19848976879691427`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 165}], {
             RGBColor[
             0.8819348515311312, 0.4836294110547851, 0.24528249245442546`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 170}], {
             RGBColor[
             0.8291458764290967, 0.22503355480433335`, 0.17554343022504929`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 192}], {
             RGBColor[
             0.8435101090021122, 0.32854264127856764`, 0.18902842147164728`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 228}], {
             RGBColor[
             0.8272958107858699, 0.4540884427009072, 0.44678697508970566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 232}], {
             RGBColor[
             0.8865469098631019, 0.4985313121518687, 0.318951604366873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 240}], {
             RGBColor[
             0.8868259160618033, 0.4991280781990371, 0.3493197072688504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 256}], {
             RGBColor[
             0.8869307215281732, 0.49935224649414445`, 0.36072713549885926`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 281}], {
             RGBColor[
             0.833873528065198, 0.26137235694956523`, 0.1800706347708988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 299}], {
             RGBColor[
             0.8866762458048552, 0.4992665827665768, 0.36636688189725086`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 173}], {
             RGBColor[
             0.24821711809960986`, 0.3782223073699194, 0.9374469697202291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 209}], {
             RGBColor[
             0.25220846656924684`, 0.38241746767761725`, 0.9376742711109041]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 218}], {
             RGBColor[
             0.24765166805898178`, 0.377627983525616, 0.9374147681769237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 276}], {
             RGBColor[
             0.235521079118485, 0.3648779654253926, 0.9367239490823606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 279}], {
             RGBColor[
             0.24902661375038676`, 0.3790731386238746, 0.9374930692999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 161}], {
             RGBColor[
             0.22609023535273692`, 0.35496555067756064`, 0.9361868764815843]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 230}], {
             RGBColor[
             0.2426308084736596, 0.3723507417605582, 0.9371288376512357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 263}], {
             RGBColor[
             0.24844649898142085`, 0.37846340122029065`, 0.9374600326221096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 265}], {
             RGBColor[
             0.22918762870603976`, 0.3582211074779632, 0.936363268450872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 269}], {
             RGBColor[
             0.23146736458154496`, 0.36061725442672216`, 0.9364930960364151]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 289}], {
             RGBColor[
             0.26344635035437974`, 0.39422919605877726`, 0.9383142519675081]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 298}], {
             RGBColor[
             0.26058075662513375`, 0.3912172753602034, 0.9381510606438935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 176}], {
             RGBColor[
             0.17893943915932659`, 0.3054070743451405, 0.9335017083917216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 199}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 220}], {
             RGBColor[
             0.21805936955163013`, 0.34652460153429643`, 0.9357295305548126]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 226}], {
             RGBColor[
             0.178927005110741, 0.3053940053717128, 0.9335010002910491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 228}], {
             RGBColor[
             0.49763512145939465`, 0.5809234064486897, 0.9579150616794772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 266}], {
             RGBColor[
             0.21328047700996416`, 0.3415016824737179, 0.9354573796943026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 139}], {
             RGBColor[
             0.29015495986038786`, 0.4208144502573191, 0.9398897209981389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 143}], {
             RGBColor[
             0.3607906299670138, 0.4869204426382663, 0.9442102378002388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 172}], {
             RGBColor[
             0.297163306859998, 0.4281806673087738, 0.9402888359918464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 174}], {
             RGBColor[
             0.3585773503848271, 0.4850034111068425, 0.9440692095823882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 183}], {
             RGBColor[
             0.2897103519915022, 0.4203471391973532, 0.9398644012377442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 283}], {
             RGBColor[
             0.47177717102653804`, 0.5785602690993044, 0.9525231166057517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 188}], {
             RGBColor[
             0.20621351468350757`, 0.3340738569973212, 0.9350549266444448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 212}], {
             RGBColor[
             0.20921642322248857`, 0.3372301042671883, 0.9352259378433346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 243}], {
             RGBColor[
             0.21243933131542342`, 0.34061758501703826`, 0.935409477691362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 294}], {
             RGBColor[
             0.2083047996307834, 0.33627193007203204`, 0.9351740222284133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 162}], {
             RGBColor[
             0.31733689752319516`, 0.44704376794557543`, 0.9415233937816148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 164}], {
             RGBColor[
             0.36703566028493084`, 0.49232957401529565`, 0.9446081656098331]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 210}], {
             RGBColor[
             0.36435206965698563`, 0.49000518269455634`, 0.9444371695880264]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 239}], {
             RGBColor[
             0.38064066205782954`, 0.5041135427437089, 0.9454750642923715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 241}], {
             RGBColor[
             0.3146112316266204, 0.4441789202710761, 0.9413681711410662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 277}], {
             RGBColor[
             0.3496210523003913, 0.4772459158627348, 0.9434985221881913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 144}], {
             RGBColor[
             0.29485513198583013`, 0.42659799471298, 0.9401265091035182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 159}], {
             RGBColor[
             0.26069725479200045`, 0.3913397223199907, 0.9381576950421531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 175}], {
             RGBColor[
             0.2842559782593704, 0.41610143439353686`, 0.9394993294916116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 204}], {
             RGBColor[
             0.25244174288045984`, 0.38266265587127446`, 0.9376875558517261]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 235}], {
             RGBColor[
             0.2580199713754525, 0.388525727699626, 0.9380052277122666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 252}], {
             RGBColor[
             0.28726603661361816`, 0.4192651965725739, 0.9396707478619037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 253}], {
             RGBColor[
             0.2853630721871043, 0.41726506030539445`, 0.9395623768529974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 292}], {
             RGBColor[
             0.2585311409306501, 0.3890629993121603, 0.9380343380622274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 224}], {
             RGBColor[
             0.9798102252026126, 0.9495170954171317, 0.5749562479700403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 249}], {
             RGBColor[
             0.8757518909419225, 0.42593701703679554`, 0.3815512695878138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 254}], {
             RGBColor[
             0.940708824154274, 0.7947861767157479, 0.5224157389136257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 258}], {
             RGBColor[
             0.9759313858945792, 0.9805894223220096, 0.8817027084030489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 260}], {
             RGBColor[
             0.9196247583457642, 0.9363642687580429, 0.8996385198821143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 288}], {
             RGBColor[
             0.9046326551372147, 0.6405954744200593, 0.40892042898198233`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 137}], {
             RGBColor[
             0.8946800275962575, 0.5632444540456559, 0.2839856406340002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 165}], {
             RGBColor[
             0.9865840174672071, 0.9661571328498515, 0.42361874182822423`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 181}], {
             RGBColor[
             0.8533623737727853, 0.8817985705963918, 0.7207660407906598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 232}], {
             RGBColor[
             0.9935021049651632, 0.9885099844954769, 0.5341224096968956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 240}], {
             RGBColor[
             0.9939206142632153, 0.9894051335662295, 0.5796745640498617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 256}], {
             RGBColor[
             0.9940778224627702, 0.9897413860088904, 0.596785706394875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 296}], {
             RGBColor[
             0.8445716246365338, 0.8749311705589841, 0.7198898610709794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 299}], {
             RGBColor[
             0.9936961088777931, 0.9896128904175391, 0.6052453259924624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 170}], {
             RGBColor[
             0.8376752842858002, 0.29059432120131196`, 0.18371120082121695`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 192}], {
             RGBColor[
             0.8520395168588157, 0.39410340767554625`, 0.19719619206781494`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 195}], {
             RGBColor[
             0.836758723501432, 0.2835492333731616, 0.18283350117899866`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 220}], {
             RGBColor[
             0.6494413840373972, 0.36338333915495696`, 0.44016439160276355`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 228}], {
             RGBColor[
             0.8358252186425734, 0.5196492090978858, 0.45495474568587335`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 232}], {
             RGBColor[
             0.8950763177198054, 0.5640920785488474, 0.32711937496304067`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 256}], {
             RGBColor[
             0.8954601293848767, 0.5649130128911231, 0.36889490609502695`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 266}], {
             RGBColor[
             0.6462554556762865, 0.36003472644790463`, 0.439982957695757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 299}], {
             RGBColor[
             0.8952056536615587, 0.5648273491635555, 0.37453465249341855`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 154}], {
             RGBColor[
             0.7239419932746806, 0.7842682543998942, 0.9731194303332016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 171}], {
             RGBColor[
             0.5625186052786886, 0.6537822219340037, 0.9596386929535714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 245}], {
             RGBColor[
             0.5655432626553039, 0.6564020281299278, 0.9598314214470098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 258}], {
             RGBColor[
             0.8342254690641332, 0.8708963005189276, 0.9605009609416519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 147}], {
             RGBColor[
             0.2408356632285271, 0.3704639302891415, 0.9370266067852049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 148}], {
             RGBColor[
             0.24714609636833407`, 0.37709659562364867`, 0.9373859766170676]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 172}], {
             RGBColor[
             0.26248705403553485`, 0.3932209148047717, 0.9382596214613016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 183}], {
             RGBColor[
             0.2550340991670391, 0.38538738669335115`, 0.9378351867071995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 206}], {
             RGBColor[
             0.2460762386198535, 0.3759721072970965, 0.9373250498010044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 244}], {
             RGBColor[
             0.2489949569451404, 0.37903986531440326`, 0.9374912664917726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 272}], {
             RGBColor[
             0.23937950956716447`, 0.3689334204655748, 0.9369436809883765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 149}], {
             RGBColor[
             0.3110114912745308, 0.4424361680704541, 0.9410884474530516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 171}], {
             RGBColor[
             0.37321366033197056`, 0.49768064714073046`, 0.9450018223098395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 196}], {
             RGBColor[
             0.304503216827514, 0.4355955589782061, 0.9407178108514234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 198}], {
             RGBColor[
             0.3961646850276139, 0.5172626963041967, 0.9465462963516883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 222}], {
             RGBColor[
             0.3821033463817397, 0.505380446388428, 0.94556826524409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 230}], {
             RGBColor[
             0.2887130988150164, 0.4189991437957653, 0.9398185869899978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 245}], {
             RGBColor[
             0.37623831770858585`, 0.5003004533366545, 0.945194550803278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 263}], {
             RGBColor[
             0.2945287893227776, 0.42511180325549774`, 0.9401497819608717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 289}], {
             RGBColor[
             0.3095286406957365, 0.4408775980939844, 0.9410040013062702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 298}], {
             RGBColor[
             0.3066630469664905, 0.4378656773954105, 0.9408408099826556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 165}], {
             RGBColor[
             0.9396314058192, 0.789675620333774, 0.3076265899668467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 179}], {
             RGBColor[
             0.9463245104461602, 0.8129581160989631, 0.4961968694388046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 232}], {
             RGBColor[
             0.9465494933171561, 0.8120284719793993, 0.41813025783551805`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[
             0.9469680026152082, 0.812923621050152, 0.46368241218848416`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 281}], {
             RGBColor[
             0.857051745332458, 0.3969615446650806, 0.200599236428549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[
             0.810515025857468, 0.8523692859433827, 0.9579232930155395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 185}], {
             RGBColor[
             0.6135470246958941, 0.696888857774001, 0.9628943539449815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 210}], {
             RGBColor[
             0.5187904189187625, 0.6179312424348968, 0.9559956436547723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 237}], {
             RGBColor[
             0.6489015303358828, 0.7255912381548726, 0.9656775901367828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 239}], {
             RGBColor[
             0.5350790113196064, 0.6320396024840493, 0.9570335383591173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 282}], {
             RGBColor[
             0.8113403946734408, 0.8529848446549176, 0.9565261589007614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 283}], {
             RGBColor[
             0.6388734394755219, 0.7174499822340865, 0.964888142090148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 295}], {
             RGBColor[
             0.7481542644116976, 0.8033229003900898, 0.9754955751330152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 297}], {
             RGBColor[
             0.7097113891411961, 0.773151198294219, 0.9717010567057325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 167}], {
             RGBColor[
             0.5753382538779925, 0.6628795153036178, 0.9613047709389584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 172}], {
             RGBColor[
             0.33312272414216076`, 0.4593269071857189, 0.9425801382634016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 174}], {
             RGBColor[
             0.39453676766698986`, 0.5161496509837875, 0.9463605118539434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 185}], {
             RGBColor[
             0.482410173529073, 0.5891453845161638, 0.9528206307321404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 237}], {
             RGBColor[
             0.5177646791690618, 0.6178477648970354, 0.9556038669239417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 239}], {
             RGBColor[
             0.4039421601527854, 0.5242961292262122, 0.9469598151462764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 283}], {
             RGBColor[
             0.5077365883087008, 0.6097065089762495, 0.9548144188773069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 297}], {
             RGBColor[
             0.5785745379743751, 0.6654077250363819, 0.9616273334928914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 158}], {
             RGBColor[
             0.35967077338482056`, 0.4859504791523989, 0.9441388815290719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 235}], {
             RGBColor[
             0.27887432985742466`, 0.4098011584346488, 0.9392164260637837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 252}], {
             RGBColor[
             0.3081203950955903, 0.44054062730759674`, 0.940881946213421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 253}], {
             RGBColor[
             0.30621743066907636`, 0.4385404910404173, 0.9407735752045145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 257}], {
             RGBColor[
             0.3535074058070181, 0.4806120799363681, 0.9437461571970662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 292}], {
             RGBColor[
             0.2793854994126222, 0.4103384300471832, 0.9392455364137446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 169}], {
             RGBColor[
             0.28111445342614677`, 0.4127994926096401, 0.939320424299829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 219}], {
             RGBColor[
             0.27171942382339986`, 0.4029247208178715, 0.9387853912626534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 221}], {
             RGBColor[
             0.2819086057959276, 0.4136341971024482, 0.9393656501024449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 264}], {
             RGBColor[
             0.28193257724579573`, 0.4136593926161374, 0.9393670152410523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 159}], {
             RGBColor[
             0.2389221548438223, 0.3684527116533779, 0.9369176353134778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 204}], {
             RGBColor[
             0.23066664293228167`, 0.35977564520466165`, 0.936447496123051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 235}], {
             RGBColor[
             0.23624487142727435`, 0.3656387170330131, 0.9367651679835913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 242}], {
             RGBColor[
             0.23544148915831797`, 0.3647943113309621, 0.9367194165518717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 243}], {
             RGBColor[
             0.22430859499308387`, 0.3530929336970421, 0.9360854146988027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 292}], {
             RGBColor[
             0.2367560409824719, 0.36617598864554746`, 0.9367942783335522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 148}], {
             RGBColor[
             0.2325030525609364, 0.36170582815947316`, 0.9365520769346783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 172}], {
             RGBColor[
             0.2478440102281372, 0.3778301473405962, 0.9374257217789124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 183}], {
             RGBColor[
             0.24039105535964145`, 0.36999661922917565`, 0.9370012870248101]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 206}], {
             RGBColor[
             0.23143319481245586`, 0.360581339832921, 0.9364911501186151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 244}], {
             RGBColor[
             0.23435191313774276`, 0.3636490978502278, 0.9366573668093834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 270}], {
             RGBColor[
             0.2272240069658551, 0.35615721652822, 0.9362514430976865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 272}], {
             RGBColor[
             0.2247364657597668, 0.3535426530013993, 0.9361097813059873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 172}], {
             RGBColor[
             0.2541544433679442, 0.3844628126751034, 0.9377850916107751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 183}], {
             RGBColor[
             0.2467014884994484, 0.37662928456368283`, 0.937360656856673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 203}], {
             RGBColor[
             0.2492037147300215, 0.37925928298232137`, 0.9375031549387921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 206}], {
             RGBColor[
             0.23774362795226284`, 0.3672140051674282, 0.9368505199504779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 244}], {
             RGBColor[
             0.24066234627754973`, 0.37028176318473494`, 0.9370167366412461]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 270}], {
             RGBColor[
             0.23353444010566207`, 0.3627898818627272, 0.9366108129295494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 272}], {
             RGBColor[
             0.23104689889957378`, 0.3601753183359065, 0.93646915113785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 171}], {
             RGBColor[
             0.3561511381973472, 0.48153386145037547`, 0.943964705839551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 227}], {
             RGBColor[
             0.27685707898321577`, 0.40832472213698934`, 0.9390779731235251]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 245}], {
             RGBColor[
             0.3591757955739624, 0.4841536676462995, 0.9441574343329895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 289}], {
             RGBColor[
             0.29246611856111315`, 0.4247308124036294, 0.9399668848359817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 298}], {
             RGBColor[
             0.28960052483186716`, 0.4217188917050555, 0.9398036935123671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 200}], {
             RGBColor[
             0.9240011310350597, 0.7732005239509658, 0.5878910864110933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 237}], {
             RGBColor[
             0.8003928066105324, 0.8444068950673695, 0.956951896654846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 282}], {
             RGBColor[
             0.9628316709480902, 0.9718005015674145, 0.9478004654188247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 295}], {
             RGBColor[
             0.8996455406863472, 0.9221385573025866, 0.9667698816510785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 167}], {
             RGBColor[
             0.5986000016649633, 0.6830276720672528, 0.9627869889383882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 194}], {
             RGBColor[
             0.4795533660103779, 0.5880893214551517, 0.9522467003824877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 251}], {
             RGBColor[
             0.36499365332834144`, 0.4885238594535514, 0.944552636407374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 286}], {
             RGBColor[
             0.5011547059099458, 0.6056262623148936, 0.953947236987697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 241}], {
             RGBColor[
             0.2661857597767988, 0.3971084890503288, 0.9384702572815218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 277}], {
             RGBColor[
             0.3011955804505697, 0.43017548464198757`, 0.9406006083286469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 163}], {
             RGBColor[
             0.2574205034515923, 0.3878956489031873, 0.9379710889008359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 211}], {
             RGBColor[
             0.25792046228139853`, 0.38842113733253425`, 0.9379995608165705]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 216}], {
             RGBColor[
             0.2661597993989548, 0.3970812030472318, 0.9384687788764086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 219}], {
             RGBColor[
             0.2738583241419696, 0.40517284066680126`, 0.9389071984715764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 221}], {
             RGBColor[
             0.2840475061144973, 0.4158823169513779, 0.939487457311368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 171}], {
             RGBColor[
             0.5797766952507789, 0.6672643729865424, 0.9613588180759691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 179}], {
             RGBColor[
             0.8674233288276321, 0.8946955574709121, 0.8648978949263142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 245}], {
             RGBColor[
             0.5828013526273942, 0.6698841791824666, 0.9615515465694076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 156}], {
             RGBColor[
             0.22000089461836236`, 0.3485652674792311, 0.935840097535134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 184}], {
             RGBColor[
             0.22486994634019453`, 0.35368294955458646`, 0.9361173828275757]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 197}], {
             RGBColor[
             0.21140151230331092`, 0.3395267714337822, 0.9353503754339378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 202}], {
             RGBColor[
             0.22021191752572378`, 0.34878706593449305`, 0.9358521149775277]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 214}], {
             RGBColor[
             0.21259246077095287`, 0.340778533783768, 0.9354181981873197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 275}], {
             RGBColor[
             0.21254067958734837`, 0.340724108476683, 0.9354152493255168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 293}], {
             RGBColor[
             0.21078204772465953`, 0.3388756748852968, 0.9353150978425994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 178}], {
             RGBColor[
             0.25237767810444756`, 0.38259531972974414`, 0.9376839074575076]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 202}], {
             RGBColor[
             0.22791002753873152`, 0.3568782676465297, 0.9362905109544353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 208}], {
             RGBColor[
             0.2568293808226203, 0.38727434154079826`, 0.9379374253416035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 214}], {
             RGBColor[
             0.2202905707839606, 0.3488697354958046, 0.9358565941642273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 268}], {
             RGBColor[
             0.2451076812596908, 0.374954092101482, 0.9372698918921952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 201}], {
             RGBColor[
             0.3335467378743898, 0.46332315262546664`, 0.9424742810869247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 218}], {
             RGBColor[
             0.30101158042666865`, 0.4302700565079032, 0.9405795858965723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 229}], {
             RGBColor[
             0.34618459391463335`, 0.47426942833041186`, 0.9432795540985917]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 257}], {
             RGBColor[
             0.3686428791962128, 0.49372166625507674`, 0.944710576177652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 259}], {
             RGBColor[
             0.40512064339431064`, 0.5250197481568593, 0.947117003308583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 261}], {
             RGBColor[
             0.3733109108199431, 0.49776488062546065`, 0.9450080190249379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 284}], {
             RGBColor[
             0.3008123283039969, 0.4300606298936609, 0.9405682387829533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 175}], {
             RGBColor[
             0.34907161965836087`, 0.47545391883295585`, 0.9435117019171652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 177}], {
             RGBColor[
             0.4114198455834537, 0.5307729245068593, 0.947436286649661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 217}], {
             RGBColor[
             0.6053338779034495, 0.6866046110497097, 0.9641707450092601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 252}], {
             RGBColor[
             0.35208167801260865`, 0.47861768101199287`, 0.9436831202874573]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 253}], {
             RGBColor[
             0.35017871358609476`, 0.47661754474481344`, 0.9435747492785509]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 175}], {
             RGBColor[
             0.2709524595475128, 0.4021185927355705, 0.9387417137817635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 204}], {
             RGBColor[
             0.23913822416860225`, 0.3686798142133081, 0.9369299401418781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 235}], {
             RGBColor[
             0.24471645266359499`, 0.3745428860416596, 0.9372476120024185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 252}], {
             RGBColor[
             0.2739625179017606, 0.4052823549146075, 0.9389131321520556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 253}], {
             RGBColor[
             0.27205955347524674`, 0.4032822186474281, 0.9388047611431494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 292}], {
             RGBColor[
             0.24522762221879252`, 0.3750801576541939, 0.9372767223523794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 168}], {
             RGBColor[
             0.4880465107801085, 0.5934258804224648, 0.9533459462263981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[
             0.6520185359229838, 0.7272823998054908, 0.9664968499202544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 246}], {
             RGBColor[
             0.5945439555585024, 0.6817165928791875, 0.9612238245492863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 256}], {
             RGBColor[
             0.7927339846129686, 0.8352252152179895, 0.8425165155244698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 296}], {
             RGBColor[
             0.6432277867867322, 0.7204149997680831, 0.9656206702005743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 299}], {
             RGBColor[
             0.7923522710279916, 0.8350967196266381, 0.8509761351220573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 186}], {
             RGBColor[
             0.22312007554742067`, 0.3518437244031648, 0.9360177302746292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 230}], {
             RGBColor[
             0.2328116110999559, 0.36203014274772405`, 0.9365696488870041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 265}], {
             RGBColor[
             0.21936843133233605`, 0.34790050846512904`, 0.9358040796866404]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 269}], {
             RGBColor[
             0.22164816720784125`, 0.350296655413888, 0.9359339072721834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 191}], {
             RGBColor[
             0.26420786908525307`, 0.39502960052800135`, 0.9383576193326653]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 203}], {
             RGBColor[
             0.27206034387321254`, 0.4032830494058043, 0.9388048061551442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 210}], {
             RGBColor[
             0.33154191612091594`, 0.45934744108992703`, 0.9424285250056568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 239}], {
             RGBColor[
             0.34783050852175984`, 0.47345580113907954`, 0.9434664197100019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 184}], {
             RGBColor[
             0.23939823162616325`, 0.3689530985366296, 0.9369447471819397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.23660390230659725`, 0.366016081251054, 0.9367856142610302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 197}], {
             RGBColor[
             0.22592979758927967`, 0.35479692041582533`, 0.9361777397883018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 211}], {
             RGBColor[
             0.2418593140070983, 0.3715398521606279, 0.9370849021826888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 216}], {
             RGBColor[
             0.2500986511246546, 0.3801999178753255, 0.9375541202425267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 168}], {
             RGBColor[
             0.38489864849528777`, 0.5078015965832141, 0.9457463794229767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 210}], {
             RGBColor[
             0.3812406788826516, 0.5046332471596473, 0.9455132968338751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 241}], {
             RGBColor[
             0.33149984085228634`, 0.458806984736167, 0.9424442983869149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 277}], {
             RGBColor[
             0.36650966152605724`, 0.4918739803278257, 0.94457464943404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 179}], {
             RGBColor[
             0.986953469781533, 0.9683582137242022, 0.5663859549250714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 207}], {
             RGBColor[
             0.8629243195572578, 0.8731271056740303, 0.676546302374514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 232}], {
             RGBColor[
             0.9871784526525289, 0.9674285696046385, 0.48831934332178484`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 240}], {
             RGBColor[
             0.987596961950581, 0.9683237186753911, 0.533871497674751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 281}], {
             RGBColor[
             0.8841377182227066, 0.5005616097485734, 0.24739196008606018`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 217}], {
             RGBColor[
             0.899879476841495, 0.9180128953290518, 0.7153753712159427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 233}], {
             RGBColor[
             0.9934058766223102, 0.9883041618002921, 0.5236485484298345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 262}], {
             RGBColor[
             0.9933514957949947, 0.9881878467094093, 0.5177295309761065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 271}], {
             RGBColor[
             0.9850940999243964, 0.9612451065301149, 0.40815265332302325`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 291}], {
             RGBColor[
             0.8761797606414349, 0.42138431296305434`, 0.25963779623893113`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 174}], {
             RGBColor[
             0.5731249742958058, 0.6609624837721939, 0.9611637427211077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 185}], {
             RGBColor[
             0.660998380157889, 0.7339582173045702, 0.9676238615993047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 194}], {
             RGBColor[
             0.6348798248522232, 0.7127539974799229, 0.9655677132502221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 215}], {
             RGBColor[
             0.874514844691243, 0.8999677108189541, 0.8534618509904951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 282}], {
             RGBColor[
             0.8587917501354356, 0.8900542041854869, 0.9612556665550847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 283}], {
             RGBColor[
             0.6863247949375169, 0.7545193417646557, 0.9696176497444712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 286}], {
             RGBColor[
             0.6564811647517911, 0.7302909383396649, 0.9672682498554315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 297}], {
             RGBColor[
             0.7571627446031911, 0.8102205578247882, 0.9764305643600557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 182}], {
             RGBColor[
             0.34652806688330007`, 0.474422427150048, 0.9433067307526943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 277}], {
             RGBColor[
             0.3674840405107483, 0.49271793843065337`, 0.944636736001335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 187}], {
             RGBColor[
             0.3284772756829356, 0.4574787305648249, 0.9422044795128589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 213}], {
             RGBColor[
             0.36045188979201, 0.48517353421527176`, 0.944241873649848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 219}], {
             RGBColor[
             0.2836300261607937, 0.41544351905027754`, 0.9394636824456108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 221}], {
             RGBColor[
             0.2938192081333214, 0.4261529953348542, 0.9400439412854023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 264}], {
             RGBColor[
             0.29384317958318956`, 0.42617819084854336`, 0.9400453064240097]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[
             0.836257672421485, 0.2727972356818921, 0.182083480011583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 195}], {
             RGBColor[
             0.8209768790641011, 0.16224306137950753`, 0.16772078912276672`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 200}], {
             RGBColor[
             0.8432609465449801, 0.30459746782045594`, 0.18792718360618468`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 225}], {
             RGBColor[
             0.8682499113225608, 0.4061856602973817, 0.21334848907618564`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 228}], {
             RGBColor[
             0.8200433742052426, 0.3983430371042317, 0.4398420336296414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 255}], {
             RGBColor[
             0.8675804054698418, 0.4039272598487107, 0.21074758526394385`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 198}], {
             RGBColor[
             0.4413043319504303, 0.556360389684118, 0.9494225547381876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 245}], {
             RGBColor[
             0.4213779646314022, 0.5393981467165758, 0.9480708091897773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 289}], {
             RGBColor[
             0.35466828761855285`, 0.4799752914739057, 0.9438802596927696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 298}], {
             RGBColor[
             0.35180269388930685`, 0.47696337077533185`, 0.9437170683691549]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 174}], {
             RGBColor[
             0.33090944455997406`, 0.4574098756542951, 0.9424391100455509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 183}], {
             RGBColor[
             0.2620424461666492, 0.39275360374480583`, 0.9382343017009069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 203}], {
             RGBColor[
             0.26454467239722235`, 0.39538360216344437`, 0.9383767997830261]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 206}], {
             RGBColor[
             0.2530845856194636, 0.3833383243485512, 0.9377241647947119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 244}], {
             RGBColor[
             0.2560033039447505, 0.38640608236585794`, 0.9378903814854801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 270}], {
             RGBColor[
             0.24887539777286288`, 0.3789142010438502, 0.9374844577737833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 272}], {
             RGBColor[
             0.2463878565667746, 0.37629963751702955`, 0.937342795982084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 186}], {
             RGBColor[
             0.24357136840210497`, 0.3733393298802981, 0.937182401147727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 196}], {
             RGBColor[
             0.2690530219671379, 0.40012216340729806`, 0.9386335436215274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 209}], {
             RGBColor[
             0.2611649721580388, 0.3918313229266909, 0.938184330854223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 230}], {
             RGBColor[
             0.25326290395464024`, 0.3835257482248573, 0.9377343197601018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 263}], {
             RGBColor[
             0.25907859446240145`, 0.3896384076845897, 0.9380655147309758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 276}], {
             RGBColor[
             0.24447758470727698`, 0.3742918206744662, 0.9372340088256796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 279}], {
             RGBColor[
             0.2579831193391787, 0.3884869938729482, 0.9380031290433184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 185}], {
             RGBColor[
             0.4801968939468863, 0.58722835298474, 0.9526796025142897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 194}], {
             RGBColor[
             0.45407833864122044`, 0.5660241331600927, 0.9506234541652072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 283}], {
             RGBColor[
             0.5055233087265141, 0.6077894774448256, 0.9546733906594562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 297}], {
             RGBColor[
             0.5763612583921884, 0.663490693504958, 0.9614863052750408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 177}], {
             RGBColor[
             0.3568594089399756, 0.48219931048302006`, 0.944007932963718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 242}], {
             RGBColor[
             0.2674717938620085, 0.3984601924131547, 0.9385434950201575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 252}], {
             RGBColor[
             0.2975212413691305, 0.4300440669881537, 0.9402547666015143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 253}], {
             RGBColor[
             0.29561827694261666`, 0.42804393072097424`, 0.9401463955926079]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 280}], {
             RGBColor[
             0.2812847712693677, 0.4129785074616403, 0.9393301236490378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 199}], {
             RGBColor[
             0.17893943915932659`, 0.3054070743451405, 0.9335017083917216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 226}], {
             RGBColor[
             0.17893944427006758`, 0.3054070797168533, 0.9335017086827707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 287}], {
             RGBColor[
             0.5599634445497977, 0.5545563829440247, 0.6024338644222329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 217}], {
             RGBColor[
             0.6131216671850642, 0.6933500026997739, 0.964666976055813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 247}], {
             RGBColor[
             0.4991479409504841, 0.603343634292864, 0.9539698061272375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 273}], {
             RGBColor[
             0.5185213619952923, 0.6190718502597115, 0.9554949527990644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 285}], {
             RGBColor[
             0.40098949086418123`, 0.5217386754938967, 0.9467716736701495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 182}], {
             RGBColor[
             0.29211972893207316`, 0.4243667349411374, 0.9399471584590454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 202}], {
             RGBColor[
             0.25258870101180897`, 0.3828171181850061, 0.9376959248999015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 208}], {
             RGBColor[
             0.2815080542956977, 0.41321319207927465`, 0.9393428392870697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 268}], {
             RGBColor[
             0.26978635473276824`, 0.4008929426399584, 0.9386753058376613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 281}], {
             RGBColor[
             0.8885997879740133, 0.5160832735920328, 0.3731054797340321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 190}], {
             RGBColor[
             0.23107912024585836`, 0.36020918501380295`, 0.9364709860958538]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 250}], {
             RGBColor[
             0.22830469938985565`, 0.3572930927857018, 0.9363129869324922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 207}], {
             RGBColor[
             0.729702675862836, 0.7887685434205706, 0.9736936013369495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 232}], {
             RGBColor[
             0.8539568089581072, 0.8830700073511788, 0.7854666422842203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 240}], {
             RGBColor[
             0.8543753182561593, 0.8839651564219314, 0.8310187966371865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 246}], {
             RGBColor[
             0.656342497401248, 0.7307927865257904, 0.9668372480070162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 256}], {
             RGBColor[
             0.8545325264557142, 0.8843014088645924, 0.8481299389821997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 296}], {
             RGBColor[
             0.7050263286294778, 0.769491193414686, 0.9712340936583042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 299}], {
             RGBColor[
             0.8541508128707371, 0.884172913273241, 0.8565895585797871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 208}], {
             RGBColor[
             0.2965714316502459, 0.42904575675219153`, 0.9402006763431414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 268}], {
             RGBColor[
             0.28484973208731645`, 0.4167255073128753, 0.939533142893733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 244}], {
             RGBColor[
             0.24855034907625476`, 0.37857255425443737`, 0.937465946731378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 189}], {
             RGBColor[
             0.2346427787554684, 0.3639548160564028, 0.9366739311760157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 197}], {
             RGBColor[
             0.22396867403815082`, 0.3527356552211741, 0.9360660567032872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 202}], {
             RGBColor[
             0.23277907926056368`, 0.361995949721885, 0.9365677962468772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 214}], {
             RGBColor[
             0.22515962250579277`, 0.3539874175711599, 0.9361338794566691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 216}], {
             RGBColor[
             0.24813752757352578`, 0.3781386526806742, 0.9374424371575123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 275}], {
             RGBColor[
             0.22510784132218828`, 0.35393299226407493`, 0.9361309305948662]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 293}], {
             RGBColor[
             0.22334920945949943`, 0.35208455867268873`, 0.9360307791119489]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 237}], {
             RGBColor[
             0.6034248054489583, 0.6889264668979879, 0.961922957584288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 239}], {
             RGBColor[
             0.4896022864326819, 0.5953748312271646, 0.9532789058066227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 282}], {
             RGBColor[
             0.7658636697865162, 0.8163200733980329, 0.9527715263482667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 283}], {
             RGBColor[
             0.5933967145885973, 0.6807852109772019, 0.9611335095376532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 295}], {
             RGBColor[
             0.7026775395247731, 0.7666581291332051, 0.9717409425805205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 297}], {
             RGBColor[
             0.6642346642542716, 0.7364864270373344, 0.9679464241532377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 196}], {
             RGBColor[
             0.255450766680841, 0.38582533066860314`, 0.9378589153057062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 230}], {
             RGBColor[
             0.23966064866834333`, 0.3692289154861624, 0.9369596914442806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 263}], {
             RGBColor[
             0.24547633917610456`, 0.3753415749458948, 0.9372908864151546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 269}], {
             RGBColor[
             0.2284972047762287, 0.3574954281523263, 0.93632394982946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 276}], {
             RGBColor[
             0.2308753294209801, 0.3599949879357713, 0.9364593805098584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 279}], {
             RGBColor[
             0.24438086405288187`, 0.3741901611342533, 0.9372285007274972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 205}], {
             RGBColor[
             0.44668815437293624`, 0.55925348518074, 0.950254691291311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 213}], {
             RGBColor[
             0.395904109711405, 0.5173339739380506, 0.9464476376799205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 264}], {
             RGBColor[
             0.3292953995025846, 0.4583386305713222, 0.9422510704540822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 212}], {
             RGBColor[
             0.20871789165381538`, 0.33670611597978567`, 0.9351975472080101]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 243}], {
             RGBColor[
             0.21194079974675017`, 0.3400935967296356, 0.9353810870560375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 294}], {
             RGBColor[
             0.20780626806211017`, 0.3357479417846294, 0.9351456315930887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 197}], {
             RGBColor[
             0.22117434471858483`, 0.3497986379355985, 0.9359069237823778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 211}], {
             RGBColor[
             0.23710386113640347`, 0.3665415696804011, 0.9368140861767649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 216}], {
             RGBColor[
             0.24534319825395978`, 0.3752016353950986, 0.9372833042366027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 275}], {
             RGBColor[
             0.22231351200262228`, 0.3509959749784993, 0.9359717976739568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 293}], {
             RGBColor[
             0.2205548801399334, 0.3491475413871131, 0.9358716461910392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 212}], {
             RGBColor[
             0.21992645288427248`, 0.3484870244968241, 0.9358358581885042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 250}], {
             RGBColor[
             0.22535768471974588`, 0.35419559351589436`, 0.9361451588067469]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 203}], {
             RGBColor[
             0.2517414689713402, 0.38192662359285945`, 0.9376476762885642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 195}], {
             RGBColor[
             0.8497053442101324, 0.36926123432797614`, 0.19469077161596268`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 200}], {
             RGBColor[
             0.8719894116910114, 0.5116156407689246, 0.21489716609938064`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[
             0.8969783764685921, 0.6132038332458503, 0.2403184715693816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 228}], {
             RGBColor[
             0.8487718393512739, 0.6053612100527003, 0.4668120161228374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 255}], {
             RGBColor[
             0.896308870615873, 0.6109454327971793, 0.23771756775713984`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 199}], {
             RGBColor[
             0.28921237678725265`, 0.4129203038152378, 0.9400888107445714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 220}], {
             RGBColor[
             0.3283447463388828, 0.4540509053495343, 0.9423173412993839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 236}], {
             RGBColor[
             0.511354201918838, 0.6127180573453962, 0.9550785966275717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 249}], {
             RGBColor[
             0.6788858964789302, 0.269361770595781, 0.42584254337299554`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 266}], {
             RGBColor[
             0.3235658537972168, 0.4490279862889558, 0.942045190438874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 283}], {
             RGBColor[
             0.5672781592829315, 0.6595809911525545, 0.9590773611885706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 286}], {
             RGBColor[
             0.5374345290972057, 0.6353525877275636, 0.9567279612995309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 297}], {
             RGBColor[
             0.6381161089486057, 0.715282207212687, 0.9658902758041552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 200}], {
             RGBColor[
             0.8414278249762438, 0.29050729216415533`, 0.1861717843217481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 225}], {
             RGBColor[
             0.8664167897538245, 0.3920954846410811, 0.21159308979174907`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.8657472839011056, 0.38983708419241014`, 0.20899218597950728`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 230}], {
             RGBColor[
             0.2651423022333762, 0.39601174901316233`, 0.938410833918081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 263}], {
             RGBColor[
             0.27095799274113747`, 0.40212440847289477`, 0.9387420288889549]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 279}], {
             RGBColor[
             0.2698625176179148, 0.40097299466125325`, 0.9386796432012976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 289}], {
             RGBColor[
             0.28595784411409636`, 0.4178902033113814, 0.9395962482343534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 298}], {
             RGBColor[
             0.28309225038485036`, 0.4148782826128075, 0.9394330569107388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 214}], {
             RGBColor[
             0.21169118846890916`, 0.33983123945035565`, 0.9353668720630313]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 275}], {
             RGBColor[
             0.21163940728530467`, 0.33977681414327066`, 0.9353639232012283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 293}], {
             RGBColor[
             0.20988077542261582`, 0.33792838055188446`, 0.9352637717183109]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 222}], {
             RGBColor[
             0.4501940180001994, 0.5640601889318158, 0.9499889976724383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 245}], {
             RGBColor[
             0.4443289893270455, 0.5589801958800422, 0.949615283231626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 258}], {
             RGBColor[
             0.7130111957358749, 0.7734744682690422, 0.9502848227262681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 278}], {
             RGBColor[
             0.5335934338471843, 0.6322342135642272, 0.9564255762110536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 290}], {
             RGBColor[
             0.5385920372825843, 0.6362923050176035, 0.9568190845839761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 220}], {
             RGBColor[
             0.21805936955163013`, 0.34652460153429643`, 0.9357295305548126]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 226}], {
             RGBColor[
             0.178927005110741, 0.3053940053717128, 0.9335010002910491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 228}], {
             RGBColor[
             0.49763512145939465`, 0.5809234064486897, 0.9579150616794772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 266}], {
             RGBColor[
             0.21328047700996416`, 0.3415016824737179, 0.9354573796943026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 225}], {
             RGBColor[
             0.9234794071043728, 0.7275983937614409, 0.2647165314935854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 255}], {
             RGBColor[
             0.9224751483252943, 0.7242107930884344, 0.2608151757752228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 282}], {
             RGBColor[
             0.9248264998510323, 0.7738160826625009, 0.5864939522963153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 295}], {
             RGBColor[
             0.8616403695892892, 0.7241541383976731, 0.6054633685285691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 209}], {
             RGBColor[
             0.29313467956513195`, 0.424290095199951, 0.9400468245012701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 218}], {
             RGBColor[
             0.2885778810548669, 0.4195006110479498, 0.9397873215672898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 229}], {
             RGBColor[
             0.3337508945428317, 0.46349998287045846`, 0.9424872897693092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 257}], {
             RGBColor[
             0.35620917982441114`, 0.48295222079512334`, 0.9439183118483695]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 259}], {
             RGBColor[
             0.3926869440225089, 0.5142503026969059, 0.9463247389793005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 261}], {
             RGBColor[
             0.36087721144814144`, 0.48699543516550725`, 0.9442157546956553]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 208}], {
             RGBColor[
             0.2570404037299817, 0.3874961399960602, 0.9379494427839974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 214}], {
             RGBColor[
             0.22050159369132202`, 0.3490915339510665, 0.935868611606621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 268}], {
             RGBColor[
             0.2453187041670522, 0.37517589055674394`, 0.937281909334589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 275}], {
             RGBColor[
             0.22044981250771753`, 0.3490371086439815, 0.9358656627448182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 206}], {
             RGBColor[
             0.24813385698154097`, 0.37813479465576916`, 0.9374422281227288]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 244}], {
             RGBColor[
             0.2510525753068279, 0.38120255267307596`, 0.9376084448134971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 270}], {
             RGBColor[
             0.2439246691349402, 0.37371067135106817`, 0.9372025211018002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 235}], {
             RGBColor[
             0.23646094075205434`, 0.36586581959294334`, 0.9367774728119916]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 253}], {
             RGBColor[
             0.26380404156370607`, 0.39460515219871184`, 0.9383346219527224]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 292}], {
             RGBColor[
             0.2369721103072519, 0.36640309120547765`, 0.9368065831619525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 213}], {
             RGBColor[
             0.4786627684820106, 0.5869482888311869, 0.9522920854283001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 231}], {
             RGBColor[
             0.4872830813565614, 0.5944147705735998, 0.9528413641420233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 244}], {
             RGBColor[
             0.23959248852906917`, 0.3691572748581827, 0.9369558098251829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 270}], {
             RGBColor[
             0.23246458235718154`, 0.361665393536175, 0.936549886113486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 272}], {
             RGBColor[
             0.22997704115109324`, 0.35905083000935434`, 0.9364082243217868]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 231}], {
             RGBColor[
             0.5953538117647618, 0.6805701172311853, 0.962430259270135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 232}], {
             RGBColor[
             0.8698424070552139, 0.8954799573196557, 0.7870499702431855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 240}], {
             RGBColor[
             0.870260916353266, 0.8963751063904083, 0.8326021245961515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 268}], {
             RGBColor[
             0.274238057450941, 0.4055719644510125, 0.9389288237217572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 218}], {
             RGBColor[
             0.2605995221174108, 0.3912369990823875, 0.9381521293109176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 276}], {
             RGBColor[
             0.24846893317691396`, 0.37848698098216405`, 0.9374613102163545]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 279}], {
             RGBColor[
             0.2619744678088157, 0.39268215418064606`, 0.9382304304339932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 239}], {
             RGBColor[
             0.39484568065555037`, 0.5164172158880604, 0.9463801955164135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 277}], {
             RGBColor[
             0.36382607089811214`, 0.48954958900708645`, 0.9444036534122333]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 216}], {
             RGBColor[
             0.2505986099544608, 0.38072540630467244`, 0.9375825921582613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 221}], {
             RGBColor[
             0.26848631667000333`, 0.39952652020881857`, 0.9386012705932207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 243}], {
             RGBColor[
             0.2149437082857312, 0.34324984399950276`, 0.9355520982549272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 250}], {
             RGBColor[
             0.21715203202826977`, 0.34557093226872304`, 0.9356778590251427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 294}], {
             RGBColor[
             0.2108091766010912, 0.3389041890544966, 0.9353166427919786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 231}], {
             RGBColor[
             0.43649903669503015`, 0.5524952593309104, 0.9490343105306326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 264}], {
             RGBColor[
             0.36127001361165895`, 0.48603343422176903`, 0.9442884645910713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 275}], {
             RGBColor[
             0.21283035575294662`, 0.34102857649325646`, 0.9354317459546102]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 293}], {
             RGBColor[
             0.21107172389025777`, 0.33918014290187026`, 0.9353315944716927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 223}], {
             RGBColor[
             0.9412290011481947, 0.7868146166289862, 0.47926705037049566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 234}], {
             RGBColor[
             0.8765804096252258, 0.42016569118196145`, 0.35308390005828916`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 271}], {
             RGBColor[
             0.9862840872732699, 0.9639445925953173, 0.5488858494022204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 274}], {
             RGBColor[
             0.979839341035498, 0.9422049502369351, 0.5238492272566825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 282}], {
             RGBColor[
             0.97938013431987, 0.9823295669124169, 0.8386095157394571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 286}], {
             RGBColor[
             0.7770695489362254, 0.8225663010665949, 0.8446220990398039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 233}], {
             RGBColor[
             0.9005620992858752, 0.9194729557138646, 0.7896746116293041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 247}], {
             RGBColor[
             0.6930619732704799, 0.7591753208357144, 0.9707042644868367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 262}], {
             RGBColor[
             0.9005077184585596, 0.9193566406229818, 0.783755594175576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 273}], {
             RGBColor[
             0.7124353943152881, 0.7749035368025619, 0.9722294111586636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 229}], {
             RGBColor[
             0.3012157370951104, 0.430446886752895, 0.9405925945789568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 284}], {
             RGBColor[
             0.25584347148447395`, 0.38623808831614403`, 0.9378812792633183]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 221}], {
             RGBColor[
             0.28442417853057445`, 0.4162782235430855, 0.9395089082482266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 264}], {
             RGBColor[
             0.28444814998044265`, 0.4163034190567747, 0.9395102733868341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 226}], {
             RGBColor[
             0.21805937466237113`, 0.3465246069060093, 0.9357295308458616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 228}], {
             RGBColor[
             0.5367674910110247, 0.6220540079829862, 0.9601435922342896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 236}], {
             RGBColor[
             0.4402011946832155, 0.5463223550644548, 0.9507193164378127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 266}], {
             RGBColor[
             0.2524128465615943, 0.3826322840080144, 0.9376859102491151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 231}], {
             RGBColor[
             0.3698663550363416, 0.4934747204504928, 0.9448363781661868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 245}], {
             RGBColor[
             0.43026765068117134`, 0.5470979459642735, 0.9486372521240278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 261}], {
             RGBColor[
             0.41838703187400994`, 0.5368075510907742, 0.9478802295992542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 278}], {
             RGBColor[
             0.51953209520131, 0.6203519636484585, 0.9554475451034554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 290}], {
             RGBColor[
             0.5245306986367102, 0.6244100551018348, 0.9558410534763778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 234}], {
             RGBColor[
             0.840664257806904, 0.28321338657069606`, 0.18538480018870795`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 271}], {
             RGBColor[
             0.9324098595457874, 0.7585161356784191, 0.29733719959784854`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 274}], {
             RGBColor[
             0.9259651133080155, 0.7367764933200369, 0.2723005774523107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 287}], {
             RGBColor[
             0.9141648921008272, 0.6925393884549282, 0.24954185631357317`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 291}], {
             RGBColor[
             0.8410569337223622, 0.2862316657285906, 0.18576082708881467`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 249}], {
             RGBColor[
             0.8688948831013429, 0.39883351601253714`, 0.22232023481210886`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 254}], {
             RGBColor[
             0.9304233123934045, 0.7541309251793602, 0.28356918675006826`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 258}], {
             RGBColor[
             0.9656458741337097, 0.9399341707856219, 0.6428561562394914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 260}], {
             RGBColor[
             0.9093392465848947, 0.8957090172216551, 0.6607919677185569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 288}], {
             RGBColor[
             0.897775647296635, 0.6134919733958007, 0.2496893942062774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 234}], {
             RGBColor[
             0.8652002847569147, 0.3827448941589432, 0.21042816323286231`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 255}], {
             RGBColor[
             0.9599585954916654, 0.876593081803823, 0.2989471339802242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 287}], {
             RGBColor[
             0.950968932525843, 0.8418366498372989, 0.2871069008798047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 228}], {
             RGBColor[
             0.4976351265701356, 0.5809234118204025, 0.9579150619705263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 266}], {
             RGBColor[
             0.21328048212070516`, 0.3415016878454308, 0.9354573799853517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 264}], {
             RGBColor[
             0.2772132461146813, 0.4086990763744601, 0.9390982563147601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 266}], {
             RGBColor[
             0.5319885984693589, 0.6170310889224077, 0.9598714413737797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 257}], {
             RGBColor[
             0.3688470358646546, 0.49389849650006856`, 0.9447235848600365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 259}], {
             RGBColor[
             0.40532480006275245`, 0.5251965784018511, 0.9471300119909675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 261}], {
             RGBColor[
             0.3735150674883849, 0.49794171087045247`, 0.9450210277073223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 284}], {
             RGBColor[
             0.3010164849724387, 0.4302374601386527, 0.9405812474653377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 263}], {
             RGBColor[
             0.2551678747286398, 0.38552799329045395`, 0.9378428050275294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 269}], {
             RGBColor[
             0.23818874032876391`, 0.3676818464968855, 0.9368758684418348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 289}], {
             RGBColor[
             0.27016772610159867`, 0.4012937881289406, 0.9386970243729278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 298}], {
             RGBColor[
             0.2673021323723527, 0.39828186743036675`, 0.9385338330493134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 240}], {
             RGBColor[
             0.9945150494485371, 0.9906765703210165, 0.6443751655434223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 256}], {
             RGBColor[
             0.9946722576480922, 0.9910128227636774, 0.6614863078884357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 296}], {
             RGBColor[
             0.8451660598218556, 0.8762026073137711, 0.7845904625645401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 299}], {
             RGBColor[
             0.994290544063115, 0.9908843271723261, 0.6699459274860231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 262}], {
             RGBColor[
             0.9940341182393746, 0.9896479070942221, 0.5920287713894679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 288}], {
             RGBColor[
             0.905963575838284, 0.6404594328305877, 0.3369687585518484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 291}], {
             RGBColor[
             0.8766348422710215, 0.4223576865529295, 0.30917062318117206`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 255}], {
             RGBColor[
             0.8645307789041956, 0.38048649371027216`, 0.20782725942062052`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 271}], {
             RGBColor[
             0.8707009818902876, 0.40130003721491675`, 0.23179733287652443`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 274}], {
             RGBColor[
             0.8664044843984396, 0.3868069423093286, 0.21510625144616582`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 287}], {
             RGBColor[
             0.8585376702603141, 0.3573155390659227, 0.19993377068700752`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 252}], {
             RGBColor[
             0.2712852344852127, 0.40246836029424277`, 0.9387606648221691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 253}], {
             RGBColor[
             0.2693822700586988, 0.40046822402706334`, 0.9386522938132629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 292}], {
             RGBColor[
             0.24255033880224458`, 0.3722661630338292, 0.9371242550224929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 249}], {
             RGBColor[
             0.7534568620418187, 0.33087607040572803`, 0.43144386013194813`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 266}], {
             RGBColor[
             0.43542230214154953`, 0.5412994360038763, 0.9504471655773028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 239}], {
             RGBColor[
             0.5249567920726707, 0.6240772116080362, 0.9560621419984239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 282}], {
             RGBColor[
             0.8012181754265049, 0.8450224537789045, 0.955554762540068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 283}], {
             RGBColor[
             0.6287512202285861, 0.7094875913580734, 0.9639167457294545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 295}], {
             RGBColor[
             0.738032045164762, 0.7953605095140767, 0.9745241787723218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 297}], {
             RGBColor[
             0.6995891698942603, 0.7651888074182058, 0.970729660345039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 251}], {
             RGBColor[
             0.2826141781107905, 0.4143757983412377, 0.9394058314019756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 300}], {
             RGBColor[
             0.2671877155710705, 0.398161608117775, 0.9385273171817448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 295}], {
             RGBColor[
             0.6242095261484855, 0.7018088738432534, 0.9658801269946564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 256}], {
             RGBColor[
             0.9950907669461442, 0.9919079718344301, 0.7070384622414018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 281}], {
             RGBColor[
             0.8890287827533787, 0.5160602768928254, 0.3514291749004852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 299}], {
             RGBColor[
             0.9947090533611671, 0.9917794762430787, 0.7154980818389891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 277}], {
             RGBColor[
             0.3140852328677468, 0.44372332658360614`, 0.9413346549652732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 243}], {
             RGBColor[
             0.22929951054390013`, 0.35833870238327276`, 0.9363696399560237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 280}], {
             RGBColor[
             0.25424538211649345`, 0.38455839506567835`, 0.9377902704379731]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 294}], {
             RGBColor[
             0.22516497885926012`, 0.35399304743826654`, 0.9361341844930751]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 294}], {
             RGBColor[
             0.21403208469402601`, 0.34229166980434655`, 0.935500182640006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 270}], {
             RGBColor[
             0.23538330068246843`, 0.36473315155348174`, 0.9367161028042543]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 272}], {
             RGBColor[
             0.23289575947638014`, 0.3621185880266611, 0.936574441012555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 289}], {
             RGBColor[
             0.3576929449951681, 0.48259509766982983`, 0.944072988186208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 298}], {
             RGBColor[
             0.35482735126592213`, 0.47958317697125596`, 0.9439097968625934]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 256}], {
             RGBColor[
             0.7970579460912328, 0.838735601938289, 0.8428569136112316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 296}], {
             RGBColor[
             0.6475517482649964, 0.7239253864883827, 0.965961068287336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 299}], {
             RGBColor[
             0.7966762325062557, 0.8386071063469377, 0.851316533208819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 267}], {
             RGBColor[
             0.5234677465828359, 0.6240137244860162, 0.9556284450179895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 273}], {
             RGBColor[
             0.598461668080708, 0.6848971683956518, 0.9615322412300882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 285}], {
             RGBColor[
             0.4809297969495969, 0.5875639936298371, 0.952808962101173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 270}], {
             RGBColor[
             0.21830317142063266`, 0.3467808527565494, 0.9357434147105796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 254}], {
             RGBColor[
             0.8428272824024504, 0.2956795702116145, 0.1872932287744991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 288}], {
             RGBColor[
             0.8330203500287888, 0.2511485807700654, 0.1791100840120061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 300}], {
             RGBColor[
             0.27128730129384493`, 0.40247053264115845`, 0.9387607825238632]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 253}], {
             RGBColor[
             0.29862833529686444`, 0.43120769290001126`, 0.9403178139629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 292}], {
             RGBColor[
             0.2717964040404102, 0.4030056319067771, 0.9387897751721301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 292}], {
             RGBColor[
             0.26989343961389634`, 0.40100549563959764`, 0.9386814041632237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 258}], {
             RGBColor[
             0.926544473085371, 0.7852032520842381, 0.5903156471830767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 260}], {
             RGBColor[
             0.870237845536556, 0.7409780985202714, 0.6082514586621423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 288}], {
             RGBColor[
             0.8717080465977426, 0.5103380275948782, 0.21466238816866762`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 287}], {
             RGBColor[
             0.9499646737467646, 0.8384490491642924, 0.28320554516144203`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 296}], {
             RGBColor[
             0.8457417773194627, 0.8774340088271846, 0.8472537592625196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 299}], {
             RGBColor[
             0.994866261560722, 0.9921157286857396, 0.7326092241840025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 259}], {
             RGBColor[
             0.4277830853443319, 0.544648816326516, 0.9485610340700278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 261}], {
             RGBColor[
             0.39597335276996437`, 0.5173939487951174, 0.9464520497863826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 260}], {
             RGBColor[
             0.9054604072768613, 0.9267813441265331, 0.9675384281515653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 278}], {
             RGBColor[
             0.7823492729369855, 0.8297662429856849, 0.9557433701572854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 290}], {
             RGBColor[
             0.7873478763723856, 0.8338243344390612, 0.9561368785302078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 260}], {
             RGBColor[
             0.656707314635238, 0.7292515443954324, 0.9682208504157948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 261}], {
             RGBColor[
             0.4324511169680622, 0.5486920306968999, 0.9488584769173136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 261}], {
             RGBColor[
             0.6248975820608704, 0.7019966768640338, 0.9661118661321497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 278}], {
             RGBColor[
             0.7260426453881705, 0.7855410894217181, 0.9736791816363508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 290}], {
             RGBColor[
             0.7310412488235707, 0.7895991808750945, 0.9740726900092733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 278}], {
             RGBColor[
             0.5017864477209948, 0.6049815757231856, 0.9543168081378697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 290}], {
             RGBColor[
             0.5067850511563949, 0.6090396671765619, 0.9547103165107921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 271}], {
             RGBColor[
             0.9857223415414609, 0.9625888518240449, 0.4765328762826566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 291}], {
             RGBColor[
             0.8765985883861446, 0.42228014315900764`, 0.3052246115453534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 269}], {
             RGBColor[
             0.24400443083652518`, 0.3737945059566179, 0.9372070634127088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 276}], {
             RGBColor[
             0.24638255548127658`, 0.37629406574006286`, 0.9373424940931072]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 279}], {
             RGBColor[
             0.25988809011317837`, 0.3904892389385449, 0.938111614310746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 289}], {
             RGBColor[
             0.27598341660935993`, 0.40740644758867306`, 0.9390282193438018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 298}], {
             RGBColor[
             0.27311782288011394`, 0.40439452689009914`, 0.9388650280201871]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 269}], {
             RGBColor[
             0.2247455605611441, 0.35355221221429056`, 0.9361102992414712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 273}], {
             RGBColor[
             0.5428411676276441, 0.6397419404528637, 0.9571535916898165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 285}], {
             RGBColor[
             0.42530929649653304`, 0.542408765687049, 0.9484303125609015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 286}], {
             RGBColor[
             0.5134415575632728, 0.6158740125652669, 0.954839146691229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 298}], {
             RGBColor[
             0.2561386884802381, 0.3865483800965307, 0.9378980914344927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 272}], {
             RGBColor[
             0.22576785330449248`, 0.35462670670465335`, 0.9361685173008583]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 274}], {
             RGBColor[
             0.9710201994330907, 0.9139064692863681, 0.34191937648403536`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 291}], {
             RGBColor[
             0.8710936578057457, 0.40431831637281135`, 0.23217335977663117`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 285}], {
             RGBColor[
             0.5003032179944051, 0.6032922095966846, 0.9543341087730001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 287}], {
             RGBColor[
             0.9527752319881305, 0.8479297220628771, 0.29412403319976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 293}], {
             RGBColor[
             0.21101994270665328`, 0.33912571759478527`, 0.9353286456098898]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 279}], {
             RGBColor[
             0.24528708035805388`, 0.3751426519284214, 0.9372801084054498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 290}], {
             RGBColor[
             0.607930114483695, 0.6925840797342462, 0.9622776320149933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 283}], {
             RGBColor[
             0.7911900845661439, 0.8368811978581185, 0.9547653144934332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 295}], {
             RGBColor[
             0.9004709095023198, 0.9227541160141217, 0.9653727475363004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 297}], {
             RGBColor[
             0.8620280342318183, 0.892582413918251, 0.9615782291090177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 295}], {
             RGBColor[
             0.728003954304401, 0.7872192535932907, 0.973734730725687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 297}], {
             RGBColor[
             0.6895610790338994, 0.7570475514974199, 0.9699402122984042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 291}], {
             RGBColor[
             0.8472367474404496, 0.3567561650145, 0.19258017572083644`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 298}], {
             RGBColor[
             0.28811767425307283`, 0.4201603217285858, 0.9397192473655857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 297}], {
             RGBColor[
             0.7988419039700752, 0.8429204696534232, 0.9805476453412715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 299}], {
             RGBColor[
             0.8453600637344856, 0.8773055132358333, 0.8557133788601069]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.10302533798448267`], {
             RGBColor[
             0.41852266255485593`, 0.5369250275695268, 0.9478888718663042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.10302533798448267`], {
             RGBColor[
             0.2307572995292167, 0.3598709310360006, 0.936452658882132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.10302533798448267`], {
             RGBColor[
             0.3773249031069595, 0.5012415989953558, 0.9452637870640326]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.10302533798448267`], {
             RGBColor[
             0.5396207399250182, 0.6371274521652572, 0.9569000678242504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.10302533798448267`], {
             RGBColor[
             0.220958970004222, 0.34957226545525755`, 0.9358946585110132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.10302533798448267`], {
             RGBColor[
             0.3056730571205615, 0.43861214219787836`, 0.9407190004490276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.10302533798448267`], {
             RGBColor[
             0.394746751143397, 0.516331528116975, 0.946373891815379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.10302533798448267`], {
             RGBColor[
             0.6518492866916434, 0.7279488840923621, 0.9659339030856515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.10302533798448267`], {
             RGBColor[
             0.5168296547678491, 0.6186246225079816, 0.9551058701141822]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.10302533798448267`], {
             RGBColor[
             0.2114327980870659, 0.3395596547761419, 0.9353521571130395]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.10302533798448267`], {
             RGBColor[
             0.34350580070653963`, 0.47194919229362253`, 0.9431088637641358]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.10302533798448267`], {
             RGBColor[
             0.20154157699751735`, 0.32916335427138743`, 0.93478886670474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.10302533798448267`], {
             RGBColor[
             0.30612838775897044`, 0.4390907235684761, 0.9407449308552837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.10302533798448267`], {
             RGBColor[
             0.8226976998778256, 0.17547004422228246`, 0.1693686490773784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.10302533798448267`], {
             RGBColor[
             0.23892277989457777`, 0.36845336862135236`, 0.9369176709091936]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.10302533798448267`], {
             RGBColor[
             0.9934703621130101, 0.9884420897444159, 0.5306673961342021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.10302533798448267`], {
             RGBColor[
             0.29622239326445615`, 0.42867889527841463`, 0.9401807991234267]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.10302533798448267`], {
             RGBColor[
             0.9464007204285422, 0.9595463255731478, 0.9756137787701872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.10302533798448267`], {
             RGBColor[
             0.2912671539208582, 0.4234706245479727, 0.9398986055734284]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.10302533798448267`], {
             RGBColor[
             0.865905855945801, 0.8959138414156087, 0.9870720676150353]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.10302533798448267`], {
             RGBColor[
             0.38345468665213356`, 0.5065509094103063, 0.9456543714511763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.10302533798448267`], {
             RGBColor[
             0.8173789776787558, 0.8572619367637411, 0.982432355720336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.10302533798448267`], {
             RGBColor[
             0.2963741173821658, 0.42883836694599214`, 0.9401894395874745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.10302533798448267`], {
             RGBColor[
             0.9556367854010767, 0.9664345677069957, 0.9599795299232305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.10302533798448267`], {
             RGBColor[
             0.2518103509231395, 0.3819990228915686, 0.9376515990138174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.10302533798448267`], {
             RGBColor[
             0.9858349896506369, 0.9884104184434465, 0.8844144095680297]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.10302533798448267`], {
             RGBColor[
             0.2584384877012701, 0.38896561489352793`, 0.9380290615978824]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.10302533798448267`], {
             RGBColor[
             0.22341264573171882`, 0.35215123421688327`, 0.9360343917138061]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.10302533798448267`], {
             RGBColor[
             0.24282295558358705`, 0.3725527005559224, 0.9371397801448899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.10302533798448267`], {
             RGBColor[
             0.46219840465570133`, 0.574272512557169, 0.9508050979844909]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.10302533798448267`], {
             RGBColor[
             0.6188367246795077, 0.7014385572283971, 0.9631362403218372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.10302533798448267`], {
             RGBColor[
             0.2562574704790552, 0.38667322750850125`, 0.9379048558936031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.10302533798448267`], {
             RGBColor[
             0.9146626577353835, 0.9347911916944939, 0.9917225348954364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.10302533798448267`], {
             RGBColor[
             0.3274991935787168, 0.458085073714969, 0.9420889369120379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.10302533798448267`], {
             RGBColor[
             0.2262311772849768, 0.3551136895845794, 0.9361949029161204]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.10302533798448267`], {
             RGBColor[
             0.7595712694087771, 0.8121021157083784, 0.9766706236037325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.10302533798448267`], {
             RGBColor[
             0.6807027709206555, 0.7504894452666685, 0.968809748742459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.10302533798448267`], {
             RGBColor[
             0.4179442959916355, 0.5364240755220139, 0.9478520188603253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.10302533798448267`], {
             RGBColor[
             0.8675327116732591, 0.4913788068770457, 0.21117838636085415`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.10302533798448267`], {
             RGBColor[
             0.2372124705557414, 0.3666557250663601, 0.9368202713225229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.10302533798448267`], {
             RGBColor[
             0.35699077137457635`, 0.483629196111943, 0.9439681141708117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.10302533798448267`], {
             RGBColor[
             0.2544378422070241, 0.3847606828235006, 0.9378012307554097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.10302533798448267`], {
             RGBColor[
             0.322173741643116, 0.45347243491334854`, 0.9417496038238137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.10302533798448267`], {
             RGBColor[
             0.9650552642631052, 0.8937853423246256, 0.3187467297321304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.10302533798448267`], {
             RGBColor[
             0.8578237913971699, 0.4454645759914146, 0.2030054339855487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.10302533798448267`], {
             RGBColor[
             0.29213812634371106`, 0.4243860717872321, 0.9399482061644217]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.10302533798448267`], {
             RGBColor[
             0.6440597930627512, 0.7218636724671273, 0.9651575191576801]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.10302533798448267`], {
             RGBColor[
             0.4136829046946342, 0.5327330725643056, 0.9475804867750808]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.10302533798448267`], {
             RGBColor[
             0.23655451757503262`, 0.36596417476700677`, 0.9367828018736257]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.10302533798448267`], {
             RGBColor[
             0.35244904856935166`, 0.4796953840916829, 0.9436787196097506]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.10302533798448267`], {
             RGBColor[
             0.993562122803693, 0.9916057865804992, 0.7563558160423134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.10302533798448267`], {
             RGBColor[
             0.8177080186927622, 0.13711716814164848`, 0.16459052473952288`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.10302533798448267`], {
             RGBColor[
             0.8317291195209172, 0.2448894931924079, 0.17801714672713256`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.10302533798448267`], {
             RGBColor[
             0.4174064139952154, 0.53595818917145, 0.9478177454951437]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.10302533798448267`], {
             RGBColor[
             0.2766948027559306, 0.4081541595332056, 0.9390687317324474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.10302533798448267`], {
             RGBColor[
             0.5476923991281734, 0.6436803887304818, 0.9575354984041846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.10302533798448267`], {
             RGBColor[
             0.24705297562595502`, 0.37699871981921224`, 0.9373806735285489]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.10302533798448267`], {
             RGBColor[
             0.5489231824340144, 0.6446795940643196, 0.9576323901745283]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.10302533798448267`], {
             RGBColor[
             0.8328101555207211, 0.25319880959989605`, 0.17905234802140027`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.10302533798448267`], {
             RGBColor[
             0.9260824493199337, 0.7446485736567867, 0.2593824075361489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.10302533798448267`], {
             RGBColor[
             0.5668393910348319, 0.659224779322463, 0.9590428197448192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.10302533798448267`], {
             RGBColor[
             0.9948487335515908, 0.9913902868768101, 0.6806946209012268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.10302533798448267`], {
             RGBColor[
             0.32451328924336914`, 0.4554988334556064, 0.9418986777281211]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.10302533798448267`], {
             RGBColor[
             0.23365539790008147`, 0.3629170161738291, 0.9366177012970005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.10302533798448267`], {
             RGBColor[
             0.28791659856684826`, 0.41994897843342893`, 0.9397077964027201]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.10302533798448267`], {
             RGBColor[
             0.9464558742569554, 0.9595874592080723, 0.9755204177251058]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.10302533798448267`], {
             RGBColor[
             0.9123183312358003, 0.932921889378774, 0.9914989309411012]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.10302533798448267`], {
             RGBColor[
             0.8743662175245639, 0.5224081609419808, 0.2168804311477391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.10302533798448267`], {
             RGBColor[
             0.9930380091079225, 0.9875173303841278, 0.48360843970387296`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.10302533798448267`], {
             RGBColor[
             0.26423372362278924`, 0.39505677528622424`, 0.9383590917103296]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.10302533798448267`], {
             RGBColor[
             0.6295965520330332, 0.7101738697986875, 0.963983293345653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.10302533798448267`], {
             RGBColor[
             0.6518075404484566, 0.7279162716099014, 0.9659297422102715]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.10302533798448267`], {
             RGBColor[
             0.3290101239879992, 0.459393765693919, 0.9421852120616541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.10302533798448267`], {
             RGBColor[
             0.6382140736915616, 0.7171699620960075, 0.9646616962176343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.10302533798448267`], {
             RGBColor[
             0.7305123993392341, 0.7894011055544591, 0.9737743070057807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.10302533798448267`], {
             RGBColor[
             0.29429562032882867`, 0.4266537347586102, 0.9400710722551477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.10302533798448267`], {
             RGBColor[
             0.2460324096232273, 0.37592604024272347`, 0.9373225538044856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.10302533798448267`], {
             RGBColor[
             0.1800403201715783, 0.3065641700889047, 0.9335644019367618]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.10302533798448267`], {
             RGBColor[
             0.39493077240962093`, 0.5164909180886005, 0.9463856174877392]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.10302533798448267`], {
             RGBColor[
             0.26782978190622225`, 0.39883646054537636`, 0.9385638819096797]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.10302533798448267`], {
             RGBColor[
             0.29584127485450173`, 0.42827831566524976`, 0.9401590949937939]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.10302533798448267`], {
             RGBColor[
             0.9950766756732579, 0.9918778320265724, 0.7055047141489801]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.10302533798448267`], {
             RGBColor[
             0.21628848662157388`, 0.34466329129434453`, 0.9356286813917323]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.10302533798448267`], {
             RGBColor[
             0.30061798398773654`, 0.43329893982513096`, 0.9404311215124237]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.10302533798448267`], {
             RGBColor[
             0.9196256639800194, 0.938748558156751, 0.9921959108615778]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.10302533798448267`], {
             RGBColor[
             0.9748675947682047, 0.926884637163092, 0.35686578084130904`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.10302533798448267`], {
             RGBColor[
             0.27610729667649436`, 0.4075366533936812, 0.9390352741303609]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.10302533798448267`], {
             RGBColor[
             0.5042211596463271, 0.6083884781620977, 0.9541132831917766]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.10302533798448267`], {
             RGBColor[
             0.27813245697413447`, 0.40966522526908, 0.9391506040133554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.10302533798448267`], {
             RGBColor[
             0.4035464690461924, 0.5239534014776945, 0.9469346020588602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.10302533798448267`], {
             RGBColor[
             0.2726124428491967, 0.4038633404346605, 0.9388362473750692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.10302533798448267`], {
             RGBColor[
             0.261097249315751, 0.3917601419255701, 0.9381804741385418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.10302533798448267`], {
             RGBColor[
             0.5312094509757161, 0.6302987888719648, 0.9562379003465947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.10302533798448267`], {
             RGBColor[
             0.8619491220774967, 0.8927588492317026, 0.9866946708064583]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.10302533798448267`], {
             RGBColor[
             0.48864650773140994`, 0.5957442741074949, 0.9528871895412045]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.10302533798448267`], {
             RGBColor[
             0.40546591079173033`, 0.5256159254437323, 0.9470569071895901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.10302533798448267`], {
             RGBColor[
             0.2574804300414378, 0.3879586355486801, 0.9379745016314742]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.10302533798448267`], {
             RGBColor[
             0.4228071955400177, 0.5406360746943846, 0.948161878519455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.10302533798448267`], {
             RGBColor[
             0.3674883934084197, 0.4927217086918333, 0.9446370133641255]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.10302533798448267`], {
             RGBColor[
             0.8501803311271197, 0.38671359097016134`, 0.19568604779889498`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.10302533798448267`], {
             RGBColor[
             0.5465902564750337, 0.6427856196737024, 0.9574487336972479]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.10302533798448267`], {
             RGBColor[
             0.38532279281260967`, 0.5081689690727651, 0.9457734055238204]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.10302533798448267`], {
             RGBColor[
             0.2788168781365947, 0.4103845953056338, 0.9391895807860471]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.10302533798448267`], {
             RGBColor[
             0.28507184392659923`, 0.4169589609386654, 0.9395457918343952]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.10302533798448267`], {
             RGBColor[
             0.28917033221241484`, 0.4212667319862237, 0.9397791946791023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.10302533798448267`], {
             RGBColor[
             0.6566687686170058, 0.7317139000018745, 0.9664142640033524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.10302533798448267`], {
             RGBColor[
             0.8341470216086144, 0.26347454816989946`, 0.18033253249694123`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.10302533798448267`], {
             RGBColor[
             0.3439204196877902, 0.4723083144158259, 0.943135282918988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.10302533798448267`], {
             RGBColor[
             0.9211686584075277, 0.939978900029778, 0.992343083047521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.10302533798448267`], {
             RGBColor[
             0.9929459767177286, 0.9913509943397207, 0.7665669512217009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.10302533798448267`], {
             RGBColor[
             0.24301438028138522`, 0.37275390005033504`, 0.937150681498242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.10302533798448267`], {
             RGBColor[
             0.2522134290242518, 0.3824226835324653, 0.9376745537153752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.10302533798448267`], {
             RGBColor[
             0.9594092884334661, 0.9692480942916449, 0.9535936663157671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.10302533798448267`], {
             RGBColor[
             0.3044111891973746, 0.4372858390035616, 0.9406471389375684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.10302533798448267`], {
             RGBColor[
             0.2215913444714862, 0.35023693111520926`, 0.9359306713014096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.10302533798448267`], {
             RGBColor[
             0.3224078413052081, 0.4536752002744616, 0.941764520447276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.10302533798448267`], {
             RGBColor[
             0.20347429876271564`, 0.33119476738824843`, 0.9348989323500625]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.10302533798448267`], {
             RGBColor[
             0.17892956896395254`, 0.30539670014399584`, 0.9335011462986966]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.10302533798448267`], {
             RGBColor[
             0.28222472928714576`, 0.41396646293510553`, 0.9393836528676069]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.10302533798448267`], {
             RGBColor[
             0.18991457468017128`, 0.31694263764133146`, 0.9341267261233757]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.10302533798448267`], {
             RGBColor[
             0.9946101233350695, 0.9908799237508646, 0.6547233713644478]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.10302533798448267`], {
             RGBColor[
             0.6241927467762723, 0.7057868172525964, 0.96355788600105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.10302533798448267`], {
             RGBColor[
             0.43622064479054923`, 0.5522541302556329, 0.9490165716446514]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.10302533798448267`], {
             RGBColor[
             0.9476938047146304, 0.9605107057164812, 0.973424924364235]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.10302533798448267`], {
             RGBColor[
             0.9926251659969516, 0.9866343007146026, 0.4386730148470409]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.10302533798448267`], {
             RGBColor[
             0.22593857337368983`, 0.3548061443216573, 0.9361782395562414]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.10302533798448267`], {
             RGBColor[
             0.8327720947194103, 0.2529062576026711, 0.17901590095508144`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.10302533798448267`], {
             RGBColor[
             0.23926061251081787`, 0.3688084521208458, 0.93693690997691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.10302533798448267`], {
             RGBColor[
             0.23590943272644063`, 0.36528614969039486`, 0.9367460652458159]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.10302533798448267`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.10302533798448267`], {
             RGBColor[
             0.324831212684851, 0.4557742027613212, 0.9419189355286837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.10302533798448267`], {
             RGBColor[
             0.2067120462521808, 0.3345978452847238, 0.9350833172797693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.10302533798448267`], {
             RGBColor[
             0.35014705105926486`, 0.47770150955020474`, 0.9435320383639844]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.10302533798448267`], {
             RGBColor[
             0.27400077350385804`, 0.40532256397795713`, 0.9389153107520011]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.10302533798448267`], {
             RGBColor[
             0.9900957369634822, 0.9901723469535194, 0.8138028001335977]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.10302533798448267`], {
             RGBColor[
             0.9929076697798414, 0.9872385477406899, 0.46942180820333496`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.10302533798448267`], {
             RGBColor[
             0.8455662065044656, 0.351247407198139, 0.19126755684933291`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.10302533798448267`], {
             RGBColor[
             0.7066839033025902, 0.7707861033473555, 0.971399305210804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.10302533798448267`], {
             RGBColor[
             0.25547870703592473`, 0.385854697753317, 0.9378605064675941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.10302533798448267`], {
             RGBColor[
             0.3280740134091542, 0.4585829537608091, 0.9421255639233401]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.10302533798448267`], {
             RGBColor[
             0.8990024464838272, 0.6342755227085348, 0.23743750448057996`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.10302533798448267`], {
             RGBColor[
             0.6590237495828186, 0.7335536290308857, 0.9666489864974762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.10302533798448267`], {
             RGBColor[
             0.39675004724917656`, 0.5180666825152114, 0.9465015400717941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.10302533798448267`], {
             RGBColor[
             0.3157094904678022, 0.4478734254480028, 0.9413377074550355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.10302533798448267`], {
             RGBColor[
             0.26920385108875294`, 0.4002806943772341, 0.9386421331168716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.10302533798448267`], {
             RGBColor[
             0.23045057360750168`, 0.3595485426447314, 0.9364351912946507]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.10302533798448267`], {
             RGBColor[
             0.22619261942112945`, 0.35507316282496604`, 0.9361927071028155]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.10302533798448267`], {
             RGBColor[
             0.23881348570074337`, 0.36833849349398035`, 0.9369114467665411]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.10302533798448267`], {
             RGBColor[
             0.2939489691399074, 0.4262893823800991, 0.9400513309827632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.10302533798448267`], {
             RGBColor[
             0.9620063021321176, 0.9711849428558795, 0.9491975995336027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.10302533798448267`], {
             RGBColor[
             0.443273542823118, 0.5583629960424816, 0.9494659760706539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.10302533798448267`], {
             RGBColor[
             0.25329610735962166`, 0.38356064710871024`, 0.9377362106448954]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.10302533798448267`], {
             RGBColor[
             0.27348165172589245`, 0.40477693407509363`, 0.9388857475347178]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.10302533798448267`], {
             RGBColor[
             0.7412000832467709, 0.797750405452433, 0.9748395554555993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.10302533798448267`], {
             RGBColor[
             0.21230278460535462`, 0.3404740657671945, 0.9354017015582263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.10302533798448267`], {
             RGBColor[
             0.2276990046313701, 0.35665646919126776`, 0.9362784935120415]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.10302533798448267`], {
             RGBColor[
             0.34598043724619154`, 0.47409259808542004`, 0.9432665454162072]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.10302533798448267`], {
             RGBColor[
             0.40363205630183896`, 0.524027532856795, 0.9469400556031081]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.10302533798448267`], {
             RGBColor[
             0.2473937360801429, 0.37735688066202433`, 0.937400079332305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.10302533798448267`], {
             RGBColor[
             0.5902199940802382, 0.6782062061588879, 0.9608834264625246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.10302533798448267`], {
             RGBColor[
             0.21627103797903324`, 0.3446449516647265, 0.9356276877173526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.10302533798448267`], {
             RGBColor[
             0.2845267439871254, 0.4163860263409461, 0.9395147491992453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.10302533798448267`], {
             RGBColor[
             0.2413593551772921, 0.3710143637312809, 0.9370564302669542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.10302533798448267`], {
             RGBColor[
             0.38392426951059677`, 0.5069576384803866, 0.9456842928556817]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.10302533798448267`], {
             RGBColor[
             0.9802603651545728, 0.9450757179590131, 0.3778156754531135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.10302533798448267`], {
             RGBColor[
             0.9927232541779302, 0.9868441014154793, 0.4493493080164732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.10302533798448267`], {
             RGBColor[
             0.7539264605068086, 0.8076923480920241, 0.9761080018061227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.10302533798448267`], {
             RGBColor[
             0.3858730274799788, 0.5086455546860418, 0.9458084659902717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.10302533798448267`], {
             RGBColor[
             0.2930250557635406, 0.42531829084204614`, 0.9399987154827865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.10302533798448267`], {
             RGBColor[
             0.8218934398484693, 0.16928814920765783`, 0.168598488764985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.10302533798448267`], {
             RGBColor[
             0.4183533072547869, 0.5367783405206518, 0.9478780806963388]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.10302533798448267`], {
             RGBColor[
             0.26949540103514497`, 0.4005871318562264, 0.9386587364550091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.10302533798448267`], {
             RGBColor[
             0.25717362368840185`, 0.38763616261899303`, 0.9379570294635482]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.10302533798448267`], {
             RGBColor[
             0.3923234880848031, 0.5142326194523638, 0.9462194836360928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.10302533798448267`], {
             RGBColor[
             0.2945111830148827, 0.42688030480911665`, 0.9400833482312222]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.10302533798448267`], {
             RGBColor[
             0.1789518783186532, 0.305420148690281, 0.9335024167834431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.10302533798448267`], {
             RGBColor[
             0.41920763486506846`, 0.5375183161569235, 0.9479325176962138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.10302533798448267`], {
             RGBColor[
             0.27705635157752495`, 0.4085341702682206, 0.9390893214029737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.10302533798448267`], {
             RGBColor[
             0.9936465744084931, 0.9916407094893913, 0.7549562343970292]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.10302533798448267`], {
             RGBColor[
             0.23402613491596813`, 0.3633066842836104, 0.936638814221599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.10302533798448267`], {
             RGBColor[
             0.7138170777657293, 0.7763585934520937, 0.9721102733779844]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.10302533798448267`], {
             RGBColor[
             0.3071831062866214, 0.4401992996140543, 0.9408049955151171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.10302533798448267`], {
             RGBColor[
             0.25458949129815345`, 0.38492007563338526`, 0.9378098669468048]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.10302533798448267`], {
             RGBColor[
             0.23743710807503443`, 0.3668918333419784, 0.9368330640969252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.10302533798448267`], {
             RGBColor[
             0.5680702998089695, 0.6602240865171163, 0.9591397213924867]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.10302533798448267`], {
             RGBColor[
             0.2299691131158081, 0.3590424971416032, 0.9364077728319058]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.10302533798448267`], {
             RGBColor[
             0.3639294956023307, 0.48963917028760373`, 0.9444102435429313]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.10302533798448267`], {
             RGBColor[
             0.20571498311483435`, 0.33354986870991854`, 0.9350265360091202]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.10302533798448267`], {
             RGBColor[
             0.2318484494359024, 0.3610177987708272, 0.9365147982551062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.10302533798448267`], {
             RGBColor[
             0.22813210557574862`, 0.35711168574399543`, 0.9363031579701084]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.10302533798448267`], {
             RGBColor[
             0.24388899418338073`, 0.37367317471505657`, 0.9372004894660854]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.10302533798448267`], {
             RGBColor[
             0.8649861375675162, 0.47981540863036076`, 0.20905346250477896`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.10302533798448267`], {
             RGBColor[
             0.39949775357450523`, 0.5204466076304757, 0.9466766214891428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.10302533798448267`], {
             RGBColor[
             0.5158331891976378, 0.6178156468678216, 0.9550274246943216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.10302533798448267`], {
             RGBColor[
             0.8191437574953648, 0.1481528857232069, 0.16596538983833015`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.10302533798448267`], {
             RGBColor[
             0.2809324202458739, 0.4126081641956031, 0.9393100577795065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.10302533798448267`], {
             RGBColor[
             0.2105002400012672, 0.3385794771003698, 0.9352990493096494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.10302533798448267`], {
             RGBColor[
             0.4642553566460736, 0.5759424388475844, 0.9509670287800365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.10302533798448267`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.10302533798448267`], {
             RGBColor[
             0.8859959599380017, 0.5752161050460523, 0.226584573288584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.10302533798448267`], {
             RGBColor[
             0.32111303850258816`, 0.4525537071655133, 0.9416820167576422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.10302533798448267`], {
             RGBColor[
             0.22812105044609293`, 0.3571000661017916, 0.9363025283968291]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.10302533798448267`], {
             RGBColor[
             0.2595939437592997, 0.3901800724706624, 0.9380948631110431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.10302533798448267`], {
             RGBColor[
             0.23088271225706164`, 0.36000274776459185`, 0.9364598009514513]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.10302533798448267`], {
             RGBColor[
             0.5294468131435418, 0.6288678000738763, 0.9560991390396908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.10302533798448267`], {
             RGBColor[
             0.23667377020378227`, 0.366089516840876, 0.9367895931344146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.10302533798448267`], {
             RGBColor[
             0.7455882739599426, 0.8011784933890475, 0.9752769292959146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.10302533798448267`], {
             RGBColor[
             0.28595975701387044`, 0.41789221389032877`, 0.9395963571711656]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.10302533798448267`], {
             RGBColor[
             0.2651563206276758, 0.3960264832343887, 0.938411632244898]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.10302533798448267`], {
             RGBColor[
             0.37855708825470646`, 0.5023088558389079, 0.9453423008120684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.10302533798448267`], {
             RGBColor[
             0.24235927283690456`, 0.3720653405899749, 0.9371133740984234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.10302533798448267`], {
             RGBColor[
             0.21172080019279638`, 0.3398623632496528, 0.9353685584068999]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.10302533798448267`], {
             RGBColor[
             0.42787872382047937`, 0.5450287775884974, 0.9484850318169096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.10302533798448267`], {
             RGBColor[
             0.21288213693655111`, 0.34108300180034146`, 0.9354346948164131]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.10302533798448267`], {
             RGBColor[
             0.9951032288756773, 0.9922430735458843, 0.7308157001748675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.10302533798448267`], {
             RGBColor[
             0.2588379470720171, 0.38938547201937, 0.9380518102180992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.10302533798448267`], {
             RGBColor[
             0.80703569950506, 0.8491816892426243, 0.9814014344154122]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.10302533798448267`], {
             RGBColor[
             0.2560427236071457, 0.38644751493038626`, 0.9378926263769374]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.10302533798448267`], {
             RGBColor[
             0.27423499655804673`, 0.4055687472585089, 0.9389286494084351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.10302533798448267`], {
             RGBColor[
             0.25719173910326026`, 0.38765520306859286`, 0.937958061109625]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.10302533798448267`], {
             RGBColor[
             0.29461336050310216`, 0.4269876998276622, 0.9400891670880182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.10302533798448267`], {
             RGBColor[
             0.43613267935432526`, 0.5521779390160471, 0.94901096656484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.10302533798448267`], {
             RGBColor[
             0.8873547734207121, 0.5813861597120881, 0.22771840056612383`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.10302533798448267`], {
             RGBColor[
             0.9695247134417432, 0.9088618438807439, 0.33610969580648287`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.10302533798448267`], {
             RGBColor[
             0.9609628542707439, 0.8799806824768295, 0.3028484896985869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.10302533798448267`], {
             RGBColor[
             0.178927010221482, 0.30539401074342565`, 0.9335010005820983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.10302533798448267`], {
             RGBColor[
             0.25976518882652405`, 0.3903600618938796, 0.9381046152642871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.10302533798448267`], {
             RGBColor[
             0.8163432429187892, 0.8564528128973794, 0.9823291233589543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.10302533798448267`], {
             RGBColor[
             0.34638875058307517`, 0.4744462585754037, 0.9432925627809762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.10302533798448267`], {
             RGBColor[
             0.24935218422087857`, 0.37941533383072157`, 0.9375116100566555]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.10302533798448267`], {
             RGBColor[
             0.44511934956958094`, 0.5599617410733233, 0.9495835892443556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.10302533798448267`], {
             RGBColor[
             0.9940965401504851, 0.9897814212502639, 0.5988230111904562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.10302533798448267`], {
             RGBColor[
             0.9940884990666902, 0.9897642221851048, 0.5979477888431959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.10302533798448267`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.10302533798448267`], {
             RGBColor[
             0.24203916924704705`, 0.37172889142129484`, 0.937095144672532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.10302533798448267`], {
             RGBColor[
             0.6232106502631707, 0.7049895070603167, 0.9634805717660004]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.10302533798448267`], {
             RGBColor[
             0.638779311088947, 0.7176288472788594, 0.9647061937760893]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.10302533798448267`], {
             RGBColor[
             0.2785145923880161, 0.4100668738178543, 0.9391723660598572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.10302533798448267`], {
             RGBColor[
             0.4111342730563943, 0.530525575937213, 0.9474180902207585]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.10302533798448267`], {
             RGBColor[
             0.9949335587465892, 0.9915717193917691, 0.6899273198963884]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.10302533798448267`], {
             RGBColor[
             0.2790754121939759, 0.4106563309919474, 0.9392043039181481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.10302533798448267`], {
             RGBColor[
             0.24043240470913427`, 0.3700400800171928, 0.9370036418090929]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.10302533798448267`], {
             RGBColor[
             0.21816661637866602`, 0.3466373247493527, 0.9357356381029547]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.10302533798448267`], {
             RGBColor[
             0.24251120685435607`, 0.3722250328754895, 0.9371220265159511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.10302533798448267`], {
             RGBColor[
             0.4244026220080174, 0.5420179529125, 0.9482635376832157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.10302533798448267`], {
             RGBColor[
             0.5988679170367666, 0.6852269795994871, 0.961564222636048]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.10302533798448267`], {
             RGBColor[
             0.5790882470358998, 0.6691689524288044, 0.9600070945582612]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.10302533798448267`], {
             RGBColor[
             0.20835094833068457`, 0.3363204352816248, 0.9351766503286018]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.10302533798448267`], {
             RGBColor[
             0.8185799679311427, 0.1438193520784336, 0.16542550431492184`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.10302533798448267`], {
             RGBColor[
             0.22258326386374316`, 0.3512795012877932, 0.9359871596433854]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.10302533798448267`], {
             RGBColor[
             0.2867137638335649, 0.4186847228646212, 0.9396392967440941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.10302533798448267`], {
             RGBColor[
             0.30053129972337833`, 0.4332078291671907, 0.9404261849718064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.10302533798448267`], {
             RGBColor[
             0.29672537087035056`, 0.42920755663283183`, 0.9402094429539937]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.10302533798448267`], {
             RGBColor[
             0.8913219113450659, 0.5994000064779764, 0.23102867769365362`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.10302533798448267`], {
             RGBColor[
             0.9589543367125869, 0.8732054811308165, 0.29504577826186157`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.10302533798448267`], {
             RGBColor[
             0.9952479751456992, 0.992244224277091, 0.7241496045864151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.10302533798448267`], {
             RGBColor[
             0.39130532114623406`, 0.5133507344247334, 0.9461546069390968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.10302533798448267`], {
             RGBColor[
             0.9617670348256762, 0.9710064976904998, 0.9496026166724999]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.10302533798448267`], {
             RGBColor[
             0.46426084954242974`, 0.5759468982282985, 0.9509674612009588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.10302533798448267`], {
             RGBColor[
             0.8491537797280463, 0.8825561905625664, 0.9854742396306309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.10302533798448267`], {
             RGBColor[
             0.4006413843936947, 0.5214371631655013, 0.9467494926336685]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.10302533798448267`], {
             RGBColor[
             0.9939797374120591, 0.9895315920033393, 0.5861097539357399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.10302533798448267`], {
             RGBColor[
             0.26098356523640104`, 0.3916406527501864, 0.9381739999984032]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.10302533798448267`], {
             RGBColor[
             0.2946613034028385, 0.4270380908550406, 0.940091897365233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.10302533798448267`], {
             RGBColor[
             0.22246582468563886`, 0.3511560652655316, 0.9359804716559281]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.10302533798448267`], {
             RGBColor[
             0.24763395401992835`, 0.3776093649474359, 0.9374137593886052]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.10302533798448267`], {
             RGBColor[
             0.467847246129772, 0.578858496543228, 0.9512497954777179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.10302533798448267`], {
             RGBColor[
             0.2625163578880115, 0.3932517150116962, 0.938261290272349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.10302533798448267`], {
             RGBColor[
             0.2270252964366493, 0.35594835916304945`, 0.9362401268270142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.10302533798448267`], {
             RGBColor[
             0.22825539451058077`, 0.357241270231474, 0.9363101790925575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.10302533798448267`], {
             RGBColor[
             0.9774649456708626, 0.9356461116447503, 0.3669559986295733]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.10302533798448267`], {
             RGBColor[
             0.22328031209840418`, 0.35201214317783264`, 0.936026855509159]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.10302533798448267`], {
             RGBColor[
             0.6178350891255162, 0.7006253843624993, 0.9630573879019151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.10302533798448267`], {
             RGBColor[
             0.9645754531953188, 0.8921668269279859, 0.3168827543384975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.10302533798448267`], {
             RGBColor[
             0.21277857456934213`, 0.34097415118617147`, 0.9354287970928072]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.10302533798448267`], {
             RGBColor[
             0.23178154572615212`, 0.3609474787299394, 0.9365109881878111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.10302533798448267`], {
             RGBColor[
             0.34909505354151776`, 0.4767903221752649, 0.9434650060123984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.10302533798448267`], {
             RGBColor[
             0.6029315110482949, 0.6885259882808699, 0.9618841236420709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.10302533798448267`], {
             RGBColor[
             0.25879261498995565`, 0.3893378251269034, 0.9380492286230886]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.10302533798448267`], {
             RGBColor[
             0.2680583595238526, 0.3990767101141639, 0.9385768990668534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.10302533798448267`], {
             RGBColor[
             0.8360763947567734, 0.2783045556433535, 0.18218010240253352`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.10302533798448267`], {
             RGBColor[
             0.9636570397640628, 0.9724160602789496, 0.9464033313040466]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.10302533798448267`], {
             RGBColor[
             0.6187231293682252, 0.7013463354372874, 0.9631272976828197]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.10302533798448267`], {
             RGBColor[
             0.25564421936180226`, 0.3860286617019018, 0.9378699321496993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.10302533798448267`], {
             RGBColor[
             0.382771346863294, 0.50595903483087, 0.945610829644085]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.10302533798448267`], {
             RGBColor[
             0.5590358689967736, 0.6528895285873056, 0.9584284979047402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.10302533798448267`], {
             RGBColor[
             0.9409750107809423, 0.8036926171977683, 0.27136531206102255`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.10302533798448267`], {
             RGBColor[
             0.8619011142240809, 0.46580703815332913`, 0.20647924340617463`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.10302533798448267`], {
             RGBColor[
             0.2909832679823188, 0.4231722424271597, 0.9398824386892002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.10302533798448267`], {
             RGBColor[
             0.6129287179190951, 0.6966421711876226, 0.9626711403879157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.10302533798448267`], {
             RGBColor[
             0.8179080138731872, 0.1386544187368418, 0.16478204035016009`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.10302533798448267`], {
             RGBColor[
             0.24306150835744214`, 0.3728034346463635, 0.9371533653724538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.10302533798448267`], {
             RGBColor[
             0.20926131084396443`, 0.33727728400339907`, 0.9352284941269724]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.10302533798448267`], {
             RGBColor[
             0.209897553009386, 0.33794601485934034`, 0.9352647271770572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.10302533798448267`], {
             RGBColor[
             0.8372847792405768, 0.8730921717492939, 0.9843421637685542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.10302533798448267`], {
             RGBColor[
             0.6962355794932261, 0.7626237933772783, 0.9703579139386239]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.10302533798448267`], {
             RGBColor[
             0.7603990286995737, 0.8127487675575523, 0.9767531269139887]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.10302533798448267`], {
             RGBColor[
             0.28525208052382683`, 0.41714840103001194`, 0.9395560560419711]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.10302533798448267`], {
             RGBColor[
             0.9944845479757449, 0.9919872330943883, 0.7410688437815899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.10302533798448267`], {
             RGBColor[
             0.2558608387541249, 0.3862563424176957, 0.9378822683036323]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{{3.834946926643799*^9, 3.8349469478612347`*^9}, 
   3.834947050298876*^9, {3.8349471234738255`*^9, 3.8349471300172663`*^9}, {
   3.8349471617829676`*^9, 3.834947218900016*^9}, {3.8349472753220577`*^9, 
   3.834947307624898*^9}, 3.83494993428115*^9, 3.8349573375769677`*^9, {
   3.8349587473655295`*^9, 3.83495875945916*^9}, 3.835018920680505*^9, 
   3.835019004300144*^9, 3.8350204747493663`*^9, 3.8350205388580465`*^9, {
   3.8350445644807453`*^9, 3.8350445774530525`*^9}, 3.8350450259183207`*^9, 
   3.8350454022679205`*^9, {3.8350519838738446`*^9, 3.8350519964753327`*^9}},
 Background->RGBColor[1, 1, 0.85],
 CellLabel->
  "Out[412]=",ExpressionUUID->"40310f2e-de89-4200-8598-42f7b6e3017b"]
}, Open  ]],

Cell["Estimated with cubic Mean Deviation v Calculated: (r=6)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 
  3.834950339812094*^9}},ExpressionUUID->"aa8fe70b-9ede-4d12-8a35-\
a985bb556b4d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphinf3", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsif3", ",", "#"}], "}"}], "]"}], ",", "500", ",", "3"}],
      "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"CMDi6f300", ",", "krif3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.834950273560528*^9, 3.834950273964845*^9}, {
   3.834957360267254*^9, 3.8349573712318316`*^9}, {3.8349587856645794`*^9, 
   3.83495878977224*^9}, {3.8350188291975336`*^9, 3.8350188308736053`*^9}, {
   3.8350443206807604`*^9, 3.835044327012074*^9}, {3.8350446304641314`*^9, 
   3.835044631224497*^9}, {3.8350448339393716`*^9, 3.8350448366448307`*^9}, {
   3.835045274648884*^9, 3.8350452787380857`*^9}, {3.835052008344263*^9, 
   3.835052010749015*^9}, {3.835178563025854*^9, 3.835178566228209*^9}},
 CellLabel->
  "In[653]:=",ExpressionUUID->"34657f3a-f2d5-428e-b03a-958670cfcbd6"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1FO4EAYYBuBzsm2dTrZdW7WsZbtVy3bLtWxr2bat5WVjyzZXrfc8u3i/
//a7+f7gJu2rtAsMCAjIJEJuKEIThrCEIzwRiEgkIhOFqEQjOjGISSxiE4e4
xCM+CUhIIhKThKQkI4jkBJOClKQiNWlISzrSk4GMIX3JTBayko3s5CAnuchN
HvKSj/wUoCCF+IEfKUwRivITxShOCUpSitKUoSzlKE8FfqYilahMFapSjerU
oCa1qE0d6lKP+jSgIY1oTBN+oSnNaM6vtKAlrWhNG9rSjvZ0oCOd6EwXutKN
7vSgJ73ozW/0oS/96M8ABjKIwQzhd4YyjOGMYCSjGM0YxjKO8UxgIpOYzBSm
Mo3pzGAms5jNH8xhLvOYzwIWsojFLGEpy1jOClayitWsYS3rWM8GNrKJzWxh
K9vYzg52sovd7GEv+9jPAQ5yiMMc4U+OcozjnOAkpzjNX5zhLOc4zwUuconL
XOEq17jODW5yi9v8zT/c4S73uM8DHvKIxzzhKc94zgte8orXvOEt73jPBz7y
ic/8yxe+8o3/CBl/IKEITRjCEo7wRCAikYhMFKISjejEICaxiE0c4hKP+CQg
IYlITBKSkowgkhNMClKSitSkIS3pSE8GMgb+/6++Az6VhWw=
          "], {Null, CompressedData["
1:eJxN2nu4llWZB+C1RcxDZpqQRxAUUVHStBgOUSMyo5BNY0aKowyCpqCIyVg4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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[57, 280] -> 
             RGBColor[
              0.46835734464181794`, 0.5790411687591923, 0.9513539022764395], 
             UndirectedEdge[46, 187] -> 
             RGBColor[
              0.6386498870733448, 0.7163687197619277, 0.965485722640316], 
             UndirectedEdge[96, 298] -> 
             RGBColor[
              0.3805323369368797, 0.5019684863575355, 0.9456498503715589], 
             UndirectedEdge[165, 207] -> 
             RGBColor[
              0.5002853996598899, 0.6051932509011412, 0.9538034457484803], 
             UndirectedEdge[69, 224] -> 
             RGBColor[
              0.4964414416979015, 0.5992342379542833, 0.9542920078572892], 
             UndirectedEdge[51, 110] -> 
             RGBColor[
              0.8002156036037575, 0.843925258014865, 0.9807027025252526], 
             UndirectedEdge[122, 231] -> 
             RGBColor[
              0.38458913363865677`, 0.5075335103710694, 0.9457266574100054], 
             UndirectedEdge[71, 246] -> 
             RGBColor[
              0.47642515968090116`, 0.5834950564492485, 0.9525681413835694], 
             UndirectedEdge[9, 239] -> 
             RGBColor[
              0.5036461209043853, 0.6011726111274138, 0.9560518558072257], 
             UndirectedEdge[99, 229] -> 
             RGBColor[
              0.4899987269992422, 0.5956979625323469, 0.953309760565221], 
             UndirectedEdge[49, 112] -> 
             RGBColor[
              0.6113867964831234, 0.6953903699031319, 0.9625497546842317], 
             UndirectedEdge[115, 243] -> 
             RGBColor[
              0.5479000812060785, 0.6396706146075535, 0.9593208276629137], 
             UndirectedEdge[58, 95] -> 
             RGBColor[
              0.4525151641021228, 0.5648825747878173, 0.950465167500071], 
             UndirectedEdge[210, 239] -> 
             RGBColor[
              0.665224008447207, 0.7380142806784675, 0.9675288553244933], 
             UndirectedEdge[94, 150] -> 
             RGBColor[
              0.3568880716537025, 0.4807061790677869, 0.9440653391907573], 
             UndirectedEdge[21, 108] -> 
             RGBColor[
              0.5816287474340985, 0.6711159576189637, 0.9602860514774921], 
             UndirectedEdge[83, 202] -> 
             RGBColor[
              0.3586376256441649, 0.4850556185069582, 0.9440730502686139], 
             UndirectedEdge[172, 174] -> 
             RGBColor[
              0.6940065197668115, 0.7602545377919292, 0.9705650388318927], 
             UndirectedEdge[3, 157] -> 
             RGBColor[
              0.49007463344149726`, 0.5945707747188915, 0.9536442085189618], 
             UndirectedEdge[181, 246] -> 
             RGBColor[
              0.6937049759307329, 0.7597719961694364, 0.970703840744835], 
             UndirectedEdge[159, 253] -> 
             RGBColor[
              0.676801242546697, 0.745935689049217, 0.9694504405021502], 
             UndirectedEdge[170, 228] -> 
             RGBColor[
              0.5301461065964597, 0.6126559553524642, 0.9601392899299674], 
             UndirectedEdge[151, 194] -> 
             RGBColor[
              0.6982889166374662, 0.7631295819526609, 0.9713559356336496], 
             UndirectedEdge[62, 100] -> 
             RGBColor[
              0.775461124368557, 0.8209509460566552, 0.8205534183897285], 
             UndirectedEdge[76, 99] -> 
             RGBColor[
              0.36694967035543324`, 0.4922550938603444, 0.9446026864075634], 
             UndirectedEdge[131, 283] -> 
             RGBColor[
              0.878676240820763, 0.9053495787385013, 0.9511626756652718], 
             UndirectedEdge[173, 263] -> 
             RGBColor[
              0.46774708694796285`, 0.5772013889263026, 0.9516773071244353], 
             UndirectedEdge[20, 75] -> 
             RGBColor[
              0.4110539010580321, 0.529570060348961, 0.9476577461852549], 
             UndirectedEdge[175, 253] -> 
             RGBColor[
              0.7074299557649031, 0.770801458247563, 0.9718616450033607], 
             UndirectedEdge[52, 193] -> 
             RGBColor[
              0.5024161311236448, 0.5997304361754252, 0.9560054583919029], 
             UndirectedEdge[282, 283] -> 
             RGBColor[
              0.7733620957709877, 0.8228756140766997, 0.978045164292918], 
             UndirectedEdge[173, 279] -> 
             RGBColor[
              0.424681114945645, 0.5398998085365851, 0.9489331814701915], 
             UndirectedEdge[95, 198] -> 
             RGBColor[
              0.35766249359523994`, 0.4842110081377413, 0.9440109157167318], 
             UndirectedEdge[18, 288] -> 
             RGBColor[
              0.5834649075941003, 0.671676507258677, 0.9610665342539229], 
             UndirectedEdge[29, 91] -> 
             RGBColor[
              0.5645836997218958, 0.6573935074968859, 0.9588652434617954], 
             UndirectedEdge[46, 169] -> 
             RGBColor[
              0.687785185854632, 0.7547535886119712, 0.9703830700273612], 
             UndirectedEdge[34, 264] -> 
             RGBColor[
              0.7581297592106956, 0.810975996985754, 0.9765269473388665], 
             UndirectedEdge[116, 277] -> 
             RGBColor[
              0.5667329920396866, 0.6550636635547976, 0.9609098388529916], 
             UndirectedEdge[60, 299] -> 
             RGBColor[
              0.7355539283845324, 0.7926334441320138, 0.9750660372473104], 
             UndirectedEdge[205, 213] -> 
             RGBColor[
              0.397769477548056, 0.517942754069085, 0.9468265546770573], 
             UndirectedEdge[240, 299] -> 
             RGBColor[
              0.9394159112762828, 0.9543370663439681, 0.987437238734973], 
             UndirectedEdge[184, 214] -> 
             RGBColor[
              0.6443068280636031, 0.7083031210397264, 0.7663672591719091], 
             UndirectedEdge[39, 59] -> 
             RGBColor[
              0.7208373913057491, 0.7757845292104552, 0.7612958224635376], 
             UndirectedEdge[246, 299] -> 
             RGBColor[
              0.7605200987019681, 0.8129021059088637, 0.9770314656287942], 
             UndirectedEdge[21, 114] -> 
             RGBColor[
              0.6278468950407292, 0.7072219258001955, 0.9648926444977752], 
             UndirectedEdge[204, 253] -> 
             RGBColor[
              0.7153961100576498, 0.7772687411735759, 0.9724887698502704], 
             UndirectedEdge[202, 214] -> 
             RGBColor[
              0.6648547748237763, 0.7274110316308495, 0.7676285792330823], 
             UndirectedEdge[26, 39] -> 
             RGBColor[
              0.6764709862989573, 0.7373565791139256, 0.7584688343681762], 
             UndirectedEdge[118, 220] -> 
             RGBColor[
              0.4731518576519888, 0.5817523015642758, 0.9520577320054775], 
             UndirectedEdge[28, 126] -> 
             RGBColor[
              0.48214670123288894`, 0.5903980341924167, 0.9523946775476217], 
             UndirectedEdge[9, 237] -> 
             RGBColor[
              0.5701496932399541, 0.653336798878414, 0.9626242931671558], 
             UndirectedEdge[174, 297] -> 
             RGBColor[
              0.7758780151265752, 0.8248884275392481, 0.9653145589038838], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.5032327378098516, 0.5953371952343968, 0.956883359787859], 
             UndirectedEdge[63, 139] -> 
             RGBColor[
              0.46423882046903825`, 0.5682142453306788, 0.9524681353411917], 
             UndirectedEdge[124, 150] -> 
             RGBColor[
              0.36773649597774727`, 0.49210856086218724`, 0.9446831409072061],
              UndirectedEdge[127, 165] -> 
             RGBColor[
              0.414990727888384, 0.5299143506553801, 0.9483651817857941], 
             UndirectedEdge[8, 22] -> 
             RGBColor[
              0.6864573922491878, 0.7543336553956257, 0.9698286429227806], 
             UndirectedEdge[127, 137] -> 
             RGBColor[
              0.31175718035957556`, 0.4428211513169793, 0.9411455147519802], 
             UndirectedEdge[21, 213] -> 
             RGBColor[
              0.41064315835549436`, 0.5283941881012748, 0.9478400179880655], 
             UndirectedEdge[41, 278] -> 
             RGBColor[
              0.45238465588617105`, 0.565920434761936, 0.9501388546347347], 
             UndirectedEdge[69, 249] -> 
             RGBColor[
              0.44937360685470584`, 0.561039478477123, 0.9505750125054828], 
             UndirectedEdge[100, 136] -> 
             RGBColor[
              0.4331163725899124, 0.5467758659882325, 0.9495895172469009], 
             UndirectedEdge[88, 222] -> 
             RGBColor[
              0.5465310592882033, 0.6424808482502629, 0.9575422932892104], 
             UndirectedEdge[153, 216] -> 
             RGBColor[
              0.40436786734873886`, 0.5189475550354079, 0.9477421564939044], 
             UndirectedEdge[60, 121] -> 
             RGBColor[
              0.45044293350306974`, 0.5623463381545762, 0.9505379708211241], 
             UndirectedEdge[203, 206] -> 
             RGBColor[
              0.5875960664958653, 0.6760759835393033, 0.9606768612713192], 
             UndirectedEdge[50, 108] -> 
             RGBColor[
              0.7336084874845481, 0.430275752272095, 0.5649787072845964], 
             UndirectedEdge[98, 181] -> 
             RGBColor[
              0.5961146738804735, 0.678826385431436, 0.9634956993923467], 
             UndirectedEdge[267, 285] -> 
             RGBColor[
              0.3679020561096674, 0.49308000253236217`, 0.9446633715856616], 
             UndirectedEdge[156, 178] -> 
             RGBColor[
              0.750440251342215, 0.8050762758625187, 0.9757320334768833], 
             UndirectedEdge[185, 295] -> 
             RGBColor[
              0.7357364972363951, 0.7930141006915619, 0.9748991352967196], 
             UndirectedEdge[83, 156] -> 
             RGBColor[
              0.607437447963322, 0.6874198256666942, 0.9647478578332733], 
             UndirectedEdge[44, 150] -> 
             RGBColor[
              0.6319241587891792, 0.7088045040939621, 0.9662273277832185], 
             UndirectedEdge[223, 274] -> 
             RGBColor[
              0.5427187274454346, 0.6318592904011571, 0.9599204646155192], 
             UndirectedEdge[20, 142] -> 
             RGBColor[
              0.6451311025303823, 0.7154385190685048, 0.9526113858004777], 
             UndirectedEdge[87, 264] -> 
             RGBColor[
              0.6549678200317146, 0.7288786211005012, 0.9672747213250026], 
             UndirectedEdge[16, 192] -> 
             RGBColor[
              0.4952071078502313, 0.5952270136692603, 0.9551083005095845], 
             UndirectedEdge[75, 143] -> 
             RGBColor[
              0.5144214597180611, 0.616669541278613, 0.9549162881783538], 
             UndirectedEdge[230, 263] -> 
             RGBColor[
              0.4974459206073936, 0.601312240008238, 0.954015308100518], 
             UndirectedEdge[52, 82] -> 
             RGBColor[
              0.8243551939243623, 0.8636374788015486, 0.9828820356987407], 
             UndirectedEdge[34, 213] -> 
             RGBColor[
              0.5291334810281378, 0.6229358362424897, 0.9582989505002694], 
             UndirectedEdge[145, 219] -> 
             RGBColor[
              0.5919736697363878, 0.6650670926113301, 0.965565084733925], 
             UndirectedEdge[237, 295] -> 
             RGBColor[
              0.7067853429450135, 0.7699292361177625, 0.9721377483554071], 
             UndirectedEdge[257, 259] -> 
             RGBColor[
              0.7252700002896869, 0.784698649490877, 0.973866015016831], 
             UndirectedEdge[116, 241] -> 
             RGBColor[
              0.5711263170316458, 0.658868940847898, 0.9611897776366145], 
             UndirectedEdge[95, 105] -> 
             RGBColor[
              0.36468445412243766`, 0.49029307741240186`, 0.944458348832249], 
             UndirectedEdge[115, 146] -> 
             RGBColor[
              0.7562586886491973, 0.8095143024424485, 0.9763404565114449], 
             UndirectedEdge[16, 170] -> 
             RGBColor[
              0.7633780605080971, 0.8152000936751784, 0.9770171209314827], 
             UndirectedEdge[199, 226] -> 
             RGBColor[
              0.46425758485636126`, 0.5749871058200207, 0.9512316653762947], 
             UndirectedEdge[78, 130] -> 
             RGBColor[
              0.6774367621042349, 0.7460943478457321, 0.9698369752366216], 
             UndirectedEdge[155, 214] -> 
             RGBColor[
              0.7055540005106693, 0.7626626553182746, 0.7702218979049389], 
             UndirectedEdge[185, 297] -> 
             RGBColor[
              0.9271944556318922, 0.9444049724961703, 0.9797868600520754], 
             UndirectedEdge[45, 53] -> 
             RGBColor[
              0.36208952122731786`, 0.4880454769637687, 0.944293002002781], 
             UndirectedEdge[49, 204] -> 
             RGBColor[
              0.6204560956846561, 0.702753235562209, 0.963263723139314], 
             UndirectedEdge[69, 254] -> 
             RGBColor[
              0.42488112211408524`, 0.5411553759908236, 0.9486468743877734], 
             UndirectedEdge[102, 295] -> 
             RGBColor[
              0.5035527753931325, 0.6074743436345844, 0.9541633148771231], 
             UndirectedEdge[14, 254] -> 
             RGBColor[
              0.42170359091475346`, 0.5384031581733242, 0.9484444049095324], 
             UndirectedEdge[125, 299] -> 
             RGBColor[
              0.6537618522116848, 0.7240156824912006, 0.9692391509634827], 
             UndirectedEdge[16, 44] -> 
             RGBColor[
              0.7597927735629918, 0.8123412831851731, 0.9766751530620351], 
             UndirectedEdge[49, 84] -> 
             RGBColor[
              0.6863933361831619, 0.7545873132872862, 0.9696146177633359], 
             UndirectedEdge[186, 230] -> 
             RGBColor[
              0.5014598998809077, 0.6047889471064916, 0.9542710753104038], 
             UndirectedEdge[215, 282] -> 
             RGBColor[
              0.6401735864642298, 0.716859068735866, 0.9661161685601736], 
             UndirectedEdge[134, 159] -> 
             RGBColor[
              0.5167074927027411, 0.6185254458401885, 0.9550962530689227], 
             UndirectedEdge[26, 266] -> 
             RGBColor[
              0.36761622997629223`, 0.4928324343016718, 0.9446451589971889], 
             UndirectedEdge[142, 150] -> 
             RGBColor[
              0.6948912230815165, 0.7585382344735181, 0.955782056680849], 
             UndirectedEdge[114, 221] -> 
             RGBColor[
              0.6710869086278768, 0.7423261167706554, 0.9682966567607443], 
             UndirectedEdge[147, 172] -> 
             RGBColor[
              0.8741776550237295, 0.9021082190883773, 0.9645319834980206], 
             UndirectedEdge[35, 211] -> 
             RGBColor[
              0.36314907157204124`, 0.47440678932508984`, 0.9455056039781589],
              UndirectedEdge[124, 295] -> 
             RGBColor[
              0.4336299994755702, 0.5460827077504959, 0.9497382160926904], 
             UndirectedEdge[166, 233] -> 
             RGBColor[
              0.5701999922030292, 0.6619530667441629, 0.9593073785790673], 
             UndirectedEdge[88, 290] -> 
             RGBColor[
              0.5748725651182767, 0.6646214480081385, 0.9603671097239217], 
             UndirectedEdge[134, 235] -> 
             RGBColor[
              0.4622023931098314, 0.5737796600307044, 0.9509424832626375], 
             UndirectedEdge[185, 239] -> 
             RGBColor[
              0.8085482860618769, 0.8510424277579272, 0.9813719841336758], 
             UndirectedEdge[260, 278] -> 
             RGBColor[
              0.602432502577612, 0.6866367691481865, 0.9628595282203366], 
             UndirectedEdge[15, 242] -> 
             RGBColor[
              0.41737205592796595`, 0.5359284299404852, 0.9478155562294803], 
             UndirectedEdge[4, 266] -> 
             RGBColor[
              0.4908038695598578, 0.595400378640162, 0.9536359733723871], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.5228161586189409, 0.6231916431586491, 0.9556581320583789], 
             UndirectedEdge[3, 123] -> 
             RGBColor[
              0.46860842867270464`, 0.5759778270709861, 0.952276400932914], 
             UndirectedEdge[28, 184] -> 
             RGBColor[
              0.40405267888593516`, 0.5214466052778821, 0.9474665724360556], 
             UndirectedEdge[116, 210] -> 
             RGBColor[
              0.6899069686914221, 0.7572967968186942, 0.9699890221262587], 
             UndirectedEdge[118, 120] -> 
             RGBColor[
              0.3895617255747437, 0.5118405195763702, 0.9460435065710825], 
             UndirectedEdge[15, 89] -> 
             RGBColor[
              0.5198779792928658, 0.620806296818271, 0.9554268278189249], 
             UndirectedEdge[11, 283] -> 
             RGBColor[
              0.667518970960779, 0.7388491112813753, 0.9684125934725741], 
             UndirectedEdge[157, 201] -> 
             RGBColor[
              0.6534500411154083, 0.7235224028816253, 0.965961742740238], 
             UndirectedEdge[196, 279] -> 
             RGBColor[
              0.3999058887513316, 0.5197861638008205, 0.9469827849095311], 
             UndirectedEdge[7, 11] -> 
             RGBColor[
              0.6279087519679106, 0.7079053071553323, 0.9644646170219071], 
             UndirectedEdge[76, 284] -> 
             RGBColor[
              0.3363779611159017, 0.4657754158958465, 0.9426546841283214], 
             UndirectedEdge[34, 108] -> 
             RGBColor[
              0.7001190701067419, 0.7656576057601787, 0.970744983989696], 
             UndirectedEdge[46, 213] -> 
             RGBColor[
              0.4337330205478802, 0.5471395784154914, 0.9496577365208023], 
             UndirectedEdge[261, 278] -> 
             RGBColor[
              0.4108242486918938, 0.5299228989370558, 0.9474906622387403], 
             UndirectedEdge[58, 66] -> 
             RGBColor[
              0.5294358467877089, 0.6288588970921825, 0.9560982757279886], 
             UndirectedEdge[194, 297] -> 
             RGBColor[
              0.7572119282729466, 0.8097344573338423, 0.9638450961706371], 
             UndirectedEdge[283, 297] -> 
             RGBColor[
              0.8653039903639066, 0.8953765762428283, 0.9737984076472387], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.5942212339758234, 0.6801887146352811, 0.962063906648285], 
             UndirectedEdge[6, 169] -> 
             RGBColor[
              0.8100062948602298, 0.8515023409114437, 0.9816975155986236], 
             UndirectedEdge[11, 172] -> 
             RGBColor[
              0.6707293838120656, 0.7413571102008418, 0.9687325774225766], 
             UndirectedEdge[4, 82] -> 
             RGBColor[
              0.7699846003808559, 0.8205975040809674, 0.9778493501752021], 
             UndirectedEdge[140, 230] -> 
             RGBColor[
              0.4355750853835101, 0.5442829805051864, 0.9501989030134078], 
             UndirectedEdge[207, 232] -> 
             RGBColor[
              0.3727038511955644, 0.4946945489878862, 0.9451171635958837], 
             UndirectedEdge[147, 244] -> 
             RGBColor[
              0.807409649850275, 0.8499485459912408, 0.9578771727248139], 
             UndirectedEdge[56, 296] -> 
             RGBColor[
              0.30721059959564917`, 0.4340133258840956, 0.9410341180878385], 
             UndirectedEdge[243, 294] -> 
             RGBColor[
              0.42236000959720643`, 0.5392598186892551, 0.9484066274318034], 
             UndirectedEdge[211, 216] -> 
             RGBColor[
              0.3580608419058512, 0.4702759352599425, 0.9451050399000369], 
             UndirectedEdge[107, 141] -> 
             RGBColor[
              0.47845611588464154`, 0.584420563224088, 0.9529278797754832], 
             UndirectedEdge[19, 175] -> 
             RGBColor[
              0.5505130282086022, 0.6459703024858661, 0.9577575486577008], 
             UndirectedEdge[17, 158] -> 
             RGBColor[
              0.3507370246893895, 0.47821251505568185`, 0.9435696309620027], 
             UndirectedEdge[115, 242] -> 
             RGBColor[
              0.5665200130553887, 0.6557982637104396, 0.9605072732553925], 
             UndirectedEdge[159, 292] -> 
             RGBColor[
              0.4259439885125621, 0.5408045627201585, 0.9490456047914373], 
             UndirectedEdge[34, 205] -> 
             RGBColor[
              0.6189761617643058, 0.6998976248027625, 0.9642781575869872], 
             UndirectedEdge[23, 180] -> 
             RGBColor[
              0.45094043369137504`, 0.5646652943547857, 0.9500479982081567], 
             UndirectedEdge[47, 158] -> 
             RGBColor[
              0.29026037205339345`, 0.42236550628697656`, 0.9398429890512772],
              UndirectedEdge[130, 199] -> 
             RGBColor[
              0.46284039926056963`, 0.5738365707098736, 0.9511200993348721], 
             UndirectedEdge[112, 204] -> 
             RGBColor[
              0.6121780015907041, 0.6960327058528496, 0.9626120412485801], 
             UndirectedEdge[217, 247] -> 
             RGBColor[
              0.886404498748788, 0.9122589027658746, 0.9890272464649387], 
             UndirectedEdge[102, 185] -> 
             RGBColor[
              0.6718192908455648, 0.7407517230257492, 0.9699699880153219], 
             UndirectedEdge[136, 137] -> 
             RGBColor[
              0.32128340466975647`, 0.45270126977666203`, 0.9416928723391652],
              UndirectedEdge[138, 258] -> 
             RGBColor[
              0.5371857661690557, 0.6351506307758492, 0.9567083777705783], 
             UndirectedEdge[79, 277] -> 
             RGBColor[
              0.5314331544809321, 0.6274871621651965, 0.9573914809408723], 
             UndirectedEdge[41, 259] -> 
             RGBColor[
              0.5053975833904621, 0.6089587175150879, 0.9543122264806244], 
             UndirectedEdge[225, 287] -> 
             RGBColor[
              0.5664688664594663, 0.6589239707802392, 0.9590136506929702], 
             UndirectedEdge[167, 194] -> 
             RGBColor[
              0.6146439096137678, 0.6976839822743579, 0.9630459138974194], 
             UndirectedEdge[64, 219] -> 
             RGBColor[
              0.7213863867978187, 0.7811436374346364, 0.9740231151001291], 
             UndirectedEdge[83, 293] -> 
             RGBColor[
              0.6106657635523014, 0.6899939968870542, 0.9650557774561016], 
             UndirectedEdge[31, 95] -> 
             RGBColor[
              0.29062025122111607`, 0.41462923666138174`, 0.9401605961641415],
              UndirectedEdge[256, 299] -> 
             RGBColor[
              0.696236866578641, 0.7607140821445414, 0.9719708541188077], 
             UndirectedEdge[129, 269] -> 
             RGBColor[
              0.4695446759778679, 0.5780726014833701, 0.9519813278460247], 
             UndirectedEdge[83, 126] -> 
             RGBColor[
              0.4161837012309455, 0.5348991368303697, 0.947739835319007], 
             UndirectedEdge[23, 81] -> 
             RGBColor[
              0.4945856698641997, 0.6005659534830987, 0.9533547421401655], 
             UndirectedEdge[235, 252] -> 
             RGBColor[
              0.445128682097329, 0.5599184522688391, 0.9495983781886691], 
             UndirectedEdge[6, 264] -> 
             RGBColor[
              0.7849504077360359, 0.8319284914582282, 0.9792001789306617], 
             UndirectedEdge[167, 215] -> 
             RGBColor[
              0.58954746239797, 0.6773095558425102, 0.9610702296412766], 
             UndirectedEdge[273, 285] -> 
             RGBColor[
              0.4249763947177009, 0.5425149259949729, 0.9483000979729095], 
             UndirectedEdge[267, 273] -> 
             RGBColor[
              0.37448662111141084`, 0.4987832217870125, 0.9450829342450704], 
             UndirectedEdge[66, 109] -> 
             RGBColor[
              0.6024186104760573, 0.6879316234424118, 0.9619654246403087], 
             UndirectedEdge[104, 173] -> 
             RGBColor[
              0.5698462861545481, 0.6616659122397301, 0.959279533543263], 
             UndirectedEdge[9, 185] -> 
             RGBColor[
              0.5991008475313357, 0.6764216634522134, 0.9653856801084684], 
             UndirectedEdge[233, 288] -> 
             RGBColor[
              0.5246215589144325, 0.6249504413154595, 0.9557192773512866], 
             UndirectedEdge[139, 147] -> 
             RGBColor[
              0.6199027853555588, 0.6902948416867865, 0.9444217310323768], 
             UndirectedEdge[65, 103] -> 
             RGBColor[
              0.5699833668046019, 0.655300956571774, 0.9622130948099488], 
             UndirectedEdge[33, 124] -> 
             RGBColor[
              0.5184752850269086, 0.6135116939170628, 0.9574104514238595], 
             UndirectedEdge[82, 226] -> 
             RGBColor[
              0.7224788549286658, 0.7820301998134352, 0.9741095238739264], 
             UndirectedEdge[6, 221] -> 
             RGBColor[
              0.701910504684232, 0.7664057442778865, 0.9713688647527596], 
             UndirectedEdge[125, 136] -> 
             RGBColor[
              0.340955468762036, 0.46974022294670414`, 0.942946358867802], 
             UndirectedEdge[112, 292] -> 
             RGBColor[
              0.4554695568219823, 0.5647747491854402, 0.9513699656844753], 
             UndirectedEdge[58, 67] -> 
             RGBColor[
              0.53774938196147, 0.6356081994667333, 0.9567527476703498], 
             UndirectedEdge[73, 105] -> 
             RGBColor[
              0.41949223653641243`, 0.5363171511014679, 0.9483506485485627], 
             UndirectedEdge[263, 298] -> 
             RGBColor[
              0.4324888464098876, 0.5485771608918577, 0.9489016492740874], 
             UndirectedEdge[60, 170] -> 
             RGBColor[
              0.685325696933328, 0.7525852237841649, 0.970358710644275], 
             UndirectedEdge[10, 129] -> 
             RGBColor[
              0.5388898061258093, 0.636534047178867, 0.956842526038078], 
             UndirectedEdge[53, 234] -> 
             RGBColor[
              0.4789524398941616, 0.5848819462013961, 0.9529508037507572], 
             UndirectedEdge[51, 154] -> 
             RGBColor[
              0.6356756073300287, 0.7120310462799859, 0.9664768508840205], 
             UndirectedEdge[17, 84] -> 
             RGBColor[
              0.5726711393982349, 0.6606035703597629, 0.9611203600437036], 
             UndirectedEdge[98, 160] -> 
             RGBColor[
              0.3706706132679357, 0.4954779875911253, 0.9448397815996474], 
             UndirectedEdge[25, 147] -> 
             RGBColor[
              0.737778732865685, 0.7935836748280772, 0.9522830038152736], 
             UndirectedEdge[159, 204] -> 
             RGBColor[
              0.5826524332812839, 0.6720625193875678, 0.9602876803555422], 
             UndirectedEdge[37, 94] -> 
             RGBColor[
              0.3945630998309667, 0.5117712964630396, 0.9468989526313263], 
             UndirectedEdge[37, 283] -> 
             RGBColor[
              0.6456275566478508, 0.721076674945164, 0.9666892211469675], 
             UndirectedEdge[9, 142] -> 
             RGBColor[
              0.6241490768742801, 0.6959199441224784, 0.951323676678082], 
             UndirectedEdge[51, 109] -> 
             RGBColor[
              0.7414021727924627, 0.7979797588664518, 0.9748407293847421], 
             UndirectedEdge[123, 257] -> 
             RGBColor[
              0.601677877944333, 0.6808623650577795, 0.9651030727900562], 
             UndirectedEdge[212, 294] -> 
             RGBColor[
              0.42277173207327534`, 0.5396164320042527, 0.9484328620239066], 
             UndirectedEdge[237, 297] -> 
             RGBColor[
              0.8982433013405107, 0.9213201079223708, 0.9770254731107628], 
             UndirectedEdge[163, 197] -> 
             RGBColor[
              0.43104020949528166`, 0.5474920591270753, 0.9487624728322939], 
             UndirectedEdge[76, 229] -> 
             RGBColor[
              0.4457668726215972, 0.5573865534280731, 0.9504913459169705], 
             UndirectedEdge[18, 24] -> 
             RGBColor[
              0.6402114449443379, 0.717745902681975, 0.965533829543549], 
             UndirectedEdge[44, 124] -> 
             RGBColor[
              0.5639776799786095, 0.64912463743237, 0.9619281569028726], 
             UndirectedEdge[26, 82] -> 
             RGBColor[
              0.6467969607972905, 0.7180295597424771, 0.9688585358000039], 
             UndirectedEdge[7, 106] -> 
             RGBColor[
              0.8169935438240297, 0.8578741815065939, 0.9821515646403512], 
             UndirectedEdge[53, 255] -> 
             RGBColor[
              0.34544484694449906`, 0.47362869668564533`, 0.9432324180757874],
              UndirectedEdge[89, 242] -> 
             RGBColor[
              0.4947264203721214, 0.5990212806352304, 0.9538241927251452], 
             UndirectedEdge[121, 181] -> 
             RGBColor[
              0.5838662619299627, 0.6682174266229883, 0.9627152414137056], 
             UndirectedEdge[217, 273] -> 
             RGBColor[
              0.6624310907535771, 0.7329881538800872, 0.9692023613487433], 
             UndirectedEdge[141, 240] -> 
             RGBColor[
              0.6420014048749632, 0.7133932770805, 0.9621252034343095], 
             UndirectedEdge[42, 159] -> 
             RGBColor[
              0.5506522362731144, 0.646083317863889, 0.9577685076264751], 
             UndirectedEdge[51, 52] -> 
             RGBColor[
              0.7715141260160722, 0.8215034455840564, 0.9778420074698697], 
             UndirectedEdge[170, 225] -> 
             RGBColor[
              0.6662325891532404, 0.7370845787535862, 0.9688556312594682], 
             UndirectedEdge[51, 179] -> 
             RGBColor[
              0.8835885150964957, 0.9099451665376975, 0.9863890115758058], 
             UndirectedEdge[36, 198] -> 
             RGBColor[
              0.44073235346774686`, 0.553179509499724, 0.9501281096979819], 
             UndirectedEdge[150, 295] -> 
             RGBColor[
              0.5015764782861398, 0.6057625744120883, 0.9540373869730365], 
             UndirectedEdge[140, 196] -> 
             RGBColor[
              0.3811010255297659, 0.5000584846874864, 0.9459105054766649], 
             UndirectedEdge[31, 73] -> 
             RGBColor[
              0.3454280336350909, 0.4606533103504479, 0.944052895880455], 
             UndirectedEdge[188, 212] -> 
             RGBColor[
              0.4994233159328177, 0.6018351697265061, 0.954474314685057], 
             UndirectedEdge[172, 244] -> 
             RGBColor[
              0.7198749026819751, 0.7810910123178394, 0.9727140607520433], 
             UndirectedEdge[7, 63] -> 
             RGBColor[
              0.6756930582930539, 0.74657581968676, 0.9683104274061659], 
             UndirectedEdge[128, 218] -> 
             RGBColor[
              0.6240259332770233, 0.70487404147007, 0.9640762316352804], 
             UndirectedEdge[138, 154] -> 
             RGBColor[
              0.47958420945437563`, 0.5880939992497396, 0.9522547546562965], 
             UndirectedEdge[1, 297] -> 
             RGBColor[
              0.7072410796066119, 0.7691658712254336, 0.9599112079143731], 
             UndirectedEdge[90, 123] -> 
             RGBColor[
              0.28890488642165724`, 0.4195343029167533, 0.9398172950789955], 
             UndirectedEdge[8, 61] -> 
             RGBColor[
              0.6142838797164961, 0.697742352584096, 0.9627778236887283], 
             UndirectedEdge[201, 209] -> 
             RGBColor[
              0.695255346439769, 0.759732057157846, 0.9686255398285264], 
             UndirectedEdge[44, 94] -> 
             RGBColor[
              0.5531292556545647, 0.6377222556379696, 0.9613103551864237], 
             UndirectedEdge[114, 213] -> 
             RGBColor[
              0.5251305334971229, 0.6198087032077328, 0.9578999741000493], 
             UndirectedEdge[82, 107] -> 
             RGBColor[
              0.7752293003085946, 0.8248553877533448, 0.9782622321654826], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.5210131322577285, 0.6217895092619881, 0.9554991587620695], 
             UndirectedEdge[182, 268] -> 
             RGBColor[
              0.6216878775965344, 0.6875365834906768, 0.893468134902879], 
             UndirectedEdge[157, 229] -> 
             RGBColor[
              0.4681072089079256, 0.5767366298613404, 0.9519148523903516], 
             UndirectedEdge[99, 157] -> 
             RGBColor[
              0.3892900066417616, 0.5116051702936117, 0.9460261928809445], 
             UndirectedEdge[249, 288] -> 
             RGBColor[
              0.5028242338256653, 0.6072543908500934, 0.9540033120740662], 
             UndirectedEdge[66, 138] -> 
             RGBColor[
              0.5337526396192886, 0.6323634639821597, 0.9564381094726236], 
             UndirectedEdge[215, 286] -> 
             RGBColor[
              0.4269552126368211, 0.5425854269358682, 0.9488802770974208], 
             UndirectedEdge[83, 275] -> 
             RGBColor[
              0.4907225262185325, 0.5954825170777248, 0.9535886280831858], 
             UndirectedEdge[95, 289] -> 
             RGBColor[
              0.3761638333313525, 0.5002359387127887, 0.9451898047246245], 
             UndirectedEdge[37, 75] -> 
             RGBColor[
              0.4984890497864305, 0.6037348931492272, 0.9536620305061952], 
             UndirectedEdge[88, 260] -> 
             RGBColor[
              0.5927854884071306, 0.6786151598246505, 0.9621525025115691], 
             UndirectedEdge[60, 82] -> 
             RGBColor[
              0.7349126064071658, 0.7921244793978024, 0.9750883543366462], 
             UndirectedEdge[50, 227] -> 
             RGBColor[
              0.7505313987725166, 0.4434960591891454, 0.5666654249281837], 
             UndirectedEdge[12, 248] -> 
             RGBColor[
              0.3207611823808119, 0.4444555912304561, 0.9419449497309591], 
             UndirectedEdge[103, 164] -> 
             RGBColor[
              0.5106694295096867, 0.6089327534462432, 0.9563096492622817], 
             UndirectedEdge[127, 228] -> 
             RGBColor[
              0.2580417302878341, 0.3885485976961338, 0.9380064668501371], 
             UndirectedEdge[163, 184] -> 
             RGBColor[
              0.37901065370262155`, 0.5011163611036898, 0.9454951724816644], 
             UndirectedEdge[11, 183] -> 
             RGBColor[
              0.4579993795245326, 0.5683618707940843, 0.9511657580869592], 
             UndirectedEdge[226, 266] -> 
             RGBColor[
              0.44329812410766756`, 0.55683307437263, 0.9498961470711114], 
             UndirectedEdge[98, 178] -> 
             RGBColor[
              0.528839162921106, 0.6262702449571574, 0.9567903051853114], 
             UndirectedEdge[200, 255] -> 
             RGBColor[
              0.3150851057608943, 0.4448964106409077, 0.9413871235818421], 
             UndirectedEdge[223, 234] -> 
             RGBColor[
              0.45509737457957555`, 0.5629864869152674, 0.9514759409247471], 
             UndirectedEdge[111, 190] -> 
             RGBColor[
              0.6298531311490796, 0.7095520746059741, 0.9645710345094918], 
             UndirectedEdge[85, 181] -> 
             RGBColor[
              0.5783759520844984, 0.6634619961858437, 0.9623654037252429], 
             UndirectedEdge[57, 134] -> 
             RGBColor[
              0.4906390940701756, 0.5973619454622965, 0.9530440532368765], 
             UndirectedEdge[9, 131] -> 
             RGBColor[
              0.6356645409312569, 0.70450815836133, 0.9318309997436585], 
             UndirectedEdge[184, 189] -> 
             RGBColor[
              0.509784432677516, 0.6060185278424693, 0.95665565132686], 
             UndirectedEdge[194, 286] -> 
             RGBColor[
              0.45205165985261897`, 0.5629598533677159, 0.9508559613535637], 
             UndirectedEdge[171, 298] -> 
             RGBColor[
              0.5733375563428555, 0.6639699309310663, 0.959916983494012], 
             UndirectedEdge[108, 213] -> 
             RGBColor[
              0.4789123858904921, 0.5837027350265012, 0.9532933810797661], 
             UndirectedEdge[158, 175] -> 
             RGBColor[
              0.4572842722891503, 0.56637131100691, 0.9514990503990739], 
             UndirectedEdge[37, 297] -> 
             RGBColor[
              0.7307094648589012, 0.7882185636119494, 0.9617587251689611], 
             UndirectedEdge[68, 234] -> 
             RGBColor[
              0.5013491490249841, 0.6042808499591826, 0.954377902251941], 
             UndirectedEdge[38, 252] -> 
             RGBColor[
              0.638426807411995, 0.7146096713053237, 0.9665526203769503], 
             UndirectedEdge[42, 252] -> 
             RGBColor[
              0.506228452193022, 0.6100180886790033, 0.9542713046140072], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.6306025138628183, 0.70780621494668, 0.9660756932570913], 
             UndirectedEdge[184, 216] -> 
             RGBColor[
              0.4158842681080083, 0.5310520224153815, 0.9483979984801565], 
             UndirectedEdge[16, 59] -> 
             RGBColor[
              0.5696186001580895, 0.6605801462563918, 0.9598167216166964], 
             UndirectedEdge[7, 185] -> 
             RGBColor[
              0.8025023284279734, 0.8463192797033419, 0.9807693795794147], 
             UndirectedEdge[127, 299] -> 
             RGBColor[
              0.6134597718228307, 0.6874790643356741, 0.9667307830409855], 
             UndirectedEdge[166, 217] -> 
             RGBColor[
              0.7203857822980615, 0.7806291379585641, 0.9736015396912212], 
             UndirectedEdge[101, 207] -> 
             RGBColor[
              0.4262689117958256, 0.5434064001522247, 0.9484454639208726], 
             UndirectedEdge[14, 69] -> 
             RGBColor[
              0.3462346910899687, 0.47431281998573005`, 0.9432827462463049], 
             UndirectedEdge[51, 107] -> 
             RGBColor[
              0.7223882324003044, 0.7827213545358525, 0.9732222039366117], 
             UndirectedEdge[74, 233] -> 
             RGBColor[
              0.5084424282398019, 0.6110182257144962, 0.9546658845688152], 
             UndirectedEdge[158, 252] -> 
             RGBColor[
              0.3822317749908518, 0.5054403126236784, 0.9455906428853955], 
             UndirectedEdge[86, 110] -> 
             RGBColor[
              0.5977320299024128, 0.6815251112245274, 0.9630494428607452], 
             UndirectedEdge[58, 73] -> 
             RGBColor[
              0.5073229465160976, 0.6109066484768835, 0.9543574672163846], 
             UndirectedEdge[13, 96] -> 
             RGBColor[
              0.37943077160069155`, 0.5010741859926651, 0.9455631311131274], 
             UndirectedEdge[16, 53] -> 
             RGBColor[
              0.5172680238765899, 0.615236708297827, 0.9564809891878362], 
             UndirectedEdge[44, 170] -> 
             RGBColor[
              0.8317506297351467, 0.8686793911541503, 0.9838143116483327], 
             UndirectedEdge[27, 32] -> 
             RGBColor[
              0.3827966108200537, 0.5059809172004118, 0.9456124394410698], 
             UndirectedEdge[116, 164] -> 
             RGBColor[
              0.733869077466142, 0.7920233680188983, 0.9741088693115303], 
             UndirectedEdge[70, 300] -> 
             RGBColor[
              0.568516837278211, 0.6568146521110728, 0.9609363524012238], 
             UndirectedEdge[79, 116] -> 
             RGBColor[
              0.7271596423646022, 0.7867819063239798, 0.9734401355238447], 
             UndirectedEdge[137, 195] -> 
             RGBColor[
              0.4661133718647731, 0.5741673044685605, 0.952020554528785], 
             UndirectedEdge[156, 214] -> 
             RGBColor[
              0.9136545971429333, 0.9297752387905854, 0.7883033867977418], 
             UndirectedEdge[14, 249] -> 
             RGBColor[
              0.44619607565537406`, 0.5582872606596235, 0.9503725430272418], 
             UndirectedEdge[84, 89] -> 
             RGBColor[
              0.6751770627631348, 0.7454814372375489, 0.968731631633148], 
             UndirectedEdge[98, 246] -> 
             RGBColor[
              0.4876575157710162, 0.5932239587398739, 0.953283857181249], 
             UndirectedEdge[4, 107] -> 
             RGBColor[
              0.6107041650615231, 0.6948361789628814, 0.962496015438162], 
             UndirectedEdge[20, 295] -> 
             RGBColor[
              0.45181635773500567`, 0.5626628590070749, 0.9508667160926652], 
             UndirectedEdge[57, 175] -> 
             RGBColor[
              0.5486178803559716, 0.6444317360836628, 0.9576083556765864], 
             UndirectedEdge[93, 160] -> 
             RGBColor[
              0.46771319656846005`, 0.5759789355736422, 0.9520048045257965], 
             UndirectedEdge[13, 149] -> 
             RGBColor[
              0.5880982523136815, 0.6754673496568864, 0.9614112662014039], 
             UndirectedEdge[230, 298] -> 
             RGBColor[
              0.5346520456837388, 0.6330936423430619, 0.9565089140126501], 
             UndirectedEdge[96, 198] -> 
             RGBColor[
              0.3048377898853212, 0.43685034739211803`, 0.9407037962451414], 
             UndirectedEdge[32, 182] -> 
             RGBColor[
              0.28755080223730844`, 0.41855238264857375`, 0.9397240235378803],
              UndirectedEdge[80, 241] -> 
             RGBColor[
              0.5849124481213693, 0.6696387712336669, 0.9625638503449183], 
             UndirectedEdge[55, 292] -> 
             RGBColor[
              0.3239478864945474, 0.45492445757723443`, 0.9418657503052691], 
             UndirectedEdge[121, 160] -> 
             RGBColor[
              0.35842220131742497`, 0.4848690287826777, 0.9440593236210062], 
             UndirectedEdge[62, 220] -> 
             RGBColor[
              0.7699420676813191, 0.8164703272072851, 0.8201189380303383], 
             UndirectedEdge[28, 189] -> 
             RGBColor[
              0.6192632591591369, 0.7005189588094733, 0.9640353066026763], 
             UndirectedEdge[25, 91] -> 
             RGBColor[
              0.548998721930573, 0.6447409204306415, 0.9576383369204077], 
             UndirectedEdge[41, 99] -> 
             RGBColor[
              0.4251631839052175, 0.5426767134009023, 0.9483120000147668], 
             UndirectedEdge[148, 206] -> 
             RGBColor[
              0.5043462059752055, 0.6084899964051541, 0.9541231272968458], 
             UndirectedEdge[3, 90] -> 
             RGBColor[
              0.43304723608150203`, 0.540054187660945, 0.9501980264779301], 
             UndirectedEdge[99, 104] -> 
             RGBColor[
              0.5053313222398955, 0.6081456540742536, 0.9545167986277121], 
             UndirectedEdge[193, 266] -> 
             RGBColor[
              0.33338994200621164`, 0.4615125448045019, 0.9425256127928701], 
             UndirectedEdge[275, 293] -> 
             RGBColor[
              0.7197827844071647, 0.7805272724439866, 0.9731078622846454], 
             UndirectedEdge[229, 257] -> 
             RGBColor[
              0.7238528030706062, 0.7835481049444202, 0.9737544480603806], 
             UndirectedEdge[90, 144] -> 
             RGBColor[
              0.3248022731286927, 0.4506268150272705, 0.9421046448171551], 
             UndirectedEdge[49, 115] -> 
             RGBColor[
              0.6802422098403156, 0.749782006637963, 0.9690015309750248], 
             UndirectedEdge[77, 244] -> 
             RGBColor[
              0.4981936046425942, 0.6003426121683367, 0.9545768728938765], 
             UndirectedEdge[66, 95] -> 
             RGBColor[
              0.4739397924929502, 0.582276053284001, 0.9521517927279967], 
             UndirectedEdge[94, 125] -> 
             RGBColor[
              0.3249122466798986, 0.4530103266271711, 0.9420278678985383], 
             UndirectedEdge[196, 230] -> 
             RGBColor[
              0.5451350600275006, 0.6416042256417421, 0.9573341753023379], 
             UndirectedEdge[138, 245] -> 
             RGBColor[
              0.5444598981090516, 0.6410560987806474, 0.9572810240829179], 
             UndirectedEdge[100, 127] -> 
             RGBColor[
              0.4235901482797315, 0.5368957475285498, 0.9490421596597158], 
             UndirectedEdge[24, 288] -> 
             RGBColor[
              0.5130600135814571, 0.6155642579724683, 0.9548091101513387], 
             UndirectedEdge[224, 258] -> 
             RGBColor[
              0.6005986946922865, 0.6866150736405412, 0.9617121187709279], 
             UndirectedEdge[25, 203] -> 
             RGBColor[
              0.5757476945521571, 0.6664569414323277, 0.959744114029894], 
             UndirectedEdge[143, 239] -> 
             RGBColor[
              0.6279957052205165, 0.707790667003092, 0.9645981069227201], 
             UndirectedEdge[142, 282] -> 
             RGBColor[
              0.8603007903819175, 0.8914022910003065, 0.9699716132673684], 
             UndirectedEdge[57, 242] -> 
             RGBColor[
              0.44207063275621084`, 0.5562729401324347, 0.9496789362395153], 
             UndirectedEdge[47, 177] -> 
             RGBColor[
              0.33393986158332284`, 0.46019848472282365`, 0.9426262074998681],
              UndirectedEdge[43, 174] -> 
             RGBColor[
              0.5258372766725488, 0.625855590041803, 0.9558375917959766], 
             UndirectedEdge[5, 29] -> 
             RGBColor[
              0.5811720490820724, 0.6708606768040997, 0.9601711390885543], 
             UndirectedEdge[167, 282] -> 
             RGBColor[
              0.7158759853228593, 0.7779670276840005, 0.972315486041694], 
             UndirectedEdge[131, 172] -> 
             RGBColor[
              0.8818866536720497, 0.9078575776579678, 0.9514826596152743], 
             UndirectedEdge[21, 101] -> 
             RGBColor[
              0.45209041794236965`, 0.5643694620875849, 0.950478227472022], 
             UndirectedEdge[251, 300] -> 
             RGBColor[
              0.39030194372923777`, 0.5124816593373467, 0.9460906726173377], 
             UndirectedEdge[75, 167] -> 
             RGBColor[
              0.5755974648433075, 0.665984319387407, 0.9599720347332488], 
             UndirectedEdge[165, 281] -> 
             RGBColor[
              0.38165422958847217`, 0.49487557728610154`, 0.9464667175245438],
              UndirectedEdge[63, 174] -> 
             RGBColor[
              0.625877302048591, 0.7070314751092229, 0.9637745551134782], 
             UndirectedEdge[64, 211] -> 
             RGBColor[
              0.34361937361570705`, 0.45855170072127105`, 0.9439681546153953],
              UndirectedEdge[124, 237] -> 
             RGBColor[
              0.5729453606366209, 0.6562752225678615, 0.9627835022895768], 
             UndirectedEdge[127, 192] -> 
             RGBColor[
              0.29506058771376065`, 0.42745776398190716`, 0.9401146360160518],
              UndirectedEdge[62, 228] -> 
             RGBColor[
              0.6099127063766596, 0.6726037962242392, 0.8095177255801498], 
             UndirectedEdge[152, 277] -> 
             RGBColor[
              0.45904527169879694`, 0.5694777070821284, 0.9511743951777177], 
             UndirectedEdge[76, 157] -> 
             RGBColor[
              0.34505815226411674`, 0.4732937611893379, 0.943207778232694], 
             UndirectedEdge[106, 297] -> 
             RGBColor[
              0.9416856710279484, 0.9559598742994223, 0.981169045113012], 
             UndirectedEdge[91, 203] -> 
             RGBColor[
              0.6109013529433895, 0.6949962649685935, 0.9625115387905455], 
             UndirectedEdge[215, 271] -> 
             RGBColor[
              0.43204281315428195`, 0.5469920507938557, 0.9492044545036049], 
             UndirectedEdge[181, 296] -> 
             RGBColor[
              0.5890636487498967, 0.6727191418581581, 0.9630464143060031], 
             UndirectedEdge[27, 119] -> 
             RGBColor[
              0.39660796623046296`, 0.5179436190780013, 0.9464924867949189], 
             UndirectedEdge[100, 170] -> 
             RGBColor[
              0.695694524588357, 0.7610031051848802, 0.971174982739546], 
             UndirectedEdge[112, 115] -> 
             RGBColor[
              0.6719641157463636, 0.7430614769286036, 0.9683498490842911], 
             UndirectedEdge[75, 282] -> 
             RGBColor[
              0.6262235889095674, 0.7055338322807629, 0.9650179736521458], 
             UndirectedEdge[234, 255] -> 
             RGBColor[
              0.481281443421423, 0.5868992119975889, 0.9530992057960574], 
             UndirectedEdge[29, 77] -> 
             RGBColor[
              0.44414766544932704`, 0.5566303280714175, 0.9502096105257241], 
             UndirectedEdge[44, 192] -> 
             RGBColor[
              0.563579677077281, 0.6487063111482322, 0.9619054912264344], 
             UndirectedEdge[49, 57] -> 
             RGBColor[
              0.5557928295411378, 0.650256683059958, 0.9581731939591476], 
             UndirectedEdge[4, 281] -> 
             RGBColor[
              0.41495681629848086`, 0.521912117441721, 0.9490884191417505], 
             UndirectedEdge[23, 285] -> 
             RGBColor[
              0.4420860012438484, 0.5569960300054531, 0.9494838016022675], 
             UndirectedEdge[86, 109] -> 
             RGBColor[
              0.538918599091118, 0.6355796120761142, 0.9571874697202347], 
             UndirectedEdge[276, 279] -> 
             RGBColor[
              0.36272039443880666`, 0.4885919076309507, 0.9443332006859577], 
             UndirectedEdge[139, 183] -> 
             RGBColor[
              0.3196380338997258, 0.44844206860662755`, 0.9416917997239889], 
             UndirectedEdge[234, 287] -> 
             RGBColor[
              0.6252987538318946, 0.7066847236054006, 0.9636449549279058], 
             UndirectedEdge[160, 181] -> 
             RGBColor[
              0.5767180734276525, 0.6620260250206877, 0.9622597651632332], 
             UndirectedEdge[196, 298] -> 
             RGBColor[
              0.4801779858299946, 0.5888691465253618, 0.9522205164759072], 
             UndirectedEdge[255, 287] -> 
             RGBColor[
              0.4917911608822321, 0.5954314740896499, 0.953926569252936], 
             UndirectedEdge[126, 216] -> 
             RGBColor[
              0.4939782904549621, 0.6000034513299161, 0.9533261035917228], 
             UndirectedEdge[190, 212] -> 
             RGBColor[
              0.5261757555032601, 0.622734378845007, 0.9571407478456768], 
             UndirectedEdge[39, 137] -> 
             RGBColor[
              0.6631224916437057, 0.7257947839583958, 0.757618280092354], 
             UndirectedEdge[170, 195] -> 
             RGBColor[
              0.7175877318768239, 0.7787769971394064, 0.9728984962147549], 
             UndirectedEdge[69, 288] -> 
             RGBColor[
              0.40286284926025995`, 0.5232799501761999, 0.9469135152931292], 
             UndirectedEdge[101, 231] -> 
             RGBColor[
              0.40634195945553747`, 0.5263747147648359, 0.9471127282357885], 
             UndirectedEdge[57, 253] -> 
             RGBColor[
              0.6507328439141316, 0.724772188671325, 0.967398240670104], 
             UndirectedEdge[52, 266] -> 
             RGBColor[
              0.5451744631033641, 0.6384403533607433, 0.9586686588959257], 
             UndirectedEdge[28, 275] -> 
             RGBColor[
              0.556685526220476, 0.6509814144397716, 0.9582434703118008], 
             UndirectedEdge[4, 226] -> 
             RGBColor[
              0.5579537196815944, 0.6520109910229719, 0.9583433071466056], 
             UndirectedEdge[104, 229] -> 
             RGBColor[
              0.5841485245060596, 0.6732771136419823, 0.9604054581371193], 
             UndirectedEdge[189, 293] -> 
             RGBColor[
              0.7823605173458257, 0.8300648168136883, 0.978899698575521], 
             UndirectedEdge[155, 156] -> 
             RGBColor[
              0.6251687939307107, 0.7027778263402852, 0.9658776835191019], 
             UndirectedEdge[107, 281] -> 
             RGBColor[
              0.42020151622621943`, 0.5261700011140984, 0.9495013011320309], 
             UndirectedEdge[107, 240] -> 
             RGBColor[
              0.7794941539795832, 0.8280667764916709, 0.9721062210872686], 
             UndirectedEdge[13, 105] -> 
             RGBColor[
              0.3999208196256838, 0.5204281931710542, 0.9468099149168876], 
             UndirectedEdge[96, 138] -> 
             RGBColor[
              0.4040072532237838, 0.5210264809321714, 0.9474978817731157], 
             UndirectedEdge[254, 260] -> 
             RGBColor[
              0.6197952791995545, 0.7007326533940524, 0.9642263895979624], 
             UndirectedEdge[120, 176] -> 
             RGBColor[
              0.48573757923762034`, 0.5913331278354397, 0.9532244839978861], 
             UndirectedEdge[59, 125] -> 
             RGBColor[
              0.409774160410473, 0.5293475147245652, 0.9473314250456608], 
             UndirectedEdge[22, 267] -> 
             RGBColor[
              0.5452437599641785, 0.6359999082404979, 0.9597313903958271], 
             UndirectedEdge[28, 197] -> 
             RGBColor[
              0.45608223467859527`, 0.5678223033012676, 0.950733872786685], 
             UndirectedEdge[245, 298] -> 
             RGBColor[
              0.5209849818221476, 0.6219981042060115, 0.9554329926813612], 
             UndirectedEdge[193, 199] -> 
             RGBColor[
              0.35434940275490534`, 0.47966657625189263`, 0.9438611310980534],
              UndirectedEdge[22, 274] -> 
             RGBColor[
              0.7815534897638916, 0.8292747933208564, 0.9788616058932016], 
             UndirectedEdge[76, 201] -> 
             RGBColor[
              0.6311097048290799, 0.7041723264483579, 0.9645382362668569], 
             UndirectedEdge[19, 158] -> 
             RGBColor[
              0.4024823082910094, 0.5218806078328753, 0.9471848390469316], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.6326635583269835, 0.7087883020204601, 0.9665767258090092], 
             UndirectedEdge[61, 267] -> 
             RGBColor[
              0.47307024743148685`, 0.5794086054289683, 0.9526805711617747], 
             UndirectedEdge[106, 283] -> 
             RGBColor[
              0.856603762816898, 0.8888179856326369, 0.9860995410910183], 
             UndirectedEdge[174, 283] -> 
             RGBColor[
              0.6907961069155248, 0.7577465388724627, 0.9702450548818903], 
             UndirectedEdge[19, 242] -> 
             RGBColor[
              0.4439657806088414, 0.557811506534638, 0.9498281292206296], 
             UndirectedEdge[125, 195] -> 
             RGBColor[
              0.4857854359570526, 0.5912062576386026, 0.9532740410574219], 
             UndirectedEdge[115, 159] -> 
             RGBColor[
              0.6424385474369434, 0.7190912904633218, 0.9660254881912531], 
             UndirectedEdge[158, 177] -> 
             RGBColor[
              0.3529330419014869, 0.48011459478976626`, 0.9437095592368958], 
             UndirectedEdge[42, 134] -> 
             RGBColor[
              0.5233021632055244, 0.6238792964408686, 0.9556154096879756], 
             UndirectedEdge[165, 179] -> 
             RGBColor[
              0.7386018610477058, 0.7950234508091072, 0.9730411214601495], 
             UndirectedEdge[108, 145] -> 
             RGBColor[
              0.44969214403882435`, 0.5529904081700597, 0.9516293315337877], 
             UndirectedEdge[44, 125] -> 
             RGBColor[
              0.5999483338153753, 0.6811086516533464, 0.9641898564909996], 
             UndirectedEdge[39, 141] -> 
             RGBColor[
              0.6674105767056413, 0.7295089077136225, 0.7578915130806958], 
             UndirectedEdge[50, 87] -> 
             RGBColor[
              0.6806676434432128, 0.3874114776028309, 0.5607320506912358], 
             UndirectedEdge[26, 226] -> 
             RGBColor[
              0.43476608009802886`, 0.5494430466844816, 0.9493524927714074], 
             UndirectedEdge[9, 143] -> 
             RGBColor[
              0.41854826668997525`, 0.5331699026973783, 0.9486118028975127], 
             UndirectedEdge[136, 299] -> 
             RGBColor[
              0.6229859961330118, 0.6973591827953567, 0.9672781406281705], 
             UndirectedEdge[134, 144] -> 
             RGBColor[
              0.4428091360310409, 0.5569821954824985, 0.9497067620703609], 
             UndirectedEdge[240, 281] -> 
             RGBColor[
              0.583746805216541, 0.6551427149705104, 0.9586986247908571], 
             UndirectedEdge[257, 261] -> 
             RGBColor[
              0.6174568527823044, 0.6945293199880953, 0.966108495113932], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.6225212751472242, 0.702733096734753, 0.9645863751475181], 
             UndirectedEdge[135, 254] -> 
             RGBColor[
              0.5508600768085318, 0.6462520521736501, 0.9577848695947682], 
             UndirectedEdge[14, 224] -> 
             RGBColor[
              0.4932639104985697, 0.5964820201367839, 0.9540895383790482], 
             UndirectedEdge[96, 289] -> 
             RGBColor[
              0.32333912962143374`, 0.4528752779671654, 0.9418826852530342], 
             UndirectedEdge[92, 189] -> 
             RGBColor[
              0.6819902801407756, 0.7514435802624599, 0.9689734074709997], 
             UndirectedEdge[107, 127] -> 
             RGBColor[
              0.4535380145261313, 0.5612087744833769, 0.9513997653932811], 
             UndirectedEdge[172, 270] -> 
             RGBColor[
              0.5911525202324699, 0.6751875354747441, 0.9629005453191049], 
             UndirectedEdge[48, 84] -> 
             RGBColor[
              0.5444782832084554, 0.6361843353423295, 0.9593239361772548], 
             UndirectedEdge[149, 289] -> 
             RGBColor[
              0.5320066103344236, 0.6272684416313867, 0.9577308203413106], 
             UndirectedEdge[1, 102] -> 
             RGBColor[
              0.4518659148202845, 0.5655126217550126, 0.9500943358776197], 
             UndirectedEdge[33, 297] -> 
             RGBColor[
              0.8437732257307984, 0.8785565792715722, 0.9716524222450456], 
             UndirectedEdge[18, 135] -> 
             RGBColor[
              0.6559932353175874, 0.7305582710685331, 0.9667762298923342], 
             UndirectedEdge[60, 137] -> 
             RGBColor[
              0.4338513369212772, 0.547975531113319, 0.9494807689583051], 
             UndirectedEdge[156, 208] -> 
             RGBColor[
              0.6378965027058425, 0.713801927968061, 0.9666886818675823], 
             UndirectedEdge[104, 279] -> 
             RGBColor[
              0.4543159485378098, 0.5639587014807439, 0.951266144126539], 
             UndirectedEdge[74, 158] -> 
             RGBColor[
              0.36660438362675785`, 0.49195602385058135`, 0.9445806850425372],
              UndirectedEdge[80, 277] -> 
             RGBColor[
              0.5805191231294102, 0.6658334939405666, 0.9622839115612954], 
             UndirectedEdge[223, 291] -> 
             RGBColor[
              0.3123991040774018, 0.44377273444041676`, 0.9411719334031281], 
             UndirectedEdge[114, 264] -> 
             RGBColor[
              0.7541268116796807, 0.8078488639509971, 0.9761279709386463], 
             UndirectedEdge[1, 237] -> 
             RGBColor[
              0.6550984823721656, 0.7279675142381907, 0.9680687693559037], 
             UndirectedEdge[84, 292] -> 
             RGBColor[
              0.5304760965220208, 0.6239716925695947, 0.9584348287635795], 
             UndirectedEdge[103, 152] -> 
             RGBColor[
              0.4315721116260117, 0.5456818366682568, 0.9494238297114415], 
             UndirectedEdge[10, 269] -> 
             RGBColor[
              0.442966694474965, 0.5564953987748915, 0.9498890117837622], 
             UndirectedEdge[109, 138] -> 
             RGBColor[
              0.5853107749168096, 0.6740427118362053, 0.9606186331570181], 
             UndirectedEdge[165, 240] -> 
             RGBColor[
              0.740946867341836, 0.7967723526636741, 0.9690716374797816], 
             UndirectedEdge[249, 254] -> 
             RGBColor[
              0.5248425066794906, 0.625129816664717, 0.9557366711687103], 
             UndirectedEdge[2, 155] -> 
             RGBColor[
              0.39745147613297144`, 0.5186742249595138, 0.9465462345000203], 
             UndirectedEdge[117, 161] -> 
             RGBColor[
              0.5114412683142167, 0.6127608994909848, 0.9550931437170971], 
             UndirectedEdge[169, 264] -> 
             RGBColor[
              0.7909752403011976, 0.836635136448556, 0.9798006779354955], 
             UndirectedEdge[3, 229] -> 
             RGBColor[
              0.5907833537989777, 0.6786635669576268, 0.9609277762032383], 
             UndirectedEdge[55, 90] -> 
             RGBColor[
              0.2967045277823782, 0.42628996024203647`, 0.9403142813295485], 
             UndirectedEdge[3, 259] -> 
             RGBColor[
              0.5922005510180585, 0.6798141115040837, 0.9610393431596889], 
             UndirectedEdge[113, 254] -> 
             RGBColor[
              0.39190191742368785`, 0.5102520109639875, 0.946631090206289], 
             UndirectedEdge[6, 205] -> 
             RGBColor[
              0.6457968102896461, 0.7208501192752368, 0.9669513891787824], 
             UndirectedEdge[120, 287] -> 
             RGBColor[0.5068216131301, 0.6084500963742574, 0.954884296379263],
              UndirectedEdge[31, 67] -> 
             RGBColor[
              0.3758544690804633, 0.4853548613402977, 0.9464481763344201], 
             UndirectedEdge[141, 232] -> 
             RGBColor[
              0.3123272807825688, 0.44262743748283623`, 0.9412070140153996], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.44273764171568963`, 0.5578988254384001, 0.9494318289259672], 
             UndirectedEdge[71, 122] -> 
             RGBColor[
              0.3574590829462019, 0.48403482405726106`, 0.9439979545700441], 
             UndirectedEdge[78, 120] -> 
             RGBColor[
              0.6125473380690725, 0.6913646431036858, 0.9652949380422502], 
             UndirectedEdge[177, 247] -> 
             RGBColor[
              0.6380601535706412, 0.7123536081234056, 0.9674311042750979], 
             UndirectedEdge[168, 182] -> 
             RGBColor[
              0.4457188826999683, 0.5505885890580104, 0.9511731025498219], 
             UndirectedEdge[26, 228] -> 
             RGBColor[
              0.29202024123966047`, 0.41960805783714805`, 0.9401119025198198],
              UndirectedEdge[7, 194] -> 
             RGBColor[
              0.6325198010690278, 0.7116487645410139, 0.9648276156979765], 
             UndirectedEdge[206, 244] -> 
             RGBColor[
              0.5953243524676388, 0.6821855101645149, 0.9613978283107216], 
             UndirectedEdge[31, 109] -> 
             RGBColor[
              0.41909906920422313`, 0.5202848068197925, 0.9499742280764535], 
             UndirectedEdge[57, 235] -> 
             RGBColor[
              0.463484067544856, 0.5748201810758327, 0.9510433813690908], 
             UndirectedEdge[24, 135] -> 
             RGBColor[
              0.5855883413049441, 0.6744460217823245, 0.9605188057897502], 
             UndirectedEdge[130, 220] -> 
             RGBColor[
              0.5263143110799037, 0.6263246937810051, 0.955852537002508], 
             UndirectedEdge[84, 112] -> 
             RGBColor[
              0.6781152420892099, 0.7478667835779269, 0.9689629358726022], 
             UndirectedEdge[76, 104] -> 
             RGBColor[
              0.46109946786225064`, 0.5698342449699797, 0.9516983839794617], 
             UndirectedEdge[21, 87] -> 
             RGBColor[
              0.5286879033927632, 0.6282516829496996, 0.9560393948841315], 
             UndirectedEdge[43, 183] -> 
             RGBColor[
              0.40574366047363375`, 0.5258564982580921, 0.9470746051537166], 
             UndirectedEdge[11, 131] -> 
             RGBColor[
              0.7659731296286858, 0.8159640024438337, 0.9408463655126009], 
             UndirectedEdge[21, 187] -> 
             RGBColor[
              0.615560024880959, 0.697623329447711, 0.9636680041075792], 
             UndirectedEdge[36, 66] -> 
             RGBColor[
              0.5570096523654571, 0.6512445546459839, 0.9582689867092469], 
             UndirectedEdge[124, 125] -> 
             RGBColor[
              0.33576067100394336`, 0.4644127084215715, 0.9426456696149871], 
             UndirectedEdge[232, 296] -> 
             RGBColor[
              0.32982817912235973`, 0.45778583600403644`, 0.9423221557821744],
              UndirectedEdge[75, 239] -> 
             RGBColor[
              0.599519313932471, 0.6846722497086484, 0.9623563410880669], 
             UndirectedEdge[108, 114] -> 
             RGBColor[
              0.6961161225757271, 0.7625304727254218, 0.9703460075894759], 
             UndirectedEdge[137, 266] -> 
             RGBColor[
              0.3542677353210406, 0.4812706391461419, 0.9437946047213667], 
             UndirectedEdge[74, 262] -> 
             RGBColor[
              0.4621526184104141, 0.5734380727628305, 0.9510217811738853], 
             UndirectedEdge[48, 90] -> 
             RGBColor[
              0.29458923922905855`, 0.424457803614645, 0.9401794970134072], 
             UndirectedEdge[125, 150] -> 
             RGBColor[
              0.40370714981451306`, 0.5240925750831638, 0.9469448404953331], 
             UndirectedEdge[38, 55] -> 
             RGBColor[
              0.5808544894740728, 0.6647947953472853, 0.9628699689032498], 
             UndirectedEdge[110, 165] -> 
             RGBColor[
              0.6552289495549676, 0.7290035422862746, 0.9673548124095963], 
             UndirectedEdge[114, 145] -> 
             RGBColor[
              0.4959102916454551, 0.5890963763512915, 0.9562359245540708], 
             UndirectedEdge[222, 290] -> 
             RGBColor[
              0.6750731840524578, 0.7460915692187876, 0.9682486441349174], 
             UndirectedEdge[267, 286] -> 
             RGBColor[
              0.32873882211883954`, 0.45915877765088126`, 0.9421679249464541],
              UndirectedEdge[6, 187] -> 
             RGBColor[
              0.7608709960789426, 0.8131174720614003, 0.9768001682115783], 
             UndirectedEdge[221, 231] -> 
             RGBColor[
              0.5108510749994162, 0.6129168543414483, 0.9548712014125269], 
             UndirectedEdge[106, 286] -> 
             RGBColor[
              0.6365254026076208, 0.7091852703332958, 0.9681799102959385], 
             UndirectedEdge[67, 154] -> 
             RGBColor[
              0.5050055801873845, 0.6087322132304969, 0.9542560180819483], 
             UndirectedEdge[85, 296] -> 
             RGBColor[
              0.36527746679420503`, 0.49080671518300323`, 0.9444961350753135],
              UndirectedEdge[41, 201] -> 
             RGBColor[
              0.6893232183788642, 0.7545939459889158, 0.9682475498740604], 
             UndirectedEdge[42, 235] -> 
             RGBColor[
              0.4961471366802048, 0.6013375320544048, 0.95361473782019], 
             UndirectedEdge[44, 60] -> 
             RGBColor[
              0.6817404099882227, 0.7497264132941596, 0.9700167427748274], 
             UndirectedEdge[199, 228] -> 
             RGBColor[
              0.32151174599799287`, 0.4451521169726871, 0.941991075124707], 
             UndirectedEdge[39, 62] -> 
             RGBColor[
              0.9943634514359565, 0.9903523175010167, 0.6278746574285063], 
             UndirectedEdge[48, 144] -> 
             RGBColor[
              0.3660478185272966, 0.49147395513520326`, 0.9445452212065508], 
             UndirectedEdge[68, 215] -> 
             RGBColor[
              0.4508771626091116, 0.5633054176497007, 0.9504045625963053], 
             UndirectedEdge[127, 240] -> 
             RGBColor[
              0.6170833035164529, 0.690181488339789, 0.9605970890521074], 
             UndirectedEdge[4, 26] -> 
             RGBColor[
              0.4822718255502191, 0.5880103509520138, 0.9530923190726833], 
             UndirectedEdge[8, 47] -> 
             RGBColor[
              0.43555336940431266`, 0.5442325944273455, 0.9502001751129896], 
             UndirectedEdge[112, 175] -> 
             RGBColor[
              0.6042118472979573, 0.6895654229268366, 0.9619849164016705], 
             UndirectedEdge[162, 203] -> 
             RGBColor[
              0.5323136931393333, 0.630480044147292, 0.9565224472705431], 
             UndirectedEdge[6, 50] -> 
             RGBColor[
              0.8106502311475341, 0.49046134796055796`, 0.5726575082968948], 
             UndirectedEdge[15, 294] -> 
             RGBColor[
              0.466131500367261, 0.577172483975182, 0.9511957081180618], 
             UndirectedEdge[6, 219] -> 
             RGBColor[
              0.8692212443296456, 0.8986867846739234, 0.9873539687816286], 
             UndirectedEdge[110, 281] -> 
             RGBColor[
              0.49802888742967255`, 0.5873739045931108, 0.9569817997206718], 
             UndirectedEdge[167, 297] -> 
             RGBColor[
              0.8078178799157782, 0.8504679898501292, 0.9680687293960146], 
             UndirectedEdge[122, 246] -> 
             RGBColor[
              0.4662817410865764, 0.5747093370858867, 0.951921811720212], 
             UndirectedEdge[210, 277] -> 
             RGBColor[
              0.49418048080775206`, 0.5980020526599108, 0.9539403675432864], 
             UndirectedEdge[225, 234] -> 
             RGBColor[
              0.5559591489986571, 0.6503917086881783, 0.9581862872360918], 
             UndirectedEdge[84, 280] -> 
             RGBColor[
              0.598957851283842, 0.6833717989865206, 0.9627953260806279], 
             UndirectedEdge[67, 95] -> 
             RGBColor[
              0.48225332766671136`, 0.589025355658552, 0.9528062646703579], 
             UndirectedEdge[81, 285] -> 
             RGBColor[
              0.47089149833630883`, 0.5803816302179682, 0.9517514758513985], 
             UndirectedEdge[79, 164] -> 
             RGBColor[
              0.6985692399073875, 0.7644468666292972, 0.9705905113994111], 
             UndirectedEdge[123, 157] -> 
             RGBColor[
              0.34593228378165247`, 0.47405088997469985`, 0.9432634771200272],
              UndirectedEdge[85, 165] -> 
             RGBColor[
              0.44672203092128693`, 0.5590273922449771, 0.9503274273540109], 
             UndirectedEdge[59, 62] -> 
             RGBColor[
              0.7213430561104444, 0.776866095097144, 0.8163343158531764], 
             UndirectedEdge[38, 48] -> 
             RGBColor[
              0.5787392009207531, 0.6629626387198938, 0.9627351845871086], 
             UndirectedEdge[262, 291] -> 
             RGBColor[
              0.41487125865280405`, 0.5324853353710279, 0.9480090547393952], 
             UndirectedEdge[26, 170] -> 
             RGBColor[
              0.5972100513234527, 0.6784903041288396, 0.9641288921076328], 
             UndirectedEdge[43, 139] -> 
             RGBColor[
              0.3641987950929961, 0.48703836026325886`, 0.9445311720236902], 
             UndirectedEdge[52, 281] -> 
             RGBColor[
              0.46932740984198723`, 0.5649520921623022, 0.9541211046652889], 
             UndirectedEdge[124, 142] -> 
             RGBColor[
              0.6269447442709468, 0.6988583678119258, 0.9514828858005029], 
             UndirectedEdge[166, 271] -> 
             RGBColor[
              0.4488554527888181, 0.5606413090499563, 0.9505280070823638], 
             UndirectedEdge[37, 150] -> 
             RGBColor[
              0.47335800296558117`, 0.5828535449190322, 0.9518159252281211], 
             UndirectedEdge[51, 66] -> 
             RGBColor[
              0.6898440374949417, 0.7563005110124061, 0.9706602057003476], 
             UndirectedEdge[60, 125] -> 
             RGBColor[
              0.4535234010135567, 0.5650144842833611, 0.9507342554869419], 
             UndirectedEdge[215, 223] -> 
             RGBColor[
              0.4046253881637031, 0.5220110546057855, 0.9475026012691115], 
             UndirectedEdge[237, 282] -> 
             RGBColor[
              0.8063014067475918, 0.8488191457562422, 0.9812722297564422], 
             UndirectedEdge[143, 172] -> 
             RGBColor[
              0.664770379430768, 0.7365193219940163, 0.9682634627691286], 
             UndirectedEdge[177, 285] -> 
             RGBColor[
              0.4075021805736869, 0.527379639982968, 0.9471866564994937], 
             UndirectedEdge[244, 270] -> 
             RGBColor[
              0.5243845150590156, 0.6230278623776075, 0.9562457345458981], 
             UndirectedEdge[147, 272] -> 
             RGBColor[
              0.6193398548163561, 0.689703165998227, 0.9443896729709503], 
             UndirectedEdge[46, 114] -> 
             RGBColor[
              0.6509367572331151, 0.7259673161144121, 0.966710363030512], 
             UndirectedEdge[104, 128] -> 
             RGBColor[
              0.6462925725707694, 0.7229511023494022, 0.9658291430458714], 
             UndirectedEdge[199, 220] -> 
             RGBColor[
              0.4815411073026523, 0.589018647955733, 0.9525922875748956], 
             UndirectedEdge[112, 146] -> 
             RGBColor[
              0.6874032752920052, 0.7551226657076173, 0.9698886802206517], 
             UndirectedEdge[191, 203] -> 
             RGBColor[
              0.533710591956615, 0.6316899676926455, 0.9566114564279513], 
             UndirectedEdge[31, 96] -> 
             RGBColor[
              0.23779554751119736`, 0.36726857591575857`, 0.936853476692551], 
             UndirectedEdge[59, 228] -> 
             RGBColor[
              0.3363866462464521, 0.45803600793367755`, 0.942938890615181], 
             UndirectedEdge[129, 289] -> 
             RGBColor[
              0.46038817224202655`, 0.5701416981666435, 0.9513978835247553], 
             UndirectedEdge[54, 106] -> 
             RGBColor[
              0.7080893211524399, 0.7703591579784376, 0.9729640318223356], 
             UndirectedEdge[102, 142] -> 
             RGBColor[
              0.6968675201885091, 0.7602500036960143, 0.9559079845849356], 
             UndirectedEdge[74, 90] -> 
             RGBColor[
              0.3386494543562064, 0.4626205474269779, 0.9429869749603906], 
             UndirectedEdge[143, 174] -> 
             RGBColor[
              0.5721339913421499, 0.6635231743709695, 0.9594596300757713], 
             UndirectedEdge[144, 292] -> 
             RGBColor[
              0.3520456318408619, 0.47926131236246844`, 0.9436561137928756], 
             UndirectedEdge[59, 255] -> 
             RGBColor[
              0.39779542322599865`, 0.5189721346442103, 0.9465681505046475], 
             UndirectedEdge[254, 258] -> 
             RGBColor[
              0.5290383751084702, 0.6285362116770814, 0.9560669853014121], 
             UndirectedEdge[46, 108] -> 
             RGBColor[
              0.6047186096264844, 0.6898613479331803, 0.9621037700102288], 
             UndirectedEdge[222, 278] -> 
             RGBColor[
              0.5561780734586848, 0.650502457573799, 0.9582493189979777], 
             UndirectedEdge[115, 294] -> 
             RGBColor[
              0.6152794574946836, 0.6970423177451364, 0.963887425143974], 
             UndirectedEdge[89, 177] -> 
             RGBColor[
              0.4969224375842188, 0.6009233603693149, 0.9539641210000382], 
             UndirectedEdge[45, 195] -> 
             RGBColor[
              0.490451373055397, 0.595247657836371, 0.9535713504434022], 
             UndirectedEdge[205, 231] -> 
             RGBColor[
              0.4547373806048302, 0.5673612293387986, 0.9504537258385497], 
             UndirectedEdge[148, 244] -> 
             RGBColor[
              0.5621287510160875, 0.6552358254613422, 0.9587845489649607], 
             UndirectedEdge[20, 297] -> 
             RGBColor[
              0.6432743161305028, 0.7140537308116832, 0.9557544408480207], 
             UndirectedEdge[6, 34] -> 
             RGBColor[
              0.7771608137697279, 0.8258432014486417, 0.9784237850019945], 
             UndirectedEdge[13, 245] -> 
             RGBColor[
              0.5198834164859594, 0.6211038038411412, 0.9553462734229297], 
             UndirectedEdge[104, 201] -> 
             RGBColor[
              0.7694913567135422, 0.8200628866622671, 0.9744523484870058], 
             UndirectedEdge[55, 253] -> 
             RGBColor[
              0.5748051405286824, 0.6600555839062929, 0.9622705860159819], 
             UndirectedEdge[52, 141] -> 
             RGBColor[
              0.5275820095004093, 0.6232026542722919, 0.9575476833087413], 
             UndirectedEdge[160, 299] -> 
             RGBColor[
              0.6435331961988877, 0.7151561347601152, 0.9685873900471926], 
             UndirectedEdge[229, 284] -> 
             RGBColor[
              0.45942701775971057`, 0.5692182845678491, 0.951361758285979], 
             UndirectedEdge[27, 268] -> 
             RGBColor[
              0.7169336861792797, 0.774965118042515, 0.8993565508060685], 
             UndirectedEdge[193, 236] -> 
             RGBColor[
              0.4001159391490532, 0.5177790542446857, 0.9471995793079653], 
             UndirectedEdge[78, 193] -> 
             RGBColor[
              0.5689457655985706, 0.6519243533877512, 0.962578006999803], 
             UndirectedEdge[175, 177] -> 
             RGBColor[
              0.5009637618190796, 0.6042042894427571, 0.954282268847665], 
             UndirectedEdge[36, 67] -> 
             RGBColor[
              0.5653231875392183, 0.6579938570205348, 0.958923458651608], 
             UndirectedEdge[37, 239] -> 
             RGBColor[
              0.6120632952888859, 0.6948560188737063, 0.9633438492505615], 
             UndirectedEdge[49, 280] -> 
             RGBColor[
              0.5322294056777556, 0.6308953853117255, 0.9563821448922574], 
             UndirectedEdge[263, 276] -> 
             RGBColor[
              0.40578636644112454`, 0.5258934880206683, 0.9470773263402017], 
             UndirectedEdge[13, 73] -> 
             RGBColor[
              0.4870632577245851, 0.5944589204273545, 0.9527625503010314], 
             UndirectedEdge[136, 240] -> 
             RGBColor[
              0.6266095278266337, 0.7000616067994716, 0.9611444466392924], 
             UndirectedEdge[79, 241] -> 
             RGBColor[
              0.5358264794728913, 0.6312924394582968, 0.9576714197244952], 
             UndirectedEdge[78, 226] -> 
             RGBColor[
              0.6788539477000264, 0.7472448829558792, 0.9699485412780442], 
             UndirectedEdge[3, 74] -> 
             RGBColor[
              0.5183529966072538, 0.6190640715812107, 0.9554460808143092], 
             UndirectedEdge[148, 203] -> 
             RGBColor[
              0.554400465044314, 0.6491262988361306, 0.9580635819255583], 
             UndirectedEdge[90, 257] -> 
             RGBColor[
              0.5661166853531305, 0.6449387256477385, 0.9630246983350723], 
             UndirectedEdge[34, 87] -> 
             RGBColor[
              0.6471782260654066, 0.7227933310909145, 0.9664983273963353], 
             UndirectedEdge[146, 235] -> 
             RGBColor[
              0.6033726073896754, 0.6864066934328514, 0.9634105495213287], 
             UndirectedEdge[181, 256] -> 
             RGBColor[
              0.6294217438074058, 0.7075839724051141, 0.9656432292348485], 
             UndirectedEdge[68, 287] -> 
             RGBColor[
              0.5118588664857933, 0.6128131120512437, 0.9552052657088195], 
             UndirectedEdge[17, 144] -> 
             RGBColor[
              0.39424067471707613`, 0.5158931901526367, 0.9463416450729997], 
             UndirectedEdge[163, 216] -> 
             RGBColor[
              0.5003210694063156, 0.6052222092081934, 0.9538062538015817], 
             UndirectedEdge[67, 258] -> 
             RGBColor[
              0.5626071369020645, 0.6557888447566065, 0.9587096411962299], 
             UndirectedEdge[232, 240] -> 
             RGBColor[
              0.6133653188775106, 0.686273650750419, 0.960385355327185], 
             UndirectedEdge[133, 210] -> 
             RGBColor[
              0.4542408107612441, 0.5617793361276512, 0.9514550920873366], 
             UndirectedEdge[58, 154] -> 
             RGBColor[
              0.4752674166227959, 0.5845894323597622, 0.9519149209116614], 
             UndirectedEdge[94, 124] -> 
             RGBColor[
              0.2889415928431328, 0.4210263124061947, 0.9397661683104113], 
             UndirectedEdge[50, 213] -> 
             RGBColor[
              0.562622898405944, 0.28755398275440613`, 0.5525326737951698], 
             UndirectedEdge[15, 212] -> 
             RGBColor[
              0.39916384655472475`, 0.5201573941525965, 0.9466553452291047], 
             UndirectedEdge[11, 139] -> 
             RGBColor[
              0.41645451414389495`, 0.529543732799251, 0.9486223249569328], 
             UndirectedEdge[167, 286] -> 
             RGBColor[
              0.5026576114954506, 0.6036933858840027, 0.9550795945789413], 
             UndirectedEdge[113, 288] -> 
             RGBColor[
              0.36988364456986256`, 0.4923765851493638, 0.9448977311116449], 
             UndirectedEdge[73, 171] -> 
             RGBColor[
              0.5918074079173961, 0.6789645884966097, 0.9613709978672556], 
             UndirectedEdge[31, 110] -> 
             RGBColor[
              0.477912500015518, 0.5662303059682057, 0.9558362012169639], 
             UndirectedEdge[202, 275] -> 
             RGBColor[
              0.4677546464990283, 0.5755888940638906, 0.9521251350971576], 
             UndirectedEdge[103, 241] -> 
             RGBColor[
              0.3479266690751906, 0.475778326275243, 0.9433905575873658], 
             UndirectedEdge[9, 20] -> 
             RGBColor[
              0.31518070802994635`, 0.4460704217677265, 0.9413532609044137], 
             UndirectedEdge[71, 207] -> 
             RGBColor[
              0.4146595045732696, 0.53335091512182, 0.9477057227584469], 
             UndirectedEdge[160, 168] -> 
             RGBColor[
              0.49365156363574647`, 0.5970368704689855, 0.9540467677967026], 
             UndirectedEdge[6, 114] -> 
             RGBColor[
              0.7731578662387129, 0.8227160684138848, 0.9780248086017744], 
             UndirectedEdge[95, 96] -> 
             RGBColor[
              0.3441944060974454, 0.47093907023401277`, 0.9432115650284887], 
             UndirectedEdge[198, 278] -> 
             RGBColor[
              0.39196517303905043`, 0.5135881154912662, 0.946288978614567], 
             UndirectedEdge[86, 281] -> 
             RGBColor[
              0.3241573099359174, 0.4473971462243544, 0.9421613479756927], 
             UndirectedEdge[107, 165] -> 
             RGBColor[
              0.5774015783515145, 0.667799638807262, 0.9598743138209553], 
             UndirectedEdge[155, 184] -> 
             RGBColor[
              0.3558210248513805, 0.48130570858942623`, 0.9439415558932691], 
             UndirectedEdge[247, 285] -> 
             RGBColor[
              0.6489498027129118, 0.7217856748807603, 0.9681249830891048], 
             UndirectedEdge[34, 227] -> 
             RGBColor[
              0.7170419813947104, 0.7788779126772291, 0.9724317016332833], 
             UndirectedEdge[116, 152] -> 
             RGBColor[
              0.6547717595824669, 0.7287724512409117, 0.9672230497606901], 
             UndirectedEdge[146, 204] -> 
             RGBColor[
              0.6964725744935378, 0.7624855313666945, 0.970602648675734], 
             UndirectedEdge[36, 58] -> 
             RGBColor[
              0.5355850239746297, 0.6338510761498002, 0.9565823614813211], 
             UndirectedEdge[105, 129] -> 
             RGBColor[
              0.4489087930331117, 0.5601988368662567, 0.9506664276323797], 
             UndirectedEdge[87, 187] -> 
             RGBColor[
              0.6308884083746213, 0.7100676017036732, 0.9648747106059192], 
             UndirectedEdge[119, 168] -> 
             RGBColor[
              0.49167238940412766`, 0.5953226092257465, 0.9539206565647789], 
             UndirectedEdge[20, 37] -> 
             RGBColor[
              0.42359788241444696`, 0.539753829514019, 0.9486452543477497], 
             UndirectedEdge[150, 200] -> 
             RGBColor[
              0.3590396679191726, 0.48296764316187835`, 0.9441878694150744], 
             UndirectedEdge[1, 43] -> 
             RGBColor[
              0.45720034115258545`, 0.5701330337279884, 0.9504342408064659], 
             UndirectedEdge[187, 213] -> 
             RGBColor[
              0.5128436633373525, 0.6102101068552485, 0.9566753337098532], 
             UndirectedEdge[41, 222] -> 
             RGBColor[
              0.5429382606498706, 0.6393689466490492, 0.9573133633369628], 
             UndirectedEdge[196, 263] -> 
             RGBColor[
              0.44297186075364947`, 0.557087744190538, 0.9497269105637751], 
             UndirectedEdge[148, 172] -> 
             RGBColor[
              0.6288967561895419, 0.7073954985584787, 0.9654393597381674], 
             UndirectedEdge[96, 171] -> 
             RGBColor[
              0.48417492179350247`, 0.5855798540619204, 0.9541715786793514], 
             UndirectedEdge[178, 208] -> 
             RGBColor[
              0.5550673634850829, 0.6489877940179836, 0.9584615429325609], 
             UndirectedEdge[25, 270] -> 
             RGBColor[
              0.4547535980744255, 0.566662991214444, 0.9506515656363579], 
             UndirectedEdge[47, 217] -> 
             RGBColor[
              0.5822842067614697, 0.6601037793652926, 0.9642223496897089], 
             UndirectedEdge[33, 142] -> 
             RGBColor[
              0.8456300121306779, 0.8799413675283937, 0.9685093671975025], 
             UndirectedEdge[26, 62] -> 
             RGBColor[
              0.6769766511036526, 0.7384381450006146, 0.8135073277578151], 
             UndirectedEdge[48, 177] -> 
             RGBColor[
              0.3662236580295394, 0.4916262584740956, 0.944556425544145], 
             UndirectedEdge[238, 300] -> 
             RGBColor[
              0.5227499971118408, 0.6210612487322362, 0.9563747414888779], 
             UndirectedEdge[25, 139] -> 
             RGBColor[
              0.3959691160292143, 0.512912763753085, 0.9470096393768593], 
             UndirectedEdge[3, 30] -> 
             RGBColor[
              0.6337938409198325, 0.7133902724352579, 0.9644444065703999], 
             UndirectedEdge[95, 171] -> 
             RGBColor[
              0.5369996255034212, 0.6329405148075435, 0.9574786981509419], 
             UndirectedEdge[21, 50] -> 
             RGBColor[
              0.6653392599495505, 0.37496720534686867`, 0.5595253441928958], 
             UndirectedEdge[122, 232] -> 
             RGBColor[
              0.31550342956849664`, 0.44537845792332725`, 0.9414093954074808],
              UndirectedEdge[127, 136] -> 
             RGBColor[
              0.3006533883731818, 0.4332036047911776, 0.9404379909453049], 
             UndirectedEdge[41, 290] -> 
             RGBColor[
              0.5712797664799439, 0.6615095464069247, 0.9601381797716744], 
             UndirectedEdge[123, 259] -> 
             RGBColor[
              0.44805820135821367`, 0.5592942267598919, 0.9506586117607543], 
             UndirectedEdge[20, 185] -> 
             RGBColor[
              0.6200828731874379, 0.6959402383982398, 0.9666733892308639], 
             UndirectedEdge[163, 211] -> 
             RGBColor[
              0.3211872275004644, 0.4403402739482508, 0.9422022139015447], 
             UndirectedEdge[33, 37] -> 
             RGBColor[
              0.6240967920147426, 0.7042566779739079, 0.9645432357447745], 
             UndirectedEdge[7, 9] -> 
             RGBColor[
              0.49760016327048173`, 0.5964494630728284, 0.9554492512529646], 
             UndirectedEdge[105, 263] -> 
             RGBColor[
              0.3638162598855268, 0.48954109120110084`, 0.944403028263187], 
             UndirectedEdge[15, 49] -> 
             RGBColor[
              0.5310942527128929, 0.6299121728680085, 0.9563098139491126], 
             UndirectedEdge[20, 237] -> 
             RGBColor[
              0.5911317188960564, 0.6728553738244405, 0.9639120022895513], 
             UndirectedEdge[26, 220] -> 
             RGBColor[
              0.4520496025443199, 0.563474588820194, 0.9507131149700083], 
             UndirectedEdge[101, 187] -> 
             RGBColor[
              0.5542909229242279, 0.6461853808415585, 0.9593135431938098], 
             UndirectedEdge[93, 94] -> 
             RGBColor[
              0.4311227744204467, 0.5414520872893508, 0.9497770641375108], 
             UndirectedEdge[143, 297] -> 
             RGBColor[
              0.7466418747905317, 0.8011532117413351, 0.9630129828411197], 
             UndirectedEdge[208, 268] -> 
             RGBColor[
              0.7152453595491104, 0.7735027743732261, 0.8992489721261228], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.714290378611291, 0.7767283396698661, 0.9721574475830221], 
             UndirectedEdge[224, 288] -> 
             RGBColor[
              0.549892068668861, 0.6454491503272537, 0.9577203074258724], 
             UndirectedEdge[1, 75] -> 
             RGBColor[
              0.47502066453414127`, 0.5846822007627114, 0.9518145132516073], 
             UndirectedEdge[36, 113] -> 
             RGBColor[
              0.4233063212304418, 0.5357475207265795, 0.9491033599120783], 
             UndirectedEdge[29, 244] -> 
             RGBColor[
              0.5990609583152535, 0.6852190551237837, 0.961691987610684], 
             UndirectedEdge[36, 96] -> 
             RGBColor[
              0.4272642659699523, 0.5399075715959956, 0.9493287590097389], 
             UndirectedEdge[58, 138] -> 
             RGBColor[
              0.5123280112284612, 0.614969985485976, 0.954751484244698], 
             UndirectedEdge[71, 136] -> 
             RGBColor[
              0.33889105711194467`, 0.46795213333574154`, 0.9428148163829457],
              UndirectedEdge[144, 252] -> 
             RGBColor[
              0.42573542501853845`, 0.5431209877206331, 0.9483626569963924], 
             UndirectedEdge[58, 198] -> 
             RGBColor[
              0.4131585478899986, 0.5307938519459227, 0.9479573987167237], 
             UndirectedEdge[110, 154] -> 
             RGBColor[
              0.6070636111224392, 0.6896076578584048, 0.963644042964492], 
             UndirectedEdge[119, 152] -> 
             RGBColor[
              0.44719985179672717`, 0.5592177997310709, 0.9504196154960514], 
             UndirectedEdge[38, 90] -> 
             RGBColor[
              0.5374936555221492, 0.622115498611961, 0.9602946081977128], 
             UndirectedEdge[66, 179] -> 
             RGBColor[
              0.7446049527800903, 0.7998970311136575, 0.9735137068313724], 
             UndirectedEdge[6, 21] -> 
             RGBColor[
              0.6586704910970844, 0.7313015533074266, 0.9679648524897906], 
             UndirectedEdge[176, 287] -> 
             RGBColor[
              0.6147244374002241, 0.6981000171586439, 0.9628125060034074], 
             UndirectedEdge[142, 237] -> 
             RGBColor[
              0.9001000877403902, 0.9227048961791924, 0.9738824180632196], 
             UndirectedEdge[108, 221] -> 
             RGBColor[
              0.6248687610212461, 0.7062201485894236, 0.9636900637404612], 
             UndirectedEdge[44, 256] -> 
             RGBColor[
              0.6424233481823314, 0.7178070513066872, 0.9669215596463246], 
             UndirectedEdge[89, 112] -> 
             RGBColor[
              0.6001705230630964, 0.6862844938533944, 0.9616667685540439], 
             UndirectedEdge[83, 184] -> 
             RGBColor[
              0.3380896788839917, 0.4659477079158353, 0.9428117302074407], 
             UndirectedEdge[259, 261] -> 
             RGBColor[
              0.46383717619618503`, 0.5729611816902076, 0.9516640340846301], 
             UndirectedEdge[207, 231] -> 
             RGBColor[
              0.4417895552657245, 0.5568496014356283, 0.9494344255984084], 
             UndirectedEdge[112, 280] -> 
             RGBColor[
              0.5239513115838036, 0.6241748556023661, 0.9557304630015235], 
             UndirectedEdge[174, 194] -> 
             RGBColor[
              0.5827040448245648, 0.6721044199634768, 0.9602917434052887], 
             UndirectedEdge[125, 200] -> 
             RGBColor[
              0.3270638429453687, 0.45527179072126256`, 0.9421503981228554], 
             UndirectedEdge[99, 222] -> 
             RGBColor[
              0.5289566014777313, 0.6272587362127651, 0.9564224643780099], 
             UndirectedEdge[108, 169] -> 
             RGBColor[
              0.732964551197244, 0.7913167452229808, 0.974018714586325], 
             UndirectedEdge[15, 57] -> 
             RGBColor[
              0.4672221916769553, 0.5780579563154753, 0.9512815713332947], 
             UndirectedEdge[4, 78] -> 
             RGBColor[
              0.7263596931522167, 0.7858121872234114, 0.9736883675793202], 
             UndirectedEdge[52, 86] -> 
             RGBColor[
              0.5690305523147274, 0.6591032987937189, 0.9601887478053623], 
             UndirectedEdge[20, 282] -> 
             RGBColor[
              0.5513324215375839, 0.6415527686455547, 0.9600011974937002], 
             UndirectedEdge[42, 55] -> 
             RGBColor[
              0.44865613425509976`, 0.5602032127209648, 0.9505886531403069], 
             UndirectedEdge[136, 165] -> 
             RGBColor[
              0.424516952198565, 0.5397944691150628, 0.9489125393729791], 
             UndirectedEdge[161, 269] -> 
             RGBColor[
              0.3860469541187833, 0.5087962011987672, 0.9458195484418991], 
             UndirectedEdge[57, 243] -> 
             RGBColor[
              0.42345070090690073`, 0.5401452910295486, 0.9484924906470364], 
             UndirectedEdge[57, 146] -> 
             RGBColor[
              0.6318093083500196, 0.7099889788644436, 0.9655121194955676], 
             UndirectedEdge[4, 130] -> 
             RGBColor[
              0.5565365340858028, 0.6508604559128248, 0.958231741105183], 
             UndirectedEdge[31, 58] -> 
             RGBColor[
              0.34611630551587474`, 0.4612120804695631, 0.9441070791641333], 
             UndirectedEdge[95, 140] -> 
             RGBColor[
              0.33428008034656975`, 0.4605184852652834, 0.942646958843907], 
             UndirectedEdge[58, 96] -> 
             RGBColor[
              0.39969046039220407`, 0.517521914042194, 0.9471580480284807], 
             UndirectedEdge[16, 94] -> 
             RGBColor[
              0.4847566864275151, 0.5842429581589978, 0.9545131644695739], 
             UndirectedEdge[113, 135] -> 
             RGBColor[
              0.4424119722933496, 0.55125834895922, 0.9506074267500563], 
             UndirectedEdge[47, 262] -> 
             RGBColor[
              0.3858086068370497, 0.5038475551992257, 0.9462840851826252], 
             UndirectedEdge[153, 211] -> 
             RGBColor[
              0.22523402544288768`, 0.35406561977546536`, 0.9361381165938674],
              UndirectedEdge[89, 111] -> 
             RGBColor[
              0.5801955866446996, 0.670067940608309, 0.9600942683885846], 
             UndirectedEdge[137, 256] -> 
             RGBColor[
              0.39453427511538586`, 0.5160561691258466, 0.9463855858298024], 
             UndirectedEdge[136, 181] -> 
             RGBColor[
              0.5561708733617764, 0.6442290730559294, 0.9609505157442113], 
             UndirectedEdge[288, 291] -> 
             RGBColor[
              0.39285298579897876`, 0.5146099095564043, 0.9462756956447511], 
             UndirectedEdge[121, 296] -> 
             RGBColor[
              0.3707677766396693, 0.4955621456201479, 0.9448459727637761], 
             UndirectedEdge[241, 277] -> 
             RGBColor[
              0.37539982914797587`, 0.4995741966891146, 0.9451411230536422], 
             UndirectedEdge[217, 262] -> 
             RGBColor[
              0.69682562186329, 0.7615019383444844, 0.9717467975580847], 
             UndirectedEdge[75, 142] -> 
             RGBColor[
              0.7200222699023658, 0.7794195827037129, 0.9576281619589232], 
             UndirectedEdge[57, 112] -> 
             RGBColor[
              0.5475147354471859, 0.6435361533505985, 0.9575215120684137], 
             UndirectedEdge[274, 287] -> 
             RGBColor[
              0.7129201066977537, 0.7755575270912902, 0.972089478618678], 
             UndirectedEdge[97, 252] -> 
             RGBColor[
              0.38269480514675447`, 0.5058413660721489, 0.9456201467574881], 
             UndirectedEdge[18, 69] -> 
             RGBColor[
              0.5300142806231408, 0.6254615948857065, 0.9576382346853394], 
             UndirectedEdge[106, 167] -> 
             RGBColor[
              0.7991176523687696, 0.8439093992399378, 0.9803698628397943], 
             UndirectedEdge[256, 296] -> 
             RGBColor[
              0.4163232585171124, 0.5349286914022735, 0.9477739605849189], 
             UndirectedEdge[131, 183] -> 
             RGBColor[
              0.6691566493845167, 0.7348623382512103, 0.933915840279657], 
             UndirectedEdge[172, 183] -> 
             RGBColor[
              0.5739129035678965, 0.6602554460082184, 0.9618020521896327], 
             UndirectedEdge[1, 143] -> 
             RGBColor[
              0.5034970558221866, 0.6078006180571549, 0.9540562790862606], 
             UndirectedEdge[17, 252] -> 
             RGBColor[
              0.4237152473086838, 0.5413712113254411, 0.9482339330590935], 
             UndirectedEdge[126, 214] -> 
             RGBColor[
              0.7224008504105568, 0.7772545499542609, 0.7712953642834752], 
             UndirectedEdge[84, 134] -> 
             RGBColor[
              0.6212396007121996, 0.7016925756896247, 0.9644854770410648], 
             UndirectedEdge[45, 234] -> 
             RGBColor[
              0.4979261177042418, 0.6013159922757123, 0.9541597897230512], 
             UndirectedEdge[32, 156] -> 
             RGBColor[
              0.5764811720470167, 0.6606070553756582, 0.9627753513054464], 
             UndirectedEdge[140, 149] -> 
             RGBColor[
              0.4901228573496409, 0.5875509881838814, 0.9551879744605931], 
             UndirectedEdge[16, 150] -> 
             RGBColor[
              0.5635515895621296, 0.6553252066149904, 0.9594301370663687], 
             UndirectedEdge[209, 218] -> 
             RGBColor[
              0.5029784701791936, 0.6073169148001356, 0.9540327761305402], 
             UndirectedEdge[82, 281] -> 
             RGBColor[
              0.5794819515455523, 0.6519313262321842, 0.964854635869071], 
             UndirectedEdge[178, 182] -> 
             RGBColor[
              0.4615098815325068, 0.5630216031354343, 0.9526807057093172], 
             UndirectedEdge[41, 157] -> 
             RGBColor[
              0.40327166581390095`, 0.5237153807298958, 0.9469170918398975], 
             UndirectedEdge[254, 288] -> 
             RGBColor[
              0.4783317490850447, 0.5873702883637939, 0.9520751739563567], 
             UndirectedEdge[129, 161] -> 
             RGBColor[
              0.48197006576962753`, 0.5888348496027427, 0.952773062696215], 
             UndirectedEdge[20, 283] -> 
             RGBColor[
              0.5581924079194523, 0.6469118421448978, 0.9606849368260273], 
             UndirectedEdge[162, 210] -> 
             RGBColor[
              0.5221657590865902, 0.6222414941240559, 0.955723564728804], 
             UndirectedEdge[203, 244] -> 
             RGBColor[
              0.6453786115367471, 0.7228218125954913, 0.9653382829394341], 
             UndirectedEdge[121, 246] -> 
             RGBColor[
              0.4754091038205055, 0.5826149999314262, 0.952503399202608], 
             UndirectedEdge[24, 259] -> 
             RGBColor[
              0.5707284373176311, 0.6623820822943778, 0.959348979714247], 
             UndirectedEdge[141, 281] -> 
             RGBColor[
              0.2827087671215993, 0.4114965017029275, 0.9395202834790717], 
             UndirectedEdge[110, 138] -> 
             RGBColor[
              0.6441242057281045, 0.7199882109846185, 0.9664806062975286], 
             UndirectedEdge[67, 109] -> 
             RGBColor[
              0.6107321456498185, 0.6946809258169627, 0.96261989658267], 
             UndirectedEdge[154, 245] -> 
             RGBColor[
              0.5073993035033864, 0.6106755456544337, 0.9544444607498814], 
             UndirectedEdge[193, 249] -> 
             RGBColor[
              0.41998330072330176`, 0.5339082733851002, 0.9487636107876336], 
             UndirectedEdge[82, 137] -> 
             RGBColor[
              0.6334484661420388, 0.7064677645869473, 0.9680079815241817], 
             UndirectedEdge[100, 125] -> 
             RGBColor[
              0.4638922286685857, 0.5734323656840763, 0.9515505275822129], 
             UndirectedEdge[104, 218] -> 
             RGBColor[
              0.5772144804529667, 0.6676477443045568, 0.9598595847890196], 
             UndirectedEdge[73, 149] -> 
             RGBColor[
              0.6076696692244101, 0.6913563075873002, 0.9629519998330789], 
             UndirectedEdge[108, 219] -> 
             RGBColor[
              0.7921795006666598, 0.8385011889854604, 0.9796751677693301], 
             UndirectedEdge[58, 140] -> 
             RGBColor[
              0.38977613464132843`, 0.5071013290734647, 0.9465934418438988], 
             UndirectedEdge[9, 63] -> 
             RGBColor[
              0.47229157739641625`, 0.5766782034356317, 0.9529267279352196], 
             UndirectedEdge[48, 217] -> 
             RGBColor[
              0.6145680032076862, 0.6915315531165644, 0.9661525677339857], 
             UndirectedEdge[8, 271] -> 
             RGBColor[
              0.47504005492130963`, 0.5818991486639964, 0.9525893548795916], 
             UndirectedEdge[18, 222] -> 
             RGBColor[
              0.6786740085896827, 0.7489045607145479, 0.9686075406731696], 
             UndirectedEdge[215, 234] -> 
             RGBColor[
              0.564317049955213, 0.6571770292038577, 0.9588442518153918], 
             UndirectedEdge[15, 146] -> 
             RGBColor[
              0.6071107315217746, 0.6896444686724941, 0.9636487394855326], 
             UndirectedEdge[54, 151] -> 
             RGBColor[
              0.6578665370639681, 0.7303128732074475, 0.9681737378415686], 
             UndirectedEdge[195, 255] -> 
             RGBColor[
              0.4738066987725782, 0.5808308775582477, 0.9525107665164085], 
             UndirectedEdge[1, 11] -> 
             RGBColor[
              0.5094560602034843, 0.6126384062639806, 0.9545253937397086], 
             UndirectedEdge[32, 178] -> 
             RGBColor[
              0.4936520328262569, 0.5957929214255808, 0.954548212370425], 
             UndirectedEdge[126, 189] -> 
             RGBColor[
              0.5878784550244699, 0.6749699567570038, 0.9615837564384262], 
             UndirectedEdge[61, 273] -> 
             RGBColor[
              0.5301445860395203, 0.628843528891579, 0.9563172975490226], 
             UndirectedEdge[54, 194] -> 
             RGBColor[
              0.5236155783974381, 0.6241337410128576, 0.9556400828799608], 
             UndirectedEdge[38, 144] -> 
             RGBColor[
              0.6089522348203873, 0.6891316501325193, 0.9646603323908565], 
             UndirectedEdge[4, 220] -> 
             RGBColor[
              0.5752372421278855, 0.6660425331586843, 0.9597039293452065], 
             UndirectedEdge[45, 200] -> 
             RGBColor[
              0.3317297800437131, 0.4593131909190311, 0.9424477075088358], 
             UndirectedEdge[2, 202] -> 
             RGBColor[
              0.3567522504460784, 0.4834226012720886, 0.9439529158281637], 
             UndirectedEdge[17, 175] -> 
             RGBColor[
              0.4987677446069823, 0.6023022097086727, 0.9541423405727719], 
             UndirectedEdge[233, 262] -> 
             RGBColor[
              0.5466398317682577, 0.6428258671300833, 0.9574526364459308], 
             UndirectedEdge[67, 138] -> 
             RGBColor[
              0.5420661747930497, 0.6391127663567107, 0.9570925814149849], 
             UndirectedEdge[39, 192] -> 
             RGBColor[
              0.6464258989978908, 0.7104313966233237, 0.7565874013564257], 
             UndirectedEdge[164, 168] -> 
             RGBColor[
              0.6706538947326528, 0.7425422210409047, 0.967874466704984], 
             UndirectedEdge[19, 253] -> 
             RGBColor[
              0.6526279917667621, 0.7263107550735283, 0.9675474336512184], 
             UndirectedEdge[24, 74] -> 
             RGBColor[
              0.49688088290682647`, 0.6016320423715049, 0.9537557173688673], 
             UndirectedEdge[80, 133] -> 
             RGBColor[
              0.5405794530829022, 0.6296107774083068, 0.9597986361053457], 
             UndirectedEdge[198, 222] -> 
             RGBColor[
              0.48251877780275, 0.5870366273783794, 0.9534634873167952], 
             UndirectedEdge[111, 212] -> 
             RGBColor[
              0.45948145390655853`, 0.5694190379426345, 0.9513227857987645], 
             UndirectedEdge[126, 184] -> 
             RGBColor[
              0.37266787475126806`, 0.49589760322541254`, 0.9450150222718054],
              UndirectedEdge[132, 294] -> 
             RGBColor[
              0.5293539363783751, 0.6287923985318634, 0.9560918274405181], 
             UndirectedEdge[39, 136] -> 
             RGBColor[
              0.652018699657312, 0.7161772374325941, 0.7569107562856787], 
             UndirectedEdge[133, 162] -> 
             RGBColor[
              0.3590521123883469, 0.4837856443278996, 0.9441591059995872], 
             UndirectedEdge[22, 271] -> 
             RGBColor[
              0.5616579000971015, 0.6502170114249649, 0.9607772848906426], 
             UndirectedEdge[107, 110] -> 
             RGBColor[
              0.6937762361927149, 0.7602979661142714, 0.9703893960170833], 
             UndirectedEdge[40, 191] -> 
             RGBColor[
              0.4335346682375676, 0.5499276723665472, 0.9488454235938112], 
             UndirectedEdge[143, 237] -> 
             RGBColor[
              0.6944992775560854, 0.7599548547540922, 0.9711705442826503], 
             UndirectedEdge[157, 261] -> 
             RGBColor[
              0.36171125861962383`, 0.4877178449050156, 0.9442688994439032], 
             UndirectedEdge[35, 163] -> 
             RGBColor[
              0.5054092990725056, 0.6093530632733406, 0.9542068178797035], 
             UndirectedEdge[89, 175] -> 
             RGBColor[
              0.6012736679718822, 0.6871800765864586, 0.9617536121622163], 
             UndirectedEdge[16, 200] -> 
             RGBColor[
              0.4869082826929852, 0.5865044222530893, 0.954635694693891], 
             UndirectedEdge[35, 189] -> 
             RGBColor[
              0.6361830780474002, 0.7142552300121201, 0.9653672967248992], 
             UndirectedEdge[233, 291] -> 
             RGBColor[
              0.46116106848219174`, 0.5700654883226934, 0.9516531581343252], 
             UndirectedEdge[258, 290] -> 
             RGBColor[
              0.6305707090803008, 0.7100294390762041, 0.9646994490607261], 
             UndirectedEdge[157, 259] -> 
             RGBColor[
              0.4695244061270063, 0.5778871744077974, 0.9520264193468021], 
             UndirectedEdge[105, 245] -> 
             RGBColor[
              0.4523123952977868, 0.5629620345152546, 0.9509343716704608], 
             UndirectedEdge[100, 192] -> 
             RGBColor[
              0.4275235719304913, 0.5410300251789621, 0.9492661623176478], 
             UndirectedEdge[258, 278] -> 
             RGBColor[
              0.5116755984865278, 0.6144403274312155, 0.9547001239237864], 
             UndirectedEdge[99, 201] -> 
             RGBColor[
              0.6753415592067249, 0.7424837355526317, 0.9673566509151074], 
             UndirectedEdge[9, 282] -> 
             RGBColor[
              0.5303503958814816, 0.6220341936995283, 0.9587134883713047], 
             UndirectedEdge[84, 175] -> 
             RGBColor[
              0.6792183869979957, 0.748762366310991, 0.9690497794807748], 
             UndirectedEdge[271, 291] -> 
             RGBColor[
              0.3398165290679807, 0.4687537306284869, 0.9428737866376217], 
             UndirectedEdge[127, 256] -> 
             RGBColor[
              0.3739042588188111, 0.4965585041403622, 0.945130704435942], 
             UndirectedEdge[80, 116] -> 
             RGBColor[
              0.7762456110130802, 0.8251282380993499, 0.9783325661442678], 
             UndirectedEdge[202, 268] -> 
             RGBColor[
              0.6618184250870855, 0.7272270490580253, 0.8958446551057856], 
             UndirectedEdge[161, 265] -> 
             RGBColor[
              0.6932197240800266, 0.7544252759705332, 0.8978455181105374], 
             UndirectedEdge[22, 72] -> 
             RGBColor[
              0.7902659300790247, 0.8360810179120373, 0.9797299805214303], 
             UndirectedEdge[77, 162] -> 
             RGBColor[
              0.3851286862451803, 0.5080008437201375, 0.9457610372249855], 
             UndirectedEdge[93, 164] -> 
             RGBColor[
              0.6447155276653664, 0.7214842861455614, 0.965832503434078], 
             UndirectedEdge[19, 111] -> 
             RGBColor[
              0.5294349468814196, 0.6288581665077164, 0.9560982048840689], 
             UndirectedEdge[37, 142] -> 
             RGBColor[
              0.7325662512587807, 0.7896033518687708, 0.9586156701214179], 
             UndirectedEdge[43, 172] -> 
             RGBColor[
              0.6184736647611668, 0.6988517376648496, 0.9646414244893339], 
             UndirectedEdge[61, 285] -> 
             RGBColor[
              0.5235600210377769, 0.6231403096369288, 0.9558977348896138], 
             UndirectedEdge[38, 257] -> 
             RGBColor[
              0.850266647044825, 0.8834435607529872, 0.9855803859087736], 
             UndirectedEdge[174, 185] -> 
             RGBColor[
              0.7526865721835105, 0.8067749351258047, 0.976233507286727], 
             UndirectedEdge[75, 237] -> 
             RGBColor[
              0.66602288626804, 0.7368364374596487, 0.968928778447997], 
             UndirectedEdge[30, 48] -> 
             RGBColor[
              0.49533584406738906`, 0.5977938883889578, 0.9544258771058771], 
             UndirectedEdge[289, 298] -> 
             RGBColor[
              0.4125017641707868, 0.5312653548363114, 0.9476280900676948], 
             UndirectedEdge[123, 261] -> 
             RGBColor[
              0.34024505385083115`, 0.46912489725711015`, 0.9429010918578553],
              UndirectedEdge[77, 206] -> 
             RGBColor[
              0.4404110596017123, 0.5535967831121488, 0.9499154512257615], 
             UndirectedEdge[121, 137] -> 
             RGBColor[
              0.3489787932379428, 0.476689623343721, 0.9434575980086595], 
             UndirectedEdge[87, 227] -> 
             RGBColor[
              0.6138800422157294, 0.6967805367919764, 0.9631794756194194], 
             UndirectedEdge[123, 144] -> 
             RGBColor[
              0.3603634657198953, 0.4865504544373116, 0.944183019272139], 
             UndirectedEdge[9, 37] -> 
             RGBColor[
              0.40261585675834477`, 0.5202352545679926, 0.9473575452253541], 
             UndirectedEdge[178, 268] -> 
             RGBColor[
              0.8277891081854829, 0.8647771222676839, 0.9082923237354237], 
             UndirectedEdge[112, 253] -> 
             RGBColor[
              0.7063268108561173, 0.7699058755144987, 0.9717748013951881], 
             UndirectedEdge[78, 220] -> 
             RGBColor[
              0.6961374701463175, 0.7612764250915915, 0.9713091634766451], 
             UndirectedEdge[66, 67] -> 
             RGBColor[
              0.5591740103522975, 0.6530016779629171, 0.9584393728982754], 
             UndirectedEdge[20, 124] -> 
             RGBColor[
              0.31797637542661306`, 0.44900884545717396`, 0.9415124700268347],
              UndirectedEdge[18, 224] -> 
             RGBColor[
              0.6770435000317419, 0.7476307950367604, 0.9684450268180828], 
             UndirectedEdge[72, 151] -> 
             RGBColor[
              0.819998249018533, 0.8594096159073656, 0.9826664893521432], 
             UndirectedEdge[25, 29] -> 
             RGBColor[
              0.5294300413306634, 0.6288541839606201, 0.9560978187011439], 
             UndirectedEdge[135, 258] -> 
             RGBColor[
              0.5795484299781319, 0.6695425496723139, 0.9600433218451794], 
             UndirectedEdge[130, 176] -> 
             RGBColor[
              0.5506270032727827, 0.646062832577486, 0.9577665211922575], 
             UndirectedEdge[31, 245] -> 
             RGBColor[
              0.3782481923964652, 0.48729819376423456`, 0.9466366190023533], 
             UndirectedEdge[295, 297] -> 
             RGBColor[
              0.7589279401794599, 0.8111275931050053, 0.9639801869138765], 
             UndirectedEdge[17, 30] -> 
             RGBColor[
              0.5235287002571686, 0.6222131234063912, 0.9562223009723261], 
             UndirectedEdge[22, 273] -> 
             RGBColor[
              0.602318098572212, 0.6854348317031087, 0.963368116783075], 
             UndirectedEdge[86, 165] -> 
             RGBColor[
              0.48135737206121243`, 0.5890267839175181, 0.9525343606646173], 
             UndirectedEdge[124, 200] -> 
             RGBColor[
              0.2910931891086029, 0.42328777650028615`, 0.9398886985347283], 
             UndirectedEdge[198, 258] -> 
             RGBColor[
              0.4380163028305931, 0.5509744972357958, 0.9499142922426038], 
             UndirectedEdge[177, 217] -> 
             RGBColor[
              0.6449568766095631, 0.7178528678680822, 0.9680889198753276], 
             UndirectedEdge[52, 110] -> 
             RGBColor[
              0.7429021298084826, 0.7990800571624752, 0.9750091995503414], 
             UndirectedEdge[121, 299] -> 
             RGBColor[
              0.6506813847011979, 0.7213475363624158, 0.9690428662976649], 
             UndirectedEdge[173, 196] -> 
             RGBColor[
              0.5154362263680698, 0.6174933745598067, 0.9549961743262552], 
             UndirectedEdge[238, 251] -> 
             RGBColor[
              0.5336294701095035, 0.6304845014245992, 0.9570679718879488], 
             UndirectedEdge[218, 284] -> 
             RGBColor[
              0.4524929737066178, 0.5635889152304235, 0.9508158849378793], 
             UndirectedEdge[209, 276] -> 
             RGBColor[
              0.43364955537393657`, 0.5500271818296745, 0.9488527441005499], 
             UndirectedEdge[8, 72] -> 
             RGBColor[
              0.7036480849032328, 0.7677631551510689, 0.9715420505103793], 
             UndirectedEdge[56, 168] -> 
             RGBColor[
              0.43724257509403663`, 0.5416794523352337, 0.9506903893712375], 
             UndirectedEdge[201, 257] -> 
             RGBColor[
              0.9091956352780889, 0.930333877964705, 0.987801338410267], 
             UndirectedEdge[31, 51] -> 
             RGBColor[
              0.5065244962231075, 0.5886536943897869, 0.9586690091364924], 
             UndirectedEdge[53, 282] -> 
             RGBColor[
              0.5548089764031784, 0.6445639857334045, 0.9602227204955391], 
             UndirectedEdge[17, 97] -> 
             RGBColor[
              0.35120005484529215`, 0.4786135685041524, 0.9435991348340953], 
             UndirectedEdge[102, 162] -> 
             RGBColor[
              0.43330631485799753`, 0.5497298841465381, 0.9488308731183899], 
             UndirectedEdge[36, 260] -> 
             RGBColor[
              0.6511996830063085, 0.7262281631566444, 0.9666986593037517], 
             UndirectedEdge[79, 168] -> 
             RGBColor[
              0.6639444596311129, 0.7373007593459863, 0.9672057329172983], 
             UndirectedEdge[142, 297] -> 
             RGBColor[
              0.9522426849748364, 0.9639032531664351, 0.965724856621689], 
             UndirectedEdge[232, 299] -> 
             RGBColor[
              0.6097417871838884, 0.6835712267463043, 0.9665190493160631], 
             UndirectedEdge[50, 169] -> 
             RGBColor[
              0.8166750637126958, 0.4951679929508858, 0.5732580073017287], 
             UndirectedEdge[92, 153] -> 
             RGBColor[
              0.4552632991083042, 0.5602667593508951, 0.9517488313181268], 
             UndirectedEdge[44, 299] -> 
             RGBColor[
              0.881978861186351, 0.9087276115019991, 0.9885216382513682], 
             UndirectedEdge[90, 252] -> 
             RGBColor[
              0.3542768457203004, 0.47610483620007493`, 0.9439969328032489], 
             UndirectedEdge[7, 283] -> 
             RGBColor[
              0.7406118631599878, 0.7972908834499999, 0.974780927174578], 
             UndirectedEdge[52, 179] -> 
             RGBColor[
              0.8262750413012208, 0.8650999656853078, 0.9806955086008946], 
             UndirectedEdge[98, 296] -> 
             RGBColor[
              0.38301618859018, 0.5061711044285956, 0.9456264307424171], 
             UndirectedEdge[18, 88] -> 
             RGBColor[
              0.5784733896555018, 0.6674344395038987, 0.9607260062621739], 
             UndirectedEdge[100, 240] -> 
             RGBColor[
              0.7495462877331835, 0.8037537495368439, 0.9697486153537034], 
             UndirectedEdge[2, 214] -> 
             RGBColor[
              0.6859372793451941, 0.745671637409814, 0.7689719377786602], 
             UndirectedEdge[114, 169] -> 
             RGBColor[
              0.7791826988038747, 0.8274227134042126, 0.9786253076066083], 
             UndirectedEdge[37, 295] -> 
             RGBColor[
              0.539251506463404, 0.636827691807341, 0.9568710004136054], 
             UndirectedEdge[45, 225] -> 
             RGBColor[
              0.43909623033181344`, 0.553555239450551, 0.9495284854881154], 
             UndirectedEdge[38, 74] -> 
             RGBColor[
              0.622799416047901, 0.7011253825322267, 0.9655426625340919], 
             UndirectedEdge[38, 158] -> 
             RGBColor[
              0.5654485847927007, 0.6514509750355645, 0.9618883182798594], 
             UndirectedEdge[69, 135] -> 
             RGBColor[
              0.475391176983747, 0.582161713986056, 0.9526232109315407], 
             UndirectedEdge[113, 224] -> 
             RGBColor[
              0.4634622370075041, 0.5683308729274472, 0.9522762236758048], 
             UndirectedEdge[124, 282] -> 
             RGBColor[
              0.5331460632781484, 0.6249726173889758, 0.9588726974937255], 
             UndirectedEdge[56, 79] -> 
             RGBColor[
              0.46515792026877134`, 0.5635840979236262, 0.9534064340656645], 
             UndirectedEdge[49, 146] -> 
             RGBColor[
              0.6956813693859571, 0.7618431954169766, 0.9705403621113854], 
             UndirectedEdge[47, 166] -> 
             RGBColor[
              0.40936876727182114`, 0.5229747548133055, 0.9481388273157618], 
             UndirectedEdge[189, 197] -> 
             RGBColor[
              0.5618139884701763, 0.6523942258658548, 0.9599229516774894], 
             UndirectedEdge[125, 256] -> 
             RGBColor[
              0.4142063392076653, 0.5330951222958887, 0.9476390723584391], 
             UndirectedEdge[69, 138] -> 
             RGBColor[
              0.43302851317467067`, 0.5477697950895914, 0.9492882668569395], 
             UndirectedEdge[170, 255] -> 
             RGBColor[
              0.5915548835760062, 0.6735920820629969, 0.9637685498194339], 
             UndirectedEdge[41, 104] -> 
             RGBColor[
              0.5193129814120349, 0.6202558645105376, 0.9554076975866652], 
             UndirectedEdge[185, 283] -> 
             RGBColor[
              0.8421125474208417, 0.8772630838293849, 0.9847173560300817], 
             UndirectedEdge[103, 277] -> 
             RGBColor[
              0.34353334408323144`, 0.4719730489821426, 0.943110618803743], 
             UndirectedEdge[45, 282] -> 
             RGBColor[
              0.5737826542132586, 0.6609980318077207, 0.9614317064678328], 
             UndirectedEdge[222, 245] -> 
             RGBColor[
              0.6095033351902233, 0.6937943073231267, 0.9624472789383545], 
             UndirectedEdge[53, 195] -> 
             RGBColor[
              0.4714776952453168, 0.5788136117620548, 0.9523623644711083], 
             UndirectedEdge[121, 136] -> 
             RGBColor[
              0.337875001251549, 0.46707207681791924`, 0.9427500742019843], 
             UndirectedEdge[92, 211] -> 
             RGBColor[
              0.40895627366541654`, 0.5115951395754297, 0.9491117147242594], 
             UndirectedEdge[26, 137] -> 
             RGBColor[
              0.3457356913114019, 0.47388061145799365`, 0.9432509504216628], 
             UndirectedEdge[139, 148] -> 
             RGBColor[
              0.3746218865213712, 0.4955821211568878, 0.9453291072725236], 
             UndirectedEdge[69, 258] -> 
             RGBColor[
              0.45356947528368546`, 0.5644458734894873, 0.9509053266381846], 
             UndirectedEdge[244, 272] -> 
             RGBColor[
              0.4650371024746018, 0.568685959227689, 0.9525717502249731], 
             UndirectedEdge[100, 256] -> 
             RGBColor[
              0.5063672430355418, 0.6101307653374171, 0.954282230737538], 
             UndirectedEdge[29, 206] -> 
             RGBColor[
              0.5412784132743715, 0.6384732260675956, 0.9570305659425691], 
             UndirectedEdge[101, 213] -> 
             RGBColor[
              0.3493740563987633, 0.47695623949512234`, 0.9434855570742962], 
             UndirectedEdge[39, 107] -> 
             RGBColor[
              0.8049033258102615, 0.8441824071247934, 0.7678725307336549], 
             UndirectedEdge[134, 252] -> 
             RGBColor[
              0.47228370862264857`, 0.5824602166553029, 0.9515990500564547], 
             UndirectedEdge[14, 288] -> 
             RGBColor[
              0.39968531806092816`, 0.5205277323587004, 0.9467110458148882], 
             UndirectedEdge[155, 202] -> 
             RGBColor[
              0.3763689716115537, 0.5004136191805492, 0.9452028759544423], 
             UndirectedEdge[220, 228] -> 
             RGBColor[
              0.38498565781732685`, 0.49764024004381857`, 0.946723512792343], 
             UndirectedEdge[228, 266] -> 
             RGBColor[
              0.30055228524929917`, 0.42699808552529633`, 0.9406555568195236],
              UndirectedEdge[113, 249] -> 
             RGBColor[
              0.41639440216430845`, 0.5301361134502869, 0.9485592283239985], 
             UndirectedEdge[109, 179] -> 
             RGBColor[
              0.7961630880776113, 0.8415762789677033, 0.977694230515767], 
             UndirectedEdge[41, 209] -> 
             RGBColor[
              0.4450769711382617, 0.5599250350061165, 0.9495808889281858], 
             UndirectedEdge[76, 261] -> 
             RGBColor[
              0.3393709223332954, 0.4683677684717482, 0.9428453929705221], 
             UndirectedEdge[114, 219] -> 
             RGBColor[
              0.8383976482732904, 0.8746071571666922, 0.9842817607896133], 
             UndirectedEdge[130, 266] -> 
             RGBColor[
              0.44188093851187593`, 0.5556825392624829, 0.9497845810296888], 
             UndirectedEdge[1, 185] -> 
             RGBColor[
              0.6840496366635471, 0.75105237881199, 0.9708301562972161], 
             UndirectedEdge[202, 208] -> 
             RGBColor[
              0.38909668038668555`, 0.511437720808325, 0.9460138743029227], 
             UndirectedEdge[8, 285] -> 
             RGBColor[
              0.5091156883946767, 0.6114137496874898, 0.9547606241126151], 
             UndirectedEdge[65, 210] -> 
             RGBColor[
              0.7206305035291226, 0.7813299602495423, 0.9730428435494922], 
             UndirectedEdge[63, 183] -> 
             RGBColor[
              0.5057836858496759, 0.607032383325512, 0.9550115684712182], 
             UndirectedEdge[51, 86] -> 
             RGBColor[
              0.6263440261100024, 0.7039484996461085, 0.9658822507802736], 
             UndirectedEdge[91, 191] -> 
             RGBColor[
              0.5069616193350309, 0.6099739466909593, 0.954505679318465], 
             UndirectedEdge[122, 181] -> 
             RGBColor[
              0.5747388991960336, 0.6603117637774489, 0.9621336539313096], 
             UndirectedEdge[17, 42] -> 
             RGBColor[
              0.47473370189155967`, 0.5827902911110068, 0.9522502926906145], 
             UndirectedEdge[90, 253] -> 
             RGBColor[
              0.5314443065767589, 0.6173762871709687, 0.9596952253104449], 
             UndirectedEdge[60, 136] -> 
             RGBColor[
              0.4227475449348834, 0.5383579845875173, 0.9487732451516298], 
             UndirectedEdge[80, 210] -> 
             RGBColor[
              0.7036930997811456, 0.7680666272044632, 0.9713630948345625], 
             UndirectedEdge[229, 259] -> 
             RGBColor[
              0.5702331264844869, 0.6619799666465325, 0.9593099870310786], 
             UndirectedEdge[97, 159] -> 
             RGBColor[
              0.42711858922684687`, 0.5419065952570346, 0.949117349769956], 
             UndirectedEdge[242, 280] -> 
             RGBColor[
              0.4185072088928286, 0.5369116423842022, 0.9478878871726251], 
             UndirectedEdge[88, 99] -> 
             RGBColor[
              0.4287559825435503, 0.545788615002116, 0.9485409299670142], 
             UndirectedEdge[21, 46] -> 
             RGBColor[
              0.5364493820914866, 0.634552801007954, 0.9566504069185282], 
             UndirectedEdge[246, 256] -> 
             RGBColor[
              0.5209645856979486, 0.6219815457135518, 0.9554313870237507], 
             UndirectedEdge[14, 135] -> 
             RGBColor[
              0.4722136457844152, 0.5794094961685566, 0.9524207414532997], 
             UndirectedEdge[67, 179] -> 
             RGBColor[
              0.7529184879538515, 0.8066463334882085, 0.9741681787737336], 
             UndirectedEdge[66, 69] -> 
             RGBColor[
              0.4501363487339184, 0.5616587066957979, 0.95063505834023], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.5620969363125762, 0.6448728407734612, 0.9621657005731279], 
             UndirectedEdge[116, 133] -> 
             RGBColor[
              0.5267933219931787, 0.618840947022538, 0.9584245633970419], 
             UndirectedEdge[2, 83] -> 
             RGBColor[
              0.37972013016558265`, 0.5033162242859228, 0.9454164088141919], 
             UndirectedEdge[103, 168] -> 
             RGBColor[
              0.47604464923341216`, 0.5817866461629324, 0.952924870780169], 
             UndirectedEdge[26, 199] -> 
             RGBColor[
              0.38857569072498593`, 0.5109864657490625, 0.9459806773023723], 
             UndirectedEdge[91, 239] -> 
             RGBColor[
              0.6486229698783659, 0.7245368097000173, 0.9662219607567462], 
             UndirectedEdge[13, 298] -> 
             RGBColor[
              0.46859340615004463`, 0.5794642628618112, 0.951308535927788], 
             UndirectedEdge[229, 261] -> 
             RGBColor[
              0.4624199789771043, 0.5718106371437508, 0.9515524671281796], 
             UndirectedEdge[141, 179] -> 
             RGBColor[
              0.6396563985808328, 0.7116443752259332, 0.9660946874146774], 
             UndirectedEdge[59, 195] -> 
             RGBColor[
              0.5238282715268163, 0.6241570497206198, 0.9556980968999687], 
             UndirectedEdge[134, 253] -> 
             RGBColor[
              0.649451169479107, 0.7237316676261967, 0.9672973425636507], 
             UndirectedEdge[42, 292] -> 
             RGBColor[
              0.4325386590153455, 0.5461584133208386, 0.9495647614104905], 
             UndirectedEdge[70, 238] -> 
             RGBColor[
              0.7118443636584767, 0.7748174941983255, 0.9719136516718349], 
             UndirectedEdge[178, 202] -> 
             RGBColor[
              0.5016404290230579, 0.6027120687027827, 0.9550572259122239], 
             UndirectedEdge[29, 191] -> 
             RGBColor[
              0.48739293873512135`, 0.5940872102209379, 0.9529651610992012], 
             UndirectedEdge[17, 38] -> 
             RGBColor[
              0.6069320571105327, 0.6873818737373272, 0.9645316084535576], 
             UndirectedEdge[40, 162] -> 
             RGBColor[
              0.4321377694202858, 0.5487177488211936, 0.9487564144364031], 
             UndirectedEdge[13, 95] -> 
             RGBColor[
              0.43225547531061026`, 0.5484348467382884, 0.9488702505847177], 
             UndirectedEdge[206, 270] -> 
             RGBColor[
              0.46660197001813364`, 0.5762820333214196, 0.9515843128777832], 
             UndirectedEdge[16, 295] -> 
             RGBColor[
              0.6294450930599524, 0.7092993535032992, 0.964485212251853], 
             UndirectedEdge[37, 124] -> 
             RGBColor[
              0.40541152415501147`, 0.5231736782574401, 0.9475167543477749], 
             UndirectedEdge[22, 177] -> 
             RGBColor[
              0.584843884428198, 0.6702995456911037, 0.9622546753096592], 
             UndirectedEdge[115, 204] -> 
             RGBColor[
              0.6810334149478963, 0.7504243425876808, 0.9690638175393733], 
             UndirectedEdge[192, 200] -> 
             RGBColor[
              0.2906951862072743, 0.4228694502161483, 0.9398660328582902], 
             UndirectedEdge[13, 171] -> 
             RGBColor[
              0.5722359910066673, 0.6630756305661959, 0.9598302642355805], 
             UndirectedEdge[39, 52] -> 
             RGBColor[
              0.8540292194260293, 0.8829644981729973, 0.772492334266913], 
             UndirectedEdge[92, 216] -> 
             RGBColor[
              0.5880901155712677, 0.6764770748353722, 0.9607157546242964], 
             UndirectedEdge[82, 127] -> 
             RGBColor[
              0.6128184498454641, 0.6869700996014628, 0.9667531001303213], 
             UndirectedEdge[53, 150] -> 
             RGBColor[
              0.3893994091027773, 0.511699929206616, 0.9460331639090196], 
             UndirectedEdge[18, 66] -> 
             RGBColor[
              0.6307384070677587, 0.7100552637782749, 0.9647880773010236], 
             UndirectedEdge[31, 36] -> 
             RGBColor[
              0.373690111093623, 0.4835977380233646, 0.9462777901453916], 
             UndirectedEdge[71, 181] -> 
             RGBColor[
              0.5848823177903584, 0.6690974831408106, 0.9627799835946671], 
             UndirectedEdge[43, 143] -> 
             RGBColor[
              0.49660113633650527`, 0.6021203742438899, 0.9535360157332124], 
             UndirectedEdge[75, 185] -> 
             RGBColor[
              0.6949740405594216, 0.7599213020334481, 0.9716901653893095], 
             UndirectedEdge[46, 145] -> 
             RGBColor[
              0.40451277869621244`, 0.51642725155905, 0.9479936869748238], 
             UndirectedEdge[62, 255] -> 
             RGBColor[
              0.6713214833562061, 0.7335399229347719, 0.8131469854696163], 
             UndirectedEdge[111, 242] -> 
             RGBColor[
              0.4776896632797997, 0.5851900737305231, 0.9524829967991402], 
             UndirectedEdge[4, 193] -> 
             RGBColor[
              0.44804553758013843`, 0.5566904614548439, 0.9509727728683643], 
             UndirectedEdge[18, 258] -> 
             RGBColor[
              0.6341715336175258, 0.7128424305719644, 0.9650583455989782], 
             UndirectedEdge[81, 267] -> 
             RGBColor[
              0.42040172473001874`, 0.5366499260100078, 0.9485343121235595], 
             UndirectedEdge[75, 124] -> 
             RGBColor[
              0.3928675427985966, 0.5129899090923822, 0.9465292461852803], 
             UndirectedEdge[72, 106] -> 
             RGBColor[
              0.8702210331070048, 0.8994559006783557, 0.9874567833329102], 
             UndirectedEdge[262, 271] -> 
             RGBColor[
              0.42529529235404673`, 0.5415141094358766, 0.9486732649492273], 
             UndirectedEdge[17, 235] -> 
             RGBColor[
              0.41363393179586666`, 0.5326906547008425, 0.9475773662652763], 
             UndirectedEdge[263, 279] -> 
             RGBColor[
              0.3522167493312246, 0.47949417816731643`, 0.9436639177077113], 
             UndirectedEdge[3, 252] -> 
             RGBColor[
              0.5339803879713478, 0.6325483603543077, 0.9564560386571674], 
             UndirectedEdge[48, 158] -> 
             RGBColor[
              0.32254416849961, 0.4537932800382485, 0.9417732070955538], 
             UndirectedEdge[18, 36] -> 
             RGBColor[
              0.6368875842546795, 0.7150474428358926, 0.9652721630543563], 
             UndirectedEdge[105, 196] -> 
             RGBColor[
              0.4115053993056338, 0.5298330768346049, 0.9477218954650068], 
             UndirectedEdge[269, 298] -> 
             RGBColor[
              0.4216582679066282, 0.5391962581530381, 0.9482115343889642], 
             UndirectedEdge[85, 207] -> 
             RGBColor[
              0.40815313886740967`, 0.527715428166853, 0.9472911428890229], 
             UndirectedEdge[79, 103] -> 
             RGBColor[
              0.5039599944081469, 0.6036912917513249, 0.955640915474596], 
             UndirectedEdge[76, 128] -> 
             RGBColor[
              0.5079109206863072, 0.607060542135493, 0.9559150308257226], 
             UndirectedEdge[10, 265] -> 
             RGBColor[
              0.7501394644362085, 0.8021244735466575, 0.9019149814524003], 
             UndirectedEdge[88, 198] -> 
             RGBColor[
              0.382318158868569, 0.5055665061677301, 0.9455819529057996], 
             UndirectedEdge[63, 143] -> 
             RGBColor[
              0.5966411617125474, 0.6832962593113099, 0.9614729790507139], 
             UndirectedEdge[49, 242] -> 
             RGBColor[
              0.5059426937921485, 0.6081271566849679, 0.9547071788553331], 
             UndirectedEdge[252, 253] -> 
             RGBColor[
              0.6323774584666046, 0.7098704598643314, 0.9659532374896823], 
             UndirectedEdge[16, 125] -> 
             RGBColor[
              0.5315757645883257, 0.6276293541743747, 0.9573926657741496], 
             UndirectedEdge[59, 100] -> 
             RGBColor[
              0.5019350642383495, 0.6063831577660936, 0.9539745834247597], 
             UndirectedEdge[75, 295] -> 
             RGBColor[
              0.5267075251069893, 0.6266439226422831, 0.9558834922511107], 
             UndirectedEdge[94, 295] -> 
             RGBColor[
              0.4227815751515254, 0.5346803259560956, 0.9491204143762417], 
             UndirectedEdge[26, 192] -> 
             RGBColor[
              0.329039098665587, 0.4585172241229215, 0.9422200716857345], 
             UndirectedEdge[132, 188] -> 
             RGBColor[
              0.6060055202379175, 0.6910111362541168, 0.9621332801016684], 
             UndirectedEdge[186, 196] -> 
             RGBColor[
              0.44698584002716346`, 0.5605644512887915, 0.9499826777736609], 
             UndirectedEdge[110, 179] -> 
             RGBColor[
              0.8549765188889061, 0.8875217781161164, 0.9835562036562774], 
             UndirectedEdge[61, 177] -> 
             RGBColor[
              0.5126703718955063, 0.6137082428795742, 0.955203856075607], 
             UndirectedEdge[21, 264] -> 
             RGBColor[
              0.6396394365380522, 0.7164343488445389, 0.9660680148266626], 
             UndirectedEdge[200, 225] -> 
             RGBColor[
              0.38976281133812846`, 0.508388907331497, 0.9464742050218764], 
             UndirectedEdge[83, 197] -> 
             RGBColor[
              0.3901192346766518, 0.5123234059392208, 0.9460790305580702], 
             UndirectedEdge[220, 226] -> 
             RGBColor[
              0.5277314966756952, 0.6274752288911521, 0.9559641030439306], 
             UndirectedEdge[13, 140] -> 
             RGBColor[
              0.3695164458498159, 0.49065360102393574`, 0.9449985249285456], 
             UndirectedEdge[144, 158] -> 
             RGBColor[
              0.35275720239924413`, 0.47996229145087393`, 0.9436983548993017],
              UndirectedEdge[62, 225] -> 
             RGBColor[
              0.7459991889334403, 0.7970324196253613, 0.8182340669096506], 
             UndirectedEdge[65, 277] -> 
             RGBColor[
              0.5974565268773873, 0.6790968269856457, 0.9639636602762252], 
             UndirectedEdge[99, 261] -> 
             RGBColor[
              0.38360277671094034`, 0.506679177576022, 0.9456638076187724], 
             UndirectedEdge[260, 290] -> 
             RGBColor[
              0.721327613171385, 0.7822258807931752, 0.9728588533572763], 
             UndirectedEdge[72, 267] -> 
             RGBColor[
              0.5624344526182236, 0.6494294079959411, 0.9614447979834257], 
             UndirectedEdge[39, 170] -> 
             RGBColor[
              0.9145968516557565, 0.9304044766292418, 0.7784962217783239], 
             UndirectedEdge[92, 163] -> 
             RGBColor[
              0.551216501165881, 0.6465414135236804, 0.9578129286258041], 
             UndirectedEdge[102, 133] -> 
             RGBColor[
              0.3653813665326515, 0.48926772615013336`, 0.9445624004769226], 
             UndirectedEdge[184, 197] -> 
             RGBColor[
              0.34660340819697444`, 0.4733218723342635, 0.9433542175108687], 
             UndirectedEdge[44, 200] -> 
             RGBColor[
              0.5552808519200347, 0.639983719732061, 0.9614328854107408], 
             UndirectedEdge[115, 132] -> 
             RGBColor[
              0.6548940079872472, 0.7292031944501618, 0.9670060276716284], 
             UndirectedEdge[9, 283] -> 
             RGBColor[
              0.5372103822633502, 0.6273932671988715, 0.9593972277036317], 
             UndirectedEdge[52, 165] -> 
             RGBColor[
              0.6265274719672822, 0.706581729855466, 0.9644941173542134], 
             UndirectedEdge[160, 256] -> 
             RGBColor[
              0.40397768319486804`, 0.5242355745648033, 0.9469873114421491], 
             UndirectedEdge[45, 215] -> 
             RGBColor[
              0.4474541312883693, 0.5603405599662303, 0.9501864500674155], 
             UndirectedEdge[16, 124] -> 
             RGBColor[
              0.4956051107515599, 0.5956453399533982, 0.9551309661860226], 
             UndirectedEdge[160, 246] -> 
             RGBColor[
              0.4682609153181952, 0.5764235983291257, 0.9520479229521356], 
             UndirectedEdge[57, 204] -> 
             RGBColor[
              0.5565840346487184, 0.6508990190096757, 0.958235480523496], 
             UndirectedEdge[112, 252] -> 
             RGBColor[
              0.5291593499996587, 0.6286344245436051, 0.9560765088879921], 
             UndirectedEdge[5, 248] -> 
             RGBColor[
              0.5171986381703025, 0.6179399127246545, 0.955406873780438], 
             UndirectedEdge[186, 276] -> 
             RGBColor[
              0.4098003457146385, 0.5293701951189216, 0.9473330935500874], 
             UndirectedEdge[95, 154] -> 
             RGBColor[
              0.41977136232803725`, 0.5380065885515809, 0.9479684379116695], 
             UndirectedEdge[198, 290] -> 
             RGBColor[
              0.5108602836328234, 0.6091772271362549, 0.9562883037515066], 
             UndirectedEdge[77, 191] -> 
             RGBColor[
              0.38652558506246204`, 0.509210767265491, 0.9458500463823936], 
             UndirectedEdge[36, 224] -> 
             RGBColor[
              0.6033147453294403, 0.6888200859044693, 0.961925936226306], 
             UndirectedEdge[29, 203] -> 
             RGBColor[
              0.59133267234348, 0.6791095284985721, 0.9609710205712817], 
             UndirectedEdge[25, 172] -> 
             RGBColor[
              0.650243985697385, 0.7247261411546758, 0.967119891842503], 
             UndirectedEdge[224, 260] -> 
             RGBColor[
              0.6913555987833708, 0.7588115153575121, 0.9698715230674781], 
             UndirectedEdge[45, 255] -> 
             RGBColor[
              0.36441852475457925`, 0.4900627427599616, 0.9444414040480811], 
             UndirectedEdge[102, 239] -> 
             RGBColor[
              0.5763645642186144, 0.6655026707009497, 0.9606361637140792], 
             UndirectedEdge[33, 239] -> 
             RGBColor[
              0.7251270561607831, 0.7851940345333291, 0.973237546326646], 
             UndirectedEdge[64, 92] -> 
             RGBColor[
              0.5736486472811236, 0.6647528402967007, 0.9595788693396547], 
             UndirectedEdge[32, 268] -> 
             RGBColor[
              0.6538300288902845, 0.7203079017808234, 0.8953356415639868], 
             UndirectedEdge[85, 240] -> 
             RGBColor[
              0.6488146065493559, 0.7192945299293858, 0.9625593346203242], 
             UndirectedEdge[1, 174] -> 
             RGBColor[
              0.5327331961582302, 0.6315358338550681, 0.9563578551490247], 
             UndirectedEdge[2, 184] -> 
             RGBColor[
              0.33620430368590526`, 0.46431469068096554`, 0.9426915957669905],
              UndirectedEdge[60, 85] -> 
             RGBColor[
              0.44495262365760546`, 0.5575909077174315, 0.9501881331326616], 
             UndirectedEdge[121, 127] -> 
             RGBColor[
              0.32834877694136805`, 0.45719195835823656`, 0.9422027166147993],
              UndirectedEdge[132, 212] -> 
             RGBColor[
              0.4623862825658389, 0.5717773087092781, 0.951551464551561], 
             UndirectedEdge[172, 206] -> 
             RGBColor[
              0.6620923576410931, 0.7343451832616514, 0.9680526390839284], 
             UndirectedEdge[147, 148] -> 
             RGBColor[
              0.7164315033578418, 0.7762530322318801, 0.950602471710938], 
             UndirectedEdge[118, 226] -> 
             RGBColor[
              0.4558683352056977, 0.5677207594285636, 0.9506971098068766], 
             UndirectedEdge[75, 283] -> 
             RGBColor[
              0.6330835752914359, 0.7108929057801061, 0.9657017129844728], 
             UndirectedEdge[188, 243] -> 
             RGBColor[
              0.4990115934567487, 0.6014785564115085, 0.9544480800929538], 
             UndirectedEdge[88, 258] -> 
             RGBColor[
              0.5020285843160464, 0.6064187181076794, 0.953993098215019], 
             UndirectedEdge[197, 293] -> 
             RGBColor[
              0.6191794928652841, 0.6973681613054825, 0.9655982647595296], 
             UndirectedEdge[86, 179] -> 
             RGBColor[
              0.681104941395151, 0.74754501974736, 0.9687357519112985], 
             UndirectedEdge[41, 76] -> 
             RGBColor[
              0.3809313295275726, 0.5043653042966284, 0.9454935853665163], 
             UndirectedEdge[175, 242] -> 
             RGBColor[
              0.4987677446069823, 0.6023022097086727, 0.9541423405727719], 
             UndirectedEdge[89, 285] -> 
             RGBColor[
              0.5078120867264894, 0.6103554271266695, 0.9546579998140452], 
             UndirectedEdge[138, 171] -> 
             RGBColor[
              0.5968124726297596, 0.6830279255057021, 0.9617650148955689], 
             UndirectedEdge[181, 207] -> 
             RGBColor[
              0.6319393208231013, 0.7096278548420079, 0.9658414221197125], 
             UndirectedEdge[17, 55] -> 
             RGBColor[
              0.36614292937076165`, 0.4915563353674026, 0.9445512815853931], 
             UndirectedEdge[142, 295] -> 
             RGBColor[
              0.7607847265793395, 0.8125123813618268, 0.9608371318663333], 
             UndirectedEdge[53, 200] -> 
             RGBColor[
              0.3127561022336329, 0.4428791448447148, 0.9412387215365419], 
             UndirectedEdge[33, 237] -> 
             RGBColor[
              0.791630628496352, 0.8373582222843294, 0.9798099836865761], 
             UndirectedEdge[51, 67] -> 
             RGBColor[
              0.6981575726687028, 0.763049813386957, 0.9713146776427088], 
             UndirectedEdge[47, 48] -> 
             RGBColor[
              0.30355098818144594`, 0.4338771699713059, 0.9406898553585262], 
             UndirectedEdge[102, 237] -> 
             RGBColor[
              0.6428681365541833, 0.7176668584519499, 0.9672086010740093], 
             UndirectedEdge[150, 282] -> 
             RGBColor[
              0.6010925420887181, 0.6846524840505679, 0.9631718683740715], 
             UndirectedEdge[214, 293] -> 
             RGBColor[
              0.9168829127319127, 0.9323494100109454, 0.78861130642057], 
             UndirectedEdge[73, 245] -> 
             RGBColor[
              0.539454833396688, 0.636992761771555, 0.9568870070546046], 
             UndirectedEdge[82, 192] -> 
             RGBColor[
              0.6167518734962238, 0.691104377251875, 0.9669771027882533], 
             UndirectedEdge[82, 266] -> 
             RGBColor[
              0.6553290048069291, 0.7254195874306253, 0.9694021900997079], 
             UndirectedEdge[30, 38] -> 
             RGBColor[
              0.7382402603604797, 0.7954515833862739, 0.9745409882901828], 
             UndirectedEdge[146, 242] -> 
             RGBColor[
              0.5819591726010303, 0.6678594524894534, 0.9620461043917531], 
             UndirectedEdge[25, 77] -> 
             RGBColor[
              0.42856268765800415`, 0.5439777410051732, 0.9489827039843364], 
             UndirectedEdge[68, 271] -> 
             RGBColor[
              0.369074912224053, 0.49409587154918067`, 0.9447381049401542], 
             UndirectedEdge[23, 267] -> 
             RGBColor[
              0.3915962276375583, 0.5132643257974926, 0.9462666378744284], 
             UndirectedEdge[10, 161] -> 
             RGBColor[
              0.4553920842667246, 0.5672576468942641, 0.9506807466339522], 
             UndirectedEdge[223, 287] -> 
             RGBColor[
              0.46560709204038464`, 0.5715187490073285, 0.9523033043816256], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.42450727107127295`, 0.5380076909042039, 0.9490809175509607], 
             UndirectedEdge[218, 229] -> 
             RGBColor[
              0.5618818852123133, 0.6552000527626501, 0.9586525467265283], 
             UndirectedEdge[62, 170] -> 
             RGBColor[
              0.9151025164604518, 0.9314860425159306, 0.8335347151679626], 
             UndirectedEdge[188, 294] -> 
             RGBColor[
              0.566390969745354, 0.6588502595490914, 0.959014677574014], 
             UndirectedEdge[181, 299] -> 
             RGBColor[
              0.8689772568114253, 0.898504532600426, 0.9872433078398919], 
             UndirectedEdge[69, 109] -> 
             RGBColor[
              0.5016944840314393, 0.6033379545498435, 0.9548155820246245], 
             UndirectedEdge[48, 175] -> 
             RGBColor[
              0.4705748884172028, 0.5778829746912393, 0.9523459167063231], 
             UndirectedEdge[248, 270] -> 
             RGBColor[
              0.40636516495397856`, 0.5263948142012433, 0.9471142068696293], 
             UndirectedEdge[85, 232] -> 
             RGBColor[
              0.31914048245696147`, 0.44852869033172205`, 0.9416411452014142],
              UndirectedEdge[65, 152] -> 
             RGBColor[
              0.6854952944201675, 0.7528056146717598, 0.9702768711839236], 
             UndirectedEdge[43, 63] -> 
             RGBColor[
              0.5503444470429463, 0.6456286749821434, 0.9578509407709193], 
             UndirectedEdge[184, 293] -> 
             RGBColor[
              0.567149937072624, 0.650992463282097, 0.9623309644089002], 
             UndirectedEdge[24, 260] -> 
             RGBColor[
              0.6545235436959669, 0.7289266230027267, 0.9669603257929444], 
             UndirectedEdge[201, 229] -> 
             RGBColor[
              0.7541587614728889, 0.8076151951203605, 0.9732453104245145], 
             UndirectedEdge[17, 48] -> 
             RGBColor[
              0.364027640817442, 0.4897241787400112, 0.9444164972692519], 
             UndirectedEdge[153, 163] -> 
             RGBColor[
              0.3674942529433521, 0.4890118937237161, 0.9448393304954121], 
             UndirectedEdge[33, 200] -> 
             RGBColor[
              0.5097784569683339, 0.604370776216754, 0.9569151799317278], 
             UndirectedEdge[33, 282] -> 
             RGBColor[
              0.7518313311378795, 0.8060556171054436, 0.975899178890725], 
             UndirectedEdge[150, 237] -> 
             RGBColor[
              0.6408918394471906, 0.7159550892294537, 0.9670826731699227], 
             UndirectedEdge[172, 203] -> 
             RGBColor[
              0.7121466167102015, 0.7749814856926278, 0.9719930937126409], 
             UndirectedEdge[56, 93] -> 
             RGBColor[
              0.4113042080267503, 0.5206215174398904, 0.9486484261003314], 
             UndirectedEdge[122, 299] -> 
             RGBColor[
              0.6415540219672689, 0.7134418735168763, 0.9684612788152689], 
             UndirectedEdge[44, 100] -> 
             RGBColor[
              0.6921092376432518, 0.7581442946948749, 0.9708330148700984], 
             UndirectedEdge[31, 171] -> 
             RGBColor[
              0.43060076691717314`, 0.5292700204892893, 0.9511206098150042], 
             UndirectedEdge[136, 256] -> 
             RGBColor[
              0.3834304831289921, 0.5064386226000449, 0.9456780620231271], 
             UndirectedEdge[146, 159] -> 
             RGBColor[
              0.657877706982585, 0.7311524792423355, 0.9675643193276138], 
             UndirectedEdge[65, 133] -> 
             RGBColor[
              0.5575168568308793, 0.6428741104533859, 0.9614783848202754], 
             UndirectedEdge[58, 245] -> 
             RGBColor[
              0.5401431052774719, 0.6375515318906702, 0.956941190338283], 
             UndirectedEdge[172, 272] -> 
             RGBColor[
              0.5318051076480561, 0.6208456323248256, 0.9592265609981798], 
             UndirectedEdge[99, 218] -> 
             RGBColor[
              0.48306468294614935`, 0.5900685931949214, 0.9527638872171211], 
             UndirectedEdge[18, 113] -> 
             RGBColor[
              0.49703507593274343`, 0.5945582298588705, 0.9556224505038551], 
             UndirectedEdge[43, 131] -> 
             RGBColor[
              0.713717410577787, 0.7734586299078415, 0.9367552125793581], 
             UndirectedEdge[2, 156] -> 
             RGBColor[
              0.6055520727652355, 0.6857868084318246, 0.9646277233928231], 
             UndirectedEdge[165, 232] -> 
             RGBColor[
              0.4112727432494417, 0.5260065130660103, 0.9481534480608718], 
             UndirectedEdge[173, 186] -> 
             RGBColor[
              0.47176106622147684`, 0.5806780960245561, 0.9519330743343212], 
             UndirectedEdge[39, 281] -> 
             RGBColor[
              0.6091559770472192, 0.6712583456036328, 0.7544649344372434], 
             UndirectedEdge[77, 91] -> 
             RGBColor[
              0.46371634604923656`, 0.5725170645414389, 0.9517501287449879], 
             UndirectedEdge[15, 19] -> 
             RGBColor[
              0.4691173395295858, 0.5795965227176786, 0.9514307643144092], 
             UndirectedEdge[119, 241] -> 
             RGBColor[
              0.3635544092459061, 0.48931428933805715`, 0.9443863433719758], 
             UndirectedEdge[103, 116] -> 
             RGBColor[
              0.5392598319669014, 0.6312677931409261, 0.9591592733867154], 
             UndirectedEdge[99, 257] -> 
             RGBColor[
              0.6450356008044422, 0.7184166453766914, 0.9678657885509734], 
             UndirectedEdge[17, 253] -> 
             RGBColor[
              0.6008827081651422, 0.6826426622963349, 0.9639322255662895], 
             UndirectedEdge[204, 292] -> 
             RGBColor[
              0.46453885602351486`, 0.5721376148445174, 0.9520839341395575], 
             UndirectedEdge[65, 241] -> 
             RGBColor[
              0.6018498518693464, 0.682902104278746, 0.9642435990598479], 
             UndirectedEdge[71, 256] -> 
             RGBColor[
              0.412141927557574, 0.5313070326849262, 0.9475075298735829], 
             UndirectedEdge[37, 102] -> 
             RGBColor[
              0.47533430007257377`, 0.5845653141415283, 0.9519418531322077], 
             UndirectedEdge[61, 217] -> 
             RGBColor[
              0.7610147170736532, 0.813613537522043, 0.9767999982654477], 
             UndirectedEdge[35, 184] -> 
             RGBColor[
              0.4209724977741984, 0.5351828764805289, 0.9487985625582784], 
             UndirectedEdge[164, 241] -> 
             RGBColor[
              0.5425359145744312, 0.6365339011532153, 0.9583401535121809], 
             UndirectedEdge[192, 255] -> 
             RGBColor[
              0.32338393091814044`, 0.45361900205707884`, 0.9418597293975357],
              UndirectedEdge[112, 134] -> 
             RGBColor[
              0.5462330610121613, 0.6424956323054702, 0.9574206139619605], 
             UndirectedEdge[44, 195] -> 
             RGBColor[
              0.7140024449317186, 0.775918186649401, 0.9725565283453073], 
             UndirectedEdge[127, 281] -> 
             RGBColor[
              0.257790665763089, 0.38828471296221634`, 0.9379921690968696], 
             UndirectedEdge[59, 192] -> 
             RGBColor[
              0.3734055036723786, 0.49694517421945095`, 0.9450470597810957], 
             UndirectedEdge[108, 264] -> 
             RGBColor[
              0.7079086640730499, 0.7717428957697653, 0.9715213779183632], 
             UndirectedEdge[136, 296] -> 
             RGBColor[
              0.343072388071483, 0.4715737920530889, 0.9430812470942818], 
             UndirectedEdge[118, 130] -> 
             RGBColor[
              0.4544511496099061, 0.5665702243184165, 0.950585543765454], 
             UndirectedEdge[85, 136] -> 
             RGBColor[
              0.33238469140608473`, 0.4623166463807745, 0.9424002365135217], 
             UndirectedEdge[104, 157] -> 
             RGBColor[
              0.483439804148579, 0.5891843214032471, 0.9531218904528429], 
             UndirectedEdge[158, 217] -> 
             RGBColor[
              0.6012773870796337, 0.6800198894322351, 0.9653057014267366], 
             UndirectedEdge[11, 174] -> 
             RGBColor[
              0.5780929957234477, 0.6683609625777951, 0.9599287447292193], 
             UndirectedEdge[39, 220] -> 
             RGBColor[
              0.7694364028766238, 0.8153887613205961, 0.7650804446406996], 
             UndirectedEdge[32, 208] -> 
             RGBColor[
              0.38110828418988446`, 0.5045185735311231, 0.945504860761124], 
             UndirectedEdge[27, 103] -> 
             RGBColor[
              0.38098022605974746`, 0.5044076560151871, 0.945496701010309], 
             UndirectedEdge[212, 250] -> 
             RGBColor[
              0.6671185201295156, 0.7330186305347763, 0.9326420241370849], 
             UndirectedEdge[129, 298] -> 
             RGBColor[
              0.5175813795574725, 0.6192349065570136, 0.9551650486432801], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.7771491476854531, 0.8263178746371039, 0.9760757050676365], 
             UndirectedEdge[261, 290] -> 
             RGBColor[
              0.5297193592856668, 0.6255120105820445, 0.95748998737568], 
             UndirectedEdge[24, 113] -> 
             RGBColor[
              0.4266301819201002, 0.5384459805726618, 0.9493650264012711], 
             UndirectedEdge[15, 243] -> 
             RGBColor[
              0.3987521240786558, 0.5198007808375991, 0.9466291106370015], 
             UndirectedEdge[246, 296] -> 
             RGBColor[
              0.4806064906404395, 0.5871167151665959, 0.9528345720949054], 
             UndirectedEdge[131, 174] -> 
             RGBColor[
              0.7892502655834317, 0.8348614300349211, 0.9426788269219171], 
             UndirectedEdge[44, 121] -> 
             RGBColor[
              0.5968678663048883, 0.6784405055245616, 0.9639935718251817], 
             UndirectedEdge[155, 293] -> 
             RGBColor[
              0.6283971095196901, 0.7053519975606451, 0.96618560314193], 
             UndirectedEdge[105, 140] -> 
             RGBColor[
              0.30194542466164326`, 0.4325118316980492, 0.9405866231760769], 
             UndirectedEdge[51, 138] -> 
             RGBColor[
              0.672736201935694, 0.7424115994061997, 0.9693134142170571], 
             UndirectedEdge[133, 277] -> 
             RGBColor[
              0.33106683410950877`, 0.4595462028637546, 0.9423759088140695], 
             UndirectedEdge[201, 261] -> 
             RGBColor[
              0.647762811184587, 0.7185964101640356, 0.9655993574780661], 
             UndirectedEdge[19, 57] -> 
             RGBColor[
              0.49381591635783073`, 0.5999410329096281, 0.953294144324444], 
             UndirectedEdge[104, 261] -> 
             RGBColor[
              0.47775257421775774`, 0.5842583286856574, 0.9527595051906709], 
             UndirectedEdge[15, 111] -> 
             RGBColor[
              0.5028412222005442, 0.6069750899135637, 0.9540856318929196], 
             UndirectedEdge[71, 85] -> 
             RGBColor[
              0.36109613583466665`, 0.4871850564656558, 0.9442297043639775], 
             UndirectedEdge[84, 158] -> 
             RGBColor[
              0.531187667080403, 0.6246726716580002, 0.9584770698700056], 
             UndirectedEdge[65, 162] -> 
             RGBColor[
              0.6254418051562254, 0.7033362684497907, 0.9657468574617427], 
             UndirectedEdge[156, 268] -> 
             RGBColor[
              0.9106182474062426, 0.9295912562177613, 0.9165194626704452], 
             UndirectedEdge[48, 252] -> 
             RGBColor[
              0.3955223911189043, 0.5169519763080077, 0.9464375091926447], 
             UndirectedEdge[204, 235] -> 
             RGBColor[
              0.5281473336883742, 0.6273167335780836, 0.9561339105492572], 
             UndirectedEdge[62, 130] -> 
             RGBColor[
              0.7512413596392364, 0.8012882499614257, 0.8186467497903148], 
             UndirectedEdge[142, 283] -> 
             RGBColor[
              0.8671607767637861, 0.8967613644996497, 0.9706553525996955], 
             UndirectedEdge[99, 259] -> 
             RGBColor[
              0.4914159242183228, 0.5968485070788038, 0.9534213275216714], 
             UndirectedEdge[43, 244] -> 
             RGBColor[
              0.5517056595877123, 0.6466920645677131, 0.9579866137161271], 
             UndirectedEdge[36, 154] -> 
             RGBColor[
              0.5028412222005442, 0.6069750899135637, 0.9540856318929196], 
             UndirectedEdge[11, 185] -> 
             RGBColor[
              0.7294094362287646, 0.7878775075347173, 0.9744010458774108], 
             UndirectedEdge[20, 150] -> 
             RGBColor[
              0.38592285423718276`, 0.5086887121187662, 0.9458116409071807], 
             UndirectedEdge[175, 252] -> 
             RGBColor[
              0.5302624949084447, 0.6295300072766692, 0.9561633524961647], 
             UndirectedEdge[97, 292] -> 
             RGBColor[
              0.3090050119690779, 0.4419816907139842, 0.9409136035539714], 
             UndirectedEdge[176, 226] -> 
             RGBColor[
              0.5520441888685743, 0.647213367687633, 0.9578780872336801], 
             UndirectedEdge[80, 103] -> 
             RGBColor[
              0.5530459630566249, 0.6420376235266949, 0.9605333460950192], 
             UndirectedEdge[137, 220] -> 
             RGBColor[
              0.4387011078890683, 0.5519127936646642, 0.949862560694186], 
             UndirectedEdge[20, 167] -> 
             RGBColor[
              0.500706297471324, 0.6020032557521988, 0.9549552585748032], 
             UndirectedEdge[240, 256] -> 
             RGBColor[
              0.6998603982722631, 0.7634165061486562, 0.9658371601299296], 
             UndirectedEdge[113, 278] -> 
             RGBColor[
              0.37453914080174544`, 0.4961561267181216, 0.9452642288286632], 
             UndirectedEdge[181, 240] -> 
             RGBColor[
              0.8726007885050475, 0.9012069566045406, 0.9811096138510138], 
             UndirectedEdge[7, 151] -> 
             RGBColor[
              0.7667707597355579, 0.8178278967356039, 0.9773612706595842], 
             UndirectedEdge[6, 101] -> 
             RGBColor[
              0.5974013891403533, 0.6798636047012742, 0.9636103915760212], 
             UndirectedEdge[65, 116] -> 
             RGBColor[
              0.7931830147610572, 0.838391571144429, 0.9800123148591975], 
             UndirectedEdge[50, 264] -> 
             RGBColor[
              0.7916191765885018, 0.47559414349767026`, 0.5707606706337669], 
             UndirectedEdge[55, 235] -> 
             RGBColor[
              0.38755636415940675`, 0.5101035763108006, 0.9459157267149687], 
             UndirectedEdge[100, 232] -> 
             RGBColor[
              0.41987216364078916`, 0.53298790993918, 0.9488304259347935], 
             UndirectedEdge[28, 163] -> 
             RGBColor[
              0.48848948018424243`, 0.5956167920706938, 0.9528748277574807], 
             UndirectedEdge[11, 63] -> 
             RGBColor[
              0.6026001660938451, 0.6881340475181354, 0.9619420937041621], 
             UndirectedEdge[234, 274] -> 
             RGBColor[
              0.7024103892369447, 0.7670252649992293, 0.9712621151617995], 
             UndirectedEdge[148, 270] -> 
             RGBColor[
              0.4334063685665823, 0.5493323486182469, 0.9489710335320223], 
             UndirectedEdge[96, 245] -> 
             RGBColor[
              0.4318223472727945, 0.5436080273368655, 0.9496875878667006], 
             UndirectedEdge[159, 235] -> 
             RGBColor[
              0.48955246617742143`, 0.5959836814537247, 0.953095581201137], 
             UndirectedEdge[53, 287] -> 
             RGBColor[
              0.48946215735497073`, 0.593414208293457, 0.9537781672076358], 
             UndirectedEdge[105, 289] -> 
             RGBColor[
              0.343829177646426, 0.4722292851455545, 0.9431294690567944], 
             UndirectedEdge[56, 164] -> 
             RGBColor[
              0.4718673553703112, 0.5688255596185445, 0.9540751678533501], 
             UndirectedEdge[112, 235] -> 
             RGBColor[
              0.5190780344868416, 0.6199538679190064, 0.9554199420941749], 
             UndirectedEdge[7, 43] -> 
             RGBColor[
              0.5756530329170118, 0.6653999346193401, 0.9603734640886643], 
             UndirectedEdge[242, 243] -> 
             RGBColor[
              0.3736005651579114, 0.4980157646545584, 0.9450264755432219], 
             UndirectedEdge[151, 286] -> 
             RGBColor[
              0.586302618519149, 0.6691389855623058, 0.9633896163151714], 
             UndirectedEdge[126, 163] -> 
             RGBColor[
              0.45710467604957533`, 0.5700677900182243, 0.9504232775932306], 
             UndirectedEdge[31, 138] -> 
             RGBColor[
              0.35043309834745445`, 0.46471664735954044`, 0.9444469129087685],
              UndirectedEdge[95, 138] -> 
             RGBColor[
              0.4568319569337025, 0.5683871416777946, 0.9508050012447061], 
             UndirectedEdge[197, 275] -> 
             RGBColor[
              0.49923625553151524`, 0.6028566814961531, 0.9541311153866139], 
             UndirectedEdge[198, 245] -> 
             RGBColor[
              0.44529043477058905`, 0.556879965240594, 0.9504869385549437], 
             UndirectedEdge[187, 264] -> 
             RGBColor[
              0.7418399415199104, 0.7982502675985126, 0.9749033305484504], 
             UndirectedEdge[62, 195] -> 
             RGBColor[
              0.7973543316570239, 0.8387248380111814, 0.8222769318649373], 
             UndirectedEdge[169, 187] -> 
             RGBColor[
              0.7668958286441043, 0.8178241170517282, 0.9774006672164122], 
             UndirectedEdge[82, 199] -> 
             RGBColor[
              0.6762884655556228, 0.7435736188780161, 0.9707377084048912], 
             UndirectedEdge[126, 155] -> 
             RGBColor[
              0.4339150471983343, 0.5502571375039607, 0.9488696610048353], 
             UndirectedEdge[82, 220] -> 
             RGBColor[
              0.7397623773749569, 0.7960617419491476, 0.9754701460725272], 
             UndirectedEdge[32, 202] -> 
             RGBColor[
              0.32768134972785956`, 0.4582428482159222, 0.9421005437407869], 
             UndirectedEdge[113, 260] -> 
             RGBColor[
              0.5113471746843723, 0.6057389501796223, 0.9570489467532504], 
             UndirectedEdge[105, 230] -> 
             RGBColor[
              0.465979459159378, 0.574057572652305, 0.9520102930017498], 
             UndirectedEdge[245, 289] -> 
             RGBColor[
              0.4637917745067016, 0.5729048958156414, 0.9516658275628365], 
             UndirectedEdge[108, 187] -> 
             RGBColor[
              0.6838292524159567, 0.7529318763729373, 0.9691213671992799], 
             UndirectedEdge[137, 228] -> 
             RGBColor[
              0.27867174658440885`, 0.4080462626816182, 0.9392613482439975], 
             UndirectedEdge[88, 261] -> 
             RGBColor[
              0.4011772345214124, 0.5219012896135198, 0.9467836365299729], 
             UndirectedEdge[192, 228] -> 
             RGBColor[
              0.26197515393859394`, 0.39268287534654606`, 0.9382304695080692],
              UndirectedEdge[42, 97] -> 
             RGBColor[
              0.43371325972963026`, 0.5472604458577146, 0.9496365063890091], 
             UndirectedEdge[121, 240] -> 
             RGBColor[
              0.65430491639482, 0.7240499603665306, 0.9629091723087868], 
             UndirectedEdge[25, 43] -> 
             RGBColor[
              0.48207474260312233`, 0.5903271934045495, 0.952392444806587], 
             UndirectedEdge[77, 270] -> 
             RGBColor[
              0.3694712221930891, 0.4944391353252414, 0.9447633574609381], 
             UndirectedEdge[225, 255] -> 
             RGBColor[
              0.4224515560489946, 0.5391384591724275, 0.9484679015611217], 
             UndirectedEdge[2, 275] -> 
             RGBColor[
              0.48883715102044606`, 0.5938494998428552, 0.9534684936427356], 
             UndirectedEdge[235, 253] -> 
             RGBColor[
              0.6222961429537874, 0.7011899032397328, 0.9652966706958651], 
             UndirectedEdge[73, 95] -> 
             RGBColor[
              0.4518268922213389, 0.5643238046687021, 0.9504109842163928], 
             UndirectedEdge[49, 175] -> 
             RGBColor[
              0.6124899413919093, 0.696285952636196, 0.9626365982924042], 
             UndirectedEdge[153, 219] -> 
             RGBColor[
              0.6030010386249993, 0.6766575564888309, 0.9661930770786011], 
             UndirectedEdge[54, 167] -> 
             RGBColor[
              0.5742215300402698, 0.6648672735291444, 0.9598637161053385], 
             UndirectedEdge[56, 246] -> 
             RGBColor[
              0.4118519267764854, 0.5210661801953739, 0.9486915445266704], 
             UndirectedEdge[192, 225] -> 
             RGBColor[
              0.39806163649537457`, 0.5171114987476682, 0.9469468108375699], 
             UndirectedEdge[84, 252] -> 
             RGBColor[
              0.6041658896996973, 0.6878313679277595, 0.9631413719670964], 
             UndirectedEdge[119, 164] -> 
             RGBColor[
              0.5262971696804022, 0.6224687165090574, 0.9573054350468917], 
             UndirectedEdge[93, 168] -> 
             RGBColor[
              0.6100907473890917, 0.6943381788622505, 0.9624477249519652], 
             UndirectedEdge[111, 250] -> 
             RGBColor[
              0.7707958957753349, 0.8198363262957435, 0.9400723108008998], 
             UndirectedEdge[54, 286] -> 
             RGBColor[
              0.4116292802791209, 0.5301431446225024, 0.9476737635614827], 
             UndirectedEdge[74, 257] -> 
             RGBColor[
              0.6514224458788822, 0.7239486095680041, 0.9682727526714514], 
             UndirectedEdge[220, 236] -> 
             RGBColor[
              0.5273076436968003, 0.6271311259485262, 0.9559307357848075], 
             UndirectedEdge[130, 228] -> 
             RGBColor[
              0.3662849497752442, 0.48245816279795917`, 0.9452513245523195], 
             UndirectedEdge[1, 142] -> 
             RGBColor[
              0.7090978660064915, 0.7705506594822551, 0.9567681528668299], 
             UndirectedEdge[101, 114] -> 
             RGBColor[
              0.5665777930839981, 0.655783977194043, 0.9605381835840059], 
             UndirectedEdge[199, 266] -> 
             RGBColor[
              0.39710773473462463`, 0.5183764934372108, 0.9465243316020762], 
             UndirectedEdge[93, 277] -> 
             RGBColor[
              0.477579442238911, 0.5845245816814607, 0.9526334729755392], 
             UndirectedEdge[19, 112] -> 
             RGBColor[
              0.5494098832998163, 0.645074719752802, 0.9576707050495282], 
             UndirectedEdge[77, 203] -> 
             RGBColor[
              0.49046531867082066`, 0.5942330855431252, 0.9538559058544742], 
             UndirectedEdge[26, 60] -> 
             RGBColor[
              0.4471998315765289, 0.5595373262688489, 0.9503313232341274], 
             UndirectedEdge[186, 263] -> 
             RGBColor[
              0.39929670060705647`, 0.5202724656552874, 0.946663810571841], 
             UndirectedEdge[167, 283] -> 
             RGBColor[
              0.7227359717047278, 0.7833261011833438, 0.9729992253740212], 
             UndirectedEdge[170, 200] -> 
             RGBColor[
              0.55886613886514, 0.6428425302220664, 0.9617748532801884], 
             UndirectedEdge[17, 292] -> 
             RGBColor[
              0.3500254541310073, 0.47751153596727636`, 0.9435273898555767], 
             UndirectedEdge[106, 215] -> 
             RGBColor[
              0.7234152535101401, 0.7828014402918033, 0.9741705453582739], 
             UndirectedEdge[123, 229] -> 
             RGBColor[
              0.446641004139133, 0.558143682213435, 0.9505470448043037], 
             UndirectedEdge[105, 149] -> 
             RGBColor[
              0.5205272311255088, 0.6173255803309998, 0.9569993644489352], 
             UndirectedEdge[68, 274] -> 
             RGBColor[
              0.5889705018908431, 0.6731536534450722, 0.9628224259427132], 
             UndirectedEdge[149, 171] -> 
             RGBColor[
              0.6928424025064923, 0.7599730177261416, 0.9700197137676281], 
             UndirectedEdge[29, 172] -> 
             RGBColor[
              0.6658289634887079, 0.7373787282209202, 0.9683467983838907], 
             UndirectedEdge[76, 209] -> 
             RGBColor[
              0.3868634575884775, 0.5095034154655586, 0.9458715753209823], 
             UndirectedEdge[247, 267] -> 
             RGBColor[
              0.5984600291066218, 0.6780539706727999, 0.9649078193612657], 
             UndirectedEdge[164, 210] -> 
             RGBColor[
              0.6613165662342074, 0.7349617571240115, 0.967139398001825], 
             UndirectedEdge[258, 260] -> 
             RGBColor[
              0.6484836323691547, 0.7240231508927162, 0.9664848418483736], 
             UndirectedEdge[62, 137] -> 
             RGBColor[
              0.663628156448401, 0.7268763498450848, 0.8126567734819927], 
             UndirectedEdge[175, 280] -> 
             RGBColor[
              0.5250544564925894, 0.6250704383354303, 0.9558173066096962], 
             UndirectedEdge[72, 194] -> 
             RGBColor[
              0.685747290352003, 0.7532304837127757, 0.9701328343905354], 
             UndirectedEdge[3, 257] -> 
             RGBColor[
              0.7458202276041779, 0.8013822498019713, 0.9754838041889908], 
             UndirectedEdge[154, 171] -> 
             RGBColor[
              0.5597518780240943, 0.6526473723794884, 0.9589284515625323], 
             UndirectedEdge[168, 277] -> 
             RGBColor[
              0.5035178093061974, 0.6055825165768041, 0.9546754362464454], 
             UndirectedEdge[146, 243] -> 
             RGBColor[
              0.56333924075172, 0.6517318033865672, 0.9608596587992743], 
             UndirectedEdge[98, 122] -> 
             RGBColor[
              0.3686914390363169, 0.4937637263478864, 0.9447136703677237], 
             UndirectedEdge[142, 210] -> 
             RGBColor[
              0.7857269644171018, 0.8327616136735321, 0.9628006761953496], 
             UndirectedEdge[3, 38] -> 
             RGBColor[
              0.7171971977731966, 0.7785590227661938, 0.9727537140516314], 
             UndirectedEdge[21, 205] -> 
             RGBColor[
              0.5004858390916624, 0.6053559766615475, 0.9538192250747833], 
             UndirectedEdge[153, 221] -> 
             RGBColor[
              0.43569029897958567`, 0.5443765160927939, 0.9502079730497321], 
             UndirectedEdge[55, 159] -> 
             RGBColor[
              0.44206146375231636`, 0.5548493621202848, 0.9500694965212537], 
             UndirectedEdge[149, 298] -> 
             RGBColor[
              0.5891998176498696, 0.6763616500217569, 0.9614979854598354], 
             UndirectedEdge[22, 247] -> 
             RGBColor[
              0.8262915065674229, 0.8647055805888961, 0.9831930018992703], 
             UndirectedEdge[105, 298] -> 
             RGBColor[
              0.401022384961872, 0.5213224935359246, 0.9468966341753191], 
             UndirectedEdge[169, 219] -> 
             RGBColor[
              0.8752460768948074, 0.9033934296642512, 0.9879544677864625], 
             UndirectedEdge[53, 225] -> 
             RGBColor[
              0.4201225525217332, 0.5371211933762347, 0.9483194995158216], 
             UndirectedEdge[47, 90] -> 
             RGBColor[
              0.262305442782842, 0.3930300298633731, 0.9382492789691306], 
             UndirectedEdge[100, 137] -> 
             RGBColor[
              0.4442201645763062, 0.5563934125140342, 0.9502970410535762], 
             UndirectedEdge[15, 175] -> 
             RGBColor[
              0.5239193035277268, 0.6240872258917133, 0.9557449756665515], 
             UndirectedEdge[49, 253] -> 
             RGBColor[
              0.7146049049500692, 0.7766264052238582, 0.9724264832859218], 
             UndirectedEdge[166, 291] -> 
             RGBColor[
              0.43843141908757544`, 0.5516125349851076, 0.9498637968725319], 
             UndirectedEdge[161, 230] -> 
             RGBColor[
              0.4990407318958938, 0.6026935853887909, 0.954116928065585], 
             UndirectedEdge[263, 269] -> 
             RGBColor[
              0.38445214283028306`, 0.5074148558182143, 0.9457179284768321], 
             UndirectedEdge[122, 160] -> 
             RGBColor[
              0.3492948385834959, 0.4769633659371382, 0.9434777361386102], 
             UndirectedEdge[196, 289] -> 
             RGBColor[
              0.42298477851454863`, 0.5397759381349917, 0.9484533513573825], 
             UndirectedEdge[30, 158] -> 
             RGBColor[
              0.4820452279393366, 0.5862822247046284, 0.953579010798628], 
             UndirectedEdge[114, 187] -> 
             RGBColor[
              0.7300474000225874, 0.789037844554169, 0.973727960219563], 
             UndirectedEdge[49, 159] -> 
             RGBColor[
              0.5818612281737032, 0.6714201834378499, 0.9602253937911938], 
             UndirectedEdge[33, 94] -> 
             RGBColor[
              0.5076268607028639, 0.6021093121226625, 0.9567926497074107], 
             UndirectedEdge[193, 220] -> 
             RGBColor[
              0.4178233145742393, 0.5321546993230242, 0.9485935687656895], 
             UndirectedEdge[60, 127] -> 
             RGBColor[
              0.4132213206247025, 0.5284778661278345, 0.9482258875644447], 
             UndirectedEdge[282, 297] -> 
             RGBColor[
              0.858444003982038, 0.8900175027434851, 0.9731146683149117], 
             UndirectedEdge[97, 235] -> 
             RGBColor[
              0.37261348963393726`, 0.49716080944755037`, 0.9449635799636709],
              UndirectedEdge[50, 187] -> 
             RGBColor[
              0.7675397649314086, 0.4567831241008423, 0.5683606599146835], 
             UndirectedEdge[271, 274] -> 
             RGBColor[
              0.5701361524360136, 0.6568402865892272, 0.9616223178500127], 
             UndirectedEdge[137, 170] -> 
             RGBColor[
              0.583861556668201, 0.6669285089733097, 0.9632783378318104], 
             UndirectedEdge[84, 253] -> 
             RGBColor[
              0.7813333505561557, 0.8291028188986532, 0.9788396644742924], 
             UndirectedEdge[33, 185] -> 
             RGBColor[
              0.8205817827877335, 0.8604430868581288, 0.9825713706278887], 
             UndirectedEdge[3, 144] -> 
             RGBColor[
              0.5045058153797402, 0.6070703391815033, 0.9545637506710736], 
             UndirectedEdge[11, 43] -> 
             RGBColor[
              0.502560140717803, 0.6069581624507155, 0.9540051303866605], 
             UndirectedEdge[29, 272] -> 
             RGBColor[
              0.4109911632813346, 0.5249736751307699, 0.9482044878568205], 
             UndirectedEdge[70, 251] -> 
             RGBColor[
              0.5793963102758737, 0.6662379048034359, 0.9616295828002945], 
             UndirectedEdge[99, 123] -> 
             RGBColor[
              0.36782380187296904`, 0.4930122226457063, 0.9446583852948967], 
             UndirectedEdge[133, 239] -> 
             RGBColor[
              0.5021103617489636, 0.5995584308823112, 0.9559643965952764], 
             UndirectedEdge[259, 260] -> 
             RGBColor[
              0.6554454300819033, 0.7296750519013383, 0.9670329000662263], 
             UndirectedEdge[125, 192] -> 
             RGBColor[
              0.33536266810261484`, 0.4639943821374337, 0.942623003938549], 
             UndirectedEdge[213, 264] -> 
             RGBColor[
              0.5369230749944458, 0.6290211262520764, 0.9590753444289366], 
             UndirectedEdge[134, 204] -> 
             RGBColor[
              0.5553023602136938, 0.6498584979645474, 0.9581345824170429], 
             UndirectedEdge[94, 142] -> 
             RGBColor[
              0.6160963199469021, 0.6874559860175256, 0.9508650840840542], 
             UndirectedEdge[134, 175] -> 
             RGBColor[
              0.547336205920947, 0.6433912150385345, 0.9575074575701331], 
             UndirectedEdge[8, 267] -> 
             RGBColor[
              0.45862591478838666`, 0.5676820454795295, 0.9515434603847761], 
             UndirectedEdge[195, 225] -> 
             RGBColor[
              0.5484844043498123, 0.644323374248837, 0.9575978479564429], 
             UndirectedEdge[51, 281] -> 
             RGBColor[
              0.526640883637262, 0.609797293014692, 0.9598146076402002], 
             UndirectedEdge[49, 243] -> 
             RGBColor[
              0.4873227619428383, 0.5919995075820816, 0.9535207332628542], 
             UndirectedEdge[212, 243] -> 
             RGBColor[
              0.3553923557846702, 0.4822447288666698, 0.9438662645428464], 
             UndirectedEdge[22, 285] -> 
             RGBColor[
              0.5957335335704685, 0.6797316124484583, 0.9629485541236661], 
             UndirectedEdge[20, 33] -> 
             RGBColor[
              0.5366616432863441, 0.6300918451736418, 0.9585389514238342], 
             UndirectedEdge[9, 174] -> 
             RGBColor[
              0.44778440702601885`, 0.5569051184952913, 0.9509133789602768], 
             UndirectedEdge[180, 250] -> 
             RGBColor[
              0.7072668283046513, 0.7677930771634367, 0.9352002388322496], 
             UndirectedEdge[92, 221] -> 
             RGBColor[
              0.6194125472021146, 0.7019060358927582, 0.9631815711801242], 
             UndirectedEdge[71, 232] -> 
             RGBColor[
              0.3256468481628214, 0.454164177286689, 0.9420557250708383], 
             UndirectedEdge[25, 148] -> 
             RGBColor[
              0.4924978340314974, 0.5988709542981785, 0.9531903800554204], 
             UndirectedEdge[76, 218] -> 
             RGBColor[
              0.4388328285685045, 0.5517571840906476, 0.9499454725688707], 
             UndirectedEdge[20, 200] -> 
             RGBColor[
              0.30927954736803837`, 0.439867927756865, 0.941017198534703], 
             UndirectedEdge[68, 255] -> 
             RGBColor[
              0.36784155607532154`, 0.4930276004434319, 0.9446595165769711], 
             UndirectedEdge[30, 123] -> 
             RGBColor[
              0.48965149125998775`, 0.5928703876910661, 0.9540636751714653], 
             UndirectedEdge[113, 290] -> 
             RGBColor[
              0.4934342513955184, 0.5917452383631102, 0.9552635539656029], 
             UndirectedEdge[230, 269] -> 
             RGBColor[
              0.4866153421041342, 0.5919313372694184, 0.9533251932153949], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.5920974214955297, 0.6788320557958005, 0.9616454179058953], 
             UndirectedEdge[71, 296] -> 
             RGBColor[
              0.37178383250006497`, 0.4964422021379702, 0.9449107149447376], 
             UndirectedEdge[37, 237] -> 
             RGBColor[
              0.6785668676244548, 0.7470202066247065, 0.9699162866104917], 
             UndirectedEdge[8, 217] -> 
             RGBColor[
              0.7465703844305529, 0.8018869775726042, 0.975662887488449], 
             UndirectedEdge[39, 100] -> 
             RGBColor[
              0.7749554595638617, 0.8198693801699664, 0.7655149250000897], 
             UndirectedEdge[35, 216] -> 
             RGBColor[
              0.5422829134778924, 0.6392887245850324, 0.9571096438781956], 
             UndirectedEdge[48, 253] -> 
             RGBColor[
              0.5726898519753627, 0.6582234272789015, 0.9621358016998407], 
             UndirectedEdge[72, 247] -> 
             RGBColor[
              0.8434821992214679, 0.8781350803443393, 0.9849064094868689], 
             UndirectedEdge[24, 254] -> 
             RGBColor[
              0.5350782864352823, 0.6334396837870919, 0.956542469245983], 
             UndirectedEdge[247, 273] -> 
             RGBColor[
              0.6555343677146552, 0.7274888941354106, 0.9685445457485136], 
             UndirectedEdge[80, 152] -> 
             RGBColor[
              0.6685578906721905, 0.7395422816266807, 0.9685971224689939], 
             UndirectedEdge[121, 125] -> 
             RGBColor[
              0.36865085733022224`, 0.4937285765137631, 0.9447110845372964], 
             UndirectedEdge[8, 177] -> 
             RGBColor[
              0.4982260392524061, 0.6019816829301352, 0.9540667452986082], 
             UndirectedEdge[38, 253] -> 
             RGBColor[
              0.8155942682684534, 0.8558811222762175, 0.9822509128841463], 
             UndirectedEdge[134, 292] -> 
             RGBColor[
              0.398593915444972, 0.5186005412971382, 0.9468925068529379], 
             UndirectedEdge[19, 177] -> 
             RGBColor[
              0.4461617978209388, 0.5597135862687224, 0.9499680574955227], 
             UndirectedEdge[219, 221] -> 
             RGBColor[
              0.7671502867188096, 0.818296833030694, 0.9776258169405985], 
             UndirectedEdge[37, 185] -> 
             RGBColor[
              0.7075180219158363, 0.7701050711985059, 0.9726776735518041], 
             UndirectedEdge[15, 280] -> 
             RGBColor[
              0.44365876781357305`, 0.5586966585672428, 0.9494905222664045], 
             UndirectedEdge[140, 171] -> 
             RGBColor[
              0.4742605960426268, 0.5751592690931909, 0.9536069724947698], 
             UndirectedEdge[211, 221] -> 
             RGBColor[
              0.389383273536698, 0.4957048963173286, 0.9475708564558648], 
             UndirectedEdge[47, 273] -> 
             RGBColor[
              0.35141407572733685`, 0.4753337707348285, 0.9437396489732839], 
             UndirectedEdge[58, 171] -> 
             RGBColor[
              0.5924956797981799, 0.6795233586157249, 0.9614251811509338], 
             UndirectedEdge[75, 150] -> 
             RGBColor[
              0.4608140216091663, 0.5726697757539744, 0.9508284170656263], 
             UndirectedEdge[9, 167] -> 
             RGBColor[
              0.4797242718152218, 0.5824846808061723, 0.9536675494524076], 
             UndirectedEdge[135, 260] -> 
             RGBColor[
              0.6703053340692162, 0.7417389913892849, 0.9682027261417296], 
             UndirectedEdge[184, 202] -> 
             RGBColor[
              0.31512179916448746`, 0.44605408490200105`, 0.9413482372214125],
              UndirectedEdge[166, 262] -> 
             RGBColor[
              0.5239101823736414, 0.6243729137924974, 0.9556632751841374], 
             UndirectedEdge[173, 276] -> 
             RGBColor[
              0.4782507320555449, 0.5862991183899369, 0.9523465901026817], 
             UndirectedEdge[67, 86] -> 
             RGBColor[
              0.49567399896735814`, 0.6006496665966194, 0.9536614179782015], 
             UndirectedEdge[25, 272] -> 
             RGBColor[
              0.3954061854900117, 0.5123210880645255, 0.9469775813154329], 
             UndirectedEdge[7, 174] -> 
             RGBColor[
              0.6511858879226564, 0.7268027347464197, 0.9662970784312233], 
             UndirectedEdge[88, 113] -> 
             RGBColor[
              0.364892126631264, 0.4881345173945856, 0.9445572031198959], 
             UndirectedEdge[147, 206] -> 
             RGBColor[
              0.7496271048093931, 0.8032027169350529, 0.9532157510566989], 
             UndirectedEdge[189, 211] -> 
             RGBColor[
              0.451961006475359, 0.5452424406870303, 0.9533626927467403], 
             UndirectedEdge[104, 209] -> 
             RGBColor[
              0.5252451094729398, 0.6253939756794678, 0.9557856875411311], 
             UndirectedEdge[151, 167] -> 
             RGBColor[
              0.7488948682802978, 0.8038631144689476, 0.9755795688590272], 
             UndirectedEdge[215, 274] -> 
             RGBColor[
              0.6519384028210722, 0.7260498326897473, 0.9672887755061639], 
             UndirectedEdge[41, 261] -> 
             RGBColor[
              0.3975844358830797, 0.5187893880123061, 0.9465547065777256], 
             UndirectedEdge[157, 218] -> 
             RGBColor[
              0.46117316485483284`, 0.5711072605239149, 0.9513689790422519], 
             UndirectedEdge[187, 205] -> 
             RGBColor[
              0.6026863440735206, 0.6871718954155213, 0.9626545407965711], 
             UndirectedEdge[62, 82] -> 
             RGBColor[
              0.9646894259342895, 0.9710252981295682, 0.838264358860334], 
             UndirectedEdge[42, 144] -> 
             RGBColor[
              0.4767538796014143, 0.5845400675061989, 0.9523790166279134], 
             UndirectedEdge[33, 150] -> 
             RGBColor[
              0.5864217638374783, 0.6731915605786551, 0.9617096223042055], 
             UndirectedEdge[34, 46] -> 
             RGBColor[
              0.6549397047641301, 0.729094449149169, 0.9671093394307322], 
             UndirectedEdge[220, 266] -> 
             RGBColor[
              0.4605816465539586, 0.5708646165083422, 0.9512567692697123], 
             UndirectedEdge[128, 279] -> 
             RGBColor[
              0.5011274013618663, 0.6011849986462572, 0.9554827909727999], 
             UndirectedEdge[147, 270] -> 
             RGBColor[
              0.6786872674007699, 0.7440450691481455, 0.9480636572918755], 
             UndirectedEdge[30, 90] -> 
             RGBColor[
              0.45409029866878514`, 0.5569467482810251, 0.9519853007164814], 
             UndirectedEdge[36, 222] -> 
             RGBColor[
              0.6049452538873812, 0.6900938515822568, 0.9620884500813927], 
             UndirectedEdge[127, 170] -> 
             RGBColor[
              0.5632315403716264, 0.6474308439878252, 0.9620234564379501], 
             UndirectedEdge[1, 295] -> 
             RGBColor[
              0.5157831212111148, 0.6177749994208253, 0.9550234831590174], 
             UndirectedEdge[96, 140] -> 
             RGBColor[
              0.281455376636651, 0.4131578245196601, 0.9393398393723166], 
             UndirectedEdge[206, 272] -> 
             RGBColor[
              0.40725455743371985`, 0.521940130171501, 0.9479103285568581], 
             UndirectedEdge[129, 265] -> 
             RGBColor[
              0.7767174459391113, 0.8237016762551361, 0.9040072975146631], 
             UndirectedEdge[39, 60] -> 
             RGBColor[
              0.7645866319088327, 0.811451498769251, 0.7646986529048185], 
             UndirectedEdge[71, 240] -> 
             RGBColor[
              0.6553209722552158, 0.7249300168843529, 0.9629739144897482], 
             UndirectedEdge[30, 144] -> 
             RGBColor[
              0.5255488779670232, 0.6239628998015833, 0.956351024909625], 
             UndirectedEdge[26, 59] -> 
             RGBColor[
              0.40345059097344516`, 0.523870356710053, 0.9469284927928463], 
             UndirectedEdge[133, 241] -> 
             RGBColor[
              0.3354601591014679, 0.463351480156855, 0.9426558475976925], 
             UndirectedEdge[236, 266] -> 
             RGBColor[
              0.44287427112877253`, 0.5564889714300039, 0.9498627798119881], 
             UndirectedEdge[28, 216] -> 
             RGBColor[
              0.5253630945896292, 0.6255524533823856, 0.9557776537559728], 
             UndirectedEdge[173, 230] -> 
             RGBColor[
              0.5699102862218139, 0.6617178703775067, 0.9592845718629981], 
             UndirectedEdge[39, 266] -> 
             RGBColor[
              0.6850030303085961, 0.7447466068020739, 0.7590124886678802], 
             UndirectedEdge[86, 141] -> 
             RGBColor[
              0.38241190959433957`, 0.505647708334344, 0.9455879266191451], 
             UndirectedEdge[25, 206] -> 
             RGBColor[
              0.5256934354830487, 0.6258206390013512, 0.9558036594011814], 
             UndirectedEdge[141, 165] -> 
             RGBColor[
              0.43990882924689434`, 0.5531261393960912, 0.9498932961679962], 
             UndirectedEdge[152, 241] -> 
             RGBColor[
              0.46343859669075615`, 0.5732829843752287, 0.9514543339613406], 
             UndirectedEdge[110, 141] -> 
             RGBColor[
              0.5562834870880947, 0.6456244667031006, 0.9604083783641242], 
             UndirectedEdge[97, 134] -> 
             RGBColor[
              0.3997685161592569, 0.5197025738340142, 0.9469642518314565], 
             UndirectedEdge[103, 119] -> 
             RGBColor[
              0.33168792418116166`, 0.4617131416310851, 0.9423558391220765], 
             UndirectedEdge[3, 17] -> 
             RGBColor[
              0.5024856376698854, 0.6053205627863112, 0.9544350267337747], 
             UndirectedEdge[203, 270] -> 
             RGBColor[
              0.5166562290872421, 0.616918335752396, 0.9555247675064957], 
             UndirectedEdge[51, 141] -> 
             RGBColor[
              0.5848954832956842, 0.6680478551246816, 0.9632411862836525], 
             UndirectedEdge[184, 275] -> 
             RGBColor[
              0.44720669973885513`, 0.5564809834727676, 0.9508638150359845], 
             UndirectedEdge[58, 109] -> 
             RGBColor[
              0.5809939820852299, 0.6705381449462281, 0.9602787994123831], 
             UndirectedEdge[179, 281] -> 
             RGBColor[
              0.5814017989224107, 0.6533938131159434, 0.962668108771225], 
             UndirectedEdge[31, 154] -> 
             RGBColor[
              0.3133725037417892, 0.43433609423332664`, 0.9416103495757318], 
             UndirectedEdge[122, 296] -> 
             RGBColor[
              0.3616404139057402, 0.48765648277460844`, 0.9442643852813801], 
             UndirectedEdge[96, 290] -> 
             RGBColor[
              0.4973921961350289, 0.5959052892325263, 0.9554889530632635], 
             UndirectedEdge[122, 240] -> 
             RGBColor[
              0.645177553660891, 0.7161442975209911, 0.9623275848263908], 
             UndirectedEdge[97, 144] -> 
             RGBColor[
              0.3532202325551468, 0.4803633448993445, 0.9437278587713942], 
             UndirectedEdge[61, 247] -> 
             RGBColor[
              0.7541179940347312, 0.8081142777773664, 0.976142182665218], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.6135920629273919, 0.6879765652554655, 0.9667678651694049], 
             UndirectedEdge[45, 287] -> 
             RGBColor[
              0.508435835165051, 0.6098482543677732, 0.9549871531799295], 
             UndirectedEdge[278, 290] -> 
             RGBColor[
              0.5845195792887581, 0.6726430573316744, 0.9610741354326892], 
             UndirectedEdge[109, 110] -> 
             RGBColor[
              0.7127901765848731, 0.7755563704448707, 0.9720079214652138], 
             UndirectedEdge[56, 160] -> 
             RGBColor[
              0.2948650242734049, 0.4233202090466253, 0.9402474689450688], 
             UndirectedEdge[146, 292] -> 
             RGBColor[
              0.539764129724816, 0.6312275746992853, 0.959360573111629], 
             UndirectedEdge[131, 139] -> 
             RGBColor[
              0.627611784003879, 0.696044200256377, 0.9313724071496305], 
             UndirectedEdge[47, 74] -> 
             RGBColor[
              0.3476112033085938, 0.47203991378363874`, 0.9434973333055097], 
             UndirectedEdge[46, 221] -> 
             RGBColor[
              0.5796893956786342, 0.6696569919784139, 0.9600544191814973], 
             UndirectedEdge[48, 74] -> 
             RGBColor[
              0.37989499975481034`, 0.5034676875349107, 0.9454275513497863], 
             UndirectedEdge[90, 134] -> 
             RGBColor[
              0.3713505567328028, 0.4899660439619402, 0.9453410378772173], 
             UndirectedEdge[1, 37] -> 
             RGBColor[
              0.48756464589055615`, 0.5948659699277692, 0.952802021414102], 
             UndirectedEdge[33, 295] -> 
             RGBColor[
              0.6523152673353012, 0.7271657074669639, 0.96676469748969], 
             UndirectedEdge[28, 35] -> 
             RGBColor[
              0.5304513242558192, 0.629683307447533, 0.9561782178340947], 
             UndirectedEdge[21, 169] -> 
             RGBColor[
              0.6646953236622462, 0.7360081982977544, 0.9685653514946244], 
             UndirectedEdge[100, 228] -> 
             RGBColor[
              0.3905047145045648, 0.5021208588931887, 0.9471579931517331], 
             UndirectedEdge[190, 250] -> 
             RGBColor[
              0.8374901973720366, 0.8731516671981161, 0.9458902728478122], 
             UndirectedEdge[81, 180] -> 
             RGBColor[
              0.47974593078383543`, 0.5880508945673009, 0.9523156724572878], 
             UndirectedEdge[127, 141] -> 
             RGBColor[
              0.3160452654215111, 0.44653527507220603`, 0.941418747740322], 
             UndirectedEdge[143, 185] -> 
             RGBColor[
              0.7234504318474669, 0.7830397193278916, 0.9739319312239627], 
             UndirectedEdge[283, 295] -> 
             RGBColor[
              0.6738460319684094, 0.7439857044382199, 0.968910682891883], 
             UndirectedEdge[26, 100] -> 
             RGBColor[
              0.4575686592315579, 0.5679552076695641, 0.9511475953293984], 
             UndirectedEdge[242, 294] -> 
             RGBColor[
              0.44097994144651653`, 0.5553874677921413, 0.9495930730242822], 
             UndirectedEdge[39, 228] -> 
             RGBColor[
              0.6094070415719643, 0.6715222303375503, 0.7544792321905109], 
             UndirectedEdge[39, 82] -> 
             RGBColor[
              0.9641837611295943, 0.9699437322428792, 0.7832258654706952], 
             UndirectedEdge[109, 258] -> 
             RGBColor[
              0.6058517370258243, 0.6907187902361014, 0.9622356929382633], 
             UndirectedEdge[118, 199] -> 
             RGBColor[
              0.4096779458326548, 0.5292641784931444, 0.9473252943378414], 
             UndirectedEdge[57, 115] -> 
             RGBColor[
              0.616370148804378, 0.6979277900854297, 0.9639732883592069], 
             UndirectedEdge[96, 222] -> 
             RGBColor[
              0.4690506903049555, 0.5737646894746509, 0.9526641366285522], 
             UndirectedEdge[6, 108] -> 
             RGBColor[
              0.7269397186320822, 0.786610100232653, 0.9734182155814912], 
             UndirectedEdge[1, 9] -> 
             RGBColor[
              0.3791474715060555, 0.5011825621814767, 0.9455100279707661], 
             UndirectedEdge[180, 190] -> 
             RGBColor[
              0.5663240636783959, 0.6575088254736674, 0.9596989625408416], 
             UndirectedEdge[144, 253] -> 
             RGBColor[
              0.602902885874997, 0.684392438691527, 0.9640609495035884], 
             UndirectedEdge[53, 192] -> 
             RGBColor[
              0.32105492739087904`, 0.45160173626088596`, 0.9417113273522355],
              UndirectedEdge[85, 121] -> 
             RGBColor[
              0.360080079974271, 0.4863049999478335, 0.9441649621830159], 
             UndirectedEdge[36, 278] -> 
             RGBColor[
              0.5143916491236815, 0.6166453396951437, 0.9549139413791645], 
             UndirectedEdge[122, 207] -> 
             RGBColor[
              0.40451608597894484`, 0.5245651957584582, 0.9470593930950895], 
             UndirectedEdge[226, 228] -> 
             RGBColor[
              0.3677021353710358, 0.48360869790810623`, 0.9453628905937421], 
             UndirectedEdge[7, 143] -> 
             RGBColor[
              0.6219497475866129, 0.7030675189485067, 0.963995502368459], 
             UndirectedEdge[133, 164] -> 
             RGBColor[
              0.4982029195359641, 0.5965059073278552, 0.9555749392726083], 
             UndirectedEdge[7, 131] -> 
             RGBColor[
              0.8390660218278947, 0.8744057746124583, 0.9472146992146048], 
             UndirectedEdge[111, 280] -> 
             RGBColor[
              0.5039763751654068, 0.6079583023572808, 0.9541579628360644], 
             UndirectedEdge[135, 224] -> 
             RGBColor[
              0.622420396392348, 0.7043309141371099, 0.963430003064284], 
             UndirectedEdge[91, 102] -> 
             RGBColor[
              0.5118939746620538, 0.6142461049678395, 0.9548199646383922], 
             UndirectedEdge[200, 282] -> 
             RGBColor[
              0.5244492352195737, 0.6158316996886668, 0.9583774260015938], 
             UndirectedEdge[106, 194] -> 
             RGBColor[
              0.748511700725938, 0.803175866723651, 0.9761462296144168], 
             UndirectedEdge[38, 259] -> 
             RGBColor[
              0.6966469704587057, 0.7618754224550996, 0.9711359248794716], 
             UndirectedEdge[36, 69] -> 
             RGBColor[
              0.4562855259208392, 0.5666508857534156, 0.9511191440935627], 
             UndirectedEdge[64, 153] -> 
             RGBColor[
              0.3899263990585947, 0.5072233204967364, 0.9466052712092627], 
             UndirectedEdge[159, 175] -> 
             RGBColor[
              0.5746862789885371, 0.6655952364615547, 0.9596605555086326], 
             UndirectedEdge[94, 200] -> 
             RGBColor[
              0.2802447647845581, 0.41188539470588575`, 0.9392708968182796], 
             UndirectedEdge[88, 201] -> 
             RGBColor[
              0.6929160170171969, 0.7577058475901295, 0.9684764798263078], 
             UndirectedEdge[121, 232] -> 
             RGBColor[
              0.32463079230242575`, 0.4532841207688667, 0.9419909828898768], 
             UndirectedEdge[140, 289] -> 
             RGBColor[
              0.3134248038705581, 0.44245469299843604`, 0.9413180790684523], 
             UndirectedEdge[139, 244] -> 
             RGBColor[
              0.46560003301380437`, 0.5692776349162486, 0.9526038082863995], 
             UndirectedEdge[167, 174] -> 
             RGBColor[
              0.6333099964673965, 0.7128379524797637, 0.9645153766306662], 
             UndirectedEdge[185, 282] -> 
             RGBColor[
              0.8352525610389733, 0.8719040103300416, 0.9840336166977547], 
             UndirectedEdge[236, 249] -> 
             RGBColor[
              0.5294676298458627, 0.6288847000106021, 0.9561007778067516], 
             UndirectedEdge[137, 299] -> 
             RGBColor[
              0.6340897881194054, 0.7069767293211585, 0.9679856644348459], 
             UndirectedEdge[201, 218] -> 
             RGBColor[
              0.747224717419796, 0.801985825782935, 0.9726994370764148], 
             UndirectedEdge[36, 109] -> 
             RGBColor[
              0.608567787662978, 0.6929238025000295, 0.9624495103936413], 
             UndirectedEdge[4, 52] -> 
             RGBColor[
              0.6598300586772909, 0.7336182700110854, 0.96711581897142], 
             UndirectedEdge[5, 191] -> 
             RGBColor[
              0.5235499686952074, 0.6234411159981731, 0.9558115749452238], 
             UndirectedEdge[55, 134] -> 
             RGBColor[
              0.4147113906847264, 0.5326453406972644, 0.9479163985827543], 
             UndirectedEdge[67, 69] -> 
             RGBColor[
              0.45844988390767955`, 0.5684080090703487, 0.9512895302825912], 
             UndirectedEdge[232, 256] -> 
             RGBColor[
              0.3701862741798688, 0.4926506665509924, 0.9449189707110197], 
             UndirectedEdge[185, 237] -> 
             RGBColor[
              0.8750518583974458, 0.9032066155089273, 0.987944421493606], 
             UndirectedEdge[28, 211] -> 
             RGBColor[
              0.346229252683778, 0.4606705181224431, 0.944173613855936], 
             UndirectedEdge[85, 246] -> 
             RGBColor[
              0.4699187939750412, 0.5778595694942815, 0.9521535615141453], 
             UndirectedEdge[26, 127] -> 
             RGBColor[
              0.3251056750148272, 0.4543829464725092, 0.9419960690278024], 
             UndirectedEdge[91, 162] -> 
             RGBColor[
              0.5055647205177491, 0.6087640231456057, 0.9544166701610568], 
             UndirectedEdge[112, 242] -> 
             RGBColor[
              0.4976645996981965, 0.6014066269756084, 0.9540554969645993], 
             UndirectedEdge[85, 122] -> 
             RGBColor[
              0.35095271724034194`, 0.47839933710229404`, 0.9435833747006199],
              UndirectedEdge[63, 131] -> 
             RGBColor[
              0.8137574359538291, 0.8546345149752614, 0.9446921758968597], 
             UndirectedEdge[140, 222] -> 
             RGBColor[
              0.4591363645540798, 0.5633441045059214, 0.9520995304439703], 
             UndirectedEdge[121, 256] -> 
             RGBColor[
              0.41112587169717835`, 0.5304269761671039, 0.9474427876926215], 
             UndirectedEdge[171, 198] -> 
             RGBColor[
              0.497643009291297, 0.5988517919656489, 0.9549709293675945], 
             UndirectedEdge[10, 117] -> 
             RGBColor[
              0.5683610086703983, 0.6604600970671091, 0.9591626070589601], 
             UndirectedEdge[18, 290] -> 
             RGBColor[
              0.7070155144197561, 0.7710451604724233, 0.9714323571078809], 
             UndirectedEdge[207, 240] -> 
             RGBColor[
              0.7023779752879588, 0.76546038858555, 0.9660353530147936], 
             UndirectedEdge[219, 264] -> 
             RGBColor[
              0.8501901897706134, 0.8838195802110357, 0.9854571311185005], 
             UndirectedEdge[78, 118] -> 
             RGBColor[
              0.6242743086763201, 0.7015219556290029, 0.966042170239591], 
             UndirectedEdge[2, 208] -> 
             RGBColor[
              0.4101791849081033, 0.5296983265872894, 0.9473572328485007], 
             UndirectedEdge[34, 169] -> 
             RGBColor[
              0.7831856463348896, 0.8305498464389695, 0.9790242840068284], 
             UndirectedEdge[35, 275] -> 
             RGBColor[
              0.5736053451087392, 0.6647176856424184, 0.9595754604340236], 
             UndirectedEdge[157, 284] -> 
             RGBColor[
              0.35871829740223005`, 0.48512549232911384`, 0.9440781906017026],
              UndirectedEdge[30, 259] -> 
             RGBColor[
              0.6132436136053416, 0.6967066721241636, 0.9628266173982402], 
             UndirectedEdge[62, 192] -> 
             RGBColor[
              0.6469315638025861, 0.7115129625100125, 0.8116258947460644], 
             UndirectedEdge[95, 245] -> 
             RGBColor[
              0.4846470509827132, 0.5909686880824887, 0.952994707338291], 
             UndirectedEdge[129, 230] -> 
             RGBColor[
              0.5825384537549785, 0.6719699856733939, 0.9602787074697108], 
             UndirectedEdge[35, 92] -> 
             RGBColor[
              0.5931783452374577, 0.6806079289005196, 0.9611163187024182], 
             UndirectedEdge[186, 279] -> 
             RGBColor[
              0.3562307286047386, 0.48297088526556986`, 0.9439196849175971], 
             UndirectedEdge[217, 233] -> 
             RGBColor[
              0.7431154316926778, 0.79908209129615, 0.9753909009530146], 
             UndirectedEdge[28, 293] -> 
             RGBColor[
              0.6766287635542447, 0.745492894249101, 0.9697106196847165], 
             UndirectedEdge[24, 233] -> 
             RGBColor[
              0.5813680962646701, 0.6710198367387575, 0.9601865726409129], 
             UndirectedEdge[41, 229] -> 
             RGBColor[
              0.5039803861713815, 0.607808172968631, 0.9542006595241739], 
             UndirectedEdge[197, 214] -> 
             RGBColor[
              0.6963363838562633, 0.754678819063112, 0.7696345595225385], 
             UndirectedEdge[84, 144] -> 
             RGBColor[
              0.5746913171080896, 0.6623533467549549, 0.9612490839810025], 
             UndirectedEdge[101, 205] -> 
             RGBColor[
              0.43921673713493126`, 0.553918028055395, 0.9494647641610139], 
             UndirectedEdge[7, 297] -> 
             RGBColor[
              0.8256937713710382, 0.8644327721167853, 0.9698504311965717], 
             UndirectedEdge[30, 47] -> 
             RGBColor[
              0.4630520476211725, 0.5663661146376858, 0.9524956590616004], 
             UndirectedEdge[140, 298] -> 
             RGBColor[
              0.37061801118600407`, 0.4915479013888061, 0.9450852441869771], 
             UndirectedEdge[159, 252] -> 
             RGBColor[
              0.4996337816902386, 0.6046642380783231, 0.9537521479949542], 
             UndirectedEdge[26, 195] -> 
             RGBColor[
              0.47946186652002476`, 0.5857290996240904, 0.9528711088046073], 
             UndirectedEdge[43, 185] -> 
             RGBColor[
              0.6771537171778658, 0.745372134998725, 0.970309892944168], 
             UndirectedEdge[36, 95] -> 
             RGBColor[
              0.480088969679871, 0.5872682323416187, 0.9526358784813294], 
             UndirectedEdge[6, 46] -> 
             RGBColor[
              0.6817603532894703, 0.7500469436216433, 0.9697825710225274], 
             UndirectedEdge[148, 183] -> 
             RGBColor[
              0.41616675190200886`, 0.5344002591517211, 0.9478725404025501], 
             UndirectedEdge[222, 261] -> 
             RGBColor[
              0.5013778534555934, 0.603371410824169, 0.9546651709409686], 
             UndirectedEdge[64, 145] -> 
             RGBColor[
              0.3788990301699833, 0.49563285661923573`, 0.9459772788645866], 
             UndirectedEdge[8, 247] -> 
             RGBColor[
              0.739673661391631, 0.7963877178279276, 0.9750050718882193], 
             UndirectedEdge[122, 136] -> 
             RGBColor[
              0.3287476385176199, 0.4591664139723798, 0.9421684867195883], 
             UndirectedEdge[139, 206] -> 
             RGBColor[
              0.40781748797292244`, 0.5225318058600605, 0.9479423866182846], 
             UndirectedEdge[65, 80] -> 
             RGBColor[
              0.8069691458507807, 0.8491614015301979, 0.9813863875675013], 
             UndirectedEdge[171, 245] -> 
             RGBColor[
              0.6246275666787703, 0.7056094719103962, 0.9639547209891537], 
             UndirectedEdge[137, 232] -> 
             RGBColor[
              0.3080391957206332, 0.4389133137276095, 0.9409337810270577], 
             UndirectedEdge[64, 221] -> 
             RGBColor[
              0.5540756471524051, 0.6488625970385996, 0.9580380110712601], 
             UndirectedEdge[140, 263] -> 
             RGBColor[
              0.3334118861096589, 0.45976649905398237`, 0.942591638274845], 
             UndirectedEdge[200, 295] -> 
             RGBColor[
              0.4249331714169955, 0.536941790050187, 0.9492429446005588], 
             UndirectedEdge[136, 232] -> 
             RGBColor[
              0.29693540373423943`, 0.42929576720180773`, 0.9402262572203826],
              UndirectedEdge[45, 68] -> 
             RGBColor[
              0.38448623035814034`, 0.5074443807215553, 0.9457201005039647], 
             UndirectedEdge[224, 254] -> 
             RGBColor[
              0.5719103415226863, 0.6633245761418773, 0.9594536665205167], 
             UndirectedEdge[148, 272] -> 
             RGBColor[
              0.37405895598216854`, 0.49499044546832827`, 0.9452970492110973],
              UndirectedEdge[167, 185] -> 
             RGBColor[
              0.7846264369727134, 0.8323544974366857, 0.9789876777788578], 
             UndirectedEdge[59, 137] -> 
             RGBColor[
              0.39010209631819354`, 0.5123085615545231, 0.946077938517024], 
             UndirectedEdge[55, 97] -> 
             RGBColor[
              0.32512248720883224`, 0.4560264901141105, 0.9419374952837878], 
             UndirectedEdge[156, 202] -> 
             RGBColor[
              0.5844695682438177, 0.66752620265286, 0.9632843648472451], 
             UndirectedEdge[78, 176] -> 
             RGBColor[
              0.7204501623391966, 0.7810145638880723, 0.9732231476663946], 
             UndirectedEdge[131, 143] -> 
             RGBColor[
              0.7600141252473882, 0.8111262142370081, 0.9403772508591528], 
             UndirectedEdge[230, 289] -> 
             RGBColor[
              0.47745883836829284`, 0.5840004339526917, 0.9527417488941254], 
             UndirectedEdge[35, 126] -> 
             RGBColor[
              0.49906652012115216`, 0.6041343053950634, 0.9537266676698446], 
             UndirectedEdge[147, 183] -> 
             RGBColor[
              0.6614476507361964, 0.7291129796816198, 0.9469651641624033], 
             UndirectedEdge[66, 258] -> 
             RGBColor[
              0.5542936017283033, 0.6490395423820556, 0.9580551692538688], 
             UndirectedEdge[60, 232] -> 
             RGBColor[
              0.40950333598576016`, 0.5245700285384647, 0.9480141538395224], 
             UndirectedEdge[39, 127] -> 
             RGBColor[
              0.642492475347131, 0.7062971189729114, 0.7563633986984937], 
             UndirectedEdge[113, 258] -> 
             RGBColor[
              0.4205902705932881, 0.5335425084626513, 0.9488895424567002], 
             UndirectedEdge[45, 223] -> 
             RGBColor[
              0.3382344559127318, 0.4661500176776401, 0.9428181391767707], 
             UndirectedEdge[40, 80] -> 
             RGBColor[
              0.6136651101148413, 0.6945428819016009, 0.9643959445421617], 
             UndirectedEdge[18, 198] -> 
             RGBColor[
              0.5144611081700484, 0.6119902186320151, 0.9566472002897588], 
             UndirectedEdge[13, 58] -> 
             RGBColor[
              0.48775152960536894`, 0.5950176905464697, 0.9528167335847098], 
             UndirectedEdge[16, 195] -> 
             RGBColor[
              0.645629875704669, 0.7224388891704292, 0.9657593376284574], 
             UndirectedEdge[17, 90] -> 
             RGBColor[
              0.32278209541883807`, 0.4488770386320784, 0.9419759208798562], 
             UndirectedEdge[8, 273] -> 
             RGBColor[
              0.5157002533964201, 0.6171169689421402, 0.955180186772024], 
             UndirectedEdge[85, 256] -> 
             RGBColor[
              0.40563556185171407`, 0.5256715457299592, 0.9470929500041588], 
             UndirectedEdge[149, 227] -> 
             RGBColor[
              0.6962242306792699, 0.7626149275975614, 0.9703567827949094], 
             UndirectedEdge[182, 208] -> 
             RGBColor[
              0.3489661328961344, 0.4717472552409765, 0.9436373541000163], 
             UndirectedEdge[82, 100] -> 
             RGBColor[
              0.7452814340621947, 0.8005423607985177, 0.9759046264319173], 
             UndirectedEdge[227, 264] -> 
             RGBColor[
              0.7248315753610184, 0.7849632026868156, 0.9732080955619506], 
             UndirectedEdge[74, 259] -> 
             RGBColor[
              0.49780276929276285`, 0.6023804712701164, 0.9538282916421494], 
             UndirectedEdge[96, 105] -> 
             RGBColor[
              0.3118597504125189, 0.44293241666677863`, 0.9411512293606585], 
             UndirectedEdge[60, 100] -> 
             RGBColor[
              0.5456843048414332, 0.6420501273248895, 0.9573774138660407], 
             UndirectedEdge[73, 87] -> 
             RGBColor[
              0.5253254807608696, 0.625521916781715, 0.955774692657589], 
             UndirectedEdge[68, 223] -> 
             RGBColor[
              0.3416574872334741, 0.4691148753611104, 0.9430362517056607], 
             UndirectedEdge[162, 191] -> 
             RGBColor[
              0.4283739595309747, 0.5454577258696578, 0.9485165877984626], 
             UndirectedEdge[87, 149] -> 
             RGBColor[
              0.6263604753499661, 0.7065303460112469, 0.9644234085579615], 
             UndirectedEdge[60, 256] -> 
             RGBColor[
              0.4959984153805128, 0.6017128839367019, 0.9534659586422669], 
             UndirectedEdge[145, 169] -> 
             RGBColor[
              0.532758720266972, 0.6178826488488505, 0.95990863155092], 
             UndirectedEdge[144, 235] -> 
             RGBColor[
              0.4156541095057213, 0.5344404310960347, 0.9477060902025752], 
             UndirectedEdge[36, 88] -> 
             RGBColor[
              0.5047446349532001, 0.6086237303716077, 0.9542069156703971], 
             UndirectedEdge[38, 123] -> 
             RGBColor[
              0.5730548481133518, 0.6580391380220021, 0.9623729826526968], 
             UndirectedEdge[183, 244] -> 
             RGBColor[
              0.5071448983944421, 0.6080957729110819, 0.9551472414164259], 
             UndirectedEdge[2, 32] -> 
             RGBColor[
              0.34876385424927736`, 0.4765034539948867, 0.9434439022863649], 
             UndirectedEdge[106, 151] -> 
             RGBColor[
              0.882762659392468, 0.9093549989182408, 0.9886798845760245], 
             UndirectedEdge[164, 277] -> 
             RGBColor[
              0.5381425895824721, 0.6327286238601149, 0.958060214728558], 
             UndirectedEdge[296, 299] -> 
             RGBColor[
              0.6558787715211319, 0.7258492515975854, 0.9693740391899623], 
             UndirectedEdge[75, 174] -> 
             RGBColor[
              0.5436576000541046, 0.6404047570765259, 0.957217864241118], 
             UndirectedEdge[31, 66] -> 
             RGBColor[
              0.36754093390670217`, 0.47860555896574686`, 0.945793704392059], 
             UndirectedEdge[2, 268] -> 
             RGBColor[
              0.6829009296085033, 0.7454876548369898, 0.8971880136513636], 
             UndirectedEdge[46, 264] -> 
             RGBColor[
              0.6627292987304381, 0.7351797391587556, 0.9678857333593993], 
             UndirectedEdge[71, 160] -> 
             RGBColor[
              0.35943825717782063`, 0.4857490853005, 0.9441240658019677], 
             UndirectedEdge[50, 114] -> 
             RGBColor[
              0.7798266350911789, 0.46638172045332676`, 0.5695853003048795], 
             UndirectedEdge[126, 197] -> 
             RGBColor[
              0.42469743054392817`, 0.542273301248798, 0.948282322622435], 
             UndirectedEdge[265, 269] -> 
             RGBColor[
              0.6807943342882671, 0.7436630278511606, 0.8970537832603472], 
             UndirectedEdge[144, 257] -> 
             RGBColor[
              0.6375752646513686, 0.7119548771682966, 0.9673904225282157], 
             UndirectedEdge[86, 107] -> 
             RGBColor[
              0.5199046586989597, 0.6203212077455149, 0.9555689442721043], 
             UndirectedEdge[149, 245] -> 
             RGBColor[
              0.6404898279857845, 0.7180011910010868, 0.9655357229549771], 
             UndirectedEdge[143, 283] -> 
             RGBColor[
              0.6615599665794814, 0.7340113230745497, 0.9679434788191261], 
             UndirectedEdge[66, 154] -> 
             RGBColor[
              0.49669204501362335`, 0.601982910855946, 0.953601546139587], 
             UndirectedEdge[57, 159] -> 
             RGBColor[
              0.5179891671377657, 0.6195659668853168, 0.9551971511753758], 
             UndirectedEdge[7, 167] -> 
             RGBColor[
              0.6831257527118595, 0.7523822970573008, 0.969051248923354], 
             UndirectedEdge[57, 89] -> 
             RGBColor[
              0.5445765561211107, 0.6411508070102205, 0.9572902078289597], 
             UndirectedEdge[122, 256] -> 
             RGBColor[
              0.4019985089632493, 0.5225213133215644, 0.9468612002102255], 
             UndirectedEdge[39, 232] -> 
             RGBColor[
              0.6387744907081887, 0.7023892813835415, 0.7561516649735713], 
             UndirectedEdge[72, 286] -> 
             RGBColor[
              0.5737609922336857, 0.6592398873224206, 0.9621665150720573], 
             UndirectedEdge[71, 299] -> 
             RGBColor[
              0.6516974405615936, 0.7222275928802381, 0.9691076084786263], 
             UndirectedEdge[90, 158] -> 
             RGBColor[
              0.28129862310100606`, 0.4129461399303157, 0.9393326307061581], 
             UndirectedEdge[52, 236] -> 
             RGBColor[
              0.6119004602462057, 0.6947068628009272, 0.9633426254110209], 
             UndirectedEdge[17, 134] -> 
             RGBColor[
              0.44078895832118625`, 0.5552324190873064, 0.949578038133062], 
             UndirectedEdge[54, 72] -> 
             RGBColor[
              0.6453249107785048, 0.7204137749675623, 0.9669506365984544], 
             UndirectedEdge[170, 192] -> 
             RGBColor[
              0.5671649640223861, 0.6515651216382375, 0.962247459095882], 
             UndirectedEdge[140, 198] -> 
             RGBColor[
              0.29492346413444553`, 0.42642976242338865`, 0.9401391900605596],
              UndirectedEdge[19, 89] -> 
             RGBColor[
              0.5464717039737412, 0.6426893734124239, 0.9574394008100742], 
             UndirectedEdge[239, 295] -> 
             RGBColor[
              0.6402817706094446, 0.7177650483667622, 0.9655653109954769], 
             UndirectedEdge[51, 69] -> 
             RGBColor[
              0.5891199110503238, 0.6717068421198378, 0.9635103630846634], 
             UndirectedEdge[186, 269] -> 
             RGBColor[
              0.38846612210379705`, 0.5108915629164676, 0.945973695686718], 
             UndirectedEdge[37, 282] -> 
             RGBColor[
              0.6387675702659823, 0.7157176014458208, 0.9660054818146404], 
             UndirectedEdge[1, 239] -> 
             RGBColor[
              0.5885949100365967, 0.6758033264871905, 0.9614963319959735], 
             UndirectedEdge[59, 200] -> 
             RGBColor[
              0.3651066785151325, 0.4882225828032798, 0.9445744539654022], 
             UndirectedEdge[145, 221] -> 
             RGBColor[
              0.42466293009097417`, 0.5327860522152933, 0.9495799807050561], 
             UndirectedEdge[75, 297] -> 
             RGBColor[
              0.7181654835024863, 0.7780347944468915, 0.9607712170064664], 
             UndirectedEdge[142, 185] -> 
             RGBColor[
              0.9290512420317718, 0.9457897607529917, 0.9766438050045321], 
             UndirectedEdge[36, 258] -> 
             RGBColor[
              0.5604427789152242, 0.6540317214396734, 0.9585392550072014], 
             UndirectedEdge[13, 289] -> 
             RGBColor[
              0.41140019883459866`, 0.5303710544714411, 0.9475413708092633], 
             UndirectedEdge[53, 170] -> 
             RGBColor[
              0.5892258800487448, 0.671574816266804, 0.9636201477741337], 
             UndirectedEdge[130, 226] -> 
             RGBColor[
              0.5090307886336125, 0.6122931516452927, 0.9544919148039072], 
             UndirectedEdge[224, 249] -> 
             RGBColor[
              0.5964028262633069, 0.6832086786281768, 0.9613818046382261], 
             UndirectedEdge[234, 271] -> 
             RGBColor[
              0.4825147995701544, 0.5879674831033377, 0.9531777941592405], 
             UndirectedEdge[78, 266] -> 
             RGBColor[
              0.6117040975782898, 0.6906342705730693, 0.9652412075038258], 
             UndirectedEdge[127, 232] -> 
             RGBColor[
              0.2874091794240585, 0.4194156487421251, 0.9396788996331975], 
             UndirectedEdge[57, 292] -> 
             RGBColor[
              0.3998755898799966, 0.5196410623422665, 0.9469934049593911], 
             UndirectedEdge[52, 107] -> 
             RGBColor[
              0.6650747586050295, 0.7378761536834628, 0.9675287009617004], 
             UndirectedEdge[26, 130] -> 
             RGBColor[
              0.43334889450223724`, 0.5482925115743346, 0.9492409267299848], 
             UndirectedEdge[51, 58] -> 
             RGBColor[
              0.6684194091041142, 0.7389070325162224, 0.968973580472422], 
             UndirectedEdge[192, 195] -> 
             RGBColor[
              0.4494167792189582, 0.5588039171334883, 0.9509896757928566], 
             UndirectedEdge[118, 266] -> 
             RGBColor[
              0.3887184850839611, 0.5111101470457536, 0.9459897760326581], 
             UndirectedEdge[171, 289] -> 
             RGBColor[
              0.5161443490274096, 0.6148767225406963, 0.9561498183754873], 
             UndirectedEdge[1, 283] -> 
             RGBColor[
              0.6221591713955615, 0.7020239825586482, 0.9648417038923796], 
             UndirectedEdge[44, 59] -> 
             RGBColor[
              0.6379911693851391, 0.7140594437353637, 0.9666139123335463], 
             UndirectedEdge[62, 127] -> 
             RGBColor[
              0.6429981401518263, 0.7073786848596003, 0.8114018920881325], 
             UndirectedEdge[46, 219] -> 
             RGBColor[
              0.7470001353240479, 0.8019380323744507, 0.9760395232103662], 
             UndirectedEdge[55, 252] -> 
             RGBColor[
              0.39763767967222396`, 0.5187841329353992, 0.9465722935087859], 
             UndirectedEdge[55, 144] -> 
             RGBColor[
              0.3681631070806163, 0.49330611176259476`, 0.944680005522692], 
             UndirectedEdge[160, 296] -> 
             RGBColor[
              0.363619588137359, 0.48937074401784736`, 0.9443904965133038], 
             UndirectedEdge[154, 179] -> 
             RGBColor[
              0.6904365226151774, 0.7556275663812374, 0.9693303520150452], 
             UndirectedEdge[6, 145] -> 
             RGBColor[
              0.5267338877018102, 0.6131760038585227, 0.9593081325460862], 
             UndirectedEdge[132, 243] -> 
             RGBColor[
              0.46197456008977, 0.5714206953942805, 0.9515252299594579], 
             UndirectedEdge[53, 59] -> 
             RGBColor[
              0.39546641969873725`, 0.5169548688480174, 0.9464197484593474], 
             UndirectedEdge[4, 228] -> 
             RGBColor[
              0.415207880823226, 0.5221760021756383, 0.949102716895018], 
             UndirectedEdge[71, 98] -> 
             RGBColor[
              0.3788348576306416, 0.5025494457112482, 0.9453600000310811], 
             UndirectedEdge[201, 259] -> 
             RGBColor[
              0.7555759586919695, 0.8087657396668173, 0.973356877380965], 
             UndirectedEdge[34, 187] -> 
             RGBColor[
              0.7340503475536024, 0.7921649775889259, 0.9741269366197831], 
             UndirectedEdge[18, 260] -> 
             RGBColor[
              0.72492843770861, 0.7850388722889354, 0.9732177498955283], 
             UndirectedEdge[263, 289] -> 
             RGBColor[
              0.37529563909444164`, 0.4994839525014877, 0.9451344841555627], 
             UndirectedEdge[173, 209] -> 
             RGBColor[
              0.49561027588077494`, 0.601335082735309, 0.9534527248847836], 
             UndirectedEdge[4, 199] -> 
             RGBColor[
              0.5117633303085515, 0.6135544100875527, 0.9549714916775706], 
             UndirectedEdge[253, 292] -> 
             RGBColor[
              0.5586876652889281, 0.6460107845061667, 0.9612466942861655], 
             UndirectedEdge[128, 209] -> 
             RGBColor[
              0.5720565622969963, 0.662620272844981, 0.960002334387392], 
             UndirectedEdge[44, 137] -> 
             RGBColor[
              0.5802762697230959, 0.6640696984833043, 0.9629363699623628], 
             UndirectedEdge[129, 263] -> 
             RGBColor[
              0.48037525448112733`, 0.5874535042221898, 0.952671442731148], 
             UndirectedEdge[73, 289] -> 
             RGBColor[
              0.4309716157453273, 0.5462600124018548, 0.9490821044409381], 
             UndirectedEdge[128, 276] -> 
             RGBColor[
              0.5546970184717662, 0.6475843084996089, 0.9588961996052903], 
             UndirectedEdge[96, 196] -> 
             RGBColor[
              0.3910153512806416, 0.5104790696562158, 0.9464751116612466], 
             UndirectedEdge[24, 224] -> 
             RGBColor[
              0.6066386060190987, 0.6915185457505517, 0.9621876027154987], 
             UndirectedEdge[88, 278] -> 
             RGBColor[
              0.4559774545245038, 0.5690323363631498, 0.950367784586982], 
             UndirectedEdge[158, 253] -> 
             RGBColor[
              0.5593992358473103, 0.6467117635945722, 0.9612889353925915], 
             UndirectedEdge[67, 110] -> 
             RGBColor[
              0.6695455764611133, 0.7406264249653759, 0.9684818697231804], 
             UndirectedEdge[155, 275] -> 
             RGBColor[
              0.5084538721859213, 0.6108405177513158, 0.9547184537690143], 
             UndirectedEdge[101, 108] -> 
             RGBColor[
              0.5203596454773673, 0.6196780090128112, 0.9559315905637227], 
             UndirectedEdge[102, 210] -> 
             RGBColor[
              0.5284950132308948, 0.6277235759462896, 0.9561268592061394], 
             UndirectedEdge[176, 199] -> 
             RGBColor[
              0.5058537994955314, 0.6087567867522139, 0.954506271764645], 
             UndirectedEdge[62, 226] -> 
             RGBColor[
              0.752658545235028, 0.8024387850715727, 0.8187583158317374], 
             UndirectedEdge[69, 113] -> 
             RGBColor[
              0.3164330175989031, 0.4461616727763934, 0.9414694315430614], 
             UndirectedEdge[51, 258] -> 
             RGBColor[
              0.6932771640447087, 0.7590876778060955, 0.9709304739983022], 
             UndirectedEdge[30, 74] -> 
             RGBColor[
              0.5393960591945369, 0.6359566322012906, 0.9572333550528604], 
             UndirectedEdge[118, 228] -> 
             RGBColor[
              0.31312249634732936`, 0.43788577058122996`, 0.9414565195552889],
              UndirectedEdge[71, 121] -> 
             RGBColor[
              0.36658644568013093`, 0.4919404869028005, 0.9445795420524401], 
             UndirectedEdge[1, 20] -> 
             RGBColor[
              0.40012949716215773`, 0.5207011371275032, 0.9467977370931617], 
             UndirectedEdge[126, 293] -> 
             RGBColor[
              0.6452439594195777, 0.7199438921966315, 0.9672590695204664], 
             UndirectedEdge[112, 159] -> 
             RGBColor[
              0.5735831340797513, 0.6646996537284906, 0.9595737119004599], 
             UndirectedEdge[17, 159] -> 
             RGBColor[
              0.46813903138877627`, 0.5774364405103267, 0.9517311360715615], 
             UndirectedEdge[139, 172] -> 
             RGBColor[
              0.5323680381872588, 0.6214373080133851, 0.9592586190596062], 
             UndirectedEdge[47, 233] -> 
             RGBColor[
              0.43209841666643745`, 0.5414277081508914, 0.9499281885775551], 
             UndirectedEdge[98, 182] -> 
             RGBColor[
              0.32273793233215753`, 0.44902970618015037`, 0.9419661163527666],
              UndirectedEdge[84, 159] -> 
             RGBColor[
              0.6485896737797897, 0.723896597112645, 0.9666385749795643], 
             UndirectedEdge[118, 176] -> 
             RGBColor[
              0.4974645498448679, 0.6014904403607567, 0.9539717161952268], 
             UndirectedEdge[18, 278] -> 
             RGBColor[
              0.5881204038259832, 0.6754560488274347, 0.9614330319709412], 
             UndirectedEdge[155, 197] -> 
             RGBColor[
              0.4078505806440406, 0.5276814066128117, 0.9472088562438985], 
             UndirectedEdge[72, 215] -> 
             RGBColor[
              0.6606508431362051, 0.7328560572809281, 0.9681571501343926], 
             UndirectedEdge[162, 239] -> 
             RGBColor[
              0.5700353100743096, 0.660020588878716, 0.9602328692367439], 
             UndirectedEdge[139, 272] -> 
             RGBColor[
              0.27753023797988546`, 0.40903225492323475`, 0.939116308532536], 
             UndirectedEdge[9, 75] -> 
             RGBColor[
              0.3900718754019299, 0.5100514854029347, 0.9463700370628594], 
             UndirectedEdge[18, 254] -> 
             RGBColor[
              0.6054831804479256, 0.6895519330733006, 0.962799893348567], 
             UndirectedEdge[25, 244] -> 
             RGBColor[
              0.5834759805239307, 0.6725664680575393, 0.9604650810692963], 
             UndirectedEdge[30, 257] -> 
             RGBColor[
              0.7668632901914609, 0.8182748104220512, 0.9772710784275421], 
             UndirectedEdge[29, 270] -> 
             RGBColor[
              0.4703385758657484, 0.5793155782806884, 0.9518784721777456], 
             UndirectedEdge[73, 298] -> 
             RGBColor[
              0.48816482306077325`, 0.595353220792225, 0.9528492695594629], 
             UndirectedEdge[73, 96] -> 
             RGBColor[
              0.3990021885114202, 0.5169631439230788, 0.9471038647448023], 
             UndirectedEdge[108, 205] -> 
             RGBColor[
              0.5687550666266601, 0.6606645235867739, 0.959272588166484], 
             UndirectedEdge[9, 43] -> 
             RGBColor[
              0.3722515520203741, 0.4955023183682117, 0.944989764617718], 
             UndirectedEdge[151, 251] -> 
             RGBColor[
              0.6168606460154483, 0.6956068130884803, 0.9653367468058329], 
             UndirectedEdge[209, 279] -> 
             RGBColor[
              0.3800799382640367, 0.5036278719763227, 0.9454393354680596], 
             UndirectedEdge[53, 68] -> 
             RGBColor[
              0.36551255254806014`, 0.49101033464723903`, 0.9445111145316709],
              UndirectedEdge[282, 295] -> 
             RGBColor[
              0.666986045586541, 0.7386266309388767, 0.9682269435595559], 
             UndirectedEdge[35, 197] -> 
             RGBColor[
              0.4730020535668585, 0.5815585745039143, 0.9520658629089078], 
             UndirectedEdge[116, 168] -> 
             RGBColor[
              0.6992442971898675, 0.7648772607355874, 0.9707240908294177], 
             UndirectedEdge[27, 152] -> 
             RGBColor[
              0.496492153675313, 0.601912314115173, 0.9535604773842838], 
             UndirectedEdge[114, 231] -> 
             RGBColor[
              0.582098436553897, 0.6692271784774465, 0.9615271452615417], 
             UndirectedEdge[83, 155] -> 
             RGBColor[
              0.3993368513310579, 0.5203072421943834, 0.9466663689404705], 
             UndirectedEdge[62, 199] -> 
             RGBColor[
              0.7064681558619851, 0.7639822041361536, 0.8153865003627023], 
             UndirectedEdge[96, 278] -> 
             RGBColor[
              0.37849708554125594`, 0.5003161775875377, 0.9454896279263239], 
             UndirectedEdge[2, 178] -> 
             RGBColor[
              0.5227229335444757, 0.6209726744817472, 0.9564005844578019], 
             UndirectedEdge[6, 213] -> 
             RGBColor[
              0.555954129553478, 0.6438883307149641, 0.9609721820920646], 
             UndirectedEdge[79, 93] -> 
             RGBColor[
              0.6380060925638265, 0.7162428244506429, 0.9651637696463923], 
             UndirectedEdge[270, 272] -> 
             RGBColor[
              0.33631472002509666`, 0.46278248238459374`, 0.9427582347920347],
              UndirectedEdge[161, 186] -> 
             RGBColor[
              0.4008915118955567, 0.5216538110358403, 0.946765430536908], 
             UndirectedEdge[189, 275] -> 
             RGBColor[
              0.6624172800120569, 0.7355533370043589, 0.9674325492026051], 
             UndirectedEdge[260, 261] -> 
             RGBColor[
              0.5476322825745208, 0.6395057223985565, 0.9592753801633275], 
             UndirectedEdge[195, 200] -> 
             RGBColor[
              0.44111795406171206`, 0.5500813257173172, 0.9505170699771631], 
             UndirectedEdge[66, 110] -> 
             RGBColor[
              0.6612320412873521, 0.7338771225908249, 0.9678273977808192], 
             UndirectedEdge[63, 172] -> 
             RGBColor[
              0.7185136901372089, 0.7800276227322696, 0.9725783878068355], 
             UndirectedEdge[4, 236] -> 
             RGBColor[
              0.5575298667026993, 0.6516668880803459, 0.9583099398874824], 
             UndirectedEdge[143, 167] -> 
             RGBColor[
              0.604073856131353, 0.6891027366818505, 0.9622138005679022], 
             UndirectedEdge[135, 249] -> 
             RGBColor[
              0.5753525615491524, 0.6661361546599496, 0.9597130077124776], 
             UndirectedEdge[135, 288] -> 
             RGBColor[
              0.5288418039547065, 0.6283766263590265, 0.9560515105001239], 
             UndirectedEdge[83, 214] -> 
             RGBColor[
              0.6878226545432805, 0.7473046546446837, 0.7690920722191105], 
             UndirectedEdge[36, 290] -> 
             RGBColor[
              0.6332867597174545, 0.7122344513401324, 0.9649132665161042], 
             UndirectedEdge[79, 119] -> 
             RGBColor[
              0.5195877345788624, 0.617227254814139, 0.956636701259206], 
             UndirectedEdge[145, 264] -> 
             RGBColor[
              0.507702833142778, 0.598308799395635, 0.9574112948829582], 
             UndirectedEdge[54, 238] -> 
             RGBColor[
              0.5746353611580233, 0.6651905615435665, 0.9599049629236844], 
             UndirectedEdge[177, 273] -> 
             RGBColor[
              0.41408674557543024`, 0.5330828592376182, 0.9476062191589025], 
             UndirectedEdge[98, 208] -> 
             RGBColor[
              0.41629541428473354`, 0.5349958970626997, 0.9477469535760104], 
             UndirectedEdge[125, 170] -> 
             RGBColor[
              0.6035336207604806, 0.6839674621433518, 0.9645318243604473], 
             UndirectedEdge[22, 217] -> 
             RGBColor[
              0.8331882296063449, 0.8702048403335727, 0.9838508174995], 
             UndirectedEdge[78, 236] -> 
             RGBColor[
              0.6784300947211315, 0.7469007800132532, 0.969915174018921], 
             UndirectedEdge[86, 240] -> 
             RGBColor[
              0.6834499476892812, 0.749293921601927, 0.9647662679309306], 
             UndirectedEdge[59, 170] -> 
             RGBColor[
              0.6415764563302444, 0.716918254225369, 0.966955880202994], 
             UndirectedEdge[95, 109] -> 
             RGBColor[
              0.5254979277904712, 0.6239553011380468, 0.9563323164123911], 
             UndirectedEdge[30, 252] -> 
             RGBColor[
              0.5550234505586309, 0.6494409209743877, 0.9582433128957188], 
             UndirectedEdge[116, 119] -> 
             RGBColor[
              0.554887572137617, 0.6448037562037401, 0.9601550591713253], 
             UndirectedEdge[6, 231] -> 
             RGBColor[
              0.6129220326102522, 0.6933068059846776, 0.9645993532535571], 
             UndirectedEdge[214, 275] -> 
             RGBColor[
              0.7969396753981439, 0.837837930201616, 0.7771441570476543], 
             UndirectedEdge[157, 257] -> 
             RGBColor[
              0.6231440827131257, 0.699455312705685, 0.9664708803761041], 
             UndirectedEdge[128, 173] -> 
             RGBColor[
              0.6166577389786045, 0.6988922094052433, 0.9634961803895239], 
             UndirectedEdge[14, 113] -> 
             RGBColor[
              0.3132554863995713, 0.443409454958894, 0.9412669620648205], 
             UndirectedEdge[213, 231] -> 
             RGBColor[
              0.3648946998686622, 0.4903994407785258, 0.944474518751832], 
             UndirectedEdge[29, 148] -> 
             RGBColor[
              0.5080828118228203, 0.6115235413644229, 0.9544172865968081], 
             UndirectedEdge[109, 154] -> 
             RGBColor[
              0.5482501803111444, 0.6436621587099917, 0.9577820698239816], 
             UndirectedEdge[74, 123] -> 
             RGBColor[
              0.374210646947409, 0.49854418683701895`, 0.9450653494153746], 
             UndirectedEdge[189, 216] -> 
             RGBColor[
              0.6310948483812101, 0.7101243759469729, 0.9649667326467772], 
             UndirectedEdge[29, 162] -> 
             RGBColor[
              0.48599603991783963`, 0.5928772866755845, 0.952876151941793], 
             UndirectedEdge[73, 140] -> 
             RGBColor[
              0.3890878627605445, 0.5065425589543495, 0.9465392585602206], 
             UndirectedEdge[9, 295] -> 
             RGBColor[
              0.4308343320789034, 0.5431442840610485, 0.9495790069702695], 
             UndirectedEdge[169, 221] -> 
             RGBColor[
              0.7079353372493937, 0.7711123892682143, 0.9719693637575935], 
             UndirectedEdge[22, 61] -> 
             RGBColor[
              0.700901724892288, 0.7660602153450645, 0.9709657536997793], 
             UndirectedEdge[11, 143] -> 
             RGBColor[
              0.5488568553874041, 0.6446257467798822, 0.9576271686664551], 
             UndirectedEdge[100, 299] -> 
             RGBColor[
              0.7459227560395614, 0.801051325532729, 0.9758823093425815], 
             UndirectedEdge[181, 232] -> 
             RGBColor[
              0.5429266644126531, 0.6304411170068769, 0.9601914244321038], 
             UndirectedEdge[49, 292] -> 
             RGBColor[
              0.4637476509159343, 0.5714952788947997, 0.952021647575209], 
             UndirectedEdge[4, 39] -> 
             RGBColor[
              0.7996586258825229, 0.839924523452416, 0.7674596487433745], 
             UndirectedEdge[33, 75] -> 
             RGBColor[
              0.6115528106583277, 0.69407290880885, 0.9635557275822797], 
             UndirectedEdge[223, 271] -> 
             RGBColor[
              0.32282313777864446`, 0.45280150850526546`, 0.9418361436129603],
              UndirectedEdge[21, 34] -> 
             RGBColor[
              0.6318498425717443, 0.7103490588349524, 0.9652916208979954], 
             UndirectedEdge[51, 165] -> 
             RGBColor[
              0.6838409457625572, 0.7514269307078556, 0.9701876203291246], 
             UndirectedEdge[36, 138] -> 
             RGBColor[
              0.5399018168062094, 0.6373556430397774, 0.9569221952259563], 
             UndirectedEdge[50, 205] -> 
             RGBColor[
              0.652465579142112, 0.3645157713146789, 0.5585118808818876], 
             UndirectedEdge[237, 283] -> 
             RGBColor[
              0.8131613931294602, 0.8541782192555855, 0.9819559690887693], 
             UndirectedEdge[140, 245] -> 
             RGBColor[
              0.42190802152191886`, 0.5331874423681361, 0.9491229816821188], 
             UndirectedEdge[19, 49] -> 
             RGBColor[
              0.5576879773937683, 0.6517952494621613, 0.958322386940262], 
             UndirectedEdge[235, 292] -> 
             RGBColor[
              0.3714388889196525, 0.49605877691067435`, 0.9448918349851523], 
             UndirectedEdge[15, 115] -> 
             RGBColor[
              0.5916715719761331, 0.6775832798934802, 0.9621099083491721], 
             UndirectedEdge[69, 110] -> 
             RGBColor[
              0.5605079148427342, 0.6492834536982567, 0.960677555165135], 
             UndirectedEdge[34, 50] -> 
             RGBColor[
              0.7838295826221938, 0.46950885348808363`, 0.5699842767050995], 
             UndirectedEdge[126, 275] -> 
             RGBColor[
              0.5253007220858089, 0.6254324123873021, 0.9557919201475507], 
             UndirectedEdge[59, 225] -> 
             RGBColor[
              0.4724731288032328, 0.5824646313347996, 0.9516552319446818], 
             UndirectedEdge[82, 228] -> 
             RGBColor[
              0.5797330160702974, 0.6521952109661017, 0.9648689336223386], 
             UndirectedEdge[19, 280] -> 
             RGBColor[
              0.47025249249444845`, 0.5805797351613956, 0.9515030952575538], 
             UndirectedEdge[194, 283] -> 
             RGBColor[
              0.6721300200618961, 0.7425925686670569, 0.9687755921486435], 
             UndirectedEdge[63, 283] -> 
             RGBColor[
              0.7153032772859222, 0.777519623812803, 0.9722584038568329], 
             UndirectedEdge[36, 245] -> 
             RGBColor[
              0.5677169108552201, 0.6599371894444716, 0.9591119013195412], 
             UndirectedEdge[3, 55] -> 
             RGBColor[
              0.47640807003342556`, 0.5827334843962693, 0.952773387183467], 
             UndirectedEdge[137, 192] -> 
             RGBColor[
              0.31569060401033533`, 0.4469554289673916, 0.9413695174099121], 
             UndirectedEdge[54, 251] -> 
             RGBColor[
              0.4421873077754202, 0.5566109721486769, 0.9496208940521441], 
             UndirectedEdge[252, 292] -> 
             RGBColor[
              0.3815202044324696, 0.5047393335352729, 0.9455484017789695], 
             UndirectedEdge[100, 121] -> 
             RGBColor[
              0.46081176115809874`, 0.5707642195552914, 0.9513542429163953], 
             UndirectedEdge[142, 239] -> 
             RGBColor[
              0.8335965154048213, 0.8705407084281921, 0.9673099807032894], 
             UndirectedEdge[85, 299] -> 
             RGBColor[
              0.6451910748557337, 0.7165921059252711, 0.9686930286092024], 
             UndirectedEdge[120, 130] -> 
             RGBColor[
              0.4427241790026586, 0.5564129117930994, 0.949838311568113], 
             UndirectedEdge[9, 297] -> 
             RGBColor[
              0.6222922904744006, 0.694535155865657, 0.9544667317256252], 
             UndirectedEdge[237, 239] -> 
             RGBColor[
              0.7795971317704954, 0.8279575631841278, 0.9786105971923633], 
             UndirectedEdge[169, 213] -> 
             RGBColor[
              0.5619789621186398, 0.6485949757052919, 0.9615726810968985], 
             UndirectedEdge[46, 50] -> 
             RGBColor[
              0.6884291221419363, 0.39371259566108535`, 0.5613430627256325], 
             UndirectedEdge[105, 171] -> 
             RGBColor[
              0.5046649698184947, 0.6049338612403095, 0.9554183624831117], 
             UndirectedEdge[34, 114] -> 
             RGBColor[
              0.7463372177133727, 0.8017635739414104, 0.9753515770099792], 
             UndirectedEdge[60, 240] -> 
             RGBColor[
              0.7391774600781544, 0.7953358681361286, 0.9689323432584322], 
             UndirectedEdge[19, 84] -> 
             RGBColor[
              0.6244164229998548, 0.7042716631369563, 0.9647355681286325], 
             UndirectedEdge[19, 48] -> 
             RGBColor[
              0.4157729244190619, 0.5333922715172046, 0.9480317053541807], 
             UndirectedEdge[5, 77] -> 
             RGBColor[
              0.48030469540941306`, 0.5859842338486527, 0.9530560243717467]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {3}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.2494863131085524, 0.3795563117959294, 0.9375192484983826], 
             160 -> RGBColor[
              0.3512740128151147, 0.4786776271803771, 0.9436038473705339], 
             245 -> RGBColor[
              0.5722749921580623, 0.6636376451853415, 0.9594707301765029], 
             155 -> RGBColor[
              0.4170681972984467, 0.5356652428679743, 0.9477961946262989], 
             213 -> RGBColor[
              0.307926796811888, 0.4409809655088122, 0.9408473475903395], 27 -> 
             RGBColor[
              0.4459002681090488, 0.5606381334621033, 0.9496333486831514], 19 -> 
             RGBColor[
              0.49571106421046124`, 0.6014795993118314, 0.9534433373055585], 
             164 -> RGBColor[
              0.7052786750089274, 0.7696883283242155, 0.9712592451870967], 
             190 -> 
             RGBColor[
              0.6965474327457811, 0.7628674155083467, 0.9703889965564042], 
             103 -> RGBColor[
              0.31606018401044617`, 0.448177178568271, 0.9413600533374666], 
             138 -> RGBColor[
              0.5166448040600409, 0.6184745523759533, 0.9550913179893331], 
             291 -> RGBColor[
              0.32939249536673804`, 0.4597249565636382, 0.9422095764277896], 
             28 -> RGBColor[
              0.513531505367556, 0.6159470362448862, 0.9548462277118719], 114 -> 
             RGBColor[
              0.7423342701823578, 0.7986364409066535, 0.9749526006097591], 
             195 -> RGBColor[
              0.5998395470733959, 0.6860157926346572, 0.9616407129117296], 93 -> 
             RGBColor[
              0.5841523803218054, 0.6732802439669072, 0.9604057616810592], 34 -> 
             RGBColor[
              0.7503401652443876, 0.8048907069761673, 0.9757505534101992], 
             161 -> RGBColor[
              0.3984723439105429, 0.5195584493181398, 0.9466112832920892], 22 -> 
             RGBColor[
              0.7730752374249796, 0.8226515181565941, 0.9780165729338316], 
             124 -> RGBColor[
              0.29979001716717757`, 0.43242869420059504`, 0.94038397002686], 
             84 -> RGBColor[
              0.7531217817892484, 0.8070637269620813, 0.9760277989517064], 46 -> 
             RGBColor[
              0.5595392442838725, 0.6532981913221707, 0.958468125451265], 241 -> 
             RGBColor[
              0.37979315413993503`, 0.503379473982215, 0.945421061837265], 
             185 -> RGBColor[
              0.9040030126888274, 0.9262914800827268, 0.9907058084349184], 
             121 -> RGBColor[
              0.3655703898197353, 0.4910604303849782, 0.9445147998714786], 
             126 -> RGBColor[
              0.45076189709822184`, 0.5648490321399471, 0.9499431273833717], 
             236 -> RGBColor[
              0.5096002682716141, 0.6127554808701877, 0.9545367463270833], 78 -> 
             RGBColor[
              0.8472599211706487, 0.8810460791563186, 0.9852936017107587], 
             254 -> RGBColor[
              0.50035002193887, 0.6052457141784177, 0.9538085330510009], 290 -> 
             RGBColor[
              0.7034146898825311, 0.7682321689766631, 0.9710734605696288], 
             251 -> RGBColor[
              0.4011814167269004, 0.5219049120297097, 0.9467839030164085], 
             165 -> RGBColor[
              0.5388542917137672, 0.6365052149792653, 0.9568397302134684], 
             100 -> RGBColor[
              0.5560531324964622, 0.6504680087256047, 0.9581936859613118], 
             235 -> RGBColor[
              0.4350473665845118, 0.5512378956442405, 0.9489418113948519], 70 -> 
             RGBColor[
              0.7576112038248469, 0.810570897577162, 0.9764752625841806], 234 -> 
             RGBColor[
              0.6147890363710855, 0.6981524615133397, 0.9628175914710274], 
             257 -> RGBColor[
              0.8788896768758063, 0.9062667877887647, 0.988310476046133], 135 -> 
             RGBColor[
              0.6013701316781935, 0.6872583901688826, 0.9617612061385354], 
             265 -> RGBColor[
              0.9879671042495105, 0.9892921026229266, 0.8490797529289855], 
             111 -> RGBColor[
              0.563158829552378, 0.6562367337036016, 0.9587530724625795], 182 -> 
             RGBColor[
              0.25540865094355836`, 0.38578106435842713`, 0.9378565168767725],
              188 -> RGBColor[
              0.6430425536048963, 0.7210689972713448, 0.9650561302351643], 
             154 -> RGBColor[
              0.4425236148487104, 0.5577134461235258, 0.9494181913232599], 
             269 -> RGBColor[
              0.37362156432702365`, 0.4980339530793946, 0.945027813591709], 
             208 -> RGBColor[
              0.4425236148487104, 0.5577134461235258, 0.9494181913232599], 86 -> 
             RGBColor[
              0.42386045240865766`, 0.541548352855771, 0.9482289911157662], 
             119 -> RGBColor[
              0.3473156643518771, 0.47524910469389925`, 0.9433516249066866], 
             140 -> RGBColor[
              0.27154105088577535`, 0.4027372395509307, 0.9387752331877348], 
             85 -> RGBColor[
              0.3545897701288067, 0.48154956951068884`, 0.9438151244945534], 
             242 -> RGBColor[
              0.3922204970072215, 0.5141434137574445, 0.9462129211357008], 
             117 -> RGBColor[
              0.6244101927178903, 0.7059633496638299, 0.9635750041421048], 47 -> 
             RGBColor[
              0.2712671917352294, 0.4024493962200339, 0.9387596373142495], 81 -> 
             RGBColor[
              0.5233911669566601, 0.6239515536956138, 0.9556224163892966], 
             275 -> RGBColor[
              0.5998395470733959, 0.6860157926346572, 0.9616407129117296], 23 -> 
             RGBColor[
              0.4657801727717393, 0.5771803532705835, 0.9510870678910344], 
             110 -> RGBColor[
              0.771603607396168, 0.8215018695932839, 0.9778698946057242], 6 -> 
             RGBColor[
              0.8039814622950681, 0.8467956959211159, 0.9810970165937897], 
             218 -> RGBColor[
              0.5549478411592206, 0.6495706834252246, 0.9581066733784286], 
             108 -> RGBColor[
              0.6498979749690963, 0.72642450454419, 0.9657394145691928], 297 -> 
             RGBColor[
              0.9503858985749569, 0.9625184649096137, 0.9688679116692323], 
             157 -> RGBColor[
              0.3673984885504451, 0.4926438376226053, 0.9446312847060752], 
             270 -> RGBColor[
              0.39566213260951044`, 0.5171243855345122, 0.9464322191129597], 
             33 -> RGBColor[
              0.7371605528866397, 0.7945946936335307, 0.974436932820859], 252 -> 
             RGBColor[
              0.45520999761014613`, 0.5685990088934376, 0.9502549449824863], 
             260 -> RGBColor[
              0.739240536460239, 0.7962195926096872, 0.9746442461449237], 159 -> 
             RGBColor[
              0.544057565770331, 0.6407294672632088, 0.957249351007422], 183 -> 
             RGBColor[
              0.36118289928036346`, 0.4872602066014608, 0.9442352328540153], 
             99 -> RGBColor[
              0.4111815247330782, 0.5305665029646182, 0.9474211010558138], 17 -> 
             RGBColor[
              0.3922204970072215, 0.5141434137574445, 0.9462129211357008], 
             277 -> RGBColor[
              0.37100650415601666`, 0.4957689193960142, 0.9448611842700193], 
             104 -> RGBColor[
              0.5994811197467129, 0.6857248051838889, 0.9616124961996105], 79 -> 
             RGBColor[
              0.6918598048058476, 0.7592054049343787, 0.9699217776117254], 
             191 -> RGBColor[
              0.4297708583482564, 0.5466676494150113, 0.9486055969558707], 50 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 225 -> 
             RGBColor[
              0.4971292616262287, 0.6026309558630168, 0.953554983001156], 61 -> 
             RGBColor[
              0.6287282123595963, 0.709468912533535, 0.9639149344657271], 196 -> 
             RGBColor[
              0.4906610001737564, 0.5973797298240421, 0.953045777765595], 1 -> 
             RGBColor[
              0.46409626063826687`, 0.5758132775412534, 0.950954504159514], 
             263 -> RGBColor[
              0.3952827213335425, 0.516795758557034, 0.9464080433619553], 201 -> 
             RGBColor[
              0.9395015936803714, 0.9544009681406453, 0.9872922007744009], 
             293 -> RGBColor[
              0.8397260217409336, 0.875038752253316, 0.9845750116575611], 184 -> 
             RGBColor[
              0.29457385240431433`, 0.42694617431087806`, 0.9400869171602393],
              106 -> RGBColor[
              0.9329854434809398, 0.9494012836892309, 0.9934701785567915], 
             206 -> RGBColor[
              0.5375418074267568, 0.6354396811083268, 0.9567364066426066], 
             247 -> RGBColor[
              0.8795077757098662, 0.906759643021198, 0.988369430864709], 220 -> 
             RGBColor[
              0.5450150191219864, 0.6415067710268645, 0.9573247252425315], 
             107 -> RGBColor[
              0.6159488649892617, 0.6990940626352589, 0.9629088974284424], 
             131 -> RGBColor[
              0.9771303994886699, 0.9824644699009597, 0.9235964477052986], 
             127 -> RGBColor[
              0.2911271640630008, 0.4233234863314949, 0.9398906333581198], 
             210 -> RGBColor[
              0.6173544574594875, 0.7002351859238074, 0.9630195508165534], 
             181 -> RGBColor[
              0.8021621340401901, 0.8453744228609985, 0.9809156829559326], 
             194 -> RGBColor[
              0.5640379579709361, 0.656950449758071, 0.9588222806720419], 118 -> 
             RGBColor[
              0.40128869618199126`, 0.5219978321016873, 0.9467907387684233], 
             276 -> RGBColor[
              0.41629001154870654`, 0.5349912174843025, 0.9477466093184481], 
             280 -> RGBColor[
              0.4447939207784357, 0.5596798710109598, 0.9495628532095493], 
             189 -> RGBColor[
              0.7249950129507179, 0.7850908813740606, 0.9732243854934807], 
             168 -> RGBColor[
              0.6360291144563782, 0.7153961137575938, 0.9644896882228713], 41 -> 
             RGBColor[
              0.43914484307735685`, 0.5547869238371863, 0.9492028989737198], 
             14 -> RGBColor[
              0.3430571598906369, 0.47156060216823065`, 0.9430802767680639], 
             77 -> RGBColor[
              0.34328031177666773`, 0.47175388511597066`, 0.9430944958089165],
              51 -> RGBColor[
              0.828827599811347, 0.866348646436446, 0.983535510444781], 179 -> 
             RGBColor[
              0.9383494303816443, 0.953541686638949, 0.9892425127068306], 223 -> 
             RGBColor[
              0.29540571278806554`, 0.42782051231719526`, 0.9401342903784667],
              292 -> RGBColor[
              0.3078304112547931, 0.44087965817710817`, 0.9408418585754527], 
             143 -> RGBColor[
              0.5428978510061064, 0.6397879585730565, 0.9571580540130071], 
             112 -> 
             RGBColor[
              0.6031087023891715, 0.6886698401937724, 0.9618980727934979], 
             197 -> RGBColor[
              0.39863296398963455`, 0.519697570357649, 0.9466215178614982], 
             54 -> RGBColor[
              0.48319319882394, 0.5913170322676442, 0.9524578850878798], 71 -> 
             RGBColor[
              0.3676025015405266, 0.4928205434206228, 0.9446442842334015], 
             177 -> RGBColor[
              0.3966125314314163, 0.5179475732256134, 0.9464927776854869], 
             158 -> RGBColor[
              0.3092535523715575, 0.44228161635391916`, 0.9409263407883047], 
             226 -> RGBColor[
              0.5104479742294041, 0.6134436867554398, 0.9546034808453298], 
             203 -> RGBColor[
              0.6376503255649736, 0.7167122859702797, 0.9646173159000319], 
             115 -> RGBColor[
              0.7408195291035558, 0.7974531136634347, 0.9748016253750843], 
             173 -> RGBColor[
              0.5402114525623832, 0.6376070192955713, 0.9569465708869155], 
             212 -> RGBColor[
              0.3558040782607391, 0.48260134218166734`, 0.9438924991349495], 
             129 -> RGBColor[
              0.5654677876287122, 0.6581112498873457, 0.9589348421003406], 
             279 -> RGBColor[
              0.3091507773289067, 0.4421925977775989, 0.9409197920534674], 26 -> 
             RGBColor[
              0.35908418596665354`, 0.4854424066135235, 0.9441015046974851], 
             40 -> RGBColor[
              0.4372984781268788, 0.553187695318083, 0.9490852502317517], 146 -> 
             RGBColor[
              0.7716978481948389, 0.8215754912214622, 0.9778792876478054], 
             192 -> RGBColor[
              0.2989940113645204, 0.43159204163231946`, 0.9403386386739838], 
             300 -> RGBColor[
              0.3794224707315751, 0.5030584066449836, 0.9453974422182668], 
             221 -> RGBColor[
              0.5998395470733959, 0.6860157926346572, 0.9616407129117296], 62 -> 
             RGBColor[
              0.9948691162406518, 0.9914338833877057, 0.6829131508181451], 
             286 -> RGBColor[
              0.34006536173430174`, 0.46896925697736075`, 0.9428896420350855],
              152 -> RGBColor[
              0.5470840392415772, 0.6431864947682425, 0.9574876060854162], 64 -> 
             RGBColor[
              0.5083117472314141, 0.611709401442542, 0.9544353092307907], 37 -> 
             RGBColor[
              0.5110330311428454, 0.613918662314285, 0.95464953866869], 148 -> 
             RGBColor[
              0.47115060452365426`, 0.5815403117019814, 0.9515098479510848], 
             261 -> RGBColor[
              0.3560240286888025, 0.4827918521874259, 0.9439065141817312], 15 -> 
             RGBColor[
              0.4425236148487104, 0.5577134461235258, 0.9494181913232599], 
             136 -> RGBColor[
              0.31017961268336275`, 0.44308372325086026`, 0.9409853485324899],
              198 -> RGBColor[
              0.3183058773831157, 0.4501222852958466, 0.9415031469333844], 63 -> 
             RGBColor[
              0.6503844724189884, 0.7268045600495633, 0.9657879040884209], 
             171 -> RGBColor[
              0.6769801411994782, 0.7475812986354511, 0.9684387118018046], 59 -> 
             RGBColor[
              0.44781699598023683`, 0.5622983068065824, 0.9497554808882076], 
             229 -> RGBColor[
              0.5688159292654061, 0.6608294221000757, 0.9591984200746281], 
             102 -> RGBColor[
              0.43963556900230216`, 0.5552119659687718, 0.9492341675957253], 
             299 -> RGBColor[
              0.9357923795826606, 0.9516346423398533, 0.9935709327238512], 
             128 -> RGBColor[
              0.693104025394826, 0.7601773995149154, 0.9700457898921323], 12 -> 
             RGBColor[
              0.22445416746317717`, 0.3532459395929378, 0.9360937048356194], 
             222 -> RGBColor[
              0.6467316782223843, 0.7239509694609121, 0.965423827700206], 92 -> 
             RGBColor[
              0.6389855473308331, 0.7177962791508594, 0.9647224294485188], 
             271 -> RGBColor[
              0.3502405627692234, 0.47778250469333566`, 0.9435379968474538], 
             132 -> RGBColor[
              0.5689684868709387, 0.6609532752368888, 0.9592104299681725], 80 -> 
             RGBColor[
              0.7900317421028037, 0.8358980684851188, 0.9797066388525716], 
             244 -> RGBColor[
              0.6531068975085207, 0.7289313392207029, 0.9660592499788365], 
             150 -> RGBColor[
              0.43568297478831697`, 0.5517884275237794, 0.9489823117875521], 
             125 -> RGBColor[
              0.3717313248407092, 0.49639672264254797`, 0.9449073692031141], 
             133 -> RGBColor[
              0.2911271640630008, 0.4233234863314949, 0.9398906333581198], 
             258 -> RGBColor[
              0.5577267282780705, 0.6518267091757451, 0.9583254375518233], 
             255 -> RGBColor[
              0.34777385047176046`, 0.4756459624818382, 0.9433808201210875], 
             176 -> 
             RGBColor[
              0.5936404035077445, 0.6809830486198262, 0.9611526936220304], 
             230 -> RGBColor[
              0.5996091198812448, 0.6858287214594422, 0.9616225728390808], 
             274 -> RGBColor[
              0.7900317421028037, 0.8358980684851188, 0.9797066388525716], 87 -> 
             RGBColor[
              0.5440162868864256, 0.6406959552056618, 0.9572461013824715], 
             130 -> RGBColor[
              0.507613603037821, 0.6111426165351457, 0.9543803487624846], 35 -> 
             RGBColor[
              0.5473711431440824, 0.6434195786501797, 0.9575102079563176], 31 -> 
             RGBColor[
              0.18422139263486803`, 0.31095874234312754`, 0.9338025078282037],
              18 -> RGBColor[
              0.7106163389569812, 0.7738581519681836, 0.9717912536461331], 24 -> 
             RGBColor[
              0.5698065509316947, 0.6616336533957663, 0.959276405440965], 151 -> 
             RGBColor[
              0.8325398753039963, 0.8693087141472507, 0.9838895905952574], 
             137 -> RGBColor[
              0.33238719665615024`, 0.46231881630246374`, 0.9424003961458405],
              296 -> RGBColor[
              0.3759651634596033, 0.5000638608553176, 0.9451771456560736], 
             266 -> RGBColor[
              0.3761482739859309, 0.50022246198982, 0.9451888132968929], 283 -> 
             RGBColor[
              0.7802220821528562, 0.8282346875760429, 0.9787289036252451], 
             284 -> RGBColor[
              0.350038106254015, 0.47760714703562246`, 0.94352509649733], 238 -> 
             RGBColor[
              0.6660775234921065, 0.7390640908194888, 0.9673520407594891], 72 -> 
             RGBColor[
              0.8074566227330697, 0.8495105176674804, 0.981443388109029], 288 -> 
             RGBColor[
              0.45631347623121943`, 0.5694948625491703, 0.9503418148617125], 
             172 -> RGBColor[
              0.7866429078554295, 0.8332506854149759, 0.97936887152525], 243 -> 
             RGBColor[
              0.35498063330860125`, 0.4818881155516722, 0.9438400299507431], 
             88 -> RGBColor[
              0.44633044035402236`, 0.5610107270396137, 0.9496607588782147], 
             273 -> RGBColor[
              0.43156095971944425`, 0.5482181452496232, 0.9487196606323183], 
             202 -> RGBColor[
              0.33566974592466065`, 0.46516199549312404`, 0.9426095572825857],
              98 -> RGBColor[
              0.3900672137207567, 0.5122783480018736, 0.9460757158287608], 30 -> 
             RGBColor[
              0.6548369035071157, 0.7302828330553378, 0.9662316808089513], 
             116 -> RGBColor[
              0.7624594799233567, 0.814358407713581, 0.976958493435964], 240 -> 
             RGBColor[
              0.9430394429699048, 0.9570394903480829, 0.9813035447460949], 73 -> 
             RGBColor[
              0.5066346746353138, 0.6103478783577683, 0.9543032839327064], 29 -> 
             RGBColor[
              0.5450150191219864, 0.6415067710268645, 0.9573247252425315], 75 -> 
             RGBColor[
              0.48594506843001567`, 0.5935511239841693, 0.9526745223437005], 
             200 -> RGBColor[
              0.2823963610500282, 0.4141468587999772, 0.9393934270425967], 
             156 -> RGBColor[
              0.8332693905629748, 0.869890409812596, 0.9839591724119047], 25 -> 
             RGBColor[
              0.5138450635393406, 0.6162015968943757, 0.9548709121597562], 38 -> 
             RGBColor[
              0.8216436172138438, 0.8606203337172098, 0.9828502957714143], 3 -> 
             RGBColor[
              0.6127507783325494, 0.6964977118151778, 0.9626571323318486], 57 -> 
             RGBColor[
              0.49192076850520017`, 0.5984024665074248, 0.9531449513433297], 
             227 -> RGBColor[
              0.6837437975450333, 0.7528651183782908, 0.9691128498563675], 39 -> 
             RGBColor[
              0.9938577866312612, 0.9892707516143279, 0.5728361640388675], 
             109 -> RGBColor[
              0.6539767457735782, 0.7296108712964575, 0.9661459483247032], 
             256 -> RGBColor[
              0.4566813535746214, 0.5697935219492295, 0.9503707755137643], 
             287 -> RGBColor[
              0.6358084712927038, 0.7152169856974616, 0.9644723183847843], 
             239 -> RGBColor[
              0.7130935594349265, 0.7757933754331275, 0.9720381598324331], 
             285 -> RGBColor[
              0.4183918297159575, 0.5368117067403225, 0.9478805353135006], 
             216 -> RGBColor[
              0.5371946838117023, 0.635157870519885, 0.9567090798000738], 21 -> 
             RGBColor[
              0.5133595198991008, 0.6158074106937373, 0.9548326883857915], 
             175 -> RGBColor[
              0.6053149922067431, 0.6904610056599008, 0.9620717600098431], 7 -> 
             RGBColor[
              0.7010016441671194, 0.7663470793239568, 0.970832950723911], 13 -> 
             RGBColor[
              0.4674918408138564, 0.5785699624969407, 0.9512218166693565], 
             294 -> RGBColor[
              0.48973938588581156`, 0.596631521826838, 0.9529732249128636], 
             193 -> 
             RGBColor[
              0.2906316100264923, 0.42280262761918375`, 0.9398624122888473], 
             60 -> RGBColor[
              0.5353154771864042, 0.6336322459241742, 0.9565611417707697], 65 -> 
             RGBColor[
              0.8239065495987578, 0.862424734575277, 0.9830661362824309], 69 -> 
             RGBColor[
              0.34941222228930047`, 0.4770650378032295, 0.9434852157245458], 
             217 -> RGBColor[
              0.89330122178771, 0.9177581625105512, 0.9896850620651684], 214 -> 
             RGBColor[
              0.9940398037228919, 0.9896600677685748, 0.5926476011835788], 
             170 -> RGBColor[
              0.8353359166802519, 0.8715382016441556, 0.9841562795177803], 74 -> 
             RGBColor[
              0.4239552148819582, 0.5416304313472435, 0.9482350292967697], 
             246 -> RGBColor[
              0.5852478178212757, 0.6741695694778742, 0.9604919985337372], 
             264 -> RGBColor[
              0.7659193531770035, 0.8170612869953405, 0.9773033412675337], 
             278 -> RGBColor[
              0.4656244686949852, 0.5770539456866858, 0.9510748102957495], 45 -> 
             RGBColor[
              0.3810631990373981, 0.504479523038085, 0.9455019879750748], 237 -> 
             RGBColor[
              0.8461007041060643, 0.880121750935128, 0.9851830345522934], 228 -> 
             RGBColor[
              0.2249562965126674, 0.35377370906077266`, 0.9361223003421545], 
             180 -> RGBColor[
              0.43610069461101075`, 0.552150235438988, 0.949008928525279], 53 -> 
             RGBColor[
              0.34311584341723766`, 0.47161143088945245`, 0.9430840160304872],
              48 -> RGBColor[
              0.3358347846276625, 0.4653049437225778, 0.942620073402803], 5 -> 
             RGBColor[
              0.6173290790421584, 0.7002145825813348, 0.9630175529345771], 
             101 -> RGBColor[
              0.3908213159856385, 0.5129315134814324, 0.9461237665582527], 
             267 -> RGBColor[
              0.3174122825033774, 0.44934829832440176`, 0.9414462078578225], 
             120 -> RGBColor[
              0.3778347549674962, 0.5016832070510531, 0.9452962743737416], 
             147 -> RGBColor[
              0.9617124021920294, 0.9709657527617788, 0.9496950954707911], 89 -> 
             RGBColor[
              0.5972323437370213, 0.6838991475130164, 0.9614354643145897], 43 -> 
             RGBColor[
              0.4503044216669041, 0.5644527899147234, 0.9499139774534178], 
             199 -> RGBColor[
              0.41806719548331833`, 0.5365305248846015, 0.9478598499072596], 
             268 -> RGBColor[
              0.9879671042495105, 0.9892921026229266, 0.8490797529289855], 
             169 -> RGBColor[
              0.8160311274253916, 0.8562089859017716, 0.9822980146034574], 20 -> 
             RGBColor[
              0.33616273368604854`, 0.46558899671375287`, 0.9426409700268094],
              4 -> RGBColor[
              0.6054594651337846, 0.6905782952905041, 0.9620831334478815], 
             167 -> RGBColor[
              0.6652498612565995, 0.7384175147906447, 0.9672695471227971], 
             142 -> RGBColor[
              0.9540994713747161, 0.9652880414232566, 0.9625818015741459], 16 -> 
             RGBColor[
              0.6914202043359422, 0.7588619857062013, 0.9698779623451852], 
             281 -> RGBColor[
              0.22445416746317717`, 0.3532459395929378, 0.9360937048356194], 
             289 -> RGBColor[
              0.35530855685534085`, 0.48217214644594136`, 0.94386092494917], 
             178 -> RGBColor[
              0.6676111121214553, 0.7402621419124413, 0.967504894541862], 58 -> 
             RGBColor[
              0.5080112183968815, 0.6114654185959987, 0.9544116505000629], 
             186 -> RGBColor[
              0.40331067988057046`, 0.5237491727535408, 0.9469195777817269], 
             122 -> RGBColor[
              0.3473156643518771, 0.47524910469389925`, 0.9433516249066866], 
             249 -> RGBColor[
              0.5493349914201112, 0.6450139191510165, 0.9576648092864198], 
             113 -> RGBColor[
              0.2834538129085057, 0.41525830774955735`, 0.9394536473615771], 
             52 -> RGBColor[
              0.7142006522207973, 0.7766582447316667, 0.9721485044949585], 
             187 -> RGBColor[
              0.7177605298628171, 0.7794392482016846, 0.972503319829367], 259 -> 
             RGBColor[
              0.5716503237035675, 0.6631305111929894, 0.959421553987529], 42 -> 
             RGBColor[
              0.5572469067758978, 0.651437168464569, 0.9582876642455282], 134 -> 
             RGBColor[
              0.489357419635151, 0.5963214244171682, 0.9529431551304232], 248 -> 
             RGBColor[
              0.4170681972984467, 0.5356652428679743, 0.9477961946262989], 
             174 -> RGBColor[
              0.6013701316781935, 0.6872583901688826, 0.9617612061385354], 
             215 -> RGBColor[
              0.5138450635393406, 0.6162015968943757, 0.9548709121597562], 83 -> 
             RGBColor[
              0.3816055053636691, 0.5049492415207925, 0.9455365432546421], 95 -> 
             RGBColor[
              0.3970191098073641, 0.518299730979636, 0.9465186845000791], 166 -> 
             RGBColor[
              0.5474703428084129, 0.6435001134065771, 0.957518017317274], 233 -> 
             RGBColor[
              0.5929296415976455, 0.6804060200817488, 0.9610967398408607], 
             295 -> RGBColor[
              0.5674699817839628, 0.659736721300397, 0.9590924621585208], 141 -> 
             RGBColor[
              0.3409633667800214, 0.4697470638129172, 0.9429468621225241], 
             205 -> RGBColor[
              0.487612158284224, 0.5949045426293578, 0.9528057617637752], 224 -> 
             RGBColor[
              0.6434706611065025, 0.7214034381053371, 0.9650987999900325], 
             231 -> RGBColor[
              0.4218626029254364, 0.5398179160482395, 0.9481016899133243], 68 -> 
             RGBColor[
              0.3879092616788826, 0.5104092384050256, 0.9459382130328546], 10 -> 
             RGBColor[
              0.5123118246229064, 0.6149568444703883, 0.9547502099758153], 
             250 -> RGBColor[
              0.9784329619982919, 0.9834359188878854, 0.9213915491392202], 
             282 -> RGBColor[
              0.7665021093891191, 0.8175165405773565, 0.977361424960591], 232 -> 
             RGBColor[
              0.2836911947851162, 0.41550781115275526`, 0.9394671659082751], 
             253 -> RGBColor[
              0.809544919323063, 0.8511419108352252, 0.9816515299968783], 55 -> 
             RGBColor[
              0.34006536173430174`, 0.46896925697736075`, 0.9428896420350855],
              91 -> RGBColor[
              0.5841523803218054, 0.6732802439669072, 0.9604057616810592], 
             105 -> RGBColor[
              0.33234979843751117`, 0.4622864238451677, 0.9423980131644188], 
             36 -> RGBColor[
              0.563158829552378, 0.6562367337036016, 0.9587530724625795], 123 -> 
             RGBColor[
              0.32446607901285984`, 0.45545794232679443`, 0.9418956695339794],
              94 -> RGBColor[
              0.27809316851908805`, 0.4096239306117943, 0.9391483665939625], 
             96 -> RGBColor[
              0.2913697023875267, 0.42357840948838954`, 0.9399044455568983], 
             2 -> RGBColor[
              0.3778347549674962, 0.5016832070510531, 0.9452962743737416], 
             262 -> RGBColor[
              0.50035002193887, 0.6052457141784177, 0.9538085330510009], 272 -> 
             RGBColor[
              0.2769673074406829, 0.4084405792346752, 0.9390842504711095], 97 -> R\
GBColor[0.31017961268336275`, 0.44308372325086026`, 0.9409853485324899], 209 -> 
             RGBColor[
              0.45100909919916665`, 0.5650631461750466, 0.9499588788826517], 
             66 -> RGBColor[
              0.5508604751785363, 0.6462523755883661, 0.9577849009559142], 
             139 -> RGBColor[
              0.27809316851908805`, 0.4096239306117943, 0.9391483665939625], 
             56 -> RGBColor[
              0.23845603573169508`, 0.36796279091287354`, 0.9368910905196036],
              144 -> RGBColor[
              0.39626085242693077`, 0.5176429665478287, 0.9464703690102986], 
             298 -> RGBColor[
              0.4696949714862328, 0.5803585632266816, 0.9513952551862195], 
             204 -> RGBColor[
              0.6212473007922367, 0.7033955715119268, 0.9633260097036624], 
             207 -> RGBColor[
              0.4617165076060126, 0.5738812868230171, 0.9507671612834924], 
             149 -> RGBColor[
              0.7087046638135065, 0.772364736816832, 0.9716007157334514], 219 -> 
             RGBColor[
              0.9344610263642232, 0.9505778734267308, 0.9936109209694675], 9 -> 
             RGBColor[
              0.2941986823738441, 0.42655184682170005`, 0.9400655517820182], 
             11 -> RGBColor[
              0.5548158597687018, 0.6494635349867077, 0.9580962833199032], 44 -> 
             RGBColor[
              0.8281653427900414, 0.8658205806641449, 0.983472343778885], 153 -> 
             RGBColor[
              0.27154105088577535`, 0.4027372395509307, 0.9387752331877348], 
             32 -> RGBColor[
              0.31969295353105853`, 0.4513237009387203, 0.9415915301989881], 
             162 -> RGBColor[
              0.4269770607136929, 0.5442478023243044, 0.9484275786410545], 90 -> 
             RGBColor[
              0.25334369383045463`, 0.38361066350671225`, 0.9377389206240115],
              8 -> RGBColor[
              0.5998395470733959, 0.6860157926346572, 0.9616407129117296], 
             163 -> RGBColor[
              0.4634474550009288, 0.5752865478965016, 0.9509034278030895], 49 -> 
             RGBColor[
              0.6196648905770754, 0.7021108996124912, 0.9632014365749654], 76 -> 
             RGBColor[
              0.3227178159777883, 0.45394368475607055`, 0.9417842717593129], 
             82 -> RGBColor[
              0.9345097356279274, 0.9506167128714307, 0.9936155669025228], 67 -> 
             RGBColor[
              0.5674875455260586, 0.6597509803374679, 0.9590938448406366], 
             211 -> RGBColor[0.178927, 0.305394, 0.933501]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9mHk4FFzYxsmSfR/LzGBWM2NmbHmlLHNH8aZCu0SWIkQLqbSgomQtVNoX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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 9}], {
             RGBColor[
             0.3791474715060555, 0.5011825621814767, 0.9455100279707661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 11}], {
             RGBColor[
             0.5094560602034843, 0.6126384062639806, 0.9545253937397086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 20}], {
             RGBColor[
             0.40012949716215773`, 0.5207011371275032, 0.9467977370931617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 37}], {
             RGBColor[
             0.48756464589055615`, 0.5948659699277692, 0.952802021414102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 43}], {
             RGBColor[
             0.45720034115258545`, 0.5701330337279884, 0.9504342408064659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 75}], {
             RGBColor[
             0.47502066453414127`, 0.5846822007627114, 0.9518145132516073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 102}], {
             RGBColor[
             0.4518659148202845, 0.5655126217550126, 0.9500943358776197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 142}], {
             RGBColor[
             0.7090978660064915, 0.7705506594822551, 0.9567681528668299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 143}], {
             RGBColor[
             0.5034970558221866, 0.6078006180571549, 0.9540562790862606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 174}], {
             RGBColor[
             0.5327331961582302, 0.6315358338550681, 0.9563578551490247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 185}], {
             RGBColor[
             0.6840496366635471, 0.75105237881199, 0.9708301562972161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 237}], {
             RGBColor[
             0.6550984823721656, 0.7279675142381907, 0.9680687693559037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 239}], {
             RGBColor[
             0.5885949100365967, 0.6758033264871905, 0.9614963319959735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 283}], {
             RGBColor[
             0.6221591713955615, 0.7020239825586482, 0.9648417038923796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 295}], {
             RGBColor[
             0.5157831212111148, 0.6177749994208253, 0.9550234831590174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 297}], {
             RGBColor[
             0.7072410796066119, 0.7691658712254336, 0.9599112079143731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 32}], {
             RGBColor[
             0.34876385424927736`, 0.4765034539948867, 0.9434439022863649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 83}], {
             RGBColor[
             0.37972013016558265`, 0.5033162242859228, 0.9454164088141919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 155}], {
             RGBColor[
             0.39745147613297144`, 0.5186742249595138, 0.9465462345000203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 156}], {
             RGBColor[
             0.6055520727652355, 0.6857868084318246, 0.9646277233928231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 178}], {
             RGBColor[
             0.5227229335444757, 0.6209726744817472, 0.9564005844578019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 184}], {
             RGBColor[
             0.33620430368590526`, 0.46431469068096554`, 0.9426915957669905]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 202}], {
             RGBColor[
             0.3567522504460784, 0.4834226012720886, 0.9439529158281637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 208}], {
             RGBColor[
             0.4101791849081033, 0.5296983265872894, 0.9473572328485007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 214}], {
             RGBColor[
             0.6859372793451941, 0.745671637409814, 0.7689719377786602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 268}], {
             RGBColor[
             0.6829009296085033, 0.7454876548369898, 0.8971880136513636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 275}], {
             RGBColor[
             0.48883715102044606`, 0.5938494998428552, 0.9534684936427356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 17}], {
             RGBColor[
             0.5024856376698854, 0.6053205627863112, 0.9544350267337747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 30}], {
             RGBColor[
             0.6337938409198325, 0.7133902724352579, 0.9644444065703999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 38}], {
             RGBColor[
             0.7171971977731966, 0.7785590227661938, 0.9727537140516314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 55}], {
             RGBColor[
             0.47640807003342556`, 0.5827334843962693, 0.952773387183467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 74}], {
             RGBColor[
             0.5183529966072538, 0.6190640715812107, 0.9554460808143092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 90}], {
             RGBColor[
             0.43304723608150203`, 0.540054187660945, 0.9501980264779301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[
             0.46860842867270464`, 0.5759778270709861, 0.952276400932914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 144}], {
             RGBColor[
             0.5045058153797402, 0.6070703391815033, 0.9545637506710736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 157}], {
             RGBColor[
             0.49007463344149726`, 0.5945707747188915, 0.9536442085189618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 229}], {
             RGBColor[
             0.5907833537989777, 0.6786635669576268, 0.9609277762032383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 252}], {
             RGBColor[
             0.5339803879713478, 0.6325483603543077, 0.9564560386571674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 257}], {
             RGBColor[
             0.7458202276041779, 0.8013822498019713, 0.9754838041889908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 259}], {
             RGBColor[
             0.5922005510180585, 0.6798141115040837, 0.9610393431596889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 26}], {
             RGBColor[
             0.4822718255502191, 0.5880103509520138, 0.9530923190726833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 39}], {
             RGBColor[
             0.7996586258825229, 0.839924523452416, 0.7674596487433745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 52}], {
             RGBColor[
             0.6598300586772909, 0.7336182700110854, 0.96711581897142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 78}], {
             RGBColor[
             0.7263596931522167, 0.7858121872234114, 0.9736883675793202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 82}], {
             RGBColor[
             0.7699846003808559, 0.8205975040809674, 0.9778493501752021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 107}], {
             RGBColor[
             0.6107041650615231, 0.6948361789628814, 0.962496015438162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 130}], {
             RGBColor[
             0.5565365340858028, 0.6508604559128248, 0.958231741105183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 193}], {
             RGBColor[
             0.44804553758013843`, 0.5566904614548439, 0.9509727728683643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 199}], {
             RGBColor[
             0.5117633303085515, 0.6135544100875527, 0.9549714916775706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 220}], {
             RGBColor[
             0.5752372421278855, 0.6660425331586843, 0.9597039293452065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.5579537196815944, 0.6520109910229719, 0.9583433071466056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 228}], {
             RGBColor[
             0.415207880823226, 0.5221760021756383, 0.949102716895018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 236}], {
             RGBColor[
             0.5575298667026993, 0.6516668880803459, 0.9583099398874824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 266}], {
             RGBColor[
             0.4908038695598578, 0.595400378640162, 0.9536359733723871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 281}], {
             RGBColor[
             0.41495681629848086`, 0.521912117441721, 0.9490884191417505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.5811720490820724, 0.6708606768040997, 0.9601711390885543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[
             0.48030469540941306`, 0.5859842338486527, 0.9530560243717467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 191}], {
             RGBColor[
             0.5235499686952074, 0.6234411159981731, 0.9558115749452238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 248}], {
             RGBColor[
             0.5171986381703025, 0.6179399127246545, 0.955406873780438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 21}], {
             RGBColor[
             0.6586704910970844, 0.7313015533074266, 0.9679648524897906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 34}], {
             RGBColor[
             0.7771608137697279, 0.8258432014486417, 0.9784237850019945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 46}], {
             RGBColor[
             0.6817603532894703, 0.7500469436216433, 0.9697825710225274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 50}], {
             RGBColor[
             0.8106502311475341, 0.49046134796055796`, 0.5726575082968948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 101}], {
             RGBColor[
             0.5974013891403533, 0.6798636047012742, 0.9636103915760212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 108}], {
             RGBColor[
             0.7269397186320822, 0.786610100232653, 0.9734182155814912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 114}], {
             RGBColor[
             0.7731578662387129, 0.8227160684138848, 0.9780248086017744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 145}], {
             RGBColor[
             0.5267338877018102, 0.6131760038585227, 0.9593081325460862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 169}], {
             RGBColor[
             0.8100062948602298, 0.8515023409114437, 0.9816975155986236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 187}], {
             RGBColor[
             0.7608709960789426, 0.8131174720614003, 0.9768001682115783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 205}], {
             RGBColor[
             0.6457968102896461, 0.7208501192752368, 0.9669513891787824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 213}], {
             RGBColor[
             0.555954129553478, 0.6438883307149641, 0.9609721820920646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 219}], {
             RGBColor[
             0.8692212443296456, 0.8986867846739234, 0.9873539687816286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 221}], {
             RGBColor[
             0.701910504684232, 0.7664057442778865, 0.9713688647527596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 231}], {
             RGBColor[
             0.6129220326102522, 0.6933068059846776, 0.9645993532535571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 264}], {
             RGBColor[
             0.7849504077360359, 0.8319284914582282, 0.9792001789306617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 9}], {
             RGBColor[
             0.49760016327048173`, 0.5964494630728284, 0.9554492512529646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 11}], {
             RGBColor[
             0.6279087519679106, 0.7079053071553323, 0.9644646170219071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 43}], {
             RGBColor[
             0.5756530329170118, 0.6653999346193401, 0.9603734640886643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.5920974214955297, 0.6788320557958005, 0.9616454179058953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 63}], {
             RGBColor[
             0.6756930582930539, 0.74657581968676, 0.9683104274061659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 106}], {
             RGBColor[
             0.8169935438240297, 0.8578741815065939, 0.9821515646403512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 131}], {
             RGBColor[
             0.8390660218278947, 0.8744057746124583, 0.9472146992146048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 143}], {
             RGBColor[
             0.6219497475866129, 0.7030675189485067, 0.963995502368459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 151}], {
             RGBColor[
             0.7667707597355579, 0.8178278967356039, 0.9773612706595842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 167}], {
             RGBColor[
             0.6831257527118595, 0.7523822970573008, 0.969051248923354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 174}], {
             RGBColor[
             0.6511858879226564, 0.7268027347464197, 0.9662970784312233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 185}], {
             RGBColor[
             0.8025023284279734, 0.8463192797033419, 0.9807693795794147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[
             0.6325198010690278, 0.7116487645410139, 0.9648276156979765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 283}], {
             RGBColor[
             0.7406118631599878, 0.7972908834499999, 0.974780927174578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 297}], {
             RGBColor[
             0.8256937713710382, 0.8644327721167853, 0.9698504311965717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 22}], {
             RGBColor[
             0.6864573922491878, 0.7543336553956257, 0.9698286429227806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 47}], {
             RGBColor[
             0.43555336940431266`, 0.5442325944273455, 0.9502001751129896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 61}], {
             RGBColor[
             0.6142838797164961, 0.697742352584096, 0.9627778236887283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 72}], {
             RGBColor[
             0.7036480849032328, 0.7677631551510689, 0.9715420505103793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 177}], {
             RGBColor[
             0.4982260392524061, 0.6019816829301352, 0.9540667452986082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 217}], {
             RGBColor[
             0.7465703844305529, 0.8018869775726042, 0.975662887488449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 247}], {
             RGBColor[
             0.739673661391631, 0.7963877178279276, 0.9750050718882193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 267}], {
             RGBColor[
             0.45862591478838666`, 0.5676820454795295, 0.9515434603847761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 271}], {
             RGBColor[
             0.47504005492130963`, 0.5818991486639964, 0.9525893548795916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 273}], {
             RGBColor[
             0.5157002533964201, 0.6171169689421402, 0.955180186772024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 285}], {
             RGBColor[
             0.5091156883946767, 0.6114137496874898, 0.9547606241126151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.42450727107127295`, 0.5380076909042039, 0.9490809175509607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 20}], {
             RGBColor[
             0.31518070802994635`, 0.4460704217677265, 0.9413532609044137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 37}], {
             RGBColor[
             0.40261585675834477`, 0.5202352545679926, 0.9473575452253541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 43}], {
             RGBColor[
             0.3722515520203741, 0.4955023183682117, 0.944989764617718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 63}], {
             RGBColor[
             0.47229157739641625`, 0.5766782034356317, 0.9529267279352196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 75}], {
             RGBColor[
             0.3900718754019299, 0.5100514854029347, 0.9463700370628594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.6135920629273919, 0.6879765652554655, 0.9667678651694049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 131}], {
             RGBColor[
             0.6356645409312569, 0.70450815836133, 0.9318309997436585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 142}], {
             RGBColor[
             0.6241490768742801, 0.6959199441224784, 0.951323676678082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 143}], {
             RGBColor[
             0.41854826668997525`, 0.5331699026973783, 0.9486118028975127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 167}], {
             RGBColor[
             0.4797242718152218, 0.5824846808061723, 0.9536675494524076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 174}], {
             RGBColor[
             0.44778440702601885`, 0.5569051184952913, 0.9509133789602768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 185}], {
             RGBColor[
             0.5991008475313357, 0.6764216634522134, 0.9653856801084684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 237}], {
             RGBColor[
             0.5701496932399541, 0.653336798878414, 0.9626242931671558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 239}], {
             RGBColor[
             0.5036461209043853, 0.6011726111274138, 0.9560518558072257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 282}], {
             RGBColor[
             0.5303503958814816, 0.6220341936995283, 0.9587134883713047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 283}], {
             RGBColor[
             0.5372103822633502, 0.6273932671988715, 0.9593972277036317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 295}], {
             RGBColor[
             0.4308343320789034, 0.5431442840610485, 0.9495790069702695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 297}], {
             RGBColor[
             0.6222922904744006, 0.694535155865657, 0.9544667317256252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 117}], {
             RGBColor[
             0.5683610086703983, 0.6604600970671091, 0.9591626070589601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.5388898061258093, 0.636534047178867, 0.956842526038078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 161}], {
             RGBColor[
             0.4553920842667246, 0.5672576468942641, 0.9506807466339522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 265}], {
             RGBColor[
             0.7501394644362085, 0.8021244735466575, 0.9019149814524003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 269}], {
             RGBColor[
             0.442966694474965, 0.5564953987748915, 0.9498890117837622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 43}], {
             RGBColor[
             0.502560140717803, 0.6069581624507155, 0.9540051303866605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 63}], {
             RGBColor[
             0.6026001660938451, 0.6881340475181354, 0.9619420937041621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 131}], {
             RGBColor[
             0.7659731296286858, 0.8159640024438337, 0.9408463655126009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 139}], {
             RGBColor[
             0.41645451414389495`, 0.529543732799251, 0.9486223249569328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 143}], {
             RGBColor[
             0.5488568553874041, 0.6446257467798822, 0.9576271686664551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 172}], {
             RGBColor[
             0.6707293838120656, 0.7413571102008418, 0.9687325774225766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 174}], {
             RGBColor[
             0.5780929957234477, 0.6683609625777951, 0.9599287447292193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 183}], {
             RGBColor[
             0.4579993795245326, 0.5683618707940843, 0.9511657580869592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 185}], {
             RGBColor[
             0.7294094362287646, 0.7878775075347173, 0.9744010458774108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 283}], {
             RGBColor[
             0.667518970960779, 0.7388491112813753, 0.9684125934725741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 248}], {
             RGBColor[
             0.3207611823808119, 0.4444555912304561, 0.9419449497309591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 58}], {
             RGBColor[
             0.48775152960536894`, 0.5950176905464697, 0.9528167335847098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 73}], {
             RGBColor[
             0.4870632577245851, 0.5944589204273545, 0.9527625503010314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 95}], {
             RGBColor[
             0.43225547531061026`, 0.5484348467382884, 0.9488702505847177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 96}], {
             RGBColor[
             0.37943077160069155`, 0.5010741859926651, 0.9455631311131274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 105}], {
             RGBColor[
             0.3999208196256838, 0.5204281931710542, 0.9468099149168876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[
             0.3695164458498159, 0.49065360102393574`, 0.9449985249285456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 149}], {
             RGBColor[
             0.5880982523136815, 0.6754673496568864, 0.9614112662014039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 171}], {
             RGBColor[
             0.5722359910066673, 0.6630756305661959, 0.9598302642355805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 245}], {
             RGBColor[
             0.5198834164859594, 0.6211038038411412, 0.9553462734229297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 289}], {
             RGBColor[
             0.41140019883459866`, 0.5303710544714411, 0.9475413708092633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 298}], {
             RGBColor[
             0.46859340615004463`, 0.5794642628618112, 0.951308535927788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 69}], {
             RGBColor[
             0.3462346910899687, 0.47431281998573005`, 0.9432827462463049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 113}], {
             RGBColor[
             0.3132554863995713, 0.443409454958894, 0.9412669620648205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 135}], {
             RGBColor[
             0.4722136457844152, 0.5794094961685566, 0.9524207414532997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 224}], {
             RGBColor[
             0.4932639104985697, 0.5964820201367839, 0.9540895383790482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 249}], {
             RGBColor[
             0.44619607565537406`, 0.5582872606596235, 0.9503725430272418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 254}], {
             RGBColor[
             0.42170359091475346`, 0.5384031581733242, 0.9484444049095324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 288}], {
             RGBColor[
             0.39968531806092816`, 0.5205277323587004, 0.9467110458148882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 19}], {
             RGBColor[
             0.4691173395295858, 0.5795965227176786, 0.9514307643144092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 49}], {
             RGBColor[
             0.5310942527128929, 0.6299121728680085, 0.9563098139491126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 57}], {
             RGBColor[
             0.4672221916769553, 0.5780579563154753, 0.9512815713332947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 89}], {
             RGBColor[
             0.5198779792928658, 0.620806296818271, 0.9554268278189249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 111}], {
             RGBColor[
             0.5028412222005442, 0.6069750899135637, 0.9540856318929196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.5228161586189409, 0.6231916431586491, 0.9556581320583789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 115}], {
             RGBColor[
             0.5916715719761331, 0.6775832798934802, 0.9621099083491721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 146}], {
             RGBColor[
             0.6071107315217746, 0.6896444686724941, 0.9636487394855326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 175}], {
             RGBColor[
             0.5239193035277268, 0.6240872258917133, 0.9557449756665515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 212}], {
             RGBColor[
             0.39916384655472475`, 0.5201573941525965, 0.9466553452291047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 242}], {
             RGBColor[
             0.41737205592796595`, 0.5359284299404852, 0.9478155562294803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 243}], {
             RGBColor[
             0.3987521240786558, 0.5198007808375991, 0.9466291106370015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 280}], {
             RGBColor[
             0.44365876781357305`, 0.5586966585672428, 0.9494905222664045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 294}], {
             RGBColor[
             0.466131500367261, 0.577172483975182, 0.9511957081180618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.714290378611291, 0.7767283396698661, 0.9721574475830221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 44}], {
             RGBColor[
             0.7597927735629918, 0.8123412831851731, 0.9766751530620351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 53}], {
             RGBColor[
             0.5172680238765899, 0.615236708297827, 0.9564809891878362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 59}], {
             RGBColor[
             0.5696186001580895, 0.6605801462563918, 0.9598167216166964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 94}], {
             RGBColor[
             0.4847566864275151, 0.5842429581589978, 0.9545131644695739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 124}], {
             RGBColor[
             0.4956051107515599, 0.5956453399533982, 0.9551309661860226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 125}], {
             RGBColor[
             0.5315757645883257, 0.6276293541743747, 0.9573926657741496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 150}], {
             RGBColor[
             0.5635515895621296, 0.6553252066149904, 0.9594301370663687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 170}], {
             RGBColor[
             0.7633780605080971, 0.8152000936751784, 0.9770171209314827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 192}], {
             RGBColor[
             0.4952071078502313, 0.5952270136692603, 0.9551083005095845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 195}], {
             RGBColor[
             0.645629875704669, 0.7224388891704292, 0.9657593376284574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 200}], {
             RGBColor[
             0.4869082826929852, 0.5865044222530893, 0.954635694693891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 295}], {
             RGBColor[
             0.6294450930599524, 0.7092993535032992, 0.964485212251853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 30}], {
             RGBColor[
             0.5235287002571686, 0.6222131234063912, 0.9562223009723261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 38}], {
             RGBColor[
             0.6069320571105327, 0.6873818737373272, 0.9645316084535576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[
             0.47473370189155967`, 0.5827902911110068, 0.9522502926906145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 48}], {
             RGBColor[
             0.364027640817442, 0.4897241787400112, 0.9444164972692519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 55}], {
             RGBColor[
             0.36614292937076165`, 0.4915563353674026, 0.9445512815853931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 84}], {
             RGBColor[
             0.5726711393982349, 0.6606035703597629, 0.9611203600437036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 90}], {
             RGBColor[
             0.32278209541883807`, 0.4488770386320784, 0.9419759208798562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 97}], {
             RGBColor[
             0.35120005484529215`, 0.4786135685041524, 0.9435991348340953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 134}], {
             RGBColor[
             0.44078895832118625`, 0.5552324190873064, 0.949578038133062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 144}], {
             RGBColor[
             0.39424067471707613`, 0.5158931901526367, 0.9463416450729997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 158}], {
             RGBColor[
             0.3507370246893895, 0.47821251505568185`, 0.9435696309620027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 159}], {
             RGBColor[
             0.46813903138877627`, 0.5774364405103267, 0.9517311360715615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 175}], {
             RGBColor[
             0.4987677446069823, 0.6023022097086727, 0.9541423405727719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 235}], {
             RGBColor[
             0.41363393179586666`, 0.5326906547008425, 0.9475773662652763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 252}], {
             RGBColor[
             0.4237152473086838, 0.5413712113254411, 0.9482339330590935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 253}], {
             RGBColor[
             0.6008827081651422, 0.6826426622963349, 0.9639322255662895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 292}], {
             RGBColor[
             0.3500254541310073, 0.47751153596727636`, 0.9435273898555767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 24}], {
             RGBColor[
             0.6402114449443379, 0.717745902681975, 0.965533829543549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 36}], {
             RGBColor[
             0.6368875842546795, 0.7150474428358926, 0.9652721630543563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 66}], {
             RGBColor[
             0.6307384070677587, 0.7100552637782749, 0.9647880773010236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 69}], {
             RGBColor[
             0.5300142806231408, 0.6254615948857065, 0.9576382346853394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 88}], {
             RGBColor[
             0.5784733896555018, 0.6674344395038987, 0.9607260062621739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 113}], {
             RGBColor[
             0.49703507593274343`, 0.5945582298588705, 0.9556224505038551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 135}], {
             RGBColor[
             0.6559932353175874, 0.7305582710685331, 0.9667762298923342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.5144611081700484, 0.6119902186320151, 0.9566472002897588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 222}], {
             RGBColor[
             0.6786740085896827, 0.7489045607145479, 0.9686075406731696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.6770435000317419, 0.7476307950367604, 0.9684450268180828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 254}], {
             RGBColor[
             0.6054831804479256, 0.6895519330733006, 0.962799893348567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 258}], {
             RGBColor[
             0.6341715336175258, 0.7128424305719644, 0.9650583455989782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 260}], {
             RGBColor[
             0.72492843770861, 0.7850388722889354, 0.9732177498955283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 278}], {
             RGBColor[
             0.5881204038259832, 0.6754560488274347, 0.9614330319709412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 288}], {
             RGBColor[
             0.5834649075941003, 0.671676507258677, 0.9610665342539229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 290}], {
             RGBColor[
             0.7070155144197561, 0.7710451604724233, 0.9714323571078809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 48}], {
             RGBColor[
             0.4157729244190619, 0.5333922715172046, 0.9480317053541807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 49}], {
             RGBColor[
             0.5576879773937683, 0.6517952494621613, 0.958322386940262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 57}], {
             RGBColor[
             0.49381591635783073`, 0.5999410329096281, 0.953294144324444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 84}], {
             RGBColor[
             0.6244164229998548, 0.7042716631369563, 0.9647355681286325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 89}], {
             RGBColor[
             0.5464717039737412, 0.6426893734124239, 0.9574394008100742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 111}], {
             RGBColor[
             0.5294349468814196, 0.6288581665077164, 0.9560982048840689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 112}], {
             RGBColor[
             0.5494098832998163, 0.645074719752802, 0.9576707050495282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 158}], {
             RGBColor[
             0.4024823082910094, 0.5218806078328753, 0.9471848390469316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 175}], {
             RGBColor[
             0.5505130282086022, 0.6459703024858661, 0.9577575486577008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 177}], {
             RGBColor[
             0.4461617978209388, 0.5597135862687224, 0.9499680574955227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 242}], {
             RGBColor[
             0.4439657806088414, 0.557811506534638, 0.9498281292206296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 253}], {
             RGBColor[
             0.6526279917667621, 0.7263107550735283, 0.9675474336512184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 280}], {
             RGBColor[
             0.47025249249444845`, 0.5805797351613956, 0.9515030952575538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 33}], {
             RGBColor[
             0.5366616432863441, 0.6300918451736418, 0.9585389514238342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 37}], {
             RGBColor[
             0.42359788241444696`, 0.539753829514019, 0.9486452543477497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 75}], {
             RGBColor[
             0.4110539010580321, 0.529570060348961, 0.9476577461852549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 124}], {
             RGBColor[
             0.31797637542661306`, 0.44900884545717396`, 0.9415124700268347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 142}], {
             RGBColor[
             0.6451311025303823, 0.7154385190685048, 0.9526113858004777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 150}], {
             RGBColor[
             0.38592285423718276`, 0.5086887121187662, 0.9458116409071807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 167}], {
             RGBColor[
             0.500706297471324, 0.6020032557521988, 0.9549552585748032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 185}], {
             RGBColor[
             0.6200828731874379, 0.6959402383982398, 0.9666733892308639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 200}], {
             RGBColor[
             0.30927954736803837`, 0.439867927756865, 0.941017198534703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 237}], {
             RGBColor[
             0.5911317188960564, 0.6728553738244405, 0.9639120022895513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 282}], {
             RGBColor[
             0.5513324215375839, 0.6415527686455547, 0.9600011974937002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 283}], {
             RGBColor[
             0.5581924079194523, 0.6469118421448978, 0.9606849368260273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 295}], {
             RGBColor[
             0.45181635773500567`, 0.5626628590070749, 0.9508667160926652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 297}], {
             RGBColor[
             0.6432743161305028, 0.7140537308116832, 0.9557544408480207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 34}], {
             RGBColor[
             0.6318498425717443, 0.7103490588349524, 0.9652916208979954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 46}], {
             RGBColor[
             0.5364493820914866, 0.634552801007954, 0.9566504069185282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 50}], {
             RGBColor[
             0.6653392599495505, 0.37496720534686867`, 0.5595253441928958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[
             0.5286879033927632, 0.6282516829496996, 0.9560393948841315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 101}], {
             RGBColor[
             0.45209041794236965`, 0.5643694620875849, 0.950478227472022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 108}], {
             RGBColor[
             0.5816287474340985, 0.6711159576189637, 0.9602860514774921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[
             0.6278468950407292, 0.7072219258001955, 0.9648926444977752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 169}], {
             RGBColor[
             0.6646953236622462, 0.7360081982977544, 0.9685653514946244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 187}], {
             RGBColor[
             0.615560024880959, 0.697623329447711, 0.9636680041075792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 205}], {
             RGBColor[
             0.5004858390916624, 0.6053559766615475, 0.9538192250747833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 213}], {
             RGBColor[
             0.41064315835549436`, 0.5283941881012748, 0.9478400179880655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 264}], {
             RGBColor[
             0.6396394365380522, 0.7164343488445389, 0.9660680148266626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 61}], {
             RGBColor[
             0.700901724892288, 0.7660602153450645, 0.9709657536997793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 72}], {
             RGBColor[
             0.7902659300790247, 0.8360810179120373, 0.9797299805214303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 177}], {
             RGBColor[
             0.584843884428198, 0.6702995456911037, 0.9622546753096592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 217}], {
             RGBColor[
             0.8331882296063449, 0.8702048403335727, 0.9838508174995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 247}], {
             RGBColor[
             0.8262915065674229, 0.8647055805888961, 0.9831930018992703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 267}], {
             RGBColor[
             0.5452437599641785, 0.6359999082404979, 0.9597313903958271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 271}], {
             RGBColor[
             0.5616579000971015, 0.6502170114249649, 0.9607772848906426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 273}], {
             RGBColor[
             0.602318098572212, 0.6854348317031087, 0.963368116783075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 274}], {
             RGBColor[
             0.7815534897638916, 0.8292747933208564, 0.9788616058932016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 285}], {
             RGBColor[
             0.5957335335704685, 0.6797316124484583, 0.9629485541236661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[
             0.4945856698641997, 0.6005659534830987, 0.9533547421401655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 180}], {
             RGBColor[
             0.45094043369137504`, 0.5646652943547857, 0.9500479982081567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 267}], {
             RGBColor[
             0.3915962276375583, 0.5132643257974926, 0.9462666378744284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 285}], {
             RGBColor[
             0.4420860012438484, 0.5569960300054531, 0.9494838016022675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.49688088290682647`, 0.6016320423715049, 0.9537557173688673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 113}], {
             RGBColor[
             0.4266301819201002, 0.5384459805726618, 0.9493650264012711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 135}], {
             RGBColor[
             0.5855883413049441, 0.6744460217823245, 0.9605188057897502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 224}], {
             RGBColor[
             0.6066386060190987, 0.6915185457505517, 0.9621876027154987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 233}], {
             RGBColor[
             0.5813680962646701, 0.6710198367387575, 0.9601865726409129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 254}], {
             RGBColor[
             0.5350782864352823, 0.6334396837870919, 0.956542469245983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 259}], {
             RGBColor[
             0.5707284373176311, 0.6623820822943778, 0.959348979714247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 260}], {
             RGBColor[
             0.6545235436959669, 0.7289266230027267, 0.9669603257929444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 288}], {
             RGBColor[
             0.5130600135814571, 0.6155642579724683, 0.9548091101513387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 29}], {
             RGBColor[
             0.5294300413306634, 0.6288541839606201, 0.9560978187011439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[
             0.48207474260312233`, 0.5903271934045495, 0.952392444806587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 77}], {
             RGBColor[
             0.42856268765800415`, 0.5439777410051732, 0.9489827039843364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 91}], {
             RGBColor[
             0.548998721930573, 0.6447409204306415, 0.9576383369204077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 139}], {
             RGBColor[
             0.3959691160292143, 0.512912763753085, 0.9470096393768593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 147}], {
             RGBColor[
             0.737778732865685, 0.7935836748280772, 0.9522830038152736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 148}], {
             RGBColor[
             0.4924978340314974, 0.5988709542981785, 0.9531903800554204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 172}], {
             RGBColor[
             0.650243985697385, 0.7247261411546758, 0.967119891842503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 203}], {
             RGBColor[
             0.5757476945521571, 0.6664569414323277, 0.959744114029894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 206}], {
             RGBColor[
             0.5256934354830487, 0.6258206390013512, 0.9558036594011814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 244}], {
             RGBColor[
             0.5834759805239307, 0.6725664680575393, 0.9604650810692963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 270}], {
             RGBColor[
             0.4547535980744255, 0.566662991214444, 0.9506515656363579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 272}], {
             RGBColor[
             0.3954061854900117, 0.5123210880645255, 0.9469775813154329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 39}], {
             RGBColor[
             0.6764709862989573, 0.7373565791139256, 0.7584688343681762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 59}], {
             RGBColor[
             0.40345059097344516`, 0.523870356710053, 0.9469284927928463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 60}], {
             RGBColor[
             0.4471998315765289, 0.5595373262688489, 0.9503313232341274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 62}], {
             RGBColor[
             0.6769766511036526, 0.7384381450006146, 0.8135073277578151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 82}], {
             RGBColor[
             0.6467969607972905, 0.7180295597424771, 0.9688585358000039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[
             0.4575686592315579, 0.5679552076695641, 0.9511475953293984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 127}], {
             RGBColor[
             0.3251056750148272, 0.4543829464725092, 0.9419960690278024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 130}], {
             RGBColor[
             0.43334889450223724`, 0.5482925115743346, 0.9492409267299848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 137}], {
             RGBColor[
             0.3457356913114019, 0.47388061145799365`, 0.9432509504216628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 170}], {
             RGBColor[
             0.5972100513234527, 0.6784903041288396, 0.9641288921076328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 192}], {
             RGBColor[
             0.329039098665587, 0.4585172241229215, 0.9422200716857345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 195}], {
             RGBColor[
             0.47946186652002476`, 0.5857290996240904, 0.9528711088046073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 199}], {
             RGBColor[
             0.38857569072498593`, 0.5109864657490625, 0.9459806773023723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 220}], {
             RGBColor[
             0.4520496025443199, 0.563474588820194, 0.9507131149700083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 226}], {
             RGBColor[
             0.43476608009802886`, 0.5494430466844816, 0.9493524927714074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 228}], {
             RGBColor[
             0.29202024123966047`, 0.41960805783714805`, 0.9401119025198198]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 266}], {
             RGBColor[
             0.36761622997629223`, 0.4928324343016718, 0.9446451589971889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 32}], {
             RGBColor[
             0.3827966108200537, 0.5059809172004118, 0.9456124394410698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 103}], {
             RGBColor[
             0.38098022605974746`, 0.5044076560151871, 0.945496701010309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 119}], {
             RGBColor[
             0.39660796623046296`, 0.5179436190780013, 0.9464924867949189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 152}], {
             RGBColor[
             0.496492153675313, 0.601912314115173, 0.9535604773842838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 268}], {
             RGBColor[
             0.7169336861792797, 0.774965118042515, 0.8993565508060685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 35}], {
             RGBColor[
             0.5304513242558192, 0.629683307447533, 0.9561782178340947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 126}], {
             RGBColor[
             0.48214670123288894`, 0.5903980341924167, 0.9523946775476217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 163}], {
             RGBColor[
             0.48848948018424243`, 0.5956167920706938, 0.9528748277574807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 184}], {
             RGBColor[
             0.40405267888593516`, 0.5214466052778821, 0.9474665724360556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 189}], {
             RGBColor[
             0.6192632591591369, 0.7005189588094733, 0.9640353066026763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 197}], {
             RGBColor[
             0.45608223467859527`, 0.5678223033012676, 0.950733872786685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 211}], {
             RGBColor[
             0.346229252683778, 0.4606705181224431, 0.944173613855936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 216}], {
             RGBColor[
             0.5253630945896292, 0.6255524533823856, 0.9557776537559728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 275}], {
             RGBColor[
             0.556685526220476, 0.6509814144397716, 0.9582434703118008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 293}], {
             RGBColor[
             0.6766287635542447, 0.745492894249101, 0.9697106196847165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 77}], {
             RGBColor[
             0.44414766544932704`, 0.5566303280714175, 0.9502096105257241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 91}], {
             RGBColor[
             0.5645836997218958, 0.6573935074968859, 0.9588652434617954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 148}], {
             RGBColor[
             0.5080828118228203, 0.6115235413644229, 0.9544172865968081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 162}], {
             RGBColor[
             0.48599603991783963`, 0.5928772866755845, 0.952876151941793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 172}], {
             RGBColor[
             0.6658289634887079, 0.7373787282209202, 0.9683467983838907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 191}], {
             RGBColor[
             0.48739293873512135`, 0.5940872102209379, 0.9529651610992012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 203}], {
             RGBColor[
             0.59133267234348, 0.6791095284985721, 0.9609710205712817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 206}], {
             RGBColor[
             0.5412784132743715, 0.6384732260675956, 0.9570305659425691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 244}], {
             RGBColor[
             0.5990609583152535, 0.6852190551237837, 0.961691987610684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 270}], {
             RGBColor[
             0.4703385758657484, 0.5793155782806884, 0.9518784721777456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 272}], {
             RGBColor[
             0.4109911632813346, 0.5249736751307699, 0.9482044878568205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 38}], {
             RGBColor[
             0.7382402603604797, 0.7954515833862739, 0.9745409882901828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 47}], {
             RGBColor[
             0.4630520476211725, 0.5663661146376858, 0.9524956590616004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 48}], {
             RGBColor[
             0.49533584406738906`, 0.5977938883889578, 0.9544258771058771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 74}], {
             RGBColor[
             0.5393960591945369, 0.6359566322012906, 0.9572333550528604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 90}], {
             RGBColor[
             0.45409029866878514`, 0.5569467482810251, 0.9519853007164814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 123}], {
             RGBColor[
             0.48965149125998775`, 0.5928703876910661, 0.9540636751714653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 144}], {
             RGBColor[
             0.5255488779670232, 0.6239628998015833, 0.956351024909625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 158}], {
             RGBColor[
             0.4820452279393366, 0.5862822247046284, 0.953579010798628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 252}], {
             RGBColor[
             0.5550234505586309, 0.6494409209743877, 0.9582433128957188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 257}], {
             RGBColor[
             0.7668632901914609, 0.8182748104220512, 0.9772710784275421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 259}], {
             RGBColor[
             0.6132436136053416, 0.6967066721241636, 0.9628266173982402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 36}], {
             RGBColor[
             0.373690111093623, 0.4835977380233646, 0.9462777901453916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 51}], {
             RGBColor[
             0.5065244962231075, 0.5886536943897869, 0.9586690091364924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 58}], {
             RGBColor[
             0.34611630551587474`, 0.4612120804695631, 0.9441070791641333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 66}], {
             RGBColor[
             0.36754093390670217`, 0.47860555896574686`, 0.945793704392059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 67}], {
             RGBColor[
             0.3758544690804633, 0.4853548613402977, 0.9464481763344201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 73}], {
             RGBColor[
             0.3454280336350909, 0.4606533103504479, 0.944052895880455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 95}], {
             RGBColor[
             0.29062025122111607`, 0.41462923666138174`, 0.9401605961641415]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 96}], {
             RGBColor[
             0.23779554751119736`, 0.36726857591575857`, 0.936853476692551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 109}], {
             RGBColor[
             0.41909906920422313`, 0.5202848068197925, 0.9499742280764535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 110}], {
             RGBColor[
             0.477912500015518, 0.5662303059682057, 0.9558362012169639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 138}], {
             RGBColor[
             0.35043309834745445`, 0.46471664735954044`, 0.9444469129087685]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 154}], {
             RGBColor[
             0.3133725037417892, 0.43433609423332664`, 0.9416103495757318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 171}], {
             RGBColor[
             0.43060076691717314`, 0.5292700204892893, 0.9511206098150042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 245}], {
             RGBColor[
             0.3782481923964652, 0.48729819376423456`, 0.9466366190023533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 156}], {
             RGBColor[
             0.5764811720470167, 0.6606070553756582, 0.9627753513054464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 178}], {
             RGBColor[
             0.4936520328262569, 0.5957929214255808, 0.954548212370425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 182}], {
             RGBColor[
             0.28755080223730844`, 0.41855238264857375`, 0.9397240235378803]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 202}], {
             RGBColor[
             0.32768134972785956`, 0.4582428482159222, 0.9421005437407869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 208}], {
             RGBColor[
             0.38110828418988446`, 0.5045185735311231, 0.945504860761124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 268}], {
             RGBColor[
             0.6538300288902845, 0.7203079017808234, 0.8953356415639868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 37}], {
             RGBColor[
             0.6240967920147426, 0.7042566779739079, 0.9645432357447745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 75}], {
             RGBColor[
             0.6115528106583277, 0.69407290880885, 0.9635557275822797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 94}], {
             RGBColor[
             0.5076268607028639, 0.6021093121226625, 0.9567926497074107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 124}], {
             RGBColor[
             0.5184752850269086, 0.6135116939170628, 0.9574104514238595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 142}], {
             RGBColor[
             0.8456300121306779, 0.8799413675283937, 0.9685093671975025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 150}], {
             RGBColor[
             0.5864217638374783, 0.6731915605786551, 0.9617096223042055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 185}], {
             RGBColor[
             0.8205817827877335, 0.8604430868581288, 0.9825713706278887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 200}], {
             RGBColor[
             0.5097784569683339, 0.604370776216754, 0.9569151799317278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 237}], {
             RGBColor[
             0.791630628496352, 0.8373582222843294, 0.9798099836865761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 239}], {
             RGBColor[
             0.7251270561607831, 0.7851940345333291, 0.973237546326646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 282}], {
             RGBColor[
             0.7518313311378795, 0.8060556171054436, 0.975899178890725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 295}], {
             RGBColor[
             0.6523152673353012, 0.7271657074669639, 0.96676469748969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 297}], {
             RGBColor[
             0.8437732257307984, 0.8785565792715722, 0.9716524222450456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 46}], {
             RGBColor[
             0.6549397047641301, 0.729094449149169, 0.9671093394307322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 50}], {
             RGBColor[
             0.7838295826221938, 0.46950885348808363`, 0.5699842767050995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 87}], {
             RGBColor[
             0.6471782260654066, 0.7227933310909145, 0.9664983273963353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 108}], {
             RGBColor[
             0.7001190701067419, 0.7656576057601787, 0.970744983989696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 114}], {
             RGBColor[
             0.7463372177133727, 0.8017635739414104, 0.9753515770099792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 169}], {
             RGBColor[
             0.7831856463348896, 0.8305498464389695, 0.9790242840068284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 187}], {
             RGBColor[
             0.7340503475536024, 0.7921649775889259, 0.9741269366197831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 205}], {
             RGBColor[
             0.6189761617643058, 0.6998976248027625, 0.9642781575869872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 213}], {
             RGBColor[
             0.5291334810281378, 0.6229358362424897, 0.9582989505002694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 227}], {
             RGBColor[
             0.7170419813947104, 0.7788779126772291, 0.9724317016332833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 264}], {
             RGBColor[
             0.7581297592106956, 0.810975996985754, 0.9765269473388665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 92}], {
             RGBColor[
             0.5931783452374577, 0.6806079289005196, 0.9611163187024182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 126}], {
             RGBColor[
             0.49906652012115216`, 0.6041343053950634, 0.9537266676698446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 163}], {
             RGBColor[
             0.5054092990725056, 0.6093530632733406, 0.9542068178797035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 184}], {
             RGBColor[
             0.4209724977741984, 0.5351828764805289, 0.9487985625582784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 189}], {
             RGBColor[
             0.6361830780474002, 0.7142552300121201, 0.9653672967248992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 197}], {
             RGBColor[
             0.4730020535668585, 0.5815585745039143, 0.9520658629089078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 211}], {
             RGBColor[
             0.36314907157204124`, 0.47440678932508984`, 0.9455056039781589]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 216}], {
             RGBColor[
             0.5422829134778924, 0.6392887245850324, 0.9571096438781956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 275}], {
             RGBColor[
             0.5736053451087392, 0.6647176856424184, 0.9595754604340236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 58}], {
             RGBColor[
             0.5355850239746297, 0.6338510761498002, 0.9565823614813211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 66}], {
             RGBColor[
             0.5570096523654571, 0.6512445546459839, 0.9582689867092469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 67}], {
             RGBColor[
             0.5653231875392183, 0.6579938570205348, 0.958923458651608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 69}], {
             RGBColor[
             0.4562855259208392, 0.5666508857534156, 0.9511191440935627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 88}], {
             RGBColor[
             0.5047446349532001, 0.6086237303716077, 0.9542069156703971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 95}], {
             RGBColor[
             0.480088969679871, 0.5872682323416187, 0.9526358784813294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 96}], {
             RGBColor[
             0.4272642659699523, 0.5399075715959956, 0.9493287590097389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 109}], {
             RGBColor[
             0.608567787662978, 0.6929238025000295, 0.9624495103936413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 113}], {
             RGBColor[
             0.4233063212304418, 0.5357475207265795, 0.9491033599120783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 138}], {
             RGBColor[
             0.5399018168062094, 0.6373556430397774, 0.9569221952259563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 154}], {
             RGBColor[
             0.5028412222005442, 0.6069750899135637, 0.9540856318929196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 198}], {
             RGBColor[
             0.44073235346774686`, 0.553179509499724, 0.9501281096979819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 222}], {
             RGBColor[
             0.6049452538873812, 0.6900938515822568, 0.9620884500813927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 224}], {
             RGBColor[
             0.6033147453294403, 0.6888200859044693, 0.961925936226306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 245}], {
             RGBColor[
             0.5677169108552201, 0.6599371894444716, 0.9591119013195412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 258}], {
             RGBColor[
             0.5604427789152242, 0.6540317214396734, 0.9585392550072014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 260}], {
             RGBColor[
             0.6511996830063085, 0.7262281631566444, 0.9666986593037517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 278}], {
             RGBColor[
             0.5143916491236815, 0.6166453396951437, 0.9549139413791645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 290}], {
             RGBColor[
             0.6332867597174545, 0.7122344513401324, 0.9649132665161042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 75}], {
             RGBColor[
             0.4984890497864305, 0.6037348931492272, 0.9536620305061952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 94}], {
             RGBColor[
             0.3945630998309667, 0.5117712964630396, 0.9468989526313263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 102}], {
             RGBColor[
             0.47533430007257377`, 0.5845653141415283, 0.9519418531322077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 124}], {
             RGBColor[
             0.40541152415501147`, 0.5231736782574401, 0.9475167543477749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 142}], {
             RGBColor[
             0.7325662512587807, 0.7896033518687708, 0.9586156701214179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 150}], {
             RGBColor[
             0.47335800296558117`, 0.5828535449190322, 0.9518159252281211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 185}], {
             RGBColor[
             0.7075180219158363, 0.7701050711985059, 0.9726776735518041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 237}], {
             RGBColor[
             0.6785668676244548, 0.7470202066247065, 0.9699162866104917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 239}], {
             RGBColor[
             0.6120632952888859, 0.6948560188737063, 0.9633438492505615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 282}], {
             RGBColor[
             0.6387675702659823, 0.7157176014458208, 0.9660054818146404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 283}], {
             RGBColor[
             0.6456275566478508, 0.721076674945164, 0.9666892211469675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 295}], {
             RGBColor[
             0.539251506463404, 0.636827691807341, 0.9568710004136054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 297}], {
             RGBColor[
             0.7307094648589012, 0.7882185636119494, 0.9617587251689611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 48}], {
             RGBColor[
             0.5787392009207531, 0.6629626387198938, 0.9627351845871086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 55}], {
             RGBColor[
             0.5808544894740728, 0.6647947953472853, 0.9628699689032498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 74}], {
             RGBColor[
             0.622799416047901, 0.7011253825322267, 0.9655426625340919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 90}], {
             RGBColor[
             0.5374936555221492, 0.622115498611961, 0.9602946081977128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 123}], {
             RGBColor[
             0.5730548481133518, 0.6580391380220021, 0.9623729826526968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 144}], {
             RGBColor[
             0.6089522348203873, 0.6891316501325193, 0.9646603323908565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 158}], {
             RGBColor[
             0.5654485847927007, 0.6514509750355645, 0.9618883182798594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 252}], {
             RGBColor[
             0.638426807411995, 0.7146096713053237, 0.9665526203769503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 253}], {
             RGBColor[
             0.8155942682684534, 0.8558811222762175, 0.9822509128841463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 257}], {
             RGBColor[
             0.850266647044825, 0.8834435607529872, 0.9855803859087736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 259}], {
             RGBColor[
             0.6966469704587057, 0.7618754224550996, 0.9711359248794716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 52}], {
             RGBColor[
             0.8540292194260293, 0.8829644981729973, 0.772492334266913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 59}], {
             RGBColor[
             0.7208373913057491, 0.7757845292104552, 0.7612958224635376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 60}], {
             RGBColor[
             0.7645866319088327, 0.811451498769251, 0.7646986529048185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 62}], {
             RGBColor[
             0.9943634514359565, 0.9903523175010167, 0.6278746574285063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 82}], {
             RGBColor[
             0.9641837611295943, 0.9699437322428792, 0.7832258654706952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 100}], {
             RGBColor[
             0.7749554595638617, 0.8198693801699664, 0.7655149250000897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 107}], {
             RGBColor[
             0.8049033258102615, 0.8441824071247934, 0.7678725307336549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 127}], {
             RGBColor[
             0.642492475347131, 0.7062971189729114, 0.7563633986984937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 136}], {
             RGBColor[
             0.652018699657312, 0.7161772374325941, 0.7569107562856787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 137}], {
             RGBColor[
             0.6631224916437057, 0.7257947839583958, 0.757618280092354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 141}], {
             RGBColor[
             0.6674105767056413, 0.7295089077136225, 0.7578915130806958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 170}], {
             RGBColor[
             0.9145968516557565, 0.9304044766292418, 0.7784962217783239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 192}], {
             RGBColor[
             0.6464258989978908, 0.7104313966233237, 0.7565874013564257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 220}], {
             RGBColor[
             0.7694364028766238, 0.8153887613205961, 0.7650804446406996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 228}], {
             RGBColor[
             0.6094070415719643, 0.6715222303375503, 0.7544792321905109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 232}], {
             RGBColor[
             0.6387744907081887, 0.7023892813835415, 0.7561516649735713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 266}], {
             RGBColor[
             0.6850030303085961, 0.7447466068020739, 0.7590124886678802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 281}], {
             RGBColor[
             0.6091559770472192, 0.6712583456036328, 0.7544649344372434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.6306025138628183, 0.70780621494668, 0.9660756932570913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.6136651101148413, 0.6945428819016009, 0.9643959445421617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 162}], {
             RGBColor[
             0.4321377694202858, 0.5487177488211936, 0.9487564144364031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 191}], {
             RGBColor[
             0.4335346682375676, 0.5499276723665472, 0.9488454235938112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 76}], {
             RGBColor[
             0.3809313295275726, 0.5043653042966284, 0.9454935853665163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.44273764171568963`, 0.5578988254384001, 0.9494318289259672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 99}], {
             RGBColor[
             0.4251631839052175, 0.5426767134009023, 0.9483120000147668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 104}], {
             RGBColor[
             0.5193129814120349, 0.6202558645105376, 0.9554076975866652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 157}], {
             RGBColor[
             0.40327166581390095`, 0.5237153807298958, 0.9469170918398975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 201}], {
             RGBColor[
             0.6893232183788642, 0.7545939459889158, 0.9682475498740604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 209}], {
             RGBColor[
             0.4450769711382617, 0.5599250350061165, 0.9495808889281858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 222}], {
             RGBColor[
             0.5429382606498706, 0.6393689466490492, 0.9573133633369628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 229}], {
             RGBColor[
             0.5039803861713815, 0.607808172968631, 0.9542006595241739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 259}], {
             RGBColor[
             0.5053975833904621, 0.6089587175150879, 0.9543122264806244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 261}], {
             RGBColor[
             0.3975844358830797, 0.5187893880123061, 0.9465547065777256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 278}], {
             RGBColor[
             0.45238465588617105`, 0.565920434761936, 0.9501388546347347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 290}], {
             RGBColor[
             0.5712797664799439, 0.6615095464069247, 0.9601381797716744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 55}], {
             RGBColor[
             0.44865613425509976`, 0.5602032127209648, 0.9505886531403069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[
             0.43371325972963026`, 0.5472604458577146, 0.9496365063890091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 134}], {
             RGBColor[
             0.5233021632055244, 0.6238792964408686, 0.9556154096879756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 144}], {
             RGBColor[
             0.4767538796014143, 0.5845400675061989, 0.9523790166279134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 159}], {
             RGBColor[
             0.5506522362731144, 0.646083317863889, 0.9577685076264751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 235}], {
             RGBColor[
             0.4961471366802048, 0.6013375320544048, 0.95361473782019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 252}], {
             RGBColor[
             0.506228452193022, 0.6100180886790033, 0.9542713046140072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 292}], {
             RGBColor[
             0.4325386590153455, 0.5461584133208386, 0.9495647614104905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 63}], {
             RGBColor[
             0.5503444470429463, 0.6456286749821434, 0.9578509407709193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 131}], {
             RGBColor[
             0.713717410577787, 0.7734586299078415, 0.9367552125793581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 139}], {
             RGBColor[
             0.3641987950929961, 0.48703836026325886`, 0.9445311720236902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 143}], {
             RGBColor[
             0.49660113633650527`, 0.6021203742438899, 0.9535360157332124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 172}], {
             RGBColor[
             0.6184736647611668, 0.6988517376648496, 0.9646414244893339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 174}], {
             RGBColor[
             0.5258372766725488, 0.625855590041803, 0.9558375917959766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 183}], {
             RGBColor[
             0.40574366047363375`, 0.5258564982580921, 0.9470746051537166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 185}], {
             RGBColor[
             0.6771537171778658, 0.745372134998725, 0.970309892944168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 244}], {
             RGBColor[
             0.5517056595877123, 0.6466920645677131, 0.9579866137161271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 59}], {
             RGBColor[
             0.6379911693851391, 0.7140594437353637, 0.9666139123335463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 60}], {
             RGBColor[
             0.6817404099882227, 0.7497264132941596, 0.9700167427748274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 94}], {
             RGBColor[
             0.5531292556545647, 0.6377222556379696, 0.9613103551864237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 100}], {
             RGBColor[
             0.6921092376432518, 0.7581442946948749, 0.9708330148700984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 121}], {
             RGBColor[
             0.5968678663048883, 0.6784405055245616, 0.9639935718251817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 124}], {
             RGBColor[
             0.5639776799786095, 0.64912463743237, 0.9619281569028726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 125}], {
             RGBColor[
             0.5999483338153753, 0.6811086516533464, 0.9641898564909996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 137}], {
             RGBColor[
             0.5802762697230959, 0.6640696984833043, 0.9629363699623628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 150}], {
             RGBColor[
             0.6319241587891792, 0.7088045040939621, 0.9662273277832185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 170}], {
             RGBColor[
             0.8317506297351467, 0.8686793911541503, 0.9838143116483327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 192}], {
             RGBColor[
             0.563579677077281, 0.6487063111482322, 0.9619054912264344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 195}], {
             RGBColor[
             0.7140024449317186, 0.775918186649401, 0.9725565283453073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 200}], {
             RGBColor[
             0.5552808519200347, 0.639983719732061, 0.9614328854107408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 256}], {
             RGBColor[
             0.6424233481823314, 0.7178070513066872, 0.9669215596463246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 299}], {
             RGBColor[
             0.881978861186351, 0.9087276115019991, 0.9885216382513682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 53}], {
             RGBColor[
             0.36208952122731786`, 0.4880454769637687, 0.944293002002781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 68}], {
             RGBColor[
             0.38448623035814034`, 0.5074443807215553, 0.9457201005039647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 195}], {
             RGBColor[
             0.490451373055397, 0.595247657836371, 0.9535713504434022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 200}], {
             RGBColor[
             0.3317297800437131, 0.4593131909190311, 0.9424477075088358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 215}], {
             RGBColor[
             0.4474541312883693, 0.5603405599662303, 0.9501864500674155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 223}], {
             RGBColor[
             0.3382344559127318, 0.4661500176776401, 0.9428181391767707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 225}], {
             RGBColor[
             0.43909623033181344`, 0.553555239450551, 0.9495284854881154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 234}], {
             RGBColor[
             0.4979261177042418, 0.6013159922757123, 0.9541597897230512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 255}], {
             RGBColor[
             0.36441852475457925`, 0.4900627427599616, 0.9444414040480811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 282}], {
             RGBColor[
             0.5737826542132586, 0.6609980318077207, 0.9614317064678328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 287}], {
             RGBColor[
             0.508435835165051, 0.6098482543677732, 0.9549871531799295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 50}], {
             RGBColor[
             0.6884291221419363, 0.39371259566108535`, 0.5613430627256325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 108}], {
             RGBColor[
             0.6047186096264844, 0.6898613479331803, 0.9621037700102288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 114}], {
             RGBColor[
             0.6509367572331151, 0.7259673161144121, 0.966710363030512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 145}], {
             RGBColor[
             0.40451277869621244`, 0.51642725155905, 0.9479936869748238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 169}], {
             RGBColor[
             0.687785185854632, 0.7547535886119712, 0.9703830700273612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 187}], {
             RGBColor[
             0.6386498870733448, 0.7163687197619277, 0.965485722640316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 213}], {
             RGBColor[
             0.4337330205478802, 0.5471395784154914, 0.9496577365208023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 219}], {
             RGBColor[
             0.7470001353240479, 0.8019380323744507, 0.9760395232103662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 221}], {
             RGBColor[
             0.5796893956786342, 0.6696569919784139, 0.9600544191814973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 264}], {
             RGBColor[
             0.6627292987304381, 0.7351797391587556, 0.9678857333593993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 48}], {
             RGBColor[
             0.30355098818144594`, 0.4338771699713059, 0.9406898553585262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 74}], {
             RGBColor[
             0.3476112033085938, 0.47203991378363874`, 0.9434973333055097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 90}], {
             RGBColor[
             0.262305442782842, 0.3930300298633731, 0.9382492789691306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.29026037205339345`, 0.42236550628697656`, 0.9398429890512772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 166}], {
             RGBColor[
             0.40936876727182114`, 0.5229747548133055, 0.9481388273157618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 177}], {
             RGBColor[
             0.33393986158332284`, 0.46019848472282365`, 0.9426262074998681]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 217}], {
             RGBColor[
             0.5822842067614697, 0.6601037793652926, 0.9642223496897089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 233}], {
             RGBColor[
             0.43209841666643745`, 0.5414277081508914, 0.9499281885775551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 262}], {
             RGBColor[
             0.3858086068370497, 0.5038475551992257, 0.9462840851826252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 273}], {
             RGBColor[
             0.35141407572733685`, 0.4753337707348285, 0.9437396489732839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 74}], {
             RGBColor[
             0.37989499975481034`, 0.5034676875349107, 0.9454275513497863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 84}], {
             RGBColor[
             0.5444782832084554, 0.6361843353423295, 0.9593239361772548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 90}], {
             RGBColor[
             0.29458923922905855`, 0.424457803614645, 0.9401794970134072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 144}], {
             RGBColor[
             0.3660478185272966, 0.49147395513520326`, 0.9445452212065508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 158}], {
             RGBColor[
             0.32254416849961, 0.4537932800382485, 0.9417732070955538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 175}], {
             RGBColor[
             0.4705748884172028, 0.5778829746912393, 0.9523459167063231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 177}], {
             RGBColor[
             0.3662236580295394, 0.4916262584740956, 0.944556425544145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 217}], {
             RGBColor[
             0.6145680032076862, 0.6915315531165644, 0.9661525677339857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 252}], {
             RGBColor[
             0.3955223911189043, 0.5169519763080077, 0.9464375091926447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 253}], {
             RGBColor[
             0.5726898519753627, 0.6582234272789015, 0.9621358016998407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 57}], {
             RGBColor[
             0.5557928295411378, 0.650256683059958, 0.9581731939591476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 84}], {
             RGBColor[
             0.6863933361831619, 0.7545873132872862, 0.9696146177633359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 112}], {
             RGBColor[
             0.6113867964831234, 0.6953903699031319, 0.9625497546842317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 115}], {
             RGBColor[
             0.6802422098403156, 0.749782006637963, 0.9690015309750248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 146}], {
             RGBColor[
             0.6956813693859571, 0.7618431954169766, 0.9705403621113854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 159}], {
             RGBColor[
             0.5818612281737032, 0.6714201834378499, 0.9602253937911938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 175}], {
             RGBColor[
             0.6124899413919093, 0.696285952636196, 0.9626365982924042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 204}], {
             RGBColor[
             0.6204560956846561, 0.702753235562209, 0.963263723139314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 242}], {
             RGBColor[
             0.5059426937921485, 0.6081271566849679, 0.9547071788553331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 243}], {
             RGBColor[
             0.4873227619428383, 0.5919995075820816, 0.9535207332628542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 253}], {
             RGBColor[
             0.7146049049500692, 0.7766264052238582, 0.9724264832859218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 280}], {
             RGBColor[
             0.5322294056777556, 0.6308953853117255, 0.9563821448922574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 292}], {
             RGBColor[
             0.4637476509159343, 0.5714952788947997, 0.952021647575209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 87}], {
             RGBColor[
             0.6806676434432128, 0.3874114776028309, 0.5607320506912358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 108}], {
             RGBColor[
             0.7336084874845481, 0.430275752272095, 0.5649787072845964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 114}], {
             RGBColor[
             0.7798266350911789, 0.46638172045332676`, 0.5695853003048795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 169}], {
             RGBColor[
             0.8166750637126958, 0.4951679929508858, 0.5732580073017287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 187}], {
             RGBColor[
             0.7675397649314086, 0.4567831241008423, 0.5683606599146835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 205}], {
             RGBColor[
             0.652465579142112, 0.3645157713146789, 0.5585118808818876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 213}], {
             RGBColor[
             0.562622898405944, 0.28755398275440613`, 0.5525326737951698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 227}], {
             RGBColor[
             0.7505313987725166, 0.4434960591891454, 0.5666654249281837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 264}], {
             RGBColor[
             0.7916191765885018, 0.47559414349767026`, 0.5707606706337669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 52}], {
             RGBColor[
             0.7715141260160722, 0.8215034455840564, 0.9778420074698697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 58}], {
             RGBColor[
             0.6684194091041142, 0.7389070325162224, 0.968973580472422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 66}], {
             RGBColor[
             0.6898440374949417, 0.7563005110124061, 0.9706602057003476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 67}], {
             RGBColor[
             0.6981575726687028, 0.763049813386957, 0.9713146776427088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 69}], {
             RGBColor[
             0.5891199110503238, 0.6717068421198378, 0.9635103630846634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 86}], {
             RGBColor[
             0.6263440261100024, 0.7039484996461085, 0.9658822507802736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[
             0.7223882324003044, 0.7827213545358525, 0.9732222039366117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 109}], {
             RGBColor[
             0.7414021727924627, 0.7979797588664518, 0.9748407293847421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 110}], {
             RGBColor[
             0.8002156036037575, 0.843925258014865, 0.9807027025252526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 138}], {
             RGBColor[
             0.672736201935694, 0.7424115994061997, 0.9693134142170571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 141}], {
             RGBColor[
             0.5848954832956842, 0.6680478551246816, 0.9632411862836525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 154}], {
             RGBColor[
             0.6356756073300287, 0.7120310462799859, 0.9664768508840205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 165}], {
             RGBColor[
             0.6838409457625572, 0.7514269307078556, 0.9701876203291246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 179}], {
             RGBColor[
             0.8835885150964957, 0.9099451665376975, 0.9863890115758058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 258}], {
             RGBColor[
             0.6932771640447087, 0.7590876778060955, 0.9709304739983022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 281}], {
             RGBColor[
             0.526640883637262, 0.609797293014692, 0.9598146076402002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 82}], {
             RGBColor[
             0.8243551939243623, 0.8636374788015486, 0.9828820356987407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 86}], {
             RGBColor[
             0.5690305523147274, 0.6591032987937189, 0.9601887478053623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 107}], {
             RGBColor[
             0.6650747586050295, 0.7378761536834628, 0.9675287009617004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 110}], {
             RGBColor[
             0.7429021298084826, 0.7990800571624752, 0.9750091995503414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 141}], {
             RGBColor[
             0.5275820095004093, 0.6232026542722919, 0.9575476833087413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 165}], {
             RGBColor[
             0.6265274719672822, 0.706581729855466, 0.9644941173542134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 179}], {
             RGBColor[
             0.8262750413012208, 0.8650999656853078, 0.9806955086008946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 193}], {
             RGBColor[
             0.5024161311236448, 0.5997304361754252, 0.9560054583919029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 236}], {
             RGBColor[
             0.6119004602462057, 0.6947068628009272, 0.9633426254110209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 266}], {
             RGBColor[
             0.5451744631033641, 0.6384403533607433, 0.9586686588959257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 281}], {
             RGBColor[
             0.46932740984198723`, 0.5649520921623022, 0.9541211046652889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 59}], {
             RGBColor[
             0.39546641969873725`, 0.5169548688480174, 0.9464197484593474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 68}], {
             RGBColor[
             0.36551255254806014`, 0.49101033464723903`, 0.9445111145316709]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 150}], {
             RGBColor[
             0.3893994091027773, 0.511699929206616, 0.9460331639090196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 170}], {
             RGBColor[
             0.5892258800487448, 0.671574816266804, 0.9636201477741337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 192}], {
             RGBColor[
             0.32105492739087904`, 0.45160173626088596`, 0.9417113273522355]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 195}], {
             RGBColor[
             0.4714776952453168, 0.5788136117620548, 0.9523623644711083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 200}], {
             RGBColor[
             0.3127561022336329, 0.4428791448447148, 0.9412387215365419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 225}], {
             RGBColor[
             0.4201225525217332, 0.5371211933762347, 0.9483194995158216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 234}], {
             RGBColor[
             0.4789524398941616, 0.5848819462013961, 0.9529508037507572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 255}], {
             RGBColor[
             0.34544484694449906`, 0.47362869668564533`, 0.9432324180757874]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 282}], {
             RGBColor[
             0.5548089764031784, 0.6445639857334045, 0.9602227204955391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 287}], {
             RGBColor[
             0.48946215735497073`, 0.593414208293457, 0.9537781672076358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 72}], {
             RGBColor[
             0.6453249107785048, 0.7204137749675623, 0.9669506365984544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 106}], {
             RGBColor[
             0.7080893211524399, 0.7703591579784376, 0.9729640318223356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 151}], {
             RGBColor[
             0.6578665370639681, 0.7303128732074475, 0.9681737378415686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 167}], {
             RGBColor[
             0.5742215300402698, 0.6648672735291444, 0.9598637161053385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 194}], {
             RGBColor[
             0.5236155783974381, 0.6241337410128576, 0.9556400828799608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 238}], {
             RGBColor[
             0.5746353611580233, 0.6651905615435665, 0.9599049629236844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 251}], {
             RGBColor[
             0.4421873077754202, 0.5566109721486769, 0.9496208940521441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 286}], {
             RGBColor[
             0.4116292802791209, 0.5301431446225024, 0.9476737635614827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 90}], {
             RGBColor[
             0.2967045277823782, 0.42628996024203647`, 0.9403142813295485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 97}], {
             RGBColor[
             0.32512248720883224`, 0.4560264901141105, 0.9419374952837878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 134}], {
             RGBColor[
             0.4147113906847264, 0.5326453406972644, 0.9479163985827543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 144}], {
             RGBColor[
             0.3681631070806163, 0.49330611176259476`, 0.944680005522692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 159}], {
             RGBColor[
             0.44206146375231636`, 0.5548493621202848, 0.9500694965212537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 235}], {
             RGBColor[
             0.38755636415940675`, 0.5101035763108006, 0.9459157267149687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 252}], {
             RGBColor[
             0.39763767967222396`, 0.5187841329353992, 0.9465722935087859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 253}], {
             RGBColor[
             0.5748051405286824, 0.6600555839062929, 0.9622705860159819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 292}], {
             RGBColor[
             0.3239478864945474, 0.45492445757723443`, 0.9418657503052691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 79}], {
             RGBColor[
             0.46515792026877134`, 0.5635840979236262, 0.9534064340656645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 93}], {
             RGBColor[
             0.4113042080267503, 0.5206215174398904, 0.9486484261003314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 160}], {
             RGBColor[
             0.2948650242734049, 0.4233202090466253, 0.9402474689450688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 164}], {
             RGBColor[
             0.4718673553703112, 0.5688255596185445, 0.9540751678533501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 168}], {
             RGBColor[
             0.43724257509403663`, 0.5416794523352337, 0.9506903893712375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 246}], {
             RGBColor[
             0.4118519267764854, 0.5210661801953739, 0.9486915445266704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 296}], {
             RGBColor[
             0.30721059959564917`, 0.4340133258840956, 0.9410341180878385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.6225212751472242, 0.702733096734753, 0.9645863751475181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 89}], {
             RGBColor[
             0.5445765561211107, 0.6411508070102205, 0.9572902078289597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 112}], {
             RGBColor[
             0.5475147354471859, 0.6435361533505985, 0.9575215120684137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 115}], {
             RGBColor[
             0.616370148804378, 0.6979277900854297, 0.9639732883592069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 134}], {
             RGBColor[
             0.4906390940701756, 0.5973619454622965, 0.9530440532368765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 146}], {
             RGBColor[
             0.6318093083500196, 0.7099889788644436, 0.9655121194955676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 159}], {
             RGBColor[
             0.5179891671377657, 0.6195659668853168, 0.9551971511753758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 175}], {
             RGBColor[
             0.5486178803559716, 0.6444317360836628, 0.9576083556765864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 204}], {
             RGBColor[
             0.5565840346487184, 0.6508990190096757, 0.958235480523496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 235}], {
             RGBColor[
             0.463484067544856, 0.5748201810758327, 0.9510433813690908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 242}], {
             RGBColor[
             0.44207063275621084`, 0.5562729401324347, 0.9496789362395153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 243}], {
             RGBColor[
             0.42345070090690073`, 0.5401452910295486, 0.9484924906470364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 253}], {
             RGBColor[
             0.6507328439141316, 0.724772188671325, 0.967398240670104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 280}], {
             RGBColor[
             0.46835734464181794`, 0.5790411687591923, 0.9513539022764395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 292}], {
             RGBColor[
             0.3998755898799966, 0.5196410623422665, 0.9469934049593911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 66}], {
             RGBColor[
             0.5294358467877089, 0.6288588970921825, 0.9560982757279886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 67}], {
             RGBColor[
             0.53774938196147, 0.6356081994667333, 0.9567527476703498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 73}], {
             RGBColor[
             0.5073229465160976, 0.6109066484768835, 0.9543574672163846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 95}], {
             RGBColor[
             0.4525151641021228, 0.5648825747878173, 0.950465167500071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 96}], {
             RGBColor[
             0.39969046039220407`, 0.517521914042194, 0.9471580480284807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 109}], {
             RGBColor[
             0.5809939820852299, 0.6705381449462281, 0.9602787994123831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 138}], {
             RGBColor[
             0.5123280112284612, 0.614969985485976, 0.954751484244698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 140}], {
             RGBColor[
             0.38977613464132843`, 0.5071013290734647, 0.9465934418438988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 154}], {
             RGBColor[
             0.4752674166227959, 0.5845894323597622, 0.9519149209116614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 171}], {
             RGBColor[
             0.5924956797981799, 0.6795233586157249, 0.9614251811509338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 198}], {
             RGBColor[
             0.4131585478899986, 0.5307938519459227, 0.9479573987167237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[
             0.5401431052774719, 0.6375515318906702, 0.956941190338283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 62}], {
             RGBColor[
             0.7213430561104444, 0.776866095097144, 0.8163343158531764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 100}], {
             RGBColor[
             0.5019350642383495, 0.6063831577660936, 0.9539745834247597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 125}], {
             RGBColor[
             0.409774160410473, 0.5293475147245652, 0.9473314250456608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 137}], {
             RGBColor[
             0.39010209631819354`, 0.5123085615545231, 0.946077938517024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 170}], {
             RGBColor[
             0.6415764563302444, 0.716918254225369, 0.966955880202994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 192}], {
             RGBColor[
             0.3734055036723786, 0.49694517421945095`, 0.9450470597810957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 195}], {
             RGBColor[
             0.5238282715268163, 0.6241570497206198, 0.9556980968999687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 200}], {
             RGBColor[
             0.3651066785151325, 0.4882225828032798, 0.9445744539654022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 225}], {
             RGBColor[
             0.4724731288032328, 0.5824646313347996, 0.9516552319446818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 228}], {
             RGBColor[
             0.3363866462464521, 0.45803600793367755`, 0.942938890615181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 255}], {
             RGBColor[
             0.39779542322599865`, 0.5189721346442103, 0.9465681505046475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.7349126064071658, 0.7921244793978024, 0.9750883543366462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 85}], {
             RGBColor[
             0.44495262365760546`, 0.5575909077174315, 0.9501881331326616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 100}], {
             RGBColor[
             0.5456843048414332, 0.6420501273248895, 0.9573774138660407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 121}], {
             RGBColor[
             0.45044293350306974`, 0.5623463381545762, 0.9505379708211241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 125}], {
             RGBColor[
             0.4535234010135567, 0.5650144842833611, 0.9507342554869419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 127}], {
             RGBColor[
             0.4132213206247025, 0.5284778661278345, 0.9482258875644447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.4227475449348834, 0.5383579845875173, 0.9487732451516298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 137}], {
             RGBColor[
             0.4338513369212772, 0.547975531113319, 0.9494807689583051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 170}], {
             RGBColor[
             0.685325696933328, 0.7525852237841649, 0.970358710644275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 232}], {
             RGBColor[
             0.40950333598576016`, 0.5245700285384647, 0.9480141538395224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 240}], {
             RGBColor[
             0.7391774600781544, 0.7953358681361286, 0.9689323432584322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 256}], {
             RGBColor[
             0.4959984153805128, 0.6017128839367019, 0.9534659586422669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 299}], {
             RGBColor[
             0.7355539283845324, 0.7926334441320138, 0.9750660372473104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 177}], {
             RGBColor[
             0.5126703718955063, 0.6137082428795742, 0.955203856075607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 217}], {
             RGBColor[
             0.7610147170736532, 0.813613537522043, 0.9767999982654477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 247}], {
             RGBColor[
             0.7541179940347312, 0.8081142777773664, 0.976142182665218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 267}], {
             RGBColor[
             0.47307024743148685`, 0.5794086054289683, 0.9526805711617747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 273}], {
             RGBColor[
             0.5301445860395203, 0.628843528891579, 0.9563172975490226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 285}], {
             RGBColor[
             0.5235600210377769, 0.6231403096369288, 0.9558977348896138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 82}], {
             RGBColor[
             0.9646894259342895, 0.9710252981295682, 0.838264358860334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 100}], {
             RGBColor[
             0.775461124368557, 0.8209509460566552, 0.8205534183897285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 127}], {
             RGBColor[
             0.6429981401518263, 0.7073786848596003, 0.8114018920881325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 130}], {
             RGBColor[
             0.7512413596392364, 0.8012882499614257, 0.8186467497903148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 137}], {
             RGBColor[
             0.663628156448401, 0.7268763498450848, 0.8126567734819927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 170}], {
             RGBColor[
             0.9151025164604518, 0.9314860425159306, 0.8335347151679626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 192}], {
             RGBColor[
             0.6469315638025861, 0.7115129625100125, 0.8116258947460644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 195}], {
             RGBColor[
             0.7973543316570239, 0.8387248380111814, 0.8222769318649373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 199}], {
             RGBColor[
             0.7064681558619851, 0.7639822041361536, 0.8153865003627023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 220}], {
             RGBColor[
             0.7699420676813191, 0.8164703272072851, 0.8201189380303383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 225}], {
             RGBColor[
             0.7459991889334403, 0.7970324196253613, 0.8182340669096506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 226}], {
             RGBColor[
             0.752658545235028, 0.8024387850715727, 0.8187583158317374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 228}], {
             RGBColor[
             0.6099127063766596, 0.6726037962242392, 0.8095177255801498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 255}], {
             RGBColor[
             0.6713214833562061, 0.7335399229347719, 0.8131469854696163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 131}], {
             RGBColor[
             0.8137574359538291, 0.8546345149752614, 0.9446921758968597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 139}], {
             RGBColor[
             0.46423882046903825`, 0.5682142453306788, 0.9524681353411917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 143}], {
             RGBColor[
             0.5966411617125474, 0.6832962593113099, 0.9614729790507139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 172}], {
             RGBColor[
             0.7185136901372089, 0.7800276227322696, 0.9725783878068355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 174}], {
             RGBColor[
             0.625877302048591, 0.7070314751092229, 0.9637745551134782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 183}], {
             RGBColor[
             0.5057836858496759, 0.607032383325512, 0.9550115684712182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 283}], {
             RGBColor[
             0.7153032772859222, 0.777519623812803, 0.9722584038568329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 92}], {
             RGBColor[
             0.5736486472811236, 0.6647528402967007, 0.9595788693396547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 145}], {
             RGBColor[
             0.3788990301699833, 0.49563285661923573`, 0.9459772788645866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 153}], {
             RGBColor[
             0.3899263990585947, 0.5072233204967364, 0.9466052712092627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 211}], {
             RGBColor[
             0.34361937361570705`, 0.45855170072127105`, 0.9439681546153953]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 219}], {
             RGBColor[
             0.7213863867978187, 0.7811436374346364, 0.9740231151001291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 221}], {
             RGBColor[
             0.5540756471524051, 0.6488625970385996, 0.9580380110712601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 80}], {
             RGBColor[
             0.8069691458507807, 0.8491614015301979, 0.9813863875675013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 103}], {
             RGBColor[
             0.5699833668046019, 0.655300956571774, 0.9622130948099488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 116}], {
             RGBColor[
             0.7931830147610572, 0.838391571144429, 0.9800123148591975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 133}], {
             RGBColor[
             0.5575168568308793, 0.6428741104533859, 0.9614783848202754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 152}], {
             RGBColor[
             0.6854952944201675, 0.7528056146717598, 0.9702768711839236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 162}], {
             RGBColor[
             0.6254418051562254, 0.7033362684497907, 0.9657468574617427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[
             0.7206305035291226, 0.7813299602495423, 0.9730428435494922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 241}], {
             RGBColor[
             0.6018498518693464, 0.682902104278746, 0.9642435990598479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 277}], {
             RGBColor[
             0.5974565268773873, 0.6790968269856457, 0.9639636602762252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 67}], {
             RGBColor[
             0.5591740103522975, 0.6530016779629171, 0.9584393728982754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 69}], {
             RGBColor[
             0.4501363487339184, 0.5616587066957979, 0.95063505834023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 95}], {
             RGBColor[
             0.4739397924929502, 0.582276053284001, 0.9521517927279967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 109}], {
             RGBColor[
             0.6024186104760573, 0.6879316234424118, 0.9619654246403087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 110}], {
             RGBColor[
             0.6612320412873521, 0.7338771225908249, 0.9678273977808192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 138}], {
             RGBColor[
             0.5337526396192886, 0.6323634639821597, 0.9564381094726236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 154}], {
             RGBColor[
             0.49669204501362335`, 0.601982910855946, 0.953601546139587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 179}], {
             RGBColor[
             0.7446049527800903, 0.7998970311136575, 0.9735137068313724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 258}], {
             RGBColor[
             0.5542936017283033, 0.6490395423820556, 0.9580551692538688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 69}], {
             RGBColor[
             0.45844988390767955`, 0.5684080090703487, 0.9512895302825912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 86}], {
             RGBColor[
             0.49567399896735814`, 0.6006496665966194, 0.9536614179782015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 95}], {
             RGBColor[
             0.48225332766671136`, 0.589025355658552, 0.9528062646703579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 109}], {
             RGBColor[
             0.6107321456498185, 0.6946809258169627, 0.96261989658267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 110}], {
             RGBColor[
             0.6695455764611133, 0.7406264249653759, 0.9684818697231804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 138}], {
             RGBColor[
             0.5420661747930497, 0.6391127663567107, 0.9570925814149849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 154}], {
             RGBColor[
             0.5050055801873845, 0.6087322132304969, 0.9542560180819483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 179}], {
             RGBColor[
             0.7529184879538515, 0.8066463334882085, 0.9741681787737336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 258}], {
             RGBColor[
             0.5626071369020645, 0.6557888447566065, 0.9587096411962299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 215}], {
             RGBColor[
             0.4508771626091116, 0.5633054176497007, 0.9504045625963053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 223}], {
             RGBColor[
             0.3416574872334741, 0.4691148753611104, 0.9430362517056607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 234}], {
             RGBColor[
             0.5013491490249841, 0.6042808499591826, 0.954377902251941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 255}], {
             RGBColor[
             0.36784155607532154`, 0.4930276004434319, 0.9446595165769711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 271}], {
             RGBColor[
             0.369074912224053, 0.49409587154918067`, 0.9447381049401542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 274}], {
             RGBColor[
             0.5889705018908431, 0.6731536534450722, 0.9628224259427132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 287}], {
             RGBColor[
             0.5118588664857933, 0.6128131120512437, 0.9552052657088195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 109}], {
             RGBColor[
             0.5016944840314393, 0.6033379545498435, 0.9548155820246245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 110}], {
             RGBColor[
             0.5605079148427342, 0.6492834536982567, 0.960677555165135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 113}], {
             RGBColor[
             0.3164330175989031, 0.4461616727763934, 0.9414694315430614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 135}], {
             RGBColor[
             0.475391176983747, 0.582161713986056, 0.9526232109315407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 138}], {
             RGBColor[
             0.43302851317467067`, 0.5477697950895914, 0.9492882668569395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 224}], {
             RGBColor[
             0.4964414416979015, 0.5992342379542833, 0.9542920078572892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 249}], {
             RGBColor[
             0.44937360685470584`, 0.561039478477123, 0.9505750125054828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 254}], {
             RGBColor[
             0.42488112211408524`, 0.5411553759908236, 0.9486468743877734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 258}], {
             RGBColor[
             0.45356947528368546`, 0.5644458734894873, 0.9509053266381846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 288}], {
             RGBColor[
             0.40286284926025995`, 0.5232799501761999, 0.9469135152931292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[
             0.7118443636584767, 0.7748174941983255, 0.9719136516718349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 251}], {
             RGBColor[
             0.5793963102758737, 0.6662379048034359, 0.9616295828002945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 300}], {
             RGBColor[
             0.568516837278211, 0.6568146521110728, 0.9609363524012238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 85}], {
             RGBColor[
             0.36109613583466665`, 0.4871850564656558, 0.9442297043639775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 98}], {
             RGBColor[
             0.3788348576306416, 0.5025494457112482, 0.9453600000310811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 121}], {
             RGBColor[
             0.36658644568013093`, 0.4919404869028005, 0.9445795420524401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 122}], {
             RGBColor[
             0.3574590829462019, 0.48403482405726106`, 0.9439979545700441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 136}], {
             RGBColor[
             0.33889105711194467`, 0.46795213333574154`, 0.9428148163829457]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 160}], {
             RGBColor[
             0.35943825717782063`, 0.4857490853005, 0.9441240658019677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 181}], {
             RGBColor[
             0.5848823177903584, 0.6690974831408106, 0.9627799835946671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 207}], {
             RGBColor[
             0.4146595045732696, 0.53335091512182, 0.9477057227584469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 232}], {
             RGBColor[
             0.3256468481628214, 0.454164177286689, 0.9420557250708383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 240}], {
             RGBColor[
             0.6553209722552158, 0.7249300168843529, 0.9629739144897482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 246}], {
             RGBColor[
             0.47642515968090116`, 0.5834950564492485, 0.9525681413835694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 256}], {
             RGBColor[
             0.412141927557574, 0.5313070326849262, 0.9475075298735829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 296}], {
             RGBColor[
             0.37178383250006497`, 0.4964422021379702, 0.9449107149447376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 299}], {
             RGBColor[
             0.6516974405615936, 0.7222275928802381, 0.9691076084786263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 106}], {
             RGBColor[
             0.8702210331070048, 0.8994559006783557, 0.9874567833329102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 151}], {
             RGBColor[
             0.819998249018533, 0.8594096159073656, 0.9826664893521432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 194}], {
             RGBColor[
             0.685747290352003, 0.7532304837127757, 0.9701328343905354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 215}], {
             RGBColor[
             0.6606508431362051, 0.7328560572809281, 0.9681571501343926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 247}], {
             RGBColor[
             0.8434821992214679, 0.8781350803443393, 0.9849064094868689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 267}], {
             RGBColor[
             0.5624344526182236, 0.6494294079959411, 0.9614447979834257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 286}], {
             RGBColor[
             0.5737609922336857, 0.6592398873224206, 0.9621665150720573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 87}], {
             RGBColor[
             0.5253254807608696, 0.625521916781715, 0.955774692657589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 95}], {
             RGBColor[
             0.4518268922213389, 0.5643238046687021, 0.9504109842163928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 96}], {
             RGBColor[
             0.3990021885114202, 0.5169631439230788, 0.9471038647448023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 105}], {
             RGBColor[
             0.41949223653641243`, 0.5363171511014679, 0.9483506485485627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 140}], {
             RGBColor[
             0.3890878627605445, 0.5065425589543495, 0.9465392585602206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 149}], {
             RGBColor[
             0.6076696692244101, 0.6913563075873002, 0.9629519998330789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 171}], {
             RGBColor[
             0.5918074079173961, 0.6789645884966097, 0.9613709978672556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 245}], {
             RGBColor[
             0.539454833396688, 0.636992761771555, 0.9568870070546046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 289}], {
             RGBColor[
             0.4309716157453273, 0.5462600124018548, 0.9490821044409381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 298}], {
             RGBColor[
             0.48816482306077325`, 0.595353220792225, 0.9528492695594629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 90}], {
             RGBColor[
             0.3386494543562064, 0.4626205474269779, 0.9429869749603906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 123}], {
             RGBColor[
             0.374210646947409, 0.49854418683701895`, 0.9450653494153746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 158}], {
             RGBColor[
             0.36660438362675785`, 0.49195602385058135`, 0.9445806850425372]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 233}], {
             RGBColor[
             0.5084424282398019, 0.6110182257144962, 0.9546658845688152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 257}], {
             RGBColor[
             0.6514224458788822, 0.7239486095680041, 0.9682727526714514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 259}], {
             RGBColor[
             0.49780276929276285`, 0.6023804712701164, 0.9538282916421494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 262}], {
             RGBColor[
             0.4621526184104141, 0.5734380727628305, 0.9510217811738853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 124}], {
             RGBColor[
             0.3928675427985966, 0.5129899090923822, 0.9465292461852803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 142}], {
             RGBColor[
             0.7200222699023658, 0.7794195827037129, 0.9576281619589232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 143}], {
             RGBColor[
             0.5144214597180611, 0.616669541278613, 0.9549162881783538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 150}], {
             RGBColor[
             0.4608140216091663, 0.5726697757539744, 0.9508284170656263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 167}], {
             RGBColor[
             0.5755974648433075, 0.665984319387407, 0.9599720347332488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 174}], {
             RGBColor[
             0.5436576000541046, 0.6404047570765259, 0.957217864241118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 185}], {
             RGBColor[
             0.6949740405594216, 0.7599213020334481, 0.9716901653893095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 237}], {
             RGBColor[
             0.66602288626804, 0.7368364374596487, 0.968928778447997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 239}], {
             RGBColor[
             0.599519313932471, 0.6846722497086484, 0.9623563410880669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 282}], {
             RGBColor[
             0.6262235889095674, 0.7055338322807629, 0.9650179736521458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 283}], {
             RGBColor[
             0.6330835752914359, 0.7108929057801061, 0.9657017129844728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 295}], {
             RGBColor[
             0.5267075251069893, 0.6266439226422831, 0.9558834922511107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 297}], {
             RGBColor[
             0.7181654835024863, 0.7780347944468915, 0.9607712170064664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 99}], {
             RGBColor[
             0.36694967035543324`, 0.4922550938603444, 0.9446026864075634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[
             0.46109946786225064`, 0.5698342449699797, 0.9516983839794617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 128}], {
             RGBColor[
             0.5079109206863072, 0.607060542135493, 0.9559150308257226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[
             0.34505815226411674`, 0.4732937611893379, 0.943207778232694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 201}], {
             RGBColor[
             0.6311097048290799, 0.7041723264483579, 0.9645382362668569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 209}], {
             RGBColor[
             0.3868634575884775, 0.5095034154655586, 0.9458715753209823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 218}], {
             RGBColor[
             0.4388328285685045, 0.5517571840906476, 0.9499454725688707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 229}], {
             RGBColor[
             0.4457668726215972, 0.5573865534280731, 0.9504913459169705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 261}], {
             RGBColor[
             0.3393709223332954, 0.4683677684717482, 0.9428453929705221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 284}], {
             RGBColor[
             0.3363779611159017, 0.4657754158958465, 0.9426546841283214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 91}], {
             RGBColor[
             0.46371634604923656`, 0.5725170645414389, 0.9517501287449879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 162}], {
             RGBColor[
             0.3851286862451803, 0.5080008437201375, 0.9457610372249855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 191}], {
             RGBColor[
             0.38652558506246204`, 0.509210767265491, 0.9458500463823936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 203}], {
             RGBColor[
             0.49046531867082066`, 0.5942330855431252, 0.9538559058544742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 206}], {
             RGBColor[
             0.4404110596017123, 0.5535967831121488, 0.9499154512257615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 244}], {
             RGBColor[
             0.4981936046425942, 0.6003426121683367, 0.9545768728938765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 270}], {
             RGBColor[
             0.3694712221930891, 0.4944391353252414, 0.9447633574609381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 118}], {
             RGBColor[
             0.6242743086763201, 0.7015219556290029, 0.966042170239591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 120}], {
             RGBColor[
             0.6125473380690725, 0.6913646431036858, 0.9652949380422502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 130}], {
             RGBColor[
             0.6774367621042349, 0.7460943478457321, 0.9698369752366216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 176}], {
             RGBColor[
             0.7204501623391966, 0.7810145638880723, 0.9732231476663946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 193}], {
             RGBColor[
             0.5689457655985706, 0.6519243533877512, 0.962578006999803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.6326635583269835, 0.7087883020204601, 0.9665767258090092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 220}], {
             RGBColor[
             0.6961374701463175, 0.7612764250915915, 0.9713091634766451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 226}], {
             RGBColor[
             0.6788539477000264, 0.7472448829558792, 0.9699485412780442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 236}], {
             RGBColor[
             0.6784300947211315, 0.7469007800132532, 0.969915174018921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 266}], {
             RGBColor[
             0.6117040975782898, 0.6906342705730693, 0.9652412075038258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 93}], {
             RGBColor[
             0.6380060925638265, 0.7162428244506429, 0.9651637696463923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 103}], {
             RGBColor[
             0.5039599944081469, 0.6036912917513249, 0.955640915474596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 116}], {
             RGBColor[
             0.7271596423646022, 0.7867819063239798, 0.9734401355238447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 119}], {
             RGBColor[
             0.5195877345788624, 0.617227254814139, 0.956636701259206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 164}], {
             RGBColor[
             0.6985692399073875, 0.7644468666292972, 0.9705905113994111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 168}], {
             RGBColor[
             0.6639444596311129, 0.7373007593459863, 0.9672057329172983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 241}], {
             RGBColor[
             0.5358264794728913, 0.6312924394582968, 0.9576714197244952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[
             0.5314331544809321, 0.6274871621651965, 0.9573914809408723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 103}], {
             RGBColor[
             0.5530459630566249, 0.6420376235266949, 0.9605333460950192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 116}], {
             RGBColor[
             0.7762456110130802, 0.8251282380993499, 0.9783325661442678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 133}], {
             RGBColor[
             0.5405794530829022, 0.6296107774083068, 0.9597986361053457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 152}], {
             RGBColor[
             0.6685578906721905, 0.7395422816266807, 0.9685971224689939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 210}], {
             RGBColor[
             0.7036930997811456, 0.7680666272044632, 0.9713630948345625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 241}], {
             RGBColor[
             0.5849124481213693, 0.6696387712336669, 0.9625638503449183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 277}], {
             RGBColor[
             0.5805191231294102, 0.6658334939405666, 0.9622839115612954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 180}], {
             RGBColor[
             0.47974593078383543`, 0.5880508945673009, 0.9523156724572878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[
             0.42040172473001874`, 0.5366499260100078, 0.9485343121235595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 285}], {
             RGBColor[
             0.47089149833630883`, 0.5803816302179682, 0.9517514758513985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 100}], {
             RGBColor[
             0.7452814340621947, 0.8005423607985177, 0.9759046264319173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 107}], {
             RGBColor[
             0.7752293003085946, 0.8248553877533448, 0.9782622321654826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 127}], {
             RGBColor[
             0.6128184498454641, 0.6869700996014628, 0.9667531001303213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 137}], {
             RGBColor[
             0.6334484661420388, 0.7064677645869473, 0.9680079815241817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 192}], {
             RGBColor[
             0.6167518734962238, 0.691104377251875, 0.9669771027882533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 199}], {
             RGBColor[
             0.6762884655556228, 0.7435736188780161, 0.9707377084048912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 220}], {
             RGBColor[
             0.7397623773749569, 0.7960617419491476, 0.9754701460725272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 226}], {
             RGBColor[
             0.7224788549286658, 0.7820301998134352, 0.9741095238739264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 228}], {
             RGBColor[
             0.5797330160702974, 0.6521952109661017, 0.9648689336223386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 266}], {
             RGBColor[
             0.6553290048069291, 0.7254195874306253, 0.9694021900997079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 281}], {
             RGBColor[
             0.5794819515455523, 0.6519313262321842, 0.964854635869071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 126}], {
             RGBColor[
             0.4161837012309455, 0.5348991368303697, 0.947739835319007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 155}], {
             RGBColor[
             0.3993368513310579, 0.5203072421943834, 0.9466663689404705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 156}], {
             RGBColor[
             0.607437447963322, 0.6874198256666942, 0.9647478578332733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 184}], {
             RGBColor[
             0.3380896788839917, 0.4659477079158353, 0.9428117302074407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[
             0.3901192346766518, 0.5123234059392208, 0.9460790305580702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 202}], {
             RGBColor[
             0.3586376256441649, 0.4850556185069582, 0.9440730502686139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 214}], {
             RGBColor[
             0.6878226545432805, 0.7473046546446837, 0.7690920722191105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 275}], {
             RGBColor[
             0.4907225262185325, 0.5954825170777248, 0.9535886280831858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 293}], {
             RGBColor[
             0.6106657635523014, 0.6899939968870542, 0.9650557774561016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 89}], {
             RGBColor[
             0.6751770627631348, 0.7454814372375489, 0.968731631633148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.5032327378098516, 0.5953371952343968, 0.956883359787859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 112}], {
             RGBColor[
             0.6781152420892099, 0.7478667835779269, 0.9689629358726022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 134}], {
             RGBColor[
             0.6212396007121996, 0.7016925756896247, 0.9644854770410648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 144}], {
             RGBColor[
             0.5746913171080896, 0.6623533467549549, 0.9612490839810025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 158}], {
             RGBColor[
             0.531187667080403, 0.6246726716580002, 0.9584770698700056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 159}], {
             RGBColor[
             0.6485896737797897, 0.723896597112645, 0.9666385749795643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 175}], {
             RGBColor[
             0.6792183869979957, 0.748762366310991, 0.9690497794807748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 252}], {
             RGBColor[
             0.6041658896996973, 0.6878313679277595, 0.9631413719670964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 253}], {
             RGBColor[
             0.7813333505561557, 0.8291028188986532, 0.9788396644742924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 280}], {
             RGBColor[
             0.598957851283842, 0.6833717989865206, 0.9627953260806279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 292}], {
             RGBColor[
             0.5304760965220208, 0.6239716925695947, 0.9584348287635795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[
             0.360080079974271, 0.4863049999478335, 0.9441649621830159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 122}], {
             RGBColor[
             0.35095271724034194`, 0.47839933710229404`, 0.9435833747006199]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 136}], {
             RGBColor[
             0.33238469140608473`, 0.4623166463807745, 0.9424002365135217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 165}], {
             RGBColor[
             0.44672203092128693`, 0.5590273922449771, 0.9503274273540109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 181}], {
             RGBColor[
             0.5783759520844984, 0.6634619961858437, 0.9623654037252429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 207}], {
             RGBColor[
             0.40815313886740967`, 0.527715428166853, 0.9472911428890229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 232}], {
             RGBColor[
             0.31914048245696147`, 0.44852869033172205`, 0.9416411452014142]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 240}], {
             RGBColor[
             0.6488146065493559, 0.7192945299293858, 0.9625593346203242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 246}], {
             RGBColor[
             0.4699187939750412, 0.5778595694942815, 0.9521535615141453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 256}], {
             RGBColor[
             0.40563556185171407`, 0.5256715457299592, 0.9470929500041588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 296}], {
             RGBColor[
             0.36527746679420503`, 0.49080671518300323`, 0.9444961350753135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 299}], {
             RGBColor[
             0.6451910748557337, 0.7165921059252711, 0.9686930286092024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 107}], {
             RGBColor[
             0.5199046586989597, 0.6203212077455149, 0.9555689442721043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 109}], {
             RGBColor[
             0.538918599091118, 0.6355796120761142, 0.9571874697202347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 110}], {
             RGBColor[
             0.5977320299024128, 0.6815251112245274, 0.9630494428607452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 141}], {
             RGBColor[
             0.38241190959433957`, 0.505647708334344, 0.9455879266191451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 165}], {
             RGBColor[
             0.48135737206121243`, 0.5890267839175181, 0.9525343606646173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 179}], {
             RGBColor[
             0.681104941395151, 0.74754501974736, 0.9687357519112985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 240}], {
             RGBColor[
             0.6834499476892812, 0.749293921601927, 0.9647662679309306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 281}], {
             RGBColor[
             0.3241573099359174, 0.4473971462243544, 0.9421613479756927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 149}], {
             RGBColor[
             0.6263604753499661, 0.7065303460112469, 0.9644234085579615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 187}], {
             RGBColor[
             0.6308884083746213, 0.7100676017036732, 0.9648747106059192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 227}], {
             RGBColor[
             0.6138800422157294, 0.6967805367919764, 0.9631794756194194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 264}], {
             RGBColor[
             0.6549678200317146, 0.7288786211005012, 0.9672747213250026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 99}], {
             RGBColor[
             0.4287559825435503, 0.545788615002116, 0.9485409299670142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[
             0.364892126631264, 0.4881345173945856, 0.9445572031198959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 198}], {
             RGBColor[
             0.382318158868569, 0.5055665061677301, 0.9455819529057996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 201}], {
             RGBColor[
             0.6929160170171969, 0.7577058475901295, 0.9684764798263078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 222}], {
             RGBColor[
             0.5465310592882033, 0.6424808482502629, 0.9575422932892104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 258}], {
             RGBColor[
             0.5020285843160464, 0.6064187181076794, 0.953993098215019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 260}], {
             RGBColor[
             0.5927854884071306, 0.6786151598246505, 0.9621525025115691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 261}], {
             RGBColor[
             0.4011772345214124, 0.5219012896135198, 0.9467836365299729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 278}], {
             RGBColor[
             0.4559774545245038, 0.5690323363631498, 0.950367784586982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 290}], {
             RGBColor[
             0.5748725651182767, 0.6646214480081385, 0.9603671097239217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 111}], {
             RGBColor[
             0.5801955866446996, 0.670067940608309, 0.9600942683885846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 112}], {
             RGBColor[
             0.6001705230630964, 0.6862844938533944, 0.9616667685540439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 175}], {
             RGBColor[
             0.6012736679718822, 0.6871800765864586, 0.9617536121622163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 177}], {
             RGBColor[
             0.4969224375842188, 0.6009233603693149, 0.9539641210000382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 242}], {
             RGBColor[
             0.4947264203721214, 0.5990212806352304, 0.9538241927251452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.5210131322577285, 0.6217895092619881, 0.9554991587620695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 285}], {
             RGBColor[
             0.5078120867264894, 0.6103554271266695, 0.9546579998140452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 123}], {
             RGBColor[
             0.28890488642165724`, 0.4195343029167533, 0.9398172950789955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 134}], {
             RGBColor[
             0.3713505567328028, 0.4899660439619402, 0.9453410378772173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 144}], {
             RGBColor[
             0.3248022731286927, 0.4506268150272705, 0.9421046448171551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 158}], {
             RGBColor[
             0.28129862310100606`, 0.4129461399303157, 0.9393326307061581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 252}], {
             RGBColor[
             0.3542768457203004, 0.47610483620007493`, 0.9439969328032489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 253}], {
             RGBColor[
             0.5314443065767589, 0.6173762871709687, 0.9596952253104449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[
             0.5661166853531305, 0.6449387256477385, 0.9630246983350723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 102}], {
             RGBColor[
             0.5118939746620538, 0.6142461049678395, 0.9548199646383922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 162}], {
             RGBColor[
             0.5055647205177491, 0.6087640231456057, 0.9544166701610568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 191}], {
             RGBColor[
             0.5069616193350309, 0.6099739466909593, 0.954505679318465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 203}], {
             RGBColor[
             0.6109013529433895, 0.6949962649685935, 0.9625115387905455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 239}], {
             RGBColor[
             0.6486229698783659, 0.7245368097000173, 0.9662219607567462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 153}], {
             RGBColor[
             0.4552632991083042, 0.5602667593508951, 0.9517488313181268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 163}], {
             RGBColor[
             0.551216501165881, 0.6465414135236804, 0.9578129286258041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 189}], {
             RGBColor[
             0.6819902801407756, 0.7514435802624599, 0.9689734074709997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 211}], {
             RGBColor[
             0.40895627366541654`, 0.5115951395754297, 0.9491117147242594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 216}], {
             RGBColor[
             0.5880901155712677, 0.6764770748353722, 0.9607157546242964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 221}], {
             RGBColor[
             0.6194125472021146, 0.7019060358927582, 0.9631815711801242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 94}], {
             RGBColor[
             0.4311227744204467, 0.5414520872893508, 0.9497770641375108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 160}], {
             RGBColor[
             0.46771319656846005`, 0.5759789355736422, 0.9520048045257965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 164}], {
             RGBColor[
             0.6447155276653664, 0.7214842861455614, 0.965832503434078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 168}], {
             RGBColor[
             0.6100907473890917, 0.6943381788622505, 0.9624477249519652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 277}], {
             RGBColor[
             0.477579442238911, 0.5845245816814607, 0.9526334729755392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 124}], {
             RGBColor[
             0.2889415928431328, 0.4210263124061947, 0.9397661683104113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 125}], {
             RGBColor[
             0.3249122466798986, 0.4530103266271711, 0.9420278678985383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 142}], {
             RGBColor[
             0.6160963199469021, 0.6874559860175256, 0.9508650840840542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 150}], {
             RGBColor[
             0.3568880716537025, 0.4807061790677869, 0.9440653391907573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 200}], {
             RGBColor[
             0.2802447647845581, 0.41188539470588575`, 0.9392708968182796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.5620969363125762, 0.6448728407734612, 0.9621657005731279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 295}], {
             RGBColor[
             0.4227815751515254, 0.5346803259560956, 0.9491204143762417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 96}], {
             RGBColor[
             0.3441944060974454, 0.47093907023401277`, 0.9432115650284887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 105}], {
             RGBColor[
             0.36468445412243766`, 0.49029307741240186`, 0.944458348832249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 109}], {
             RGBColor[
             0.5254979277904712, 0.6239553011380468, 0.9563323164123911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 138}], {
             RGBColor[
             0.4568319569337025, 0.5683871416777946, 0.9508050012447061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 140}], {
             RGBColor[
             0.33428008034656975`, 0.4605184852652834, 0.942646958843907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 154}], {
             RGBColor[
             0.41977136232803725`, 0.5380065885515809, 0.9479684379116695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 171}], {
             RGBColor[
             0.5369996255034212, 0.6329405148075435, 0.9574786981509419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 198}], {
             RGBColor[
             0.35766249359523994`, 0.4842110081377413, 0.9440109157167318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 245}], {
             RGBColor[
             0.4846470509827132, 0.5909686880824887, 0.952994707338291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 289}], {
             RGBColor[
             0.3761638333313525, 0.5002359387127887, 0.9451898047246245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 105}], {
             RGBColor[
             0.3118597504125189, 0.44293241666677863`, 0.9411512293606585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 138}], {
             RGBColor[
             0.4040072532237838, 0.5210264809321714, 0.9474978817731157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 140}], {
             RGBColor[
             0.281455376636651, 0.4131578245196601, 0.9393398393723166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 171}], {
             RGBColor[
             0.48417492179350247`, 0.5855798540619204, 0.9541715786793514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 196}], {
             RGBColor[
             0.3910153512806416, 0.5104790696562158, 0.9464751116612466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 198}], {
             RGBColor[
             0.3048377898853212, 0.43685034739211803`, 0.9407037962451414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 222}], {
             RGBColor[
             0.4690506903049555, 0.5737646894746509, 0.9526641366285522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 245}], {
             RGBColor[
             0.4318223472727945, 0.5436080273368655, 0.9496875878667006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 278}], {
             RGBColor[
             0.37849708554125594`, 0.5003161775875377, 0.9454896279263239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 289}], {
             RGBColor[
             0.32333912962143374`, 0.4528752779671654, 0.9418826852530342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 290}], {
             RGBColor[
             0.4973921961350289, 0.5959052892325263, 0.9554889530632635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 298}], {
             RGBColor[
             0.3805323369368797, 0.5019684863575355, 0.9456498503715589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 134}], {
             RGBColor[
             0.3997685161592569, 0.5197025738340142, 0.9469642518314565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 144}], {
             RGBColor[
             0.3532202325551468, 0.4803633448993445, 0.9437278587713942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 159}], {
             RGBColor[
             0.42711858922684687`, 0.5419065952570346, 0.949117349769956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 235}], {
             RGBColor[
             0.37261348963393726`, 0.49716080944755037`, 0.9449635799636709]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 252}], {
             RGBColor[
             0.38269480514675447`, 0.5058413660721489, 0.9456201467574881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 292}], {
             RGBColor[
             0.3090050119690779, 0.4419816907139842, 0.9409136035539714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 122}], {
             RGBColor[
             0.3686914390363169, 0.4937637263478864, 0.9447136703677237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 160}], {
             RGBColor[
             0.3706706132679357, 0.4954779875911253, 0.9448397815996474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 178}], {
             RGBColor[
             0.528839162921106, 0.6262702449571574, 0.9567903051853114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 181}], {
             RGBColor[
             0.5961146738804735, 0.678826385431436, 0.9634956993923467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 182}], {
             RGBColor[
             0.32273793233215753`, 0.44902970618015037`, 0.9419661163527666]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 208}], {
             RGBColor[
             0.41629541428473354`, 0.5349958970626997, 0.9477469535760104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 246}], {
             RGBColor[
             0.4876575157710162, 0.5932239587398739, 0.953283857181249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 296}], {
             RGBColor[
             0.38301618859018, 0.5061711044285956, 0.9456264307424171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 104}], {
             RGBColor[
             0.5053313222398955, 0.6081456540742536, 0.9545167986277121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 123}], {
             RGBColor[
             0.36782380187296904`, 0.4930122226457063, 0.9446583852948967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 157}], {
             RGBColor[
             0.3892900066417616, 0.5116051702936117, 0.9460261928809445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 201}], {
             RGBColor[
             0.6753415592067249, 0.7424837355526317, 0.9673566509151074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[
             0.48306468294614935`, 0.5900685931949214, 0.9527638872171211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 222}], {
             RGBColor[
             0.5289566014777313, 0.6272587362127651, 0.9564224643780099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 229}], {
             RGBColor[
             0.4899987269992422, 0.5956979625323469, 0.953309760565221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 257}], {
             RGBColor[
             0.6450356008044422, 0.7184166453766914, 0.9678657885509734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 259}], {
             RGBColor[
             0.4914159242183228, 0.5968485070788038, 0.9534213275216714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 261}], {
             RGBColor[
             0.38360277671094034`, 0.506679177576022, 0.9456638076187724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 121}], {
             RGBColor[
             0.46081176115809874`, 0.5707642195552914, 0.9513542429163953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 125}], {
             RGBColor[
             0.4638922286685857, 0.5734323656840763, 0.9515505275822129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 127}], {
             RGBColor[
             0.4235901482797315, 0.5368957475285498, 0.9490421596597158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 136}], {
             RGBColor[
             0.4331163725899124, 0.5467758659882325, 0.9495895172469009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 137}], {
             RGBColor[
             0.4442201645763062, 0.5563934125140342, 0.9502970410535762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 170}], {
             RGBColor[
             0.695694524588357, 0.7610031051848802, 0.971174982739546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 192}], {
             RGBColor[
             0.4275235719304913, 0.5410300251789621, 0.9492661623176478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 228}], {
             RGBColor[
             0.3905047145045648, 0.5021208588931887, 0.9471579931517331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 232}], {
             RGBColor[
             0.41987216364078916`, 0.53298790993918, 0.9488304259347935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 240}], {
             RGBColor[
             0.7495462877331835, 0.8037537495368439, 0.9697486153537034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 256}], {
             RGBColor[
             0.5063672430355418, 0.6101307653374171, 0.954282230737538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 299}], {
             RGBColor[
             0.7459227560395614, 0.801051325532729, 0.9758823093425815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 108}], {
             RGBColor[
             0.5203596454773673, 0.6196780090128112, 0.9559315905637227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 114}], {
             RGBColor[
             0.5665777930839981, 0.655783977194043, 0.9605381835840059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 187}], {
             RGBColor[
             0.5542909229242279, 0.6461853808415585, 0.9593135431938098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 205}], {
             RGBColor[
             0.43921673713493126`, 0.553918028055395, 0.9494647641610139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 207}], {
             RGBColor[
             0.4262689117958256, 0.5434064001522247, 0.9484454639208726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 213}], {
             RGBColor[
             0.3493740563987633, 0.47695623949512234`, 0.9434855570742962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 231}], {
             RGBColor[
             0.40634195945553747`, 0.5263747147648359, 0.9471127282357885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 133}], {
             RGBColor[
             0.3653813665326515, 0.48926772615013336`, 0.9445624004769226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 142}], {
             RGBColor[
             0.6968675201885091, 0.7602500036960143, 0.9559079845849356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 162}], {
             RGBColor[
             0.43330631485799753`, 0.5497298841465381, 0.9488308731183899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[
             0.6718192908455648, 0.7407517230257492, 0.9699699880153219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 210}], {
             RGBColor[
             0.5284950132308948, 0.6277235759462896, 0.9561268592061394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 237}], {
             RGBColor[
             0.6428681365541833, 0.7176668584519499, 0.9672086010740093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 239}], {
             RGBColor[
             0.5763645642186144, 0.6655026707009497, 0.9606361637140792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 295}], {
             RGBColor[
             0.5035527753931325, 0.6074743436345844, 0.9541633148771231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 116}], {
             RGBColor[
             0.5392598319669014, 0.6312677931409261, 0.9591592733867154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 119}], {
             RGBColor[
             0.33168792418116166`, 0.4617131416310851, 0.9423558391220765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 152}], {
             RGBColor[
             0.4315721116260117, 0.5456818366682568, 0.9494238297114415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 164}], {
             RGBColor[
             0.5106694295096867, 0.6089327534462432, 0.9563096492622817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 168}], {
             RGBColor[
             0.47604464923341216`, 0.5817866461629324, 0.952924870780169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 241}], {
             RGBColor[
             0.3479266690751906, 0.475778326275243, 0.9433905575873658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 277}], {
             RGBColor[
             0.34353334408323144`, 0.4719730489821426, 0.943110618803743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 128}], {
             RGBColor[
             0.6462925725707694, 0.7229511023494022, 0.9658291430458714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 157}], {
             RGBColor[
             0.483439804148579, 0.5891843214032471, 0.9531218904528429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 173}], {
             RGBColor[
             0.5698462861545481, 0.6616659122397301, 0.959279533543263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 201}], {
             RGBColor[
             0.7694913567135422, 0.8200628866622671, 0.9744523484870058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 209}], {
             RGBColor[
             0.5252451094729398, 0.6253939756794678, 0.9557856875411311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 218}], {
             RGBColor[
             0.5772144804529667, 0.6676477443045568, 0.9598595847890196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 229}], {
             RGBColor[
             0.5841485245060596, 0.6732771136419823, 0.9604054581371193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 261}], {
             RGBColor[
             0.47775257421775774`, 0.5842583286856574, 0.9527595051906709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 279}], {
             RGBColor[
             0.4543159485378098, 0.5639587014807439, 0.951266144126539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 129}], {
             RGBColor[
             0.4489087930331117, 0.5601988368662567, 0.9506664276323797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 140}], {
             RGBColor[
             0.30194542466164326`, 0.4325118316980492, 0.9405866231760769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 149}], {
             RGBColor[
             0.5205272311255088, 0.6173255803309998, 0.9569993644489352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 171}], {
             RGBColor[
             0.5046649698184947, 0.6049338612403095, 0.9554183624831117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 196}], {
             RGBColor[
             0.4115053993056338, 0.5298330768346049, 0.9477218954650068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 230}], {
             RGBColor[
             0.465979459159378, 0.574057572652305, 0.9520102930017498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 245}], {
             RGBColor[
             0.4523123952977868, 0.5629620345152546, 0.9509343716704608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 263}], {
             RGBColor[
             0.3638162598855268, 0.48954109120110084`, 0.944403028263187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 289}], {
             RGBColor[
             0.343829177646426, 0.4722292851455545, 0.9431294690567944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 298}], {
             RGBColor[
             0.401022384961872, 0.5213224935359246, 0.9468966341753191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 151}], {
             RGBColor[
             0.882762659392468, 0.9093549989182408, 0.9886798845760245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 167}], {
             RGBColor[
             0.7991176523687696, 0.8439093992399378, 0.9803698628397943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 194}], {
             RGBColor[
             0.748511700725938, 0.803175866723651, 0.9761462296144168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 215}], {
             RGBColor[
             0.7234152535101401, 0.7828014402918033, 0.9741705453582739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 283}], {
             RGBColor[
             0.856603762816898, 0.8888179856326369, 0.9860995410910183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 286}], {
             RGBColor[
             0.6365254026076208, 0.7091852703332958, 0.9681799102959385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 297}], {
             RGBColor[
             0.9416856710279484, 0.9559598742994223, 0.981169045113012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 110}], {
             RGBColor[
             0.6937762361927149, 0.7602979661142714, 0.9703893960170833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 127}], {
             RGBColor[
             0.4535380145261313, 0.5612087744833769, 0.9513997653932811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 141}], {
             RGBColor[
             0.47845611588464154`, 0.584420563224088, 0.9529278797754832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 165}], {
             RGBColor[
             0.5774015783515145, 0.667799638807262, 0.9598743138209553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.7771491476854531, 0.8263178746371039, 0.9760757050676365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 240}], {
             RGBColor[
             0.7794941539795832, 0.8280667764916709, 0.9721062210872686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 281}], {
             RGBColor[
             0.42020151622621943`, 0.5261700011140984, 0.9495013011320309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 114}], {
             RGBColor[
             0.6961161225757271, 0.7625304727254218, 0.9703460075894759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 145}], {
             RGBColor[
             0.44969214403882435`, 0.5529904081700597, 0.9516293315337877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 169}], {
             RGBColor[
             0.732964551197244, 0.7913167452229808, 0.974018714586325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 187}], {
             RGBColor[
             0.6838292524159567, 0.7529318763729373, 0.9691213671992799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 205}], {
             RGBColor[
             0.5687550666266601, 0.6606645235867739, 0.959272588166484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 213}], {
             RGBColor[
             0.4789123858904921, 0.5837027350265012, 0.9532933810797661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 219}], {
             RGBColor[
             0.7921795006666598, 0.8385011889854604, 0.9796751677693301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 221}], {
             RGBColor[
             0.6248687610212461, 0.7062201485894236, 0.9636900637404612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 264}], {
             RGBColor[
             0.7079086640730499, 0.7717428957697653, 0.9715213779183632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 110}], {
             RGBColor[
             0.7127901765848731, 0.7755563704448707, 0.9720079214652138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 138}], {
             RGBColor[
             0.5853107749168096, 0.6740427118362053, 0.9606186331570181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 154}], {
             RGBColor[
             0.5482501803111444, 0.6436621587099917, 0.9577820698239816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 179}], {
             RGBColor[
             0.7961630880776113, 0.8415762789677033, 0.977694230515767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 258}], {
             RGBColor[
             0.6058517370258243, 0.6907187902361014, 0.9622356929382633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 138}], {
             RGBColor[
             0.6441242057281045, 0.7199882109846185, 0.9664806062975286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 141}], {
             RGBColor[
             0.5562834870880947, 0.6456244667031006, 0.9604083783641242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 154}], {
             RGBColor[
             0.6070636111224392, 0.6896076578584048, 0.963644042964492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 165}], {
             RGBColor[
             0.6552289495549676, 0.7290035422862746, 0.9673548124095963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 179}], {
             RGBColor[
             0.8549765188889061, 0.8875217781161164, 0.9835562036562774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 281}], {
             RGBColor[
             0.49802888742967255`, 0.5873739045931108, 0.9569817997206718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 190}], {
             RGBColor[
             0.6298531311490796, 0.7095520746059741, 0.9645710345094918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 212}], {
             RGBColor[
             0.45948145390655853`, 0.5694190379426345, 0.9513227857987645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 242}], {
             RGBColor[
             0.4776896632797997, 0.5851900737305231, 0.9524829967991402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 250}], {
             RGBColor[
             0.7707958957753349, 0.8198363262957435, 0.9400723108008998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 280}], {
             RGBColor[
             0.5039763751654068, 0.6079583023572808, 0.9541579628360644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 115}], {
             RGBColor[
             0.6719641157463636, 0.7430614769286036, 0.9683498490842911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 134}], {
             RGBColor[
             0.5462330610121613, 0.6424956323054702, 0.9574206139619605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 146}], {
             RGBColor[
             0.6874032752920052, 0.7551226657076173, 0.9698886802206517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 159}], {
             RGBColor[
             0.5735831340797513, 0.6646996537284906, 0.9595737119004599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 175}], {
             RGBColor[
             0.6042118472979573, 0.6895654229268366, 0.9619849164016705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 204}], {
             RGBColor[
             0.6121780015907041, 0.6960327058528496, 0.9626120412485801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 235}], {
             RGBColor[
             0.5190780344868416, 0.6199538679190064, 0.9554199420941749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 242}], {
             RGBColor[
             0.4976645996981965, 0.6014066269756084, 0.9540554969645993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 252}], {
             RGBColor[
             0.5291593499996587, 0.6286344245436051, 0.9560765088879921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 253}], {
             RGBColor[
             0.7063268108561173, 0.7699058755144987, 0.9717748013951881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 280}], {
             RGBColor[
             0.5239513115838036, 0.6241748556023661, 0.9557304630015235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 292}], {
             RGBColor[
             0.4554695568219823, 0.5647747491854402, 0.9513699656844753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 135}], {
             RGBColor[
             0.4424119722933496, 0.55125834895922, 0.9506074267500563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 224}], {
             RGBColor[
             0.4634622370075041, 0.5683308729274472, 0.9522762236758048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 249}], {
             RGBColor[
             0.41639440216430845`, 0.5301361134502869, 0.9485592283239985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 254}], {
             RGBColor[
             0.39190191742368785`, 0.5102520109639875, 0.946631090206289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 258}], {
             RGBColor[
             0.4205902705932881, 0.5335425084626513, 0.9488895424567002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 260}], {
             RGBColor[
             0.5113471746843723, 0.6057389501796223, 0.9570489467532504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 278}], {
             RGBColor[
             0.37453914080174544`, 0.4961561267181216, 0.9452642288286632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 288}], {
             RGBColor[
             0.36988364456986256`, 0.4923765851493638, 0.9448977311116449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 290}], {
             RGBColor[
             0.4934342513955184, 0.5917452383631102, 0.9552635539656029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 145}], {
             RGBColor[
             0.4959102916454551, 0.5890963763512915, 0.9562359245540708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 169}], {
             RGBColor[
             0.7791826988038747, 0.8274227134042126, 0.9786253076066083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 187}], {
             RGBColor[
             0.7300474000225874, 0.789037844554169, 0.973727960219563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 213}], {
             RGBColor[
             0.5251305334971229, 0.6198087032077328, 0.9578999741000493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 219}], {
             RGBColor[
             0.8383976482732904, 0.8746071571666922, 0.9842817607896133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 221}], {
             RGBColor[
             0.6710869086278768, 0.7423261167706554, 0.9682966567607443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 231}], {
             RGBColor[
             0.582098436553897, 0.6692271784774465, 0.9615271452615417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 264}], {
             RGBColor[
             0.7541268116796807, 0.8078488639509971, 0.9761279709386463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 132}], {
             RGBColor[
             0.6548940079872472, 0.7292031944501618, 0.9670060276716284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 146}], {
             RGBColor[
             0.7562586886491973, 0.8095143024424485, 0.9763404565114449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 159}], {
             RGBColor[
             0.6424385474369434, 0.7190912904633218, 0.9660254881912531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 204}], {
             RGBColor[
             0.6810334149478963, 0.7504243425876808, 0.9690638175393733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 242}], {
             RGBColor[
             0.5665200130553887, 0.6557982637104396, 0.9605072732553925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 243}], {
             RGBColor[
             0.5479000812060785, 0.6396706146075535, 0.9593208276629137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 294}], {
             RGBColor[
             0.6152794574946836, 0.6970423177451364, 0.963887425143974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 119}], {
             RGBColor[
             0.554887572137617, 0.6448037562037401, 0.9601550591713253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 133}], {
             RGBColor[
             0.5267933219931787, 0.618840947022538, 0.9584245633970419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 152}], {
             RGBColor[
             0.6547717595824669, 0.7287724512409117, 0.9672230497606901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 164}], {
             RGBColor[
             0.733869077466142, 0.7920233680188983, 0.9741088693115303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 168}], {
             RGBColor[
             0.6992442971898675, 0.7648772607355874, 0.9707240908294177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 210}], {
             RGBColor[
             0.6899069686914221, 0.7572967968186942, 0.9699890221262587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 241}], {
             RGBColor[
             0.5711263170316458, 0.658868940847898, 0.9611897776366145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 277}], {
             RGBColor[
             0.5667329920396866, 0.6550636635547976, 0.9609098388529916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 161}], {
             RGBColor[
             0.5114412683142167, 0.6127608994909848, 0.9550931437170971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 120}], {
             RGBColor[
             0.3895617255747437, 0.5118405195763702, 0.9460435065710825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 130}], {
             RGBColor[
             0.4544511496099061, 0.5665702243184165, 0.950585543765454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 176}], {
             RGBColor[
             0.4974645498448679, 0.6014904403607567, 0.9539717161952268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[
             0.4096779458326548, 0.5292641784931444, 0.9473252943378414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 220}], {
             RGBColor[
             0.4731518576519888, 0.5817523015642758, 0.9520577320054775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 226}], {
             RGBColor[
             0.4558683352056977, 0.5677207594285636, 0.9506971098068766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 228}], {
             RGBColor[
             0.31312249634732936`, 0.43788577058122996`, 0.9414565195552889]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 266}], {
             RGBColor[
             0.3887184850839611, 0.5111101470457536, 0.9459897760326581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 152}], {
             RGBColor[
             0.44719985179672717`, 0.5592177997310709, 0.9504196154960514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 164}], {
             RGBColor[
             0.5262971696804022, 0.6224687165090574, 0.9573054350468917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 168}], {
             RGBColor[
             0.49167238940412766`, 0.5953226092257465, 0.9539206565647789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 241}], {
             RGBColor[
             0.3635544092459061, 0.48931428933805715`, 0.9443863433719758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 130}], {
             RGBColor[
             0.4427241790026586, 0.5564129117930994, 0.949838311568113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 176}], {
             RGBColor[
             0.48573757923762034`, 0.5913331278354397, 0.9532244839978861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 287}], {
             RGBColor[
             0.5068216131301, 0.6084500963742574, 0.954884296379263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 125}], {
             RGBColor[
             0.36865085733022224`, 0.4937285765137631, 0.9447110845372964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 127}], {
             RGBColor[
             0.32834877694136805`, 0.45719195835823656`, 0.9422027166147993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 136}], {
             RGBColor[
             0.337875001251549, 0.46707207681791924`, 0.9427500742019843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 137}], {
             RGBColor[
             0.3489787932379428, 0.476689623343721, 0.9434575980086595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 160}], {
             RGBColor[
             0.35842220131742497`, 0.4848690287826777, 0.9440593236210062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 181}], {
             RGBColor[
             0.5838662619299627, 0.6682174266229883, 0.9627152414137056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 232}], {
             RGBColor[
             0.32463079230242575`, 0.4532841207688667, 0.9419909828898768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 240}], {
             RGBColor[
             0.65430491639482, 0.7240499603665306, 0.9629091723087868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 246}], {
             RGBColor[
             0.4754091038205055, 0.5826149999314262, 0.952503399202608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 256}], {
             RGBColor[
             0.41112587169717835`, 0.5304269761671039, 0.9474427876926215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 296}], {
             RGBColor[
             0.3707677766396693, 0.4955621456201479, 0.9448459727637761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 299}], {
             RGBColor[
             0.6506813847011979, 0.7213475363624158, 0.9690428662976649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 136}], {
             RGBColor[
             0.3287476385176199, 0.4591664139723798, 0.9421684867195883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 160}], {
             RGBColor[
             0.3492948385834959, 0.4769633659371382, 0.9434777361386102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 181}], {
             RGBColor[
             0.5747388991960336, 0.6603117637774489, 0.9621336539313096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 207}], {
             RGBColor[
             0.40451608597894484`, 0.5245651957584582, 0.9470593930950895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 231}], {
             RGBColor[
             0.38458913363865677`, 0.5075335103710694, 0.9457266574100054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 232}], {
             RGBColor[
             0.31550342956849664`, 0.44537845792332725`, 0.9414093954074808]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 240}], {
             RGBColor[
             0.645177553660891, 0.7161442975209911, 0.9623275848263908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 246}], {
             RGBColor[
             0.4662817410865764, 0.5747093370858867, 0.951921811720212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 256}], {
             RGBColor[
             0.4019985089632493, 0.5225213133215644, 0.9468612002102255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 296}], {
             RGBColor[
             0.3616404139057402, 0.48765648277460844`, 0.9442643852813801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 299}], {
             RGBColor[
             0.6415540219672689, 0.7134418735168763, 0.9684612788152689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 144}], {
             RGBColor[
             0.3603634657198953, 0.4865504544373116, 0.944183019272139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 157}], {
             RGBColor[
             0.34593228378165247`, 0.47405088997469985`, 0.9432634771200272]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 229}], {
             RGBColor[
             0.446641004139133, 0.558143682213435, 0.9505470448043037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 257}], {
             RGBColor[
             0.601677877944333, 0.6808623650577795, 0.9651030727900562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 259}], {
             RGBColor[
             0.44805820135821367`, 0.5592942267598919, 0.9506586117607543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 261}], {
             RGBColor[
             0.34024505385083115`, 0.46912489725711015`, 0.9429010918578553]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 125}], {
             RGBColor[
             0.33576067100394336`, 0.4644127084215715, 0.9426456696149871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 142}], {
             RGBColor[
             0.6269447442709468, 0.6988583678119258, 0.9514828858005029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 150}], {
             RGBColor[
             0.36773649597774727`, 0.49210856086218724`, 0.9446831409072061]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 200}], {
             RGBColor[
             0.2910931891086029, 0.42328777650028615`, 0.9398886985347283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 237}], {
             RGBColor[
             0.5729453606366209, 0.6562752225678615, 0.9627835022895768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 282}], {
             RGBColor[
             0.5331460632781484, 0.6249726173889758, 0.9588726974937255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 295}], {
             RGBColor[
             0.4336299994755702, 0.5460827077504959, 0.9497382160926904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 136}], {
             RGBColor[
             0.340955468762036, 0.46974022294670414`, 0.942946358867802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 150}], {
             RGBColor[
             0.40370714981451306`, 0.5240925750831638, 0.9469448404953331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[
             0.6035336207604806, 0.6839674621433518, 0.9645318243604473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 192}], {
             RGBColor[
             0.33536266810261484`, 0.4639943821374337, 0.942623003938549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 195}], {
             RGBColor[
             0.4857854359570526, 0.5912062576386026, 0.9532740410574219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 200}], {
             RGBColor[
             0.3270638429453687, 0.45527179072126256`, 0.9421503981228554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 256}], {
             RGBColor[
             0.4142063392076653, 0.5330951222958887, 0.9476390723584391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 299}], {
             RGBColor[
             0.6537618522116848, 0.7240156824912006, 0.9692391509634827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 155}], {
             RGBColor[
             0.4339150471983343, 0.5502571375039607, 0.9488696610048353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 163}], {
             RGBColor[
             0.45710467604957533`, 0.5700677900182243, 0.9504232775932306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 184}], {
             RGBColor[
             0.37266787475126806`, 0.49589760322541254`, 0.9450150222718054]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 189}], {
             RGBColor[
             0.5878784550244699, 0.6749699567570038, 0.9615837564384262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 197}], {
             RGBColor[
             0.42469743054392817`, 0.542273301248798, 0.948282322622435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 214}], {
             RGBColor[
             0.7224008504105568, 0.7772545499542609, 0.7712953642834752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 216}], {
             RGBColor[
             0.4939782904549621, 0.6000034513299161, 0.9533261035917228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 275}], {
             RGBColor[
             0.5253007220858089, 0.6254324123873021, 0.9557919201475507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 293}], {
             RGBColor[
             0.6452439594195777, 0.7199438921966315, 0.9672590695204664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 136}], {
             RGBColor[
             0.3006533883731818, 0.4332036047911776, 0.9404379909453049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 137}], {
             RGBColor[
             0.31175718035957556`, 0.4428211513169793, 0.9411455147519802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 141}], {
             RGBColor[
             0.3160452654215111, 0.44653527507220603`, 0.941418747740322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 165}], {
             RGBColor[
             0.414990727888384, 0.5299143506553801, 0.9483651817857941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 170}], {
             RGBColor[
             0.5632315403716264, 0.6474308439878252, 0.9620234564379501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 192}], {
             RGBColor[
             0.29506058771376065`, 0.42745776398190716`, 0.9401146360160518]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 228}], {
             RGBColor[
             0.2580417302878341, 0.3885485976961338, 0.9380064668501371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 232}], {
             RGBColor[
             0.2874091794240585, 0.4194156487421251, 0.9396788996331975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 240}], {
             RGBColor[
             0.6170833035164529, 0.690181488339789, 0.9605970890521074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 256}], {
             RGBColor[
             0.3739042588188111, 0.4965585041403622, 0.945130704435942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 281}], {
             RGBColor[
             0.257790665763089, 0.38828471296221634`, 0.9379921690968696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 299}], {
             RGBColor[
             0.6134597718228307, 0.6874790643356741, 0.9667307830409855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 173}], {
             RGBColor[
             0.6166577389786045, 0.6988922094052433, 0.9634961803895239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 209}], {
             RGBColor[
             0.5720565622969963, 0.662620272844981, 0.960002334387392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 218}], {
             RGBColor[
             0.6240259332770233, 0.70487404147007, 0.9640762316352804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 276}], {
             RGBColor[
             0.5546970184717662, 0.6475843084996089, 0.9588961996052903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 279}], {
             RGBColor[
             0.5011274013618663, 0.6011849986462572, 0.9554827909727999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 161}], {
             RGBColor[
             0.48197006576962753`, 0.5888348496027427, 0.952773062696215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 230}], {
             RGBColor[
             0.5825384537549785, 0.6719699856733939, 0.9602787074697108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 263}], {
             RGBColor[
             0.48037525448112733`, 0.5874535042221898, 0.952671442731148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 265}], {
             RGBColor[
             0.7767174459391113, 0.8237016762551361, 0.9040072975146631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 269}], {
             RGBColor[
             0.4695446759778679, 0.5780726014833701, 0.9519813278460247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 289}], {
             RGBColor[
             0.46038817224202655`, 0.5701416981666435, 0.9513978835247553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 298}], {
             RGBColor[
             0.5175813795574725, 0.6192349065570136, 0.9551650486432801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 176}], {
             RGBColor[
             0.5506270032727827, 0.646062832577486, 0.9577665211922575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 199}], {
             RGBColor[
             0.46284039926056963`, 0.5738365707098736, 0.9511200993348721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 220}], {
             RGBColor[
             0.5263143110799037, 0.6263246937810051, 0.955852537002508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 226}], {
             RGBColor[
             0.5090307886336125, 0.6122931516452927, 0.9544919148039072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 228}], {
             RGBColor[
             0.3662849497752442, 0.48245816279795917`, 0.9452513245523195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 266}], {
             RGBColor[
             0.44188093851187593`, 0.5556825392624829, 0.9497845810296888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 139}], {
             RGBColor[
             0.627611784003879, 0.696044200256377, 0.9313724071496305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 143}], {
             RGBColor[
             0.7600141252473882, 0.8111262142370081, 0.9403772508591528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 172}], {
             RGBColor[
             0.8818866536720497, 0.9078575776579678, 0.9514826596152743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 174}], {
             RGBColor[
             0.7892502655834317, 0.8348614300349211, 0.9426788269219171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 183}], {
             RGBColor[
             0.6691566493845167, 0.7348623382512103, 0.933915840279657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 283}], {
             RGBColor[
             0.878676240820763, 0.9053495787385013, 0.9511626756652718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 188}], {
             RGBColor[
             0.6060055202379175, 0.6910111362541168, 0.9621332801016684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 212}], {
             RGBColor[
             0.4623862825658389, 0.5717773087092781, 0.951551464551561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 243}], {
             RGBColor[
             0.46197456008977, 0.5714206953942805, 0.9515252299594579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 294}], {
             RGBColor[
             0.5293539363783751, 0.6287923985318634, 0.9560918274405181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 162}], {
             RGBColor[
             0.3590521123883469, 0.4837856443278996, 0.9441591059995872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 164}], {
             RGBColor[
             0.4982029195359641, 0.5965059073278552, 0.9555749392726083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 210}], {
             RGBColor[
             0.4542408107612441, 0.5617793361276512, 0.9514550920873366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 239}], {
             RGBColor[
             0.5021103617489636, 0.5995584308823112, 0.9559643965952764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 241}], {
             RGBColor[
             0.3354601591014679, 0.463351480156855, 0.9426558475976925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 277}], {
             RGBColor[
             0.33106683410950877`, 0.4595462028637546, 0.9423759088140695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 144}], {
             RGBColor[
             0.4428091360310409, 0.5569821954824985, 0.9497067620703609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 159}], {
             RGBColor[
             0.5167074927027411, 0.6185254458401885, 0.9550962530689227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 175}], {
             RGBColor[
             0.547336205920947, 0.6433912150385345, 0.9575074575701331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 204}], {
             RGBColor[
             0.5553023602136938, 0.6498584979645474, 0.9581345824170429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 235}], {
             RGBColor[
             0.4622023931098314, 0.5737796600307044, 0.9509424832626375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 252}], {
             RGBColor[
             0.47228370862264857`, 0.5824602166553029, 0.9515990500564547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 253}], {
             RGBColor[
             0.649451169479107, 0.7237316676261967, 0.9672973425636507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 292}], {
             RGBColor[
             0.398593915444972, 0.5186005412971382, 0.9468925068529379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 224}], {
             RGBColor[
             0.622420396392348, 0.7043309141371099, 0.963430003064284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 249}], {
             RGBColor[
             0.5753525615491524, 0.6661361546599496, 0.9597130077124776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 254}], {
             RGBColor[
             0.5508600768085318, 0.6462520521736501, 0.9577848695947682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 258}], {
             RGBColor[
             0.5795484299781319, 0.6695425496723139, 0.9600433218451794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 260}], {
             RGBColor[
             0.6703053340692162, 0.7417389913892849, 0.9682027261417296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 288}], {
             RGBColor[
             0.5288418039547065, 0.6283766263590265, 0.9560515105001239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 137}], {
             RGBColor[
             0.32128340466975647`, 0.45270126977666203`, 0.9416928723391652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 165}], {
             RGBColor[
             0.424516952198565, 0.5397944691150628, 0.9489125393729791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 181}], {
             RGBColor[
             0.5561708733617764, 0.6442290730559294, 0.9609505157442113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 232}], {
             RGBColor[
             0.29693540373423943`, 0.42929576720180773`, 0.9402262572203826]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 240}], {
             RGBColor[
             0.6266095278266337, 0.7000616067994716, 0.9611444466392924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 256}], {
             RGBColor[
             0.3834304831289921, 0.5064386226000449, 0.9456780620231271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 296}], {
             RGBColor[
             0.343072388071483, 0.4715737920530889, 0.9430812470942818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 299}], {
             RGBColor[
             0.6229859961330118, 0.6973591827953567, 0.9672781406281705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 170}], {
             RGBColor[
             0.583861556668201, 0.6669285089733097, 0.9632783378318104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 192}], {
             RGBColor[
             0.31569060401033533`, 0.4469554289673916, 0.9413695174099121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 195}], {
             RGBColor[
             0.4661133718647731, 0.5741673044685605, 0.952020554528785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 220}], {
             RGBColor[
             0.4387011078890683, 0.5519127936646642, 0.949862560694186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 228}], {
             RGBColor[
             0.27867174658440885`, 0.4080462626816182, 0.9392613482439975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 232}], {
             RGBColor[
             0.3080391957206332, 0.4389133137276095, 0.9409337810270577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 256}], {
             RGBColor[
             0.39453427511538586`, 0.5160561691258466, 0.9463855858298024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 266}], {
             RGBColor[
             0.3542677353210406, 0.4812706391461419, 0.9437946047213667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 299}], {
             RGBColor[
             0.6340897881194054, 0.7069767293211585, 0.9679856644348459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 154}], {
             RGBColor[
             0.47958420945437563`, 0.5880939992497396, 0.9522547546562965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 171}], {
             RGBColor[
             0.5968124726297596, 0.6830279255057021, 0.9617650148955689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 245}], {
             RGBColor[
             0.5444598981090516, 0.6410560987806474, 0.9572810240829179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 258}], {
             RGBColor[
             0.5371857661690557, 0.6351506307758492, 0.9567083777705783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 147}], {
             RGBColor[
             0.6199027853555588, 0.6902948416867865, 0.9444217310323768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 148}], {
             RGBColor[
             0.3746218865213712, 0.4955821211568878, 0.9453291072725236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 172}], {
             RGBColor[
             0.5323680381872588, 0.6214373080133851, 0.9592586190596062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 183}], {
             RGBColor[
             0.3196380338997258, 0.44844206860662755`, 0.9416917997239889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 206}], {
             RGBColor[
             0.40781748797292244`, 0.5225318058600605, 0.9479423866182846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 244}], {
             RGBColor[
             0.46560003301380437`, 0.5692776349162486, 0.9526038082863995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 272}], {
             RGBColor[
             0.27753023797988546`, 0.40903225492323475`, 0.939116308532536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 149}], {
             RGBColor[
             0.4901228573496409, 0.5875509881838814, 0.9551879744605931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 171}], {
             RGBColor[
             0.4742605960426268, 0.5751592690931909, 0.9536069724947698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 196}], {
             RGBColor[
             0.3811010255297659, 0.5000584846874864, 0.9459105054766649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 198}], {
             RGBColor[
             0.29492346413444553`, 0.42642976242338865`, 0.9401391900605596]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 222}], {
             RGBColor[
             0.4591363645540798, 0.5633441045059214, 0.9520995304439703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 230}], {
             RGBColor[
             0.4355750853835101, 0.5442829805051864, 0.9501989030134078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 245}], {
             RGBColor[
             0.42190802152191886`, 0.5331874423681361, 0.9491229816821188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 263}], {
             RGBColor[
             0.3334118861096589, 0.45976649905398237`, 0.942591638274845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 289}], {
             RGBColor[
             0.3134248038705581, 0.44245469299843604`, 0.9413180790684523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 298}], {
             RGBColor[
             0.37061801118600407`, 0.4915479013888061, 0.9450852441869771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 165}], {
             RGBColor[
             0.43990882924689434`, 0.5531261393960912, 0.9498932961679962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 179}], {
             RGBColor[
             0.6396563985808328, 0.7116443752259332, 0.9660946874146774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 232}], {
             RGBColor[
             0.3123272807825688, 0.44262743748283623`, 0.9412070140153996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[
             0.6420014048749632, 0.7133932770805, 0.9621252034343095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 281}], {
             RGBColor[
             0.2827087671215993, 0.4114965017029275, 0.9395202834790717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[
             0.6948912230815165, 0.7585382344735181, 0.955782056680849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 185}], {
             RGBColor[
             0.9290512420317718, 0.9457897607529917, 0.9766438050045321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 210}], {
             RGBColor[
             0.7857269644171018, 0.8327616136735321, 0.9628006761953496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 237}], {
             RGBColor[
             0.9001000877403902, 0.9227048961791924, 0.9738824180632196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 239}], {
             RGBColor[
             0.8335965154048213, 0.8705407084281921, 0.9673099807032894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 282}], {
             RGBColor[
             0.8603007903819175, 0.8914022910003065, 0.9699716132673684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 283}], {
             RGBColor[
             0.8671607767637861, 0.8967613644996497, 0.9706553525996955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 295}], {
             RGBColor[
             0.7607847265793395, 0.8125123813618268, 0.9608371318663333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 297}], {
             RGBColor[
             0.9522426849748364, 0.9639032531664351, 0.965724856621689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 167}], {
             RGBColor[
             0.604073856131353, 0.6891027366818505, 0.9622138005679022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 172}], {
             RGBColor[
             0.664770379430768, 0.7365193219940163, 0.9682634627691286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 174}], {
             RGBColor[
             0.5721339913421499, 0.6635231743709695, 0.9594596300757713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 185}], {
             RGBColor[
             0.7234504318474669, 0.7830397193278916, 0.9739319312239627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 237}], {
             RGBColor[
             0.6944992775560854, 0.7599548547540922, 0.9711705442826503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 239}], {
             RGBColor[
             0.6279957052205165, 0.707790667003092, 0.9645981069227201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 283}], {
             RGBColor[
             0.6615599665794814, 0.7340113230745497, 0.9679434788191261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 297}], {
             RGBColor[
             0.7466418747905317, 0.8011532117413351, 0.9630129828411197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 158}], {
             RGBColor[
             0.35275720239924413`, 0.47996229145087393`, 0.9436983548993017]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 235}], {
             RGBColor[
             0.4156541095057213, 0.5344404310960347, 0.9477060902025752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 252}], {
             RGBColor[
             0.42573542501853845`, 0.5431209877206331, 0.9483626569963924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 253}], {
             RGBColor[
             0.602902885874997, 0.684392438691527, 0.9640609495035884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 257}], {
             RGBColor[
             0.6375752646513686, 0.7119548771682966, 0.9673904225282157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 292}], {
             RGBColor[
             0.3520456318408619, 0.47926131236246844`, 0.9436561137928756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 169}], {
             RGBColor[
             0.532758720266972, 0.6178826488488505, 0.95990863155092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 219}], {
             RGBColor[
             0.5919736697363878, 0.6650670926113301, 0.965565084733925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 221}], {
             RGBColor[
             0.42466293009097417`, 0.5327860522152933, 0.9495799807050561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 264}], {
             RGBColor[
             0.507702833142778, 0.598308799395635, 0.9574112948829582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 159}], {
             RGBColor[
             0.657877706982585, 0.7311524792423355, 0.9675643193276138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 204}], {
             RGBColor[
             0.6964725744935378, 0.7624855313666945, 0.970602648675734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 235}], {
             RGBColor[
             0.6033726073896754, 0.6864066934328514, 0.9634105495213287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 242}], {
             RGBColor[
             0.5819591726010303, 0.6678594524894534, 0.9620461043917531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 243}], {
             RGBColor[
             0.56333924075172, 0.6517318033865672, 0.9608596587992743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 292}], {
             RGBColor[
             0.539764129724816, 0.6312275746992853, 0.959360573111629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 148}], {
             RGBColor[
             0.7164315033578418, 0.7762530322318801, 0.950602471710938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 172}], {
             RGBColor[
             0.8741776550237295, 0.9021082190883773, 0.9645319834980206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 183}], {
             RGBColor[
             0.6614476507361964, 0.7291129796816198, 0.9469651641624033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 206}], {
             RGBColor[
             0.7496271048093931, 0.8032027169350529, 0.9532157510566989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 244}], {
             RGBColor[
             0.807409649850275, 0.8499485459912408, 0.9578771727248139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 270}], {
             RGBColor[
             0.6786872674007699, 0.7440450691481455, 0.9480636572918755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 272}], {
             RGBColor[
             0.6193398548163561, 0.689703165998227, 0.9443896729709503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 172}], {
             RGBColor[
             0.6288967561895419, 0.7073954985584787, 0.9654393597381674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 183}], {
             RGBColor[
             0.41616675190200886`, 0.5344002591517211, 0.9478725404025501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 203}], {
             RGBColor[
             0.554400465044314, 0.6491262988361306, 0.9580635819255583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 206}], {
             RGBColor[
             0.5043462059752055, 0.6084899964051541, 0.9541231272968458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 244}], {
             RGBColor[
             0.5621287510160875, 0.6552358254613422, 0.9587845489649607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 270}], {
             RGBColor[
             0.4334063685665823, 0.5493323486182469, 0.9489710335320223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 272}], {
             RGBColor[
             0.37405895598216854`, 0.49499044546832827`, 0.9452970492110973]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 171}], {
             RGBColor[
             0.6928424025064923, 0.7599730177261416, 0.9700197137676281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 227}], {
             RGBColor[
             0.6962242306792699, 0.7626149275975614, 0.9703567827949094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 245}], {
             RGBColor[
             0.6404898279857845, 0.7180011910010868, 0.9655357229549771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 289}], {
             RGBColor[
             0.5320066103344236, 0.6272684416313867, 0.9577308203413106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 298}], {
             RGBColor[
             0.5891998176498696, 0.6763616500217569, 0.9614979854598354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 200}], {
             RGBColor[
             0.3590396679191726, 0.48296764316187835`, 0.9441878694150744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 237}], {
             RGBColor[
             0.6408918394471906, 0.7159550892294537, 0.9670826731699227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 282}], {
             RGBColor[
             0.6010925420887181, 0.6846524840505679, 0.9631718683740715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 295}], {
             RGBColor[
             0.5015764782861398, 0.6057625744120883, 0.9540373869730365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 167}], {
             RGBColor[
             0.7488948682802978, 0.8038631144689476, 0.9755795688590272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 194}], {
             RGBColor[
             0.6982889166374662, 0.7631295819526609, 0.9713559356336496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 251}], {
             RGBColor[
             0.6168606460154483, 0.6956068130884803, 0.9653367468058329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 286}], {
             RGBColor[
             0.586302618519149, 0.6691389855623058, 0.9633896163151714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 241}], {
             RGBColor[
             0.46343859669075615`, 0.5732829843752287, 0.9514543339613406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 277}], {
             RGBColor[
             0.45904527169879694`, 0.5694777070821284, 0.9511743951777177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 163}], {
             RGBColor[
             0.3674942529433521, 0.4890118937237161, 0.9448393304954121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 211}], {
             RGBColor[
             0.22523402544288768`, 0.35406561977546536`, 0.9361381165938674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 216}], {
             RGBColor[
             0.40436786734873886`, 0.5189475550354079, 0.9477421564939044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 219}], {
             RGBColor[
             0.6030010386249993, 0.6766575564888309, 0.9661930770786011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 221}], {
             RGBColor[
             0.43569029897958567`, 0.5443765160927939, 0.9502079730497321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 171}], {
             RGBColor[
             0.5597518780240943, 0.6526473723794884, 0.9589284515625323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 179}], {
             RGBColor[
             0.6904365226151774, 0.7556275663812374, 0.9693303520150452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 245}], {
             RGBColor[
             0.5073993035033864, 0.6106755456544337, 0.9544444607498814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 156}], {
             RGBColor[
             0.6251687939307107, 0.7027778263402852, 0.9658776835191019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 184}], {
             RGBColor[
             0.3558210248513805, 0.48130570858942623`, 0.9439415558932691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 197}], {
             RGBColor[
             0.4078505806440406, 0.5276814066128117, 0.9472088562438985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 202}], {
             RGBColor[
             0.3763689716115537, 0.5004136191805492, 0.9452028759544423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 214}], {
             RGBColor[
             0.7055540005106693, 0.7626626553182746, 0.7702218979049389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 275}], {
             RGBColor[
             0.5084538721859213, 0.6108405177513158, 0.9547184537690143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 293}], {
             RGBColor[
             0.6283971095196901, 0.7053519975606451, 0.96618560314193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 178}], {
             RGBColor[
             0.750440251342215, 0.8050762758625187, 0.9757320334768833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 202}], {
             RGBColor[
             0.5844695682438177, 0.66752620265286, 0.9632843648472451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 208}], {
             RGBColor[
             0.6378965027058425, 0.713801927968061, 0.9666886818675823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 214}], {
             RGBColor[
             0.9136545971429333, 0.9297752387905854, 0.7883033867977418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 268}], {
             RGBColor[
             0.9106182474062426, 0.9295912562177613, 0.9165194626704452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 201}], {
             RGBColor[
             0.6534500411154083, 0.7235224028816253, 0.965961742740238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 218}], {
             RGBColor[
             0.46117316485483284`, 0.5711072605239149, 0.9513689790422519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 229}], {
             RGBColor[
             0.4681072089079256, 0.5767366298613404, 0.9519148523903516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 257}], {
             RGBColor[
             0.6231440827131257, 0.699455312705685, 0.9664708803761041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 259}], {
             RGBColor[
             0.4695244061270063, 0.5778871744077974, 0.9520264193468021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 261}], {
             RGBColor[
             0.36171125861962383`, 0.4877178449050156, 0.9442688994439032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 284}], {
             RGBColor[
             0.35871829740223005`, 0.48512549232911384`, 0.9440781906017026]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 175}], {
             RGBColor[
             0.4572842722891503, 0.56637131100691, 0.9514990503990739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 177}], {
             RGBColor[
             0.3529330419014869, 0.48011459478976626`, 0.9437095592368958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 217}], {
             RGBColor[
             0.6012773870796337, 0.6800198894322351, 0.9653057014267366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 252}], {
             RGBColor[
             0.3822317749908518, 0.5054403126236784, 0.9455906428853955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 253}], {
             RGBColor[
             0.5593992358473103, 0.6467117635945722, 0.9612889353925915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 175}], {
             RGBColor[
             0.5746862789885371, 0.6655952364615547, 0.9596605555086326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 204}], {
             RGBColor[
             0.5826524332812839, 0.6720625193875678, 0.9602876803555422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 235}], {
             RGBColor[
             0.48955246617742143`, 0.5959836814537247, 0.953095581201137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 252}], {
             RGBColor[
             0.4996337816902386, 0.6046642380783231, 0.9537521479949542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 253}], {
             RGBColor[
             0.676801242546697, 0.745935689049217, 0.9694504405021502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 292}], {
             RGBColor[
             0.4259439885125621, 0.5408045627201585, 0.9490456047914373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 168}], {
             RGBColor[
             0.49365156363574647`, 0.5970368704689855, 0.9540467677967026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[
             0.5767180734276525, 0.6620260250206877, 0.9622597651632332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 246}], {
             RGBColor[
             0.4682609153181952, 0.5764235983291257, 0.9520479229521356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 256}], {
             RGBColor[
             0.40397768319486804`, 0.5242355745648033, 0.9469873114421491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 296}], {
             RGBColor[
             0.363619588137359, 0.48937074401784736`, 0.9443904965133038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 299}], {
             RGBColor[
             0.6435331961988877, 0.7151561347601152, 0.9685873900471926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 186}], {
             RGBColor[
             0.4008915118955567, 0.5216538110358403, 0.946765430536908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 230}], {
             RGBColor[
             0.4990407318958938, 0.6026935853887909, 0.954116928065585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 265}], {
             RGBColor[
             0.6932197240800266, 0.7544252759705332, 0.8978455181105374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 269}], {
             RGBColor[
             0.3860469541187833, 0.5087962011987672, 0.9458195484418991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 191}], {
             RGBColor[
             0.4283739595309747, 0.5454577258696578, 0.9485165877984626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 203}], {
             RGBColor[
             0.5323136931393333, 0.630480044147292, 0.9565224472705431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 210}], {
             RGBColor[
             0.5221657590865902, 0.6222414941240559, 0.955723564728804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 239}], {
             RGBColor[
             0.5700353100743096, 0.660020588878716, 0.9602328692367439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 184}], {
             RGBColor[
             0.37901065370262155`, 0.5011163611036898, 0.9454951724816644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.5942212339758234, 0.6801887146352811, 0.962063906648285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 197}], {
             RGBColor[
             0.43104020949528166`, 0.5474920591270753, 0.9487624728322939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 211}], {
             RGBColor[
             0.3211872275004644, 0.4403402739482508, 0.9422022139015447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 216}], {
             RGBColor[
             0.5003210694063156, 0.6052222092081934, 0.9538062538015817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 168}], {
             RGBColor[
             0.6706538947326528, 0.7425422210409047, 0.967874466704984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 210}], {
             RGBColor[
             0.6613165662342074, 0.7349617571240115, 0.967139398001825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 241}], {
             RGBColor[
             0.5425359145744312, 0.6365339011532153, 0.9583401535121809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 277}], {
             RGBColor[
             0.5381425895824721, 0.6327286238601149, 0.958060214728558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 179}], {
             RGBColor[
             0.7386018610477058, 0.7950234508091072, 0.9730411214601495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 207}], {
             RGBColor[
             0.5002853996598899, 0.6051932509011412, 0.9538034457484803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 232}], {
             RGBColor[
             0.4112727432494417, 0.5260065130660103, 0.9481534480608718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 240}], {
             RGBColor[
             0.740946867341836, 0.7967723526636741, 0.9690716374797816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 281}], {
             RGBColor[
             0.38165422958847217`, 0.49487557728610154`, 0.9464667175245438]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 217}], {
             RGBColor[
             0.7203857822980615, 0.7806291379585641, 0.9736015396912212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 233}], {
             RGBColor[
             0.5701999922030292, 0.6619530667441629, 0.9593073785790673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 262}], {
             RGBColor[
             0.5239101823736414, 0.6243729137924974, 0.9556632751841374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 271}], {
             RGBColor[
             0.4488554527888181, 0.5606413090499563, 0.9505280070823638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 291}], {
             RGBColor[
             0.43843141908757544`, 0.5516125349851076, 0.9498637968725319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 174}], {
             RGBColor[
             0.6333099964673965, 0.7128379524797637, 0.9645153766306662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 185}], {
             RGBColor[
             0.7846264369727134, 0.8323544974366857, 0.9789876777788578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 194}], {
             RGBColor[
             0.6146439096137678, 0.6976839822743579, 0.9630459138974194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 215}], {
             RGBColor[
             0.58954746239797, 0.6773095558425102, 0.9610702296412766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 282}], {
             RGBColor[
             0.7158759853228593, 0.7779670276840005, 0.972315486041694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 283}], {
             RGBColor[
             0.7227359717047278, 0.7833261011833438, 0.9729992253740212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 286}], {
             RGBColor[
             0.5026576114954506, 0.6036933858840027, 0.9550795945789413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 297}], {
             RGBColor[
             0.8078178799157782, 0.8504679898501292, 0.9680687293960146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 182}], {
             RGBColor[
             0.4457188826999683, 0.5505885890580104, 0.9511731025498219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 277}], {
             RGBColor[
             0.5035178093061974, 0.6055825165768041, 0.9546754362464454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 187}], {
             RGBColor[
             0.7668958286441043, 0.8178241170517282, 0.9774006672164122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 213}], {
             RGBColor[
             0.5619789621186398, 0.6485949757052919, 0.9615726810968985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 219}], {
             RGBColor[
             0.8752460768948074, 0.9033934296642512, 0.9879544677864625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 221}], {
             RGBColor[
             0.7079353372493937, 0.7711123892682143, 0.9719693637575935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 264}], {
             RGBColor[
             0.7909752403011976, 0.836635136448556, 0.9798006779354955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[
             0.5671649640223861, 0.6515651216382375, 0.962247459095882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 195}], {
             RGBColor[
             0.7175877318768239, 0.7787769971394064, 0.9728984962147549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 200}], {
             RGBColor[
             0.55886613886514, 0.6428425302220664, 0.9617748532801884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 225}], {
             RGBColor[
             0.6662325891532404, 0.7370845787535862, 0.9688556312594682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 228}], {
             RGBColor[
             0.5301461065964597, 0.6126559553524642, 0.9601392899299674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 255}], {
             RGBColor[
             0.5915548835760062, 0.6735920820629969, 0.9637685498194339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 198}], {
             RGBColor[
             0.497643009291297, 0.5988517919656489, 0.9549709293675945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 245}], {
             RGBColor[
             0.6246275666787703, 0.7056094719103962, 0.9639547209891537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 289}], {
             RGBColor[
             0.5161443490274096, 0.6148767225406963, 0.9561498183754873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 298}], {
             RGBColor[
             0.5733375563428555, 0.6639699309310663, 0.959916983494012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 174}], {
             RGBColor[
             0.6940065197668115, 0.7602545377919292, 0.9705650388318927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 183}], {
             RGBColor[
             0.5739129035678965, 0.6602554460082184, 0.9618020521896327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 203}], {
             RGBColor[
             0.7121466167102015, 0.7749814856926278, 0.9719930937126409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 206}], {
             RGBColor[
             0.6620923576410931, 0.7343451832616514, 0.9680526390839284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 244}], {
             RGBColor[
             0.7198749026819751, 0.7810910123178394, 0.9727140607520433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 270}], {
             RGBColor[
             0.5911525202324699, 0.6751875354747441, 0.9629005453191049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 272}], {
             RGBColor[
             0.5318051076480561, 0.6208456323248256, 0.9592265609981798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 186}], {
             RGBColor[
             0.47176106622147684`, 0.5806780960245561, 0.9519330743343212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 196}], {
             RGBColor[
             0.5154362263680698, 0.6174933745598067, 0.9549961743262552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 209}], {
             RGBColor[
             0.49561027588077494`, 0.601335082735309, 0.9534527248847836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 230}], {
             RGBColor[
             0.5699102862218139, 0.6617178703775067, 0.9592845718629981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 263}], {
             RGBColor[
             0.46774708694796285`, 0.5772013889263026, 0.9516773071244353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 276}], {
             RGBColor[
             0.4782507320555449, 0.5862991183899369, 0.9523465901026817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 279}], {
             RGBColor[
             0.424681114945645, 0.5398998085365851, 0.9489331814701915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 185}], {
             RGBColor[
             0.7526865721835105, 0.8067749351258047, 0.976233507286727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 194}], {
             RGBColor[
             0.5827040448245648, 0.6721044199634768, 0.9602917434052887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 283}], {
             RGBColor[
             0.6907961069155248, 0.7577465388724627, 0.9702450548818903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 297}], {
             RGBColor[
             0.7758780151265752, 0.8248884275392481, 0.9653145589038838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 177}], {
             RGBColor[
             0.5009637618190796, 0.6042042894427571, 0.954282268847665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 242}], {
             RGBColor[
             0.4987677446069823, 0.6023022097086727, 0.9541423405727719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 252}], {
             RGBColor[
             0.5302624949084447, 0.6295300072766692, 0.9561633524961647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 253}], {
             RGBColor[
             0.7074299557649031, 0.770801458247563, 0.9718616450033607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 280}], {
             RGBColor[
             0.5250544564925894, 0.6250704383354303, 0.9558173066096962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 199}], {
             RGBColor[
             0.5058537994955314, 0.6087567867522139, 0.954506271764645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 226}], {
             RGBColor[
             0.5520441888685743, 0.647213367687633, 0.9578780872336801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 287}], {
             RGBColor[
             0.6147244374002241, 0.6981000171586439, 0.9628125060034074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 217}], {
             RGBColor[
             0.6449568766095631, 0.7178528678680822, 0.9680889198753276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 247}], {
             RGBColor[
             0.6380601535706412, 0.7123536081234056, 0.9674311042750979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 273}], {
             RGBColor[
             0.41408674557543024`, 0.5330828592376182, 0.9476062191589025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 285}], {
             RGBColor[
             0.4075021805736869, 0.527379639982968, 0.9471866564994937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 182}], {
             RGBColor[
             0.4615098815325068, 0.5630216031354343, 0.9526807057093172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 202}], {
             RGBColor[
             0.5016404290230579, 0.6027120687027827, 0.9550572259122239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 208}], {
             RGBColor[
             0.5550673634850829, 0.6489877940179836, 0.9584615429325609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 268}], {
             RGBColor[
             0.8277891081854829, 0.8647771222676839, 0.9082923237354237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 281}], {
             RGBColor[
             0.5814017989224107, 0.6533938131159434, 0.962668108771225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 190}], {
             RGBColor[
             0.5663240636783959, 0.6575088254736674, 0.9596989625408416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 250}], {
             RGBColor[
             0.7072668283046513, 0.7677930771634367, 0.9352002388322496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 207}], {
             RGBColor[
             0.6319393208231013, 0.7096278548420079, 0.9658414221197125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 232}], {
             RGBColor[
             0.5429266644126531, 0.6304411170068769, 0.9601914244321038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 240}], {
             RGBColor[
             0.8726007885050475, 0.9012069566045406, 0.9811096138510138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 246}], {
             RGBColor[
             0.6937049759307329, 0.7597719961694364, 0.970703840744835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 256}], {
             RGBColor[
             0.6294217438074058, 0.7075839724051141, 0.9656432292348485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 296}], {
             RGBColor[
             0.5890636487498967, 0.6727191418581581, 0.9630464143060031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 299}], {
             RGBColor[
             0.8689772568114253, 0.898504532600426, 0.9872433078398919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 208}], {
             RGBColor[
             0.3489661328961344, 0.4717472552409765, 0.9436373541000163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 268}], {
             RGBColor[
             0.6216878775965344, 0.6875365834906768, 0.893468134902879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 244}], {
             RGBColor[
             0.5071448983944421, 0.6080957729110819, 0.9551472414164259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 189}], {
             RGBColor[
             0.509784432677516, 0.6060185278424693, 0.95665565132686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 197}], {
             RGBColor[
             0.34660340819697444`, 0.4733218723342635, 0.9433542175108687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 202}], {
             RGBColor[
             0.31512179916448746`, 0.44605408490200105`, 0.9413482372214125]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 214}], {
             RGBColor[
             0.6443068280636031, 0.7083031210397264, 0.7663672591719091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 216}], {
             RGBColor[
             0.4158842681080083, 0.5310520224153815, 0.9483979984801565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 275}], {
             RGBColor[
             0.44720669973885513`, 0.5564809834727676, 0.9508638150359845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 293}], {
             RGBColor[
             0.567149937072624, 0.650992463282097, 0.9623309644089002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 237}], {
             RGBColor[
             0.8750518583974458, 0.9032066155089273, 0.987944421493606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 239}], {
             RGBColor[
             0.8085482860618769, 0.8510424277579272, 0.9813719841336758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 282}], {
             RGBColor[
             0.8352525610389733, 0.8719040103300416, 0.9840336166977547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 283}], {
             RGBColor[
             0.8421125474208417, 0.8772630838293849, 0.9847173560300817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 295}], {
             RGBColor[
             0.7357364972363951, 0.7930141006915619, 0.9748991352967196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 297}], {
             RGBColor[
             0.9271944556318922, 0.9444049724961703, 0.9797868600520754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 196}], {
             RGBColor[
             0.44698584002716346`, 0.5605644512887915, 0.9499826777736609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 230}], {
             RGBColor[
             0.5014598998809077, 0.6047889471064916, 0.9542710753104038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 263}], {
             RGBColor[
             0.39929670060705647`, 0.5202724656552874, 0.946663810571841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 269}], {
             RGBColor[
             0.38846612210379705`, 0.5108915629164676, 0.945973695686718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 276}], {
             RGBColor[
             0.4098003457146385, 0.5293701951189216, 0.9473330935500874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 279}], {
             RGBColor[
             0.3562307286047386, 0.48297088526556986`, 0.9439196849175971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 205}], {
             RGBColor[
             0.6026863440735206, 0.6871718954155213, 0.9626545407965711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 213}], {
             RGBColor[
             0.5128436633373525, 0.6102101068552485, 0.9566753337098532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 264}], {
             RGBColor[
             0.7418399415199104, 0.7982502675985126, 0.9749033305484504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 212}], {
             RGBColor[
             0.4994233159328177, 0.6018351697265061, 0.954474314685057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 243}], {
             RGBColor[
             0.4990115934567487, 0.6014785564115085, 0.9544480800929538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 294}], {
             RGBColor[
             0.566390969745354, 0.6588502595490914, 0.959014677574014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 197}], {
             RGBColor[
             0.5618139884701763, 0.6523942258658548, 0.9599229516774894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 211}], {
             RGBColor[
             0.451961006475359, 0.5452424406870303, 0.9533626927467403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 216}], {
             RGBColor[
             0.6310948483812101, 0.7101243759469729, 0.9649667326467772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 275}], {
             RGBColor[
             0.6624172800120569, 0.7355533370043589, 0.9674325492026051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 293}], {
             RGBColor[
             0.7823605173458257, 0.8300648168136883, 0.978899698575521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 212}], {
             RGBColor[
             0.5261757555032601, 0.622734378845007, 0.9571407478456768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 250}], {
             RGBColor[
             0.8374901973720366, 0.8731516671981161, 0.9458902728478122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 203}], {
             RGBColor[
             0.533710591956615, 0.6316899676926455, 0.9566114564279513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 195}], {
             RGBColor[
             0.4494167792189582, 0.5588039171334883, 0.9509896757928566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 200}], {
             RGBColor[
             0.2906951862072743, 0.4228694502161483, 0.9398660328582902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[
             0.39806163649537457`, 0.5171114987476682, 0.9469468108375699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 228}], {
             RGBColor[
             0.26197515393859394`, 0.39268287534654606`, 0.9382304695080692]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 255}], {
             RGBColor[
             0.32338393091814044`, 0.45361900205707884`, 0.9418597293975357]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 199}], {
             RGBColor[
             0.35434940275490534`, 0.47966657625189263`, 0.9438611310980534]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 220}], {
             RGBColor[
             0.4178233145742393, 0.5321546993230242, 0.9485935687656895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 236}], {
             RGBColor[
             0.4001159391490532, 0.5177790542446857, 0.9471995793079653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 249}], {
             RGBColor[
             0.41998330072330176`, 0.5339082733851002, 0.9487636107876336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 266}], {
             RGBColor[
             0.33338994200621164`, 0.4615125448045019, 0.9425256127928701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 283}], {
             RGBColor[
             0.6721300200618961, 0.7425925686670569, 0.9687755921486435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 286}], {
             RGBColor[
             0.45205165985261897`, 0.5629598533677159, 0.9508559613535637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 297}], {
             RGBColor[
             0.7572119282729466, 0.8097344573338423, 0.9638450961706371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 200}], {
             RGBColor[
             0.44111795406171206`, 0.5500813257173172, 0.9505170699771631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 225}], {
             RGBColor[
             0.5484844043498123, 0.644323374248837, 0.9575978479564429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.4738066987725782, 0.5808308775582477, 0.9525107665164085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 230}], {
             RGBColor[
             0.5451350600275006, 0.6416042256417421, 0.9573341753023379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 263}], {
             RGBColor[
             0.44297186075364947`, 0.557087744190538, 0.9497269105637751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 279}], {
             RGBColor[
             0.3999058887513316, 0.5197861638008205, 0.9469827849095311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 289}], {
             RGBColor[
             0.42298477851454863`, 0.5397759381349917, 0.9484533513573825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 298}], {
             RGBColor[
             0.4801779858299946, 0.5888691465253618, 0.9522205164759072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 214}], {
             RGBColor[
             0.6963363838562633, 0.754678819063112, 0.7696345595225385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 275}], {
             RGBColor[
             0.49923625553151524`, 0.6028566814961531, 0.9541311153866139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 293}], {
             RGBColor[
             0.6191794928652841, 0.6973681613054825, 0.9655982647595296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 222}], {
             RGBColor[
             0.48251877780275, 0.5870366273783794, 0.9534634873167952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 245}], {
             RGBColor[
             0.44529043477058905`, 0.556879965240594, 0.9504869385549437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 258}], {
             RGBColor[
             0.4380163028305931, 0.5509744972357958, 0.9499142922426038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 278}], {
             RGBColor[
             0.39196517303905043`, 0.5135881154912662, 0.946288978614567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 290}], {
             RGBColor[
             0.5108602836328234, 0.6091772271362549, 0.9562883037515066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 220}], {
             RGBColor[
             0.4815411073026523, 0.589018647955733, 0.9525922875748956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 226}], {
             RGBColor[
             0.46425758485636126`, 0.5749871058200207, 0.9512316653762947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 228}], {
             RGBColor[
             0.32151174599799287`, 0.4451521169726871, 0.941991075124707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 266}], {
             RGBColor[
             0.39710773473462463`, 0.5183764934372108, 0.9465243316020762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 225}], {
             RGBColor[
             0.38976281133812846`, 0.508388907331497, 0.9464742050218764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 255}], {
             RGBColor[
             0.3150851057608943, 0.4448964106409077, 0.9413871235818421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 282}], {
             RGBColor[
             0.5244492352195737, 0.6158316996886668, 0.9583774260015938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 295}], {
             RGBColor[
             0.4249331714169955, 0.536941790050187, 0.9492429446005588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 209}], {
             RGBColor[
             0.695255346439769, 0.759732057157846, 0.9686255398285264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 218}], {
             RGBColor[
             0.747224717419796, 0.801985825782935, 0.9726994370764148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 229}], {
             RGBColor[
             0.7541587614728889, 0.8076151951203605, 0.9732453104245145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 257}], {
             RGBColor[
             0.9091956352780889, 0.930333877964705, 0.987801338410267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 259}], {
             RGBColor[
             0.7555759586919695, 0.8087657396668173, 0.973356877380965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 261}], {
             RGBColor[
             0.647762811184587, 0.7185964101640356, 0.9655993574780661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 208}], {
             RGBColor[
             0.38909668038668555`, 0.511437720808325, 0.9460138743029227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 214}], {
             RGBColor[
             0.6648547748237763, 0.7274110316308495, 0.7676285792330823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 268}], {
             RGBColor[
             0.6618184250870855, 0.7272270490580253, 0.8958446551057856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 275}], {
             RGBColor[
             0.4677546464990283, 0.5755888940638906, 0.9521251350971576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 206}], {
             RGBColor[
             0.5875960664958653, 0.6760759835393033, 0.9606768612713192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 244}], {
             RGBColor[
             0.6453786115367471, 0.7228218125954913, 0.9653382829394341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 270}], {
             RGBColor[
             0.5166562290872421, 0.616918335752396, 0.9555247675064957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 235}], {
             RGBColor[
             0.5281473336883742, 0.6273167335780836, 0.9561339105492572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 253}], {
             RGBColor[
             0.7153961100576498, 0.7772687411735759, 0.9724887698502704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 292}], {
             RGBColor[
             0.46453885602351486`, 0.5721376148445174, 0.9520839341395575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 213}], {
             RGBColor[
             0.397769477548056, 0.517942754069085, 0.9468265546770573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 231}], {
             RGBColor[
             0.4547373806048302, 0.5673612293387986, 0.9504537258385497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 244}], {
             RGBColor[
             0.5953243524676388, 0.6821855101645149, 0.9613978283107216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 270}], {
             RGBColor[
             0.46660197001813364`, 0.5762820333214196, 0.9515843128777832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 272}], {
             RGBColor[
             0.40725455743371985`, 0.521940130171501, 0.9479103285568581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 231}], {
             RGBColor[
             0.4417895552657245, 0.5568496014356283, 0.9494344255984084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 232}], {
             RGBColor[
             0.3727038511955644, 0.4946945489878862, 0.9451171635958837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 240}], {
             RGBColor[
             0.7023779752879588, 0.76546038858555, 0.9660353530147936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 268}], {
             RGBColor[
             0.7152453595491104, 0.7735027743732261, 0.8992489721261228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 218}], {
             RGBColor[
             0.5029784701791936, 0.6073169148001356, 0.9540327761305402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 276}], {
             RGBColor[
             0.43364955537393657`, 0.5500271818296745, 0.9488527441005499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 279}], {
             RGBColor[
             0.3800799382640367, 0.5036278719763227, 0.9454393354680596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 239}], {
             RGBColor[
             0.665224008447207, 0.7380142806784675, 0.9675288553244933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 277}], {
             RGBColor[
             0.49418048080775206`, 0.5980020526599108, 0.9539403675432864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 216}], {
             RGBColor[
             0.3580608419058512, 0.4702759352599425, 0.9451050399000369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 221}], {
             RGBColor[
             0.389383273536698, 0.4957048963173286, 0.9475708564558648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 243}], {
             RGBColor[
             0.3553923557846702, 0.4822447288666698, 0.9438662645428464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 250}], {
             RGBColor[
             0.6671185201295156, 0.7330186305347763, 0.9326420241370849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 294}], {
             RGBColor[
             0.42277173207327534`, 0.5396164320042527, 0.9484328620239066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 231}], {
             RGBColor[
             0.3648946998686622, 0.4903994407785258, 0.944474518751832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 264}], {
             RGBColor[
             0.5369230749944458, 0.6290211262520764, 0.9590753444289366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 275}], {
             RGBColor[
             0.7969396753981439, 0.837837930201616, 0.7771441570476543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 293}], {
             RGBColor[
             0.9168829127319127, 0.9323494100109454, 0.78861130642057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 223}], {
             RGBColor[
             0.4046253881637031, 0.5220110546057855, 0.9475026012691115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 234}], {
             RGBColor[
             0.564317049955213, 0.6571770292038577, 0.9588442518153918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 271}], {
             RGBColor[
             0.43204281315428195`, 0.5469920507938557, 0.9492044545036049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 274}], {
             RGBColor[
             0.6519384028210722, 0.7260498326897473, 0.9672887755061639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 282}], {
             RGBColor[
             0.6401735864642298, 0.716859068735866, 0.9661161685601736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 286}], {
             RGBColor[
             0.4269552126368211, 0.5425854269358682, 0.9488802770974208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 233}], {
             RGBColor[
             0.7431154316926778, 0.79908209129615, 0.9753909009530146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 247}], {
             RGBColor[
             0.886404498748788, 0.9122589027658746, 0.9890272464649387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 262}], {
             RGBColor[
             0.69682562186329, 0.7615019383444844, 0.9717467975580847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 273}], {
             RGBColor[
             0.6624310907535771, 0.7329881538800872, 0.9692023613487433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 229}], {
             RGBColor[
             0.5618818852123133, 0.6552000527626501, 0.9586525467265283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 284}], {
             RGBColor[
             0.4524929737066178, 0.5635889152304235, 0.9508158849378793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 221}], {
             RGBColor[
             0.7671502867188096, 0.818296833030694, 0.9776258169405985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 264}], {
             RGBColor[
             0.8501901897706134, 0.8838195802110357, 0.9854571311185005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 226}], {
             RGBColor[
             0.5277314966756952, 0.6274752288911521, 0.9559641030439306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 228}], {
             RGBColor[
             0.38498565781732685`, 0.49764024004381857`, 0.946723512792343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 236}], {
             RGBColor[
             0.5273076436968003, 0.6271311259485262, 0.9559307357848075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 266}], {
             RGBColor[
             0.4605816465539586, 0.5708646165083422, 0.9512567692697123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 231}], {
             RGBColor[
             0.5108510749994162, 0.6129168543414483, 0.9548712014125269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 245}], {
             RGBColor[
             0.6095033351902233, 0.6937943073231267, 0.9624472789383545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 261}], {
             RGBColor[
             0.5013778534555934, 0.603371410824169, 0.9546651709409686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 278}], {
             RGBColor[
             0.5561780734586848, 0.650502457573799, 0.9582493189979777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 290}], {
             RGBColor[
             0.6750731840524578, 0.7460915692187876, 0.9682486441349174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 234}], {
             RGBColor[
             0.45509737457957555`, 0.5629864869152674, 0.9514759409247471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 271}], {
             RGBColor[
             0.32282313777864446`, 0.45280150850526546`, 0.9418361436129603]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 274}], {
             RGBColor[
             0.5427187274454346, 0.6318592904011571, 0.9599204646155192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 287}], {
             RGBColor[
             0.46560709204038464`, 0.5715187490073285, 0.9523033043816256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 291}], {
             RGBColor[
             0.3123991040774018, 0.44377273444041676`, 0.9411719334031281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 249}], {
             RGBColor[
             0.5964028262633069, 0.6832086786281768, 0.9613818046382261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 254}], {
             RGBColor[
             0.5719103415226863, 0.6633245761418773, 0.9594536665205167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 258}], {
             RGBColor[
             0.6005986946922865, 0.6866150736405412, 0.9617121187709279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 260}], {
             RGBColor[
             0.6913555987833708, 0.7588115153575121, 0.9698715230674781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 288}], {
             RGBColor[
             0.549892068668861, 0.6454491503272537, 0.9577203074258724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 234}], {
             RGBColor[
             0.5559591489986571, 0.6503917086881783, 0.9581862872360918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 255}], {
             RGBColor[
             0.4224515560489946, 0.5391384591724275, 0.9484679015611217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 287}], {
             RGBColor[
             0.5664688664594663, 0.6589239707802392, 0.9590136506929702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 228}], {
             RGBColor[
             0.3677021353710358, 0.48360869790810623`, 0.9453628905937421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 266}], {
             RGBColor[
             0.44329812410766756`, 0.55683307437263, 0.9498961470711114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 264}], {
             RGBColor[
             0.7248315753610184, 0.7849632026868156, 0.9732080955619506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 266}], {
             RGBColor[
             0.30055228524929917`, 0.42699808552529633`, 0.9406555568195236]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 257}], {
             RGBColor[
             0.7238528030706062, 0.7835481049444202, 0.9737544480603806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 259}], {
             RGBColor[
             0.5702331264844869, 0.6619799666465325, 0.9593099870310786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 261}], {
             RGBColor[
             0.4624199789771043, 0.5718106371437508, 0.9515524671281796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 284}], {
             RGBColor[
             0.45942701775971057`, 0.5692182845678491, 0.951361758285979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 263}], {
             RGBColor[
             0.4974459206073936, 0.601312240008238, 0.954015308100518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 269}], {
             RGBColor[
             0.4866153421041342, 0.5919313372694184, 0.9533251932153949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 289}], {
             RGBColor[
             0.47745883836829284`, 0.5840004339526917, 0.9527417488941254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 298}], {
             RGBColor[
             0.5346520456837388, 0.6330936423430619, 0.9565089140126501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 240}], {
             RGBColor[
             0.6133653188775106, 0.686273650750419, 0.960385355327185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 256}], {
             RGBColor[
             0.3701862741798688, 0.4926506665509924, 0.9449189707110197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 296}], {
             RGBColor[
             0.32982817912235973`, 0.45778583600403644`, 0.9423221557821744]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 299}], {
             RGBColor[
             0.6097417871838884, 0.6835712267463043, 0.9665190493160631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 262}], {
             RGBColor[
             0.5466398317682577, 0.6428258671300833, 0.9574526364459308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 288}], {
             RGBColor[
             0.5246215589144325, 0.6249504413154595, 0.9557192773512866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 291}], {
             RGBColor[
             0.46116106848219174`, 0.5700654883226934, 0.9516531581343252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 255}], {
             RGBColor[
             0.481281443421423, 0.5868992119975889, 0.9530992057960574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 271}], {
             RGBColor[
             0.4825147995701544, 0.5879674831033377, 0.9531777941592405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 274}], {
             RGBColor[
             0.7024103892369447, 0.7670252649992293, 0.9712621151617995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 287}], {
             RGBColor[
             0.6252987538318946, 0.7066847236054006, 0.9636449549279058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 252}], {
             RGBColor[
             0.445128682097329, 0.5599184522688391, 0.9495983781886691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 253}], {
             RGBColor[
             0.6222961429537874, 0.7011899032397328, 0.9652966706958651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 292}], {
             RGBColor[
             0.3714388889196525, 0.49605877691067435`, 0.9448918349851523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 249}], {
             RGBColor[
             0.5294676298458627, 0.6288847000106021, 0.9561007778067516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 266}], {
             RGBColor[
             0.44287427112877253`, 0.5564889714300039, 0.9498627798119881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 239}], {
             RGBColor[
             0.7795971317704954, 0.8279575631841278, 0.9786105971923633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 282}], {
             RGBColor[
             0.8063014067475918, 0.8488191457562422, 0.9812722297564422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 283}], {
             RGBColor[
             0.8131613931294602, 0.8541782192555855, 0.9819559690887693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 295}], {
             RGBColor[
             0.7067853429450135, 0.7699292361177625, 0.9721377483554071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 297}], {
             RGBColor[
             0.8982433013405107, 0.9213201079223708, 0.9770254731107628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 251}], {
             RGBColor[
             0.5336294701095035, 0.6304845014245992, 0.9570679718879488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 300}], {
             RGBColor[
             0.5227499971118408, 0.6210612487322362, 0.9563747414888779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 295}], {
             RGBColor[
             0.6402817706094446, 0.7177650483667622, 0.9655653109954769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 256}], {
             RGBColor[
             0.6998603982722631, 0.7634165061486562, 0.9658371601299296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 281}], {
             RGBColor[
             0.583746805216541, 0.6551427149705104, 0.9586986247908571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 299}], {
             RGBColor[
             0.9394159112762828, 0.9543370663439681, 0.987437238734973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 277}], {
             RGBColor[
             0.37539982914797587`, 0.4995741966891146, 0.9451411230536422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 243}], {
             RGBColor[
             0.3736005651579114, 0.4980157646545584, 0.9450264755432219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 280}], {
             RGBColor[
             0.4185072088928286, 0.5369116423842022, 0.9478878871726251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 294}], {
             RGBColor[
             0.44097994144651653`, 0.5553874677921413, 0.9495930730242822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 294}], {
             RGBColor[
             0.42236000959720643`, 0.5392598186892551, 0.9484066274318034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 270}], {
             RGBColor[
             0.5243845150590156, 0.6230278623776075, 0.9562457345458981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 272}], {
             RGBColor[
             0.4650371024746018, 0.568685959227689, 0.9525717502249731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 289}], {
             RGBColor[
             0.4637917745067016, 0.5729048958156414, 0.9516658275628365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 298}], {
             RGBColor[
             0.5209849818221476, 0.6219981042060115, 0.9554329926813612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 256}], {
             RGBColor[
             0.5209645856979486, 0.6219815457135518, 0.9554313870237507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 296}], {
             RGBColor[
             0.4806064906404395, 0.5871167151665959, 0.9528345720949054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 299}], {
             RGBColor[
             0.7605200987019681, 0.8129021059088637, 0.9770314656287942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 267}], {
             RGBColor[
             0.5984600291066218, 0.6780539706727999, 0.9649078193612657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 273}], {
             RGBColor[
             0.6555343677146552, 0.7274888941354106, 0.9685445457485136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 285}], {
             RGBColor[
             0.6489498027129118, 0.7217856748807603, 0.9681249830891048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 270}], {
             RGBColor[
             0.40636516495397856`, 0.5263948142012433, 0.9471142068696293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 254}], {
             RGBColor[
             0.5248425066794906, 0.625129816664717, 0.9557366711687103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 288}], {
             RGBColor[
             0.5028242338256653, 0.6072543908500934, 0.9540033120740662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 300}], {
             RGBColor[
             0.39030194372923777`, 0.5124816593373467, 0.9460906726173377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 253}], {
             RGBColor[
             0.6323774584666046, 0.7098704598643314, 0.9659532374896823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 292}], {
             RGBColor[
             0.3815202044324696, 0.5047393335352729, 0.9455484017789695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 292}], {
             RGBColor[
             0.5586876652889281, 0.6460107845061667, 0.9612466942861655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 258}], {
             RGBColor[
             0.5290383751084702, 0.6285362116770814, 0.9560669853014121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 260}], {
             RGBColor[
             0.6197952791995545, 0.7007326533940524, 0.9642263895979624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 288}], {
             RGBColor[
             0.4783317490850447, 0.5873702883637939, 0.9520751739563567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 287}], {
             RGBColor[
             0.4917911608822321, 0.5954314740896499, 0.953926569252936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 296}], {
             RGBColor[
             0.4163232585171124, 0.5349286914022735, 0.9477739605849189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 299}], {
             RGBColor[
             0.696236866578641, 0.7607140821445414, 0.9719708541188077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 259}], {
             RGBColor[
             0.7252700002896869, 0.784698649490877, 0.973866015016831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 261}], {
             RGBColor[
             0.6174568527823044, 0.6945293199880953, 0.966108495113932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 260}], {
             RGBColor[
             0.6484836323691547, 0.7240231508927162, 0.9664848418483736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 278}], {
             RGBColor[
             0.5116755984865278, 0.6144403274312155, 0.9547001239237864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 290}], {
             RGBColor[
             0.6305707090803008, 0.7100294390762041, 0.9646994490607261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 260}], {
             RGBColor[
             0.6554454300819033, 0.7296750519013383, 0.9670329000662263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 261}], {
             RGBColor[
             0.46383717619618503`, 0.5729611816902076, 0.9516640340846301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 261}], {
             RGBColor[
             0.5476322825745208, 0.6395057223985565, 0.9592753801633275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 278}], {
             RGBColor[
             0.602432502577612, 0.6866367691481865, 0.9628595282203366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 290}], {
             RGBColor[
             0.721327613171385, 0.7822258807931752, 0.9728588533572763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 278}], {
             RGBColor[
             0.4108242486918938, 0.5299228989370558, 0.9474906622387403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 290}], {
             RGBColor[
             0.5297193592856668, 0.6255120105820445, 0.95748998737568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 271}], {
             RGBColor[
             0.42529529235404673`, 0.5415141094358766, 0.9486732649492273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 291}], {
             RGBColor[
             0.41487125865280405`, 0.5324853353710279, 0.9480090547393952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 269}], {
             RGBColor[
             0.38445214283028306`, 0.5074148558182143, 0.9457179284768321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 276}], {
             RGBColor[
             0.40578636644112454`, 0.5258934880206683, 0.9470773263402017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 279}], {
             RGBColor[
             0.3522167493312246, 0.47949417816731643`, 0.9436639177077113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 289}], {
             RGBColor[
             0.37529563909444164`, 0.4994839525014877, 0.9451344841555627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 298}], {
             RGBColor[
             0.4324888464098876, 0.5485771608918577, 0.9489016492740874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 269}], {
             RGBColor[
             0.6807943342882671, 0.7436630278511606, 0.8970537832603472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 273}], {
             RGBColor[
             0.37448662111141084`, 0.4987832217870125, 0.9450829342450704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 285}], {
             RGBColor[
             0.3679020561096674, 0.49308000253236217`, 0.9446633715856616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 286}], {
             RGBColor[
             0.32873882211883954`, 0.45915877765088126`, 0.9421679249464541]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 298}], {
             RGBColor[
             0.4216582679066282, 0.5391962581530381, 0.9482115343889642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 272}], {
             RGBColor[
             0.33631472002509666`, 0.46278248238459374`, 0.9427582347920347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 274}], {
             RGBColor[
             0.5701361524360136, 0.6568402865892272, 0.9616223178500127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 291}], {
             RGBColor[
             0.3398165290679807, 0.4687537306284869, 0.9428737866376217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 285}], {
             RGBColor[
             0.4249763947177009, 0.5425149259949729, 0.9483000979729095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 287}], {
             RGBColor[
             0.7129201066977537, 0.7755575270912902, 0.972089478618678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 293}], {
             RGBColor[
             0.7197827844071647, 0.7805272724439866, 0.9731078622846454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 279}], {
             RGBColor[
             0.36272039443880666`, 0.4885919076309507, 0.9443332006859577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 290}], {
             RGBColor[
             0.5845195792887581, 0.6726430573316744, 0.9610741354326892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 283}], {
             RGBColor[
             0.7733620957709877, 0.8228756140766997, 0.978045164292918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 295}], {
             RGBColor[
             0.666986045586541, 0.7386266309388767, 0.9682269435595559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 297}], {
             RGBColor[
             0.858444003982038, 0.8900175027434851, 0.9731146683149117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 295}], {
             RGBColor[
             0.6738460319684094, 0.7439857044382199, 0.968910682891883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 297}], {
             RGBColor[
             0.8653039903639066, 0.8953765762428283, 0.9737984076472387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 291}], {
             RGBColor[
             0.39285298579897876`, 0.5146099095564043, 0.9462756956447511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 298}], {
             RGBColor[
             0.4125017641707868, 0.5312653548363114, 0.9476280900676948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 297}], {
             RGBColor[
             0.7589279401794599, 0.8111275931050053, 0.9639801869138765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 299}], {
             RGBColor[
             0.6558787715211319, 0.7258492515975854, 0.9693740391899623]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.10302533798448267`], {
             RGBColor[
             0.46409626063826687`, 0.5758132775412534, 0.950954504159514]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.10302533798448267`], {
             RGBColor[
             0.3778347549674962, 0.5016832070510531, 0.9452962743737416]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.10302533798448267`], {
             RGBColor[
             0.6127507783325494, 0.6964977118151778, 0.9626571323318486]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.10302533798448267`], {
             RGBColor[
             0.6054594651337846, 0.6905782952905041, 0.9620831334478815]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.10302533798448267`], {
             RGBColor[
             0.6173290790421584, 0.7002145825813348, 0.9630175529345771]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.10302533798448267`], {
             RGBColor[
             0.8039814622950681, 0.8467956959211159, 0.9810970165937897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.10302533798448267`], {
             RGBColor[
             0.7010016441671194, 0.7663470793239568, 0.970832950723911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.10302533798448267`], {
             RGBColor[
             0.5998395470733959, 0.6860157926346572, 0.9616407129117296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.10302533798448267`], {
             RGBColor[
             0.2941986823738441, 0.42655184682170005`, 0.9400655517820182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.10302533798448267`], {
             RGBColor[
             0.5123118246229064, 0.6149568444703883, 0.9547502099758153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.10302533798448267`], {
             RGBColor[
             0.5548158597687018, 0.6494635349867077, 0.9580962833199032]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.10302533798448267`], {
             RGBColor[
             0.22445416746317717`, 0.3532459395929378, 0.9360937048356194]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.10302533798448267`], {
             RGBColor[
             0.4674918408138564, 0.5785699624969407, 0.9512218166693565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.10302533798448267`], {
             RGBColor[
             0.3430571598906369, 0.47156060216823065`, 0.9430802767680639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.10302533798448267`], {
             RGBColor[
             0.4425236148487104, 0.5577134461235258, 0.9494181913232599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.10302533798448267`], {
             RGBColor[
             0.6914202043359422, 0.7588619857062013, 0.9698779623451852]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.10302533798448267`], {
             RGBColor[
             0.3922204970072215, 0.5141434137574445, 0.9462129211357008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.10302533798448267`], {
             RGBColor[
             0.7106163389569812, 0.7738581519681836, 0.9717912536461331]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.10302533798448267`], {
             RGBColor[
             0.49571106421046124`, 0.6014795993118314, 0.9534433373055585]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.10302533798448267`], {
             RGBColor[
             0.33616273368604854`, 0.46558899671375287`, 0.9426409700268094]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.10302533798448267`], {
             RGBColor[
             0.5133595198991008, 0.6158074106937373, 0.9548326883857915]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.10302533798448267`], {
             RGBColor[
             0.7730752374249796, 0.8226515181565941, 0.9780165729338316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.10302533798448267`], {
             RGBColor[
             0.4657801727717393, 0.5771803532705835, 0.9510870678910344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.10302533798448267`], {
             RGBColor[
             0.5698065509316947, 0.6616336533957663, 0.959276405440965]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.10302533798448267`], {
             RGBColor[
             0.5138450635393406, 0.6162015968943757, 0.9548709121597562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.10302533798448267`], {
             RGBColor[
             0.35908418596665354`, 0.4854424066135235, 0.9441015046974851]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.10302533798448267`], {
             RGBColor[
             0.4459002681090488, 0.5606381334621033, 0.9496333486831514]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.10302533798448267`], {
             RGBColor[
             0.513531505367556, 0.6159470362448862, 0.9548462277118719]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.10302533798448267`], {
             RGBColor[
             0.5450150191219864, 0.6415067710268645, 0.9573247252425315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.10302533798448267`], {
             RGBColor[
             0.6548369035071157, 0.7302828330553378, 0.9662316808089513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.10302533798448267`], {
             RGBColor[
             0.18422139263486803`, 0.31095874234312754`, 0.9338025078282037]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.10302533798448267`], {
             RGBColor[
             0.31969295353105853`, 0.4513237009387203, 0.9415915301989881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.10302533798448267`], {
             RGBColor[
             0.7371605528866397, 0.7945946936335307, 0.974436932820859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.10302533798448267`], {
             RGBColor[
             0.7503401652443876, 0.8048907069761673, 0.9757505534101992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.10302533798448267`], {
             RGBColor[
             0.5473711431440824, 0.6434195786501797, 0.9575102079563176]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.10302533798448267`], {
             RGBColor[
             0.563158829552378, 0.6562367337036016, 0.9587530724625795]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.10302533798448267`], {
             RGBColor[
             0.5110330311428454, 0.613918662314285, 0.95464953866869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.10302533798448267`], {
             RGBColor[
             0.8216436172138438, 0.8606203337172098, 0.9828502957714143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.10302533798448267`], {
             RGBColor[
             0.9938577866312612, 0.9892707516143279, 0.5728361640388675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.10302533798448267`], {
             RGBColor[
             0.4372984781268788, 0.553187695318083, 0.9490852502317517]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.10302533798448267`], {
             RGBColor[
             0.43914484307735685`, 0.5547869238371863, 0.9492028989737198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.10302533798448267`], {
             RGBColor[
             0.5572469067758978, 0.651437168464569, 0.9582876642455282]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.10302533798448267`], {
             RGBColor[
             0.4503044216669041, 0.5644527899147234, 0.9499139774534178]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.10302533798448267`], {
             RGBColor[
             0.8281653427900414, 0.8658205806641449, 0.983472343778885]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.10302533798448267`], {
             RGBColor[
             0.3810631990373981, 0.504479523038085, 0.9455019879750748]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.10302533798448267`], {
             RGBColor[
             0.5595392442838725, 0.6532981913221707, 0.958468125451265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.10302533798448267`], {
             RGBColor[
             0.2712671917352294, 0.4024493962200339, 0.9387596373142495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.10302533798448267`], {
             RGBColor[
             0.3358347846276625, 0.4653049437225778, 0.942620073402803]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.10302533798448267`], {
             RGBColor[
             0.6196648905770754, 0.7021108996124912, 0.9632014365749654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.10302533798448267`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.10302533798448267`], {
             RGBColor[
             0.828827599811347, 0.866348646436446, 0.983535510444781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.10302533798448267`], {
             RGBColor[
             0.7142006522207973, 0.7766582447316667, 0.9721485044949585]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.10302533798448267`], {
             RGBColor[
             0.34311584341723766`, 0.47161143088945245`, 0.9430840160304872]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.10302533798448267`], {
             RGBColor[
             0.48319319882394, 0.5913170322676442, 0.9524578850878798]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.10302533798448267`], {
             RGBColor[
             0.34006536173430174`, 0.46896925697736075`, 0.9428896420350855]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.10302533798448267`], {
             RGBColor[
             0.23845603573169508`, 0.36796279091287354`, 0.9368910905196036]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.10302533798448267`], {
             RGBColor[
             0.49192076850520017`, 0.5984024665074248, 0.9531449513433297]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.10302533798448267`], {
             RGBColor[
             0.5080112183968815, 0.6114654185959987, 0.9544116505000629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.10302533798448267`], {
             RGBColor[
             0.44781699598023683`, 0.5622983068065824, 0.9497554808882076]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.10302533798448267`], {
             RGBColor[
             0.5353154771864042, 0.6336322459241742, 0.9565611417707697]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.10302533798448267`], {
             RGBColor[
             0.6287282123595963, 0.709468912533535, 0.9639149344657271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.10302533798448267`], {
             RGBColor[
             0.9948691162406518, 0.9914338833877057, 0.6829131508181451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.10302533798448267`], {
             RGBColor[
             0.6503844724189884, 0.7268045600495633, 0.9657879040884209]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.10302533798448267`], {
             RGBColor[
             0.5083117472314141, 0.611709401442542, 0.9544353092307907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.10302533798448267`], {
             RGBColor[
             0.8239065495987578, 0.862424734575277, 0.9830661362824309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.10302533798448267`], {
             RGBColor[
             0.5508604751785363, 0.6462523755883661, 0.9577849009559142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.10302533798448267`], {
             RGBColor[
             0.5674875455260586, 0.6597509803374679, 0.9590938448406366]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.10302533798448267`], {
             RGBColor[
             0.3879092616788826, 0.5104092384050256, 0.9459382130328546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.10302533798448267`], {
             RGBColor[
             0.34941222228930047`, 0.4770650378032295, 0.9434852157245458]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.10302533798448267`], {
             RGBColor[
             0.7576112038248469, 0.810570897577162, 0.9764752625841806]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.10302533798448267`], {
             RGBColor[
             0.3676025015405266, 0.4928205434206228, 0.9446442842334015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.10302533798448267`], {
             RGBColor[
             0.8074566227330697, 0.8495105176674804, 0.981443388109029]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.10302533798448267`], {
             RGBColor[
             0.5066346746353138, 0.6103478783577683, 0.9543032839327064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.10302533798448267`], {
             RGBColor[
             0.4239552148819582, 0.5416304313472435, 0.9482350292967697]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.10302533798448267`], {
             RGBColor[
             0.48594506843001567`, 0.5935511239841693, 0.9526745223437005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.10302533798448267`], {
             RGBColor[
             0.3227178159777883, 0.45394368475607055`, 0.9417842717593129]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.10302533798448267`], {
             RGBColor[
             0.34328031177666773`, 0.47175388511597066`, 0.9430944958089165]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.10302533798448267`], {
             RGBColor[
             0.8472599211706487, 0.8810460791563186, 0.9852936017107587]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.10302533798448267`], {
             RGBColor[
             0.6918598048058476, 0.7592054049343787, 0.9699217776117254]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.10302533798448267`], {
             RGBColor[
             0.7900317421028037, 0.8358980684851188, 0.9797066388525716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.10302533798448267`], {
             RGBColor[
             0.5233911669566601, 0.6239515536956138, 0.9556224163892966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.10302533798448267`], {
             RGBColor[
             0.9345097356279274, 0.9506167128714307, 0.9936155669025228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.10302533798448267`], {
             RGBColor[
             0.3816055053636691, 0.5049492415207925, 0.9455365432546421]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.10302533798448267`], {
             RGBColor[
             0.7531217817892484, 0.8070637269620813, 0.9760277989517064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.10302533798448267`], {
             RGBColor[
             0.3545897701288067, 0.48154956951068884`, 0.9438151244945534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.10302533798448267`], {
             RGBColor[
             0.42386045240865766`, 0.541548352855771, 0.9482289911157662]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.10302533798448267`], {
             RGBColor[
             0.5440162868864256, 0.6406959552056618, 0.9572461013824715]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.10302533798448267`], {
             RGBColor[
             0.44633044035402236`, 0.5610107270396137, 0.9496607588782147]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.10302533798448267`], {
             RGBColor[
             0.5972323437370213, 0.6838991475130164, 0.9614354643145897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.10302533798448267`], {
             RGBColor[
             0.25334369383045463`, 0.38361066350671225`, 0.9377389206240115]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.10302533798448267`], {
             RGBColor[
             0.5841523803218054, 0.6732802439669072, 0.9604057616810592]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.10302533798448267`], {
             RGBColor[
             0.6389855473308331, 0.7177962791508594, 0.9647224294485188]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.10302533798448267`], {
             RGBColor[
             0.5841523803218054, 0.6732802439669072, 0.9604057616810592]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.10302533798448267`], {
             RGBColor[
             0.27809316851908805`, 0.4096239306117943, 0.9391483665939625]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.10302533798448267`], {
             RGBColor[
             0.3970191098073641, 0.518299730979636, 0.9465186845000791]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.10302533798448267`], {
             RGBColor[
             0.2913697023875267, 0.42357840948838954`, 0.9399044455568983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.10302533798448267`], {
             RGBColor[
             0.31017961268336275`, 0.44308372325086026`, 0.9409853485324899]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.10302533798448267`], {
             RGBColor[
             0.3900672137207567, 0.5122783480018736, 0.9460757158287608]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.10302533798448267`], {
             RGBColor[
             0.4111815247330782, 0.5305665029646182, 0.9474211010558138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.10302533798448267`], {
             RGBColor[
             0.5560531324964622, 0.6504680087256047, 0.9581936859613118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.10302533798448267`], {
             RGBColor[
             0.3908213159856385, 0.5129315134814324, 0.9461237665582527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.10302533798448267`], {
             RGBColor[
             0.43963556900230216`, 0.5552119659687718, 0.9492341675957253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.10302533798448267`], {
             RGBColor[
             0.31606018401044617`, 0.448177178568271, 0.9413600533374666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.10302533798448267`], {
             RGBColor[
             0.5994811197467129, 0.6857248051838889, 0.9616124961996105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.10302533798448267`], {
             RGBColor[
             0.33234979843751117`, 0.4622864238451677, 0.9423980131644188]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.10302533798448267`], {
             RGBColor[
             0.9329854434809398, 0.9494012836892309, 0.9934701785567915]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.10302533798448267`], {
             RGBColor[
             0.6159488649892617, 0.6990940626352589, 0.9629088974284424]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.10302533798448267`], {
             RGBColor[
             0.6498979749690963, 0.72642450454419, 0.9657394145691928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.10302533798448267`], {
             RGBColor[
             0.6539767457735782, 0.7296108712964575, 0.9661459483247032]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.10302533798448267`], {
             RGBColor[
             0.771603607396168, 0.8215018695932839, 0.9778698946057242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.10302533798448267`], {
             RGBColor[
             0.563158829552378, 0.6562367337036016, 0.9587530724625795]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.10302533798448267`], {
             RGBColor[
             0.6031087023891715, 0.6886698401937724, 0.9618980727934979]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.10302533798448267`], {
             RGBColor[
             0.2834538129085057, 0.41525830774955735`, 0.9394536473615771]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.10302533798448267`], {
             RGBColor[
             0.7423342701823578, 0.7986364409066535, 0.9749526006097591]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.10302533798448267`], {
             RGBColor[
             0.7408195291035558, 0.7974531136634347, 0.9748016253750843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.10302533798448267`], {
             RGBColor[
             0.7624594799233567, 0.814358407713581, 0.976958493435964]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.10302533798448267`], {
             RGBColor[
             0.6244101927178903, 0.7059633496638299, 0.9635750041421048]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.10302533798448267`], {
             RGBColor[
             0.40128869618199126`, 0.5219978321016873, 0.9467907387684233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.10302533798448267`], {
             RGBColor[
             0.3473156643518771, 0.47524910469389925`, 0.9433516249066866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.10302533798448267`], {
             RGBColor[
             0.3778347549674962, 0.5016832070510531, 0.9452962743737416]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.10302533798448267`], {
             RGBColor[
             0.3655703898197353, 0.4910604303849782, 0.9445147998714786]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.10302533798448267`], {
             RGBColor[
             0.3473156643518771, 0.47524910469389925`, 0.9433516249066866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.10302533798448267`], {
             RGBColor[
             0.32446607901285984`, 0.45545794232679443`, 0.9418956695339794]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.10302533798448267`], {
             RGBColor[
             0.29979001716717757`, 0.43242869420059504`, 0.94038397002686]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.10302533798448267`], {
             RGBColor[
             0.3717313248407092, 0.49639672264254797`, 0.9449073692031141]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.10302533798448267`], {
             RGBColor[
             0.45076189709822184`, 0.5648490321399471, 0.9499431273833717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.10302533798448267`], {
             RGBColor[
             0.2911271640630008, 0.4233234863314949, 0.9398906333581198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.10302533798448267`], {
             RGBColor[
             0.693104025394826, 0.7601773995149154, 0.9700457898921323]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.10302533798448267`], {
             RGBColor[
             0.5654677876287122, 0.6581112498873457, 0.9589348421003406]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.10302533798448267`], {
             RGBColor[
             0.507613603037821, 0.6111426165351457, 0.9543803487624846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.10302533798448267`], {
             RGBColor[
             0.9771303994886699, 0.9824644699009597, 0.9235964477052986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.10302533798448267`], {
             RGBColor[
             0.5689684868709387, 0.6609532752368888, 0.9592104299681725]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.10302533798448267`], {
             RGBColor[
             0.2911271640630008, 0.4233234863314949, 0.9398906333581198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.10302533798448267`], {
             RGBColor[
             0.489357419635151, 0.5963214244171682, 0.9529431551304232]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.10302533798448267`], {
             RGBColor[
             0.6013701316781935, 0.6872583901688826, 0.9617612061385354]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.10302533798448267`], {
             RGBColor[
             0.31017961268336275`, 0.44308372325086026`, 0.9409853485324899]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.10302533798448267`], {
             RGBColor[
             0.33238719665615024`, 0.46231881630246374`, 0.9424003961458405]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.10302533798448267`], {
             RGBColor[
             0.5166448040600409, 0.6184745523759533, 0.9550913179893331]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.10302533798448267`], {
             RGBColor[
             0.27809316851908805`, 0.4096239306117943, 0.9391483665939625]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.10302533798448267`], {
             RGBColor[
             0.27154105088577535`, 0.4027372395509307, 0.9387752331877348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.10302533798448267`], {
             RGBColor[
             0.3409633667800214, 0.4697470638129172, 0.9429468621225241]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.10302533798448267`], {
             RGBColor[
             0.9540994713747161, 0.9652880414232566, 0.9625818015741459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.10302533798448267`], {
             RGBColor[
             0.5428978510061064, 0.6397879585730565, 0.9571580540130071]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.10302533798448267`], {
             RGBColor[
             0.39626085242693077`, 0.5176429665478287, 0.9464703690102986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.10302533798448267`], {
             RGBColor[
             0.2494863131085524, 0.3795563117959294, 0.9375192484983826]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.10302533798448267`], {
             RGBColor[
             0.7716978481948389, 0.8215754912214622, 0.9778792876478054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.10302533798448267`], {
             RGBColor[
             0.9617124021920294, 0.9709657527617788, 0.9496950954707911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.10302533798448267`], {
             RGBColor[
             0.47115060452365426`, 0.5815403117019814, 0.9515098479510848]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.10302533798448267`], {
             RGBColor[
             0.7087046638135065, 0.772364736816832, 0.9716007157334514]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.10302533798448267`], {
             RGBColor[
             0.43568297478831697`, 0.5517884275237794, 0.9489823117875521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.10302533798448267`], {
             RGBColor[
             0.8325398753039963, 0.8693087141472507, 0.9838895905952574]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.10302533798448267`], {
             RGBColor[
             0.5470840392415772, 0.6431864947682425, 0.9574876060854162]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.10302533798448267`], {
             RGBColor[
             0.27154105088577535`, 0.4027372395509307, 0.9387752331877348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.10302533798448267`], {
             RGBColor[
             0.4425236148487104, 0.5577134461235258, 0.9494181913232599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.10302533798448267`], {
             RGBColor[
             0.4170681972984467, 0.5356652428679743, 0.9477961946262989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.10302533798448267`], {
             RGBColor[
             0.8332693905629748, 0.869890409812596, 0.9839591724119047]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.10302533798448267`], {
             RGBColor[
             0.3673984885504451, 0.4926438376226053, 0.9446312847060752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.10302533798448267`], {
             RGBColor[
             0.3092535523715575, 0.44228161635391916`, 0.9409263407883047]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.10302533798448267`], {
             RGBColor[
             0.544057565770331, 0.6407294672632088, 0.957249351007422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.10302533798448267`], {
             RGBColor[
             0.3512740128151147, 0.4786776271803771, 0.9436038473705339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.10302533798448267`], {
             RGBColor[
             0.3984723439105429, 0.5195584493181398, 0.9466112832920892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.10302533798448267`], {
             RGBColor[
             0.4269770607136929, 0.5442478023243044, 0.9484275786410545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.10302533798448267`], {
             RGBColor[
             0.4634474550009288, 0.5752865478965016, 0.9509034278030895]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.10302533798448267`], {
             RGBColor[
             0.7052786750089274, 0.7696883283242155, 0.9712592451870967]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.10302533798448267`], {
             RGBColor[
             0.5388542917137672, 0.6365052149792653, 0.9568397302134684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.10302533798448267`], {
             RGBColor[
             0.5474703428084129, 0.6435001134065771, 0.957518017317274]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.10302533798448267`], {
             RGBColor[
             0.6652498612565995, 0.7384175147906447, 0.9672695471227971]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.10302533798448267`], {
             RGBColor[
             0.6360291144563782, 0.7153961137575938, 0.9644896882228713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.10302533798448267`], {
             RGBColor[
             0.8160311274253916, 0.8562089859017716, 0.9822980146034574]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.10302533798448267`], {
             RGBColor[
             0.8353359166802519, 0.8715382016441556, 0.9841562795177803]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.10302533798448267`], {
             RGBColor[
             0.6769801411994782, 0.7475812986354511, 0.9684387118018046]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.10302533798448267`], {
             RGBColor[
             0.7866429078554295, 0.8332506854149759, 0.97936887152525]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.10302533798448267`], {
             RGBColor[
             0.5402114525623832, 0.6376070192955713, 0.9569465708869155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.10302533798448267`], {
             RGBColor[
             0.6013701316781935, 0.6872583901688826, 0.9617612061385354]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.10302533798448267`], {
             RGBColor[
             0.6053149922067431, 0.6904610056599008, 0.9620717600098431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.10302533798448267`], {
             RGBColor[
             0.5936404035077445, 0.6809830486198262, 0.9611526936220304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.10302533798448267`], {
             RGBColor[
             0.3966125314314163, 0.5179475732256134, 0.9464927776854869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.10302533798448267`], {
             RGBColor[
             0.6676111121214553, 0.7402621419124413, 0.967504894541862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.10302533798448267`], {
             RGBColor[
             0.9383494303816443, 0.953541686638949, 0.9892425127068306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.10302533798448267`], {
             RGBColor[
             0.43610069461101075`, 0.552150235438988, 0.949008928525279]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.10302533798448267`], {
             RGBColor[
             0.8021621340401901, 0.8453744228609985, 0.9809156829559326]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.10302533798448267`], {
             RGBColor[
             0.25540865094355836`, 0.38578106435842713`, 0.9378565168767725]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.10302533798448267`], {
             RGBColor[
             0.36118289928036346`, 0.4872602066014608, 0.9442352328540153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.10302533798448267`], {
             RGBColor[
             0.29457385240431433`, 0.42694617431087806`, 0.9400869171602393]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.10302533798448267`], {
             RGBColor[
             0.9040030126888274, 0.9262914800827268, 0.9907058084349184]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.10302533798448267`], {
             RGBColor[
             0.40331067988057046`, 0.5237491727535408, 0.9469195777817269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.10302533798448267`], {
             RGBColor[
             0.7177605298628171, 0.7794392482016846, 0.972503319829367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.10302533798448267`], {
             RGBColor[
             0.6430425536048963, 0.7210689972713448, 0.9650561302351643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.10302533798448267`], {
             RGBColor[
             0.7249950129507179, 0.7850908813740606, 0.9732243854934807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.10302533798448267`], {
             RGBColor[
             0.6965474327457811, 0.7628674155083467, 0.9703889965564042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.10302533798448267`], {
             RGBColor[
             0.4297708583482564, 0.5466676494150113, 0.9486055969558707]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.10302533798448267`], {
             RGBColor[
             0.2989940113645204, 0.43159204163231946`, 0.9403386386739838]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.10302533798448267`], {
             RGBColor[
             0.2906316100264923, 0.42280262761918375`, 0.9398624122888473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.10302533798448267`], {
             RGBColor[
             0.5640379579709361, 0.656950449758071, 0.9588222806720419]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.10302533798448267`], {
             RGBColor[
             0.5998395470733959, 0.6860157926346572, 0.9616407129117296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.10302533798448267`], {
             RGBColor[
             0.4906610001737564, 0.5973797298240421, 0.953045777765595]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.10302533798448267`], {
             RGBColor[
             0.39863296398963455`, 0.519697570357649, 0.9466215178614982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.10302533798448267`], {
             RGBColor[
             0.3183058773831157, 0.4501222852958466, 0.9415031469333844]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.10302533798448267`], {
             RGBColor[
             0.41806719548331833`, 0.5365305248846015, 0.9478598499072596]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.10302533798448267`], {
             RGBColor[
             0.2823963610500282, 0.4141468587999772, 0.9393934270425967]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.10302533798448267`], {
             RGBColor[
             0.9395015936803714, 0.9544009681406453, 0.9872922007744009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.10302533798448267`], {
             RGBColor[
             0.33566974592466065`, 0.46516199549312404`, 0.9426095572825857]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.10302533798448267`], {
             RGBColor[
             0.6376503255649736, 0.7167122859702797, 0.9646173159000319]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.10302533798448267`], {
             RGBColor[
             0.6212473007922367, 0.7033955715119268, 0.9633260097036624]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.10302533798448267`], {
             RGBColor[
             0.487612158284224, 0.5949045426293578, 0.9528057617637752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.10302533798448267`], {
             RGBColor[
             0.5375418074267568, 0.6354396811083268, 0.9567364066426066]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.10302533798448267`], {
             RGBColor[
             0.4617165076060126, 0.5738812868230171, 0.9507671612834924]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.10302533798448267`], {
             RGBColor[
             0.4425236148487104, 0.5577134461235258, 0.9494181913232599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.10302533798448267`], {
             RGBColor[
             0.45100909919916665`, 0.5650631461750466, 0.9499588788826517]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.10302533798448267`], {
             RGBColor[
             0.6173544574594875, 0.7002351859238074, 0.9630195508165534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.10302533798448267`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.10302533798448267`], {
             RGBColor[
             0.3558040782607391, 0.48260134218166734`, 0.9438924991349495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.10302533798448267`], {
             RGBColor[
             0.307926796811888, 0.4409809655088122, 0.9408473475903395]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.10302533798448267`], {
             RGBColor[
             0.9940398037228919, 0.9896600677685748, 0.5926476011835788]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.10302533798448267`], {
             RGBColor[
             0.5138450635393406, 0.6162015968943757, 0.9548709121597562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.10302533798448267`], {
             RGBColor[
             0.5371946838117023, 0.635157870519885, 0.9567090798000738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.10302533798448267`], {
             RGBColor[
             0.89330122178771, 0.9177581625105512, 0.9896850620651684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.10302533798448267`], {
             RGBColor[
             0.5549478411592206, 0.6495706834252246, 0.9581066733784286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.10302533798448267`], {
             RGBColor[
             0.9344610263642232, 0.9505778734267308, 0.9936109209694675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.10302533798448267`], {
             RGBColor[
             0.5450150191219864, 0.6415067710268645, 0.9573247252425315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.10302533798448267`], {
             RGBColor[
             0.5998395470733959, 0.6860157926346572, 0.9616407129117296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.10302533798448267`], {
             RGBColor[
             0.6467316782223843, 0.7239509694609121, 0.965423827700206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.10302533798448267`], {
             RGBColor[
             0.29540571278806554`, 0.42782051231719526`, 0.9401342903784667]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.10302533798448267`], {
             RGBColor[
             0.6434706611065025, 0.7214034381053371, 0.9650987999900325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.10302533798448267`], {
             RGBColor[
             0.4971292616262287, 0.6026309558630168, 0.953554983001156]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.10302533798448267`], {
             RGBColor[
             0.5104479742294041, 0.6134436867554398, 0.9546034808453298]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.10302533798448267`], {
             RGBColor[
             0.6837437975450333, 0.7528651183782908, 0.9691128498563675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.10302533798448267`], {
             RGBColor[
             0.2249562965126674, 0.35377370906077266`, 0.9361223003421545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.10302533798448267`], {
             RGBColor[
             0.5688159292654061, 0.6608294221000757, 0.9591984200746281]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.10302533798448267`], {
             RGBColor[
             0.5996091198812448, 0.6858287214594422, 0.9616225728390808]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.10302533798448267`], {
             RGBColor[
             0.4218626029254364, 0.5398179160482395, 0.9481016899133243]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.10302533798448267`], {
             RGBColor[
             0.2836911947851162, 0.41550781115275526`, 0.9394671659082751]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.10302533798448267`], {
             RGBColor[
             0.5929296415976455, 0.6804060200817488, 0.9610967398408607]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.10302533798448267`], {
             RGBColor[
             0.6147890363710855, 0.6981524615133397, 0.9628175914710274]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.10302533798448267`], {
             RGBColor[
             0.4350473665845118, 0.5512378956442405, 0.9489418113948519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.10302533798448267`], {
             RGBColor[
             0.5096002682716141, 0.6127554808701877, 0.9545367463270833]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.10302533798448267`], {
             RGBColor[
             0.8461007041060643, 0.880121750935128, 0.9851830345522934]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.10302533798448267`], {
             RGBColor[
             0.6660775234921065, 0.7390640908194888, 0.9673520407594891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.10302533798448267`], {
             RGBColor[
             0.7130935594349265, 0.7757933754331275, 0.9720381598324331]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.10302533798448267`], {
             RGBColor[
             0.9430394429699048, 0.9570394903480829, 0.9813035447460949]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.10302533798448267`], {
             RGBColor[
             0.37979315413993503`, 0.503379473982215, 0.945421061837265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.10302533798448267`], {
             RGBColor[
             0.3922204970072215, 0.5141434137574445, 0.9462129211357008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.10302533798448267`], {
             RGBColor[
             0.35498063330860125`, 0.4818881155516722, 0.9438400299507431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.10302533798448267`], {
             RGBColor[
             0.6531068975085207, 0.7289313392207029, 0.9660592499788365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.10302533798448267`], {
             RGBColor[
             0.5722749921580623, 0.6636376451853415, 0.9594707301765029]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.10302533798448267`], {
             RGBColor[
             0.5852478178212757, 0.6741695694778742, 0.9604919985337372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.10302533798448267`], {
             RGBColor[
             0.8795077757098662, 0.906759643021198, 0.988369430864709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.10302533798448267`], {
             RGBColor[
             0.4170681972984467, 0.5356652428679743, 0.9477961946262989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.10302533798448267`], {
             RGBColor[
             0.5493349914201112, 0.6450139191510165, 0.9576648092864198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.10302533798448267`], {
             RGBColor[
             0.9784329619982919, 0.9834359188878854, 0.9213915491392202]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.10302533798448267`], {
             RGBColor[
             0.4011814167269004, 0.5219049120297097, 0.9467839030164085]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.10302533798448267`], {
             RGBColor[
             0.45520999761014613`, 0.5685990088934376, 0.9502549449824863]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.10302533798448267`], {
             RGBColor[
             0.809544919323063, 0.8511419108352252, 0.9816515299968783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.10302533798448267`], {
             RGBColor[
             0.50035002193887, 0.6052457141784177, 0.9538085330510009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.10302533798448267`], {
             RGBColor[
             0.34777385047176046`, 0.4756459624818382, 0.9433808201210875]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.10302533798448267`], {
             RGBColor[
             0.4566813535746214, 0.5697935219492295, 0.9503707755137643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.10302533798448267`], {
             RGBColor[
             0.8788896768758063, 0.9062667877887647, 0.988310476046133]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.10302533798448267`], {
             RGBColor[
             0.5577267282780705, 0.6518267091757451, 0.9583254375518233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.10302533798448267`], {
             RGBColor[
             0.5716503237035675, 0.6631305111929894, 0.959421553987529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.10302533798448267`], {
             RGBColor[
             0.739240536460239, 0.7962195926096872, 0.9746442461449237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.10302533798448267`], {
             RGBColor[
             0.3560240286888025, 0.4827918521874259, 0.9439065141817312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.10302533798448267`], {
             RGBColor[
             0.50035002193887, 0.6052457141784177, 0.9538085330510009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.10302533798448267`], {
             RGBColor[
             0.3952827213335425, 0.516795758557034, 0.9464080433619553]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.10302533798448267`], {
             RGBColor[
             0.7659193531770035, 0.8170612869953405, 0.9773033412675337]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.10302533798448267`], {
             RGBColor[
             0.9879671042495105, 0.9892921026229266, 0.8490797529289855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.10302533798448267`], {
             RGBColor[
             0.3761482739859309, 0.50022246198982, 0.9451888132968929]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.10302533798448267`], {
             RGBColor[
             0.3174122825033774, 0.44934829832440176`, 0.9414462078578225]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.10302533798448267`], {
             RGBColor[
             0.9879671042495105, 0.9892921026229266, 0.8490797529289855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.10302533798448267`], {
             RGBColor[
             0.37362156432702365`, 0.4980339530793946, 0.945027813591709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.10302533798448267`], {
             RGBColor[
             0.39566213260951044`, 0.5171243855345122, 0.9464322191129597]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.10302533798448267`], {
             RGBColor[
             0.3502405627692234, 0.47778250469333566`, 0.9435379968474538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.10302533798448267`], {
             RGBColor[
             0.2769673074406829, 0.4084405792346752, 0.9390842504711095]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.10302533798448267`], {
             RGBColor[
             0.43156095971944425`, 0.5482181452496232, 0.9487196606323183]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.10302533798448267`], {
             RGBColor[
             0.7900317421028037, 0.8358980684851188, 0.9797066388525716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.10302533798448267`], {
             RGBColor[
             0.5998395470733959, 0.6860157926346572, 0.9616407129117296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.10302533798448267`], {
             RGBColor[
             0.41629001154870654`, 0.5349912174843025, 0.9477466093184481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.10302533798448267`], {
             RGBColor[
             0.37100650415601666`, 0.4957689193960142, 0.9448611842700193]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.10302533798448267`], {
             RGBColor[
             0.4656244686949852, 0.5770539456866858, 0.9510748102957495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.10302533798448267`], {
             RGBColor[
             0.3091507773289067, 0.4421925977775989, 0.9409197920534674]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.10302533798448267`], {
             RGBColor[
             0.4447939207784357, 0.5596798710109598, 0.9495628532095493]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.10302533798448267`], {
             RGBColor[
             0.22445416746317717`, 0.3532459395929378, 0.9360937048356194]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.10302533798448267`], {
             RGBColor[
             0.7665021093891191, 0.8175165405773565, 0.977361424960591]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.10302533798448267`], {
             RGBColor[
             0.7802220821528562, 0.8282346875760429, 0.9787289036252451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.10302533798448267`], {
             RGBColor[
             0.350038106254015, 0.47760714703562246`, 0.94352509649733]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.10302533798448267`], {
             RGBColor[
             0.4183918297159575, 0.5368117067403225, 0.9478805353135006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.10302533798448267`], {
             RGBColor[
             0.34006536173430174`, 0.46896925697736075`, 0.9428896420350855]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.10302533798448267`], {
             RGBColor[
             0.6358084712927038, 0.7152169856974616, 0.9644723183847843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.10302533798448267`], {
             RGBColor[
             0.45631347623121943`, 0.5694948625491703, 0.9503418148617125]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.10302533798448267`], {
             RGBColor[
             0.35530855685534085`, 0.48217214644594136`, 0.94386092494917]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.10302533798448267`], {
             RGBColor[
             0.7034146898825311, 0.7682321689766631, 0.9710734605696288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.10302533798448267`], {
             RGBColor[
             0.32939249536673804`, 0.4597249565636382, 0.9422095764277896]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.10302533798448267`], {
             RGBColor[
             0.3078304112547931, 0.44087965817710817`, 0.9408418585754527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.10302533798448267`], {
             RGBColor[
             0.8397260217409336, 0.875038752253316, 0.9845750116575611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.10302533798448267`], {
             RGBColor[
             0.48973938588581156`, 0.596631521826838, 0.9529732249128636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.10302533798448267`], {
             RGBColor[
             0.5674699817839628, 0.659736721300397, 0.9590924621585208]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.10302533798448267`], {
             RGBColor[
             0.3759651634596033, 0.5000638608553176, 0.9451771456560736]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.10302533798448267`], {
             RGBColor[
             0.9503858985749569, 0.9625184649096137, 0.9688679116692323]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.10302533798448267`], {
             RGBColor[
             0.4696949714862328, 0.5803585632266816, 0.9513952551862195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.10302533798448267`], {
             RGBColor[
             0.9357923795826606, 0.9516346423398533, 0.9935709327238512]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.10302533798448267`], {
             RGBColor[
             0.3794224707315751, 0.5030584066449836, 0.9453974422182668]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1FO4EAYYBuBzsm2dTrZdW7WsZbtVy3bLtWxr2bat5WVjyzZXrfc8u3i/
//a7+f7gJu2rtAsMCAjIJEJuKEIThrCEIzwRiEgkIhOFqEQjOjGISSxiE4e4
xCM+CUhIIhKThKQkI4jkBJOClKQiNWlISzrSk4GMIX3JTBayko3s5CAnuchN
HvKSj/wUoCCF+IEfKUwRivITxShOCUpSitKUoSzlKE8FfqYilahMFapSjerU
oCa1qE0d6lKP+jSgIY1oTBN+oSnNaM6vtKAlrWhNG9rSjvZ0oCOd6EwXutKN
7vSgJ73ozW/0oS/96M8ABjKIwQzhd4YyjOGMYCSjGM0YxjKO8UxgIpOYzBSm
Mo3pzGAms5jNH8xhLvOYzwIWsojFLGEpy1jOClayitWsYS3rWM8GNrKJzWxh
K9vYzg52sovd7GEv+9jPAQ5yiMMc4U+OcozjnOAkpzjNX5zhLOc4zwUuconL
XOEq17jODW5yi9v8zT/c4S73uM8DHvKIxzzhKc94zgte8orXvOEt73jPBz7y
ic/8yxe+8o3/CBl/IKEITRjCEo7wRCAikYhMFKISjejEICaxiE0c4hKP+CQg
IYlITBKSkowgkhNMClKSitSkIS3pSE8GMgb+/6++Az6VhWw=
          "], {Null, CompressedData["
1:eJxN2nu4llWZB+C1RcxDZpqQRxAUUVHStBgOUSMyo5BNY0aKowyCpqCIyVg4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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[57, 280] -> 
             RGBColor[
              0.2575556675749038, 0.38803771496668804`, 0.9379787862977012], 
             UndirectedEdge[46, 187] -> 
             RGBColor[
              0.32803381097302087`, 0.4570126210374179, 0.9421792248536764], 
             UndirectedEdge[96, 298] -> 
             RGBColor[
              0.3453589956577786, 0.4713821632368721, 0.9433064816157806], 
             UndirectedEdge[165, 207] -> 
             RGBColor[
              0.8629243195572578, 0.8731271056740303, 0.676546302374514], 
             UndirectedEdge[69, 224] -> 
             RGBColor[
              0.9812813612748328, 0.9481895871324358, 0.4098590677551779], 
             UndirectedEdge[51, 110] -> 
             RGBColor[
              0.9932540497607107, 0.99147839046011, 0.7614613836320072], 
             UndirectedEdge[122, 231] -> 
             RGBColor[
              0.5346560481729267, 0.6328742791629598, 0.9565707376227028], 
             UndirectedEdge[71, 246] -> 
             RGBColor[
              0.6142322345348998, 0.6977004246990872, 0.9627737579908505], 
             UndirectedEdge[9, 239] -> 
             RGBColor[
              0.4639819639121217, 0.5745750992225973, 0.9512619801674704], 
             UndirectedEdge[99, 229] -> 
             RGBColor[
              0.3569385719957474, 0.4835839836336185, 0.9439647880725508], 
             UndirectedEdge[49, 112] -> 
             RGBColor[
              0.24438397329964223`, 0.374193429149736, 0.9372286777945005], 
             UndirectedEdge[115, 243] -> 
             RGBColor[
              0.21987898042507611`, 0.348437127932281, 0.9358331547021821], 
             UndirectedEdge[58, 95] -> 
             RGBColor[
              0.5187848450827122, 0.6202119340859072, 0.9552597898578664], 
             UndirectedEdge[210, 239] -> 
             RGBColor[
              0.39484568065555037`, 0.5164172158880604, 0.9463801955164135], 
             UndirectedEdge[94, 150] -> 
             RGBColor[
              0.9119777121048072, 0.931971896043791, 0.9679461351700305], 
             UndirectedEdge[21, 108] -> 
             RGBColor[
              0.3636875531699619, 0.4894296119130661, 0.9443948271850822], 
             UndirectedEdge[83, 202] -> 
             RGBColor[
              0.22220476853383342`, 0.3508816786980681, 0.9359656048942807], 
             UndirectedEdge[172, 174] -> 
             RGBColor[
              0.33090944455997406`, 0.4574098756542951, 0.9424391100455509], 
             UndirectedEdge[3, 157] -> 
             RGBColor[
              0.36165267017657554`, 0.4876670985403879, 0.9442651662401199], 
             UndirectedEdge[181, 246] -> 
             RGBColor[
              0.656342497401248, 0.7307927865257904, 0.9668372480070162], 
             UndirectedEdge[159, 253] -> 
             RGBColor[
              0.27205955347524674`, 0.4032822186474281, 0.9388047611431494], 
             UndirectedEdge[170, 228] -> 
             RGBColor[
              0.8191183413836293, 0.5128704810525186, 0.5754638060619697], 
             UndirectedEdge[151, 194] -> 
             RGBColor[
              0.4795533660103779, 0.5880893214551517, 0.9522467003824877], 
             UndirectedEdge[62, 100] -> 
             RGBColor[
              0.9225145323393552, 0.6890519389234857, 0.4381903343500609], 
             UndirectedEdge[76, 99] -> 
             RGBColor[
              0.3308920068686242, 0.45968772172522177`, 0.9423540428096366], 
             UndirectedEdge[131, 283] -> 
             RGBColor[
              0.47177717102653804`, 0.5785602690993044, 0.9525231166057517], 
             UndirectedEdge[173, 263] -> 
             RGBColor[
              0.25907859446240145`, 0.3896384076845897, 0.9380655147309758], 
             UndirectedEdge[20, 75] -> 
             RGBColor[
              0.7982091276425176, 0.8426574734850338, 0.980423187310408], 
             UndirectedEdge[175, 253] -> 
             RGBColor[
              0.29561827694261666`, 0.42804393072097424`, 0.9401463955926079],
              UndirectedEdge[52, 193] -> 
             RGBColor[
              0.6086028861336337, 0.3287818878860621, 0.5556335731143328], 
             UndirectedEdge[282, 283] -> 
             RGBColor[
              0.7911900845661439, 0.8368811978581185, 0.9547653144934332], 
             UndirectedEdge[173, 279] -> 
             RGBColor[
              0.2579831193391787, 0.3884869938729482, 0.9380031290433184], 
             UndirectedEdge[95, 198] -> 
             RGBColor[
              0.4764509321887418, 0.5858433564775396, 0.9519271091606205], 
             UndirectedEdge[18, 288] -> 
             RGBColor[
              0.9041509173263116, 0.7126766818632384, 0.5910465110881808], 
             UndirectedEdge[29, 91] -> 
             RGBColor[
              0.25771769921639187`, 0.38820802049529146`, 0.9379880137599795],
              UndirectedEdge[46, 169] -> 
             RGBColor[
              0.2925815910536258, 0.4248521813146391, 0.9399734608236041], 
             UndirectedEdge[34, 264] -> 
             RGBColor[
              0.31108024849077764`, 0.44256158228500475`, 0.9410904171386354],
              UndirectedEdge[116, 277] -> 
             RGBColor[
              0.33575144742336294`, 0.46523276122486323`, 0.9426147632298372],
              UndirectedEdge[60, 299] -> 
             RGBColor[
              0.9602834986478392, 0.8683179033755875, 0.5002256256588694], 
             UndirectedEdge[205, 213] -> 
             RGBColor[
              0.4786627684820106, 0.5869482888311869, 0.9522920854283001], 
             UndirectedEdge[240, 299] -> 
             RGBColor[
              0.9947090533611671, 0.9917794762430787, 0.7154980818389891], 
             UndirectedEdge[184, 214] -> 
             RGBColor[
              0.22515962250579277`, 0.3539874175711599, 0.9361338794566691], 
             UndirectedEdge[39, 59] -> 
             RGBColor[
              0.8501714335969901, 0.3722888082384709, 0.1951153671911272], 
             UndirectedEdge[246, 299] -> 
             RGBColor[
              0.7966762325062557, 0.8386071063469377, 0.851316533208819], 
             UndirectedEdge[21, 114] -> 
             RGBColor[
              0.3439329379247541, 0.47191837420693394`, 0.9431507551943723], 
             UndirectedEdge[204, 253] -> 
             RGBColor[
              0.26380404156370607`, 0.39460515219871184`, 0.9383346219527224],
              UndirectedEdge[202, 214] -> 
             RGBColor[
              0.22050159369132202`, 0.3490915339510665, 0.935868611606621], 
             UndirectedEdge[26, 39] -> 
             RGBColor[
              0.9266838506619479, 0.7398946126602461, 0.547796397964442], 
             UndirectedEdge[118, 220] -> 
             RGBColor[
              0.21806065403360642`, 0.34652595160629435`, 0.9357296037041608],
              UndirectedEdge[28, 126] -> 
             RGBColor[
              0.22467560955270433`, 0.3534786892692703, 0.9361063156350238], 
             UndirectedEdge[9, 237] -> 
             RGBColor[
              0.5778044829283981, 0.6681267348934206, 0.9599060319451358], 
             UndirectedEdge[174, 297] -> 
             RGBColor[
              0.5763612583921884, 0.663490693504958, 0.9614863052750408], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.35208222651696447`, 0.4786261706514128, 0.9436828617856419], 
             UndirectedEdge[63, 139] -> 
             RGBColor[
              0.28999599813964694`, 0.42067676560446166`, 0.9398795920978575],
              UndirectedEdge[124, 150] -> 
             RGBColor[
              0.9548500534233739, 0.9658478242861803, 0.9613112619489188], 
             UndirectedEdge[127, 165] -> 
             RGBColor[
              0.9065162299369915, 0.5989909877808421, 0.27841578820409746`], 
             UndirectedEdge[8, 22] -> 
             RGBColor[
              0.7346141321851996, 0.7926054104280515, 0.9741831294029938], 
             UndirectedEdge[127, 137] -> 
             RGBColor[
              0.8391691506119379, 0.30207683240040506`, 0.18514172890220718`],
              UndirectedEdge[21, 213] -> 
             RGBColor[
              0.40566670523630644`, 0.5257898434994019, 0.9470697016340429], 
             UndirectedEdge[41, 278] -> 
             RGBColor[
              0.4799611412114356, 0.5860775921964064, 0.9529261189064413], 
             UndirectedEdge[69, 249] -> 
             RGBColor[
              0.9058089885195326, 0.5656683412312807, 0.3245169720093974], 
             UndirectedEdge[100, 136] -> 
             RGBColor[
              0.9215440004534805, 0.6869760693554257, 0.33255392800111494`], 
             UndirectedEdge[88, 222] -> 
             RGBColor[
              0.47017691950032614`, 0.5802832085890723, 0.9515621248783083], 
             UndirectedEdge[153, 216] -> 
             RGBColor[
              0.2661597993989548, 0.3970812030472318, 0.9384687788764086], 
             UndirectedEdge[60, 121] -> 
             RGBColor[
              0.9603462863275016, 0.8677642487038257, 0.4570528894502983], 
             UndirectedEdge[203, 206] -> 
             RGBColor[
              0.24813385698154097`, 0.37813479465576916`, 0.9374422281227288],
              UndirectedEdge[50, 108] -> 
             RGBColor[
              0.3481847341285709, 0.4760018492537544, 0.9434070012643693], 
             UndirectedEdge[98, 181] -> 
             RGBColor[
              0.5683121366528735, 0.6584973340732392, 0.9601360759487196], 
             UndirectedEdge[267, 285] -> 
             RGBColor[
              0.42530929649653304`, 0.542408765687049, 0.9484303125609015], 
             UndirectedEdge[156, 178] -> 
             RGBColor[
              0.25237767810444756`, 0.38259531972974414`, 0.9376839074575076],
              UndirectedEdge[185, 295] -> 
             RGBColor[
              0.7026775395247731, 0.7666581291332051, 0.9717409425805205], 
             UndirectedEdge[83, 156] -> 
             RGBColor[
              0.221993745626472, 0.35065988024280614`, 0.935953587451887], 
             UndirectedEdge[44, 150] -> 
             RGBColor[
              0.9635307831976114, 0.9324851425902525, 0.6339721646328667], 
             UndirectedEdge[223, 274] -> 
             RGBColor[
              0.9259651133080155, 0.7367764933200369, 0.2723005774523107], 
             UndirectedEdge[20, 142] -> 
             RGBColor[
              0.7624648027643098, 0.8147337352232472, 0.9768605270562558], 
             UndirectedEdge[87, 264] -> 
             RGBColor[
              0.2853843000396664, 0.4172873721243609, 0.939563585747797], 
             UndirectedEdge[16, 192] -> 
             RGBColor[
              0.9292282498402631, 0.7341287491873884, 0.36986042931949054`], 
             UndirectedEdge[75, 143] -> 
             RGBColor[
              0.5636312232942053, 0.6537338940348352, 0.9601379235387875], 
             UndirectedEdge[230, 263] -> 
             RGBColor[
              0.2551678747286398, 0.38552799329045395`, 0.9378428050275294], 
             UndirectedEdge[52, 82] -> 
             RGBColor[
              0.90639234718301, 0.5644975000841104, 0.4350476194442515], 
             UndirectedEdge[34, 213] -> 
             RGBColor[
              0.37768895869959807`, 0.5015569256517332, 0.9452869843644738], 
             UndirectedEdge[145, 219] -> 
             RGBColor[
              0.27171942382339986`, 0.4029247208178715, 0.9387853912626534], 
             UndirectedEdge[237, 295] -> 
             RGBColor[
              0.738032045164762, 0.7953605095140767, 0.9745241787723218], 
             UndirectedEdge[257, 259] -> 
             RGBColor[
              0.4277830853443319, 0.544648816326516, 0.9485610340700278], 
             UndirectedEdge[116, 241] -> 
             RGBColor[
              0.30074162674959204`, 0.4321657656332045, 0.9404844121827121], 
             UndirectedEdge[95, 105] -> 
             RGBColor[
              0.3889084199719124, 0.5085055030468593, 0.9463331921101534], 
             UndirectedEdge[115, 146] -> 
             RGBColor[
              0.22602095903949393`, 0.35489273687997036`, 0.9361829312980301],
              UndirectedEdge[16, 170] -> 
             RGBColor[
              0.9076819009807398, 0.5788651194760369, 0.34963294244959353`], 
             UndirectedEdge[199, 226] -> 
             RGBColor[
              0.178927005110741, 0.3053940053717128, 0.9335010002910491], 
             UndirectedEdge[78, 130] -> 
             RGBColor[
              0.17948366008578914`, 0.30597908504445237`, 0.9335327009683809],
              UndirectedEdge[155, 214] -> 
             RGBColor[
              0.21259246077095287`, 0.340778533783768, 0.9354181981873197], 
             UndirectedEdge[185, 297] -> 
             RGBColor[
              0.6642346642542716, 0.7364864270373344, 0.9679464241532377], 
             UndirectedEdge[45, 53] -> 
             RGBColor[
              0.8447764554590436, 0.34517703459191124`, 0.19051129035634062`],
              UndirectedEdge[49, 204] -> 
             RGBColor[
              0.23371861491604712`, 0.3629834612657993, 0.9366213014125385], 
             UndirectedEdge[69, 254] -> 
             RGBColor[
              0.9421799602264942, 0.7934586684310521, 0.3573185586987633], 
             UndirectedEdge[102, 295] -> 
             RGBColor[
              0.6113037860265932, 0.6906305704110295, 0.9650577846461873], 
             UndirectedEdge[14, 254] -> 
             RGBColor[
              0.8570098056114457, 0.3874350253501294, 0.200198663385516], 
             UndirectedEdge[125, 299] -> 
             RGBColor[
              0.9935548569863483, 0.9893107669044954, 0.5898709293143154], 
             UndirectedEdge[16, 44] -> 
             RGBColor[
              0.9792628131880576, 0.9411137160345208, 0.4247070629331663], 
             UndirectedEdge[49, 84] -> 
             RGBColor[
              0.2685862507813846, 0.39963155729606886`, 0.9386069616930247], 
             UndirectedEdge[186, 230] -> 
             RGBColor[
              0.23966064866834333`, 0.3692289154861624, 0.9369596914442806], 
             UndirectedEdge[215, 282] -> 
             RGBColor[
              0.97938013431987, 0.9823295669124169, 0.8386095157394571], 
             UndirectedEdge[134, 159] -> 
             RGBColor[
              0.26069725479200045`, 0.3913397223199907, 0.9381576950421531], 
             UndirectedEdge[26, 266] -> 
             RGBColor[
              0.6167344718352826, 0.6830098916954412, 0.9109140844783175], 
             UndirectedEdge[142, 150] -> 
             RGBColor[
              0.810515025857468, 0.8523692859433827, 0.9579232930155395], 
             UndirectedEdge[114, 221] -> 
             RGBColor[
              0.29951227485023835`, 0.4321367694156119, 0.9403681530127932], 
             UndirectedEdge[147, 172] -> 
             RGBColor[
              0.2478440102281372, 0.3778301473405962, 0.9374257217789124], 
             UndirectedEdge[35, 211] -> 
             RGBColor[
              0.2342952250609407, 0.36358951508727716`, 0.936654138507272], 
             UndirectedEdge[124, 295] -> 
             RGBColor[
              0.8924892919776035, 0.9168014387328876, 0.9788835440663946], 
             UndirectedEdge[166, 233] -> 
             RGBColor[
              0.9934058766223102, 0.9883041618002921, 0.5236485484298345], 
             UndirectedEdge[88, 290] -> 
             RGBColor[
              0.558574938782711, 0.6525153246748602, 0.9583922117898461], 
             UndirectedEdge[134, 235] -> 
             RGBColor[
              0.2580199713754525, 0.388525727699626, 0.9380052277122666], 
             UndirectedEdge[185, 239] -> 
             RGBColor[
              0.4896022864326819, 0.5953748312271646, 0.9532789058066227], 
             UndirectedEdge[260, 278] -> 
             RGBColor[
              0.7260426453881705, 0.7855410894217181, 0.9736791816363508], 
             UndirectedEdge[15, 242] -> 
             RGBColor[
              0.23967759230185604`, 0.3692467243192726, 0.9369606563591433], 
             UndirectedEdge[4, 266] -> 
             RGBColor[
              0.3936273469724733, 0.5073684085563466, 0.9471569136064277], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.2455681044594148, 0.3754380260769088, 0.9372961123122845], 
             UndirectedEdge[3, 123] -> 
             RGBColor[
              0.40677277394875433`, 0.5267478646254944, 0.9471401793543419], 
             UndirectedEdge[28, 184] -> 
             RGBColor[
              0.23042487690337662`, 0.35952153377943086`, 0.9364337279053656],
              UndirectedEdge[116, 210] -> 
             RGBColor[
              0.35048246477995726`, 0.4779920280566848, 0.9435534106296721], 
             UndirectedEdge[118, 120] -> 
             RGBColor[
              0.1844220718220619, 0.3111696688926636, 0.9338139362110361], 
             UndirectedEdge[15, 89] -> 
             RGBColor[
              0.2585276184343561, 0.3890592969452162, 0.9380341374612745], 
             UndirectedEdge[11, 283] -> 
             RGBColor[
              0.4811144650373824, 0.586647763865455, 0.9531180807234778], 
             UndirectedEdge[157, 201] -> 
             RGBColor[
              0.3335467378743898, 0.46332315262546664`, 0.9424742810869247], 
             UndirectedEdge[196, 279] -> 
             RGBColor[
              0.2698625176179148, 0.40097299466125325`, 0.9386796432012976], 
             UndirectedEdge[7, 11] -> 
             RGBColor[
              0.36912627592496833`, 0.4941403602052988, 0.9447413777897574], 
             UndirectedEdge[76, 284] -> 
             RGBColor[
              0.2749699198453155, 0.406341198230256, 0.9389705022024235], 
             UndirectedEdge[34, 108] -> 
             RGBColor[
              0.3357098066332535, 0.46519669406539743`, 0.9426121099155129], 
             UndirectedEdge[46, 213] -> 
             RGBColor[
              0.3600084250820952, 0.48470742468786476`, 0.9442166189906656], 
             UndirectedEdge[261, 278] -> 
             RGBColor[
              0.5017864477209948, 0.6049815757231856, 0.9543168081378697], 
             UndirectedEdge[58, 66] -> 
             RGBColor[
              0.747689528345485, 0.802133526636196, 0.966576403949817], 
             UndirectedEdge[194, 297] -> 
             RGBColor[
              0.6381161089486057, 0.715282207212687, 0.9658902758041552], 
             UndirectedEdge[283, 297] -> 
             RGBColor[
              0.6895610790338994, 0.7570475514974199, 0.9699402122984042], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.23660390230659725`, 0.366016081251054, 0.9367856142610302], 
             UndirectedEdge[6, 169] -> 
             RGBColor[
              0.299349056442051, 0.4319652165199622, 0.940358857965907], 
             UndirectedEdge[11, 172] -> 
             RGBColor[
              0.3065006008708423, 0.43626816207492447`, 0.9408838001095725], 
             UndirectedEdge[4, 82] -> 
             RGBColor[
              0.7673487077991381, 0.8145026420959148, 0.8312023909866153], 
             UndirectedEdge[140, 230] -> 
             RGBColor[
              0.2887130988150164, 0.4189991437957653, 0.9398185869899978], 
             UndirectedEdge[207, 232] -> 
             RGBColor[
              0.8698424070552139, 0.8954799573196557, 0.7870499702431855], 
             UndirectedEdge[147, 244] -> 
             RGBColor[
              0.23435191313774276`, 0.3636490978502278, 0.9366573668093834], 
             UndirectedEdge[56, 296] -> 
             RGBColor[
              0.6219639893106997, 0.70315209105388, 0.9639467061714042], 
             UndirectedEdge[243, 294] -> 
             RGBColor[
              0.21403208469402601`, 0.34229166980434655`, 0.935500182640006], 
             UndirectedEdge[211, 216] -> 
             RGBColor[
              0.2505986099544608, 0.38072540630467244`, 0.9375825921582613], 
             UndirectedEdge[107, 141] -> 
             RGBColor[
              0.8665747340462209, 0.44887503543921714`, 0.2088850184887606], 
             UndirectedEdge[19, 175] -> 
             RGBColor[
              0.2928891684678705, 0.42517546467854467`, 0.9399909769023254], 
             UndirectedEdge[17, 158] -> 
             RGBColor[
              0.34992722478314753`, 0.47635321406760484`, 0.9435604273632674],
              UndirectedEdge[115, 242] -> 
             RGBColor[
              0.23101187459031025`, 0.36013850556620103`, 0.9364671565552513],
              UndirectedEdge[159, 292] -> 
             RGBColor[
              0.24522762221879252`, 0.3750801576541939, 0.9372767223523794], 
             UndirectedEdge[34, 205] -> 
             RGBColor[
              0.4284730033611293, 0.5434764368944227, 0.9490940379758643], 
             UndirectedEdge[23, 180] -> 
             RGBColor[
              0.26520012614906696`, 0.3960725256148013, 0.9384141269045367], 
             UndirectedEdge[47, 158] -> 
             RGBColor[
              0.5238459246822951, 0.6229456026619612, 0.9560487873803941], 
             UndirectedEdge[130, 199] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[112, 204] -> 
             RGBColor[
              0.24154807064065673`, 0.37121271564852854`, 0.9370671773334133],
              UndirectedEdge[217, 247] -> 
             RGBColor[
              0.6930619732704799, 0.7591753208357144, 0.9707042644868367], 
             UndirectedEdge[102, 185] -> 
             RGBColor[
              0.4766965463107896, 0.5841965277949407, 0.9524565634581535], 
             UndirectedEdge[136, 137] -> 
             RGBColor[
              0.9192369381421535, 0.6692429774694144, 0.3303446825263339], 
             UndirectedEdge[138, 258] -> 
             RGBColor[
              0.8342254690641332, 0.8708963005189276, 0.9605009609416519], 
             UndirectedEdge[79, 277] -> 
             RGBColor[
              0.3720129129755694, 0.49664062013193266`, 0.9449253117500688], 
             UndirectedEdge[41, 259] -> 
             RGBColor[
              0.41062581045850305`, 0.5297880471701207, 0.9474677876858852], 
             UndirectedEdge[225, 287] -> 
             RGBColor[
              0.950968932525843, 0.8418366498372989, 0.2871069008798047], 
             UndirectedEdge[167, 194] -> 
             RGBColor[
              0.6348798248522232, 0.7127539974799229, 0.9655677132502221], 
             UndirectedEdge[64, 219] -> 
             RGBColor[
              0.2539451972290641, 0.384242881716169, 0.9377731753527179], 
             UndirectedEdge[83, 293] -> 
             RGBColor[
              0.21277489873276917`, 0.34097028764887183`, 0.9354285877593523],
              UndirectedEdge[31, 95] -> 
             RGBColor[
              0.5537416162054588, 0.648591415667946, 0.9580117149315208], 
             UndirectedEdge[256, 299] -> 
             RGBColor[
              0.994866261560722, 0.9921157286857396, 0.7326092241840025], 
             UndirectedEdge[129, 269] -> 
             RGBColor[
              0.23146736458154496`, 0.36061725442672216`, 0.9364930960364151],
              UndirectedEdge[83, 126] -> 
             RGBColor[
              0.22111352999763184`, 0.3497347178080009, 0.9359034604739869], 
             UndirectedEdge[23, 81] -> 
             RGBColor[
              0.29610769611833376`, 0.428558341305621, 0.9401742672906341], 
             UndirectedEdge[235, 252] -> 
             RGBColor[
              0.2712852344852127, 0.40246836029424277`, 0.9387606648221691], 
             UndirectedEdge[6, 264] -> 
             RGBColor[
              0.3001671802617, 0.4328251165264595, 0.9404054489071303], 
             UndirectedEdge[167, 215] -> 
             RGBColor[
              0.874514844691243, 0.8999677108189541, 0.8534618509904951], 
             UndirectedEdge[273, 285] -> 
             RGBColor[
              0.5003032179944051, 0.6032922095966846, 0.9543341087730001], 
             UndirectedEdge[267, 273] -> 
             RGBColor[
              0.5428411676276441, 0.6397419404528637, 0.9571535916898165], 
             UndirectedEdge[66, 109] -> 
             RGBColor[
              0.9338122663322416, 0.9497831796189251, 0.9839317503863134], 
             UndirectedEdge[104, 173] -> 
             RGBColor[
              0.2711227338075005, 0.40229756177882925`, 0.9387514106489717], 
             UndirectedEdge[9, 185] -> 
             RGBColor[
              0.5424499772884093, 0.6394243545125489, 0.9571227957533345], 
             UndirectedEdge[233, 288] -> 
             RGBColor[
              0.9279948066453856, 0.7277856301692169, 0.40221351612468526`], 
             UndirectedEdge[139, 147] -> 
             RGBColor[
              0.2408356632285271, 0.3704639302891415, 0.9370266067852049], 
             UndirectedEdge[65, 103] -> 
             RGBColor[
              0.2833667383517215, 0.41516678686953135`, 0.9394486885943836], 
             UndirectedEdge[33, 124] -> 
             RGBColor[
              0.931178231225007, 0.9476509487054876, 0.9825737296298357], 
             UndirectedEdge[82, 226] -> 
             RGBColor[
              0.5870018429473699, 0.648635921384999, 0.8195028573655392], 
             UndirectedEdge[6, 221] -> 
             RGBColor[
              0.3001432088118318, 0.4327999210127703, 0.9404040837685228], 
             UndirectedEdge[125, 136] -> 
             RGBColor[
              0.9927664178883965, 0.9869364242276462, 0.4540474115251879], 
             UndirectedEdge[112, 292] -> 
             RGBColor[
              0.24763746869084696`, 0.3776130590894144, 0.9374139595439145], 
             UndirectedEdge[58, 67] -> 
             RGBColor[
              0.7306207568349073, 0.7888007417215468, 0.9745656605578148], 
             UndirectedEdge[73, 105] -> 
             RGBColor[
              0.30909022810020703`, 0.4403302488400713, 0.9409822033703782], 
             UndirectedEdge[263, 298] -> 
             RGBColor[
              0.27311782288011394`, 0.40439452689009914`, 0.9388650280201871],
              UndirectedEdge[60, 170] -> 
             RGBColor[
              0.8739879445842015, 0.4569683614322223, 0.21399044815056695`], 
             UndirectedEdge[10, 129] -> 
             RGBColor[
              0.22367111540675327`, 0.3524229022332684, 0.9360491111794278], 
             UndirectedEdge[53, 234] -> 
             RGBColor[
              0.8245240597604586, 0.18950824659620397`, 0.17111757336356628`],
              UndirectedEdge[51, 154] -> 
             RGBColor[
              0.867381103025232, 0.8946780960164662, 0.8655976857489563], 
             UndirectedEdge[17, 84] -> 
             RGBColor[
              0.2984201886260963, 0.4309889175517728, 0.9403059603179251], 
             UndirectedEdge[98, 160] -> 
             RGBColor[
              0.5065135948101279, 0.6094211404266363, 0.9545226524909898], 
             UndirectedEdge[25, 147] -> 
             RGBColor[
              0.2390014851721345, 0.36853609285826733`, 0.9369221530583165], 
             UndirectedEdge[159, 204] -> 
             RGBColor[
              0.23913822416860225`, 0.3686798142133081, 0.9369299401418781], 
             UndirectedEdge[37, 94] -> 
             RGBColor[
              0.771325946499076, 0.8216241472491855, 0.9777522097744586], 
             UndirectedEdge[37, 283] -> 
             RGBColor[
              0.6497129501444403, 0.725917890351978, 0.9659685232126394], 
             UndirectedEdge[9, 142] -> 
             RGBColor[
              0.5879267021753338, 0.6760891257694337, 0.9608774283058292], 
             UndirectedEdge[51, 109] -> 
             RGBColor[
              0.9573653906056103, 0.9657923433051386, 0.8743494495449171], 
             UndirectedEdge[123, 257] -> 
             RGBColor[
              0.41376298296839165`, 0.5328024323401832, 0.9475855892918741], 
             UndirectedEdge[212, 294] -> 
             RGBColor[
              0.2108091766010912, 0.3389041890544966, 0.9353166427919786], 
             UndirectedEdge[237, 297] -> 
             RGBColor[
              0.6995891698942603, 0.7651888074182058, 0.970729660345039], 
             UndirectedEdge[163, 197] -> 
             RGBColor[
              0.22592979758927967`, 0.35479692041582533`, 0.9361777397883018],
              UndirectedEdge[76, 229] -> 
             RGBColor[
              0.32034218545595194`, 0.4505499966670069, 0.9416818175180619], 
             UndirectedEdge[18, 24] -> 
             RGBColor[
              0.9510187529148094, 0.9629904466400717, 0.9677966543467089], 
             UndirectedEdge[44, 124] -> 
             RGBColor[
              0.9563745344888678, 0.9271480240205534, 0.6460858270481826], 
             UndirectedEdge[26, 82] -> 
             RGBColor[
              0.9904558326619474, 0.9901441252350094, 0.7949595618585049], 
             UndirectedEdge[7, 106] -> 
             RGBColor[
              0.5257077598802015, 0.6240227140594248, 0.9563940779093657], 
             UndirectedEdge[53, 255] -> 
             RGBColor[
              0.8953417281167521, 0.5590474871616122, 0.23653146249449708`], 
             UndirectedEdge[89, 242] -> 
             RGBColor[
              0.2592824308416344, 0.3898526526431364, 0.9380771229112241], 
             UndirectedEdge[121, 181] -> 
             RGBColor[
              0.8542136005503994, 0.8836192586014792, 0.8134168223712162], 
             UndirectedEdge[217, 273] -> 
             RGBColor[
              0.7124353943152881, 0.7749035368025619, 0.9722294111586636], 
             UndirectedEdge[141, 240] -> 
             RGBColor[
              0.9469680026152082, 0.812923621050152, 0.46368241218848416`], 
             UndirectedEdge[42, 159] -> 
             RGBColor[
              0.2509157891435835, 0.3810587817427625, 0.9376006550438574], 
             UndirectedEdge[51, 52] -> 
             RGBColor[
              0.9056350707482277, 0.5643614773610739, 0.4604731703909181], 
             UndirectedEdge[170, 225] -> 
             RGBColor[
              0.8914281470596066, 0.5246344158422436, 0.23572348923178596`], 
             UndirectedEdge[51, 179] -> 
             RGBColor[
              0.993604348606093, 0.9916232480349453, 0.7556560252196713], 
             UndirectedEdge[36, 198] -> 
             RGBColor[
              0.6119133130274254, 0.6940222772779814, 0.9638188261918845], 
             UndirectedEdge[150, 295] -> 
             RGBColor[
              0.8996455406863472, 0.9221385573025866, 0.9667698816510785], 
             UndirectedEdge[140, 196] -> 
             RGBColor[
              0.304503216827514, 0.4355955589782061, 0.9407178108514234], 
             UndirectedEdge[31, 73] -> 
             RGBColor[
              0.47392342433375345`, 0.580416161461158, 0.9526607261917457], 
             UndirectedEdge[188, 212] -> 
             RGBColor[
              0.20871789165381538`, 0.33670611597978567`, 0.9351975472080101],
              UndirectedEdge[172, 244] -> 
             RGBColor[
              0.2560033039447505, 0.38640608236585794`, 0.9378903814854801], 
             UndirectedEdge[7, 63] -> 
             RGBColor[
              0.3596300201933831, 0.4859151807862907, 0.94413628477175], 
             UndirectedEdge[128, 218] -> 
             RGBColor[
              0.24765166805898178`, 0.377627983525616, 0.9374147681769237], 
             UndirectedEdge[138, 154] -> 
             RGBColor[
              0.7239419932746806, 0.7842682543998942, 0.9731194303332016], 
             UndirectedEdge[1, 297] -> 
             RGBColor[
              0.5894608456272148, 0.6748368975635395, 0.9623209993901465], 
             UndirectedEdge[90, 123] -> 
             RGBColor[
              0.4198835569183708, 0.5381037658666636, 0.9479755868517558], 
             UndirectedEdge[8, 61] -> 
             RGBColor[
              0.6093443388632377, 0.6935868317074125, 0.9624883614152353], 
             UndirectedEdge[201, 209] -> 
             RGBColor[
              0.29313467956513195`, 0.424290095199951, 0.9400468245012701], 
             UndirectedEdge[44, 94] -> 
             RGBColor[
              0.9135021931703009, 0.8932720957781641, 0.6527207002692943], 
             UndirectedEdge[114, 213] -> 
             RGBColor[
              0.366144956508927, 0.49115730829602955`, 0.944566085377239], 
             UndirectedEdge[82, 107] -> 
             RGBColor[
              0.9146118486409361, 0.6276761900982359, 0.44291862332296067`], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.27309540824899353`, 0.40437096769162195`, 0.9388637515401044],
              UndirectedEdge[182, 268] -> 
             RGBColor[
              0.28484973208731645`, 0.4167255073128753, 0.939533142893733], 
             UndirectedEdge[157, 229] -> 
             RGBColor[
              0.34618459391463335`, 0.47426942833041186`, 0.9432795540985917],
              UndirectedEdge[99, 157] -> 
             RGBColor[
              0.35673441532730565`, 0.48340715338862666`, 0.9439517793901664],
              UndirectedEdge[249, 288] -> 
             RGBColor[
              0.8402405410776118, 0.30481319511588134`, 0.18595237386054825`],
              UndirectedEdge[66, 138] -> 
             RGBColor[
              0.8265698887797728, 0.8651867812777139, 0.9734598614679548], 
             UndirectedEdge[215, 286] -> 
             RGBColor[
              0.7770695489362254, 0.8225663010665949, 0.8446220990398039], 
             UndirectedEdge[83, 275] -> 
             RGBColor[
              0.214533530595458, 0.34281872124025803`, 0.9355287392422698], 
             UndirectedEdge[95, 289] -> 
             RGBColor[
              0.38981488785686436`, 0.5094582582673273, 0.9463848141152024], 
             UndirectedEdge[37, 75] -> 
             RGBColor[
              0.7056075851299448, 0.7699452754105638, 0.9712920278741198], 
             UndirectedEdge[88, 260] -> 
             RGBColor[
              0.6766874696871867, 0.7454723343623321, 0.9697937614112038], 
             UndirectedEdge[60, 82] -> 
             RGBColor[
              0.9605795624965958, 0.8682632028416796, 0.48244356084256446`], 
             UndirectedEdge[50, 227] -> 
             RGBColor[
              0.30610711869793783`, 0.43502772299278125`, 0.9408916674370189],
              UndirectedEdge[12, 248] -> 
             RGBColor[
              0.20494626266410096`, 0.3327418947765061, 0.9349827585166709], 
             UndirectedEdge[103, 164] -> 
             RGBColor[
              0.33137057382359575`, 0.4586711168930102, 0.9424369368208644], 
             UndirectedEdge[127, 228] -> 
             RGBColor[
              0.8245576688190998, 0.5546795352500253, 0.5806725121570179], 
             UndirectedEdge[163, 184] -> 
             RGBColor[
              0.23939823162616325`, 0.3689530985366296, 0.9369447471819397], 
             UndirectedEdge[11, 183] -> 
             RGBColor[
              0.29904764600234657`, 0.4284346339635039, 0.9404593653554703], 
             UndirectedEdge[226, 266] -> 
             RGBColor[
              0.21328048212070516`, 0.3415016878454308, 0.9354573799853517], 
             UndirectedEdge[98, 178] -> 
             RGBColor[
              0.34993177355877136`, 0.4745851224813026, 0.9436255999612144], 
             UndirectedEdge[200, 255] -> 
             RGBColor[
              0.9224751483252943, 0.7242107930884344, 0.2608151757752228], 
             UndirectedEdge[223, 234] -> 
             RGBColor[
              0.852336886710356, 0.35775657985604403`, 0.19596820028306192`], 
             UndirectedEdge[111, 190] -> 
             RGBColor[
              0.2355732429285669, 0.36493279289716524`, 0.9367269197341752], 
             UndirectedEdge[85, 181] -> 
             RGBColor[
              0.8167213708728744, 0.8575535758044224, 0.9821530921197811], 
             UndirectedEdge[57, 134] -> 
             RGBColor[
              0.26052687456490653`, 0.3911606418985847, 0.938147992140275], 
             UndirectedEdge[9, 131] -> 
             RGBColor[
              0.4208304337263501, 0.5371994126346513, 0.9485124028214329], 
             UndirectedEdge[184, 189] -> 
             RGBColor[
              0.2346427787554684, 0.3639548160564028, 0.9366739311760157], 
             UndirectedEdge[194, 286] -> 
             RGBColor[
              0.5374345290972057, 0.6353525877275636, 0.9567279612995309], 
             UndirectedEdge[171, 298] -> 
             RGBColor[
              0.35180269388930685`, 0.47696337077533185`, 0.9437170683691549],
              UndirectedEdge[108, 213] -> 
             RGBColor[
              0.3858995717541348, 0.5086685460021616, 0.9458101573679487], 
             UndirectedEdge[158, 175] -> 
             RGBColor[
              0.34907161965836087`, 0.47545391883295585`, 0.9435117019171652],
              UndirectedEdge[37, 297] -> 
             RGBColor[
              0.7205508998101146, 0.7816191064121104, 0.9727814378282238], 
             UndirectedEdge[68, 234] -> 
             RGBColor[
              0.8458426087622819, 0.3282675804709904, 0.19054921557386956`], 
             UndirectedEdge[38, 252] -> 
             RGBColor[
              0.3592377978575069, 0.4848159523446023, 0.9441391019160659], 
             UndirectedEdge[42, 252] -> 
             RGBColor[
              0.2774845709652012, 0.40898425599534566`, 0.939113707863608], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.2625645345612948, 0.39330235174989453`, 0.9382640338626215], 
             UndirectedEdge[184, 216] -> 
             RGBColor[
              0.24813752757352578`, 0.3781386526806742, 0.9374424371575123], 
             UndirectedEdge[16, 59] -> 
             RGBColor[
              0.9131402588168656, 0.620820449672156, 0.3548598720778012], 
             UndirectedEdge[7, 185] -> 
             RGBColor[
              0.4814085254761833, 0.5882778073170456, 0.9527568066039329], 
             UndirectedEdge[127, 299] -> 
             RGBColor[
              0.9136283213475775, 0.6224467453485296, 0.4600423723683357], 
             UndirectedEdge[166, 217] -> 
             RGBColor[
              0.899879476841495, 0.9180128953290518, 0.7153753712159427], 
             UndirectedEdge[101, 207] -> 
             RGBColor[
              0.6460892652174881, 0.7219820565313749, 0.9663628314965813], 
             UndirectedEdge[14, 69] -> 
             RGBColor[
              0.907867854492874, 0.581493687303205, 0.3264885443906257], 
             UndirectedEdge[51, 107] -> 
             RGBColor[
              0.9138545722061537, 0.6275401673751994, 0.4683441742696273], 
             UndirectedEdge[74, 233] -> 
             RGBColor[
              0.8161512863791258, 0.8534670921405562, 0.7813047425304152], 
             UndirectedEdge[158, 252] -> 
             RGBColor[
              0.35208167801260865`, 0.47861768101199287`, 0.9436831202874573],
              UndirectedEdge[86, 110] -> 
             RGBColor[
              0.9839067857429666, 0.9591178157514064, 0.561716366031505], 
             UndirectedEdge[58, 73] -> 
             RGBColor[
              0.4389666532110068, 0.5520366798791193, 0.9499088011180912], 
             UndirectedEdge[13, 96] -> 
             RGBColor[
              0.3557971492753504, 0.4823533245061042, 0.9439009190224369], 
             UndirectedEdge[16, 53] -> 
             RGBColor[
              0.9125997408169637, 0.6166657914684119, 0.3543422714306673], 
             UndirectedEdge[44, 170] -> 
             RGBColor[
              0.8934743520557873, 0.5315367457661417, 0.24367260924855771`], 
             UndirectedEdge[27, 32] -> 
             RGBColor[
              0.25734797909016266`, 0.3878194212010146, 0.9379669587457427], 
             UndirectedEdge[116, 164] -> 
             RGBColor[
              0.35316605540790247`, 0.4803164193774241, 0.9437244066514788], 
             UndirectedEdge[70, 300] -> 
             RGBColor[
              0.2600472811884571, 0.39065655885195993`, 0.938120680006981], 
             UndirectedEdge[79, 116] -> 
             RGBColor[
              0.3586693068574145, 0.48508305918153105`, 0.9440750689675076], 
             UndirectedEdge[137, 195] -> 
             RGBColor[
              0.8323549819999152, 0.24970014646067296`, 0.17861647334383152`],
              UndirectedEdge[156, 214] -> 
             RGBColor[
              0.2202905707839606, 0.3488697354958046, 0.9358565941642273], 
             UndirectedEdge[14, 249] -> 
             RGBColor[
              0.8206388339044841, 0.15964469815035803`, 0.16739707669615012`],
              UndirectedEdge[84, 89] -> 
             RGBColor[
              0.2893752204809355, 0.4214820825471055, 0.9397908627628895], 
             UndirectedEdge[98, 246] -> 
             RGBColor[
              0.5108375562883921, 0.6129315271469358, 0.9548630505777516], 
             UndirectedEdge[4, 107] -> 
             RGBColor[
              0.6868838807668163, 0.45030100016757835`, 0.5686163001605958], 
             UndirectedEdge[20, 295] -> 
             RGBColor[
              0.851595317593189, 0.8845030065824513, 0.9857071156917947], 
             UndirectedEdge[57, 175] -> 
             RGBColor[
              0.27078207932041887`, 0.40193951231416447`, 0.9387320108798856],
              UndirectedEdge[93, 160] -> 
             RGBColor[
              0.5607147225279772, 0.6542524975154264, 0.9585606634045596], 
             UndirectedEdge[13, 149] -> 
             RGBColor[
              0.30003867844943893`, 0.43269005297428764`, 0.9403981309190235],
              UndirectedEdge[230, 298] -> 
             RGBColor[
              0.2673021323723527, 0.39828186743036675`, 0.9385338330493134], 
             UndirectedEdge[96, 198] -> 
             RGBColor[
              0.43486063371890193`, 0.5507791821456584, 0.9490119679848132], 
             UndirectedEdge[32, 182] -> 
             RGBColor[
              0.2817202883828383, 0.4134362635612778, 0.9393549257043601], 
             UndirectedEdge[80, 241] -> 
             RGBColor[
              0.27345259705009906`, 0.4047463957686619, 0.938884092913914], 
             UndirectedEdge[55, 292] -> 
             RGBColor[
              0.25987815555668636`, 0.39047879708978456`, 0.9381110485524506],
              UndirectedEdge[121, 160] -> 
             RGBColor[
              0.7924150587076538, 0.8345430649548763, 0.8078033989134862], 
             UndirectedEdge[62, 220] -> 
             RGBColor[
              0.6260202363274255, 0.6895227449727015, 0.8093263410054259], 
             UndirectedEdge[28, 189] -> 
             RGBColor[
              0.22763054758381063`, 0.35658451649385525`, 0.9362745949844562],
              UndirectedEdge[25, 91] -> 
             RGBColor[
              0.2622113968861681, 0.3929311816631146, 0.9382439231944433], 
             UndirectedEdge[41, 99] -> 
             RGBColor[
              0.362239582391498, 0.48817545240188814`, 0.9443025637674687], 
             UndirectedEdge[148, 206] -> 
             RGBColor[
              0.23774362795226284`, 0.3672140051674282, 0.9368505199504779], 
             UndirectedEdge[3, 90] -> 
             RGBColor[
              0.39043568607657597`, 0.5125975002365252, 0.9460991945614463], 
             UndirectedEdge[99, 104] -> 
             RGBColor[
              0.3262801186675095, 0.4548403348152493, 0.9420914025992604], 
             UndirectedEdge[193, 266] -> 
             RGBColor[
              0.3235658537972168, 0.4490279862889558, 0.942045190438874], 
             UndirectedEdge[275, 293] -> 
             RGBColor[
              0.21101994270665328`, 0.33912571759478527`, 0.9353286456098898],
              UndirectedEdge[229, 257] -> 
             RGBColor[
              0.3688470358646546, 0.49389849650006856`, 0.9447235848600365], 
             UndirectedEdge[90, 144] -> 
             RGBColor[
              0.35962797975699734`, 0.48591341346284866`, 0.9441361547569478],
              UndirectedEdge[49, 115] -> 
             RGBColor[
              0.22907293102325943`, 0.358100552941108, 0.9363567365875176], 
             UndirectedEdge[77, 244] -> 
             RGBColor[
              0.2442718082387917, 0.3740755365591065, 0.9372222901602183], 
             UndirectedEdge[66, 95] -> 
             RGBColor[
              0.7175511909941827, 0.7776658666577836, 0.9642038036331552], 
             UndirectedEdge[94, 125] -> 
             RGBColor[
              0.9272871440372241, 0.9396965749731525, 0.7126838428267497], 
             UndirectedEdge[196, 230] -> 
             RGBColor[
              0.2651423022333762, 0.39601174901316233`, 0.938410833918081], 
             UndirectedEdge[138, 245] -> 
             RGBColor[
              0.5655432626553039, 0.6564020281299278, 0.9598314214470098], 
             UndirectedEdge[100, 127] -> 
             RGBColor[
              0.8414762129232649, 0.3198099242864162, 0.18735097437698822`], 
             UndirectedEdge[24, 288] -> 
             RGBColor[
              0.9087689498125788, 0.7161208029301624, 0.5832293866647026], 
             UndirectedEdge[224, 258] -> 
             RGBColor[
              0.9656458741337097, 0.9399341707856219, 0.6428561562394914], 
             UndirectedEdge[25, 203] -> 
             RGBColor[
              0.2557021473412196, 0.3860895476811155, 0.9378732310624303], 
             UndirectedEdge[143, 239] -> 
             RGBColor[
              0.4039421601527854, 0.5242961292262122, 0.9469598151462764], 
             UndirectedEdge[142, 282] -> 
             RGBColor[
              0.8113403946734408, 0.8529848446549176, 0.9565261589007614], 
             UndirectedEdge[57, 242] -> 
             RGBColor[
              0.24374269016754463`, 0.3735193999182025, 0.9371921576688209], 
             UndirectedEdge[47, 177] -> 
             RGBColor[
              0.5316337139639098, 0.6296909943120255, 0.956545018426947], 
             UndirectedEdge[43, 174] -> 
             RGBColor[
              0.35724861486395953`, 0.48385252718285615`, 0.9439845437299532],
              UndirectedEdge[5, 29] -> 
             RGBColor[
              0.23189096279390453`, 0.36106248300558996`, 0.9365172193279515],
              UndirectedEdge[167, 282] -> 
             RGBColor[
              0.8587917501354356, 0.8900542041854869, 0.9612556665550847], 
             UndirectedEdge[131, 172] -> 
             RGBColor[
              0.297163306859998, 0.4281806673087738, 0.9402888359918464], 
             UndirectedEdge[21, 101] -> 
             RGBColor[
              0.4650224715635836, 0.5746682645420044, 0.9515515525742121], 
             UndirectedEdge[251, 300] -> 
             RGBColor[
              0.27128730129384493`, 0.40247053264115845`, 0.9387607825238632],
              UndirectedEdge[75, 167] -> 
             RGBColor[
              0.7422194299230214, 0.7985467268232416, 0.9749411544059516], 
             UndirectedEdge[165, 281] -> 
             RGBColor[
              0.9081683799556731, 0.6116901368011833, 0.2799978889278235], 
             UndirectedEdge[63, 174] -> 
             RGBColor[
              0.35841838866408615`, 0.48486572645398507`, 0.944059080682107], 
             UndirectedEdge[64, 211] -> 
             RGBColor[
              0.238007335368493, 0.36749117838190204`, 0.936865537697712], 
             UndirectedEdge[124, 237] -> 
             RGBColor[
              0.7932365579017887, 0.8390697764976703, 0.9690655590701622], 
             UndirectedEdge[127, 192] -> 
             RGBColor[
              0.8488791161434632, 0.3663608331165159, 0.19403468172993021`], 
             UndirectedEdge[62, 228] -> 
             RGBColor[
              0.90559598823519, 0.9239215498870947, 0.8315118721300905], 
             UndirectedEdge[152, 277] -> 
             RGBColor[
              0.3011955804505697, 0.43017548464198757`, 0.9406006083286469], 
             UndirectedEdge[76, 157] -> 
             RGBColor[
              0.3201380287875101, 0.4503731664220151, 0.9416688088356775], 
             UndirectedEdge[106, 297] -> 
             RGBColor[
              0.7085338986582898, 0.7722313337797134, 0.9715836954586705], 
             UndirectedEdge[91, 203] -> 
             RGBColor[
              0.2661031933042482, 0.39702170645266144`, 0.9384655552430561], 
             UndirectedEdge[215, 271] -> 
             RGBColor[
              0.9862840872732699, 0.9639445925953173, 0.5488858494022204], 
             UndirectedEdge[181, 296] -> 
             RGBColor[
              0.7050263286294778, 0.769491193414686, 0.9712340936583042], 
             UndirectedEdge[27, 119] -> 
             RGBColor[
              0.2703316084942079, 0.40146603891431676`, 0.9387063572327446], 
             UndirectedEdge[100, 170] -> 
             RGBColor[
              0.8360368854877944, 0.2780008700889096, 0.18214226828194], 
             UndirectedEdge[112, 115] -> 
             RGBColor[
              0.236902386747869, 0.36632980732383724`, 0.9368026125083924], 
             UndirectedEdge[75, 282] -> 
             RGBColor[
              0.8470847195516484, 0.8809085829167043, 0.9600888191549137], 
             UndirectedEdge[234, 255] -> 
             RGBColor[
              0.8881366683562935, 0.5036662405654082, 0.2296318891309308], 
             UndirectedEdge[29, 77] -> 
             RGBColor[
              0.2444276826034072, 0.3742393703993229, 0.9372311669746878], 
             UndirectedEdge[44, 192] -> 
             RGBColor[
              0.9150207009153106, 0.6868003754774932, 0.26390009611845466`], 
             UndirectedEdge[49, 57] -> 
             RGBColor[
              0.2418037466004938, 0.3714814472931095, 0.9370817377010874], 
             UndirectedEdge[4, 281] -> 
             RGBColor[
              0.6878485673408958, 0.45771600390430534`, 0.5695400851133919], 
             UndirectedEdge[23, 285] -> 
             RGBColor[
              0.33957273212272987`, 0.46739870088843105`, 0.9429001346157797],
              UndirectedEdge[86, 109] -> 
             RGBColor[
              0.9480181265878662, 0.9334317685964351, 0.674604431944415], 
             UndirectedEdge[276, 279] -> 
             RGBColor[
              0.24528708035805388`, 0.3751426519284214, 0.9372801084054498], 
             UndirectedEdge[139, 183] -> 
             RGBColor[
              0.2550340991670391, 0.38538738669335115`, 0.9378351867071995], 
             UndirectedEdge[234, 287] -> 
             RGBColor[
              0.8791470053904711, 0.46890980859888415`, 0.21779165603051126`],
              UndirectedEdge[160, 181] -> 
             RGBColor[
              0.6520185359229838, 0.7272823998054908, 0.9664968499202544], 
             UndirectedEdge[196, 298] -> 
             RGBColor[
              0.28309225038485036`, 0.4148782826128075, 0.9394330569107388], 
             UndirectedEdge[255, 287] -> 
             RGBColor[
              0.9499646737467646, 0.8384490491642924, 0.28320554516144203`], 
             UndirectedEdge[126, 216] -> 
             RGBColor[
              0.24238826022285348`, 0.3720958081705137, 0.9371150248871702], 
             UndirectedEdge[190, 212] -> 
             RGBColor[
              0.21992645288427248`, 0.3484870244968241, 0.9358358581885042], 
             UndirectedEdge[39, 137] -> 
             RGBColor[
              0.8565494590888623, 0.4213131070375924, 0.20122297160509353`], 
             UndirectedEdge[170, 195] -> 
             RGBColor[
              0.820518598671917, 0.15872051746543236`, 0.16728193930165758`], 
             UndirectedEdge[69, 288] -> 
             RGBColor[
              0.9274695616660017, 0.7266621842687284, 0.34504384155502377`], 
             UndirectedEdge[101, 231] -> 
             RGBColor[
              0.49585480302230733`, 0.6013736803735128, 0.9535161614708018], 
             UndirectedEdge[57, 253] -> 
             RGBColor[
              0.27188917324815276`, 0.40310313822602206`, 0.9387950582412713],
              UndirectedEdge[52, 266] -> 
             RGBColor[
              0.5326709863563452, 0.2573632665445422, 0.5510021420640641], 
             UndirectedEdge[28, 275] -> 
             RGBColor[
              0.21809561015053047`, 0.3465626927015274, 0.9357315944033067], 
             UndirectedEdge[4, 226] -> 
             RGBColor[
              0.35927387507325015`, 0.47126073145434144`, 0.9452005342031744],
              UndirectedEdge[104, 229] -> 
             RGBColor[
              0.3157302972548372, 0.4457026097570346, 0.9414191773076857], 
             UndirectedEdge[189, 293] -> 
             RGBColor[
              0.2205548801399334, 0.3491475413871131, 0.9358716461910392], 
             UndirectedEdge[155, 156] -> 
             RGBColor[
              0.22000089461836236`, 0.3485652674792311, 0.935840097535134], 
             UndirectedEdge[107, 281] -> 
             RGBColor[
              0.835111708182694, 0.27088955190662645`, 0.18125631744973736`], 
             UndirectedEdge[107, 240] -> 
             RGBColor[
              0.9145402901776019, 0.6275231337808342, 0.4351299261966648], 
             UndirectedEdge[13, 105] -> 
             RGBColor[
              0.29764935998569264`, 0.4301787277773499, 0.9402620627671929], 
             UndirectedEdge[96, 138] -> 
             RGBColor[
              0.5560749070471602, 0.6482010143955439, 0.959228106200197], 
             UndirectedEdge[254, 260] -> 
             RGBColor[
              0.870237845536556, 0.7409780985202714, 0.6082514586621423], 
             UndirectedEdge[120, 176] -> 
             RGBColor[
              0.18443322649941224`, 0.31118139316580623`, 0.9338145714534094],
              UndirectedEdge[59, 125] -> 
             RGBColor[
              0.9127176607588363, 0.6199165551572493, 0.3088626814342206], 
             UndirectedEdge[22, 267] -> 
             RGBColor[
              0.642613111904264, 0.7180602166534845, 0.966841075599027], 
             UndirectedEdge[28, 197] -> 
             RGBColor[
              0.21695644286649302`, 0.3453653556586265, 0.9356667205117277], 
             UndirectedEdge[245, 298] -> 
             RGBColor[
              0.35482735126592213`, 0.47958317697125596`, 0.9439097968625934],
              UndirectedEdge[193, 199] -> 
             RGBColor[
              0.28921237678725265`, 0.4129203038152378, 0.9400888107445714], 
             UndirectedEdge[22, 274] -> 
             RGBColor[
              0.8909772154370372, 0.8747143818458635, 0.6496575550294168], 
             UndirectedEdge[76, 201] -> 
             RGBColor[
              0.3077043294157084, 0.43960372096206174`, 0.9408765445063949], 
             UndirectedEdge[19, 158] -> 
             RGBColor[
              0.3474496051113486, 0.47374907870238386`, 0.9434193305882683], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.17948366008578914`, 0.30597908504445237`, 0.9335327009683809],
              UndirectedEdge[61, 267] -> 
             RGBColor[
              0.517343318582302, 0.6190416379328455, 0.9551463076112685], 
             UndirectedEdge[106, 283] -> 
             RGBColor[
              0.6376959489926155, 0.716530117719581, 0.9647707808430861], 
             UndirectedEdge[174, 283] -> 
             RGBColor[
              0.5055233087265141, 0.6077894774448256, 0.9546733906594562], 
             UndirectedEdge[19, 242] -> 
             RGBColor[
              0.26584977931499626`, 0.39675535228258274`, 0.9384511236912607],
              UndirectedEdge[125, 195] -> 
             RGBColor[
              0.9058844617461582, 0.5673935932189047, 0.3023192023426855], 
             UndirectedEdge[115, 159] -> 
             RGBColor[
              0.23449254027581456`, 0.3637969058886168, 0.9366653753168572], 
             UndirectedEdge[158, 177] -> 
             RGBColor[
              0.4114198455834537, 0.5307729245068593, 0.947436286649661], 
             UndirectedEdge[42, 134] -> 
             RGBColor[
              0.26421930785544107`, 0.3950416234007289, 0.9383582707537054], 
             UndirectedEdge[165, 179] -> 
             RGBColor[
              0.986953469781533, 0.9683582137242022, 0.5663859549250714], 
             UndirectedEdge[108, 145] -> 
             RGBColor[
              0.3065621353882716, 0.43629450439653, 0.9408887080179298], 
             UndirectedEdge[44, 125] -> 
             RGBColor[
              0.9788402151300284, 0.9402098215196141, 0.37870987228958564`], 
             UndirectedEdge[39, 141] -> 
             RGBColor[
              0.8832675790785431, 0.5628271647927903, 0.22430794542071705`], 
             UndirectedEdge[50, 87] -> 
             RGBColor[
              0.314278172622923, 0.4436160187426821, 0.9413569968700557], 
             UndirectedEdge[26, 226] -> 
             RGBColor[
              0.5823809999360594, 0.646902214593436, 0.908957705075064], 
             UndirectedEdge[9, 143] -> 
             RGBColor[
              0.4567898510085129, 0.5683456525115964, 0.9508037050929882], 
             UndirectedEdge[136, 299] -> 
             RGBColor[
              0.9936961088777931, 0.9896128904175391, 0.6052453259924624], 
             UndirectedEdge[134, 144] -> 
             RGBColor[
              0.29485513198583013`, 0.42659799471298, 0.9401265091035182], 
             UndirectedEdge[240, 281] -> 
             RGBColor[
              0.9155049767516813, 0.6349381375175613, 0.436053711149461], 
             UndirectedEdge[257, 261] -> 
             RGBColor[
              0.39597335276996437`, 0.5173939487951174, 0.9464520497863826], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.27383547980684575`, 0.4051488298221716, 0.9389058975204863], 
             UndirectedEdge[135, 254] -> 
             RGBColor[
              0.940708824154274, 0.7947861767157479, 0.5224157389136257], 
             UndirectedEdge[14, 224] -> 
             RGBColor[
              0.8961112066597844, 0.5421659440515132, 0.2527391724419306], 
             UndirectedEdge[96, 289] -> 
             RGBColor[
              0.3482245893870246, 0.47439408393544596`, 0.9434696729393952], 
             UndirectedEdge[92, 189] -> 
             RGBColor[
              0.2464728493758267, 0.3763889703481986, 0.937347636196824], 
             UndirectedEdge[107, 127] -> 
             RGBColor[
              0.8334595581640123, 0.25819040288628525`, 0.17967421672601133`],
              UndirectedEdge[172, 270] -> 
             RGBColor[
              0.24887539777286288`, 0.3789142010438502, 0.9374844577737833], 
             UndirectedEdge[48, 84] -> 
             RGBColor[
              0.35715044434118537`, 0.4830160061947183, 0.9440058041437522], 
             UndirectedEdge[149, 289] -> 
             RGBColor[
              0.29246611856111315`, 0.4247308124036294, 0.9399668848359817], 
             UndirectedEdge[1, 102] -> 
             RGBColor[
              0.40192272768373283`, 0.5225469983211459, 0.9468311386950623], 
             UndirectedEdge[33, 297] -> 
             RGBColor[
              0.8375308432174786, 0.8737699796260231, 0.9842378309047126], 
             UndirectedEdge[18, 135] -> 
             RGBColor[
              0.9682482286960121, 0.9748593362633335, 0.8947082894518925], 
             UndirectedEdge[60, 137] -> 
             RGBColor[
              0.8858243279121996, 0.5479479904274629, 0.22532498219274089`], 
             UndirectedEdge[156, 208] -> 
             RGBColor[
              0.2568293808226203, 0.38727434154079826`, 0.9379374253416035], 
             UndirectedEdge[104, 279] -> 
             RGBColor[
              0.27193222945827744`, 0.4031483930327844, 0.9387975102287419], 
             UndirectedEdge[74, 158] -> 
             RGBColor[
              0.5209230649967003, 0.6205987474764012, 0.9558008759103712], 
             UndirectedEdge[80, 277] -> 
             RGBColor[
              0.30846241772387, 0.4378133913603206, 0.9410144439610391], 
             UndirectedEdge[223, 291] -> 
             RGBColor[
              0.8526313936469496, 0.36002028922446494`, 0.19625022045814194`],
              UndirectedEdge[114, 264] -> 
             RGBColor[
              0.29953624630010656`, 0.4321619649293011, 0.9403695181514007], 
             UndirectedEdge[1, 237] -> 
             RGBColor[
              0.5286509868219015, 0.6272769374241931, 0.9562975328211968], 
             UndirectedEdge[84, 292] -> 
             RGBColor[
              0.2718397461725893, 0.40305118723574723`, 0.9387922434424387], 
             UndirectedEdge[103, 152] -> 
             RGBColor[
              0.26605649274810816`, 0.396972621207172, 0.9384628957154713], 
             UndirectedEdge[10, 269] -> 
             RGBColor[
              0.2192290472618576, 0.3477540069695957, 0.9357961419700269], 
             UndirectedEdge[109, 138] -> 
             RGBColor[
              0.8139262808550589, 0.8553825016885668, 0.9818711941291625], 
             UndirectedEdge[165, 240] -> 
             RGBColor[
              0.987596961950581, 0.9683237186753911, 0.533871497674751], 
             UndirectedEdge[249, 254] -> 
             RGBColor[
              0.8549509396381043, 0.371609679278205, 0.19822709100428773`], 
             UndirectedEdge[2, 155] -> 
             RGBColor[
              0.22153004206728566`, 0.3501724984015976, 0.9359271802201792], 
             UndirectedEdge[117, 161] -> 
             RGBColor[
              0.20987266837087443`, 0.33791985952648745`, 0.9352633100337076],
              UndirectedEdge[169, 264] -> 
             RGBColor[
              0.29384317958318956`, 0.42617819084854336`, 0.9400453064240097],
              UndirectedEdge[3, 229] -> 
             RGBColor[
              0.3618568268450173, 0.48784392878537974`, 0.9442781749225044], 
             UndirectedEdge[55, 90] -> 
             RGBColor[
              0.3401206359010615, 0.4660537805054501, 0.9430016668956538], 
             UndirectedEdge[3, 259] -> 
             RGBColor[
              0.42079287632469464`, 0.5385942486118271, 0.9481156241324957], 
             UndirectedEdge[113, 254] -> 
             RGBColor[
              0.925365599889266, 0.7843240503848107, 0.5923111720047104], 
             UndirectedEdge[6, 205] -> 
             RGBColor[
              0.41755993513205164`, 0.5337399711358773, 0.9484090697443592], 
             UndirectedEdge[120, 287] -> 
             RGBColor[
              0.5654447927305568, 0.5603176274195498, 0.6027460190921992], 
             UndirectedEdge[31, 67] -> 
             RGBColor[
              0.765577527957654, 0.8171802233035855, 0.9773175856314692], 
             UndirectedEdge[141, 232] -> 
             RGBColor[
              0.9465494933171561, 0.8120284719793993, 0.41813025783551805`], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.4306059655104517, 0.5460088371370204, 0.9490406986812941], 
             UndirectedEdge[71, 122] -> 
             RGBColor[
              0.6268946494046528, 0.707980343525642, 0.9637705896733515], 
             UndirectedEdge[78, 120] -> 
             RGBColor[
              0.1849774474258748, 0.3117534038651181, 0.9338455640300687], 
             UndirectedEdge[177, 247] -> 
             RGBColor[
              0.4991479409504841, 0.603343634292864, 0.9539698061272375], 
             UndirectedEdge[168, 182] -> 
             RGBColor[
              0.34652806688330007`, 0.474422427150048, 0.9433067307526943], 
             UndirectedEdge[26, 228] -> 
             RGBColor[
              0.901089116284713, 0.9224316156704129, 0.933371766463492], 
             UndirectedEdge[7, 194] -> 
             RGBColor[
              0.4552899701705174, 0.5670735874923983, 0.9507006582548503], 
             UndirectedEdge[206, 244] -> 
             RGBColor[
              0.23959248852906917`, 0.3691572748581827, 0.9369558098251829], 
             UndirectedEdge[31, 109] -> 
             RGBColor[
              0.7700026915435176, 0.8207087286290875, 0.9777396616846791], 
             UndirectedEdge[57, 235] -> 
             RGBColor[
              0.24454607243650103`, 0.3743638056202535, 0.9372379091005405], 
             UndirectedEdge[24, 135] -> 
             RGBColor[
              0.9728662611822794, 0.9783034573302576, 0.8868911650284141], 
             UndirectedEdge[130, 220] -> 
             RGBColor[
              0.21805936955163013`, 0.34652460153429643`, 0.9357295305548126],
              UndirectedEdge[84, 112] -> 
             RGBColor[
              0.2764157065059942, 0.4078608116787981, 0.9390528376138995], 
             UndirectedEdge[76, 104] -> 
             RGBColor[
              0.2896837321277139, 0.4218063478486378, 0.9398084320447715], 
             UndirectedEdge[21, 87] -> 
             RGBColor[
              0.32978099166431396`, 0.45704378140199375`, 0.9423448227907686],
              UndirectedEdge[43, 183] -> 
             RGBColor[
              0.28838161647063476`, 0.4191962552733669, 0.9397797353853092], 
             UndirectedEdge[11, 131] -> 
             RGBColor[
              0.3341685066956953, 0.46386169752747186`, 0.9425138996464097], 
             UndirectedEdge[21, 187] -> 
             RGBColor[
              0.3736920911272321, 0.49809503984895503`, 0.9450323074970538], 
             UndirectedEdge[36, 66] -> 
             RGBColor[
              0.8530135718328662, 0.8858447874582254, 0.9760955206644191], 
             UndirectedEdge[124, 125] -> 
             RGBColor[
              0.970159485355791, 0.9735725032155419, 0.706048969605638], 
             UndirectedEdge[232, 296] -> 
             RGBColor[
              0.8451660598218556, 0.8762026073137711, 0.7845904625645401], 
             UndirectedEdge[75, 239] -> 
             RGBColor[
              0.5708233361978141, 0.6599633407458361, 0.9605961986132696], 
             UndirectedEdge[108, 114] -> 
             RGBColor[
              0.32416580444258236`, 0.4547970767096937, 0.9418912109282782], 
             UndirectedEdge[137, 266] -> 
             RGBColor[
              0.546600080262197, 0.3644283860727875, 0.564340658118969], 
             UndirectedEdge[74, 262] -> 
             RGBColor[
              0.8160969055518104, 0.8533507770496733, 0.7753857250766871], 
             UndirectedEdge[48, 90] -> 
             RGBColor[
              0.4086146868704133, 0.5283432370210001, 0.9472575444169704], 
             UndirectedEdge[125, 150] -> 
             RGBColor[
              0.9773157340645346, 0.9789096217852411, 0.6939353071903218], 
             UndirectedEdge[38, 55] -> 
             RGBColor[
              0.34731954937378307`, 0.4722891175276097, 0.9434603752963864], 
             UndirectedEdge[110, 165] -> 
             RGBColor[
              0.9866031709361507, 0.9682133561493669, 0.5721913133374072], 
             UndirectedEdge[114, 145] -> 
             RGBColor[
              0.28680752014306377`, 0.4187832666903979, 0.9396446360272199], 
             UndirectedEdge[222, 290] -> 
             RGBColor[
              0.5245306986367102, 0.6244100551018348, 0.9558410534763778], 
             UndirectedEdge[267, 286] -> 
             RGBColor[
              0.5134415575632728, 0.6158740125652669, 0.954839146691229], 
             UndirectedEdge[6, 187] -> 
             RGBColor[
              0.3348012763614461, 0.46412565624274105`, 0.9425646219959795], 
             UndirectedEdge[221, 231] -> 
             RGBColor[
              0.3698663550363416, 0.4934747204504928, 0.9448363781661868], 
             UndirectedEdge[106, 286] -> 
             RGBColor[
              0.6078523188068897, 0.6923017142945901, 0.9624213809540463], 
             UndirectedEdge[67, 154] -> 
             RGBColor[
              0.8267592072412856, 0.8653361474156035, 0.9831692431983503], 
             UndirectedEdge[85, 296] -> 
             RGBColor[
              0.8079306217366228, 0.8506861757670146, 0.9812769124001008], 
             UndirectedEdge[41, 201] -> 
             RGBColor[
              0.3390519049385823, 0.4680914516387281, 0.942825065464227], 
             UndirectedEdge[42, 235] -> 
             RGBColor[
              0.24823850572703557`, 0.37824478712239773`, 0.9374481877139709],
              UndirectedEdge[44, 60] -> 
             RGBColor[
              0.9455688567915195, 0.8192169579907062, 0.28906456863413965`], 
             UndirectedEdge[199, 228] -> 
             RGBColor[
              0.49763512145939465`, 0.5809234064486897, 0.9579150616794772], 
             UndirectedEdge[39, 62] -> 
             RGBColor[
              0.931190722612425, 0.7413845468769279, 0.4459365036310404], 
             UndirectedEdge[48, 144] -> 
             RGBColor[
              0.3646961975812182, 0.4903032490061542, 0.9444590971150582], 
             UndirectedEdge[68, 215] -> 
             RGBColor[
              0.9347347232001206, 0.7573256172439325, 0.47384806566130333`], 
             UndirectedEdge[127, 240] -> 
             RGBColor[
              0.9138528267329997, 0.6222389884972201, 0.4344716104257349], 
             UndirectedEdge[4, 26] -> 
             RGBColor[
              0.7627278647878275, 0.8127689353043519, 0.92065723869614], 
             UndirectedEdge[8, 47] -> 
             RGBColor[
              0.6479545398771973, 0.7249062782797447, 0.9655457111216659], 
             UndirectedEdge[112, 175] -> 
             RGBColor[
              0.27336230601956724`, 0.40465149417079094`, 0.9388789509732987],
              UndirectedEdge[162, 203] -> 
             RGBColor[
              0.27206034387321254`, 0.4032830494058043, 0.9388048061551442], 
             UndirectedEdge[6, 50] -> 
             RGBColor[
              0.32906105284495657`, 0.4591537631447806, 0.9421988600293891], 
             UndirectedEdge[15, 294] -> 
             RGBColor[
              0.2244101664519819, 0.3531996917403464, 0.9360911990431254], 
             UndirectedEdge[6, 219] -> 
             RGBColor[
              0.2899540268393041, 0.4220904447281936, 0.9398238249287314], 
             UndirectedEdge[110, 281] -> 
             RGBColor[
              0.914511185737251, 0.6348277749915371, 0.4743735268121172], 
             UndirectedEdge[167, 297] -> 
             RGBColor[
              0.7571627446031911, 0.8102205578247882, 0.9764305643600557], 
             UndirectedEdge[122, 246] -> 
             RGBColor[
              0.6115303319065195, 0.6955068984260417, 0.962561054318549], 
             UndirectedEdge[210, 277] -> 
             RGBColor[
              0.36382607089811214`, 0.48954958900708645`, 0.9444036534122333],
              UndirectedEdge[225, 234] -> 
             RGBColor[
              0.889140927135372, 0.5070538412384147, 0.23353324484929344`], 
             UndirectedEdge[84, 280] -> 
             RGBColor[
              0.28433817175579457`, 0.41618782496964746`, 0.9395040102896386],
              UndirectedEdge[67, 95] -> 
             RGBColor[
              0.7004824194836051, 0.7643330817431344, 0.9721930602411528], 
             UndirectedEdge[81, 285] -> 
             RGBColor[
              0.33930631085889784`, 0.4671186752480599, 0.9428849623189395], 
             UndirectedEdge[79, 164] -> 
             RGBColor[
              0.38942752096010885`, 0.5117242782844935, 0.9460349551717104], 
             UndirectedEdge[123, 157] -> 
             RGBColor[
              0.3911005410183704, 0.5131733641705265, 0.9461415585304294], 
             UndirectedEdge[85, 165] -> 
             RGBColor[
              0.9499430145672961, 0.9419121380578821, 0.6850057931573457], 
             UndirectedEdge[59, 62] -> 
             RGBColor[
              0.9138294445361559, 0.6222945482383531, 0.42987348446131357`], 
             UndirectedEdge[38, 48] -> 
             RGBColor[
              0.41581360034313486`, 0.5345785740431597, 0.947716252817703], 
             UndirectedEdge[262, 291] -> 
             RGBColor[
              0.9059438756426232, 0.5640930053700905, 0.37544589714295], 
             UndirectedEdge[26, 170] -> 
             RGBColor[
              0.903864214749553, 0.5788492838255521, 0.5265064491665074], 
             UndirectedEdge[43, 139] -> 
             RGBColor[
              0.2888262243395204, 0.4196635663333328, 0.9398050551457039], 
             UndirectedEdge[52, 281] -> 
             RGBColor[
              0.8268922067247678, 0.207710861892501, 0.1733853135710282], 
             UndirectedEdge[124, 142] -> 
             RGBColor[
              0.8033587771487245, 0.8470321673736835, 0.9700369554308557], 
             UndirectedEdge[166, 271] -> 
             RGBColor[
              0.9850940999243964, 0.9612451065301149, 0.40815265332302325`], 
             UndirectedEdge[37, 150] -> 
             RGBColor[
              0.8213545365263866, 0.860837194061274, 0.9590036741380308], 
             UndirectedEdge[51, 66] -> 
             RGBColor[
              0.9700089985303242, 0.9755966228942858, 0.8659381168837096], 
             UndirectedEdge[60, 125] -> 
             RGBColor[
              0.9593538076584427, 0.8656414371856946, 0.3490277111915949], 
             UndirectedEdge[215, 223] -> 
             RGBColor[
              0.9412290011481947, 0.7868146166289862, 0.47926705037049566`], 
             UndirectedEdge[237, 282] -> 
             RGBColor[
              0.8012181754265049, 0.8450224537789045, 0.955554762540068], 
             UndirectedEdge[143, 172] -> 
             RGBColor[
              0.33312272414216076`, 0.4593269071857189, 0.9425801382634016], 
             UndirectedEdge[177, 285] -> 
             RGBColor[
              0.40098949086418123`, 0.5217386754938967, 0.9467716736701495], 
             UndirectedEdge[244, 270] -> 
             RGBColor[
              0.23538330068246843`, 0.36473315155348174`, 0.9367161028042543],
              UndirectedEdge[147, 272] -> 
             RGBColor[
              0.2247364657597668, 0.3535426530013993, 0.9361097813059873], 
             UndirectedEdge[46, 114] -> 
             RGBColor[
              0.29827465777054285`, 0.4308359553953969, 0.9402976725509951], 
             UndirectedEdge[104, 128] -> 
             RGBColor[
              0.26216622821870855`, 0.39288370652975557`, 0.9382413509056526],
              UndirectedEdge[199, 220] -> 
             RGBColor[
              0.21805936955163013`, 0.34652460153429643`, 0.9357295305548126],
              UndirectedEdge[112, 146] -> 
             RGBColor[
              0.24133200131587673`, 0.37098561308859834`, 0.937054872505013], 
             UndirectedEdge[191, 203] -> 
             RGBColor[
              0.2517414689713402, 0.38192662359285945`, 0.9376476762885642], 
             UndirectedEdge[31, 96] -> 
             RGBColor[
              0.512151317735619, 0.6135272413360646, 0.9550965737557137], 
             UndirectedEdge[59, 228] -> 
             RGBColor[
              0.8245766992197552, 0.5548258112486377, 0.5806907356901773], 
             UndirectedEdge[129, 289] -> 
             RGBColor[
              0.26344635035437974`, 0.39422919605877726`, 0.9383142519675081],
              UndirectedEdge[54, 106] -> 
             RGBColor[
              0.5370375913061106, 0.6338360445866622, 0.9571160047492481], 
             UndirectedEdge[102, 142] -> 
             RGBColor[
              0.5221732711977142, 0.6208612990518254, 0.9562111960106483], 
             UndirectedEdge[74, 90] -> 
             RGBColor[
              0.5208802713688769, 0.620561681786851, 0.9557981491382472], 
             UndirectedEdge[143, 174] -> 
             RGBColor[
              0.39453676766698986`, 0.5161496509837875, 0.9463605118539434], 
             UndirectedEdge[144, 292] -> 
             RGBColor[
              0.2793854994126222, 0.4103384300471832, 0.9392455364137446], 
             UndirectedEdge[59, 255] -> 
             RGBColor[
              0.895882246116654, 0.5632021453653563, 0.23704906314163093`], 
             UndirectedEdge[254, 258] -> 
             RGBColor[
              0.926544473085371, 0.7852032520842381, 0.5903156471830767], 
             UndirectedEdge[46, 108] -> 
             RGBColor[
              0.3180292730157506, 0.448347193101529, 0.9415417445417048], 
             UndirectedEdge[222, 278] -> 
             RGBColor[
              0.51953209520131, 0.6203519636484585, 0.9554475451034554], 
             UndirectedEdge[115, 294] -> 
             RGBColor[
              0.2157444487404361, 0.3440914729872748, 0.9355976992392334], 
             UndirectedEdge[89, 177] -> 
             RGBColor[
              0.3486700459196015, 0.47359177071300174`, 0.9435415608547846], 
             UndirectedEdge[45, 195] -> 
             RGBColor[
              0.8384837744462674, 0.29680873085731074`, 0.18448541191193943`],
              UndirectedEdge[205, 231] -> 
             RGBColor[
              0.4872830813565614, 0.5944147705735998, 0.9528413641420233], 
             UndirectedEdge[148, 244] -> 
             RGBColor[
              0.24066234627754973`, 0.37028176318473494`, 0.9370167366412461],
              UndirectedEdge[20, 297] -> 
             RGBColor[
              0.8131524423226874, 0.8543313044865806, 0.981912597264512], 
             UndirectedEdge[6, 34] -> 
             RGBColor[
              0.31658612534963915`, 0.4483486079564237, 0.9414039686805327], 
             UndirectedEdge[13, 245] -> 
             RGBColor[
              0.36526550488349396`, 0.49055433824048805`, 0.9445042342692497],
              UndirectedEdge[104, 201] -> 
             RGBColor[
              0.30309244121459367`, 0.43475633405208935`, 0.9406139042960187],
              UndirectedEdge[55, 253] -> 
             RGBColor[
              0.2867100868131406, 0.4186808580830187, 0.9396390873432205], 
             UndirectedEdge[52, 141] -> 
             RGBColor[
              0.8583552325882947, 0.3856963454250917, 0.20101401461005142`], 
             UndirectedEdge[160, 299] -> 
             RGBColor[
              0.7923522710279916, 0.8350967196266381, 0.8509761351220573], 
             UndirectedEdge[229, 284] -> 
             RGBColor[
              0.3010164849724387, 0.4302374601386527, 0.9405812474653377], 
             UndirectedEdge[27, 268] -> 
             RGBColor[
              0.2604774227946408, 0.3911086649526121, 0.9381451759351156], 
             UndirectedEdge[193, 236] -> 
             RGBColor[
              0.511354201918838, 0.6127180573453962, 0.9550785966275717], 
             UndirectedEdge[78, 193] -> 
             RGBColor[
              0.2897690368730418, 0.4135053888596902, 0.9401205117129523], 
             UndirectedEdge[175, 177] -> 
             RGBColor[
              0.3568594089399756, 0.48219931048302006`, 0.944007932963718], 
             UndirectedEdge[36, 67] -> 
             RGBColor[
              0.8359448003222887, 0.8725120025435762, 0.9840847772724168], 
             UndirectedEdge[37, 239] -> 
             RGBColor[
              0.5459185219885249, 0.6405075106019407, 0.9581139194816087], 
             UndirectedEdge[49, 280] -> 
             RGBColor[
              0.2523064385494426, 0.38252044244058536`, 0.9376798504702395], 
             UndirectedEdge[263, 276] -> 
             RGBColor[
              0.24638255548127658`, 0.37629406574006286`, 0.9373424940931072],
              UndirectedEdge[13, 73] -> 
             RGBColor[
              0.31756925587348483`, 0.44924224463119755`, 0.9414650714584689],
              UndirectedEdge[136, 240] -> 
             RGBColor[
              0.9939206142632153, 0.9894051335662295, 0.5796745640498617], 
             UndirectedEdge[79, 241] -> 
             RGBColor[
              0.3370030923017984, 0.46357362454027395`, 0.9427949607029437], 
             UndirectedEdge[78, 226] -> 
             RGBColor[
              0.17948366519653014`, 0.30597909041616517`, 0.9335327012594301],
              UndirectedEdge[3, 74] -> 
             RGBColor[
              0.5077694883992605, 0.6092057805456816, 0.9549627416408335], 
             UndirectedEdge[148, 203] -> 
             RGBColor[
              0.2492037147300215, 0.37925928298232137`, 0.9375031549387921], 
             UndirectedEdge[90, 257] -> 
             RGBColor[
              0.39742589509621323`, 0.518652067951214, 0.9465446044989785], 
             UndirectedEdge[34, 87] -> 
             RGBColor[
              0.3018032451276056, 0.4328108635543251, 0.9405621055211995], 
             UndirectedEdge[146, 235] -> 
             RGBColor[
              0.23624487142727435`, 0.3656387170330131, 0.9367651679835913], 
             UndirectedEdge[181, 256] -> 
             RGBColor[
              0.8545325264557142, 0.8843014088645924, 0.8481299389821997], 
             UndirectedEdge[68, 287] -> 
             RGBColor[
              0.9076706141527531, 0.6630503890698746, 0.24412287160438084`], 
             UndirectedEdge[17, 144] -> 
             RGBColor[
              0.3059659418661292, 0.4382761603632087, 0.940759253289231], 
             UndirectedEdge[163, 216] -> 
             RGBColor[
              0.2500986511246546, 0.3801999178753255, 0.9375541202425267], 
             UndirectedEdge[67, 258] -> 
             RGBColor[
              0.9370426830307382, 0.9519641935346369, 0.9705507738068005], 
             UndirectedEdge[232, 240] -> 
             RGBColor[
              0.9945150494485371, 0.9906765703210165, 0.6443751655434223], 
             UndirectedEdge[133, 210] -> 
             RGBColor[
              0.36435206965698563`, 0.49000518269455634`, 0.9444371695880264],
              UndirectedEdge[58, 154] -> 
             RGBColor[
              0.6450616328403926, 0.7212149997583763, 0.9662359728150638], 
             UndirectedEdge[94, 124] -> 
             RGBColor[
              0.9048214633960636, 0.926634777474092, 0.9800597975853467], 
             UndirectedEdge[50, 213] -> 
             RGBColor[
              0.3901638861949155, 0.5123620808400902, 0.94608187571333], 
             UndirectedEdge[15, 212] -> 
             RGBColor[
              0.22532179004368708`, 0.3541578659355026, 0.9361431146580468], 
             UndirectedEdge[11, 139] -> 
             RGBColor[
              0.2994922538712322, 0.4289019450234698, 0.940484685115865], 
             UndirectedEdge[167, 286] -> 
             RGBColor[
              0.6564811647517911, 0.7302909383396649, 0.9672682498554315], 
             UndirectedEdge[113, 288] -> 
             RGBColor[
              0.9106552013287734, 0.717527566222487, 0.5800364548609709], 
             UndirectedEdge[73, 171] -> 
             RGBColor[
              0.3736817156213931, 0.4980860531072854, 0.9450316463789965], 
             UndirectedEdge[31, 110] -> 
             RGBColor[
              0.8058913506986181, 0.8463947757840589, 0.8648515957717691], 
             UndirectedEdge[202, 275] -> 
             RGBColor[
              0.22044981250771753`, 0.3490371086439815, 0.9358656627448182], 
             UndirectedEdge[103, 241] -> 
             RGBColor[
              0.2789461451652853, 0.41052046314879065`, 0.9391969423520976], 
             UndirectedEdge[9, 20] -> 
             RGBColor[
              0.6913677553568252, 0.7572692319617951, 0.9710889688646087], 
             UndirectedEdge[71, 207] -> 
             RGBColor[
              0.6875924129964879, 0.7556761815938675, 0.9696301113207838], 
             UndirectedEdge[160, 168] -> 
             RGBColor[
              0.4880465107801085, 0.5934258804224648, 0.9533459462263981], 
             UndirectedEdge[6, 114] -> 
             RGBColor[
              0.30504212315896806`, 0.43794899060072, 0.940683069693298], 
             UndirectedEdge[95, 96] -> 
             RGBColor[
              0.44705620926157014`, 0.5606800997756136, 0.9499720483653973], 
             UndirectedEdge[198, 278] -> 
             RGBColor[
              0.5335934338471843, 0.6322342135642272, 0.9564255762110536], 
             UndirectedEdge[86, 281] -> 
             RGBColor[
              0.9054719947624891, 0.6025945964032228, 0.26952294162192125`], 
             UndirectedEdge[107, 165] -> 
             RGBColor[
              0.9072036933815937, 0.6042751330644562, 0.27907410397502735`], 
             UndirectedEdge[155, 184] -> 
             RGBColor[
              0.22486994634019453`, 0.35368294955458646`, 0.9361173828275757],
              UndirectedEdge[247, 285] -> 
             RGBColor[
              0.4809297969495969, 0.5875639936298371, 0.952808962101173], 
             UndirectedEdge[34, 227] -> 
             RGBColor[
              0.2936321912026204, 0.4242225678044243, 0.9400967760881624], 
             UndirectedEdge[116, 152] -> 
             RGBColor[
              0.2878519743324149, 0.4186179236915859, 0.9397503655460857], 
             UndirectedEdge[146, 204] -> 
             RGBColor[
              0.23066664293228167`, 0.35977564520466165`, 0.936447496123051], 
             UndirectedEdge[36, 58] -> 
             RGBColor[
              0.6542472259213957, 0.728390854886349, 0.9671515068891303], 
             UndirectedEdge[105, 129] -> 
             RGBColor[
              0.2625398824694277, 0.39327644083830926`, 0.9382626299624591], 
             UndirectedEdge[87, 187] -> 
             RGBColor[
              0.3200183961394125, 0.4485879118406425, 0.9417227588366461], 
             UndirectedEdge[119, 168] -> 
             RGBColor[
              0.3340488783835623, 0.46130600881057365`, 0.9425960594289393], 
             UndirectedEdge[20, 37] -> 
             RGBColor[
              0.7733043134332283, 0.8232016433411387, 0.9779409081787471], 
             UndirectedEdge[150, 200] -> 
             RGBColor[
              0.9240011310350597, 0.7732005239509658, 0.5878910864110933], 
             UndirectedEdge[1, 43] -> 
             RGBColor[
              0.370348202098986, 0.49519873124143765`, 0.944819237845059], 
             UndirectedEdge[187, 213] -> 
             RGBColor[
              0.395904109711405, 0.5173339739380506, 0.9464476376799205], 
             UndirectedEdge[41, 222] -> 
             RGBColor[
              0.3965617253644508, 0.517903567563995, 0.9464895403678258], 
             UndirectedEdge[196, 263] -> 
             RGBColor[
              0.27095799274113747`, 0.40212440847289477`, 0.9387420288889549],
              UndirectedEdge[148, 172] -> 
             RGBColor[
              0.2541544433679442, 0.3844628126751034, 0.9377850916107751], 
             UndirectedEdge[96, 171] -> 
             RGBColor[
              0.4119096090232586, 0.5311971329821921, 0.9474674939429645], 
             UndirectedEdge[178, 208] -> 
             RGBColor[
              0.2815080542956977, 0.41321319207927465`, 0.9393428392870697], 
             UndirectedEdge[25, 270] -> 
             RGBColor[
              0.24003287271686014`, 0.3696201465615213, 0.9369808890531874], 
             UndirectedEdge[47, 217] -> 
             RGBColor[
              0.7255477462839056, 0.7855226808548759, 0.9732794767865461], 
             UndirectedEdge[33, 142] -> 
             RGBColor[
              0.7868432036591011, 0.8341724103626897, 0.9791857606964562], 
             UndirectedEdge[26, 62] -> 
             RGBColor[
              0.9903418616011138, 0.9899003526601282, 0.7825545152346283], 
             UndirectedEdge[48, 177] -> 
             RGBColor[
              0.4164452697798513, 0.5351256943606145, 0.9477565022356473], 
             UndirectedEdge[238, 300] -> 
             RGBColor[
              0.2671877155710705, 0.398161608117775, 0.9385273171817448], 
             UndirectedEdge[25, 139] -> 
             RGBColor[
              0.25364452897953216`, 0.38392686032244283`, 0.9377560527407058],
              UndirectedEdge[3, 30] -> 
             RGBColor[
              0.4197616538813304, 0.5377570557762624, 0.9480344425242617], 
             UndirectedEdge[95, 171] -> 
             RGBColor[
              0.45349990749309843`, 0.5662613073140733, 0.9503826351187716], 
             UndirectedEdge[21, 50] -> 
             RGBColor[
              0.3679518676107426, 0.4931231467509946, 0.9446665455304635], 
             UndirectedEdge[122, 232] -> 
             RGBColor[
              0.8091446434633787, 0.8477841192514302, 0.781190448595753], 
             UndirectedEdge[127, 136] -> 
             RGBColor[
              0.9128398822496258, 0.6200724026716804, 0.3242188545792082], 
             UndirectedEdge[41, 290] -> 
             RGBColor[
              0.4849597446468357, 0.5901356836497829, 0.9533196272793637], 
             UndirectedEdge[123, 259] -> 
             RGBColor[
              0.4502407471664895, 0.5641005142419657, 0.9499920164228051], 
             UndirectedEdge[20, 185] -> 
             RGBColor[
              0.7169880778773853, 0.7780689639663625, 0.973105894503761], 
             UndirectedEdge[163, 211] -> 
             RGBColor[
              0.2418593140070983, 0.3715398521606279, 0.9370849021826888], 
             UndirectedEdge[33, 37] -> 
             RGBColor[
              0.7976827143280194, 0.8426403184805812, 0.9802661418189477], 
             UndirectedEdge[7, 9] -> 
             RGBColor[
              0.45578820295562306`, 0.5674780753124783, 0.9507398809647807], 
             UndirectedEdge[105, 263] -> 
             RGBColor[
              0.2750769487244079, 0.40645369236820506`, 0.9389765973387527], 
             UndirectedEdge[15, 49] -> 
             RGBColor[
              0.2377386487348052, 0.36720877169417954`, 0.9368502363914097], 
             UndirectedEdge[20, 237] -> 
             RGBColor[
              0.752342583517374, 0.8067713443472341, 0.9758891306955624], 
             UndirectedEdge[26, 220] -> 
             RGBColor[
              0.6215133643769486, 0.6880328107560196, 0.9111862353388274], 
             UndirectedEdge[101, 187] -> 
             RGBColor[
              0.4552598760386822, 0.566212394980653, 0.9509294886200896], 
             UndirectedEdge[93, 94] -> 
             RGBColor[
              0.6965792865266065, 0.7615288190518337, 0.9714662855765266], 
             UndirectedEdge[143, 297] -> 
             RGBColor[
              0.5785745379743751, 0.6654077250363819, 0.9616273334928914], 
             UndirectedEdge[208, 268] -> 
             RGBColor[
              0.274238057450941, 0.4055719644510125, 0.9389288237217572], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.9540665099241967, 0.9616166407194549, 0.7611949655148192], 
             UndirectedEdge[224, 288] -> 
             RGBColor[
              0.9157129138329121, 0.6873344410170366, 0.27129446960632875`], 
             UndirectedEdge[1, 75] -> 
             RGBColor[
              0.5745175309470449, 0.663163066561993, 0.9608315894360424], 
             UndirectedEdge[36, 113] -> 
             RGBColor[
              0.8594902789211216, 0.8906751050000117, 0.9651321449597499], 
             UndirectedEdge[29, 244] -> 
             RGBColor[
              0.24266708121897157`, 0.3723888667157059, 0.9371309033304205], 
             UndirectedEdge[36, 96] -> 
             RGBColor[
              0.5825185901002536, 0.6688590205760554, 0.9618637653966613], 
             UndirectedEdge[58, 138] -> 
             RGBColor[
              0.6278035428683023, 0.7077328487058376, 0.9645158476926661], 
             UndirectedEdge[71, 136] -> 
             RGBColor[
              0.8112521109064372, 0.8487062087696886, 0.716702550774494], 
             UndirectedEdge[144, 252] -> 
             RGBColor[
              0.3081203950955903, 0.44054062730759674`, 0.940881946213421], 
             UndirectedEdge[58, 198] -> 
             RGBColor[
              0.506589269540044, 0.610311016455952, 0.9542997094772824], 
             UndirectedEdge[110, 154] -> 
             RGBColor[
              0.8670730299822498, 0.8945506998960768, 0.8707032533386501], 
             UndirectedEdge[119, 152] -> 
             RGBColor[
              0.2677604183233837, 0.39876355502190786`, 0.9385599317562512], 
             UndirectedEdge[38, 90] -> 
             RGBColor[
              0.41074538251891396`, 0.5301887384998543, 0.9473933104595927], 
             UndirectedEdge[66, 179] -> 
             RGBColor[
              0.9700512243327243, 0.9756140843487318, 0.8652383260610674], 
             UndirectedEdge[6, 21] -> 
             RGBColor[
              0.3445638718863475, 0.47258152580409235`, 0.9431866859501019], 
             UndirectedEdge[176, 287] -> 
             RGBColor[
              0.5599634445497977, 0.5545563829440247, 0.6024338644222329], 
             UndirectedEdge[142, 237] -> 
             RGBColor[
              0.6489015303358828, 0.7255912381548726, 0.9656775901367828], 
             UndirectedEdge[108, 221] -> 
             RGBColor[
              0.3192668900954462, 0.449648007121744, 0.9416122250035031], 
             UndirectedEdge[44, 256] -> 
             RGBColor[
              0.9801516197044022, 0.9430147833008583, 0.5214481671592728], 
             UndirectedEdge[89, 112] -> 
             RGBColor[
              0.26517294299919314`, 0.39604395440077267`, 0.9384125788643654],
              UndirectedEdge[83, 184] -> 
             RGBColor[
              0.22686279734830417`, 0.3557775623181615, 0.9362308727443287], 
             UndirectedEdge[259, 261] -> 
             RGBColor[
              0.4324511169680622, 0.5486920306968999, 0.9488584769173136], 
             UndirectedEdge[207, 231] -> 
             RGBColor[
              0.5953538117647618, 0.6805701172311853, 0.962430259270135], 
             UndirectedEdge[112, 280] -> 
             RGBColor[
              0.2601358942740522, 0.3907496968233146, 0.9381257263911142], 
             UndirectedEdge[174, 194] -> 
             RGBColor[
              0.45407833864122044`, 0.5660241331600927, 0.9506234541652072], 
             UndirectedEdge[125, 200] -> 
             RGBColor[
              0.9393105629674767, 0.7809252028803274, 0.3326287940678124], 
             UndirectedEdge[99, 222] -> 
             RGBColor[
              0.4018105363813725, 0.5224498238539401, 0.9468239899644828], 
             UndirectedEdge[108, 169] -> 
             RGBColor[
              0.3184727377256654, 0.44881330262893604`, 0.9415669992008873], 
             UndirectedEdge[15, 57] -> 
             RGBColor[
              0.2429878777602664, 0.3727260442202823, 0.9371491722188713], 
             UndirectedEdge[4, 78] -> 
             RGBColor[
              0.3598305300482983, 0.47184581112708096`, 0.9452322348805061], 
             UndirectedEdge[52, 86] -> 
             RGBColor[
              0.8962878067304835, 0.5320009026523702, 0.26072815279041595`], 
             UndirectedEdge[20, 282] -> 
             RGBColor[
              0.9147814478549319, 0.9341649508472791, 0.9667376994595409], 
             UndirectedEdge[42, 55] -> 
             RGBColor[
              0.2655663224814774, 0.39645742117835314`, 0.9384349812439285], 
             UndirectedEdge[136, 165] -> 
             RGBColor[
              0.9865840174672071, 0.9661571328498515, 0.42361874182822423`], 
             UndirectedEdge[161, 269] -> 
             RGBColor[
              0.22164816720784125`, 0.350296655413888, 0.9359339072721834], 
             UndirectedEdge[57, 243] -> 
             RGBColor[
              0.23260979600231052`, 0.3618180222842825, 0.9365581558157519], 
             UndirectedEdge[57, 146] -> 
             RGBColor[
              0.23875177461672836`, 0.3682736312319718, 0.9369079324115999], 
             UndirectedEdge[4, 130] -> 
             RGBColor[
              0.3592738699625091, 0.4712607260826286, 0.9452005339121252], 
             UndirectedEdge[31, 58] -> 
             RGBColor[
              0.583879953556761, 0.6730590756463584, 0.9603843152481828], 
             UndirectedEdge[95, 140] -> 
             RGBColor[
              0.4083602605702821, 0.527163613934152, 0.9475063767322723], 
             UndirectedEdge[58, 96] -> 
             RGBColor[
              0.47719454661287236`, 0.585147759754026, 0.9523446486820593], 
             UndirectedEdge[16, 94] -> 
             RGBColor[
              0.9277097420952534, 0.9406004694880592, 0.7586810334703302], 
             UndirectedEdge[113, 135] -> 
             RGBColor[
              0.9747525126984742, 0.9797102206225822, 0.8836982332246824], 
             UndirectedEdge[47, 262] -> 
             RGBColor[
              0.8190197652374052, 0.8556976322352333, 0.77563363654671], 
             UndirectedEdge[153, 211] -> 
             RGBColor[
              0.25792046228139853`, 0.38842113733253425`, 0.9379995608165705],
              UndirectedEdge[89, 111] -> 
             RGBColor[
              0.26057341862775985`, 0.3912095626597075, 0.9381506427557986], 
             UndirectedEdge[137, 256] -> 
             RGBColor[
              0.9204070908250823, 0.671745815737615, 0.457708580717874], 
             UndirectedEdge[136, 181] -> 
             RGBColor[
              0.8533623737727853, 0.8817985705963918, 0.7207660407906598], 
             UndirectedEdge[288, 291] -> 
             RGBColor[
              0.839904564048634, 0.3022307284450855, 0.18563064187816736`], 
             UndirectedEdge[121, 296] -> 
             RGBColor[
              0.8454228514141477, 0.8767518585640715, 0.8125406426515358], 
             UndirectedEdge[241, 277] -> 
             RGBColor[
              0.3140852328677468, 0.44372332658360614`, 0.9413346549652732], 
             UndirectedEdge[217, 262] -> 
             RGBColor[
              0.9005077184585596, 0.9193566406229818, 0.783755594175576], 
             UndirectedEdge[75, 142] -> 
             RGBColor[
              0.6947680744610263, 0.7614773672926725, 0.9702116467516284], 
             UndirectedEdge[57, 112] -> 
             RGBColor[
              0.24963320232510341`, 0.37971070167583876`, 0.9375276136219621],
              UndirectedEdge[274, 287] -> 
             RGBColor[
              0.9527752319881305, 0.8479297220628771, 0.29412403319976], 
             UndirectedEdge[97, 252] -> 
             RGBColor[
              0.2790058648824081, 0.41058323235793537`, 0.9392003433016403], 
             UndirectedEdge[18, 69] -> 
             RGBColor[
              0.9697193647682323, 0.9735318279786378, 0.7296111092370301], 
             UndirectedEdge[106, 167] -> 
             RGBColor[
              0.7052976145619072, 0.7697031240469493, 0.9712611329047376], 
             UndirectedEdge[256, 296] -> 
             RGBColor[
              0.8457417773194627, 0.8774340088271846, 0.8472537592625196], 
             UndirectedEdge[131, 183] -> 
             RGBColor[
              0.2897103519915022, 0.4203471391973532, 0.9398644012377442], 
             UndirectedEdge[172, 183] -> 
             RGBColor[
              0.2620424461666492, 0.39275360374480583`, 0.9382343017009069], 
             UndirectedEdge[1, 143] -> 
             RGBColor[
              0.4076363549020162, 0.5274958550423691, 0.9471952059690492], 
             UndirectedEdge[17, 252] -> 
             RGBColor[
              0.29837684649391727`, 0.43094336222280266`, 0.9403034920476165],
              UndirectedEdge[126, 214] -> 
             RGBColor[
              0.21941035515512047`, 0.34794457306099935`, 0.9358064671863272],
              UndirectedEdge[84, 134] -> 
             RGBColor[
              0.2873093787457973, 0.41931075190154404`, 0.9396732161322123], 
             UndirectedEdge[45, 234] -> 
             RGBColor[
              0.837571395698585, 0.28979578799570727`, 0.18361171699277434`], 
             UndirectedEdge[32, 156] -> 
             RGBColor[
              0.24197823755521267`, 0.3716648483498845, 0.9370916747028223], 
             UndirectedEdge[140, 149] -> 
             RGBColor[
              0.3110114912745308, 0.4424361680704541, 0.9410884474530516], 
             UndirectedEdge[16, 150] -> 
             RGBColor[
              0.9777383321225639, 0.9798135163001478, 0.7399324978339024], 
             UndirectedEdge[209, 218] -> 
             RGBColor[
              0.2605995221174108, 0.3912369990823875, 0.9381521293109176], 
             UndirectedEdge[82, 281] -> 
             RGBColor[
              0.9155765352150156, 0.6350911938349629, 0.44384240827575683`], 
             UndirectedEdge[178, 182] -> 
             RGBColor[
              0.29211972893207316`, 0.4243667349411374, 0.9399471584590454], 
             UndirectedEdge[41, 157] -> 
             RGBColor[
              0.35148560431038395`, 0.4788608970986815, 0.9436173297935095], 
             UndirectedEdge[254, 288] -> 
             RGBColor[
              0.8766115127845734, 0.5326035223156528, 0.21875396054991414`], 
             UndirectedEdge[129, 161] -> 
             RGBColor[
              0.22609023535273692`, 0.35496555067756064`, 0.9361868764815843],
              UndirectedEdge[20, 283] -> 
             RGBColor[
              0.7423144926570131, 0.7986300884264481, 0.9750996826489275], 
             UndirectedEdge[162, 210] -> 
             RGBColor[
              0.33154191612091594`, 0.45934744108992703`, 0.9424285250056568],
              UndirectedEdge[203, 244] -> 
             RGBColor[
              0.2510525753068279, 0.38120255267307596`, 0.9376084448134971], 
             UndirectedEdge[121, 246] -> 
             RGBColor[
              0.796739020185918, 0.8380534516751759, 0.8081437970002479], 
             UndirectedEdge[24, 259] -> 
             RGBColor[
              0.7099488174717532, 0.7711907329676471, 0.9554734955620947], 
             UndirectedEdge[141, 281] -> 
             RGBColor[
              0.8675394206203003, 0.45629003917594413`, 0.20980880344155672`],
              UndirectedEdge[110, 138] -> 
             RGBColor[
              0.8498149400101593, 0.8810685488435381, 0.8689831282162525], 
             UndirectedEdge[67, 109] -> 
             RGBColor[
              0.916743494821664, 0.9364503947042759, 0.9919210069943111], 
             UndirectedEdge[154, 245] -> 
             RGBColor[
              0.5828013526273942, 0.6698841791824666, 0.9615515465694076], 
             UndirectedEdge[193, 249] -> 
             RGBColor[
              0.609038860752824, 0.33213297985445467`, 0.5560510629020323], 
             UndirectedEdge[82, 137] -> 
             RGBColor[
              0.9203214410888617, 0.6715626196123557, 0.4483861354991565], 
             UndirectedEdge[100, 125] -> 
             RGBColor[
              0.9214027485620356, 0.686673945842382, 0.31717953132296794`], 
             UndirectedEdge[104, 218] -> 
             RGBColor[
              0.2705572837668725, 0.40170323793452584`, 0.9387192091056663], 
             UndirectedEdge[73, 149] -> 
             RGBColor[
              0.3114795465639533, 0.4428415740370091, 0.9411182715222086], 
             UndirectedEdge[108, 219] -> 
             RGBColor[
              0.30907770812291846`, 0.4389385308371674, 0.9410319661637115], 
             UndirectedEdge[58, 140] -> 
             RGBColor[
              0.4384985979215843, 0.5516312739125644, 0.9498789770489342], 
             UndirectedEdge[9, 63] -> 
             RGBColor[
              0.42067147200560917`, 0.537061727981794, 0.9485022739211517], 
             UndirectedEdge[48, 217] -> 
             RGBColor[
              0.6103593020998471, 0.6909573809034649, 0.9644909605952465], 
             UndirectedEdge[8, 271] -> 
             RGBColor[
              0.814657116181253, 0.8317974978685563, 0.6664449508576125], 
             UndirectedEdge[18, 222] -> 
             RGBColor[
              0.6912666998914337, 0.7558621322945974, 0.9623123726675136], 
             UndirectedEdge[215, 234] -> 
             RGBColor[
              0.9062111144378386, 0.5631850367729421, 0.44751685008743375`], 
             UndirectedEdge[15, 146] -> 
             RGBColor[
              0.2346866767510397, 0.3640009556330419, 0.9366764311019222], 
             UndirectedEdge[54, 151] -> 
             RGBColor[
              0.4303399784091667, 0.5471605926069658, 0.9486418607828988], 
             UndirectedEdge[195, 255] -> 
             RGBColor[
              0.8890490471039758, 0.5106791834270117, 0.23050558405009586`], 
             UndirectedEdge[1, 11] -> 
             RGBColor[
              0.3810142316306978, 0.5044371099315746, 0.9454988678152201], 
             UndirectedEdge[32, 178] -> 
             RGBColor[
              0.2666569110282901, 0.3976036988883609, 0.9384970886482884], 
             UndirectedEdge[126, 189] -> 
             RGBColor[
              0.22889351140479614`, 0.3579119715462422, 0.9363465189056738], 
             UndirectedEdge[61, 273] -> 
             RGBColor[
              0.5923372400801741, 0.6799250818424811, 0.9610501038233672], 
             UndirectedEdge[54, 194] -> 
             RGBColor[
              0.4666198015964266, 0.5768869180196359, 0.9514225850947327], 
             UndirectedEdge[38, 144] -> 
             RGBColor[
              0.36682689322971884`, 0.49214875048500833`, 0.9445948631576804],
              UndirectedEdge[4, 220] -> 
             RGBColor[
              0.3984062395141392, 0.5123913276169251, 0.9474290644669376], 
             UndirectedEdge[45, 200] -> 
             RGBColor[
              0.8719098756675858, 0.5103403405187334, 0.21479500363706636`], 
             UndirectedEdge[2, 202] -> 
             RGBColor[
              0.22943917498765481`, 0.3584854985688961, 0.9363775936394806], 
             UndirectedEdge[17, 175] -> 
             RGBColor[
              0.29536678813966943`, 0.42777960004376564`, 0.9401320736773244],
              UndirectedEdge[233, 262] -> 
             RGBColor[
              0.9940341182393746, 0.9896479070942221, 0.5920287713894679], 
             UndirectedEdge[67, 138] -> 
             RGBColor[
              0.8095011172691953, 0.8518539963630647, 0.9814491180759526], 
             UndirectedEdge[39, 192] -> 
             RGBColor[
              0.8662594246203876, 0.48559710775370324`, 0.21011592443281657`],
              UndirectedEdge[164, 168] -> 
             RGBColor[
              0.38489864849528777`, 0.5078015965832141, 0.9457463794229767], 
             UndirectedEdge[19, 253] -> 
             RGBColor[
              0.2939962623956044, 0.42633909059040226`, 0.940054024263711], 
             UndirectedEdge[24, 74] -> 
             RGBColor[
              0.7969254295463191, 0.8418022649015016, 0.9623206130704325], 
             UndirectedEdge[80, 133] -> 
             RGBColor[
              0.30898841648274356`, 0.43826898504779055`, 0.941047960136832], 
             UndirectedEdge[198, 222] -> 
             RGBColor[
              0.4501940180001994, 0.5640601889318158, 0.9499889976724383], 
             UndirectedEdge[111, 212] -> 
             RGBColor[
              0.2273675902370908, 0.3563081316499939, 0.936259619952571], 
             UndirectedEdge[126, 184] -> 
             RGBColor[
              0.23168784072436213`, 0.3608489888318178, 0.9365056518265833], 
             UndirectedEdge[132, 294] -> 
             RGBColor[
              0.2083047996307834, 0.33627193007203204`, 0.9351740222284133], 
             UndirectedEdge[39, 136] -> 
             RGBColor[
              0.9302201907265502, 0.7393086773088677, 0.34030009728209454`], 
             UndirectedEdge[133, 162] -> 
             RGBColor[
              0.31733689752319516`, 0.44704376794557543`, 0.9415233937816148],
              UndirectedEdge[22, 271] -> 
             RGBColor[
              0.8974219616748091, 0.8964540242042457, 0.6746941771749546], 
             UndirectedEdge[107, 110] -> 
             RGBColor[
              0.9135464991631714, 0.6274127712548101, 0.4734497418593211], 
             UndirectedEdge[40, 191] -> 
             RGBColor[
              0.24055073236956107`, 0.37016444989070835`, 0.9370103803943042],
              UndirectedEdge[143, 237] -> 
             RGBColor[
              0.5177646791690618, 0.6178477648970354, 0.9556038669239417], 
             UndirectedEdge[157, 261] -> 
             RGBColor[
              0.3733109108199431, 0.49776488062546065`, 0.9450080190249379], 
             UndirectedEdge[35, 163] -> 
             RGBColor[
              0.23379526623113445`, 0.36306402665793014`, 0.9366256665915373],
              UndirectedEdge[89, 175] -> 
             RGBColor[
              0.28632181999450856`, 0.4182727650390983, 0.9396169761222888], 
             UndirectedEdge[16, 200] -> 
             RGBColor[
              0.939733161025506, 0.7818290973952341, 0.3786259847113931], 
             UndirectedEdge[35, 189] -> 
             RGBColor[
              0.2290398133604396, 0.3580657441777033, 0.9363548505856133], 
             UndirectedEdge[233, 291] -> 
             RGBColor[
              0.9059982564699387, 0.5642093204609733, 0.381364914596678], 
             UndirectedEdge[258, 290] -> 
             RGBColor[
              0.7873478763723856, 0.8338243344390612, 0.9561368785302078], 
             UndirectedEdge[157, 259] -> 
             RGBColor[
              0.40512064339431064`, 0.5250197481568593, 0.947117003308583], 
             UndirectedEdge[105, 245] -> 
             RGBColor[
              0.35678647711021616`, 0.4816423424493619, 0.944021366181159], 
             UndirectedEdge[100, 192] -> 
             RGBColor[
              0.857583234347318, 0.43326449980026105`, 0.20236975515183697`], 
             UndirectedEdge[258, 278] -> 
             RGBColor[
              0.7823492729369855, 0.8297662429856849, 0.9557433701572854], 
             UndirectedEdge[99, 201] -> 
             RGBColor[
              0.34430071595550393`, 0.4726377079286733, 0.9431595150608838], 
             UndirectedEdge[9, 282] -> 
             RGBColor[
              0.740243347265956, 0.7955203413934655, 0.9507546007091144], 
             UndirectedEdge[84, 175] -> 
             RGBColor[
              0.29756458350130965`, 0.4300896223171238, 0.940257234871823], 
             UndirectedEdge[271, 291] -> 
             RGBColor[
              0.897686479772025, 0.537150265190796, 0.2658690194898667], 
             UndirectedEdge[127, 256] -> 
             RGBColor[
              0.9140100349325547, 0.622575240939881, 0.4515827527707482], 
             UndirectedEdge[80, 116] -> 
             RGBColor[
              0.2951188116057152, 0.426255830409919, 0.9401642011784779], 
             UndirectedEdge[202, 268] -> 
             RGBColor[
              0.2453187041670522, 0.37517589055674394`, 0.937281909334589], 
             UndirectedEdge[161, 265] -> 
             RGBColor[
              0.21936843133233605`, 0.34790050846512904`, 0.9358040796866404],
              UndirectedEdge[22, 72] -> 
             RGBColor[
              0.7345932590636062, 0.7925891041868212, 0.9741810489653038], 
             UndirectedEdge[77, 162] -> 
             RGBColor[
              0.26527957680517633`, 0.3961560332918348, 0.9384186515018654], 
             UndirectedEdge[93, 164] -> 
             RGBColor[
              0.45756686024315646`, 0.5686282136761757, 0.9509610966011381], 
             UndirectedEdge[19, 111] -> 
             RGBColor[
              0.2671407671011217, 0.39811226229915386`, 0.9385246435358352], 
             UndirectedEdge[37, 142] -> 
             RGBColor[
              0.669863260251737, 0.742021537148777, 0.9677293676199676], 
             UndirectedEdge[43, 172] -> 
             RGBColor[
              0.2958345713391305, 0.4270297833847875, 0.9402041701394114], 
             UndirectedEdge[61, 285] -> 
             RGBColor[
              0.474805368949063, 0.5825919070766665, 0.9523268246944521], 
             UndirectedEdge[38, 257] -> 
             RGBColor[
              0.4046248085689348, 0.5248874049733736, 0.9470033128997111], 
             UndirectedEdge[174, 185] -> 
             RGBColor[
              0.4801968939468863, 0.58722835298474, 0.9526796025142897], 
             UndirectedEdge[75, 237] -> 
             RGBColor[
              0.6846458552140906, 0.7535149764166593, 0.969240250390935], 
             UndirectedEdge[30, 48] -> 
             RGBColor[
              0.43794065467516774`, 0.5535027925607373, 0.9491927923797858], 
             UndirectedEdge[289, 298] -> 
             RGBColor[
              0.28811767425307283`, 0.4201603217285858, 0.9397192473655857], 
             UndirectedEdge[123, 261] -> 
             RGBColor[
              0.41843101459212195`, 0.5368456467105671, 0.9478830321391599], 
             UndirectedEdge[77, 206] -> 
             RGBColor[
              0.2413530899135048, 0.3710077785417997, 0.9370560734694501], 
             UndirectedEdge[121, 137] -> 
             RGBColor[
              0.9200881649197675, 0.6710636654745018, 0.4229954641068904], 
             UndirectedEdge[87, 227] -> 
             RGBColor[
              0.2679362427515092, 0.39894835764378045`, 0.938569944697324], 
             UndirectedEdge[123, 144] -> 
             RGBColor[
              0.3759650676291757, 0.5000637778518178, 0.9451771395498434], 
             UndirectedEdge[9, 37] -> 
             RGBColor[
              0.5987662128442524, 0.684557033887325, 0.9619578094283205], 
             UndirectedEdge[178, 268] -> 
             RGBColor[
              0.26978635473276824`, 0.4008929426399584, 0.9386753058376613], 
             UndirectedEdge[112, 253] -> 
             RGBColor[
              0.2744693999473012, 0.40581512008264853`, 0.9389419983346845], 
             UndirectedEdge[78, 220] -> 
             RGBColor[
              0.21861602963741927`, 0.34710968657874874`, 0.9357612315231933],
              UndirectedEdge[66, 67] -> 
             RGBColor[
              0.9293871027463778, 0.9462546742934231, 0.9835096743331035], 
             UndirectedEdge[20, 124] -> 
             RGBColor[
              0.9067998303302157, 0.928212273566045, 0.9802484959896351], 
             UndirectedEdge[18, 224] -> 
             RGBColor[
              0.9579627169351427, 0.9342040847269458, 0.6558617372883351], 
             UndirectedEdge[72, 151] -> 
             RGBColor[
              0.5475405416357872, 0.6431396338261914, 0.9576978591404627], 
             UndirectedEdge[25, 29] -> 
             RGBColor[
              0.24731665325336327`, 0.3772758617237455, 0.9373956895793536], 
             UndirectedEdge[135, 258] -> 
             RGBColor[
              0.9759313858945792, 0.9805894223220096, 0.8817027084030489], 
             UndirectedEdge[130, 176] -> 
             RGBColor[
              0.17893943915932659`, 0.3054070743451405, 0.9335017083917216], 
             UndirectedEdge[31, 245] -> 
             RGBColor[
              0.5216196733437626, 0.6217282550704486, 0.9556998890025264], 
             UndirectedEdge[295, 297] -> 
             RGBColor[
              0.7988419039700752, 0.8429204696534232, 0.9805476453412715], 
             UndirectedEdge[17, 30] -> 
             RGBColor[
              0.37921039896007874`, 0.5014757039177918, 0.9454929485539587], 
             UndirectedEdge[22, 273] -> 
             RGBColor[
              0.717607033402136, 0.7789436605631201, 0.9727448718111256], 
             UndirectedEdge[86, 165] -> 
             RGBColor[
              0.9775639799613888, 0.9359801775610526, 0.3673407281472113], 
             UndirectedEdge[124, 200] -> 
             RGBColor[
              0.916844882326316, 0.7678634053812667, 0.6000047488264095], 
             UndirectedEdge[198, 258] -> 
             RGBColor[
              0.7130111957358749, 0.7734744682690422, 0.9502848227262681], 
             UndirectedEdge[177, 217] -> 
             RGBColor[
              0.6131216671850642, 0.6933500026997739, 0.964666976055813], 
             UndirectedEdge[52, 110] -> 
             RGBColor[
              0.9053269977052454, 0.5642340812406845, 0.4655787379806119], 
             UndirectedEdge[121, 299] -> 
             RGBColor[
              0.9945473356554072, 0.9914335784226265, 0.6978961075730188], 
             UndirectedEdge[173, 196] -> 
             RGBColor[
              0.2690530219671379, 0.40012216340729806`, 0.9386335436215274], 
             UndirectedEdge[238, 251] -> 
             RGBColor[
              0.2826141781107905, 0.4143757983412377, 0.9394058314019756], 
             UndirectedEdge[218, 284] -> 
             RGBColor[
              0.25584347148447395`, 0.38623808831614403`, 0.9378812792633183],
              UndirectedEdge[209, 276] -> 
             RGBColor[
              0.24846893317691396`, 0.37848698098216405`, 0.9374613102163545],
              UndirectedEdge[8, 72] -> 
             RGBColor[
              0.6518284135700501, 0.7279325778511317, 0.9659318226479615], 
             UndirectedEdge[56, 168] -> 
             RGBColor[
              0.46678271330407606`, 0.5761629717082618, 0.9516719821972282], 
             UndirectedEdge[201, 257] -> 
             RGBColor[
              0.35620917982441114`, 0.48295222079512334`, 0.9439183118483695],
              UndirectedEdge[31, 51] -> 
             RGBColor[
              0.8061994237416004, 0.8465221719044482, 0.8597460281820752], 
             UndirectedEdge[53, 282] -> 
             RGBColor[
              0.89769307964249, 0.6086527767356787, 0.5622102390155896], 
             UndirectedEdge[17, 97] -> 
             RGBColor[
              0.27685141165294697`, 0.4083187654135474, 0.9390776503774505], 
             UndirectedEdge[102, 162] -> 
             RGBColor[
              0.3349247683998675, 0.4622774977068556, 0.9426440773615328], 
             UndirectedEdge[36, 260] -> 
             RGBColor[
              0.8043625245684116, 0.8473291531354724, 0.9810724316171817], 
             UndirectedEdge[79, 168] -> 
             RGBColor[
              0.3904018999447999, 0.5125682363873212, 0.9460970417390054], 
             UndirectedEdge[142, 297] -> 
             RGBColor[
              0.7097113891411961, 0.773151198294219, 0.9717010567057325], 
             UndirectedEdge[232, 299] -> 
             RGBColor[
              0.994290544063115, 0.9908843271723261, 0.6699459274860231], 
             UndirectedEdge[50, 169] -> 
             RGBColor[
              0.3227370521664461, 0.4525068374668645, 0.9418387175462686], 
             UndirectedEdge[92, 153] -> 
             RGBColor[
              0.26728945052082176`, 0.3982685380003319, 0.9385331108366297], 
             UndirectedEdge[44, 299] -> 
             RGBColor[
              0.979769906119425, 0.942886287709507, 0.5299077867568601], 
             UndirectedEdge[90, 252] -> 
             RGBColor[
              0.35203888438478537`, 0.4785806153224426, 0.9436803935153333], 
             UndirectedEdge[7, 283] -> 
             RGBColor[
              0.5067349402558111, 0.6088389317771312, 0.9547505947490993], 
             UndirectedEdge[52, 179] -> 
             RGBColor[
              0.9056772965506277, 0.5643789388155198, 0.459773379568276], 
             UndirectedEdge[98, 296] -> 
             RGBColor[
              0.559521387516622, 0.6516299340358314, 0.9592598962290395], 
             UndirectedEdge[18, 88] -> 
             RGBColor[
              0.7253109400374347, 0.7839674018676228, 0.9648635309809819], 
             UndirectedEdge[100, 240] -> 
             RGBColor[
              0.9225569449368545, 0.6891426551809652, 0.4428066838476417], 
             UndirectedEdge[2, 214] -> 
             RGBColor[
              0.2218197182328839, 0.35047696641817105`, 0.9359436768492726], 
             UndirectedEdge[114, 169] -> 
             RGBColor[
              0.2987181224804576, 0.4313020649228039, 0.9403229272101774], 
             UndirectedEdge[37, 295] -> 
             RGBColor[
              0.7589937750806162, 0.8117908085079812, 0.9765759562555065], 
             UndirectedEdge[45, 225] -> 
             RGBColor[
              0.9093933228339569, 0.6627226292341221, 0.2529269618420678], 
             UndirectedEdge[38, 74] -> 
             RGBColor[
              0.5280791848415985, 0.6267970188090106, 0.9562568575389798], 
             UndirectedEdge[38, 158] -> 
             RGBColor[
              0.41078817614673724`, 0.5302258041894045, 0.9473960372317167], 
             UndirectedEdge[69, 135] -> 
             RGBColor[
              0.9915668730357023, 0.9888448386688236, 0.6487056199187353], 
             UndirectedEdge[113, 224] -> 
             RGBColor[
              0.9644670009376046, 0.9390549690861945, 0.644851681061125], 
             UndirectedEdge[124, 282] -> 
             RGBColor[
              0.9556754222393467, 0.9664633829977154, 0.9599141278341408], 
             UndirectedEdge[56, 79] -> 
             RGBColor[
              0.47131158576889715`, 0.5800856534095411, 0.9519605579459619], 
             UndirectedEdge[49, 146] -> 
             RGBColor[
              0.23350254559126715`, 0.3627563587058691, 0.9366089965841382], 
             UndirectedEdge[47, 166] -> 
             RGBColor[
              0.8183915236203407, 0.8543538869413033, 0.7072534135870767], 
             UndirectedEdge[189, 197] -> 
             RGBColor[
              0.22117434471858483`, 0.3497986379355985, 0.9359069237823778], 
             UndirectedEdge[125, 256] -> 
             RGBColor[
              0.9939365705713255, 0.9894392624958468, 0.5814113097167279], 
             UndirectedEdge[69, 138] -> 
             RGBColor[
              0.8498609562052564, 0.8791517168657417, 0.7275038724573385], 
             UndirectedEdge[170, 255] -> 
             RGBColor[
              0.8904238882805281, 0.5212468151692371, 0.2318221335134233], 
             UndirectedEdge[41, 104] -> 
             RGBColor[
              0.3210313076505878, 0.45029407852530423`, 0.9417569530026035], 
             UndirectedEdge[185, 283] -> 
             RGBColor[
              0.5933967145885973, 0.6807852109772019, 0.9611335095376532], 
             UndirectedEdge[103, 277] -> 
             RGBColor[
              0.3139559658390563, 0.44358745874044936`, 0.9413272933992227], 
             UndirectedEdge[45, 282] -> 
             RGBColor[
              0.9107404155806164, 0.7089403181351821, 0.5747043826447977], 
             UndirectedEdge[222, 245] -> 
             RGBColor[
              0.43026765068117134`, 0.5470979459642735, 0.9486372521240278], 
             UndirectedEdge[53, 195] -> 
             RGBColor[
              0.825436438508141, 0.1965211894578074, 0.17199126828273137`], 
             UndirectedEdge[121, 136] -> 
             RGBColor[
              0.9937588965574554, 0.9890592357457773, 0.5620725897838914], 
             UndirectedEdge[92, 211] -> 
             RGBColor[
              0.2517282610763278, 0.3819127412577725, 0.9376469241184826], 
             UndirectedEdge[26, 137] -> 
             RGBColor[
              0.9157005980775512, 0.6698289128207927, 0.5378409832086813], 
             UndirectedEdge[139, 148] -> 
             RGBColor[
              0.24714609636833407`, 0.37709659562364867`, 0.9373859766170676],
              UndirectedEdge[69, 258] -> 
             RGBColor[
              0.9774025219667993, 0.9792619140373138, 0.7166055281881865], 
             UndirectedEdge[244, 272] -> 
             RGBColor[
              0.23289575947638014`, 0.3621185880266611, 0.936574441012555], 
             UndirectedEdge[100, 256] -> 
             RGBColor[
              0.9227141531364094, 0.6894789076236262, 0.45991782619265503`], 
             UndirectedEdge[29, 206] -> 
             RGBColor[
              0.23974836289368467`, 0.3693211086983992, 0.9369646866396522], 
             UndirectedEdge[101, 213] -> 
             RGBColor[
              0.48723449014775655`, 0.5939071986311, 0.9529668827570787], 
             UndirectedEdge[39, 107] -> 
             RGBColor[
              0.8508398666409367, 0.3774266775234726, 0.1957554594288977], 
             UndirectedEdge[134, 252] -> 
             RGBColor[
              0.28726603661361816`, 0.4192651965725739, 0.9396707478619037], 
             UndirectedEdge[14, 288] -> 
             RGBColor[
              0.8422994070509533, 0.32063854118780577`, 0.1879239462417765], 
             UndirectedEdge[155, 202] -> 
             RGBColor[
              0.22021191752572378`, 0.34878706593449305`, 0.9358521149775277],
              UndirectedEdge[220, 228] -> 
             RGBColor[
              0.5367674910110247, 0.6220540079829862, 0.9601435922342896], 
             UndirectedEdge[228, 266] -> 
             RGBColor[
              0.5319885984693589, 0.6170310889224077, 0.9598714413737797], 
             UndirectedEdge[113, 249] -> 
             RGBColor[
              0.8889946281823045, 0.5565337231850392, 0.5595095853153444], 
             UndirectedEdge[109, 179] -> 
             RGBColor[
              0.9574076164080104, 0.9658098047595847, 0.8736496587222751], 
             UndirectedEdge[41, 209] -> 
             RGBColor[
              0.3110735460011261, 0.43982783967316585`, 0.9411898732078549], 
             UndirectedEdge[76, 261] -> 
             RGBColor[
              0.3474685023612617, 0.4740454489620557, 0.9434102824444082], 
             UndirectedEdge[114, 219] -> 
             RGBColor[
              0.28932309287771063`, 0.4214272931310352, 0.9397878941730018], 
             UndirectedEdge[130, 266] -> 
             RGBColor[
              0.21328047700996416`, 0.3415016824737179, 0.9354573796943026], 
             UndirectedEdge[1, 185] -> 
             RGBColor[
              0.4932964811819127, 0.5985745570433215, 0.9535142966293955], 
             UndirectedEdge[202, 208] -> 
             RGBColor[
              0.2570404037299817, 0.3874961399960602, 0.9379494427839974], 
             UndirectedEdge[8, 285] -> 
             RGBColor[
              0.5173103167774687, 0.616953959461616, 0.9557723663648683], 
             UndirectedEdge[65, 210] -> 
             RGBColor[
              0.33323684341077736`, 0.46112891713616844`, 0.9425250486073942],
              UndirectedEdge[63, 183] -> 
             RGBColor[
              0.28955139027076127`, 0.4202094545444958, 0.939854272337463], 
             UndirectedEdge[51, 86] -> 
             RGBColor[
              0.9842148587859489, 0.9592452118717956, 0.5566107984418112], 
             UndirectedEdge[91, 191] -> 
             RGBColor[
              0.2582507185162887, 0.38876825757485856`, 0.9380183684205773], 
             UndirectedEdge[122, 181] -> 
             RGBColor[
              0.6690049122710009, 0.741072705352345, 0.9678340796895172], 
             UndirectedEdge[17, 42] -> 
             RGBColor[
              0.2753301177357401, 0.4067197890509576, 0.9389910149394182], 
             UndirectedEdge[90, 253] -> 
             RGBColor[
              0.3501359199582715, 0.4765804790552632, 0.9435720225064269], 
             UndirectedEdge[60, 136] -> 
             RGBColor[
              0.9594950595498875, 0.8659435606987382, 0.3644021078697419], 
             UndirectedEdge[80, 210] -> 
             RGBColor[
              0.3231934350804644, 0.45057265819214215`, 0.941953091360874], 
             UndirectedEdge[229, 259] -> 
             RGBColor[
              0.40532480006275245`, 0.5251965784018511, 0.9471300119909675], 
             UndirectedEdge[97, 159] -> 
             RGBColor[
              0.2524370830607903, 0.3826577581053522, 0.9376872904818896], 
             UndirectedEdge[242, 280] -> 
             RGBColor[
              0.25424538211649345`, 0.38455839506567835`, 0.9377902704379731],
              UndirectedEdge[88, 99] -> 
             RGBColor[
              0.43585477652737337`, 0.5505550934269655, 0.9493751482779511], 
             UndirectedEdge[21, 46] -> 
             RGBColor[
              0.3377964064979223, 0.4654684905987692, 0.942801288807799], 
             UndirectedEdge[246, 256] -> 
             RGBColor[
              0.7970579460912328, 0.838735601938289, 0.8428569136112316], 
             UndirectedEdge[14, 135] -> 
             RGBColor[
              0.9063967184206538, 0.582821195587901, 0.4915857246054881], 
             UndirectedEdge[67, 179] -> 
             RGBColor[
              0.9529824528221467, 0.9622812994340826, 0.8732275826690652], 
             UndirectedEdge[66, 69] -> 
             RGBColor[
              0.9697469416824389, 0.9735523947961, 0.7295644287144893], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.7503642165832218, 0.805193848255281, 0.9757004322912739], 
             UndirectedEdge[116, 133] -> 
             RGBColor[
              0.3362774461822365, 0.4656883549123332, 0.9426482794056301], 
             UndirectedEdge[2, 83] -> 
             RGBColor[
              0.2235228930753953, 0.35226711116517256`, 0.9360406701369322], 
             UndirectedEdge[103, 168] -> 
             RGBColor[
              0.3323449528082868, 0.45951507499583777`, 0.9424990233881594], 
             UndirectedEdge[26, 199] -> 
             RGBColor[
              0.5823809948253185, 0.6469022092217233, 0.9089577047840149], 
             UndirectedEdge[91, 239] -> 
             RGBColor[
              0.3418733579527955, 0.46719445818593675`, 0.9431271687979139], 
             UndirectedEdge[13, 298] -> 
             RGBColor[
              0.2956902341413986, 0.428119562299244, 0.9401504934486273], 
             UndirectedEdge[229, 261] -> 
             RGBColor[
              0.3735150674883849, 0.49794171087045247`, 0.9450210277073223], 
             UndirectedEdge[141, 179] -> 
             RGBColor[
              0.9463245104461602, 0.8129581160989631, 0.4961968694388046], 
             UndirectedEdge[59, 195] -> 
             RGBColor[
              0.825976956508043, 0.20067584766155147`, 0.17250886892986522`], 
             UndirectedEdge[134, 253] -> 
             RGBColor[
              0.2853630721871043, 0.41726506030539445`, 0.9395623768529974], 
             UndirectedEdge[42, 292] -> 
             RGBColor[
              0.24874967528223313`, 0.3787820587349321, 0.9374772980639317], 
             UndirectedEdge[70, 238] -> 
             RGBColor[
              0.27137415800540265`, 0.40256182455203926`, 0.9387657288850935],
              UndirectedEdge[178, 202] -> 
             RGBColor[
              0.25258870101180897`, 0.3828171181850061, 0.9376959248999015], 
             UndirectedEdge[29, 191] -> 
             RGBColor[
              0.24335597488348387`, 0.37311293763548947`, 0.9371701348054876],
              UndirectedEdge[17, 38] -> 
             RGBColor[
              0.3570833446280458, 0.48255148540021425`, 0.944016408991876], 
             UndirectedEdge[40, 162] -> 
             RGBColor[
              0.2608696072714334, 0.3915208757036531, 0.9381675102608841], 
             UndirectedEdge[13, 95] -> 
             RGBColor[
              0.3973874477451902, 0.5174174988379855, 0.946816060198244], 
             UndirectedEdge[206, 270] -> 
             RGBColor[
              0.23246458235718154`, 0.361665393536175, 0.936549886113486], 
             UndirectedEdge[16, 295] -> 
             RGBColor[
              0.9153775706767935, 0.9307671307468549, 0.7575047799513781], 
             UndirectedEdge[37, 124] -> 
             RGBColor[
              0.8141982878176429, 0.8555000754915749, 0.971117336553347], 
             UndirectedEdge[22, 177] -> 
             RGBColor[
              0.6182933062719121, 0.6973901264603323, 0.9651824367082749], 
             UndirectedEdge[115, 204] -> 
             RGBColor[
              0.22623702836427392`, 0.35511983943990055`, 0.9361952361264305],
              UndirectedEdge[192, 200] -> 
             RGBColor[
              0.875491048752759, 0.5275157568382065, 0.21781901789668148`], 
             UndirectedEdge[13, 171] -> 
             RGBColor[
              0.3622408475068787, 0.48793453204456394`, 0.9443115057758112], 
             UndirectedEdge[39, 52] -> 
             RGBColor[
              0.8426203651830106, 0.3142479875093471, 0.1878844555501885], 
             UndirectedEdge[92, 216] -> 
             RGBColor[
              0.25996759819388404`, 0.3905728069724701, 0.9381161421783205], 
             UndirectedEdge[82, 127] -> 
             RGBColor[
              0.9139243851963341, 0.6223920448146217, 0.4422603075520308], 
             UndirectedEdge[53, 150] -> 
             RGBColor[
              0.8968677108265174, 0.6080372180241437, 0.5636073731303677], 
             UndirectedEdge[18, 66] -> 
             RGBColor[
              0.9464282973427488, 0.95956689239061, 0.9755670982476465], 
             UndirectedEdge[31, 36] -> 
             RGBColor[
              0.6892039970441424, 0.7567703364683878, 0.9699034319627848], 
             UndirectedEdge[71, 181] -> 
             RGBColor[
              0.6717068148993812, 0.7432662316253906, 0.9680467833618187], 
             UndirectedEdge[43, 143] -> 
             RGBColor[
              0.3594618944461463, 0.48576955871427996`, 0.9441255719478039], 
             UndirectedEdge[75, 185] -> 
             RGBColor[
              0.6492913495741017, 0.7248125960357876, 0.9664570141991338], 
             UndirectedEdge[46, 145] -> 
             RGBColor[
              0.280670988716232, 0.4123333830822331, 0.9392951696406466], 
             UndirectedEdge[62, 255] -> 
             RGBColor[
              0.9769015351320889, 0.9322978840038133, 0.4878701995815442], 
             UndirectedEdge[111, 242] -> 
             RGBColor[
              0.24172339249525976`, 0.3713969900337639, 0.9370771616536675], 
             UndirectedEdge[4, 193] -> 
             RGBColor[
              0.46955924674976174`, 0.5787870298978665, 0.9517883446566966], 
             UndirectedEdge[18, 258] -> 
             RGBColor[
              0.9540838776271092, 0.9652764116318238, 0.9626081977213435], 
             UndirectedEdge[81, 267] -> 
             RGBColor[
              0.3818442604921369, 0.5035684061042389, 0.9457044452357559], 
             UndirectedEdge[75, 124] -> 
             RGBColor[
              0.8391031020269322, 0.8749559056354701, 0.9735996156850079], 
             UndirectedEdge[72, 106] -> 
             RGBColor[
              0.6542381545327312, 0.7298150858058879, 0.966172003106812], 
             UndirectedEdge[262, 271] -> 
             RGBColor[
              0.9857223415414609, 0.9625888518240449, 0.4765328762826566], 
             UndirectedEdge[17, 235] -> 
             RGBColor[
              0.2691307812557516, 0.40020389334985473`, 0.9386379718979794], 
             UndirectedEdge[263, 279] -> 
             RGBColor[
              0.25988809011317837`, 0.3904892389385449, 0.938111614310746], 
             UndirectedEdge[3, 252] -> 
             RGBColor[
              0.33892810141516894`, 0.46722471408127325`, 0.9428449860179196],
              UndirectedEdge[48, 158] -> 
             RGBColor[
              0.4086574804982366, 0.5283803027105503, 0.9472602711890945], 
             UndirectedEdge[18, 36] -> 
             RGBColor[
              0.8529859949186596, 0.8858242206407632, 0.9761422011869598], 
             UndirectedEdge[105, 196] -> 
             RGBColor[
              0.28505137622914434`, 0.4169374480909134, 0.9395446262293043], 
             UndirectedEdge[269, 298] -> 
             RGBColor[
              0.2561386884802381, 0.3865483800965307, 0.9378980914344927], 
             UndirectedEdge[85, 207] -> 
             RGBColor[
              0.8326069689699811, 0.8699635257728993, 0.9837364200787462], 
             UndirectedEdge[79, 103] -> 
             RGBColor[
              0.33687382527310783`, 0.4634377566971172, 0.9427875991368931], 
             UndirectedEdge[76, 128] -> 
             RGBColor[
              0.2667781164198233, 0.397731093439728, 0.9385039911160289], 
             UndirectedEdge[10, 265] -> 
             RGBColor[
              0.21694931138635237`, 0.3453578600208368, 0.9356663143844839], 
             UndirectedEdge[88, 198] -> 
             RGBColor[
              0.48423825814620036`, 0.592165458504841, 0.9525401559859066], 
             UndirectedEdge[63, 143] -> 
             RGBColor[
              0.36063166824627285`, 0.4867827579854089, 0.9442001088999576], 
             UndirectedEdge[49, 242] -> 
             RGBColor[
              0.23849346114208345`, 0.3680021273920998, 0.9368932218413593], 
             UndirectedEdge[252, 253] -> 
             RGBColor[
              0.29862833529686444`, 0.43120769290001126`, 0.9403178139629], 
             UndirectedEdge[16, 125] -> 
             RGBColor[
              0.9930477640549809, 0.9875381952295093, 0.4846702054906215], 
             UndirectedEdge[59, 100] -> 
             RGBColor[
              0.8414952433239204, 0.3199562002850287, 0.1873691979101476], 
             UndirectedEdge[75, 295] -> 
             RGBColor[
              0.7838985892899054, 0.8312466386518764, 0.9790582353871675], 
             UndirectedEdge[94, 295] -> 
             RGBColor[
              0.8496169506590368, 0.8829255104904983, 0.9855184172875062], 
             UndirectedEdge[26, 192] -> 
             RGBColor[
              0.9254105636090766, 0.7341129135369036, 0.5467339360364043], 
             UndirectedEdge[132, 188] -> 
             RGBColor[
              0.20621351468350757`, 0.3340738569973212, 0.9350549266444448], 
             UndirectedEdge[186, 196] -> 
             RGBColor[
              0.255450766680841, 0.38582533066860314`, 0.9378589153057062], 
             UndirectedEdge[110, 179] -> 
             RGBColor[
              0.9932962755631108, 0.991495851914556, 0.7607615928093651], 
             UndirectedEdge[61, 177] -> 
             RGBColor[
              0.49302351294995017`, 0.5983715477396933, 0.9534876687205165], 
             UndirectedEdge[21, 264] -> 
             RGBColor[
              0.339057995027486, 0.46679450013267343`, 0.9428731344082046], 
             UndirectedEdge[200, 225] -> 
             RGBColor[
              0.9234794071043728, 0.7275983937614409, 0.2647165314935854], 
             UndirectedEdge[83, 197] -> 
             RGBColor[
              0.21339436331142053`, 0.34162138419735716`, 0.9354638653506908],
              UndirectedEdge[220, 226] -> 
             RGBColor[
              0.21805937466237113`, 0.3465246069060093, 0.9357295308458616], 
             UndirectedEdge[13, 140] -> 
             RGBColor[
              0.3171012005840623, 0.44883683866464263`, 0.941435247389312], 
             UndirectedEdge[144, 158] -> 
             RGBColor[
              0.35967077338482056`, 0.4859504791523989, 0.9441388815290719], 
             UndirectedEdge[62, 225] -> 
             RGBColor[
              0.9779057939111673, 0.9356854846768198, 0.49177155529990685`], 
             UndirectedEdge[65, 277] -> 
             RGBColor[
              0.318505826054183, 0.44836965030434695`, 0.9415864012075592], 
             UndirectedEdge[99, 261] -> 
             RGBColor[
              0.38406488890105717`, 0.5070794359286672, 0.9456932529988971], 
             UndirectedEdge[260, 290] -> 
             RGBColor[
              0.7310412488235707, 0.7895991808750945, 0.9740726900092733], 
             UndirectedEdge[72, 267] -> 
             RGBColor[
              0.5598273932891142, 0.6533873840765647, 0.9585897688439947], 
             UndirectedEdge[39, 170] -> 
             RGBColor[
              0.8447130757608642, 0.3303334780423518, 0.18988843756291957`], 
             UndirectedEdge[92, 163] -> 
             RGBColor[
              0.25122830224652154`, 0.3813872528284255, 0.937618452202748], 
             UndirectedEdge[102, 133] -> 
             RGBColor[
              0.36773492193593726`, 0.4929352393114849, 0.9446527219439024], 
             UndirectedEdge[184, 197] -> 
             RGBColor[
              0.22396867403815082`, 0.3527356552211741, 0.9360660567032872], 
             UndirectedEdge[44, 200] -> 
             RGBColor[
              0.9255256121005535, 0.7345007236853389, 0.2726656515103572], 
             UndirectedEdge[115, 132] -> 
             RGBColor[
              0.21415169536183348`, 0.34241738819996653`, 0.9355069942905895],
              UndirectedEdge[9, 283] -> 
             RGBColor[
              0.5677763920680372, 0.6599854789726345, 0.959116583898501], 
             UndirectedEdge[52, 165] -> 
             RGBColor[
              0.8989841919236675, 0.5410964430503309, 0.2712031000963182], 
             UndirectedEdge[160, 256] -> 
             RGBColor[
              0.7927339846129686, 0.8352252152179895, 0.8425165155244698], 
             UndirectedEdge[45, 215] -> 
             RGBColor[
              0.9264635101364236, 0.7188538247686493, 0.4669105670802081], 
             UndirectedEdge[16, 124] -> 
             RGBColor[
              0.9705820834138202, 0.9744763977304486, 0.7520461602492186], 
             UndirectedEdge[160, 246] -> 
             RGBColor[
              0.5945439555585024, 0.6817165928791875, 0.9612238245492863], 
             UndirectedEdge[57, 204] -> 
             RGBColor[
              0.23896784394150833`, 0.36850073379190207`, 0.9369202372400001],
              UndirectedEdge[112, 252] -> 
             RGBColor[
              0.27637236437381507`, 0.40781525634982796`, 0.9390503693435908],
              UndirectedEdge[5, 248] -> 
             RGBColor[
              0.21465495916745328`, 0.3429463503684412, 0.9355356544198075], 
             UndirectedEdge[186, 276] -> 
             RGBColor[
              0.2308753294209801, 0.3599949879357713, 0.9364593805098584], 
             UndirectedEdge[95, 154] -> 
             RGBColor[
              0.6149232954890904, 0.696747339779964, 0.9638633724984019], 
             UndirectedEdge[198, 290] -> 
             RGBColor[
              0.5385920372825843, 0.6362923050176035, 0.9568190845839761], 
             UndirectedEdge[77, 191] -> 
             RGBColor[
              0.24496070190330402`, 0.37479960747889, 0.9372615216352855], 
             UndirectedEdge[36, 224] -> 
             RGBColor[
              0.8645479914252601, 0.8604819797945611, 0.6563901597051076], 
             UndirectedEdge[29, 203] -> 
             RGBColor[
              0.25120844967144335`, 0.38136638651329235`, 0.9376173216279664],
              UndirectedEdge[25, 172] -> 
             RGBColor[
              0.2606528759791422, 0.3912930773738975, 0.9381551677344133], 
             UndirectedEdge[224, 260] -> 
             RGBColor[
              0.9093392465848947, 0.8957090172216551, 0.6607919677185569], 
             UndirectedEdge[45, 255] -> 
             RGBColor[
              0.9083890640548784, 0.6593350285611156, 0.24902560612370514`], 
             UndirectedEdge[102, 239] -> 
             RGBColor[
              0.398228532934502, 0.519347272504989, 0.9465957478722895], 
             UndirectedEdge[33, 239] -> 
             RGBColor[
              0.6628984653958889, 0.7326583838158534, 0.9695703125580974], 
             UndirectedEdge[64, 92] -> 
             RGBColor[
              0.24737632360791623`, 0.3773385790496996, 0.9373990877177711], 
             UndirectedEdge[32, 268] -> 
             RGBColor[
              0.2593869141835333, 0.38996247126009875`, 0.938083073082976], 
             UndirectedEdge[85, 240] -> 
             RGBColor[
              0.9572796113633043, 0.9651601387742601, 0.8410616153789832], 
             UndirectedEdge[1, 174] -> 
             RGBColor[
              0.4054230753198295, 0.5255788235109453, 0.9470541777511985], 
             UndirectedEdge[2, 184] -> 
             RGBColor[
              0.23409720380212556`, 0.3633813821889895, 0.9366428614895286], 
             UndirectedEdge[60, 85] -> 
             RGBColor[
              0.9228540566499766, 0.8416985659067688, 0.6257891591988634], 
             UndirectedEdge[121, 127] -> 
             RGBColor[
              0.9136911090272399, 0.6218930906767679, 0.41686963615976463`], 
             UndirectedEdge[132, 212] -> 
             RGBColor[
              0.20921642322248857`, 0.3372301042671883, 0.9352259378433346], 
             UndirectedEdge[172, 206] -> 
             RGBColor[
              0.2530845856194636, 0.3833383243485512, 0.9377241647947119], 
             UndirectedEdge[147, 148] -> 
             RGBColor[
              0.2325030525609364, 0.36170582815947316`, 0.9365520769346783], 
             UndirectedEdge[118, 226] -> 
             RGBColor[
              0.17892828959271728`, 0.30539535544371077`, 0.9335010734403975],
              UndirectedEdge[75, 283] -> 
             RGBColor[
              0.6746177643537297, 0.7453737204958732, 0.9684508023443001], 
             UndirectedEdge[188, 243] -> 
             RGBColor[
              0.21194079974675017`, 0.3400935967296356, 0.9353810870560375], 
             UndirectedEdge[88, 258] -> 
             RGBColor[
              0.7329940972360016, 0.7896974879262988, 0.9518579499321382], 
             UndirectedEdge[197, 293] -> 
             RGBColor[
              0.20988077542261582`, 0.33792838055188446`, 0.9352637717183109],
              UndirectedEdge[86, 179] -> 
             RGBColor[
              0.9842570845883489, 0.9592626733262417, 0.5559110076191691], 
             UndirectedEdge[41, 76] -> 
             RGBColor[
              0.32564319585170254`, 0.45514146543527656`, 0.9420195932129798],
              UndirectedEdge[175, 242] -> 
             RGBColor[
              0.2674717938620085, 0.3984601924131547, 0.9385434950201575], 
             UndirectedEdge[89, 285] -> 
             RGBColor[
              0.3304519019187142, 0.457812130049975, 0.9423807168287202], 
             UndirectedEdge[138, 171] -> 
             RGBColor[
              0.5625186052786886, 0.6537822219340037, 0.9596386929535714], 
             UndirectedEdge[181, 207] -> 
             RGBColor[
              0.729702675862836, 0.7887685434205706, 0.9736936013369495], 
             UndirectedEdge[17, 55] -> 
             RGBColor[
              0.28645859801019335`, 0.41841652740581015`, 0.939624765427937], 
             UndirectedEdge[142, 295] -> 
             RGBColor[
              0.7481542644116976, 0.8033229003900898, 0.9754955751330152], 
             UndirectedEdge[53, 200] -> 
             RGBColor[
              0.8588625397294595, 0.4100527991192301, 0.2023008600078583], 
             UndirectedEdge[33, 237] -> 
             RGBColor[
              0.7767209844121652, 0.8262100194866766, 0.9782143643357628], 
             UndirectedEdge[51, 67] -> 
             RGBColor[
              0.9529402270197467, 0.9622638379796367, 0.8739273734917072], 
             UndirectedEdge[47, 48] -> 
             RGBColor[
              0.5288713488786927, 0.6272983725157164, 0.9563690029663805], 
             UndirectedEdge[102, 237] -> 
             RGBColor[
              0.5120510519507784, 0.6128989081758123, 0.9552397996499549], 
             UndirectedEdge[150, 282] -> 
             RGBColor[
              0.9628316709480902, 0.9718005015674145, 0.9478004654188247], 
             UndirectedEdge[214, 293] -> 
             RGBColor[
              0.21107172389025777`, 0.33918014290187026`, 0.9353315944716927],
              UndirectedEdge[73, 245] -> 
             RGBColor[
              0.37670637299800835`, 0.5007058593032094, 0.9452243748724349], 
             UndirectedEdge[82, 192] -> 
             RGBColor[
              0.930031406620387, 0.7358466203284666, 0.4572790883268795], 
             UndirectedEdge[82, 266] -> 
             RGBColor[
              0.6213553148465931, 0.6847435984870042, 0.8214592367687926], 
             UndirectedEdge[30, 38] -> 
             RGBColor[
              0.4400713503236684, 0.5553482940395915, 0.949328558422408], 
             UndirectedEdge[146, 242] -> 
             RGBColor[
              0.23544148915831797`, 0.3647943113309621, 0.9367194165518717], 
             UndirectedEdge[25, 77] -> 
             RGBColor[
              0.24892138027318342`, 0.37896253156714604`, 0.9374870764091515],
              UndirectedEdge[68, 271] -> 
             RGBColor[
              0.9259155815977133, 0.7290271362933656, 0.2919182148886562], 
             UndirectedEdge[23, 267] -> 
             RGBColor[
              0.3821106817559689, 0.50384843174461, 0.9457196175325961], 
             UndirectedEdge[10, 161] -> 
             RGBColor[
              0.21385191803304957`, 0.3421023032204342, 0.935489922415196], 
             UndirectedEdge[223, 287] -> 
             RGBColor[
              0.9141648921008272, 0.6925393884549282, 0.24954185631357317`], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.43016772773719436`, 0.545286907400802, 0.949107366939159], 
             UndirectedEdge[218, 229] -> 
             RGBColor[
              0.3012157370951104, 0.430446886752895, 0.9405925945789568], 
             UndirectedEdge[62, 170] -> 
             RGBColor[
              0.9083710867000301, 0.580339218042234, 0.42464655483310587`], 
             UndirectedEdge[188, 294] -> 
             RGBColor[
              0.20780626806211017`, 0.3357479417846294, 0.9351456315930887], 
             UndirectedEdge[181, 299] -> 
             RGBColor[
              0.8541508128707371, 0.884172913273241, 0.8565895585797871], 
             UndirectedEdge[69, 109] -> 
             RGBColor[
              0.957103333757725, 0.9637481152069529, 0.737975761375697], 
             UndirectedEdge[48, 175] -> 
             RGBColor[
              0.3540970438547585, 0.4798066886867111, 0.9438319175031515], 
             UndirectedEdge[248, 270] -> 
             RGBColor[
              0.21830317142063266`, 0.3467808527565494, 0.9357434147105796], 
             UndirectedEdge[85, 232] -> 
             RGBColor[
              0.9568611020652522, 0.9642649897035074, 0.7955094610260169], 
             UndirectedEdge[65, 152] -> 
             RGBColor[
              0.270606352963235, 0.4017548127710696, 0.9387220035238077], 
             UndirectedEdge[43, 63] -> 
             RGBColor[
              0.3233435154432426, 0.45448563418447746`, 0.9418241407759673], 
             UndirectedEdge[184, 293] -> 
             RGBColor[
              0.22334920945949943`, 0.35208455867268873`, 0.9360307791119489],
              UndirectedEdge[24, 260] -> 
             RGBColor[
              0.9023952825645615, 0.924495379134781, 0.9727268847769307], 
             UndirectedEdge[201, 229] -> 
             RGBColor[
              0.3337508945428317, 0.46349998287045846`, 0.9424872897693092], 
             UndirectedEdge[17, 48] -> 
             RGBColor[
              0.35495264897954515`, 0.4807059839213601, 0.9438806429492537], 
             UndirectedEdge[153, 163] -> 
             RGBColor[
              0.2574205034515923, 0.3878956489031873, 0.9379710889008359], 
             UndirectedEdge[33, 200] -> 
             RGBColor[
              0.9003293088366926, 0.7550036483702731, 0.6091535540920102], 
             UndirectedEdge[33, 282] -> 
             RGBColor[
              0.9391598487497231, 0.9536036259867218, 0.9690629330997416], 
             UndirectedEdge[150, 237] -> 
             RGBColor[
              0.8003928066105324, 0.8444068950673695, 0.956951896654846], 
             UndirectedEdge[172, 203] -> 
             RGBColor[
              0.26454467239722235`, 0.39538360216344437`, 0.9383767997830261],
              UndirectedEdge[56, 93] -> 
             RGBColor[
              0.5394509250519448, 0.6369895888012234, 0.9568866993753897], 
             UndirectedEdge[122, 299] -> 
             RGBColor[
              0.8093386473760087, 0.8488870251734923, 0.8523133648913199], 
             UndirectedEdge[44, 100] -> 
             RGBColor[
              0.9076177976951124, 0.6402494666473935, 0.25721638876551267`], 
             UndirectedEdge[31, 171] -> 
             RGBColor[
              0.5185950159671473, 0.6191084488745244, 0.955507160509088], 
             UndirectedEdge[136, 256] -> 
             RGBColor[
              0.9940778224627702, 0.9897413860088904, 0.596785706394875], 
             UndirectedEdge[146, 159] -> 
             RGBColor[
              0.2389221548438223, 0.3684527116533779, 0.9369176353134778], 
             UndirectedEdge[65, 133] -> 
             RGBColor[
              0.3190318248130566, 0.44882524399181684`, 0.9416199173833522], 
             UndirectedEdge[58, 245] -> 
             RGBColor[
              0.48666290222101594`, 0.5933487734884098, 0.952947963928872], 
             UndirectedEdge[172, 272] -> 
             RGBColor[
              0.2463878565667746, 0.37629963751702955`, 0.937342795982084], 
             UndirectedEdge[99, 218] -> 
             RGBColor[
              0.3117655585077827, 0.43958461181110975`, 0.9412648198705315], 
             UndirectedEdge[18, 113] -> 
             RGBColor[
              0.9529050044310041, 0.9643972099323963, 0.9646037225429771], 
             UndirectedEdge[43, 131] -> 
             RGBColor[
              0.3235024771639835, 0.45462331883733487`, 0.9418342696762487], 
             UndirectedEdge[2, 156] -> 
             RGBColor[
              0.2292281520802934, 0.3582637001136342, 0.9363655761970868], 
             UndirectedEdge[165, 232] -> 
             RGBColor[
              0.9871784526525289, 0.9674285696046385, 0.48831934332178484`], 
             UndirectedEdge[173, 186] -> 
             RGBColor[
              0.24357136840210497`, 0.3733393298802981, 0.937182401147727], 
             UndirectedEdge[39, 281] -> 
             RGBColor[
              0.8518045532150162, 0.3848416812601996, 0.19667924438169382`], 
             UndirectedEdge[77, 91] -> 
             RGBColor[
              0.25932242623621204`, 0.38989469033869195`, 0.9380794005897775],
              UndirectedEdge[15, 19] -> 
             RGBColor[
              0.265094966907718, 0.3959619965846625, 0.938408138241311], 
             UndirectedEdge[119, 241] -> 
             RGBColor[
              0.2806500707405608, 0.4123113969635265, 0.9392939783928775], 
             UndirectedEdge[103, 116] -> 
             RGBColor[
              0.3006123597209014, 0.43202989779004775`, 0.9404770506166615], 
             UndirectedEdge[99, 257] -> 
             RGBColor[
              0.37939685727732686`, 0.5030362215582833, 0.9453958101516111], 
             UndirectedEdge[17, 253] -> 
             RGBColor[
              0.2964738820674033, 0.42894322595562323`, 0.9401951210387102], 
             UndirectedEdge[204, 292] -> 
             RGBColor[
              0.2369721103072519, 0.36640309120547765`, 0.9368065831619525], 
             UndirectedEdge[65, 241] -> 
             RGBColor[
              0.2834960053804121, 0.4153026547126882, 0.9394560501604341], 
             UndirectedEdge[71, 256] -> 
             RGBColor[
              0.8124222635893662, 0.8512090470378892, 0.8440664489660341], 
             UndirectedEdge[37, 102] -> 
             RGBColor[
              0.5330127818666326, 0.6293292071697167, 0.9572915771331396], 
             UndirectedEdge[61, 217] -> 
             RGBColor[
              0.686937545269946, 0.7542032342825437, 0.9702221270801157], 
             UndirectedEdge[35, 184] -> 
             RGBColor[
              0.23183414268000563`, 0.3610027614632789, 0.9365139835065228], 
             UndirectedEdge[164, 241] -> 
             RGBColor[
              0.33149984085228634`, 0.458806984736167, 0.9424442983869149], 
             UndirectedEdge[192, 255] -> 
             RGBColor[
              0.9119702371400515, 0.6765104448805886, 0.25204962038332024`], 
             UndirectedEdge[112, 134] -> 
             RGBColor[
              0.2631071012640549, 0.3938726237552112, 0.9382949322336882], 
             UndirectedEdge[44, 195] -> 
             RGBColor[
              0.892099510879235, 0.5209691140239162, 0.24235605978523028`], 
             UndirectedEdge[127, 281] -> 
             RGBColor[
              0.8344242447380918, 0.2656054066230123, 0.18059800167880746`], 
             UndirectedEdge[59, 192] -> 
             RGBColor[
              0.8488981465441187, 0.3665071091151284, 0.1940529052630896], 
             UndirectedEdge[108, 264] -> 
             RGBColor[
              0.3192908615453144, 0.4496732026354332, 0.9416135901421105], 
             UndirectedEdge[136, 296] -> 
             RGBColor[
              0.8445716246365338, 0.8749311705589841, 0.7198898610709794], 
             UndirectedEdge[118, 130] -> 
             RGBColor[
              0.17892828448197629`, 0.3053953500719979, 0.9335010731493483], 
             UndirectedEdge[85, 136] -> 
             RGBColor[
              0.9562666668799304, 0.9629935529487204, 0.7308088595324563], 
             UndirectedEdge[104, 157] -> 
             RGBColor[
              0.3155261405863954, 0.44552577951204275`, 0.9414061686253012], 
             UndirectedEdge[158, 217] -> 
             RGBColor[
              0.6053338779034495, 0.6866046110497097, 0.9641707450092601], 
             UndirectedEdge[11, 174] -> 
             RGBColor[
              0.36791464439567134`, 0.49309090587299315`, 0.9446641737001142],
              UndirectedEdge[39, 220] -> 
             RGBColor[
              0.5623622253882596, 0.4395170049728193, 0.5745682237352395], 
             UndirectedEdge[32, 208] -> 
             RGBColor[
              0.27110861374646283`, 0.402282720699415, 0.9387506065323843], 
             UndirectedEdge[27, 103] -> 
             RGBColor[
              0.2686276829189324, 0.3996751050995809, 0.9386093211919647], 
             UndirectedEdge[212, 250] -> 
             RGBColor[
              0.21715203202826977`, 0.34557093226872304`, 0.9356778590251427],
              UndirectedEdge[129, 298] -> 
             RGBColor[
              0.26058075662513375`, 0.3912172753602034, 0.9381510606438935], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.9138967980085537, 0.6275576288296454, 0.4676443834469852], 
             UndirectedEdge[261, 290] -> 
             RGBColor[
              0.5067850511563949, 0.6090396671765619, 0.9547103165107921], 
             UndirectedEdge[24, 113] -> 
             RGBColor[
              0.9575230369172714, 0.9678413309993203, 0.9567865981194988], 
             UndirectedEdge[15, 243] -> 
             RGBColor[
              0.2285446981366219, 0.35754534668535254`, 0.9363266545060742], 
             UndirectedEdge[246, 296] -> 
             RGBColor[
              0.6475517482649964, 0.7239253864883827, 0.965961068287336], 
             UndirectedEdge[131, 174] -> 
             RGBColor[
              0.3585773503848271, 0.4850034111068425, 0.9440692095823882], 
             UndirectedEdge[44, 121] -> 
             RGBColor[
              0.9798326937990873, 0.9423326330377451, 0.48673505054828914`], 
             UndirectedEdge[155, 293] -> 
             RGBColor[
              0.21078204772465953`, 0.3388756748852968, 0.9353150978425994], 
             UndirectedEdge[105, 140] -> 
             RGBColor[
              0.3086221728107845, 0.4399248428735164, 0.9409523793012212], 
             UndirectedEdge[51, 138] -> 
             RGBColor[
              0.8501230130531416, 0.8811959449639274, 0.8638775606265587], 
             UndirectedEdge[133, 277] -> 
             RGBColor[
              0.3496210523003913, 0.4772459158627348, 0.9434985221881913], 
             UndirectedEdge[201, 261] -> 
             RGBColor[
              0.36087721144814144`, 0.48699543516550725`, 0.9442157546956553],
              UndirectedEdge[19, 57] -> 
             RGBColor[
              0.2691600647734066, 0.40023467218359243`, 0.9386396395509886], 
             UndirectedEdge[104, 261] -> 
             RGBColor[
              0.34285661416014696`, 0.46919806205208336`, 0.9431476422340319],
              UndirectedEdge[15, 111] -> 
             RGBColor[
              0.2409685800879815, 0.3706036343358437, 0.9370341762037178], 
             UndirectedEdge[71, 85] -> 
             RGBColor[
              0.7746111080065263, 0.8244612139777192, 0.9780896021036154], 
             UndirectedEdge[84, 158] -> 
             RGBColor[
              0.35212502014478775`, 0.47866323634096297`, 0.943685588557766], 
             UndirectedEdge[65, 162] -> 
             RGBColor[
              0.28622167127698683`, 0.41816750238718753`, 0.9396112728009827],
              UndirectedEdge[156, 268] -> 
             RGBColor[
              0.2451076812596908, 0.374954092101482, 0.9372698918921952], 
             UndirectedEdge[48, 252] -> 
             RGBColor[
              0.35710710220900627`, 0.48297045086574814`, 0.9440033358734436],
              UndirectedEdge[204, 235] -> 
             RGBColor[
              0.23646094075205434`, 0.36586581959294334`, 0.9367774728119916],
              UndirectedEdge[62, 130] -> 
             RGBColor[
              0.5868878667757954, 0.648392143438405, 0.8070978104506135], 
             UndirectedEdge[142, 283] -> 
             RGBColor[
              0.6388734394755219, 0.7174499822340865, 0.964888142090148], 
             UndirectedEdge[99, 259] -> 
             RGBColor[
              0.41587462147542475`, 0.5343343034600658, 0.9478022372825421], 
             UndirectedEdge[43, 244] -> 
             RGBColor[
              0.28234247424873604`, 0.412848733894419, 0.9394358151698824], 
             UndirectedEdge[36, 154] -> 
             RGBColor[
              0.750385676327774, 0.8049262605804057, 0.9757550895296658], 
             UndirectedEdge[11, 185] -> 
             RGBColor[
              0.4557880502577546, 0.5660866394053694, 0.9511242925783112], 
             UndirectedEdge[20, 150] -> 
             RGBColor[
              0.9139560790389594, 0.9335493921357441, 0.968134833574319], 
             UndirectedEdge[175, 252] -> 
             RGBColor[
              0.2975212413691305, 0.4300440669881537, 0.9402547666015143], 
             UndirectedEdge[97, 292] -> 
             RGBColor[
              0.25027096919944, 0.3803810350975218, 0.937563933501964], 
             UndirectedEdge[176, 226] -> 
             RGBColor[
              0.17893944427006758`, 0.3054070797168533, 0.9335017086827707], 
             UndirectedEdge[80, 103] -> 
             RGBColor[
              0.2733233300214085, 0.4046105279255051, 0.9388767313478634], 
             UndirectedEdge[137, 220] -> 
             RGBColor[
              0.5513789728038629, 0.36945130513336594`, 0.564612808979479], 
             UndirectedEdge[20, 167] -> 
             RGBColor[
              0.8099161582263048, 0.8518030947538164, 0.981590034710579], 
             UndirectedEdge[240, 256] -> 
             RGBColor[
              0.9950907669461442, 0.9919079718344301, 0.7070384622414018], 
             UndirectedEdge[113, 278] -> 
             RGBColor[
              0.7811703997408805, 0.8288870412862575, 0.957738894978919], 
             UndirectedEdge[181, 240] -> 
             RGBColor[
              0.8543753182561593, 0.8839651564219314, 0.8310187966371865], 
             UndirectedEdge[7, 151] -> 
             RGBColor[
              0.4190101469832575, 0.5373472620797284, 0.9479199339430164], 
             UndirectedEdge[6, 101] -> 
             RGBColor[
              0.4261316567977976, 0.5406988809357904, 0.9490838670731377], 
             UndirectedEdge[65, 116] -> 
             RGBColor[
              0.3051622199360282, 0.4368120893539453, 0.940736158424998], 
             UndirectedEdge[50, 264] -> 
             RGBColor[
              0.32355517598609507`, 0.45336673747336176`, 0.9418853084874919],
              UndirectedEdge[55, 235] -> 
             RGBColor[
              0.25936698600148883`, 0.38994152547725025`, 0.9380819382024896],
              UndirectedEdge[100, 232] -> 
             RGBColor[
              0.9221384356388024, 0.6882475061102127, 0.3972545294946756], 
             UndirectedEdge[28, 163] -> 
             RGBColor[
              0.23238600045450547`, 0.3615827989740821, 0.9365454109903801], 
             UndirectedEdge[11, 63] -> 
             RGBColor[
              0.3340095449749544, 0.46372401287461446`, 0.9425037707461285], 
             UndirectedEdge[234, 274] -> 
             RGBColor[
              0.8909472265976595, 0.513146913463993, 0.24055037716924876`], 
             UndirectedEdge[148, 270] -> 
             RGBColor[
              0.23353444010566207`, 0.3627898818627272, 0.9366108129295494], 
             UndirectedEdge[96, 245] -> 
             RGBColor[
              0.41493426639987385`, 0.5338169391781161, 0.9476602224364029], 
             UndirectedEdge[159, 235] -> 
             RGBColor[
              0.24471645266359499`, 0.3745428860416596, 0.9372476120024185], 
             UndirectedEdge[53, 287] -> 
             RGBColor[
              0.8863520651509298, 0.5242910551950881, 0.22469122939407754`], 
             UndirectedEdge[105, 289] -> 
             RGBColor[
              0.2900768000973668, 0.42221948720669167`, 0.9398308166841512], 
             UndirectedEdge[56, 164] -> 
             RGBColor[
              0.46580833431938506`, 0.5753190136054342, 0.9516098956299331], 
             UndirectedEdge[112, 235] -> 
             RGBColor[
              0.24712629913564943`, 0.3770757874768801, 0.9373848491939536], 
             UndirectedEdge[7, 43] -> 
             RGBColor[
              0.3584602463932565, 0.4849019815151618, 0.9440617478195963], 
             UndirectedEdge[242, 243] -> 
             RGBColor[
              0.22929951054390013`, 0.35833870238327276`, 0.9363696399560237],
              UndirectedEdge[151, 286] -> 
             RGBColor[
              0.5011547059099458, 0.6056262623148936, 0.953947236987697], 
             UndirectedEdge[126, 163] -> 
             RGBColor[
              0.23364896427549098`, 0.3629102540264691, 0.9366173349115978], 
             UndirectedEdge[31, 138] -> 
             RGBColor[
              0.662760313991049, 0.7361123302878763, 0.9672677727663206], 
             UndirectedEdge[95, 138] -> 
             RGBColor[
              0.5976652055170001, 0.6832651887274253, 0.9621432473760043], 
             UndirectedEdge[197, 275] -> 
             RGBColor[
              0.21163940728530467`, 0.33977681414327066`, 0.9353639232012283],
              UndirectedEdge[198, 245] -> 
             RGBColor[
              0.4443289893270455, 0.5589801958800422, 0.949615283231626], 
             UndirectedEdge[187, 264] -> 
             RGBColor[
              0.3292953995025846, 0.4583386305713222, 0.9422510704540822], 
             UndirectedEdge[62, 195] -> 
             RGBColor[
              0.9069962455234778, 0.5697715863000085, 0.4233300053697785], 
             UndirectedEdge[169, 187] -> 
             RGBColor[
              0.3284772756829356, 0.4574787305648249, 0.9422044795128589], 
             UndirectedEdge[82, 199] -> 
             RGBColor[
              0.587001837836629, 0.6486359160132862, 0.81950285707449], 
             UndirectedEdge[126, 155] -> 
             RGBColor[
              0.21912067898952223`, 0.3476401050444259, 0.9357899705572339], 
             UndirectedEdge[82, 220] -> 
             RGBColor[
              0.6261342073882591, 0.6897665175475827, 0.8217313876293025], 
             UndirectedEdge[32, 202] -> 
             RGBColor[
              0.24218926046257408`, 0.37188664680514644`, 0.937103692145216], 
             UndirectedEdge[113, 260] -> 
             RGBColor[
              0.9042815340807562, 0.9259021424271057, 0.969533952973199], 
             UndirectedEdge[105, 230] -> 
             RGBColor[
              0.2692612582166467, 0.40034103290847267`, 0.938645402367879], 
             UndirectedEdge[245, 289] -> 
             RGBColor[
              0.3576929449951681, 0.48259509766982983`, 0.944072988186208], 
             UndirectedEdge[108, 187] -> 
             RGBColor[
              0.35392495764506043`, 0.4809737423517148, 0.9437727632309596], 
             UndirectedEdge[137, 228] -> 
             RGBColor[
              0.8309547247116273, 0.6038501100477591, 0.5867983401041436], 
             UndirectedEdge[88, 261] -> 
             RGBColor[
              0.4524312720200109, 0.5649128206637994, 0.9504313879127225], 
             UndirectedEdge[192, 228] -> 
             RGBColor[
              0.8406646902431527, 0.6681341107638701, 0.5956912929318666], 
             UndirectedEdge[42, 97] -> 
             RGBColor[
              0.25595913612423093`, 0.3863596591860904, 0.937887866193442], 
             UndirectedEdge[121, 240] -> 
             RGBColor[
              0.9947718410408293, 0.9912258215713169, 0.6723253456304181], 
             UndirectedEdge[25, 43] -> 
             RGBColor[
              0.2869920462831278, 0.4177357289024586, 0.9397006014188156], 
             UndirectedEdge[77, 270] -> 
             RGBColor[
              0.23714390206690406`, 0.36658365523709874`, 0.9368163664485216],
              UndirectedEdge[225, 255] -> 
             RGBColor[
              0.9599585954916654, 0.876593081803823, 0.2989471339802242], 
             UndirectedEdge[2, 275] -> 
             RGBColor[
              0.2217679370492794, 0.35042254111108606`, 0.9359407279874696], 
             UndirectedEdge[235, 253] -> 
             RGBColor[
              0.2693822700586988, 0.40046822402706334`, 0.9386522938132629], 
             UndirectedEdge[73, 95] -> 
             RGBColor[
              0.4088283158597046, 0.5275690199007069, 0.9475362008014293], 
             UndirectedEdge[49, 175] -> 
             RGBColor[
              0.26553285029495766`, 0.3964222397880617, 0.9384330750524239], 
             UndirectedEdge[153, 219] -> 
             RGBColor[
              0.2738583241419696, 0.40517284066680126`, 0.9389071984715764], 
             UndirectedEdge[54, 167] -> 
             RGBColor[
              0.585666437251012, 0.671825268631737, 0.9619628736506332], 
             UndirectedEdge[56, 246] -> 
             RGBColor[
              0.57328015808247, 0.6644536841649844, 0.9595498605201163], 
             UndirectedEdge[192, 225] -> 
             RGBColor[
              0.91297449591913, 0.6798980455535951, 0.25595097610168294`], 
             UndirectedEdge[84, 252] -> 
             RGBColor[
              0.30057464185555743`, 0.4332533844961608, 0.9404286532421151], 
             UndirectedEdge[119, 164] -> 
             RGBColor[
              0.33307449939887124`, 0.46046205070774604`, 0.9425339728616443],
              UndirectedEdge[93, 168] -> 
             RGBColor[
              0.4585412392278475, 0.5694721717790032, 0.9510231831684333], 
             UndirectedEdge[111, 250] -> 
             RGBColor[
              0.2327988220725642, 0.3620167006690641, 0.9365689205708136], 
             UndirectedEdge[54, 286] -> 
             RGBColor[
              0.4882211414959945, 0.5944238588793778, 0.953123121699942], 
             UndirectedEdge[74, 257] -> 
             RGBColor[
              0.5147596974188978, 0.6152603482603705, 0.9554081515783656], 
             UndirectedEdge[220, 236] -> 
             RGBColor[
              0.4402011946832155, 0.5463223550644548, 0.9507193164378127], 
             UndirectedEdge[130, 228] -> 
             RGBColor[
              0.49763512145939465`, 0.5809234064486897, 0.9579150616794772], 
             UndirectedEdge[1, 142] -> 
             RGBColor[
              0.5387732060688373, 0.6352393283002062, 0.9572689291818902], 
             UndirectedEdge[101, 114] -> 
             RGBColor[
              0.4255007228362041, 0.540035729338632, 0.9490479363174081], 
             UndirectedEdge[199, 266] -> 
             RGBColor[
              0.21328047700996416`, 0.3415016824737179, 0.9354573796943026], 
             UndirectedEdge[93, 277] -> 
             RGBColor[
              0.440152252258617, 0.5535445555236148, 0.9498514531794966], 
             UndirectedEdge[19, 112] -> 
             RGBColor[
              0.271740291472555, 0.402946654040219, 0.9387865796444018], 
             UndirectedEdge[77, 203] -> 
             RGBColor[
              0.25281317669126346`, 0.38305305635669296`, 0.9377087084577643],
              UndirectedEdge[26, 60] -> 
             RGBColor[
              0.9559587194852852, 0.8665294960501166, 0.5718984085520893], 
             UndirectedEdge[186, 263] -> 
             RGBColor[
              0.24547633917610456`, 0.3753415749458948, 0.9372908864151546], 
             UndirectedEdge[167, 283] -> 
             RGBColor[
              0.6863247949375169, 0.7545193417646557, 0.9696176497444712], 
             UndirectedEdge[170, 200] -> 
             RGBColor[
              0.8539446998932355, 0.37225212712685507`, 0.1975915310267845], 
             UndirectedEdge[17, 292] -> 
             RGBColor[
              0.26964195081094916`, 0.4007411649623891, 0.9386670822479402], 
             UndirectedEdge[106, 215] -> 
             RGBColor[
              0.8258859987463416, 0.8619784867738793, 0.84861498208911], 
             UndirectedEdge[123, 229] -> 
             RGBColor[
              0.3913046976868122, 0.5133501944155183, 0.9461545672128138], 
             UndirectedEdge[105, 149] -> 
             RGBColor[
              0.29155965067616113`, 0.4237780571831614, 0.9399152628309327], 
             UndirectedEdge[68, 274] -> 
             RGBColor[
              0.9194708353599413, 0.7072874939349834, 0.2668815927431183], 
             UndirectedEdge[149, 171] -> 
             RGBColor[
              0.3561511381973472, 0.48153386145037547`, 0.943964705839551], 
             UndirectedEdge[29, 172] -> 
             RGBColor[
              0.256159178309366, 0.3865699162060744, 0.9378992582999495], 
             UndirectedEdge[76, 209] -> 
             RGBColor[
              0.2797259704782522, 0.4113401089964994, 0.9392413522500229], 
             UndirectedEdge[247, 267] -> 
             RGBColor[
              0.5234677465828359, 0.6240137244860162, 0.9556284450179895], 
             UndirectedEdge[164, 210] -> 
             RGBColor[
              0.3812406788826516, 0.5046332471596473, 0.9455132968338751], 
             UndirectedEdge[258, 260] -> 
             RGBColor[
              0.9054604072768613, 0.9267813441265331, 0.9675384281515653], 
             UndirectedEdge[62, 137] -> 
             RGBColor[
              0.9202074700280282, 0.6713188470374746, 0.43598108887527987`], 
             UndirectedEdge[175, 280] -> 
             RGBColor[
              0.2812847712693677, 0.4129785074616403, 0.9393301236490378], 
             UndirectedEdge[72, 194] -> 
             RGBColor[
              0.5838203648230471, 0.6728659592388615, 0.9604785834522965], 
             UndirectedEdge[3, 257] -> 
             RGBColor[
              0.38431511212659675`, 0.5072961667100446, 0.9457091970015647], 
             UndirectedEdge[154, 171] -> 
             RGBColor[
              0.5797766952507789, 0.6672643729865424, 0.9613588180759691], 
             UndirectedEdge[168, 277] -> 
             RGBColor[
              0.3674840405107483, 0.49271793843065337`, 0.944636736001335], 
             UndirectedEdge[146, 243] -> 
             RGBColor[
              0.22430859499308387`, 0.3530929336970421, 0.9360854146988027], 
             UndirectedEdge[98, 122] -> 
             RGBColor[
              0.5234999711581451, 0.6232114459734905, 0.9558598822602524], 
             UndirectedEdge[142, 210] -> 
             RGBColor[
              0.5187904189187625, 0.6179312424348968, 0.9559956436547723], 
             UndirectedEdge[3, 38] -> 
             RGBColor[
              0.3976345995492975, 0.5188328372586848, 0.9465579029621789], 
             UndirectedEdge[21, 205] -> 
             RGBColor[
              0.4564507498978377, 0.5677093547420913, 0.9508767552454336], 
             UndirectedEdge[153, 221] -> 
             RGBColor[
              0.2840475061144973, 0.4158823169513779, 0.939487457311368], 
             UndirectedEdge[55, 159] -> 
             RGBColor[
              0.26204426941803677`, 0.39275552009761494`, 0.9382344055323761],
              UndirectedEdge[149, 298] -> 
             RGBColor[
              0.28960052483186716`, 0.4217188917050555, 0.9398036935123671], 
             UndirectedEdge[22, 247] -> 
             RGBColor[
              0.6982336123573278, 0.7632154445962727, 0.9712197251392987], 
             UndirectedEdge[105, 298] -> 
             RGBColor[
              0.2872112063681208, 0.41920756650811786`, 0.9396676253605367], 
             UndirectedEdge[169, 219] -> 
             RGBColor[
              0.2836300261607937, 0.41544351905027754`, 0.9394636824456108], 
             UndirectedEdge[53, 225] -> 
             RGBColor[
              0.8963459868958306, 0.5624350878346187, 0.24043281821285972`], 
             UndirectedEdge[47, 90] -> 
             RGBColor[
              0.5238031310544717, 0.622908536972411, 0.9560460606082701], 
             UndirectedEdge[100, 137] -> 
             RGBColor[
              0.8478732688157926, 0.3689804990841502, 0.19347680232411396`], 
             UndirectedEdge[15, 175] -> 
             RGBColor[
              0.2667169814547302, 0.3976668367152345, 0.9385005095702079], 
             UndirectedEdge[49, 253] -> 
             RGBColor[
              0.2666399442226916, 0.39758586569991927`, 0.9384961224138098], 
             UndirectedEdge[166, 291] -> 
             RGBColor[
              0.9053156340255587, 0.5627492600761606, 0.30706567418331665`], 
             UndirectedEdge[161, 230] -> 
             RGBColor[
              0.2328116110999559, 0.36203014274772405`, 0.9365696488870041], 
             UndirectedEdge[263, 269] -> 
             RGBColor[
              0.24400443083652518`, 0.3737945059566179, 0.9372070634127088], 
             UndirectedEdge[122, 160] -> 
             RGBColor[
              0.6072063704282553, 0.6919965117057422, 0.9622206562317872], 
             UndirectedEdge[196, 289] -> 
             RGBColor[
              0.28595784411409636`, 0.4178902033113814, 0.9395962482343534], 
             UndirectedEdge[30, 158] -> 
             RGBColor[
              0.4329152304787701, 0.5491500227069821, 0.9488725767937995], 
             UndirectedEdge[114, 187] -> 
             RGBColor[
              0.33417034239985266`, 0.4634625046455827, 0.9425286912402498], 
             UndirectedEdge[49, 159] -> 
             RGBColor[
              0.24197412682758776`, 0.3716605277145155, 0.9370914406029653], 
             UndirectedEdge[33, 94] -> 
             RGBColor[
              0.8883058899064401, 0.9137750204630982, 0.9892086028509474], 
             UndirectedEdge[193, 220] -> 
             RGBColor[
              0.3283447463388828, 0.4540509053495343, 0.9423173412993839], 
             UndirectedEdge[60, 127] -> 
             RGBColor[
              0.879427272019672, 0.4987774156297289, 0.21919915424561515`], 
             UndirectedEdge[282, 297] -> 
             RGBColor[
              0.8620280342318183, 0.892582413918251, 0.9615782291090177], 
             UndirectedEdge[97, 235] -> 
             RGBColor[
              0.24975979964424241`, 0.3798437634849875, 0.9375348231520031], 
             UndirectedEdge[50, 187] -> 
             RGBColor[
              0.35818927208584117`, 0.4846672771896433, 0.9440444815763409], 
             UndirectedEdge[271, 274] -> 
             RGBColor[
              0.9710201994330907, 0.9139064692863681, 0.34191937648403536`], 
             UndirectedEdge[137, 170] -> 
             RGBColor[
              0.8337298231764674, 0.2602677782028984, 0.17993302280715895`], 
             UndirectedEdge[84, 253] -> 
             RGBColor[
              0.29867167742904355`, 0.43125324822898137`, 0.9403202822332086],
              UndirectedEdge[33, 185] -> 
             RGBColor[
              0.7413664787721765, 0.7975076391058051, 0.9754311281439616], 
             UndirectedEdge[3, 144] -> 
             RGBColor[
              0.34651719678738085`, 0.4745575122216793, 0.9433007472595341], 
             UndirectedEdge[11, 43] -> 
             RGBColor[
              0.3328397711748278, 0.46271081360348554`, 0.9424292337939748], 
             UndirectedEdge[29, 272] -> 
             RGBColor[
              0.23305163384099561`, 0.36228242186687754`, 0.9365833178270244],
              UndirectedEdge[70, 251] -> 
             RGBColor[
              0.27547374372817707`, 0.40687074907542276`, 0.9389991942272118],
              UndirectedEdge[99, 123] -> 
             RGBColor[
              0.40185451909948444`, 0.5224879194737331, 0.9468267925043885], 
             UndirectedEdge[133, 239] -> 
             RGBColor[
              0.38064066205782954`, 0.5041135427437089, 0.9454750642923715], 
             UndirectedEdge[259, 260] -> 
             RGBColor[
              0.656707314635238, 0.7292515443954324, 0.9682208504157948], 
             UndirectedEdge[125, 192] -> 
             RGBColor[
              0.9288056517822338, 0.7332248546724817, 0.32386323867590994`], 
             UndirectedEdge[213, 264] -> 
             RGBColor[
              0.36127001361165895`, 0.48603343422176903`, 0.9442884645910713],
              UndirectedEdge[134, 204] -> 
             RGBColor[
              0.25244174288045984`, 0.38266265587127446`, 0.9376875558517261],
              UndirectedEdge[94, 142] -> 
             RGBColor[
              0.7604864358301577, 0.8131562391312941, 0.9766718286519673], 
             UndirectedEdge[134, 175] -> 
             RGBColor[
              0.2842559782593704, 0.41610143439353686`, 0.9394993294916116], 
             UndirectedEdge[8, 267] -> 
             RGBColor[
              0.5598482664107077, 0.6534036903177951, 0.9585918492816847], 
             UndirectedEdge[195, 225] -> 
             RGBColor[
              0.8900533058830544, 0.5140667841000182, 0.23440693976845853`], 
             UndirectedEdge[51, 281] -> 
             RGBColor[
              0.9148192587802333, 0.6349551711119263, 0.4692679592224235], 
             UndirectedEdge[49, 243] -> 
             RGBColor[
              0.2273605669768493, 0.3563007497581797, 0.9362592199882902], 
             UndirectedEdge[212, 243] -> 
             RGBColor[
              0.2149437082857312, 0.34324984399950276`, 0.9355520982549272], 
             UndirectedEdge[22, 285] -> 
             RGBColor[
              0.6000751622710249, 0.6816104857973055, 0.9640215926822105], 
             UndirectedEdge[20, 33] -> 
             RGBColor[
              0.8902842568405922, 0.9153525165550513, 0.9893973012552358], 
             UndirectedEdge[9, 174] -> 
             RGBColor[
              0.4545765714263261, 0.5664286209801727, 0.9506626768751375], 
             UndirectedEdge[180, 250] -> 
             RGBColor[
              0.22830469938985565`, 0.3572930927857018, 0.9363129869324922], 
             UndirectedEdge[92, 221] -> 
             RGBColor[
              0.27785530490942656`, 0.40937392087661617`, 0.9391348206132799],
              UndirectedEdge[71, 232] -> 
             RGBColor[
              0.8118465460917592, 0.8499776455244756, 0.7814031522680547], 
             UndirectedEdge[25, 148] -> 
             RGBColor[
              0.24531191831194143`, 0.3751687581927745, 0.9372815228901793], 
             UndirectedEdge[76, 218] -> 
             RGBColor[
              0.2751691719679872, 0.4065506248444982, 0.9389818493160426], 
             UndirectedEdge[20, 200] -> 
             RGBColor[
              0.8759509079419014, 0.7355649732308305, 0.6068283204518097], 
             UndirectedEdge[68, 255] -> 
             RGBColor[
              0.9166602771185755, 0.6978068210363987, 0.2559631047048003], 
             UndirectedEdge[30, 123] -> 
             RGBColor[
              0.44920952472312525`, 0.5632633214064009, 0.9499108348145711], 
             UndirectedEdge[113, 290] -> 
             RGBColor[
              0.7861690031762806, 0.8329451327396338, 0.9581324033518415], 
             UndirectedEdge[230, 269] -> 
             RGBColor[
              0.23818874032876391`, 0.3676818464968855, 0.9368758684418348], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.40607658256930623`, 0.5261448586442126, 0.9470958186552614], 
             UndirectedEdge[71, 296] -> 
             RGBColor[
              0.6629160657631297, 0.7363988315879828, 0.9671706036421385], 
             UndirectedEdge[37, 237] -> 
             RGBColor[
              0.6597410410048012, 0.7340591462727639, 0.9667579712592742], 
             UndirectedEdge[8, 217] -> 
             RGBColor[
              0.7294424930983517, 0.7885652866674933, 0.9736676687505319], 
             UndirectedEdge[39, 100] -> 
             RGBColor[
              0.8588565214001893, 0.4390461989236035, 0.20343221707987458`], 
             UndirectedEdge[35, 216] -> 
             RGBColor[
              0.24253456217849695`, 0.3722495808019747, 0.9371233565671098], 
             UndirectedEdge[48, 253] -> 
             RGBColor[
              0.3552041377824924, 0.4809703145985687, 0.9438949648645372], 
             UndirectedEdge[72, 247] -> 
             RGBColor[
              0.6154478937421781, 0.6985426120193529, 0.9629684183842664], 
             UndirectedEdge[24, 254] -> 
             RGBColor[
              0.9234793483730712, 0.7829172870924861, 0.5955041038084421], 
             UndirectedEdge[247, 273] -> 
             RGBColor[
              0.598461668080708, 0.6848971683956518, 0.9615322412300882], 
             UndirectedEdge[80, 152] -> 
             RGBColor[
              0.26056294463292196`, 0.39119855382704327`, 0.9381500462772876],
              UndirectedEdge[121, 125] -> 
             RGBColor[
              0.9936176446660105, 0.9887571122327337, 0.5466981931057444], 
             UndirectedEdge[8, 177] -> 
             RGBColor[
              0.5355284607783559, 0.6327336001246429, 0.9569332103909327], 
             UndirectedEdge[38, 253] -> 
             RGBColor[
              0.35733483343099304`, 0.48281581607742285`, 0.9440307309071595],
              UndirectedEdge[134, 292] -> 
             RGBColor[
              0.2585311409306501, 0.3890629993121603, 0.9380343380622274], 
             UndirectedEdge[19, 177] -> 
             RGBColor[
              0.3552373943929633, 0.4804944703524481, 0.9439155616348212], 
             UndirectedEdge[219, 221] -> 
             RGBColor[
              0.28442417853057445`, 0.4162782235430855, 0.9395089082482266], 
             UndirectedEdge[37, 185] -> 
             RGBColor[
              0.6243865353648125, 0.7053567658918924, 0.9639747350674728], 
             UndirectedEdge[15, 280] -> 
             RGBColor[
              0.2534905697092152, 0.38376503936775813`, 0.9377472849880235], 
             UndirectedEdge[140, 171] -> 
             RGBColor[
              0.37321366033197056`, 0.49768064714073046`, 0.9450018223098395],
              UndirectedEdge[211, 221] -> 
             RGBColor[
              0.26848631667000333`, 0.39952652020881857`, 0.9386012705932207],
              UndirectedEdge[47, 273] -> 
             RGBColor[
              0.6309474410941337, 0.7112445284148133, 0.9641074535297975], 
             UndirectedEdge[58, 171] -> 
             RGBColor[
              0.48363824484440066`, 0.5907289672924857, 0.9527552354354336], 
             UndirectedEdge[75, 150] -> 
             RGBColor[
              0.8462593507356758, 0.8802930242051693, 0.9614859532696918], 
             UndirectedEdge[9, 167] -> 
             RGBColor[
              0.6353780576373289, 0.7131584853000028, 0.9656069359601525], 
             UndirectedEdge[135, 260] -> 
             RGBColor[
              0.9196247583457642, 0.9363642687580429, 0.8996385198821143], 
             UndirectedEdge[184, 202] -> 
             RGBColor[
              0.23277907926056368`, 0.361995949721885, 0.9365677962468772], 
             UndirectedEdge[166, 262] -> 
             RGBColor[
              0.9933514957949947, 0.9881878467094093, 0.5177295309761065], 
             UndirectedEdge[173, 276] -> 
             RGBColor[
              0.24447758470727698`, 0.3742918206744662, 0.9372340088256796], 
             UndirectedEdge[67, 86] -> 
             RGBColor[
              0.9435929630020026, 0.929903263270933, 0.6741823558912051], 
             UndirectedEdge[25, 272] -> 
             RGBColor[
              0.23754533151077184`, 0.36700558303470066`, 0.9368392272614883],
              UndirectedEdge[7, 174] -> 
             RGBColor[
              0.39353511961410004`, 0.5152820737846694, 0.9462966877257359], 
             UndirectedEdge[88, 113] -> 
             RGBColor[
              0.7318152240398965, 0.7888182862268713, 0.9538534747537719], 
             UndirectedEdge[147, 206] -> 
             RGBColor[
              0.23143319481245586`, 0.360581339832921, 0.9364911501186151], 
             UndirectedEdge[189, 211] -> 
             RGBColor[
              0.23710386113640347`, 0.3665415696804011, 0.9368140861767649], 
             UndirectedEdge[104, 209] -> 
             RGBColor[
              0.2751140822771375, 0.4064927220865271, 0.9389787120396467], 
             UndirectedEdge[151, 167] -> 
             RGBColor[
              0.5986000016649633, 0.6830276720672528, 0.9627869889383882], 
             UndirectedEdge[215, 274] -> 
             RGBColor[
              0.979839341035498, 0.9422049502369351, 0.5238492272566825], 
             UndirectedEdge[41, 261] -> 
             RGBColor[
              0.3788160778841355, 0.5025331796387221, 0.9453588034022401], 
             UndirectedEdge[157, 218] -> 
             RGBColor[
              0.30101158042666865`, 0.4302700565079032, 0.9405795858965723], 
             UndirectedEdge[187, 205] -> 
             RGBColor[
              0.44668815437293624`, 0.55925348518074, 0.950254691291311], 
             UndirectedEdge[62, 82] -> 
             RGBColor[
              0.9949627046124243, 0.9916340594516913, 0.6930996675251034], 
             UndirectedEdge[42, 144] -> 
             RGBColor[
              0.28507366633741316`, 0.4163170541357517, 0.9395694691052225], 
             UndirectedEdge[33, 150] -> 
             RGBColor[
              0.9383344799337505, 0.9529880672751867, 0.9704600672145196], 
             UndirectedEdge[34, 46] -> 
             RGBColor[
              0.30981865996121394`, 0.44123557275110054`, 0.9410185715382298],
              UndirectedEdge[220, 266] -> 
             RGBColor[
              0.2524128465615943, 0.3826322840080144, 0.9376859102491151], 
             UndirectedEdge[128, 279] -> 
             RGBColor[
              0.24902661375038676`, 0.3790731386238746, 0.9374930692999993], 
             UndirectedEdge[147, 270] -> 
             RGBColor[
              0.2272240069658551, 0.35615721652822, 0.9362514430976865], 
             UndirectedEdge[30, 90] -> 
             RGBColor[
              0.4328724368509469, 0.5491129570174318, 0.9488698500216755], 
             UndirectedEdge[36, 222] -> 
             RGBColor[
              0.5978519743815511, 0.6821400273622127, 0.9628407950842862], 
             UndirectedEdge[127, 170] -> 
             RGBColor[
              0.8273327672839398, 0.21109720340516447`, 0.1738071948600332], 
             UndirectedEdge[1, 295] -> 
             RGBColor[
              0.6279037208977163, 0.7050085996594103, 0.9661155178174292], 
             UndirectedEdge[96, 140] -> 
             RGBColor[
              0.36676996210044227`, 0.49209943960227065`, 0.9445912355564652],
              UndirectedEdge[206, 272] -> 
             RGBColor[
              0.22997704115109324`, 0.35905083000935434`, 0.9364082243217868],
              UndirectedEdge[129, 265] -> 
             RGBColor[
              0.22918762870603976`, 0.3582211074779632, 0.936363268450872], 
             UndirectedEdge[39, 60] -> 
             RGBColor[
              0.8968075804965964, 0.6180136902669162, 0.2352803969485015], 
             UndirectedEdge[71, 240] -> 
             RGBColor[
              0.8122650553898112, 0.8508727945952284, 0.8269553066210207], 
             UndirectedEdge[30, 144] -> 
             RGBColor[
              0.3889539475617518, 0.5110729690025859, 0.9460714027197632], 
             UndirectedEdge[26, 59] -> 
             RGBColor[
              0.9093225725856791, 0.6208046140216712, 0.5317333787947149], 
             UndirectedEdge[133, 241] -> 
             RGBColor[
              0.3146112316266204, 0.4441789202710761, 0.9413681711410662], 
             UndirectedEdge[236, 266] -> 
             RGBColor[
              0.43542230214154953`, 0.5412994360038763, 0.9504471655773028], 
             UndirectedEdge[28, 216] -> 
             RGBColor[
              0.24112529640186797`, 0.3707683531181266, 0.9370431009659527], 
             UndirectedEdge[173, 230] -> 
             RGBColor[
              0.25326290395464024`, 0.3835257482248573, 0.9377343197601018], 
             UndirectedEdge[39, 266] -> 
             RGBColor[
              0.5575833328465938, 0.4344940859122408, 0.5742960728747296], 
             UndirectedEdge[86, 141] -> 
             RGBColor[
              0.936935020626016, 0.7805800799358134, 0.2971516426609445], 
             UndirectedEdge[25, 206] -> 
             RGBColor[
              0.2442420605634609, 0.3740442698662223, 0.937220596074116], 
             UndirectedEdge[141, 165] -> 
             RGBColor[0.9396314058192, 0.789675620333774, 0.3076265899668467],
              UndirectedEdge[152, 241] -> 
             RGBColor[
              0.2661857597767988, 0.3971084890503288, 0.9384702572815218], 
             UndirectedEdge[110, 141] -> 
             RGBColor[
              0.9459742116007779, 0.8128132585241278, 0.5020022278511405], 
             UndirectedEdge[97, 134] -> 
             RGBColor[
              0.2657406017726479, 0.3966405997633186, 0.9384449061917377], 
             UndirectedEdge[103, 119] -> 
             RGBColor[
              0.28052080371187027`, 0.4121755291203697, 0.939286616826827], 
             UndirectedEdge[3, 17] -> 
             RGBColor[
              0.3367736481857078, 0.4649602471368852, 0.9427222930937296], 
             UndirectedEdge[203, 270] -> 
             RGBColor[
              0.2439246691349402, 0.37371067135106817`, 0.9372025211018002], 
             UndirectedEdge[51, 141] -> 
             RGBColor[
              0.9462822846437602, 0.812940654644517, 0.4968966602614467], 
             UndirectedEdge[184, 275] -> 
             RGBColor[
              0.22510784132218828`, 0.35393299226407493`, 0.9361309305948662],
              UndirectedEdge[58, 109] -> 
             RGBColor[
              0.7350459204207711, 0.7923292470470489, 0.9749877366110247], 
             UndirectedEdge[179, 281] -> 
             RGBColor[
              0.9148614845826333, 0.6349726325663724, 0.4685681683997813], 
             UndirectedEdge[31, 154] -> 
             RGBColor[
              0.6800184039631393, 0.7495944813404151, 0.9689878978887183], 
             UndirectedEdge[122, 296] -> 
             RGBColor[
              0.6602141631347492, 0.7342053053149373, 0.9669578999698369], 
             UndirectedEdge[96, 290] -> 
             RGBColor[
              0.5091973143554127, 0.6111290483156775, 0.9548640237887529], 
             UndirectedEdge[122, 240] -> 
             RGBColor[
              0.8095631527614308, 0.8486792683221828, 0.8267426029487193], 
             UndirectedEdge[97, 144] -> 
             RGBColor[
              0.28659496025462, 0.4179160304983415, 0.9396561045432549], 
             UndirectedEdge[61, 247] -> 
             RGBColor[
              0.5729638190353659, 0.6641968658756336, 0.9595249571515402], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.5867492116924276, 0.675169261254928, 0.9607600670587673], 
             UndirectedEdge[45, 287] -> 
             RGBColor[
              0.899399401089056, 0.6245785965945915, 0.23718537302328563`], 
             UndirectedEdge[278, 290] -> 
             RGBColor[
              0.607930114483695, 0.6925840797342462, 0.9622776320149933], 
             UndirectedEdge[109, 110] -> 
             RGBColor[
              0.9570573175626281, 0.9656649471847494, 0.8794550171346109], 
             UndirectedEdge[56, 160] -> 
             RGBColor[
              0.5689561966042058, 0.6609432974446849, 0.9592094624333546], 
             UndirectedEdge[146, 292] -> 
             RGBColor[
              0.2367560409824719, 0.36617598864554746`, 0.9367942783335522], 
             UndirectedEdge[131, 139] -> 
             RGBColor[
              0.29015495986038786`, 0.4208144502573191, 0.9398897209981389], 
             UndirectedEdge[47, 74] -> 
             RGBColor[
              0.6411369333771564, 0.7195168172815674, 0.9649096076876572], 
             UndirectedEdge[46, 221] -> 
             RGBColor[
              0.2933757434234066, 0.4256868858074472, 0.9400186866262199], 
             UndirectedEdge[48, 74] -> 
             RGBColor[
              0.5259484891930979, 0.6249515173301565, 0.9561210914963576], 
             UndirectedEdge[90, 134] -> 
             RGBColor[
              0.3387736212750252, 0.46463798272782586`, 0.9429249564054306], 
             UndirectedEdge[1, 37] -> 
             RGBColor[
              0.5496127167377557, 0.6437072364180976, 0.9583493103043816], 
             UndirectedEdge[33, 295] -> 
             RGBColor[
              0.8759737184879801, 0.9039416817218939, 0.9880323493319954], 
             UndirectedEdge[28, 35] -> 
             RGBColor[
              0.2248219115083478, 0.35363246190073133`, 0.9361146473149633], 
             UndirectedEdge[21, 169] -> 
             RGBColor[
              0.33823987120783705`, 0.46593460012617627`, 0.9428265434669814],
              UndirectedEdge[100, 228] -> 
             RGBColor[
              0.8332617870229544, 0.6215832019337704, 0.5890075855789246], 
             UndirectedEdge[190, 250] -> 
             RGBColor[
              0.22535768471974588`, 0.35419559351589436`, 0.9361451588067469],
              UndirectedEdge[81, 180] -> 
             RGBColor[
              0.26493370488523493`, 0.3957924999744301, 0.9383989546076965], 
             UndirectedEdge[127, 141] -> 
             RGBColor[
              0.8658872706016187, 0.44359089015560293`, 0.2082267027178307], 
             UndirectedEdge[143, 185] -> 
             RGBColor[
              0.482410173529073, 0.5891453845161638, 0.9528206307321404], 
             UndirectedEdge[283, 295] -> 
             RGBColor[
              0.728003954304401, 0.7872192535932907, 0.973734730725687], 
             UndirectedEdge[26, 100] -> 
             RGBColor[
              0.9180076603888783, 0.6875620047068038, 0.5400502286834623], 
             UndirectedEdge[242, 294] -> 
             RGBColor[
              0.22516497885926012`, 0.35399304743826654`, 0.9361341844930751],
              UndirectedEdge[39, 228] -> 
             RGBColor[
              0.8419379772960242, 0.6739158098872126, 0.5967537548599042], 
             UndirectedEdge[39, 82] -> 
             RGBColor[
              0.9313046936732585, 0.7416283194518091, 0.4583415502549171], 
             UndirectedEdge[109, 258] -> 
             RGBColor[
              0.941467846616602, 0.9554926988601389, 0.9709728498600104], 
             UndirectedEdge[118, 199] -> 
             RGBColor[
              0.17892828448197629`, 0.3053953500719979, 0.9335010731493483], 
             UndirectedEdge[57, 115] -> 
             RGBColor[
              0.2343221600487206, 0.3636178254672108, 0.9366556724149793], 
             UndirectedEdge[96, 222] -> 
             RGBColor[
              0.4207992950730278, 0.5388969322298897, 0.948033936877215], 
             UndirectedEdge[6, 108] -> 
             RGBColor[
              0.32479673840417583`, 0.4554602283068521, 0.9419271416840078], 
             UndirectedEdge[1, 9] -> 
             RGBColor[
              0.46767615866135254`, 0.5777748250387542, 0.9514973709902432], 
             UndirectedEdge[180, 190] -> 
             RGBColor[
              0.23107912024585836`, 0.36020918501380295`, 0.9364709860958538],
              UndirectedEdge[144, 253] -> 
             RGBColor[
              0.30621743066907636`, 0.4385404910404173, 0.9407735752045145], 
             UndirectedEdge[53, 192] -> 
             RGBColor[
              0.8483576285442167, 0.36235245091138435`, 0.19353530461595575`],
              UndirectedEdge[85, 121] -> 
             RGBColor[
              0.9571178936575444, 0.9648142409538079, 0.8234596411130128], 
             UndirectedEdge[36, 278] -> 
             RGBColor[
              0.681251390228536, 0.7503140519946241, 0.9692773736229017], 
             UndirectedEdge[122, 207] -> 
             RGBColor[
              0.6848905103681076, 0.7534826553208219, 0.9694174076484823], 
             UndirectedEdge[226, 228] -> 
             RGBColor[
              0.4976351265701356, 0.5809234118204025, 0.9579150619705263], 
             UndirectedEdge[7, 143] -> 
             RGBColor[
              0.3957483991962868, 0.5171991053160931, 0.9464377159435866], 
             UndirectedEdge[133, 164] -> 
             RGBColor[
              0.36703566028493084`, 0.49232957401529565`, 0.9446081656098331],
              UndirectedEdge[7, 131] -> 
             RGBColor[
              0.359788981914124, 0.4860528654391481, 0.9441464136720313], 
             UndirectedEdge[111, 280] -> 
             RGBColor[
              0.2555363699026189, 0.38591530508224947`, 0.9378637902825477], 
             UndirectedEdge[135, 224] -> 
             RGBColor[
              0.9798102252026126, 0.9495170954171317, 0.5749562479700403], 
             UndirectedEdge[91, 102] -> 
             RGBColor[
              0.3289676178309032, 0.4560161547537128, 0.9423048264494448], 
             UndirectedEdge[200, 282] -> 
             RGBColor[
              0.9248264998510323, 0.7738160826625009, 0.5864939522963153], 
             UndirectedEdge[106, 194] -> 
             RGBColor[
              0.5862509789073218, 0.6747647734348481, 0.960720844348837], 
             UndirectedEdge[38, 259] -> 
             RGBColor[
              0.44110257276703263`, 0.5561854868751561, 0.949409740030642], 
             UndirectedEdge[36, 69] -> 
             RGBColor[
              0.8763046392583498, 0.8998097230462532, 0.7301395316538027], 
             UndirectedEdge[64, 153] -> 
             RGBColor[
              0.253568524812987, 0.38384697512446136`, 0.9377517244158591], 
             UndirectedEdge[159, 175] -> 
             RGBColor[
              0.2709524595475128, 0.4021185927355705, 0.9387417137817635], 
             UndirectedEdge[94, 200] -> 
             RGBColor[
              0.8739725410077492, 0.7339874771388775, 0.6066396220475212], 
             UndirectedEdge[88, 201] -> 
             RGBColor[
              0.41266709907445764`, 0.5304710926638055, 0.9478976499747094], 
             UndirectedEdge[121, 232] -> 
             RGBColor[
              0.9943533317427773, 0.9903306725005643, 0.626773191277452], 
             UndirectedEdge[140, 289] -> 
             RGBColor[
              0.3095286406957365, 0.4408775980939844, 0.9410040013062702], 
             UndirectedEdge[139, 244] -> 
             RGBColor[
              0.2489949569451404, 0.37903986531440326`, 0.9374912664917726], 
             UndirectedEdge[167, 174] -> 
             RGBColor[
              0.5731249742958058, 0.6609624837721939, 0.9611637427211077], 
             UndirectedEdge[185, 282] -> 
             RGBColor[
              0.7658636697865162, 0.8163200733980329, 0.9527715263482667], 
             UndirectedEdge[236, 249] -> 
             RGBColor[
              0.7208953090971567, 0.4244044295693752, 0.5644530380404611], 
             UndirectedEdge[137, 299] -> 
             RGBColor[
              0.9200253772401052, 0.6716173201462636, 0.46616820031546136`], 
             UndirectedEdge[201, 218] -> 
             RGBColor[
              0.2885778810548669, 0.4195006110479498, 0.9397873215672898], 
             UndirectedEdge[36, 109] -> 
             RGBColor[
              0.8403699639081523, 0.8760405078690783, 0.9845068533256267], 
             UndirectedEdge[4, 52] -> 
             RGBColor[
              0.6786643793088902, 0.3871223101534529, 0.5607452962818866], 
             UndirectedEdge[5, 191] -> 
             RGBColor[
              0.23242398209380136`, 0.36162272008515706`, 0.9365475739885493],
              UndirectedEdge[55, 134] -> 
             RGBColor[
              0.27534778812989436`, 0.40673836175558137`, 0.9389920212422243],
              UndirectedEdge[67, 69] -> 
             RGBColor[
              0.9526781701718614, 0.9602196098814508, 0.7375536853224871], 
             UndirectedEdge[232, 256] -> 
             RGBColor[
              0.9946722576480922, 0.9910128227636774, 0.6614863078884357], 
             UndirectedEdge[185, 237] -> 
             RGBColor[
              0.6034248054489583, 0.6889264668979879, 0.961922957584288], 
             UndirectedEdge[28, 211] -> 
             RGBColor[
              0.2328859592843117, 0.3621082874034291, 0.9365738829061148], 
             UndirectedEdge[85, 246] -> 
             RGBColor[
              0.759246790508393, 0.811987768878119, 0.9768800667488129], 
             UndirectedEdge[26, 127] -> 
             RGBColor[
              0.9093035421850235, 0.6206583380230588, 0.5317151552615555], 
             UndirectedEdge[91, 162] -> 
             RGBColor[
              0.27856959341816107`, 0.4101246833878033, 0.9391754982871572], 
             UndirectedEdge[112, 242] -> 
             RGBColor[
              0.24632291686669305`, 0.37623138177482907`, 0.937339097762234], 
             UndirectedEdge[85, 122] -> 
             RGBColor[
              0.7719092053781459, 0.8222676877046737, 0.9778768984313139], 
             UndirectedEdge[63, 131] -> 
             RGBColor[
              0.32467225096411007`, 0.4556365181084638, 0.9419088066284024], 
             UndirectedEdge[140, 222] -> 
             RGBColor[
              0.3821033463817397, 0.505380446388428, 0.94556826524409], 
             UndirectedEdge[121, 256] -> 
             RGBColor[
              0.9949290492403844, 0.9915620740139779, 0.6894364879754314], 
             UndirectedEdge[171, 198] -> 
             RGBColor[
              0.4413043319504303, 0.556360389684118, 0.9494225547381876], 
             UndirectedEdge[10, 117] -> 
             RGBColor[
              0.20745354842489078`, 0.3353772110821952, 0.935125544731551], 
             UndirectedEdge[18, 290] -> 
             RGBColor[
              0.7796647191738186, 0.8280942483803853, 0.9691424595790514], 
             UndirectedEdge[207, 240] -> 
             RGBColor[
              0.870260916353266, 0.8963751063904083, 0.8326021245961515], 
             UndirectedEdge[219, 264] -> 
             RGBColor[
              0.28444814998044265`, 0.4163034190567747, 0.9395102733868341], 
             UndirectedEdge[78, 118] -> 
             RGBColor[
              0.17948494456776543`, 0.30598043511645023`, 0.9335327741177293],
              UndirectedEdge[2, 208] -> 
             RGBColor[
              0.2583585282715436, 0.3888815724631647, 0.9380245080266488], 
             UndirectedEdge[34, 169] -> 
             RGBColor[
              0.3102621246711287, 0.4417016822785076, 0.9410438261974121], 
             UndirectedEdge[35, 275] -> 
             RGBColor[
              0.21950487592715945`, 0.34804392038537546`, 0.9358118500044639],
              UndirectedEdge[157, 284] -> 
             RGBColor[
              0.3008123283039969, 0.4300606298936609, 0.9405682387829533], 
             UndirectedEdge[30, 259] -> 
             RGBColor[
              0.46322962709906557`, 0.5751097053927338, 0.9508862795927249], 
             UndirectedEdge[62, 192] -> 
             RGBColor[
              0.9299174355595534, 0.7356028477535854, 0.4448740417030029], 
             UndirectedEdge[95, 245] -> 
             RGBColor[
              0.4565245648697137, 0.5688811135099974, 0.9505753636122101], 
             UndirectedEdge[129, 230] -> 
             RGBColor[
              0.2426308084736596, 0.3723507417605582, 0.9371288376512357], 
             UndirectedEdge[35, 92] -> 
             RGBColor[
              0.24366421330036392`, 0.37343691575507476`, 0.9371876885273311],
              UndirectedEdge[186, 279] -> 
             RGBColor[
              0.24438086405288187`, 0.3741901611342533, 0.9372285007274972], 
             UndirectedEdge[217, 233] -> 
             RGBColor[
              0.9005620992858752, 0.9194729557138646, 0.7896746116293041], 
             UndirectedEdge[28, 293] -> 
             RGBColor[
              0.21633697828784162`, 0.3447142591101412, 0.9356314429203892], 
             UndirectedEdge[24, 233] -> 
             RGBColor[
              0.9748626422338834, 0.9780993949460502, 0.7789636593832132], 
             UndirectedEdge[41, 229] -> 
             RGBColor[
              0.35168976097882576`, 0.47903772734367334`, 0.943630338475894], 
             UndirectedEdge[197, 214] -> 
             RGBColor[
              0.21169118846890916`, 0.33983123945035565`, 0.9353668720630313],
              UndirectedEdge[84, 144] -> 
             RGBColor[
              0.30816373722776935`, 0.4405861826365669, 0.9408844144837296], 
             UndirectedEdge[101, 205] -> 
             RGBColor[
              0.5380185348092877, 0.6358267098737893, 0.9567739363684693], 
             UndirectedEdge[7, 297] -> 
             RGBColor[
              0.5775728899214854, 0.6645401478372637, 0.9615635093646839], 
             UndirectedEdge[30, 47] -> 
             RGBColor[
              0.5531290988592262, 0.6480680925121483, 0.9579813085710855], 
             UndirectedEdge[140, 298] -> 
             RGBColor[
              0.3066630469664905, 0.4378656773954105, 0.9408408099826556], 
             UndirectedEdge[159, 252] -> 
             RGBColor[
              0.2739625179017606, 0.4052823549146075, 0.9389131321520556], 
             UndirectedEdge[26, 195] -> 
             RGBColor[
              0.9024893735730009, 0.5682816520833267, 0.52518989970318], 
             UndirectedEdge[43, 185] -> 
             RGBColor[
              0.4451220207260428, 0.5568482607152324, 0.9504446626081502], 
             UndirectedEdge[36, 95] -> 
             RGBColor[
              0.6241088885700935, 0.7039231949079366, 0.9647789065724686], 
             UndirectedEdge[6, 46] -> 
             RGBColor[
              0.29890559173213627`, 0.4314991069925552, 0.9403336033067247], 
             UndirectedEdge[148, 183] -> 
             RGBColor[
              0.2467014884994484, 0.37662928456368283`, 0.937360656856673], 
             UndirectedEdge[222, 261] -> 
             RGBColor[
              0.41838703187400994`, 0.5368075510907742, 0.9478802295992542], 
             UndirectedEdge[64, 145] -> 
             RGBColor[
              0.2514296244944172, 0.3815988552755316, 0.937629917206936], 
             UndirectedEdge[8, 247] -> 
             RGBColor[
              0.6154687668637716, 0.6985589182605833, 0.9629704988219563], 
             UndirectedEdge[122, 136] -> 
             RGBColor[
              0.8085502082780569, 0.8465126824966431, 0.7164898471021924], 
             UndirectedEdge[139, 206] -> 
             RGBColor[
              0.2460762386198535, 0.3759721072970965, 0.9373250498010044], 
             UndirectedEdge[65, 80] -> 
             RGBColor[
              0.27787319023653523`, 0.40939271948940265`, 0.9391358391561999],
              UndirectedEdge[171, 245] -> 
             RGBColor[
              0.4213779646314022, 0.5393981467165758, 0.9480708091897773], 
             UndirectedEdge[137, 232] -> 
             RGBColor[
              0.9198313733274753, 0.6705144142242014, 0.3950452840198946], 
             UndirectedEdge[64, 221] -> 
             RGBColor[
              0.26413437920159183`, 0.3949523580007457, 0.9383534341925093], 
             UndirectedEdge[140, 263] -> 
             RGBColor[
              0.2945287893227776, 0.42511180325549774`, 0.9401497819608717], 
             UndirectedEdge[200, 295] -> 
             RGBColor[
              0.8616403695892892, 0.7241541383976731, 0.6054633685285691], 
             UndirectedEdge[136, 232] -> 
             RGBColor[
              0.9935021049651632, 0.9885099844954769, 0.5341224096968956], 
             UndirectedEdge[45, 68] -> 
             RGBColor[
              0.8660950044608668, 0.48393636846669774`, 0.20994293256664392`],
              UndirectedEdge[224, 254] -> 
             RGBColor[
              0.9304233123934045, 0.7541309251793602, 0.28356918675006826`], 
             UndirectedEdge[148, 272] -> 
             RGBColor[
              0.23104689889957378`, 0.3601753183359065, 0.93646915113785], 
             UndirectedEdge[167, 185] -> 
             RGBColor[
              0.660998380157889, 0.7339582173045702, 0.9676238615993047], 
             UndirectedEdge[59, 137] -> 
             RGBColor[
              0.8391881810125934, 0.30222310839901756`, 0.1851599524353666], 
             UndirectedEdge[55, 97] -> 
             RGBColor[
              0.26708761639868417`, 0.39805639754094285`, 0.9385216166819608],
              UndirectedEdge[156, 202] -> 
             RGBColor[
              0.22791002753873152`, 0.3568782676465297, 0.9362905109544353], 
             UndirectedEdge[78, 176] -> 
             RGBColor[
              0.17949609924511575`, 0.30599215938959284`, 0.9335334093601024],
              UndirectedEdge[131, 143] -> 
             RGBColor[
              0.3607906299670138, 0.4869204426382663, 0.9442102378002388], 
             UndirectedEdge[230, 289] -> 
             RGBColor[
              0.27016772610159867`, 0.4012937881289406, 0.9386970243729278], 
             UndirectedEdge[35, 126] -> 
             RGBColor[
              0.2260848753293333, 0.35495991695311835`, 0.9361865712361809], 
             UndirectedEdge[147, 183] -> 
             RGBColor[
              0.24039105535964145`, 0.36999661922917565`, 0.9370012870248101],
              UndirectedEdge[66, 258] -> 
             RGBColor[
              0.9541114545413159, 0.9652969784492861, 0.9625615171988029], 
             UndirectedEdge[60, 232] -> 
             RGBColor[
              0.9600894947352094, 0.8672149974535253, 0.4291027093633025], 
             UndirectedEdge[39, 127] -> 
             RGBColor[
              0.8501524031963347, 0.3721425322398584, 0.1950971436579678], 
             UndirectedEdge[113, 258] -> 
             RGBColor[
              0.9605881616295711, 0.9701272959910724, 0.9515981414941335], 
             UndirectedEdge[45, 223] -> 
             RGBColor[
              0.872589282408941, 0.5134253678517513, 0.21536191727583626`], 
             UndirectedEdge[40, 80] -> 
             RGBColor[
              0.25252112623098183`, 0.38274609280586824`, 0.9376920766161012],
              UndirectedEdge[18, 198] -> 
             RGBColor[
              0.7053280385373079, 0.7677443822103661, 0.9632904037751118], 
             UndirectedEdge[13, 58] -> 
             RGBColor[
              0.4275257850964924, 0.5418851588163979, 0.949188660514906], 
             UndirectedEdge[16, 195] -> 
             RGBColor[
              0.9063070598041875, 0.5682974877338114, 0.34831639298626615`], 
             UndirectedEdge[17, 90] -> 
             RGBColor[
              0.3498844311553243, 0.4763161483780546, 0.9435577005911434], 
             UndirectedEdge[8, 273] -> 
             RGBColor[
              0.6348421879085798, 0.7142871342274307, 0.9644956454937833], 
             UndirectedEdge[85, 256] -> 
             RGBColor[
              0.9574368195628593, 0.965496391216921, 0.8581727577239964], 
             UndirectedEdge[149, 227] -> 
             RGBColor[
              0.27685707898321577`, 0.40832472213698934`, 0.9390779731235251],
              UndirectedEdge[182, 208] -> 
             RGBColor[
              0.2965714316502459, 0.42904575675219153`, 0.9402006763431414], 
             UndirectedEdge[82, 100] -> 
             RGBColor[
              0.9226285034001888, 0.6892957114983669, 0.45059538097393753`], 
             UndirectedEdge[227, 264] -> 
             RGBColor[
              0.2772132461146813, 0.4086990763744601, 0.9390982563147601], 
             UndirectedEdge[74, 259] -> 
             RGBColor[
              0.5512374616169957, 0.646558430162153, 0.9578145787092965], 
             UndirectedEdge[96, 105] -> 
             RGBColor[
              0.3473181215020726, 0.473441328714978, 0.9434180509343462], 
             UndirectedEdge[60, 100] -> 
             RGBColor[
              0.8881313902235266, 0.565681082313474, 0.22753422766752193`], 
             UndirectedEdge[73, 87] -> 
             RGBColor[
              0.3025587103322468, 0.4334652095438001, 0.9406102430960075], 
             UndirectedEdge[68, 223] -> 
             RGBColor[
              0.880860495472638, 0.5518971603270344, 0.22229941585693147`], 
             UndirectedEdge[162, 191] -> 
             RGBColor[
              0.26420786908525307`, 0.39502960052800135`, 0.9383576193326653],
              UndirectedEdge[87, 149] -> 
             RGBColor[
              0.2850281329082009, 0.41691301788689017`, 0.939543302556562], 
             UndirectedEdge[60, 256] -> 
             RGBColor[
              0.9606652122328164, 0.8684463989669389, 0.49176600606128196`], 
             UndirectedEdge[145, 169] -> 
             RGBColor[
              0.28111445342614677`, 0.4127994926096401, 0.939320424299829], 
             UndirectedEdge[144, 235] -> 
             RGBColor[
              0.27887432985742466`, 0.4098011584346488, 0.9392164260637837], 
             UndirectedEdge[36, 88] -> 
             RGBColor[
              0.6318962145275521, 0.7102452969352381, 0.9653919533977545], 
             UndirectedEdge[38, 123] -> 
             RGBColor[
              0.4270824703910924, 0.5443391028888234, 0.9484342952524883], 
             UndirectedEdge[183, 244] -> 
             RGBColor[
              0.24855034907625476`, 0.37857255425443737`, 0.937465946731378], 
             UndirectedEdge[2, 32] -> 
             RGBColor[
              0.24350738500413596`, 0.3732720792722509, 0.9371787573878676], 
             UndirectedEdge[106, 151] -> 
             RGBColor[
              0.5499711557200619, 0.645038448022178, 0.9579401200370031], 
             UndirectedEdge[164, 277] -> 
             RGBColor[
              0.36650966152605724`, 0.4918739803278257, 0.94457464943404], 
             UndirectedEdge[296, 299] -> 
             RGBColor[
              0.8453600637344856, 0.8773055132358333, 0.8557133788601069], 
             UndirectedEdge[75, 174] -> 
             RGBColor[
              0.5614179437120186, 0.6518168625034114, 0.9599968953209368], 
             UndirectedEdge[31, 66] -> 
             RGBColor[
              0.7826462994682315, 0.8305130082182347, 0.9693283290234715], 
             UndirectedEdge[2, 268] -> 
             RGBColor[
              0.2466368287086141, 0.37656132302384837`, 0.9373569745772405], 
             UndirectedEdge[46, 264] -> 
             RGBColor[
              0.29339971487327476`, 0.42571208132113636`, 0.9400200517648274],
              UndirectedEdge[71, 160] -> 
             RGBColor[
              0.6099082730566356, 0.6941900379787878, 0.9624333599040888], 
             UndirectedEdge[50, 114] -> 
             RGBColor[
              0.32843011888336315`, 0.4584906115476223, 0.9421629292736595], 
             UndirectedEdge[126, 197] -> 
             RGBColor[
              0.21821940668747852`, 0.34669281071101354`, 0.9357386444329454],
              UndirectedEdge[265, 269] -> 
             RGBColor[
              0.2247455605611441, 0.35355221221429056`, 0.9361102992414712], 
             UndirectedEdge[144, 257] -> 
             RGBColor[
              0.3535074058070181, 0.4806120799363681, 0.9437461571970662], 
             UndirectedEdge[86, 107] -> 
             RGBColor[
              0.9045073081884096, 0.5951795926664958, 0.26859915666912515`], 
             UndirectedEdge[149, 245] -> 
             RGBColor[
              0.3591757955739624, 0.4841536676462995, 0.9441574343329895], 
             UndirectedEdge[143, 283] -> 
             RGBColor[
              0.5077365883087008, 0.6097065089762495, 0.9548144188773069], 
             UndirectedEdge[66, 154] -> 
             RGBColor[
              0.8438279787518632, 0.8786689323302527, 0.9751799865903525], 
             UndirectedEdge[57, 159] -> 
             RGBColor[
              0.24722335585304894`, 0.3771778002406183, 0.937390376430427], 
             UndirectedEdge[7, 167] -> 
             RGBColor[
              0.5743366058251028, 0.6620119381044995, 0.9612409468107508], 
             UndirectedEdge[57, 89] -> 
             RGBColor[
              0.26259271630004477`, 0.3933319725441461, 0.9382656387709521], 
             UndirectedEdge[122, 256] -> 
             RGBColor[
              0.8097203609609858, 0.8490155207648438, 0.8438537452937325], 
             UndirectedEdge[39, 232] -> 
             RGBColor[
              0.9308146259118721, 0.7405801140636548, 0.40500069877565514`], 
             UndirectedEdge[72, 286] -> 
             RGBColor[
              0.6054217047226151, 0.6904029000986035, 0.9621791200575058], 
             UndirectedEdge[71, 299] -> 
             RGBColor[
              0.812040550004389, 0.8510805514465378, 0.8525260685636215], 
             UndirectedEdge[90, 158] -> 
             RGBColor[
              0.4035892626740157, 0.5239904671672448, 0.9469373288309841], 
             UndirectedEdge[52, 236] -> 
             RGBColor[
              0.7204593344779664, 0.42105333760098257`, 0.5640355482527617], 
             UndirectedEdge[17, 134] -> 
             RGBColor[
              0.2851115833841571, 0.4170007296281859, 0.9395480549377139], 
             UndirectedEdge[54, 72] -> 
             RGBColor[
              0.534606977221836, 0.6319372303906756, 0.9568737438527076], 
             UndirectedEdge[170, 192] -> 
             RGBColor[
              0.8434397887079927, 0.3245517789190093, 0.188825975634882], 
             UndirectedEdge[140, 198] -> 
             RGBColor[
              0.3961646850276139, 0.5172626963041967, 0.9465462963516883], 
             UndirectedEdge[19, 89] -> 
             RGBColor[
              0.28469980544749635`, 0.41656792490852634`, 0.9395246047933918],
              UndirectedEdge[239, 295] -> 
             RGBColor[
              0.6242095261484855, 0.7018088738432534, 0.9658801269946564], 
             UndirectedEdge[51, 69] -> 
             RGBColor[
              0.9933000659558078, 0.9895615584823135, 0.6199821278730931], 
             UndirectedEdge[186, 269] -> 
             RGBColor[
              0.2284972047762287, 0.3574954281523263, 0.93632394982946], 
             UndirectedEdge[37, 282] -> 
             RGBColor[
              0.8221799053423591, 0.8614527527728091, 0.9576065400232527], 
             UndirectedEdge[1, 239] -> 
             RGBColor[
              0.4148284678056251, 0.5337253017533699, 0.9476534810435313], 
             UndirectedEdge[59, 200] -> 
             RGBColor[
              0.8594030577293614, 0.41420745732297415`, 0.20281846065499215`],
              UndirectedEdge[145, 221] -> 
             RGBColor[
              0.2819086057959276, 0.4136341971024482, 0.9393656501024449], 
             UndirectedEdge[75, 297] -> 
             RGBColor[
              0.7454557140194038, 0.8010749365560057, 0.9752637169598848], 
             UndirectedEdge[142, 185] -> 
             RGBColor[
              0.6135470246958941, 0.696888857774001, 0.9628943539449815], 
             UndirectedEdge[36, 258] -> 
             RGBColor[
              0.8606691521172266, 0.8915543066994391, 0.9631366201381162], 
             UndirectedEdge[13, 289] -> 
             RGBColor[
              0.2985558278706446, 0.4311314829978179, 0.940313684772242], 
             UndirectedEdge[53, 170] -> 
             RGBColor[
              0.8268112796846933, 0.20708882120003286`, 0.1733078177460588], 
             UndirectedEdge[130, 226] -> 
             RGBColor[
              0.178927005110741, 0.3053940053717128, 0.9335010002910491], 
             UndirectedEdge[224, 249] -> 
             RGBColor[
              0.8940523406864429, 0.5263405979795888, 0.25076760006070237`], 
             UndirectedEdge[234, 271] -> 
             RGBColor[
              0.8973919728354314, 0.5348865558223752, 0.26558699931478663`], 
             UndirectedEdge[78, 266] -> 
             RGBColor[
              0.21383713709575333`, 0.3420867675181703, 0.9354890806626834], 
             UndirectedEdge[127, 232] -> 
             RGBColor[
              0.9134343174349477, 0.6213438394264674, 0.3889194560727688], 
             UndirectedEdge[57, 292] -> 
             RGBColor[
              0.2450572419916986, 0.37490107723278787`, 0.9372670194505013], 
             UndirectedEdge[52, 107] -> 
             RGBColor[
              0.8259275201506884, 0.20029585815577397`, 0.17246152861823205`],
              UndirectedEdge[26, 130] -> 
             RGBColor[
              0.5823809948253185, 0.6469022092217233, 0.9089577047840149], 
             UndirectedEdge[51, 58] -> 
             RGBColor[
              0.7712426526188537, 0.8181426903224094, 0.8569941031084208], 
             UndirectedEdge[192, 195] -> 
             RGBColor[
              0.8420649475314406, 0.3139841471767838, 0.18750942617155456`], 
             UndirectedEdge[118, 266] -> 
             RGBColor[
              0.21328176149194045`, 0.3415030325457159, 0.9354574528436509], 
             UndirectedEdge[171, 289] -> 
             RGBColor[
              0.35466828761855285`, 0.4799752914739057, 0.9438802596927696], 
             UndirectedEdge[1, 283] -> 
             RGBColor[
              0.5186228959615405, 0.619135681503407, 0.955508084774562], 
             UndirectedEdge[44, 59] -> 
             RGBColor[
              0.8989327098919131, 0.5734920759622608, 0.24889953887676536`], 
             UndirectedEdge[62, 127] -> 
             RGBColor[
              0.9138104141355006, 0.6221482722397406, 0.4298552609281541], 
             UndirectedEdge[46, 219] -> 
             RGBColor[
              0.2831865614508789, 0.4149774095228705, 0.9394384277864284], 
             UndirectedEdge[55, 252] -> 
             RGBColor[
              0.2886130512396545, 0.4206809943501981, 0.9397474583521269], 
             UndirectedEdge[55, 144] -> 
             RGBColor[
              0.2962021466118664, 0.42801379249060423`, 0.9402032195937415], 
             UndirectedEdge[160, 296] -> 
             RGBColor[
              0.6432277867867322, 0.7204149997680831, 0.9656206702005743], 
             UndirectedEdge[154, 179] -> 
             RGBColor[
              0.8674233288276321, 0.8946955574709121, 0.8648978949263142], 
             UndirectedEdge[6, 145] -> 
             RGBColor[
              0.2874384541046572, 0.41944641828755624`, 0.9396805667829495], 
             UndirectedEdge[132, 243] -> 
             RGBColor[
              0.21243933131542342`, 0.34061758501703826`, 0.935409477691362], 
             UndirectedEdge[53, 59] -> 
             RGBColor[
              0.8322696375208192, 0.249044151396152, 0.17853474737426642`], 
             UndirectedEdge[4, 228] -> 
             RGBColor[
              0.6779819914219037, 0.7467901325313183, 0.9696145955916023], 
             UndirectedEdge[71, 98] -> 
             RGBColor[
              0.5262018737865255, 0.625404972246536, 0.9560725859325541], 
             UndirectedEdge[201, 259] -> 
             RGBColor[
              0.3926869440225089, 0.5142503026969059, 0.9463247389793005], 
             UndirectedEdge[34, 187] -> 
             RGBColor[
              0.34571434459052375`, 0.47386212200128636`, 0.9432495902274847],
              UndirectedEdge[18, 260] -> 
             RGBColor[
              0.8977772500782942, 0.9210512580678571, 0.980544009200409], 
             UndirectedEdge[263, 289] -> 
             RGBColor[
              0.27598341660935993`, 0.40740644758867306`, 0.9390282193438018],
              UndirectedEdge[173, 209] -> 
             RGBColor[
              0.2611649721580388, 0.3918313229266909, 0.938184330854223], 
             UndirectedEdge[4, 199] -> 
             RGBColor[
              0.3592738699625091, 0.4712607260826286, 0.9452005339121252], 
             UndirectedEdge[253, 292] -> 
             RGBColor[
              0.26989343961389634`, 0.40100549563959764`, 0.9386814041632237],
              UndirectedEdge[128, 209] -> 
             RGBColor[
              0.25220846656924684`, 0.38241746767761725`, 0.9376742711109041],
              UndirectedEdge[44, 137] -> 
             RGBColor[
              0.9053107353837854, 0.6225163747613823, 0.25500714329073165`], 
             UndirectedEdge[129, 263] -> 
             RGBColor[
              0.24844649898142085`, 0.37846340122029065`, 0.9374600326221096],
              UndirectedEdge[73, 289] -> 
             RGBColor[
              0.309996695985159, 0.44128300406053933`, 0.9410338253754271], 
             UndirectedEdge[128, 276] -> 
             RGBColor[
              0.235521079118485, 0.3648779654253926, 0.9367239490823606], 
             UndirectedEdge[96, 196] -> 
             RGBColor[
              0.34319916551880214`, 0.4691120448196677, 0.9431834824845483], 
             UndirectedEdge[24, 224] -> 
             RGBColor[
              0.9625807494214099, 0.9376482057938698, 0.6480446128648567], 
             UndirectedEdge[88, 278] -> 
             RGBColor[
              0.553576335347311, 0.6484572332214837, 0.9579987034169237], 
             UndirectedEdge[158, 253] -> 
             RGBColor[
              0.35017871358609476`, 0.47661754474481344`, 0.9435747492785509],
              UndirectedEdge[67, 110] -> 
             RGBColor[
              0.9526321539767644, 0.9621364418592473, 0.8790329410814011], 
             UndirectedEdge[155, 275] -> 
             RGBColor[
              0.21254067958734837`, 0.340724108476683, 0.9354152493255168], 
             UndirectedEdge[101, 108] -> 
             RGBColor[
              0.44525533808141193`, 0.5575469670447641, 0.9502920083081179], 
             UndirectedEdge[102, 210] -> 
             RGBColor[
              0.3819399405336581, 0.5052389124558365, 0.9455578531679444], 
             UndirectedEdge[176, 199] -> 
             RGBColor[
              0.17893943915932659`, 0.3054070743451405, 0.9335017083917216], 
             UndirectedEdge[62, 226] -> 
             RGBColor[
              0.5868878718865363, 0.6483921488101179, 0.8070978107416625], 
             UndirectedEdge[69, 113] -> 
             RGBColor[
              0.9762236487706943, 0.9783827123378863, 0.71860105300982], 
             UndirectedEdge[51, 258] -> 
             RGBColor[
              0.9776645788146846, 0.9813061421354996, 0.8529792163574066], 
             UndirectedEdge[30, 74] -> 
             RGBColor[
              0.5502062391736314, 0.6457212373265883, 0.9577333971010626], 
             UndirectedEdge[118, 228] -> 
             RGBColor[
              0.49763640594137093`, 0.5809247565206876, 0.9579151348288255], 
             UndirectedEdge[71, 121] -> 
             RGBColor[
              0.8121033376840514, 0.8505268967747761, 0.8093533323550504], 
             UndirectedEdge[1, 20] -> 
             RGBColor[
              0.6422142592503285, 0.7164194344925677, 0.9674804697406698], 
             UndirectedEdge[126, 293] -> 
             RGBColor[
              0.21759994210882713`, 0.34604171416252816`, 0.9357033668416068],
              UndirectedEdge[112, 159] -> 
             RGBColor[
              0.24980358255219737`, 0.3798897820972448, 0.9375373165238401], 
             UndirectedEdge[17, 159] -> 
             RGBColor[
              0.2718080646722995, 0.4030178879702195, 0.9387904392278659], 
             UndirectedEdge[139, 172] -> 
             RGBColor[
              0.26248705403553485`, 0.3932209148047717, 0.9382596214613016], 
             UndirectedEdge[47, 233] -> 
             RGBColor[
              0.8190741460647206, 0.8558139473261162, 0.781552654000438], 
             UndirectedEdge[98, 182] -> 
             RGBColor[
              0.3649951509133196, 0.4904176871542194, 0.9444834370172861], 
             UndirectedEdge[84, 159] -> 
             RGBColor[
              0.27400586003393973`, 0.4053279102435776, 0.9389156004223643], 
             UndirectedEdge[118, 176] -> 
             RGBColor[
              0.17894072364130287`, 0.30540842441713845`, 0.9335017815410699],
              UndirectedEdge[18, 278] -> 
             RGBColor[
              0.7746661157384185, 0.8240361569270088, 0.968748951206129], 
             UndirectedEdge[155, 197] -> 
             RGBColor[
              0.21140151230331092`, 0.3395267714337822, 0.9353503754339378], 
             UndirectedEdge[72, 215] -> 
             RGBColor[
              0.8234553846620669, 0.8600796725778928, 0.8483727211925696], 
             UndirectedEdge[162, 239] -> 
             RGBColor[
              0.34783050852175984`, 0.47345580113907954`, 0.9434664197100019],
              UndirectedEdge[139, 272] -> 
             RGBColor[
              0.23937950956716447`, 0.3689334204655748, 0.9369436809883765], 
             UndirectedEdge[9, 75] -> 
             RGBColor[
              0.6236710270535416, 0.7040128640312203, 0.9644400885599815], 
             UndirectedEdge[18, 254] -> 
             RGBColor[
              0.918861315886804, 0.779473166025562, 0.6033212282319205], 
             UndirectedEdge[25, 244] -> 
             RGBColor[
              0.2471607788887478, 0.37711202788352904`, 0.9373868127648843], 
             UndirectedEdge[30, 257] -> 
             RGBColor[
              0.42675186290096767`, 0.5438116234909512, 0.9484798524617939], 
             UndirectedEdge[29, 270] -> 
             RGBColor[
              0.2355391750470839, 0.3648969853936982, 0.9367249796187237], 
             UndirectedEdge[73, 298] -> 
             RGBColor[
              0.307131102255913, 0.43827108336196546`, 0.9408706340518126], 
             UndirectedEdge[73, 96] -> 
             RGBColor[
              0.3672380173898648, 0.4925048455688256, 0.9446210596256222], 
             UndirectedEdge[108, 205] -> 
             RGBColor[
              0.436683616415666, 0.5505880572448512, 0.9496172109793394], 
             UndirectedEdge[9, 43] -> 
             RGBColor[
              0.41950169820548255`, 0.5360485287106651, 0.948427736968998], 
             UndirectedEdge[151, 251] -> 
             RGBColor[
              0.36499365332834144`, 0.4885238594535514, 0.944552636407374], 
             UndirectedEdge[209, 279] -> 
             RGBColor[
              0.2619744678088157, 0.39268215418064606`, 0.9382304304339932], 
             UndirectedEdge[53, 68] -> 
             RGBColor[
              0.8530476685227406, 0.3836488270671944, 0.19744878893743584`], 
             UndirectedEdge[282, 295] -> 
             RGBColor[
              0.9004709095023198, 0.9227541160141217, 0.9653727475363004], 
             UndirectedEdge[35, 197] -> 
             RGBColor[
              0.218365708643122, 0.3468465833424746, 0.9357469761128849], 
             UndirectedEdge[116, 168] -> 
             RGBColor[
              0.35414043439259346`, 0.4811603774802517, 0.9437864932187738], 
             UndirectedEdge[27, 152] -> 
             RGBColor[
              0.2558672975304459, 0.3862631310011191, 0.9378826361213889], 
             UndirectedEdge[114, 231] -> 
             RGBColor[
              0.37476526938347776`, 0.4986237900384425, 0.945115364090962], 
             UndirectedEdge[83, 155] -> 
             RGBColor[
              0.21429563561346426`, 0.34256867853076955`, 0.9355151914749793],
              UndirectedEdge[62, 199] -> 
             RGBColor[
              0.5868878667757954, 0.648392143438405, 0.8070978104506135], 
             UndirectedEdge[96, 278] -> 
             RGBColor[
              0.5041987109200126, 0.6070709568623011, 0.9544705154158305], 
             UndirectedEdge[2, 178] -> 
             RGBColor[
              0.25390682555337085`, 0.3842025506521106, 0.9377709901425528], 
             UndirectedEdge[6, 213] -> 
             RGBColor[
              0.3667758904705204, 0.4918204598931879, 0.9446020161329686], 
             UndirectedEdge[79, 93] -> 
             RGBColor[
              0.46307011169266854`, 0.5733948534802826, 0.9513117589171669], 
             UndirectedEdge[270, 272] -> 
             RGBColor[
              0.22576785330449248`, 0.35462670670465335`, 0.9361685173008583],
              UndirectedEdge[161, 186] -> 
             RGBColor[
              0.22312007554742067`, 0.3518437244031648, 0.9360177302746292], 
             UndirectedEdge[189, 275] -> 
             RGBColor[
              0.22231351200262228`, 0.3509959749784993, 0.9359717976739568], 
             UndirectedEdge[260, 261] -> 
             RGBColor[
              0.6248975820608704, 0.7019966768640338, 0.9661118661321497], 
             UndirectedEdge[195, 200] -> 
             RGBColor[
              0.8525698587166832, 0.36168449538462955`, 0.19627498156345707`],
              UndirectedEdge[66, 110] -> 
             RGBColor[
              0.969700925487342, 0.9754692267738965, 0.8710436844734033], 
             UndirectedEdge[63, 172] -> 
             RGBColor[
              0.29700434513925705`, 0.4280429826559164, 0.940278707091565], 
             UndirectedEdge[4, 236] -> 
             RGBColor[
              0.5814156950940945, 0.671058479612787, 0.9601903197951254], 
             UndirectedEdge[143, 167] -> 
             RGBColor[
              0.5753382538779925, 0.6628795153036178, 0.9613047709389584], 
             UndirectedEdge[135, 249] -> 
             RGBColor[
              0.9043378524473125, 0.5669958495159765, 0.4896141522242598], 
             UndirectedEdge[135, 288] -> 
             RGBColor[
              0.9259984255937815, 0.7279896925534243, 0.5101410217698862], 
             UndirectedEdge[83, 214] -> 
             RGBColor[
              0.21458531177906248`, 0.342873146547343, 0.9355316881040727], 
             UndirectedEdge[36, 290] -> 
             RGBColor[
              0.6862499936639361, 0.7543721434480005, 0.9696708819958241], 
             UndirectedEdge[79, 119] -> 
             RGBColor[
              0.3385777508483834, 0.465228690511853, 0.9428846351776731], 
             UndirectedEdge[145, 264] -> 
             RGBColor[
              0.28193257724579573`, 0.4136593926161374, 0.9393670152410523], 
             UndirectedEdge[54, 238] -> 
             RGBColor[
              0.34796050319161576`, 0.47301253149465217`, 0.9434950557775005],
              UndirectedEdge[177, 273] -> 
             RGBColor[
              0.5185213619952923, 0.6190718502597115, 0.9554949527990644], 
             UndirectedEdge[98, 208] -> 
             RGBColor[
              0.3543834762769441, 0.47926414429235664`, 0.9438791178453103], 
             UndirectedEdge[125, 170] -> 
             RGBColor[
              0.9072593029227105, 0.5779612249611302, 0.303635751806013], 
             UndirectedEdge[22, 217] -> 
             RGBColor[
              0.812207338591908, 0.8532218130031827, 0.981916895067874], 
             UndirectedEdge[78, 236] -> 
             RGBColor[
              0.4016254852173745, 0.5057768385746106, 0.9485224868513811], 
             UndirectedEdge[86, 240] -> 
             RGBColor[
              0.984900576757397, 0.9592281782774306, 0.5233965503688487], 
             UndirectedEdge[59, 170] -> 
             RGBColor[
              0.8273517976845952, 0.21124347940377694`, 0.17382541839319265`],
              UndirectedEdge[95, 109] -> 
             RGBColor[
              0.7049075830694689, 0.7678615870686365, 0.9726151362943627], 
             UndirectedEdge[30, 252] -> 
             RGBColor[
              0.38136485218953986`, 0.5037401708621798, 0.9456156414781487], 
             UndirectedEdge[116, 119] -> 
             RGBColor[
              0.30231628529617693`, 0.4338208316047836, 0.9405740866574415], 
             UndirectedEdge[6, 231] -> 
             RGBColor[
              0.3753962033450712, 0.49928694163560083`, 0.9451512948466916], 
             UndirectedEdge[214, 275] -> 
             RGBColor[
              0.21283035575294662`, 0.34102857649325646`, 0.9354317459546102],
              UndirectedEdge[157, 257] -> 
             RGBColor[
              0.3686428791962128, 0.49372166625507674`, 0.944710576177652], 
             UndirectedEdge[128, 173] -> 
             RGBColor[
              0.24821711809960986`, 0.3782223073699194, 0.9374469697202291], 
             UndirectedEdge[14, 113] -> 
             RGBColor[
              0.8910534941556458, 0.5723590692569638, 0.5614811576965728], 
             UndirectedEdge[213, 231] -> 
             RGBColor[
              0.43649903669503015`, 0.5524952593309104, 0.9490343105306326], 
             UndirectedEdge[29, 148] -> 
             RGBColor[
              0.2408182206421652, 0.3704455970249514, 0.9370256134557156], 
             UndirectedEdge[109, 154] -> 
             RGBColor[
              0.8311843708271494, 0.8688646527411055, 0.9835913192515602], 
             UndirectedEdge[74, 123] -> 
             RGBColor[
              0.5372173592410554, 0.6347120461758202, 0.9568391339311428], 
             UndirectedEdge[189, 216] -> 
             RGBColor[
              0.24534319825395978`, 0.3752016353950986, 0.9372833042366027], 
             UndirectedEdge[29, 162] -> 
             RGBColor[
              0.2636748497853562, 0.39446936344843425`, 0.9383272646720675], 
             UndirectedEdge[73, 140] -> 
             RGBColor[
              0.3285420686985767, 0.45898835972736407`, 0.9421553879924971], 
             UndirectedEdge[9, 295] -> 
             RGBColor[
              0.677057217004213, 0.7458583971286377, 0.9697240169413682], 
             UndirectedEdge[169, 221] -> 
             RGBColor[
              0.2938192081333214, 0.4261529953348542, 0.9400439412854023], 
             UndirectedEdge[22, 61] -> 
             RGBColor[
              0.6921091843567939, 0.7582433580431021, 0.9707375877325777], 
             UndirectedEdge[11, 143] -> 
             RGBColor[
              0.3701279239778581, 0.49500793740441695`, 0.9448052019179649], 
             UndirectedEdge[100, 299] -> 
             RGBColor[
              0.9223324395514323, 0.6893504120322749, 0.46837744579024243`], 
             UndirectedEdge[181, 232] -> 
             RGBColor[
              0.8539568089581072, 0.8830700073511788, 0.7854666422842203], 
             UndirectedEdge[49, 292] -> 
             RGBColor[
              0.23980801296623738`, 0.36938380470668514`, 0.9369680836230397],
              UndirectedEdge[4, 39] -> 
             RGBColor[
              0.7035767257991387, 0.5642531295211515, 0.5840392270925523], 
             UndirectedEdge[33, 75] -> 
             RGBColor[
              0.8225875285373088, 0.8620961486244765, 0.9827484209506085], 
             UndirectedEdge[223, 271] -> 
             RGBColor[
              0.9324098595457874, 0.7585161356784191, 0.29733719959784854`], 
             UndirectedEdge[21, 34] -> 
             RGBColor[
              0.3554769401154252, 0.48231799156263766`, 0.943871654181607], 
             UndirectedEdge[51, 165] -> 
             RGBColor[
              0.986911243979133, 0.9683407522697562, 0.5670857457477134], 
             UndirectedEdge[36, 138] -> 
             RGBColor[
              0.7331275863556836, 0.791444109527867, 0.9740349644072682], 
             UndirectedEdge[50, 205] -> 
             RGBColor[
              0.44094793085644673`, 0.5542815920827796, 0.9498889293247207], 
             UndirectedEdge[237, 283] -> 
             RGBColor[
              0.6287512202285861, 0.7094875913580734, 0.9639167457294545], 
             UndirectedEdge[140, 245] -> 
             RGBColor[
              0.37623831770858585`, 0.5003004533366545, 0.945194550803278], 
             UndirectedEdge[19, 49] -> 
             RGBColor[
              0.26391083574794544`, 0.39471739965748975`, 0.9383407037235271],
              UndirectedEdge[235, 292] -> 
             RGBColor[
              0.24255033880224458`, 0.3722661630338292, 0.9371242550224929], 
             UndirectedEdge[15, 115] -> 
             RGBColor[
              0.230257062183032, 0.3593451498682808, 0.9364241711053016], 
             UndirectedEdge[69, 110] -> 
             RGBColor[
              0.9929919929128255, 0.9894341623619243, 0.625087695462787], 
             UndirectedEdge[34, 50] -> 
             RGBColor[
              0.33997412107403424`, 0.46889022890332593`, 0.9428838282608942],
              UndirectedEdge[126, 275] -> 
             RGBColor[
              0.21935857397151598`, 0.34789014775391436`, 0.9358035183245244],
              UndirectedEdge[59, 225] -> 
             RGBColor[
              0.8968865048957325, 0.5665897460383628, 0.24095041885999358`], 
             UndirectedEdge[82, 228] -> 
             RGBColor[
              0.9057099592960236, 0.9241653224619759, 0.8439169187539672], 
             UndirectedEdge[19, 280] -> 
             RGBColor[
              0.2796627567223554, 0.4112736673310683, 0.939237752320141], 
             UndirectedEdge[194, 283] -> 
             RGBColor[
              0.5672781592829315, 0.6595809911525545, 0.9590773611885706], 
             UndirectedEdge[63, 283] -> 
             RGBColor[
              0.4716182093057971, 0.5784225844464469, 0.9525129877054703], 
             UndirectedEdge[36, 245] -> 
             RGBColor[
              0.5919869457083973, 0.6770600343104392, 0.9624670806434741], 
             UndirectedEdge[3, 55] -> 
             RGBColor[
              0.327009852931445, 0.45469787926428074`, 0.9421662593982401], 
             UndirectedEdge[137, 192] -> 
             RGBColor[
              0.8552761720359909, 0.4155314079142499, 0.20016050967705595`], 
             UndirectedEdge[54, 251] -> 
             RGBColor[
              0.3520600889143901, 0.4773214560180356, 0.9437285211196189], 
             UndirectedEdge[252, 292] -> 
             RGBColor[
              0.2717964040404102, 0.4030056319067771, 0.9387897751721301], 
             UndirectedEdge[100, 121] -> 
             RGBColor[
              0.9223952272310946, 0.6887967573605129, 0.4252047095816714], 
             UndirectedEdge[142, 239] -> 
             RGBColor[
              0.5350790113196064, 0.6320396024840493, 0.9570335383591173], 
             UndirectedEdge[85, 299] -> 
             RGBColor[
              0.9570551059778822, 0.9653678956255696, 0.8666323773215838], 
             UndirectedEdge[120, 130] -> 
             RGBColor[
              0.18442078734008566`, 0.31116831882066576`, 0.9338138630616879],
              UndirectedEdge[9, 297] -> 
             RGBColor[
              0.6386143417337113, 0.7156866950327669, 0.9659294985140855], 
             UndirectedEdge[237, 239] -> 
             RGBColor[
              0.5249567920726707, 0.6240772116080362, 0.9560621419984239], 
             UndirectedEdge[169, 213] -> 
             RGBColor[
              0.36045188979201, 0.48517353421527176`, 0.944241873649848], 
             UndirectedEdge[46, 50] -> 
             RGBColor[
              0.32229358745653136`, 0.4520407279394575, 0.9418134628870861], 
             UndirectedEdge[105, 171] -> 
             RGBColor[
              0.3537618197336009, 0.4790225362534377, 0.9438286376877205], 
             UndirectedEdge[34, 114] -> 
             RGBColor[
              0.31595519138804573`, 0.44768545635926527`, 0.9413680379248031],
              UndirectedEdge[60, 240] -> 
             RGBColor[
              0.9605080040332614, 0.868110146524278, 0.47465486371626864`], 
             UndirectedEdge[19, 84] -> 
             RGBColor[
              0.2959425689542974, 0.42838478218655185`, 0.940164863542926], 
             UndirectedEdge[19, 48] -> 
             RGBColor[
              0.3524750293077462, 0.47810184855613913`, 0.9437395461742546], 
             UndirectedEdge[5, 77] -> 
             RGBColor[
              0.23349568981372465`, 0.3627491528489905, 0.9366086061577494]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {3}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.26920385108875294`, 0.4002806943772341, 0.9386421331168716], 
             160 -> RGBColor[
              0.5902199940802382, 0.6782062061588879, 0.9608834264625246], 
             245 -> RGBColor[
              0.4244026220080174, 0.5420179529125, 0.9482635376832157], 155 -> 
             RGBColor[
              0.21230278460535462`, 0.3404740657671945, 0.9354017015582263], 
             213 -> RGBColor[
              0.42787872382047937`, 0.5450287775884974, 0.9484850318169096], 
             27 -> RGBColor[
              0.2584384877012701, 0.38896561489352793`, 0.9380290615978824], 
             19 -> RGBColor[
              0.2912671539208582, 0.4234706245479727, 0.9398986055734284], 
             164 -> RGBColor[
              0.38392426951059677`, 0.5069576384803866, 0.9456842928556817], 
             190 -> RGBColor[
              0.22813210557574862`, 0.35711168574399543`, 0.9363031579701084],
              103 -> RGBColor[
              0.2788168781365947, 0.4103845953056338, 0.9391895807860471], 
             138 -> RGBColor[
              0.7066839033025902, 0.7707861033473555, 0.971399305210804], 291 -> 
             RGBColor[
              0.8179080138731872, 0.1386544187368418, 0.16478204035016009`], 
             28 -> RGBColor[
              0.22341264573171882`, 0.35215123421688327`, 0.9360343917138061],
              114 -> RGBColor[
              0.3044111891973746, 0.4372858390035616, 0.9406471389375684], 
             195 -> RGBColor[
              0.8191437574953648, 0.1481528857232069, 0.16596538983833015`], 
             93 -> RGBColor[
              0.5312094509757161, 0.6302987888719648, 0.9562379003465947], 34 -> 
             RGBColor[
              0.3274991935787168, 0.458085073714969, 0.9420889369120379], 161 -> 
             RGBColor[
              0.21627103797903324`, 0.3446449516647265, 0.9356276877173526], 
             22 -> RGBColor[
              0.8173789776787558, 0.8572619367637411, 0.982432355720336], 124 -> 
             RGBColor[
              0.9476938047146304, 0.9605107057164812, 0.973424924364235], 84 -> 
             RGBColor[
              0.30061798398773654`, 0.43329893982513096`, 0.9404311215124237],
              46 -> RGBColor[
              0.29213812634371106`, 0.4243860717872321, 0.9399482061644217], 
             241 -> RGBColor[
              0.2790754121939759, 0.4106563309919474, 0.9392043039181481], 
             185 -> RGBColor[
              0.5680702998089695, 0.6602240865171163, 0.9591397213924867], 
             121 -> RGBColor[
              0.9946101233350695, 0.9908799237508646, 0.6547233713644478], 
             126 -> RGBColor[
              0.22593857337368983`, 0.3548061443216573, 0.9361782395562414], 
             236 -> RGBColor[
              0.6232106502631707, 0.7049895070603167, 0.9634805717660004], 78 -> 
             RGBColor[
              0.1800403201715783, 0.3065641700889047, 0.9335644019367618], 
             254 -> RGBColor[
              0.8913219113450659, 0.5994000064779764, 0.23102867769365362`], 
             290 -> RGBColor[
              0.6129287179190951, 0.6966421711876226, 0.9626711403879157], 
             251 -> RGBColor[
              0.2867137638335649, 0.4186847228646212, 0.9396392967440941], 
             165 -> RGBColor[
              0.9802603651545728, 0.9450757179590131, 0.3778156754531135], 
             100 -> RGBColor[
              0.8501803311271197, 0.38671359097016134`, 0.19568604779889498`],
              235 -> RGBColor[
              0.24203916924704705`, 0.37172889142129484`, 0.937095144672532], 
             70 -> RGBColor[
              0.26423372362278924`, 0.39505677528622424`, 0.9383590917103296],
              234 -> RGBColor[0.817319, 0.134127, 0.164218], 257 -> 
             RGBColor[
              0.39130532114623406`, 0.5133507344247334, 0.9461546069390968], 
             135 -> RGBColor[
              0.9900957369634822, 0.9901723469535194, 0.8138028001335977], 
             265 -> RGBColor[
              0.22246582468563886`, 0.3511560652655316, 0.9359804716559281], 
             111 -> RGBColor[
              0.24301438028138522`, 0.37275390005033504`, 0.937150681498242], 
             182 -> RGBColor[
              0.3071831062866214, 0.4401992996140543, 0.9408049955151171], 
             188 -> RGBColor[
              0.20571498311483435`, 0.33354986870991854`, 0.9350265360091202],
              154 -> RGBColor[
              0.7412000832467709, 0.797750405452433, 0.9748395554555993], 269 -> 
             RGBColor[
              0.2270252964366493, 0.35594835916304945`, 0.9362401268270142], 
             208 -> RGBColor[
              0.28595975701387044`, 0.41789221389032877`, 0.9395963571711656],
              86 -> RGBColor[
              0.9748675947682047, 0.926884637163092, 0.35686578084130904`], 
             119 -> RGBColor[
              0.28222472928714576`, 0.41396646293510553`, 0.9393836528676069],
              140 -> RGBColor[
              0.3280740134091542, 0.4585829537608091, 0.9421255639233401], 85 -> 
             RGBColor[
              0.9196256639800194, 0.938748558156751, 0.9921959108615778], 242 -> 
             RGBColor[
              0.24043240470913427`, 0.3700400800171928, 0.9370036418090929], 
             117 -> RGBColor[
              0.20347429876271564`, 0.33119476738824843`, 0.9348989323500625],
              47 -> RGBColor[
              0.6440597930627512, 0.7218636724671273, 0.9651575191576801], 81 -> 
             RGBColor[
              0.29584127485450173`, 0.42827831566524976`, 0.9401590949937939],
              275 -> RGBColor[
              0.21277857456934213`, 0.34097415118617147`, 0.9354287970928072],
              23 -> RGBColor[
              0.2963741173821658, 0.42883836694599214`, 0.9401894395874745], 
             110 -> RGBColor[
              0.9929459767177286, 0.9913509943397207, 0.7665669512217009], 6 -> 
             RGBColor[
              0.3056730571205615, 0.43861214219787836`, 0.9407190004490276], 
             218 -> RGBColor[
              0.2560427236071457, 0.38644751493038626`, 0.9378926263769374], 
             108 -> RGBColor[
              0.3439204196877902, 0.4723083144158259, 0.943135282918988], 297 -> 
             RGBColor[
              0.7603990286995737, 0.8127487675575523, 0.9767531269139887], 
             157 -> RGBColor[
              0.34598043724619154`, 0.47409259808542004`, 0.9432665454162072],
              270 -> RGBColor[
              0.22825539451058077`, 0.357241270231474, 0.9363101790925575], 
             33 -> RGBColor[
              0.9146626577353835, 0.9347911916944939, 0.9917225348954364], 
             252 -> RGBColor[
              0.30053129972337833`, 0.4332078291671907, 0.9404261849718064], 
             260 -> RGBColor[
              0.8491537797280463, 0.8825561905625664, 0.9854742396306309], 
             159 -> RGBColor[
              0.2473937360801429, 0.37735688066202433`, 0.937400079332305], 
             183 -> RGBColor[
              0.25458949129815345`, 0.38492007563338526`, 0.9378098669468048],
              99 -> RGBColor[
              0.3674883934084197, 0.4927217086918333, 0.9446370133641255], 17 -> 
             RGBColor[
              0.29622239326445615`, 0.42867889527841463`, 0.9401807991234267],
              277 -> 
             RGBColor[
              0.34909505354151776`, 0.4767903221752649, 0.9434650060123984], 
             104 -> RGBColor[
              0.28507184392659923`, 0.4169589609386654, 0.9395457918343952], 
             79 -> RGBColor[
              0.39493077240962093`, 0.5164909180886005, 0.9463856174877392], 
             191 -> RGBColor[
              0.24388899418338073`, 0.37367317471505657`, 0.9372004894660854],
              50 -> RGBColor[
              0.35244904856935166`, 0.4796953840916829, 0.9436787196097506], 
             225 -> RGBColor[
              0.9609628542707439, 0.8799806824768295, 0.3028484896985869], 61 -> 
             RGBColor[
              0.5668393910348319, 0.659224779322463, 0.9590428197448192], 196 -> 
             RGBColor[
              0.2809324202458739, 0.4126081641956031, 0.9393100577795065], 1 -> 
             RGBColor[
              0.41852266255485593`, 0.5369250275695268, 0.9478888718663042], 
             263 -> RGBColor[
              0.26098356523640104`, 0.3916406527501864, 0.9381739999984032], 
             201 -> RGBColor[
              0.32111303850258816`, 0.4525537071655133, 0.9416820167576422], 
             293 -> RGBColor[
              0.20926131084396443`, 0.33727728400339907`, 0.9352284941269724],
              184 -> RGBColor[
              0.23743710807503443`, 0.3668918333419784, 0.9368330640969252], 
             106 -> RGBColor[
              0.6566687686170058, 0.7317139000018745, 0.9664142640033524], 
             206 -> RGBColor[
              0.23667377020378227`, 0.366089516840876, 0.9367895931344146], 
             247 -> RGBColor[
              0.5790882470358998, 0.6691689524288044, 0.9600070945582612], 
             220 -> RGBColor[
              0.25719173910326026`, 0.38765520306859286`, 0.937958061109625], 
             107 -> RGBColor[
              0.8341470216086144, 0.26347454816989946`, 0.18033253249694123`],
              131 -> RGBColor[
              0.324831212684851, 0.4557742027613212, 0.9419189355286837], 127 -> 
             RGBColor[
              0.8327720947194103, 0.2529062576026711, 0.17901590095508144`], 
             210 -> RGBColor[
              0.37855708825470646`, 0.5023088558389079, 0.9453423008120684], 
             181 -> RGBColor[
              0.7138170777657293, 0.7763585934520937, 0.9721102733779844], 
             194 -> RGBColor[
              0.5158331891976378, 0.6178156468678216, 0.9550274246943216], 
             118 -> RGBColor[
              0.17892956896395254`, 0.30539670014399584`, 0.9335011462986966],
              276 -> 
             RGBColor[
              0.23178154572615212`, 0.3609474787299394, 0.9365109881878111], 
             280 -> RGBColor[
              0.2680583595238526, 0.3990767101141639, 0.9385768990668534], 
             189 -> RGBColor[
              0.2318484494359024, 0.3610177987708272, 0.9365147982551062], 
             168 -> RGBColor[
              0.3858730274799788, 0.5086455546860418, 0.9458084659902717], 41 -> 
             RGBColor[
              0.35699077137457635`, 0.483629196111943, 0.9439681141708117], 
             14 -> RGBColor[
              0.8226976998778256, 0.17547004422228246`, 0.1693686490773784], 
             77 -> RGBColor[
              0.2460324096232273, 0.37592604024272347`, 0.9373225538044856], 
             51 -> RGBColor[
              0.993562122803693, 0.9916057865804992, 0.7563558160423134], 179 -> 
             RGBColor[
              0.9936465744084931, 0.9916407094893913, 0.7549562343970292], 
             223 -> RGBColor[
              0.8873547734207121, 0.5813861597120881, 0.22771840056612383`], 
             292 -> RGBColor[
              0.24306150835744214`, 0.3728034346463635, 0.9371533653724538], 
             143 -> RGBColor[
              0.39675004724917656`, 0.5180666825152114, 0.9465015400717941], 
             112 -> RGBColor[
              0.2522134290242518, 0.3824226835324653, 0.9376745537153752], 
             197 -> RGBColor[
              0.2105002400012672, 0.3385794771003698, 0.9352990493096494], 54 -> 
             RGBColor[
              0.4174064139952154, 0.53595818917145, 0.9478177454951437], 71 -> 
             RGBColor[
              0.6295965520330332, 0.7101738697986875, 0.963983293345653], 177 -> 
             RGBColor[
              0.41920763486506846`, 0.5375183161569235, 0.9479325176962138], 
             158 -> RGBColor[
              0.40363205630183896`, 0.524027532856795, 0.9469400556031081], 
             226 -> RGBColor[
              0.178927010221482, 0.30539401074342565`, 0.9335010005820983], 
             203 -> RGBColor[
              0.2595939437592997, 0.3901800724706624, 0.9380948631110431], 
             115 -> RGBColor[
              0.2215913444714862, 0.35023693111520926`, 0.9359306713014096], 
             173 -> RGBColor[
              0.25717362368840185`, 0.38763616261899303`, 0.9379570294635482],
              212 -> RGBColor[
              0.21172080019279638`, 0.3398623632496528, 0.9353685584068999], 
             129 -> RGBColor[
              0.23590943272644063`, 0.36528614969039486`, 0.9367460652458159],
              279 -> 
             RGBColor[
              0.25879261498995565`, 0.3893378251269034, 0.9380492286230886], 
             26 -> RGBColor[
              0.9858349896506369, 0.9884104184434465, 0.8844144095680297], 40 -> 
             RGBColor[
              0.2372124705557414, 0.3666557250663601, 0.9368202713225229], 
             146 -> RGBColor[
              0.23045057360750168`, 0.3595485426447314, 0.9364351912946507], 
             192 -> RGBColor[
              0.8649861375675162, 0.47981540863036076`, 0.20905346250477896`],
              300 -> RGBColor[
              0.2558608387541249, 0.3862563424176957, 0.9378822683036323], 
             221 -> RGBColor[
              0.29461336050310216`, 0.4269876998276622, 0.9400891670880182], 
             62 -> RGBColor[
              0.9948487335515908, 0.9913902868768101, 0.6806946209012268], 
             286 -> RGBColor[
              0.5590358689967736, 0.6528895285873056, 0.9584284979047402], 
             152 -> RGBColor[
              0.25329610735962166`, 0.38356064710871024`, 0.9377362106448954],
              64 -> RGBColor[
              0.23365539790008147`, 0.3629170161738291, 0.9366177012970005], 
             37 -> RGBColor[
              0.6807027709206555, 0.7504894452666685, 0.968809748742459], 148 -> 
             RGBColor[
              0.23881348570074337`, 0.36833849349398035`, 0.9369114467665411],
              261 -> RGBColor[
              0.4006413843936947, 0.5214371631655013, 0.9467494926336685], 15 -> 
             RGBColor[
              0.23892277989457777`, 0.36845336862135236`, 0.9369176709091936],
              136 -> RGBColor[
              0.9929076697798414, 0.9872385477406899, 0.46942180820333496`], 
             198 -> RGBColor[
              0.4642553566460736, 0.5759424388475844, 0.9509670287800365], 63 -> 
             RGBColor[
              0.32451328924336914`, 0.4554988334556064, 0.9418986777281211], 
             171 -> RGBColor[
              0.4183533072547869, 0.5367783405206518, 0.9478780806963388], 59 -> 
             RGBColor[
              0.8328101555207211, 0.25319880959989605`, 0.17905234802140027`],
              229 -> RGBColor[
              0.34638875058307517`, 0.4744462585754037, 0.9432925627809762], 
             102 -> RGBColor[
              0.38532279281260967`, 0.5081689690727651, 0.9457734055238204], 
             299 -> RGBColor[
              0.9944845479757449, 0.9919872330943883, 0.7410688437815899], 
             128 -> RGBColor[
              0.23926061251081787`, 0.3688084521208458, 0.93693690997691], 12 -> 
             RGBColor[
              0.20154157699751735`, 0.32916335427138743`, 0.93478886670474], 
             222 -> RGBColor[
              0.43613267935432526`, 0.5521779390160471, 0.94901096656484], 92 -> 
             RGBColor[
              0.261097249315751, 0.3917601419255701, 0.9381804741385418], 271 -> 
             RGBColor[
              0.9774649456708626, 0.9356461116447503, 0.3669559986295733], 
             132 -> RGBColor[
              0.2067120462521808, 0.3345978452847238, 0.9350833172797693], 80 -> 
             RGBColor[
              0.26782978190622225`, 0.39883646054537636`, 0.9385638819096797],
              244 -> RGBColor[
              0.24251120685435607`, 0.3722250328754895, 0.9371220265159511], 
             150 -> RGBColor[
              0.9620063021321176, 0.9711849428558795, 0.9491975995336027], 
             125 -> RGBColor[
              0.9926251659969516, 0.9866343007146026, 0.4386730148470409], 
             133 -> RGBColor[
              0.35014705105926486`, 0.47770150955020474`, 0.9435320383639844],
              258 -> RGBColor[
              0.9617670348256762, 0.9710064976904998, 0.9496026166724999], 
             255 -> RGBColor[
              0.9589543367125869, 0.8732054811308165, 0.29504577826186157`], 
             176 -> RGBColor[
              0.1789518783186532, 0.305420148690281, 0.9335024167834431], 230 -> 
             RGBColor[
              0.24935218422087857`, 0.37941533383072157`, 0.9375116100566555],
              274 -> RGBColor[
              0.9645754531953188, 0.8921668269279859, 0.3168827543384975], 87 -> 
             RGBColor[
              0.27610729667649436`, 0.4075366533936812, 0.9390352741303609], 
             130 -> RGBColor[0.178927, 0.305394, 0.933501], 35 -> 
             RGBColor[
              0.2262311772849768, 0.3551136895845794, 0.9361949029161204], 31 -> 
             RGBColor[
              0.6188367246795077, 0.7014385572283971, 0.9631362403218372], 18 -> 
             RGBColor[
              0.9464007204285422, 0.9595463255731478, 0.9756137787701872], 24 -> 
             RGBColor[
              0.9556367854010767, 0.9664345677069957, 0.9599795299232305], 
             151 -> RGBColor[
              0.443273542823118, 0.5583629960424816, 0.9494659760706539], 137 -> 
             RGBColor[
              0.8455662065044656, 0.351247407198139, 0.19126755684933291`], 
             296 -> RGBColor[
              0.6962355794932261, 0.7626237933772783, 0.9703579139386239], 
             266 -> RGBColor[
              0.24763395401992835`, 0.3776093649474359, 0.9374137593886052], 
             283 -> 
             RGBColor[
              0.6187231293682252, 0.7013463354372874, 0.9631272976828197], 
             284 -> RGBColor[
              0.25564421936180226`, 0.3860286617019018, 0.9378699321496993], 
             238 -> RGBColor[
              0.2785145923880161, 0.4100668738178543, 0.9391723660598572], 72 -> 
             RGBColor[
              0.6518075404484566, 0.7279162716099014, 0.9659297422102715], 
             288 -> RGBColor[
              0.8619011142240809, 0.46580703815332913`, 0.20647924340617463`],
              172 -> RGBColor[
              0.26949540103514497`, 0.4005871318562264, 0.9386587364550091], 
             243 -> RGBColor[
              0.21816661637866602`, 0.3466373247493527, 0.9357356381029547], 
             88 -> RGBColor[
              0.5042211596463271, 0.6083884781620977, 0.9541132831917766], 
             273 -> RGBColor[
              0.6178350891255162, 0.7006253843624993, 0.9630573879019151], 
             202 -> RGBColor[
              0.22812105044609293`, 0.3571000661017916, 0.9363025283968291], 
             98 -> RGBColor[
              0.4228071955400177, 0.5406360746943846, 0.948161878519455], 30 -> 
             RGBColor[
              0.46219840465570133`, 0.574272512557169, 0.9508050979844909], 
             116 -> RGBColor[
              0.3224078413052081, 0.4536752002744616, 0.941764520447276], 240 -> 
             RGBColor[
              0.9949335587465892, 0.9915717193917691, 0.6899273198963884], 73 -> 
             RGBColor[
              0.3290101239879992, 0.459393765693919, 0.9421852120616541], 29 -> 
             RGBColor[
              0.24282295558358705`, 0.3725527005559224, 0.9371397801448899], 
             75 -> RGBColor[
              0.7305123993392341, 0.7894011055544591, 0.9737743070057807], 
             200 -> RGBColor[
              0.8859959599380017, 0.5752161050460523, 0.226584573288584], 156 -> 
             RGBColor[
              0.2276990046313701, 0.35665646919126776`, 0.9362784935120415], 
             25 -> RGBColor[
              0.2518103509231395, 0.3819990228915686, 0.9376515990138174], 38 -> 
             RGBColor[
              0.4179442959916355, 0.5364240755220139, 0.9478520188603253], 3 -> 
             RGBColor[
              0.3773249031069595, 0.5012415989953558, 0.9452637870640326], 57 -> 
             RGBColor[
              0.24705297562595502`, 0.37699871981921224`, 0.9373806735285489],
              227 -> RGBColor[
              0.25976518882652405`, 0.3903600618938796, 0.9381046152642871], 
             39 -> 
             RGBColor[
              0.8675327116732591, 0.4913788068770457, 0.21117838636085415`], 
             109 -> RGBColor[
              0.9211686584075277, 0.939978900029778, 0.992343083047521], 256 -> 
             RGBColor[
              0.9952479751456992, 0.992244224277091, 0.7241496045864151], 287 -> 
             RGBColor[
              0.9409750107809423, 0.8036926171977683, 0.27136531206102255`], 
             239 -> RGBColor[
              0.4111342730563943, 0.530525575937213, 0.9474180902207585], 285 -> 
             RGBColor[0.382771346863294, 0.50595903483087, 0.945610829644085],
              216 -> RGBColor[
              0.2588379470720171, 0.38938547201937, 0.9380518102180992], 21 -> 
             RGBColor[
              0.38345468665213356`, 0.5065509094103063, 0.9456543714511763], 
             175 -> RGBColor[
              0.2945111830148827, 0.42688030480911665`, 0.9400833482312222], 
             7 -> RGBColor[
              0.394746751143397, 0.516331528116975, 0.946373891815379], 13 -> 
             RGBColor[
              0.30612838775897044`, 0.4390907235684761, 0.9407449308552837], 
             294 -> RGBColor[
              0.209897553009386, 0.33794601485934034`, 0.9352647271770572], 
             193 -> RGBColor[
              0.39949775357450523`, 0.5204466076304757, 0.9466766214891428], 
             60 -> RGBColor[
              0.9260824493199337, 0.7446485736567867, 0.2593824075361489], 65 -> 
             RGBColor[
              0.28791659856684826`, 0.41994897843342893`, 0.9397077964027201],
              69 -> RGBColor[
              0.9930380091079225, 0.9875173303841278, 0.48360843970387296`], 
             217 -> RGBColor[
              0.80703569950506, 0.8491816892426243, 0.9814014344154122], 214 -> 
             RGBColor[
              0.21288213693655111`, 0.34108300180034146`, 0.9354346948164131],
              170 -> RGBColor[
              0.8218934398484693, 0.16928814920765783`, 0.168598488764985], 
             74 -> RGBColor[
              0.6382140736915616, 0.7171699620960075, 0.9646616962176343], 
             246 -> RGBColor[
              0.5988679170367666, 0.6852269795994871, 0.961564222636048], 264 -> 
             RGBColor[
              0.2946613034028385, 0.4270380908550406, 0.940091897365233], 278 -> 
             RGBColor[
              0.6029315110482949, 0.6885259882808699, 0.9618841236420709], 45 -> 
             RGBColor[
              0.8578237913971699, 0.4454645759914146, 0.2030054339855487], 
             237 -> RGBColor[
              0.638779311088947, 0.7176288472788594, 0.9647061937760893], 228 -> 
             RGBColor[
              0.8163432429187892, 0.8564528128973794, 0.9823291233589543], 
             180 -> RGBColor[
              0.23402613491596813`, 0.3633066842836104, 0.936638814221599], 
             53 -> RGBColor[
              0.8317291195209172, 0.2448894931924079, 0.17801714672713256`], 
             48 -> RGBColor[
              0.4136829046946342, 0.5327330725643056, 0.9475804867750808], 5 -> 
             RGBColor[
              0.220958970004222, 0.34957226545525755`, 0.9358946585110132], 
             101 -> RGBColor[
              0.5465902564750337, 0.6427856196737024, 0.9574487336972479], 
             267 -> RGBColor[
              0.467847246129772, 0.578858496543228, 0.9512497954777179], 120 -> 
             RGBColor[
              0.18991457468017128`, 0.31694263764133146`, 0.9341267261233757],
              147 -> RGBColor[
              0.22619261942112945`, 0.35507316282496604`, 0.9361927071028155],
              89 -> RGBColor[
              0.27813245697413447`, 0.40966522526908, 0.9391506040133554], 43 -> 
             RGBColor[
              0.322173741643116, 0.45347243491334854`, 0.9417496038238137], 
             199 -> RGBColor[0.178927, 0.305394, 0.933501], 268 -> 
             RGBColor[
              0.2625163578880115, 0.3932517150116962, 0.938261290272349], 169 -> 
             RGBColor[
              0.2930250557635406, 0.42531829084204614`, 0.9399987154827865], 
             20 -> RGBColor[
              0.865905855945801, 0.8959138414156087, 0.9870720676150353], 4 -> 
             RGBColor[
              0.5396207399250182, 0.6371274521652572, 0.9569000678242504], 
             167 -> RGBColor[
              0.7539264605068086, 0.8076923480920241, 0.9761080018061227], 
             142 -> RGBColor[
              0.6590237495828186, 0.7335536290308857, 0.9666489864974762], 16 -> 
             RGBColor[
              0.9934703621130101, 0.9884420897444159, 0.5306673961342021], 
             281 -> RGBColor[
              0.8360763947567734, 0.2783045556433535, 0.18218010240253352`], 
             289 -> RGBColor[
              0.2909832679823188, 0.4231722424271597, 0.9398824386892002], 
             178 -> RGBColor[
              0.27705635157752495`, 0.4085341702682206, 0.9390893214029737], 
             58 -> RGBColor[
              0.5489231824340144, 0.6446795940643196, 0.9576323901745283], 
             186 -> RGBColor[
              0.2299691131158081, 0.3590424971416032, 0.9364077728319058], 
             122 -> 
             RGBColor[
              0.6241927467762723, 0.7057868172525964, 0.96355788600105], 249 -> 
             RGBColor[
              0.8185799679311427, 0.1438193520784336, 0.16542550431492184`], 
             113 -> RGBColor[
              0.9594092884334661, 0.9692480942916449, 0.9535936663157671], 52 -> 
             RGBColor[
              0.8177080186927622, 0.13711716814164848`, 0.16459052473952288`],
              187 -> RGBColor[
              0.3639294956023307, 0.48963917028760373`, 0.9444102435429313], 
             259 -> RGBColor[
              0.46426084954242974`, 0.5759468982282985, 0.9509674612009588], 
             42 -> RGBColor[
              0.2544378422070241, 0.3847606828235006, 0.9378012307554097], 
             134 -> RGBColor[
              0.27400077350385804`, 0.40532256397795713`, 0.9389153107520011],
              248 -> RGBColor[
              0.20835094833068457`, 0.3363204352816248, 0.9351766503286018], 
             174 -> RGBColor[
              0.3923234880848031, 0.5142326194523638, 0.9462194836360928], 
             215 -> RGBColor[
              0.9951032288756773, 0.9922430735458843, 0.7308157001748675], 83 -> 
             RGBColor[
              0.21628848662157388`, 0.34466329129434453`, 0.9356286813917323],
              95 -> RGBColor[
              0.48864650773140994`, 0.5957442741074949, 0.9528871895412045], 
             166 -> RGBColor[
              0.9927232541779302, 0.9868441014154793, 0.4493493080164732], 
             233 -> RGBColor[
              0.9940884990666902, 0.9897642221851048, 0.5979477888431959], 
             295 -> RGBColor[
              0.8372847792405768, 0.8730921717492939, 0.9843421637685542], 
             141 -> RGBColor[
              0.8990024464838272, 0.6342755227085348, 0.23743750448057996`], 
             205 -> RGBColor[
              0.5294468131435418, 0.6288678000738763, 0.9560991390396908], 
             224 -> RGBColor[
              0.9695247134417432, 0.9088618438807439, 0.33610969580648287`], 
             231 -> RGBColor[
              0.44511934956958094`, 0.5599617410733233, 0.9495835892443556], 
             68 -> RGBColor[
              0.8743662175245639, 0.5224081609419808, 0.2168804311477391], 10 -> 
             RGBColor[
              0.2114327980870659, 0.3395596547761419, 0.9353521571130395], 
             250 -> RGBColor[
              0.22258326386374316`, 0.3512795012877932, 0.9359871596433854], 
             282 -> RGBColor[
              0.9636570397640628, 0.9724160602789496, 0.9464033313040466], 
             232 -> 
             RGBColor[
              0.9940965401504851, 0.9897814212502639, 0.5988230111904562], 
             253 -> RGBColor[
              0.29672537087035056`, 0.42920755663283183`, 0.9402094429539937],
              55 -> RGBColor[
              0.2766948027559306, 0.4081541595332056, 0.9390687317324474], 91 -> 
             RGBColor[
              0.2726124428491967, 0.4038633404346605, 0.9388362473750692], 
             105 -> RGBColor[
              0.28917033221241484`, 0.4212667319862237, 0.9397791946791023], 
             36 -> RGBColor[
              0.7595712694087771, 0.8121021157083784, 0.9766706236037325], 
             123 -> RGBColor[
              0.43622064479054923`, 0.5522541302556329, 0.9490165716446514], 
             94 -> RGBColor[
              0.8619491220774967, 0.8927588492317026, 0.9866946708064583], 96 -> 
             RGBColor[
              0.40546591079173033`, 0.5256159254437323, 0.9470569071895901], 
             2 -> RGBColor[
              0.2307572995292167, 0.3598709310360006, 0.936452658882132], 262 -> 
             RGBColor[
              0.9939797374120591, 0.9895315920033393, 0.5861097539357399], 
             272 -> RGBColor[
              0.22328031209840418`, 0.35201214317783264`, 0.936026855509159], 
             97 -> RGBColor[
              0.2574804300414378, 0.3879586355486801, 0.9379745016314742], 
             209 -> RGBColor[
              0.2651563206276758, 0.3960264832343887, 0.938411632244898], 66 -> 
             RGBColor[
              0.9464558742569554, 0.9595874592080723, 0.9755204177251058], 
             139 -> RGBColor[
              0.25547870703592473`, 0.385854697753317, 0.9378605064675941], 
             56 -> RGBColor[
              0.5476923991281734, 0.6436803887304818, 0.9575354984041846], 
             144 -> RGBColor[
              0.3157094904678022, 0.4478734254480028, 0.9413377074550355], 
             298 -> RGBColor[
              0.28525208052382683`, 0.41714840103001194`, 0.9395560560419711],
              204 -> RGBColor[
              0.23088271225706164`, 0.36000274776459185`, 0.9364598009514513],
              207 -> RGBColor[
              0.7455882739599426, 0.8011784933890475, 0.9752769292959146], 
             149 -> RGBColor[
              0.2939489691399074, 0.4262893823800991, 0.9400513309827632], 
             219 -> RGBColor[
              0.27423499655804673`, 0.4055687472585089, 0.9389286494084351], 
             9 -> RGBColor[
              0.5168296547678491, 0.6186246225079816, 0.9551058701141822], 11 -> 
             RGBColor[
              0.34350580070653963`, 0.47194919229362253`, 0.9431088637641358],
              44 -> RGBColor[
              0.9650552642631052, 0.8937853423246256, 0.3187467297321304], 
             153 -> RGBColor[
              0.27348165172589245`, 0.40477693407509363`, 0.9388857475347178],
              32 -> RGBColor[
              0.2562574704790552, 0.38667322750850125`, 0.9379048558936031], 
             162 -> RGBColor[
              0.2845267439871254, 0.4163860263409461, 0.9395147491992453], 90 -> 
             RGBColor[
              0.4035464690461924, 0.5239534014776945, 0.9469346020588602], 8 -> 
             RGBColor[
              0.6518492866916434, 0.7279488840923621, 0.9659339030856515], 
             163 -> RGBColor[
              0.2413593551772921, 0.3710143637312809, 0.9370564302669542], 49 -> 
             RGBColor[
              0.23655451757503262`, 0.36596417476700677`, 0.9367828018736257],
              76 -> RGBColor[
              0.29429562032882867`, 0.4266537347586102, 0.9400710722551477], 
             82 -> RGBColor[
              0.9950766756732579, 0.9918778320265724, 0.7055047141489801], 67 -> 
             RGBColor[
              0.9123183312358003, 0.932921889378774, 0.9914989309411012], 211 -> 
             RGBColor[
              0.24235927283690456`, 0.3720653405899749, 
               0.9371133740984234]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9mHk4FFzYxsmSfR/LzGBWM2NmbHmlLHNH8aZCu0SWIkQLqbSgomQtVNoX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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 9}], {
             RGBColor[
             0.46767615866135254`, 0.5777748250387542, 0.9514973709902432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 11}], {
             RGBColor[
             0.3810142316306978, 0.5044371099315746, 0.9454988678152201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 20}], {
             RGBColor[
             0.6422142592503285, 0.7164194344925677, 0.9674804697406698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 37}], {
             RGBColor[
             0.5496127167377557, 0.6437072364180976, 0.9583493103043816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 43}], {
             RGBColor[
             0.370348202098986, 0.49519873124143765`, 0.944819237845059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 75}], {
             RGBColor[
             0.5745175309470449, 0.663163066561993, 0.9608315894360424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 102}], {
             RGBColor[
             0.40192272768373283`, 0.5225469983211459, 0.9468311386950623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 142}], {
             RGBColor[
             0.5387732060688373, 0.6352393283002062, 0.9572689291818902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 143}], {
             RGBColor[
             0.4076363549020162, 0.5274958550423691, 0.9471952059690492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 174}], {
             RGBColor[
             0.4054230753198295, 0.5255788235109453, 0.9470541777511985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 185}], {
             RGBColor[
             0.4932964811819127, 0.5985745570433215, 0.9535142966293955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 237}], {
             RGBColor[
             0.5286509868219015, 0.6272769374241931, 0.9562975328211968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 239}], {
             RGBColor[
             0.4148284678056251, 0.5337253017533699, 0.9476534810435313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 283}], {
             RGBColor[
             0.5186228959615405, 0.619135681503407, 0.955508084774562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 295}], {
             RGBColor[
             0.6279037208977163, 0.7050085996594103, 0.9661155178174292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 297}], {
             RGBColor[
             0.5894608456272148, 0.6748368975635395, 0.9623209993901465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 32}], {
             RGBColor[
             0.24350738500413596`, 0.3732720792722509, 0.9371787573878676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 83}], {
             RGBColor[
             0.2235228930753953, 0.35226711116517256`, 0.9360406701369322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 155}], {
             RGBColor[
             0.22153004206728566`, 0.3501724984015976, 0.9359271802201792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 156}], {
             RGBColor[
             0.2292281520802934, 0.3582637001136342, 0.9363655761970868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 178}], {
             RGBColor[
             0.25390682555337085`, 0.3842025506521106, 0.9377709901425528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 184}], {
             RGBColor[
             0.23409720380212556`, 0.3633813821889895, 0.9366428614895286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 202}], {
             RGBColor[
             0.22943917498765481`, 0.3584854985688961, 0.9363775936394806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 208}], {
             RGBColor[
             0.2583585282715436, 0.3888815724631647, 0.9380245080266488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 214}], {
             RGBColor[
             0.2218197182328839, 0.35047696641817105`, 0.9359436768492726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 268}], {
             RGBColor[
             0.2466368287086141, 0.37656132302384837`, 0.9373569745772405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 275}], {
             RGBColor[
             0.2217679370492794, 0.35042254111108606`, 0.9359407279874696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 17}], {
             RGBColor[
             0.3367736481857078, 0.4649602471368852, 0.9427222930937296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 30}], {
             RGBColor[
             0.4197616538813304, 0.5377570557762624, 0.9480344425242617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 38}], {
             RGBColor[
             0.3976345995492975, 0.5188328372586848, 0.9465579029621789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 55}], {
             RGBColor[
             0.327009852931445, 0.45469787926428074`, 0.9421662593982401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 74}], {
             RGBColor[
             0.5077694883992605, 0.6092057805456816, 0.9549627416408335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 90}], {
             RGBColor[
             0.39043568607657597`, 0.5125975002365252, 0.9460991945614463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[
             0.40677277394875433`, 0.5267478646254944, 0.9471401793543419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 144}], {
             RGBColor[
             0.34651719678738085`, 0.4745575122216793, 0.9433007472595341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 157}], {
             RGBColor[
             0.36165267017657554`, 0.4876670985403879, 0.9442651662401199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 229}], {
             RGBColor[
             0.3618568268450173, 0.48784392878537974`, 0.9442781749225044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 252}], {
             RGBColor[
             0.33892810141516894`, 0.46722471408127325`, 0.9428449860179196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 257}], {
             RGBColor[
             0.38431511212659675`, 0.5072961667100446, 0.9457091970015647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 259}], {
             RGBColor[
             0.42079287632469464`, 0.5385942486118271, 0.9481156241324957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 26}], {
             RGBColor[
             0.7627278647878275, 0.8127689353043519, 0.92065723869614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 39}], {
             RGBColor[
             0.7035767257991387, 0.5642531295211515, 0.5840392270925523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 52}], {
             RGBColor[
             0.6786643793088902, 0.3871223101534529, 0.5607452962818866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 78}], {
             RGBColor[
             0.3598305300482983, 0.47184581112708096`, 0.9452322348805061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 82}], {
             RGBColor[
             0.7673487077991381, 0.8145026420959148, 0.8312023909866153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 107}], {
             RGBColor[
             0.6868838807668163, 0.45030100016757835`, 0.5686163001605958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 130}], {
             RGBColor[
             0.3592738699625091, 0.4712607260826286, 0.9452005339121252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 193}], {
             RGBColor[
             0.46955924674976174`, 0.5787870298978665, 0.9517883446566966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 199}], {
             RGBColor[
             0.3592738699625091, 0.4712607260826286, 0.9452005339121252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 220}], {
             RGBColor[
             0.3984062395141392, 0.5123913276169251, 0.9474290644669376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.35927387507325015`, 0.47126073145434144`, 0.9452005342031744]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 228}], {
             RGBColor[
             0.6779819914219037, 0.7467901325313183, 0.9696145955916023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 236}], {
             RGBColor[
             0.5814156950940945, 0.671058479612787, 0.9601903197951254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 266}], {
             RGBColor[
             0.3936273469724733, 0.5073684085563466, 0.9471569136064277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 281}], {
             RGBColor[
             0.6878485673408958, 0.45771600390430534`, 0.5695400851133919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.23189096279390453`, 0.36106248300558996`, 0.9365172193279515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[
             0.23349568981372465`, 0.3627491528489905, 0.9366086061577494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 191}], {
             RGBColor[
             0.23242398209380136`, 0.36162272008515706`, 0.9365475739885493]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 248}], {
             RGBColor[
             0.21465495916745328`, 0.3429463503684412, 0.9355356544198075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 21}], {
             RGBColor[
             0.3445638718863475, 0.47258152580409235`, 0.9431866859501019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 34}], {
             RGBColor[
             0.31658612534963915`, 0.4483486079564237, 0.9414039686805327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 46}], {
             RGBColor[
             0.29890559173213627`, 0.4314991069925552, 0.9403336033067247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 50}], {
             RGBColor[
             0.32906105284495657`, 0.4591537631447806, 0.9421988600293891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 101}], {
             RGBColor[
             0.4261316567977976, 0.5406988809357904, 0.9490838670731377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 108}], {
             RGBColor[
             0.32479673840417583`, 0.4554602283068521, 0.9419271416840078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 114}], {
             RGBColor[
             0.30504212315896806`, 0.43794899060072, 0.940683069693298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 145}], {
             RGBColor[
             0.2874384541046572, 0.41944641828755624`, 0.9396805667829495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 169}], {
             RGBColor[
             0.299349056442051, 0.4319652165199622, 0.940358857965907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 187}], {
             RGBColor[
             0.3348012763614461, 0.46412565624274105`, 0.9425646219959795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 205}], {
             RGBColor[
             0.41755993513205164`, 0.5337399711358773, 0.9484090697443592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 213}], {
             RGBColor[
             0.3667758904705204, 0.4918204598931879, 0.9446020161329686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 219}], {
             RGBColor[
             0.2899540268393041, 0.4220904447281936, 0.9398238249287314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 221}], {
             RGBColor[
             0.3001432088118318, 0.4327999210127703, 0.9404040837685228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 231}], {
             RGBColor[
             0.3753962033450712, 0.49928694163560083`, 0.9451512948466916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 264}], {
             RGBColor[
             0.3001671802617, 0.4328251165264595, 0.9404054489071303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 9}], {
             RGBColor[
             0.45578820295562306`, 0.5674780753124783, 0.9507398809647807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 11}], {
             RGBColor[
             0.36912627592496833`, 0.4941403602052988, 0.9447413777897574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 43}], {
             RGBColor[
             0.3584602463932565, 0.4849019815151618, 0.9440617478195963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.40607658256930623`, 0.5261448586442126, 0.9470958186552614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 63}], {
             RGBColor[
             0.3596300201933831, 0.4859151807862907, 0.94413628477175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 106}], {
             RGBColor[
             0.5257077598802015, 0.6240227140594248, 0.9563940779093657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 131}], {
             RGBColor[
             0.359788981914124, 0.4860528654391481, 0.9441464136720313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 143}], {
             RGBColor[
             0.3957483991962868, 0.5171991053160931, 0.9464377159435866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 151}], {
             RGBColor[
             0.4190101469832575, 0.5373472620797284, 0.9479199339430164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 167}], {
             RGBColor[
             0.5743366058251028, 0.6620119381044995, 0.9612409468107508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 174}], {
             RGBColor[
             0.39353511961410004`, 0.5152820737846694, 0.9462966877257359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 185}], {
             RGBColor[
             0.4814085254761833, 0.5882778073170456, 0.9527568066039329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[
             0.4552899701705174, 0.5670735874923983, 0.9507006582548503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 283}], {
             RGBColor[
             0.5067349402558111, 0.6088389317771312, 0.9547505947490993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 297}], {
             RGBColor[
             0.5775728899214854, 0.6645401478372637, 0.9615635093646839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 22}], {
             RGBColor[
             0.7346141321851996, 0.7926054104280515, 0.9741831294029938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 47}], {
             RGBColor[
             0.6479545398771973, 0.7249062782797447, 0.9655457111216659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 61}], {
             RGBColor[
             0.6093443388632377, 0.6935868317074125, 0.9624883614152353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 72}], {
             RGBColor[
             0.6518284135700501, 0.7279325778511317, 0.9659318226479615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 177}], {
             RGBColor[
             0.5355284607783559, 0.6327336001246429, 0.9569332103909327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 217}], {
             RGBColor[
             0.7294424930983517, 0.7885652866674933, 0.9736676687505319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 247}], {
             RGBColor[
             0.6154687668637716, 0.6985589182605833, 0.9629704988219563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 267}], {
             RGBColor[
             0.5598482664107077, 0.6534036903177951, 0.9585918492816847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 271}], {
             RGBColor[
             0.814657116181253, 0.8317974978685563, 0.6664449508576125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 273}], {
             RGBColor[
             0.6348421879085798, 0.7142871342274307, 0.9644956454937833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 285}], {
             RGBColor[
             0.5173103167774687, 0.616953959461616, 0.9557723663648683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.43016772773719436`, 0.545286907400802, 0.949107366939159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 20}], {
             RGBColor[
             0.6913677553568252, 0.7572692319617951, 0.9710889688646087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 37}], {
             RGBColor[
             0.5987662128442524, 0.684557033887325, 0.9619578094283205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 43}], {
             RGBColor[
             0.41950169820548255`, 0.5360485287106651, 0.948427736968998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 63}], {
             RGBColor[
             0.42067147200560917`, 0.537061727981794, 0.9485022739211517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 75}], {
             RGBColor[
             0.6236710270535416, 0.7040128640312203, 0.9644400885599815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.5867492116924276, 0.675169261254928, 0.9607600670587673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 131}], {
             RGBColor[
             0.4208304337263501, 0.5371994126346513, 0.9485124028214329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 142}], {
             RGBColor[
             0.5879267021753338, 0.6760891257694337, 0.9608774283058292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 143}], {
             RGBColor[
             0.4567898510085129, 0.5683456525115964, 0.9508037050929882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 167}], {
             RGBColor[
             0.6353780576373289, 0.7131584853000028, 0.9656069359601525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 174}], {
             RGBColor[
             0.4545765714263261, 0.5664286209801727, 0.9506626768751375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 185}], {
             RGBColor[
             0.5424499772884093, 0.6394243545125489, 0.9571227957533345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 237}], {
             RGBColor[
             0.5778044829283981, 0.6681267348934206, 0.9599060319451358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 239}], {
             RGBColor[
             0.4639819639121217, 0.5745750992225973, 0.9512619801674704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 282}], {
             RGBColor[
             0.740243347265956, 0.7955203413934655, 0.9507546007091144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 283}], {
             RGBColor[
             0.5677763920680372, 0.6599854789726345, 0.959116583898501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 295}], {
             RGBColor[
             0.677057217004213, 0.7458583971286377, 0.9697240169413682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 297}], {
             RGBColor[
             0.6386143417337113, 0.7156866950327669, 0.9659294985140855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 117}], {
             RGBColor[
             0.20745354842489078`, 0.3353772110821952, 0.935125544731551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.22367111540675327`, 0.3524229022332684, 0.9360491111794278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 161}], {
             RGBColor[
             0.21385191803304957`, 0.3421023032204342, 0.935489922415196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 265}], {
             RGBColor[
             0.21694931138635237`, 0.3453578600208368, 0.9356663143844839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 269}], {
             RGBColor[
             0.2192290472618576, 0.3477540069695957, 0.9357961419700269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 43}], {
             RGBColor[
             0.3328397711748278, 0.46271081360348554`, 0.9424292337939748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 63}], {
             RGBColor[
             0.3340095449749544, 0.46372401287461446`, 0.9425037707461285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 131}], {
             RGBColor[
             0.3341685066956953, 0.46386169752747186`, 0.9425138996464097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 139}], {
             RGBColor[
             0.2994922538712322, 0.4289019450234698, 0.940484685115865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 143}], {
             RGBColor[
             0.3701279239778581, 0.49500793740441695`, 0.9448052019179649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 172}], {
             RGBColor[
             0.3065006008708423, 0.43626816207492447`, 0.9408838001095725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 174}], {
             RGBColor[
             0.36791464439567134`, 0.49309090587299315`, 0.9446641737001142]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 183}], {
             RGBColor[
             0.29904764600234657`, 0.4284346339635039, 0.9404593653554703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 185}], {
             RGBColor[
             0.4557880502577546, 0.5660866394053694, 0.9511242925783112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 283}], {
             RGBColor[
             0.4811144650373824, 0.586647763865455, 0.9531180807234778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 248}], {
             RGBColor[
             0.20494626266410096`, 0.3327418947765061, 0.9349827585166709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 58}], {
             RGBColor[
             0.4275257850964924, 0.5418851588163979, 0.949188660514906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 73}], {
             RGBColor[
             0.31756925587348483`, 0.44924224463119755`, 0.9414650714584689]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 95}], {
             RGBColor[
             0.3973874477451902, 0.5174174988379855, 0.946816060198244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 96}], {
             RGBColor[
             0.3557971492753504, 0.4823533245061042, 0.9439009190224369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 105}], {
             RGBColor[
             0.29764935998569264`, 0.4301787277773499, 0.9402620627671929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[
             0.3171012005840623, 0.44883683866464263`, 0.941435247389312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 149}], {
             RGBColor[
             0.30003867844943893`, 0.43269005297428764`, 0.9403981309190235]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 171}], {
             RGBColor[
             0.3622408475068787, 0.48793453204456394`, 0.9443115057758112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 245}], {
             RGBColor[
             0.36526550488349396`, 0.49055433824048805`, 0.9445042342692497]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 289}], {
             RGBColor[
             0.2985558278706446, 0.4311314829978179, 0.940313684772242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 298}], {
             RGBColor[
             0.2956902341413986, 0.428119562299244, 0.9401504934486273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 69}], {
             RGBColor[
             0.907867854492874, 0.581493687303205, 0.3264885443906257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 113}], {
             RGBColor[
             0.8910534941556458, 0.5723590692569638, 0.5614811576965728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 135}], {
             RGBColor[
             0.9063967184206538, 0.582821195587901, 0.4915857246054881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 224}], {
             RGBColor[
             0.8961112066597844, 0.5421659440515132, 0.2527391724419306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 249}], {
             RGBColor[
             0.8206388339044841, 0.15964469815035803`, 0.16739707669615012`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 254}], {
             RGBColor[
             0.8570098056114457, 0.3874350253501294, 0.200198663385516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 288}], {
             RGBColor[
             0.8422994070509533, 0.32063854118780577`, 0.1879239462417765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 19}], {
             RGBColor[
             0.265094966907718, 0.3959619965846625, 0.938408138241311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 49}], {
             RGBColor[
             0.2377386487348052, 0.36720877169417954`, 0.9368502363914097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 57}], {
             RGBColor[
             0.2429878777602664, 0.3727260442202823, 0.9371491722188713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 89}], {
             RGBColor[
             0.2585276184343561, 0.3890592969452162, 0.9380341374612745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 111}], {
             RGBColor[
             0.2409685800879815, 0.3706036343358437, 0.9370341762037178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.2455681044594148, 0.3754380260769088, 0.9372961123122845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 115}], {
             RGBColor[
             0.230257062183032, 0.3593451498682808, 0.9364241711053016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 146}], {
             RGBColor[
             0.2346866767510397, 0.3640009556330419, 0.9366764311019222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 175}], {
             RGBColor[
             0.2667169814547302, 0.3976668367152345, 0.9385005095702079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 212}], {
             RGBColor[
             0.22532179004368708`, 0.3541578659355026, 0.9361431146580468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 242}], {
             RGBColor[
             0.23967759230185604`, 0.3692467243192726, 0.9369606563591433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 243}], {
             RGBColor[
             0.2285446981366219, 0.35754534668535254`, 0.9363266545060742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 280}], {
             RGBColor[
             0.2534905697092152, 0.38376503936775813`, 0.9377472849880235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 294}], {
             RGBColor[
             0.2244101664519819, 0.3531996917403464, 0.9360911990431254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.9540665099241967, 0.9616166407194549, 0.7611949655148192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 44}], {
             RGBColor[
             0.9792628131880576, 0.9411137160345208, 0.4247070629331663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 53}], {
             RGBColor[
             0.9125997408169637, 0.6166657914684119, 0.3543422714306673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 59}], {
             RGBColor[
             0.9131402588168656, 0.620820449672156, 0.3548598720778012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 94}], {
             RGBColor[
             0.9277097420952534, 0.9406004694880592, 0.7586810334703302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 124}], {
             RGBColor[
             0.9705820834138202, 0.9744763977304486, 0.7520461602492186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 125}], {
             RGBColor[
             0.9930477640549809, 0.9875381952295093, 0.4846702054906215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 150}], {
             RGBColor[
             0.9777383321225639, 0.9798135163001478, 0.7399324978339024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 170}], {
             RGBColor[
             0.9076819009807398, 0.5788651194760369, 0.34963294244959353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 192}], {
             RGBColor[
             0.9292282498402631, 0.7341287491873884, 0.36986042931949054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 195}], {
             RGBColor[
             0.9063070598041875, 0.5682974877338114, 0.34831639298626615`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 200}], {
             RGBColor[
             0.939733161025506, 0.7818290973952341, 0.3786259847113931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 295}], {
             RGBColor[
             0.9153775706767935, 0.9307671307468549, 0.7575047799513781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 30}], {
             RGBColor[
             0.37921039896007874`, 0.5014757039177918, 0.9454929485539587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 38}], {
             RGBColor[
             0.3570833446280458, 0.48255148540021425`, 0.944016408991876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[
             0.2753301177357401, 0.4067197890509576, 0.9389910149394182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 48}], {
             RGBColor[
             0.35495264897954515`, 0.4807059839213601, 0.9438806429492537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 55}], {
             RGBColor[
             0.28645859801019335`, 0.41841652740581015`, 0.939624765427937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 84}], {
             RGBColor[
             0.2984201886260963, 0.4309889175517728, 0.9403059603179251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 90}], {
             RGBColor[
             0.3498844311553243, 0.4763161483780546, 0.9435577005911434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 97}], {
             RGBColor[
             0.27685141165294697`, 0.4083187654135474, 0.9390776503774505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 134}], {
             RGBColor[
             0.2851115833841571, 0.4170007296281859, 0.9395480549377139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 144}], {
             RGBColor[
             0.3059659418661292, 0.4382761603632087, 0.940759253289231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 158}], {
             RGBColor[
             0.34992722478314753`, 0.47635321406760484`, 0.9435604273632674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 159}], {
             RGBColor[
             0.2718080646722995, 0.4030178879702195, 0.9387904392278659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 175}], {
             RGBColor[
             0.29536678813966943`, 0.42777960004376564`, 0.9401320736773244]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 235}], {
             RGBColor[
             0.2691307812557516, 0.40020389334985473`, 0.9386379718979794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 252}], {
             RGBColor[
             0.29837684649391727`, 0.43094336222280266`, 0.9403034920476165]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 253}], {
             RGBColor[
             0.2964738820674033, 0.42894322595562323`, 0.9401951210387102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 292}], {
             RGBColor[
             0.26964195081094916`, 0.4007411649623891, 0.9386670822479402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 24}], {
             RGBColor[
             0.9510187529148094, 0.9629904466400717, 0.9677966543467089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 36}], {
             RGBColor[
             0.8529859949186596, 0.8858242206407632, 0.9761422011869598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 66}], {
             RGBColor[
             0.9464282973427488, 0.95956689239061, 0.9755670982476465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 69}], {
             RGBColor[
             0.9697193647682323, 0.9735318279786378, 0.7296111092370301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 88}], {
             RGBColor[
             0.7253109400374347, 0.7839674018676228, 0.9648635309809819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 113}], {
             RGBColor[
             0.9529050044310041, 0.9643972099323963, 0.9646037225429771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 135}], {
             RGBColor[
             0.9682482286960121, 0.9748593362633335, 0.8947082894518925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.7053280385373079, 0.7677443822103661, 0.9632904037751118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 222}], {
             RGBColor[
             0.6912666998914337, 0.7558621322945974, 0.9623123726675136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.9579627169351427, 0.9342040847269458, 0.6558617372883351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 254}], {
             RGBColor[
             0.918861315886804, 0.779473166025562, 0.6033212282319205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 258}], {
             RGBColor[
             0.9540838776271092, 0.9652764116318238, 0.9626081977213435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 260}], {
             RGBColor[
             0.8977772500782942, 0.9210512580678571, 0.980544009200409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 278}], {
             RGBColor[
             0.7746661157384185, 0.8240361569270088, 0.968748951206129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 288}], {
             RGBColor[
             0.9041509173263116, 0.7126766818632384, 0.5910465110881808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 290}], {
             RGBColor[
             0.7796647191738186, 0.8280942483803853, 0.9691424595790514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 48}], {
             RGBColor[
             0.3524750293077462, 0.47810184855613913`, 0.9437395461742546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 49}], {
             RGBColor[
             0.26391083574794544`, 0.39471739965748975`, 0.9383407037235271]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 57}], {
             RGBColor[
             0.2691600647734066, 0.40023467218359243`, 0.9386396395509886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 84}], {
             RGBColor[
             0.2959425689542974, 0.42838478218655185`, 0.940164863542926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 89}], {
             RGBColor[
             0.28469980544749635`, 0.41656792490852634`, 0.9395246047933918]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 111}], {
             RGBColor[
             0.2671407671011217, 0.39811226229915386`, 0.9385246435358352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 112}], {
             RGBColor[
             0.271740291472555, 0.402946654040219, 0.9387865796444018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 158}], {
             RGBColor[
             0.3474496051113486, 0.47374907870238386`, 0.9434193305882683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 175}], {
             RGBColor[
             0.2928891684678705, 0.42517546467854467`, 0.9399909769023254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 177}], {
             RGBColor[
             0.3552373943929633, 0.4804944703524481, 0.9439155616348212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 242}], {
             RGBColor[
             0.26584977931499626`, 0.39675535228258274`, 0.9384511236912607]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 253}], {
             RGBColor[
             0.2939962623956044, 0.42633909059040226`, 0.940054024263711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 280}], {
             RGBColor[
             0.2796627567223554, 0.4112736673310683, 0.939237752320141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 33}], {
             RGBColor[
             0.8902842568405922, 0.9153525165550513, 0.9893973012552358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 37}], {
             RGBColor[
             0.7733043134332283, 0.8232016433411387, 0.9779409081787471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 75}], {
             RGBColor[
             0.7982091276425176, 0.8426574734850338, 0.980423187310408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 124}], {
             RGBColor[
             0.9067998303302157, 0.928212273566045, 0.9802484959896351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 142}], {
             RGBColor[
             0.7624648027643098, 0.8147337352232472, 0.9768605270562558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 150}], {
             RGBColor[
             0.9139560790389594, 0.9335493921357441, 0.968134833574319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 167}], {
             RGBColor[
             0.8099161582263048, 0.8518030947538164, 0.981590034710579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 185}], {
             RGBColor[
             0.7169880778773853, 0.7780689639663625, 0.973105894503761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 200}], {
             RGBColor[
             0.8759509079419014, 0.7355649732308305, 0.6068283204518097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 237}], {
             RGBColor[
             0.752342583517374, 0.8067713443472341, 0.9758891306955624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 282}], {
             RGBColor[
             0.9147814478549319, 0.9341649508472791, 0.9667376994595409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 283}], {
             RGBColor[
             0.7423144926570131, 0.7986300884264481, 0.9750996826489275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 295}], {
             RGBColor[
             0.851595317593189, 0.8845030065824513, 0.9857071156917947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 297}], {
             RGBColor[
             0.8131524423226874, 0.8543313044865806, 0.981912597264512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 34}], {
             RGBColor[
             0.3554769401154252, 0.48231799156263766`, 0.943871654181607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 46}], {
             RGBColor[
             0.3377964064979223, 0.4654684905987692, 0.942801288807799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 50}], {
             RGBColor[
             0.3679518676107426, 0.4931231467509946, 0.9446665455304635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[
             0.32978099166431396`, 0.45704378140199375`, 0.9423448227907686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 101}], {
             RGBColor[
             0.4650224715635836, 0.5746682645420044, 0.9515515525742121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 108}], {
             RGBColor[
             0.3636875531699619, 0.4894296119130661, 0.9443948271850822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[
             0.3439329379247541, 0.47191837420693394`, 0.9431507551943723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 169}], {
             RGBColor[
             0.33823987120783705`, 0.46593460012617627`, 0.9428265434669814]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 187}], {
             RGBColor[
             0.3736920911272321, 0.49809503984895503`, 0.9450323074970538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 205}], {
             RGBColor[
             0.4564507498978377, 0.5677093547420913, 0.9508767552454336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 213}], {
             RGBColor[
             0.40566670523630644`, 0.5257898434994019, 0.9470697016340429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 264}], {
             RGBColor[
             0.339057995027486, 0.46679450013267343`, 0.9428731344082046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 61}], {
             RGBColor[
             0.6921091843567939, 0.7582433580431021, 0.9707375877325777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 72}], {
             RGBColor[
             0.7345932590636062, 0.7925891041868212, 0.9741810489653038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 177}], {
             RGBColor[
             0.6182933062719121, 0.6973901264603323, 0.9651824367082749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 217}], {
             RGBColor[
             0.812207338591908, 0.8532218130031827, 0.981916895067874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 247}], {
             RGBColor[
             0.6982336123573278, 0.7632154445962727, 0.9712197251392987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 267}], {
             RGBColor[
             0.642613111904264, 0.7180602166534845, 0.966841075599027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 271}], {
             RGBColor[
             0.8974219616748091, 0.8964540242042457, 0.6746941771749546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 273}], {
             RGBColor[
             0.717607033402136, 0.7789436605631201, 0.9727448718111256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 274}], {
             RGBColor[
             0.8909772154370372, 0.8747143818458635, 0.6496575550294168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 285}], {
             RGBColor[
             0.6000751622710249, 0.6816104857973055, 0.9640215926822105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[
             0.29610769611833376`, 0.428558341305621, 0.9401742672906341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 180}], {
             RGBColor[
             0.26520012614906696`, 0.3960725256148013, 0.9384141269045367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 267}], {
             RGBColor[
             0.3821106817559689, 0.50384843174461, 0.9457196175325961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 285}], {
             RGBColor[
             0.33957273212272987`, 0.46739870088843105`, 0.9429001346157797]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.7969254295463191, 0.8418022649015016, 0.9623206130704325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 113}], {
             RGBColor[
             0.9575230369172714, 0.9678413309993203, 0.9567865981194988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 135}], {
             RGBColor[
             0.9728662611822794, 0.9783034573302576, 0.8868911650284141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 224}], {
             RGBColor[
             0.9625807494214099, 0.9376482057938698, 0.6480446128648567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 233}], {
             RGBColor[
             0.9748626422338834, 0.9780993949460502, 0.7789636593832132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 254}], {
             RGBColor[
             0.9234793483730712, 0.7829172870924861, 0.5955041038084421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 259}], {
             RGBColor[
             0.7099488174717532, 0.7711907329676471, 0.9554734955620947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 260}], {
             RGBColor[
             0.9023952825645615, 0.924495379134781, 0.9727268847769307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 288}], {
             RGBColor[
             0.9087689498125788, 0.7161208029301624, 0.5832293866647026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 29}], {
             RGBColor[
             0.24731665325336327`, 0.3772758617237455, 0.9373956895793536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[
             0.2869920462831278, 0.4177357289024586, 0.9397006014188156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 77}], {
             RGBColor[
             0.24892138027318342`, 0.37896253156714604`, 0.9374870764091515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 91}], {
             RGBColor[
             0.2622113968861681, 0.3929311816631146, 0.9382439231944433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 139}], {
             RGBColor[
             0.25364452897953216`, 0.38392686032244283`, 0.9377560527407058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 147}], {
             RGBColor[
             0.2390014851721345, 0.36853609285826733`, 0.9369221530583165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 148}], {
             RGBColor[
             0.24531191831194143`, 0.3751687581927745, 0.9372815228901793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 172}], {
             RGBColor[
             0.2606528759791422, 0.3912930773738975, 0.9381551677344133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 203}], {
             RGBColor[
             0.2557021473412196, 0.3860895476811155, 0.9378732310624303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 206}], {
             RGBColor[
             0.2442420605634609, 0.3740442698662223, 0.937220596074116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 244}], {
             RGBColor[
             0.2471607788887478, 0.37711202788352904`, 0.9373868127648843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 270}], {
             RGBColor[
             0.24003287271686014`, 0.3696201465615213, 0.9369808890531874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 272}], {
             RGBColor[
             0.23754533151077184`, 0.36700558303470066`, 0.9368392272614883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 39}], {
             RGBColor[
             0.9266838506619479, 0.7398946126602461, 0.547796397964442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 59}], {
             RGBColor[
             0.9093225725856791, 0.6208046140216712, 0.5317333787947149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 60}], {
             RGBColor[
             0.9559587194852852, 0.8665294960501166, 0.5718984085520893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 62}], {
             RGBColor[
             0.9903418616011138, 0.9899003526601282, 0.7825545152346283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 82}], {
             RGBColor[
             0.9904558326619474, 0.9901441252350094, 0.7949595618585049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[
             0.9180076603888783, 0.6875620047068038, 0.5400502286834623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 127}], {
             RGBColor[
             0.9093035421850235, 0.6206583380230588, 0.5317151552615555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 130}], {
             RGBColor[
             0.5823809948253185, 0.6469022092217233, 0.9089577047840149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 137}], {
             RGBColor[
             0.9157005980775512, 0.6698289128207927, 0.5378409832086813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 170}], {
             RGBColor[
             0.903864214749553, 0.5788492838255521, 0.5265064491665074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 192}], {
             RGBColor[
             0.9254105636090766, 0.7341129135369036, 0.5467339360364043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 195}], {
             RGBColor[
             0.9024893735730009, 0.5682816520833267, 0.52518989970318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 199}], {
             RGBColor[
             0.5823809948253185, 0.6469022092217233, 0.9089577047840149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 220}], {
             RGBColor[
             0.6215133643769486, 0.6880328107560196, 0.9111862353388274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 226}], {
             RGBColor[
             0.5823809999360594, 0.646902214593436, 0.908957705075064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 228}], {
             RGBColor[
             0.901089116284713, 0.9224316156704129, 0.933371766463492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 266}], {
             RGBColor[
             0.6167344718352826, 0.6830098916954412, 0.9109140844783175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 32}], {
             RGBColor[
             0.25734797909016266`, 0.3878194212010146, 0.9379669587457427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 103}], {
             RGBColor[
             0.2686276829189324, 0.3996751050995809, 0.9386093211919647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 119}], {
             RGBColor[
             0.2703316084942079, 0.40146603891431676`, 0.9387063572327446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 152}], {
             RGBColor[
             0.2558672975304459, 0.3862631310011191, 0.9378826361213889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 268}], {
             RGBColor[
             0.2604774227946408, 0.3911086649526121, 0.9381451759351156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 35}], {
             RGBColor[
             0.2248219115083478, 0.35363246190073133`, 0.9361146473149633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 126}], {
             RGBColor[
             0.22467560955270433`, 0.3534786892692703, 0.9361063156350238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 163}], {
             RGBColor[
             0.23238600045450547`, 0.3615827989740821, 0.9365454109903801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 184}], {
             RGBColor[
             0.23042487690337662`, 0.35952153377943086`, 0.9364337279053656]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 189}], {
             RGBColor[
             0.22763054758381063`, 0.35658451649385525`, 0.9362745949844562]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 197}], {
             RGBColor[
             0.21695644286649302`, 0.3453653556586265, 0.9356667205117277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 211}], {
             RGBColor[
             0.2328859592843117, 0.3621082874034291, 0.9365738829061148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 216}], {
             RGBColor[
             0.24112529640186797`, 0.3707683531181266, 0.9370431009659527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 275}], {
             RGBColor[
             0.21809561015053047`, 0.3465626927015274, 0.9357315944033067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 293}], {
             RGBColor[
             0.21633697828784162`, 0.3447142591101412, 0.9356314429203892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 77}], {
             RGBColor[
             0.2444276826034072, 0.3742393703993229, 0.9372311669746878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 91}], {
             RGBColor[
             0.25771769921639187`, 0.38820802049529146`, 0.9379880137599795]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 148}], {
             RGBColor[
             0.2408182206421652, 0.3704455970249514, 0.9370256134557156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 162}], {
             RGBColor[
             0.2636748497853562, 0.39446936344843425`, 0.9383272646720675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 172}], {
             RGBColor[
             0.256159178309366, 0.3865699162060744, 0.9378992582999495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 191}], {
             RGBColor[
             0.24335597488348387`, 0.37311293763548947`, 0.9371701348054876]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 203}], {
             RGBColor[
             0.25120844967144335`, 0.38136638651329235`, 0.9376173216279664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 206}], {
             RGBColor[
             0.23974836289368467`, 0.3693211086983992, 0.9369646866396522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 244}], {
             RGBColor[
             0.24266708121897157`, 0.3723888667157059, 0.9371309033304205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 270}], {
             RGBColor[
             0.2355391750470839, 0.3648969853936982, 0.9367249796187237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 272}], {
             RGBColor[
             0.23305163384099561`, 0.36228242186687754`, 0.9365833178270244]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 38}], {
             RGBColor[
             0.4400713503236684, 0.5553482940395915, 0.949328558422408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 47}], {
             RGBColor[
             0.5531290988592262, 0.6480680925121483, 0.9579813085710855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 48}], {
             RGBColor[
             0.43794065467516774`, 0.5535027925607373, 0.9491927923797858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 74}], {
             RGBColor[
             0.5502062391736314, 0.6457212373265883, 0.9577333971010626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 90}], {
             RGBColor[
             0.4328724368509469, 0.5491129570174318, 0.9488698500216755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 123}], {
             RGBColor[
             0.44920952472312525`, 0.5632633214064009, 0.9499108348145711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 144}], {
             RGBColor[
             0.3889539475617518, 0.5110729690025859, 0.9460714027197632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 158}], {
             RGBColor[
             0.4329152304787701, 0.5491500227069821, 0.9488725767937995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 252}], {
             RGBColor[
             0.38136485218953986`, 0.5037401708621798, 0.9456156414781487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 257}], {
             RGBColor[
             0.42675186290096767`, 0.5438116234909512, 0.9484798524617939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 259}], {
             RGBColor[
             0.46322962709906557`, 0.5751097053927338, 0.9508862795927249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 36}], {
             RGBColor[
             0.6892039970441424, 0.7567703364683878, 0.9699034319627848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 51}], {
             RGBColor[
             0.8061994237416004, 0.8465221719044482, 0.8597460281820752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 58}], {
             RGBColor[
             0.583879953556761, 0.6730590756463584, 0.9603843152481828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 66}], {
             RGBColor[
             0.7826462994682315, 0.8305130082182347, 0.9693283290234715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 67}], {
             RGBColor[
             0.765577527957654, 0.8171802233035855, 0.9773175856314692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 73}], {
             RGBColor[
             0.47392342433375345`, 0.580416161461158, 0.9526607261917457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 95}], {
             RGBColor[
             0.5537416162054588, 0.648591415667946, 0.9580117149315208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 96}], {
             RGBColor[
             0.512151317735619, 0.6135272413360646, 0.9550965737557137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 109}], {
             RGBColor[
             0.7700026915435176, 0.8207087286290875, 0.9777396616846791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 110}], {
             RGBColor[
             0.8058913506986181, 0.8463947757840589, 0.8648515957717691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 138}], {
             RGBColor[
             0.662760313991049, 0.7361123302878763, 0.9672677727663206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 154}], {
             RGBColor[
             0.6800184039631393, 0.7495944813404151, 0.9689878978887183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 171}], {
             RGBColor[
             0.5185950159671473, 0.6191084488745244, 0.955507160509088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 245}], {
             RGBColor[
             0.5216196733437626, 0.6217282550704486, 0.9556998890025264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 156}], {
             RGBColor[
             0.24197823755521267`, 0.3716648483498845, 0.9370916747028223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 178}], {
             RGBColor[
             0.2666569110282901, 0.3976036988883609, 0.9384970886482884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 182}], {
             RGBColor[
             0.2817202883828383, 0.4134362635612778, 0.9393549257043601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 202}], {
             RGBColor[
             0.24218926046257408`, 0.37188664680514644`, 0.937103692145216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 208}], {
             RGBColor[
             0.27110861374646283`, 0.402282720699415, 0.9387506065323843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 268}], {
             RGBColor[
             0.2593869141835333, 0.38996247126009875`, 0.938083073082976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 37}], {
             RGBColor[
             0.7976827143280194, 0.8426403184805812, 0.9802661418189477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 75}], {
             RGBColor[
             0.8225875285373088, 0.8620961486244765, 0.9827484209506085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 94}], {
             RGBColor[
             0.8883058899064401, 0.9137750204630982, 0.9892086028509474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 124}], {
             RGBColor[
             0.931178231225007, 0.9476509487054876, 0.9825737296298357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 142}], {
             RGBColor[
             0.7868432036591011, 0.8341724103626897, 0.9791857606964562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 150}], {
             RGBColor[
             0.9383344799337505, 0.9529880672751867, 0.9704600672145196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 185}], {
             RGBColor[
             0.7413664787721765, 0.7975076391058051, 0.9754311281439616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 200}], {
             RGBColor[
             0.9003293088366926, 0.7550036483702731, 0.6091535540920102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 237}], {
             RGBColor[
             0.7767209844121652, 0.8262100194866766, 0.9782143643357628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 239}], {
             RGBColor[
             0.6628984653958889, 0.7326583838158534, 0.9695703125580974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 282}], {
             RGBColor[
             0.9391598487497231, 0.9536036259867218, 0.9690629330997416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 295}], {
             RGBColor[
             0.8759737184879801, 0.9039416817218939, 0.9880323493319954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 297}], {
             RGBColor[
             0.8375308432174786, 0.8737699796260231, 0.9842378309047126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 46}], {
             RGBColor[
             0.30981865996121394`, 0.44123557275110054`, 0.9410185715382298]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 50}], {
             RGBColor[
             0.33997412107403424`, 0.46889022890332593`, 0.9428838282608942]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 87}], {
             RGBColor[
             0.3018032451276056, 0.4328108635543251, 0.9405621055211995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 108}], {
             RGBColor[
             0.3357098066332535, 0.46519669406539743`, 0.9426121099155129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 114}], {
             RGBColor[
             0.31595519138804573`, 0.44768545635926527`, 0.9413680379248031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 169}], {
             RGBColor[
             0.3102621246711287, 0.4417016822785076, 0.9410438261974121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 187}], {
             RGBColor[
             0.34571434459052375`, 0.47386212200128636`, 0.9432495902274847]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 205}], {
             RGBColor[
             0.4284730033611293, 0.5434764368944227, 0.9490940379758643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 213}], {
             RGBColor[
             0.37768895869959807`, 0.5015569256517332, 0.9452869843644738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 227}], {
             RGBColor[
             0.2936321912026204, 0.4242225678044243, 0.9400967760881624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 264}], {
             RGBColor[
             0.31108024849077764`, 0.44256158228500475`, 0.9410904171386354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 92}], {
             RGBColor[
             0.24366421330036392`, 0.37343691575507476`, 0.9371876885273311]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 126}], {
             RGBColor[
             0.2260848753293333, 0.35495991695311835`, 0.9361865712361809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 163}], {
             RGBColor[
             0.23379526623113445`, 0.36306402665793014`, 0.9366256665915373]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 184}], {
             RGBColor[
             0.23183414268000563`, 0.3610027614632789, 0.9365139835065228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 189}], {
             RGBColor[
             0.2290398133604396, 0.3580657441777033, 0.9363548505856133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 197}], {
             RGBColor[
             0.218365708643122, 0.3468465833424746, 0.9357469761128849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 211}], {
             RGBColor[
             0.2342952250609407, 0.36358951508727716`, 0.936654138507272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 216}], {
             RGBColor[
             0.24253456217849695`, 0.3722495808019747, 0.9371233565671098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 275}], {
             RGBColor[
             0.21950487592715945`, 0.34804392038537546`, 0.9358118500044639]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 58}], {
             RGBColor[
             0.6542472259213957, 0.728390854886349, 0.9671515068891303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 66}], {
             RGBColor[
             0.8530135718328662, 0.8858447874582254, 0.9760955206644191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 67}], {
             RGBColor[
             0.8359448003222887, 0.8725120025435762, 0.9840847772724168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 69}], {
             RGBColor[
             0.8763046392583498, 0.8998097230462532, 0.7301395316538027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 88}], {
             RGBColor[
             0.6318962145275521, 0.7102452969352381, 0.9653919533977545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 95}], {
             RGBColor[
             0.6241088885700935, 0.7039231949079366, 0.9647789065724686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 96}], {
             RGBColor[
             0.5825185901002536, 0.6688590205760554, 0.9618637653966613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 109}], {
             RGBColor[
             0.8403699639081523, 0.8760405078690783, 0.9845068533256267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 113}], {
             RGBColor[
             0.8594902789211216, 0.8906751050000117, 0.9651321449597499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 138}], {
             RGBColor[
             0.7331275863556836, 0.791444109527867, 0.9740349644072682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 154}], {
             RGBColor[
             0.750385676327774, 0.8049262605804057, 0.9757550895296658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 198}], {
             RGBColor[
             0.6119133130274254, 0.6940222772779814, 0.9638188261918845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 222}], {
             RGBColor[
             0.5978519743815511, 0.6821400273622127, 0.9628407950842862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 224}], {
             RGBColor[
             0.8645479914252601, 0.8604819797945611, 0.6563901597051076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 245}], {
             RGBColor[
             0.5919869457083973, 0.6770600343104392, 0.9624670806434741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 258}], {
             RGBColor[
             0.8606691521172266, 0.8915543066994391, 0.9631366201381162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 260}], {
             RGBColor[
             0.8043625245684116, 0.8473291531354724, 0.9810724316171817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 278}], {
             RGBColor[
             0.681251390228536, 0.7503140519946241, 0.9692773736229017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 290}], {
             RGBColor[
             0.6862499936639361, 0.7543721434480005, 0.9696708819958241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 75}], {
             RGBColor[
             0.7056075851299448, 0.7699452754105638, 0.9712920278741198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 94}], {
             RGBColor[
             0.771325946499076, 0.8216241472491855, 0.9777522097744586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 102}], {
             RGBColor[
             0.5330127818666326, 0.6293292071697167, 0.9572915771331396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 124}], {
             RGBColor[
             0.8141982878176429, 0.8555000754915749, 0.971117336553347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 142}], {
             RGBColor[
             0.669863260251737, 0.742021537148777, 0.9677293676199676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 150}], {
             RGBColor[
             0.8213545365263866, 0.860837194061274, 0.9590036741380308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 185}], {
             RGBColor[
             0.6243865353648125, 0.7053567658918924, 0.9639747350674728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 237}], {
             RGBColor[
             0.6597410410048012, 0.7340591462727639, 0.9667579712592742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 239}], {
             RGBColor[
             0.5459185219885249, 0.6405075106019407, 0.9581139194816087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 282}], {
             RGBColor[
             0.8221799053423591, 0.8614527527728091, 0.9576065400232527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 283}], {
             RGBColor[
             0.6497129501444403, 0.725917890351978, 0.9659685232126394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 295}], {
             RGBColor[
             0.7589937750806162, 0.8117908085079812, 0.9765759562555065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 297}], {
             RGBColor[
             0.7205508998101146, 0.7816191064121104, 0.9727814378282238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 48}], {
             RGBColor[
             0.41581360034313486`, 0.5345785740431597, 0.947716252817703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 55}], {
             RGBColor[
             0.34731954937378307`, 0.4722891175276097, 0.9434603752963864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 74}], {
             RGBColor[
             0.5280791848415985, 0.6267970188090106, 0.9562568575389798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 90}], {
             RGBColor[
             0.41074538251891396`, 0.5301887384998543, 0.9473933104595927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 123}], {
             RGBColor[
             0.4270824703910924, 0.5443391028888234, 0.9484342952524883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 144}], {
             RGBColor[
             0.36682689322971884`, 0.49214875048500833`, 0.9445948631576804]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 158}], {
             RGBColor[
             0.41078817614673724`, 0.5302258041894045, 0.9473960372317167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 252}], {
             RGBColor[
             0.3592377978575069, 0.4848159523446023, 0.9441391019160659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 253}], {
             RGBColor[
             0.35733483343099304`, 0.48281581607742285`, 0.9440307309071595]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 257}], {
             RGBColor[
             0.4046248085689348, 0.5248874049733736, 0.9470033128997111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 259}], {
             RGBColor[
             0.44110257276703263`, 0.5561854868751561, 0.949409740030642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 52}], {
             RGBColor[
             0.8426203651830106, 0.3142479875093471, 0.1878844555501885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 59}], {
             RGBColor[
             0.8501714335969901, 0.3722888082384709, 0.1951153671911272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 60}], {
             RGBColor[
             0.8968075804965964, 0.6180136902669162, 0.2352803969485015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 62}], {
             RGBColor[
             0.931190722612425, 0.7413845468769279, 0.4459365036310404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 82}], {
             RGBColor[
             0.9313046936732585, 0.7416283194518091, 0.4583415502549171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 100}], {
             RGBColor[
             0.8588565214001893, 0.4390461989236035, 0.20343221707987458`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 107}], {
             RGBColor[
             0.8508398666409367, 0.3774266775234726, 0.1957554594288977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 127}], {
             RGBColor[
             0.8501524031963347, 0.3721425322398584, 0.1950971436579678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 136}], {
             RGBColor[
             0.9302201907265502, 0.7393086773088677, 0.34030009728209454`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 137}], {
             RGBColor[
             0.8565494590888623, 0.4213131070375924, 0.20122297160509353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 141}], {
             RGBColor[
             0.8832675790785431, 0.5628271647927903, 0.22430794542071705`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 170}], {
             RGBColor[
             0.8447130757608642, 0.3303334780423518, 0.18988843756291957`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 192}], {
             RGBColor[
             0.8662594246203876, 0.48559710775370324`, 0.21011592443281657`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 220}], {
             RGBColor[
             0.5623622253882596, 0.4395170049728193, 0.5745682237352395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 228}], {
             RGBColor[
             0.8419379772960242, 0.6739158098872126, 0.5967537548599042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 232}], {
             RGBColor[
             0.9308146259118721, 0.7405801140636548, 0.40500069877565514`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 266}], {
             RGBColor[
             0.5575833328465938, 0.4344940859122408, 0.5742960728747296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 281}], {
             RGBColor[
             0.8518045532150162, 0.3848416812601996, 0.19667924438169382`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.2625645345612948, 0.39330235174989453`, 0.9382640338626215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.25252112623098183`, 0.38274609280586824`, 0.9376920766161012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 162}], {
             RGBColor[
             0.2608696072714334, 0.3915208757036531, 0.9381675102608841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 191}], {
             RGBColor[
             0.24055073236956107`, 0.37016444989070835`, 0.9370103803943042]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 76}], {
             RGBColor[
             0.32564319585170254`, 0.45514146543527656`, 0.9420195932129798]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.4306059655104517, 0.5460088371370204, 0.9490406986812941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 99}], {
             RGBColor[
             0.362239582391498, 0.48817545240188814`, 0.9443025637674687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 104}], {
             RGBColor[
             0.3210313076505878, 0.45029407852530423`, 0.9417569530026035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 157}], {
             RGBColor[
             0.35148560431038395`, 0.4788608970986815, 0.9436173297935095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 201}], {
             RGBColor[
             0.3390519049385823, 0.4680914516387281, 0.942825065464227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 209}], {
             RGBColor[
             0.3110735460011261, 0.43982783967316585`, 0.9411898732078549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 222}], {
             RGBColor[
             0.3965617253644508, 0.517903567563995, 0.9464895403678258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 229}], {
             RGBColor[
             0.35168976097882576`, 0.47903772734367334`, 0.943630338475894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 259}], {
             RGBColor[
             0.41062581045850305`, 0.5297880471701207, 0.9474677876858852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 261}], {
             RGBColor[
             0.3788160778841355, 0.5025331796387221, 0.9453588034022401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 278}], {
             RGBColor[
             0.4799611412114356, 0.5860775921964064, 0.9529261189064413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 290}], {
             RGBColor[
             0.4849597446468357, 0.5901356836497829, 0.9533196272793637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 55}], {
             RGBColor[
             0.2655663224814774, 0.39645742117835314`, 0.9384349812439285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[
             0.25595913612423093`, 0.3863596591860904, 0.937887866193442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 134}], {
             RGBColor[
             0.26421930785544107`, 0.3950416234007289, 0.9383582707537054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 144}], {
             RGBColor[
             0.28507366633741316`, 0.4163170541357517, 0.9395694691052225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 159}], {
             RGBColor[
             0.2509157891435835, 0.3810587817427625, 0.9376006550438574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 235}], {
             RGBColor[
             0.24823850572703557`, 0.37824478712239773`, 0.9374481877139709]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 252}], {
             RGBColor[
             0.2774845709652012, 0.40898425599534566`, 0.939113707863608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 292}], {
             RGBColor[
             0.24874967528223313`, 0.3787820587349321, 0.9374772980639317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 63}], {
             RGBColor[
             0.3233435154432426, 0.45448563418447746`, 0.9418241407759673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 131}], {
             RGBColor[
             0.3235024771639835, 0.45462331883733487`, 0.9418342696762487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 139}], {
             RGBColor[
             0.2888262243395204, 0.4196635663333328, 0.9398050551457039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 143}], {
             RGBColor[
             0.3594618944461463, 0.48576955871427996`, 0.9441255719478039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 172}], {
             RGBColor[
             0.2958345713391305, 0.4270297833847875, 0.9402041701394114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 174}], {
             RGBColor[
             0.35724861486395953`, 0.48385252718285615`, 0.9439845437299532]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 183}], {
             RGBColor[
             0.28838161647063476`, 0.4191962552733669, 0.9397797353853092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 185}], {
             RGBColor[
             0.4451220207260428, 0.5568482607152324, 0.9504446626081502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 244}], {
             RGBColor[
             0.28234247424873604`, 0.412848733894419, 0.9394358151698824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 59}], {
             RGBColor[
             0.8989327098919131, 0.5734920759622608, 0.24889953887676536`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 60}], {
             RGBColor[
             0.9455688567915195, 0.8192169579907062, 0.28906456863413965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 94}], {
             RGBColor[
             0.9135021931703009, 0.8932720957781641, 0.6527207002692943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 100}], {
             RGBColor[
             0.9076177976951124, 0.6402494666473935, 0.25721638876551267`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 121}], {
             RGBColor[
             0.9798326937990873, 0.9423326330377451, 0.48673505054828914`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 124}], {
             RGBColor[
             0.9563745344888678, 0.9271480240205534, 0.6460858270481826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 125}], {
             RGBColor[
             0.9788402151300284, 0.9402098215196141, 0.37870987228958564`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 137}], {
             RGBColor[
             0.9053107353837854, 0.6225163747613823, 0.25500714329073165`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 150}], {
             RGBColor[
             0.9635307831976114, 0.9324851425902525, 0.6339721646328667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 170}], {
             RGBColor[
             0.8934743520557873, 0.5315367457661417, 0.24367260924855771`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 192}], {
             RGBColor[
             0.9150207009153106, 0.6868003754774932, 0.26390009611845466`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 195}], {
             RGBColor[
             0.892099510879235, 0.5209691140239162, 0.24235605978523028`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 200}], {
             RGBColor[
             0.9255256121005535, 0.7345007236853389, 0.2726656515103572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 256}], {
             RGBColor[
             0.9801516197044022, 0.9430147833008583, 0.5214481671592728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 299}], {
             RGBColor[
             0.979769906119425, 0.942886287709507, 0.5299077867568601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 53}], {
             RGBColor[
             0.8447764554590436, 0.34517703459191124`, 0.19051129035634062`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 68}], {
             RGBColor[
             0.8660950044608668, 0.48393636846669774`, 0.20994293256664392`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 195}], {
             RGBColor[
             0.8384837744462674, 0.29680873085731074`, 0.18448541191193943`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 200}], {
             RGBColor[
             0.8719098756675858, 0.5103403405187334, 0.21479500363706636`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 215}], {
             RGBColor[
             0.9264635101364236, 0.7188538247686493, 0.4669105670802081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 223}], {
             RGBColor[
             0.872589282408941, 0.5134253678517513, 0.21536191727583626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 225}], {
             RGBColor[
             0.9093933228339569, 0.6627226292341221, 0.2529269618420678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 234}], {
             RGBColor[
             0.837571395698585, 0.28979578799570727`, 0.18361171699277434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 255}], {
             RGBColor[
             0.9083890640548784, 0.6593350285611156, 0.24902560612370514`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 282}], {
             RGBColor[
             0.9107404155806164, 0.7089403181351821, 0.5747043826447977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 287}], {
             RGBColor[
             0.899399401089056, 0.6245785965945915, 0.23718537302328563`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 50}], {
             RGBColor[
             0.32229358745653136`, 0.4520407279394575, 0.9418134628870861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 108}], {
             RGBColor[
             0.3180292730157506, 0.448347193101529, 0.9415417445417048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 114}], {
             RGBColor[
             0.29827465777054285`, 0.4308359553953969, 0.9402976725509951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 145}], {
             RGBColor[
             0.280670988716232, 0.4123333830822331, 0.9392951696406466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 169}], {
             RGBColor[
             0.2925815910536258, 0.4248521813146391, 0.9399734608236041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 187}], {
             RGBColor[
             0.32803381097302087`, 0.4570126210374179, 0.9421792248536764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 213}], {
             RGBColor[
             0.3600084250820952, 0.48470742468786476`, 0.9442166189906656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 219}], {
             RGBColor[
             0.2831865614508789, 0.4149774095228705, 0.9394384277864284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 221}], {
             RGBColor[
             0.2933757434234066, 0.4256868858074472, 0.9400186866262199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 264}], {
             RGBColor[
             0.29339971487327476`, 0.42571208132113636`, 0.9400200517648274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 48}], {
             RGBColor[
             0.5288713488786927, 0.6272983725157164, 0.9563690029663805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 74}], {
             RGBColor[
             0.6411369333771564, 0.7195168172815674, 0.9649096076876572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 90}], {
             RGBColor[
             0.5238031310544717, 0.622908536972411, 0.9560460606082701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.5238459246822951, 0.6229456026619612, 0.9560487873803941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 166}], {
             RGBColor[
             0.8183915236203407, 0.8543538869413033, 0.7072534135870767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 177}], {
             RGBColor[
             0.5316337139639098, 0.6296909943120255, 0.956545018426947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 217}], {
             RGBColor[
             0.7255477462839056, 0.7855226808548759, 0.9732794767865461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 233}], {
             RGBColor[
             0.8190741460647206, 0.8558139473261162, 0.781552654000438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 262}], {
             RGBColor[
             0.8190197652374052, 0.8556976322352333, 0.77563363654671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 273}], {
             RGBColor[
             0.6309474410941337, 0.7112445284148133, 0.9641074535297975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 74}], {
             RGBColor[
             0.5259484891930979, 0.6249515173301565, 0.9561210914963576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 84}], {
             RGBColor[
             0.35715044434118537`, 0.4830160061947183, 0.9440058041437522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 90}], {
             RGBColor[
             0.4086146868704133, 0.5283432370210001, 0.9472575444169704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 144}], {
             RGBColor[
             0.3646961975812182, 0.4903032490061542, 0.9444590971150582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 158}], {
             RGBColor[
             0.4086574804982366, 0.5283803027105503, 0.9472602711890945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 175}], {
             RGBColor[
             0.3540970438547585, 0.4798066886867111, 0.9438319175031515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 177}], {
             RGBColor[
             0.4164452697798513, 0.5351256943606145, 0.9477565022356473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 217}], {
             RGBColor[
             0.6103593020998471, 0.6909573809034649, 0.9644909605952465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 252}], {
             RGBColor[
             0.35710710220900627`, 0.48297045086574814`, 0.9440033358734436]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 253}], {
             RGBColor[
             0.3552041377824924, 0.4809703145985687, 0.9438949648645372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 57}], {
             RGBColor[
             0.2418037466004938, 0.3714814472931095, 0.9370817377010874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 84}], {
             RGBColor[
             0.2685862507813846, 0.39963155729606886`, 0.9386069616930247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 112}], {
             RGBColor[
             0.24438397329964223`, 0.374193429149736, 0.9372286777945005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 115}], {
             RGBColor[
             0.22907293102325943`, 0.358100552941108, 0.9363567365875176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 146}], {
             RGBColor[
             0.23350254559126715`, 0.3627563587058691, 0.9366089965841382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 159}], {
             RGBColor[
             0.24197412682758776`, 0.3716605277145155, 0.9370914406029653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 175}], {
             RGBColor[
             0.26553285029495766`, 0.3964222397880617, 0.9384330750524239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 204}], {
             RGBColor[
             0.23371861491604712`, 0.3629834612657993, 0.9366213014125385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 242}], {
             RGBColor[
             0.23849346114208345`, 0.3680021273920998, 0.9368932218413593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 243}], {
             RGBColor[
             0.2273605669768493, 0.3563007497581797, 0.9362592199882902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 253}], {
             RGBColor[
             0.2666399442226916, 0.39758586569991927`, 0.9384961224138098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 280}], {
             RGBColor[
             0.2523064385494426, 0.38252044244058536`, 0.9376798504702395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 292}], {
             RGBColor[
             0.23980801296623738`, 0.36938380470668514`, 0.9369680836230397]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 87}], {
             RGBColor[
             0.314278172622923, 0.4436160187426821, 0.9413569968700557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 108}], {
             RGBColor[
             0.3481847341285709, 0.4760018492537544, 0.9434070012643693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 114}], {
             RGBColor[
             0.32843011888336315`, 0.4584906115476223, 0.9421629292736595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 169}], {
             RGBColor[
             0.3227370521664461, 0.4525068374668645, 0.9418387175462686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 187}], {
             RGBColor[
             0.35818927208584117`, 0.4846672771896433, 0.9440444815763409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 205}], {
             RGBColor[
             0.44094793085644673`, 0.5542815920827796, 0.9498889293247207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 213}], {
             RGBColor[
             0.3901638861949155, 0.5123620808400902, 0.94608187571333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 227}], {
             RGBColor[
             0.30610711869793783`, 0.43502772299278125`, 0.9408916674370189]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 264}], {
             RGBColor[
             0.32355517598609507`, 0.45336673747336176`, 0.9418853084874919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 52}], {
             RGBColor[
             0.9056350707482277, 0.5643614773610739, 0.4604731703909181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 58}], {
             RGBColor[
             0.7712426526188537, 0.8181426903224094, 0.8569941031084208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 66}], {
             RGBColor[
             0.9700089985303242, 0.9755966228942858, 0.8659381168837096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 67}], {
             RGBColor[
             0.9529402270197467, 0.9622638379796367, 0.8739273734917072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 69}], {
             RGBColor[
             0.9933000659558078, 0.9895615584823135, 0.6199821278730931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 86}], {
             RGBColor[
             0.9842148587859489, 0.9592452118717956, 0.5566107984418112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[
             0.9138545722061537, 0.6275401673751994, 0.4683441742696273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 109}], {
             RGBColor[
             0.9573653906056103, 0.9657923433051386, 0.8743494495449171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 110}], {
             RGBColor[
             0.9932540497607107, 0.99147839046011, 0.7614613836320072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 138}], {
             RGBColor[
             0.8501230130531416, 0.8811959449639274, 0.8638775606265587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 141}], {
             RGBColor[
             0.9462822846437602, 0.812940654644517, 0.4968966602614467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 154}], {
             RGBColor[
             0.867381103025232, 0.8946780960164662, 0.8655976857489563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 165}], {
             RGBColor[
             0.986911243979133, 0.9683407522697562, 0.5670857457477134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 179}], {
             RGBColor[
             0.993604348606093, 0.9916232480349453, 0.7556560252196713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 258}], {
             RGBColor[
             0.9776645788146846, 0.9813061421354996, 0.8529792163574066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 281}], {
             RGBColor[
             0.9148192587802333, 0.6349551711119263, 0.4692679592224235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 82}], {
             RGBColor[
             0.90639234718301, 0.5644975000841104, 0.4350476194442515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 86}], {
             RGBColor[
             0.8962878067304835, 0.5320009026523702, 0.26072815279041595`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 107}], {
             RGBColor[
             0.8259275201506884, 0.20029585815577397`, 0.17246152861823205`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 110}], {
             RGBColor[
             0.9053269977052454, 0.5642340812406845, 0.4655787379806119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 141}], {
             RGBColor[
             0.8583552325882947, 0.3856963454250917, 0.20101401461005142`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 165}], {
             RGBColor[
             0.8989841919236675, 0.5410964430503309, 0.2712031000963182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 179}], {
             RGBColor[
             0.9056772965506277, 0.5643789388155198, 0.459773379568276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 193}], {
             RGBColor[
             0.6086028861336337, 0.3287818878860621, 0.5556335731143328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 236}], {
             RGBColor[
             0.7204593344779664, 0.42105333760098257`, 0.5640355482527617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 266}], {
             RGBColor[
             0.5326709863563452, 0.2573632665445422, 0.5510021420640641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 281}], {
             RGBColor[
             0.8268922067247678, 0.207710861892501, 0.1733853135710282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 59}], {
             RGBColor[
             0.8322696375208192, 0.249044151396152, 0.17853474737426642`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 68}], {
             RGBColor[
             0.8530476685227406, 0.3836488270671944, 0.19744878893743584`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 150}], {
             RGBColor[
             0.8968677108265174, 0.6080372180241437, 0.5636073731303677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 170}], {
             RGBColor[
             0.8268112796846933, 0.20708882120003286`, 0.1733078177460588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 192}], {
             RGBColor[
             0.8483576285442167, 0.36235245091138435`, 0.19353530461595575`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 195}], {
             RGBColor[
             0.825436438508141, 0.1965211894578074, 0.17199126828273137`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 200}], {
             RGBColor[
             0.8588625397294595, 0.4100527991192301, 0.2023008600078583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 225}], {
             RGBColor[
             0.8963459868958306, 0.5624350878346187, 0.24043281821285972`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 234}], {
             RGBColor[
             0.8245240597604586, 0.18950824659620397`, 0.17111757336356628`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 255}], {
             RGBColor[
             0.8953417281167521, 0.5590474871616122, 0.23653146249449708`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 282}], {
             RGBColor[
             0.89769307964249, 0.6086527767356787, 0.5622102390155896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 287}], {
             RGBColor[
             0.8863520651509298, 0.5242910551950881, 0.22469122939407754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 72}], {
             RGBColor[
             0.534606977221836, 0.6319372303906756, 0.9568737438527076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 106}], {
             RGBColor[
             0.5370375913061106, 0.6338360445866622, 0.9571160047492481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 151}], {
             RGBColor[
             0.4303399784091667, 0.5471605926069658, 0.9486418607828988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 167}], {
             RGBColor[
             0.585666437251012, 0.671825268631737, 0.9619628736506332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 194}], {
             RGBColor[
             0.4666198015964266, 0.5768869180196359, 0.9514225850947327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 238}], {
             RGBColor[
             0.34796050319161576`, 0.47301253149465217`, 0.9434950557775005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 251}], {
             RGBColor[
             0.3520600889143901, 0.4773214560180356, 0.9437285211196189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 286}], {
             RGBColor[
             0.4882211414959945, 0.5944238588793778, 0.953123121699942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 90}], {
             RGBColor[
             0.3401206359010615, 0.4660537805054501, 0.9430016668956538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 97}], {
             RGBColor[
             0.26708761639868417`, 0.39805639754094285`, 0.9385216166819608]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 134}], {
             RGBColor[
             0.27534778812989436`, 0.40673836175558137`, 0.9389920212422243]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 144}], {
             RGBColor[
             0.2962021466118664, 0.42801379249060423`, 0.9402032195937415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 159}], {
             RGBColor[
             0.26204426941803677`, 0.39275552009761494`, 0.9382344055323761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 235}], {
             RGBColor[
             0.25936698600148883`, 0.38994152547725025`, 0.9380819382024896]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 252}], {
             RGBColor[
             0.2886130512396545, 0.4206809943501981, 0.9397474583521269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 253}], {
             RGBColor[
             0.2867100868131406, 0.4186808580830187, 0.9396390873432205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 292}], {
             RGBColor[
             0.25987815555668636`, 0.39047879708978456`, 0.9381110485524506]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 79}], {
             RGBColor[
             0.47131158576889715`, 0.5800856534095411, 0.9519605579459619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 93}], {
             RGBColor[
             0.5394509250519448, 0.6369895888012234, 0.9568866993753897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 160}], {
             RGBColor[
             0.5689561966042058, 0.6609432974446849, 0.9592094624333546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 164}], {
             RGBColor[
             0.46580833431938506`, 0.5753190136054342, 0.9516098956299331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 168}], {
             RGBColor[
             0.46678271330407606`, 0.5761629717082618, 0.9516719821972282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 246}], {
             RGBColor[
             0.57328015808247, 0.6644536841649844, 0.9595498605201163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 296}], {
             RGBColor[
             0.6219639893106997, 0.70315209105388, 0.9639467061714042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.27383547980684575`, 0.4051488298221716, 0.9389058975204863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 89}], {
             RGBColor[
             0.26259271630004477`, 0.3933319725441461, 0.9382656387709521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 112}], {
             RGBColor[
             0.24963320232510341`, 0.37971070167583876`, 0.9375276136219621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 115}], {
             RGBColor[
             0.2343221600487206, 0.3636178254672108, 0.9366556724149793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 134}], {
             RGBColor[
             0.26052687456490653`, 0.3911606418985847, 0.938147992140275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 146}], {
             RGBColor[
             0.23875177461672836`, 0.3682736312319718, 0.9369079324115999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 159}], {
             RGBColor[
             0.24722335585304894`, 0.3771778002406183, 0.937390376430427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 175}], {
             RGBColor[
             0.27078207932041887`, 0.40193951231416447`, 0.9387320108798856]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 204}], {
             RGBColor[
             0.23896784394150833`, 0.36850073379190207`, 0.9369202372400001]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 235}], {
             RGBColor[
             0.24454607243650103`, 0.3743638056202535, 0.9372379091005405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 242}], {
             RGBColor[
             0.24374269016754463`, 0.3735193999182025, 0.9371921576688209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 243}], {
             RGBColor[
             0.23260979600231052`, 0.3618180222842825, 0.9365581558157519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 253}], {
             RGBColor[
             0.27188917324815276`, 0.40310313822602206`, 0.9387950582412713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 280}], {
             RGBColor[
             0.2575556675749038, 0.38803771496668804`, 0.9379787862977012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 292}], {
             RGBColor[
             0.2450572419916986, 0.37490107723278787`, 0.9372670194505013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 66}], {
             RGBColor[
             0.747689528345485, 0.802133526636196, 0.966576403949817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 67}], {
             RGBColor[
             0.7306207568349073, 0.7888007417215468, 0.9745656605578148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 73}], {
             RGBColor[
             0.4389666532110068, 0.5520366798791193, 0.9499088011180912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 95}], {
             RGBColor[
             0.5187848450827122, 0.6202119340859072, 0.9552597898578664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 96}], {
             RGBColor[
             0.47719454661287236`, 0.585147759754026, 0.9523446486820593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 109}], {
             RGBColor[
             0.7350459204207711, 0.7923292470470489, 0.9749877366110247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 138}], {
             RGBColor[
             0.6278035428683023, 0.7077328487058376, 0.9645158476926661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 140}], {
             RGBColor[
             0.4384985979215843, 0.5516312739125644, 0.9498789770489342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 154}], {
             RGBColor[
             0.6450616328403926, 0.7212149997583763, 0.9662359728150638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 171}], {
             RGBColor[
             0.48363824484440066`, 0.5907289672924857, 0.9527552354354336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 198}], {
             RGBColor[
             0.506589269540044, 0.610311016455952, 0.9542997094772824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[
             0.48666290222101594`, 0.5933487734884098, 0.952947963928872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 62}], {
             RGBColor[
             0.9138294445361559, 0.6222945482383531, 0.42987348446131357`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 100}], {
             RGBColor[
             0.8414952433239204, 0.3199562002850287, 0.1873691979101476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 125}], {
             RGBColor[
             0.9127176607588363, 0.6199165551572493, 0.3088626814342206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 137}], {
             RGBColor[
             0.8391881810125934, 0.30222310839901756`, 0.1851599524353666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 170}], {
             RGBColor[
             0.8273517976845952, 0.21124347940377694`, 0.17382541839319265`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 192}], {
             RGBColor[
             0.8488981465441187, 0.3665071091151284, 0.1940529052630896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 195}], {
             RGBColor[
             0.825976956508043, 0.20067584766155147`, 0.17250886892986522`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 200}], {
             RGBColor[
             0.8594030577293614, 0.41420745732297415`, 0.20281846065499215`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 225}], {
             RGBColor[
             0.8968865048957325, 0.5665897460383628, 0.24095041885999358`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 228}], {
             RGBColor[
             0.8245766992197552, 0.5548258112486377, 0.5806907356901773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 255}], {
             RGBColor[
             0.895882246116654, 0.5632021453653563, 0.23704906314163093`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.9605795624965958, 0.8682632028416796, 0.48244356084256446`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 85}], {
             RGBColor[
             0.9228540566499766, 0.8416985659067688, 0.6257891591988634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 100}], {
             RGBColor[
             0.8881313902235266, 0.565681082313474, 0.22753422766752193`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 121}], {
             RGBColor[
             0.9603462863275016, 0.8677642487038257, 0.4570528894502983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 125}], {
             RGBColor[
             0.9593538076584427, 0.8656414371856946, 0.3490277111915949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 127}], {
             RGBColor[
             0.879427272019672, 0.4987774156297289, 0.21919915424561515`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.9594950595498875, 0.8659435606987382, 0.3644021078697419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 137}], {
             RGBColor[
             0.8858243279121996, 0.5479479904274629, 0.22532498219274089`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 170}], {
             RGBColor[
             0.8739879445842015, 0.4569683614322223, 0.21399044815056695`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 232}], {
             RGBColor[
             0.9600894947352094, 0.8672149974535253, 0.4291027093633025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 240}], {
             RGBColor[
             0.9605080040332614, 0.868110146524278, 0.47465486371626864`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 256}], {
             RGBColor[
             0.9606652122328164, 0.8684463989669389, 0.49176600606128196`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 299}], {
             RGBColor[
             0.9602834986478392, 0.8683179033755875, 0.5002256256588694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 177}], {
             RGBColor[
             0.49302351294995017`, 0.5983715477396933, 0.9534876687205165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 217}], {
             RGBColor[
             0.686937545269946, 0.7542032342825437, 0.9702221270801157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 247}], {
             RGBColor[
             0.5729638190353659, 0.6641968658756336, 0.9595249571515402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 267}], {
             RGBColor[
             0.517343318582302, 0.6190416379328455, 0.9551463076112685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 273}], {
             RGBColor[
             0.5923372400801741, 0.6799250818424811, 0.9610501038233672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 285}], {
             RGBColor[
             0.474805368949063, 0.5825919070766665, 0.9523268246944521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 82}], {
             RGBColor[
             0.9949627046124243, 0.9916340594516913, 0.6930996675251034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 100}], {
             RGBColor[
             0.9225145323393552, 0.6890519389234857, 0.4381903343500609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 127}], {
             RGBColor[
             0.9138104141355006, 0.6221482722397406, 0.4298552609281541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 130}], {
             RGBColor[
             0.5868878667757954, 0.648392143438405, 0.8070978104506135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 137}], {
             RGBColor[
             0.9202074700280282, 0.6713188470374746, 0.43598108887527987`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 170}], {
             RGBColor[
             0.9083710867000301, 0.580339218042234, 0.42464655483310587`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 192}], {
             RGBColor[
             0.9299174355595534, 0.7356028477535854, 0.4448740417030029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 195}], {
             RGBColor[
             0.9069962455234778, 0.5697715863000085, 0.4233300053697785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 199}], {
             RGBColor[
             0.5868878667757954, 0.648392143438405, 0.8070978104506135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 220}], {
             RGBColor[
             0.6260202363274255, 0.6895227449727015, 0.8093263410054259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 225}], {
             RGBColor[
             0.9779057939111673, 0.9356854846768198, 0.49177155529990685`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 226}], {
             RGBColor[
             0.5868878718865363, 0.6483921488101179, 0.8070978107416625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 228}], {
             RGBColor[
             0.90559598823519, 0.9239215498870947, 0.8315118721300905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 255}], {
             RGBColor[
             0.9769015351320889, 0.9322978840038133, 0.4878701995815442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 131}], {
             RGBColor[
             0.32467225096411007`, 0.4556365181084638, 0.9419088066284024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 139}], {
             RGBColor[
             0.28999599813964694`, 0.42067676560446166`, 0.9398795920978575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 143}], {
             RGBColor[
             0.36063166824627285`, 0.4867827579854089, 0.9442001088999576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 172}], {
             RGBColor[
             0.29700434513925705`, 0.4280429826559164, 0.940278707091565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 174}], {
             RGBColor[
             0.35841838866408615`, 0.48486572645398507`, 0.944059080682107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 183}], {
             RGBColor[
             0.28955139027076127`, 0.4202094545444958, 0.939854272337463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 283}], {
             RGBColor[
             0.4716182093057971, 0.5784225844464469, 0.9525129877054703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 92}], {
             RGBColor[
             0.24737632360791623`, 0.3773385790496996, 0.9373990877177711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 145}], {
             RGBColor[
             0.2514296244944172, 0.3815988552755316, 0.937629917206936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 153}], {
             RGBColor[
             0.253568524812987, 0.38384697512446136`, 0.9377517244158591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 211}], {
             RGBColor[
             0.238007335368493, 0.36749117838190204`, 0.936865537697712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 219}], {
             RGBColor[
             0.2539451972290641, 0.384242881716169, 0.9377731753527179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 221}], {
             RGBColor[
             0.26413437920159183`, 0.3949523580007457, 0.9383534341925093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 80}], {
             RGBColor[
             0.27787319023653523`, 0.40939271948940265`, 0.9391358391561999]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 103}], {
             RGBColor[
             0.2833667383517215, 0.41516678686953135`, 0.9394486885943836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 116}], {
             RGBColor[
             0.3051622199360282, 0.4368120893539453, 0.940736158424998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 133}], {
             RGBColor[
             0.3190318248130566, 0.44882524399181684`, 0.9416199173833522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 152}], {
             RGBColor[
             0.270606352963235, 0.4017548127710696, 0.9387220035238077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 162}], {
             RGBColor[
             0.28622167127698683`, 0.41816750238718753`, 0.9396112728009827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[
             0.33323684341077736`, 0.46112891713616844`, 0.9425250486073942]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 241}], {
             RGBColor[
             0.2834960053804121, 0.4153026547126882, 0.9394560501604341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 277}], {
             RGBColor[
             0.318505826054183, 0.44836965030434695`, 0.9415864012075592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 67}], {
             RGBColor[
             0.9293871027463778, 0.9462546742934231, 0.9835096743331035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 69}], {
             RGBColor[
             0.9697469416824389, 0.9735523947961, 0.7295644287144893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 95}], {
             RGBColor[
             0.7175511909941827, 0.7776658666577836, 0.9642038036331552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 109}], {
             RGBColor[
             0.9338122663322416, 0.9497831796189251, 0.9839317503863134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 110}], {
             RGBColor[
             0.969700925487342, 0.9754692267738965, 0.8710436844734033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 138}], {
             RGBColor[
             0.8265698887797728, 0.8651867812777139, 0.9734598614679548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 154}], {
             RGBColor[
             0.8438279787518632, 0.8786689323302527, 0.9751799865903525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 179}], {
             RGBColor[
             0.9700512243327243, 0.9756140843487318, 0.8652383260610674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 258}], {
             RGBColor[
             0.9541114545413159, 0.9652969784492861, 0.9625615171988029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 69}], {
             RGBColor[
             0.9526781701718614, 0.9602196098814508, 0.7375536853224871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 86}], {
             RGBColor[
             0.9435929630020026, 0.929903263270933, 0.6741823558912051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 95}], {
             RGBColor[
             0.7004824194836051, 0.7643330817431344, 0.9721930602411528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 109}], {
             RGBColor[
             0.916743494821664, 0.9364503947042759, 0.9919210069943111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 110}], {
             RGBColor[
             0.9526321539767644, 0.9621364418592473, 0.8790329410814011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 138}], {
             RGBColor[
             0.8095011172691953, 0.8518539963630647, 0.9814491180759526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 154}], {
             RGBColor[
             0.8267592072412856, 0.8653361474156035, 0.9831692431983503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 179}], {
             RGBColor[
             0.9529824528221467, 0.9622812994340826, 0.8732275826690652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 258}], {
             RGBColor[
             0.9370426830307382, 0.9519641935346369, 0.9705507738068005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 215}], {
             RGBColor[
             0.9347347232001206, 0.7573256172439325, 0.47384806566130333`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 223}], {
             RGBColor[
             0.880860495472638, 0.5518971603270344, 0.22229941585693147`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 234}], {
             RGBColor[
             0.8458426087622819, 0.3282675804709904, 0.19054921557386956`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 255}], {
             RGBColor[
             0.9166602771185755, 0.6978068210363987, 0.2559631047048003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 271}], {
             RGBColor[
             0.9259155815977133, 0.7290271362933656, 0.2919182148886562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 274}], {
             RGBColor[
             0.9194708353599413, 0.7072874939349834, 0.2668815927431183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 287}], {
             RGBColor[
             0.9076706141527531, 0.6630503890698746, 0.24412287160438084`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 109}], {
             RGBColor[
             0.957103333757725, 0.9637481152069529, 0.737975761375697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 110}], {
             RGBColor[
             0.9929919929128255, 0.9894341623619243, 0.625087695462787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 113}], {
             RGBColor[
             0.9762236487706943, 0.9783827123378863, 0.71860105300982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 135}], {
             RGBColor[
             0.9915668730357023, 0.9888448386688236, 0.6487056199187353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 138}], {
             RGBColor[
             0.8498609562052564, 0.8791517168657417, 0.7275038724573385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 224}], {
             RGBColor[
             0.9812813612748328, 0.9481895871324358, 0.4098590677551779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 249}], {
             RGBColor[
             0.9058089885195326, 0.5656683412312807, 0.3245169720093974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 254}], {
             RGBColor[
             0.9421799602264942, 0.7934586684310521, 0.3573185586987633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 258}], {
             RGBColor[
             0.9774025219667993, 0.9792619140373138, 0.7166055281881865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 288}], {
             RGBColor[
             0.9274695616660017, 0.7266621842687284, 0.34504384155502377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[
             0.27137415800540265`, 0.40256182455203926`, 0.9387657288850935]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 251}], {
             RGBColor[
             0.27547374372817707`, 0.40687074907542276`, 0.9389991942272118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 300}], {
             RGBColor[
             0.2600472811884571, 0.39065655885195993`, 0.938120680006981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 85}], {
             RGBColor[
             0.7746111080065263, 0.8244612139777192, 0.9780896021036154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 98}], {
             RGBColor[
             0.5262018737865255, 0.625404972246536, 0.9560725859325541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 121}], {
             RGBColor[
             0.8121033376840514, 0.8505268967747761, 0.8093533323550504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 122}], {
             RGBColor[
             0.6268946494046528, 0.707980343525642, 0.9637705896733515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 136}], {
             RGBColor[
             0.8112521109064372, 0.8487062087696886, 0.716702550774494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 160}], {
             RGBColor[
             0.6099082730566356, 0.6941900379787878, 0.9624333599040888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 181}], {
             RGBColor[
             0.6717068148993812, 0.7432662316253906, 0.9680467833618187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 207}], {
             RGBColor[
             0.6875924129964879, 0.7556761815938675, 0.9696301113207838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 232}], {
             RGBColor[
             0.8118465460917592, 0.8499776455244756, 0.7814031522680547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 240}], {
             RGBColor[
             0.8122650553898112, 0.8508727945952284, 0.8269553066210207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 246}], {
             RGBColor[
             0.6142322345348998, 0.6977004246990872, 0.9627737579908505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 256}], {
             RGBColor[
             0.8124222635893662, 0.8512090470378892, 0.8440664489660341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 296}], {
             RGBColor[
             0.6629160657631297, 0.7363988315879828, 0.9671706036421385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 299}], {
             RGBColor[
             0.812040550004389, 0.8510805514465378, 0.8525260685636215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 106}], {
             RGBColor[
             0.6542381545327312, 0.7298150858058879, 0.966172003106812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 151}], {
             RGBColor[
             0.5475405416357872, 0.6431396338261914, 0.9576978591404627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 194}], {
             RGBColor[
             0.5838203648230471, 0.6728659592388615, 0.9604785834522965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 215}], {
             RGBColor[
             0.8234553846620669, 0.8600796725778928, 0.8483727211925696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 247}], {
             RGBColor[
             0.6154478937421781, 0.6985426120193529, 0.9629684183842664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 267}], {
             RGBColor[
             0.5598273932891142, 0.6533873840765647, 0.9585897688439947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 286}], {
             RGBColor[
             0.6054217047226151, 0.6904029000986035, 0.9621791200575058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 87}], {
             RGBColor[
             0.3025587103322468, 0.4334652095438001, 0.9406102430960075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 95}], {
             RGBColor[
             0.4088283158597046, 0.5275690199007069, 0.9475362008014293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 96}], {
             RGBColor[
             0.3672380173898648, 0.4925048455688256, 0.9446210596256222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 105}], {
             RGBColor[
             0.30909022810020703`, 0.4403302488400713, 0.9409822033703782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 140}], {
             RGBColor[
             0.3285420686985767, 0.45898835972736407`, 0.9421553879924971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 149}], {
             RGBColor[
             0.3114795465639533, 0.4428415740370091, 0.9411182715222086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 171}], {
             RGBColor[
             0.3736817156213931, 0.4980860531072854, 0.9450316463789965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 245}], {
             RGBColor[
             0.37670637299800835`, 0.5007058593032094, 0.9452243748724349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 289}], {
             RGBColor[
             0.309996695985159, 0.44128300406053933`, 0.9410338253754271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 298}], {
             RGBColor[
             0.307131102255913, 0.43827108336196546`, 0.9408706340518126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 90}], {
             RGBColor[
             0.5208802713688769, 0.620561681786851, 0.9557981491382472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 123}], {
             RGBColor[
             0.5372173592410554, 0.6347120461758202, 0.9568391339311428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 158}], {
             RGBColor[
             0.5209230649967003, 0.6205987474764012, 0.9558008759103712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 233}], {
             RGBColor[
             0.8161512863791258, 0.8534670921405562, 0.7813047425304152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 257}], {
             RGBColor[
             0.5147596974188978, 0.6152603482603705, 0.9554081515783656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 259}], {
             RGBColor[
             0.5512374616169957, 0.646558430162153, 0.9578145787092965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 262}], {
             RGBColor[
             0.8160969055518104, 0.8533507770496733, 0.7753857250766871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 124}], {
             RGBColor[
             0.8391031020269322, 0.8749559056354701, 0.9735996156850079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 142}], {
             RGBColor[
             0.6947680744610263, 0.7614773672926725, 0.9702116467516284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 143}], {
             RGBColor[
             0.5636312232942053, 0.6537338940348352, 0.9601379235387875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 150}], {
             RGBColor[
             0.8462593507356758, 0.8802930242051693, 0.9614859532696918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 167}], {
             RGBColor[
             0.7422194299230214, 0.7985467268232416, 0.9749411544059516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 174}], {
             RGBColor[
             0.5614179437120186, 0.6518168625034114, 0.9599968953209368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 185}], {
             RGBColor[
             0.6492913495741017, 0.7248125960357876, 0.9664570141991338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 237}], {
             RGBColor[
             0.6846458552140906, 0.7535149764166593, 0.969240250390935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 239}], {
             RGBColor[
             0.5708233361978141, 0.6599633407458361, 0.9605961986132696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 282}], {
             RGBColor[
             0.8470847195516484, 0.8809085829167043, 0.9600888191549137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 283}], {
             RGBColor[
             0.6746177643537297, 0.7453737204958732, 0.9684508023443001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 295}], {
             RGBColor[
             0.7838985892899054, 0.8312466386518764, 0.9790582353871675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 297}], {
             RGBColor[
             0.7454557140194038, 0.8010749365560057, 0.9752637169598848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 99}], {
             RGBColor[
             0.3308920068686242, 0.45968772172522177`, 0.9423540428096366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[
             0.2896837321277139, 0.4218063478486378, 0.9398084320447715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 128}], {
             RGBColor[
             0.2667781164198233, 0.397731093439728, 0.9385039911160289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[
             0.3201380287875101, 0.4503731664220151, 0.9416688088356775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 201}], {
             RGBColor[
             0.3077043294157084, 0.43960372096206174`, 0.9408765445063949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 209}], {
             RGBColor[
             0.2797259704782522, 0.4113401089964994, 0.9392413522500229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 218}], {
             RGBColor[
             0.2751691719679872, 0.4065506248444982, 0.9389818493160426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 229}], {
             RGBColor[
             0.32034218545595194`, 0.4505499966670069, 0.9416818175180619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 261}], {
             RGBColor[
             0.3474685023612617, 0.4740454489620557, 0.9434102824444082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 284}], {
             RGBColor[
             0.2749699198453155, 0.406341198230256, 0.9389705022024235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 91}], {
             RGBColor[
             0.25932242623621204`, 0.38989469033869195`, 0.9380794005897775]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 162}], {
             RGBColor[
             0.26527957680517633`, 0.3961560332918348, 0.9384186515018654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 191}], {
             RGBColor[
             0.24496070190330402`, 0.37479960747889, 0.9372615216352855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 203}], {
             RGBColor[
             0.25281317669126346`, 0.38305305635669296`, 0.9377087084577643]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 206}], {
             RGBColor[
             0.2413530899135048, 0.3710077785417997, 0.9370560734694501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 244}], {
             RGBColor[
             0.2442718082387917, 0.3740755365591065, 0.9372222901602183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 270}], {
             RGBColor[
             0.23714390206690406`, 0.36658365523709874`, 0.9368163664485216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 118}], {
             RGBColor[
             0.17948494456776543`, 0.30598043511645023`, 0.9335327741177293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 120}], {
             RGBColor[
             0.1849774474258748, 0.3117534038651181, 0.9338455640300687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 130}], {
             RGBColor[
             0.17948366008578914`, 0.30597908504445237`, 0.9335327009683809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 176}], {
             RGBColor[
             0.17949609924511575`, 0.30599215938959284`, 0.9335334093601024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 193}], {
             RGBColor[
             0.2897690368730418, 0.4135053888596902, 0.9401205117129523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.17948366008578914`, 0.30597908504445237`, 0.9335327009683809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 220}], {
             RGBColor[
             0.21861602963741927`, 0.34710968657874874`, 0.9357612315231933]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 226}], {
             RGBColor[
             0.17948366519653014`, 0.30597909041616517`, 0.9335327012594301]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 236}], {
             RGBColor[
             0.4016254852173745, 0.5057768385746106, 0.9485224868513811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 266}], {
             RGBColor[
             0.21383713709575333`, 0.3420867675181703, 0.9354890806626834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 93}], {
             RGBColor[
             0.46307011169266854`, 0.5733948534802826, 0.9513117589171669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 103}], {
             RGBColor[
             0.33687382527310783`, 0.4634377566971172, 0.9427875991368931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 116}], {
             RGBColor[
             0.3586693068574145, 0.48508305918153105`, 0.9440750689675076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 119}], {
             RGBColor[
             0.3385777508483834, 0.465228690511853, 0.9428846351776731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 164}], {
             RGBColor[
             0.38942752096010885`, 0.5117242782844935, 0.9460349551717104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 168}], {
             RGBColor[
             0.3904018999447999, 0.5125682363873212, 0.9460970417390054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 241}], {
             RGBColor[
             0.3370030923017984, 0.46357362454027395`, 0.9427949607029437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[
             0.3720129129755694, 0.49664062013193266`, 0.9449253117500688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 103}], {
             RGBColor[
             0.2733233300214085, 0.4046105279255051, 0.9388767313478634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 116}], {
             RGBColor[
             0.2951188116057152, 0.426255830409919, 0.9401642011784779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 133}], {
             RGBColor[
             0.30898841648274356`, 0.43826898504779055`, 0.941047960136832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 152}], {
             RGBColor[
             0.26056294463292196`, 0.39119855382704327`, 0.9381500462772876]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 210}], {
             RGBColor[
             0.3231934350804644, 0.45057265819214215`, 0.941953091360874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 241}], {
             RGBColor[
             0.27345259705009906`, 0.4047463957686619, 0.938884092913914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 277}], {
             RGBColor[
             0.30846241772387, 0.4378133913603206, 0.9410144439610391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 180}], {
             RGBColor[
             0.26493370488523493`, 0.3957924999744301, 0.9383989546076965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[
             0.3818442604921369, 0.5035684061042389, 0.9457044452357559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 285}], {
             RGBColor[
             0.33930631085889784`, 0.4671186752480599, 0.9428849623189395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 100}], {
             RGBColor[
             0.9226285034001888, 0.6892957114983669, 0.45059538097393753`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 107}], {
             RGBColor[
             0.9146118486409361, 0.6276761900982359, 0.44291862332296067`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 127}], {
             RGBColor[
             0.9139243851963341, 0.6223920448146217, 0.4422603075520308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 137}], {
             RGBColor[
             0.9203214410888617, 0.6715626196123557, 0.4483861354991565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 192}], {
             RGBColor[
             0.930031406620387, 0.7358466203284666, 0.4572790883268795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 199}], {
             RGBColor[
             0.587001837836629, 0.6486359160132862, 0.81950285707449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 220}], {
             RGBColor[
             0.6261342073882591, 0.6897665175475827, 0.8217313876293025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 226}], {
             RGBColor[
             0.5870018429473699, 0.648635921384999, 0.8195028573655392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 228}], {
             RGBColor[
             0.9057099592960236, 0.9241653224619759, 0.8439169187539672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 266}], {
             RGBColor[
             0.6213553148465931, 0.6847435984870042, 0.8214592367687926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 281}], {
             RGBColor[
             0.9155765352150156, 0.6350911938349629, 0.44384240827575683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 126}], {
             RGBColor[
             0.22111352999763184`, 0.3497347178080009, 0.9359034604739869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 155}], {
             RGBColor[
             0.21429563561346426`, 0.34256867853076955`, 0.9355151914749793]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 156}], {
             RGBColor[
             0.221993745626472, 0.35065988024280614`, 0.935953587451887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 184}], {
             RGBColor[
             0.22686279734830417`, 0.3557775623181615, 0.9362308727443287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[
             0.21339436331142053`, 0.34162138419735716`, 0.9354638653506908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 202}], {
             RGBColor[
             0.22220476853383342`, 0.3508816786980681, 0.9359656048942807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 214}], {
             RGBColor[
             0.21458531177906248`, 0.342873146547343, 0.9355316881040727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 275}], {
             RGBColor[
             0.214533530595458, 0.34281872124025803`, 0.9355287392422698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 293}], {
             RGBColor[
             0.21277489873276917`, 0.34097028764887183`, 0.9354285877593523]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 89}], {
             RGBColor[
             0.2893752204809355, 0.4214820825471055, 0.9397908627628895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.35208222651696447`, 0.4786261706514128, 0.9436828617856419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 112}], {
             RGBColor[
             0.2764157065059942, 0.4078608116787981, 0.9390528376138995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 134}], {
             RGBColor[
             0.2873093787457973, 0.41931075190154404`, 0.9396732161322123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 144}], {
             RGBColor[
             0.30816373722776935`, 0.4405861826365669, 0.9408844144837296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 158}], {
             RGBColor[
             0.35212502014478775`, 0.47866323634096297`, 0.943685588557766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 159}], {
             RGBColor[
             0.27400586003393973`, 0.4053279102435776, 0.9389156004223643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 175}], {
             RGBColor[
             0.29756458350130965`, 0.4300896223171238, 0.940257234871823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 252}], {
             RGBColor[
             0.30057464185555743`, 0.4332533844961608, 0.9404286532421151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 253}], {
             RGBColor[
             0.29867167742904355`, 0.43125324822898137`, 0.9403202822332086]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 280}], {
             RGBColor[
             0.28433817175579457`, 0.41618782496964746`, 0.9395040102896386]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 292}], {
             RGBColor[
             0.2718397461725893, 0.40305118723574723`, 0.9387922434424387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[
             0.9571178936575444, 0.9648142409538079, 0.8234596411130128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 122}], {
             RGBColor[
             0.7719092053781459, 0.8222676877046737, 0.9778768984313139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 136}], {
             RGBColor[
             0.9562666668799304, 0.9629935529487204, 0.7308088595324563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 165}], {
             RGBColor[
             0.9499430145672961, 0.9419121380578821, 0.6850057931573457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 181}], {
             RGBColor[
             0.8167213708728744, 0.8575535758044224, 0.9821530921197811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 207}], {
             RGBColor[
             0.8326069689699811, 0.8699635257728993, 0.9837364200787462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 232}], {
             RGBColor[
             0.9568611020652522, 0.9642649897035074, 0.7955094610260169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 240}], {
             RGBColor[
             0.9572796113633043, 0.9651601387742601, 0.8410616153789832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 246}], {
             RGBColor[
             0.759246790508393, 0.811987768878119, 0.9768800667488129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 256}], {
             RGBColor[
             0.9574368195628593, 0.965496391216921, 0.8581727577239964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 296}], {
             RGBColor[
             0.8079306217366228, 0.8506861757670146, 0.9812769124001008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 299}], {
             RGBColor[
             0.9570551059778822, 0.9653678956255696, 0.8666323773215838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 107}], {
             RGBColor[
             0.9045073081884096, 0.5951795926664958, 0.26859915666912515`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 109}], {
             RGBColor[
             0.9480181265878662, 0.9334317685964351, 0.674604431944415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 110}], {
             RGBColor[
             0.9839067857429666, 0.9591178157514064, 0.561716366031505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 141}], {
             RGBColor[
             0.936935020626016, 0.7805800799358134, 0.2971516426609445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 165}], {
             RGBColor[
             0.9775639799613888, 0.9359801775610526, 0.3673407281472113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 179}], {
             RGBColor[
             0.9842570845883489, 0.9592626733262417, 0.5559110076191691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 240}], {
             RGBColor[
             0.984900576757397, 0.9592281782774306, 0.5233965503688487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 281}], {
             RGBColor[
             0.9054719947624891, 0.6025945964032228, 0.26952294162192125`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 149}], {
             RGBColor[
             0.2850281329082009, 0.41691301788689017`, 0.939543302556562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 187}], {
             RGBColor[
             0.3200183961394125, 0.4485879118406425, 0.9417227588366461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 227}], {
             RGBColor[
             0.2679362427515092, 0.39894835764378045`, 0.938569944697324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 264}], {
             RGBColor[
             0.2853843000396664, 0.4172873721243609, 0.939563585747797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 99}], {
             RGBColor[
             0.43585477652737337`, 0.5505550934269655, 0.9493751482779511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[
             0.7318152240398965, 0.7888182862268713, 0.9538534747537719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 198}], {
             RGBColor[
             0.48423825814620036`, 0.592165458504841, 0.9525401559859066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 201}], {
             RGBColor[
             0.41266709907445764`, 0.5304710926638055, 0.9478976499747094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 222}], {
             RGBColor[
             0.47017691950032614`, 0.5802832085890723, 0.9515621248783083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 258}], {
             RGBColor[
             0.7329940972360016, 0.7896974879262988, 0.9518579499321382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 260}], {
             RGBColor[
             0.6766874696871867, 0.7454723343623321, 0.9697937614112038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 261}], {
             RGBColor[
             0.4524312720200109, 0.5649128206637994, 0.9504313879127225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 278}], {
             RGBColor[
             0.553576335347311, 0.6484572332214837, 0.9579987034169237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 290}], {
             RGBColor[
             0.558574938782711, 0.6525153246748602, 0.9583922117898461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 111}], {
             RGBColor[
             0.26057341862775985`, 0.3912095626597075, 0.9381506427557986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 112}], {
             RGBColor[
             0.26517294299919314`, 0.39604395440077267`, 0.9384125788643654]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 175}], {
             RGBColor[
             0.28632181999450856`, 0.4182727650390983, 0.9396169761222888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 177}], {
             RGBColor[
             0.3486700459196015, 0.47359177071300174`, 0.9435415608547846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 242}], {
             RGBColor[
             0.2592824308416344, 0.3898526526431364, 0.9380771229112241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.27309540824899353`, 0.40437096769162195`, 0.9388637515401044]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 285}], {
             RGBColor[
             0.3304519019187142, 0.457812130049975, 0.9423807168287202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 123}], {
             RGBColor[
             0.4198835569183708, 0.5381037658666636, 0.9479755868517558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 134}], {
             RGBColor[
             0.3387736212750252, 0.46463798272782586`, 0.9429249564054306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 144}], {
             RGBColor[
             0.35962797975699734`, 0.48591341346284866`, 0.9441361547569478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 158}], {
             RGBColor[
             0.4035892626740157, 0.5239904671672448, 0.9469373288309841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 252}], {
             RGBColor[
             0.35203888438478537`, 0.4785806153224426, 0.9436803935153333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 253}], {
             RGBColor[
             0.3501359199582715, 0.4765804790552632, 0.9435720225064269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[
             0.39742589509621323`, 0.518652067951214, 0.9465446044989785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 102}], {
             RGBColor[
             0.3289676178309032, 0.4560161547537128, 0.9423048264494448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 162}], {
             RGBColor[
             0.27856959341816107`, 0.4101246833878033, 0.9391754982871572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 191}], {
             RGBColor[
             0.2582507185162887, 0.38876825757485856`, 0.9380183684205773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 203}], {
             RGBColor[
             0.2661031933042482, 0.39702170645266144`, 0.9384655552430561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 239}], {
             RGBColor[
             0.3418733579527955, 0.46719445818593675`, 0.9431271687979139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 153}], {
             RGBColor[
             0.26728945052082176`, 0.3982685380003319, 0.9385331108366297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 163}], {
             RGBColor[
             0.25122830224652154`, 0.3813872528284255, 0.937618452202748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 189}], {
             RGBColor[
             0.2464728493758267, 0.3763889703481986, 0.937347636196824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 211}], {
             RGBColor[
             0.2517282610763278, 0.3819127412577725, 0.9376469241184826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 216}], {
             RGBColor[
             0.25996759819388404`, 0.3905728069724701, 0.9381161421783205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 221}], {
             RGBColor[
             0.27785530490942656`, 0.40937392087661617`, 0.9391348206132799]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 94}], {
             RGBColor[
             0.6965792865266065, 0.7615288190518337, 0.9714662855765266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 160}], {
             RGBColor[
             0.5607147225279772, 0.6542524975154264, 0.9585606634045596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 164}], {
             RGBColor[
             0.45756686024315646`, 0.5686282136761757, 0.9509610966011381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 168}], {
             RGBColor[
             0.4585412392278475, 0.5694721717790032, 0.9510231831684333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 277}], {
             RGBColor[
             0.440152252258617, 0.5535445555236148, 0.9498514531794966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 124}], {
             RGBColor[
             0.9048214633960636, 0.926634777474092, 0.9800597975853467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 125}], {
             RGBColor[
             0.9272871440372241, 0.9396965749731525, 0.7126838428267497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 142}], {
             RGBColor[
             0.7604864358301577, 0.8131562391312941, 0.9766718286519673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 150}], {
             RGBColor[
             0.9119777121048072, 0.931971896043791, 0.9679461351700305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 200}], {
             RGBColor[
             0.8739725410077492, 0.7339874771388775, 0.6066396220475212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.7503642165832218, 0.805193848255281, 0.9757004322912739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 295}], {
             RGBColor[
             0.8496169506590368, 0.8829255104904983, 0.9855184172875062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 96}], {
             RGBColor[
             0.44705620926157014`, 0.5606800997756136, 0.9499720483653973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 105}], {
             RGBColor[
             0.3889084199719124, 0.5085055030468593, 0.9463331921101534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 109}], {
             RGBColor[
             0.7049075830694689, 0.7678615870686365, 0.9726151362943627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 138}], {
             RGBColor[
             0.5976652055170001, 0.6832651887274253, 0.9621432473760043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 140}], {
             RGBColor[
             0.4083602605702821, 0.527163613934152, 0.9475063767322723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 154}], {
             RGBColor[
             0.6149232954890904, 0.696747339779964, 0.9638633724984019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 171}], {
             RGBColor[
             0.45349990749309843`, 0.5662613073140733, 0.9503826351187716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 198}], {
             RGBColor[
             0.4764509321887418, 0.5858433564775396, 0.9519271091606205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 245}], {
             RGBColor[
             0.4565245648697137, 0.5688811135099974, 0.9505753636122101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 289}], {
             RGBColor[
             0.38981488785686436`, 0.5094582582673273, 0.9463848141152024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 105}], {
             RGBColor[
             0.3473181215020726, 0.473441328714978, 0.9434180509343462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 138}], {
             RGBColor[
             0.5560749070471602, 0.6482010143955439, 0.959228106200197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 140}], {
             RGBColor[
             0.36676996210044227`, 0.49209943960227065`, 0.9445912355564652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 171}], {
             RGBColor[
             0.4119096090232586, 0.5311971329821921, 0.9474674939429645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 196}], {
             RGBColor[
             0.34319916551880214`, 0.4691120448196677, 0.9431834824845483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 198}], {
             RGBColor[
             0.43486063371890193`, 0.5507791821456584, 0.9490119679848132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 222}], {
             RGBColor[
             0.4207992950730278, 0.5388969322298897, 0.948033936877215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 245}], {
             RGBColor[
             0.41493426639987385`, 0.5338169391781161, 0.9476602224364029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 278}], {
             RGBColor[
             0.5041987109200126, 0.6070709568623011, 0.9544705154158305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 289}], {
             RGBColor[
             0.3482245893870246, 0.47439408393544596`, 0.9434696729393952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 290}], {
             RGBColor[
             0.5091973143554127, 0.6111290483156775, 0.9548640237887529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 298}], {
             RGBColor[
             0.3453589956577786, 0.4713821632368721, 0.9433064816157806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 134}], {
             RGBColor[
             0.2657406017726479, 0.3966405997633186, 0.9384449061917377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 144}], {
             RGBColor[
             0.28659496025462, 0.4179160304983415, 0.9396561045432549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 159}], {
             RGBColor[
             0.2524370830607903, 0.3826577581053522, 0.9376872904818896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 235}], {
             RGBColor[
             0.24975979964424241`, 0.3798437634849875, 0.9375348231520031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 252}], {
             RGBColor[
             0.2790058648824081, 0.41058323235793537`, 0.9392003433016403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 292}], {
             RGBColor[
             0.25027096919944, 0.3803810350975218, 0.937563933501964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 122}], {
             RGBColor[
             0.5234999711581451, 0.6232114459734905, 0.9558598822602524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 160}], {
             RGBColor[
             0.5065135948101279, 0.6094211404266363, 0.9545226524909898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 178}], {
             RGBColor[
             0.34993177355877136`, 0.4745851224813026, 0.9436255999612144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 181}], {
             RGBColor[
             0.5683121366528735, 0.6584973340732392, 0.9601360759487196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 182}], {
             RGBColor[
             0.3649951509133196, 0.4904176871542194, 0.9444834370172861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 208}], {
             RGBColor[
             0.3543834762769441, 0.47926414429235664`, 0.9438791178453103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 246}], {
             RGBColor[
             0.5108375562883921, 0.6129315271469358, 0.9548630505777516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 296}], {
             RGBColor[
             0.559521387516622, 0.6516299340358314, 0.9592598962290395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 104}], {
             RGBColor[
             0.3262801186675095, 0.4548403348152493, 0.9420914025992604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 123}], {
             RGBColor[
             0.40185451909948444`, 0.5224879194737331, 0.9468267925043885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 157}], {
             RGBColor[
             0.35673441532730565`, 0.48340715338862666`, 0.9439517793901664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 201}], {
             RGBColor[
             0.34430071595550393`, 0.4726377079286733, 0.9431595150608838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[
             0.3117655585077827, 0.43958461181110975`, 0.9412648198705315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 222}], {
             RGBColor[
             0.4018105363813725, 0.5224498238539401, 0.9468239899644828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 229}], {
             RGBColor[
             0.3569385719957474, 0.4835839836336185, 0.9439647880725508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 257}], {
             RGBColor[
             0.37939685727732686`, 0.5030362215582833, 0.9453958101516111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 259}], {
             RGBColor[
             0.41587462147542475`, 0.5343343034600658, 0.9478022372825421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 261}], {
             RGBColor[
             0.38406488890105717`, 0.5070794359286672, 0.9456932529988971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 121}], {
             RGBColor[
             0.9223952272310946, 0.6887967573605129, 0.4252047095816714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 125}], {
             RGBColor[
             0.9214027485620356, 0.686673945842382, 0.31717953132296794`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 127}], {
             RGBColor[
             0.8414762129232649, 0.3198099242864162, 0.18735097437698822`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 136}], {
             RGBColor[
             0.9215440004534805, 0.6869760693554257, 0.33255392800111494`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 137}], {
             RGBColor[
             0.8478732688157926, 0.3689804990841502, 0.19347680232411396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 170}], {
             RGBColor[
             0.8360368854877944, 0.2780008700889096, 0.18214226828194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 192}], {
             RGBColor[
             0.857583234347318, 0.43326449980026105`, 0.20236975515183697`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 228}], {
             RGBColor[
             0.8332617870229544, 0.6215832019337704, 0.5890075855789246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 232}], {
             RGBColor[
             0.9221384356388024, 0.6882475061102127, 0.3972545294946756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 240}], {
             RGBColor[
             0.9225569449368545, 0.6891426551809652, 0.4428066838476417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 256}], {
             RGBColor[
             0.9227141531364094, 0.6894789076236262, 0.45991782619265503`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 299}], {
             RGBColor[
             0.9223324395514323, 0.6893504120322749, 0.46837744579024243`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 108}], {
             RGBColor[
             0.44525533808141193`, 0.5575469670447641, 0.9502920083081179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 114}], {
             RGBColor[
             0.4255007228362041, 0.540035729338632, 0.9490479363174081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 187}], {
             RGBColor[
             0.4552598760386822, 0.566212394980653, 0.9509294886200896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 205}], {
             RGBColor[
             0.5380185348092877, 0.6358267098737893, 0.9567739363684693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 207}], {
             RGBColor[
             0.6460892652174881, 0.7219820565313749, 0.9663628314965813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 213}], {
             RGBColor[
             0.48723449014775655`, 0.5939071986311, 0.9529668827570787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 231}], {
             RGBColor[
             0.49585480302230733`, 0.6013736803735128, 0.9535161614708018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 133}], {
             RGBColor[
             0.36773492193593726`, 0.4929352393114849, 0.9446527219439024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 142}], {
             RGBColor[
             0.5221732711977142, 0.6208612990518254, 0.9562111960106483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 162}], {
             RGBColor[
             0.3349247683998675, 0.4622774977068556, 0.9426440773615328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[
             0.4766965463107896, 0.5841965277949407, 0.9524565634581535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 210}], {
             RGBColor[
             0.3819399405336581, 0.5052389124558365, 0.9455578531679444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 237}], {
             RGBColor[
             0.5120510519507784, 0.6128989081758123, 0.9552397996499549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 239}], {
             RGBColor[
             0.398228532934502, 0.519347272504989, 0.9465957478722895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 295}], {
             RGBColor[
             0.6113037860265932, 0.6906305704110295, 0.9650577846461873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 116}], {
             RGBColor[
             0.3006123597209014, 0.43202989779004775`, 0.9404770506166615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 119}], {
             RGBColor[
             0.28052080371187027`, 0.4121755291203697, 0.939286616826827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 152}], {
             RGBColor[
             0.26605649274810816`, 0.396972621207172, 0.9384628957154713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 164}], {
             RGBColor[
             0.33137057382359575`, 0.4586711168930102, 0.9424369368208644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 168}], {
             RGBColor[
             0.3323449528082868, 0.45951507499583777`, 0.9424990233881594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 241}], {
             RGBColor[
             0.2789461451652853, 0.41052046314879065`, 0.9391969423520976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 277}], {
             RGBColor[
             0.3139559658390563, 0.44358745874044936`, 0.9413272933992227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 128}], {
             RGBColor[
             0.26216622821870855`, 0.39288370652975557`, 0.9382413509056526]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 157}], {
             RGBColor[
             0.3155261405863954, 0.44552577951204275`, 0.9414061686253012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 173}], {
             RGBColor[
             0.2711227338075005, 0.40229756177882925`, 0.9387514106489717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 201}], {
             RGBColor[
             0.30309244121459367`, 0.43475633405208935`, 0.9406139042960187]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 209}], {
             RGBColor[
             0.2751140822771375, 0.4064927220865271, 0.9389787120396467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 218}], {
             RGBColor[
             0.2705572837668725, 0.40170323793452584`, 0.9387192091056663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 229}], {
             RGBColor[
             0.3157302972548372, 0.4457026097570346, 0.9414191773076857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 261}], {
             RGBColor[
             0.34285661416014696`, 0.46919806205208336`, 0.9431476422340319]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 279}], {
             RGBColor[
             0.27193222945827744`, 0.4031483930327844, 0.9387975102287419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 129}], {
             RGBColor[
             0.2625398824694277, 0.39327644083830926`, 0.9382626299624591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 140}], {
             RGBColor[
             0.3086221728107845, 0.4399248428735164, 0.9409523793012212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 149}], {
             RGBColor[
             0.29155965067616113`, 0.4237780571831614, 0.9399152628309327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 171}], {
             RGBColor[
             0.3537618197336009, 0.4790225362534377, 0.9438286376877205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 196}], {
             RGBColor[
             0.28505137622914434`, 0.4169374480909134, 0.9395446262293043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 230}], {
             RGBColor[
             0.2692612582166467, 0.40034103290847267`, 0.938645402367879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 245}], {
             RGBColor[
             0.35678647711021616`, 0.4816423424493619, 0.944021366181159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 263}], {
             RGBColor[
             0.2750769487244079, 0.40645369236820506`, 0.9389765973387527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 289}], {
             RGBColor[
             0.2900768000973668, 0.42221948720669167`, 0.9398308166841512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 298}], {
             RGBColor[
             0.2872112063681208, 0.41920756650811786`, 0.9396676253605367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 151}], {
             RGBColor[
             0.5499711557200619, 0.645038448022178, 0.9579401200370031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 167}], {
             RGBColor[
             0.7052976145619072, 0.7697031240469493, 0.9712611329047376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 194}], {
             RGBColor[
             0.5862509789073218, 0.6747647734348481, 0.960720844348837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 215}], {
             RGBColor[
             0.8258859987463416, 0.8619784867738793, 0.84861498208911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 283}], {
             RGBColor[
             0.6376959489926155, 0.716530117719581, 0.9647707808430861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 286}], {
             RGBColor[
             0.6078523188068897, 0.6923017142945901, 0.9624213809540463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 297}], {
             RGBColor[
             0.7085338986582898, 0.7722313337797134, 0.9715836954586705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 110}], {
             RGBColor[
             0.9135464991631714, 0.6274127712548101, 0.4734497418593211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 127}], {
             RGBColor[
             0.8334595581640123, 0.25819040288628525`, 0.17967421672601133`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 141}], {
             RGBColor[
             0.8665747340462209, 0.44887503543921714`, 0.2088850184887606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 165}], {
             RGBColor[
             0.9072036933815937, 0.6042751330644562, 0.27907410397502735`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.9138967980085537, 0.6275576288296454, 0.4676443834469852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 240}], {
             RGBColor[
             0.9145402901776019, 0.6275231337808342, 0.4351299261966648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 281}], {
             RGBColor[
             0.835111708182694, 0.27088955190662645`, 0.18125631744973736`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 114}], {
             RGBColor[
             0.32416580444258236`, 0.4547970767096937, 0.9418912109282782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 145}], {
             RGBColor[
             0.3065621353882716, 0.43629450439653, 0.9408887080179298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 169}], {
             RGBColor[
             0.3184727377256654, 0.44881330262893604`, 0.9415669992008873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 187}], {
             RGBColor[
             0.35392495764506043`, 0.4809737423517148, 0.9437727632309596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 205}], {
             RGBColor[
             0.436683616415666, 0.5505880572448512, 0.9496172109793394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 213}], {
             RGBColor[
             0.3858995717541348, 0.5086685460021616, 0.9458101573679487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 219}], {
             RGBColor[
             0.30907770812291846`, 0.4389385308371674, 0.9410319661637115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 221}], {
             RGBColor[
             0.3192668900954462, 0.449648007121744, 0.9416122250035031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 264}], {
             RGBColor[
             0.3192908615453144, 0.4496732026354332, 0.9416135901421105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 110}], {
             RGBColor[
             0.9570573175626281, 0.9656649471847494, 0.8794550171346109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 138}], {
             RGBColor[
             0.8139262808550589, 0.8553825016885668, 0.9818711941291625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 154}], {
             RGBColor[
             0.8311843708271494, 0.8688646527411055, 0.9835913192515602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 179}], {
             RGBColor[
             0.9574076164080104, 0.9658098047595847, 0.8736496587222751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 258}], {
             RGBColor[
             0.941467846616602, 0.9554926988601389, 0.9709728498600104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 138}], {
             RGBColor[
             0.8498149400101593, 0.8810685488435381, 0.8689831282162525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 141}], {
             RGBColor[
             0.9459742116007779, 0.8128132585241278, 0.5020022278511405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 154}], {
             RGBColor[
             0.8670730299822498, 0.8945506998960768, 0.8707032533386501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 165}], {
             RGBColor[
             0.9866031709361507, 0.9682133561493669, 0.5721913133374072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 179}], {
             RGBColor[
             0.9932962755631108, 0.991495851914556, 0.7607615928093651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 281}], {
             RGBColor[
             0.914511185737251, 0.6348277749915371, 0.4743735268121172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 190}], {
             RGBColor[
             0.2355732429285669, 0.36493279289716524`, 0.9367269197341752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 212}], {
             RGBColor[
             0.2273675902370908, 0.3563081316499939, 0.936259619952571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 242}], {
             RGBColor[
             0.24172339249525976`, 0.3713969900337639, 0.9370771616536675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 250}], {
             RGBColor[
             0.2327988220725642, 0.3620167006690641, 0.9365689205708136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 280}], {
             RGBColor[
             0.2555363699026189, 0.38591530508224947`, 0.9378637902825477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 115}], {
             RGBColor[
             0.236902386747869, 0.36632980732383724`, 0.9368026125083924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 134}], {
             RGBColor[
             0.2631071012640549, 0.3938726237552112, 0.9382949322336882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 146}], {
             RGBColor[
             0.24133200131587673`, 0.37098561308859834`, 0.937054872505013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 159}], {
             RGBColor[
             0.24980358255219737`, 0.3798897820972448, 0.9375373165238401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 175}], {
             RGBColor[
             0.27336230601956724`, 0.40465149417079094`, 0.9388789509732987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 204}], {
             RGBColor[
             0.24154807064065673`, 0.37121271564852854`, 0.9370671773334133]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 235}], {
             RGBColor[
             0.24712629913564943`, 0.3770757874768801, 0.9373848491939536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 242}], {
             RGBColor[
             0.24632291686669305`, 0.37623138177482907`, 0.937339097762234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 252}], {
             RGBColor[
             0.27637236437381507`, 0.40781525634982796`, 0.9390503693435908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 253}], {
             RGBColor[
             0.2744693999473012, 0.40581512008264853`, 0.9389419983346845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 280}], {
             RGBColor[
             0.2601358942740522, 0.3907496968233146, 0.9381257263911142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 292}], {
             RGBColor[
             0.24763746869084696`, 0.3776130590894144, 0.9374139595439145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 135}], {
             RGBColor[
             0.9747525126984742, 0.9797102206225822, 0.8836982332246824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 224}], {
             RGBColor[
             0.9644670009376046, 0.9390549690861945, 0.644851681061125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 249}], {
             RGBColor[
             0.8889946281823045, 0.5565337231850392, 0.5595095853153444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 254}], {
             RGBColor[
             0.925365599889266, 0.7843240503848107, 0.5923111720047104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 258}], {
             RGBColor[
             0.9605881616295711, 0.9701272959910724, 0.9515981414941335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 260}], {
             RGBColor[
             0.9042815340807562, 0.9259021424271057, 0.969533952973199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 278}], {
             RGBColor[
             0.7811703997408805, 0.8288870412862575, 0.957738894978919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 288}], {
             RGBColor[
             0.9106552013287734, 0.717527566222487, 0.5800364548609709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 290}], {
             RGBColor[
             0.7861690031762806, 0.8329451327396338, 0.9581324033518415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 145}], {
             RGBColor[
             0.28680752014306377`, 0.4187832666903979, 0.9396446360272199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 169}], {
             RGBColor[
             0.2987181224804576, 0.4313020649228039, 0.9403229272101774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 187}], {
             RGBColor[
             0.33417034239985266`, 0.4634625046455827, 0.9425286912402498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 213}], {
             RGBColor[
             0.366144956508927, 0.49115730829602955`, 0.944566085377239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 219}], {
             RGBColor[
             0.28932309287771063`, 0.4214272931310352, 0.9397878941730018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 221}], {
             RGBColor[
             0.29951227485023835`, 0.4321367694156119, 0.9403681530127932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 231}], {
             RGBColor[
             0.37476526938347776`, 0.4986237900384425, 0.945115364090962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 264}], {
             RGBColor[
             0.29953624630010656`, 0.4321619649293011, 0.9403695181514007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 132}], {
             RGBColor[
             0.21415169536183348`, 0.34241738819996653`, 0.9355069942905895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 146}], {
             RGBColor[
             0.22602095903949393`, 0.35489273687997036`, 0.9361829312980301]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 159}], {
             RGBColor[
             0.23449254027581456`, 0.3637969058886168, 0.9366653753168572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 204}], {
             RGBColor[
             0.22623702836427392`, 0.35511983943990055`, 0.9361952361264305]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 242}], {
             RGBColor[
             0.23101187459031025`, 0.36013850556620103`, 0.9364671565552513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 243}], {
             RGBColor[
             0.21987898042507611`, 0.348437127932281, 0.9358331547021821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 294}], {
             RGBColor[
             0.2157444487404361, 0.3440914729872748, 0.9355976992392334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 119}], {
             RGBColor[
             0.30231628529617693`, 0.4338208316047836, 0.9405740866574415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 133}], {
             RGBColor[
             0.3362774461822365, 0.4656883549123332, 0.9426482794056301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 152}], {
             RGBColor[
             0.2878519743324149, 0.4186179236915859, 0.9397503655460857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 164}], {
             RGBColor[
             0.35316605540790247`, 0.4803164193774241, 0.9437244066514788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 168}], {
             RGBColor[
             0.35414043439259346`, 0.4811603774802517, 0.9437864932187738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 210}], {
             RGBColor[
             0.35048246477995726`, 0.4779920280566848, 0.9435534106296721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 241}], {
             RGBColor[
             0.30074162674959204`, 0.4321657656332045, 0.9404844121827121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 277}], {
             RGBColor[
             0.33575144742336294`, 0.46523276122486323`, 0.9426147632298372]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 161}], {
             RGBColor[
             0.20987266837087443`, 0.33791985952648745`, 0.9352633100337076]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 120}], {
             RGBColor[
             0.1844220718220619, 0.3111696688926636, 0.9338139362110361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 130}], {
             RGBColor[
             0.17892828448197629`, 0.3053953500719979, 0.9335010731493483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 176}], {
             RGBColor[
             0.17894072364130287`, 0.30540842441713845`, 0.9335017815410699]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[
             0.17892828448197629`, 0.3053953500719979, 0.9335010731493483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 220}], {
             RGBColor[
             0.21806065403360642`, 0.34652595160629435`, 0.9357296037041608]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 226}], {
             RGBColor[
             0.17892828959271728`, 0.30539535544371077`, 0.9335010734403975]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 228}], {
             RGBColor[
             0.49763640594137093`, 0.5809247565206876, 0.9579151348288255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 266}], {
             RGBColor[
             0.21328176149194045`, 0.3415030325457159, 0.9354574528436509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 152}], {
             RGBColor[
             0.2677604183233837, 0.39876355502190786`, 0.9385599317562512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 164}], {
             RGBColor[
             0.33307449939887124`, 0.46046205070774604`, 0.9425339728616443]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 168}], {
             RGBColor[
             0.3340488783835623, 0.46130600881057365`, 0.9425960594289393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 241}], {
             RGBColor[
             0.2806500707405608, 0.4123113969635265, 0.9392939783928775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 130}], {
             RGBColor[
             0.18442078734008566`, 0.31116831882066576`, 0.9338138630616879]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 176}], {
             RGBColor[
             0.18443322649941224`, 0.31118139316580623`, 0.9338145714534094]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 287}], {
             RGBColor[
             0.5654447927305568, 0.5603176274195498, 0.6027460190921992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 125}], {
             RGBColor[
             0.9936176446660105, 0.9887571122327337, 0.5466981931057444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 127}], {
             RGBColor[
             0.9136911090272399, 0.6218930906767679, 0.41686963615976463`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 136}], {
             RGBColor[
             0.9937588965574554, 0.9890592357457773, 0.5620725897838914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 137}], {
             RGBColor[
             0.9200881649197675, 0.6710636654745018, 0.4229954641068904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 160}], {
             RGBColor[
             0.7924150587076538, 0.8345430649548763, 0.8078033989134862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 181}], {
             RGBColor[
             0.8542136005503994, 0.8836192586014792, 0.8134168223712162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 232}], {
             RGBColor[
             0.9943533317427773, 0.9903306725005643, 0.626773191277452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 240}], {
             RGBColor[
             0.9947718410408293, 0.9912258215713169, 0.6723253456304181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 246}], {
             RGBColor[
             0.796739020185918, 0.8380534516751759, 0.8081437970002479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 256}], {
             RGBColor[
             0.9949290492403844, 0.9915620740139779, 0.6894364879754314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 296}], {
             RGBColor[
             0.8454228514141477, 0.8767518585640715, 0.8125406426515358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 299}], {
             RGBColor[
             0.9945473356554072, 0.9914335784226265, 0.6978961075730188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 136}], {
             RGBColor[
             0.8085502082780569, 0.8465126824966431, 0.7164898471021924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 160}], {
             RGBColor[
             0.6072063704282553, 0.6919965117057422, 0.9622206562317872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 181}], {
             RGBColor[
             0.6690049122710009, 0.741072705352345, 0.9678340796895172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 207}], {
             RGBColor[
             0.6848905103681076, 0.7534826553208219, 0.9694174076484823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 231}], {
             RGBColor[
             0.5346560481729267, 0.6328742791629598, 0.9565707376227028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 232}], {
             RGBColor[
             0.8091446434633787, 0.8477841192514302, 0.781190448595753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 240}], {
             RGBColor[
             0.8095631527614308, 0.8486792683221828, 0.8267426029487193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 246}], {
             RGBColor[
             0.6115303319065195, 0.6955068984260417, 0.962561054318549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 256}], {
             RGBColor[
             0.8097203609609858, 0.8490155207648438, 0.8438537452937325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 296}], {
             RGBColor[
             0.6602141631347492, 0.7342053053149373, 0.9669578999698369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 299}], {
             RGBColor[
             0.8093386473760087, 0.8488870251734923, 0.8523133648913199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 144}], {
             RGBColor[
             0.3759650676291757, 0.5000637778518178, 0.9451771395498434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 157}], {
             RGBColor[
             0.3911005410183704, 0.5131733641705265, 0.9461415585304294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 229}], {
             RGBColor[
             0.3913046976868122, 0.5133501944155183, 0.9461545672128138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 257}], {
             RGBColor[
             0.41376298296839165`, 0.5328024323401832, 0.9475855892918741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 259}], {
             RGBColor[
             0.4502407471664895, 0.5641005142419657, 0.9499920164228051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 261}], {
             RGBColor[
             0.41843101459212195`, 0.5368456467105671, 0.9478830321391599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 125}], {
             RGBColor[
             0.970159485355791, 0.9735725032155419, 0.706048969605638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 142}], {
             RGBColor[
             0.8033587771487245, 0.8470321673736835, 0.9700369554308557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 150}], {
             RGBColor[
             0.9548500534233739, 0.9658478242861803, 0.9613112619489188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 200}], {
             RGBColor[
             0.916844882326316, 0.7678634053812667, 0.6000047488264095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 237}], {
             RGBColor[
             0.7932365579017887, 0.8390697764976703, 0.9690655590701622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 282}], {
             RGBColor[
             0.9556754222393467, 0.9664633829977154, 0.9599141278341408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 295}], {
             RGBColor[
             0.8924892919776035, 0.9168014387328876, 0.9788835440663946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 136}], {
             RGBColor[
             0.9927664178883965, 0.9869364242276462, 0.4540474115251879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 150}], {
             RGBColor[
             0.9773157340645346, 0.9789096217852411, 0.6939353071903218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[
             0.9072593029227105, 0.5779612249611302, 0.303635751806013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 192}], {
             RGBColor[
             0.9288056517822338, 0.7332248546724817, 0.32386323867590994`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 195}], {
             RGBColor[
             0.9058844617461582, 0.5673935932189047, 0.3023192023426855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 200}], {
             RGBColor[
             0.9393105629674767, 0.7809252028803274, 0.3326287940678124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 256}], {
             RGBColor[
             0.9939365705713255, 0.9894392624958468, 0.5814113097167279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 299}], {
             RGBColor[
             0.9935548569863483, 0.9893107669044954, 0.5898709293143154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 155}], {
             RGBColor[
             0.21912067898952223`, 0.3476401050444259, 0.9357899705572339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 163}], {
             RGBColor[
             0.23364896427549098`, 0.3629102540264691, 0.9366173349115978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 184}], {
             RGBColor[
             0.23168784072436213`, 0.3608489888318178, 0.9365056518265833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 189}], {
             RGBColor[
             0.22889351140479614`, 0.3579119715462422, 0.9363465189056738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 197}], {
             RGBColor[
             0.21821940668747852`, 0.34669281071101354`, 0.9357386444329454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 214}], {
             RGBColor[
             0.21941035515512047`, 0.34794457306099935`, 0.9358064671863272]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 216}], {
             RGBColor[
             0.24238826022285348`, 0.3720958081705137, 0.9371150248871702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 275}], {
             RGBColor[
             0.21935857397151598`, 0.34789014775391436`, 0.9358035183245244]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 293}], {
             RGBColor[
             0.21759994210882713`, 0.34604171416252816`, 0.9357033668416068]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 136}], {
             RGBColor[
             0.9128398822496258, 0.6200724026716804, 0.3242188545792082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 137}], {
             RGBColor[
             0.8391691506119379, 0.30207683240040506`, 0.18514172890220718`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 141}], {
             RGBColor[
             0.8658872706016187, 0.44359089015560293`, 0.2082267027178307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 165}], {
             RGBColor[
             0.9065162299369915, 0.5989909877808421, 0.27841578820409746`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 170}], {
             RGBColor[
             0.8273327672839398, 0.21109720340516447`, 0.1738071948600332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 192}], {
             RGBColor[
             0.8488791161434632, 0.3663608331165159, 0.19403468172993021`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 228}], {
             RGBColor[
             0.8245576688190998, 0.5546795352500253, 0.5806725121570179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 232}], {
             RGBColor[
             0.9134343174349477, 0.6213438394264674, 0.3889194560727688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 240}], {
             RGBColor[
             0.9138528267329997, 0.6222389884972201, 0.4344716104257349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 256}], {
             RGBColor[
             0.9140100349325547, 0.622575240939881, 0.4515827527707482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 281}], {
             RGBColor[
             0.8344242447380918, 0.2656054066230123, 0.18059800167880746`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 299}], {
             RGBColor[
             0.9136283213475775, 0.6224467453485296, 0.4600423723683357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 173}], {
             RGBColor[
             0.24821711809960986`, 0.3782223073699194, 0.9374469697202291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 209}], {
             RGBColor[
             0.25220846656924684`, 0.38241746767761725`, 0.9376742711109041]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 218}], {
             RGBColor[
             0.24765166805898178`, 0.377627983525616, 0.9374147681769237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 276}], {
             RGBColor[
             0.235521079118485, 0.3648779654253926, 0.9367239490823606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 279}], {
             RGBColor[
             0.24902661375038676`, 0.3790731386238746, 0.9374930692999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 161}], {
             RGBColor[
             0.22609023535273692`, 0.35496555067756064`, 0.9361868764815843]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 230}], {
             RGBColor[
             0.2426308084736596, 0.3723507417605582, 0.9371288376512357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 263}], {
             RGBColor[
             0.24844649898142085`, 0.37846340122029065`, 0.9374600326221096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 265}], {
             RGBColor[
             0.22918762870603976`, 0.3582211074779632, 0.936363268450872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 269}], {
             RGBColor[
             0.23146736458154496`, 0.36061725442672216`, 0.9364930960364151]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 289}], {
             RGBColor[
             0.26344635035437974`, 0.39422919605877726`, 0.9383142519675081]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 298}], {
             RGBColor[
             0.26058075662513375`, 0.3912172753602034, 0.9381510606438935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 176}], {
             RGBColor[
             0.17893943915932659`, 0.3054070743451405, 0.9335017083917216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 199}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 220}], {
             RGBColor[
             0.21805936955163013`, 0.34652460153429643`, 0.9357295305548126]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 226}], {
             RGBColor[
             0.178927005110741, 0.3053940053717128, 0.9335010002910491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 228}], {
             RGBColor[
             0.49763512145939465`, 0.5809234064486897, 0.9579150616794772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 266}], {
             RGBColor[
             0.21328047700996416`, 0.3415016824737179, 0.9354573796943026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 139}], {
             RGBColor[
             0.29015495986038786`, 0.4208144502573191, 0.9398897209981389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 143}], {
             RGBColor[
             0.3607906299670138, 0.4869204426382663, 0.9442102378002388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 172}], {
             RGBColor[
             0.297163306859998, 0.4281806673087738, 0.9402888359918464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 174}], {
             RGBColor[
             0.3585773503848271, 0.4850034111068425, 0.9440692095823882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 183}], {
             RGBColor[
             0.2897103519915022, 0.4203471391973532, 0.9398644012377442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 283}], {
             RGBColor[
             0.47177717102653804`, 0.5785602690993044, 0.9525231166057517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 188}], {
             RGBColor[
             0.20621351468350757`, 0.3340738569973212, 0.9350549266444448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 212}], {
             RGBColor[
             0.20921642322248857`, 0.3372301042671883, 0.9352259378433346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 243}], {
             RGBColor[
             0.21243933131542342`, 0.34061758501703826`, 0.935409477691362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 294}], {
             RGBColor[
             0.2083047996307834, 0.33627193007203204`, 0.9351740222284133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 162}], {
             RGBColor[
             0.31733689752319516`, 0.44704376794557543`, 0.9415233937816148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 164}], {
             RGBColor[
             0.36703566028493084`, 0.49232957401529565`, 0.9446081656098331]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 210}], {
             RGBColor[
             0.36435206965698563`, 0.49000518269455634`, 0.9444371695880264]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 239}], {
             RGBColor[
             0.38064066205782954`, 0.5041135427437089, 0.9454750642923715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 241}], {
             RGBColor[
             0.3146112316266204, 0.4441789202710761, 0.9413681711410662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 277}], {
             RGBColor[
             0.3496210523003913, 0.4772459158627348, 0.9434985221881913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 144}], {
             RGBColor[
             0.29485513198583013`, 0.42659799471298, 0.9401265091035182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 159}], {
             RGBColor[
             0.26069725479200045`, 0.3913397223199907, 0.9381576950421531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 175}], {
             RGBColor[
             0.2842559782593704, 0.41610143439353686`, 0.9394993294916116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 204}], {
             RGBColor[
             0.25244174288045984`, 0.38266265587127446`, 0.9376875558517261]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 235}], {
             RGBColor[
             0.2580199713754525, 0.388525727699626, 0.9380052277122666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 252}], {
             RGBColor[
             0.28726603661361816`, 0.4192651965725739, 0.9396707478619037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 253}], {
             RGBColor[
             0.2853630721871043, 0.41726506030539445`, 0.9395623768529974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 292}], {
             RGBColor[
             0.2585311409306501, 0.3890629993121603, 0.9380343380622274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 224}], {
             RGBColor[
             0.9798102252026126, 0.9495170954171317, 0.5749562479700403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 249}], {
             RGBColor[
             0.9043378524473125, 0.5669958495159765, 0.4896141522242598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 254}], {
             RGBColor[
             0.940708824154274, 0.7947861767157479, 0.5224157389136257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 258}], {
             RGBColor[
             0.9759313858945792, 0.9805894223220096, 0.8817027084030489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 260}], {
             RGBColor[
             0.9196247583457642, 0.9363642687580429, 0.8996385198821143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 288}], {
             RGBColor[
             0.9259984255937815, 0.7279896925534243, 0.5101410217698862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 137}], {
             RGBColor[
             0.9192369381421535, 0.6692429774694144, 0.3303446825263339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 165}], {
             RGBColor[
             0.9865840174672071, 0.9661571328498515, 0.42361874182822423`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 181}], {
             RGBColor[
             0.8533623737727853, 0.8817985705963918, 0.7207660407906598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 232}], {
             RGBColor[
             0.9935021049651632, 0.9885099844954769, 0.5341224096968956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 240}], {
             RGBColor[
             0.9939206142632153, 0.9894051335662295, 0.5796745640498617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 256}], {
             RGBColor[
             0.9940778224627702, 0.9897413860088904, 0.596785706394875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 296}], {
             RGBColor[
             0.8445716246365338, 0.8749311705589841, 0.7198898610709794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 299}], {
             RGBColor[
             0.9936961088777931, 0.9896128904175391, 0.6052453259924624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 170}], {
             RGBColor[
             0.8337298231764674, 0.2602677782028984, 0.17993302280715895`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 192}], {
             RGBColor[
             0.8552761720359909, 0.4155314079142499, 0.20016050967705595`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 195}], {
             RGBColor[
             0.8323549819999152, 0.24970014646067296`, 0.17861647334383152`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 220}], {
             RGBColor[
             0.5513789728038629, 0.36945130513336594`, 0.564612808979479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 228}], {
             RGBColor[
             0.8309547247116273, 0.6038501100477591, 0.5867983401041436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 232}], {
             RGBColor[
             0.9198313733274753, 0.6705144142242014, 0.3950452840198946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 256}], {
             RGBColor[
             0.9204070908250823, 0.671745815737615, 0.457708580717874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 266}], {
             RGBColor[
             0.546600080262197, 0.3644283860727875, 0.564340658118969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 299}], {
             RGBColor[
             0.9200253772401052, 0.6716173201462636, 0.46616820031546136`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 154}], {
             RGBColor[
             0.7239419932746806, 0.7842682543998942, 0.9731194303332016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 171}], {
             RGBColor[
             0.5625186052786886, 0.6537822219340037, 0.9596386929535714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 245}], {
             RGBColor[
             0.5655432626553039, 0.6564020281299278, 0.9598314214470098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 258}], {
             RGBColor[
             0.8342254690641332, 0.8708963005189276, 0.9605009609416519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 147}], {
             RGBColor[
             0.2408356632285271, 0.3704639302891415, 0.9370266067852049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 148}], {
             RGBColor[
             0.24714609636833407`, 0.37709659562364867`, 0.9373859766170676]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 172}], {
             RGBColor[
             0.26248705403553485`, 0.3932209148047717, 0.9382596214613016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 183}], {
             RGBColor[
             0.2550340991670391, 0.38538738669335115`, 0.9378351867071995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 206}], {
             RGBColor[
             0.2460762386198535, 0.3759721072970965, 0.9373250498010044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 244}], {
             RGBColor[
             0.2489949569451404, 0.37903986531440326`, 0.9374912664917726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 272}], {
             RGBColor[
             0.23937950956716447`, 0.3689334204655748, 0.9369436809883765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 149}], {
             RGBColor[
             0.3110114912745308, 0.4424361680704541, 0.9410884474530516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 171}], {
             RGBColor[
             0.37321366033197056`, 0.49768064714073046`, 0.9450018223098395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 196}], {
             RGBColor[
             0.304503216827514, 0.4355955589782061, 0.9407178108514234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 198}], {
             RGBColor[
             0.3961646850276139, 0.5172626963041967, 0.9465462963516883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 222}], {
             RGBColor[
             0.3821033463817397, 0.505380446388428, 0.94556826524409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 230}], {
             RGBColor[
             0.2887130988150164, 0.4189991437957653, 0.9398185869899978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 245}], {
             RGBColor[
             0.37623831770858585`, 0.5003004533366545, 0.945194550803278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 263}], {
             RGBColor[
             0.2945287893227776, 0.42511180325549774`, 0.9401497819608717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 289}], {
             RGBColor[
             0.3095286406957365, 0.4408775980939844, 0.9410040013062702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 298}], {
             RGBColor[
             0.3066630469664905, 0.4378656773954105, 0.9408408099826556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 165}], {
             RGBColor[
             0.9396314058192, 0.789675620333774, 0.3076265899668467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 179}], {
             RGBColor[
             0.9463245104461602, 0.8129581160989631, 0.4961968694388046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 232}], {
             RGBColor[
             0.9465494933171561, 0.8120284719793993, 0.41813025783551805`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[
             0.9469680026152082, 0.812923621050152, 0.46368241218848416`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 281}], {
             RGBColor[
             0.8675394206203003, 0.45629003917594413`, 0.20980880344155672`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[
             0.810515025857468, 0.8523692859433827, 0.9579232930155395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 185}], {
             RGBColor[
             0.6135470246958941, 0.696888857774001, 0.9628943539449815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 210}], {
             RGBColor[
             0.5187904189187625, 0.6179312424348968, 0.9559956436547723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 237}], {
             RGBColor[
             0.6489015303358828, 0.7255912381548726, 0.9656775901367828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 239}], {
             RGBColor[
             0.5350790113196064, 0.6320396024840493, 0.9570335383591173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 282}], {
             RGBColor[
             0.8113403946734408, 0.8529848446549176, 0.9565261589007614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 283}], {
             RGBColor[
             0.6388734394755219, 0.7174499822340865, 0.964888142090148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 295}], {
             RGBColor[
             0.7481542644116976, 0.8033229003900898, 0.9754955751330152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 297}], {
             RGBColor[
             0.7097113891411961, 0.773151198294219, 0.9717010567057325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 167}], {
             RGBColor[
             0.5753382538779925, 0.6628795153036178, 0.9613047709389584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 172}], {
             RGBColor[
             0.33312272414216076`, 0.4593269071857189, 0.9425801382634016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 174}], {
             RGBColor[
             0.39453676766698986`, 0.5161496509837875, 0.9463605118539434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 185}], {
             RGBColor[
             0.482410173529073, 0.5891453845161638, 0.9528206307321404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 237}], {
             RGBColor[
             0.5177646791690618, 0.6178477648970354, 0.9556038669239417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 239}], {
             RGBColor[
             0.4039421601527854, 0.5242961292262122, 0.9469598151462764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 283}], {
             RGBColor[
             0.5077365883087008, 0.6097065089762495, 0.9548144188773069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 297}], {
             RGBColor[
             0.5785745379743751, 0.6654077250363819, 0.9616273334928914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 158}], {
             RGBColor[
             0.35967077338482056`, 0.4859504791523989, 0.9441388815290719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 235}], {
             RGBColor[
             0.27887432985742466`, 0.4098011584346488, 0.9392164260637837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 252}], {
             RGBColor[
             0.3081203950955903, 0.44054062730759674`, 0.940881946213421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 253}], {
             RGBColor[
             0.30621743066907636`, 0.4385404910404173, 0.9407735752045145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 257}], {
             RGBColor[
             0.3535074058070181, 0.4806120799363681, 0.9437461571970662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 292}], {
             RGBColor[
             0.2793854994126222, 0.4103384300471832, 0.9392455364137446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 169}], {
             RGBColor[
             0.28111445342614677`, 0.4127994926096401, 0.939320424299829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 219}], {
             RGBColor[
             0.27171942382339986`, 0.4029247208178715, 0.9387853912626534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 221}], {
             RGBColor[
             0.2819086057959276, 0.4136341971024482, 0.9393656501024449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 264}], {
             RGBColor[
             0.28193257724579573`, 0.4136593926161374, 0.9393670152410523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 159}], {
             RGBColor[
             0.2389221548438223, 0.3684527116533779, 0.9369176353134778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 204}], {
             RGBColor[
             0.23066664293228167`, 0.35977564520466165`, 0.936447496123051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 235}], {
             RGBColor[
             0.23624487142727435`, 0.3656387170330131, 0.9367651679835913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 242}], {
             RGBColor[
             0.23544148915831797`, 0.3647943113309621, 0.9367194165518717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 243}], {
             RGBColor[
             0.22430859499308387`, 0.3530929336970421, 0.9360854146988027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 292}], {
             RGBColor[
             0.2367560409824719, 0.36617598864554746`, 0.9367942783335522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 148}], {
             RGBColor[
             0.2325030525609364, 0.36170582815947316`, 0.9365520769346783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 172}], {
             RGBColor[
             0.2478440102281372, 0.3778301473405962, 0.9374257217789124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 183}], {
             RGBColor[
             0.24039105535964145`, 0.36999661922917565`, 0.9370012870248101]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 206}], {
             RGBColor[
             0.23143319481245586`, 0.360581339832921, 0.9364911501186151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 244}], {
             RGBColor[
             0.23435191313774276`, 0.3636490978502278, 0.9366573668093834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 270}], {
             RGBColor[
             0.2272240069658551, 0.35615721652822, 0.9362514430976865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 272}], {
             RGBColor[
             0.2247364657597668, 0.3535426530013993, 0.9361097813059873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 172}], {
             RGBColor[
             0.2541544433679442, 0.3844628126751034, 0.9377850916107751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 183}], {
             RGBColor[
             0.2467014884994484, 0.37662928456368283`, 0.937360656856673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 203}], {
             RGBColor[
             0.2492037147300215, 0.37925928298232137`, 0.9375031549387921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 206}], {
             RGBColor[
             0.23774362795226284`, 0.3672140051674282, 0.9368505199504779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 244}], {
             RGBColor[
             0.24066234627754973`, 0.37028176318473494`, 0.9370167366412461]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 270}], {
             RGBColor[
             0.23353444010566207`, 0.3627898818627272, 0.9366108129295494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 272}], {
             RGBColor[
             0.23104689889957378`, 0.3601753183359065, 0.93646915113785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 171}], {
             RGBColor[
             0.3561511381973472, 0.48153386145037547`, 0.943964705839551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 227}], {
             RGBColor[
             0.27685707898321577`, 0.40832472213698934`, 0.9390779731235251]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 245}], {
             RGBColor[
             0.3591757955739624, 0.4841536676462995, 0.9441574343329895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 289}], {
             RGBColor[
             0.29246611856111315`, 0.4247308124036294, 0.9399668848359817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 298}], {
             RGBColor[
             0.28960052483186716`, 0.4217188917050555, 0.9398036935123671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 200}], {
             RGBColor[
             0.9240011310350597, 0.7732005239509658, 0.5878910864110933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 237}], {
             RGBColor[
             0.8003928066105324, 0.8444068950673695, 0.956951896654846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 282}], {
             RGBColor[
             0.9628316709480902, 0.9718005015674145, 0.9478004654188247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 295}], {
             RGBColor[
             0.8996455406863472, 0.9221385573025866, 0.9667698816510785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 167}], {
             RGBColor[
             0.5986000016649633, 0.6830276720672528, 0.9627869889383882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 194}], {
             RGBColor[
             0.4795533660103779, 0.5880893214551517, 0.9522467003824877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 251}], {
             RGBColor[
             0.36499365332834144`, 0.4885238594535514, 0.944552636407374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 286}], {
             RGBColor[
             0.5011547059099458, 0.6056262623148936, 0.953947236987697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 241}], {
             RGBColor[
             0.2661857597767988, 0.3971084890503288, 0.9384702572815218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 277}], {
             RGBColor[
             0.3011955804505697, 0.43017548464198757`, 0.9406006083286469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 163}], {
             RGBColor[
             0.2574205034515923, 0.3878956489031873, 0.9379710889008359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 211}], {
             RGBColor[
             0.25792046228139853`, 0.38842113733253425`, 0.9379995608165705]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 216}], {
             RGBColor[
             0.2661597993989548, 0.3970812030472318, 0.9384687788764086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 219}], {
             RGBColor[
             0.2738583241419696, 0.40517284066680126`, 0.9389071984715764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 221}], {
             RGBColor[
             0.2840475061144973, 0.4158823169513779, 0.939487457311368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 171}], {
             RGBColor[
             0.5797766952507789, 0.6672643729865424, 0.9613588180759691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 179}], {
             RGBColor[
             0.8674233288276321, 0.8946955574709121, 0.8648978949263142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 245}], {
             RGBColor[
             0.5828013526273942, 0.6698841791824666, 0.9615515465694076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 156}], {
             RGBColor[
             0.22000089461836236`, 0.3485652674792311, 0.935840097535134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 184}], {
             RGBColor[
             0.22486994634019453`, 0.35368294955458646`, 0.9361173828275757]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 197}], {
             RGBColor[
             0.21140151230331092`, 0.3395267714337822, 0.9353503754339378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 202}], {
             RGBColor[
             0.22021191752572378`, 0.34878706593449305`, 0.9358521149775277]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 214}], {
             RGBColor[
             0.21259246077095287`, 0.340778533783768, 0.9354181981873197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 275}], {
             RGBColor[
             0.21254067958734837`, 0.340724108476683, 0.9354152493255168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 293}], {
             RGBColor[
             0.21078204772465953`, 0.3388756748852968, 0.9353150978425994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 178}], {
             RGBColor[
             0.25237767810444756`, 0.38259531972974414`, 0.9376839074575076]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 202}], {
             RGBColor[
             0.22791002753873152`, 0.3568782676465297, 0.9362905109544353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 208}], {
             RGBColor[
             0.2568293808226203, 0.38727434154079826`, 0.9379374253416035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 214}], {
             RGBColor[
             0.2202905707839606, 0.3488697354958046, 0.9358565941642273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 268}], {
             RGBColor[
             0.2451076812596908, 0.374954092101482, 0.9372698918921952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 201}], {
             RGBColor[
             0.3335467378743898, 0.46332315262546664`, 0.9424742810869247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 218}], {
             RGBColor[
             0.30101158042666865`, 0.4302700565079032, 0.9405795858965723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 229}], {
             RGBColor[
             0.34618459391463335`, 0.47426942833041186`, 0.9432795540985917]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 257}], {
             RGBColor[
             0.3686428791962128, 0.49372166625507674`, 0.944710576177652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 259}], {
             RGBColor[
             0.40512064339431064`, 0.5250197481568593, 0.947117003308583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 261}], {
             RGBColor[
             0.3733109108199431, 0.49776488062546065`, 0.9450080190249379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 284}], {
             RGBColor[
             0.3008123283039969, 0.4300606298936609, 0.9405682387829533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 175}], {
             RGBColor[
             0.34907161965836087`, 0.47545391883295585`, 0.9435117019171652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 177}], {
             RGBColor[
             0.4114198455834537, 0.5307729245068593, 0.947436286649661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 217}], {
             RGBColor[
             0.6053338779034495, 0.6866046110497097, 0.9641707450092601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 252}], {
             RGBColor[
             0.35208167801260865`, 0.47861768101199287`, 0.9436831202874573]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 253}], {
             RGBColor[
             0.35017871358609476`, 0.47661754474481344`, 0.9435747492785509]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 175}], {
             RGBColor[
             0.2709524595475128, 0.4021185927355705, 0.9387417137817635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 204}], {
             RGBColor[
             0.23913822416860225`, 0.3686798142133081, 0.9369299401418781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 235}], {
             RGBColor[
             0.24471645266359499`, 0.3745428860416596, 0.9372476120024185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 252}], {
             RGBColor[
             0.2739625179017606, 0.4052823549146075, 0.9389131321520556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 253}], {
             RGBColor[
             0.27205955347524674`, 0.4032822186474281, 0.9388047611431494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 292}], {
             RGBColor[
             0.24522762221879252`, 0.3750801576541939, 0.9372767223523794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 168}], {
             RGBColor[
             0.4880465107801085, 0.5934258804224648, 0.9533459462263981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[
             0.6520185359229838, 0.7272823998054908, 0.9664968499202544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 246}], {
             RGBColor[
             0.5945439555585024, 0.6817165928791875, 0.9612238245492863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 256}], {
             RGBColor[
             0.7927339846129686, 0.8352252152179895, 0.8425165155244698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 296}], {
             RGBColor[
             0.6432277867867322, 0.7204149997680831, 0.9656206702005743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 299}], {
             RGBColor[
             0.7923522710279916, 0.8350967196266381, 0.8509761351220573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 186}], {
             RGBColor[
             0.22312007554742067`, 0.3518437244031648, 0.9360177302746292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 230}], {
             RGBColor[
             0.2328116110999559, 0.36203014274772405`, 0.9365696488870041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 265}], {
             RGBColor[
             0.21936843133233605`, 0.34790050846512904`, 0.9358040796866404]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 269}], {
             RGBColor[
             0.22164816720784125`, 0.350296655413888, 0.9359339072721834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 191}], {
             RGBColor[
             0.26420786908525307`, 0.39502960052800135`, 0.9383576193326653]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 203}], {
             RGBColor[
             0.27206034387321254`, 0.4032830494058043, 0.9388048061551442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 210}], {
             RGBColor[
             0.33154191612091594`, 0.45934744108992703`, 0.9424285250056568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 239}], {
             RGBColor[
             0.34783050852175984`, 0.47345580113907954`, 0.9434664197100019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 184}], {
             RGBColor[
             0.23939823162616325`, 0.3689530985366296, 0.9369447471819397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.23660390230659725`, 0.366016081251054, 0.9367856142610302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 197}], {
             RGBColor[
             0.22592979758927967`, 0.35479692041582533`, 0.9361777397883018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 211}], {
             RGBColor[
             0.2418593140070983, 0.3715398521606279, 0.9370849021826888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 216}], {
             RGBColor[
             0.2500986511246546, 0.3801999178753255, 0.9375541202425267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 168}], {
             RGBColor[
             0.38489864849528777`, 0.5078015965832141, 0.9457463794229767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 210}], {
             RGBColor[
             0.3812406788826516, 0.5046332471596473, 0.9455132968338751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 241}], {
             RGBColor[
             0.33149984085228634`, 0.458806984736167, 0.9424442983869149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 277}], {
             RGBColor[
             0.36650966152605724`, 0.4918739803278257, 0.94457464943404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 179}], {
             RGBColor[
             0.986953469781533, 0.9683582137242022, 0.5663859549250714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 207}], {
             RGBColor[
             0.8629243195572578, 0.8731271056740303, 0.676546302374514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 232}], {
             RGBColor[
             0.9871784526525289, 0.9674285696046385, 0.48831934332178484`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 240}], {
             RGBColor[
             0.987596961950581, 0.9683237186753911, 0.533871497674751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 281}], {
             RGBColor[
             0.9081683799556731, 0.6116901368011833, 0.2799978889278235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 217}], {
             RGBColor[
             0.899879476841495, 0.9180128953290518, 0.7153753712159427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 233}], {
             RGBColor[
             0.9934058766223102, 0.9883041618002921, 0.5236485484298345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 262}], {
             RGBColor[
             0.9933514957949947, 0.9881878467094093, 0.5177295309761065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 271}], {
             RGBColor[
             0.9850940999243964, 0.9612451065301149, 0.40815265332302325`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 291}], {
             RGBColor[
             0.9053156340255587, 0.5627492600761606, 0.30706567418331665`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 174}], {
             RGBColor[
             0.5731249742958058, 0.6609624837721939, 0.9611637427211077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 185}], {
             RGBColor[
             0.660998380157889, 0.7339582173045702, 0.9676238615993047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 194}], {
             RGBColor[
             0.6348798248522232, 0.7127539974799229, 0.9655677132502221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 215}], {
             RGBColor[
             0.874514844691243, 0.8999677108189541, 0.8534618509904951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 282}], {
             RGBColor[
             0.8587917501354356, 0.8900542041854869, 0.9612556665550847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 283}], {
             RGBColor[
             0.6863247949375169, 0.7545193417646557, 0.9696176497444712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 286}], {
             RGBColor[
             0.6564811647517911, 0.7302909383396649, 0.9672682498554315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 297}], {
             RGBColor[
             0.7571627446031911, 0.8102205578247882, 0.9764305643600557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 182}], {
             RGBColor[
             0.34652806688330007`, 0.474422427150048, 0.9433067307526943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 277}], {
             RGBColor[
             0.3674840405107483, 0.49271793843065337`, 0.944636736001335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 187}], {
             RGBColor[
             0.3284772756829356, 0.4574787305648249, 0.9422044795128589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 213}], {
             RGBColor[
             0.36045188979201, 0.48517353421527176`, 0.944241873649848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 219}], {
             RGBColor[
             0.2836300261607937, 0.41544351905027754`, 0.9394636824456108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 221}], {
             RGBColor[
             0.2938192081333214, 0.4261529953348542, 0.9400439412854023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 264}], {
             RGBColor[
             0.29384317958318956`, 0.42617819084854336`, 0.9400453064240097]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[
             0.8434397887079927, 0.3245517789190093, 0.188825975634882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 195}], {
             RGBColor[
             0.820518598671917, 0.15872051746543236`, 0.16728193930165758`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 200}], {
             RGBColor[
             0.8539446998932355, 0.37225212712685507`, 0.1975915310267845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 225}], {
             RGBColor[
             0.8914281470596066, 0.5246344158422436, 0.23572348923178596`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 228}], {
             RGBColor[
             0.8191183413836293, 0.5128704810525186, 0.5754638060619697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 255}], {
             RGBColor[
             0.8904238882805281, 0.5212468151692371, 0.2318221335134233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 198}], {
             RGBColor[
             0.4413043319504303, 0.556360389684118, 0.9494225547381876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 245}], {
             RGBColor[
             0.4213779646314022, 0.5393981467165758, 0.9480708091897773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 289}], {
             RGBColor[
             0.35466828761855285`, 0.4799752914739057, 0.9438802596927696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 298}], {
             RGBColor[
             0.35180269388930685`, 0.47696337077533185`, 0.9437170683691549]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 174}], {
             RGBColor[
             0.33090944455997406`, 0.4574098756542951, 0.9424391100455509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 183}], {
             RGBColor[
             0.2620424461666492, 0.39275360374480583`, 0.9382343017009069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 203}], {
             RGBColor[
             0.26454467239722235`, 0.39538360216344437`, 0.9383767997830261]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 206}], {
             RGBColor[
             0.2530845856194636, 0.3833383243485512, 0.9377241647947119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 244}], {
             RGBColor[
             0.2560033039447505, 0.38640608236585794`, 0.9378903814854801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 270}], {
             RGBColor[
             0.24887539777286288`, 0.3789142010438502, 0.9374844577737833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 272}], {
             RGBColor[
             0.2463878565667746, 0.37629963751702955`, 0.937342795982084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 186}], {
             RGBColor[
             0.24357136840210497`, 0.3733393298802981, 0.937182401147727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 196}], {
             RGBColor[
             0.2690530219671379, 0.40012216340729806`, 0.9386335436215274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 209}], {
             RGBColor[
             0.2611649721580388, 0.3918313229266909, 0.938184330854223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 230}], {
             RGBColor[
             0.25326290395464024`, 0.3835257482248573, 0.9377343197601018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 263}], {
             RGBColor[
             0.25907859446240145`, 0.3896384076845897, 0.9380655147309758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 276}], {
             RGBColor[
             0.24447758470727698`, 0.3742918206744662, 0.9372340088256796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 279}], {
             RGBColor[
             0.2579831193391787, 0.3884869938729482, 0.9380031290433184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 185}], {
             RGBColor[
             0.4801968939468863, 0.58722835298474, 0.9526796025142897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 194}], {
             RGBColor[
             0.45407833864122044`, 0.5660241331600927, 0.9506234541652072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 283}], {
             RGBColor[
             0.5055233087265141, 0.6077894774448256, 0.9546733906594562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 297}], {
             RGBColor[
             0.5763612583921884, 0.663490693504958, 0.9614863052750408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 177}], {
             RGBColor[
             0.3568594089399756, 0.48219931048302006`, 0.944007932963718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 242}], {
             RGBColor[
             0.2674717938620085, 0.3984601924131547, 0.9385434950201575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 252}], {
             RGBColor[
             0.2975212413691305, 0.4300440669881537, 0.9402547666015143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 253}], {
             RGBColor[
             0.29561827694261666`, 0.42804393072097424`, 0.9401463955926079]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 280}], {
             RGBColor[
             0.2812847712693677, 0.4129785074616403, 0.9393301236490378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 199}], {
             RGBColor[
             0.17893943915932659`, 0.3054070743451405, 0.9335017083917216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 226}], {
             RGBColor[
             0.17893944427006758`, 0.3054070797168533, 0.9335017086827707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 287}], {
             RGBColor[
             0.5599634445497977, 0.5545563829440247, 0.6024338644222329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 217}], {
             RGBColor[
             0.6131216671850642, 0.6933500026997739, 0.964666976055813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 247}], {
             RGBColor[
             0.4991479409504841, 0.603343634292864, 0.9539698061272375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 273}], {
             RGBColor[
             0.5185213619952923, 0.6190718502597115, 0.9554949527990644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 285}], {
             RGBColor[
             0.40098949086418123`, 0.5217386754938967, 0.9467716736701495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 182}], {
             RGBColor[
             0.29211972893207316`, 0.4243667349411374, 0.9399471584590454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 202}], {
             RGBColor[
             0.25258870101180897`, 0.3828171181850061, 0.9376959248999015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 208}], {
             RGBColor[
             0.2815080542956977, 0.41321319207927465`, 0.9393428392870697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 268}], {
             RGBColor[
             0.26978635473276824`, 0.4008929426399584, 0.9386753058376613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 281}], {
             RGBColor[
             0.9148614845826333, 0.6349726325663724, 0.4685681683997813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 190}], {
             RGBColor[
             0.23107912024585836`, 0.36020918501380295`, 0.9364709860958538]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 250}], {
             RGBColor[
             0.22830469938985565`, 0.3572930927857018, 0.9363129869324922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 207}], {
             RGBColor[
             0.729702675862836, 0.7887685434205706, 0.9736936013369495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 232}], {
             RGBColor[
             0.8539568089581072, 0.8830700073511788, 0.7854666422842203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 240}], {
             RGBColor[
             0.8543753182561593, 0.8839651564219314, 0.8310187966371865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 246}], {
             RGBColor[
             0.656342497401248, 0.7307927865257904, 0.9668372480070162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 256}], {
             RGBColor[
             0.8545325264557142, 0.8843014088645924, 0.8481299389821997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 296}], {
             RGBColor[
             0.7050263286294778, 0.769491193414686, 0.9712340936583042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 299}], {
             RGBColor[
             0.8541508128707371, 0.884172913273241, 0.8565895585797871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 208}], {
             RGBColor[
             0.2965714316502459, 0.42904575675219153`, 0.9402006763431414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 268}], {
             RGBColor[
             0.28484973208731645`, 0.4167255073128753, 0.939533142893733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 244}], {
             RGBColor[
             0.24855034907625476`, 0.37857255425443737`, 0.937465946731378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 189}], {
             RGBColor[
             0.2346427787554684, 0.3639548160564028, 0.9366739311760157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 197}], {
             RGBColor[
             0.22396867403815082`, 0.3527356552211741, 0.9360660567032872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 202}], {
             RGBColor[
             0.23277907926056368`, 0.361995949721885, 0.9365677962468772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 214}], {
             RGBColor[
             0.22515962250579277`, 0.3539874175711599, 0.9361338794566691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 216}], {
             RGBColor[
             0.24813752757352578`, 0.3781386526806742, 0.9374424371575123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 275}], {
             RGBColor[
             0.22510784132218828`, 0.35393299226407493`, 0.9361309305948662]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 293}], {
             RGBColor[
             0.22334920945949943`, 0.35208455867268873`, 0.9360307791119489]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 237}], {
             RGBColor[
             0.6034248054489583, 0.6889264668979879, 0.961922957584288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 239}], {
             RGBColor[
             0.4896022864326819, 0.5953748312271646, 0.9532789058066227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 282}], {
             RGBColor[
             0.7658636697865162, 0.8163200733980329, 0.9527715263482667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 283}], {
             RGBColor[
             0.5933967145885973, 0.6807852109772019, 0.9611335095376532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 295}], {
             RGBColor[
             0.7026775395247731, 0.7666581291332051, 0.9717409425805205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 297}], {
             RGBColor[
             0.6642346642542716, 0.7364864270373344, 0.9679464241532377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 196}], {
             RGBColor[
             0.255450766680841, 0.38582533066860314`, 0.9378589153057062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 230}], {
             RGBColor[
             0.23966064866834333`, 0.3692289154861624, 0.9369596914442806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 263}], {
             RGBColor[
             0.24547633917610456`, 0.3753415749458948, 0.9372908864151546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 269}], {
             RGBColor[
             0.2284972047762287, 0.3574954281523263, 0.93632394982946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 276}], {
             RGBColor[
             0.2308753294209801, 0.3599949879357713, 0.9364593805098584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 279}], {
             RGBColor[
             0.24438086405288187`, 0.3741901611342533, 0.9372285007274972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 205}], {
             RGBColor[
             0.44668815437293624`, 0.55925348518074, 0.950254691291311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 213}], {
             RGBColor[
             0.395904109711405, 0.5173339739380506, 0.9464476376799205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 264}], {
             RGBColor[
             0.3292953995025846, 0.4583386305713222, 0.9422510704540822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 212}], {
             RGBColor[
             0.20871789165381538`, 0.33670611597978567`, 0.9351975472080101]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 243}], {
             RGBColor[
             0.21194079974675017`, 0.3400935967296356, 0.9353810870560375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 294}], {
             RGBColor[
             0.20780626806211017`, 0.3357479417846294, 0.9351456315930887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 197}], {
             RGBColor[
             0.22117434471858483`, 0.3497986379355985, 0.9359069237823778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 211}], {
             RGBColor[
             0.23710386113640347`, 0.3665415696804011, 0.9368140861767649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 216}], {
             RGBColor[
             0.24534319825395978`, 0.3752016353950986, 0.9372833042366027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 275}], {
             RGBColor[
             0.22231351200262228`, 0.3509959749784993, 0.9359717976739568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 293}], {
             RGBColor[
             0.2205548801399334, 0.3491475413871131, 0.9358716461910392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 212}], {
             RGBColor[
             0.21992645288427248`, 0.3484870244968241, 0.9358358581885042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 250}], {
             RGBColor[
             0.22535768471974588`, 0.35419559351589436`, 0.9361451588067469]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 203}], {
             RGBColor[
             0.2517414689713402, 0.38192662359285945`, 0.9376476762885642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 195}], {
             RGBColor[
             0.8420649475314406, 0.3139841471767838, 0.18750942617155456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 200}], {
             RGBColor[
             0.875491048752759, 0.5275157568382065, 0.21781901789668148`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[
             0.91297449591913, 0.6798980455535951, 0.25595097610168294`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 228}], {
             RGBColor[
             0.8406646902431527, 0.6681341107638701, 0.5956912929318666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 255}], {
             RGBColor[
             0.9119702371400515, 0.6765104448805886, 0.25204962038332024`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 199}], {
             RGBColor[
             0.28921237678725265`, 0.4129203038152378, 0.9400888107445714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 220}], {
             RGBColor[
             0.3283447463388828, 0.4540509053495343, 0.9423173412993839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 236}], {
             RGBColor[
             0.511354201918838, 0.6127180573453962, 0.9550785966275717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 249}], {
             RGBColor[
             0.609038860752824, 0.33213297985445467`, 0.5560510629020323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 266}], {
             RGBColor[
             0.3235658537972168, 0.4490279862889558, 0.942045190438874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 283}], {
             RGBColor[
             0.5672781592829315, 0.6595809911525545, 0.9590773611885706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 286}], {
             RGBColor[
             0.5374345290972057, 0.6353525877275636, 0.9567279612995309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 297}], {
             RGBColor[
             0.6381161089486057, 0.715282207212687, 0.9658902758041552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 200}], {
             RGBColor[
             0.8525698587166832, 0.36168449538462955`, 0.19627498156345707`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 225}], {
             RGBColor[
             0.8900533058830544, 0.5140667841000182, 0.23440693976845853`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.8890490471039758, 0.5106791834270117, 0.23050558405009586`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 230}], {
             RGBColor[
             0.2651423022333762, 0.39601174901316233`, 0.938410833918081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 263}], {
             RGBColor[
             0.27095799274113747`, 0.40212440847289477`, 0.9387420288889549]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 279}], {
             RGBColor[
             0.2698625176179148, 0.40097299466125325`, 0.9386796432012976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 289}], {
             RGBColor[
             0.28595784411409636`, 0.4178902033113814, 0.9395962482343534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 298}], {
             RGBColor[
             0.28309225038485036`, 0.4148782826128075, 0.9394330569107388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 214}], {
             RGBColor[
             0.21169118846890916`, 0.33983123945035565`, 0.9353668720630313]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 275}], {
             RGBColor[
             0.21163940728530467`, 0.33977681414327066`, 0.9353639232012283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 293}], {
             RGBColor[
             0.20988077542261582`, 0.33792838055188446`, 0.9352637717183109]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 222}], {
             RGBColor[
             0.4501940180001994, 0.5640601889318158, 0.9499889976724383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 245}], {
             RGBColor[
             0.4443289893270455, 0.5589801958800422, 0.949615283231626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 258}], {
             RGBColor[
             0.7130111957358749, 0.7734744682690422, 0.9502848227262681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 278}], {
             RGBColor[
             0.5335934338471843, 0.6322342135642272, 0.9564255762110536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 290}], {
             RGBColor[
             0.5385920372825843, 0.6362923050176035, 0.9568190845839761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 220}], {
             RGBColor[
             0.21805936955163013`, 0.34652460153429643`, 0.9357295305548126]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 226}], {
             RGBColor[
             0.178927005110741, 0.3053940053717128, 0.9335010002910491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 228}], {
             RGBColor[
             0.49763512145939465`, 0.5809234064486897, 0.9579150616794772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 266}], {
             RGBColor[
             0.21328047700996416`, 0.3415016824737179, 0.9354573796943026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 225}], {
             RGBColor[
             0.9234794071043728, 0.7275983937614409, 0.2647165314935854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 255}], {
             RGBColor[
             0.9224751483252943, 0.7242107930884344, 0.2608151757752228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 282}], {
             RGBColor[
             0.9248264998510323, 0.7738160826625009, 0.5864939522963153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 295}], {
             RGBColor[
             0.8616403695892892, 0.7241541383976731, 0.6054633685285691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 209}], {
             RGBColor[
             0.29313467956513195`, 0.424290095199951, 0.9400468245012701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 218}], {
             RGBColor[
             0.2885778810548669, 0.4195006110479498, 0.9397873215672898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 229}], {
             RGBColor[
             0.3337508945428317, 0.46349998287045846`, 0.9424872897693092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 257}], {
             RGBColor[
             0.35620917982441114`, 0.48295222079512334`, 0.9439183118483695]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 259}], {
             RGBColor[
             0.3926869440225089, 0.5142503026969059, 0.9463247389793005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 261}], {
             RGBColor[
             0.36087721144814144`, 0.48699543516550725`, 0.9442157546956553]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 208}], {
             RGBColor[
             0.2570404037299817, 0.3874961399960602, 0.9379494427839974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 214}], {
             RGBColor[
             0.22050159369132202`, 0.3490915339510665, 0.935868611606621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 268}], {
             RGBColor[
             0.2453187041670522, 0.37517589055674394`, 0.937281909334589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 275}], {
             RGBColor[
             0.22044981250771753`, 0.3490371086439815, 0.9358656627448182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 206}], {
             RGBColor[
             0.24813385698154097`, 0.37813479465576916`, 0.9374422281227288]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 244}], {
             RGBColor[
             0.2510525753068279, 0.38120255267307596`, 0.9376084448134971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 270}], {
             RGBColor[
             0.2439246691349402, 0.37371067135106817`, 0.9372025211018002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 235}], {
             RGBColor[
             0.23646094075205434`, 0.36586581959294334`, 0.9367774728119916]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 253}], {
             RGBColor[
             0.26380404156370607`, 0.39460515219871184`, 0.9383346219527224]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 292}], {
             RGBColor[
             0.2369721103072519, 0.36640309120547765`, 0.9368065831619525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 213}], {
             RGBColor[
             0.4786627684820106, 0.5869482888311869, 0.9522920854283001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 231}], {
             RGBColor[
             0.4872830813565614, 0.5944147705735998, 0.9528413641420233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 244}], {
             RGBColor[
             0.23959248852906917`, 0.3691572748581827, 0.9369558098251829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 270}], {
             RGBColor[
             0.23246458235718154`, 0.361665393536175, 0.936549886113486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 272}], {
             RGBColor[
             0.22997704115109324`, 0.35905083000935434`, 0.9364082243217868]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 231}], {
             RGBColor[
             0.5953538117647618, 0.6805701172311853, 0.962430259270135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 232}], {
             RGBColor[
             0.8698424070552139, 0.8954799573196557, 0.7870499702431855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 240}], {
             RGBColor[
             0.870260916353266, 0.8963751063904083, 0.8326021245961515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 268}], {
             RGBColor[
             0.274238057450941, 0.4055719644510125, 0.9389288237217572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 218}], {
             RGBColor[
             0.2605995221174108, 0.3912369990823875, 0.9381521293109176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 276}], {
             RGBColor[
             0.24846893317691396`, 0.37848698098216405`, 0.9374613102163545]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 279}], {
             RGBColor[
             0.2619744678088157, 0.39268215418064606`, 0.9382304304339932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 239}], {
             RGBColor[
             0.39484568065555037`, 0.5164172158880604, 0.9463801955164135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 277}], {
             RGBColor[
             0.36382607089811214`, 0.48954958900708645`, 0.9444036534122333]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 216}], {
             RGBColor[
             0.2505986099544608, 0.38072540630467244`, 0.9375825921582613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 221}], {
             RGBColor[
             0.26848631667000333`, 0.39952652020881857`, 0.9386012705932207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 243}], {
             RGBColor[
             0.2149437082857312, 0.34324984399950276`, 0.9355520982549272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 250}], {
             RGBColor[
             0.21715203202826977`, 0.34557093226872304`, 0.9356778590251427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 294}], {
             RGBColor[
             0.2108091766010912, 0.3389041890544966, 0.9353166427919786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 231}], {
             RGBColor[
             0.43649903669503015`, 0.5524952593309104, 0.9490343105306326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 264}], {
             RGBColor[
             0.36127001361165895`, 0.48603343422176903`, 0.9442884645910713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 275}], {
             RGBColor[
             0.21283035575294662`, 0.34102857649325646`, 0.9354317459546102]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 293}], {
             RGBColor[
             0.21107172389025777`, 0.33918014290187026`, 0.9353315944716927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 223}], {
             RGBColor[
             0.9412290011481947, 0.7868146166289862, 0.47926705037049566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 234}], {
             RGBColor[
             0.9062111144378386, 0.5631850367729421, 0.44751685008743375`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 271}], {
             RGBColor[
             0.9862840872732699, 0.9639445925953173, 0.5488858494022204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 274}], {
             RGBColor[
             0.979839341035498, 0.9422049502369351, 0.5238492272566825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 282}], {
             RGBColor[
             0.97938013431987, 0.9823295669124169, 0.8386095157394571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 286}], {
             RGBColor[
             0.7770695489362254, 0.8225663010665949, 0.8446220990398039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 233}], {
             RGBColor[
             0.9005620992858752, 0.9194729557138646, 0.7896746116293041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 247}], {
             RGBColor[
             0.6930619732704799, 0.7591753208357144, 0.9707042644868367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 262}], {
             RGBColor[
             0.9005077184585596, 0.9193566406229818, 0.783755594175576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 273}], {
             RGBColor[
             0.7124353943152881, 0.7749035368025619, 0.9722294111586636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 229}], {
             RGBColor[
             0.3012157370951104, 0.430446886752895, 0.9405925945789568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 284}], {
             RGBColor[
             0.25584347148447395`, 0.38623808831614403`, 0.9378812792633183]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 221}], {
             RGBColor[
             0.28442417853057445`, 0.4162782235430855, 0.9395089082482266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 264}], {
             RGBColor[
             0.28444814998044265`, 0.4163034190567747, 0.9395102733868341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 226}], {
             RGBColor[
             0.21805937466237113`, 0.3465246069060093, 0.9357295308458616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 228}], {
             RGBColor[
             0.5367674910110247, 0.6220540079829862, 0.9601435922342896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 236}], {
             RGBColor[
             0.4402011946832155, 0.5463223550644548, 0.9507193164378127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 266}], {
             RGBColor[
             0.2524128465615943, 0.3826322840080144, 0.9376859102491151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 231}], {
             RGBColor[
             0.3698663550363416, 0.4934747204504928, 0.9448363781661868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 245}], {
             RGBColor[
             0.43026765068117134`, 0.5470979459642735, 0.9486372521240278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 261}], {
             RGBColor[
             0.41838703187400994`, 0.5368075510907742, 0.9478802295992542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 278}], {
             RGBColor[
             0.51953209520131, 0.6203519636484585, 0.9554475451034554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 290}], {
             RGBColor[
             0.5245306986367102, 0.6244100551018348, 0.9558410534763778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 234}], {
             RGBColor[
             0.852336886710356, 0.35775657985604403`, 0.19596820028306192`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 271}], {
             RGBColor[
             0.9324098595457874, 0.7585161356784191, 0.29733719959784854`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 274}], {
             RGBColor[
             0.9259651133080155, 0.7367764933200369, 0.2723005774523107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 287}], {
             RGBColor[
             0.9141648921008272, 0.6925393884549282, 0.24954185631357317`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 291}], {
             RGBColor[
             0.8526313936469496, 0.36002028922446494`, 0.19625022045814194`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 249}], {
             RGBColor[
             0.8940523406864429, 0.5263405979795888, 0.25076760006070237`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 254}], {
             RGBColor[
             0.9304233123934045, 0.7541309251793602, 0.28356918675006826`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 258}], {
             RGBColor[
             0.9656458741337097, 0.9399341707856219, 0.6428561562394914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 260}], {
             RGBColor[
             0.9093392465848947, 0.8957090172216551, 0.6607919677185569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 288}], {
             RGBColor[
             0.9157129138329121, 0.6873344410170366, 0.27129446960632875`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 234}], {
             RGBColor[
             0.889140927135372, 0.5070538412384147, 0.23353324484929344`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 255}], {
             RGBColor[
             0.9599585954916654, 0.876593081803823, 0.2989471339802242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 287}], {
             RGBColor[
             0.950968932525843, 0.8418366498372989, 0.2871069008798047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 228}], {
             RGBColor[
             0.4976351265701356, 0.5809234118204025, 0.9579150619705263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 266}], {
             RGBColor[
             0.21328048212070516`, 0.3415016878454308, 0.9354573799853517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 264}], {
             RGBColor[
             0.2772132461146813, 0.4086990763744601, 0.9390982563147601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 266}], {
             RGBColor[
             0.5319885984693589, 0.6170310889224077, 0.9598714413737797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 257}], {
             RGBColor[
             0.3688470358646546, 0.49389849650006856`, 0.9447235848600365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 259}], {
             RGBColor[
             0.40532480006275245`, 0.5251965784018511, 0.9471300119909675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 261}], {
             RGBColor[
             0.3735150674883849, 0.49794171087045247`, 0.9450210277073223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 284}], {
             RGBColor[
             0.3010164849724387, 0.4302374601386527, 0.9405812474653377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 263}], {
             RGBColor[
             0.2551678747286398, 0.38552799329045395`, 0.9378428050275294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 269}], {
             RGBColor[
             0.23818874032876391`, 0.3676818464968855, 0.9368758684418348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 289}], {
             RGBColor[
             0.27016772610159867`, 0.4012937881289406, 0.9386970243729278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 298}], {
             RGBColor[
             0.2673021323723527, 0.39828186743036675`, 0.9385338330493134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 240}], {
             RGBColor[
             0.9945150494485371, 0.9906765703210165, 0.6443751655434223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 256}], {
             RGBColor[
             0.9946722576480922, 0.9910128227636774, 0.6614863078884357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 296}], {
             RGBColor[
             0.8451660598218556, 0.8762026073137711, 0.7845904625645401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 299}], {
             RGBColor[
             0.994290544063115, 0.9908843271723261, 0.6699459274860231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 262}], {
             RGBColor[
             0.9940341182393746, 0.9896479070942221, 0.5920287713894679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 288}], {
             RGBColor[
             0.9279948066453856, 0.7277856301692169, 0.40221351612468526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 291}], {
             RGBColor[
             0.9059982564699387, 0.5642093204609733, 0.381364914596678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 255}], {
             RGBColor[
             0.8881366683562935, 0.5036662405654082, 0.2296318891309308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 271}], {
             RGBColor[
             0.8973919728354314, 0.5348865558223752, 0.26558699931478663`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 274}], {
             RGBColor[
             0.8909472265976595, 0.513146913463993, 0.24055037716924876`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 287}], {
             RGBColor[
             0.8791470053904711, 0.46890980859888415`, 0.21779165603051126`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 252}], {
             RGBColor[
             0.2712852344852127, 0.40246836029424277`, 0.9387606648221691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 253}], {
             RGBColor[
             0.2693822700586988, 0.40046822402706334`, 0.9386522938132629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 292}], {
             RGBColor[
             0.24255033880224458`, 0.3722661630338292, 0.9371242550224929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 249}], {
             RGBColor[
             0.7208953090971567, 0.4244044295693752, 0.5644530380404611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 266}], {
             RGBColor[
             0.43542230214154953`, 0.5412994360038763, 0.9504471655773028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 239}], {
             RGBColor[
             0.5249567920726707, 0.6240772116080362, 0.9560621419984239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 282}], {
             RGBColor[
             0.8012181754265049, 0.8450224537789045, 0.955554762540068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 283}], {
             RGBColor[
             0.6287512202285861, 0.7094875913580734, 0.9639167457294545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 295}], {
             RGBColor[
             0.738032045164762, 0.7953605095140767, 0.9745241787723218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 297}], {
             RGBColor[
             0.6995891698942603, 0.7651888074182058, 0.970729660345039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 251}], {
             RGBColor[
             0.2826141781107905, 0.4143757983412377, 0.9394058314019756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 300}], {
             RGBColor[
             0.2671877155710705, 0.398161608117775, 0.9385273171817448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 295}], {
             RGBColor[
             0.6242095261484855, 0.7018088738432534, 0.9658801269946564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 256}], {
             RGBColor[
             0.9950907669461442, 0.9919079718344301, 0.7070384622414018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 281}], {
             RGBColor[
             0.9155049767516813, 0.6349381375175613, 0.436053711149461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 299}], {
             RGBColor[
             0.9947090533611671, 0.9917794762430787, 0.7154980818389891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 277}], {
             RGBColor[
             0.3140852328677468, 0.44372332658360614`, 0.9413346549652732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 243}], {
             RGBColor[
             0.22929951054390013`, 0.35833870238327276`, 0.9363696399560237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 280}], {
             RGBColor[
             0.25424538211649345`, 0.38455839506567835`, 0.9377902704379731]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 294}], {
             RGBColor[
             0.22516497885926012`, 0.35399304743826654`, 0.9361341844930751]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 294}], {
             RGBColor[
             0.21403208469402601`, 0.34229166980434655`, 0.935500182640006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 270}], {
             RGBColor[
             0.23538330068246843`, 0.36473315155348174`, 0.9367161028042543]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 272}], {
             RGBColor[
             0.23289575947638014`, 0.3621185880266611, 0.936574441012555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 289}], {
             RGBColor[
             0.3576929449951681, 0.48259509766982983`, 0.944072988186208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 298}], {
             RGBColor[
             0.35482735126592213`, 0.47958317697125596`, 0.9439097968625934]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 256}], {
             RGBColor[
             0.7970579460912328, 0.838735601938289, 0.8428569136112316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 296}], {
             RGBColor[
             0.6475517482649964, 0.7239253864883827, 0.965961068287336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 299}], {
             RGBColor[
             0.7966762325062557, 0.8386071063469377, 0.851316533208819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 267}], {
             RGBColor[
             0.5234677465828359, 0.6240137244860162, 0.9556284450179895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 273}], {
             RGBColor[
             0.598461668080708, 0.6848971683956518, 0.9615322412300882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 285}], {
             RGBColor[
             0.4809297969495969, 0.5875639936298371, 0.952808962101173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 270}], {
             RGBColor[
             0.21830317142063266`, 0.3467808527565494, 0.9357434147105796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 254}], {
             RGBColor[
             0.8549509396381043, 0.371609679278205, 0.19822709100428773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 288}], {
             RGBColor[
             0.8402405410776118, 0.30481319511588134`, 0.18595237386054825`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 300}], {
             RGBColor[
             0.27128730129384493`, 0.40247053264115845`, 0.9387607825238632]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 253}], {
             RGBColor[
             0.29862833529686444`, 0.43120769290001126`, 0.9403178139629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 292}], {
             RGBColor[
             0.2717964040404102, 0.4030056319067771, 0.9387897751721301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 292}], {
             RGBColor[
             0.26989343961389634`, 0.40100549563959764`, 0.9386814041632237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 258}], {
             RGBColor[
             0.926544473085371, 0.7852032520842381, 0.5903156471830767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 260}], {
             RGBColor[
             0.870237845536556, 0.7409780985202714, 0.6082514586621423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 288}], {
             RGBColor[
             0.8766115127845734, 0.5326035223156528, 0.21875396054991414`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 287}], {
             RGBColor[
             0.9499646737467646, 0.8384490491642924, 0.28320554516144203`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 296}], {
             RGBColor[
             0.8457417773194627, 0.8774340088271846, 0.8472537592625196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 299}], {
             RGBColor[
             0.994866261560722, 0.9921157286857396, 0.7326092241840025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 259}], {
             RGBColor[
             0.4277830853443319, 0.544648816326516, 0.9485610340700278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 261}], {
             RGBColor[
             0.39597335276996437`, 0.5173939487951174, 0.9464520497863826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 260}], {
             RGBColor[
             0.9054604072768613, 0.9267813441265331, 0.9675384281515653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 278}], {
             RGBColor[
             0.7823492729369855, 0.8297662429856849, 0.9557433701572854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 290}], {
             RGBColor[
             0.7873478763723856, 0.8338243344390612, 0.9561368785302078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 260}], {
             RGBColor[
             0.656707314635238, 0.7292515443954324, 0.9682208504157948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 261}], {
             RGBColor[
             0.4324511169680622, 0.5486920306968999, 0.9488584769173136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 261}], {
             RGBColor[
             0.6248975820608704, 0.7019966768640338, 0.9661118661321497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 278}], {
             RGBColor[
             0.7260426453881705, 0.7855410894217181, 0.9736791816363508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 290}], {
             RGBColor[
             0.7310412488235707, 0.7895991808750945, 0.9740726900092733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 278}], {
             RGBColor[
             0.5017864477209948, 0.6049815757231856, 0.9543168081378697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 290}], {
             RGBColor[
             0.5067850511563949, 0.6090396671765619, 0.9547103165107921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 271}], {
             RGBColor[
             0.9857223415414609, 0.9625888518240449, 0.4765328762826566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 291}], {
             RGBColor[
             0.9059438756426232, 0.5640930053700905, 0.37544589714295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 269}], {
             RGBColor[
             0.24400443083652518`, 0.3737945059566179, 0.9372070634127088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 276}], {
             RGBColor[
             0.24638255548127658`, 0.37629406574006286`, 0.9373424940931072]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 279}], {
             RGBColor[
             0.25988809011317837`, 0.3904892389385449, 0.938111614310746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 289}], {
             RGBColor[
             0.27598341660935993`, 0.40740644758867306`, 0.9390282193438018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 298}], {
             RGBColor[
             0.27311782288011394`, 0.40439452689009914`, 0.9388650280201871]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 269}], {
             RGBColor[
             0.2247455605611441, 0.35355221221429056`, 0.9361102992414712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 273}], {
             RGBColor[
             0.5428411676276441, 0.6397419404528637, 0.9571535916898165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 285}], {
             RGBColor[
             0.42530929649653304`, 0.542408765687049, 0.9484303125609015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 286}], {
             RGBColor[
             0.5134415575632728, 0.6158740125652669, 0.954839146691229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 298}], {
             RGBColor[
             0.2561386884802381, 0.3865483800965307, 0.9378980914344927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 272}], {
             RGBColor[
             0.22576785330449248`, 0.35462670670465335`, 0.9361685173008583]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 274}], {
             RGBColor[
             0.9710201994330907, 0.9139064692863681, 0.34191937648403536`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 291}], {
             RGBColor[
             0.897686479772025, 0.537150265190796, 0.2658690194898667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 285}], {
             RGBColor[
             0.5003032179944051, 0.6032922095966846, 0.9543341087730001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 287}], {
             RGBColor[
             0.9527752319881305, 0.8479297220628771, 0.29412403319976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 293}], {
             RGBColor[
             0.21101994270665328`, 0.33912571759478527`, 0.9353286456098898]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 279}], {
             RGBColor[
             0.24528708035805388`, 0.3751426519284214, 0.9372801084054498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 290}], {
             RGBColor[
             0.607930114483695, 0.6925840797342462, 0.9622776320149933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 283}], {
             RGBColor[
             0.7911900845661439, 0.8368811978581185, 0.9547653144934332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 295}], {
             RGBColor[
             0.9004709095023198, 0.9227541160141217, 0.9653727475363004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 297}], {
             RGBColor[
             0.8620280342318183, 0.892582413918251, 0.9615782291090177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 295}], {
             RGBColor[
             0.728003954304401, 0.7872192535932907, 0.973734730725687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 297}], {
             RGBColor[
             0.6895610790338994, 0.7570475514974199, 0.9699402122984042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 291}], {
             RGBColor[
             0.839904564048634, 0.3022307284450855, 0.18563064187816736`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 298}], {
             RGBColor[
             0.28811767425307283`, 0.4201603217285858, 0.9397192473655857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 297}], {
             RGBColor[
             0.7988419039700752, 0.8429204696534232, 0.9805476453412715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 299}], {
             RGBColor[
             0.8453600637344856, 0.8773055132358333, 0.8557133788601069]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.10302533798448267`], {
             RGBColor[
             0.41852266255485593`, 0.5369250275695268, 0.9478888718663042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.10302533798448267`], {
             RGBColor[
             0.2307572995292167, 0.3598709310360006, 0.936452658882132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.10302533798448267`], {
             RGBColor[
             0.3773249031069595, 0.5012415989953558, 0.9452637870640326]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.10302533798448267`], {
             RGBColor[
             0.5396207399250182, 0.6371274521652572, 0.9569000678242504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.10302533798448267`], {
             RGBColor[
             0.220958970004222, 0.34957226545525755`, 0.9358946585110132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.10302533798448267`], {
             RGBColor[
             0.3056730571205615, 0.43861214219787836`, 0.9407190004490276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.10302533798448267`], {
             RGBColor[
             0.394746751143397, 0.516331528116975, 0.946373891815379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.10302533798448267`], {
             RGBColor[
             0.6518492866916434, 0.7279488840923621, 0.9659339030856515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.10302533798448267`], {
             RGBColor[
             0.5168296547678491, 0.6186246225079816, 0.9551058701141822]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.10302533798448267`], {
             RGBColor[
             0.2114327980870659, 0.3395596547761419, 0.9353521571130395]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.10302533798448267`], {
             RGBColor[
             0.34350580070653963`, 0.47194919229362253`, 0.9431088637641358]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.10302533798448267`], {
             RGBColor[
             0.20154157699751735`, 0.32916335427138743`, 0.93478886670474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.10302533798448267`], {
             RGBColor[
             0.30612838775897044`, 0.4390907235684761, 0.9407449308552837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.10302533798448267`], {
             RGBColor[
             0.8226976998778256, 0.17547004422228246`, 0.1693686490773784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.10302533798448267`], {
             RGBColor[
             0.23892277989457777`, 0.36845336862135236`, 0.9369176709091936]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.10302533798448267`], {
             RGBColor[
             0.9934703621130101, 0.9884420897444159, 0.5306673961342021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.10302533798448267`], {
             RGBColor[
             0.29622239326445615`, 0.42867889527841463`, 0.9401807991234267]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.10302533798448267`], {
             RGBColor[
             0.9464007204285422, 0.9595463255731478, 0.9756137787701872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.10302533798448267`], {
             RGBColor[
             0.2912671539208582, 0.4234706245479727, 0.9398986055734284]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.10302533798448267`], {
             RGBColor[
             0.865905855945801, 0.8959138414156087, 0.9870720676150353]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.10302533798448267`], {
             RGBColor[
             0.38345468665213356`, 0.5065509094103063, 0.9456543714511763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.10302533798448267`], {
             RGBColor[
             0.8173789776787558, 0.8572619367637411, 0.982432355720336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.10302533798448267`], {
             RGBColor[
             0.2963741173821658, 0.42883836694599214`, 0.9401894395874745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.10302533798448267`], {
             RGBColor[
             0.9556367854010767, 0.9664345677069957, 0.9599795299232305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.10302533798448267`], {
             RGBColor[
             0.2518103509231395, 0.3819990228915686, 0.9376515990138174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.10302533798448267`], {
             RGBColor[
             0.9858349896506369, 0.9884104184434465, 0.8844144095680297]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.10302533798448267`], {
             RGBColor[
             0.2584384877012701, 0.38896561489352793`, 0.9380290615978824]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.10302533798448267`], {
             RGBColor[
             0.22341264573171882`, 0.35215123421688327`, 0.9360343917138061]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.10302533798448267`], {
             RGBColor[
             0.24282295558358705`, 0.3725527005559224, 0.9371397801448899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.10302533798448267`], {
             RGBColor[
             0.46219840465570133`, 0.574272512557169, 0.9508050979844909]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.10302533798448267`], {
             RGBColor[
             0.6188367246795077, 0.7014385572283971, 0.9631362403218372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.10302533798448267`], {
             RGBColor[
             0.2562574704790552, 0.38667322750850125`, 0.9379048558936031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.10302533798448267`], {
             RGBColor[
             0.9146626577353835, 0.9347911916944939, 0.9917225348954364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.10302533798448267`], {
             RGBColor[
             0.3274991935787168, 0.458085073714969, 0.9420889369120379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.10302533798448267`], {
             RGBColor[
             0.2262311772849768, 0.3551136895845794, 0.9361949029161204]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.10302533798448267`], {
             RGBColor[
             0.7595712694087771, 0.8121021157083784, 0.9766706236037325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.10302533798448267`], {
             RGBColor[
             0.6807027709206555, 0.7504894452666685, 0.968809748742459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.10302533798448267`], {
             RGBColor[
             0.4179442959916355, 0.5364240755220139, 0.9478520188603253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.10302533798448267`], {
             RGBColor[
             0.8675327116732591, 0.4913788068770457, 0.21117838636085415`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.10302533798448267`], {
             RGBColor[
             0.2372124705557414, 0.3666557250663601, 0.9368202713225229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.10302533798448267`], {
             RGBColor[
             0.35699077137457635`, 0.483629196111943, 0.9439681141708117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.10302533798448267`], {
             RGBColor[
             0.2544378422070241, 0.3847606828235006, 0.9378012307554097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.10302533798448267`], {
             RGBColor[
             0.322173741643116, 0.45347243491334854`, 0.9417496038238137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.10302533798448267`], {
             RGBColor[
             0.9650552642631052, 0.8937853423246256, 0.3187467297321304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.10302533798448267`], {
             RGBColor[
             0.8578237913971699, 0.4454645759914146, 0.2030054339855487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.10302533798448267`], {
             RGBColor[
             0.29213812634371106`, 0.4243860717872321, 0.9399482061644217]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.10302533798448267`], {
             RGBColor[
             0.6440597930627512, 0.7218636724671273, 0.9651575191576801]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.10302533798448267`], {
             RGBColor[
             0.4136829046946342, 0.5327330725643056, 0.9475804867750808]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.10302533798448267`], {
             RGBColor[
             0.23655451757503262`, 0.36596417476700677`, 0.9367828018736257]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.10302533798448267`], {
             RGBColor[
             0.35244904856935166`, 0.4796953840916829, 0.9436787196097506]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.10302533798448267`], {
             RGBColor[
             0.993562122803693, 0.9916057865804992, 0.7563558160423134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.10302533798448267`], {
             RGBColor[
             0.8177080186927622, 0.13711716814164848`, 0.16459052473952288`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.10302533798448267`], {
             RGBColor[
             0.8317291195209172, 0.2448894931924079, 0.17801714672713256`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.10302533798448267`], {
             RGBColor[
             0.4174064139952154, 0.53595818917145, 0.9478177454951437]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.10302533798448267`], {
             RGBColor[
             0.2766948027559306, 0.4081541595332056, 0.9390687317324474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.10302533798448267`], {
             RGBColor[
             0.5476923991281734, 0.6436803887304818, 0.9575354984041846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.10302533798448267`], {
             RGBColor[
             0.24705297562595502`, 0.37699871981921224`, 0.9373806735285489]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.10302533798448267`], {
             RGBColor[
             0.5489231824340144, 0.6446795940643196, 0.9576323901745283]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.10302533798448267`], {
             RGBColor[
             0.8328101555207211, 0.25319880959989605`, 0.17905234802140027`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.10302533798448267`], {
             RGBColor[
             0.9260824493199337, 0.7446485736567867, 0.2593824075361489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.10302533798448267`], {
             RGBColor[
             0.5668393910348319, 0.659224779322463, 0.9590428197448192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.10302533798448267`], {
             RGBColor[
             0.9948487335515908, 0.9913902868768101, 0.6806946209012268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.10302533798448267`], {
             RGBColor[
             0.32451328924336914`, 0.4554988334556064, 0.9418986777281211]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.10302533798448267`], {
             RGBColor[
             0.23365539790008147`, 0.3629170161738291, 0.9366177012970005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.10302533798448267`], {
             RGBColor[
             0.28791659856684826`, 0.41994897843342893`, 0.9397077964027201]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.10302533798448267`], {
             RGBColor[
             0.9464558742569554, 0.9595874592080723, 0.9755204177251058]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.10302533798448267`], {
             RGBColor[
             0.9123183312358003, 0.932921889378774, 0.9914989309411012]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.10302533798448267`], {
             RGBColor[
             0.8743662175245639, 0.5224081609419808, 0.2168804311477391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.10302533798448267`], {
             RGBColor[
             0.9930380091079225, 0.9875173303841278, 0.48360843970387296`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.10302533798448267`], {
             RGBColor[
             0.26423372362278924`, 0.39505677528622424`, 0.9383590917103296]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.10302533798448267`], {
             RGBColor[
             0.6295965520330332, 0.7101738697986875, 0.963983293345653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.10302533798448267`], {
             RGBColor[
             0.6518075404484566, 0.7279162716099014, 0.9659297422102715]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.10302533798448267`], {
             RGBColor[
             0.3290101239879992, 0.459393765693919, 0.9421852120616541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.10302533798448267`], {
             RGBColor[
             0.6382140736915616, 0.7171699620960075, 0.9646616962176343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.10302533798448267`], {
             RGBColor[
             0.7305123993392341, 0.7894011055544591, 0.9737743070057807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.10302533798448267`], {
             RGBColor[
             0.29429562032882867`, 0.4266537347586102, 0.9400710722551477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.10302533798448267`], {
             RGBColor[
             0.2460324096232273, 0.37592604024272347`, 0.9373225538044856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.10302533798448267`], {
             RGBColor[
             0.1800403201715783, 0.3065641700889047, 0.9335644019367618]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.10302533798448267`], {
             RGBColor[
             0.39493077240962093`, 0.5164909180886005, 0.9463856174877392]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.10302533798448267`], {
             RGBColor[
             0.26782978190622225`, 0.39883646054537636`, 0.9385638819096797]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.10302533798448267`], {
             RGBColor[
             0.29584127485450173`, 0.42827831566524976`, 0.9401590949937939]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.10302533798448267`], {
             RGBColor[
             0.9950766756732579, 0.9918778320265724, 0.7055047141489801]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.10302533798448267`], {
             RGBColor[
             0.21628848662157388`, 0.34466329129434453`, 0.9356286813917323]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.10302533798448267`], {
             RGBColor[
             0.30061798398773654`, 0.43329893982513096`, 0.9404311215124237]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.10302533798448267`], {
             RGBColor[
             0.9196256639800194, 0.938748558156751, 0.9921959108615778]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.10302533798448267`], {
             RGBColor[
             0.9748675947682047, 0.926884637163092, 0.35686578084130904`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.10302533798448267`], {
             RGBColor[
             0.27610729667649436`, 0.4075366533936812, 0.9390352741303609]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.10302533798448267`], {
             RGBColor[
             0.5042211596463271, 0.6083884781620977, 0.9541132831917766]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.10302533798448267`], {
             RGBColor[
             0.27813245697413447`, 0.40966522526908, 0.9391506040133554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.10302533798448267`], {
             RGBColor[
             0.4035464690461924, 0.5239534014776945, 0.9469346020588602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.10302533798448267`], {
             RGBColor[
             0.2726124428491967, 0.4038633404346605, 0.9388362473750692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.10302533798448267`], {
             RGBColor[
             0.261097249315751, 0.3917601419255701, 0.9381804741385418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.10302533798448267`], {
             RGBColor[
             0.5312094509757161, 0.6302987888719648, 0.9562379003465947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.10302533798448267`], {
             RGBColor[
             0.8619491220774967, 0.8927588492317026, 0.9866946708064583]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.10302533798448267`], {
             RGBColor[
             0.48864650773140994`, 0.5957442741074949, 0.9528871895412045]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.10302533798448267`], {
             RGBColor[
             0.40546591079173033`, 0.5256159254437323, 0.9470569071895901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.10302533798448267`], {
             RGBColor[
             0.2574804300414378, 0.3879586355486801, 0.9379745016314742]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.10302533798448267`], {
             RGBColor[
             0.4228071955400177, 0.5406360746943846, 0.948161878519455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.10302533798448267`], {
             RGBColor[
             0.3674883934084197, 0.4927217086918333, 0.9446370133641255]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.10302533798448267`], {
             RGBColor[
             0.8501803311271197, 0.38671359097016134`, 0.19568604779889498`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.10302533798448267`], {
             RGBColor[
             0.5465902564750337, 0.6427856196737024, 0.9574487336972479]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.10302533798448267`], {
             RGBColor[
             0.38532279281260967`, 0.5081689690727651, 0.9457734055238204]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.10302533798448267`], {
             RGBColor[
             0.2788168781365947, 0.4103845953056338, 0.9391895807860471]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.10302533798448267`], {
             RGBColor[
             0.28507184392659923`, 0.4169589609386654, 0.9395457918343952]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.10302533798448267`], {
             RGBColor[
             0.28917033221241484`, 0.4212667319862237, 0.9397791946791023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.10302533798448267`], {
             RGBColor[
             0.6566687686170058, 0.7317139000018745, 0.9664142640033524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.10302533798448267`], {
             RGBColor[
             0.8341470216086144, 0.26347454816989946`, 0.18033253249694123`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.10302533798448267`], {
             RGBColor[
             0.3439204196877902, 0.4723083144158259, 0.943135282918988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.10302533798448267`], {
             RGBColor[
             0.9211686584075277, 0.939978900029778, 0.992343083047521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.10302533798448267`], {
             RGBColor[
             0.9929459767177286, 0.9913509943397207, 0.7665669512217009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.10302533798448267`], {
             RGBColor[
             0.24301438028138522`, 0.37275390005033504`, 0.937150681498242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.10302533798448267`], {
             RGBColor[
             0.2522134290242518, 0.3824226835324653, 0.9376745537153752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.10302533798448267`], {
             RGBColor[
             0.9594092884334661, 0.9692480942916449, 0.9535936663157671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.10302533798448267`], {
             RGBColor[
             0.3044111891973746, 0.4372858390035616, 0.9406471389375684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.10302533798448267`], {
             RGBColor[
             0.2215913444714862, 0.35023693111520926`, 0.9359306713014096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.10302533798448267`], {
             RGBColor[
             0.3224078413052081, 0.4536752002744616, 0.941764520447276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.10302533798448267`], {
             RGBColor[
             0.20347429876271564`, 0.33119476738824843`, 0.9348989323500625]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.10302533798448267`], {
             RGBColor[
             0.17892956896395254`, 0.30539670014399584`, 0.9335011462986966]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.10302533798448267`], {
             RGBColor[
             0.28222472928714576`, 0.41396646293510553`, 0.9393836528676069]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.10302533798448267`], {
             RGBColor[
             0.18991457468017128`, 0.31694263764133146`, 0.9341267261233757]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.10302533798448267`], {
             RGBColor[
             0.9946101233350695, 0.9908799237508646, 0.6547233713644478]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.10302533798448267`], {
             RGBColor[
             0.6241927467762723, 0.7057868172525964, 0.96355788600105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.10302533798448267`], {
             RGBColor[
             0.43622064479054923`, 0.5522541302556329, 0.9490165716446514]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.10302533798448267`], {
             RGBColor[
             0.9476938047146304, 0.9605107057164812, 0.973424924364235]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.10302533798448267`], {
             RGBColor[
             0.9926251659969516, 0.9866343007146026, 0.4386730148470409]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.10302533798448267`], {
             RGBColor[
             0.22593857337368983`, 0.3548061443216573, 0.9361782395562414]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.10302533798448267`], {
             RGBColor[
             0.8327720947194103, 0.2529062576026711, 0.17901590095508144`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.10302533798448267`], {
             RGBColor[
             0.23926061251081787`, 0.3688084521208458, 0.93693690997691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.10302533798448267`], {
             RGBColor[
             0.23590943272644063`, 0.36528614969039486`, 0.9367460652458159]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.10302533798448267`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.10302533798448267`], {
             RGBColor[
             0.324831212684851, 0.4557742027613212, 0.9419189355286837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.10302533798448267`], {
             RGBColor[
             0.2067120462521808, 0.3345978452847238, 0.9350833172797693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.10302533798448267`], {
             RGBColor[
             0.35014705105926486`, 0.47770150955020474`, 0.9435320383639844]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.10302533798448267`], {
             RGBColor[
             0.27400077350385804`, 0.40532256397795713`, 0.9389153107520011]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.10302533798448267`], {
             RGBColor[
             0.9900957369634822, 0.9901723469535194, 0.8138028001335977]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.10302533798448267`], {
             RGBColor[
             0.9929076697798414, 0.9872385477406899, 0.46942180820333496`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.10302533798448267`], {
             RGBColor[
             0.8455662065044656, 0.351247407198139, 0.19126755684933291`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.10302533798448267`], {
             RGBColor[
             0.7066839033025902, 0.7707861033473555, 0.971399305210804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.10302533798448267`], {
             RGBColor[
             0.25547870703592473`, 0.385854697753317, 0.9378605064675941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.10302533798448267`], {
             RGBColor[
             0.3280740134091542, 0.4585829537608091, 0.9421255639233401]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.10302533798448267`], {
             RGBColor[
             0.8990024464838272, 0.6342755227085348, 0.23743750448057996`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.10302533798448267`], {
             RGBColor[
             0.6590237495828186, 0.7335536290308857, 0.9666489864974762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.10302533798448267`], {
             RGBColor[
             0.39675004724917656`, 0.5180666825152114, 0.9465015400717941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.10302533798448267`], {
             RGBColor[
             0.3157094904678022, 0.4478734254480028, 0.9413377074550355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.10302533798448267`], {
             RGBColor[
             0.26920385108875294`, 0.4002806943772341, 0.9386421331168716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.10302533798448267`], {
             RGBColor[
             0.23045057360750168`, 0.3595485426447314, 0.9364351912946507]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.10302533798448267`], {
             RGBColor[
             0.22619261942112945`, 0.35507316282496604`, 0.9361927071028155]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.10302533798448267`], {
             RGBColor[
             0.23881348570074337`, 0.36833849349398035`, 0.9369114467665411]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.10302533798448267`], {
             RGBColor[
             0.2939489691399074, 0.4262893823800991, 0.9400513309827632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.10302533798448267`], {
             RGBColor[
             0.9620063021321176, 0.9711849428558795, 0.9491975995336027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.10302533798448267`], {
             RGBColor[
             0.443273542823118, 0.5583629960424816, 0.9494659760706539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.10302533798448267`], {
             RGBColor[
             0.25329610735962166`, 0.38356064710871024`, 0.9377362106448954]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.10302533798448267`], {
             RGBColor[
             0.27348165172589245`, 0.40477693407509363`, 0.9388857475347178]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.10302533798448267`], {
             RGBColor[
             0.7412000832467709, 0.797750405452433, 0.9748395554555993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.10302533798448267`], {
             RGBColor[
             0.21230278460535462`, 0.3404740657671945, 0.9354017015582263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.10302533798448267`], {
             RGBColor[
             0.2276990046313701, 0.35665646919126776`, 0.9362784935120415]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.10302533798448267`], {
             RGBColor[
             0.34598043724619154`, 0.47409259808542004`, 0.9432665454162072]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.10302533798448267`], {
             RGBColor[
             0.40363205630183896`, 0.524027532856795, 0.9469400556031081]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.10302533798448267`], {
             RGBColor[
             0.2473937360801429, 0.37735688066202433`, 0.937400079332305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.10302533798448267`], {
             RGBColor[
             0.5902199940802382, 0.6782062061588879, 0.9608834264625246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.10302533798448267`], {
             RGBColor[
             0.21627103797903324`, 0.3446449516647265, 0.9356276877173526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.10302533798448267`], {
             RGBColor[
             0.2845267439871254, 0.4163860263409461, 0.9395147491992453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.10302533798448267`], {
             RGBColor[
             0.2413593551772921, 0.3710143637312809, 0.9370564302669542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.10302533798448267`], {
             RGBColor[
             0.38392426951059677`, 0.5069576384803866, 0.9456842928556817]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.10302533798448267`], {
             RGBColor[
             0.9802603651545728, 0.9450757179590131, 0.3778156754531135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.10302533798448267`], {
             RGBColor[
             0.9927232541779302, 0.9868441014154793, 0.4493493080164732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.10302533798448267`], {
             RGBColor[
             0.7539264605068086, 0.8076923480920241, 0.9761080018061227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.10302533798448267`], {
             RGBColor[
             0.3858730274799788, 0.5086455546860418, 0.9458084659902717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.10302533798448267`], {
             RGBColor[
             0.2930250557635406, 0.42531829084204614`, 0.9399987154827865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.10302533798448267`], {
             RGBColor[
             0.8218934398484693, 0.16928814920765783`, 0.168598488764985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.10302533798448267`], {
             RGBColor[
             0.4183533072547869, 0.5367783405206518, 0.9478780806963388]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.10302533798448267`], {
             RGBColor[
             0.26949540103514497`, 0.4005871318562264, 0.9386587364550091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.10302533798448267`], {
             RGBColor[
             0.25717362368840185`, 0.38763616261899303`, 0.9379570294635482]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.10302533798448267`], {
             RGBColor[
             0.3923234880848031, 0.5142326194523638, 0.9462194836360928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.10302533798448267`], {
             RGBColor[
             0.2945111830148827, 0.42688030480911665`, 0.9400833482312222]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.10302533798448267`], {
             RGBColor[
             0.1789518783186532, 0.305420148690281, 0.9335024167834431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.10302533798448267`], {
             RGBColor[
             0.41920763486506846`, 0.5375183161569235, 0.9479325176962138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.10302533798448267`], {
             RGBColor[
             0.27705635157752495`, 0.4085341702682206, 0.9390893214029737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.10302533798448267`], {
             RGBColor[
             0.9936465744084931, 0.9916407094893913, 0.7549562343970292]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.10302533798448267`], {
             RGBColor[
             0.23402613491596813`, 0.3633066842836104, 0.936638814221599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.10302533798448267`], {
             RGBColor[
             0.7138170777657293, 0.7763585934520937, 0.9721102733779844]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.10302533798448267`], {
             RGBColor[
             0.3071831062866214, 0.4401992996140543, 0.9408049955151171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.10302533798448267`], {
             RGBColor[
             0.25458949129815345`, 0.38492007563338526`, 0.9378098669468048]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.10302533798448267`], {
             RGBColor[
             0.23743710807503443`, 0.3668918333419784, 0.9368330640969252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.10302533798448267`], {
             RGBColor[
             0.5680702998089695, 0.6602240865171163, 0.9591397213924867]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.10302533798448267`], {
             RGBColor[
             0.2299691131158081, 0.3590424971416032, 0.9364077728319058]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.10302533798448267`], {
             RGBColor[
             0.3639294956023307, 0.48963917028760373`, 0.9444102435429313]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.10302533798448267`], {
             RGBColor[
             0.20571498311483435`, 0.33354986870991854`, 0.9350265360091202]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.10302533798448267`], {
             RGBColor[
             0.2318484494359024, 0.3610177987708272, 0.9365147982551062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.10302533798448267`], {
             RGBColor[
             0.22813210557574862`, 0.35711168574399543`, 0.9363031579701084]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.10302533798448267`], {
             RGBColor[
             0.24388899418338073`, 0.37367317471505657`, 0.9372004894660854]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.10302533798448267`], {
             RGBColor[
             0.8649861375675162, 0.47981540863036076`, 0.20905346250477896`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.10302533798448267`], {
             RGBColor[
             0.39949775357450523`, 0.5204466076304757, 0.9466766214891428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.10302533798448267`], {
             RGBColor[
             0.5158331891976378, 0.6178156468678216, 0.9550274246943216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.10302533798448267`], {
             RGBColor[
             0.8191437574953648, 0.1481528857232069, 0.16596538983833015`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.10302533798448267`], {
             RGBColor[
             0.2809324202458739, 0.4126081641956031, 0.9393100577795065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.10302533798448267`], {
             RGBColor[
             0.2105002400012672, 0.3385794771003698, 0.9352990493096494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.10302533798448267`], {
             RGBColor[
             0.4642553566460736, 0.5759424388475844, 0.9509670287800365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.10302533798448267`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.10302533798448267`], {
             RGBColor[
             0.8859959599380017, 0.5752161050460523, 0.226584573288584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.10302533798448267`], {
             RGBColor[
             0.32111303850258816`, 0.4525537071655133, 0.9416820167576422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.10302533798448267`], {
             RGBColor[
             0.22812105044609293`, 0.3571000661017916, 0.9363025283968291]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.10302533798448267`], {
             RGBColor[
             0.2595939437592997, 0.3901800724706624, 0.9380948631110431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.10302533798448267`], {
             RGBColor[
             0.23088271225706164`, 0.36000274776459185`, 0.9364598009514513]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.10302533798448267`], {
             RGBColor[
             0.5294468131435418, 0.6288678000738763, 0.9560991390396908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.10302533798448267`], {
             RGBColor[
             0.23667377020378227`, 0.366089516840876, 0.9367895931344146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.10302533798448267`], {
             RGBColor[
             0.7455882739599426, 0.8011784933890475, 0.9752769292959146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.10302533798448267`], {
             RGBColor[
             0.28595975701387044`, 0.41789221389032877`, 0.9395963571711656]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.10302533798448267`], {
             RGBColor[
             0.2651563206276758, 0.3960264832343887, 0.938411632244898]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.10302533798448267`], {
             RGBColor[
             0.37855708825470646`, 0.5023088558389079, 0.9453423008120684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.10302533798448267`], {
             RGBColor[
             0.24235927283690456`, 0.3720653405899749, 0.9371133740984234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.10302533798448267`], {
             RGBColor[
             0.21172080019279638`, 0.3398623632496528, 0.9353685584068999]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.10302533798448267`], {
             RGBColor[
             0.42787872382047937`, 0.5450287775884974, 0.9484850318169096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.10302533798448267`], {
             RGBColor[
             0.21288213693655111`, 0.34108300180034146`, 0.9354346948164131]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.10302533798448267`], {
             RGBColor[
             0.9951032288756773, 0.9922430735458843, 0.7308157001748675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.10302533798448267`], {
             RGBColor[
             0.2588379470720171, 0.38938547201937, 0.9380518102180992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.10302533798448267`], {
             RGBColor[
             0.80703569950506, 0.8491816892426243, 0.9814014344154122]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.10302533798448267`], {
             RGBColor[
             0.2560427236071457, 0.38644751493038626`, 0.9378926263769374]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.10302533798448267`], {
             RGBColor[
             0.27423499655804673`, 0.4055687472585089, 0.9389286494084351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.10302533798448267`], {
             RGBColor[
             0.25719173910326026`, 0.38765520306859286`, 0.937958061109625]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.10302533798448267`], {
             RGBColor[
             0.29461336050310216`, 0.4269876998276622, 0.9400891670880182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.10302533798448267`], {
             RGBColor[
             0.43613267935432526`, 0.5521779390160471, 0.94901096656484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.10302533798448267`], {
             RGBColor[
             0.8873547734207121, 0.5813861597120881, 0.22771840056612383`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.10302533798448267`], {
             RGBColor[
             0.9695247134417432, 0.9088618438807439, 0.33610969580648287`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.10302533798448267`], {
             RGBColor[
             0.9609628542707439, 0.8799806824768295, 0.3028484896985869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.10302533798448267`], {
             RGBColor[
             0.178927010221482, 0.30539401074342565`, 0.9335010005820983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.10302533798448267`], {
             RGBColor[
             0.25976518882652405`, 0.3903600618938796, 0.9381046152642871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.10302533798448267`], {
             RGBColor[
             0.8163432429187892, 0.8564528128973794, 0.9823291233589543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.10302533798448267`], {
             RGBColor[
             0.34638875058307517`, 0.4744462585754037, 0.9432925627809762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.10302533798448267`], {
             RGBColor[
             0.24935218422087857`, 0.37941533383072157`, 0.9375116100566555]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.10302533798448267`], {
             RGBColor[
             0.44511934956958094`, 0.5599617410733233, 0.9495835892443556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.10302533798448267`], {
             RGBColor[
             0.9940965401504851, 0.9897814212502639, 0.5988230111904562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.10302533798448267`], {
             RGBColor[
             0.9940884990666902, 0.9897642221851048, 0.5979477888431959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.10302533798448267`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.10302533798448267`], {
             RGBColor[
             0.24203916924704705`, 0.37172889142129484`, 0.937095144672532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.10302533798448267`], {
             RGBColor[
             0.6232106502631707, 0.7049895070603167, 0.9634805717660004]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.10302533798448267`], {
             RGBColor[
             0.638779311088947, 0.7176288472788594, 0.9647061937760893]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.10302533798448267`], {
             RGBColor[
             0.2785145923880161, 0.4100668738178543, 0.9391723660598572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.10302533798448267`], {
             RGBColor[
             0.4111342730563943, 0.530525575937213, 0.9474180902207585]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.10302533798448267`], {
             RGBColor[
             0.9949335587465892, 0.9915717193917691, 0.6899273198963884]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.10302533798448267`], {
             RGBColor[
             0.2790754121939759, 0.4106563309919474, 0.9392043039181481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.10302533798448267`], {
             RGBColor[
             0.24043240470913427`, 0.3700400800171928, 0.9370036418090929]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.10302533798448267`], {
             RGBColor[
             0.21816661637866602`, 0.3466373247493527, 0.9357356381029547]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.10302533798448267`], {
             RGBColor[
             0.24251120685435607`, 0.3722250328754895, 0.9371220265159511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.10302533798448267`], {
             RGBColor[
             0.4244026220080174, 0.5420179529125, 0.9482635376832157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.10302533798448267`], {
             RGBColor[
             0.5988679170367666, 0.6852269795994871, 0.961564222636048]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.10302533798448267`], {
             RGBColor[
             0.5790882470358998, 0.6691689524288044, 0.9600070945582612]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.10302533798448267`], {
             RGBColor[
             0.20835094833068457`, 0.3363204352816248, 0.9351766503286018]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.10302533798448267`], {
             RGBColor[
             0.8185799679311427, 0.1438193520784336, 0.16542550431492184`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.10302533798448267`], {
             RGBColor[
             0.22258326386374316`, 0.3512795012877932, 0.9359871596433854]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.10302533798448267`], {
             RGBColor[
             0.2867137638335649, 0.4186847228646212, 0.9396392967440941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.10302533798448267`], {
             RGBColor[
             0.30053129972337833`, 0.4332078291671907, 0.9404261849718064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.10302533798448267`], {
             RGBColor[
             0.29672537087035056`, 0.42920755663283183`, 0.9402094429539937]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.10302533798448267`], {
             RGBColor[
             0.8913219113450659, 0.5994000064779764, 0.23102867769365362`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.10302533798448267`], {
             RGBColor[
             0.9589543367125869, 0.8732054811308165, 0.29504577826186157`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.10302533798448267`], {
             RGBColor[
             0.9952479751456992, 0.992244224277091, 0.7241496045864151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.10302533798448267`], {
             RGBColor[
             0.39130532114623406`, 0.5133507344247334, 0.9461546069390968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.10302533798448267`], {
             RGBColor[
             0.9617670348256762, 0.9710064976904998, 0.9496026166724999]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.10302533798448267`], {
             RGBColor[
             0.46426084954242974`, 0.5759468982282985, 0.9509674612009588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.10302533798448267`], {
             RGBColor[
             0.8491537797280463, 0.8825561905625664, 0.9854742396306309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.10302533798448267`], {
             RGBColor[
             0.4006413843936947, 0.5214371631655013, 0.9467494926336685]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.10302533798448267`], {
             RGBColor[
             0.9939797374120591, 0.9895315920033393, 0.5861097539357399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.10302533798448267`], {
             RGBColor[
             0.26098356523640104`, 0.3916406527501864, 0.9381739999984032]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.10302533798448267`], {
             RGBColor[
             0.2946613034028385, 0.4270380908550406, 0.940091897365233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.10302533798448267`], {
             RGBColor[
             0.22246582468563886`, 0.3511560652655316, 0.9359804716559281]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.10302533798448267`], {
             RGBColor[
             0.24763395401992835`, 0.3776093649474359, 0.9374137593886052]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.10302533798448267`], {
             RGBColor[
             0.467847246129772, 0.578858496543228, 0.9512497954777179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.10302533798448267`], {
             RGBColor[
             0.2625163578880115, 0.3932517150116962, 0.938261290272349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.10302533798448267`], {
             RGBColor[
             0.2270252964366493, 0.35594835916304945`, 0.9362401268270142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.10302533798448267`], {
             RGBColor[
             0.22825539451058077`, 0.357241270231474, 0.9363101790925575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.10302533798448267`], {
             RGBColor[
             0.9774649456708626, 0.9356461116447503, 0.3669559986295733]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.10302533798448267`], {
             RGBColor[
             0.22328031209840418`, 0.35201214317783264`, 0.936026855509159]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.10302533798448267`], {
             RGBColor[
             0.6178350891255162, 0.7006253843624993, 0.9630573879019151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.10302533798448267`], {
             RGBColor[
             0.9645754531953188, 0.8921668269279859, 0.3168827543384975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.10302533798448267`], {
             RGBColor[
             0.21277857456934213`, 0.34097415118617147`, 0.9354287970928072]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.10302533798448267`], {
             RGBColor[
             0.23178154572615212`, 0.3609474787299394, 0.9365109881878111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.10302533798448267`], {
             RGBColor[
             0.34909505354151776`, 0.4767903221752649, 0.9434650060123984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.10302533798448267`], {
             RGBColor[
             0.6029315110482949, 0.6885259882808699, 0.9618841236420709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.10302533798448267`], {
             RGBColor[
             0.25879261498995565`, 0.3893378251269034, 0.9380492286230886]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.10302533798448267`], {
             RGBColor[
             0.2680583595238526, 0.3990767101141639, 0.9385768990668534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.10302533798448267`], {
             RGBColor[
             0.8360763947567734, 0.2783045556433535, 0.18218010240253352`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.10302533798448267`], {
             RGBColor[
             0.9636570397640628, 0.9724160602789496, 0.9464033313040466]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.10302533798448267`], {
             RGBColor[
             0.6187231293682252, 0.7013463354372874, 0.9631272976828197]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.10302533798448267`], {
             RGBColor[
             0.25564421936180226`, 0.3860286617019018, 0.9378699321496993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.10302533798448267`], {
             RGBColor[
             0.382771346863294, 0.50595903483087, 0.945610829644085]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.10302533798448267`], {
             RGBColor[
             0.5590358689967736, 0.6528895285873056, 0.9584284979047402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.10302533798448267`], {
             RGBColor[
             0.9409750107809423, 0.8036926171977683, 0.27136531206102255`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.10302533798448267`], {
             RGBColor[
             0.8619011142240809, 0.46580703815332913`, 0.20647924340617463`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.10302533798448267`], {
             RGBColor[
             0.2909832679823188, 0.4231722424271597, 0.9398824386892002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.10302533798448267`], {
             RGBColor[
             0.6129287179190951, 0.6966421711876226, 0.9626711403879157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.10302533798448267`], {
             RGBColor[
             0.8179080138731872, 0.1386544187368418, 0.16478204035016009`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.10302533798448267`], {
             RGBColor[
             0.24306150835744214`, 0.3728034346463635, 0.9371533653724538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.10302533798448267`], {
             RGBColor[
             0.20926131084396443`, 0.33727728400339907`, 0.9352284941269724]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.10302533798448267`], {
             RGBColor[
             0.209897553009386, 0.33794601485934034`, 0.9352647271770572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.10302533798448267`], {
             RGBColor[
             0.8372847792405768, 0.8730921717492939, 0.9843421637685542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.10302533798448267`], {
             RGBColor[
             0.6962355794932261, 0.7626237933772783, 0.9703579139386239]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.10302533798448267`], {
             RGBColor[
             0.7603990286995737, 0.8127487675575523, 0.9767531269139887]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.10302533798448267`], {
             RGBColor[
             0.28525208052382683`, 0.41714840103001194`, 0.9395560560419711]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.10302533798448267`], {
             RGBColor[
             0.9944845479757449, 0.9919872330943883, 0.7410688437815899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.10302533798448267`], {
             RGBColor[
             0.2558608387541249, 0.3862563424176957, 0.9378822683036323]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{
  3.834950276960332*^9, {3.8349573666066523`*^9, 3.83495737580899*^9}, 
   3.8349587938370156`*^9, 3.8350189212906833`*^9, 3.835019008666805*^9, 
   3.8350204886401753`*^9, 3.83502054312705*^9, {3.8350446267813253`*^9, 
   3.8350446323653708`*^9}, 3.835045028161322*^9, 3.835045406061925*^9, 
   3.8350520136370316`*^9, 3.8351785714105206`*^9},
 CellLabel->
  "Out[653]=",ExpressionUUID->"e116e124-afc7-4a15-9fa0-e4c1fb582862"]
}, Open  ]],

Cell["Estimated with absolute Mean Deviation v Calculated: (r=3)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 
  3.8349503756793146`*^9}},ExpressionUUID->"0e921e27-d36a-4b07-aeb5-\
e544c35320f1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphinf3", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsif3", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}],
      "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"AMDi3f300", ",", "krif3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502409842243`*^9}, {3.834957391671958*^9, 3.8349574025038147`*^9}, {
   3.8350188314314775`*^9, 3.835018832832349*^9}, {3.8350443332621727`*^9, 
   3.835044338598092*^9}, {3.835044923956807*^9, 3.8350449330660315`*^9}, {
   3.8350452796317253`*^9, 3.8350452814557223`*^9}},
 CellLabel->
  "In[299]:=",ExpressionUUID->"7ede751f-091b-453c-8db6-e622bb73c640"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1FO4EAYYBuBzsm2dTrZdW7WsZbtVy3bLtWxr2bat5WVjyzZXrfc8u3i/
//a7+f7gJu2rtAsMCAjIJEJuKEIThrCEIzwRiEgkIhOFqEQjOjGISSxiE4e4
xCM+CUhIIhKThKQkI4jkBJOClKQiNWlISzrSk4GMIX3JTBayko3s5CAnuchN
HvKSj/wUoCCF+IEfKUwRivITxShOCUpSitKUoSzlKE8FfqYilahMFapSjerU
oCa1qE0d6lKP+jSgIY1oTBN+oSnNaM6vtKAlrWhNG9rSjvZ0oCOd6EwXutKN
7vSgJ73ozW/0oS/96M8ABjKIwQzhd4YyjOGMYCSjGM0YxjKO8UxgIpOYzBSm
Mo3pzGAms5jNH8xhLvOYzwIWsojFLGEpy1jOClayitWsYS3rWM8GNrKJzWxh
K9vYzg52sovd7GEv+9jPAQ5yiMMc4U+OcozjnOAkpzjNX5zhLOc4zwUuconL
XOEq17jODW5yi9v8zT/c4S73uM8DHvKIxzzhKc94zgte8orXvOEt73jPBz7y
ic/8yxe+8o3/CBl/IKEITRjCEo7wRCAikYhMFKISjejEICaxiE0c4hKP+CQg
IYlITBKSkowgkhNMClKSitSkIS3pSE8GMgb+/6++Az6VhWw=
          "], {Null, CompressedData["
1:eJxN2nu4llWZB+C1RcxDZpqQRxAUUVHStBgOUSMyo5BNY0aKowyCpqCIyVg4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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[57, 280] -> 
             RGBColor[
              0.980491538037473, 0.9821931012842413, 0.7611584630678667], 
             UndirectedEdge[46, 187] -> 
             RGBColor[
              0.9354869644965342, 0.9490533999385002, 0.9029335074001259], 
             UndirectedEdge[96, 298] -> 
             RGBColor[
              0.8045428784487958, 0.8465781853440186, 0.9181775450488092], 
             UndirectedEdge[165, 207] -> 
             RGBColor[
              0.9406987531626159, 0.9538899761769282, 0.9329949241425648], 
             UndirectedEdge[69, 224] -> 
             RGBColor[
              0.9500465195188702, 0.9602813788034088, 0.8877598501962503], 
             UndirectedEdge[51, 110] -> 
             RGBColor[
              0.9597791733493186, 0.9373310172316861, 0.6565490428960103], 
             UndirectedEdge[122, 231] -> 
             RGBColor[
              0.6474187132451832, 0.7122275272605725, 0.8319082375120959], 
             UndirectedEdge[71, 246] -> 
             RGBColor[0.97353468, 0.9223884026666667, 0.35168765866666657`], 
             UndirectedEdge[9, 239] -> 
             RGBColor[
              0.9396669389879592, 0.9246656240877915, 0.6707080178509373], 
             UndirectedEdge[99, 229] -> 
             RGBColor[
              0.703656915286544, 0.760322786955214, 0.710554305863434], 
             UndirectedEdge[49, 112] -> 
             RGBColor[
              0.9801063789649382, 0.9493097635234238, 0.5677686547206584], 
             UndirectedEdge[115, 243] -> 
             RGBColor[
              0.9713748438467793, 0.9118514687722284, 0.44446617179923165`], 
             UndirectedEdge[58, 95] -> 
             RGBColor[
              0.7528534112435215, 0.8072009804349426, 0.975912168679804], 
             UndirectedEdge[210, 239] -> 
             RGBColor[
              0.9812828047289504, 0.9556115992003076, 0.5884677412302959], 
             UndirectedEdge[94, 150] -> 
             RGBColor[
              0.8583848656976963, 0.8871529304306858, 0.8358625027131026], 
             UndirectedEdge[21, 108] -> 
             RGBColor[
              0.8470371082304526, 0.8776569746502059, 0.7841914653497943], 
             UndirectedEdge[83, 202] -> 
             RGBColor[
              0.9146959836950418, 0.9329200115167156, 0.9202641248052694], 
             UndirectedEdge[172, 174] -> 
             RGBColor[
              0.8812864055547518, 0.9078146733772653, 0.9729875970354774], 
             UndirectedEdge[3, 157] -> 
             RGBColor[
              0.7351220959164295, 0.7930022355555557, 0.9742337584805318], 
             UndirectedEdge[181, 246] -> 
             RGBColor[
              0.9558583635827664, 0.9402921233922903, 0.675679201115646], 
             UndirectedEdge[159, 253] -> 
             RGBColor[
              0.579768135055748, 0.663414990438293, 0.9630027784083045], 
             UndirectedEdge[170, 228] -> 
             RGBColor[
              0.9714804239472865, 0.9154589146386054, 0.3437072618155792], 
             UndirectedEdge[151, 194] -> 
             RGBColor[
              0.9840457404923405, 0.9862459968810577, 0.85027393529191], 
             UndirectedEdge[62, 100] -> 
             RGBColor[
              0.9928408868890215, 0.9906376235336292, 0.7196129249812991], 
             UndirectedEdge[76, 99] -> 
             RGBColor[
              0.702641962277092, 0.7571718972290808, 0.6834157294375857], 
             UndirectedEdge[131, 283] -> 
             RGBColor[
              0.9777824136470163, 0.945723185996034, 0.5881350142166937], 
             UndirectedEdge[173, 263] -> 
             RGBColor[
              0.9196379626930236, 0.8991313343171872, 0.6547281402263465], 
             UndirectedEdge[20, 75] -> 
             RGBColor[
              0.8685215110159161, 0.897999493768453, 0.9873215511306457], 
             UndirectedEdge[175, 253] -> 
             RGBColor[
              0.914532967766859, 0.9308919624827374, 0.8221366147638598], 
             UndirectedEdge[52, 193] -> 
             RGBColor[
              0.4036551036234294, 0.5240474952883646, 0.9469415241580599], 
             UndirectedEdge[282, 283] -> 
             RGBColor[
              0.9862997335411879, 0.9886026019855625, 0.8767124005829632], 
             UndirectedEdge[173, 279] -> 
             RGBColor[
              0.8734060955176275, 0.8625823405190601, 0.6502349009616917], 
             UndirectedEdge[95, 198] -> 
             RGBColor[
              0.5299021448298902, 0.6282768905175873, 0.9564003923100459], 
             UndirectedEdge[18, 288] -> 
             RGBColor[
              0.5920256643648608, 0.6531048523354761, 0.7386440823201713], 
             UndirectedEdge[29, 91] -> 
             RGBColor[
              0.8716242143880508, 0.44457355126962433`, 0.21196426285932035`],
              UndirectedEdge[46, 169] -> 
             RGBColor[
              0.9916849742825788, 0.9892819115237311, 0.6749689593799724], 
             UndirectedEdge[34, 264] -> 
             RGBColor[
              0.9488843212982081, 0.9611560254879159, 0.9629997905280645], 
             UndirectedEdge[116, 277] -> 
             RGBColor[
              0.8712008787871606, 0.9002316725297914, 0.9869602347338953], 
             UndirectedEdge[60, 299] -> 
             RGBColor[
              0.951265076007229, 0.9254745603782418, 0.6592715982245696], 
             UndirectedEdge[205, 213] -> 
             RGBColor[
              0.9896077356222154, 0.9893349067047581, 0.7756859889841171], 
             UndirectedEdge[240, 299] -> 
             RGBColor[
              0.9725873570425081, 0.941376682662322, 0.6231785381733885], 
             UndirectedEdge[184, 214] -> 
             RGBColor[
              0.98958685588559, 0.988146986383948, 0.6903103762764584], 
             UndirectedEdge[39, 59] -> 
             RGBColor[
              0.5479194812113497, 0.44199051295351344`, 0.5776788348535766], 
             UndirectedEdge[246, 299] -> 
             RGBColor[
              0.9710178141563786, 0.9138984231879287, 0.3419101101344307], 
             UndirectedEdge[21, 114] -> 
             RGBColor[
              0.8471679554086318, 0.8787430531643711, 0.857036302571166], 
             UndirectedEdge[204, 253] -> 
             RGBColor[
              0.90791936527797, 0.9282349119938486, 0.9501901557416379], 
             UndirectedEdge[202, 214] -> 
             RGBColor[
              0.9139115181298318, 0.9325956148456558, 0.9332647493526027], 
             UndirectedEdge[26, 39] -> 
             RGBColor[
              0.7335389267523723, 0.607441702291603, 0.5902209090113254], 
             UndirectedEdge[118, 220] -> 
             RGBColor[
              0.8986609100751796, 0.5696033496548606, 0.5453849826388922], 
             UndirectedEdge[28, 126] -> 
             RGBColor[
              0.9663864033112186, 0.8924663452752375, 0.41723334504213727`], 
             UndirectedEdge[9, 237] -> 
             RGBColor[
              0.9453401123212924, 0.9438025698655692, 0.6927472249620483], 
             UndirectedEdge[174, 297] -> 
             RGBColor[
              0.9738497679526998, 0.9782834081478851, 0.8514809738785164], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.8148409063111112, 0.8551948333511112, 0.9311677479644445], 
             UndirectedEdge[63, 139] -> 
             RGBColor[
              0.7119963032716892, 0.7749361905789509, 0.9719287955925235], 
             UndirectedEdge[124, 150] -> 
             RGBColor[
              0.9761693845571855, 0.9797195199226814, 0.8279740064865242], 
             UndirectedEdge[127, 165] -> 
             RGBColor[
              0.9040917168197471, 0.9247005190686551, 0.9295033123366949], 
             UndirectedEdge[8, 22] -> 
             RGBColor[
              0.980901176345679, 0.9825011000493827, 0.7606627171851852], 
             UndirectedEdge[127, 137] -> 
             RGBColor[
              0.8460002349966697, 0.880041639594458, 0.9851734517189494], 
             UndirectedEdge[21, 213] -> 
             RGBColor[
              0.8472668154576064, 0.8781482951821243, 0.8091936794367921], 
             UndirectedEdge[41, 278] -> 
             RGBColor[
              0.8413079790306265, 0.8761510414318618, 0.9471259745661282], 
             UndirectedEdge[69, 249] -> 
             RGBColor[
              0.9803648350243261, 0.9836012385777778, 0.861003326816568], 
             UndirectedEdge[100, 136] -> 
             RGBColor[
              0.9772236585202272, 0.9391928972924941, 0.5538549959032848], 
             UndirectedEdge[88, 222] -> 
             RGBColor[
              0.9703398090714939, 0.9717876576315114, 0.6950980877820029], 
             UndirectedEdge[153, 216] -> 
             RGBColor[
              0.8853504069847133, 0.9108913624048426, 0.9684248392674668], 
             UndirectedEdge[60, 121] -> 
             RGBColor[
              0.9653365462952948, 0.9715078643014242, 0.8357944889790277], 
             UndirectedEdge[203, 206] -> 
             RGBColor[
              0.984189213831044, 0.9576938832239349, 0.4470542473370381], 
             UndirectedEdge[50, 108] -> 
             RGBColor[
              0.9924282064857327, 0.9901049131993335, 0.7001344303268375], 
             UndirectedEdge[98, 181] -> 
             RGBColor[
              0.9393627633597753, 0.9542974287148585, 0.9875272042944234], 
             UndirectedEdge[267, 285] -> 
             RGBColor[
              0.9717290982439016, 0.9186967098598173, 0.5339061082931766], 
             UndirectedEdge[156, 178] -> 
             RGBColor[
              0.9413666222386832, 0.7951764983879288, 0.5120132854979424], 
             UndirectedEdge[185, 295] -> 
             RGBColor[
              0.7409242370312825, 0.7971052379590297, 0.9754462306136495], 
             UndirectedEdge[83, 156] -> 
             RGBColor[
              0.9394718445783719, 0.7943929591318253, 0.5434146548566976], 
             UndirectedEdge[44, 150] -> 
             RGBColor[
              0.9293054954861111, 0.9429091625555556, 0.8428376664027777], 
             UndirectedEdge[223, 274] -> 
             RGBColor[
              0.9591083772588078, 0.9133951658420986, 0.6131171020084949], 
             UndirectedEdge[20, 142] -> 
             RGBColor[
              0.9362421504653802, 0.9473734242988978, 0.7570178923904567], 
             UndirectedEdge[87, 264] -> 
             RGBColor[
              0.8163752311615191, 0.8567796644521338, 0.9500205420419496], 
             UndirectedEdge[16, 192] -> 
             RGBColor[
              0.989856099398321, 0.9763361585996378, 0.5093286732678847], 
             UndirectedEdge[75, 143] -> 
             RGBColor[
              0.8801384855131802, 0.9072625538981991, 0.9884295885287903], 
             UndirectedEdge[230, 263] -> 
             RGBColor[
              0.9304496254381667, 0.9455074940259983, 0.9228938292342878], 
             UndirectedEdge[52, 82] -> 
             RGBColor[
              0.6220412485969257, 0.4810971084135469, 0.5750760389842424], 
             UndirectedEdge[34, 213] -> 
             RGBColor[
              0.9604188856447033, 0.9674028051144845, 0.8202436010759677], 
             UndirectedEdge[145, 219] -> 
             RGBColor[
              0.7357668983983119, 0.7680925057540134, 0.6604266615770796], 
             UndirectedEdge[237, 295] -> 
             RGBColor[
              0.9526170072656878, 0.9496049683681788, 0.6934413016980056], 
             UndirectedEdge[257, 259] -> 
             RGBColor[
              0.979404408917425, 0.956090950592063, 0.6282798502367123], 
             UndirectedEdge[116, 241] -> 
             RGBColor[
              0.9618669565649383, 0.9605705444582714, 0.6990427336355552], 
             UndirectedEdge[95, 105] -> 
             RGBColor[
              0.7263290752063825, 0.7861254672066598, 0.9733625442336455], 
             UndirectedEdge[115, 146] -> 
             RGBColor[
              0.8752916050191295, 0.8998158685409161, 0.7939170974477345], 
             UndirectedEdge[16, 170] -> 
             RGBColor[
              0.9811910409134061, 0.947106881677535, 0.4756665573129818], 
             UndirectedEdge[199, 226] -> 
             RGBColor[
              0.9554237121503885, 0.9580006287858853, 0.7027677468874606], 
             UndirectedEdge[78, 130] -> 
             RGBColor[
              0.9280626462808643, 0.9044699046805558, 0.6535029402615742], 
             UndirectedEdge[155, 214] -> 
             RGBColor[
              0.9874349810707752, 0.9890720560135776, 0.8578984110912736], 
             UndirectedEdge[185, 297] -> 
             RGBColor[
              0.7779118953522164, 0.8233441149284144, 0.8486162703951865], 
             UndirectedEdge[45, 53] -> 
             RGBColor[
              0.9904079098208162, 0.9903014384525035, 0.8086292880101165], 
             UndirectedEdge[49, 204] -> 
             RGBColor[0.98617209536, 0.9880914978773334, 0.8583030802844445], 
             UndirectedEdge[69, 254] -> 
             RGBColor[
              0.9796286527493112, 0.9462800862942147, 0.5561102708561982], 
             UndirectedEdge[102, 295] -> 
             RGBColor[
              0.9566437996919916, 0.9653955815019657, 0.8820367124100239], 
             UndirectedEdge[14, 254] -> 
             RGBColor[
              0.8982574908727681, 0.8841208743831037, 0.6556866458191611], 
             UndirectedEdge[125, 299] -> 
             RGBColor[
              0.9757426252674897, 0.9436283369657066, 0.6132903425788754], 
             UndirectedEdge[16, 44] -> 
             RGBColor[
              0.9289471791514075, 0.942142760146963, 0.8038371446423703], 
             UndirectedEdge[49, 84] -> 
             RGBColor[
              0.9879895314488889, 0.9893013768462222, 0.8487080761955554], 
             UndirectedEdge[186, 230] -> 
             RGBColor[
              0.9348674759373145, 0.9490301680946616, 0.9233152077587582], 
             UndirectedEdge[215, 282] -> 
             RGBColor[
              0.9898545710437674, 0.9899560249225846, 0.8093244105263003], 
             UndirectedEdge[134, 159] -> 
             RGBColor[
              0.5778281136620644, 0.6618680700394477, 0.9628177374358975], 
             UndirectedEdge[26, 266] -> 
             RGBColor[
              0.7919242643820096, 0.8347618989987282, 0.8514714464770492], 
             UndirectedEdge[142, 150] -> 
             RGBColor[
              0.9942200505947736, 0.9900455976017754, 0.612266360833142], 
             UndirectedEdge[114, 221] -> 
             RGBColor[
              0.9941448912604837, 0.9906910490162228, 0.6626886604970921], 
             UndirectedEdge[147, 172] -> 
             RGBColor[
              0.9009181387727013, 0.9211037126927344, 0.8791985483009064], 
             UndirectedEdge[35, 211] -> 
             RGBColor[
              0.9803628702567977, 0.9454214917381603, 0.378213888418793], 
             UndirectedEdge[124, 295] -> 
             RGBColor[
              0.9389898052256511, 0.953631363068638, 0.9747093004484189], 
             UndirectedEdge[166, 233] -> 
             RGBColor[
              0.7735197425974936, 0.8219334034334524, 0.9372220133627389], 
             UndirectedEdge[88, 290] -> 
             RGBColor[
              0.9624730536094376, 0.9715330453434294, 0.9484075110307818], 
             UndirectedEdge[134, 235] -> 
             RGBColor[
              0.5047262003287311, 0.5865482133727811, 0.958599224102564], 
             UndirectedEdge[185, 239] -> 
             RGBColor[
              0.7672119364322614, 0.7880030331464063, 0.6545541271378661], 
             UndirectedEdge[260, 278] -> 
             RGBColor[
              0.6684010247929808, 0.7407154066307905, 0.9676956310111119], 
             UndirectedEdge[15, 242] -> 
             RGBColor[
              0.8320202789574761, 0.8689402182716051, 0.9484679675994512], 
             UndirectedEdge[4, 266] -> 
             RGBColor[
              0.9756580159486454, 0.979666958672474, 0.8499857572988405], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.9721251251851852, 0.9444736115226338, 0.6312669702880657], 
             UndirectedEdge[3, 123] -> 
             RGBColor[
              0.8059555877234569, 0.7474173381925926, 0.613874569491358], 
             UndirectedEdge[28, 184] -> 
             RGBColor[
              0.9934806091582491, 0.9884640071380472, 0.5317827237710433], 
             UndirectedEdge[116, 210] -> 
             RGBColor[
              0.9628448057383331, 0.9709560118067273, 0.9095215741251107], 
             UndirectedEdge[118, 120] -> 
             RGBColor[
              0.9294367432158015, 0.9455052381923809, 0.9561586575003697], 
             UndirectedEdge[15, 89] -> 
             RGBColor[
              0.8961336980246914, 0.5574820676543211, 0.545754005185185], 
             UndirectedEdge[11, 283] -> 
             RGBColor[
              0.8523764833373313, 0.883972085082716, 0.9101588604904012], 
             UndirectedEdge[157, 201] -> 
             RGBColor[
              0.8478039726585578, 0.7607165869663912, 0.6137511869552589], 
             UndirectedEdge[196, 279] -> 
             RGBColor[
              0.8845776010776281, 0.9091073044793534, 0.9124370632840926], 
             UndirectedEdge[7, 11] -> 
             RGBColor[
              0.8171966471326082, 0.8579091189521724, 0.9822046417938255], 
             UndirectedEdge[76, 284] -> 
             RGBColor[
              0.9794153414222222, 0.9783043429925926, 0.6792009875259257], 
             UndirectedEdge[34, 108] -> 
             RGBColor[
              0.9601891784175497, 0.9669114845825661, 0.7952413869889701], 
             UndirectedEdge[46, 213] -> 
             RGBColor[
              0.9922135479020509, 0.990412477048791, 0.7325009358812364], 
             UndirectedEdge[261, 278] -> 
             RGBColor[
              0.7697035116516913, 0.8201329671794872, 0.9776498694747607], 
             UndirectedEdge[58, 66] -> 
             RGBColor[
              0.9139194423731637, 0.9334688870881829, 0.9663530145204376], 
             UndirectedEdge[194, 297] -> 
             RGBColor[
              0.9935526711636037, 0.9916018780844262, 0.7565124541786548], 
             UndirectedEdge[283, 297] -> 
             RGBColor[
              0.9913343121379107, 0.9906845296180756, 0.7932764041635159], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.7346077499141006, 0.7926004245493621, 0.9741824932778563], 
             UndirectedEdge[6, 169] -> 
             RGBColor[
              0.9930303485468659, 0.9875009452186293, 0.4827746349083657], 
             UndirectedEdge[11, 172] -> 
             RGBColor[
              0.7631102599747159, 0.8148668020358145, 0.9770233571095981], 
             UndirectedEdge[4, 82] -> 
             RGBColor[
              0.9081651701465174, 0.710991694466645, 0.5811356917685367], 
             UndirectedEdge[140, 230] -> 
             RGBColor[
              0.8997593809937222, 0.9210997340259983, 0.9199496336787323], 
             UndirectedEdge[207, 232] -> 
             RGBColor[
              0.9358567314380165, 0.9506347462582185, 0.9571310119162534], 
             UndirectedEdge[147, 244] -> 
             RGBColor[
              0.9835043145642566, 0.9858658501535394, 0.8522494268929841], 
             UndirectedEdge[56, 296] -> 
             RGBColor[
              0.8151069217913204, 0.8057122395937211, 0.6278843111357341], 
             UndirectedEdge[243, 294] -> 
             RGBColor[
              0.9642641449430595, 0.8889206762696216, 0.3271103672576178], 
             UndirectedEdge[211, 216] -> 
             RGBColor[
              0.9654041361034872, 0.943264532630764, 0.6507178005146592], 
             UndirectedEdge[107, 141] -> 
             RGBColor[
              0.9239275567209877, 0.9413697799111111, 0.964558012237037], 
             UndirectedEdge[19, 175] -> 
             RGBColor[
              0.8689317508504327, 0.8951513820869791, 0.8176224439075247], 
             UndirectedEdge[17, 158] -> 
             RGBColor[
              0.8229374247197669, 0.8114616499466727, 0.6281276281341874], 
             UndirectedEdge[115, 242] -> 
             RGBColor[
              0.8416525058752857, 0.8735367486231227, 0.7905642664203305], 
             UndirectedEdge[159, 292] -> 
             RGBColor[
              0.5337799022222223, 0.6273720702666666, 0.9584500334222222], 
             UndirectedEdge[34, 205] -> 
             RGBColor[
              0.9554814347961504, 0.9659966814549941, 0.9482741956309451], 
             UndirectedEdge[23, 180] -> 
             RGBColor[
              0.9755416923374507, 0.9779146514591948, 0.7229721912535763], 
             UndirectedEdge[47, 158] -> 
             RGBColor[
              0.9760219225369823, 0.9290762093293887, 0.5060968769699212], 
             UndirectedEdge[130, 199] -> 
             RGBColor[
              0.9403745455308643, 0.9460008318222224, 0.7013323439407407], 
             UndirectedEdge[112, 204] -> 
             RGBColor[
              0.9753675707160493, 0.9468918220905349, 0.6257783557695473], 
             UndirectedEdge[217, 247] -> 
             RGBColor[
              0.9379981239389643, 0.9526163052681736, 0.9668374650129004], 
             UndirectedEdge[102, 185] -> 
             RGBColor[
              0.7769119021918985, 0.822930592057971, 0.8651887449609954], 
             UndirectedEdge[136, 137] -> 
             RGBColor[
              0.9167112527206218, 0.8935329035390944, 0.649646110727023], 
             UndirectedEdge[138, 258] -> 
             RGBColor[
              0.7526739493805246, 0.8065087204938273, 0.975782736603112], 
             UndirectedEdge[79, 277] -> 
             RGBColor[
              0.8965244498081564, 0.9186509947012682, 0.9231828071735213], 
             UndirectedEdge[41, 259] -> 
             RGBColor[
              0.9811036055309281, 0.9853385526666597, 0.9128795214910427], 
             UndirectedEdge[225, 287] -> 
             RGBColor[
              0.896208240771753, 0.9196488469773177, 0.9751478000948506], 
             UndirectedEdge[167, 194] -> 
             RGBColor[
              0.9685216122723754, 0.9746681274730347, 0.8765522350272132], 
             UndirectedEdge[64, 219] -> 
             RGBColor[
              0.9785023030070925, 0.9601550244305566, 0.64366446712308], 
             UndirectedEdge[83, 293] -> 
             RGBColor[
              0.9897716757440504, 0.9900383393112908, 0.8191733331831352], 
             UndirectedEdge[31, 95] -> 
             RGBColor[
              0.8170748073051477, 0.85560538452024, 0.8712239827620405], 
             UndirectedEdge[256, 299] -> 
             RGBColor[
              0.9418134686658388, 0.9179419496994343, 0.6585033852569379], 
             UndirectedEdge[129, 269] -> 
             RGBColor[
              0.9735022271158049, 0.929296123466943, 0.5577594846198015], 
             UndirectedEdge[83, 126] -> 
             RGBColor[
              0.9632771156037694, 0.892473721192198, 0.5627603730002191], 
             UndirectedEdge[23, 81] -> 
             RGBColor[
              0.7454719347976948, 0.7954280011585895, 0.7217774916229207], 
             UndirectedEdge[235, 252] -> 
             RGBColor[
              0.5611102460695598, 0.5591393115974146, 0.603365908291782], 
             UndirectedEdge[6, 264] -> 
             RGBColor[
              0.9820243578198425, 0.9823847311171203, 0.6830628008617265], 
             UndirectedEdge[167, 215] -> 
             RGBColor[
              0.9698580907492619, 0.9751042019437062, 0.8459281949554115], 
             UndirectedEdge[273, 285] -> 
             RGBColor[
              0.9909169521426524, 0.9905119405343737, 0.8001931393779892], 
             UndirectedEdge[267, 273] -> 
             RGBColor[
              0.9709779594345824, 0.918386094658777, 0.5463544222485206], 
             UndirectedEdge[66, 109] -> 
             RGBColor[
              0.9794148798332816, 0.9820140132994929, 0.812483328142043], 
             UndirectedEdge[104, 173] -> 
             RGBColor[
              0.9775824084708012, 0.9360423412505204, 0.36741231942634656`], 
             UndirectedEdge[9, 185] -> 
             RGBColor[
              0.7336473420868872, 0.7913028394564201, 0.9747521538776924], 
             UndirectedEdge[233, 288] -> 
             RGBColor[
              0.5861797696296296, 0.6517695874074074, 0.9248463200000001], 
             UndirectedEdge[139, 147] -> 
             RGBColor[
              0.8570429946845017, 0.8868281166675873, 0.8748254839747277], 
             UndirectedEdge[65, 103] -> 
             RGBColor[
              0.9403239031367319, 0.9544076900387433, 0.9648705976070857], 
             UndirectedEdge[33, 124] -> 
             RGBColor[
              0.7946003679649016, 0.8398589750066321, 0.9606436209331293], 
             UndirectedEdge[82, 226] -> 
             RGBColor[
              0.89046190273027, 0.6974221766454511, 0.5983976553008727], 
             UndirectedEdge[6, 221] -> 
             RGBColor[
              0.9932574870050278, 0.9879867714134167, 0.507497254343208], 
             UndirectedEdge[125, 136] -> 
             RGBColor[
              0.974037091111111, 0.9378751697777776, 0.6066646644444443], 
             UndirectedEdge[112, 292] -> 
             RGBColor[
              0.8558654160493827, 0.8534102574683127, 0.6551029851917695], 
             UndirectedEdge[58, 67] -> 
             RGBColor[
              0.8568231564158374, 0.8886715433537267, 0.9862057516256457], 
             UndirectedEdge[73, 105] -> 
             RGBColor[
              0.8567592113214351, 0.7516452955131061, 0.6111593012602128], 
             UndirectedEdge[263, 298] -> 
             RGBColor[
              0.748013795029586, 0.8032023036423407, 0.9756113518211702], 
             UndirectedEdge[60, 170] -> 
             RGBColor[
              0.9519657525017379, 0.9278381067208852, 0.6619935940940835], 
             UndirectedEdge[10, 129] -> 
             RGBColor[
              0.9283768402436463, 0.943480074673388, 0.9064281060407476], 
             UndirectedEdge[53, 234] -> 
             RGBColor[
              0.9704812873486321, 0.9770850077132869, 0.9160178894550182], 
             UndirectedEdge[51, 154] -> 
             RGBColor[
              0.961816508411047, 0.9710433950094638, 0.9495188707972448], 
             UndirectedEdge[17, 84] -> 
             RGBColor[
              0.8370801605772291, 0.8725683078083951, 0.9333843489920438], 
             UndirectedEdge[98, 160] -> 
             RGBColor[
              0.963294485653552, 0.9721399177472596, 0.9467595320182836], 
             UndirectedEdge[25, 147] -> 
             RGBColor[
              0.9937391996378961, 0.9915624186766581, 0.7449460616250467], 
             UndirectedEdge[159, 204] -> 
             RGBColor[
              0.6532820568888889, 0.720853634888889, 0.9291254040000001], 
             UndirectedEdge[37, 94] -> 
             RGBColor[
              0.8238594947545215, 0.8631811672989529, 0.9828509574405188], 
             UndirectedEdge[37, 283] -> 
             RGBColor[
              0.9570008622053363, 0.9665620463710014, 0.9203595251475005], 
             UndirectedEdge[9, 142] -> 
             RGBColor[
              0.9497635763188438, 0.9581550422451224, 0.7583075780590793], 
             UndirectedEdge[51, 109] -> 
             RGBColor[
              0.9717595172169459, 0.9763046563947356, 0.825441860213157], 
             UndirectedEdge[123, 257] -> 
             RGBColor[
              0.9494048091061729, 0.8317563703703703, 0.30605053567407403`], 
             UndirectedEdge[212, 294] -> 
             RGBColor[
              0.9688093341673256, 0.906448701609092, 0.333330582413411], 
             UndirectedEdge[237, 297] -> 
             RGBColor[
              0.9896046655866217, 0.9758438453375635, 0.5666113414795424], 
             UndirectedEdge[163, 197] -> 
             RGBColor[
              0.7505476347954593, 0.8050527837662915, 0.9757712320361369], 
             UndirectedEdge[76, 229] -> 
             RGBColor[
              0.991930041898341, 0.984167492689096, 0.44634584161103347`], 
             UndirectedEdge[18, 24] -> 
             RGBColor[
              0.7687815648773582, 0.8146760415352241, 0.7501865587284888], 
             UndirectedEdge[44, 124] -> 
             RGBColor[
              0.9104595868488521, 0.9308821413671258, 0.9719880627504132], 
             UndirectedEdge[26, 82] -> 
             RGBColor[
              0.7244314185798817, 0.5660866347928992, 0.5826213809467455], 
             UndirectedEdge[7, 106] -> 
             RGBColor[
              0.9559367416083198, 0.9635946320321317, 0.800828396557453], 
             UndirectedEdge[53, 255] -> 
             RGBColor[
              0.9659584327375731, 0.9737118701498538, 0.9236739025621344], 
             UndirectedEdge[89, 242] -> 
             RGBColor[
              0.7532055809327847, 0.445585150617284, 0.5669319624142661], 
             UndirectedEdge[121, 181] -> 
             RGBColor[
              0.9655940880272109, 0.9716999385034013, 0.8353585380045352], 
             UndirectedEdge[217, 273] -> 
             RGBColor[
              0.9780940438658048, 0.9821906868648815, 0.8775205296768235], 
             UndirectedEdge[141, 240] -> 
             RGBColor[
              0.9727816919527961, 0.9792212109410601, 0.9309576752389578], 
             UndirectedEdge[42, 159] -> 
             RGBColor[
              0.6601740941484044, 0.7241619918531335, 0.8354311258669742], 
             UndirectedEdge[51, 52] -> 
             RGBColor[
              0.6666659004033997, 0.7344167209757905, 0.9587390436495566], 
             UndirectedEdge[170, 225] -> 
             RGBColor[
              0.9041154730016682, 0.8896874371669357, 0.6575628814970578], 
             UndirectedEdge[51, 179] -> 
             RGBColor[
              0.9326216195759244, 0.9487763169788141, 0.9818255522691506], 
             UndirectedEdge[36, 198] -> 
             RGBColor[
              0.6212544824521511, 0.6996866751463615, 0.9654905156600706], 
             UndirectedEdge[150, 295] -> 
             RGBColor[
              0.9578357138629101, 0.9656583842570678, 0.8455589041007834], 
             UndirectedEdge[140, 196] -> 
             RGBColor[
              0.9001192238085796, 0.9212485382774804, 0.9139861069931919], 
             UndirectedEdge[31, 73] -> 
             RGBColor[
              0.9475049434202003, 0.8211252128266863, 0.5090207397886076], 
             UndirectedEdge[188, 212] -> 
             RGBColor[
              0.976150169036734, 0.9298717316719914, 0.47573526658568427`], 
             UndirectedEdge[172, 244] -> 
             RGBColor[
              0.8920909021689025, 0.9158726492613594, 0.9546984025317515], 
             UndirectedEdge[7, 63] -> 
             RGBColor[
              0.8099578345177809, 0.8522541035204558, 0.9814831446029295], 
             UndirectedEdge[128, 218] -> 
             RGBColor[
              0.6734420210724517, 0.7406898595164555, 0.9650670064423212], 
             UndirectedEdge[138, 154] -> 
             RGBColor[
              0.9557266196274381, 0.966501565925926, 0.9598274640105193], 
             UndirectedEdge[1, 297] -> 
             RGBColor[
              0.9607158724073626, 0.9682586972202304, 0.8657572555346537], 
             UndirectedEdge[90, 123] -> 
             RGBColor[
              0.7846714637728396, 0.7307900187970371, 0.6117531669274074], 
             UndirectedEdge[8, 61] -> 
             RGBColor[
              0.9936920002962963, 0.9889161514074074, 0.5547913445925923], 
             UndirectedEdge[201, 209] -> 
             RGBColor[
              0.9531296155746545, 0.8413240552400701, 0.5011681111738225], 
             UndirectedEdge[44, 94] -> 
             RGBColor[
              0.792675067989363, 0.8383155518751302, 0.9798765589769916], 
             UndirectedEdge[114, 213] -> 
             RGBColor[
              0.9944463264217938, 0.9913357883464953, 0.6954980175635137], 
             UndirectedEdge[82, 107] -> 
             RGBColor[
              0.8701098462342025, 0.6811939992373437, 0.5964564579837826], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.8921816681944444, 0.5545346502777778, 0.5524437608333334], 
             UndirectedEdge[182, 268] -> 
             RGBColor[
              0.9345628992088497, 0.7565220750589277, 0.45660811737730156`], 
             UndirectedEdge[157, 229] -> 
             RGBColor[
              0.888003642753042, 0.9088859312076146, 0.7262482035483555], 
             UndirectedEdge[99, 157] -> 
             RGBColor[
              0.598715563131793, 0.6818903357475996, 0.9633180913749078], 
             UndirectedEdge[249, 288] -> 
             RGBColor[
              0.5796634496909928, 0.6469097266666668, 0.9358767499276792], 
             UndirectedEdge[66, 138] -> 
             RGBColor[0.950250094605438, 0.962417182531505, 0.96909779236628],
              UndirectedEdge[215, 286] -> 
             RGBColor[
              0.8570596646850323, 0.8862069788072777, 0.8428833332032475], 
             UndirectedEdge[83, 275] -> 
             RGBColor[
              0.990753382487837, 0.9892885729809335, 0.7188947378031997], 
             UndirectedEdge[95, 289] -> 
             RGBColor[
              0.8159388408063823, 0.8551356331799931, 0.8900498874336453], 
             UndirectedEdge[37, 75] -> 
             RGBColor[
              0.8919740402021346, 0.9166999039395978, 0.9895584743007471], 
             UndirectedEdge[88, 260] -> 
             RGBColor[
              0.7906188320390672, 0.8368825368419206, 0.9671951656667215], 
             UndirectedEdge[60, 82] -> 
             RGBColor[
              0.8976417004307319, 0.7031433079832123, 0.5989491810368843], 
             UndirectedEdge[50, 227] -> 
             RGBColor[
              0.857275880034289, 0.887297007690402, 0.8878606451494038], 
             UndirectedEdge[12, 248] -> 
             RGBColor[
              0.9382473139087848, 0.7861293177145189, 0.5309913214569941], 
             UndirectedEdge[103, 164] -> 
             RGBColor[
              0.5951719483555556, 0.6712552483377778, 0.9653190172622221], 
             UndirectedEdge[127, 228] -> 
             RGBColor[
              0.8983631955724467, 0.8938509371633967, 0.6698869288035606], 
             UndirectedEdge[163, 184] -> 
             RGBColor[
              0.8679774678117187, 0.8933996373766586, 0.7369317050843197], 
             UndirectedEdge[11, 183] -> 
             RGBColor[
              0.7711547831459398, 0.8211965863823074, 0.97781312770472], 
             UndirectedEdge[226, 266] -> 
             RGBColor[
              0.9579547485323979, 0.9660974408512801, 0.8672477208311765], 
             UndirectedEdge[98, 178] -> 
             RGBColor[
              0.9668581818510829, 0.9736135977077535, 0.8876998634750737], 
             UndirectedEdge[200, 255] -> 
             RGBColor[
              0.8734567575217325, 0.9018375107823614, 0.9792645250039513], 
             UndirectedEdge[223, 234] -> 
             RGBColor[
              0.9539058986131383, 0.9095151657864351, 0.6219235413318701], 
             UndirectedEdge[111, 190] -> 
             RGBColor[
              0.9091172555034812, 0.9259069222903352, 0.7675753392344473], 
             UndirectedEdge[85, 181] -> 
             RGBColor[
              0.9558473588914085, 0.9665916130713026, 0.9596230839304609], 
             UndirectedEdge[57, 134] -> 
             RGBColor[
              0.9122320701717597, 0.9285731643792445, 0.7826724263370975], 
             UndirectedEdge[9, 131] -> 
             RGBColor[
              0.93681499941702, 0.9150453622477579, 0.6596287711614355], 
             UndirectedEdge[184, 189] -> 
             RGBColor[
              0.859808476176456, 0.8870179590245554, 0.7361174963416839], 
             UndirectedEdge[194, 286] -> 
             RGBColor[
              0.8557231862081458, 0.8857709043366062, 0.8735073732750491], 
             UndirectedEdge[171, 298] -> 
             RGBColor[
              0.808622982086854, 0.8477533383013155, 0.8133372401403816], 
             UndirectedEdge[108, 213] -> 
             RGBColor[
              0.9943154792436146, 0.9902497098323301, 0.622653180342142], 
             UndirectedEdge[158, 175] -> 
             RGBColor[
              0.9757215898314267, 0.9284338280404998, 0.47340751540881], 
             UndirectedEdge[37, 297] -> 
             RGBColor[
              0.9602980012406691, 0.9679254980947196, 0.8657173986097364], 
             UndirectedEdge[68, 234] -> 
             RGBColor[
              0.9710756873202988, 0.9773308073769535, 0.9061671436666849], 
             UndirectedEdge[38, 252] -> 
             RGBColor[
              0.9665270247854332, 0.9014591823991274, 0.5462942044874208], 
             UndirectedEdge[42, 252] -> 
             RGBColor[
              0.969255426884631, 0.9025874467838813, 0.5010775208254229], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.9808374491533, 0.9837318652512612, 0.8502685000555799], 
             UndirectedEdge[184, 216] -> 
             RGBColor[
              0.9758947262439726, 0.9782350483307685, 0.7269056155637628], 
             UndirectedEdge[16, 59] -> 
             RGBColor[
              0.606243644721496, 0.6684370988088735, 0.7782797291512883], 
             UndirectedEdge[7, 185] -> 
             RGBColor[
              0.7394349201121606, 0.7959176970741526, 0.9753041782363748], 
             UndirectedEdge[127, 299] -> 
             RGBColor[
              0.8942655164324265, 0.8800285032432921, 0.6539682191263569], 
             UndirectedEdge[166, 217] -> 
             RGBColor[
              0.7655843435003356, 0.8160151957798154, 0.9506545741506736], 
             UndirectedEdge[101, 207] -> 
             RGBColor[
              0.9045759995407272, 0.926748364245118, 0.9907604604323641], 
             UndirectedEdge[14, 69] -> 
             RGBColor[
              0.9104980754567902, 0.9287465230222223, 0.8839876842962964], 
             UndirectedEdge[51, 107] -> 
             RGBColor[
              0.9147344980406766, 0.9345136117995871, 0.9801194626490968], 
             UndirectedEdge[74, 233] -> 
             RGBColor[
              0.7398414332904806, 0.7945918347474747, 0.934570733486379], 
             UndirectedEdge[158, 252] -> 
             RGBColor[
              0.9500380898565421, 0.8393823109268033, 0.2799200740117034], 
             UndirectedEdge[86, 110] -> 
             RGBColor[
              0.9820336902367349, 0.9506313099971984, 0.4209499199211236], 
             UndirectedEdge[58, 73] -> 
             RGBColor[
              0.8832835473585741, 0.7727208087413888, 0.6137089257063713], 
             UndirectedEdge[13, 96] -> 
             RGBColor[
              0.9359012738140675, 0.7803182321271445, 0.5494541829980704], 
             UndirectedEdge[16, 53] -> 
             RGBColor[
              0.9905110535264074, 0.9894957772441852, 0.7452564732395925], 
             UndirectedEdge[44, 170] -> 
             RGBColor[
              0.9158395595397765, 0.899035905530572, 0.6586811353372781], 
             UndirectedEdge[27, 32] -> 
             RGBColor[
              0.9097180705738377, 0.9294080353707816, 0.9396458581482242], 
             UndirectedEdge[116, 164] -> 
             RGBColor[
              0.6072609743427161, 0.6808777792730865, 0.9658850973392592], 
             UndirectedEdge[70, 300] -> 
             RGBColor[
              0.45467933192386845`, 0.5592184091426613, 0.951757222441701], 
             UndirectedEdge[79, 116] -> 
             RGBColor[
              0.9616791063730945, 0.9704739651620939, 0.9288402293403667], 
             UndirectedEdge[137, 195] -> 
             RGBColor[
              0.932046910794696, 0.9443753793909465, 0.7847568508751714], 
             UndirectedEdge[156, 214] -> 
             RGBColor[
              0.938687379013162, 0.7940685624607655, 0.5564152794040309], 
             UndirectedEdge[14, 249] -> 
             RGBColor[
              0.898993673147783, 0.9214420266666667, 0.960579701779531], 
             UndirectedEdge[84, 89] -> 
             RGBColor[
              0.9011935796444444, 0.5611101571911111, 0.5306703865777778], 
             UndirectedEdge[98, 246] -> 
             RGBColor[
              0.9588579597770088, 0.9425292173225682, 0.6706016671787772], 
             UndirectedEdge[4, 107] -> 
             RGBColor[
              0.9188396992209569, 0.9375752641181903, 0.9731704278588282], 
             UndirectedEdge[20, 295] -> 
             RGBColor[
              0.8998578137335167, 0.9229862109541902, 0.9903104356580981], 
             UndirectedEdge[57, 175] -> 
             RGBColor[
              0.9942996158874731, 0.9902157797175747, 0.6209265519234222], 
             UndirectedEdge[93, 160] -> 
             RGBColor[
              0.9619860980119217, 0.8932818318081828, 0.5907227401557955], 
             UndirectedEdge[13, 149] -> 
             RGBColor[
              0.9143152204565861, 0.764607518450158, 0.6033749760667277], 
             UndirectedEdge[230, 298] -> 
             RGBColor[
              0.804993376023308, 0.846764477668339, 0.9107116343887913], 
             UndirectedEdge[96, 198] -> 
             RGBColor[
              0.7022346085982734, 0.7625591546126054, 0.910388871170706], 
             UndirectedEdge[32, 182] -> 
             RGBColor[
              0.9296567071013162, 0.7547414891541678, 0.5559616164677071], 
             UndirectedEdge[80, 241] -> 
             RGBColor[
              0.9760112316193017, 0.9711193216346908, 0.6751001653862723], 
             UndirectedEdge[55, 292] -> 
             RGBColor[
              0.7307007295200527, 0.789548230523077, 0.9737930779981592], 
             UndirectedEdge[121, 160] -> 
             RGBColor[
              0.9895258103209876, 0.9895424275358025, 0.7945908657283952], 
             UndirectedEdge[62, 220] -> 
             RGBColor[
              0.9073870911519067, 0.5737279678811293, 0.40518685934474175`], 
             UndirectedEdge[28, 189] -> 
             RGBColor[
              0.8601108912606311, 0.8876647943107506, 0.7690335119645799], 
             UndirectedEdge[25, 91] -> 
             RGBColor[
              0.9590632756588068, 0.8621875715138305, 0.4850142078865698], 
             UndirectedEdge[41, 99] -> 
             RGBColor[
              0.6959237864461506, 0.7580257255555296, 0.9353154982326568], 
             UndirectedEdge[148, 206] -> 
             RGBColor[
              0.9807517584775086, 0.9467333030219145, 0.3797246457208764], 
             UndirectedEdge[3, 90] -> 
             RGBColor[
              0.6658977772839508, 0.7389236717155558, 0.967334125337284], 
             UndirectedEdge[99, 104] -> 
             RGBColor[
              0.7018638858326476, 0.7545472626809329, 0.6803930493783265], 
             UndirectedEdge[193, 266] -> 
             RGBColor[
              0.7085420179883948, 0.766236080666445, 0.8451372725976122], 
             UndirectedEdge[275, 293] -> 
             RGBColor[
              0.9929606094043617, 0.990201318034061, 0.6823152756762318], 
             UndirectedEdge[229, 257] -> 
             RGBColor[
              0.9835126694538965, 0.9557737189409479, 0.4136459391517743], 
             UndirectedEdge[90, 144] -> 
             RGBColor[
              0.8172956895178634, 0.8562099492921541, 0.8904856374532639], 
             UndirectedEdge[49, 115] -> 
             RGBColor[
              0.9925618767469454, 0.9902698176609498, 0.7058879936238422], 
             UndirectedEdge[77, 244] -> 
             RGBColor[
              0.9835986827540406, 0.9835223815192458, 0.6775034619981264], 
             UndirectedEdge[66, 95] -> 
             RGBColor[
              0.8029293148757402, 0.8464004618665598, 0.9553898212412579], 
             UndirectedEdge[94, 125] -> 
             RGBColor[
              0.8532788102115851, 0.8852715296529079, 0.9372077620881027], 
             UndirectedEdge[196, 230] -> 
             RGBColor[
              0.987789049246746, 0.9892184723034787, 0.8520305851163685], 
             UndirectedEdge[138, 245] -> 
             RGBColor[
              0.9341917888780348, 0.9503424102860912, 0.9928647686608556], 
             UndirectedEdge[100, 127] -> 
             RGBColor[
              0.906512640796275, 0.9257016333478577, 0.8893823368952113], 
             UndirectedEdge[24, 288] -> 
             RGBColor[
              0.3672223671791642, 0.4790939003108592, 0.9457006319638732], 
             UndirectedEdge[224, 258] -> 
             RGBColor[
              0.7385334286299814, 0.7952542335589645, 0.9751544733073614], 
             UndirectedEdge[25, 203] -> 
             RGBColor[
              0.9943391794074038, 0.9903004020862209, 0.6252327969101388], 
             UndirectedEdge[143, 239] -> 
             RGBColor[
              0.9377624876317596, 0.9231470662713129, 0.6705263695804592], 
             UndirectedEdge[142, 282] -> 
             RGBColor[
              0.9889935509874503, 0.9881143900846037, 0.7156076909960207], 
             UndirectedEdge[57, 242] -> 
             RGBColor[
              0.8415154507758134, 0.8732436016237475, 0.7756466646487996], 
             UndirectedEdge[47, 177] -> 
             RGBColor[
              0.9691293599296982, 0.9746403379286694, 0.8534794300977366], 
             UndirectedEdge[43, 174] -> 
             RGBColor[
              0.9482842285883004, 0.8891118348103213, 0.6188624737323072], 
             UndirectedEdge[5, 29] -> 
             RGBColor[
              0.9014924709444293, 0.5717151231148917, 0.5405918886766041], 
             UndirectedEdge[167, 282] -> 
             RGBColor[
              0.9645658136852924, 0.9730323030978894, 0.9421100548937574], 
             UndirectedEdge[131, 172] -> 
             RGBColor[
              0.8885161902844012, 0.8766179029491326, 0.6549995108358906], 
             UndirectedEdge[21, 101] -> 
             RGBColor[
              0.807038703144033, 0.8499446510814817, 0.9811998898567902], 
             UndirectedEdge[251, 300] -> 
             RGBColor[
              0.6309679469396124, 0.6949955865287096, 0.8341354416815827], 
             UndirectedEdge[75, 167] -> 
             RGBColor[
              0.9012764312434807, 0.9238886365752805, 0.9825151341653209], 
             UndirectedEdge[165, 281] -> 
             RGBColor[
              0.936977326230262, 0.7856041451722551, 0.552038303912874], 
             UndirectedEdge[63, 174] -> 
             RGBColor[
              0.8276531265372933, 0.8659159481808087, 0.9676419330145059], 
             UndirectedEdge[64, 211] -> 
             RGBColor[
              0.9757917139942214, 0.9510115712135758, 0.6331343406598595], 
             UndirectedEdge[124, 237] -> 
             RGBColor[
              0.9709506779599633, 0.9636661040337924, 0.6758564040837464], 
             UndirectedEdge[127, 192] -> 
             RGBColor[
              0.9036312514118503, 0.9116213265080382, 0.6903523309507739], 
             UndirectedEdge[62, 228] -> 
             RGBColor[
              0.9846914416651933, 0.958786927349168, 0.5001175168896485], 
             UndirectedEdge[152, 277] -> 
             RGBColor[
              0.8285968187620147, 0.8662772817611264, 0.9834836034692227], 
             UndirectedEdge[76, 157] -> 
             RGBColor[
              0.8869886897435899, 0.9057350414814815, 0.699109627122507], 
             UndirectedEdge[106, 297] -> 
             RGBColor[
              0.9944137168483755, 0.9910210498863935, 0.6741404887162646], 
             UndirectedEdge[91, 203] -> 
             RGBColor[
              0.9582556069584737, 0.86046004983165, 0.3971044542087542], 
             UndirectedEdge[215, 271] -> 
             RGBColor[
              0.902227720788473, 0.9214926075252265, 0.8473852629161556], 
             UndirectedEdge[181, 296] -> 
             RGBColor[
              0.8047552502494331, 0.8483237073922902, 0.9803307157823129], 
             UndirectedEdge[27, 119] -> 
             RGBColor[
              0.5669251140214084, 0.6514502233240997, 0.9622130152518724], 
             UndirectedEdge[100, 170] -> 
             RGBColor[
              0.9796298691711148, 0.9473096108230663, 0.5632026699072299], 
             UndirectedEdge[112, 115] -> 
             RGBColor[
              0.9817573521029948, 0.9490701418741514, 0.47336326910894505`], 
             UndirectedEdge[75, 282] -> 
             RGBColor[
              0.9212729115379862, 0.9387404595541589, 0.9459113497362097], 
             UndirectedEdge[234, 255] -> 
             RGBColor[
              0.9497162735584275, 0.9620190596686963, 0.9700014121560416], 
             UndirectedEdge[29, 77] -> 
             RGBColor[
              0.9063945065569241, 0.5716049297981582, 0.29715015170293946`], 
             UndirectedEdge[44, 192] -> 
             RGBColor[
              0.9245046180246914, 0.9282651824526749, 0.692343251292181], 
             UndirectedEdge[49, 57] -> 
             RGBColor[
              0.9924248216474731, 0.9899766706615747, 0.6909703918523112], 
             UndirectedEdge[4, 281] -> 
             RGBColor[
              0.9222576032531985, 0.7749821418327091, 0.5928947633898964], 
             UndirectedEdge[23, 285] -> 
             RGBColor[
              0.9923821513847917, 0.9892321879151853, 0.6388441354453545], 
             UndirectedEdge[86, 109] -> 
             RGBColor[
              0.9940140341043622, 0.9896049491602479, 0.5898427372382702], 
             UndirectedEdge[276, 279] -> 
             RGBColor[
              0.8838658659130644, 0.908812983698047, 0.924232356872474], 
             UndirectedEdge[139, 183] -> 
             RGBColor[
              0.7736741054603715, 0.8231647001219002, 0.9780642302086169], 
             UndirectedEdge[234, 287] -> 
             RGBColor[
              0.9532540425057157, 0.9646575219570188, 0.9640128921262002], 
             UndirectedEdge[160, 181] -> 
             RGBColor[
              0.9602948894593096, 0.9699028238169816, 0.9518370659551525], 
             UndirectedEdge[196, 298] -> 
             RGBColor[
              0.8053532188381654, 0.8469132819198211, 0.9047481077032511], 
             UndirectedEdge[255, 287] -> 
             RGBColor[
              0.9487311878946566, 0.9612843843935857, 0.9716689052333165], 
             UndirectedEdge[126, 216] -> 
             RGBColor[
              0.9488005203969421, 0.8822373864679588, 0.6123562368348567], 
             UndirectedEdge[190, 212] -> 
             RGBColor[
              0.9756468841367159, 0.9287952561607614, 0.4209558111330709], 
             UndirectedEdge[39, 137] -> 
             RGBColor[
              0.8739009194729941, 0.7183098858306977, 0.6035488997383487], 
             UndirectedEdge[170, 195] -> 
             RGBColor[
              0.9810128687249617, 0.9467257893824239, 0.456273614152093], 
             UndirectedEdge[69, 288] -> 
             RGBColor[
              0.5911678520000001, 0.6542142230222223, 0.8592847324444445], 
             UndirectedEdge[101, 231] -> 
             RGBColor[
              0.9546652250995886, 0.9632820459259259, 0.8575556863901233], 
             UndirectedEdge[57, 253] -> 
             RGBColor[
              0.9141720915654432, 0.9301200847780899, 0.7828574673095046], 
             UndirectedEdge[52, 266] -> 
             RGBColor[
              0.6895340943990536, 0.7497723726193759, 0.8439261045145462], 
             UndirectedEdge[28, 275] -> 
             RGBColor[
              0.9938626701952862, 0.989281197063973, 0.5733677098451178], 
             UndirectedEdge[4, 226] -> 
             RGBColor[
              0.9391917557170244, 0.9538034415262977, 0.9751116251759184], 
             UndirectedEdge[104, 229] -> 
             RGBColor[
              0.9911519654538965, 0.9815428581409479, 0.44332316155177426`], 
             UndirectedEdge[189, 293] -> 
             RGBColor[
              0.8592088304697065, 0.8885849152808385, 0.877981077795694], 
             UndirectedEdge[155, 156] -> 
             RGBColor[
              0.9401268423868312, 0.7946638175582992, 0.532559646090535], 
             UndirectedEdge[107, 281] -> 
             RGBColor[
              0.8842022793408836, 0.7451844466034077, 0.6082155296051424], 
             UndirectedEdge[107, 240] -> 
             RGBColor[
              0.9296385105404503, 0.9456289999188378, 0.9548908570759949], 
             UndirectedEdge[13, 105] -> 
             RGBColor[
              0.8480346015059688, 0.7120288800254666, 0.6038792729704315], 
             UndirectedEdge[96, 138] -> 
             RGBColor[
              0.9615165272441788, 0.9704315399732828, 0.9326454253863063], 
             UndirectedEdge[254, 260] -> 
             RGBColor[
              0.7995264484585021, 0.8067537138344069, 0.645977674022179], 
             UndirectedEdge[120, 176] -> 
             RGBColor[
              0.9381995459045365, 0.9497081863437212, 0.8199465706708745], 
             UndirectedEdge[59, 125] -> 
             RGBColor[
              0.6014959055700886, 0.6673221004396883, 0.9186255102866958], 
             UndirectedEdge[22, 267] -> 
             RGBColor[
              0.9598250710395207, 0.9110607561896412, 0.6096780726188911], 
             UndirectedEdge[28, 197] -> 
             RGBColor[
              0.8760507761419898, 0.9001171535276801, 0.7706222507228604], 
             UndirectedEdge[245, 298] -> 
             RGBColor[
              0.7772181400826517, 0.826489055656827, 0.9783968883233582], 
             UndirectedEdge[193, 199] -> 
             RGBColor[
              0.7060109816063853, 0.7581392686010502, 0.6806572986538962], 
             UndirectedEdge[22, 274] -> 
             RGBColor[
              0.9662520610020178, 0.9743514228692589, 0.9420106372381244], 
             UndirectedEdge[76, 201] -> 
             RGBColor[
              0.9517303718038568, 0.8359981484478725, 0.33384882501793683`], 
             UndirectedEdge[19, 158] -> 
             RGBColor[
              0.8499928485929706, 0.8325975527052567, 0.6308242599385573], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.97704703675, 0.9342364067250001, 0.36533250138750006`], 
             UndirectedEdge[61, 267] -> 
             RGBColor[
              0.972615894990138, 0.9174758075476659, 0.4038067000262981], 
             UndirectedEdge[106, 283] -> 
             RGBColor[
              0.9911165778130429, 0.9896575981626752, 0.7287826152540288], 
             UndirectedEdge[174, 283] -> 
             RGBColor[
              0.9705526289173672, 0.9769199564241667, 0.9061231004162805], 
             UndirectedEdge[19, 242] -> 
             RGBColor[
              0.716147585738773, 0.7781792039931519, 0.972342556632902], 
             UndirectedEdge[125, 195] -> 
             RGBColor[
              0.9893727491851851, 0.9887176456296296, 0.7417754045925928], 
             UndirectedEdge[115, 159] -> 
             RGBColor[
              0.6596718382758343, 0.7230319546725054, 0.7767103173393979], 
             UndirectedEdge[158, 177] -> 
             RGBColor[
              0.9498901249666805, 0.9114441272580581, 0.6339918845676579], 
             UndirectedEdge[42, 134] -> 
             RGBColor[
              0.9128713811438023, 0.9299963485592477, 0.8563108366362049], 
             UndirectedEdge[165, 179] -> 
             RGBColor[
              0.9514465437332682, 0.9624599726369631, 0.9340200580018596], 
             UndirectedEdge[108, 145] -> 
             RGBColor[
              0.7440006884971194, 0.794890176961317, 0.775476479216461], 
             UndirectedEdge[44, 125] -> 
             RGBColor[0.92419944, 0.9410277617777778, 0.9441829257777778], 
             UndirectedEdge[39, 141] -> 
             RGBColor[
              0.9223605358190389, 0.7561412777582697, 0.5801228042113253], 
             UndirectedEdge[50, 87] -> 
             RGBColor[
              0.8260225227501325, 0.862881647445706, 0.8847456025745484], 
             UndirectedEdge[26, 226] -> 
             RGBColor[
              0.7554580041503886, 0.8088983818525519, 0.9765973143541273], 
             UndirectedEdge[9, 143] -> 
             RGBColor[
              0.9041978932863854, 0.9264468725813266, 0.9907243963202854], 
             UndirectedEdge[136, 299] -> 
             RGBColor[
              0.9649765341563785, 0.8935197671879285, 0.3184408781344305], 
             UndirectedEdge[134, 144] -> 
             RGBColor[
              0.9102515631799277, 0.928912986504935, 0.8997280001691614], 
             UndirectedEdge[240, 281] -> 
             RGBColor[
              0.9330564145726921, 0.7830358776333566, 0.5746151926070631], 
             UndirectedEdge[257, 261] -> 
             RGBColor[
              0.9041750732345679, 0.8974585832888888, 0.6689310264296295], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.989503449487473, 0.9887686081975746, 0.7393850888123112], 
             UndirectedEdge[135, 254] -> 
             RGBColor[
              0.9602280764487228, 0.9330866363045361, 0.646068451255172], 
             UndirectedEdge[14, 224] -> 
             RGBColor[
              0.8686753576423271, 0.8981221668922977, 0.9873362251592133], 
             UndirectedEdge[96, 289] -> 
             RGBColor[
              0.9882713045747655, 0.9894178972750113, 0.8440383662943054], 
             UndirectedEdge[92, 189] -> 
             RGBColor[
              0.8411486317889456, 0.8244597297644001, 0.6283546028230165], 
             UndirectedEdge[107, 127] -> 
             RGBColor[
              0.8513166699303687, 0.8842808204998078, 0.9856805380289633], 
             UndirectedEdge[172, 270] -> 
             RGBColor[
              0.4971727657649718, 0.5813601479864181, 0.9577426531972117], 
             UndirectedEdge[48, 84] -> 
             RGBColor[
              0.8767180686705076, 0.9035337428701236, 0.9373350852334705], 
             UndirectedEdge[149, 289] -> 
             RGBColor[
              0.966685251217284, 0.9737071835980248, 0.8979591593629627], 
             UndirectedEdge[1, 102] -> 
             RGBColor[
              0.9597158792470446, 0.9678451743497869, 0.8823297301004627], 
             UndirectedEdge[33, 297] -> 
             RGBColor[
              0.8132543555915601, 0.8520367163104032, 0.8513985583289252], 
             UndirectedEdge[18, 135] -> 
             RGBColor[
              0.9733264733976056, 0.9766029142569086, 0.753728839608034], 
             UndirectedEdge[60, 137] -> 
             RGBColor[
              0.9029997945714722, 0.9254876967294078, 0.9904768308171621], 
             UndirectedEdge[156, 208] -> 
             RGBColor[
              0.9331638181893005, 0.7902487296570646, 0.5791832623868312], 
             UndirectedEdge[104, 279] -> 
             RGBColor[
              0.8851826230468263, 0.9023073331352064, 0.6959844866020117], 
             UndirectedEdge[74, 158] -> 
             RGBColor[
              0.7272862407811667, 0.7345236022250117, 0.6201081569840781], 
             UndirectedEdge[80, 277] -> 
             RGBColor[
              0.885345153841524, 0.9107804497062109, 0.9630176664846124], 
             UndirectedEdge[223, 291] -> 
             RGBColor[
              0.9734817883555555, 0.9209551395160496, 0.40176047612839516`], 
             UndirectedEdge[114, 264] -> 
             RGBColor[
              0.9829117620752984, 0.9850890087199266, 0.8382542070156105], 
             UndirectedEdge[1, 237] -> 
             RGBColor[0.9556890868207408, 0.952054561216, 0.6937343193884443],
              UndirectedEdge[84, 292] -> 
             RGBColor[
              0.8637485685333333, 0.8934018707911111, 0.9360424066666666], 
             UndirectedEdge[103, 152] -> 
             RGBColor[
              0.8816624493397925, 0.9084777212866437, 0.9885749455590311], 
             UndirectedEdge[10, 269] -> 
             RGBColor[
              0.9124978511443702, 0.8828993238786211, 0.638543332605519], 
             UndirectedEdge[109, 138] -> 
             RGBColor[
              0.965669628433337, 0.9717628273111978, 0.8357504534264315], 
             UndirectedEdge[165, 240] -> 
             RGBColor[
              0.9824135574298287, 0.9860486984876851, 0.8987136313837265], 
             UndirectedEdge[249, 254] -> 
             RGBColor[
              0.968124250440304, 0.9389755899386591, 0.6327022883394329], 
             UndirectedEdge[2, 155] -> 
             RGBColor[
              0.9353474181459567, 0.9491354857330704, 0.911316394017094], 
             UndirectedEdge[117, 161] -> 
             RGBColor[
              0.9355616309940558, 0.7726798085313824, 0.3003532303454961], 
             UndirectedEdge[169, 264] -> 
             RGBColor[
              0.982482048504801, 0.98336368521262, 0.7328796073799726], 
             UndirectedEdge[3, 229] -> 
             RGBColor[
              0.8400634480711806, 0.8714346867631702, 0.7214699729690582], 
             UndirectedEdge[55, 90] -> 
             RGBColor[
              0.6817930672978305, 0.7513411930830771, 0.9689184192959369], 
             UndirectedEdge[3, 259] -> 
             RGBColor[
              0.835955187534709, 0.8717519184142852, 0.9361038840539962], 
             UndirectedEdge[113, 254] -> 
             RGBColor[
              0.9800343550702989, 0.9464478546300172, 0.5493867334734821], 
             UndirectedEdge[6, 205] -> 
             RGBColor[
              0.988621471317785, 0.9872253870841986, 0.6683372059646071], 
             UndirectedEdge[120, 287] -> 
             RGBColor[
              0.9170446743447068, 0.936263253518469, 0.9771351977299427], 
             UndirectedEdge[31, 67] -> 
             RGBColor[
              0.9210445524774638, 0.937075947439024, 0.8815175657078822], 
             UndirectedEdge[141, 232] -> 
             RGBColor[
              0.9718605818857667, 0.9785342485612489, 0.9325168743184573], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.963525786276713, 0.9723181716429918, 0.9466255092217377], 
             UndirectedEdge[71, 122] -> 
             RGBColor[
              0.6356558690674055, 0.6742387990827947, 0.6424972854232072], 
             UndirectedEdge[78, 120] -> 
             RGBColor[
              0.9232777646737345, 0.9006545699691815, 0.6530465539823719], 
             UndirectedEdge[177, 247] -> 
             RGBColor[
              0.9264857679195244, 0.9440304089986282, 0.9863248808504801], 
             UndirectedEdge[168, 182] -> 
             RGBColor[
              0.9285644282634884, 0.7540913196394547, 0.5651749779982058], 
             UndirectedEdge[26, 228] -> 
             RGBColor[
              0.782152473296399, 0.8022403211080333, 0.6588625078116345], 
             UndirectedEdge[7, 194] -> 
             RGBColor[
              0.9550756959235478, 0.9641754602301644, 0.8832003620198432], 
             UndirectedEdge[206, 244] -> 
             RGBColor[
              0.9747619974577375, 0.9537248363829969, 0.6422673662827912], 
             UndirectedEdge[31, 109] -> 
             RGBColor[
              0.993560372262689, 0.9912189359531731, 0.7283174896628255], 
             UndirectedEdge[57, 235] -> 
             RGBColor[
              0.5864328698430287, 0.6474189510064635, 0.7575742022345335], 
             UndirectedEdge[24, 135] -> 
             RGBColor[
              0.7485231762119089, 0.8025919622322917, 0.960785389251736], 
             UndirectedEdge[130, 220] -> 
             RGBColor[
              0.8558294403139768, 0.5365171065288835, 0.5782727216741351], 
             UndirectedEdge[84, 112] -> 
             RGBColor[
              0.9771850068049381, 0.9481017010594238, 0.6161833516806583], 
             UndirectedEdge[76, 104] -> 
             RGBColor[
              0.9901370124444444, 0.9783919684148148, 0.4161845851259258], 
             UndirectedEdge[21, 87] -> 
             RGBColor[
              0.6806314244948526, 0.7504337088965783, 0.9688026375975052], 
             UndirectedEdge[43, 183] -> 
             RGBColor[
              0.8845470725821196, 0.8387374575801034, 0.6283121712316253], 
             UndirectedEdge[11, 131] -> 
             RGBColor[
              0.8421217238817698, 0.8403741931843925, 0.650375344005815], 
             UndirectedEdge[21, 187] -> 
             RGBColor[
              0.7905402320520899, 0.8367892180718337, 0.9796262509556816], 
             UndirectedEdge[36, 66] -> 
             RGBColor[
              0.8942816524980011, 0.917810246495334, 0.9644799445912826], 
             UndirectedEdge[124, 125] -> 
             RGBColor[
              0.9710633290710744, 0.9778381191449037, 0.9293192658615244], 
             UndirectedEdge[232, 296] -> 
             RGBColor[
              0.8248988794857668, 0.8633467930945822, 0.9462328057851239], 
             UndirectedEdge[75, 239] -> 
             RGBColor[
              0.9156075312147538, 0.9054813054046639, 0.6684132100594421], 
             UndirectedEdge[108, 114] -> 
             RGBColor[
              0.99421661919464, 0.9908444678145768, 0.670495803476516], 
             UndirectedEdge[137, 266] -> 
             RGBColor[
              0.9322862571026314, 0.9456300825378228, 0.8647994372040726], 
             UndirectedEdge[74, 262] -> 
             RGBColor[
              0.732588931076829, 0.752410821723171, 0.6407081074536882], 
             UndirectedEdge[48, 90] -> 
             RGBColor[
              0.7064908156927301, 0.7706352618390125, 0.9713800600423594], 
             UndirectedEdge[125, 150] -> 
             RGBColor[
              0.9899092377083334, 0.9898651403333334, 0.800168869513889], 
             UndirectedEdge[38, 55] -> 
             RGBColor[
              0.8543665193470371, 0.8852098877247898, 0.8959908541049091], 
             UndirectedEdge[110, 165] -> 
             RGBColor[
              0.9786040975066623, 0.9510146728898351, 0.6087435486287194], 
             UndirectedEdge[114, 145] -> 
             RGBColor[
              0.7441315356752985, 0.7959762554754821, 0.8483213164378327], 
             UndirectedEdge[222, 290] -> 
             RGBColor[
              0.9832400273545118, 0.9814086193048173, 0.6732613831446366], 
             UndirectedEdge[267, 286] -> 
             RGBColor[
              0.8353812933990796, 0.8134784489151874, 0.6263457534911243], 
             UndirectedEdge[6, 187] -> 
             RGBColor[
              0.9368323387608213, 0.9472724336333984, 0.7107391829285192], 
             UndirectedEdge[221, 231] -> 
             RGBColor[
              0.9945919022518519, 0.9908409506962963, 0.6527401189037036], 
             UndirectedEdge[106, 286] -> 
             RGBColor[
              0.8565842318929177, 0.8851900761385736, 0.791135407812659], 
             UndirectedEdge[67, 154] -> 
             RGBColor[
              0.9123755850700563, 0.9319554081797647, 0.9564130758313389], 
             UndirectedEdge[85, 296] -> 
             RGBColor[
              0.8242394419753087, 0.8628549856790124, 0.9473490614814813], 
             UndirectedEdge[41, 201] -> 
             RGBColor[
              0.9450121959729154, 0.8368519767743212, 0.585748593813008], 
             UndirectedEdge[42, 235] -> 
             RGBColor[
              0.5870721808150712, 0.6488421351864667, 0.8312126125336408], 
             UndirectedEdge[44, 60] -> 
             RGBColor[
              0.8997218907397392, 0.9228739851903132, 0.9901641814234721], 
             UndirectedEdge[199, 228] -> 
             RGBColor[
              0.9821181812963989, 0.9513425680413667, 0.3850329403449677], 
             UndirectedEdge[39, 62] -> 
             RGBColor[
              0.9360778951211666, 0.7639883085327377, 0.43147591808933944`], 
             UndirectedEdge[48, 144] -> 
             RGBColor[
              0.8791728518772599, 0.9045488588111664, 0.89665297472229], 
             UndirectedEdge[68, 215] -> 
             RGBColor[
              0.991529547289424, 0.9906486706450897, 0.7815657194361993], 
             UndirectedEdge[127, 240] -> 
             RGBColor[
              0.9001708051621772, 0.9221322515297568, 0.952080201030884], 
             UndirectedEdge[4, 26] -> 
             RGBColor[
              0.773161271566636, 0.8224678996737458, 0.9593353508217912], 
             UndirectedEdge[8, 47] -> 
             RGBColor[
              0.994601736824074, 0.9908619858518519, 0.6538105513981483], 
             UndirectedEdge[112, 175] -> 
             RGBColor[
              0.9819811732049382, 0.9495488725794239, 0.4977248147917693], 
             UndirectedEdge[162, 203] -> 
             RGBColor[
              0.976885522020202, 0.9330568157575757, 0.4186807838383837], 
             UndirectedEdge[6, 50] -> 
             RGBColor[
              0.991671649408456, 0.9884867141106926, 0.6177878613943252], 
             UndirectedEdge[15, 294] -> 
             RGBColor[
              0.9774699240634726, 0.9625028731575528, 0.6520305046496357], 
             UndirectedEdge[6, 219] -> 
             RGBColor[
              0.9850954248403766, 0.9613425190044671, 0.40025457968325057`], 
             UndirectedEdge[110, 281] -> 
             RGBColor[
              0.9292469546495257, 0.7480018520355066, 0.284645109852056], 
             UndirectedEdge[167, 297] -> 
             RGBColor[
              0.9696003922820151, 0.9751142307304024, 0.8586740584743102], 
             UndirectedEdge[122, 246] -> 
             RGBColor[
              0.6374747490674053, 0.680374308416128, 0.6495632907565404], 
             UndirectedEdge[210, 277] -> 
             RGBColor[
              0.8976901491733948, 0.9191330413459015, 0.9038641519582653], 
             UndirectedEdge[225, 234] -> 
             RGBColor[
              0.8971933264355239, 0.9203835222524284, 0.9734803070175757], 
             UndirectedEdge[84, 280] -> 
             RGBColor[
              0.9760562478388888, 0.981517807468889, 0.918896147411111], 
             UndirectedEdge[67, 95] -> 
             RGBColor[
              0.7458330289184139, 0.8016031181321035, 0.975242558346466], 
             UndirectedEdge[81, 285] -> 
             RGBColor[
              0.7447578743648747, 0.7970183689788182, 0.8706781816002115], 
             UndirectedEdge[79, 164] -> 
             RGBColor[
              0.632584545363712, 0.6992971014445633, 0.9021076697788852], 
             UndirectedEdge[123, 157] -> 
             RGBColor[
              0.8538957824053183, 0.7848685826370371, 0.6186528000706553], 
             UndirectedEdge[85, 165] -> 
             RGBColor[
              0.9808330098523415, 0.9848699286923042, 0.9013890861595835], 
             UndirectedEdge[59, 62] -> 
             RGBColor[
              0.6063470428277717, 0.6686582569030453, 0.7895339749202653], 
             UndirectedEdge[38, 48] -> 
             RGBColor[
              0.8790642677419367, 0.9045039564807253, 0.8984524948513315], 
             UndirectedEdge[262, 291] -> 
             RGBColor[
              0.9803894879098052, 0.9449632911732271, 0.42491425051051923`], 
             UndirectedEdge[26, 170] -> 
             RGBColor[
              0.7787554706508877, 0.7907814335305721, 0.6456657940039447], 
             UndirectedEdge[43, 139] -> 
             RGBColor[
              0.8326274053226963, 0.7981320772084635, 0.6231493363103249], 
             UndirectedEdge[52, 281] -> 
             RGBColor[
              0.6361336817036067, 0.545087555779611, 0.5868351106056022], 
             UndirectedEdge[124, 142] -> 
             RGBColor[
              0.9753741419575146, 0.9780185764133456, 0.7414167571807774], 
             UndirectedEdge[166, 271] -> 
             RGBColor[
              0.6872275030358019, 0.7544038172226264, 0.9702687587626951], 
             UndirectedEdge[37, 150] -> 
             RGBColor[
              0.9604899222512696, 0.9677747779793783, 0.845812064866305], 
             UndirectedEdge[51, 66] -> 
             RGBColor[
              0.9563399833890469, 0.9669590116150428, 0.9587891991530055], 
             UndirectedEdge[60, 125] -> 
             RGBColor[
              0.9603256329619614, 0.9698299629680909, 0.9474953845345834], 
             UndirectedEdge[215, 223] -> 
             RGBColor[
              0.9743597585822635, 0.9228330290545712, 0.49732211710138463`], 
             UndirectedEdge[237, 282] -> 
             RGBColor[
              0.984570086989899, 0.9737619177050504, 0.6500473378989897], 
             UndirectedEdge[143, 172] -> 
             RGBColor[
              0.8558990841537667, 0.8880194132827013, 0.9860951359947405], 
             UndirectedEdge[177, 285] -> 
             RGBColor[
              0.967332826655684, 0.9739154057963765, 0.8845596315590591], 
             UndirectedEdge[244, 270] -> 
             RGBColor[
              0.579758941556527, 0.646122285447223, 0.9307935317892895], 
             UndirectedEdge[147, 272] -> 
             RGBColor[
              0.9870700761511353, 0.9885251893066349, 0.8462135226259655], 
             UndirectedEdge[46, 114] -> 
             RGBColor[
              0.9921146878530762, 0.9910072350310377, 0.7803435590156105], 
             UndirectedEdge[104, 128] -> 
             RGBColor[
              0.6971360442962964, 0.7504522439703705, 0.6800917954962963], 
             UndirectedEdge[199, 220] -> 
             RGBColor[
              0.9048138307831124, 0.5662836085733279, 0.290102282800061], 
             UndirectedEdge[112, 146] -> 
             RGBColor[
              0.8628361072371222, 0.8588558144033901, 0.6557977585445506], 
             UndirectedEdge[191, 203] -> 
             RGBColor[
              0.9906241976941008, 0.9888807554025463, 0.6952747909784232], 
             UndirectedEdge[31, 96] -> 
             RGBColor[
              0.9894072710735309, 0.9898876486152581, 0.8252124616227006], 
             UndirectedEdge[59, 228] -> 
             RGBColor[
              0.5965330277553764, 0.6367891317699438, 0.6463204336538857], 
             UndirectedEdge[129, 289] -> 
             RGBColor[
              0.9896978070408737, 0.9900077927041883, 0.8203975287608483], 
             UndirectedEdge[54, 106] -> 
             RGBColor[
              0.8504804405275879, 0.8804217479334453, 0.7905270389325363], 
             UndirectedEdge[102, 142] -> 
             RGBColor[
              0.9930281364238551, 0.9897827948466733, 0.6487441691423824], 
             UndirectedEdge[74, 90] -> 
             RGBColor[
              0.5712017236608511, 0.6627317790556231, 0.9594098526508235], 
             UndirectedEdge[143, 174] -> 
             RGBColor[
              0.9276807633311712, 0.9447235748594122, 0.9774352090905443], 
             UndirectedEdge[144, 292] -> 
             RGBColor[
              0.8662033517400856, 0.894416986732154, 0.8953602961554862], 
             UndirectedEdge[59, 255] -> 
             RGBColor[
              0.5816910239326616, 0.6526531917145421, 0.9566971584738302], 
             UndirectedEdge[254, 258] -> 
             RGBColor[
              0.7681155618604225, 0.7812529410497704, 0.6435048939673093], 
             UndirectedEdge[46, 108] -> 
             RGBColor[
              0.9919838406748971, 0.9899211565168724, 0.7074987217942388], 
             UndirectedEdge[222, 278] -> 
             RGBColor[
              0.8481220018254074, 0.8756205274203813, 0.6955985531263933], 
             UndirectedEdge[115, 294] -> 
             RGBColor[
              0.9871021509812821, 0.9670994035090704, 0.4941268034705151], 
             UndirectedEdge[89, 177] -> 
             RGBColor[
              0.8801582811796982, 0.5455676279286694, 0.5727962188477366], 
             UndirectedEdge[45, 195] -> 
             RGBColor[
              0.9940173446310014, 0.990638305207133, 0.6648024382277091], 
             UndirectedEdge[205, 231] -> 
             RGBColor[
              0.989955886564609, 0.9900795663670783, 0.8135800705251026], 
             UndirectedEdge[148, 244] -> 
             RGBColor[
              0.9806668389802289, 0.9736432533610822, 0.6652065605619145], 
             UndirectedEdge[20, 297] -> 
             RGBColor[
              0.9368454720544506, 0.949225087923575, 0.863480475439635], 
             UndirectedEdge[6, 34] -> 
             RGBColor[
              0.959432621340273, 0.9652932854939251, 0.7128948180564577], 
             UndirectedEdge[13, 245] -> 
             RGBColor[
              0.9085765354479234, 0.7602291024399528, 0.6096735262726196], 
             UndirectedEdge[104, 201] -> 
             RGBColor[
              0.9509522953594123, 0.8333735138997245, 0.3308261449586776], 
             UndirectedEdge[55, 253] -> 
             RGBColor[
              0.7766889623535784, 0.8255911506947033, 0.9783458229842414], 
             UndirectedEdge[52, 141] -> 
             RGBColor[
              0.6758589590837107, 0.7412728890873144, 0.943177593237497], 
             UndirectedEdge[160, 299] -> 
             RGBColor[
              0.9754543400329219, 0.9435091236126201, 0.6180679749739371], 
             UndirectedEdge[229, 284] -> 
             RGBColor[
              0.9804302944316743, 0.9814552327187257, 0.7063395639517742], 
             UndirectedEdge[27, 268] -> 
             RGBColor[
              0.9146242626813712, 0.9311886212755416, 0.8402923590578186], 
             UndirectedEdge[193, 236] -> 
             RGBColor[
              0.6379969627450142, 0.7131990574221394, 0.9670126745839691], 
             UndirectedEdge[78, 193] -> 
             RGBColor[
              0.6936990823563853, 0.7166083414593836, 0.6328278949747297], 
             UndirectedEdge[175, 177] -> 
             RGBColor[
              0.9688290272241427, 0.9739979566397805, 0.8207900685366253], 
             UndirectedEdge[36, 67] -> 
             RGBColor[
              0.8371853665406748, 0.8730129027608777, 0.9843326816964908], 
             UndirectedEdge[37, 239] -> 
             RGBColor[
              0.949598042320714, 0.9325844163127115, 0.671655255352416], 
             UndirectedEdge[49, 280] -> 
             RGBColor[
              0.9789776199988889, 0.9827258699328889, 0.8704814504511111], 
             UndirectedEdge[263, 276] -> 
             RGBColor[
              0.9300977330884603, 0.9453619774961739, 0.9287255961371288], 
             UndirectedEdge[13, 73] -> 
             RGBColor[
              0.8939989461607369, 0.6115557963385725, 0.23326246116397756`], 
             UndirectedEdge[136, 240] -> 
             RGBColor[
              0.9708818228861293, 0.935623515474393, 0.6165528600389576], 
             UndirectedEdge[79, 241] -> 
             RGBColor[
              0.9871905275859341, 0.9789898666297481, 0.6352653060751813], 
             UndirectedEdge[78, 226] -> 
             RGBColor[
              0.9431118129003885, 0.9164697016442187, 0.654938343208294], 
             UndirectedEdge[3, 74] -> 
             RGBColor[
              0.5924858476114684, 0.6793590984511786, 0.961531255214774], 
             UndirectedEdge[148, 203] -> 
             RGBColor[
              0.9900940553535353, 0.9776123002020201, 0.46999344161616136`], 
             UndirectedEdge[90, 257] -> 
             RGBColor[
              0.8093469986666668, 0.8232627038933334, 0.6595100915200001], 
             UndirectedEdge[34, 87] -> 
             RGBColor[
              0.7937834946819495, 0.8396882188289385, 0.9798525592366809], 
             UndirectedEdge[146, 235] -> 
             RGBColor[
              0.4676486800766285, 0.5574977705350774, 0.95492629344167], 
             UndirectedEdge[181, 256] -> 
             RGBColor[
              0.9266540180922266, 0.9443356499037958, 0.9922724762381533], 
             UndirectedEdge[68, 287] -> 
             RGBColor[
              0.9700906016565279, 0.976596132101843, 0.9078346367439598], 
             UndirectedEdge[17, 144] -> 
             RGBColor[
              0.8395349437839814, 0.873583423749438, 0.8927022384808634], 
             UndirectedEdge[163, 216] -> 
             RGBColor[
              0.8506939999816172, 0.8838175138555752, 0.9649706124999351], 
             UndirectedEdge[67, 258] -> 
             RGBColor[
              0.7093229148231428, 0.7719625627476661, 0.9723683484239316], 
             UndirectedEdge[232, 240] -> 
             RGBColor[
              0.9775715357052295, 0.9827934685689755, 0.922849719157415], 
             UndirectedEdge[133, 210] -> 
             RGBColor[
              0.9055915203383316, 0.925320726366782, 0.9046476866666666], 
             UndirectedEdge[58, 154] -> 
             RGBColor[
              0.9193959673951638, 0.9375532704826038, 0.957082686164677], 
             UndirectedEdge[94, 124] -> 
             RGBColor[
              0.8395389570604374, 0.875125909242256, 0.9650128990607381], 
             UndirectedEdge[50, 213] -> 
             RGBColor[
              0.9926579137128864, 0.9905962337312519, 0.7251366444138352], 
             UndirectedEdge[15, 212] -> 
             RGBColor[
              0.9662878061532358, 0.9247829637601812, 0.6085900881341455], 
             UndirectedEdge[11, 139] -> 
             RGBColor[
              0.7192351158865165, 0.7805912060106674, 0.9726502927834195], 
             UndirectedEdge[167, 286] -> 
             RGBColor[
              0.8317709073265572, 0.8692832569825825, 0.9756689775707046], 
             UndirectedEdge[113, 288] -> 
             RGBColor[
              0.5915735543209877, 0.6543819913580248, 0.8525611950617284], 
             UndirectedEdge[73, 171] -> 
             RGBColor[
              0.948705987267592, 0.8211098005720808, 0.45189390637942406`], 
             UndirectedEdge[31, 110] -> 
             RGBColor[
              0.9815800283950618, 0.9522452967901236, 0.559424672345679], 
             UndirectedEdge[202, 275] -> 
             RGBColor[
              0.917884917355353, 0.9330829902394857, 0.7834060672983663], 
             UndirectedEdge[103, 241] -> 
             RGBColor[
              0.9497779305777778, 0.9509480135229629, 0.6984766535585183], 
             UndirectedEdge[9, 20] -> 
             RGBColor[
              0.8925809187891214, 0.9171838124515805, 0.989616358922141], 
             UndirectedEdge[71, 207] -> 
             RGBColor[
              0.9333894186189164, 0.917707939830303, 0.6672373794644628], 
             UndirectedEdge[160, 168] -> 
             RGBColor[
              0.9836119526585501, 0.9872926513727882, 0.9123673600228972], 
             UndirectedEdge[6, 114] -> 
             RGBColor[
              0.9934600621173633, 0.9892262687259359, 0.5881492345440037], 
             UndirectedEdge[95, 96] -> 
             RGBColor[
              0.8141957475144811, 0.8544148193083376, 0.9189374542612844], 
             UndirectedEdge[198, 278] -> 
             RGBColor[
              0.5615391133739646, 0.6529995245348592, 0.9595484777881982], 
             UndirectedEdge[86, 281] -> 
             RGBColor[
              0.9404069189603346, 0.7852207822796182, 0.3642446752052782], 
             UndirectedEdge[107, 165] -> 
             RGBColor[
              0.9335594221980203, 0.9481972674577361, 0.9323139683818058], 
             UndirectedEdge[155, 184] -> 
             RGBColor[
              0.9910263192592592, 0.9887422414814815, 0.6664547429629625], 
             UndirectedEdge[247, 285] -> 
             RGBColor[
              0.9508210322158119, 0.9609375589376659, 0.8895100747140661], 
             UndirectedEdge[34, 227] -> 
             RGBColor[
              0.825036851966106, 0.8641035790736347, 0.9829676018115363], 
             UndirectedEdge[116, 152] -> 
             RGBColor[
              0.893751475326953, 0.9181002522219524, 0.9891410256360682], 
             UndirectedEdge[146, 204] -> 
             RGBColor[
              0.8689018236321839, 0.8976375487572996, 0.9463321841083367], 
             UndirectedEdge[36, 58] -> 
             RGBColor[
              0.8442057488657824, 0.8786107650637168, 0.9850022920298287], 
             UndirectedEdge[105, 129] -> 
             RGBColor[
              0.9000880414408738, 0.920997626730855, 0.9037101855608485], 
             UndirectedEdge[87, 187] -> 
             RGBColor[
              0.771183212102498, 0.8216673669684119, 0.9776969241087423], 
             UndirectedEdge[119, 168] -> 
             RGBColor[
              0.6412966158494122, 0.709532347364225, 0.9270191219399315], 
             UndirectedEdge[20, 37] -> 
             RGBColor[
              0.9025120221218763, 0.9251026046765007, 0.9905635964236197], 
             UndirectedEdge[150, 200] -> 
             RGBColor[
              0.8983676946452704, 0.9183878202852853, 0.8398476174418168], 
             UndirectedEdge[1, 43] -> 
             RGBColor[
              0.935150333042963, 0.8790871238826667, 0.6331387553884444], 
             UndirectedEdge[187, 213] -> 
             RGBColor[
              0.9378186030652518, 0.9493819532539579, 0.8180879659480292], 
             UndirectedEdge[41, 222] -> 
             RGBColor[
              0.9842927600217872, 0.9821937456043798, 0.6714793813355926], 
             UndirectedEdge[196, 263] -> 
             RGBColor[
              0.930809468253024, 0.9456562982774803, 0.9169303025487474], 
             UndirectedEdge[148, 172] -> 
             RGBColor[
              0.8980806631886736, 0.9088811159002771, 0.6921556819698367], 
             UndirectedEdge[96, 171] -> 
             RGBColor[
              0.9906083149209226, 0.9898722363606527, 0.7680856282135169], 
             UndirectedEdge[178, 208] -> 
             RGBColor[
              0.9831512000987654, 0.9857649040395062, 0.8601200334814814], 
             UndirectedEdge[25, 270] -> 
             RGBColor[
              0.5899938266301665, 0.6518188539703417, 0.8234901665213521], 
             UndirectedEdge[47, 217] -> 
             RGBColor[
              0.9806417159491382, 0.9832262341982149, 0.8339920142601569], 
             UndirectedEdge[33, 142] -> 
             RGBColor[
              0.8126510340024896, 0.850185052685726, 0.7449359752797469], 
             UndirectedEdge[26, 62] -> 
             RGBColor[
              0.7919664883687945, 0.8341094462411348, 0.8020760490780141], 
             UndirectedEdge[48, 177] -> 
             RGBColor[
              0.8556827702057614, 0.8879912136076819, 0.9794609175034293], 
             UndirectedEdge[238, 300] -> 
             RGBColor[
              0.597041081053498, 0.5736241294759945, 0.5994379169602195], 
             UndirectedEdge[25, 139] -> 
             RGBColor[
              0.8584506431543426, 0.8872936217593309, 0.8430219729376354], 
             UndirectedEdge[3, 30] -> 
             RGBColor[
              0.8121947861728396, 0.854120577777778, 0.9803153706172839], 
             UndirectedEdge[95, 171] -> 
             RGBColor[
              0.8182758511525394, 0.8555899722656346, 0.8140971493528568], 
             UndirectedEdge[21, 50] -> 
             RGBColor[
              0.8453795426997246, 0.8780034985491277, 0.8866749294214875], 
             UndirectedEdge[122, 232] -> 
             RGBColor[
              0.6381231818865054, 0.7071656055107103, 0.9323909178749977], 
             UndirectedEdge[127, 136] -> 
             RGBColor[
              0.8925599822760477, 0.8742753360553631, 0.647342540991926], 
             UndirectedEdge[41, 290] -> 
             RGBColor[
              0.9764260045597308, 0.9819391333162979, 0.9247888045843715], 
             UndirectedEdge[123, 259] -> 
             RGBColor[
              0.9547288740235977, 0.8636182654957665, 0.5805229256441198], 
             UndirectedEdge[20, 185] -> 
             RGBColor[
              0.7201259162334236, 0.7805212215101954, 0.9734624682090697], 
             UndirectedEdge[163, 211] -> 
             RGBColor[
              0.8574868776712334, 0.8584291216766541, 0.6607438900352163], 
             UndirectedEdge[33, 37] -> 
             RGBColor[
              0.7789209056589856, 0.8279142330633289, 0.9784816793129099], 
             UndirectedEdge[7, 9] -> 
             RGBColor[
              0.9118899226678583, 0.9325802880155378, 0.9914580689494461], 
             UndirectedEdge[105, 263] -> 
             RGBColor[0.8421324555555557, 0.8770318496, 0.9847848298666666], 
             UndirectedEdge[15, 49] -> 
             RGBColor[
              0.9829296498291358, 0.9856732873094322, 0.8637916948029629], 
             UndirectedEdge[20, 237] -> 
             RGBColor[
              0.9318186864678288, 0.9330209519193445, 0.6914575392934257], 
             UndirectedEdge[26, 220] -> 
             RGBColor[
              0.7048481227831125, 0.41718136163999464`, 0.5639318502667277], 
             UndirectedEdge[101, 187] -> 
             RGBColor[
              0.8975904907516784, 0.9211783091533152, 0.9900941763680273], 
             UndirectedEdge[93, 94] -> 
             RGBColor[
              0.8307500112358527, 0.7906888352586217, 0.6216387409599475], 
             UndirectedEdge[143, 297] -> 
             RGBColor[
              0.9484624465517147, 0.958488148053321, 0.8645885128377795], 
             UndirectedEdge[208, 268] -> 
             RGBColor[
              0.9849713157520597, 0.9862693180218909, 0.8119108077476718], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.8130879602674568, 0.8511195937864693, 0.7924927028250863], 
             UndirectedEdge[224, 288] -> 
             RGBColor[
              0.5493451341855369, 0.6235898668922978, 0.9626332733073615], 
             UndirectedEdge[1, 75] -> 
             RGBColor[
              0.892391911368828, 0.9170331030651084, 0.9895983312256644], 
             UndirectedEdge[36, 113] -> 
             RGBColor[
              0.9086243004829642, 0.9270966980379032, 0.8770467283342875], 
             UndirectedEdge[29, 244] -> 
             RGBColor[
              0.8974729017633414, 0.5687173350010768, 0.5473959708286424], 
             UndirectedEdge[36, 96] -> 
             RGBColor[
              0.905548085136742, 0.9258246039371119, 0.9280275776113092], 
             UndirectedEdge[58, 138] -> 
             RGBColor[
              0.9001741909732192, 0.9232177010998878, 0.9896201398048261], 
             UndirectedEdge[71, 136] -> 
             RGBColor[0.9674934, 0.9020097466666663, 0.3282184266666664], 
             UndirectedEdge[144, 252] -> 
             RGBColor[
              0.9666356089207565, 0.9015040847295686, 0.5444946843583793], 
             UndirectedEdge[58, 198] -> 
             RGBColor[
              0.6408922723273136, 0.7153453157392103, 0.9673635855892255], 
             UndirectedEdge[110, 154] -> 
             RGBColor[
              0.9729110609876543, 0.9471247575308643, 0.6343201824691358], 
             UndirectedEdge[119, 152] -> 
             RGBColor[
              0.575371676718309, 0.6581852831427717, 0.9630186559422382], 
             UndirectedEdge[38, 90] -> 
             RGBColor[
              0.8171871053825401, 0.856165046961713, 0.8922851575823054], 
             UndirectedEdge[66, 179] -> 
             RGBColor[
              0.9402769821922601, 0.9544856738835714, 0.9688670201980367], 
             UndirectedEdge[6, 21] -> 
             RGBColor[
              0.8462805511531759, 0.8760387755615648, 0.7018448964172821], 
             UndirectedEdge[176, 287] -> 
             RGBColor[
              0.9734238284017744, 0.9773677795071605, 0.8084917581444069], 
             UndirectedEdge[142, 237] -> 
             RGBColor[
              0.9890013439975512, 0.9739921817128863, 0.46014875843036407`], 
             UndirectedEdge[108, 221] -> 
             RGBColor[
              0.9940140440823045, 0.9896049705020576, 0.5898438232757204], 
             UndirectedEdge[44, 256] -> 
             RGBColor[
              0.890270283398349, 0.9153413745115055, 0.9893959684558404], 
             UndirectedEdge[89, 112] -> 
             RGBColor[
              0.8933104271604938, 0.5211185438683127, 0.24973096510288056`], 
             UndirectedEdge[83, 184] -> 
             RGBColor[
              0.9903713214507999, 0.9884713830550077, 0.6773097517291251], 
             UndirectedEdge[259, 261] -> 
             RGBColor[
              0.9094991381519928, 0.929320478414285, 0.9434034163996752], 
             UndirectedEdge[207, 231] -> 
             RGBColor[
              0.9451522627966942, 0.9556966680080808, 0.8566483315533515], 
             UndirectedEdge[112, 280] -> 
             RGBColor[
              0.9681730953549382, 0.9415261941460905, 0.6379567259362139], 
             UndirectedEdge[174, 194] -> 
             RGBColor[
              0.9727709879430602, 0.9778373048905173, 0.8693591504314194], 
             UndirectedEdge[125, 200] -> 
             RGBColor[
              0.8932616391591592, 0.9165064195075077, 0.941192876816817], 
             UndirectedEdge[99, 222] -> 
             RGBColor[
              0.7027378092409315, 0.7574952115440491, 0.683788076792922], 
             UndirectedEdge[108, 169] -> 
             RGBColor[
              0.9937869056241426, 0.9891191443072702, 0.565121203840878], 
             UndirectedEdge[15, 57] -> 
             RGBColor[
              0.98444356786772, 0.9851405186607846, 0.7544687074197185], 
             UndirectedEdge[4, 78] -> 
             RGBColor[
              0.960815080316636, 0.9300392194654126, 0.6376763796759579], 
             UndirectedEdge[52, 86] -> 
             RGBColor[
              0.688920417290816, 0.7477170137413027, 0.7231399206746698], 
             UndirectedEdge[20, 282] -> 
             RGBColor[
              0.9318108934577278, 0.9471431602910618, 0.9469164718590822], 
             UndirectedEdge[42, 55] -> 
             RGBColor[
              0.8570949214462349, 0.8863381521095437, 0.850774170442911], 
             UndirectedEdge[136, 165] -> 
             RGBColor[
              0.9748027345436994, 0.9381917830132915, 0.5939759713447685], 
             UndirectedEdge[161, 269] -> 
             RGBColor[
              0.9676706710082645, 0.9026077234027547, 0.32890709105895305`], 
             UndirectedEdge[57, 243] -> 
             RGBColor[
              0.9712377887473069, 0.9115583217728533, 0.42954857002770064`], 
             UndirectedEdge[57, 146] -> 
             RGBColor[
              0.8751545499196571, 0.8995227215415409, 0.7789994956762034], 
             UndirectedEdge[4, 130] -> 
             RGBColor[
              0.9241425890975001, 0.9418036445626348, 0.9736762222291986], 
             UndirectedEdge[31, 58] -> 
             RGBColor[
              0.9280649348025711, 0.9426738097418631, 0.8821871760412201], 
             UndirectedEdge[95, 140] -> 
             RGBColor[
              0.7269764196508268, 0.7866311776066598, 0.9734270654780899], 
             UndirectedEdge[58, 96] -> 
             RGBColor[
              0.9251858750119046, 0.9414832445299608, 0.9299006475404641], 
             UndirectedEdge[16, 94] -> 
             RGBColor[
              0.8580265493629926, 0.8863865280220931, 0.7968619809526952], 
             UndirectedEdge[113, 135] -> 
             RGBColor[
              0.9728743633537325, 0.9778800532794572, 0.8676459523495912], 
             UndirectedEdge[47, 262] -> 
             RGBColor[
              0.9813246128326446, 0.9469634288275481, 0.5266968274395315], 
             UndirectedEdge[153, 211] -> 
             RGBColor[
              0.8921432846743296, 0.8855029702259215, 0.664198116802748], 
             UndirectedEdge[89, 111] -> 
             RGBColor[
              0.8209434794953099, 0.498539562235434, 0.5736736110503369], 
             UndirectedEdge[137, 256] -> 
             RGBColor[
              0.893548187230082, 0.9179550860506003, 0.9897086178495305], 
             UndirectedEdge[136, 181] -> 
             RGBColor[
              0.9498170835827664, 0.91991346739229, 0.652209969115646], 
             UndirectedEdge[288, 291] -> 
             RGBColor[
              0.5919286871604938, 0.6528974279012347, 0.7280887120987656], 
             UndirectedEdge[121, 296] -> 
             RGBColor[
              0.8339861711111112, 0.8679633111111111, 0.8230845155555556], 
             UndirectedEdge[241, 277] -> 
             RGBColor[0.8967123, 0.9087475739974455, 0.6933853114687099], 
             UndirectedEdge[217, 262] -> 
             RGBColor[
              0.9667051712817828, 0.937917243025763, 0.6351044191996884], 
             UndirectedEdge[75, 142] -> 
             RGBColor[
              0.9257041685456384, 0.9389707235619948, 0.7560127702675841], 
             UndirectedEdge[57, 112] -> 
             RGBColor[
              0.9816202970035224, 0.9487769948747762, 0.45844566733741404`], 
             UndirectedEdge[274, 287] -> 
             RGBColor[
              0.9584565211513851, 0.9685375220126822, 0.955206452802825], 
             UndirectedEdge[97, 252] -> 
             RGBColor[
              0.9532822460695598, 0.8503256115974143, 0.2925230082917818], 
             UndirectedEdge[18, 69] -> 
             RGBColor[
              0.9927270496981941, 0.9897963642465871, 0.6637706592090602], 
             UndirectedEdge[106, 167] -> 
             RGBColor[
              0.9693826579571473, 0.974087299275002, 0.794180269564823], 
             UndirectedEdge[256, 296] -> 
             RGBColor[
              0.7950461011761267, 0.8405990225115055, 0.9799984537891737], 
             UndirectedEdge[131, 183] -> 
             RGBColor[
              0.8965607134556248, 0.8829476872956254, 0.6557892814310124], 
             UndirectedEdge[172, 183] -> 
             RGBColor[
              0.8175492495485711, 0.8574402961470473, 0.9824372945347956], 
             UndirectedEdge[1, 143] -> 
             RGBColor[
              0.9145468677858338, 0.9346988639317575, 0.9917114907466815], 
             UndirectedEdge[17, 252] -> 
             RGBColor[
              0.8161928270023446, 0.7849639622146984, 0.6214383707060481], 
             UndirectedEdge[126, 214] -> 
             RGBColor[
              0.9624926500385595, 0.8921493245211383, 0.5757609975475524], 
             UndirectedEdge[84, 134] -> 
             RGBColor[
              0.9077967799731754, 0.9278978705638922, 0.9404101106803417], 
             UndirectedEdge[45, 234] -> 
             RGBColor[
              0.9741657506416705, 0.978608627971346, 0.8549567976040235], 
             UndirectedEdge[32, 156] -> 
             RGBColor[
              0.9382805457844438, 0.7939003264655535, 0.5631575588545384], 
             UndirectedEdge[140, 149] -> 
             RGBColor[
              0.8777228300617286, 0.9052027280246915, 0.9813363374074073], 
             UndirectedEdge[16, 150] -> 
             RGBColor[
              0.9946569768597407, 0.9909801387025186, 0.6598230883784815], 
             UndirectedEdge[209, 218] -> 
             RGBColor[
              0.9678422329913976, 0.9739554907530974, 0.8684790822278363], 
             UndirectedEdge[82, 281] -> 
             RGBColor[
              0.8735277502664442, 0.5186008769518625, 0.2161807935148508], 
             UndirectedEdge[178, 182] -> 
             RGBColor[
              0.9327427835555555, 0.7560176610765431, 0.5048173431111111], 
             UndirectedEdge[41, 157] -> 
             RGBColor[
              0.8802705139126485, 0.9065888698079303, 0.9510093959175783], 
             UndirectedEdge[254, 288] -> 
             RGBColor[
              0.578927267415978, 0.6095885743831037, 0.6309836939673092], 
             UndirectedEdge[129, 161] -> 
             RGBColor[
              0.9835496601075404, 0.9631884741975215, 0.5967918644941818], 
             UndirectedEdge[20, 283] -> 
             RGBColor[
              0.9335483330191179, 0.9478616361998566, 0.9181226019773991], 
             UndirectedEdge[162, 210] -> 
             RGBColor[
              0.9747868047289504, 0.9336990658669742, 0.5632320078969626], 
             UndirectedEdge[203, 244] -> 
             RGBColor[
              0.9841042943337642, 0.9846038335631024, 0.7325361621780762], 
             UndirectedEdge[121, 246] -> 
             RGBColor[
              0.9850892844444444, 0.9599317271111111, 0.5184330008888889], 
             UndirectedEdge[24, 259] -> 
             RGBColor[
              0.7643533707632557, 0.8143089676140332, 0.9299976742894743], 
             UndirectedEdge[141, 281] -> 
             RGBColor[
              0.9273454607532292, 0.77877665762563, 0.5842823477681053], 
             UndirectedEdge[110, 138] -> 
             RGBColor[
              0.9536892845657097, 0.9327891881481483, 0.6668576361092848], 
             UndirectedEdge[67, 109] -> 
             RGBColor[
              0.9223185938759553, 0.9372166695650366, 0.8323360652472511], 
             UndirectedEdge[154, 245] -> 
             RGBColor[
              0.9534135652999794, 0.9646779796688073, 0.9603273150207065], 
             UndirectedEdge[193, 249] -> 
             RGBColor[
              0.6957617299640446, 0.7584039727788281, 0.9428740182704642], 
             UndirectedEdge[82, 137] -> 
             RGBColor[
              0.8647934113005035, 0.6769548183319939, 0.5959493716737688], 
             UndirectedEdge[100, 125] -> 
             RGBColor[
              0.9879897496313383, 0.9893014670702722, 0.8487044603477296], 
             UndirectedEdge[104, 218] -> 
             RGBColor[
              0.9656649127761553, 0.9660049494127516, 0.6981371160126915], 
             UndirectedEdge[73, 149] -> 
             RGBColor[
              0.9230398302720523, 0.8042239339377975, 0.6106550043565089], 
             UndirectedEdge[108, 219] -> 
             RGBColor[
              0.9858519819176533, 0.9629607180931081, 0.4826011486157629], 
             UndirectedEdge[58, 140] -> 
             RGBColor[
              0.8379665471482503, 0.8736996028282829, 0.9843902587572697], 
             UndirectedEdge[9, 63] -> 
             RGBColor[
              0.8041702564925076, 0.8476392459027233, 0.980931120244247], 
             UndirectedEdge[48, 217] -> 
             RGBColor[
              0.8671951262252015, 0.8965771098772273, 0.9599735016658497], 
             UndirectedEdge[8, 271] -> 
             RGBColor[
              0.9016254548086787, 0.9202044214928776, 0.7818323277703266], 
             UndirectedEdge[18, 222] -> 
             RGBColor[
              0.9923458224398114, 0.9851751125763701, 0.48154098449032234`], 
             UndirectedEdge[215, 234] -> 
             RGBColor[
              0.9746929881386117, 0.9787100605002654, 0.8377439748184399], 
             UndirectedEdge[15, 146] -> 
             RGBColor[
              0.8656593781013199, 0.8952193381893985, 0.9518207986268551], 
             UndirectedEdge[54, 151] -> 
             RGBColor[
              0.8411912441811926, 0.8760927981854774, 0.9487823089552786], 
             UndirectedEdge[195, 255] -> 
             RGBColor[
              0.9695678675477584, 0.9740487369044835, 0.7798470527797271], 
             UndirectedEdge[1, 11] -> 
             RGBColor[
              0.8217580436067831, 0.8615462526848707, 0.9826397118615391], 
             UndirectedEdge[32, 178] -> 
             RGBColor[
              0.9882679276939088, 0.9894165008479952, 0.8440943299491886], 
             UndirectedEdge[126, 189] -> 
             RGBColor[
              0.8327142703294255, 0.7910202971617457, 0.6215681176127779], 
             UndirectedEdge[61, 273] -> 
             RGBColor[
              0.9918037488888889, 0.9892910382222222, 0.6700937311111106], 
             UndirectedEdge[54, 194] -> 
             RGBColor[
              0.8496193948428159, 0.8810025761314781, 0.8728990043949264], 
             UndirectedEdge[38, 144] -> 
             RGBColor[
              0.98986914156707, 0.9900786439338669, 0.8175580722622361], 
             UndirectedEdge[4, 220] -> 
             RGBColor[
              0.8885818743497483, 0.5620864213137403, 0.562446161088519], 
             UndirectedEdge[45, 200] -> 
             RGBColor[
              0.8979062346049755, 0.9184270790850111, 0.8642199104519332], 
             UndirectedEdge[2, 202] -> 
             RGBColor[
              0.8618239552050133, 0.8926590445651486, 0.9866827322784231], 
             UndirectedEdge[17, 175] -> 
             RGBColor[
              0.8418763269772291, 0.8740154793283952, 0.8149258121031548], 
             UndirectedEdge[233, 262] -> 
             RGBColor[
              0.9746405703789409, 0.9438354506793999, 0.6216718584117538], 
             UndirectedEdge[67, 138] -> 
             RGBColor[
              0.8931538086481117, 0.9176198387970487, 0.988950529471488], 
             UndirectedEdge[39, 192] -> 
             RGBColor[
              0.9315319358881746, 0.7498895727442778, 0.308727778970173], 
             UndirectedEdge[164, 168] -> 
             RGBColor[
              0.6305818534486736, 0.6982704527258747, 0.9264089320722799], 
             UndirectedEdge[19, 253] -> 
             RGBColor[
              0.7888042265284029, 0.8350556871474943, 0.9795533592936072], 
             UndirectedEdge[24, 74] -> 
             RGBColor[
              0.5208840308400151, 0.6219161476509265, 0.9554250454502521], 
             UndirectedEdge[80, 133] -> 
             RGBColor[
              0.8932465250064605, 0.9169681347270915, 0.9638012011930136], 
             UndirectedEdge[198, 222] -> 
             RGBColor[
              0.7045238943651253, 0.7590422287073771, 0.6839018845576625], 
             UndirectedEdge[111, 212] -> 
             RGBColor[
              0.8910975876238543, 0.8658404583412942, 0.6365096939992974], 
             UndirectedEdge[126, 184] -> 
             RGBColor[
              0.9660839882270436, 0.8918195099890422, 0.38431732941924124`], 
             UndirectedEdge[132, 294] -> 
             RGBColor[
              0.9619698032321684, 0.8798243759299907, 0.32526428606191315`], 
             UndirectedEdge[39, 136] -> 
             RGBColor[
              0.9204606667523721, 0.7125435822916028, 0.26571798901132515`], 
             UndirectedEdge[133, 162] -> 
             RGBColor[
              0.8910442489427144, 0.8691624116109189, 0.6414542032141484], 
             UndirectedEdge[22, 271] -> 
             RGBColor[
              0.8885843150062096, 0.9132539698385567, 0.9604583646592154], 
             UndirectedEdge[107, 110] -> 
             RGBColor[
              0.9258290506172839, 0.9105949743209878, 0.6649207743209877], 
             UndirectedEdge[40, 191] -> 
             RGBColor[
              0.9904607300460224, 0.990323280973044, 0.8077539201840891], 
             UndirectedEdge[143, 237] -> 
             RGBColor[
              0.9434356609650929, 0.9422840120490906, 0.6925655766915702], 
             UndirectedEdge[157, 261] -> 
             RGBColor[
              0.8086660465337133, 0.8505707955555556, 0.9815332908262109], 
             UndirectedEdge[35, 163] -> 
             RGBColor[
              0.8656527341349277, 0.8859744729629715, 0.6924667004040689], 
             UndirectedEdge[89, 175] -> 
             RGBColor[
              0.9059897460444444, 0.5625573287111112, 0.4122118496888887], 
             UndirectedEdge[16, 200] -> 
             RGBColor[
              0.8980093783105667, 0.9176214178766928, 0.8008470956814093], 
             UndirectedEdge[35, 189] -> 
             RGBColor[
              0.8574837424996651, 0.8795927946108683, 0.691652491661433], 
             UndirectedEdge[233, 291] -> 
             RGBColor[
              0.9876419901234568, 0.9871443041975309, 0.71877687654321], 
             UndirectedEdge[258, 290] -> 
             RGBColor[
              0.7721081637240056, 0.8210027257305901, 0.9428856809744854], 
             UndirectedEdge[157, 259] -> 
             RGBColor[
              0.8838953822165704, 0.9092031628587296, 0.9408821146332935], 
             UndirectedEdge[105, 245] -> 
             RGBColor[
              0.8713368006086215, 0.9003186016144864, 0.9875703663688546], 
             UndirectedEdge[100, 192] -> 
             RGBColor[
              0.9882949276560298, 0.9765388877451693, 0.5968647858621328], 
             UndirectedEdge[258, 278] -> 
             RGBColor[
              0.6369901381949012, 0.715214633846154, 0.9652228509562422], 
             UndirectedEdge[99, 201] -> 
             RGBColor[
              0.6634572451920597, 0.6121534427139905, 0.5980572892703375], 
             UndirectedEdge[9, 282] -> 
             RGBColor[
              0.9453323193111915, 0.9579247782372864, 0.948206157527705], 
             UndirectedEdge[84, 175] -> 
             RGBColor[
              0.9898643256888888, 0.9895404859022223, 0.7786642362666665], 
             UndirectedEdge[271, 291] -> 
             RGBColor[
              0.9013497505617651, 0.9196147179867048, 0.7518236219431662], 
             UndirectedEdge[127, 256] -> 
             RGBColor[
              0.8693969167855079, 0.8986975185668689, 0.9874050481144333], 
             UndirectedEdge[80, 116] -> 
             RGBColor[
              0.9504998104064621, 0.9626034201670367, 0.9686750886514577], 
             UndirectedEdge[202, 268] -> 
             RGBColor[
              0.9184108770086472, 0.9342079647552036, 0.8406535297127047], 
             UndirectedEdge[161, 265] -> 
             RGBColor[
              0.9863561697273682, 0.9641007874342364, 0.5322355380291534], 
             UndirectedEdge[22, 72] -> 
             RGBColor[
              0.9580703239739936, 0.9682494967901234, 0.9558601838877931], 
             UndirectedEdge[77, 162] -> 
             RGBColor[
              0.9763799104404783, 0.9319753637137191, 0.36364808365843393`], 
             UndirectedEdge[93, 164] -> 
             RGBColor[
              0.6089559988020453, 0.6042596331612693, 0.604764312205178], 
             UndirectedEdge[19, 111] -> 
             RGBColor[
              0.7838854843012981, 0.831133615611302, 0.9790842052689729], 
             UndirectedEdge[37, 142] -> 
             RGBColor[
              0.9596946796515986, 0.9660738344700425, 0.7592548155605581], 
             UndirectedEdge[43, 172] -> 
             RGBColor[
              0.8765025494108959, 0.8324076732336105, 0.6275224006365036], 
             UndirectedEdge[61, 285] -> 
             RGBColor[
              0.992554887698208, 0.9896016534232626, 0.6576454171557666], 
             UndirectedEdge[38, 257] -> 
             RGBColor[
              0.9819204507158734, 0.9571313985350463, 0.5865825263289721], 
             UndirectedEdge[174, 185] -> 
             RGBColor[
              0.7571302121316729, 0.8095795417345055, 0.9614629666479511], 
             UndirectedEdge[75, 237] -> 
             RGBColor[
              0.9212807045480871, 0.9246182511824416, 0.6904524171705531], 
             UndirectedEdge[30, 48] -> 
             RGBColor[
              0.8527878245816188, 0.8858321679012346, 0.9843613053223594], 
             UndirectedEdge[289, 298] -> 
             RGBColor[
              0.8062859717406969, 0.8472989992156741, 0.8892899782211701], 
             UndirectedEdge[123, 261] -> 
             RGBColor[
              0.8794995383407407, 0.8049858981925925, 0.6211741018370369], 
             UndirectedEdge[77, 206] -> 
             RGBColor[
              0.9836836022513203, 0.9566124311800783, 0.39202154715708826`], 
             UndirectedEdge[121, 137] -> 
             RGBColor[
              0.9324882571650663, 0.9453193746502058, 0.8327946796159122], 
             UndirectedEdge[87, 227] -> 
             RGBColor[
              0.692527761829417, 0.7597272180378526, 0.9699883533254214], 
             UndirectedEdge[123, 144] -> 
             RGBColor[
              0.9573534999573694, 0.864703615769191, 0.537026081607338], 
             UndirectedEdge[9, 37] -> 
             RGBColor[
              0.9160334479753398, 0.9358842226227253, 0.9918532820922423], 
             UndirectedEdge[178, 268] -> 
             RGBColor[
              0.9931741198014423, 0.9911970867527551, 0.7447408308587831], 
             UndirectedEdge[112, 253] -> 
             RGBColor[
              0.9018536488829083, 0.889453177639939, 0.6596557301778517], 
             UndirectedEdge[78, 220] -> 
             RGBColor[
              0.8925019315331124, 0.5247526814316613, 0.24227287912089446`], 
             UndirectedEdge[66, 67] -> 
             RGBColor[
              0.9068990600480562, 0.9278710247853439, 0.9656834041870996], 
             UndirectedEdge[20, 124] -> 
             RGBColor[
              0.9181914844277921, 0.9370473466198038, 0.9727255380438389], 
             UndirectedEdge[18, 224] -> 
             RGBColor[
              0.9509043318837309, 0.9591720081166626, 0.7671192000719771], 
             UndirectedEdge[72, 151] -> 
             RGBColor[
              0.9619491006177473, 0.971142282060121, 0.9492944267768872], 
             UndirectedEdge[25, 29] -> 
             RGBColor[
              0.907707786836981, 0.5744139035241953, 0.4400926055607049], 
             UndirectedEdge[135, 258] -> 
             RGBColor[
              0.760955570143856, 0.8126851396992104, 0.9617641128434182], 
             UndirectedEdge[130, 176] -> 
             RGBColor[
              0.9429844275116663, 0.9535235210550954, 0.8204029569500768], 
             UndirectedEdge[31, 245] -> 
             RGBColor[
              0.9620825327073868, 0.9697985189280666, 0.8854318048972496], 
             UndirectedEdge[295, 297] -> 
             RGBColor[
              0.9576437928523096, 0.9658091043724092, 0.8654642378442149], 
             UndirectedEdge[17, 30] -> 
             RGBColor[
              0.8131499164883402, 0.8548667328395063, 0.9804105690809327], 
             UndirectedEdge[22, 273] -> 
             RGBColor[
              0.9790129249382715, 0.9828759868641976, 0.8759651037037035], 
             UndirectedEdge[86, 165] -> 
             RGBColor[
              0.9897640618174712, 0.9882336031339467, 0.6883431139819416], 
             UndirectedEdge[124, 200] -> 
             RGBColor[
              0.8795217860080115, 0.9063607990968556, 0.9689980137894523], 
             UndirectedEdge[198, 258] -> 
             RGBColor[
              0.49339203073461907`, 0.5986363351331498, 0.9535261823875114], 
             UndirectedEdge[177, 217] -> 
             RGBColor[
              0.9545099183788364, 0.9655941521268843, 0.9618870218578934], 
             UndirectedEdge[52, 110] -> 
             RGBColor[
              0.6777604529800071, 0.710498083497191, 0.6435403553214476], 
             UndirectedEdge[121, 299] -> 
             RGBColor[
              0.980753538600823, 0.9453062382990398, 0.5015894470233198], 
             UndirectedEdge[173, 196] -> 
             RGBColor[
              0.9769773865016029, 0.9428423125946674, 0.5838648961084274], 
             UndirectedEdge[238, 251] -> 
             RGBColor[
              0.9612396187750033, 0.8708977743860482, 0.49506986338802983`], 
             UndirectedEdge[218, 284] -> 
             RGBColor[
              0.9549432417539331, 0.9659173239905294, 0.9611535184126915], 
             UndirectedEdge[209, 276] -> 
             RGBColor[
              0.9902194990814803, 0.990223525769853, 0.8117517415522737], 
             UndirectedEdge[8, 72] -> 
             RGBColor[
              0.9711114637764628, 0.9751999484444445, 0.7772341469989044], 
             UndirectedEdge[56, 168] -> 
             RGBColor[
              0.9700319019066606, 0.9268386945418181, 0.6006886276524583], 
             UndirectedEdge[201, 257] -> 
             RGBColor[
              0.9433129993594123, 0.8076043746997243, 0.30114892255867765`], 
             UndirectedEdge[31, 51] -> 
             RGBColor[
              0.9704854758184543, 0.976163934268723, 0.874623360673788], 
             UndirectedEdge[53, 282] -> 
             RGBColor[
              0.9856428702537878, 0.9883309721356061, 0.8875983251628787], 
             UndirectedEdge[17, 97] -> 
             RGBColor[
              0.8261815809327846, 0.8224049506172837, 0.6407305624142658], 
             UndirectedEdge[102, 162] -> 
             RGBColor[
              0.9764354990929704, 0.934380843356009, 0.535908875600907], 
             UndirectedEdge[36, 260] -> 
             RGBColor[
              0.7281163938711672, 0.7874025572422928, 0.9736376688829843], 
             UndirectedEdge[79, 168] -> 
             RGBColor[
              0.9849999854790521, 0.9878666386148822, 0.8893640640733873], 
             UndirectedEdge[142, 297] -> 
             RGBColor[
              0.9940281295841731, 0.9901963177171167, 0.6321716945765734], 
             UndirectedEdge[232, 299] -> 
             RGBColor[
              0.9716662469754787, 0.9406897202825109, 0.624737737252888], 
             UndirectedEdge[50, 169] -> 
             RGBColor[
              0.9921293400934145, 0.9894656682061922, 0.6676046679125712], 
             UndirectedEdge[92, 153] -> 
             RGBColor[
              0.8839740304273045, 0.8579152566657707, 0.632623038333184], 
             UndirectedEdge[44, 299] -> 
             RGBColor[
              0.9151388830452676, 0.8966723591879286, 0.6559591394677641], 
             UndirectedEdge[90, 252] -> 
             RGBColor[
              0.7939535727362266, 0.7675904877574147, 0.6192217696784488], 
             UndirectedEdge[7, 283] -> 
             RGBColor[
              0.9528573368978548, 0.9632581117638138, 0.9199643120047043], 
             UndirectedEdge[52, 179] -> 
             RGBColor[
              0.6506028992066129, 0.7219433832443191, 0.9688168646945878], 
             UndirectedEdge[98, 296] -> 
             RGBColor[
              0.8077548464436755, 0.8505608013225683, 0.975253181845444], 
             UndirectedEdge[18, 88] -> 
             RGBColor[
              0.9715788486947372, 0.9752995386149822, 0.7566871123764676], 
             UndirectedEdge[100, 240] -> 
             RGBColor[
              0.9848344814063567, 0.9870498127668876, 0.8585926559422429], 
             UndirectedEdge[2, 214] -> 
             RGBColor[
              0.9339079547722874, 0.9485402306355368, 0.9351720273305899], 
             UndirectedEdge[114, 169] -> 
             RGBColor[
              0.9939177528023218, 0.9902052228214355, 0.6379660410622497], 
             UndirectedEdge[37, 295] -> 
             RGBColor[
              0.9233103429197351, 0.941686621125335, 0.9925473588281996], 
             UndirectedEdge[45, 225] -> 
             RGBColor[
              0.9171199489077079, 0.9335999529916449, 0.8660917055726739], 
             UndirectedEdge[38, 74] -> 
             RGBColor[
              0.7437751757100577, 0.7966004736973358, 0.8864822874597955], 
             UndirectedEdge[38, 158] -> 
             RGBColor[
              0.9732716225028557, 0.9279568701311016, 0.55298346191556], 
             UndirectedEdge[69, 135] -> 
             RGBColor[
              0.9724686610327449, 0.9777122849436548, 0.8743694897323072], 
             UndirectedEdge[113, 224] -> 
             RGBColor[
              0.9504522218398579, 0.9604491471392113, 0.8810363128135343], 
             UndirectedEdge[124, 282] -> 
             RGBColor[
              0.9709428849498623, 0.9777883124055097, 0.9313153366494029], 
             UndirectedEdge[56, 79] -> 
             RGBColor[
              0.972034593821699, 0.9278653432605065, 0.5763873653590638], 
             UndirectedEdge[49, 146] -> 
             RGBColor[
              0.873640631881073, 0.9000554901901885, 0.8883224830594478], 
             UndirectedEdge[47, 166] -> 
             RGBColor[
              0.7802037850511974, 0.8250613815816006, 0.8422469823905168], 
             UndirectedEdge[189, 197] -> 
             RGBColor[
              0.7423786431601966, 0.7986711054141883, 0.974957023293501], 
             UndirectedEdge[125, 256] -> 
             RGBColor[
              0.9508740256205712, 0.9622973522892834, 0.9467271715669516], 
             UndirectedEdge[69, 138] -> 
             RGBColor[
              0.9641870402694134, 0.9715358657382716, 0.8883881134920009], 
             UndirectedEdge[170, 255] -> 
             RGBColor[
              0.9566384201245718, 0.9313229745832037, 0.6540839866355237], 
             UndirectedEdge[41, 104] -> 
             RGBColor[
              0.9834188366135032, 0.9792457967412636, 0.6680843539209971], 
             UndirectedEdge[185, 283] -> 
             RGBColor[
              0.7746147563168837, 0.8219806632046961, 0.9032583969329506], 
             UndirectedEdge[103, 277] -> 
             RGBColor[
              0.8591118528000001, 0.8906091415944828, 0.9863941546568582], 
             UndirectedEdge[45, 282] -> 
             RGBColor[
              0.9893273335468262, 0.989854592393665, 0.8265372333118841], 
             UndirectedEdge[222, 245] -> 
             RGBColor[
              0.9614927586835721, 0.9650910278109359, 0.7066582897834501], 
             UndirectedEdge[53, 195] -> 
             RGBColor[
              0.990332881337963, 0.9891146849490741, 0.7258635300787037], 
             UndirectedEdge[121, 136] -> 
             RGBColor[
              0.9790480044444444, 0.9395530711111109, 0.4949637688888887], 
             UndirectedEdge[92, 211] -> 
             RGBColor[
              0.9640277595460784, 0.8902884268916922, 0.3149159995803764], 
             UndirectedEdge[26, 137] -> 
             RGBColor[
              0.729789512720622, 0.7884310235390948, 0.9741490307270233], 
             UndirectedEdge[139, 148] -> 
             RGBColor[
              0.854205519100474, 0.87460551987513, 0.6877826176436581], 
             UndirectedEdge[69, 258] -> 
             RGBColor[
              0.7803561464444445, 0.8258785896888889, 0.8718059324444445], 
             UndirectedEdge[244, 272] -> 
             RGBColor[
              0.9782428395473366, 0.9832941258752599, 0.9217133768568107], 
             UndirectedEdge[100, 256] -> 
             RGBColor[0.9540605930296874, 0.963615079804, 0.8939175030257922],
              UndirectedEdge[29, 206] -> 
             RGBColor[
              0.8975578212606211, 0.5418073846619091, 0.26191405598760426`], 
             UndirectedEdge[101, 213] -> 
             RGBColor[
              0.9543170741571949, 0.9625373862636057, 0.8196616048491379], 
             UndirectedEdge[39, 107] -> 
             RGBColor[
              0.8792173544066932, 0.7225490667360475, 0.6040559860483624], 
             UndirectedEdge[134, 252] -> 
             RGBColor[
              0.886909446398291, 0.8402935249701955, 0.6284641323943462], 
             UndirectedEdge[14, 288] -> 
             RGBColor[
              0.509796690123457, 0.5920550111111113, 0.9588611074074074], 
             UndirectedEdge[155, 202] -> 
             RGBColor[
              0.9153509815035011, 0.9331908699431894, 0.9094091160391069], 
             UndirectedEdge[220, 228] -> 
             RGBColor[
              0.8975730760795113, 0.541858842748028, 0.26197331807836216`], 
             UndirectedEdge[228, 266] -> 
             RGBColor[
              0.9846492176784084, 0.9594393801067616, 0.5495129142886837], 
             UndirectedEdge[113, 249] -> 
             RGBColor[
              0.9807705373453137, 0.9837690069135803, 0.8542797894338521], 
             UndirectedEdge[109, 179] -> 
             RGBColor[
              0.955696516020159, 0.9638313186632642, 0.8355196812581882], 
             UndirectedEdge[41, 209] -> 
             RGBColor[
              0.9855961568287455, 0.9871963380816092, 0.8384263201361419], 
             UndirectedEdge[76, 261] -> 
             RGBColor[
              0.9125924456790123, 0.9258523570370369, 0.7016309288888888], 
             UndirectedEdge[114, 219] -> 
             RGBColor[
              0.9859828290958325, 0.9640467966072732, 0.5554459858371346], 
             UndirectedEdge[130, 266] -> 
             RGBColor[
              0.9429055819128738, 0.9540976438876172, 0.8658123178844567], 
             UndirectedEdge[1, 185] -> 
             RGBColor[
              0.7439963165863355, 0.7995548308068509, 0.9757392483040883], 
             UndirectedEdge[202, 208] -> 
             RGBColor[
              0.9083879573059703, 0.9287757820419549, 0.9560327323354031], 
             UndirectedEdge[8, 285] -> 
             RGBColor[
              0.9928052035500599, 0.9901370537195588, 0.6848907528594708], 
             UndirectedEdge[65, 210] -> 
             RGBColor[
              0.9789021995101268, 0.9829315897901618, 0.8823405949084928], 
             UndirectedEdge[63, 183] -> 
             RGBColor[
              0.7639159705311125, 0.8155415709505909, 0.977091630513824], 
             UndirectedEdge[51, 86] -> 
             RGBColor[
              0.9709391376601275, 0.9745499474757977, 0.7361486082492326], 
             UndirectedEdge[91, 191] -> 
             RGBColor[
              0.9553482939455038, 0.8607679248301559, 0.5550562019548544], 
             UndirectedEdge[122, 181] -> 
             RGBColor[
              0.6179795526501719, 0.6921425198084183, 0.9664888278721866], 
             UndirectedEdge[17, 42] -> 
             RGBColor[
              0.8421547617478559, 0.8746667858037507, 0.8492850749479068], 
             UndirectedEdge[90, 253] -> 
             RGBColor[
              0.7395095483890813, 0.7965463099316265, 0.9746401264616378], 
             UndirectedEdge[60, 136] -> 
             RGBColor[
              0.9495595418508502, 0.9197213931903129, 0.6526459200901386], 
             UndirectedEdge[80, 210] -> 
             RGBColor[
              0.9769890807926965, 0.9815047889831467, 0.8855790058758277], 
             UndirectedEdge[229, 259] -> 
             RGBColor[
              0.9888367343713214, 0.987635614066344, 0.6881183291218199], 
             UndirectedEdge[97, 159] -> 
             RGBColor[
              0.6442009133333333, 0.6719001566666665, 0.6268766133333331], 
             UndirectedEdge[242, 280] -> 
             RGBColor[
              0.8280682491272291, 0.8659928008950618, 0.9551577232475994], 
             UndirectedEdge[88, 99] -> 
             RGBColor[
              0.6819708354958574, 0.7476196375826611, 0.9589342046790672], 
             UndirectedEdge[21, 46] -> 
             RGBColor[
              0.8449351768888889, 0.8778197418666667, 0.8940392208888888], 
             UndirectedEdge[246, 256] -> 
             RGBColor[
              0.9461492145094601, 0.9325674385115055, 0.6753469391225071], 
             UndirectedEdge[14, 135] -> 
             RGBColor[
              0.8910974991562017, 0.9155530730325436, 0.9739458646952701], 
             UndirectedEdge[67, 179] -> 
             RGBColor[
              0.8831806962349338, 0.9096883301491152, 0.9887197573032447], 
             UndirectedEdge[66, 69] -> 
             RGBColor[
              0.9779322916693579, 0.9817870517265668, 0.8651209882076125], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.853166159100474, 0.8710995145417967, 0.6837449003103248], 
             UndirectedEdge[116, 133] -> 
             RGBColor[
              0.8791022499520971, 0.906419357550672, 0.9877437694422966], 
             UndirectedEdge[2, 83] -> 
             RGBColor[
              0.9346924203374973, 0.9488646273065966, 0.9221714027832566], 
             UndirectedEdge[103, 168] -> 
             RGBColor[
              0.9475873884708959, 0.959824785508097, 0.9525754115567243], 
             UndirectedEdge[26, 199] -> 
             RGBColor[
              0.7893932280000001, 0.8266650869333334, 0.6869914725333333], 
             UndirectedEdge[91, 239] -> 
             RGBColor[
              0.948105618271605, 0.8268565185185186, 0.3036979281481481], 
             UndirectedEdge[13, 298] -> 
             RGBColor[
              0.753915940979999, 0.6381993340678072, 0.5947057949249351], 
             UndirectedEdge[229, 261] -> 
             RGBColor[
              0.9136073986884643, 0.92900324676317, 0.7287695053147372], 
             UndirectedEdge[141, 179] -> 
             RGBColor[
              0.9418146782562354, 0.955632485090338, 0.9662641018570909], 
             UndirectedEdge[59, 195] -> 
             RGBColor[
              0.6060654725330515, 0.6680560065137623, 0.7588867859903995], 
             UndirectedEdge[134, 253] -> 
             RGBColor[
              0.8324654220511456, 0.8692493471444074, 0.9838824891775353], 
             UndirectedEdge[42, 292] -> 
             RGBColor[
              0.8688231697039601, 0.8955003487864668, 0.8519431326225297], 
             UndirectedEdge[70, 238] -> 
             RGBColor[
              0.7849510037592593, 0.7351205969999999, 0.6126916441481481], 
             UndirectedEdge[178, 202] -> 
             RGBColor[
              0.916590761355353, 0.9337035507728191, 0.8888627554465143], 
             UndirectedEdge[29, 191] -> 
             RGBColor[
              0.9039928051236779, 0.5729942568405206, 0.5101345996289894], 
             UndirectedEdge[17, 38] -> 
             RGBColor[
              0.8394263596486581, 0.8735385214189968, 0.8945017586099049], 
             UndirectedEdge[40, 162] -> 
             RGBColor[
              0.9767220543721236, 0.9344993413280736, 0.5311599130440496], 
             UndirectedEdge[13, 95] -> 
             RGBColor[
              0.7635688100456843, 0.6460359680321263, 0.5954657041374103], 
             UndirectedEdge[206, 270] -> 
             RGBColor[
              0.5798438610538068, 0.6192123351080556, 0.6453116169482513], 
             UndirectedEdge[16, 295] -> 
             RGBColor[
              0.9574773975282063, 0.9648919818484751, 0.806558382340376], 
             UndirectedEdge[37, 124] -> 
             RGBColor[
              0.9416440136140106, 0.9557477567909485, 0.9749624612139404], 
             UndirectedEdge[22, 177] -> 
             RGBColor[
              0.9554287994513031, 0.9662794521262004, 0.9603315958847736], 
             UndirectedEdge[115, 204] -> 
             RGBColor[
              0.9878230684980565, 0.9878518762280608, 0.7638976946727312], 
             UndirectedEdge[192, 200] -> 
             RGBColor[
              0.8935668171838507, 0.9037438401824047, 0.6893532023312201], 
             UndirectedEdge[13, 171] -> 
             RGBColor[
              0.9399813774521257, 0.7814933850844413, 0.44461387808964287`], 
             UndirectedEdge[39, 52] -> 
             RGBColor[
              0.6311487567694163, 0.5224521759122507, 0.5826755670488224], 
             UndirectedEdge[92, 216] -> 
             RGBColor[
              0.9572348818564622, 0.9156768190706133, 0.6191427220450954], 
             UndirectedEdge[82, 127] -> 
             RGBColor[
              0.8406421408559294, 0.6576972508482626, 0.5936458019386717], 
             UndirectedEdge[53, 150] -> 
             RGBColor[0.9908693698611111, 0.9902621796527777, 0.784256995], 
             UndirectedEdge[18, 66] -> 
             RGBColor[
              0.9787901040342186, 0.9806776810398206, 0.7444803380833394], 
             UndirectedEdge[31, 36] -> 
             RGBColor[
              0.9084271449274086, 0.9270151691490143, 0.8803141061120652], 
             UndirectedEdge[71, 181] -> 
             RGBColor[
              0.9540394835827665, 0.9341566140589569, 0.6686131957823128], 
             UndirectedEdge[43, 143] -> 
             RGBColor[
              0.9228969071873152, 0.8693165747157574, 0.6319700126915704], 
             UndirectedEdge[75, 185] -> 
             RGBColor[
              0.709587934313682, 0.7721185207732925, 0.9724573460861972], 
             UndirectedEdge[46, 145] -> 
             RGBColor[
              0.7418987571555556, 0.7950529441777778, 0.8853242347555554], 
             UndirectedEdge[62, 255] -> 
             RGBColor[
              0.9698494378424785, 0.9746509872937663, 0.8104942417095929], 
             UndirectedEdge[111, 242] -> 
             RGBColor[
              0.7568300604280946, 0.809997712852718, 0.976387573464603], 
             UndirectedEdge[4, 193] -> 
             RGBColor[
              0.6897790251730211, 0.7539420813414627, 0.9530011769423541], 
             UndirectedEdge[18, 258] -> 
             RGBColor[
              0.7812139588093052, 0.8247692190021427, 0.7511652823201713], 
             UndirectedEdge[81, 267] -> 
             RGBColor[
              0.7248188816568047, 0.7248925231032215, 0.6168394644707429], 
             UndirectedEdge[75, 124] -> 
             RGBColor[
              0.9076535025080504, 0.9286446458829009, 0.9717204159209665], 
             UndirectedEdge[72, 106] -> 
             RGBColor[
              0.9712382969641427, 0.9754712318080891, 0.7910391567541448], 
             UndirectedEdge[262, 271] -> 
             RGBColor[
              0.8883483308172493, 0.8763058644685738, 0.6547186038117099], 
             UndirectedEdge[17, 235] -> 
             RGBColor[
              0.43400958093278474`, 0.531218650617284, 0.9515734624142661], 
             UndirectedEdge[263, 279] -> 
             RGBColor[
              0.8272381772690485, 0.8653963262018731, 0.9833003074020118], 
             UndirectedEdge[3, 252] -> 
             RGBColor[
              0.815237696686844, 0.7842178071529702, 0.6213431722423993], 
             UndirectedEdge[48, 158] -> 
             RGBColor[
              0.8625753328130455, 0.8424270850084011, 0.632078364375614], 
             UndirectedEdge[18, 36] -> 
             RGBColor[
              0.9090764105268373, 0.9258195590153544, 0.7631296155927304], 
             UndirectedEdge[105, 196] -> 
             RGBColor[
              0.8994718793641352, 0.9207428278774804, 0.9139215857487475], 
             UndirectedEdge[269, 298] -> 
             RGBColor[
              0.7900903918156281, 0.7865873299784287, 0.6266519340801233], 
             UndirectedEdge[85, 207] -> 
             RGBColor[
              0.9351972939275585, 0.9501429388426488, 0.9582472676126108], 
             UndirectedEdge[79, 103] -> 
             RGBColor[
              0.9495900803859341, 0.9608514342267854, 0.9282741492633297], 
             UndirectedEdge[76, 128] -> 
             RGBColor[
              0.6979141207407409, 0.7530768785185186, 0.6831144755555555], 
             UndirectedEdge[10, 265] -> 
             RGBColor[
              0.9311833498634741, 0.9443923879101028, 0.8418717795757192], 
             UndirectedEdge[88, 198] -> 
             RGBColor[
              0.6837569206200511, 0.7491666547459892, 0.9590480124438078], 
             UndirectedEdge[63, 143] -> 
             RGBColor[
              0.8022658051363081, 0.8461206880862449, 0.9807494719737689], 
             UndirectedEdge[49, 242] -> 
             RGBColor[
              0.8400015327372292, 0.8737763702723951, 0.8849696520320438], 
             UndirectedEdge[252, 253] -> 
             RGBColor[
              0.8888494677919745, 0.8418404453690409, 0.6286491733667532], 
             UndirectedEdge[16, 125] -> 
             RGBColor[
              0.9895509213736295, 0.9890987379247408, 0.7611683477534816], 
             UndirectedEdge[59, 100] -> 
             RGBColor[
              0.6046824729792046, 0.6686398279544048, 0.8658158417455364], 
             UndirectedEdge[75, 295] -> 
             RGBColor[
              0.8893198318137749, 0.9145835102172872, 0.9893053135352257], 
             UndirectedEdge[94, 295] -> 
             RGBColor[
              0.8212052863661619, 0.8610647735766424, 0.9825977966749972], 
             UndirectedEdge[26, 192] -> 
             RGBColor[
              0.7874205291358025, 0.8200107104526749, 0.6793279099588476], 
             UndirectedEdge[132, 188] -> 
             RGBColor[
              0.9693106381015768, 0.9032474059928902, 0.4676689702341864], 
             UndirectedEdge[186, 196] -> 
             RGBColor[
              0.9352273187521718, 0.9491789723461437, 0.9173516810732179], 
             UndirectedEdge[110, 179] -> 
             RGBColor[
              0.9437161721525318, 0.9248576795002147, 0.6666268639410415], 
             UndirectedEdge[61, 177] -> 
             RGBColor[
              0.9682196234019205, 0.9726945034842249, 0.7544602232921807], 
             UndirectedEdge[21, 264] -> 
             RGBColor[
              0.8357322511111112, 0.8719015155555556, 0.9519498688888889], 
             UndirectedEdge[200, 225] -> 
             RGBColor[
              0.8209338103988288, 0.8602019733660935, 0.9827434198654854], 
             UndirectedEdge[83, 197] -> 
             RGBColor[
              0.8729414884345404, 0.9001245294446406, 0.9161492786809422], 
             UndirectedEdge[220, 226] -> 
             RGBColor[
              0.8708786069335008, 0.5485169034925466, 0.579708124620855], 
             UndirectedEdge[13, 140] -> 
             RGBColor[
              0.8486819459504132, 0.7125345904254665, 0.603943794214876], 
             UndirectedEdge[144, 158] -> 
             RGBColor[
              0.9733802066381789, 0.9280017724615427, 0.5511839417865185], 
             UndirectedEdge[62, 225] -> 
             RGBColor[
              0.9173264907195748, 0.9330154498774984, 0.813973136571127], 
             UndirectedEdge[65, 277] -> 
             RGBColor[
              0.8872582725589542, 0.9122072505132259, 0.9597792555172774], 
             UndirectedEdge[99, 261] -> 
             RGBColor[
              0.6243193190672154, 0.702007651303155, 0.9658393931412894], 
             UndirectedEdge[260, 290] -> 
             RGBColor[
              0.8035190503220851, 0.8465034985152264, 0.9453584610293552], 
             UndirectedEdge[72, 267] -> 
             RGBColor[
              0.9500353584703045, 0.903759604584703, 0.6262495024326101], 
             UndirectedEdge[39, 170] -> 
             RGBColor[
              0.9228668774032598, 0.7206602958221751, 0.2750656630152702], 
             UndirectedEdge[92, 163] -> 
             RGBColor[
              0.8493176234242084, 0.8308414081165033, 0.6291688115656523], 
             UndirectedEdge[102, 133] -> 
             RGBColor[
              0.9072402147023516, 0.9260025038558168, 0.8773245543706111], 
             UndirectedEdge[184, 197] -> 
             RGBColor[
              0.8757483610578146, 0.8994703182414848, 0.7377062350999644], 
             UndirectedEdge[44, 200] -> 
             RGBColor[
              0.8326578969369371, 0.8695504417297297, 0.9838616737057058], 
             UndirectedEdge[115, 132] -> 
             RGBColor[
              0.9690805021358881, 0.9027551684325976, 0.442620090603527], 
             UndirectedEdge[9, 283] -> 
             RGBColor[
              0.9470697588725814, 0.9586432541460812, 0.9194122876460218], 
             UndirectedEdge[52, 165] -> 
             RGBColor[
              0.6854908245607434, 0.7481003766339395, 0.9109335493822657], 
             UndirectedEdge[160, 256] -> 
             RGBColor[
              0.9505857403860033, 0.962178138936197, 0.9515048039620133], 
             UndirectedEdge[45, 215] -> 
             RGBColor[
              0.9946196106107957, 0.9919264912394821, 0.7303553733735382], 
             UndirectedEdge[16, 124] -> 
             RGBColor[
              0.9758110682224818, 0.9789531175140889, 0.7889734847261168], 
             UndirectedEdge[160, 246] -> 
             RGBColor[
              0.9797900858765431, 0.9581346124246913, 0.6349115288395062], 
             UndirectedEdge[57, 204] -> 
             RGBColor[
              0.9876860133985841, 0.9875587292286858, 0.7489800929012002], 
             UndirectedEdge[112, 252] -> 
             RGBColor[
              0.9562976732300537, 0.8604973554657271, 0.3042373733946626], 
             UndirectedEdge[5, 248] -> 
             RGBColor[
              0.9857953303835391, 0.9881488370304528, 0.8740919472987654], 
             UndirectedEdge[186, 276] -> 
             RGBColor[
              0.9345155835876082, 0.9488846515648373, 0.9291469746615992], 
             UndirectedEdge[95, 154] -> 
             RGBColor[
              0.8084058398977403, 0.8504848452609808, 0.9461194928854972], 
             UndirectedEdge[198, 290] -> 
             RGBColor[
              0.6966571389030689, 0.7587876164192953, 0.9372113078064415], 
             UndirectedEdge[77, 191] -> 
             RGBColor[
              0.9901185861143771, 0.9877993033586896, 0.6402420907984734], 
             UndirectedEdge[36, 224] -> 
             RGBColor[
              0.8663958803475134, 0.8963045735721762, 0.9871188065799206], 
             UndirectedEdge[29, 203] -> 
             RGBColor[
              0.9069001181366478, 0.5726863818420147, 0.3521828518828892], 
             UndirectedEdge[25, 172] -> 
             RGBColor[
              0.9023257872425421, 0.921569217784478, 0.8473950372638142], 
             UndirectedEdge[224, 260] -> 
             RGBColor[
              0.769944315228061, 0.8207550063436009, 0.977627253362231], 
             UndirectedEdge[45, 255] -> 
             RGBColor[
              0.9696428960306115, 0.9752354904079128, 0.8626128107111398], 
             UndirectedEdge[102, 239] -> 
             RGBColor[
              0.9829314990929705, 0.9562933766893424, 0.5611446089342405], 
             UndirectedEdge[33, 239] -> 
             RGBColor[
              0.802554396671605, 0.8166956345283951, 0.6573364150716049], 
             UndirectedEdge[64, 92] -> 
             RGBColor[
              0.9676224597471963, 0.923423857653425, 0.6015592621902955], 
             UndirectedEdge[32, 268] -> 
             RGBColor[
              0.9900880433472029, 0.9899209148303798, 0.7958851042153791], 
             UndirectedEdge[85, 240] -> 
             RGBColor[
              0.9769120981947714, 0.9823016611534057, 0.9239659748537725], 
             UndirectedEdge[1, 174] -> 
             RGBColor[
              0.9399341891868189, 0.9544941240263215, 0.9786039517874183], 
             UndirectedEdge[2, 184] -> 
             RGBColor[
              0.9374992929607715, 0.9482104161034408, 0.7437283592022788], 
             UndirectedEdge[60, 85] -> 
             RGBColor[
              0.9555898171594923, 0.9663995388693255, 0.9600590349049535], 
             UndirectedEdge[121, 127] -> 
             RGBColor[
              0.9083369867204922, 0.9260618071664745, 0.8304911098808152], 
             UndirectedEdge[132, 212] -> 
             RGBColor[
              0.9507876853219317, 0.8421044665326192, 0.2818238695464229], 
             UndirectedEdge[172, 206] -> 
             RGBColor[
              0.8921758216661824, 0.8889626989221919, 0.6692164876907134], 
             UndirectedEdge[147, 148] -> 
             RGBColor[
              0.9894940755840276, 0.9788743167924572, 0.5897067063310693], 
             UndirectedEdge[118, 226] -> 
             RGBColor[
              0.9492707914424556, 0.961320369867418, 0.9580504467262918], 
             UndirectedEdge[75, 283] -> 
             RGBColor[
              0.9230103510993761, 0.9394589354629537, 0.9171174798545265], 
             UndirectedEdge[188, 243] -> 
             RGBColor[
              0.9716049798124679, 0.912343706332521, 0.46951505142989103`], 
             UndirectedEdge[88, 258] -> 
             RGBColor[
              0.7592079454409877, 0.811381764057284, 0.9647223856118519], 
             UndirectedEdge[197, 293] -> 
             RGBColor[
              0.8751487153510651, 0.9010372744977679, 0.8795698165539745], 
             UndirectedEdge[86, 179] -> 
             RGBColor[
              0.9548761364633407, 0.9620766097443263, 0.7462264292942637], 
             UndirectedEdge[41, 76] -> 
             RGBColor[
              0.9841969130579475, 0.9818704312894115, 0.6711070339802563], 
             UndirectedEdge[175, 242] -> 
             RGBColor[
              0.8418763269772291, 0.8740154793283952, 0.8149258121031548], 
             UndirectedEdge[89, 285] -> 
             RGBColor[
              0.9044935454759858, 0.562474777867707, 0.47598141271132266`], 
             UndirectedEdge[138, 171] -> 
             RGBColor[
              0.9655966308822371, 0.9716066929305798, 0.8278051204778789], 
             UndirectedEdge[181, 207] -> 
             RGBColor[
              0.9157131022016829, 0.9356116605559266, 0.9912289219134423], 
             UndirectedEdge[17, 55] -> 
             RGBColor[
              0.7040323215639486, 0.768714667540361, 0.9711350203235363], 
             UndirectedEdge[142, 295] -> 
             RGBColor[
              0.9570404712632391, 0.963957440747732, 0.7590016547950366], 
             UndirectedEdge[53, 200] -> 
             RGBColor[
              0.8942217713119371, 0.916903458826952, 0.9252810023029279], 
             UndirectedEdge[33, 237] -> 
             RGBColor[
              0.8082275700049383, 0.8358325803061728, 0.6793756221827159], 
             UndirectedEdge[51, 67] -> 
             RGBColor[
              0.8992436974317206, 0.9221616678805866, 0.9786419362582135], 
             UndirectedEdge[47, 48] -> 
             RGBColor[
              0.8818145677760633, 0.9056232956790125, 0.8515659099056927], 
             UndirectedEdge[102, 237] -> 
             RGBColor[
              0.9886046724263038, 0.9754303224671201, 0.5831838160453514], 
             UndirectedEdge[150, 282] -> 
             RGBColor[
              0.9897887935871212, 0.9898153335939395, 0.8021649403017675], 
             UndirectedEdge[214, 293] -> 
             RGBColor[
              0.9889872101788405, 0.989713942640231, 0.8321739577304685], 
             UndirectedEdge[73, 245] -> 
             RGBColor[
              0.9173011452633897, 0.7998455179275923, 0.6169535545624008], 
             UndirectedEdge[82, 192] -> 
             RGBColor[
              0.9224244277156841, 0.708534505245574, 0.30112825090559314`], 
             UndirectedEdge[82, 266] -> 
             RGBColor[
              0.9269281629618911, 0.7232856937916274, 0.4732717874237948], 
             UndirectedEdge[30, 38] -> 
             RGBColor[
              0.963484114271429, 0.9713619530239351, 0.9052664028623054], 
             UndirectedEdge[146, 242] -> 
             RGBColor[
              0.7227312610094132, 0.7833224211523614, 0.9729987558559361], 
             UndirectedEdge[25, 77] -> 
             RGBColor[
              0.9938335678276802, 0.9892189500423644, 0.5702000967301889], 
             UndirectedEdge[68, 271] -> 
             RGBColor[
              0.8986104199701601, 0.9201133544019147, 0.9158084317644006], 
             UndirectedEdge[23, 267] -> 
             RGBColor[
              0.9724431586767217, 0.9171063420395886, 0.3850054183158859], 
             UndirectedEdge[10, 161] -> 
             RGBColor[
              0.9225452841361058, 0.9167916746091997, 0.6775757124798991], 
             UndirectedEdge[223, 287] -> 
             RGBColor[
              0.9529208129493675, 0.9087804905113246, 0.623591034409145], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.8114090691073348, 0.8532942613344399, 0.981652617435143], 
             UndirectedEdge[218, 229] -> 
             RGBColor[
              0.9674579422300518, 0.9717804736870328, 0.7282983724977992], 
             UndirectedEdge[62, 170] -> 
             RGBColor[
              0.9812944390196818, 0.9473280397717068, 0.48692080308195884`], 
             UndirectedEdge[188, 294] -> 
             RGBColor[
              0.9873322869469707, 0.967591641069363, 0.5191756831011745], 
             UndirectedEdge[181, 299] -> 
             RGBColor[
              0.9515226177391451, 0.9256666345802189, 0.6588356472500769], 
             UndirectedEdge[69, 109] -> 
             RGBColor[
              0.9933518254972569, 0.9911326965062595, 0.731773649267764], 
             UndirectedEdge[48, 175] -> 
             RGBColor[
              0.8815142350705076, 0.9049809143901235, 0.8188765483445815], 
             UndirectedEdge[248, 270] -> 
             RGBColor[
              0.5868576247985203, 0.6506385476416965, 0.8839402801162637], 
             UndirectedEdge[85, 232] -> 
             RGBColor[
              0.9759909881277421, 0.9816146987735945, 0.9255251739332719], 
             UndirectedEdge[65, 152] -> 
             RGBColor[
              0.9098088690987467, 0.9300758302053869, 0.9619600464194502], 
             UndirectedEdge[43, 63] -> 
             RGBColor[
              0.8228692703934373, 0.790508948037154, 0.622176736615532], 
             UndirectedEdge[184, 293] -> 
             RGBColor[
              0.9925785483673246, 0.989384128108135, 0.6407302896021574], 
             UndirectedEdge[24, 260] -> 
             RGBColor[
              0.5878215482216882, 0.6762590397621624, 0.9606946120187427], 
             UndirectedEdge[201, 229] -> 
             RGBColor[
              0.9527453248133088, 0.8391490381740057, 0.36098740144378527`], 
             UndirectedEdge[17, 48] -> 
             RGBColor[
              0.7287300699588479, 0.7880087362962964, 0.9735966610699589], 
             UndirectedEdge[153, 163] -> 
             RGBColor[
              0.7774331485524595, 0.8260559514507326, 0.9784509287880239], 
             UndirectedEdge[33, 200] -> 
             RGBColor[
              0.7167986780529865, 0.778527275369236, 0.9725172318884218], 
             UndirectedEdge[33, 282] -> 
             RGBColor[
              0.8082197769948374, 0.8499547886778901, 0.9348345547483725], 
             UndirectedEdge[150, 237] -> 
             RGBColor[
              0.9897965865972222, 0.9756931252222221, 0.546706007736111], 
             UndirectedEdge[172, 203] -> 
             RGBColor[
              0.901518118542209, 0.9198416961022975, 0.7594852835859984], 
             UndirectedEdge[56, 93] -> 
             RGBColor[
              0.9484060472600323, 0.8328278749772127, 0.27904400778535665`], 
             UndirectedEdge[122, 299] -> 
             RGBColor[
              0.633139003223784, 0.6657488196040567, 0.6327197368909712], 
             UndirectedEdge[44, 100] -> 
             RGBColor[
              0.9273860074091161, 0.9423454892924943, 0.8913732572366184], 
             UndirectedEdge[31, 171] -> 
             RGBColor[
              0.9934873747115891, 0.9910628015725551, 0.7203721567142729], 
             UndirectedEdge[136, 256] -> 
             RGBColor[
              0.9401079345094601, 0.9121887825115054, 0.6518777071225068], 
             UndirectedEdge[146, 159] -> 
             RGBColor[
              0.5407505934099619, 0.6328176272017441, 0.9591448067750034], 
             UndirectedEdge[65, 133] -> 
             RGBColor[
              0.8951596437238908, 0.9183949355341066, 0.9605627902256786], 
             UndirectedEdge[58, 245] -> 
             RGBColor[
              0.8978611366457605, 0.9213941148427691, 0.9901199908150132], 
             UndirectedEdge[172, 272] -> 
             RGBColor[
              0.8956566637557815, 0.9185319884144549, 0.9486624982647329], 
             UndirectedEdge[99, 218] -> 
             RGBColor[
              0.6781698626088029, 0.7447848782270178, 0.9653682603243514], 
             UndirectedEdge[18, 113] -> 
             RGBColor[
              0.9931327520191817, 0.9899641325823896, 0.6570471218263442], 
             UndirectedEdge[43, 131] -> 
             RGBColor[
              0.9555140133179496, 0.8579150643821886, 0.3008743875327204], 
             UndirectedEdge[2, 156] -> 
             RGBColor[
              0.8865998160883435, 0.7541319921802583, 0.6098332623298512], 
             UndirectedEdge[165, 232] -> 
             RGBColor[
              0.9814924473627995, 0.9853617361078739, 0.9002728304632259], 
             UndirectedEdge[173, 186] -> 
             RGBColor[
              0.9240558131921713, 0.9026540083858504, 0.655149518750817], 
             UndirectedEdge[39, 281] -> 
             RGBColor[
              0.8826352584389348, 0.5599559444505663, 0.22378032157943067`], 
             UndirectedEdge[77, 91] -> 
             RGBColor[
              0.95774999537875, 0.8593785977877935, 0.34207175402880435`], 
             UndirectedEdge[15, 19] -> 
             RGBColor[
              0.8590757028306797, 0.890076121030189, 0.9511645994038211], 
             UndirectedEdge[119, 241] -> 
             RGBColor[
              0.6434871579562942, 0.7006555753790908, 0.6729203639417254], 
             UndirectedEdge[103, 116] -> 
             RGBColor[
              0.9242665093649383, 0.9424321120553087, 0.9920515768237037], 
             UndirectedEdge[99, 257] -> 
             RGBColor[
              0.6942245898326476, 0.7287781234809327, 0.6507158269783264], 
             UndirectedEdge[17, 253] -> 
             RGBColor[
              0.7617488026551993, 0.8139197843889103, 0.9768567274892372], 
             UndirectedEdge[204, 292] -> 
             RGBColor[
              0.8619311324444444, 0.8921919918222222, 0.9456374107555556], 
             UndirectedEdge[65, 241] -> 
             RGBColor[
              0.9779243503367319, 0.9725461224417059, 0.6718617544189374], 
             UndirectedEdge[71, 256] -> 
             RGBColor[
              0.9443303345094601, 0.9264319291781722, 0.6682809337891737], 
             UndirectedEdge[37, 102] -> 
             RGBColor[
              0.9592980080803513, 0.9675119752242762, 0.8822898731755454], 
             UndirectedEdge[61, 217] -> 
             RGBColor[
              0.9797319794213604, 0.9812803997537705, 0.7349728074546009], 
             UndirectedEdge[35, 184] -> 
             RGBColor[
              0.9908534603972831, 0.9803920074381648, 0.45440170346789643`], 
             UndirectedEdge[164, 241] -> 
             RGBColor[
              0.6327723955555555, 0.6893936807407406, 0.6723101740740738], 
             UndirectedEdge[192, 255] -> 
             RGBColor[
              0.9653034786094867, 0.9605522515053064, 0.6877461025904266], 
             UndirectedEdge[112, 134] -> 
             RGBColor[
              0.8999136274892249, 0.8879062572410937, 0.6594706892054447], 
             UndirectedEdge[44, 195] -> 
             RGBColor[
              0.928769006962963, 0.9417616678518519, 0.7844442014814815], 
             UndirectedEdge[127, 281] -> 
             RGBColor[
              0.8547345739626104, 0.7216876982143267, 0.6054048735600315], 
             UndirectedEdge[59, 192] -> 
             RGBColor[
              0.6018010835947799, 0.6545595211145854, 0.666785835801099], 
             UndirectedEdge[108, 264] -> 
             RGBColor[
              0.9827809148971193, 0.9840029302057614, 0.7654093697942388], 
             UndirectedEdge[136, 296] -> 
             RGBColor[
              0.8182091666666667, 0.8161768399999998, 0.6399359466666664], 
             UndirectedEdge[118, 130] -> 
             RGBColor[
              0.9342216248229314, 0.949320572903755, 0.956615043779572], 
             UndirectedEdge[85, 136] -> 
             RGBColor[
              0.969301275308642, 0.9344447456790121, 0.6192283148148144], 
             UndirectedEdge[104, 157] -> 
             RGBColor[
              0.8862106132991454, 0.9031104069333334, 0.6960869470632478], 
             UndirectedEdge[158, 217] -> 
             RGBColor[
              0.9614024809861205, 0.9200300235276035, 0.6145044687300782], 
             UndirectedEdge[11, 174] -> 
             RGBColor[
              0.8348919391521205, 0.8715709636125253, 0.9683634302054018], 
             UndirectedEdge[39, 220] -> 
             RGBColor[
              0.8489595295354846, 0.3470602239315975, 0.1933317192780531], 
             UndirectedEdge[32, 208] -> 
             RGBColor[
              0.9800651236445261, 0.984488732117131, 0.9112643068380775], 
             UndirectedEdge[27, 103] -> 
             RGBColor[
              0.8732158866428918, 0.9017426614679718, 0.9877693048686652], 
             UndirectedEdge[212, 250] -> 
             RGBColor[
              0.9622679881285444, 0.8843832054391935, 0.30791868828229363`], 
             UndirectedEdge[129, 298] -> 
             RGBColor[
              0.8059693809149041, 0.8471680807731956, 0.8945367075153521], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.8986714968438898, 0.9220402740681157, 0.990197283694128], 
             UndirectedEdge[261, 290] -> 
             RGBColor[
              0.9048215371807956, 0.9259210590639232, 0.955312699493004], 
             UndirectedEdge[24, 113] -> 
             RGBColor[
              0.7683294548334851, 0.8159531805577727, 0.8641036714700461], 
             UndirectedEdge[15, 243] -> 
             RGBColor[
              0.9617426169289697, 0.9072549384207108, 0.6023698729783522], 
             UndirectedEdge[246, 296] -> 
             RGBColor[
              0.8242504466666667, 0.8365554959999999, 0.6634051786666666], 
             UndirectedEdge[131, 174] -> 
             RGBColor[
              0.9602978694618056, 0.9333220645258433, 0.6463395839316943], 
             UndirectedEdge[44, 121] -> 
             RGBColor[
              0.9292103533333333, 0.942705663111111, 0.8324820302222222], 
             UndirectedEdge[155, 293] -> 
             RGBColor[
              0.9904266735525098, 0.9903091977377647, 0.8083183244169725], 
             UndirectedEdge[105, 140] -> 
             RGBColor[
              0.8114422111111113, 0.8526240896000001, 0.9818406343111111], 
             UndirectedEdge[51, 138] -> 
             RGBColor[
              0.9425947319891024, 0.9567078256267477, 0.9820563244373939], 
             UndirectedEdge[133, 277] -> 
             RGBColor[
              0.8139475933871589, 0.8545963870898461, 0.9820863472754511], 
             UndirectedEdge[201, 261] -> 
             RGBColor[
              0.8734077285939801, 0.7808339025219466, 0.6162724887216406], 
             UndirectedEdge[19, 57] -> 
             RGBColor[
              0.8685708746490169, 0.8943795043823315, 0.7783432964531695], 
             UndirectedEdge[104, 261] -> 
             RGBColor[
              0.9118143692345679, 0.9232277224888888, 0.6986082488296296], 
             UndirectedEdge[15, 111] -> 
             RGBColor[
              0.8997581775200012, 0.921894629889755, 0.9552096162355219], 
             UndirectedEdge[71, 85] -> 
             RGBColor[
              0.973523675308642, 0.948687892345679, 0.6356315414814813], 
             UndirectedEdge[84, 158] -> 
             RGBColor[
              0.9709254234314266, 0.9269866565204998, 0.5918660522976991], 
             UndirectedEdge[65, 162] -> 
             RGBColor[
              0.9643549281145096, 0.9267732750342986, 0.6191471114559746], 
             UndirectedEdge[156, 268] -> 
             RGBColor[
              0.9431867378919773, 0.7956809123703134, 0.46380405976413286`], 
             UndirectedEdge[48, 252] -> 
             RGBColor[
              0.8558307350956231, 0.815929397276427, 0.6253891069474748], 
             UndirectedEdge[204, 235] -> 
             RGBColor[
              0.5801801435555555, 0.6455337782222222, 0.9249068906666666], 
             UndirectedEdge[62, 130] -> 
             RGBColor[
              0.9429478058996585, 0.9534451911300237, 0.8164169204854215], 
             UndirectedEdge[142, 283] -> 
             RGBColor[
              0.9907309905488402, 0.9888328659933985, 0.6868138211143375], 
             UndirectedEdge[99, 259] -> 
             RGBColor[
              0.6995486547500724, 0.760640018606329, 0.925188216948372], 
             UndirectedEdge[43, 244] -> 
             RGBColor[
              0.9590887252024511, 0.8971698106944155, 0.6005732792285814], 
             UndirectedEdge[36, 154] -> 
             RGBColor[
              0.8997581775200012, 0.921894629889755, 0.9552096162355219], 
             UndirectedEdge[11, 185] -> 
             RGBColor[
              0.638954066551637, 0.7166316703930546, 0.9654987267220718], 
             UndirectedEdge[20, 150] -> 
             RGBColor[
              0.9370373930650511, 0.9490743678082336, 0.8435751416962035], 
             UndirectedEdge[175, 252] -> 
             RGBColor[
              0.9689769921140043, 0.9019361403085256, 0.4667182579806708], 
             UndirectedEdge[97, 292] -> 
             RGBColor[
              0.8528499888888889, 0.8432385135999998, 0.6433886200888886], 
             UndirectedEdge[176, 226] -> 
             RGBColor[
              0.9580335941311906, 0.9655233180187583, 0.8218383598967967], 
             UndirectedEdge[80, 103] -> 
             RGBColor[
              0.9384107844193017, 0.9529808892317282, 0.9681090085744207], 
             UndirectedEdge[137, 220] -> 
             RGBColor[
              0.8452101155037344, 0.5280495451790892, 0.577259840993751], 
             UndirectedEdge[20, 167] -> 
             RGBColor[
              0.9118144131632223, 0.9322913373121835, 0.9835202562881934], 
             UndirectedEdge[240, 256] -> 
             RGBColor[
              0.9477187573955895, 0.9600456979858989, 0.9566153671614649], 
             UndirectedEdge[113, 278] -> 
             RGBColor[
              0.8489089314047776, 0.8804095474264009, 0.8711046904624151], 
             UndirectedEdge[181, 240] -> 
             RGBColor[
              0.9574279064688959, 0.9677703828666836, 0.956947629154604], 
             UndirectedEdge[7, 151] -> 
             RGBColor[
              0.9466475452619244, 0.9592656822841636, 0.9590836665801954], 
             UndirectedEdge[6, 101] -> 
             RGBColor[
              0.9533308098527644, 0.9604278666430464, 0.7123128218296277], 
             UndirectedEdge[65, 116] -> 
             RGBColor[
              0.9524129291238923, 0.9640302209740518, 0.9654366776841228], 
             UndirectedEdge[50, 264] -> 
             RGBColor[
              0.9811233493663911, 0.9843494541046832, 0.867892833865932], 
             UndirectedEdge[55, 235] -> 
             RGBColor[
              0.4489497406311638, 0.542890016923077, 0.9530625579092702], 
             UndirectedEdge[100, 232] -> 
             RGBColor[
              0.9839133713393273, 0.9863628503870765, 0.8601518550217424], 
             UndirectedEdge[28, 163] -> 
             RGBColor[
              0.8682798828958938, 0.8940464726628539, 0.7698477207072156], 
             UndirectedEdge[11, 63] -> 
             RGBColor[
              0.7094769809572574, 0.772968076839358, 0.9716776930886265], 
             UndirectedEdge[234, 274] -> 
             RGBColor[
              0.959441606815156, 0.9692721972877927, 0.9535389597255501], 
             UndirectedEdge[148, 270] -> 
             RGBColor[
              0.5857487025762981, 0.6391307520861408, 0.6682508112273746], 
             UndirectedEdge[96, 245] -> 
             RGBColor[
              0.9592034729167203, 0.9686079537161643, 0.9331452763964936], 
             UndirectedEdge[159, 235] -> 
             RGBColor[
              0.2520289133333333, 0.3807138566666667, 0.9377195133333334], 
             UndirectedEdge[53, 287] -> 
             RGBColor[
              0.9694962016848613, 0.9763503324381764, 0.917685382532293], 
             UndirectedEdge[105, 289] -> 
             RGBColor[
              0.9004046322666668, 0.9211285451733334, 0.8984634562666665], 
             UndirectedEdge[56, 164] -> 
             RGBColor[
              0.6176164617913205, 0.6382691573714989, 0.6134322333579563], 
             UndirectedEdge[112, 235] -> 
             RGBColor[
              0.5741144271604938, 0.6067520438683127, 0.6343724651028806], 
             UndirectedEdge[7, 43] -> 
             RGBColor[
              0.930588936568788, 0.8754499901499684, 0.6327036853207308], 
             UndirectedEdge[242, 243] -> 
             RGBColor[
              0.818814499837063, 0.7953580213836737, 0.6235478302074332], 
             UndirectedEdge[151, 286] -> 
             RGBColor[
              0.8472950355465223, 0.8808611263906054, 0.9493906778354013], 
             UndirectedEdge[126, 163] -> 
             RGBColor[
              0.8408832619646882, 0.7974019755138488, 0.6223823263554138], 
             UndirectedEdge[31, 138] -> 
             RGBColor[
              0.9643955870348455, 0.9716221051851852, 0.8849319538870625], 
             UndirectedEdge[95, 138] -> 
             RGBColor[
              0.7891840634757956, 0.8361492758782647, 0.9786569465256463], 
             UndirectedEdge[197, 275] -> 
             RGBColor[
              0.8761304220948517, 0.9002875081674107, 0.779291221174039], 
             UndirectedEdge[198, 245] -> 
             RGBColor[
              0.6749098702321292, 0.7424700249254138, 0.970608214445255], 
             UndirectedEdge[187, 264] -> 
             RGBColor[
              0.9262840387187565, 0.9431351736273892, 0.960844155400126], 
             UndirectedEdge[62, 195] -> 
             RGBColor[
              0.9942238864428684, 0.9900538020929865, 0.6126838692261622], 
             UndirectedEdge[169, 187] -> 
             RGBColor[
              0.9372900294457798, 0.948251387728898, 0.7605559894467653], 
             UndirectedEdge[82, 199] -> 
             RGBColor[
              0.9243971265798816, 0.7151888817262326, 0.30879181348007884`], 
             UndirectedEdge[126, 155] -> 
             RGBColor[
              0.9639321134122287, 0.8927445796186718, 0.5519053642340566], 
             UndirectedEdge[82, 220] -> 
             RGBColor[
              0.8398520213629941, 0.30570515643289375`, 0.18573219121347323`],
              UndirectedEdge[32, 202] -> 
             RGBColor[
              0.9135046849011137, 0.9324273788504438, 0.9400070288031104], 
             UndirectedEdge[113, 260] -> 
             RGBColor[
              0.8121727353635118, 0.8515471308093279, 0.8675551751165981], 
             UndirectedEdge[105, 230] -> 
             RGBColor[
              0.8991120365492777, 0.9205940236259984, 0.9198851124342877], 
             UndirectedEdge[245, 289] -> 
             RGBColor[
              0.9609465662086214, 0.9693287675878197, 0.9042577095688544], 
             UndirectedEdge[108, 187] -> 
             RGBColor[
              0.937588895838098, 0.9488906327220394, 0.7930857518610315], 
             UndirectedEdge[137, 228] -> 
             RGBColor[
              0.9225144660170208, 0.913108504647128, 0.6721904985386578], 
             UndirectedEdge[88, 261] -> 
             RGBColor[
              0.8919213188977777, 0.9163000973906172, 0.9771494041303703], 
             UndirectedEdge[192, 228] -> 
             RGBColor[
              0.9801454824322013, 0.9446881915607082, 0.3773693777704821], 
             UndirectedEdge[42, 97] -> 
             RGBColor[
              0.9792441808150711, 0.9400284351864665, 0.5203697125336406], 
             UndirectedEdge[121, 240] -> 
             RGBColor[
              0.9866588273305739, 0.9874099865855044, 0.7997014289278468], 
             UndirectedEdge[25, 43] -> 
             RGBColor[
              0.9693236102760907, 0.902866379217534, 0.49326991396064385`], 
             UndirectedEdge[77, 270] -> 
             RGBColor[
              0.5886805463501098, 0.6490098802443045, 0.6805477126635866], 
             UndirectedEdge[225, 255] -> 
             RGBColor[
              0.8926704718244648, 0.9170103846889952, 0.9811363201246919], 
             UndirectedEdge[2, 275] -> 
             RGBColor[
              0.9378813539978086, 0.9490276060293666, 0.7853133452763533], 
             UndirectedEdge[235, 253] -> 
             RGBColor[
              0.5066662217224145, 0.5880951337716263, 0.9587842650749712], 
             UndirectedEdge[73, 95] -> 
             RGBColor[
              0.7722934198611506, 0.6856523835197658, 0.6027457324271914], 
             UndirectedEdge[49, 175] -> 
             RGBColor[
              0.9927856978488889, 0.9907485483662223, 0.7302495393066665], 
             UndirectedEdge[153, 219] -> 
             RGBColor[
              0.8948538736872007, 0.8946464234429023, 0.6747282432659685], 
             UndirectedEdge[54, 167] -> 
             RGBColor[
              0.8256671159612274, 0.8645149287774543, 0.9750606086905818], 
             UndirectedEdge[56, 246] -> 
             RGBColor[
              0.9662100351246536, 0.8976806555937211, 0.32323279646906733`], 
             UndirectedEdge[192, 225] -> 
             RGBColor[
              0.9127805314865831, 0.9189167140890385, 0.6912249974519606], 
             UndirectedEdge[84, 252] -> 
             RGBColor[
              0.9641808257140043, 0.9004889687885256, 0.5851767948695598], 
             UndirectedEdge[119, 164] -> 
             RGBColor[
              0.2888811757340721, 0.4209628101939059, 0.9397627276454293], 
             UndirectedEdge[93, 168] -> 
             RGBColor[
              0.9613714389173855, 0.8928291703315884, 0.5920207064996803], 
             UndirectedEdge[111, 250] -> 
             RGBColor[
              0.8957383594953099, 0.8814948715687673, 0.6545382163836702], 
             UndirectedEdge[54, 286] -> 
             RGBColor[
              0.7128686898969978, 0.7756177056410258, 0.9720157469384177], 
             UndirectedEdge[74, 257] -> 
             RGBColor[
              0.7359350689941844, 0.7636981306289563, 0.65370722139749], 
             UndirectedEdge[220, 236] -> 
             RGBColor[
              0.8367998119217412, 0.521343397394417, 0.5764576587301339], 
             UndirectedEdge[130, 228] -> 
             RGBColor[
              0.9331337908272632, 0.9215760659969223, 0.6732033792190418], 
             UndirectedEdge[1, 142] -> 
             RGBColor[
              0.9601125508182922, 0.9664070335955532, 0.7592946724854753], 
             UndirectedEdge[101, 114] -> 
             RGBColor[
              0.9542182141082203, 0.9631321442458525, 0.8675042279835118], 
             UndirectedEdge[199, 266] -> 
             RGBColor[
              0.9918899723820095, 0.9838641459320615, 0.5776418790103826], 
             UndirectedEdge[93, 277] -> 
             RGBColor[
              0.8728959032464898, 0.8236135264179743, 0.6258394495998141], 
             UndirectedEdge[19, 112] -> 
             RGBColor[
              0.8562524319664822, 0.8537125972441806, 0.6551415593215166], 
             UndirectedEdge[77, 203] -> 
             RGBColor[
              0.9930258991273471, 0.9874914283601839, 0.4822903430523733], 
             UndirectedEdge[26, 60] -> 
             RGBColor[
              0.7626378018508504, 0.8146195131903131, 0.9771488400901388], 
             UndirectedEdge[186, 263] -> 
             RGBColor[
              0.8778878949435924, 0.9054679940686634, 0.9882149251911371], 
             UndirectedEdge[167, 283] -> 
             RGBColor[
              0.9663032532466824, 0.9737507790066842, 0.9133161850120743], 
             UndirectedEdge[170, 200] -> 
             RGBColor[
              0.8849017586989358, 0.8745145632603017, 0.6556910863763172], 
             UndirectedEdge[17, 292] -> 
             RGBColor[
              0.7157605698216736, 0.777876864217284, 0.972303982503155], 
             UndirectedEdge[106, 215] -> 
             RGBColor[
              0.9946714153156223, 0.9910110210996973, 0.6613946251973659], 
             UndirectedEdge[123, 229] -> 
             RGBColor[
              0.9588371345600692, 0.8633010338446515, 0.36588901455918166`], 
             UndirectedEdge[105, 149] -> 
             RGBColor[
              0.8770754856172841, 0.9046970176246915, 0.9812718161629629], 
             UndirectedEdge[68, 274] -> 
             RGBColor[
              0.9762781659659683, 0.9812108074326169, 0.8973607043433096], 
             UndirectedEdge[149, 171] -> 
             RGBColor[
              0.9690222615634411, 0.9741615226836662, 0.8220064212821743], 
             UndirectedEdge[29, 172] -> 
             RGBColor[
              0.8148867259717861, 0.5039551975402718, 0.5743450922365646], 
             UndirectedEdge[76, 209] -> 
             RGBColor[
              0.9923143326596867, 0.9863425097551606, 0.5865265513410707], 
             UndirectedEdge[247, 267] -> 
             RGBColor[
              0.930882039507742, 0.8888117130620692, 0.6356713575845975], 
             UndirectedEdge[164, 210] -> 
             RGBColor[
              0.6337502447289505, 0.6997791480891965, 0.8827890145636292], 
             UndirectedEdge[258, 260] -> 
             RGBColor[
              0.6002539421536353, 0.6863522172290811, 0.9616733356104252], 
             UndirectedEdge[62, 137] -> 
             RGBColor[
              0.9323284810894161, 0.9449776297802295, 0.8154040398050373], 
             UndirectedEdge[175, 280] -> 
             RGBColor[
              0.9808524142388888, 0.982964978988889, 0.800437610522222], 
             UndirectedEdge[72, 194] -> 
             RGBColor[
              0.9703772512793707, 0.9760520600061218, 0.873411122216535], 
             UndirectedEdge[3, 257] -> 
             RGBColor[
              0.830631122617284, 0.8398900232888891, 0.6616314940839506], 
             UndirectedEdge[154, 171] -> 
             RGBColor[
              0.9848184073041818, 0.9859422623132958, 0.7952676668377298], 
             UndirectedEdge[168, 277] -> 
             RGBColor[
              0.894521757893118, 0.9176243459825797, 0.947484069466916], 
             UndirectedEdge[146, 243] -> 
             RGBColor[
              0.8524535989809068, 0.8216371413014671, 0.6269006612348371], 
             UndirectedEdge[98, 122] -> 
             RGBColor[
              0.6209791488444143, 0.6943796137386963, 0.9614112939353178], 
             UndirectedEdge[142, 210] -> 
             RGBColor[
              0.991379442059835, 0.9891010173576384, 0.676067301438438], 
             UndirectedEdge[3, 38] -> 
             RGBColor[
              0.8384712293331574, 0.8727923663572685, 0.8944065601462561], 
             UndirectedEdge[21, 205] -> 
             RGBColor[
              0.8423293646090535, 0.8767421715226338, 0.9372242739917694], 
             UndirectedEdge[153, 221] -> 
             RGBColor[
              0.9030159358518519, 0.9212906758518519, 0.781970917925926], 
             UndirectedEdge[55, 159] -> 
             RGBColor[
              0.5220516539644972, 0.6182098735897437, 0.9572810712426036], 
             UndirectedEdge[149, 298] -> 
             RGBColor[
              0.7829568250913144, 0.8308674716670321, 0.9720983381174665], 
             UndirectedEdge[22, 247] -> 
             RGBColor[
              0.938917005011431, 0.9533016052674896, 0.9652820390397805], 
             UndirectedEdge[105, 298] -> 
             RGBColor[
              0.716676206140697, 0.7782888332423408, 0.9726026350211703], 
             UndirectedEdge[169, 219] -> 
             RGBColor[
              0.9855531155253351, 0.9623214730999667, 0.4500713862014966], 
             UndirectedEdge[53, 225] -> 
             RGBColor[
              0.9134354856146695, 0.9320763327335859, 0.9271527974236685], 
             UndirectedEdge[47, 90] -> 
             RGBColor[
              0.8199374054166668, 0.8572843861600001, 0.8453985726366666], 
             UndirectedEdge[100, 137] -> 
             RGBColor[
              0.9306639112408491, 0.944959200831589, 0.8916859066303084], 
             UndirectedEdge[15, 175] -> 
             RGBColor[
              0.9848044440691358, 0.9859123963654322, 0.7937478548740737], 
             UndirectedEdge[49, 253] -> 
             RGBColor[
              0.9126581735268591, 0.9306528534267375, 0.892180454692749], 
             UndirectedEdge[166, 291] -> 
             RGBColor[
              0.7792686601283578, 0.8230612439272795, 0.7404644054615044], 
             UndirectedEdge[161, 230] -> 
             RGBColor[
              0.9825736552159443, 0.962784871092665, 0.6129667913676211], 
             UndirectedEdge[263, 269] -> 
             RGBColor[
              0.9155466412304867, 0.8853303463360881, 0.6388341289256197], 
             UndirectedEdge[122, 160] -> 
             RGBColor[
              0.6419112749439486, 0.7099850088408195, 0.9257211555960467], 
             UndirectedEdge[196, 289] -> 
             RGBColor[
              0.9890816449641351, 0.9897529938508137, 0.8306089289487473], 
             UndirectedEdge[30, 158] -> 
             RGBColor[
              0.9469951793425379, 0.9092850815516109, 0.638892272386588], 
             UndirectedEdge[114, 187] -> 
             RGBColor[
              0.9377197430162771, 0.9499767112362046, 0.8659305890824032], 
             UndirectedEdge[49, 159] -> 
             RGBColor[
              0.6580208651377778, 0.7232715763217779, 0.8711157029511112], 
             UndirectedEdge[33, 94] -> 
             RGBColor[
              0.6768158491054124, 0.7472923855146364, 0.9685321171597077], 
             UndirectedEdge[193, 220] -> 
             RGBColor[
              0.6214658763894977, 0.3486555433077114, 0.5575976763872906], 
             UndirectedEdge[60, 127] -> 
             RGBColor[
              0.8788485241268981, 0.9062301292456765, 0.988173261082065], 
             UndirectedEdge[282, 297] -> 
             RGBColor[
              0.9895968725765207, 0.9899660537092808, 0.8220702740451991], 
             UndirectedEdge[97, 235] -> 
             RGBColor[
              0.5710989999999999, 0.5965802999999997, 0.6226580999999998], 
             UndirectedEdge[50, 187] -> 
             RGBColor[
              0.93593133030737, 0.9492371566209613, 0.8955692159327246], 
             UndirectedEdge[271, 274] -> 
             RGBColor[
              0.8869763394650174, 0.9120547443127538, 0.9631802478232658], 
             UndirectedEdge[137, 170] -> 
             RGBColor[
              0.9191174633715095, 0.9016496170696666, 0.6589937847309681], 
             UndirectedEdge[84, 253] -> 
             RGBColor[
              0.909736801366859, 0.9294447909627375, 0.9405951516527489], 
             UndirectedEdge[33, 185] -> 
             RGBColor[
              0.596534799770533, 0.6833328498970237, 0.96138055109836], 
             UndirectedEdge[3, 144] -> 
             RGBColor[
              0.8385798134684808, 0.8728372686877097, 0.8926070400172146], 
             UndirectedEdge[11, 43] -> 
             RGBColor[
              0.8301080830082646, 0.7961639634688705, 0.622898233806428], 
             UndirectedEdge[29, 272] -> 
             RGBColor[
              0.9010386633502201, 0.5713766741541724, 0.5413600665616237], 
             UndirectedEdge[70, 251] -> 
             RGBColor[
              0.8188778696453738, 0.8564920540527151, 0.8473891688695114], 
             UndirectedEdge[99, 123] -> 
             RGBColor[
              0.6695490549388203, 0.6363054383846365, 0.6029589023857339], 
             UndirectedEdge[133, 239] -> 
             RGBColor[
              0.8975402489427144, 0.8910749449442522, 0.6666899365474817], 
             UndirectedEdge[259, 260] -> 
             RGBColor[
              0.8081966512932823, 0.8499029178655884, 0.9334491779360263], 
             UndirectedEdge[125, 192] -> 
             RGBColor[
              0.9851083602469135, 0.9752211602304527, 0.6496744544032922], 
             UndirectedEdge[213, 264] -> 
             RGBColor[
              0.9830106221242729, 0.9844942507376798, 0.7904115838812366], 
             UndirectedEdge[134, 204] -> 
             RGBColor[
              0.9059793438842866, 0.9266879915950033, 0.9500051147692308], 
             UndirectedEdge[94, 142] -> 
             RGBColor[
              0.8575896230980253, 0.88545198692135, 0.7493052534073558], 
             UndirectedEdge[134, 175] -> 
             RGBColor[
              0.9125929463731755, 0.9293450420838922, 0.8219515737914528], 
             UndirectedEdge[8, 267] -> 
             RGBColor[
              0.9728662108419899, 0.9180112078439622, 0.4310520357300022], 
             UndirectedEdge[195, 225] -> 
             RGBColor[
              0.9170449204248547, 0.9324131994882154, 0.7833259476412612], 
             UndirectedEdge[51, 281] -> 
             RGBColor[
              0.9181524020729182, 0.7719204895141061, 0.599843798180165], 
             UndirectedEdge[49, 243] -> 
             RGBColor[
              0.9697238707087228, 0.9120910904215009, 0.538871557410945], 
             UndirectedEdge[212, 243] -> 
             RGBColor[
              0.9530820270328227, 0.85120076687225, 0.28366995074212753`], 
             UndirectedEdge[22, 285] -> 
             RGBColor[
              0.9797640637475907, 0.983186602065238, 0.8635167897483595], 
             UndirectedEdge[20, 33] -> 
             RGBColor[
              0.7554683764727672, 0.8092138228921842, 0.9762447561428085], 
             UndirectedEdge[9, 174] -> 
             RGBColor[
              0.9295852146873707, 0.9462421326758907, 0.9776168573610223], 
             UndirectedEdge[180, 250] -> 
             RGBColor[
              0.9624479664286447, 0.9341125507450497, 0.6409740738528775], 
             UndirectedEdge[92, 221] -> 
             RGBColor[
              0.9749004107236008, 0.9260761325176226, 0.4326888007035544], 
             UndirectedEdge[71, 232] -> 
             RGBColor[
              0.9741831128191001, 0.9491796997612488, 0.634515285785124], 
             UndirectedEdge[25, 148] -> 
             RGBColor[
              0.9909017240538684, 0.9793398218842007, 0.557903195293977], 
             UndirectedEdge[76, 218] -> 
             RGBColor[
              0.9664429892205997, 0.9686295839608998, 0.7011597960719507], 
             UndirectedEdge[20, 200] -> 
             RGBColor[
              0.8403897945158771, 0.8757156469824078, 0.9845991489991315], 
             UndirectedEdge[68, 255] -> 
             RGBColor[
              0.9665528327092398, 0.9739576698135205, 0.9138231567738011], 
             UndirectedEdge[30, 123] -> 
             RGBColor[
              0.9309684726617284, 0.8459869248592593, 0.6247344122074073], 
             UndirectedEdge[113, 290] -> 
             RGBColor[
              0.984026956933882, 0.9861976393108368, 0.8487675204806584], 
             UndirectedEdge[230, 269] -> 
             RGBColor[
              0.9725262222242088, 0.9288925203620864, 0.5739344114932409], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.8122211996123998, 0.854022261534584, 0.9817087356832117], 
             UndirectedEdge[71, 296] -> 
             RGBColor[
              0.8224315666666666, 0.8304199866666666, 0.6563391733333332], 
             UndirectedEdge[37, 237] -> 
             RGBColor[
              0.9552712156540473, 0.9517213620904892, 0.6936944624635271], 
             UndirectedEdge[8, 217] -> 
             RGBColor[
              0.9799822952732122, 0.9818158000500667, 0.762218143158305], 
             UndirectedEdge[39, 100] -> 
             RGBColor[
              0.9344133252725995, 0.7639698795840973, 0.5077577849146104], 
             UndirectedEdge[35, 216] -> 
             RGBColor[
              0.9735699925671815, 0.9708098839170813, 0.6824406108835119], 
             UndirectedEdge[48, 253] -> 
             RGBColor[
              0.8013867107484778, 0.8448852194506388, 0.9808074637306639], 
             UndirectedEdge[72, 247] -> 
             RGBColor[
              0.9291272924422149, 0.9460004536625514, 0.9818534688534996], 
             UndirectedEdge[24, 254] -> 
             RGBColor[
              0.7556831679284755, 0.7711597635828517, 0.6425261703756269], 
             UndirectedEdge[247, 273] -> 
             RGBColor[
              0.9500698934064928, 0.9606269437366255, 0.90195838866941], 
             UndirectedEdge[80, 152] -> 
             RGBColor[
              0.9078957503813164, 0.9286490293983718, 0.9651984573867852], 
             UndirectedEdge[121, 125] -> 
             RGBColor[
              0.9898140955555556, 0.989661640888889, 0.7898132333333335], 
             UndirectedEdge[8, 177] -> 
             RGBColor[
              0.9684699392537723, 0.9732299037805212, 0.7817055589958848], 
             UndirectedEdge[38, 253] -> 
             RGBColor[
              0.9120830004382879, 0.9304150045733393, 0.90171256127061], 
             UndirectedEdge[134, 292] -> 
             RGBColor[0.78647718921762, 0.833206426972781, 0.979329744191453],
              UndirectedEdge[19, 177] -> 
             RGBColor[
              0.8431002859856865, 0.8781616813045374, 0.9782068130663726], 
             UndirectedEdge[219, 221] -> 
             RGBColor[
              0.985780253983497, 0.9628072992947541, 0.47479400563633894`], 
             UndirectedEdge[37, 185] -> 
             RGBColor[
              0.7435784454196421, 0.7992216316813401, 0.9756993913791712], 
             UndirectedEdge[15, 280] -> 
             RGBColor[
              0.9709963662191359, 0.9778897179320989, 0.9339797660185184], 
             UndirectedEdge[140, 171] -> 
             RGBColor[
              0.9033889870572682, 0.9220885946589749, 0.8225752394303225], 
             UndirectedEdge[211, 221] -> 
             RGBColor[
              0.9830696649706259, 0.9536638460777733, 0.4642638791731184], 
             UndirectedEdge[47, 273] -> 
             RGBColor[
              0.9927134854166666, 0.9912368726666667, 0.7691129379166666], 
             UndirectedEdge[58, 171] -> 
             RGBColor[
              0.9292659786499629, 0.9426583974872577, 0.8250603426320365], 
             UndirectedEdge[75, 150] -> 
             RGBColor[
              0.9264994111453094, 0.9406716670713307, 0.842570019573331], 
             UndirectedEdge[9, 167] -> 
             RGBColor[
              0.9253358390166859, 0.9430729552584081, 0.9848099419568161], 
             UndirectedEdge[135, 260] -> 
             RGBColor[
              0.7923664567419355, 0.8381859124838469, 0.964236892898288], 
             UndirectedEdge[184, 202] -> 
             RGBColor[
              0.917502856318316, 0.9322658003135598, 0.7418210812242916], 
             UndirectedEdge[166, 262] -> 
             RGBColor[
              0.766267240383842, 0.7797523904091486, 0.6433593873300483], 
             UndirectedEdge[173, 276] -> 
             RGBColor[
              0.9762656513370394, 0.942547991813361, 0.5956601896968088], 
             UndirectedEdge[67, 86] -> 
             RGBColor[
              0.9214982143191368, 0.9354619606460988, 0.7430428132833268], 
             UndirectedEdge[25, 272] -> 
             RGBColor[
              0.9884777246209762, 0.9889906943983785, 0.8144100115888733], 
             UndirectedEdge[7, 174] -> 
             RGBColor[
              0.9353727927126441, 0.9508569902936232, 0.9781688817197047], 
             UndirectedEdge[88, 113] -> 
             RGBColor[
              0.9711267386508642, 0.9765766776375309, 0.8706042251180247], 
             UndirectedEdge[147, 206] -> 
             RGBColor[
              0.9835892340615363, 0.9589558998143719, 0.566767512051946], 
             UndirectedEdge[189, 211] -> 
             RGBColor[
              0.8493178860359707, 0.8520474433245508, 0.6599296812925805], 
             UndirectedEdge[104, 209] -> 
             RGBColor[
              0.9915362562152423, 0.9837178752070124, 0.5835038712818115], 
             UndirectedEdge[151, 167] -> 
             RGBColor[
              0.9600934616107519, 0.9697583495270339, 0.9524355395875654], 
             UndirectedEdge[215, 274] -> 
             RGBColor[
              0.9798954667842812, 0.9825900605559288, 0.8289375354950645], 
             UndirectedEdge[41, 261] -> 
             RGBColor[
              0.9058742698480711, 0.9267061853634857, 0.9535306976839599], 
             UndirectedEdge[157, 218] -> 
             RGBColor[
              0.8625165900753007, 0.8933480224794184, 0.9810621580092728], 
             UndirectedEdge[187, 205] -> 
             RGBColor[
              0.9328811522166989, 0.9479758295944674, 0.9461185605030066], 
             UndirectedEdge[62, 82] -> 
             RGBColor[
              0.9269703869486758, 0.7226332410340339, 0.4238763900247596], 
             UndirectedEdge[42, 144] -> 
             RGBColor[
              0.9925975436662677, 0.9912069083186208, 0.7723413886002382], 
             UndirectedEdge[33, 150] -> 
             RGBColor[
              0.8134462766021606, 0.8518859961950618, 0.8314932245854938], 
             UndirectedEdge[34, 46] -> 
             RGBColor[
              0.9580872470759859, 0.967074251799027, 0.9050891425280645], 
             UndirectedEdge[220, 266] -> 
             RGBColor[
              0.9073448671651219, 0.5743804206387226, 0.45458225674377695`], 
             UndirectedEdge[128, 279] -> 
             RGBColor[
              0.5929597313431227, 0.6769922432389102, 0.9629143770316415], 
             UndirectedEdge[147, 270] -> 
             RGBColor[
              0.5885861781603258, 0.6513533488785981, 0.8552936775584443], 
             UndirectedEdge[30, 90] -> 
             RGBColor[
              0.7909106622222224, 0.8374932583822223, 0.9781939680533334], 
             UndirectedEdge[36, 222] -> 
             RGBColor[
              0.9078373709035938, 0.9223076780318836, 0.7015405909982657], 
             UndirectedEdge[127, 170] -> 
             RGBColor[
              0.8949661929269354, 0.8823920495859354, 0.656690214995871], 
             UndirectedEdge[1, 295] -> 
             RGBColor[
              0.9237282140864287, 0.9420198202508456, 0.9925872157531168], 
             UndirectedEdge[96, 140] -> 
             RGBColor[0.89930888341921, 0.920913441701678, 0.92741554433875], 
             UndirectedEdge[206, 272] -> 
             RGBColor[
              0.9783277590446164, 0.9563841755360925, 0.6362314620157725], 
             UndirectedEdge[129, 265] -> 
             RGBColor[
              0.9921877258349087, 0.9907891874984247, 0.7610879315900019], 
             UndirectedEdge[39, 60] -> 
             RGBColor[
              0.9067492086032225, 0.7444983754819161, 0.6065487091014642], 
             UndirectedEdge[71, 240] -> 
             RGBColor[
              0.9751042228861294, 0.94986666214106, 0.6329560867056244], 
             UndirectedEdge[30, 144] -> 
             RGBColor[
              0.9635926984067522, 0.9714068553543762, 0.9034668827332639], 
             UndirectedEdge[26, 59] -> 
             RGBColor[
              0.40380807445897754`, 0.5121116506619106, 0.9482789658422512], 
             UndirectedEdge[133, 241] -> 
             RGBColor[
              0.9046136711649366, 0.9149352590183262, 0.6941688461771112], 
             UndirectedEdge[236, 266] -> 
             RGBColor[
              0.9238759535206383, 0.9389239347531507, 0.8639972549404554], 
             UndirectedEdge[28, 216] -> 
             RGBColor[
              0.9761971413281476, 0.9788818836169637, 0.7598216311866587], 
             UndirectedEdge[173, 230] -> 
             RGBColor[
              0.9766175436867456, 0.9426935083431853, 0.5898284227939676], 
             UndirectedEdge[39, 266] -> 
             RGBColor[
              0.9360356711343817, 0.7646407612903312, 0.48087131548837464`], 
             UndirectedEdge[86, 141] -> 
             RGBColor[
              0.9801321963404386, 0.9814061155873217, 0.720587157837173], 
             UndirectedEdge[25, 206] -> 
             RGBColor[
              0.9849968825313771, 0.9594214049061154, 0.5349640010148538], 
             UndirectedEdge[141, 165] -> 
             RGBColor[
              0.9767026036103661, 0.9817894784799585, 0.9083807865447687], 
             UndirectedEdge[152, 241] -> 
             RGBColor[
              0.9192628965397924, 0.9266161536896065, 0.6955661023708828], 
             UndirectedEdge[110, 141] -> 
             RGBColor[
              0.9689722320296297, 0.94418718534321, 0.6409875924839508], 
             UndirectedEdge[97, 134] -> 
             RGBColor[
              0.896898200328731, 0.8777345133727807, 0.6477563241025639], 
             UndirectedEdge[103, 119] -> 
             RGBColor[
              0.6058867107562943, 0.6825171429761281, 0.9659292071298737], 
             UndirectedEdge[3, 17] -> 
             RGBColor[
              0.6881370315500688, 0.7562971461728396, 0.9695507263648834], 
             UndirectedEdge[203, 270] -> 
             RGBColor[
              0.5891861579298334, 0.6500913322881612, 0.7355804128435364], 
             UndirectedEdge[51, 141] -> 
             RGBColor[
              0.9578776794530223, 0.9681058228218095, 0.9561862808120597], 
             UndirectedEdge[184, 275] -> 
             RGBColor[
              0.9935602551111111, 0.9886343617777777, 0.5404516942222218], 
             UndirectedEdge[58, 109] -> 
             RGBColor[
              0.9293389762010626, 0.9428145318678757, 0.8330056755805891], 
             UndirectedEdge[179, 281] -> 
             RGBColor[
              0.9020894008761313, 0.7594471517826347, 0.6099216192251962], 
             UndirectedEdge[31, 154] -> 
             RGBColor[
              0.9836173634567902, 0.9859576745679013, 0.8523945002469133], 
             UndirectedEdge[122, 296] -> 
             RGBColor[
              0.48637163573407205`, 0.5884058924161281, 0.9542148054232071], 
             UndirectedEdge[96, 290] -> 
             RGBColor[
              0.9809507415876599, 0.9849255452100456, 0.89974836975768], 
             UndirectedEdge[122, 240] -> 
             RGBColor[
              0.6390442919535348, 0.7078525678905214, 0.9308317187954982], 
             UndirectedEdge[97, 144] -> 
             RGBColor[
              0.9766243628511966, 0.9389450731321538, 0.563786876066597], 
             UndirectedEdge[61, 247] -> 
             RGBColor[
              0.9517078289620484, 0.9597166566255144, 0.7594106664471876], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.9501491635830464, 0.9589797744143991, 0.8002763721987706], 
             UndirectedEdge[45, 287] -> 
             RGBColor[
              0.9731806649778997, 0.9778739526962353, 0.8566242906812984], 
             UndirectedEdge[278, 290] -> 
             RGBColor[
              0.840255246363351, 0.8753659151322994, 0.9489079763751722], 
             UndirectedEdge[109, 110] -> 
             RGBColor[
              0.9828540697935533, 0.9523860189161362, 0.510243171885048], 
             UndirectedEdge[56, 160] -> 
             RGBColor[
              0.970646561001197, 0.9272913560184125, 0.5993906613085737], 
             UndirectedEdge[146, 292] -> 
             RGBColor[
              0.7493996689655174, 0.8041559841350774, 0.9756568135305589], 
             UndirectedEdge[131, 139] -> 
             RGBColor[
              0.8446410461962015, 0.8423423069239855, 0.650626446509712], 
             UndirectedEdge[47, 74] -> 
             RGBColor[
              0.7465254757441844, 0.7977198128956229, 0.8395957025141567], 
             UndirectedEdge[46, 221] -> 
             RGBColor[
              0.9919121127407408, 0.9897677377185186, 0.6996915788148148], 
             UndirectedEdge[48, 74] -> 
             RGBColor[
              0.6330788860202476, 0.7110706885746354, 0.9655771899198495], 
             UndirectedEdge[90, 134] -> 
             RGBColor[
              0.7375695269953979, 0.7949993895327812, 0.9744550854892308], 
             UndirectedEdge[1, 37] -> 
             RGBColor[
              0.9263824224747882, 0.9441362139731562, 0.9928403765186383], 
             UndirectedEdge[33, 295] -> 
             RGBColor[
              0.7762666972706261, 0.8257978393410185, 0.9782285185473885], 
             UndirectedEdge[28, 35] -> 
             RGBColor[
              0.9911558754814582, 0.98103884272436, 0.4873177190907924], 
             UndirectedEdge[21, 169] -> 
             RGBColor[
              0.8467382418381344, 0.8770177296570645, 0.7516617029355281], 
             UndirectedEdge[100, 228] -> 
             RGBColor[
              0.9830268718166262, 0.9587684984005277, 0.5763993837149195], 
             UndirectedEdge[190, 250] -> 
             RGBColor[
              0.9802876560081712, 0.9444496693882345, 0.4389843335174437], 
             UndirectedEdge[81, 180] -> 
             RGBColor[
              0.7279174153175337, 0.7857008325228276, 0.9548062374084332], 
             UndirectedEdge[127, 141] -> 
             RGBColor[
              0.8944598513427144, 0.91787303152203, 0.9617473561919262], 
             UndirectedEdge[143, 185] -> 
             RGBColor[
              0.7317428907306878, 0.7897842816399415, 0.9745705056072143], 
             UndirectedEdge[283, 295] -> 
             RGBColor[
              0.9543466538169767, 0.9644456526486909, 0.920106364381979], 
             UndirectedEdge[26, 100] -> 
             RGBColor[
              0.7903019185202274, 0.8340910172924945, 0.878357915903285], 
             UndirectedEdge[242, 294] -> 
             RGBColor[
              0.8345418069715659, 0.8506059561205157, 0.6732084618787166], 
             UndirectedEdge[39, 228] -> 
             RGBColor[
              0.9262638800487711, 0.7321191833996363, 0.28826237682295985`], 
             UndirectedEdge[39, 82] -> 
             RGBColor[
              0.8685428253322538, 0.4959654970845022, 0.21202124995807092`], 
             UndirectedEdge[109, 258] -> 
             RGBColor[
              0.7818387346083682, 0.8261055512618152, 0.819168272378875], 
             UndirectedEdge[118, 199] -> 
             RGBColor[
              0.9832060152920672, 0.9790870749481995, 0.6684446049054978], 
             UndirectedEdge[57, 115] -> 
             RGBColor[
              0.9940757947855297, 0.9897370490123022, 0.5965650062405979], 
             UndirectedEdge[96, 222] -> 
             RGBColor[
              0.9888174970497161, 0.9851801574981276, 0.6464389465089011], 
             UndirectedEdge[6, 108] -> 
             RGBColor[
              0.9933292149391841, 0.9881401902117706, 0.515304397322632], 
             UndirectedEdge[1, 9] -> 
             RGBColor[
              0.9164513191420334, 0.936217421748236, 0.9918931390171596], 
             UndirectedEdge[180, 190] -> 
             RGBColor[
              0.975826862436816, 0.9785246014666177, 0.7540111967036549], 
             UndirectedEdge[144, 253] -> 
             RGBColor[
              0.9121915845736113, 0.9304599069037803, 0.8999130411415684], 
             UndirectedEdge[53, 192] -> 
             RGBColor[
              0.9860684923996914, 0.9756181995498971, 0.6337625798894032], 
             UndirectedEdge[85, 121] -> 
             RGBColor[
              0.9850782797530865, 0.9862312167901235, 0.8023768837037036], 
             UndirectedEdge[36, 278] -> 
             RGBColor[
              0.7648525899124332, 0.8162649738593657, 0.9771871842288014], 
             UndirectedEdge[122, 207] -> 
             RGBColor[
              0.5973294876863218, 0.6756938455797644, 0.9651130115543366], 
             UndirectedEdge[226, 228] -> 
             RGBColor[
              0.9481829574467874, 0.9335758629605853, 0.6746387821657617], 
             UndirectedEdge[7, 143] -> 
             RGBColor[
              0.9099854713116589, 0.9310617301990592, 0.9912764206789679], 
             UndirectedEdge[133, 164] -> 
             RGBColor[
              0.5500076889427146, 0.6352424938331411, 0.961011209880815], 
             UndirectedEdge[7, 131] -> 
             RGBColor[
              0.9426025774422933, 0.9196602198654904, 0.660180795520118], 
             UndirectedEdge[111, 280] -> 
             RGBColor[
              0.8958061476897543, 0.9189472125132119, 0.9618993718836701], 
             UndirectedEdge[135, 224] -> 
             RGBColor[
              0.9306459432182816, 0.9470879288137302, 0.9777180305952242], 
             UndirectedEdge[91, 102] -> 
             RGBColor[
              0.9578055840312422, 0.8617840774300833, 0.5143325459712775], 
             UndirectedEdge[200, 282] -> 
             RGBColor[
              0.8931411950379472, 0.9164566127681136, 0.9431889476046955], 
             UndirectedEdge[106, 194] -> 
             RGBColor[
              0.9933349368387359, 0.9905749466290258, 0.6920186652691677], 
             UndirectedEdge[38, 259] -> 
             RGBColor[
              0.9872445156332983, 0.9889932936604424, 0.8610549162990178], 
             UndirectedEdge[36, 69] -> 
             RGBColor[
              0.9082185981619766, 0.9269289297021006, 0.8837702657170036], 
             UndirectedEdge[64, 153] -> 
             RGBColor[
              0.8957379848754475, 0.9186384009876544, 0.9508413794126671], 
             UndirectedEdge[159, 175] -> 
             RGBColor[
              0.6598956593777778, 0.7235106853777777, 0.801071863022222], 
             UndirectedEdge[94, 200] -> 
             RGBColor[
              0.7617372671485223, 0.8137942096048599, 0.9768865100160307], 
             UndirectedEdge[88, 201] -> 
             RGBColor[
              0.931059245022622, 0.8264458888014528, 0.6093673002594184], 
             UndirectedEdge[121, 232] -> 
             RGBColor[
              0.9857377172635445, 0.9867230242056932, 0.8012606280073462], 
             UndirectedEdge[140, 289] -> 
             RGBColor[
              0.9010519767111111, 0.9216342555733334, 0.8985279775111109], 
             UndirectedEdge[139, 244] -> 
             RGBColor[
              0.848215758080703, 0.8815970532362123, 0.950325338205573], 
             UndirectedEdge[167, 174] -> 
             RGBColor[
              0.9488187090614716, 0.9613496575364935, 0.9715207547270748], 
             UndirectedEdge[185, 282] -> 
             RGBColor[
              0.7728773167554936, 0.8212621872959013, 0.9320522668146337], 
             UndirectedEdge[236, 249] -> 
             RGBColor[
              0.9110956654962883, 0.9310918268655337, 0.9617340006133075], 
             UndirectedEdge[137, 299] -> 
             RGBColor[
              0.9184167868770006, 0.8992860707270234, 0.656271788861454], 
             UndirectedEdge[201, 218] -> 
             RGBColor[
              0.9272582721355676, 0.8236111294458094, 0.6158013559047025], 
             UndirectedEdge[36, 109] -> 
             RGBColor[
              0.9097011863259001, 0.9271558912750268, 0.8311326056514341], 
             UndirectedEdge[4, 52] -> 
             RGBColor[
              0.6707711015836799, 0.7374783732943935, 0.9517900088592881], 
             UndirectedEdge[5, 191] -> 
             RGBColor[
              0.9852165505018823, 0.9879094966754232, 0.8836838277721382], 
             UndirectedEdge[55, 134] -> 
             RGBColor[
              0.7747489409598949, 0.824044230295858, 0.9781607820118343], 
             UndirectedEdge[67, 69] -> 
             RGBColor[
              0.9208360057120316, 0.9369897079921105, 0.8849737253128205], 
             UndirectedEdge[232, 256] -> 
             RGBColor[
              0.9467976473285602, 0.9593587356060878, 0.9581745662409644], 
             UndirectedEdge[185, 237] -> 
             RGBColor[
              0.7728851097655947, 0.807139978924184, 0.6765933342489772], 
             UndirectedEdge[28, 211] -> 
             RGBColor[
              0.9829900190177638, 0.9534934914380426, 0.45559490872193986`], 
             UndirectedEdge[85, 246] -> 
             RGBColor[
              0.975342555308642, 0.9548234016790124, 0.6426975468148146], 
             UndirectedEdge[26, 127] -> 
             RGBColor[
              0.7056382422760479, 0.7691734560553634, 0.9718454609919263], 
             UndirectedEdge[91, 162] -> 
             RGBColor[
              0.9416096182716049, 0.8049439851851853, 0.2784621948148148], 
             UndirectedEdge[112, 242] -> 
             RGBColor[
              0.8291970080932785, 0.8325766944855967, 0.6524449275171467], 
             UndirectedEdge[85, 122] -> 
             RGBColor[
              0.6374637443760474, 0.7066737980951404, 0.9335071735713552], 
             UndirectedEdge[63, 131] -> 
             RGBColor[
              0.8348829112669426, 0.834719177752676, 0.649653846814919], 
             UndirectedEdge[140, 222] -> 
             RGBColor[
              0.901598169186062, 0.9173965157964497, 0.7009285577257066], 
             UndirectedEdge[121, 256] -> 
             RGBColor[
              0.9558849389539046, 0.9639752536226167, 0.835026276011396], 
             UndirectedEdge[171, 198] -> 
             RGBColor[
              0.7063147122363316, 0.7637343075699023, 0.8055485662622783], 
             UndirectedEdge[10, 117] -> 
             RGBColor[
              0.8803888111301617, 0.7529714090072488, 0.609989471892062], 
             UndirectedEdge[18, 290] -> 
             RGBColor[
              0.9844790669777552, 0.9849205002882881, 0.7348504077391013], 
             UndirectedEdge[207, 240] -> 
             RGBColor[
              0.9367778415050458, 0.9513217086380297, 0.9555718128367539], 
             UndirectedEdge[219, 264] -> 
             RGBColor[
              0.9745471247983117, 0.9572052589984579, 0.6503595521548574], 
             UndirectedEdge[78, 118] -> 
             RGBColor[
              0.9708941160420672, 0.9375561478065328, 0.6206152012263313], 
             UndirectedEdge[2, 208] -> 
             RGBColor[
              0.9283843939484258, 0.9447203978318358, 0.9579400103133902], 
             UndirectedEdge[34, 169] -> 
             RGBColor[
              0.9598903120252315, 0.9662722395894248, 0.7627116245747038], 
             UndirectedEdge[35, 275] -> 
             RGBColor[
              0.9912355214343201, 0.9812091973640906, 0.495986689541971], 
             UndirectedEdge[157, 284] -> 
             RGBColor[
              0.8754889422769232, 0.9030227815111113, 0.9591033494632478], 
             UndirectedEdge[30, 259] -> 
             RGBColor[
              0.9609680724729806, 0.9703215050809518, 0.9469637267700456], 
             UndirectedEdge[62, 192] -> 
             RGBColor[
              0.9899594975045968, 0.9765573166938096, 0.5205829190368617], 
             UndirectedEdge[95, 245] -> 
             RGBColor[
              0.7868710091483371, 0.8343256896211461, 0.9791567975358335], 
             UndirectedEdge[129, 230] -> 
             RGBColor[
              0.9884052113234848, 0.9894732711568532, 0.8418191849284695], 
             UndirectedEdge[35, 92] -> 
             RGBColor[
              0.9721936160097727, 0.9178337781780095, 0.346638809949229], 
             UndirectedEdge[186, 279] -> 
             RGBColor[
              0.8316560277681964, 0.8689190002705364, 0.9837216859264822], 
             UndirectedEdge[217, 233] -> 
             RGBColor[
              0.9739576734954345, 0.9800982560500666, 0.9289670452323792], 
             UndirectedEdge[28, 293] -> 
             RGBColor[
              0.9928809634514997, 0.9900309633943303, 0.6736463052250533], 
             UndirectedEdge[24, 233] -> 
             RGBColor[
              0.762935670142127, 0.8133407766071554, 0.9363887964083176], 
             UndirectedEdge[41, 229] -> 
             RGBColor[
              0.9852118660673996, 0.9850213210155447, 0.6982456104061047], 
             UndirectedEdge[197, 214] -> 
             RGBColor[
              0.8721570228693305, 0.899800132773581, 0.9291499032282755], 
             UndirectedEdge[84, 144] -> 
             RGBColor[
              0.9875229424956411, 0.9891084303232651, 0.856440662644375], 
             UndirectedEdge[101, 205] -> 
             RGBColor[
              0.949379623308642, 0.9611312626041153, 0.9476921994041152], 
             UndirectedEdge[7, 297] -> 
             RGBColor[
              0.9561544759331876, 0.9646215634875321, 0.8653221854669402], 
             UndirectedEdge[30, 47] -> 
             RGBColor[
              0.9662344143055556, 0.9724812922222223, 0.8583798179166666], 
             UndirectedEdge[140, 298] -> 
             RGBColor[
              0.7173235505851415, 0.7787945436423407, 0.9726671562656147], 
             UndirectedEdge[159, 252] -> 
             RGBColor[
              0.6342121594028932, 0.6344591682640812, 0.6075844216251154], 
             UndirectedEdge[26, 195] -> 
             RGBColor[
              0.7916849180740742, 0.8335071958518518, 0.7714288601481483], 
             UndirectedEdge[43, 185] -> 
             RGBColor[
              0.752346355987817, 0.7341725415908507, 0.6159977702489772], 
             UndirectedEdge[36, 95] -> 
             RGBColor[
              0.7332156213683588, 0.7915423398420938, 0.9740390987506491], 
             UndirectedEdge[6, 46] -> 
             RGBColor[
              0.9912272835976204, 0.9883029574282315, 0.6251521528617263], 
             UndirectedEdge[148, 183] -> 
             RGBColor[
              0.9061251863598974, 0.9152109002467701, 0.6929454525649585], 
             UndirectedEdge[222, 261] -> 
             RGBColor[
              0.9126882926428519, 0.9261756713520051, 0.7020032762442252], 
             UndirectedEdge[64, 145] -> 
             RGBColor[
              0.7366510095865586, 0.7920844832987655, 0.9365397977237782], 
             UndirectedEdge[8, 247] -> 
             RGBColor[
              0.9519581448139003, 0.9602520569218107, 0.7866560021508917], 
             UndirectedEdge[122, 136] -> 
             RGBColor[
              0.6314334690674053, 0.6599956524161278, 0.6260940587565402], 
             UndirectedEdge[139, 206] -> 
             RGBColor[
              0.8483006775779828, 0.8546871028970449, 0.6648434233645348], 
             UndirectedEdge[65, 80] -> 
             RGBColor[
              0.9665572041782557, 0.9745789981504712, 0.9414941094348399], 
             UndirectedEdge[171, 245] -> 
             RGBColor[
              0.9632835765547785, 0.9697831066734611, 0.828304971488066], 
             UndirectedEdge[137, 232] -> 
             RGBColor[
              0.923400965539722, 0.9407028566336768, 0.9559429698454806], 
             UndirectedEdge[64, 221] -> 
             RGBColor[
              0.9866643651717437, 0.9867992768395062, 0.7509071417830375], 
             UndirectedEdge[140, 263] -> 
             RGBColor[0.8427798000000002, 0.87753756, 0.9848493511111112], 
             UndirectedEdge[200, 295] -> 
             RGBColor[
              0.861188115313736, 0.892299663431242, 0.9865829114037115], 
             UndirectedEdge[136, 232] -> 
             RGBColor[0.9699607128191, 0.9349365530945819, 0.618112059118457],
              UndirectedEdge[45, 68] -> 
             RGBColor[
              0.9910023097924828, 0.9905472381161702, 0.7987785422217831], 
             UndirectedEdge[224, 254] -> 
             RGBColor[
              0.9378059349348482, 0.9156557301642902, 0.6594588117191151], 
             UndirectedEdge[148, 272] -> 
             RGBColor[
              0.9842326005671076, 0.9763025925141776, 0.6591706562948958], 
             UndirectedEdge[167, 185] -> 
             RGBColor[
              0.7528808364609881, 0.8064103643170228, 0.9686560512437449], 
             UndirectedEdge[59, 137] -> 
             RGBColor[
              0.5441700671795993, 0.6229798342010051, 0.9616069565692746], 
             UndirectedEdge[55, 97] -> 
             RGBColor[
              0.8411217406311637, 0.8340763169230767, 0.64221965790927], 
             UndirectedEdge[156, 202] -> 
             RGBColor[
              0.8666033794458881, 0.7381873763903773, 0.6079259843518641], 
             UndirectedEdge[78, 176] -> 
             RGBColor[
              0.9796569187308022, 0.9417590959578732, 0.48440311439683614`], 
             UndirectedEdge[131, 143] -> 
             RGBColor[
              0.9349105480608204, 0.9135268044312794, 0.6594471228909574], 
             UndirectedEdge[230, 289] -> 
             RGBColor[
              0.9887218021492776, 0.9896041895993317, 0.8365724556342875], 
             UndirectedEdge[35, 126] -> 
             RGBColor[
              0.9637592545502526, 0.8843943455753551, 0.3398523247389904], 
             UndirectedEdge[147, 183] -> 
             RGBColor[
              0.908962661943925, 0.9274334970392274, 0.8799883188960281], 
             UndirectedEdge[66, 258] -> 
             RGBColor[
              0.7664192007804691, 0.8167599064821224, 0.9525156113187235], 
             UndirectedEdge[60, 232] -> 
             RGBColor[
              0.9562492546699504, 0.9668913462848954, 0.958942779208596], 
             UndirectedEdge[39, 127] -> 
             RGBColor[
              0.84974964902842, 0.6990523183469664, 0.6012453300032516], 
             UndirectedEdge[113, 258] -> 
             RGBColor[
              0.7807618487654322, 0.8260463580246915, 0.8650823950617283], 
             UndirectedEdge[45, 223] -> 
             RGBColor[
              0.9738325210853224, 0.9227315965256517, 0.5145349398869683], 
             UndirectedEdge[40, 80] -> 
             RGBColor[
              0.9789243304358697, 0.9823050644442461, 0.8535069110229149], 
             UndirectedEdge[18, 198] -> 
             RGBColor[
              0.7057629339883686, 0.7625541096908479, 0.7454909091521272], 
             UndirectedEdge[13, 58] -> 
             RGBColor[
              0.8745589375431078, 0.7331043932537493, 0.6064288974165901], 
             UndirectedEdge[16, 195] -> 
             RGBColor[
              0.9941204883365926, 0.9898326439988148, 0.6014296234571852], 
             UndirectedEdge[17, 90] -> 
             RGBColor[
              0.6668529075994515, 0.7396698267772841, 0.9674293238009328], 
             UndirectedEdge[8, 273] -> 
             RGBColor[
              0.9920540647407408, 0.9898264385185185, 0.6973390668148147], 
             UndirectedEdge[85, 256] -> 
             RGBColor[
              0.9461382098181021, 0.958866928190518, 0.9592908219373217], 
             UndirectedEdge[149, 227] -> 
             RGBColor[
              0.8335686118407375, 0.8707091171659658, 0.976935457579768], 
             UndirectedEdge[182, 208] -> 
             RGBColor[
              0.9245399795061728, 0.7510898923456789, 0.5719873199999999], 
             UndirectedEdge[82, 100] -> 
             RGBColor[
              0.9253058171001088, 0.7226148120853936, 0.5001582568500307], 
             UndirectedEdge[227, 264] -> 
             RGBColor[
              0.8476285884456756, 0.8811950246968299, 0.9531355846168051], 
             UndirectedEdge[74, 259] -> 
             RGBColor[
              0.7412591339116092, 0.7955600257543525, 0.9281796113675357], 
             UndirectedEdge[96, 105] -> 
             RGBColor[
              0.8986615389747656, 0.920407731301678, 0.9273510230943056], 
             UndirectedEdge[60, 100] -> 
             RGBColor[
              0.9635122003710775, 0.9711476904828075, 0.8946857159934238], 
             UndirectedEdge[73, 87] -> 
             RGBColor[
              0.7819989802607319, 0.6932420348096843, 0.6037079001021624], 
             UndirectedEdge[68, 223] -> 
             RGBColor[
              0.9707424577639506, 0.9214537759312593, 0.5657452859496297], 
             UndirectedEdge[162, 191] -> 
             RGBColor[
              0.9739782090072321, 0.9333646907560815, 0.5766325315844838], 
             UndirectedEdge[87, 149] -> 
             RGBColor[
              0.8023152545565809, 0.8462937569212696, 0.9738204150049126], 
             UndirectedEdge[60, 256] -> 
             RGBColor[
              0.9263964763603104, 0.9441435757018186, 0.9927084272126458], 
             UndirectedEdge[145, 169] -> 
             RGBColor[
              0.7437018221048012, 0.7942509319681756, 0.7429467168021948], 
             UndirectedEdge[144, 235] -> 
             RGBColor[
              0.5844523628511966, 0.647758773132154, 0.8746297760665973], 
             UndirectedEdge[36, 88] -> 
             RGBColor[
              0.8870703971585197, 0.9124321040704957, 0.9766867188844109], 
             UndirectedEdge[38, 123] -> 
             RGBColor[
              0.9572449158220462, 0.8646587134387498, 0.5388256017363795], 
             UndirectedEdge[183, 244] -> 
             RGBColor[
              0.9001354253401264, 0.9222024336078524, 0.9554881731268734], 
             UndirectedEdge[2, 32] -> 
             RGBColor[
              0.9335011215435691, 0.9483719946403247, 0.9419143067810974], 
             UndirectedEdge[106, 151] -> 
             RGBColor[
              0.9849067861771124, 0.985665168683025, 0.7679019698295199], 
             UndirectedEdge[164, 277] -> 
             RGBColor[
              0.5421063177777778, 0.6290548088122606, 0.9602276751724138], 
             UndirectedEdge[296, 299] -> 
             RGBColor[
              0.8199147008230453, 0.8219300071879287, 0.6465616248010975], 
             UndirectedEdge[75, 174] -> 
             RGBColor[
              0.9055258069141654, 0.9270578139927631, 0.9753220495695272], 
             UndirectedEdge[31, 66] -> 
             RGBColor[
              0.97814083843479, 0.9818732911734803, 0.861664828602674], 
             UndirectedEdge[2, 268] -> 
             RGBColor[
              0.9384073136511026, 0.9501525805450846, 0.8425608076906919], 
             UndirectedEdge[46, 264] -> 
             RGBColor[
              0.9806789835555555, 0.9841656974222222, 0.8752571253333332], 
             UndirectedEdge[71, 160] -> 
             RGBColor[
              0.9779712058765432, 0.9519991030913579, 0.6278455235061728], 
             UndirectedEdge[50, 114] -> 
             RGBColor[
              0.9925590536639118, 0.9911909917134987, 0.7729792675482092], 
             UndirectedEdge[126, 197] -> 
             RGBColor[
              0.8486541552107841, 0.8034726563786752, 0.6231568563710583], 
             UndirectedEdge[265, 269] -> 
             RGBColor[
              0.9763087367356327, 0.9302084367036578, 0.49320315815477317`], 
             UndirectedEdge[144, 257] -> 
             RGBColor[
              0.9820290348511966, 0.9571763008654873, 0.5847830061999306], 
             UndirectedEdge[86, 107] -> 
             RGBColor[
              0.9369890149280928, 0.9478139045650994, 0.7445203396742099], 
             UndirectedEdge[149, 245] -> 
             RGBColor[
              0.9376174195592387, 0.9528972400391778, 0.987066069465151], 
             UndirectedEdge[143, 283] -> 
             RGBColor[
              0.945165307516382, 0.9571246963296027, 0.9192306393755436], 
             UndirectedEdge[66, 154] -> 
             RGBColor[
              0.9694718710273826, 0.9767527519142211, 0.9365603387261309], 
             UndirectedEdge[57, 159] -> 
             RGBColor[
              0.659534783176362, 0.7227388076731303, 0.7617927155678668], 
             UndirectedEdge[7, 167] -> 
             RGBColor[
              0.9311234170419593, 0.9476878128761406, 0.9853619663154985], 
             UndirectedEdge[57, 89] -> 
             RGBColor[
              0.9056288698430286, 0.5617854510064635, 0.37293270223453345`], 
             UndirectedEdge[122, 256] -> 
             RGBColor[
              0.6082704035768656, 0.6844178349276335, 0.9661565658790476], 
             UndirectedEdge[39, 232] -> 
             RGBColor[
              0.9271503795714723, 0.7597135353861852, 0.5720148481297826], 
             UndirectedEdge[72, 286] -> 
             RGBColor[
              0.8336265463335526, 0.8706671895156696, 0.9725278647600264], 
             UndirectedEdge[71, 299] -> 
             RGBColor[
              0.9691989341563787, 0.9077629138545953, 0.3348441048010974], 
             UndirectedEdge[90, 158] -> 
             RGBColor[
              0.8006981704536491, 0.7940881754893888, 0.625911027106588], 
             UndirectedEdge[52, 236] -> 
             RGBColor[
              0.6189890391556729, 0.6967353493750703, 0.9658015065009031], 
             UndirectedEdge[17, 134] -> 
             RGBColor[
              0.7598087812615157, 0.812372863990065, 0.9766716865168301], 
             UndirectedEdge[54, 72] -> 
             RGBColor[
              0.8275227549682227, 0.8658988613105414, 0.9719194958799036], 
             UndirectedEdge[170, 192] -> 
             RGBColor[
              0.9767484797866901, 0.9332293039832469, 0.36417266396279246`], 
             UndirectedEdge[140, 198] -> 
             RGBColor[
              0.6150152807346191, 0.6947755129109275, 0.9648784823875115], 
             UndirectedEdge[19, 89] -> 
             RGBColor[
              0.7802610048059884, 0.46672105337586794`, 0.569628594218636], 
             UndirectedEdge[239, 295] -> 
             RGBColor[
              0.9469438339323545, 0.9304680225904011, 0.6714020945868946], 
             UndirectedEdge[51, 69] -> 
             RGBColor[
              0.9702769290530222, 0.9760776948218095, 0.8780795202787264], 
             UndirectedEdge[186, 269] -> 
             RGBColor[
              0.9199644917296346, 0.8888530204047513, 0.6392555074500902], 
             UndirectedEdge[37, 282] -> 
             RGBColor[
              0.9552634226439464, 0.9658435704622066, 0.9491533950291837], 
             UndirectedEdge[1, 239] -> 
             RGBColor[
              0.9500159134874075, 0.9329176154382223, 0.6716951122773334], 
             UndirectedEdge[59, 200] -> 
             RGBColor[
              0.5099543625070256, 0.5958447803916402, 0.9583042582146237], 
             UndirectedEdge[145, 221] -> 
             RGBColor[
              0.7439289605629631, 0.794736758162963, 0.767669336237037], 
             UndirectedEdge[75, 297] -> 
             RGBColor[
              0.9263074901347089, 0.940822387186672, 0.8624753533167624], 
             UndirectedEdge[142, 185] -> 
             RGBColor[
              0.777308573763146, 0.8214924513037372, 0.7421536873460082], 
             UndirectedEdge[36, 258] -> 
             RGBColor[
              0.6967055072730877, 0.7619017844576563, 0.9711648888281146], 
             UndirectedEdge[13, 289] -> 
             RGBColor[
              0.9376443671059687, 0.7810390459987999, 0.5205666161704313], 
             UndirectedEdge[53, 170] -> 
             RGBColor[
              0.9774034339147765, 0.9463889226277942, 0.6001004639345003], 
             UndirectedEdge[130, 226] -> 
             RGBColor[
              0.9064393216812527, 0.9282341267414409, 0.9909381857615347], 
             UndirectedEdge[224, 249] -> 
             RGBColor[
              0.9385421172098629, 0.9529768824478533, 0.964351867679485], 
             UndirectedEdge[234, 271] -> 
             RGBColor[
              0.8817738608193478, 0.9081747442570904, 0.9719866871466412], 
             UndirectedEdge[78, 266] -> 
             RGBColor[
              0.9795780731320095, 0.9423332187903949, 0.529812475331216], 
             UndirectedEdge[127, 232] -> 
             RGBColor[
              0.8992496950951478, 0.9214452891499456, 0.9536394001103834], 
             UndirectedEdge[57, 292] -> 
             RGBColor[
              0.8681838587319175, 0.8940771646064636, 0.7783047223234223], 
             UndirectedEdge[52, 107] -> 
             RGBColor[
              0.632715777671365, 0.7076806780650922, 0.967110775074534], 
             UndirectedEdge[26, 130] -> 
             RGBColor[
              0.7404088375308644, 0.796898584888889, 0.9751619114074075], 
             UndirectedEdge[51, 58] -> 
             RGBColor[
              0.906264079756828, 0.9277595301834256, 0.9793115465915516], 
             UndirectedEdge[192, 195] -> 
             RGBColor[
              0.9896779272098766, 0.9759550663045267, 0.48993573010699587`], 
             UndirectedEdge[118, 266] -> 
             RGBColor[
              0.9857370516740767, 0.9871838870135943, 0.8329245788492138], 
             UndirectedEdge[171, 289] -> 
             RGBColor[
              0.9923514082128237, 0.9905930502323081, 0.7391980613858777], 
             UndirectedEdge[1, 283] -> 
             RGBColor[
              0.9574187333720298, 0.9668952454965121, 0.9203993820724178], 
             UndirectedEdge[44, 59] -> 
             RGBColor[
              0.5408921633478663, 0.6203661226619104, 0.9612943071755846], 
             UndirectedEdge[62, 127] -> 
             RGBColor[
              0.908177210644842, 0.9257200622964981, 0.8131004700699402], 
             UndirectedEdge[46, 219] -> 
             RGBColor[
              0.9837500505760896, 0.9631234853095689, 0.5924489041548573], 
             UndirectedEdge[55, 252] -> 
             RGBColor[
              0.8311329867007237, 0.7966353285204915, 0.6229274662010523], 
             UndirectedEdge[55, 144] -> 
             RGBColor[
              0.8544751034823604, 0.885254790055231, 0.8941913339758676], 
             UndirectedEdge[160, 296] -> 
             RGBColor[
              0.8286869725432098, 0.8661661964246914, 0.9395630435061729], 
             UndirectedEdge[154, 179] -> 
             RGBColor[
              0.9457535072142602, 0.9585700572779924, 0.959596691842276], 
             UndirectedEdge[6, 145] -> 
             RGBColor[
              0.7432441314198427, 0.793271977872676, 0.6931299102839488], 
             UndirectedEdge[132, 243] -> 
             RGBColor[
              0.9462424960976654, 0.8245764411931488, 0.27560365439062967`], 
             UndirectedEdge[53, 59] -> 
             RGBColor[
              0.6024560377228663, 0.6677191397591327, 0.9027136357728068], 
             UndirectedEdge[4, 228] -> 
             RGBColor[
              0.9658862248630349, 0.9471453807817791, 0.6573768186334257], 
             UndirectedEdge[71, 98] -> 
             RGBColor[
              0.9570390797770089, 0.9363937079892348, 0.663535661845444], 
             UndirectedEdge[201, 259] -> 
             RGBColor[
              0.9486370642768371, 0.8394662698251206, 0.5756213125287233], 
             UndirectedEdge[34, 187] -> 
             RGBColor[
              0.903692302239187, 0.926043728004194, 0.9906761725948572], 
             UndirectedEdge[18, 260] -> 
             RGBColor[
              0.8126248454073848, 0.8502699917867793, 0.7536380623750409], 
             UndirectedEdge[263, 289] -> 
             RGBColor[
              0.9317422211555556, 0.9460420155733333, 0.9014721730666664], 
             UndirectedEdge[173, 209] -> 
             RGBColor[
              0.9797597286860436, 0.9439928825908661, 0.5377542856414914], 
             UndirectedEdge[4, 199] -> 
             RGBColor[
              0.973126979566636, 0.9715701466070792, 0.6855057833551246], 
             UndirectedEdge[253, 292] -> 
             RGBColor[
              0.7884172106113034, 0.8347533473716263, 0.97951478516386], 
             UndirectedEdge[128, 209] -> 
             RGBColor[
              0.6993133645115387, 0.7584027853107163, 0.8504337617114411], 
             UndirectedEdge[44, 137] -> 
             RGBColor[
              0.8668736016095108, 0.8966854955390946, 0.9871643720603567], 
             UndirectedEdge[129, 263] -> 
             RGBColor[
              0.9314256303297628, 0.9459110971308549, 0.9067189023608484], 
             UndirectedEdge[73, 289] -> 
             RGBColor[
              0.946368976921435, 0.8206554614864394, 0.5278466444602126], 
             UndirectedEdge[128, 276] -> 
             RGBColor[
              0.6958192871625346, 0.7569578945332109, 0.9083396657667585], 
             UndirectedEdge[96, 196] -> 
             RGBColor[
              0.9873385516722339, 0.9890321799791583, 0.8594964957763864], 
             UndirectedEdge[24, 224] -> 
             RGBColor[
              0.7261010346980343, 0.7851610560920457, 0.974175749715679], 
             UndirectedEdge[88, 278] -> 
             RGBColor[
              0.8273550280803332, 0.8657449534589934, 0.9707446810125385], 
             UndirectedEdge[158, 253] -> 
             RGBColor[
              0.8955940655093968, 0.868338133101015, 0.6353384307948924], 
             UndirectedEdge[67, 110] -> 
             RGBColor[
              0.9103382500083279, 0.898243030401987, 0.6634432479301046], 
             UndirectedEdge[155, 275] -> 
             RGBColor[
              0.9914083802962963, 0.9895594314074074, 0.708039729037037], 
             UndirectedEdge[101, 108] -> 
             RGBColor[
              0.9540873669300411, 0.9620460657316874, 0.7946593907621401], 
             UndirectedEdge[102, 210] -> 
             RGBColor[
              0.9909827704885876, 0.9905391581118722, 0.7991023590534252], 
             UndirectedEdge[176, 199] -> 
             RGBColor[
              0.9919688179808022, 0.9832900230995398, 0.5322325180760027], 
             UndirectedEdge[62, 226] -> 
             RGBColor[
              0.9579969725191828, 0.9654449880936866, 0.8178523234321413], 
             UndirectedEdge[69, 113] -> 
             RGBColor[
              0.9922749396543209, 0.9910735032691358, 0.7776877719506173], 
             UndirectedEdge[51, 258] -> 
             RGBColor[
              0.7587638381641335, 0.8110505495773651, 0.9654741433898375], 
             UndirectedEdge[30, 74] -> 
             RGBColor[
              0.71749873254974, 0.7779286851178452, 0.9723910979308233], 
             UndirectedEdge[118, 228] -> 
             RGBColor[
              0.9759652605884661, 0.9546623091228994, 0.6403156401837989], 
             UndirectedEdge[71, 121] -> 
             RGBColor[
              0.9832704044444445, 0.9537962177777777, 0.5113669955555555], 
             UndirectedEdge[1, 20] -> 
             RGBColor[
              0.9029298932885697, 0.9254358038020114, 0.9906034533485368], 
             UndirectedEdge[126, 293] -> 
             RGBColor[
              0.9654843425202941, 0.8933864662453253, 0.5261809108732514], 
             UndirectedEdge[112, 159] -> 
             RGBColor[
              0.6472163404938271, 0.6820719005349793, 0.6385909784362139], 
             UndirectedEdge[17, 159] -> 
             RGBColor[
              0.5071114942661181, 0.6065385072839506, 0.9557919757475994], 
             UndirectedEdge[139, 172] -> 
             RGBColor[
              0.7656295822891478, 0.8168349157754073, 0.9772744596134951], 
             UndirectedEdge[47, 233] -> 
             RGBColor[
              0.9885771150462963, 0.9891444418518518, 0.8205594534722223], 
             UndirectedEdge[98, 182] -> 
             RGBColor[
              0.9082469612584902, 0.7389385860139261, 0.5995671499935921], 
             UndirectedEdge[84, 159] -> 
             RGBColor[
              0.6550994929777778, 0.7220635138577778, 0.9195303999111111], 
             UndirectedEdge[118, 176] -> 
             RGBColor[
              0.9858158972728692, 0.9866097641810725, 0.7875152179148339], 
             UndirectedEdge[18, 278] -> 
             RGBColor[
              0.8493610414486508, 0.8791324084038521, 0.757187577720858], 
             UndirectedEdge[155, 197] -> 
             RGBColor[
              0.8735964862429998, 0.9003953878711144, 0.9052942699147797], 
             UndirectedEdge[72, 215] -> 
             RGBColor[
              0.9717137297562572, 0.9764881344767933, 0.8427870821447333], 
             UndirectedEdge[162, 239] -> 
             RGBColor[
              0.9667355333333334, 0.8994532844444443, 0.3252742577777777], 
             UndirectedEdge[139, 272] -> 
             RGBColor[
              0.8517815196675818, 0.8842563923893079, 0.9442894339385542], 
             UndirectedEdge[9, 75] -> 
             RGBColor[
              0.8820429368693796, 0.9087811117146776, 0.9886112367992683], 
             UndirectedEdge[18, 254] -> 
             RGBColor[
              0.980486465114172, 0.9451707156074685, 0.435469620731925], 
             UndirectedEdge[25, 244] -> 
             RGBColor[
              0.9849119630340973, 0.986331355245283, 0.8204459158558919], 
             UndirectedEdge[30, 257] -> 
             RGBColor[0.9556440075555556, 0.9384596099555556, 0.6724913368], 
             UndirectedEdge[29, 270] -> 
             RGBColor[
              0.5025547653594106, 0.23420483372613546`, 0.5504402214941025], 
             UndirectedEdge[73, 298] -> 
             RGBColor[
              0.7626405507954652, 0.6778157495554467, 0.6019858232147164], 
             UndirectedEdge[73, 96] -> 
             RGBColor[
              0.9446258836295338, 0.819934647614784, 0.5567342112878515], 
             UndirectedEdge[108, 205] -> 
             RGBColor[
              0.9893780283950617, 0.9888435861728395, 0.7506837748971193], 
             UndirectedEdge[9, 43] -> 
             RGBColor[
              0.9248013585435146, 0.8708351325322359, 0.6321516609620484], 
             UndirectedEdge[151, 251] -> 
             RGBColor[
              0.9853920372459175, 0.9868027251869103, 0.8279623139808276], 
             UndirectedEdge[209, 279] -> 
             RGBColor[
              0.8873599432620685, 0.9102578744755521, 0.8663264528171566], 
             UndirectedEdge[53, 68] -> 
             RGBColor[
              0.9873178464994444, 0.9890236178581111, 0.8598396340727777], 
             UndirectedEdge[282, 295] -> 
             RGBColor[
              0.9526092142555869, 0.963727176739896, 0.9489002342636621], 
             UndirectedEdge[35, 197] -> 
             RGBColor[
              0.8734236273810236, 0.8920451538277977, 0.6932412304197135], 
             UndirectedEdge[116, 168] -> 
             RGBColor[
              0.9596764144580563, 0.9694473164434055, 0.9531414916337613], 
             UndirectedEdge[27, 152] -> 
             RGBColor[
              0.8427008526049067, 0.8774108016346154, 0.9848587536810297], 
             UndirectedEdge[114, 231] -> 
             RGBColor[
              0.9947944773641874, 0.9920804480088155, 0.7333920991044993], 
             UndirectedEdge[83, 155] -> 
             RGBColor[
              0.988219446635985, 0.9893964526846373, 0.8448977865439403], 
             UndirectedEdge[62, 199] -> 
             RGBColor[
              0.9919321963687944, 0.9832116931744681, 0.5282464816113474], 
             UndirectedEdge[96, 278] -> 
             RGBColor[
              0.8458327160585555, 0.8791374533256096, 0.9220855397394367], 
             UndirectedEdge[2, 178] -> 
             RGBColor[
              0.9365871979978084, 0.9496481665627, 0.8907700334245015], 
             UndirectedEdge[6, 213] -> 
             RGBColor[
              0.9935589221663379, 0.9886315107436892, 0.5403066114096298], 
             UndirectedEdge[79, 93] -> 
             RGBColor[
              0.9633741308324237, 0.8938558190502768, 0.5677194442062856], 
             UndirectedEdge[270, 272] -> 
             RGBColor[
              0.5833247031434058, 0.6487816246003186, 0.9247576275222709], 
             UndirectedEdge[161, 186] -> 
             RGBColor[
              0.9300119247213701, 0.92274537113533, 0.6782878873244704], 
             UndirectedEdge[189, 275] -> 
             RGBColor[
              0.860190537213493, 0.8878351489504812, 0.7777024824157585], 
             UndirectedEdge[260, 261] -> 
             RGBColor[
              0.7329673156104253, 0.7912705505624142, 0.9741003541289437], 
             UndirectedEdge[195, 200] -> 
             RGBColor[
              0.8978312061221223, 0.9172403255815816, 0.7814541525205205], 
             UndirectedEdge[66, 110] -> 
             RGBColor[
              0.9674345359656542, 0.9430403741364434, 0.6435905108248965], 
             UndirectedEdge[63, 172] -> 
             RGBColor[
              0.7558714473598889, 0.809211786604098, 0.9763018599187021], 
             UndirectedEdge[4, 236] -> 
             RGBColor[
              0.9051129607052648, 0.9266299354281684, 0.9718611592851973], 
             UndirectedEdge[143, 167] -> 
             RGBColor[
              0.9234313876604865, 0.9415543974419296, 0.984628293686338], 
             UndirectedEdge[135, 249] -> 
             RGBColor[
              0.9609642587237376, 0.9704077885880993, 0.950961507215542], 
             UndirectedEdge[135, 288] -> 
             RGBColor[
              0.5717672756994115, 0.6410207730325437, 0.9492429128434183], 
             UndirectedEdge[83, 214] -> 
             RGBColor[
              0.9867799832623159, 0.9888011975871038, 0.8687534198574363], 
             UndirectedEdge[36, 290] -> 
             RGBColor[
              0.8999706154415377, 0.9220530657438017, 0.9548500142470446], 
             UndirectedEdge[79, 119] -> 
             RGBColor[
              0.6432993077644507, 0.7105589960829134, 0.9027178596465368], 
             UndirectedEdge[145, 264] -> 
             RGBColor[
              0.7326958313777778, 0.7891347178666668, 0.9432348827555556], 
             UndirectedEdge[54, 238] -> 
             RGBColor[
              0.8170388257102784, 0.7601878473846153, 0.6158898583624808], 
             UndirectedEdge[177, 273] -> 
             RGBColor[
              0.9665816878463649, 0.9736047905953361, 0.8970079455144031], 
             UndirectedEdge[98, 208] -> 
             RGBColor[
              0.9586553778017002, 0.9686858289768893, 0.9548698403639624], 
             UndirectedEdge[125, 170] -> 
             RGBColor[
              0.9764433017619987, 0.9459918833083498, 0.6160123384483893], 
             UndirectedEdge[22, 217] -> 
             RGBColor[
              0.9669411554707431, 0.9748653483957457, 0.9408441800471938], 
             UndirectedEdge[78, 236] -> 
             RGBColor[
              0.9090330178886289, 0.8892961955460893, 0.6516878773175729], 
             UndirectedEdge[86, 240] -> 
             RGBColor[
              0.9858431501599013, 0.9856653355950483, 0.7109200026761306], 
             UndirectedEdge[59, 170] -> 
             RGBColor[
              0.593136025109865, 0.6253302441924824, 0.6331237198461961], 
             UndirectedEdge[95, 109] -> 
             RGBColor[
              0.8183488487036392, 0.8557461066462526, 0.8220424823014094], 
             UndirectedEdge[30, 252] -> 
             RGBColor[
              0.9402505816251154, 0.8827873938196368, 0.6322030149584487], 
             UndirectedEdge[116, 119] -> 
             RGBColor[
              0.6179757367434547, 0.6921396739114367, 0.9664952872069108], 
             UndirectedEdge[6, 231] -> 
             RGBColor[
              0.9939070731087315, 0.9893761704060093, 0.5782006929506152], 
             UndirectedEdge[214, 275] -> 
             RGBColor[
              0.9899689169226271, 0.9889641763098739, 0.731895362350533], 
             UndirectedEdge[157, 257] -> 
             RGBColor[
              0.8785713172991454, 0.8773412677333334, 0.6664097246632479], 
             UndirectedEdge[128, 173] -> 
             RGBColor[
              0.6853595167670976, 0.7107272513542242, 0.6343422098559762], 
             UndirectedEdge[14, 113] -> 
             RGBColor[
              0.9109037777777778, 0.9289142913580247, 0.8772641469135802], 
             UndirectedEdge[213, 231] -> 
             RGBColor[
              0.9948933374131619, 0.9914856900265687, 0.6855494759701253], 
             UndirectedEdge[29, 148] -> 
             RGBColor[
              0.9034626627831124, 0.5617258016399944, 0.28485325026672753`], 
             UndirectedEdge[109, 154] -> 
             RGBColor[
              0.9848914048552817, 0.9860983966939139, 0.8032129997862824], 
             UndirectedEdge[74, 123] -> 
             RGBColor[
              0.7112595341003571, 0.6712254455326598, 0.6059502968048974], 
             UndirectedEdge[189, 216] -> 
             RGBColor[
              0.8425250083463545, 0.8774358355034719, 0.9641564037572994], 
             UndirectedEdge[29, 162] -> 
             RGBColor[
              0.8902541294497791, 0.51717031719555, 0.23354059248894987`], 
             UndirectedEdge[73, 140] -> 
             RGBColor[
              0.8574065557658794, 0.752151005913106, 0.6112238225046571], 
             UndirectedEdge[9, 295] -> 
             RGBColor[
              0.9133792395869803, 0.9337678289004148, 0.9916001213267208], 
             UndirectedEdge[169, 221] -> 
             RGBColor[
              0.9937151776899863, 0.9889657255089164, 0.5573140608614541], 
             UndirectedEdge[22, 61] -> 
             RGBColor[
              0.9806508604938271, 0.9819656997530865, 0.7334173814814811], 
             UndirectedEdge[11, 143] -> 
             RGBColor[
              0.8095046177511354, 0.8517757035179614, 0.9814709691646649], 
             UndirectedEdge[100, 299] -> 
             RGBColor[
              0.9789291926766059, 0.9449460644804231, 0.5604806740377158], 
             UndirectedEdge[181, 232] -> 
             RGBColor[
              0.9565067964018665, 0.9670834204868725, 0.9585068282341034], 
             UndirectedEdge[49, 292] -> 
             RGBColor[
              0.8666699406933334, 0.8946099332551112, 0.8876277097066667], 
             UndirectedEdge[4, 39] -> 
             RGBColor[
              0.9172726783190082, 0.7523467619653488, 0.5887352198331166], 
             UndirectedEdge[33, 75] -> 
             RGBColor[
              0.7449303945530255, 0.8008111221552813, 0.975239634019936], 
             UndirectedEdge[223, 271] -> 
             RGBColor[
              0.8814406312629997, 0.8522977128113962, 0.6315648294295859], 
             UndirectedEdge[21, 34] -> 
             RGBColor[
              0.8131405146315416, 0.8548100699323604, 0.98178188608362], 
             UndirectedEdge[51, 165] -> 
             RGBColor[
              0.967509544930055, 0.9749333103684346, 0.9239422369568284], 
             UndirectedEdge[36, 138] -> 
             RGBColor[
              0.8805364010980565, 0.9075590605070389, 0.9877470698756711], 
             UndirectedEdge[50, 205] -> 
             RGBColor[
              0.9877204628643335, 0.9891901100717615, 0.8531672389688125], 
             UndirectedEdge[237, 283] -> 
             RGBColor[
              0.9863075265512888, 0.9744803936138452, 0.6212534680173065], 
             UndirectedEdge[140, 245] -> 
             RGBColor[
              0.8719841450530659, 0.9008243120144863, 0.9876348876132992], 
             UndirectedEdge[19, 49] -> 
             RGBColor[
              0.8670569566104327, 0.8949122730309791, 0.8876662838364138], 
             UndirectedEdge[235, 292] -> 
             RGBColor[0.46067798888888895`, 0.5520522136, 0.9542315200888889],
              UndirectedEdge[15, 115] -> 
             RGBColor[
              0.9845806229671923, 0.9854336656601597, 0.7693863091912496], 
             UndirectedEdge[69, 110] -> 
             RGBColor[
              0.9813714816296297, 0.9521590573432099, 0.5628808319506173], 
             UndirectedEdge[34, 50] -> 
             RGBColor[
              0.9585316128868215, 0.9672580084814879, 0.8977248510606632], 
             UndirectedEdge[126, 275] -> 
             RGBColor[
              0.9664660492640806, 0.8926366999149681, 0.4259023154933158], 
             UndirectedEdge[59, 225] -> 
             RGBColor[
              0.529168076809758, 0.6110176542982741, 0.9601760533353643], 
             UndirectedEdge[82, 228] -> 
             RGBColor[
              0.9171563718762805, 0.6907641159009326, 0.28066284875838], 
             UndirectedEdge[19, 280] -> 
             RGBColor[
              0.8551236730004328, 0.8871287036536457, 0.9578543550519694], 
             UndirectedEdge[194, 283] -> 
             RGBColor[
              0.9902555321282709, 0.9902384263607079, 0.8111545807164189], 
             UndirectedEdge[63, 283] -> 
             RGBColor[
              0.845137670722504, 0.8783170696509994, 0.9094373632995052], 
             UndirectedEdge[36, 245] -> 
             RGBColor[
              0.878223346770598, 0.9057354742499203, 0.9882469208858582], 
             UndirectedEdge[3, 55] -> 
             RGBColor[
              0.7030771912484479, 0.7679685124786326, 0.9710398218598875], 
             UndirectedEdge[137, 192] -> 
             RGBColor[
              0.9277825218564244, 0.9308788939917696, 0.6926559006858709], 
             UndirectedEdge[54, 251] -> 
             RGBColor[
              0.8509656915963929, 0.8815593044373305, 0.8505873830838441], 
             UndirectedEdge[252, 292] -> 
             RGBColor[
              0.8428612349584488, 0.8057975251974145, 0.6240964283806709], 
             UndirectedEdge[100, 121] -> 
             RGBColor[
              0.9930006629646717, 0.9909793684036055, 0.737003564792174], 
             UndirectedEdge[142, 239] -> 
             RGBColor[
              0.983328170664218, 0.9548552359351086, 0.43810955131925305`], 
             UndirectedEdge[85, 299] -> 
             RGBColor[
              0.9710068094650206, 0.9401979128669411, 0.6258539929492455], 
             UndirectedEdge[120, 130] -> 
             RGBColor[
              0.8866052734545987, 0.9124189950664038, 0.9890463965356125], 
             UndirectedEdge[9, 297] -> 
             RGBColor[
              0.9503668979079143, 0.9600067058697996, 0.8647701611082577], 
             UndirectedEdge[237, 239] -> 
             RGBColor[
              0.9789047066666666, 0.9405027635555554, 0.37254919822222204`], 
             UndirectedEdge[169, 213] -> 
             RGBColor[
              0.9940166128512964, 0.9896104648391888, 0.5901234179278758], 
             UndirectedEdge[46, 50] -> 
             RGBColor[
              0.9903262751441689, 0.9902676804157944, 0.809982185865932], 
             UndirectedEdge[105, 171] -> 
             RGBColor[
              0.9027416426128239, 0.9215828842589748, 0.822510718185878], 
             UndirectedEdge[34, 114] -> 
             RGBColor[
              0.9603200255957288, 0.9679975630967312, 0.8680862242103418], 
             UndirectedEdge[60, 240] -> 
             RGBColor[
              0.9571703647369797, 0.9675783086647065, 0.9573835801290966], 
             UndirectedEdge[19, 84] -> 
             RGBColor[
              0.8641355844504327, 0.893704210566979, 0.9360809807964137], 
             UndirectedEdge[19, 48] -> 
             RGBColor[
              0.7557854938320516, 0.8091446390548804, 0.9762932928743288], 
             UndirectedEdge[5, 77] -> 
             RGBColor[
              0.9876182519351285, 0.9865201696330608, 0.6706993798460882]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.493915604977778, 0.6000219646222223, 0.9533019921777778], 160 -> 
             RGBColor[
              0.9842266117530863, 0.9877453128493827, 0.9110693936790125], 
             245 -> RGBColor[
              0.9318787345505761, 0.9485188240289726, 0.9933646196710427], 
             155 -> RGBColor[
              0.9888744444444444, 0.9896673111111112, 0.8340427777777777], 
             213 -> RGBColor[
              0.9945451864707683, 0.9907410303642485, 0.6476553944291398], 27 -> 
             RGBColor[
              0.834254289908006, 0.8706757418159434, 0.9840531129906638], 19 -> 
             RGBColor[
              0.7432030096119766, 0.7993151067517359, 0.975039188437272], 164 -> 
             RGBColor[
              0.2781664133333335, 0.40970091555555566`, 0.9391525377777777], 
             190 -> RGBColor[
              0.9936665520163427, 0.9888617201098024, 0.552021456368221], 103 -> 
             RGBColor[
              0.9121774833777778, 0.9328095811200001, 0.9914854967466666], 
             138 -> RGBColor[
              0.9365048432054934, 0.9521659965432099, 0.9923649176506684], 
             291 -> RGBColor[
              0.993390907654321, 0.988272144691358, 0.5220192686419755], 28 -> 
             RGBColor[
              0.9937830242424243, 0.9891108424242424, 0.5646987393939392], 
             114 -> 
             RGBColor[
              0.9943474663728191, 0.991930546328742, 0.7433406406978877], 195 -> 
             RGBColor[
              0.9939423161481482, 0.9894515517037037, 0.5820366802962964], 93 -> 
             RGBColor[
              0.9397455842707572, 0.7988183507669829, 0.27037608663257845`], 
             34 -> RGBColor[
              0.9262925848186385, 0.9440645798647206, 0.9928318077227958], 
             161 -> RGBColor[
              0.977718104, 0.9365000741333332, 0.36793947093333323`], 22 -> 
             RGBColor[
              0.9678600365432098, 0.9755506483950618, 0.939288754074074], 124 -> 
             RGBColor[
              0.9573234759199265, 0.9676924987342517, 0.9571244028341597], 84 -> 
             RGBColor[
              0.9850681592888888, 0.9880933143822223, 0.8971227731555554], 46 -> 
             RGBColor[
              0.9898819093333333, 0.9900839237333333, 0.8173464773333331], 
             241 -> RGBColor[
              0.9873783777777777, 0.9690864459259255, 0.40546781037036983`], 
             185 -> RGBColor[
              0.5611923395311894, 0.6546402485150349, 0.9585982631646212], 
             121 -> RGBColor[
              0.9948250088888889, 0.9913395422222222, 0.6781123377777779], 
             126 -> RGBColor[
              0.9389897823800131, 0.7958218481262325, 0.26976795069033527`], 
             236 -> RGBColor[
              0.8533308982772577, 0.8858869115088451, 0.9858726569268124], 78 -> 
             RGBColor[
              0.9647351375000001, 0.8927054795833335, 0.3175030977083335], 
             254 -> RGBColor[
              0.9673880681652892, 0.9016544376550961, 0.327809232379063], 290 -> 
             RGBColor[
              0.9753732718924555, 0.9811540070167354, 0.9265708063934155], 
             251 -> RGBColor[
              0.9951664846611178, 0.9922692314387634, 0.7297673881093931], 
             165 -> RGBColor[
              0.9863344690873987, 0.9886169660265836, 0.8761367426895375], 
             100 -> RGBColor[
              0.9911763170404545, 0.9906191945849887, 0.7958947918065702], 
             235 -> RGBColor[0.178927, 0.305394, 0.933501], 70 -> 
             RGBColor[
              0.6425892546296297, 0.7207148766666668, 0.9650109496296296], 
             234 -> RGBColor[
              0.9542391281694864, 0.9653921972321293, 0.9623453990489254], 
             257 -> RGBColor[
              0.974080344, 0.9242290554666667, 0.35380746026666665`], 135 -> 
             RGBColor[
              0.9530680847321563, 0.9645188349539762, 0.9643276701312811], 
             265 -> 
             RGBColor[
              0.9949942354547364, 0.9917015007351396, 0.6965316051249735], 
             111 -> RGBColor[
              0.8245679589906197, 0.862952124470868, 0.9831292221006738], 182 -> 
             RGBColor[
              0.8741315629629629, 0.5213426493827158, 0.2166846296296296], 
             188 -> RGBColor[
              0.9946731218163791, 0.9910146711322625, 0.6615803672734477], 
             154 -> RGBColor[
              0.9749483960493828, 0.980837135308642, 0.9272900103703702], 269 -> 
             RGBColor[
              0.9576232380165289, 0.8687153726721761, 0.28987471118457286`], 
             208 -> RGBColor[
              0.9749483960493828, 0.980837135308642, 0.9272900103703702], 86 -> 
             RGBColor[
              0.9931936545475438, 0.98785024024131, 0.5005494852743458], 119 -> 
             RGBColor[
              0.2995959381348108, 0.4322247048322561, 0.9403729175130809], 
             140 -> RGBColor[
              0.8120895555555557, 0.8531298, 0.9819051555555556], 85 -> 
             RGBColor[
              0.975331550617284, 0.9811228913580248, 0.9266414296296294], 242 -> 
             RGBColor[
              0.6890921618655694, 0.757043301234568, 0.9696459248285322], 117 -> 
             RGBColor[
              0.8934051579881116, 0.6088595429294316, 0.23276698975765892`], 
             47 -> RGBColor[0.9952611575, 0.99227242, 0.7255844225], 81 -> 
             RGBColor[
              0.4978476577777779, 0.6032141822222223, 0.9536115377777777], 
             275 -> RGBColor[
              0.9939423161481482, 0.9894515517037037, 0.5820366802962964], 23 -> 
             RGBColor[
              0.9930962118176118, 0.9876418200949566, 0.4899434454680638], 
             110 -> RGBColor[
              0.970873725925926, 0.9134123797530866, 0.3413503545679014], 6 -> 
             RGBColor[
              0.9925726578619074, 0.9865219911231297, 0.43295782839011965`], 
             218 -> RGBColor[
              0.9419708895523106, 0.9562425649588366, 0.9831123269587164], 
             108 -> RGBColor[
              0.9940857720164609, 0.9897583893004116, 0.5976509662551444], 
             297 -> RGBColor[
              0.9946314511732435, 0.992047981341794, 0.7386342776257517], 157 -> 
             RGBColor[
              0.7830622905982909, 0.8304534800000002, 0.9790119890598291], 
             270 -> RGBColor[
              0.18484080515259624`, 0.3116097841722818, 0.9338377824547497], 
             33 -> RGBColor[
              0.6318772600098767, 0.7120254512790125, 0.9641628390320988], 
             252 -> 
             RGBColor[
              0.9432934921391197, 0.812884623194829, 0.27323081658356413`], 
             260 -> RGBColor[
              0.6316648287517148, 0.7118529900137176, 0.9641461156652948], 
             159 -> RGBColor[
              0.3251308266666667, 0.45603371333333337`, 0.9419380266666667], 
             183 -> RGBColor[
              0.8255937727197948, 0.8637700804935403, 0.9832270651299173], 99 -> 
             RGBColor[
              0.414368835665295, 0.5333271914951989, 0.9476241936899863], 17 -> 
             RGBColor[
              0.6890921618655694, 0.757043301234568, 0.9696459248285322], 277 -> 
             RGBColor[
              0.8060462222222223, 0.8484087020689656, 0.9813028125670499], 
             104 -> RGBColor[
              0.989358936, 0.9757673338666667, 0.4131619050666666], 79 -> 
             RGBColor[
              0.9870026773940904, 0.9888932873335707, 0.8650628017799927], 
             191 -> RGBColor[
              0.9877168846811308, 0.989188630401052, 0.8532265387245234], 50 -> 
             RGBColor[
              0.9907706409550046, 0.9904514370982553, 0.8026178943985307], 
             225 -> RGBColor[
              0.8401475247015612, 0.8753748472727273, 0.984615214986226], 61 -> 
             RGBColor[
              0.9934416844444445, 0.9883807511111111, 0.5275460088888881], 
             196 -> RGBColor[
              0.9881488920616035, 0.9893672765549607, 0.8460670584308283], 1 -> 
             RGBColor[
              0.9268002936414816, 0.9444694130986668, 0.9928802334435556], 
             263 -> RGBColor[
              0.8734700444444445, 0.90194532, 0.9877935466666666], 201 -> 
             RGBColor[
              0.9125456547188245, 0.6909796939327821, 0.24849038485068867`], 
             293 -> RGBColor[
              0.9919789026605751, 0.9909510843644181, 0.7825938710561674], 
             184 -> RGBColor[
              0.993178194074074, 0.9878171718518519, 0.49886670814814726`], 
             106 -> RGBColor[
              0.9941959825235077, 0.989994118430993, 0.6096466998067775], 206 -> 
             RGBColor[
              0.9748469169550174, 0.9268148860438293, 0.3567854514417531], 
             247 -> RGBColor[
              0.9099739734796524, 0.9310525621399176, 0.9912753240054869], 
             220 -> RGBColor[
              0.8202687255662249, 0.15679988327998912`, 0.16704266053345543`],
              107 -> RGBColor[
              0.880784375308642, 0.9077775688888888, 0.988491194074074], 131 -> 
             RGBColor[
              0.9675276541914549, 0.9021252940977106, 0.3283514977321075], 
             127 -> 
             RGBColor[
              0.8218489645520956, 0.8607840721107267, 0.9828698819838524], 
             210 -> RGBColor[
              0.9893340761245675, 0.9898573806228373, 0.8264254913494807], 
             181 -> RGBColor[
              0.9363631671655329, 0.9520603347845805, 0.9926047382312924], 
             194 -> RGBColor[
              0.9924738911539639, 0.9911557748270585, 0.7743906307315578], 
             118 -> RGBColor[
              0.9770530945841343, 0.9824068160297321, 0.9237273047443291], 
             276 -> RGBColor[
              0.9867254217324762, 0.9887786349923477, 0.8696576456075911], 
             280 -> RGBColor[
              0.9670443363888889, 0.9749423005555556, 0.9406695216666666], 
             189 -> RGBColor[
              0.726438758278838, 0.7862187461972588, 0.9733682845352205], 168 -> 
             RGBColor[
              0.9829972935640138, 0.9868399898961938, 0.913665326366782], 41 -> 
             RGBColor[
              0.9774787372270063, 0.9827242596158603, 0.9230068027753274], 14 -> 
             RGBColor[
              0.829126913580247, 0.8665873111111112, 0.9835640592592593], 77 -> 
             RGBColor[
              0.9925202875476233, 0.9864099763163272, 0.42725764287242346`], 
             51 -> RGBColor[
              0.9486846207727112, 0.9612496547102856, 0.9717477312241194], 
             179 -> RGBColor[
              0.9165586183791375, 0.9363029792473427, 0.9919033733141818], 
             223 -> RGBColor[
              0.9535726690567902, 0.853638134340741, 0.28150168361481487`], 
             292 -> RGBColor[
              0.7424289777777778, 0.7987104272, 0.9749620401777778], 143 -> 
             RGBColor[
              0.902293441930186, 0.9249283147648482, 0.9905427480498074], 112 -> 
             RGBColor[
              0.9693018543209876, 0.9081100877366254, 0.33524393020576115`], 
             197 -> RGBColor[
              0.7583185280415552, 0.8111234646311177, 0.9765457620517816], 54 -> 
             RGBColor[
              0.706764898531668, 0.7708493774358977, 0.971407378058295], 71 -> 
             RGBColor[0.9717158, 0.9162528933333333, 0.3446216533333333], 177 -> 
             RGBColor[
              0.9429975623593965, 0.9570082558573388, 0.9813744376954732], 
             158 -> RGBColor[
              0.9567826875739646, 0.8658799986587774, 0.2866093314398426], 
             226 -> RGBColor[
              0.9214884883007769, 0.9402339237051038, 0.9923735887082545], 
             203 -> RGBColor[
              0.9935315107070707, 0.9885728804040405, 0.537323043232323], 115 -> 
             RGBColor[
              0.9942128498850019, 0.9900301960116773, 0.611482608012129], 173 -> 
             RGBColor[
              0.9658058809416025, 0.8963173486343742, 0.3216627337860265], 
             212 -> RGBColor[
              0.9576272162570889, 0.8687287922117204, 0.2898901658979208], 
             129 -> RGBColor[
              0.9893812162150809, 0.9898768742617098, 0.8256442580550303], 
             279 -> RGBColor[
              0.7810063100936525, 0.8288473324037461, 0.978807068137357], 26 -> 
             RGBColor[0.5894275200000002, 0.6775628400000001, 0.96082104], 40 -> 
             RGBColor[
              0.9932045754109139, 0.9914579315450361, 0.7622813016436549], 
             146 -> RGBColor[
              0.756370360153257, 0.8096015410701548, 0.97635158688334], 192 -> 
             RGBColor[
              0.9854135382716049, 0.9624585809053497, 0.3978347799176953], 
             300 -> RGBColor[
              0.26676940921810716`, 0.3977219416186558, 0.9385034952537723], 
             221 -> RGBColor[
              0.9939423161481482, 0.9894515517037037, 0.5820366802962964], 62 -> 
             RGBColor[
              0.9945054567375886, 0.9906560524822695, 0.6433310581560281], 
             286 -> RGBColor[
              0.7189724812623276, 0.780386033846154, 0.9726241158185405], 152 -> 
             RGBColor[
              0.8511474153018073, 0.8841458614532873, 0.9856643943713956], 64 -> 
             RGBColor[
              0.9793864141953393, 0.9841470019753087, 0.9197776032697786], 37 -> 
             RGBColor[
              0.9259645513080947, 0.9438030148476454, 0.9928005195937211], 
             148 -> RGBColor[
              0.9866565999999999, 0.9666517199999998, 0.40266383999999966`], 
             261 -> RGBColor[
              0.8342698024691357, 0.870688111111111, 0.9840545925925925], 15 -> 
             RGBColor[
              0.9749483960493828, 0.980837135308642, 0.9272900103703702], 136 -> 
             RGBColor[
              0.9632709999999999, 0.8877665999999995, 0.3118151999999995], 
             198 -> RGBColor[
              0.41794100591368244`, 0.536421225821855, 0.9478518092194674], 
             63 -> RGBColor[
              0.7022381683424302, 0.7673130614076414, 0.9709561958977305], 
             171 -> RGBColor[
              0.9946884185589808, 0.9910473893179497, 0.6632453233050893], 59 -> 
             RGBColor[
              0.21818862891795487`, 0.3466604613238209, 0.9357368916845026], 
             229 -> RGBColor[
              0.992944994907793, 0.9873183824152291, 0.4734844180368819], 102 -> 
             RGBColor[
              0.9926314648526077, 0.9912209356009071, 0.7717792267573698], 
             299 -> RGBColor[
              0.9666820683127573, 0.8992729343758574, 0.3250665562688615], 
             128 -> RGBColor[
              0.40491315259259286`, 0.5251371540740742, 0.947021685925926], 
             12 -> RGBColor[
              0.8876201833731252, 0.5825913243179266, 0.22793986513621056`], 
             222 -> RGBColor[
              0.991106782816568, 0.9816632315928993, 0.4199519598958577], 92 -> 
             RGBColor[
              0.9558585052990534, 0.8627007133315414, 0.28334092111081244`], 
             271 -> RGBColor[
              0.8093085934692092, 0.8509572912820516, 0.9816279752443569], 
             132 -> RGBColor[
              0.9439481543867744, 0.8154801408535179, 0.27375757319492505`], 
             80 -> RGBColor[
              0.9646440854608256, 0.9731521973434561, 0.9447325204021748], 
             244 -> RGBColor[
              0.9746770779604578, 0.9806347867221644, 0.9277492811238294], 
             150 -> RGBColor[
              0.9950152931944445, 0.9917465411111112, 0.6988236101388888], 
             125 -> RGBColor[
              0.9848031822222222, 0.9879837395555556, 0.9015141288888892], 
             133 -> RGBColor[
              0.8218489645520956, 0.8607840721107267, 0.9828698819838524], 
             258 -> RGBColor[
              0.5688430555555557, 0.6608514444444447, 0.9592005555555555], 
             255 -> RGBColor[
              0.9451934189473684, 0.9586459221052632, 0.9776574252631578], 
             176 -> RGBColor[
              0.9945786999616042, 0.9908127123324129, 0.6513031310853388], 
             230 -> RGBColor[
              0.9874292064318887, 0.9890696680519966, 0.8579941118019089], 
             274 -> RGBColor[
              0.9646440854608256, 0.9731521973434561, 0.9447325204021748], 87 -> 
             RGBColor[
              0.6612744045452605, 0.7353118577931566, 0.966873310750566], 130 -> 
             RGBColor[
              0.8913901550617286, 0.916234329777778, 0.9895027828148149], 35 -> 
             RGBColor[
              0.9885287267204921, 0.9729668430244777, 0.4099366987876456], 31 -> 
             RGBColor[
              0.9922863308641975, 0.9910782138271605, 0.7774989901234566], 18 -> 
             RGBColor[
              0.9935848620630549, 0.9886869935598409, 0.543130009084787], 24 -> 
             RGBColor[
              0.5439782676916616, 0.6406650895106072, 0.9572431083721907], 
             151 -> RGBColor[
              0.9756175898307171, 0.981336218935057, 0.9261572398522622], 137 -> 
             RGBColor[
              0.8701515054412438, 0.8992992070781893, 0.9874770214540466], 
             296 -> RGBColor[
              0.6731473333333333, 0.74458708, 0.9680566933333333], 266 -> 
             RGBColor[
              0.994421008764019, 0.9919609579974563, 0.7421218529540985], 283 -> 
             RGBColor[
              0.9880371731025779, 0.9893210778943573, 0.84791853070128], 284 -> 
             RGBColor[
              0.9679155939555556, 0.9755920830222223, 0.9391947098666665], 
             238 -> RGBColor[
              0.9273127528888888, 0.7495263173333331, 0.2603723386666666], 72 -> 
             RGBColor[
              0.9482806114047775, 0.9609483451851851, 0.9724316137015122], 
             288 -> RGBColor[
              0.19046646666666678`, 0.31752271111111124`, 0.9341581555555556],
              172 -> RGBColor[
              0.8095047263773474, 0.8511105118005544, 0.9816475239396738], 
             243 -> RGBColor[
              0.9485368378085566, 0.8336727415327796, 0.2774497355863343], 88 -> 
             RGBColor[
              0.9495728353264197, 0.9619120836701235, 0.9702442156681481], 
             273 -> RGBColor[
              0.9901658133333333, 0.9902013253333334, 0.8126414533333332], 
             202 -> RGBColor[
              0.8418275185625579, 0.8767144287752676, 0.984775454300436], 98 -> 
             RGBColor[
              0.9423623595540177, 0.9565345226451365, 0.9824496703575546], 30 -> 
             RGBColor[
              0.9372076711111111, 0.9526901644444445, 0.9911752133333332], 
             116 -> RGBColor[
              0.9363555353520987, 0.9520546429906173, 0.9926176569007407], 
             240 -> RGBColor[
              0.9784926457722588, 0.9834804309487867, 0.9212905200779156], 73 -> 
             RGBColor[
              0.9027235559762032, 0.651172211826212, 0.24054248945375872`], 
             29 -> RGBColor[
              0.8202687255662249, 0.15679988327998912`, 0.16704266053345543`],
              75 -> RGBColor[
              0.8579835290961744, 0.88959679303155, 0.9863164290077732], 200 -> 
             RGBColor[
              0.8017200960960964, 0.8450290994594596, 0.9808716247447448], 
             156 -> RGBColor[
              0.8913792403292181, 0.5996603240054871, 0.23107651440329222`], 
             25 -> RGBColor[
              0.9951468481077369, 0.9920279237684015, 0.7131425505879544], 38 -> 
             RGBColor[
              0.9897605574317467, 0.9900337416034257, 0.8193575923912776], 3 -> 
             RGBColor[
              0.6871819012345681, 0.7555509911111113, 0.9694555279012346], 57 -> 
             RGBColor[
              0.9939387396860573, 0.9894439020129271, 0.5816474044690669], 
             227 -> RGBColor[
              0.7237811191135736, 0.7841425782825486, 0.973103395900277], 39 -> 
             RGBColor[
              0.8776503335047444, 0.537320564583206, 0.2196207780226508], 109 -> 
             RGBColor[
              0.9948344136611805, 0.9913596580791857, 0.6791359892021945], 
             256 -> RGBColor[
              0.9169448690189202, 0.9366109650230111, 0.9919402142450142], 
             287 -> RGBColor[
              0.9522689568419448, 0.9639228466819082, 0.9656803852034751], 
             239 -> RGBColor[
              0.9732315333333333, 0.9213658177777777, 0.35050999111111103`], 
             285 -> RGBColor[
              0.9916680909519716, 0.9908225557354141, 0.7877448254226452], 
             216 -> RGBColor[
              0.958611258413871, 0.9686529248096851, 0.9549445229793782], 21 -> 
             RGBColor[
              0.6999884444444445, 0.7655555600000001, 0.9707319644444444], 
             175 -> RGBColor[
              0.9946604920888888, 0.9909876574222223, 0.6602056993777774], 7 -> 
             RGBColor[
              0.9176775006931317, 0.9371951456332703, 0.9920100933081285], 13 -> 
             RGBColor[
              0.8852743363452708, 0.571939380850933, 0.2259824328741964], 294 -> 
             RGBColor[
              0.9799914520775623, 0.9441686110064635, 0.3767709989289012], 
             193 -> RGBColor[
              0.42266302721277055`, 0.5405112033354338, 0.9481526922411259], 
             60 -> RGBColor[
              0.9358480837017006, 0.9516761863806262, 0.9934766401802776], 65 -> 
             RGBColor[
              0.968470322895686, 0.9760057989574863, 0.9382556984675049], 69 -> 
             RGBColor[
              0.9918692373333333, 0.9909057349333333, 0.7844113093333334], 
             217 -> RGBColor[
              0.9660222743982764, 0.9741800483964297, 0.9423996060203138], 
             214 -> RGBColor[
              0.9859955176971059, 0.9884768009160441, 0.8817540444047696], 
             170 -> RGBColor[
              0.9680834213017752, 0.904000027061144, 0.3305105480078896], 74 -> 
             RGBColor[
              0.49778979398836865`, 0.6031672057912458, 0.9536069825283134], 
             246 -> RGBColor[0.97535356, 0.928523912, 0.35875366399999986`], 
             264 -> RGBColor[
              0.9714760577777777, 0.9782474711111111, 0.9331677733333333], 
             278 -> 
             RGBColor[
              0.7051372208342467, 0.7695778232478634, 0.9712451463569289], 45 -> 
             RGBColor[
              0.9940923731138546, 0.9918250587105625, 0.7475681961591218], 
             237 -> RGBColor[
              0.9845778799999999, 0.9596397093333331, 0.39458840533333306`], 
             228 -> RGBColor[
              0.9748774265927979, 0.9269178022160667, 0.35690397562326887`], 
             180 -> RGBColor[
              0.9579871728572895, 0.9681874828234329, 0.9560009370390887], 53 -> 
             RGBColor[
              0.9867234465277778, 0.9887778181944444, 0.8696903798611111], 48 -> 
             RGBColor[
              0.7683679780521265, 0.8189741713580249, 0.9775473973113855], 5 -> 
             RGBColor[
              0.9827162163226337, 0.9866303629497943, 0.914141116819753], 101 -> 
             RGBColor[
              0.9140889618436215, 0.934333742162963, 0.9916678152691358], 267 -> 
             RGBColor[
              0.9517901055358317, 0.8465708639842207, 0.28006739116370805`], 
             120 -> RGBColor[
              0.8818203918474689, 0.9086036603550296, 0.9885900102564102], 
             147 -> RGBColor[
              0.9923315511680553, 0.9910969135849145, 0.776749572662139], 89 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 43 -> 
             RGBColor[
              0.9435003724444444, 0.8137048346666665, 0.2733972773333333], 
             199 -> RGBColor[
              0.989358936, 0.9757673338666667, 0.4131619050666666], 268 -> 
             RGBColor[
              0.9949942354547364, 0.9917015007351396, 0.6965316051249735], 
             169 -> RGBColor[
              0.9934880392318244, 0.9884798993141289, 0.5325914414266117], 20 -> 
             RGBColor[
              0.8790594929356578, 0.906402194505356, 0.9883266732535182], 4 -> 
             RGBColor[
              0.9568950231332718, 0.9673729593474916, 0.9578496616435824], 
             167 -> RGBColor[
              0.9445693333907869, 0.9581804801190109, 0.9787138393228686], 
             142 -> RGBColor[
              0.9934248079951026, 0.9883446540924395, 0.5257091115273951], 16 -> 
             RGBColor[
              0.994298660525037, 0.990213736293926, 0.620822566618074], 281 -> 
             RGBColor[
              0.8876201833731252, 0.5825913243179266, 0.22793986513621056`], 
             289 -> RGBColor[
              0.9900143978666667, 0.9901387111466667, 0.8151507994666662], 
             178 -> RGBColor[
              0.9913540041481481, 0.9906926727703704, 0.7929500565925927], 58 -> 
             RGBColor[
              0.8638435387409449, 0.8942694056565657, 0.9868753619589837], 
             186 -> RGBColor[
              0.8823057454427402, 0.9089906681373267, 0.9886363037156075], 
             122 -> RGBColor[
              0.2995959381348108, 0.4322247048322561, 0.9403729175130809], 
             249 -> RGBColor[
              0.9688604327153189, 0.9762967422222223, 0.9375953442998027], 
             113 -> RGBColor[
              0.9926806419753086, 0.9912412716049382, 0.7709642345679013], 52 -> 
             RGBColor[
              0.38464718003408815`, 0.5075837872412954, 0.9457303560749939], 
             187 -> RGBColor[
              0.8810920196597353, 0.9080228761436673, 0.9885205374669187], 
             259 -> RGBColor[
              0.9847284738348498, 0.9879528457174591, 0.9027522402067579], 42 -> 
             RGBColor[
              0.9952173616301423, 0.9922902703729335, 0.7289242250672816], 
             134 -> RGBColor[
              0.8305254006574622, 0.8677024267455621, 0.9836974482051282], 
             248 -> RGBColor[
              0.9888744444444444, 0.9896673111111112, 0.8340427777777777], 
             174 -> RGBColor[
              0.9530680847321563, 0.9645188349539762, 0.9643276701312811], 
             215 -> RGBColor[
              0.9951468481077369, 0.9920279237684015, 0.7131425505879544], 83 -> 
             RGBColor[
              0.9875644488275257, 0.9891255942581635, 0.855752795310103], 95 -> 
             RGBColor[
              0.6418632837460979, 0.7201325552133195, 0.9649489754006243], 
             166 -> RGBColor[
              0.5651464126023946, 0.6578503431632011, 0.9589095422810334], 
             233 -> RGBColor[
              0.9818930725925925, 0.9860164637037037, 0.9155344844444445], 
             295 -> RGBColor[
              0.9206561345313756, 0.9395702274030244, 0.992294198062678], 141 -> 
             RGBColor[0.9670707381333333, 0.9749619909333334, 0.9406248304], 
             205 -> RGBColor[
              0.9846702847736625, 0.9879287830452675, 0.9037165835390945], 
             224 -> RGBColor[
              0.9082238017044071, 0.9296570226734843, 0.9911083910591673], 
             231 -> RGBColor[
              0.9952414883555556, 0.9922303496888889, 0.7234435575111108], 68 -> 
             RGBColor[
              0.9879122464711111, 0.9892694175217778, 0.8499888882844444], 10 -> 
             RGBColor[
              0.8673724642722116, 0.8970832750850661, 0.987211954026465], 250 -> 
             RGBColor[
              0.9669087599999999, 0.9000376186666665, 0.32594721066666643`], 
             282 -> 
             RGBColor[
              0.984562293979798, 0.9878841260767677, 0.9055062704646463], 232 -> 
             RGBColor[
              0.9766504256382001, 0.9821065061891644, 0.9244089182369145], 
             253 -> RGBColor[
              0.8344054434448291, 0.8707962675432527, 0.9840675301499423], 55 -> 
             RGBColor[
              0.7189724812623276, 0.780386033846154, 0.9726241158185405], 91 -> 
             RGBColor[
              0.9229797032098767, 0.7323472192592596, 0.25688586518518525`], 
             105 -> RGBColor[
              0.8107948666666669, 0.8521183792000001, 0.9817761130666667], 36 -> 
             RGBColor[
              0.8245679589906197, 0.862952124470868, 0.9831292221006738], 123 -> 
             RGBColor[
              0.9247292742123456, 0.739283685274074, 0.25829361108148147`], 
             94 -> RGBColor[
              0.7217544382009482, 0.7825593197502603, 0.9729013952873165], 96 -> 
             RGBColor[
              0.9865282112828643, 0.9886970834033558, 0.8729259331219444], 2 -> 
             RGBColor[
              0.8818203918474689, 0.9086036603550296, 0.9885900102564102], 
             262 -> RGBColor[
              0.9673880681652892, 0.9016544376550961, 0.327809232379063], 272 -> 
             RGBColor[
              0.9818086011342154, 0.9859534650283555, 0.915677472589792], 97 -> 
             RGBColor[
              0.9632709999999999, 0.8877665999999995, 0.3118151999999995], 
             209 -> RGBColor[
              0.9937135764304845, 0.9916684165473582, 0.7538458374969563], 66 -> 
             RGBColor[
              0.9639953460053825, 0.9726683685198001, 0.9458306670818916], 
             139 -> RGBColor[
              0.7217544382009482, 0.7825593197502603, 0.9729013952873165], 56 -> 
             RGBColor[
              0.9570665102493074, 0.8668373991874423, 0.2877119289381348], 
             144 -> RGBColor[
              0.9899777257023933, 0.990123546264308, 0.8157585521331946], 298 -> 
             RGBColor[
              0.6225575456147273, 0.7044592872846813, 0.9634291569756739], 
             204 -> RGBColor[
              0.981433287111111, 0.9856735564444444, 0.9163127813333334], 207 -> 
             RGBColor[
              0.8950630372378329, 0.9191629863272728, 0.9898531055955923], 
             149 -> RGBColor[
              0.9433561045679013, 0.9572756560493828, 0.9807675192592591], 
             219 -> RGBColor[
              0.9776181918188458, 0.9361630468858045, 0.3675513309763815], 9 -> 
             RGBColor[
              0.906102344642585, 0.9279654303978052, 0.9909060445907636], 
             11 -> 
             RGBColor[
              0.7167157935720846, 0.7786230922710745, 0.9723991902795225], 44 -> 
             RGBColor[0.8635956977777778, 0.894071784, 0.9868517226666667], 
             153 -> RGBColor[
              0.8120895555555557, 0.8531298, 0.9819051555555556], 32 -> 
             RGBColor[
              0.9851818512396694, 0.9881403289256199, 0.8952386033057846], 
             162 -> RGBColor[
              0.9602395333333333, 0.877540751111111, 0.30003852444444434`], 
             90 -> RGBColor[
              0.6446136533333335, 0.7222963523200002, 0.9652127227733334], 8 -> 
             RGBColor[
              0.9939423161481482, 0.9894515517037037, 0.5820366802962964], 
             163 -> RGBColor[
              0.7427767415493634, 0.7989821029014652, 0.9749967020204922], 49 -> 
             RGBColor[
              0.9909109036088889, 0.9905094393102223, 0.8002933792355555], 76 -> 
             RGBColor[
              0.9909150888888889, 0.9810166029629629, 0.41920726518518503`], 
             82 -> RGBColor[
              0.8594353171597632, 0.45461042958579845`, 0.20442172189349106`],
              67 -> RGBColor[
              0.8498027740907299, 0.8830736810508876, 0.9855361412923077], 
             211 -> RGBColor[
              0.9721970137931034, 0.917876140451843, 
               0.34649107804994045`]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9mHk4FFzYxsmSfR/LzGBWM2NmbHmlLHNH8aZCu0SWIkQLqbSgomQtVNoX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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 9}], {
             RGBColor[
             0.9164513191420334, 0.936217421748236, 0.9918931390171596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 11}], {
             RGBColor[
             0.8217580436067831, 0.8615462526848707, 0.9826397118615391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 20}], {
             RGBColor[
             0.9029298932885697, 0.9254358038020114, 0.9906034533485368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 37}], {
             RGBColor[
             0.9263824224747882, 0.9441362139731562, 0.9928403765186383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 43}], {
             RGBColor[
             0.935150333042963, 0.8790871238826667, 0.6331387553884444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 75}], {
             RGBColor[
             0.892391911368828, 0.9170331030651084, 0.9895983312256644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 102}], {
             RGBColor[
             0.9597158792470446, 0.9678451743497869, 0.8823297301004627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 142}], {
             RGBColor[
             0.9601125508182922, 0.9664070335955532, 0.7592946724854753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 143}], {
             RGBColor[
             0.9145468677858338, 0.9346988639317575, 0.9917114907466815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 174}], {
             RGBColor[
             0.9399341891868189, 0.9544941240263215, 0.9786039517874183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 185}], {
             RGBColor[
             0.7439963165863355, 0.7995548308068509, 0.9757392483040883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 237}], {
             RGBColor[
             0.9556890868207408, 0.952054561216, 0.6937343193884443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 239}], {
             RGBColor[
             0.9500159134874075, 0.9329176154382223, 0.6716951122773334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 283}], {
             RGBColor[
             0.9574187333720298, 0.9668952454965121, 0.9203993820724178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 295}], {
             RGBColor[
             0.9237282140864287, 0.9420198202508456, 0.9925872157531168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 297}], {
             RGBColor[
             0.9607158724073626, 0.9682586972202304, 0.8657572555346537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 32}], {
             RGBColor[
             0.9335011215435691, 0.9483719946403247, 0.9419143067810974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 83}], {
             RGBColor[
             0.9346924203374973, 0.9488646273065966, 0.9221714027832566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 155}], {
             RGBColor[
             0.9353474181459567, 0.9491354857330704, 0.911316394017094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 156}], {
             RGBColor[
             0.8865998160883435, 0.7541319921802583, 0.6098332623298512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 178}], {
             RGBColor[
             0.9365871979978084, 0.9496481665627, 0.8907700334245015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 184}], {
             RGBColor[
             0.9374992929607715, 0.9482104161034408, 0.7437283592022788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 202}], {
             RGBColor[
             0.8618239552050133, 0.8926590445651486, 0.9866827322784231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 208}], {
             RGBColor[
             0.9283843939484258, 0.9447203978318358, 0.9579400103133902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 214}], {
             RGBColor[
             0.9339079547722874, 0.9485402306355368, 0.9351720273305899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 268}], {
             RGBColor[
             0.9384073136511026, 0.9501525805450846, 0.8425608076906919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 275}], {
             RGBColor[
             0.9378813539978086, 0.9490276060293666, 0.7853133452763533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 17}], {
             RGBColor[
             0.6881370315500688, 0.7562971461728396, 0.9695507263648834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 30}], {
             RGBColor[
             0.8121947861728396, 0.854120577777778, 0.9803153706172839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 38}], {
             RGBColor[
             0.8384712293331574, 0.8727923663572685, 0.8944065601462561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 55}], {
             RGBColor[
             0.7030771912484479, 0.7679685124786326, 0.9710398218598875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 74}], {
             RGBColor[
             0.5924858476114684, 0.6793590984511786, 0.961531255214774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 90}], {
             RGBColor[
             0.6658977772839508, 0.7389236717155558, 0.967334125337284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[
             0.8059555877234569, 0.7474173381925926, 0.613874569491358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 144}], {
             RGBColor[
             0.8385798134684808, 0.8728372686877097, 0.8926070400172146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 157}], {
             RGBColor[
             0.7351220959164295, 0.7930022355555557, 0.9742337584805318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 229}], {
             RGBColor[
             0.8400634480711806, 0.8714346867631702, 0.7214699729690582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 252}], {
             RGBColor[
             0.815237696686844, 0.7842178071529702, 0.6213431722423993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 257}], {
             RGBColor[
             0.830631122617284, 0.8398900232888891, 0.6616314940839506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 259}], {
             RGBColor[
             0.835955187534709, 0.8717519184142852, 0.9361038840539962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 26}], {
             RGBColor[
             0.773161271566636, 0.8224678996737458, 0.9593353508217912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 39}], {
             RGBColor[
             0.9172726783190082, 0.7523467619653488, 0.5887352198331166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 52}], {
             RGBColor[
             0.6707711015836799, 0.7374783732943935, 0.9517900088592881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 78}], {
             RGBColor[
             0.960815080316636, 0.9300392194654126, 0.6376763796759579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 82}], {
             RGBColor[
             0.9081651701465174, 0.710991694466645, 0.5811356917685367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 107}], {
             RGBColor[
             0.9188396992209569, 0.9375752641181903, 0.9731704278588282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 130}], {
             RGBColor[
             0.9241425890975001, 0.9418036445626348, 0.9736762222291986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 193}], {
             RGBColor[
             0.6897790251730211, 0.7539420813414627, 0.9530011769423541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 199}], {
             RGBColor[
             0.973126979566636, 0.9715701466070792, 0.6855057833551246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 220}], {
             RGBColor[
             0.8885818743497483, 0.5620864213137403, 0.562446161088519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.9391917557170244, 0.9538034415262977, 0.9751116251759184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 228}], {
             RGBColor[
             0.9658862248630349, 0.9471453807817791, 0.6573768186334257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 236}], {
             RGBColor[
             0.9051129607052648, 0.9266299354281684, 0.9718611592851973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 266}], {
             RGBColor[
             0.9756580159486454, 0.979666958672474, 0.8499857572988405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 281}], {
             RGBColor[
             0.9222576032531985, 0.7749821418327091, 0.5928947633898964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.9014924709444293, 0.5717151231148917, 0.5405918886766041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[
             0.9876182519351285, 0.9865201696330608, 0.6706993798460882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 191}], {
             RGBColor[
             0.9852165505018823, 0.9879094966754232, 0.8836838277721382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 248}], {
             RGBColor[
             0.9857953303835391, 0.9881488370304528, 0.8740919472987654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 21}], {
             RGBColor[
             0.8462805511531759, 0.8760387755615648, 0.7018448964172821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 34}], {
             RGBColor[
             0.959432621340273, 0.9652932854939251, 0.7128948180564577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 46}], {
             RGBColor[
             0.9912272835976204, 0.9883029574282315, 0.6251521528617263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 50}], {
             RGBColor[
             0.991671649408456, 0.9884867141106926, 0.6177878613943252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 101}], {
             RGBColor[
             0.9533308098527644, 0.9604278666430464, 0.7123128218296277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 108}], {
             RGBColor[
             0.9933292149391841, 0.9881401902117706, 0.515304397322632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 114}], {
             RGBColor[
             0.9934600621173633, 0.9892262687259359, 0.5881492345440037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 145}], {
             RGBColor[
             0.7432441314198427, 0.793271977872676, 0.6931299102839488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 169}], {
             RGBColor[
             0.9930303485468659, 0.9875009452186293, 0.4827746349083657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 187}], {
             RGBColor[
             0.9368323387608213, 0.9472724336333984, 0.7107391829285192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 205}], {
             RGBColor[
             0.988621471317785, 0.9872253870841986, 0.6683372059646071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 213}], {
             RGBColor[
             0.9935589221663379, 0.9886315107436892, 0.5403066114096298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 219}], {
             RGBColor[
             0.9850954248403766, 0.9613425190044671, 0.40025457968325057`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 221}], {
             RGBColor[
             0.9932574870050278, 0.9879867714134167, 0.507497254343208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 231}], {
             RGBColor[
             0.9939070731087315, 0.9893761704060093, 0.5782006929506152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 264}], {
             RGBColor[
             0.9820243578198425, 0.9823847311171203, 0.6830628008617265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 9}], {
             RGBColor[
             0.9118899226678583, 0.9325802880155378, 0.9914580689494461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 11}], {
             RGBColor[
             0.8171966471326082, 0.8579091189521724, 0.9822046417938255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 43}], {
             RGBColor[
             0.930588936568788, 0.8754499901499684, 0.6327036853207308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.8122211996123998, 0.854022261534584, 0.9817087356832117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 63}], {
             RGBColor[
             0.8099578345177809, 0.8522541035204558, 0.9814831446029295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 106}], {
             RGBColor[
             0.9559367416083198, 0.9635946320321317, 0.800828396557453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 131}], {
             RGBColor[
             0.9426025774422933, 0.9196602198654904, 0.660180795520118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 143}], {
             RGBColor[
             0.9099854713116589, 0.9310617301990592, 0.9912764206789679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 151}], {
             RGBColor[
             0.9466475452619244, 0.9592656822841636, 0.9590836665801954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 167}], {
             RGBColor[
             0.9311234170419593, 0.9476878128761406, 0.9853619663154985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 174}], {
             RGBColor[
             0.9353727927126441, 0.9508569902936232, 0.9781688817197047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 185}], {
             RGBColor[
             0.7394349201121606, 0.7959176970741526, 0.9753041782363748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[
             0.9550756959235478, 0.9641754602301644, 0.8832003620198432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 283}], {
             RGBColor[
             0.9528573368978548, 0.9632581117638138, 0.9199643120047043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 297}], {
             RGBColor[
             0.9561544759331876, 0.9646215634875321, 0.8653221854669402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 22}], {
             RGBColor[
             0.980901176345679, 0.9825011000493827, 0.7606627171851852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 47}], {
             RGBColor[
             0.994601736824074, 0.9908619858518519, 0.6538105513981483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 61}], {
             RGBColor[
             0.9936920002962963, 0.9889161514074074, 0.5547913445925923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 72}], {
             RGBColor[
             0.9711114637764628, 0.9751999484444445, 0.7772341469989044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 177}], {
             RGBColor[
             0.9684699392537723, 0.9732299037805212, 0.7817055589958848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 217}], {
             RGBColor[
             0.9799822952732122, 0.9818158000500667, 0.762218143158305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 247}], {
             RGBColor[
             0.9519581448139003, 0.9602520569218107, 0.7866560021508917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 267}], {
             RGBColor[
             0.9728662108419899, 0.9180112078439622, 0.4310520357300022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 271}], {
             RGBColor[
             0.9016254548086787, 0.9202044214928776, 0.7818323277703266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 273}], {
             RGBColor[
             0.9920540647407408, 0.9898264385185185, 0.6973390668148147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 285}], {
             RGBColor[
             0.9928052035500599, 0.9901370537195588, 0.6848907528594708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.8114090691073348, 0.8532942613344399, 0.981652617435143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 20}], {
             RGBColor[
             0.8925809187891214, 0.9171838124515805, 0.989616358922141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 37}], {
             RGBColor[
             0.9160334479753398, 0.9358842226227253, 0.9918532820922423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 43}], {
             RGBColor[
             0.9248013585435146, 0.8708351325322359, 0.6321516609620484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 63}], {
             RGBColor[
             0.8041702564925076, 0.8476392459027233, 0.980931120244247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 75}], {
             RGBColor[
             0.8820429368693796, 0.9087811117146776, 0.9886112367992683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.9501491635830464, 0.9589797744143991, 0.8002763721987706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 131}], {
             RGBColor[
             0.93681499941702, 0.9150453622477579, 0.6596287711614355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 142}], {
             RGBColor[
             0.9497635763188438, 0.9581550422451224, 0.7583075780590793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 143}], {
             RGBColor[
             0.9041978932863854, 0.9264468725813266, 0.9907243963202854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 167}], {
             RGBColor[
             0.9253358390166859, 0.9430729552584081, 0.9848099419568161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 174}], {
             RGBColor[
             0.9295852146873707, 0.9462421326758907, 0.9776168573610223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 185}], {
             RGBColor[
             0.7336473420868872, 0.7913028394564201, 0.9747521538776924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 237}], {
             RGBColor[
             0.9453401123212924, 0.9438025698655692, 0.6927472249620483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 239}], {
             RGBColor[
             0.9396669389879592, 0.9246656240877915, 0.6707080178509373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 282}], {
             RGBColor[
             0.9453323193111915, 0.9579247782372864, 0.948206157527705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 283}], {
             RGBColor[
             0.9470697588725814, 0.9586432541460812, 0.9194122876460218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 295}], {
             RGBColor[
             0.9133792395869803, 0.9337678289004148, 0.9916001213267208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 297}], {
             RGBColor[
             0.9503668979079143, 0.9600067058697996, 0.8647701611082577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 117}], {
             RGBColor[
             0.8803888111301617, 0.7529714090072488, 0.609989471892062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.9283768402436463, 0.943480074673388, 0.9064281060407476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 161}], {
             RGBColor[
             0.9225452841361058, 0.9167916746091997, 0.6775757124798991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 265}], {
             RGBColor[
             0.9311833498634741, 0.9443923879101028, 0.8418717795757192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 269}], {
             RGBColor[
             0.9124978511443702, 0.8828993238786211, 0.638543332605519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 43}], {
             RGBColor[
             0.8301080830082646, 0.7961639634688705, 0.622898233806428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 63}], {
             RGBColor[
             0.7094769809572574, 0.772968076839358, 0.9716776930886265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 131}], {
             RGBColor[
             0.8421217238817698, 0.8403741931843925, 0.650375344005815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 139}], {
             RGBColor[
             0.7192351158865165, 0.7805912060106674, 0.9726502927834195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 143}], {
             RGBColor[
             0.8095046177511354, 0.8517757035179614, 0.9814709691646649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 172}], {
             RGBColor[
             0.7631102599747159, 0.8148668020358145, 0.9770233571095981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 174}], {
             RGBColor[
             0.8348919391521205, 0.8715709636125253, 0.9683634302054018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 183}], {
             RGBColor[
             0.7711547831459398, 0.8211965863823074, 0.97781312770472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 185}], {
             RGBColor[
             0.638954066551637, 0.7166316703930546, 0.9654987267220718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 283}], {
             RGBColor[
             0.8523764833373313, 0.883972085082716, 0.9101588604904012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 248}], {
             RGBColor[
             0.9382473139087848, 0.7861293177145189, 0.5309913214569941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 58}], {
             RGBColor[
             0.8745589375431078, 0.7331043932537493, 0.6064288974165901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 73}], {
             RGBColor[
             0.8939989461607369, 0.6115557963385725, 0.23326246116397756`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 95}], {
             RGBColor[
             0.7635688100456843, 0.6460359680321263, 0.5954657041374103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 96}], {
             RGBColor[
             0.9359012738140675, 0.7803182321271445, 0.5494541829980704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 105}], {
             RGBColor[
             0.8480346015059688, 0.7120288800254666, 0.6038792729704315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[
             0.8486819459504132, 0.7125345904254665, 0.603943794214876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 149}], {
             RGBColor[
             0.9143152204565861, 0.764607518450158, 0.6033749760667277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 171}], {
             RGBColor[
             0.9399813774521257, 0.7814933850844413, 0.44461387808964287`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 245}], {
             RGBColor[
             0.9085765354479234, 0.7602291024399528, 0.6096735262726196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 289}], {
             RGBColor[
             0.9376443671059687, 0.7810390459987999, 0.5205666161704313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 298}], {
             RGBColor[
             0.753915940979999, 0.6381993340678072, 0.5947057949249351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 69}], {
             RGBColor[
             0.9104980754567902, 0.9287465230222223, 0.8839876842962964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 113}], {
             RGBColor[
             0.9109037777777778, 0.9289142913580247, 0.8772641469135802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 135}], {
             RGBColor[
             0.8910974991562017, 0.9155530730325436, 0.9739458646952701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 224}], {
             RGBColor[
             0.8686753576423271, 0.8981221668922977, 0.9873362251592133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 249}], {
             RGBColor[
             0.898993673147783, 0.9214420266666667, 0.960579701779531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 254}], {
             RGBColor[
             0.8982574908727681, 0.8841208743831037, 0.6556866458191611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 288}], {
             RGBColor[
             0.509796690123457, 0.5920550111111113, 0.9588611074074074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 19}], {
             RGBColor[
             0.8590757028306797, 0.890076121030189, 0.9511645994038211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 49}], {
             RGBColor[
             0.9829296498291358, 0.9856732873094322, 0.8637916948029629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 57}], {
             RGBColor[
             0.98444356786772, 0.9851405186607846, 0.7544687074197185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 89}], {
             RGBColor[
             0.8961336980246914, 0.5574820676543211, 0.545754005185185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 111}], {
             RGBColor[
             0.8997581775200012, 0.921894629889755, 0.9552096162355219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.9721251251851852, 0.9444736115226338, 0.6312669702880657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 115}], {
             RGBColor[
             0.9845806229671923, 0.9854336656601597, 0.7693863091912496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 146}], {
             RGBColor[
             0.8656593781013199, 0.8952193381893985, 0.9518207986268551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 175}], {
             RGBColor[
             0.9848044440691358, 0.9859123963654322, 0.7937478548740737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 212}], {
             RGBColor[
             0.9662878061532358, 0.9247829637601812, 0.6085900881341455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 242}], {
             RGBColor[
             0.8320202789574761, 0.8689402182716051, 0.9484679675994512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 243}], {
             RGBColor[
             0.9617426169289697, 0.9072549384207108, 0.6023698729783522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 280}], {
             RGBColor[
             0.9709963662191359, 0.9778897179320989, 0.9339797660185184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 294}], {
             RGBColor[
             0.9774699240634726, 0.9625028731575528, 0.6520305046496357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.8130879602674568, 0.8511195937864693, 0.7924927028250863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 44}], {
             RGBColor[
             0.9289471791514075, 0.942142760146963, 0.8038371446423703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 53}], {
             RGBColor[
             0.9905110535264074, 0.9894957772441852, 0.7452564732395925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 59}], {
             RGBColor[
             0.606243644721496, 0.6684370988088735, 0.7782797291512883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 94}], {
             RGBColor[
             0.8580265493629926, 0.8863865280220931, 0.7968619809526952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 124}], {
             RGBColor[
             0.9758110682224818, 0.9789531175140889, 0.7889734847261168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 125}], {
             RGBColor[
             0.9895509213736295, 0.9890987379247408, 0.7611683477534816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 150}], {
             RGBColor[
             0.9946569768597407, 0.9909801387025186, 0.6598230883784815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 170}], {
             RGBColor[
             0.9811910409134061, 0.947106881677535, 0.4756665573129818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 192}], {
             RGBColor[
             0.989856099398321, 0.9763361585996378, 0.5093286732678847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 195}], {
             RGBColor[
             0.9941204883365926, 0.9898326439988148, 0.6014296234571852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 200}], {
             RGBColor[
             0.8980093783105667, 0.9176214178766928, 0.8008470956814093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 295}], {
             RGBColor[
             0.9574773975282063, 0.9648919818484751, 0.806558382340376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 30}], {
             RGBColor[
             0.8131499164883402, 0.8548667328395063, 0.9804105690809327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 38}], {
             RGBColor[
             0.8394263596486581, 0.8735385214189968, 0.8945017586099049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[
             0.8421547617478559, 0.8746667858037507, 0.8492850749479068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 48}], {
             RGBColor[
             0.7287300699588479, 0.7880087362962964, 0.9735966610699589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 55}], {
             RGBColor[
             0.7040323215639486, 0.768714667540361, 0.9711350203235363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 84}], {
             RGBColor[
             0.8370801605772291, 0.8725683078083951, 0.9333843489920438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 90}], {
             RGBColor[
             0.6668529075994515, 0.7396698267772841, 0.9674293238009328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 97}], {
             RGBColor[
             0.8261815809327846, 0.8224049506172837, 0.6407305624142658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 134}], {
             RGBColor[
             0.7598087812615157, 0.812372863990065, 0.9766716865168301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 144}], {
             RGBColor[
             0.8395349437839814, 0.873583423749438, 0.8927022384808634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 158}], {
             RGBColor[
             0.8229374247197669, 0.8114616499466727, 0.6281276281341874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 159}], {
             RGBColor[
             0.5071114942661181, 0.6065385072839506, 0.9557919757475994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 175}], {
             RGBColor[
             0.8418763269772291, 0.8740154793283952, 0.8149258121031548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 235}], {
             RGBColor[
             0.43400958093278474`, 0.531218650617284, 0.9515734624142661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 252}], {
             RGBColor[
             0.8161928270023446, 0.7849639622146984, 0.6214383707060481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 253}], {
             RGBColor[
             0.7617488026551993, 0.8139197843889103, 0.9768567274892372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 292}], {
             RGBColor[
             0.7157605698216736, 0.777876864217284, 0.972303982503155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 24}], {
             RGBColor[
             0.7687815648773582, 0.8146760415352241, 0.7501865587284888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 36}], {
             RGBColor[
             0.9090764105268373, 0.9258195590153544, 0.7631296155927304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 66}], {
             RGBColor[
             0.9787901040342186, 0.9806776810398206, 0.7444803380833394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 69}], {
             RGBColor[
             0.9927270496981941, 0.9897963642465871, 0.6637706592090602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 88}], {
             RGBColor[
             0.9715788486947372, 0.9752995386149822, 0.7566871123764676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 113}], {
             RGBColor[
             0.9931327520191817, 0.9899641325823896, 0.6570471218263442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 135}], {
             RGBColor[
             0.9733264733976056, 0.9766029142569086, 0.753728839608034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.7057629339883686, 0.7625541096908479, 0.7454909091521272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 222}], {
             RGBColor[
             0.9923458224398114, 0.9851751125763701, 0.48154098449032234`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.9509043318837309, 0.9591720081166626, 0.7671192000719771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 254}], {
             RGBColor[
             0.980486465114172, 0.9451707156074685, 0.435469620731925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 258}], {
             RGBColor[
             0.7812139588093052, 0.8247692190021427, 0.7511652823201713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 260}], {
             RGBColor[
             0.8126248454073848, 0.8502699917867793, 0.7536380623750409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 278}], {
             RGBColor[
             0.8493610414486508, 0.8791324084038521, 0.757187577720858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 288}], {
             RGBColor[
             0.5920256643648608, 0.6531048523354761, 0.7386440823201713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 290}], {
             RGBColor[
             0.9844790669777552, 0.9849205002882881, 0.7348504077391013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 48}], {
             RGBColor[
             0.7557854938320516, 0.8091446390548804, 0.9762932928743288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 49}], {
             RGBColor[
             0.8670569566104327, 0.8949122730309791, 0.8876662838364138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 57}], {
             RGBColor[
             0.8685708746490169, 0.8943795043823315, 0.7783432964531695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 84}], {
             RGBColor[
             0.8641355844504327, 0.893704210566979, 0.9360809807964137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 89}], {
             RGBColor[
             0.7802610048059884, 0.46672105337586794`, 0.569628594218636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 111}], {
             RGBColor[
             0.7838854843012981, 0.831133615611302, 0.9790842052689729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 112}], {
             RGBColor[
             0.8562524319664822, 0.8537125972441806, 0.6551415593215166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 158}], {
             RGBColor[
             0.8499928485929706, 0.8325975527052567, 0.6308242599385573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 175}], {
             RGBColor[
             0.8689317508504327, 0.8951513820869791, 0.8176224439075247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 177}], {
             RGBColor[
             0.8431002859856865, 0.8781616813045374, 0.9782068130663726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 242}], {
             RGBColor[
             0.716147585738773, 0.7781792039931519, 0.972342556632902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 253}], {
             RGBColor[
             0.7888042265284029, 0.8350556871474943, 0.9795533592936072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 280}], {
             RGBColor[
             0.8551236730004328, 0.8871287036536457, 0.9578543550519694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 33}], {
             RGBColor[
             0.7554683764727672, 0.8092138228921842, 0.9762447561428085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 37}], {
             RGBColor[
             0.9025120221218763, 0.9251026046765007, 0.9905635964236197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 75}], {
             RGBColor[
             0.8685215110159161, 0.897999493768453, 0.9873215511306457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 124}], {
             RGBColor[
             0.9181914844277921, 0.9370473466198038, 0.9727255380438389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 142}], {
             RGBColor[
             0.9362421504653802, 0.9473734242988978, 0.7570178923904567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 150}], {
             RGBColor[
             0.9370373930650511, 0.9490743678082336, 0.8435751416962035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 167}], {
             RGBColor[
             0.9118144131632223, 0.9322913373121835, 0.9835202562881934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 185}], {
             RGBColor[
             0.7201259162334236, 0.7805212215101954, 0.9734624682090697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 200}], {
             RGBColor[
             0.8403897945158771, 0.8757156469824078, 0.9845991489991315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 237}], {
             RGBColor[
             0.9318186864678288, 0.9330209519193445, 0.6914575392934257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 282}], {
             RGBColor[
             0.9318108934577278, 0.9471431602910618, 0.9469164718590822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 283}], {
             RGBColor[
             0.9335483330191179, 0.9478616361998566, 0.9181226019773991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 295}], {
             RGBColor[
             0.8998578137335167, 0.9229862109541902, 0.9903104356580981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 297}], {
             RGBColor[
             0.9368454720544506, 0.949225087923575, 0.863480475439635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 34}], {
             RGBColor[
             0.8131405146315416, 0.8548100699323604, 0.98178188608362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 46}], {
             RGBColor[
             0.8449351768888889, 0.8778197418666667, 0.8940392208888888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 50}], {
             RGBColor[
             0.8453795426997246, 0.8780034985491277, 0.8866749294214875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[
             0.6806314244948526, 0.7504337088965783, 0.9688026375975052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 101}], {
             RGBColor[
             0.807038703144033, 0.8499446510814817, 0.9811998898567902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 108}], {
             RGBColor[
             0.8470371082304526, 0.8776569746502059, 0.7841914653497943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[
             0.8471679554086318, 0.8787430531643711, 0.857036302571166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 169}], {
             RGBColor[
             0.8467382418381344, 0.8770177296570645, 0.7516617029355281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 187}], {
             RGBColor[
             0.7905402320520899, 0.8367892180718337, 0.9796262509556816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 205}], {
             RGBColor[
             0.8423293646090535, 0.8767421715226338, 0.9372242739917694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 213}], {
             RGBColor[
             0.8472668154576064, 0.8781482951821243, 0.8091936794367921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 264}], {
             RGBColor[
             0.8357322511111112, 0.8719015155555556, 0.9519498688888889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 61}], {
             RGBColor[
             0.9806508604938271, 0.9819656997530865, 0.7334173814814811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 72}], {
             RGBColor[
             0.9580703239739936, 0.9682494967901234, 0.9558601838877931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 177}], {
             RGBColor[
             0.9554287994513031, 0.9662794521262004, 0.9603315958847736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 217}], {
             RGBColor[
             0.9669411554707431, 0.9748653483957457, 0.9408441800471938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 247}], {
             RGBColor[
             0.938917005011431, 0.9533016052674896, 0.9652820390397805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 267}], {
             RGBColor[
             0.9598250710395207, 0.9110607561896412, 0.6096780726188911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 271}], {
             RGBColor[
             0.8885843150062096, 0.9132539698385567, 0.9604583646592154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 273}], {
             RGBColor[
             0.9790129249382715, 0.9828759868641976, 0.8759651037037035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 274}], {
             RGBColor[
             0.9662520610020178, 0.9743514228692589, 0.9420106372381244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 285}], {
             RGBColor[
             0.9797640637475907, 0.983186602065238, 0.8635167897483595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[
             0.7454719347976948, 0.7954280011585895, 0.7217774916229207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 180}], {
             RGBColor[
             0.9755416923374507, 0.9779146514591948, 0.7229721912535763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 267}], {
             RGBColor[
             0.9724431586767217, 0.9171063420395886, 0.3850054183158859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 285}], {
             RGBColor[
             0.9923821513847917, 0.9892321879151853, 0.6388441354453545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.5208840308400151, 0.6219161476509265, 0.9554250454502521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 113}], {
             RGBColor[
             0.7683294548334851, 0.8159531805577727, 0.8641036714700461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 135}], {
             RGBColor[
             0.7485231762119089, 0.8025919622322917, 0.960785389251736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 224}], {
             RGBColor[
             0.7261010346980343, 0.7851610560920457, 0.974175749715679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 233}], {
             RGBColor[
             0.762935670142127, 0.8133407766071554, 0.9363887964083176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 254}], {
             RGBColor[
             0.7556831679284755, 0.7711597635828517, 0.6425261703756269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 259}], {
             RGBColor[
             0.7643533707632557, 0.8143089676140332, 0.9299976742894743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 260}], {
             RGBColor[
             0.5878215482216882, 0.6762590397621624, 0.9606946120187427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 288}], {
             RGBColor[
             0.3672223671791642, 0.4790939003108592, 0.9457006319638732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 29}], {
             RGBColor[
             0.907707786836981, 0.5744139035241953, 0.4400926055607049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[
             0.9693236102760907, 0.902866379217534, 0.49326991396064385`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 77}], {
             RGBColor[
             0.9938335678276802, 0.9892189500423644, 0.5702000967301889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 91}], {
             RGBColor[
             0.9590632756588068, 0.8621875715138305, 0.4850142078865698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 139}], {
             RGBColor[
             0.8584506431543426, 0.8872936217593309, 0.8430219729376354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 147}], {
             RGBColor[
             0.9937391996378961, 0.9915624186766581, 0.7449460616250467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 148}], {
             RGBColor[
             0.9909017240538684, 0.9793398218842007, 0.557903195293977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 172}], {
             RGBColor[
             0.9023257872425421, 0.921569217784478, 0.8473950372638142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 203}], {
             RGBColor[
             0.9943391794074038, 0.9903004020862209, 0.6252327969101388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 206}], {
             RGBColor[
             0.9849968825313771, 0.9594214049061154, 0.5349640010148538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 244}], {
             RGBColor[
             0.9849119630340973, 0.986331355245283, 0.8204459158558919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 270}], {
             RGBColor[
             0.5899938266301665, 0.6518188539703417, 0.8234901665213521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 272}], {
             RGBColor[
             0.9884777246209762, 0.9889906943983785, 0.8144100115888733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 39}], {
             RGBColor[
             0.7335389267523723, 0.607441702291603, 0.5902209090113254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 59}], {
             RGBColor[
             0.40380807445897754`, 0.5121116506619106, 0.9482789658422512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 60}], {
             RGBColor[
             0.7626378018508504, 0.8146195131903131, 0.9771488400901388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 62}], {
             RGBColor[
             0.7919664883687945, 0.8341094462411348, 0.8020760490780141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 82}], {
             RGBColor[
             0.7244314185798817, 0.5660866347928992, 0.5826213809467455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[
             0.7903019185202274, 0.8340910172924945, 0.878357915903285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 127}], {
             RGBColor[
             0.7056382422760479, 0.7691734560553634, 0.9718454609919263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 130}], {
             RGBColor[
             0.7404088375308644, 0.796898584888889, 0.9751619114074075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 137}], {
             RGBColor[
             0.729789512720622, 0.7884310235390948, 0.9741490307270233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 170}], {
             RGBColor[
             0.7787554706508877, 0.7907814335305721, 0.6456657940039447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 192}], {
             RGBColor[
             0.7874205291358025, 0.8200107104526749, 0.6793279099588476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 195}], {
             RGBColor[
             0.7916849180740742, 0.8335071958518518, 0.7714288601481483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 199}], {
             RGBColor[
             0.7893932280000001, 0.8266650869333334, 0.6869914725333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 220}], {
             RGBColor[
             0.7048481227831125, 0.41718136163999464`, 0.5639318502667277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 226}], {
             RGBColor[
             0.7554580041503886, 0.8088983818525519, 0.9765973143541273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 228}], {
             RGBColor[
             0.782152473296399, 0.8022403211080333, 0.6588625078116345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 266}], {
             RGBColor[
             0.7919242643820096, 0.8347618989987282, 0.8514714464770492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 32}], {
             RGBColor[
             0.9097180705738377, 0.9294080353707816, 0.9396458581482242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 103}], {
             RGBColor[
             0.8732158866428918, 0.9017426614679718, 0.9877693048686652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 119}], {
             RGBColor[
             0.5669251140214084, 0.6514502233240997, 0.9622130152518724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 152}], {
             RGBColor[
             0.8427008526049067, 0.8774108016346154, 0.9848587536810297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 268}], {
             RGBColor[
             0.9146242626813712, 0.9311886212755416, 0.8402923590578186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 35}], {
             RGBColor[
             0.9911558754814582, 0.98103884272436, 0.4873177190907924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 126}], {
             RGBColor[
             0.9663864033112186, 0.8924663452752375, 0.41723334504213727`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 163}], {
             RGBColor[
             0.8682798828958938, 0.8940464726628539, 0.7698477207072156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 184}], {
             RGBColor[
             0.9934806091582491, 0.9884640071380472, 0.5317827237710433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 189}], {
             RGBColor[
             0.8601108912606311, 0.8876647943107506, 0.7690335119645799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 197}], {
             RGBColor[
             0.8760507761419898, 0.9001171535276801, 0.7706222507228604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 211}], {
             RGBColor[
             0.9829900190177638, 0.9534934914380426, 0.45559490872193986`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 216}], {
             RGBColor[
             0.9761971413281476, 0.9788818836169637, 0.7598216311866587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 275}], {
             RGBColor[
             0.9938626701952862, 0.989281197063973, 0.5733677098451178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 293}], {
             RGBColor[
             0.9928809634514997, 0.9900309633943303, 0.6736463052250533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 77}], {
             RGBColor[
             0.9063945065569241, 0.5716049297981582, 0.29715015170293946`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 91}], {
             RGBColor[
             0.8716242143880508, 0.44457355126962433`, 0.21196426285932035`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 148}], {
             RGBColor[
             0.9034626627831124, 0.5617258016399944, 0.28485325026672753`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 162}], {
             RGBColor[
             0.8902541294497791, 0.51717031719555, 0.23354059248894987`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 172}], {
             RGBColor[
             0.8148867259717861, 0.5039551975402718, 0.5743450922365646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 191}], {
             RGBColor[
             0.9039928051236779, 0.5729942568405206, 0.5101345996289894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 203}], {
             RGBColor[
             0.9069001181366478, 0.5726863818420147, 0.3521828518828892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 206}], {
             RGBColor[
             0.8975578212606211, 0.5418073846619091, 0.26191405598760426`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 244}], {
             RGBColor[
             0.8974729017633414, 0.5687173350010768, 0.5473959708286424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 270}], {
             RGBColor[
             0.5025547653594106, 0.23420483372613546`, 0.5504402214941025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 272}], {
             RGBColor[
             0.9010386633502201, 0.5713766741541724, 0.5413600665616237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 38}], {
             RGBColor[
             0.963484114271429, 0.9713619530239351, 0.9052664028623054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 47}], {
             RGBColor[
             0.9662344143055556, 0.9724812922222223, 0.8583798179166666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 48}], {
             RGBColor[
             0.8527878245816188, 0.8858321679012346, 0.9843613053223594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 74}], {
             RGBColor[
             0.71749873254974, 0.7779286851178452, 0.9723910979308233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 90}], {
             RGBColor[
             0.7909106622222224, 0.8374932583822223, 0.9781939680533334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 123}], {
             RGBColor[
             0.9309684726617284, 0.8459869248592593, 0.6247344122074073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 144}], {
             RGBColor[
             0.9635926984067522, 0.9714068553543762, 0.9034668827332639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 158}], {
             RGBColor[
             0.9469951793425379, 0.9092850815516109, 0.638892272386588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 252}], {
             RGBColor[
             0.9402505816251154, 0.8827873938196368, 0.6322030149584487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 257}], {
             RGBColor[0.9556440075555556, 0.9384596099555556, 0.6724913368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 259}], {
             RGBColor[
             0.9609680724729806, 0.9703215050809518, 0.9469637267700456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 36}], {
             RGBColor[
             0.9084271449274086, 0.9270151691490143, 0.8803141061120652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 51}], {
             RGBColor[
             0.9704854758184543, 0.976163934268723, 0.874623360673788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 58}], {
             RGBColor[
             0.9280649348025711, 0.9426738097418631, 0.8821871760412201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 66}], {
             RGBColor[
             0.97814083843479, 0.9818732911734803, 0.861664828602674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 67}], {
             RGBColor[
             0.9210445524774638, 0.937075947439024, 0.8815175657078822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 73}], {
             RGBColor[
             0.9475049434202003, 0.8211252128266863, 0.5090207397886076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 95}], {
             RGBColor[
             0.8170748073051477, 0.85560538452024, 0.8712239827620405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 96}], {
             RGBColor[
             0.9894072710735309, 0.9898876486152581, 0.8252124616227006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 109}], {
             RGBColor[
             0.993560372262689, 0.9912189359531731, 0.7283174896628255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 110}], {
             RGBColor[
             0.9815800283950618, 0.9522452967901236, 0.559424672345679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 138}], {
             RGBColor[
             0.9643955870348455, 0.9716221051851852, 0.8849319538870625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 154}], {
             RGBColor[
             0.9836173634567902, 0.9859576745679013, 0.8523945002469133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 171}], {
             RGBColor[
             0.9934873747115891, 0.9910628015725551, 0.7203721567142729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 245}], {
             RGBColor[
             0.9620825327073868, 0.9697985189280666, 0.8854318048972496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 156}], {
             RGBColor[
             0.9382805457844438, 0.7939003264655535, 0.5631575588545384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 178}], {
             RGBColor[
             0.9882679276939088, 0.9894165008479952, 0.8440943299491886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 182}], {
             RGBColor[
             0.9296567071013162, 0.7547414891541678, 0.5559616164677071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 202}], {
             RGBColor[
             0.9135046849011137, 0.9324273788504438, 0.9400070288031104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 208}], {
             RGBColor[
             0.9800651236445261, 0.984488732117131, 0.9112643068380775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 268}], {
             RGBColor[
             0.9900880433472029, 0.9899209148303798, 0.7958851042153791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 37}], {
             RGBColor[
             0.7789209056589856, 0.8279142330633289, 0.9784816793129099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 75}], {
             RGBColor[
             0.7449303945530255, 0.8008111221552813, 0.975239634019936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 94}], {
             RGBColor[
             0.6768158491054124, 0.7472923855146364, 0.9685321171597077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 124}], {
             RGBColor[
             0.7946003679649016, 0.8398589750066321, 0.9606436209331293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 142}], {
             RGBColor[
             0.8126510340024896, 0.850185052685726, 0.7449359752797469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 150}], {
             RGBColor[
             0.8134462766021606, 0.8518859961950618, 0.8314932245854938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 185}], {
             RGBColor[
             0.596534799770533, 0.6833328498970237, 0.96138055109836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 200}], {
             RGBColor[
             0.7167986780529865, 0.778527275369236, 0.9725172318884218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 237}], {
             RGBColor[
             0.8082275700049383, 0.8358325803061728, 0.6793756221827159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 239}], {
             RGBColor[
             0.802554396671605, 0.8166956345283951, 0.6573364150716049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 282}], {
             RGBColor[
             0.8082197769948374, 0.8499547886778901, 0.9348345547483725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 295}], {
             RGBColor[
             0.7762666972706261, 0.8257978393410185, 0.9782285185473885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 297}], {
             RGBColor[
             0.8132543555915601, 0.8520367163104032, 0.8513985583289252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 46}], {
             RGBColor[
             0.9580872470759859, 0.967074251799027, 0.9050891425280645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 50}], {
             RGBColor[
             0.9585316128868215, 0.9672580084814879, 0.8977248510606632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 87}], {
             RGBColor[
             0.7937834946819495, 0.8396882188289385, 0.9798525592366809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 108}], {
             RGBColor[
             0.9601891784175497, 0.9669114845825661, 0.7952413869889701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 114}], {
             RGBColor[
             0.9603200255957288, 0.9679975630967312, 0.8680862242103418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 169}], {
             RGBColor[
             0.9598903120252315, 0.9662722395894248, 0.7627116245747038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 187}], {
             RGBColor[
             0.903692302239187, 0.926043728004194, 0.9906761725948572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 205}], {
             RGBColor[
             0.9554814347961504, 0.9659966814549941, 0.9482741956309451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 213}], {
             RGBColor[
             0.9604188856447033, 0.9674028051144845, 0.8202436010759677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 227}], {
             RGBColor[
             0.825036851966106, 0.8641035790736347, 0.9829676018115363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 264}], {
             RGBColor[
             0.9488843212982081, 0.9611560254879159, 0.9629997905280645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 92}], {
             RGBColor[
             0.9721936160097727, 0.9178337781780095, 0.346638809949229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 126}], {
             RGBColor[
             0.9637592545502526, 0.8843943455753551, 0.3398523247389904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 163}], {
             RGBColor[
             0.8656527341349277, 0.8859744729629715, 0.6924667004040689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 184}], {
             RGBColor[
             0.9908534603972831, 0.9803920074381648, 0.45440170346789643`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 189}], {
             RGBColor[
             0.8574837424996651, 0.8795927946108683, 0.691652491661433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 197}], {
             RGBColor[
             0.8734236273810236, 0.8920451538277977, 0.6932412304197135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 211}], {
             RGBColor[
             0.9803628702567977, 0.9454214917381603, 0.378213888418793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 216}], {
             RGBColor[
             0.9735699925671815, 0.9708098839170813, 0.6824406108835119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 275}], {
             RGBColor[
             0.9912355214343201, 0.9812091973640906, 0.495986689541971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 58}], {
             RGBColor[
             0.8442057488657824, 0.8786107650637168, 0.9850022920298287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 66}], {
             RGBColor[
             0.8942816524980011, 0.917810246495334, 0.9644799445912826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 67}], {
             RGBColor[
             0.8371853665406748, 0.8730129027608777, 0.9843326816964908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 69}], {
             RGBColor[
             0.9082185981619766, 0.9269289297021006, 0.8837702657170036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 88}], {
             RGBColor[
             0.8870703971585197, 0.9124321040704957, 0.9766867188844109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 95}], {
             RGBColor[
             0.7332156213683588, 0.7915423398420938, 0.9740390987506491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 96}], {
             RGBColor[
             0.905548085136742, 0.9258246039371119, 0.9280275776113092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 109}], {
             RGBColor[
             0.9097011863259001, 0.9271558912750268, 0.8311326056514341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 113}], {
             RGBColor[
             0.9086243004829642, 0.9270966980379032, 0.8770467283342875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 138}], {
             RGBColor[
             0.8805364010980565, 0.9075590605070389, 0.9877470698756711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 154}], {
             RGBColor[
             0.8997581775200012, 0.921894629889755, 0.9552096162355219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 198}], {
             RGBColor[
             0.6212544824521511, 0.6996866751463615, 0.9654905156600706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 222}], {
             RGBColor[
             0.9078373709035938, 0.9223076780318836, 0.7015405909982657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 224}], {
             RGBColor[
             0.8663958803475134, 0.8963045735721762, 0.9871188065799206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 245}], {
             RGBColor[
             0.878223346770598, 0.9057354742499203, 0.9882469208858582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 258}], {
             RGBColor[
             0.6967055072730877, 0.7619017844576563, 0.9711648888281146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 260}], {
             RGBColor[
             0.7281163938711672, 0.7874025572422928, 0.9736376688829843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 278}], {
             RGBColor[
             0.7648525899124332, 0.8162649738593657, 0.9771871842288014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 290}], {
             RGBColor[
             0.8999706154415377, 0.9220530657438017, 0.9548500142470446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 75}], {
             RGBColor[
             0.8919740402021346, 0.9166999039395978, 0.9895584743007471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 94}], {
             RGBColor[
             0.8238594947545215, 0.8631811672989529, 0.9828509574405188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 102}], {
             RGBColor[
             0.9592980080803513, 0.9675119752242762, 0.8822898731755454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 124}], {
             RGBColor[
             0.9416440136140106, 0.9557477567909485, 0.9749624612139404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 142}], {
             RGBColor[
             0.9596946796515986, 0.9660738344700425, 0.7592548155605581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 150}], {
             RGBColor[
             0.9604899222512696, 0.9677747779793783, 0.845812064866305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 185}], {
             RGBColor[
             0.7435784454196421, 0.7992216316813401, 0.9756993913791712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 237}], {
             RGBColor[
             0.9552712156540473, 0.9517213620904892, 0.6936944624635271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 239}], {
             RGBColor[
             0.949598042320714, 0.9325844163127115, 0.671655255352416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 282}], {
             RGBColor[
             0.9552634226439464, 0.9658435704622066, 0.9491533950291837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 283}], {
             RGBColor[
             0.9570008622053363, 0.9665620463710014, 0.9203595251475005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 295}], {
             RGBColor[
             0.9233103429197351, 0.941686621125335, 0.9925473588281996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 297}], {
             RGBColor[
             0.9602980012406691, 0.9679254980947196, 0.8657173986097364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 48}], {
             RGBColor[
             0.8790642677419367, 0.9045039564807253, 0.8984524948513315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 55}], {
             RGBColor[
             0.8543665193470371, 0.8852098877247898, 0.8959908541049091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 74}], {
             RGBColor[
             0.7437751757100577, 0.7966004736973358, 0.8864822874597955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 90}], {
             RGBColor[
             0.8171871053825401, 0.856165046961713, 0.8922851575823054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 123}], {
             RGBColor[
             0.9572449158220462, 0.8646587134387498, 0.5388256017363795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 144}], {
             RGBColor[
             0.98986914156707, 0.9900786439338669, 0.8175580722622361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 158}], {
             RGBColor[
             0.9732716225028557, 0.9279568701311016, 0.55298346191556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 252}], {
             RGBColor[
             0.9665270247854332, 0.9014591823991274, 0.5462942044874208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 253}], {
             RGBColor[
             0.9120830004382879, 0.9304150045733393, 0.90171256127061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 257}], {
             RGBColor[
             0.9819204507158734, 0.9571313985350463, 0.5865825263289721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 259}], {
             RGBColor[
             0.9872445156332983, 0.9889932936604424, 0.8610549162990178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 52}], {
             RGBColor[
             0.6311487567694163, 0.5224521759122507, 0.5826755670488224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 59}], {
             RGBColor[
             0.5479194812113497, 0.44199051295351344`, 0.5776788348535766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 60}], {
             RGBColor[
             0.9067492086032225, 0.7444983754819161, 0.6065487091014642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 62}], {
             RGBColor[
             0.9360778951211666, 0.7639883085327377, 0.43147591808933944`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 82}], {
             RGBColor[
             0.8685428253322538, 0.4959654970845022, 0.21202124995807092`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 100}], {
             RGBColor[
             0.9344133252725995, 0.7639698795840973, 0.5077577849146104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 107}], {
             RGBColor[
             0.8792173544066932, 0.7225490667360475, 0.6040559860483624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 127}], {
             RGBColor[
             0.84974964902842, 0.6990523183469664, 0.6012453300032516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 136}], {
             RGBColor[
             0.9204606667523721, 0.7125435822916028, 0.26571798901132515`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 137}], {
             RGBColor[
             0.8739009194729941, 0.7183098858306977, 0.6035488997383487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 141}], {
             RGBColor[
             0.9223605358190389, 0.7561412777582697, 0.5801228042113253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 170}], {
             RGBColor[
             0.9228668774032598, 0.7206602958221751, 0.2750656630152702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 192}], {
             RGBColor[
             0.9315319358881746, 0.7498895727442778, 0.308727778970173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 220}], {
             RGBColor[
             0.8489595295354846, 0.3470602239315975, 0.1933317192780531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 228}], {
             RGBColor[
             0.9262638800487711, 0.7321191833996363, 0.28826237682295985`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 232}], {
             RGBColor[
             0.9271503795714723, 0.7597135353861852, 0.5720148481297826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 266}], {
             RGBColor[
             0.9360356711343817, 0.7646407612903312, 0.48087131548837464`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 281}], {
             RGBColor[
             0.8826352584389348, 0.5599559444505663, 0.22378032157943067`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.9808374491533, 0.9837318652512612, 0.8502685000555799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.9789243304358697, 0.9823050644442461, 0.8535069110229149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 162}], {
             RGBColor[
             0.9767220543721236, 0.9344993413280736, 0.5311599130440496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 191}], {
             RGBColor[
             0.9904607300460224, 0.990323280973044, 0.8077539201840891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 76}], {
             RGBColor[
             0.9841969130579475, 0.9818704312894115, 0.6711070339802563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.963525786276713, 0.9723181716429918, 0.9466255092217377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 99}], {
             RGBColor[
             0.6959237864461506, 0.7580257255555296, 0.9353154982326568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 104}], {
             RGBColor[
             0.9834188366135032, 0.9792457967412636, 0.6680843539209971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 157}], {
             RGBColor[
             0.8802705139126485, 0.9065888698079303, 0.9510093959175783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 201}], {
             RGBColor[
             0.9450121959729154, 0.8368519767743212, 0.585748593813008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 209}], {
             RGBColor[
             0.9855961568287455, 0.9871963380816092, 0.8384263201361419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 222}], {
             RGBColor[
             0.9842927600217872, 0.9821937456043798, 0.6714793813355926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 229}], {
             RGBColor[
             0.9852118660673996, 0.9850213210155447, 0.6982456104061047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 259}], {
             RGBColor[
             0.9811036055309281, 0.9853385526666597, 0.9128795214910427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 261}], {
             RGBColor[
             0.9058742698480711, 0.9267061853634857, 0.9535306976839599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 278}], {
             RGBColor[
             0.8413079790306265, 0.8761510414318618, 0.9471259745661282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 290}], {
             RGBColor[
             0.9764260045597308, 0.9819391333162979, 0.9247888045843715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 55}], {
             RGBColor[
             0.8570949214462349, 0.8863381521095437, 0.850774170442911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[
             0.9792441808150711, 0.9400284351864665, 0.5203697125336406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 134}], {
             RGBColor[
             0.9128713811438023, 0.9299963485592477, 0.8563108366362049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 144}], {
             RGBColor[
             0.9925975436662677, 0.9912069083186208, 0.7723413886002382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 159}], {
             RGBColor[
             0.6601740941484044, 0.7241619918531335, 0.8354311258669742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 235}], {
             RGBColor[
             0.5870721808150712, 0.6488421351864667, 0.8312126125336408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 252}], {
             RGBColor[
             0.969255426884631, 0.9025874467838813, 0.5010775208254229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 292}], {
             RGBColor[
             0.8688231697039601, 0.8955003487864668, 0.8519431326225297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 63}], {
             RGBColor[
             0.8228692703934373, 0.790508948037154, 0.622176736615532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 131}], {
             RGBColor[
             0.9555140133179496, 0.8579150643821886, 0.3008743875327204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 139}], {
             RGBColor[
             0.8326274053226963, 0.7981320772084635, 0.6231493363103249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 143}], {
             RGBColor[
             0.9228969071873152, 0.8693165747157574, 0.6319700126915704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 172}], {
             RGBColor[
             0.8765025494108959, 0.8324076732336105, 0.6275224006365036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 174}], {
             RGBColor[
             0.9482842285883004, 0.8891118348103213, 0.6188624737323072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 183}], {
             RGBColor[
             0.8845470725821196, 0.8387374575801034, 0.6283121712316253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 185}], {
             RGBColor[
             0.752346355987817, 0.7341725415908507, 0.6159977702489772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 244}], {
             RGBColor[
             0.9590887252024511, 0.8971698106944155, 0.6005732792285814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 59}], {
             RGBColor[
             0.5408921633478663, 0.6203661226619104, 0.9612943071755846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 60}], {
             RGBColor[
             0.8997218907397392, 0.9228739851903132, 0.9901641814234721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 94}], {
             RGBColor[
             0.792675067989363, 0.8383155518751302, 0.9798765589769916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 100}], {
             RGBColor[
             0.9273860074091161, 0.9423454892924943, 0.8913732572366184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 121}], {
             RGBColor[
             0.9292103533333333, 0.942705663111111, 0.8324820302222222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 124}], {
             RGBColor[
             0.9104595868488521, 0.9308821413671258, 0.9719880627504132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 125}], {
             RGBColor[0.92419944, 0.9410277617777778, 0.9441829257777778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 137}], {
             RGBColor[
             0.8668736016095108, 0.8966854955390946, 0.9871643720603567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 150}], {
             RGBColor[
             0.9293054954861111, 0.9429091625555556, 0.8428376664027777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 170}], {
             RGBColor[
             0.9158395595397765, 0.899035905530572, 0.6586811353372781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 192}], {
             RGBColor[
             0.9245046180246914, 0.9282651824526749, 0.692343251292181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 195}], {
             RGBColor[
             0.928769006962963, 0.9417616678518519, 0.7844442014814815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 200}], {
             RGBColor[
             0.8326578969369371, 0.8695504417297297, 0.9838616737057058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 256}], {
             RGBColor[
             0.890270283398349, 0.9153413745115055, 0.9893959684558404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 299}], {
             RGBColor[
             0.9151388830452676, 0.8966723591879286, 0.6559591394677641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 53}], {
             RGBColor[
             0.9904079098208162, 0.9903014384525035, 0.8086292880101165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 68}], {
             RGBColor[
             0.9910023097924828, 0.9905472381161702, 0.7987785422217831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 195}], {
             RGBColor[
             0.9940173446310014, 0.990638305207133, 0.6648024382277091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 200}], {
             RGBColor[
             0.8979062346049755, 0.9184270790850111, 0.8642199104519332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 215}], {
             RGBColor[
             0.9946196106107957, 0.9919264912394821, 0.7303553733735382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 223}], {
             RGBColor[
             0.9738325210853224, 0.9227315965256517, 0.5145349398869683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 225}], {
             RGBColor[
             0.9171199489077079, 0.9335999529916449, 0.8660917055726739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 234}], {
             RGBColor[
             0.9741657506416705, 0.978608627971346, 0.8549567976040235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 255}], {
             RGBColor[
             0.9696428960306115, 0.9752354904079128, 0.8626128107111398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 282}], {
             RGBColor[
             0.9893273335468262, 0.989854592393665, 0.8265372333118841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 287}], {
             RGBColor[
             0.9731806649778997, 0.9778739526962353, 0.8566242906812984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 50}], {
             RGBColor[
             0.9903262751441689, 0.9902676804157944, 0.809982185865932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 108}], {
             RGBColor[
             0.9919838406748971, 0.9899211565168724, 0.7074987217942388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 114}], {
             RGBColor[
             0.9921146878530762, 0.9910072350310377, 0.7803435590156105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 145}], {
             RGBColor[
             0.7418987571555556, 0.7950529441777778, 0.8853242347555554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 169}], {
             RGBColor[
             0.9916849742825788, 0.9892819115237311, 0.6749689593799724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 187}], {
             RGBColor[
             0.9354869644965342, 0.9490533999385002, 0.9029335074001259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 213}], {
             RGBColor[
             0.9922135479020509, 0.990412477048791, 0.7325009358812364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 219}], {
             RGBColor[
             0.9837500505760896, 0.9631234853095689, 0.5924489041548573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 221}], {
             RGBColor[
             0.9919121127407408, 0.9897677377185186, 0.6996915788148148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 264}], {
             RGBColor[
             0.9806789835555555, 0.9841656974222222, 0.8752571253333332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 48}], {
             RGBColor[
             0.8818145677760633, 0.9056232956790125, 0.8515659099056927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 74}], {
             RGBColor[
             0.7465254757441844, 0.7977198128956229, 0.8395957025141567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 90}], {
             RGBColor[
             0.8199374054166668, 0.8572843861600001, 0.8453985726366666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.9760219225369823, 0.9290762093293887, 0.5060968769699212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 166}], {
             RGBColor[
             0.7802037850511974, 0.8250613815816006, 0.8422469823905168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 177}], {
             RGBColor[
             0.9691293599296982, 0.9746403379286694, 0.8534794300977366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 217}], {
             RGBColor[
             0.9806417159491382, 0.9832262341982149, 0.8339920142601569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 233}], {
             RGBColor[
             0.9885771150462963, 0.9891444418518518, 0.8205594534722223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 262}], {
             RGBColor[
             0.9813246128326446, 0.9469634288275481, 0.5266968274395315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 273}], {
             RGBColor[
             0.9927134854166666, 0.9912368726666667, 0.7691129379166666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 74}], {
             RGBColor[
             0.6330788860202476, 0.7110706885746354, 0.9655771899198495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 84}], {
             RGBColor[
             0.8767180686705076, 0.9035337428701236, 0.9373350852334705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 90}], {
             RGBColor[
             0.7064908156927301, 0.7706352618390125, 0.9713800600423594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 144}], {
             RGBColor[
             0.8791728518772599, 0.9045488588111664, 0.89665297472229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 158}], {
             RGBColor[
             0.8625753328130455, 0.8424270850084011, 0.632078364375614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 175}], {
             RGBColor[
             0.8815142350705076, 0.9049809143901235, 0.8188765483445815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 177}], {
             RGBColor[
             0.8556827702057614, 0.8879912136076819, 0.9794609175034293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 217}], {
             RGBColor[
             0.8671951262252015, 0.8965771098772273, 0.9599735016658497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 252}], {
             RGBColor[
             0.8558307350956231, 0.815929397276427, 0.6253891069474748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 253}], {
             RGBColor[
             0.8013867107484778, 0.8448852194506388, 0.9808074637306639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 57}], {
             RGBColor[
             0.9924248216474731, 0.9899766706615747, 0.6909703918523112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 84}], {
             RGBColor[
             0.9879895314488889, 0.9893013768462222, 0.8487080761955554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 112}], {
             RGBColor[
             0.9801063789649382, 0.9493097635234238, 0.5677686547206584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 115}], {
             RGBColor[
             0.9925618767469454, 0.9902698176609498, 0.7058879936238422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 146}], {
             RGBColor[
             0.873640631881073, 0.9000554901901885, 0.8883224830594478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 159}], {
             RGBColor[
             0.6580208651377778, 0.7232715763217779, 0.8711157029511112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 175}], {
             RGBColor[
             0.9927856978488889, 0.9907485483662223, 0.7302495393066665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 204}], {
             RGBColor[0.98617209536, 0.9880914978773334, 0.8583030802844445]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 242}], {
             RGBColor[
             0.8400015327372292, 0.8737763702723951, 0.8849696520320438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 243}], {
             RGBColor[
             0.9697238707087228, 0.9120910904215009, 0.538871557410945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 253}], {
             RGBColor[
             0.9126581735268591, 0.9306528534267375, 0.892180454692749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 280}], {
             RGBColor[
             0.9789776199988889, 0.9827258699328889, 0.8704814504511111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 292}], {
             RGBColor[
             0.8666699406933334, 0.8946099332551112, 0.8876277097066667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 87}], {
             RGBColor[
             0.8260225227501325, 0.862881647445706, 0.8847456025745484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 108}], {
             RGBColor[
             0.9924282064857327, 0.9901049131993335, 0.7001344303268375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 114}], {
             RGBColor[
             0.9925590536639118, 0.9911909917134987, 0.7729792675482092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 169}], {
             RGBColor[
             0.9921293400934145, 0.9894656682061922, 0.6676046679125712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 187}], {
             RGBColor[
             0.93593133030737, 0.9492371566209613, 0.8955692159327246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 205}], {
             RGBColor[
             0.9877204628643335, 0.9891901100717615, 0.8531672389688125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 213}], {
             RGBColor[
             0.9926579137128864, 0.9905962337312519, 0.7251366444138352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 227}], {
             RGBColor[
             0.857275880034289, 0.887297007690402, 0.8878606451494038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 264}], {
             RGBColor[
             0.9811233493663911, 0.9843494541046832, 0.867892833865932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 52}], {
             RGBColor[
             0.6666659004033997, 0.7344167209757905, 0.9587390436495566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 58}], {
             RGBColor[
             0.906264079756828, 0.9277595301834256, 0.9793115465915516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 66}], {
             RGBColor[
             0.9563399833890469, 0.9669590116150428, 0.9587891991530055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 67}], {
             RGBColor[
             0.8992436974317206, 0.9221616678805866, 0.9786419362582135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 69}], {
             RGBColor[
             0.9702769290530222, 0.9760776948218095, 0.8780795202787264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 86}], {
             RGBColor[
             0.9709391376601275, 0.9745499474757977, 0.7361486082492326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[
             0.9147344980406766, 0.9345136117995871, 0.9801194626490968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 109}], {
             RGBColor[
             0.9717595172169459, 0.9763046563947356, 0.825441860213157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 110}], {
             RGBColor[
             0.9597791733493186, 0.9373310172316861, 0.6565490428960103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 138}], {
             RGBColor[
             0.9425947319891024, 0.9567078256267477, 0.9820563244373939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 141}], {
             RGBColor[
             0.9578776794530223, 0.9681058228218095, 0.9561862808120597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 154}], {
             RGBColor[
             0.961816508411047, 0.9710433950094638, 0.9495188707972448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 165}], {
             RGBColor[
             0.967509544930055, 0.9749333103684346, 0.9239422369568284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 179}], {
             RGBColor[
             0.9326216195759244, 0.9487763169788141, 0.9818255522691506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 258}], {
             RGBColor[
             0.7587638381641335, 0.8110505495773651, 0.9654741433898375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 281}], {
             RGBColor[
             0.9181524020729182, 0.7719204895141061, 0.599843798180165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 82}], {
             RGBColor[
             0.6220412485969257, 0.4810971084135469, 0.5750760389842424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 86}], {
             RGBColor[
             0.688920417290816, 0.7477170137413027, 0.7231399206746698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 107}], {
             RGBColor[
             0.632715777671365, 0.7076806780650922, 0.967110775074534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 110}], {
             RGBColor[
             0.6777604529800071, 0.710498083497191, 0.6435403553214476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 141}], {
             RGBColor[
             0.6758589590837107, 0.7412728890873144, 0.943177593237497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 165}], {
             RGBColor[
             0.6854908245607434, 0.7481003766339395, 0.9109335493822657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 179}], {
             RGBColor[
             0.6506028992066129, 0.7219433832443191, 0.9688168646945878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 193}], {
             RGBColor[
             0.4036551036234294, 0.5240474952883646, 0.9469415241580599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 236}], {
             RGBColor[
             0.6189890391556729, 0.6967353493750703, 0.9658015065009031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 266}], {
             RGBColor[
             0.6895340943990536, 0.7497723726193759, 0.8439261045145462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 281}], {
             RGBColor[
             0.6361336817036067, 0.545087555779611, 0.5868351106056022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 59}], {
             RGBColor[
             0.6024560377228663, 0.6677191397591327, 0.9027136357728068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 68}], {
             RGBColor[
             0.9873178464994444, 0.9890236178581111, 0.8598396340727777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 150}], {
             RGBColor[0.9908693698611111, 0.9902621796527777, 0.784256995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 170}], {
             RGBColor[
             0.9774034339147765, 0.9463889226277942, 0.6001004639345003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 192}], {
             RGBColor[
             0.9860684923996914, 0.9756181995498971, 0.6337625798894032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 195}], {
             RGBColor[
             0.990332881337963, 0.9891146849490741, 0.7258635300787037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 200}], {
             RGBColor[
             0.8942217713119371, 0.916903458826952, 0.9252810023029279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 225}], {
             RGBColor[
             0.9134354856146695, 0.9320763327335859, 0.9271527974236685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 234}], {
             RGBColor[
             0.9704812873486321, 0.9770850077132869, 0.9160178894550182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 255}], {
             RGBColor[
             0.9659584327375731, 0.9737118701498538, 0.9236739025621344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 282}], {
             RGBColor[
             0.9856428702537878, 0.9883309721356061, 0.8875983251628787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 287}], {
             RGBColor[
             0.9694962016848613, 0.9763503324381764, 0.917685382532293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 72}], {
             RGBColor[
             0.8275227549682227, 0.8658988613105414, 0.9719194958799036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 106}], {
             RGBColor[
             0.8504804405275879, 0.8804217479334453, 0.7905270389325363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 151}], {
             RGBColor[
             0.8411912441811926, 0.8760927981854774, 0.9487823089552786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 167}], {
             RGBColor[
             0.8256671159612274, 0.8645149287774543, 0.9750606086905818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 194}], {
             RGBColor[
             0.8496193948428159, 0.8810025761314781, 0.8728990043949264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 238}], {
             RGBColor[
             0.8170388257102784, 0.7601878473846153, 0.6158898583624808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 251}], {
             RGBColor[
             0.8509656915963929, 0.8815593044373305, 0.8505873830838441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 286}], {
             RGBColor[
             0.7128686898969978, 0.7756177056410258, 0.9720157469384177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 90}], {
             RGBColor[
             0.6817930672978305, 0.7513411930830771, 0.9689184192959369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 97}], {
             RGBColor[
             0.8411217406311637, 0.8340763169230767, 0.64221965790927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 134}], {
             RGBColor[
             0.7747489409598949, 0.824044230295858, 0.9781607820118343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 144}], {
             RGBColor[
             0.8544751034823604, 0.885254790055231, 0.8941913339758676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 159}], {
             RGBColor[
             0.5220516539644972, 0.6182098735897437, 0.9572810712426036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 235}], {
             RGBColor[
             0.4489497406311638, 0.542890016923077, 0.9530625579092702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 252}], {
             RGBColor[
             0.8311329867007237, 0.7966353285204915, 0.6229274662010523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 253}], {
             RGBColor[
             0.7766889623535784, 0.8255911506947033, 0.9783458229842414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 292}], {
             RGBColor[
             0.7307007295200527, 0.789548230523077, 0.9737930779981592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 79}], {
             RGBColor[
             0.972034593821699, 0.9278653432605065, 0.5763873653590638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 93}], {
             RGBColor[
             0.9484060472600323, 0.8328278749772127, 0.27904400778535665`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 160}], {
             RGBColor[
             0.970646561001197, 0.9272913560184125, 0.5993906613085737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 164}], {
             RGBColor[
             0.6176164617913205, 0.6382691573714989, 0.6134322333579563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 168}], {
             RGBColor[
             0.9700319019066606, 0.9268386945418181, 0.6006886276524583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 246}], {
             RGBColor[
             0.9662100351246536, 0.8976806555937211, 0.32323279646906733`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 296}], {
             RGBColor[
             0.8151069217913204, 0.8057122395937211, 0.6278843111357341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.989503449487473, 0.9887686081975746, 0.7393850888123112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 89}], {
             RGBColor[
             0.9056288698430286, 0.5617854510064635, 0.37293270223453345`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 112}], {
             RGBColor[
             0.9816202970035224, 0.9487769948747762, 0.45844566733741404`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 115}], {
             RGBColor[
             0.9940757947855297, 0.9897370490123022, 0.5965650062405979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 134}], {
             RGBColor[
             0.9122320701717597, 0.9285731643792445, 0.7826724263370975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 146}], {
             RGBColor[
             0.8751545499196571, 0.8995227215415409, 0.7789994956762034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 159}], {
             RGBColor[
             0.659534783176362, 0.7227388076731303, 0.7617927155678668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 175}], {
             RGBColor[
             0.9942996158874731, 0.9902157797175747, 0.6209265519234222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 204}], {
             RGBColor[
             0.9876860133985841, 0.9875587292286858, 0.7489800929012002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 235}], {
             RGBColor[
             0.5864328698430287, 0.6474189510064635, 0.7575742022345335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 242}], {
             RGBColor[
             0.8415154507758134, 0.8732436016237475, 0.7756466646487996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 243}], {
             RGBColor[
             0.9712377887473069, 0.9115583217728533, 0.42954857002770064`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 253}], {
             RGBColor[
             0.9141720915654432, 0.9301200847780899, 0.7828574673095046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 280}], {
             RGBColor[
             0.980491538037473, 0.9821931012842413, 0.7611584630678667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 292}], {
             RGBColor[
             0.8681838587319175, 0.8940771646064636, 0.7783047223234223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 66}], {
             RGBColor[
             0.9139194423731637, 0.9334688870881829, 0.9663530145204376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 67}], {
             RGBColor[
             0.8568231564158374, 0.8886715433537267, 0.9862057516256457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 73}], {
             RGBColor[
             0.8832835473585741, 0.7727208087413888, 0.6137089257063713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 95}], {
             RGBColor[
             0.7528534112435215, 0.8072009804349426, 0.975912168679804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 96}], {
             RGBColor[
             0.9251858750119046, 0.9414832445299608, 0.9299006475404641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 109}], {
             RGBColor[
             0.9293389762010626, 0.9428145318678757, 0.8330056755805891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 138}], {
             RGBColor[
             0.9001741909732192, 0.9232177010998878, 0.9896201398048261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 140}], {
             RGBColor[
             0.8379665471482503, 0.8736996028282829, 0.9843902587572697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 154}], {
             RGBColor[
             0.9193959673951638, 0.9375532704826038, 0.957082686164677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 171}], {
             RGBColor[
             0.9292659786499629, 0.9426583974872577, 0.8250603426320365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 198}], {
             RGBColor[
             0.6408922723273136, 0.7153453157392103, 0.9673635855892255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[
             0.8978611366457605, 0.9213941148427691, 0.9901199908150132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 62}], {
             RGBColor[
             0.6063470428277717, 0.6686582569030453, 0.7895339749202653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 100}], {
             RGBColor[
             0.6046824729792046, 0.6686398279544048, 0.8658158417455364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 125}], {
             RGBColor[
             0.6014959055700886, 0.6673221004396883, 0.9186255102866958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 137}], {
             RGBColor[
             0.5441700671795993, 0.6229798342010051, 0.9616069565692746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 170}], {
             RGBColor[
             0.593136025109865, 0.6253302441924824, 0.6331237198461961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 192}], {
             RGBColor[
             0.6018010835947799, 0.6545595211145854, 0.666785835801099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 195}], {
             RGBColor[
             0.6060654725330515, 0.6680560065137623, 0.7588867859903995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 200}], {
             RGBColor[
             0.5099543625070256, 0.5958447803916402, 0.9583042582146237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 225}], {
             RGBColor[
             0.529168076809758, 0.6110176542982741, 0.9601760533353643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 228}], {
             RGBColor[
             0.5965330277553764, 0.6367891317699438, 0.6463204336538857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 255}], {
             RGBColor[
             0.5816910239326616, 0.6526531917145421, 0.9566971584738302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.8976417004307319, 0.7031433079832123, 0.5989491810368843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 85}], {
             RGBColor[
             0.9555898171594923, 0.9663995388693255, 0.9600590349049535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 100}], {
             RGBColor[
             0.9635122003710775, 0.9711476904828075, 0.8946857159934238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 121}], {
             RGBColor[
             0.9653365462952948, 0.9715078643014242, 0.8357944889790277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 125}], {
             RGBColor[
             0.9603256329619614, 0.9698299629680909, 0.9474953845345834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 127}], {
             RGBColor[
             0.8788485241268981, 0.9062301292456765, 0.988173261082065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.9495595418508502, 0.9197213931903129, 0.6526459200901386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 137}], {
             RGBColor[
             0.9029997945714722, 0.9254876967294078, 0.9904768308171621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 170}], {
             RGBColor[
             0.9519657525017379, 0.9278381067208852, 0.6619935940940835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 232}], {
             RGBColor[
             0.9562492546699504, 0.9668913462848954, 0.958942779208596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 240}], {
             RGBColor[
             0.9571703647369797, 0.9675783086647065, 0.9573835801290966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 256}], {
             RGBColor[
             0.9263964763603104, 0.9441435757018186, 0.9927084272126458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 299}], {
             RGBColor[
             0.951265076007229, 0.9254745603782418, 0.6592715982245696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 177}], {
             RGBColor[
             0.9682196234019205, 0.9726945034842249, 0.7544602232921807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 217}], {
             RGBColor[
             0.9797319794213604, 0.9812803997537705, 0.7349728074546009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 247}], {
             RGBColor[
             0.9517078289620484, 0.9597166566255144, 0.7594106664471876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 267}], {
             RGBColor[
             0.972615894990138, 0.9174758075476659, 0.4038067000262981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 273}], {
             RGBColor[
             0.9918037488888889, 0.9892910382222222, 0.6700937311111106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 285}], {
             RGBColor[
             0.992554887698208, 0.9896016534232626, 0.6576454171557666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 82}], {
             RGBColor[
             0.9269703869486758, 0.7226332410340339, 0.4238763900247596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 100}], {
             RGBColor[
             0.9928408868890215, 0.9906376235336292, 0.7196129249812991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 127}], {
             RGBColor[
             0.908177210644842, 0.9257200622964981, 0.8131004700699402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 130}], {
             RGBColor[
             0.9429478058996585, 0.9534451911300237, 0.8164169204854215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 137}], {
             RGBColor[
             0.9323284810894161, 0.9449776297802295, 0.8154040398050373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 170}], {
             RGBColor[
             0.9812944390196818, 0.9473280397717068, 0.48692080308195884`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 192}], {
             RGBColor[
             0.9899594975045968, 0.9765573166938096, 0.5205829190368617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 195}], {
             RGBColor[
             0.9942238864428684, 0.9900538020929865, 0.6126838692261622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 199}], {
             RGBColor[
             0.9919321963687944, 0.9832116931744681, 0.5282464816113474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 220}], {
             RGBColor[
             0.9073870911519067, 0.5737279678811293, 0.40518685934474175`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 225}], {
             RGBColor[
             0.9173264907195748, 0.9330154498774984, 0.813973136571127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 226}], {
             RGBColor[
             0.9579969725191828, 0.9654449880936866, 0.8178523234321413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 228}], {
             RGBColor[
             0.9846914416651933, 0.958786927349168, 0.5001175168896485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 255}], {
             RGBColor[
             0.9698494378424785, 0.9746509872937663, 0.8104942417095929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 131}], {
             RGBColor[
             0.8348829112669426, 0.834719177752676, 0.649653846814919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 139}], {
             RGBColor[
             0.7119963032716892, 0.7749361905789509, 0.9719287955925235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 143}], {
             RGBColor[
             0.8022658051363081, 0.8461206880862449, 0.9807494719737689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 172}], {
             RGBColor[
             0.7558714473598889, 0.809211786604098, 0.9763018599187021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 174}], {
             RGBColor[
             0.8276531265372933, 0.8659159481808087, 0.9676419330145059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 183}], {
             RGBColor[
             0.7639159705311125, 0.8155415709505909, 0.977091630513824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 283}], {
             RGBColor[
             0.845137670722504, 0.8783170696509994, 0.9094373632995052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 92}], {
             RGBColor[
             0.9676224597471963, 0.923423857653425, 0.6015592621902955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 145}], {
             RGBColor[
             0.7366510095865586, 0.7920844832987655, 0.9365397977237782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 153}], {
             RGBColor[
             0.8957379848754475, 0.9186384009876544, 0.9508413794126671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 211}], {
             RGBColor[
             0.9757917139942214, 0.9510115712135758, 0.6331343406598595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 219}], {
             RGBColor[
             0.9785023030070925, 0.9601550244305566, 0.64366446712308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 221}], {
             RGBColor[
             0.9866643651717437, 0.9867992768395062, 0.7509071417830375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 80}], {
             RGBColor[
             0.9665572041782557, 0.9745789981504712, 0.9414941094348399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 103}], {
             RGBColor[
             0.9403239031367319, 0.9544076900387433, 0.9648705976070857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 116}], {
             RGBColor[
             0.9524129291238923, 0.9640302209740518, 0.9654366776841228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 133}], {
             RGBColor[
             0.8951596437238908, 0.9183949355341066, 0.9605627902256786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 152}], {
             RGBColor[
             0.9098088690987467, 0.9300758302053869, 0.9619600464194502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 162}], {
             RGBColor[
             0.9643549281145096, 0.9267732750342986, 0.6191471114559746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[
             0.9789021995101268, 0.9829315897901618, 0.8823405949084928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 241}], {
             RGBColor[
             0.9779243503367319, 0.9725461224417059, 0.6718617544189374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 277}], {
             RGBColor[
             0.8872582725589542, 0.9122072505132259, 0.9597792555172774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 67}], {
             RGBColor[
             0.9068990600480562, 0.9278710247853439, 0.9656834041870996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 69}], {
             RGBColor[
             0.9779322916693579, 0.9817870517265668, 0.8651209882076125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 95}], {
             RGBColor[
             0.8029293148757402, 0.8464004618665598, 0.9553898212412579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 109}], {
             RGBColor[
             0.9794148798332816, 0.9820140132994929, 0.812483328142043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 110}], {
             RGBColor[
             0.9674345359656542, 0.9430403741364434, 0.6435905108248965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 138}], {
             RGBColor[
             0.950250094605438, 0.962417182531505, 0.96909779236628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 154}], {
             RGBColor[
             0.9694718710273826, 0.9767527519142211, 0.9365603387261309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 179}], {
             RGBColor[
             0.9402769821922601, 0.9544856738835714, 0.9688670201980367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 258}], {
             RGBColor[
             0.7664192007804691, 0.8167599064821224, 0.9525156113187235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 69}], {
             RGBColor[
             0.9208360057120316, 0.9369897079921105, 0.8849737253128205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 86}], {
             RGBColor[
             0.9214982143191368, 0.9354619606460988, 0.7430428132833268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 95}], {
             RGBColor[
             0.7458330289184139, 0.8016031181321035, 0.975242558346466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 109}], {
             RGBColor[
             0.9223185938759553, 0.9372166695650366, 0.8323360652472511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 110}], {
             RGBColor[
             0.9103382500083279, 0.898243030401987, 0.6634432479301046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 138}], {
             RGBColor[
             0.8931538086481117, 0.9176198387970487, 0.988950529471488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 154}], {
             RGBColor[
             0.9123755850700563, 0.9319554081797647, 0.9564130758313389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 179}], {
             RGBColor[
             0.8831806962349338, 0.9096883301491152, 0.9887197573032447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 258}], {
             RGBColor[
             0.7093229148231428, 0.7719625627476661, 0.9723683484239316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 215}], {
             RGBColor[
             0.991529547289424, 0.9906486706450897, 0.7815657194361993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 223}], {
             RGBColor[
             0.9707424577639506, 0.9214537759312593, 0.5657452859496297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 234}], {
             RGBColor[
             0.9710756873202988, 0.9773308073769535, 0.9061671436666849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 255}], {
             RGBColor[
             0.9665528327092398, 0.9739576698135205, 0.9138231567738011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 271}], {
             RGBColor[
             0.8986104199701601, 0.9201133544019147, 0.9158084317644006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 274}], {
             RGBColor[
             0.9762781659659683, 0.9812108074326169, 0.8973607043433096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 287}], {
             RGBColor[
             0.9700906016565279, 0.976596132101843, 0.9078346367439598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 109}], {
             RGBColor[
             0.9933518254972569, 0.9911326965062595, 0.731773649267764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 110}], {
             RGBColor[
             0.9813714816296297, 0.9521590573432099, 0.5628808319506173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 113}], {
             RGBColor[
             0.9922749396543209, 0.9910735032691358, 0.7776877719506173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 135}], {
             RGBColor[
             0.9724686610327449, 0.9777122849436548, 0.8743694897323072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 138}], {
             RGBColor[
             0.9641870402694134, 0.9715358657382716, 0.8883881134920009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 224}], {
             RGBColor[
             0.9500465195188702, 0.9602813788034088, 0.8877598501962503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 249}], {
             RGBColor[
             0.9803648350243261, 0.9836012385777778, 0.861003326816568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 254}], {
             RGBColor[
             0.9796286527493112, 0.9462800862942147, 0.5561102708561982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 258}], {
             RGBColor[
             0.7803561464444445, 0.8258785896888889, 0.8718059324444445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 288}], {
             RGBColor[
             0.5911678520000001, 0.6542142230222223, 0.8592847324444445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[
             0.7849510037592593, 0.7351205969999999, 0.6126916441481481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 251}], {
             RGBColor[
             0.8188778696453738, 0.8564920540527151, 0.8473891688695114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 300}], {
             RGBColor[
             0.45467933192386845`, 0.5592184091426613, 0.951757222441701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 85}], {
             RGBColor[
             0.973523675308642, 0.948687892345679, 0.6356315414814813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 98}], {
             RGBColor[
             0.9570390797770089, 0.9363937079892348, 0.663535661845444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 121}], {
             RGBColor[
             0.9832704044444445, 0.9537962177777777, 0.5113669955555555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 122}], {
             RGBColor[
             0.6356558690674055, 0.6742387990827947, 0.6424972854232072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 136}], {
             RGBColor[0.9674934, 0.9020097466666663, 0.3282184266666664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 160}], {
             RGBColor[
             0.9779712058765432, 0.9519991030913579, 0.6278455235061728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 181}], {
             RGBColor[
             0.9540394835827665, 0.9341566140589569, 0.6686131957823128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 207}], {
             RGBColor[
             0.9333894186189164, 0.917707939830303, 0.6672373794644628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 232}], {
             RGBColor[
             0.9741831128191001, 0.9491796997612488, 0.634515285785124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 240}], {
             RGBColor[
             0.9751042228861294, 0.94986666214106, 0.6329560867056244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 246}], {
             RGBColor[0.97353468, 0.9223884026666667, 0.35168765866666657`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 256}], {
             RGBColor[
             0.9443303345094601, 0.9264319291781722, 0.6682809337891737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 296}], {
             RGBColor[
             0.8224315666666666, 0.8304199866666666, 0.6563391733333332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 299}], {
             RGBColor[
             0.9691989341563787, 0.9077629138545953, 0.3348441048010974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 106}], {
             RGBColor[
             0.9712382969641427, 0.9754712318080891, 0.7910391567541448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 151}], {
             RGBColor[
             0.9619491006177473, 0.971142282060121, 0.9492944267768872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 194}], {
             RGBColor[
             0.9703772512793707, 0.9760520600061218, 0.873411122216535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 215}], {
             RGBColor[
             0.9717137297562572, 0.9764881344767933, 0.8427870821447333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 247}], {
             RGBColor[
             0.9291272924422149, 0.9460004536625514, 0.9818534688534996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 267}], {
             RGBColor[
             0.9500353584703045, 0.903759604584703, 0.6262495024326101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 286}], {
             RGBColor[
             0.8336265463335526, 0.8706671895156696, 0.9725278647600264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 87}], {
             RGBColor[
             0.7819989802607319, 0.6932420348096843, 0.6037079001021624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 95}], {
             RGBColor[
             0.7722934198611506, 0.6856523835197658, 0.6027457324271914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 96}], {
             RGBColor[
             0.9446258836295338, 0.819934647614784, 0.5567342112878515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 105}], {
             RGBColor[
             0.8567592113214351, 0.7516452955131061, 0.6111593012602128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 140}], {
             RGBColor[
             0.8574065557658794, 0.752151005913106, 0.6112238225046571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 149}], {
             RGBColor[
             0.9230398302720523, 0.8042239339377975, 0.6106550043565089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 171}], {
             RGBColor[
             0.948705987267592, 0.8211098005720808, 0.45189390637942406`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 245}], {
             RGBColor[
             0.9173011452633897, 0.7998455179275923, 0.6169535545624008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 289}], {
             RGBColor[
             0.946368976921435, 0.8206554614864394, 0.5278466444602126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 298}], {
             RGBColor[
             0.7626405507954652, 0.6778157495554467, 0.6019858232147164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 90}], {
             RGBColor[
             0.5712017236608511, 0.6627317790556231, 0.9594098526508235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 123}], {
             RGBColor[
             0.7112595341003571, 0.6712254455326598, 0.6059502968048974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 158}], {
             RGBColor[
             0.7272862407811667, 0.7345236022250117, 0.6201081569840781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 233}], {
             RGBColor[
             0.7398414332904806, 0.7945918347474747, 0.934570733486379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 257}], {
             RGBColor[
             0.7359350689941844, 0.7636981306289563, 0.65370722139749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 259}], {
             RGBColor[
             0.7412591339116092, 0.7955600257543525, 0.9281796113675357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 262}], {
             RGBColor[
             0.732588931076829, 0.752410821723171, 0.6407081074536882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 124}], {
             RGBColor[
             0.9076535025080504, 0.9286446458829009, 0.9717204159209665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 142}], {
             RGBColor[
             0.9257041685456384, 0.9389707235619948, 0.7560127702675841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 143}], {
             RGBColor[
             0.8801384855131802, 0.9072625538981991, 0.9884295885287903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 150}], {
             RGBColor[
             0.9264994111453094, 0.9406716670713307, 0.842570019573331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 167}], {
             RGBColor[
             0.9012764312434807, 0.9238886365752805, 0.9825151341653209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 174}], {
             RGBColor[
             0.9055258069141654, 0.9270578139927631, 0.9753220495695272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 185}], {
             RGBColor[
             0.709587934313682, 0.7721185207732925, 0.9724573460861972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 237}], {
             RGBColor[
             0.9212807045480871, 0.9246182511824416, 0.6904524171705531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 239}], {
             RGBColor[
             0.9156075312147538, 0.9054813054046639, 0.6684132100594421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 282}], {
             RGBColor[
             0.9212729115379862, 0.9387404595541589, 0.9459113497362097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 283}], {
             RGBColor[
             0.9230103510993761, 0.9394589354629537, 0.9171174798545265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 295}], {
             RGBColor[
             0.8893198318137749, 0.9145835102172872, 0.9893053135352257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 297}], {
             RGBColor[
             0.9263074901347089, 0.940822387186672, 0.8624753533167624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 99}], {
             RGBColor[
             0.702641962277092, 0.7571718972290808, 0.6834157294375857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[
             0.9901370124444444, 0.9783919684148148, 0.4161845851259258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 128}], {
             RGBColor[
             0.6979141207407409, 0.7530768785185186, 0.6831144755555555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[
             0.8869886897435899, 0.9057350414814815, 0.699109627122507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 201}], {
             RGBColor[
             0.9517303718038568, 0.8359981484478725, 0.33384882501793683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 209}], {
             RGBColor[
             0.9923143326596867, 0.9863425097551606, 0.5865265513410707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 218}], {
             RGBColor[
             0.9664429892205997, 0.9686295839608998, 0.7011597960719507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 229}], {
             RGBColor[
             0.991930041898341, 0.984167492689096, 0.44634584161103347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 261}], {
             RGBColor[
             0.9125924456790123, 0.9258523570370369, 0.7016309288888888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 284}], {
             RGBColor[
             0.9794153414222222, 0.9783043429925926, 0.6792009875259257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 91}], {
             RGBColor[
             0.95774999537875, 0.8593785977877935, 0.34207175402880435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 162}], {
             RGBColor[
             0.9763799104404783, 0.9319753637137191, 0.36364808365843393`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 191}], {
             RGBColor[
             0.9901185861143771, 0.9877993033586896, 0.6402420907984734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 203}], {
             RGBColor[
             0.9930258991273471, 0.9874914283601839, 0.4822903430523733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 206}], {
             RGBColor[
             0.9836836022513203, 0.9566124311800783, 0.39202154715708826`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 244}], {
             RGBColor[
             0.9835986827540406, 0.9835223815192458, 0.6775034619981264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 270}], {
             RGBColor[
             0.5886805463501098, 0.6490098802443045, 0.6805477126635866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 118}], {
             RGBColor[
             0.9708941160420672, 0.9375561478065328, 0.6206152012263313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 120}], {
             RGBColor[
             0.9232777646737345, 0.9006545699691815, 0.6530465539823719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 130}], {
             RGBColor[
             0.9280626462808643, 0.9044699046805558, 0.6535029402615742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 176}], {
             RGBColor[
             0.9796569187308022, 0.9417590959578732, 0.48440311439683614`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 193}], {
             RGBColor[
             0.6936990823563853, 0.7166083414593836, 0.6328278949747297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.97704703675, 0.9342364067250001, 0.36533250138750006`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 220}], {
             RGBColor[
             0.8925019315331124, 0.5247526814316613, 0.24227287912089446`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 226}], {
             RGBColor[
             0.9431118129003885, 0.9164697016442187, 0.654938343208294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 236}], {
             RGBColor[
             0.9090330178886289, 0.8892961955460893, 0.6516878773175729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 266}], {
             RGBColor[
             0.9795780731320095, 0.9423332187903949, 0.529812475331216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 93}], {
             RGBColor[
             0.9633741308324237, 0.8938558190502768, 0.5677194442062856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 103}], {
             RGBColor[
             0.9495900803859341, 0.9608514342267854, 0.9282741492633297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 116}], {
             RGBColor[
             0.9616791063730945, 0.9704739651620939, 0.9288402293403667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 119}], {
             RGBColor[
             0.6432993077644507, 0.7105589960829134, 0.9027178596465368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 164}], {
             RGBColor[
             0.632584545363712, 0.6992971014445633, 0.9021076697788852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 168}], {
             RGBColor[
             0.9849999854790521, 0.9878666386148822, 0.8893640640733873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 241}], {
             RGBColor[
             0.9871905275859341, 0.9789898666297481, 0.6352653060751813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[
             0.8965244498081564, 0.9186509947012682, 0.9231828071735213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 103}], {
             RGBColor[
             0.9384107844193017, 0.9529808892317282, 0.9681090085744207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 116}], {
             RGBColor[
             0.9504998104064621, 0.9626034201670367, 0.9686750886514577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 133}], {
             RGBColor[
             0.8932465250064605, 0.9169681347270915, 0.9638012011930136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 152}], {
             RGBColor[
             0.9078957503813164, 0.9286490293983718, 0.9651984573867852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 210}], {
             RGBColor[
             0.9769890807926965, 0.9815047889831467, 0.8855790058758277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 241}], {
             RGBColor[
             0.9760112316193017, 0.9711193216346908, 0.6751001653862723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 277}], {
             RGBColor[
             0.885345153841524, 0.9107804497062109, 0.9630176664846124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 180}], {
             RGBColor[
             0.7279174153175337, 0.7857008325228276, 0.9548062374084332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[
             0.7248188816568047, 0.7248925231032215, 0.6168394644707429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 285}], {
             RGBColor[
             0.7447578743648747, 0.7970183689788182, 0.8706781816002115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 100}], {
             RGBColor[
             0.9253058171001088, 0.7226148120853936, 0.5001582568500307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 107}], {
             RGBColor[
             0.8701098462342025, 0.6811939992373437, 0.5964564579837826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 127}], {
             RGBColor[
             0.8406421408559294, 0.6576972508482626, 0.5936458019386717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 137}], {
             RGBColor[
             0.8647934113005035, 0.6769548183319939, 0.5959493716737688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 192}], {
             RGBColor[
             0.9224244277156841, 0.708534505245574, 0.30112825090559314`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 199}], {
             RGBColor[
             0.9243971265798816, 0.7151888817262326, 0.30879181348007884`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 220}], {
             RGBColor[
             0.8398520213629941, 0.30570515643289375`, 0.18573219121347323`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 226}], {
             RGBColor[
             0.89046190273027, 0.6974221766454511, 0.5983976553008727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 228}], {
             RGBColor[
             0.9171563718762805, 0.6907641159009326, 0.28066284875838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 266}], {
             RGBColor[
             0.9269281629618911, 0.7232856937916274, 0.4732717874237948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 281}], {
             RGBColor[
             0.8735277502664442, 0.5186008769518625, 0.2161807935148508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 126}], {
             RGBColor[
             0.9632771156037694, 0.892473721192198, 0.5627603730002191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 155}], {
             RGBColor[
             0.988219446635985, 0.9893964526846373, 0.8448977865439403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 156}], {
             RGBColor[
             0.9394718445783719, 0.7943929591318253, 0.5434146548566976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 184}], {
             RGBColor[
             0.9903713214507999, 0.9884713830550077, 0.6773097517291251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[
             0.8729414884345404, 0.9001245294446406, 0.9161492786809422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 202}], {
             RGBColor[
             0.9146959836950418, 0.9329200115167156, 0.9202641248052694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 214}], {
             RGBColor[
             0.9867799832623159, 0.9888011975871038, 0.8687534198574363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 275}], {
             RGBColor[
             0.990753382487837, 0.9892885729809335, 0.7188947378031997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 293}], {
             RGBColor[
             0.9897716757440504, 0.9900383393112908, 0.8191733331831352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 89}], {
             RGBColor[
             0.9011935796444444, 0.5611101571911111, 0.5306703865777778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.8148409063111112, 0.8551948333511112, 0.9311677479644445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 112}], {
             RGBColor[
             0.9771850068049381, 0.9481017010594238, 0.6161833516806583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 134}], {
             RGBColor[
             0.9077967799731754, 0.9278978705638922, 0.9404101106803417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 144}], {
             RGBColor[
             0.9875229424956411, 0.9891084303232651, 0.856440662644375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 158}], {
             RGBColor[
             0.9709254234314266, 0.9269866565204998, 0.5918660522976991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 159}], {
             RGBColor[
             0.6550994929777778, 0.7220635138577778, 0.9195303999111111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 175}], {
             RGBColor[
             0.9898643256888888, 0.9895404859022223, 0.7786642362666665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 252}], {
             RGBColor[
             0.9641808257140043, 0.9004889687885256, 0.5851767948695598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 253}], {
             RGBColor[
             0.909736801366859, 0.9294447909627375, 0.9405951516527489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 280}], {
             RGBColor[
             0.9760562478388888, 0.981517807468889, 0.918896147411111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 292}], {
             RGBColor[
             0.8637485685333333, 0.8934018707911111, 0.9360424066666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[
             0.9850782797530865, 0.9862312167901235, 0.8023768837037036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 122}], {
             RGBColor[
             0.6374637443760474, 0.7066737980951404, 0.9335071735713552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 136}], {
             RGBColor[
             0.969301275308642, 0.9344447456790121, 0.6192283148148144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 165}], {
             RGBColor[
             0.9808330098523415, 0.9848699286923042, 0.9013890861595835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 181}], {
             RGBColor[
             0.9558473588914085, 0.9665916130713026, 0.9596230839304609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 207}], {
             RGBColor[
             0.9351972939275585, 0.9501429388426488, 0.9582472676126108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 232}], {
             RGBColor[
             0.9759909881277421, 0.9816146987735945, 0.9255251739332719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 240}], {
             RGBColor[
             0.9769120981947714, 0.9823016611534057, 0.9239659748537725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 246}], {
             RGBColor[
             0.975342555308642, 0.9548234016790124, 0.6426975468148146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 256}], {
             RGBColor[
             0.9461382098181021, 0.958866928190518, 0.9592908219373217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 296}], {
             RGBColor[
             0.8242394419753087, 0.8628549856790124, 0.9473490614814813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 299}], {
             RGBColor[
             0.9710068094650206, 0.9401979128669411, 0.6258539929492455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 107}], {
             RGBColor[
             0.9369890149280928, 0.9478139045650994, 0.7445203396742099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 109}], {
             RGBColor[
             0.9940140341043622, 0.9896049491602479, 0.5898427372382702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 110}], {
             RGBColor[
             0.9820336902367349, 0.9506313099971984, 0.4209499199211236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 141}], {
             RGBColor[
             0.9801321963404386, 0.9814061155873217, 0.720587157837173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 165}], {
             RGBColor[
             0.9897640618174712, 0.9882336031339467, 0.6883431139819416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 179}], {
             RGBColor[
             0.9548761364633407, 0.9620766097443263, 0.7462264292942637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 240}], {
             RGBColor[
             0.9858431501599013, 0.9856653355950483, 0.7109200026761306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 281}], {
             RGBColor[
             0.9404069189603346, 0.7852207822796182, 0.3642446752052782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 149}], {
             RGBColor[
             0.8023152545565809, 0.8462937569212696, 0.9738204150049126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 187}], {
             RGBColor[
             0.771183212102498, 0.8216673669684119, 0.9776969241087423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 227}], {
             RGBColor[
             0.692527761829417, 0.7597272180378526, 0.9699883533254214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 264}], {
             RGBColor[
             0.8163752311615191, 0.8567796644521338, 0.9500205420419496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 99}], {
             RGBColor[
             0.6819708354958574, 0.7476196375826611, 0.9589342046790672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[
             0.9711267386508642, 0.9765766776375309, 0.8706042251180247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 198}], {
             RGBColor[
             0.6837569206200511, 0.7491666547459892, 0.9590480124438078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 201}], {
             RGBColor[
             0.931059245022622, 0.8264458888014528, 0.6093673002594184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 222}], {
             RGBColor[
             0.9703398090714939, 0.9717876576315114, 0.6950980877820029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 258}], {
             RGBColor[
             0.7592079454409877, 0.811381764057284, 0.9647223856118519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 260}], {
             RGBColor[
             0.7906188320390672, 0.8368825368419206, 0.9671951656667215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 261}], {
             RGBColor[
             0.8919213188977777, 0.9163000973906172, 0.9771494041303703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 278}], {
             RGBColor[
             0.8273550280803332, 0.8657449534589934, 0.9707446810125385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 290}], {
             RGBColor[
             0.9624730536094376, 0.9715330453434294, 0.9484075110307818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 111}], {
             RGBColor[
             0.8209434794953099, 0.498539562235434, 0.5736736110503369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 112}], {
             RGBColor[
             0.8933104271604938, 0.5211185438683127, 0.24973096510288056`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 175}], {
             RGBColor[
             0.9059897460444444, 0.5625573287111112, 0.4122118496888887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 177}], {
             RGBColor[
             0.8801582811796982, 0.5455676279286694, 0.5727962188477366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 242}], {
             RGBColor[
             0.7532055809327847, 0.445585150617284, 0.5669319624142661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.8921816681944444, 0.5545346502777778, 0.5524437608333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 285}], {
             RGBColor[
             0.9044935454759858, 0.562474777867707, 0.47598141271132266`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 123}], {
             RGBColor[
             0.7846714637728396, 0.7307900187970371, 0.6117531669274074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 134}], {
             RGBColor[
             0.7375695269953979, 0.7949993895327812, 0.9744550854892308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 144}], {
             RGBColor[
             0.8172956895178634, 0.8562099492921541, 0.8904856374532639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 158}], {
             RGBColor[
             0.8006981704536491, 0.7940881754893888, 0.625911027106588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 252}], {
             RGBColor[
             0.7939535727362266, 0.7675904877574147, 0.6192217696784488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 253}], {
             RGBColor[
             0.7395095483890813, 0.7965463099316265, 0.9746401264616378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[
             0.8093469986666668, 0.8232627038933334, 0.6595100915200001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 102}], {
             RGBColor[
             0.9578055840312422, 0.8617840774300833, 0.5143325459712775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 162}], {
             RGBColor[
             0.9416096182716049, 0.8049439851851853, 0.2784621948148148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 191}], {
             RGBColor[
             0.9553482939455038, 0.8607679248301559, 0.5550562019548544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 203}], {
             RGBColor[
             0.9582556069584737, 0.86046004983165, 0.3971044542087542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 239}], {
             RGBColor[
             0.948105618271605, 0.8268565185185186, 0.3036979281481481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 153}], {
             RGBColor[
             0.8839740304273045, 0.8579152566657707, 0.632623038333184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 163}], {
             RGBColor[
             0.8493176234242084, 0.8308414081165033, 0.6291688115656523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 189}], {
             RGBColor[
             0.8411486317889456, 0.8244597297644001, 0.6283546028230165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 211}], {
             RGBColor[
             0.9640277595460784, 0.8902884268916922, 0.3149159995803764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 216}], {
             RGBColor[
             0.9572348818564622, 0.9156768190706133, 0.6191427220450954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 221}], {
             RGBColor[
             0.9749004107236008, 0.9260761325176226, 0.4326888007035544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 94}], {
             RGBColor[
             0.8307500112358527, 0.7906888352586217, 0.6216387409599475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 160}], {
             RGBColor[
             0.9619860980119217, 0.8932818318081828, 0.5907227401557955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 164}], {
             RGBColor[
             0.6089559988020453, 0.6042596331612693, 0.604764312205178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 168}], {
             RGBColor[
             0.9613714389173855, 0.8928291703315884, 0.5920207064996803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 277}], {
             RGBColor[
             0.8728959032464898, 0.8236135264179743, 0.6258394495998141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 124}], {
             RGBColor[
             0.8395389570604374, 0.875125909242256, 0.9650128990607381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 125}], {
             RGBColor[
             0.8532788102115851, 0.8852715296529079, 0.9372077620881027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 142}], {
             RGBColor[
             0.8575896230980253, 0.88545198692135, 0.7493052534073558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 150}], {
             RGBColor[
             0.8583848656976963, 0.8871529304306858, 0.8358625027131026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 200}], {
             RGBColor[
             0.7617372671485223, 0.8137942096048599, 0.9768865100160307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.853166159100474, 0.8710995145417967, 0.6837449003103248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 295}], {
             RGBColor[
             0.8212052863661619, 0.8610647735766424, 0.9825977966749972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 96}], {
             RGBColor[
             0.8141957475144811, 0.8544148193083376, 0.9189374542612844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 105}], {
             RGBColor[
             0.7263290752063825, 0.7861254672066598, 0.9733625442336455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 109}], {
             RGBColor[
             0.8183488487036392, 0.8557461066462526, 0.8220424823014094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 138}], {
             RGBColor[
             0.7891840634757956, 0.8361492758782647, 0.9786569465256463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 140}], {
             RGBColor[
             0.7269764196508268, 0.7866311776066598, 0.9734270654780899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 154}], {
             RGBColor[
             0.8084058398977403, 0.8504848452609808, 0.9461194928854972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 171}], {
             RGBColor[
             0.8182758511525394, 0.8555899722656346, 0.8140971493528568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 198}], {
             RGBColor[
             0.5299021448298902, 0.6282768905175873, 0.9564003923100459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 245}], {
             RGBColor[
             0.7868710091483371, 0.8343256896211461, 0.9791567975358335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 289}], {
             RGBColor[
             0.8159388408063823, 0.8551356331799931, 0.8900498874336453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 105}], {
             RGBColor[
             0.8986615389747656, 0.920407731301678, 0.9273510230943056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 138}], {
             RGBColor[
             0.9615165272441788, 0.9704315399732828, 0.9326454253863063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 140}], {
             RGBColor[0.89930888341921, 0.920913441701678, 0.92741554433875]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 171}], {
             RGBColor[
             0.9906083149209226, 0.9898722363606527, 0.7680856282135169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 196}], {
             RGBColor[
             0.9873385516722339, 0.9890321799791583, 0.8594964957763864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 198}], {
             RGBColor[
             0.7022346085982734, 0.7625591546126054, 0.910388871170706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 222}], {
             RGBColor[
             0.9888174970497161, 0.9851801574981276, 0.6464389465089011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 245}], {
             RGBColor[
             0.9592034729167203, 0.9686079537161643, 0.9331452763964936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 278}], {
             RGBColor[
             0.8458327160585555, 0.8791374533256096, 0.9220855397394367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 289}], {
             RGBColor[
             0.9882713045747655, 0.9894178972750113, 0.8440383662943054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 290}], {
             RGBColor[
             0.9809507415876599, 0.9849255452100456, 0.89974836975768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 298}], {
             RGBColor[
             0.8045428784487958, 0.8465781853440186, 0.9181775450488092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 134}], {
             RGBColor[
             0.896898200328731, 0.8777345133727807, 0.6477563241025639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 144}], {
             RGBColor[
             0.9766243628511966, 0.9389450731321538, 0.563786876066597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 159}], {
             RGBColor[
             0.6442009133333333, 0.6719001566666665, 0.6268766133333331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 235}], {
             RGBColor[
             0.5710989999999999, 0.5965802999999997, 0.6226580999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 252}], {
             RGBColor[
             0.9532822460695598, 0.8503256115974143, 0.2925230082917818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 292}], {
             RGBColor[
             0.8528499888888889, 0.8432385135999998, 0.6433886200888886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 122}], {
             RGBColor[
             0.6209791488444143, 0.6943796137386963, 0.9614112939353178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 160}], {
             RGBColor[
             0.963294485653552, 0.9721399177472596, 0.9467595320182836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 178}], {
             RGBColor[
             0.9668581818510829, 0.9736135977077535, 0.8876998634750737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 181}], {
             RGBColor[
             0.9393627633597753, 0.9542974287148585, 0.9875272042944234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 182}], {
             RGBColor[
             0.9082469612584902, 0.7389385860139261, 0.5995671499935921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 208}], {
             RGBColor[
             0.9586553778017002, 0.9686858289768893, 0.9548698403639624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 246}], {
             RGBColor[
             0.9588579597770088, 0.9425292173225682, 0.6706016671787772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 296}], {
             RGBColor[
             0.8077548464436755, 0.8505608013225683, 0.975253181845444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 104}], {
             RGBColor[
             0.7018638858326476, 0.7545472626809329, 0.6803930493783265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 123}], {
             RGBColor[
             0.6695490549388203, 0.6363054383846365, 0.6029589023857339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 157}], {
             RGBColor[
             0.598715563131793, 0.6818903357475996, 0.9633180913749078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 201}], {
             RGBColor[
             0.6634572451920597, 0.6121534427139905, 0.5980572892703375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[
             0.6781698626088029, 0.7447848782270178, 0.9653682603243514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 222}], {
             RGBColor[
             0.7027378092409315, 0.7574952115440491, 0.683788076792922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 229}], {
             RGBColor[
             0.703656915286544, 0.760322786955214, 0.710554305863434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 257}], {
             RGBColor[
             0.6942245898326476, 0.7287781234809327, 0.6507158269783264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 259}], {
             RGBColor[
             0.6995486547500724, 0.760640018606329, 0.925188216948372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 261}], {
             RGBColor[
             0.6243193190672154, 0.702007651303155, 0.9658393931412894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 121}], {
             RGBColor[
             0.9930006629646717, 0.9909793684036055, 0.737003564792174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 125}], {
             RGBColor[
             0.9879897496313383, 0.9893014670702722, 0.8487044603477296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 127}], {
             RGBColor[
             0.906512640796275, 0.9257016333478577, 0.8893823368952113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 136}], {
             RGBColor[
             0.9772236585202272, 0.9391928972924941, 0.5538549959032848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 137}], {
             RGBColor[
             0.9306639112408491, 0.944959200831589, 0.8916859066303084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 170}], {
             RGBColor[
             0.9796298691711148, 0.9473096108230663, 0.5632026699072299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 192}], {
             RGBColor[
             0.9882949276560298, 0.9765388877451693, 0.5968647858621328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 228}], {
             RGBColor[
             0.9830268718166262, 0.9587684984005277, 0.5763993837149195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 232}], {
             RGBColor[
             0.9839133713393273, 0.9863628503870765, 0.8601518550217424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 240}], {
             RGBColor[
             0.9848344814063567, 0.9870498127668876, 0.8585926559422429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 256}], {
             RGBColor[
             0.9540605930296874, 0.963615079804, 0.8939175030257922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 299}], {
             RGBColor[
             0.9789291926766059, 0.9449460644804231, 0.5604806740377158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 108}], {
             RGBColor[
             0.9540873669300411, 0.9620460657316874, 0.7946593907621401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 114}], {
             RGBColor[
             0.9542182141082203, 0.9631321442458525, 0.8675042279835118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 187}], {
             RGBColor[
             0.8975904907516784, 0.9211783091533152, 0.9900941763680273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 205}], {
             RGBColor[
             0.949379623308642, 0.9611312626041153, 0.9476921994041152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 207}], {
             RGBColor[
             0.9045759995407272, 0.926748364245118, 0.9907604604323641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 213}], {
             RGBColor[
             0.9543170741571949, 0.9625373862636057, 0.8196616048491379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 231}], {
             RGBColor[
             0.9546652250995886, 0.9632820459259259, 0.8575556863901233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 133}], {
             RGBColor[
             0.9072402147023516, 0.9260025038558168, 0.8773245543706111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 142}], {
             RGBColor[
             0.9930281364238551, 0.9897827948466733, 0.6487441691423824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 162}], {
             RGBColor[
             0.9764354990929704, 0.934380843356009, 0.535908875600907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[
             0.7769119021918985, 0.822930592057971, 0.8651887449609954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 210}], {
             RGBColor[
             0.9909827704885876, 0.9905391581118722, 0.7991023590534252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 237}], {
             RGBColor[
             0.9886046724263038, 0.9754303224671201, 0.5831838160453514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 239}], {
             RGBColor[
             0.9829314990929705, 0.9562933766893424, 0.5611446089342405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 295}], {
             RGBColor[
             0.9566437996919916, 0.9653955815019657, 0.8820367124100239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 116}], {
             RGBColor[
             0.9242665093649383, 0.9424321120553087, 0.9920515768237037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 119}], {
             RGBColor[
             0.6058867107562943, 0.6825171429761281, 0.9659292071298737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 152}], {
             RGBColor[
             0.8816624493397925, 0.9084777212866437, 0.9885749455590311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 164}], {
             RGBColor[
             0.5951719483555556, 0.6712552483377778, 0.9653190172622221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 168}], {
             RGBColor[
             0.9475873884708959, 0.959824785508097, 0.9525754115567243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 241}], {
             RGBColor[
             0.9497779305777778, 0.9509480135229629, 0.6984766535585183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 277}], {
             RGBColor[
             0.8591118528000001, 0.8906091415944828, 0.9863941546568582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 128}], {
             RGBColor[
             0.6971360442962964, 0.7504522439703705, 0.6800917954962963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 157}], {
             RGBColor[
             0.8862106132991454, 0.9031104069333334, 0.6960869470632478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 173}], {
             RGBColor[
             0.9775824084708012, 0.9360423412505204, 0.36741231942634656`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 201}], {
             RGBColor[
             0.9509522953594123, 0.8333735138997245, 0.3308261449586776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 209}], {
             RGBColor[
             0.9915362562152423, 0.9837178752070124, 0.5835038712818115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 218}], {
             RGBColor[
             0.9656649127761553, 0.9660049494127516, 0.6981371160126915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 229}], {
             RGBColor[
             0.9911519654538965, 0.9815428581409479, 0.44332316155177426`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 261}], {
             RGBColor[
             0.9118143692345679, 0.9232277224888888, 0.6986082488296296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 279}], {
             RGBColor[
             0.8851826230468263, 0.9023073331352064, 0.6959844866020117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 129}], {
             RGBColor[
             0.9000880414408738, 0.920997626730855, 0.9037101855608485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 140}], {
             RGBColor[
             0.8114422111111113, 0.8526240896000001, 0.9818406343111111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 149}], {
             RGBColor[
             0.8770754856172841, 0.9046970176246915, 0.9812718161629629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 171}], {
             RGBColor[
             0.9027416426128239, 0.9215828842589748, 0.822510718185878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 196}], {
             RGBColor[
             0.8994718793641352, 0.9207428278774804, 0.9139215857487475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 230}], {
             RGBColor[
             0.8991120365492777, 0.9205940236259984, 0.9198851124342877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 245}], {
             RGBColor[
             0.8713368006086215, 0.9003186016144864, 0.9875703663688546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 263}], {
             RGBColor[0.8421324555555557, 0.8770318496, 0.9847848298666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 289}], {
             RGBColor[
             0.9004046322666668, 0.9211285451733334, 0.8984634562666665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 298}], {
             RGBColor[
             0.716676206140697, 0.7782888332423408, 0.9726026350211703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 151}], {
             RGBColor[
             0.9849067861771124, 0.985665168683025, 0.7679019698295199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 167}], {
             RGBColor[
             0.9693826579571473, 0.974087299275002, 0.794180269564823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 194}], {
             RGBColor[
             0.9933349368387359, 0.9905749466290258, 0.6920186652691677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 215}], {
             RGBColor[
             0.9946714153156223, 0.9910110210996973, 0.6613946251973659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 283}], {
             RGBColor[
             0.9911165778130429, 0.9896575981626752, 0.7287826152540288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 286}], {
             RGBColor[
             0.8565842318929177, 0.8851900761385736, 0.791135407812659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 297}], {
             RGBColor[
             0.9944137168483755, 0.9910210498863935, 0.6741404887162646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 110}], {
             RGBColor[
             0.9258290506172839, 0.9105949743209878, 0.6649207743209877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 127}], {
             RGBColor[
             0.8513166699303687, 0.8842808204998078, 0.9856805380289633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 141}], {
             RGBColor[
             0.9239275567209877, 0.9413697799111111, 0.964558012237037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 165}], {
             RGBColor[
             0.9335594221980203, 0.9481972674577361, 0.9323139683818058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.8986714968438898, 0.9220402740681157, 0.990197283694128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 240}], {
             RGBColor[
             0.9296385105404503, 0.9456289999188378, 0.9548908570759949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 281}], {
             RGBColor[
             0.8842022793408836, 0.7451844466034077, 0.6082155296051424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 114}], {
             RGBColor[
             0.99421661919464, 0.9908444678145768, 0.670495803476516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 145}], {
             RGBColor[
             0.7440006884971194, 0.794890176961317, 0.775476479216461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 169}], {
             RGBColor[
             0.9937869056241426, 0.9891191443072702, 0.565121203840878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 187}], {
             RGBColor[
             0.937588895838098, 0.9488906327220394, 0.7930857518610315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 205}], {
             RGBColor[
             0.9893780283950617, 0.9888435861728395, 0.7506837748971193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 213}], {
             RGBColor[
             0.9943154792436146, 0.9902497098323301, 0.622653180342142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 219}], {
             RGBColor[
             0.9858519819176533, 0.9629607180931081, 0.4826011486157629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 221}], {
             RGBColor[
             0.9940140440823045, 0.9896049705020576, 0.5898438232757204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 264}], {
             RGBColor[
             0.9827809148971193, 0.9840029302057614, 0.7654093697942388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 110}], {
             RGBColor[
             0.9828540697935533, 0.9523860189161362, 0.510243171885048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 138}], {
             RGBColor[
             0.965669628433337, 0.9717628273111978, 0.8357504534264315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 154}], {
             RGBColor[
             0.9848914048552817, 0.9860983966939139, 0.8032129997862824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 179}], {
             RGBColor[
             0.955696516020159, 0.9638313186632642, 0.8355196812581882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 258}], {
             RGBColor[
             0.7818387346083682, 0.8261055512618152, 0.819168272378875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 138}], {
             RGBColor[
             0.9536892845657097, 0.9327891881481483, 0.6668576361092848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 141}], {
             RGBColor[
             0.9689722320296297, 0.94418718534321, 0.6409875924839508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 154}], {
             RGBColor[
             0.9729110609876543, 0.9471247575308643, 0.6343201824691358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 165}], {
             RGBColor[
             0.9786040975066623, 0.9510146728898351, 0.6087435486287194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 179}], {
             RGBColor[
             0.9437161721525318, 0.9248576795002147, 0.6666268639410415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 281}], {
             RGBColor[
             0.9292469546495257, 0.7480018520355066, 0.284645109852056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 190}], {
             RGBColor[
             0.9091172555034812, 0.9259069222903352, 0.7675753392344473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 212}], {
             RGBColor[
             0.8910975876238543, 0.8658404583412942, 0.6365096939992974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 242}], {
             RGBColor[
             0.7568300604280946, 0.809997712852718, 0.976387573464603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 250}], {
             RGBColor[
             0.8957383594953099, 0.8814948715687673, 0.6545382163836702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 280}], {
             RGBColor[
             0.8958061476897543, 0.9189472125132119, 0.9618993718836701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 115}], {
             RGBColor[
             0.9817573521029948, 0.9490701418741514, 0.47336326910894505`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 134}], {
             RGBColor[
             0.8999136274892249, 0.8879062572410937, 0.6594706892054447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 146}], {
             RGBColor[
             0.8628361072371222, 0.8588558144033901, 0.6557977585445506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 159}], {
             RGBColor[
             0.6472163404938271, 0.6820719005349793, 0.6385909784362139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 175}], {
             RGBColor[
             0.9819811732049382, 0.9495488725794239, 0.4977248147917693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 204}], {
             RGBColor[
             0.9753675707160493, 0.9468918220905349, 0.6257783557695473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 235}], {
             RGBColor[
             0.5741144271604938, 0.6067520438683127, 0.6343724651028806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 242}], {
             RGBColor[
             0.8291970080932785, 0.8325766944855967, 0.6524449275171467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 252}], {
             RGBColor[
             0.9562976732300537, 0.8604973554657271, 0.3042373733946626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 253}], {
             RGBColor[
             0.9018536488829083, 0.889453177639939, 0.6596557301778517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 280}], {
             RGBColor[
             0.9681730953549382, 0.9415261941460905, 0.6379567259362139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 292}], {
             RGBColor[
             0.8558654160493827, 0.8534102574683127, 0.6551029851917695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 135}], {
             RGBColor[
             0.9728743633537325, 0.9778800532794572, 0.8676459523495912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 224}], {
             RGBColor[
             0.9504522218398579, 0.9604491471392113, 0.8810363128135343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 249}], {
             RGBColor[
             0.9807705373453137, 0.9837690069135803, 0.8542797894338521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 254}], {
             RGBColor[
             0.9800343550702989, 0.9464478546300172, 0.5493867334734821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 258}], {
             RGBColor[
             0.7807618487654322, 0.8260463580246915, 0.8650823950617283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 260}], {
             RGBColor[
             0.8121727353635118, 0.8515471308093279, 0.8675551751165981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 278}], {
             RGBColor[
             0.8489089314047776, 0.8804095474264009, 0.8711046904624151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 288}], {
             RGBColor[
             0.5915735543209877, 0.6543819913580248, 0.8525611950617284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 290}], {
             RGBColor[
             0.984026956933882, 0.9861976393108368, 0.8487675204806584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 145}], {
             RGBColor[
             0.7441315356752985, 0.7959762554754821, 0.8483213164378327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 169}], {
             RGBColor[
             0.9939177528023218, 0.9902052228214355, 0.6379660410622497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 187}], {
             RGBColor[
             0.9377197430162771, 0.9499767112362046, 0.8659305890824032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 213}], {
             RGBColor[
             0.9944463264217938, 0.9913357883464953, 0.6954980175635137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 219}], {
             RGBColor[
             0.9859828290958325, 0.9640467966072732, 0.5554459858371346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 221}], {
             RGBColor[
             0.9941448912604837, 0.9906910490162228, 0.6626886604970921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 231}], {
             RGBColor[
             0.9947944773641874, 0.9920804480088155, 0.7333920991044993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 264}], {
             RGBColor[
             0.9829117620752984, 0.9850890087199266, 0.8382542070156105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 132}], {
             RGBColor[
             0.9690805021358881, 0.9027551684325976, 0.442620090603527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 146}], {
             RGBColor[
             0.8752916050191295, 0.8998158685409161, 0.7939170974477345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 159}], {
             RGBColor[
             0.6596718382758343, 0.7230319546725054, 0.7767103173393979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 204}], {
             RGBColor[
             0.9878230684980565, 0.9878518762280608, 0.7638976946727312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 242}], {
             RGBColor[
             0.8416525058752857, 0.8735367486231227, 0.7905642664203305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 243}], {
             RGBColor[
             0.9713748438467793, 0.9118514687722284, 0.44446617179923165`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 294}], {
             RGBColor[
             0.9871021509812821, 0.9670994035090704, 0.4941268034705151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 119}], {
             RGBColor[
             0.6179757367434547, 0.6921396739114367, 0.9664952872069108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 133}], {
             RGBColor[
             0.8791022499520971, 0.906419357550672, 0.9877437694422966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 152}], {
             RGBColor[
             0.893751475326953, 0.9181002522219524, 0.9891410256360682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 164}], {
             RGBColor[
             0.6072609743427161, 0.6808777792730865, 0.9658850973392592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 168}], {
             RGBColor[
             0.9596764144580563, 0.9694473164434055, 0.9531414916337613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 210}], {
             RGBColor[
             0.9628448057383331, 0.9709560118067273, 0.9095215741251107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 241}], {
             RGBColor[
             0.9618669565649383, 0.9605705444582714, 0.6990427336355552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 277}], {
             RGBColor[
             0.8712008787871606, 0.9002316725297914, 0.9869602347338953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 161}], {
             RGBColor[
             0.9355616309940558, 0.7726798085313824, 0.3003532303454961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 120}], {
             RGBColor[
             0.9294367432158015, 0.9455052381923809, 0.9561586575003697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 130}], {
             RGBColor[
             0.9342216248229314, 0.949320572903755, 0.956615043779572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 176}], {
             RGBColor[
             0.9858158972728692, 0.9866097641810725, 0.7875152179148339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[
             0.9832060152920672, 0.9790870749481995, 0.6684446049054978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 220}], {
             RGBColor[
             0.8986609100751796, 0.5696033496548606, 0.5453849826388922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 226}], {
             RGBColor[
             0.9492707914424556, 0.961320369867418, 0.9580504467262918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 228}], {
             RGBColor[
             0.9759652605884661, 0.9546623091228994, 0.6403156401837989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 266}], {
             RGBColor[
             0.9857370516740767, 0.9871838870135943, 0.8329245788492138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 152}], {
             RGBColor[
             0.575371676718309, 0.6581852831427717, 0.9630186559422382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 164}], {
             RGBColor[
             0.2888811757340721, 0.4209628101939059, 0.9397627276454293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 168}], {
             RGBColor[
             0.6412966158494122, 0.709532347364225, 0.9270191219399315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 241}], {
             RGBColor[
             0.6434871579562942, 0.7006555753790908, 0.6729203639417254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 130}], {
             RGBColor[
             0.8866052734545987, 0.9124189950664038, 0.9890463965356125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 176}], {
             RGBColor[
             0.9381995459045365, 0.9497081863437212, 0.8199465706708745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 287}], {
             RGBColor[
             0.9170446743447068, 0.936263253518469, 0.9771351977299427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 125}], {
             RGBColor[
             0.9898140955555556, 0.989661640888889, 0.7898132333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 127}], {
             RGBColor[
             0.9083369867204922, 0.9260618071664745, 0.8304911098808152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 136}], {
             RGBColor[
             0.9790480044444444, 0.9395530711111109, 0.4949637688888887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 137}], {
             RGBColor[
             0.9324882571650663, 0.9453193746502058, 0.8327946796159122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 160}], {
             RGBColor[
             0.9895258103209876, 0.9895424275358025, 0.7945908657283952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 181}], {
             RGBColor[
             0.9655940880272109, 0.9716999385034013, 0.8353585380045352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 232}], {
             RGBColor[
             0.9857377172635445, 0.9867230242056932, 0.8012606280073462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 240}], {
             RGBColor[
             0.9866588273305739, 0.9874099865855044, 0.7997014289278468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 246}], {
             RGBColor[
             0.9850892844444444, 0.9599317271111111, 0.5184330008888889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 256}], {
             RGBColor[
             0.9558849389539046, 0.9639752536226167, 0.835026276011396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 296}], {
             RGBColor[
             0.8339861711111112, 0.8679633111111111, 0.8230845155555556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 299}], {
             RGBColor[
             0.980753538600823, 0.9453062382990398, 0.5015894470233198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 136}], {
             RGBColor[
             0.6314334690674053, 0.6599956524161278, 0.6260940587565402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 160}], {
             RGBColor[
             0.6419112749439486, 0.7099850088408195, 0.9257211555960467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 181}], {
             RGBColor[
             0.6179795526501719, 0.6921425198084183, 0.9664888278721866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 207}], {
             RGBColor[
             0.5973294876863218, 0.6756938455797644, 0.9651130115543366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 231}], {
             RGBColor[
             0.6474187132451832, 0.7122275272605725, 0.8319082375120959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 232}], {
             RGBColor[
             0.6381231818865054, 0.7071656055107103, 0.9323909178749977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 240}], {
             RGBColor[
             0.6390442919535348, 0.7078525678905214, 0.9308317187954982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 246}], {
             RGBColor[
             0.6374747490674053, 0.680374308416128, 0.6495632907565404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 256}], {
             RGBColor[
             0.6082704035768656, 0.6844178349276335, 0.9661565658790476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 296}], {
             RGBColor[
             0.48637163573407205`, 0.5884058924161281, 0.9542148054232071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 299}], {
             RGBColor[
             0.633139003223784, 0.6657488196040567, 0.6327197368909712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 144}], {
             RGBColor[
             0.9573534999573694, 0.864703615769191, 0.537026081607338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 157}], {
             RGBColor[
             0.8538957824053183, 0.7848685826370371, 0.6186528000706553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 229}], {
             RGBColor[
             0.9588371345600692, 0.8633010338446515, 0.36588901455918166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 257}], {
             RGBColor[
             0.9494048091061729, 0.8317563703703703, 0.30605053567407403`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 259}], {
             RGBColor[
             0.9547288740235977, 0.8636182654957665, 0.5805229256441198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 261}], {
             RGBColor[
             0.8794995383407407, 0.8049858981925925, 0.6211741018370369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 125}], {
             RGBColor[
             0.9710633290710744, 0.9778381191449037, 0.9293192658615244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 142}], {
             RGBColor[
             0.9753741419575146, 0.9780185764133456, 0.7414167571807774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 150}], {
             RGBColor[
             0.9761693845571855, 0.9797195199226814, 0.8279740064865242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 200}], {
             RGBColor[
             0.8795217860080115, 0.9063607990968556, 0.9689980137894523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 237}], {
             RGBColor[
             0.9709506779599633, 0.9636661040337924, 0.6758564040837464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 282}], {
             RGBColor[
             0.9709428849498623, 0.9777883124055097, 0.9313153366494029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 295}], {
             RGBColor[
             0.9389898052256511, 0.953631363068638, 0.9747093004484189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 136}], {
             RGBColor[
             0.974037091111111, 0.9378751697777776, 0.6066646644444443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 150}], {
             RGBColor[
             0.9899092377083334, 0.9898651403333334, 0.800168869513889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[
             0.9764433017619987, 0.9459918833083498, 0.6160123384483893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 192}], {
             RGBColor[
             0.9851083602469135, 0.9752211602304527, 0.6496744544032922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 195}], {
             RGBColor[
             0.9893727491851851, 0.9887176456296296, 0.7417754045925928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 200}], {
             RGBColor[
             0.8932616391591592, 0.9165064195075077, 0.941192876816817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 256}], {
             RGBColor[
             0.9508740256205712, 0.9622973522892834, 0.9467271715669516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 299}], {
             RGBColor[
             0.9757426252674897, 0.9436283369657066, 0.6132903425788754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 155}], {
             RGBColor[
             0.9639321134122287, 0.8927445796186718, 0.5519053642340566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 163}], {
             RGBColor[
             0.8408832619646882, 0.7974019755138488, 0.6223823263554138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 184}], {
             RGBColor[
             0.9660839882270436, 0.8918195099890422, 0.38431732941924124`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 189}], {
             RGBColor[
             0.8327142703294255, 0.7910202971617457, 0.6215681176127779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 197}], {
             RGBColor[
             0.8486541552107841, 0.8034726563786752, 0.6231568563710583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 214}], {
             RGBColor[
             0.9624926500385595, 0.8921493245211383, 0.5757609975475524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 216}], {
             RGBColor[
             0.9488005203969421, 0.8822373864679588, 0.6123562368348567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 275}], {
             RGBColor[
             0.9664660492640806, 0.8926366999149681, 0.4259023154933158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 293}], {
             RGBColor[
             0.9654843425202941, 0.8933864662453253, 0.5261809108732514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 136}], {
             RGBColor[
             0.8925599822760477, 0.8742753360553631, 0.647342540991926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 137}], {
             RGBColor[
             0.8460002349966697, 0.880041639594458, 0.9851734517189494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 141}], {
             RGBColor[
             0.8944598513427144, 0.91787303152203, 0.9617473561919262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 165}], {
             RGBColor[
             0.9040917168197471, 0.9247005190686551, 0.9295033123366949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 170}], {
             RGBColor[
             0.8949661929269354, 0.8823920495859354, 0.656690214995871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 192}], {
             RGBColor[
             0.9036312514118503, 0.9116213265080382, 0.6903523309507739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 228}], {
             RGBColor[
             0.8983631955724467, 0.8938509371633967, 0.6698869288035606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 232}], {
             RGBColor[
             0.8992496950951478, 0.9214452891499456, 0.9536394001103834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 240}], {
             RGBColor[
             0.9001708051621772, 0.9221322515297568, 0.952080201030884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 256}], {
             RGBColor[
             0.8693969167855079, 0.8986975185668689, 0.9874050481144333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 281}], {
             RGBColor[
             0.8547345739626104, 0.7216876982143267, 0.6054048735600315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 299}], {
             RGBColor[
             0.8942655164324265, 0.8800285032432921, 0.6539682191263569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 173}], {
             RGBColor[
             0.6853595167670976, 0.7107272513542242, 0.6343422098559762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 209}], {
             RGBColor[
             0.6993133645115387, 0.7584027853107163, 0.8504337617114411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 218}], {
             RGBColor[
             0.6734420210724517, 0.7406898595164555, 0.9650670064423212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 276}], {
             RGBColor[
             0.6958192871625346, 0.7569578945332109, 0.9083396657667585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 279}], {
             RGBColor[
             0.5929597313431227, 0.6769922432389102, 0.9629143770316415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 161}], {
             RGBColor[
             0.9835496601075404, 0.9631884741975215, 0.5967918644941818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 230}], {
             RGBColor[
             0.9884052113234848, 0.9894732711568532, 0.8418191849284695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 263}], {
             RGBColor[
             0.9314256303297628, 0.9459110971308549, 0.9067189023608484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 265}], {
             RGBColor[
             0.9921877258349087, 0.9907891874984247, 0.7610879315900019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 269}], {
             RGBColor[
             0.9735022271158049, 0.929296123466943, 0.5577594846198015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 289}], {
             RGBColor[
             0.9896978070408737, 0.9900077927041883, 0.8203975287608483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 298}], {
             RGBColor[
             0.8059693809149041, 0.8471680807731956, 0.8945367075153521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 176}], {
             RGBColor[
             0.9429844275116663, 0.9535235210550954, 0.8204029569500768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 199}], {
             RGBColor[
             0.9403745455308643, 0.9460008318222224, 0.7013323439407407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 220}], {
             RGBColor[
             0.8558294403139768, 0.5365171065288835, 0.5782727216741351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 226}], {
             RGBColor[
             0.9064393216812527, 0.9282341267414409, 0.9909381857615347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 228}], {
             RGBColor[
             0.9331337908272632, 0.9215760659969223, 0.6732033792190418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 266}], {
             RGBColor[
             0.9429055819128738, 0.9540976438876172, 0.8658123178844567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 139}], {
             RGBColor[
             0.8446410461962015, 0.8423423069239855, 0.650626446509712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 143}], {
             RGBColor[
             0.9349105480608204, 0.9135268044312794, 0.6594471228909574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 172}], {
             RGBColor[
             0.8885161902844012, 0.8766179029491326, 0.6549995108358906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 174}], {
             RGBColor[
             0.9602978694618056, 0.9333220645258433, 0.6463395839316943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 183}], {
             RGBColor[
             0.8965607134556248, 0.8829476872956254, 0.6557892814310124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 283}], {
             RGBColor[
             0.9777824136470163, 0.945723185996034, 0.5881350142166937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 188}], {
             RGBColor[
             0.9693106381015768, 0.9032474059928902, 0.4676689702341864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 212}], {
             RGBColor[
             0.9507876853219317, 0.8421044665326192, 0.2818238695464229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 243}], {
             RGBColor[
             0.9462424960976654, 0.8245764411931488, 0.27560365439062967`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 294}], {
             RGBColor[
             0.9619698032321684, 0.8798243759299907, 0.32526428606191315`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 162}], {
             RGBColor[
             0.8910442489427144, 0.8691624116109189, 0.6414542032141484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 164}], {
             RGBColor[
             0.5500076889427146, 0.6352424938331411, 0.961011209880815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 210}], {
             RGBColor[
             0.9055915203383316, 0.925320726366782, 0.9046476866666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 239}], {
             RGBColor[
             0.8975402489427144, 0.8910749449442522, 0.6666899365474817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 241}], {
             RGBColor[
             0.9046136711649366, 0.9149352590183262, 0.6941688461771112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 277}], {
             RGBColor[
             0.8139475933871589, 0.8545963870898461, 0.9820863472754511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 144}], {
             RGBColor[
             0.9102515631799277, 0.928912986504935, 0.8997280001691614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 159}], {
             RGBColor[
             0.5778281136620644, 0.6618680700394477, 0.9628177374358975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 175}], {
             RGBColor[
             0.9125929463731755, 0.9293450420838922, 0.8219515737914528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 204}], {
             RGBColor[
             0.9059793438842866, 0.9266879915950033, 0.9500051147692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 235}], {
             RGBColor[
             0.5047262003287311, 0.5865482133727811, 0.958599224102564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 252}], {
             RGBColor[
             0.886909446398291, 0.8402935249701955, 0.6284641323943462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 253}], {
             RGBColor[
             0.8324654220511456, 0.8692493471444074, 0.9838824891775353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 292}], {
             RGBColor[
             0.78647718921762, 0.833206426972781, 0.979329744191453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 224}], {
             RGBColor[
             0.9306459432182816, 0.9470879288137302, 0.9777180305952242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 249}], {
             RGBColor[
             0.9609642587237376, 0.9704077885880993, 0.950961507215542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 254}], {
             RGBColor[
             0.9602280764487228, 0.9330866363045361, 0.646068451255172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 258}], {
             RGBColor[
             0.760955570143856, 0.8126851396992104, 0.9617641128434182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 260}], {
             RGBColor[
             0.7923664567419355, 0.8381859124838469, 0.964236892898288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 288}], {
             RGBColor[
             0.5717672756994115, 0.6410207730325437, 0.9492429128434183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 137}], {
             RGBColor[
             0.9167112527206218, 0.8935329035390944, 0.649646110727023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 165}], {
             RGBColor[
             0.9748027345436994, 0.9381917830132915, 0.5939759713447685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 181}], {
             RGBColor[
             0.9498170835827664, 0.91991346739229, 0.652209969115646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 232}], {
             RGBColor[
             0.9699607128191, 0.9349365530945819, 0.618112059118457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 240}], {
             RGBColor[
             0.9708818228861293, 0.935623515474393, 0.6165528600389576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 256}], {
             RGBColor[
             0.9401079345094601, 0.9121887825115054, 0.6518777071225068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 296}], {
             RGBColor[
             0.8182091666666667, 0.8161768399999998, 0.6399359466666664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 299}], {
             RGBColor[
             0.9649765341563785, 0.8935197671879285, 0.3184408781344305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 170}], {
             RGBColor[
             0.9191174633715095, 0.9016496170696666, 0.6589937847309681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 192}], {
             RGBColor[
             0.9277825218564244, 0.9308788939917696, 0.6926559006858709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 195}], {
             RGBColor[
             0.932046910794696, 0.9443753793909465, 0.7847568508751714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 220}], {
             RGBColor[
             0.8452101155037344, 0.5280495451790892, 0.577259840993751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 228}], {
             RGBColor[
             0.9225144660170208, 0.913108504647128, 0.6721904985386578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 232}], {
             RGBColor[
             0.923400965539722, 0.9407028566336768, 0.9559429698454806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 256}], {
             RGBColor[
             0.893548187230082, 0.9179550860506003, 0.9897086178495305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 266}], {
             RGBColor[
             0.9322862571026314, 0.9456300825378228, 0.8647994372040726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 299}], {
             RGBColor[
             0.9184167868770006, 0.8992860707270234, 0.656271788861454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 154}], {
             RGBColor[
             0.9557266196274381, 0.966501565925926, 0.9598274640105193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 171}], {
             RGBColor[
             0.9655966308822371, 0.9716066929305798, 0.8278051204778789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 245}], {
             RGBColor[
             0.9341917888780348, 0.9503424102860912, 0.9928647686608556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 258}], {
             RGBColor[
             0.7526739493805246, 0.8065087204938273, 0.975782736603112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 147}], {
             RGBColor[
             0.8570429946845017, 0.8868281166675873, 0.8748254839747277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 148}], {
             RGBColor[
             0.854205519100474, 0.87460551987513, 0.6877826176436581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 172}], {
             RGBColor[
             0.7656295822891478, 0.8168349157754073, 0.9772744596134951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 183}], {
             RGBColor[
             0.7736741054603715, 0.8231647001219002, 0.9780642302086169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 206}], {
             RGBColor[
             0.8483006775779828, 0.8546871028970449, 0.6648434233645348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 244}], {
             RGBColor[
             0.848215758080703, 0.8815970532362123, 0.950325338205573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 272}], {
             RGBColor[
             0.8517815196675818, 0.8842563923893079, 0.9442894339385542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 149}], {
             RGBColor[
             0.8777228300617286, 0.9052027280246915, 0.9813363374074073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 171}], {
             RGBColor[
             0.9033889870572682, 0.9220885946589749, 0.8225752394303225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 196}], {
             RGBColor[
             0.9001192238085796, 0.9212485382774804, 0.9139861069931919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 198}], {
             RGBColor[
             0.6150152807346191, 0.6947755129109275, 0.9648784823875115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 222}], {
             RGBColor[
             0.901598169186062, 0.9173965157964497, 0.7009285577257066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 230}], {
             RGBColor[
             0.8997593809937222, 0.9210997340259983, 0.9199496336787323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 245}], {
             RGBColor[
             0.8719841450530659, 0.9008243120144863, 0.9876348876132992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 263}], {
             RGBColor[0.8427798000000002, 0.87753756, 0.9848493511111112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 289}], {
             RGBColor[
             0.9010519767111111, 0.9216342555733334, 0.8985279775111109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 298}], {
             RGBColor[
             0.7173235505851415, 0.7787945436423407, 0.9726671562656147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 165}], {
             RGBColor[
             0.9767026036103661, 0.9817894784799585, 0.9083807865447687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 179}], {
             RGBColor[
             0.9418146782562354, 0.955632485090338, 0.9662641018570909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 232}], {
             RGBColor[
             0.9718605818857667, 0.9785342485612489, 0.9325168743184573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[
             0.9727816919527961, 0.9792212109410601, 0.9309576752389578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 281}], {
             RGBColor[
             0.9273454607532292, 0.77877665762563, 0.5842823477681053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[
             0.9942200505947736, 0.9900455976017754, 0.612266360833142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 185}], {
             RGBColor[
             0.777308573763146, 0.8214924513037372, 0.7421536873460082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 210}], {
             RGBColor[
             0.991379442059835, 0.9891010173576384, 0.676067301438438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 237}], {
             RGBColor[
             0.9890013439975512, 0.9739921817128863, 0.46014875843036407`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 239}], {
             RGBColor[
             0.983328170664218, 0.9548552359351086, 0.43810955131925305`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 282}], {
             RGBColor[
             0.9889935509874503, 0.9881143900846037, 0.7156076909960207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 283}], {
             RGBColor[
             0.9907309905488402, 0.9888328659933985, 0.6868138211143375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 295}], {
             RGBColor[
             0.9570404712632391, 0.963957440747732, 0.7590016547950366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 297}], {
             RGBColor[
             0.9940281295841731, 0.9901963177171167, 0.6321716945765734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 167}], {
             RGBColor[
             0.9234313876604865, 0.9415543974419296, 0.984628293686338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 172}], {
             RGBColor[
             0.8558990841537667, 0.8880194132827013, 0.9860951359947405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 174}], {
             RGBColor[
             0.9276807633311712, 0.9447235748594122, 0.9774352090905443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 185}], {
             RGBColor[
             0.7317428907306878, 0.7897842816399415, 0.9745705056072143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 237}], {
             RGBColor[
             0.9434356609650929, 0.9422840120490906, 0.6925655766915702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 239}], {
             RGBColor[
             0.9377624876317596, 0.9231470662713129, 0.6705263695804592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 283}], {
             RGBColor[
             0.945165307516382, 0.9571246963296027, 0.9192306393755436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 297}], {
             RGBColor[
             0.9484624465517147, 0.958488148053321, 0.8645885128377795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 158}], {
             RGBColor[
             0.9733802066381789, 0.9280017724615427, 0.5511839417865185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 235}], {
             RGBColor[
             0.5844523628511966, 0.647758773132154, 0.8746297760665973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 252}], {
             RGBColor[
             0.9666356089207565, 0.9015040847295686, 0.5444946843583793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 253}], {
             RGBColor[
             0.9121915845736113, 0.9304599069037803, 0.8999130411415684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 257}], {
             RGBColor[
             0.9820290348511966, 0.9571763008654873, 0.5847830061999306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 292}], {
             RGBColor[
             0.8662033517400856, 0.894416986732154, 0.8953602961554862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 169}], {
             RGBColor[
             0.7437018221048012, 0.7942509319681756, 0.7429467168021948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 219}], {
             RGBColor[
             0.7357668983983119, 0.7680925057540134, 0.6604266615770796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 221}], {
             RGBColor[
             0.7439289605629631, 0.794736758162963, 0.767669336237037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 264}], {
             RGBColor[
             0.7326958313777778, 0.7891347178666668, 0.9432348827555556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 159}], {
             RGBColor[
             0.5407505934099619, 0.6328176272017441, 0.9591448067750034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 204}], {
             RGBColor[
             0.8689018236321839, 0.8976375487572996, 0.9463321841083367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 235}], {
             RGBColor[
             0.4676486800766285, 0.5574977705350774, 0.95492629344167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 242}], {
             RGBColor[
             0.7227312610094132, 0.7833224211523614, 0.9729987558559361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 243}], {
             RGBColor[
             0.8524535989809068, 0.8216371413014671, 0.6269006612348371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 292}], {
             RGBColor[
             0.7493996689655174, 0.8041559841350774, 0.9756568135305589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 148}], {
             RGBColor[
             0.9894940755840276, 0.9788743167924572, 0.5897067063310693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 172}], {
             RGBColor[
             0.9009181387727013, 0.9211037126927344, 0.8791985483009064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 183}], {
             RGBColor[
             0.908962661943925, 0.9274334970392274, 0.8799883188960281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 206}], {
             RGBColor[
             0.9835892340615363, 0.9589558998143719, 0.566767512051946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 244}], {
             RGBColor[
             0.9835043145642566, 0.9858658501535394, 0.8522494268929841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 270}], {
             RGBColor[
             0.5885861781603258, 0.6513533488785981, 0.8552936775584443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 272}], {
             RGBColor[
             0.9870700761511353, 0.9885251893066349, 0.8462135226259655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 172}], {
             RGBColor[
             0.8980806631886736, 0.9088811159002771, 0.6921556819698367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 183}], {
             RGBColor[
             0.9061251863598974, 0.9152109002467701, 0.6929454525649585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 203}], {
             RGBColor[
             0.9900940553535353, 0.9776123002020201, 0.46999344161616136`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 206}], {
             RGBColor[
             0.9807517584775086, 0.9467333030219145, 0.3797246457208764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 244}], {
             RGBColor[
             0.9806668389802289, 0.9736432533610822, 0.6652065605619145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 270}], {
             RGBColor[
             0.5857487025762981, 0.6391307520861408, 0.6682508112273746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 272}], {
             RGBColor[
             0.9842326005671076, 0.9763025925141776, 0.6591706562948958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 171}], {
             RGBColor[
             0.9690222615634411, 0.9741615226836662, 0.8220064212821743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 227}], {
             RGBColor[
             0.8335686118407375, 0.8707091171659658, 0.976935457579768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 245}], {
             RGBColor[
             0.9376174195592387, 0.9528972400391778, 0.987066069465151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 289}], {
             RGBColor[
             0.966685251217284, 0.9737071835980248, 0.8979591593629627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 298}], {
             RGBColor[
             0.7829568250913144, 0.8308674716670321, 0.9720983381174665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 200}], {
             RGBColor[
             0.8983676946452704, 0.9183878202852853, 0.8398476174418168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 237}], {
             RGBColor[
             0.9897965865972222, 0.9756931252222221, 0.546706007736111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 282}], {
             RGBColor[
             0.9897887935871212, 0.9898153335939395, 0.8021649403017675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 295}], {
             RGBColor[
             0.9578357138629101, 0.9656583842570678, 0.8455589041007834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 167}], {
             RGBColor[
             0.9600934616107519, 0.9697583495270339, 0.9524355395875654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 194}], {
             RGBColor[
             0.9840457404923405, 0.9862459968810577, 0.85027393529191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 251}], {
             RGBColor[
             0.9853920372459175, 0.9868027251869103, 0.8279623139808276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 286}], {
             RGBColor[
             0.8472950355465223, 0.8808611263906054, 0.9493906778354013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 241}], {
             RGBColor[
             0.9192628965397924, 0.9266161536896065, 0.6955661023708828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 277}], {
             RGBColor[
             0.8285968187620147, 0.8662772817611264, 0.9834836034692227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 163}], {
             RGBColor[
             0.7774331485524595, 0.8260559514507326, 0.9784509287880239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 211}], {
             RGBColor[
             0.8921432846743296, 0.8855029702259215, 0.664198116802748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 216}], {
             RGBColor[
             0.8853504069847133, 0.9108913624048426, 0.9684248392674668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 219}], {
             RGBColor[
             0.8948538736872007, 0.8946464234429023, 0.6747282432659685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 221}], {
             RGBColor[
             0.9030159358518519, 0.9212906758518519, 0.781970917925926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 171}], {
             RGBColor[
             0.9848184073041818, 0.9859422623132958, 0.7952676668377298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 179}], {
             RGBColor[
             0.9457535072142602, 0.9585700572779924, 0.959596691842276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 245}], {
             RGBColor[
             0.9534135652999794, 0.9646779796688073, 0.9603273150207065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 156}], {
             RGBColor[
             0.9401268423868312, 0.7946638175582992, 0.532559646090535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 184}], {
             RGBColor[
             0.9910263192592592, 0.9887422414814815, 0.6664547429629625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 197}], {
             RGBColor[
             0.8735964862429998, 0.9003953878711144, 0.9052942699147797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 202}], {
             RGBColor[
             0.9153509815035011, 0.9331908699431894, 0.9094091160391069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 214}], {
             RGBColor[
             0.9874349810707752, 0.9890720560135776, 0.8578984110912736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 275}], {
             RGBColor[
             0.9914083802962963, 0.9895594314074074, 0.708039729037037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 293}], {
             RGBColor[
             0.9904266735525098, 0.9903091977377647, 0.8083183244169725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 178}], {
             RGBColor[
             0.9413666222386832, 0.7951764983879288, 0.5120132854979424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 202}], {
             RGBColor[
             0.8666033794458881, 0.7381873763903773, 0.6079259843518641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 208}], {
             RGBColor[
             0.9331638181893005, 0.7902487296570646, 0.5791832623868312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 214}], {
             RGBColor[
             0.938687379013162, 0.7940685624607655, 0.5564152794040309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 268}], {
             RGBColor[
             0.9431867378919773, 0.7956809123703134, 0.46380405976413286`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 201}], {
             RGBColor[
             0.8478039726585578, 0.7607165869663912, 0.6137511869552589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 218}], {
             RGBColor[
             0.8625165900753007, 0.8933480224794184, 0.9810621580092728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 229}], {
             RGBColor[
             0.888003642753042, 0.9088859312076146, 0.7262482035483555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 257}], {
             RGBColor[
             0.8785713172991454, 0.8773412677333334, 0.6664097246632479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 259}], {
             RGBColor[
             0.8838953822165704, 0.9092031628587296, 0.9408821146332935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 261}], {
             RGBColor[
             0.8086660465337133, 0.8505707955555556, 0.9815332908262109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 284}], {
             RGBColor[
             0.8754889422769232, 0.9030227815111113, 0.9591033494632478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 175}], {
             RGBColor[
             0.9757215898314267, 0.9284338280404998, 0.47340751540881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 177}], {
             RGBColor[
             0.9498901249666805, 0.9114441272580581, 0.6339918845676579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 217}], {
             RGBColor[
             0.9614024809861205, 0.9200300235276035, 0.6145044687300782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 252}], {
             RGBColor[
             0.9500380898565421, 0.8393823109268033, 0.2799200740117034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 253}], {
             RGBColor[
             0.8955940655093968, 0.868338133101015, 0.6353384307948924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 175}], {
             RGBColor[
             0.6598956593777778, 0.7235106853777777, 0.801071863022222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 204}], {
             RGBColor[
             0.6532820568888889, 0.720853634888889, 0.9291254040000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 235}], {
             RGBColor[
             0.2520289133333333, 0.3807138566666667, 0.9377195133333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 252}], {
             RGBColor[
             0.6342121594028932, 0.6344591682640812, 0.6075844216251154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 253}], {
             RGBColor[
             0.579768135055748, 0.663414990438293, 0.9630027784083045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 292}], {
             RGBColor[
             0.5337799022222223, 0.6273720702666666, 0.9584500334222222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 168}], {
             RGBColor[
             0.9836119526585501, 0.9872926513727882, 0.9123673600228972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[
             0.9602948894593096, 0.9699028238169816, 0.9518370659551525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 246}], {
             RGBColor[
             0.9797900858765431, 0.9581346124246913, 0.6349115288395062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 256}], {
             RGBColor[
             0.9505857403860033, 0.962178138936197, 0.9515048039620133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 296}], {
             RGBColor[
             0.8286869725432098, 0.8661661964246914, 0.9395630435061729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 299}], {
             RGBColor[
             0.9754543400329219, 0.9435091236126201, 0.6180679749739371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 186}], {
             RGBColor[
             0.9300119247213701, 0.92274537113533, 0.6782878873244704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 230}], {
             RGBColor[
             0.9825736552159443, 0.962784871092665, 0.6129667913676211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 265}], {
             RGBColor[
             0.9863561697273682, 0.9641007874342364, 0.5322355380291534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 269}], {
             RGBColor[
             0.9676706710082645, 0.9026077234027547, 0.32890709105895305`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 191}], {
             RGBColor[
             0.9739782090072321, 0.9333646907560815, 0.5766325315844838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 203}], {
             RGBColor[
             0.976885522020202, 0.9330568157575757, 0.4186807838383837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 210}], {
             RGBColor[
             0.9747868047289504, 0.9336990658669742, 0.5632320078969626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 239}], {
             RGBColor[
             0.9667355333333334, 0.8994532844444443, 0.3252742577777777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 184}], {
             RGBColor[
             0.8679774678117187, 0.8933996373766586, 0.7369317050843197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.7346077499141006, 0.7926004245493621, 0.9741824932778563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 197}], {
             RGBColor[
             0.7505476347954593, 0.8050527837662915, 0.9757712320361369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 211}], {
             RGBColor[
             0.8574868776712334, 0.8584291216766541, 0.6607438900352163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 216}], {
             RGBColor[
             0.8506939999816172, 0.8838175138555752, 0.9649706124999351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 168}], {
             RGBColor[
             0.6305818534486736, 0.6982704527258747, 0.9264089320722799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 210}], {
             RGBColor[
             0.6337502447289505, 0.6997791480891965, 0.8827890145636292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 241}], {
             RGBColor[
             0.6327723955555555, 0.6893936807407406, 0.6723101740740738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 277}], {
             RGBColor[
             0.5421063177777778, 0.6290548088122606, 0.9602276751724138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 179}], {
             RGBColor[
             0.9514465437332682, 0.9624599726369631, 0.9340200580018596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 207}], {
             RGBColor[
             0.9406987531626159, 0.9538899761769282, 0.9329949241425648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 232}], {
             RGBColor[
             0.9814924473627995, 0.9853617361078739, 0.9002728304632259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 240}], {
             RGBColor[
             0.9824135574298287, 0.9860486984876851, 0.8987136313837265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 281}], {
             RGBColor[
             0.936977326230262, 0.7856041451722551, 0.552038303912874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 217}], {
             RGBColor[
             0.7655843435003356, 0.8160151957798154, 0.9506545741506736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 233}], {
             RGBColor[
             0.7735197425974936, 0.8219334034334524, 0.9372220133627389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 262}], {
             RGBColor[
             0.766267240383842, 0.7797523904091486, 0.6433593873300483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 271}], {
             RGBColor[
             0.6872275030358019, 0.7544038172226264, 0.9702687587626951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 291}], {
             RGBColor[
             0.7792686601283578, 0.8230612439272795, 0.7404644054615044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 174}], {
             RGBColor[
             0.9488187090614716, 0.9613496575364935, 0.9715207547270748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 185}], {
             RGBColor[
             0.7528808364609881, 0.8064103643170228, 0.9686560512437449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 194}], {
             RGBColor[
             0.9685216122723754, 0.9746681274730347, 0.8765522350272132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 215}], {
             RGBColor[
             0.9698580907492619, 0.9751042019437062, 0.8459281949554115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 282}], {
             RGBColor[
             0.9645658136852924, 0.9730323030978894, 0.9421100548937574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 283}], {
             RGBColor[
             0.9663032532466824, 0.9737507790066842, 0.9133161850120743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 286}], {
             RGBColor[
             0.8317709073265572, 0.8692832569825825, 0.9756689775707046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 297}], {
             RGBColor[
             0.9696003922820151, 0.9751142307304024, 0.8586740584743102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 182}], {
             RGBColor[
             0.9285644282634884, 0.7540913196394547, 0.5651749779982058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 277}], {
             RGBColor[
             0.894521757893118, 0.9176243459825797, 0.947484069466916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 187}], {
             RGBColor[
             0.9372900294457798, 0.948251387728898, 0.7605559894467653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 213}], {
             RGBColor[
             0.9940166128512964, 0.9896104648391888, 0.5901234179278758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 219}], {
             RGBColor[
             0.9855531155253351, 0.9623214730999667, 0.4500713862014966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 221}], {
             RGBColor[
             0.9937151776899863, 0.9889657255089164, 0.5573140608614541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 264}], {
             RGBColor[
             0.982482048504801, 0.98336368521262, 0.7328796073799726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[
             0.9767484797866901, 0.9332293039832469, 0.36417266396279246`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 195}], {
             RGBColor[
             0.9810128687249617, 0.9467257893824239, 0.456273614152093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 200}], {
             RGBColor[
             0.8849017586989358, 0.8745145632603017, 0.6556910863763172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 225}], {
             RGBColor[
             0.9041154730016682, 0.8896874371669357, 0.6575628814970578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 228}], {
             RGBColor[
             0.9714804239472865, 0.9154589146386054, 0.3437072618155792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 255}], {
             RGBColor[
             0.9566384201245718, 0.9313229745832037, 0.6540839866355237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 198}], {
             RGBColor[
             0.7063147122363316, 0.7637343075699023, 0.8055485662622783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 245}], {
             RGBColor[
             0.9632835765547785, 0.9697831066734611, 0.828304971488066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 289}], {
             RGBColor[
             0.9923514082128237, 0.9905930502323081, 0.7391980613858777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 298}], {
             RGBColor[
             0.808622982086854, 0.8477533383013155, 0.8133372401403816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 174}], {
             RGBColor[
             0.8812864055547518, 0.9078146733772653, 0.9729875970354774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 183}], {
             RGBColor[
             0.8175492495485711, 0.8574402961470473, 0.9824372945347956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 203}], {
             RGBColor[
             0.901518118542209, 0.9198416961022975, 0.7594852835859984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 206}], {
             RGBColor[
             0.8921758216661824, 0.8889626989221919, 0.6692164876907134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 244}], {
             RGBColor[
             0.8920909021689025, 0.9158726492613594, 0.9546984025317515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 270}], {
             RGBColor[
             0.4971727657649718, 0.5813601479864181, 0.9577426531972117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 272}], {
             RGBColor[
             0.8956566637557815, 0.9185319884144549, 0.9486624982647329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 186}], {
             RGBColor[
             0.9240558131921713, 0.9026540083858504, 0.655149518750817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 196}], {
             RGBColor[
             0.9769773865016029, 0.9428423125946674, 0.5838648961084274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 209}], {
             RGBColor[
             0.9797597286860436, 0.9439928825908661, 0.5377542856414914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 230}], {
             RGBColor[
             0.9766175436867456, 0.9426935083431853, 0.5898284227939676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 263}], {
             RGBColor[
             0.9196379626930236, 0.8991313343171872, 0.6547281402263465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 276}], {
             RGBColor[
             0.9762656513370394, 0.942547991813361, 0.5956601896968088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 279}], {
             RGBColor[
             0.8734060955176275, 0.8625823405190601, 0.6502349009616917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 185}], {
             RGBColor[
             0.7571302121316729, 0.8095795417345055, 0.9614629666479511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 194}], {
             RGBColor[
             0.9727709879430602, 0.9778373048905173, 0.8693591504314194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 283}], {
             RGBColor[
             0.9705526289173672, 0.9769199564241667, 0.9061231004162805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 297}], {
             RGBColor[
             0.9738497679526998, 0.9782834081478851, 0.8514809738785164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 177}], {
             RGBColor[
             0.9688290272241427, 0.9739979566397805, 0.8207900685366253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 242}], {
             RGBColor[
             0.8418763269772291, 0.8740154793283952, 0.8149258121031548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 252}], {
             RGBColor[
             0.9689769921140043, 0.9019361403085256, 0.4667182579806708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 253}], {
             RGBColor[
             0.914532967766859, 0.9308919624827374, 0.8221366147638598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 280}], {
             RGBColor[
             0.9808524142388888, 0.982964978988889, 0.800437610522222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 199}], {
             RGBColor[
             0.9919688179808022, 0.9832900230995398, 0.5322325180760027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 226}], {
             RGBColor[
             0.9580335941311906, 0.9655233180187583, 0.8218383598967967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 287}], {
             RGBColor[
             0.9734238284017744, 0.9773677795071605, 0.8084917581444069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 217}], {
             RGBColor[
             0.9545099183788364, 0.9655941521268843, 0.9618870218578934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 247}], {
             RGBColor[
             0.9264857679195244, 0.9440304089986282, 0.9863248808504801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 273}], {
             RGBColor[
             0.9665816878463649, 0.9736047905953361, 0.8970079455144031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 285}], {
             RGBColor[
             0.967332826655684, 0.9739154057963765, 0.8845596315590591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 182}], {
             RGBColor[
             0.9327427835555555, 0.7560176610765431, 0.5048173431111111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 202}], {
             RGBColor[
             0.916590761355353, 0.9337035507728191, 0.8888627554465143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 208}], {
             RGBColor[
             0.9831512000987654, 0.9857649040395062, 0.8601200334814814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 268}], {
             RGBColor[
             0.9931741198014423, 0.9911970867527551, 0.7447408308587831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 281}], {
             RGBColor[
             0.9020894008761313, 0.7594471517826347, 0.6099216192251962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 190}], {
             RGBColor[
             0.975826862436816, 0.9785246014666177, 0.7540111967036549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 250}], {
             RGBColor[
             0.9624479664286447, 0.9341125507450497, 0.6409740738528775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 207}], {
             RGBColor[
             0.9157131022016829, 0.9356116605559266, 0.9912289219134423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 232}], {
             RGBColor[
             0.9565067964018665, 0.9670834204868725, 0.9585068282341034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 240}], {
             RGBColor[
             0.9574279064688959, 0.9677703828666836, 0.956947629154604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 246}], {
             RGBColor[
             0.9558583635827664, 0.9402921233922903, 0.675679201115646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 256}], {
             RGBColor[
             0.9266540180922266, 0.9443356499037958, 0.9922724762381533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 296}], {
             RGBColor[
             0.8047552502494331, 0.8483237073922902, 0.9803307157823129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 299}], {
             RGBColor[
             0.9515226177391451, 0.9256666345802189, 0.6588356472500769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 208}], {
             RGBColor[
             0.9245399795061728, 0.7510898923456789, 0.5719873199999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 268}], {
             RGBColor[
             0.9345628992088497, 0.7565220750589277, 0.45660811737730156`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 244}], {
             RGBColor[
             0.9001354253401264, 0.9222024336078524, 0.9554881731268734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 189}], {
             RGBColor[
             0.859808476176456, 0.8870179590245554, 0.7361174963416839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 197}], {
             RGBColor[
             0.8757483610578146, 0.8994703182414848, 0.7377062350999644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 202}], {
             RGBColor[
             0.917502856318316, 0.9322658003135598, 0.7418210812242916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 214}], {
             RGBColor[
             0.98958685588559, 0.988146986383948, 0.6903103762764584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 216}], {
             RGBColor[
             0.9758947262439726, 0.9782350483307685, 0.7269056155637628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 275}], {
             RGBColor[
             0.9935602551111111, 0.9886343617777777, 0.5404516942222218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 293}], {
             RGBColor[
             0.9925785483673246, 0.989384128108135, 0.6407302896021574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 237}], {
             RGBColor[
             0.7728851097655947, 0.807139978924184, 0.6765933342489772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 239}], {
             RGBColor[
             0.7672119364322614, 0.7880030331464063, 0.6545541271378661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 282}], {
             RGBColor[
             0.7728773167554936, 0.8212621872959013, 0.9320522668146337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 283}], {
             RGBColor[
             0.7746147563168837, 0.8219806632046961, 0.9032583969329506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 295}], {
             RGBColor[
             0.7409242370312825, 0.7971052379590297, 0.9754462306136495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 297}], {
             RGBColor[
             0.7779118953522164, 0.8233441149284144, 0.8486162703951865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 196}], {
             RGBColor[
             0.9352273187521718, 0.9491789723461437, 0.9173516810732179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 230}], {
             RGBColor[
             0.9348674759373145, 0.9490301680946616, 0.9233152077587582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 263}], {
             RGBColor[
             0.8778878949435924, 0.9054679940686634, 0.9882149251911371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 269}], {
             RGBColor[
             0.9199644917296346, 0.8888530204047513, 0.6392555074500902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 276}], {
             RGBColor[
             0.9345155835876082, 0.9488846515648373, 0.9291469746615992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 279}], {
             RGBColor[
             0.8316560277681964, 0.8689190002705364, 0.9837216859264822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 205}], {
             RGBColor[
             0.9328811522166989, 0.9479758295944674, 0.9461185605030066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 213}], {
             RGBColor[
             0.9378186030652518, 0.9493819532539579, 0.8180879659480292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 264}], {
             RGBColor[
             0.9262840387187565, 0.9431351736273892, 0.960844155400126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 212}], {
             RGBColor[
             0.976150169036734, 0.9298717316719914, 0.47573526658568427`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 243}], {
             RGBColor[
             0.9716049798124679, 0.912343706332521, 0.46951505142989103`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 294}], {
             RGBColor[
             0.9873322869469707, 0.967591641069363, 0.5191756831011745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 197}], {
             RGBColor[
             0.7423786431601966, 0.7986711054141883, 0.974957023293501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 211}], {
             RGBColor[
             0.8493178860359707, 0.8520474433245508, 0.6599296812925805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 216}], {
             RGBColor[
             0.8425250083463545, 0.8774358355034719, 0.9641564037572994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 275}], {
             RGBColor[
             0.860190537213493, 0.8878351489504812, 0.7777024824157585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 293}], {
             RGBColor[
             0.8592088304697065, 0.8885849152808385, 0.877981077795694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 212}], {
             RGBColor[
             0.9756468841367159, 0.9287952561607614, 0.4209558111330709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 250}], {
             RGBColor[
             0.9802876560081712, 0.9444496693882345, 0.4389843335174437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 203}], {
             RGBColor[
             0.9906241976941008, 0.9888807554025463, 0.6952747909784232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 195}], {
             RGBColor[
             0.9896779272098766, 0.9759550663045267, 0.48993573010699587`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 200}], {
             RGBColor[
             0.8935668171838507, 0.9037438401824047, 0.6893532023312201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[
             0.9127805314865831, 0.9189167140890385, 0.6912249974519606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 228}], {
             RGBColor[
             0.9801454824322013, 0.9446881915607082, 0.3773693777704821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 255}], {
             RGBColor[
             0.9653034786094867, 0.9605522515053064, 0.6877461025904266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 199}], {
             RGBColor[
             0.7060109816063853, 0.7581392686010502, 0.6806572986538962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 220}], {
             RGBColor[
             0.6214658763894977, 0.3486555433077114, 0.5575976763872906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 236}], {
             RGBColor[
             0.6379969627450142, 0.7131990574221394, 0.9670126745839691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 249}], {
             RGBColor[
             0.6957617299640446, 0.7584039727788281, 0.9428740182704642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 266}], {
             RGBColor[
             0.7085420179883948, 0.766236080666445, 0.8451372725976122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 283}], {
             RGBColor[
             0.9902555321282709, 0.9902384263607079, 0.8111545807164189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 286}], {
             RGBColor[
             0.8557231862081458, 0.8857709043366062, 0.8735073732750491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 297}], {
             RGBColor[
             0.9935526711636037, 0.9916018780844262, 0.7565124541786548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 200}], {
             RGBColor[
             0.8978312061221223, 0.9172403255815816, 0.7814541525205205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 225}], {
             RGBColor[
             0.9170449204248547, 0.9324131994882154, 0.7833259476412612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.9695678675477584, 0.9740487369044835, 0.7798470527797271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 230}], {
             RGBColor[
             0.987789049246746, 0.9892184723034787, 0.8520305851163685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 263}], {
             RGBColor[
             0.930809468253024, 0.9456562982774803, 0.9169303025487474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 279}], {
             RGBColor[
             0.8845776010776281, 0.9091073044793534, 0.9124370632840926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 289}], {
             RGBColor[
             0.9890816449641351, 0.9897529938508137, 0.8306089289487473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 298}], {
             RGBColor[
             0.8053532188381654, 0.8469132819198211, 0.9047481077032511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 214}], {
             RGBColor[
             0.8721570228693305, 0.899800132773581, 0.9291499032282755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 275}], {
             RGBColor[
             0.8761304220948517, 0.9002875081674107, 0.779291221174039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 293}], {
             RGBColor[
             0.8751487153510651, 0.9010372744977679, 0.8795698165539745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 222}], {
             RGBColor[
             0.7045238943651253, 0.7590422287073771, 0.6839018845576625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 245}], {
             RGBColor[
             0.6749098702321292, 0.7424700249254138, 0.970608214445255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 258}], {
             RGBColor[
             0.49339203073461907`, 0.5986363351331498, 0.9535261823875114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 278}], {
             RGBColor[
             0.5615391133739646, 0.6529995245348592, 0.9595484777881982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 290}], {
             RGBColor[
             0.6966571389030689, 0.7587876164192953, 0.9372113078064415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 220}], {
             RGBColor[
             0.9048138307831124, 0.5662836085733279, 0.290102282800061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 226}], {
             RGBColor[
             0.9554237121503885, 0.9580006287858853, 0.7027677468874606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 228}], {
             RGBColor[
             0.9821181812963989, 0.9513425680413667, 0.3850329403449677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 266}], {
             RGBColor[
             0.9918899723820095, 0.9838641459320615, 0.5776418790103826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 225}], {
             RGBColor[
             0.8209338103988288, 0.8602019733660935, 0.9827434198654854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 255}], {
             RGBColor[
             0.8734567575217325, 0.9018375107823614, 0.9792645250039513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 282}], {
             RGBColor[
             0.8931411950379472, 0.9164566127681136, 0.9431889476046955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 295}], {
             RGBColor[
             0.861188115313736, 0.892299663431242, 0.9865829114037115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 209}], {
             RGBColor[
             0.9531296155746545, 0.8413240552400701, 0.5011681111738225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 218}], {
             RGBColor[
             0.9272582721355676, 0.8236111294458094, 0.6158013559047025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 229}], {
             RGBColor[
             0.9527453248133088, 0.8391490381740057, 0.36098740144378527`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 257}], {
             RGBColor[
             0.9433129993594123, 0.8076043746997243, 0.30114892255867765`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 259}], {
             RGBColor[
             0.9486370642768371, 0.8394662698251206, 0.5756213125287233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 261}], {
             RGBColor[
             0.8734077285939801, 0.7808339025219466, 0.6162724887216406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 208}], {
             RGBColor[
             0.9083879573059703, 0.9287757820419549, 0.9560327323354031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 214}], {
             RGBColor[
             0.9139115181298318, 0.9325956148456558, 0.9332647493526027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 268}], {
             RGBColor[
             0.9184108770086472, 0.9342079647552036, 0.8406535297127047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 275}], {
             RGBColor[
             0.917884917355353, 0.9330829902394857, 0.7834060672983663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 206}], {
             RGBColor[
             0.984189213831044, 0.9576938832239349, 0.4470542473370381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 244}], {
             RGBColor[
             0.9841042943337642, 0.9846038335631024, 0.7325361621780762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 270}], {
             RGBColor[
             0.5891861579298334, 0.6500913322881612, 0.7355804128435364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 235}], {
             RGBColor[
             0.5801801435555555, 0.6455337782222222, 0.9249068906666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 253}], {
             RGBColor[
             0.90791936527797, 0.9282349119938486, 0.9501901557416379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 292}], {
             RGBColor[
             0.8619311324444444, 0.8921919918222222, 0.9456374107555556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 213}], {
             RGBColor[
             0.9896077356222154, 0.9893349067047581, 0.7756859889841171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 231}], {
             RGBColor[
             0.989955886564609, 0.9900795663670783, 0.8135800705251026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 244}], {
             RGBColor[
             0.9747619974577375, 0.9537248363829969, 0.6422673662827912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 270}], {
             RGBColor[
             0.5798438610538068, 0.6192123351080556, 0.6453116169482513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 272}], {
             RGBColor[
             0.9783277590446164, 0.9563841755360925, 0.6362314620157725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 231}], {
             RGBColor[
             0.9451522627966942, 0.9556966680080808, 0.8566483315533515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 232}], {
             RGBColor[
             0.9358567314380165, 0.9506347462582185, 0.9571310119162534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 240}], {
             RGBColor[
             0.9367778415050458, 0.9513217086380297, 0.9555718128367539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 268}], {
             RGBColor[
             0.9849713157520597, 0.9862693180218909, 0.8119108077476718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 218}], {
             RGBColor[
             0.9678422329913976, 0.9739554907530974, 0.8684790822278363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 276}], {
             RGBColor[
             0.9902194990814803, 0.990223525769853, 0.8117517415522737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 279}], {
             RGBColor[
             0.8873599432620685, 0.9102578744755521, 0.8663264528171566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 239}], {
             RGBColor[
             0.9812828047289504, 0.9556115992003076, 0.5884677412302959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 277}], {
             RGBColor[
             0.8976901491733948, 0.9191330413459015, 0.9038641519582653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 216}], {
             RGBColor[
             0.9654041361034872, 0.943264532630764, 0.6507178005146592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 221}], {
             RGBColor[
             0.9830696649706259, 0.9536638460777733, 0.4642638791731184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 243}], {
             RGBColor[
             0.9530820270328227, 0.85120076687225, 0.28366995074212753`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 250}], {
             RGBColor[
             0.9622679881285444, 0.8843832054391935, 0.30791868828229363`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 294}], {
             RGBColor[
             0.9688093341673256, 0.906448701609092, 0.333330582413411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 231}], {
             RGBColor[
             0.9948933374131619, 0.9914856900265687, 0.6855494759701253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 264}], {
             RGBColor[
             0.9830106221242729, 0.9844942507376798, 0.7904115838812366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 275}], {
             RGBColor[
             0.9899689169226271, 0.9889641763098739, 0.731895362350533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 293}], {
             RGBColor[
             0.9889872101788405, 0.989713942640231, 0.8321739577304685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 223}], {
             RGBColor[
             0.9743597585822635, 0.9228330290545712, 0.49732211710138463`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 234}], {
             RGBColor[
             0.9746929881386117, 0.9787100605002654, 0.8377439748184399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 271}], {
             RGBColor[
             0.902227720788473, 0.9214926075252265, 0.8473852629161556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 274}], {
             RGBColor[
             0.9798954667842812, 0.9825900605559288, 0.8289375354950645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 282}], {
             RGBColor[
             0.9898545710437674, 0.9899560249225846, 0.8093244105263003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 286}], {
             RGBColor[
             0.8570596646850323, 0.8862069788072777, 0.8428833332032475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 233}], {
             RGBColor[
             0.9739576734954345, 0.9800982560500666, 0.9289670452323792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 247}], {
             RGBColor[
             0.9379981239389643, 0.9526163052681736, 0.9668374650129004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 262}], {
             RGBColor[
             0.9667051712817828, 0.937917243025763, 0.6351044191996884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 273}], {
             RGBColor[
             0.9780940438658048, 0.9821906868648815, 0.8775205296768235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 229}], {
             RGBColor[
             0.9674579422300518, 0.9717804736870328, 0.7282983724977992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 284}], {
             RGBColor[
             0.9549432417539331, 0.9659173239905294, 0.9611535184126915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 221}], {
             RGBColor[
             0.985780253983497, 0.9628072992947541, 0.47479400563633894`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 264}], {
             RGBColor[
             0.9745471247983117, 0.9572052589984579, 0.6503595521548574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 226}], {
             RGBColor[
             0.8708786069335008, 0.5485169034925466, 0.579708124620855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 228}], {
             RGBColor[
             0.8975730760795113, 0.541858842748028, 0.26197331807836216`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 236}], {
             RGBColor[
             0.8367998119217412, 0.521343397394417, 0.5764576587301339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 266}], {
             RGBColor[
             0.9073448671651219, 0.5743804206387226, 0.45458225674377695`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 231}], {
             RGBColor[
             0.9945919022518519, 0.9908409506962963, 0.6527401189037036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 245}], {
             RGBColor[
             0.9614927586835721, 0.9650910278109359, 0.7066582897834501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 261}], {
             RGBColor[
             0.9126882926428519, 0.9261756713520051, 0.7020032762442252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 278}], {
             RGBColor[
             0.8481220018254074, 0.8756205274203813, 0.6955985531263933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 290}], {
             RGBColor[
             0.9832400273545118, 0.9814086193048173, 0.6732613831446366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 234}], {
             RGBColor[
             0.9539058986131383, 0.9095151657864351, 0.6219235413318701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 271}], {
             RGBColor[
             0.8814406312629997, 0.8522977128113962, 0.6315648294295859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 274}], {
             RGBColor[
             0.9591083772588078, 0.9133951658420986, 0.6131171020084949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 287}], {
             RGBColor[
             0.9529208129493675, 0.9087804905113246, 0.623591034409145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 291}], {
             RGBColor[
             0.9734817883555555, 0.9209551395160496, 0.40176047612839516`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 249}], {
             RGBColor[
             0.9385421172098629, 0.9529768824478533, 0.964351867679485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 254}], {
             RGBColor[
             0.9378059349348482, 0.9156557301642902, 0.6594588117191151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 258}], {
             RGBColor[
             0.7385334286299814, 0.7952542335589645, 0.9751544733073614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 260}], {
             RGBColor[
             0.769944315228061, 0.8207550063436009, 0.977627253362231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 288}], {
             RGBColor[
             0.5493451341855369, 0.6235898668922978, 0.9626332733073615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 234}], {
             RGBColor[
             0.8971933264355239, 0.9203835222524284, 0.9734803070175757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 255}], {
             RGBColor[
             0.8926704718244648, 0.9170103846889952, 0.9811363201246919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 287}], {
             RGBColor[
             0.896208240771753, 0.9196488469773177, 0.9751478000948506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 228}], {
             RGBColor[
             0.9481829574467874, 0.9335758629605853, 0.6746387821657617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 266}], {
             RGBColor[
             0.9579547485323979, 0.9660974408512801, 0.8672477208311765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 264}], {
             RGBColor[
             0.8476285884456756, 0.8811950246968299, 0.9531355846168051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 266}], {
             RGBColor[
             0.9846492176784084, 0.9594393801067616, 0.5495129142886837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 257}], {
             RGBColor[
             0.9835126694538965, 0.9557737189409479, 0.4136459391517743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 259}], {
             RGBColor[
             0.9888367343713214, 0.987635614066344, 0.6881183291218199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 261}], {
             RGBColor[
             0.9136073986884643, 0.92900324676317, 0.7287695053147372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 284}], {
             RGBColor[
             0.9804302944316743, 0.9814552327187257, 0.7063395639517742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 263}], {
             RGBColor[
             0.9304496254381667, 0.9455074940259983, 0.9228938292342878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 269}], {
             RGBColor[
             0.9725262222242088, 0.9288925203620864, 0.5739344114932409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 289}], {
             RGBColor[
             0.9887218021492776, 0.9896041895993317, 0.8365724556342875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 298}], {
             RGBColor[
             0.804993376023308, 0.846764477668339, 0.9107116343887913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 240}], {
             RGBColor[
             0.9775715357052295, 0.9827934685689755, 0.922849719157415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 256}], {
             RGBColor[
             0.9467976473285602, 0.9593587356060878, 0.9581745662409644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 296}], {
             RGBColor[
             0.8248988794857668, 0.8633467930945822, 0.9462328057851239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 299}], {
             RGBColor[
             0.9716662469754787, 0.9406897202825109, 0.624737737252888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 262}], {
             RGBColor[
             0.9746405703789409, 0.9438354506793999, 0.6216718584117538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 288}], {
             RGBColor[
             0.5861797696296296, 0.6517695874074074, 0.9248463200000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 291}], {
             RGBColor[
             0.9876419901234568, 0.9871443041975309, 0.71877687654321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 255}], {
             RGBColor[
             0.9497162735584275, 0.9620190596686963, 0.9700014121560416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 271}], {
             RGBColor[
             0.8817738608193478, 0.9081747442570904, 0.9719866871466412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 274}], {
             RGBColor[
             0.959441606815156, 0.9692721972877927, 0.9535389597255501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 287}], {
             RGBColor[
             0.9532540425057157, 0.9646575219570188, 0.9640128921262002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 252}], {
             RGBColor[
             0.5611102460695598, 0.5591393115974146, 0.603365908291782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 253}], {
             RGBColor[
             0.5066662217224145, 0.5880951337716263, 0.9587842650749712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 292}], {
             RGBColor[
             0.46067798888888895`, 0.5520522136, 0.9542315200888889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 249}], {
             RGBColor[
             0.9110956654962883, 0.9310918268655337, 0.9617340006133075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 266}], {
             RGBColor[
             0.9238759535206383, 0.9389239347531507, 0.8639972549404554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 239}], {
             RGBColor[
             0.9789047066666666, 0.9405027635555554, 0.37254919822222204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 282}], {
             RGBColor[
             0.984570086989899, 0.9737619177050504, 0.6500473378989897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 283}], {
             RGBColor[
             0.9863075265512888, 0.9744803936138452, 0.6212534680173065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 295}], {
             RGBColor[
             0.9526170072656878, 0.9496049683681788, 0.6934413016980056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 297}], {
             RGBColor[
             0.9896046655866217, 0.9758438453375635, 0.5666113414795424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 251}], {
             RGBColor[
             0.9612396187750033, 0.8708977743860482, 0.49506986338802983`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 300}], {
             RGBColor[
             0.597041081053498, 0.5736241294759945, 0.5994379169602195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 295}], {
             RGBColor[
             0.9469438339323545, 0.9304680225904011, 0.6714020945868946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 256}], {
             RGBColor[
             0.9477187573955895, 0.9600456979858989, 0.9566153671614649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 281}], {
             RGBColor[
             0.9330564145726921, 0.7830358776333566, 0.5746151926070631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 299}], {
             RGBColor[
             0.9725873570425081, 0.941376682662322, 0.6231785381733885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 277}], {
             RGBColor[0.8967123, 0.9087475739974455, 0.6933853114687099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 243}], {
             RGBColor[
             0.818814499837063, 0.7953580213836737, 0.6235478302074332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 280}], {
             RGBColor[
             0.8280682491272291, 0.8659928008950618, 0.9551577232475994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 294}], {
             RGBColor[
             0.8345418069715659, 0.8506059561205157, 0.6732084618787166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 294}], {
             RGBColor[
             0.9642641449430595, 0.8889206762696216, 0.3271103672576178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 270}], {
             RGBColor[
             0.579758941556527, 0.646122285447223, 0.9307935317892895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 272}], {
             RGBColor[
             0.9782428395473366, 0.9832941258752599, 0.9217133768568107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 289}], {
             RGBColor[
             0.9609465662086214, 0.9693287675878197, 0.9042577095688544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 298}], {
             RGBColor[
             0.7772181400826517, 0.826489055656827, 0.9783968883233582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 256}], {
             RGBColor[
             0.9461492145094601, 0.9325674385115055, 0.6753469391225071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 296}], {
             RGBColor[
             0.8242504466666667, 0.8365554959999999, 0.6634051786666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 299}], {
             RGBColor[
             0.9710178141563786, 0.9138984231879287, 0.3419101101344307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 267}], {
             RGBColor[
             0.930882039507742, 0.8888117130620692, 0.6356713575845975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 273}], {
             RGBColor[
             0.9500698934064928, 0.9606269437366255, 0.90195838866941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 285}], {
             RGBColor[
             0.9508210322158119, 0.9609375589376659, 0.8895100747140661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 270}], {
             RGBColor[
             0.5868576247985203, 0.6506385476416965, 0.8839402801162637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 254}], {
             RGBColor[
             0.968124250440304, 0.9389755899386591, 0.6327022883394329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 288}], {
             RGBColor[
             0.5796634496909928, 0.6469097266666668, 0.9358767499276792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 300}], {
             RGBColor[
             0.6309679469396124, 0.6949955865287096, 0.8341354416815827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 253}], {
             RGBColor[
             0.8888494677919745, 0.8418404453690409, 0.6286491733667532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 292}], {
             RGBColor[
             0.8428612349584488, 0.8057975251974145, 0.6240964283806709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 292}], {
             RGBColor[
             0.7884172106113034, 0.8347533473716263, 0.97951478516386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 258}], {
             RGBColor[
             0.7681155618604225, 0.7812529410497704, 0.6435048939673093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 260}], {
             RGBColor[
             0.7995264484585021, 0.8067537138344069, 0.645977674022179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 288}], {
             RGBColor[
             0.578927267415978, 0.6095885743831037, 0.6309836939673092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 287}], {
             RGBColor[
             0.9487311878946566, 0.9612843843935857, 0.9716689052333165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 296}], {
             RGBColor[
             0.7950461011761267, 0.8405990225115055, 0.9799984537891737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 299}], {
             RGBColor[
             0.9418134686658388, 0.9179419496994343, 0.6585033852569379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 259}], {
             RGBColor[
             0.979404408917425, 0.956090950592063, 0.6282798502367123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 261}], {
             RGBColor[
             0.9041750732345679, 0.8974585832888888, 0.6689310264296295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 260}], {
             RGBColor[
             0.6002539421536353, 0.6863522172290811, 0.9616733356104252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 278}], {
             RGBColor[
             0.6369901381949012, 0.715214633846154, 0.9652228509562422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 290}], {
             RGBColor[
             0.7721081637240056, 0.8210027257305901, 0.9428856809744854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 260}], {
             RGBColor[
             0.8081966512932823, 0.8499029178655884, 0.9334491779360263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 261}], {
             RGBColor[
             0.9094991381519928, 0.929320478414285, 0.9434034163996752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 261}], {
             RGBColor[
             0.7329673156104253, 0.7912705505624142, 0.9741003541289437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 278}], {
             RGBColor[
             0.6684010247929808, 0.7407154066307905, 0.9676956310111119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 290}], {
             RGBColor[
             0.8035190503220851, 0.8465034985152264, 0.9453584610293552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 278}], {
             RGBColor[
             0.7697035116516913, 0.8201329671794872, 0.9776498694747607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 290}], {
             RGBColor[
             0.9048215371807956, 0.9259210590639232, 0.955312699493004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 271}], {
             RGBColor[
             0.8883483308172493, 0.8763058644685738, 0.6547186038117099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 291}], {
             RGBColor[
             0.9803894879098052, 0.9449632911732271, 0.42491425051051923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 269}], {
             RGBColor[
             0.9155466412304867, 0.8853303463360881, 0.6388341289256197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 276}], {
             RGBColor[
             0.9300977330884603, 0.9453619774961739, 0.9287255961371288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 279}], {
             RGBColor[
             0.8272381772690485, 0.8653963262018731, 0.9833003074020118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 289}], {
             RGBColor[
             0.9317422211555556, 0.9460420155733333, 0.9014721730666664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 298}], {
             RGBColor[
             0.748013795029586, 0.8032023036423407, 0.9756113518211702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 269}], {
             RGBColor[
             0.9763087367356327, 0.9302084367036578, 0.49320315815477317`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 273}], {
             RGBColor[
             0.9709779594345824, 0.918386094658777, 0.5463544222485206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 285}], {
             RGBColor[
             0.9717290982439016, 0.9186967098598173, 0.5339061082931766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 286}], {
             RGBColor[
             0.8353812933990796, 0.8134784489151874, 0.6263457534911243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 298}], {
             RGBColor[
             0.7900903918156281, 0.7865873299784287, 0.6266519340801233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 272}], {
             RGBColor[
             0.5833247031434058, 0.6487816246003186, 0.9247576275222709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 274}], {
             RGBColor[
             0.8869763394650174, 0.9120547443127538, 0.9631802478232658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 291}], {
             RGBColor[
             0.9013497505617651, 0.9196147179867048, 0.7518236219431662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 285}], {
             RGBColor[
             0.9909169521426524, 0.9905119405343737, 0.8001931393779892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 287}], {
             RGBColor[
             0.9584565211513851, 0.9685375220126822, 0.955206452802825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 293}], {
             RGBColor[
             0.9929606094043617, 0.990201318034061, 0.6823152756762318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 279}], {
             RGBColor[
             0.8838658659130644, 0.908812983698047, 0.924232356872474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 290}], {
             RGBColor[
             0.840255246363351, 0.8753659151322994, 0.9489079763751722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 283}], {
             RGBColor[
             0.9862997335411879, 0.9886026019855625, 0.8767124005829632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 295}], {
             RGBColor[
             0.9526092142555869, 0.963727176739896, 0.9489002342636621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 297}], {
             RGBColor[
             0.9895968725765207, 0.9899660537092808, 0.8220702740451991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 295}], {
             RGBColor[
             0.9543466538169767, 0.9644456526486909, 0.920106364381979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 297}], {
             RGBColor[
             0.9913343121379107, 0.9906845296180756, 0.7932764041635159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 291}], {
             RGBColor[
             0.5919286871604938, 0.6528974279012347, 0.7280887120987656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 298}], {
             RGBColor[
             0.8062859717406969, 0.8472989992156741, 0.8892899782211701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 297}], {
             RGBColor[
             0.9576437928523096, 0.9658091043724092, 0.8654642378442149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 299}], {
             RGBColor[
             0.8199147008230453, 0.8219300071879287, 0.6465616248010975]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.03434177932816089], {
             RGBColor[
             0.9268002936414816, 0.9444694130986668, 0.9928802334435556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.03434177932816089], {
             RGBColor[
             0.8818203918474689, 0.9086036603550296, 0.9885900102564102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.03434177932816089], {
             RGBColor[
             0.6871819012345681, 0.7555509911111113, 0.9694555279012346]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.03434177932816089], {
             RGBColor[
             0.9568950231332718, 0.9673729593474916, 0.9578496616435824]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.03434177932816089], {
             RGBColor[
             0.9827162163226337, 0.9866303629497943, 0.914141116819753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.03434177932816089], {
             RGBColor[
             0.9925726578619074, 0.9865219911231297, 0.43295782839011965`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.03434177932816089], {
             RGBColor[
             0.9176775006931317, 0.9371951456332703, 0.9920100933081285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.03434177932816089], {
             RGBColor[
             0.9939423161481482, 0.9894515517037037, 0.5820366802962964]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.03434177932816089], {
             RGBColor[
             0.906102344642585, 0.9279654303978052, 0.9909060445907636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.03434177932816089], {
             RGBColor[
             0.8673724642722116, 0.8970832750850661, 0.987211954026465]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.03434177932816089], {
             RGBColor[
             0.7167157935720846, 0.7786230922710745, 0.9723991902795225]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.03434177932816089], {
             RGBColor[
             0.8876201833731252, 0.5825913243179266, 0.22793986513621056`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.03434177932816089], {
             RGBColor[
             0.8852743363452708, 0.571939380850933, 0.2259824328741964]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.03434177932816089], {
             RGBColor[
             0.829126913580247, 0.8665873111111112, 0.9835640592592593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.03434177932816089], {
             RGBColor[
             0.9749483960493828, 0.980837135308642, 0.9272900103703702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.03434177932816089], {
             RGBColor[
             0.994298660525037, 0.990213736293926, 0.620822566618074]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.03434177932816089], {
             RGBColor[
             0.6890921618655694, 0.757043301234568, 0.9696459248285322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.03434177932816089], {
             RGBColor[
             0.9935848620630549, 0.9886869935598409, 0.543130009084787]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.03434177932816089], {
             RGBColor[
             0.7432030096119766, 0.7993151067517359, 0.975039188437272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.03434177932816089], {
             RGBColor[
             0.8790594929356578, 0.906402194505356, 0.9883266732535182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.03434177932816089], {
             RGBColor[
             0.6999884444444445, 0.7655555600000001, 0.9707319644444444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.03434177932816089], {
             RGBColor[
             0.9678600365432098, 0.9755506483950618, 0.939288754074074]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.03434177932816089], {
             RGBColor[
             0.9930962118176118, 0.9876418200949566, 0.4899434454680638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.03434177932816089], {
             RGBColor[
             0.5439782676916616, 0.6406650895106072, 0.9572431083721907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.03434177932816089], {
             RGBColor[
             0.9951468481077369, 0.9920279237684015, 0.7131425505879544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.03434177932816089], {
             RGBColor[0.5894275200000002, 0.6775628400000001, 0.96082104]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.03434177932816089], {
             RGBColor[
             0.834254289908006, 0.8706757418159434, 0.9840531129906638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.03434177932816089], {
             RGBColor[
             0.9937830242424243, 0.9891108424242424, 0.5646987393939392]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.03434177932816089], {
             RGBColor[
             0.8202687255662249, 0.15679988327998912`, 0.16704266053345543`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.03434177932816089], {
             RGBColor[
             0.9372076711111111, 0.9526901644444445, 0.9911752133333332]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.03434177932816089], {
             RGBColor[
             0.9922863308641975, 0.9910782138271605, 0.7774989901234566]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.03434177932816089], {
             RGBColor[
             0.9851818512396694, 0.9881403289256199, 0.8952386033057846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.03434177932816089], {
             RGBColor[
             0.6318772600098767, 0.7120254512790125, 0.9641628390320988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.03434177932816089], {
             RGBColor[
             0.9262925848186385, 0.9440645798647206, 0.9928318077227958]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.03434177932816089], {
             RGBColor[
             0.9885287267204921, 0.9729668430244777, 0.4099366987876456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.03434177932816089], {
             RGBColor[
             0.8245679589906197, 0.862952124470868, 0.9831292221006738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.03434177932816089], {
             RGBColor[
             0.9259645513080947, 0.9438030148476454, 0.9928005195937211]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.03434177932816089], {
             RGBColor[
             0.9897605574317467, 0.9900337416034257, 0.8193575923912776]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.03434177932816089], {
             RGBColor[
             0.8776503335047444, 0.537320564583206, 0.2196207780226508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.03434177932816089], {
             RGBColor[
             0.9932045754109139, 0.9914579315450361, 0.7622813016436549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.03434177932816089], {
             RGBColor[
             0.9774787372270063, 0.9827242596158603, 0.9230068027753274]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.03434177932816089], {
             RGBColor[
             0.9952173616301423, 0.9922902703729335, 0.7289242250672816]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.03434177932816089], {
             RGBColor[
             0.9435003724444444, 0.8137048346666665, 0.2733972773333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.03434177932816089], {
             RGBColor[0.8635956977777778, 0.894071784, 0.9868517226666667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.03434177932816089], {
             RGBColor[
             0.9940923731138546, 0.9918250587105625, 0.7475681961591218]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.03434177932816089], {
             RGBColor[
             0.9898819093333333, 0.9900839237333333, 0.8173464773333331]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.03434177932816089], {
             RGBColor[0.9952611575, 0.99227242, 0.7255844225]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[48, 0.03434177932816089], {
             RGBColor[
             0.7683679780521265, 0.8189741713580249, 0.9775473973113855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.03434177932816089], {
             RGBColor[
             0.9909109036088889, 0.9905094393102223, 0.8002933792355555]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.03434177932816089], {
             RGBColor[
             0.9907706409550046, 0.9904514370982553, 0.8026178943985307]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.03434177932816089], {
             RGBColor[
             0.9486846207727112, 0.9612496547102856, 0.9717477312241194]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.03434177932816089], {
             RGBColor[
             0.38464718003408815`, 0.5075837872412954, 0.9457303560749939]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.03434177932816089], {
             RGBColor[
             0.9867234465277778, 0.9887778181944444, 0.8696903798611111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.03434177932816089], {
             RGBColor[
             0.706764898531668, 0.7708493774358977, 0.971407378058295]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.03434177932816089], {
             RGBColor[
             0.7189724812623276, 0.780386033846154, 0.9726241158185405]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.03434177932816089], {
             RGBColor[
             0.9570665102493074, 0.8668373991874423, 0.2877119289381348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.03434177932816089], {
             RGBColor[
             0.9939387396860573, 0.9894439020129271, 0.5816474044690669]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.03434177932816089], {
             RGBColor[
             0.8638435387409449, 0.8942694056565657, 0.9868753619589837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.03434177932816089], {
             RGBColor[
             0.21818862891795487`, 0.3466604613238209, 0.9357368916845026]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.03434177932816089], {
             RGBColor[
             0.9358480837017006, 0.9516761863806262, 0.9934766401802776]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.03434177932816089], {
             RGBColor[
             0.9934416844444445, 0.9883807511111111, 0.5275460088888881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.03434177932816089], {
             RGBColor[
             0.9945054567375886, 0.9906560524822695, 0.6433310581560281]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.03434177932816089], {
             RGBColor[
             0.7022381683424302, 0.7673130614076414, 0.9709561958977305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.03434177932816089], {
             RGBColor[
             0.9793864141953393, 0.9841470019753087, 0.9197776032697786]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.03434177932816089], {
             RGBColor[
             0.968470322895686, 0.9760057989574863, 0.9382556984675049]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.03434177932816089], {
             RGBColor[
             0.9639953460053825, 0.9726683685198001, 0.9458306670818916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.03434177932816089], {
             RGBColor[
             0.8498027740907299, 0.8830736810508876, 0.9855361412923077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.03434177932816089], {
             RGBColor[
             0.9879122464711111, 0.9892694175217778, 0.8499888882844444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.03434177932816089], {
             RGBColor[
             0.9918692373333333, 0.9909057349333333, 0.7844113093333334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.03434177932816089], {
             RGBColor[
             0.6425892546296297, 0.7207148766666668, 0.9650109496296296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.03434177932816089], {
             RGBColor[0.9717158, 0.9162528933333333, 0.3446216533333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.03434177932816089], {
             RGBColor[
             0.9482806114047775, 0.9609483451851851, 0.9724316137015122]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.03434177932816089], {
             RGBColor[
             0.9027235559762032, 0.651172211826212, 0.24054248945375872`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.03434177932816089], {
             RGBColor[
             0.49778979398836865`, 0.6031672057912458, 0.9536069825283134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.03434177932816089], {
             RGBColor[
             0.8579835290961744, 0.88959679303155, 0.9863164290077732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.03434177932816089], {
             RGBColor[
             0.9909150888888889, 0.9810166029629629, 0.41920726518518503`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.03434177932816089], {
             RGBColor[
             0.9925202875476233, 0.9864099763163272, 0.42725764287242346`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.03434177932816089], {
             RGBColor[
             0.9647351375000001, 0.8927054795833335, 0.3175030977083335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.03434177932816089], {
             RGBColor[
             0.9870026773940904, 0.9888932873335707, 0.8650628017799927]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.03434177932816089], {
             RGBColor[
             0.9646440854608256, 0.9731521973434561, 0.9447325204021748]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.03434177932816089], {
             RGBColor[
             0.4978476577777779, 0.6032141822222223, 0.9536115377777777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.03434177932816089], {
             RGBColor[
             0.8594353171597632, 0.45461042958579845`, 0.20442172189349106`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.03434177932816089], {
             RGBColor[
             0.9875644488275257, 0.9891255942581635, 0.855752795310103]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.03434177932816089], {
             RGBColor[
             0.9850681592888888, 0.9880933143822223, 0.8971227731555554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.03434177932816089], {
             RGBColor[
             0.975331550617284, 0.9811228913580248, 0.9266414296296294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.03434177932816089], {
             RGBColor[
             0.9931936545475438, 0.98785024024131, 0.5005494852743458]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.03434177932816089], {
             RGBColor[
             0.6612744045452605, 0.7353118577931566, 0.966873310750566]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.03434177932816089], {
             RGBColor[
             0.9495728353264197, 0.9619120836701235, 0.9702442156681481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.03434177932816089], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.03434177932816089], {
             RGBColor[
             0.6446136533333335, 0.7222963523200002, 0.9652127227733334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.03434177932816089], {
             RGBColor[
             0.9229797032098767, 0.7323472192592596, 0.25688586518518525`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.03434177932816089], {
             RGBColor[
             0.9558585052990534, 0.8627007133315414, 0.28334092111081244`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.03434177932816089], {
             RGBColor[
             0.9397455842707572, 0.7988183507669829, 0.27037608663257845`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.03434177932816089], {
             RGBColor[
             0.7217544382009482, 0.7825593197502603, 0.9729013952873165]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.03434177932816089], {
             RGBColor[
             0.6418632837460979, 0.7201325552133195, 0.9649489754006243]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.03434177932816089], {
             RGBColor[
             0.9865282112828643, 0.9886970834033558, 0.8729259331219444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.03434177932816089], {
             RGBColor[
             0.9632709999999999, 0.8877665999999995, 0.3118151999999995]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.03434177932816089], {
             RGBColor[
             0.9423623595540177, 0.9565345226451365, 0.9824496703575546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.03434177932816089], {
             RGBColor[
             0.414368835665295, 0.5333271914951989, 0.9476241936899863]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.03434177932816089], {
             RGBColor[
             0.9911763170404545, 0.9906191945849887, 0.7958947918065702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.03434177932816089], {
             RGBColor[
             0.9140889618436215, 0.934333742162963, 0.9916678152691358]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.03434177932816089], {
             RGBColor[
             0.9926314648526077, 0.9912209356009071, 0.7717792267573698]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.03434177932816089], {
             RGBColor[
             0.9121774833777778, 0.9328095811200001, 0.9914854967466666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.03434177932816089], {
             RGBColor[0.989358936, 0.9757673338666667, 0.4131619050666666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.03434177932816089], {
             RGBColor[
             0.8107948666666669, 0.8521183792000001, 0.9817761130666667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.03434177932816089], {
             RGBColor[
             0.9941959825235077, 0.989994118430993, 0.6096466998067775]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.03434177932816089], {
             RGBColor[
             0.880784375308642, 0.9077775688888888, 0.988491194074074]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.03434177932816089], {
             RGBColor[
             0.9940857720164609, 0.9897583893004116, 0.5976509662551444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.03434177932816089], {
             RGBColor[
             0.9948344136611805, 0.9913596580791857, 0.6791359892021945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.03434177932816089], {
             RGBColor[
             0.970873725925926, 0.9134123797530866, 0.3413503545679014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.03434177932816089], {
             RGBColor[
             0.8245679589906197, 0.862952124470868, 0.9831292221006738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.03434177932816089], {
             RGBColor[
             0.9693018543209876, 0.9081100877366254, 0.33524393020576115`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.03434177932816089], {
             RGBColor[
             0.9926806419753086, 0.9912412716049382, 0.7709642345679013]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.03434177932816089], {
             RGBColor[
             0.9943474663728191, 0.991930546328742, 0.7433406406978877]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.03434177932816089], {
             RGBColor[
             0.9942128498850019, 0.9900301960116773, 0.611482608012129]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.03434177932816089], {
             RGBColor[
             0.9363555353520987, 0.9520546429906173, 0.9926176569007407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.03434177932816089], {
             RGBColor[
             0.8934051579881116, 0.6088595429294316, 0.23276698975765892`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.03434177932816089], {
             RGBColor[
             0.9770530945841343, 0.9824068160297321, 0.9237273047443291]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.03434177932816089], {
             RGBColor[
             0.2995959381348108, 0.4322247048322561, 0.9403729175130809]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.03434177932816089], {
             RGBColor[
             0.8818203918474689, 0.9086036603550296, 0.9885900102564102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.03434177932816089], {
             RGBColor[
             0.9948250088888889, 0.9913395422222222, 0.6781123377777779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.03434177932816089], {
             RGBColor[
             0.2995959381348108, 0.4322247048322561, 0.9403729175130809]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.03434177932816089], {
             RGBColor[
             0.9247292742123456, 0.739283685274074, 0.25829361108148147`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.03434177932816089], {
             RGBColor[
             0.9573234759199265, 0.9676924987342517, 0.9571244028341597]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.03434177932816089], {
             RGBColor[
             0.9848031822222222, 0.9879837395555556, 0.9015141288888892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.03434177932816089], {
             RGBColor[
             0.9389897823800131, 0.7958218481262325, 0.26976795069033527`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.03434177932816089], {
             RGBColor[
             0.8218489645520956, 0.8607840721107267, 0.9828698819838524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.03434177932816089], {
             RGBColor[
             0.40491315259259286`, 0.5251371540740742, 0.947021685925926]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.03434177932816089], {
             RGBColor[
             0.9893812162150809, 0.9898768742617098, 0.8256442580550303]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.03434177932816089], {
             RGBColor[
             0.8913901550617286, 0.916234329777778, 0.9895027828148149]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.03434177932816089], {
             RGBColor[
             0.9675276541914549, 0.9021252940977106, 0.3283514977321075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.03434177932816089], {
             RGBColor[
             0.9439481543867744, 0.8154801408535179, 0.27375757319492505`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.03434177932816089], {
             RGBColor[
             0.8218489645520956, 0.8607840721107267, 0.9828698819838524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.03434177932816089], {
             RGBColor[
             0.8305254006574622, 0.8677024267455621, 0.9836974482051282]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.03434177932816089], {
             RGBColor[
             0.9530680847321563, 0.9645188349539762, 0.9643276701312811]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.03434177932816089], {
             RGBColor[
             0.9632709999999999, 0.8877665999999995, 0.3118151999999995]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.03434177932816089], {
             RGBColor[
             0.8701515054412438, 0.8992992070781893, 0.9874770214540466]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.03434177932816089], {
             RGBColor[
             0.9365048432054934, 0.9521659965432099, 0.9923649176506684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.03434177932816089], {
             RGBColor[
             0.7217544382009482, 0.7825593197502603, 0.9729013952873165]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.03434177932816089], {
             RGBColor[0.8120895555555557, 0.8531298, 0.9819051555555556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.03434177932816089], {
             RGBColor[0.9670707381333333, 0.9749619909333334, 0.9406248304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.03434177932816089], {
             RGBColor[
             0.9934248079951026, 0.9883446540924395, 0.5257091115273951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.03434177932816089], {
             RGBColor[
             0.902293441930186, 0.9249283147648482, 0.9905427480498074]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.03434177932816089], {
             RGBColor[
             0.9899777257023933, 0.990123546264308, 0.8157585521331946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.03434177932816089], {
             RGBColor[
             0.493915604977778, 0.6000219646222223, 0.9533019921777778]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.03434177932816089], {
             RGBColor[
             0.756370360153257, 0.8096015410701548, 0.97635158688334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.03434177932816089], {
             RGBColor[
             0.9923315511680553, 0.9910969135849145, 0.776749572662139]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.03434177932816089], {
             RGBColor[
             0.9866565999999999, 0.9666517199999998, 0.40266383999999966`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.03434177932816089], {
             RGBColor[
             0.9433561045679013, 0.9572756560493828, 0.9807675192592591]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.03434177932816089], {
             RGBColor[
             0.9950152931944445, 0.9917465411111112, 0.6988236101388888]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.03434177932816089], {
             RGBColor[
             0.9756175898307171, 0.981336218935057, 0.9261572398522622]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.03434177932816089], {
             RGBColor[
             0.8511474153018073, 0.8841458614532873, 0.9856643943713956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.03434177932816089], {
             RGBColor[0.8120895555555557, 0.8531298, 0.9819051555555556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.03434177932816089], {
             RGBColor[
             0.9749483960493828, 0.980837135308642, 0.9272900103703702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.03434177932816089], {
             RGBColor[
             0.9888744444444444, 0.9896673111111112, 0.8340427777777777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.03434177932816089], {
             RGBColor[
             0.8913792403292181, 0.5996603240054871, 0.23107651440329222`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.03434177932816089], {
             RGBColor[
             0.7830622905982909, 0.8304534800000002, 0.9790119890598291]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.03434177932816089], {
             RGBColor[
             0.9567826875739646, 0.8658799986587774, 0.2866093314398426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.03434177932816089], {
             RGBColor[
             0.3251308266666667, 0.45603371333333337`, 0.9419380266666667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.03434177932816089], {
             RGBColor[
             0.9842266117530863, 0.9877453128493827, 0.9110693936790125]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.03434177932816089], {
             RGBColor[0.977718104, 0.9365000741333332, 0.36793947093333323`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.03434177932816089], {
             RGBColor[
             0.9602395333333333, 0.877540751111111, 0.30003852444444434`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.03434177932816089], {
             RGBColor[
             0.7427767415493634, 0.7989821029014652, 0.9749967020204922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.03434177932816089], {
             RGBColor[
             0.2781664133333335, 0.40970091555555566`, 0.9391525377777777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.03434177932816089], {
             RGBColor[
             0.9863344690873987, 0.9886169660265836, 0.8761367426895375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.03434177932816089], {
             RGBColor[
             0.5651464126023946, 0.6578503431632011, 0.9589095422810334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.03434177932816089], {
             RGBColor[
             0.9445693333907869, 0.9581804801190109, 0.9787138393228686]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.03434177932816089], {
             RGBColor[
             0.9829972935640138, 0.9868399898961938, 0.913665326366782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.03434177932816089], {
             RGBColor[
             0.9934880392318244, 0.9884798993141289, 0.5325914414266117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.03434177932816089], {
             RGBColor[
             0.9680834213017752, 0.904000027061144, 0.3305105480078896]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.03434177932816089], {
             RGBColor[
             0.9946884185589808, 0.9910473893179497, 0.6632453233050893]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.03434177932816089], {
             RGBColor[
             0.8095047263773474, 0.8511105118005544, 0.9816475239396738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.03434177932816089], {
             RGBColor[
             0.9658058809416025, 0.8963173486343742, 0.3216627337860265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.03434177932816089], {
             RGBColor[
             0.9530680847321563, 0.9645188349539762, 0.9643276701312811]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.03434177932816089], {
             RGBColor[
             0.9946604920888888, 0.9909876574222223, 0.6602056993777774]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.03434177932816089], {
             RGBColor[
             0.9945786999616042, 0.9908127123324129, 0.6513031310853388]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.03434177932816089], {
             RGBColor[
             0.9429975623593965, 0.9570082558573388, 0.9813744376954732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.03434177932816089], {
             RGBColor[
             0.9913540041481481, 0.9906926727703704, 0.7929500565925927]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.03434177932816089], {
             RGBColor[
             0.9165586183791375, 0.9363029792473427, 0.9919033733141818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.03434177932816089], {
             RGBColor[
             0.9579871728572895, 0.9681874828234329, 0.9560009370390887]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.03434177932816089], {
             RGBColor[
             0.9363631671655329, 0.9520603347845805, 0.9926047382312924]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.03434177932816089], {
             RGBColor[
             0.8741315629629629, 0.5213426493827158, 0.2166846296296296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.03434177932816089], {
             RGBColor[
             0.8255937727197948, 0.8637700804935403, 0.9832270651299173]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.03434177932816089], {
             RGBColor[
             0.993178194074074, 0.9878171718518519, 0.49886670814814726`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.03434177932816089], {
             RGBColor[
             0.5611923395311894, 0.6546402485150349, 0.9585982631646212]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.03434177932816089], {
             RGBColor[
             0.8823057454427402, 0.9089906681373267, 0.9886363037156075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.03434177932816089], {
             RGBColor[
             0.8810920196597353, 0.9080228761436673, 0.9885205374669187]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.03434177932816089], {
             RGBColor[
             0.9946731218163791, 0.9910146711322625, 0.6615803672734477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.03434177932816089], {
             RGBColor[
             0.726438758278838, 0.7862187461972588, 0.9733682845352205]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.03434177932816089], {
             RGBColor[
             0.9936665520163427, 0.9888617201098024, 0.552021456368221]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.03434177932816089], {
             RGBColor[
             0.9877168846811308, 0.989188630401052, 0.8532265387245234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.03434177932816089], {
             RGBColor[
             0.9854135382716049, 0.9624585809053497, 0.3978347799176953]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.03434177932816089], {
             RGBColor[
             0.42266302721277055`, 0.5405112033354338, 0.9481526922411259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.03434177932816089], {
             RGBColor[
             0.9924738911539639, 0.9911557748270585, 0.7743906307315578]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.03434177932816089], {
             RGBColor[
             0.9939423161481482, 0.9894515517037037, 0.5820366802962964]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.03434177932816089], {
             RGBColor[
             0.9881488920616035, 0.9893672765549607, 0.8460670584308283]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.03434177932816089], {
             RGBColor[
             0.7583185280415552, 0.8111234646311177, 0.9765457620517816]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.03434177932816089], {
             RGBColor[
             0.41794100591368244`, 0.536421225821855, 0.9478518092194674]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.03434177932816089], {
             RGBColor[0.989358936, 0.9757673338666667, 0.4131619050666666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.03434177932816089], {
             RGBColor[
             0.8017200960960964, 0.8450290994594596, 0.9808716247447448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.03434177932816089], {
             RGBColor[
             0.9125456547188245, 0.6909796939327821, 0.24849038485068867`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.03434177932816089], {
             RGBColor[
             0.8418275185625579, 0.8767144287752676, 0.984775454300436]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.03434177932816089], {
             RGBColor[
             0.9935315107070707, 0.9885728804040405, 0.537323043232323]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.03434177932816089], {
             RGBColor[
             0.981433287111111, 0.9856735564444444, 0.9163127813333334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.03434177932816089], {
             RGBColor[
             0.9846702847736625, 0.9879287830452675, 0.9037165835390945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.03434177932816089], {
             RGBColor[
             0.9748469169550174, 0.9268148860438293, 0.3567854514417531]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.03434177932816089], {
             RGBColor[
             0.8950630372378329, 0.9191629863272728, 0.9898531055955923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.03434177932816089], {
             RGBColor[
             0.9749483960493828, 0.980837135308642, 0.9272900103703702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.03434177932816089], {
             RGBColor[
             0.9937135764304845, 0.9916684165473582, 0.7538458374969563]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.03434177932816089], {
             RGBColor[
             0.9893340761245675, 0.9898573806228373, 0.8264254913494807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.03434177932816089], {
             RGBColor[
             0.9721970137931034, 0.917876140451843, 0.34649107804994045`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.03434177932816089], {
             RGBColor[
             0.9576272162570889, 0.8687287922117204, 0.2898901658979208]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.03434177932816089], {
             RGBColor[
             0.9945451864707683, 0.9907410303642485, 0.6476553944291398]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.03434177932816089], {
             RGBColor[
             0.9859955176971059, 0.9884768009160441, 0.8817540444047696]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.03434177932816089], {
             RGBColor[
             0.9951468481077369, 0.9920279237684015, 0.7131425505879544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.03434177932816089], {
             RGBColor[
             0.958611258413871, 0.9686529248096851, 0.9549445229793782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.03434177932816089], {
             RGBColor[
             0.9660222743982764, 0.9741800483964297, 0.9423996060203138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.03434177932816089], {
             RGBColor[
             0.9419708895523106, 0.9562425649588366, 0.9831123269587164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.03434177932816089], {
             RGBColor[
             0.9776181918188458, 0.9361630468858045, 0.3675513309763815]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.03434177932816089], {
             RGBColor[
             0.8202687255662249, 0.15679988327998912`, 0.16704266053345543`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.03434177932816089], {
             RGBColor[
             0.9939423161481482, 0.9894515517037037, 0.5820366802962964]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.03434177932816089], {
             RGBColor[
             0.991106782816568, 0.9816632315928993, 0.4199519598958577]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.03434177932816089], {
             RGBColor[
             0.9535726690567902, 0.853638134340741, 0.28150168361481487`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.03434177932816089], {
             RGBColor[
             0.9082238017044071, 0.9296570226734843, 0.9911083910591673]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.03434177932816089], {
             RGBColor[
             0.8401475247015612, 0.8753748472727273, 0.984615214986226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.03434177932816089], {
             RGBColor[
             0.9214884883007769, 0.9402339237051038, 0.9923735887082545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.03434177932816089], {
             RGBColor[
             0.7237811191135736, 0.7841425782825486, 0.973103395900277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.03434177932816089], {
             RGBColor[
             0.9748774265927979, 0.9269178022160667, 0.35690397562326887`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.03434177932816089], {
             RGBColor[
             0.992944994907793, 0.9873183824152291, 0.4734844180368819]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.03434177932816089], {
             RGBColor[
             0.9874292064318887, 0.9890696680519966, 0.8579941118019089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.03434177932816089], {
             RGBColor[
             0.9952414883555556, 0.9922303496888889, 0.7234435575111108]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.03434177932816089], {
             RGBColor[
             0.9766504256382001, 0.9821065061891644, 0.9244089182369145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.03434177932816089], {
             RGBColor[
             0.9818930725925925, 0.9860164637037037, 0.9155344844444445]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.03434177932816089], {
             RGBColor[
             0.9542391281694864, 0.9653921972321293, 0.9623453990489254]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.03434177932816089], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.03434177932816089], {
             RGBColor[
             0.8533308982772577, 0.8858869115088451, 0.9858726569268124]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.03434177932816089], {
             RGBColor[
             0.9845778799999999, 0.9596397093333331, 0.39458840533333306`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.03434177932816089], {
             RGBColor[
             0.9273127528888888, 0.7495263173333331, 0.2603723386666666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.03434177932816089], {
             RGBColor[
             0.9732315333333333, 0.9213658177777777, 0.35050999111111103`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.03434177932816089], {
             RGBColor[
             0.9784926457722588, 0.9834804309487867, 0.9212905200779156]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.03434177932816089], {
             RGBColor[
             0.9873783777777777, 0.9690864459259255, 0.40546781037036983`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.03434177932816089], {
             RGBColor[
             0.6890921618655694, 0.757043301234568, 0.9696459248285322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.03434177932816089], {
             RGBColor[
             0.9485368378085566, 0.8336727415327796, 0.2774497355863343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.03434177932816089], {
             RGBColor[
             0.9746770779604578, 0.9806347867221644, 0.9277492811238294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.03434177932816089], {
             RGBColor[
             0.9318787345505761, 0.9485188240289726, 0.9933646196710427]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.03434177932816089], {
             RGBColor[0.97535356, 0.928523912, 0.35875366399999986`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.03434177932816089], {
             RGBColor[
             0.9099739734796524, 0.9310525621399176, 0.9912753240054869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.03434177932816089], {
             RGBColor[
             0.9888744444444444, 0.9896673111111112, 0.8340427777777777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.03434177932816089], {
             RGBColor[
             0.9688604327153189, 0.9762967422222223, 0.9375953442998027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.03434177932816089], {
             RGBColor[
             0.9669087599999999, 0.9000376186666665, 0.32594721066666643`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.03434177932816089], {
             RGBColor[
             0.9951664846611178, 0.9922692314387634, 0.7297673881093931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.03434177932816089], {
             RGBColor[
             0.9432934921391197, 0.812884623194829, 0.27323081658356413`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.03434177932816089], {
             RGBColor[
             0.8344054434448291, 0.8707962675432527, 0.9840675301499423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.03434177932816089], {
             RGBColor[
             0.9673880681652892, 0.9016544376550961, 0.327809232379063]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.03434177932816089], {
             RGBColor[
             0.9451934189473684, 0.9586459221052632, 0.9776574252631578]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.03434177932816089], {
             RGBColor[
             0.9169448690189202, 0.9366109650230111, 0.9919402142450142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.03434177932816089], {
             RGBColor[0.974080344, 0.9242290554666667, 0.35380746026666665`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.03434177932816089], {
             RGBColor[
             0.5688430555555557, 0.6608514444444447, 0.9592005555555555]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.03434177932816089], {
             RGBColor[
             0.9847284738348498, 0.9879528457174591, 0.9027522402067579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.03434177932816089], {
             RGBColor[
             0.6316648287517148, 0.7118529900137176, 0.9641461156652948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.03434177932816089], {
             RGBColor[
             0.8342698024691357, 0.870688111111111, 0.9840545925925925]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.03434177932816089], {
             RGBColor[
             0.9673880681652892, 0.9016544376550961, 0.327809232379063]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.03434177932816089], {
             RGBColor[0.8734700444444445, 0.90194532, 0.9877935466666666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.03434177932816089], {
             RGBColor[
             0.9714760577777777, 0.9782474711111111, 0.9331677733333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.03434177932816089], {
             RGBColor[
             0.9949942354547364, 0.9917015007351396, 0.6965316051249735]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.03434177932816089], {
             RGBColor[
             0.994421008764019, 0.9919609579974563, 0.7421218529540985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.03434177932816089], {
             RGBColor[
             0.9517901055358317, 0.8465708639842207, 0.28006739116370805`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.03434177932816089], {
             RGBColor[
             0.9949942354547364, 0.9917015007351396, 0.6965316051249735]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.03434177932816089], {
             RGBColor[
             0.9576232380165289, 0.8687153726721761, 0.28987471118457286`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.03434177932816089], {
             RGBColor[
             0.18484080515259624`, 0.3116097841722818, 0.9338377824547497]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.03434177932816089], {
             RGBColor[
             0.8093085934692092, 0.8509572912820516, 0.9816279752443569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.03434177932816089], {
             RGBColor[
             0.9818086011342154, 0.9859534650283555, 0.915677472589792]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.03434177932816089], {
             RGBColor[
             0.9901658133333333, 0.9902013253333334, 0.8126414533333332]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.03434177932816089], {
             RGBColor[
             0.9646440854608256, 0.9731521973434561, 0.9447325204021748]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.03434177932816089], {
             RGBColor[
             0.9939423161481482, 0.9894515517037037, 0.5820366802962964]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.03434177932816089], {
             RGBColor[
             0.9867254217324762, 0.9887786349923477, 0.8696576456075911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.03434177932816089], {
             RGBColor[
             0.8060462222222223, 0.8484087020689656, 0.9813028125670499]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.03434177932816089], {
             RGBColor[
             0.7051372208342467, 0.7695778232478634, 0.9712451463569289]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.03434177932816089], {
             RGBColor[
             0.7810063100936525, 0.8288473324037461, 0.978807068137357]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.03434177932816089], {
             RGBColor[
             0.9670443363888889, 0.9749423005555556, 0.9406695216666666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.03434177932816089], {
             RGBColor[
             0.8876201833731252, 0.5825913243179266, 0.22793986513621056`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.03434177932816089], {
             RGBColor[
             0.984562293979798, 0.9878841260767677, 0.9055062704646463]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.03434177932816089], {
             RGBColor[
             0.9880371731025779, 0.9893210778943573, 0.84791853070128]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.03434177932816089], {
             RGBColor[
             0.9679155939555556, 0.9755920830222223, 0.9391947098666665]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.03434177932816089], {
             RGBColor[
             0.9916680909519716, 0.9908225557354141, 0.7877448254226452]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.03434177932816089], {
             RGBColor[
             0.7189724812623276, 0.780386033846154, 0.9726241158185405]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.03434177932816089], {
             RGBColor[
             0.9522689568419448, 0.9639228466819082, 0.9656803852034751]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.03434177932816089], {
             RGBColor[
             0.19046646666666678`, 0.31752271111111124`, 0.9341581555555556]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.03434177932816089], {
             RGBColor[
             0.9900143978666667, 0.9901387111466667, 0.8151507994666662]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.03434177932816089], {
             RGBColor[
             0.9753732718924555, 0.9811540070167354, 0.9265708063934155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.03434177932816089], {
             RGBColor[
             0.993390907654321, 0.988272144691358, 0.5220192686419755]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.03434177932816089], {
             RGBColor[0.7424289777777778, 0.7987104272, 0.9749620401777778]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.03434177932816089], {
             RGBColor[
             0.9919789026605751, 0.9909510843644181, 0.7825938710561674]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.03434177932816089], {
             RGBColor[
             0.9799914520775623, 0.9441686110064635, 0.3767709989289012]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.03434177932816089], {
             RGBColor[
             0.9206561345313756, 0.9395702274030244, 0.992294198062678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.03434177932816089], {
             RGBColor[0.6731473333333333, 0.74458708, 0.9680566933333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.03434177932816089], {
             RGBColor[
             0.9946314511732435, 0.992047981341794, 0.7386342776257517]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.03434177932816089], {
             RGBColor[
             0.6225575456147273, 0.7044592872846813, 0.9634291569756739]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.03434177932816089], {
             RGBColor[
             0.9666820683127573, 0.8992729343758574, 0.3250665562688615]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.03434177932816089], {
             RGBColor[
             0.26676940921810716`, 0.3977219416186558, 0.9385034952537723]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1FO4EAYYBuBzsm2dTrZdW7WsZbtVy3bLtWxr2bat5WVjyzZXrfc8u3i/
//a7+f7gJu2rtAsMCAjIJEJuKEIThrCEIzwRiEgkIhOFqEQjOjGISSxiE4e4
xCM+CUhIIhKThKQkI4jkBJOClKQiNWlISzrSk4GMIX3JTBayko3s5CAnuchN
HvKSj/wUoCCF+IEfKUwRivITxShOCUpSitKUoSzlKE8FfqYilahMFapSjerU
oCa1qE0d6lKP+jSgIY1oTBN+oSnNaM6vtKAlrWhNG9rSjvZ0oCOd6EwXutKN
7vSgJ73ozW/0oS/96M8ABjKIwQzhd4YyjOGMYCSjGM0YxjKO8UxgIpOYzBSm
Mo3pzGAms5jNH8xhLvOYzwIWsojFLGEpy1jOClayitWsYS3rWM8GNrKJzWxh
K9vYzg52sovd7GEv+9jPAQ5yiMMc4U+OcozjnOAkpzjNX5zhLOc4zwUuconL
XOEq17jODW5yi9v8zT/c4S73uM8DHvKIxzzhKc94zgte8orXvOEt73jPBz7y
ic/8yxe+8o3/CBl/IKEITRjCEo7wRCAikYhMFKISjejEICaxiE0c4hKP+CQg
IYlITBKSkowgkhNMClKSitSkIS3pSE8GMgb+/6++Az6VhWw=
          "], {Null, CompressedData["
1:eJxN2nu4llWZB+C1RcxDZpqQRxAUUVHStBgOUSMyo5BNY0aKowyCpqCIyVg4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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[57, 280] -> 
             RGBColor[
              0.2575556675749038, 0.38803771496668804`, 0.9379787862977012], 
             UndirectedEdge[46, 187] -> 
             RGBColor[
              0.32803381097302087`, 0.4570126210374179, 0.9421792248536764], 
             UndirectedEdge[96, 298] -> 
             RGBColor[
              0.3453589956577786, 0.4713821632368721, 0.9433064816157806], 
             UndirectedEdge[165, 207] -> 
             RGBColor[
              0.8629243195572578, 0.8731271056740303, 0.676546302374514], 
             UndirectedEdge[69, 224] -> 
             RGBColor[
              0.9812813612748328, 0.9481895871324358, 0.4098590677551779], 
             UndirectedEdge[51, 110] -> 
             RGBColor[
              0.9932540497607107, 0.99147839046011, 0.7614613836320072], 
             UndirectedEdge[122, 231] -> 
             RGBColor[
              0.5346560481729267, 0.6328742791629598, 0.9565707376227028], 
             UndirectedEdge[71, 246] -> 
             RGBColor[
              0.6142322345348998, 0.6977004246990872, 0.9627737579908505], 
             UndirectedEdge[9, 239] -> 
             RGBColor[
              0.4639819639121217, 0.5745750992225973, 0.9512619801674704], 
             UndirectedEdge[99, 229] -> 
             RGBColor[
              0.3569385719957474, 0.4835839836336185, 0.9439647880725508], 
             UndirectedEdge[49, 112] -> 
             RGBColor[
              0.24438397329964223`, 0.374193429149736, 0.9372286777945005], 
             UndirectedEdge[115, 243] -> 
             RGBColor[
              0.21987898042507611`, 0.348437127932281, 0.9358331547021821], 
             UndirectedEdge[58, 95] -> 
             RGBColor[
              0.5187848450827122, 0.6202119340859072, 0.9552597898578664], 
             UndirectedEdge[210, 239] -> 
             RGBColor[
              0.39484568065555037`, 0.5164172158880604, 0.9463801955164135], 
             UndirectedEdge[94, 150] -> 
             RGBColor[
              0.9119777121048072, 0.931971896043791, 0.9679461351700305], 
             UndirectedEdge[21, 108] -> 
             RGBColor[
              0.3636875531699619, 0.4894296119130661, 0.9443948271850822], 
             UndirectedEdge[83, 202] -> 
             RGBColor[
              0.22220476853383342`, 0.3508816786980681, 0.9359656048942807], 
             UndirectedEdge[172, 174] -> 
             RGBColor[
              0.33090944455997406`, 0.4574098756542951, 0.9424391100455509], 
             UndirectedEdge[3, 157] -> 
             RGBColor[
              0.36165267017657554`, 0.4876670985403879, 0.9442651662401199], 
             UndirectedEdge[181, 246] -> 
             RGBColor[
              0.656342497401248, 0.7307927865257904, 0.9668372480070162], 
             UndirectedEdge[159, 253] -> 
             RGBColor[
              0.27205955347524674`, 0.4032822186474281, 0.9388047611431494], 
             UndirectedEdge[170, 228] -> 
             RGBColor[
              0.8191183413836293, 0.5128704810525186, 0.5754638060619697], 
             UndirectedEdge[151, 194] -> 
             RGBColor[
              0.4795533660103779, 0.5880893214551517, 0.9522467003824877], 
             UndirectedEdge[62, 100] -> 
             RGBColor[
              0.9225145323393552, 0.6890519389234857, 0.4381903343500609], 
             UndirectedEdge[76, 99] -> 
             RGBColor[
              0.3308920068686242, 0.45968772172522177`, 0.9423540428096366], 
             UndirectedEdge[131, 283] -> 
             RGBColor[
              0.47177717102653804`, 0.5785602690993044, 0.9525231166057517], 
             UndirectedEdge[173, 263] -> 
             RGBColor[
              0.25907859446240145`, 0.3896384076845897, 0.9380655147309758], 
             UndirectedEdge[20, 75] -> 
             RGBColor[
              0.7982091276425176, 0.8426574734850338, 0.980423187310408], 
             UndirectedEdge[175, 253] -> 
             RGBColor[
              0.29561827694261666`, 0.42804393072097424`, 0.9401463955926079],
              UndirectedEdge[52, 193] -> 
             RGBColor[
              0.6086028861336337, 0.3287818878860621, 0.5556335731143328], 
             UndirectedEdge[282, 283] -> 
             RGBColor[
              0.7911900845661439, 0.8368811978581185, 0.9547653144934332], 
             UndirectedEdge[173, 279] -> 
             RGBColor[
              0.2579831193391787, 0.3884869938729482, 0.9380031290433184], 
             UndirectedEdge[95, 198] -> 
             RGBColor[
              0.4764509321887418, 0.5858433564775396, 0.9519271091606205], 
             UndirectedEdge[18, 288] -> 
             RGBColor[
              0.9041509173263116, 0.7126766818632384, 0.5910465110881808], 
             UndirectedEdge[29, 91] -> 
             RGBColor[
              0.25771769921639187`, 0.38820802049529146`, 0.9379880137599795],
              UndirectedEdge[46, 169] -> 
             RGBColor[
              0.2925815910536258, 0.4248521813146391, 0.9399734608236041], 
             UndirectedEdge[34, 264] -> 
             RGBColor[
              0.31108024849077764`, 0.44256158228500475`, 0.9410904171386354],
              UndirectedEdge[116, 277] -> 
             RGBColor[
              0.33575144742336294`, 0.46523276122486323`, 0.9426147632298372],
              UndirectedEdge[60, 299] -> 
             RGBColor[
              0.9602834986478392, 0.8683179033755875, 0.5002256256588694], 
             UndirectedEdge[205, 213] -> 
             RGBColor[
              0.4786627684820106, 0.5869482888311869, 0.9522920854283001], 
             UndirectedEdge[240, 299] -> 
             RGBColor[
              0.9947090533611671, 0.9917794762430787, 0.7154980818389891], 
             UndirectedEdge[184, 214] -> 
             RGBColor[
              0.22515962250579277`, 0.3539874175711599, 0.9361338794566691], 
             UndirectedEdge[39, 59] -> 
             RGBColor[
              0.8501714335969901, 0.3722888082384709, 0.1951153671911272], 
             UndirectedEdge[246, 299] -> 
             RGBColor[
              0.7966762325062557, 0.8386071063469377, 0.851316533208819], 
             UndirectedEdge[21, 114] -> 
             RGBColor[
              0.3439329379247541, 0.47191837420693394`, 0.9431507551943723], 
             UndirectedEdge[204, 253] -> 
             RGBColor[
              0.26380404156370607`, 0.39460515219871184`, 0.9383346219527224],
              UndirectedEdge[202, 214] -> 
             RGBColor[
              0.22050159369132202`, 0.3490915339510665, 0.935868611606621], 
             UndirectedEdge[26, 39] -> 
             RGBColor[
              0.9266838506619479, 0.7398946126602461, 0.547796397964442], 
             UndirectedEdge[118, 220] -> 
             RGBColor[
              0.21806065403360642`, 0.34652595160629435`, 0.9357296037041608],
              UndirectedEdge[28, 126] -> 
             RGBColor[
              0.22467560955270433`, 0.3534786892692703, 0.9361063156350238], 
             UndirectedEdge[9, 237] -> 
             RGBColor[
              0.5778044829283981, 0.6681267348934206, 0.9599060319451358], 
             UndirectedEdge[174, 297] -> 
             RGBColor[
              0.5763612583921884, 0.663490693504958, 0.9614863052750408], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.35208222651696447`, 0.4786261706514128, 0.9436828617856419], 
             UndirectedEdge[63, 139] -> 
             RGBColor[
              0.28999599813964694`, 0.42067676560446166`, 0.9398795920978575],
              UndirectedEdge[124, 150] -> 
             RGBColor[
              0.9548500534233739, 0.9658478242861803, 0.9613112619489188], 
             UndirectedEdge[127, 165] -> 
             RGBColor[
              0.9065162299369915, 0.5989909877808421, 0.27841578820409746`], 
             UndirectedEdge[8, 22] -> 
             RGBColor[
              0.7346141321851996, 0.7926054104280515, 0.9741831294029938], 
             UndirectedEdge[127, 137] -> 
             RGBColor[
              0.8391691506119379, 0.30207683240040506`, 0.18514172890220718`],
              UndirectedEdge[21, 213] -> 
             RGBColor[
              0.40566670523630644`, 0.5257898434994019, 0.9470697016340429], 
             UndirectedEdge[41, 278] -> 
             RGBColor[
              0.4799611412114356, 0.5860775921964064, 0.9529261189064413], 
             UndirectedEdge[69, 249] -> 
             RGBColor[
              0.9058089885195326, 0.5656683412312807, 0.3245169720093974], 
             UndirectedEdge[100, 136] -> 
             RGBColor[
              0.9215440004534805, 0.6869760693554257, 0.33255392800111494`], 
             UndirectedEdge[88, 222] -> 
             RGBColor[
              0.47017691950032614`, 0.5802832085890723, 0.9515621248783083], 
             UndirectedEdge[153, 216] -> 
             RGBColor[
              0.2661597993989548, 0.3970812030472318, 0.9384687788764086], 
             UndirectedEdge[60, 121] -> 
             RGBColor[
              0.9603462863275016, 0.8677642487038257, 0.4570528894502983], 
             UndirectedEdge[203, 206] -> 
             RGBColor[
              0.24813385698154097`, 0.37813479465576916`, 0.9374422281227288],
              UndirectedEdge[50, 108] -> 
             RGBColor[
              0.3481847341285709, 0.4760018492537544, 0.9434070012643693], 
             UndirectedEdge[98, 181] -> 
             RGBColor[
              0.5683121366528735, 0.6584973340732392, 0.9601360759487196], 
             UndirectedEdge[267, 285] -> 
             RGBColor[
              0.42530929649653304`, 0.542408765687049, 0.9484303125609015], 
             UndirectedEdge[156, 178] -> 
             RGBColor[
              0.25237767810444756`, 0.38259531972974414`, 0.9376839074575076],
              UndirectedEdge[185, 295] -> 
             RGBColor[
              0.7026775395247731, 0.7666581291332051, 0.9717409425805205], 
             UndirectedEdge[83, 156] -> 
             RGBColor[
              0.221993745626472, 0.35065988024280614`, 0.935953587451887], 
             UndirectedEdge[44, 150] -> 
             RGBColor[
              0.9635307831976114, 0.9324851425902525, 0.6339721646328667], 
             UndirectedEdge[223, 274] -> 
             RGBColor[
              0.9259651133080155, 0.7367764933200369, 0.2723005774523107], 
             UndirectedEdge[20, 142] -> 
             RGBColor[
              0.7624648027643098, 0.8147337352232472, 0.9768605270562558], 
             UndirectedEdge[87, 264] -> 
             RGBColor[
              0.2853843000396664, 0.4172873721243609, 0.939563585747797], 
             UndirectedEdge[16, 192] -> 
             RGBColor[
              0.9292282498402631, 0.7341287491873884, 0.36986042931949054`], 
             UndirectedEdge[75, 143] -> 
             RGBColor[
              0.5636312232942053, 0.6537338940348352, 0.9601379235387875], 
             UndirectedEdge[230, 263] -> 
             RGBColor[
              0.2551678747286398, 0.38552799329045395`, 0.9378428050275294], 
             UndirectedEdge[52, 82] -> 
             RGBColor[
              0.90639234718301, 0.5644975000841104, 0.4350476194442515], 
             UndirectedEdge[34, 213] -> 
             RGBColor[
              0.37768895869959807`, 0.5015569256517332, 0.9452869843644738], 
             UndirectedEdge[145, 219] -> 
             RGBColor[
              0.27171942382339986`, 0.4029247208178715, 0.9387853912626534], 
             UndirectedEdge[237, 295] -> 
             RGBColor[
              0.738032045164762, 0.7953605095140767, 0.9745241787723218], 
             UndirectedEdge[257, 259] -> 
             RGBColor[
              0.4277830853443319, 0.544648816326516, 0.9485610340700278], 
             UndirectedEdge[116, 241] -> 
             RGBColor[
              0.30074162674959204`, 0.4321657656332045, 0.9404844121827121], 
             UndirectedEdge[95, 105] -> 
             RGBColor[
              0.3889084199719124, 0.5085055030468593, 0.9463331921101534], 
             UndirectedEdge[115, 146] -> 
             RGBColor[
              0.22602095903949393`, 0.35489273687997036`, 0.9361829312980301],
              UndirectedEdge[16, 170] -> 
             RGBColor[
              0.9076819009807398, 0.5788651194760369, 0.34963294244959353`], 
             UndirectedEdge[199, 226] -> 
             RGBColor[
              0.178927005110741, 0.3053940053717128, 0.9335010002910491], 
             UndirectedEdge[78, 130] -> 
             RGBColor[
              0.17948366008578914`, 0.30597908504445237`, 0.9335327009683809],
              UndirectedEdge[155, 214] -> 
             RGBColor[
              0.21259246077095287`, 0.340778533783768, 0.9354181981873197], 
             UndirectedEdge[185, 297] -> 
             RGBColor[
              0.6642346642542716, 0.7364864270373344, 0.9679464241532377], 
             UndirectedEdge[45, 53] -> 
             RGBColor[
              0.8447764554590436, 0.34517703459191124`, 0.19051129035634062`],
              UndirectedEdge[49, 204] -> 
             RGBColor[
              0.23371861491604712`, 0.3629834612657993, 0.9366213014125385], 
             UndirectedEdge[69, 254] -> 
             RGBColor[
              0.9421799602264942, 0.7934586684310521, 0.3573185586987633], 
             UndirectedEdge[102, 295] -> 
             RGBColor[
              0.6113037860265932, 0.6906305704110295, 0.9650577846461873], 
             UndirectedEdge[14, 254] -> 
             RGBColor[
              0.8570098056114457, 0.3874350253501294, 0.200198663385516], 
             UndirectedEdge[125, 299] -> 
             RGBColor[
              0.9935548569863483, 0.9893107669044954, 0.5898709293143154], 
             UndirectedEdge[16, 44] -> 
             RGBColor[
              0.9792628131880576, 0.9411137160345208, 0.4247070629331663], 
             UndirectedEdge[49, 84] -> 
             RGBColor[
              0.2685862507813846, 0.39963155729606886`, 0.9386069616930247], 
             UndirectedEdge[186, 230] -> 
             RGBColor[
              0.23966064866834333`, 0.3692289154861624, 0.9369596914442806], 
             UndirectedEdge[215, 282] -> 
             RGBColor[
              0.97938013431987, 0.9823295669124169, 0.8386095157394571], 
             UndirectedEdge[134, 159] -> 
             RGBColor[
              0.26069725479200045`, 0.3913397223199907, 0.9381576950421531], 
             UndirectedEdge[26, 266] -> 
             RGBColor[
              0.6167344718352826, 0.6830098916954412, 0.9109140844783175], 
             UndirectedEdge[142, 150] -> 
             RGBColor[
              0.810515025857468, 0.8523692859433827, 0.9579232930155395], 
             UndirectedEdge[114, 221] -> 
             RGBColor[
              0.29951227485023835`, 0.4321367694156119, 0.9403681530127932], 
             UndirectedEdge[147, 172] -> 
             RGBColor[
              0.2478440102281372, 0.3778301473405962, 0.9374257217789124], 
             UndirectedEdge[35, 211] -> 
             RGBColor[
              0.2342952250609407, 0.36358951508727716`, 0.936654138507272], 
             UndirectedEdge[124, 295] -> 
             RGBColor[
              0.8924892919776035, 0.9168014387328876, 0.9788835440663946], 
             UndirectedEdge[166, 233] -> 
             RGBColor[
              0.9934058766223102, 0.9883041618002921, 0.5236485484298345], 
             UndirectedEdge[88, 290] -> 
             RGBColor[
              0.558574938782711, 0.6525153246748602, 0.9583922117898461], 
             UndirectedEdge[134, 235] -> 
             RGBColor[
              0.2580199713754525, 0.388525727699626, 0.9380052277122666], 
             UndirectedEdge[185, 239] -> 
             RGBColor[
              0.4896022864326819, 0.5953748312271646, 0.9532789058066227], 
             UndirectedEdge[260, 278] -> 
             RGBColor[
              0.7260426453881705, 0.7855410894217181, 0.9736791816363508], 
             UndirectedEdge[15, 242] -> 
             RGBColor[
              0.23967759230185604`, 0.3692467243192726, 0.9369606563591433], 
             UndirectedEdge[4, 266] -> 
             RGBColor[
              0.3936273469724733, 0.5073684085563466, 0.9471569136064277], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.2455681044594148, 0.3754380260769088, 0.9372961123122845], 
             UndirectedEdge[3, 123] -> 
             RGBColor[
              0.40677277394875433`, 0.5267478646254944, 0.9471401793543419], 
             UndirectedEdge[28, 184] -> 
             RGBColor[
              0.23042487690337662`, 0.35952153377943086`, 0.9364337279053656],
              UndirectedEdge[116, 210] -> 
             RGBColor[
              0.35048246477995726`, 0.4779920280566848, 0.9435534106296721], 
             UndirectedEdge[118, 120] -> 
             RGBColor[
              0.1844220718220619, 0.3111696688926636, 0.9338139362110361], 
             UndirectedEdge[15, 89] -> 
             RGBColor[
              0.2585276184343561, 0.3890592969452162, 0.9380341374612745], 
             UndirectedEdge[11, 283] -> 
             RGBColor[
              0.4811144650373824, 0.586647763865455, 0.9531180807234778], 
             UndirectedEdge[157, 201] -> 
             RGBColor[
              0.3335467378743898, 0.46332315262546664`, 0.9424742810869247], 
             UndirectedEdge[196, 279] -> 
             RGBColor[
              0.2698625176179148, 0.40097299466125325`, 0.9386796432012976], 
             UndirectedEdge[7, 11] -> 
             RGBColor[
              0.36912627592496833`, 0.4941403602052988, 0.9447413777897574], 
             UndirectedEdge[76, 284] -> 
             RGBColor[
              0.2749699198453155, 0.406341198230256, 0.9389705022024235], 
             UndirectedEdge[34, 108] -> 
             RGBColor[
              0.3357098066332535, 0.46519669406539743`, 0.9426121099155129], 
             UndirectedEdge[46, 213] -> 
             RGBColor[
              0.3600084250820952, 0.48470742468786476`, 0.9442166189906656], 
             UndirectedEdge[261, 278] -> 
             RGBColor[
              0.5017864477209948, 0.6049815757231856, 0.9543168081378697], 
             UndirectedEdge[58, 66] -> 
             RGBColor[
              0.747689528345485, 0.802133526636196, 0.966576403949817], 
             UndirectedEdge[194, 297] -> 
             RGBColor[
              0.6381161089486057, 0.715282207212687, 0.9658902758041552], 
             UndirectedEdge[283, 297] -> 
             RGBColor[
              0.6895610790338994, 0.7570475514974199, 0.9699402122984042], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.23660390230659725`, 0.366016081251054, 0.9367856142610302], 
             UndirectedEdge[6, 169] -> 
             RGBColor[
              0.299349056442051, 0.4319652165199622, 0.940358857965907], 
             UndirectedEdge[11, 172] -> 
             RGBColor[
              0.3065006008708423, 0.43626816207492447`, 0.9408838001095725], 
             UndirectedEdge[4, 82] -> 
             RGBColor[
              0.7673487077991381, 0.8145026420959148, 0.8312023909866153], 
             UndirectedEdge[140, 230] -> 
             RGBColor[
              0.2887130988150164, 0.4189991437957653, 0.9398185869899978], 
             UndirectedEdge[207, 232] -> 
             RGBColor[
              0.8698424070552139, 0.8954799573196557, 0.7870499702431855], 
             UndirectedEdge[147, 244] -> 
             RGBColor[
              0.23435191313774276`, 0.3636490978502278, 0.9366573668093834], 
             UndirectedEdge[56, 296] -> 
             RGBColor[
              0.6219639893106997, 0.70315209105388, 0.9639467061714042], 
             UndirectedEdge[243, 294] -> 
             RGBColor[
              0.21403208469402601`, 0.34229166980434655`, 0.935500182640006], 
             UndirectedEdge[211, 216] -> 
             RGBColor[
              0.2505986099544608, 0.38072540630467244`, 0.9375825921582613], 
             UndirectedEdge[107, 141] -> 
             RGBColor[
              0.8665747340462209, 0.44887503543921714`, 0.2088850184887606], 
             UndirectedEdge[19, 175] -> 
             RGBColor[
              0.2928891684678705, 0.42517546467854467`, 0.9399909769023254], 
             UndirectedEdge[17, 158] -> 
             RGBColor[
              0.34992722478314753`, 0.47635321406760484`, 0.9435604273632674],
              UndirectedEdge[115, 242] -> 
             RGBColor[
              0.23101187459031025`, 0.36013850556620103`, 0.9364671565552513],
              UndirectedEdge[159, 292] -> 
             RGBColor[
              0.24522762221879252`, 0.3750801576541939, 0.9372767223523794], 
             UndirectedEdge[34, 205] -> 
             RGBColor[
              0.4284730033611293, 0.5434764368944227, 0.9490940379758643], 
             UndirectedEdge[23, 180] -> 
             RGBColor[
              0.26520012614906696`, 0.3960725256148013, 0.9384141269045367], 
             UndirectedEdge[47, 158] -> 
             RGBColor[
              0.5238459246822951, 0.6229456026619612, 0.9560487873803941], 
             UndirectedEdge[130, 199] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[112, 204] -> 
             RGBColor[
              0.24154807064065673`, 0.37121271564852854`, 0.9370671773334133],
              UndirectedEdge[217, 247] -> 
             RGBColor[
              0.6930619732704799, 0.7591753208357144, 0.9707042644868367], 
             UndirectedEdge[102, 185] -> 
             RGBColor[
              0.4766965463107896, 0.5841965277949407, 0.9524565634581535], 
             UndirectedEdge[136, 137] -> 
             RGBColor[
              0.9192369381421535, 0.6692429774694144, 0.3303446825263339], 
             UndirectedEdge[138, 258] -> 
             RGBColor[
              0.8342254690641332, 0.8708963005189276, 0.9605009609416519], 
             UndirectedEdge[79, 277] -> 
             RGBColor[
              0.3720129129755694, 0.49664062013193266`, 0.9449253117500688], 
             UndirectedEdge[41, 259] -> 
             RGBColor[
              0.41062581045850305`, 0.5297880471701207, 0.9474677876858852], 
             UndirectedEdge[225, 287] -> 
             RGBColor[
              0.950968932525843, 0.8418366498372989, 0.2871069008798047], 
             UndirectedEdge[167, 194] -> 
             RGBColor[
              0.6348798248522232, 0.7127539974799229, 0.9655677132502221], 
             UndirectedEdge[64, 219] -> 
             RGBColor[
              0.2539451972290641, 0.384242881716169, 0.9377731753527179], 
             UndirectedEdge[83, 293] -> 
             RGBColor[
              0.21277489873276917`, 0.34097028764887183`, 0.9354285877593523],
              UndirectedEdge[31, 95] -> 
             RGBColor[
              0.5537416162054588, 0.648591415667946, 0.9580117149315208], 
             UndirectedEdge[256, 299] -> 
             RGBColor[
              0.994866261560722, 0.9921157286857396, 0.7326092241840025], 
             UndirectedEdge[129, 269] -> 
             RGBColor[
              0.23146736458154496`, 0.36061725442672216`, 0.9364930960364151],
              UndirectedEdge[83, 126] -> 
             RGBColor[
              0.22111352999763184`, 0.3497347178080009, 0.9359034604739869], 
             UndirectedEdge[23, 81] -> 
             RGBColor[
              0.29610769611833376`, 0.428558341305621, 0.9401742672906341], 
             UndirectedEdge[235, 252] -> 
             RGBColor[
              0.2712852344852127, 0.40246836029424277`, 0.9387606648221691], 
             UndirectedEdge[6, 264] -> 
             RGBColor[
              0.3001671802617, 0.4328251165264595, 0.9404054489071303], 
             UndirectedEdge[167, 215] -> 
             RGBColor[
              0.874514844691243, 0.8999677108189541, 0.8534618509904951], 
             UndirectedEdge[273, 285] -> 
             RGBColor[
              0.5003032179944051, 0.6032922095966846, 0.9543341087730001], 
             UndirectedEdge[267, 273] -> 
             RGBColor[
              0.5428411676276441, 0.6397419404528637, 0.9571535916898165], 
             UndirectedEdge[66, 109] -> 
             RGBColor[
              0.9338122663322416, 0.9497831796189251, 0.9839317503863134], 
             UndirectedEdge[104, 173] -> 
             RGBColor[
              0.2711227338075005, 0.40229756177882925`, 0.9387514106489717], 
             UndirectedEdge[9, 185] -> 
             RGBColor[
              0.5424499772884093, 0.6394243545125489, 0.9571227957533345], 
             UndirectedEdge[233, 288] -> 
             RGBColor[
              0.9279948066453856, 0.7277856301692169, 0.40221351612468526`], 
             UndirectedEdge[139, 147] -> 
             RGBColor[
              0.2408356632285271, 0.3704639302891415, 0.9370266067852049], 
             UndirectedEdge[65, 103] -> 
             RGBColor[
              0.2833667383517215, 0.41516678686953135`, 0.9394486885943836], 
             UndirectedEdge[33, 124] -> 
             RGBColor[
              0.931178231225007, 0.9476509487054876, 0.9825737296298357], 
             UndirectedEdge[82, 226] -> 
             RGBColor[
              0.5870018429473699, 0.648635921384999, 0.8195028573655392], 
             UndirectedEdge[6, 221] -> 
             RGBColor[
              0.3001432088118318, 0.4327999210127703, 0.9404040837685228], 
             UndirectedEdge[125, 136] -> 
             RGBColor[
              0.9927664178883965, 0.9869364242276462, 0.4540474115251879], 
             UndirectedEdge[112, 292] -> 
             RGBColor[
              0.24763746869084696`, 0.3776130590894144, 0.9374139595439145], 
             UndirectedEdge[58, 67] -> 
             RGBColor[
              0.7306207568349073, 0.7888007417215468, 0.9745656605578148], 
             UndirectedEdge[73, 105] -> 
             RGBColor[
              0.30909022810020703`, 0.4403302488400713, 0.9409822033703782], 
             UndirectedEdge[263, 298] -> 
             RGBColor[
              0.27311782288011394`, 0.40439452689009914`, 0.9388650280201871],
              UndirectedEdge[60, 170] -> 
             RGBColor[
              0.8739879445842015, 0.4569683614322223, 0.21399044815056695`], 
             UndirectedEdge[10, 129] -> 
             RGBColor[
              0.22367111540675327`, 0.3524229022332684, 0.9360491111794278], 
             UndirectedEdge[53, 234] -> 
             RGBColor[
              0.8245240597604586, 0.18950824659620397`, 0.17111757336356628`],
              UndirectedEdge[51, 154] -> 
             RGBColor[
              0.867381103025232, 0.8946780960164662, 0.8655976857489563], 
             UndirectedEdge[17, 84] -> 
             RGBColor[
              0.2984201886260963, 0.4309889175517728, 0.9403059603179251], 
             UndirectedEdge[98, 160] -> 
             RGBColor[
              0.5065135948101279, 0.6094211404266363, 0.9545226524909898], 
             UndirectedEdge[25, 147] -> 
             RGBColor[
              0.2390014851721345, 0.36853609285826733`, 0.9369221530583165], 
             UndirectedEdge[159, 204] -> 
             RGBColor[
              0.23913822416860225`, 0.3686798142133081, 0.9369299401418781], 
             UndirectedEdge[37, 94] -> 
             RGBColor[
              0.771325946499076, 0.8216241472491855, 0.9777522097744586], 
             UndirectedEdge[37, 283] -> 
             RGBColor[
              0.6497129501444403, 0.725917890351978, 0.9659685232126394], 
             UndirectedEdge[9, 142] -> 
             RGBColor[
              0.5879267021753338, 0.6760891257694337, 0.9608774283058292], 
             UndirectedEdge[51, 109] -> 
             RGBColor[
              0.9573653906056103, 0.9657923433051386, 0.8743494495449171], 
             UndirectedEdge[123, 257] -> 
             RGBColor[
              0.41376298296839165`, 0.5328024323401832, 0.9475855892918741], 
             UndirectedEdge[212, 294] -> 
             RGBColor[
              0.2108091766010912, 0.3389041890544966, 0.9353166427919786], 
             UndirectedEdge[237, 297] -> 
             RGBColor[
              0.6995891698942603, 0.7651888074182058, 0.970729660345039], 
             UndirectedEdge[163, 197] -> 
             RGBColor[
              0.22592979758927967`, 0.35479692041582533`, 0.9361777397883018],
              UndirectedEdge[76, 229] -> 
             RGBColor[
              0.32034218545595194`, 0.4505499966670069, 0.9416818175180619], 
             UndirectedEdge[18, 24] -> 
             RGBColor[
              0.9510187529148094, 0.9629904466400717, 0.9677966543467089], 
             UndirectedEdge[44, 124] -> 
             RGBColor[
              0.9563745344888678, 0.9271480240205534, 0.6460858270481826], 
             UndirectedEdge[26, 82] -> 
             RGBColor[
              0.9904558326619474, 0.9901441252350094, 0.7949595618585049], 
             UndirectedEdge[7, 106] -> 
             RGBColor[
              0.5257077598802015, 0.6240227140594248, 0.9563940779093657], 
             UndirectedEdge[53, 255] -> 
             RGBColor[
              0.8953417281167521, 0.5590474871616122, 0.23653146249449708`], 
             UndirectedEdge[89, 242] -> 
             RGBColor[
              0.2592824308416344, 0.3898526526431364, 0.9380771229112241], 
             UndirectedEdge[121, 181] -> 
             RGBColor[
              0.8542136005503994, 0.8836192586014792, 0.8134168223712162], 
             UndirectedEdge[217, 273] -> 
             RGBColor[
              0.7124353943152881, 0.7749035368025619, 0.9722294111586636], 
             UndirectedEdge[141, 240] -> 
             RGBColor[
              0.9469680026152082, 0.812923621050152, 0.46368241218848416`], 
             UndirectedEdge[42, 159] -> 
             RGBColor[
              0.2509157891435835, 0.3810587817427625, 0.9376006550438574], 
             UndirectedEdge[51, 52] -> 
             RGBColor[
              0.9056350707482277, 0.5643614773610739, 0.4604731703909181], 
             UndirectedEdge[170, 225] -> 
             RGBColor[
              0.8914281470596066, 0.5246344158422436, 0.23572348923178596`], 
             UndirectedEdge[51, 179] -> 
             RGBColor[
              0.993604348606093, 0.9916232480349453, 0.7556560252196713], 
             UndirectedEdge[36, 198] -> 
             RGBColor[
              0.6119133130274254, 0.6940222772779814, 0.9638188261918845], 
             UndirectedEdge[150, 295] -> 
             RGBColor[
              0.8996455406863472, 0.9221385573025866, 0.9667698816510785], 
             UndirectedEdge[140, 196] -> 
             RGBColor[
              0.304503216827514, 0.4355955589782061, 0.9407178108514234], 
             UndirectedEdge[31, 73] -> 
             RGBColor[
              0.47392342433375345`, 0.580416161461158, 0.9526607261917457], 
             UndirectedEdge[188, 212] -> 
             RGBColor[
              0.20871789165381538`, 0.33670611597978567`, 0.9351975472080101],
              UndirectedEdge[172, 244] -> 
             RGBColor[
              0.2560033039447505, 0.38640608236585794`, 0.9378903814854801], 
             UndirectedEdge[7, 63] -> 
             RGBColor[
              0.3596300201933831, 0.4859151807862907, 0.94413628477175], 
             UndirectedEdge[128, 218] -> 
             RGBColor[
              0.24765166805898178`, 0.377627983525616, 0.9374147681769237], 
             UndirectedEdge[138, 154] -> 
             RGBColor[
              0.7239419932746806, 0.7842682543998942, 0.9731194303332016], 
             UndirectedEdge[1, 297] -> 
             RGBColor[
              0.5894608456272148, 0.6748368975635395, 0.9623209993901465], 
             UndirectedEdge[90, 123] -> 
             RGBColor[
              0.4198835569183708, 0.5381037658666636, 0.9479755868517558], 
             UndirectedEdge[8, 61] -> 
             RGBColor[
              0.6093443388632377, 0.6935868317074125, 0.9624883614152353], 
             UndirectedEdge[201, 209] -> 
             RGBColor[
              0.29313467956513195`, 0.424290095199951, 0.9400468245012701], 
             UndirectedEdge[44, 94] -> 
             RGBColor[
              0.9135021931703009, 0.8932720957781641, 0.6527207002692943], 
             UndirectedEdge[114, 213] -> 
             RGBColor[
              0.366144956508927, 0.49115730829602955`, 0.944566085377239], 
             UndirectedEdge[82, 107] -> 
             RGBColor[
              0.9146118486409361, 0.6276761900982359, 0.44291862332296067`], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.27309540824899353`, 0.40437096769162195`, 0.9388637515401044],
              UndirectedEdge[182, 268] -> 
             RGBColor[
              0.28484973208731645`, 0.4167255073128753, 0.939533142893733], 
             UndirectedEdge[157, 229] -> 
             RGBColor[
              0.34618459391463335`, 0.47426942833041186`, 0.9432795540985917],
              UndirectedEdge[99, 157] -> 
             RGBColor[
              0.35673441532730565`, 0.48340715338862666`, 0.9439517793901664],
              UndirectedEdge[249, 288] -> 
             RGBColor[
              0.8402405410776118, 0.30481319511588134`, 0.18595237386054825`],
              UndirectedEdge[66, 138] -> 
             RGBColor[
              0.8265698887797728, 0.8651867812777139, 0.9734598614679548], 
             UndirectedEdge[215, 286] -> 
             RGBColor[
              0.7770695489362254, 0.8225663010665949, 0.8446220990398039], 
             UndirectedEdge[83, 275] -> 
             RGBColor[
              0.214533530595458, 0.34281872124025803`, 0.9355287392422698], 
             UndirectedEdge[95, 289] -> 
             RGBColor[
              0.38981488785686436`, 0.5094582582673273, 0.9463848141152024], 
             UndirectedEdge[37, 75] -> 
             RGBColor[
              0.7056075851299448, 0.7699452754105638, 0.9712920278741198], 
             UndirectedEdge[88, 260] -> 
             RGBColor[
              0.6766874696871867, 0.7454723343623321, 0.9697937614112038], 
             UndirectedEdge[60, 82] -> 
             RGBColor[
              0.9605795624965958, 0.8682632028416796, 0.48244356084256446`], 
             UndirectedEdge[50, 227] -> 
             RGBColor[
              0.30610711869793783`, 0.43502772299278125`, 0.9408916674370189],
              UndirectedEdge[12, 248] -> 
             RGBColor[
              0.20494626266410096`, 0.3327418947765061, 0.9349827585166709], 
             UndirectedEdge[103, 164] -> 
             RGBColor[
              0.33137057382359575`, 0.4586711168930102, 0.9424369368208644], 
             UndirectedEdge[127, 228] -> 
             RGBColor[
              0.8245576688190998, 0.5546795352500253, 0.5806725121570179], 
             UndirectedEdge[163, 184] -> 
             RGBColor[
              0.23939823162616325`, 0.3689530985366296, 0.9369447471819397], 
             UndirectedEdge[11, 183] -> 
             RGBColor[
              0.29904764600234657`, 0.4284346339635039, 0.9404593653554703], 
             UndirectedEdge[226, 266] -> 
             RGBColor[
              0.21328048212070516`, 0.3415016878454308, 0.9354573799853517], 
             UndirectedEdge[98, 178] -> 
             RGBColor[
              0.34993177355877136`, 0.4745851224813026, 0.9436255999612144], 
             UndirectedEdge[200, 255] -> 
             RGBColor[
              0.9224751483252943, 0.7242107930884344, 0.2608151757752228], 
             UndirectedEdge[223, 234] -> 
             RGBColor[
              0.852336886710356, 0.35775657985604403`, 0.19596820028306192`], 
             UndirectedEdge[111, 190] -> 
             RGBColor[
              0.2355732429285669, 0.36493279289716524`, 0.9367269197341752], 
             UndirectedEdge[85, 181] -> 
             RGBColor[
              0.8167213708728744, 0.8575535758044224, 0.9821530921197811], 
             UndirectedEdge[57, 134] -> 
             RGBColor[
              0.26052687456490653`, 0.3911606418985847, 0.938147992140275], 
             UndirectedEdge[9, 131] -> 
             RGBColor[
              0.4208304337263501, 0.5371994126346513, 0.9485124028214329], 
             UndirectedEdge[184, 189] -> 
             RGBColor[
              0.2346427787554684, 0.3639548160564028, 0.9366739311760157], 
             UndirectedEdge[194, 286] -> 
             RGBColor[
              0.5374345290972057, 0.6353525877275636, 0.9567279612995309], 
             UndirectedEdge[171, 298] -> 
             RGBColor[
              0.35180269388930685`, 0.47696337077533185`, 0.9437170683691549],
              UndirectedEdge[108, 213] -> 
             RGBColor[
              0.3858995717541348, 0.5086685460021616, 0.9458101573679487], 
             UndirectedEdge[158, 175] -> 
             RGBColor[
              0.34907161965836087`, 0.47545391883295585`, 0.9435117019171652],
              UndirectedEdge[37, 297] -> 
             RGBColor[
              0.7205508998101146, 0.7816191064121104, 0.9727814378282238], 
             UndirectedEdge[68, 234] -> 
             RGBColor[
              0.8458426087622819, 0.3282675804709904, 0.19054921557386956`], 
             UndirectedEdge[38, 252] -> 
             RGBColor[
              0.3592377978575069, 0.4848159523446023, 0.9441391019160659], 
             UndirectedEdge[42, 252] -> 
             RGBColor[
              0.2774845709652012, 0.40898425599534566`, 0.939113707863608], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.2625645345612948, 0.39330235174989453`, 0.9382640338626215], 
             UndirectedEdge[184, 216] -> 
             RGBColor[
              0.24813752757352578`, 0.3781386526806742, 0.9374424371575123], 
             UndirectedEdge[16, 59] -> 
             RGBColor[
              0.9131402588168656, 0.620820449672156, 0.3548598720778012], 
             UndirectedEdge[7, 185] -> 
             RGBColor[
              0.4814085254761833, 0.5882778073170456, 0.9527568066039329], 
             UndirectedEdge[127, 299] -> 
             RGBColor[
              0.9136283213475775, 0.6224467453485296, 0.4600423723683357], 
             UndirectedEdge[166, 217] -> 
             RGBColor[
              0.899879476841495, 0.9180128953290518, 0.7153753712159427], 
             UndirectedEdge[101, 207] -> 
             RGBColor[
              0.6460892652174881, 0.7219820565313749, 0.9663628314965813], 
             UndirectedEdge[14, 69] -> 
             RGBColor[
              0.907867854492874, 0.581493687303205, 0.3264885443906257], 
             UndirectedEdge[51, 107] -> 
             RGBColor[
              0.9138545722061537, 0.6275401673751994, 0.4683441742696273], 
             UndirectedEdge[74, 233] -> 
             RGBColor[
              0.8161512863791258, 0.8534670921405562, 0.7813047425304152], 
             UndirectedEdge[158, 252] -> 
             RGBColor[
              0.35208167801260865`, 0.47861768101199287`, 0.9436831202874573],
              UndirectedEdge[86, 110] -> 
             RGBColor[
              0.9839067857429666, 0.9591178157514064, 0.561716366031505], 
             UndirectedEdge[58, 73] -> 
             RGBColor[
              0.4389666532110068, 0.5520366798791193, 0.9499088011180912], 
             UndirectedEdge[13, 96] -> 
             RGBColor[
              0.3557971492753504, 0.4823533245061042, 0.9439009190224369], 
             UndirectedEdge[16, 53] -> 
             RGBColor[
              0.9125997408169637, 0.6166657914684119, 0.3543422714306673], 
             UndirectedEdge[44, 170] -> 
             RGBColor[
              0.8934743520557873, 0.5315367457661417, 0.24367260924855771`], 
             UndirectedEdge[27, 32] -> 
             RGBColor[
              0.25734797909016266`, 0.3878194212010146, 0.9379669587457427], 
             UndirectedEdge[116, 164] -> 
             RGBColor[
              0.35316605540790247`, 0.4803164193774241, 0.9437244066514788], 
             UndirectedEdge[70, 300] -> 
             RGBColor[
              0.2600472811884571, 0.39065655885195993`, 0.938120680006981], 
             UndirectedEdge[79, 116] -> 
             RGBColor[
              0.3586693068574145, 0.48508305918153105`, 0.9440750689675076], 
             UndirectedEdge[137, 195] -> 
             RGBColor[
              0.8323549819999152, 0.24970014646067296`, 0.17861647334383152`],
              UndirectedEdge[156, 214] -> 
             RGBColor[
              0.2202905707839606, 0.3488697354958046, 0.9358565941642273], 
             UndirectedEdge[14, 249] -> 
             RGBColor[
              0.8206388339044841, 0.15964469815035803`, 0.16739707669615012`],
              UndirectedEdge[84, 89] -> 
             RGBColor[
              0.2893752204809355, 0.4214820825471055, 0.9397908627628895], 
             UndirectedEdge[98, 246] -> 
             RGBColor[
              0.5108375562883921, 0.6129315271469358, 0.9548630505777516], 
             UndirectedEdge[4, 107] -> 
             RGBColor[
              0.6868838807668163, 0.45030100016757835`, 0.5686163001605958], 
             UndirectedEdge[20, 295] -> 
             RGBColor[
              0.851595317593189, 0.8845030065824513, 0.9857071156917947], 
             UndirectedEdge[57, 175] -> 
             RGBColor[
              0.27078207932041887`, 0.40193951231416447`, 0.9387320108798856],
              UndirectedEdge[93, 160] -> 
             RGBColor[
              0.5607147225279772, 0.6542524975154264, 0.9585606634045596], 
             UndirectedEdge[13, 149] -> 
             RGBColor[
              0.30003867844943893`, 0.43269005297428764`, 0.9403981309190235],
              UndirectedEdge[230, 298] -> 
             RGBColor[
              0.2673021323723527, 0.39828186743036675`, 0.9385338330493134], 
             UndirectedEdge[96, 198] -> 
             RGBColor[
              0.43486063371890193`, 0.5507791821456584, 0.9490119679848132], 
             UndirectedEdge[32, 182] -> 
             RGBColor[
              0.2817202883828383, 0.4134362635612778, 0.9393549257043601], 
             UndirectedEdge[80, 241] -> 
             RGBColor[
              0.27345259705009906`, 0.4047463957686619, 0.938884092913914], 
             UndirectedEdge[55, 292] -> 
             RGBColor[
              0.25987815555668636`, 0.39047879708978456`, 0.9381110485524506],
              UndirectedEdge[121, 160] -> 
             RGBColor[
              0.7924150587076538, 0.8345430649548763, 0.8078033989134862], 
             UndirectedEdge[62, 220] -> 
             RGBColor[
              0.6260202363274255, 0.6895227449727015, 0.8093263410054259], 
             UndirectedEdge[28, 189] -> 
             RGBColor[
              0.22763054758381063`, 0.35658451649385525`, 0.9362745949844562],
              UndirectedEdge[25, 91] -> 
             RGBColor[
              0.2622113968861681, 0.3929311816631146, 0.9382439231944433], 
             UndirectedEdge[41, 99] -> 
             RGBColor[
              0.362239582391498, 0.48817545240188814`, 0.9443025637674687], 
             UndirectedEdge[148, 206] -> 
             RGBColor[
              0.23774362795226284`, 0.3672140051674282, 0.9368505199504779], 
             UndirectedEdge[3, 90] -> 
             RGBColor[
              0.39043568607657597`, 0.5125975002365252, 0.9460991945614463], 
             UndirectedEdge[99, 104] -> 
             RGBColor[
              0.3262801186675095, 0.4548403348152493, 0.9420914025992604], 
             UndirectedEdge[193, 266] -> 
             RGBColor[
              0.3235658537972168, 0.4490279862889558, 0.942045190438874], 
             UndirectedEdge[275, 293] -> 
             RGBColor[
              0.21101994270665328`, 0.33912571759478527`, 0.9353286456098898],
              UndirectedEdge[229, 257] -> 
             RGBColor[
              0.3688470358646546, 0.49389849650006856`, 0.9447235848600365], 
             UndirectedEdge[90, 144] -> 
             RGBColor[
              0.35962797975699734`, 0.48591341346284866`, 0.9441361547569478],
              UndirectedEdge[49, 115] -> 
             RGBColor[
              0.22907293102325943`, 0.358100552941108, 0.9363567365875176], 
             UndirectedEdge[77, 244] -> 
             RGBColor[
              0.2442718082387917, 0.3740755365591065, 0.9372222901602183], 
             UndirectedEdge[66, 95] -> 
             RGBColor[
              0.7175511909941827, 0.7776658666577836, 0.9642038036331552], 
             UndirectedEdge[94, 125] -> 
             RGBColor[
              0.9272871440372241, 0.9396965749731525, 0.7126838428267497], 
             UndirectedEdge[196, 230] -> 
             RGBColor[
              0.2651423022333762, 0.39601174901316233`, 0.938410833918081], 
             UndirectedEdge[138, 245] -> 
             RGBColor[
              0.5655432626553039, 0.6564020281299278, 0.9598314214470098], 
             UndirectedEdge[100, 127] -> 
             RGBColor[
              0.8414762129232649, 0.3198099242864162, 0.18735097437698822`], 
             UndirectedEdge[24, 288] -> 
             RGBColor[
              0.9087689498125788, 0.7161208029301624, 0.5832293866647026], 
             UndirectedEdge[224, 258] -> 
             RGBColor[
              0.9656458741337097, 0.9399341707856219, 0.6428561562394914], 
             UndirectedEdge[25, 203] -> 
             RGBColor[
              0.2557021473412196, 0.3860895476811155, 0.9378732310624303], 
             UndirectedEdge[143, 239] -> 
             RGBColor[
              0.4039421601527854, 0.5242961292262122, 0.9469598151462764], 
             UndirectedEdge[142, 282] -> 
             RGBColor[
              0.8113403946734408, 0.8529848446549176, 0.9565261589007614], 
             UndirectedEdge[57, 242] -> 
             RGBColor[
              0.24374269016754463`, 0.3735193999182025, 0.9371921576688209], 
             UndirectedEdge[47, 177] -> 
             RGBColor[
              0.5316337139639098, 0.6296909943120255, 0.956545018426947], 
             UndirectedEdge[43, 174] -> 
             RGBColor[
              0.35724861486395953`, 0.48385252718285615`, 0.9439845437299532],
              UndirectedEdge[5, 29] -> 
             RGBColor[
              0.23189096279390453`, 0.36106248300558996`, 0.9365172193279515],
              UndirectedEdge[167, 282] -> 
             RGBColor[
              0.8587917501354356, 0.8900542041854869, 0.9612556665550847], 
             UndirectedEdge[131, 172] -> 
             RGBColor[
              0.297163306859998, 0.4281806673087738, 0.9402888359918464], 
             UndirectedEdge[21, 101] -> 
             RGBColor[
              0.4650224715635836, 0.5746682645420044, 0.9515515525742121], 
             UndirectedEdge[251, 300] -> 
             RGBColor[
              0.27128730129384493`, 0.40247053264115845`, 0.9387607825238632],
              UndirectedEdge[75, 167] -> 
             RGBColor[
              0.7422194299230214, 0.7985467268232416, 0.9749411544059516], 
             UndirectedEdge[165, 281] -> 
             RGBColor[
              0.9081683799556731, 0.6116901368011833, 0.2799978889278235], 
             UndirectedEdge[63, 174] -> 
             RGBColor[
              0.35841838866408615`, 0.48486572645398507`, 0.944059080682107], 
             UndirectedEdge[64, 211] -> 
             RGBColor[
              0.238007335368493, 0.36749117838190204`, 0.936865537697712], 
             UndirectedEdge[124, 237] -> 
             RGBColor[
              0.7932365579017887, 0.8390697764976703, 0.9690655590701622], 
             UndirectedEdge[127, 192] -> 
             RGBColor[
              0.8488791161434632, 0.3663608331165159, 0.19403468172993021`], 
             UndirectedEdge[62, 228] -> 
             RGBColor[
              0.90559598823519, 0.9239215498870947, 0.8315118721300905], 
             UndirectedEdge[152, 277] -> 
             RGBColor[
              0.3011955804505697, 0.43017548464198757`, 0.9406006083286469], 
             UndirectedEdge[76, 157] -> 
             RGBColor[
              0.3201380287875101, 0.4503731664220151, 0.9416688088356775], 
             UndirectedEdge[106, 297] -> 
             RGBColor[
              0.7085338986582898, 0.7722313337797134, 0.9715836954586705], 
             UndirectedEdge[91, 203] -> 
             RGBColor[
              0.2661031933042482, 0.39702170645266144`, 0.9384655552430561], 
             UndirectedEdge[215, 271] -> 
             RGBColor[
              0.9862840872732699, 0.9639445925953173, 0.5488858494022204], 
             UndirectedEdge[181, 296] -> 
             RGBColor[
              0.7050263286294778, 0.769491193414686, 0.9712340936583042], 
             UndirectedEdge[27, 119] -> 
             RGBColor[
              0.2703316084942079, 0.40146603891431676`, 0.9387063572327446], 
             UndirectedEdge[100, 170] -> 
             RGBColor[
              0.8360368854877944, 0.2780008700889096, 0.18214226828194], 
             UndirectedEdge[112, 115] -> 
             RGBColor[
              0.236902386747869, 0.36632980732383724`, 0.9368026125083924], 
             UndirectedEdge[75, 282] -> 
             RGBColor[
              0.8470847195516484, 0.8809085829167043, 0.9600888191549137], 
             UndirectedEdge[234, 255] -> 
             RGBColor[
              0.8881366683562935, 0.5036662405654082, 0.2296318891309308], 
             UndirectedEdge[29, 77] -> 
             RGBColor[
              0.2444276826034072, 0.3742393703993229, 0.9372311669746878], 
             UndirectedEdge[44, 192] -> 
             RGBColor[
              0.9150207009153106, 0.6868003754774932, 0.26390009611845466`], 
             UndirectedEdge[49, 57] -> 
             RGBColor[
              0.2418037466004938, 0.3714814472931095, 0.9370817377010874], 
             UndirectedEdge[4, 281] -> 
             RGBColor[
              0.6878485673408958, 0.45771600390430534`, 0.5695400851133919], 
             UndirectedEdge[23, 285] -> 
             RGBColor[
              0.33957273212272987`, 0.46739870088843105`, 0.9429001346157797],
              UndirectedEdge[86, 109] -> 
             RGBColor[
              0.9480181265878662, 0.9334317685964351, 0.674604431944415], 
             UndirectedEdge[276, 279] -> 
             RGBColor[
              0.24528708035805388`, 0.3751426519284214, 0.9372801084054498], 
             UndirectedEdge[139, 183] -> 
             RGBColor[
              0.2550340991670391, 0.38538738669335115`, 0.9378351867071995], 
             UndirectedEdge[234, 287] -> 
             RGBColor[
              0.8791470053904711, 0.46890980859888415`, 0.21779165603051126`],
              UndirectedEdge[160, 181] -> 
             RGBColor[
              0.6520185359229838, 0.7272823998054908, 0.9664968499202544], 
             UndirectedEdge[196, 298] -> 
             RGBColor[
              0.28309225038485036`, 0.4148782826128075, 0.9394330569107388], 
             UndirectedEdge[255, 287] -> 
             RGBColor[
              0.9499646737467646, 0.8384490491642924, 0.28320554516144203`], 
             UndirectedEdge[126, 216] -> 
             RGBColor[
              0.24238826022285348`, 0.3720958081705137, 0.9371150248871702], 
             UndirectedEdge[190, 212] -> 
             RGBColor[
              0.21992645288427248`, 0.3484870244968241, 0.9358358581885042], 
             UndirectedEdge[39, 137] -> 
             RGBColor[
              0.8565494590888623, 0.4213131070375924, 0.20122297160509353`], 
             UndirectedEdge[170, 195] -> 
             RGBColor[
              0.820518598671917, 0.15872051746543236`, 0.16728193930165758`], 
             UndirectedEdge[69, 288] -> 
             RGBColor[
              0.9274695616660017, 0.7266621842687284, 0.34504384155502377`], 
             UndirectedEdge[101, 231] -> 
             RGBColor[
              0.49585480302230733`, 0.6013736803735128, 0.9535161614708018], 
             UndirectedEdge[57, 253] -> 
             RGBColor[
              0.27188917324815276`, 0.40310313822602206`, 0.9387950582412713],
              UndirectedEdge[52, 266] -> 
             RGBColor[
              0.5326709863563452, 0.2573632665445422, 0.5510021420640641], 
             UndirectedEdge[28, 275] -> 
             RGBColor[
              0.21809561015053047`, 0.3465626927015274, 0.9357315944033067], 
             UndirectedEdge[4, 226] -> 
             RGBColor[
              0.35927387507325015`, 0.47126073145434144`, 0.9452005342031744],
              UndirectedEdge[104, 229] -> 
             RGBColor[
              0.3157302972548372, 0.4457026097570346, 0.9414191773076857], 
             UndirectedEdge[189, 293] -> 
             RGBColor[
              0.2205548801399334, 0.3491475413871131, 0.9358716461910392], 
             UndirectedEdge[155, 156] -> 
             RGBColor[
              0.22000089461836236`, 0.3485652674792311, 0.935840097535134], 
             UndirectedEdge[107, 281] -> 
             RGBColor[
              0.835111708182694, 0.27088955190662645`, 0.18125631744973736`], 
             UndirectedEdge[107, 240] -> 
             RGBColor[
              0.9145402901776019, 0.6275231337808342, 0.4351299261966648], 
             UndirectedEdge[13, 105] -> 
             RGBColor[
              0.29764935998569264`, 0.4301787277773499, 0.9402620627671929], 
             UndirectedEdge[96, 138] -> 
             RGBColor[
              0.5560749070471602, 0.6482010143955439, 0.959228106200197], 
             UndirectedEdge[254, 260] -> 
             RGBColor[
              0.870237845536556, 0.7409780985202714, 0.6082514586621423], 
             UndirectedEdge[120, 176] -> 
             RGBColor[
              0.18443322649941224`, 0.31118139316580623`, 0.9338145714534094],
              UndirectedEdge[59, 125] -> 
             RGBColor[
              0.9127176607588363, 0.6199165551572493, 0.3088626814342206], 
             UndirectedEdge[22, 267] -> 
             RGBColor[
              0.642613111904264, 0.7180602166534845, 0.966841075599027], 
             UndirectedEdge[28, 197] -> 
             RGBColor[
              0.21695644286649302`, 0.3453653556586265, 0.9356667205117277], 
             UndirectedEdge[245, 298] -> 
             RGBColor[
              0.35482735126592213`, 0.47958317697125596`, 0.9439097968625934],
              UndirectedEdge[193, 199] -> 
             RGBColor[
              0.28921237678725265`, 0.4129203038152378, 0.9400888107445714], 
             UndirectedEdge[22, 274] -> 
             RGBColor[
              0.8909772154370372, 0.8747143818458635, 0.6496575550294168], 
             UndirectedEdge[76, 201] -> 
             RGBColor[
              0.3077043294157084, 0.43960372096206174`, 0.9408765445063949], 
             UndirectedEdge[19, 158] -> 
             RGBColor[
              0.3474496051113486, 0.47374907870238386`, 0.9434193305882683], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.17948366008578914`, 0.30597908504445237`, 0.9335327009683809],
              UndirectedEdge[61, 267] -> 
             RGBColor[
              0.517343318582302, 0.6190416379328455, 0.9551463076112685], 
             UndirectedEdge[106, 283] -> 
             RGBColor[
              0.6376959489926155, 0.716530117719581, 0.9647707808430861], 
             UndirectedEdge[174, 283] -> 
             RGBColor[
              0.5055233087265141, 0.6077894774448256, 0.9546733906594562], 
             UndirectedEdge[19, 242] -> 
             RGBColor[
              0.26584977931499626`, 0.39675535228258274`, 0.9384511236912607],
              UndirectedEdge[125, 195] -> 
             RGBColor[
              0.9058844617461582, 0.5673935932189047, 0.3023192023426855], 
             UndirectedEdge[115, 159] -> 
             RGBColor[
              0.23449254027581456`, 0.3637969058886168, 0.9366653753168572], 
             UndirectedEdge[158, 177] -> 
             RGBColor[
              0.4114198455834537, 0.5307729245068593, 0.947436286649661], 
             UndirectedEdge[42, 134] -> 
             RGBColor[
              0.26421930785544107`, 0.3950416234007289, 0.9383582707537054], 
             UndirectedEdge[165, 179] -> 
             RGBColor[
              0.986953469781533, 0.9683582137242022, 0.5663859549250714], 
             UndirectedEdge[108, 145] -> 
             RGBColor[
              0.3065621353882716, 0.43629450439653, 0.9408887080179298], 
             UndirectedEdge[44, 125] -> 
             RGBColor[
              0.9788402151300284, 0.9402098215196141, 0.37870987228958564`], 
             UndirectedEdge[39, 141] -> 
             RGBColor[
              0.8832675790785431, 0.5628271647927903, 0.22430794542071705`], 
             UndirectedEdge[50, 87] -> 
             RGBColor[
              0.314278172622923, 0.4436160187426821, 0.9413569968700557], 
             UndirectedEdge[26, 226] -> 
             RGBColor[
              0.5823809999360594, 0.646902214593436, 0.908957705075064], 
             UndirectedEdge[9, 143] -> 
             RGBColor[
              0.4567898510085129, 0.5683456525115964, 0.9508037050929882], 
             UndirectedEdge[136, 299] -> 
             RGBColor[
              0.9936961088777931, 0.9896128904175391, 0.6052453259924624], 
             UndirectedEdge[134, 144] -> 
             RGBColor[
              0.29485513198583013`, 0.42659799471298, 0.9401265091035182], 
             UndirectedEdge[240, 281] -> 
             RGBColor[
              0.9155049767516813, 0.6349381375175613, 0.436053711149461], 
             UndirectedEdge[257, 261] -> 
             RGBColor[
              0.39597335276996437`, 0.5173939487951174, 0.9464520497863826], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.27383547980684575`, 0.4051488298221716, 0.9389058975204863], 
             UndirectedEdge[135, 254] -> 
             RGBColor[
              0.940708824154274, 0.7947861767157479, 0.5224157389136257], 
             UndirectedEdge[14, 224] -> 
             RGBColor[
              0.8961112066597844, 0.5421659440515132, 0.2527391724419306], 
             UndirectedEdge[96, 289] -> 
             RGBColor[
              0.3482245893870246, 0.47439408393544596`, 0.9434696729393952], 
             UndirectedEdge[92, 189] -> 
             RGBColor[
              0.2464728493758267, 0.3763889703481986, 0.937347636196824], 
             UndirectedEdge[107, 127] -> 
             RGBColor[
              0.8334595581640123, 0.25819040288628525`, 0.17967421672601133`],
              UndirectedEdge[172, 270] -> 
             RGBColor[
              0.24887539777286288`, 0.3789142010438502, 0.9374844577737833], 
             UndirectedEdge[48, 84] -> 
             RGBColor[
              0.35715044434118537`, 0.4830160061947183, 0.9440058041437522], 
             UndirectedEdge[149, 289] -> 
             RGBColor[
              0.29246611856111315`, 0.4247308124036294, 0.9399668848359817], 
             UndirectedEdge[1, 102] -> 
             RGBColor[
              0.40192272768373283`, 0.5225469983211459, 0.9468311386950623], 
             UndirectedEdge[33, 297] -> 
             RGBColor[
              0.8375308432174786, 0.8737699796260231, 0.9842378309047126], 
             UndirectedEdge[18, 135] -> 
             RGBColor[
              0.9682482286960121, 0.9748593362633335, 0.8947082894518925], 
             UndirectedEdge[60, 137] -> 
             RGBColor[
              0.8858243279121996, 0.5479479904274629, 0.22532498219274089`], 
             UndirectedEdge[156, 208] -> 
             RGBColor[
              0.2568293808226203, 0.38727434154079826`, 0.9379374253416035], 
             UndirectedEdge[104, 279] -> 
             RGBColor[
              0.27193222945827744`, 0.4031483930327844, 0.9387975102287419], 
             UndirectedEdge[74, 158] -> 
             RGBColor[
              0.5209230649967003, 0.6205987474764012, 0.9558008759103712], 
             UndirectedEdge[80, 277] -> 
             RGBColor[
              0.30846241772387, 0.4378133913603206, 0.9410144439610391], 
             UndirectedEdge[223, 291] -> 
             RGBColor[
              0.8526313936469496, 0.36002028922446494`, 0.19625022045814194`],
              UndirectedEdge[114, 264] -> 
             RGBColor[
              0.29953624630010656`, 0.4321619649293011, 0.9403695181514007], 
             UndirectedEdge[1, 237] -> 
             RGBColor[
              0.5286509868219015, 0.6272769374241931, 0.9562975328211968], 
             UndirectedEdge[84, 292] -> 
             RGBColor[
              0.2718397461725893, 0.40305118723574723`, 0.9387922434424387], 
             UndirectedEdge[103, 152] -> 
             RGBColor[
              0.26605649274810816`, 0.396972621207172, 0.9384628957154713], 
             UndirectedEdge[10, 269] -> 
             RGBColor[
              0.2192290472618576, 0.3477540069695957, 0.9357961419700269], 
             UndirectedEdge[109, 138] -> 
             RGBColor[
              0.8139262808550589, 0.8553825016885668, 0.9818711941291625], 
             UndirectedEdge[165, 240] -> 
             RGBColor[
              0.987596961950581, 0.9683237186753911, 0.533871497674751], 
             UndirectedEdge[249, 254] -> 
             RGBColor[
              0.8549509396381043, 0.371609679278205, 0.19822709100428773`], 
             UndirectedEdge[2, 155] -> 
             RGBColor[
              0.22153004206728566`, 0.3501724984015976, 0.9359271802201792], 
             UndirectedEdge[117, 161] -> 
             RGBColor[
              0.20987266837087443`, 0.33791985952648745`, 0.9352633100337076],
              UndirectedEdge[169, 264] -> 
             RGBColor[
              0.29384317958318956`, 0.42617819084854336`, 0.9400453064240097],
              UndirectedEdge[3, 229] -> 
             RGBColor[
              0.3618568268450173, 0.48784392878537974`, 0.9442781749225044], 
             UndirectedEdge[55, 90] -> 
             RGBColor[
              0.3401206359010615, 0.4660537805054501, 0.9430016668956538], 
             UndirectedEdge[3, 259] -> 
             RGBColor[
              0.42079287632469464`, 0.5385942486118271, 0.9481156241324957], 
             UndirectedEdge[113, 254] -> 
             RGBColor[
              0.925365599889266, 0.7843240503848107, 0.5923111720047104], 
             UndirectedEdge[6, 205] -> 
             RGBColor[
              0.41755993513205164`, 0.5337399711358773, 0.9484090697443592], 
             UndirectedEdge[120, 287] -> 
             RGBColor[
              0.5654447927305568, 0.5603176274195498, 0.6027460190921992], 
             UndirectedEdge[31, 67] -> 
             RGBColor[
              0.765577527957654, 0.8171802233035855, 0.9773175856314692], 
             UndirectedEdge[141, 232] -> 
             RGBColor[
              0.9465494933171561, 0.8120284719793993, 0.41813025783551805`], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.4306059655104517, 0.5460088371370204, 0.9490406986812941], 
             UndirectedEdge[71, 122] -> 
             RGBColor[
              0.6268946494046528, 0.707980343525642, 0.9637705896733515], 
             UndirectedEdge[78, 120] -> 
             RGBColor[
              0.1849774474258748, 0.3117534038651181, 0.9338455640300687], 
             UndirectedEdge[177, 247] -> 
             RGBColor[
              0.4991479409504841, 0.603343634292864, 0.9539698061272375], 
             UndirectedEdge[168, 182] -> 
             RGBColor[
              0.34652806688330007`, 0.474422427150048, 0.9433067307526943], 
             UndirectedEdge[26, 228] -> 
             RGBColor[
              0.901089116284713, 0.9224316156704129, 0.933371766463492], 
             UndirectedEdge[7, 194] -> 
             RGBColor[
              0.4552899701705174, 0.5670735874923983, 0.9507006582548503], 
             UndirectedEdge[206, 244] -> 
             RGBColor[
              0.23959248852906917`, 0.3691572748581827, 0.9369558098251829], 
             UndirectedEdge[31, 109] -> 
             RGBColor[
              0.7700026915435176, 0.8207087286290875, 0.9777396616846791], 
             UndirectedEdge[57, 235] -> 
             RGBColor[
              0.24454607243650103`, 0.3743638056202535, 0.9372379091005405], 
             UndirectedEdge[24, 135] -> 
             RGBColor[
              0.9728662611822794, 0.9783034573302576, 0.8868911650284141], 
             UndirectedEdge[130, 220] -> 
             RGBColor[
              0.21805936955163013`, 0.34652460153429643`, 0.9357295305548126],
              UndirectedEdge[84, 112] -> 
             RGBColor[
              0.2764157065059942, 0.4078608116787981, 0.9390528376138995], 
             UndirectedEdge[76, 104] -> 
             RGBColor[
              0.2896837321277139, 0.4218063478486378, 0.9398084320447715], 
             UndirectedEdge[21, 87] -> 
             RGBColor[
              0.32978099166431396`, 0.45704378140199375`, 0.9423448227907686],
              UndirectedEdge[43, 183] -> 
             RGBColor[
              0.28838161647063476`, 0.4191962552733669, 0.9397797353853092], 
             UndirectedEdge[11, 131] -> 
             RGBColor[
              0.3341685066956953, 0.46386169752747186`, 0.9425138996464097], 
             UndirectedEdge[21, 187] -> 
             RGBColor[
              0.3736920911272321, 0.49809503984895503`, 0.9450323074970538], 
             UndirectedEdge[36, 66] -> 
             RGBColor[
              0.8530135718328662, 0.8858447874582254, 0.9760955206644191], 
             UndirectedEdge[124, 125] -> 
             RGBColor[
              0.970159485355791, 0.9735725032155419, 0.706048969605638], 
             UndirectedEdge[232, 296] -> 
             RGBColor[
              0.8451660598218556, 0.8762026073137711, 0.7845904625645401], 
             UndirectedEdge[75, 239] -> 
             RGBColor[
              0.5708233361978141, 0.6599633407458361, 0.9605961986132696], 
             UndirectedEdge[108, 114] -> 
             RGBColor[
              0.32416580444258236`, 0.4547970767096937, 0.9418912109282782], 
             UndirectedEdge[137, 266] -> 
             RGBColor[
              0.546600080262197, 0.3644283860727875, 0.564340658118969], 
             UndirectedEdge[74, 262] -> 
             RGBColor[
              0.8160969055518104, 0.8533507770496733, 0.7753857250766871], 
             UndirectedEdge[48, 90] -> 
             RGBColor[
              0.4086146868704133, 0.5283432370210001, 0.9472575444169704], 
             UndirectedEdge[125, 150] -> 
             RGBColor[
              0.9773157340645346, 0.9789096217852411, 0.6939353071903218], 
             UndirectedEdge[38, 55] -> 
             RGBColor[
              0.34731954937378307`, 0.4722891175276097, 0.9434603752963864], 
             UndirectedEdge[110, 165] -> 
             RGBColor[
              0.9866031709361507, 0.9682133561493669, 0.5721913133374072], 
             UndirectedEdge[114, 145] -> 
             RGBColor[
              0.28680752014306377`, 0.4187832666903979, 0.9396446360272199], 
             UndirectedEdge[222, 290] -> 
             RGBColor[
              0.5245306986367102, 0.6244100551018348, 0.9558410534763778], 
             UndirectedEdge[267, 286] -> 
             RGBColor[
              0.5134415575632728, 0.6158740125652669, 0.954839146691229], 
             UndirectedEdge[6, 187] -> 
             RGBColor[
              0.3348012763614461, 0.46412565624274105`, 0.9425646219959795], 
             UndirectedEdge[221, 231] -> 
             RGBColor[
              0.3698663550363416, 0.4934747204504928, 0.9448363781661868], 
             UndirectedEdge[106, 286] -> 
             RGBColor[
              0.6078523188068897, 0.6923017142945901, 0.9624213809540463], 
             UndirectedEdge[67, 154] -> 
             RGBColor[
              0.8267592072412856, 0.8653361474156035, 0.9831692431983503], 
             UndirectedEdge[85, 296] -> 
             RGBColor[
              0.8079306217366228, 0.8506861757670146, 0.9812769124001008], 
             UndirectedEdge[41, 201] -> 
             RGBColor[
              0.3390519049385823, 0.4680914516387281, 0.942825065464227], 
             UndirectedEdge[42, 235] -> 
             RGBColor[
              0.24823850572703557`, 0.37824478712239773`, 0.9374481877139709],
              UndirectedEdge[44, 60] -> 
             RGBColor[
              0.9455688567915195, 0.8192169579907062, 0.28906456863413965`], 
             UndirectedEdge[199, 228] -> 
             RGBColor[
              0.49763512145939465`, 0.5809234064486897, 0.9579150616794772], 
             UndirectedEdge[39, 62] -> 
             RGBColor[
              0.931190722612425, 0.7413845468769279, 0.4459365036310404], 
             UndirectedEdge[48, 144] -> 
             RGBColor[
              0.3646961975812182, 0.4903032490061542, 0.9444590971150582], 
             UndirectedEdge[68, 215] -> 
             RGBColor[
              0.9347347232001206, 0.7573256172439325, 0.47384806566130333`], 
             UndirectedEdge[127, 240] -> 
             RGBColor[
              0.9138528267329997, 0.6222389884972201, 0.4344716104257349], 
             UndirectedEdge[4, 26] -> 
             RGBColor[
              0.7627278647878275, 0.8127689353043519, 0.92065723869614], 
             UndirectedEdge[8, 47] -> 
             RGBColor[
              0.6479545398771973, 0.7249062782797447, 0.9655457111216659], 
             UndirectedEdge[112, 175] -> 
             RGBColor[
              0.27336230601956724`, 0.40465149417079094`, 0.9388789509732987],
              UndirectedEdge[162, 203] -> 
             RGBColor[
              0.27206034387321254`, 0.4032830494058043, 0.9388048061551442], 
             UndirectedEdge[6, 50] -> 
             RGBColor[
              0.32906105284495657`, 0.4591537631447806, 0.9421988600293891], 
             UndirectedEdge[15, 294] -> 
             RGBColor[
              0.2244101664519819, 0.3531996917403464, 0.9360911990431254], 
             UndirectedEdge[6, 219] -> 
             RGBColor[
              0.2899540268393041, 0.4220904447281936, 0.9398238249287314], 
             UndirectedEdge[110, 281] -> 
             RGBColor[
              0.914511185737251, 0.6348277749915371, 0.4743735268121172], 
             UndirectedEdge[167, 297] -> 
             RGBColor[
              0.7571627446031911, 0.8102205578247882, 0.9764305643600557], 
             UndirectedEdge[122, 246] -> 
             RGBColor[
              0.6115303319065195, 0.6955068984260417, 0.962561054318549], 
             UndirectedEdge[210, 277] -> 
             RGBColor[
              0.36382607089811214`, 0.48954958900708645`, 0.9444036534122333],
              UndirectedEdge[225, 234] -> 
             RGBColor[
              0.889140927135372, 0.5070538412384147, 0.23353324484929344`], 
             UndirectedEdge[84, 280] -> 
             RGBColor[
              0.28433817175579457`, 0.41618782496964746`, 0.9395040102896386],
              UndirectedEdge[67, 95] -> 
             RGBColor[
              0.7004824194836051, 0.7643330817431344, 0.9721930602411528], 
             UndirectedEdge[81, 285] -> 
             RGBColor[
              0.33930631085889784`, 0.4671186752480599, 0.9428849623189395], 
             UndirectedEdge[79, 164] -> 
             RGBColor[
              0.38942752096010885`, 0.5117242782844935, 0.9460349551717104], 
             UndirectedEdge[123, 157] -> 
             RGBColor[
              0.3911005410183704, 0.5131733641705265, 0.9461415585304294], 
             UndirectedEdge[85, 165] -> 
             RGBColor[
              0.9499430145672961, 0.9419121380578821, 0.6850057931573457], 
             UndirectedEdge[59, 62] -> 
             RGBColor[
              0.9138294445361559, 0.6222945482383531, 0.42987348446131357`], 
             UndirectedEdge[38, 48] -> 
             RGBColor[
              0.41581360034313486`, 0.5345785740431597, 0.947716252817703], 
             UndirectedEdge[262, 291] -> 
             RGBColor[
              0.9059438756426232, 0.5640930053700905, 0.37544589714295], 
             UndirectedEdge[26, 170] -> 
             RGBColor[
              0.903864214749553, 0.5788492838255521, 0.5265064491665074], 
             UndirectedEdge[43, 139] -> 
             RGBColor[
              0.2888262243395204, 0.4196635663333328, 0.9398050551457039], 
             UndirectedEdge[52, 281] -> 
             RGBColor[
              0.8268922067247678, 0.207710861892501, 0.1733853135710282], 
             UndirectedEdge[124, 142] -> 
             RGBColor[
              0.8033587771487245, 0.8470321673736835, 0.9700369554308557], 
             UndirectedEdge[166, 271] -> 
             RGBColor[
              0.9850940999243964, 0.9612451065301149, 0.40815265332302325`], 
             UndirectedEdge[37, 150] -> 
             RGBColor[
              0.8213545365263866, 0.860837194061274, 0.9590036741380308], 
             UndirectedEdge[51, 66] -> 
             RGBColor[
              0.9700089985303242, 0.9755966228942858, 0.8659381168837096], 
             UndirectedEdge[60, 125] -> 
             RGBColor[
              0.9593538076584427, 0.8656414371856946, 0.3490277111915949], 
             UndirectedEdge[215, 223] -> 
             RGBColor[
              0.9412290011481947, 0.7868146166289862, 0.47926705037049566`], 
             UndirectedEdge[237, 282] -> 
             RGBColor[
              0.8012181754265049, 0.8450224537789045, 0.955554762540068], 
             UndirectedEdge[143, 172] -> 
             RGBColor[
              0.33312272414216076`, 0.4593269071857189, 0.9425801382634016], 
             UndirectedEdge[177, 285] -> 
             RGBColor[
              0.40098949086418123`, 0.5217386754938967, 0.9467716736701495], 
             UndirectedEdge[244, 270] -> 
             RGBColor[
              0.23538330068246843`, 0.36473315155348174`, 0.9367161028042543],
              UndirectedEdge[147, 272] -> 
             RGBColor[
              0.2247364657597668, 0.3535426530013993, 0.9361097813059873], 
             UndirectedEdge[46, 114] -> 
             RGBColor[
              0.29827465777054285`, 0.4308359553953969, 0.9402976725509951], 
             UndirectedEdge[104, 128] -> 
             RGBColor[
              0.26216622821870855`, 0.39288370652975557`, 0.9382413509056526],
              UndirectedEdge[199, 220] -> 
             RGBColor[
              0.21805936955163013`, 0.34652460153429643`, 0.9357295305548126],
              UndirectedEdge[112, 146] -> 
             RGBColor[
              0.24133200131587673`, 0.37098561308859834`, 0.937054872505013], 
             UndirectedEdge[191, 203] -> 
             RGBColor[
              0.2517414689713402, 0.38192662359285945`, 0.9376476762885642], 
             UndirectedEdge[31, 96] -> 
             RGBColor[
              0.512151317735619, 0.6135272413360646, 0.9550965737557137], 
             UndirectedEdge[59, 228] -> 
             RGBColor[
              0.8245766992197552, 0.5548258112486377, 0.5806907356901773], 
             UndirectedEdge[129, 289] -> 
             RGBColor[
              0.26344635035437974`, 0.39422919605877726`, 0.9383142519675081],
              UndirectedEdge[54, 106] -> 
             RGBColor[
              0.5370375913061106, 0.6338360445866622, 0.9571160047492481], 
             UndirectedEdge[102, 142] -> 
             RGBColor[
              0.5221732711977142, 0.6208612990518254, 0.9562111960106483], 
             UndirectedEdge[74, 90] -> 
             RGBColor[
              0.5208802713688769, 0.620561681786851, 0.9557981491382472], 
             UndirectedEdge[143, 174] -> 
             RGBColor[
              0.39453676766698986`, 0.5161496509837875, 0.9463605118539434], 
             UndirectedEdge[144, 292] -> 
             RGBColor[
              0.2793854994126222, 0.4103384300471832, 0.9392455364137446], 
             UndirectedEdge[59, 255] -> 
             RGBColor[
              0.895882246116654, 0.5632021453653563, 0.23704906314163093`], 
             UndirectedEdge[254, 258] -> 
             RGBColor[
              0.926544473085371, 0.7852032520842381, 0.5903156471830767], 
             UndirectedEdge[46, 108] -> 
             RGBColor[
              0.3180292730157506, 0.448347193101529, 0.9415417445417048], 
             UndirectedEdge[222, 278] -> 
             RGBColor[
              0.51953209520131, 0.6203519636484585, 0.9554475451034554], 
             UndirectedEdge[115, 294] -> 
             RGBColor[
              0.2157444487404361, 0.3440914729872748, 0.9355976992392334], 
             UndirectedEdge[89, 177] -> 
             RGBColor[
              0.3486700459196015, 0.47359177071300174`, 0.9435415608547846], 
             UndirectedEdge[45, 195] -> 
             RGBColor[
              0.8384837744462674, 0.29680873085731074`, 0.18448541191193943`],
              UndirectedEdge[205, 231] -> 
             RGBColor[
              0.4872830813565614, 0.5944147705735998, 0.9528413641420233], 
             UndirectedEdge[148, 244] -> 
             RGBColor[
              0.24066234627754973`, 0.37028176318473494`, 0.9370167366412461],
              UndirectedEdge[20, 297] -> 
             RGBColor[
              0.8131524423226874, 0.8543313044865806, 0.981912597264512], 
             UndirectedEdge[6, 34] -> 
             RGBColor[
              0.31658612534963915`, 0.4483486079564237, 0.9414039686805327], 
             UndirectedEdge[13, 245] -> 
             RGBColor[
              0.36526550488349396`, 0.49055433824048805`, 0.9445042342692497],
              UndirectedEdge[104, 201] -> 
             RGBColor[
              0.30309244121459367`, 0.43475633405208935`, 0.9406139042960187],
              UndirectedEdge[55, 253] -> 
             RGBColor[
              0.2867100868131406, 0.4186808580830187, 0.9396390873432205], 
             UndirectedEdge[52, 141] -> 
             RGBColor[
              0.8583552325882947, 0.3856963454250917, 0.20101401461005142`], 
             UndirectedEdge[160, 299] -> 
             RGBColor[
              0.7923522710279916, 0.8350967196266381, 0.8509761351220573], 
             UndirectedEdge[229, 284] -> 
             RGBColor[
              0.3010164849724387, 0.4302374601386527, 0.9405812474653377], 
             UndirectedEdge[27, 268] -> 
             RGBColor[
              0.2604774227946408, 0.3911086649526121, 0.9381451759351156], 
             UndirectedEdge[193, 236] -> 
             RGBColor[
              0.511354201918838, 0.6127180573453962, 0.9550785966275717], 
             UndirectedEdge[78, 193] -> 
             RGBColor[
              0.2897690368730418, 0.4135053888596902, 0.9401205117129523], 
             UndirectedEdge[175, 177] -> 
             RGBColor[
              0.3568594089399756, 0.48219931048302006`, 0.944007932963718], 
             UndirectedEdge[36, 67] -> 
             RGBColor[
              0.8359448003222887, 0.8725120025435762, 0.9840847772724168], 
             UndirectedEdge[37, 239] -> 
             RGBColor[
              0.5459185219885249, 0.6405075106019407, 0.9581139194816087], 
             UndirectedEdge[49, 280] -> 
             RGBColor[
              0.2523064385494426, 0.38252044244058536`, 0.9376798504702395], 
             UndirectedEdge[263, 276] -> 
             RGBColor[
              0.24638255548127658`, 0.37629406574006286`, 0.9373424940931072],
              UndirectedEdge[13, 73] -> 
             RGBColor[
              0.31756925587348483`, 0.44924224463119755`, 0.9414650714584689],
              UndirectedEdge[136, 240] -> 
             RGBColor[
              0.9939206142632153, 0.9894051335662295, 0.5796745640498617], 
             UndirectedEdge[79, 241] -> 
             RGBColor[
              0.3370030923017984, 0.46357362454027395`, 0.9427949607029437], 
             UndirectedEdge[78, 226] -> 
             RGBColor[
              0.17948366519653014`, 0.30597909041616517`, 0.9335327012594301],
              UndirectedEdge[3, 74] -> 
             RGBColor[
              0.5077694883992605, 0.6092057805456816, 0.9549627416408335], 
             UndirectedEdge[148, 203] -> 
             RGBColor[
              0.2492037147300215, 0.37925928298232137`, 0.9375031549387921], 
             UndirectedEdge[90, 257] -> 
             RGBColor[
              0.39742589509621323`, 0.518652067951214, 0.9465446044989785], 
             UndirectedEdge[34, 87] -> 
             RGBColor[
              0.3018032451276056, 0.4328108635543251, 0.9405621055211995], 
             UndirectedEdge[146, 235] -> 
             RGBColor[
              0.23624487142727435`, 0.3656387170330131, 0.9367651679835913], 
             UndirectedEdge[181, 256] -> 
             RGBColor[
              0.8545325264557142, 0.8843014088645924, 0.8481299389821997], 
             UndirectedEdge[68, 287] -> 
             RGBColor[
              0.9076706141527531, 0.6630503890698746, 0.24412287160438084`], 
             UndirectedEdge[17, 144] -> 
             RGBColor[
              0.3059659418661292, 0.4382761603632087, 0.940759253289231], 
             UndirectedEdge[163, 216] -> 
             RGBColor[
              0.2500986511246546, 0.3801999178753255, 0.9375541202425267], 
             UndirectedEdge[67, 258] -> 
             RGBColor[
              0.9370426830307382, 0.9519641935346369, 0.9705507738068005], 
             UndirectedEdge[232, 240] -> 
             RGBColor[
              0.9945150494485371, 0.9906765703210165, 0.6443751655434223], 
             UndirectedEdge[133, 210] -> 
             RGBColor[
              0.36435206965698563`, 0.49000518269455634`, 0.9444371695880264],
              UndirectedEdge[58, 154] -> 
             RGBColor[
              0.6450616328403926, 0.7212149997583763, 0.9662359728150638], 
             UndirectedEdge[94, 124] -> 
             RGBColor[
              0.9048214633960636, 0.926634777474092, 0.9800597975853467], 
             UndirectedEdge[50, 213] -> 
             RGBColor[
              0.3901638861949155, 0.5123620808400902, 0.94608187571333], 
             UndirectedEdge[15, 212] -> 
             RGBColor[
              0.22532179004368708`, 0.3541578659355026, 0.9361431146580468], 
             UndirectedEdge[11, 139] -> 
             RGBColor[
              0.2994922538712322, 0.4289019450234698, 0.940484685115865], 
             UndirectedEdge[167, 286] -> 
             RGBColor[
              0.6564811647517911, 0.7302909383396649, 0.9672682498554315], 
             UndirectedEdge[113, 288] -> 
             RGBColor[
              0.9106552013287734, 0.717527566222487, 0.5800364548609709], 
             UndirectedEdge[73, 171] -> 
             RGBColor[
              0.3736817156213931, 0.4980860531072854, 0.9450316463789965], 
             UndirectedEdge[31, 110] -> 
             RGBColor[
              0.8058913506986181, 0.8463947757840589, 0.8648515957717691], 
             UndirectedEdge[202, 275] -> 
             RGBColor[
              0.22044981250771753`, 0.3490371086439815, 0.9358656627448182], 
             UndirectedEdge[103, 241] -> 
             RGBColor[
              0.2789461451652853, 0.41052046314879065`, 0.9391969423520976], 
             UndirectedEdge[9, 20] -> 
             RGBColor[
              0.6913677553568252, 0.7572692319617951, 0.9710889688646087], 
             UndirectedEdge[71, 207] -> 
             RGBColor[
              0.6875924129964879, 0.7556761815938675, 0.9696301113207838], 
             UndirectedEdge[160, 168] -> 
             RGBColor[
              0.4880465107801085, 0.5934258804224648, 0.9533459462263981], 
             UndirectedEdge[6, 114] -> 
             RGBColor[
              0.30504212315896806`, 0.43794899060072, 0.940683069693298], 
             UndirectedEdge[95, 96] -> 
             RGBColor[
              0.44705620926157014`, 0.5606800997756136, 0.9499720483653973], 
             UndirectedEdge[198, 278] -> 
             RGBColor[
              0.5335934338471843, 0.6322342135642272, 0.9564255762110536], 
             UndirectedEdge[86, 281] -> 
             RGBColor[
              0.9054719947624891, 0.6025945964032228, 0.26952294162192125`], 
             UndirectedEdge[107, 165] -> 
             RGBColor[
              0.9072036933815937, 0.6042751330644562, 0.27907410397502735`], 
             UndirectedEdge[155, 184] -> 
             RGBColor[
              0.22486994634019453`, 0.35368294955458646`, 0.9361173828275757],
              UndirectedEdge[247, 285] -> 
             RGBColor[
              0.4809297969495969, 0.5875639936298371, 0.952808962101173], 
             UndirectedEdge[34, 227] -> 
             RGBColor[
              0.2936321912026204, 0.4242225678044243, 0.9400967760881624], 
             UndirectedEdge[116, 152] -> 
             RGBColor[
              0.2878519743324149, 0.4186179236915859, 0.9397503655460857], 
             UndirectedEdge[146, 204] -> 
             RGBColor[
              0.23066664293228167`, 0.35977564520466165`, 0.936447496123051], 
             UndirectedEdge[36, 58] -> 
             RGBColor[
              0.6542472259213957, 0.728390854886349, 0.9671515068891303], 
             UndirectedEdge[105, 129] -> 
             RGBColor[
              0.2625398824694277, 0.39327644083830926`, 0.9382626299624591], 
             UndirectedEdge[87, 187] -> 
             RGBColor[
              0.3200183961394125, 0.4485879118406425, 0.9417227588366461], 
             UndirectedEdge[119, 168] -> 
             RGBColor[
              0.3340488783835623, 0.46130600881057365`, 0.9425960594289393], 
             UndirectedEdge[20, 37] -> 
             RGBColor[
              0.7733043134332283, 0.8232016433411387, 0.9779409081787471], 
             UndirectedEdge[150, 200] -> 
             RGBColor[
              0.9240011310350597, 0.7732005239509658, 0.5878910864110933], 
             UndirectedEdge[1, 43] -> 
             RGBColor[
              0.370348202098986, 0.49519873124143765`, 0.944819237845059], 
             UndirectedEdge[187, 213] -> 
             RGBColor[
              0.395904109711405, 0.5173339739380506, 0.9464476376799205], 
             UndirectedEdge[41, 222] -> 
             RGBColor[
              0.3965617253644508, 0.517903567563995, 0.9464895403678258], 
             UndirectedEdge[196, 263] -> 
             RGBColor[
              0.27095799274113747`, 0.40212440847289477`, 0.9387420288889549],
              UndirectedEdge[148, 172] -> 
             RGBColor[
              0.2541544433679442, 0.3844628126751034, 0.9377850916107751], 
             UndirectedEdge[96, 171] -> 
             RGBColor[
              0.4119096090232586, 0.5311971329821921, 0.9474674939429645], 
             UndirectedEdge[178, 208] -> 
             RGBColor[
              0.2815080542956977, 0.41321319207927465`, 0.9393428392870697], 
             UndirectedEdge[25, 270] -> 
             RGBColor[
              0.24003287271686014`, 0.3696201465615213, 0.9369808890531874], 
             UndirectedEdge[47, 217] -> 
             RGBColor[
              0.7255477462839056, 0.7855226808548759, 0.9732794767865461], 
             UndirectedEdge[33, 142] -> 
             RGBColor[
              0.7868432036591011, 0.8341724103626897, 0.9791857606964562], 
             UndirectedEdge[26, 62] -> 
             RGBColor[
              0.9903418616011138, 0.9899003526601282, 0.7825545152346283], 
             UndirectedEdge[48, 177] -> 
             RGBColor[
              0.4164452697798513, 0.5351256943606145, 0.9477565022356473], 
             UndirectedEdge[238, 300] -> 
             RGBColor[
              0.2671877155710705, 0.398161608117775, 0.9385273171817448], 
             UndirectedEdge[25, 139] -> 
             RGBColor[
              0.25364452897953216`, 0.38392686032244283`, 0.9377560527407058],
              UndirectedEdge[3, 30] -> 
             RGBColor[
              0.4197616538813304, 0.5377570557762624, 0.9480344425242617], 
             UndirectedEdge[95, 171] -> 
             RGBColor[
              0.45349990749309843`, 0.5662613073140733, 0.9503826351187716], 
             UndirectedEdge[21, 50] -> 
             RGBColor[
              0.3679518676107426, 0.4931231467509946, 0.9446665455304635], 
             UndirectedEdge[122, 232] -> 
             RGBColor[
              0.8091446434633787, 0.8477841192514302, 0.781190448595753], 
             UndirectedEdge[127, 136] -> 
             RGBColor[
              0.9128398822496258, 0.6200724026716804, 0.3242188545792082], 
             UndirectedEdge[41, 290] -> 
             RGBColor[
              0.4849597446468357, 0.5901356836497829, 0.9533196272793637], 
             UndirectedEdge[123, 259] -> 
             RGBColor[
              0.4502407471664895, 0.5641005142419657, 0.9499920164228051], 
             UndirectedEdge[20, 185] -> 
             RGBColor[
              0.7169880778773853, 0.7780689639663625, 0.973105894503761], 
             UndirectedEdge[163, 211] -> 
             RGBColor[
              0.2418593140070983, 0.3715398521606279, 0.9370849021826888], 
             UndirectedEdge[33, 37] -> 
             RGBColor[
              0.7976827143280194, 0.8426403184805812, 0.9802661418189477], 
             UndirectedEdge[7, 9] -> 
             RGBColor[
              0.45578820295562306`, 0.5674780753124783, 0.9507398809647807], 
             UndirectedEdge[105, 263] -> 
             RGBColor[
              0.2750769487244079, 0.40645369236820506`, 0.9389765973387527], 
             UndirectedEdge[15, 49] -> 
             RGBColor[
              0.2377386487348052, 0.36720877169417954`, 0.9368502363914097], 
             UndirectedEdge[20, 237] -> 
             RGBColor[
              0.752342583517374, 0.8067713443472341, 0.9758891306955624], 
             UndirectedEdge[26, 220] -> 
             RGBColor[
              0.6215133643769486, 0.6880328107560196, 0.9111862353388274], 
             UndirectedEdge[101, 187] -> 
             RGBColor[
              0.4552598760386822, 0.566212394980653, 0.9509294886200896], 
             UndirectedEdge[93, 94] -> 
             RGBColor[
              0.6965792865266065, 0.7615288190518337, 0.9714662855765266], 
             UndirectedEdge[143, 297] -> 
             RGBColor[
              0.5785745379743751, 0.6654077250363819, 0.9616273334928914], 
             UndirectedEdge[208, 268] -> 
             RGBColor[
              0.274238057450941, 0.4055719644510125, 0.9389288237217572], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.9540665099241967, 0.9616166407194549, 0.7611949655148192], 
             UndirectedEdge[224, 288] -> 
             RGBColor[
              0.9157129138329121, 0.6873344410170366, 0.27129446960632875`], 
             UndirectedEdge[1, 75] -> 
             RGBColor[
              0.5745175309470449, 0.663163066561993, 0.9608315894360424], 
             UndirectedEdge[36, 113] -> 
             RGBColor[
              0.8594902789211216, 0.8906751050000117, 0.9651321449597499], 
             UndirectedEdge[29, 244] -> 
             RGBColor[
              0.24266708121897157`, 0.3723888667157059, 0.9371309033304205], 
             UndirectedEdge[36, 96] -> 
             RGBColor[
              0.5825185901002536, 0.6688590205760554, 0.9618637653966613], 
             UndirectedEdge[58, 138] -> 
             RGBColor[
              0.6278035428683023, 0.7077328487058376, 0.9645158476926661], 
             UndirectedEdge[71, 136] -> 
             RGBColor[
              0.8112521109064372, 0.8487062087696886, 0.716702550774494], 
             UndirectedEdge[144, 252] -> 
             RGBColor[
              0.3081203950955903, 0.44054062730759674`, 0.940881946213421], 
             UndirectedEdge[58, 198] -> 
             RGBColor[
              0.506589269540044, 0.610311016455952, 0.9542997094772824], 
             UndirectedEdge[110, 154] -> 
             RGBColor[
              0.8670730299822498, 0.8945506998960768, 0.8707032533386501], 
             UndirectedEdge[119, 152] -> 
             RGBColor[
              0.2677604183233837, 0.39876355502190786`, 0.9385599317562512], 
             UndirectedEdge[38, 90] -> 
             RGBColor[
              0.41074538251891396`, 0.5301887384998543, 0.9473933104595927], 
             UndirectedEdge[66, 179] -> 
             RGBColor[
              0.9700512243327243, 0.9756140843487318, 0.8652383260610674], 
             UndirectedEdge[6, 21] -> 
             RGBColor[
              0.3445638718863475, 0.47258152580409235`, 0.9431866859501019], 
             UndirectedEdge[176, 287] -> 
             RGBColor[
              0.5599634445497977, 0.5545563829440247, 0.6024338644222329], 
             UndirectedEdge[142, 237] -> 
             RGBColor[
              0.6489015303358828, 0.7255912381548726, 0.9656775901367828], 
             UndirectedEdge[108, 221] -> 
             RGBColor[
              0.3192668900954462, 0.449648007121744, 0.9416122250035031], 
             UndirectedEdge[44, 256] -> 
             RGBColor[
              0.9801516197044022, 0.9430147833008583, 0.5214481671592728], 
             UndirectedEdge[89, 112] -> 
             RGBColor[
              0.26517294299919314`, 0.39604395440077267`, 0.9384125788643654],
              UndirectedEdge[83, 184] -> 
             RGBColor[
              0.22686279734830417`, 0.3557775623181615, 0.9362308727443287], 
             UndirectedEdge[259, 261] -> 
             RGBColor[
              0.4324511169680622, 0.5486920306968999, 0.9488584769173136], 
             UndirectedEdge[207, 231] -> 
             RGBColor[
              0.5953538117647618, 0.6805701172311853, 0.962430259270135], 
             UndirectedEdge[112, 280] -> 
             RGBColor[
              0.2601358942740522, 0.3907496968233146, 0.9381257263911142], 
             UndirectedEdge[174, 194] -> 
             RGBColor[
              0.45407833864122044`, 0.5660241331600927, 0.9506234541652072], 
             UndirectedEdge[125, 200] -> 
             RGBColor[
              0.9393105629674767, 0.7809252028803274, 0.3326287940678124], 
             UndirectedEdge[99, 222] -> 
             RGBColor[
              0.4018105363813725, 0.5224498238539401, 0.9468239899644828], 
             UndirectedEdge[108, 169] -> 
             RGBColor[
              0.3184727377256654, 0.44881330262893604`, 0.9415669992008873], 
             UndirectedEdge[15, 57] -> 
             RGBColor[
              0.2429878777602664, 0.3727260442202823, 0.9371491722188713], 
             UndirectedEdge[4, 78] -> 
             RGBColor[
              0.3598305300482983, 0.47184581112708096`, 0.9452322348805061], 
             UndirectedEdge[52, 86] -> 
             RGBColor[
              0.8962878067304835, 0.5320009026523702, 0.26072815279041595`], 
             UndirectedEdge[20, 282] -> 
             RGBColor[
              0.9147814478549319, 0.9341649508472791, 0.9667376994595409], 
             UndirectedEdge[42, 55] -> 
             RGBColor[
              0.2655663224814774, 0.39645742117835314`, 0.9384349812439285], 
             UndirectedEdge[136, 165] -> 
             RGBColor[
              0.9865840174672071, 0.9661571328498515, 0.42361874182822423`], 
             UndirectedEdge[161, 269] -> 
             RGBColor[
              0.22164816720784125`, 0.350296655413888, 0.9359339072721834], 
             UndirectedEdge[57, 243] -> 
             RGBColor[
              0.23260979600231052`, 0.3618180222842825, 0.9365581558157519], 
             UndirectedEdge[57, 146] -> 
             RGBColor[
              0.23875177461672836`, 0.3682736312319718, 0.9369079324115999], 
             UndirectedEdge[4, 130] -> 
             RGBColor[
              0.3592738699625091, 0.4712607260826286, 0.9452005339121252], 
             UndirectedEdge[31, 58] -> 
             RGBColor[
              0.583879953556761, 0.6730590756463584, 0.9603843152481828], 
             UndirectedEdge[95, 140] -> 
             RGBColor[
              0.4083602605702821, 0.527163613934152, 0.9475063767322723], 
             UndirectedEdge[58, 96] -> 
             RGBColor[
              0.47719454661287236`, 0.585147759754026, 0.9523446486820593], 
             UndirectedEdge[16, 94] -> 
             RGBColor[
              0.9277097420952534, 0.9406004694880592, 0.7586810334703302], 
             UndirectedEdge[113, 135] -> 
             RGBColor[
              0.9747525126984742, 0.9797102206225822, 0.8836982332246824], 
             UndirectedEdge[47, 262] -> 
             RGBColor[
              0.8190197652374052, 0.8556976322352333, 0.77563363654671], 
             UndirectedEdge[153, 211] -> 
             RGBColor[
              0.25792046228139853`, 0.38842113733253425`, 0.9379995608165705],
              UndirectedEdge[89, 111] -> 
             RGBColor[
              0.26057341862775985`, 0.3912095626597075, 0.9381506427557986], 
             UndirectedEdge[137, 256] -> 
             RGBColor[
              0.9204070908250823, 0.671745815737615, 0.457708580717874], 
             UndirectedEdge[136, 181] -> 
             RGBColor[
              0.8533623737727853, 0.8817985705963918, 0.7207660407906598], 
             UndirectedEdge[288, 291] -> 
             RGBColor[
              0.839904564048634, 0.3022307284450855, 0.18563064187816736`], 
             UndirectedEdge[121, 296] -> 
             RGBColor[
              0.8454228514141477, 0.8767518585640715, 0.8125406426515358], 
             UndirectedEdge[241, 277] -> 
             RGBColor[
              0.3140852328677468, 0.44372332658360614`, 0.9413346549652732], 
             UndirectedEdge[217, 262] -> 
             RGBColor[
              0.9005077184585596, 0.9193566406229818, 0.783755594175576], 
             UndirectedEdge[75, 142] -> 
             RGBColor[
              0.6947680744610263, 0.7614773672926725, 0.9702116467516284], 
             UndirectedEdge[57, 112] -> 
             RGBColor[
              0.24963320232510341`, 0.37971070167583876`, 0.9375276136219621],
              UndirectedEdge[274, 287] -> 
             RGBColor[
              0.9527752319881305, 0.8479297220628771, 0.29412403319976], 
             UndirectedEdge[97, 252] -> 
             RGBColor[
              0.2790058648824081, 0.41058323235793537`, 0.9392003433016403], 
             UndirectedEdge[18, 69] -> 
             RGBColor[
              0.9697193647682323, 0.9735318279786378, 0.7296111092370301], 
             UndirectedEdge[106, 167] -> 
             RGBColor[
              0.7052976145619072, 0.7697031240469493, 0.9712611329047376], 
             UndirectedEdge[256, 296] -> 
             RGBColor[
              0.8457417773194627, 0.8774340088271846, 0.8472537592625196], 
             UndirectedEdge[131, 183] -> 
             RGBColor[
              0.2897103519915022, 0.4203471391973532, 0.9398644012377442], 
             UndirectedEdge[172, 183] -> 
             RGBColor[
              0.2620424461666492, 0.39275360374480583`, 0.9382343017009069], 
             UndirectedEdge[1, 143] -> 
             RGBColor[
              0.4076363549020162, 0.5274958550423691, 0.9471952059690492], 
             UndirectedEdge[17, 252] -> 
             RGBColor[
              0.29837684649391727`, 0.43094336222280266`, 0.9403034920476165],
              UndirectedEdge[126, 214] -> 
             RGBColor[
              0.21941035515512047`, 0.34794457306099935`, 0.9358064671863272],
              UndirectedEdge[84, 134] -> 
             RGBColor[
              0.2873093787457973, 0.41931075190154404`, 0.9396732161322123], 
             UndirectedEdge[45, 234] -> 
             RGBColor[
              0.837571395698585, 0.28979578799570727`, 0.18361171699277434`], 
             UndirectedEdge[32, 156] -> 
             RGBColor[
              0.24197823755521267`, 0.3716648483498845, 0.9370916747028223], 
             UndirectedEdge[140, 149] -> 
             RGBColor[
              0.3110114912745308, 0.4424361680704541, 0.9410884474530516], 
             UndirectedEdge[16, 150] -> 
             RGBColor[
              0.9777383321225639, 0.9798135163001478, 0.7399324978339024], 
             UndirectedEdge[209, 218] -> 
             RGBColor[
              0.2605995221174108, 0.3912369990823875, 0.9381521293109176], 
             UndirectedEdge[82, 281] -> 
             RGBColor[
              0.9155765352150156, 0.6350911938349629, 0.44384240827575683`], 
             UndirectedEdge[178, 182] -> 
             RGBColor[
              0.29211972893207316`, 0.4243667349411374, 0.9399471584590454], 
             UndirectedEdge[41, 157] -> 
             RGBColor[
              0.35148560431038395`, 0.4788608970986815, 0.9436173297935095], 
             UndirectedEdge[254, 288] -> 
             RGBColor[
              0.8766115127845734, 0.5326035223156528, 0.21875396054991414`], 
             UndirectedEdge[129, 161] -> 
             RGBColor[
              0.22609023535273692`, 0.35496555067756064`, 0.9361868764815843],
              UndirectedEdge[20, 283] -> 
             RGBColor[
              0.7423144926570131, 0.7986300884264481, 0.9750996826489275], 
             UndirectedEdge[162, 210] -> 
             RGBColor[
              0.33154191612091594`, 0.45934744108992703`, 0.9424285250056568],
              UndirectedEdge[203, 244] -> 
             RGBColor[
              0.2510525753068279, 0.38120255267307596`, 0.9376084448134971], 
             UndirectedEdge[121, 246] -> 
             RGBColor[
              0.796739020185918, 0.8380534516751759, 0.8081437970002479], 
             UndirectedEdge[24, 259] -> 
             RGBColor[
              0.7099488174717532, 0.7711907329676471, 0.9554734955620947], 
             UndirectedEdge[141, 281] -> 
             RGBColor[
              0.8675394206203003, 0.45629003917594413`, 0.20980880344155672`],
              UndirectedEdge[110, 138] -> 
             RGBColor[
              0.8498149400101593, 0.8810685488435381, 0.8689831282162525], 
             UndirectedEdge[67, 109] -> 
             RGBColor[
              0.916743494821664, 0.9364503947042759, 0.9919210069943111], 
             UndirectedEdge[154, 245] -> 
             RGBColor[
              0.5828013526273942, 0.6698841791824666, 0.9615515465694076], 
             UndirectedEdge[193, 249] -> 
             RGBColor[
              0.609038860752824, 0.33213297985445467`, 0.5560510629020323], 
             UndirectedEdge[82, 137] -> 
             RGBColor[
              0.9203214410888617, 0.6715626196123557, 0.4483861354991565], 
             UndirectedEdge[100, 125] -> 
             RGBColor[
              0.9214027485620356, 0.686673945842382, 0.31717953132296794`], 
             UndirectedEdge[104, 218] -> 
             RGBColor[
              0.2705572837668725, 0.40170323793452584`, 0.9387192091056663], 
             UndirectedEdge[73, 149] -> 
             RGBColor[
              0.3114795465639533, 0.4428415740370091, 0.9411182715222086], 
             UndirectedEdge[108, 219] -> 
             RGBColor[
              0.30907770812291846`, 0.4389385308371674, 0.9410319661637115], 
             UndirectedEdge[58, 140] -> 
             RGBColor[
              0.4384985979215843, 0.5516312739125644, 0.9498789770489342], 
             UndirectedEdge[9, 63] -> 
             RGBColor[
              0.42067147200560917`, 0.537061727981794, 0.9485022739211517], 
             UndirectedEdge[48, 217] -> 
             RGBColor[
              0.6103593020998471, 0.6909573809034649, 0.9644909605952465], 
             UndirectedEdge[8, 271] -> 
             RGBColor[
              0.814657116181253, 0.8317974978685563, 0.6664449508576125], 
             UndirectedEdge[18, 222] -> 
             RGBColor[
              0.6912666998914337, 0.7558621322945974, 0.9623123726675136], 
             UndirectedEdge[215, 234] -> 
             RGBColor[
              0.9062111144378386, 0.5631850367729421, 0.44751685008743375`], 
             UndirectedEdge[15, 146] -> 
             RGBColor[
              0.2346866767510397, 0.3640009556330419, 0.9366764311019222], 
             UndirectedEdge[54, 151] -> 
             RGBColor[
              0.4303399784091667, 0.5471605926069658, 0.9486418607828988], 
             UndirectedEdge[195, 255] -> 
             RGBColor[
              0.8890490471039758, 0.5106791834270117, 0.23050558405009586`], 
             UndirectedEdge[1, 11] -> 
             RGBColor[
              0.3810142316306978, 0.5044371099315746, 0.9454988678152201], 
             UndirectedEdge[32, 178] -> 
             RGBColor[
              0.2666569110282901, 0.3976036988883609, 0.9384970886482884], 
             UndirectedEdge[126, 189] -> 
             RGBColor[
              0.22889351140479614`, 0.3579119715462422, 0.9363465189056738], 
             UndirectedEdge[61, 273] -> 
             RGBColor[
              0.5923372400801741, 0.6799250818424811, 0.9610501038233672], 
             UndirectedEdge[54, 194] -> 
             RGBColor[
              0.4666198015964266, 0.5768869180196359, 0.9514225850947327], 
             UndirectedEdge[38, 144] -> 
             RGBColor[
              0.36682689322971884`, 0.49214875048500833`, 0.9445948631576804],
              UndirectedEdge[4, 220] -> 
             RGBColor[
              0.3984062395141392, 0.5123913276169251, 0.9474290644669376], 
             UndirectedEdge[45, 200] -> 
             RGBColor[
              0.8719098756675858, 0.5103403405187334, 0.21479500363706636`], 
             UndirectedEdge[2, 202] -> 
             RGBColor[
              0.22943917498765481`, 0.3584854985688961, 0.9363775936394806], 
             UndirectedEdge[17, 175] -> 
             RGBColor[
              0.29536678813966943`, 0.42777960004376564`, 0.9401320736773244],
              UndirectedEdge[233, 262] -> 
             RGBColor[
              0.9940341182393746, 0.9896479070942221, 0.5920287713894679], 
             UndirectedEdge[67, 138] -> 
             RGBColor[
              0.8095011172691953, 0.8518539963630647, 0.9814491180759526], 
             UndirectedEdge[39, 192] -> 
             RGBColor[
              0.8662594246203876, 0.48559710775370324`, 0.21011592443281657`],
              UndirectedEdge[164, 168] -> 
             RGBColor[
              0.38489864849528777`, 0.5078015965832141, 0.9457463794229767], 
             UndirectedEdge[19, 253] -> 
             RGBColor[
              0.2939962623956044, 0.42633909059040226`, 0.940054024263711], 
             UndirectedEdge[24, 74] -> 
             RGBColor[
              0.7969254295463191, 0.8418022649015016, 0.9623206130704325], 
             UndirectedEdge[80, 133] -> 
             RGBColor[
              0.30898841648274356`, 0.43826898504779055`, 0.941047960136832], 
             UndirectedEdge[198, 222] -> 
             RGBColor[
              0.4501940180001994, 0.5640601889318158, 0.9499889976724383], 
             UndirectedEdge[111, 212] -> 
             RGBColor[
              0.2273675902370908, 0.3563081316499939, 0.936259619952571], 
             UndirectedEdge[126, 184] -> 
             RGBColor[
              0.23168784072436213`, 0.3608489888318178, 0.9365056518265833], 
             UndirectedEdge[132, 294] -> 
             RGBColor[
              0.2083047996307834, 0.33627193007203204`, 0.9351740222284133], 
             UndirectedEdge[39, 136] -> 
             RGBColor[
              0.9302201907265502, 0.7393086773088677, 0.34030009728209454`], 
             UndirectedEdge[133, 162] -> 
             RGBColor[
              0.31733689752319516`, 0.44704376794557543`, 0.9415233937816148],
              UndirectedEdge[22, 271] -> 
             RGBColor[
              0.8974219616748091, 0.8964540242042457, 0.6746941771749546], 
             UndirectedEdge[107, 110] -> 
             RGBColor[
              0.9135464991631714, 0.6274127712548101, 0.4734497418593211], 
             UndirectedEdge[40, 191] -> 
             RGBColor[
              0.24055073236956107`, 0.37016444989070835`, 0.9370103803943042],
              UndirectedEdge[143, 237] -> 
             RGBColor[
              0.5177646791690618, 0.6178477648970354, 0.9556038669239417], 
             UndirectedEdge[157, 261] -> 
             RGBColor[
              0.3733109108199431, 0.49776488062546065`, 0.9450080190249379], 
             UndirectedEdge[35, 163] -> 
             RGBColor[
              0.23379526623113445`, 0.36306402665793014`, 0.9366256665915373],
              UndirectedEdge[89, 175] -> 
             RGBColor[
              0.28632181999450856`, 0.4182727650390983, 0.9396169761222888], 
             UndirectedEdge[16, 200] -> 
             RGBColor[
              0.939733161025506, 0.7818290973952341, 0.3786259847113931], 
             UndirectedEdge[35, 189] -> 
             RGBColor[
              0.2290398133604396, 0.3580657441777033, 0.9363548505856133], 
             UndirectedEdge[233, 291] -> 
             RGBColor[
              0.9059982564699387, 0.5642093204609733, 0.381364914596678], 
             UndirectedEdge[258, 290] -> 
             RGBColor[
              0.7873478763723856, 0.8338243344390612, 0.9561368785302078], 
             UndirectedEdge[157, 259] -> 
             RGBColor[
              0.40512064339431064`, 0.5250197481568593, 0.947117003308583], 
             UndirectedEdge[105, 245] -> 
             RGBColor[
              0.35678647711021616`, 0.4816423424493619, 0.944021366181159], 
             UndirectedEdge[100, 192] -> 
             RGBColor[
              0.857583234347318, 0.43326449980026105`, 0.20236975515183697`], 
             UndirectedEdge[258, 278] -> 
             RGBColor[
              0.7823492729369855, 0.8297662429856849, 0.9557433701572854], 
             UndirectedEdge[99, 201] -> 
             RGBColor[
              0.34430071595550393`, 0.4726377079286733, 0.9431595150608838], 
             UndirectedEdge[9, 282] -> 
             RGBColor[
              0.740243347265956, 0.7955203413934655, 0.9507546007091144], 
             UndirectedEdge[84, 175] -> 
             RGBColor[
              0.29756458350130965`, 0.4300896223171238, 0.940257234871823], 
             UndirectedEdge[271, 291] -> 
             RGBColor[
              0.897686479772025, 0.537150265190796, 0.2658690194898667], 
             UndirectedEdge[127, 256] -> 
             RGBColor[
              0.9140100349325547, 0.622575240939881, 0.4515827527707482], 
             UndirectedEdge[80, 116] -> 
             RGBColor[
              0.2951188116057152, 0.426255830409919, 0.9401642011784779], 
             UndirectedEdge[202, 268] -> 
             RGBColor[
              0.2453187041670522, 0.37517589055674394`, 0.937281909334589], 
             UndirectedEdge[161, 265] -> 
             RGBColor[
              0.21936843133233605`, 0.34790050846512904`, 0.9358040796866404],
              UndirectedEdge[22, 72] -> 
             RGBColor[
              0.7345932590636062, 0.7925891041868212, 0.9741810489653038], 
             UndirectedEdge[77, 162] -> 
             RGBColor[
              0.26527957680517633`, 0.3961560332918348, 0.9384186515018654], 
             UndirectedEdge[93, 164] -> 
             RGBColor[
              0.45756686024315646`, 0.5686282136761757, 0.9509610966011381], 
             UndirectedEdge[19, 111] -> 
             RGBColor[
              0.2671407671011217, 0.39811226229915386`, 0.9385246435358352], 
             UndirectedEdge[37, 142] -> 
             RGBColor[
              0.669863260251737, 0.742021537148777, 0.9677293676199676], 
             UndirectedEdge[43, 172] -> 
             RGBColor[
              0.2958345713391305, 0.4270297833847875, 0.9402041701394114], 
             UndirectedEdge[61, 285] -> 
             RGBColor[
              0.474805368949063, 0.5825919070766665, 0.9523268246944521], 
             UndirectedEdge[38, 257] -> 
             RGBColor[
              0.4046248085689348, 0.5248874049733736, 0.9470033128997111], 
             UndirectedEdge[174, 185] -> 
             RGBColor[
              0.4801968939468863, 0.58722835298474, 0.9526796025142897], 
             UndirectedEdge[75, 237] -> 
             RGBColor[
              0.6846458552140906, 0.7535149764166593, 0.969240250390935], 
             UndirectedEdge[30, 48] -> 
             RGBColor[
              0.43794065467516774`, 0.5535027925607373, 0.9491927923797858], 
             UndirectedEdge[289, 298] -> 
             RGBColor[
              0.28811767425307283`, 0.4201603217285858, 0.9397192473655857], 
             UndirectedEdge[123, 261] -> 
             RGBColor[
              0.41843101459212195`, 0.5368456467105671, 0.9478830321391599], 
             UndirectedEdge[77, 206] -> 
             RGBColor[
              0.2413530899135048, 0.3710077785417997, 0.9370560734694501], 
             UndirectedEdge[121, 137] -> 
             RGBColor[
              0.9200881649197675, 0.6710636654745018, 0.4229954641068904], 
             UndirectedEdge[87, 227] -> 
             RGBColor[
              0.2679362427515092, 0.39894835764378045`, 0.938569944697324], 
             UndirectedEdge[123, 144] -> 
             RGBColor[
              0.3759650676291757, 0.5000637778518178, 0.9451771395498434], 
             UndirectedEdge[9, 37] -> 
             RGBColor[
              0.5987662128442524, 0.684557033887325, 0.9619578094283205], 
             UndirectedEdge[178, 268] -> 
             RGBColor[
              0.26978635473276824`, 0.4008929426399584, 0.9386753058376613], 
             UndirectedEdge[112, 253] -> 
             RGBColor[
              0.2744693999473012, 0.40581512008264853`, 0.9389419983346845], 
             UndirectedEdge[78, 220] -> 
             RGBColor[
              0.21861602963741927`, 0.34710968657874874`, 0.9357612315231933],
              UndirectedEdge[66, 67] -> 
             RGBColor[
              0.9293871027463778, 0.9462546742934231, 0.9835096743331035], 
             UndirectedEdge[20, 124] -> 
             RGBColor[
              0.9067998303302157, 0.928212273566045, 0.9802484959896351], 
             UndirectedEdge[18, 224] -> 
             RGBColor[
              0.9579627169351427, 0.9342040847269458, 0.6558617372883351], 
             UndirectedEdge[72, 151] -> 
             RGBColor[
              0.5475405416357872, 0.6431396338261914, 0.9576978591404627], 
             UndirectedEdge[25, 29] -> 
             RGBColor[
              0.24731665325336327`, 0.3772758617237455, 0.9373956895793536], 
             UndirectedEdge[135, 258] -> 
             RGBColor[
              0.9759313858945792, 0.9805894223220096, 0.8817027084030489], 
             UndirectedEdge[130, 176] -> 
             RGBColor[
              0.17893943915932659`, 0.3054070743451405, 0.9335017083917216], 
             UndirectedEdge[31, 245] -> 
             RGBColor[
              0.5216196733437626, 0.6217282550704486, 0.9556998890025264], 
             UndirectedEdge[295, 297] -> 
             RGBColor[
              0.7988419039700752, 0.8429204696534232, 0.9805476453412715], 
             UndirectedEdge[17, 30] -> 
             RGBColor[
              0.37921039896007874`, 0.5014757039177918, 0.9454929485539587], 
             UndirectedEdge[22, 273] -> 
             RGBColor[
              0.717607033402136, 0.7789436605631201, 0.9727448718111256], 
             UndirectedEdge[86, 165] -> 
             RGBColor[
              0.9775639799613888, 0.9359801775610526, 0.3673407281472113], 
             UndirectedEdge[124, 200] -> 
             RGBColor[
              0.916844882326316, 0.7678634053812667, 0.6000047488264095], 
             UndirectedEdge[198, 258] -> 
             RGBColor[
              0.7130111957358749, 0.7734744682690422, 0.9502848227262681], 
             UndirectedEdge[177, 217] -> 
             RGBColor[
              0.6131216671850642, 0.6933500026997739, 0.964666976055813], 
             UndirectedEdge[52, 110] -> 
             RGBColor[
              0.9053269977052454, 0.5642340812406845, 0.4655787379806119], 
             UndirectedEdge[121, 299] -> 
             RGBColor[
              0.9945473356554072, 0.9914335784226265, 0.6978961075730188], 
             UndirectedEdge[173, 196] -> 
             RGBColor[
              0.2690530219671379, 0.40012216340729806`, 0.9386335436215274], 
             UndirectedEdge[238, 251] -> 
             RGBColor[
              0.2826141781107905, 0.4143757983412377, 0.9394058314019756], 
             UndirectedEdge[218, 284] -> 
             RGBColor[
              0.25584347148447395`, 0.38623808831614403`, 0.9378812792633183],
              UndirectedEdge[209, 276] -> 
             RGBColor[
              0.24846893317691396`, 0.37848698098216405`, 0.9374613102163545],
              UndirectedEdge[8, 72] -> 
             RGBColor[
              0.6518284135700501, 0.7279325778511317, 0.9659318226479615], 
             UndirectedEdge[56, 168] -> 
             RGBColor[
              0.46678271330407606`, 0.5761629717082618, 0.9516719821972282], 
             UndirectedEdge[201, 257] -> 
             RGBColor[
              0.35620917982441114`, 0.48295222079512334`, 0.9439183118483695],
              UndirectedEdge[31, 51] -> 
             RGBColor[
              0.8061994237416004, 0.8465221719044482, 0.8597460281820752], 
             UndirectedEdge[53, 282] -> 
             RGBColor[
              0.89769307964249, 0.6086527767356787, 0.5622102390155896], 
             UndirectedEdge[17, 97] -> 
             RGBColor[
              0.27685141165294697`, 0.4083187654135474, 0.9390776503774505], 
             UndirectedEdge[102, 162] -> 
             RGBColor[
              0.3349247683998675, 0.4622774977068556, 0.9426440773615328], 
             UndirectedEdge[36, 260] -> 
             RGBColor[
              0.8043625245684116, 0.8473291531354724, 0.9810724316171817], 
             UndirectedEdge[79, 168] -> 
             RGBColor[
              0.3904018999447999, 0.5125682363873212, 0.9460970417390054], 
             UndirectedEdge[142, 297] -> 
             RGBColor[
              0.7097113891411961, 0.773151198294219, 0.9717010567057325], 
             UndirectedEdge[232, 299] -> 
             RGBColor[
              0.994290544063115, 0.9908843271723261, 0.6699459274860231], 
             UndirectedEdge[50, 169] -> 
             RGBColor[
              0.3227370521664461, 0.4525068374668645, 0.9418387175462686], 
             UndirectedEdge[92, 153] -> 
             RGBColor[
              0.26728945052082176`, 0.3982685380003319, 0.9385331108366297], 
             UndirectedEdge[44, 299] -> 
             RGBColor[
              0.979769906119425, 0.942886287709507, 0.5299077867568601], 
             UndirectedEdge[90, 252] -> 
             RGBColor[
              0.35203888438478537`, 0.4785806153224426, 0.9436803935153333], 
             UndirectedEdge[7, 283] -> 
             RGBColor[
              0.5067349402558111, 0.6088389317771312, 0.9547505947490993], 
             UndirectedEdge[52, 179] -> 
             RGBColor[
              0.9056772965506277, 0.5643789388155198, 0.459773379568276], 
             UndirectedEdge[98, 296] -> 
             RGBColor[
              0.559521387516622, 0.6516299340358314, 0.9592598962290395], 
             UndirectedEdge[18, 88] -> 
             RGBColor[
              0.7253109400374347, 0.7839674018676228, 0.9648635309809819], 
             UndirectedEdge[100, 240] -> 
             RGBColor[
              0.9225569449368545, 0.6891426551809652, 0.4428066838476417], 
             UndirectedEdge[2, 214] -> 
             RGBColor[
              0.2218197182328839, 0.35047696641817105`, 0.9359436768492726], 
             UndirectedEdge[114, 169] -> 
             RGBColor[
              0.2987181224804576, 0.4313020649228039, 0.9403229272101774], 
             UndirectedEdge[37, 295] -> 
             RGBColor[
              0.7589937750806162, 0.8117908085079812, 0.9765759562555065], 
             UndirectedEdge[45, 225] -> 
             RGBColor[
              0.9093933228339569, 0.6627226292341221, 0.2529269618420678], 
             UndirectedEdge[38, 74] -> 
             RGBColor[
              0.5280791848415985, 0.6267970188090106, 0.9562568575389798], 
             UndirectedEdge[38, 158] -> 
             RGBColor[
              0.41078817614673724`, 0.5302258041894045, 0.9473960372317167], 
             UndirectedEdge[69, 135] -> 
             RGBColor[
              0.9915668730357023, 0.9888448386688236, 0.6487056199187353], 
             UndirectedEdge[113, 224] -> 
             RGBColor[
              0.9644670009376046, 0.9390549690861945, 0.644851681061125], 
             UndirectedEdge[124, 282] -> 
             RGBColor[
              0.9556754222393467, 0.9664633829977154, 0.9599141278341408], 
             UndirectedEdge[56, 79] -> 
             RGBColor[
              0.47131158576889715`, 0.5800856534095411, 0.9519605579459619], 
             UndirectedEdge[49, 146] -> 
             RGBColor[
              0.23350254559126715`, 0.3627563587058691, 0.9366089965841382], 
             UndirectedEdge[47, 166] -> 
             RGBColor[
              0.8183915236203407, 0.8543538869413033, 0.7072534135870767], 
             UndirectedEdge[189, 197] -> 
             RGBColor[
              0.22117434471858483`, 0.3497986379355985, 0.9359069237823778], 
             UndirectedEdge[125, 256] -> 
             RGBColor[
              0.9939365705713255, 0.9894392624958468, 0.5814113097167279], 
             UndirectedEdge[69, 138] -> 
             RGBColor[
              0.8498609562052564, 0.8791517168657417, 0.7275038724573385], 
             UndirectedEdge[170, 255] -> 
             RGBColor[
              0.8904238882805281, 0.5212468151692371, 0.2318221335134233], 
             UndirectedEdge[41, 104] -> 
             RGBColor[
              0.3210313076505878, 0.45029407852530423`, 0.9417569530026035], 
             UndirectedEdge[185, 283] -> 
             RGBColor[
              0.5933967145885973, 0.6807852109772019, 0.9611335095376532], 
             UndirectedEdge[103, 277] -> 
             RGBColor[
              0.3139559658390563, 0.44358745874044936`, 0.9413272933992227], 
             UndirectedEdge[45, 282] -> 
             RGBColor[
              0.9107404155806164, 0.7089403181351821, 0.5747043826447977], 
             UndirectedEdge[222, 245] -> 
             RGBColor[
              0.43026765068117134`, 0.5470979459642735, 0.9486372521240278], 
             UndirectedEdge[53, 195] -> 
             RGBColor[
              0.825436438508141, 0.1965211894578074, 0.17199126828273137`], 
             UndirectedEdge[121, 136] -> 
             RGBColor[
              0.9937588965574554, 0.9890592357457773, 0.5620725897838914], 
             UndirectedEdge[92, 211] -> 
             RGBColor[
              0.2517282610763278, 0.3819127412577725, 0.9376469241184826], 
             UndirectedEdge[26, 137] -> 
             RGBColor[
              0.9157005980775512, 0.6698289128207927, 0.5378409832086813], 
             UndirectedEdge[139, 148] -> 
             RGBColor[
              0.24714609636833407`, 0.37709659562364867`, 0.9373859766170676],
              UndirectedEdge[69, 258] -> 
             RGBColor[
              0.9774025219667993, 0.9792619140373138, 0.7166055281881865], 
             UndirectedEdge[244, 272] -> 
             RGBColor[
              0.23289575947638014`, 0.3621185880266611, 0.936574441012555], 
             UndirectedEdge[100, 256] -> 
             RGBColor[
              0.9227141531364094, 0.6894789076236262, 0.45991782619265503`], 
             UndirectedEdge[29, 206] -> 
             RGBColor[
              0.23974836289368467`, 0.3693211086983992, 0.9369646866396522], 
             UndirectedEdge[101, 213] -> 
             RGBColor[
              0.48723449014775655`, 0.5939071986311, 0.9529668827570787], 
             UndirectedEdge[39, 107] -> 
             RGBColor[
              0.8508398666409367, 0.3774266775234726, 0.1957554594288977], 
             UndirectedEdge[134, 252] -> 
             RGBColor[
              0.28726603661361816`, 0.4192651965725739, 0.9396707478619037], 
             UndirectedEdge[14, 288] -> 
             RGBColor[
              0.8422994070509533, 0.32063854118780577`, 0.1879239462417765], 
             UndirectedEdge[155, 202] -> 
             RGBColor[
              0.22021191752572378`, 0.34878706593449305`, 0.9358521149775277],
              UndirectedEdge[220, 228] -> 
             RGBColor[
              0.5367674910110247, 0.6220540079829862, 0.9601435922342896], 
             UndirectedEdge[228, 266] -> 
             RGBColor[
              0.5319885984693589, 0.6170310889224077, 0.9598714413737797], 
             UndirectedEdge[113, 249] -> 
             RGBColor[
              0.8889946281823045, 0.5565337231850392, 0.5595095853153444], 
             UndirectedEdge[109, 179] -> 
             RGBColor[
              0.9574076164080104, 0.9658098047595847, 0.8736496587222751], 
             UndirectedEdge[41, 209] -> 
             RGBColor[
              0.3110735460011261, 0.43982783967316585`, 0.9411898732078549], 
             UndirectedEdge[76, 261] -> 
             RGBColor[
              0.3474685023612617, 0.4740454489620557, 0.9434102824444082], 
             UndirectedEdge[114, 219] -> 
             RGBColor[
              0.28932309287771063`, 0.4214272931310352, 0.9397878941730018], 
             UndirectedEdge[130, 266] -> 
             RGBColor[
              0.21328047700996416`, 0.3415016824737179, 0.9354573796943026], 
             UndirectedEdge[1, 185] -> 
             RGBColor[
              0.4932964811819127, 0.5985745570433215, 0.9535142966293955], 
             UndirectedEdge[202, 208] -> 
             RGBColor[
              0.2570404037299817, 0.3874961399960602, 0.9379494427839974], 
             UndirectedEdge[8, 285] -> 
             RGBColor[
              0.5173103167774687, 0.616953959461616, 0.9557723663648683], 
             UndirectedEdge[65, 210] -> 
             RGBColor[
              0.33323684341077736`, 0.46112891713616844`, 0.9425250486073942],
              UndirectedEdge[63, 183] -> 
             RGBColor[
              0.28955139027076127`, 0.4202094545444958, 0.939854272337463], 
             UndirectedEdge[51, 86] -> 
             RGBColor[
              0.9842148587859489, 0.9592452118717956, 0.5566107984418112], 
             UndirectedEdge[91, 191] -> 
             RGBColor[
              0.2582507185162887, 0.38876825757485856`, 0.9380183684205773], 
             UndirectedEdge[122, 181] -> 
             RGBColor[
              0.6690049122710009, 0.741072705352345, 0.9678340796895172], 
             UndirectedEdge[17, 42] -> 
             RGBColor[
              0.2753301177357401, 0.4067197890509576, 0.9389910149394182], 
             UndirectedEdge[90, 253] -> 
             RGBColor[
              0.3501359199582715, 0.4765804790552632, 0.9435720225064269], 
             UndirectedEdge[60, 136] -> 
             RGBColor[
              0.9594950595498875, 0.8659435606987382, 0.3644021078697419], 
             UndirectedEdge[80, 210] -> 
             RGBColor[
              0.3231934350804644, 0.45057265819214215`, 0.941953091360874], 
             UndirectedEdge[229, 259] -> 
             RGBColor[
              0.40532480006275245`, 0.5251965784018511, 0.9471300119909675], 
             UndirectedEdge[97, 159] -> 
             RGBColor[
              0.2524370830607903, 0.3826577581053522, 0.9376872904818896], 
             UndirectedEdge[242, 280] -> 
             RGBColor[
              0.25424538211649345`, 0.38455839506567835`, 0.9377902704379731],
              UndirectedEdge[88, 99] -> 
             RGBColor[
              0.43585477652737337`, 0.5505550934269655, 0.9493751482779511], 
             UndirectedEdge[21, 46] -> 
             RGBColor[
              0.3377964064979223, 0.4654684905987692, 0.942801288807799], 
             UndirectedEdge[246, 256] -> 
             RGBColor[
              0.7970579460912328, 0.838735601938289, 0.8428569136112316], 
             UndirectedEdge[14, 135] -> 
             RGBColor[
              0.9063967184206538, 0.582821195587901, 0.4915857246054881], 
             UndirectedEdge[67, 179] -> 
             RGBColor[
              0.9529824528221467, 0.9622812994340826, 0.8732275826690652], 
             UndirectedEdge[66, 69] -> 
             RGBColor[
              0.9697469416824389, 0.9735523947961, 0.7295644287144893], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.7503642165832218, 0.805193848255281, 0.9757004322912739], 
             UndirectedEdge[116, 133] -> 
             RGBColor[
              0.3362774461822365, 0.4656883549123332, 0.9426482794056301], 
             UndirectedEdge[2, 83] -> 
             RGBColor[
              0.2235228930753953, 0.35226711116517256`, 0.9360406701369322], 
             UndirectedEdge[103, 168] -> 
             RGBColor[
              0.3323449528082868, 0.45951507499583777`, 0.9424990233881594], 
             UndirectedEdge[26, 199] -> 
             RGBColor[
              0.5823809948253185, 0.6469022092217233, 0.9089577047840149], 
             UndirectedEdge[91, 239] -> 
             RGBColor[
              0.3418733579527955, 0.46719445818593675`, 0.9431271687979139], 
             UndirectedEdge[13, 298] -> 
             RGBColor[
              0.2956902341413986, 0.428119562299244, 0.9401504934486273], 
             UndirectedEdge[229, 261] -> 
             RGBColor[
              0.3735150674883849, 0.49794171087045247`, 0.9450210277073223], 
             UndirectedEdge[141, 179] -> 
             RGBColor[
              0.9463245104461602, 0.8129581160989631, 0.4961968694388046], 
             UndirectedEdge[59, 195] -> 
             RGBColor[
              0.825976956508043, 0.20067584766155147`, 0.17250886892986522`], 
             UndirectedEdge[134, 253] -> 
             RGBColor[
              0.2853630721871043, 0.41726506030539445`, 0.9395623768529974], 
             UndirectedEdge[42, 292] -> 
             RGBColor[
              0.24874967528223313`, 0.3787820587349321, 0.9374772980639317], 
             UndirectedEdge[70, 238] -> 
             RGBColor[
              0.27137415800540265`, 0.40256182455203926`, 0.9387657288850935],
              UndirectedEdge[178, 202] -> 
             RGBColor[
              0.25258870101180897`, 0.3828171181850061, 0.9376959248999015], 
             UndirectedEdge[29, 191] -> 
             RGBColor[
              0.24335597488348387`, 0.37311293763548947`, 0.9371701348054876],
              UndirectedEdge[17, 38] -> 
             RGBColor[
              0.3570833446280458, 0.48255148540021425`, 0.944016408991876], 
             UndirectedEdge[40, 162] -> 
             RGBColor[
              0.2608696072714334, 0.3915208757036531, 0.9381675102608841], 
             UndirectedEdge[13, 95] -> 
             RGBColor[
              0.3973874477451902, 0.5174174988379855, 0.946816060198244], 
             UndirectedEdge[206, 270] -> 
             RGBColor[
              0.23246458235718154`, 0.361665393536175, 0.936549886113486], 
             UndirectedEdge[16, 295] -> 
             RGBColor[
              0.9153775706767935, 0.9307671307468549, 0.7575047799513781], 
             UndirectedEdge[37, 124] -> 
             RGBColor[
              0.8141982878176429, 0.8555000754915749, 0.971117336553347], 
             UndirectedEdge[22, 177] -> 
             RGBColor[
              0.6182933062719121, 0.6973901264603323, 0.9651824367082749], 
             UndirectedEdge[115, 204] -> 
             RGBColor[
              0.22623702836427392`, 0.35511983943990055`, 0.9361952361264305],
              UndirectedEdge[192, 200] -> 
             RGBColor[
              0.875491048752759, 0.5275157568382065, 0.21781901789668148`], 
             UndirectedEdge[13, 171] -> 
             RGBColor[
              0.3622408475068787, 0.48793453204456394`, 0.9443115057758112], 
             UndirectedEdge[39, 52] -> 
             RGBColor[
              0.8426203651830106, 0.3142479875093471, 0.1878844555501885], 
             UndirectedEdge[92, 216] -> 
             RGBColor[
              0.25996759819388404`, 0.3905728069724701, 0.9381161421783205], 
             UndirectedEdge[82, 127] -> 
             RGBColor[
              0.9139243851963341, 0.6223920448146217, 0.4422603075520308], 
             UndirectedEdge[53, 150] -> 
             RGBColor[
              0.8968677108265174, 0.6080372180241437, 0.5636073731303677], 
             UndirectedEdge[18, 66] -> 
             RGBColor[
              0.9464282973427488, 0.95956689239061, 0.9755670982476465], 
             UndirectedEdge[31, 36] -> 
             RGBColor[
              0.6892039970441424, 0.7567703364683878, 0.9699034319627848], 
             UndirectedEdge[71, 181] -> 
             RGBColor[
              0.6717068148993812, 0.7432662316253906, 0.9680467833618187], 
             UndirectedEdge[43, 143] -> 
             RGBColor[
              0.3594618944461463, 0.48576955871427996`, 0.9441255719478039], 
             UndirectedEdge[75, 185] -> 
             RGBColor[
              0.6492913495741017, 0.7248125960357876, 0.9664570141991338], 
             UndirectedEdge[46, 145] -> 
             RGBColor[
              0.280670988716232, 0.4123333830822331, 0.9392951696406466], 
             UndirectedEdge[62, 255] -> 
             RGBColor[
              0.9769015351320889, 0.9322978840038133, 0.4878701995815442], 
             UndirectedEdge[111, 242] -> 
             RGBColor[
              0.24172339249525976`, 0.3713969900337639, 0.9370771616536675], 
             UndirectedEdge[4, 193] -> 
             RGBColor[
              0.46955924674976174`, 0.5787870298978665, 0.9517883446566966], 
             UndirectedEdge[18, 258] -> 
             RGBColor[
              0.9540838776271092, 0.9652764116318238, 0.9626081977213435], 
             UndirectedEdge[81, 267] -> 
             RGBColor[
              0.3818442604921369, 0.5035684061042389, 0.9457044452357559], 
             UndirectedEdge[75, 124] -> 
             RGBColor[
              0.8391031020269322, 0.8749559056354701, 0.9735996156850079], 
             UndirectedEdge[72, 106] -> 
             RGBColor[
              0.6542381545327312, 0.7298150858058879, 0.966172003106812], 
             UndirectedEdge[262, 271] -> 
             RGBColor[
              0.9857223415414609, 0.9625888518240449, 0.4765328762826566], 
             UndirectedEdge[17, 235] -> 
             RGBColor[
              0.2691307812557516, 0.40020389334985473`, 0.9386379718979794], 
             UndirectedEdge[263, 279] -> 
             RGBColor[
              0.25988809011317837`, 0.3904892389385449, 0.938111614310746], 
             UndirectedEdge[3, 252] -> 
             RGBColor[
              0.33892810141516894`, 0.46722471408127325`, 0.9428449860179196],
              UndirectedEdge[48, 158] -> 
             RGBColor[
              0.4086574804982366, 0.5283803027105503, 0.9472602711890945], 
             UndirectedEdge[18, 36] -> 
             RGBColor[
              0.8529859949186596, 0.8858242206407632, 0.9761422011869598], 
             UndirectedEdge[105, 196] -> 
             RGBColor[
              0.28505137622914434`, 0.4169374480909134, 0.9395446262293043], 
             UndirectedEdge[269, 298] -> 
             RGBColor[
              0.2561386884802381, 0.3865483800965307, 0.9378980914344927], 
             UndirectedEdge[85, 207] -> 
             RGBColor[
              0.8326069689699811, 0.8699635257728993, 0.9837364200787462], 
             UndirectedEdge[79, 103] -> 
             RGBColor[
              0.33687382527310783`, 0.4634377566971172, 0.9427875991368931], 
             UndirectedEdge[76, 128] -> 
             RGBColor[
              0.2667781164198233, 0.397731093439728, 0.9385039911160289], 
             UndirectedEdge[10, 265] -> 
             RGBColor[
              0.21694931138635237`, 0.3453578600208368, 0.9356663143844839], 
             UndirectedEdge[88, 198] -> 
             RGBColor[
              0.48423825814620036`, 0.592165458504841, 0.9525401559859066], 
             UndirectedEdge[63, 143] -> 
             RGBColor[
              0.36063166824627285`, 0.4867827579854089, 0.9442001088999576], 
             UndirectedEdge[49, 242] -> 
             RGBColor[
              0.23849346114208345`, 0.3680021273920998, 0.9368932218413593], 
             UndirectedEdge[252, 253] -> 
             RGBColor[
              0.29862833529686444`, 0.43120769290001126`, 0.9403178139629], 
             UndirectedEdge[16, 125] -> 
             RGBColor[
              0.9930477640549809, 0.9875381952295093, 0.4846702054906215], 
             UndirectedEdge[59, 100] -> 
             RGBColor[
              0.8414952433239204, 0.3199562002850287, 0.1873691979101476], 
             UndirectedEdge[75, 295] -> 
             RGBColor[
              0.7838985892899054, 0.8312466386518764, 0.9790582353871675], 
             UndirectedEdge[94, 295] -> 
             RGBColor[
              0.8496169506590368, 0.8829255104904983, 0.9855184172875062], 
             UndirectedEdge[26, 192] -> 
             RGBColor[
              0.9254105636090766, 0.7341129135369036, 0.5467339360364043], 
             UndirectedEdge[132, 188] -> 
             RGBColor[
              0.20621351468350757`, 0.3340738569973212, 0.9350549266444448], 
             UndirectedEdge[186, 196] -> 
             RGBColor[
              0.255450766680841, 0.38582533066860314`, 0.9378589153057062], 
             UndirectedEdge[110, 179] -> 
             RGBColor[
              0.9932962755631108, 0.991495851914556, 0.7607615928093651], 
             UndirectedEdge[61, 177] -> 
             RGBColor[
              0.49302351294995017`, 0.5983715477396933, 0.9534876687205165], 
             UndirectedEdge[21, 264] -> 
             RGBColor[
              0.339057995027486, 0.46679450013267343`, 0.9428731344082046], 
             UndirectedEdge[200, 225] -> 
             RGBColor[
              0.9234794071043728, 0.7275983937614409, 0.2647165314935854], 
             UndirectedEdge[83, 197] -> 
             RGBColor[
              0.21339436331142053`, 0.34162138419735716`, 0.9354638653506908],
              UndirectedEdge[220, 226] -> 
             RGBColor[
              0.21805937466237113`, 0.3465246069060093, 0.9357295308458616], 
             UndirectedEdge[13, 140] -> 
             RGBColor[
              0.3171012005840623, 0.44883683866464263`, 0.941435247389312], 
             UndirectedEdge[144, 158] -> 
             RGBColor[
              0.35967077338482056`, 0.4859504791523989, 0.9441388815290719], 
             UndirectedEdge[62, 225] -> 
             RGBColor[
              0.9779057939111673, 0.9356854846768198, 0.49177155529990685`], 
             UndirectedEdge[65, 277] -> 
             RGBColor[
              0.318505826054183, 0.44836965030434695`, 0.9415864012075592], 
             UndirectedEdge[99, 261] -> 
             RGBColor[
              0.38406488890105717`, 0.5070794359286672, 0.9456932529988971], 
             UndirectedEdge[260, 290] -> 
             RGBColor[
              0.7310412488235707, 0.7895991808750945, 0.9740726900092733], 
             UndirectedEdge[72, 267] -> 
             RGBColor[
              0.5598273932891142, 0.6533873840765647, 0.9585897688439947], 
             UndirectedEdge[39, 170] -> 
             RGBColor[
              0.8447130757608642, 0.3303334780423518, 0.18988843756291957`], 
             UndirectedEdge[92, 163] -> 
             RGBColor[
              0.25122830224652154`, 0.3813872528284255, 0.937618452202748], 
             UndirectedEdge[102, 133] -> 
             RGBColor[
              0.36773492193593726`, 0.4929352393114849, 0.9446527219439024], 
             UndirectedEdge[184, 197] -> 
             RGBColor[
              0.22396867403815082`, 0.3527356552211741, 0.9360660567032872], 
             UndirectedEdge[44, 200] -> 
             RGBColor[
              0.9255256121005535, 0.7345007236853389, 0.2726656515103572], 
             UndirectedEdge[115, 132] -> 
             RGBColor[
              0.21415169536183348`, 0.34241738819996653`, 0.9355069942905895],
              UndirectedEdge[9, 283] -> 
             RGBColor[
              0.5677763920680372, 0.6599854789726345, 0.959116583898501], 
             UndirectedEdge[52, 165] -> 
             RGBColor[
              0.8989841919236675, 0.5410964430503309, 0.2712031000963182], 
             UndirectedEdge[160, 256] -> 
             RGBColor[
              0.7927339846129686, 0.8352252152179895, 0.8425165155244698], 
             UndirectedEdge[45, 215] -> 
             RGBColor[
              0.9264635101364236, 0.7188538247686493, 0.4669105670802081], 
             UndirectedEdge[16, 124] -> 
             RGBColor[
              0.9705820834138202, 0.9744763977304486, 0.7520461602492186], 
             UndirectedEdge[160, 246] -> 
             RGBColor[
              0.5945439555585024, 0.6817165928791875, 0.9612238245492863], 
             UndirectedEdge[57, 204] -> 
             RGBColor[
              0.23896784394150833`, 0.36850073379190207`, 0.9369202372400001],
              UndirectedEdge[112, 252] -> 
             RGBColor[
              0.27637236437381507`, 0.40781525634982796`, 0.9390503693435908],
              UndirectedEdge[5, 248] -> 
             RGBColor[
              0.21465495916745328`, 0.3429463503684412, 0.9355356544198075], 
             UndirectedEdge[186, 276] -> 
             RGBColor[
              0.2308753294209801, 0.3599949879357713, 0.9364593805098584], 
             UndirectedEdge[95, 154] -> 
             RGBColor[
              0.6149232954890904, 0.696747339779964, 0.9638633724984019], 
             UndirectedEdge[198, 290] -> 
             RGBColor[
              0.5385920372825843, 0.6362923050176035, 0.9568190845839761], 
             UndirectedEdge[77, 191] -> 
             RGBColor[
              0.24496070190330402`, 0.37479960747889, 0.9372615216352855], 
             UndirectedEdge[36, 224] -> 
             RGBColor[
              0.8645479914252601, 0.8604819797945611, 0.6563901597051076], 
             UndirectedEdge[29, 203] -> 
             RGBColor[
              0.25120844967144335`, 0.38136638651329235`, 0.9376173216279664],
              UndirectedEdge[25, 172] -> 
             RGBColor[
              0.2606528759791422, 0.3912930773738975, 0.9381551677344133], 
             UndirectedEdge[224, 260] -> 
             RGBColor[
              0.9093392465848947, 0.8957090172216551, 0.6607919677185569], 
             UndirectedEdge[45, 255] -> 
             RGBColor[
              0.9083890640548784, 0.6593350285611156, 0.24902560612370514`], 
             UndirectedEdge[102, 239] -> 
             RGBColor[
              0.398228532934502, 0.519347272504989, 0.9465957478722895], 
             UndirectedEdge[33, 239] -> 
             RGBColor[
              0.6628984653958889, 0.7326583838158534, 0.9695703125580974], 
             UndirectedEdge[64, 92] -> 
             RGBColor[
              0.24737632360791623`, 0.3773385790496996, 0.9373990877177711], 
             UndirectedEdge[32, 268] -> 
             RGBColor[
              0.2593869141835333, 0.38996247126009875`, 0.938083073082976], 
             UndirectedEdge[85, 240] -> 
             RGBColor[
              0.9572796113633043, 0.9651601387742601, 0.8410616153789832], 
             UndirectedEdge[1, 174] -> 
             RGBColor[
              0.4054230753198295, 0.5255788235109453, 0.9470541777511985], 
             UndirectedEdge[2, 184] -> 
             RGBColor[
              0.23409720380212556`, 0.3633813821889895, 0.9366428614895286], 
             UndirectedEdge[60, 85] -> 
             RGBColor[
              0.9228540566499766, 0.8416985659067688, 0.6257891591988634], 
             UndirectedEdge[121, 127] -> 
             RGBColor[
              0.9136911090272399, 0.6218930906767679, 0.41686963615976463`], 
             UndirectedEdge[132, 212] -> 
             RGBColor[
              0.20921642322248857`, 0.3372301042671883, 0.9352259378433346], 
             UndirectedEdge[172, 206] -> 
             RGBColor[
              0.2530845856194636, 0.3833383243485512, 0.9377241647947119], 
             UndirectedEdge[147, 148] -> 
             RGBColor[
              0.2325030525609364, 0.36170582815947316`, 0.9365520769346783], 
             UndirectedEdge[118, 226] -> 
             RGBColor[
              0.17892828959271728`, 0.30539535544371077`, 0.9335010734403975],
              UndirectedEdge[75, 283] -> 
             RGBColor[
              0.6746177643537297, 0.7453737204958732, 0.9684508023443001], 
             UndirectedEdge[188, 243] -> 
             RGBColor[
              0.21194079974675017`, 0.3400935967296356, 0.9353810870560375], 
             UndirectedEdge[88, 258] -> 
             RGBColor[
              0.7329940972360016, 0.7896974879262988, 0.9518579499321382], 
             UndirectedEdge[197, 293] -> 
             RGBColor[
              0.20988077542261582`, 0.33792838055188446`, 0.9352637717183109],
              UndirectedEdge[86, 179] -> 
             RGBColor[
              0.9842570845883489, 0.9592626733262417, 0.5559110076191691], 
             UndirectedEdge[41, 76] -> 
             RGBColor[
              0.32564319585170254`, 0.45514146543527656`, 0.9420195932129798],
              UndirectedEdge[175, 242] -> 
             RGBColor[
              0.2674717938620085, 0.3984601924131547, 0.9385434950201575], 
             UndirectedEdge[89, 285] -> 
             RGBColor[
              0.3304519019187142, 0.457812130049975, 0.9423807168287202], 
             UndirectedEdge[138, 171] -> 
             RGBColor[
              0.5625186052786886, 0.6537822219340037, 0.9596386929535714], 
             UndirectedEdge[181, 207] -> 
             RGBColor[
              0.729702675862836, 0.7887685434205706, 0.9736936013369495], 
             UndirectedEdge[17, 55] -> 
             RGBColor[
              0.28645859801019335`, 0.41841652740581015`, 0.939624765427937], 
             UndirectedEdge[142, 295] -> 
             RGBColor[
              0.7481542644116976, 0.8033229003900898, 0.9754955751330152], 
             UndirectedEdge[53, 200] -> 
             RGBColor[
              0.8588625397294595, 0.4100527991192301, 0.2023008600078583], 
             UndirectedEdge[33, 237] -> 
             RGBColor[
              0.7767209844121652, 0.8262100194866766, 0.9782143643357628], 
             UndirectedEdge[51, 67] -> 
             RGBColor[
              0.9529402270197467, 0.9622638379796367, 0.8739273734917072], 
             UndirectedEdge[47, 48] -> 
             RGBColor[
              0.5288713488786927, 0.6272983725157164, 0.9563690029663805], 
             UndirectedEdge[102, 237] -> 
             RGBColor[
              0.5120510519507784, 0.6128989081758123, 0.9552397996499549], 
             UndirectedEdge[150, 282] -> 
             RGBColor[
              0.9628316709480902, 0.9718005015674145, 0.9478004654188247], 
             UndirectedEdge[214, 293] -> 
             RGBColor[
              0.21107172389025777`, 0.33918014290187026`, 0.9353315944716927],
              UndirectedEdge[73, 245] -> 
             RGBColor[
              0.37670637299800835`, 0.5007058593032094, 0.9452243748724349], 
             UndirectedEdge[82, 192] -> 
             RGBColor[
              0.930031406620387, 0.7358466203284666, 0.4572790883268795], 
             UndirectedEdge[82, 266] -> 
             RGBColor[
              0.6213553148465931, 0.6847435984870042, 0.8214592367687926], 
             UndirectedEdge[30, 38] -> 
             RGBColor[
              0.4400713503236684, 0.5553482940395915, 0.949328558422408], 
             UndirectedEdge[146, 242] -> 
             RGBColor[
              0.23544148915831797`, 0.3647943113309621, 0.9367194165518717], 
             UndirectedEdge[25, 77] -> 
             RGBColor[
              0.24892138027318342`, 0.37896253156714604`, 0.9374870764091515],
              UndirectedEdge[68, 271] -> 
             RGBColor[
              0.9259155815977133, 0.7290271362933656, 0.2919182148886562], 
             UndirectedEdge[23, 267] -> 
             RGBColor[
              0.3821106817559689, 0.50384843174461, 0.9457196175325961], 
             UndirectedEdge[10, 161] -> 
             RGBColor[
              0.21385191803304957`, 0.3421023032204342, 0.935489922415196], 
             UndirectedEdge[223, 287] -> 
             RGBColor[
              0.9141648921008272, 0.6925393884549282, 0.24954185631357317`], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.43016772773719436`, 0.545286907400802, 0.949107366939159], 
             UndirectedEdge[218, 229] -> 
             RGBColor[
              0.3012157370951104, 0.430446886752895, 0.9405925945789568], 
             UndirectedEdge[62, 170] -> 
             RGBColor[
              0.9083710867000301, 0.580339218042234, 0.42464655483310587`], 
             UndirectedEdge[188, 294] -> 
             RGBColor[
              0.20780626806211017`, 0.3357479417846294, 0.9351456315930887], 
             UndirectedEdge[181, 299] -> 
             RGBColor[
              0.8541508128707371, 0.884172913273241, 0.8565895585797871], 
             UndirectedEdge[69, 109] -> 
             RGBColor[
              0.957103333757725, 0.9637481152069529, 0.737975761375697], 
             UndirectedEdge[48, 175] -> 
             RGBColor[
              0.3540970438547585, 0.4798066886867111, 0.9438319175031515], 
             UndirectedEdge[248, 270] -> 
             RGBColor[
              0.21830317142063266`, 0.3467808527565494, 0.9357434147105796], 
             UndirectedEdge[85, 232] -> 
             RGBColor[
              0.9568611020652522, 0.9642649897035074, 0.7955094610260169], 
             UndirectedEdge[65, 152] -> 
             RGBColor[
              0.270606352963235, 0.4017548127710696, 0.9387220035238077], 
             UndirectedEdge[43, 63] -> 
             RGBColor[
              0.3233435154432426, 0.45448563418447746`, 0.9418241407759673], 
             UndirectedEdge[184, 293] -> 
             RGBColor[
              0.22334920945949943`, 0.35208455867268873`, 0.9360307791119489],
              UndirectedEdge[24, 260] -> 
             RGBColor[
              0.9023952825645615, 0.924495379134781, 0.9727268847769307], 
             UndirectedEdge[201, 229] -> 
             RGBColor[
              0.3337508945428317, 0.46349998287045846`, 0.9424872897693092], 
             UndirectedEdge[17, 48] -> 
             RGBColor[
              0.35495264897954515`, 0.4807059839213601, 0.9438806429492537], 
             UndirectedEdge[153, 163] -> 
             RGBColor[
              0.2574205034515923, 0.3878956489031873, 0.9379710889008359], 
             UndirectedEdge[33, 200] -> 
             RGBColor[
              0.9003293088366926, 0.7550036483702731, 0.6091535540920102], 
             UndirectedEdge[33, 282] -> 
             RGBColor[
              0.9391598487497231, 0.9536036259867218, 0.9690629330997416], 
             UndirectedEdge[150, 237] -> 
             RGBColor[
              0.8003928066105324, 0.8444068950673695, 0.956951896654846], 
             UndirectedEdge[172, 203] -> 
             RGBColor[
              0.26454467239722235`, 0.39538360216344437`, 0.9383767997830261],
              UndirectedEdge[56, 93] -> 
             RGBColor[
              0.5394509250519448, 0.6369895888012234, 0.9568866993753897], 
             UndirectedEdge[122, 299] -> 
             RGBColor[
              0.8093386473760087, 0.8488870251734923, 0.8523133648913199], 
             UndirectedEdge[44, 100] -> 
             RGBColor[
              0.9076177976951124, 0.6402494666473935, 0.25721638876551267`], 
             UndirectedEdge[31, 171] -> 
             RGBColor[
              0.5185950159671473, 0.6191084488745244, 0.955507160509088], 
             UndirectedEdge[136, 256] -> 
             RGBColor[
              0.9940778224627702, 0.9897413860088904, 0.596785706394875], 
             UndirectedEdge[146, 159] -> 
             RGBColor[
              0.2389221548438223, 0.3684527116533779, 0.9369176353134778], 
             UndirectedEdge[65, 133] -> 
             RGBColor[
              0.3190318248130566, 0.44882524399181684`, 0.9416199173833522], 
             UndirectedEdge[58, 245] -> 
             RGBColor[
              0.48666290222101594`, 0.5933487734884098, 0.952947963928872], 
             UndirectedEdge[172, 272] -> 
             RGBColor[
              0.2463878565667746, 0.37629963751702955`, 0.937342795982084], 
             UndirectedEdge[99, 218] -> 
             RGBColor[
              0.3117655585077827, 0.43958461181110975`, 0.9412648198705315], 
             UndirectedEdge[18, 113] -> 
             RGBColor[
              0.9529050044310041, 0.9643972099323963, 0.9646037225429771], 
             UndirectedEdge[43, 131] -> 
             RGBColor[
              0.3235024771639835, 0.45462331883733487`, 0.9418342696762487], 
             UndirectedEdge[2, 156] -> 
             RGBColor[
              0.2292281520802934, 0.3582637001136342, 0.9363655761970868], 
             UndirectedEdge[165, 232] -> 
             RGBColor[
              0.9871784526525289, 0.9674285696046385, 0.48831934332178484`], 
             UndirectedEdge[173, 186] -> 
             RGBColor[
              0.24357136840210497`, 0.3733393298802981, 0.937182401147727], 
             UndirectedEdge[39, 281] -> 
             RGBColor[
              0.8518045532150162, 0.3848416812601996, 0.19667924438169382`], 
             UndirectedEdge[77, 91] -> 
             RGBColor[
              0.25932242623621204`, 0.38989469033869195`, 0.9380794005897775],
              UndirectedEdge[15, 19] -> 
             RGBColor[
              0.265094966907718, 0.3959619965846625, 0.938408138241311], 
             UndirectedEdge[119, 241] -> 
             RGBColor[
              0.2806500707405608, 0.4123113969635265, 0.9392939783928775], 
             UndirectedEdge[103, 116] -> 
             RGBColor[
              0.3006123597209014, 0.43202989779004775`, 0.9404770506166615], 
             UndirectedEdge[99, 257] -> 
             RGBColor[
              0.37939685727732686`, 0.5030362215582833, 0.9453958101516111], 
             UndirectedEdge[17, 253] -> 
             RGBColor[
              0.2964738820674033, 0.42894322595562323`, 0.9401951210387102], 
             UndirectedEdge[204, 292] -> 
             RGBColor[
              0.2369721103072519, 0.36640309120547765`, 0.9368065831619525], 
             UndirectedEdge[65, 241] -> 
             RGBColor[
              0.2834960053804121, 0.4153026547126882, 0.9394560501604341], 
             UndirectedEdge[71, 256] -> 
             RGBColor[
              0.8124222635893662, 0.8512090470378892, 0.8440664489660341], 
             UndirectedEdge[37, 102] -> 
             RGBColor[
              0.5330127818666326, 0.6293292071697167, 0.9572915771331396], 
             UndirectedEdge[61, 217] -> 
             RGBColor[
              0.686937545269946, 0.7542032342825437, 0.9702221270801157], 
             UndirectedEdge[35, 184] -> 
             RGBColor[
              0.23183414268000563`, 0.3610027614632789, 0.9365139835065228], 
             UndirectedEdge[164, 241] -> 
             RGBColor[
              0.33149984085228634`, 0.458806984736167, 0.9424442983869149], 
             UndirectedEdge[192, 255] -> 
             RGBColor[
              0.9119702371400515, 0.6765104448805886, 0.25204962038332024`], 
             UndirectedEdge[112, 134] -> 
             RGBColor[
              0.2631071012640549, 0.3938726237552112, 0.9382949322336882], 
             UndirectedEdge[44, 195] -> 
             RGBColor[
              0.892099510879235, 0.5209691140239162, 0.24235605978523028`], 
             UndirectedEdge[127, 281] -> 
             RGBColor[
              0.8344242447380918, 0.2656054066230123, 0.18059800167880746`], 
             UndirectedEdge[59, 192] -> 
             RGBColor[
              0.8488981465441187, 0.3665071091151284, 0.1940529052630896], 
             UndirectedEdge[108, 264] -> 
             RGBColor[
              0.3192908615453144, 0.4496732026354332, 0.9416135901421105], 
             UndirectedEdge[136, 296] -> 
             RGBColor[
              0.8445716246365338, 0.8749311705589841, 0.7198898610709794], 
             UndirectedEdge[118, 130] -> 
             RGBColor[
              0.17892828448197629`, 0.3053953500719979, 0.9335010731493483], 
             UndirectedEdge[85, 136] -> 
             RGBColor[
              0.9562666668799304, 0.9629935529487204, 0.7308088595324563], 
             UndirectedEdge[104, 157] -> 
             RGBColor[
              0.3155261405863954, 0.44552577951204275`, 0.9414061686253012], 
             UndirectedEdge[158, 217] -> 
             RGBColor[
              0.6053338779034495, 0.6866046110497097, 0.9641707450092601], 
             UndirectedEdge[11, 174] -> 
             RGBColor[
              0.36791464439567134`, 0.49309090587299315`, 0.9446641737001142],
              UndirectedEdge[39, 220] -> 
             RGBColor[
              0.5623622253882596, 0.4395170049728193, 0.5745682237352395], 
             UndirectedEdge[32, 208] -> 
             RGBColor[
              0.27110861374646283`, 0.402282720699415, 0.9387506065323843], 
             UndirectedEdge[27, 103] -> 
             RGBColor[
              0.2686276829189324, 0.3996751050995809, 0.9386093211919647], 
             UndirectedEdge[212, 250] -> 
             RGBColor[
              0.21715203202826977`, 0.34557093226872304`, 0.9356778590251427],
              UndirectedEdge[129, 298] -> 
             RGBColor[
              0.26058075662513375`, 0.3912172753602034, 0.9381510606438935], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.9138967980085537, 0.6275576288296454, 0.4676443834469852], 
             UndirectedEdge[261, 290] -> 
             RGBColor[
              0.5067850511563949, 0.6090396671765619, 0.9547103165107921], 
             UndirectedEdge[24, 113] -> 
             RGBColor[
              0.9575230369172714, 0.9678413309993203, 0.9567865981194988], 
             UndirectedEdge[15, 243] -> 
             RGBColor[
              0.2285446981366219, 0.35754534668535254`, 0.9363266545060742], 
             UndirectedEdge[246, 296] -> 
             RGBColor[
              0.6475517482649964, 0.7239253864883827, 0.965961068287336], 
             UndirectedEdge[131, 174] -> 
             RGBColor[
              0.3585773503848271, 0.4850034111068425, 0.9440692095823882], 
             UndirectedEdge[44, 121] -> 
             RGBColor[
              0.9798326937990873, 0.9423326330377451, 0.48673505054828914`], 
             UndirectedEdge[155, 293] -> 
             RGBColor[
              0.21078204772465953`, 0.3388756748852968, 0.9353150978425994], 
             UndirectedEdge[105, 140] -> 
             RGBColor[
              0.3086221728107845, 0.4399248428735164, 0.9409523793012212], 
             UndirectedEdge[51, 138] -> 
             RGBColor[
              0.8501230130531416, 0.8811959449639274, 0.8638775606265587], 
             UndirectedEdge[133, 277] -> 
             RGBColor[
              0.3496210523003913, 0.4772459158627348, 0.9434985221881913], 
             UndirectedEdge[201, 261] -> 
             RGBColor[
              0.36087721144814144`, 0.48699543516550725`, 0.9442157546956553],
              UndirectedEdge[19, 57] -> 
             RGBColor[
              0.2691600647734066, 0.40023467218359243`, 0.9386396395509886], 
             UndirectedEdge[104, 261] -> 
             RGBColor[
              0.34285661416014696`, 0.46919806205208336`, 0.9431476422340319],
              UndirectedEdge[15, 111] -> 
             RGBColor[
              0.2409685800879815, 0.3706036343358437, 0.9370341762037178], 
             UndirectedEdge[71, 85] -> 
             RGBColor[
              0.7746111080065263, 0.8244612139777192, 0.9780896021036154], 
             UndirectedEdge[84, 158] -> 
             RGBColor[
              0.35212502014478775`, 0.47866323634096297`, 0.943685588557766], 
             UndirectedEdge[65, 162] -> 
             RGBColor[
              0.28622167127698683`, 0.41816750238718753`, 0.9396112728009827],
              UndirectedEdge[156, 268] -> 
             RGBColor[
              0.2451076812596908, 0.374954092101482, 0.9372698918921952], 
             UndirectedEdge[48, 252] -> 
             RGBColor[
              0.35710710220900627`, 0.48297045086574814`, 0.9440033358734436],
              UndirectedEdge[204, 235] -> 
             RGBColor[
              0.23646094075205434`, 0.36586581959294334`, 0.9367774728119916],
              UndirectedEdge[62, 130] -> 
             RGBColor[
              0.5868878667757954, 0.648392143438405, 0.8070978104506135], 
             UndirectedEdge[142, 283] -> 
             RGBColor[
              0.6388734394755219, 0.7174499822340865, 0.964888142090148], 
             UndirectedEdge[99, 259] -> 
             RGBColor[
              0.41587462147542475`, 0.5343343034600658, 0.9478022372825421], 
             UndirectedEdge[43, 244] -> 
             RGBColor[
              0.28234247424873604`, 0.412848733894419, 0.9394358151698824], 
             UndirectedEdge[36, 154] -> 
             RGBColor[
              0.750385676327774, 0.8049262605804057, 0.9757550895296658], 
             UndirectedEdge[11, 185] -> 
             RGBColor[
              0.4557880502577546, 0.5660866394053694, 0.9511242925783112], 
             UndirectedEdge[20, 150] -> 
             RGBColor[
              0.9139560790389594, 0.9335493921357441, 0.968134833574319], 
             UndirectedEdge[175, 252] -> 
             RGBColor[
              0.2975212413691305, 0.4300440669881537, 0.9402547666015143], 
             UndirectedEdge[97, 292] -> 
             RGBColor[
              0.25027096919944, 0.3803810350975218, 0.937563933501964], 
             UndirectedEdge[176, 226] -> 
             RGBColor[
              0.17893944427006758`, 0.3054070797168533, 0.9335017086827707], 
             UndirectedEdge[80, 103] -> 
             RGBColor[
              0.2733233300214085, 0.4046105279255051, 0.9388767313478634], 
             UndirectedEdge[137, 220] -> 
             RGBColor[
              0.5513789728038629, 0.36945130513336594`, 0.564612808979479], 
             UndirectedEdge[20, 167] -> 
             RGBColor[
              0.8099161582263048, 0.8518030947538164, 0.981590034710579], 
             UndirectedEdge[240, 256] -> 
             RGBColor[
              0.9950907669461442, 0.9919079718344301, 0.7070384622414018], 
             UndirectedEdge[113, 278] -> 
             RGBColor[
              0.7811703997408805, 0.8288870412862575, 0.957738894978919], 
             UndirectedEdge[181, 240] -> 
             RGBColor[
              0.8543753182561593, 0.8839651564219314, 0.8310187966371865], 
             UndirectedEdge[7, 151] -> 
             RGBColor[
              0.4190101469832575, 0.5373472620797284, 0.9479199339430164], 
             UndirectedEdge[6, 101] -> 
             RGBColor[
              0.4261316567977976, 0.5406988809357904, 0.9490838670731377], 
             UndirectedEdge[65, 116] -> 
             RGBColor[
              0.3051622199360282, 0.4368120893539453, 0.940736158424998], 
             UndirectedEdge[50, 264] -> 
             RGBColor[
              0.32355517598609507`, 0.45336673747336176`, 0.9418853084874919],
              UndirectedEdge[55, 235] -> 
             RGBColor[
              0.25936698600148883`, 0.38994152547725025`, 0.9380819382024896],
              UndirectedEdge[100, 232] -> 
             RGBColor[
              0.9221384356388024, 0.6882475061102127, 0.3972545294946756], 
             UndirectedEdge[28, 163] -> 
             RGBColor[
              0.23238600045450547`, 0.3615827989740821, 0.9365454109903801], 
             UndirectedEdge[11, 63] -> 
             RGBColor[
              0.3340095449749544, 0.46372401287461446`, 0.9425037707461285], 
             UndirectedEdge[234, 274] -> 
             RGBColor[
              0.8909472265976595, 0.513146913463993, 0.24055037716924876`], 
             UndirectedEdge[148, 270] -> 
             RGBColor[
              0.23353444010566207`, 0.3627898818627272, 0.9366108129295494], 
             UndirectedEdge[96, 245] -> 
             RGBColor[
              0.41493426639987385`, 0.5338169391781161, 0.9476602224364029], 
             UndirectedEdge[159, 235] -> 
             RGBColor[
              0.24471645266359499`, 0.3745428860416596, 0.9372476120024185], 
             UndirectedEdge[53, 287] -> 
             RGBColor[
              0.8863520651509298, 0.5242910551950881, 0.22469122939407754`], 
             UndirectedEdge[105, 289] -> 
             RGBColor[
              0.2900768000973668, 0.42221948720669167`, 0.9398308166841512], 
             UndirectedEdge[56, 164] -> 
             RGBColor[
              0.46580833431938506`, 0.5753190136054342, 0.9516098956299331], 
             UndirectedEdge[112, 235] -> 
             RGBColor[
              0.24712629913564943`, 0.3770757874768801, 0.9373848491939536], 
             UndirectedEdge[7, 43] -> 
             RGBColor[
              0.3584602463932565, 0.4849019815151618, 0.9440617478195963], 
             UndirectedEdge[242, 243] -> 
             RGBColor[
              0.22929951054390013`, 0.35833870238327276`, 0.9363696399560237],
              UndirectedEdge[151, 286] -> 
             RGBColor[
              0.5011547059099458, 0.6056262623148936, 0.953947236987697], 
             UndirectedEdge[126, 163] -> 
             RGBColor[
              0.23364896427549098`, 0.3629102540264691, 0.9366173349115978], 
             UndirectedEdge[31, 138] -> 
             RGBColor[
              0.662760313991049, 0.7361123302878763, 0.9672677727663206], 
             UndirectedEdge[95, 138] -> 
             RGBColor[
              0.5976652055170001, 0.6832651887274253, 0.9621432473760043], 
             UndirectedEdge[197, 275] -> 
             RGBColor[
              0.21163940728530467`, 0.33977681414327066`, 0.9353639232012283],
              UndirectedEdge[198, 245] -> 
             RGBColor[
              0.4443289893270455, 0.5589801958800422, 0.949615283231626], 
             UndirectedEdge[187, 264] -> 
             RGBColor[
              0.3292953995025846, 0.4583386305713222, 0.9422510704540822], 
             UndirectedEdge[62, 195] -> 
             RGBColor[
              0.9069962455234778, 0.5697715863000085, 0.4233300053697785], 
             UndirectedEdge[169, 187] -> 
             RGBColor[
              0.3284772756829356, 0.4574787305648249, 0.9422044795128589], 
             UndirectedEdge[82, 199] -> 
             RGBColor[
              0.587001837836629, 0.6486359160132862, 0.81950285707449], 
             UndirectedEdge[126, 155] -> 
             RGBColor[
              0.21912067898952223`, 0.3476401050444259, 0.9357899705572339], 
             UndirectedEdge[82, 220] -> 
             RGBColor[
              0.6261342073882591, 0.6897665175475827, 0.8217313876293025], 
             UndirectedEdge[32, 202] -> 
             RGBColor[
              0.24218926046257408`, 0.37188664680514644`, 0.937103692145216], 
             UndirectedEdge[113, 260] -> 
             RGBColor[
              0.9042815340807562, 0.9259021424271057, 0.969533952973199], 
             UndirectedEdge[105, 230] -> 
             RGBColor[
              0.2692612582166467, 0.40034103290847267`, 0.938645402367879], 
             UndirectedEdge[245, 289] -> 
             RGBColor[
              0.3576929449951681, 0.48259509766982983`, 0.944072988186208], 
             UndirectedEdge[108, 187] -> 
             RGBColor[
              0.35392495764506043`, 0.4809737423517148, 0.9437727632309596], 
             UndirectedEdge[137, 228] -> 
             RGBColor[
              0.8309547247116273, 0.6038501100477591, 0.5867983401041436], 
             UndirectedEdge[88, 261] -> 
             RGBColor[
              0.4524312720200109, 0.5649128206637994, 0.9504313879127225], 
             UndirectedEdge[192, 228] -> 
             RGBColor[
              0.8406646902431527, 0.6681341107638701, 0.5956912929318666], 
             UndirectedEdge[42, 97] -> 
             RGBColor[
              0.25595913612423093`, 0.3863596591860904, 0.937887866193442], 
             UndirectedEdge[121, 240] -> 
             RGBColor[
              0.9947718410408293, 0.9912258215713169, 0.6723253456304181], 
             UndirectedEdge[25, 43] -> 
             RGBColor[
              0.2869920462831278, 0.4177357289024586, 0.9397006014188156], 
             UndirectedEdge[77, 270] -> 
             RGBColor[
              0.23714390206690406`, 0.36658365523709874`, 0.9368163664485216],
              UndirectedEdge[225, 255] -> 
             RGBColor[
              0.9599585954916654, 0.876593081803823, 0.2989471339802242], 
             UndirectedEdge[2, 275] -> 
             RGBColor[
              0.2217679370492794, 0.35042254111108606`, 0.9359407279874696], 
             UndirectedEdge[235, 253] -> 
             RGBColor[
              0.2693822700586988, 0.40046822402706334`, 0.9386522938132629], 
             UndirectedEdge[73, 95] -> 
             RGBColor[
              0.4088283158597046, 0.5275690199007069, 0.9475362008014293], 
             UndirectedEdge[49, 175] -> 
             RGBColor[
              0.26553285029495766`, 0.3964222397880617, 0.9384330750524239], 
             UndirectedEdge[153, 219] -> 
             RGBColor[
              0.2738583241419696, 0.40517284066680126`, 0.9389071984715764], 
             UndirectedEdge[54, 167] -> 
             RGBColor[
              0.585666437251012, 0.671825268631737, 0.9619628736506332], 
             UndirectedEdge[56, 246] -> 
             RGBColor[
              0.57328015808247, 0.6644536841649844, 0.9595498605201163], 
             UndirectedEdge[192, 225] -> 
             RGBColor[
              0.91297449591913, 0.6798980455535951, 0.25595097610168294`], 
             UndirectedEdge[84, 252] -> 
             RGBColor[
              0.30057464185555743`, 0.4332533844961608, 0.9404286532421151], 
             UndirectedEdge[119, 164] -> 
             RGBColor[
              0.33307449939887124`, 0.46046205070774604`, 0.9425339728616443],
              UndirectedEdge[93, 168] -> 
             RGBColor[
              0.4585412392278475, 0.5694721717790032, 0.9510231831684333], 
             UndirectedEdge[111, 250] -> 
             RGBColor[
              0.2327988220725642, 0.3620167006690641, 0.9365689205708136], 
             UndirectedEdge[54, 286] -> 
             RGBColor[
              0.4882211414959945, 0.5944238588793778, 0.953123121699942], 
             UndirectedEdge[74, 257] -> 
             RGBColor[
              0.5147596974188978, 0.6152603482603705, 0.9554081515783656], 
             UndirectedEdge[220, 236] -> 
             RGBColor[
              0.4402011946832155, 0.5463223550644548, 0.9507193164378127], 
             UndirectedEdge[130, 228] -> 
             RGBColor[
              0.49763512145939465`, 0.5809234064486897, 0.9579150616794772], 
             UndirectedEdge[1, 142] -> 
             RGBColor[
              0.5387732060688373, 0.6352393283002062, 0.9572689291818902], 
             UndirectedEdge[101, 114] -> 
             RGBColor[
              0.4255007228362041, 0.540035729338632, 0.9490479363174081], 
             UndirectedEdge[199, 266] -> 
             RGBColor[
              0.21328047700996416`, 0.3415016824737179, 0.9354573796943026], 
             UndirectedEdge[93, 277] -> 
             RGBColor[
              0.440152252258617, 0.5535445555236148, 0.9498514531794966], 
             UndirectedEdge[19, 112] -> 
             RGBColor[
              0.271740291472555, 0.402946654040219, 0.9387865796444018], 
             UndirectedEdge[77, 203] -> 
             RGBColor[
              0.25281317669126346`, 0.38305305635669296`, 0.9377087084577643],
              UndirectedEdge[26, 60] -> 
             RGBColor[
              0.9559587194852852, 0.8665294960501166, 0.5718984085520893], 
             UndirectedEdge[186, 263] -> 
             RGBColor[
              0.24547633917610456`, 0.3753415749458948, 0.9372908864151546], 
             UndirectedEdge[167, 283] -> 
             RGBColor[
              0.6863247949375169, 0.7545193417646557, 0.9696176497444712], 
             UndirectedEdge[170, 200] -> 
             RGBColor[
              0.8539446998932355, 0.37225212712685507`, 0.1975915310267845], 
             UndirectedEdge[17, 292] -> 
             RGBColor[
              0.26964195081094916`, 0.4007411649623891, 0.9386670822479402], 
             UndirectedEdge[106, 215] -> 
             RGBColor[
              0.8258859987463416, 0.8619784867738793, 0.84861498208911], 
             UndirectedEdge[123, 229] -> 
             RGBColor[
              0.3913046976868122, 0.5133501944155183, 0.9461545672128138], 
             UndirectedEdge[105, 149] -> 
             RGBColor[
              0.29155965067616113`, 0.4237780571831614, 0.9399152628309327], 
             UndirectedEdge[68, 274] -> 
             RGBColor[
              0.9194708353599413, 0.7072874939349834, 0.2668815927431183], 
             UndirectedEdge[149, 171] -> 
             RGBColor[
              0.3561511381973472, 0.48153386145037547`, 0.943964705839551], 
             UndirectedEdge[29, 172] -> 
             RGBColor[
              0.256159178309366, 0.3865699162060744, 0.9378992582999495], 
             UndirectedEdge[76, 209] -> 
             RGBColor[
              0.2797259704782522, 0.4113401089964994, 0.9392413522500229], 
             UndirectedEdge[247, 267] -> 
             RGBColor[
              0.5234677465828359, 0.6240137244860162, 0.9556284450179895], 
             UndirectedEdge[164, 210] -> 
             RGBColor[
              0.3812406788826516, 0.5046332471596473, 0.9455132968338751], 
             UndirectedEdge[258, 260] -> 
             RGBColor[
              0.9054604072768613, 0.9267813441265331, 0.9675384281515653], 
             UndirectedEdge[62, 137] -> 
             RGBColor[
              0.9202074700280282, 0.6713188470374746, 0.43598108887527987`], 
             UndirectedEdge[175, 280] -> 
             RGBColor[
              0.2812847712693677, 0.4129785074616403, 0.9393301236490378], 
             UndirectedEdge[72, 194] -> 
             RGBColor[
              0.5838203648230471, 0.6728659592388615, 0.9604785834522965], 
             UndirectedEdge[3, 257] -> 
             RGBColor[
              0.38431511212659675`, 0.5072961667100446, 0.9457091970015647], 
             UndirectedEdge[154, 171] -> 
             RGBColor[
              0.5797766952507789, 0.6672643729865424, 0.9613588180759691], 
             UndirectedEdge[168, 277] -> 
             RGBColor[
              0.3674840405107483, 0.49271793843065337`, 0.944636736001335], 
             UndirectedEdge[146, 243] -> 
             RGBColor[
              0.22430859499308387`, 0.3530929336970421, 0.9360854146988027], 
             UndirectedEdge[98, 122] -> 
             RGBColor[
              0.5234999711581451, 0.6232114459734905, 0.9558598822602524], 
             UndirectedEdge[142, 210] -> 
             RGBColor[
              0.5187904189187625, 0.6179312424348968, 0.9559956436547723], 
             UndirectedEdge[3, 38] -> 
             RGBColor[
              0.3976345995492975, 0.5188328372586848, 0.9465579029621789], 
             UndirectedEdge[21, 205] -> 
             RGBColor[
              0.4564507498978377, 0.5677093547420913, 0.9508767552454336], 
             UndirectedEdge[153, 221] -> 
             RGBColor[
              0.2840475061144973, 0.4158823169513779, 0.939487457311368], 
             UndirectedEdge[55, 159] -> 
             RGBColor[
              0.26204426941803677`, 0.39275552009761494`, 0.9382344055323761],
              UndirectedEdge[149, 298] -> 
             RGBColor[
              0.28960052483186716`, 0.4217188917050555, 0.9398036935123671], 
             UndirectedEdge[22, 247] -> 
             RGBColor[
              0.6982336123573278, 0.7632154445962727, 0.9712197251392987], 
             UndirectedEdge[105, 298] -> 
             RGBColor[
              0.2872112063681208, 0.41920756650811786`, 0.9396676253605367], 
             UndirectedEdge[169, 219] -> 
             RGBColor[
              0.2836300261607937, 0.41544351905027754`, 0.9394636824456108], 
             UndirectedEdge[53, 225] -> 
             RGBColor[
              0.8963459868958306, 0.5624350878346187, 0.24043281821285972`], 
             UndirectedEdge[47, 90] -> 
             RGBColor[
              0.5238031310544717, 0.622908536972411, 0.9560460606082701], 
             UndirectedEdge[100, 137] -> 
             RGBColor[
              0.8478732688157926, 0.3689804990841502, 0.19347680232411396`], 
             UndirectedEdge[15, 175] -> 
             RGBColor[
              0.2667169814547302, 0.3976668367152345, 0.9385005095702079], 
             UndirectedEdge[49, 253] -> 
             RGBColor[
              0.2666399442226916, 0.39758586569991927`, 0.9384961224138098], 
             UndirectedEdge[166, 291] -> 
             RGBColor[
              0.9053156340255587, 0.5627492600761606, 0.30706567418331665`], 
             UndirectedEdge[161, 230] -> 
             RGBColor[
              0.2328116110999559, 0.36203014274772405`, 0.9365696488870041], 
             UndirectedEdge[263, 269] -> 
             RGBColor[
              0.24400443083652518`, 0.3737945059566179, 0.9372070634127088], 
             UndirectedEdge[122, 160] -> 
             RGBColor[
              0.6072063704282553, 0.6919965117057422, 0.9622206562317872], 
             UndirectedEdge[196, 289] -> 
             RGBColor[
              0.28595784411409636`, 0.4178902033113814, 0.9395962482343534], 
             UndirectedEdge[30, 158] -> 
             RGBColor[
              0.4329152304787701, 0.5491500227069821, 0.9488725767937995], 
             UndirectedEdge[114, 187] -> 
             RGBColor[
              0.33417034239985266`, 0.4634625046455827, 0.9425286912402498], 
             UndirectedEdge[49, 159] -> 
             RGBColor[
              0.24197412682758776`, 0.3716605277145155, 0.9370914406029653], 
             UndirectedEdge[33, 94] -> 
             RGBColor[
              0.8883058899064401, 0.9137750204630982, 0.9892086028509474], 
             UndirectedEdge[193, 220] -> 
             RGBColor[
              0.3283447463388828, 0.4540509053495343, 0.9423173412993839], 
             UndirectedEdge[60, 127] -> 
             RGBColor[
              0.879427272019672, 0.4987774156297289, 0.21919915424561515`], 
             UndirectedEdge[282, 297] -> 
             RGBColor[
              0.8620280342318183, 0.892582413918251, 0.9615782291090177], 
             UndirectedEdge[97, 235] -> 
             RGBColor[
              0.24975979964424241`, 0.3798437634849875, 0.9375348231520031], 
             UndirectedEdge[50, 187] -> 
             RGBColor[
              0.35818927208584117`, 0.4846672771896433, 0.9440444815763409], 
             UndirectedEdge[271, 274] -> 
             RGBColor[
              0.9710201994330907, 0.9139064692863681, 0.34191937648403536`], 
             UndirectedEdge[137, 170] -> 
             RGBColor[
              0.8337298231764674, 0.2602677782028984, 0.17993302280715895`], 
             UndirectedEdge[84, 253] -> 
             RGBColor[
              0.29867167742904355`, 0.43125324822898137`, 0.9403202822332086],
              UndirectedEdge[33, 185] -> 
             RGBColor[
              0.7413664787721765, 0.7975076391058051, 0.9754311281439616], 
             UndirectedEdge[3, 144] -> 
             RGBColor[
              0.34651719678738085`, 0.4745575122216793, 0.9433007472595341], 
             UndirectedEdge[11, 43] -> 
             RGBColor[
              0.3328397711748278, 0.46271081360348554`, 0.9424292337939748], 
             UndirectedEdge[29, 272] -> 
             RGBColor[
              0.23305163384099561`, 0.36228242186687754`, 0.9365833178270244],
              UndirectedEdge[70, 251] -> 
             RGBColor[
              0.27547374372817707`, 0.40687074907542276`, 0.9389991942272118],
              UndirectedEdge[99, 123] -> 
             RGBColor[
              0.40185451909948444`, 0.5224879194737331, 0.9468267925043885], 
             UndirectedEdge[133, 239] -> 
             RGBColor[
              0.38064066205782954`, 0.5041135427437089, 0.9454750642923715], 
             UndirectedEdge[259, 260] -> 
             RGBColor[
              0.656707314635238, 0.7292515443954324, 0.9682208504157948], 
             UndirectedEdge[125, 192] -> 
             RGBColor[
              0.9288056517822338, 0.7332248546724817, 0.32386323867590994`], 
             UndirectedEdge[213, 264] -> 
             RGBColor[
              0.36127001361165895`, 0.48603343422176903`, 0.9442884645910713],
              UndirectedEdge[134, 204] -> 
             RGBColor[
              0.25244174288045984`, 0.38266265587127446`, 0.9376875558517261],
              UndirectedEdge[94, 142] -> 
             RGBColor[
              0.7604864358301577, 0.8131562391312941, 0.9766718286519673], 
             UndirectedEdge[134, 175] -> 
             RGBColor[
              0.2842559782593704, 0.41610143439353686`, 0.9394993294916116], 
             UndirectedEdge[8, 267] -> 
             RGBColor[
              0.5598482664107077, 0.6534036903177951, 0.9585918492816847], 
             UndirectedEdge[195, 225] -> 
             RGBColor[
              0.8900533058830544, 0.5140667841000182, 0.23440693976845853`], 
             UndirectedEdge[51, 281] -> 
             RGBColor[
              0.9148192587802333, 0.6349551711119263, 0.4692679592224235], 
             UndirectedEdge[49, 243] -> 
             RGBColor[
              0.2273605669768493, 0.3563007497581797, 0.9362592199882902], 
             UndirectedEdge[212, 243] -> 
             RGBColor[
              0.2149437082857312, 0.34324984399950276`, 0.9355520982549272], 
             UndirectedEdge[22, 285] -> 
             RGBColor[
              0.6000751622710249, 0.6816104857973055, 0.9640215926822105], 
             UndirectedEdge[20, 33] -> 
             RGBColor[
              0.8902842568405922, 0.9153525165550513, 0.9893973012552358], 
             UndirectedEdge[9, 174] -> 
             RGBColor[
              0.4545765714263261, 0.5664286209801727, 0.9506626768751375], 
             UndirectedEdge[180, 250] -> 
             RGBColor[
              0.22830469938985565`, 0.3572930927857018, 0.9363129869324922], 
             UndirectedEdge[92, 221] -> 
             RGBColor[
              0.27785530490942656`, 0.40937392087661617`, 0.9391348206132799],
              UndirectedEdge[71, 232] -> 
             RGBColor[
              0.8118465460917592, 0.8499776455244756, 0.7814031522680547], 
             UndirectedEdge[25, 148] -> 
             RGBColor[
              0.24531191831194143`, 0.3751687581927745, 0.9372815228901793], 
             UndirectedEdge[76, 218] -> 
             RGBColor[
              0.2751691719679872, 0.4065506248444982, 0.9389818493160426], 
             UndirectedEdge[20, 200] -> 
             RGBColor[
              0.8759509079419014, 0.7355649732308305, 0.6068283204518097], 
             UndirectedEdge[68, 255] -> 
             RGBColor[
              0.9166602771185755, 0.6978068210363987, 0.2559631047048003], 
             UndirectedEdge[30, 123] -> 
             RGBColor[
              0.44920952472312525`, 0.5632633214064009, 0.9499108348145711], 
             UndirectedEdge[113, 290] -> 
             RGBColor[
              0.7861690031762806, 0.8329451327396338, 0.9581324033518415], 
             UndirectedEdge[230, 269] -> 
             RGBColor[
              0.23818874032876391`, 0.3676818464968855, 0.9368758684418348], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.40607658256930623`, 0.5261448586442126, 0.9470958186552614], 
             UndirectedEdge[71, 296] -> 
             RGBColor[
              0.6629160657631297, 0.7363988315879828, 0.9671706036421385], 
             UndirectedEdge[37, 237] -> 
             RGBColor[
              0.6597410410048012, 0.7340591462727639, 0.9667579712592742], 
             UndirectedEdge[8, 217] -> 
             RGBColor[
              0.7294424930983517, 0.7885652866674933, 0.9736676687505319], 
             UndirectedEdge[39, 100] -> 
             RGBColor[
              0.8588565214001893, 0.4390461989236035, 0.20343221707987458`], 
             UndirectedEdge[35, 216] -> 
             RGBColor[
              0.24253456217849695`, 0.3722495808019747, 0.9371233565671098], 
             UndirectedEdge[48, 253] -> 
             RGBColor[
              0.3552041377824924, 0.4809703145985687, 0.9438949648645372], 
             UndirectedEdge[72, 247] -> 
             RGBColor[
              0.6154478937421781, 0.6985426120193529, 0.9629684183842664], 
             UndirectedEdge[24, 254] -> 
             RGBColor[
              0.9234793483730712, 0.7829172870924861, 0.5955041038084421], 
             UndirectedEdge[247, 273] -> 
             RGBColor[
              0.598461668080708, 0.6848971683956518, 0.9615322412300882], 
             UndirectedEdge[80, 152] -> 
             RGBColor[
              0.26056294463292196`, 0.39119855382704327`, 0.9381500462772876],
              UndirectedEdge[121, 125] -> 
             RGBColor[
              0.9936176446660105, 0.9887571122327337, 0.5466981931057444], 
             UndirectedEdge[8, 177] -> 
             RGBColor[
              0.5355284607783559, 0.6327336001246429, 0.9569332103909327], 
             UndirectedEdge[38, 253] -> 
             RGBColor[
              0.35733483343099304`, 0.48281581607742285`, 0.9440307309071595],
              UndirectedEdge[134, 292] -> 
             RGBColor[
              0.2585311409306501, 0.3890629993121603, 0.9380343380622274], 
             UndirectedEdge[19, 177] -> 
             RGBColor[
              0.3552373943929633, 0.4804944703524481, 0.9439155616348212], 
             UndirectedEdge[219, 221] -> 
             RGBColor[
              0.28442417853057445`, 0.4162782235430855, 0.9395089082482266], 
             UndirectedEdge[37, 185] -> 
             RGBColor[
              0.6243865353648125, 0.7053567658918924, 0.9639747350674728], 
             UndirectedEdge[15, 280] -> 
             RGBColor[
              0.2534905697092152, 0.38376503936775813`, 0.9377472849880235], 
             UndirectedEdge[140, 171] -> 
             RGBColor[
              0.37321366033197056`, 0.49768064714073046`, 0.9450018223098395],
              UndirectedEdge[211, 221] -> 
             RGBColor[
              0.26848631667000333`, 0.39952652020881857`, 0.9386012705932207],
              UndirectedEdge[47, 273] -> 
             RGBColor[
              0.6309474410941337, 0.7112445284148133, 0.9641074535297975], 
             UndirectedEdge[58, 171] -> 
             RGBColor[
              0.48363824484440066`, 0.5907289672924857, 0.9527552354354336], 
             UndirectedEdge[75, 150] -> 
             RGBColor[
              0.8462593507356758, 0.8802930242051693, 0.9614859532696918], 
             UndirectedEdge[9, 167] -> 
             RGBColor[
              0.6353780576373289, 0.7131584853000028, 0.9656069359601525], 
             UndirectedEdge[135, 260] -> 
             RGBColor[
              0.9196247583457642, 0.9363642687580429, 0.8996385198821143], 
             UndirectedEdge[184, 202] -> 
             RGBColor[
              0.23277907926056368`, 0.361995949721885, 0.9365677962468772], 
             UndirectedEdge[166, 262] -> 
             RGBColor[
              0.9933514957949947, 0.9881878467094093, 0.5177295309761065], 
             UndirectedEdge[173, 276] -> 
             RGBColor[
              0.24447758470727698`, 0.3742918206744662, 0.9372340088256796], 
             UndirectedEdge[67, 86] -> 
             RGBColor[
              0.9435929630020026, 0.929903263270933, 0.6741823558912051], 
             UndirectedEdge[25, 272] -> 
             RGBColor[
              0.23754533151077184`, 0.36700558303470066`, 0.9368392272614883],
              UndirectedEdge[7, 174] -> 
             RGBColor[
              0.39353511961410004`, 0.5152820737846694, 0.9462966877257359], 
             UndirectedEdge[88, 113] -> 
             RGBColor[
              0.7318152240398965, 0.7888182862268713, 0.9538534747537719], 
             UndirectedEdge[147, 206] -> 
             RGBColor[
              0.23143319481245586`, 0.360581339832921, 0.9364911501186151], 
             UndirectedEdge[189, 211] -> 
             RGBColor[
              0.23710386113640347`, 0.3665415696804011, 0.9368140861767649], 
             UndirectedEdge[104, 209] -> 
             RGBColor[
              0.2751140822771375, 0.4064927220865271, 0.9389787120396467], 
             UndirectedEdge[151, 167] -> 
             RGBColor[
              0.5986000016649633, 0.6830276720672528, 0.9627869889383882], 
             UndirectedEdge[215, 274] -> 
             RGBColor[
              0.979839341035498, 0.9422049502369351, 0.5238492272566825], 
             UndirectedEdge[41, 261] -> 
             RGBColor[
              0.3788160778841355, 0.5025331796387221, 0.9453588034022401], 
             UndirectedEdge[157, 218] -> 
             RGBColor[
              0.30101158042666865`, 0.4302700565079032, 0.9405795858965723], 
             UndirectedEdge[187, 205] -> 
             RGBColor[
              0.44668815437293624`, 0.55925348518074, 0.950254691291311], 
             UndirectedEdge[62, 82] -> 
             RGBColor[
              0.9949627046124243, 0.9916340594516913, 0.6930996675251034], 
             UndirectedEdge[42, 144] -> 
             RGBColor[
              0.28507366633741316`, 0.4163170541357517, 0.9395694691052225], 
             UndirectedEdge[33, 150] -> 
             RGBColor[
              0.9383344799337505, 0.9529880672751867, 0.9704600672145196], 
             UndirectedEdge[34, 46] -> 
             RGBColor[
              0.30981865996121394`, 0.44123557275110054`, 0.9410185715382298],
              UndirectedEdge[220, 266] -> 
             RGBColor[
              0.2524128465615943, 0.3826322840080144, 0.9376859102491151], 
             UndirectedEdge[128, 279] -> 
             RGBColor[
              0.24902661375038676`, 0.3790731386238746, 0.9374930692999993], 
             UndirectedEdge[147, 270] -> 
             RGBColor[
              0.2272240069658551, 0.35615721652822, 0.9362514430976865], 
             UndirectedEdge[30, 90] -> 
             RGBColor[
              0.4328724368509469, 0.5491129570174318, 0.9488698500216755], 
             UndirectedEdge[36, 222] -> 
             RGBColor[
              0.5978519743815511, 0.6821400273622127, 0.9628407950842862], 
             UndirectedEdge[127, 170] -> 
             RGBColor[
              0.8273327672839398, 0.21109720340516447`, 0.1738071948600332], 
             UndirectedEdge[1, 295] -> 
             RGBColor[
              0.6279037208977163, 0.7050085996594103, 0.9661155178174292], 
             UndirectedEdge[96, 140] -> 
             RGBColor[
              0.36676996210044227`, 0.49209943960227065`, 0.9445912355564652],
              UndirectedEdge[206, 272] -> 
             RGBColor[
              0.22997704115109324`, 0.35905083000935434`, 0.9364082243217868],
              UndirectedEdge[129, 265] -> 
             RGBColor[
              0.22918762870603976`, 0.3582211074779632, 0.936363268450872], 
             UndirectedEdge[39, 60] -> 
             RGBColor[
              0.8968075804965964, 0.6180136902669162, 0.2352803969485015], 
             UndirectedEdge[71, 240] -> 
             RGBColor[
              0.8122650553898112, 0.8508727945952284, 0.8269553066210207], 
             UndirectedEdge[30, 144] -> 
             RGBColor[
              0.3889539475617518, 0.5110729690025859, 0.9460714027197632], 
             UndirectedEdge[26, 59] -> 
             RGBColor[
              0.9093225725856791, 0.6208046140216712, 0.5317333787947149], 
             UndirectedEdge[133, 241] -> 
             RGBColor[
              0.3146112316266204, 0.4441789202710761, 0.9413681711410662], 
             UndirectedEdge[236, 266] -> 
             RGBColor[
              0.43542230214154953`, 0.5412994360038763, 0.9504471655773028], 
             UndirectedEdge[28, 216] -> 
             RGBColor[
              0.24112529640186797`, 0.3707683531181266, 0.9370431009659527], 
             UndirectedEdge[173, 230] -> 
             RGBColor[
              0.25326290395464024`, 0.3835257482248573, 0.9377343197601018], 
             UndirectedEdge[39, 266] -> 
             RGBColor[
              0.5575833328465938, 0.4344940859122408, 0.5742960728747296], 
             UndirectedEdge[86, 141] -> 
             RGBColor[
              0.936935020626016, 0.7805800799358134, 0.2971516426609445], 
             UndirectedEdge[25, 206] -> 
             RGBColor[
              0.2442420605634609, 0.3740442698662223, 0.937220596074116], 
             UndirectedEdge[141, 165] -> 
             RGBColor[0.9396314058192, 0.789675620333774, 0.3076265899668467],
              UndirectedEdge[152, 241] -> 
             RGBColor[
              0.2661857597767988, 0.3971084890503288, 0.9384702572815218], 
             UndirectedEdge[110, 141] -> 
             RGBColor[
              0.9459742116007779, 0.8128132585241278, 0.5020022278511405], 
             UndirectedEdge[97, 134] -> 
             RGBColor[
              0.2657406017726479, 0.3966405997633186, 0.9384449061917377], 
             UndirectedEdge[103, 119] -> 
             RGBColor[
              0.28052080371187027`, 0.4121755291203697, 0.939286616826827], 
             UndirectedEdge[3, 17] -> 
             RGBColor[
              0.3367736481857078, 0.4649602471368852, 0.9427222930937296], 
             UndirectedEdge[203, 270] -> 
             RGBColor[
              0.2439246691349402, 0.37371067135106817`, 0.9372025211018002], 
             UndirectedEdge[51, 141] -> 
             RGBColor[
              0.9462822846437602, 0.812940654644517, 0.4968966602614467], 
             UndirectedEdge[184, 275] -> 
             RGBColor[
              0.22510784132218828`, 0.35393299226407493`, 0.9361309305948662],
              UndirectedEdge[58, 109] -> 
             RGBColor[
              0.7350459204207711, 0.7923292470470489, 0.9749877366110247], 
             UndirectedEdge[179, 281] -> 
             RGBColor[
              0.9148614845826333, 0.6349726325663724, 0.4685681683997813], 
             UndirectedEdge[31, 154] -> 
             RGBColor[
              0.6800184039631393, 0.7495944813404151, 0.9689878978887183], 
             UndirectedEdge[122, 296] -> 
             RGBColor[
              0.6602141631347492, 0.7342053053149373, 0.9669578999698369], 
             UndirectedEdge[96, 290] -> 
             RGBColor[
              0.5091973143554127, 0.6111290483156775, 0.9548640237887529], 
             UndirectedEdge[122, 240] -> 
             RGBColor[
              0.8095631527614308, 0.8486792683221828, 0.8267426029487193], 
             UndirectedEdge[97, 144] -> 
             RGBColor[
              0.28659496025462, 0.4179160304983415, 0.9396561045432549], 
             UndirectedEdge[61, 247] -> 
             RGBColor[
              0.5729638190353659, 0.6641968658756336, 0.9595249571515402], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.5867492116924276, 0.675169261254928, 0.9607600670587673], 
             UndirectedEdge[45, 287] -> 
             RGBColor[
              0.899399401089056, 0.6245785965945915, 0.23718537302328563`], 
             UndirectedEdge[278, 290] -> 
             RGBColor[
              0.607930114483695, 0.6925840797342462, 0.9622776320149933], 
             UndirectedEdge[109, 110] -> 
             RGBColor[
              0.9570573175626281, 0.9656649471847494, 0.8794550171346109], 
             UndirectedEdge[56, 160] -> 
             RGBColor[
              0.5689561966042058, 0.6609432974446849, 0.9592094624333546], 
             UndirectedEdge[146, 292] -> 
             RGBColor[
              0.2367560409824719, 0.36617598864554746`, 0.9367942783335522], 
             UndirectedEdge[131, 139] -> 
             RGBColor[
              0.29015495986038786`, 0.4208144502573191, 0.9398897209981389], 
             UndirectedEdge[47, 74] -> 
             RGBColor[
              0.6411369333771564, 0.7195168172815674, 0.9649096076876572], 
             UndirectedEdge[46, 221] -> 
             RGBColor[
              0.2933757434234066, 0.4256868858074472, 0.9400186866262199], 
             UndirectedEdge[48, 74] -> 
             RGBColor[
              0.5259484891930979, 0.6249515173301565, 0.9561210914963576], 
             UndirectedEdge[90, 134] -> 
             RGBColor[
              0.3387736212750252, 0.46463798272782586`, 0.9429249564054306], 
             UndirectedEdge[1, 37] -> 
             RGBColor[
              0.5496127167377557, 0.6437072364180976, 0.9583493103043816], 
             UndirectedEdge[33, 295] -> 
             RGBColor[
              0.8759737184879801, 0.9039416817218939, 0.9880323493319954], 
             UndirectedEdge[28, 35] -> 
             RGBColor[
              0.2248219115083478, 0.35363246190073133`, 0.9361146473149633], 
             UndirectedEdge[21, 169] -> 
             RGBColor[
              0.33823987120783705`, 0.46593460012617627`, 0.9428265434669814],
              UndirectedEdge[100, 228] -> 
             RGBColor[
              0.8332617870229544, 0.6215832019337704, 0.5890075855789246], 
             UndirectedEdge[190, 250] -> 
             RGBColor[
              0.22535768471974588`, 0.35419559351589436`, 0.9361451588067469],
              UndirectedEdge[81, 180] -> 
             RGBColor[
              0.26493370488523493`, 0.3957924999744301, 0.9383989546076965], 
             UndirectedEdge[127, 141] -> 
             RGBColor[
              0.8658872706016187, 0.44359089015560293`, 0.2082267027178307], 
             UndirectedEdge[143, 185] -> 
             RGBColor[
              0.482410173529073, 0.5891453845161638, 0.9528206307321404], 
             UndirectedEdge[283, 295] -> 
             RGBColor[
              0.728003954304401, 0.7872192535932907, 0.973734730725687], 
             UndirectedEdge[26, 100] -> 
             RGBColor[
              0.9180076603888783, 0.6875620047068038, 0.5400502286834623], 
             UndirectedEdge[242, 294] -> 
             RGBColor[
              0.22516497885926012`, 0.35399304743826654`, 0.9361341844930751],
              UndirectedEdge[39, 228] -> 
             RGBColor[
              0.8419379772960242, 0.6739158098872126, 0.5967537548599042], 
             UndirectedEdge[39, 82] -> 
             RGBColor[
              0.9313046936732585, 0.7416283194518091, 0.4583415502549171], 
             UndirectedEdge[109, 258] -> 
             RGBColor[
              0.941467846616602, 0.9554926988601389, 0.9709728498600104], 
             UndirectedEdge[118, 199] -> 
             RGBColor[
              0.17892828448197629`, 0.3053953500719979, 0.9335010731493483], 
             UndirectedEdge[57, 115] -> 
             RGBColor[
              0.2343221600487206, 0.3636178254672108, 0.9366556724149793], 
             UndirectedEdge[96, 222] -> 
             RGBColor[
              0.4207992950730278, 0.5388969322298897, 0.948033936877215], 
             UndirectedEdge[6, 108] -> 
             RGBColor[
              0.32479673840417583`, 0.4554602283068521, 0.9419271416840078], 
             UndirectedEdge[1, 9] -> 
             RGBColor[
              0.46767615866135254`, 0.5777748250387542, 0.9514973709902432], 
             UndirectedEdge[180, 190] -> 
             RGBColor[
              0.23107912024585836`, 0.36020918501380295`, 0.9364709860958538],
              UndirectedEdge[144, 253] -> 
             RGBColor[
              0.30621743066907636`, 0.4385404910404173, 0.9407735752045145], 
             UndirectedEdge[53, 192] -> 
             RGBColor[
              0.8483576285442167, 0.36235245091138435`, 0.19353530461595575`],
              UndirectedEdge[85, 121] -> 
             RGBColor[
              0.9571178936575444, 0.9648142409538079, 0.8234596411130128], 
             UndirectedEdge[36, 278] -> 
             RGBColor[
              0.681251390228536, 0.7503140519946241, 0.9692773736229017], 
             UndirectedEdge[122, 207] -> 
             RGBColor[
              0.6848905103681076, 0.7534826553208219, 0.9694174076484823], 
             UndirectedEdge[226, 228] -> 
             RGBColor[
              0.4976351265701356, 0.5809234118204025, 0.9579150619705263], 
             UndirectedEdge[7, 143] -> 
             RGBColor[
              0.3957483991962868, 0.5171991053160931, 0.9464377159435866], 
             UndirectedEdge[133, 164] -> 
             RGBColor[
              0.36703566028493084`, 0.49232957401529565`, 0.9446081656098331],
              UndirectedEdge[7, 131] -> 
             RGBColor[
              0.359788981914124, 0.4860528654391481, 0.9441464136720313], 
             UndirectedEdge[111, 280] -> 
             RGBColor[
              0.2555363699026189, 0.38591530508224947`, 0.9378637902825477], 
             UndirectedEdge[135, 224] -> 
             RGBColor[
              0.9798102252026126, 0.9495170954171317, 0.5749562479700403], 
             UndirectedEdge[91, 102] -> 
             RGBColor[
              0.3289676178309032, 0.4560161547537128, 0.9423048264494448], 
             UndirectedEdge[200, 282] -> 
             RGBColor[
              0.9248264998510323, 0.7738160826625009, 0.5864939522963153], 
             UndirectedEdge[106, 194] -> 
             RGBColor[
              0.5862509789073218, 0.6747647734348481, 0.960720844348837], 
             UndirectedEdge[38, 259] -> 
             RGBColor[
              0.44110257276703263`, 0.5561854868751561, 0.949409740030642], 
             UndirectedEdge[36, 69] -> 
             RGBColor[
              0.8763046392583498, 0.8998097230462532, 0.7301395316538027], 
             UndirectedEdge[64, 153] -> 
             RGBColor[
              0.253568524812987, 0.38384697512446136`, 0.9377517244158591], 
             UndirectedEdge[159, 175] -> 
             RGBColor[
              0.2709524595475128, 0.4021185927355705, 0.9387417137817635], 
             UndirectedEdge[94, 200] -> 
             RGBColor[
              0.8739725410077492, 0.7339874771388775, 0.6066396220475212], 
             UndirectedEdge[88, 201] -> 
             RGBColor[
              0.41266709907445764`, 0.5304710926638055, 0.9478976499747094], 
             UndirectedEdge[121, 232] -> 
             RGBColor[
              0.9943533317427773, 0.9903306725005643, 0.626773191277452], 
             UndirectedEdge[140, 289] -> 
             RGBColor[
              0.3095286406957365, 0.4408775980939844, 0.9410040013062702], 
             UndirectedEdge[139, 244] -> 
             RGBColor[
              0.2489949569451404, 0.37903986531440326`, 0.9374912664917726], 
             UndirectedEdge[167, 174] -> 
             RGBColor[
              0.5731249742958058, 0.6609624837721939, 0.9611637427211077], 
             UndirectedEdge[185, 282] -> 
             RGBColor[
              0.7658636697865162, 0.8163200733980329, 0.9527715263482667], 
             UndirectedEdge[236, 249] -> 
             RGBColor[
              0.7208953090971567, 0.4244044295693752, 0.5644530380404611], 
             UndirectedEdge[137, 299] -> 
             RGBColor[
              0.9200253772401052, 0.6716173201462636, 0.46616820031546136`], 
             UndirectedEdge[201, 218] -> 
             RGBColor[
              0.2885778810548669, 0.4195006110479498, 0.9397873215672898], 
             UndirectedEdge[36, 109] -> 
             RGBColor[
              0.8403699639081523, 0.8760405078690783, 0.9845068533256267], 
             UndirectedEdge[4, 52] -> 
             RGBColor[
              0.6786643793088902, 0.3871223101534529, 0.5607452962818866], 
             UndirectedEdge[5, 191] -> 
             RGBColor[
              0.23242398209380136`, 0.36162272008515706`, 0.9365475739885493],
              UndirectedEdge[55, 134] -> 
             RGBColor[
              0.27534778812989436`, 0.40673836175558137`, 0.9389920212422243],
              UndirectedEdge[67, 69] -> 
             RGBColor[
              0.9526781701718614, 0.9602196098814508, 0.7375536853224871], 
             UndirectedEdge[232, 256] -> 
             RGBColor[
              0.9946722576480922, 0.9910128227636774, 0.6614863078884357], 
             UndirectedEdge[185, 237] -> 
             RGBColor[
              0.6034248054489583, 0.6889264668979879, 0.961922957584288], 
             UndirectedEdge[28, 211] -> 
             RGBColor[
              0.2328859592843117, 0.3621082874034291, 0.9365738829061148], 
             UndirectedEdge[85, 246] -> 
             RGBColor[
              0.759246790508393, 0.811987768878119, 0.9768800667488129], 
             UndirectedEdge[26, 127] -> 
             RGBColor[
              0.9093035421850235, 0.6206583380230588, 0.5317151552615555], 
             UndirectedEdge[91, 162] -> 
             RGBColor[
              0.27856959341816107`, 0.4101246833878033, 0.9391754982871572], 
             UndirectedEdge[112, 242] -> 
             RGBColor[
              0.24632291686669305`, 0.37623138177482907`, 0.937339097762234], 
             UndirectedEdge[85, 122] -> 
             RGBColor[
              0.7719092053781459, 0.8222676877046737, 0.9778768984313139], 
             UndirectedEdge[63, 131] -> 
             RGBColor[
              0.32467225096411007`, 0.4556365181084638, 0.9419088066284024], 
             UndirectedEdge[140, 222] -> 
             RGBColor[
              0.3821033463817397, 0.505380446388428, 0.94556826524409], 
             UndirectedEdge[121, 256] -> 
             RGBColor[
              0.9949290492403844, 0.9915620740139779, 0.6894364879754314], 
             UndirectedEdge[171, 198] -> 
             RGBColor[
              0.4413043319504303, 0.556360389684118, 0.9494225547381876], 
             UndirectedEdge[10, 117] -> 
             RGBColor[
              0.20745354842489078`, 0.3353772110821952, 0.935125544731551], 
             UndirectedEdge[18, 290] -> 
             RGBColor[
              0.7796647191738186, 0.8280942483803853, 0.9691424595790514], 
             UndirectedEdge[207, 240] -> 
             RGBColor[
              0.870260916353266, 0.8963751063904083, 0.8326021245961515], 
             UndirectedEdge[219, 264] -> 
             RGBColor[
              0.28444814998044265`, 0.4163034190567747, 0.9395102733868341], 
             UndirectedEdge[78, 118] -> 
             RGBColor[
              0.17948494456776543`, 0.30598043511645023`, 0.9335327741177293],
              UndirectedEdge[2, 208] -> 
             RGBColor[
              0.2583585282715436, 0.3888815724631647, 0.9380245080266488], 
             UndirectedEdge[34, 169] -> 
             RGBColor[
              0.3102621246711287, 0.4417016822785076, 0.9410438261974121], 
             UndirectedEdge[35, 275] -> 
             RGBColor[
              0.21950487592715945`, 0.34804392038537546`, 0.9358118500044639],
              UndirectedEdge[157, 284] -> 
             RGBColor[
              0.3008123283039969, 0.4300606298936609, 0.9405682387829533], 
             UndirectedEdge[30, 259] -> 
             RGBColor[
              0.46322962709906557`, 0.5751097053927338, 0.9508862795927249], 
             UndirectedEdge[62, 192] -> 
             RGBColor[
              0.9299174355595534, 0.7356028477535854, 0.4448740417030029], 
             UndirectedEdge[95, 245] -> 
             RGBColor[
              0.4565245648697137, 0.5688811135099974, 0.9505753636122101], 
             UndirectedEdge[129, 230] -> 
             RGBColor[
              0.2426308084736596, 0.3723507417605582, 0.9371288376512357], 
             UndirectedEdge[35, 92] -> 
             RGBColor[
              0.24366421330036392`, 0.37343691575507476`, 0.9371876885273311],
              UndirectedEdge[186, 279] -> 
             RGBColor[
              0.24438086405288187`, 0.3741901611342533, 0.9372285007274972], 
             UndirectedEdge[217, 233] -> 
             RGBColor[
              0.9005620992858752, 0.9194729557138646, 0.7896746116293041], 
             UndirectedEdge[28, 293] -> 
             RGBColor[
              0.21633697828784162`, 0.3447142591101412, 0.9356314429203892], 
             UndirectedEdge[24, 233] -> 
             RGBColor[
              0.9748626422338834, 0.9780993949460502, 0.7789636593832132], 
             UndirectedEdge[41, 229] -> 
             RGBColor[
              0.35168976097882576`, 0.47903772734367334`, 0.943630338475894], 
             UndirectedEdge[197, 214] -> 
             RGBColor[
              0.21169118846890916`, 0.33983123945035565`, 0.9353668720630313],
              UndirectedEdge[84, 144] -> 
             RGBColor[
              0.30816373722776935`, 0.4405861826365669, 0.9408844144837296], 
             UndirectedEdge[101, 205] -> 
             RGBColor[
              0.5380185348092877, 0.6358267098737893, 0.9567739363684693], 
             UndirectedEdge[7, 297] -> 
             RGBColor[
              0.5775728899214854, 0.6645401478372637, 0.9615635093646839], 
             UndirectedEdge[30, 47] -> 
             RGBColor[
              0.5531290988592262, 0.6480680925121483, 0.9579813085710855], 
             UndirectedEdge[140, 298] -> 
             RGBColor[
              0.3066630469664905, 0.4378656773954105, 0.9408408099826556], 
             UndirectedEdge[159, 252] -> 
             RGBColor[
              0.2739625179017606, 0.4052823549146075, 0.9389131321520556], 
             UndirectedEdge[26, 195] -> 
             RGBColor[
              0.9024893735730009, 0.5682816520833267, 0.52518989970318], 
             UndirectedEdge[43, 185] -> 
             RGBColor[
              0.4451220207260428, 0.5568482607152324, 0.9504446626081502], 
             UndirectedEdge[36, 95] -> 
             RGBColor[
              0.6241088885700935, 0.7039231949079366, 0.9647789065724686], 
             UndirectedEdge[6, 46] -> 
             RGBColor[
              0.29890559173213627`, 0.4314991069925552, 0.9403336033067247], 
             UndirectedEdge[148, 183] -> 
             RGBColor[
              0.2467014884994484, 0.37662928456368283`, 0.937360656856673], 
             UndirectedEdge[222, 261] -> 
             RGBColor[
              0.41838703187400994`, 0.5368075510907742, 0.9478802295992542], 
             UndirectedEdge[64, 145] -> 
             RGBColor[
              0.2514296244944172, 0.3815988552755316, 0.937629917206936], 
             UndirectedEdge[8, 247] -> 
             RGBColor[
              0.6154687668637716, 0.6985589182605833, 0.9629704988219563], 
             UndirectedEdge[122, 136] -> 
             RGBColor[
              0.8085502082780569, 0.8465126824966431, 0.7164898471021924], 
             UndirectedEdge[139, 206] -> 
             RGBColor[
              0.2460762386198535, 0.3759721072970965, 0.9373250498010044], 
             UndirectedEdge[65, 80] -> 
             RGBColor[
              0.27787319023653523`, 0.40939271948940265`, 0.9391358391561999],
              UndirectedEdge[171, 245] -> 
             RGBColor[
              0.4213779646314022, 0.5393981467165758, 0.9480708091897773], 
             UndirectedEdge[137, 232] -> 
             RGBColor[
              0.9198313733274753, 0.6705144142242014, 0.3950452840198946], 
             UndirectedEdge[64, 221] -> 
             RGBColor[
              0.26413437920159183`, 0.3949523580007457, 0.9383534341925093], 
             UndirectedEdge[140, 263] -> 
             RGBColor[
              0.2945287893227776, 0.42511180325549774`, 0.9401497819608717], 
             UndirectedEdge[200, 295] -> 
             RGBColor[
              0.8616403695892892, 0.7241541383976731, 0.6054633685285691], 
             UndirectedEdge[136, 232] -> 
             RGBColor[
              0.9935021049651632, 0.9885099844954769, 0.5341224096968956], 
             UndirectedEdge[45, 68] -> 
             RGBColor[
              0.8660950044608668, 0.48393636846669774`, 0.20994293256664392`],
              UndirectedEdge[224, 254] -> 
             RGBColor[
              0.9304233123934045, 0.7541309251793602, 0.28356918675006826`], 
             UndirectedEdge[148, 272] -> 
             RGBColor[
              0.23104689889957378`, 0.3601753183359065, 0.93646915113785], 
             UndirectedEdge[167, 185] -> 
             RGBColor[
              0.660998380157889, 0.7339582173045702, 0.9676238615993047], 
             UndirectedEdge[59, 137] -> 
             RGBColor[
              0.8391881810125934, 0.30222310839901756`, 0.1851599524353666], 
             UndirectedEdge[55, 97] -> 
             RGBColor[
              0.26708761639868417`, 0.39805639754094285`, 0.9385216166819608],
              UndirectedEdge[156, 202] -> 
             RGBColor[
              0.22791002753873152`, 0.3568782676465297, 0.9362905109544353], 
             UndirectedEdge[78, 176] -> 
             RGBColor[
              0.17949609924511575`, 0.30599215938959284`, 0.9335334093601024],
              UndirectedEdge[131, 143] -> 
             RGBColor[
              0.3607906299670138, 0.4869204426382663, 0.9442102378002388], 
             UndirectedEdge[230, 289] -> 
             RGBColor[
              0.27016772610159867`, 0.4012937881289406, 0.9386970243729278], 
             UndirectedEdge[35, 126] -> 
             RGBColor[
              0.2260848753293333, 0.35495991695311835`, 0.9361865712361809], 
             UndirectedEdge[147, 183] -> 
             RGBColor[
              0.24039105535964145`, 0.36999661922917565`, 0.9370012870248101],
              UndirectedEdge[66, 258] -> 
             RGBColor[
              0.9541114545413159, 0.9652969784492861, 0.9625615171988029], 
             UndirectedEdge[60, 232] -> 
             RGBColor[
              0.9600894947352094, 0.8672149974535253, 0.4291027093633025], 
             UndirectedEdge[39, 127] -> 
             RGBColor[
              0.8501524031963347, 0.3721425322398584, 0.1950971436579678], 
             UndirectedEdge[113, 258] -> 
             RGBColor[
              0.9605881616295711, 0.9701272959910724, 0.9515981414941335], 
             UndirectedEdge[45, 223] -> 
             RGBColor[
              0.872589282408941, 0.5134253678517513, 0.21536191727583626`], 
             UndirectedEdge[40, 80] -> 
             RGBColor[
              0.25252112623098183`, 0.38274609280586824`, 0.9376920766161012],
              UndirectedEdge[18, 198] -> 
             RGBColor[
              0.7053280385373079, 0.7677443822103661, 0.9632904037751118], 
             UndirectedEdge[13, 58] -> 
             RGBColor[
              0.4275257850964924, 0.5418851588163979, 0.949188660514906], 
             UndirectedEdge[16, 195] -> 
             RGBColor[
              0.9063070598041875, 0.5682974877338114, 0.34831639298626615`], 
             UndirectedEdge[17, 90] -> 
             RGBColor[
              0.3498844311553243, 0.4763161483780546, 0.9435577005911434], 
             UndirectedEdge[8, 273] -> 
             RGBColor[
              0.6348421879085798, 0.7142871342274307, 0.9644956454937833], 
             UndirectedEdge[85, 256] -> 
             RGBColor[
              0.9574368195628593, 0.965496391216921, 0.8581727577239964], 
             UndirectedEdge[149, 227] -> 
             RGBColor[
              0.27685707898321577`, 0.40832472213698934`, 0.9390779731235251],
              UndirectedEdge[182, 208] -> 
             RGBColor[
              0.2965714316502459, 0.42904575675219153`, 0.9402006763431414], 
             UndirectedEdge[82, 100] -> 
             RGBColor[
              0.9226285034001888, 0.6892957114983669, 0.45059538097393753`], 
             UndirectedEdge[227, 264] -> 
             RGBColor[
              0.2772132461146813, 0.4086990763744601, 0.9390982563147601], 
             UndirectedEdge[74, 259] -> 
             RGBColor[
              0.5512374616169957, 0.646558430162153, 0.9578145787092965], 
             UndirectedEdge[96, 105] -> 
             RGBColor[
              0.3473181215020726, 0.473441328714978, 0.9434180509343462], 
             UndirectedEdge[60, 100] -> 
             RGBColor[
              0.8881313902235266, 0.565681082313474, 0.22753422766752193`], 
             UndirectedEdge[73, 87] -> 
             RGBColor[
              0.3025587103322468, 0.4334652095438001, 0.9406102430960075], 
             UndirectedEdge[68, 223] -> 
             RGBColor[
              0.880860495472638, 0.5518971603270344, 0.22229941585693147`], 
             UndirectedEdge[162, 191] -> 
             RGBColor[
              0.26420786908525307`, 0.39502960052800135`, 0.9383576193326653],
              UndirectedEdge[87, 149] -> 
             RGBColor[
              0.2850281329082009, 0.41691301788689017`, 0.939543302556562], 
             UndirectedEdge[60, 256] -> 
             RGBColor[
              0.9606652122328164, 0.8684463989669389, 0.49176600606128196`], 
             UndirectedEdge[145, 169] -> 
             RGBColor[
              0.28111445342614677`, 0.4127994926096401, 0.939320424299829], 
             UndirectedEdge[144, 235] -> 
             RGBColor[
              0.27887432985742466`, 0.4098011584346488, 0.9392164260637837], 
             UndirectedEdge[36, 88] -> 
             RGBColor[
              0.6318962145275521, 0.7102452969352381, 0.9653919533977545], 
             UndirectedEdge[38, 123] -> 
             RGBColor[
              0.4270824703910924, 0.5443391028888234, 0.9484342952524883], 
             UndirectedEdge[183, 244] -> 
             RGBColor[
              0.24855034907625476`, 0.37857255425443737`, 0.937465946731378], 
             UndirectedEdge[2, 32] -> 
             RGBColor[
              0.24350738500413596`, 0.3732720792722509, 0.9371787573878676], 
             UndirectedEdge[106, 151] -> 
             RGBColor[
              0.5499711557200619, 0.645038448022178, 0.9579401200370031], 
             UndirectedEdge[164, 277] -> 
             RGBColor[
              0.36650966152605724`, 0.4918739803278257, 0.94457464943404], 
             UndirectedEdge[296, 299] -> 
             RGBColor[
              0.8453600637344856, 0.8773055132358333, 0.8557133788601069], 
             UndirectedEdge[75, 174] -> 
             RGBColor[
              0.5614179437120186, 0.6518168625034114, 0.9599968953209368], 
             UndirectedEdge[31, 66] -> 
             RGBColor[
              0.7826462994682315, 0.8305130082182347, 0.9693283290234715], 
             UndirectedEdge[2, 268] -> 
             RGBColor[
              0.2466368287086141, 0.37656132302384837`, 0.9373569745772405], 
             UndirectedEdge[46, 264] -> 
             RGBColor[
              0.29339971487327476`, 0.42571208132113636`, 0.9400200517648274],
              UndirectedEdge[71, 160] -> 
             RGBColor[
              0.6099082730566356, 0.6941900379787878, 0.9624333599040888], 
             UndirectedEdge[50, 114] -> 
             RGBColor[
              0.32843011888336315`, 0.4584906115476223, 0.9421629292736595], 
             UndirectedEdge[126, 197] -> 
             RGBColor[
              0.21821940668747852`, 0.34669281071101354`, 0.9357386444329454],
              UndirectedEdge[265, 269] -> 
             RGBColor[
              0.2247455605611441, 0.35355221221429056`, 0.9361102992414712], 
             UndirectedEdge[144, 257] -> 
             RGBColor[
              0.3535074058070181, 0.4806120799363681, 0.9437461571970662], 
             UndirectedEdge[86, 107] -> 
             RGBColor[
              0.9045073081884096, 0.5951795926664958, 0.26859915666912515`], 
             UndirectedEdge[149, 245] -> 
             RGBColor[
              0.3591757955739624, 0.4841536676462995, 0.9441574343329895], 
             UndirectedEdge[143, 283] -> 
             RGBColor[
              0.5077365883087008, 0.6097065089762495, 0.9548144188773069], 
             UndirectedEdge[66, 154] -> 
             RGBColor[
              0.8438279787518632, 0.8786689323302527, 0.9751799865903525], 
             UndirectedEdge[57, 159] -> 
             RGBColor[
              0.24722335585304894`, 0.3771778002406183, 0.937390376430427], 
             UndirectedEdge[7, 167] -> 
             RGBColor[
              0.5743366058251028, 0.6620119381044995, 0.9612409468107508], 
             UndirectedEdge[57, 89] -> 
             RGBColor[
              0.26259271630004477`, 0.3933319725441461, 0.9382656387709521], 
             UndirectedEdge[122, 256] -> 
             RGBColor[
              0.8097203609609858, 0.8490155207648438, 0.8438537452937325], 
             UndirectedEdge[39, 232] -> 
             RGBColor[
              0.9308146259118721, 0.7405801140636548, 0.40500069877565514`], 
             UndirectedEdge[72, 286] -> 
             RGBColor[
              0.6054217047226151, 0.6904029000986035, 0.9621791200575058], 
             UndirectedEdge[71, 299] -> 
             RGBColor[
              0.812040550004389, 0.8510805514465378, 0.8525260685636215], 
             UndirectedEdge[90, 158] -> 
             RGBColor[
              0.4035892626740157, 0.5239904671672448, 0.9469373288309841], 
             UndirectedEdge[52, 236] -> 
             RGBColor[
              0.7204593344779664, 0.42105333760098257`, 0.5640355482527617], 
             UndirectedEdge[17, 134] -> 
             RGBColor[
              0.2851115833841571, 0.4170007296281859, 0.9395480549377139], 
             UndirectedEdge[54, 72] -> 
             RGBColor[
              0.534606977221836, 0.6319372303906756, 0.9568737438527076], 
             UndirectedEdge[170, 192] -> 
             RGBColor[
              0.8434397887079927, 0.3245517789190093, 0.188825975634882], 
             UndirectedEdge[140, 198] -> 
             RGBColor[
              0.3961646850276139, 0.5172626963041967, 0.9465462963516883], 
             UndirectedEdge[19, 89] -> 
             RGBColor[
              0.28469980544749635`, 0.41656792490852634`, 0.9395246047933918],
              UndirectedEdge[239, 295] -> 
             RGBColor[
              0.6242095261484855, 0.7018088738432534, 0.9658801269946564], 
             UndirectedEdge[51, 69] -> 
             RGBColor[
              0.9933000659558078, 0.9895615584823135, 0.6199821278730931], 
             UndirectedEdge[186, 269] -> 
             RGBColor[
              0.2284972047762287, 0.3574954281523263, 0.93632394982946], 
             UndirectedEdge[37, 282] -> 
             RGBColor[
              0.8221799053423591, 0.8614527527728091, 0.9576065400232527], 
             UndirectedEdge[1, 239] -> 
             RGBColor[
              0.4148284678056251, 0.5337253017533699, 0.9476534810435313], 
             UndirectedEdge[59, 200] -> 
             RGBColor[
              0.8594030577293614, 0.41420745732297415`, 0.20281846065499215`],
              UndirectedEdge[145, 221] -> 
             RGBColor[
              0.2819086057959276, 0.4136341971024482, 0.9393656501024449], 
             UndirectedEdge[75, 297] -> 
             RGBColor[
              0.7454557140194038, 0.8010749365560057, 0.9752637169598848], 
             UndirectedEdge[142, 185] -> 
             RGBColor[
              0.6135470246958941, 0.696888857774001, 0.9628943539449815], 
             UndirectedEdge[36, 258] -> 
             RGBColor[
              0.8606691521172266, 0.8915543066994391, 0.9631366201381162], 
             UndirectedEdge[13, 289] -> 
             RGBColor[
              0.2985558278706446, 0.4311314829978179, 0.940313684772242], 
             UndirectedEdge[53, 170] -> 
             RGBColor[
              0.8268112796846933, 0.20708882120003286`, 0.1733078177460588], 
             UndirectedEdge[130, 226] -> 
             RGBColor[
              0.178927005110741, 0.3053940053717128, 0.9335010002910491], 
             UndirectedEdge[224, 249] -> 
             RGBColor[
              0.8940523406864429, 0.5263405979795888, 0.25076760006070237`], 
             UndirectedEdge[234, 271] -> 
             RGBColor[
              0.8973919728354314, 0.5348865558223752, 0.26558699931478663`], 
             UndirectedEdge[78, 266] -> 
             RGBColor[
              0.21383713709575333`, 0.3420867675181703, 0.9354890806626834], 
             UndirectedEdge[127, 232] -> 
             RGBColor[
              0.9134343174349477, 0.6213438394264674, 0.3889194560727688], 
             UndirectedEdge[57, 292] -> 
             RGBColor[
              0.2450572419916986, 0.37490107723278787`, 0.9372670194505013], 
             UndirectedEdge[52, 107] -> 
             RGBColor[
              0.8259275201506884, 0.20029585815577397`, 0.17246152861823205`],
              UndirectedEdge[26, 130] -> 
             RGBColor[
              0.5823809948253185, 0.6469022092217233, 0.9089577047840149], 
             UndirectedEdge[51, 58] -> 
             RGBColor[
              0.7712426526188537, 0.8181426903224094, 0.8569941031084208], 
             UndirectedEdge[192, 195] -> 
             RGBColor[
              0.8420649475314406, 0.3139841471767838, 0.18750942617155456`], 
             UndirectedEdge[118, 266] -> 
             RGBColor[
              0.21328176149194045`, 0.3415030325457159, 0.9354574528436509], 
             UndirectedEdge[171, 289] -> 
             RGBColor[
              0.35466828761855285`, 0.4799752914739057, 0.9438802596927696], 
             UndirectedEdge[1, 283] -> 
             RGBColor[
              0.5186228959615405, 0.619135681503407, 0.955508084774562], 
             UndirectedEdge[44, 59] -> 
             RGBColor[
              0.8989327098919131, 0.5734920759622608, 0.24889953887676536`], 
             UndirectedEdge[62, 127] -> 
             RGBColor[
              0.9138104141355006, 0.6221482722397406, 0.4298552609281541], 
             UndirectedEdge[46, 219] -> 
             RGBColor[
              0.2831865614508789, 0.4149774095228705, 0.9394384277864284], 
             UndirectedEdge[55, 252] -> 
             RGBColor[
              0.2886130512396545, 0.4206809943501981, 0.9397474583521269], 
             UndirectedEdge[55, 144] -> 
             RGBColor[
              0.2962021466118664, 0.42801379249060423`, 0.9402032195937415], 
             UndirectedEdge[160, 296] -> 
             RGBColor[
              0.6432277867867322, 0.7204149997680831, 0.9656206702005743], 
             UndirectedEdge[154, 179] -> 
             RGBColor[
              0.8674233288276321, 0.8946955574709121, 0.8648978949263142], 
             UndirectedEdge[6, 145] -> 
             RGBColor[
              0.2874384541046572, 0.41944641828755624`, 0.9396805667829495], 
             UndirectedEdge[132, 243] -> 
             RGBColor[
              0.21243933131542342`, 0.34061758501703826`, 0.935409477691362], 
             UndirectedEdge[53, 59] -> 
             RGBColor[
              0.8322696375208192, 0.249044151396152, 0.17853474737426642`], 
             UndirectedEdge[4, 228] -> 
             RGBColor[
              0.6779819914219037, 0.7467901325313183, 0.9696145955916023], 
             UndirectedEdge[71, 98] -> 
             RGBColor[
              0.5262018737865255, 0.625404972246536, 0.9560725859325541], 
             UndirectedEdge[201, 259] -> 
             RGBColor[
              0.3926869440225089, 0.5142503026969059, 0.9463247389793005], 
             UndirectedEdge[34, 187] -> 
             RGBColor[
              0.34571434459052375`, 0.47386212200128636`, 0.9432495902274847],
              UndirectedEdge[18, 260] -> 
             RGBColor[
              0.8977772500782942, 0.9210512580678571, 0.980544009200409], 
             UndirectedEdge[263, 289] -> 
             RGBColor[
              0.27598341660935993`, 0.40740644758867306`, 0.9390282193438018],
              UndirectedEdge[173, 209] -> 
             RGBColor[
              0.2611649721580388, 0.3918313229266909, 0.938184330854223], 
             UndirectedEdge[4, 199] -> 
             RGBColor[
              0.3592738699625091, 0.4712607260826286, 0.9452005339121252], 
             UndirectedEdge[253, 292] -> 
             RGBColor[
              0.26989343961389634`, 0.40100549563959764`, 0.9386814041632237],
              UndirectedEdge[128, 209] -> 
             RGBColor[
              0.25220846656924684`, 0.38241746767761725`, 0.9376742711109041],
              UndirectedEdge[44, 137] -> 
             RGBColor[
              0.9053107353837854, 0.6225163747613823, 0.25500714329073165`], 
             UndirectedEdge[129, 263] -> 
             RGBColor[
              0.24844649898142085`, 0.37846340122029065`, 0.9374600326221096],
              UndirectedEdge[73, 289] -> 
             RGBColor[
              0.309996695985159, 0.44128300406053933`, 0.9410338253754271], 
             UndirectedEdge[128, 276] -> 
             RGBColor[
              0.235521079118485, 0.3648779654253926, 0.9367239490823606], 
             UndirectedEdge[96, 196] -> 
             RGBColor[
              0.34319916551880214`, 0.4691120448196677, 0.9431834824845483], 
             UndirectedEdge[24, 224] -> 
             RGBColor[
              0.9625807494214099, 0.9376482057938698, 0.6480446128648567], 
             UndirectedEdge[88, 278] -> 
             RGBColor[
              0.553576335347311, 0.6484572332214837, 0.9579987034169237], 
             UndirectedEdge[158, 253] -> 
             RGBColor[
              0.35017871358609476`, 0.47661754474481344`, 0.9435747492785509],
              UndirectedEdge[67, 110] -> 
             RGBColor[
              0.9526321539767644, 0.9621364418592473, 0.8790329410814011], 
             UndirectedEdge[155, 275] -> 
             RGBColor[
              0.21254067958734837`, 0.340724108476683, 0.9354152493255168], 
             UndirectedEdge[101, 108] -> 
             RGBColor[
              0.44525533808141193`, 0.5575469670447641, 0.9502920083081179], 
             UndirectedEdge[102, 210] -> 
             RGBColor[
              0.3819399405336581, 0.5052389124558365, 0.9455578531679444], 
             UndirectedEdge[176, 199] -> 
             RGBColor[
              0.17893943915932659`, 0.3054070743451405, 0.9335017083917216], 
             UndirectedEdge[62, 226] -> 
             RGBColor[
              0.5868878718865363, 0.6483921488101179, 0.8070978107416625], 
             UndirectedEdge[69, 113] -> 
             RGBColor[
              0.9762236487706943, 0.9783827123378863, 0.71860105300982], 
             UndirectedEdge[51, 258] -> 
             RGBColor[
              0.9776645788146846, 0.9813061421354996, 0.8529792163574066], 
             UndirectedEdge[30, 74] -> 
             RGBColor[
              0.5502062391736314, 0.6457212373265883, 0.9577333971010626], 
             UndirectedEdge[118, 228] -> 
             RGBColor[
              0.49763640594137093`, 0.5809247565206876, 0.9579151348288255], 
             UndirectedEdge[71, 121] -> 
             RGBColor[
              0.8121033376840514, 0.8505268967747761, 0.8093533323550504], 
             UndirectedEdge[1, 20] -> 
             RGBColor[
              0.6422142592503285, 0.7164194344925677, 0.9674804697406698], 
             UndirectedEdge[126, 293] -> 
             RGBColor[
              0.21759994210882713`, 0.34604171416252816`, 0.9357033668416068],
              UndirectedEdge[112, 159] -> 
             RGBColor[
              0.24980358255219737`, 0.3798897820972448, 0.9375373165238401], 
             UndirectedEdge[17, 159] -> 
             RGBColor[
              0.2718080646722995, 0.4030178879702195, 0.9387904392278659], 
             UndirectedEdge[139, 172] -> 
             RGBColor[
              0.26248705403553485`, 0.3932209148047717, 0.9382596214613016], 
             UndirectedEdge[47, 233] -> 
             RGBColor[
              0.8190741460647206, 0.8558139473261162, 0.781552654000438], 
             UndirectedEdge[98, 182] -> 
             RGBColor[
              0.3649951509133196, 0.4904176871542194, 0.9444834370172861], 
             UndirectedEdge[84, 159] -> 
             RGBColor[
              0.27400586003393973`, 0.4053279102435776, 0.9389156004223643], 
             UndirectedEdge[118, 176] -> 
             RGBColor[
              0.17894072364130287`, 0.30540842441713845`, 0.9335017815410699],
              UndirectedEdge[18, 278] -> 
             RGBColor[
              0.7746661157384185, 0.8240361569270088, 0.968748951206129], 
             UndirectedEdge[155, 197] -> 
             RGBColor[
              0.21140151230331092`, 0.3395267714337822, 0.9353503754339378], 
             UndirectedEdge[72, 215] -> 
             RGBColor[
              0.8234553846620669, 0.8600796725778928, 0.8483727211925696], 
             UndirectedEdge[162, 239] -> 
             RGBColor[
              0.34783050852175984`, 0.47345580113907954`, 0.9434664197100019],
              UndirectedEdge[139, 272] -> 
             RGBColor[
              0.23937950956716447`, 0.3689334204655748, 0.9369436809883765], 
             UndirectedEdge[9, 75] -> 
             RGBColor[
              0.6236710270535416, 0.7040128640312203, 0.9644400885599815], 
             UndirectedEdge[18, 254] -> 
             RGBColor[
              0.918861315886804, 0.779473166025562, 0.6033212282319205], 
             UndirectedEdge[25, 244] -> 
             RGBColor[
              0.2471607788887478, 0.37711202788352904`, 0.9373868127648843], 
             UndirectedEdge[30, 257] -> 
             RGBColor[
              0.42675186290096767`, 0.5438116234909512, 0.9484798524617939], 
             UndirectedEdge[29, 270] -> 
             RGBColor[
              0.2355391750470839, 0.3648969853936982, 0.9367249796187237], 
             UndirectedEdge[73, 298] -> 
             RGBColor[
              0.307131102255913, 0.43827108336196546`, 0.9408706340518126], 
             UndirectedEdge[73, 96] -> 
             RGBColor[
              0.3672380173898648, 0.4925048455688256, 0.9446210596256222], 
             UndirectedEdge[108, 205] -> 
             RGBColor[
              0.436683616415666, 0.5505880572448512, 0.9496172109793394], 
             UndirectedEdge[9, 43] -> 
             RGBColor[
              0.41950169820548255`, 0.5360485287106651, 0.948427736968998], 
             UndirectedEdge[151, 251] -> 
             RGBColor[
              0.36499365332834144`, 0.4885238594535514, 0.944552636407374], 
             UndirectedEdge[209, 279] -> 
             RGBColor[
              0.2619744678088157, 0.39268215418064606`, 0.9382304304339932], 
             UndirectedEdge[53, 68] -> 
             RGBColor[
              0.8530476685227406, 0.3836488270671944, 0.19744878893743584`], 
             UndirectedEdge[282, 295] -> 
             RGBColor[
              0.9004709095023198, 0.9227541160141217, 0.9653727475363004], 
             UndirectedEdge[35, 197] -> 
             RGBColor[
              0.218365708643122, 0.3468465833424746, 0.9357469761128849], 
             UndirectedEdge[116, 168] -> 
             RGBColor[
              0.35414043439259346`, 0.4811603774802517, 0.9437864932187738], 
             UndirectedEdge[27, 152] -> 
             RGBColor[
              0.2558672975304459, 0.3862631310011191, 0.9378826361213889], 
             UndirectedEdge[114, 231] -> 
             RGBColor[
              0.37476526938347776`, 0.4986237900384425, 0.945115364090962], 
             UndirectedEdge[83, 155] -> 
             RGBColor[
              0.21429563561346426`, 0.34256867853076955`, 0.9355151914749793],
              UndirectedEdge[62, 199] -> 
             RGBColor[
              0.5868878667757954, 0.648392143438405, 0.8070978104506135], 
             UndirectedEdge[96, 278] -> 
             RGBColor[
              0.5041987109200126, 0.6070709568623011, 0.9544705154158305], 
             UndirectedEdge[2, 178] -> 
             RGBColor[
              0.25390682555337085`, 0.3842025506521106, 0.9377709901425528], 
             UndirectedEdge[6, 213] -> 
             RGBColor[
              0.3667758904705204, 0.4918204598931879, 0.9446020161329686], 
             UndirectedEdge[79, 93] -> 
             RGBColor[
              0.46307011169266854`, 0.5733948534802826, 0.9513117589171669], 
             UndirectedEdge[270, 272] -> 
             RGBColor[
              0.22576785330449248`, 0.35462670670465335`, 0.9361685173008583],
              UndirectedEdge[161, 186] -> 
             RGBColor[
              0.22312007554742067`, 0.3518437244031648, 0.9360177302746292], 
             UndirectedEdge[189, 275] -> 
             RGBColor[
              0.22231351200262228`, 0.3509959749784993, 0.9359717976739568], 
             UndirectedEdge[260, 261] -> 
             RGBColor[
              0.6248975820608704, 0.7019966768640338, 0.9661118661321497], 
             UndirectedEdge[195, 200] -> 
             RGBColor[
              0.8525698587166832, 0.36168449538462955`, 0.19627498156345707`],
              UndirectedEdge[66, 110] -> 
             RGBColor[
              0.969700925487342, 0.9754692267738965, 0.8710436844734033], 
             UndirectedEdge[63, 172] -> 
             RGBColor[
              0.29700434513925705`, 0.4280429826559164, 0.940278707091565], 
             UndirectedEdge[4, 236] -> 
             RGBColor[
              0.5814156950940945, 0.671058479612787, 0.9601903197951254], 
             UndirectedEdge[143, 167] -> 
             RGBColor[
              0.5753382538779925, 0.6628795153036178, 0.9613047709389584], 
             UndirectedEdge[135, 249] -> 
             RGBColor[
              0.9043378524473125, 0.5669958495159765, 0.4896141522242598], 
             UndirectedEdge[135, 288] -> 
             RGBColor[
              0.9259984255937815, 0.7279896925534243, 0.5101410217698862], 
             UndirectedEdge[83, 214] -> 
             RGBColor[
              0.21458531177906248`, 0.342873146547343, 0.9355316881040727], 
             UndirectedEdge[36, 290] -> 
             RGBColor[
              0.6862499936639361, 0.7543721434480005, 0.9696708819958241], 
             UndirectedEdge[79, 119] -> 
             RGBColor[
              0.3385777508483834, 0.465228690511853, 0.9428846351776731], 
             UndirectedEdge[145, 264] -> 
             RGBColor[
              0.28193257724579573`, 0.4136593926161374, 0.9393670152410523], 
             UndirectedEdge[54, 238] -> 
             RGBColor[
              0.34796050319161576`, 0.47301253149465217`, 0.9434950557775005],
              UndirectedEdge[177, 273] -> 
             RGBColor[
              0.5185213619952923, 0.6190718502597115, 0.9554949527990644], 
             UndirectedEdge[98, 208] -> 
             RGBColor[
              0.3543834762769441, 0.47926414429235664`, 0.9438791178453103], 
             UndirectedEdge[125, 170] -> 
             RGBColor[
              0.9072593029227105, 0.5779612249611302, 0.303635751806013], 
             UndirectedEdge[22, 217] -> 
             RGBColor[
              0.812207338591908, 0.8532218130031827, 0.981916895067874], 
             UndirectedEdge[78, 236] -> 
             RGBColor[
              0.4016254852173745, 0.5057768385746106, 0.9485224868513811], 
             UndirectedEdge[86, 240] -> 
             RGBColor[
              0.984900576757397, 0.9592281782774306, 0.5233965503688487], 
             UndirectedEdge[59, 170] -> 
             RGBColor[
              0.8273517976845952, 0.21124347940377694`, 0.17382541839319265`],
              UndirectedEdge[95, 109] -> 
             RGBColor[
              0.7049075830694689, 0.7678615870686365, 0.9726151362943627], 
             UndirectedEdge[30, 252] -> 
             RGBColor[
              0.38136485218953986`, 0.5037401708621798, 0.9456156414781487], 
             UndirectedEdge[116, 119] -> 
             RGBColor[
              0.30231628529617693`, 0.4338208316047836, 0.9405740866574415], 
             UndirectedEdge[6, 231] -> 
             RGBColor[
              0.3753962033450712, 0.49928694163560083`, 0.9451512948466916], 
             UndirectedEdge[214, 275] -> 
             RGBColor[
              0.21283035575294662`, 0.34102857649325646`, 0.9354317459546102],
              UndirectedEdge[157, 257] -> 
             RGBColor[
              0.3686428791962128, 0.49372166625507674`, 0.944710576177652], 
             UndirectedEdge[128, 173] -> 
             RGBColor[
              0.24821711809960986`, 0.3782223073699194, 0.9374469697202291], 
             UndirectedEdge[14, 113] -> 
             RGBColor[
              0.8910534941556458, 0.5723590692569638, 0.5614811576965728], 
             UndirectedEdge[213, 231] -> 
             RGBColor[
              0.43649903669503015`, 0.5524952593309104, 0.9490343105306326], 
             UndirectedEdge[29, 148] -> 
             RGBColor[
              0.2408182206421652, 0.3704455970249514, 0.9370256134557156], 
             UndirectedEdge[109, 154] -> 
             RGBColor[
              0.8311843708271494, 0.8688646527411055, 0.9835913192515602], 
             UndirectedEdge[74, 123] -> 
             RGBColor[
              0.5372173592410554, 0.6347120461758202, 0.9568391339311428], 
             UndirectedEdge[189, 216] -> 
             RGBColor[
              0.24534319825395978`, 0.3752016353950986, 0.9372833042366027], 
             UndirectedEdge[29, 162] -> 
             RGBColor[
              0.2636748497853562, 0.39446936344843425`, 0.9383272646720675], 
             UndirectedEdge[73, 140] -> 
             RGBColor[
              0.3285420686985767, 0.45898835972736407`, 0.9421553879924971], 
             UndirectedEdge[9, 295] -> 
             RGBColor[
              0.677057217004213, 0.7458583971286377, 0.9697240169413682], 
             UndirectedEdge[169, 221] -> 
             RGBColor[
              0.2938192081333214, 0.4261529953348542, 0.9400439412854023], 
             UndirectedEdge[22, 61] -> 
             RGBColor[
              0.6921091843567939, 0.7582433580431021, 0.9707375877325777], 
             UndirectedEdge[11, 143] -> 
             RGBColor[
              0.3701279239778581, 0.49500793740441695`, 0.9448052019179649], 
             UndirectedEdge[100, 299] -> 
             RGBColor[
              0.9223324395514323, 0.6893504120322749, 0.46837744579024243`], 
             UndirectedEdge[181, 232] -> 
             RGBColor[
              0.8539568089581072, 0.8830700073511788, 0.7854666422842203], 
             UndirectedEdge[49, 292] -> 
             RGBColor[
              0.23980801296623738`, 0.36938380470668514`, 0.9369680836230397],
              UndirectedEdge[4, 39] -> 
             RGBColor[
              0.7035767257991387, 0.5642531295211515, 0.5840392270925523], 
             UndirectedEdge[33, 75] -> 
             RGBColor[
              0.8225875285373088, 0.8620961486244765, 0.9827484209506085], 
             UndirectedEdge[223, 271] -> 
             RGBColor[
              0.9324098595457874, 0.7585161356784191, 0.29733719959784854`], 
             UndirectedEdge[21, 34] -> 
             RGBColor[
              0.3554769401154252, 0.48231799156263766`, 0.943871654181607], 
             UndirectedEdge[51, 165] -> 
             RGBColor[
              0.986911243979133, 0.9683407522697562, 0.5670857457477134], 
             UndirectedEdge[36, 138] -> 
             RGBColor[
              0.7331275863556836, 0.791444109527867, 0.9740349644072682], 
             UndirectedEdge[50, 205] -> 
             RGBColor[
              0.44094793085644673`, 0.5542815920827796, 0.9498889293247207], 
             UndirectedEdge[237, 283] -> 
             RGBColor[
              0.6287512202285861, 0.7094875913580734, 0.9639167457294545], 
             UndirectedEdge[140, 245] -> 
             RGBColor[
              0.37623831770858585`, 0.5003004533366545, 0.945194550803278], 
             UndirectedEdge[19, 49] -> 
             RGBColor[
              0.26391083574794544`, 0.39471739965748975`, 0.9383407037235271],
              UndirectedEdge[235, 292] -> 
             RGBColor[
              0.24255033880224458`, 0.3722661630338292, 0.9371242550224929], 
             UndirectedEdge[15, 115] -> 
             RGBColor[
              0.230257062183032, 0.3593451498682808, 0.9364241711053016], 
             UndirectedEdge[69, 110] -> 
             RGBColor[
              0.9929919929128255, 0.9894341623619243, 0.625087695462787], 
             UndirectedEdge[34, 50] -> 
             RGBColor[
              0.33997412107403424`, 0.46889022890332593`, 0.9428838282608942],
              UndirectedEdge[126, 275] -> 
             RGBColor[
              0.21935857397151598`, 0.34789014775391436`, 0.9358035183245244],
              UndirectedEdge[59, 225] -> 
             RGBColor[
              0.8968865048957325, 0.5665897460383628, 0.24095041885999358`], 
             UndirectedEdge[82, 228] -> 
             RGBColor[
              0.9057099592960236, 0.9241653224619759, 0.8439169187539672], 
             UndirectedEdge[19, 280] -> 
             RGBColor[
              0.2796627567223554, 0.4112736673310683, 0.939237752320141], 
             UndirectedEdge[194, 283] -> 
             RGBColor[
              0.5672781592829315, 0.6595809911525545, 0.9590773611885706], 
             UndirectedEdge[63, 283] -> 
             RGBColor[
              0.4716182093057971, 0.5784225844464469, 0.9525129877054703], 
             UndirectedEdge[36, 245] -> 
             RGBColor[
              0.5919869457083973, 0.6770600343104392, 0.9624670806434741], 
             UndirectedEdge[3, 55] -> 
             RGBColor[
              0.327009852931445, 0.45469787926428074`, 0.9421662593982401], 
             UndirectedEdge[137, 192] -> 
             RGBColor[
              0.8552761720359909, 0.4155314079142499, 0.20016050967705595`], 
             UndirectedEdge[54, 251] -> 
             RGBColor[
              0.3520600889143901, 0.4773214560180356, 0.9437285211196189], 
             UndirectedEdge[252, 292] -> 
             RGBColor[
              0.2717964040404102, 0.4030056319067771, 0.9387897751721301], 
             UndirectedEdge[100, 121] -> 
             RGBColor[
              0.9223952272310946, 0.6887967573605129, 0.4252047095816714], 
             UndirectedEdge[142, 239] -> 
             RGBColor[
              0.5350790113196064, 0.6320396024840493, 0.9570335383591173], 
             UndirectedEdge[85, 299] -> 
             RGBColor[
              0.9570551059778822, 0.9653678956255696, 0.8666323773215838], 
             UndirectedEdge[120, 130] -> 
             RGBColor[
              0.18442078734008566`, 0.31116831882066576`, 0.9338138630616879],
              UndirectedEdge[9, 297] -> 
             RGBColor[
              0.6386143417337113, 0.7156866950327669, 0.9659294985140855], 
             UndirectedEdge[237, 239] -> 
             RGBColor[
              0.5249567920726707, 0.6240772116080362, 0.9560621419984239], 
             UndirectedEdge[169, 213] -> 
             RGBColor[
              0.36045188979201, 0.48517353421527176`, 0.944241873649848], 
             UndirectedEdge[46, 50] -> 
             RGBColor[
              0.32229358745653136`, 0.4520407279394575, 0.9418134628870861], 
             UndirectedEdge[105, 171] -> 
             RGBColor[
              0.3537618197336009, 0.4790225362534377, 0.9438286376877205], 
             UndirectedEdge[34, 114] -> 
             RGBColor[
              0.31595519138804573`, 0.44768545635926527`, 0.9413680379248031],
              UndirectedEdge[60, 240] -> 
             RGBColor[
              0.9605080040332614, 0.868110146524278, 0.47465486371626864`], 
             UndirectedEdge[19, 84] -> 
             RGBColor[
              0.2959425689542974, 0.42838478218655185`, 0.940164863542926], 
             UndirectedEdge[19, 48] -> 
             RGBColor[
              0.3524750293077462, 0.47810184855613913`, 0.9437395461742546], 
             UndirectedEdge[5, 77] -> 
             RGBColor[
              0.23349568981372465`, 0.3627491528489905, 0.9366086061577494]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.26920385108875294`, 0.4002806943772341, 0.9386421331168716], 
             160 -> RGBColor[
              0.5902199940802382, 0.6782062061588879, 0.9608834264625246], 
             245 -> RGBColor[
              0.4244026220080174, 0.5420179529125, 0.9482635376832157], 155 -> 
             RGBColor[
              0.21230278460535462`, 0.3404740657671945, 0.9354017015582263], 
             213 -> RGBColor[
              0.42787872382047937`, 0.5450287775884974, 0.9484850318169096], 
             27 -> RGBColor[
              0.2584384877012701, 0.38896561489352793`, 0.9380290615978824], 
             19 -> RGBColor[
              0.2912671539208582, 0.4234706245479727, 0.9398986055734284], 
             164 -> RGBColor[
              0.38392426951059677`, 0.5069576384803866, 0.9456842928556817], 
             190 -> RGBColor[
              0.22813210557574862`, 0.35711168574399543`, 0.9363031579701084],
              103 -> RGBColor[
              0.2788168781365947, 0.4103845953056338, 0.9391895807860471], 
             138 -> RGBColor[
              0.7066839033025902, 0.7707861033473555, 0.971399305210804], 291 -> 
             RGBColor[
              0.8179080138731872, 0.1386544187368418, 0.16478204035016009`], 
             28 -> RGBColor[
              0.22341264573171882`, 0.35215123421688327`, 0.9360343917138061],
              114 -> RGBColor[
              0.3044111891973746, 0.4372858390035616, 0.9406471389375684], 
             195 -> RGBColor[
              0.8191437574953648, 0.1481528857232069, 0.16596538983833015`], 
             93 -> RGBColor[
              0.5312094509757161, 0.6302987888719648, 0.9562379003465947], 34 -> 
             RGBColor[
              0.3274991935787168, 0.458085073714969, 0.9420889369120379], 161 -> 
             RGBColor[
              0.21627103797903324`, 0.3446449516647265, 0.9356276877173526], 
             22 -> RGBColor[
              0.8173789776787558, 0.8572619367637411, 0.982432355720336], 124 -> 
             RGBColor[
              0.9476938047146304, 0.9605107057164812, 0.973424924364235], 84 -> 
             RGBColor[
              0.30061798398773654`, 0.43329893982513096`, 0.9404311215124237],
              46 -> RGBColor[
              0.29213812634371106`, 0.4243860717872321, 0.9399482061644217], 
             241 -> RGBColor[
              0.2790754121939759, 0.4106563309919474, 0.9392043039181481], 
             185 -> RGBColor[
              0.5680702998089695, 0.6602240865171163, 0.9591397213924867], 
             121 -> RGBColor[
              0.9946101233350695, 0.9908799237508646, 0.6547233713644478], 
             126 -> RGBColor[
              0.22593857337368983`, 0.3548061443216573, 0.9361782395562414], 
             236 -> RGBColor[
              0.6232106502631707, 0.7049895070603167, 0.9634805717660004], 78 -> 
             RGBColor[
              0.1800403201715783, 0.3065641700889047, 0.9335644019367618], 
             254 -> RGBColor[
              0.8913219113450659, 0.5994000064779764, 0.23102867769365362`], 
             290 -> RGBColor[
              0.6129287179190951, 0.6966421711876226, 0.9626711403879157], 
             251 -> RGBColor[
              0.2867137638335649, 0.4186847228646212, 0.9396392967440941], 
             165 -> RGBColor[
              0.9802603651545728, 0.9450757179590131, 0.3778156754531135], 
             100 -> RGBColor[
              0.8501803311271197, 0.38671359097016134`, 0.19568604779889498`],
              235 -> RGBColor[
              0.24203916924704705`, 0.37172889142129484`, 0.937095144672532], 
             70 -> RGBColor[
              0.26423372362278924`, 0.39505677528622424`, 0.9383590917103296],
              234 -> RGBColor[0.817319, 0.134127, 0.164218], 257 -> 
             RGBColor[
              0.39130532114623406`, 0.5133507344247334, 0.9461546069390968], 
             135 -> RGBColor[
              0.9900957369634822, 0.9901723469535194, 0.8138028001335977], 
             265 -> RGBColor[
              0.22246582468563886`, 0.3511560652655316, 0.9359804716559281], 
             111 -> RGBColor[
              0.24301438028138522`, 0.37275390005033504`, 0.937150681498242], 
             182 -> RGBColor[
              0.3071831062866214, 0.4401992996140543, 0.9408049955151171], 
             188 -> RGBColor[
              0.20571498311483435`, 0.33354986870991854`, 0.9350265360091202],
              154 -> RGBColor[
              0.7412000832467709, 0.797750405452433, 0.9748395554555993], 269 -> 
             RGBColor[
              0.2270252964366493, 0.35594835916304945`, 0.9362401268270142], 
             208 -> RGBColor[
              0.28595975701387044`, 0.41789221389032877`, 0.9395963571711656],
              86 -> RGBColor[
              0.9748675947682047, 0.926884637163092, 0.35686578084130904`], 
             119 -> RGBColor[
              0.28222472928714576`, 0.41396646293510553`, 0.9393836528676069],
              140 -> RGBColor[
              0.3280740134091542, 0.4585829537608091, 0.9421255639233401], 85 -> 
             RGBColor[
              0.9196256639800194, 0.938748558156751, 0.9921959108615778], 242 -> 
             RGBColor[
              0.24043240470913427`, 0.3700400800171928, 0.9370036418090929], 
             117 -> RGBColor[
              0.20347429876271564`, 0.33119476738824843`, 0.9348989323500625],
              47 -> RGBColor[
              0.6440597930627512, 0.7218636724671273, 0.9651575191576801], 81 -> 
             RGBColor[
              0.29584127485450173`, 0.42827831566524976`, 0.9401590949937939],
              275 -> RGBColor[
              0.21277857456934213`, 0.34097415118617147`, 0.9354287970928072],
              23 -> RGBColor[
              0.2963741173821658, 0.42883836694599214`, 0.9401894395874745], 
             110 -> RGBColor[
              0.9929459767177286, 0.9913509943397207, 0.7665669512217009], 6 -> 
             RGBColor[
              0.3056730571205615, 0.43861214219787836`, 0.9407190004490276], 
             218 -> RGBColor[
              0.2560427236071457, 0.38644751493038626`, 0.9378926263769374], 
             108 -> RGBColor[
              0.3439204196877902, 0.4723083144158259, 0.943135282918988], 297 -> 
             RGBColor[
              0.7603990286995737, 0.8127487675575523, 0.9767531269139887], 
             157 -> RGBColor[
              0.34598043724619154`, 0.47409259808542004`, 0.9432665454162072],
              270 -> RGBColor[
              0.22825539451058077`, 0.357241270231474, 0.9363101790925575], 
             33 -> RGBColor[
              0.9146626577353835, 0.9347911916944939, 0.9917225348954364], 
             252 -> RGBColor[
              0.30053129972337833`, 0.4332078291671907, 0.9404261849718064], 
             260 -> RGBColor[
              0.8491537797280463, 0.8825561905625664, 0.9854742396306309], 
             159 -> RGBColor[
              0.2473937360801429, 0.37735688066202433`, 0.937400079332305], 
             183 -> RGBColor[
              0.25458949129815345`, 0.38492007563338526`, 0.9378098669468048],
              99 -> RGBColor[
              0.3674883934084197, 0.4927217086918333, 0.9446370133641255], 17 -> 
             RGBColor[
              0.29622239326445615`, 0.42867889527841463`, 0.9401807991234267],
              277 -> RGBColor[
              0.34909505354151776`, 0.4767903221752649, 0.9434650060123984], 
             104 -> RGBColor[
              0.28507184392659923`, 0.4169589609386654, 0.9395457918343952], 
             79 -> RGBColor[
              0.39493077240962093`, 0.5164909180886005, 0.9463856174877392], 
             191 -> RGBColor[
              0.24388899418338073`, 0.37367317471505657`, 0.9372004894660854],
              50 -> RGBColor[
              0.35244904856935166`, 0.4796953840916829, 0.9436787196097506], 
             225 -> RGBColor[
              0.9609628542707439, 0.8799806824768295, 0.3028484896985869], 61 -> 
             RGBColor[
              0.5668393910348319, 0.659224779322463, 0.9590428197448192], 196 -> 
             RGBColor[
              0.2809324202458739, 0.4126081641956031, 0.9393100577795065], 1 -> 
             RGBColor[
              0.41852266255485593`, 0.5369250275695268, 0.9478888718663042], 
             263 -> RGBColor[
              0.26098356523640104`, 0.3916406527501864, 0.9381739999984032], 
             201 -> RGBColor[
              0.32111303850258816`, 0.4525537071655133, 0.9416820167576422], 
             293 -> RGBColor[
              0.20926131084396443`, 0.33727728400339907`, 0.9352284941269724],
              184 -> RGBColor[
              0.23743710807503443`, 0.3668918333419784, 0.9368330640969252], 
             106 -> RGBColor[
              0.6566687686170058, 0.7317139000018745, 0.9664142640033524], 
             206 -> 
             RGBColor[
              0.23667377020378227`, 0.366089516840876, 0.9367895931344146], 
             247 -> RGBColor[
              0.5790882470358998, 0.6691689524288044, 0.9600070945582612], 
             220 -> RGBColor[
              0.25719173910326026`, 0.38765520306859286`, 0.937958061109625], 
             107 -> RGBColor[
              0.8341470216086144, 0.26347454816989946`, 0.18033253249694123`],
              131 -> RGBColor[
              0.324831212684851, 0.4557742027613212, 0.9419189355286837], 127 -> 
             RGBColor[
              0.8327720947194103, 0.2529062576026711, 0.17901590095508144`], 
             210 -> RGBColor[
              0.37855708825470646`, 0.5023088558389079, 0.9453423008120684], 
             181 -> RGBColor[
              0.7138170777657293, 0.7763585934520937, 0.9721102733779844], 
             194 -> RGBColor[
              0.5158331891976378, 0.6178156468678216, 0.9550274246943216], 
             118 -> RGBColor[
              0.17892956896395254`, 0.30539670014399584`, 0.9335011462986966],
              276 -> RGBColor[
              0.23178154572615212`, 0.3609474787299394, 0.9365109881878111], 
             280 -> RGBColor[
              0.2680583595238526, 0.3990767101141639, 0.9385768990668534], 
             189 -> RGBColor[
              0.2318484494359024, 0.3610177987708272, 0.9365147982551062], 
             168 -> RGBColor[
              0.3858730274799788, 0.5086455546860418, 0.9458084659902717], 41 -> 
             RGBColor[
              0.35699077137457635`, 0.483629196111943, 0.9439681141708117], 
             14 -> RGBColor[
              0.8226976998778256, 0.17547004422228246`, 0.1693686490773784], 
             77 -> RGBColor[
              0.2460324096232273, 0.37592604024272347`, 0.9373225538044856], 
             51 -> RGBColor[
              0.993562122803693, 0.9916057865804992, 0.7563558160423134], 179 -> 
             RGBColor[
              0.9936465744084931, 0.9916407094893913, 0.7549562343970292], 
             223 -> RGBColor[
              0.8873547734207121, 0.5813861597120881, 0.22771840056612383`], 
             292 -> RGBColor[
              0.24306150835744214`, 0.3728034346463635, 0.9371533653724538], 
             143 -> RGBColor[
              0.39675004724917656`, 0.5180666825152114, 0.9465015400717941], 
             112 -> RGBColor[
              0.2522134290242518, 0.3824226835324653, 0.9376745537153752], 
             197 -> RGBColor[
              0.2105002400012672, 0.3385794771003698, 0.9352990493096494], 54 -> 
             RGBColor[
              0.4174064139952154, 0.53595818917145, 0.9478177454951437], 71 -> 
             RGBColor[
              0.6295965520330332, 0.7101738697986875, 0.963983293345653], 177 -> 
             RGBColor[
              0.41920763486506846`, 0.5375183161569235, 0.9479325176962138], 
             158 -> RGBColor[
              0.40363205630183896`, 0.524027532856795, 0.9469400556031081], 
             226 -> RGBColor[
              0.178927010221482, 0.30539401074342565`, 0.9335010005820983], 
             203 -> RGBColor[
              0.2595939437592997, 0.3901800724706624, 0.9380948631110431], 
             115 -> RGBColor[
              0.2215913444714862, 0.35023693111520926`, 0.9359306713014096], 
             173 -> RGBColor[
              0.25717362368840185`, 0.38763616261899303`, 0.9379570294635482],
              212 -> RGBColor[
              0.21172080019279638`, 0.3398623632496528, 0.9353685584068999], 
             129 -> RGBColor[
              0.23590943272644063`, 0.36528614969039486`, 0.9367460652458159],
              279 -> RGBColor[
              0.25879261498995565`, 0.3893378251269034, 0.9380492286230886], 
             26 -> RGBColor[
              0.9858349896506369, 0.9884104184434465, 0.8844144095680297], 40 -> 
             RGBColor[
              0.2372124705557414, 0.3666557250663601, 0.9368202713225229], 
             146 -> RGBColor[
              0.23045057360750168`, 0.3595485426447314, 0.9364351912946507], 
             192 -> RGBColor[
              0.8649861375675162, 0.47981540863036076`, 0.20905346250477896`],
              300 -> RGBColor[
              0.2558608387541249, 0.3862563424176957, 0.9378822683036323], 
             221 -> RGBColor[
              0.29461336050310216`, 0.4269876998276622, 0.9400891670880182], 
             62 -> RGBColor[
              0.9948487335515908, 0.9913902868768101, 0.6806946209012268], 
             286 -> RGBColor[
              0.5590358689967736, 0.6528895285873056, 0.9584284979047402], 
             152 -> RGBColor[
              0.25329610735962166`, 0.38356064710871024`, 0.9377362106448954],
              64 -> RGBColor[
              0.23365539790008147`, 0.3629170161738291, 0.9366177012970005], 
             37 -> RGBColor[
              0.6807027709206555, 0.7504894452666685, 0.968809748742459], 148 -> 
             RGBColor[
              0.23881348570074337`, 0.36833849349398035`, 0.9369114467665411],
              261 -> RGBColor[
              0.4006413843936947, 0.5214371631655013, 0.9467494926336685], 15 -> 
             RGBColor[
              0.23892277989457777`, 0.36845336862135236`, 0.9369176709091936],
              136 -> RGBColor[
              0.9929076697798414, 0.9872385477406899, 0.46942180820333496`], 
             198 -> RGBColor[
              0.4642553566460736, 0.5759424388475844, 0.9509670287800365], 63 -> 
             RGBColor[
              0.32451328924336914`, 0.4554988334556064, 0.9418986777281211], 
             171 -> RGBColor[
              0.4183533072547869, 0.5367783405206518, 0.9478780806963388], 59 -> 
             RGBColor[
              0.8328101555207211, 0.25319880959989605`, 0.17905234802140027`],
              229 -> RGBColor[
              0.34638875058307517`, 0.4744462585754037, 0.9432925627809762], 
             102 -> RGBColor[
              0.38532279281260967`, 0.5081689690727651, 0.9457734055238204], 
             299 -> RGBColor[
              0.9944845479757449, 0.9919872330943883, 0.7410688437815899], 
             128 -> RGBColor[
              0.23926061251081787`, 0.3688084521208458, 0.93693690997691], 12 -> 
             RGBColor[
              0.20154157699751735`, 0.32916335427138743`, 0.93478886670474], 
             222 -> RGBColor[
              0.43613267935432526`, 0.5521779390160471, 0.94901096656484], 92 -> 
             RGBColor[
              0.261097249315751, 0.3917601419255701, 0.9381804741385418], 271 -> 
             RGBColor[
              0.9774649456708626, 0.9356461116447503, 0.3669559986295733], 
             132 -> RGBColor[
              0.2067120462521808, 0.3345978452847238, 0.9350833172797693], 80 -> 
             RGBColor[
              0.26782978190622225`, 0.39883646054537636`, 0.9385638819096797],
              244 -> RGBColor[
              0.24251120685435607`, 0.3722250328754895, 0.9371220265159511], 
             150 -> RGBColor[
              0.9620063021321176, 0.9711849428558795, 0.9491975995336027], 
             125 -> RGBColor[
              0.9926251659969516, 0.9866343007146026, 0.4386730148470409], 
             133 -> RGBColor[
              0.35014705105926486`, 0.47770150955020474`, 0.9435320383639844],
              258 -> RGBColor[
              0.9617670348256762, 0.9710064976904998, 0.9496026166724999], 
             255 -> RGBColor[
              0.9589543367125869, 0.8732054811308165, 0.29504577826186157`], 
             176 -> RGBColor[
              0.1789518783186532, 0.305420148690281, 0.9335024167834431], 230 -> 
             RGBColor[
              0.24935218422087857`, 0.37941533383072157`, 0.9375116100566555],
              274 -> 
             RGBColor[
              0.9645754531953188, 0.8921668269279859, 0.3168827543384975], 87 -> 
             RGBColor[
              0.27610729667649436`, 0.4075366533936812, 0.9390352741303609], 
             130 -> RGBColor[0.178927, 0.305394, 0.933501], 35 -> 
             RGBColor[
              0.2262311772849768, 0.3551136895845794, 0.9361949029161204], 31 -> 
             RGBColor[
              0.6188367246795077, 0.7014385572283971, 0.9631362403218372], 18 -> 
             RGBColor[
              0.9464007204285422, 0.9595463255731478, 0.9756137787701872], 24 -> 
             RGBColor[
              0.9556367854010767, 0.9664345677069957, 0.9599795299232305], 
             151 -> RGBColor[
              0.443273542823118, 0.5583629960424816, 0.9494659760706539], 137 -> 
             RGBColor[
              0.8455662065044656, 0.351247407198139, 0.19126755684933291`], 
             296 -> RGBColor[
              0.6962355794932261, 0.7626237933772783, 0.9703579139386239], 
             266 -> RGBColor[
              0.24763395401992835`, 0.3776093649474359, 0.9374137593886052], 
             283 -> RGBColor[
              0.6187231293682252, 0.7013463354372874, 0.9631272976828197], 
             284 -> RGBColor[
              0.25564421936180226`, 0.3860286617019018, 0.9378699321496993], 
             238 -> RGBColor[
              0.2785145923880161, 0.4100668738178543, 0.9391723660598572], 72 -> 
             RGBColor[
              0.6518075404484566, 0.7279162716099014, 0.9659297422102715], 
             288 -> RGBColor[
              0.8619011142240809, 0.46580703815332913`, 0.20647924340617463`],
              172 -> RGBColor[
              0.26949540103514497`, 0.4005871318562264, 0.9386587364550091], 
             243 -> RGBColor[
              0.21816661637866602`, 0.3466373247493527, 0.9357356381029547], 
             88 -> RGBColor[
              0.5042211596463271, 0.6083884781620977, 0.9541132831917766], 
             273 -> RGBColor[
              0.6178350891255162, 0.7006253843624993, 0.9630573879019151], 
             202 -> RGBColor[
              0.22812105044609293`, 0.3571000661017916, 0.9363025283968291], 
             98 -> RGBColor[
              0.4228071955400177, 0.5406360746943846, 0.948161878519455], 30 -> 
             RGBColor[
              0.46219840465570133`, 0.574272512557169, 0.9508050979844909], 
             116 -> RGBColor[
              0.3224078413052081, 0.4536752002744616, 0.941764520447276], 240 -> 
             RGBColor[
              0.9949335587465892, 0.9915717193917691, 0.6899273198963884], 73 -> 
             RGBColor[
              0.3290101239879992, 0.459393765693919, 0.9421852120616541], 29 -> 
             RGBColor[
              0.24282295558358705`, 0.3725527005559224, 0.9371397801448899], 
             75 -> RGBColor[
              0.7305123993392341, 0.7894011055544591, 0.9737743070057807], 
             200 -> RGBColor[
              0.8859959599380017, 0.5752161050460523, 0.226584573288584], 156 -> 
             RGBColor[
              0.2276990046313701, 0.35665646919126776`, 0.9362784935120415], 
             25 -> RGBColor[
              0.2518103509231395, 0.3819990228915686, 0.9376515990138174], 38 -> 
             RGBColor[
              0.4179442959916355, 0.5364240755220139, 0.9478520188603253], 3 -> 
             RGBColor[
              0.3773249031069595, 0.5012415989953558, 0.9452637870640326], 57 -> 
             RGBColor[
              0.24705297562595502`, 0.37699871981921224`, 0.9373806735285489],
              227 -> RGBColor[
              0.25976518882652405`, 0.3903600618938796, 0.9381046152642871], 
             39 -> RGBColor[
              0.8675327116732591, 0.4913788068770457, 0.21117838636085415`], 
             109 -> RGBColor[
              0.9211686584075277, 0.939978900029778, 0.992343083047521], 256 -> 
             RGBColor[
              0.9952479751456992, 0.992244224277091, 0.7241496045864151], 287 -> 
             RGBColor[
              0.9409750107809423, 0.8036926171977683, 0.27136531206102255`], 
             239 -> RGBColor[
              0.4111342730563943, 0.530525575937213, 0.9474180902207585], 285 -> 
             RGBColor[0.382771346863294, 0.50595903483087, 0.945610829644085],
              216 -> RGBColor[
              0.2588379470720171, 0.38938547201937, 0.9380518102180992], 21 -> 
             RGBColor[
              0.38345468665213356`, 0.5065509094103063, 0.9456543714511763], 
             175 -> RGBColor[
              0.2945111830148827, 0.42688030480911665`, 0.9400833482312222], 
             7 -> RGBColor[
              0.394746751143397, 0.516331528116975, 0.946373891815379], 13 -> 
             RGBColor[
              0.30612838775897044`, 0.4390907235684761, 0.9407449308552837], 
             294 -> RGBColor[
              0.209897553009386, 0.33794601485934034`, 0.9352647271770572], 
             193 -> RGBColor[
              0.39949775357450523`, 0.5204466076304757, 0.9466766214891428], 
             60 -> RGBColor[
              0.9260824493199337, 0.7446485736567867, 0.2593824075361489], 65 -> 
             RGBColor[
              0.28791659856684826`, 0.41994897843342893`, 0.9397077964027201],
              69 -> RGBColor[
              0.9930380091079225, 0.9875173303841278, 0.48360843970387296`], 
             217 -> RGBColor[
              0.80703569950506, 0.8491816892426243, 0.9814014344154122], 214 -> 
             RGBColor[
              0.21288213693655111`, 0.34108300180034146`, 0.9354346948164131],
              170 -> RGBColor[
              0.8218934398484693, 0.16928814920765783`, 0.168598488764985], 
             74 -> RGBColor[
              0.6382140736915616, 0.7171699620960075, 0.9646616962176343], 
             246 -> RGBColor[
              0.5988679170367666, 0.6852269795994871, 0.961564222636048], 264 -> 
             RGBColor[
              0.2946613034028385, 0.4270380908550406, 0.940091897365233], 278 -> 
             RGBColor[
              0.6029315110482949, 0.6885259882808699, 0.9618841236420709], 45 -> 
             RGBColor[
              0.8578237913971699, 0.4454645759914146, 0.2030054339855487], 
             237 -> RGBColor[
              0.638779311088947, 0.7176288472788594, 0.9647061937760893], 228 -> 
             RGBColor[
              0.8163432429187892, 0.8564528128973794, 0.9823291233589543], 
             180 -> RGBColor[
              0.23402613491596813`, 0.3633066842836104, 0.936638814221599], 
             53 -> RGBColor[
              0.8317291195209172, 0.2448894931924079, 0.17801714672713256`], 
             48 -> RGBColor[
              0.4136829046946342, 0.5327330725643056, 0.9475804867750808], 5 -> 
             RGBColor[
              0.220958970004222, 0.34957226545525755`, 0.9358946585110132], 
             101 -> RGBColor[
              0.5465902564750337, 0.6427856196737024, 0.9574487336972479], 
             267 -> RGBColor[
              0.467847246129772, 0.578858496543228, 0.9512497954777179], 120 -> 
             RGBColor[
              0.18991457468017128`, 0.31694263764133146`, 0.9341267261233757],
              147 -> RGBColor[
              0.22619261942112945`, 0.35507316282496604`, 0.9361927071028155],
              89 -> RGBColor[
              0.27813245697413447`, 0.40966522526908, 0.9391506040133554], 43 -> 
             RGBColor[
              0.322173741643116, 0.45347243491334854`, 0.9417496038238137], 
             199 -> RGBColor[0.178927, 0.305394, 0.933501], 268 -> 
             RGBColor[
              0.2625163578880115, 0.3932517150116962, 0.938261290272349], 169 -> 
             RGBColor[
              0.2930250557635406, 0.42531829084204614`, 0.9399987154827865], 
             20 -> 
             RGBColor[
              0.865905855945801, 0.8959138414156087, 0.9870720676150353], 4 -> 
             RGBColor[
              0.5396207399250182, 0.6371274521652572, 0.9569000678242504], 
             167 -> RGBColor[
              0.7539264605068086, 0.8076923480920241, 0.9761080018061227], 
             142 -> RGBColor[
              0.6590237495828186, 0.7335536290308857, 0.9666489864974762], 16 -> 
             RGBColor[
              0.9934703621130101, 0.9884420897444159, 0.5306673961342021], 
             281 -> RGBColor[
              0.8360763947567734, 0.2783045556433535, 0.18218010240253352`], 
             289 -> RGBColor[
              0.2909832679823188, 0.4231722424271597, 0.9398824386892002], 
             178 -> RGBColor[
              0.27705635157752495`, 0.4085341702682206, 0.9390893214029737], 
             58 -> RGBColor[
              0.5489231824340144, 0.6446795940643196, 0.9576323901745283], 
             186 -> RGBColor[
              0.2299691131158081, 0.3590424971416032, 0.9364077728319058], 
             122 -> RGBColor[
              0.6241927467762723, 0.7057868172525964, 0.96355788600105], 249 -> 
             RGBColor[
              0.8185799679311427, 0.1438193520784336, 0.16542550431492184`], 
             113 -> RGBColor[
              0.9594092884334661, 0.9692480942916449, 0.9535936663157671], 52 -> 
             RGBColor[
              0.8177080186927622, 0.13711716814164848`, 0.16459052473952288`],
              187 -> RGBColor[
              0.3639294956023307, 0.48963917028760373`, 0.9444102435429313], 
             259 -> RGBColor[
              0.46426084954242974`, 0.5759468982282985, 0.9509674612009588], 
             42 -> RGBColor[
              0.2544378422070241, 0.3847606828235006, 0.9378012307554097], 
             134 -> RGBColor[
              0.27400077350385804`, 0.40532256397795713`, 0.9389153107520011],
              248 -> RGBColor[
              0.20835094833068457`, 0.3363204352816248, 0.9351766503286018], 
             174 -> RGBColor[
              0.3923234880848031, 0.5142326194523638, 0.9462194836360928], 
             215 -> RGBColor[
              0.9951032288756773, 0.9922430735458843, 0.7308157001748675], 83 -> 
             RGBColor[
              0.21628848662157388`, 0.34466329129434453`, 0.9356286813917323],
              95 -> RGBColor[
              0.48864650773140994`, 0.5957442741074949, 0.9528871895412045], 
             166 -> RGBColor[
              0.9927232541779302, 0.9868441014154793, 0.4493493080164732], 
             233 -> 
             RGBColor[
              0.9940884990666902, 0.9897642221851048, 0.5979477888431959], 
             295 -> RGBColor[
              0.8372847792405768, 0.8730921717492939, 0.9843421637685542], 
             141 -> RGBColor[
              0.8990024464838272, 0.6342755227085348, 0.23743750448057996`], 
             205 -> RGBColor[
              0.5294468131435418, 0.6288678000738763, 0.9560991390396908], 
             224 -> RGBColor[
              0.9695247134417432, 0.9088618438807439, 0.33610969580648287`], 
             231 -> RGBColor[
              0.44511934956958094`, 0.5599617410733233, 0.9495835892443556], 
             68 -> RGBColor[
              0.8743662175245639, 0.5224081609419808, 0.2168804311477391], 10 -> 
             RGBColor[
              0.2114327980870659, 0.3395596547761419, 0.9353521571130395], 
             250 -> RGBColor[
              0.22258326386374316`, 0.3512795012877932, 0.9359871596433854], 
             282 -> RGBColor[
              0.9636570397640628, 0.9724160602789496, 0.9464033313040466], 
             232 -> RGBColor[
              0.9940965401504851, 0.9897814212502639, 0.5988230111904562], 
             253 -> RGBColor[
              0.29672537087035056`, 0.42920755663283183`, 0.9402094429539937],
              55 -> RGBColor[
              0.2766948027559306, 0.4081541595332056, 0.9390687317324474], 91 -> 
             RGBColor[
              0.2726124428491967, 0.4038633404346605, 0.9388362473750692], 
             105 -> RGBColor[
              0.28917033221241484`, 0.4212667319862237, 0.9397791946791023], 
             36 -> RGBColor[
              0.7595712694087771, 0.8121021157083784, 0.9766706236037325], 
             123 -> RGBColor[
              0.43622064479054923`, 0.5522541302556329, 0.9490165716446514], 
             94 -> RGBColor[
              0.8619491220774967, 0.8927588492317026, 0.9866946708064583], 96 -> 
             RGBColor[
              0.40546591079173033`, 0.5256159254437323, 0.9470569071895901], 
             2 -> RGBColor[
              0.2307572995292167, 0.3598709310360006, 0.936452658882132], 262 -> 
             RGBColor[
              0.9939797374120591, 0.9895315920033393, 0.5861097539357399], 
             272 -> RGBColor[
              0.22328031209840418`, 0.35201214317783264`, 0.936026855509159], 
             97 -> RGBColor[
              0.2574804300414378, 0.3879586355486801, 0.9379745016314742], 
             209 -> RGBColor[
              0.2651563206276758, 0.3960264832343887, 0.938411632244898], 66 -> 
             RGBColor[
              0.9464558742569554, 0.9595874592080723, 0.9755204177251058], 
             139 -> RGBColor[
              0.25547870703592473`, 0.385854697753317, 0.9378605064675941], 
             56 -> RGBColor[
              0.5476923991281734, 0.6436803887304818, 0.9575354984041846], 
             144 -> RGBColor[
              0.3157094904678022, 0.4478734254480028, 0.9413377074550355], 
             298 -> RGBColor[
              0.28525208052382683`, 0.41714840103001194`, 0.9395560560419711],
              204 -> RGBColor[
              0.23088271225706164`, 0.36000274776459185`, 0.9364598009514513],
              207 -> RGBColor[
              0.7455882739599426, 0.8011784933890475, 0.9752769292959146], 
             149 -> RGBColor[
              0.2939489691399074, 0.4262893823800991, 0.9400513309827632], 
             219 -> RGBColor[
              0.27423499655804673`, 0.4055687472585089, 0.9389286494084351], 
             9 -> RGBColor[
              0.5168296547678491, 0.6186246225079816, 0.9551058701141822], 11 -> 
             RGBColor[
              0.34350580070653963`, 0.47194919229362253`, 0.9431088637641358],
              44 -> RGBColor[
              0.9650552642631052, 0.8937853423246256, 0.3187467297321304], 
             153 -> RGBColor[
              0.27348165172589245`, 0.40477693407509363`, 0.9388857475347178],
              32 -> RGBColor[
              0.2562574704790552, 0.38667322750850125`, 0.9379048558936031], 
             162 -> RGBColor[
              0.2845267439871254, 0.4163860263409461, 0.9395147491992453], 90 -> 
             RGBColor[
              0.4035464690461924, 0.5239534014776945, 0.9469346020588602], 8 -> 
             RGBColor[
              0.6518492866916434, 0.7279488840923621, 0.9659339030856515], 
             163 -> RGBColor[
              0.2413593551772921, 0.3710143637312809, 0.9370564302669542], 49 -> 
             RGBColor[
              0.23655451757503262`, 0.36596417476700677`, 0.9367828018736257],
              76 -> RGBColor[
              0.29429562032882867`, 0.4266537347586102, 0.9400710722551477], 
             82 -> RGBColor[
              0.9950766756732579, 0.9918778320265724, 0.7055047141489801], 67 -> 
             RGBColor[
              0.9123183312358003, 0.932921889378774, 0.9914989309411012], 211 -> 
             RGBColor[
              0.24235927283690456`, 0.3720653405899749, 
               0.9371133740984234]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9mHk4FFzYxsmSfR/LzGBWM2NmbHmlLHNH8aZCu0SWIkQLqbSgomQtVNoX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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 9}], {
             RGBColor[
             0.46767615866135254`, 0.5777748250387542, 0.9514973709902432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 11}], {
             RGBColor[
             0.3810142316306978, 0.5044371099315746, 0.9454988678152201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 20}], {
             RGBColor[
             0.6422142592503285, 0.7164194344925677, 0.9674804697406698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 37}], {
             RGBColor[
             0.5496127167377557, 0.6437072364180976, 0.9583493103043816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 43}], {
             RGBColor[
             0.370348202098986, 0.49519873124143765`, 0.944819237845059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 75}], {
             RGBColor[
             0.5745175309470449, 0.663163066561993, 0.9608315894360424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 102}], {
             RGBColor[
             0.40192272768373283`, 0.5225469983211459, 0.9468311386950623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 142}], {
             RGBColor[
             0.5387732060688373, 0.6352393283002062, 0.9572689291818902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 143}], {
             RGBColor[
             0.4076363549020162, 0.5274958550423691, 0.9471952059690492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 174}], {
             RGBColor[
             0.4054230753198295, 0.5255788235109453, 0.9470541777511985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 185}], {
             RGBColor[
             0.4932964811819127, 0.5985745570433215, 0.9535142966293955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 237}], {
             RGBColor[
             0.5286509868219015, 0.6272769374241931, 0.9562975328211968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 239}], {
             RGBColor[
             0.4148284678056251, 0.5337253017533699, 0.9476534810435313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 283}], {
             RGBColor[
             0.5186228959615405, 0.619135681503407, 0.955508084774562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 295}], {
             RGBColor[
             0.6279037208977163, 0.7050085996594103, 0.9661155178174292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 297}], {
             RGBColor[
             0.5894608456272148, 0.6748368975635395, 0.9623209993901465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 32}], {
             RGBColor[
             0.24350738500413596`, 0.3732720792722509, 0.9371787573878676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 83}], {
             RGBColor[
             0.2235228930753953, 0.35226711116517256`, 0.9360406701369322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 155}], {
             RGBColor[
             0.22153004206728566`, 0.3501724984015976, 0.9359271802201792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 156}], {
             RGBColor[
             0.2292281520802934, 0.3582637001136342, 0.9363655761970868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 178}], {
             RGBColor[
             0.25390682555337085`, 0.3842025506521106, 0.9377709901425528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 184}], {
             RGBColor[
             0.23409720380212556`, 0.3633813821889895, 0.9366428614895286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 202}], {
             RGBColor[
             0.22943917498765481`, 0.3584854985688961, 0.9363775936394806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 208}], {
             RGBColor[
             0.2583585282715436, 0.3888815724631647, 0.9380245080266488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 214}], {
             RGBColor[
             0.2218197182328839, 0.35047696641817105`, 0.9359436768492726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 268}], {
             RGBColor[
             0.2466368287086141, 0.37656132302384837`, 0.9373569745772405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 275}], {
             RGBColor[
             0.2217679370492794, 0.35042254111108606`, 0.9359407279874696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 17}], {
             RGBColor[
             0.3367736481857078, 0.4649602471368852, 0.9427222930937296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 30}], {
             RGBColor[
             0.4197616538813304, 0.5377570557762624, 0.9480344425242617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 38}], {
             RGBColor[
             0.3976345995492975, 0.5188328372586848, 0.9465579029621789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 55}], {
             RGBColor[
             0.327009852931445, 0.45469787926428074`, 0.9421662593982401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 74}], {
             RGBColor[
             0.5077694883992605, 0.6092057805456816, 0.9549627416408335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 90}], {
             RGBColor[
             0.39043568607657597`, 0.5125975002365252, 0.9460991945614463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[
             0.40677277394875433`, 0.5267478646254944, 0.9471401793543419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 144}], {
             RGBColor[
             0.34651719678738085`, 0.4745575122216793, 0.9433007472595341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 157}], {
             RGBColor[
             0.36165267017657554`, 0.4876670985403879, 0.9442651662401199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 229}], {
             RGBColor[
             0.3618568268450173, 0.48784392878537974`, 0.9442781749225044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 252}], {
             RGBColor[
             0.33892810141516894`, 0.46722471408127325`, 0.9428449860179196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 257}], {
             RGBColor[
             0.38431511212659675`, 0.5072961667100446, 0.9457091970015647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 259}], {
             RGBColor[
             0.42079287632469464`, 0.5385942486118271, 0.9481156241324957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 26}], {
             RGBColor[
             0.7627278647878275, 0.8127689353043519, 0.92065723869614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 39}], {
             RGBColor[
             0.7035767257991387, 0.5642531295211515, 0.5840392270925523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 52}], {
             RGBColor[
             0.6786643793088902, 0.3871223101534529, 0.5607452962818866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 78}], {
             RGBColor[
             0.3598305300482983, 0.47184581112708096`, 0.9452322348805061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 82}], {
             RGBColor[
             0.7673487077991381, 0.8145026420959148, 0.8312023909866153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 107}], {
             RGBColor[
             0.6868838807668163, 0.45030100016757835`, 0.5686163001605958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 130}], {
             RGBColor[
             0.3592738699625091, 0.4712607260826286, 0.9452005339121252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 193}], {
             RGBColor[
             0.46955924674976174`, 0.5787870298978665, 0.9517883446566966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 199}], {
             RGBColor[
             0.3592738699625091, 0.4712607260826286, 0.9452005339121252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 220}], {
             RGBColor[
             0.3984062395141392, 0.5123913276169251, 0.9474290644669376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.35927387507325015`, 0.47126073145434144`, 0.9452005342031744]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 228}], {
             RGBColor[
             0.6779819914219037, 0.7467901325313183, 0.9696145955916023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 236}], {
             RGBColor[
             0.5814156950940945, 0.671058479612787, 0.9601903197951254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 266}], {
             RGBColor[
             0.3936273469724733, 0.5073684085563466, 0.9471569136064277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 281}], {
             RGBColor[
             0.6878485673408958, 0.45771600390430534`, 0.5695400851133919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.23189096279390453`, 0.36106248300558996`, 0.9365172193279515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[
             0.23349568981372465`, 0.3627491528489905, 0.9366086061577494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 191}], {
             RGBColor[
             0.23242398209380136`, 0.36162272008515706`, 0.9365475739885493]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 248}], {
             RGBColor[
             0.21465495916745328`, 0.3429463503684412, 0.9355356544198075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 21}], {
             RGBColor[
             0.3445638718863475, 0.47258152580409235`, 0.9431866859501019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 34}], {
             RGBColor[
             0.31658612534963915`, 0.4483486079564237, 0.9414039686805327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 46}], {
             RGBColor[
             0.29890559173213627`, 0.4314991069925552, 0.9403336033067247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 50}], {
             RGBColor[
             0.32906105284495657`, 0.4591537631447806, 0.9421988600293891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 101}], {
             RGBColor[
             0.4261316567977976, 0.5406988809357904, 0.9490838670731377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 108}], {
             RGBColor[
             0.32479673840417583`, 0.4554602283068521, 0.9419271416840078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 114}], {
             RGBColor[
             0.30504212315896806`, 0.43794899060072, 0.940683069693298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 145}], {
             RGBColor[
             0.2874384541046572, 0.41944641828755624`, 0.9396805667829495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 169}], {
             RGBColor[
             0.299349056442051, 0.4319652165199622, 0.940358857965907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 187}], {
             RGBColor[
             0.3348012763614461, 0.46412565624274105`, 0.9425646219959795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 205}], {
             RGBColor[
             0.41755993513205164`, 0.5337399711358773, 0.9484090697443592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 213}], {
             RGBColor[
             0.3667758904705204, 0.4918204598931879, 0.9446020161329686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 219}], {
             RGBColor[
             0.2899540268393041, 0.4220904447281936, 0.9398238249287314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 221}], {
             RGBColor[
             0.3001432088118318, 0.4327999210127703, 0.9404040837685228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 231}], {
             RGBColor[
             0.3753962033450712, 0.49928694163560083`, 0.9451512948466916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 264}], {
             RGBColor[
             0.3001671802617, 0.4328251165264595, 0.9404054489071303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 9}], {
             RGBColor[
             0.45578820295562306`, 0.5674780753124783, 0.9507398809647807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 11}], {
             RGBColor[
             0.36912627592496833`, 0.4941403602052988, 0.9447413777897574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 43}], {
             RGBColor[
             0.3584602463932565, 0.4849019815151618, 0.9440617478195963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.40607658256930623`, 0.5261448586442126, 0.9470958186552614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 63}], {
             RGBColor[
             0.3596300201933831, 0.4859151807862907, 0.94413628477175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 106}], {
             RGBColor[
             0.5257077598802015, 0.6240227140594248, 0.9563940779093657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 131}], {
             RGBColor[
             0.359788981914124, 0.4860528654391481, 0.9441464136720313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 143}], {
             RGBColor[
             0.3957483991962868, 0.5171991053160931, 0.9464377159435866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 151}], {
             RGBColor[
             0.4190101469832575, 0.5373472620797284, 0.9479199339430164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 167}], {
             RGBColor[
             0.5743366058251028, 0.6620119381044995, 0.9612409468107508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 174}], {
             RGBColor[
             0.39353511961410004`, 0.5152820737846694, 0.9462966877257359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 185}], {
             RGBColor[
             0.4814085254761833, 0.5882778073170456, 0.9527568066039329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[
             0.4552899701705174, 0.5670735874923983, 0.9507006582548503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 283}], {
             RGBColor[
             0.5067349402558111, 0.6088389317771312, 0.9547505947490993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 297}], {
             RGBColor[
             0.5775728899214854, 0.6645401478372637, 0.9615635093646839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 22}], {
             RGBColor[
             0.7346141321851996, 0.7926054104280515, 0.9741831294029938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 47}], {
             RGBColor[
             0.6479545398771973, 0.7249062782797447, 0.9655457111216659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 61}], {
             RGBColor[
             0.6093443388632377, 0.6935868317074125, 0.9624883614152353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 72}], {
             RGBColor[
             0.6518284135700501, 0.7279325778511317, 0.9659318226479615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 177}], {
             RGBColor[
             0.5355284607783559, 0.6327336001246429, 0.9569332103909327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 217}], {
             RGBColor[
             0.7294424930983517, 0.7885652866674933, 0.9736676687505319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 247}], {
             RGBColor[
             0.6154687668637716, 0.6985589182605833, 0.9629704988219563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 267}], {
             RGBColor[
             0.5598482664107077, 0.6534036903177951, 0.9585918492816847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 271}], {
             RGBColor[
             0.814657116181253, 0.8317974978685563, 0.6664449508576125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 273}], {
             RGBColor[
             0.6348421879085798, 0.7142871342274307, 0.9644956454937833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 285}], {
             RGBColor[
             0.5173103167774687, 0.616953959461616, 0.9557723663648683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.43016772773719436`, 0.545286907400802, 0.949107366939159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 20}], {
             RGBColor[
             0.6913677553568252, 0.7572692319617951, 0.9710889688646087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 37}], {
             RGBColor[
             0.5987662128442524, 0.684557033887325, 0.9619578094283205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 43}], {
             RGBColor[
             0.41950169820548255`, 0.5360485287106651, 0.948427736968998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 63}], {
             RGBColor[
             0.42067147200560917`, 0.537061727981794, 0.9485022739211517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 75}], {
             RGBColor[
             0.6236710270535416, 0.7040128640312203, 0.9644400885599815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.5867492116924276, 0.675169261254928, 0.9607600670587673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 131}], {
             RGBColor[
             0.4208304337263501, 0.5371994126346513, 0.9485124028214329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 142}], {
             RGBColor[
             0.5879267021753338, 0.6760891257694337, 0.9608774283058292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 143}], {
             RGBColor[
             0.4567898510085129, 0.5683456525115964, 0.9508037050929882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 167}], {
             RGBColor[
             0.6353780576373289, 0.7131584853000028, 0.9656069359601525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 174}], {
             RGBColor[
             0.4545765714263261, 0.5664286209801727, 0.9506626768751375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 185}], {
             RGBColor[
             0.5424499772884093, 0.6394243545125489, 0.9571227957533345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 237}], {
             RGBColor[
             0.5778044829283981, 0.6681267348934206, 0.9599060319451358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 239}], {
             RGBColor[
             0.4639819639121217, 0.5745750992225973, 0.9512619801674704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 282}], {
             RGBColor[
             0.740243347265956, 0.7955203413934655, 0.9507546007091144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 283}], {
             RGBColor[
             0.5677763920680372, 0.6599854789726345, 0.959116583898501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 295}], {
             RGBColor[
             0.677057217004213, 0.7458583971286377, 0.9697240169413682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 297}], {
             RGBColor[
             0.6386143417337113, 0.7156866950327669, 0.9659294985140855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 117}], {
             RGBColor[
             0.20745354842489078`, 0.3353772110821952, 0.935125544731551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.22367111540675327`, 0.3524229022332684, 0.9360491111794278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 161}], {
             RGBColor[
             0.21385191803304957`, 0.3421023032204342, 0.935489922415196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 265}], {
             RGBColor[
             0.21694931138635237`, 0.3453578600208368, 0.9356663143844839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 269}], {
             RGBColor[
             0.2192290472618576, 0.3477540069695957, 0.9357961419700269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 43}], {
             RGBColor[
             0.3328397711748278, 0.46271081360348554`, 0.9424292337939748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 63}], {
             RGBColor[
             0.3340095449749544, 0.46372401287461446`, 0.9425037707461285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 131}], {
             RGBColor[
             0.3341685066956953, 0.46386169752747186`, 0.9425138996464097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 139}], {
             RGBColor[
             0.2994922538712322, 0.4289019450234698, 0.940484685115865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 143}], {
             RGBColor[
             0.3701279239778581, 0.49500793740441695`, 0.9448052019179649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 172}], {
             RGBColor[
             0.3065006008708423, 0.43626816207492447`, 0.9408838001095725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 174}], {
             RGBColor[
             0.36791464439567134`, 0.49309090587299315`, 0.9446641737001142]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 183}], {
             RGBColor[
             0.29904764600234657`, 0.4284346339635039, 0.9404593653554703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 185}], {
             RGBColor[
             0.4557880502577546, 0.5660866394053694, 0.9511242925783112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 283}], {
             RGBColor[
             0.4811144650373824, 0.586647763865455, 0.9531180807234778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 248}], {
             RGBColor[
             0.20494626266410096`, 0.3327418947765061, 0.9349827585166709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 58}], {
             RGBColor[
             0.4275257850964924, 0.5418851588163979, 0.949188660514906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 73}], {
             RGBColor[
             0.31756925587348483`, 0.44924224463119755`, 0.9414650714584689]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 95}], {
             RGBColor[
             0.3973874477451902, 0.5174174988379855, 0.946816060198244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 96}], {
             RGBColor[
             0.3557971492753504, 0.4823533245061042, 0.9439009190224369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 105}], {
             RGBColor[
             0.29764935998569264`, 0.4301787277773499, 0.9402620627671929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[
             0.3171012005840623, 0.44883683866464263`, 0.941435247389312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 149}], {
             RGBColor[
             0.30003867844943893`, 0.43269005297428764`, 0.9403981309190235]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 171}], {
             RGBColor[
             0.3622408475068787, 0.48793453204456394`, 0.9443115057758112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 245}], {
             RGBColor[
             0.36526550488349396`, 0.49055433824048805`, 0.9445042342692497]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 289}], {
             RGBColor[
             0.2985558278706446, 0.4311314829978179, 0.940313684772242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 298}], {
             RGBColor[
             0.2956902341413986, 0.428119562299244, 0.9401504934486273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 69}], {
             RGBColor[
             0.907867854492874, 0.581493687303205, 0.3264885443906257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 113}], {
             RGBColor[
             0.8910534941556458, 0.5723590692569638, 0.5614811576965728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 135}], {
             RGBColor[
             0.9063967184206538, 0.582821195587901, 0.4915857246054881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 224}], {
             RGBColor[
             0.8961112066597844, 0.5421659440515132, 0.2527391724419306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 249}], {
             RGBColor[
             0.8206388339044841, 0.15964469815035803`, 0.16739707669615012`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 254}], {
             RGBColor[
             0.8570098056114457, 0.3874350253501294, 0.200198663385516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 288}], {
             RGBColor[
             0.8422994070509533, 0.32063854118780577`, 0.1879239462417765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 19}], {
             RGBColor[
             0.265094966907718, 0.3959619965846625, 0.938408138241311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 49}], {
             RGBColor[
             0.2377386487348052, 0.36720877169417954`, 0.9368502363914097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 57}], {
             RGBColor[
             0.2429878777602664, 0.3727260442202823, 0.9371491722188713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 89}], {
             RGBColor[
             0.2585276184343561, 0.3890592969452162, 0.9380341374612745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 111}], {
             RGBColor[
             0.2409685800879815, 0.3706036343358437, 0.9370341762037178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.2455681044594148, 0.3754380260769088, 0.9372961123122845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 115}], {
             RGBColor[
             0.230257062183032, 0.3593451498682808, 0.9364241711053016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 146}], {
             RGBColor[
             0.2346866767510397, 0.3640009556330419, 0.9366764311019222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 175}], {
             RGBColor[
             0.2667169814547302, 0.3976668367152345, 0.9385005095702079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 212}], {
             RGBColor[
             0.22532179004368708`, 0.3541578659355026, 0.9361431146580468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 242}], {
             RGBColor[
             0.23967759230185604`, 0.3692467243192726, 0.9369606563591433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 243}], {
             RGBColor[
             0.2285446981366219, 0.35754534668535254`, 0.9363266545060742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 280}], {
             RGBColor[
             0.2534905697092152, 0.38376503936775813`, 0.9377472849880235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 294}], {
             RGBColor[
             0.2244101664519819, 0.3531996917403464, 0.9360911990431254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.9540665099241967, 0.9616166407194549, 0.7611949655148192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 44}], {
             RGBColor[
             0.9792628131880576, 0.9411137160345208, 0.4247070629331663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 53}], {
             RGBColor[
             0.9125997408169637, 0.6166657914684119, 0.3543422714306673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 59}], {
             RGBColor[
             0.9131402588168656, 0.620820449672156, 0.3548598720778012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 94}], {
             RGBColor[
             0.9277097420952534, 0.9406004694880592, 0.7586810334703302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 124}], {
             RGBColor[
             0.9705820834138202, 0.9744763977304486, 0.7520461602492186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 125}], {
             RGBColor[
             0.9930477640549809, 0.9875381952295093, 0.4846702054906215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 150}], {
             RGBColor[
             0.9777383321225639, 0.9798135163001478, 0.7399324978339024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 170}], {
             RGBColor[
             0.9076819009807398, 0.5788651194760369, 0.34963294244959353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 192}], {
             RGBColor[
             0.9292282498402631, 0.7341287491873884, 0.36986042931949054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 195}], {
             RGBColor[
             0.9063070598041875, 0.5682974877338114, 0.34831639298626615`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 200}], {
             RGBColor[
             0.939733161025506, 0.7818290973952341, 0.3786259847113931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 295}], {
             RGBColor[
             0.9153775706767935, 0.9307671307468549, 0.7575047799513781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 30}], {
             RGBColor[
             0.37921039896007874`, 0.5014757039177918, 0.9454929485539587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 38}], {
             RGBColor[
             0.3570833446280458, 0.48255148540021425`, 0.944016408991876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[
             0.2753301177357401, 0.4067197890509576, 0.9389910149394182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 48}], {
             RGBColor[
             0.35495264897954515`, 0.4807059839213601, 0.9438806429492537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 55}], {
             RGBColor[
             0.28645859801019335`, 0.41841652740581015`, 0.939624765427937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 84}], {
             RGBColor[
             0.2984201886260963, 0.4309889175517728, 0.9403059603179251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 90}], {
             RGBColor[
             0.3498844311553243, 0.4763161483780546, 0.9435577005911434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 97}], {
             RGBColor[
             0.27685141165294697`, 0.4083187654135474, 0.9390776503774505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 134}], {
             RGBColor[
             0.2851115833841571, 0.4170007296281859, 0.9395480549377139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 144}], {
             RGBColor[
             0.3059659418661292, 0.4382761603632087, 0.940759253289231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 158}], {
             RGBColor[
             0.34992722478314753`, 0.47635321406760484`, 0.9435604273632674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 159}], {
             RGBColor[
             0.2718080646722995, 0.4030178879702195, 0.9387904392278659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 175}], {
             RGBColor[
             0.29536678813966943`, 0.42777960004376564`, 0.9401320736773244]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 235}], {
             RGBColor[
             0.2691307812557516, 0.40020389334985473`, 0.9386379718979794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 252}], {
             RGBColor[
             0.29837684649391727`, 0.43094336222280266`, 0.9403034920476165]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 253}], {
             RGBColor[
             0.2964738820674033, 0.42894322595562323`, 0.9401951210387102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 292}], {
             RGBColor[
             0.26964195081094916`, 0.4007411649623891, 0.9386670822479402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 24}], {
             RGBColor[
             0.9510187529148094, 0.9629904466400717, 0.9677966543467089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 36}], {
             RGBColor[
             0.8529859949186596, 0.8858242206407632, 0.9761422011869598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 66}], {
             RGBColor[
             0.9464282973427488, 0.95956689239061, 0.9755670982476465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 69}], {
             RGBColor[
             0.9697193647682323, 0.9735318279786378, 0.7296111092370301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 88}], {
             RGBColor[
             0.7253109400374347, 0.7839674018676228, 0.9648635309809819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 113}], {
             RGBColor[
             0.9529050044310041, 0.9643972099323963, 0.9646037225429771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 135}], {
             RGBColor[
             0.9682482286960121, 0.9748593362633335, 0.8947082894518925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.7053280385373079, 0.7677443822103661, 0.9632904037751118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 222}], {
             RGBColor[
             0.6912666998914337, 0.7558621322945974, 0.9623123726675136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.9579627169351427, 0.9342040847269458, 0.6558617372883351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 254}], {
             RGBColor[
             0.918861315886804, 0.779473166025562, 0.6033212282319205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 258}], {
             RGBColor[
             0.9540838776271092, 0.9652764116318238, 0.9626081977213435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 260}], {
             RGBColor[
             0.8977772500782942, 0.9210512580678571, 0.980544009200409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 278}], {
             RGBColor[
             0.7746661157384185, 0.8240361569270088, 0.968748951206129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 288}], {
             RGBColor[
             0.9041509173263116, 0.7126766818632384, 0.5910465110881808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 290}], {
             RGBColor[
             0.7796647191738186, 0.8280942483803853, 0.9691424595790514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 48}], {
             RGBColor[
             0.3524750293077462, 0.47810184855613913`, 0.9437395461742546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 49}], {
             RGBColor[
             0.26391083574794544`, 0.39471739965748975`, 0.9383407037235271]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 57}], {
             RGBColor[
             0.2691600647734066, 0.40023467218359243`, 0.9386396395509886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 84}], {
             RGBColor[
             0.2959425689542974, 0.42838478218655185`, 0.940164863542926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 89}], {
             RGBColor[
             0.28469980544749635`, 0.41656792490852634`, 0.9395246047933918]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 111}], {
             RGBColor[
             0.2671407671011217, 0.39811226229915386`, 0.9385246435358352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 112}], {
             RGBColor[
             0.271740291472555, 0.402946654040219, 0.9387865796444018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 158}], {
             RGBColor[
             0.3474496051113486, 0.47374907870238386`, 0.9434193305882683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 175}], {
             RGBColor[
             0.2928891684678705, 0.42517546467854467`, 0.9399909769023254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 177}], {
             RGBColor[
             0.3552373943929633, 0.4804944703524481, 0.9439155616348212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 242}], {
             RGBColor[
             0.26584977931499626`, 0.39675535228258274`, 0.9384511236912607]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 253}], {
             RGBColor[
             0.2939962623956044, 0.42633909059040226`, 0.940054024263711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 280}], {
             RGBColor[
             0.2796627567223554, 0.4112736673310683, 0.939237752320141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 33}], {
             RGBColor[
             0.8902842568405922, 0.9153525165550513, 0.9893973012552358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 37}], {
             RGBColor[
             0.7733043134332283, 0.8232016433411387, 0.9779409081787471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 75}], {
             RGBColor[
             0.7982091276425176, 0.8426574734850338, 0.980423187310408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 124}], {
             RGBColor[
             0.9067998303302157, 0.928212273566045, 0.9802484959896351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 142}], {
             RGBColor[
             0.7624648027643098, 0.8147337352232472, 0.9768605270562558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 150}], {
             RGBColor[
             0.9139560790389594, 0.9335493921357441, 0.968134833574319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 167}], {
             RGBColor[
             0.8099161582263048, 0.8518030947538164, 0.981590034710579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 185}], {
             RGBColor[
             0.7169880778773853, 0.7780689639663625, 0.973105894503761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 200}], {
             RGBColor[
             0.8759509079419014, 0.7355649732308305, 0.6068283204518097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 237}], {
             RGBColor[
             0.752342583517374, 0.8067713443472341, 0.9758891306955624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 282}], {
             RGBColor[
             0.9147814478549319, 0.9341649508472791, 0.9667376994595409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 283}], {
             RGBColor[
             0.7423144926570131, 0.7986300884264481, 0.9750996826489275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 295}], {
             RGBColor[
             0.851595317593189, 0.8845030065824513, 0.9857071156917947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 297}], {
             RGBColor[
             0.8131524423226874, 0.8543313044865806, 0.981912597264512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 34}], {
             RGBColor[
             0.3554769401154252, 0.48231799156263766`, 0.943871654181607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 46}], {
             RGBColor[
             0.3377964064979223, 0.4654684905987692, 0.942801288807799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 50}], {
             RGBColor[
             0.3679518676107426, 0.4931231467509946, 0.9446665455304635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[
             0.32978099166431396`, 0.45704378140199375`, 0.9423448227907686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 101}], {
             RGBColor[
             0.4650224715635836, 0.5746682645420044, 0.9515515525742121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 108}], {
             RGBColor[
             0.3636875531699619, 0.4894296119130661, 0.9443948271850822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[
             0.3439329379247541, 0.47191837420693394`, 0.9431507551943723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 169}], {
             RGBColor[
             0.33823987120783705`, 0.46593460012617627`, 0.9428265434669814]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 187}], {
             RGBColor[
             0.3736920911272321, 0.49809503984895503`, 0.9450323074970538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 205}], {
             RGBColor[
             0.4564507498978377, 0.5677093547420913, 0.9508767552454336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 213}], {
             RGBColor[
             0.40566670523630644`, 0.5257898434994019, 0.9470697016340429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 264}], {
             RGBColor[
             0.339057995027486, 0.46679450013267343`, 0.9428731344082046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 61}], {
             RGBColor[
             0.6921091843567939, 0.7582433580431021, 0.9707375877325777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 72}], {
             RGBColor[
             0.7345932590636062, 0.7925891041868212, 0.9741810489653038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 177}], {
             RGBColor[
             0.6182933062719121, 0.6973901264603323, 0.9651824367082749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 217}], {
             RGBColor[
             0.812207338591908, 0.8532218130031827, 0.981916895067874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 247}], {
             RGBColor[
             0.6982336123573278, 0.7632154445962727, 0.9712197251392987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 267}], {
             RGBColor[
             0.642613111904264, 0.7180602166534845, 0.966841075599027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 271}], {
             RGBColor[
             0.8974219616748091, 0.8964540242042457, 0.6746941771749546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 273}], {
             RGBColor[
             0.717607033402136, 0.7789436605631201, 0.9727448718111256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 274}], {
             RGBColor[
             0.8909772154370372, 0.8747143818458635, 0.6496575550294168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 285}], {
             RGBColor[
             0.6000751622710249, 0.6816104857973055, 0.9640215926822105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[
             0.29610769611833376`, 0.428558341305621, 0.9401742672906341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 180}], {
             RGBColor[
             0.26520012614906696`, 0.3960725256148013, 0.9384141269045367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 267}], {
             RGBColor[
             0.3821106817559689, 0.50384843174461, 0.9457196175325961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 285}], {
             RGBColor[
             0.33957273212272987`, 0.46739870088843105`, 0.9429001346157797]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.7969254295463191, 0.8418022649015016, 0.9623206130704325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 113}], {
             RGBColor[
             0.9575230369172714, 0.9678413309993203, 0.9567865981194988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 135}], {
             RGBColor[
             0.9728662611822794, 0.9783034573302576, 0.8868911650284141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 224}], {
             RGBColor[
             0.9625807494214099, 0.9376482057938698, 0.6480446128648567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 233}], {
             RGBColor[
             0.9748626422338834, 0.9780993949460502, 0.7789636593832132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 254}], {
             RGBColor[
             0.9234793483730712, 0.7829172870924861, 0.5955041038084421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 259}], {
             RGBColor[
             0.7099488174717532, 0.7711907329676471, 0.9554734955620947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 260}], {
             RGBColor[
             0.9023952825645615, 0.924495379134781, 0.9727268847769307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 288}], {
             RGBColor[
             0.9087689498125788, 0.7161208029301624, 0.5832293866647026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 29}], {
             RGBColor[
             0.24731665325336327`, 0.3772758617237455, 0.9373956895793536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[
             0.2869920462831278, 0.4177357289024586, 0.9397006014188156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 77}], {
             RGBColor[
             0.24892138027318342`, 0.37896253156714604`, 0.9374870764091515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 91}], {
             RGBColor[
             0.2622113968861681, 0.3929311816631146, 0.9382439231944433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 139}], {
             RGBColor[
             0.25364452897953216`, 0.38392686032244283`, 0.9377560527407058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 147}], {
             RGBColor[
             0.2390014851721345, 0.36853609285826733`, 0.9369221530583165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 148}], {
             RGBColor[
             0.24531191831194143`, 0.3751687581927745, 0.9372815228901793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 172}], {
             RGBColor[
             0.2606528759791422, 0.3912930773738975, 0.9381551677344133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 203}], {
             RGBColor[
             0.2557021473412196, 0.3860895476811155, 0.9378732310624303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 206}], {
             RGBColor[
             0.2442420605634609, 0.3740442698662223, 0.937220596074116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 244}], {
             RGBColor[
             0.2471607788887478, 0.37711202788352904`, 0.9373868127648843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 270}], {
             RGBColor[
             0.24003287271686014`, 0.3696201465615213, 0.9369808890531874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 272}], {
             RGBColor[
             0.23754533151077184`, 0.36700558303470066`, 0.9368392272614883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 39}], {
             RGBColor[
             0.9266838506619479, 0.7398946126602461, 0.547796397964442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 59}], {
             RGBColor[
             0.9093225725856791, 0.6208046140216712, 0.5317333787947149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 60}], {
             RGBColor[
             0.9559587194852852, 0.8665294960501166, 0.5718984085520893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 62}], {
             RGBColor[
             0.9903418616011138, 0.9899003526601282, 0.7825545152346283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 82}], {
             RGBColor[
             0.9904558326619474, 0.9901441252350094, 0.7949595618585049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[
             0.9180076603888783, 0.6875620047068038, 0.5400502286834623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 127}], {
             RGBColor[
             0.9093035421850235, 0.6206583380230588, 0.5317151552615555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 130}], {
             RGBColor[
             0.5823809948253185, 0.6469022092217233, 0.9089577047840149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 137}], {
             RGBColor[
             0.9157005980775512, 0.6698289128207927, 0.5378409832086813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 170}], {
             RGBColor[
             0.903864214749553, 0.5788492838255521, 0.5265064491665074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 192}], {
             RGBColor[
             0.9254105636090766, 0.7341129135369036, 0.5467339360364043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 195}], {
             RGBColor[
             0.9024893735730009, 0.5682816520833267, 0.52518989970318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 199}], {
             RGBColor[
             0.5823809948253185, 0.6469022092217233, 0.9089577047840149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 220}], {
             RGBColor[
             0.6215133643769486, 0.6880328107560196, 0.9111862353388274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 226}], {
             RGBColor[
             0.5823809999360594, 0.646902214593436, 0.908957705075064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 228}], {
             RGBColor[
             0.901089116284713, 0.9224316156704129, 0.933371766463492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 266}], {
             RGBColor[
             0.6167344718352826, 0.6830098916954412, 0.9109140844783175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 32}], {
             RGBColor[
             0.25734797909016266`, 0.3878194212010146, 0.9379669587457427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 103}], {
             RGBColor[
             0.2686276829189324, 0.3996751050995809, 0.9386093211919647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 119}], {
             RGBColor[
             0.2703316084942079, 0.40146603891431676`, 0.9387063572327446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 152}], {
             RGBColor[
             0.2558672975304459, 0.3862631310011191, 0.9378826361213889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 268}], {
             RGBColor[
             0.2604774227946408, 0.3911086649526121, 0.9381451759351156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 35}], {
             RGBColor[
             0.2248219115083478, 0.35363246190073133`, 0.9361146473149633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 126}], {
             RGBColor[
             0.22467560955270433`, 0.3534786892692703, 0.9361063156350238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 163}], {
             RGBColor[
             0.23238600045450547`, 0.3615827989740821, 0.9365454109903801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 184}], {
             RGBColor[
             0.23042487690337662`, 0.35952153377943086`, 0.9364337279053656]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 189}], {
             RGBColor[
             0.22763054758381063`, 0.35658451649385525`, 0.9362745949844562]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 197}], {
             RGBColor[
             0.21695644286649302`, 0.3453653556586265, 0.9356667205117277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 211}], {
             RGBColor[
             0.2328859592843117, 0.3621082874034291, 0.9365738829061148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 216}], {
             RGBColor[
             0.24112529640186797`, 0.3707683531181266, 0.9370431009659527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 275}], {
             RGBColor[
             0.21809561015053047`, 0.3465626927015274, 0.9357315944033067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 293}], {
             RGBColor[
             0.21633697828784162`, 0.3447142591101412, 0.9356314429203892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 77}], {
             RGBColor[
             0.2444276826034072, 0.3742393703993229, 0.9372311669746878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 91}], {
             RGBColor[
             0.25771769921639187`, 0.38820802049529146`, 0.9379880137599795]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 148}], {
             RGBColor[
             0.2408182206421652, 0.3704455970249514, 0.9370256134557156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 162}], {
             RGBColor[
             0.2636748497853562, 0.39446936344843425`, 0.9383272646720675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 172}], {
             RGBColor[
             0.256159178309366, 0.3865699162060744, 0.9378992582999495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 191}], {
             RGBColor[
             0.24335597488348387`, 0.37311293763548947`, 0.9371701348054876]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 203}], {
             RGBColor[
             0.25120844967144335`, 0.38136638651329235`, 0.9376173216279664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 206}], {
             RGBColor[
             0.23974836289368467`, 0.3693211086983992, 0.9369646866396522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 244}], {
             RGBColor[
             0.24266708121897157`, 0.3723888667157059, 0.9371309033304205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 270}], {
             RGBColor[
             0.2355391750470839, 0.3648969853936982, 0.9367249796187237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 272}], {
             RGBColor[
             0.23305163384099561`, 0.36228242186687754`, 0.9365833178270244]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 38}], {
             RGBColor[
             0.4400713503236684, 0.5553482940395915, 0.949328558422408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 47}], {
             RGBColor[
             0.5531290988592262, 0.6480680925121483, 0.9579813085710855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 48}], {
             RGBColor[
             0.43794065467516774`, 0.5535027925607373, 0.9491927923797858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 74}], {
             RGBColor[
             0.5502062391736314, 0.6457212373265883, 0.9577333971010626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 90}], {
             RGBColor[
             0.4328724368509469, 0.5491129570174318, 0.9488698500216755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 123}], {
             RGBColor[
             0.44920952472312525`, 0.5632633214064009, 0.9499108348145711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 144}], {
             RGBColor[
             0.3889539475617518, 0.5110729690025859, 0.9460714027197632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 158}], {
             RGBColor[
             0.4329152304787701, 0.5491500227069821, 0.9488725767937995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 252}], {
             RGBColor[
             0.38136485218953986`, 0.5037401708621798, 0.9456156414781487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 257}], {
             RGBColor[
             0.42675186290096767`, 0.5438116234909512, 0.9484798524617939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 259}], {
             RGBColor[
             0.46322962709906557`, 0.5751097053927338, 0.9508862795927249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 36}], {
             RGBColor[
             0.6892039970441424, 0.7567703364683878, 0.9699034319627848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 51}], {
             RGBColor[
             0.8061994237416004, 0.8465221719044482, 0.8597460281820752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 58}], {
             RGBColor[
             0.583879953556761, 0.6730590756463584, 0.9603843152481828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 66}], {
             RGBColor[
             0.7826462994682315, 0.8305130082182347, 0.9693283290234715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 67}], {
             RGBColor[
             0.765577527957654, 0.8171802233035855, 0.9773175856314692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 73}], {
             RGBColor[
             0.47392342433375345`, 0.580416161461158, 0.9526607261917457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 95}], {
             RGBColor[
             0.5537416162054588, 0.648591415667946, 0.9580117149315208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 96}], {
             RGBColor[
             0.512151317735619, 0.6135272413360646, 0.9550965737557137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 109}], {
             RGBColor[
             0.7700026915435176, 0.8207087286290875, 0.9777396616846791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 110}], {
             RGBColor[
             0.8058913506986181, 0.8463947757840589, 0.8648515957717691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 138}], {
             RGBColor[
             0.662760313991049, 0.7361123302878763, 0.9672677727663206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 154}], {
             RGBColor[
             0.6800184039631393, 0.7495944813404151, 0.9689878978887183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 171}], {
             RGBColor[
             0.5185950159671473, 0.6191084488745244, 0.955507160509088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 245}], {
             RGBColor[
             0.5216196733437626, 0.6217282550704486, 0.9556998890025264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 156}], {
             RGBColor[
             0.24197823755521267`, 0.3716648483498845, 0.9370916747028223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 178}], {
             RGBColor[
             0.2666569110282901, 0.3976036988883609, 0.9384970886482884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 182}], {
             RGBColor[
             0.2817202883828383, 0.4134362635612778, 0.9393549257043601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 202}], {
             RGBColor[
             0.24218926046257408`, 0.37188664680514644`, 0.937103692145216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 208}], {
             RGBColor[
             0.27110861374646283`, 0.402282720699415, 0.9387506065323843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 268}], {
             RGBColor[
             0.2593869141835333, 0.38996247126009875`, 0.938083073082976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 37}], {
             RGBColor[
             0.7976827143280194, 0.8426403184805812, 0.9802661418189477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 75}], {
             RGBColor[
             0.8225875285373088, 0.8620961486244765, 0.9827484209506085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 94}], {
             RGBColor[
             0.8883058899064401, 0.9137750204630982, 0.9892086028509474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 124}], {
             RGBColor[
             0.931178231225007, 0.9476509487054876, 0.9825737296298357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 142}], {
             RGBColor[
             0.7868432036591011, 0.8341724103626897, 0.9791857606964562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 150}], {
             RGBColor[
             0.9383344799337505, 0.9529880672751867, 0.9704600672145196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 185}], {
             RGBColor[
             0.7413664787721765, 0.7975076391058051, 0.9754311281439616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 200}], {
             RGBColor[
             0.9003293088366926, 0.7550036483702731, 0.6091535540920102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 237}], {
             RGBColor[
             0.7767209844121652, 0.8262100194866766, 0.9782143643357628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 239}], {
             RGBColor[
             0.6628984653958889, 0.7326583838158534, 0.9695703125580974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 282}], {
             RGBColor[
             0.9391598487497231, 0.9536036259867218, 0.9690629330997416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 295}], {
             RGBColor[
             0.8759737184879801, 0.9039416817218939, 0.9880323493319954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 297}], {
             RGBColor[
             0.8375308432174786, 0.8737699796260231, 0.9842378309047126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 46}], {
             RGBColor[
             0.30981865996121394`, 0.44123557275110054`, 0.9410185715382298]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 50}], {
             RGBColor[
             0.33997412107403424`, 0.46889022890332593`, 0.9428838282608942]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 87}], {
             RGBColor[
             0.3018032451276056, 0.4328108635543251, 0.9405621055211995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 108}], {
             RGBColor[
             0.3357098066332535, 0.46519669406539743`, 0.9426121099155129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 114}], {
             RGBColor[
             0.31595519138804573`, 0.44768545635926527`, 0.9413680379248031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 169}], {
             RGBColor[
             0.3102621246711287, 0.4417016822785076, 0.9410438261974121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 187}], {
             RGBColor[
             0.34571434459052375`, 0.47386212200128636`, 0.9432495902274847]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 205}], {
             RGBColor[
             0.4284730033611293, 0.5434764368944227, 0.9490940379758643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 213}], {
             RGBColor[
             0.37768895869959807`, 0.5015569256517332, 0.9452869843644738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 227}], {
             RGBColor[
             0.2936321912026204, 0.4242225678044243, 0.9400967760881624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 264}], {
             RGBColor[
             0.31108024849077764`, 0.44256158228500475`, 0.9410904171386354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 92}], {
             RGBColor[
             0.24366421330036392`, 0.37343691575507476`, 0.9371876885273311]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 126}], {
             RGBColor[
             0.2260848753293333, 0.35495991695311835`, 0.9361865712361809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 163}], {
             RGBColor[
             0.23379526623113445`, 0.36306402665793014`, 0.9366256665915373]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 184}], {
             RGBColor[
             0.23183414268000563`, 0.3610027614632789, 0.9365139835065228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 189}], {
             RGBColor[
             0.2290398133604396, 0.3580657441777033, 0.9363548505856133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 197}], {
             RGBColor[
             0.218365708643122, 0.3468465833424746, 0.9357469761128849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 211}], {
             RGBColor[
             0.2342952250609407, 0.36358951508727716`, 0.936654138507272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 216}], {
             RGBColor[
             0.24253456217849695`, 0.3722495808019747, 0.9371233565671098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 275}], {
             RGBColor[
             0.21950487592715945`, 0.34804392038537546`, 0.9358118500044639]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 58}], {
             RGBColor[
             0.6542472259213957, 0.728390854886349, 0.9671515068891303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 66}], {
             RGBColor[
             0.8530135718328662, 0.8858447874582254, 0.9760955206644191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 67}], {
             RGBColor[
             0.8359448003222887, 0.8725120025435762, 0.9840847772724168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 69}], {
             RGBColor[
             0.8763046392583498, 0.8998097230462532, 0.7301395316538027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 88}], {
             RGBColor[
             0.6318962145275521, 0.7102452969352381, 0.9653919533977545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 95}], {
             RGBColor[
             0.6241088885700935, 0.7039231949079366, 0.9647789065724686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 96}], {
             RGBColor[
             0.5825185901002536, 0.6688590205760554, 0.9618637653966613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 109}], {
             RGBColor[
             0.8403699639081523, 0.8760405078690783, 0.9845068533256267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 113}], {
             RGBColor[
             0.8594902789211216, 0.8906751050000117, 0.9651321449597499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 138}], {
             RGBColor[
             0.7331275863556836, 0.791444109527867, 0.9740349644072682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 154}], {
             RGBColor[
             0.750385676327774, 0.8049262605804057, 0.9757550895296658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 198}], {
             RGBColor[
             0.6119133130274254, 0.6940222772779814, 0.9638188261918845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 222}], {
             RGBColor[
             0.5978519743815511, 0.6821400273622127, 0.9628407950842862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 224}], {
             RGBColor[
             0.8645479914252601, 0.8604819797945611, 0.6563901597051076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 245}], {
             RGBColor[
             0.5919869457083973, 0.6770600343104392, 0.9624670806434741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 258}], {
             RGBColor[
             0.8606691521172266, 0.8915543066994391, 0.9631366201381162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 260}], {
             RGBColor[
             0.8043625245684116, 0.8473291531354724, 0.9810724316171817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 278}], {
             RGBColor[
             0.681251390228536, 0.7503140519946241, 0.9692773736229017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 290}], {
             RGBColor[
             0.6862499936639361, 0.7543721434480005, 0.9696708819958241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 75}], {
             RGBColor[
             0.7056075851299448, 0.7699452754105638, 0.9712920278741198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 94}], {
             RGBColor[
             0.771325946499076, 0.8216241472491855, 0.9777522097744586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 102}], {
             RGBColor[
             0.5330127818666326, 0.6293292071697167, 0.9572915771331396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 124}], {
             RGBColor[
             0.8141982878176429, 0.8555000754915749, 0.971117336553347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 142}], {
             RGBColor[
             0.669863260251737, 0.742021537148777, 0.9677293676199676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 150}], {
             RGBColor[
             0.8213545365263866, 0.860837194061274, 0.9590036741380308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 185}], {
             RGBColor[
             0.6243865353648125, 0.7053567658918924, 0.9639747350674728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 237}], {
             RGBColor[
             0.6597410410048012, 0.7340591462727639, 0.9667579712592742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 239}], {
             RGBColor[
             0.5459185219885249, 0.6405075106019407, 0.9581139194816087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 282}], {
             RGBColor[
             0.8221799053423591, 0.8614527527728091, 0.9576065400232527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 283}], {
             RGBColor[
             0.6497129501444403, 0.725917890351978, 0.9659685232126394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 295}], {
             RGBColor[
             0.7589937750806162, 0.8117908085079812, 0.9765759562555065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 297}], {
             RGBColor[
             0.7205508998101146, 0.7816191064121104, 0.9727814378282238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 48}], {
             RGBColor[
             0.41581360034313486`, 0.5345785740431597, 0.947716252817703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 55}], {
             RGBColor[
             0.34731954937378307`, 0.4722891175276097, 0.9434603752963864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 74}], {
             RGBColor[
             0.5280791848415985, 0.6267970188090106, 0.9562568575389798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 90}], {
             RGBColor[
             0.41074538251891396`, 0.5301887384998543, 0.9473933104595927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 123}], {
             RGBColor[
             0.4270824703910924, 0.5443391028888234, 0.9484342952524883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 144}], {
             RGBColor[
             0.36682689322971884`, 0.49214875048500833`, 0.9445948631576804]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 158}], {
             RGBColor[
             0.41078817614673724`, 0.5302258041894045, 0.9473960372317167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 252}], {
             RGBColor[
             0.3592377978575069, 0.4848159523446023, 0.9441391019160659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 253}], {
             RGBColor[
             0.35733483343099304`, 0.48281581607742285`, 0.9440307309071595]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 257}], {
             RGBColor[
             0.4046248085689348, 0.5248874049733736, 0.9470033128997111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 259}], {
             RGBColor[
             0.44110257276703263`, 0.5561854868751561, 0.949409740030642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 52}], {
             RGBColor[
             0.8426203651830106, 0.3142479875093471, 0.1878844555501885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 59}], {
             RGBColor[
             0.8501714335969901, 0.3722888082384709, 0.1951153671911272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 60}], {
             RGBColor[
             0.8968075804965964, 0.6180136902669162, 0.2352803969485015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 62}], {
             RGBColor[
             0.931190722612425, 0.7413845468769279, 0.4459365036310404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 82}], {
             RGBColor[
             0.9313046936732585, 0.7416283194518091, 0.4583415502549171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 100}], {
             RGBColor[
             0.8588565214001893, 0.4390461989236035, 0.20343221707987458`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 107}], {
             RGBColor[
             0.8508398666409367, 0.3774266775234726, 0.1957554594288977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 127}], {
             RGBColor[
             0.8501524031963347, 0.3721425322398584, 0.1950971436579678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 136}], {
             RGBColor[
             0.9302201907265502, 0.7393086773088677, 0.34030009728209454`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 137}], {
             RGBColor[
             0.8565494590888623, 0.4213131070375924, 0.20122297160509353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 141}], {
             RGBColor[
             0.8832675790785431, 0.5628271647927903, 0.22430794542071705`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 170}], {
             RGBColor[
             0.8447130757608642, 0.3303334780423518, 0.18988843756291957`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 192}], {
             RGBColor[
             0.8662594246203876, 0.48559710775370324`, 0.21011592443281657`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 220}], {
             RGBColor[
             0.5623622253882596, 0.4395170049728193, 0.5745682237352395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 228}], {
             RGBColor[
             0.8419379772960242, 0.6739158098872126, 0.5967537548599042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 232}], {
             RGBColor[
             0.9308146259118721, 0.7405801140636548, 0.40500069877565514`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 266}], {
             RGBColor[
             0.5575833328465938, 0.4344940859122408, 0.5742960728747296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 281}], {
             RGBColor[
             0.8518045532150162, 0.3848416812601996, 0.19667924438169382`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.2625645345612948, 0.39330235174989453`, 0.9382640338626215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.25252112623098183`, 0.38274609280586824`, 0.9376920766161012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 162}], {
             RGBColor[
             0.2608696072714334, 0.3915208757036531, 0.9381675102608841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 191}], {
             RGBColor[
             0.24055073236956107`, 0.37016444989070835`, 0.9370103803943042]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 76}], {
             RGBColor[
             0.32564319585170254`, 0.45514146543527656`, 0.9420195932129798]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.4306059655104517, 0.5460088371370204, 0.9490406986812941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 99}], {
             RGBColor[
             0.362239582391498, 0.48817545240188814`, 0.9443025637674687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 104}], {
             RGBColor[
             0.3210313076505878, 0.45029407852530423`, 0.9417569530026035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 157}], {
             RGBColor[
             0.35148560431038395`, 0.4788608970986815, 0.9436173297935095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 201}], {
             RGBColor[
             0.3390519049385823, 0.4680914516387281, 0.942825065464227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 209}], {
             RGBColor[
             0.3110735460011261, 0.43982783967316585`, 0.9411898732078549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 222}], {
             RGBColor[
             0.3965617253644508, 0.517903567563995, 0.9464895403678258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 229}], {
             RGBColor[
             0.35168976097882576`, 0.47903772734367334`, 0.943630338475894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 259}], {
             RGBColor[
             0.41062581045850305`, 0.5297880471701207, 0.9474677876858852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 261}], {
             RGBColor[
             0.3788160778841355, 0.5025331796387221, 0.9453588034022401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 278}], {
             RGBColor[
             0.4799611412114356, 0.5860775921964064, 0.9529261189064413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 290}], {
             RGBColor[
             0.4849597446468357, 0.5901356836497829, 0.9533196272793637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 55}], {
             RGBColor[
             0.2655663224814774, 0.39645742117835314`, 0.9384349812439285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[
             0.25595913612423093`, 0.3863596591860904, 0.937887866193442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 134}], {
             RGBColor[
             0.26421930785544107`, 0.3950416234007289, 0.9383582707537054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 144}], {
             RGBColor[
             0.28507366633741316`, 0.4163170541357517, 0.9395694691052225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 159}], {
             RGBColor[
             0.2509157891435835, 0.3810587817427625, 0.9376006550438574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 235}], {
             RGBColor[
             0.24823850572703557`, 0.37824478712239773`, 0.9374481877139709]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 252}], {
             RGBColor[
             0.2774845709652012, 0.40898425599534566`, 0.939113707863608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 292}], {
             RGBColor[
             0.24874967528223313`, 0.3787820587349321, 0.9374772980639317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 63}], {
             RGBColor[
             0.3233435154432426, 0.45448563418447746`, 0.9418241407759673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 131}], {
             RGBColor[
             0.3235024771639835, 0.45462331883733487`, 0.9418342696762487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 139}], {
             RGBColor[
             0.2888262243395204, 0.4196635663333328, 0.9398050551457039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 143}], {
             RGBColor[
             0.3594618944461463, 0.48576955871427996`, 0.9441255719478039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 172}], {
             RGBColor[
             0.2958345713391305, 0.4270297833847875, 0.9402041701394114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 174}], {
             RGBColor[
             0.35724861486395953`, 0.48385252718285615`, 0.9439845437299532]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 183}], {
             RGBColor[
             0.28838161647063476`, 0.4191962552733669, 0.9397797353853092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 185}], {
             RGBColor[
             0.4451220207260428, 0.5568482607152324, 0.9504446626081502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 244}], {
             RGBColor[
             0.28234247424873604`, 0.412848733894419, 0.9394358151698824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 59}], {
             RGBColor[
             0.8989327098919131, 0.5734920759622608, 0.24889953887676536`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 60}], {
             RGBColor[
             0.9455688567915195, 0.8192169579907062, 0.28906456863413965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 94}], {
             RGBColor[
             0.9135021931703009, 0.8932720957781641, 0.6527207002692943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 100}], {
             RGBColor[
             0.9076177976951124, 0.6402494666473935, 0.25721638876551267`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 121}], {
             RGBColor[
             0.9798326937990873, 0.9423326330377451, 0.48673505054828914`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 124}], {
             RGBColor[
             0.9563745344888678, 0.9271480240205534, 0.6460858270481826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 125}], {
             RGBColor[
             0.9788402151300284, 0.9402098215196141, 0.37870987228958564`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 137}], {
             RGBColor[
             0.9053107353837854, 0.6225163747613823, 0.25500714329073165`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 150}], {
             RGBColor[
             0.9635307831976114, 0.9324851425902525, 0.6339721646328667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 170}], {
             RGBColor[
             0.8934743520557873, 0.5315367457661417, 0.24367260924855771`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 192}], {
             RGBColor[
             0.9150207009153106, 0.6868003754774932, 0.26390009611845466`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 195}], {
             RGBColor[
             0.892099510879235, 0.5209691140239162, 0.24235605978523028`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 200}], {
             RGBColor[
             0.9255256121005535, 0.7345007236853389, 0.2726656515103572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 256}], {
             RGBColor[
             0.9801516197044022, 0.9430147833008583, 0.5214481671592728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 299}], {
             RGBColor[
             0.979769906119425, 0.942886287709507, 0.5299077867568601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 53}], {
             RGBColor[
             0.8447764554590436, 0.34517703459191124`, 0.19051129035634062`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 68}], {
             RGBColor[
             0.8660950044608668, 0.48393636846669774`, 0.20994293256664392`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 195}], {
             RGBColor[
             0.8384837744462674, 0.29680873085731074`, 0.18448541191193943`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 200}], {
             RGBColor[
             0.8719098756675858, 0.5103403405187334, 0.21479500363706636`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 215}], {
             RGBColor[
             0.9264635101364236, 0.7188538247686493, 0.4669105670802081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 223}], {
             RGBColor[
             0.872589282408941, 0.5134253678517513, 0.21536191727583626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 225}], {
             RGBColor[
             0.9093933228339569, 0.6627226292341221, 0.2529269618420678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 234}], {
             RGBColor[
             0.837571395698585, 0.28979578799570727`, 0.18361171699277434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 255}], {
             RGBColor[
             0.9083890640548784, 0.6593350285611156, 0.24902560612370514`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 282}], {
             RGBColor[
             0.9107404155806164, 0.7089403181351821, 0.5747043826447977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 287}], {
             RGBColor[
             0.899399401089056, 0.6245785965945915, 0.23718537302328563`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 50}], {
             RGBColor[
             0.32229358745653136`, 0.4520407279394575, 0.9418134628870861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 108}], {
             RGBColor[
             0.3180292730157506, 0.448347193101529, 0.9415417445417048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 114}], {
             RGBColor[
             0.29827465777054285`, 0.4308359553953969, 0.9402976725509951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 145}], {
             RGBColor[
             0.280670988716232, 0.4123333830822331, 0.9392951696406466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 169}], {
             RGBColor[
             0.2925815910536258, 0.4248521813146391, 0.9399734608236041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 187}], {
             RGBColor[
             0.32803381097302087`, 0.4570126210374179, 0.9421792248536764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 213}], {
             RGBColor[
             0.3600084250820952, 0.48470742468786476`, 0.9442166189906656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 219}], {
             RGBColor[
             0.2831865614508789, 0.4149774095228705, 0.9394384277864284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 221}], {
             RGBColor[
             0.2933757434234066, 0.4256868858074472, 0.9400186866262199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 264}], {
             RGBColor[
             0.29339971487327476`, 0.42571208132113636`, 0.9400200517648274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 48}], {
             RGBColor[
             0.5288713488786927, 0.6272983725157164, 0.9563690029663805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 74}], {
             RGBColor[
             0.6411369333771564, 0.7195168172815674, 0.9649096076876572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 90}], {
             RGBColor[
             0.5238031310544717, 0.622908536972411, 0.9560460606082701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.5238459246822951, 0.6229456026619612, 0.9560487873803941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 166}], {
             RGBColor[
             0.8183915236203407, 0.8543538869413033, 0.7072534135870767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 177}], {
             RGBColor[
             0.5316337139639098, 0.6296909943120255, 0.956545018426947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 217}], {
             RGBColor[
             0.7255477462839056, 0.7855226808548759, 0.9732794767865461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 233}], {
             RGBColor[
             0.8190741460647206, 0.8558139473261162, 0.781552654000438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 262}], {
             RGBColor[
             0.8190197652374052, 0.8556976322352333, 0.77563363654671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 273}], {
             RGBColor[
             0.6309474410941337, 0.7112445284148133, 0.9641074535297975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 74}], {
             RGBColor[
             0.5259484891930979, 0.6249515173301565, 0.9561210914963576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 84}], {
             RGBColor[
             0.35715044434118537`, 0.4830160061947183, 0.9440058041437522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 90}], {
             RGBColor[
             0.4086146868704133, 0.5283432370210001, 0.9472575444169704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 144}], {
             RGBColor[
             0.3646961975812182, 0.4903032490061542, 0.9444590971150582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 158}], {
             RGBColor[
             0.4086574804982366, 0.5283803027105503, 0.9472602711890945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 175}], {
             RGBColor[
             0.3540970438547585, 0.4798066886867111, 0.9438319175031515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 177}], {
             RGBColor[
             0.4164452697798513, 0.5351256943606145, 0.9477565022356473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 217}], {
             RGBColor[
             0.6103593020998471, 0.6909573809034649, 0.9644909605952465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 252}], {
             RGBColor[
             0.35710710220900627`, 0.48297045086574814`, 0.9440033358734436]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 253}], {
             RGBColor[
             0.3552041377824924, 0.4809703145985687, 0.9438949648645372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 57}], {
             RGBColor[
             0.2418037466004938, 0.3714814472931095, 0.9370817377010874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 84}], {
             RGBColor[
             0.2685862507813846, 0.39963155729606886`, 0.9386069616930247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 112}], {
             RGBColor[
             0.24438397329964223`, 0.374193429149736, 0.9372286777945005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 115}], {
             RGBColor[
             0.22907293102325943`, 0.358100552941108, 0.9363567365875176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 146}], {
             RGBColor[
             0.23350254559126715`, 0.3627563587058691, 0.9366089965841382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 159}], {
             RGBColor[
             0.24197412682758776`, 0.3716605277145155, 0.9370914406029653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 175}], {
             RGBColor[
             0.26553285029495766`, 0.3964222397880617, 0.9384330750524239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 204}], {
             RGBColor[
             0.23371861491604712`, 0.3629834612657993, 0.9366213014125385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 242}], {
             RGBColor[
             0.23849346114208345`, 0.3680021273920998, 0.9368932218413593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 243}], {
             RGBColor[
             0.2273605669768493, 0.3563007497581797, 0.9362592199882902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 253}], {
             RGBColor[
             0.2666399442226916, 0.39758586569991927`, 0.9384961224138098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 280}], {
             RGBColor[
             0.2523064385494426, 0.38252044244058536`, 0.9376798504702395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 292}], {
             RGBColor[
             0.23980801296623738`, 0.36938380470668514`, 0.9369680836230397]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 87}], {
             RGBColor[
             0.314278172622923, 0.4436160187426821, 0.9413569968700557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 108}], {
             RGBColor[
             0.3481847341285709, 0.4760018492537544, 0.9434070012643693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 114}], {
             RGBColor[
             0.32843011888336315`, 0.4584906115476223, 0.9421629292736595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 169}], {
             RGBColor[
             0.3227370521664461, 0.4525068374668645, 0.9418387175462686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 187}], {
             RGBColor[
             0.35818927208584117`, 0.4846672771896433, 0.9440444815763409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 205}], {
             RGBColor[
             0.44094793085644673`, 0.5542815920827796, 0.9498889293247207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 213}], {
             RGBColor[
             0.3901638861949155, 0.5123620808400902, 0.94608187571333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 227}], {
             RGBColor[
             0.30610711869793783`, 0.43502772299278125`, 0.9408916674370189]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 264}], {
             RGBColor[
             0.32355517598609507`, 0.45336673747336176`, 0.9418853084874919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 52}], {
             RGBColor[
             0.9056350707482277, 0.5643614773610739, 0.4604731703909181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 58}], {
             RGBColor[
             0.7712426526188537, 0.8181426903224094, 0.8569941031084208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 66}], {
             RGBColor[
             0.9700089985303242, 0.9755966228942858, 0.8659381168837096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 67}], {
             RGBColor[
             0.9529402270197467, 0.9622638379796367, 0.8739273734917072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 69}], {
             RGBColor[
             0.9933000659558078, 0.9895615584823135, 0.6199821278730931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 86}], {
             RGBColor[
             0.9842148587859489, 0.9592452118717956, 0.5566107984418112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[
             0.9138545722061537, 0.6275401673751994, 0.4683441742696273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 109}], {
             RGBColor[
             0.9573653906056103, 0.9657923433051386, 0.8743494495449171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 110}], {
             RGBColor[
             0.9932540497607107, 0.99147839046011, 0.7614613836320072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 138}], {
             RGBColor[
             0.8501230130531416, 0.8811959449639274, 0.8638775606265587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 141}], {
             RGBColor[
             0.9462822846437602, 0.812940654644517, 0.4968966602614467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 154}], {
             RGBColor[
             0.867381103025232, 0.8946780960164662, 0.8655976857489563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 165}], {
             RGBColor[
             0.986911243979133, 0.9683407522697562, 0.5670857457477134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 179}], {
             RGBColor[
             0.993604348606093, 0.9916232480349453, 0.7556560252196713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 258}], {
             RGBColor[
             0.9776645788146846, 0.9813061421354996, 0.8529792163574066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 281}], {
             RGBColor[
             0.9148192587802333, 0.6349551711119263, 0.4692679592224235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 82}], {
             RGBColor[
             0.90639234718301, 0.5644975000841104, 0.4350476194442515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 86}], {
             RGBColor[
             0.8962878067304835, 0.5320009026523702, 0.26072815279041595`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 107}], {
             RGBColor[
             0.8259275201506884, 0.20029585815577397`, 0.17246152861823205`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 110}], {
             RGBColor[
             0.9053269977052454, 0.5642340812406845, 0.4655787379806119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 141}], {
             RGBColor[
             0.8583552325882947, 0.3856963454250917, 0.20101401461005142`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 165}], {
             RGBColor[
             0.8989841919236675, 0.5410964430503309, 0.2712031000963182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 179}], {
             RGBColor[
             0.9056772965506277, 0.5643789388155198, 0.459773379568276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 193}], {
             RGBColor[
             0.6086028861336337, 0.3287818878860621, 0.5556335731143328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 236}], {
             RGBColor[
             0.7204593344779664, 0.42105333760098257`, 0.5640355482527617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 266}], {
             RGBColor[
             0.5326709863563452, 0.2573632665445422, 0.5510021420640641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 281}], {
             RGBColor[
             0.8268922067247678, 0.207710861892501, 0.1733853135710282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 59}], {
             RGBColor[
             0.8322696375208192, 0.249044151396152, 0.17853474737426642`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 68}], {
             RGBColor[
             0.8530476685227406, 0.3836488270671944, 0.19744878893743584`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 150}], {
             RGBColor[
             0.8968677108265174, 0.6080372180241437, 0.5636073731303677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 170}], {
             RGBColor[
             0.8268112796846933, 0.20708882120003286`, 0.1733078177460588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 192}], {
             RGBColor[
             0.8483576285442167, 0.36235245091138435`, 0.19353530461595575`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 195}], {
             RGBColor[
             0.825436438508141, 0.1965211894578074, 0.17199126828273137`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 200}], {
             RGBColor[
             0.8588625397294595, 0.4100527991192301, 0.2023008600078583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 225}], {
             RGBColor[
             0.8963459868958306, 0.5624350878346187, 0.24043281821285972`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 234}], {
             RGBColor[
             0.8245240597604586, 0.18950824659620397`, 0.17111757336356628`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 255}], {
             RGBColor[
             0.8953417281167521, 0.5590474871616122, 0.23653146249449708`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 282}], {
             RGBColor[
             0.89769307964249, 0.6086527767356787, 0.5622102390155896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 287}], {
             RGBColor[
             0.8863520651509298, 0.5242910551950881, 0.22469122939407754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 72}], {
             RGBColor[
             0.534606977221836, 0.6319372303906756, 0.9568737438527076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 106}], {
             RGBColor[
             0.5370375913061106, 0.6338360445866622, 0.9571160047492481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 151}], {
             RGBColor[
             0.4303399784091667, 0.5471605926069658, 0.9486418607828988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 167}], {
             RGBColor[
             0.585666437251012, 0.671825268631737, 0.9619628736506332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 194}], {
             RGBColor[
             0.4666198015964266, 0.5768869180196359, 0.9514225850947327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 238}], {
             RGBColor[
             0.34796050319161576`, 0.47301253149465217`, 0.9434950557775005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 251}], {
             RGBColor[
             0.3520600889143901, 0.4773214560180356, 0.9437285211196189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 286}], {
             RGBColor[
             0.4882211414959945, 0.5944238588793778, 0.953123121699942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 90}], {
             RGBColor[
             0.3401206359010615, 0.4660537805054501, 0.9430016668956538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 97}], {
             RGBColor[
             0.26708761639868417`, 0.39805639754094285`, 0.9385216166819608]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 134}], {
             RGBColor[
             0.27534778812989436`, 0.40673836175558137`, 0.9389920212422243]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 144}], {
             RGBColor[
             0.2962021466118664, 0.42801379249060423`, 0.9402032195937415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 159}], {
             RGBColor[
             0.26204426941803677`, 0.39275552009761494`, 0.9382344055323761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 235}], {
             RGBColor[
             0.25936698600148883`, 0.38994152547725025`, 0.9380819382024896]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 252}], {
             RGBColor[
             0.2886130512396545, 0.4206809943501981, 0.9397474583521269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 253}], {
             RGBColor[
             0.2867100868131406, 0.4186808580830187, 0.9396390873432205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 292}], {
             RGBColor[
             0.25987815555668636`, 0.39047879708978456`, 0.9381110485524506]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 79}], {
             RGBColor[
             0.47131158576889715`, 0.5800856534095411, 0.9519605579459619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 93}], {
             RGBColor[
             0.5394509250519448, 0.6369895888012234, 0.9568866993753897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 160}], {
             RGBColor[
             0.5689561966042058, 0.6609432974446849, 0.9592094624333546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 164}], {
             RGBColor[
             0.46580833431938506`, 0.5753190136054342, 0.9516098956299331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 168}], {
             RGBColor[
             0.46678271330407606`, 0.5761629717082618, 0.9516719821972282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 246}], {
             RGBColor[
             0.57328015808247, 0.6644536841649844, 0.9595498605201163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 296}], {
             RGBColor[
             0.6219639893106997, 0.70315209105388, 0.9639467061714042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.27383547980684575`, 0.4051488298221716, 0.9389058975204863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 89}], {
             RGBColor[
             0.26259271630004477`, 0.3933319725441461, 0.9382656387709521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 112}], {
             RGBColor[
             0.24963320232510341`, 0.37971070167583876`, 0.9375276136219621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 115}], {
             RGBColor[
             0.2343221600487206, 0.3636178254672108, 0.9366556724149793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 134}], {
             RGBColor[
             0.26052687456490653`, 0.3911606418985847, 0.938147992140275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 146}], {
             RGBColor[
             0.23875177461672836`, 0.3682736312319718, 0.9369079324115999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 159}], {
             RGBColor[
             0.24722335585304894`, 0.3771778002406183, 0.937390376430427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 175}], {
             RGBColor[
             0.27078207932041887`, 0.40193951231416447`, 0.9387320108798856]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 204}], {
             RGBColor[
             0.23896784394150833`, 0.36850073379190207`, 0.9369202372400001]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 235}], {
             RGBColor[
             0.24454607243650103`, 0.3743638056202535, 0.9372379091005405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 242}], {
             RGBColor[
             0.24374269016754463`, 0.3735193999182025, 0.9371921576688209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 243}], {
             RGBColor[
             0.23260979600231052`, 0.3618180222842825, 0.9365581558157519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 253}], {
             RGBColor[
             0.27188917324815276`, 0.40310313822602206`, 0.9387950582412713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 280}], {
             RGBColor[
             0.2575556675749038, 0.38803771496668804`, 0.9379787862977012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 292}], {
             RGBColor[
             0.2450572419916986, 0.37490107723278787`, 0.9372670194505013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 66}], {
             RGBColor[
             0.747689528345485, 0.802133526636196, 0.966576403949817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 67}], {
             RGBColor[
             0.7306207568349073, 0.7888007417215468, 0.9745656605578148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 73}], {
             RGBColor[
             0.4389666532110068, 0.5520366798791193, 0.9499088011180912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 95}], {
             RGBColor[
             0.5187848450827122, 0.6202119340859072, 0.9552597898578664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 96}], {
             RGBColor[
             0.47719454661287236`, 0.585147759754026, 0.9523446486820593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 109}], {
             RGBColor[
             0.7350459204207711, 0.7923292470470489, 0.9749877366110247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 138}], {
             RGBColor[
             0.6278035428683023, 0.7077328487058376, 0.9645158476926661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 140}], {
             RGBColor[
             0.4384985979215843, 0.5516312739125644, 0.9498789770489342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 154}], {
             RGBColor[
             0.6450616328403926, 0.7212149997583763, 0.9662359728150638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 171}], {
             RGBColor[
             0.48363824484440066`, 0.5907289672924857, 0.9527552354354336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 198}], {
             RGBColor[
             0.506589269540044, 0.610311016455952, 0.9542997094772824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[
             0.48666290222101594`, 0.5933487734884098, 0.952947963928872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 62}], {
             RGBColor[
             0.9138294445361559, 0.6222945482383531, 0.42987348446131357`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 100}], {
             RGBColor[
             0.8414952433239204, 0.3199562002850287, 0.1873691979101476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 125}], {
             RGBColor[
             0.9127176607588363, 0.6199165551572493, 0.3088626814342206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 137}], {
             RGBColor[
             0.8391881810125934, 0.30222310839901756`, 0.1851599524353666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 170}], {
             RGBColor[
             0.8273517976845952, 0.21124347940377694`, 0.17382541839319265`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 192}], {
             RGBColor[
             0.8488981465441187, 0.3665071091151284, 0.1940529052630896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 195}], {
             RGBColor[
             0.825976956508043, 0.20067584766155147`, 0.17250886892986522`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 200}], {
             RGBColor[
             0.8594030577293614, 0.41420745732297415`, 0.20281846065499215`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 225}], {
             RGBColor[
             0.8968865048957325, 0.5665897460383628, 0.24095041885999358`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 228}], {
             RGBColor[
             0.8245766992197552, 0.5548258112486377, 0.5806907356901773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 255}], {
             RGBColor[
             0.895882246116654, 0.5632021453653563, 0.23704906314163093`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.9605795624965958, 0.8682632028416796, 0.48244356084256446`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 85}], {
             RGBColor[
             0.9228540566499766, 0.8416985659067688, 0.6257891591988634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 100}], {
             RGBColor[
             0.8881313902235266, 0.565681082313474, 0.22753422766752193`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 121}], {
             RGBColor[
             0.9603462863275016, 0.8677642487038257, 0.4570528894502983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 125}], {
             RGBColor[
             0.9593538076584427, 0.8656414371856946, 0.3490277111915949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 127}], {
             RGBColor[
             0.879427272019672, 0.4987774156297289, 0.21919915424561515`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.9594950595498875, 0.8659435606987382, 0.3644021078697419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 137}], {
             RGBColor[
             0.8858243279121996, 0.5479479904274629, 0.22532498219274089`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 170}], {
             RGBColor[
             0.8739879445842015, 0.4569683614322223, 0.21399044815056695`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 232}], {
             RGBColor[
             0.9600894947352094, 0.8672149974535253, 0.4291027093633025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 240}], {
             RGBColor[
             0.9605080040332614, 0.868110146524278, 0.47465486371626864`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 256}], {
             RGBColor[
             0.9606652122328164, 0.8684463989669389, 0.49176600606128196`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 299}], {
             RGBColor[
             0.9602834986478392, 0.8683179033755875, 0.5002256256588694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 177}], {
             RGBColor[
             0.49302351294995017`, 0.5983715477396933, 0.9534876687205165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 217}], {
             RGBColor[
             0.686937545269946, 0.7542032342825437, 0.9702221270801157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 247}], {
             RGBColor[
             0.5729638190353659, 0.6641968658756336, 0.9595249571515402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 267}], {
             RGBColor[
             0.517343318582302, 0.6190416379328455, 0.9551463076112685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 273}], {
             RGBColor[
             0.5923372400801741, 0.6799250818424811, 0.9610501038233672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 285}], {
             RGBColor[
             0.474805368949063, 0.5825919070766665, 0.9523268246944521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 82}], {
             RGBColor[
             0.9949627046124243, 0.9916340594516913, 0.6930996675251034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 100}], {
             RGBColor[
             0.9225145323393552, 0.6890519389234857, 0.4381903343500609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 127}], {
             RGBColor[
             0.9138104141355006, 0.6221482722397406, 0.4298552609281541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 130}], {
             RGBColor[
             0.5868878667757954, 0.648392143438405, 0.8070978104506135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 137}], {
             RGBColor[
             0.9202074700280282, 0.6713188470374746, 0.43598108887527987`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 170}], {
             RGBColor[
             0.9083710867000301, 0.580339218042234, 0.42464655483310587`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 192}], {
             RGBColor[
             0.9299174355595534, 0.7356028477535854, 0.4448740417030029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 195}], {
             RGBColor[
             0.9069962455234778, 0.5697715863000085, 0.4233300053697785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 199}], {
             RGBColor[
             0.5868878667757954, 0.648392143438405, 0.8070978104506135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 220}], {
             RGBColor[
             0.6260202363274255, 0.6895227449727015, 0.8093263410054259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 225}], {
             RGBColor[
             0.9779057939111673, 0.9356854846768198, 0.49177155529990685`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 226}], {
             RGBColor[
             0.5868878718865363, 0.6483921488101179, 0.8070978107416625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 228}], {
             RGBColor[
             0.90559598823519, 0.9239215498870947, 0.8315118721300905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 255}], {
             RGBColor[
             0.9769015351320889, 0.9322978840038133, 0.4878701995815442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 131}], {
             RGBColor[
             0.32467225096411007`, 0.4556365181084638, 0.9419088066284024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 139}], {
             RGBColor[
             0.28999599813964694`, 0.42067676560446166`, 0.9398795920978575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 143}], {
             RGBColor[
             0.36063166824627285`, 0.4867827579854089, 0.9442001088999576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 172}], {
             RGBColor[
             0.29700434513925705`, 0.4280429826559164, 0.940278707091565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 174}], {
             RGBColor[
             0.35841838866408615`, 0.48486572645398507`, 0.944059080682107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 183}], {
             RGBColor[
             0.28955139027076127`, 0.4202094545444958, 0.939854272337463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 283}], {
             RGBColor[
             0.4716182093057971, 0.5784225844464469, 0.9525129877054703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 92}], {
             RGBColor[
             0.24737632360791623`, 0.3773385790496996, 0.9373990877177711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 145}], {
             RGBColor[
             0.2514296244944172, 0.3815988552755316, 0.937629917206936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 153}], {
             RGBColor[
             0.253568524812987, 0.38384697512446136`, 0.9377517244158591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 211}], {
             RGBColor[
             0.238007335368493, 0.36749117838190204`, 0.936865537697712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 219}], {
             RGBColor[
             0.2539451972290641, 0.384242881716169, 0.9377731753527179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 221}], {
             RGBColor[
             0.26413437920159183`, 0.3949523580007457, 0.9383534341925093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 80}], {
             RGBColor[
             0.27787319023653523`, 0.40939271948940265`, 0.9391358391561999]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 103}], {
             RGBColor[
             0.2833667383517215, 0.41516678686953135`, 0.9394486885943836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 116}], {
             RGBColor[
             0.3051622199360282, 0.4368120893539453, 0.940736158424998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 133}], {
             RGBColor[
             0.3190318248130566, 0.44882524399181684`, 0.9416199173833522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 152}], {
             RGBColor[
             0.270606352963235, 0.4017548127710696, 0.9387220035238077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 162}], {
             RGBColor[
             0.28622167127698683`, 0.41816750238718753`, 0.9396112728009827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[
             0.33323684341077736`, 0.46112891713616844`, 0.9425250486073942]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 241}], {
             RGBColor[
             0.2834960053804121, 0.4153026547126882, 0.9394560501604341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 277}], {
             RGBColor[
             0.318505826054183, 0.44836965030434695`, 0.9415864012075592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 67}], {
             RGBColor[
             0.9293871027463778, 0.9462546742934231, 0.9835096743331035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 69}], {
             RGBColor[
             0.9697469416824389, 0.9735523947961, 0.7295644287144893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 95}], {
             RGBColor[
             0.7175511909941827, 0.7776658666577836, 0.9642038036331552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 109}], {
             RGBColor[
             0.9338122663322416, 0.9497831796189251, 0.9839317503863134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 110}], {
             RGBColor[
             0.969700925487342, 0.9754692267738965, 0.8710436844734033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 138}], {
             RGBColor[
             0.8265698887797728, 0.8651867812777139, 0.9734598614679548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 154}], {
             RGBColor[
             0.8438279787518632, 0.8786689323302527, 0.9751799865903525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 179}], {
             RGBColor[
             0.9700512243327243, 0.9756140843487318, 0.8652383260610674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 258}], {
             RGBColor[
             0.9541114545413159, 0.9652969784492861, 0.9625615171988029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 69}], {
             RGBColor[
             0.9526781701718614, 0.9602196098814508, 0.7375536853224871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 86}], {
             RGBColor[
             0.9435929630020026, 0.929903263270933, 0.6741823558912051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 95}], {
             RGBColor[
             0.7004824194836051, 0.7643330817431344, 0.9721930602411528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 109}], {
             RGBColor[
             0.916743494821664, 0.9364503947042759, 0.9919210069943111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 110}], {
             RGBColor[
             0.9526321539767644, 0.9621364418592473, 0.8790329410814011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 138}], {
             RGBColor[
             0.8095011172691953, 0.8518539963630647, 0.9814491180759526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 154}], {
             RGBColor[
             0.8267592072412856, 0.8653361474156035, 0.9831692431983503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 179}], {
             RGBColor[
             0.9529824528221467, 0.9622812994340826, 0.8732275826690652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 258}], {
             RGBColor[
             0.9370426830307382, 0.9519641935346369, 0.9705507738068005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 215}], {
             RGBColor[
             0.9347347232001206, 0.7573256172439325, 0.47384806566130333`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 223}], {
             RGBColor[
             0.880860495472638, 0.5518971603270344, 0.22229941585693147`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 234}], {
             RGBColor[
             0.8458426087622819, 0.3282675804709904, 0.19054921557386956`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 255}], {
             RGBColor[
             0.9166602771185755, 0.6978068210363987, 0.2559631047048003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 271}], {
             RGBColor[
             0.9259155815977133, 0.7290271362933656, 0.2919182148886562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 274}], {
             RGBColor[
             0.9194708353599413, 0.7072874939349834, 0.2668815927431183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 287}], {
             RGBColor[
             0.9076706141527531, 0.6630503890698746, 0.24412287160438084`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 109}], {
             RGBColor[
             0.957103333757725, 0.9637481152069529, 0.737975761375697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 110}], {
             RGBColor[
             0.9929919929128255, 0.9894341623619243, 0.625087695462787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 113}], {
             RGBColor[
             0.9762236487706943, 0.9783827123378863, 0.71860105300982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 135}], {
             RGBColor[
             0.9915668730357023, 0.9888448386688236, 0.6487056199187353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 138}], {
             RGBColor[
             0.8498609562052564, 0.8791517168657417, 0.7275038724573385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 224}], {
             RGBColor[
             0.9812813612748328, 0.9481895871324358, 0.4098590677551779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 249}], {
             RGBColor[
             0.9058089885195326, 0.5656683412312807, 0.3245169720093974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 254}], {
             RGBColor[
             0.9421799602264942, 0.7934586684310521, 0.3573185586987633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 258}], {
             RGBColor[
             0.9774025219667993, 0.9792619140373138, 0.7166055281881865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 288}], {
             RGBColor[
             0.9274695616660017, 0.7266621842687284, 0.34504384155502377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[
             0.27137415800540265`, 0.40256182455203926`, 0.9387657288850935]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 251}], {
             RGBColor[
             0.27547374372817707`, 0.40687074907542276`, 0.9389991942272118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 300}], {
             RGBColor[
             0.2600472811884571, 0.39065655885195993`, 0.938120680006981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 85}], {
             RGBColor[
             0.7746111080065263, 0.8244612139777192, 0.9780896021036154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 98}], {
             RGBColor[
             0.5262018737865255, 0.625404972246536, 0.9560725859325541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 121}], {
             RGBColor[
             0.8121033376840514, 0.8505268967747761, 0.8093533323550504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 122}], {
             RGBColor[
             0.6268946494046528, 0.707980343525642, 0.9637705896733515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 136}], {
             RGBColor[
             0.8112521109064372, 0.8487062087696886, 0.716702550774494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 160}], {
             RGBColor[
             0.6099082730566356, 0.6941900379787878, 0.9624333599040888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 181}], {
             RGBColor[
             0.6717068148993812, 0.7432662316253906, 0.9680467833618187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 207}], {
             RGBColor[
             0.6875924129964879, 0.7556761815938675, 0.9696301113207838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 232}], {
             RGBColor[
             0.8118465460917592, 0.8499776455244756, 0.7814031522680547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 240}], {
             RGBColor[
             0.8122650553898112, 0.8508727945952284, 0.8269553066210207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 246}], {
             RGBColor[
             0.6142322345348998, 0.6977004246990872, 0.9627737579908505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 256}], {
             RGBColor[
             0.8124222635893662, 0.8512090470378892, 0.8440664489660341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 296}], {
             RGBColor[
             0.6629160657631297, 0.7363988315879828, 0.9671706036421385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 299}], {
             RGBColor[
             0.812040550004389, 0.8510805514465378, 0.8525260685636215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 106}], {
             RGBColor[
             0.6542381545327312, 0.7298150858058879, 0.966172003106812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 151}], {
             RGBColor[
             0.5475405416357872, 0.6431396338261914, 0.9576978591404627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 194}], {
             RGBColor[
             0.5838203648230471, 0.6728659592388615, 0.9604785834522965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 215}], {
             RGBColor[
             0.8234553846620669, 0.8600796725778928, 0.8483727211925696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 247}], {
             RGBColor[
             0.6154478937421781, 0.6985426120193529, 0.9629684183842664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 267}], {
             RGBColor[
             0.5598273932891142, 0.6533873840765647, 0.9585897688439947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 286}], {
             RGBColor[
             0.6054217047226151, 0.6904029000986035, 0.9621791200575058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 87}], {
             RGBColor[
             0.3025587103322468, 0.4334652095438001, 0.9406102430960075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 95}], {
             RGBColor[
             0.4088283158597046, 0.5275690199007069, 0.9475362008014293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 96}], {
             RGBColor[
             0.3672380173898648, 0.4925048455688256, 0.9446210596256222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 105}], {
             RGBColor[
             0.30909022810020703`, 0.4403302488400713, 0.9409822033703782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 140}], {
             RGBColor[
             0.3285420686985767, 0.45898835972736407`, 0.9421553879924971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 149}], {
             RGBColor[
             0.3114795465639533, 0.4428415740370091, 0.9411182715222086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 171}], {
             RGBColor[
             0.3736817156213931, 0.4980860531072854, 0.9450316463789965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 245}], {
             RGBColor[
             0.37670637299800835`, 0.5007058593032094, 0.9452243748724349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 289}], {
             RGBColor[
             0.309996695985159, 0.44128300406053933`, 0.9410338253754271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 298}], {
             RGBColor[
             0.307131102255913, 0.43827108336196546`, 0.9408706340518126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 90}], {
             RGBColor[
             0.5208802713688769, 0.620561681786851, 0.9557981491382472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 123}], {
             RGBColor[
             0.5372173592410554, 0.6347120461758202, 0.9568391339311428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 158}], {
             RGBColor[
             0.5209230649967003, 0.6205987474764012, 0.9558008759103712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 233}], {
             RGBColor[
             0.8161512863791258, 0.8534670921405562, 0.7813047425304152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 257}], {
             RGBColor[
             0.5147596974188978, 0.6152603482603705, 0.9554081515783656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 259}], {
             RGBColor[
             0.5512374616169957, 0.646558430162153, 0.9578145787092965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 262}], {
             RGBColor[
             0.8160969055518104, 0.8533507770496733, 0.7753857250766871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 124}], {
             RGBColor[
             0.8391031020269322, 0.8749559056354701, 0.9735996156850079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 142}], {
             RGBColor[
             0.6947680744610263, 0.7614773672926725, 0.9702116467516284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 143}], {
             RGBColor[
             0.5636312232942053, 0.6537338940348352, 0.9601379235387875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 150}], {
             RGBColor[
             0.8462593507356758, 0.8802930242051693, 0.9614859532696918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 167}], {
             RGBColor[
             0.7422194299230214, 0.7985467268232416, 0.9749411544059516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 174}], {
             RGBColor[
             0.5614179437120186, 0.6518168625034114, 0.9599968953209368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 185}], {
             RGBColor[
             0.6492913495741017, 0.7248125960357876, 0.9664570141991338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 237}], {
             RGBColor[
             0.6846458552140906, 0.7535149764166593, 0.969240250390935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 239}], {
             RGBColor[
             0.5708233361978141, 0.6599633407458361, 0.9605961986132696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 282}], {
             RGBColor[
             0.8470847195516484, 0.8809085829167043, 0.9600888191549137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 283}], {
             RGBColor[
             0.6746177643537297, 0.7453737204958732, 0.9684508023443001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 295}], {
             RGBColor[
             0.7838985892899054, 0.8312466386518764, 0.9790582353871675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 297}], {
             RGBColor[
             0.7454557140194038, 0.8010749365560057, 0.9752637169598848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 99}], {
             RGBColor[
             0.3308920068686242, 0.45968772172522177`, 0.9423540428096366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[
             0.2896837321277139, 0.4218063478486378, 0.9398084320447715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 128}], {
             RGBColor[
             0.2667781164198233, 0.397731093439728, 0.9385039911160289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[
             0.3201380287875101, 0.4503731664220151, 0.9416688088356775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 201}], {
             RGBColor[
             0.3077043294157084, 0.43960372096206174`, 0.9408765445063949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 209}], {
             RGBColor[
             0.2797259704782522, 0.4113401089964994, 0.9392413522500229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 218}], {
             RGBColor[
             0.2751691719679872, 0.4065506248444982, 0.9389818493160426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 229}], {
             RGBColor[
             0.32034218545595194`, 0.4505499966670069, 0.9416818175180619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 261}], {
             RGBColor[
             0.3474685023612617, 0.4740454489620557, 0.9434102824444082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 284}], {
             RGBColor[
             0.2749699198453155, 0.406341198230256, 0.9389705022024235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 91}], {
             RGBColor[
             0.25932242623621204`, 0.38989469033869195`, 0.9380794005897775]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 162}], {
             RGBColor[
             0.26527957680517633`, 0.3961560332918348, 0.9384186515018654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 191}], {
             RGBColor[
             0.24496070190330402`, 0.37479960747889, 0.9372615216352855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 203}], {
             RGBColor[
             0.25281317669126346`, 0.38305305635669296`, 0.9377087084577643]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 206}], {
             RGBColor[
             0.2413530899135048, 0.3710077785417997, 0.9370560734694501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 244}], {
             RGBColor[
             0.2442718082387917, 0.3740755365591065, 0.9372222901602183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 270}], {
             RGBColor[
             0.23714390206690406`, 0.36658365523709874`, 0.9368163664485216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 118}], {
             RGBColor[
             0.17948494456776543`, 0.30598043511645023`, 0.9335327741177293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 120}], {
             RGBColor[
             0.1849774474258748, 0.3117534038651181, 0.9338455640300687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 130}], {
             RGBColor[
             0.17948366008578914`, 0.30597908504445237`, 0.9335327009683809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 176}], {
             RGBColor[
             0.17949609924511575`, 0.30599215938959284`, 0.9335334093601024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 193}], {
             RGBColor[
             0.2897690368730418, 0.4135053888596902, 0.9401205117129523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.17948366008578914`, 0.30597908504445237`, 0.9335327009683809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 220}], {
             RGBColor[
             0.21861602963741927`, 0.34710968657874874`, 0.9357612315231933]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 226}], {
             RGBColor[
             0.17948366519653014`, 0.30597909041616517`, 0.9335327012594301]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 236}], {
             RGBColor[
             0.4016254852173745, 0.5057768385746106, 0.9485224868513811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 266}], {
             RGBColor[
             0.21383713709575333`, 0.3420867675181703, 0.9354890806626834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 93}], {
             RGBColor[
             0.46307011169266854`, 0.5733948534802826, 0.9513117589171669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 103}], {
             RGBColor[
             0.33687382527310783`, 0.4634377566971172, 0.9427875991368931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 116}], {
             RGBColor[
             0.3586693068574145, 0.48508305918153105`, 0.9440750689675076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 119}], {
             RGBColor[
             0.3385777508483834, 0.465228690511853, 0.9428846351776731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 164}], {
             RGBColor[
             0.38942752096010885`, 0.5117242782844935, 0.9460349551717104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 168}], {
             RGBColor[
             0.3904018999447999, 0.5125682363873212, 0.9460970417390054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 241}], {
             RGBColor[
             0.3370030923017984, 0.46357362454027395`, 0.9427949607029437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[
             0.3720129129755694, 0.49664062013193266`, 0.9449253117500688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 103}], {
             RGBColor[
             0.2733233300214085, 0.4046105279255051, 0.9388767313478634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 116}], {
             RGBColor[
             0.2951188116057152, 0.426255830409919, 0.9401642011784779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 133}], {
             RGBColor[
             0.30898841648274356`, 0.43826898504779055`, 0.941047960136832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 152}], {
             RGBColor[
             0.26056294463292196`, 0.39119855382704327`, 0.9381500462772876]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 210}], {
             RGBColor[
             0.3231934350804644, 0.45057265819214215`, 0.941953091360874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 241}], {
             RGBColor[
             0.27345259705009906`, 0.4047463957686619, 0.938884092913914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 277}], {
             RGBColor[
             0.30846241772387, 0.4378133913603206, 0.9410144439610391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 180}], {
             RGBColor[
             0.26493370488523493`, 0.3957924999744301, 0.9383989546076965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[
             0.3818442604921369, 0.5035684061042389, 0.9457044452357559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 285}], {
             RGBColor[
             0.33930631085889784`, 0.4671186752480599, 0.9428849623189395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 100}], {
             RGBColor[
             0.9226285034001888, 0.6892957114983669, 0.45059538097393753`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 107}], {
             RGBColor[
             0.9146118486409361, 0.6276761900982359, 0.44291862332296067`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 127}], {
             RGBColor[
             0.9139243851963341, 0.6223920448146217, 0.4422603075520308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 137}], {
             RGBColor[
             0.9203214410888617, 0.6715626196123557, 0.4483861354991565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 192}], {
             RGBColor[
             0.930031406620387, 0.7358466203284666, 0.4572790883268795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 199}], {
             RGBColor[
             0.587001837836629, 0.6486359160132862, 0.81950285707449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 220}], {
             RGBColor[
             0.6261342073882591, 0.6897665175475827, 0.8217313876293025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 226}], {
             RGBColor[
             0.5870018429473699, 0.648635921384999, 0.8195028573655392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 228}], {
             RGBColor[
             0.9057099592960236, 0.9241653224619759, 0.8439169187539672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 266}], {
             RGBColor[
             0.6213553148465931, 0.6847435984870042, 0.8214592367687926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 281}], {
             RGBColor[
             0.9155765352150156, 0.6350911938349629, 0.44384240827575683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 126}], {
             RGBColor[
             0.22111352999763184`, 0.3497347178080009, 0.9359034604739869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 155}], {
             RGBColor[
             0.21429563561346426`, 0.34256867853076955`, 0.9355151914749793]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 156}], {
             RGBColor[
             0.221993745626472, 0.35065988024280614`, 0.935953587451887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 184}], {
             RGBColor[
             0.22686279734830417`, 0.3557775623181615, 0.9362308727443287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[
             0.21339436331142053`, 0.34162138419735716`, 0.9354638653506908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 202}], {
             RGBColor[
             0.22220476853383342`, 0.3508816786980681, 0.9359656048942807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 214}], {
             RGBColor[
             0.21458531177906248`, 0.342873146547343, 0.9355316881040727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 275}], {
             RGBColor[
             0.214533530595458, 0.34281872124025803`, 0.9355287392422698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 293}], {
             RGBColor[
             0.21277489873276917`, 0.34097028764887183`, 0.9354285877593523]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 89}], {
             RGBColor[
             0.2893752204809355, 0.4214820825471055, 0.9397908627628895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.35208222651696447`, 0.4786261706514128, 0.9436828617856419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 112}], {
             RGBColor[
             0.2764157065059942, 0.4078608116787981, 0.9390528376138995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 134}], {
             RGBColor[
             0.2873093787457973, 0.41931075190154404`, 0.9396732161322123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 144}], {
             RGBColor[
             0.30816373722776935`, 0.4405861826365669, 0.9408844144837296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 158}], {
             RGBColor[
             0.35212502014478775`, 0.47866323634096297`, 0.943685588557766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 159}], {
             RGBColor[
             0.27400586003393973`, 0.4053279102435776, 0.9389156004223643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 175}], {
             RGBColor[
             0.29756458350130965`, 0.4300896223171238, 0.940257234871823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 252}], {
             RGBColor[
             0.30057464185555743`, 0.4332533844961608, 0.9404286532421151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 253}], {
             RGBColor[
             0.29867167742904355`, 0.43125324822898137`, 0.9403202822332086]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 280}], {
             RGBColor[
             0.28433817175579457`, 0.41618782496964746`, 0.9395040102896386]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 292}], {
             RGBColor[
             0.2718397461725893, 0.40305118723574723`, 0.9387922434424387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[
             0.9571178936575444, 0.9648142409538079, 0.8234596411130128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 122}], {
             RGBColor[
             0.7719092053781459, 0.8222676877046737, 0.9778768984313139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 136}], {
             RGBColor[
             0.9562666668799304, 0.9629935529487204, 0.7308088595324563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 165}], {
             RGBColor[
             0.9499430145672961, 0.9419121380578821, 0.6850057931573457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 181}], {
             RGBColor[
             0.8167213708728744, 0.8575535758044224, 0.9821530921197811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 207}], {
             RGBColor[
             0.8326069689699811, 0.8699635257728993, 0.9837364200787462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 232}], {
             RGBColor[
             0.9568611020652522, 0.9642649897035074, 0.7955094610260169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 240}], {
             RGBColor[
             0.9572796113633043, 0.9651601387742601, 0.8410616153789832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 246}], {
             RGBColor[
             0.759246790508393, 0.811987768878119, 0.9768800667488129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 256}], {
             RGBColor[
             0.9574368195628593, 0.965496391216921, 0.8581727577239964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 296}], {
             RGBColor[
             0.8079306217366228, 0.8506861757670146, 0.9812769124001008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 299}], {
             RGBColor[
             0.9570551059778822, 0.9653678956255696, 0.8666323773215838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 107}], {
             RGBColor[
             0.9045073081884096, 0.5951795926664958, 0.26859915666912515`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 109}], {
             RGBColor[
             0.9480181265878662, 0.9334317685964351, 0.674604431944415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 110}], {
             RGBColor[
             0.9839067857429666, 0.9591178157514064, 0.561716366031505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 141}], {
             RGBColor[
             0.936935020626016, 0.7805800799358134, 0.2971516426609445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 165}], {
             RGBColor[
             0.9775639799613888, 0.9359801775610526, 0.3673407281472113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 179}], {
             RGBColor[
             0.9842570845883489, 0.9592626733262417, 0.5559110076191691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 240}], {
             RGBColor[
             0.984900576757397, 0.9592281782774306, 0.5233965503688487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 281}], {
             RGBColor[
             0.9054719947624891, 0.6025945964032228, 0.26952294162192125`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 149}], {
             RGBColor[
             0.2850281329082009, 0.41691301788689017`, 0.939543302556562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 187}], {
             RGBColor[
             0.3200183961394125, 0.4485879118406425, 0.9417227588366461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 227}], {
             RGBColor[
             0.2679362427515092, 0.39894835764378045`, 0.938569944697324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 264}], {
             RGBColor[
             0.2853843000396664, 0.4172873721243609, 0.939563585747797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 99}], {
             RGBColor[
             0.43585477652737337`, 0.5505550934269655, 0.9493751482779511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[
             0.7318152240398965, 0.7888182862268713, 0.9538534747537719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 198}], {
             RGBColor[
             0.48423825814620036`, 0.592165458504841, 0.9525401559859066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 201}], {
             RGBColor[
             0.41266709907445764`, 0.5304710926638055, 0.9478976499747094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 222}], {
             RGBColor[
             0.47017691950032614`, 0.5802832085890723, 0.9515621248783083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 258}], {
             RGBColor[
             0.7329940972360016, 0.7896974879262988, 0.9518579499321382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 260}], {
             RGBColor[
             0.6766874696871867, 0.7454723343623321, 0.9697937614112038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 261}], {
             RGBColor[
             0.4524312720200109, 0.5649128206637994, 0.9504313879127225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 278}], {
             RGBColor[
             0.553576335347311, 0.6484572332214837, 0.9579987034169237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 290}], {
             RGBColor[
             0.558574938782711, 0.6525153246748602, 0.9583922117898461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 111}], {
             RGBColor[
             0.26057341862775985`, 0.3912095626597075, 0.9381506427557986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 112}], {
             RGBColor[
             0.26517294299919314`, 0.39604395440077267`, 0.9384125788643654]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 175}], {
             RGBColor[
             0.28632181999450856`, 0.4182727650390983, 0.9396169761222888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 177}], {
             RGBColor[
             0.3486700459196015, 0.47359177071300174`, 0.9435415608547846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 242}], {
             RGBColor[
             0.2592824308416344, 0.3898526526431364, 0.9380771229112241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.27309540824899353`, 0.40437096769162195`, 0.9388637515401044]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 285}], {
             RGBColor[
             0.3304519019187142, 0.457812130049975, 0.9423807168287202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 123}], {
             RGBColor[
             0.4198835569183708, 0.5381037658666636, 0.9479755868517558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 134}], {
             RGBColor[
             0.3387736212750252, 0.46463798272782586`, 0.9429249564054306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 144}], {
             RGBColor[
             0.35962797975699734`, 0.48591341346284866`, 0.9441361547569478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 158}], {
             RGBColor[
             0.4035892626740157, 0.5239904671672448, 0.9469373288309841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 252}], {
             RGBColor[
             0.35203888438478537`, 0.4785806153224426, 0.9436803935153333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 253}], {
             RGBColor[
             0.3501359199582715, 0.4765804790552632, 0.9435720225064269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[
             0.39742589509621323`, 0.518652067951214, 0.9465446044989785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 102}], {
             RGBColor[
             0.3289676178309032, 0.4560161547537128, 0.9423048264494448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 162}], {
             RGBColor[
             0.27856959341816107`, 0.4101246833878033, 0.9391754982871572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 191}], {
             RGBColor[
             0.2582507185162887, 0.38876825757485856`, 0.9380183684205773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 203}], {
             RGBColor[
             0.2661031933042482, 0.39702170645266144`, 0.9384655552430561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 239}], {
             RGBColor[
             0.3418733579527955, 0.46719445818593675`, 0.9431271687979139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 153}], {
             RGBColor[
             0.26728945052082176`, 0.3982685380003319, 0.9385331108366297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 163}], {
             RGBColor[
             0.25122830224652154`, 0.3813872528284255, 0.937618452202748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 189}], {
             RGBColor[
             0.2464728493758267, 0.3763889703481986, 0.937347636196824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 211}], {
             RGBColor[
             0.2517282610763278, 0.3819127412577725, 0.9376469241184826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 216}], {
             RGBColor[
             0.25996759819388404`, 0.3905728069724701, 0.9381161421783205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 221}], {
             RGBColor[
             0.27785530490942656`, 0.40937392087661617`, 0.9391348206132799]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 94}], {
             RGBColor[
             0.6965792865266065, 0.7615288190518337, 0.9714662855765266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 160}], {
             RGBColor[
             0.5607147225279772, 0.6542524975154264, 0.9585606634045596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 164}], {
             RGBColor[
             0.45756686024315646`, 0.5686282136761757, 0.9509610966011381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 168}], {
             RGBColor[
             0.4585412392278475, 0.5694721717790032, 0.9510231831684333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 277}], {
             RGBColor[
             0.440152252258617, 0.5535445555236148, 0.9498514531794966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 124}], {
             RGBColor[
             0.9048214633960636, 0.926634777474092, 0.9800597975853467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 125}], {
             RGBColor[
             0.9272871440372241, 0.9396965749731525, 0.7126838428267497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 142}], {
             RGBColor[
             0.7604864358301577, 0.8131562391312941, 0.9766718286519673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 150}], {
             RGBColor[
             0.9119777121048072, 0.931971896043791, 0.9679461351700305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 200}], {
             RGBColor[
             0.8739725410077492, 0.7339874771388775, 0.6066396220475212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.7503642165832218, 0.805193848255281, 0.9757004322912739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 295}], {
             RGBColor[
             0.8496169506590368, 0.8829255104904983, 0.9855184172875062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 96}], {
             RGBColor[
             0.44705620926157014`, 0.5606800997756136, 0.9499720483653973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 105}], {
             RGBColor[
             0.3889084199719124, 0.5085055030468593, 0.9463331921101534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 109}], {
             RGBColor[
             0.7049075830694689, 0.7678615870686365, 0.9726151362943627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 138}], {
             RGBColor[
             0.5976652055170001, 0.6832651887274253, 0.9621432473760043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 140}], {
             RGBColor[
             0.4083602605702821, 0.527163613934152, 0.9475063767322723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 154}], {
             RGBColor[
             0.6149232954890904, 0.696747339779964, 0.9638633724984019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 171}], {
             RGBColor[
             0.45349990749309843`, 0.5662613073140733, 0.9503826351187716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 198}], {
             RGBColor[
             0.4764509321887418, 0.5858433564775396, 0.9519271091606205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 245}], {
             RGBColor[
             0.4565245648697137, 0.5688811135099974, 0.9505753636122101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 289}], {
             RGBColor[
             0.38981488785686436`, 0.5094582582673273, 0.9463848141152024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 105}], {
             RGBColor[
             0.3473181215020726, 0.473441328714978, 0.9434180509343462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 138}], {
             RGBColor[
             0.5560749070471602, 0.6482010143955439, 0.959228106200197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 140}], {
             RGBColor[
             0.36676996210044227`, 0.49209943960227065`, 0.9445912355564652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 171}], {
             RGBColor[
             0.4119096090232586, 0.5311971329821921, 0.9474674939429645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 196}], {
             RGBColor[
             0.34319916551880214`, 0.4691120448196677, 0.9431834824845483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 198}], {
             RGBColor[
             0.43486063371890193`, 0.5507791821456584, 0.9490119679848132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 222}], {
             RGBColor[
             0.4207992950730278, 0.5388969322298897, 0.948033936877215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 245}], {
             RGBColor[
             0.41493426639987385`, 0.5338169391781161, 0.9476602224364029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 278}], {
             RGBColor[
             0.5041987109200126, 0.6070709568623011, 0.9544705154158305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 289}], {
             RGBColor[
             0.3482245893870246, 0.47439408393544596`, 0.9434696729393952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 290}], {
             RGBColor[
             0.5091973143554127, 0.6111290483156775, 0.9548640237887529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 298}], {
             RGBColor[
             0.3453589956577786, 0.4713821632368721, 0.9433064816157806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 134}], {
             RGBColor[
             0.2657406017726479, 0.3966405997633186, 0.9384449061917377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 144}], {
             RGBColor[
             0.28659496025462, 0.4179160304983415, 0.9396561045432549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 159}], {
             RGBColor[
             0.2524370830607903, 0.3826577581053522, 0.9376872904818896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 235}], {
             RGBColor[
             0.24975979964424241`, 0.3798437634849875, 0.9375348231520031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 252}], {
             RGBColor[
             0.2790058648824081, 0.41058323235793537`, 0.9392003433016403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 292}], {
             RGBColor[
             0.25027096919944, 0.3803810350975218, 0.937563933501964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 122}], {
             RGBColor[
             0.5234999711581451, 0.6232114459734905, 0.9558598822602524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 160}], {
             RGBColor[
             0.5065135948101279, 0.6094211404266363, 0.9545226524909898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 178}], {
             RGBColor[
             0.34993177355877136`, 0.4745851224813026, 0.9436255999612144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 181}], {
             RGBColor[
             0.5683121366528735, 0.6584973340732392, 0.9601360759487196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 182}], {
             RGBColor[
             0.3649951509133196, 0.4904176871542194, 0.9444834370172861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 208}], {
             RGBColor[
             0.3543834762769441, 0.47926414429235664`, 0.9438791178453103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 246}], {
             RGBColor[
             0.5108375562883921, 0.6129315271469358, 0.9548630505777516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 296}], {
             RGBColor[
             0.559521387516622, 0.6516299340358314, 0.9592598962290395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 104}], {
             RGBColor[
             0.3262801186675095, 0.4548403348152493, 0.9420914025992604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 123}], {
             RGBColor[
             0.40185451909948444`, 0.5224879194737331, 0.9468267925043885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 157}], {
             RGBColor[
             0.35673441532730565`, 0.48340715338862666`, 0.9439517793901664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 201}], {
             RGBColor[
             0.34430071595550393`, 0.4726377079286733, 0.9431595150608838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[
             0.3117655585077827, 0.43958461181110975`, 0.9412648198705315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 222}], {
             RGBColor[
             0.4018105363813725, 0.5224498238539401, 0.9468239899644828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 229}], {
             RGBColor[
             0.3569385719957474, 0.4835839836336185, 0.9439647880725508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 257}], {
             RGBColor[
             0.37939685727732686`, 0.5030362215582833, 0.9453958101516111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 259}], {
             RGBColor[
             0.41587462147542475`, 0.5343343034600658, 0.9478022372825421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 261}], {
             RGBColor[
             0.38406488890105717`, 0.5070794359286672, 0.9456932529988971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 121}], {
             RGBColor[
             0.9223952272310946, 0.6887967573605129, 0.4252047095816714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 125}], {
             RGBColor[
             0.9214027485620356, 0.686673945842382, 0.31717953132296794`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 127}], {
             RGBColor[
             0.8414762129232649, 0.3198099242864162, 0.18735097437698822`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 136}], {
             RGBColor[
             0.9215440004534805, 0.6869760693554257, 0.33255392800111494`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 137}], {
             RGBColor[
             0.8478732688157926, 0.3689804990841502, 0.19347680232411396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 170}], {
             RGBColor[
             0.8360368854877944, 0.2780008700889096, 0.18214226828194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 192}], {
             RGBColor[
             0.857583234347318, 0.43326449980026105`, 0.20236975515183697`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 228}], {
             RGBColor[
             0.8332617870229544, 0.6215832019337704, 0.5890075855789246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 232}], {
             RGBColor[
             0.9221384356388024, 0.6882475061102127, 0.3972545294946756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 240}], {
             RGBColor[
             0.9225569449368545, 0.6891426551809652, 0.4428066838476417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 256}], {
             RGBColor[
             0.9227141531364094, 0.6894789076236262, 0.45991782619265503`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 299}], {
             RGBColor[
             0.9223324395514323, 0.6893504120322749, 0.46837744579024243`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 108}], {
             RGBColor[
             0.44525533808141193`, 0.5575469670447641, 0.9502920083081179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 114}], {
             RGBColor[
             0.4255007228362041, 0.540035729338632, 0.9490479363174081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 187}], {
             RGBColor[
             0.4552598760386822, 0.566212394980653, 0.9509294886200896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 205}], {
             RGBColor[
             0.5380185348092877, 0.6358267098737893, 0.9567739363684693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 207}], {
             RGBColor[
             0.6460892652174881, 0.7219820565313749, 0.9663628314965813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 213}], {
             RGBColor[
             0.48723449014775655`, 0.5939071986311, 0.9529668827570787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 231}], {
             RGBColor[
             0.49585480302230733`, 0.6013736803735128, 0.9535161614708018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 133}], {
             RGBColor[
             0.36773492193593726`, 0.4929352393114849, 0.9446527219439024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 142}], {
             RGBColor[
             0.5221732711977142, 0.6208612990518254, 0.9562111960106483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 162}], {
             RGBColor[
             0.3349247683998675, 0.4622774977068556, 0.9426440773615328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[
             0.4766965463107896, 0.5841965277949407, 0.9524565634581535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 210}], {
             RGBColor[
             0.3819399405336581, 0.5052389124558365, 0.9455578531679444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 237}], {
             RGBColor[
             0.5120510519507784, 0.6128989081758123, 0.9552397996499549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 239}], {
             RGBColor[
             0.398228532934502, 0.519347272504989, 0.9465957478722895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 295}], {
             RGBColor[
             0.6113037860265932, 0.6906305704110295, 0.9650577846461873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 116}], {
             RGBColor[
             0.3006123597209014, 0.43202989779004775`, 0.9404770506166615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 119}], {
             RGBColor[
             0.28052080371187027`, 0.4121755291203697, 0.939286616826827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 152}], {
             RGBColor[
             0.26605649274810816`, 0.396972621207172, 0.9384628957154713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 164}], {
             RGBColor[
             0.33137057382359575`, 0.4586711168930102, 0.9424369368208644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 168}], {
             RGBColor[
             0.3323449528082868, 0.45951507499583777`, 0.9424990233881594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 241}], {
             RGBColor[
             0.2789461451652853, 0.41052046314879065`, 0.9391969423520976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 277}], {
             RGBColor[
             0.3139559658390563, 0.44358745874044936`, 0.9413272933992227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 128}], {
             RGBColor[
             0.26216622821870855`, 0.39288370652975557`, 0.9382413509056526]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 157}], {
             RGBColor[
             0.3155261405863954, 0.44552577951204275`, 0.9414061686253012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 173}], {
             RGBColor[
             0.2711227338075005, 0.40229756177882925`, 0.9387514106489717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 201}], {
             RGBColor[
             0.30309244121459367`, 0.43475633405208935`, 0.9406139042960187]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 209}], {
             RGBColor[
             0.2751140822771375, 0.4064927220865271, 0.9389787120396467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 218}], {
             RGBColor[
             0.2705572837668725, 0.40170323793452584`, 0.9387192091056663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 229}], {
             RGBColor[
             0.3157302972548372, 0.4457026097570346, 0.9414191773076857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 261}], {
             RGBColor[
             0.34285661416014696`, 0.46919806205208336`, 0.9431476422340319]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 279}], {
             RGBColor[
             0.27193222945827744`, 0.4031483930327844, 0.9387975102287419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 129}], {
             RGBColor[
             0.2625398824694277, 0.39327644083830926`, 0.9382626299624591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 140}], {
             RGBColor[
             0.3086221728107845, 0.4399248428735164, 0.9409523793012212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 149}], {
             RGBColor[
             0.29155965067616113`, 0.4237780571831614, 0.9399152628309327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 171}], {
             RGBColor[
             0.3537618197336009, 0.4790225362534377, 0.9438286376877205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 196}], {
             RGBColor[
             0.28505137622914434`, 0.4169374480909134, 0.9395446262293043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 230}], {
             RGBColor[
             0.2692612582166467, 0.40034103290847267`, 0.938645402367879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 245}], {
             RGBColor[
             0.35678647711021616`, 0.4816423424493619, 0.944021366181159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 263}], {
             RGBColor[
             0.2750769487244079, 0.40645369236820506`, 0.9389765973387527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 289}], {
             RGBColor[
             0.2900768000973668, 0.42221948720669167`, 0.9398308166841512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 298}], {
             RGBColor[
             0.2872112063681208, 0.41920756650811786`, 0.9396676253605367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 151}], {
             RGBColor[
             0.5499711557200619, 0.645038448022178, 0.9579401200370031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 167}], {
             RGBColor[
             0.7052976145619072, 0.7697031240469493, 0.9712611329047376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 194}], {
             RGBColor[
             0.5862509789073218, 0.6747647734348481, 0.960720844348837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 215}], {
             RGBColor[
             0.8258859987463416, 0.8619784867738793, 0.84861498208911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 283}], {
             RGBColor[
             0.6376959489926155, 0.716530117719581, 0.9647707808430861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 286}], {
             RGBColor[
             0.6078523188068897, 0.6923017142945901, 0.9624213809540463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 297}], {
             RGBColor[
             0.7085338986582898, 0.7722313337797134, 0.9715836954586705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 110}], {
             RGBColor[
             0.9135464991631714, 0.6274127712548101, 0.4734497418593211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 127}], {
             RGBColor[
             0.8334595581640123, 0.25819040288628525`, 0.17967421672601133`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 141}], {
             RGBColor[
             0.8665747340462209, 0.44887503543921714`, 0.2088850184887606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 165}], {
             RGBColor[
             0.9072036933815937, 0.6042751330644562, 0.27907410397502735`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.9138967980085537, 0.6275576288296454, 0.4676443834469852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 240}], {
             RGBColor[
             0.9145402901776019, 0.6275231337808342, 0.4351299261966648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 281}], {
             RGBColor[
             0.835111708182694, 0.27088955190662645`, 0.18125631744973736`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 114}], {
             RGBColor[
             0.32416580444258236`, 0.4547970767096937, 0.9418912109282782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 145}], {
             RGBColor[
             0.3065621353882716, 0.43629450439653, 0.9408887080179298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 169}], {
             RGBColor[
             0.3184727377256654, 0.44881330262893604`, 0.9415669992008873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 187}], {
             RGBColor[
             0.35392495764506043`, 0.4809737423517148, 0.9437727632309596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 205}], {
             RGBColor[
             0.436683616415666, 0.5505880572448512, 0.9496172109793394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 213}], {
             RGBColor[
             0.3858995717541348, 0.5086685460021616, 0.9458101573679487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 219}], {
             RGBColor[
             0.30907770812291846`, 0.4389385308371674, 0.9410319661637115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 221}], {
             RGBColor[
             0.3192668900954462, 0.449648007121744, 0.9416122250035031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 264}], {
             RGBColor[
             0.3192908615453144, 0.4496732026354332, 0.9416135901421105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 110}], {
             RGBColor[
             0.9570573175626281, 0.9656649471847494, 0.8794550171346109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 138}], {
             RGBColor[
             0.8139262808550589, 0.8553825016885668, 0.9818711941291625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 154}], {
             RGBColor[
             0.8311843708271494, 0.8688646527411055, 0.9835913192515602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 179}], {
             RGBColor[
             0.9574076164080104, 0.9658098047595847, 0.8736496587222751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 258}], {
             RGBColor[
             0.941467846616602, 0.9554926988601389, 0.9709728498600104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 138}], {
             RGBColor[
             0.8498149400101593, 0.8810685488435381, 0.8689831282162525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 141}], {
             RGBColor[
             0.9459742116007779, 0.8128132585241278, 0.5020022278511405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 154}], {
             RGBColor[
             0.8670730299822498, 0.8945506998960768, 0.8707032533386501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 165}], {
             RGBColor[
             0.9866031709361507, 0.9682133561493669, 0.5721913133374072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 179}], {
             RGBColor[
             0.9932962755631108, 0.991495851914556, 0.7607615928093651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 281}], {
             RGBColor[
             0.914511185737251, 0.6348277749915371, 0.4743735268121172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 190}], {
             RGBColor[
             0.2355732429285669, 0.36493279289716524`, 0.9367269197341752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 212}], {
             RGBColor[
             0.2273675902370908, 0.3563081316499939, 0.936259619952571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 242}], {
             RGBColor[
             0.24172339249525976`, 0.3713969900337639, 0.9370771616536675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 250}], {
             RGBColor[
             0.2327988220725642, 0.3620167006690641, 0.9365689205708136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 280}], {
             RGBColor[
             0.2555363699026189, 0.38591530508224947`, 0.9378637902825477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 115}], {
             RGBColor[
             0.236902386747869, 0.36632980732383724`, 0.9368026125083924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 134}], {
             RGBColor[
             0.2631071012640549, 0.3938726237552112, 0.9382949322336882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 146}], {
             RGBColor[
             0.24133200131587673`, 0.37098561308859834`, 0.937054872505013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 159}], {
             RGBColor[
             0.24980358255219737`, 0.3798897820972448, 0.9375373165238401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 175}], {
             RGBColor[
             0.27336230601956724`, 0.40465149417079094`, 0.9388789509732987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 204}], {
             RGBColor[
             0.24154807064065673`, 0.37121271564852854`, 0.9370671773334133]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 235}], {
             RGBColor[
             0.24712629913564943`, 0.3770757874768801, 0.9373848491939536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 242}], {
             RGBColor[
             0.24632291686669305`, 0.37623138177482907`, 0.937339097762234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 252}], {
             RGBColor[
             0.27637236437381507`, 0.40781525634982796`, 0.9390503693435908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 253}], {
             RGBColor[
             0.2744693999473012, 0.40581512008264853`, 0.9389419983346845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 280}], {
             RGBColor[
             0.2601358942740522, 0.3907496968233146, 0.9381257263911142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 292}], {
             RGBColor[
             0.24763746869084696`, 0.3776130590894144, 0.9374139595439145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 135}], {
             RGBColor[
             0.9747525126984742, 0.9797102206225822, 0.8836982332246824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 224}], {
             RGBColor[
             0.9644670009376046, 0.9390549690861945, 0.644851681061125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 249}], {
             RGBColor[
             0.8889946281823045, 0.5565337231850392, 0.5595095853153444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 254}], {
             RGBColor[
             0.925365599889266, 0.7843240503848107, 0.5923111720047104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 258}], {
             RGBColor[
             0.9605881616295711, 0.9701272959910724, 0.9515981414941335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 260}], {
             RGBColor[
             0.9042815340807562, 0.9259021424271057, 0.969533952973199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 278}], {
             RGBColor[
             0.7811703997408805, 0.8288870412862575, 0.957738894978919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 288}], {
             RGBColor[
             0.9106552013287734, 0.717527566222487, 0.5800364548609709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 290}], {
             RGBColor[
             0.7861690031762806, 0.8329451327396338, 0.9581324033518415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 145}], {
             RGBColor[
             0.28680752014306377`, 0.4187832666903979, 0.9396446360272199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 169}], {
             RGBColor[
             0.2987181224804576, 0.4313020649228039, 0.9403229272101774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 187}], {
             RGBColor[
             0.33417034239985266`, 0.4634625046455827, 0.9425286912402498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 213}], {
             RGBColor[
             0.366144956508927, 0.49115730829602955`, 0.944566085377239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 219}], {
             RGBColor[
             0.28932309287771063`, 0.4214272931310352, 0.9397878941730018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 221}], {
             RGBColor[
             0.29951227485023835`, 0.4321367694156119, 0.9403681530127932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 231}], {
             RGBColor[
             0.37476526938347776`, 0.4986237900384425, 0.945115364090962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 264}], {
             RGBColor[
             0.29953624630010656`, 0.4321619649293011, 0.9403695181514007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 132}], {
             RGBColor[
             0.21415169536183348`, 0.34241738819996653`, 0.9355069942905895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 146}], {
             RGBColor[
             0.22602095903949393`, 0.35489273687997036`, 0.9361829312980301]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 159}], {
             RGBColor[
             0.23449254027581456`, 0.3637969058886168, 0.9366653753168572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 204}], {
             RGBColor[
             0.22623702836427392`, 0.35511983943990055`, 0.9361952361264305]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 242}], {
             RGBColor[
             0.23101187459031025`, 0.36013850556620103`, 0.9364671565552513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 243}], {
             RGBColor[
             0.21987898042507611`, 0.348437127932281, 0.9358331547021821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 294}], {
             RGBColor[
             0.2157444487404361, 0.3440914729872748, 0.9355976992392334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 119}], {
             RGBColor[
             0.30231628529617693`, 0.4338208316047836, 0.9405740866574415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 133}], {
             RGBColor[
             0.3362774461822365, 0.4656883549123332, 0.9426482794056301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 152}], {
             RGBColor[
             0.2878519743324149, 0.4186179236915859, 0.9397503655460857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 164}], {
             RGBColor[
             0.35316605540790247`, 0.4803164193774241, 0.9437244066514788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 168}], {
             RGBColor[
             0.35414043439259346`, 0.4811603774802517, 0.9437864932187738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 210}], {
             RGBColor[
             0.35048246477995726`, 0.4779920280566848, 0.9435534106296721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 241}], {
             RGBColor[
             0.30074162674959204`, 0.4321657656332045, 0.9404844121827121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 277}], {
             RGBColor[
             0.33575144742336294`, 0.46523276122486323`, 0.9426147632298372]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 161}], {
             RGBColor[
             0.20987266837087443`, 0.33791985952648745`, 0.9352633100337076]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 120}], {
             RGBColor[
             0.1844220718220619, 0.3111696688926636, 0.9338139362110361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 130}], {
             RGBColor[
             0.17892828448197629`, 0.3053953500719979, 0.9335010731493483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 176}], {
             RGBColor[
             0.17894072364130287`, 0.30540842441713845`, 0.9335017815410699]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[
             0.17892828448197629`, 0.3053953500719979, 0.9335010731493483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 220}], {
             RGBColor[
             0.21806065403360642`, 0.34652595160629435`, 0.9357296037041608]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 226}], {
             RGBColor[
             0.17892828959271728`, 0.30539535544371077`, 0.9335010734403975]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 228}], {
             RGBColor[
             0.49763640594137093`, 0.5809247565206876, 0.9579151348288255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 266}], {
             RGBColor[
             0.21328176149194045`, 0.3415030325457159, 0.9354574528436509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 152}], {
             RGBColor[
             0.2677604183233837, 0.39876355502190786`, 0.9385599317562512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 164}], {
             RGBColor[
             0.33307449939887124`, 0.46046205070774604`, 0.9425339728616443]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 168}], {
             RGBColor[
             0.3340488783835623, 0.46130600881057365`, 0.9425960594289393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 241}], {
             RGBColor[
             0.2806500707405608, 0.4123113969635265, 0.9392939783928775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 130}], {
             RGBColor[
             0.18442078734008566`, 0.31116831882066576`, 0.9338138630616879]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 176}], {
             RGBColor[
             0.18443322649941224`, 0.31118139316580623`, 0.9338145714534094]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 287}], {
             RGBColor[
             0.5654447927305568, 0.5603176274195498, 0.6027460190921992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 125}], {
             RGBColor[
             0.9936176446660105, 0.9887571122327337, 0.5466981931057444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 127}], {
             RGBColor[
             0.9136911090272399, 0.6218930906767679, 0.41686963615976463`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 136}], {
             RGBColor[
             0.9937588965574554, 0.9890592357457773, 0.5620725897838914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 137}], {
             RGBColor[
             0.9200881649197675, 0.6710636654745018, 0.4229954641068904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 160}], {
             RGBColor[
             0.7924150587076538, 0.8345430649548763, 0.8078033989134862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 181}], {
             RGBColor[
             0.8542136005503994, 0.8836192586014792, 0.8134168223712162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 232}], {
             RGBColor[
             0.9943533317427773, 0.9903306725005643, 0.626773191277452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 240}], {
             RGBColor[
             0.9947718410408293, 0.9912258215713169, 0.6723253456304181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 246}], {
             RGBColor[
             0.796739020185918, 0.8380534516751759, 0.8081437970002479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 256}], {
             RGBColor[
             0.9949290492403844, 0.9915620740139779, 0.6894364879754314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 296}], {
             RGBColor[
             0.8454228514141477, 0.8767518585640715, 0.8125406426515358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 299}], {
             RGBColor[
             0.9945473356554072, 0.9914335784226265, 0.6978961075730188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 136}], {
             RGBColor[
             0.8085502082780569, 0.8465126824966431, 0.7164898471021924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 160}], {
             RGBColor[
             0.6072063704282553, 0.6919965117057422, 0.9622206562317872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 181}], {
             RGBColor[
             0.6690049122710009, 0.741072705352345, 0.9678340796895172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 207}], {
             RGBColor[
             0.6848905103681076, 0.7534826553208219, 0.9694174076484823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 231}], {
             RGBColor[
             0.5346560481729267, 0.6328742791629598, 0.9565707376227028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 232}], {
             RGBColor[
             0.8091446434633787, 0.8477841192514302, 0.781190448595753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 240}], {
             RGBColor[
             0.8095631527614308, 0.8486792683221828, 0.8267426029487193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 246}], {
             RGBColor[
             0.6115303319065195, 0.6955068984260417, 0.962561054318549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 256}], {
             RGBColor[
             0.8097203609609858, 0.8490155207648438, 0.8438537452937325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 296}], {
             RGBColor[
             0.6602141631347492, 0.7342053053149373, 0.9669578999698369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 299}], {
             RGBColor[
             0.8093386473760087, 0.8488870251734923, 0.8523133648913199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 144}], {
             RGBColor[
             0.3759650676291757, 0.5000637778518178, 0.9451771395498434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 157}], {
             RGBColor[
             0.3911005410183704, 0.5131733641705265, 0.9461415585304294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 229}], {
             RGBColor[
             0.3913046976868122, 0.5133501944155183, 0.9461545672128138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 257}], {
             RGBColor[
             0.41376298296839165`, 0.5328024323401832, 0.9475855892918741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 259}], {
             RGBColor[
             0.4502407471664895, 0.5641005142419657, 0.9499920164228051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 261}], {
             RGBColor[
             0.41843101459212195`, 0.5368456467105671, 0.9478830321391599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 125}], {
             RGBColor[
             0.970159485355791, 0.9735725032155419, 0.706048969605638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 142}], {
             RGBColor[
             0.8033587771487245, 0.8470321673736835, 0.9700369554308557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 150}], {
             RGBColor[
             0.9548500534233739, 0.9658478242861803, 0.9613112619489188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 200}], {
             RGBColor[
             0.916844882326316, 0.7678634053812667, 0.6000047488264095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 237}], {
             RGBColor[
             0.7932365579017887, 0.8390697764976703, 0.9690655590701622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 282}], {
             RGBColor[
             0.9556754222393467, 0.9664633829977154, 0.9599141278341408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 295}], {
             RGBColor[
             0.8924892919776035, 0.9168014387328876, 0.9788835440663946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 136}], {
             RGBColor[
             0.9927664178883965, 0.9869364242276462, 0.4540474115251879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 150}], {
             RGBColor[
             0.9773157340645346, 0.9789096217852411, 0.6939353071903218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[
             0.9072593029227105, 0.5779612249611302, 0.303635751806013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 192}], {
             RGBColor[
             0.9288056517822338, 0.7332248546724817, 0.32386323867590994`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 195}], {
             RGBColor[
             0.9058844617461582, 0.5673935932189047, 0.3023192023426855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 200}], {
             RGBColor[
             0.9393105629674767, 0.7809252028803274, 0.3326287940678124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 256}], {
             RGBColor[
             0.9939365705713255, 0.9894392624958468, 0.5814113097167279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 299}], {
             RGBColor[
             0.9935548569863483, 0.9893107669044954, 0.5898709293143154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 155}], {
             RGBColor[
             0.21912067898952223`, 0.3476401050444259, 0.9357899705572339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 163}], {
             RGBColor[
             0.23364896427549098`, 0.3629102540264691, 0.9366173349115978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 184}], {
             RGBColor[
             0.23168784072436213`, 0.3608489888318178, 0.9365056518265833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 189}], {
             RGBColor[
             0.22889351140479614`, 0.3579119715462422, 0.9363465189056738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 197}], {
             RGBColor[
             0.21821940668747852`, 0.34669281071101354`, 0.9357386444329454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 214}], {
             RGBColor[
             0.21941035515512047`, 0.34794457306099935`, 0.9358064671863272]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 216}], {
             RGBColor[
             0.24238826022285348`, 0.3720958081705137, 0.9371150248871702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 275}], {
             RGBColor[
             0.21935857397151598`, 0.34789014775391436`, 0.9358035183245244]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 293}], {
             RGBColor[
             0.21759994210882713`, 0.34604171416252816`, 0.9357033668416068]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 136}], {
             RGBColor[
             0.9128398822496258, 0.6200724026716804, 0.3242188545792082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 137}], {
             RGBColor[
             0.8391691506119379, 0.30207683240040506`, 0.18514172890220718`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 141}], {
             RGBColor[
             0.8658872706016187, 0.44359089015560293`, 0.2082267027178307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 165}], {
             RGBColor[
             0.9065162299369915, 0.5989909877808421, 0.27841578820409746`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 170}], {
             RGBColor[
             0.8273327672839398, 0.21109720340516447`, 0.1738071948600332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 192}], {
             RGBColor[
             0.8488791161434632, 0.3663608331165159, 0.19403468172993021`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 228}], {
             RGBColor[
             0.8245576688190998, 0.5546795352500253, 0.5806725121570179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 232}], {
             RGBColor[
             0.9134343174349477, 0.6213438394264674, 0.3889194560727688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 240}], {
             RGBColor[
             0.9138528267329997, 0.6222389884972201, 0.4344716104257349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 256}], {
             RGBColor[
             0.9140100349325547, 0.622575240939881, 0.4515827527707482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 281}], {
             RGBColor[
             0.8344242447380918, 0.2656054066230123, 0.18059800167880746`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 299}], {
             RGBColor[
             0.9136283213475775, 0.6224467453485296, 0.4600423723683357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 173}], {
             RGBColor[
             0.24821711809960986`, 0.3782223073699194, 0.9374469697202291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 209}], {
             RGBColor[
             0.25220846656924684`, 0.38241746767761725`, 0.9376742711109041]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 218}], {
             RGBColor[
             0.24765166805898178`, 0.377627983525616, 0.9374147681769237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 276}], {
             RGBColor[
             0.235521079118485, 0.3648779654253926, 0.9367239490823606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 279}], {
             RGBColor[
             0.24902661375038676`, 0.3790731386238746, 0.9374930692999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 161}], {
             RGBColor[
             0.22609023535273692`, 0.35496555067756064`, 0.9361868764815843]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 230}], {
             RGBColor[
             0.2426308084736596, 0.3723507417605582, 0.9371288376512357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 263}], {
             RGBColor[
             0.24844649898142085`, 0.37846340122029065`, 0.9374600326221096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 265}], {
             RGBColor[
             0.22918762870603976`, 0.3582211074779632, 0.936363268450872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 269}], {
             RGBColor[
             0.23146736458154496`, 0.36061725442672216`, 0.9364930960364151]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 289}], {
             RGBColor[
             0.26344635035437974`, 0.39422919605877726`, 0.9383142519675081]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 298}], {
             RGBColor[
             0.26058075662513375`, 0.3912172753602034, 0.9381510606438935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 176}], {
             RGBColor[
             0.17893943915932659`, 0.3054070743451405, 0.9335017083917216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 199}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 220}], {
             RGBColor[
             0.21805936955163013`, 0.34652460153429643`, 0.9357295305548126]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 226}], {
             RGBColor[
             0.178927005110741, 0.3053940053717128, 0.9335010002910491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 228}], {
             RGBColor[
             0.49763512145939465`, 0.5809234064486897, 0.9579150616794772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 266}], {
             RGBColor[
             0.21328047700996416`, 0.3415016824737179, 0.9354573796943026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 139}], {
             RGBColor[
             0.29015495986038786`, 0.4208144502573191, 0.9398897209981389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 143}], {
             RGBColor[
             0.3607906299670138, 0.4869204426382663, 0.9442102378002388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 172}], {
             RGBColor[
             0.297163306859998, 0.4281806673087738, 0.9402888359918464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 174}], {
             RGBColor[
             0.3585773503848271, 0.4850034111068425, 0.9440692095823882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 183}], {
             RGBColor[
             0.2897103519915022, 0.4203471391973532, 0.9398644012377442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 283}], {
             RGBColor[
             0.47177717102653804`, 0.5785602690993044, 0.9525231166057517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 188}], {
             RGBColor[
             0.20621351468350757`, 0.3340738569973212, 0.9350549266444448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 212}], {
             RGBColor[
             0.20921642322248857`, 0.3372301042671883, 0.9352259378433346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 243}], {
             RGBColor[
             0.21243933131542342`, 0.34061758501703826`, 0.935409477691362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 294}], {
             RGBColor[
             0.2083047996307834, 0.33627193007203204`, 0.9351740222284133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 162}], {
             RGBColor[
             0.31733689752319516`, 0.44704376794557543`, 0.9415233937816148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 164}], {
             RGBColor[
             0.36703566028493084`, 0.49232957401529565`, 0.9446081656098331]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 210}], {
             RGBColor[
             0.36435206965698563`, 0.49000518269455634`, 0.9444371695880264]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 239}], {
             RGBColor[
             0.38064066205782954`, 0.5041135427437089, 0.9454750642923715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 241}], {
             RGBColor[
             0.3146112316266204, 0.4441789202710761, 0.9413681711410662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 277}], {
             RGBColor[
             0.3496210523003913, 0.4772459158627348, 0.9434985221881913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 144}], {
             RGBColor[
             0.29485513198583013`, 0.42659799471298, 0.9401265091035182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 159}], {
             RGBColor[
             0.26069725479200045`, 0.3913397223199907, 0.9381576950421531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 175}], {
             RGBColor[
             0.2842559782593704, 0.41610143439353686`, 0.9394993294916116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 204}], {
             RGBColor[
             0.25244174288045984`, 0.38266265587127446`, 0.9376875558517261]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 235}], {
             RGBColor[
             0.2580199713754525, 0.388525727699626, 0.9380052277122666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 252}], {
             RGBColor[
             0.28726603661361816`, 0.4192651965725739, 0.9396707478619037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 253}], {
             RGBColor[
             0.2853630721871043, 0.41726506030539445`, 0.9395623768529974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 292}], {
             RGBColor[
             0.2585311409306501, 0.3890629993121603, 0.9380343380622274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 224}], {
             RGBColor[
             0.9798102252026126, 0.9495170954171317, 0.5749562479700403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 249}], {
             RGBColor[
             0.9043378524473125, 0.5669958495159765, 0.4896141522242598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 254}], {
             RGBColor[
             0.940708824154274, 0.7947861767157479, 0.5224157389136257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 258}], {
             RGBColor[
             0.9759313858945792, 0.9805894223220096, 0.8817027084030489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 260}], {
             RGBColor[
             0.9196247583457642, 0.9363642687580429, 0.8996385198821143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 288}], {
             RGBColor[
             0.9259984255937815, 0.7279896925534243, 0.5101410217698862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 137}], {
             RGBColor[
             0.9192369381421535, 0.6692429774694144, 0.3303446825263339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 165}], {
             RGBColor[
             0.9865840174672071, 0.9661571328498515, 0.42361874182822423`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 181}], {
             RGBColor[
             0.8533623737727853, 0.8817985705963918, 0.7207660407906598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 232}], {
             RGBColor[
             0.9935021049651632, 0.9885099844954769, 0.5341224096968956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 240}], {
             RGBColor[
             0.9939206142632153, 0.9894051335662295, 0.5796745640498617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 256}], {
             RGBColor[
             0.9940778224627702, 0.9897413860088904, 0.596785706394875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 296}], {
             RGBColor[
             0.8445716246365338, 0.8749311705589841, 0.7198898610709794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 299}], {
             RGBColor[
             0.9936961088777931, 0.9896128904175391, 0.6052453259924624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 170}], {
             RGBColor[
             0.8337298231764674, 0.2602677782028984, 0.17993302280715895`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 192}], {
             RGBColor[
             0.8552761720359909, 0.4155314079142499, 0.20016050967705595`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 195}], {
             RGBColor[
             0.8323549819999152, 0.24970014646067296`, 0.17861647334383152`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 220}], {
             RGBColor[
             0.5513789728038629, 0.36945130513336594`, 0.564612808979479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 228}], {
             RGBColor[
             0.8309547247116273, 0.6038501100477591, 0.5867983401041436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 232}], {
             RGBColor[
             0.9198313733274753, 0.6705144142242014, 0.3950452840198946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 256}], {
             RGBColor[
             0.9204070908250823, 0.671745815737615, 0.457708580717874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 266}], {
             RGBColor[
             0.546600080262197, 0.3644283860727875, 0.564340658118969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 299}], {
             RGBColor[
             0.9200253772401052, 0.6716173201462636, 0.46616820031546136`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 154}], {
             RGBColor[
             0.7239419932746806, 0.7842682543998942, 0.9731194303332016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 171}], {
             RGBColor[
             0.5625186052786886, 0.6537822219340037, 0.9596386929535714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 245}], {
             RGBColor[
             0.5655432626553039, 0.6564020281299278, 0.9598314214470098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 258}], {
             RGBColor[
             0.8342254690641332, 0.8708963005189276, 0.9605009609416519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 147}], {
             RGBColor[
             0.2408356632285271, 0.3704639302891415, 0.9370266067852049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 148}], {
             RGBColor[
             0.24714609636833407`, 0.37709659562364867`, 0.9373859766170676]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 172}], {
             RGBColor[
             0.26248705403553485`, 0.3932209148047717, 0.9382596214613016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 183}], {
             RGBColor[
             0.2550340991670391, 0.38538738669335115`, 0.9378351867071995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 206}], {
             RGBColor[
             0.2460762386198535, 0.3759721072970965, 0.9373250498010044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 244}], {
             RGBColor[
             0.2489949569451404, 0.37903986531440326`, 0.9374912664917726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 272}], {
             RGBColor[
             0.23937950956716447`, 0.3689334204655748, 0.9369436809883765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 149}], {
             RGBColor[
             0.3110114912745308, 0.4424361680704541, 0.9410884474530516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 171}], {
             RGBColor[
             0.37321366033197056`, 0.49768064714073046`, 0.9450018223098395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 196}], {
             RGBColor[
             0.304503216827514, 0.4355955589782061, 0.9407178108514234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 198}], {
             RGBColor[
             0.3961646850276139, 0.5172626963041967, 0.9465462963516883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 222}], {
             RGBColor[
             0.3821033463817397, 0.505380446388428, 0.94556826524409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 230}], {
             RGBColor[
             0.2887130988150164, 0.4189991437957653, 0.9398185869899978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 245}], {
             RGBColor[
             0.37623831770858585`, 0.5003004533366545, 0.945194550803278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 263}], {
             RGBColor[
             0.2945287893227776, 0.42511180325549774`, 0.9401497819608717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 289}], {
             RGBColor[
             0.3095286406957365, 0.4408775980939844, 0.9410040013062702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 298}], {
             RGBColor[
             0.3066630469664905, 0.4378656773954105, 0.9408408099826556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 165}], {
             RGBColor[
             0.9396314058192, 0.789675620333774, 0.3076265899668467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 179}], {
             RGBColor[
             0.9463245104461602, 0.8129581160989631, 0.4961968694388046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 232}], {
             RGBColor[
             0.9465494933171561, 0.8120284719793993, 0.41813025783551805`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[
             0.9469680026152082, 0.812923621050152, 0.46368241218848416`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 281}], {
             RGBColor[
             0.8675394206203003, 0.45629003917594413`, 0.20980880344155672`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[
             0.810515025857468, 0.8523692859433827, 0.9579232930155395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 185}], {
             RGBColor[
             0.6135470246958941, 0.696888857774001, 0.9628943539449815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 210}], {
             RGBColor[
             0.5187904189187625, 0.6179312424348968, 0.9559956436547723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 237}], {
             RGBColor[
             0.6489015303358828, 0.7255912381548726, 0.9656775901367828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 239}], {
             RGBColor[
             0.5350790113196064, 0.6320396024840493, 0.9570335383591173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 282}], {
             RGBColor[
             0.8113403946734408, 0.8529848446549176, 0.9565261589007614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 283}], {
             RGBColor[
             0.6388734394755219, 0.7174499822340865, 0.964888142090148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 295}], {
             RGBColor[
             0.7481542644116976, 0.8033229003900898, 0.9754955751330152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 297}], {
             RGBColor[
             0.7097113891411961, 0.773151198294219, 0.9717010567057325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 167}], {
             RGBColor[
             0.5753382538779925, 0.6628795153036178, 0.9613047709389584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 172}], {
             RGBColor[
             0.33312272414216076`, 0.4593269071857189, 0.9425801382634016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 174}], {
             RGBColor[
             0.39453676766698986`, 0.5161496509837875, 0.9463605118539434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 185}], {
             RGBColor[
             0.482410173529073, 0.5891453845161638, 0.9528206307321404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 237}], {
             RGBColor[
             0.5177646791690618, 0.6178477648970354, 0.9556038669239417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 239}], {
             RGBColor[
             0.4039421601527854, 0.5242961292262122, 0.9469598151462764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 283}], {
             RGBColor[
             0.5077365883087008, 0.6097065089762495, 0.9548144188773069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 297}], {
             RGBColor[
             0.5785745379743751, 0.6654077250363819, 0.9616273334928914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 158}], {
             RGBColor[
             0.35967077338482056`, 0.4859504791523989, 0.9441388815290719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 235}], {
             RGBColor[
             0.27887432985742466`, 0.4098011584346488, 0.9392164260637837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 252}], {
             RGBColor[
             0.3081203950955903, 0.44054062730759674`, 0.940881946213421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 253}], {
             RGBColor[
             0.30621743066907636`, 0.4385404910404173, 0.9407735752045145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 257}], {
             RGBColor[
             0.3535074058070181, 0.4806120799363681, 0.9437461571970662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 292}], {
             RGBColor[
             0.2793854994126222, 0.4103384300471832, 0.9392455364137446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 169}], {
             RGBColor[
             0.28111445342614677`, 0.4127994926096401, 0.939320424299829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 219}], {
             RGBColor[
             0.27171942382339986`, 0.4029247208178715, 0.9387853912626534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 221}], {
             RGBColor[
             0.2819086057959276, 0.4136341971024482, 0.9393656501024449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 264}], {
             RGBColor[
             0.28193257724579573`, 0.4136593926161374, 0.9393670152410523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 159}], {
             RGBColor[
             0.2389221548438223, 0.3684527116533779, 0.9369176353134778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 204}], {
             RGBColor[
             0.23066664293228167`, 0.35977564520466165`, 0.936447496123051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 235}], {
             RGBColor[
             0.23624487142727435`, 0.3656387170330131, 0.9367651679835913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 242}], {
             RGBColor[
             0.23544148915831797`, 0.3647943113309621, 0.9367194165518717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 243}], {
             RGBColor[
             0.22430859499308387`, 0.3530929336970421, 0.9360854146988027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 292}], {
             RGBColor[
             0.2367560409824719, 0.36617598864554746`, 0.9367942783335522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 148}], {
             RGBColor[
             0.2325030525609364, 0.36170582815947316`, 0.9365520769346783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 172}], {
             RGBColor[
             0.2478440102281372, 0.3778301473405962, 0.9374257217789124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 183}], {
             RGBColor[
             0.24039105535964145`, 0.36999661922917565`, 0.9370012870248101]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 206}], {
             RGBColor[
             0.23143319481245586`, 0.360581339832921, 0.9364911501186151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 244}], {
             RGBColor[
             0.23435191313774276`, 0.3636490978502278, 0.9366573668093834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 270}], {
             RGBColor[
             0.2272240069658551, 0.35615721652822, 0.9362514430976865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 272}], {
             RGBColor[
             0.2247364657597668, 0.3535426530013993, 0.9361097813059873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 172}], {
             RGBColor[
             0.2541544433679442, 0.3844628126751034, 0.9377850916107751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 183}], {
             RGBColor[
             0.2467014884994484, 0.37662928456368283`, 0.937360656856673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 203}], {
             RGBColor[
             0.2492037147300215, 0.37925928298232137`, 0.9375031549387921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 206}], {
             RGBColor[
             0.23774362795226284`, 0.3672140051674282, 0.9368505199504779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 244}], {
             RGBColor[
             0.24066234627754973`, 0.37028176318473494`, 0.9370167366412461]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 270}], {
             RGBColor[
             0.23353444010566207`, 0.3627898818627272, 0.9366108129295494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 272}], {
             RGBColor[
             0.23104689889957378`, 0.3601753183359065, 0.93646915113785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 171}], {
             RGBColor[
             0.3561511381973472, 0.48153386145037547`, 0.943964705839551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 227}], {
             RGBColor[
             0.27685707898321577`, 0.40832472213698934`, 0.9390779731235251]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 245}], {
             RGBColor[
             0.3591757955739624, 0.4841536676462995, 0.9441574343329895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 289}], {
             RGBColor[
             0.29246611856111315`, 0.4247308124036294, 0.9399668848359817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 298}], {
             RGBColor[
             0.28960052483186716`, 0.4217188917050555, 0.9398036935123671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 200}], {
             RGBColor[
             0.9240011310350597, 0.7732005239509658, 0.5878910864110933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 237}], {
             RGBColor[
             0.8003928066105324, 0.8444068950673695, 0.956951896654846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 282}], {
             RGBColor[
             0.9628316709480902, 0.9718005015674145, 0.9478004654188247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 295}], {
             RGBColor[
             0.8996455406863472, 0.9221385573025866, 0.9667698816510785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 167}], {
             RGBColor[
             0.5986000016649633, 0.6830276720672528, 0.9627869889383882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 194}], {
             RGBColor[
             0.4795533660103779, 0.5880893214551517, 0.9522467003824877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 251}], {
             RGBColor[
             0.36499365332834144`, 0.4885238594535514, 0.944552636407374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 286}], {
             RGBColor[
             0.5011547059099458, 0.6056262623148936, 0.953947236987697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 241}], {
             RGBColor[
             0.2661857597767988, 0.3971084890503288, 0.9384702572815218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 277}], {
             RGBColor[
             0.3011955804505697, 0.43017548464198757`, 0.9406006083286469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 163}], {
             RGBColor[
             0.2574205034515923, 0.3878956489031873, 0.9379710889008359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 211}], {
             RGBColor[
             0.25792046228139853`, 0.38842113733253425`, 0.9379995608165705]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 216}], {
             RGBColor[
             0.2661597993989548, 0.3970812030472318, 0.9384687788764086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 219}], {
             RGBColor[
             0.2738583241419696, 0.40517284066680126`, 0.9389071984715764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 221}], {
             RGBColor[
             0.2840475061144973, 0.4158823169513779, 0.939487457311368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 171}], {
             RGBColor[
             0.5797766952507789, 0.6672643729865424, 0.9613588180759691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 179}], {
             RGBColor[
             0.8674233288276321, 0.8946955574709121, 0.8648978949263142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 245}], {
             RGBColor[
             0.5828013526273942, 0.6698841791824666, 0.9615515465694076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 156}], {
             RGBColor[
             0.22000089461836236`, 0.3485652674792311, 0.935840097535134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 184}], {
             RGBColor[
             0.22486994634019453`, 0.35368294955458646`, 0.9361173828275757]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 197}], {
             RGBColor[
             0.21140151230331092`, 0.3395267714337822, 0.9353503754339378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 202}], {
             RGBColor[
             0.22021191752572378`, 0.34878706593449305`, 0.9358521149775277]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 214}], {
             RGBColor[
             0.21259246077095287`, 0.340778533783768, 0.9354181981873197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 275}], {
             RGBColor[
             0.21254067958734837`, 0.340724108476683, 0.9354152493255168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 293}], {
             RGBColor[
             0.21078204772465953`, 0.3388756748852968, 0.9353150978425994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 178}], {
             RGBColor[
             0.25237767810444756`, 0.38259531972974414`, 0.9376839074575076]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 202}], {
             RGBColor[
             0.22791002753873152`, 0.3568782676465297, 0.9362905109544353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 208}], {
             RGBColor[
             0.2568293808226203, 0.38727434154079826`, 0.9379374253416035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 214}], {
             RGBColor[
             0.2202905707839606, 0.3488697354958046, 0.9358565941642273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 268}], {
             RGBColor[
             0.2451076812596908, 0.374954092101482, 0.9372698918921952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 201}], {
             RGBColor[
             0.3335467378743898, 0.46332315262546664`, 0.9424742810869247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 218}], {
             RGBColor[
             0.30101158042666865`, 0.4302700565079032, 0.9405795858965723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 229}], {
             RGBColor[
             0.34618459391463335`, 0.47426942833041186`, 0.9432795540985917]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 257}], {
             RGBColor[
             0.3686428791962128, 0.49372166625507674`, 0.944710576177652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 259}], {
             RGBColor[
             0.40512064339431064`, 0.5250197481568593, 0.947117003308583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 261}], {
             RGBColor[
             0.3733109108199431, 0.49776488062546065`, 0.9450080190249379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 284}], {
             RGBColor[
             0.3008123283039969, 0.4300606298936609, 0.9405682387829533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 175}], {
             RGBColor[
             0.34907161965836087`, 0.47545391883295585`, 0.9435117019171652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 177}], {
             RGBColor[
             0.4114198455834537, 0.5307729245068593, 0.947436286649661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 217}], {
             RGBColor[
             0.6053338779034495, 0.6866046110497097, 0.9641707450092601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 252}], {
             RGBColor[
             0.35208167801260865`, 0.47861768101199287`, 0.9436831202874573]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 253}], {
             RGBColor[
             0.35017871358609476`, 0.47661754474481344`, 0.9435747492785509]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 175}], {
             RGBColor[
             0.2709524595475128, 0.4021185927355705, 0.9387417137817635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 204}], {
             RGBColor[
             0.23913822416860225`, 0.3686798142133081, 0.9369299401418781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 235}], {
             RGBColor[
             0.24471645266359499`, 0.3745428860416596, 0.9372476120024185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 252}], {
             RGBColor[
             0.2739625179017606, 0.4052823549146075, 0.9389131321520556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 253}], {
             RGBColor[
             0.27205955347524674`, 0.4032822186474281, 0.9388047611431494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 292}], {
             RGBColor[
             0.24522762221879252`, 0.3750801576541939, 0.9372767223523794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 168}], {
             RGBColor[
             0.4880465107801085, 0.5934258804224648, 0.9533459462263981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[
             0.6520185359229838, 0.7272823998054908, 0.9664968499202544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 246}], {
             RGBColor[
             0.5945439555585024, 0.6817165928791875, 0.9612238245492863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 256}], {
             RGBColor[
             0.7927339846129686, 0.8352252152179895, 0.8425165155244698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 296}], {
             RGBColor[
             0.6432277867867322, 0.7204149997680831, 0.9656206702005743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 299}], {
             RGBColor[
             0.7923522710279916, 0.8350967196266381, 0.8509761351220573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 186}], {
             RGBColor[
             0.22312007554742067`, 0.3518437244031648, 0.9360177302746292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 230}], {
             RGBColor[
             0.2328116110999559, 0.36203014274772405`, 0.9365696488870041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 265}], {
             RGBColor[
             0.21936843133233605`, 0.34790050846512904`, 0.9358040796866404]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 269}], {
             RGBColor[
             0.22164816720784125`, 0.350296655413888, 0.9359339072721834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 191}], {
             RGBColor[
             0.26420786908525307`, 0.39502960052800135`, 0.9383576193326653]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 203}], {
             RGBColor[
             0.27206034387321254`, 0.4032830494058043, 0.9388048061551442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 210}], {
             RGBColor[
             0.33154191612091594`, 0.45934744108992703`, 0.9424285250056568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 239}], {
             RGBColor[
             0.34783050852175984`, 0.47345580113907954`, 0.9434664197100019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 184}], {
             RGBColor[
             0.23939823162616325`, 0.3689530985366296, 0.9369447471819397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.23660390230659725`, 0.366016081251054, 0.9367856142610302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 197}], {
             RGBColor[
             0.22592979758927967`, 0.35479692041582533`, 0.9361777397883018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 211}], {
             RGBColor[
             0.2418593140070983, 0.3715398521606279, 0.9370849021826888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 216}], {
             RGBColor[
             0.2500986511246546, 0.3801999178753255, 0.9375541202425267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 168}], {
             RGBColor[
             0.38489864849528777`, 0.5078015965832141, 0.9457463794229767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 210}], {
             RGBColor[
             0.3812406788826516, 0.5046332471596473, 0.9455132968338751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 241}], {
             RGBColor[
             0.33149984085228634`, 0.458806984736167, 0.9424442983869149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 277}], {
             RGBColor[
             0.36650966152605724`, 0.4918739803278257, 0.94457464943404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 179}], {
             RGBColor[
             0.986953469781533, 0.9683582137242022, 0.5663859549250714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 207}], {
             RGBColor[
             0.8629243195572578, 0.8731271056740303, 0.676546302374514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 232}], {
             RGBColor[
             0.9871784526525289, 0.9674285696046385, 0.48831934332178484`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 240}], {
             RGBColor[
             0.987596961950581, 0.9683237186753911, 0.533871497674751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 281}], {
             RGBColor[
             0.9081683799556731, 0.6116901368011833, 0.2799978889278235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 217}], {
             RGBColor[
             0.899879476841495, 0.9180128953290518, 0.7153753712159427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 233}], {
             RGBColor[
             0.9934058766223102, 0.9883041618002921, 0.5236485484298345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 262}], {
             RGBColor[
             0.9933514957949947, 0.9881878467094093, 0.5177295309761065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 271}], {
             RGBColor[
             0.9850940999243964, 0.9612451065301149, 0.40815265332302325`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 291}], {
             RGBColor[
             0.9053156340255587, 0.5627492600761606, 0.30706567418331665`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 174}], {
             RGBColor[
             0.5731249742958058, 0.6609624837721939, 0.9611637427211077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 185}], {
             RGBColor[
             0.660998380157889, 0.7339582173045702, 0.9676238615993047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 194}], {
             RGBColor[
             0.6348798248522232, 0.7127539974799229, 0.9655677132502221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 215}], {
             RGBColor[
             0.874514844691243, 0.8999677108189541, 0.8534618509904951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 282}], {
             RGBColor[
             0.8587917501354356, 0.8900542041854869, 0.9612556665550847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 283}], {
             RGBColor[
             0.6863247949375169, 0.7545193417646557, 0.9696176497444712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 286}], {
             RGBColor[
             0.6564811647517911, 0.7302909383396649, 0.9672682498554315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 297}], {
             RGBColor[
             0.7571627446031911, 0.8102205578247882, 0.9764305643600557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 182}], {
             RGBColor[
             0.34652806688330007`, 0.474422427150048, 0.9433067307526943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 277}], {
             RGBColor[
             0.3674840405107483, 0.49271793843065337`, 0.944636736001335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 187}], {
             RGBColor[
             0.3284772756829356, 0.4574787305648249, 0.9422044795128589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 213}], {
             RGBColor[
             0.36045188979201, 0.48517353421527176`, 0.944241873649848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 219}], {
             RGBColor[
             0.2836300261607937, 0.41544351905027754`, 0.9394636824456108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 221}], {
             RGBColor[
             0.2938192081333214, 0.4261529953348542, 0.9400439412854023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 264}], {
             RGBColor[
             0.29384317958318956`, 0.42617819084854336`, 0.9400453064240097]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[
             0.8434397887079927, 0.3245517789190093, 0.188825975634882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 195}], {
             RGBColor[
             0.820518598671917, 0.15872051746543236`, 0.16728193930165758`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 200}], {
             RGBColor[
             0.8539446998932355, 0.37225212712685507`, 0.1975915310267845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 225}], {
             RGBColor[
             0.8914281470596066, 0.5246344158422436, 0.23572348923178596`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 228}], {
             RGBColor[
             0.8191183413836293, 0.5128704810525186, 0.5754638060619697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 255}], {
             RGBColor[
             0.8904238882805281, 0.5212468151692371, 0.2318221335134233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 198}], {
             RGBColor[
             0.4413043319504303, 0.556360389684118, 0.9494225547381876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 245}], {
             RGBColor[
             0.4213779646314022, 0.5393981467165758, 0.9480708091897773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 289}], {
             RGBColor[
             0.35466828761855285`, 0.4799752914739057, 0.9438802596927696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 298}], {
             RGBColor[
             0.35180269388930685`, 0.47696337077533185`, 0.9437170683691549]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 174}], {
             RGBColor[
             0.33090944455997406`, 0.4574098756542951, 0.9424391100455509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 183}], {
             RGBColor[
             0.2620424461666492, 0.39275360374480583`, 0.9382343017009069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 203}], {
             RGBColor[
             0.26454467239722235`, 0.39538360216344437`, 0.9383767997830261]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 206}], {
             RGBColor[
             0.2530845856194636, 0.3833383243485512, 0.9377241647947119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 244}], {
             RGBColor[
             0.2560033039447505, 0.38640608236585794`, 0.9378903814854801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 270}], {
             RGBColor[
             0.24887539777286288`, 0.3789142010438502, 0.9374844577737833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 272}], {
             RGBColor[
             0.2463878565667746, 0.37629963751702955`, 0.937342795982084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 186}], {
             RGBColor[
             0.24357136840210497`, 0.3733393298802981, 0.937182401147727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 196}], {
             RGBColor[
             0.2690530219671379, 0.40012216340729806`, 0.9386335436215274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 209}], {
             RGBColor[
             0.2611649721580388, 0.3918313229266909, 0.938184330854223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 230}], {
             RGBColor[
             0.25326290395464024`, 0.3835257482248573, 0.9377343197601018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 263}], {
             RGBColor[
             0.25907859446240145`, 0.3896384076845897, 0.9380655147309758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 276}], {
             RGBColor[
             0.24447758470727698`, 0.3742918206744662, 0.9372340088256796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 279}], {
             RGBColor[
             0.2579831193391787, 0.3884869938729482, 0.9380031290433184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 185}], {
             RGBColor[
             0.4801968939468863, 0.58722835298474, 0.9526796025142897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 194}], {
             RGBColor[
             0.45407833864122044`, 0.5660241331600927, 0.9506234541652072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 283}], {
             RGBColor[
             0.5055233087265141, 0.6077894774448256, 0.9546733906594562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 297}], {
             RGBColor[
             0.5763612583921884, 0.663490693504958, 0.9614863052750408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 177}], {
             RGBColor[
             0.3568594089399756, 0.48219931048302006`, 0.944007932963718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 242}], {
             RGBColor[
             0.2674717938620085, 0.3984601924131547, 0.9385434950201575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 252}], {
             RGBColor[
             0.2975212413691305, 0.4300440669881537, 0.9402547666015143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 253}], {
             RGBColor[
             0.29561827694261666`, 0.42804393072097424`, 0.9401463955926079]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 280}], {
             RGBColor[
             0.2812847712693677, 0.4129785074616403, 0.9393301236490378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 199}], {
             RGBColor[
             0.17893943915932659`, 0.3054070743451405, 0.9335017083917216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 226}], {
             RGBColor[
             0.17893944427006758`, 0.3054070797168533, 0.9335017086827707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 287}], {
             RGBColor[
             0.5599634445497977, 0.5545563829440247, 0.6024338644222329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 217}], {
             RGBColor[
             0.6131216671850642, 0.6933500026997739, 0.964666976055813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 247}], {
             RGBColor[
             0.4991479409504841, 0.603343634292864, 0.9539698061272375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 273}], {
             RGBColor[
             0.5185213619952923, 0.6190718502597115, 0.9554949527990644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 285}], {
             RGBColor[
             0.40098949086418123`, 0.5217386754938967, 0.9467716736701495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 182}], {
             RGBColor[
             0.29211972893207316`, 0.4243667349411374, 0.9399471584590454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 202}], {
             RGBColor[
             0.25258870101180897`, 0.3828171181850061, 0.9376959248999015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 208}], {
             RGBColor[
             0.2815080542956977, 0.41321319207927465`, 0.9393428392870697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 268}], {
             RGBColor[
             0.26978635473276824`, 0.4008929426399584, 0.9386753058376613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 281}], {
             RGBColor[
             0.9148614845826333, 0.6349726325663724, 0.4685681683997813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 190}], {
             RGBColor[
             0.23107912024585836`, 0.36020918501380295`, 0.9364709860958538]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 250}], {
             RGBColor[
             0.22830469938985565`, 0.3572930927857018, 0.9363129869324922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 207}], {
             RGBColor[
             0.729702675862836, 0.7887685434205706, 0.9736936013369495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 232}], {
             RGBColor[
             0.8539568089581072, 0.8830700073511788, 0.7854666422842203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 240}], {
             RGBColor[
             0.8543753182561593, 0.8839651564219314, 0.8310187966371865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 246}], {
             RGBColor[
             0.656342497401248, 0.7307927865257904, 0.9668372480070162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 256}], {
             RGBColor[
             0.8545325264557142, 0.8843014088645924, 0.8481299389821997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 296}], {
             RGBColor[
             0.7050263286294778, 0.769491193414686, 0.9712340936583042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 299}], {
             RGBColor[
             0.8541508128707371, 0.884172913273241, 0.8565895585797871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 208}], {
             RGBColor[
             0.2965714316502459, 0.42904575675219153`, 0.9402006763431414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 268}], {
             RGBColor[
             0.28484973208731645`, 0.4167255073128753, 0.939533142893733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 244}], {
             RGBColor[
             0.24855034907625476`, 0.37857255425443737`, 0.937465946731378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 189}], {
             RGBColor[
             0.2346427787554684, 0.3639548160564028, 0.9366739311760157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 197}], {
             RGBColor[
             0.22396867403815082`, 0.3527356552211741, 0.9360660567032872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 202}], {
             RGBColor[
             0.23277907926056368`, 0.361995949721885, 0.9365677962468772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 214}], {
             RGBColor[
             0.22515962250579277`, 0.3539874175711599, 0.9361338794566691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 216}], {
             RGBColor[
             0.24813752757352578`, 0.3781386526806742, 0.9374424371575123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 275}], {
             RGBColor[
             0.22510784132218828`, 0.35393299226407493`, 0.9361309305948662]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 293}], {
             RGBColor[
             0.22334920945949943`, 0.35208455867268873`, 0.9360307791119489]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 237}], {
             RGBColor[
             0.6034248054489583, 0.6889264668979879, 0.961922957584288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 239}], {
             RGBColor[
             0.4896022864326819, 0.5953748312271646, 0.9532789058066227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 282}], {
             RGBColor[
             0.7658636697865162, 0.8163200733980329, 0.9527715263482667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 283}], {
             RGBColor[
             0.5933967145885973, 0.6807852109772019, 0.9611335095376532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 295}], {
             RGBColor[
             0.7026775395247731, 0.7666581291332051, 0.9717409425805205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 297}], {
             RGBColor[
             0.6642346642542716, 0.7364864270373344, 0.9679464241532377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 196}], {
             RGBColor[
             0.255450766680841, 0.38582533066860314`, 0.9378589153057062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 230}], {
             RGBColor[
             0.23966064866834333`, 0.3692289154861624, 0.9369596914442806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 263}], {
             RGBColor[
             0.24547633917610456`, 0.3753415749458948, 0.9372908864151546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 269}], {
             RGBColor[
             0.2284972047762287, 0.3574954281523263, 0.93632394982946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 276}], {
             RGBColor[
             0.2308753294209801, 0.3599949879357713, 0.9364593805098584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 279}], {
             RGBColor[
             0.24438086405288187`, 0.3741901611342533, 0.9372285007274972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 205}], {
             RGBColor[
             0.44668815437293624`, 0.55925348518074, 0.950254691291311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 213}], {
             RGBColor[
             0.395904109711405, 0.5173339739380506, 0.9464476376799205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 264}], {
             RGBColor[
             0.3292953995025846, 0.4583386305713222, 0.9422510704540822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 212}], {
             RGBColor[
             0.20871789165381538`, 0.33670611597978567`, 0.9351975472080101]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 243}], {
             RGBColor[
             0.21194079974675017`, 0.3400935967296356, 0.9353810870560375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 294}], {
             RGBColor[
             0.20780626806211017`, 0.3357479417846294, 0.9351456315930887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 197}], {
             RGBColor[
             0.22117434471858483`, 0.3497986379355985, 0.9359069237823778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 211}], {
             RGBColor[
             0.23710386113640347`, 0.3665415696804011, 0.9368140861767649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 216}], {
             RGBColor[
             0.24534319825395978`, 0.3752016353950986, 0.9372833042366027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 275}], {
             RGBColor[
             0.22231351200262228`, 0.3509959749784993, 0.9359717976739568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 293}], {
             RGBColor[
             0.2205548801399334, 0.3491475413871131, 0.9358716461910392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 212}], {
             RGBColor[
             0.21992645288427248`, 0.3484870244968241, 0.9358358581885042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 250}], {
             RGBColor[
             0.22535768471974588`, 0.35419559351589436`, 0.9361451588067469]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 203}], {
             RGBColor[
             0.2517414689713402, 0.38192662359285945`, 0.9376476762885642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 195}], {
             RGBColor[
             0.8420649475314406, 0.3139841471767838, 0.18750942617155456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 200}], {
             RGBColor[
             0.875491048752759, 0.5275157568382065, 0.21781901789668148`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[
             0.91297449591913, 0.6798980455535951, 0.25595097610168294`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 228}], {
             RGBColor[
             0.8406646902431527, 0.6681341107638701, 0.5956912929318666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 255}], {
             RGBColor[
             0.9119702371400515, 0.6765104448805886, 0.25204962038332024`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 199}], {
             RGBColor[
             0.28921237678725265`, 0.4129203038152378, 0.9400888107445714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 220}], {
             RGBColor[
             0.3283447463388828, 0.4540509053495343, 0.9423173412993839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 236}], {
             RGBColor[
             0.511354201918838, 0.6127180573453962, 0.9550785966275717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 249}], {
             RGBColor[
             0.609038860752824, 0.33213297985445467`, 0.5560510629020323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 266}], {
             RGBColor[
             0.3235658537972168, 0.4490279862889558, 0.942045190438874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 283}], {
             RGBColor[
             0.5672781592829315, 0.6595809911525545, 0.9590773611885706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 286}], {
             RGBColor[
             0.5374345290972057, 0.6353525877275636, 0.9567279612995309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 297}], {
             RGBColor[
             0.6381161089486057, 0.715282207212687, 0.9658902758041552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 200}], {
             RGBColor[
             0.8525698587166832, 0.36168449538462955`, 0.19627498156345707`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 225}], {
             RGBColor[
             0.8900533058830544, 0.5140667841000182, 0.23440693976845853`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.8890490471039758, 0.5106791834270117, 0.23050558405009586`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 230}], {
             RGBColor[
             0.2651423022333762, 0.39601174901316233`, 0.938410833918081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 263}], {
             RGBColor[
             0.27095799274113747`, 0.40212440847289477`, 0.9387420288889549]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 279}], {
             RGBColor[
             0.2698625176179148, 0.40097299466125325`, 0.9386796432012976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 289}], {
             RGBColor[
             0.28595784411409636`, 0.4178902033113814, 0.9395962482343534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 298}], {
             RGBColor[
             0.28309225038485036`, 0.4148782826128075, 0.9394330569107388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 214}], {
             RGBColor[
             0.21169118846890916`, 0.33983123945035565`, 0.9353668720630313]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 275}], {
             RGBColor[
             0.21163940728530467`, 0.33977681414327066`, 0.9353639232012283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 293}], {
             RGBColor[
             0.20988077542261582`, 0.33792838055188446`, 0.9352637717183109]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 222}], {
             RGBColor[
             0.4501940180001994, 0.5640601889318158, 0.9499889976724383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 245}], {
             RGBColor[
             0.4443289893270455, 0.5589801958800422, 0.949615283231626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 258}], {
             RGBColor[
             0.7130111957358749, 0.7734744682690422, 0.9502848227262681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 278}], {
             RGBColor[
             0.5335934338471843, 0.6322342135642272, 0.9564255762110536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 290}], {
             RGBColor[
             0.5385920372825843, 0.6362923050176035, 0.9568190845839761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 220}], {
             RGBColor[
             0.21805936955163013`, 0.34652460153429643`, 0.9357295305548126]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 226}], {
             RGBColor[
             0.178927005110741, 0.3053940053717128, 0.9335010002910491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 228}], {
             RGBColor[
             0.49763512145939465`, 0.5809234064486897, 0.9579150616794772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 266}], {
             RGBColor[
             0.21328047700996416`, 0.3415016824737179, 0.9354573796943026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 225}], {
             RGBColor[
             0.9234794071043728, 0.7275983937614409, 0.2647165314935854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 255}], {
             RGBColor[
             0.9224751483252943, 0.7242107930884344, 0.2608151757752228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 282}], {
             RGBColor[
             0.9248264998510323, 0.7738160826625009, 0.5864939522963153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 295}], {
             RGBColor[
             0.8616403695892892, 0.7241541383976731, 0.6054633685285691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 209}], {
             RGBColor[
             0.29313467956513195`, 0.424290095199951, 0.9400468245012701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 218}], {
             RGBColor[
             0.2885778810548669, 0.4195006110479498, 0.9397873215672898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 229}], {
             RGBColor[
             0.3337508945428317, 0.46349998287045846`, 0.9424872897693092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 257}], {
             RGBColor[
             0.35620917982441114`, 0.48295222079512334`, 0.9439183118483695]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 259}], {
             RGBColor[
             0.3926869440225089, 0.5142503026969059, 0.9463247389793005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 261}], {
             RGBColor[
             0.36087721144814144`, 0.48699543516550725`, 0.9442157546956553]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 208}], {
             RGBColor[
             0.2570404037299817, 0.3874961399960602, 0.9379494427839974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 214}], {
             RGBColor[
             0.22050159369132202`, 0.3490915339510665, 0.935868611606621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 268}], {
             RGBColor[
             0.2453187041670522, 0.37517589055674394`, 0.937281909334589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 275}], {
             RGBColor[
             0.22044981250771753`, 0.3490371086439815, 0.9358656627448182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 206}], {
             RGBColor[
             0.24813385698154097`, 0.37813479465576916`, 0.9374422281227288]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 244}], {
             RGBColor[
             0.2510525753068279, 0.38120255267307596`, 0.9376084448134971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 270}], {
             RGBColor[
             0.2439246691349402, 0.37371067135106817`, 0.9372025211018002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 235}], {
             RGBColor[
             0.23646094075205434`, 0.36586581959294334`, 0.9367774728119916]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 253}], {
             RGBColor[
             0.26380404156370607`, 0.39460515219871184`, 0.9383346219527224]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 292}], {
             RGBColor[
             0.2369721103072519, 0.36640309120547765`, 0.9368065831619525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 213}], {
             RGBColor[
             0.4786627684820106, 0.5869482888311869, 0.9522920854283001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 231}], {
             RGBColor[
             0.4872830813565614, 0.5944147705735998, 0.9528413641420233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 244}], {
             RGBColor[
             0.23959248852906917`, 0.3691572748581827, 0.9369558098251829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 270}], {
             RGBColor[
             0.23246458235718154`, 0.361665393536175, 0.936549886113486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 272}], {
             RGBColor[
             0.22997704115109324`, 0.35905083000935434`, 0.9364082243217868]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 231}], {
             RGBColor[
             0.5953538117647618, 0.6805701172311853, 0.962430259270135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 232}], {
             RGBColor[
             0.8698424070552139, 0.8954799573196557, 0.7870499702431855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 240}], {
             RGBColor[
             0.870260916353266, 0.8963751063904083, 0.8326021245961515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 268}], {
             RGBColor[
             0.274238057450941, 0.4055719644510125, 0.9389288237217572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 218}], {
             RGBColor[
             0.2605995221174108, 0.3912369990823875, 0.9381521293109176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 276}], {
             RGBColor[
             0.24846893317691396`, 0.37848698098216405`, 0.9374613102163545]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 279}], {
             RGBColor[
             0.2619744678088157, 0.39268215418064606`, 0.9382304304339932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 239}], {
             RGBColor[
             0.39484568065555037`, 0.5164172158880604, 0.9463801955164135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 277}], {
             RGBColor[
             0.36382607089811214`, 0.48954958900708645`, 0.9444036534122333]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 216}], {
             RGBColor[
             0.2505986099544608, 0.38072540630467244`, 0.9375825921582613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 221}], {
             RGBColor[
             0.26848631667000333`, 0.39952652020881857`, 0.9386012705932207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 243}], {
             RGBColor[
             0.2149437082857312, 0.34324984399950276`, 0.9355520982549272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 250}], {
             RGBColor[
             0.21715203202826977`, 0.34557093226872304`, 0.9356778590251427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 294}], {
             RGBColor[
             0.2108091766010912, 0.3389041890544966, 0.9353166427919786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 231}], {
             RGBColor[
             0.43649903669503015`, 0.5524952593309104, 0.9490343105306326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 264}], {
             RGBColor[
             0.36127001361165895`, 0.48603343422176903`, 0.9442884645910713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 275}], {
             RGBColor[
             0.21283035575294662`, 0.34102857649325646`, 0.9354317459546102]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 293}], {
             RGBColor[
             0.21107172389025777`, 0.33918014290187026`, 0.9353315944716927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 223}], {
             RGBColor[
             0.9412290011481947, 0.7868146166289862, 0.47926705037049566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 234}], {
             RGBColor[
             0.9062111144378386, 0.5631850367729421, 0.44751685008743375`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 271}], {
             RGBColor[
             0.9862840872732699, 0.9639445925953173, 0.5488858494022204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 274}], {
             RGBColor[
             0.979839341035498, 0.9422049502369351, 0.5238492272566825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 282}], {
             RGBColor[
             0.97938013431987, 0.9823295669124169, 0.8386095157394571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 286}], {
             RGBColor[
             0.7770695489362254, 0.8225663010665949, 0.8446220990398039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 233}], {
             RGBColor[
             0.9005620992858752, 0.9194729557138646, 0.7896746116293041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 247}], {
             RGBColor[
             0.6930619732704799, 0.7591753208357144, 0.9707042644868367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 262}], {
             RGBColor[
             0.9005077184585596, 0.9193566406229818, 0.783755594175576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 273}], {
             RGBColor[
             0.7124353943152881, 0.7749035368025619, 0.9722294111586636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 229}], {
             RGBColor[
             0.3012157370951104, 0.430446886752895, 0.9405925945789568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 284}], {
             RGBColor[
             0.25584347148447395`, 0.38623808831614403`, 0.9378812792633183]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 221}], {
             RGBColor[
             0.28442417853057445`, 0.4162782235430855, 0.9395089082482266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 264}], {
             RGBColor[
             0.28444814998044265`, 0.4163034190567747, 0.9395102733868341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 226}], {
             RGBColor[
             0.21805937466237113`, 0.3465246069060093, 0.9357295308458616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 228}], {
             RGBColor[
             0.5367674910110247, 0.6220540079829862, 0.9601435922342896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 236}], {
             RGBColor[
             0.4402011946832155, 0.5463223550644548, 0.9507193164378127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 266}], {
             RGBColor[
             0.2524128465615943, 0.3826322840080144, 0.9376859102491151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 231}], {
             RGBColor[
             0.3698663550363416, 0.4934747204504928, 0.9448363781661868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 245}], {
             RGBColor[
             0.43026765068117134`, 0.5470979459642735, 0.9486372521240278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 261}], {
             RGBColor[
             0.41838703187400994`, 0.5368075510907742, 0.9478802295992542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 278}], {
             RGBColor[
             0.51953209520131, 0.6203519636484585, 0.9554475451034554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 290}], {
             RGBColor[
             0.5245306986367102, 0.6244100551018348, 0.9558410534763778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 234}], {
             RGBColor[
             0.852336886710356, 0.35775657985604403`, 0.19596820028306192`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 271}], {
             RGBColor[
             0.9324098595457874, 0.7585161356784191, 0.29733719959784854`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 274}], {
             RGBColor[
             0.9259651133080155, 0.7367764933200369, 0.2723005774523107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 287}], {
             RGBColor[
             0.9141648921008272, 0.6925393884549282, 0.24954185631357317`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 291}], {
             RGBColor[
             0.8526313936469496, 0.36002028922446494`, 0.19625022045814194`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 249}], {
             RGBColor[
             0.8940523406864429, 0.5263405979795888, 0.25076760006070237`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 254}], {
             RGBColor[
             0.9304233123934045, 0.7541309251793602, 0.28356918675006826`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 258}], {
             RGBColor[
             0.9656458741337097, 0.9399341707856219, 0.6428561562394914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 260}], {
             RGBColor[
             0.9093392465848947, 0.8957090172216551, 0.6607919677185569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 288}], {
             RGBColor[
             0.9157129138329121, 0.6873344410170366, 0.27129446960632875`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 234}], {
             RGBColor[
             0.889140927135372, 0.5070538412384147, 0.23353324484929344`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 255}], {
             RGBColor[
             0.9599585954916654, 0.876593081803823, 0.2989471339802242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 287}], {
             RGBColor[
             0.950968932525843, 0.8418366498372989, 0.2871069008798047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 228}], {
             RGBColor[
             0.4976351265701356, 0.5809234118204025, 0.9579150619705263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 266}], {
             RGBColor[
             0.21328048212070516`, 0.3415016878454308, 0.9354573799853517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 264}], {
             RGBColor[
             0.2772132461146813, 0.4086990763744601, 0.9390982563147601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 266}], {
             RGBColor[
             0.5319885984693589, 0.6170310889224077, 0.9598714413737797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 257}], {
             RGBColor[
             0.3688470358646546, 0.49389849650006856`, 0.9447235848600365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 259}], {
             RGBColor[
             0.40532480006275245`, 0.5251965784018511, 0.9471300119909675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 261}], {
             RGBColor[
             0.3735150674883849, 0.49794171087045247`, 0.9450210277073223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 284}], {
             RGBColor[
             0.3010164849724387, 0.4302374601386527, 0.9405812474653377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 263}], {
             RGBColor[
             0.2551678747286398, 0.38552799329045395`, 0.9378428050275294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 269}], {
             RGBColor[
             0.23818874032876391`, 0.3676818464968855, 0.9368758684418348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 289}], {
             RGBColor[
             0.27016772610159867`, 0.4012937881289406, 0.9386970243729278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 298}], {
             RGBColor[
             0.2673021323723527, 0.39828186743036675`, 0.9385338330493134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 240}], {
             RGBColor[
             0.9945150494485371, 0.9906765703210165, 0.6443751655434223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 256}], {
             RGBColor[
             0.9946722576480922, 0.9910128227636774, 0.6614863078884357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 296}], {
             RGBColor[
             0.8451660598218556, 0.8762026073137711, 0.7845904625645401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 299}], {
             RGBColor[
             0.994290544063115, 0.9908843271723261, 0.6699459274860231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 262}], {
             RGBColor[
             0.9940341182393746, 0.9896479070942221, 0.5920287713894679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 288}], {
             RGBColor[
             0.9279948066453856, 0.7277856301692169, 0.40221351612468526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 291}], {
             RGBColor[
             0.9059982564699387, 0.5642093204609733, 0.381364914596678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 255}], {
             RGBColor[
             0.8881366683562935, 0.5036662405654082, 0.2296318891309308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 271}], {
             RGBColor[
             0.8973919728354314, 0.5348865558223752, 0.26558699931478663`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 274}], {
             RGBColor[
             0.8909472265976595, 0.513146913463993, 0.24055037716924876`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 287}], {
             RGBColor[
             0.8791470053904711, 0.46890980859888415`, 0.21779165603051126`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 252}], {
             RGBColor[
             0.2712852344852127, 0.40246836029424277`, 0.9387606648221691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 253}], {
             RGBColor[
             0.2693822700586988, 0.40046822402706334`, 0.9386522938132629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 292}], {
             RGBColor[
             0.24255033880224458`, 0.3722661630338292, 0.9371242550224929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 249}], {
             RGBColor[
             0.7208953090971567, 0.4244044295693752, 0.5644530380404611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 266}], {
             RGBColor[
             0.43542230214154953`, 0.5412994360038763, 0.9504471655773028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 239}], {
             RGBColor[
             0.5249567920726707, 0.6240772116080362, 0.9560621419984239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 282}], {
             RGBColor[
             0.8012181754265049, 0.8450224537789045, 0.955554762540068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 283}], {
             RGBColor[
             0.6287512202285861, 0.7094875913580734, 0.9639167457294545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 295}], {
             RGBColor[
             0.738032045164762, 0.7953605095140767, 0.9745241787723218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 297}], {
             RGBColor[
             0.6995891698942603, 0.7651888074182058, 0.970729660345039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 251}], {
             RGBColor[
             0.2826141781107905, 0.4143757983412377, 0.9394058314019756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 300}], {
             RGBColor[
             0.2671877155710705, 0.398161608117775, 0.9385273171817448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 295}], {
             RGBColor[
             0.6242095261484855, 0.7018088738432534, 0.9658801269946564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 256}], {
             RGBColor[
             0.9950907669461442, 0.9919079718344301, 0.7070384622414018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 281}], {
             RGBColor[
             0.9155049767516813, 0.6349381375175613, 0.436053711149461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 299}], {
             RGBColor[
             0.9947090533611671, 0.9917794762430787, 0.7154980818389891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 277}], {
             RGBColor[
             0.3140852328677468, 0.44372332658360614`, 0.9413346549652732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 243}], {
             RGBColor[
             0.22929951054390013`, 0.35833870238327276`, 0.9363696399560237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 280}], {
             RGBColor[
             0.25424538211649345`, 0.38455839506567835`, 0.9377902704379731]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 294}], {
             RGBColor[
             0.22516497885926012`, 0.35399304743826654`, 0.9361341844930751]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 294}], {
             RGBColor[
             0.21403208469402601`, 0.34229166980434655`, 0.935500182640006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 270}], {
             RGBColor[
             0.23538330068246843`, 0.36473315155348174`, 0.9367161028042543]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 272}], {
             RGBColor[
             0.23289575947638014`, 0.3621185880266611, 0.936574441012555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 289}], {
             RGBColor[
             0.3576929449951681, 0.48259509766982983`, 0.944072988186208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 298}], {
             RGBColor[
             0.35482735126592213`, 0.47958317697125596`, 0.9439097968625934]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 256}], {
             RGBColor[
             0.7970579460912328, 0.838735601938289, 0.8428569136112316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 296}], {
             RGBColor[
             0.6475517482649964, 0.7239253864883827, 0.965961068287336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 299}], {
             RGBColor[
             0.7966762325062557, 0.8386071063469377, 0.851316533208819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 267}], {
             RGBColor[
             0.5234677465828359, 0.6240137244860162, 0.9556284450179895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 273}], {
             RGBColor[
             0.598461668080708, 0.6848971683956518, 0.9615322412300882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 285}], {
             RGBColor[
             0.4809297969495969, 0.5875639936298371, 0.952808962101173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 270}], {
             RGBColor[
             0.21830317142063266`, 0.3467808527565494, 0.9357434147105796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 254}], {
             RGBColor[
             0.8549509396381043, 0.371609679278205, 0.19822709100428773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 288}], {
             RGBColor[
             0.8402405410776118, 0.30481319511588134`, 0.18595237386054825`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 300}], {
             RGBColor[
             0.27128730129384493`, 0.40247053264115845`, 0.9387607825238632]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 253}], {
             RGBColor[
             0.29862833529686444`, 0.43120769290001126`, 0.9403178139629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 292}], {
             RGBColor[
             0.2717964040404102, 0.4030056319067771, 0.9387897751721301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 292}], {
             RGBColor[
             0.26989343961389634`, 0.40100549563959764`, 0.9386814041632237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 258}], {
             RGBColor[
             0.926544473085371, 0.7852032520842381, 0.5903156471830767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 260}], {
             RGBColor[
             0.870237845536556, 0.7409780985202714, 0.6082514586621423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 288}], {
             RGBColor[
             0.8766115127845734, 0.5326035223156528, 0.21875396054991414`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 287}], {
             RGBColor[
             0.9499646737467646, 0.8384490491642924, 0.28320554516144203`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 296}], {
             RGBColor[
             0.8457417773194627, 0.8774340088271846, 0.8472537592625196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 299}], {
             RGBColor[
             0.994866261560722, 0.9921157286857396, 0.7326092241840025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 259}], {
             RGBColor[
             0.4277830853443319, 0.544648816326516, 0.9485610340700278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 261}], {
             RGBColor[
             0.39597335276996437`, 0.5173939487951174, 0.9464520497863826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 260}], {
             RGBColor[
             0.9054604072768613, 0.9267813441265331, 0.9675384281515653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 278}], {
             RGBColor[
             0.7823492729369855, 0.8297662429856849, 0.9557433701572854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 290}], {
             RGBColor[
             0.7873478763723856, 0.8338243344390612, 0.9561368785302078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 260}], {
             RGBColor[
             0.656707314635238, 0.7292515443954324, 0.9682208504157948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 261}], {
             RGBColor[
             0.4324511169680622, 0.5486920306968999, 0.9488584769173136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 261}], {
             RGBColor[
             0.6248975820608704, 0.7019966768640338, 0.9661118661321497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 278}], {
             RGBColor[
             0.7260426453881705, 0.7855410894217181, 0.9736791816363508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 290}], {
             RGBColor[
             0.7310412488235707, 0.7895991808750945, 0.9740726900092733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 278}], {
             RGBColor[
             0.5017864477209948, 0.6049815757231856, 0.9543168081378697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 290}], {
             RGBColor[
             0.5067850511563949, 0.6090396671765619, 0.9547103165107921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 271}], {
             RGBColor[
             0.9857223415414609, 0.9625888518240449, 0.4765328762826566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 291}], {
             RGBColor[
             0.9059438756426232, 0.5640930053700905, 0.37544589714295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 269}], {
             RGBColor[
             0.24400443083652518`, 0.3737945059566179, 0.9372070634127088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 276}], {
             RGBColor[
             0.24638255548127658`, 0.37629406574006286`, 0.9373424940931072]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 279}], {
             RGBColor[
             0.25988809011317837`, 0.3904892389385449, 0.938111614310746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 289}], {
             RGBColor[
             0.27598341660935993`, 0.40740644758867306`, 0.9390282193438018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 298}], {
             RGBColor[
             0.27311782288011394`, 0.40439452689009914`, 0.9388650280201871]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 269}], {
             RGBColor[
             0.2247455605611441, 0.35355221221429056`, 0.9361102992414712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 273}], {
             RGBColor[
             0.5428411676276441, 0.6397419404528637, 0.9571535916898165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 285}], {
             RGBColor[
             0.42530929649653304`, 0.542408765687049, 0.9484303125609015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 286}], {
             RGBColor[
             0.5134415575632728, 0.6158740125652669, 0.954839146691229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 298}], {
             RGBColor[
             0.2561386884802381, 0.3865483800965307, 0.9378980914344927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 272}], {
             RGBColor[
             0.22576785330449248`, 0.35462670670465335`, 0.9361685173008583]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 274}], {
             RGBColor[
             0.9710201994330907, 0.9139064692863681, 0.34191937648403536`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 291}], {
             RGBColor[
             0.897686479772025, 0.537150265190796, 0.2658690194898667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 285}], {
             RGBColor[
             0.5003032179944051, 0.6032922095966846, 0.9543341087730001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 287}], {
             RGBColor[
             0.9527752319881305, 0.8479297220628771, 0.29412403319976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 293}], {
             RGBColor[
             0.21101994270665328`, 0.33912571759478527`, 0.9353286456098898]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 279}], {
             RGBColor[
             0.24528708035805388`, 0.3751426519284214, 0.9372801084054498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 290}], {
             RGBColor[
             0.607930114483695, 0.6925840797342462, 0.9622776320149933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 283}], {
             RGBColor[
             0.7911900845661439, 0.8368811978581185, 0.9547653144934332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 295}], {
             RGBColor[
             0.9004709095023198, 0.9227541160141217, 0.9653727475363004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 297}], {
             RGBColor[
             0.8620280342318183, 0.892582413918251, 0.9615782291090177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 295}], {
             RGBColor[
             0.728003954304401, 0.7872192535932907, 0.973734730725687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 297}], {
             RGBColor[
             0.6895610790338994, 0.7570475514974199, 0.9699402122984042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 291}], {
             RGBColor[
             0.839904564048634, 0.3022307284450855, 0.18563064187816736`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 298}], {
             RGBColor[
             0.28811767425307283`, 0.4201603217285858, 0.9397192473655857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 297}], {
             RGBColor[
             0.7988419039700752, 0.8429204696534232, 0.9805476453412715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 299}], {
             RGBColor[
             0.8453600637344856, 0.8773055132358333, 0.8557133788601069]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.03434177932816089], {
             RGBColor[
             0.41852266255485593`, 0.5369250275695268, 0.9478888718663042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.03434177932816089], {
             RGBColor[
             0.2307572995292167, 0.3598709310360006, 0.936452658882132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.03434177932816089], {
             RGBColor[
             0.3773249031069595, 0.5012415989953558, 0.9452637870640326]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.03434177932816089], {
             RGBColor[
             0.5396207399250182, 0.6371274521652572, 0.9569000678242504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.03434177932816089], {
             RGBColor[
             0.220958970004222, 0.34957226545525755`, 0.9358946585110132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.03434177932816089], {
             RGBColor[
             0.3056730571205615, 0.43861214219787836`, 0.9407190004490276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.03434177932816089], {
             RGBColor[
             0.394746751143397, 0.516331528116975, 0.946373891815379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.03434177932816089], {
             RGBColor[
             0.6518492866916434, 0.7279488840923621, 0.9659339030856515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.03434177932816089], {
             RGBColor[
             0.5168296547678491, 0.6186246225079816, 0.9551058701141822]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.03434177932816089], {
             RGBColor[
             0.2114327980870659, 0.3395596547761419, 0.9353521571130395]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.03434177932816089], {
             RGBColor[
             0.34350580070653963`, 0.47194919229362253`, 0.9431088637641358]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.03434177932816089], {
             RGBColor[
             0.20154157699751735`, 0.32916335427138743`, 0.93478886670474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.03434177932816089], {
             RGBColor[
             0.30612838775897044`, 0.4390907235684761, 0.9407449308552837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.03434177932816089], {
             RGBColor[
             0.8226976998778256, 0.17547004422228246`, 0.1693686490773784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.03434177932816089], {
             RGBColor[
             0.23892277989457777`, 0.36845336862135236`, 0.9369176709091936]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.03434177932816089], {
             RGBColor[
             0.9934703621130101, 0.9884420897444159, 0.5306673961342021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.03434177932816089], {
             RGBColor[
             0.29622239326445615`, 0.42867889527841463`, 0.9401807991234267]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.03434177932816089], {
             RGBColor[
             0.9464007204285422, 0.9595463255731478, 0.9756137787701872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.03434177932816089], {
             RGBColor[
             0.2912671539208582, 0.4234706245479727, 0.9398986055734284]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.03434177932816089], {
             RGBColor[
             0.865905855945801, 0.8959138414156087, 0.9870720676150353]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.03434177932816089], {
             RGBColor[
             0.38345468665213356`, 0.5065509094103063, 0.9456543714511763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.03434177932816089], {
             RGBColor[
             0.8173789776787558, 0.8572619367637411, 0.982432355720336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.03434177932816089], {
             RGBColor[
             0.2963741173821658, 0.42883836694599214`, 0.9401894395874745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.03434177932816089], {
             RGBColor[
             0.9556367854010767, 0.9664345677069957, 0.9599795299232305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.03434177932816089], {
             RGBColor[
             0.2518103509231395, 0.3819990228915686, 0.9376515990138174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.03434177932816089], {
             RGBColor[
             0.9858349896506369, 0.9884104184434465, 0.8844144095680297]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.03434177932816089], {
             RGBColor[
             0.2584384877012701, 0.38896561489352793`, 0.9380290615978824]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.03434177932816089], {
             RGBColor[
             0.22341264573171882`, 0.35215123421688327`, 0.9360343917138061]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.03434177932816089], {
             RGBColor[
             0.24282295558358705`, 0.3725527005559224, 0.9371397801448899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.03434177932816089], {
             RGBColor[
             0.46219840465570133`, 0.574272512557169, 0.9508050979844909]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.03434177932816089], {
             RGBColor[
             0.6188367246795077, 0.7014385572283971, 0.9631362403218372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.03434177932816089], {
             RGBColor[
             0.2562574704790552, 0.38667322750850125`, 0.9379048558936031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.03434177932816089], {
             RGBColor[
             0.9146626577353835, 0.9347911916944939, 0.9917225348954364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.03434177932816089], {
             RGBColor[
             0.3274991935787168, 0.458085073714969, 0.9420889369120379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.03434177932816089], {
             RGBColor[
             0.2262311772849768, 0.3551136895845794, 0.9361949029161204]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.03434177932816089], {
             RGBColor[
             0.7595712694087771, 0.8121021157083784, 0.9766706236037325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.03434177932816089], {
             RGBColor[
             0.6807027709206555, 0.7504894452666685, 0.968809748742459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.03434177932816089], {
             RGBColor[
             0.4179442959916355, 0.5364240755220139, 0.9478520188603253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.03434177932816089], {
             RGBColor[
             0.8675327116732591, 0.4913788068770457, 0.21117838636085415`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.03434177932816089], {
             RGBColor[
             0.2372124705557414, 0.3666557250663601, 0.9368202713225229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.03434177932816089], {
             RGBColor[
             0.35699077137457635`, 0.483629196111943, 0.9439681141708117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.03434177932816089], {
             RGBColor[
             0.2544378422070241, 0.3847606828235006, 0.9378012307554097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.03434177932816089], {
             RGBColor[
             0.322173741643116, 0.45347243491334854`, 0.9417496038238137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.03434177932816089], {
             RGBColor[
             0.9650552642631052, 0.8937853423246256, 0.3187467297321304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.03434177932816089], {
             RGBColor[
             0.8578237913971699, 0.4454645759914146, 0.2030054339855487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.03434177932816089], {
             RGBColor[
             0.29213812634371106`, 0.4243860717872321, 0.9399482061644217]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.03434177932816089], {
             RGBColor[
             0.6440597930627512, 0.7218636724671273, 0.9651575191576801]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.03434177932816089], {
             RGBColor[
             0.4136829046946342, 0.5327330725643056, 0.9475804867750808]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.03434177932816089], {
             RGBColor[
             0.23655451757503262`, 0.36596417476700677`, 0.9367828018736257]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.03434177932816089], {
             RGBColor[
             0.35244904856935166`, 0.4796953840916829, 0.9436787196097506]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.03434177932816089], {
             RGBColor[
             0.993562122803693, 0.9916057865804992, 0.7563558160423134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.03434177932816089], {
             RGBColor[
             0.8177080186927622, 0.13711716814164848`, 0.16459052473952288`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.03434177932816089], {
             RGBColor[
             0.8317291195209172, 0.2448894931924079, 0.17801714672713256`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.03434177932816089], {
             RGBColor[
             0.4174064139952154, 0.53595818917145, 0.9478177454951437]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.03434177932816089], {
             RGBColor[
             0.2766948027559306, 0.4081541595332056, 0.9390687317324474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.03434177932816089], {
             RGBColor[
             0.5476923991281734, 0.6436803887304818, 0.9575354984041846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.03434177932816089], {
             RGBColor[
             0.24705297562595502`, 0.37699871981921224`, 0.9373806735285489]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.03434177932816089], {
             RGBColor[
             0.5489231824340144, 0.6446795940643196, 0.9576323901745283]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.03434177932816089], {
             RGBColor[
             0.8328101555207211, 0.25319880959989605`, 0.17905234802140027`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.03434177932816089], {
             RGBColor[
             0.9260824493199337, 0.7446485736567867, 0.2593824075361489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.03434177932816089], {
             RGBColor[
             0.5668393910348319, 0.659224779322463, 0.9590428197448192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.03434177932816089], {
             RGBColor[
             0.9948487335515908, 0.9913902868768101, 0.6806946209012268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.03434177932816089], {
             RGBColor[
             0.32451328924336914`, 0.4554988334556064, 0.9418986777281211]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.03434177932816089], {
             RGBColor[
             0.23365539790008147`, 0.3629170161738291, 0.9366177012970005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.03434177932816089], {
             RGBColor[
             0.28791659856684826`, 0.41994897843342893`, 0.9397077964027201]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.03434177932816089], {
             RGBColor[
             0.9464558742569554, 0.9595874592080723, 0.9755204177251058]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.03434177932816089], {
             RGBColor[
             0.9123183312358003, 0.932921889378774, 0.9914989309411012]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.03434177932816089], {
             RGBColor[
             0.8743662175245639, 0.5224081609419808, 0.2168804311477391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.03434177932816089], {
             RGBColor[
             0.9930380091079225, 0.9875173303841278, 0.48360843970387296`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.03434177932816089], {
             RGBColor[
             0.26423372362278924`, 0.39505677528622424`, 0.9383590917103296]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.03434177932816089], {
             RGBColor[
             0.6295965520330332, 0.7101738697986875, 0.963983293345653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.03434177932816089], {
             RGBColor[
             0.6518075404484566, 0.7279162716099014, 0.9659297422102715]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.03434177932816089], {
             RGBColor[
             0.3290101239879992, 0.459393765693919, 0.9421852120616541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.03434177932816089], {
             RGBColor[
             0.6382140736915616, 0.7171699620960075, 0.9646616962176343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.03434177932816089], {
             RGBColor[
             0.7305123993392341, 0.7894011055544591, 0.9737743070057807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.03434177932816089], {
             RGBColor[
             0.29429562032882867`, 0.4266537347586102, 0.9400710722551477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.03434177932816089], {
             RGBColor[
             0.2460324096232273, 0.37592604024272347`, 0.9373225538044856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.03434177932816089], {
             RGBColor[
             0.1800403201715783, 0.3065641700889047, 0.9335644019367618]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.03434177932816089], {
             RGBColor[
             0.39493077240962093`, 0.5164909180886005, 0.9463856174877392]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.03434177932816089], {
             RGBColor[
             0.26782978190622225`, 0.39883646054537636`, 0.9385638819096797]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.03434177932816089], {
             RGBColor[
             0.29584127485450173`, 0.42827831566524976`, 0.9401590949937939]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.03434177932816089], {
             RGBColor[
             0.9950766756732579, 0.9918778320265724, 0.7055047141489801]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.03434177932816089], {
             RGBColor[
             0.21628848662157388`, 0.34466329129434453`, 0.9356286813917323]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.03434177932816089], {
             RGBColor[
             0.30061798398773654`, 0.43329893982513096`, 0.9404311215124237]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.03434177932816089], {
             RGBColor[
             0.9196256639800194, 0.938748558156751, 0.9921959108615778]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.03434177932816089], {
             RGBColor[
             0.9748675947682047, 0.926884637163092, 0.35686578084130904`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.03434177932816089], {
             RGBColor[
             0.27610729667649436`, 0.4075366533936812, 0.9390352741303609]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.03434177932816089], {
             RGBColor[
             0.5042211596463271, 0.6083884781620977, 0.9541132831917766]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.03434177932816089], {
             RGBColor[
             0.27813245697413447`, 0.40966522526908, 0.9391506040133554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.03434177932816089], {
             RGBColor[
             0.4035464690461924, 0.5239534014776945, 0.9469346020588602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.03434177932816089], {
             RGBColor[
             0.2726124428491967, 0.4038633404346605, 0.9388362473750692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.03434177932816089], {
             RGBColor[
             0.261097249315751, 0.3917601419255701, 0.9381804741385418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.03434177932816089], {
             RGBColor[
             0.5312094509757161, 0.6302987888719648, 0.9562379003465947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.03434177932816089], {
             RGBColor[
             0.8619491220774967, 0.8927588492317026, 0.9866946708064583]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.03434177932816089], {
             RGBColor[
             0.48864650773140994`, 0.5957442741074949, 0.9528871895412045]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.03434177932816089], {
             RGBColor[
             0.40546591079173033`, 0.5256159254437323, 0.9470569071895901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.03434177932816089], {
             RGBColor[
             0.2574804300414378, 0.3879586355486801, 0.9379745016314742]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.03434177932816089], {
             RGBColor[
             0.4228071955400177, 0.5406360746943846, 0.948161878519455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.03434177932816089], {
             RGBColor[
             0.3674883934084197, 0.4927217086918333, 0.9446370133641255]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.03434177932816089], {
             RGBColor[
             0.8501803311271197, 0.38671359097016134`, 0.19568604779889498`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.03434177932816089], {
             RGBColor[
             0.5465902564750337, 0.6427856196737024, 0.9574487336972479]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.03434177932816089], {
             RGBColor[
             0.38532279281260967`, 0.5081689690727651, 0.9457734055238204]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.03434177932816089], {
             RGBColor[
             0.2788168781365947, 0.4103845953056338, 0.9391895807860471]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.03434177932816089], {
             RGBColor[
             0.28507184392659923`, 0.4169589609386654, 0.9395457918343952]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.03434177932816089], {
             RGBColor[
             0.28917033221241484`, 0.4212667319862237, 0.9397791946791023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.03434177932816089], {
             RGBColor[
             0.6566687686170058, 0.7317139000018745, 0.9664142640033524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.03434177932816089], {
             RGBColor[
             0.8341470216086144, 0.26347454816989946`, 0.18033253249694123`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.03434177932816089], {
             RGBColor[
             0.3439204196877902, 0.4723083144158259, 0.943135282918988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.03434177932816089], {
             RGBColor[
             0.9211686584075277, 0.939978900029778, 0.992343083047521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.03434177932816089], {
             RGBColor[
             0.9929459767177286, 0.9913509943397207, 0.7665669512217009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.03434177932816089], {
             RGBColor[
             0.24301438028138522`, 0.37275390005033504`, 0.937150681498242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.03434177932816089], {
             RGBColor[
             0.2522134290242518, 0.3824226835324653, 0.9376745537153752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.03434177932816089], {
             RGBColor[
             0.9594092884334661, 0.9692480942916449, 0.9535936663157671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.03434177932816089], {
             RGBColor[
             0.3044111891973746, 0.4372858390035616, 0.9406471389375684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.03434177932816089], {
             RGBColor[
             0.2215913444714862, 0.35023693111520926`, 0.9359306713014096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.03434177932816089], {
             RGBColor[
             0.3224078413052081, 0.4536752002744616, 0.941764520447276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.03434177932816089], {
             RGBColor[
             0.20347429876271564`, 0.33119476738824843`, 0.9348989323500625]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.03434177932816089], {
             RGBColor[
             0.17892956896395254`, 0.30539670014399584`, 0.9335011462986966]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.03434177932816089], {
             RGBColor[
             0.28222472928714576`, 0.41396646293510553`, 0.9393836528676069]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.03434177932816089], {
             RGBColor[
             0.18991457468017128`, 0.31694263764133146`, 0.9341267261233757]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.03434177932816089], {
             RGBColor[
             0.9946101233350695, 0.9908799237508646, 0.6547233713644478]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.03434177932816089], {
             RGBColor[
             0.6241927467762723, 0.7057868172525964, 0.96355788600105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.03434177932816089], {
             RGBColor[
             0.43622064479054923`, 0.5522541302556329, 0.9490165716446514]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.03434177932816089], {
             RGBColor[
             0.9476938047146304, 0.9605107057164812, 0.973424924364235]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.03434177932816089], {
             RGBColor[
             0.9926251659969516, 0.9866343007146026, 0.4386730148470409]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.03434177932816089], {
             RGBColor[
             0.22593857337368983`, 0.3548061443216573, 0.9361782395562414]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.03434177932816089], {
             RGBColor[
             0.8327720947194103, 0.2529062576026711, 0.17901590095508144`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.03434177932816089], {
             RGBColor[
             0.23926061251081787`, 0.3688084521208458, 0.93693690997691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.03434177932816089], {
             RGBColor[
             0.23590943272644063`, 0.36528614969039486`, 0.9367460652458159]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.03434177932816089], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.03434177932816089], {
             RGBColor[
             0.324831212684851, 0.4557742027613212, 0.9419189355286837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.03434177932816089], {
             RGBColor[
             0.2067120462521808, 0.3345978452847238, 0.9350833172797693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.03434177932816089], {
             RGBColor[
             0.35014705105926486`, 0.47770150955020474`, 0.9435320383639844]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.03434177932816089], {
             RGBColor[
             0.27400077350385804`, 0.40532256397795713`, 0.9389153107520011]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.03434177932816089], {
             RGBColor[
             0.9900957369634822, 0.9901723469535194, 0.8138028001335977]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.03434177932816089], {
             RGBColor[
             0.9929076697798414, 0.9872385477406899, 0.46942180820333496`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.03434177932816089], {
             RGBColor[
             0.8455662065044656, 0.351247407198139, 0.19126755684933291`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.03434177932816089], {
             RGBColor[
             0.7066839033025902, 0.7707861033473555, 0.971399305210804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.03434177932816089], {
             RGBColor[
             0.25547870703592473`, 0.385854697753317, 0.9378605064675941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.03434177932816089], {
             RGBColor[
             0.3280740134091542, 0.4585829537608091, 0.9421255639233401]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.03434177932816089], {
             RGBColor[
             0.8990024464838272, 0.6342755227085348, 0.23743750448057996`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.03434177932816089], {
             RGBColor[
             0.6590237495828186, 0.7335536290308857, 0.9666489864974762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.03434177932816089], {
             RGBColor[
             0.39675004724917656`, 0.5180666825152114, 0.9465015400717941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.03434177932816089], {
             RGBColor[
             0.3157094904678022, 0.4478734254480028, 0.9413377074550355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.03434177932816089], {
             RGBColor[
             0.26920385108875294`, 0.4002806943772341, 0.9386421331168716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.03434177932816089], {
             RGBColor[
             0.23045057360750168`, 0.3595485426447314, 0.9364351912946507]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.03434177932816089], {
             RGBColor[
             0.22619261942112945`, 0.35507316282496604`, 0.9361927071028155]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.03434177932816089], {
             RGBColor[
             0.23881348570074337`, 0.36833849349398035`, 0.9369114467665411]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.03434177932816089], {
             RGBColor[
             0.2939489691399074, 0.4262893823800991, 0.9400513309827632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.03434177932816089], {
             RGBColor[
             0.9620063021321176, 0.9711849428558795, 0.9491975995336027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.03434177932816089], {
             RGBColor[
             0.443273542823118, 0.5583629960424816, 0.9494659760706539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.03434177932816089], {
             RGBColor[
             0.25329610735962166`, 0.38356064710871024`, 0.9377362106448954]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.03434177932816089], {
             RGBColor[
             0.27348165172589245`, 0.40477693407509363`, 0.9388857475347178]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.03434177932816089], {
             RGBColor[
             0.7412000832467709, 0.797750405452433, 0.9748395554555993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.03434177932816089], {
             RGBColor[
             0.21230278460535462`, 0.3404740657671945, 0.9354017015582263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.03434177932816089], {
             RGBColor[
             0.2276990046313701, 0.35665646919126776`, 0.9362784935120415]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.03434177932816089], {
             RGBColor[
             0.34598043724619154`, 0.47409259808542004`, 0.9432665454162072]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.03434177932816089], {
             RGBColor[
             0.40363205630183896`, 0.524027532856795, 0.9469400556031081]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.03434177932816089], {
             RGBColor[
             0.2473937360801429, 0.37735688066202433`, 0.937400079332305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.03434177932816089], {
             RGBColor[
             0.5902199940802382, 0.6782062061588879, 0.9608834264625246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.03434177932816089], {
             RGBColor[
             0.21627103797903324`, 0.3446449516647265, 0.9356276877173526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.03434177932816089], {
             RGBColor[
             0.2845267439871254, 0.4163860263409461, 0.9395147491992453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.03434177932816089], {
             RGBColor[
             0.2413593551772921, 0.3710143637312809, 0.9370564302669542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.03434177932816089], {
             RGBColor[
             0.38392426951059677`, 0.5069576384803866, 0.9456842928556817]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.03434177932816089], {
             RGBColor[
             0.9802603651545728, 0.9450757179590131, 0.3778156754531135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.03434177932816089], {
             RGBColor[
             0.9927232541779302, 0.9868441014154793, 0.4493493080164732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.03434177932816089], {
             RGBColor[
             0.7539264605068086, 0.8076923480920241, 0.9761080018061227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.03434177932816089], {
             RGBColor[
             0.3858730274799788, 0.5086455546860418, 0.9458084659902717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.03434177932816089], {
             RGBColor[
             0.2930250557635406, 0.42531829084204614`, 0.9399987154827865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.03434177932816089], {
             RGBColor[
             0.8218934398484693, 0.16928814920765783`, 0.168598488764985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.03434177932816089], {
             RGBColor[
             0.4183533072547869, 0.5367783405206518, 0.9478780806963388]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.03434177932816089], {
             RGBColor[
             0.26949540103514497`, 0.4005871318562264, 0.9386587364550091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.03434177932816089], {
             RGBColor[
             0.25717362368840185`, 0.38763616261899303`, 0.9379570294635482]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.03434177932816089], {
             RGBColor[
             0.3923234880848031, 0.5142326194523638, 0.9462194836360928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.03434177932816089], {
             RGBColor[
             0.2945111830148827, 0.42688030480911665`, 0.9400833482312222]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.03434177932816089], {
             RGBColor[
             0.1789518783186532, 0.305420148690281, 0.9335024167834431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.03434177932816089], {
             RGBColor[
             0.41920763486506846`, 0.5375183161569235, 0.9479325176962138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.03434177932816089], {
             RGBColor[
             0.27705635157752495`, 0.4085341702682206, 0.9390893214029737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.03434177932816089], {
             RGBColor[
             0.9936465744084931, 0.9916407094893913, 0.7549562343970292]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.03434177932816089], {
             RGBColor[
             0.23402613491596813`, 0.3633066842836104, 0.936638814221599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.03434177932816089], {
             RGBColor[
             0.7138170777657293, 0.7763585934520937, 0.9721102733779844]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.03434177932816089], {
             RGBColor[
             0.3071831062866214, 0.4401992996140543, 0.9408049955151171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.03434177932816089], {
             RGBColor[
             0.25458949129815345`, 0.38492007563338526`, 0.9378098669468048]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.03434177932816089], {
             RGBColor[
             0.23743710807503443`, 0.3668918333419784, 0.9368330640969252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.03434177932816089], {
             RGBColor[
             0.5680702998089695, 0.6602240865171163, 0.9591397213924867]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.03434177932816089], {
             RGBColor[
             0.2299691131158081, 0.3590424971416032, 0.9364077728319058]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.03434177932816089], {
             RGBColor[
             0.3639294956023307, 0.48963917028760373`, 0.9444102435429313]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.03434177932816089], {
             RGBColor[
             0.20571498311483435`, 0.33354986870991854`, 0.9350265360091202]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.03434177932816089], {
             RGBColor[
             0.2318484494359024, 0.3610177987708272, 0.9365147982551062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.03434177932816089], {
             RGBColor[
             0.22813210557574862`, 0.35711168574399543`, 0.9363031579701084]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.03434177932816089], {
             RGBColor[
             0.24388899418338073`, 0.37367317471505657`, 0.9372004894660854]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.03434177932816089], {
             RGBColor[
             0.8649861375675162, 0.47981540863036076`, 0.20905346250477896`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.03434177932816089], {
             RGBColor[
             0.39949775357450523`, 0.5204466076304757, 0.9466766214891428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.03434177932816089], {
             RGBColor[
             0.5158331891976378, 0.6178156468678216, 0.9550274246943216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.03434177932816089], {
             RGBColor[
             0.8191437574953648, 0.1481528857232069, 0.16596538983833015`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.03434177932816089], {
             RGBColor[
             0.2809324202458739, 0.4126081641956031, 0.9393100577795065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.03434177932816089], {
             RGBColor[
             0.2105002400012672, 0.3385794771003698, 0.9352990493096494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.03434177932816089], {
             RGBColor[
             0.4642553566460736, 0.5759424388475844, 0.9509670287800365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.03434177932816089], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.03434177932816089], {
             RGBColor[
             0.8859959599380017, 0.5752161050460523, 0.226584573288584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.03434177932816089], {
             RGBColor[
             0.32111303850258816`, 0.4525537071655133, 0.9416820167576422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.03434177932816089], {
             RGBColor[
             0.22812105044609293`, 0.3571000661017916, 0.9363025283968291]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.03434177932816089], {
             RGBColor[
             0.2595939437592997, 0.3901800724706624, 0.9380948631110431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.03434177932816089], {
             RGBColor[
             0.23088271225706164`, 0.36000274776459185`, 0.9364598009514513]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.03434177932816089], {
             RGBColor[
             0.5294468131435418, 0.6288678000738763, 0.9560991390396908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.03434177932816089], {
             RGBColor[
             0.23667377020378227`, 0.366089516840876, 0.9367895931344146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.03434177932816089], {
             RGBColor[
             0.7455882739599426, 0.8011784933890475, 0.9752769292959146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.03434177932816089], {
             RGBColor[
             0.28595975701387044`, 0.41789221389032877`, 0.9395963571711656]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.03434177932816089], {
             RGBColor[
             0.2651563206276758, 0.3960264832343887, 0.938411632244898]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.03434177932816089], {
             RGBColor[
             0.37855708825470646`, 0.5023088558389079, 0.9453423008120684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.03434177932816089], {
             RGBColor[
             0.24235927283690456`, 0.3720653405899749, 0.9371133740984234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.03434177932816089], {
             RGBColor[
             0.21172080019279638`, 0.3398623632496528, 0.9353685584068999]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.03434177932816089], {
             RGBColor[
             0.42787872382047937`, 0.5450287775884974, 0.9484850318169096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.03434177932816089], {
             RGBColor[
             0.21288213693655111`, 0.34108300180034146`, 0.9354346948164131]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.03434177932816089], {
             RGBColor[
             0.9951032288756773, 0.9922430735458843, 0.7308157001748675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.03434177932816089], {
             RGBColor[
             0.2588379470720171, 0.38938547201937, 0.9380518102180992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.03434177932816089], {
             RGBColor[
             0.80703569950506, 0.8491816892426243, 0.9814014344154122]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.03434177932816089], {
             RGBColor[
             0.2560427236071457, 0.38644751493038626`, 0.9378926263769374]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.03434177932816089], {
             RGBColor[
             0.27423499655804673`, 0.4055687472585089, 0.9389286494084351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.03434177932816089], {
             RGBColor[
             0.25719173910326026`, 0.38765520306859286`, 0.937958061109625]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.03434177932816089], {
             RGBColor[
             0.29461336050310216`, 0.4269876998276622, 0.9400891670880182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.03434177932816089], {
             RGBColor[
             0.43613267935432526`, 0.5521779390160471, 0.94901096656484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.03434177932816089], {
             RGBColor[
             0.8873547734207121, 0.5813861597120881, 0.22771840056612383`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.03434177932816089], {
             RGBColor[
             0.9695247134417432, 0.9088618438807439, 0.33610969580648287`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.03434177932816089], {
             RGBColor[
             0.9609628542707439, 0.8799806824768295, 0.3028484896985869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.03434177932816089], {
             RGBColor[
             0.178927010221482, 0.30539401074342565`, 0.9335010005820983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.03434177932816089], {
             RGBColor[
             0.25976518882652405`, 0.3903600618938796, 0.9381046152642871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.03434177932816089], {
             RGBColor[
             0.8163432429187892, 0.8564528128973794, 0.9823291233589543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.03434177932816089], {
             RGBColor[
             0.34638875058307517`, 0.4744462585754037, 0.9432925627809762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.03434177932816089], {
             RGBColor[
             0.24935218422087857`, 0.37941533383072157`, 0.9375116100566555]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.03434177932816089], {
             RGBColor[
             0.44511934956958094`, 0.5599617410733233, 0.9495835892443556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.03434177932816089], {
             RGBColor[
             0.9940965401504851, 0.9897814212502639, 0.5988230111904562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.03434177932816089], {
             RGBColor[
             0.9940884990666902, 0.9897642221851048, 0.5979477888431959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.03434177932816089], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.03434177932816089], {
             RGBColor[
             0.24203916924704705`, 0.37172889142129484`, 0.937095144672532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.03434177932816089], {
             RGBColor[
             0.6232106502631707, 0.7049895070603167, 0.9634805717660004]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.03434177932816089], {
             RGBColor[
             0.638779311088947, 0.7176288472788594, 0.9647061937760893]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.03434177932816089], {
             RGBColor[
             0.2785145923880161, 0.4100668738178543, 0.9391723660598572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.03434177932816089], {
             RGBColor[
             0.4111342730563943, 0.530525575937213, 0.9474180902207585]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.03434177932816089], {
             RGBColor[
             0.9949335587465892, 0.9915717193917691, 0.6899273198963884]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.03434177932816089], {
             RGBColor[
             0.2790754121939759, 0.4106563309919474, 0.9392043039181481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.03434177932816089], {
             RGBColor[
             0.24043240470913427`, 0.3700400800171928, 0.9370036418090929]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.03434177932816089], {
             RGBColor[
             0.21816661637866602`, 0.3466373247493527, 0.9357356381029547]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.03434177932816089], {
             RGBColor[
             0.24251120685435607`, 0.3722250328754895, 0.9371220265159511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.03434177932816089], {
             RGBColor[
             0.4244026220080174, 0.5420179529125, 0.9482635376832157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.03434177932816089], {
             RGBColor[
             0.5988679170367666, 0.6852269795994871, 0.961564222636048]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.03434177932816089], {
             RGBColor[
             0.5790882470358998, 0.6691689524288044, 0.9600070945582612]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.03434177932816089], {
             RGBColor[
             0.20835094833068457`, 0.3363204352816248, 0.9351766503286018]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.03434177932816089], {
             RGBColor[
             0.8185799679311427, 0.1438193520784336, 0.16542550431492184`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.03434177932816089], {
             RGBColor[
             0.22258326386374316`, 0.3512795012877932, 0.9359871596433854]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.03434177932816089], {
             RGBColor[
             0.2867137638335649, 0.4186847228646212, 0.9396392967440941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.03434177932816089], {
             RGBColor[
             0.30053129972337833`, 0.4332078291671907, 0.9404261849718064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.03434177932816089], {
             RGBColor[
             0.29672537087035056`, 0.42920755663283183`, 0.9402094429539937]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.03434177932816089], {
             RGBColor[
             0.8913219113450659, 0.5994000064779764, 0.23102867769365362`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.03434177932816089], {
             RGBColor[
             0.9589543367125869, 0.8732054811308165, 0.29504577826186157`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.03434177932816089], {
             RGBColor[
             0.9952479751456992, 0.992244224277091, 0.7241496045864151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.03434177932816089], {
             RGBColor[
             0.39130532114623406`, 0.5133507344247334, 0.9461546069390968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.03434177932816089], {
             RGBColor[
             0.9617670348256762, 0.9710064976904998, 0.9496026166724999]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.03434177932816089], {
             RGBColor[
             0.46426084954242974`, 0.5759468982282985, 0.9509674612009588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.03434177932816089], {
             RGBColor[
             0.8491537797280463, 0.8825561905625664, 0.9854742396306309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.03434177932816089], {
             RGBColor[
             0.4006413843936947, 0.5214371631655013, 0.9467494926336685]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.03434177932816089], {
             RGBColor[
             0.9939797374120591, 0.9895315920033393, 0.5861097539357399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.03434177932816089], {
             RGBColor[
             0.26098356523640104`, 0.3916406527501864, 0.9381739999984032]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.03434177932816089], {
             RGBColor[
             0.2946613034028385, 0.4270380908550406, 0.940091897365233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.03434177932816089], {
             RGBColor[
             0.22246582468563886`, 0.3511560652655316, 0.9359804716559281]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.03434177932816089], {
             RGBColor[
             0.24763395401992835`, 0.3776093649474359, 0.9374137593886052]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.03434177932816089], {
             RGBColor[
             0.467847246129772, 0.578858496543228, 0.9512497954777179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.03434177932816089], {
             RGBColor[
             0.2625163578880115, 0.3932517150116962, 0.938261290272349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.03434177932816089], {
             RGBColor[
             0.2270252964366493, 0.35594835916304945`, 0.9362401268270142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.03434177932816089], {
             RGBColor[
             0.22825539451058077`, 0.357241270231474, 0.9363101790925575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.03434177932816089], {
             RGBColor[
             0.9774649456708626, 0.9356461116447503, 0.3669559986295733]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.03434177932816089], {
             RGBColor[
             0.22328031209840418`, 0.35201214317783264`, 0.936026855509159]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.03434177932816089], {
             RGBColor[
             0.6178350891255162, 0.7006253843624993, 0.9630573879019151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.03434177932816089], {
             RGBColor[
             0.9645754531953188, 0.8921668269279859, 0.3168827543384975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.03434177932816089], {
             RGBColor[
             0.21277857456934213`, 0.34097415118617147`, 0.9354287970928072]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.03434177932816089], {
             RGBColor[
             0.23178154572615212`, 0.3609474787299394, 0.9365109881878111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.03434177932816089], {
             RGBColor[
             0.34909505354151776`, 0.4767903221752649, 0.9434650060123984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.03434177932816089], {
             RGBColor[
             0.6029315110482949, 0.6885259882808699, 0.9618841236420709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.03434177932816089], {
             RGBColor[
             0.25879261498995565`, 0.3893378251269034, 0.9380492286230886]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.03434177932816089], {
             RGBColor[
             0.2680583595238526, 0.3990767101141639, 0.9385768990668534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.03434177932816089], {
             RGBColor[
             0.8360763947567734, 0.2783045556433535, 0.18218010240253352`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.03434177932816089], {
             RGBColor[
             0.9636570397640628, 0.9724160602789496, 0.9464033313040466]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.03434177932816089], {
             RGBColor[
             0.6187231293682252, 0.7013463354372874, 0.9631272976828197]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.03434177932816089], {
             RGBColor[
             0.25564421936180226`, 0.3860286617019018, 0.9378699321496993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.03434177932816089], {
             RGBColor[
             0.382771346863294, 0.50595903483087, 0.945610829644085]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.03434177932816089], {
             RGBColor[
             0.5590358689967736, 0.6528895285873056, 0.9584284979047402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.03434177932816089], {
             RGBColor[
             0.9409750107809423, 0.8036926171977683, 0.27136531206102255`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.03434177932816089], {
             RGBColor[
             0.8619011142240809, 0.46580703815332913`, 0.20647924340617463`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.03434177932816089], {
             RGBColor[
             0.2909832679823188, 0.4231722424271597, 0.9398824386892002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.03434177932816089], {
             RGBColor[
             0.6129287179190951, 0.6966421711876226, 0.9626711403879157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.03434177932816089], {
             RGBColor[
             0.8179080138731872, 0.1386544187368418, 0.16478204035016009`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.03434177932816089], {
             RGBColor[
             0.24306150835744214`, 0.3728034346463635, 0.9371533653724538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.03434177932816089], {
             RGBColor[
             0.20926131084396443`, 0.33727728400339907`, 0.9352284941269724]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.03434177932816089], {
             RGBColor[
             0.209897553009386, 0.33794601485934034`, 0.9352647271770572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.03434177932816089], {
             RGBColor[
             0.8372847792405768, 0.8730921717492939, 0.9843421637685542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.03434177932816089], {
             RGBColor[
             0.6962355794932261, 0.7626237933772783, 0.9703579139386239]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.03434177932816089], {
             RGBColor[
             0.7603990286995737, 0.8127487675575523, 0.9767531269139887]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.03434177932816089], {
             RGBColor[
             0.28525208052382683`, 0.41714840103001194`, 0.9395560560419711]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.03434177932816089], {
             RGBColor[
             0.9944845479757449, 0.9919872330943883, 0.7410688437815899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.03434177932816089], {
             RGBColor[
             0.2558608387541249, 0.3862563424176957, 0.9378822683036323]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{3.8349502435193233`*^9, 3.834957407142641*^9, 
  3.835018921852682*^9, 3.8350190129675236`*^9, 3.8350205474078445`*^9, 
  3.8350446401426015`*^9, 3.835045030495333*^9, 3.835045409247921*^9},
 CellLabel->
  "Out[299]=",ExpressionUUID->"56c87920-5717-454f-a542-41ab6f888b45"]
}, Open  ]],

Cell["Estimated with absolute Mean Deviation v Calculated: (r=6)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 
  3.8349503922098827`*^9}},ExpressionUUID->"4bdf7cd2-84d2-4523-80d9-\
d3ef8d0b79ce"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraphb", "[", 
     RowBox[{"graphinf3", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsif3", ",", "#"}], "}"}], "]"}], ",", "500", ",", "3"}],
      "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"AMDi6f300", ",", "krif3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502409842243`*^9}, {3.8349504019691753`*^9, 3.834950402221115*^9}, {
   3.8349577477528667`*^9, 3.8349577551942053`*^9}, {3.835018833417392*^9, 
   3.8350188346728773`*^9}, {3.8350443403897114`*^9, 
   3.8350443452390656`*^9}, {3.8350449339623103`*^9, 3.835044937670579*^9}, {
   3.835045282278721*^9, 3.835045284084992*^9}, {3.8350520325248504`*^9, 
   3.835052035216877*^9}},
 CellLabel->
  "In[414]:=",ExpressionUUID->"44b5cc8c-69d2-4b56-ac7b-538aac84629b"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1FO4EAYYBuBzsm2dTrZdW7WsZbtVy3bLtWxr2bat5WVjyzZXrfc8u3i/
//a7+f7gJu2rtAsMCAjIJEJuKEIThrCEIzwRiEgkIhOFqEQjOjGISSxiE4e4
xCM+CUhIIhKThKQkI4jkBJOClKQiNWlISzrSk4GMIX3JTBayko3s5CAnuchN
HvKSj/wUoCCF+IEfKUwRivITxShOCUpSitKUoSzlKE8FfqYilahMFapSjerU
oCa1qE0d6lKP+jSgIY1oTBN+oSnNaM6vtKAlrWhNG9rSjvZ0oCOd6EwXutKN
7vSgJ73ozW/0oS/96M8ABjKIwQzhd4YyjOGMYCSjGM0YxjKO8UxgIpOYzBSm
Mo3pzGAms5jNH8xhLvOYzwIWsojFLGEpy1jOClayitWsYS3rWM8GNrKJzWxh
K9vYzg52sovd7GEv+9jPAQ5yiMMc4U+OcozjnOAkpzjNX5zhLOc4zwUuconL
XOEq17jODW5yi9v8zT/c4S73uM8DHvKIxzzhKc94zgte8orXvOEt73jPBz7y
ic/8yxe+8o3/CBl/IKEITRjCEo7wRCAikYhMFKISjejEICaxiE0c4hKP+CQg
IYlITBKSkowgkhNMClKSitSkIS3pSE8GMgb+/6++Az6VhWw=
          "], {Null, CompressedData["
1:eJxN2nu4llWZB+C1RcxDZpqQRxAUUVHStBgOUSMyo5BNY0aKowyCpqCIyVg4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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[57, 280] -> 
             RGBColor[
              0.6864911358853162, 0.7541086923301018, 0.9700038376622893], 
             UndirectedEdge[46, 187] -> 
             RGBColor[
              0.8804065400138319, 0.9074638797904837, 0.9880247723019371], 
             UndirectedEdge[96, 298] -> 
             RGBColor[
              0.7660904457053719, 0.8167684520036422, 0.9598775087724766], 
             UndirectedEdge[165, 207] -> 
             RGBColor[
              0.8326142411113925, 0.8693680114234624, 0.9838966836723539], 
             UndirectedEdge[69, 224] -> 
             RGBColor[
              0.7217816498319958, 0.7813356171636294, 0.9708471975698616], 
             UndirectedEdge[51, 110] -> 
             RGBColor[
              0.6097358188348763, 0.6924304661556685, 0.9635270896019487], 
             UndirectedEdge[122, 231] -> 
             RGBColor[
              0.2765436993680016, 0.40194733218092393`, 0.9392815738218883], 
             UndirectedEdge[71, 246] -> 
             RGBColor[
              0.5742299911986046, 0.6652248014781568, 0.9596246348623718], 
             UndirectedEdge[9, 239] -> 
             RGBColor[
              0.5639450282700239, 0.6568750052404352, 0.9588149649055733], 
             UndirectedEdge[99, 229] -> 
             RGBColor[
              0.5072664903721023, 0.6108608148358678, 0.9543530227819236], 
             UndirectedEdge[49, 112] -> 
             RGBColor[
              0.5737632034723755, 0.6583166318648173, 0.962572819767274], 
             UndirectedEdge[115, 243] -> 
             RGBColor[
              0.9085994192280958, 0.9284329253797254, 0.9359294652789708], 
             UndirectedEdge[58, 95] -> 
             RGBColor[
              0.5708632735481443, 0.6605169674422793, 0.9603790631866269], 
             UndirectedEdge[210, 239] -> 
             RGBColor[
              0.7129047009004919, 0.774970173723363, 0.9725355027858229], 
             UndirectedEdge[94, 150] -> 
             RGBColor[
              0.6269238217404183, 0.7023176035297372, 0.9669011714753261], 
             UndirectedEdge[21, 108] -> 
             RGBColor[
              0.605383301289114, 0.6877156037901633, 0.9637217878372802], 
             UndirectedEdge[83, 202] -> 
             RGBColor[
              0.8596593076943806, 0.8909454939055056, 0.9864729543234936], 
             UndirectedEdge[172, 174] -> 
             RGBColor[
              0.8361101760942842, 0.8726832639274857, 0.9840900966778156], 
             UndirectedEdge[3, 157] -> 
             RGBColor[
              0.6462680588322194, 0.7197592453259812, 0.9678176729380832], 
             UndirectedEdge[181, 246] -> 
             RGBColor[
              0.660822524037127, 0.7336193274443668, 0.9677441072022066], 
             UndirectedEdge[159, 253] -> 
             RGBColor[
              0.7186746239428103, 0.7796123686718989, 0.9730381753658928], 
             UndirectedEdge[170, 228] -> 
             RGBColor[
              0.5531265702632941, 0.6480920936645927, 0.9579632962619662], 
             UndirectedEdge[151, 194] -> 
             RGBColor[
              0.703445832743784, 0.7681012410951802, 0.9711827146040808], 
             UndirectedEdge[62, 100] -> 
             RGBColor[
              0.7633717895921435, 0.8141442515373767, 0.9484770168006762], 
             UndirectedEdge[76, 99] -> 
             RGBColor[
              0.39810876208201706`, 0.5175909523560585, 0.9469103604293232], 
             UndirectedEdge[131, 283] -> 
             RGBColor[
              0.99040306955434, 0.9884335328412222, 0.6730779777678136], 
             UndirectedEdge[173, 263] -> 
             RGBColor[
              0.7420457573014925, 0.7984373740829842, 0.9750492261338927], 
             UndirectedEdge[20, 75] -> 
             RGBColor[
              0.6469383608003022, 0.7209996170081585, 0.9675566464969323], 
             UndirectedEdge[175, 253] -> 
             RGBColor[
              0.8552038623954673, 0.8873803622564488, 0.986051301916422], 
             UndirectedEdge[52, 193] -> 
             RGBColor[
              0.48044367165591834`, 0.5859811368259326, 0.9530989952929368], 
             UndirectedEdge[282, 283] -> 
             RGBColor[
              0.9059026729535493, 0.9258849364309187, 0.9184037531649666], 
             UndirectedEdge[173, 279] -> 
             RGBColor[
              0.7045374996653679, 0.7679864808062279, 0.972096438695502], 
             UndirectedEdge[95, 198] -> 
             RGBColor[
              0.4124523179364444, 0.5316672001654504, 0.947502074875014], 
             UndirectedEdge[18, 288] -> 
             RGBColor[
              0.7842618569368547, 0.8319159710518603, 0.9789921307351145], 
             UndirectedEdge[29, 91] -> 
             RGBColor[
              0.8963377724833197, 0.9168961581543345, 0.8471845064832115], 
             UndirectedEdge[46, 169] -> 
             RGBColor[
              0.9644659866053434, 0.969414363385533, 0.7226739380561804], 
             UndirectedEdge[34, 264] -> 
             RGBColor[
              0.6843717469648043, 0.7520163176388337, 0.9700911654586043], 
             UndirectedEdge[116, 277] -> 
             RGBColor[
              0.6314975482838469, 0.7094789530545874, 0.9656632375882145], 
             UndirectedEdge[60, 299] -> 
             RGBColor[
              0.8714795121931077, 0.8946191431552235, 0.6990241024809445], 
             UndirectedEdge[205, 213] -> 
             RGBColor[
              0.9417322881742011, 0.9557807311899651, 0.9736737369662734], 
             UndirectedEdge[240, 299] -> 
             RGBColor[
              0.9892405621445579, 0.9862132652482025, 0.6453592292433536], 
             UndirectedEdge[184, 214] -> 
             RGBColor[
              0.8320665059442035, 0.8696197803758261, 0.981043869811953], 
             UndirectedEdge[39, 59] -> 
             RGBColor[
              0.8542414067700201, 0.8290140577504801, 0.6284031379385278], 
             UndirectedEdge[246, 299] -> 
             RGBColor[
              0.7733012529271497, 0.8165820229728336, 0.6901544468029382], 
             UndirectedEdge[21, 114] -> 
             RGBColor[
              0.7048996881444562, 0.7655932648331953, 0.9328673296687409], 
             UndirectedEdge[204, 253] -> 
             RGBColor[
              0.7732563349085164, 0.8229695934441061, 0.9779877586806851], 
             UndirectedEdge[202, 214] -> 
             RGBColor[
              0.9197417732553649, 0.9387662075471656, 0.9896090115249216], 
             UndirectedEdge[26, 39] -> 
             RGBColor[
              0.7450067623619886, 0.7420761811638797, 0.6186115897496699], 
             UndirectedEdge[118, 220] -> 
             RGBColor[
              0.8883220295580906, 0.910634198859243, 0.8463855721398013], 
             UndirectedEdge[28, 126] -> 
             RGBColor[
              0.9377702872312974, 0.9523431319095955, 0.9636432828133437], 
             UndirectedEdge[9, 237] -> 
             RGBColor[
              0.7446189517993956, 0.7994859983501085, 0.962185519999929], 
             UndirectedEdge[174, 297] -> 
             RGBColor[
              0.8330901133945088, 0.8702751479081029, 0.9838020404014691], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.5102132601320107, 0.6083406987560154, 0.9563639384621566], 
             UndirectedEdge[63, 139] -> 
             RGBColor[
              0.6412162028156452, 0.7137139602427739, 0.9682643915412404], 
             UndirectedEdge[124, 150] -> 
             RGBColor[
              0.6413394319845045, 0.7148036805735265, 0.9678197214128557], 
             UndirectedEdge[127, 165] -> 
             RGBColor[
              0.7067840937936154, 0.7699664866687586, 0.9720936080861395], 
             UndirectedEdge[8, 22] -> 
             RGBColor[
              0.8686974022422034, 0.8976928798877588, 0.9571964243330248], 
             UndirectedEdge[127, 137] -> 
             RGBColor[
              0.4659556527380001, 0.5747660912082824, 0.9518073129426872], 
             UndirectedEdge[21, 213] -> 
             RGBColor[
              0.676786017561744, 0.7443422500927679, 0.970613960857273], 
             UndirectedEdge[41, 278] -> 
             RGBColor[
              0.7754998647771321, 0.8246810087004941, 0.9782223185437371], 
             UndirectedEdge[69, 249] -> 
             RGBColor[
              0.6984456551881135, 0.7628217984726986, 0.9718689872494046], 
             UndirectedEdge[100, 136] -> 
             RGBColor[
              0.5657055166065647, 0.6583042489811348, 0.958953556996307], 
             UndirectedEdge[88, 222] -> 
             RGBColor[
              0.6076157780558329, 0.6915326615626585, 0.9627972701587652], 
             UndirectedEdge[153, 216] -> 
             RGBColor[
              0.5681551149723088, 0.6562805693497424, 0.9610067470999871], 
             UndirectedEdge[60, 121] -> 
             RGBColor[
              0.8720558085013888, 0.8963555909178077, 0.7189101837048393], 
             UndirectedEdge[203, 206] -> 
             RGBColor[
              0.49704251622604767`, 0.5999215712809964, 0.9542773068058065], 
             UndirectedEdge[50, 108] -> 
             RGBColor[
              0.8055076070922157, 0.3659292106722779, 0.43577687664064135`], 
             UndirectedEdge[98, 181] -> 
             RGBColor[
              0.5297821962418141, 0.6214063363618406, 0.9586859815566375], 
             UndirectedEdge[267, 285] -> 
             RGBColor[
              0.6040229696245509, 0.6892107739489559, 0.9621076837143752], 
             UndirectedEdge[156, 178] -> 
             RGBColor[
              0.5884589593480679, 0.6555882372103161, 0.9331327665514366], 
             UndirectedEdge[185, 295] -> 
             RGBColor[
              0.7131872721659598, 0.7749139648493616, 0.9728864831060621], 
             UndirectedEdge[83, 156] -> 
             RGBColor[
              0.5113941403794997, 0.5951021122033315, 0.95874340396191], 
             UndirectedEdge[44, 150] -> 
             RGBColor[
              0.796675472743786, 0.8416610394458919, 0.9802168102177926], 
             UndirectedEdge[223, 274] -> 
             RGBColor[
              0.5861435595510183, 0.6699302389407891, 0.9629702527872146], 
             UndirectedEdge[20, 142] -> 
             RGBColor[
              0.6482206902673643, 0.7220221117172877, 0.9676789562262497], 
             UndirectedEdge[87, 264] -> 
             RGBColor[
              0.7028412115899998, 0.7666935245254187, 0.9718660262463599], 
             UndirectedEdge[16, 192] -> 
             RGBColor[
              0.6359747065465486, 0.7024199699111613, 0.8908131852992442], 
             UndirectedEdge[75, 143] -> 
             RGBColor[
              0.8994051827479433, 0.9223311131224192, 0.9800677827951625], 
             UndirectedEdge[230, 263] -> 
             RGBColor[
              0.7500368992328785, 0.8048092937453022, 0.975811428385085], 
             UndirectedEdge[52, 82] -> 
             RGBColor[
              0.8073106484241704, 0.847587078756935, 0.8666377065065995], 
             UndirectedEdge[34, 213] -> 
             RGBColor[
              0.8692537939278009, 0.8986332391503842, 0.9873781701645792], 
             UndirectedEdge[145, 219] -> 
             RGBColor[
              0.5259676513100143, 0.6210161468573339, 0.9577784347572715], 
             UndirectedEdge[237, 295] -> 
             RGBColor[
              0.9133139155450951, 0.9333175522681155, 0.9777884275646518], 
             UndirectedEdge[257, 259] -> 
             RGBColor[
              0.45610034769127117`, 0.5664348194985634, 0.9511227276422616], 
             UndirectedEdge[116, 241] -> 
             RGBColor[
              0.5043427507916814, 0.6084871913315151, 0.9541228552921419], 
             UndirectedEdge[95, 105] -> 
             RGBColor[
              0.39830358785993425`, 0.5194122813090283, 0.9466005303057695], 
             UndirectedEdge[115, 146] -> 
             RGBColor[
              0.9644080760115016, 0.9727397730739984, 0.9345451533789515], 
             UndirectedEdge[16, 170] -> 
             RGBColor[
              0.7521375108206942, 0.8036634967691829, 0.8985991697799554], 
             UndirectedEdge[199, 226] -> 
             RGBColor[
              0.6814889878506831, 0.750162726337533, 0.9695314219800943], 
             UndirectedEdge[78, 130] -> 
             RGBColor[
              0.8396928602508804, 0.8755393569515906, 0.9844319866774023], 
             UndirectedEdge[155, 214] -> 
             RGBColor[
              0.8951357033721246, 0.9191459953362437, 0.9872620626133601], 
             UndirectedEdge[185, 297] -> 
             RGBColor[
              0.7311850243829996, 0.7892648839312595, 0.9746031247793063], 
             UndirectedEdge[45, 53] -> 
             RGBColor[
              0.8280729243222475, 0.8659108757656471, 0.9508262738659305], 
             UndirectedEdge[49, 204] -> 
             RGBColor[
              0.7680475039376888, 0.8188162130179184, 0.9774909357327093], 
             UndirectedEdge[69, 254] -> 
             RGBColor[
              0.6474344196259121, 0.7223840251355462, 0.9669405441481723], 
             UndirectedEdge[102, 295] -> 
             RGBColor[
              0.9326906279830687, 0.9468214064152207, 0.9025681890418943], 
             UndirectedEdge[14, 254] -> 
             RGBColor[
              0.6442117869654953, 0.719767746763873, 0.9666868467002518], 
             UndirectedEdge[125, 299] -> 
             RGBColor[
              0.6618187929106012, 0.722780138622453, 0.6822886683141609], 
             UndirectedEdge[16, 44] -> 
             RGBColor[
              0.8454392261172525, 0.8784888380109654, 0.9065740482466711], 
             UndirectedEdge[49, 84] -> 
             RGBColor[
              0.7706657690166281, 0.8208616215971374, 0.9777518999266996], 
             UndirectedEdge[186, 230] -> 
             RGBColor[
              0.6844928791645497, 0.7515977055293779, 0.9706515630296495], 
             UndirectedEdge[215, 282] -> 
             RGBColor[
              0.7475631726807632, 0.8027547153497218, 0.9754649011463515], 
             UndirectedEdge[134, 159] -> 
             RGBColor[
              0.6921706637717233, 0.7587306729917065, 0.9704433726674819], 
             UndirectedEdge[26, 266] -> 
             RGBColor[
              0.7302645206158765, 0.7884356184177113, 0.9746249927569841], 
             UndirectedEdge[142, 150] -> 
             RGBColor[
              0.872562364978715, 0.90122156103233, 0.9877069713889304], 
             UndirectedEdge[114, 221] -> 
             RGBColor[0.874512171360897, 0.90202952517567, 0.947353536949751],
              UndirectedEdge[147, 172] -> 
             RGBColor[
              0.8316605107451938, 0.869207151538067, 0.9836465956203051], 
             UndirectedEdge[35, 211] -> 
             RGBColor[
              0.7476973128572706, 0.8029525854497243, 0.975578131365251], 
             UndirectedEdge[124, 295] -> 
             RGBColor[
              0.6336548124580728, 0.7086761735565902, 0.9670867555422837], 
             UndirectedEdge[166, 233] -> 
             RGBColor[
              0.679709550681646, 0.7448891566839992, 0.947525129405784], 
             UndirectedEdge[88, 290] -> 
             RGBColor[
              0.5926514473845327, 0.6798424127091133, 0.9613057655270709], 
             UndirectedEdge[134, 235] -> 
             RGBColor[
              0.7157404257031995, 0.7778611274788311, 0.9723019747256829], 
             UndirectedEdge[185, 239] -> 
             RGBColor[
              0.5703397487787529, 0.6620665274282974, 0.9593183807286536], 
             UndirectedEdge[260, 278] -> 
             RGBColor[
              0.8511289808507871, 0.883006488875293, 0.910440906047437], 
             UndirectedEdge[15, 242] -> 
             RGBColor[
              0.669928595798696, 0.741999954057659, 0.9677855328886207], 
             UndirectedEdge[4, 266] -> 
             RGBColor[
              0.8528109367321484, 0.8857727522360008, 0.9857433339441398], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.5091748538960031, 0.6077673238123316, 0.9561597764078948], 
             UndirectedEdge[3, 123] -> 
             RGBColor[
              0.7843308809742523, 0.8318559642618542, 0.9790292436312058], 
             UndirectedEdge[28, 184] -> 
             RGBColor[
              0.8157490656750456, 0.8566836294243598, 0.9820854717353205], 
             UndirectedEdge[116, 210] -> 
             RGBColor[
              0.6552711138009496, 0.7281806313524437, 0.9679983756905612], 
             UndirectedEdge[118, 120] -> 
             RGBColor[
              0.6484281756793662, 0.7233309191289238, 0.9669229767813994], 
             UndirectedEdge[15, 89] -> 
             RGBColor[
              0.6788633795212078, 0.7490524987255276, 0.968626415397852], 
             UndirectedEdge[11, 283] -> 
             RGBColor[
              0.8007567913349718, 0.843273677673701, 0.9082314964763614], 
             UndirectedEdge[157, 201] -> 
             RGBColor[
              0.7075111715036679, 0.7639353828692697, 0.7342382023694787], 
             UndirectedEdge[196, 279] -> 
             RGBColor[
              0.5770741583288452, 0.6675338244827553, 0.9598485381173918], 
             UndirectedEdge[7, 11] -> 
             RGBColor[
              0.5541504530812186, 0.6489233278615791, 0.9580439000679994], 
             UndirectedEdge[76, 284] -> 
             RGBColor[
              0.3431500500156586, 0.4710804607145792, 0.9431067218913594], 
             UndirectedEdge[34, 108] -> 
             RGBColor[
              0.797851077655171, 0.8420065928477796, 0.9804859971445863], 
             UndirectedEdge[46, 213] -> 
             RGBColor[
              0.9304353174083249, 0.9473554688898665, 0.9927965617510406], 
             UndirectedEdge[261, 278] -> 
             RGBColor[
              0.7999247369324016, 0.8441567387616133, 0.9805519846542474], 
             UndirectedEdge[58, 66] -> 
             RGBColor[
              0.816558027825572, 0.8573871654621898, 0.9821471094011383], 
             UndirectedEdge[194, 297] -> 
             RGBColor[
              0.7718534561431023, 0.8222813489260833, 0.9778046927008358], 
             UndirectedEdge[283, 297] -> 
             RGBColor[
              0.9495850290121151, 0.9607160614260513, 0.9225702152815323], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.9295603086193355, 0.9449767370741736, 0.9305540184657966], 
             UndirectedEdge[6, 169] -> 
             RGBColor[
              0.9839452674006077, 0.9839419791082462, 0.6897005966798979], 
             UndirectedEdge[11, 172] -> 
             RGBColor[
              0.7656748448596422, 0.8172215670103349, 0.9773685956653688], 
             UndirectedEdge[4, 82] -> 
             RGBColor[
              0.8877786488072447, 0.9107630590719882, 0.8744434806689224], 
             UndirectedEdge[140, 230] -> 
             RGBColor[
              0.6259353992206667, 0.701890879384734, 0.9666405146903205], 
             UndirectedEdge[207, 232] -> 
             RGBColor[
              0.5430318002039529, 0.6275848010053084, 0.960663268203453], 
             UndirectedEdge[147, 244] -> 
             RGBColor[
              0.8652146756189643, 0.894627485246992, 0.9398287913411786], 
             UndirectedEdge[56, 296] -> 
             RGBColor[
              0.7058763578137802, 0.7701552426739242, 0.971318816623421], 
             UndirectedEdge[243, 294] -> 
             RGBColor[
              0.8750153573850186, 0.9031775105924115, 0.9879409399944558], 
             UndirectedEdge[211, 216] -> 
             RGBColor[
              0.692865670812223, 0.7596934426688919, 0.9702256079005532], 
             UndirectedEdge[107, 141] -> 
             RGBColor[
              0.7699716010039984, 0.8198285615914211, 0.9577480121214311], 
             UndirectedEdge[19, 175] -> 
             RGBColor[
              0.7784731906564801, 0.8272611777622665, 0.9784503700042286], 
             UndirectedEdge[17, 158] -> 
             RGBColor[
              0.7181910551167084, 0.7797029540851665, 0.9725958837951153], 
             UndirectedEdge[115, 242] -> 
             RGBColor[
              0.8116165673056673, 0.8525028033128366, 0.9263376545004619], 
             UndirectedEdge[159, 292] -> 
             RGBColor[
              0.5647862820861559, 0.6575579729864236, 0.9588811914875935], 
             UndirectedEdge[34, 205] -> 
             RGBColor[
              0.8862958282800952, 0.9116270457183063, 0.9683729311689429], 
             UndirectedEdge[23, 180] -> 
             RGBColor[
              0.827937200571586, 0.8661806005903601, 0.9833067706599516], 
             UndirectedEdge[47, 158] -> 
             RGBColor[
              0.7279526056938617, 0.787401375303542, 0.9735191706978417], 
             UndirectedEdge[130, 199] -> 
             RGBColor[
              0.6678564680756209, 0.7395128982782667, 0.9681726598120567], 
             UndirectedEdge[112, 204] -> 
             RGBColor[
              0.51039497048276, 0.6087204881631355, 0.956281386226625], 
             UndirectedEdge[217, 247] -> 
             RGBColor[
              0.6060885409304552, 0.6894933192491969, 0.9632236372764024], 
             UndirectedEdge[102, 185] -> 
             RGBColor[
              0.7703903847460982, 0.8181813746850759, 0.8874686973002517], 
             UndirectedEdge[136, 137] -> 
             RGBColor[
              0.4660536789801466, 0.5748456733276888, 0.9518150299275508], 
             UndirectedEdge[138, 258] -> 
             RGBColor[
              0.7715150554833694, 0.8216640317521118, 0.9777996781655038], 
             UndirectedEdge[79, 277] -> 
             RGBColor[
              0.8493069297394262, 0.8829330257537309, 0.9854212530150219], 
             UndirectedEdge[41, 259] -> 
             RGBColor[
              0.7009697289802086, 0.7652756646505239, 0.9716018785276932], 
             UndirectedEdge[225, 287] -> 
             RGBColor[
              0.3605323145365995, 0.47256808550503815`, 0.9452735973222375], 
             UndirectedEdge[167, 194] -> 
             RGBColor[
              0.6615491813640866, 0.7353712586110165, 0.9670068479410201], 
             UndirectedEdge[64, 219] -> 
             RGBColor[
              0.7930751720306842, 0.8385456308513486, 0.9799383266821582], 
             UndirectedEdge[83, 293] -> 
             RGBColor[
              0.860043880529358, 0.8912521418451651, 0.9865096352238059], 
             UndirectedEdge[31, 95] -> 
             RGBColor[
              0.6843407229099476, 0.7499326616852402, 0.9628848209087617], 
             UndirectedEdge[256, 299] -> 
             RGBColor[
              0.6054269230430476, 0.6656541602843706, 0.6789986792294355], 
             UndirectedEdge[129, 269] -> 
             RGBColor[
              0.8120889361991961, 0.8535847570691162, 0.9817842338085827], 
             UndirectedEdge[83, 126] -> 
             RGBColor[
              0.8940052619394712, 0.9174585692194018, 0.9594656236885482], 
             UndirectedEdge[23, 81] -> 
             RGBColor[
              0.7698445391232706, 0.8207122400426995, 0.9775753891854178], 
             UndirectedEdge[235, 252] -> 
             RGBColor[
              0.5563998339817058, 0.6507449365555269, 0.9582240836323122], 
             UndirectedEdge[6, 264] -> 
             RGBColor[
              0.7650325512405924, 0.8152661631010294, 0.9425362156687832], 
             UndirectedEdge[167, 215] -> 
             RGBColor[
              0.6809412539603134, 0.7506757500297874, 0.9688335185031014], 
             UndirectedEdge[273, 285] -> 
             RGBColor[
              0.7707079174449141, 0.818642989871472, 0.896014497892086], 
             UndirectedEdge[267, 273] -> 
             RGBColor[
              0.8221853534523591, 0.8602333818806134, 0.9002046266776903], 
             UndirectedEdge[66, 109] -> 
             RGBColor[
              0.951061974416276, 0.961968137219381, 0.9259417759647162], 
             UndirectedEdge[104, 173] -> 
             RGBColor[
              0.7987395898178458, 0.8430434392853619, 0.9804836046723177], 
             UndirectedEdge[9, 185] -> 
             RGBColor[
              0.5444923084202603, 0.6410824109313545, 0.9572835755413392], 
             UndirectedEdge[233, 288] -> 
             RGBColor[
              0.8229691291864464, 0.8620915599112651, 0.9588119733665523], 
             UndirectedEdge[139, 147] -> 
             RGBColor[
              0.5543943826394346, 0.6450842163700806, 0.959824128427764], 
             UndirectedEdge[65, 103] -> 
             RGBColor[
              0.7864379868837652, 0.8309996819660161, 0.8799590908332804], 
             UndirectedEdge[33, 124] -> 
             RGBColor[
              0.38593208226427733`, 0.5086967049720214, 0.9458122289089071], 
             UndirectedEdge[82, 226] -> 
             RGBColor[
              0.8873932755851401, 0.9104620025819352, 0.8744050702676605], 
             UndirectedEdge[6, 221] -> 
             RGBColor[
              0.871622845159867, 0.8998746704257792, 0.9522444125511317], 
             UndirectedEdge[125, 136] -> 
             RGBColor[
              0.45245123524909586`, 0.5630639202465534, 0.9509482942411771], 
             UndirectedEdge[112, 292] -> 
             RGBColor[
              0.42508369258654866`, 0.5404156166055298, 0.9489126588369505], 
             UndirectedEdge[58, 67] -> 
             RGBColor[
              0.7327302175917669, 0.7911336820293808, 0.9739953584025032], 
             UndirectedEdge[73, 105] -> 
             RGBColor[
              0.45796915892139384`, 0.5686628718344162, 0.951073432585281], 
             UndirectedEdge[263, 298] -> 
             RGBColor[
              0.5991150783977888, 0.6854276363268574, 0.9615836800837696], 
             UndirectedEdge[60, 170] -> 
             RGBColor[
              0.6335815537733597, 0.7117406601638752, 0.9654377107499702], 
             UndirectedEdge[10, 129] -> 
             RGBColor[
              0.8932676151718449, 0.9177313655072876, 0.9896818566361462], 
             UndirectedEdge[53, 234] -> 
             RGBColor[
              0.8531040689519875, 0.8854653961941452, 0.9533211444332771], 
             UndirectedEdge[51, 154] -> 
             RGBColor[
              0.5868135479774355, 0.6745234139461249, 0.9612424118636791], 
             UndirectedEdge[17, 84] -> 
             RGBColor[
              0.6737669774643922, 0.7449985269876819, 0.9681681069013413], 
             UndirectedEdge[98, 160] -> 
             RGBColor[
              0.44933251458609036`, 0.5579988537181189, 0.951050096963918], 
             UndirectedEdge[25, 147] -> 
             RGBColor[
              0.7084029569477375, 0.7721290411202362, 0.9715706444126826], 
             UndirectedEdge[159, 204] -> 
             RGBColor[
              0.6500975599823673, 0.7258628445440294, 0.966249918877268], 
             UndirectedEdge[37, 94] -> 
             RGBColor[
              0.5722342177155803, 0.6590208311193338, 0.9616022364654166], 
             UndirectedEdge[37, 283] -> 
             RGBColor[
              0.8845822922966691, 0.9091958769506863, 0.9162876044689504], 
             UndirectedEdge[9, 142] -> 
             RGBColor[
              0.6961827817065838, 0.7612625000973866, 0.9713710979536356], 
             UndirectedEdge[51, 109] -> 
             RGBColor[
              0.729343722028406, 0.7853745355968642, 0.9058370577711362], 
             UndirectedEdge[123, 257] -> 
             RGBColor[
              0.5223817454582405, 0.6193961867068025, 0.9569210105403192], 
             UndirectedEdge[212, 294] -> 
             RGBColor[
              0.690893354514781, 0.7565039002120764, 0.9714892160521078], 
             UndirectedEdge[237, 297] -> 
             RGBColor[
              0.9313116677621349, 0.9476684713500134, 0.979505069237896], 
             UndirectedEdge[163, 197] -> 
             RGBColor[
              0.8183189361880623, 0.8584216826671365, 0.9824131424634686], 
             UndirectedEdge[76, 229] -> 
             RGBColor[
              0.4118403774741505, 0.5287388963336161, 0.9479913634935566], 
             UndirectedEdge[18, 24] -> 
             RGBColor[
              0.6479996691546335, 0.7207743559694089, 0.9681511543236392], 
             UndirectedEdge[44, 124] -> 
             RGBColor[
              0.5471581502724967, 0.6406557094060392, 0.9585846250417998], 
             UndirectedEdge[26, 82] -> 
             RGBColor[
              0.7652322326909728, 0.8134259252536986, 0.8633251394817667], 
             UndirectedEdge[7, 106] -> 
             RGBColor[
              0.7413320356510298, 0.7949298720749237, 0.8993682926845064], 
             UndirectedEdge[53, 255] -> 
             RGBColor[
              0.7258039067570534, 0.7835262708943821, 0.9423363495940869], 
             UndirectedEdge[89, 242] -> 
             RGBColor[
              0.6465529375453443, 0.7237387121685577, 0.9654556657318729], 
             UndirectedEdge[121, 181] -> 
             RGBColor[
              0.8797842446964163, 0.9023931040116537, 0.719680481998417], 
             UndirectedEdge[217, 273] -> 
             RGBColor[
              0.867697580318348, 0.8957878794140592, 0.9047408601157506], 
             UndirectedEdge[141, 240] -> 
             RGBColor[
              0.7841670006685919, 0.8299831064180474, 0.9143568942795217], 
             UndirectedEdge[42, 159] -> 
             RGBColor[
              0.7908468869636716, 0.8355289253791658, 0.9200157101917763], 
             UndirectedEdge[51, 52] -> 
             RGBColor[
              0.5466322445027542, 0.642819707446145, 0.9574520391485973], 
             UndirectedEdge[170, 225] -> 
             RGBColor[
              0.34860317580699923`, 0.4628834732827731, 0.9443344918235683], 
             UndirectedEdge[51, 179] -> 
             RGBColor[
              0.7089079037778958, 0.7706497854975698, 0.9635482834930287], 
             UndirectedEdge[36, 198] -> 
             RGBColor[
              0.5715770212680374, 0.6601416554665132, 0.9608450491644116], 
             UndirectedEdge[150, 295] -> 
             RGBColor[
              0.883172134929362, 0.9096815035964427, 0.9887189407182766], 
             UndirectedEdge[140, 196] -> 
             RGBColor[
              0.49048091595275795`, 0.5950663033989434, 0.9536304118610182], 
             UndirectedEdge[31, 73] -> 
             RGBColor[
              0.7440062939714072, 0.7991832522106282, 0.9673577231882733], 
             UndirectedEdge[188, 212] -> 
             RGBColor[
              0.7229277437860302, 0.7808399805412589, 0.9326878022411957], 
             UndirectedEdge[172, 244] -> 
             RGBColor[
              0.9510773101103314, 0.9624924004909929, 0.9481775664677595], 
             UndirectedEdge[7, 63] -> 
             RGBColor[
              0.7069579391429807, 0.7695386562620045, 0.9727621631364123], 
             UndirectedEdge[128, 218] -> 
             RGBColor[
              0.5208628696738699, 0.6218989680629501, 0.9554233795657372], 
             UndirectedEdge[138, 154] -> 
             RGBColor[
              0.7754224332406572, 0.8247165049532758, 0.9781891290638292], 
             UndirectedEdge[1, 297] -> 
             RGBColor[
              0.8365930934215242, 0.8730117025288416, 0.9841511847133526], 
             UndirectedEdge[90, 123] -> 
             RGBColor[
              0.5041413907672246, 0.6035973082603281, 0.95575875126872], 
             UndirectedEdge[8, 61] -> 
             RGBColor[
              0.7996075767387962, 0.843468697712032, 0.9806372080326554], 
             UndirectedEdge[201, 209] -> 
             RGBColor[
              0.9839104278759435, 0.9843508749522399, 0.72426536779122], 
             UndirectedEdge[44, 94] -> 
             RGBColor[
              0.5327425400284105, 0.6281696323622499, 0.9576660751042703], 
             UndirectedEdge[114, 213] -> 
             RGBColor[
              0.9528039244046191, 0.9640379393624705, 0.9549323447733774], 
             UndirectedEdge[82, 107] -> 
             RGBColor[
              0.9755742568524575, 0.9798829594824087, 0.8625979148420175], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.722518381438909, 0.7831561180139388, 0.9729775380098209], 
             UndirectedEdge[182, 268] -> 
             RGBColor[
              0.8859947025351157, 0.9111357337259356, 0.9553806825293067], 
             UndirectedEdge[157, 229] -> 
             RGBColor[
              0.47132226192827475`, 0.5808197132124899, 0.9517609703265397], 
             UndirectedEdge[99, 157] -> 
             RGBColor[
              0.45759064653614134`, 0.5696717692349322, 0.9506799672623063], 
             UndirectedEdge[249, 288] -> 
             RGBColor[
              0.7880989571486492, 0.8349755706054347, 0.9793581167787353], 
             UndirectedEdge[66, 138] -> 
             RGBColor[
              0.881715195831403, 0.9085197799072886, 0.9885799765664882], 
             UndirectedEdge[215, 286] -> 
             RGBColor[
              0.6009829208896983, 0.6865051682893739, 0.9620307790586691], 
             UndirectedEdge[83, 275] -> 
             RGBColor[
              0.7932733163152061, 0.8384304108967242, 0.9800297286758306], 
             UndirectedEdge[95, 289] -> 
             RGBColor[
              0.500506069107616, 0.6045610082655006, 0.9540450076923791], 
             UndirectedEdge[37, 75] -> 
             RGBColor[
              0.8165904314868149, 0.8569022939127975, 0.9822857266497036], 
             UndirectedEdge[88, 260] -> 
             RGBColor[
              0.7544418477025328, 0.8056130962141566, 0.9020761860361408], 
             UndirectedEdge[60, 82] -> 
             RGBColor[
              0.8720086065656008, 0.8984433822160558, 0.872871670237699], 
             UndirectedEdge[50, 227] -> 
             RGBColor[
              0.776798287096623, 0.34350127169280753`, 0.43291539992732975`], 
             UndirectedEdge[12, 248] -> 
             RGBColor[
              0.8294106270077437, 0.8669172312495399, 0.9835636027002456], 
             UndirectedEdge[103, 164] -> 
             RGBColor[
              0.614037120426642, 0.6974840143968659, 0.9627980581974418], 
             UndirectedEdge[127, 228] -> 
             RGBColor[
              0.5815589447793905, 0.671174776160635, 0.9602015969350928], 
             UndirectedEdge[163, 184] -> 
             RGBColor[
              0.7990744678188726, 0.8433877577137487, 0.9804950337062095], 
             UndirectedEdge[11, 183] -> 
             RGBColor[
              0.5630902960148387, 0.6561810950904267, 0.9587476772514578], 
             UndirectedEdge[226, 266] -> 
             RGBColor[
              0.8524255635100438, 0.8854716957459479, 0.9857049235428779], 
             UndirectedEdge[98, 178] -> 
             RGBColor[
              0.6327023479093009, 0.7020908437810269, 0.935652362077771], 
             UndirectedEdge[200, 255] -> 
             RGBColor[
              0.43858967694507567`, 0.5535889230351068, 0.9493656732478422], 
             UndirectedEdge[223, 234] -> 
             RGBColor[
              0.549170578920325, 0.6410466654670313, 0.9592851316100954], 
             UndirectedEdge[111, 190] -> 
             RGBColor[
              0.817814039962887, 0.85819959879233, 0.9823170840906108], 
             UndirectedEdge[85, 181] -> 
             RGBColor[
              0.8758364818114255, 0.9028679131175625, 0.9382843577877216], 
             UndirectedEdge[57, 134] -> 
             RGBColor[
              0.6861293543437279, 0.7538260658401715, 0.9699677786592644], 
             UndirectedEdge[9, 131] -> 
             RGBColor[
              0.7656083444164956, 0.8117908331585684, 0.7246074714425076], 
             UndirectedEdge[184, 189] -> 
             RGBColor[
              0.8560140366709517, 0.8870963872837507, 0.9233365129436328], 
             UndirectedEdge[194, 286] -> 
             RGBColor[
              0.5815908482934715, 0.6712006768706029, 0.9602041084965878], 
             UndirectedEdge[171, 298] -> 
             RGBColor[
              0.7778901080807127, 0.8255686208829975, 0.9399037582158555], 
             UndirectedEdge[108, 213] -> 
             RGBColor[
              0.8532875375492769, 0.8861602783194383, 0.9857868029419168], 
             UndirectedEdge[158, 175] -> 
             RGBColor[
              0.8336691411662798, 0.8703806738052831, 0.9839517865155615], 
             UndirectedEdge[37, 297] -> 
             RGBColor[
              0.8464802831215639, 0.8807356502679374, 0.9851366473816114], 
             UndirectedEdge[68, 234] -> 
             RGBColor[
              0.776148826115039, 0.8250526290014077, 0.9783229195301374], 
             UndirectedEdge[38, 252] -> 
             RGBColor[
              0.7280199878510802, 0.7845794300416351, 0.9174196153776883], 
             UndirectedEdge[42, 252] -> 
             RGBColor[
              0.72816110999724, 0.784637787675746, 0.9150808562034116], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.8460344614644901, 0.8784826188846309, 0.8852661919884659], 
             UndirectedEdge[184, 216] -> 
             RGBColor[
              0.7441688465748346, 0.8000696259277535, 0.9751354540394701], 
             UndirectedEdge[16, 59] -> 
             RGBColor[
              0.8722865746887958, 0.8994621907624615, 0.9092499410495457], 
             UndirectedEdge[7, 185] -> 
             RGBColor[
              0.5226806953043515, 0.6233747608018865, 0.9555664854582835], 
             UndirectedEdge[127, 299] -> 
             RGBColor[
              0.7822210933745061, 0.8238235512822303, 0.6908566493174063], 
             UndirectedEdge[166, 217] -> 
             RGBColor[
              0.5717720951154083, 0.6601050417376175, 0.9609444889809469], 
             UndirectedEdge[101, 207] -> 
             RGBColor[
              0.8669606347567855, 0.8967548934082796, 0.9871726733596391], 
             UndirectedEdge[14, 69] -> 
             RGBColor[
              0.5010092512949557, 0.605780906267632, 0.9538604300007487], 
             UndirectedEdge[51, 107] -> 
             RGBColor[
              0.7148958529310412, 0.7751155881716187, 0.9534122474840152], 
             UndirectedEdge[74, 233] -> 
             RGBColor[
              0.8491312264986071, 0.8825295891708289, 0.9614195667279288], 
             UndirectedEdge[158, 252] -> 
             RGBColor[
              0.6344541257471914, 0.7117215425173133, 0.9660038059766677], 
             UndirectedEdge[86, 110] -> 
             RGBColor[
              0.77811073670498, 0.8265852884653424, 0.9785184644426459], 
             UndirectedEdge[58, 73] -> 
             RGBColor[
              0.6305288446096039, 0.7097675579676672, 0.9648519654661385], 
             UndirectedEdge[13, 96] -> 
             RGBColor[
              0.9720306461446305, 0.9779608466445262, 0.9008710207329242], 
             UndirectedEdge[16, 53] -> 
             RGBColor[
              0.9801311095779894, 0.9840059076737275, 0.887326921907607], 
             UndirectedEdge[44, 170] -> 
             RGBColor[
              0.6091924757352201, 0.6926877270366221, 0.963006835380021], 
             UndirectedEdge[27, 32] -> 
             RGBColor[
              0.6009880010525995, 0.6869481593122369, 0.9617311234158981], 
             UndirectedEdge[116, 164] -> 
             RGBColor[
              0.5603355123887854, 0.6538866297618611, 0.9585704708972298], 
             UndirectedEdge[70, 300] -> 
             RGBColor[
              0.6129239392519832, 0.6954522762854864, 0.96348164937614], 
             UndirectedEdge[79, 116] -> 
             RGBColor[
              0.6923346758850116, 0.7577341096946831, 0.9715335313291715], 
             UndirectedEdge[137, 195] -> 
             RGBColor[
              0.5636312718698042, 0.6521372639390411, 0.9608137139702362], 
             UndirectedEdge[156, 214] -> 
             RGBColor[
              0.571476605940484, 0.6429228258449915, 0.9618794611633381], 
             UndirectedEdge[14, 249] -> 
             RGBColor[
              0.6952230225276967, 0.7602055201010254, 0.9716152898014843], 
             UndirectedEdge[84, 89] -> 
             RGBColor[
              0.682701761186904, 0.7520510716555506, 0.9690089894105725], 
             UndirectedEdge[98, 246] -> 
             RGBColor[
              0.4238755007808286, 0.5373317030856045, 0.9490460275850534], 
             UndirectedEdge[4, 107] -> 
             RGBColor[
              0.8706080396365583, 0.8993781886551959, 0.9671415196221771], 
             UndirectedEdge[20, 295] -> 
             RGBColor[
              0.6588304602180113, 0.7304820542814005, 0.9686909255555958], 
             UndirectedEdge[57, 175] -> 
             RGBColor[
              0.7260037780413227, 0.7853690062048371, 0.9738378681047873], 
             UndirectedEdge[93, 160] -> 
             RGBColor[
              0.7016757241612013, 0.7663140958444873, 0.971282724547789], 
             UndirectedEdge[13, 149] -> 
             RGBColor[
              0.7970532417585441, 0.8401236167797501, 0.9019472423729697], 
             UndirectedEdge[230, 298] -> 
             RGBColor[
              0.7274482449408068, 0.7864708065837193, 0.9740331667742459], 
             UndirectedEdge[96, 198] -> 
             RGBColor[
              0.6785620243883597, 0.7443011303450389, 0.9533759318455775], 
             UndirectedEdge[32, 182] -> 
             RGBColor[
              0.6813503908318655, 0.7497942323001101, 0.9696955224385959], 
             UndirectedEdge[80, 241] -> 
             RGBColor[
              0.6712181741830201, 0.7414225386996839, 0.9689976323670519], 
             UndirectedEdge[55, 292] -> 
             RGBColor[
              0.5325072596466994, 0.6313524084166835, 0.9563400685992043], 
             UndirectedEdge[121, 160] -> 
             RGBColor[
              0.7993345630406925, 0.838985621367932, 0.7120445974056975], 
             UndirectedEdge[62, 220] -> 
             RGBColor[
              0.9817190303786034, 0.9839550200955374, 0.8262433838486106], 
             UndirectedEdge[28, 189] -> 
             RGBColor[
              0.9462349064755085, 0.9582726087847848, 0.9321444564949075], 
             UndirectedEdge[25, 91] -> 
             RGBColor[
              0.7342648148886928, 0.7923325211011107, 0.9741483127194337], 
             UndirectedEdge[41, 99] -> 
             RGBColor[
              0.6651325330489726, 0.736181414546268, 0.968780643188012], 
             UndirectedEdge[148, 206] -> 
             RGBColor[
              0.5507244728213949, 0.6419257425373999, 0.9595817279742087], 
             UndirectedEdge[3, 90] -> 
             RGBColor[
              0.5907002093650973, 0.6716291670388821, 0.964276938706758], 
             UndirectedEdge[99, 104] -> 
             RGBColor[
              0.6143131363512679, 0.6963455623757528, 0.9637513592445743], 
             UndirectedEdge[193, 266] -> 
             RGBColor[
              0.6309101771797956, 0.7046715811322112, 0.9676610179503176], 
             UndirectedEdge[275, 293] -> 
             RGBColor[
              0.8348773119486144, 0.8715918271968828, 0.9840012668626321], 
             UndirectedEdge[229, 257] -> 
             RGBColor[
              0.43399476715216845`, 0.5484885133718651, 0.9493824953668137], 
             UndirectedEdge[90, 144] -> 
             RGBColor[
              0.5447336866830101, 0.635308318342615, 0.9598046119690329], 
             UndirectedEdge[49, 115] -> 
             RGBColor[
              0.9085153588579034, 0.928365897922292, 0.9359214475258203], 
             UndirectedEdge[77, 244] -> 
             RGBColor[
              0.732462204266815, 0.7884376002311666, 0.9282946638850447], 
             UndirectedEdge[66, 95] -> 
             RGBColor[
              0.6691298086786237, 0.7380500925027439, 0.9699699313454069], 
             UndirectedEdge[94, 125] -> 
             RGBColor[
              0.3474708987840436, 0.4753835609567324, 0.9433615163074358], 
             UndirectedEdge[196, 230] -> 
             RGBColor[
              0.7429155825079878, 0.7990278880163736, 0.9752508122462589], 
             UndirectedEdge[138, 245] -> 
             RGBColor[
              0.7771382230670925, 0.8260568930061727, 0.9783601429587606], 
             UndirectedEdge[100, 127] -> 
             RGBColor[
              0.5656074903644182, 0.6582246668617284, 0.9589458400114433], 
             UndirectedEdge[24, 288] -> 
             RGBColor[
              0.5472763000942226, 0.6415631138223259, 0.958251410095855], 
             UndirectedEdge[224, 258] -> 
             RGBColor[
              0.8168778489843016, 0.8577414219501271, 0.9788788242245017], 
             UndirectedEdge[25, 203] -> 
             RGBColor[
              0.6544829842500253, 0.7299389298756758, 0.9662425000235835], 
             UndirectedEdge[143, 239] -> 
             RGBColor[
              0.7684497587784456, 0.8189661129745971, 0.9676339594764176], 
             UndirectedEdge[142, 282] -> 
             RGBColor[
              0.8391931416107572, 0.8746138481021591, 0.9845241850750373], 
             UndirectedEdge[57, 242] -> 
             RGBColor[
              0.6105256919917514, 0.6946912864847207, 0.9624819653843412], 
             UndirectedEdge[47, 177] -> 
             RGBColor[
              0.511703761445921, 0.6118730874762146, 0.9555102488182217], 
             UndirectedEdge[43, 174] -> 
             RGBColor[
              0.7748564668796192, 0.8240430281444038, 0.9781941092393345], 
             UndirectedEdge[5, 29] -> 
             RGBColor[
              0.9577956358376181, 0.9657194348833125, 0.8530945915431528], 
             UndirectedEdge[167, 282] -> 
             RGBColor[
              0.7574963889994284, 0.810514619433103, 0.9764549513178119], 
             UndirectedEdge[131, 172] -> 
             RGBColor[
              0.9553211230790104, 0.9623814221778562, 0.7422150769568211], 
             UndirectedEdge[21, 101] -> 
             RGBColor[
              0.6691936233543718, 0.7382882810418598, 0.9698897915199636], 
             UndirectedEdge[251, 300] -> 
             RGBColor[
              0.6275456252786418, 0.7068748485384417, 0.9649390023918527], 
             UndirectedEdge[75, 167] -> 
             RGBColor[
              0.7712888934232452, 0.8215123880730957, 0.9777704927024696], 
             UndirectedEdge[165, 281] -> 
             RGBColor[
              0.8239836707027666, 0.8625899236027557, 0.9830459747631758], 
             UndirectedEdge[63, 174] -> 
             RGBColor[
              0.8370693617791276, 0.8734480925561781, 0.9841815846647111], 
             UndirectedEdge[64, 211] -> 
             RGBColor[
              0.7381561395526749, 0.7953447128448896, 0.9746680857379526], 
             UndirectedEdge[124, 237] -> 
             RGBColor[
              0.6714812126002376, 0.7384397292451993, 0.9568892082592309], 
             UndirectedEdge[127, 192] -> 
             RGBColor[
              0.42816033068061243`, 0.5397015414328604, 0.9494842731057209], 
             UndirectedEdge[62, 228] -> 
             RGBColor[
              0.7793232440071158, 0.8270943608362834, 0.9497327737243257], 
             UndirectedEdge[152, 277] -> 
             RGBColor[
              0.701981063311581, 0.7667006458002693, 0.9712119580808205], 
             UndirectedEdge[76, 157] -> 
             RGBColor[
              0.36216453363818957`, 0.48754985073268053`, 0.9443183079739393],
              UndirectedEdge[106, 297] -> 
             RGBColor[
              0.9498363647296779, 0.9608199952042967, 0.9184049320055292], 
             UndirectedEdge[91, 203] -> 
             RGBColor[
              0.7177397614970698, 0.7793556050303804, 0.9725473444113761], 
             UndirectedEdge[215, 271] -> 
             RGBColor[
              0.6175599859439966, 0.6999631764887237, 0.9633357863435336], 
             UndirectedEdge[181, 296] -> 
             RGBColor[
              0.7052419519682607, 0.7696596400057412, 0.9712555849775993], 
             UndirectedEdge[27, 119] -> 
             RGBColor[
              0.5060936144866282, 0.607759306893213, 0.9548545516853961], 
             UndirectedEdge[100, 170] -> 
             RGBColor[
              0.5371751158483219, 0.635141984365686, 0.9567075393383166], 
             UndirectedEdge[112, 115] -> 
             RGBColor[
              0.6508628254029745, 0.7182701730675092, 0.914711898019736], 
             UndirectedEdge[75, 282] -> 
             RGBColor[
              0.8379108121436951, 0.87359135339303, 0.9844018753457198], 
             UndirectedEdge[234, 255] -> 
             RGBColor[
              0.6070300177557887, 0.6904444594845984, 0.9631700328587555], 
             UndirectedEdge[29, 77] -> 
             RGBColor[
              0.7377234431902151, 0.7905027931576345, 0.8330727107203265], 
             UndirectedEdge[44, 192] -> 
             RGBColor[
              0.49302967146107446`, 0.5914442001786006, 0.9552208508993099], 
             UndirectedEdge[49, 57] -> 
             RGBColor[
              0.7074244835439873, 0.7705543810941762, 0.9720657584096996], 
             UndirectedEdge[4, 281] -> 
             RGBColor[
              0.7949835474402509, 0.839766456449847, 0.9802001885313565], 
             UndirectedEdge[23, 285] -> 
             RGBColor[
              0.7277426054789911, 0.786531993639777, 0.9742609707444755], 
             UndirectedEdge[86, 109] -> 
             RGBColor[
              0.89771863989851, 0.9195293579065381, 0.9208284326118334], 
             UndirectedEdge[276, 279] -> 
             RGBColor[
              0.5570482191725801, 0.6512758649174211, 0.9582720228295785], 
             UndirectedEdge[139, 183] -> 
             RGBColor[
              0.4376724682859984, 0.5519086596941734, 0.9495519851404338], 
             UndirectedEdge[234, 287] -> 
             RGBColor[
              0.6370396089242926, 0.7148075975118657, 0.9655324978042947], 
             UndirectedEdge[160, 181] -> 
             RGBColor[
              0.6862795378423887, 0.7542864780768811, 0.9697481765810712], 
             UndirectedEdge[196, 298] -> 
             RGBColor[
              0.5919937616728982, 0.6796462305979287, 0.9610230639449435], 
             UndirectedEdge[255, 287] -> 
             RGBColor[
              0.5097394467293583, 0.6128684722121025, 0.9545477029651044], 
             UndirectedEdge[126, 216] -> 
             RGBColor[
              0.8661900681310866, 0.8957291284129891, 0.9566932651174932], 
             UndirectedEdge[190, 212] -> 
             RGBColor[
              0.678641735394303, 0.7467347916867488, 0.9703206456832472], 
             UndirectedEdge[39, 137] -> 
             RGBColor[
              0.6557248606851607, 0.6670363866746019, 0.6122894220251924], 
             UndirectedEdge[170, 195] -> 
             RGBColor[
              0.6419987540865622, 0.7183162410216408, 0.966276658613981], 
             UndirectedEdge[69, 288] -> 
             RGBColor[
              0.5938851859159081, 0.6805509567720414, 0.9616032569779998], 
             UndirectedEdge[101, 231] -> 
             RGBColor[
              0.5442162327035813, 0.6180364932601136, 0.9623658186436455], 
             UndirectedEdge[57, 253] -> 
             RGBColor[
              0.7126333145148149, 0.7747077615203639, 0.9725625813576754], 
             UndirectedEdge[52, 266] -> 
             RGBColor[
              0.7723429363490741, 0.8225967719209476, 0.977937559781817], 
             UndirectedEdge[28, 275] -> 
             RGBColor[
              0.8370383416070325, 0.8733149735869179, 0.9842073878006261], 
             UndirectedEdge[4, 226] -> 
             RGBColor[
              0.7824270583692409, 0.8299572317547226, 0.97894867504782], 
             UndirectedEdge[104, 229] -> 
             RGBColor[
              0.6280447517434014, 0.7074935063533105, 0.9648323623088078], 
             UndirectedEdge[189, 293] -> 
             RGBColor[
              0.9440738768170904, 0.9565494623947496, 0.9319383355569137], 
             UndirectedEdge[155, 156] -> 
             RGBColor[
              0.5280074932946903, 0.6083366683529088, 0.9603313123368379], 
             UndirectedEdge[107, 281] -> 
             RGBColor[
              0.8827791554854638, 0.9088863568602675, 0.9683546227044516], 
             UndirectedEdge[107, 240] -> 
             RGBColor[
              0.9725990473463646, 0.9786526338922426, 0.9119048359533628], 
             UndirectedEdge[13, 105] -> 
             RGBColor[
              0.6807894731514534, 0.7435593032911327, 0.8933958089372347], 
             UndirectedEdge[96, 138] -> 
             RGBColor[
              0.9021301480058905, 0.9242835120669664, 0.9726857873225404], 
             UndirectedEdge[254, 260] -> 
             RGBColor[
              0.889312689280869, 0.9128358921078055, 0.9142467012567047], 
             UndirectedEdge[120, 176] -> 
             RGBColor[
              0.5847600949331458, 0.6735929305546408, 0.9605771375046586], 
             UndirectedEdge[59, 125] -> 
             RGBColor[
              0.5440698983589547, 0.6357003496243832, 0.959353047852777], 
             UndirectedEdge[22, 267] -> 
             RGBColor[
              0.81239423119097, 0.8537084147425864, 0.9515846504256861], 
             UndirectedEdge[28, 197] -> 
             RGBColor[
              0.8349935340442354, 0.8717175543777477, 0.9840035804925795], 
             UndirectedEdge[245, 298] -> 
             RGBColor[
              0.6410985207665738, 0.7185418329428486, 0.9655518644086968], 
             UndirectedEdge[193, 199] -> 
             RGBColor[
              0.4599736015204348, 0.5693626117237963, 0.951487516387534], 
             UndirectedEdge[22, 274] -> 
             RGBColor[
              0.8887820989810268, 0.9133831976294765, 0.9591982792017884], 
             UndirectedEdge[76, 201] -> 
             RGBColor[
              0.6480292870495437, 0.7118545659903959, 0.7304685955364956], 
             UndirectedEdge[19, 158] -> 
             RGBColor[
              0.7435680059007849, 0.7996002446266275, 0.9750755678562562], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.7527726827294894, 0.8066957360837204, 0.9764119061789762], 
             UndirectedEdge[61, 267] -> 
             RGBColor[
              0.7433044056875631, 0.7994842325668597, 0.9750254341253167], 
             UndirectedEdge[106, 283] -> 
             RGBColor[
              0.9879383739047831, 0.9892802218870456, 0.8495558890928682], 
             UndirectedEdge[174, 283] -> 
             RGBColor[
              0.871192122569614, 0.8987353745908517, 0.9149529974888081], 
             UndirectedEdge[19, 242] -> 
             RGBColor[
              0.6629951046069088, 0.73658345804215, 0.9670944672837825], 
             UndirectedEdge[125, 195] -> 
             RGBColor[
              0.5500288281387535, 0.6403555108579058, 0.9599469782838623], 
             UndirectedEdge[115, 159] -> 
             RGBColor[
              0.7905654149025818, 0.835412529448403, 0.9246804306703789], 
             UndirectedEdge[158, 177] -> 
             RGBColor[
              0.5825151121626437, 0.6671914528423166, 0.9625680624879691], 
             UndirectedEdge[42, 134] -> 
             RGBColor[
              0.8875017017187338, 0.91175397859905, 0.9291587472967825], 
             UndirectedEdge[165, 179] -> 
             RGBColor[
              0.8936202137459285, 0.9177358531340556, 0.9801233418630098], 
             UndirectedEdge[108, 145] -> 
             RGBColor[
              0.5505301072976958, 0.6402045241564903, 0.960226590820922], 
             UndirectedEdge[44, 125] -> 
             RGBColor[
              0.5172225497874114, 0.6147269968728871, 0.9566771550499023], 
             UndirectedEdge[39, 141] -> 
             RGBColor[
              0.7669167398457006, 0.7598636879183946, 0.6203364234360798], 
             UndirectedEdge[50, 87] -> 
             RGBColor[
              0.8284647544280287, 0.38402932248396504`, 0.43802102864758663`],
              UndirectedEdge[26, 226] -> 
             RGBColor[
              0.659880642252969, 0.7326200979364329, 0.9678303338606643], 
             UndirectedEdge[9, 143] -> 
             RGBColor[
              0.742602318419953, 0.7979819964776542, 0.9655991542891034], 
             UndirectedEdge[136, 299] -> 
             RGBColor[
              0.7823191196166526, 0.8239031334016367, 0.69086436630227], 
             UndirectedEdge[134, 144] -> 
             RGBColor[
              0.7838910663673682, 0.8311009259297324, 0.9790945936831408], 
             UndirectedEdge[240, 281] -> 
             RGBColor[
              0.8969745551500572, 0.9190409016868937, 0.9249635048625422], 
             UndirectedEdge[257, 261] -> 
             RGBColor[
              0.6162856819843083, 0.6932848431433845, 0.9661397818834127], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.6466745156333111, 0.7230036459717135, 0.9660352890630408], 
             UndirectedEdge[135, 254] -> 
             RGBColor[
              0.7726670811242295, 0.8223326633523453, 0.9779758917282103], 
             UndirectedEdge[14, 224] -> 
             RGBColor[
              0.718559017171579, 0.7787193387919561, 0.9705935001219412], 
             UndirectedEdge[96, 289] -> 
             RGBColor[
              0.7666157755595311, 0.817194938445089, 0.9599188646629426], 
             UndirectedEdge[92, 189] -> 
             RGBColor[
              0.9753616994477203, 0.9807619540087985, 0.9094199616595142], 
             UndirectedEdge[107, 127] -> 
             RGBColor[
              0.7655795785763126, 0.8162629199262703, 0.9574022560274154], 
             UndirectedEdge[172, 270] -> 
             RGBColor[
              0.7339421808738834, 0.7914595608464743, 0.9748704841158315], 
             UndirectedEdge[48, 84] -> 
             RGBColor[
              0.7865116042123288, 0.833496660458451, 0.9792632898334096], 
             UndirectedEdge[149, 289] -> 
             RGBColor[
              0.5916383711734448, 0.6793577085803129, 0.9609950863029882], 
             UndirectedEdge[1, 102] -> 
             RGBColor[
              0.8757984537846228, 0.9019281932826579, 0.8970167572342979], 
             UndirectedEdge[33, 297] -> 
             RGBColor[
              0.6457625374261746, 0.7179254470768355, 0.9684280898875723], 
             UndirectedEdge[18, 135] -> 
             RGBColor[
              0.8198412164746367, 0.8597108371359233, 0.9825383487858219], 
             UndirectedEdge[60, 137] -> 
             RGBColor[
              0.5552140715566017, 0.6455616830812756, 0.9599747661062252], 
             UndirectedEdge[156, 208] -> 
             RGBColor[
              0.4532937168188047, 0.5497136197381427, 0.9529524967207078], 
             UndirectedEdge[104, 279] -> 
             RGBColor[
              0.6408893075700892, 0.7179212954140616, 0.9658435327946429], 
             UndirectedEdge[74, 158] -> 
             RGBColor[
              0.7673133194556749, 0.8181502640467747, 0.9774422787988362], 
             UndirectedEdge[80, 277] -> 
             RGBColor[
              0.7983729716751855, 0.8424143004227562, 0.9805380146631244], 
             UndirectedEdge[223, 291] -> 
             RGBColor[
              0.6552878493961647, 0.7246891915038638, 0.9598758021341804], 
             UndirectedEdge[114, 264] -> 
             RGBColor[
              0.7679218774416225, 0.8174210178509201, 0.9376453400674025], 
             UndirectedEdge[1, 237] -> 
             RGBColor[
              0.8564217413466493, 0.8884243391355529, 0.9722369957570554], 
             UndirectedEdge[84, 292] -> 
             RGBColor[
              0.6219862581308012, 0.70296060633785, 0.9640917389963761], 
             UndirectedEdge[103, 152] -> 
             RGBColor[
              0.5987104174950231, 0.6850991143762263, 0.9615518236951821], 
             UndirectedEdge[10, 269] -> 
             RGBColor[
              0.8290244266344662, 0.867088657440559, 0.9833995560047897], 
             UndirectedEdge[109, 138] -> 
             RGBColor[
              0.9179526072916278, 0.9355676266040152, 0.9227837749712862], 
             UndirectedEdge[165, 240] -> 
             RGBColor[
              0.9138035625636673, 0.9323562006347307, 0.926596188012087], 
             UndirectedEdge[249, 254] -> 
             RGBColor[
              0.8416481908586531, 0.8768086389689396, 0.9846954039489079], 
             UndirectedEdge[2, 155] -> 
             RGBColor[
              0.683516417899892, 0.7509981992181882, 0.9703522894646266], 
             UndirectedEdge[117, 161] -> 
             RGBColor[
              0.6995406757086668, 0.765205759660442, 0.9706873350414988], 
             UndirectedEdge[169, 264] -> 
             RGBColor[
              0.7738388760559287, 0.8182288976061591, 0.7052693475610745], 
             UndirectedEdge[3, 229] -> 
             RGBColor[
              0.6959439026681803, 0.7609482909269168, 0.9714907284577003], 
             UndirectedEdge[55, 90] -> 
             RGBColor[
              0.42073426164790895`, 0.5367325008348488, 0.9486122680649847], 
             UndirectedEdge[3, 259] -> 
             RGBColor[
              0.718049483207283, 0.7788945970536152, 0.9732309607331482], 
             UndirectedEdge[113, 254] -> 
             RGBColor[
              0.7280107437499301, 0.7874467931948081, 0.9735249653559395], 
             UndirectedEdge[6, 205] -> 
             RGBColor[
              0.9669566325558834, 0.9748768911805019, 0.9408179813791218], 
             UndirectedEdge[120, 287] -> 
             RGBColor[
              0.5275576414856576, 0.6273340854157926, 0.9559504165265184], 
             UndirectedEdge[31, 67] -> 
             RGBColor[
              0.8462076669535703, 0.8805493762723418, 0.976501116124638], 
             UndirectedEdge[141, 232] -> 
             RGBColor[
              0.42159367531386166`, 0.5317489179157554, 0.9492059487112544], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.6788127316288777, 0.7472876160393577, 0.9698575985324408], 
             UndirectedEdge[71, 122] -> 
             RGBColor[
              0.48385227627853544`, 0.5897027865750154, 0.9531036320689488], 
             UndirectedEdge[78, 120] -> 
             RGBColor[
              0.7199876599891011, 0.7800793776746299, 0.9738309490933574], 
             UndirectedEdge[177, 247] -> 
             RGBColor[
              0.4159592452058198, 0.5343698212441969, 0.9478180678925269], 
             UndirectedEdge[168, 182] -> 
             RGBColor[
              0.8105293251843648, 0.8519297124479672, 0.9817446637280309], 
             UndirectedEdge[26, 228] -> 
             RGBColor[
              0.5640409897233642, 0.6569529110712711, 0.9588225193426987], 
             UndirectedEdge[7, 194] -> 
             RGBColor[
              0.5633491270644542, 0.6563912257967103, 0.9587680533798129], 
             UndirectedEdge[206, 244] -> 
             RGBColor[
              0.6703792882888975, 0.7353969314784826, 0.92413642204236], 
             UndirectedEdge[31, 109] -> 
             RGBColor[0.9662728886476, 0.9738507064018773, 0.918856665528071],
              UndirectedEdge[57, 235] -> 
             RGBColor[
              0.6130443015201419, 0.6967314671074119, 0.9626833436124593], 
             UndirectedEdge[24, 135] -> 
             RGBColor[
              0.5828556596320045, 0.6693579799063889, 0.9617976281465624], 
             UndirectedEdge[130, 220] -> 
             RGBColor[
              0.8749652992139569, 0.9001998195994954, 0.8450542980848397], 
             UndirectedEdge[84, 112] -> 
             RGBColor[
              0.5130132355616993, 0.6107658967423546, 0.9565423504206153], 
             UndirectedEdge[76, 104] -> 
             RGBColor[
              0.5188870234533162, 0.6142236438735011, 0.9573896999562074], 
             UndirectedEdge[21, 87] -> 
             RGBColor[
              0.6398190222928336, 0.714865771507694, 0.9670880158476982], 
             UndirectedEdge[43, 183] -> 
             RGBColor[
              0.6536848871770925, 0.7273913590790777, 0.9674784648944939], 
             UndirectedEdge[11, 131] -> 
             RGBColor[
              0.8034728227020916, 0.842530922406123, 0.7275883018753039], 
             UndirectedEdge[21, 187] -> 
             RGBColor[
              0.626757240167251, 0.704450660993385, 0.9658421714081695], 
             UndirectedEdge[36, 66] -> 
             RGBColor[
              0.8282545120102168, 0.8665245478038066, 0.9833129056348044], 
             UndirectedEdge[124, 125] -> 
             RGBColor[
              0.3618865090281298, 0.4878696380005218, 0.9442800662449654], 
             UndirectedEdge[232, 296] -> 
             RGBColor[
              0.4527012403699532, 0.5569820605025821, 0.9516694678781633], 
             UndirectedEdge[75, 239] -> 
             RGBColor[
              0.7207478925980143, 0.7812241218852003, 0.9732835934116326], 
             UndirectedEdge[108, 114] -> 
             RGBColor[
              0.8814012081319893, 0.9074112930598659, 0.9480401717533846], 
             UndirectedEdge[137, 266] -> 
             RGBColor[
              0.6409826189390486, 0.7133958239284334, 0.9683028250325065], 
             UndirectedEdge[74, 262] -> 
             RGBColor[
              0.7632498188986084, 0.8149758265278463, 0.9770372670388794], 
             UndirectedEdge[48, 90] -> 
             RGBColor[
              0.5868090632383876, 0.6685264727397916, 0.9639057977155253], 
             UndirectedEdge[125, 150] -> 
             RGBColor[
              0.611403831499419, 0.6888749680403744, 0.9659122514209582], 
             UndirectedEdge[38, 55] -> 
             RGBColor[
              0.7584267423780553, 0.8092650031753146, 0.9198133464776638], 
             UndirectedEdge[110, 165] -> 
             RGBColor[
              0.7944481288029088, 0.8395165337921544, 0.9801021479719297], 
             UndirectedEdge[114, 145] -> 
             RGBColor[
              0.6500464941530382, 0.7180821851995225, 0.9293721326523825], 
             UndirectedEdge[222, 290] -> 
             RGBColor[
              0.6793719533005865, 0.749449800427282, 0.9686771052792882], 
             UndirectedEdge[267, 286] -> 
             RGBColor[
              0.5932291048848721, 0.6804478282952195, 0.9612579511428383], 
             UndirectedEdge[6, 187] -> 
             RGBColor[
              0.8998858208090962, 0.9219914955131969, 0.9550514309256546], 
             UndirectedEdge[221, 231] -> 
             RGBColor[
              0.4735168738672313, 0.5620820481242209, 0.9555111801573284], 
             UndirectedEdge[106, 286] -> 
             RGBColor[
              0.7595737568800471, 0.8097393231488164, 0.9008043478012812], 
             UndirectedEdge[67, 154] -> 
             RGBColor[
              0.7247039901315006, 0.7848635321358326, 0.973195379058624], 
             UndirectedEdge[85, 296] -> 
             RGBColor[
              0.8143492142815736, 0.8548335924027008, 0.9321558815915301], 
             UndirectedEdge[41, 201] -> 
             RGBColor[
              0.9150530580164992, 0.9304450281806054, 0.7523388782951843], 
             UndirectedEdge[42, 235] -> 
             RGBColor[
              0.8144166488951478, 0.8546593798662904, 0.9218743122499773], 
             UndirectedEdge[44, 60] -> 
             RGBColor[
              0.726883269069918, 0.7865660014056577, 0.9734125892166858], 
             UndirectedEdge[199, 228] -> 
             RGBColor[
              0.5856493353210783, 0.6744955394723712, 0.9605236074621288], 
             UndirectedEdge[39, 62] -> 
             RGBColor[
              0.9602890166457403, 0.9122176309288921, 0.6095218441312971], 
             UndirectedEdge[48, 144] -> 
             RGBColor[
              0.8210320307633281, 0.8604642800450507, 0.9827039633402859], 
             UndirectedEdge[68, 215] -> 
             RGBColor[
              0.7444877549605017, 0.8003187595824299, 0.9751672398469851], 
             UndirectedEdge[127, 240] -> 
             RGBColor[
              0.7797749782409061, 0.8264174647528966, 0.9140111381855061], 
             UndirectedEdge[4, 26] -> 
             RGBColor[
              0.6602660154750736, 0.7329211544264859, 0.9678687442619263], 
             UndirectedEdge[8, 47] -> 
             RGBColor[
              0.7126240013558007, 0.775426553092941, 0.9719913586713755], 
             UndirectedEdge[112, 175] -> 
             RGBColor[
              0.592342497969711, 0.6731312569754782, 0.9643449294623618], 
             UndirectedEdge[162, 203] -> 
             RGBColor[
              0.7182129156038719, 0.7797252366147186, 0.9725945039908657], 
             UndirectedEdge[6, 50] -> 
             RGBColor[
              0.8699256475284238, 0.41641108153437223`, 0.4184678215958688], 
             UndirectedEdge[15, 294] -> 
             RGBColor[
              0.8103429474384538, 0.8525611750824924, 0.9815198788819259], 
             UndirectedEdge[6, 219] -> 
             RGBColor[
              0.8539494259432776, 0.8860680610108187, 0.9504828912911147], 
             UndirectedEdge[110, 281] -> 
             RGBColor[
              0.7776191213892988, 0.8262012348443173, 0.9784694648223851], 
             UndirectedEdge[167, 297] -> 
             RGBColor[
              0.8011787450579941, 0.8453457444282355, 0.9806214134343776], 
             UndirectedEdge[122, 246] -> 
             RGBColor[
              0.4645381136560724, 0.5740226792649892, 0.9515831504371995], 
             UndirectedEdge[210, 277] -> 
             RGBColor[
              0.8122433676553642, 0.8533795474114916, 0.9818860973764116], 
             UndirectedEdge[225, 234] -> 
             RGBColor[
              0.45782288556302986`, 0.550144072777534, 0.9538959272158886], 
             UndirectedEdge[84, 280] -> 
             RGBColor[
              0.7497324213579569, 0.804415932833063, 0.9756899791792893], 
             UndirectedEdge[67, 95] -> 
             RGBColor[
              0.5853019984448188, 0.6717966090699349, 0.9618181803467718], 
             UndirectedEdge[81, 285] -> 
             RGBColor[
              0.5946474672613855, 0.6818006283427371, 0.9612319733697131], 
             UndirectedEdge[79, 164] -> 
             RGBColor[
              0.7781448938443649, 0.8273407024610047, 0.9783284863240371], 
             UndirectedEdge[123, 157] -> 
             RGBColor[
              0.5597092402343468, 0.6517273865474272, 0.9592994855000451], 
             UndirectedEdge[85, 165] -> 
             RGBColor[
              0.9128782111205576, 0.9319735440325574, 0.9419316561571864], 
             UndirectedEdge[59, 62] -> 
             RGBColor[
              0.862236498050585, 0.8926633469598089, 0.9574522056452552], 
             UndirectedEdge[38, 48] -> 
             RGBColor[
              0.9245015439685339, 0.9410589750802574, 0.9351068761282044], 
             UndirectedEdge[262, 291] -> 
             RGBColor[
              0.868600838099427, 0.8980197512449068, 0.9775515647968958], 
             UndirectedEdge[26, 170] -> 
             RGBColor[
              0.5268051798987318, 0.626723203201518, 0.9558911799940379], 
             UndirectedEdge[43, 139] -> 
             RGBColor[
              0.5790033079161367, 0.6643088958309996, 0.9622769161158637], 
             UndirectedEdge[52, 281] -> 
             RGBColor[
              0.7145155470571767, 0.7765904761347938, 0.9723944143690337], 
             UndirectedEdge[124, 142] -> 
             RGBColor[
              0.6230450425074257, 0.7002162309924774, 0.9660747862129376], 
             UndirectedEdge[166, 271] -> 
             RGBColor[
              0.480565632556594, 0.5876552147406435, 0.9526734014706099], 
             UndirectedEdge[37, 150] -> 
             RGBColor[
              0.8361671504309558, 0.8725122382029759, 0.984152971578939], 
             UndirectedEdge[51, 66] -> 
             RGBColor[
              0.6931063105681814, 0.7583266889001377, 0.9716332593663383], 
             UndirectedEdge[60, 125] -> 
             RGBColor[
              0.541611627825551, 0.6337799300001402, 0.9591080304198515], 
             UndirectedEdge[215, 223] -> 
             RGBColor[
              0.5175095077657876, 0.6163127960480534, 0.956129451926943], 
             UndirectedEdge[237, 282] -> 
             RGBColor[
              0.8876293117035692, 0.912837346354881, 0.9753386071213304], 
             UndirectedEdge[143, 172] -> 
             RGBColor[
              0.9323150970824677, 0.948572585496942, 0.9832067598034169], 
             UndirectedEdge[177, 285] -> 
             RGBColor[
              0.4594059007659045, 0.569641773477402, 0.95123834776856], 
             UndirectedEdge[244, 270] -> 
             RGBColor[
              0.7674963457476538, 0.8168798945553993, 0.9310526798367051], 
             UndirectedEdge[147, 272] -> 
             RGBColor[
              0.5424620611638138, 0.6347490392438133, 0.959063811454675], 
             UndirectedEdge[46, 114] -> 
             RGBColor[
              0.9585489879910372, 0.9686064836302941, 0.9550499305625083], 
             UndirectedEdge[104, 128] -> 
             RGBColor[
              0.6478729735656814, 0.7235909500798512, 0.9663933125638273], 
             UndirectedEdge[199, 220] -> 
             RGBColor[
              0.7880451216925659, 0.8313561987316251, 0.8370342175864136], 
             UndirectedEdge[112, 146] -> 
             RGBColor[
              0.6296559206259738, 0.7026905070165236, 0.9611965256204053], 
             UndirectedEdge[191, 203] -> 
             RGBColor[
              0.6499772406621723, 0.7264190087399256, 0.9657934096113141], 
             UndirectedEdge[31, 96] -> 
             RGBColor[
              0.9504504293618629, 0.9625665918648286, 0.9687586778793252], 
             UndirectedEdge[59, 228] -> 
             RGBColor[
              0.6732756341313957, 0.7438907876578713, 0.9686140675315564], 
             UndirectedEdge[129, 289] -> 
             RGBColor[
              0.7269546042753052, 0.7860847935920063, 0.973977332346901], 
             UndirectedEdge[54, 106] -> 
             RGBColor[
              0.8276079400402481, 0.8645946683523187, 0.9064185994201598], 
             UndirectedEdge[102, 142] -> 
             RGBColor[
              0.9220808580324217, 0.938361463851108, 0.9015562197125482], 
             UndirectedEdge[74, 90] -> 
             RGBColor[
              0.5231867008294174, 0.6184756492306307, 0.9576570097871778], 
             UndirectedEdge[143, 174] -> 
             RGBColor[
              0.8509021279401912, 0.8841837826423598, 0.9753014857343463], 
             UndirectedEdge[144, 292] -> 
             RGBColor[
              0.6565066846818006, 0.7299282259244497, 0.9675324125032525], 
             UndirectedEdge[59, 255] -> 
             RGBColor[
              0.6179593718678597, 0.698982553983116, 0.9642593687360256], 
             UndirectedEdge[254, 258] -> 
             RGBColor[
              0.7425306187782179, 0.798789829922044, 0.9749721708028125], 
             UndirectedEdge[46, 108] -> 
             RGBColor[
              0.8590326011356948, 0.8907288225872619, 0.9859043887310477], 
             UndirectedEdge[222, 278] -> 
             RGBColor[
              0.7043029112040873, 0.7689260542237948, 0.9711619901700614], 
             UndirectedEdge[115, 294] -> 
             RGBColor[
              0.952030918945425, 0.96306402433767, 0.9400720004937672], 
             UndirectedEdge[89, 177] -> 
             RGBColor[
              0.5108769945912794, 0.6112272109257078, 0.9554278444247266], 
             UndirectedEdge[45, 195] -> 
             RGBColor[
              0.7261873192128527, 0.7860223200879035, 0.9733432234389547], 
             UndirectedEdge[205, 231] -> 
             RGBColor[
              0.5688506612632477, 0.6370842688789436, 0.9440847489853186], 
             UndirectedEdge[148, 244] -> 
             RGBColor[
              0.8649766595165993, 0.8944415452588352, 0.9398050681204817], 
             UndirectedEdge[20, 297] -> 
             RGBColor[
              0.6768282124350511, 0.7448329733632983, 0.9704075672288401], 
             UndirectedEdge[6, 34] -> 
             RGBColor[
              0.8944781383094833, 0.917729399140921, 0.9545224145774276], 
             UndirectedEdge[13, 245] -> 
             RGBColor[
              0.8470387212058325, 0.8797342275837325, 0.9065453763691445], 
             UndirectedEdge[104, 201] -> 
             RGBColor[
              0.8642336613187945, 0.8906091760100903, 0.7473095943517467], 
             UndirectedEdge[55, 253] -> 
             RGBColor[
              0.6863956015033539, 0.7534068041021587, 0.9704970524775036], 
             UndirectedEdge[52, 141] -> 
             RGBColor[
              0.6017079925757114, 0.6875326808659474, 0.9617878037860133], 
             UndirectedEdge[160, 299] -> 
             RGBColor[
              0.7987582667324115, 0.8372491736053478, 0.6921585161818027], 
             UndirectedEdge[229, 284] -> 
             RGBColor[
              0.4523077783057438, 0.5643503231943886, 0.9505493842439596], 
             UndirectedEdge[27, 268] -> 
             RGBColor[
              0.8056323127558497, 0.8482896607380622, 0.9474162835066089], 
             UndirectedEdge[193, 236] -> 
             RGBColor[
              0.5095579756663069, 0.6090392192320957, 0.9557863129284079], 
             UndirectedEdge[78, 193] -> 
             RGBColor[
              0.6318099936956943, 0.7053890703971202, 0.9677468432528796], 
             UndirectedEdge[175, 177] -> 
             RGBColor[
              0.617420296918339, 0.6948523859779556, 0.9659428646359416], 
             UndirectedEdge[36, 67] -> 
             RGBColor[
              0.7444267017764119, 0.8002710643709976, 0.9751611546361694], 
             UndirectedEdge[37, 239] -> 
             RGBColor[
              0.6856350075173172, 0.7535372937649754, 0.9698519033309587], 
             UndirectedEdge[49, 280] -> 
             RGBColor[
              0.8104823892686333, 0.8519666679555257, 0.9817204485259481], 
             UndirectedEdge[263, 276] -> 
             RGBColor[
              0.5945564768087045, 0.6817267581941775, 0.961224810267969], 
             UndirectedEdge[13, 73] -> 
             RGBColor[
              0.7655865107541748, 0.8145775069903258, 0.8994700660418722], 
             UndirectedEdge[136, 240] -> 
             RGBColor[
              0.7798730044830526, 0.826497046872303, 0.9140188551703698], 
             UndirectedEdge[79, 241] -> 
             RGBColor[
              0.7221521322472608, 0.7819412640306584, 0.9738808707189494], 
             UndirectedEdge[78, 226] -> 
             RGBColor[
              0.8533253800259426, 0.886189185010857, 0.98579074884544], 
             UndirectedEdge[3, 74] -> 
             RGBColor[
              0.8033761910364451, 0.8467343052321568, 0.9809275021496635], 
             UndirectedEdge[148, 203] -> 
             RGBColor[
              0.6916398874537495, 0.7589661850613489, 0.9699459528839283], 
             UndirectedEdge[90, 257] -> 
             RGBColor[
              0.3287510738490854, 0.45916938948383035`, 0.9421687056158715], 
             UndirectedEdge[34, 87] -> 
             RGBColor[
              0.8322867986588907, 0.8691567605653103, 0.9838522251550043], 
             UndirectedEdge[146, 235] -> 
             RGBColor[
              0.7929282720570572, 0.8389633178845421, 0.9730236603292493], 
             UndirectedEdge[181, 256] -> 
             RGBColor[
              0.49294819415302493`, 0.5826914647559039, 0.9565883396287038], 
             UndirectedEdge[68, 287] -> 
             RGBColor[
              0.6788582550886086, 0.7474766417289118, 0.9697005896364863], 
             UndirectedEdge[17, 144] -> 
             RGBColor[
              0.7082874040153915, 0.7719661465742815, 0.9716087804082175], 
             UndirectedEdge[163, 216] -> 
             RGBColor[
              0.8177151185232185, 0.8579499757181763, 0.9823529595616338], 
             UndirectedEdge[67, 258] -> 
             RGBColor[
              0.7207966123742129, 0.7818110589346686, 0.9728059281602988], 
             UndirectedEdge[232, 240] -> 
             RGBColor[
              0.6242211216562278, 0.6905729902165767, 0.9033627725431861], 
             UndirectedEdge[133, 210] -> 
             RGBColor[
              0.7043862213216607, 0.7680544882481362, 0.9718648968691586], 
             UndirectedEdge[58, 154] -> 
             RGBColor[
              0.710265265234826, 0.773583890508177, 0.9717562618984792], 
             UndirectedEdge[94, 124] -> 
             RGBColor[
              0.37740649926912895`, 0.5013122734898845, 0.9452689862993333], 
             UndirectedEdge[50, 213] -> 
             RGBColor[
              0.8531094179406357, 0.4036803082073476, 0.4403716586539699], 
             UndirectedEdge[15, 212] -> 
             RGBColor[
              0.5827894448508868, 0.6712564657442128, 0.9609256197247817], 
             UndirectedEdge[11, 139] -> 
             RGBColor[
              0.4884087167538831, 0.5930986318423486, 0.9535461284728277], 
             UndirectedEdge[167, 286] -> 
             RGBColor[
              0.6109161372083634, 0.6942650723727553, 0.9630208292301294], 
             UndirectedEdge[113, 288] -> 
             RGBColor[
              0.6744615100399262, 0.7456137248313033, 0.9681876781857669], 
             UndirectedEdge[73, 171] -> 
             RGBColor[
              0.7610099942899118, 0.811864584067165, 0.9385748938243494], 
             UndirectedEdge[31, 110] -> 
             RGBColor[
              0.8466649854540701, 0.8809066369606816, 0.9765466973588834], 
             UndirectedEdge[202, 275] -> 
             RGBColor[
              0.834492739113637, 0.8712851792572233, 0.9839645859623198], 
             UndirectedEdge[103, 241] -> 
             RGBColor[
              0.5580443588295381, 0.6520845759665197, 0.9583504425923539], 
             UndirectedEdge[9, 20] -> 
             RGBColor[
              0.4901354964723118, 0.5966505003633934, 0.953088017990873], 
             UndirectedEdge[71, 207] -> 
             RGBColor[
              0.708979978963738, 0.7718678545422576, 0.9721299129630542], 
             UndirectedEdge[160, 168] -> 
             RGBColor[
              0.7140684483798048, 0.7760141624643844, 0.9725129328360009], 
             UndirectedEdge[6, 114] -> 
             RGBColor[
              0.9780282687863016, 0.9831340993530073, 0.9220765891862258], 
             UndirectedEdge[95, 96] -> 
             RGBColor[
              0.6895447608531113, 0.7538138246624217, 0.954075742101459], 
             UndirectedEdge[198, 278] -> 
             RGBColor[
              0.5578695599539902, 0.6494332825074149, 0.9594788175241364], 
             UndirectedEdge[86, 281] -> 
             RGBColor[
              0.8076462786048377, 0.8496586782759437, 0.981462291233892], 
             UndirectedEdge[107, 165] -> 
             RGBColor[
              0.8996081628990739, 0.9222016558081045, 0.9699873058539963], 
             UndirectedEdge[155, 184] -> 
             RGBColor[
              0.7885973932984098, 0.8350336228837434, 0.9794957209854529], 
             UndirectedEdge[247, 285] -> 
             RGBColor[
              0.5090988780570214, 0.6123484297066095, 0.9544972750527377], 
             UndirectedEdge[34, 227] -> 
             RGBColor[
              0.7547870976617821, 0.8083646843785739, 0.9761937820746189], 
             UndirectedEdge[116, 152] -> 
             RGBColor[
              0.5450088094571665, 0.6415017297412215, 0.9573242363949701], 
             UndirectedEdge[146, 204] -> 
             RGBColor[
              0.8239402210912871, 0.8631900881696247, 0.9761146415858405], 
             UndirectedEdge[36, 58] -> 
             RGBColor[
              0.7299879768797374, 0.788991422743342, 0.9737220374760246], 
             UndirectedEdge[105, 129] -> 
             RGBColor[
              0.6247521230276236, 0.700936066635534, 0.9665328549602914], 
             UndirectedEdge[87, 187] -> 
             RGBColor[
              0.8376944811585035, 0.8734188569375863, 0.9843812415032311], 
             UndirectedEdge[119, 168] -> 
             RGBColor[
              0.5982337196544738, 0.6798249969287287, 0.9639878606637133], 
             UndirectedEdge[20, 37] -> 
             RGBColor[
              0.6118254757196051, 0.6933127888879336, 0.9641249564162584], 
             UndirectedEdge[150, 200] -> 
             RGBColor[
              0.6441531263925453, 0.7172407612493786, 0.9679990075324838], 
             UndirectedEdge[1, 43] -> 
             RGBColor[
              0.7783594469066346, 0.8267795827651425, 0.9785432535512177], 
             UndirectedEdge[187, 213] -> 
             RGBColor[
              0.8746614764274139, 0.9028953355226601, 0.9879071865128062], 
             UndirectedEdge[41, 222] -> 
             RGBColor[
              0.7655332375449315, 0.8168950037575264, 0.9772289382846582], 
             UndirectedEdge[196, 263] -> 
             RGBColor[
              0.6145824159649698, 0.6979847177595118, 0.9628013255557825], 
             UndirectedEdge[148, 172] -> 
             RGBColor[
              0.8314224946428288, 0.8690212115499102, 0.9836228723996083], 
             UndirectedEdge[96, 171] -> 
             RGBColor[
              0.9674541296803674, 0.9752479237213654, 0.9399758485154014], 
             UndirectedEdge[178, 208] -> 
             RGBColor[
              0.8374042803038229, 0.8731883580868022, 0.9511365523853288], 
             UndirectedEdge[25, 270] -> 
             RGBColor[
              0.6106846270764271, 0.6943814504286434, 0.962794532908209], 
             UndirectedEdge[47, 217] -> 
             RGBColor[
              0.7018330571705563, 0.7669965854812146, 0.9709158182020972], 
             UndirectedEdge[33, 142] -> 
             RGBColor[
              0.6171550152584879, 0.6951145854308248, 0.9656994788849819], 
             UndirectedEdge[26, 62] -> 
             RGBColor[
              0.7530018536425533, 0.8057254703732086, 0.9476606574563975], 
             UndirectedEdge[48, 177] -> 
             RGBColor[
              0.6146868376167043, 0.6926727997286082, 0.9656821448475637], 
             UndirectedEdge[238, 300] -> 
             RGBColor[
              0.6233938776992625, 0.7036314717749803, 0.9645251949934273], 
             UndirectedEdge[25, 139] -> 
             RGBColor[
              0.5169994633333455, 0.6158710211962506, 0.9560969523467224], 
             UndirectedEdge[3, 30] -> 
             RGBColor[
              0.9164007174902626, 0.935501119094289, 0.9684525536995741], 
             UndirectedEdge[95, 171] -> 
             RGBColor[
              0.7013444232284521, 0.7626139935417771, 0.9341019915448379], 
             UndirectedEdge[21, 50] -> 
             RGBColor[
              0.687839927100527, 0.27138385852116426`, 0.4256616485842122], 
             UndirectedEdge[122, 232] -> 
             RGBColor[
              0.31790409751875043`, 0.4454197330380663, 0.9416369873093475], 
             UndirectedEdge[127, 136] -> 
             RGBColor[
              0.5728535357130008, 0.6641073329063307, 0.9595162752444224], 
             UndirectedEdge[41, 290] -> 
             RGBColor[
              0.7505689068736313, 0.8052047549039814, 0.9757374336529638], 
             UndirectedEdge[123, 259] -> 
             RGBColor[
              0.6314906646094103, 0.7108627382750612, 0.9647127732951101], 
             UndirectedEdge[20, 185] -> 
             RGBColor[
              0.49653021698104083`, 0.6018420225512556, 0.9535914338139533], 
             UndirectedEdge[163, 211] -> 
             RGBColor[
              0.7477712920562608, 0.8030115744548871, 0.9755851875672926], 
             UndirectedEdge[33, 37] -> 
             RGBColor[
              0.5807598007107286, 0.6664052626014707, 0.9621454790749906], 
             UndirectedEdge[7, 9] -> 
             RGBColor[
              0.5162859747956224, 0.6181832386140242, 0.9550630696352032], 
             UndirectedEdge[105, 263] -> 
             RGBColor[
              0.49743792700426637`, 0.6007053958118318, 0.9541805585876261], 
             UndirectedEdge[15, 49] -> 
             RGBColor[
              0.766827387350932, 0.8178630486671145, 0.9773693259139791], 
             UndirectedEdge[20, 237] -> 
             RGBColor[
              0.6966568603601762, 0.7602456099700096, 0.9584933782725429], 
             UndirectedEdge[26, 220] -> 
             RGBColor[
              0.7664367760948518, 0.8138135703305249, 0.8353331294669836], 
             UndirectedEdge[101, 187] -> 
             RGBColor[
              0.8670690822200418, 0.8968413664717523, 0.9871830171754967], 
             UndirectedEdge[93, 94] -> 
             RGBColor[
              0.58025624058039, 0.6652876963509552, 0.9624017967345151], 
             UndirectedEdge[143, 297] -> 
             RGBColor[
              0.9292950343826922, 0.9461644694775592, 0.9829187035270704], 
             UndirectedEdge[208, 268] -> 
             RGBColor[
              0.837738416524503, 0.8734375563330875, 0.9505709469204009], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.6842131581090332, 0.7465298335769475, 0.8938016521137784], 
             UndirectedEdge[224, 288] -> 
             RGBColor[
              0.8114349517925314, 0.8534893892963654, 0.9783363270991923], 
             UndirectedEdge[1, 75] -> 
             RGBColor[
              0.8067032417867752, 0.8491783461737017, 0.9813002639814447], 
             UndirectedEdge[36, 113] -> 
             RGBColor[
              0.7035344966338954, 0.768325762921394, 0.9710854017869471], 
             UndirectedEdge[29, 244] -> 
             RGBColor[
              0.9898927139075018, 0.9899779271263859, 0.8091378090239149], 
             UndirectedEdge[36, 96] -> 
             RGBColor[
              0.8486694641847043, 0.8822882799634845, 0.9674187163908566], 
             UndirectedEdge[58, 138] -> 
             RGBColor[
              0.7834486607009236, 0.8309866548468239, 0.9789891084077084], 
             UndirectedEdge[71, 136] -> 
             RGBColor[
              0.5832478578881075, 0.6725459119069601, 0.9603345543617036], 
             UndirectedEdge[144, 252] -> 
             RGBColor[
              0.6245504746458744, 0.7039847350064283, 0.9650167025897699], 
             UndirectedEdge[58, 198] -> 
             RGBColor[
              0.5598805370833926, 0.6510042731248964, 0.9596792529307454], 
             UndirectedEdge[110, 154] -> 
             RGBColor[
              0.7251613086320003, 0.7852207928241725, 0.9732409602928694], 
             UndirectedEdge[119, 152] -> 
             RGBColor[
              0.494826361610452, 0.5986120434243756, 0.9539675522656763], 
             UndirectedEdge[38, 90] -> 
             RGBColor[
              0.6482031998882158, 0.7159030133778218, 0.9122075247569514], 
             UndirectedEdge[66, 179] -> 
             RGBColor[
              0.9306261561657658, 0.9472433871200865, 0.9836530016866086], 
             UndirectedEdge[6, 21] -> 
             RGBColor[
              0.7020103619434263, 0.7634384100833047, 0.9377582052701214], 
             UndirectedEdge[176, 287] -> 
             RGBColor[
              0.5969514913453504, 0.683490455378218, 0.9615368888887839], 
             UndirectedEdge[142, 237] -> 
             RGBColor[
              0.9027041455944481, 0.9248576097040028, 0.9767764582353056], 
             UndirectedEdge[108, 221] -> 
             RGBColor[
              0.7749957845055547, 0.8241518641326377, 0.9782079951182905], 
             UndirectedEdge[44, 256] -> 
             RGBColor[
              0.46083067991985793`, 0.5576010185348048, 0.9533871659651769], 
             UndirectedEdge[89, 112] -> 
             RGBColor[
              0.4857991956426514, 0.5895060819232304, 0.9538299092511469], 
             UndirectedEdge[83, 184] -> 
             RGBColor[
              0.7719840403832192, 0.8217990667341661, 0.9779078126105251], 
             UndirectedEdge[259, 261] -> 
             RGBColor[
              0.7253946011354782, 0.7847513947116431, 0.9739315446382035], 
             UndirectedEdge[207, 231] -> 
             RGBColor[
              0.5016714020532042, 0.5841124001481661, 0.9583078547159938], 
             UndirectedEdge[112, 280] -> 
             RGBColor[
              0.5528298558137044, 0.6418709431007428, 0.9605108990198638], 
             UndirectedEdge[174, 194] -> 
             RGBColor[
              0.6934605497006011, 0.7603006620908839, 0.9701874749081116], 
             UndirectedEdge[125, 200] -> 
             RGBColor[
              0.36470020343617066`, 0.4903067186763739, 0.9444593523645934], 
             UndirectedEdge[99, 222] -> 
             RGBColor[
              0.5939355794759278, 0.6804264600695686, 0.9617203148143364], 
             UndirectedEdge[108, 169] -> 
             RGBColor[
              0.8873182067462955, 0.9082191728151048, 0.7156641792470566], 
             UndirectedEdge[15, 57] -> 
             RGBColor[
              0.642836133967615, 0.7200050730416906, 0.9656527150503202], 
             UndirectedEdge[4, 78] -> 
             RGBColor[
              0.8537107532480472, 0.8864902415009099, 0.9858291592467019], 
             UndirectedEdge[52, 86] -> 
             RGBColor[
              0.715007162372858, 0.7769745297558188, 0.9724434139892946], 
             UndirectedEdge[20, 282] -> 
             RGBColor[
              0.6331458563764853, 0.7100018483681659, 0.9662411051122746], 
             UndirectedEdge[42, 55] -> 
             RGBColor[
              0.7585678645242151, 0.8093233608094255, 0.9174745873033869], 
             UndirectedEdge[136, 165] -> 
             RGBColor[
              0.706882120035762, 0.770046068788165, 0.9721013250710033], 
             UndirectedEdge[161, 269] -> 
             RGBColor[
              0.7408044978014194, 0.7974413710959638, 0.9748001271953628], 
             UndirectedEdge[57, 243] -> 
             RGBColor[
              0.7075085439141799, 0.7706214085516097, 0.9720737761628501], 
             UndirectedEdge[57, 146] -> 
             RGBColor[
              0.7633172006975857, 0.8149282562458826, 0.9706894642628308], 
             UndirectedEdge[4, 130] -> 
             RGBColor[
              0.7687945385941787, 0.8193074036954562, 0.9775899128797824], 
             UndirectedEdge[31, 58] -> 
             RGBColor[
              0.8317689420568959, 0.8692697346446862, 0.9750619989644932], 
             UndirectedEdge[95, 140] -> 
             RGBColor[
              0.3984678935333164, 0.5195545946250686, 0.9466109997179877], 
             UndirectedEdge[58, 96] -> 
             RGBColor[
              0.8369729800000596, 0.8731508976218676, 0.9662529201571904], 
             UndirectedEdge[16, 94] -> 
             RGBColor[
              0.6756875751138847, 0.7391454020948107, 0.8932584095042047], 
             UndirectedEdge[113, 135] -> 
             RGBColor[
              0.7100408695777081, 0.7734085909153663, 0.9717338962364743], 
             UndirectedEdge[47, 262] -> 
             RGBColor[
              0.7238891051367953, 0.7842269377846136, 0.9731141589378849], 
             UndirectedEdge[153, 211] -> 
             RGBColor[
              0.49821128850535096`, 0.6013421680864532, 0.9542389751056459], 
             UndirectedEdge[89, 111] -> 
             RGBColor[
              0.6985860911661191, 0.7644600309606926, 0.9705921909753974], 
             UndirectedEdge[137, 256] -> 
             RGBColor[
              0.2891614824065417, 0.4165967002104227, 0.9399493428547163], 
             UndirectedEdge[136, 181] -> 
             RGBColor[
              0.6698403907266299, 0.74094043787317, 0.9684540267015385], 
             UndirectedEdge[288, 291] -> 
             RGBColor[
              0.815051604389423, 0.856186682881402, 0.9722142776267231], 
             UndirectedEdge[121, 296] -> 
             RGBColor[
              0.8182969771665645, 0.854358783296792, 0.7135520058022258], 
             UndirectedEdge[241, 277] -> 
             RGBColor[
              0.661315004646096, 0.7336861073905627, 0.9680105769779923], 
             UndirectedEdge[217, 262] -> 
             RGBColor[
              0.7685809073302127, 0.8191405133283882, 0.9775686201118878], 
             UndirectedEdge[75, 142] -> 
             RGBColor[
              0.8529856460345742, 0.8856116167421517, 0.985839726459695], 
             UndirectedEdge[57, 112] -> 
             RGBColor[
              0.44977195008905857`, 0.5604586562393934, 0.9508562089036152], 
             UndirectedEdge[274, 287] -> 
             RGBColor[
              0.6740125895549858, 0.7436911709856235, 0.9692176189814139], 
             UndirectedEdge[97, 252] -> 
             RGBColor[
              0.5215479285194727, 0.6224551296953598, 0.9554773099075162], 
             UndirectedEdge[18, 69] -> 
             RGBColor[
              0.694608554976319, 0.7597621989191243, 0.9715030012057839], 
             UndirectedEdge[106, 167] -> 
             RGBColor[
              0.8395320899506622, 0.8739099048892299, 0.9076070872457135], 
             UndirectedEdge[256, 296] -> 
             RGBColor[
              0.43146092662317315`, 0.5346571440410424, 0.9504598634325125], 
             UndirectedEdge[131, 183] -> 
             RGBColor[
              0.7527365742342069, 0.8013409502579478, 0.7235941585429101], 
             UndirectedEdge[172, 183] -> 
             RGBColor[
              0.7149385963917575, 0.7760315948621597, 0.973374452332975], 
             UndirectedEdge[1, 143] -> 
             RGBColor[
              0.8544051079672066, 0.8869203372630985, 0.9756506300462298], 
             UndirectedEdge[17, 252] -> 
             RGBColor[
              0.5538812244533153, 0.6487047559328358, 0.958022705404194], 
             UndirectedEdge[126, 214] -> 
             RGBColor[
              0.9540877275004553, 0.9652792828610618, 0.9626016808899762], 
             UndirectedEdge[84, 134] -> 
             RGBColor[
              0.7493706398163686, 0.8041333063431327, 0.9756539201762645], 
             UndirectedEdge[45, 234] -> 
             RGBColor[
              0.7092990353209829, 0.7728290643558633, 0.9716599571305993], 
             UndirectedEdge[32, 156] -> 
             RGBColor[
              0.38414878386549783`, 0.49449593403077596`, 0.946882000995798], 
             UndirectedEdge[140, 149] -> 
             RGBColor[
              0.48960019559914525`, 0.5943512949398808, 0.9535610783285968], 
             UndirectedEdge[16, 150] -> 
             RGBColor[
              0.9396205078292602, 0.9526368091784527, 0.915809144617727], 
             UndirectedEdge[209, 218] -> 
             RGBColor[
              0.7277580603879045, 0.7850279708184442, 0.9402165392128417], 
             UndirectedEdge[82, 281] -> 
             RGBColor[
              0.8999497646561503, 0.9202712272770598, 0.8756565837511969], 
             UndirectedEdge[178, 182] -> 
             RGBColor[
              0.8856605663144357, 0.9108865354796503, 0.9559462879942345], 
             UndirectedEdge[41, 157] -> 
             RGBColor[
              0.6291883046051451, 0.70614031292289, 0.9661885907326282], 
             UndirectedEdge[254, 288] -> 
             RGBColor[
              0.7370877215864478, 0.7945377972682823, 0.9744296736775029], 
             UndirectedEdge[129, 161] -> 
             RGBColor[
              0.8050476863387982, 0.8480840791626924, 0.9810824278267194], 
             UndirectedEdge[20, 283] -> 
             RGBColor[
              0.7149302216101563, 0.7732932000460473, 0.901558524316179], 
             UndirectedEdge[162, 210] -> 
             RGBColor[
              0.8172424167609043, 0.8572848425669197, 0.9823843558724819], 
             UndirectedEdge[203, 244] -> 
             RGBColor[
              0.811294702921252, 0.8524373740024318, 0.9345006469520795], 
             UndirectedEdge[121, 246] -> 
             RGBColor[
              0.7738775492354308, 0.8183184707354176, 0.710040528026833], 
             UndirectedEdge[24, 259] -> 
             RGBColor[
              0.4881116895772212, 0.5941614349033483, 0.9531624620407162], 
             UndirectedEdge[141, 281] -> 
             RGBColor[
              0.6943471088076911, 0.7602168293860723, 0.9708066810306106], 
             UndirectedEdge[110, 138] -> 
             RGBColor[
              0.7983447040980978, 0.8426235571628193, 0.9804738068020986], 
             UndirectedEdge[67, 109] -> 
             RGBColor[
              0.8672341641824711, 0.895714653786572, 0.9177900249660811], 
             UndirectedEdge[154, 245] -> 
             RGBColor[
              0.703954827600995, 0.7686541286675259, 0.9711272964495314], 
             UndirectedEdge[193, 249] -> 
             RGBColor[
              0.6158351694537472, 0.692651179171644, 0.9662231502557888], 
             UndirectedEdge[82, 137] -> 
             RGBColor[
              0.6759503310141449, 0.7383861307644207, 0.8570029717572891], 
             UndirectedEdge[100, 125] -> 
             RGBColor[
              0.4452051899005132, 0.557181254201951, 0.9503778590081979], 
             UndirectedEdge[104, 218] -> 
             RGBColor[
              0.6080812938307555, 0.6912862718762944, 0.9632607657733683], 
             UndirectedEdge[73, 149] -> 
             RGBColor[
              0.5742329275284845, 0.6652271853230336, 0.959624866021016], 
             UndirectedEdge[108, 219] -> 
             RGBColor[
              0.7573223652889653, 0.8103452547176773, 0.9764464738582735], 
             UndirectedEdge[58, 140] -> 
             RGBColor[
              0.5458961126802646, 0.6388916675845144, 0.958788177773719], 
             UndirectedEdge[9, 63] -> 
             RGBColor[
              0.7287695522588895, 0.7872463063914725, 0.9744792532194682], 
             UndirectedEdge[48, 217] -> 
             RGBColor[
              0.8048161333413397, 0.8477962977336082, 0.9810877142314391], 
             UndirectedEdge[8, 271] -> 
             RGBColor[
              0.6661093409904038, 0.7378903016397416, 0.9681747323350415], 
             UndirectedEdge[18, 222] -> 
             RGBColor[
              0.7896607549845762, 0.8361336312398853, 0.9795302424369405], 
             UndirectedEdge[215, 234] -> 
             RGBColor[
              0.7026691087961856, 0.7676497153653838, 0.9709991480147934], 
             UndirectedEdge[15, 146] -> 
             RGBColor[
              0.8227201045045303, 0.8622369238188208, 0.9759930317671104], 
             UndirectedEdge[54, 151] -> 
             RGBColor[
              0.720846971748262, 0.7818504000604212, 0.9728109475120688], 
             UndirectedEdge[195, 255] -> 
             RGBColor[
              0.6239183016476585, 0.7036377152166386, 0.964853299167111], 
             UndirectedEdge[1, 11] -> 
             RGBColor[
              0.687764855744381, 0.7555693187764914, 0.9698124659081817], 
             UndirectedEdge[32, 178] -> 
             RGBColor[
              0.7682593473505162, 0.8179706723794353, 0.945066056660419], 
             UndirectedEdge[126, 189] -> 
             RGBColor[
              0.9780352582272034, 0.9827558897689863, 0.9048943240216559], 
             UndirectedEdge[61, 273] -> 
             RGBColor[
              0.9099893535079261, 0.9289164484893757, 0.9089322483030275], 
             UndirectedEdge[54, 194] -> 
             RGBColor[
              0.6496250314536725, 0.7260560220741052, 0.9658183601154664], 
             UndirectedEdge[38, 144] -> 
             RGBColor[
              0.8824261674131564, 0.9078408206830808, 0.9310056903817119], 
             UndirectedEdge[4, 220] -> 
             RGBColor[
              0.8889831922111237, 0.9111507041488147, 0.8464514706541393], 
             UndirectedEdge[45, 200] -> 
             RGBColor[
              0.5408586945102698, 0.6359735279063716, 0.9578555975196859], 
             UndirectedEdge[2, 202] -> 
             RGBColor[
              0.7081224877831322, 0.77061841142911, 0.9726992383761879], 
             UndirectedEdge[17, 175] -> 
             RGBColor[
              0.7530962398724037, 0.8073638872208055, 0.9759706859430878], 
             UndirectedEdge[233, 262] -> 
             RGBColor[
              0.8765183628964504, 0.9039246282747699, 0.964149260536725], 
             UndirectedEdge[67, 138] -> 
             RGBColor[
              0.7978873855975981, 0.8422662964744796, 0.9804282255678531], 
             UndirectedEdge[39, 192] -> 
             RGBColor[
              0.617929538627773, 0.6319718368991799, 0.6099663821882262], 
             UndirectedEdge[164, 168] -> 
             RGBColor[
              0.7342263854605415, 0.7923212760118961, 0.9741394997878728], 
             UndirectedEdge[19, 253] -> 
             RGBColor[
              0.7651027271299724, 0.8165999330777933, 0.9771750832571167], 
             UndirectedEdge[24, 74] -> 
             RGBColor[
              0.5734383974063832, 0.66200114308189, 0.9608590034572315], 
             UndirectedEdge[80, 133] -> 
             RGBColor[
              0.6905158253414818, 0.7570892412594008, 0.9705168141558713], 
             UndirectedEdge[198, 222] -> 
             RGBColor[
              0.5479029327217897, 0.6416472775644474, 0.9584854372650575], 
             UndirectedEdge[111, 212] -> 
             RGBColor[
              0.6025121564957981, 0.6866639979793778, 0.9628913953023271], 
             UndirectedEdge[126, 184] -> 
             RGBColor[
              0.8475494174267405, 0.8811669104085615, 0.9548353392620689], 
             UndirectedEdge[132, 294] -> 
             RGBColor[
              0.9334922302575053, 0.9494743094771181, 0.9820400342378325], 
             UndirectedEdge[39, 136] -> 
             RGBColor[
              0.7626227436601614, 0.7563776283726502, 0.6199983843269279], 
             UndirectedEdge[133, 162] -> 
             RGBColor[
              0.6856117049100979, 0.753258105105708, 0.9700280172628821], 
             UndirectedEdge[22, 271] -> 
             RGBColor[
              0.7666999954981446, 0.8168130852790585, 0.9478497963534094], 
             UndirectedEdge[107, 110] -> 
             RGBColor[
              0.8532436135856061, 0.8858129670496662, 0.9654107959132056], 
             UndirectedEdge[40, 191] -> 
             RGBColor[
              0.6815590050662688, 0.7511583418888421, 0.9688950901601308], 
             UndirectedEdge[143, 237] -> 
             RGBColor[
              0.9491236823078173, 0.9615771060842704, 0.9710045145707732], 
             UndirectedEdge[157, 261] -> 
             RGBColor[
              0.6536131767604146, 0.7256160429840093, 0.9685182568431385], 
             UndirectedEdge[35, 163] -> 
             RGBColor[
              0.8725467605682662, 0.9012091184990088, 0.9877054830263315], 
             UndirectedEdge[89, 175] -> 
             RGBColor[
              0.7620310235949155, 0.8144164318886742, 0.9768115684523191], 
             UndirectedEdge[16, 200] -> 
             RGBColor[
              0.6929168797660118, 0.7540685598144521, 0.8943562455613623], 
             UndirectedEdge[35, 189] -> 
             RGBColor[
              0.9294863294203453, 0.9449177480690107, 0.9305469622637549], 
             UndirectedEdge[233, 291] -> 
             RGBColor[
              0.9544822456994256, 0.9655735138878896, 0.9619338644859452], 
             UndirectedEdge[258, 290] -> 
             RGBColor[
              0.6794159524446353, 0.7494841728930188, 0.9686814907027717], 
             UndirectedEdge[157, 259] -> 
             RGBColor[
              0.4934278424673774, 0.5987660193391882, 0.9535012026019875], 
             UndirectedEdge[105, 245] -> 
             RGBColor[
              0.5394213693730514, 0.6338195924278229, 0.9581487429125533], 
             UndirectedEdge[100, 192] -> 
             RGBColor[
              0.4210123115741763, 0.5338984575076644, 0.9489215548576055], 
             UndirectedEdge[258, 278] -> 
             RGBColor[
              0.704346910348136, 0.7689604266895316, 0.9711663755935448], 
             UndirectedEdge[99, 201] -> 
             RGBColor[
              0.7434553999474954, 0.7939764844926476, 0.7368302548248625], 
             UndirectedEdge[9, 282] -> 
             RGBColor[
              0.6811079478157047, 0.7492422367482648, 0.9699332468396605], 
             UndirectedEdge[84, 175] -> 
             RGBColor[
              0.7892450635139634, 0.8356762467077983, 0.9795240096217874], 
             UndirectedEdge[271, 291] -> 
             RGBColor[
              0.7553383275743737, 0.8083395719445339, 0.967082136550771], 
             UndirectedEdge[127, 256] -> 
             RGBColor[
              0.3959613391393959, 0.5058583597890647, 0.9476505881715879], 
             UndirectedEdge[80, 116] -> 
             RGBColor[
              0.6414007178207708, 0.7172153843637086, 0.966650292977274], 
             UndirectedEdge[202, 268] -> 
             RGBColor[
              0.9370582628836288, 0.9516808171587754, 0.9602967114480925], 
             UndirectedEdge[161, 265] -> 
             RGBColor[
              0.853500521607734, 0.8857510326205431, 0.9521419662498507], 
             UndirectedEdge[22, 72] -> 
             RGBColor[
              0.9239090206539724, 0.941297821212605, 0.9625738283115761], 
             UndirectedEdge[77, 162] -> 
             RGBColor[
              0.6393804169494349, 0.7157254628434534, 0.9663885209238309], 
             UndirectedEdge[93, 164] -> 
             RGBColor[
              0.721833661241938, 0.7826212093919989, 0.9729092914996609], 
             UndirectedEdge[19, 111] -> 
             RGBColor[
              0.7150282582276837, 0.7773047768342849, 0.972230992527307], 
             UndirectedEdge[37, 142] -> 
             RGBColor[
              0.817872760953877, 0.8579247886219268, 0.9824080363790211], 
             UndirectedEdge[43, 172] -> 
             RGBColor[
              0.8562694360218959, 0.888431830998986, 0.9860993833084049], 
             UndirectedEdge[61, 285] -> 
             RGBColor[
              0.691826969680118, 0.7578938405577185, 0.9708353053397124], 
             UndirectedEdge[38, 257] -> 
             RGBColor[
              0.6664435545792318, 0.7317018918242961, 0.9133697840285506], 
             UndirectedEdge[174, 185] -> 
             RGBColor[
              0.6527921179404985, 0.7272841970960602, 0.9669859069865823], 
             UndirectedEdge[75, 237] -> 
             RGBColor[
              0.901421816127386, 0.9238351149948736, 0.9766541485059881], 
             UndirectedEdge[30, 48] -> 
             RGBColor[
              0.9125095713635529, 0.9323984247951986, 0.9680814127083412], 
             UndirectedEdge[289, 298] -> 
             RGBColor[
              0.5770517539598765, 0.6675156356067211, 0.9598467743633967], 
             UndirectedEdge[123, 261] -> 
             RGBColor[
              0.7916759989024476, 0.8377127619198822, 0.9797298275362611], 
             UndirectedEdge[77, 206] -> 
             RGBColor[
              0.4182100175716107, 0.5359217975097312, 0.9480713237387717], 
             UndirectedEdge[121, 137] -> 
             RGBColor[
              0.675997532949933, 0.7362983394661725, 0.7030414852244294], 
             UndirectedEdge[87, 227] -> 
             RGBColor[
              0.7732565622869776, 0.8230418912651589, 0.9779686428623745], 
             UndirectedEdge[123, 144] -> 
             RGBColor[
              0.7383643582921652, 0.7955351155655872, 0.9745569168934806], 
             UndirectedEdge[9, 37] -> 
             RGBColor[
              0.6597875671588245, 0.7325531772680325, 0.9678170981436444], 
             UndirectedEdge[178, 268] -> 
             RGBColor[
              0.9729036590537663, 0.9793121738052608, 0.9307512167511298], 
             UndirectedEdge[112, 253] -> 
             RGBColor[
              0.5789720344432032, 0.662470012291005, 0.9630696427152499], 
             UndirectedEdge[78, 220] -> 
             RGBColor[
              0.9598815138678254, 0.9673826574049491, 0.8532935444517593], 
             UndirectedEdge[66, 67] -> 
             RGBColor[
              0.8309967527222464, 0.8686668070898454, 0.9835862265612831], 
             UndirectedEdge[20, 124] -> 
             RGBColor[
              0.41699775727315375`, 0.5356042312584842, 0.947791706250175], 
             UndirectedEdge[18, 224] -> 
             RGBColor[
              0.9121583208529425, 0.9327006314434483, 0.9882360713269764], 
             UndirectedEdge[72, 151] -> 
             RGBColor[
              0.8265988787981872, 0.8649377989898153, 0.9832257351362215], 
             UndirectedEdge[25, 29] -> 
             RGBColor[
              0.8330809952362751, 0.86747948299963, 0.8408796620954189], 
             UndirectedEdge[135, 258] -> 
             RGBColor[
              0.7245607446059958, 0.7847516276426021, 0.9731811016833471], 
             UndirectedEdge[130, 176] -> 
             RGBColor[
              0.7044652951949253, 0.7690529098316015, 0.9711781750887034], 
             UndirectedEdge[31, 245] -> 
             RGBColor[
              0.8254585044230648, 0.8643399728040351, 0.9744330335155454], 
             UndirectedEdge[295, 297] -> 
             RGBColor[
              0.89348526761997, 0.9179049156614043, 0.989702616520949], 
             UndirectedEdge[17, 30] -> 
             RGBColor[
              0.7997649446156163, 0.8439002913244296, 0.9569862297762729], 
             UndirectedEdge[22, 273] -> 
             RGBColor[
              0.9790791790113331, 0.9831406306651025, 0.8854914646033969], 
             UndirectedEdge[86, 165] -> 
             RGBColor[
              0.8244752860184479, 0.8629739772237807, 0.9830949743834365], 
             UndirectedEdge[124, 200] -> 
             RGBColor[
              0.394635803921256, 0.5162354312095261, 0.9463668223564909], 
             UndirectedEdge[198, 258] -> 
             RGBColor[
              0.5479469318658384, 0.6416816500301842, 0.958489822688541], 
             UndirectedEdge[177, 217] -> 
             RGBColor[
              0.5563955636393383, 0.6467866630199892, 0.9599647099922246], 
             UndirectedEdge[52, 110] -> 
             RGBColor[
              0.6849800051573189, 0.7535170863241925, 0.9694505875777877], 
             UndirectedEdge[121, 299] -> 
             RGBColor[
              0.992262973586439, 0.9853557995401205, 0.4420908215991487], 
             UndirectedEdge[173, 196] -> 
             RGBColor[
              0.7349244405766018, 0.7926559683540556, 0.9744886099950666], 
             UndirectedEdge[238, 251] -> 
             RGBColor[
              0.7448732164761307, 0.8006198850480555, 0.9752056590485203], 
             UndirectedEdge[218, 284] -> 
             RGBColor[
              0.4323443203930979, 0.5481430887173726, 0.9489777877085204], 
             UndirectedEdge[209, 276] -> 
             RGBColor[
              0.7709270758822069, 0.8200745223387047, 0.9436149622458674], 
             UndirectedEdge[8, 72] -> 
             RGBColor[
              0.8233183661462317, 0.8623750375732882, 0.9828987642932082], 
             UndirectedEdge[56, 168] -> 
             RGBColor[
              0.7951525358810481, 0.8399172477762891, 0.9802120490745423], 
             UndirectedEdge[201, 257] -> 
             RGBColor[
              0.6701836767275616, 0.7316041830286448, 0.7318597274097527], 
             UndirectedEdge[31, 51] -> 
             RGBColor[
              0.7083172247995053, 0.7702092580826341, 0.9645481489296932], 
             UndirectedEdge[53, 282] -> 
             RGBColor[
              0.8979981328365653, 0.9205703961784831, 0.9577868975648353], 
             UndirectedEdge[17, 97] -> 
             RGBColor[
              0.6052848578889898, 0.6904365412632131, 0.9620693877259638], 
             UndirectedEdge[102, 162] -> 
             RGBColor[
              0.8941808204562743, 0.9162886378377133, 0.8988489397511447], 
             UndirectedEdge[36, 260] -> 
             RGBColor[
              0.8648364421648344, 0.8937148618343913, 0.9118071376877124], 
             UndirectedEdge[79, 168] -> 
             RGBColor[
              0.8662255489567677, 0.896168755944718, 0.9871025602198147], 
             UndirectedEdge[142, 297] -> 
             RGBColor[
              0.882875497669323, 0.9094449730972916, 0.9886906471916028], 
             UndirectedEdge[232, 299] -> 
             RGBColor[
              0.6266672367898277, 0.6879790767459106, 0.6802082836750862], 
             UndirectedEdge[50, 169] -> 
             RGBColor[
              0.875796530738648, 0.4183862378711253, 0.26028990952406306`], 
             UndirectedEdge[92, 153] -> 
             RGBColor[
              0.6688621270447314, 0.7353839180703626, 0.9452322699604441], 
             UndirectedEdge[44, 299] -> 
             RGBColor[
              0.8470904341549681, 0.8755662100279704, 0.6965932271109954], 
             UndirectedEdge[90, 252] -> 
             RGBColor[
              0.3903275071209339, 0.5120469277011692, 0.9462185369650093], 
             UndirectedEdge[7, 283] -> 
             RGBColor[
              0.7410806999334669, 0.7948259382966782, 0.9035335759605092], 
             UndirectedEdge[52, 179] -> 
             RGBColor[
              0.7841520901003387, 0.8317364056660937, 0.9694717814688677], 
             UndirectedEdge[98, 296] -> 
             RGBColor[
              0.4682949287119622, 0.573372015646979, 0.9525575053604461], 
             UndirectedEdge[18, 88] -> 
             RGBColor[
              0.7029402490685224, 0.7665262435217164, 0.9721589026847233], 
             UndirectedEdge[100, 240] -> 
             RGBColor[
              0.77262695913447, 0.8206143808277006, 0.9134484199373907], 
             UndirectedEdge[2, 214] -> 
             RGBColor[
              0.7269855305456857, 0.7855843567102709, 0.9719004382911267], 
             UndirectedEdge[114, 169] -> 
             RGBColor[
              0.9868345936016378, 0.9860968338581371, 0.6848097210785172], 
             UndirectedEdge[37, 295] -> 
             RGBColor[
              0.8284825309045241, 0.8663847311860395, 0.9834200057083672], 
             UndirectedEdge[45, 225] -> 
             RGBColor[
              0.43279174093328976`, 0.5305895523490358, 0.951401056648542], 
             UndirectedEdge[38, 74] -> 
             RGBColor[
              0.8608791815595638, 0.8910081515710965, 0.9288580881998569], 
             UndirectedEdge[38, 158] -> 
             RGBColor[
              0.8923298185144733, 0.9155776281939658, 0.9319927937686097], 
             UndirectedEdge[69, 135] -> 
             RGBColor[
              0.62946454545369, 0.7083458228561044, 0.9651494750287071], 
             UndirectedEdge[113, 224] -> 
             RGBColor[
              0.8023579739560138, 0.8463983852228911, 0.9774316187776289], 
             UndirectedEdge[124, 282] -> 
             RGBColor[
              0.6079702086165467, 0.6881959676433557, 0.9646369350989625], 
             UndirectedEdge[56, 79] -> 
             RGBColor[
              0.8390710442648713, 0.8749366742253977, 0.9844010356107066], 
             UndirectedEdge[49, 146] -> 
             RGBColor[
              0.8873084540809026, 0.9127862318713065, 0.9824060751264896], 
             UndirectedEdge[47, 166] -> 
             RGBColor[
              0.5270802929219909, 0.6251914661938429, 0.9564900278069439], 
             UndirectedEdge[189, 197] -> 
             RGBColor[
              0.8752585050401414, 0.9021303122371385, 0.9252546217008919], 
             UndirectedEdge[125, 256] -> 
             RGBColor[
              0.2755590386754909, 0.40481494712928734`, 0.9390826071683425], 
             UndirectedEdge[69, 138] -> 
             RGBColor[
              0.6764188563310636, 0.7452582269656141, 0.9697680515108638], 
             UndirectedEdge[170, 255] -> 
             RGBColor[
              0.4978103079997581, 0.6031838599898375, 0.9536085974664352], 
             UndirectedEdge[41, 104] -> 
             RGBColor[
              0.7859107944202717, 0.8328141060637106, 0.9792599827148962], 
             UndirectedEdge[185, 283] -> 
             RGBColor[
              0.7692870335581048, 0.8177251106140084, 0.9057540818666453], 
             UndirectedEdge[103, 277] -> 
             RGBColor[
              0.6851991563217035, 0.7530763376895921, 0.9698908248884265], 
             UndirectedEdge[45, 282] -> 
             RGBColor[
              0.7541930992055605, 0.8079340643402013, 0.9761257102621574], 
             UndirectedEdge[222, 245] -> 
             RGBColor[
              0.7000034506996586, 0.765567283000625, 0.9707334601277227], 
             UndirectedEdge[53, 195] -> 
             RGBColor[
              0.8699923528438573, 0.8986586519261854, 0.9550044107416327], 
             UndirectedEdge[121, 136] -> 
             RGBColor[
              0.7828954159249337, 0.8256395811642209, 0.7107504475261648], 
             UndirectedEdge[92, 211] -> 
             RGBColor[
              0.7935726828846457, 0.838796791389512, 0.9544511307610102], 
             UndirectedEdge[26, 137] -> 
             RGBColor[
              0.44843769768197383`, 0.5605442261189183, 0.950428235350293], 
             UndirectedEdge[139, 148] -> 
             RGBColor[
              0.5541563665370697, 0.6448982763819238, 0.9598004052070671], 
             UndirectedEdge[69, 258] -> 
             RGBColor[
              0.5993280831076784, 0.6848029894258031, 0.9621457541033092], 
             UndirectedEdge[244, 272] -> 
             RGBColor[
              0.6618788605289513, 0.7280342881967392, 0.9235947823021294], 
             UndirectedEdge[100, 256] -> 
             RGBColor[
              0.38881332003295976`, 0.5000552758638688, 0.9470878699234725], 
             UndirectedEdge[29, 206] -> 
             RGBColor[
              0.6756405272122975, 0.7374621244049505, 0.8289144688776419], 
             UndirectedEdge[101, 213] -> 
             RGBColor[
              0.9170978596145347, 0.936732955571135, 0.9919548066246002], 
             UndirectedEdge[39, 107] -> 
             RGBColor[
              0.9553487865234733, 0.9085332153925898, 0.6178843651099208], 
             UndirectedEdge[134, 252] -> 
             RGBColor[
              0.6294848868052918, 0.7078395352882867, 0.9655085186791172], 
             UndirectedEdge[14, 288] -> 
             RGBColor[
              0.5906625532554913, 0.6779346784003681, 0.9613495595300793], 
             UndirectedEdge[155, 202] -> 
             RGBColor[
              0.8762726606095712, 0.9041800500550828, 0.9880608626984214], 
             UndirectedEdge[220, 228] -> 
             RGBColor[
              0.7927581664594143, 0.8351824607935998, 0.8374052457349118], 
             UndirectedEdge[228, 266] -> 
             RGBColor[
              0.7565859109804389, 0.809804508880786, 0.9766971090249124], 
             UndirectedEdge[113, 249] -> 
             RGBColor[
              0.7790219793121316, 0.8278845665319604, 0.9784534084571719], 
             UndirectedEdge[109, 179] -> 
             RGBColor[
              0.9668635676259906, 0.974291233816813, 0.9178568000914066], 
             UndirectedEdge[41, 209] -> 
             RGBColor[
              0.9055875609774207, 0.9265558050058603, 0.9562157561543695], 
             UndirectedEdge[76, 261] -> 
             RGBColor[
              0.5941312923062904, 0.6735352261051355, 0.9647486500101554], 
             UndirectedEdge[114, 219] -> 
             RGBColor[
              0.8568387521443077, 0.8882229157607094, 0.9455920156897342], 
             UndirectedEdge[130, 266] -> 
             RGBColor[
              0.8387930437349816, 0.8748218676866816, 0.9843461613748402], 
             UndirectedEdge[1, 185] -> 
             RGBColor[
              0.656295097967514, 0.7300207517167989, 0.9673350512984656], 
             UndirectedEdge[202, 208] -> 
             RGBColor[
              0.8015588841336856, 0.8455570014403168, 0.9806820470822913], 
             UndirectedEdge[8, 285] -> 
             RGBColor[
              0.6603261406757843, 0.7331952390941283, 0.9677194576217139], 
             UndirectedEdge[65, 210] -> 
             RGBColor[
              0.9134821982174262, 0.9313028916879156, 0.8919543633212655], 
             UndirectedEdge[63, 183] -> 
             RGBColor[
              0.7158977820766009, 0.776796423490852, 0.9734659403198705], 
             UndirectedEdge[51, 86] -> 
             RGBColor[
              0.6397629760504152, 0.7158879095872948, 0.9665199160134554], 
             UndirectedEdge[91, 191] -> 
             RGBColor[
              0.72975907130084, 0.7888125999653604, 0.9736992223071643], 
             UndirectedEdge[122, 181] -> 
             RGBColor[
              0.5704448091170579, 0.6580973125412253, 0.9612231044087836], 
             UndirectedEdge[17, 42] -> 
             RGBColor[
              0.8118980393667572, 0.8526191992435992, 0.9216729340218592], 
             UndirectedEdge[90, 253] -> 
             RGBColor[
              0.5761720590135146, 0.6600448143046658, 0.9628912307567912], 
             UndirectedEdge[60, 136] -> 
             RGBColor[
              0.6621119545316024, 0.734902924779324, 0.9676837284079607], 
             UndirectedEdge[80, 210] -> 
             RGBColor[
              0.8221465371922883, 0.8611159787206126, 0.9828731527654712], 
             UndirectedEdge[229, 259] -> 
             RGBColor[
              0.5431036863033383, 0.6399550649401238, 0.9571742581216047], 
             UndirectedEdge[97, 159] -> 
             RGBColor[
              0.5842337054859043, 0.6733462673987796, 0.9604121638958809], 
             UndirectedEdge[242, 280] -> 
             RGBColor[
              0.7135835977163971, 0.7761035733460702, 0.9721366555005897], 
             UndirectedEdge[88, 99] -> 
             RGBColor[
              0.5072150735598739, 0.6108190723513998, 0.954348975062119], 
             UndirectedEdge[21, 46] -> 
             RGBColor[
              0.682531081148162, 0.7489107943605915, 0.9707315466464039], 
             UndirectedEdge[246, 256] -> 
             RGBColor[
              0.3870414986920395, 0.49861683147966784`, 0.9469483856571198], 
             UndirectedEdge[14, 135] -> 
             RGBColor[
              0.6262419127932732, 0.7057295444844311, 0.9648957775807867], 
             UndirectedEdge[67, 179] -> 
             RGBColor[
              0.8467983459319609, 0.8809899036872775, 0.9755012506879736], 
             UndirectedEdge[66, 69] -> 
             RGBColor[
              0.7095282234557119, 0.7716587375809799, 0.9729260525042936], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.6570656023561514, 0.7259536522014098, 0.9559706583217012], 
             UndirectedEdge[116, 133] -> 
             RGBColor[
              0.5236404019501433, 0.624153893891232, 0.9556420370809614], 
             UndirectedEdge[2, 83] -> 
             RGBColor[
              0.6669030649847014, 0.737763643068611, 0.9687643810896986], 
             UndirectedEdge[103, 168] -> 
             RGBColor[
              0.7021177755390449, 0.7663120678805793, 0.9715721320932191], 
             UndirectedEdge[26, 199] -> 
             RGBColor[
              0.5593279449565158, 0.6531266490092964, 0.9584514911942006], 
             UndirectedEdge[91, 239] -> 
             RGBColor[
              0.693657030382127, 0.7598041589965967, 0.970651463600057], 
             UndirectedEdge[13, 298] -> 
             RGBColor[
              0.7824666245449758, 0.8282815438061584, 0.9007989304333783], 
             UndirectedEdge[229, 261] -> 
             RGBColor[
              0.7032890205963755, 0.7668050885849449, 0.9721913123627557], 
             UndirectedEdge[141, 179] -> 
             RGBColor[
              0.763983651850853, 0.8153627589173722, 0.9678840481304446], 
             UndirectedEdge[59, 195] -> 
             RGBColor[
              0.7621478179546637, 0.8141149350149193, 0.9769274298835714], 
             UndirectedEdge[134, 253] -> 
             RGBColor[
              0.8153294386978726, 0.8558374218917832, 0.9821812124708991], 
             UndirectedEdge[42, 292] -> 
             RGBColor[
              0.7601173200331663, 0.8105812785937673, 0.9175965661168941], 
             UndirectedEdge[70, 238] -> 
             RGBColor[
              0.7302515304494721, 0.7891973127951001, 0.9737483060328076], 
             UndirectedEdge[178, 202] -> 
             RGBColor[
              0.9367241266629488, 0.9514316189124901, 0.9608623169130202], 
             UndirectedEdge[29, 191] -> 
             RGBColor[
              0.8285752516484222, 0.8639595618638797, 0.8404305716831495], 
             UndirectedEdge[17, 38] -> 
             RGBColor[
              0.8117569172205973, 0.8525608416094883, 0.924011693196136], 
             UndirectedEdge[40, 162] -> 
             RGBColor[
              0.7497946800079682, 0.8044645697636352, 0.9756961845396823], 
             UndirectedEdge[13, 95] -> 
             RGBColor[
              0.7059209396927153, 0.7653269164649379, 0.8949971637623606], 
             UndirectedEdge[206, 270] -> 
             RGBColor[
              0.4532441590524495, 0.564364091833964, 0.9508293396904322], 
             UndirectedEdge[16, 295] -> 
             RGBColor[
              0.9319358883028286, 0.9465093021615163, 0.9150761787471551], 
             UndirectedEdge[37, 124] -> 
             RGBColor[
              0.5866498279596665, 0.6715069081631233, 0.9625207864029464], 
             UndirectedEdge[22, 177] -> 
             RGBColor[
              0.6677771623323235, 0.7341394142710325, 0.9407153144798709], 
             UndirectedEdge[115, 204] -> 
             RGBColor[
              0.8451471258682878, 0.8787697542206103, 0.9296300139851712], 
             UndirectedEdge[192, 200] -> 
             RGBColor[
              0.3405073251098337, 0.4670239219820873, 0.943003048214001], 
             UndirectedEdge[13, 171] -> 
             RGBColor[
              0.9838303085199713, 0.9867610155238815, 0.8808972701763031], 
             UndirectedEdge[39, 52] -> 
             RGBColor[
              0.7870851780951862, 0.7762373346671161, 0.6219241567745029], 
             UndirectedEdge[92, 216] -> 
             RGBColor[
              0.8635165093516033, 0.8937351926528012, 0.9612189027553515], 
             UndirectedEdge[82, 127] -> 
             RGBColor[
              0.7827501877469991, 0.8276477903430626, 0.8647042170741608], 
             UndirectedEdge[53, 150] -> 
             RGBColor[
              0.931367356204523, 0.947178109108654, 0.9609696838787285], 
             UndirectedEdge[18, 66] -> 
             RGBColor[
              0.8999048944766586, 0.9230237518607989, 0.9903149262614084], 
             UndirectedEdge[31, 36] -> 
             RGBColor[
              0.8434654262415406, 0.878407116986303, 0.9762277951981594], 
             UndirectedEdge[71, 181] -> 
             RGBColor[
              0.68013668665959, 0.7492994347543929, 0.9692645888339558], 
             UndirectedEdge[43, 143] -> 
             RGBColor[
              0.8710613878678027, 0.89993234971386, 0.9773107723649357], 
             UndirectedEdge[75, 185] -> 
             RGBColor[
              0.7012951727482507, 0.7654315275761197, 0.9717522040473985], 
             UndirectedEdge[46, 145] -> 
             RGBColor[
              0.6276778871567438, 0.7013997147269185, 0.9672363496300458], 
             UndirectedEdge[62, 255] -> 
             RGBColor[
              0.7240069817435797, 0.7821861271615281, 0.9453780749287949], 
             UndirectedEdge[111, 242] -> 
             RGBColor[
              0.6896513074436073, 0.757407486292824, 0.9697513084661662], 
             UndirectedEdge[4, 193] -> 
             RGBColor[
              0.5609116720389926, 0.6491571171409858, 0.9609047694552597], 
             UndirectedEdge[18, 258] -> 
             RGBColor[
              0.789704754128625, 0.836168003705622, 0.979534627860424], 
             UndirectedEdge[81, 267] -> 
             RGBColor[
              0.6461249032688305, 0.7233910203518784, 0.9654221021553174], 
             UndirectedEdge[75, 124] -> 
             RGBColor[
              0.6217627130403636, 0.6991937362833482, 0.9659524764836203], 
             UndirectedEdge[72, 106] -> 
             RGBColor[
              0.9333598470901734, 0.9476820672817128, 0.9168333870443124], 
             UndirectedEdge[262, 271] -> 
             RGBColor[
              0.6773744447713983, 0.7466906863314142, 0.9692975326015508], 
             UndirectedEdge[17, 235] -> 
             RGBColor[
              0.6401367633512229, 0.7187263481233802, 0.9648161614507598], 
             UndirectedEdge[263, 279] -> 
             RGBColor[
              0.5841954750537359, 0.673315230211684, 0.9604091542562179], 
             UndirectedEdge[3, 252] -> 
             RGBColor[
              0.6705169973279616, 0.7403055837026953, 0.9694890293274951], 
             UndirectedEdge[48, 158] -> 
             RGBColor[
              0.8309356818646451, 0.8682010875559356, 0.9836910667271836], 
             UndirectedEdge[18, 36] -> 
             RGBColor[
              0.813334843530824, 0.854628009141951, 0.9818898543362947], 
             UndirectedEdge[105, 196] -> 
             RGBColor[
              0.4903166102793758, 0.5949239900829031, 0.9536199424488], 
             UndirectedEdge[269, 298] -> 
             RGBColor[
              0.6621860858837673, 0.735015599083831, 0.9676536758250784], 
             UndirectedEdge[85, 207] -> 
             RGBColor[
              0.9046797741155734, 0.9254363329054272, 0.9411496819168199], 
             UndirectedEdge[79, 103] -> 
             RGBColor[
              0.7460362839228682, 0.8013314943296879, 0.9757611186293835], 
             UndirectedEdge[76, 128] -> 
             RGBColor[
              0.43166859929643053`, 0.5448363400601568, 0.9495523137485762], 
             UndirectedEdge[10, 265] -> 
             RGBColor[
              0.9417204504407808, 0.9553983189651383, 0.9607413950592776], 
             UndirectedEdge[88, 198] -> 
             RGBColor[
              0.46118242680573585`, 0.5720398898462786, 0.9511140975128402], 
             UndirectedEdge[63, 143] -> 
             RGBColor[
              0.9332742827673112, 0.9493374141256343, 0.9832982477903124], 
             UndirectedEdge[49, 242] -> 
             RGBColor[0.7345169453750684, 0.7925492621101445, 0.974198576248],
              UndirectedEdge[252, 253] -> 
             RGBColor[
              0.6559888469763788, 0.7287212309684791, 0.9681033213775282], 
             UndirectedEdge[16, 125] -> 
             RGBColor[
              0.6601675848728856, 0.7257027666054479, 0.8922694894498366], 
             UndirectedEdge[59, 100] -> 
             RGBColor[
              0.6573241797164234, 0.7309406783589646, 0.9673583106079069], 
             UndirectedEdge[75, 295] -> 
             RGBColor[
              0.8635954159852213, 0.8940715593062645, 0.9868516957890411], 
             UndirectedEdge[94, 295] -> 
             RGBColor[
              0.6192392022139865, 0.6961900965128007, 0.9661682056047542], 
             UndirectedEdge[26, 192] -> 
             RGBColor[
              0.41064237562458616`, 0.5254796763434963, 0.9481051955133268], 
             UndirectedEdge[132, 188] -> 
             RGBColor[
              0.9655266195287546, 0.9738103898063006, 0.9432386204269203], 
             UndirectedEdge[186, 196] -> 
             RGBColor[
              0.5490383958966409, 0.6447731295435873, 0.9576414602003471], 
             UndirectedEdge[110, 179] -> 
             RGBColor[
              0.8472556644324607, 0.8813471643756172, 0.975546831922219], 
             UndirectedEdge[61, 177] -> 
             RGBColor[
              0.5986873368289165, 0.6799152320953057, 0.9641560981795015], 
             UndirectedEdge[21, 264] -> 
             RGBColor[
              0.49190397059874724`, 0.5977253285812174, 0.9533269561512983], 
             UndirectedEdge[200, 225] -> 
             RGBColor[
              0.2893825447523168, 0.4132885363280423, 0.9400915676049753], 
             UndirectedEdge[83, 197] -> 
             RGBColor[
              0.791228508752409, 0.836832991687554, 0.979825921367784], 
             UndirectedEdge[220, 226] -> 
             RGBColor[
              0.8885978189890191, 0.9108496476587618, 0.8464130602528774], 
             UndirectedEdge[13, 140] -> 
             RGBColor[
              0.6809537788248357, 0.743701616607173, 0.8934062783494529], 
             UndirectedEdge[144, 158] -> 
             RGBColor[
              0.7888603053092675, 0.834982933158759, 0.9795898809806912], 
             UndirectedEdge[62, 225] -> 
             RGBColor[
              0.5747998495508209, 0.6418857404544638, 0.936103969285928], 
             UndirectedEdge[65, 277] -> 
             RGBColor[
              0.8897086327003233, 0.9126012133900592, 0.8896192252189188], 
             UndirectedEdge[99, 261] -> 
             RGBColor[
              0.6895574052042421, 0.7556571446073872, 0.9711103092985225], 
             UndirectedEdge[260, 290] -> 
             RGBColor[
              0.8261980229472864, 0.8635302350787804, 0.907956021156664], 
             UndirectedEdge[72, 267] -> 
             RGBColor[
              0.7670151950949984, 0.8183905724281157, 0.9772869903858695], 
             UndirectedEdge[39, 170] -> 
             RGBColor[
              0.7340923429019186, 0.7332153637572014, 0.6177523666689373], 
             UndirectedEdge[92, 163] -> 
             RGBColor[
              0.9184221305956413, 0.9370533244387965, 0.9665784824220909], 
             UndirectedEdge[102, 133] -> 
             RGBColor[
              0.7813246250170307, 0.8270582835189296, 0.8883294807478213], 
             UndirectedEdge[184, 197] -> 
             RGBColor[
              0.7447726642396784, 0.8005413328767137, 0.9751956369413048], 
             UndirectedEdge[44, 200] -> 
             RGBColor[
              0.5499718446805376, 0.6430927900818914, 0.9587639111614279], 
             UndirectedEdge[115, 132] -> 
             RGBColor[
              0.9670762921005825, 0.9747297242644322, 0.9300285595223475], 
             UndirectedEdge[9, 283] -> 
             RGBColor[
              0.7628923130493758, 0.8125335884261462, 0.9052506660435651], 
             UndirectedEdge[52, 165] -> 
             RGBColor[
              0.7313445544707868, 0.7899057750826308, 0.9740270975185784], 
             UndirectedEdge[160, 256] -> 
             RGBColor[
              0.4124985124973013, 0.5192839821121822, 0.9489524550359842], 
             UndirectedEdge[45, 215] -> 
             RGBColor[
              0.6776379641664456, 0.7480951949368857, 0.9685042774474468], 
             UndirectedEdge[16, 124] -> 
             RGBColor[
              0.6901031853579709, 0.7516314791386001, 0.8941769594417341], 
             UndirectedEdge[160, 246] -> 
             RGBColor[
              0.5803728423814033, 0.670211844800645, 0.960108222609487], 
             UndirectedEdge[57, 204] -> 
             RGBColor[
              0.6440562505543719, 0.7209582373924945, 0.9657743248690505], 
             UndirectedEdge[112, 252] -> 
             RGBColor[
              0.39312748255062246`, 0.5144721256875084, 0.946396948923468], 
             UndirectedEdge[5, 248] -> 
             RGBColor[
              0.8860519547853325, 0.911977793778966, 0.9889936205069845], 
             UndirectedEdge[186, 276] -> 
             RGBColor[
              0.5290124567403757, 0.6285151699782531, 0.9560649449125336], 
             UndirectedEdge[95, 154] -> 
             RGBColor[
              0.5628370460878779, 0.654246817548731, 0.9595790838427476], 
             UndirectedEdge[198, 290] -> 
             RGBColor[
              0.5329386020504895, 0.6299570287109022, 0.9569939326333632], 
             UndirectedEdge[77, 191] -> 
             RGBColor[
              0.5711447420077354, 0.6624192349686604, 0.9595874265442793], 
             UndirectedEdge[36, 224] -> 
             RGBColor[
              0.8405079383865006, 0.8762014273864561, 0.9812340507003725], 
             UndirectedEdge[29, 203] -> 
             RGBColor[
              0.8165559418446521, 0.8545025669288997, 0.8392786937873613], 
             UndirectedEdge[25, 172] -> 
             RGBColor[
              0.7942655914391046, 0.8399939563642371, 0.9799194195392635], 
             UndirectedEdge[224, 260] -> 
             RGBColor[
              0.9636599194869528, 0.9717874841358884, 0.918153354678394], 
             UndirectedEdge[45, 255] -> 
             RGBColor[
              0.5819988731260486, 0.6708899390561003, 0.9606751622914089], 
             UndirectedEdge[102, 239] -> 
             RGBColor[
              0.7898431045958618, 0.8339739689941565, 0.8890000866644858], 
             UndirectedEdge[33, 239] -> 
             RGBColor[
              0.484917261821928, 0.5907270905738734, 0.9531433458369195], 
             UndirectedEdge[64, 92] -> 
             RGBColor[
              0.9088069780920554, 0.9293864628287989, 0.9656613805927509], 
             UndirectedEdge[32, 268] -> 
             RGBColor[
              0.7685934835711962, 0.8182198706257207, 0.9445004511954911], 
             UndirectedEdge[85, 240] -> 
             RGBColor[
              0.9858690955678482, 0.9884245221166954, 0.8838491862565528], 
             UndirectedEdge[1, 174] -> 
             RGBColor[
              0.758200186979023, 0.8110310156936422, 0.9765339669206284], 
             UndirectedEdge[2, 184] -> 
             RGBColor[
              0.6204472204719709, 0.7014719842577706, 0.9641340966632195], 
             UndirectedEdge[60, 85] -> 
             RGBColor[
              0.868108045616398, 0.8968304000237164, 0.9375140594941437], 
             UndirectedEdge[121, 127] -> 
             RGBColor[
              0.7827973896827871, 0.8255599990448145, 0.7107427305413011], 
             UndirectedEdge[132, 212] -> 
             RGBColor[
              0.7059387276699385, 0.7681696001388385, 0.9614457750806882], 
             UndirectedEdge[172, 206] -> 
             RGBColor[
              0.636825123415127, 0.7099765977695576, 0.9679542263214865], 
             UndirectedEdge[147, 148] -> 
             RGBColor[
              0.7455598601514617, 0.8011562963059092, 0.9752740972730274], 
             UndirectedEdge[118, 226] -> 
             RGBColor[
              0.7817658957162078, 0.8294407264651509, 0.978882776533482], 
             UndirectedEdge[75, 283] -> 
             RGBColor[
              0.9196951773773662, 0.9368827050709113, 0.9197192945496243], 
             UndirectedEdge[188, 243] -> 
             RGBColor[
              0.9070497466562679, 0.9275135909215941, 0.9491395261835436], 
             UndirectedEdge[88, 258] -> 
             RGBColor[
              0.6076597771998816, 0.6915670340283953, 0.9628016555822485], 
             UndirectedEdge[197, 293] -> 
             RGBColor[
              0.8328325043858171, 0.8699944079877124, 0.9837974595545856], 
             UndirectedEdge[86, 179] -> 
             RGBColor[
              0.8772828216479998, 0.9048046078072436, 0.9785396583337258], 
             UndirectedEdge[41, 76] -> 
             RGBColor[
              0.5697064201510208, 0.6540594960440163, 0.9624189838996451], 
             UndirectedEdge[175, 242] -> 
             RGBColor[
              0.7530962398724037, 0.8073638872208055, 0.9759706859430878], 
             UndirectedEdge[89, 285] -> 
             RGBColor[
              0.604016627442481, 0.6892058193881205, 0.9621070515849375], 
             UndirectedEdge[138, 171] -> 
             RGBColor[
              0.9139298103812314, 0.9330836809463217, 0.9527120367659193], 
             UndirectedEdge[181, 207] -> 
             RGBColor[
              0.7955725118022604, 0.8402623805084675, 0.9802493853028891], 
             UndirectedEdge[17, 55] -> 
             RGBColor[
              0.5842879789802904, 0.6733903290665153, 0.9604164365041694], 
             UndirectedEdge[142, 295] -> 
             RGBColor[
              0.8648777454522834, 0.8950940540153937, 0.9869740055183585], 
             UndirectedEdge[53, 200] -> 
             RGBColor[
              0.6846637281412746, 0.7486098597446535, 0.9395167848223638], 
             UndirectedEdge[33, 237] -> 
             RGBColor[
              0.6655911853512997, 0.7333380836835467, 0.9565139009312751], 
             UndirectedEdge[51, 67] -> 
             RGBColor[
              0.6092785003343764, 0.6920732054673286, 0.9634815083677032], 
             UndirectedEdge[47, 48] -> 
             RGBColor[
              0.7601243311479222, 0.8128827221898336, 0.9766332530574363], 
             UndirectedEdge[102, 237] -> 
             RGBColor[
              0.9705170281252335, 0.9765849621038298, 0.8923706417588413], 
             UndirectedEdge[150, 282] -> 
             RGBColor[
              0.857487531087836, 0.8892012976832082, 0.9862691202749552], 
             UndirectedEdge[214, 293] -> 
             RGBColor[
              0.9201263460903423, 0.9390728554868251, 0.9896456924252339], 
             UndirectedEdge[73, 245] -> 
             RGBColor[
              0.6242184069757728, 0.704837796127016, 0.9642230000171907], 
             UndirectedEdge[82, 192] -> 
             RGBColor[
              0.6381550089567573, 0.7033215809889987, 0.854679931920323], 
             UndirectedEdge[82, 266] -> 
             RGBColor[
              0.9577771539480476, 0.9662775230632136, 0.8811997291639803], 
             UndirectedEdge[30, 38] -> 
             RGBColor[
              0.9739037080133812, 0.9797749654332288, 0.9163831397497673], 
             UndirectedEdge[146, 242] -> 
             RGBColor[
              0.7904096625286666, 0.8369231372618509, 0.9728222821011312], 
             UndirectedEdge[25, 77] -> 
             RGBColor[
              0.5756504855955883, 0.6659391561044106, 0.9600365169565487], 
             UndirectedEdge[68, 271] -> 
             RGBColor[
              0.6910397032628501, 0.7573660901247475, 0.9706595578588776], 
             UndirectedEdge[23, 267] -> 
             RGBColor[
              0.7792200414864361, 0.8281223856489184, 0.9784510995300798], 
             UndirectedEdge[10, 161] -> 
             RGBColor[
              0.8219831767740684, 0.8615879795341352, 0.9826977500229263], 
             UndirectedEdge[223, 287] -> 
             RGBColor[
              0.4518800078938946, 0.5634706781945353, 0.9506628017164444], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.5759620661971274, 0.6666309779910471, 0.9597609901510553], 
             UndirectedEdge[218, 229] -> 
             RGBColor[
              0.5010346478515898, 0.6058015243364094, 0.9538624293107175], 
             UndirectedEdge[62, 170] -> 
             RGBColor[
              0.7420874341824835, 0.7968646529665303, 0.946801434375665], 
             UndirectedEdge[188, 294] -> 
             RGBColor[
              0.9504812463735971, 0.9621446898795385, 0.9532820613983399], 
             UndirectedEdge[181, 299] -> 
             RGBColor[
              0.8792079483881352, 0.9006566562490697, 0.6997944007745223], 
             UndirectedEdge[69, 109] -> 
             RGBColor[
              0.7457656349159366, 0.7987065842777065, 0.9071298509090916], 
             UndirectedEdge[48, 175] -> 
             RGBColor[
              0.8658408666203403, 0.8958620206915746, 0.9870658688751561], 
             UndirectedEdge[248, 270] -> 
             RGBColor[
              0.7010139036187684, 0.7652034463775208, 0.9717297556358186], 
             UndirectedEdge[85, 232] -> 
             RGBColor[
              0.623295770213118, 0.6901903336144035, 0.9186982406882855], 
             UndirectedEdge[65, 152] -> 
             RGBColor[
              0.803219893873643, 0.8446239900766933, 0.8812802240256745], 
             UndirectedEdge[43, 63] -> 
             RGBColor[
              0.8572286217067393, 0.8891966596276784, 0.9861908712953005], 
             UndirectedEdge[184, 293] -> 
             RGBColor[
              0.8135880360166274, 0.8549604830343247, 0.9818793507973267], 
             UndirectedEdge[24, 260] -> 
             RGBColor[
              0.6995012677886439, 0.759861208661849, 0.8980684376750568], 
             UndirectedEdge[201, 229] -> 
             RGBColor[
              0.7571870153396288, 0.8051244284702053, 0.7379112578890958], 
             UndirectedEdge[17, 48] -> 
             RGBColor[
              0.750362780570769, 0.8051843009714581, 0.97570996615471], 
             UndirectedEdge[153, 163] -> 
             RGBColor[
              0.6230607362163465, 0.6995987011357377, 0.9663663267667265], 
             UndirectedEdge[33, 200] -> 
             RGBColor[
              0.3887457766723182, 0.5111337856478735, 0.9459915150285352], 
             UndirectedEdge[33, 282] -> 
             RGBColor[
              0.6020801813676089, 0.6830943220817031, 0.9642616277710068], 
             UndirectedEdge[150, 237] -> 
             RGBColor[
              0.9209985350715268, 0.9394450592850518, 0.9785213934352236], 
             UndirectedEdge[172, 203] -> 
             RGBColor[
              0.7777405380474816, 0.8270170402935068, 0.978318451231206], 
             UndirectedEdge[56, 93] -> 
             RGBColor[
              0.7827598116624446, 0.830217181156392, 0.9789818407863303], 
             UndirectedEdge[122, 299] -> 
             RGBColor[
              0.6829235380070806, 0.7410600080696921, 0.6836334440095152], 
             UndirectedEdge[44, 100] -> 
             RGBColor[
              0.6304768311448802, 0.7099673256074686, 0.9646824178050324], 
             UndirectedEdge[31, 171] -> 
             RGBColor[
              0.9622500917372037, 0.9713667607441839, 0.9487849273227041], 
             UndirectedEdge[136, 256] -> 
             RGBColor[
              0.3960593653815424, 0.5059379419084711, 0.9476583051564516], 
             UndirectedEdge[146, 159] -> 
             RGBColor[
              0.7693585101255811, 0.8198328633974175, 0.9711650582710483], 
             UndirectedEdge[65, 133] -> 
             RGBColor[
              0.7818514863666197, 0.8272761542267038, 0.8795980247116657], 
             UndirectedEdge[58, 245] -> 
             RGBColor[
              0.7119810550612615, 0.7749242785610739, 0.9719272757934106], 
             UndirectedEdge[172, 272] -> 
             RGBColor[
              0.6283246956551809, 0.7026139544878143, 0.967412586581256], 
             UndirectedEdge[99, 218] -> 
             RGBColor[
              0.4873030324594564, 0.5946535803588517, 0.9527814262464842], 
             UndirectedEdge[18, 113] -> 
             RGBColor[
              0.7751848791003371, 0.824824966978386, 0.9780874224135511], 
             UndirectedEdge[43, 131] -> 
             RGBColor[
              0.8940674138643454, 0.9137411863947742, 0.73631908951834], 
             UndirectedEdge[2, 156] -> 
             RGBColor[
              0.35985732046825136`, 0.474775029726936, 0.9449696880146043], 
             UndirectedEdge[165, 232] -> 
             RGBColor[
              0.551230237208937, 0.6341220121324387, 0.9614452424438196], 
             UndirectedEdge[173, 186] -> 
             RGBColor[
              0.6765017372331636, 0.7452257858670599, 0.9698893607784573], 
             UndirectedEdge[39, 281] -> 
             RGBColor[
              0.8797242943271659, 0.8489214831872409, 0.6309430340191002], 
             UndirectedEdge[77, 91] -> 
             RGBColor[
              0.6389072628426329, 0.7153558312591152, 0.9663413613443415], 
             UndirectedEdge[15, 19] -> 
             RGBColor[
              0.6953055465827724, 0.7618972445991199, 0.9702652169497616], 
             UndirectedEdge[119, 241] -> 
             RGBColor[
              0.45416030294496695`, 0.5655975050146691, 0.9507661711628481], 
             UndirectedEdge[103, 116] -> 
             RGBColor[
              0.5282269024672888, 0.6278774216305444, 0.9560031032025761], 
             UndirectedEdge[99, 257] -> 
             RGBColor[
              0.42026315176003504`, 0.5373405693943074, 0.9483014923025805], 
             UndirectedEdge[17, 253] -> 
             RGBColor[
              0.739725776345896, 0.7967026425363324, 0.9746953991959758], 
             UndirectedEdge[204, 292] -> 
             RGBColor[
              0.6193679930518619, 0.700915197758631, 0.9638307748023858], 
             UndirectedEdge[65, 241] -> 
             RGBColor[
              0.7625538352081579, 0.8116094516669867, 0.8780788429228463], 
             UndirectedEdge[71, 256] -> 
             RGBColor[
              0.4063556613145025, 0.5142969387896941, 0.948468867288869], 
             UndirectedEdge[37, 102] -> 
             RGBColor[
              0.8856856434846625, 0.9096521410217537, 0.8980022199025568], 
             UndirectedEdge[61, 217] -> 
             RGBColor[
              0.7888166325535519, 0.8350387301003057, 0.979561667563377], 
             UndirectedEdge[35, 184] -> 
             RGBColor[
              0.7990004886198824, 0.8433287687085858, 0.9804879775041678], 
             UndirectedEdge[164, 241] -> 
             RGBColor[
              0.5901529687510347, 0.6780937840978365, 0.9609178102870075], 
             UndirectedEdge[192, 255] -> 
             RGBColor[
              0.3816475037256125, 0.5019403331318159, 0.9458226129857241], 
             UndirectedEdge[112, 134] -> 
             RGBColor[
              0.5524680742721161, 0.6415883166108125, 0.9604748400168389], 
             UndirectedEdge[44, 195] -> 
             RGBColor[
              0.7353004693831204, 0.7931415822634232, 0.9742515370806968], 
             UndirectedEdge[127, 281] -> 
             RGBColor[
              0.6899550863800055, 0.7566511877209214, 0.970460924936595], 
             UndirectedEdge[59, 192] -> 
             RGBColor[
              0.5198770200326177, 0.6124175529300966, 0.9578967437021846], 
             UndirectedEdge[108, 264] -> 
             RGBColor[
              0.6684054905862802, 0.739543356807888, 0.968499798235942], 
             UndirectedEdge[136, 296] -> 
             RGBColor[
              0.608353123196778, 0.6929061171583084, 0.9623255505053471], 
             UndirectedEdge[118, 130] -> 
             RGBColor[
              0.7681333759411456, 0.8187908984058845, 0.9775240143654442], 
             UndirectedEdge[85, 136] -> 
             RGBColor[
              0.7789476530399428, 0.8261143902701296, 0.9293543233154693], 
             UndirectedEdge[104, 157] -> 
             RGBColor[
              0.5783689079074404, 0.6663044607523749, 0.9611593067891905], 
             UndirectedEdge[158, 217] -> 
             RGBColor[
              0.7726444078872792, 0.8223149508473167, 0.9779736318718446], 
             UndirectedEdge[11, 174] -> 
             RGBColor[
              0.6842618757173655, 0.7528327641557526, 0.9694633215962983], 
             UndirectedEdge[39, 220] -> 
             RGBColor[
              0.9737239390980387, 0.9203057308862086, 0.49719431614188303`], 
             UndirectedEdge[32, 208] -> 
             RGBColor[
              0.6330941048212528, 0.7120960549072621, 0.9648857868296901], 
             UndirectedEdge[27, 103] -> 
             RGBColor[
              0.6099776703711992, 0.6942463778450637, 0.9624388231149019], 
             UndirectedEdge[212, 250] -> 
             RGBColor[
              0.7275491164818292, 0.7830295419397448, 0.8685717209773236], 
             UndirectedEdge[129, 298] -> 
             RGBColor[
              0.726429274421146, 0.7856583071505596, 0.973935976456435], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.9524156985286257, 0.9640322863915675, 0.9654319898042856], 
             UndirectedEdge[261, 290] -> 
             RGBColor[
              0.7749937790289009, 0.8246804849651006, 0.9780670997634743], 
             UndirectedEdge[24, 113] -> 
             RGBColor[
              0.538199322257705, 0.6344721097488517, 0.9573467017742916], 
             UndirectedEdge[15, 243] -> 
             RGBColor[
              0.7669114477211245, 0.8179300761245479, 0.9773773436671296], 
             UndirectedEdge[246, 296] -> 
             RGBColor[
              0.5993352565072751, 0.6855850067295051, 0.9616156310060153], 
             UndirectedEdge[131, 174] -> 
             RGBColor[
              0.8739081539367337, 0.8979926193232739, 0.7343098028877506], 
             UndirectedEdge[44, 121] -> 
             RGBColor[
              0.8476667304632493, 0.8773026577905546, 0.71647930833489], 
             UndirectedEdge[155, 293] -> 
             RGBColor[
              0.8766572334445486, 0.9044866979947424, 0.9880975435987338], 
             UndirectedEdge[105, 140] -> 
             RGBColor[
              0.37333642699205455`, 0.4977869814512635, 0.9450096448928618], 
             UndirectedEdge[51, 138] -> 
             RGBColor[
              0.659996943443533, 0.7319261782847718, 0.9684752583729084], 
             UndirectedEdge[133, 277] -> 
             RGBColor[
              0.6806126558045579, 0.7493528099502798, 0.9695297587668118], 
             UndirectedEdge[201, 261] -> 
             RGBColor[
              0.9394779301717687, 0.9499207582417246, 0.7546685444056946], 
             UndirectedEdge[19, 57] -> 
             RGBColor[
              0.6359026427758279, 0.7145885770261816, 0.964961649445482], 
             UndirectedEdge[104, 261] -> 
             RGBColor[
              0.8103356665755412, 0.8522898361248299, 0.9815896488254066], 
             UndirectedEdge[15, 111] -> 
             RGBColor[
              0.721961749419471, 0.7827212728497939, 0.9729220581321454], 
             UndirectedEdge[71, 85] -> 
             RGBColor[
              0.7892439489729031, 0.8344733871513526, 0.9301648854478866], 
             UndirectedEdge[84, 158] -> 
             RGBColor[
              0.7543398787582682, 0.8080153135721594, 0.976149207473815], 
             UndirectedEdge[65, 162] -> 
             RGBColor[
              0.8947076818058634, 0.9165065085454874, 0.8901174837149891], 
             UndirectedEdge[156, 268] -> 
             RGBColor[
              0.588793095568748, 0.6558374354566014, 0.9325671610865089], 
             UndirectedEdge[48, 252] -> 
             RGBColor[
              0.666625851201252, 0.7372028894036049, 0.9691178883362623], 
             UndirectedEdge[204, 235] -> 
             RGBColor[
              0.6736673219138434, 0.7449932990311541, 0.968108520935469], 
             UndirectedEdge[62, 130] -> 
             RGBColor[
              0.8615303767616584, 0.892111719642179, 0.9573818260742537], 
             UndirectedEdge[142, 283] -> 
             RGBColor[
              0.9209775068444283, 0.9379051997800405, 0.9198416042789417], 
             UndirectedEdge[99, 259] -> 
             RGBColor[
              0.5293720709112049, 0.6288071209625661, 0.9560932550573713], 
             UndirectedEdge[43, 244] -> 
             RGBColor[
              0.8898236008956664, 0.913852164707911, 0.9422815790292784], 
             UndirectedEdge[36, 154] -> 
             RGBColor[
              0.721961749419471, 0.7827212728497939, 0.9729220581321454], 
             UndirectedEdge[11, 185] -> 
             RGBColor[
              0.5823567867058563, 0.6718225001789093, 0.9602644059741355], 
             UndirectedEdge[20, 150] -> 
             RGBColor[
              0.666515079744443, 0.7366095612983368, 0.9694238914261677], 
             UndirectedEdge[175, 252] -> 
             RGBColor[
              0.6693593105028866, 0.7393824756529522, 0.9693786081246402], 
             UndirectedEdge[97, 292] -> 
             RGBColor[
              0.5535041385553989, 0.6483986206133812, 0.9579930198209988], 
             UndirectedEdge[176, 226] -> 
             RGBColor[
              0.7180978149699875, 0.7797027378908679, 0.9725369372567412], 
             UndirectedEdge[80, 103] -> 
             RGBColor[
              0.6951023258586274, 0.7608127689987132, 0.970877880277486], 
             UndirectedEdge[137, 220] -> 
             RGBColor[
              0.677154874418024, 0.7387737758412471, 0.8290109617425061], 
             UndirectedEdge[20, 167] -> 
             RGBColor[
              0.5665239376560354, 0.6579228830482315, 0.9596097224690243], 
             UndirectedEdge[240, 256] -> 
             RGBColor[
              0.6029808079094477, 0.6682480737550369, 0.9021531680975352], 
             UndirectedEdge[113, 278] -> 
             RGBColor[
              0.6898270353198481, 0.7576173899622957, 0.9697191701466719], 
             UndirectedEdge[181, 240] -> 
             RGBColor[
              0.8767618332545353, 0.9032505697197357, 0.9229488896426221], 
             UndirectedEdge[7, 151] -> 
             RGBColor[
              0.6345710673590436, 0.7121856037830263, 0.9657606407764153], 
             UndirectedEdge[6, 101] -> 
             RGBColor[
              0.942322203996217, 0.9558291155616718, 0.9590990510374486], 
             UndirectedEdge[65, 116] -> 
             RGBColor[
              0.7327363788459087, 0.7874022973310114, 0.8757315035330684], 
             UndirectedEdge[50, 264] -> 
             RGBColor[
              0.7298547199653045, 0.30593569386631403`, 0.4288469888499866], 
             UndirectedEdge[55, 235] -> 
             RGBColor[
              0.5868065885086808, 0.6754305096892066, 0.9606178147322875], 
             UndirectedEdge[100, 232] -> 
             RGBColor[
              0.4100536337797398, 0.5223801923254086, 0.9482974743691233], 
             UndirectedEdge[28, 163] -> 
             RGBColor[
              0.8892953376234294, 0.9145639792147828, 0.9893029772574842], 
             UndirectedEdge[11, 63] -> 
             RGBColor[
              0.7666340305444856, 0.8179863956390272, 0.9774600836522644], 
             UndirectedEdge[234, 274] -> 
             RGBColor[
              0.7713031605814162, 0.8212671582581195, 0.9778399488750649], 
             UndirectedEdge[148, 270] -> 
             RGBColor[
              0.6478415302801513, 0.7234087056143166, 0.9664979857685538], 
             UndirectedEdge[96, 245] -> 
             RGBColor[
              0.8306625423662285, 0.8682211357812164, 0.9656239547082427], 
             UndirectedEdge[159, 235] -> 
             RGBColor[
              0.6190856109481373, 0.7016360742589467, 0.9631589376206767], 
             UndirectedEdge[53, 287] -> 
             RGBColor[
              0.7558134979255573, 0.8078894089216493, 0.944698814539626], 
             UndirectedEdge[105, 289] -> 
             RGBColor[
              0.47537460256635405`, 0.5827933950916955, 0.9524436528672532], 
             UndirectedEdge[56, 164] -> 
             RGBColor[
              0.7070718807686451, 0.7710891942925757, 0.9714379751787647], 
             UndirectedEdge[112, 235] -> 
             RGBColor[
              0.47938302144853007`, 0.5844937178780529, 0.9531904049700337], 
             UndirectedEdge[7, 43] -> 
             RGBColor[
              0.6447450442434722, 0.7201335918502302, 0.9667746877110356], 
             UndirectedEdge[242, 243] -> 
             RGBColor[
              0.7346010057452609, 0.792616289567578, 0.9742065940011505], 
             UndirectedEdge[151, 286] -> 
             RGBColor[
              0.6528127885880609, 0.726995054856919, 0.9671966958931901], 
             UndirectedEdge[126, 163] -> 
             RGBColor[
              0.9210956893751243, 0.9390472601989843, 0.9620528447842326], 
             UndirectedEdge[31, 138] -> 
             RGBColor[
              0.8969261100627268, 0.9204023490897849, 0.9814948661298432], 
             UndirectedEdge[95, 138] -> 
             RGBColor[
              0.6360204415539754, 0.711649581887378, 0.9668119303519769], 
             UndirectedEdge[197, 275] -> 
             RGBColor[
              0.7660619401716653, 0.8171726770392717, 0.9773175530066103], 
             UndirectedEdge[198, 245] -> 
             RGBColor[
              0.5535700994495616, 0.6460745112842452, 0.9590502874817977], 
             UndirectedEdge[187, 264] -> 
             RGBColor[
              0.6897794294644172, 0.7562784140111098, 0.9706201818068312], 
             UndirectedEdge[62, 195] -> 
             RGBColor[
              0.8681954278303838, 0.8973185081933315, 0.9580461360763407], 
             UndirectedEdge[169, 187] -> 
             RGBColor[
              0.9086921456244326, 0.9249542300183267, 0.717784562817946], 
             UndirectedEdge[82, 199] -> 
             RGBColor[
              0.7868405782886869, 0.8309685536547987, 0.8650262276011967], 
             UndirectedEdge[126, 155] -> 
             RGBColor[
              0.9106186148546616, 0.9306931253689791, 0.961053532063476], 
             UndirectedEdge[82, 220] -> 
             RGBColor[
              0.9939494094270229, 0.9916554749760274, 0.7419078658739797], 
             UndirectedEdge[32, 202] -> 
             RGBColor[
              0.7324139511803787, 0.7903393157329499, 0.9746115513573815], 
             UndirectedEdge[113, 260] -> 
             RGBColor[
              0.8266864777343474, 0.8639118196708263, 0.9080047057649687], 
             UndirectedEdge[105, 230] -> 
             RGBColor[
              0.6257710935472844, 0.7017485660686936, 0.9666300452781025], 
             UndirectedEdge[245, 289] -> 
             RGBColor[
              0.641623850620733, 0.7189683193842953, 0.9655932202991628], 
             UndirectedEdge[108, 187] -> 
             RGBColor[
              0.8032587601547839, 0.8462686892200555, 0.9810150134928133], 
             UndirectedEdge[137, 228] -> 
             RGBColor[
              0.4747590880465363, 0.5819131165819932, 0.9525003516182212], 
             UndirectedEdge[88, 261] -> 
             RGBColor[
              0.7032376037841472, 0.7667633461004769, 0.9721872646429512], 
             UndirectedEdge[192, 228] -> 
             RGBColor[
              0.43696376598914854`, 0.5468485668065711, 0.9501773117812551], 
             UndirectedEdge[42, 97] -> 
             RGBColor[
              0.7795647434329147, 0.8263695730061232, 0.9191275385251816], 
             UndirectedEdge[121, 240] -> 
             RGBColor[
              0.9898168584528391, 0.9879497130107866, 0.6652453104672484], 
             UndirectedEdge[25, 43] -> 
             RGBColor[
              0.7330118822244396, 0.7913537205811552, 0.9740234321007823], 
             UndirectedEdge[77, 270] -> 
             RGBColor[
              0.5153270750303671, 0.617404760586648, 0.9549875815331168], 
             UndirectedEdge[225, 255] -> 
             RGBColor[
              0.33052272336809563`, 0.4482049474777709, 0.9429111323766983], 
             UndirectedEdge[2, 275] -> 
             RGBColor[
              0.6417364964039578, 0.7181033284203286, 0.9662560127285249], 
             UndirectedEdge[235, 253] -> 
             RGBColor[
              0.7422443858742865, 0.7987428231590235, 0.974896777424094], 
             UndirectedEdge[73, 95] -> 
             RGBColor[
              0.4831006254626557, 0.5904304850082214, 0.9526747874104069], 
             UndirectedEdge[49, 175] -> 
             RGBColor[
              0.8499950314246397, 0.8832269818302609, 0.9855544789684462], 
             UndirectedEdge[153, 219] -> 
             RGBColor[
              0.5531303209833602, 0.6445430860929123, 0.9595092160498515], 
             UndirectedEdge[54, 167] -> 
             RGBColor[
              0.6789503203685643, 0.7491204175762574, 0.9686350808490081], 
             UndirectedEdge[56, 246] -> 
             RGBColor[
              0.6614569298826466, 0.7341149301125497, 0.9678073388480284], 
             UndirectedEdge[192, 225] -> 
             RGBColor[
              0.23244037153285363`, 0.3616399464247515, 0.9365485073428572], 
             UndirectedEdge[84, 252] -> 
             RGBColor[
              0.590030048094875, 0.6770171154198286, 0.9615760290828936], 
             UndirectedEdge[119, 164] -> 
             RGBColor[
              0.510153064542071, 0.6109969434450152, 0.955213786767936], 
             UndirectedEdge[93, 168] -> 
             RGBColor[
              0.809914316354341, 0.8514492628757123, 0.9816833653954384], 
             UndirectedEdge[111, 250] -> 
             RGBColor[
              0.8667214210504133, 0.8944943490453259, 0.8805681593846872], 
             UndirectedEdge[54, 286] -> 
             RGBColor[
              0.5989919872979492, 0.6849498358358439, 0.9618323414045757], 
             UndirectedEdge[74, 257] -> 
             RGBColor[
              0.5414270555204332, 0.6342745276771051, 0.958819269058777], 
             UndirectedEdge[220, 236] -> 
             RGBColor[
              0.837629495838438, 0.8710328062399246, 0.8413330141272877], 
             UndirectedEdge[130, 228] -> 
             RGBColor[
              0.6725695128424694, 0.7433391603402414, 0.9685436879605549], 
             UndirectedEdge[1, 142] -> 
             RGBColor[
              0.8079855712538373, 0.850200840882831, 0.981422573710762], 
             UndirectedEdge[101, 114] -> 
             RGBColor[
              0.945211530197247, 0.9579839703115626, 0.954208175436068], 
             UndirectedEdge[199, 266] -> 
             RGBColor[
              0.7518728662135906, 0.8059782468188114, 0.9763260808764141], 
             UndirectedEdge[93, 277] -> 
             RGBColor[
              0.7929956971369994, 0.8382135326847252, 0.9800020581906457], 
             UndirectedEdge[19, 112] -> 
             RGBColor[
              0.5022413627042159, 0.6023508277968226, 0.9554687108030565], 
             UndirectedEdge[77, 203] -> 
             RGBColor[
              0.5591254322039653, 0.6529622400336803, 0.9584355486484911], 
             UndirectedEdge[26, 60] -> 
             RGBColor[
              0.6444959732334297, 0.7206014775705535, 0.9662969338307028], 
             UndirectedEdge[186, 263] -> 
             RGBColor[
              0.5561597126215315, 0.6505545352725159, 0.9582020763391732], 
             UndirectedEdge[167, 283] -> 
             RGBColor[
              0.8392807542330993, 0.8738059711109845, 0.9117723705217164], 
             UndirectedEdge[170, 200] -> 
             RGBColor[
              0.45667012938397933`, 0.5682674488401089, 0.9507890326947122], 
             UndirectedEdge[17, 292] -> 
             RGBColor[
              0.5858374344892414, 0.6746482468508571, 0.9605384153176766], 
             UndirectedEdge[106, 215] -> 
             RGBColor[
              0.8295988736319971, 0.8661500008058487, 0.9066170370742531], 
             UndirectedEdge[123, 229] -> 
             RGBColor[
              0.6093850840703077, 0.6929164321483628, 0.9629725410196623], 
             UndirectedEdge[105, 149] -> 
             RGBColor[
              0.4894358899257631, 0.5942089816238405, 0.9535506089163787], 
             UndirectedEdge[68, 274] -> 
             RGBColor[
              0.8131218067457322, 0.8539362024751656, 0.9820080407072566], 
             UndirectedEdge[149, 171] -> 
             RGBColor[
              0.792476725294281, 0.8374106938565893, 0.941052070155447], 
             UndirectedEdge[29, 172] -> 
             RGBColor[
              0.9563385490337314, 0.9645575934174608, 0.8529556133030414], 
             UndirectedEdge[76, 209] -> 
             RGBColor[
              0.6385637900104651, 0.7079653428156508, 0.9343454733956806], 
             UndirectedEdge[247, 267] -> 
             RGBColor[
              0.5605763140644663, 0.6539388217157509, 0.9586874038383421], 
             UndirectedEdge[164, 210] -> 
             RGBColor[
              0.7410813317603029, 0.7977872241187652, 0.9747933306854268], 
             UndirectedEdge[258, 260] -> 
             RGBColor[
              0.8412063527626353, 0.8752548563980622, 0.9094519112118415], 
             UndirectedEdge[62, 137] -> 
             RGBColor[
              0.6637199519657255, 0.7306856758839307, 0.94133848973192], 
             UndirectedEdge[175, 280] -> 
             RGBColor[
              0.8290616837659686, 0.8667812930661867, 0.9834925582210359], 
             UndirectedEdge[72, 194] -> 
             RGBColor[
              0.7553769385035978, 0.8091434210034993, 0.9762331477396189], 
             UndirectedEdge[3, 257] -> 
             RGBColor[
              0.6089405640561131, 0.6874280454853565, 0.9654391979783572], 
             UndirectedEdge[154, 171] -> 
             RGBColor[
              0.8407464149151339, 0.8756809166076748, 0.9454791902566901], 
             UndirectedEdge[168, 277] -> 
             RGBColor[
              0.805388421355603, 0.8479135993046223, 0.9812322664788575], 
             UndirectedEdge[146, 243] -> 
             RGBColor[
              0.8873925144510951, 0.91285325932874, 0.9824140928796401], 
             UndirectedEdge[98, 122] -> 
             RGBColor[
              0.33349778586075945`, 0.46180968818246315`, 0.9425250247916304],
              UndirectedEdge[142, 210] -> 
             RGBColor[
              0.8451424543370516, 0.8793576685803144, 0.9850916358338853], 
             UndirectedEdge[3, 38] -> 
             RGBColor[
              0.9283926900952435, 0.9441616693793479, 0.9354780171194371], 
             UndirectedEdge[21, 205] -> 
             RGBColor[
              0.6938280519140382, 0.75733605666069, 0.9516087218616368], 
             UndirectedEdge[153, 221] -> 
             RGBColor[
              0.5708037401999496, 0.6583496955078729, 0.9612707373098683], 
             UndirectedEdge[55, 159] -> 
             RGBColor[
              0.5632368265772048, 0.6563000552020819, 0.9587592126740864], 
             UndirectedEdge[149, 298] -> 
             RGBColor[
              0.5911130413192855, 0.6789312221388661, 0.9609537304125222], 
             UndirectedEdge[22, 247] -> 
             RGBColor[
              0.7174701396234404, 0.77684607050024, 0.9439742417640486], 
             UndirectedEdge[105, 298] -> 
             RGBColor[
              0.4748492727121948, 0.5823669086502488, 0.9524022969767871], 
             UndirectedEdge[169, 219] -> 
             RGBColor[
              0.862755750758614, 0.8890307955159484, 0.7132160231834062], 
             UndirectedEdge[53, 225] -> 
             RGBColor[
              0.5765967745642945, 0.6432258841873177, 0.93306224395122], 
             UndirectedEdge[47, 90] -> 
             RGBColor[
              0.48382598706760427`, 0.5877267604873979, 0.9537339016861833], 
             UndirectedEdge[100, 137] -> 
             RGBColor[
              0.45880763363156396`, 0.5689630072830865, 0.9512445946945718], 
             UndirectedEdge[15, 175] -> 
             RGBColor[
              0.7854066818482673, 0.8326776737777755, 0.9791414356090669], 
             UndirectedEdge[49, 253] -> 
             RGBColor[
              0.836624567898132, 0.8725657371457878, 0.9842791922213342], 
             UndirectedEdge[166, 291] -> 
             RGBColor[
              0.6717920258846226, 0.7389842796541362, 0.9609274336659548], 
             UndirectedEdge[161, 230] -> 
             RGBColor[
              0.8060666568584591, 0.848896578595852, 0.9811796181445304], 
             UndirectedEdge[263, 269] -> 
             RGBColor[
              0.6847747401758388, 0.753354086245414, 0.9694319374359174], 
             UndirectedEdge[122, 160] -> 
             RGBColor[
              0.48999512746133417`, 0.5946898298975036, 0.953587219816064], 
             UndirectedEdge[196, 289] -> 
             RGBColor[
              0.5925190915270575, 0.6800727170393754, 0.9610644198354096], 
             UndirectedEdge[30, 158] -> 
             RGBColor[
              0.8803378459094924, 0.9069170779089071, 0.9649673303487466], 
             UndirectedEdge[114, 187] -> 
             RGBColor[
              0.9027751470101262, 0.9241463502630878, 0.9501605553242738], 
             UndirectedEdge[49, 159] -> 
             RGBColor[
              0.7134657929719828, 0.775458988245711, 0.972541352417917], 
             UndirectedEdge[33, 94] -> 
             RGBColor[
              0.3715164720201911, 0.49621062792823195`, 0.9448936789713775], 
             UndirectedEdge[193, 220] -> 
             RGBColor[
              0.6670824326587708, 0.730049533045025, 0.828369154660317], 
             UndirectedEdge[60, 127] -> 
             RGBColor[
              0.6620139282894559, 0.7348233426599176, 0.9676760114230969], 
             UndirectedEdge[282, 297] -> 
             RGBColor[
              0.8678006637784441, 0.8974247097481698, 0.9872527960776276], 
             UndirectedEdge[97, 235] -> 
             RGBColor[
              0.6078034674173804, 0.6924767218859043, 0.962270765954082], 
             UndirectedEdge[50, 187] -> 
             RGBColor[
              0.8197568996776403, 0.37708591547442577`, 0.4371904656879009], 
             UndirectedEdge[271, 274] -> 
             RGBColor[
              0.6861940377292273, 0.7535806193814594, 0.9701765872038051], 
             UndirectedEdge[137, 170] -> 
             RGBColor[
              0.43752327822190384`, 0.5516834087122401, 0.9495690122695604], 
             UndirectedEdge[84, 253] -> 
             RGBColor[
              0.7758745999874557, 0.8250150020233251, 0.9782487228746755], 
             UndirectedEdge[33, 185] -> 
             RGBColor[
              0.4654645419721644, 0.5749344962647928, 0.9516119564726855], 
             UndirectedEdge[3, 144] -> 
             RGBColor[
              0.8249231768900378, 0.8635669743441412, 0.9830751043315187], 
             UndirectedEdge[11, 43] -> 
             RGBColor[
              0.7044211356449772, 0.7685813312272529, 0.9714726082268876], 
             UndirectedEdge[29, 272] -> 
             RGBColor[
              0.6671400994523514, 0.7300994811232071, 0.8283728291374113], 
             UndirectedEdge[70, 251] -> 
             RGBColor[
              0.7344032780288514, 0.7924406895585615, 0.974162113431233], 
             UndirectedEdge[99, 123] -> 
             RGBColor[
              0.5956534686781743, 0.681768488170805, 0.9618915379554289], 
             UndirectedEdge[133, 239] -> 
             RGBColor[
              0.5812739890496854, 0.6709434362621511, 0.9601791641762232], 
             UndirectedEdge[259, 260] -> 
             RGBColor[
              0.7765988450538637, 0.8236011448253229, 0.9038204660313931], 
             UndirectedEdge[125, 192] -> 
             RGBColor[
              0.30775803021670745`, 0.4386581287730831, 0.9409162921024755], 
             UndirectedEdge[213, 264] -> 
             RGBColor[
              0.7398082068589101, 0.7961700031104926, 0.9753919712559348], 
             UndirectedEdge[134, 204] -> 
             RGBColor[
              0.7467523747374294, 0.8020878977639136, 0.9753929559822742], 
             UndirectedEdge[94, 142] -> 
             RGBColor[
              0.6086294322633394, 0.687730153948688, 0.965156236275408], 
             UndirectedEdge[134, 175] -> 
             RGBColor[
              0.8286999022243803, 0.8664986665762564, 0.983456499218011], 
             UndirectedEdge[8, 267] -> 
             RGBColor[
              0.7118035766832292, 0.7747856311032696, 0.9719095864073182], 
             UndirectedEdge[195, 225] -> 
             RGBColor[
              0.4747111694548996, 0.5633373285095742, 0.9555791935242441], 
             UndirectedEdge[51, 281] -> 
             RGBColor[
              0.639271360734734, 0.7155038559662699, 0.9664709163931947], 
             UndirectedEdge[49, 243] -> 
             RGBColor[
              0.8314997972974969, 0.8684793841770335, 0.9837903870265089], 
             UndirectedEdge[212, 243] -> 
             RGBColor[
              0.6474618547974518, 0.7218728012541318, 0.9673466808373115], 
             UndirectedEdge[22, 285] -> 
             RGBColor[
              0.7609167951835251, 0.8121180227334451, 0.9473945216400818], 
             UndirectedEdge[20, 33] -> 
             RGBColor[
              0.4111077300242159, 0.5305025856968316, 0.9474163989222192], 
             UndirectedEdge[9, 174] -> 
             RGBColor[
              0.6463973974317694, 0.722092674908198, 0.966482491163502], 
             UndirectedEdge[180, 250] -> 
             RGBColor[
              0.8723465524193701, 0.8988887444233368, 0.8811288199097036], 
             UndirectedEdge[92, 221] -> 
             RGBColor[
              0.8661651345792443, 0.8958043188109317, 0.9614828929652326], 
             UndirectedEdge[71, 232] -> 
             RGBColor[
              0.4275959750612826, 0.5366218552512338, 0.9496784717345198], 
             UndirectedEdge[25, 148] -> 
             RGBColor[
              0.7081649408453725, 0.7719431011320792, 0.9715469211919858], 
             UndirectedEdge[76, 218] -> 
             RGBColor[
              0.3918769195615046, 0.5125316618566, 0.9464197669581171], 
             UndirectedEdge[20, 200] -> 
             RGBColor[
              0.4198114516811946, 0.5380413119343364, 0.947970992369803], 
             UndirectedEdge[68, 255] -> 
             RGBColor[
              0.6488486639201048, 0.7231135037016445, 0.9673381246909472], 
             UndirectedEdge[30, 123] -> 
             RGBColor[
              0.82984189889239, 0.867469260315735, 0.9599343662615359], 
             UndirectedEdge[113, 290] -> 
             RGBColor[
              0.6648960774163475, 0.738141136165783, 0.9672342852558987], 
             UndirectedEdge[230, 269] -> 
             RGBColor[
              0.8131079067188569, 0.8543972565022758, 0.9818814241263938], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.580750266068932, 0.6701403847619511, 0.9603962862878008], 
             UndirectedEdge[71, 296] -> 
             RGBColor[
              0.6186494191297383, 0.7012651140395313, 0.9631361126377644], 
             UndirectedEdge[37, 237] -> 
             RGBColor[
              0.8663089310466889, 0.8961482868746486, 0.9732224584253142], 
             UndirectedEdge[8, 217] -> 
             RGBColor[
              0.7573158035492181, 0.8103401286367156, 0.9764458198453785], 
             UndirectedEdge[39, 100] -> 
             RGBColor[
              0.7553766983115787, 0.7504949623280479, 0.6194279490939487], 
             UndirectedEdge[35, 216] -> 
             RGBColor[
              0.8176411393242284, 0.8578909867130134, 0.9823459033595922], 
             UndirectedEdge[48, 253] -> 
             RGBColor[
              0.8524704030938326, 0.8852007760071015, 0.9857905821280442], 
             UndirectedEdge[72, 247] -> 
             RGBColor[
              0.6720911035274687, 0.7415282281857694, 0.9696765817242321], 
             UndirectedEdge[24, 254] -> 
             RGBColor[
              0.6008255338042265, 0.6833961821858308, 0.9635886972660277], 
             UndirectedEdge[247, 273] -> 
             RGBColor[
              0.7272612618848293, 0.783371037638267, 0.8925942180160529], 
             UndirectedEdge[80, 152] -> 
             RGBColor[
              0.7118842328485051, 0.7744370771093905, 0.9721990134698801], 
             UndirectedEdge[121, 125] -> 
             RGBColor[
              0.6623950892188822, 0.7245165863850371, 0.7021747495380557], 
             UndirectedEdge[8, 177] -> 
             RGBColor[
              0.5671865078245828, 0.6552166306317155, 0.961040250461503], 
             UndirectedEdge[38, 253] -> 
             RGBColor[
              0.9138645397436609, 0.9325773166451317, 0.9340923091694702], 
             UndirectedEdge[134, 292] -> 
             RGBColor[
              0.6614410968412181, 0.733783026206308, 0.9680242285925997], 
             UndirectedEdge[19, 177] -> 
             RGBColor[
              0.5273191616528441, 0.6240719567993, 0.9570666459766362], 
             UndirectedEdge[219, 221] -> 
             RGBColor[
              0.7504333285178733, 0.8049634868334814, 0.97575983905464], 
             UndirectedEdge[37, 185] -> 
             RGBColor[
              0.6661822876675536, 0.7377446994558947, 0.9683205139667246], 
             UndirectedEdge[15, 280] -> 
             RGBColor[
              0.7458940396922609, 0.8014173599030401, 0.9753074051665689], 
             UndirectedEdge[140, 171] -> 
             RGBColor[
              0.6763772623605724, 0.7409886936840122, 0.93251110613193], 
             UndirectedEdge[211, 221] -> 
             RGBColor[
              0.6955142960398639, 0.7617625688270223, 0.9704895981104344], 
             UndirectedEdge[47, 273] -> 
             RGBColor[
              0.8230057781249305, 0.8608743038702846, 0.9002863989417478], 
             UndirectedEdge[58, 171] -> 
             RGBColor[
              0.8487726423754003, 0.8819510665012229, 0.9462791696005693], 
             UndirectedEdge[75, 150] -> 
             RGBColor[
              0.8712800355116529, 0.9001990663232009, 0.9875846616596129], 
             UndirectedEdge[9, 167] -> 
             RGBColor[
              0.6144860290952548, 0.6971632714283305, 0.9633018641964104], 
             UndirectedEdge[135, 260] -> 
             RGBColor[
              0.8713428151086471, 0.8987976898283636, 0.9124556321372395], 
             UndirectedEdge[184, 202] -> 
             RGBColor[
              0.81320346318165, 0.8546538350946653, 0.9818426698970143], 
             UndirectedEdge[166, 262] -> 
             RGBColor[
              0.5938281430816472, 0.6773353940410165, 0.9631428297167346], 
             UndirectedEdge[173, 276] -> 
             RGBColor[
              0.7148985014203366, 0.7763980087887213, 0.9729120947072532], 
             UndirectedEdge[67, 86] -> 
             RGBColor[
              0.7776534182044803, 0.8262280277770025, 0.9784728832084004], 
             UndirectedEdge[25, 272] -> 
             RGBColor[
              0.5050671418577246, 0.6055358440699833, 0.9553366353736334], 
             UndirectedEdge[7, 174] -> 
             RGBColor[
              0.6245857843158606, 0.7043850247787299, 0.9647654010804463], 
             UndirectedEdge[88, 113] -> 
             RGBColor[
              0.5931399021715937, 0.6802239973011592, 0.9613544501353757], 
             UndirectedEdge[147, 206] -> 
             RGBColor[
              0.5509624889237599, 0.6421116825255566, 0.9596054511949056], 
             UndirectedEdge[189, 211] -> 
             RGBColor[
              0.8047108609083399, 0.8467202040248891, 0.918426666804716], 
             UndirectedEdge[104, 209] -> 
             RGBColor[
              0.854768164279716, 0.8867199528353452, 0.9511864722109318], 
             UndirectedEdge[151, 167] -> 
             RGBColor[
              0.732771121658676, 0.7911656365973325, 0.9739994353376225], 
             UndirectedEdge[215, 274] -> 
             RGBColor[
              0.7396420894268789, 0.7965332888391418, 0.9746842691919125], 
             UndirectedEdge[41, 261] -> 
             RGBColor[
              0.8611550632732459, 0.892125688295345, 0.9866189327688442], 
             UndirectedEdge[157, 218] -> 
             RGBColor[
              0.4513588040156289, 0.5646124787354738, 0.9501893737911002], 
             UndirectedEdge[187, 205] -> 
             RGBColor[
              0.8917035107797081, 0.9158891420905824, 0.9689019475171698], 
             UndirectedEdge[62, 82] -> 
             RGBColor[
              0.9805144869747244, 0.9835673750187109, 0.8542353938633938], 
             UndirectedEdge[42, 144] -> 
             RGBColor[
              0.8825672895593164, 0.9078991783171917, 0.9286669312074352], 
             UndirectedEdge[33, 150] -> 
             RGBColor[
              0.6354494047355665, 0.7097020350118739, 0.9674444140848999], 
             UndirectedEdge[34, 46] -> 
             RGBColor[
              0.8749988575142189, 0.9032017834182078, 0.9874957559537101], 
             UndirectedEdge[220, 266] -> 
             RGBColor[
              0.9589816973519266, 0.96666516814004, 0.8532077191491971], 
             UndirectedEdge[128, 279] -> 
             RGBColor[
              0.5536708834132036, 0.6485339916007172, 0.9580061465870118], 
             UndirectedEdge[147, 270] -> 
             RGBColor[
              0.6480795463825163, 0.7235946456024733, 0.9665217089892506], 
             UndirectedEdge[30, 90] -> 
             RGBColor[
              0.636211227283235, 0.707242463092763, 0.9451820613370883], 
             UndirectedEdge[36, 222] -> 
             RGBColor[
              0.7180103725181345, 0.779634427182893, 0.9725282218103366], 
             UndirectedEdge[127, 170] -> 
             RGBColor[
              0.544323134954758, 0.6409450682908819, 0.957270257586432], 
             UndirectedEdge[1, 295] -> 
             RGBColor[
              0.8185953412044844, 0.8586607834469437, 0.9824345430401082], 
             UndirectedEdge[96, 140] -> 
             RGBColor[
              0.6645775999852317, 0.7321885248046569, 0.9524848566885511], 
             UndirectedEdge[206, 272] -> 
             RGBColor[
              0.34762667383374696`, 0.47551848547530384`, 0.9433714421558564],
              UndirectedEdge[129, 265] -> 
             RGBColor[
              0.9247849600055105, 0.9418944185936955, 0.9591260728630706], 
             UndirectedEdge[39, 60] -> 
             RGBColor[
              0.8517831362366165, 0.827093638126237, 0.6281581205056022], 
             UndirectedEdge[71, 240] -> 
             RGBColor[
              0.7901693004160129, 0.8348560437535258, 0.9148294173027871], 
             UndirectedEdge[30, 144] -> 
             RGBColor[
              0.8704341948081755, 0.8991802703980221, 0.9639802269618488], 
             UndirectedEdge[26, 59] -> 
             RGBColor[
              0.6469542437668333, 0.7225218971947964, 0.9665419512636282], 
             UndirectedEdge[133, 241] -> 
             RGBColor[
              0.5534578583123925, 0.6483610482272073, 0.9579893764707392], 
             UndirectedEdge[236, 266] -> 
             RGBColor[
              0.8014572403594626, 0.8456548543271107, 0.9806248774172881], 
             UndirectedEdge[28, 216] -> 
             RGBColor[
              0.8343897163793916, 0.8712458474287875, 0.9839433975907448], 
             UndirectedEdge[173, 230] -> 
             RGBColor[
              0.8703789238445105, 0.8994805443398461, 0.9874987128243691], 
             UndirectedEdge[39, 266] -> 
             RGBColor[
              0.9375516836190634, 0.8949277789733947, 0.6364861794318835], 
             UndirectedEdge[86, 141] -> 
             RGBColor[
              0.6948387241233724, 0.7606008830070974, 0.9708556806508715], 
             UndirectedEdge[25, 206] -> 
             RGBColor[
              0.5135675696176707, 0.6128984873517267, 0.955878275113864], 
             UndirectedEdge[141, 165] -> 
             RGBColor[
              0.7111761162213012, 0.7735321283339094, 0.9724393641801553], 
             UndirectedEdge[152, 241] -> 
             RGBColor[
              0.5748262658194156, 0.665708884077197, 0.9596715757847479], 
             UndirectedEdge[110, 141] -> 
             RGBColor[
              0.6648115669078334, 0.737143439575471, 0.9678628542393646], 
             UndirectedEdge[97, 134] -> 
             RGBColor[
              0.6808885202409665, 0.7495713206186639, 0.9695552010008872], 
             UndirectedEdge[103, 119] -> 
             RGBColor[
              0.4780444546205743, 0.5849877353136985, 0.9526464190732823], 
             UndirectedEdge[3, 17] -> 
             RGBColor[
              0.7542539266974786, 0.8082869952705486, 0.9760811071459428], 
             UndirectedEdge[203, 270] -> 
             RGBColor[
              0.5941595736848041, 0.6814045343579131, 0.9611935646001515], 
             UndirectedEdge[51, 141] -> 
             RGBColor[
              0.5264638062532685, 0.6264460606974235, 0.9558643058101742], 
             UndirectedEdge[184, 275] -> 
             RGBColor[
              0.7468174718024756, 0.8021387520858838, 0.9753994442493513], 
             UndirectedEdge[58, 109] -> 
             RGBColor[
              0.8527954392857966, 0.8844350121589164, 0.9163509078059362], 
             UndirectedEdge[179, 281] -> 
             RGBColor[
              0.8767912063323184, 0.9044205541862186, 0.9784906587134651], 
             UndirectedEdge[31, 154] -> 
             RGBColor[
              0.8237427145966294, 0.862999584751138, 0.974262019620614], 
             UndirectedEdge[122, 296] -> 
             RGBColor[
              0.5089575415872061, 0.6100629918263637, 0.9550946282125923], 
             UndirectedEdge[96, 290] -> 
             RGBColor[
              0.8100310449671564, 0.8521036532078735, 0.9635675998598082], 
             UndirectedEdge[122, 240] -> 
             RGBColor[
              0.6804774228734807, 0.7436539215403583, 0.9067879328776149], 
             UndirectedEdge[97, 144] -> 
             RGBColor[
              0.675954108081549, 0.7457165203368057, 0.9690633849115398], 
             UndirectedEdge[61, 247] -> 
             RGBColor[
              0.6483803141200333, 0.7226218883245134, 0.9674150254636793], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.7631436487669386, 0.8126375222043918, 0.9010853827675621], 
             UndirectedEdge[45, 287] -> 
             RGBColor[
              0.6120084642945525, 0.6952530770833675, 0.9630376272369482], 
             UndirectedEdge[278, 290] -> 
             RGBColor[
              0.6893385805327871, 0.7572358053702497, 0.9696704855383671], 
             UndirectedEdge[109, 110] -> 
             RGBColor[
              0.8676914826829709, 0.8960719144749119, 0.9178356062003266], 
             UndirectedEdge[56, 160] -> 
             RGBColor[
              0.6869139436879084, 0.754782080745064, 0.9698114082268928], 
             UndirectedEdge[146, 292] -> 
             RGBColor[
              0.7386289431950757, 0.794885216612019, 0.9687459141961661], 
             UndirectedEdge[131, 139] -> 
             RGBColor[
              0.6780549949732513, 0.7382584870098697, 0.71839260976428], 
             UndirectedEdge[47, 74] -> 
             RGBColor[
              0.6965019687389521, 0.7628318986806726, 0.9703844651290888], 
             UndirectedEdge[46, 221] -> 
             RGBColor[
              0.8521435643646027, 0.885347054703066, 0.9852177539274142], 
             UndirectedEdge[48, 74] -> 
             RGBColor[
              0.7994850449097355, 0.8436316109330664, 0.9805563611584308], 
             UndirectedEdge[90, 134] -> 
             RGBColor[
              0.5496680988424276, 0.6391631186244734, 0.9602964280583802], 
             UndirectedEdge[1, 37] -> 
             RGBColor[
              0.7715903567060781, 0.8214915180534768, 0.9778685739007708], 
             UndirectedEdge[33, 295] -> 
             RGBColor[
              0.6277647852091349, 0.7035745279949376, 0.966711448214328], 
             UndirectedEdge[28, 35] -> 
             RGBColor[
              0.8892213584244393, 0.9145049902096198, 0.9892959210554426], 
             UndirectedEdge[21, 169] -> 
             RGBColor[
              0.7108166867587626, 0.7664011445884343, 0.7004913371624129], 
             UndirectedEdge[100, 228] -> 
             RGBColor[
              0.5744109256729544, 0.6653716922354391, 0.9596388786869774], 
             UndirectedEdge[190, 250] -> 
             RGBColor[
              0.9428509999489181, 0.954565142752697, 0.8879974097656073], 
             UndirectedEdge[81, 180] -> 
             RGBColor[
              0.6948420623539805, 0.7614492352933201, 0.9702777732851893], 
             UndirectedEdge[127, 141] -> 
             RGBColor[
              0.57714753189854, 0.6675933924520752, 0.9598543143535745], 
             UndirectedEdge[143, 185] -> 
             RGBColor[
              0.748997038928682, 0.8031735186655165, 0.9661025701121835], 
             UndirectedEdge[283, 295] -> 
             RGBColor[
              0.9315872767950752, 0.9463651423441533, 0.9208535736082879], 
             UndirectedEdge[26, 100] -> 
             RGBColor[
              0.5480895353083919, 0.6440028017723642, 0.9575667624190491], 
             UndirectedEdge[242, 294] -> 
             RGBColor[
              0.7780325054625901, 0.8272473885255225, 0.9783491292159469], 
             UndirectedEdge[39, 228] -> 
             RGBColor[
              0.771328152726551, 0.7634450716269545, 0.6206837060175983], 
             UndirectedEdge[39, 82] -> 
             RGBColor[
              0.9725193956941597, 0.9199180858093821, 0.5251863261566662], 
             UndirectedEdge[109, 258] -> 
             RGBColor[
              0.8408618340682426, 0.8751123890642042, 0.9151614775637318], 
             UndirectedEdge[118, 199] -> 
             RGBColor[
              0.6812131984197546, 0.7499472775380143, 0.9695039338670182], 
             UndirectedEdge[57, 115] -> 
             RGBColor[
              0.7845241054745864, 0.8305079222968681, 0.9242048366621615], 
             UndirectedEdge[96, 222] -> 
             RGBColor[
              0.8249953756384567, 0.8637939020614187, 0.9650591044915025], 
             UndirectedEdge[6, 108] -> 
             RGBColor[
              0.8785118819309592, 0.9052564383099752, 0.9529310473547652], 
             UndirectedEdge[1, 9] -> 
             RGBColor[
              0.6499003774587848, 0.7248292295289367, 0.9668316354753854], 
             UndirectedEdge[180, 190] -> 
             RGBColor[
              0.8234391713318439, 0.8625939941703409, 0.9828777446156269], 
             UndirectedEdge[144, 253] -> 
             RGBColor[
              0.8103950265384552, 0.8519826216099249, 0.9816893963815517], 
             UndirectedEdge[53, 192] -> 
             RGBColor[
              0.6277215549218114, 0.6969612698413626, 0.9359737245602457], 
             UndirectedEdge[85, 121] -> 
             RGBColor[
              0.9888915070097293, 0.9875670564086134, 0.6805807786123479], 
             UndirectedEdge[36, 278] -> 
             RGBColor[
              0.727976999750335, 0.7874204321258607, 0.9735216020694155], 
             UndirectedEdge[122, 207] -> 
             RGBColor[
              0.5992881014212058, 0.68066573232909, 0.9640884285378819], 
             UndirectedEdge[226, 228] -> 
             RGBColor[
              0.6862020326175315, 0.7539889883995077, 0.9699024501285926], 
             UndirectedEdge[7, 143] -> 
             RGBColor[
              0.7207907053040441, 0.7802743463481862, 0.9638820642060475], 
             UndirectedEdge[133, 164] -> 
             RGBColor[
              0.6094506199094964, 0.6937604866575535, 0.9624369920758271], 
             UndirectedEdge[7, 131] -> 
             RGBColor[
              0.7437967313005868, 0.7940831830291003, 0.7228903813594518], 
             UndirectedEdge[111, 280] -> 
             RGBColor[
              0.7656167513371721, 0.8168248921382051, 0.9772731807441143], 
             UndirectedEdge[135, 224] -> 
             RGBColor[
              0.8470143113303134, 0.8812842553804284, 0.9818825451498996], 
             UndirectedEdge[91, 102] -> 
             RGBColor[
              0.8937076663494723, 0.9159190062533751, 0.8988017801716552], 
             UndirectedEdge[200, 282] -> 
             RGBColor[
              0.6107839030245876, 0.6906330483192078, 0.9648162212185906], 
             UndirectedEdge[106, 194] -> 
             RGBColor[
              0.8102068010357704, 0.8508455093870777, 0.9047903665121717], 
             UndirectedEdge[38, 259] -> 
             RGBColor[
              0.7755524737304016, 0.8231684433925548, 0.9211615467833414], 
             UndirectedEdge[36, 69] -> 
             RGBColor[
              0.6229581725098774, 0.7032629948621321, 0.96450098057918], 
             UndirectedEdge[64, 153] -> 
             RGBColor[
              0.6134455837127606, 0.6919318395257401, 0.9654492249373865], 
             UndirectedEdge[159, 175] -> 
             RGBColor[
              0.7320450874693181, 0.790273613356372, 0.9743134621130047], 
             UndirectedEdge[94, 200] -> 
             RGBColor[
              0.38022019367716975`, 0.5037493541657366, 0.9454482724189615], 
             UndirectedEdge[88, 201] -> 
             RGBColor[
              0.7571355985274005, 0.8050826859857373, 0.7379072101692913], 
             UndirectedEdge[121, 232] -> 
             RGBColor[
              0.6272435330981088, 0.6897155245084947, 0.700094364898981], 
             UndirectedEdge[140, 289] -> 
             RGBColor[
              0.4755389082397362, 0.5829357084077358, 0.9524541222794713], 
             UndirectedEdge[139, 244] -> 
             RGBColor[
              0.6738111820045722, 0.7383694653230066, 0.9243550992752183], 
             UndirectedEdge[167, 174] -> 
             RGBColor[
              0.7227858386154931, 0.7833650575930361, 0.9730041956416534], 
             UndirectedEdge[185, 282] -> 
             RGBColor[
              0.6875026683244339, 0.7544337589361271, 0.9704366626627408], 
             UndirectedEdge[236, 249] -> 
             RGBColor[
              0.7863822326334143, 0.8336344523665435, 0.9791870097227593], 
             UndirectedEdge[137, 299] -> 
             RGBColor[
              0.6754212366416519, 0.7345618917035884, 0.6831554040005348], 
             UndirectedEdge[201, 218] -> 
             RGBColor[
              0.737223557426983, 0.7889171939931892, 0.7363396613536565], 
             UndirectedEdge[36, 109] -> 
             RGBColor[
              0.8644919234704416, 0.8935723945005332, 0.9175167040396024], 
             UndirectedEdge[4, 52] -> 
             RGBColor[
              0.7023444312082712, 0.7670823079297222, 0.9711813112867591], 
             UndirectedEdge[5, 191] -> 
             RGBColor[
              0.7912169346551383, 0.8376358766943384, 0.9796093073671056], 
             UndirectedEdge[55, 134] -> 
             RGBColor[
              0.6598916413322669, 0.7325251084219662, 0.9679022497790926], 
             UndirectedEdge[67, 69] -> 
             RGBColor[
              0.625700413221907, 0.7054052541481709, 0.9647743015056586], 
             UndirectedEdge[232, 256] -> 
             RGBColor[
              0.24040748255471753`, 0.3700138852527449, 0.9370022225292678], 
             UndirectedEdge[185, 237] -> 
             RGBColor[
              0.7510136723081247, 0.8046775205379707, 0.9626889358230091], 
             UndirectedEdge[28, 211] -> 
             RGBColor[
              0.7644458899124338, 0.8163074461654983, 0.9771756255964037], 
             UndirectedEdge[85, 246] -> 
             RGBColor[
              0.76992978635044, 0.8187932798413264, 0.9286444038161374], 
             UndirectedEdge[26, 127] -> 
             RGBColor[
              0.555237554414828, 0.6498058856975603, 0.9581294806671645], 
             UndirectedEdge[91, 162] -> 
             RGBColor[
              0.7979947462425394, 0.8421188278401535, 0.9805003166867159], 
             UndirectedEdge[112, 242] -> 
             RGBColor[
              0.4768644119201395, 0.5824535372553616, 0.9529890267419157], 
             UndirectedEdge[85, 122] -> 
             RGBColor[
              0.6795520714303709, 0.743271264938185, 0.9221234010227144], 
             UndirectedEdge[63, 131] -> 
             RGBColor[
              0.9562803087638538, 0.9631462508065485, 0.7423065649437167], 
             UndirectedEdge[140, 222] -> 
             RGBColor[
              0.5339185083186617, 0.6295346720240655, 0.9575943621080312], 
             UndirectedEdge[121, 256] -> 
             RGBColor[
              0.6060032193513287, 0.6673906080469548, 0.6988847604533303], 
             UndirectedEdge[171, 198] -> 
             RGBColor[
              0.6903616867637004, 0.7531012992243942, 0.9334021812889564], 
             UndirectedEdge[10, 117] -> 
             RGBColor[
              0.7877606045417136, 0.8348530460050374, 0.9792867638509256], 
             UndirectedEdge[18, 290] -> 
             RGBColor[
              0.774696424313276, 0.8244433823863401, 0.9780387378052463], 
             UndirectedEdge[207, 240] -> 
             RGBColor[
              0.9056051255586832, 0.9258189895076004, 0.9258142137717205], 
             UndirectedEdge[219, 264] -> 
             RGBColor[
              0.6438430345985986, 0.7203549795087315, 0.9660516421722916], 
             UndirectedEdge[78, 118] -> 
             RGBColor[
              0.8530495905950142, 0.8859737362113382, 0.9857632607323639], 
             UndirectedEdge[2, 208] -> 
             RGBColor[
              0.6088026414240064, 0.6923751506034221, 0.9629734738484965], 
             UndirectedEdge[34, 169] -> 
             RGBColor[
              0.9032844631248196, 0.9206921336460506, 0.717255546469719], 
             UndirectedEdge[35, 275] -> 
             RGBColor[
              0.8202897645518693, 0.8599601128711438, 0.9826098935694734], 
             UndirectedEdge[157, 284] -> 
             RGBColor[
              0.4026319344697829, 0.523161277593453, 0.9468763287243425], 
             UndirectedEdge[30, 259] -> 
             RGBColor[
              0.7635605011254207, 0.814507893107496, 0.9541360833634783], 
             UndirectedEdge[62, 192] -> 
             RGBColor[
              0.6259246299083377, 0.6956211261085087, 0.9390154498949539], 
             UndirectedEdge[95, 245] -> 
             RGBColor[
              0.5645528359143133, 0.6555872056016281, 0.9597500977376792], 
             UndirectedEdge[129, 230] -> 
             RGBColor[
              0.8773510952562357, 0.9050399645690044, 0.9881637247577503], 
             UndirectedEdge[35, 92] -> 
             RGBColor[
              0.918348151396651, 0.9369943354336336, 0.9665714262200491], 
             UndirectedEdge[186, 279] -> 
             RGBColor[
              0.5186514549854071, 0.6201036419957596, 0.9552492889007825], 
             UndirectedEdge[217, 233] -> 
             RGBColor[
              0.8544623149302113, 0.886694275971371, 0.9619509198009373], 
             UndirectedEdge[28, 293] -> 
             RGBColor[
              0.9038089058211843, 0.9261367045353588, 0.9906872943486014], 
             UndirectedEdge[24, 233] -> 
             RGBColor[
              0.6867069414042252, 0.7509499448288135, 0.9479709969550771], 
             UndirectedEdge[41, 229] -> 
             RGBColor[
              0.678864148441106, 0.7473293585238256, 0.9698616462522454], 
             UndirectedEdge[197, 214] -> 
             RGBColor[
              0.8513109743133933, 0.884653705329214, 0.9829619785692121], 
             UndirectedEdge[84, 144] -> 
             RGBColor[
              0.7444362276569513, 0.8002785060612745, 0.9751621040869172], 
             UndirectedEdge[101, 205] -> 
             RGBColor[
              0.934139893966829, 0.9497267621390573, 0.9729495676289639], 
             UndirectedEdge[7, 297] -> 
             RGBColor[
              0.7029786907583617, 0.7663657116139293, 0.9723826188731703], 
             UndirectedEdge[30, 47] -> 
             RGBColor[
              0.8095264951927696, 0.851598712542805, 0.9579095166789993], 
             UndirectedEdge[140, 298] -> 
             RGBColor[
              0.47501357838557695`, 0.5825092219662891, 0.9524127663890052], 
             UndirectedEdge[159, 252] -> 
             RGBColor[
              0.5328300720502297, 0.6316144820684023, 0.9563654815741109], 
             UndirectedEdge[26, 195] -> 
             RGBColor[
              0.6529131735466321, 0.727177058428319, 0.9671358816947137], 
             UndirectedEdge[43, 185] -> 
             RGBColor[
              0.6729513778681101, 0.7430327641675605, 0.9689951936171717], 
             UndirectedEdge[36, 95] -> 
             RGBColor[
              0.5825597577327892, 0.669654349783896, 0.9615448594202931], 
             UndirectedEdge[6, 46] -> 
             RGBColor[
              0.955659661790007, 0.9664516288804034, 0.959940806163889], 
             UndirectedEdge[148, 183] -> 
             RGBColor[
              0.6288379457980254, 0.707980739630002, 0.9650019539856972], 
             UndirectedEdge[222, 261] -> 
             RGBColor[
              0.7899581097002011, 0.8363707338186457, 0.9795586043951685], 
             UndirectedEdge[64, 145] -> 
             RGBColor[
              0.5862829140394147, 0.6684049002901616, 0.9637184436448066], 
             UndirectedEdge[8, 247] -> 
             RGBColor[
              0.6168794851156996, 0.6979232868609232, 0.9642991777456807], 
             UndirectedEdge[122, 136] -> 
             RGBColor[
              0.4735559803455753, 0.5813437896937925, 0.9522930699365313], 
             UndirectedEdge[139, 206] -> 
             RGBColor[
              0.35955899530936786`, 0.4858536626015712, 0.9441317591289453], 
             UndirectedEdge[65, 80] -> 
             RGBColor[
              0.8996118022372472, 0.9203376446991802, 0.8906062806079784], 
             UndirectedEdge[171, 245] -> 
             RGBColor[
              0.8424622047415693, 0.8770213046605717, 0.9456502041516216], 
             UndirectedEdge[137, 232] -> 
             RGBColor[
              0.31040179615332175`, 0.4389216166719626, 0.9411589473003671], 
             UndirectedEdge[64, 221] -> 
             RGBColor[
              0.8107485912472736, 0.8523522402663092, 0.981699847942175], 
             UndirectedEdge[140, 263] -> 
             RGBColor[
              0.4976022326776485, 0.6008477091278721, 0.9541910279998442], 
             UndirectedEdge[200, 295] -> 
             RGBColor[
              0.6364685068661136, 0.7111132542324423, 0.9672660416619119], 
             UndirectedEdge[136, 232] -> 
             RGBColor[
              0.41729967912832244`, 0.528262858370011, 0.9488679096021024], 
             UndirectedEdge[45, 68] -> 
             RGBColor[
              0.7511176814852989, 0.8054981085729095, 0.9758280489627909], 
             UndirectedEdge[224, 254] -> 
             RGBColor[
              0.8649841855025353, 0.8953224576598703, 0.9836736142693648], 
             UndirectedEdge[148, 272] -> 
             RGBColor[
              0.5422240450614488, 0.6345630992556563, 0.9590400882339782], 
             UndirectedEdge[167, 185] -> 
             RGBColor[
              0.6208807496039839, 0.7023547936161927, 0.9638052800194906], 
             UndirectedEdge[59, 137] -> 
             RGBColor[
              0.5576723420900054, 0.6474821027055186, 0.9602197835391507], 
             UndirectedEdge[55, 97] -> 
             RGBColor[
              0.5519546830464478, 0.6471407028290395, 0.9578710410074917], 
             UndirectedEdge[156, 202] -> 
             RGBColor[
              0.5526135631779305, 0.6279568805638307, 0.9626782612483993], 
             UndirectedEdge[78, 176] -> 
             RGBColor[
              0.7893815098487937, 0.8362357476370552, 0.979417421455623], 
             UndirectedEdge[131, 143] -> 
             RGBColor[
              0.9701130749249172, 0.9738819408927302, 0.7334264660133519], 
             UndirectedEdge[230, 289] -> 
             RGBColor[
              0.7279735747949662, 0.786897293025166, 0.9740745226647121], 
             UndirectedEdge[35, 126] -> 
             RGBColor[
              0.9210217101761342, 0.9389882711938214, 0.9620457885821909], 
             UndirectedEdge[147, 183] -> 
             RGBColor[
              0.6290759619003904, 0.7081666796181587, 0.9650256772063941], 
             UndirectedEdge[66, 258] -> 
             RGBColor[
              0.8046244226080178, 0.8480645423674776, 0.9809576791589338], 
             UndirectedEdge[60, 232] -> 
             RGBColor[
              0.5064600717047776, 0.5989788681235978, 0.9570276457807769], 
             UndirectedEdge[39, 127] -> 
             RGBColor[
              0.7625247174180149, 0.7562980462532438, 0.6199906673420641], 
             UndirectedEdge[113, 258] -> 
             RGBColor[
              0.6799044072316964, 0.7498657574850649, 0.9687301753110764], 
             UndirectedEdge[45, 223] -> 
             RGBColor[
              0.524139434290585, 0.621492145038533, 0.9567902610427489], 
             UndirectedEdge[40, 80] -> 
             RGBColor[
              0.7546988004393522, 0.808295705917328, 0.9761849814326715], 
             UndirectedEdge[18, 198] -> 
             RGBColor[
              0.6432274037344792, 0.7166408595235054, 0.9678470697910155], 
             UndirectedEdge[13, 58] -> 
             RGBColor[
              0.8533491588396636, 0.8846639894243837, 0.9071743418180922], 
             UndirectedEdge[16, 195] -> 
             RGBColor[
              0.8782455044685946, 0.904117351995984, 0.9098438714806312], 
             UndirectedEdge[17, 90] -> 
             RGBColor[
              0.474064436490451, 0.5800283392690225, 0.952810614783457], 
             UndirectedEdge[8, 273] -> 
             RGBColor[
              0.8784885245035923, 0.9042178470257856, 0.905816400585029], 
             UndirectedEdge[85, 256] -> 
             RGBColor[
              0.602055456466338, 0.6678654171528635, 0.9174886362426347], 
             UndirectedEdge[149, 227] -> 
             RGBColor[
              0.6507282599113615, 0.7265115550954402, 0.9662061210670514], 
             UndirectedEdge[182, 208] -> 
             RGBColor[
              0.7504953237851724, 0.8050119180074768, 0.9757660181635057], 
             UndirectedEdge[82, 100] -> 
             RGBColor[
              0.775602168640563, 0.8218447064178667, 0.8641414988260454], 
             UndirectedEdge[227, 264] -> 
             RGBColor[
              0.6253415105928912, 0.7059014483386824, 0.9642075831659745], 
             UndirectedEdge[74, 259] -> 
             RGBColor[
              0.6505359746716031, 0.7257410792453638, 0.9666110318135679], 
             UndirectedEdge[96, 105] -> 
             RGBColor[
              0.6644132943118495, 0.7320462114886166, 0.952474387276333], 
             UndirectedEdge[60, 100] -> 
             RGBColor[
              0.6548659091830198, 0.7290202587347216, 0.9671132931749815], 
             UndirectedEdge[73, 87] -> 
             RGBColor[
              0.6967612299041007, 0.7617575214927523, 0.9713873878163392], 
             UndirectedEdge[68, 223] -> 
             RGBColor[
              0.590989225084641, 0.6737157096840773, 0.963453223442287], 
             UndirectedEdge[162, 191] -> 
             RGBColor[
              0.730232225407642, 0.7891822315496986, 0.9737463818866539], 
             UndirectedEdge[87, 149] -> 
             RGBColor[
              0.72822796090847, 0.7873036312821766, 0.9738645641474368], 
             UndirectedEdge[60, 256] -> 
             RGBColor[
              0.48521975795799754`, 0.5766539516620579, 0.955818041335126], 
             UndirectedEdge[145, 169] -> 
             RGBColor[
              0.6559634927673444, 0.7188900649547614, 0.6969961401460546], 
             UndirectedEdge[144, 235] -> 
             RGBColor[
              0.7108060135437821, 0.7740063271969728, 0.9718101586363357], 
             UndirectedEdge[36, 88] -> 
             RGBColor[
              0.6312898666020806, 0.7100270394647242, 0.9651568820581193], 
             UndirectedEdge[38, 123] -> 
             RGBColor[
              0.841833871497371, 0.8761298106007939, 0.926959829681399], 
             UndirectedEdge[183, 244] -> 
             RGBColor[
              0.7484927612655279, 0.8014519285710847, 0.9295566480538484], 
             UndirectedEdge[2, 32] -> 
             RGBColor[
              0.5396577084706995, 0.6371574648960554, 0.9569029781235867], 
             UndirectedEdge[106, 151] -> 
             RGBColor[
              0.8814287413303598, 0.9066398873733936, 0.9117829539087743], 
             UndirectedEdge[164, 277] -> 
             RGBColor[
              0.7173077662432001, 0.7790855458209089, 0.9724581925830802], 
             UndirectedEdge[296, 299] -> 
             RGBColor[
              0.8177206808582833, 0.852622335534208, 0.693665924578331], 
             UndirectedEdge[75, 174] -> 
             RGBColor[
              0.8032002617597598, 0.846441791552963, 0.9809511196695613], 
             UndirectedEdge[31, 66] -> 
             RGBColor[
              0.9300354771873753, 0.9468028597051508, 0.984652867123273], 
             UndirectedEdge[2, 268] -> 
             RGBColor[
              0.7443020201739496, 0.7984989663218808, 0.9425881382142975], 
             UndirectedEdge[46, 264] -> 
             RGBColor[
              0.745553270445328, 0.8007385473783162, 0.9755095570450657], 
             UndirectedEdge[71, 160] -> 
             RGBColor[
              0.5996870050038663, 0.6858919521106712, 0.9616287042412361], 
             UndirectedEdge[50, 114] -> 
             RGBColor[
              0.8718518649957772, 0.4178476513676327, 0.41520723786161506`], 
             UndirectedEdge[126, 197] -> 
             RGBColor[
              0.8667938857959303, 0.8962008353619493, 0.9567534480193278], 
             UndirectedEdge[265, 269] -> 
             RGBColor[
              0.8605417714681318, 0.8912517105269668, 0.9528437722317141], 
             UndirectedEdge[144, 257] -> 
             RGBColor[
              0.562974041374026, 0.6511071967890895, 0.9609668712406321], 
             UndirectedEdge[86, 107] -> 
             RGBColor[
              0.8832707708011451, 0.9092704104812925, 0.9684036223247123], 
             UndirectedEdge[149, 245] -> 
             RGBColor[
              0.655685137980142, 0.7303839059164403, 0.9667001763482883], 
             UndirectedEdge[143, 283] -> 
             RGBColor[
              0.9673970435577974, 0.974624696160308, 0.9140696606144094], 
             UndirectedEdge[66, 154] -> 
             RGBColor[
              0.8085318003653055, 0.8511170155686416, 0.981347130057259], 
             UndirectedEdge[57, 159] -> 
             RGBColor[
              0.5894745395886658, 0.6776010126202872, 0.9608247415542581], 
             UndirectedEdge[7, 167] -> 
             RGBColor[
              0.592674415979346, 0.6794556212988625, 0.9615847741133545], 
             UndirectedEdge[57, 89] -> 
             RGBColor[
              0.6194604757142632, 0.7017438311525894, 0.9633228478935725], 
             UndirectedEdge[122, 256] -> 
             RGBColor[
              0.29666378377197034`, 0.4230948165765264, 0.9404273828636968], 
             UndirectedEdge[39, 232] -> 
             RGBColor[
              0.6069708608333365, 0.6204535717169241, 0.6093423016997441], 
             UndirectedEdge[72, 286] -> 
             RGBColor[
              0.7047438943478745, 0.768037234765238, 0.9722471290287283], 
             UndirectedEdge[71, 299] -> 
             RGBColor[
              0.7926154155496128, 0.8322621302828597, 0.6916749284346875], 
             UndirectedEdge[90, 158] -> 
             RGBColor[0.554637337784327, 0.6430451258535, 0.9607917153559307],
              UndirectedEdge[52, 236] -> 
             RGBColor[
              0.6509907348355854, 0.7269644100208321, 0.9660628547599075], 
             UndirectedEdge[17, 134] -> 
             RGBColor[
              0.713221816174809, 0.7758209468561399, 0.9721005964975649], 
             UndirectedEdge[54, 72] -> 
             RGBColor[
              0.7727780775080755, 0.8228925799687402, 0.977861380647607], 
             UndirectedEdge[170, 192] -> 
             RGBColor[
              0.3997279561645162, 0.516618858936818, 0.9472459724325942], 
             UndirectedEdge[140, 198] -> 
             RGBColor[
              0.3874851570685647, 0.5100419003076857, 0.9459111894621062], 
             UndirectedEdge[19, 89] -> 
             RGBColor[
              0.6719298883294207, 0.7436360027100186, 0.9679353497930137], 
             UndirectedEdge[239, 295] -> 
             RGBColor[
              0.7326399920157234, 0.7907065591584422, 0.9744178724702961], 
             UndirectedEdge[51, 69] -> 
             RGBColor[
              0.4878099710678419, 0.5950651359584631, 0.9528213343107137], 
             UndirectedEdge[186, 269] -> 
             RGBColor[
              0.61923072010751, 0.7001424980294896, 0.964272072080482], 
             UndirectedEdge[37, 282] -> 
             RGBColor[
              0.802797927062998, 0.845904525272805, 0.9809701852650459], 
             UndirectedEdge[1, 239] -> 
             RGBColor[
              0.6757478178172776, 0.7458133460258796, 0.9688664406626997], 
             UndirectedEdge[59, 200] -> 
             RGBColor[
              0.5768191932520809, 0.6640661428333874, 0.9614398039643025], 
             UndirectedEdge[145, 221] -> 
             RGBColor[
              0.5436410705266037, 0.6348227562722943, 0.9595399560172884], 
             UndirectedEdge[75, 297] -> 
             RGBColor[
              0.881593168202261, 0.9084224783881625, 0.9885683374622853], 
             UndirectedEdge[142, 185] -> 
             RGBColor[
              0.7025775022153128, 0.7664540222852488, 0.971874513776716], 
             UndirectedEdge[36, 258] -> 
             RGBColor[
              0.7180543716621832, 0.7796687996486298, 0.9725326072338201], 
             UndirectedEdge[13, 289] -> 
             RGBColor[
              0.782991954399135, 0.8287080302476051, 0.9008402863238443], 
             UndirectedEdge[53, 170] -> 
             RGBColor[
              0.743884359195957, 0.7982047966993843, 0.9437597090409569], 
             UndirectedEdge[130, 226] -> 
             RGBColor[
              0.7684091653720742, 0.8190063472054032, 0.9775515024785204], 
             UndirectedEdge[224, 249] -> 
             RGBColor[
              0.9159954210647369, 0.9357602309970225, 0.9886020573705971], 
             UndirectedEdge[234, 271] -> 
             RGBColor[
              0.649221057098534, 0.7246970459077013, 0.9664914660266859], 
             UndirectedEdge[78, 266] -> 
             RGBColor[
              0.9237092583888502, 0.9420047054921352, 0.9925854077417597], 
             UndirectedEdge[127, 232] -> 
             RGBColor[
              0.41720165288617594`, 0.5281832762506046, 0.9488601926172386], 
             UndirectedEdge[57, 292] -> 
             RGBColor[
              0.5587449726581605, 0.6526533658348888, 0.9584055974793761], 
             UndirectedEdge[52, 107] -> 
             RGBColor[
              0.7901400392534841, 0.8362022083401427, 0.9593357454598542], 
             UndirectedEdge[26, 130] -> 
             RGBColor[
              0.6462481224779069, 0.7219702698771666, 0.9664715716926267], 
             UndirectedEdge[51, 58] -> 
             RGBColor[
              0.594839775437702, 0.680793563839673, 0.9620423912075584], 
             UndirectedEdge[192, 195] -> 
             RGBColor[
              0.5258359498124165, 0.6170727141636192, 0.9584906741332699], 
             UndirectedEdge[118, 266] -> 
             RGBColor[
              0.8521497740791153, 0.8852562469464291, 0.9856774354298017], 
             UndirectedEdge[171, 289] -> 
             RGBColor[
              0.778415437934872, 0.8259951073244443, 0.9399451141063215], 
             UndirectedEdge[1, 283] -> 
             RGBColor[
              0.8746951025966294, 0.9014719292115905, 0.9153021418006915], 
             UndirectedEdge[44, 59] -> 
             RGBColor[
              0.7293415396033216, 0.7884864210299007, 0.9736576066496113], 
             UndirectedEdge[62, 127] -> 
             RGBColor[
              0.7705198086985796, 0.8199473354625726, 0.9490397350487916], 
             UndirectedEdge[46, 219] -> 
             RGBColor[
              0.8344701451480133, 0.8715404452881055, 0.9834562326673972], 
             UndirectedEdge[55, 252] -> 
             RGBColor[
              0.5005510496107732, 0.6054089174986621, 0.9538243586857218], 
             UndirectedEdge[55, 144] -> 
             RGBColor[
              0.6549572291728495, 0.7286703081401079, 0.9674104336897453], 
             UndirectedEdge[160, 296] -> 
             RGBColor[
              0.6247922703125369, 0.7062521573620195, 0.9636197003848797], 
             UndirectedEdge[154, 179] -> 
             RGBColor[
              0.82433339357502, 0.8634401121660737, 0.9732621541839495], 
             UndirectedEdge[6, 145] -> 
             RGBColor[
              0.6471571679520081, 0.7159273304496317, 0.9342630082537633], 
             UndirectedEdge[132, 243] -> 
             RGBColor[
              0.8900607305401761, 0.9148432105191736, 0.9778974990230361], 
             UndirectedEdge[53, 59] -> 
             RGBColor[
              0.8640334230640585, 0.8940034906926628, 0.9544104803105472], 
             UndirectedEdge[4, 228] -> 
             RGBColor[
              0.686587405839636, 0.7542900448895606, 0.9699408605298545], 
             UndirectedEdge[71, 98] -> 
             RGBColor[
              0.44318966340329163`, 0.5530118103956307, 0.9505665092168026], 
             UndirectedEdge[201, 259] -> 
             RGBColor[
              0.7792925958787316, 0.8230707345969035, 0.7396514901645437], 
             UndirectedEdge[34, 187] -> 
             RGBColor[
              0.8192250165333079, 0.8587416500510013, 0.9826063807154757], 
             UndirectedEdge[18, 260] -> 
             RGBColor[
              0.9364868246312761, 0.9502140658913834, 0.9188091583143163], 
             UndirectedEdge[263, 289] -> 
             RGBColor[
              0.599640408251948, 0.6858541227683042, 0.9616250359742357], 
             UndirectedEdge[173, 209] -> 
             RGBColor[
              0.9184163563749947, 0.9367851382275115, 0.9574393781117909], 
             UndirectedEdge[4, 199] -> 
             RGBColor[
              0.6818743610727876, 0.750463782827586, 0.9695698323813563], 
             UndirectedEdge[253, 292] -> 
             RGBColor[
              0.6879450570123051, 0.7546647218865004, 0.9706190312910108], 
             UndirectedEdge[128, 209] -> 
             RGBColor[
              0.7675497401228304, 0.8173326490220009, 0.9433490860033007], 
             UndirectedEdge[44, 137] -> 
             RGBColor[
              0.5308249935184621, 0.6265087499540225, 0.9575438907362761], 
             UndirectedEdge[129, 263] -> 
             RGBColor[
              0.7490179287132175, 0.8039967943121425, 0.9757142380672739], 
             UndirectedEdge[73, 289] -> 
             RGBColor[
              0.5601716401690755, 0.6538115987908886, 0.9585179099718906], 
             UndirectedEdge[128, 276] -> 
             RGBColor[
              0.5640318851681723, 0.6569455195832107, 0.9588218025987629], 
             UndirectedEdge[96, 196] -> 
             RGBColor[
              0.7815577832725529, 0.8293255334362966, 0.9610951542444894], 
             UndirectedEdge[24, 224] -> 
             RGBColor[
              0.6751727640103102, 0.742347774213914, 0.967495350687717], 
             UndirectedEdge[88, 278] -> 
             RGBColor[
              0.6175824052880334, 0.6993186665056259, 0.963790650417844], 
             UndirectedEdge[158, 253] -> 
             RGBColor[
              0.820298677639772, 0.8597194291208099, 0.9826764997684495], 
             UndirectedEdge[67, 110] -> 
             RGBColor[
              0.7476262609889412, 0.8027705843453763, 0.9754800567968935], 
             UndirectedEdge[155, 275] -> 
             RGBColor[
              0.8098866692303968, 0.8516649670463015, 0.9816176370507584], 
             UndirectedEdge[101, 108] -> 
             RGBColor[
              0.8456951433419048, 0.8801063092685304, 0.9850626336046073], 
             UndirectedEdge[102, 210] -> 
             RGBColor[
              0.9129553368678371, 0.9310850209801413, 0.9006858193574211], 
             UndirectedEdge[176, 199] -> 
             RGBColor[
              0.6175451176735343, 0.7002092889637312, 0.9631580945902773], 
             UndirectedEdge[62, 226] -> 
             RGBColor[
              0.8751628965367206, 0.9027615477014452, 0.9587405882422914], 
             UndirectedEdge[69, 113] -> 
             RGBColor[
              0.5848082080793905, 0.6734599526985672, 0.9606985486564363], 
             UndirectedEdge[51, 258] -> 
             RGBColor[
              0.5829061702201478, 0.6714709407449608, 0.9608529609653538], 
             UndirectedEdge[30, 74] -> 
             RGBColor[
              0.8488872089545828, 0.8823476012860376, 0.9618326247799938], 
             UndirectedEdge[118, 228] -> 
             RGBColor[
              0.6859262431866029, 0.7537735395999889, 0.9698749620155164], 
             UndirectedEdge[71, 121] -> 
             RGBColor[
              0.7931917118578938, 0.8339985780454438, 0.7115610096585822], 
             UndirectedEdge[1, 20] -> 
             RGBColor[
              0.6019382860195654, 0.6855888411488378, 0.9631394937479993], 
             UndirectedEdge[126, 293] -> 
             RGBColor[
              0.9356092575728793, 0.9506199855195603, 0.9634371618753497], 
             UndirectedEdge[112, 159] -> 
             RGBColor[
              0.455813259517054, 0.5653632633909282, 0.9513318029118327], 
             UndirectedEdge[17, 159] -> 
             RGBColor[
              0.6165670014197469, 0.6995958936362556, 0.9629575593925586], 
             UndirectedEdge[139, 172] -> 
             RGBColor[
              0.6402570171308017, 0.7129491316140816, 0.9681729035543449], 
             UndirectedEdge[47, 233] -> 
             RGBColor[
              0.809770512736794, 0.8517807004275962, 0.9574964586269343], 
             UndirectedEdge[98, 182] -> 
             RGBColor[
              0.5457933913906503, 0.6339144037017017, 0.960281827855948], 
             UndirectedEdge[84, 159] -> 
             RGBColor[
              0.6527158250613065, 0.7279082531232484, 0.9665108830712583], 
             UndirectedEdge[118, 176] -> 
             RGBColor[
              0.7178220255390589, 0.7794872890913491, 0.972509449143665], 
             UndirectedEdge[18, 278] -> 
             RGBColor[
              0.7996273822167768, 0.8439196361828527, 0.9805236226960194], 
             UndirectedEdge[155, 197] -> 
             RGBColor[
              0.8078418616675995, 0.8500675478371312, 0.981413829742712], 
             UndirectedEdge[72, 215] -> 
             RGBColor[
              0.7747690110998245, 0.8244479124222702, 0.9780598183017003], 
             UndirectedEdge[162, 239] -> 
             RGBColor[
              0.694130184488929, 0.7601737905809349, 0.9706986231795465], 
             UndirectedEdge[139, 272] -> 
             RGBColor[
              0.3510585675494218, 0.4784910193198278, 0.9435901193887148], 
             UndirectedEdge[9, 75] -> 
             RGBColor[
              0.6949004522395217, 0.7602400053882574, 0.9712487882243183], 
             UndirectedEdge[18, 254] -> 
             RGBColor[
              0.8378110906468587, 0.8737490394153652, 0.984329417905287], 
             UndirectedEdge[25, 244] -> 
             RGBColor[
              0.8278197563128751, 0.8654142900731621, 0.936101615260137], 
             UndirectedEdge[30, 257] -> 
             RGBColor[
              0.6544515819742508, 0.7230413415392374, 0.9463443206086875], 
             UndirectedEdge[29, 270] -> 
             RGBColor[
              0.7727575846710539, 0.8189450874818672, 0.8358307266719869], 
             UndirectedEdge[73, 298] -> 
             RGBColor[
              0.5596463103149163, 0.6533851123494419, 0.9584765540814246], 
             UndirectedEdge[73, 96] -> 
             RGBColor[
              0.7492103319145709, 0.8030644151878097, 0.9585486443809705], 
             UndirectedEdge[108, 205] -> 
             RGBColor[
              0.8703295719015711, 0.8991540848873605, 0.9667815639462806], 
             UndirectedEdge[9, 43] -> 
             RGBColor[
              0.6665566573593811, 0.7378412419796982, 0.9684917777940913], 
             UndirectedEdge[151, 251] -> 
             RGBColor[
              0.7618463685469419, 0.8138794404465066, 0.9768973842238144], 
             UndirectedEdge[209, 279] -> 
             RGBColor[
              0.7605660741272382, 0.8116629943562113, 0.9427993062341162], 
             UndirectedEdge[53, 68] -> 
             RGBColor[
              0.8949227151163037, 0.9181344404111913, 0.9574892362654688], 
             UndirectedEdge[282, 295] -> 
             RGBColor[
              0.8498029115614043, 0.8830737906662719, 0.9855361544043834], 
             UndirectedEdge[35, 197] -> 
             RGBColor[
              0.8182449569890722, 0.8583626936619736, 0.9824060862614268], 
             UndirectedEdge[116, 168] -> 
             RGBColor[
              0.6484161675011884, 0.7227146832455745, 0.9673445447930071], 
             UndirectedEdge[27, 152] -> 
             RGBColor[
              0.6267595773610769, 0.7078706859557409, 0.9637599563072959], 
             UndirectedEdge[114, 231] -> 
             RGBColor[
              0.5799222974936658, 0.6453414770514491, 0.9253433567924225], 
             UndirectedEdge[83, 155] -> 
             RGBColor[
              0.8350532378111404, 0.8713252816945838, 0.9841260054119322], 
             UndirectedEdge[62, 199] -> 
             RGBColor[
              0.7746101992402674, 0.8232680987743087, 0.9493617455758276], 
             UndirectedEdge[96, 278] -> 
             RGBColor[
              0.8349620028706572, 0.8715799070043861, 0.9660524847505814], 
             UndirectedEdge[2, 178] -> 
             RGBColor[
              0.7439678839532696, 0.7982497680755954, 0.9431537436792253], 
             UndirectedEdge[6, 213] -> 
             RGBColor[
              0.9499145982035891, 0.9618830846125798, 0.9598232203747581], 
             UndirectedEdge[79, 93] -> 
             RGBColor[
              0.8538328247381641, 0.8864686893248209, 0.9858723519316027], 
             UndirectedEdge[270, 272] -> 
             RGBColor[
              0.44474373129250344`, 0.5570014485522206, 0.9502876999502015], 
             UndirectedEdge[161, 186] -> 
             RGBColor[
              0.6121894702471122, 0.6946418201230657, 0.9635702660986186], 
             UndirectedEdge[189, 275] -> 
             RGBColor[
              0.8773033126029386, 0.9037277314463088, 0.9254584290089384], 
             UndirectedEdge[260, 261] -> 
             RGBColor[
              0.936784179346901, 0.950451168470144, 0.9188375202725443], 
             UndirectedEdge[195, 200] -> 
             RGBColor[
              0.5827781230318797, 0.66872130406691, 0.962033734395388], 
             UndirectedEdge[66, 110] -> 
             RGBColor[
              0.8314540712227463, 0.8690240677781853, 0.9836318077955286], 
             UndirectedEdge[63, 172] -> 
             RGBColor[
              0.9184823309214043, 0.9378368954107603, 0.9920868587337817], 
             UndirectedEdge[4, 236] -> 
             RGBColor[
              0.7314587352186597, 0.7901403903358855, 0.9738686289222303], 
             UndirectedEdge[143, 167] -> 
             RGBColor[
              0.8189907596036765, 0.8592543791624924, 0.9721208587672547], 
             UndirectedEdge[135, 249] -> 
             RGBColor[
              0.8236783166864311, 0.8627704366894977, 0.9829043348294426], 
             UndirectedEdge[135, 288] -> 
             RGBColor[
              0.7191178474142257, 0.7804995949888405, 0.9726386045580377], 
             UndirectedEdge[83, 214] -> 
             RGBColor[
              0.8785223504569342, 0.9059114391866665, 0.9856741542384324], 
             UndirectedEdge[36, 290] -> 
             RGBColor[
              0.7030460418468343, 0.7679441783293479, 0.9710367171786424], 
             UndirectedEdge[79, 119] -> 
             RGBColor[
              0.6421522280382972, 0.7148444233778373, 0.9681768471998777], 
             UndirectedEdge[145, 264] -> 
             RGBColor[
              0.4370507766073291, 0.5502142489475446, 0.9498317591349399], 
             UndirectedEdge[54, 238] -> 
             RGBColor[
              0.7038738196774508, 0.76859084466197, 0.9711192223367746], 
             UndirectedEdge[177, 273] -> 
             RGBColor[
              0.6775682845937125, 0.7406643814090592, 0.8893352907318751], 
             UndirectedEdge[98, 208] -> 
             RGBColor[
              0.49753710538003765`, 0.5962162263088536, 0.9554720922470421], 
             UndirectedEdge[125, 170] -> 
             RGBColor[
              0.4239208344908531, 0.5399016556311047, 0.9487022765831866], 
             UndirectedEdge[22, 217] -> 
             RGBColor[
              0.8579064580569589, 0.8892629122760325, 0.9561208838637464], 
             UndirectedEdge[78, 236] -> 
             RGBColor[
              0.8023570568753615, 0.8463723435920198, 0.9807107027198503], 
             UndirectedEdge[86, 240] -> 
             RGBColor[
              0.8974661704657385, 0.9194249553079187, 0.925012504482803], 
             UndirectedEdge[59, 170] -> 
             RGBColor[
              0.6360398243067633, 0.7136610797881182, 0.9656827281828957], 
             UndirectedEdge[95, 109] -> 
             RGBColor[
              0.7053672201388484, 0.7650979391994704, 0.9041737297502048], 
             UndirectedEdge[30, 252] -> 
             RGBColor[
              0.7160280152460993, 0.7759188797565763, 0.9503941519578253], 
             UndirectedEdge[116, 119] -> 
             RGBColor[
              0.4243428465827177, 0.5413903506786937, 0.9484188317730703], 
             UndirectedEdge[6, 231] -> 
             RGBColor[
              0.5770329712926358, 0.6431866223015583, 0.9302342323938033], 
             UndirectedEdge[214, 275] -> 
             RGBColor[
              0.8533557818761904, 0.8862511245383842, 0.9831657858772587], 
             UndirectedEdge[157, 257] -> 
             RGBColor[
              0.38431892331620754`, 0.5072994677709295, 0.9457094398471966], 
             UndirectedEdge[128, 173] -> 
             RGBColor[
              0.7115211656609601, 0.7736561354720175, 0.9726462184646865], 
             UndirectedEdge[14, 113] -> 
             RGBColor[
              0.5815855754189737, 0.670843674326894, 0.9604448512085159], 
             UndirectedEdge[213, 231] -> 
             RGBColor[
              0.5518086269109534, 0.6240904623110215, 0.9630899879809549], 
             UndirectedEdge[29, 148] -> 
             RGBColor[
              0.8702378984399993, 0.8965067381853031, 0.8445831149557637], 
             UndirectedEdge[109, 154] -> 
             RGBColor[
              0.8447692118255302, 0.8781648622653682, 0.915550928462057], 
             UndirectedEdge[74, 123] -> 
             RGBColor[
              0.7168173724385725, 0.7787024464536028, 0.9724093147116255], 
             UndirectedEdge[189, 216] -> 
             RGBColor[
              0.8746546873752976, 0.9016586052881783, 0.9251944387990572], 
             UndirectedEdge[29, 162] -> 
             RGBColor[
              0.8968109265901217, 0.9172657897386727, 0.8472316660627011], 
             UndirectedEdge[73, 140] -> 
             RGBColor[
              0.458133464594776, 0.5688051851504565, 0.9510839019974991], 
             UndirectedEdge[9, 295] -> 
             RGBColor[
              0.7067925516572309, 0.7697224426614994, 0.9723830672829818], 
             UndirectedEdge[169, 221] -> 
             RGBColor[
              0.8804291699752034, 0.9028374049309089, 0.714977544443423], 
             UndirectedEdge[22, 61] -> 
             RGBColor[
              0.9001982312465371, 0.922391481351349, 0.9603122720510233], 
             UndirectedEdge[11, 143] -> 
             RGBColor[
              0.780466796705549, 0.8287220857252089, 0.9685799847218997], 
             UndirectedEdge[100, 299] -> 
             RGBColor[
              0.7750730742680699, 0.8180204673570344, 0.6902939310692909], 
             UndirectedEdge[181, 232] -> 
             RGBColor[
              0.514188507899805, 0.6050163812174438, 0.9577979440743547], 
             UndirectedEdge[49, 292] -> 
             RGBColor[
              0.6827362260414775, 0.7505113414603126, 0.970122208343035], 
             UndirectedEdge[4, 39] -> 
             RGBColor[
              0.8675531784782604, 0.8394133149821694, 0.6297299309368257], 
             UndirectedEdge[33, 75] -> 
             RGBColor[
              0.6158726857914258, 0.6940920907216956, 0.9655771691556645], 
             UndirectedEdge[223, 271] -> 
             RGBColor[
              0.4640614560681361, 0.573360126590371, 0.9516217699388356], 
             UndirectedEdge[21, 34] -> 
             RGBColor[
              0.621349557667638, 0.700188564621109, 0.9653131550599425], 
             UndirectedEdge[51, 165] -> 
             RGBColor[
              0.6561003681483439, 0.7288191549141068, 0.9681035995427394], 
             UndirectedEdge[36, 138] -> 
             RGBColor[
              0.7951451448855684, 0.8401240371884408, 0.9801549046413746], 
             UndirectedEdge[50, 205] -> 
             RGBColor[
              0.8644707741754984, 0.41234284591929576`, 0.42770149932354573`],
              UndirectedEdge[237, 283] -> 
             RGBColor[
              0.9694136769372401, 0.9761286980327624, 0.910656026325235], 
             UndirectedEdge[140, 245] -> 
             RGBColor[
              0.5395856750464336, 0.6339619057438634, 0.9581592123247713], 
             UndirectedEdge[19, 49] -> 
             RGBColor[
              0.7598938961591448, 0.8124465526516055, 0.9766782603091408], 
             UndirectedEdge[235, 292] -> 
             RGBColor[
              0.5883560440176321, 0.6766884274735483, 0.9607397935457946], 
             UndirectedEdge[15, 115] -> 
             RGBColor[
              0.843927009281531, 0.8778165898698065, 0.929508404166441], 
             UndirectedEdge[69, 110] -> 
             RGBColor[
              0.6261577317224067, 0.7057625148365108, 0.964819882739904], 
             UndirectedEdge[34, 50] -> 
             RGBColor[
              0.8161517780112317, 0.37424451789290847`, 0.43683778812241625`],
              UndirectedEdge[126, 275] -> 
             RGBColor[
              0.8688386933587274, 0.8977982545711195, 0.9569572553273744], 
             UndirectedEdge[59, 225] -> 
             RGBColor[
              0.46875223967510077`, 0.5586821672760516, 0.9549852630931587], 
             UndirectedEdge[82, 228] -> 
             RGBColor[
              0.7915536230555353, 0.8347948157167734, 0.865397255749695], 
             UndirectedEdge[19, 280] -> 
             RGBColor[
              0.7389605485004735, 0.7960008638875311, 0.9746163395617305], 
             UndirectedEdge[194, 283] -> 
             RGBColor[
              0.8099554653182075, 0.8507415756088321, 0.9089556497881748], 
             UndirectedEdge[63, 283] -> 
             RGBColor[
              0.953564277396734, 0.9638890060741263, 0.9229497595447742], 
             UndirectedEdge[36, 245] -> 
             RGBColor[
              0.7236775392459063, 0.7840616609026909, 0.9730930720270768], 
             UndirectedEdge[3, 55] -> 
             RGBColor[
              0.7009237518549366, 0.764991156836375, 0.9718827604274705], 
             UndirectedEdge[137, 192] -> 
             RGBColor[
              0.32136047394775824`, 0.45043988185421846`, 0.9417830277888493],
              UndirectedEdge[54, 251] -> 
             RGBColor[
              0.7080255672568302, 0.7718342214254315, 0.9715330297352001], 
             UndirectedEdge[252, 292] -> 
             RGBColor[
              0.5021005051197244, 0.6066668352830038, 0.953946337499229], 
             UndirectedEdge[100, 121] -> 
             RGBColor[
              0.775649370576351, 0.8197569151196185, 0.7101800122931857], 
             UndirectedEdge[142, 239] -> 
             RGBColor[
              0.7220302220650764, 0.7822466165943295, 0.97340590314095], 
             UndirectedEdge[85, 299] -> 
             RGBColor[
              0.9883152107014481, 0.9858306086460292, 0.6606946973884531], 
             UndirectedEdge[120, 130] -> 
             RGBColor[
              0.6350714453352325, 0.7128965398691762, 0.9655917027264379], 
             UndirectedEdge[9, 297] -> 
             RGBColor[
              0.7247903038742706, 0.7840733617433973, 0.9740997089562262], 
             UndirectedEdge[237, 239] -> 
             RGBColor[
              0.7704663921578883, 0.8204701148470513, 0.9642203251872432], 
             UndirectedEdge[169, 213] -> 
             RGBColor[
              0.9587209230189255, 0.9648458191177094, 0.7225563522670495], 
             UndirectedEdge[46, 50] -> 
             RGBColor[
              0.856939460331581, 0.4067260043858968, 0.44045004918005715`], 
             UndirectedEdge[105, 171] -> 
             RGBColor[
              0.6762129566871903, 0.7408463803679719, 0.932500636719712], 
             UndirectedEdge[34, 114] -> 
             RGBColor[
              0.8973674645105133, 0.9198842538908116, 0.9496315389760469], 
             UndirectedEdge[60, 240] -> 
             RGBColor[
              0.8690333970595078, 0.8972130566258898, 0.9221785913490442], 
             UndirectedEdge[19, 84] -> 
             RGBColor[
              0.6991439282484686, 0.7648958175291428, 0.9706477909624821], 
             UndirectedEdge[19, 48] -> 
             RGBColor[
              0.7757397313548454, 0.825081591512919, 0.9781896502158508], 
             UndirectedEdge[5, 77] -> 
             RGBColor[
              0.7003651261969313, 0.7641791079880931, 0.9722514464042826]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {3}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.3191753933187448, 0.45087541629614686`, 0.94155855171992], 
             160 -> RGBColor[
              0.6058298561866651, 0.6908789954331593, 0.9621122919883515], 
             245 -> RGBColor[
              0.7056706174274304, 0.7699945167204229, 0.9712983103444629], 
             155 -> RGBColor[
              0.8516665907263309, 0.884559837844161, 0.98571391378686], 213 -> 
             RGBColor[
              0.9246902538219068, 0.9427869246220429, 0.9926789759619097], 27 -> 
             RGBColor[
              0.638026830237253, 0.7170179494245783, 0.9646469557270158], 19 -> 
             RGBColor[
              0.6883720553909852, 0.7564807485836109, 0.9695741513449233], 
             164 -> RGBColor[
              0.6461457303481387, 0.7234932225281826, 0.9653654258920954], 
             190 -> RGBColor[
              0.8939436188613918, 0.9182703924997011, 0.9897463344715307], 
             103 -> RGBColor[
              0.5819285105051454, 0.6714748062655491, 0.9602306905027881], 
             138 -> RGBColor[
              0.8486058287067546, 0.8821192692919226, 0.9854219755730583], 
             291 -> 
             RGBColor[
              0.9465647209024023, 0.9596686368580266, 0.975336168746116], 28 -> 
             RGBColor[
              0.9059699354796025, 0.9278598509253939, 0.9908934152865952], 
             114 -> RGBColor[
              0.9809175949873316, 0.9852889541028981, 0.9171857135848451], 
             195 -> RGBColor[
              0.7681067477344625, 0.8187700962484419, 0.9775213603146569], 93 -> 
             RGBColor[
              0.7975215921357374, 0.8417491962558152, 0.9804531571072265], 34 -> 
             RGBColor[
              0.813817334033695, 0.8544795536787253, 0.9820773643672487], 161 -> 
             RGBColor[
              0.7337632479410217, 0.79194069318954, 0.9740983212134995], 22 -> 
             RGBColor[
              0.9692880567499441, 0.9766156635270756, 0.9368714883513927], 
             124 -> RGBColor[
              0.39182210951321517`, 0.513798350533674, 0.9461875362368629], 
             84 -> RGBColor[
              0.7099158011059519, 0.7733108864746747, 0.9717214305800409], 46 -> 
             RGBColor[
              0.9361803809947428, 0.9519240131576902, 0.9929141475401715], 
             241 -> RGBColor[
              0.5341602071539306, 0.6326943456674904, 0.9564701946819197], 
             185 -> RGBColor[
              0.5508870289289893, 0.6462739331192168, 0.9577869913644195], 
             121 -> RGBColor[
              0.99283926989472, 0.9870922473027046, 0.46197690282304343`], 
             126 -> RGBColor[
              0.9695706389829923, 0.9768264128937971, 0.936393150340092], 236 -> 
             RGBColor[
              0.6801050388459741, 0.7500224924269954, 0.9687501723953785], 78 -> 
             RGBColor[
              0.924609074904749, 0.9427221947570443, 0.9926712330443219], 254 -> 
             RGBColor[
              0.7906369552964516, 0.8363708656317872, 0.9797669608476756], 
             290 -> RGBColor[
              0.6644076226292863, 0.737759551573737, 0.967185600647594], 251 -> 
             RGBColor[
              0.7490249640555101, 0.8038632618115169, 0.9756194664469457], 
             165 -> RGBColor[
              0.8408126781163766, 0.8759052225505927, 0.9846786579127205], 
             100 -> RGBColor[
              0.558459471257982, 0.6524215829365324, 0.958383121763328], 235 -> 
             RGBColor[
              0.6426553728796135, 0.7207665287460714, 0.9650175396788778], 70 -> 
             RGBColor[
              0.7197815920021928, 0.7810181173056061, 0.9727047604155205], 
             234 -> RGBColor[
              0.7343301799507229, 0.7923835847843615, 0.9741548276979457], 
             257 -> 
             RGBColor[
              0.3469914285401013, 0.4749682679303048, 0.9433309648874707], 
             135 -> RGBColor[
              0.7546972069520076, 0.8082944610729035, 0.9761848226087451], 
             265 -> RGBColor[
              0.9732377952744463, 0.9795613720515461, 0.930185611286202], 111 -> 
             RGBColor[
              0.7416844610643822, 0.7981288050849589, 0.9748878337096908], 
             182 -> RGBColor[
              0.7987516097957851, 0.8427100954003249, 0.9805757537724115], 
             188 -> RGBColor[
              0.9825156356448463, 0.9864807702087212, 0.9144806475874279], 
             154 -> RGBColor[
              0.7022390377745596, 0.7673137406146289, 0.9709562825545999], 
             269 -> RGBColor[
              0.7478457476618173, 0.8029420490023875, 0.9755019331772262], 
             208 -> RGBColor[
              0.7022390377745596, 0.7673137406146289, 0.9709562825545999], 86 -> 
             RGBColor[
              0.808137893920519, 0.8500427318969687, 0.9815112908541527], 119 -> 
             RGBColor[
              0.37416039873600326`, 0.4985006643618478, 0.9450621476437765], 
             140 -> RGBColor[
              0.3735007326654367, 0.49792929476730385`, 0.9450201143050798], 
             85 -> RGBColor[
              0.9849437441247384, 0.9880418655145221, 0.8991846544016523], 
             242 -> RGBColor[
              0.6376181538228324, 0.716686167500689, 0.9646147832226416], 117 -> 
             RGBColor[
              0.665318103476312, 0.7384708261313442, 0.9672763488694982], 47 -> 
             RGBColor[
              0.6571412549771389, 0.7320830099374399, 0.9664613570280943], 81 -> 
             RGBColor[
              0.636749400905665, 0.7159808747456595, 0.9645463918106554], 275 -> 
             RGBColor[
              0.7681067477344625, 0.8187700962484419, 0.9775213603146569], 23 -> 
             RGBColor[
              0.9029396773408761, 0.9254436053397395, 0.9906043865601801], 
             110 -> RGBColor[
              0.748083579489441, 0.803127845033716, 0.975525638031139], 6 -> 
             RGBColor[
              0.9751389425852715, 0.9809792446031166, 0.9269674647876065], 
             218 -> RGBColor[
              0.4810711899389439, 0.5895942898593934, 0.9522908327752782], 
             108 -> RGBColor[
              0.7818848212766469, 0.8295336320168337, 0.978894629921924], 297 -> 
             RGBColor[
              0.9114830198370099, 0.9322558347433023, 0.9914192581941933], 
             157 -> RGBColor[
              0.42164641809231385`, 0.5396306676115543, 0.9480879148069224], 
             270 -> RGBColor[
              0.550361216511206, 0.6458470549108807, 0.9577455974847772], 33 -> 
             RGBColor[
              0.3800420550153395, 0.5035950594103688, 0.9454369215809514], 
             252 -> RGBColor[
              0.4701442950837982, 0.5807233443649825, 0.9514306275857464], 
             260 -> RGBColor[
              0.9879884232652865, 0.9893009185838236, 0.8487264416657339], 
             159 -> RGBColor[
              0.5955158490166612, 0.6825056197718221, 0.9613003355624756], 
             183 -> RGBColor[
              0.5123540475469541, 0.6149911229422514, 0.9547535339190639], 99 -> 
             RGBColor[
              0.49353487497996884`, 0.59971287085831, 0.9532720197176903], 17 -> 
             RGBColor[
              0.6376181538228324, 0.716686167500689, 0.9646147832226416], 277 -> 
             RGBColor[
              0.7884698021382615, 0.8346778691136352, 0.9795509592740649], 
             104 -> RGBColor[
              0.735091397722567, 0.7929782538931955, 0.9742306987714585], 79 -> 
             RGBColor[
              0.910144057340591, 0.9311881823938266, 0.991291546755979], 191 -> 
             RGBColor[
              0.6619965504659424, 0.7358760036749056, 0.9669452875071023], 50 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 225 -> 
             RGBColor[
              0.18131559117533672`, 0.3079045607707065, 0.9336370267338314], 
             61 -> RGBColor[
              0.83110840574313, 0.8681672991756222, 0.983753055750654], 196 -> 
             RGBColor[
              0.6074610992400792, 0.692203312030583, 0.9622407094169564], 1 -> 
             RGBColor[
              0.7617031670060385, 0.813767570314381, 0.9768831112325118], 263 -> 
             RGBColor[
              0.6217037326898603, 0.7037661234884404, 0.9633619416946085], 
             201 -> RGBColor[
              0.993375924915022, 0.988240098126985, 0.5203884899320348], 293 -> 
             RGBColor[
              0.9016478761627662, 0.9244135581453236, 0.9904811734106075], 
             184 -> RGBColor[
              0.7255281958704887, 0.7855074079233259, 0.9732775281840458], 
             106 -> RGBColor[
              0.988189709622346, 0.9893841556652911, 0.8453906058168652], 206 -> 
             RGBColor[
              0.35612710159369304`, 0.48288112875704725`, 0.943913081896087], 
             247 -> RGBColor[
              0.4656522224969366, 0.5770764774734045, 0.9510769951767046], 
             220 -> 
             RGBColor[
              0.9951539528309019, 0.9920431200528538, 0.7139158558591967], 
             107 -> RGBColor[
              0.9584036476817711, 0.9684980890656164, 0.9552959537952721], 
             131 -> RGBColor[
              0.9931191009214598, 0.9876907775736443, 0.4924347831667562], 
             127 -> RGBColor[
              0.5727555094708543, 0.6640277507869243, 0.9595085582595587], 
             210 -> RGBColor[
              0.8360169331724671, 0.8720812257093479, 0.9842212354787583], 
             181 -> RGBColor[
              0.7667292194981125, 0.8176939607206029, 0.9773840611737907], 
             194 -> RGBColor[
              0.6322238924491946, 0.7123068631088643, 0.9641901272074783], 
             118 -> RGBColor[
              0.7814901062852793, 0.8292252776656321, 0.9788552884204058], 
             276 -> RGBColor[
              0.5674092209275486, 0.6596873928999145, 0.9590876788413295], 
             280 -> RGBColor[
              0.789549041609962, 0.8355209791914513, 0.9796585277785378], 189 -> 
             RGBColor[
              0.9864998774714145, 0.9886853666441756, 0.8733954977032199], 
             168 -> RGBColor[
              0.8223070405729445, 0.8611493294956094, 0.9829135736836503], 41 -> 
             RGBColor[
              0.8367301911179763, 0.8726499582342258, 0.9842892666583338], 14 -> 
             RGBColor[
              0.4977866186345389, 0.6031646278959588, 0.9536067325528282], 77 -> 
             RGBColor[
              0.48029293354952834`, 0.5889624662624151, 0.9522295655814563], 
             51 -> RGBColor[
              0.4713880581803114, 0.581733087277621, 0.9515285411727583], 179 -> 
             RGBColor[
              0.9464277493754804, 0.9595664837175185, 0.975568025813299], 223 -> 
             RGBColor[
              0.36401097788992703`, 0.48970974614970086`, 0.944415435522245], 
             292 -> RGBColor[
              0.5340567151556506, 0.6326103262010252, 0.9564620474127115], 
             143 -> RGBColor[
              0.9471070489283746, 0.960073104211816, 0.9744181488599476], 112 -> 
             RGBColor[
              0.3161106700174467, 0.44822090701003436`, 0.9413632702611897], 
             197 -> RGBColor[
              0.7640171326088682, 0.8155752578301014, 0.9771137456985638], 54 -> 
             RGBColor[
              0.6670261704581503, 0.7398051810393461, 0.9674465930234544], 71 -> 
             RGBColor[
              0.5935441538210676, 0.680904908788183, 0.9611451164941209], 177 -> 
             RGBColor[
              0.36626626791470296`, 0.4916631650149892, 0.9445591406083491], 
             158 -> RGBColor[
              0.7987639564105845, 0.8427197406696441, 0.980576984367589], 226 -> 
             RGBColor[
              0.7820416851471363, 0.8296561752646696, 0.9789102646465582], 
             203 -> RGBColor[
              0.6379579308584022, 0.7169620138049455, 0.9646415317155259], 
             115 -> RGBColor[
              0.9856149807885023, 0.988319439124984, 0.8880605257782822], 173 -> 
             RGBColor[
              0.8623877819131245, 0.8931086246775282, 0.9867365105731768], 
             212 -> RGBColor[
              0.46333985192721405`, 0.5751991908737967, 0.9508949568949635], 
             129 -> RGBColor[
              0.8763321247365747, 0.9042274651358447, 0.9880665344399393], 
             279 -> RGBColor[
              0.5466872174176114, 0.6428643369349276, 0.9574563668178273], 26 -> 
             RGBColor[
              0.5377195993588018, 0.6355840206081962, 0.9567504030747704], 40 -> 
             RGBColor[
              0.701121459666595, 0.7664406801027787, 0.9708448928131591], 146 -> 
             RGBColor[
              0.9432011712345009, 0.9571601070230128, 0.9810297809796208], 
             192 -> RGBColor[
              0.2835651518903705, 0.41537533207879646`, 0.9394599879518831], 
             300 -> RGBColor[
              0.5060662865017735, 0.6098864352653667, 0.9542585383367597], 
             221 -> RGBColor[
              0.7681067477344625, 0.8187700962484419, 0.9775213603146569], 62 -> 
             RGBColor[
              0.968284107926305, 0.975866920138221, 0.9385709118380245], 286 -> 
             RGBColor[
              0.5309578041377483, 0.6300944906323417, 0.9562180897856971], 
             152 -> RGBColor[
              0.6154923244849008, 0.6987234224869034, 0.9628729568875761], 64 -> 
             RGBColor[
              0.8533904347600846, 0.8859343842841765, 0.9858783355696933], 37 -> 
             RGBColor[
              0.7814775464061178, 0.8292154657925725, 0.9788540365690297], 
             148 -> RGBColor[
              0.7453218440490967, 0.8009703563177524, 0.9752503740523305], 
             261 -> RGBColor[
              0.8855799354285154, 0.9116014183564642, 0.9889485988793546], 15 -> 
             RGBColor[
              0.7022390377745596, 0.7673137406146289, 0.9709562825545999], 
             136 -> RGBColor[
              0.5729515619551473, 0.6641869150257371, 0.9595239922292862], 
             198 -> RGBColor[
              0.40146958147169265`, 0.5221545058480676, 0.9468022646191325], 
             63 -> RGBColor[
              0.9194415166062477, 0.9386017240394526, 0.9921783467206772], 
             171 -> RGBColor[
              0.9792537920557082, 0.9840480926007207, 0.9200020979587803], 59 -> 
             RGBColor[
              0.7561888881748648, 0.8094597737813968, 0.9763334994524859], 
             229 -> RGBColor[
              0.5209981057642357, 0.6220087588134255, 0.9554340258461569], 
             102 -> RGBColor[
              0.9898937405632071, 0.9900888162509349, 0.8171504032360839], 
             299 -> RGBColor[
              0.9916866772781578, 0.9836193517775363, 0.4222047403752539], 
             128 -> RGBColor[
              0.5606545494087958, 0.6542036462665068, 0.9585559263561962], 12 -> 
             RGBColor[
              0.8071546632891565, 0.8492746246549187, 0.9814132916136311], 
             222 -> RGBColor[
              0.6943362839718867, 0.7611400492808272, 0.9701686099109825], 92 -> 
             RGBColor[
              0.964223521424026, 0.9728385413734214, 0.9454444256158084], 271 -> 
             RGBColor[
              0.5641119342463451, 0.6570105070310412, 0.9588281043554261], 
             132 -> RGBColor[
              0.9485376034126628, 0.9611400094038802, 0.9719965932664129], 80 -> 
             RGBColor[
              0.8082761412121094, 0.8501507317318774, 0.981525070052184], 244 -> 
             RGBColor[
              0.9846314749841018, 0.987912734199918, 0.904359762188633], 150 -> 
             RGBColor[
              0.8908567544557937, 0.9158090106133792, 0.9894519065888484], 
             125 -> RGBColor[
              0.33195090854304443`, 0.46194092546736965`, 0.9423725962530679],
              133 -> RGBColor[
              0.5727555094708543, 0.6640277507869243, 0.9595085582595587], 
             258 -> RGBColor[
              0.6944242822599842, 0.7612087942123008, 0.9701773807579493], 
             255 -> RGBColor[
              0.47972985556085446`, 0.5885053341848353, 0.9521852380195652], 
             176 -> RGBColor[
              0.6541539447928386, 0.7297493005170661, 0.9661636098669242], 
             230 -> RGBColor[
              0.8783700657758966, 0.9058524640021641, 0.9882609150755612], 
             274 -> RGBColor[
              0.8082761412121094, 0.8501507317318774, 0.981525070052184], 87 -> 
             RGBColor[
              0.8507562632840862, 0.8838339674518952, 0.9856270859427598], 
             130 -> RGBColor[
              0.754776645597012, 0.8083565191461369, 0.9761927403104828], 35 -> 
             RGBColor[
              0.8724727813692761, 0.9011501294938458, 0.9876984268242899], 31 -> 
             RGBColor[
              0.9452463914186992, 0.9586854288876472, 0.977567756686628], 18 -> 
             RGBColor[
              0.8849852259972657, 0.9111272131989432, 0.9888918749628987], 24 -> 
             RGBColor[
              0.41101411231200136`, 0.5304214987398744, 0.9474104336843798], 
             151 -> RGBColor[
              0.7746677730383735, 0.8238956190814962, 0.9781753020006833], 
             137 -> RGBColor[
              0.35915579600514597`, 0.48550443162964046`, 0.9441060676258155],
              296 -> RGBColor[
              0.6437546844384088, 0.7216253192908796, 0.965127108781408], 266 -> 
             RGBColor[
              0.9228094418729513, 0.9412872162272262, 0.9924995824391977], 
             283 -> RGBColor[
              0.9876870381872203, 0.9891762881088001, 0.8537211723688711], 
             284 -> RGBColor[
              0.38361745084725196`, 0.5066918875753517, 0.9456647426417625], 
             238 -> RGBColor[
              0.7407214688967514, 0.797376508284594, 0.9747918516500947], 72 -> 
             RGBColor[
              0.8785299845580008, 0.9059799788981343, 0.9882761682717596], 
             288 -> RGBColor[
              0.6835384878764438, 0.7527047289047775, 0.9690923865073303], 
             172 -> RGBColor[
              0.9175231452365609, 0.937072066782068, 0.991995370746886], 243 -> 
             RGBColor[
              0.8315838576676894, 0.868546411634467, 0.9837984047796594], 88 -> 
             RGBColor[
              0.520895272139779, 0.6219252738444896, 0.9554259304065478], 273 -> 
             RGBColor[
              0.9888703012727221, 0.9896655978031293, 0.8341114408554011], 
             202 -> RGBColor[
              0.9008787304928114, 0.9238002622660046, 0.9904078116099828], 98 -> 
             RGBColor[
              0.29283517298551565`, 0.42511871200307844`, 0.9399879019394843],
              30 -> RGBColor[
              0.9619117354084004, 0.97111441514817, 0.9493576763299042], 116 -> 
             RGBColor[
              0.4745252944294322, 0.5842800369955397, 0.9517755159023641], 
             240 -> RGBColor[
              0.986794447010958, 0.9888071787188687, 0.8685137181114534], 73 -> 
             RGBColor[
              0.5427661965241153, 0.6396810755336093, 0.9571476896899185], 29 -> 
             RGBColor[
              0.9951539528309019, 0.9920431200528538, 0.7139158558591967], 75 -> 
             RGBColor[
              0.8517033165675121, 0.8845891220330225, 0.9857174167303775], 
             200 -> RGBColor[
              0.3974494983292969, 0.5186725118853781, 0.9465461084761191], 
             156 -> RGBColor[
              0.20434839586304968`, 0.33211349886165664`, 0.9349487108868157],
              25 -> RGBColor[
              0.6710080376416483, 0.7429158459464061, 0.967843468331641], 38 -> 
             RGBColor[
              0.9858956806183622, 0.9884355157182876, 0.8834086031696304], 3 -> 
             RGBColor[
              0.8708896995721249, 0.8998878230404082, 0.9875474310692438], 57 -> 
             RGBColor[
              0.5834332301606704, 0.6726964054687523, 0.9603491475460407], 
             227 -> RGBColor[
              0.6957568612898691, 0.7622498150784226, 0.9703101997819892], 39 -> 
             RGBColor[
              0.9522939253651754, 0.8485683417195633, 0.2804727764245694], 
             109 -> RGBColor[
              0.9872993858765008, 0.9890159839161076, 0.8601455743695141], 
             256 -> RGBColor[
              0.21916716880793746`, 0.34768896879120503`, 0.935792618083617], 
             287 -> RGBColor[
              0.5397490378978622, 0.6372316102393698, 0.9569101679106436], 
             239 -> RGBColor[
              0.5897924686285165, 0.6778591217373781, 0.9608497700928876], 
             285 -> RGBColor[
              0.552545533617106, 0.6476203819398146, 0.9579175549287708], 216 -> 
             RGBColor[
              0.7628094972791807, 0.8146318439321811, 0.9769933798948944], 21 -> 
             RGBColor[
              0.42888178130158106`, 0.5458975755634927, 0.9485489457526365], 
             175 -> RGBColor[
              0.868574325921975, 0.8980416069409219, 0.987326588663534], 7 -> 
             RGBColor[
              0.49447436167971365`, 0.6004755884845563, 0.9533459795521474], 
             13 -> RGBColor[
              0.9884068249842345, 0.9894739384470423, 0.8417924423938259], 
             294 -> RGBColor[
              0.9184468571023479, 0.9378086095503559, 0.9920834752092521], 
             193 -> RGBColor[
              0.3390109124866397, 0.4680559460371961, 0.9428224534614373], 60 -> 
             RGBColor[
              0.7512723471080576, 0.8056189345329108, 0.9758434645866351], 65 -> 
             RGBColor[
              0.9909474632623851, 0.9905245576664832, 0.7996874911637728], 69 -> 
             RGBColor[
              0.5042318839553724, 0.6083971846393054, 0.9541141274486691], 
             217 -> RGBColor[
              0.7465248593639737, 0.8019101610249892, 0.9753702793761001], 
             214 -> 
             RGBColor[
              0.9386048160179183, 0.9537321528283265, 0.9888102114398604], 
             170 -> RGBColor[
              0.5158907604386618, 0.6178623857948397, 0.9550319569133053], 74 -> 
             RGBColor[
              0.7358626825007653, 0.7935807874239054, 0.9743075732300833], 
             246 -> RGBColor[
              0.5549158285761415, 0.6495446941681307, 0.9581041532306226], 
             264 -> RGBColor[
              0.5549261598959134, 0.6495530815989422, 0.9581049665499599], 
             278 -> RGBColor[
              0.7142695384362878, 0.7767120591667623, 0.9721553704291402], 45 -> 
             RGBColor[
              0.6842678906912428, 0.7532745439273651, 0.9691650865632527], 
             237 -> RGBColor[
              0.95114031568726, 0.9630811079567246, 0.9675908802815988], 228 -> 
             RGBColor[
              0.5903623800879266, 0.6783218015343458, 0.9608946356106269], 
             180 -> RGBColor[
              0.752934723802296, 0.8069175958409807, 0.9760091547597233], 53 -> 
             RGBColor[
              0.9718779579532523, 0.9785472076039289, 0.9324874611686085], 48 -> 
             RGBColor[
              0.8631074073187056, 0.8936824344422273, 0.9868051490867783], 5 -> 
             RGBColor[
              0.9204373188443341, 0.939395749713771, 0.9922733272271089], 101 -> 
             RGBColor[
              0.9095054654071626, 0.9306789865202271, 0.9912306372872908], 
             267 -> RGBColor[
              0.655500405631996, 0.7308011659580973, 0.9662978124999795], 120 -> 
             RGBColor[
              0.5153662450734531, 0.6174365605922154, 0.9549906651423931], 
             147 -> RGBColor[
              0.7457978762538267, 0.8013422362940661, 0.9752978204937242], 89 -> 
             RGBColor[
              0.655487721267856, 0.7307912568364264, 0.9662965482411041], 43 -> 
             RGBColor[
              0.7950157268072309, 0.8397915952159041, 0.9802033958699238], 
             199 -> RGBColor[
              0.5809362905542299, 0.6706692774103965, 0.9601525793136306], 
             268 -> RGBColor[
              0.9732377952744463, 0.9795613720515461, 0.930185611286202], 169 -> 
             RGBColor[
              0.9927515922159441, 0.986904713613376, 0.4524337285721893], 20 -> 
             RGBColor[
              0.4421734050330923, 0.5574101119832945, 0.949395876263487], 4 -> 
             RGBColor[
              0.7828124315913454, 0.8302582882447755, 0.978987085449082], 167 -> 
             RGBColor[
              0.6908744702789784, 0.7584356541131687, 0.9698235686745618], 
             142 -> 
             RGBColor[
              0.8542679755016362, 0.8866341114512809, 0.9859620361890123], 16 -> 
             RGBColor[
              0.9883842612027267, 0.9894646077435262, 0.8421663826466055], 
             281 -> RGBColor[
              0.8071546632891565, 0.8492746246549187, 0.9814132916136311], 
             289 -> RGBColor[
              0.5775770838140357, 0.6679421220481678, 0.9598881302538628], 
             178 -> RGBColor[
              0.9725695228330862, 0.9790629755589755, 0.9313168222160576], 58 -> 
             RGBColor[
              0.7182914926950925, 0.7798540404017251, 0.9725562412423584], 
             186 -> RGBColor[
              0.49061569255320275`, 0.5973429470565916, 0.9530422109837378], 
             122 -> RGBColor[
              0.37416039873600326`, 0.4985006643618478, 0.9450621476437765], 
             249 -> RGBColor[
              0.8926594264208546, 0.9172464123060918, 0.9896238470501402], 
             113 -> RGBColor[
              0.6653845322034085, 0.738522720757829, 0.9672829698642035], 52 -> 
             RGBColor[
              0.621876430825197, 0.703906327614669, 0.9633755371244364], 187 -> 
             RGBColor[
              0.8246326990329209, 0.8630037464232774, 0.9831353970637026], 
             259 -> RGBColor[
              0.565209266842441, 0.6579013710668221, 0.9589144903970525], 42 -> 
             RGBColor[
              0.986177924910682, 0.9885522309865094, 0.8787310848210769], 134 -> 
             RGBColor[
              0.7888254785267855, 0.8349557262115908, 0.9795864097724881], 
             248 -> RGBColor[
              0.8516665907263309, 0.884559837844161, 0.98571391378686], 174 -> 
             RGBColor[
              0.7546972069520076, 0.8082944610729035, 0.9761848226087451], 
             215 -> RGBColor[
              0.6710080376416483, 0.7429158459464061, 0.967843468331641], 83 -> 
             RGBColor[
              0.8184398848959499, 0.8580907255450065, 0.9825380970370043], 95 -> 
             RGBColor[
              0.4234350544011961, 0.5411798944828333, 0.9482018851308954], 
             166 -> RGBColor[
              0.3970193308668429, 0.5182999224502458, 0.9465186985857936], 
             233 -> RGBColor[
              0.962399770496449, 0.9714783909177526, 0.9485315602257745], 295 -> 
             RGBColor[
              0.8754875154029303, 0.9035539965795064, 0.9879859748477047], 
             141 -> RGBColor[
              0.5815395543262257, 0.671159034117226, 0.9602000704475901], 205 -> 
             RGBColor[
              0.9587743225264953, 0.9687745377578874, 0.9546684979706371], 
             224 -> RGBColor[
              0.9393314157086191, 0.9542740496879534, 0.9875802676910541], 
             231 -> RGBColor[0.178927, 0.305394, 0.933501], 68 -> 
             RGBColor[
              0.8179674722793551, 0.8577216732184538, 0.9824910113623291], 10 -> 
             RGBColor[
              0.9102031056071151, 0.9312352658787305, 0.991297178832353], 250 -> 
             RGBColor[
              0.9917583810364443, 0.9908598930056929, 0.7862484850596838], 
             282 -> RGBColor[
              0.8241183077198783, 0.8625935847530374, 0.983086333961062], 232 -> 
             RGBColor[
              0.2616477963014976, 0.3923388017142848, 0.9382118269749187], 
             253 -> RGBColor[
              0.8418333988689596, 0.8767191175719756, 0.98477601516931], 55 -> 
             RGBColor[
              0.5309578041377483, 0.6300944906323417, 0.9562180897856971], 91 -> 
             RGBColor[
              0.7975215921357374, 0.8417491962558152, 0.9804531571072265], 
             105 -> RGBColor[
              0.3731721213186724, 0.4976446681352231, 0.9449991754806436], 36 -> 
             RGBColor[
              0.7416844610643822, 0.7981288050849589, 0.9748878337096908], 
             123 -> RGBColor[
              0.6977720623763797, 0.7638241054833002, 0.9705110561931677], 94 -> 
             RGBColor[
              0.3629908890250427, 0.48882619644609515`, 0.9443504363618037], 
             96 -> RGBColor[
              0.9556544673050266, 0.9664477548420101, 0.9599495990720225], 2 -> 
             RGBColor[
              0.5153662450734531, 0.6174365605922154, 0.9549906651423931], 
             262 -> RGBColor[
              0.7906369552964516, 0.8363708656317872, 0.9797669608476756], 
             272 -> RGBColor[
              0.3391262460738009, 0.46815584219356043`, 0.9428298024156259], 
             97 -> RGBColor[
              0.5729515619551473, 0.6641869150257371, 0.9595239922292862], 
             209 -> RGBColor[
              0.974444930836865, 0.9804616517774949, 0.9281422456504052], 66 -> 
             RGBColor[
              0.9148245629560514, 0.9349202905226545, 0.9917379775599182], 
             139 -> RGBColor[
              0.3629908890250427, 0.48882619644609515`, 0.9443504363618037], 
             56 -> RGBColor[
              0.7679980311891517, 0.8186851660569687, 0.9775105244654342], 
             144 -> RGBColor[
              0.7789566542079507, 0.8272461256478741, 0.9786027775937934], 
             298 -> 
             RGBColor[
              0.5765264241057172, 0.6670891491652744, 0.9598054184729307], 
             204 -> RGBColor[
              0.7046792709480733, 0.7692200693162367, 0.9711995021920602], 
             207 -> RGBColor[
              0.8244158041064084, 0.8628308002963322, 0.9831147094319874], 
             149 -> RGBColor[
              0.6056996585328538, 0.6907732951124579, 0.9621020423521137], 
             219 -> RGBColor[
              0.7327599093012839, 0.7911568774185208, 0.9739983177946231], 9 -> 
             RGBColor[
              0.5380975879115313, 0.6358908887434923, 0.956780159718259], 11 -> 
             RGBColor[
              0.6138265444827234, 0.6973710672386019, 0.9627418205838516], 44 -> 
             RGBColor[
              0.7024941910317783, 0.7675130682784046, 0.9709817138467367], 
             153 -> RGBColor[
              0.3735007326654367, 0.49792929476730385`, 0.9450201143050798], 
             32 -> RGBColor[
              0.563949171867946, 0.6568783691998953, 0.9588152911047803], 162 -> 
             RGBColor[
              0.7984679003493416, 0.8424884594244917, 0.9805474762662054], 90 -> 
             RGBColor[
              0.3105107191580696, 0.443370511037356, 0.9410064463442723], 8 -> 
             RGBColor[
              0.7681067477344625, 0.8187700962484419, 0.9775213603146569], 
             163 -> RGBColor[
              0.8726207397672564, 0.9012681075041716, 0.9877125392283732], 49 -> 
             RGBColor[
              0.8314157369273044, 0.8684123567196, 0.9837823692733584], 76 -> 
             RGBColor[
              0.3026826491840653, 0.43546903385380675`, 0.9405487011409562], 
             82 -> RGBColor[
              0.9927448660231439, 0.9912678298992009, 0.7698998758887629], 67 -> 
             RGBColor[
              0.7471689424884415, 0.8024133236570364, 0.9754344755626481], 
             211 -> RGBColor[
              0.6229218443452652, 0.7047550414056027, 0.963457835906212]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9mHk4FFzYxsmSfR/LzGBWM2NmbHmlLHNH8aZCu0SWIkQLqbSgomQtVNoX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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 9}], {
             RGBColor[
             0.6499003774587848, 0.7248292295289367, 0.9668316354753854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 11}], {
             RGBColor[
             0.687764855744381, 0.7555693187764914, 0.9698124659081817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 20}], {
             RGBColor[
             0.6019382860195654, 0.6855888411488378, 0.9631394937479993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 37}], {
             RGBColor[
             0.7715903567060781, 0.8214915180534768, 0.9778685739007708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 43}], {
             RGBColor[
             0.7783594469066346, 0.8267795827651425, 0.9785432535512177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 75}], {
             RGBColor[
             0.8067032417867752, 0.8491783461737017, 0.9813002639814447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 102}], {
             RGBColor[
             0.8757984537846228, 0.9019281932826579, 0.8970167572342979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 142}], {
             RGBColor[
             0.8079855712538373, 0.850200840882831, 0.981422573710762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 143}], {
             RGBColor[
             0.8544051079672066, 0.8869203372630985, 0.9756506300462298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 174}], {
             RGBColor[
             0.758200186979023, 0.8110310156936422, 0.9765339669206284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 185}], {
             RGBColor[
             0.656295097967514, 0.7300207517167989, 0.9673350512984656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 237}], {
             RGBColor[
             0.8564217413466493, 0.8884243391355529, 0.9722369957570554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 239}], {
             RGBColor[
             0.6757478178172776, 0.7458133460258796, 0.9688664406626997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 283}], {
             RGBColor[
             0.8746951025966294, 0.9014719292115905, 0.9153021418006915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 295}], {
             RGBColor[
             0.8185953412044844, 0.8586607834469437, 0.9824345430401082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 297}], {
             RGBColor[
             0.8365930934215242, 0.8730117025288416, 0.9841511847133526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 32}], {
             RGBColor[
             0.5396577084706995, 0.6371574648960554, 0.9569029781235867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 83}], {
             RGBColor[
             0.6669030649847014, 0.737763643068611, 0.9687643810896986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 155}], {
             RGBColor[
             0.683516417899892, 0.7509981992181882, 0.9703522894646266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 156}], {
             RGBColor[
             0.35985732046825136`, 0.474775029726936, 0.9449696880146043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 178}], {
             RGBColor[
             0.7439678839532696, 0.7982497680755954, 0.9431537436792253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 184}], {
             RGBColor[
             0.6204472204719709, 0.7014719842577706, 0.9641340966632195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 202}], {
             RGBColor[
             0.7081224877831322, 0.77061841142911, 0.9726992383761879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 208}], {
             RGBColor[
             0.6088026414240064, 0.6923751506034221, 0.9629734738484965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 214}], {
             RGBColor[
             0.7269855305456857, 0.7855843567102709, 0.9719004382911267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 268}], {
             RGBColor[
             0.7443020201739496, 0.7984989663218808, 0.9425881382142975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 275}], {
             RGBColor[
             0.6417364964039578, 0.7181033284203286, 0.9662560127285249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 17}], {
             RGBColor[
             0.7542539266974786, 0.8082869952705486, 0.9760811071459428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 30}], {
             RGBColor[
             0.9164007174902626, 0.935501119094289, 0.9684525536995741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 38}], {
             RGBColor[
             0.9283926900952435, 0.9441616693793479, 0.9354780171194371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 55}], {
             RGBColor[
             0.7009237518549366, 0.764991156836375, 0.9718827604274705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 74}], {
             RGBColor[
             0.8033761910364451, 0.8467343052321568, 0.9809275021496635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 90}], {
             RGBColor[
             0.5907002093650973, 0.6716291670388821, 0.964276938706758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[
             0.7843308809742523, 0.8318559642618542, 0.9790292436312058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 144}], {
             RGBColor[
             0.8249231768900378, 0.8635669743441412, 0.9830751043315187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 157}], {
             RGBColor[
             0.6462680588322194, 0.7197592453259812, 0.9678176729380832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 229}], {
             RGBColor[
             0.6959439026681803, 0.7609482909269168, 0.9714907284577003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 252}], {
             RGBColor[
             0.6705169973279616, 0.7403055837026953, 0.9694890293274951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 257}], {
             RGBColor[
             0.6089405640561131, 0.6874280454853565, 0.9654391979783572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 259}], {
             RGBColor[
             0.718049483207283, 0.7788945970536152, 0.9732309607331482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 26}], {
             RGBColor[
             0.6602660154750736, 0.7329211544264859, 0.9678687442619263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 39}], {
             RGBColor[
             0.8675531784782604, 0.8394133149821694, 0.6297299309368257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 52}], {
             RGBColor[
             0.7023444312082712, 0.7670823079297222, 0.9711813112867591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 78}], {
             RGBColor[
             0.8537107532480472, 0.8864902415009099, 0.9858291592467019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 82}], {
             RGBColor[
             0.8877786488072447, 0.9107630590719882, 0.8744434806689224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 107}], {
             RGBColor[
             0.8706080396365583, 0.8993781886551959, 0.9671415196221771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 130}], {
             RGBColor[
             0.7687945385941787, 0.8193074036954562, 0.9775899128797824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 193}], {
             RGBColor[
             0.5609116720389926, 0.6491571171409858, 0.9609047694552597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 199}], {
             RGBColor[
             0.6818743610727876, 0.750463782827586, 0.9695698323813563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 220}], {
             RGBColor[
             0.8889831922111237, 0.9111507041488147, 0.8464514706541393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.7824270583692409, 0.8299572317547226, 0.97894867504782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 228}], {
             RGBColor[
             0.686587405839636, 0.7542900448895606, 0.9699408605298545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 236}], {
             RGBColor[
             0.7314587352186597, 0.7901403903358855, 0.9738686289222303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 266}], {
             RGBColor[
             0.8528109367321484, 0.8857727522360008, 0.9857433339441398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 281}], {
             RGBColor[
             0.7949835474402509, 0.839766456449847, 0.9802001885313565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.9577956358376181, 0.9657194348833125, 0.8530945915431528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[
             0.7003651261969313, 0.7641791079880931, 0.9722514464042826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 191}], {
             RGBColor[
             0.7912169346551383, 0.8376358766943384, 0.9796093073671056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 248}], {
             RGBColor[
             0.8860519547853325, 0.911977793778966, 0.9889936205069845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 21}], {
             RGBColor[
             0.7020103619434263, 0.7634384100833047, 0.9377582052701214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 34}], {
             RGBColor[
             0.8944781383094833, 0.917729399140921, 0.9545224145774276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 46}], {
             RGBColor[
             0.955659661790007, 0.9664516288804034, 0.959940806163889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 50}], {
             RGBColor[
             0.8699256475284238, 0.41641108153437223`, 0.4184678215958688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 101}], {
             RGBColor[
             0.942322203996217, 0.9558291155616718, 0.9590990510374486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 108}], {
             RGBColor[
             0.8785118819309592, 0.9052564383099752, 0.9529310473547652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 114}], {
             RGBColor[
             0.9780282687863016, 0.9831340993530073, 0.9220765891862258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 145}], {
             RGBColor[
             0.6471571679520081, 0.7159273304496317, 0.9342630082537633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 169}], {
             RGBColor[
             0.9839452674006077, 0.9839419791082462, 0.6897005966798979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 187}], {
             RGBColor[
             0.8998858208090962, 0.9219914955131969, 0.9550514309256546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 205}], {
             RGBColor[
             0.9669566325558834, 0.9748768911805019, 0.9408179813791218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 213}], {
             RGBColor[
             0.9499145982035891, 0.9618830846125798, 0.9598232203747581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 219}], {
             RGBColor[
             0.8539494259432776, 0.8860680610108187, 0.9504828912911147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 221}], {
             RGBColor[
             0.871622845159867, 0.8998746704257792, 0.9522444125511317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 231}], {
             RGBColor[
             0.5770329712926358, 0.6431866223015583, 0.9302342323938033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 264}], {
             RGBColor[
             0.7650325512405924, 0.8152661631010294, 0.9425362156687832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 9}], {
             RGBColor[
             0.5162859747956224, 0.6181832386140242, 0.9550630696352032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 11}], {
             RGBColor[
             0.5541504530812186, 0.6489233278615791, 0.9580439000679994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 43}], {
             RGBColor[
             0.6447450442434722, 0.7201335918502302, 0.9667746877110356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.580750266068932, 0.6701403847619511, 0.9603962862878008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 63}], {
             RGBColor[
             0.7069579391429807, 0.7695386562620045, 0.9727621631364123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 106}], {
             RGBColor[
             0.7413320356510298, 0.7949298720749237, 0.8993682926845064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 131}], {
             RGBColor[
             0.7437967313005868, 0.7940831830291003, 0.7228903813594518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 143}], {
             RGBColor[
             0.7207907053040441, 0.7802743463481862, 0.9638820642060475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 151}], {
             RGBColor[
             0.6345710673590436, 0.7121856037830263, 0.9657606407764153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 167}], {
             RGBColor[
             0.592674415979346, 0.6794556212988625, 0.9615847741133545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 174}], {
             RGBColor[
             0.6245857843158606, 0.7043850247787299, 0.9647654010804463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 185}], {
             RGBColor[
             0.5226806953043515, 0.6233747608018865, 0.9555664854582835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[
             0.5633491270644542, 0.6563912257967103, 0.9587680533798129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 283}], {
             RGBColor[
             0.7410806999334669, 0.7948259382966782, 0.9035335759605092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 297}], {
             RGBColor[
             0.7029786907583617, 0.7663657116139293, 0.9723826188731703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 22}], {
             RGBColor[
             0.8686974022422034, 0.8976928798877588, 0.9571964243330248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 47}], {
             RGBColor[
             0.7126240013558007, 0.775426553092941, 0.9719913586713755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 61}], {
             RGBColor[
             0.7996075767387962, 0.843468697712032, 0.9806372080326554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 72}], {
             RGBColor[
             0.8233183661462317, 0.8623750375732882, 0.9828987642932082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 177}], {
             RGBColor[
             0.5671865078245828, 0.6552166306317155, 0.961040250461503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 217}], {
             RGBColor[
             0.7573158035492181, 0.8103401286367156, 0.9764458198453785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 247}], {
             RGBColor[
             0.6168794851156996, 0.6979232868609232, 0.9642991777456807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 267}], {
             RGBColor[
             0.7118035766832292, 0.7747856311032696, 0.9719095864073182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 271}], {
             RGBColor[
             0.6661093409904038, 0.7378903016397416, 0.9681747323350415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 273}], {
             RGBColor[
             0.8784885245035923, 0.9042178470257856, 0.905816400585029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 285}], {
             RGBColor[
             0.6603261406757843, 0.7331952390941283, 0.9677194576217139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.5759620661971274, 0.6666309779910471, 0.9597609901510553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 20}], {
             RGBColor[
             0.4901354964723118, 0.5966505003633934, 0.953088017990873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 37}], {
             RGBColor[
             0.6597875671588245, 0.7325531772680325, 0.9678170981436444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 43}], {
             RGBColor[
             0.6665566573593811, 0.7378412419796982, 0.9684917777940913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 63}], {
             RGBColor[
             0.7287695522588895, 0.7872463063914725, 0.9744792532194682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 75}], {
             RGBColor[
             0.6949004522395217, 0.7602400053882574, 0.9712487882243183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.7631436487669386, 0.8126375222043918, 0.9010853827675621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 131}], {
             RGBColor[
             0.7656083444164956, 0.8117908331585684, 0.7246074714425076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 142}], {
             RGBColor[
             0.6961827817065838, 0.7612625000973866, 0.9713710979536356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 143}], {
             RGBColor[
             0.742602318419953, 0.7979819964776542, 0.9655991542891034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 167}], {
             RGBColor[
             0.6144860290952548, 0.6971632714283305, 0.9633018641964104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 174}], {
             RGBColor[
             0.6463973974317694, 0.722092674908198, 0.966482491163502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 185}], {
             RGBColor[
             0.5444923084202603, 0.6410824109313545, 0.9572835755413392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 237}], {
             RGBColor[
             0.7446189517993956, 0.7994859983501085, 0.962185519999929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 239}], {
             RGBColor[
             0.5639450282700239, 0.6568750052404352, 0.9588149649055733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 282}], {
             RGBColor[
             0.6811079478157047, 0.7492422367482648, 0.9699332468396605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 283}], {
             RGBColor[
             0.7628923130493758, 0.8125335884261462, 0.9052506660435651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 295}], {
             RGBColor[
             0.7067925516572309, 0.7697224426614994, 0.9723830672829818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 297}], {
             RGBColor[
             0.7247903038742706, 0.7840733617433973, 0.9740997089562262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 117}], {
             RGBColor[
             0.7877606045417136, 0.8348530460050374, 0.9792867638509256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.8932676151718449, 0.9177313655072876, 0.9896818566361462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 161}], {
             RGBColor[
             0.8219831767740684, 0.8615879795341352, 0.9826977500229263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 265}], {
             RGBColor[
             0.9417204504407808, 0.9553983189651383, 0.9607413950592776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 269}], {
             RGBColor[
             0.8290244266344662, 0.867088657440559, 0.9833995560047897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 43}], {
             RGBColor[
             0.7044211356449772, 0.7685813312272529, 0.9714726082268876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 63}], {
             RGBColor[
             0.7666340305444856, 0.8179863956390272, 0.9774600836522644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 131}], {
             RGBColor[
             0.8034728227020916, 0.842530922406123, 0.7275883018753039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 139}], {
             RGBColor[
             0.4884087167538831, 0.5930986318423486, 0.9535461284728277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 143}], {
             RGBColor[
             0.780466796705549, 0.8287220857252089, 0.9685799847218997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 172}], {
             RGBColor[
             0.7656748448596422, 0.8172215670103349, 0.9773685956653688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 174}], {
             RGBColor[
             0.6842618757173655, 0.7528327641557526, 0.9694633215962983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 183}], {
             RGBColor[
             0.5630902960148387, 0.6561810950904267, 0.9587476772514578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 185}], {
             RGBColor[
             0.5823567867058563, 0.6718225001789093, 0.9602644059741355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 283}], {
             RGBColor[
             0.8007567913349718, 0.843273677673701, 0.9082314964763614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 248}], {
             RGBColor[
             0.8294106270077437, 0.8669172312495399, 0.9835636027002456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 58}], {
             RGBColor[
             0.8533491588396636, 0.8846639894243837, 0.9071743418180922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 73}], {
             RGBColor[
             0.7655865107541748, 0.8145775069903258, 0.8994700660418722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 95}], {
             RGBColor[
             0.7059209396927153, 0.7653269164649379, 0.8949971637623606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 96}], {
             RGBColor[
             0.9720306461446305, 0.9779608466445262, 0.9008710207329242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 105}], {
             RGBColor[
             0.6807894731514534, 0.7435593032911327, 0.8933958089372347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[
             0.6809537788248357, 0.743701616607173, 0.8934062783494529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 149}], {
             RGBColor[
             0.7970532417585441, 0.8401236167797501, 0.9019472423729697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 171}], {
             RGBColor[
             0.9838303085199713, 0.9867610155238815, 0.8808972701763031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 245}], {
             RGBColor[
             0.8470387212058325, 0.8797342275837325, 0.9065453763691445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 289}], {
             RGBColor[
             0.782991954399135, 0.8287080302476051, 0.9008402863238443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 298}], {
             RGBColor[
             0.7824666245449758, 0.8282815438061584, 0.9007989304333783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 69}], {
             RGBColor[
             0.5010092512949557, 0.605780906267632, 0.9538604300007487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 113}], {
             RGBColor[
             0.5815855754189737, 0.670843674326894, 0.9604448512085159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 135}], {
             RGBColor[
             0.6262419127932732, 0.7057295444844311, 0.9648957775807867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 224}], {
             RGBColor[
             0.718559017171579, 0.7787193387919561, 0.9705935001219412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 249}], {
             RGBColor[
             0.6952230225276967, 0.7602055201010254, 0.9716152898014843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 254}], {
             RGBColor[
             0.6442117869654953, 0.719767746763873, 0.9666868467002518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 288}], {
             RGBColor[
             0.5906625532554913, 0.6779346784003681, 0.9613495595300793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 19}], {
             RGBColor[
             0.6953055465827724, 0.7618972445991199, 0.9702652169497616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 49}], {
             RGBColor[
             0.766827387350932, 0.8178630486671145, 0.9773693259139791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 57}], {
             RGBColor[
             0.642836133967615, 0.7200050730416906, 0.9656527150503202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 89}], {
             RGBColor[
             0.6788633795212078, 0.7490524987255276, 0.968626415397852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 111}], {
             RGBColor[
             0.721961749419471, 0.7827212728497939, 0.9729220581321454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.5091748538960031, 0.6077673238123316, 0.9561597764078948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 115}], {
             RGBColor[
             0.843927009281531, 0.8778165898698065, 0.929508404166441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 146}], {
             RGBColor[
             0.8227201045045303, 0.8622369238188208, 0.9759930317671104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 175}], {
             RGBColor[
             0.7854066818482673, 0.8326776737777755, 0.9791414356090669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 212}], {
             RGBColor[
             0.5827894448508868, 0.6712564657442128, 0.9609256197247817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 242}], {
             RGBColor[
             0.669928595798696, 0.741999954057659, 0.9677855328886207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 243}], {
             RGBColor[
             0.7669114477211245, 0.8179300761245479, 0.9773773436671296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 280}], {
             RGBColor[
             0.7458940396922609, 0.8014173599030401, 0.9753074051665689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 294}], {
             RGBColor[
             0.8103429474384538, 0.8525611750824924, 0.9815198788819259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.6842131581090332, 0.7465298335769475, 0.8938016521137784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 44}], {
             RGBColor[
             0.8454392261172525, 0.8784888380109654, 0.9065740482466711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 53}], {
             RGBColor[
             0.9801311095779894, 0.9840059076737275, 0.887326921907607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 59}], {
             RGBColor[
             0.8722865746887958, 0.8994621907624615, 0.9092499410495457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 94}], {
             RGBColor[
             0.6756875751138847, 0.7391454020948107, 0.8932584095042047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 124}], {
             RGBColor[
             0.6901031853579709, 0.7516314791386001, 0.8941769594417341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 125}], {
             RGBColor[
             0.6601675848728856, 0.7257027666054479, 0.8922694894498366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 150}], {
             RGBColor[
             0.9396205078292602, 0.9526368091784527, 0.915809144617727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 170}], {
             RGBColor[
             0.7521375108206942, 0.8036634967691829, 0.8985991697799554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 192}], {
             RGBColor[
             0.6359747065465486, 0.7024199699111613, 0.8908131852992442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 195}], {
             RGBColor[
             0.8782455044685946, 0.904117351995984, 0.9098438714806312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 200}], {
             RGBColor[
             0.6929168797660118, 0.7540685598144521, 0.8943562455613623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 295}], {
             RGBColor[
             0.9319358883028286, 0.9465093021615163, 0.9150761787471551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 30}], {
             RGBColor[
             0.7997649446156163, 0.8439002913244296, 0.9569862297762729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 38}], {
             RGBColor[
             0.8117569172205973, 0.8525608416094883, 0.924011693196136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[
             0.8118980393667572, 0.8526191992435992, 0.9216729340218592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 48}], {
             RGBColor[
             0.750362780570769, 0.8051843009714581, 0.97570996615471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 55}], {
             RGBColor[
             0.5842879789802904, 0.6733903290665153, 0.9604164365041694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 84}], {
             RGBColor[
             0.6737669774643922, 0.7449985269876819, 0.9681681069013413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 90}], {
             RGBColor[
             0.474064436490451, 0.5800283392690225, 0.952810614783457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 97}], {
             RGBColor[
             0.6052848578889898, 0.6904365412632131, 0.9620693877259638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 134}], {
             RGBColor[
             0.713221816174809, 0.7758209468561399, 0.9721005964975649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 144}], {
             RGBColor[
             0.7082874040153915, 0.7719661465742815, 0.9716087804082175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 158}], {
             RGBColor[
             0.7181910551167084, 0.7797029540851665, 0.9725958837951153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 159}], {
             RGBColor[
             0.6165670014197469, 0.6995958936362556, 0.9629575593925586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 175}], {
             RGBColor[
             0.7530962398724037, 0.8073638872208055, 0.9759706859430878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 235}], {
             RGBColor[
             0.6401367633512229, 0.7187263481233802, 0.9648161614507598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 252}], {
             RGBColor[
             0.5538812244533153, 0.6487047559328358, 0.958022705404194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 253}], {
             RGBColor[
             0.739725776345896, 0.7967026425363324, 0.9746953991959758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 292}], {
             RGBColor[
             0.5858374344892414, 0.6746482468508571, 0.9605384153176766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 24}], {
             RGBColor[
             0.6479996691546335, 0.7207743559694089, 0.9681511543236392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 36}], {
             RGBColor[
             0.813334843530824, 0.854628009141951, 0.9818898543362947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 66}], {
             RGBColor[
             0.8999048944766586, 0.9230237518607989, 0.9903149262614084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 69}], {
             RGBColor[
             0.694608554976319, 0.7597621989191243, 0.9715030012057839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 88}], {
             RGBColor[
             0.7029402490685224, 0.7665262435217164, 0.9721589026847233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 113}], {
             RGBColor[
             0.7751848791003371, 0.824824966978386, 0.9780874224135511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 135}], {
             RGBColor[
             0.8198412164746367, 0.8597108371359233, 0.9825383487858219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.6432274037344792, 0.7166408595235054, 0.9678470697910155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 222}], {
             RGBColor[
             0.7896607549845762, 0.8361336312398853, 0.9795302424369405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.9121583208529425, 0.9327006314434483, 0.9882360713269764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 254}], {
             RGBColor[
             0.8378110906468587, 0.8737490394153652, 0.984329417905287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 258}], {
             RGBColor[
             0.789704754128625, 0.836168003705622, 0.979534627860424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 260}], {
             RGBColor[
             0.9364868246312761, 0.9502140658913834, 0.9188091583143163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 278}], {
             RGBColor[
             0.7996273822167768, 0.8439196361828527, 0.9805236226960194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 288}], {
             RGBColor[
             0.7842618569368547, 0.8319159710518603, 0.9789921307351145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 290}], {
             RGBColor[
             0.774696424313276, 0.8244433823863401, 0.9780387378052463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 48}], {
             RGBColor[
             0.7757397313548454, 0.825081591512919, 0.9781896502158508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 49}], {
             RGBColor[
             0.7598938961591448, 0.8124465526516055, 0.9766782603091408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 57}], {
             RGBColor[
             0.6359026427758279, 0.7145885770261816, 0.964961649445482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 84}], {
             RGBColor[
             0.6991439282484686, 0.7648958175291428, 0.9706477909624821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 89}], {
             RGBColor[
             0.6719298883294207, 0.7436360027100186, 0.9679353497930137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 111}], {
             RGBColor[
             0.7150282582276837, 0.7773047768342849, 0.972230992527307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 112}], {
             RGBColor[
             0.5022413627042159, 0.6023508277968226, 0.9554687108030565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 158}], {
             RGBColor[
             0.7435680059007849, 0.7996002446266275, 0.9750755678562562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 175}], {
             RGBColor[
             0.7784731906564801, 0.8272611777622665, 0.9784503700042286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 177}], {
             RGBColor[
             0.5273191616528441, 0.6240719567993, 0.9570666459766362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 242}], {
             RGBColor[
             0.6629951046069088, 0.73658345804215, 0.9670944672837825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 253}], {
             RGBColor[
             0.7651027271299724, 0.8165999330777933, 0.9771750832571167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 280}], {
             RGBColor[
             0.7389605485004735, 0.7960008638875311, 0.9746163395617305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 33}], {
             RGBColor[
             0.4111077300242159, 0.5305025856968316, 0.9474163989222192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 37}], {
             RGBColor[
             0.6118254757196051, 0.6933127888879336, 0.9641249564162584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 75}], {
             RGBColor[
             0.6469383608003022, 0.7209996170081585, 0.9675566464969323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 124}], {
             RGBColor[
             0.41699775727315375`, 0.5356042312584842, 0.947791706250175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 142}], {
             RGBColor[
             0.6482206902673643, 0.7220221117172877, 0.9676789562262497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 150}], {
             RGBColor[
             0.666515079744443, 0.7366095612983368, 0.9694238914261677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 167}], {
             RGBColor[
             0.5665239376560354, 0.6579228830482315, 0.9596097224690243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 185}], {
             RGBColor[
             0.49653021698104083`, 0.6018420225512556, 0.9535914338139533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 200}], {
             RGBColor[
             0.4198114516811946, 0.5380413119343364, 0.947970992369803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 237}], {
             RGBColor[
             0.6966568603601762, 0.7602456099700096, 0.9584933782725429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 282}], {
             RGBColor[
             0.6331458563764853, 0.7100018483681659, 0.9662411051122746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 283}], {
             RGBColor[
             0.7149302216101563, 0.7732932000460473, 0.901558524316179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 295}], {
             RGBColor[
             0.6588304602180113, 0.7304820542814005, 0.9686909255555958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 297}], {
             RGBColor[
             0.6768282124350511, 0.7448329733632983, 0.9704075672288401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 34}], {
             RGBColor[
             0.621349557667638, 0.700188564621109, 0.9653131550599425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 46}], {
             RGBColor[
             0.682531081148162, 0.7489107943605915, 0.9707315466464039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 50}], {
             RGBColor[
             0.687839927100527, 0.27138385852116426`, 0.4256616485842122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[
             0.6398190222928336, 0.714865771507694, 0.9670880158476982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 101}], {
             RGBColor[
             0.6691936233543718, 0.7382882810418598, 0.9698897915199636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 108}], {
             RGBColor[
             0.605383301289114, 0.6877156037901633, 0.9637217878372802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[
             0.7048996881444562, 0.7655932648331953, 0.9328673296687409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 169}], {
             RGBColor[
             0.7108166867587626, 0.7664011445884343, 0.7004913371624129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 187}], {
             RGBColor[
             0.626757240167251, 0.704450660993385, 0.9658421714081695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 205}], {
             RGBColor[
             0.6938280519140382, 0.75733605666069, 0.9516087218616368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 213}], {
             RGBColor[
             0.676786017561744, 0.7443422500927679, 0.970613960857273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 264}], {
             RGBColor[
             0.49190397059874724`, 0.5977253285812174, 0.9533269561512983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 61}], {
             RGBColor[
             0.9001982312465371, 0.922391481351349, 0.9603122720510233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 72}], {
             RGBColor[
             0.9239090206539724, 0.941297821212605, 0.9625738283115761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 177}], {
             RGBColor[
             0.6677771623323235, 0.7341394142710325, 0.9407153144798709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 217}], {
             RGBColor[
             0.8579064580569589, 0.8892629122760325, 0.9561208838637464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 247}], {
             RGBColor[
             0.7174701396234404, 0.77684607050024, 0.9439742417640486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 267}], {
             RGBColor[
             0.81239423119097, 0.8537084147425864, 0.9515846504256861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 271}], {
             RGBColor[
             0.7666999954981446, 0.8168130852790585, 0.9478497963534094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 273}], {
             RGBColor[
             0.9790791790113331, 0.9831406306651025, 0.8854914646033969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 274}], {
             RGBColor[
             0.8887820989810268, 0.9133831976294765, 0.9591982792017884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 285}], {
             RGBColor[
             0.7609167951835251, 0.8121180227334451, 0.9473945216400818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[
             0.7698445391232706, 0.8207122400426995, 0.9775753891854178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 180}], {
             RGBColor[
             0.827937200571586, 0.8661806005903601, 0.9833067706599516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 267}], {
             RGBColor[
             0.7792200414864361, 0.8281223856489184, 0.9784510995300798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 285}], {
             RGBColor[
             0.7277426054789911, 0.786531993639777, 0.9742609707444755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.5734383974063832, 0.66200114308189, 0.9608590034572315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 113}], {
             RGBColor[
             0.538199322257705, 0.6344721097488517, 0.9573467017742916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 135}], {
             RGBColor[
             0.5828556596320045, 0.6693579799063889, 0.9617976281465624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 224}], {
             RGBColor[
             0.6751727640103102, 0.742347774213914, 0.967495350687717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 233}], {
             RGBColor[
             0.6867069414042252, 0.7509499448288135, 0.9479709969550771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 254}], {
             RGBColor[
             0.6008255338042265, 0.6833961821858308, 0.9635886972660277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 259}], {
             RGBColor[
             0.4881116895772212, 0.5941614349033483, 0.9531624620407162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 260}], {
             RGBColor[
             0.6995012677886439, 0.759861208661849, 0.8980684376750568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 288}], {
             RGBColor[
             0.5472763000942226, 0.6415631138223259, 0.958251410095855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 29}], {
             RGBColor[
             0.8330809952362751, 0.86747948299963, 0.8408796620954189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[
             0.7330118822244396, 0.7913537205811552, 0.9740234321007823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 77}], {
             RGBColor[
             0.5756504855955883, 0.6659391561044106, 0.9600365169565487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 91}], {
             RGBColor[
             0.7342648148886928, 0.7923325211011107, 0.9741483127194337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 139}], {
             RGBColor[
             0.5169994633333455, 0.6158710211962506, 0.9560969523467224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 147}], {
             RGBColor[
             0.7084029569477375, 0.7721290411202362, 0.9715706444126826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 148}], {
             RGBColor[
             0.7081649408453725, 0.7719431011320792, 0.9715469211919858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 172}], {
             RGBColor[
             0.7942655914391046, 0.8399939563642371, 0.9799194195392635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 203}], {
             RGBColor[
             0.6544829842500253, 0.7299389298756758, 0.9662425000235835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 206}], {
             RGBColor[
             0.5135675696176707, 0.6128984873517267, 0.955878275113864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 244}], {
             RGBColor[
             0.8278197563128751, 0.8654142900731621, 0.936101615260137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 270}], {
             RGBColor[
             0.6106846270764271, 0.6943814504286434, 0.962794532908209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 272}], {
             RGBColor[
             0.5050671418577246, 0.6055358440699833, 0.9553366353736334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 39}], {
             RGBColor[
             0.7450067623619886, 0.7420761811638797, 0.6186115897496699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 59}], {
             RGBColor[
             0.6469542437668333, 0.7225218971947964, 0.9665419512636282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 60}], {
             RGBColor[
             0.6444959732334297, 0.7206014775705535, 0.9662969338307028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 62}], {
             RGBColor[
             0.7530018536425533, 0.8057254703732086, 0.9476606574563975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 82}], {
             RGBColor[
             0.7652322326909728, 0.8134259252536986, 0.8633251394817667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[
             0.5480895353083919, 0.6440028017723642, 0.9575667624190491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 127}], {
             RGBColor[
             0.555237554414828, 0.6498058856975603, 0.9581294806671645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 130}], {
             RGBColor[
             0.6462481224779069, 0.7219702698771666, 0.9664715716926267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 137}], {
             RGBColor[
             0.44843769768197383`, 0.5605442261189183, 0.950428235350293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 170}], {
             RGBColor[
             0.5268051798987318, 0.626723203201518, 0.9558911799940379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 192}], {
             RGBColor[
             0.41064237562458616`, 0.5254796763434963, 0.9481051955133268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 195}], {
             RGBColor[
             0.6529131735466321, 0.727177058428319, 0.9671358816947137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 199}], {
             RGBColor[
             0.5593279449565158, 0.6531266490092964, 0.9584514911942006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 220}], {
             RGBColor[
             0.7664367760948518, 0.8138135703305249, 0.8353331294669836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 226}], {
             RGBColor[
             0.659880642252969, 0.7326200979364329, 0.9678303338606643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 228}], {
             RGBColor[
             0.5640409897233642, 0.6569529110712711, 0.9588225193426987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 266}], {
             RGBColor[
             0.7302645206158765, 0.7884356184177113, 0.9746249927569841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 32}], {
             RGBColor[
             0.6009880010525995, 0.6869481593122369, 0.9617311234158981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 103}], {
             RGBColor[
             0.6099776703711992, 0.6942463778450637, 0.9624388231149019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 119}], {
             RGBColor[
             0.5060936144866282, 0.607759306893213, 0.9548545516853961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 152}], {
             RGBColor[
             0.6267595773610769, 0.7078706859557409, 0.9637599563072959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 268}], {
             RGBColor[
             0.8056323127558497, 0.8482896607380622, 0.9474162835066089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 35}], {
             RGBColor[
             0.8892213584244393, 0.9145049902096198, 0.9892959210554426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 126}], {
             RGBColor[
             0.9377702872312974, 0.9523431319095955, 0.9636432828133437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 163}], {
             RGBColor[
             0.8892953376234294, 0.9145639792147828, 0.9893029772574842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 184}], {
             RGBColor[
             0.8157490656750456, 0.8566836294243598, 0.9820854717353205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 189}], {
             RGBColor[
             0.9462349064755085, 0.9582726087847848, 0.9321444564949075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 197}], {
             RGBColor[
             0.8349935340442354, 0.8717175543777477, 0.9840035804925795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 211}], {
             RGBColor[
             0.7644458899124338, 0.8163074461654983, 0.9771756255964037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 216}], {
             RGBColor[
             0.8343897163793916, 0.8712458474287875, 0.9839433975907448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 275}], {
             RGBColor[
             0.8370383416070325, 0.8733149735869179, 0.9842073878006261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 293}], {
             RGBColor[
             0.9038089058211843, 0.9261367045353588, 0.9906872943486014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 77}], {
             RGBColor[
             0.7377234431902151, 0.7905027931576345, 0.8330727107203265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 91}], {
             RGBColor[
             0.8963377724833197, 0.9168961581543345, 0.8471845064832115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 148}], {
             RGBColor[
             0.8702378984399993, 0.8965067381853031, 0.8445831149557637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 162}], {
             RGBColor[
             0.8968109265901217, 0.9172657897386727, 0.8472316660627011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 172}], {
             RGBColor[
             0.9563385490337314, 0.9645575934174608, 0.8529556133030414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 191}], {
             RGBColor[
             0.8285752516484222, 0.8639595618638797, 0.8404305716831495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 203}], {
             RGBColor[
             0.8165559418446521, 0.8545025669288997, 0.8392786937873613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 206}], {
             RGBColor[
             0.6756405272122975, 0.7374621244049505, 0.8289144688776419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 244}], {
             RGBColor[
             0.9898927139075018, 0.9899779271263859, 0.8091378090239149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 270}], {
             RGBColor[
             0.7727575846710539, 0.8189450874818672, 0.8358307266719869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 272}], {
             RGBColor[
             0.6671400994523514, 0.7300994811232071, 0.8283728291374113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 38}], {
             RGBColor[
             0.9739037080133812, 0.9797749654332288, 0.9163831397497673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 47}], {
             RGBColor[
             0.8095264951927696, 0.851598712542805, 0.9579095166789993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 48}], {
             RGBColor[
             0.9125095713635529, 0.9323984247951986, 0.9680814127083412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 74}], {
             RGBColor[
             0.8488872089545828, 0.8823476012860376, 0.9618326247799938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 90}], {
             RGBColor[
             0.636211227283235, 0.707242463092763, 0.9451820613370883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 123}], {
             RGBColor[
             0.82984189889239, 0.867469260315735, 0.9599343662615359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 144}], {
             RGBColor[
             0.8704341948081755, 0.8991802703980221, 0.9639802269618488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 158}], {
             RGBColor[
             0.8803378459094924, 0.9069170779089071, 0.9649673303487466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 252}], {
             RGBColor[
             0.7160280152460993, 0.7759188797565763, 0.9503941519578253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 257}], {
             RGBColor[
             0.6544515819742508, 0.7230413415392374, 0.9463443206086875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 259}], {
             RGBColor[
             0.7635605011254207, 0.814507893107496, 0.9541360833634783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 36}], {
             RGBColor[
             0.8434654262415406, 0.878407116986303, 0.9762277951981594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 51}], {
             RGBColor[
             0.7083172247995053, 0.7702092580826341, 0.9645481489296932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 58}], {
             RGBColor[
             0.8317689420568959, 0.8692697346446862, 0.9750619989644932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 66}], {
             RGBColor[
             0.9300354771873753, 0.9468028597051508, 0.984652867123273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 67}], {
             RGBColor[
             0.8462076669535703, 0.8805493762723418, 0.976501116124638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 73}], {
             RGBColor[
             0.7440062939714072, 0.7991832522106282, 0.9673577231882733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 95}], {
             RGBColor[
             0.6843407229099476, 0.7499326616852402, 0.9628848209087617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 96}], {
             RGBColor[
             0.9504504293618629, 0.9625665918648286, 0.9687586778793252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 109}], {
             RGBColor[
             0.9662728886476, 0.9738507064018773, 0.918856665528071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 110}], {
             RGBColor[
             0.8466649854540701, 0.8809066369606816, 0.9765466973588834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 138}], {
             RGBColor[
             0.8969261100627268, 0.9204023490897849, 0.9814948661298432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 154}], {
             RGBColor[
             0.8237427145966294, 0.862999584751138, 0.974262019620614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 171}], {
             RGBColor[
             0.9622500917372037, 0.9713667607441839, 0.9487849273227041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 245}], {
             RGBColor[
             0.8254585044230648, 0.8643399728040351, 0.9744330335155454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 156}], {
             RGBColor[
             0.38414878386549783`, 0.49449593403077596`, 0.946882000995798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 178}], {
             RGBColor[
             0.7682593473505162, 0.8179706723794353, 0.945066056660419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 182}], {
             RGBColor[
             0.6813503908318655, 0.7497942323001101, 0.9696955224385959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 202}], {
             RGBColor[
             0.7324139511803787, 0.7903393157329499, 0.9746115513573815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 208}], {
             RGBColor[
             0.6330941048212528, 0.7120960549072621, 0.9648857868296901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 268}], {
             RGBColor[
             0.7685934835711962, 0.8182198706257207, 0.9445004511954911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 37}], {
             RGBColor[
             0.5807598007107286, 0.6664052626014707, 0.9621454790749906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 75}], {
             RGBColor[
             0.6158726857914258, 0.6940920907216956, 0.9655771691556645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 94}], {
             RGBColor[
             0.3715164720201911, 0.49621062792823195`, 0.9448936789713775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 124}], {
             RGBColor[
             0.38593208226427733`, 0.5086967049720214, 0.9458122289089071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 142}], {
             RGBColor[
             0.6171550152584879, 0.6951145854308248, 0.9656994788849819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 150}], {
             RGBColor[
             0.6354494047355665, 0.7097020350118739, 0.9674444140848999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 185}], {
             RGBColor[
             0.4654645419721644, 0.5749344962647928, 0.9516119564726855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 200}], {
             RGBColor[
             0.3887457766723182, 0.5111337856478735, 0.9459915150285352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 237}], {
             RGBColor[
             0.6655911853512997, 0.7333380836835467, 0.9565139009312751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 239}], {
             RGBColor[
             0.484917261821928, 0.5907270905738734, 0.9531433458369195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 282}], {
             RGBColor[
             0.6020801813676089, 0.6830943220817031, 0.9642616277710068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 295}], {
             RGBColor[
             0.6277647852091349, 0.7035745279949376, 0.966711448214328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 297}], {
             RGBColor[
             0.6457625374261746, 0.7179254470768355, 0.9684280898875723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 46}], {
             RGBColor[
             0.8749988575142189, 0.9032017834182078, 0.9874957559537101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 50}], {
             RGBColor[
             0.8161517780112317, 0.37424451789290847`, 0.43683778812241625`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 87}], {
             RGBColor[
             0.8322867986588907, 0.8691567605653103, 0.9838522251550043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 108}], {
             RGBColor[
             0.797851077655171, 0.8420065928477796, 0.9804859971445863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 114}], {
             RGBColor[
             0.8973674645105133, 0.9198842538908116, 0.9496315389760469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 169}], {
             RGBColor[
             0.9032844631248196, 0.9206921336460506, 0.717255546469719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 187}], {
             RGBColor[
             0.8192250165333079, 0.8587416500510013, 0.9826063807154757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 205}], {
             RGBColor[
             0.8862958282800952, 0.9116270457183063, 0.9683729311689429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 213}], {
             RGBColor[
             0.8692537939278009, 0.8986332391503842, 0.9873781701645792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 227}], {
             RGBColor[
             0.7547870976617821, 0.8083646843785739, 0.9761937820746189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 264}], {
             RGBColor[
             0.6843717469648043, 0.7520163176388337, 0.9700911654586043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 92}], {
             RGBColor[
             0.918348151396651, 0.9369943354336336, 0.9665714262200491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 126}], {
             RGBColor[
             0.9210217101761342, 0.9389882711938214, 0.9620457885821909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 163}], {
             RGBColor[
             0.8725467605682662, 0.9012091184990088, 0.9877054830263315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 184}], {
             RGBColor[
             0.7990004886198824, 0.8433287687085858, 0.9804879775041678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 189}], {
             RGBColor[
             0.9294863294203453, 0.9449177480690107, 0.9305469622637549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 197}], {
             RGBColor[
             0.8182449569890722, 0.8583626936619736, 0.9824060862614268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 211}], {
             RGBColor[
             0.7476973128572706, 0.8029525854497243, 0.975578131365251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 216}], {
             RGBColor[
             0.8176411393242284, 0.8578909867130134, 0.9823459033595922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 275}], {
             RGBColor[
             0.8202897645518693, 0.8599601128711438, 0.9826098935694734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 58}], {
             RGBColor[
             0.7299879768797374, 0.788991422743342, 0.9737220374760246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 66}], {
             RGBColor[
             0.8282545120102168, 0.8665245478038066, 0.9833129056348044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 67}], {
             RGBColor[
             0.7444267017764119, 0.8002710643709976, 0.9751611546361694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 69}], {
             RGBColor[
             0.6229581725098774, 0.7032629948621321, 0.96450098057918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 88}], {
             RGBColor[
             0.6312898666020806, 0.7100270394647242, 0.9651568820581193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 95}], {
             RGBColor[
             0.5825597577327892, 0.669654349783896, 0.9615448594202931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 96}], {
             RGBColor[
             0.8486694641847043, 0.8822882799634845, 0.9674187163908566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 109}], {
             RGBColor[
             0.8644919234704416, 0.8935723945005332, 0.9175167040396024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 113}], {
             RGBColor[
             0.7035344966338954, 0.768325762921394, 0.9710854017869471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 138}], {
             RGBColor[
             0.7951451448855684, 0.8401240371884408, 0.9801549046413746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 154}], {
             RGBColor[
             0.721961749419471, 0.7827212728497939, 0.9729220581321454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 198}], {
             RGBColor[
             0.5715770212680374, 0.6601416554665132, 0.9608450491644116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 222}], {
             RGBColor[
             0.7180103725181345, 0.779634427182893, 0.9725282218103366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 224}], {
             RGBColor[
             0.8405079383865006, 0.8762014273864561, 0.9812340507003725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 245}], {
             RGBColor[
             0.7236775392459063, 0.7840616609026909, 0.9730930720270768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 258}], {
             RGBColor[
             0.7180543716621832, 0.7796687996486298, 0.9725326072338201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 260}], {
             RGBColor[
             0.8648364421648344, 0.8937148618343913, 0.9118071376877124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 278}], {
             RGBColor[
             0.727976999750335, 0.7874204321258607, 0.9735216020694155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 290}], {
             RGBColor[
             0.7030460418468343, 0.7679441783293479, 0.9710367171786424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 75}], {
             RGBColor[
             0.8165904314868149, 0.8569022939127975, 0.9822857266497036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 94}], {
             RGBColor[
             0.5722342177155803, 0.6590208311193338, 0.9616022364654166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 102}], {
             RGBColor[
             0.8856856434846625, 0.9096521410217537, 0.8980022199025568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 124}], {
             RGBColor[
             0.5866498279596665, 0.6715069081631233, 0.9625207864029464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 142}], {
             RGBColor[
             0.817872760953877, 0.8579247886219268, 0.9824080363790211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 150}], {
             RGBColor[
             0.8361671504309558, 0.8725122382029759, 0.984152971578939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 185}], {
             RGBColor[
             0.6661822876675536, 0.7377446994558947, 0.9683205139667246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 237}], {
             RGBColor[
             0.8663089310466889, 0.8961482868746486, 0.9732224584253142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 239}], {
             RGBColor[
             0.6856350075173172, 0.7535372937649754, 0.9698519033309587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 282}], {
             RGBColor[
             0.802797927062998, 0.845904525272805, 0.9809701852650459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 283}], {
             RGBColor[
             0.8845822922966691, 0.9091958769506863, 0.9162876044689504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 295}], {
             RGBColor[
             0.8284825309045241, 0.8663847311860395, 0.9834200057083672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 297}], {
             RGBColor[
             0.8464802831215639, 0.8807356502679374, 0.9851366473816114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 48}], {
             RGBColor[
             0.9245015439685339, 0.9410589750802574, 0.9351068761282044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 55}], {
             RGBColor[
             0.7584267423780553, 0.8092650031753146, 0.9198133464776638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 74}], {
             RGBColor[
             0.8608791815595638, 0.8910081515710965, 0.9288580881998569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 90}], {
             RGBColor[
             0.6482031998882158, 0.7159030133778218, 0.9122075247569514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 123}], {
             RGBColor[
             0.841833871497371, 0.8761298106007939, 0.926959829681399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 144}], {
             RGBColor[
             0.8824261674131564, 0.9078408206830808, 0.9310056903817119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 158}], {
             RGBColor[
             0.8923298185144733, 0.9155776281939658, 0.9319927937686097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 252}], {
             RGBColor[
             0.7280199878510802, 0.7845794300416351, 0.9174196153776883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 253}], {
             RGBColor[
             0.9138645397436609, 0.9325773166451317, 0.9340923091694702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 257}], {
             RGBColor[
             0.6664435545792318, 0.7317018918242961, 0.9133697840285506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 259}], {
             RGBColor[
             0.7755524737304016, 0.8231684433925548, 0.9211615467833414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 52}], {
             RGBColor[
             0.7870851780951862, 0.7762373346671161, 0.6219241567745029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 59}], {
             RGBColor[
             0.8542414067700201, 0.8290140577504801, 0.6284031379385278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 60}], {
             RGBColor[
             0.8517831362366165, 0.827093638126237, 0.6281581205056022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 62}], {
             RGBColor[
             0.9602890166457403, 0.9122176309288921, 0.6095218441312971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 82}], {
             RGBColor[
             0.9725193956941597, 0.9199180858093821, 0.5251863261566662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 100}], {
             RGBColor[
             0.7553766983115787, 0.7504949623280479, 0.6194279490939487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 107}], {
             RGBColor[
             0.9553487865234733, 0.9085332153925898, 0.6178843651099208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 127}], {
             RGBColor[
             0.7625247174180149, 0.7562980462532438, 0.6199906673420641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 136}], {
             RGBColor[
             0.7626227436601614, 0.7563776283726502, 0.6199983843269279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 137}], {
             RGBColor[
             0.6557248606851607, 0.6670363866746019, 0.6122894220251924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 141}], {
             RGBColor[
             0.7669167398457006, 0.7598636879183946, 0.6203364234360798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 170}], {
             RGBColor[
             0.7340923429019186, 0.7332153637572014, 0.6177523666689373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 192}], {
             RGBColor[
             0.617929538627773, 0.6319718368991799, 0.6099663821882262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 220}], {
             RGBColor[
             0.9737239390980387, 0.9203057308862086, 0.49719431614188303`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 228}], {
             RGBColor[
             0.771328152726551, 0.7634450716269545, 0.6206837060175983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 232}], {
             RGBColor[
             0.6069708608333365, 0.6204535717169241, 0.6093423016997441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 266}], {
             RGBColor[
             0.9375516836190634, 0.8949277789733947, 0.6364861794318835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 281}], {
             RGBColor[
             0.8797242943271659, 0.8489214831872409, 0.6309430340191002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.8460344614644901, 0.8784826188846309, 0.8852661919884659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.7546988004393522, 0.808295705917328, 0.9761849814326715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 162}], {
             RGBColor[
             0.7497946800079682, 0.8044645697636352, 0.9756961845396823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 191}], {
             RGBColor[
             0.6815590050662688, 0.7511583418888421, 0.9688950901601308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 76}], {
             RGBColor[
             0.5697064201510208, 0.6540594960440163, 0.9624189838996451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.6788127316288777, 0.7472876160393577, 0.9698575985324408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 99}], {
             RGBColor[
             0.6651325330489726, 0.736181414546268, 0.968780643188012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 104}], {
             RGBColor[
             0.7859107944202717, 0.8328141060637106, 0.9792599827148962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 157}], {
             RGBColor[
             0.6291883046051451, 0.70614031292289, 0.9661885907326282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 201}], {
             RGBColor[
             0.9150530580164992, 0.9304450281806054, 0.7523388782951843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 209}], {
             RGBColor[
             0.9055875609774207, 0.9265558050058603, 0.9562157561543695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 222}], {
             RGBColor[
             0.7655332375449315, 0.8168950037575264, 0.9772289382846582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 229}], {
             RGBColor[
             0.678864148441106, 0.7473293585238256, 0.9698616462522454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 259}], {
             RGBColor[
             0.7009697289802086, 0.7652756646505239, 0.9716018785276932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 261}], {
             RGBColor[
             0.8611550632732459, 0.892125688295345, 0.9866189327688442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 278}], {
             RGBColor[
             0.7754998647771321, 0.8246810087004941, 0.9782223185437371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 290}], {
             RGBColor[
             0.7505689068736313, 0.8052047549039814, 0.9757374336529638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 55}], {
             RGBColor[
             0.7585678645242151, 0.8093233608094255, 0.9174745873033869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[
             0.7795647434329147, 0.8263695730061232, 0.9191275385251816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 134}], {
             RGBColor[
             0.8875017017187338, 0.91175397859905, 0.9291587472967825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 144}], {
             RGBColor[
             0.8825672895593164, 0.9078991783171917, 0.9286669312074352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 159}], {
             RGBColor[
             0.7908468869636716, 0.8355289253791658, 0.9200157101917763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 235}], {
             RGBColor[
             0.8144166488951478, 0.8546593798662904, 0.9218743122499773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 252}], {
             RGBColor[
             0.72816110999724, 0.784637787675746, 0.9150808562034116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 292}], {
             RGBColor[
             0.7601173200331663, 0.8105812785937673, 0.9175965661168941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 63}], {
             RGBColor[
             0.8572286217067393, 0.8891966596276784, 0.9861908712953005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 131}], {
             RGBColor[
             0.8940674138643454, 0.9137411863947742, 0.73631908951834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 139}], {
             RGBColor[
             0.5790033079161367, 0.6643088958309996, 0.9622769161158637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 143}], {
             RGBColor[
             0.8710613878678027, 0.89993234971386, 0.9773107723649357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 172}], {
             RGBColor[
             0.8562694360218959, 0.888431830998986, 0.9860993833084049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 174}], {
             RGBColor[
             0.7748564668796192, 0.8240430281444038, 0.9781941092393345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 183}], {
             RGBColor[
             0.6536848871770925, 0.7273913590790777, 0.9674784648944939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 185}], {
             RGBColor[
             0.6729513778681101, 0.7430327641675605, 0.9689951936171717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 244}], {
             RGBColor[
             0.8898236008956664, 0.913852164707911, 0.9422815790292784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 59}], {
             RGBColor[
             0.7293415396033216, 0.7884864210299007, 0.9736576066496113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 60}], {
             RGBColor[
             0.726883269069918, 0.7865660014056577, 0.9734125892166858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 94}], {
             RGBColor[
             0.5327425400284105, 0.6281696323622499, 0.9576660751042703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 100}], {
             RGBColor[
             0.6304768311448802, 0.7099673256074686, 0.9646824178050324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 121}], {
             RGBColor[
             0.8476667304632493, 0.8773026577905546, 0.71647930833489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 124}], {
             RGBColor[
             0.5471581502724967, 0.6406557094060392, 0.9585846250417998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 125}], {
             RGBColor[
             0.5172225497874114, 0.6147269968728871, 0.9566771550499023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 137}], {
             RGBColor[
             0.5308249935184621, 0.6265087499540225, 0.9575438907362761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 150}], {
             RGBColor[
             0.796675472743786, 0.8416610394458919, 0.9802168102177926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 170}], {
             RGBColor[
             0.6091924757352201, 0.6926877270366221, 0.963006835380021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 192}], {
             RGBColor[
             0.49302967146107446`, 0.5914442001786006, 0.9552208508993099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 195}], {
             RGBColor[
             0.7353004693831204, 0.7931415822634232, 0.9742515370806968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 200}], {
             RGBColor[
             0.5499718446805376, 0.6430927900818914, 0.9587639111614279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 256}], {
             RGBColor[
             0.46083067991985793`, 0.5576010185348048, 0.9533871659651769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 299}], {
             RGBColor[
             0.8470904341549681, 0.8755662100279704, 0.6965932271109954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 53}], {
             RGBColor[
             0.8280729243222475, 0.8659108757656471, 0.9508262738659305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 68}], {
             RGBColor[
             0.7511176814852989, 0.8054981085729095, 0.9758280489627909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 195}], {
             RGBColor[
             0.7261873192128527, 0.7860223200879035, 0.9733432234389547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 200}], {
             RGBColor[
             0.5408586945102698, 0.6359735279063716, 0.9578555975196859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 215}], {
             RGBColor[
             0.6776379641664456, 0.7480951949368857, 0.9685042774474468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 223}], {
             RGBColor[
             0.524139434290585, 0.621492145038533, 0.9567902610427489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 225}], {
             RGBColor[
             0.43279174093328976`, 0.5305895523490358, 0.951401056648542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 234}], {
             RGBColor[
             0.7092990353209829, 0.7728290643558633, 0.9716599571305993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 255}], {
             RGBColor[
             0.5819988731260486, 0.6708899390561003, 0.9606751622914089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 282}], {
             RGBColor[
             0.7541930992055605, 0.8079340643402013, 0.9761257102621574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 287}], {
             RGBColor[
             0.6120084642945525, 0.6952530770833675, 0.9630376272369482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 50}], {
             RGBColor[
             0.856939460331581, 0.4067260043858968, 0.44045004918005715`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 108}], {
             RGBColor[
             0.8590326011356948, 0.8907288225872619, 0.9859043887310477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 114}], {
             RGBColor[
             0.9585489879910372, 0.9686064836302941, 0.9550499305625083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 145}], {
             RGBColor[
             0.6276778871567438, 0.7013997147269185, 0.9672363496300458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 169}], {
             RGBColor[
             0.9644659866053434, 0.969414363385533, 0.7226739380561804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 187}], {
             RGBColor[
             0.8804065400138319, 0.9074638797904837, 0.9880247723019371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 213}], {
             RGBColor[
             0.9304353174083249, 0.9473554688898665, 0.9927965617510406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 219}], {
             RGBColor[
             0.8344701451480133, 0.8715404452881055, 0.9834562326673972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 221}], {
             RGBColor[
             0.8521435643646027, 0.885347054703066, 0.9852177539274142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 264}], {
             RGBColor[
             0.745553270445328, 0.8007385473783162, 0.9755095570450657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 48}], {
             RGBColor[
             0.7601243311479222, 0.8128827221898336, 0.9766332530574363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 74}], {
             RGBColor[
             0.6965019687389521, 0.7628318986806726, 0.9703844651290888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 90}], {
             RGBColor[
             0.48382598706760427`, 0.5877267604873979, 0.9537339016861833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.7279526056938617, 0.787401375303542, 0.9735191706978417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 166}], {
             RGBColor[
             0.5270802929219909, 0.6251914661938429, 0.9564900278069439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 177}], {
             RGBColor[
             0.511703761445921, 0.6118730874762146, 0.9555102488182217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 217}], {
             RGBColor[
             0.7018330571705563, 0.7669965854812146, 0.9709158182020972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 233}], {
             RGBColor[
             0.809770512736794, 0.8517807004275962, 0.9574964586269343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 262}], {
             RGBColor[
             0.7238891051367953, 0.7842269377846136, 0.9731141589378849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 273}], {
             RGBColor[
             0.8230057781249305, 0.8608743038702846, 0.9002863989417478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 74}], {
             RGBColor[
             0.7994850449097355, 0.8436316109330664, 0.9805563611584308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 84}], {
             RGBColor[
             0.7865116042123288, 0.833496660458451, 0.9792632898334096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 90}], {
             RGBColor[
             0.5868090632383876, 0.6685264727397916, 0.9639057977155253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 144}], {
             RGBColor[
             0.8210320307633281, 0.8604642800450507, 0.9827039633402859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 158}], {
             RGBColor[
             0.8309356818646451, 0.8682010875559356, 0.9836910667271836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 175}], {
             RGBColor[
             0.8658408666203403, 0.8958620206915746, 0.9870658688751561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 177}], {
             RGBColor[
             0.6146868376167043, 0.6926727997286082, 0.9656821448475637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 217}], {
             RGBColor[
             0.8048161333413397, 0.8477962977336082, 0.9810877142314391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 252}], {
             RGBColor[
             0.666625851201252, 0.7372028894036049, 0.9691178883362623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 253}], {
             RGBColor[
             0.8524704030938326, 0.8852007760071015, 0.9857905821280442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 57}], {
             RGBColor[
             0.7074244835439873, 0.7705543810941762, 0.9720657584096996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 84}], {
             RGBColor[
             0.7706657690166281, 0.8208616215971374, 0.9777518999266996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 112}], {
             RGBColor[
             0.5737632034723755, 0.6583166318648173, 0.962572819767274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 115}], {
             RGBColor[
             0.9085153588579034, 0.928365897922292, 0.9359214475258203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 146}], {
             RGBColor[
             0.8873084540809026, 0.9127862318713065, 0.9824060751264896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 159}], {
             RGBColor[
             0.7134657929719828, 0.775458988245711, 0.972541352417917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 175}], {
             RGBColor[
             0.8499950314246397, 0.8832269818302609, 0.9855544789684462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 204}], {
             RGBColor[
             0.7680475039376888, 0.8188162130179184, 0.9774909357327093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 242}], {
             RGBColor[
             0.7345169453750684, 0.7925492621101445, 0.974198576248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 243}], {
             RGBColor[
             0.8314997972974969, 0.8684793841770335, 0.9837903870265089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 253}], {
             RGBColor[
             0.836624567898132, 0.8725657371457878, 0.9842791922213342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 280}], {
             RGBColor[
             0.8104823892686333, 0.8519666679555257, 0.9817204485259481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 292}], {
             RGBColor[
             0.6827362260414775, 0.7505113414603126, 0.970122208343035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 87}], {
             RGBColor[
             0.8284647544280287, 0.38402932248396504`, 0.43802102864758663`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 108}], {
             RGBColor[
             0.8055076070922157, 0.3659292106722779, 0.43577687664064135`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 114}], {
             RGBColor[
             0.8718518649957772, 0.4178476513676327, 0.41520723786161506`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 169}], {
             RGBColor[
             0.875796530738648, 0.4183862378711253, 0.26028990952406306`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 187}], {
             RGBColor[
             0.8197568996776403, 0.37708591547442577`, 0.4371904656879009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 205}], {
             RGBColor[
             0.8644707741754984, 0.41234284591929576`, 0.42770149932354573`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 213}], {
             RGBColor[
             0.8531094179406357, 0.4036803082073476, 0.4403716586539699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 227}], {
             RGBColor[
             0.776798287096623, 0.34350127169280753`, 0.43291539992732975`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 264}], {
             RGBColor[
             0.7298547199653045, 0.30593569386631403`, 0.4288469888499866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 52}], {
             RGBColor[
             0.5466322445027542, 0.642819707446145, 0.9574520391485973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 58}], {
             RGBColor[
             0.594839775437702, 0.680793563839673, 0.9620423912075584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 66}], {
             RGBColor[
             0.6931063105681814, 0.7583266889001377, 0.9716332593663383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 67}], {
             RGBColor[
             0.6092785003343764, 0.6920732054673286, 0.9634815083677032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 69}], {
             RGBColor[
             0.4878099710678419, 0.5950651359584631, 0.9528213343107137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 86}], {
             RGBColor[
             0.6397629760504152, 0.7158879095872948, 0.9665199160134554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[
             0.7148958529310412, 0.7751155881716187, 0.9534122474840152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 109}], {
             RGBColor[
             0.729343722028406, 0.7853745355968642, 0.9058370577711362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 110}], {
             RGBColor[
             0.6097358188348763, 0.6924304661556685, 0.9635270896019487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 138}], {
             RGBColor[
             0.659996943443533, 0.7319261782847718, 0.9684752583729084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 141}], {
             RGBColor[
             0.5264638062532685, 0.6264460606974235, 0.9558643058101742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 154}], {
             RGBColor[
             0.5868135479774355, 0.6745234139461249, 0.9612424118636791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 165}], {
             RGBColor[
             0.6561003681483439, 0.7288191549141068, 0.9681035995427394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 179}], {
             RGBColor[
             0.7089079037778958, 0.7706497854975698, 0.9635482834930287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 258}], {
             RGBColor[
             0.5829061702201478, 0.6714709407449608, 0.9608529609653538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 281}], {
             RGBColor[
             0.639271360734734, 0.7155038559662699, 0.9664709163931947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 82}], {
             RGBColor[
             0.8073106484241704, 0.847587078756935, 0.8666377065065995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 86}], {
             RGBColor[
             0.715007162372858, 0.7769745297558188, 0.9724434139892946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 107}], {
             RGBColor[
             0.7901400392534841, 0.8362022083401427, 0.9593357454598542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 110}], {
             RGBColor[
             0.6849800051573189, 0.7535170863241925, 0.9694505875777877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 141}], {
             RGBColor[
             0.6017079925757114, 0.6875326808659474, 0.9617878037860133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 165}], {
             RGBColor[
             0.7313445544707868, 0.7899057750826308, 0.9740270975185784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 179}], {
             RGBColor[
             0.7841520901003387, 0.8317364056660937, 0.9694717814688677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 193}], {
             RGBColor[
             0.48044367165591834`, 0.5859811368259326, 0.9530989952929368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 236}], {
             RGBColor[
             0.6509907348355854, 0.7269644100208321, 0.9660628547599075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 266}], {
             RGBColor[
             0.7723429363490741, 0.8225967719209476, 0.977937559781817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 281}], {
             RGBColor[
             0.7145155470571767, 0.7765904761347938, 0.9723944143690337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 59}], {
             RGBColor[
             0.8640334230640585, 0.8940034906926628, 0.9544104803105472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 68}], {
             RGBColor[
             0.8949227151163037, 0.9181344404111913, 0.9574892362654688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 150}], {
             RGBColor[
             0.931367356204523, 0.947178109108654, 0.9609696838787285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 170}], {
             RGBColor[
             0.743884359195957, 0.7982047966993843, 0.9437597090409569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 192}], {
             RGBColor[
             0.6277215549218114, 0.6969612698413626, 0.9359737245602457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 195}], {
             RGBColor[
             0.8699923528438573, 0.8986586519261854, 0.9550044107416327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 200}], {
             RGBColor[
             0.6846637281412746, 0.7486098597446535, 0.9395167848223638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 225}], {
             RGBColor[
             0.5765967745642945, 0.6432258841873177, 0.93306224395122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 234}], {
             RGBColor[
             0.8531040689519875, 0.8854653961941452, 0.9533211444332771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 255}], {
             RGBColor[
             0.7258039067570534, 0.7835262708943821, 0.9423363495940869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 282}], {
             RGBColor[
             0.8979981328365653, 0.9205703961784831, 0.9577868975648353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 287}], {
             RGBColor[
             0.7558134979255573, 0.8078894089216493, 0.944698814539626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 72}], {
             RGBColor[
             0.7727780775080755, 0.8228925799687402, 0.977861380647607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 106}], {
             RGBColor[
             0.8276079400402481, 0.8645946683523187, 0.9064185994201598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 151}], {
             RGBColor[
             0.720846971748262, 0.7818504000604212, 0.9728109475120688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 167}], {
             RGBColor[
             0.6789503203685643, 0.7491204175762574, 0.9686350808490081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 194}], {
             RGBColor[
             0.6496250314536725, 0.7260560220741052, 0.9658183601154664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 238}], {
             RGBColor[
             0.7038738196774508, 0.76859084466197, 0.9711192223367746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 251}], {
             RGBColor[
             0.7080255672568302, 0.7718342214254315, 0.9715330297352001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 286}], {
             RGBColor[
             0.5989919872979492, 0.6849498358358439, 0.9618323414045757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 90}], {
             RGBColor[
             0.42073426164790895`, 0.5367325008348488, 0.9486122680649847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 97}], {
             RGBColor[
             0.5519546830464478, 0.6471407028290395, 0.9578710410074917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 134}], {
             RGBColor[
             0.6598916413322669, 0.7325251084219662, 0.9679022497790926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 144}], {
             RGBColor[
             0.6549572291728495, 0.7286703081401079, 0.9674104336897453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 159}], {
             RGBColor[
             0.5632368265772048, 0.6563000552020819, 0.9587592126740864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 235}], {
             RGBColor[
             0.5868065885086808, 0.6754305096892066, 0.9606178147322875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 252}], {
             RGBColor[
             0.5005510496107732, 0.6054089174986621, 0.9538243586857218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 253}], {
             RGBColor[
             0.6863956015033539, 0.7534068041021587, 0.9704970524775036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 292}], {
             RGBColor[
             0.5325072596466994, 0.6313524084166835, 0.9563400685992043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 79}], {
             RGBColor[
             0.8390710442648713, 0.8749366742253977, 0.9844010356107066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 93}], {
             RGBColor[
             0.7827598116624446, 0.830217181156392, 0.9789818407863303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 160}], {
             RGBColor[
             0.6869139436879084, 0.754782080745064, 0.9698114082268928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 164}], {
             RGBColor[
             0.7070718807686451, 0.7710891942925757, 0.9714379751787647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 168}], {
             RGBColor[
             0.7951525358810481, 0.8399172477762891, 0.9802120490745423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 246}], {
             RGBColor[
             0.6614569298826466, 0.7341149301125497, 0.9678073388480284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 296}], {
             RGBColor[
             0.7058763578137802, 0.7701552426739242, 0.971318816623421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.6466745156333111, 0.7230036459717135, 0.9660352890630408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 89}], {
             RGBColor[
             0.6194604757142632, 0.7017438311525894, 0.9633228478935725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 112}], {
             RGBColor[
             0.44977195008905857`, 0.5604586562393934, 0.9508562089036152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 115}], {
             RGBColor[
             0.7845241054745864, 0.8305079222968681, 0.9242048366621615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 134}], {
             RGBColor[
             0.6861293543437279, 0.7538260658401715, 0.9699677786592644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 146}], {
             RGBColor[
             0.7633172006975857, 0.8149282562458826, 0.9706894642628308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 159}], {
             RGBColor[
             0.5894745395886658, 0.6776010126202872, 0.9608247415542581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 175}], {
             RGBColor[
             0.7260037780413227, 0.7853690062048371, 0.9738378681047873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 204}], {
             RGBColor[
             0.6440562505543719, 0.7209582373924945, 0.9657743248690505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 235}], {
             RGBColor[
             0.6130443015201419, 0.6967314671074119, 0.9626833436124593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 242}], {
             RGBColor[
             0.6105256919917514, 0.6946912864847207, 0.9624819653843412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 243}], {
             RGBColor[
             0.7075085439141799, 0.7706214085516097, 0.9720737761628501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 253}], {
             RGBColor[
             0.7126333145148149, 0.7747077615203639, 0.9725625813576754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 280}], {
             RGBColor[
             0.6864911358853162, 0.7541086923301018, 0.9700038376622893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 292}], {
             RGBColor[
             0.5587449726581605, 0.6526533658348888, 0.9584055974793761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 66}], {
             RGBColor[
             0.816558027825572, 0.8573871654621898, 0.9821471094011383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 67}], {
             RGBColor[
             0.7327302175917669, 0.7911336820293808, 0.9739953584025032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 73}], {
             RGBColor[
             0.6305288446096039, 0.7097675579676672, 0.9648519654661385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 95}], {
             RGBColor[
             0.5708632735481443, 0.6605169674422793, 0.9603790631866269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 96}], {
             RGBColor[
             0.8369729800000596, 0.8731508976218676, 0.9662529201571904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 109}], {
             RGBColor[
             0.8527954392857966, 0.8844350121589164, 0.9163509078059362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 138}], {
             RGBColor[
             0.7834486607009236, 0.8309866548468239, 0.9789891084077084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 140}], {
             RGBColor[
             0.5458961126802646, 0.6388916675845144, 0.958788177773719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 154}], {
             RGBColor[
             0.710265265234826, 0.773583890508177, 0.9717562618984792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 171}], {
             RGBColor[
             0.8487726423754003, 0.8819510665012229, 0.9462791696005693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 198}], {
             RGBColor[
             0.5598805370833926, 0.6510042731248964, 0.9596792529307454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[
             0.7119810550612615, 0.7749242785610739, 0.9719272757934106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 62}], {
             RGBColor[
             0.862236498050585, 0.8926633469598089, 0.9574522056452552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 100}], {
             RGBColor[
             0.6573241797164234, 0.7309406783589646, 0.9673583106079069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 125}], {
             RGBColor[
             0.5440698983589547, 0.6357003496243832, 0.959353047852777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 137}], {
             RGBColor[
             0.5576723420900054, 0.6474821027055186, 0.9602197835391507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 170}], {
             RGBColor[
             0.6360398243067633, 0.7136610797881182, 0.9656827281828957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 192}], {
             RGBColor[
             0.5198770200326177, 0.6124175529300966, 0.9578967437021846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 195}], {
             RGBColor[
             0.7621478179546637, 0.8141149350149193, 0.9769274298835714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 200}], {
             RGBColor[
             0.5768191932520809, 0.6640661428333874, 0.9614398039643025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 225}], {
             RGBColor[
             0.46875223967510077`, 0.5586821672760516, 0.9549852630931587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 228}], {
             RGBColor[
             0.6732756341313957, 0.7438907876578713, 0.9686140675315564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 255}], {
             RGBColor[
             0.6179593718678597, 0.698982553983116, 0.9642593687360256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.8720086065656008, 0.8984433822160558, 0.872871670237699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 85}], {
             RGBColor[
             0.868108045616398, 0.8968304000237164, 0.9375140594941437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 100}], {
             RGBColor[
             0.6548659091830198, 0.7290202587347216, 0.9671132931749815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 121}], {
             RGBColor[
             0.8720558085013888, 0.8963555909178077, 0.7189101837048393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 125}], {
             RGBColor[
             0.541611627825551, 0.6337799300001402, 0.9591080304198515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 127}], {
             RGBColor[
             0.6620139282894559, 0.7348233426599176, 0.9676760114230969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.6621119545316024, 0.734902924779324, 0.9676837284079607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 137}], {
             RGBColor[
             0.5552140715566017, 0.6455616830812756, 0.9599747661062252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 170}], {
             RGBColor[
             0.6335815537733597, 0.7117406601638752, 0.9654377107499702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 232}], {
             RGBColor[
             0.5064600717047776, 0.5989788681235978, 0.9570276457807769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 240}], {
             RGBColor[
             0.8690333970595078, 0.8972130566258898, 0.9221785913490442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 256}], {
             RGBColor[
             0.48521975795799754`, 0.5766539516620579, 0.955818041335126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 299}], {
             RGBColor[
             0.8714795121931077, 0.8946191431552235, 0.6990241024809445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 177}], {
             RGBColor[
             0.5986873368289165, 0.6799152320953057, 0.9641560981795015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 217}], {
             RGBColor[
             0.7888166325535519, 0.8350387301003057, 0.979561667563377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 247}], {
             RGBColor[
             0.6483803141200333, 0.7226218883245134, 0.9674150254636793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 267}], {
             RGBColor[
             0.7433044056875631, 0.7994842325668597, 0.9750254341253167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 273}], {
             RGBColor[
             0.9099893535079261, 0.9289164484893757, 0.9089322483030275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 285}], {
             RGBColor[
             0.691826969680118, 0.7578938405577185, 0.9708353053397124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 82}], {
             RGBColor[
             0.9805144869747244, 0.9835673750187109, 0.8542353938633938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 100}], {
             RGBColor[
             0.7633717895921435, 0.8141442515373767, 0.9484770168006762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 127}], {
             RGBColor[
             0.7705198086985796, 0.8199473354625726, 0.9490397350487916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 130}], {
             RGBColor[
             0.8615303767616584, 0.892111719642179, 0.9573818260742537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 137}], {
             RGBColor[
             0.6637199519657255, 0.7306856758839307, 0.94133848973192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 170}], {
             RGBColor[
             0.7420874341824835, 0.7968646529665303, 0.946801434375665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 192}], {
             RGBColor[
             0.6259246299083377, 0.6956211261085087, 0.9390154498949539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 195}], {
             RGBColor[
             0.8681954278303838, 0.8973185081933315, 0.9580461360763407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 199}], {
             RGBColor[
             0.7746101992402674, 0.8232680987743087, 0.9493617455758276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 220}], {
             RGBColor[
             0.9817190303786034, 0.9839550200955374, 0.8262433838486106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 225}], {
             RGBColor[
             0.5747998495508209, 0.6418857404544638, 0.936103969285928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 226}], {
             RGBColor[
             0.8751628965367206, 0.9027615477014452, 0.9587405882422914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 228}], {
             RGBColor[
             0.7793232440071158, 0.8270943608362834, 0.9497327737243257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 255}], {
             RGBColor[
             0.7240069817435797, 0.7821861271615281, 0.9453780749287949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 131}], {
             RGBColor[
             0.9562803087638538, 0.9631462508065485, 0.7423065649437167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 139}], {
             RGBColor[
             0.6412162028156452, 0.7137139602427739, 0.9682643915412404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 143}], {
             RGBColor[
             0.9332742827673112, 0.9493374141256343, 0.9832982477903124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 172}], {
             RGBColor[
             0.9184823309214043, 0.9378368954107603, 0.9920868587337817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 174}], {
             RGBColor[
             0.8370693617791276, 0.8734480925561781, 0.9841815846647111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 183}], {
             RGBColor[
             0.7158977820766009, 0.776796423490852, 0.9734659403198705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 283}], {
             RGBColor[
             0.953564277396734, 0.9638890060741263, 0.9229497595447742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 92}], {
             RGBColor[
             0.9088069780920554, 0.9293864628287989, 0.9656613805927509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 145}], {
             RGBColor[
             0.5862829140394147, 0.6684049002901616, 0.9637184436448066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 153}], {
             RGBColor[
             0.6134455837127606, 0.6919318395257401, 0.9654492249373865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 211}], {
             RGBColor[
             0.7381561395526749, 0.7953447128448896, 0.9746680857379526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 219}], {
             RGBColor[
             0.7930751720306842, 0.8385456308513486, 0.9799383266821582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 221}], {
             RGBColor[
             0.8107485912472736, 0.8523522402663092, 0.981699847942175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 80}], {
             RGBColor[
             0.8996118022372472, 0.9203376446991802, 0.8906062806079784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 103}], {
             RGBColor[
             0.7864379868837652, 0.8309996819660161, 0.8799590908332804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 116}], {
             RGBColor[
             0.7327363788459087, 0.7874022973310114, 0.8757315035330684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 133}], {
             RGBColor[
             0.7818514863666197, 0.8272761542267038, 0.8795980247116657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 152}], {
             RGBColor[
             0.803219893873643, 0.8446239900766933, 0.8812802240256745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 162}], {
             RGBColor[
             0.8947076818058634, 0.9165065085454874, 0.8901174837149891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[
             0.9134821982174262, 0.9313028916879156, 0.8919543633212655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 241}], {
             RGBColor[
             0.7625538352081579, 0.8116094516669867, 0.8780788429228463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 277}], {
             RGBColor[
             0.8897086327003233, 0.9126012133900592, 0.8896192252189188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 67}], {
             RGBColor[
             0.8309967527222464, 0.8686668070898454, 0.9835862265612831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 69}], {
             RGBColor[
             0.7095282234557119, 0.7716587375809799, 0.9729260525042936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 95}], {
             RGBColor[
             0.6691298086786237, 0.7380500925027439, 0.9699699313454069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 109}], {
             RGBColor[
             0.951061974416276, 0.961968137219381, 0.9259417759647162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 110}], {
             RGBColor[
             0.8314540712227463, 0.8690240677781853, 0.9836318077955286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 138}], {
             RGBColor[
             0.881715195831403, 0.9085197799072886, 0.9885799765664882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 154}], {
             RGBColor[
             0.8085318003653055, 0.8511170155686416, 0.981347130057259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 179}], {
             RGBColor[
             0.9306261561657658, 0.9472433871200865, 0.9836530016866086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 258}], {
             RGBColor[
             0.8046244226080178, 0.8480645423674776, 0.9809576791589338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 69}], {
             RGBColor[
             0.625700413221907, 0.7054052541481709, 0.9647743015056586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 86}], {
             RGBColor[
             0.7776534182044803, 0.8262280277770025, 0.9784728832084004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 95}], {
             RGBColor[
             0.5853019984448188, 0.6717966090699349, 0.9618181803467718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 109}], {
             RGBColor[
             0.8672341641824711, 0.895714653786572, 0.9177900249660811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 110}], {
             RGBColor[
             0.7476262609889412, 0.8027705843453763, 0.9754800567968935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 138}], {
             RGBColor[
             0.7978873855975981, 0.8422662964744796, 0.9804282255678531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 154}], {
             RGBColor[
             0.7247039901315006, 0.7848635321358326, 0.973195379058624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 179}], {
             RGBColor[
             0.8467983459319609, 0.8809899036872775, 0.9755012506879736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 258}], {
             RGBColor[
             0.7207966123742129, 0.7818110589346686, 0.9728059281602988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 215}], {
             RGBColor[
             0.7444877549605017, 0.8003187595824299, 0.9751672398469851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 223}], {
             RGBColor[
             0.590989225084641, 0.6737157096840773, 0.963453223442287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 234}], {
             RGBColor[
             0.776148826115039, 0.8250526290014077, 0.9783229195301374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 255}], {
             RGBColor[
             0.6488486639201048, 0.7231135037016445, 0.9673381246909472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 271}], {
             RGBColor[
             0.6910397032628501, 0.7573660901247475, 0.9706595578588776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 274}], {
             RGBColor[
             0.8131218067457322, 0.8539362024751656, 0.9820080407072566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 287}], {
             RGBColor[
             0.6788582550886086, 0.7474766417289118, 0.9697005896364863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 109}], {
             RGBColor[
             0.7457656349159366, 0.7987065842777065, 0.9071298509090916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 110}], {
             RGBColor[
             0.6261577317224067, 0.7057625148365108, 0.964819882739904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 113}], {
             RGBColor[
             0.5848082080793905, 0.6734599526985672, 0.9606985486564363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 135}], {
             RGBColor[
             0.62946454545369, 0.7083458228561044, 0.9651494750287071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 138}], {
             RGBColor[
             0.6764188563310636, 0.7452582269656141, 0.9697680515108638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 224}], {
             RGBColor[
             0.7217816498319958, 0.7813356171636294, 0.9708471975698616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 249}], {
             RGBColor[
             0.6984456551881135, 0.7628217984726986, 0.9718689872494046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 254}], {
             RGBColor[
             0.6474344196259121, 0.7223840251355462, 0.9669405441481723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 258}], {
             RGBColor[
             0.5993280831076784, 0.6848029894258031, 0.9621457541033092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 288}], {
             RGBColor[
             0.5938851859159081, 0.6805509567720414, 0.9616032569779998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[
             0.7302515304494721, 0.7891973127951001, 0.9737483060328076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 251}], {
             RGBColor[
             0.7344032780288514, 0.7924406895585615, 0.974162113431233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 300}], {
             RGBColor[
             0.6129239392519832, 0.6954522762854864, 0.96348164937614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 85}], {
             RGBColor[
             0.7892439489729031, 0.8344733871513526, 0.9301648854478866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 98}], {
             RGBColor[
             0.44318966340329163`, 0.5530118103956307, 0.9505665092168026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 121}], {
             RGBColor[
             0.7931917118578938, 0.8339985780454438, 0.7115610096585822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 122}], {
             RGBColor[
             0.48385227627853544`, 0.5897027865750154, 0.9531036320689488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 136}], {
             RGBColor[
             0.5832478578881075, 0.6725459119069601, 0.9603345543617036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 160}], {
             RGBColor[
             0.5996870050038663, 0.6858919521106712, 0.9616287042412361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 181}], {
             RGBColor[
             0.68013668665959, 0.7492994347543929, 0.9692645888339558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 207}], {
             RGBColor[
             0.708979978963738, 0.7718678545422576, 0.9721299129630542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 232}], {
             RGBColor[
             0.4275959750612826, 0.5366218552512338, 0.9496784717345198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 240}], {
             RGBColor[
             0.7901693004160129, 0.8348560437535258, 0.9148294173027871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 246}], {
             RGBColor[
             0.5742299911986046, 0.6652248014781568, 0.9596246348623718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 256}], {
             RGBColor[
             0.4063556613145025, 0.5142969387896941, 0.948468867288869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 296}], {
             RGBColor[
             0.6186494191297383, 0.7012651140395313, 0.9631361126377644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 299}], {
             RGBColor[
             0.7926154155496128, 0.8322621302828597, 0.6916749284346875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 106}], {
             RGBColor[
             0.9333598470901734, 0.9476820672817128, 0.9168333870443124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 151}], {
             RGBColor[
             0.8265988787981872, 0.8649377989898153, 0.9832257351362215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 194}], {
             RGBColor[
             0.7553769385035978, 0.8091434210034993, 0.9762331477396189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 215}], {
             RGBColor[
             0.7747690110998245, 0.8244479124222702, 0.9780598183017003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 247}], {
             RGBColor[
             0.6720911035274687, 0.7415282281857694, 0.9696765817242321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 267}], {
             RGBColor[
             0.7670151950949984, 0.8183905724281157, 0.9772869903858695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 286}], {
             RGBColor[
             0.7047438943478745, 0.768037234765238, 0.9722471290287283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 87}], {
             RGBColor[
             0.6967612299041007, 0.7617575214927523, 0.9713873878163392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 95}], {
             RGBColor[
             0.4831006254626557, 0.5904304850082214, 0.9526747874104069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 96}], {
             RGBColor[
             0.7492103319145709, 0.8030644151878097, 0.9585486443809705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 105}], {
             RGBColor[
             0.45796915892139384`, 0.5686628718344162, 0.951073432585281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 140}], {
             RGBColor[
             0.458133464594776, 0.5688051851504565, 0.9510839019974991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 149}], {
             RGBColor[
             0.5742329275284845, 0.6652271853230336, 0.959624866021016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 171}], {
             RGBColor[
             0.7610099942899118, 0.811864584067165, 0.9385748938243494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 245}], {
             RGBColor[
             0.6242184069757728, 0.704837796127016, 0.9642230000171907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 289}], {
             RGBColor[
             0.5601716401690755, 0.6538115987908886, 0.9585179099718906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 298}], {
             RGBColor[
             0.5596463103149163, 0.6533851123494419, 0.9584765540814246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 90}], {
             RGBColor[
             0.5231867008294174, 0.6184756492306307, 0.9576570097871778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 123}], {
             RGBColor[
             0.7168173724385725, 0.7787024464536028, 0.9724093147116255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 158}], {
             RGBColor[
             0.7673133194556749, 0.8181502640467747, 0.9774422787988362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 233}], {
             RGBColor[
             0.8491312264986071, 0.8825295891708289, 0.9614195667279288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 257}], {
             RGBColor[
             0.5414270555204332, 0.6342745276771051, 0.958819269058777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 259}], {
             RGBColor[
             0.6505359746716031, 0.7257410792453638, 0.9666110318135679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 262}], {
             RGBColor[
             0.7632498188986084, 0.8149758265278463, 0.9770372670388794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 124}], {
             RGBColor[
             0.6217627130403636, 0.6991937362833482, 0.9659524764836203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 142}], {
             RGBColor[
             0.8529856460345742, 0.8856116167421517, 0.985839726459695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 143}], {
             RGBColor[
             0.8994051827479433, 0.9223311131224192, 0.9800677827951625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 150}], {
             RGBColor[
             0.8712800355116529, 0.9001990663232009, 0.9875846616596129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 167}], {
             RGBColor[
             0.7712888934232452, 0.8215123880730957, 0.9777704927024696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 174}], {
             RGBColor[
             0.8032002617597598, 0.846441791552963, 0.9809511196695613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 185}], {
             RGBColor[
             0.7012951727482507, 0.7654315275761197, 0.9717522040473985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 237}], {
             RGBColor[
             0.901421816127386, 0.9238351149948736, 0.9766541485059881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 239}], {
             RGBColor[
             0.7207478925980143, 0.7812241218852003, 0.9732835934116326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 282}], {
             RGBColor[
             0.8379108121436951, 0.87359135339303, 0.9844018753457198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 283}], {
             RGBColor[
             0.9196951773773662, 0.9368827050709113, 0.9197192945496243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 295}], {
             RGBColor[
             0.8635954159852213, 0.8940715593062645, 0.9868516957890411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 297}], {
             RGBColor[
             0.881593168202261, 0.9084224783881625, 0.9885683374622853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 99}], {
             RGBColor[
             0.39810876208201706`, 0.5175909523560585, 0.9469103604293232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[
             0.5188870234533162, 0.6142236438735011, 0.9573896999562074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 128}], {
             RGBColor[
             0.43166859929643053`, 0.5448363400601568, 0.9495523137485762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[
             0.36216453363818957`, 0.48754985073268053`, 0.9443183079739393]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 201}], {
             RGBColor[
             0.6480292870495437, 0.7118545659903959, 0.7304685955364956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 209}], {
             RGBColor[
             0.6385637900104651, 0.7079653428156508, 0.9343454733956806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 218}], {
             RGBColor[
             0.3918769195615046, 0.5125316618566, 0.9464197669581171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 229}], {
             RGBColor[
             0.4118403774741505, 0.5287388963336161, 0.9479913634935566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 261}], {
             RGBColor[
             0.5941312923062904, 0.6735352261051355, 0.9647486500101554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 284}], {
             RGBColor[
             0.3431500500156586, 0.4710804607145792, 0.9431067218913594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 91}], {
             RGBColor[
             0.6389072628426329, 0.7153558312591152, 0.9663413613443415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 162}], {
             RGBColor[
             0.6393804169494349, 0.7157254628434534, 0.9663885209238309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 191}], {
             RGBColor[
             0.5711447420077354, 0.6624192349686604, 0.9595874265442793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 203}], {
             RGBColor[
             0.5591254322039653, 0.6529622400336803, 0.9584355486484911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 206}], {
             RGBColor[
             0.4182100175716107, 0.5359217975097312, 0.9480713237387717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 244}], {
             RGBColor[
             0.732462204266815, 0.7884376002311666, 0.9282946638850447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 270}], {
             RGBColor[
             0.5153270750303671, 0.617404760586648, 0.9549875815331168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 118}], {
             RGBColor[
             0.8530495905950142, 0.8859737362113382, 0.9857632607323639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 120}], {
             RGBColor[
             0.7199876599891011, 0.7800793776746299, 0.9738309490933574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 130}], {
             RGBColor[
             0.8396928602508804, 0.8755393569515906, 0.9844319866774023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 176}], {
             RGBColor[
             0.7893815098487937, 0.8362357476370552, 0.979417421455623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 193}], {
             RGBColor[
             0.6318099936956943, 0.7053890703971202, 0.9677468432528796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.7527726827294894, 0.8066957360837204, 0.9764119061789762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 220}], {
             RGBColor[
             0.9598815138678254, 0.9673826574049491, 0.8532935444517593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 226}], {
             RGBColor[
             0.8533253800259426, 0.886189185010857, 0.98579074884544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 236}], {
             RGBColor[
             0.8023570568753615, 0.8463723435920198, 0.9807107027198503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 266}], {
             RGBColor[
             0.9237092583888502, 0.9420047054921352, 0.9925854077417597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 93}], {
             RGBColor[
             0.8538328247381641, 0.8864686893248209, 0.9858723519316027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 103}], {
             RGBColor[
             0.7460362839228682, 0.8013314943296879, 0.9757611186293835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 116}], {
             RGBColor[
             0.6923346758850116, 0.7577341096946831, 0.9715335313291715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 119}], {
             RGBColor[
             0.6421522280382972, 0.7148444233778373, 0.9681768471998777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 164}], {
             RGBColor[
             0.7781448938443649, 0.8273407024610047, 0.9783284863240371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 168}], {
             RGBColor[
             0.8662255489567677, 0.896168755944718, 0.9871025602198147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 241}], {
             RGBColor[
             0.7221521322472608, 0.7819412640306584, 0.9738808707189494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[
             0.8493069297394262, 0.8829330257537309, 0.9854212530150219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 103}], {
             RGBColor[
             0.6951023258586274, 0.7608127689987132, 0.970877880277486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 116}], {
             RGBColor[
             0.6414007178207708, 0.7172153843637086, 0.966650292977274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 133}], {
             RGBColor[
             0.6905158253414818, 0.7570892412594008, 0.9705168141558713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 152}], {
             RGBColor[
             0.7118842328485051, 0.7744370771093905, 0.9721990134698801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 210}], {
             RGBColor[
             0.8221465371922883, 0.8611159787206126, 0.9828731527654712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 241}], {
             RGBColor[
             0.6712181741830201, 0.7414225386996839, 0.9689976323670519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 277}], {
             RGBColor[
             0.7983729716751855, 0.8424143004227562, 0.9805380146631244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 180}], {
             RGBColor[
             0.6948420623539805, 0.7614492352933201, 0.9702777732851893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[
             0.6461249032688305, 0.7233910203518784, 0.9654221021553174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 285}], {
             RGBColor[
             0.5946474672613855, 0.6818006283427371, 0.9612319733697131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 100}], {
             RGBColor[
             0.775602168640563, 0.8218447064178667, 0.8641414988260454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 107}], {
             RGBColor[
             0.9755742568524575, 0.9798829594824087, 0.8625979148420175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 127}], {
             RGBColor[
             0.7827501877469991, 0.8276477903430626, 0.8647042170741608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 137}], {
             RGBColor[
             0.6759503310141449, 0.7383861307644207, 0.8570029717572891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 192}], {
             RGBColor[
             0.6381550089567573, 0.7033215809889987, 0.854679931920323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 199}], {
             RGBColor[
             0.7868405782886869, 0.8309685536547987, 0.8650262276011967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 220}], {
             RGBColor[
             0.9939494094270229, 0.9916554749760274, 0.7419078658739797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 226}], {
             RGBColor[
             0.8873932755851401, 0.9104620025819352, 0.8744050702676605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 228}], {
             RGBColor[
             0.7915536230555353, 0.8347948157167734, 0.865397255749695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 266}], {
             RGBColor[
             0.9577771539480476, 0.9662775230632136, 0.8811997291639803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 281}], {
             RGBColor[
             0.8999497646561503, 0.9202712272770598, 0.8756565837511969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 126}], {
             RGBColor[
             0.8940052619394712, 0.9174585692194018, 0.9594656236885482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 155}], {
             RGBColor[
             0.8350532378111404, 0.8713252816945838, 0.9841260054119322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 156}], {
             RGBColor[
             0.5113941403794997, 0.5951021122033315, 0.95874340396191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 184}], {
             RGBColor[
             0.7719840403832192, 0.8217990667341661, 0.9779078126105251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[
             0.791228508752409, 0.836832991687554, 0.979825921367784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 202}], {
             RGBColor[
             0.8596593076943806, 0.8909454939055056, 0.9864729543234936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 214}], {
             RGBColor[
             0.8785223504569342, 0.9059114391866665, 0.9856741542384324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 275}], {
             RGBColor[
             0.7932733163152061, 0.8384304108967242, 0.9800297286758306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 293}], {
             RGBColor[
             0.860043880529358, 0.8912521418451651, 0.9865096352238059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 89}], {
             RGBColor[
             0.682701761186904, 0.7520510716555506, 0.9690089894105725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.5102132601320107, 0.6083406987560154, 0.9563639384621566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 112}], {
             RGBColor[
             0.5130132355616993, 0.6107658967423546, 0.9565423504206153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 134}], {
             RGBColor[
             0.7493706398163686, 0.8041333063431327, 0.9756539201762645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 144}], {
             RGBColor[
             0.7444362276569513, 0.8002785060612745, 0.9751621040869172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 158}], {
             RGBColor[
             0.7543398787582682, 0.8080153135721594, 0.976149207473815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 159}], {
             RGBColor[
             0.6527158250613065, 0.7279082531232484, 0.9665108830712583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 175}], {
             RGBColor[
             0.7892450635139634, 0.8356762467077983, 0.9795240096217874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 252}], {
             RGBColor[
             0.590030048094875, 0.6770171154198286, 0.9615760290828936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 253}], {
             RGBColor[
             0.7758745999874557, 0.8250150020233251, 0.9782487228746755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 280}], {
             RGBColor[
             0.7497324213579569, 0.804415932833063, 0.9756899791792893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 292}], {
             RGBColor[
             0.6219862581308012, 0.70296060633785, 0.9640917389963761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[
             0.9888915070097293, 0.9875670564086134, 0.6805807786123479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 122}], {
             RGBColor[
             0.6795520714303709, 0.743271264938185, 0.9221234010227144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 136}], {
             RGBColor[
             0.7789476530399428, 0.8261143902701296, 0.9293543233154693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 165}], {
             RGBColor[
             0.9128782111205576, 0.9319735440325574, 0.9419316561571864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 181}], {
             RGBColor[
             0.8758364818114255, 0.9028679131175625, 0.9382843577877216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 207}], {
             RGBColor[
             0.9046797741155734, 0.9254363329054272, 0.9411496819168199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 232}], {
             RGBColor[
             0.623295770213118, 0.6901903336144035, 0.9186982406882855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 240}], {
             RGBColor[
             0.9858690955678482, 0.9884245221166954, 0.8838491862565528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 246}], {
             RGBColor[
             0.76992978635044, 0.8187932798413264, 0.9286444038161374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 256}], {
             RGBColor[
             0.602055456466338, 0.6678654171528635, 0.9174886362426347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 296}], {
             RGBColor[
             0.8143492142815736, 0.8548335924027008, 0.9321558815915301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 299}], {
             RGBColor[
             0.9883152107014481, 0.9858306086460292, 0.6606946973884531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 107}], {
             RGBColor[
             0.8832707708011451, 0.9092704104812925, 0.9684036223247123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 109}], {
             RGBColor[
             0.89771863989851, 0.9195293579065381, 0.9208284326118334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 110}], {
             RGBColor[
             0.77811073670498, 0.8265852884653424, 0.9785184644426459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 141}], {
             RGBColor[
             0.6948387241233724, 0.7606008830070974, 0.9708556806508715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 165}], {
             RGBColor[
             0.8244752860184479, 0.8629739772237807, 0.9830949743834365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 179}], {
             RGBColor[
             0.8772828216479998, 0.9048046078072436, 0.9785396583337258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 240}], {
             RGBColor[
             0.8974661704657385, 0.9194249553079187, 0.925012504482803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 281}], {
             RGBColor[
             0.8076462786048377, 0.8496586782759437, 0.981462291233892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 149}], {
             RGBColor[
             0.72822796090847, 0.7873036312821766, 0.9738645641474368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 187}], {
             RGBColor[
             0.8376944811585035, 0.8734188569375863, 0.9843812415032311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 227}], {
             RGBColor[
             0.7732565622869776, 0.8230418912651589, 0.9779686428623745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 264}], {
             RGBColor[
             0.7028412115899998, 0.7666935245254187, 0.9718660262463599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 99}], {
             RGBColor[
             0.5072150735598739, 0.6108190723513998, 0.954348975062119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[
             0.5931399021715937, 0.6802239973011592, 0.9613544501353757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 198}], {
             RGBColor[
             0.46118242680573585`, 0.5720398898462786, 0.9511140975128402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 201}], {
             RGBColor[
             0.7571355985274005, 0.8050826859857373, 0.7379072101692913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 222}], {
             RGBColor[
             0.6076157780558329, 0.6915326615626585, 0.9627972701587652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 258}], {
             RGBColor[
             0.6076597771998816, 0.6915670340283953, 0.9628016555822485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 260}], {
             RGBColor[
             0.7544418477025328, 0.8056130962141566, 0.9020761860361408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 261}], {
             RGBColor[
             0.7032376037841472, 0.7667633461004769, 0.9721872646429512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 278}], {
             RGBColor[
             0.6175824052880334, 0.6993186665056259, 0.963790650417844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 290}], {
             RGBColor[
             0.5926514473845327, 0.6798424127091133, 0.9613057655270709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 111}], {
             RGBColor[
             0.6985860911661191, 0.7644600309606926, 0.9705921909753974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 112}], {
             RGBColor[
             0.4857991956426514, 0.5895060819232304, 0.9538299092511469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 175}], {
             RGBColor[
             0.7620310235949155, 0.8144164318886742, 0.9768115684523191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 177}], {
             RGBColor[
             0.5108769945912794, 0.6112272109257078, 0.9554278444247266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 242}], {
             RGBColor[
             0.6465529375453443, 0.7237387121685577, 0.9654556657318729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.722518381438909, 0.7831561180139388, 0.9729775380098209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 285}], {
             RGBColor[
             0.604016627442481, 0.6892058193881205, 0.9621070515849375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 123}], {
             RGBColor[
             0.5041413907672246, 0.6035973082603281, 0.95575875126872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 134}], {
             RGBColor[
             0.5496680988424276, 0.6391631186244734, 0.9602964280583802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 144}], {
             RGBColor[
             0.5447336866830101, 0.635308318342615, 0.9598046119690329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 158}], {
             RGBColor[
             0.554637337784327, 0.6430451258535, 0.9607917153559307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 252}], {
             RGBColor[
             0.3903275071209339, 0.5120469277011692, 0.9462185369650093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 253}], {
             RGBColor[
             0.5761720590135146, 0.6600448143046658, 0.9628912307567912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[
             0.3287510738490854, 0.45916938948383035`, 0.9421687056158715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 102}], {
             RGBColor[
             0.8937076663494723, 0.9159190062533751, 0.8988017801716552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 162}], {
             RGBColor[
             0.7979947462425394, 0.8421188278401535, 0.9805003166867159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 191}], {
             RGBColor[
             0.72975907130084, 0.7888125999653604, 0.9736992223071643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 203}], {
             RGBColor[
             0.7177397614970698, 0.7793556050303804, 0.9725473444113761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 239}], {
             RGBColor[
             0.693657030382127, 0.7598041589965967, 0.970651463600057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 153}], {
             RGBColor[
             0.6688621270447314, 0.7353839180703626, 0.9452322699604441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 163}], {
             RGBColor[
             0.9184221305956413, 0.9370533244387965, 0.9665784824220909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 189}], {
             RGBColor[
             0.9753616994477203, 0.9807619540087985, 0.9094199616595142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 211}], {
             RGBColor[
             0.7935726828846457, 0.838796791389512, 0.9544511307610102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 216}], {
             RGBColor[
             0.8635165093516033, 0.8937351926528012, 0.9612189027553515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 221}], {
             RGBColor[
             0.8661651345792443, 0.8958043188109317, 0.9614828929652326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 94}], {
             RGBColor[
             0.58025624058039, 0.6652876963509552, 0.9624017967345151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 160}], {
             RGBColor[
             0.7016757241612013, 0.7663140958444873, 0.971282724547789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 164}], {
             RGBColor[
             0.721833661241938, 0.7826212093919989, 0.9729092914996609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 168}], {
             RGBColor[
             0.809914316354341, 0.8514492628757123, 0.9816833653954384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 277}], {
             RGBColor[
             0.7929956971369994, 0.8382135326847252, 0.9800020581906457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 124}], {
             RGBColor[
             0.37740649926912895`, 0.5013122734898845, 0.9452689862993333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 125}], {
             RGBColor[
             0.3474708987840436, 0.4753835609567324, 0.9433615163074358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 142}], {
             RGBColor[
             0.6086294322633394, 0.687730153948688, 0.965156236275408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 150}], {
             RGBColor[
             0.6269238217404183, 0.7023176035297372, 0.9669011714753261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 200}], {
             RGBColor[
             0.38022019367716975`, 0.5037493541657366, 0.9454482724189615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.6570656023561514, 0.7259536522014098, 0.9559706583217012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 295}], {
             RGBColor[
             0.6192392022139865, 0.6961900965128007, 0.9661682056047542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 96}], {
             RGBColor[
             0.6895447608531113, 0.7538138246624217, 0.954075742101459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 105}], {
             RGBColor[
             0.39830358785993425`, 0.5194122813090283, 0.9466005303057695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 109}], {
             RGBColor[
             0.7053672201388484, 0.7650979391994704, 0.9041737297502048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 138}], {
             RGBColor[
             0.6360204415539754, 0.711649581887378, 0.9668119303519769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 140}], {
             RGBColor[
             0.3984678935333164, 0.5195545946250686, 0.9466109997179877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 154}], {
             RGBColor[
             0.5628370460878779, 0.654246817548731, 0.9595790838427476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 171}], {
             RGBColor[
             0.7013444232284521, 0.7626139935417771, 0.9341019915448379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 198}], {
             RGBColor[
             0.4124523179364444, 0.5316672001654504, 0.947502074875014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 245}], {
             RGBColor[
             0.5645528359143133, 0.6555872056016281, 0.9597500977376792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 289}], {
             RGBColor[
             0.500506069107616, 0.6045610082655006, 0.9540450076923791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 105}], {
             RGBColor[
             0.6644132943118495, 0.7320462114886166, 0.952474387276333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 138}], {
             RGBColor[
             0.9021301480058905, 0.9242835120669664, 0.9726857873225404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 140}], {
             RGBColor[
             0.6645775999852317, 0.7321885248046569, 0.9524848566885511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 171}], {
             RGBColor[
             0.9674541296803674, 0.9752479237213654, 0.9399758485154014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 196}], {
             RGBColor[
             0.7815577832725529, 0.8293255334362966, 0.9610951542444894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 198}], {
             RGBColor[
             0.6785620243883597, 0.7443011303450389, 0.9533759318455775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 222}], {
             RGBColor[
             0.8249953756384567, 0.8637939020614187, 0.9650591044915025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 245}], {
             RGBColor[
             0.8306625423662285, 0.8682211357812164, 0.9656239547082427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 278}], {
             RGBColor[
             0.8349620028706572, 0.8715799070043861, 0.9660524847505814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 289}], {
             RGBColor[
             0.7666157755595311, 0.817194938445089, 0.9599188646629426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 290}], {
             RGBColor[
             0.8100310449671564, 0.8521036532078735, 0.9635675998598082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 298}], {
             RGBColor[
             0.7660904457053719, 0.8167684520036422, 0.9598775087724766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 134}], {
             RGBColor[
             0.6808885202409665, 0.7495713206186639, 0.9695552010008872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 144}], {
             RGBColor[
             0.675954108081549, 0.7457165203368057, 0.9690633849115398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 159}], {
             RGBColor[
             0.5842337054859043, 0.6733462673987796, 0.9604121638958809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 235}], {
             RGBColor[
             0.6078034674173804, 0.6924767218859043, 0.962270765954082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 252}], {
             RGBColor[
             0.5215479285194727, 0.6224551296953598, 0.9554773099075162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 292}], {
             RGBColor[
             0.5535041385553989, 0.6483986206133812, 0.9579930198209988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 122}], {
             RGBColor[
             0.33349778586075945`, 0.46180968818246315`, 0.9425250247916304]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 160}], {
             RGBColor[
             0.44933251458609036`, 0.5579988537181189, 0.951050096963918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 178}], {
             RGBColor[
             0.6327023479093009, 0.7020908437810269, 0.935652362077771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 181}], {
             RGBColor[
             0.5297821962418141, 0.6214063363618406, 0.9586859815566375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 182}], {
             RGBColor[
             0.5457933913906503, 0.6339144037017017, 0.960281827855948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 208}], {
             RGBColor[
             0.49753710538003765`, 0.5962162263088536, 0.9554720922470421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 246}], {
             RGBColor[
             0.4238755007808286, 0.5373317030856045, 0.9490460275850534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 296}], {
             RGBColor[
             0.4682949287119622, 0.573372015646979, 0.9525575053604461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 104}], {
             RGBColor[
             0.6143131363512679, 0.6963455623757528, 0.9637513592445743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 123}], {
             RGBColor[
             0.5956534686781743, 0.681768488170805, 0.9618915379554289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 157}], {
             RGBColor[
             0.45759064653614134`, 0.5696717692349322, 0.9506799672623063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 201}], {
             RGBColor[
             0.7434553999474954, 0.7939764844926476, 0.7368302548248625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[
             0.4873030324594564, 0.5946535803588517, 0.9527814262464842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 222}], {
             RGBColor[
             0.5939355794759278, 0.6804264600695686, 0.9617203148143364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 229}], {
             RGBColor[
             0.5072664903721023, 0.6108608148358678, 0.9543530227819236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 257}], {
             RGBColor[
             0.42026315176003504`, 0.5373405693943074, 0.9483014923025805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 259}], {
             RGBColor[
             0.5293720709112049, 0.6288071209625661, 0.9560932550573713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 261}], {
             RGBColor[
             0.6895574052042421, 0.7556571446073872, 0.9711103092985225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 121}], {
             RGBColor[
             0.775649370576351, 0.8197569151196185, 0.7101800122931857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 125}], {
             RGBColor[
             0.4452051899005132, 0.557181254201951, 0.9503778590081979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 127}], {
             RGBColor[
             0.5656074903644182, 0.6582246668617284, 0.9589458400114433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 136}], {
             RGBColor[
             0.5657055166065647, 0.6583042489811348, 0.958953556996307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 137}], {
             RGBColor[
             0.45880763363156396`, 0.5689630072830865, 0.9512445946945718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 170}], {
             RGBColor[
             0.5371751158483219, 0.635141984365686, 0.9567075393383166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 192}], {
             RGBColor[
             0.4210123115741763, 0.5338984575076644, 0.9489215548576055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 228}], {
             RGBColor[
             0.5744109256729544, 0.6653716922354391, 0.9596388786869774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 232}], {
             RGBColor[
             0.4100536337797398, 0.5223801923254086, 0.9482974743691233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 240}], {
             RGBColor[
             0.77262695913447, 0.8206143808277006, 0.9134484199373907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 256}], {
             RGBColor[
             0.38881332003295976`, 0.5000552758638688, 0.9470878699234725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 299}], {
             RGBColor[
             0.7750730742680699, 0.8180204673570344, 0.6902939310692909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 108}], {
             RGBColor[
             0.8456951433419048, 0.8801063092685304, 0.9850626336046073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 114}], {
             RGBColor[
             0.945211530197247, 0.9579839703115626, 0.954208175436068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 187}], {
             RGBColor[
             0.8670690822200418, 0.8968413664717523, 0.9871830171754967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 205}], {
             RGBColor[
             0.934139893966829, 0.9497267621390573, 0.9729495676289639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 207}], {
             RGBColor[
             0.8669606347567855, 0.8967548934082796, 0.9871726733596391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 213}], {
             RGBColor[
             0.9170978596145347, 0.936732955571135, 0.9919548066246002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 231}], {
             RGBColor[
             0.5442162327035813, 0.6180364932601136, 0.9623658186436455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 133}], {
             RGBColor[
             0.7813246250170307, 0.8270582835189296, 0.8883294807478213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 142}], {
             RGBColor[
             0.9220808580324217, 0.938361463851108, 0.9015562197125482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 162}], {
             RGBColor[
             0.8941808204562743, 0.9162886378377133, 0.8988489397511447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[
             0.7703903847460982, 0.8181813746850759, 0.8874686973002517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 210}], {
             RGBColor[
             0.9129553368678371, 0.9310850209801413, 0.9006858193574211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 237}], {
             RGBColor[
             0.9705170281252335, 0.9765849621038298, 0.8923706417588413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 239}], {
             RGBColor[
             0.7898431045958618, 0.8339739689941565, 0.8890000866644858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 295}], {
             RGBColor[
             0.9326906279830687, 0.9468214064152207, 0.9025681890418943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 116}], {
             RGBColor[
             0.5282269024672888, 0.6278774216305444, 0.9560031032025761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 119}], {
             RGBColor[
             0.4780444546205743, 0.5849877353136985, 0.9526464190732823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 152}], {
             RGBColor[
             0.5987104174950231, 0.6850991143762263, 0.9615518236951821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 164}], {
             RGBColor[
             0.614037120426642, 0.6974840143968659, 0.9627980581974418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 168}], {
             RGBColor[
             0.7021177755390449, 0.7663120678805793, 0.9715721320932191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 241}], {
             RGBColor[
             0.5580443588295381, 0.6520845759665197, 0.9583504425923539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 277}], {
             RGBColor[
             0.6851991563217035, 0.7530763376895921, 0.9698908248884265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 128}], {
             RGBColor[
             0.6478729735656814, 0.7235909500798512, 0.9663933125638273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 157}], {
             RGBColor[
             0.5783689079074404, 0.6663044607523749, 0.9611593067891905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 173}], {
             RGBColor[
             0.7987395898178458, 0.8430434392853619, 0.9804836046723177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 201}], {
             RGBColor[
             0.8642336613187945, 0.8906091760100903, 0.7473095943517467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 209}], {
             RGBColor[
             0.854768164279716, 0.8867199528353452, 0.9511864722109318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 218}], {
             RGBColor[
             0.6080812938307555, 0.6912862718762944, 0.9632607657733683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 229}], {
             RGBColor[
             0.6280447517434014, 0.7074935063533105, 0.9648323623088078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 261}], {
             RGBColor[
             0.8103356665755412, 0.8522898361248299, 0.9815896488254066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 279}], {
             RGBColor[
             0.6408893075700892, 0.7179212954140616, 0.9658435327946429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 129}], {
             RGBColor[
             0.6247521230276236, 0.700936066635534, 0.9665328549602914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 140}], {
             RGBColor[
             0.37333642699205455`, 0.4977869814512635, 0.9450096448928618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 149}], {
             RGBColor[
             0.4894358899257631, 0.5942089816238405, 0.9535506089163787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 171}], {
             RGBColor[
             0.6762129566871903, 0.7408463803679719, 0.932500636719712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 196}], {
             RGBColor[
             0.4903166102793758, 0.5949239900829031, 0.9536199424488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 230}], {
             RGBColor[
             0.6257710935472844, 0.7017485660686936, 0.9666300452781025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 245}], {
             RGBColor[
             0.5394213693730514, 0.6338195924278229, 0.9581487429125533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 263}], {
             RGBColor[
             0.49743792700426637`, 0.6007053958118318, 0.9541805585876261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 289}], {
             RGBColor[
             0.47537460256635405`, 0.5827933950916955, 0.9524436528672532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 298}], {
             RGBColor[
             0.4748492727121948, 0.5823669086502488, 0.9524022969767871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 151}], {
             RGBColor[
             0.8814287413303598, 0.9066398873733936, 0.9117829539087743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 167}], {
             RGBColor[
             0.8395320899506622, 0.8739099048892299, 0.9076070872457135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 194}], {
             RGBColor[
             0.8102068010357704, 0.8508455093870777, 0.9047903665121717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 215}], {
             RGBColor[
             0.8295988736319971, 0.8661500008058487, 0.9066170370742531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 283}], {
             RGBColor[
             0.9879383739047831, 0.9892802218870456, 0.8495558890928682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 286}], {
             RGBColor[
             0.7595737568800471, 0.8097393231488164, 0.9008043478012812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 297}], {
             RGBColor[
             0.9498363647296779, 0.9608199952042967, 0.9184049320055292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 110}], {
             RGBColor[
             0.8532436135856061, 0.8858129670496662, 0.9654107959132056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 127}], {
             RGBColor[
             0.7655795785763126, 0.8162629199262703, 0.9574022560274154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 141}], {
             RGBColor[
             0.7699716010039984, 0.8198285615914211, 0.9577480121214311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 165}], {
             RGBColor[
             0.8996081628990739, 0.9222016558081045, 0.9699873058539963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.9524156985286257, 0.9640322863915675, 0.9654319898042856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 240}], {
             RGBColor[
             0.9725990473463646, 0.9786526338922426, 0.9119048359533628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 281}], {
             RGBColor[
             0.8827791554854638, 0.9088863568602675, 0.9683546227044516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 114}], {
             RGBColor[
             0.8814012081319893, 0.9074112930598659, 0.9480401717533846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 145}], {
             RGBColor[
             0.5505301072976958, 0.6402045241564903, 0.960226590820922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 169}], {
             RGBColor[
             0.8873182067462955, 0.9082191728151048, 0.7156641792470566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 187}], {
             RGBColor[
             0.8032587601547839, 0.8462686892200555, 0.9810150134928133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 205}], {
             RGBColor[
             0.8703295719015711, 0.8991540848873605, 0.9667815639462806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 213}], {
             RGBColor[
             0.8532875375492769, 0.8861602783194383, 0.9857868029419168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 219}], {
             RGBColor[
             0.7573223652889653, 0.8103452547176773, 0.9764464738582735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 221}], {
             RGBColor[
             0.7749957845055547, 0.8241518641326377, 0.9782079951182905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 264}], {
             RGBColor[
             0.6684054905862802, 0.739543356807888, 0.968499798235942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 110}], {
             RGBColor[
             0.8676914826829709, 0.8960719144749119, 0.9178356062003266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 138}], {
             RGBColor[
             0.9179526072916278, 0.9355676266040152, 0.9227837749712862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 154}], {
             RGBColor[
             0.8447692118255302, 0.8781648622653682, 0.915550928462057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 179}], {
             RGBColor[
             0.9668635676259906, 0.974291233816813, 0.9178568000914066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 258}], {
             RGBColor[
             0.8408618340682426, 0.8751123890642042, 0.9151614775637318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 138}], {
             RGBColor[
             0.7983447040980978, 0.8426235571628193, 0.9804738068020986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 141}], {
             RGBColor[
             0.6648115669078334, 0.737143439575471, 0.9678628542393646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 154}], {
             RGBColor[
             0.7251613086320003, 0.7852207928241725, 0.9732409602928694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 165}], {
             RGBColor[
             0.7944481288029088, 0.8395165337921544, 0.9801021479719297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 179}], {
             RGBColor[
             0.8472556644324607, 0.8813471643756172, 0.975546831922219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 281}], {
             RGBColor[
             0.7776191213892988, 0.8262012348443173, 0.9784694648223851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 190}], {
             RGBColor[
             0.817814039962887, 0.85819959879233, 0.9823170840906108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 212}], {
             RGBColor[
             0.6025121564957981, 0.6866639979793778, 0.9628913953023271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 242}], {
             RGBColor[
             0.6896513074436073, 0.757407486292824, 0.9697513084661662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 250}], {
             RGBColor[
             0.8667214210504133, 0.8944943490453259, 0.8805681593846872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 280}], {
             RGBColor[
             0.7656167513371721, 0.8168248921382051, 0.9772731807441143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 115}], {
             RGBColor[
             0.6508628254029745, 0.7182701730675092, 0.914711898019736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 134}], {
             RGBColor[
             0.5524680742721161, 0.6415883166108125, 0.9604748400168389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 146}], {
             RGBColor[
             0.6296559206259738, 0.7026905070165236, 0.9611965256204053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 159}], {
             RGBColor[
             0.455813259517054, 0.5653632633909282, 0.9513318029118327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 175}], {
             RGBColor[
             0.592342497969711, 0.6731312569754782, 0.9643449294623618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 204}], {
             RGBColor[
             0.51039497048276, 0.6087204881631355, 0.956281386226625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 235}], {
             RGBColor[
             0.47938302144853007`, 0.5844937178780529, 0.9531904049700337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 242}], {
             RGBColor[
             0.4768644119201395, 0.5824535372553616, 0.9529890267419157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 252}], {
             RGBColor[
             0.39312748255062246`, 0.5144721256875084, 0.946396948923468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 253}], {
             RGBColor[
             0.5789720344432032, 0.662470012291005, 0.9630696427152499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 280}], {
             RGBColor[
             0.5528298558137044, 0.6418709431007428, 0.9605108990198638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 292}], {
             RGBColor[
             0.42508369258654866`, 0.5404156166055298, 0.9489126588369505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 135}], {
             RGBColor[
             0.7100408695777081, 0.7734085909153663, 0.9717338962364743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 224}], {
             RGBColor[
             0.8023579739560138, 0.8463983852228911, 0.9774316187776289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 249}], {
             RGBColor[
             0.7790219793121316, 0.8278845665319604, 0.9784534084571719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 254}], {
             RGBColor[
             0.7280107437499301, 0.7874467931948081, 0.9735249653559395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 258}], {
             RGBColor[
             0.6799044072316964, 0.7498657574850649, 0.9687301753110764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 260}], {
             RGBColor[
             0.8266864777343474, 0.8639118196708263, 0.9080047057649687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 278}], {
             RGBColor[
             0.6898270353198481, 0.7576173899622957, 0.9697191701466719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 288}], {
             RGBColor[
             0.6744615100399262, 0.7456137248313033, 0.9681876781857669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 290}], {
             RGBColor[
             0.6648960774163475, 0.738141136165783, 0.9672342852558987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 145}], {
             RGBColor[
             0.6500464941530382, 0.7180821851995225, 0.9293721326523825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 169}], {
             RGBColor[
             0.9868345936016378, 0.9860968338581371, 0.6848097210785172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 187}], {
             RGBColor[
             0.9027751470101262, 0.9241463502630878, 0.9501605553242738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 213}], {
             RGBColor[
             0.9528039244046191, 0.9640379393624705, 0.9549323447733774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 219}], {
             RGBColor[
             0.8568387521443077, 0.8882229157607094, 0.9455920156897342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 221}], {
             RGBColor[
             0.874512171360897, 0.90202952517567, 0.947353536949751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 231}], {
             RGBColor[
             0.5799222974936658, 0.6453414770514491, 0.9253433567924225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 264}], {
             RGBColor[
             0.7679218774416225, 0.8174210178509201, 0.9376453400674025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 132}], {
             RGBColor[
             0.9670762921005825, 0.9747297242644322, 0.9300285595223475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 146}], {
             RGBColor[
             0.9644080760115016, 0.9727397730739984, 0.9345451533789515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 159}], {
             RGBColor[
             0.7905654149025818, 0.835412529448403, 0.9246804306703789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 204}], {
             RGBColor[
             0.8451471258682878, 0.8787697542206103, 0.9296300139851712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 242}], {
             RGBColor[
             0.8116165673056673, 0.8525028033128366, 0.9263376545004619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 243}], {
             RGBColor[
             0.9085994192280958, 0.9284329253797254, 0.9359294652789708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 294}], {
             RGBColor[
             0.952030918945425, 0.96306402433767, 0.9400720004937672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 119}], {
             RGBColor[
             0.4243428465827177, 0.5413903506786937, 0.9484188317730703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 133}], {
             RGBColor[
             0.5236404019501433, 0.624153893891232, 0.9556420370809614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 152}], {
             RGBColor[
             0.5450088094571665, 0.6415017297412215, 0.9573242363949701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 164}], {
             RGBColor[
             0.5603355123887854, 0.6538866297618611, 0.9585704708972298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 168}], {
             RGBColor[
             0.6484161675011884, 0.7227146832455745, 0.9673445447930071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 210}], {
             RGBColor[
             0.6552711138009496, 0.7281806313524437, 0.9679983756905612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 241}], {
             RGBColor[
             0.5043427507916814, 0.6084871913315151, 0.9541228552921419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 277}], {
             RGBColor[
             0.6314975482838469, 0.7094789530545874, 0.9656632375882145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 161}], {
             RGBColor[
             0.6995406757086668, 0.765205759660442, 0.9706873350414988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 120}], {
             RGBColor[
             0.6484281756793662, 0.7233309191289238, 0.9669229767813994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 130}], {
             RGBColor[
             0.7681333759411456, 0.8187908984058845, 0.9775240143654442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 176}], {
             RGBColor[
             0.7178220255390589, 0.7794872890913491, 0.972509449143665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[
             0.6812131984197546, 0.7499472775380143, 0.9695039338670182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 220}], {
             RGBColor[
             0.8883220295580906, 0.910634198859243, 0.8463855721398013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 226}], {
             RGBColor[
             0.7817658957162078, 0.8294407264651509, 0.978882776533482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 228}], {
             RGBColor[
             0.6859262431866029, 0.7537735395999889, 0.9698749620155164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 266}], {
             RGBColor[
             0.8521497740791153, 0.8852562469464291, 0.9856774354298017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 152}], {
             RGBColor[
             0.494826361610452, 0.5986120434243756, 0.9539675522656763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 164}], {
             RGBColor[
             0.510153064542071, 0.6109969434450152, 0.955213786767936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 168}], {
             RGBColor[
             0.5982337196544738, 0.6798249969287287, 0.9639878606637133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 241}], {
             RGBColor[
             0.45416030294496695`, 0.5655975050146691, 0.9507661711628481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 130}], {
             RGBColor[
             0.6350714453352325, 0.7128965398691762, 0.9655917027264379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 176}], {
             RGBColor[
             0.5847600949331458, 0.6735929305546408, 0.9605771375046586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 287}], {
             RGBColor[
             0.5275576414856576, 0.6273340854157926, 0.9559504165265184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 125}], {
             RGBColor[
             0.6623950892188822, 0.7245165863850371, 0.7021747495380557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 127}], {
             RGBColor[
             0.7827973896827871, 0.8255599990448145, 0.7107427305413011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 136}], {
             RGBColor[
             0.7828954159249337, 0.8256395811642209, 0.7107504475261648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 137}], {
             RGBColor[
             0.675997532949933, 0.7362983394661725, 0.7030414852244294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 160}], {
             RGBColor[
             0.7993345630406925, 0.838985621367932, 0.7120445974056975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 181}], {
             RGBColor[
             0.8797842446964163, 0.9023931040116537, 0.719680481998417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 232}], {
             RGBColor[
             0.6272435330981088, 0.6897155245084947, 0.700094364898981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 240}], {
             RGBColor[
             0.9898168584528391, 0.9879497130107866, 0.6652453104672484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 246}], {
             RGBColor[
             0.7738775492354308, 0.8183184707354176, 0.710040528026833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 256}], {
             RGBColor[
             0.6060032193513287, 0.6673906080469548, 0.6988847604533303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 296}], {
             RGBColor[
             0.8182969771665645, 0.854358783296792, 0.7135520058022258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 299}], {
             RGBColor[
             0.992262973586439, 0.9853557995401205, 0.4420908215991487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 136}], {
             RGBColor[
             0.4735559803455753, 0.5813437896937925, 0.9522930699365313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 160}], {
             RGBColor[
             0.48999512746133417`, 0.5946898298975036, 0.953587219816064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 181}], {
             RGBColor[
             0.5704448091170579, 0.6580973125412253, 0.9612231044087836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 207}], {
             RGBColor[
             0.5992881014212058, 0.68066573232909, 0.9640884285378819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 231}], {
             RGBColor[
             0.2765436993680016, 0.40194733218092393`, 0.9392815738218883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 232}], {
             RGBColor[
             0.31790409751875043`, 0.4454197330380663, 0.9416369873093475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 240}], {
             RGBColor[
             0.6804774228734807, 0.7436539215403583, 0.9067879328776149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 246}], {
             RGBColor[
             0.4645381136560724, 0.5740226792649892, 0.9515831504371995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 256}], {
             RGBColor[
             0.29666378377197034`, 0.4230948165765264, 0.9404273828636968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 296}], {
             RGBColor[
             0.5089575415872061, 0.6100629918263637, 0.9550946282125923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 299}], {
             RGBColor[
             0.6829235380070806, 0.7410600080696921, 0.6836334440095152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 144}], {
             RGBColor[
             0.7383643582921652, 0.7955351155655872, 0.9745569168934806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 157}], {
             RGBColor[
             0.5597092402343468, 0.6517273865474272, 0.9592994855000451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 229}], {
             RGBColor[
             0.6093850840703077, 0.6929164321483628, 0.9629725410196623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 257}], {
             RGBColor[
             0.5223817454582405, 0.6193961867068025, 0.9569210105403192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 259}], {
             RGBColor[
             0.6314906646094103, 0.7108627382750612, 0.9647127732951101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 261}], {
             RGBColor[
             0.7916759989024476, 0.8377127619198822, 0.9797298275362611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 125}], {
             RGBColor[
             0.3618865090281298, 0.4878696380005218, 0.9442800662449654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 142}], {
             RGBColor[
             0.6230450425074257, 0.7002162309924774, 0.9660747862129376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 150}], {
             RGBColor[
             0.6413394319845045, 0.7148036805735265, 0.9678197214128557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 200}], {
             RGBColor[
             0.394635803921256, 0.5162354312095261, 0.9463668223564909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 237}], {
             RGBColor[
             0.6714812126002376, 0.7384397292451993, 0.9568892082592309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 282}], {
             RGBColor[
             0.6079702086165467, 0.6881959676433557, 0.9646369350989625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 295}], {
             RGBColor[
             0.6336548124580728, 0.7086761735565902, 0.9670867555422837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 136}], {
             RGBColor[
             0.45245123524909586`, 0.5630639202465534, 0.9509482942411771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 150}], {
             RGBColor[
             0.611403831499419, 0.6888749680403744, 0.9659122514209582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[
             0.4239208344908531, 0.5399016556311047, 0.9487022765831866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 192}], {
             RGBColor[
             0.30775803021670745`, 0.4386581287730831, 0.9409162921024755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 195}], {
             RGBColor[
             0.5500288281387535, 0.6403555108579058, 0.9599469782838623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 200}], {
             RGBColor[
             0.36470020343617066`, 0.4903067186763739, 0.9444593523645934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 256}], {
             RGBColor[
             0.2755590386754909, 0.40481494712928734`, 0.9390826071683425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 299}], {
             RGBColor[
             0.6618187929106012, 0.722780138622453, 0.6822886683141609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 155}], {
             RGBColor[
             0.9106186148546616, 0.9306931253689791, 0.961053532063476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 163}], {
             RGBColor[
             0.9210956893751243, 0.9390472601989843, 0.9620528447842326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 184}], {
             RGBColor[
             0.8475494174267405, 0.8811669104085615, 0.9548353392620689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 189}], {
             RGBColor[
             0.9780352582272034, 0.9827558897689863, 0.9048943240216559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 197}], {
             RGBColor[
             0.8667938857959303, 0.8962008353619493, 0.9567534480193278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 214}], {
             RGBColor[
             0.9540877275004553, 0.9652792828610618, 0.9626016808899762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 216}], {
             RGBColor[
             0.8661900681310866, 0.8957291284129891, 0.9566932651174932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 275}], {
             RGBColor[
             0.8688386933587274, 0.8977982545711195, 0.9569572553273744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 293}], {
             RGBColor[
             0.9356092575728793, 0.9506199855195603, 0.9634371618753497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 136}], {
             RGBColor[
             0.5728535357130008, 0.6641073329063307, 0.9595162752444224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 137}], {
             RGBColor[
             0.4659556527380001, 0.5747660912082824, 0.9518073129426872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 141}], {
             RGBColor[
             0.57714753189854, 0.6675933924520752, 0.9598543143535745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 165}], {
             RGBColor[
             0.7067840937936154, 0.7699664866687586, 0.9720936080861395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 170}], {
             RGBColor[
             0.544323134954758, 0.6409450682908819, 0.957270257586432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 192}], {
             RGBColor[
             0.42816033068061243`, 0.5397015414328604, 0.9494842731057209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 228}], {
             RGBColor[
             0.5815589447793905, 0.671174776160635, 0.9602015969350928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 232}], {
             RGBColor[
             0.41720165288617594`, 0.5281832762506046, 0.9488601926172386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 240}], {
             RGBColor[
             0.7797749782409061, 0.8264174647528966, 0.9140111381855061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 256}], {
             RGBColor[
             0.3959613391393959, 0.5058583597890647, 0.9476505881715879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 281}], {
             RGBColor[
             0.6899550863800055, 0.7566511877209214, 0.970460924936595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 299}], {
             RGBColor[
             0.7822210933745061, 0.8238235512822303, 0.6908566493174063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 173}], {
             RGBColor[
             0.7115211656609601, 0.7736561354720175, 0.9726462184646865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 209}], {
             RGBColor[
             0.7675497401228304, 0.8173326490220009, 0.9433490860033007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 218}], {
             RGBColor[
             0.5208628696738699, 0.6218989680629501, 0.9554233795657372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 276}], {
             RGBColor[
             0.5640318851681723, 0.6569455195832107, 0.9588218025987629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 279}], {
             RGBColor[
             0.5536708834132036, 0.6485339916007172, 0.9580061465870118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 161}], {
             RGBColor[
             0.8050476863387982, 0.8480840791626924, 0.9810824278267194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 230}], {
             RGBColor[
             0.8773510952562357, 0.9050399645690044, 0.9881637247577503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 263}], {
             RGBColor[
             0.7490179287132175, 0.8039967943121425, 0.9757142380672739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 265}], {
             RGBColor[
             0.9247849600055105, 0.9418944185936955, 0.9591260728630706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 269}], {
             RGBColor[
             0.8120889361991961, 0.8535847570691162, 0.9817842338085827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 289}], {
             RGBColor[
             0.7269546042753052, 0.7860847935920063, 0.973977332346901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 298}], {
             RGBColor[
             0.726429274421146, 0.7856583071505596, 0.973935976456435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 176}], {
             RGBColor[
             0.7044652951949253, 0.7690529098316015, 0.9711781750887034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 199}], {
             RGBColor[
             0.6678564680756209, 0.7395128982782667, 0.9681726598120567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 220}], {
             RGBColor[
             0.8749652992139569, 0.9001998195994954, 0.8450542980848397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 226}], {
             RGBColor[
             0.7684091653720742, 0.8190063472054032, 0.9775515024785204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 228}], {
             RGBColor[
             0.6725695128424694, 0.7433391603402414, 0.9685436879605549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 266}], {
             RGBColor[
             0.8387930437349816, 0.8748218676866816, 0.9843461613748402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 139}], {
             RGBColor[
             0.6780549949732513, 0.7382584870098697, 0.71839260976428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 143}], {
             RGBColor[
             0.9701130749249172, 0.9738819408927302, 0.7334264660133519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 172}], {
             RGBColor[
             0.9553211230790104, 0.9623814221778562, 0.7422150769568211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 174}], {
             RGBColor[
             0.8739081539367337, 0.8979926193232739, 0.7343098028877506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 183}], {
             RGBColor[
             0.7527365742342069, 0.8013409502579478, 0.7235941585429101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 283}], {
             RGBColor[
             0.99040306955434, 0.9884335328412222, 0.6730779777678136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 188}], {
             RGBColor[
             0.9655266195287546, 0.9738103898063006, 0.9432386204269203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 212}], {
             RGBColor[
             0.7059387276699385, 0.7681696001388385, 0.9614457750806882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 243}], {
             RGBColor[
             0.8900607305401761, 0.9148432105191736, 0.9778974990230361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 294}], {
             RGBColor[
             0.9334922302575053, 0.9494743094771181, 0.9820400342378325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 162}], {
             RGBColor[
             0.6856117049100979, 0.753258105105708, 0.9700280172628821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 164}], {
             RGBColor[
             0.6094506199094964, 0.6937604866575535, 0.9624369920758271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 210}], {
             RGBColor[
             0.7043862213216607, 0.7680544882481362, 0.9718648968691586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 239}], {
             RGBColor[
             0.5812739890496854, 0.6709434362621511, 0.9601791641762232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 241}], {
             RGBColor[
             0.5534578583123925, 0.6483610482272073, 0.9579893764707392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 277}], {
             RGBColor[
             0.6806126558045579, 0.7493528099502798, 0.9695297587668118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 144}], {
             RGBColor[
             0.7838910663673682, 0.8311009259297324, 0.9790945936831408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 159}], {
             RGBColor[
             0.6921706637717233, 0.7587306729917065, 0.9704433726674819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 175}], {
             RGBColor[
             0.8286999022243803, 0.8664986665762564, 0.983456499218011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 204}], {
             RGBColor[
             0.7467523747374294, 0.8020878977639136, 0.9753929559822742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 235}], {
             RGBColor[
             0.7157404257031995, 0.7778611274788311, 0.9723019747256829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 252}], {
             RGBColor[
             0.6294848868052918, 0.7078395352882867, 0.9655085186791172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 253}], {
             RGBColor[
             0.8153294386978726, 0.8558374218917832, 0.9821812124708991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 292}], {
             RGBColor[
             0.6614410968412181, 0.733783026206308, 0.9680242285925997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 224}], {
             RGBColor[
             0.8470143113303134, 0.8812842553804284, 0.9818825451498996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 249}], {
             RGBColor[
             0.8236783166864311, 0.8627704366894977, 0.9829043348294426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 254}], {
             RGBColor[
             0.7726670811242295, 0.8223326633523453, 0.9779758917282103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 258}], {
             RGBColor[
             0.7245607446059958, 0.7847516276426021, 0.9731811016833471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 260}], {
             RGBColor[
             0.8713428151086471, 0.8987976898283636, 0.9124556321372395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 288}], {
             RGBColor[
             0.7191178474142257, 0.7804995949888405, 0.9726386045580377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 137}], {
             RGBColor[
             0.4660536789801466, 0.5748456733276888, 0.9518150299275508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 165}], {
             RGBColor[
             0.706882120035762, 0.770046068788165, 0.9721013250710033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 181}], {
             RGBColor[
             0.6698403907266299, 0.74094043787317, 0.9684540267015385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 232}], {
             RGBColor[
             0.41729967912832244`, 0.528262858370011, 0.9488679096021024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 240}], {
             RGBColor[
             0.7798730044830526, 0.826497046872303, 0.9140188551703698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 256}], {
             RGBColor[
             0.3960593653815424, 0.5059379419084711, 0.9476583051564516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 296}], {
             RGBColor[
             0.608353123196778, 0.6929061171583084, 0.9623255505053471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 299}], {
             RGBColor[
             0.7823191196166526, 0.8239031334016367, 0.69086436630227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 170}], {
             RGBColor[
             0.43752327822190384`, 0.5516834087122401, 0.9495690122695604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 192}], {
             RGBColor[
             0.32136047394775824`, 0.45043988185421846`, 0.9417830277888493]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 195}], {
             RGBColor[
             0.5636312718698042, 0.6521372639390411, 0.9608137139702362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 220}], {
             RGBColor[
             0.677154874418024, 0.7387737758412471, 0.8290109617425061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 228}], {
             RGBColor[
             0.4747590880465363, 0.5819131165819932, 0.9525003516182212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 232}], {
             RGBColor[
             0.31040179615332175`, 0.4389216166719626, 0.9411589473003671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 256}], {
             RGBColor[
             0.2891614824065417, 0.4165967002104227, 0.9399493428547163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 266}], {
             RGBColor[
             0.6409826189390486, 0.7133958239284334, 0.9683028250325065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 299}], {
             RGBColor[
             0.6754212366416519, 0.7345618917035884, 0.6831554040005348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 154}], {
             RGBColor[
             0.7754224332406572, 0.8247165049532758, 0.9781891290638292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 171}], {
             RGBColor[
             0.9139298103812314, 0.9330836809463217, 0.9527120367659193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 245}], {
             RGBColor[
             0.7771382230670925, 0.8260568930061727, 0.9783601429587606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 258}], {
             RGBColor[
             0.7715150554833694, 0.8216640317521118, 0.9777996781655038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 147}], {
             RGBColor[
             0.5543943826394346, 0.6450842163700806, 0.959824128427764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 148}], {
             RGBColor[
             0.5541563665370697, 0.6448982763819238, 0.9598004052070671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 172}], {
             RGBColor[
             0.6402570171308017, 0.7129491316140816, 0.9681729035543449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 183}], {
             RGBColor[
             0.4376724682859984, 0.5519086596941734, 0.9495519851404338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 206}], {
             RGBColor[
             0.35955899530936786`, 0.4858536626015712, 0.9441317591289453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 244}], {
             RGBColor[
             0.6738111820045722, 0.7383694653230066, 0.9243550992752183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 272}], {
             RGBColor[
             0.3510585675494218, 0.4784910193198278, 0.9435901193887148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 149}], {
             RGBColor[
             0.48960019559914525`, 0.5943512949398808, 0.9535610783285968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 171}], {
             RGBColor[
             0.6763772623605724, 0.7409886936840122, 0.93251110613193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 196}], {
             RGBColor[
             0.49048091595275795`, 0.5950663033989434, 0.9536304118610182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 198}], {
             RGBColor[
             0.3874851570685647, 0.5100419003076857, 0.9459111894621062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 222}], {
             RGBColor[
             0.5339185083186617, 0.6295346720240655, 0.9575943621080312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 230}], {
             RGBColor[
             0.6259353992206667, 0.701890879384734, 0.9666405146903205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 245}], {
             RGBColor[
             0.5395856750464336, 0.6339619057438634, 0.9581592123247713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 263}], {
             RGBColor[
             0.4976022326776485, 0.6008477091278721, 0.9541910279998442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 289}], {
             RGBColor[
             0.4755389082397362, 0.5829357084077358, 0.9524541222794713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 298}], {
             RGBColor[
             0.47501357838557695`, 0.5825092219662891, 0.9524127663890052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 165}], {
             RGBColor[
             0.7111761162213012, 0.7735321283339094, 0.9724393641801553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 179}], {
             RGBColor[
             0.763983651850853, 0.8153627589173722, 0.9678840481304446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 232}], {
             RGBColor[
             0.42159367531386166`, 0.5317489179157554, 0.9492059487112544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[
             0.7841670006685919, 0.8299831064180474, 0.9143568942795217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 281}], {
             RGBColor[
             0.6943471088076911, 0.7602168293860723, 0.9708066810306106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[
             0.872562364978715, 0.90122156103233, 0.9877069713889304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 185}], {
             RGBColor[
             0.7025775022153128, 0.7664540222852488, 0.971874513776716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 210}], {
             RGBColor[
             0.8451424543370516, 0.8793576685803144, 0.9850916358338853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 237}], {
             RGBColor[
             0.9027041455944481, 0.9248576097040028, 0.9767764582353056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 239}], {
             RGBColor[
             0.7220302220650764, 0.7822466165943295, 0.97340590314095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 282}], {
             RGBColor[
             0.8391931416107572, 0.8746138481021591, 0.9845241850750373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 283}], {
             RGBColor[
             0.9209775068444283, 0.9379051997800405, 0.9198416042789417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 295}], {
             RGBColor[
             0.8648777454522834, 0.8950940540153937, 0.9869740055183585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 297}], {
             RGBColor[
             0.882875497669323, 0.9094449730972916, 0.9886906471916028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 167}], {
             RGBColor[
             0.8189907596036765, 0.8592543791624924, 0.9721208587672547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 172}], {
             RGBColor[
             0.9323150970824677, 0.948572585496942, 0.9832067598034169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 174}], {
             RGBColor[
             0.8509021279401912, 0.8841837826423598, 0.9753014857343463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 185}], {
             RGBColor[
             0.748997038928682, 0.8031735186655165, 0.9661025701121835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 237}], {
             RGBColor[
             0.9491236823078173, 0.9615771060842704, 0.9710045145707732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 239}], {
             RGBColor[
             0.7684497587784456, 0.8189661129745971, 0.9676339594764176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 283}], {
             RGBColor[
             0.9673970435577974, 0.974624696160308, 0.9140696606144094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 297}], {
             RGBColor[
             0.9292950343826922, 0.9461644694775592, 0.9829187035270704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 158}], {
             RGBColor[
             0.7888603053092675, 0.834982933158759, 0.9795898809806912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 235}], {
             RGBColor[
             0.7108060135437821, 0.7740063271969728, 0.9718101586363357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 252}], {
             RGBColor[
             0.6245504746458744, 0.7039847350064283, 0.9650167025897699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 253}], {
             RGBColor[
             0.8103950265384552, 0.8519826216099249, 0.9816893963815517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 257}], {
             RGBColor[
             0.562974041374026, 0.6511071967890895, 0.9609668712406321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 292}], {
             RGBColor[
             0.6565066846818006, 0.7299282259244497, 0.9675324125032525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 169}], {
             RGBColor[
             0.6559634927673444, 0.7188900649547614, 0.6969961401460546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 219}], {
             RGBColor[
             0.5259676513100143, 0.6210161468573339, 0.9577784347572715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 221}], {
             RGBColor[
             0.5436410705266037, 0.6348227562722943, 0.9595399560172884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 264}], {
             RGBColor[
             0.4370507766073291, 0.5502142489475446, 0.9498317591349399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 159}], {
             RGBColor[
             0.7693585101255811, 0.8198328633974175, 0.9711650582710483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 204}], {
             RGBColor[
             0.8239402210912871, 0.8631900881696247, 0.9761146415858405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 235}], {
             RGBColor[
             0.7929282720570572, 0.8389633178845421, 0.9730236603292493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 242}], {
             RGBColor[
             0.7904096625286666, 0.8369231372618509, 0.9728222821011312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 243}], {
             RGBColor[
             0.8873925144510951, 0.91285325932874, 0.9824140928796401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 292}], {
             RGBColor[
             0.7386289431950757, 0.794885216612019, 0.9687459141961661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 148}], {
             RGBColor[
             0.7455598601514617, 0.8011562963059092, 0.9752740972730274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 172}], {
             RGBColor[
             0.8316605107451938, 0.869207151538067, 0.9836465956203051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 183}], {
             RGBColor[
             0.6290759619003904, 0.7081666796181587, 0.9650256772063941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 206}], {
             RGBColor[
             0.5509624889237599, 0.6421116825255566, 0.9596054511949056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 244}], {
             RGBColor[
             0.8652146756189643, 0.894627485246992, 0.9398287913411786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 270}], {
             RGBColor[
             0.6480795463825163, 0.7235946456024733, 0.9665217089892506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 272}], {
             RGBColor[
             0.5424620611638138, 0.6347490392438133, 0.959063811454675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 172}], {
             RGBColor[
             0.8314224946428288, 0.8690212115499102, 0.9836228723996083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 183}], {
             RGBColor[
             0.6288379457980254, 0.707980739630002, 0.9650019539856972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 203}], {
             RGBColor[
             0.6916398874537495, 0.7589661850613489, 0.9699459528839283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 206}], {
             RGBColor[
             0.5507244728213949, 0.6419257425373999, 0.9595817279742087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 244}], {
             RGBColor[
             0.8649766595165993, 0.8944415452588352, 0.9398050681204817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 270}], {
             RGBColor[
             0.6478415302801513, 0.7234087056143166, 0.9664979857685538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 272}], {
             RGBColor[
             0.5422240450614488, 0.6345630992556563, 0.9590400882339782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 171}], {
             RGBColor[
             0.792476725294281, 0.8374106938565893, 0.941052070155447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 227}], {
             RGBColor[
             0.6507282599113615, 0.7265115550954402, 0.9662061210670514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 245}], {
             RGBColor[
             0.655685137980142, 0.7303839059164403, 0.9667001763482883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 289}], {
             RGBColor[
             0.5916383711734448, 0.6793577085803129, 0.9609950863029882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 298}], {
             RGBColor[
             0.5911130413192855, 0.6789312221388661, 0.9609537304125222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 200}], {
             RGBColor[
             0.6441531263925453, 0.7172407612493786, 0.9679990075324838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 237}], {
             RGBColor[
             0.9209985350715268, 0.9394450592850518, 0.9785213934352236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 282}], {
             RGBColor[
             0.857487531087836, 0.8892012976832082, 0.9862691202749552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 295}], {
             RGBColor[
             0.883172134929362, 0.9096815035964427, 0.9887189407182766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 167}], {
             RGBColor[
             0.732771121658676, 0.7911656365973325, 0.9739994353376225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 194}], {
             RGBColor[
             0.703445832743784, 0.7681012410951802, 0.9711827146040808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 251}], {
             RGBColor[
             0.7618463685469419, 0.8138794404465066, 0.9768973842238144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 286}], {
             RGBColor[
             0.6528127885880609, 0.726995054856919, 0.9671966958931901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 241}], {
             RGBColor[
             0.5748262658194156, 0.665708884077197, 0.9596715757847479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 277}], {
             RGBColor[
             0.701981063311581, 0.7667006458002693, 0.9712119580808205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 163}], {
             RGBColor[
             0.6230607362163465, 0.6995987011357377, 0.9663663267667265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 211}], {
             RGBColor[
             0.49821128850535096`, 0.6013421680864532, 0.9542389751056459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 216}], {
             RGBColor[
             0.5681551149723088, 0.6562805693497424, 0.9610067470999871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 219}], {
             RGBColor[
             0.5531303209833602, 0.6445430860929123, 0.9595092160498515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 221}], {
             RGBColor[
             0.5708037401999496, 0.6583496955078729, 0.9612707373098683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 171}], {
             RGBColor[
             0.8407464149151339, 0.8756809166076748, 0.9454791902566901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 179}], {
             RGBColor[
             0.82433339357502, 0.8634401121660737, 0.9732621541839495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 245}], {
             RGBColor[
             0.703954827600995, 0.7686541286675259, 0.9711272964495314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 156}], {
             RGBColor[
             0.5280074932946903, 0.6083366683529088, 0.9603313123368379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 184}], {
             RGBColor[
             0.7885973932984098, 0.8350336228837434, 0.9794957209854529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 197}], {
             RGBColor[
             0.8078418616675995, 0.8500675478371312, 0.981413829742712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 202}], {
             RGBColor[
             0.8762726606095712, 0.9041800500550828, 0.9880608626984214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 214}], {
             RGBColor[
             0.8951357033721246, 0.9191459953362437, 0.9872620626133601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 275}], {
             RGBColor[
             0.8098866692303968, 0.8516649670463015, 0.9816176370507584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 293}], {
             RGBColor[
             0.8766572334445486, 0.9044866979947424, 0.9880975435987338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 178}], {
             RGBColor[
             0.5884589593480679, 0.6555882372103161, 0.9331327665514366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 202}], {
             RGBColor[
             0.5526135631779305, 0.6279568805638307, 0.9626782612483993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 208}], {
             RGBColor[
             0.4532937168188047, 0.5497136197381427, 0.9529524967207078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 214}], {
             RGBColor[
             0.571476605940484, 0.6429228258449915, 0.9618794611633381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 268}], {
             RGBColor[
             0.588793095568748, 0.6558374354566014, 0.9325671610865089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 201}], {
             RGBColor[
             0.7075111715036679, 0.7639353828692697, 0.7342382023694787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 218}], {
             RGBColor[
             0.4513588040156289, 0.5646124787354738, 0.9501893737911002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 229}], {
             RGBColor[
             0.47132226192827475`, 0.5808197132124899, 0.9517609703265397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 257}], {
             RGBColor[
             0.38431892331620754`, 0.5072994677709295, 0.9457094398471966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 259}], {
             RGBColor[
             0.4934278424673774, 0.5987660193391882, 0.9535012026019875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 261}], {
             RGBColor[
             0.6536131767604146, 0.7256160429840093, 0.9685182568431385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 284}], {
             RGBColor[
             0.4026319344697829, 0.523161277593453, 0.9468763287243425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 175}], {
             RGBColor[
             0.8336691411662798, 0.8703806738052831, 0.9839517865155615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 177}], {
             RGBColor[
             0.5825151121626437, 0.6671914528423166, 0.9625680624879691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 217}], {
             RGBColor[
             0.7726444078872792, 0.8223149508473167, 0.9779736318718446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 252}], {
             RGBColor[
             0.6344541257471914, 0.7117215425173133, 0.9660038059766677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 253}], {
             RGBColor[
             0.820298677639772, 0.8597194291208099, 0.9826764997684495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 175}], {
             RGBColor[
             0.7320450874693181, 0.790273613356372, 0.9743134621130047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 204}], {
             RGBColor[
             0.6500975599823673, 0.7258628445440294, 0.966249918877268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 235}], {
             RGBColor[
             0.6190856109481373, 0.7016360742589467, 0.9631589376206767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 252}], {
             RGBColor[
             0.5328300720502297, 0.6316144820684023, 0.9563654815741109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 253}], {
             RGBColor[
             0.7186746239428103, 0.7796123686718989, 0.9730381753658928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 292}], {
             RGBColor[
             0.5647862820861559, 0.6575579729864236, 0.9588811914875935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 168}], {
             RGBColor[
             0.7140684483798048, 0.7760141624643844, 0.9725129328360009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[
             0.6862795378423887, 0.7542864780768811, 0.9697481765810712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 246}], {
             RGBColor[
             0.5803728423814033, 0.670211844800645, 0.960108222609487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 256}], {
             RGBColor[
             0.4124985124973013, 0.5192839821121822, 0.9489524550359842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 296}], {
             RGBColor[
             0.6247922703125369, 0.7062521573620195, 0.9636197003848797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 299}], {
             RGBColor[
             0.7987582667324115, 0.8372491736053478, 0.6921585161818027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 186}], {
             RGBColor[
             0.6121894702471122, 0.6946418201230657, 0.9635702660986186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 230}], {
             RGBColor[
             0.8060666568584591, 0.848896578595852, 0.9811796181445304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 265}], {
             RGBColor[
             0.853500521607734, 0.8857510326205431, 0.9521419662498507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 269}], {
             RGBColor[
             0.7408044978014194, 0.7974413710959638, 0.9748001271953628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 191}], {
             RGBColor[
             0.730232225407642, 0.7891822315496986, 0.9737463818866539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 203}], {
             RGBColor[
             0.7182129156038719, 0.7797252366147186, 0.9725945039908657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 210}], {
             RGBColor[
             0.8172424167609043, 0.8572848425669197, 0.9823843558724819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 239}], {
             RGBColor[
             0.694130184488929, 0.7601737905809349, 0.9706986231795465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 184}], {
             RGBColor[
             0.7990744678188726, 0.8433877577137487, 0.9804950337062095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.9295603086193355, 0.9449767370741736, 0.9305540184657966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 197}], {
             RGBColor[
             0.8183189361880623, 0.8584216826671365, 0.9824131424634686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 211}], {
             RGBColor[
             0.7477712920562608, 0.8030115744548871, 0.9755851875672926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 216}], {
             RGBColor[
             0.8177151185232185, 0.8579499757181763, 0.9823529595616338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 168}], {
             RGBColor[
             0.7342263854605415, 0.7923212760118961, 0.9741394997878728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 210}], {
             RGBColor[
             0.7410813317603029, 0.7977872241187652, 0.9747933306854268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 241}], {
             RGBColor[
             0.5901529687510347, 0.6780937840978365, 0.9609178102870075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 277}], {
             RGBColor[
             0.7173077662432001, 0.7790855458209089, 0.9724581925830802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 179}], {
             RGBColor[
             0.8936202137459285, 0.9177358531340556, 0.9801233418630098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 207}], {
             RGBColor[
             0.8326142411113925, 0.8693680114234624, 0.9838966836723539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 232}], {
             RGBColor[
             0.551230237208937, 0.6341220121324387, 0.9614452424438196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 240}], {
             RGBColor[
             0.9138035625636673, 0.9323562006347307, 0.926596188012087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 281}], {
             RGBColor[
             0.8239836707027666, 0.8625899236027557, 0.9830459747631758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 217}], {
             RGBColor[
             0.5717720951154083, 0.6601050417376175, 0.9609444889809469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 233}], {
             RGBColor[
             0.679709550681646, 0.7448891566839992, 0.947525129405784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 262}], {
             RGBColor[
             0.5938281430816472, 0.6773353940410165, 0.9631428297167346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 271}], {
             RGBColor[
             0.480565632556594, 0.5876552147406435, 0.9526734014706099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 291}], {
             RGBColor[
             0.6717920258846226, 0.7389842796541362, 0.9609274336659548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 174}], {
             RGBColor[
             0.7227858386154931, 0.7833650575930361, 0.9730041956416534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 185}], {
             RGBColor[
             0.6208807496039839, 0.7023547936161927, 0.9638052800194906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 194}], {
             RGBColor[
             0.6615491813640866, 0.7353712586110165, 0.9670068479410201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 215}], {
             RGBColor[
             0.6809412539603134, 0.7506757500297874, 0.9688335185031014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 282}], {
             RGBColor[
             0.7574963889994284, 0.810514619433103, 0.9764549513178119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 283}], {
             RGBColor[
             0.8392807542330993, 0.8738059711109845, 0.9117723705217164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 286}], {
             RGBColor[
             0.6109161372083634, 0.6942650723727553, 0.9630208292301294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 297}], {
             RGBColor[
             0.8011787450579941, 0.8453457444282355, 0.9806214134343776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 182}], {
             RGBColor[
             0.8105293251843648, 0.8519297124479672, 0.9817446637280309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 277}], {
             RGBColor[
             0.805388421355603, 0.8479135993046223, 0.9812322664788575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 187}], {
             RGBColor[
             0.9086921456244326, 0.9249542300183267, 0.717784562817946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 213}], {
             RGBColor[
             0.9587209230189255, 0.9648458191177094, 0.7225563522670495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 219}], {
             RGBColor[
             0.862755750758614, 0.8890307955159484, 0.7132160231834062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 221}], {
             RGBColor[
             0.8804291699752034, 0.9028374049309089, 0.714977544443423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 264}], {
             RGBColor[
             0.7738388760559287, 0.8182288976061591, 0.7052693475610745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[
             0.3997279561645162, 0.516618858936818, 0.9472459724325942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 195}], {
             RGBColor[
             0.6419987540865622, 0.7183162410216408, 0.966276658613981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 200}], {
             RGBColor[
             0.45667012938397933`, 0.5682674488401089, 0.9507890326947122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 225}], {
             RGBColor[
             0.34860317580699923`, 0.4628834732827731, 0.9443344918235683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 228}], {
             RGBColor[
             0.5531265702632941, 0.6480920936645927, 0.9579632962619662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 255}], {
             RGBColor[
             0.4978103079997581, 0.6031838599898375, 0.9536085974664352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 198}], {
             RGBColor[
             0.6903616867637004, 0.7531012992243942, 0.9334021812889564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 245}], {
             RGBColor[
             0.8424622047415693, 0.8770213046605717, 0.9456502041516216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 289}], {
             RGBColor[
             0.778415437934872, 0.8259951073244443, 0.9399451141063215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 298}], {
             RGBColor[
             0.7778901080807127, 0.8255686208829975, 0.9399037582158555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 174}], {
             RGBColor[
             0.8361101760942842, 0.8726832639274857, 0.9840900966778156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 183}], {
             RGBColor[
             0.7149385963917575, 0.7760315948621597, 0.973374452332975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 203}], {
             RGBColor[
             0.7777405380474816, 0.8270170402935068, 0.978318451231206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 206}], {
             RGBColor[
             0.636825123415127, 0.7099765977695576, 0.9679542263214865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 244}], {
             RGBColor[
             0.9510773101103314, 0.9624924004909929, 0.9481775664677595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 270}], {
             RGBColor[
             0.7339421808738834, 0.7914595608464743, 0.9748704841158315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 272}], {
             RGBColor[
             0.6283246956551809, 0.7026139544878143, 0.967412586581256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 186}], {
             RGBColor[
             0.6765017372331636, 0.7452257858670599, 0.9698893607784573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 196}], {
             RGBColor[
             0.7349244405766018, 0.7926559683540556, 0.9744886099950666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 209}], {
             RGBColor[
             0.9184163563749947, 0.9367851382275115, 0.9574393781117909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 230}], {
             RGBColor[
             0.8703789238445105, 0.8994805443398461, 0.9874987128243691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 263}], {
             RGBColor[
             0.7420457573014925, 0.7984373740829842, 0.9750492261338927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 276}], {
             RGBColor[
             0.7148985014203366, 0.7763980087887213, 0.9729120947072532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 279}], {
             RGBColor[
             0.7045374996653679, 0.7679864808062279, 0.972096438695502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 185}], {
             RGBColor[
             0.6527921179404985, 0.7272841970960602, 0.9669859069865823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 194}], {
             RGBColor[
             0.6934605497006011, 0.7603006620908839, 0.9701874749081116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 283}], {
             RGBColor[
             0.871192122569614, 0.8987353745908517, 0.9149529974888081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 297}], {
             RGBColor[
             0.8330901133945088, 0.8702751479081029, 0.9838020404014691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 177}], {
             RGBColor[
             0.617420296918339, 0.6948523859779556, 0.9659428646359416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 242}], {
             RGBColor[
             0.7530962398724037, 0.8073638872208055, 0.9759706859430878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 252}], {
             RGBColor[
             0.6693593105028866, 0.7393824756529522, 0.9693786081246402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 253}], {
             RGBColor[
             0.8552038623954673, 0.8873803622564488, 0.986051301916422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 280}], {
             RGBColor[
             0.8290616837659686, 0.8667812930661867, 0.9834925582210359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 199}], {
             RGBColor[
             0.6175451176735343, 0.7002092889637312, 0.9631580945902773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 226}], {
             RGBColor[
             0.7180978149699875, 0.7797027378908679, 0.9725369372567412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 287}], {
             RGBColor[
             0.5969514913453504, 0.683490455378218, 0.9615368888887839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 217}], {
             RGBColor[
             0.5563955636393383, 0.6467866630199892, 0.9599647099922246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 247}], {
             RGBColor[
             0.4159592452058198, 0.5343698212441969, 0.9478180678925269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 273}], {
             RGBColor[
             0.6775682845937125, 0.7406643814090592, 0.8893352907318751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 285}], {
             RGBColor[
             0.4594059007659045, 0.569641773477402, 0.95123834776856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 182}], {
             RGBColor[
             0.8856605663144357, 0.9108865354796503, 0.9559462879942345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 202}], {
             RGBColor[
             0.9367241266629488, 0.9514316189124901, 0.9608623169130202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 208}], {
             RGBColor[
             0.8374042803038229, 0.8731883580868022, 0.9511365523853288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 268}], {
             RGBColor[
             0.9729036590537663, 0.9793121738052608, 0.9307512167511298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 281}], {
             RGBColor[
             0.8767912063323184, 0.9044205541862186, 0.9784906587134651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 190}], {
             RGBColor[
             0.8234391713318439, 0.8625939941703409, 0.9828777446156269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 250}], {
             RGBColor[
             0.8723465524193701, 0.8988887444233368, 0.8811288199097036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 207}], {
             RGBColor[
             0.7955725118022604, 0.8402623805084675, 0.9802493853028891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 232}], {
             RGBColor[
             0.514188507899805, 0.6050163812174438, 0.9577979440743547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 240}], {
             RGBColor[
             0.8767618332545353, 0.9032505697197357, 0.9229488896426221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 246}], {
             RGBColor[
             0.660822524037127, 0.7336193274443668, 0.9677441072022066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 256}], {
             RGBColor[
             0.49294819415302493`, 0.5826914647559039, 0.9565883396287038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 296}], {
             RGBColor[
             0.7052419519682607, 0.7696596400057412, 0.9712555849775993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 299}], {
             RGBColor[
             0.8792079483881352, 0.9006566562490697, 0.6997944007745223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 208}], {
             RGBColor[
             0.7504953237851724, 0.8050119180074768, 0.9757660181635057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 268}], {
             RGBColor[
             0.8859947025351157, 0.9111357337259356, 0.9553806825293067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 244}], {
             RGBColor[
             0.7484927612655279, 0.8014519285710847, 0.9295566480538484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 189}], {
             RGBColor[
             0.8560140366709517, 0.8870963872837507, 0.9233365129436328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 197}], {
             RGBColor[
             0.7447726642396784, 0.8005413328767137, 0.9751956369413048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 202}], {
             RGBColor[
             0.81320346318165, 0.8546538350946653, 0.9818426698970143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 214}], {
             RGBColor[
             0.8320665059442035, 0.8696197803758261, 0.981043869811953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 216}], {
             RGBColor[
             0.7441688465748346, 0.8000696259277535, 0.9751354540394701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 275}], {
             RGBColor[
             0.7468174718024756, 0.8021387520858838, 0.9753994442493513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 293}], {
             RGBColor[
             0.8135880360166274, 0.8549604830343247, 0.9818793507973267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 237}], {
             RGBColor[
             0.7510136723081247, 0.8046775205379707, 0.9626889358230091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 239}], {
             RGBColor[
             0.5703397487787529, 0.6620665274282974, 0.9593183807286536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 282}], {
             RGBColor[
             0.6875026683244339, 0.7544337589361271, 0.9704366626627408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 283}], {
             RGBColor[
             0.7692870335581048, 0.8177251106140084, 0.9057540818666453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 295}], {
             RGBColor[
             0.7131872721659598, 0.7749139648493616, 0.9728864831060621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 297}], {
             RGBColor[
             0.7311850243829996, 0.7892648839312595, 0.9746031247793063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 196}], {
             RGBColor[
             0.5490383958966409, 0.6447731295435873, 0.9576414602003471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 230}], {
             RGBColor[
             0.6844928791645497, 0.7515977055293779, 0.9706515630296495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 263}], {
             RGBColor[
             0.5561597126215315, 0.6505545352725159, 0.9582020763391732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 269}], {
             RGBColor[
             0.61923072010751, 0.7001424980294896, 0.964272072080482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 276}], {
             RGBColor[
             0.5290124567403757, 0.6285151699782531, 0.9560649449125336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 279}], {
             RGBColor[
             0.5186514549854071, 0.6201036419957596, 0.9552492889007825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 205}], {
             RGBColor[
             0.8917035107797081, 0.9158891420905824, 0.9689019475171698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 213}], {
             RGBColor[
             0.8746614764274139, 0.9028953355226601, 0.9879071865128062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 264}], {
             RGBColor[
             0.6897794294644172, 0.7562784140111098, 0.9706201818068312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 212}], {
             RGBColor[
             0.7229277437860302, 0.7808399805412589, 0.9326878022411957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 243}], {
             RGBColor[
             0.9070497466562679, 0.9275135909215941, 0.9491395261835436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 294}], {
             RGBColor[
             0.9504812463735971, 0.9621446898795385, 0.9532820613983399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 197}], {
             RGBColor[
             0.8752585050401414, 0.9021303122371385, 0.9252546217008919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 211}], {
             RGBColor[
             0.8047108609083399, 0.8467202040248891, 0.918426666804716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 216}], {
             RGBColor[
             0.8746546873752976, 0.9016586052881783, 0.9251944387990572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 275}], {
             RGBColor[
             0.8773033126029386, 0.9037277314463088, 0.9254584290089384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 293}], {
             RGBColor[
             0.9440738768170904, 0.9565494623947496, 0.9319383355569137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 212}], {
             RGBColor[
             0.678641735394303, 0.7467347916867488, 0.9703206456832472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 250}], {
             RGBColor[
             0.9428509999489181, 0.954565142752697, 0.8879974097656073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 203}], {
             RGBColor[
             0.6499772406621723, 0.7264190087399256, 0.9657934096113141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 195}], {
             RGBColor[
             0.5258359498124165, 0.6170727141636192, 0.9584906741332699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 200}], {
             RGBColor[
             0.3405073251098337, 0.4670239219820873, 0.943003048214001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[
             0.23244037153285363`, 0.3616399464247515, 0.9365485073428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 228}], {
             RGBColor[
             0.43696376598914854`, 0.5468485668065711, 0.9501773117812551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 255}], {
             RGBColor[
             0.3816475037256125, 0.5019403331318159, 0.9458226129857241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 199}], {
             RGBColor[
             0.4599736015204348, 0.5693626117237963, 0.951487516387534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 220}], {
             RGBColor[
             0.6670824326587708, 0.730049533045025, 0.828369154660317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 236}], {
             RGBColor[
             0.5095579756663069, 0.6090392192320957, 0.9557863129284079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 249}], {
             RGBColor[
             0.6158351694537472, 0.692651179171644, 0.9662231502557888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 266}], {
             RGBColor[
             0.6309101771797956, 0.7046715811322112, 0.9676610179503176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 283}], {
             RGBColor[
             0.8099554653182075, 0.8507415756088321, 0.9089556497881748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 286}], {
             RGBColor[
             0.5815908482934715, 0.6712006768706029, 0.9602041084965878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 297}], {
             RGBColor[
             0.7718534561431023, 0.8222813489260833, 0.9778046927008358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 200}], {
             RGBColor[
             0.5827781230318797, 0.66872130406691, 0.962033734395388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 225}], {
             RGBColor[
             0.4747111694548996, 0.5633373285095742, 0.9555791935242441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.6239183016476585, 0.7036377152166386, 0.964853299167111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 230}], {
             RGBColor[
             0.7429155825079878, 0.7990278880163736, 0.9752508122462589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 263}], {
             RGBColor[
             0.6145824159649698, 0.6979847177595118, 0.9628013255557825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 279}], {
             RGBColor[
             0.5770741583288452, 0.6675338244827553, 0.9598485381173918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 289}], {
             RGBColor[
             0.5925190915270575, 0.6800727170393754, 0.9610644198354096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 298}], {
             RGBColor[
             0.5919937616728982, 0.6796462305979287, 0.9610230639449435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 214}], {
             RGBColor[
             0.8513109743133933, 0.884653705329214, 0.9829619785692121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 275}], {
             RGBColor[
             0.7660619401716653, 0.8171726770392717, 0.9773175530066103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 293}], {
             RGBColor[
             0.8328325043858171, 0.8699944079877124, 0.9837974595545856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 222}], {
             RGBColor[
             0.5479029327217897, 0.6416472775644474, 0.9584854372650575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 245}], {
             RGBColor[
             0.5535700994495616, 0.6460745112842452, 0.9590502874817977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 258}], {
             RGBColor[
             0.5479469318658384, 0.6416816500301842, 0.958489822688541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 278}], {
             RGBColor[
             0.5578695599539902, 0.6494332825074149, 0.9594788175241364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 290}], {
             RGBColor[
             0.5329386020504895, 0.6299570287109022, 0.9569939326333632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 220}], {
             RGBColor[
             0.7880451216925659, 0.8313561987316251, 0.8370342175864136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 226}], {
             RGBColor[
             0.6814889878506831, 0.750162726337533, 0.9695314219800943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 228}], {
             RGBColor[
             0.5856493353210783, 0.6744955394723712, 0.9605236074621288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 266}], {
             RGBColor[
             0.7518728662135906, 0.8059782468188114, 0.9763260808764141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 225}], {
             RGBColor[
             0.2893825447523168, 0.4132885363280423, 0.9400915676049753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 255}], {
             RGBColor[
             0.43858967694507567`, 0.5535889230351068, 0.9493656732478422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 282}], {
             RGBColor[
             0.6107839030245876, 0.6906330483192078, 0.9648162212185906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 295}], {
             RGBColor[
             0.6364685068661136, 0.7111132542324423, 0.9672660416619119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 209}], {
             RGBColor[
             0.9839104278759435, 0.9843508749522399, 0.72426536779122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 218}], {
             RGBColor[
             0.737223557426983, 0.7889171939931892, 0.7363396613536565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 229}], {
             RGBColor[
             0.7571870153396288, 0.8051244284702053, 0.7379112578890958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 257}], {
             RGBColor[
             0.6701836767275616, 0.7316041830286448, 0.7318597274097527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 259}], {
             RGBColor[
             0.7792925958787316, 0.8230707345969035, 0.7396514901645437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 261}], {
             RGBColor[
             0.9394779301717687, 0.9499207582417246, 0.7546685444056946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 208}], {
             RGBColor[
             0.8015588841336856, 0.8455570014403168, 0.9806820470822913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 214}], {
             RGBColor[
             0.9197417732553649, 0.9387662075471656, 0.9896090115249216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 268}], {
             RGBColor[
             0.9370582628836288, 0.9516808171587754, 0.9602967114480925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 275}], {
             RGBColor[
             0.834492739113637, 0.8712851792572233, 0.9839645859623198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 206}], {
             RGBColor[
             0.49704251622604767`, 0.5999215712809964, 0.9542773068058065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 244}], {
             RGBColor[
             0.811294702921252, 0.8524373740024318, 0.9345006469520795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 270}], {
             RGBColor[
             0.5941595736848041, 0.6814045343579131, 0.9611935646001515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 235}], {
             RGBColor[
             0.6736673219138434, 0.7449932990311541, 0.968108520935469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 253}], {
             RGBColor[
             0.7732563349085164, 0.8229695934441061, 0.9779877586806851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 292}], {
             RGBColor[
             0.6193679930518619, 0.700915197758631, 0.9638307748023858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 213}], {
             RGBColor[
             0.9417322881742011, 0.9557807311899651, 0.9736737369662734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 231}], {
             RGBColor[
             0.5688506612632477, 0.6370842688789436, 0.9440847489853186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 244}], {
             RGBColor[
             0.6703792882888975, 0.7353969314784826, 0.92413642204236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 270}], {
             RGBColor[
             0.4532441590524495, 0.564364091833964, 0.9508293396904322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 272}], {
             RGBColor[
             0.34762667383374696`, 0.47551848547530384`, 0.9433714421558564]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 231}], {
             RGBColor[
             0.5016714020532042, 0.5841124001481661, 0.9583078547159938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 232}], {
             RGBColor[
             0.5430318002039529, 0.6275848010053084, 0.960663268203453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 240}], {
             RGBColor[
             0.9056051255586832, 0.9258189895076004, 0.9258142137717205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 268}], {
             RGBColor[
             0.837738416524503, 0.8734375563330875, 0.9505709469204009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 218}], {
             RGBColor[
             0.7277580603879045, 0.7850279708184442, 0.9402165392128417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 276}], {
             RGBColor[
             0.7709270758822069, 0.8200745223387047, 0.9436149622458674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 279}], {
             RGBColor[
             0.7605660741272382, 0.8116629943562113, 0.9427993062341162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 239}], {
             RGBColor[
             0.7129047009004919, 0.774970173723363, 0.9725355027858229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 277}], {
             RGBColor[
             0.8122433676553642, 0.8533795474114916, 0.9818860973764116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 216}], {
             RGBColor[
             0.692865670812223, 0.7596934426688919, 0.9702256079005532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 221}], {
             RGBColor[
             0.6955142960398639, 0.7617625688270223, 0.9704895981104344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 243}], {
             RGBColor[
             0.6474618547974518, 0.7218728012541318, 0.9673466808373115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 250}], {
             RGBColor[
             0.7275491164818292, 0.7830295419397448, 0.8685717209773236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 294}], {
             RGBColor[
             0.690893354514781, 0.7565039002120764, 0.9714892160521078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 231}], {
             RGBColor[
             0.5518086269109534, 0.6240904623110215, 0.9630899879809549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 264}], {
             RGBColor[
             0.7398082068589101, 0.7961700031104926, 0.9753919712559348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 275}], {
             RGBColor[
             0.8533557818761904, 0.8862511245383842, 0.9831657858772587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 293}], {
             RGBColor[
             0.9201263460903423, 0.9390728554868251, 0.9896456924252339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 223}], {
             RGBColor[
             0.5175095077657876, 0.6163127960480534, 0.956129451926943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 234}], {
             RGBColor[
             0.7026691087961856, 0.7676497153653838, 0.9709991480147934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 271}], {
             RGBColor[
             0.6175599859439966, 0.6999631764887237, 0.9633357863435336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 274}], {
             RGBColor[
             0.7396420894268789, 0.7965332888391418, 0.9746842691919125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 282}], {
             RGBColor[
             0.7475631726807632, 0.8027547153497218, 0.9754649011463515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 286}], {
             RGBColor[
             0.6009829208896983, 0.6865051682893739, 0.9620307790586691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 233}], {
             RGBColor[
             0.8544623149302113, 0.886694275971371, 0.9619509198009373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 247}], {
             RGBColor[
             0.6060885409304552, 0.6894933192491969, 0.9632236372764024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 262}], {
             RGBColor[
             0.7685809073302127, 0.8191405133283882, 0.9775686201118878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 273}], {
             RGBColor[
             0.867697580318348, 0.8957878794140592, 0.9047408601157506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 229}], {
             RGBColor[
             0.5010346478515898, 0.6058015243364094, 0.9538624293107175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 284}], {
             RGBColor[
             0.4323443203930979, 0.5481430887173726, 0.9489777877085204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 221}], {
             RGBColor[
             0.7504333285178733, 0.8049634868334814, 0.97575983905464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 264}], {
             RGBColor[
             0.6438430345985986, 0.7203549795087315, 0.9660516421722916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 226}], {
             RGBColor[
             0.8885978189890191, 0.9108496476587618, 0.8464130602528774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 228}], {
             RGBColor[
             0.7927581664594143, 0.8351824607935998, 0.8374052457349118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 236}], {
             RGBColor[
             0.837629495838438, 0.8710328062399246, 0.8413330141272877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 266}], {
             RGBColor[
             0.9589816973519266, 0.96666516814004, 0.8532077191491971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 231}], {
             RGBColor[
             0.4735168738672313, 0.5620820481242209, 0.9555111801573284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 245}], {
             RGBColor[
             0.7000034506996586, 0.765567283000625, 0.9707334601277227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 261}], {
             RGBColor[
             0.7899581097002011, 0.8363707338186457, 0.9795586043951685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 278}], {
             RGBColor[
             0.7043029112040873, 0.7689260542237948, 0.9711619901700614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 290}], {
             RGBColor[
             0.6793719533005865, 0.749449800427282, 0.9686771052792882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 234}], {
             RGBColor[
             0.549170578920325, 0.6410466654670313, 0.9592851316100954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 271}], {
             RGBColor[
             0.4640614560681361, 0.573360126590371, 0.9516217699388356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 274}], {
             RGBColor[
             0.5861435595510183, 0.6699302389407891, 0.9629702527872146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 287}], {
             RGBColor[
             0.4518800078938946, 0.5634706781945353, 0.9506628017164444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 291}], {
             RGBColor[
             0.6552878493961647, 0.7246891915038638, 0.9598758021341804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 249}], {
             RGBColor[
             0.9159954210647369, 0.9357602309970225, 0.9886020573705971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 254}], {
             RGBColor[
             0.8649841855025353, 0.8953224576598703, 0.9836736142693648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 258}], {
             RGBColor[
             0.8168778489843016, 0.8577414219501271, 0.9788788242245017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 260}], {
             RGBColor[
             0.9636599194869528, 0.9717874841358884, 0.918153354678394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 288}], {
             RGBColor[
             0.8114349517925314, 0.8534893892963654, 0.9783363270991923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 234}], {
             RGBColor[
             0.45782288556302986`, 0.550144072777534, 0.9538959272158886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 255}], {
             RGBColor[
             0.33052272336809563`, 0.4482049474777709, 0.9429111323766983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 287}], {
             RGBColor[
             0.3605323145365995, 0.47256808550503815`, 0.9452735973222375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 228}], {
             RGBColor[
             0.6862020326175315, 0.7539889883995077, 0.9699024501285926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 266}], {
             RGBColor[
             0.8524255635100438, 0.8854716957459479, 0.9857049235428779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 264}], {
             RGBColor[
             0.6253415105928912, 0.7059014483386824, 0.9642075831659745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 266}], {
             RGBColor[
             0.7565859109804389, 0.809804508880786, 0.9766971090249124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 257}], {
             RGBColor[
             0.43399476715216845`, 0.5484885133718651, 0.9493824953668137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 259}], {
             RGBColor[
             0.5431036863033383, 0.6399550649401238, 0.9571742581216047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 261}], {
             RGBColor[
             0.7032890205963755, 0.7668050885849449, 0.9721913123627557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 284}], {
             RGBColor[
             0.4523077783057438, 0.5643503231943886, 0.9505493842439596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 263}], {
             RGBColor[
             0.7500368992328785, 0.8048092937453022, 0.975811428385085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 269}], {
             RGBColor[
             0.8131079067188569, 0.8543972565022758, 0.9818814241263938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 289}], {
             RGBColor[
             0.7279735747949662, 0.786897293025166, 0.9740745226647121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 298}], {
             RGBColor[
             0.7274482449408068, 0.7864708065837193, 0.9740331667742459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 240}], {
             RGBColor[
             0.6242211216562278, 0.6905729902165767, 0.9033627725431861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 256}], {
             RGBColor[
             0.24040748255471753`, 0.3700138852527449, 0.9370022225292678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 296}], {
             RGBColor[
             0.4527012403699532, 0.5569820605025821, 0.9516694678781633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 299}], {
             RGBColor[
             0.6266672367898277, 0.6879790767459106, 0.6802082836750862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 262}], {
             RGBColor[
             0.8765183628964504, 0.9039246282747699, 0.964149260536725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 288}], {
             RGBColor[
             0.8229691291864464, 0.8620915599112651, 0.9588119733665523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 291}], {
             RGBColor[
             0.9544822456994256, 0.9655735138878896, 0.9619338644859452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 255}], {
             RGBColor[
             0.6070300177557887, 0.6904444594845984, 0.9631700328587555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 271}], {
             RGBColor[
             0.649221057098534, 0.7246970459077013, 0.9664914660266859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 274}], {
             RGBColor[
             0.7713031605814162, 0.8212671582581195, 0.9778399488750649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 287}], {
             RGBColor[
             0.6370396089242926, 0.7148075975118657, 0.9655324978042947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 252}], {
             RGBColor[
             0.5563998339817058, 0.6507449365555269, 0.9582240836323122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 253}], {
             RGBColor[
             0.7422443858742865, 0.7987428231590235, 0.974896777424094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 292}], {
             RGBColor[
             0.5883560440176321, 0.6766884274735483, 0.9607397935457946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 249}], {
             RGBColor[
             0.7863822326334143, 0.8336344523665435, 0.9791870097227593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 266}], {
             RGBColor[
             0.8014572403594626, 0.8456548543271107, 0.9806248774172881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 239}], {
             RGBColor[
             0.7704663921578883, 0.8204701148470513, 0.9642203251872432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 282}], {
             RGBColor[
             0.8876293117035692, 0.912837346354881, 0.9753386071213304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 283}], {
             RGBColor[
             0.9694136769372401, 0.9761286980327624, 0.910656026325235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 295}], {
             RGBColor[
             0.9133139155450951, 0.9333175522681155, 0.9777884275646518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 297}], {
             RGBColor[
             0.9313116677621349, 0.9476684713500134, 0.979505069237896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 251}], {
             RGBColor[
             0.7448732164761307, 0.8006198850480555, 0.9752056590485203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 300}], {
             RGBColor[
             0.6233938776992625, 0.7036314717749803, 0.9645251949934273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 295}], {
             RGBColor[
             0.7326399920157234, 0.7907065591584422, 0.9744178724702961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 256}], {
             RGBColor[
             0.6029808079094477, 0.6682480737550369, 0.9021531680975352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 281}], {
             RGBColor[
             0.8969745551500572, 0.9190409016868937, 0.9249635048625422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 299}], {
             RGBColor[
             0.9892405621445579, 0.9862132652482025, 0.6453592292433536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 277}], {
             RGBColor[
             0.661315004646096, 0.7336861073905627, 0.9680105769779923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 243}], {
             RGBColor[
             0.7346010057452609, 0.792616289567578, 0.9742065940011505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 280}], {
             RGBColor[
             0.7135835977163971, 0.7761035733460702, 0.9721366555005897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 294}], {
             RGBColor[
             0.7780325054625901, 0.8272473885255225, 0.9783491292159469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 294}], {
             RGBColor[
             0.8750153573850186, 0.9031775105924115, 0.9879409399944558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 270}], {
             RGBColor[
             0.7674963457476538, 0.8168798945553993, 0.9310526798367051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 272}], {
             RGBColor[
             0.6618788605289513, 0.7280342881967392, 0.9235947823021294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 289}], {
             RGBColor[
             0.641623850620733, 0.7189683193842953, 0.9655932202991628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 298}], {
             RGBColor[
             0.6410985207665738, 0.7185418329428486, 0.9655518644086968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 256}], {
             RGBColor[
             0.3870414986920395, 0.49861683147966784`, 0.9469483856571198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 296}], {
             RGBColor[
             0.5993352565072751, 0.6855850067295051, 0.9616156310060153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 299}], {
             RGBColor[
             0.7733012529271497, 0.8165820229728336, 0.6901544468029382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 267}], {
             RGBColor[
             0.5605763140644663, 0.6539388217157509, 0.9586874038383421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 273}], {
             RGBColor[
             0.7272612618848293, 0.783371037638267, 0.8925942180160529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 285}], {
             RGBColor[
             0.5090988780570214, 0.6123484297066095, 0.9544972750527377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 270}], {
             RGBColor[
             0.7010139036187684, 0.7652034463775208, 0.9717297556358186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 254}], {
             RGBColor[
             0.8416481908586531, 0.8768086389689396, 0.9846954039489079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 288}], {
             RGBColor[
             0.7880989571486492, 0.8349755706054347, 0.9793581167787353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 300}], {
             RGBColor[
             0.6275456252786418, 0.7068748485384417, 0.9649390023918527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 253}], {
             RGBColor[
             0.6559888469763788, 0.7287212309684791, 0.9681033213775282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 292}], {
             RGBColor[
             0.5021005051197244, 0.6066668352830038, 0.953946337499229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 292}], {
             RGBColor[
             0.6879450570123051, 0.7546647218865004, 0.9706190312910108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 258}], {
             RGBColor[
             0.7425306187782179, 0.798789829922044, 0.9749721708028125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 260}], {
             RGBColor[
             0.889312689280869, 0.9128358921078055, 0.9142467012567047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 288}], {
             RGBColor[
             0.7370877215864478, 0.7945377972682823, 0.9744296736775029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 287}], {
             RGBColor[
             0.5097394467293583, 0.6128684722121025, 0.9545477029651044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 296}], {
             RGBColor[
             0.43146092662317315`, 0.5346571440410424, 0.9504598634325125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 299}], {
             RGBColor[
             0.6054269230430476, 0.6656541602843706, 0.6789986792294355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 259}], {
             RGBColor[
             0.45610034769127117`, 0.5664348194985634, 0.9511227276422616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 261}], {
             RGBColor[
             0.6162856819843083, 0.6932848431433845, 0.9661397818834127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 260}], {
             RGBColor[
             0.8412063527626353, 0.8752548563980622, 0.9094519112118415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 278}], {
             RGBColor[
             0.704346910348136, 0.7689604266895316, 0.9711663755935448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 290}], {
             RGBColor[
             0.6794159524446353, 0.7494841728930188, 0.9686814907027717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 260}], {
             RGBColor[
             0.7765988450538637, 0.8236011448253229, 0.9038204660313931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 261}], {
             RGBColor[
             0.7253946011354782, 0.7847513947116431, 0.9739315446382035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 261}], {
             RGBColor[
             0.936784179346901, 0.950451168470144, 0.9188375202725443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 278}], {
             RGBColor[
             0.8511289808507871, 0.883006488875293, 0.910440906047437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 290}], {
             RGBColor[
             0.8261980229472864, 0.8635302350787804, 0.907956021156664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 278}], {
             RGBColor[
             0.7999247369324016, 0.8441567387616133, 0.9805519846542474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 290}], {
             RGBColor[
             0.7749937790289009, 0.8246804849651006, 0.9780670997634743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 271}], {
             RGBColor[
             0.6773744447713983, 0.7466906863314142, 0.9692975326015508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 291}], {
             RGBColor[
             0.868600838099427, 0.8980197512449068, 0.9775515647968958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 269}], {
             RGBColor[
             0.6847747401758388, 0.753354086245414, 0.9694319374359174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 276}], {
             RGBColor[
             0.5945564768087045, 0.6817267581941775, 0.961224810267969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 279}], {
             RGBColor[
             0.5841954750537359, 0.673315230211684, 0.9604091542562179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 289}], {
             RGBColor[
             0.599640408251948, 0.6858541227683042, 0.9616250359742357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 298}], {
             RGBColor[
             0.5991150783977888, 0.6854276363268574, 0.9615836800837696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 269}], {
             RGBColor[
             0.8605417714681318, 0.8912517105269668, 0.9528437722317141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 273}], {
             RGBColor[
             0.8221853534523591, 0.8602333818806134, 0.9002046266776903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 285}], {
             RGBColor[
             0.6040229696245509, 0.6892107739489559, 0.9621076837143752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 286}], {
             RGBColor[
             0.5932291048848721, 0.6804478282952195, 0.9612579511428383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 298}], {
             RGBColor[
             0.6621860858837673, 0.735015599083831, 0.9676536758250784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 272}], {
             RGBColor[
             0.44474373129250344`, 0.5570014485522206, 0.9502876999502015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 274}], {
             RGBColor[
             0.6861940377292273, 0.7535806193814594, 0.9701765872038051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 291}], {
             RGBColor[
             0.7553383275743737, 0.8083395719445339, 0.967082136550771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 285}], {
             RGBColor[
             0.7707079174449141, 0.818642989871472, 0.896014497892086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 287}], {
             RGBColor[
             0.6740125895549858, 0.7436911709856235, 0.9692176189814139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 293}], {
             RGBColor[
             0.8348773119486144, 0.8715918271968828, 0.9840012668626321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 279}], {
             RGBColor[
             0.5570482191725801, 0.6512758649174211, 0.9582720228295785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 290}], {
             RGBColor[
             0.6893385805327871, 0.7572358053702497, 0.9696704855383671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 283}], {
             RGBColor[
             0.9059026729535493, 0.9258849364309187, 0.9184037531649666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 295}], {
             RGBColor[
             0.8498029115614043, 0.8830737906662719, 0.9855361544043834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 297}], {
             RGBColor[
             0.8678006637784441, 0.8974247097481698, 0.9872527960776276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 295}], {
             RGBColor[
             0.9315872767950752, 0.9463651423441533, 0.9208535736082879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 297}], {
             RGBColor[
             0.9495850290121151, 0.9607160614260513, 0.9225702152815323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 291}], {
             RGBColor[
             0.815051604389423, 0.856186682881402, 0.9722142776267231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 298}], {
             RGBColor[
             0.5770517539598765, 0.6675156356067211, 0.9598467743633967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 297}], {
             RGBColor[
             0.89348526761997, 0.9179049156614043, 0.989702616520949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 299}], {
             RGBColor[
             0.8177206808582833, 0.852622335534208, 0.693665924578331]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.10302533798448267`], {
             RGBColor[
             0.7617031670060385, 0.813767570314381, 0.9768831112325118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.10302533798448267`], {
             RGBColor[
             0.5153662450734531, 0.6174365605922154, 0.9549906651423931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.10302533798448267`], {
             RGBColor[
             0.8708896995721249, 0.8998878230404082, 0.9875474310692438]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.10302533798448267`], {
             RGBColor[
             0.7828124315913454, 0.8302582882447755, 0.978987085449082]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.10302533798448267`], {
             RGBColor[
             0.9204373188443341, 0.939395749713771, 0.9922733272271089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.10302533798448267`], {
             RGBColor[
             0.9751389425852715, 0.9809792446031166, 0.9269674647876065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.10302533798448267`], {
             RGBColor[
             0.49447436167971365`, 0.6004755884845563, 0.9533459795521474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.10302533798448267`], {
             RGBColor[
             0.7681067477344625, 0.8187700962484419, 0.9775213603146569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.10302533798448267`], {
             RGBColor[
             0.5380975879115313, 0.6358908887434923, 0.956780159718259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.10302533798448267`], {
             RGBColor[
             0.9102031056071151, 0.9312352658787305, 0.991297178832353]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.10302533798448267`], {
             RGBColor[
             0.6138265444827234, 0.6973710672386019, 0.9627418205838516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.10302533798448267`], {
             RGBColor[
             0.8071546632891565, 0.8492746246549187, 0.9814132916136311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.10302533798448267`], {
             RGBColor[
             0.9884068249842345, 0.9894739384470423, 0.8417924423938259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.10302533798448267`], {
             RGBColor[
             0.4977866186345389, 0.6031646278959588, 0.9536067325528282]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.10302533798448267`], {
             RGBColor[
             0.7022390377745596, 0.7673137406146289, 0.9709562825545999]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.10302533798448267`], {
             RGBColor[
             0.9883842612027267, 0.9894646077435262, 0.8421663826466055]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.10302533798448267`], {
             RGBColor[
             0.6376181538228324, 0.716686167500689, 0.9646147832226416]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.10302533798448267`], {
             RGBColor[
             0.8849852259972657, 0.9111272131989432, 0.9888918749628987]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.10302533798448267`], {
             RGBColor[
             0.6883720553909852, 0.7564807485836109, 0.9695741513449233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.10302533798448267`], {
             RGBColor[
             0.4421734050330923, 0.5574101119832945, 0.949395876263487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.10302533798448267`], {
             RGBColor[
             0.42888178130158106`, 0.5458975755634927, 0.9485489457526365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.10302533798448267`], {
             RGBColor[
             0.9692880567499441, 0.9766156635270756, 0.9368714883513927]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.10302533798448267`], {
             RGBColor[
             0.9029396773408761, 0.9254436053397395, 0.9906043865601801]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.10302533798448267`], {
             RGBColor[
             0.41101411231200136`, 0.5304214987398744, 0.9474104336843798]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.10302533798448267`], {
             RGBColor[
             0.6710080376416483, 0.7429158459464061, 0.967843468331641]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.10302533798448267`], {
             RGBColor[
             0.5377195993588018, 0.6355840206081962, 0.9567504030747704]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.10302533798448267`], {
             RGBColor[
             0.638026830237253, 0.7170179494245783, 0.9646469557270158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.10302533798448267`], {
             RGBColor[
             0.9059699354796025, 0.9278598509253939, 0.9908934152865952]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.10302533798448267`], {
             RGBColor[
             0.9951539528309019, 0.9920431200528538, 0.7139158558591967]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.10302533798448267`], {
             RGBColor[
             0.9619117354084004, 0.97111441514817, 0.9493576763299042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.10302533798448267`], {
             RGBColor[
             0.9452463914186992, 0.9586854288876472, 0.977567756686628]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.10302533798448267`], {
             RGBColor[
             0.563949171867946, 0.6568783691998953, 0.9588152911047803]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.10302533798448267`], {
             RGBColor[
             0.3800420550153395, 0.5035950594103688, 0.9454369215809514]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.10302533798448267`], {
             RGBColor[
             0.813817334033695, 0.8544795536787253, 0.9820773643672487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.10302533798448267`], {
             RGBColor[
             0.8724727813692761, 0.9011501294938458, 0.9876984268242899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.10302533798448267`], {
             RGBColor[
             0.7416844610643822, 0.7981288050849589, 0.9748878337096908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.10302533798448267`], {
             RGBColor[
             0.7814775464061178, 0.8292154657925725, 0.9788540365690297]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.10302533798448267`], {
             RGBColor[
             0.9858956806183622, 0.9884355157182876, 0.8834086031696304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.10302533798448267`], {
             RGBColor[
             0.9522939253651754, 0.8485683417195633, 0.2804727764245694]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.10302533798448267`], {
             RGBColor[
             0.701121459666595, 0.7664406801027787, 0.9708448928131591]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.10302533798448267`], {
             RGBColor[
             0.8367301911179763, 0.8726499582342258, 0.9842892666583338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.10302533798448267`], {
             RGBColor[
             0.986177924910682, 0.9885522309865094, 0.8787310848210769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.10302533798448267`], {
             RGBColor[
             0.7950157268072309, 0.8397915952159041, 0.9802033958699238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.10302533798448267`], {
             RGBColor[
             0.7024941910317783, 0.7675130682784046, 0.9709817138467367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.10302533798448267`], {
             RGBColor[
             0.6842678906912428, 0.7532745439273651, 0.9691650865632527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.10302533798448267`], {
             RGBColor[
             0.9361803809947428, 0.9519240131576902, 0.9929141475401715]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.10302533798448267`], {
             RGBColor[
             0.6571412549771389, 0.7320830099374399, 0.9664613570280943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.10302533798448267`], {
             RGBColor[
             0.8631074073187056, 0.8936824344422273, 0.9868051490867783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.10302533798448267`], {
             RGBColor[
             0.8314157369273044, 0.8684123567196, 0.9837823692733584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.10302533798448267`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.10302533798448267`], {
             RGBColor[
             0.4713880581803114, 0.581733087277621, 0.9515285411727583]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.10302533798448267`], {
             RGBColor[
             0.621876430825197, 0.703906327614669, 0.9633755371244364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.10302533798448267`], {
             RGBColor[
             0.9718779579532523, 0.9785472076039289, 0.9324874611686085]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.10302533798448267`], {
             RGBColor[
             0.6670261704581503, 0.7398051810393461, 0.9674465930234544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.10302533798448267`], {
             RGBColor[
             0.5309578041377483, 0.6300944906323417, 0.9562180897856971]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.10302533798448267`], {
             RGBColor[
             0.7679980311891517, 0.8186851660569687, 0.9775105244654342]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.10302533798448267`], {
             RGBColor[
             0.5834332301606704, 0.6726964054687523, 0.9603491475460407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.10302533798448267`], {
             RGBColor[
             0.7182914926950925, 0.7798540404017251, 0.9725562412423584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.10302533798448267`], {
             RGBColor[
             0.7561888881748648, 0.8094597737813968, 0.9763334994524859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.10302533798448267`], {
             RGBColor[
             0.7512723471080576, 0.8056189345329108, 0.9758434645866351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.10302533798448267`], {
             RGBColor[
             0.83110840574313, 0.8681672991756222, 0.983753055750654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.10302533798448267`], {
             RGBColor[
             0.968284107926305, 0.975866920138221, 0.9385709118380245]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.10302533798448267`], {
             RGBColor[
             0.9194415166062477, 0.9386017240394526, 0.9921783467206772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.10302533798448267`], {
             RGBColor[
             0.8533904347600846, 0.8859343842841765, 0.9858783355696933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.10302533798448267`], {
             RGBColor[
             0.9909474632623851, 0.9905245576664832, 0.7996874911637728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.10302533798448267`], {
             RGBColor[
             0.9148245629560514, 0.9349202905226545, 0.9917379775599182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.10302533798448267`], {
             RGBColor[
             0.7471689424884415, 0.8024133236570364, 0.9754344755626481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.10302533798448267`], {
             RGBColor[
             0.8179674722793551, 0.8577216732184538, 0.9824910113623291]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.10302533798448267`], {
             RGBColor[
             0.5042318839553724, 0.6083971846393054, 0.9541141274486691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.10302533798448267`], {
             RGBColor[
             0.7197815920021928, 0.7810181173056061, 0.9727047604155205]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.10302533798448267`], {
             RGBColor[
             0.5935441538210676, 0.680904908788183, 0.9611451164941209]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.10302533798448267`], {
             RGBColor[
             0.8785299845580008, 0.9059799788981343, 0.9882761682717596]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.10302533798448267`], {
             RGBColor[
             0.5427661965241153, 0.6396810755336093, 0.9571476896899185]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.10302533798448267`], {
             RGBColor[
             0.7358626825007653, 0.7935807874239054, 0.9743075732300833]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.10302533798448267`], {
             RGBColor[
             0.8517033165675121, 0.8845891220330225, 0.9857174167303775]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.10302533798448267`], {
             RGBColor[
             0.3026826491840653, 0.43546903385380675`, 0.9405487011409562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.10302533798448267`], {
             RGBColor[
             0.48029293354952834`, 0.5889624662624151, 0.9522295655814563]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.10302533798448267`], {
             RGBColor[
             0.924609074904749, 0.9427221947570443, 0.9926712330443219]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.10302533798448267`], {
             RGBColor[
             0.910144057340591, 0.9311881823938266, 0.991291546755979]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.10302533798448267`], {
             RGBColor[
             0.8082761412121094, 0.8501507317318774, 0.981525070052184]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.10302533798448267`], {
             RGBColor[
             0.636749400905665, 0.7159808747456595, 0.9645463918106554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.10302533798448267`], {
             RGBColor[
             0.9927448660231439, 0.9912678298992009, 0.7698998758887629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.10302533798448267`], {
             RGBColor[
             0.8184398848959499, 0.8580907255450065, 0.9825380970370043]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.10302533798448267`], {
             RGBColor[
             0.7099158011059519, 0.7733108864746747, 0.9717214305800409]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.10302533798448267`], {
             RGBColor[
             0.9849437441247384, 0.9880418655145221, 0.8991846544016523]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.10302533798448267`], {
             RGBColor[
             0.808137893920519, 0.8500427318969687, 0.9815112908541527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.10302533798448267`], {
             RGBColor[
             0.8507562632840862, 0.8838339674518952, 0.9856270859427598]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.10302533798448267`], {
             RGBColor[
             0.520895272139779, 0.6219252738444896, 0.9554259304065478]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.10302533798448267`], {
             RGBColor[
             0.655487721267856, 0.7307912568364264, 0.9662965482411041]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.10302533798448267`], {
             RGBColor[
             0.3105107191580696, 0.443370511037356, 0.9410064463442723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.10302533798448267`], {
             RGBColor[
             0.7975215921357374, 0.8417491962558152, 0.9804531571072265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.10302533798448267`], {
             RGBColor[
             0.964223521424026, 0.9728385413734214, 0.9454444256158084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.10302533798448267`], {
             RGBColor[
             0.7975215921357374, 0.8417491962558152, 0.9804531571072265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.10302533798448267`], {
             RGBColor[
             0.3629908890250427, 0.48882619644609515`, 0.9443504363618037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.10302533798448267`], {
             RGBColor[
             0.4234350544011961, 0.5411798944828333, 0.9482018851308954]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.10302533798448267`], {
             RGBColor[
             0.9556544673050266, 0.9664477548420101, 0.9599495990720225]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.10302533798448267`], {
             RGBColor[
             0.5729515619551473, 0.6641869150257371, 0.9595239922292862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.10302533798448267`], {
             RGBColor[
             0.29283517298551565`, 0.42511871200307844`, 0.9399879019394843]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.10302533798448267`], {
             RGBColor[
             0.49353487497996884`, 0.59971287085831, 0.9532720197176903]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.10302533798448267`], {
             RGBColor[
             0.558459471257982, 0.6524215829365324, 0.958383121763328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.10302533798448267`], {
             RGBColor[
             0.9095054654071626, 0.9306789865202271, 0.9912306372872908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.10302533798448267`], {
             RGBColor[
             0.9898937405632071, 0.9900888162509349, 0.8171504032360839]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.10302533798448267`], {
             RGBColor[
             0.5819285105051454, 0.6714748062655491, 0.9602306905027881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.10302533798448267`], {
             RGBColor[
             0.735091397722567, 0.7929782538931955, 0.9742306987714585]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.10302533798448267`], {
             RGBColor[
             0.3731721213186724, 0.4976446681352231, 0.9449991754806436]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.10302533798448267`], {
             RGBColor[
             0.988189709622346, 0.9893841556652911, 0.8453906058168652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.10302533798448267`], {
             RGBColor[
             0.9584036476817711, 0.9684980890656164, 0.9552959537952721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.10302533798448267`], {
             RGBColor[
             0.7818848212766469, 0.8295336320168337, 0.978894629921924]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.10302533798448267`], {
             RGBColor[
             0.9872993858765008, 0.9890159839161076, 0.8601455743695141]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.10302533798448267`], {
             RGBColor[
             0.748083579489441, 0.803127845033716, 0.975525638031139]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.10302533798448267`], {
             RGBColor[
             0.7416844610643822, 0.7981288050849589, 0.9748878337096908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.10302533798448267`], {
             RGBColor[
             0.3161106700174467, 0.44822090701003436`, 0.9413632702611897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.10302533798448267`], {
             RGBColor[
             0.6653845322034085, 0.738522720757829, 0.9672829698642035]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.10302533798448267`], {
             RGBColor[
             0.9809175949873316, 0.9852889541028981, 0.9171857135848451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.10302533798448267`], {
             RGBColor[
             0.9856149807885023, 0.988319439124984, 0.8880605257782822]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.10302533798448267`], {
             RGBColor[
             0.4745252944294322, 0.5842800369955397, 0.9517755159023641]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.10302533798448267`], {
             RGBColor[
             0.665318103476312, 0.7384708261313442, 0.9672763488694982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.10302533798448267`], {
             RGBColor[
             0.7814901062852793, 0.8292252776656321, 0.9788552884204058]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.10302533798448267`], {
             RGBColor[
             0.37416039873600326`, 0.4985006643618478, 0.9450621476437765]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.10302533798448267`], {
             RGBColor[
             0.5153662450734531, 0.6174365605922154, 0.9549906651423931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.10302533798448267`], {
             RGBColor[
             0.99283926989472, 0.9870922473027046, 0.46197690282304343`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.10302533798448267`], {
             RGBColor[
             0.37416039873600326`, 0.4985006643618478, 0.9450621476437765]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.10302533798448267`], {
             RGBColor[
             0.6977720623763797, 0.7638241054833002, 0.9705110561931677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.10302533798448267`], {
             RGBColor[
             0.39182210951321517`, 0.513798350533674, 0.9461875362368629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.10302533798448267`], {
             RGBColor[
             0.33195090854304443`, 0.46194092546736965`, 0.9423725962530679]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.10302533798448267`], {
             RGBColor[
             0.9695706389829923, 0.9768264128937971, 0.936393150340092]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.10302533798448267`], {
             RGBColor[
             0.5727555094708543, 0.6640277507869243, 0.9595085582595587]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.10302533798448267`], {
             RGBColor[
             0.5606545494087958, 0.6542036462665068, 0.9585559263561962]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.10302533798448267`], {
             RGBColor[
             0.8763321247365747, 0.9042274651358447, 0.9880665344399393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.10302533798448267`], {
             RGBColor[
             0.754776645597012, 0.8083565191461369, 0.9761927403104828]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.10302533798448267`], {
             RGBColor[
             0.9931191009214598, 0.9876907775736443, 0.4924347831667562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.10302533798448267`], {
             RGBColor[
             0.9485376034126628, 0.9611400094038802, 0.9719965932664129]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.10302533798448267`], {
             RGBColor[
             0.5727555094708543, 0.6640277507869243, 0.9595085582595587]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.10302533798448267`], {
             RGBColor[
             0.7888254785267855, 0.8349557262115908, 0.9795864097724881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.10302533798448267`], {
             RGBColor[
             0.7546972069520076, 0.8082944610729035, 0.9761848226087451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.10302533798448267`], {
             RGBColor[
             0.5729515619551473, 0.6641869150257371, 0.9595239922292862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.10302533798448267`], {
             RGBColor[
             0.35915579600514597`, 0.48550443162964046`, 0.9441060676258155]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.10302533798448267`], {
             RGBColor[
             0.8486058287067546, 0.8821192692919226, 0.9854219755730583]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.10302533798448267`], {
             RGBColor[
             0.3629908890250427, 0.48882619644609515`, 0.9443504363618037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.10302533798448267`], {
             RGBColor[
             0.3735007326654367, 0.49792929476730385`, 0.9450201143050798]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.10302533798448267`], {
             RGBColor[
             0.5815395543262257, 0.671159034117226, 0.9602000704475901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.10302533798448267`], {
             RGBColor[
             0.8542679755016362, 0.8866341114512809, 0.9859620361890123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.10302533798448267`], {
             RGBColor[
             0.9471070489283746, 0.960073104211816, 0.9744181488599476]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.10302533798448267`], {
             RGBColor[
             0.7789566542079507, 0.8272461256478741, 0.9786027775937934]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.10302533798448267`], {
             RGBColor[
             0.3191753933187448, 0.45087541629614686`, 0.94155855171992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.10302533798448267`], {
             RGBColor[
             0.9432011712345009, 0.9571601070230128, 0.9810297809796208]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.10302533798448267`], {
             RGBColor[
             0.7457978762538267, 0.8013422362940661, 0.9752978204937242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.10302533798448267`], {
             RGBColor[
             0.7453218440490967, 0.8009703563177524, 0.9752503740523305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.10302533798448267`], {
             RGBColor[
             0.6056996585328538, 0.6907732951124579, 0.9621020423521137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.10302533798448267`], {
             RGBColor[
             0.8908567544557937, 0.9158090106133792, 0.9894519065888484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.10302533798448267`], {
             RGBColor[
             0.7746677730383735, 0.8238956190814962, 0.9781753020006833]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.10302533798448267`], {
             RGBColor[
             0.6154923244849008, 0.6987234224869034, 0.9628729568875761]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.10302533798448267`], {
             RGBColor[
             0.3735007326654367, 0.49792929476730385`, 0.9450201143050798]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.10302533798448267`], {
             RGBColor[
             0.7022390377745596, 0.7673137406146289, 0.9709562825545999]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.10302533798448267`], {
             RGBColor[
             0.8516665907263309, 0.884559837844161, 0.98571391378686]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.10302533798448267`], {
             RGBColor[
             0.20434839586304968`, 0.33211349886165664`, 0.9349487108868157]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.10302533798448267`], {
             RGBColor[
             0.42164641809231385`, 0.5396306676115543, 0.9480879148069224]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.10302533798448267`], {
             RGBColor[
             0.7987639564105845, 0.8427197406696441, 0.980576984367589]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.10302533798448267`], {
             RGBColor[
             0.5955158490166612, 0.6825056197718221, 0.9613003355624756]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.10302533798448267`], {
             RGBColor[
             0.6058298561866651, 0.6908789954331593, 0.9621122919883515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.10302533798448267`], {
             RGBColor[
             0.7337632479410217, 0.79194069318954, 0.9740983212134995]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.10302533798448267`], {
             RGBColor[
             0.7984679003493416, 0.8424884594244917, 0.9805474762662054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.10302533798448267`], {
             RGBColor[
             0.8726207397672564, 0.9012681075041716, 0.9877125392283732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.10302533798448267`], {
             RGBColor[
             0.6461457303481387, 0.7234932225281826, 0.9653654258920954]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.10302533798448267`], {
             RGBColor[
             0.8408126781163766, 0.8759052225505927, 0.9846786579127205]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.10302533798448267`], {
             RGBColor[
             0.3970193308668429, 0.5182999224502458, 0.9465186985857936]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.10302533798448267`], {
             RGBColor[
             0.6908744702789784, 0.7584356541131687, 0.9698235686745618]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.10302533798448267`], {
             RGBColor[
             0.8223070405729445, 0.8611493294956094, 0.9829135736836503]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.10302533798448267`], {
             RGBColor[
             0.9927515922159441, 0.986904713613376, 0.4524337285721893]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.10302533798448267`], {
             RGBColor[
             0.5158907604386618, 0.6178623857948397, 0.9550319569133053]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.10302533798448267`], {
             RGBColor[
             0.9792537920557082, 0.9840480926007207, 0.9200020979587803]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.10302533798448267`], {
             RGBColor[
             0.9175231452365609, 0.937072066782068, 0.991995370746886]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.10302533798448267`], {
             RGBColor[
             0.8623877819131245, 0.8931086246775282, 0.9867365105731768]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.10302533798448267`], {
             RGBColor[
             0.7546972069520076, 0.8082944610729035, 0.9761848226087451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.10302533798448267`], {
             RGBColor[
             0.868574325921975, 0.8980416069409219, 0.987326588663534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.10302533798448267`], {
             RGBColor[
             0.6541539447928386, 0.7297493005170661, 0.9661636098669242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.10302533798448267`], {
             RGBColor[
             0.36626626791470296`, 0.4916631650149892, 0.9445591406083491]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.10302533798448267`], {
             RGBColor[
             0.9725695228330862, 0.9790629755589755, 0.9313168222160576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.10302533798448267`], {
             RGBColor[
             0.9464277493754804, 0.9595664837175185, 0.975568025813299]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.10302533798448267`], {
             RGBColor[
             0.752934723802296, 0.8069175958409807, 0.9760091547597233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.10302533798448267`], {
             RGBColor[
             0.7667292194981125, 0.8176939607206029, 0.9773840611737907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.10302533798448267`], {
             RGBColor[
             0.7987516097957851, 0.8427100954003249, 0.9805757537724115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.10302533798448267`], {
             RGBColor[
             0.5123540475469541, 0.6149911229422514, 0.9547535339190639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.10302533798448267`], {
             RGBColor[
             0.7255281958704887, 0.7855074079233259, 0.9732775281840458]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.10302533798448267`], {
             RGBColor[
             0.5508870289289893, 0.6462739331192168, 0.9577869913644195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.10302533798448267`], {
             RGBColor[
             0.49061569255320275`, 0.5973429470565916, 0.9530422109837378]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.10302533798448267`], {
             RGBColor[
             0.8246326990329209, 0.8630037464232774, 0.9831353970637026]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.10302533798448267`], {
             RGBColor[
             0.9825156356448463, 0.9864807702087212, 0.9144806475874279]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.10302533798448267`], {
             RGBColor[
             0.9864998774714145, 0.9886853666441756, 0.8733954977032199]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.10302533798448267`], {
             RGBColor[
             0.8939436188613918, 0.9182703924997011, 0.9897463344715307]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.10302533798448267`], {
             RGBColor[
             0.6619965504659424, 0.7358760036749056, 0.9669452875071023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.10302533798448267`], {
             RGBColor[
             0.2835651518903705, 0.41537533207879646`, 0.9394599879518831]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.10302533798448267`], {
             RGBColor[
             0.3390109124866397, 0.4680559460371961, 0.9428224534614373]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.10302533798448267`], {
             RGBColor[
             0.6322238924491946, 0.7123068631088643, 0.9641901272074783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.10302533798448267`], {
             RGBColor[
             0.7681067477344625, 0.8187700962484419, 0.9775213603146569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.10302533798448267`], {
             RGBColor[
             0.6074610992400792, 0.692203312030583, 0.9622407094169564]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.10302533798448267`], {
             RGBColor[
             0.7640171326088682, 0.8155752578301014, 0.9771137456985638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.10302533798448267`], {
             RGBColor[
             0.40146958147169265`, 0.5221545058480676, 0.9468022646191325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.10302533798448267`], {
             RGBColor[
             0.5809362905542299, 0.6706692774103965, 0.9601525793136306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.10302533798448267`], {
             RGBColor[
             0.3974494983292969, 0.5186725118853781, 0.9465461084761191]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.10302533798448267`], {
             RGBColor[
             0.993375924915022, 0.988240098126985, 0.5203884899320348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.10302533798448267`], {
             RGBColor[
             0.9008787304928114, 0.9238002622660046, 0.9904078116099828]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.10302533798448267`], {
             RGBColor[
             0.6379579308584022, 0.7169620138049455, 0.9646415317155259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.10302533798448267`], {
             RGBColor[
             0.7046792709480733, 0.7692200693162367, 0.9711995021920602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.10302533798448267`], {
             RGBColor[
             0.9587743225264953, 0.9687745377578874, 0.9546684979706371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.10302533798448267`], {
             RGBColor[
             0.35612710159369304`, 0.48288112875704725`, 0.943913081896087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.10302533798448267`], {
             RGBColor[
             0.8244158041064084, 0.8628308002963322, 0.9831147094319874]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.10302533798448267`], {
             RGBColor[
             0.7022390377745596, 0.7673137406146289, 0.9709562825545999]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.10302533798448267`], {
             RGBColor[
             0.974444930836865, 0.9804616517774949, 0.9281422456504052]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.10302533798448267`], {
             RGBColor[
             0.8360169331724671, 0.8720812257093479, 0.9842212354787583]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.10302533798448267`], {
             RGBColor[
             0.6229218443452652, 0.7047550414056027, 0.963457835906212]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.10302533798448267`], {
             RGBColor[
             0.46333985192721405`, 0.5751991908737967, 0.9508949568949635]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.10302533798448267`], {
             RGBColor[
             0.9246902538219068, 0.9427869246220429, 0.9926789759619097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.10302533798448267`], {
             RGBColor[
             0.9386048160179183, 0.9537321528283265, 0.9888102114398604]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.10302533798448267`], {
             RGBColor[
             0.6710080376416483, 0.7429158459464061, 0.967843468331641]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.10302533798448267`], {
             RGBColor[
             0.7628094972791807, 0.8146318439321811, 0.9769933798948944]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.10302533798448267`], {
             RGBColor[
             0.7465248593639737, 0.8019101610249892, 0.9753702793761001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.10302533798448267`], {
             RGBColor[
             0.4810711899389439, 0.5895942898593934, 0.9522908327752782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.10302533798448267`], {
             RGBColor[
             0.7327599093012839, 0.7911568774185208, 0.9739983177946231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.10302533798448267`], {
             RGBColor[
             0.9951539528309019, 0.9920431200528538, 0.7139158558591967]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.10302533798448267`], {
             RGBColor[
             0.7681067477344625, 0.8187700962484419, 0.9775213603146569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.10302533798448267`], {
             RGBColor[
             0.6943362839718867, 0.7611400492808272, 0.9701686099109825]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.10302533798448267`], {
             RGBColor[
             0.36401097788992703`, 0.48970974614970086`, 0.944415435522245]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.10302533798448267`], {
             RGBColor[
             0.9393314157086191, 0.9542740496879534, 0.9875802676910541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.10302533798448267`], {
             RGBColor[
             0.18131559117533672`, 0.3079045607707065, 0.9336370267338314]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.10302533798448267`], {
             RGBColor[
             0.7820416851471363, 0.8296561752646696, 0.9789102646465582]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.10302533798448267`], {
             RGBColor[
             0.6957568612898691, 0.7622498150784226, 0.9703101997819892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.10302533798448267`], {
             RGBColor[
             0.5903623800879266, 0.6783218015343458, 0.9608946356106269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.10302533798448267`], {
             RGBColor[
             0.5209981057642357, 0.6220087588134255, 0.9554340258461569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.10302533798448267`], {
             RGBColor[
             0.8783700657758966, 0.9058524640021641, 0.9882609150755612]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.10302533798448267`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.10302533798448267`], {
             RGBColor[
             0.2616477963014976, 0.3923388017142848, 0.9382118269749187]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.10302533798448267`], {
             RGBColor[
             0.962399770496449, 0.9714783909177526, 0.9485315602257745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.10302533798448267`], {
             RGBColor[
             0.7343301799507229, 0.7923835847843615, 0.9741548276979457]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.10302533798448267`], {
             RGBColor[
             0.6426553728796135, 0.7207665287460714, 0.9650175396788778]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.10302533798448267`], {
             RGBColor[
             0.6801050388459741, 0.7500224924269954, 0.9687501723953785]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.10302533798448267`], {
             RGBColor[
             0.95114031568726, 0.9630811079567246, 0.9675908802815988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.10302533798448267`], {
             RGBColor[
             0.7407214688967514, 0.797376508284594, 0.9747918516500947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.10302533798448267`], {
             RGBColor[
             0.5897924686285165, 0.6778591217373781, 0.9608497700928876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.10302533798448267`], {
             RGBColor[
             0.986794447010958, 0.9888071787188687, 0.8685137181114534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.10302533798448267`], {
             RGBColor[
             0.5341602071539306, 0.6326943456674904, 0.9564701946819197]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.10302533798448267`], {
             RGBColor[
             0.6376181538228324, 0.716686167500689, 0.9646147832226416]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.10302533798448267`], {
             RGBColor[
             0.8315838576676894, 0.868546411634467, 0.9837984047796594]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.10302533798448267`], {
             RGBColor[
             0.9846314749841018, 0.987912734199918, 0.904359762188633]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.10302533798448267`], {
             RGBColor[
             0.7056706174274304, 0.7699945167204229, 0.9712983103444629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.10302533798448267`], {
             RGBColor[
             0.5549158285761415, 0.6495446941681307, 0.9581041532306226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.10302533798448267`], {
             RGBColor[
             0.4656522224969366, 0.5770764774734045, 0.9510769951767046]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.10302533798448267`], {
             RGBColor[
             0.8516665907263309, 0.884559837844161, 0.98571391378686]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.10302533798448267`], {
             RGBColor[
             0.8926594264208546, 0.9172464123060918, 0.9896238470501402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.10302533798448267`], {
             RGBColor[
             0.9917583810364443, 0.9908598930056929, 0.7862484850596838]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.10302533798448267`], {
             RGBColor[
             0.7490249640555101, 0.8038632618115169, 0.9756194664469457]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.10302533798448267`], {
             RGBColor[
             0.4701442950837982, 0.5807233443649825, 0.9514306275857464]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.10302533798448267`], {
             RGBColor[
             0.8418333988689596, 0.8767191175719756, 0.98477601516931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.10302533798448267`], {
             RGBColor[
             0.7906369552964516, 0.8363708656317872, 0.9797669608476756]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.10302533798448267`], {
             RGBColor[
             0.47972985556085446`, 0.5885053341848353, 0.9521852380195652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.10302533798448267`], {
             RGBColor[
             0.21916716880793746`, 0.34768896879120503`, 0.935792618083617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.10302533798448267`], {
             RGBColor[
             0.3469914285401013, 0.4749682679303048, 0.9433309648874707]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.10302533798448267`], {
             RGBColor[
             0.6944242822599842, 0.7612087942123008, 0.9701773807579493]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.10302533798448267`], {
             RGBColor[
             0.565209266842441, 0.6579013710668221, 0.9589144903970525]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.10302533798448267`], {
             RGBColor[
             0.9879884232652865, 0.9893009185838236, 0.8487264416657339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.10302533798448267`], {
             RGBColor[
             0.8855799354285154, 0.9116014183564642, 0.9889485988793546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.10302533798448267`], {
             RGBColor[
             0.7906369552964516, 0.8363708656317872, 0.9797669608476756]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.10302533798448267`], {
             RGBColor[
             0.6217037326898603, 0.7037661234884404, 0.9633619416946085]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.10302533798448267`], {
             RGBColor[
             0.5549261598959134, 0.6495530815989422, 0.9581049665499599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.10302533798448267`], {
             RGBColor[
             0.9732377952744463, 0.9795613720515461, 0.930185611286202]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.10302533798448267`], {
             RGBColor[
             0.9228094418729513, 0.9412872162272262, 0.9924995824391977]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.10302533798448267`], {
             RGBColor[
             0.655500405631996, 0.7308011659580973, 0.9662978124999795]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.10302533798448267`], {
             RGBColor[
             0.9732377952744463, 0.9795613720515461, 0.930185611286202]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.10302533798448267`], {
             RGBColor[
             0.7478457476618173, 0.8029420490023875, 0.9755019331772262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.10302533798448267`], {
             RGBColor[
             0.550361216511206, 0.6458470549108807, 0.9577455974847772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.10302533798448267`], {
             RGBColor[
             0.5641119342463451, 0.6570105070310412, 0.9588281043554261]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.10302533798448267`], {
             RGBColor[
             0.3391262460738009, 0.46815584219356043`, 0.9428298024156259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.10302533798448267`], {
             RGBColor[
             0.9888703012727221, 0.9896655978031293, 0.8341114408554011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.10302533798448267`], {
             RGBColor[
             0.8082761412121094, 0.8501507317318774, 0.981525070052184]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.10302533798448267`], {
             RGBColor[
             0.7681067477344625, 0.8187700962484419, 0.9775213603146569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.10302533798448267`], {
             RGBColor[
             0.5674092209275486, 0.6596873928999145, 0.9590876788413295]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.10302533798448267`], {
             RGBColor[
             0.7884698021382615, 0.8346778691136352, 0.9795509592740649]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.10302533798448267`], {
             RGBColor[
             0.7142695384362878, 0.7767120591667623, 0.9721553704291402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.10302533798448267`], {
             RGBColor[
             0.5466872174176114, 0.6428643369349276, 0.9574563668178273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.10302533798448267`], {
             RGBColor[
             0.789549041609962, 0.8355209791914513, 0.9796585277785378]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.10302533798448267`], {
             RGBColor[
             0.8071546632891565, 0.8492746246549187, 0.9814132916136311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.10302533798448267`], {
             RGBColor[
             0.8241183077198783, 0.8625935847530374, 0.983086333961062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.10302533798448267`], {
             RGBColor[
             0.9876870381872203, 0.9891762881088001, 0.8537211723688711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.10302533798448267`], {
             RGBColor[
             0.38361745084725196`, 0.5066918875753517, 0.9456647426417625]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.10302533798448267`], {
             RGBColor[
             0.552545533617106, 0.6476203819398146, 0.9579175549287708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.10302533798448267`], {
             RGBColor[
             0.5309578041377483, 0.6300944906323417, 0.9562180897856971]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.10302533798448267`], {
             RGBColor[
             0.5397490378978622, 0.6372316102393698, 0.9569101679106436]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.10302533798448267`], {
             RGBColor[
             0.6835384878764438, 0.7527047289047775, 0.9690923865073303]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.10302533798448267`], {
             RGBColor[
             0.5775770838140357, 0.6679421220481678, 0.9598881302538628]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.10302533798448267`], {
             RGBColor[
             0.6644076226292863, 0.737759551573737, 0.967185600647594]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.10302533798448267`], {
             RGBColor[
             0.9465647209024023, 0.9596686368580266, 0.975336168746116]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.10302533798448267`], {
             RGBColor[
             0.5340567151556506, 0.6326103262010252, 0.9564620474127115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.10302533798448267`], {
             RGBColor[
             0.9016478761627662, 0.9244135581453236, 0.9904811734106075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.10302533798448267`], {
             RGBColor[
             0.9184468571023479, 0.9378086095503559, 0.9920834752092521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.10302533798448267`], {
             RGBColor[
             0.8754875154029303, 0.9035539965795064, 0.9879859748477047]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.10302533798448267`], {
             RGBColor[
             0.6437546844384088, 0.7216253192908796, 0.965127108781408]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.10302533798448267`], {
             RGBColor[
             0.9114830198370099, 0.9322558347433023, 0.9914192581941933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.10302533798448267`], {
             RGBColor[
             0.5765264241057172, 0.6670891491652744, 0.9598054184729307]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.10302533798448267`], {
             RGBColor[
             0.9916866772781578, 0.9836193517775363, 0.4222047403752539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.10302533798448267`], {
             RGBColor[
             0.5060662865017735, 0.6098864352653667, 0.9542585383367597]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1FO4EAYYBuBzsm2dTrZdW7WsZbtVy3bLtWxr2bat5WVjyzZXrfc8u3i/
//a7+f7gJu2rtAsMCAjIJEJuKEIThrCEIzwRiEgkIhOFqEQjOjGISSxiE4e4
xCM+CUhIIhKThKQkI4jkBJOClKQiNWlISzrSk4GMIX3JTBayko3s5CAnuchN
HvKSj/wUoCCF+IEfKUwRivITxShOCUpSitKUoSzlKE8FfqYilahMFapSjerU
oCa1qE0d6lKP+jSgIY1oTBN+oSnNaM6vtKAlrWhNG9rSjvZ0oCOd6EwXutKN
7vSgJ73ozW/0oS/96M8ABjKIwQzhd4YyjOGMYCSjGM0YxjKO8UxgIpOYzBSm
Mo3pzGAms5jNH8xhLvOYzwIWsojFLGEpy1jOClayitWsYS3rWM8GNrKJzWxh
K9vYzg52sovd7GEv+9jPAQ5yiMMc4U+OcozjnOAkpzjNX5zhLOc4zwUuconL
XOEq17jODW5yi9v8zT/c4S73uM8DHvKIxzzhKc94zgte8orXvOEt73jPBz7y
ic/8yxe+8o3/CBl/IKEITRjCEo7wRCAikYhMFKISjejEICaxiE0c4hKP+CQg
IYlITBKSkowgkhNMClKSitSkIS3pSE8GMgb+/6++Az6VhWw=
          "], {Null, CompressedData["
1:eJxN2nu4llWZB+C1RcxDZpqQRxAUUVHStBgOUSMyo5BNY0aKowyCpqCIyVg4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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[57, 280] -> 
             RGBColor[
              0.2575556675749038, 0.38803771496668804`, 0.9379787862977012], 
             UndirectedEdge[46, 187] -> 
             RGBColor[
              0.32803381097302087`, 0.4570126210374179, 0.9421792248536764], 
             UndirectedEdge[96, 298] -> 
             RGBColor[
              0.3453589956577786, 0.4713821632368721, 0.9433064816157806], 
             UndirectedEdge[165, 207] -> 
             RGBColor[
              0.8629243195572578, 0.8731271056740303, 0.676546302374514], 
             UndirectedEdge[69, 224] -> 
             RGBColor[
              0.9812813612748328, 0.9481895871324358, 0.4098590677551779], 
             UndirectedEdge[51, 110] -> 
             RGBColor[
              0.9932540497607107, 0.99147839046011, 0.7614613836320072], 
             UndirectedEdge[122, 231] -> 
             RGBColor[
              0.5346560481729267, 0.6328742791629598, 0.9565707376227028], 
             UndirectedEdge[71, 246] -> 
             RGBColor[
              0.6142322345348998, 0.6977004246990872, 0.9627737579908505], 
             UndirectedEdge[9, 239] -> 
             RGBColor[
              0.4639819639121217, 0.5745750992225973, 0.9512619801674704], 
             UndirectedEdge[99, 229] -> 
             RGBColor[
              0.3569385719957474, 0.4835839836336185, 0.9439647880725508], 
             UndirectedEdge[49, 112] -> 
             RGBColor[
              0.24438397329964223`, 0.374193429149736, 0.9372286777945005], 
             UndirectedEdge[115, 243] -> 
             RGBColor[
              0.21987898042507611`, 0.348437127932281, 0.9358331547021821], 
             UndirectedEdge[58, 95] -> 
             RGBColor[
              0.5187848450827122, 0.6202119340859072, 0.9552597898578664], 
             UndirectedEdge[210, 239] -> 
             RGBColor[
              0.39484568065555037`, 0.5164172158880604, 0.9463801955164135], 
             UndirectedEdge[94, 150] -> 
             RGBColor[
              0.9119777121048072, 0.931971896043791, 0.9679461351700305], 
             UndirectedEdge[21, 108] -> 
             RGBColor[
              0.3636875531699619, 0.4894296119130661, 0.9443948271850822], 
             UndirectedEdge[83, 202] -> 
             RGBColor[
              0.22220476853383342`, 0.3508816786980681, 0.9359656048942807], 
             UndirectedEdge[172, 174] -> 
             RGBColor[
              0.33090944455997406`, 0.4574098756542951, 0.9424391100455509], 
             UndirectedEdge[3, 157] -> 
             RGBColor[
              0.36165267017657554`, 0.4876670985403879, 0.9442651662401199], 
             UndirectedEdge[181, 246] -> 
             RGBColor[
              0.656342497401248, 0.7307927865257904, 0.9668372480070162], 
             UndirectedEdge[159, 253] -> 
             RGBColor[
              0.27205955347524674`, 0.4032822186474281, 0.9388047611431494], 
             UndirectedEdge[170, 228] -> 
             RGBColor[
              0.8200433742052426, 0.3983430371042317, 0.4398420336296414], 
             UndirectedEdge[151, 194] -> 
             RGBColor[
              0.4795533660103779, 0.5880893214551517, 0.9522467003824877], 
             UndirectedEdge[62, 100] -> 
             RGBColor[
              0.8984031319352767, 0.588272489605711, 0.35735557216633895`], 
             UndirectedEdge[76, 99] -> 
             RGBColor[
              0.3308920068686242, 0.45968772172522177`, 0.9423540428096366], 
             UndirectedEdge[131, 283] -> 
             RGBColor[
              0.47177717102653804`, 0.5785602690993044, 0.9525231166057517], 
             UndirectedEdge[173, 263] -> 
             RGBColor[
              0.25907859446240145`, 0.3896384076845897, 0.9380655147309758], 
             UndirectedEdge[20, 75] -> 
             RGBColor[
              0.7982091276425176, 0.8426574734850338, 0.980423187310408], 
             UndirectedEdge[175, 253] -> 
             RGBColor[
              0.29561827694261666`, 0.42804393072097424`, 0.9401463955926079],
              UndirectedEdge[52, 193] -> 
             RGBColor[
              0.6783045969866766, 0.26489364797125753`, 0.42528589032272945`],
              UndirectedEdge[282, 283] -> 
             RGBColor[
              0.7911900845661439, 0.8368811978581185, 0.9547653144934332], 
             UndirectedEdge[173, 279] -> 
             RGBColor[
              0.2579831193391787, 0.3884869938729482, 0.9380031290433184], 
             UndirectedEdge[95, 198] -> 
             RGBColor[
              0.4764509321887418, 0.5858433564775396, 0.9519271091606205], 
             UndirectedEdge[18, 288] -> 
             RGBColor[
              0.890067649625568, 0.630386800626602, 0.46285742186084555`], 
             UndirectedEdge[29, 91] -> 
             RGBColor[
              0.25771769921639187`, 0.38820802049529146`, 0.9379880137599795],
              UndirectedEdge[46, 169] -> 
             RGBColor[
              0.2925815910536258, 0.4248521813146391, 0.9399734608236041], 
             UndirectedEdge[34, 264] -> 
             RGBColor[
              0.31108024849077764`, 0.44256158228500475`, 0.9410904171386354],
              UndirectedEdge[116, 277] -> 
             RGBColor[
              0.33575144742336294`, 0.46523276122486323`, 0.9426147632298372],
              UndirectedEdge[60, 299] -> 
             RGBColor[
              0.9602834986478392, 0.8683179033755875, 0.5002256256588694], 
             UndirectedEdge[205, 213] -> 
             RGBColor[
              0.4786627684820106, 0.5869482888311869, 0.9522920854283001], 
             UndirectedEdge[240, 299] -> 
             RGBColor[
              0.9947090533611671, 0.9917794762430787, 0.7154980818389891], 
             UndirectedEdge[184, 214] -> 
             RGBColor[
              0.22515962250579277`, 0.3539874175711599, 0.9361338794566691], 
             UndirectedEdge[39, 59] -> 
             RGBColor[
              0.8559585262890798, 0.41198547445132916`, 0.20046970691436952`],
              UndirectedEdge[246, 299] -> 
             RGBColor[
              0.7966762325062557, 0.8386071063469377, 0.851316533208819], 
             UndirectedEdge[21, 114] -> 
             RGBColor[
              0.3439329379247541, 0.47191837420693394`, 0.9431507551943723], 
             UndirectedEdge[204, 253] -> 
             RGBColor[
              0.26380404156370607`, 0.39460515219871184`, 0.9383346219527224],
              UndirectedEdge[202, 214] -> 
             RGBColor[
              0.22050159369132202`, 0.3490915339510665, 0.935868611606621], 
             UndirectedEdge[26, 39] -> 
             RGBColor[
              0.906966804332385, 0.6570560107325126, 0.4355903940965794], 
             UndirectedEdge[118, 220] -> 
             RGBColor[
              0.21806065403360642`, 0.34652595160629435`, 0.9357296037041608],
              UndirectedEdge[28, 126] -> 
             RGBColor[
              0.22467560955270433`, 0.3534786892692703, 0.9361063156350238], 
             UndirectedEdge[9, 237] -> 
             RGBColor[
              0.5778044829283981, 0.6681267348934206, 0.9599060319451358], 
             UndirectedEdge[174, 297] -> 
             RGBColor[
              0.5763612583921884, 0.663490693504958, 0.9614863052750408], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.35208222651696447`, 0.4786261706514128, 0.9436828617856419], 
             UndirectedEdge[63, 139] -> 
             RGBColor[
              0.28999599813964694`, 0.42067676560446166`, 0.9398795920978575],
              UndirectedEdge[124, 150] -> 
             RGBColor[
              0.9548500534233739, 0.9658478242861803, 0.9613112619489188], 
             UndirectedEdge[127, 165] -> 
             RGBColor[
              0.8819348515311312, 0.4836294110547851, 0.24528249245442546`], 
             UndirectedEdge[8, 22] -> 
             RGBColor[
              0.7346141321851996, 0.7926054104280515, 0.9741831294029938], 
             UndirectedEdge[127, 137] -> 
             RGBColor[
              0.837036798647762, 0.2856866408011604, 0.18309978625316525`], 
             UndirectedEdge[21, 213] -> 
             RGBColor[
              0.40566670523630644`, 0.5257898434994019, 0.9470697016340429], 
             UndirectedEdge[41, 278] -> 
             RGBColor[
              0.4799611412114356, 0.5860775921964064, 0.9529261189064413], 
             UndirectedEdge[69, 249] -> 
             RGBColor[
              0.8767326483234027, 0.4250520115136651, 0.27148648277790555`], 
             UndirectedEdge[100, 136] -> 
             RGBColor[
              0.8977561106780269, 0.5868885765603375, 0.28693130126704164`], 
             UndirectedEdge[88, 222] -> 
             RGBColor[
              0.47017691950032614`, 0.5802832085890723, 0.9515621248783083], 
             UndirectedEdge[153, 216] -> 
             RGBColor[
              0.2661597993989548, 0.3970812030472318, 0.9384687788764086], 
             UndirectedEdge[60, 121] -> 
             RGBColor[
              0.9603462863275016, 0.8677642487038257, 0.4570528894502983], 
             UndirectedEdge[203, 206] -> 
             RGBColor[
              0.24813385698154097`, 0.37813479465576916`, 0.9374422281227288],
              UndirectedEdge[50, 108] -> 
             RGBColor[
              0.3481847341285709, 0.4760018492537544, 0.9434070012643693], 
             UndirectedEdge[98, 181] -> 
             RGBColor[
              0.5683121366528735, 0.6584973340732392, 0.9601360759487196], 
             UndirectedEdge[267, 285] -> 
             RGBColor[
              0.42530929649653304`, 0.542408765687049, 0.9484303125609015], 
             UndirectedEdge[156, 178] -> 
             RGBColor[
              0.25237767810444756`, 0.38259531972974414`, 0.9376839074575076],
              UndirectedEdge[185, 295] -> 
             RGBColor[
              0.7026775395247731, 0.7666581291332051, 0.9717409425805205], 
             UndirectedEdge[83, 156] -> 
             RGBColor[
              0.221993745626472, 0.35065988024280614`, 0.935953587451887], 
             UndirectedEdge[44, 150] -> 
             RGBColor[
              0.9635307831976114, 0.9324851425902525, 0.6339721646328667], 
             UndirectedEdge[223, 274] -> 
             RGBColor[
              0.9259651133080155, 0.7367764933200369, 0.2723005774523107], 
             UndirectedEdge[20, 142] -> 
             RGBColor[
              0.7624648027643098, 0.8147337352232472, 0.9768605270562558], 
             UndirectedEdge[87, 264] -> 
             RGBColor[
              0.2853843000396664, 0.4172873721243609, 0.939563585747797], 
             UndirectedEdge[16, 192] -> 
             RGBColor[
              0.9078142124160141, 0.6493576356683792, 0.31625810704792], 
             UndirectedEdge[75, 143] -> 
             RGBColor[
              0.5636312232942053, 0.6537338940348352, 0.9601379235387875], 
             UndirectedEdge[230, 263] -> 
             RGBColor[
              0.2551678747286398, 0.38552799329045395`, 0.9378428050275294], 
             UndirectedEdge[52, 82] -> 
             RGBColor[
              0.8768309043529274, 0.4220373894366231, 0.3448952545426753], 
             UndirectedEdge[34, 213] -> 
             RGBColor[
              0.37768895869959807`, 0.5015569256517332, 0.9452869843644738], 
             UndirectedEdge[145, 219] -> 
             RGBColor[
              0.27171942382339986`, 0.4029247208178715, 0.9387853912626534], 
             UndirectedEdge[237, 295] -> 
             RGBColor[
              0.738032045164762, 0.7953605095140767, 0.9745241787723218], 
             UndirectedEdge[257, 259] -> 
             RGBColor[
              0.4277830853443319, 0.544648816326516, 0.9485610340700278], 
             UndirectedEdge[116, 241] -> 
             RGBColor[
              0.30074162674959204`, 0.4321657656332045, 0.9404844121827121], 
             UndirectedEdge[95, 105] -> 
             RGBColor[
              0.3889084199719124, 0.5085055030468593, 0.9463331921101534], 
             UndirectedEdge[115, 146] -> 
             RGBColor[
              0.22602095903949393`, 0.35489273687997036`, 0.9361829312980301],
              UndirectedEdge[16, 170] -> 
             RGBColor[
              0.8790857472699829, 0.44233946271991065`, 0.2892881245547241], 
             UndirectedEdge[199, 226] -> 
             RGBColor[
              0.178927005110741, 0.3053940053717128, 0.9335010002910491], 
             UndirectedEdge[78, 130] -> 
             RGBColor[
              0.17948366008578914`, 0.30597908504445237`, 0.9335327009683809],
              UndirectedEdge[155, 214] -> 
             RGBColor[
              0.21259246077095287`, 0.340778533783768, 0.9354181981873197], 
             UndirectedEdge[185, 297] -> 
             RGBColor[
              0.6642346642542716, 0.7364864270373344, 0.9679464241532377], 
             UndirectedEdge[45, 53] -> 
             RGBColor[
              0.849125567438419, 0.37860621505841235`, 0.19467600489941], 
             UndirectedEdge[49, 204] -> 
             RGBColor[
              0.23371861491604712`, 0.3629834612657993, 0.9366213014125385], 
             UndirectedEdge[69, 254] -> 
             RGBColor[
              0.9421799602264942, 0.7934586684310521, 0.3573185586987633], 
             UndirectedEdge[102, 295] -> 
             RGBColor[
              0.6113037860265932, 0.6906305704110295, 0.9650577846461873], 
             UndirectedEdge[14, 254] -> 
             RGBColor[
              0.8455724370335723, 0.3167800316408471, 0.18992199194947013`], 
             UndirectedEdge[125, 299] -> 
             RGBColor[
              0.9935548569863483, 0.9893107669044954, 0.5898709293143154], 
             UndirectedEdge[16, 44] -> 
             RGBColor[
              0.9792628131880576, 0.9411137160345208, 0.4247070629331663], 
             UndirectedEdge[49, 84] -> 
             RGBColor[
              0.2685862507813846, 0.39963155729606886`, 0.9386069616930247], 
             UndirectedEdge[186, 230] -> 
             RGBColor[
              0.23966064866834333`, 0.3692289154861624, 0.9369596914442806], 
             UndirectedEdge[215, 282] -> 
             RGBColor[
              0.97938013431987, 0.9823295669124169, 0.8386095157394571], 
             UndirectedEdge[134, 159] -> 
             RGBColor[
              0.26069725479200045`, 0.3913397223199907, 0.9381576950421531], 
             UndirectedEdge[26, 266] -> 
             RGBColor[
              0.6167344718352826, 0.6830098916954412, 0.9109140844783175], 
             UndirectedEdge[142, 150] -> 
             RGBColor[
              0.810515025857468, 0.8523692859433827, 0.9579232930155395], 
             UndirectedEdge[114, 221] -> 
             RGBColor[
              0.29951227485023835`, 0.4321367694156119, 0.9403681530127932], 
             UndirectedEdge[147, 172] -> 
             RGBColor[
              0.2478440102281372, 0.3778301473405962, 0.9374257217789124], 
             UndirectedEdge[35, 211] -> 
             RGBColor[
              0.2342952250609407, 0.36358951508727716`, 0.936654138507272], 
             UndirectedEdge[124, 295] -> 
             RGBColor[
              0.8924892919776035, 0.9168014387328876, 0.9788835440663946], 
             UndirectedEdge[166, 233] -> 
             RGBColor[
              0.9934058766223102, 0.9883041618002921, 0.5236485484298345], 
             UndirectedEdge[88, 290] -> 
             RGBColor[
              0.558574938782711, 0.6525153246748602, 0.9583922117898461], 
             UndirectedEdge[134, 235] -> 
             RGBColor[
              0.2580199713754525, 0.388525727699626, 0.9380052277122666], 
             UndirectedEdge[185, 239] -> 
             RGBColor[
              0.4896022864326819, 0.5953748312271646, 0.9532789058066227], 
             UndirectedEdge[260, 278] -> 
             RGBColor[
              0.7260426453881705, 0.7855410894217181, 0.9736791816363508], 
             UndirectedEdge[15, 242] -> 
             RGBColor[
              0.23967759230185604`, 0.3692467243192726, 0.9369606563591433], 
             UndirectedEdge[4, 266] -> 
             RGBColor[
              0.3936273469724733, 0.5073684085563466, 0.9471569136064277], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.2455681044594148, 0.3754380260769088, 0.9372961123122845], 
             UndirectedEdge[3, 123] -> 
             RGBColor[
              0.40677277394875433`, 0.5267478646254944, 0.9471401793543419], 
             UndirectedEdge[28, 184] -> 
             RGBColor[
              0.23042487690337662`, 0.35952153377943086`, 0.9364337279053656],
              UndirectedEdge[116, 210] -> 
             RGBColor[
              0.35048246477995726`, 0.4779920280566848, 0.9435534106296721], 
             UndirectedEdge[118, 120] -> 
             RGBColor[
              0.1844220718220619, 0.3111696688926636, 0.9338139362110361], 
             UndirectedEdge[15, 89] -> 
             RGBColor[
              0.2585276184343561, 0.3890592969452162, 0.9380341374612745], 
             UndirectedEdge[11, 283] -> 
             RGBColor[
              0.4811144650373824, 0.586647763865455, 0.9531180807234778], 
             UndirectedEdge[157, 201] -> 
             RGBColor[
              0.3335467378743898, 0.46332315262546664`, 0.9424742810869247], 
             UndirectedEdge[196, 279] -> 
             RGBColor[
              0.2698625176179148, 0.40097299466125325`, 0.9386796432012976], 
             UndirectedEdge[7, 11] -> 
             RGBColor[
              0.36912627592496833`, 0.4941403602052988, 0.9447413777897574], 
             UndirectedEdge[76, 284] -> 
             RGBColor[
              0.2749699198453155, 0.406341198230256, 0.9389705022024235], 
             UndirectedEdge[34, 108] -> 
             RGBColor[
              0.3357098066332535, 0.46519669406539743`, 0.9426121099155129], 
             UndirectedEdge[46, 213] -> 
             RGBColor[
              0.3600084250820952, 0.48470742468786476`, 0.9442166189906656], 
             UndirectedEdge[261, 278] -> 
             RGBColor[
              0.5017864477209948, 0.6049815757231856, 0.9543168081378697], 
             UndirectedEdge[58, 66] -> 
             RGBColor[
              0.747689528345485, 0.802133526636196, 0.966576403949817], 
             UndirectedEdge[194, 297] -> 
             RGBColor[
              0.6381161089486057, 0.715282207212687, 0.9658902758041552], 
             UndirectedEdge[283, 297] -> 
             RGBColor[
              0.6895610790338994, 0.7570475514974199, 0.9699402122984042], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.23660390230659725`, 0.366016081251054, 0.9367856142610302], 
             UndirectedEdge[6, 169] -> 
             RGBColor[
              0.299349056442051, 0.4319652165199622, 0.940358857965907], 
             UndirectedEdge[11, 172] -> 
             RGBColor[
              0.3065006008708423, 0.43626816207492447`, 0.9408838001095725], 
             UndirectedEdge[4, 82] -> 
             RGBColor[
              0.7673487077991381, 0.8145026420959148, 0.8312023909866153], 
             UndirectedEdge[140, 230] -> 
             RGBColor[
              0.2887130988150164, 0.4189991437957653, 0.9398185869899978], 
             UndirectedEdge[207, 232] -> 
             RGBColor[
              0.8698424070552139, 0.8954799573196557, 0.7870499702431855], 
             UndirectedEdge[147, 244] -> 
             RGBColor[
              0.23435191313774276`, 0.3636490978502278, 0.9366573668093834], 
             UndirectedEdge[56, 296] -> 
             RGBColor[
              0.6219639893106997, 0.70315209105388, 0.9639467061714042], 
             UndirectedEdge[243, 294] -> 
             RGBColor[
              0.21403208469402601`, 0.34229166980434655`, 0.935500182640006], 
             UndirectedEdge[211, 216] -> 
             RGBColor[
              0.2505986099544608, 0.38072540630467244`, 0.9375825921582613], 
             UndirectedEdge[107, 141] -> 
             RGBColor[
              0.8557654965670187, 0.3870748730161112, 0.19936752315815415`], 
             UndirectedEdge[19, 175] -> 
             RGBColor[
              0.2928891684678705, 0.42517546467854467`, 0.9399909769023254], 
             UndirectedEdge[17, 158] -> 
             RGBColor[
              0.34992722478314753`, 0.47635321406760484`, 0.9435604273632674],
              UndirectedEdge[115, 242] -> 
             RGBColor[
              0.23101187459031025`, 0.36013850556620103`, 0.9364671565552513],
              UndirectedEdge[159, 292] -> 
             RGBColor[
              0.24522762221879252`, 0.3750801576541939, 0.9372767223523794], 
             UndirectedEdge[34, 205] -> 
             RGBColor[
              0.4284730033611293, 0.5434764368944227, 0.9490940379758643], 
             UndirectedEdge[23, 180] -> 
             RGBColor[
              0.26520012614906696`, 0.3960725256148013, 0.9384141269045367], 
             UndirectedEdge[47, 158] -> 
             RGBColor[
              0.5238459246822951, 0.6229456026619612, 0.9560487873803941], 
             UndirectedEdge[130, 199] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[112, 204] -> 
             RGBColor[
              0.24154807064065673`, 0.37121271564852854`, 0.9370671773334133],
              UndirectedEdge[217, 247] -> 
             RGBColor[
              0.6930619732704799, 0.7591753208357144, 0.9707042644868367], 
             UndirectedEdge[102, 185] -> 
             RGBColor[
              0.4766965463107896, 0.5841965277949407, 0.9524565634581535], 
             UndirectedEdge[136, 137] -> 
             RGBColor[
              0.8946800275962575, 0.5632444540456559, 0.2839856406340002], 
             UndirectedEdge[138, 258] -> 
             RGBColor[
              0.8342254690641332, 0.8708963005189276, 0.9605009609416519], 
             UndirectedEdge[79, 277] -> 
             RGBColor[
              0.3720129129755694, 0.49664062013193266`, 0.9449253117500688], 
             UndirectedEdge[41, 259] -> 
             RGBColor[
              0.41062581045850305`, 0.5297880471701207, 0.9474677876858852], 
             UndirectedEdge[225, 287] -> 
             RGBColor[
              0.950968932525843, 0.8418366498372989, 0.2871069008798047], 
             UndirectedEdge[167, 194] -> 
             RGBColor[
              0.6348798248522232, 0.7127539974799229, 0.9655677132502221], 
             UndirectedEdge[64, 219] -> 
             RGBColor[
              0.2539451972290641, 0.384242881716169, 0.9377731753527179], 
             UndirectedEdge[83, 293] -> 
             RGBColor[
              0.21277489873276917`, 0.34097028764887183`, 0.9354285877593523],
              UndirectedEdge[31, 95] -> 
             RGBColor[
              0.5537416162054588, 0.648591415667946, 0.9580117149315208], 
             UndirectedEdge[256, 299] -> 
             RGBColor[
              0.994866261560722, 0.9921157286857396, 0.7326092241840025], 
             UndirectedEdge[129, 269] -> 
             RGBColor[
              0.23146736458154496`, 0.36061725442672216`, 0.9364930960364151],
              UndirectedEdge[83, 126] -> 
             RGBColor[
              0.22111352999763184`, 0.3497347178080009, 0.9359034604739869], 
             UndirectedEdge[23, 81] -> 
             RGBColor[
              0.29610769611833376`, 0.428558341305621, 0.9401742672906341], 
             UndirectedEdge[235, 252] -> 
             RGBColor[
              0.2712852344852127, 0.40246836029424277`, 0.9387606648221691], 
             UndirectedEdge[6, 264] -> 
             RGBColor[
              0.3001671802617, 0.4328251165264595, 0.9404054489071303], 
             UndirectedEdge[167, 215] -> 
             RGBColor[
              0.874514844691243, 0.8999677108189541, 0.8534618509904951], 
             UndirectedEdge[273, 285] -> 
             RGBColor[
              0.5003032179944051, 0.6032922095966846, 0.9543341087730001], 
             UndirectedEdge[267, 273] -> 
             RGBColor[
              0.5428411676276441, 0.6397419404528637, 0.9571535916898165], 
             UndirectedEdge[66, 109] -> 
             RGBColor[
              0.9338122663322416, 0.9497831796189251, 0.9839317503863134], 
             UndirectedEdge[104, 173] -> 
             RGBColor[
              0.2711227338075005, 0.40229756177882925`, 0.9387514106489717], 
             UndirectedEdge[9, 185] -> 
             RGBColor[
              0.5424499772884093, 0.6394243545125489, 0.9571227957533345], 
             UndirectedEdge[233, 288] -> 
             RGBColor[
              0.905963575838284, 0.6404594328305877, 0.3369687585518484], 
             UndirectedEdge[139, 147] -> 
             RGBColor[
              0.2408356632285271, 0.3704639302891415, 0.9370266067852049], 
             UndirectedEdge[65, 103] -> 
             RGBColor[
              0.2833667383517215, 0.41516678686953135`, 0.9394486885943836], 
             UndirectedEdge[33, 124] -> 
             RGBColor[
              0.931178231225007, 0.9476509487054876, 0.9825737296298357], 
             UndirectedEdge[82, 226] -> 
             RGBColor[
              0.5870018429473699, 0.648635921384999, 0.8195028573655392], 
             UndirectedEdge[6, 221] -> 
             RGBColor[
              0.3001432088118318, 0.4327999210127703, 0.9404040837685228], 
             UndirectedEdge[125, 136] -> 
             RGBColor[
              0.9927664178883965, 0.9869364242276462, 0.4540474115251879], 
             UndirectedEdge[112, 292] -> 
             RGBColor[
              0.24763746869084696`, 0.3776130590894144, 0.9374139595439145], 
             UndirectedEdge[58, 67] -> 
             RGBColor[
              0.7306207568349073, 0.7888007417215468, 0.9745656605578148], 
             UndirectedEdge[73, 105] -> 
             RGBColor[
              0.30909022810020703`, 0.4403302488400713, 0.9409822033703782], 
             UndirectedEdge[263, 298] -> 
             RGBColor[
              0.27311782288011394`, 0.40439452689009914`, 0.9388650280201871],
              UndirectedEdge[60, 170] -> 
             RGBColor[
              0.8566231096722907, 0.3610749573573675, 0.19885979502203965`], 
             UndirectedEdge[10, 129] -> 
             RGBColor[
              0.22367111540675327`, 0.3524229022332684, 0.9360491111794278], 
             UndirectedEdge[53, 234] -> 
             RGBColor[
              0.8269257463472781, 0.20796866212827195`, 0.17341743115142172`],
              UndirectedEdge[51, 154] -> 
             RGBColor[
              0.867381103025232, 0.8946780960164662, 0.8655976857489563], 
             UndirectedEdge[17, 84] -> 
             RGBColor[
              0.2984201886260963, 0.4309889175517728, 0.9403059603179251], 
             UndirectedEdge[98, 160] -> 
             RGBColor[
              0.5065135948101279, 0.6094211404266363, 0.9545226524909898], 
             UndirectedEdge[25, 147] -> 
             RGBColor[
              0.2390014851721345, 0.36853609285826733`, 0.9369221530583165], 
             UndirectedEdge[159, 204] -> 
             RGBColor[
              0.23913822416860225`, 0.3686798142133081, 0.9369299401418781], 
             UndirectedEdge[37, 94] -> 
             RGBColor[
              0.771325946499076, 0.8216241472491855, 0.9777522097744586], 
             UndirectedEdge[37, 283] -> 
             RGBColor[
              0.6497129501444403, 0.725917890351978, 0.9659685232126394], 
             UndirectedEdge[9, 142] -> 
             RGBColor[
              0.5879267021753338, 0.6760891257694337, 0.9608774283058292], 
             UndirectedEdge[51, 109] -> 
             RGBColor[
              0.9573653906056103, 0.9657923433051386, 0.8743494495449171], 
             UndirectedEdge[123, 257] -> 
             RGBColor[
              0.41376298296839165`, 0.5328024323401832, 0.9475855892918741], 
             UndirectedEdge[212, 294] -> 
             RGBColor[
              0.2108091766010912, 0.3389041890544966, 0.9353166427919786], 
             UndirectedEdge[237, 297] -> 
             RGBColor[
              0.6995891698942603, 0.7651888074182058, 0.970729660345039], 
             UndirectedEdge[163, 197] -> 
             RGBColor[
              0.22592979758927967`, 0.35479692041582533`, 0.9361777397883018],
              UndirectedEdge[76, 229] -> 
             RGBColor[
              0.32034218545595194`, 0.4505499966670069, 0.9416818175180619], 
             UndirectedEdge[18, 24] -> 
             RGBColor[
              0.9510187529148094, 0.9629904466400717, 0.9677966543467089], 
             UndirectedEdge[44, 124] -> 
             RGBColor[
              0.9563745344888678, 0.9271480240205534, 0.6460858270481826], 
             UndirectedEdge[26, 82] -> 
             RGBColor[
              0.9904558326619474, 0.9901441252350094, 0.7949595618585049], 
             UndirectedEdge[7, 106] -> 
             RGBColor[
              0.5257077598802015, 0.6240227140594248, 0.9563940779093657], 
             UndirectedEdge[53, 255] -> 
             RGBColor[
              0.8741375252514738, 0.45432815583854413`, 0.2170266905720422], 
             UndirectedEdge[89, 242] -> 
             RGBColor[
              0.2592824308416344, 0.3898526526431364, 0.9380771229112241], 
             UndirectedEdge[121, 181] -> 
             RGBColor[
              0.8542136005503994, 0.8836192586014792, 0.8134168223712162], 
             UndirectedEdge[217, 273] -> 
             RGBColor[
              0.7124353943152881, 0.7749035368025619, 0.9722294111586636], 
             UndirectedEdge[141, 240] -> 
             RGBColor[
              0.9469680026152082, 0.812923621050152, 0.46368241218848416`], 
             UndirectedEdge[42, 159] -> 
             RGBColor[
              0.2509157891435835, 0.3810587817427625, 0.9376006550438574], 
             UndirectedEdge[51, 52] -> 
             RGBColor[
              0.8763260533964058, 0.4219467076212655, 0.36184562184045305`], 
             UndirectedEdge[170, 225] -> 
             RGBColor[
              0.8682499113225608, 0.4061856602973817, 0.21334848907618564`], 
             UndirectedEdge[51, 179] -> 
             RGBColor[
              0.993604348606093, 0.9916232480349453, 0.7556560252196713], 
             UndirectedEdge[36, 198] -> 
             RGBColor[
              0.6119133130274254, 0.6940222772779814, 0.9638188261918845], 
             UndirectedEdge[150, 295] -> 
             RGBColor[
              0.8996455406863472, 0.9221385573025866, 0.9667698816510785], 
             UndirectedEdge[140, 196] -> 
             RGBColor[
              0.304503216827514, 0.4355955589782061, 0.9407178108514234], 
             UndirectedEdge[31, 73] -> 
             RGBColor[
              0.47392342433375345`, 0.580416161461158, 0.9526607261917457], 
             UndirectedEdge[188, 212] -> 
             RGBColor[
              0.20871789165381538`, 0.33670611597978567`, 0.9351975472080101],
              UndirectedEdge[172, 244] -> 
             RGBColor[
              0.2560033039447505, 0.38640608236585794`, 0.9378903814854801], 
             UndirectedEdge[7, 63] -> 
             RGBColor[
              0.3596300201933831, 0.4859151807862907, 0.94413628477175], 
             UndirectedEdge[128, 218] -> 
             RGBColor[
              0.24765166805898178`, 0.377627983525616, 0.9374147681769237], 
             UndirectedEdge[138, 154] -> 
             RGBColor[
              0.7239419932746806, 0.7842682543998942, 0.9731194303332016], 
             UndirectedEdge[1, 297] -> 
             RGBColor[
              0.5894608456272148, 0.6748368975635395, 0.9623209993901465], 
             UndirectedEdge[90, 123] -> 
             RGBColor[
              0.4198835569183708, 0.5381037658666636, 0.9479755868517558], 
             UndirectedEdge[8, 61] -> 
             RGBColor[
              0.6093443388632377, 0.6935868317074125, 0.9624883614152353], 
             UndirectedEdge[201, 209] -> 
             RGBColor[
              0.29313467956513195`, 0.424290095199951, 0.9400468245012701], 
             UndirectedEdge[44, 94] -> 
             RGBColor[
              0.9135021931703009, 0.8932720957781641, 0.6527207002692943], 
             UndirectedEdge[114, 213] -> 
             RGBColor[
              0.366144956508927, 0.49115730829602955`, 0.944566085377239], 
             UndirectedEdge[82, 107] -> 
             RGBColor[
              0.8877902396301622, 0.5062756427887904, 0.35538992638095424`], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.27309540824899353`, 0.40437096769162195`, 0.9388637515401044],
              UndirectedEdge[182, 268] -> 
             RGBColor[
              0.28484973208731645`, 0.4167255073128753, 0.939533142893733], 
             UndirectedEdge[157, 229] -> 
             RGBColor[
              0.34618459391463335`, 0.47426942833041186`, 0.9432795540985917],
              UndirectedEdge[99, 157] -> 
             RGBColor[
              0.35673441532730565`, 0.48340715338862666`, 0.9439517793901664],
              UndirectedEdge[249, 288] -> 
             RGBColor[
              0.8330203500287888, 0.2511485807700654, 0.1791100840120061], 
             UndirectedEdge[66, 138] -> 
             RGBColor[
              0.8265698887797728, 0.8651867812777139, 0.9734598614679548], 
             UndirectedEdge[215, 286] -> 
             RGBColor[
              0.7770695489362254, 0.8225663010665949, 0.8446220990398039], 
             UndirectedEdge[83, 275] -> 
             RGBColor[
              0.214533530595458, 0.34281872124025803`, 0.9355287392422698], 
             UndirectedEdge[95, 289] -> 
             RGBColor[
              0.38981488785686436`, 0.5094582582673273, 0.9463848141152024], 
             UndirectedEdge[37, 75] -> 
             RGBColor[
              0.7056075851299448, 0.7699452754105638, 0.9712920278741198], 
             UndirectedEdge[88, 260] -> 
             RGBColor[
              0.6766874696871867, 0.7454723343623321, 0.9697937614112038], 
             UndirectedEdge[60, 82] -> 
             RGBColor[
              0.9605795624965958, 0.8682632028416796, 0.48244356084256446`], 
             UndirectedEdge[50, 227] -> 
             RGBColor[
              0.30610711869793783`, 0.43502772299278125`, 0.9408916674370189],
              UndirectedEdge[12, 248] -> 
             RGBColor[
              0.20494626266410096`, 0.3327418947765061, 0.9349827585166709], 
             UndirectedEdge[103, 164] -> 
             RGBColor[
              0.33137057382359575`, 0.4586711168930102, 0.9424369368208644], 
             UndirectedEdge[127, 228] -> 
             RGBColor[
              0.8272958107858699, 0.4540884427009072, 0.44678697508970566`], 
             UndirectedEdge[163, 184] -> 
             RGBColor[
              0.23939823162616325`, 0.3689530985366296, 0.9369447471819397], 
             UndirectedEdge[11, 183] -> 
             RGBColor[
              0.29904764600234657`, 0.4284346339635039, 0.9404593653554703], 
             UndirectedEdge[226, 266] -> 
             RGBColor[
              0.21328048212070516`, 0.3415016878454308, 0.9354573799853517], 
             UndirectedEdge[98, 178] -> 
             RGBColor[
              0.34993177355877136`, 0.4745851224813026, 0.9436255999612144], 
             UndirectedEdge[200, 255] -> 
             RGBColor[
              0.9224751483252943, 0.7242107930884344, 0.2608151757752228], 
             UndirectedEdge[223, 234] -> 
             RGBColor[
              0.840664257806904, 0.28321338657069606`, 0.18538480018870795`], 
             UndirectedEdge[111, 190] -> 
             RGBColor[
              0.2355732429285669, 0.36493279289716524`, 0.9367269197341752], 
             UndirectedEdge[85, 181] -> 
             RGBColor[
              0.8167213708728744, 0.8575535758044224, 0.9821530921197811], 
             UndirectedEdge[57, 134] -> 
             RGBColor[
              0.26052687456490653`, 0.3911606418985847, 0.938147992140275], 
             UndirectedEdge[9, 131] -> 
             RGBColor[
              0.4208304337263501, 0.5371994126346513, 0.9485124028214329], 
             UndirectedEdge[184, 189] -> 
             RGBColor[
              0.2346427787554684, 0.3639548160564028, 0.9366739311760157], 
             UndirectedEdge[194, 286] -> 
             RGBColor[
              0.5374345290972057, 0.6353525877275636, 0.9567279612995309], 
             UndirectedEdge[171, 298] -> 
             RGBColor[
              0.35180269388930685`, 0.47696337077533185`, 0.9437170683691549],
              UndirectedEdge[108, 213] -> 
             RGBColor[
              0.3858995717541348, 0.5086685460021616, 0.9458101573679487], 
             UndirectedEdge[158, 175] -> 
             RGBColor[
              0.34907161965836087`, 0.47545391883295585`, 0.9435117019171652],
              UndirectedEdge[37, 297] -> 
             RGBColor[
              0.7205508998101146, 0.7816191064121104, 0.9727814378282238], 
             UndirectedEdge[68, 234] -> 
             RGBColor[
              0.8363347391748547, 0.263554053647327, 0.18177214371591305`], 
             UndirectedEdge[38, 252] -> 
             RGBColor[
              0.3592377978575069, 0.4848159523446023, 0.9441391019160659], 
             UndirectedEdge[42, 252] -> 
             RGBColor[
              0.2774845709652012, 0.40898425599534566`, 0.939113707863608], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.2625645345612948, 0.39330235174989453`, 0.9382640338626215], 
             UndirectedEdge[184, 216] -> 
             RGBColor[
              0.24813752757352578`, 0.3781386526806742, 0.9374424371575123], 
             UndirectedEdge[16, 59] -> 
             RGBColor[
              0.8863635577181508, 0.4982799029814027, 0.2962573640590009], 
             UndirectedEdge[7, 185] -> 
             RGBColor[
              0.4814085254761833, 0.5882778073170456, 0.9527568066039329], 
             UndirectedEdge[127, 299] -> 
             RGBColor[
              0.8866762458048552, 0.4992665827665768, 0.36636688189725086`], 
             UndirectedEdge[166, 217] -> 
             RGBColor[
              0.899879476841495, 0.9180128953290518, 0.7153753712159427], 
             UndirectedEdge[101, 207] -> 
             RGBColor[
              0.6460892652174881, 0.7219820565313749, 0.9663628314965813], 
             UndirectedEdge[14, 69] -> 
             RGBColor[
              0.8794778029545246, 0.44615247294289756`, 0.27411524595287656`],
              UndirectedEdge[51, 107] -> 
             RGBColor[
              0.8872853886736406, 0.5061849609734328, 0.372340293678732], 
             UndirectedEdge[74, 233] -> 
             RGBColor[
              0.8161512863791258, 0.8534670921405562, 0.7813047425304152], 
             UndirectedEdge[158, 252] -> 
             RGBColor[
              0.35208167801260865`, 0.47861768101199287`, 0.9436831202874573],
              UndirectedEdge[86, 110] -> 
             RGBColor[
              0.9839067857429666, 0.9591178157514064, 0.561716366031505], 
             UndirectedEdge[58, 73] -> 
             RGBColor[
              0.4389666532110068, 0.5520366798791193, 0.9499088011180912], 
             UndirectedEdge[13, 96] -> 
             RGBColor[
              0.3557971492753504, 0.4823533245061042, 0.9439009190224369], 
             UndirectedEdge[16, 53] -> 
             RGBColor[
              0.8856428670516149, 0.492740358709744, 0.2955672298628224], 
             UndirectedEdge[44, 170] -> 
             RGBColor[
              0.8696140479866813, 0.4107872135799805, 0.21864790242070015`], 
             UndirectedEdge[27, 32] -> 
             RGBColor[
              0.25734797909016266`, 0.3878194212010146, 0.9379669587457427], 
             UndirectedEdge[116, 164] -> 
             RGBColor[
              0.35316605540790247`, 0.4803164193774241, 0.9437244066514788], 
             UndirectedEdge[70, 300] -> 
             RGBColor[
              0.2600472811884571, 0.39065655885195993`, 0.938120680006981], 
             UndirectedEdge[79, 116] -> 
             RGBColor[
              0.3586693068574145, 0.48508305918153105`, 0.9440750689675076], 
             UndirectedEdge[137, 195] -> 
             RGBColor[
              0.836758723501432, 0.2835492333731616, 0.18283350117899866`], 
             UndirectedEdge[156, 214] -> 
             RGBColor[
              0.2202905707839606, 0.3488697354958046, 0.9358565941642273], 
             UndirectedEdge[14, 249] -> 
             RGBColor[
              0.8213251225622646, 0.16491981350766619`, 0.16805426748989288`],
              UndirectedEdge[84, 89] -> 
             RGBColor[
              0.2893752204809355, 0.4214820825471055, 0.9397908627628895], 
             UndirectedEdge[98, 246] -> 
             RGBColor[
              0.5108375562883921, 0.6129315271469358, 0.9548630505777516], 
             UndirectedEdge[4, 107] -> 
             RGBColor[
              0.735971594380749, 0.38802551616835207`, 0.43918837760604434`], 
             UndirectedEdge[20, 295] -> 
             RGBColor[
              0.851595317593189, 0.8845030065824513, 0.9857071156917947], 
             UndirectedEdge[57, 175] -> 
             RGBColor[
              0.27078207932041887`, 0.40193951231416447`, 0.9387320108798856],
              UndirectedEdge[93, 160] -> 
             RGBColor[
              0.5607147225279772, 0.6542524975154264, 0.9585606634045596], 
             UndirectedEdge[13, 149] -> 
             RGBColor[
              0.30003867844943893`, 0.43269005297428764`, 0.9403981309190235],
              UndirectedEdge[230, 298] -> 
             RGBColor[
              0.2673021323723527, 0.39828186743036675`, 0.9385338330493134], 
             UndirectedEdge[96, 198] -> 
             RGBColor[
              0.43486063371890193`, 0.5507791821456584, 0.9490119679848132], 
             UndirectedEdge[32, 182] -> 
             RGBColor[
              0.2817202883828383, 0.4134362635612778, 0.9393549257043601], 
             UndirectedEdge[80, 241] -> 
             RGBColor[
              0.27345259705009906`, 0.4047463957686619, 0.938884092913914], 
             UndirectedEdge[55, 292] -> 
             RGBColor[
              0.25987815555668636`, 0.39047879708978456`, 0.9381110485524506],
              UndirectedEdge[121, 160] -> 
             RGBColor[
              0.7924150587076538, 0.8345430649548763, 0.8078033989134862], 
             UndirectedEdge[62, 220] -> 
             RGBColor[
              0.6260202363274255, 0.6895227449727015, 0.8093263410054259], 
             UndirectedEdge[28, 189] -> 
             RGBColor[
              0.22763054758381063`, 0.35658451649385525`, 0.9362745949844562],
              UndirectedEdge[25, 91] -> 
             RGBColor[
              0.2622113968861681, 0.3929311816631146, 0.9382439231944433], 
             UndirectedEdge[41, 99] -> 
             RGBColor[
              0.362239582391498, 0.48817545240188814`, 0.9443025637674687], 
             UndirectedEdge[148, 206] -> 
             RGBColor[
              0.23774362795226284`, 0.3672140051674282, 0.9368505199504779], 
             UndirectedEdge[3, 90] -> 
             RGBColor[
              0.39043568607657597`, 0.5125975002365252, 0.9460991945614463], 
             UndirectedEdge[99, 104] -> 
             RGBColor[
              0.3262801186675095, 0.4548403348152493, 0.9420914025992604], 
             UndirectedEdge[193, 266] -> 
             RGBColor[
              0.3235658537972168, 0.4490279862889558, 0.942045190438874], 
             UndirectedEdge[275, 293] -> 
             RGBColor[
              0.21101994270665328`, 0.33912571759478527`, 0.9353286456098898],
              UndirectedEdge[229, 257] -> 
             RGBColor[
              0.3688470358646546, 0.49389849650006856`, 0.9447235848600365], 
             UndirectedEdge[90, 144] -> 
             RGBColor[
              0.35962797975699734`, 0.48591341346284866`, 0.9441361547569478],
              UndirectedEdge[49, 115] -> 
             RGBColor[
              0.22907293102325943`, 0.358100552941108, 0.9363567365875176], 
             UndirectedEdge[77, 244] -> 
             RGBColor[
              0.2442718082387917, 0.3740755365591065, 0.9372222901602183], 
             UndirectedEdge[66, 95] -> 
             RGBColor[
              0.7175511909941827, 0.7776658666577836, 0.9642038036331552], 
             UndirectedEdge[94, 125] -> 
             RGBColor[
              0.9272871440372241, 0.9396965749731525, 0.7126838428267497], 
             UndirectedEdge[196, 230] -> 
             RGBColor[
              0.2651423022333762, 0.39601174901316233`, 0.938410833918081], 
             UndirectedEdge[138, 245] -> 
             RGBColor[
              0.5655432626553039, 0.6564020281299278, 0.9598314214470098], 
             UndirectedEdge[100, 127] -> 
             RGBColor[
              0.8443775856578832, 0.3421111465143313, 0.19012933218429046`], 
             UndirectedEdge[24, 288] -> 
             RGBColor[
              0.8931463379497462, 0.6326828813378846, 0.45764600557852664`], 
             UndirectedEdge[224, 258] -> 
             RGBColor[
              0.9656458741337097, 0.9399341707856219, 0.6428561562394914], 
             UndirectedEdge[25, 203] -> 
             RGBColor[
              0.2557021473412196, 0.3860895476811155, 0.9378732310624303], 
             UndirectedEdge[143, 239] -> 
             RGBColor[
              0.4039421601527854, 0.5242961292262122, 0.9469598151462764], 
             UndirectedEdge[142, 282] -> 
             RGBColor[
              0.8113403946734408, 0.8529848446549176, 0.9565261589007614], 
             UndirectedEdge[57, 242] -> 
             RGBColor[
              0.24374269016754463`, 0.3735193999182025, 0.9371921576688209], 
             UndirectedEdge[47, 177] -> 
             RGBColor[
              0.5316337139639098, 0.6296909943120255, 0.956545018426947], 
             UndirectedEdge[43, 174] -> 
             RGBColor[
              0.35724861486395953`, 0.48385252718285615`, 0.9439845437299532],
              UndirectedEdge[5, 29] -> 
             RGBColor[
              0.23189096279390453`, 0.36106248300558996`, 0.9365172193279515],
              UndirectedEdge[167, 282] -> 
             RGBColor[
              0.8587917501354356, 0.8900542041854869, 0.9612556665550847], 
             UndirectedEdge[131, 172] -> 
             RGBColor[
              0.297163306859998, 0.4281806673087738, 0.9402888359918464], 
             UndirectedEdge[21, 101] -> 
             RGBColor[
              0.4650224715635836, 0.5746682645420044, 0.9515515525742121], 
             UndirectedEdge[251, 300] -> 
             RGBColor[
              0.27128730129384493`, 0.40247053264115845`, 0.9387607825238632],
              UndirectedEdge[75, 167] -> 
             RGBColor[
              0.7422194299230214, 0.7985467268232416, 0.9749411544059516], 
             UndirectedEdge[165, 281] -> 
             RGBColor[
              0.8841377182227066, 0.5005616097485734, 0.24739196008606018`], 
             UndirectedEdge[63, 174] -> 
             RGBColor[
              0.35841838866408615`, 0.48486572645398507`, 0.944059080682107], 
             UndirectedEdge[64, 211] -> 
             RGBColor[
              0.238007335368493, 0.36749117838190204`, 0.936865537697712], 
             UndirectedEdge[124, 237] -> 
             RGBColor[
              0.7932365579017887, 0.8390697764976703, 0.9690655590701622], 
             UndirectedEdge[127, 192] -> 
             RGBColor[
              0.8435101090021122, 0.32854264127856764`, 0.18902842147164728`],
              UndirectedEdge[62, 228] -> 
             RGBColor[
              0.90559598823519, 0.9239215498870947, 0.8315118721300905], 
             UndirectedEdge[152, 277] -> 
             RGBColor[
              0.3011955804505697, 0.43017548464198757`, 0.9406006083286469], 
             UndirectedEdge[76, 157] -> 
             RGBColor[
              0.3201380287875101, 0.4503731664220151, 0.9416688088356775], 
             UndirectedEdge[106, 297] -> 
             RGBColor[
              0.7085338986582898, 0.7722313337797134, 0.9715836954586705], 
             UndirectedEdge[91, 203] -> 
             RGBColor[
              0.2661031933042482, 0.39702170645266144`, 0.9384655552430561], 
             UndirectedEdge[215, 271] -> 
             RGBColor[
              0.9862840872732699, 0.9639445925953173, 0.5488858494022204], 
             UndirectedEdge[181, 296] -> 
             RGBColor[
              0.7050263286294778, 0.769491193414686, 0.9712340936583042], 
             UndirectedEdge[27, 119] -> 
             RGBColor[
              0.2703316084942079, 0.40146603891431676`, 0.9387063572327446], 
             UndirectedEdge[100, 170] -> 
             RGBColor[
              0.8407513673675695, 0.3142384437159935, 0.18665686145425833`], 
             UndirectedEdge[112, 115] -> 
             RGBColor[
              0.236902386747869, 0.36632980732383724`, 0.9368026125083924], 
             UndirectedEdge[75, 282] -> 
             RGBColor[
              0.8470847195516484, 0.8809085829167043, 0.9600888191549137], 
             UndirectedEdge[234, 255] -> 
             RGBColor[
              0.8645307789041956, 0.38048649371027216`, 0.20782725942062052`],
              UndirectedEdge[29, 77] -> 
             RGBColor[
              0.2444276826034072, 0.3742393703993229, 0.9372311669746878], 
             UndirectedEdge[44, 192] -> 
             RGBColor[
              0.8983425131327125, 0.6178053865284491, 0.24561788491389613`], 
             UndirectedEdge[49, 57] -> 
             RGBColor[
              0.2418037466004938, 0.3714814472931095, 0.9370817377010874], 
             UndirectedEdge[4, 281] -> 
             RGBColor[
              0.7372578431461884, 0.3979121878173214, 0.4404200908764392], 
             UndirectedEdge[23, 285] -> 
             RGBColor[
              0.33957273212272987`, 0.46739870088843105`, 0.9429001346157797],
              UndirectedEdge[86, 109] -> 
             RGBColor[
              0.9480181265878662, 0.9334317685964351, 0.674604431944415], 
             UndirectedEdge[276, 279] -> 
             RGBColor[
              0.24528708035805388`, 0.3751426519284214, 0.9372801084054498], 
             UndirectedEdge[139, 183] -> 
             RGBColor[
              0.2550340991670391, 0.38538738669335115`, 0.9378351867071995], 
             UndirectedEdge[234, 287] -> 
             RGBColor[
              0.8585376702603141, 0.3573155390659227, 0.19993377068700752`], 
             UndirectedEdge[160, 181] -> 
             RGBColor[
              0.6520185359229838, 0.7272823998054908, 0.9664968499202544], 
             UndirectedEdge[196, 298] -> 
             RGBColor[
              0.28309225038485036`, 0.4148782826128075, 0.9394330569107388], 
             UndirectedEdge[255, 287] -> 
             RGBColor[
              0.9499646737467646, 0.8384490491642924, 0.28320554516144203`], 
             UndirectedEdge[126, 216] -> 
             RGBColor[
              0.24238826022285348`, 0.3720958081705137, 0.9371150248871702], 
             UndirectedEdge[190, 212] -> 
             RGBColor[
              0.21992645288427248`, 0.3484870244968241, 0.9358358581885042], 
             UndirectedEdge[39, 137] -> 
             RGBColor[
              0.8602105432836612, 0.44466834031741015`, 0.20454144319034706`],
              UndirectedEdge[170, 195] -> 
             RGBColor[
              0.8209768790641011, 0.16224306137950753`, 0.16772078912276672`],
              UndirectedEdge[69, 288] -> 
             RGBColor[
              0.9056134125186948, 0.6397104688969287, 0.29885564217207405`], 
             UndirectedEdge[101, 231] -> 
             RGBColor[
              0.49585480302230733`, 0.6013736803735128, 0.9535161614708018], 
             UndirectedEdge[57, 253] -> 
             RGBColor[
              0.27188917324815276`, 0.40310313822602206`, 0.9387950582412713],
              UndirectedEdge[52, 266] -> 
             RGBColor[
              0.6276833304684843, 0.2172812337435776, 0.42219826962255025`], 
             UndirectedEdge[28, 275] -> 
             RGBColor[
              0.21809561015053047`, 0.3465626927015274, 0.9357315944033067], 
             UndirectedEdge[4, 226] -> 
             RGBColor[
              0.35927387507325015`, 0.47126073145434144`, 0.9452005342031744],
              UndirectedEdge[104, 229] -> 
             RGBColor[
              0.3157302972548372, 0.4457026097570346, 0.9414191773076857], 
             UndirectedEdge[189, 293] -> 
             RGBColor[
              0.2205548801399334, 0.3491475413871131, 0.9358716461910392], 
             UndirectedEdge[155, 156] -> 
             RGBColor[
              0.22000089461836236`, 0.3485652674792311, 0.935840097535134], 
             UndirectedEdge[107, 281] -> 
             RGBColor[
              0.834790145991334, 0.26841788399438415`, 0.18094838913213865`], 
             UndirectedEdge[107, 240] -> 
             RGBColor[
              0.8877425339879393, 0.506173605243856, 0.35019746163009025`], 
             UndirectedEdge[13, 105] -> 
             RGBColor[
              0.29764935998569264`, 0.4301787277773499, 0.9402620627671929], 
             UndirectedEdge[96, 138] -> 
             RGBColor[
              0.5560749070471602, 0.6482010143955439, 0.959228106200197], 
             UndirectedEdge[254, 260] -> 
             RGBColor[
              0.870237845536556, 0.7409780985202714, 0.6082514586621423], 
             UndirectedEdge[120, 176] -> 
             RGBColor[
              0.18443322649941224`, 0.31118139316580623`, 0.9338145714534094],
              UndirectedEdge[59, 125] -> 
             RGBColor[
              0.8860818256794646, 0.49767730663813153`, 0.2655925702966138], 
             UndirectedEdge[22, 267] -> 
             RGBColor[
              0.642613111904264, 0.7180602166534845, 0.966841075599027], 
             UndirectedEdge[28, 197] -> 
             RGBColor[
              0.21695644286649302`, 0.3453653556586265, 0.9356667205117277], 
             UndirectedEdge[245, 298] -> 
             RGBColor[
              0.35482735126592213`, 0.47958317697125596`, 0.9439097968625934],
              UndirectedEdge[193, 199] -> 
             RGBColor[
              0.28921237678725265`, 0.4129203038152378, 0.9400888107445714], 
             UndirectedEdge[22, 274] -> 
             RGBColor[
              0.8909772154370372, 0.8747143818458635, 0.6496575550294168], 
             UndirectedEdge[76, 201] -> 
             RGBColor[
              0.3077043294157084, 0.43960372096206174`, 0.9408765445063949], 
             UndirectedEdge[19, 158] -> 
             RGBColor[
              0.3474496051113486, 0.47374907870238386`, 0.9434193305882683], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.17948366008578914`, 0.30597908504445237`, 0.9335327009683809],
              UndirectedEdge[61, 267] -> 
             RGBColor[
              0.517343318582302, 0.6190416379328455, 0.9551463076112685], 
             UndirectedEdge[106, 283] -> 
             RGBColor[
              0.6376959489926155, 0.716530117719581, 0.9647707808430861], 
             UndirectedEdge[174, 283] -> 
             RGBColor[
              0.5055233087265141, 0.6077894774448256, 0.9546733906594562], 
             UndirectedEdge[19, 242] -> 
             RGBColor[
              0.26584977931499626`, 0.39675535228258274`, 0.9384511236912607],
              UndirectedEdge[125, 195] -> 
             RGBColor[
              0.8769708936625604, 0.4276466907203388, 0.25686793150790044`], 
             UndirectedEdge[115, 159] -> 
             RGBColor[
              0.23449254027581456`, 0.3637969058886168, 0.9366653753168572], 
             UndirectedEdge[158, 177] -> 
             RGBColor[
              0.4114198455834537, 0.5307729245068593, 0.947436286649661], 
             UndirectedEdge[42, 134] -> 
             RGBColor[
              0.26421930785544107`, 0.3950416234007289, 0.9383582707537054], 
             UndirectedEdge[165, 179] -> 
             RGBColor[
              0.986953469781533, 0.9683582137242022, 0.5663859549250714], 
             UndirectedEdge[108, 145] -> 
             RGBColor[
              0.3065621353882716, 0.43629450439653, 0.9408887080179298], 
             UndirectedEdge[44, 125] -> 
             RGBColor[
              0.9788402151300284, 0.9402098215196141, 0.37870987228958564`], 
             UndirectedEdge[39, 141] -> 
             RGBColor[
              0.8780226232767818, 0.5390110454875421, 0.21993142573409608`], 
             UndirectedEdge[50, 87] -> 
             RGBColor[
              0.314278172622923, 0.4436160187426821, 0.9413569968700557], 
             UndirectedEdge[26, 226] -> 
             RGBColor[
              0.5823809999360594, 0.646902214593436, 0.908957705075064], 
             UndirectedEdge[9, 143] -> 
             RGBColor[
              0.4567898510085129, 0.5683456525115964, 0.9508037050929882], 
             UndirectedEdge[136, 299] -> 
             RGBColor[
              0.9936961088777931, 0.9896128904175391, 0.6052453259924624], 
             UndirectedEdge[134, 144] -> 
             RGBColor[
              0.29485513198583013`, 0.42659799471298, 0.9401265091035182], 
             UndirectedEdge[240, 281] -> 
             RGBColor[
              0.8890287827533787, 0.5160602768928254, 0.3514291749004852], 
             UndirectedEdge[257, 261] -> 
             RGBColor[
              0.39597335276996437`, 0.5173939487951174, 0.9464520497863826], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.27383547980684575`, 0.4051488298221716, 0.9389058975204863], 
             UndirectedEdge[135, 254] -> 
             RGBColor[
              0.940708824154274, 0.7947861767157479, 0.5224157389136257], 
             UndirectedEdge[14, 224] -> 
             RGBColor[
              0.8716400377324648, 0.4199339774417696, 0.22494899798707987`], 
             UndirectedEdge[96, 289] -> 
             RGBColor[
              0.3482245893870246, 0.47439408393544596`, 0.9434696729393952], 
             UndirectedEdge[92, 189] -> 
             RGBColor[
              0.2464728493758267, 0.3763889703481986, 0.937347636196824], 
             UndirectedEdge[107, 127] -> 
             RGBColor[
              0.8336887126455463, 0.25995178464749, 0.1798936553163213], 
             UndirectedEdge[172, 270] -> 
             RGBColor[
              0.24887539777286288`, 0.3789142010438502, 0.9374844577737833], 
             UndirectedEdge[48, 84] -> 
             RGBColor[
              0.35715044434118537`, 0.4830160061947183, 0.9440058041437522], 
             UndirectedEdge[149, 289] -> 
             RGBColor[
              0.29246611856111315`, 0.4247308124036294, 0.9399668848359817], 
             UndirectedEdge[1, 102] -> 
             RGBColor[
              0.40192272768373283`, 0.5225469983211459, 0.9468311386950623], 
             UndirectedEdge[33, 297] -> 
             RGBColor[
              0.8375308432174786, 0.8737699796260231, 0.9842378309047126], 
             UndirectedEdge[18, 135] -> 
             RGBColor[
              0.9682482286960121, 0.9748593362633335, 0.8947082894518925], 
             UndirectedEdge[60, 137] -> 
             RGBColor[
              0.8724049541096216, 0.4823811293510216, 0.2139725070782716], 
             UndirectedEdge[156, 208] -> 
             RGBColor[
              0.2568293808226203, 0.38727434154079826`, 0.9379374253416035], 
             UndirectedEdge[104, 279] -> 
             RGBColor[
              0.27193222945827744`, 0.4031483930327844, 0.9387975102287419], 
             UndirectedEdge[74, 158] -> 
             RGBColor[
              0.5209230649967003, 0.6205987474764012, 0.9558008759103712], 
             UndirectedEdge[80, 277] -> 
             RGBColor[
              0.30846241772387, 0.4378133913603206, 0.9410144439610391], 
             UndirectedEdge[223, 291] -> 
             RGBColor[
              0.8410569337223622, 0.2862316657285906, 0.18576082708881467`], 
             UndirectedEdge[114, 264] -> 
             RGBColor[
              0.29953624630010656`, 0.4321619649293011, 0.9403695181514007], 
             UndirectedEdge[1, 237] -> 
             RGBColor[
              0.5286509868219015, 0.6272769374241931, 0.9562975328211968], 
             UndirectedEdge[84, 292] -> 
             RGBColor[
              0.2718397461725893, 0.40305118723574723`, 0.9387922434424387], 
             UndirectedEdge[103, 152] -> 
             RGBColor[
              0.26605649274810816`, 0.396972621207172, 0.9384628957154713], 
             UndirectedEdge[10, 269] -> 
             RGBColor[
              0.2192290472618576, 0.3477540069695957, 0.9357961419700269], 
             UndirectedEdge[109, 138] -> 
             RGBColor[
              0.8139262808550589, 0.8553825016885668, 0.9818711941291625], 
             UndirectedEdge[165, 240] -> 
             RGBColor[
              0.987596961950581, 0.9683237186753911, 0.533871497674751], 
             UndirectedEdge[249, 254] -> 
             RGBColor[
              0.8428272824024504, 0.2956795702116145, 0.1872932287744991], 
             UndirectedEdge[2, 155] -> 
             RGBColor[
              0.22153004206728566`, 0.3501724984015976, 0.9359271802201792], 
             UndirectedEdge[117, 161] -> 
             RGBColor[
              0.20987266837087443`, 0.33791985952648745`, 0.9352633100337076],
              UndirectedEdge[169, 264] -> 
             RGBColor[
              0.29384317958318956`, 0.42617819084854336`, 0.9400453064240097],
              UndirectedEdge[3, 229] -> 
             RGBColor[
              0.3618568268450173, 0.48784392878537974`, 0.9442781749225044], 
             UndirectedEdge[55, 90] -> 
             RGBColor[
              0.3401206359010615, 0.4660537805054501, 0.9430016668956538], 
             UndirectedEdge[3, 259] -> 
             RGBColor[
              0.42079287632469464`, 0.5385942486118271, 0.9481156241324957], 
             UndirectedEdge[113, 254] -> 
             RGBColor[
              0.925365599889266, 0.7843240503848107, 0.5923111720047104], 
             UndirectedEdge[6, 205] -> 
             RGBColor[
              0.41755993513205164`, 0.5337399711358773, 0.9484090697443592], 
             UndirectedEdge[120, 287] -> 
             RGBColor[
              0.5654447927305568, 0.5603176274195498, 0.6027460190921992], 
             UndirectedEdge[31, 67] -> 
             RGBColor[
              0.765577527957654, 0.8171802233035855, 0.9773175856314692], 
             UndirectedEdge[141, 232] -> 
             RGBColor[
              0.9465494933171561, 0.8120284719793993, 0.41813025783551805`], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.4306059655104517, 0.5460088371370204, 0.9490406986812941], 
             UndirectedEdge[71, 122] -> 
             RGBColor[
              0.6268946494046528, 0.707980343525642, 0.9637705896733515], 
             UndirectedEdge[78, 120] -> 
             RGBColor[
              0.1849774474258748, 0.3117534038651181, 0.9338455640300687], 
             UndirectedEdge[177, 247] -> 
             RGBColor[
              0.4991479409504841, 0.603343634292864, 0.9539698061272375], 
             UndirectedEdge[168, 182] -> 
             RGBColor[
              0.34652806688330007`, 0.474422427150048, 0.9433067307526943], 
             UndirectedEdge[26, 228] -> 
             RGBColor[
              0.901089116284713, 0.9224316156704129, 0.933371766463492], 
             UndirectedEdge[7, 194] -> 
             RGBColor[
              0.4552899701705174, 0.5670735874923983, 0.9507006582548503], 
             UndirectedEdge[206, 244] -> 
             RGBColor[
              0.23959248852906917`, 0.3691572748581827, 0.9369558098251829], 
             UndirectedEdge[31, 109] -> 
             RGBColor[
              0.7700026915435176, 0.8207087286290875, 0.9777396616846791], 
             UndirectedEdge[57, 235] -> 
             RGBColor[
              0.24454607243650103`, 0.3743638056202535, 0.9372379091005405], 
             UndirectedEdge[24, 135] -> 
             RGBColor[
              0.9728662611822794, 0.9783034573302576, 0.8868911650284141], 
             UndirectedEdge[130, 220] -> 
             RGBColor[
              0.21805936955163013`, 0.34652460153429643`, 0.9357295305548126],
              UndirectedEdge[84, 112] -> 
             RGBColor[
              0.2764157065059942, 0.4078608116787981, 0.9390528376138995], 
             UndirectedEdge[76, 104] -> 
             RGBColor[
              0.2896837321277139, 0.4218063478486378, 0.9398084320447715], 
             UndirectedEdge[21, 87] -> 
             RGBColor[
              0.32978099166431396`, 0.45704378140199375`, 0.9423448227907686],
              UndirectedEdge[43, 183] -> 
             RGBColor[
              0.28838161647063476`, 0.4191962552733669, 0.9397797353853092], 
             UndirectedEdge[11, 131] -> 
             RGBColor[
              0.3341685066956953, 0.46386169752747186`, 0.9425138996464097], 
             UndirectedEdge[21, 187] -> 
             RGBColor[
              0.3736920911272321, 0.49809503984895503`, 0.9450323074970538], 
             UndirectedEdge[36, 66] -> 
             RGBColor[
              0.8530135718328662, 0.8858447874582254, 0.9760955206644191], 
             UndirectedEdge[124, 125] -> 
             RGBColor[
              0.970159485355791, 0.9735725032155419, 0.706048969605638], 
             UndirectedEdge[232, 296] -> 
             RGBColor[
              0.8451660598218556, 0.8762026073137711, 0.7845904625645401], 
             UndirectedEdge[75, 239] -> 
             RGBColor[
              0.5708233361978141, 0.6599633407458361, 0.9605961986132696], 
             UndirectedEdge[108, 114] -> 
             RGBColor[
              0.32416580444258236`, 0.4547970767096937, 0.9418912109282782], 
             UndirectedEdge[137, 266] -> 
             RGBColor[
              0.6462554556762865, 0.36003472644790463`, 0.439982957695757], 
             UndirectedEdge[74, 262] -> 
             RGBColor[
              0.8160969055518104, 0.8533507770496733, 0.7753857250766871], 
             UndirectedEdge[48, 90] -> 
             RGBColor[
              0.4086146868704133, 0.5283432370210001, 0.9472575444169704], 
             UndirectedEdge[125, 150] -> 
             RGBColor[
              0.9773157340645346, 0.9789096217852411, 0.6939353071903218], 
             UndirectedEdge[38, 55] -> 
             RGBColor[
              0.34731954937378307`, 0.4722891175276097, 0.9434603752963864], 
             UndirectedEdge[110, 165] -> 
             RGBColor[
              0.9866031709361507, 0.9682133561493669, 0.5721913133374072], 
             UndirectedEdge[114, 145] -> 
             RGBColor[
              0.28680752014306377`, 0.4187832666903979, 0.9396446360272199], 
             UndirectedEdge[222, 290] -> 
             RGBColor[
              0.5245306986367102, 0.6244100551018348, 0.9558410534763778], 
             UndirectedEdge[267, 286] -> 
             RGBColor[
              0.5134415575632728, 0.6158740125652669, 0.954839146691229], 
             UndirectedEdge[6, 187] -> 
             RGBColor[
              0.3348012763614461, 0.46412565624274105`, 0.9425646219959795], 
             UndirectedEdge[221, 231] -> 
             RGBColor[
              0.3698663550363416, 0.4934747204504928, 0.9448363781661868], 
             UndirectedEdge[106, 286] -> 
             RGBColor[
              0.6078523188068897, 0.6923017142945901, 0.9624213809540463], 
             UndirectedEdge[67, 154] -> 
             RGBColor[
              0.8267592072412856, 0.8653361474156035, 0.9831692431983503], 
             UndirectedEdge[85, 296] -> 
             RGBColor[
              0.8079306217366228, 0.8506861757670146, 0.9812769124001008], 
             UndirectedEdge[41, 201] -> 
             RGBColor[
              0.3390519049385823, 0.4680914516387281, 0.942825065464227], 
             UndirectedEdge[42, 235] -> 
             RGBColor[
              0.24823850572703557`, 0.37824478712239773`, 0.9374481877139709],
              UndirectedEdge[44, 60] -> 
             RGBColor[
              0.9455688567915195, 0.8192169579907062, 0.28906456863413965`], 
             UndirectedEdge[199, 228] -> 
             RGBColor[
              0.49763512145939465`, 0.5809234064486897, 0.9579150616794772], 
             UndirectedEdge[39, 62] -> 
             RGBColor[
              0.909971385632703, 0.6580493002103005, 0.3676837978743117], 
             UndirectedEdge[48, 144] -> 
             RGBColor[
              0.3646961975812182, 0.4903032490061542, 0.9444590971150582], 
             UndirectedEdge[68, 215] -> 
             RGBColor[
              0.9347347232001206, 0.7573256172439325, 0.47384806566130333`], 
             UndirectedEdge[127, 240] -> 
             RGBColor[
              0.8868259160618033, 0.4991280781990371, 0.3493197072688504], 
             UndirectedEdge[4, 26] -> 
             RGBColor[
              0.7627278647878275, 0.8127689353043519, 0.92065723869614], 
             UndirectedEdge[8, 47] -> 
             RGBColor[
              0.6479545398771973, 0.7249062782797447, 0.9655457111216659], 
             UndirectedEdge[112, 175] -> 
             RGBColor[
              0.27336230601956724`, 0.40465149417079094`, 0.9388789509732987],
              UndirectedEdge[162, 203] -> 
             RGBColor[
              0.27206034387321254`, 0.4032830494058043, 0.9388048061551442], 
             UndirectedEdge[6, 50] -> 
             RGBColor[
              0.32906105284495657`, 0.4591537631447806, 0.9421988600293891], 
             UndirectedEdge[15, 294] -> 
             RGBColor[
              0.2244101664519819, 0.3531996917403464, 0.9360911990431254], 
             UndirectedEdge[6, 219] -> 
             RGBColor[
              0.2899540268393041, 0.4220904447281936, 0.9398238249287314], 
             UndirectedEdge[110, 281] -> 
             RGBColor[
              0.8883662554104251, 0.5159867018754759, 0.3769757186755893], 
             UndirectedEdge[167, 297] -> 
             RGBColor[
              0.7571627446031911, 0.8102205578247882, 0.9764305643600557], 
             UndirectedEdge[122, 246] -> 
             RGBColor[
              0.6115303319065195, 0.6955068984260417, 0.962561054318549], 
             UndirectedEdge[210, 277] -> 
             RGBColor[
              0.36382607089811214`, 0.48954958900708645`, 0.9444036534122333],
              UndirectedEdge[225, 234] -> 
             RGBColor[
              0.8652002847569147, 0.3827448941589432, 0.21042816323286231`], 
             UndirectedEdge[84, 280] -> 
             RGBColor[
              0.28433817175579457`, 0.41618782496964746`, 0.9395040102896386],
              UndirectedEdge[67, 95] -> 
             RGBColor[
              0.7004824194836051, 0.7643330817431344, 0.9721930602411528], 
             UndirectedEdge[81, 285] -> 
             RGBColor[
              0.33930631085889784`, 0.4671186752480599, 0.9428849623189395], 
             UndirectedEdge[79, 164] -> 
             RGBColor[
              0.38942752096010885`, 0.5117242782844935, 0.9460349551717104], 
             UndirectedEdge[123, 157] -> 
             RGBColor[
              0.3911005410183704, 0.5131733641705265, 0.9461415585304294], 
             UndirectedEdge[85, 165] -> 
             RGBColor[
              0.9499430145672961, 0.9419121380578821, 0.6850057931573457], 
             UndirectedEdge[59, 62] -> 
             RGBColor[
              0.8868230148643443, 0.4992626353588674, 0.34626643898134246`], 
             UndirectedEdge[38, 48] -> 
             RGBColor[
              0.41581360034313486`, 0.5345785740431597, 0.947716252817703], 
             UndirectedEdge[262, 291] -> 
             RGBColor[
              0.8765985883861446, 0.42228014315900764`, 0.3052246115453534], 
             UndirectedEdge[26, 170] -> 
             RGBColor[
              0.8765406231158585, 0.4423289056195874, 0.40720379569933324`], 
             UndirectedEdge[43, 139] -> 
             RGBColor[
              0.2888262243395204, 0.4196635663333328, 0.9398050551457039], 
             UndirectedEdge[52, 281] -> 
             RGBColor[
              0.8238308107140992, 0.18417963064221682`, 0.17045371729385975`],
              UndirectedEdge[124, 142] -> 
             RGBColor[
              0.8033587771487245, 0.8470321673736835, 0.9700369554308557], 
             UndirectedEdge[166, 271] -> 
             RGBColor[
              0.9850940999243964, 0.9612451065301149, 0.40815265332302325`], 
             UndirectedEdge[37, 150] -> 
             RGBColor[
              0.8213545365263866, 0.860837194061274, 0.9590036741380308], 
             UndirectedEdge[51, 66] -> 
             RGBColor[
              0.9700089985303242, 0.9755966228942858, 0.8659381168837096], 
             UndirectedEdge[60, 125] -> 
             RGBColor[
              0.9593538076584427, 0.8656414371856946, 0.3490277111915949], 
             UndirectedEdge[215, 223] -> 
             RGBColor[
              0.9412290011481947, 0.7868146166289862, 0.47926705037049566`], 
             UndirectedEdge[237, 282] -> 
             RGBColor[
              0.8012181754265049, 0.8450224537789045, 0.955554762540068], 
             UndirectedEdge[143, 172] -> 
             RGBColor[
              0.33312272414216076`, 0.4593269071857189, 0.9425801382634016], 
             UndirectedEdge[177, 285] -> 
             RGBColor[
              0.40098949086418123`, 0.5217386754938967, 0.9467716736701495], 
             UndirectedEdge[244, 270] -> 
             RGBColor[
              0.23538330068246843`, 0.36473315155348174`, 0.9367161028042543],
              UndirectedEdge[147, 272] -> 
             RGBColor[
              0.2247364657597668, 0.3535426530013993, 0.9361097813059873], 
             UndirectedEdge[46, 114] -> 
             RGBColor[
              0.29827465777054285`, 0.4308359553953969, 0.9402976725509951], 
             UndirectedEdge[104, 128] -> 
             RGBColor[
              0.26216622821870855`, 0.39288370652975557`, 0.9382413509056526],
              UndirectedEdge[199, 220] -> 
             RGBColor[
              0.21805936955163013`, 0.34652460153429643`, 0.9357295305548126],
              UndirectedEdge[112, 146] -> 
             RGBColor[
              0.24133200131587673`, 0.37098561308859834`, 0.937054872505013], 
             UndirectedEdge[191, 203] -> 
             RGBColor[
              0.2517414689713402, 0.38192662359285945`, 0.9376476762885642], 
             UndirectedEdge[31, 96] -> 
             RGBColor[
              0.512151317735619, 0.6135272413360646, 0.9550965737557137], 
             UndirectedEdge[59, 228] -> 
             RGBColor[
              0.8273211846534105, 0.45428347736572383`, 0.4468112731339182], 
             UndirectedEdge[129, 289] -> 
             RGBColor[
              0.26344635035437974`, 0.39422919605877726`, 0.9383142519675081],
              UndirectedEdge[54, 106] -> 
             RGBColor[
              0.5370375913061106, 0.6338360445866622, 0.9571160047492481], 
             UndirectedEdge[102, 142] -> 
             RGBColor[
              0.5221732711977142, 0.6208612990518254, 0.9562111960106483], 
             UndirectedEdge[74, 90] -> 
             RGBColor[
              0.5208802713688769, 0.620561681786851, 0.9557981491382472], 
             UndirectedEdge[143, 174] -> 
             RGBColor[
              0.39453676766698986`, 0.5161496509837875, 0.9463605118539434], 
             UndirectedEdge[144, 292] -> 
             RGBColor[
              0.2793854994126222, 0.4103384300471832, 0.9392455364137446], 
             UndirectedEdge[59, 255] -> 
             RGBColor[
              0.8748582159180097, 0.45986770011020284`, 0.21771682476822068`],
              UndirectedEdge[254, 258] -> 
             RGBColor[
              0.926544473085371, 0.7852032520842381, 0.5903156471830767], 
             UndirectedEdge[46, 108] -> 
             RGBColor[
              0.3180292730157506, 0.448347193101529, 0.9415417445417048], 
             UndirectedEdge[222, 278] -> 
             RGBColor[
              0.51953209520131, 0.6203519636484585, 0.9554475451034554], 
             UndirectedEdge[115, 294] -> 
             RGBColor[
              0.2157444487404361, 0.3440914729872748, 0.9355976992392334], 
             UndirectedEdge[89, 177] -> 
             RGBColor[
              0.3486700459196015, 0.47359177071300174`, 0.9435415608547846], 
             UndirectedEdge[45, 195] -> 
             RGBColor[
              0.8449304467632349, 0.34636067923534536`, 0.19065875260314252`],
              UndirectedEdge[205, 231] -> 
             RGBColor[
              0.4872830813565614, 0.5944147705735998, 0.9528413641420233], 
             UndirectedEdge[148, 244] -> 
             RGBColor[
              0.24066234627754973`, 0.37028176318473494`, 0.9370167366412461],
              UndirectedEdge[20, 297] -> 
             RGBColor[
              0.8131524423226874, 0.8543313044865806, 0.981912597264512], 
             UndirectedEdge[6, 34] -> 
             RGBColor[
              0.31658612534963915`, 0.4483486079564237, 0.9414039686805327], 
             UndirectedEdge[13, 245] -> 
             RGBColor[
              0.36526550488349396`, 0.49055433824048805`, 0.9445042342692497],
              UndirectedEdge[104, 201] -> 
             RGBColor[
              0.30309244121459367`, 0.43475633405208935`, 0.9406139042960187],
              UndirectedEdge[55, 253] -> 
             RGBColor[
              0.2867100868131406, 0.4186808580830187, 0.9396390873432205], 
             UndirectedEdge[52, 141] -> 
             RGBColor[
              0.8448061612897839, 0.30283661966394393`, 0.18887285131987525`],
              UndirectedEdge[160, 299] -> 
             RGBColor[
              0.7923522710279916, 0.8350967196266381, 0.8509761351220573], 
             UndirectedEdge[229, 284] -> 
             RGBColor[
              0.3010164849724387, 0.4302374601386527, 0.9405812474653377], 
             UndirectedEdge[27, 268] -> 
             RGBColor[
              0.2604774227946408, 0.3911086649526121, 0.9381451759351156], 
             UndirectedEdge[193, 236] -> 
             RGBColor[
              0.511354201918838, 0.6127180573453962, 0.9550785966275717], 
             UndirectedEdge[78, 193] -> 
             RGBColor[
              0.2897690368730418, 0.4135053888596902, 0.9401205117129523], 
             UndirectedEdge[175, 177] -> 
             RGBColor[
              0.3568594089399756, 0.48219931048302006`, 0.944007932963718], 
             UndirectedEdge[36, 67] -> 
             RGBColor[
              0.8359448003222887, 0.8725120025435762, 0.9840847772724168], 
             UndirectedEdge[37, 239] -> 
             RGBColor[
              0.5459185219885249, 0.6405075106019407, 0.9581139194816087], 
             UndirectedEdge[49, 280] -> 
             RGBColor[
              0.2523064385494426, 0.38252044244058536`, 0.9376798504702395], 
             UndirectedEdge[263, 276] -> 
             RGBColor[
              0.24638255548127658`, 0.37629406574006286`, 0.9373424940931072],
              UndirectedEdge[13, 73] -> 
             RGBColor[
              0.31756925587348483`, 0.44924224463119755`, 0.9414650714584689],
              UndirectedEdge[136, 240] -> 
             RGBColor[
              0.9939206142632153, 0.9894051335662295, 0.5796745640498617], 
             UndirectedEdge[79, 241] -> 
             RGBColor[
              0.3370030923017984, 0.46357362454027395`, 0.9427949607029437], 
             UndirectedEdge[78, 226] -> 
             RGBColor[
              0.17948366519653014`, 0.30597909041616517`, 0.9335327012594301],
              UndirectedEdge[3, 74] -> 
             RGBColor[
              0.5077694883992605, 0.6092057805456816, 0.9549627416408335], 
             UndirectedEdge[148, 203] -> 
             RGBColor[
              0.2492037147300215, 0.37925928298232137`, 0.9375031549387921], 
             UndirectedEdge[90, 257] -> 
             RGBColor[
              0.39742589509621323`, 0.518652067951214, 0.9465446044989785], 
             UndirectedEdge[34, 87] -> 
             RGBColor[
              0.3018032451276056, 0.4328108635543251, 0.9405621055211995], 
             UndirectedEdge[146, 235] -> 
             RGBColor[
              0.23624487142727435`, 0.3656387170330131, 0.9367651679835913], 
             UndirectedEdge[181, 256] -> 
             RGBColor[
              0.8545325264557142, 0.8843014088645924, 0.8481299389821997], 
             UndirectedEdge[68, 287] -> 
             RGBColor[
              0.9076706141527531, 0.6630503890698746, 0.24412287160438084`], 
             UndirectedEdge[17, 144] -> 
             RGBColor[
              0.3059659418661292, 0.4382761603632087, 0.940759253289231], 
             UndirectedEdge[163, 216] -> 
             RGBColor[
              0.2500986511246546, 0.3801999178753255, 0.9375541202425267], 
             UndirectedEdge[67, 258] -> 
             RGBColor[
              0.9370426830307382, 0.9519641935346369, 0.9705507738068005], 
             UndirectedEdge[232, 240] -> 
             RGBColor[
              0.9945150494485371, 0.9906765703210165, 0.6443751655434223], 
             UndirectedEdge[133, 210] -> 
             RGBColor[
              0.36435206965698563`, 0.49000518269455634`, 0.9444371695880264],
              UndirectedEdge[58, 154] -> 
             RGBColor[
              0.6450616328403926, 0.7212149997583763, 0.9662359728150638], 
             UndirectedEdge[94, 124] -> 
             RGBColor[
              0.9048214633960636, 0.926634777474092, 0.9800597975853467], 
             UndirectedEdge[50, 213] -> 
             RGBColor[
              0.3901638861949155, 0.5123620808400902, 0.94608187571333], 
             UndirectedEdge[15, 212] -> 
             RGBColor[
              0.22532179004368708`, 0.3541578659355026, 0.9361431146580468], 
             UndirectedEdge[11, 139] -> 
             RGBColor[
              0.2994922538712322, 0.4289019450234698, 0.940484685115865], 
             UndirectedEdge[167, 286] -> 
             RGBColor[
              0.6564811647517911, 0.7302909383396649, 0.9672682498554315], 
             UndirectedEdge[113, 288] -> 
             RGBColor[
              0.8944038389605427, 0.6336207235327678, 0.45551738437603884`], 
             UndirectedEdge[73, 171] -> 
             RGBColor[
              0.3736817156213931, 0.4980860531072854, 0.9450316463789965], 
             UndirectedEdge[31, 110] -> 
             RGBColor[
              0.8058913506986181, 0.8463947757840589, 0.8648515957717691], 
             UndirectedEdge[202, 275] -> 
             RGBColor[
              0.22044981250771753`, 0.3490371086439815, 0.9358656627448182], 
             UndirectedEdge[103, 241] -> 
             RGBColor[
              0.2789461451652853, 0.41052046314879065`, 0.9391969423520976], 
             UndirectedEdge[9, 20] -> 
             RGBColor[
              0.6913677553568252, 0.7572692319617951, 0.9710889688646087], 
             UndirectedEdge[71, 207] -> 
             RGBColor[
              0.6875924129964879, 0.7556761815938675, 0.9696301113207838], 
             UndirectedEdge[160, 168] -> 
             RGBColor[
              0.4880465107801085, 0.5934258804224648, 0.9533459462263981], 
             UndirectedEdge[6, 114] -> 
             RGBColor[
              0.30504212315896806`, 0.43794899060072, 0.940683069693298], 
             UndirectedEdge[95, 96] -> 
             RGBColor[
              0.44705620926157014`, 0.5606800997756136, 0.9499720483653973], 
             UndirectedEdge[198, 278] -> 
             RGBColor[
              0.5335934338471843, 0.6322342135642272, 0.9564255762110536], 
             UndirectedEdge[86, 281] -> 
             RGBColor[
              0.8823401280939172, 0.49449791614993305`, 0.24040866188212537`],
              UndirectedEdge[107, 165] -> 
             RGBColor[
              0.8828514694572672, 0.490674938099604, 0.2461602468156653], 
             UndirectedEdge[155, 184] -> 
             RGBColor[
              0.22486994634019453`, 0.35368294955458646`, 0.9361173828275757],
              UndirectedEdge[247, 285] -> 
             RGBColor[
              0.4809297969495969, 0.5875639936298371, 0.952808962101173], 
             UndirectedEdge[34, 227] -> 
             RGBColor[
              0.2936321912026204, 0.4242225678044243, 0.9400967760881624], 
             UndirectedEdge[116, 152] -> 
             RGBColor[
              0.2878519743324149, 0.4186179236915859, 0.9397503655460857], 
             UndirectedEdge[146, 204] -> 
             RGBColor[
              0.23066664293228167`, 0.35977564520466165`, 0.936447496123051], 
             UndirectedEdge[36, 58] -> 
             RGBColor[
              0.6542472259213957, 0.728390854886349, 0.9671515068891303], 
             UndirectedEdge[105, 129] -> 
             RGBColor[
              0.2625398824694277, 0.39327644083830926`, 0.9382626299624591], 
             UndirectedEdge[87, 187] -> 
             RGBColor[
              0.3200183961394125, 0.4485879118406425, 0.9417227588366461], 
             UndirectedEdge[119, 168] -> 
             RGBColor[
              0.3340488783835623, 0.46130600881057365`, 0.9425960594289393], 
             UndirectedEdge[20, 37] -> 
             RGBColor[
              0.7733043134332283, 0.8232016433411387, 0.9779409081787471], 
             UndirectedEdge[150, 200] -> 
             RGBColor[
              0.9240011310350597, 0.7732005239509658, 0.5878910864110933], 
             UndirectedEdge[1, 43] -> 
             RGBColor[
              0.370348202098986, 0.49519873124143765`, 0.944819237845059], 
             UndirectedEdge[187, 213] -> 
             RGBColor[
              0.395904109711405, 0.5173339739380506, 0.9464476376799205], 
             UndirectedEdge[41, 222] -> 
             RGBColor[
              0.3965617253644508, 0.517903567563995, 0.9464895403678258], 
             UndirectedEdge[196, 263] -> 
             RGBColor[
              0.27095799274113747`, 0.40212440847289477`, 0.9387420288889549],
              UndirectedEdge[148, 172] -> 
             RGBColor[
              0.2541544433679442, 0.3844628126751034, 0.9377850916107751], 
             UndirectedEdge[96, 171] -> 
             RGBColor[
              0.4119096090232586, 0.5311971329821921, 0.9474674939429645], 
             UndirectedEdge[178, 208] -> 
             RGBColor[
              0.2815080542956977, 0.41321319207927465`, 0.9393428392870697], 
             UndirectedEdge[25, 270] -> 
             RGBColor[
              0.24003287271686014`, 0.3696201465615213, 0.9369808890531874], 
             UndirectedEdge[47, 217] -> 
             RGBColor[
              0.7255477462839056, 0.7855226808548759, 0.9732794767865461], 
             UndirectedEdge[33, 142] -> 
             RGBColor[
              0.7868432036591011, 0.8341724103626897, 0.9791857606964562], 
             UndirectedEdge[26, 62] -> 
             RGBColor[
              0.9903418616011138, 0.9899003526601282, 0.7825545152346283], 
             UndirectedEdge[48, 177] -> 
             RGBColor[
              0.4164452697798513, 0.5351256943606145, 0.9477565022356473], 
             UndirectedEdge[238, 300] -> 
             RGBColor[
              0.2671877155710705, 0.398161608117775, 0.9385273171817448], 
             UndirectedEdge[25, 139] -> 
             RGBColor[
              0.25364452897953216`, 0.38392686032244283`, 0.9377560527407058],
              UndirectedEdge[3, 30] -> 
             RGBColor[
              0.4197616538813304, 0.5377570557762624, 0.9480344425242617], 
             UndirectedEdge[95, 171] -> 
             RGBColor[
              0.45349990749309843`, 0.5662613073140733, 0.9503826351187716], 
             UndirectedEdge[21, 50] -> 
             RGBColor[
              0.3679518676107426, 0.4931231467509946, 0.9446665455304635], 
             UndirectedEdge[122, 232] -> 
             RGBColor[
              0.8091446434633787, 0.8477841192514302, 0.781190448595753], 
             UndirectedEdge[127, 136] -> 
             RGBColor[
              0.886150619739554, 0.4976836876486773, 0.27581787003783265`], 
             UndirectedEdge[41, 290] -> 
             RGBColor[
              0.4849597446468357, 0.5901356836497829, 0.9533196272793637], 
             UndirectedEdge[123, 259] -> 
             RGBColor[
              0.4502407471664895, 0.5641005142419657, 0.9499920164228051], 
             UndirectedEdge[20, 185] -> 
             RGBColor[
              0.7169880778773853, 0.7780689639663625, 0.973105894503761], 
             UndirectedEdge[163, 211] -> 
             RGBColor[
              0.2418593140070983, 0.3715398521606279, 0.9370849021826888], 
             UndirectedEdge[33, 37] -> 
             RGBColor[
              0.7976827143280194, 0.8426403184805812, 0.9802661418189477], 
             UndirectedEdge[7, 9] -> 
             RGBColor[
              0.45578820295562306`, 0.5674780753124783, 0.9507398809647807], 
             UndirectedEdge[105, 263] -> 
             RGBColor[
              0.2750769487244079, 0.40645369236820506`, 0.9389765973387527], 
             UndirectedEdge[15, 49] -> 
             RGBColor[
              0.2377386487348052, 0.36720877169417954`, 0.9368502363914097], 
             UndirectedEdge[20, 237] -> 
             RGBColor[
              0.752342583517374, 0.8067713443472341, 0.9758891306955624], 
             UndirectedEdge[26, 220] -> 
             RGBColor[
              0.6215133643769486, 0.6880328107560196, 0.9111862353388274], 
             UndirectedEdge[101, 187] -> 
             RGBColor[
              0.4552598760386822, 0.566212394980653, 0.9509294886200896], 
             UndirectedEdge[93, 94] -> 
             RGBColor[
              0.6965792865266065, 0.7615288190518337, 0.9714662855765266], 
             UndirectedEdge[143, 297] -> 
             RGBColor[
              0.5785745379743751, 0.6654077250363819, 0.9616273334928914], 
             UndirectedEdge[208, 268] -> 
             RGBColor[
              0.274238057450941, 0.4055719644510125, 0.9389288237217572], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.9540665099241967, 0.9616166407194549, 0.7611949655148192], 
             UndirectedEdge[224, 288] -> 
             RGBColor[
              0.897775647296635, 0.6134919733958007, 0.2496893942062774], 
             UndirectedEdge[1, 75] -> 
             RGBColor[
              0.5745175309470449, 0.663163066561993, 0.9608315894360424], 
             UndirectedEdge[36, 113] -> 
             RGBColor[
              0.8594902789211216, 0.8906751050000117, 0.9651321449597499], 
             UndirectedEdge[29, 244] -> 
             RGBColor[
              0.24266708121897157`, 0.3723888667157059, 0.9371309033304205], 
             UndirectedEdge[36, 96] -> 
             RGBColor[
              0.5825185901002536, 0.6688590205760554, 0.9618637653966613], 
             UndirectedEdge[58, 138] -> 
             RGBColor[
              0.6278035428683023, 0.7077328487058376, 0.9645158476926661], 
             UndirectedEdge[71, 136] -> 
             RGBColor[
              0.8112521109064372, 0.8487062087696886, 0.716702550774494], 
             UndirectedEdge[144, 252] -> 
             RGBColor[
              0.3081203950955903, 0.44054062730759674`, 0.940881946213421], 
             UndirectedEdge[58, 198] -> 
             RGBColor[
              0.506589269540044, 0.610311016455952, 0.9542997094772824], 
             UndirectedEdge[110, 154] -> 
             RGBColor[
              0.8670730299822498, 0.8945506998960768, 0.8707032533386501], 
             UndirectedEdge[119, 152] -> 
             RGBColor[
              0.2677604183233837, 0.39876355502190786`, 0.9385599317562512], 
             UndirectedEdge[38, 90] -> 
             RGBColor[
              0.41074538251891396`, 0.5301887384998543, 0.9473933104595927], 
             UndirectedEdge[66, 179] -> 
             RGBColor[
              0.9700512243327243, 0.9756140843487318, 0.8652383260610674], 
             UndirectedEdge[6, 21] -> 
             RGBColor[
              0.3445638718863475, 0.47258152580409235`, 0.9431866859501019], 
             UndirectedEdge[176, 287] -> 
             RGBColor[
              0.5599634445497977, 0.5545563829440247, 0.6024338644222329], 
             UndirectedEdge[142, 237] -> 
             RGBColor[
              0.6489015303358828, 0.7255912381548726, 0.9656775901367828], 
             UndirectedEdge[108, 221] -> 
             RGBColor[
              0.3192668900954462, 0.449648007121744, 0.9416122250035031], 
             UndirectedEdge[44, 256] -> 
             RGBColor[
              0.9801516197044022, 0.9430147833008583, 0.5214481671592728], 
             UndirectedEdge[89, 112] -> 
             RGBColor[
              0.26517294299919314`, 0.39604395440077267`, 0.9384125788643654],
              UndirectedEdge[83, 184] -> 
             RGBColor[
              0.22686279734830417`, 0.3557775623181615, 0.9362308727443287], 
             UndirectedEdge[259, 261] -> 
             RGBColor[
              0.4324511169680622, 0.5486920306968999, 0.9488584769173136], 
             UndirectedEdge[207, 231] -> 
             RGBColor[
              0.5953538117647618, 0.6805701172311853, 0.962430259270135], 
             UndirectedEdge[112, 280] -> 
             RGBColor[
              0.2601358942740522, 0.3907496968233146, 0.9381257263911142], 
             UndirectedEdge[174, 194] -> 
             RGBColor[
              0.45407833864122044`, 0.5660241331600927, 0.9506234541652072], 
             UndirectedEdge[125, 200] -> 
             RGBColor[
              0.9393105629674767, 0.7809252028803274, 0.3326287940678124], 
             UndirectedEdge[99, 222] -> 
             RGBColor[
              0.4018105363813725, 0.5224498238539401, 0.9468239899644828], 
             UndirectedEdge[108, 169] -> 
             RGBColor[
              0.3184727377256654, 0.44881330262893604`, 0.9415669992008873], 
             UndirectedEdge[15, 57] -> 
             RGBColor[
              0.2429878777602664, 0.3727260442202823, 0.9371491722188713], 
             UndirectedEdge[4, 78] -> 
             RGBColor[
              0.3598305300482983, 0.47184581112708096`, 0.9452322348805061], 
             UndirectedEdge[52, 86] -> 
             RGBColor[
              0.8700945440512431, 0.4003729911487963, 0.2286822767734516], 
             UndirectedEdge[20, 282] -> 
             RGBColor[
              0.9147814478549319, 0.9341649508472791, 0.9667376994595409], 
             UndirectedEdge[42, 55] -> 
             RGBColor[
              0.2655663224814774, 0.39645742117835314`, 0.9384349812439285], 
             UndirectedEdge[136, 165] -> 
             RGBColor[
              0.9865840174672071, 0.9661571328498515, 0.42361874182822423`], 
             UndirectedEdge[161, 269] -> 
             RGBColor[
              0.22164816720784125`, 0.350296655413888, 0.9359339072721834], 
             UndirectedEdge[57, 243] -> 
             RGBColor[
              0.23260979600231052`, 0.3618180222842825, 0.9365581558157519], 
             UndirectedEdge[57, 146] -> 
             RGBColor[
              0.23875177461672836`, 0.3682736312319718, 0.9369079324115999], 
             UndirectedEdge[4, 130] -> 
             RGBColor[
              0.3592738699625091, 0.4712607260826286, 0.9452005339121252], 
             UndirectedEdge[31, 58] -> 
             RGBColor[
              0.583879953556761, 0.6730590756463584, 0.9603843152481828], 
             UndirectedEdge[95, 140] -> 
             RGBColor[
              0.4083602605702821, 0.527163613934152, 0.9475063767322723], 
             UndirectedEdge[58, 96] -> 
             RGBColor[
              0.47719454661287236`, 0.585147759754026, 0.9523446486820593], 
             UndirectedEdge[16, 94] -> 
             RGBColor[
              0.9277097420952534, 0.9406004694880592, 0.7586810334703302], 
             UndirectedEdge[113, 135] -> 
             RGBColor[
              0.9747525126984742, 0.9797102206225822, 0.8836982332246824], 
             UndirectedEdge[47, 262] -> 
             RGBColor[
              0.8190197652374052, 0.8556976322352333, 0.77563363654671], 
             UndirectedEdge[153, 211] -> 
             RGBColor[
              0.25792046228139853`, 0.38842113733253425`, 0.9379995608165705],
              UndirectedEdge[89, 111] -> 
             RGBColor[
              0.26057341862775985`, 0.3912095626597075, 0.9381506427557986], 
             UndirectedEdge[137, 256] -> 
             RGBColor[
              0.8954601293848767, 0.5649130128911231, 0.36889490609502695`], 
             UndirectedEdge[136, 181] -> 
             RGBColor[
              0.8533623737727853, 0.8817985705963918, 0.7207660407906598], 
             UndirectedEdge[288, 291] -> 
             RGBColor[
              0.8472367474404496, 0.3567561650145, 0.19258017572083644`], 
             UndirectedEdge[121, 296] -> 
             RGBColor[
              0.8454228514141477, 0.8767518585640715, 0.8125406426515358], 
             UndirectedEdge[241, 277] -> 
             RGBColor[
              0.3140852328677468, 0.44372332658360614`, 0.9413346549652732], 
             UndirectedEdge[217, 262] -> 
             RGBColor[
              0.9005077184585596, 0.9193566406229818, 0.783755594175576], 
             UndirectedEdge[75, 142] -> 
             RGBColor[
              0.6947680744610263, 0.7614773672926725, 0.9702116467516284], 
             UndirectedEdge[57, 112] -> 
             RGBColor[
              0.24963320232510341`, 0.37971070167583876`, 0.9375276136219621],
              UndirectedEdge[274, 287] -> 
             RGBColor[
              0.9527752319881305, 0.8479297220628771, 0.29412403319976], 
             UndirectedEdge[97, 252] -> 
             RGBColor[
              0.2790058648824081, 0.41058323235793537`, 0.9392003433016403], 
             UndirectedEdge[18, 69] -> 
             RGBColor[
              0.9697193647682323, 0.9735318279786378, 0.7296111092370301], 
             UndirectedEdge[106, 167] -> 
             RGBColor[
              0.7052976145619072, 0.7697031240469493, 0.9712611329047376], 
             UndirectedEdge[256, 296] -> 
             RGBColor[
              0.8457417773194627, 0.8774340088271846, 0.8472537592625196], 
             UndirectedEdge[131, 183] -> 
             RGBColor[
              0.2897103519915022, 0.4203471391973532, 0.9398644012377442], 
             UndirectedEdge[172, 183] -> 
             RGBColor[
              0.2620424461666492, 0.39275360374480583`, 0.9382343017009069], 
             UndirectedEdge[1, 143] -> 
             RGBColor[
              0.4076363549020162, 0.5274958550423691, 0.9471952059690492], 
             UndirectedEdge[17, 252] -> 
             RGBColor[
              0.29837684649391727`, 0.43094336222280266`, 0.9403034920476165],
              UndirectedEdge[126, 214] -> 
             RGBColor[
              0.21941035515512047`, 0.34794457306099935`, 0.9358064671863272],
              UndirectedEdge[84, 134] -> 
             RGBColor[
              0.2873093787457973, 0.41931075190154404`, 0.9396732161322123], 
             UndirectedEdge[45, 234] -> 
             RGBColor[
              0.84432219426478, 0.3416853839942764, 0.19007628932369913`], 
             UndirectedEdge[32, 156] -> 
             RGBColor[
              0.24197823755521267`, 0.3716648483498845, 0.9370916747028223], 
             UndirectedEdge[140, 149] -> 
             RGBColor[
              0.3110114912745308, 0.4424361680704541, 0.9410884474530516], 
             UndirectedEdge[16, 150] -> 
             RGBColor[
              0.9777383321225639, 0.9798135163001478, 0.7399324978339024], 
             UndirectedEdge[209, 218] -> 
             RGBColor[
              0.2605995221174108, 0.3912369990823875, 0.9381521293109176], 
             UndirectedEdge[82, 281] -> 
             RGBColor[
              0.8890764883956016, 0.5161623144377598, 0.3566216396513491], 
             UndirectedEdge[178, 182] -> 
             RGBColor[
              0.29211972893207316`, 0.4243667349411374, 0.9399471584590454], 
             UndirectedEdge[41, 157] -> 
             RGBColor[
              0.35148560431038395`, 0.4788608970986815, 0.9436173297935095], 
             UndirectedEdge[254, 288] -> 
             RGBColor[
              0.8717080465977426, 0.5103380275948782, 0.21466238816866762`], 
             UndirectedEdge[129, 161] -> 
             RGBColor[
              0.22609023535273692`, 0.35496555067756064`, 0.9361868764815843],
              UndirectedEdge[20, 283] -> 
             RGBColor[
              0.7423144926570131, 0.7986300884264481, 0.9750996826489275], 
             UndirectedEdge[162, 210] -> 
             RGBColor[
              0.33154191612091594`, 0.45934744108992703`, 0.9424285250056568],
              UndirectedEdge[203, 244] -> 
             RGBColor[
              0.2510525753068279, 0.38120255267307596`, 0.9376084448134971], 
             UndirectedEdge[121, 246] -> 
             RGBColor[
              0.796739020185918, 0.8380534516751759, 0.8081437970002479], 
             UndirectedEdge[24, 259] -> 
             RGBColor[
              0.7099488174717532, 0.7711907329676471, 0.9554734955620947], 
             UndirectedEdge[141, 281] -> 
             RGBColor[
              0.857051745332458, 0.3969615446650806, 0.200599236428549], 
             UndirectedEdge[110, 138] -> 
             RGBColor[
              0.8498149400101593, 0.8810685488435381, 0.8689831282162525], 
             UndirectedEdge[67, 109] -> 
             RGBColor[
              0.916743494821664, 0.9364503947042759, 0.9919210069943111], 
             UndirectedEdge[154, 245] -> 
             RGBColor[
              0.5828013526273942, 0.6698841791824666, 0.9615515465694076], 
             UndirectedEdge[193, 249] -> 
             RGBColor[
              0.6788858964789302, 0.269361770595781, 0.42584254337299554`], 
             UndirectedEdge[82, 137] -> 
             RGBColor[
              0.8954030295607297, 0.5647908821409502, 0.362679942615882], 
             UndirectedEdge[100, 125] -> 
             RGBColor[
              0.897661942750397, 0.5866871608849751, 0.27668170348161025`], 
             UndirectedEdge[104, 218] -> 
             RGBColor[
              0.2705572837668725, 0.40170323793452584`, 0.9387192091056663], 
             UndirectedEdge[73, 149] -> 
             RGBColor[
              0.3114795465639533, 0.4428415740370091, 0.9411182715222086], 
             UndirectedEdge[108, 219] -> 
             RGBColor[
              0.30907770812291846`, 0.4389385308371674, 0.9410319661637115], 
             UndirectedEdge[58, 140] -> 
             RGBColor[
              0.4384985979215843, 0.5516312739125644, 0.9498789770489342], 
             UndirectedEdge[9, 63] -> 
             RGBColor[
              0.42067147200560917`, 0.537061727981794, 0.9485022739211517], 
             UndirectedEdge[48, 217] -> 
             RGBColor[
              0.6103593020998471, 0.6909573809034649, 0.9644909605952465], 
             UndirectedEdge[8, 271] -> 
             RGBColor[
              0.814657116181253, 0.8317974978685563, 0.6664449508576125], 
             UndirectedEdge[18, 222] -> 
             RGBColor[
              0.6912666998914337, 0.7558621322945974, 0.9623123726675136], 
             UndirectedEdge[215, 234] -> 
             RGBColor[
              0.8765804096252258, 0.42016569118196145`, 0.35308390005828916`],
              UndirectedEdge[15, 146] -> 
             RGBColor[
              0.2346866767510397, 0.3640009556330419, 0.9366764311019222], 
             UndirectedEdge[54, 151] -> 
             RGBColor[
              0.4303399784091667, 0.5471605926069658, 0.9486418607828988], 
             UndirectedEdge[195, 255] -> 
             RGBColor[
              0.8657472839011056, 0.38983708419241014`, 0.20899218597950728`],
              UndirectedEdge[1, 11] -> 
             RGBColor[
              0.3810142316306978, 0.5044371099315746, 0.9454988678152201], 
             UndirectedEdge[32, 178] -> 
             RGBColor[
              0.2666569110282901, 0.3976036988883609, 0.9384970886482884], 
             UndirectedEdge[126, 189] -> 
             RGBColor[
              0.22889351140479614`, 0.3579119715462422, 0.9363465189056738], 
             UndirectedEdge[61, 273] -> 
             RGBColor[
              0.5923372400801741, 0.6799250818424811, 0.9610501038233672], 
             UndirectedEdge[54, 194] -> 
             RGBColor[
              0.4666198015964266, 0.5768869180196359, 0.9514225850947327], 
             UndirectedEdge[38, 144] -> 
             RGBColor[
              0.36682689322971884`, 0.49214875048500833`, 0.9445948631576804],
              UndirectedEdge[4, 220] -> 
             RGBColor[
              0.3984062395141392, 0.5123913276169251, 0.9474290644669376], 
             UndirectedEdge[45, 200] -> 
             RGBColor[
              0.8672145142441139, 0.4887150856762938, 0.21086514708656048`], 
             UndirectedEdge[2, 202] -> 
             RGBColor[
              0.22943917498765481`, 0.3584854985688961, 0.9363775936394806], 
             UndirectedEdge[17, 175] -> 
             RGBColor[
              0.29536678813966943`, 0.42777960004376564`, 0.9401320736773244],
              UndirectedEdge[233, 262] -> 
             RGBColor[
              0.9940341182393746, 0.9896479070942221, 0.5920287713894679], 
             UndirectedEdge[67, 138] -> 
             RGBColor[
              0.8095011172691953, 0.8518539963630647, 0.9814491180759526], 
             UndirectedEdge[39, 192] -> 
             RGBColor[
              0.8666838536380115, 0.4875243407948174, 0.2104700784088291], 
             UndirectedEdge[164, 168] -> 
             RGBColor[
              0.38489864849528777`, 0.5078015965832141, 0.9457463794229767], 
             UndirectedEdge[19, 253] -> 
             RGBColor[
              0.2939962623956044, 0.42633909059040226`, 0.940054024263711], 
             UndirectedEdge[24, 74] -> 
             RGBColor[
              0.7969254295463191, 0.8418022649015016, 0.9623206130704325], 
             UndirectedEdge[80, 133] -> 
             RGBColor[
              0.30898841648274356`, 0.43826898504779055`, 0.941047960136832], 
             UndirectedEdge[198, 222] -> 
             RGBColor[
              0.4501940180001994, 0.5640601889318158, 0.9499889976724383], 
             UndirectedEdge[111, 212] -> 
             RGBColor[
              0.2273675902370908, 0.3563081316499939, 0.936259619952571], 
             UndirectedEdge[126, 184] -> 
             RGBColor[
              0.23168784072436213`, 0.3608489888318178, 0.9365056518265833], 
             UndirectedEdge[132, 294] -> 
             RGBColor[
              0.2083047996307834, 0.33627193007203204`, 0.9351740222284133], 
             UndirectedEdge[39, 136] -> 
             RGBColor[
              0.9093243643754532, 0.6566653871649271, 0.29725952697501445`], 
             UndirectedEdge[133, 162] -> 
             RGBColor[
              0.31733689752319516`, 0.44704376794557543`, 0.9415233937816148],
              UndirectedEdge[22, 271] -> 
             RGBColor[
              0.8974219616748091, 0.8964540242042457, 0.6746941771749546], 
             UndirectedEdge[107, 110] -> 
             RGBColor[
              0.8870800066449858, 0.5061000302265065, 0.3757440054051945], 
             UndirectedEdge[40, 191] -> 
             RGBColor[
              0.24055073236956107`, 0.37016444989070835`, 0.9370103803943042],
              UndirectedEdge[143, 237] -> 
             RGBColor[
              0.5177646791690618, 0.6178477648970354, 0.9556038669239417], 
             UndirectedEdge[157, 261] -> 
             RGBColor[
              0.3733109108199431, 0.49776488062546065`, 0.9450080190249379], 
             UndirectedEdge[35, 163] -> 
             RGBColor[
              0.23379526623113445`, 0.36306402665793014`, 0.9366256665915373],
              UndirectedEdge[89, 175] -> 
             RGBColor[
              0.28632181999450856`, 0.4182727650390983, 0.9396169761222888], 
             UndirectedEdge[16, 200] -> 
             RGBColor[
              0.939733161025506, 0.7818290973952341, 0.3786259847113931], 
             UndirectedEdge[35, 189] -> 
             RGBColor[
              0.2290398133604396, 0.3580657441777033, 0.9363548505856133], 
             UndirectedEdge[233, 291] -> 
             RGBColor[
              0.8766348422710215, 0.4223576865529295, 0.30917062318117206`], 
             UndirectedEdge[258, 290] -> 
             RGBColor[
              0.7873478763723856, 0.8338243344390612, 0.9561368785302078], 
             UndirectedEdge[157, 259] -> 
             RGBColor[
              0.40512064339431064`, 0.5250197481568593, 0.947117003308583], 
             UndirectedEdge[105, 245] -> 
             RGBColor[
              0.35678647711021616`, 0.4816423424493619, 0.944021366181159], 
             UndirectedEdge[100, 192] -> 
             RGBColor[
              0.8551155999405852, 0.4177475301902278, 0.2001418527008563], 
             UndirectedEdge[258, 278] -> 
             RGBColor[
              0.7823492729369855, 0.8297662429856849, 0.9557433701572854], 
             UndirectedEdge[99, 201] -> 
             RGBColor[
              0.34430071595550393`, 0.4726377079286733, 0.9431595150608838], 
             UndirectedEdge[9, 282] -> 
             RGBColor[
              0.740243347265956, 0.7955203413934655, 0.9507546007091144], 
             UndirectedEdge[84, 175] -> 
             RGBColor[
              0.29756458350130965`, 0.4300896223171238, 0.940257234871823], 
             UndirectedEdge[271, 291] -> 
             RGBColor[
              0.8710936578057457, 0.40431831637281135`, 0.23217335977663117`],
              UndirectedEdge[127, 256] -> 
             RGBColor[
              0.8869307215281732, 0.49935224649414445`, 0.36072713549885926`],
              UndirectedEdge[80, 116] -> 
             RGBColor[
              0.2951188116057152, 0.426255830409919, 0.9401642011784779], 
             UndirectedEdge[202, 268] -> 
             RGBColor[
              0.2453187041670522, 0.37517589055674394`, 0.937281909334589], 
             UndirectedEdge[161, 265] -> 
             RGBColor[
              0.21936843133233605`, 0.34790050846512904`, 0.9358040796866404],
              UndirectedEdge[22, 72] -> 
             RGBColor[
              0.7345932590636062, 0.7925891041868212, 0.9741810489653038], 
             UndirectedEdge[77, 162] -> 
             RGBColor[
              0.26527957680517633`, 0.3961560332918348, 0.9384186515018654], 
             UndirectedEdge[93, 164] -> 
             RGBColor[
              0.45756686024315646`, 0.5686282136761757, 0.9509610966011381], 
             UndirectedEdge[19, 111] -> 
             RGBColor[
              0.2671407671011217, 0.39811226229915386`, 0.9385246435358352], 
             UndirectedEdge[37, 142] -> 
             RGBColor[
              0.669863260251737, 0.742021537148777, 0.9677293676199676], 
             UndirectedEdge[43, 172] -> 
             RGBColor[
              0.2958345713391305, 0.4270297833847875, 0.9402041701394114], 
             UndirectedEdge[61, 285] -> 
             RGBColor[
              0.474805368949063, 0.5825919070766665, 0.9523268246944521], 
             UndirectedEdge[38, 257] -> 
             RGBColor[
              0.4046248085689348, 0.5248874049733736, 0.9470033128997111], 
             UndirectedEdge[174, 185] -> 
             RGBColor[
              0.4801968939468863, 0.58722835298474, 0.9526796025142897], 
             UndirectedEdge[75, 237] -> 
             RGBColor[
              0.6846458552140906, 0.7535149764166593, 0.969240250390935], 
             UndirectedEdge[30, 48] -> 
             RGBColor[
              0.43794065467516774`, 0.5535027925607373, 0.9491927923797858], 
             UndirectedEdge[289, 298] -> 
             RGBColor[
              0.28811767425307283`, 0.4201603217285858, 0.9397192473655857], 
             UndirectedEdge[123, 261] -> 
             RGBColor[
              0.41843101459212195`, 0.5368456467105671, 0.9478830321391599], 
             UndirectedEdge[77, 206] -> 
             RGBColor[
              0.2413530899135048, 0.3710077785417997, 0.9370560734694501], 
             UndirectedEdge[121, 137] -> 
             RGBColor[
              0.8952475121146669, 0.5644582460490475, 0.34575282835437127`], 
             UndirectedEdge[87, 227] -> 
             RGBColor[
              0.2679362427515092, 0.39894835764378045`, 0.938569944697324], 
             UndirectedEdge[123, 144] -> 
             RGBColor[
              0.3759650676291757, 0.5000637778518178, 0.9451771395498434], 
             UndirectedEdge[9, 37] -> 
             RGBColor[
              0.5987662128442524, 0.684557033887325, 0.9619578094283205], 
             UndirectedEdge[178, 268] -> 
             RGBColor[
              0.26978635473276824`, 0.4008929426399584, 0.9386753058376613], 
             UndirectedEdge[112, 253] -> 
             RGBColor[
              0.2744693999473012, 0.40581512008264853`, 0.9389419983346845], 
             UndirectedEdge[78, 220] -> 
             RGBColor[
              0.21861602963741927`, 0.34710968657874874`, 0.9357612315231933],
              UndirectedEdge[66, 67] -> 
             RGBColor[
              0.9293871027463778, 0.9462546742934231, 0.9835096743331035], 
             UndirectedEdge[20, 124] -> 
             RGBColor[
              0.9067998303302157, 0.928212273566045, 0.9802484959896351], 
             UndirectedEdge[18, 224] -> 
             RGBColor[
              0.9579627169351427, 0.9342040847269458, 0.6558617372883351], 
             UndirectedEdge[72, 151] -> 
             RGBColor[
              0.5475405416357872, 0.6431396338261914, 0.9576978591404627], 
             UndirectedEdge[25, 29] -> 
             RGBColor[
              0.24731665325336327`, 0.3772758617237455, 0.9373956895793536], 
             UndirectedEdge[135, 258] -> 
             RGBColor[
              0.9759313858945792, 0.9805894223220096, 0.8817027084030489], 
             UndirectedEdge[130, 176] -> 
             RGBColor[
              0.17893943915932659`, 0.3054070743451405, 0.9335017083917216], 
             UndirectedEdge[31, 245] -> 
             RGBColor[
              0.5216196733437626, 0.6217282550704486, 0.9556998890025264], 
             UndirectedEdge[295, 297] -> 
             RGBColor[
              0.7988419039700752, 0.8429204696534232, 0.9805476453412715], 
             UndirectedEdge[17, 30] -> 
             RGBColor[
              0.37921039896007874`, 0.5014757039177918, 0.9454929485539587], 
             UndirectedEdge[22, 273] -> 
             RGBColor[
              0.717607033402136, 0.7789436605631201, 0.9727448718111256], 
             UndirectedEdge[86, 165] -> 
             RGBColor[
              0.9775639799613888, 0.9359801775610526, 0.3673407281472113], 
             UndirectedEdge[124, 200] -> 
             RGBColor[
              0.916844882326316, 0.7678634053812667, 0.6000047488264095], 
             UndirectedEdge[198, 258] -> 
             RGBColor[
              0.7130111957358749, 0.7734744682690422, 0.9502848227262681], 
             UndirectedEdge[177, 217] -> 
             RGBColor[
              0.6131216671850642, 0.6933500026997739, 0.964666976055813], 
             UndirectedEdge[52, 110] -> 
             RGBColor[
              0.876120671367751, 0.4218617768743392, 0.3652493335669156], 
             UndirectedEdge[121, 299] -> 
             RGBColor[
              0.9945473356554072, 0.9914335784226265, 0.6978961075730188], 
             UndirectedEdge[173, 196] -> 
             RGBColor[
              0.2690530219671379, 0.40012216340729806`, 0.9386335436215274], 
             UndirectedEdge[238, 251] -> 
             RGBColor[
              0.2826141781107905, 0.4143757983412377, 0.9394058314019756], 
             UndirectedEdge[218, 284] -> 
             RGBColor[
              0.25584347148447395`, 0.38623808831614403`, 0.9378812792633183],
              UndirectedEdge[209, 276] -> 
             RGBColor[
              0.24846893317691396`, 0.37848698098216405`, 0.9374613102163545],
              UndirectedEdge[8, 72] -> 
             RGBColor[
              0.6518284135700501, 0.7279325778511317, 0.9659318226479615], 
             UndirectedEdge[56, 168] -> 
             RGBColor[
              0.46678271330407606`, 0.5761629717082618, 0.9516719821972282], 
             UndirectedEdge[201, 257] -> 
             RGBColor[
              0.35620917982441114`, 0.48295222079512334`, 0.9439183118483695],
              UndirectedEdge[31, 51] -> 
             RGBColor[
              0.8061994237416004, 0.8465221719044482, 0.8597460281820752], 
             UndirectedEdge[53, 282] -> 
             RGBColor[
              0.8757050929352991, 0.4873983488879218, 0.43414587491943724`], 
             UndirectedEdge[17, 97] -> 
             RGBColor[
              0.27685141165294697`, 0.4083187654135474, 0.9390776503774505], 
             UndirectedEdge[102, 162] -> 
             RGBColor[
              0.3349247683998675, 0.4622774977068556, 0.9426440773615328], 
             UndirectedEdge[36, 260] -> 
             RGBColor[
              0.8043625245684116, 0.8473291531354724, 0.9810724316171817], 
             UndirectedEdge[79, 168] -> 
             RGBColor[
              0.3904018999447999, 0.5125682363873212, 0.9460970417390054], 
             UndirectedEdge[142, 297] -> 
             RGBColor[
              0.7097113891411961, 0.773151198294219, 0.9717010567057325], 
             UndirectedEdge[232, 299] -> 
             RGBColor[
              0.994290544063115, 0.9908843271723261, 0.6699459274860231], 
             UndirectedEdge[50, 169] -> 
             RGBColor[
              0.3227370521664461, 0.4525068374668645, 0.9418387175462686], 
             UndirectedEdge[92, 153] -> 
             RGBColor[
              0.26728945052082176`, 0.3982685380003319, 0.9385331108366297], 
             UndirectedEdge[44, 299] -> 
             RGBColor[
              0.979769906119425, 0.942886287709507, 0.5299077867568601], 
             UndirectedEdge[90, 252] -> 
             RGBColor[
              0.35203888438478537`, 0.4785806153224426, 0.9436803935153333], 
             UndirectedEdge[7, 283] -> 
             RGBColor[
              0.5067349402558111, 0.6088389317771312, 0.9547505947490993], 
             UndirectedEdge[52, 179] -> 
             RGBColor[
              0.8763542039313392, 0.42195834859089604`, 0.36137909462535833`],
              UndirectedEdge[98, 296] -> 
             RGBColor[
              0.559521387516622, 0.6516299340358314, 0.9592598962290395], 
             UndirectedEdge[18, 88] -> 
             RGBColor[
              0.7253109400374347, 0.7839674018676228, 0.9648635309809819], 
             UndirectedEdge[100, 240] -> 
             RGBColor[
              0.8984314070002761, 0.5883329671106973, 0.36043313849805947`], 
             UndirectedEdge[2, 214] -> 
             RGBColor[
              0.2218197182328839, 0.35047696641817105`, 0.9359436768492726], 
             UndirectedEdge[114, 169] -> 
             RGBColor[
              0.2987181224804576, 0.4313020649228039, 0.9403229272101774], 
             UndirectedEdge[37, 295] -> 
             RGBColor[
              0.7589937750806162, 0.8117908085079812, 0.9765759562555065], 
             UndirectedEdge[45, 225] -> 
             RGBColor[
              0.8922034790216946, 0.5903032781532196, 0.23628645255656144`], 
             UndirectedEdge[38, 74] -> 
             RGBColor[
              0.5280791848415985, 0.6267970188090106, 0.9562568575389798], 
             UndirectedEdge[38, 158] -> 
             RGBColor[
              0.41078817614673724`, 0.5302258041894045, 0.9473960372317167], 
             UndirectedEdge[69, 135] -> 
             RGBColor[
              0.9915668730357023, 0.9888448386688236, 0.6487056199187353], 
             UndirectedEdge[113, 224] -> 
             RGBColor[
              0.9644670009376046, 0.9390549690861945, 0.644851681061125], 
             UndirectedEdge[124, 282] -> 
             RGBColor[
              0.9556754222393467, 0.9664633829977154, 0.9599141278341408], 
             UndirectedEdge[56, 79] -> 
             RGBColor[
              0.47131158576889715`, 0.5800856534095411, 0.9519605579459619], 
             UndirectedEdge[49, 146] -> 
             RGBColor[
              0.23350254559126715`, 0.3627563587058691, 0.9366089965841382], 
             UndirectedEdge[47, 166] -> 
             RGBColor[
              0.8183915236203407, 0.8543538869413033, 0.7072534135870767], 
             UndirectedEdge[189, 197] -> 
             RGBColor[
              0.22117434471858483`, 0.3497986379355985, 0.9359069237823778], 
             UndirectedEdge[125, 256] -> 
             RGBColor[
              0.9939365705713255, 0.9894392624958468, 0.5814113097167279], 
             UndirectedEdge[69, 138] -> 
             RGBColor[
              0.8498609562052564, 0.8791517168657417, 0.7275038724573385], 
             UndirectedEdge[170, 255] -> 
             RGBColor[
              0.8675804054698418, 0.4039272598487107, 0.21074758526394385`], 
             UndirectedEdge[41, 104] -> 
             RGBColor[
              0.3210313076505878, 0.45029407852530423`, 0.9417569530026035], 
             UndirectedEdge[185, 283] -> 
             RGBColor[
              0.5933967145885973, 0.6807852109772019, 0.9611335095376532], 
             UndirectedEdge[103, 277] -> 
             RGBColor[
              0.3139559658390563, 0.44358745874044936`, 0.9413272933992227], 
             UndirectedEdge[45, 282] -> 
             RGBColor[
              0.8931015408528009, 0.6211150707539262, 0.45080473309171465`], 
             UndirectedEdge[222, 245] -> 
             RGBColor[
              0.43026765068117134`, 0.5470979459642735, 0.9486372521240278], 
             UndirectedEdge[53, 195] -> 
             RGBColor[
              0.8275339988457331, 0.2126439573693409, 0.17399989443086508`], 
             UndirectedEdge[121, 136] -> 
             RGBColor[
              0.9937588965574554, 0.9890592357457773, 0.5620725897838914], 
             UndirectedEdge[92, 211] -> 
             RGBColor[
              0.2517282610763278, 0.3819127412577725, 0.9376469241184826], 
             UndirectedEdge[26, 137] -> 
             RGBColor[
              0.8923224675531893, 0.5636350776132415, 0.42231650775556523`], 
             UndirectedEdge[139, 148] -> 
             RGBColor[
              0.24714609636833407`, 0.37709659562364867`, 0.9373859766170676],
              UndirectedEdge[69, 258] -> 
             RGBColor[
              0.9774025219667993, 0.9792619140373138, 0.7166055281881865], 
             UndirectedEdge[244, 272] -> 
             RGBColor[
              0.23289575947638014`, 0.3621185880266611, 0.936574441012555], 
             UndirectedEdge[100, 256] -> 
             RGBColor[
              0.8985362124666462, 0.5885571354058046, 0.3718405667280683], 
             UndirectedEdge[29, 206] -> 
             RGBColor[
              0.23974836289368467`, 0.3693211086983992, 0.9369646866396522], 
             UndirectedEdge[101, 213] -> 
             RGBColor[
              0.48723449014775655`, 0.5939071986311, 0.9529668827570787], 
             UndirectedEdge[39, 107] -> 
             RGBColor[
              0.8564041483183775, 0.41541072064133033`, 0.20089643507288318`],
              UndirectedEdge[134, 252] -> 
             RGBColor[
              0.28726603661361816`, 0.4192651965725739, 0.9396707478619037], 
             UndirectedEdge[14, 288] -> 
             RGBColor[
              0.8357655046599107, 0.272249042199298, 0.18173884718697714`], 
             UndirectedEdge[155, 202] -> 
             RGBColor[
              0.22021191752572378`, 0.34878706593449305`, 0.9358521149775277],
              UndirectedEdge[220, 228] -> 
             RGBColor[
              0.5367674910110247, 0.6220540079829862, 0.9601435922342896], 
             UndirectedEdge[228, 266] -> 
             RGBColor[
              0.5319885984693589, 0.6170310889224077, 0.9598714413737797], 
             UndirectedEdge[113, 249] -> 
             RGBColor[
              0.8655230747652505, 0.41896226614950405`, 0.42814822498187033`],
              UndirectedEdge[109, 179] -> 
             RGBColor[
              0.9574076164080104, 0.9658098047595847, 0.8736496587222751], 
             UndirectedEdge[41, 209] -> 
             RGBColor[
              0.3110735460011261, 0.43982783967316585`, 0.9411898732078549], 
             UndirectedEdge[76, 261] -> 
             RGBColor[
              0.3474685023612617, 0.4740454489620557, 0.9434102824444082], 
             UndirectedEdge[114, 219] -> 
             RGBColor[
              0.28932309287771063`, 0.4214272931310352, 0.9397878941730018], 
             UndirectedEdge[130, 266] -> 
             RGBColor[
              0.21328047700996416`, 0.3415016824737179, 0.9354573796943026], 
             UndirectedEdge[1, 185] -> 
             RGBColor[
              0.4932964811819127, 0.5985745570433215, 0.9535142966293955], 
             UndirectedEdge[202, 208] -> 
             RGBColor[
              0.2570404037299817, 0.3874961399960602, 0.9379494427839974], 
             UndirectedEdge[8, 285] -> 
             RGBColor[
              0.5173103167774687, 0.616953959461616, 0.9557723663648683], 
             UndirectedEdge[65, 210] -> 
             RGBColor[
              0.33323684341077736`, 0.46112891713616844`, 0.9425250486073942],
              UndirectedEdge[63, 183] -> 
             RGBColor[
              0.28955139027076127`, 0.4202094545444958, 0.939854272337463], 
             UndirectedEdge[51, 86] -> 
             RGBColor[
              0.9842148587859489, 0.9592452118717956, 0.5566107984418112], 
             UndirectedEdge[91, 191] -> 
             RGBColor[
              0.2582507185162887, 0.38876825757485856`, 0.9380183684205773], 
             UndirectedEdge[122, 181] -> 
             RGBColor[
              0.6690049122710009, 0.741072705352345, 0.9678340796895172], 
             UndirectedEdge[17, 42] -> 
             RGBColor[
              0.2753301177357401, 0.4067197890509576, 0.9389910149394182], 
             UndirectedEdge[90, 253] -> 
             RGBColor[
              0.3501359199582715, 0.4765804790552632, 0.9435720225064269], 
             UndirectedEdge[60, 136] -> 
             RGBColor[
              0.9594950595498875, 0.8659435606987382, 0.3644021078697419], 
             UndirectedEdge[80, 210] -> 
             RGBColor[
              0.3231934350804644, 0.45057265819214215`, 0.941953091360874], 
             UndirectedEdge[229, 259] -> 
             RGBColor[
              0.40532480006275245`, 0.5251965784018511, 0.9471300119909675], 
             UndirectedEdge[97, 159] -> 
             RGBColor[
              0.2524370830607903, 0.3826577581053522, 0.9376872904818896], 
             UndirectedEdge[242, 280] -> 
             RGBColor[
              0.25424538211649345`, 0.38455839506567835`, 0.9377902704379731],
              UndirectedEdge[88, 99] -> 
             RGBColor[
              0.43585477652737337`, 0.5505550934269655, 0.9493751482779511], 
             UndirectedEdge[21, 46] -> 
             RGBColor[
              0.3377964064979223, 0.4654684905987692, 0.942801288807799], 
             UndirectedEdge[246, 256] -> 
             RGBColor[
              0.7970579460912328, 0.838735601938289, 0.8428569136112316], 
             UndirectedEdge[14, 135] -> 
             RGBColor[
              0.8784970455730444, 0.4470374784660281, 0.38418003276278484`], 
             UndirectedEdge[67, 179] -> 
             RGBColor[
              0.9529824528221467, 0.9622812994340826, 0.8732275826690652], 
             UndirectedEdge[66, 69] -> 
             RGBColor[
              0.9697469416824389, 0.9735523947961, 0.7295644287144893], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.7503642165832218, 0.805193848255281, 0.9757004322912739], 
             UndirectedEdge[116, 133] -> 
             RGBColor[
              0.3362774461822365, 0.4656883549123332, 0.9426482794056301], 
             UndirectedEdge[2, 83] -> 
             RGBColor[
              0.2235228930753953, 0.35226711116517256`, 0.9360406701369322], 
             UndirectedEdge[103, 168] -> 
             RGBColor[
              0.3323449528082868, 0.45951507499583777`, 0.9424990233881594], 
             UndirectedEdge[26, 199] -> 
             RGBColor[
              0.5823809948253185, 0.6469022092217233, 0.9089577047840149], 
             UndirectedEdge[91, 239] -> 
             RGBColor[
              0.3418733579527955, 0.46719445818593675`, 0.9431271687979139], 
             UndirectedEdge[13, 298] -> 
             RGBColor[
              0.2956902341413986, 0.428119562299244, 0.9401504934486273], 
             UndirectedEdge[229, 261] -> 
             RGBColor[
              0.3735150674883849, 0.49794171087045247`, 0.9450210277073223], 
             UndirectedEdge[141, 179] -> 
             RGBColor[
              0.9463245104461602, 0.8129581160989631, 0.4961968694388046], 
             UndirectedEdge[59, 195] -> 
             RGBColor[
              0.828254689512269, 0.21818350164099967`, 0.17469002862704355`], 
             UndirectedEdge[134, 253] -> 
             RGBColor[
              0.2853630721871043, 0.41726506030539445`, 0.9395623768529974], 
             UndirectedEdge[42, 292] -> 
             RGBColor[
              0.24874967528223313`, 0.3787820587349321, 0.9374772980639317], 
             UndirectedEdge[70, 238] -> 
             RGBColor[
              0.27137415800540265`, 0.40256182455203926`, 0.9387657288850935],
              UndirectedEdge[178, 202] -> 
             RGBColor[
              0.25258870101180897`, 0.3828171181850061, 0.9376959248999015], 
             UndirectedEdge[29, 191] -> 
             RGBColor[
              0.24335597488348387`, 0.37311293763548947`, 0.9371701348054876],
              UndirectedEdge[17, 38] -> 
             RGBColor[
              0.3570833446280458, 0.48255148540021425`, 0.944016408991876], 
             UndirectedEdge[40, 162] -> 
             RGBColor[
              0.2608696072714334, 0.3915208757036531, 0.9381675102608841], 
             UndirectedEdge[13, 95] -> 
             RGBColor[
              0.3973874477451902, 0.5174174988379855, 0.946816060198244], 
             UndirectedEdge[206, 270] -> 
             RGBColor[
              0.23246458235718154`, 0.361665393536175, 0.936549886113486], 
             UndirectedEdge[16, 295] -> 
             RGBColor[
              0.9153775706767935, 0.9307671307468549, 0.7575047799513781], 
             UndirectedEdge[37, 124] -> 
             RGBColor[
              0.8141982878176429, 0.8555000754915749, 0.971117336553347], 
             UndirectedEdge[22, 177] -> 
             RGBColor[
              0.6182933062719121, 0.6973901264603323, 0.9651824367082749], 
             UndirectedEdge[115, 204] -> 
             RGBColor[
              0.22623702836427392`, 0.35511983943990055`, 0.9361952361264305],
              UndirectedEdge[192, 200] -> 
             RGBColor[
              0.8719894116910114, 0.5116156407689246, 0.21489716609938064`], 
             UndirectedEdge[13, 171] -> 
             RGBColor[
              0.3622408475068787, 0.48793453204456394`, 0.9443115057758112], 
             UndirectedEdge[39, 52] -> 
             RGBColor[
              0.8509244806797601, 0.37329159396524664`, 0.19564909915374373`],
              UndirectedEdge[92, 216] -> 
             RGBColor[
              0.25996759819388404`, 0.3905728069724701, 0.9381161421783205], 
             UndirectedEdge[82, 127] -> 
             RGBColor[
              0.8868736217040262, 0.4992301157439715, 0.35451217201971436`], 
             UndirectedEdge[53, 150] -> 
             RGBColor[
              0.875154847057984, 0.48698797641356506`, 0.4350772976626226], 
             UndirectedEdge[18, 66] -> 
             RGBColor[
              0.9464282973427488, 0.95956689239061, 0.9755670982476465], 
             UndirectedEdge[31, 36] -> 
             RGBColor[
              0.6892039970441424, 0.7567703364683878, 0.9699034319627848], 
             UndirectedEdge[71, 181] -> 
             RGBColor[
              0.6717068148993812, 0.7432662316253906, 0.9680467833618187], 
             UndirectedEdge[43, 143] -> 
             RGBColor[
              0.3594618944461463, 0.48576955871427996`, 0.9441255719478039], 
             UndirectedEdge[75, 185] -> 
             RGBColor[
              0.6492913495741017, 0.7248125960357876, 0.9664570141991338], 
             UndirectedEdge[46, 145] -> 
             RGBColor[
              0.280670988716232, 0.4123333830822331, 0.9392951696406466], 
             UndirectedEdge[62, 255] -> 
             RGBColor[
              0.9769015351320889, 0.9322978840038133, 0.4878701995815442], 
             UndirectedEdge[111, 242] -> 
             RGBColor[
              0.24172339249525976`, 0.3713969900337639, 0.9370771616536675], 
             UndirectedEdge[4, 193] -> 
             RGBColor[
              0.46955924674976174`, 0.5787870298978665, 0.9517883446566966], 
             UndirectedEdge[18, 258] -> 
             RGBColor[
              0.9540838776271092, 0.9652764116318238, 0.9626081977213435], 
             UndirectedEdge[81, 267] -> 
             RGBColor[
              0.3818442604921369, 0.5035684061042389, 0.9457044452357559], 
             UndirectedEdge[75, 124] -> 
             RGBColor[
              0.8391031020269322, 0.8749559056354701, 0.9735996156850079], 
             UndirectedEdge[72, 106] -> 
             RGBColor[
              0.6542381545327312, 0.7298150858058879, 0.966172003106812], 
             UndirectedEdge[262, 271] -> 
             RGBColor[
              0.9857223415414609, 0.9625888518240449, 0.4765328762826566], 
             UndirectedEdge[17, 235] -> 
             RGBColor[
              0.2691307812557516, 0.40020389334985473`, 0.9386379718979794], 
             UndirectedEdge[263, 279] -> 
             RGBColor[
              0.25988809011317837`, 0.3904892389385449, 0.938111614310746], 
             UndirectedEdge[3, 252] -> 
             RGBColor[
              0.33892810141516894`, 0.46722471408127325`, 0.9428449860179196],
              UndirectedEdge[48, 158] -> 
             RGBColor[
              0.4086574804982366, 0.5283803027105503, 0.9472602711890945], 
             UndirectedEdge[18, 36] -> 
             RGBColor[
              0.8529859949186596, 0.8858242206407632, 0.9761422011869598], 
             UndirectedEdge[105, 196] -> 
             RGBColor[
              0.28505137622914434`, 0.4169374480909134, 0.9395446262293043], 
             UndirectedEdge[269, 298] -> 
             RGBColor[
              0.2561386884802381, 0.3865483800965307, 0.9378980914344927], 
             UndirectedEdge[85, 207] -> 
             RGBColor[
              0.8326069689699811, 0.8699635257728993, 0.9837364200787462], 
             UndirectedEdge[79, 103] -> 
             RGBColor[
              0.33687382527310783`, 0.4634377566971172, 0.9427875991368931], 
             UndirectedEdge[76, 128] -> 
             RGBColor[
              0.2667781164198233, 0.397731093439728, 0.9385039911160289], 
             UndirectedEdge[10, 265] -> 
             RGBColor[
              0.21694931138635237`, 0.3453578600208368, 0.9356663143844839], 
             UndirectedEdge[88, 198] -> 
             RGBColor[
              0.48423825814620036`, 0.592165458504841, 0.9525401559859066], 
             UndirectedEdge[63, 143] -> 
             RGBColor[
              0.36063166824627285`, 0.4867827579854089, 0.9442001088999576], 
             UndirectedEdge[49, 242] -> 
             RGBColor[
              0.23849346114208345`, 0.3680021273920998, 0.9368932218413593], 
             UndirectedEdge[252, 253] -> 
             RGBColor[
              0.29862833529686444`, 0.43120769290001126`, 0.9403178139629], 
             UndirectedEdge[16, 125] -> 
             RGBColor[
              0.9930477640549809, 0.9875381952295093, 0.4846702054906215], 
             UndirectedEdge[59, 100] -> 
             RGBColor[
              0.8386002140561873, 0.2977037367233178, 0.18459691461389852`], 
             UndirectedEdge[75, 295] -> 
             RGBColor[
              0.7838985892899054, 0.8312466386518764, 0.9790582353871675], 
             UndirectedEdge[94, 295] -> 
             RGBColor[
              0.8496169506590368, 0.8829255104904983, 0.9855184172875062], 
             UndirectedEdge[26, 192] -> 
             RGBColor[
              0.9052690882618898, 0.649347078568056, 0.4341737781925292], 
             UndirectedEdge[132, 188] -> 
             RGBColor[
              0.20621351468350757`, 0.3340738569973212, 0.9350549266444448], 
             UndirectedEdge[186, 196] -> 
             RGBColor[
              0.255450766680841, 0.38582533066860314`, 0.9378589153057062], 
             UndirectedEdge[110, 179] -> 
             RGBColor[
              0.9932962755631108, 0.991495851914556, 0.7607615928093651], 
             UndirectedEdge[61, 177] -> 
             RGBColor[
              0.49302351294995017`, 0.5983715477396933, 0.9534876687205165], 
             UndirectedEdge[21, 264] -> 
             RGBColor[
              0.339057995027486, 0.46679450013267343`, 0.9428731344082046], 
             UndirectedEdge[200, 225] -> 
             RGBColor[
              0.9234794071043728, 0.7275983937614409, 0.2647165314935854], 
             UndirectedEdge[83, 197] -> 
             RGBColor[
              0.21339436331142053`, 0.34162138419735716`, 0.9354638653506908],
              UndirectedEdge[220, 226] -> 
             RGBColor[
              0.21805937466237113`, 0.3465246069060093, 0.9357295308458616], 
             UndirectedEdge[13, 140] -> 
             RGBColor[
              0.3171012005840623, 0.44883683866464263`, 0.941435247389312], 
             UndirectedEdge[144, 158] -> 
             RGBColor[
              0.35967077338482056`, 0.4859504791523989, 0.9441388815290719], 
             UndirectedEdge[62, 225] -> 
             RGBColor[
              0.9779057939111673, 0.9356854846768198, 0.49177155529990685`], 
             UndirectedEdge[65, 277] -> 
             RGBColor[
              0.318505826054183, 0.44836965030434695`, 0.9415864012075592], 
             UndirectedEdge[99, 261] -> 
             RGBColor[
              0.38406488890105717`, 0.5070794359286672, 0.9456932529988971], 
             UndirectedEdge[260, 290] -> 
             RGBColor[
              0.7310412488235707, 0.7895991808750945, 0.9740726900092733], 
             UndirectedEdge[72, 267] -> 
             RGBColor[
              0.5598273932891142, 0.6533873840765647, 0.9585897688439947], 
             UndirectedEdge[39, 170] -> 
             RGBColor[
              0.8523196210649958, 0.3840152543205831, 0.1969850871622311], 
             UndirectedEdge[92, 163] -> 
             RGBColor[
              0.25122830224652154`, 0.3813872528284255, 0.937618452202748], 
             UndirectedEdge[102, 133] -> 
             RGBColor[
              0.36773492193593726`, 0.4929352393114849, 0.9446527219439024], 
             UndirectedEdge[184, 197] -> 
             RGBColor[
              0.22396867403815082`, 0.3527356552211741, 0.9360660567032872], 
             UndirectedEdge[44, 200] -> 
             RGBColor[
              0.9255256121005535, 0.7345007236853389, 0.2726656515103572], 
             UndirectedEdge[115, 132] -> 
             RGBColor[
              0.21415169536183348`, 0.34241738819996653`, 0.9355069942905895],
              UndirectedEdge[9, 283] -> 
             RGBColor[
              0.5677763920680372, 0.6599854789726345, 0.959116583898501], 
             UndirectedEdge[52, 165] -> 
             RGBColor[
              0.8718921341800324, 0.4064366847474367, 0.2356655749773864], 
             UndirectedEdge[160, 256] -> 
             RGBColor[
              0.7927339846129686, 0.8352252152179895, 0.8425165155244698], 
             UndirectedEdge[45, 215] -> 
             RGBColor[
              0.9035836038900057, 0.6277240751762379, 0.3789421893819883], 
             UndirectedEdge[16, 124] -> 
             RGBColor[
              0.9705820834138202, 0.9744763977304486, 0.7520461602492186], 
             UndirectedEdge[160, 246] -> 
             RGBColor[
              0.5945439555585024, 0.6817165928791875, 0.9612238245492863], 
             UndirectedEdge[57, 204] -> 
             RGBColor[
              0.23896784394150833`, 0.36850073379190207`, 0.9369202372400001],
              UndirectedEdge[112, 252] -> 
             RGBColor[
              0.27637236437381507`, 0.40781525634982796`, 0.9390503693435908],
              UndirectedEdge[5, 248] -> 
             RGBColor[
              0.21465495916745328`, 0.3429463503684412, 0.9355356544198075], 
             UndirectedEdge[186, 276] -> 
             RGBColor[
              0.2308753294209801, 0.3599949879357713, 0.9364593805098584], 
             UndirectedEdge[95, 154] -> 
             RGBColor[
              0.6149232954890904, 0.696747339779964, 0.9638633724984019], 
             UndirectedEdge[198, 290] -> 
             RGBColor[
              0.5385920372825843, 0.6362923050176035, 0.9568190845839761], 
             UndirectedEdge[77, 191] -> 
             RGBColor[
              0.24496070190330402`, 0.37479960747889, 0.9372615216352855], 
             UndirectedEdge[36, 224] -> 
             RGBColor[
              0.8645479914252601, 0.8604819797945611, 0.6563901597051076], 
             UndirectedEdge[29, 203] -> 
             RGBColor[
              0.25120844967144335`, 0.38136638651329235`, 0.9376173216279664],
              UndirectedEdge[25, 172] -> 
             RGBColor[
              0.2606528759791422, 0.3912930773738975, 0.9381551677344133], 
             UndirectedEdge[224, 260] -> 
             RGBColor[
              0.9093392465848947, 0.8957090172216551, 0.6607919677185569], 
             UndirectedEdge[45, 255] -> 
             RGBColor[
              0.8915339731689755, 0.5880448777045486, 0.23368554874431965`], 
             UndirectedEdge[102, 239] -> 
             RGBColor[
              0.398228532934502, 0.519347272504989, 0.9465957478722895], 
             UndirectedEdge[33, 239] -> 
             RGBColor[
              0.6628984653958889, 0.7326583838158534, 0.9695703125580974], 
             UndirectedEdge[64, 92] -> 
             RGBColor[
              0.24737632360791623`, 0.3773385790496996, 0.9373990877177711], 
             UndirectedEdge[32, 268] -> 
             RGBColor[
              0.2593869141835333, 0.38996247126009875`, 0.938083073082976], 
             UndirectedEdge[85, 240] -> 
             RGBColor[
              0.9572796113633043, 0.9651601387742601, 0.8410616153789832], 
             UndirectedEdge[1, 174] -> 
             RGBColor[
              0.4054230753198295, 0.5255788235109453, 0.9470541777511985], 
             UndirectedEdge[2, 184] -> 
             RGBColor[
              0.23409720380212556`, 0.3633813821889895, 0.9366428614895286], 
             UndirectedEdge[60, 85] -> 
             RGBColor[
              0.9228540566499766, 0.8416985659067688, 0.6257891591988634], 
             UndirectedEdge[121, 127] -> 
             RGBColor[
              0.8867181042579634, 0.498897479652069, 0.3375850577582036], 
             UndirectedEdge[132, 212] -> 
             RGBColor[
              0.20921642322248857`, 0.3372301042671883, 0.9352259378433346], 
             UndirectedEdge[172, 206] -> 
             RGBColor[
              0.2530845856194636, 0.3833383243485512, 0.9377241647947119], 
             UndirectedEdge[147, 148] -> 
             RGBColor[
              0.2325030525609364, 0.36170582815947316`, 0.9365520769346783], 
             UndirectedEdge[118, 226] -> 
             RGBColor[
              0.17892828959271728`, 0.30539535544371077`, 0.9335010734403975],
              UndirectedEdge[75, 283] -> 
             RGBColor[
              0.6746177643537297, 0.7453737204958732, 0.9684508023443001], 
             UndirectedEdge[188, 243] -> 
             RGBColor[
              0.21194079974675017`, 0.3400935967296356, 0.9353810870560375], 
             UndirectedEdge[88, 258] -> 
             RGBColor[
              0.7329940972360016, 0.7896974879262988, 0.9518579499321382], 
             UndirectedEdge[197, 293] -> 
             RGBColor[
              0.20988077542261582`, 0.33792838055188446`, 0.9352637717183109],
              UndirectedEdge[86, 179] -> 
             RGBColor[
              0.9842570845883489, 0.9592626733262417, 0.5559110076191691], 
             UndirectedEdge[41, 76] -> 
             RGBColor[
              0.32564319585170254`, 0.45514146543527656`, 0.9420195932129798],
              UndirectedEdge[175, 242] -> 
             RGBColor[
              0.2674717938620085, 0.3984601924131547, 0.9385434950201575], 
             UndirectedEdge[89, 285] -> 
             RGBColor[
              0.3304519019187142, 0.457812130049975, 0.9423807168287202], 
             UndirectedEdge[138, 171] -> 
             RGBColor[
              0.5625186052786886, 0.6537822219340037, 0.9596386929535714], 
             UndirectedEdge[181, 207] -> 
             RGBColor[
              0.729702675862836, 0.7887685434205706, 0.9736936013369495], 
             UndirectedEdge[17, 55] -> 
             RGBColor[
              0.28645859801019335`, 0.41841652740581015`, 0.939624765427937], 
             UndirectedEdge[142, 295] -> 
             RGBColor[
              0.7481542644116976, 0.8033229003900898, 0.9754955751330152], 
             UndirectedEdge[53, 200] -> 
             RGBColor[
              0.849818066326612, 0.3549983638102894, 0.19420628891428304`], 
             UndirectedEdge[33, 237] -> 
             RGBColor[
              0.7767209844121652, 0.8262100194866766, 0.9782143643357628], 
             UndirectedEdge[51, 67] -> 
             RGBColor[
              0.9529402270197467, 0.9622638379796367, 0.8739273734917072], 
             UndirectedEdge[47, 48] -> 
             RGBColor[
              0.5288713488786927, 0.6272983725157164, 0.9563690029663805], 
             UndirectedEdge[102, 237] -> 
             RGBColor[
              0.5120510519507784, 0.6128989081758123, 0.9552397996499549], 
             UndirectedEdge[150, 282] -> 
             RGBColor[
              0.9628316709480902, 0.9718005015674145, 0.9478004654188247], 
             UndirectedEdge[214, 293] -> 
             RGBColor[
              0.21107172389025777`, 0.33918014290187026`, 0.9353315944716927],
              UndirectedEdge[73, 245] -> 
             RGBColor[
              0.37670637299800835`, 0.5007058593032094, 0.9452243748724349], 
             UndirectedEdge[82, 192] -> 
             RGBColor[
              0.90834965026943, 0.6505028830957647, 0.37453721305284604`], 
             UndirectedEdge[82, 266] -> 
             RGBColor[
              0.6213553148465931, 0.6847435984870042, 0.8214592367687926], 
             UndirectedEdge[30, 38] -> 
             RGBColor[
              0.4400713503236684, 0.5553482940395915, 0.949328558422408], 
             UndirectedEdge[146, 242] -> 
             RGBColor[
              0.23544148915831797`, 0.3647943113309621, 0.9367194165518717], 
             UndirectedEdge[25, 77] -> 
             RGBColor[
              0.24892138027318342`, 0.37896253156714604`, 0.9374870764091515],
              UndirectedEdge[68, 271] -> 
             RGBColor[
              0.9259155815977133, 0.7290271362933656, 0.2919182148886562], 
             UndirectedEdge[23, 267] -> 
             RGBColor[
              0.3821106817559689, 0.50384843174461, 0.9457196175325961], 
             UndirectedEdge[10, 161] -> 
             RGBColor[
              0.21385191803304957`, 0.3421023032204342, 0.935489922415196], 
             UndirectedEdge[223, 287] -> 
             RGBColor[
              0.9141648921008272, 0.6925393884549282, 0.24954185631357317`], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.43016772773719436`, 0.545286907400802, 0.949107366939159], 
             UndirectedEdge[218, 229] -> 
             RGBColor[
              0.3012157370951104, 0.430446886752895, 0.9405925945789568], 
             UndirectedEdge[62, 170] -> 
             RGBColor[
              0.8795452044161765, 0.44332219509737536`, 0.3392971994770656], 
             UndirectedEdge[188, 294] -> 
             RGBColor[
              0.20780626806211017`, 0.3357479417846294, 0.9351456315930887], 
             UndirectedEdge[181, 299] -> 
             RGBColor[
              0.8541508128707371, 0.884172913273241, 0.8565895585797871], 
             UndirectedEdge[69, 109] -> 
             RGBColor[
              0.957103333757725, 0.9637481152069529, 0.737975761375697], 
             UndirectedEdge[48, 175] -> 
             RGBColor[
              0.3540970438547585, 0.4798066886867111, 0.9438319175031515], 
             UndirectedEdge[248, 270] -> 
             RGBColor[
              0.21830317142063266`, 0.3467808527565494, 0.9357434147105796], 
             UndirectedEdge[85, 232] -> 
             RGBColor[
              0.9568611020652522, 0.9642649897035074, 0.7955094610260169], 
             UndirectedEdge[65, 152] -> 
             RGBColor[
              0.270606352963235, 0.4017548127710696, 0.9387220035238077], 
             UndirectedEdge[43, 63] -> 
             RGBColor[
              0.3233435154432426, 0.45448563418447746`, 0.9418241407759673], 
             UndirectedEdge[184, 293] -> 
             RGBColor[
              0.22334920945949943`, 0.35208455867268873`, 0.9360307791119489],
              UndirectedEdge[24, 260] -> 
             RGBColor[
              0.9023952825645615, 0.924495379134781, 0.9727268847769307], 
             UndirectedEdge[201, 229] -> 
             RGBColor[
              0.3337508945428317, 0.46349998287045846`, 0.9424872897693092], 
             UndirectedEdge[17, 48] -> 
             RGBColor[
              0.35495264897954515`, 0.4807059839213601, 0.9438806429492537], 
             UndirectedEdge[153, 163] -> 
             RGBColor[
              0.2574205034515923, 0.3878956489031873, 0.9379710889008359], 
             UndirectedEdge[33, 200] -> 
             RGBColor[
              0.9003293088366926, 0.7550036483702731, 0.6091535540920102], 
             UndirectedEdge[33, 282] -> 
             RGBColor[
              0.9391598487497231, 0.9536036259867218, 0.9690629330997416], 
             UndirectedEdge[150, 237] -> 
             RGBColor[
              0.8003928066105324, 0.8444068950673695, 0.956951896654846], 
             UndirectedEdge[172, 203] -> 
             RGBColor[
              0.26454467239722235`, 0.39538360216344437`, 0.9383767997830261],
              UndirectedEdge[56, 93] -> 
             RGBColor[
              0.5394509250519448, 0.6369895888012234, 0.9568866993753897], 
             UndirectedEdge[122, 299] -> 
             RGBColor[
              0.8093386473760087, 0.8488870251734923, 0.8523133648913199], 
             UndirectedEdge[44, 100] -> 
             RGBColor[
              0.8884719755057815, 0.5557375080883161, 0.23670627510997347`], 
             UndirectedEdge[31, 171] -> 
             RGBColor[
              0.5185950159671473, 0.6191084488745244, 0.955507160509088], 
             UndirectedEdge[136, 256] -> 
             RGBColor[
              0.9940778224627702, 0.9897413860088904, 0.596785706394875], 
             UndirectedEdge[146, 159] -> 
             RGBColor[
              0.2389221548438223, 0.3684527116533779, 0.9369176353134778], 
             UndirectedEdge[65, 133] -> 
             RGBColor[
              0.3190318248130566, 0.44882524399181684`, 0.9416199173833522], 
             UndirectedEdge[58, 245] -> 
             RGBColor[
              0.48666290222101594`, 0.5933487734884098, 0.952947963928872], 
             UndirectedEdge[172, 272] -> 
             RGBColor[
              0.2463878565667746, 0.37629963751702955`, 0.937342795982084], 
             UndirectedEdge[99, 218] -> 
             RGBColor[
              0.3117655585077827, 0.43958461181110975`, 0.9412648198705315], 
             UndirectedEdge[18, 113] -> 
             RGBColor[
              0.9529050044310041, 0.9643972099323963, 0.9646037225429771], 
             UndirectedEdge[43, 131] -> 
             RGBColor[
              0.3235024771639835, 0.45462331883733487`, 0.9418342696762487], 
             UndirectedEdge[2, 156] -> 
             RGBColor[
              0.2292281520802934, 0.3582637001136342, 0.9363655761970868], 
             UndirectedEdge[165, 232] -> 
             RGBColor[
              0.9871784526525289, 0.9674285696046385, 0.48831934332178484`], 
             UndirectedEdge[173, 186] -> 
             RGBColor[
              0.24357136840210497`, 0.3733393298802981, 0.937182401147727], 
             UndirectedEdge[39, 281] -> 
             RGBColor[
              0.8570472727010972, 0.420354056465815, 0.2015122917080806], 
             UndirectedEdge[77, 91] -> 
             RGBColor[
              0.25932242623621204`, 0.38989469033869195`, 0.9380794005897775],
              UndirectedEdge[15, 19] -> 
             RGBColor[
              0.265094966907718, 0.3959619965846625, 0.938408138241311], 
             UndirectedEdge[119, 241] -> 
             RGBColor[
              0.2806500707405608, 0.4123113969635265, 0.9392939783928775], 
             UndirectedEdge[103, 116] -> 
             RGBColor[
              0.3006123597209014, 0.43202989779004775`, 0.9404770506166615], 
             UndirectedEdge[99, 257] -> 
             RGBColor[
              0.37939685727732686`, 0.5030362215582833, 0.9453958101516111], 
             UndirectedEdge[17, 253] -> 
             RGBColor[
              0.2964738820674033, 0.42894322595562323`, 0.9401951210387102], 
             UndirectedEdge[204, 292] -> 
             RGBColor[
              0.2369721103072519, 0.36640309120547765`, 0.9368065831619525], 
             UndirectedEdge[65, 241] -> 
             RGBColor[
              0.2834960053804121, 0.4153026547126882, 0.9394560501604341], 
             UndirectedEdge[71, 256] -> 
             RGBColor[
              0.8124222635893662, 0.8512090470378892, 0.8440664489660341], 
             UndirectedEdge[37, 102] -> 
             RGBColor[
              0.5330127818666326, 0.6293292071697167, 0.9572915771331396], 
             UndirectedEdge[61, 217] -> 
             RGBColor[
              0.686937545269946, 0.7542032342825437, 0.9702221270801157], 
             UndirectedEdge[35, 184] -> 
             RGBColor[
              0.23183414268000563`, 0.3610027614632789, 0.9365139835065228], 
             UndirectedEdge[164, 241] -> 
             RGBColor[
              0.33149984085228634`, 0.458806984736167, 0.9424442983869149], 
             UndirectedEdge[192, 255] -> 
             RGBColor[
              0.896308870615873, 0.6109454327971793, 0.23771756775713984`], 
             UndirectedEdge[112, 134] -> 
             RGBColor[
              0.2631071012640549, 0.3938726237552112, 0.9382949322336882], 
             UndirectedEdge[44, 195] -> 
             RGBColor[
              0.8677809264179449, 0.3966970379236798, 0.21689250313626357`], 
             UndirectedEdge[127, 281] -> 
             RGBColor[
              0.833873528065198, 0.26137235694956523`, 0.1800706347708988], 
             UndirectedEdge[59, 192] -> 
             RGBColor[
              0.8435354828696529, 0.32873767594338427`, 0.18905271951585984`],
              UndirectedEdge[108, 264] -> 
             RGBColor[
              0.3192908615453144, 0.4496732026354332, 0.9416135901421105], 
             UndirectedEdge[136, 296] -> 
             RGBColor[
              0.8445716246365338, 0.8749311705589841, 0.7198898610709794], 
             UndirectedEdge[118, 130] -> 
             RGBColor[
              0.17892828448197629`, 0.3053953500719979, 0.9335010731493483], 
             UndirectedEdge[85, 136] -> 
             RGBColor[
              0.9562666668799304, 0.9629935529487204, 0.7308088595324563], 
             UndirectedEdge[104, 157] -> 
             RGBColor[
              0.3155261405863954, 0.44552577951204275`, 0.9414061686253012], 
             UndirectedEdge[158, 217] -> 
             RGBColor[
              0.6053338779034495, 0.6866046110497097, 0.9641707450092601], 
             UndirectedEdge[11, 174] -> 
             RGBColor[
              0.36791464439567134`, 0.49309090587299315`, 0.9446641737001142],
              UndirectedEdge[39, 220] -> 
             RGBColor[
              0.6640857208165928, 0.4568042722742281, 0.4534382779437778], 
             UndirectedEdge[32, 208] -> 
             RGBColor[
              0.27110861374646283`, 0.402282720699415, 0.9387506065323843], 
             UndirectedEdge[27, 103] -> 
             RGBColor[
              0.2686276829189324, 0.3996751050995809, 0.9386093211919647], 
             UndirectedEdge[212, 250] -> 
             RGBColor[
              0.21715203202826977`, 0.34557093226872304`, 0.9356778590251427],
              UndirectedEdge[129, 298] -> 
             RGBColor[
              0.26058075662513375`, 0.3912172753602034, 0.9381510606438935], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.887313539208574, 0.5061966019430634, 0.37187376646363723`], 
             UndirectedEdge[261, 290] -> 
             RGBColor[
              0.5067850511563949, 0.6090396671765619, 0.9547103165107921], 
             UndirectedEdge[24, 113] -> 
             RGBColor[
              0.9575230369172714, 0.9678413309993203, 0.9567865981194988], 
             UndirectedEdge[15, 243] -> 
             RGBColor[
              0.2285446981366219, 0.35754534668535254`, 0.9363266545060742], 
             UndirectedEdge[246, 296] -> 
             RGBColor[
              0.6475517482649964, 0.7239253864883827, 0.965961068287336], 
             UndirectedEdge[131, 174] -> 
             RGBColor[
              0.3585773503848271, 0.4850034111068425, 0.9440692095823882], 
             UndirectedEdge[44, 121] -> 
             RGBColor[
              0.9798326937990873, 0.9423326330377451, 0.48673505054828914`], 
             UndirectedEdge[155, 293] -> 
             RGBColor[
              0.21078204772465953`, 0.3388756748852968, 0.9353150978425994], 
             UndirectedEdge[105, 140] -> 
             RGBColor[
              0.3086221728107845, 0.4399248428735164, 0.9409523793012212], 
             UndirectedEdge[51, 138] -> 
             RGBColor[
              0.8501230130531416, 0.8811959449639274, 0.8638775606265587], 
             UndirectedEdge[133, 277] -> 
             RGBColor[
              0.3496210523003913, 0.4772459158627348, 0.9434985221881913], 
             UndirectedEdge[201, 261] -> 
             RGBColor[
              0.36087721144814144`, 0.48699543516550725`, 0.9442157546956553],
              UndirectedEdge[19, 57] -> 
             RGBColor[
              0.2691600647734066, 0.40023467218359243`, 0.9386396395509886], 
             UndirectedEdge[104, 261] -> 
             RGBColor[
              0.34285661416014696`, 0.46919806205208336`, 0.9431476422340319],
              UndirectedEdge[15, 111] -> 
             RGBColor[
              0.2409685800879815, 0.3706036343358437, 0.9370341762037178], 
             UndirectedEdge[71, 85] -> 
             RGBColor[
              0.7746111080065263, 0.8244612139777192, 0.9780896021036154], 
             UndirectedEdge[84, 158] -> 
             RGBColor[
              0.35212502014478775`, 0.47866323634096297`, 0.943685588557766], 
             UndirectedEdge[65, 162] -> 
             RGBColor[
              0.28622167127698683`, 0.41816750238718753`, 0.9396112728009827],
              UndirectedEdge[156, 268] -> 
             RGBColor[
              0.2451076812596908, 0.374954092101482, 0.9372698918921952], 
             UndirectedEdge[48, 252] -> 
             RGBColor[
              0.35710710220900627`, 0.48297045086574814`, 0.9440033358734436],
              UndirectedEdge[204, 235] -> 
             RGBColor[
              0.23646094075205434`, 0.36586581959294334`, 0.9367774728119916],
              UndirectedEdge[62, 130] -> 
             RGBColor[
              0.5868878667757954, 0.648392143438405, 0.8070978104506135], 
             UndirectedEdge[142, 283] -> 
             RGBColor[
              0.6388734394755219, 0.7174499822340865, 0.964888142090148], 
             UndirectedEdge[99, 259] -> 
             RGBColor[
              0.41587462147542475`, 0.5343343034600658, 0.9478022372825421], 
             UndirectedEdge[43, 244] -> 
             RGBColor[
              0.28234247424873604`, 0.412848733894419, 0.9394358151698824], 
             UndirectedEdge[36, 154] -> 
             RGBColor[
              0.750385676327774, 0.8049262605804057, 0.9757550895296658], 
             UndirectedEdge[11, 185] -> 
             RGBColor[
              0.4557880502577546, 0.5660866394053694, 0.9511242925783112], 
             UndirectedEdge[20, 150] -> 
             RGBColor[
              0.9139560790389594, 0.9335493921357441, 0.968134833574319], 
             UndirectedEdge[175, 252] -> 
             RGBColor[
              0.2975212413691305, 0.4300440669881537, 0.9402547666015143], 
             UndirectedEdge[97, 292] -> 
             RGBColor[
              0.25027096919944, 0.3803810350975218, 0.937563933501964], 
             UndirectedEdge[176, 226] -> 
             RGBColor[
              0.17893944427006758`, 0.3054070797168533, 0.9335017086827707], 
             UndirectedEdge[80, 103] -> 
             RGBColor[
              0.2733233300214085, 0.4046105279255051, 0.9388767313478634], 
             UndirectedEdge[137, 220] -> 
             RGBColor[
              0.6494413840373972, 0.36338333915495696`, 0.44016439160276355`],
              UndirectedEdge[20, 167] -> 
             RGBColor[
              0.8099161582263048, 0.8518030947538164, 0.981590034710579], 
             UndirectedEdge[240, 256] -> 
             RGBColor[
              0.9950907669461442, 0.9919079718344301, 0.7070384622414018], 
             UndirectedEdge[113, 278] -> 
             RGBColor[
              0.7811703997408805, 0.8288870412862575, 0.957738894978919], 
             UndirectedEdge[181, 240] -> 
             RGBColor[
              0.8543753182561593, 0.8839651564219314, 0.8310187966371865], 
             UndirectedEdge[7, 151] -> 
             RGBColor[
              0.4190101469832575, 0.5373472620797284, 0.9479199339430164], 
             UndirectedEdge[6, 101] -> 
             RGBColor[
              0.4261316567977976, 0.5406988809357904, 0.9490838670731377], 
             UndirectedEdge[65, 116] -> 
             RGBColor[
              0.3051622199360282, 0.4368120893539453, 0.940736158424998], 
             UndirectedEdge[50, 264] -> 
             RGBColor[
              0.32355517598609507`, 0.45336673747336176`, 0.9418853084874919],
              UndirectedEdge[55, 235] -> 
             RGBColor[
              0.25936698600148883`, 0.38994152547725025`, 0.9380819382024896],
              UndirectedEdge[100, 232] -> 
             RGBColor[
              0.8981524008015748, 0.5877362010635289, 0.330065035596082], 
             UndirectedEdge[28, 163] -> 
             RGBColor[
              0.23238600045450547`, 0.3615827989740821, 0.9365454109903801], 
             UndirectedEdge[11, 63] -> 
             RGBColor[
              0.3340095449749544, 0.46372401287461446`, 0.9425037707461285], 
             UndirectedEdge[234, 274] -> 
             RGBColor[
              0.8664044843984396, 0.3868069423093286, 0.21510625144616582`], 
             UndirectedEdge[148, 270] -> 
             RGBColor[
              0.23353444010566207`, 0.3627898818627272, 0.9366108129295494], 
             UndirectedEdge[96, 245] -> 
             RGBColor[
              0.41493426639987385`, 0.5338169391781161, 0.9476602224364029], 
             UndirectedEdge[159, 235] -> 
             RGBColor[
              0.24471645266359499`, 0.3745428860416596, 0.9372476120024185], 
             UndirectedEdge[53, 287] -> 
             RGBColor[
              0.8681444166075922, 0.43115720119419465`, 0.20913320183842923`],
              UndirectedEdge[105, 289] -> 
             RGBColor[
              0.2900768000973668, 0.42221948720669167`, 0.9398308166841512], 
             UndirectedEdge[56, 164] -> 
             RGBColor[
              0.46580833431938506`, 0.5753190136054342, 0.9516098956299331], 
             UndirectedEdge[112, 235] -> 
             RGBColor[
              0.24712629913564943`, 0.3770757874768801, 0.9373848491939536], 
             UndirectedEdge[7, 43] -> 
             RGBColor[
              0.3584602463932565, 0.4849019815151618, 0.9440617478195963], 
             UndirectedEdge[242, 243] -> 
             RGBColor[
              0.22929951054390013`, 0.35833870238327276`, 0.9363696399560237],
              UndirectedEdge[151, 286] -> 
             RGBColor[
              0.5011547059099458, 0.6056262623148936, 0.953947236987697], 
             UndirectedEdge[126, 163] -> 
             RGBColor[
              0.23364896427549098`, 0.3629102540264691, 0.9366173349115978], 
             UndirectedEdge[31, 138] -> 
             RGBColor[
              0.662760313991049, 0.7361123302878763, 0.9672677727663206], 
             UndirectedEdge[95, 138] -> 
             RGBColor[
              0.5976652055170001, 0.6832651887274253, 0.9621432473760043], 
             UndirectedEdge[197, 275] -> 
             RGBColor[
              0.21163940728530467`, 0.33977681414327066`, 0.9353639232012283],
              UndirectedEdge[198, 245] -> 
             RGBColor[
              0.4443289893270455, 0.5589801958800422, 0.949615283231626], 
             UndirectedEdge[187, 264] -> 
             RGBColor[
              0.3292953995025846, 0.4583386305713222, 0.9422510704540822], 
             UndirectedEdge[62, 195] -> 
             RGBColor[
              0.8777120828474402, 0.4292320194410746, 0.3375418001926291], 
             UndirectedEdge[169, 187] -> 
             RGBColor[
              0.3284772756829356, 0.4574787305648249, 0.9422044795128589], 
             UndirectedEdge[82, 199] -> 
             RGBColor[
              0.587001837836629, 0.6486359160132862, 0.81950285707449], 
             UndirectedEdge[126, 155] -> 
             RGBColor[
              0.21912067898952223`, 0.3476401050444259, 0.9357899705572339], 
             UndirectedEdge[82, 220] -> 
             RGBColor[
              0.6261342073882591, 0.6897665175475827, 0.8217313876293025], 
             UndirectedEdge[32, 202] -> 
             RGBColor[
              0.24218926046257408`, 0.37188664680514644`, 0.937103692145216], 
             UndirectedEdge[113, 260] -> 
             RGBColor[
              0.9042815340807562, 0.9259021424271057, 0.969533952973199], 
             UndirectedEdge[105, 230] -> 
             RGBColor[
              0.2692612582166467, 0.40034103290847267`, 0.938645402367879], 
             UndirectedEdge[245, 289] -> 
             RGBColor[
              0.3576929449951681, 0.48259509766982983`, 0.944072988186208], 
             UndirectedEdge[108, 187] -> 
             RGBColor[
              0.35392495764506043`, 0.4809737423517148, 0.9437727632309596], 
             UndirectedEdge[137, 228] -> 
             RGBColor[
              0.8358252186425734, 0.5196492090978858, 0.45495474568587335`], 
             UndirectedEdge[88, 261] -> 
             RGBColor[
              0.4524312720200109, 0.5649128206637994, 0.9504313879127225], 
             UndirectedEdge[192, 228] -> 
             RGBColor[
              0.8487718393512739, 0.6053612100527003, 0.4668120161228374], 
             UndirectedEdge[42, 97] -> 
             RGBColor[
              0.25595913612423093`, 0.3863596591860904, 0.937887866193442], 
             UndirectedEdge[121, 240] -> 
             RGBColor[
              0.9947718410408293, 0.9912258215713169, 0.6723253456304181], 
             UndirectedEdge[25, 43] -> 
             RGBColor[
              0.2869920462831278, 0.4177357289024586, 0.9397006014188156], 
             UndirectedEdge[77, 270] -> 
             RGBColor[
              0.23714390206690406`, 0.36658365523709874`, 0.9368163664485216],
              UndirectedEdge[225, 255] -> 
             RGBColor[
              0.9599585954916654, 0.876593081803823, 0.2989471339802242], 
             UndirectedEdge[2, 275] -> 
             RGBColor[
              0.2217679370492794, 0.35042254111108606`, 0.9359407279874696], 
             UndirectedEdge[235, 253] -> 
             RGBColor[
              0.2693822700586988, 0.40046822402706334`, 0.9386522938132629], 
             UndirectedEdge[73, 95] -> 
             RGBColor[
              0.4088283158597046, 0.5275690199007069, 0.9475362008014293], 
             UndirectedEdge[49, 175] -> 
             RGBColor[
              0.26553285029495766`, 0.3964222397880617, 0.9384330750524239], 
             UndirectedEdge[153, 219] -> 
             RGBColor[
              0.2738583241419696, 0.40517284066680126`, 0.9389071984715764], 
             UndirectedEdge[54, 167] -> 
             RGBColor[
              0.585666437251012, 0.671825268631737, 0.9619628736506332], 
             UndirectedEdge[56, 246] -> 
             RGBColor[
              0.57328015808247, 0.6644536841649844, 0.9595498605201163], 
             UndirectedEdge[192, 225] -> 
             RGBColor[
              0.8969783764685921, 0.6132038332458503, 0.2403184715693816], 
             UndirectedEdge[84, 252] -> 
             RGBColor[
              0.30057464185555743`, 0.4332533844961608, 0.9404286532421151], 
             UndirectedEdge[119, 164] -> 
             RGBColor[
              0.33307449939887124`, 0.46046205070774604`, 0.9425339728616443],
              UndirectedEdge[93, 168] -> 
             RGBColor[
              0.4585412392278475, 0.5694721717790032, 0.9510231831684333], 
             UndirectedEdge[111, 250] -> 
             RGBColor[
              0.2327988220725642, 0.3620167006690641, 0.9365689205708136], 
             UndirectedEdge[54, 286] -> 
             RGBColor[
              0.4882211414959945, 0.5944238588793778, 0.953123121699942], 
             UndirectedEdge[74, 257] -> 
             RGBColor[
              0.5147596974188978, 0.6152603482603705, 0.9554081515783656], 
             UndirectedEdge[220, 236] -> 
             RGBColor[
              0.4402011946832155, 0.5463223550644548, 0.9507193164378127], 
             UndirectedEdge[130, 228] -> 
             RGBColor[
              0.49763512145939465`, 0.5809234064486897, 0.9579150616794772], 
             UndirectedEdge[1, 142] -> 
             RGBColor[
              0.5387732060688373, 0.6352393283002062, 0.9572689291818902], 
             UndirectedEdge[101, 114] -> 
             RGBColor[
              0.4255007228362041, 0.540035729338632, 0.9490479363174081], 
             UndirectedEdge[199, 266] -> 
             RGBColor[
              0.21328047700996416`, 0.3415016824737179, 0.9354573796943026], 
             UndirectedEdge[93, 277] -> 
             RGBColor[
              0.440152252258617, 0.5535445555236148, 0.9498514531794966], 
             UndirectedEdge[19, 112] -> 
             RGBColor[
              0.271740291472555, 0.402946654040219, 0.9387865796444018], 
             UndirectedEdge[77, 203] -> 
             RGBColor[
              0.25281317669126346`, 0.38305305635669296`, 0.9377087084577643],
              UndirectedEdge[26, 60] -> 
             RGBColor[
              0.9559587194852852, 0.8665294960501166, 0.5718984085520893], 
             UndirectedEdge[186, 263] -> 
             RGBColor[
              0.24547633917610456`, 0.3753415749458948, 0.9372908864151546], 
             UndirectedEdge[167, 283] -> 
             RGBColor[
              0.6863247949375169, 0.7545193417646557, 0.9696176497444712], 
             UndirectedEdge[170, 200] -> 
             RGBColor[
              0.8432609465449801, 0.30459746782045594`, 0.18792718360618468`],
              UndirectedEdge[17, 292] -> 
             RGBColor[
              0.26964195081094916`, 0.4007411649623891, 0.9386670822479402], 
             UndirectedEdge[106, 215] -> 
             RGBColor[
              0.8258859987463416, 0.8619784867738793, 0.84861498208911], 
             UndirectedEdge[123, 229] -> 
             RGBColor[
              0.3913046976868122, 0.5133501944155183, 0.9461545672128138], 
             UndirectedEdge[105, 149] -> 
             RGBColor[
              0.29155965067616113`, 0.4237780571831614, 0.9399152628309327], 
             UndirectedEdge[68, 274] -> 
             RGBColor[
              0.9194708353599413, 0.7072874939349834, 0.2668815927431183], 
             UndirectedEdge[149, 171] -> 
             RGBColor[
              0.3561511381973472, 0.48153386145037547`, 0.943964705839551], 
             UndirectedEdge[29, 172] -> 
             RGBColor[
              0.256159178309366, 0.3865699162060744, 0.9378992582999495], 
             UndirectedEdge[76, 209] -> 
             RGBColor[
              0.2797259704782522, 0.4113401089964994, 0.9392413522500229], 
             UndirectedEdge[247, 267] -> 
             RGBColor[
              0.5234677465828359, 0.6240137244860162, 0.9556284450179895], 
             UndirectedEdge[164, 210] -> 
             RGBColor[
              0.3812406788826516, 0.5046332471596473, 0.9455132968338751], 
             UndirectedEdge[258, 260] -> 
             RGBColor[
              0.9054604072768613, 0.9267813441265331, 0.9675384281515653], 
             UndirectedEdge[62, 137] -> 
             RGBColor[
              0.8953270488535073, 0.5646283670910295, 0.3544099115332976], 
             UndirectedEdge[175, 280] -> 
             RGBColor[
              0.2812847712693677, 0.4129785074616403, 0.9393301236490378], 
             UndirectedEdge[72, 194] -> 
             RGBColor[
              0.5838203648230471, 0.6728659592388615, 0.9604785834522965], 
             UndirectedEdge[3, 257] -> 
             RGBColor[
              0.38431511212659675`, 0.5072961667100446, 0.9457091970015647], 
             UndirectedEdge[154, 171] -> 
             RGBColor[
              0.5797766952507789, 0.6672643729865424, 0.9613588180759691], 
             UndirectedEdge[168, 277] -> 
             RGBColor[
              0.3674840405107483, 0.49271793843065337`, 0.944636736001335], 
             UndirectedEdge[146, 243] -> 
             RGBColor[
              0.22430859499308387`, 0.3530929336970421, 0.9360854146988027], 
             UndirectedEdge[98, 122] -> 
             RGBColor[
              0.5234999711581451, 0.6232114459734905, 0.9558598822602524], 
             UndirectedEdge[142, 210] -> 
             RGBColor[
              0.5187904189187625, 0.6179312424348968, 0.9559956436547723], 
             UndirectedEdge[3, 38] -> 
             RGBColor[
              0.3976345995492975, 0.5188328372586848, 0.9465579029621789], 
             UndirectedEdge[21, 205] -> 
             RGBColor[
              0.4564507498978377, 0.5677093547420913, 0.9508767552454336], 
             UndirectedEdge[153, 221] -> 
             RGBColor[
              0.2840475061144973, 0.4158823169513779, 0.939487457311368], 
             UndirectedEdge[55, 159] -> 
             RGBColor[
              0.26204426941803677`, 0.39275552009761494`, 0.9382344055323761],
              UndirectedEdge[149, 298] -> 
             RGBColor[
              0.28960052483186716`, 0.4217188917050555, 0.9398036935123671], 
             UndirectedEdge[22, 247] -> 
             RGBColor[
              0.6982336123573278, 0.7632154445962727, 0.9712197251392987], 
             UndirectedEdge[105, 298] -> 
             RGBColor[
              0.2872112063681208, 0.41920756650811786`, 0.9396676253605367], 
             UndirectedEdge[169, 219] -> 
             RGBColor[
              0.2836300261607937, 0.41544351905027754`, 0.9394636824456108], 
             UndirectedEdge[53, 225] -> 
             RGBColor[
              0.8748070311041928, 0.4565865562872151, 0.219627594384284], 
             UndirectedEdge[47, 90] -> 
             RGBColor[
              0.5238031310544717, 0.622908536972411, 0.9560460606082701], 
             UndirectedEdge[100, 137] -> 
             RGBColor[
              0.848642289586235, 0.3748915297128206, 0.1942132174823743], 
             UndirectedEdge[15, 175] -> 
             RGBColor[
              0.2667169814547302, 0.3976668367152345, 0.9385005095702079], 
             UndirectedEdge[49, 253] -> 
             RGBColor[
              0.2666399442226916, 0.39758586569991927`, 0.9384961224138098], 
             UndirectedEdge[166, 291] -> 
             RGBColor[
              0.8761797606414349, 0.42138431296305434`, 0.25963779623893113`],
              UndirectedEdge[161, 230] -> 
             RGBColor[
              0.2328116110999559, 0.36203014274772405`, 0.9365696488870041], 
             UndirectedEdge[263, 269] -> 
             RGBColor[
              0.24400443083652518`, 0.3737945059566179, 0.9372070634127088], 
             UndirectedEdge[122, 160] -> 
             RGBColor[
              0.6072063704282553, 0.6919965117057422, 0.9622206562317872], 
             UndirectedEdge[196, 289] -> 
             RGBColor[
              0.28595784411409636`, 0.4178902033113814, 0.9395962482343534], 
             UndirectedEdge[30, 158] -> 
             RGBColor[
              0.4329152304787701, 0.5491500227069821, 0.9488725767937995], 
             UndirectedEdge[114, 187] -> 
             RGBColor[
              0.33417034239985266`, 0.4634625046455827, 0.9425286912402498], 
             UndirectedEdge[49, 159] -> 
             RGBColor[
              0.24197412682758776`, 0.3716605277145155, 0.9370914406029653], 
             UndirectedEdge[33, 94] -> 
             RGBColor[
              0.8883058899064401, 0.9137750204630982, 0.9892086028509474], 
             UndirectedEdge[193, 220] -> 
             RGBColor[
              0.3283447463388828, 0.4540509053495343, 0.9423173412993839], 
             UndirectedEdge[60, 127] -> 
             RGBColor[
              0.8638755462529181, 0.416820362954043, 0.20580473648210393`], 
             UndirectedEdge[282, 297] -> 
             RGBColor[
              0.8620280342318183, 0.892582413918251, 0.9615782291090177], 
             UndirectedEdge[97, 235] -> 
             RGBColor[
              0.24975979964424241`, 0.3798437634849875, 0.9375348231520031], 
             UndirectedEdge[50, 187] -> 
             RGBColor[
              0.35818927208584117`, 0.4846672771896433, 0.9440444815763409], 
             UndirectedEdge[271, 274] -> 
             RGBColor[
              0.9710201994330907, 0.9139064692863681, 0.34191937648403536`], 
             UndirectedEdge[137, 170] -> 
             RGBColor[
              0.8376752842858002, 0.29059432120131196`, 0.18371120082121695`],
              UndirectedEdge[84, 253] -> 
             RGBColor[
              0.29867167742904355`, 0.43125324822898137`, 0.9403202822332086],
              UndirectedEdge[33, 185] -> 
             RGBColor[
              0.7413664787721765, 0.7975076391058051, 0.9754311281439616], 
             UndirectedEdge[3, 144] -> 
             RGBColor[
              0.34651719678738085`, 0.4745575122216793, 0.9433007472595341], 
             UndirectedEdge[11, 43] -> 
             RGBColor[
              0.3328397711748278, 0.46271081360348554`, 0.9424292337939748], 
             UndirectedEdge[29, 272] -> 
             RGBColor[
              0.23305163384099561`, 0.36228242186687754`, 0.9365833178270244],
              UndirectedEdge[70, 251] -> 
             RGBColor[
              0.27547374372817707`, 0.40687074907542276`, 0.9389991942272118],
              UndirectedEdge[99, 123] -> 
             RGBColor[
              0.40185451909948444`, 0.5224879194737331, 0.9468267925043885], 
             UndirectedEdge[133, 239] -> 
             RGBColor[
              0.38064066205782954`, 0.5041135427437089, 0.9454750642923715], 
             UndirectedEdge[259, 260] -> 
             RGBColor[
              0.656707314635238, 0.7292515443954324, 0.9682208504157948], 
             UndirectedEdge[125, 192] -> 
             RGBColor[
              0.907532480377328, 0.648755039325108, 0.28559331328553295`], 
             UndirectedEdge[213, 264] -> 
             RGBColor[
              0.36127001361165895`, 0.48603343422176903`, 0.9442884645910713],
              UndirectedEdge[134, 204] -> 
             RGBColor[
              0.25244174288045984`, 0.38266265587127446`, 0.9376875558517261],
              UndirectedEdge[94, 142] -> 
             RGBColor[
              0.7604864358301577, 0.8131562391312941, 0.9766718286519673], 
             UndirectedEdge[134, 175] -> 
             RGBColor[
              0.2842559782593704, 0.41610143439353686`, 0.9394993294916116], 
             UndirectedEdge[8, 267] -> 
             RGBColor[
              0.5598482664107077, 0.6534036903177951, 0.9585918492816847], 
             UndirectedEdge[195, 225] -> 
             RGBColor[
              0.8664167897538245, 0.3920954846410811, 0.21159308979174907`], 
             UndirectedEdge[51, 281] -> 
             RGBColor[
              0.88857163743908, 0.5160716326224021, 0.37357200694912684`], 
             UndirectedEdge[49, 243] -> 
             RGBColor[
              0.2273605669768493, 0.3563007497581797, 0.9362592199882902], 
             UndirectedEdge[212, 243] -> 
             RGBColor[
              0.2149437082857312, 0.34324984399950276`, 0.9355520982549272], 
             UndirectedEdge[22, 285] -> 
             RGBColor[
              0.6000751622710249, 0.6816104857973055, 0.9640215926822105], 
             UndirectedEdge[20, 33] -> 
             RGBColor[
              0.8902842568405922, 0.9153525165550513, 0.9893973012552358], 
             UndirectedEdge[9, 174] -> 
             RGBColor[
              0.4545765714263261, 0.5664286209801727, 0.9506626768751375], 
             UndirectedEdge[180, 250] -> 
             RGBColor[
              0.22830469938985565`, 0.3572930927857018, 0.9363129869324922], 
             UndirectedEdge[92, 221] -> 
             RGBColor[
              0.27785530490942656`, 0.40937392087661617`, 0.9391348206132799],
              UndirectedEdge[71, 232] -> 
             RGBColor[
              0.8118465460917592, 0.8499776455244756, 0.7814031522680547], 
             UndirectedEdge[25, 148] -> 
             RGBColor[
              0.24531191831194143`, 0.3751687581927745, 0.9372815228901793], 
             UndirectedEdge[76, 218] -> 
             RGBColor[
              0.2751691719679872, 0.4065506248444982, 0.9389818493160426], 
             UndirectedEdge[20, 200] -> 
             RGBColor[
              0.8759509079419014, 0.7355649732308305, 0.6068283204518097], 
             UndirectedEdge[68, 255] -> 
             RGBColor[
              0.9166602771185755, 0.6978068210363987, 0.2559631047048003], 
             UndirectedEdge[30, 123] -> 
             RGBColor[
              0.44920952472312525`, 0.5632633214064009, 0.9499108348145711], 
             UndirectedEdge[113, 290] -> 
             RGBColor[
              0.7861690031762806, 0.8329451327396338, 0.9581324033518415], 
             UndirectedEdge[230, 269] -> 
             RGBColor[
              0.23818874032876391`, 0.3676818464968855, 0.9368758684418348], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.40607658256930623`, 0.5261448586442126, 0.9470958186552614], 
             UndirectedEdge[71, 296] -> 
             RGBColor[
              0.6629160657631297, 0.7363988315879828, 0.9671706036421385], 
             UndirectedEdge[37, 237] -> 
             RGBColor[
              0.6597410410048012, 0.7340591462727639, 0.9667579712592742], 
             UndirectedEdge[8, 217] -> 
             RGBColor[
              0.7294424930983517, 0.7885652866674933, 0.9736676687505319], 
             UndirectedEdge[39, 100] -> 
             RGBColor[
              0.861748584824546, 0.4564904015747509, 0.20601427350686777`], 
             UndirectedEdge[35, 216] -> 
             RGBColor[
              0.24253456217849695`, 0.3722495808019747, 0.9371233565671098], 
             UndirectedEdge[48, 253] -> 
             RGBColor[
              0.3552041377824924, 0.4809703145985687, 0.9438949648645372], 
             UndirectedEdge[72, 247] -> 
             RGBColor[
              0.6154478937421781, 0.6985426120193529, 0.9629684183842664], 
             UndirectedEdge[24, 254] -> 
             RGBColor[
              0.9234793483730712, 0.7829172870924861, 0.5955041038084421], 
             UndirectedEdge[247, 273] -> 
             RGBColor[
              0.598461668080708, 0.6848971683956518, 0.9615322412300882], 
             UndirectedEdge[80, 152] -> 
             RGBColor[
              0.26056294463292196`, 0.39119855382704327`, 0.9381500462772876],
              UndirectedEdge[121, 125] -> 
             RGBColor[
              0.9936176446660105, 0.9887571122327337, 0.5466981931057444], 
             UndirectedEdge[8, 177] -> 
             RGBColor[
              0.5355284607783559, 0.6327336001246429, 0.9569332103909327], 
             UndirectedEdge[38, 253] -> 
             RGBColor[
              0.35733483343099304`, 0.48281581607742285`, 0.9440307309071595],
              UndirectedEdge[134, 292] -> 
             RGBColor[
              0.2585311409306501, 0.3890629993121603, 0.9380343380622274], 
             UndirectedEdge[19, 177] -> 
             RGBColor[
              0.3552373943929633, 0.4804944703524481, 0.9439155616348212], 
             UndirectedEdge[219, 221] -> 
             RGBColor[
              0.28442417853057445`, 0.4162782235430855, 0.9395089082482266], 
             UndirectedEdge[37, 185] -> 
             RGBColor[
              0.6243865353648125, 0.7053567658918924, 0.9639747350674728], 
             UndirectedEdge[15, 280] -> 
             RGBColor[
              0.2534905697092152, 0.38376503936775813`, 0.9377472849880235], 
             UndirectedEdge[140, 171] -> 
             RGBColor[
              0.37321366033197056`, 0.49768064714073046`, 0.9450018223098395],
              UndirectedEdge[211, 221] -> 
             RGBColor[
              0.26848631667000333`, 0.39952652020881857`, 0.9386012705932207],
              UndirectedEdge[47, 273] -> 
             RGBColor[
              0.6309474410941337, 0.7112445284148133, 0.9641074535297975], 
             UndirectedEdge[58, 171] -> 
             RGBColor[
              0.48363824484440066`, 0.5907289672924857, 0.9527552354354336], 
             UndirectedEdge[75, 150] -> 
             RGBColor[
              0.8462593507356758, 0.8802930242051693, 0.9614859532696918], 
             UndirectedEdge[9, 167] -> 
             RGBColor[
              0.6353780576373289, 0.7131584853000028, 0.9656069359601525], 
             UndirectedEdge[135, 260] -> 
             RGBColor[
              0.9196247583457642, 0.9363642687580429, 0.8996385198821143], 
             UndirectedEdge[184, 202] -> 
             RGBColor[
              0.23277907926056368`, 0.361995949721885, 0.9365677962468772], 
             UndirectedEdge[166, 262] -> 
             RGBColor[
              0.9933514957949947, 0.9881878467094093, 0.5177295309761065], 
             UndirectedEdge[173, 276] -> 
             RGBColor[
              0.24447758470727698`, 0.3742918206744662, 0.9372340088256796], 
             UndirectedEdge[67, 86] -> 
             RGBColor[
              0.9435929630020026, 0.929903263270933, 0.6741823558912051], 
             UndirectedEdge[25, 272] -> 
             RGBColor[
              0.23754533151077184`, 0.36700558303470066`, 0.9368392272614883],
              UndirectedEdge[7, 174] -> 
             RGBColor[
              0.39353511961410004`, 0.5152820737846694, 0.9462966877257359], 
             UndirectedEdge[88, 113] -> 
             RGBColor[
              0.7318152240398965, 0.7888182862268713, 0.9538534747537719], 
             UndirectedEdge[147, 206] -> 
             RGBColor[
              0.23143319481245586`, 0.360581339832921, 0.9364911501186151], 
             UndirectedEdge[189, 211] -> 
             RGBColor[
              0.23710386113640347`, 0.3665415696804011, 0.9368140861767649], 
             UndirectedEdge[104, 209] -> 
             RGBColor[
              0.2751140822771375, 0.4064927220865271, 0.9389787120396467], 
             UndirectedEdge[151, 167] -> 
             RGBColor[
              0.5986000016649633, 0.6830276720672528, 0.9627869889383882], 
             UndirectedEdge[215, 274] -> 
             RGBColor[
              0.979839341035498, 0.9422049502369351, 0.5238492272566825], 
             UndirectedEdge[41, 261] -> 
             RGBColor[
              0.3788160778841355, 0.5025331796387221, 0.9453588034022401], 
             UndirectedEdge[157, 218] -> 
             RGBColor[
              0.30101158042666865`, 0.4302700565079032, 0.9405795858965723], 
             UndirectedEdge[187, 205] -> 
             RGBColor[
              0.44668815437293624`, 0.55925348518074, 0.950254691291311], 
             UndirectedEdge[62, 82] -> 
             RGBColor[
              0.9949627046124243, 0.9916340594516913, 0.6930996675251034], 
             UndirectedEdge[42, 144] -> 
             RGBColor[
              0.28507366633741316`, 0.4163170541357517, 0.9395694691052225], 
             UndirectedEdge[33, 150] -> 
             RGBColor[
              0.9383344799337505, 0.9529880672751867, 0.9704600672145196], 
             UndirectedEdge[34, 46] -> 
             RGBColor[
              0.30981865996121394`, 0.44123557275110054`, 0.9410185715382298],
              UndirectedEdge[220, 266] -> 
             RGBColor[
              0.2524128465615943, 0.3826322840080144, 0.9376859102491151], 
             UndirectedEdge[128, 279] -> 
             RGBColor[
              0.24902661375038676`, 0.3790731386238746, 0.9374930692999993], 
             UndirectedEdge[147, 270] -> 
             RGBColor[
              0.2272240069658551, 0.35615721652822, 0.9362514430976865], 
             UndirectedEdge[30, 90] -> 
             RGBColor[
              0.4328724368509469, 0.5491129570174318, 0.9488698500216755], 
             UndirectedEdge[36, 222] -> 
             RGBColor[
              0.5978519743815511, 0.6821400273622127, 0.9628407950842862], 
             UndirectedEdge[127, 170] -> 
             RGBColor[
              0.8291458764290967, 0.22503355480433335`, 0.17554343022504929`],
              UndirectedEdge[1, 295] -> 
             RGBColor[
              0.6279037208977163, 0.7050085996594103, 0.9661155178174292], 
             UndirectedEdge[96, 140] -> 
             RGBColor[
              0.36676996210044227`, 0.49209943960227065`, 0.9445912355564652],
              UndirectedEdge[206, 272] -> 
             RGBColor[
              0.22997704115109324`, 0.35905083000935434`, 0.9364082243217868],
              UndirectedEdge[129, 265] -> 
             RGBColor[
              0.22918762870603976`, 0.3582211074779632, 0.936363268450872], 
             UndirectedEdge[39, 60] -> 
             RGBColor[
              0.8870492908888172, 0.5758020624702928, 0.22724639341928574`], 
             UndirectedEdge[71, 240] -> 
             RGBColor[
              0.8122650553898112, 0.8508727945952284, 0.8269553066210207], 
             UndirectedEdge[30, 144] -> 
             RGBColor[
              0.3889539475617518, 0.5110729690025859, 0.9460714027197632], 
             UndirectedEdge[26, 59] -> 
             RGBColor[
              0.8838184335640263, 0.4982693458810795, 0.4141730352036101], 
             UndirectedEdge[133, 241] -> 
             RGBColor[
              0.3146112316266204, 0.4441789202710761, 0.9413681711410662], 
             UndirectedEdge[236, 266] -> 
             RGBColor[
              0.43542230214154953`, 0.5412994360038763, 0.9504471655773028], 
             UndirectedEdge[28, 216] -> 
             RGBColor[
              0.24112529640186797`, 0.3707683531181266, 0.9370431009659527], 
             UndirectedEdge[173, 230] -> 
             RGBColor[
              0.25326290395464024`, 0.3835257482248573, 0.9377343197601018], 
             UndirectedEdge[39, 266] -> 
             RGBColor[
              0.6608997924554822, 0.45345565956717576`, 0.45325684403677113`],
              UndirectedEdge[86, 141] -> 
             RGBColor[
              0.936935020626016, 0.7805800799358134, 0.2971516426609445], 
             UndirectedEdge[25, 206] -> 
             RGBColor[
              0.2442420605634609, 0.3740442698662223, 0.937220596074116], 
             UndirectedEdge[141, 165] -> 
             RGBColor[0.9396314058192, 0.789675620333774, 0.3076265899668467],
              UndirectedEdge[152, 241] -> 
             RGBColor[
              0.2661857597767988, 0.3971084890503288, 0.9384702572815218], 
             UndirectedEdge[110, 141] -> 
             RGBColor[
              0.9459742116007779, 0.8128132585241278, 0.5020022278511405], 
             UndirectedEdge[97, 134] -> 
             RGBColor[
              0.2657406017726479, 0.3966405997633186, 0.9384449061917377], 
             UndirectedEdge[103, 119] -> 
             RGBColor[
              0.28052080371187027`, 0.4121755291203697, 0.939286616826827], 
             UndirectedEdge[3, 17] -> 
             RGBColor[
              0.3367736481857078, 0.4649602471368852, 0.9427222930937296], 
             UndirectedEdge[203, 270] -> 
             RGBColor[
              0.2439246691349402, 0.37371067135106817`, 0.9372025211018002], 
             UndirectedEdge[51, 141] -> 
             RGBColor[
              0.9462822846437602, 0.812940654644517, 0.4968966602614467], 
             UndirectedEdge[184, 275] -> 
             RGBColor[
              0.22510784132218828`, 0.35393299226407493`, 0.9361309305948662],
              UndirectedEdge[58, 109] -> 
             RGBColor[
              0.7350459204207711, 0.7923292470470489, 0.9749877366110247], 
             UndirectedEdge[179, 281] -> 
             RGBColor[
              0.8885997879740133, 0.5160832735920328, 0.3731054797340321], 
             UndirectedEdge[31, 154] -> 
             RGBColor[
              0.6800184039631393, 0.7495944813404151, 0.9689878978887183], 
             UndirectedEdge[122, 296] -> 
             RGBColor[
              0.6602141631347492, 0.7342053053149373, 0.9669578999698369], 
             UndirectedEdge[96, 290] -> 
             RGBColor[
              0.5091973143554127, 0.6111290483156775, 0.9548640237887529], 
             UndirectedEdge[122, 240] -> 
             RGBColor[
              0.8095631527614308, 0.8486792683221828, 0.8267426029487193], 
             UndirectedEdge[97, 144] -> 
             RGBColor[
              0.28659496025462, 0.4179160304983415, 0.9396561045432549], 
             UndirectedEdge[61, 247] -> 
             RGBColor[
              0.5729638190353659, 0.6641968658756336, 0.9595249571515402], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.5867492116924276, 0.675169261254928, 0.9607600670587673], 
             UndirectedEdge[45, 287] -> 
             RGBColor[
              0.8855408645250941, 0.5648739230601991, 0.22579206001070665`], 
             UndirectedEdge[278, 290] -> 
             RGBColor[
              0.607930114483695, 0.6925840797342462, 0.9622776320149933], 
             UndirectedEdge[109, 110] -> 
             RGBColor[
              0.9570573175626281, 0.9656649471847494, 0.8794550171346109], 
             UndirectedEdge[56, 160] -> 
             RGBColor[
              0.5689561966042058, 0.6609432974446849, 0.9592094624333546], 
             UndirectedEdge[146, 292] -> 
             RGBColor[
              0.2367560409824719, 0.36617598864554746`, 0.9367942783335522], 
             UndirectedEdge[131, 139] -> 
             RGBColor[
              0.29015495986038786`, 0.4208144502573191, 0.9398897209981389], 
             UndirectedEdge[47, 74] -> 
             RGBColor[
              0.6411369333771564, 0.7195168172815674, 0.9649096076876572], 
             UndirectedEdge[46, 221] -> 
             RGBColor[
              0.2933757434234066, 0.4256868858074472, 0.9400186866262199], 
             UndirectedEdge[48, 74] -> 
             RGBColor[
              0.5259484891930979, 0.6249515173301565, 0.9561210914963576], 
             UndirectedEdge[90, 134] -> 
             RGBColor[
              0.3387736212750252, 0.46463798272782586`, 0.9429249564054306], 
             UndirectedEdge[1, 37] -> 
             RGBColor[
              0.5496127167377557, 0.6437072364180976, 0.9583493103043816], 
             UndirectedEdge[33, 295] -> 
             RGBColor[
              0.8759737184879801, 0.9039416817218939, 0.9880323493319954], 
             UndirectedEdge[28, 35] -> 
             RGBColor[
              0.2248219115083478, 0.35363246190073133`, 0.9361146473149633], 
             UndirectedEdge[21, 169] -> 
             RGBColor[
              0.33823987120783705`, 0.46593460012617627`, 0.9428265434669814],
              UndirectedEdge[100, 228] -> 
             RGBColor[
              0.8389013017243429, 0.5432933316125673, 0.4579004063189147], 
             UndirectedEdge[190, 250] -> 
             RGBColor[
              0.22535768471974588`, 0.35419559351589436`, 0.9361451588067469],
              UndirectedEdge[81, 180] -> 
             RGBColor[
              0.26493370488523493`, 0.3957924999744301, 0.9383989546076965], 
             UndirectedEdge[127, 141] -> 
             RGBColor[
              0.8548488786408825, 0.38002934597129234`, 0.19848976879691427`],
              UndirectedEdge[143, 185] -> 
             RGBColor[
              0.482410173529073, 0.5891453845161638, 0.9528206307321404], 
             UndirectedEdge[283, 295] -> 
             RGBColor[
              0.728003954304401, 0.7872192535932907, 0.973734730725687], 
             UndirectedEdge[26, 100] -> 
             RGBColor[
              0.8953985506349588, 0.587279200127923, 0.4252621683886066], 
             UndirectedEdge[242, 294] -> 
             RGBColor[
              0.22516497885926012`, 0.35399304743826654`, 0.9361341844930751],
              UndirectedEdge[39, 228] -> 
             RGBColor[
              0.8504695554217692, 0.6130701422171569, 0.46822863202688747`], 
             UndirectedEdge[39, 82] -> 
             RGBColor[
              0.9100473663399253, 0.6582118152602212, 0.3759538289568961], 
             UndirectedEdge[109, 258] -> 
             RGBColor[
              0.941467846616602, 0.9554926988601389, 0.9709728498600104], 
             UndirectedEdge[118, 199] -> 
             RGBColor[
              0.17892828448197629`, 0.3053953500719979, 0.9335010731493483], 
             UndirectedEdge[57, 115] -> 
             RGBColor[
              0.2343221600487206, 0.3636178254672108, 0.9366556724149793], 
             UndirectedEdge[96, 222] -> 
             RGBColor[
              0.4207992950730278, 0.5388969322298897, 0.948033936877215], 
             UndirectedEdge[6, 108] -> 
             RGBColor[
              0.32479673840417583`, 0.4554602283068521, 0.9419271416840078], 
             UndirectedEdge[1, 9] -> 
             RGBColor[
              0.46767615866135254`, 0.5777748250387542, 0.9514973709902432], 
             UndirectedEdge[180, 190] -> 
             RGBColor[
              0.23107912024585836`, 0.36020918501380295`, 0.9364709860958538],
              UndirectedEdge[144, 253] -> 
             RGBColor[
              0.30621743066907636`, 0.4385404910404173, 0.9407735752045145], 
             UndirectedEdge[53, 192] -> 
             RGBColor[
              0.8428147922031168, 0.3231981316717255, 0.18836258531968136`], 
             UndirectedEdge[85, 121] -> 
             RGBColor[
              0.9571178936575444, 0.9648142409538079, 0.8234596411130128], 
             UndirectedEdge[36, 278] -> 
             RGBColor[
              0.681251390228536, 0.7503140519946241, 0.9692773736229017], 
             UndirectedEdge[122, 207] -> 
             RGBColor[
              0.6848905103681076, 0.7534826553208219, 0.9694174076484823], 
             UndirectedEdge[226, 228] -> 
             RGBColor[
              0.4976351265701356, 0.5809234118204025, 0.9579150619705263], 
             UndirectedEdge[7, 143] -> 
             RGBColor[
              0.3957483991962868, 0.5171991053160931, 0.9464377159435866], 
             UndirectedEdge[133, 164] -> 
             RGBColor[
              0.36703566028493084`, 0.49232957401529565`, 0.9446081656098331],
              UndirectedEdge[7, 131] -> 
             RGBColor[
              0.359788981914124, 0.4860528654391481, 0.9441464136720313], 
             UndirectedEdge[111, 280] -> 
             RGBColor[
              0.2555363699026189, 0.38591530508224947`, 0.9378637902825477], 
             UndirectedEdge[135, 224] -> 
             RGBColor[
              0.9798102252026126, 0.9495170954171317, 0.5749562479700403], 
             UndirectedEdge[91, 102] -> 
             RGBColor[
              0.3289676178309032, 0.4560161547537128, 0.9423048264494448], 
             UndirectedEdge[200, 282] -> 
             RGBColor[
              0.9248264998510323, 0.7738160826625009, 0.5864939522963153], 
             UndirectedEdge[106, 194] -> 
             RGBColor[
              0.5862509789073218, 0.6747647734348481, 0.960720844348837], 
             UndirectedEdge[38, 259] -> 
             RGBColor[
              0.44110257276703263`, 0.5561854868751561, 0.949409740030642], 
             UndirectedEdge[36, 69] -> 
             RGBColor[
              0.8763046392583498, 0.8998097230462532, 0.7301395316538027], 
             UndirectedEdge[64, 153] -> 
             RGBColor[
              0.253568524812987, 0.38384697512446136`, 0.9377517244158591], 
             UndirectedEdge[159, 175] -> 
             RGBColor[
              0.2709524595475128, 0.4021185927355705, 0.9387417137817635], 
             UndirectedEdge[94, 200] -> 
             RGBColor[
              0.8739725410077492, 0.7339874771388775, 0.6066396220475212], 
             UndirectedEdge[88, 201] -> 
             RGBColor[
              0.41266709907445764`, 0.5304710926638055, 0.9478976499747094], 
             UndirectedEdge[121, 232] -> 
             RGBColor[
              0.9943533317427773, 0.9903306725005643, 0.626773191277452], 
             UndirectedEdge[140, 289] -> 
             RGBColor[
              0.3095286406957365, 0.4408775980939844, 0.9410040013062702], 
             UndirectedEdge[139, 244] -> 
             RGBColor[
              0.2489949569451404, 0.37903986531440326`, 0.9374912664917726], 
             UndirectedEdge[167, 174] -> 
             RGBColor[
              0.5731249742958058, 0.6609624837721939, 0.9611637427211077], 
             UndirectedEdge[185, 282] -> 
             RGBColor[
              0.7658636697865162, 0.8163200733980329, 0.9527715263482667], 
             UndirectedEdge[236, 249] -> 
             RGBColor[
              0.7534568620418187, 0.33087607040572803`, 0.43144386013194813`],
              UndirectedEdge[137, 299] -> 
             RGBColor[
              0.8952056536615587, 0.5648273491635555, 0.37453465249341855`], 
             UndirectedEdge[201, 218] -> 
             RGBColor[
              0.2885778810548669, 0.4195006110479498, 0.9397873215672898], 
             UndirectedEdge[36, 109] -> 
             RGBColor[
              0.8403699639081523, 0.8760405078690783, 0.9845068533256267], 
             UndirectedEdge[4, 52] -> 
             RGBColor[
              0.7250122591035142, 0.3037872628161848, 0.42869370576776544`], 
             UndirectedEdge[5, 191] -> 
             RGBColor[
              0.23242398209380136`, 0.36162272008515706`, 0.9365475739885493],
              UndirectedEdge[55, 134] -> 
             RGBColor[
              0.27534778812989436`, 0.40673836175558137`, 0.9389920212422243],
              UndirectedEdge[67, 69] -> 
             RGBColor[
              0.9526781701718614, 0.9602196098814508, 0.7375536853224871], 
             UndirectedEdge[232, 256] -> 
             RGBColor[
              0.9946722576480922, 0.9910128227636774, 0.6614863078884357], 
             UndirectedEdge[185, 237] -> 
             RGBColor[
              0.6034248054489583, 0.6889264668979879, 0.961922957584288], 
             UndirectedEdge[28, 211] -> 
             RGBColor[
              0.2328859592843117, 0.3621082874034291, 0.9365738829061148], 
             UndirectedEdge[85, 246] -> 
             RGBColor[
              0.759246790508393, 0.811987768878119, 0.9768800667488129], 
             UndirectedEdge[26, 127] -> 
             RGBColor[
              0.8837930596964858, 0.49807431121626294`, 0.4141487371593976], 
             UndirectedEdge[91, 162] -> 
             RGBColor[
              0.27856959341816107`, 0.4101246833878033, 0.9391754982871572], 
             UndirectedEdge[112, 242] -> 
             RGBColor[
              0.24632291686669305`, 0.37623138177482907`, 0.937339097762234], 
             UndirectedEdge[85, 122] -> 
             RGBColor[
              0.7719092053781459, 0.8222676877046737, 0.9778768984313139], 
             UndirectedEdge[63, 131] -> 
             RGBColor[
              0.32467225096411007`, 0.4556365181084638, 0.9419088066284024], 
             UndirectedEdge[140, 222] -> 
             RGBColor[
              0.3821033463817397, 0.505380446388428, 0.94556826524409], 
             UndirectedEdge[121, 256] -> 
             RGBColor[
              0.9949290492403844, 0.9915620740139779, 0.6894364879754314], 
             UndirectedEdge[171, 198] -> 
             RGBColor[
              0.4413043319504303, 0.556360389684118, 0.9494225547381876], 
             UndirectedEdge[10, 117] -> 
             RGBColor[
              0.20745354842489078`, 0.3353772110821952, 0.935125544731551], 
             UndirectedEdge[18, 290] -> 
             RGBColor[
              0.7796647191738186, 0.8280942483803853, 0.9691424595790514], 
             UndirectedEdge[207, 240] -> 
             RGBColor[
              0.870260916353266, 0.8963751063904083, 0.8326021245961515], 
             UndirectedEdge[219, 264] -> 
             RGBColor[
              0.28444814998044265`, 0.4163034190567747, 0.9395102733868341], 
             UndirectedEdge[78, 118] -> 
             RGBColor[
              0.17948494456776543`, 0.30598043511645023`, 0.9335327741177293],
              UndirectedEdge[2, 208] -> 
             RGBColor[
              0.2583585282715436, 0.3888815724631647, 0.9380245080266488], 
             UndirectedEdge[34, 169] -> 
             RGBColor[
              0.3102621246711287, 0.4417016822785076, 0.9410438261974121], 
             UndirectedEdge[35, 275] -> 
             RGBColor[
              0.21950487592715945`, 0.34804392038537546`, 0.9358118500044639],
              UndirectedEdge[157, 284] -> 
             RGBColor[
              0.3008123283039969, 0.4300606298936609, 0.9405682387829533], 
             UndirectedEdge[30, 259] -> 
             RGBColor[
              0.46322962709906557`, 0.5751097053927338, 0.9508862795927249], 
             UndirectedEdge[62, 192] -> 
             RGBColor[
              0.9082736695622077, 0.6503403680458439, 0.3662671819702616], 
             UndirectedEdge[95, 245] -> 
             RGBColor[
              0.4565245648697137, 0.5688811135099974, 0.9505753636122101], 
             UndirectedEdge[129, 230] -> 
             RGBColor[
              0.2426308084736596, 0.3723507417605582, 0.9371288376512357], 
             UndirectedEdge[35, 92] -> 
             RGBColor[
              0.24366421330036392`, 0.37343691575507476`, 0.9371876885273311],
              UndirectedEdge[186, 279] -> 
             RGBColor[
              0.24438086405288187`, 0.3741901611342533, 0.9372285007274972], 
             UndirectedEdge[217, 233] -> 
             RGBColor[
              0.9005620992858752, 0.9194729557138646, 0.7896746116293041], 
             UndirectedEdge[28, 293] -> 
             RGBColor[
              0.21633697828784162`, 0.3447142591101412, 0.9356314429203892], 
             UndirectedEdge[24, 233] -> 
             RGBColor[
              0.9748626422338834, 0.9780993949460502, 0.7789636593832132], 
             UndirectedEdge[41, 229] -> 
             RGBColor[
              0.35168976097882576`, 0.47903772734367334`, 0.943630338475894], 
             UndirectedEdge[197, 214] -> 
             RGBColor[
              0.21169118846890916`, 0.33983123945035565`, 0.9353668720630313],
              UndirectedEdge[84, 144] -> 
             RGBColor[
              0.30816373722776935`, 0.4405861826365669, 0.9408844144837296], 
             UndirectedEdge[101, 205] -> 
             RGBColor[
              0.5380185348092877, 0.6358267098737893, 0.9567739363684693], 
             UndirectedEdge[7, 297] -> 
             RGBColor[
              0.5775728899214854, 0.6645401478372637, 0.9615635093646839], 
             UndirectedEdge[30, 47] -> 
             RGBColor[
              0.5531290988592262, 0.6480680925121483, 0.9579813085710855], 
             UndirectedEdge[140, 298] -> 
             RGBColor[
              0.3066630469664905, 0.4378656773954105, 0.9408408099826556], 
             UndirectedEdge[159, 252] -> 
             RGBColor[
              0.2739625179017606, 0.4052823549146075, 0.9389131321520556], 
             UndirectedEdge[26, 195] -> 
             RGBColor[
              0.8747075015471222, 0.4282387299632868, 0.4054483964148967], 
             UndirectedEdge[43, 185] -> 
             RGBColor[
              0.4451220207260428, 0.5568482607152324, 0.9504446626081502], 
             UndirectedEdge[36, 95] -> 
             RGBColor[
              0.6241088885700935, 0.7039231949079366, 0.9647789065724686], 
             UndirectedEdge[6, 46] -> 
             RGBColor[
              0.29890559173213627`, 0.4314991069925552, 0.9403336033067247], 
             UndirectedEdge[148, 183] -> 
             RGBColor[
              0.2467014884994484, 0.37662928456368283`, 0.937360656856673], 
             UndirectedEdge[222, 261] -> 
             RGBColor[
              0.41838703187400994`, 0.5368075510907742, 0.9478802295992542], 
             UndirectedEdge[64, 145] -> 
             RGBColor[
              0.2514296244944172, 0.3815988552755316, 0.937629917206936], 
             UndirectedEdge[8, 247] -> 
             RGBColor[
              0.6154687668637716, 0.6985589182605833, 0.9629704988219563], 
             UndirectedEdge[122, 136] -> 
             RGBColor[
              0.8085502082780569, 0.8465126824966431, 0.7164898471021924], 
             UndirectedEdge[139, 206] -> 
             RGBColor[
              0.2460762386198535, 0.3759721072970965, 0.9373250498010044], 
             UndirectedEdge[65, 80] -> 
             RGBColor[
              0.27787319023653523`, 0.40939271948940265`, 0.9391358391561999],
              UndirectedEdge[171, 245] -> 
             RGBColor[
              0.4213779646314022, 0.5393981467165758, 0.9480708091897773], 
             UndirectedEdge[137, 232] -> 
             RGBColor[
              0.8950763177198054, 0.5640920785488474, 0.32711937496304067`], 
             UndirectedEdge[64, 221] -> 
             RGBColor[
              0.26413437920159183`, 0.3949523580007457, 0.9383534341925093], 
             UndirectedEdge[140, 263] -> 
             RGBColor[
              0.2945287893227776, 0.42511180325549774`, 0.9401497819608717], 
             UndirectedEdge[200, 295] -> 
             RGBColor[
              0.8616403695892892, 0.7241541383976731, 0.6054633685285691], 
             UndirectedEdge[136, 232] -> 
             RGBColor[
              0.9935021049651632, 0.9885099844954769, 0.5341224096968956], 
             UndirectedEdge[45, 68] -> 
             RGBColor[
              0.8633379334396346, 0.4711124376416033, 0.20763043303961218`], 
             UndirectedEdge[224, 254] -> 
             RGBColor[
              0.9304233123934045, 0.7541309251793602, 0.28356918675006826`], 
             UndirectedEdge[148, 272] -> 
             RGBColor[
              0.23104689889957378`, 0.3601753183359065, 0.93646915113785], 
             UndirectedEdge[167, 185] -> 
             RGBColor[
              0.660998380157889, 0.7339582173045702, 0.9676238615993047], 
             UndirectedEdge[59, 137] -> 
             RGBColor[
              0.8370621725153026, 0.28588167546597704`, 0.1831240842973778], 
             UndirectedEdge[55, 97] -> 
             RGBColor[
              0.26708761639868417`, 0.39805639754094285`, 0.9385216166819608],
              UndirectedEdge[156, 202] -> 
             RGBColor[
              0.22791002753873152`, 0.3568782676465297, 0.9362905109544353], 
             UndirectedEdge[78, 176] -> 
             RGBColor[
              0.17949609924511575`, 0.30599215938959284`, 0.9335334093601024],
              UndirectedEdge[131, 143] -> 
             RGBColor[
              0.3607906299670138, 0.4869204426382663, 0.9442102378002388], 
             UndirectedEdge[230, 289] -> 
             RGBColor[
              0.27016772610159867`, 0.4012937881289406, 0.9386970243729278], 
             UndirectedEdge[35, 126] -> 
             RGBColor[
              0.2260848753293333, 0.35495991695311835`, 0.9361865712361809], 
             UndirectedEdge[147, 183] -> 
             RGBColor[
              0.24039105535964145`, 0.36999661922917565`, 0.9370012870248101],
              UndirectedEdge[66, 258] -> 
             RGBColor[
              0.9541114545413159, 0.9652969784492861, 0.9625615171988029], 
             UndirectedEdge[60, 232] -> 
             RGBColor[
              0.9600894947352094, 0.8672149974535253, 0.4291027093633025], 
             UndirectedEdge[39, 127] -> 
             RGBColor[
              0.8559458393553094, 0.41188795711892084`, 0.20045755789226324`],
              UndirectedEdge[113, 258] -> 
             RGBColor[
              0.9605881616295711, 0.9701272959910724, 0.9515981414941335], 
             UndirectedEdge[45, 223] -> 
             RGBColor[
              0.8676674520716839, 0.4907717705649724, 0.21124308951240708`], 
             UndirectedEdge[40, 80] -> 
             RGBColor[
              0.25252112623098183`, 0.38274609280586824`, 0.9376920766161012],
              UndirectedEdge[18, 198] -> 
             RGBColor[
              0.7053280385373079, 0.7677443822103661, 0.9632904037751118], 
             UndirectedEdge[13, 58] -> 
             RGBColor[
              0.4275257850964924, 0.5418851588163979, 0.949188660514906], 
             UndirectedEdge[16, 195] -> 
             RGBColor[
              0.8772526257012466, 0.4282492870636099, 0.2875327252702875], 
             UndirectedEdge[17, 90] -> 
             RGBColor[
              0.3498844311553243, 0.4763161483780546, 0.9435577005911434], 
             UndirectedEdge[8, 273] -> 
             RGBColor[
              0.6348421879085798, 0.7142871342274307, 0.9644956454937833], 
             UndirectedEdge[85, 256] -> 
             RGBColor[
              0.9574368195628593, 0.965496391216921, 0.8581727577239964], 
             UndirectedEdge[149, 227] -> 
             RGBColor[
              0.27685707898321577`, 0.40832472213698934`, 0.9390779731235251],
              UndirectedEdge[182, 208] -> 
             RGBColor[
              0.2965714316502459, 0.42904575675219153`, 0.9402006763431414], 
             UndirectedEdge[82, 100] -> 
             RGBColor[
              0.898479112642499, 0.5884350046556317, 0.36562560324892335`], 
             UndirectedEdge[227, 264] -> 
             RGBColor[
              0.2772132461146813, 0.4086990763744601, 0.9390982563147601], 
             UndirectedEdge[74, 259] -> 
             RGBColor[
              0.5512374616169957, 0.646558430162153, 0.9578145787092965], 
             UndirectedEdge[96, 105] -> 
             RGBColor[
              0.3473181215020726, 0.473441328714978, 0.9434180509343462], 
             UndirectedEdge[60, 100] -> 
             RGBColor[
              0.875481037191391, 0.5060252518657031, 0.21691816771131295`], 
             UndirectedEdge[73, 87] -> 
             RGBColor[
              0.3025587103322468, 0.4334652095438001, 0.9406102430960075], 
             UndirectedEdge[68, 223] -> 
             RGBColor[
              0.880860495472638, 0.5518971603270344, 0.22229941585693147`], 
             UndirectedEdge[162, 191] -> 
             RGBColor[
              0.26420786908525307`, 0.39502960052800135`, 0.9383576193326653],
              UndirectedEdge[87, 149] -> 
             RGBColor[
              0.2850281329082009, 0.41691301788689017`, 0.939543302556562], 
             UndirectedEdge[60, 256] -> 
             RGBColor[
              0.9606652122328164, 0.8684463989669389, 0.49176600606128196`], 
             UndirectedEdge[145, 169] -> 
             RGBColor[
              0.28111445342614677`, 0.4127994926096401, 0.939320424299829], 
             UndirectedEdge[144, 235] -> 
             RGBColor[
              0.27887432985742466`, 0.4098011584346488, 0.9392164260637837], 
             UndirectedEdge[36, 88] -> 
             RGBColor[
              0.6318962145275521, 0.7102452969352381, 0.9653919533977545], 
             UndirectedEdge[38, 123] -> 
             RGBColor[
              0.4270824703910924, 0.5443391028888234, 0.9484342952524883], 
             UndirectedEdge[183, 244] -> 
             RGBColor[
              0.24855034907625476`, 0.37857255425443737`, 0.937465946731378], 
             UndirectedEdge[2, 32] -> 
             RGBColor[
              0.24350738500413596`, 0.3732720792722509, 0.9371787573878676], 
             UndirectedEdge[106, 151] -> 
             RGBColor[
              0.5499711557200619, 0.645038448022178, 0.9579401200370031], 
             UndirectedEdge[164, 277] -> 
             RGBColor[
              0.36650966152605724`, 0.4918739803278257, 0.94457464943404], 
             UndirectedEdge[296, 299] -> 
             RGBColor[
              0.8453600637344856, 0.8773055132358333, 0.8557133788601069], 
             UndirectedEdge[75, 174] -> 
             RGBColor[
              0.5614179437120186, 0.6518168625034114, 0.9599968953209368], 
             UndirectedEdge[31, 66] -> 
             RGBColor[
              0.7826462994682315, 0.8305130082182347, 0.9693283290234715], 
             UndirectedEdge[2, 268] -> 
             RGBColor[
              0.2466368287086141, 0.37656132302384837`, 0.9373569745772405], 
             UndirectedEdge[46, 264] -> 
             RGBColor[
              0.29339971487327476`, 0.42571208132113636`, 0.9400200517648274],
              UndirectedEdge[71, 160] -> 
             RGBColor[
              0.6099082730566356, 0.6941900379787878, 0.9624333599040888], 
             UndirectedEdge[50, 114] -> 
             RGBColor[
              0.32843011888336315`, 0.4584906115476223, 0.9421629292736595], 
             UndirectedEdge[126, 197] -> 
             RGBColor[
              0.21821940668747852`, 0.34669281071101354`, 0.9357386444329454],
              UndirectedEdge[265, 269] -> 
             RGBColor[
              0.2247455605611441, 0.35355221221429056`, 0.9361102992414712], 
             UndirectedEdge[144, 257] -> 
             RGBColor[
              0.3535074058070181, 0.4806120799363681, 0.9437461571970662], 
             UndirectedEdge[86, 107] -> 
             RGBColor[
              0.8810538793284779, 0.48461124450096366`, 0.2391769486117305], 
             UndirectedEdge[149, 245] -> 
             RGBColor[
              0.3591757955739624, 0.4841536676462995, 0.9441574343329895], 
             UndirectedEdge[143, 283] -> 
             RGBColor[
              0.5077365883087008, 0.6097065089762495, 0.9548144188773069], 
             UndirectedEdge[66, 154] -> 
             RGBColor[
              0.8438279787518632, 0.8786689323302527, 0.9751799865903525], 
             UndirectedEdge[57, 159] -> 
             RGBColor[
              0.24722335585304894`, 0.3771778002406183, 0.937390376430427], 
             UndirectedEdge[7, 167] -> 
             RGBColor[
              0.5743366058251028, 0.6620119381044995, 0.9612409468107508], 
             UndirectedEdge[57, 89] -> 
             RGBColor[
              0.26259271630004477`, 0.3933319725441461, 0.9382656387709521], 
             UndirectedEdge[122, 256] -> 
             RGBColor[
              0.8097203609609858, 0.8490155207648438, 0.8438537452937325], 
             UndirectedEdge[39, 232] -> 
             RGBColor[
              0.9097206544990011, 0.6575130116681185, 0.3403932613040548], 
             UndirectedEdge[72, 286] -> 
             RGBColor[
              0.6054217047226151, 0.6904029000986035, 0.9621791200575058], 
             UndirectedEdge[71, 299] -> 
             RGBColor[
              0.812040550004389, 0.8510805514465378, 0.8525260685636215], 
             UndirectedEdge[90, 158] -> 
             RGBColor[
              0.4035892626740157, 0.5239904671672448, 0.9469373288309841], 
             UndirectedEdge[52, 236] -> 
             RGBColor[
              0.752875562549565, 0.3264079477812045, 0.43088720708168204`], 
             UndirectedEdge[17, 134] -> 
             RGBColor[
              0.2851115833841571, 0.4170007296281859, 0.9395480549377139], 
             UndirectedEdge[54, 72] -> 
             RGBColor[
              0.534606977221836, 0.6319372303906756, 0.9568737438527076], 
             UndirectedEdge[170, 192] -> 
             RGBColor[
              0.836257672421485, 0.2727972356818921, 0.182083480011583], 
             UndirectedEdge[140, 198] -> 
             RGBColor[
              0.3961646850276139, 0.5172626963041967, 0.9465462963516883], 
             UndirectedEdge[19, 89] -> 
             RGBColor[
              0.28469980544749635`, 0.41656792490852634`, 0.9395246047933918],
              UndirectedEdge[239, 295] -> 
             RGBColor[
              0.6242095261484855, 0.7018088738432534, 0.9658801269946564], 
             UndirectedEdge[51, 69] -> 
             RGBColor[
              0.9933000659558078, 0.9895615584823135, 0.6199821278730931], 
             UndirectedEdge[186, 269] -> 
             RGBColor[
              0.2284972047762287, 0.3574954281523263, 0.93632394982946], 
             UndirectedEdge[37, 282] -> 
             RGBColor[
              0.8221799053423591, 0.8614527527728091, 0.9576065400232527], 
             UndirectedEdge[1, 239] -> 
             RGBColor[
              0.4148284678056251, 0.5337253017533699, 0.9476534810435313], 
             UndirectedEdge[59, 200] -> 
             RGBColor[
              0.850538756993148, 0.3605379080819481, 0.19489642311046151`], 
             UndirectedEdge[145, 221] -> 
             RGBColor[
              0.2819086057959276, 0.4136341971024482, 0.9393656501024449], 
             UndirectedEdge[75, 297] -> 
             RGBColor[
              0.7454557140194038, 0.8010749365560057, 0.9752637169598848], 
             UndirectedEdge[142, 185] -> 
             RGBColor[
              0.6135470246958941, 0.696888857774001, 0.9628943539449815], 
             UndirectedEdge[36, 258] -> 
             RGBColor[
              0.8606691521172266, 0.8915543066994391, 0.9631366201381162], 
             UndirectedEdge[13, 289] -> 
             RGBColor[
              0.2985558278706446, 0.4311314829978179, 0.940313684772242], 
             UndirectedEdge[53, 170] -> 
             RGBColor[
              0.8284505596301013, 0.21968904519749122`, 0.17487759407308337`],
              UndirectedEdge[130, 226] -> 
             RGBColor[
              0.178927005110741, 0.3053940053717128, 0.9335010002910491], 
             UndirectedEdge[224, 249] -> 
             RGBColor[
              0.8688948831013429, 0.39883351601253714`, 0.22232023481210886`],
              UndirectedEdge[234, 271] -> 
             RGBColor[
              0.8707009818902876, 0.40130003721491675`, 0.23179733287652443`],
              UndirectedEdge[78, 266] -> 
             RGBColor[
              0.21383713709575333`, 0.3420867675181703, 0.9354890806626834], 
             UndirectedEdge[127, 232] -> 
             RGBColor[
              0.8865469098631019, 0.4985313121518687, 0.318951604366873], 
             UndirectedEdge[57, 292] -> 
             RGBColor[
              0.2450572419916986, 0.37490107723278787`, 0.9372670194505013], 
             UndirectedEdge[52, 107] -> 
             RGBColor[
              0.8231876863313796, 0.17923629481773212`, 0.16983786065866233`],
              UndirectedEdge[26, 130] -> 
             RGBColor[
              0.5823809948253185, 0.6469022092217233, 0.9089577047840149], 
             UndirectedEdge[51, 58] -> 
             RGBColor[
              0.7712426526188537, 0.8181426903224094, 0.8569941031084208], 
             UndirectedEdge[192, 195] -> 
             RGBColor[
              0.8497053442101324, 0.36926123432797614`, 0.19469077161596268`],
              UndirectedEdge[118, 266] -> 
             RGBColor[
              0.21328176149194045`, 0.3415030325457159, 0.9354574528436509], 
             UndirectedEdge[171, 289] -> 
             RGBColor[
              0.35466828761855285`, 0.4799752914739057, 0.9438802596927696], 
             UndirectedEdge[1, 283] -> 
             RGBColor[
              0.5186228959615405, 0.619135681503407, 0.955508084774562], 
             UndirectedEdge[44, 59] -> 
             RGBColor[
              0.8768918584348492, 0.4667276538414726, 0.225617141924977], 
             UndirectedEdge[62, 127] -> 
             RGBColor[
              0.8867976409968038, 0.49906760069405076`, 0.3462421409371299], 
             UndirectedEdge[46, 219] -> 
             RGBColor[
              0.2831865614508789, 0.4149774095228705, 0.9394384277864284], 
             UndirectedEdge[55, 252] -> 
             RGBColor[
              0.2886130512396545, 0.4206809943501981, 0.9397474583521269], 
             UndirectedEdge[55, 144] -> 
             RGBColor[
              0.2962021466118664, 0.42801379249060423`, 0.9402032195937415], 
             UndirectedEdge[160, 296] -> 
             RGBColor[
              0.6432277867867322, 0.7204149997680831, 0.9656206702005743], 
             UndirectedEdge[154, 179] -> 
             RGBColor[
              0.8674233288276321, 0.8946955574709121, 0.8648978949263142], 
             UndirectedEdge[6, 145] -> 
             RGBColor[
              0.2874384541046572, 0.41944641828755624`, 0.9396805667829495], 
             UndirectedEdge[132, 243] -> 
             RGBColor[
              0.21243933131542342`, 0.34061758501703826`, 0.935409477691362], 
             UndirectedEdge[53, 59] -> 
             RGBColor[
              0.8320894648541852, 0.2476592653282373, 0.1783622138252218], 
             UndirectedEdge[4, 228] -> 
             RGBColor[
              0.6779819914219037, 0.7467901325313183, 0.9696145955916023], 
             UndirectedEdge[71, 98] -> 
             RGBColor[
              0.5262018737865255, 0.625404972246536, 0.9560725859325541], 
             UndirectedEdge[201, 259] -> 
             RGBColor[
              0.3926869440225089, 0.5142503026969059, 0.9463247389793005], 
             UndirectedEdge[34, 187] -> 
             RGBColor[
              0.34571434459052375`, 0.47386212200128636`, 0.9432495902274847],
              UndirectedEdge[18, 260] -> 
             RGBColor[
              0.8977772500782942, 0.9210512580678571, 0.980544009200409], 
             UndirectedEdge[263, 289] -> 
             RGBColor[
              0.27598341660935993`, 0.40740644758867306`, 0.9390282193438018],
              UndirectedEdge[173, 209] -> 
             RGBColor[
              0.2611649721580388, 0.3918313229266909, 0.938184330854223], 
             UndirectedEdge[4, 199] -> 
             RGBColor[
              0.3592738699625091, 0.4712607260826286, 0.9452005339121252], 
             UndirectedEdge[253, 292] -> 
             RGBColor[
              0.26989343961389634`, 0.40100549563959764`, 0.9386814041632237],
              UndirectedEdge[128, 209] -> 
             RGBColor[
              0.25220846656924684`, 0.38241746767761725`, 0.9376742711109041],
              UndirectedEdge[44, 137] -> 
             RGBColor[
              0.8853958924240121, 0.5320933855736346, 0.23376061447693208`], 
             UndirectedEdge[129, 263] -> 
             RGBColor[
              0.24844649898142085`, 0.37846340122029065`, 0.9374600326221096],
              UndirectedEdge[73, 289] -> 
             RGBColor[
              0.309996695985159, 0.44128300406053933`, 0.9410338253754271], 
             UndirectedEdge[128, 276] -> 
             RGBColor[
              0.235521079118485, 0.3648779654253926, 0.9367239490823606], 
             UndirectedEdge[96, 196] -> 
             RGBColor[
              0.34319916551880214`, 0.4691120448196677, 0.9431834824845483], 
             UndirectedEdge[24, 224] -> 
             RGBColor[
              0.9625807494214099, 0.9376482057938698, 0.6480446128648567], 
             UndirectedEdge[88, 278] -> 
             RGBColor[
              0.553576335347311, 0.6484572332214837, 0.9579987034169237], 
             UndirectedEdge[158, 253] -> 
             RGBColor[
              0.35017871358609476`, 0.47661754474481344`, 0.9435747492785509],
              UndirectedEdge[67, 110] -> 
             RGBColor[
              0.9526321539767644, 0.9621364418592473, 0.8790329410814011], 
             UndirectedEdge[155, 275] -> 
             RGBColor[
              0.21254067958734837`, 0.340724108476683, 0.9354152493255168], 
             UndirectedEdge[101, 108] -> 
             RGBColor[
              0.44525533808141193`, 0.5575469670447641, 0.9502920083081179], 
             UndirectedEdge[102, 210] -> 
             RGBColor[
              0.3819399405336581, 0.5052389124558365, 0.9455578531679444], 
             UndirectedEdge[176, 199] -> 
             RGBColor[
              0.17893943915932659`, 0.3054070743451405, 0.9335017083917216], 
             UndirectedEdge[62, 226] -> 
             RGBColor[
              0.5868878718865363, 0.6483921488101179, 0.8070978107416625], 
             UndirectedEdge[69, 113] -> 
             RGBColor[
              0.9762236487706943, 0.9783827123378863, 0.71860105300982], 
             UndirectedEdge[51, 258] -> 
             RGBColor[
              0.9776645788146846, 0.9813061421354996, 0.8529792163574066], 
             UndirectedEdge[30, 74] -> 
             RGBColor[
              0.5502062391736314, 0.6457212373265883, 0.9577333971010626], 
             UndirectedEdge[118, 228] -> 
             RGBColor[
              0.49763640594137093`, 0.5809247565206876, 0.9579151348288255], 
             UndirectedEdge[71, 121] -> 
             RGBColor[
              0.8121033376840514, 0.8505268967747761, 0.8093533323550504], 
             UndirectedEdge[1, 20] -> 
             RGBColor[
              0.6422142592503285, 0.7164194344925677, 0.9674804697406698], 
             UndirectedEdge[126, 293] -> 
             RGBColor[
              0.21759994210882713`, 0.34604171416252816`, 0.9357033668416068],
              UndirectedEdge[112, 159] -> 
             RGBColor[
              0.24980358255219737`, 0.3798897820972448, 0.9375373165238401], 
             UndirectedEdge[17, 159] -> 
             RGBColor[
              0.2718080646722995, 0.4030178879702195, 0.9387904392278659], 
             UndirectedEdge[139, 172] -> 
             RGBColor[
              0.26248705403553485`, 0.3932209148047717, 0.9382596214613016], 
             UndirectedEdge[47, 233] -> 
             RGBColor[
              0.8190741460647206, 0.8558139473261162, 0.781552654000438], 
             UndirectedEdge[98, 182] -> 
             RGBColor[
              0.3649951509133196, 0.4904176871542194, 0.9444834370172861], 
             UndirectedEdge[84, 159] -> 
             RGBColor[
              0.27400586003393973`, 0.4053279102435776, 0.9389156004223643], 
             UndirectedEdge[118, 176] -> 
             RGBColor[
              0.17894072364130287`, 0.30540842441713845`, 0.9335017815410699],
              UndirectedEdge[18, 278] -> 
             RGBColor[
              0.7746661157384185, 0.8240361569270088, 0.968748951206129], 
             UndirectedEdge[155, 197] -> 
             RGBColor[
              0.21140151230331092`, 0.3395267714337822, 0.9353503754339378], 
             UndirectedEdge[72, 215] -> 
             RGBColor[
              0.8234553846620669, 0.8600796725778928, 0.8483727211925696], 
             UndirectedEdge[162, 239] -> 
             RGBColor[
              0.34783050852175984`, 0.47345580113907954`, 0.9434664197100019],
              UndirectedEdge[139, 272] -> 
             RGBColor[
              0.23937950956716447`, 0.3689334204655748, 0.9369436809883765], 
             UndirectedEdge[9, 75] -> 
             RGBColor[
              0.6236710270535416, 0.7040128640312203, 0.9644400885599815], 
             UndirectedEdge[18, 254] -> 
             RGBColor[
              0.918861315886804, 0.779473166025562, 0.6033212282319205], 
             UndirectedEdge[25, 244] -> 
             RGBColor[
              0.2471607788887478, 0.37711202788352904`, 0.9373868127648843], 
             UndirectedEdge[30, 257] -> 
             RGBColor[
              0.42675186290096767`, 0.5438116234909512, 0.9484798524617939], 
             UndirectedEdge[29, 270] -> 
             RGBColor[
              0.2355391750470839, 0.3648969853936982, 0.9367249796187237], 
             UndirectedEdge[73, 298] -> 
             RGBColor[
              0.307131102255913, 0.43827108336196546`, 0.9408706340518126], 
             UndirectedEdge[73, 96] -> 
             RGBColor[
              0.3672380173898648, 0.4925048455688256, 0.9446210596256222], 
             UndirectedEdge[108, 205] -> 
             RGBColor[
              0.436683616415666, 0.5505880572448512, 0.9496172109793394], 
             UndirectedEdge[9, 43] -> 
             RGBColor[
              0.41950169820548255`, 0.5360485287106651, 0.948427736968998], 
             UndirectedEdge[151, 251] -> 
             RGBColor[
              0.36499365332834144`, 0.4885238594535514, 0.944552636407374], 
             UndirectedEdge[209, 279] -> 
             RGBColor[
              0.2619744678088157, 0.39268215418064606`, 0.9382304304339932], 
             UndirectedEdge[53, 68] -> 
             RGBColor[
              0.8459414855221328, 0.3373957157755989, 0.19097157486733474`], 
             UndirectedEdge[282, 295] -> 
             RGBColor[
              0.9004709095023198, 0.9227541160141217, 0.9653727475363004], 
             UndirectedEdge[35, 197] -> 
             RGBColor[
              0.218365708643122, 0.3468465833424746, 0.9357469761128849], 
             UndirectedEdge[116, 168] -> 
             RGBColor[
              0.35414043439259346`, 0.4811603774802517, 0.9437864932187738], 
             UndirectedEdge[27, 152] -> 
             RGBColor[
              0.2558672975304459, 0.3862631310011191, 0.9378826361213889], 
             UndirectedEdge[114, 231] -> 
             RGBColor[
              0.37476526938347776`, 0.4986237900384425, 0.945115364090962], 
             UndirectedEdge[83, 155] -> 
             RGBColor[
              0.21429563561346426`, 0.34256867853076955`, 0.9355151914749793],
              UndirectedEdge[62, 199] -> 
             RGBColor[
              0.5868878667757954, 0.648392143438405, 0.8070978104506135], 
             UndirectedEdge[96, 278] -> 
             RGBColor[
              0.5041987109200126, 0.6070709568623011, 0.9544705154158305], 
             UndirectedEdge[2, 178] -> 
             RGBColor[
              0.25390682555337085`, 0.3842025506521106, 0.9377709901425528], 
             UndirectedEdge[6, 213] -> 
             RGBColor[
              0.3667758904705204, 0.4918204598931879, 0.9446020161329686], 
             UndirectedEdge[79, 93] -> 
             RGBColor[
              0.46307011169266854`, 0.5733948534802826, 0.9513117589171669], 
             UndirectedEdge[270, 272] -> 
             RGBColor[
              0.22576785330449248`, 0.35462670670465335`, 0.9361685173008583],
              UndirectedEdge[161, 186] -> 
             RGBColor[
              0.22312007554742067`, 0.3518437244031648, 0.9360177302746292], 
             UndirectedEdge[189, 275] -> 
             RGBColor[
              0.22231351200262228`, 0.3509959749784993, 0.9359717976739568], 
             UndirectedEdge[260, 261] -> 
             RGBColor[
              0.6248975820608704, 0.7019966768640338, 0.9661118661321497], 
             UndirectedEdge[195, 200] -> 
             RGBColor[
              0.8414278249762438, 0.29050729216415533`, 0.1861717843217481], 
             UndirectedEdge[66, 110] -> 
             RGBColor[
              0.969700925487342, 0.9754692267738965, 0.8710436844734033], 
             UndirectedEdge[63, 172] -> 
             RGBColor[
              0.29700434513925705`, 0.4280429826559164, 0.940278707091565], 
             UndirectedEdge[4, 236] -> 
             RGBColor[
              0.5814156950940945, 0.671058479612787, 0.9601903197951254], 
             UndirectedEdge[143, 167] -> 
             RGBColor[
              0.5753382538779925, 0.6628795153036178, 0.9613047709389584], 
             UndirectedEdge[135, 249] -> 
             RGBColor[
              0.8757518909419225, 0.42593701703679554`, 0.3815512695878138], 
             UndirectedEdge[135, 288] -> 
             RGBColor[
              0.9046326551372147, 0.6405954744200593, 0.40892042898198233`], 
             UndirectedEdge[83, 214] -> 
             RGBColor[
              0.21458531177906248`, 0.342873146547343, 0.9355316881040727], 
             UndirectedEdge[36, 290] -> 
             RGBColor[
              0.6862499936639361, 0.7543721434480005, 0.9696708819958241], 
             UndirectedEdge[79, 119] -> 
             RGBColor[
              0.3385777508483834, 0.465228690511853, 0.9428846351776731], 
             UndirectedEdge[145, 264] -> 
             RGBColor[
              0.28193257724579573`, 0.4136593926161374, 0.9393670152410523], 
             UndirectedEdge[54, 238] -> 
             RGBColor[
              0.34796050319161576`, 0.47301253149465217`, 0.9434950557775005],
              UndirectedEdge[177, 273] -> 
             RGBColor[
              0.5185213619952923, 0.6190718502597115, 0.9554949527990644], 
             UndirectedEdge[98, 208] -> 
             RGBColor[
              0.3543834762769441, 0.47926414429235664`, 0.9438791178453103], 
             UndirectedEdge[125, 170] -> 
             RGBColor[
              0.8788040152312967, 0.44173686637663945`, 0.258623330792337], 
             UndirectedEdge[22, 217] -> 
             RGBColor[
              0.812207338591908, 0.8532218130031827, 0.981916895067874], 
             UndirectedEdge[78, 236] -> 
             RGBColor[
              0.4016254852173745, 0.5057768385746106, 0.9485224868513811], 
             UndirectedEdge[86, 240] -> 
             RGBColor[
              0.984900576757397, 0.9592281782774306, 0.5233965503688487], 
             UndirectedEdge[59, 170] -> 
             RGBColor[
              0.8291712502966372, 0.22522858946914998`, 0.17556772826926184`],
              UndirectedEdge[95, 109] -> 
             RGBColor[
              0.7049075830694689, 0.7678615870686365, 0.9726151362943627], 
             UndirectedEdge[30, 252] -> 
             RGBColor[
              0.38136485218953986`, 0.5037401708621798, 0.9456156414781487], 
             UndirectedEdge[116, 119] -> 
             RGBColor[
              0.30231628529617693`, 0.4338208316047836, 0.9405740866574415], 
             UndirectedEdge[6, 231] -> 
             RGBColor[
              0.3753962033450712, 0.49928694163560083`, 0.9451512948466916], 
             UndirectedEdge[214, 275] -> 
             RGBColor[
              0.21283035575294662`, 0.34102857649325646`, 0.9354317459546102],
              UndirectedEdge[157, 257] -> 
             RGBColor[
              0.3686428791962128, 0.49372166625507674`, 0.944710576177652], 
             UndirectedEdge[128, 173] -> 
             RGBColor[
              0.24821711809960986`, 0.3782223073699194, 0.9374469697202291], 
             UndirectedEdge[14, 113] -> 
             RGBColor[
              0.8682682293963724, 0.4400627275787366, 0.4307769881568413], 
             UndirectedEdge[213, 231] -> 
             RGBColor[
              0.43649903669503015`, 0.5524952593309104, 0.9490343105306326], 
             UndirectedEdge[29, 148] -> 
             RGBColor[
              0.2408182206421652, 0.3704455970249514, 0.9370256134557156], 
             UndirectedEdge[109, 154] -> 
             RGBColor[
              0.8311843708271494, 0.8688646527411055, 0.9835913192515602], 
             UndirectedEdge[74, 123] -> 
             RGBColor[
              0.5372173592410554, 0.6347120461758202, 0.9568391339311428], 
             UndirectedEdge[189, 216] -> 
             RGBColor[
              0.24534319825395978`, 0.3752016353950986, 0.9372833042366027], 
             UndirectedEdge[29, 162] -> 
             RGBColor[
              0.2636748497853562, 0.39446936344843425`, 0.9383272646720675], 
             UndirectedEdge[73, 140] -> 
             RGBColor[
              0.3285420686985767, 0.45898835972736407`, 0.9421553879924971], 
             UndirectedEdge[9, 295] -> 
             RGBColor[
              0.677057217004213, 0.7458583971286377, 0.9697240169413682], 
             UndirectedEdge[169, 221] -> 
             RGBColor[
              0.2938192081333214, 0.4261529953348542, 0.9400439412854023], 
             UndirectedEdge[22, 61] -> 
             RGBColor[
              0.6921091843567939, 0.7582433580431021, 0.9707375877325777], 
             UndirectedEdge[11, 143] -> 
             RGBColor[
              0.3701279239778581, 0.49500793740441695`, 0.9448052019179649], 
             UndirectedEdge[100, 299] -> 
             RGBColor[
              0.8982817367433281, 0.588471471678237, 0.3774803131264599], 
             UndirectedEdge[181, 232] -> 
             RGBColor[
              0.8539568089581072, 0.8830700073511788, 0.7854666422842203], 
             UndirectedEdge[49, 292] -> 
             RGBColor[
              0.23980801296623738`, 0.36938380470668514`, 0.9369680836230397],
              UndirectedEdge[4, 39] -> 
             RGBColor[
              0.7582287210905121, 0.5399616886397829, 0.4597522801819863], 
             UndirectedEdge[33, 75] -> 
             RGBColor[
              0.8225875285373088, 0.8620961486244765, 0.9827484209506085], 
             UndirectedEdge[223, 271] -> 
             RGBColor[
              0.9324098595457874, 0.7585161356784191, 0.29733719959784854`], 
             UndirectedEdge[21, 34] -> 
             RGBColor[
              0.3554769401154252, 0.48231799156263766`, 0.943871654181607], 
             UndirectedEdge[51, 165] -> 
             RGBColor[
              0.986911243979133, 0.9683407522697562, 0.5670857457477134], 
             UndirectedEdge[36, 138] -> 
             RGBColor[
              0.7331275863556836, 0.791444109527867, 0.9740349644072682], 
             UndirectedEdge[50, 205] -> 
             RGBColor[
              0.44094793085644673`, 0.5542815920827796, 0.9498889293247207], 
             UndirectedEdge[237, 283] -> 
             RGBColor[
              0.6287512202285861, 0.7094875913580734, 0.9639167457294545], 
             UndirectedEdge[140, 245] -> 
             RGBColor[
              0.37623831770858585`, 0.5003004533366545, 0.945194550803278], 
             UndirectedEdge[19, 49] -> 
             RGBColor[
              0.26391083574794544`, 0.39471739965748975`, 0.9383407037235271],
              UndirectedEdge[235, 292] -> 
             RGBColor[
              0.24255033880224458`, 0.3722661630338292, 0.9371242550224929], 
             UndirectedEdge[15, 115] -> 
             RGBColor[
              0.230257062183032, 0.3593451498682808, 0.9364241711053016], 
             UndirectedEdge[69, 110] -> 
             RGBColor[
              0.9929919929128255, 0.9894341623619243, 0.625087695462787], 
             UndirectedEdge[34, 50] -> 
             RGBColor[
              0.33997412107403424`, 0.46889022890332593`, 0.9428838282608942],
              UndirectedEdge[126, 275] -> 
             RGBColor[
              0.21935857397151598`, 0.34789014775391436`, 0.9358035183245244],
              UndirectedEdge[59, 225] -> 
             RGBColor[
              0.8755277217707287, 0.4621261005588738, 0.22031772858046247`], 
             UndirectedEdge[82, 228] -> 
             RGBColor[
              0.9057099592960236, 0.9241653224619759, 0.8439169187539672], 
             UndirectedEdge[19, 280] -> 
             RGBColor[
              0.2796627567223554, 0.4112736673310683, 0.939237752320141], 
             UndirectedEdge[194, 283] -> 
             RGBColor[
              0.5672781592829315, 0.6595809911525545, 0.9590773611885706], 
             UndirectedEdge[63, 283] -> 
             RGBColor[
              0.4716182093057971, 0.5784225844464469, 0.9525129877054703], 
             UndirectedEdge[36, 245] -> 
             RGBColor[
              0.5919869457083973, 0.6770600343104392, 0.9624670806434741], 
             UndirectedEdge[3, 55] -> 
             RGBColor[
              0.327009852931445, 0.45469787926428074`, 0.9421662593982401], 
             UndirectedEdge[137, 192] -> 
             RGBColor[
              0.8520395168588157, 0.39410340767554625`, 0.19719619206781494`],
              UndirectedEdge[54, 251] -> 
             RGBColor[
              0.3520600889143901, 0.4773214560180356, 0.9437285211196189], 
             UndirectedEdge[252, 292] -> 
             RGBColor[
              0.2717964040404102, 0.4030056319067771, 0.9387897751721301], 
             UndirectedEdge[100, 121] -> 
             RGBColor[
              0.8983235951964362, 0.5881023685637291, 0.34869848898741257`], 
             UndirectedEdge[142, 239] -> 
             RGBColor[
              0.5350790113196064, 0.6320396024840493, 0.9570335383591173], 
             UndirectedEdge[85, 299] -> 
             RGBColor[
              0.9570551059778822, 0.9653678956255696, 0.8666323773215838], 
             UndirectedEdge[120, 130] -> 
             RGBColor[
              0.18442078734008566`, 0.31116831882066576`, 0.9338138630616879],
              UndirectedEdge[9, 297] -> 
             RGBColor[
              0.6386143417337113, 0.7156866950327669, 0.9659294985140855], 
             UndirectedEdge[237, 239] -> 
             RGBColor[
              0.5249567920726707, 0.6240772116080362, 0.9560621419984239], 
             UndirectedEdge[169, 213] -> 
             RGBColor[
              0.36045188979201, 0.48517353421527176`, 0.944241873649848], 
             UndirectedEdge[46, 50] -> 
             RGBColor[
              0.32229358745653136`, 0.4520407279394575, 0.9418134628870861], 
             UndirectedEdge[105, 171] -> 
             RGBColor[
              0.3537618197336009, 0.4790225362534377, 0.9438286376877205], 
             UndirectedEdge[34, 114] -> 
             RGBColor[
              0.31595519138804573`, 0.44768545635926527`, 0.9413680379248031],
              UndirectedEdge[60, 240] -> 
             RGBColor[
              0.9605080040332614, 0.868110146524278, 0.47465486371626864`], 
             UndirectedEdge[19, 84] -> 
             RGBColor[
              0.2959425689542974, 0.42838478218655185`, 0.940164863542926], 
             UndirectedEdge[19, 48] -> 
             RGBColor[
              0.3524750293077462, 0.47810184855613913`, 0.9437395461742546], 
             UndirectedEdge[5, 77] -> 
             RGBColor[
              0.23349568981372465`, 0.3627491528489905, 0.9366086061577494]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {3}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.26920385108875294`, 0.4002806943772341, 0.9386421331168716], 
             160 -> RGBColor[
              0.5902199940802382, 0.6782062061588879, 0.9608834264625246], 
             245 -> RGBColor[
              0.4244026220080174, 0.5420179529125, 0.9482635376832157], 155 -> 
             RGBColor[
              0.21230278460535462`, 0.3404740657671945, 0.9354017015582263], 
             213 -> RGBColor[
              0.42787872382047937`, 0.5450287775884974, 0.9484850318169096], 
             27 -> RGBColor[
              0.2584384877012701, 0.38896561489352793`, 0.9380290615978824], 
             19 -> RGBColor[
              0.2912671539208582, 0.4234706245479727, 0.9398986055734284], 
             164 -> RGBColor[
              0.38392426951059677`, 0.5069576384803866, 0.9456842928556817], 
             190 -> RGBColor[
              0.22813210557574862`, 0.35711168574399543`, 0.9363031579701084],
              103 -> RGBColor[
              0.2788168781365947, 0.4103845953056338, 0.9391895807860471], 
             138 -> RGBColor[
              0.7066839033025902, 0.7707861033473555, 0.971399305210804], 291 -> 
             RGBColor[
              0.8179080138731872, 0.1386544187368418, 0.16478204035016009`], 
             28 -> RGBColor[
              0.22341264573171882`, 0.35215123421688327`, 0.9360343917138061],
              114 -> RGBColor[
              0.3044111891973746, 0.4372858390035616, 0.9406471389375684], 
             195 -> RGBColor[
              0.8191437574953648, 0.1481528857232069, 0.16596538983833015`], 
             93 -> RGBColor[
              0.5312094509757161, 0.6302987888719648, 0.9562379003465947], 34 -> 
             RGBColor[
              0.3274991935787168, 0.458085073714969, 0.9420889369120379], 161 -> 
             RGBColor[
              0.21627103797903324`, 0.3446449516647265, 0.9356276877173526], 
             22 -> RGBColor[
              0.8173789776787558, 0.8572619367637411, 0.982432355720336], 124 -> 
             RGBColor[
              0.9476938047146304, 0.9605107057164812, 0.973424924364235], 84 -> 
             RGBColor[
              0.30061798398773654`, 0.43329893982513096`, 0.9404311215124237],
              46 -> RGBColor[
              0.29213812634371106`, 0.4243860717872321, 0.9399482061644217], 
             241 -> RGBColor[
              0.2790754121939759, 0.4106563309919474, 0.9392043039181481], 
             185 -> 
             RGBColor[
              0.5680702998089695, 0.6602240865171163, 0.9591397213924867], 
             121 -> RGBColor[
              0.9946101233350695, 0.9908799237508646, 0.6547233713644478], 
             126 -> RGBColor[
              0.22593857337368983`, 0.3548061443216573, 0.9361782395562414], 
             236 -> RGBColor[
              0.6232106502631707, 0.7049895070603167, 0.9634805717660004], 78 -> 
             RGBColor[
              0.1800403201715783, 0.3065641700889047, 0.9335644019367618], 
             254 -> RGBColor[
              0.8913219113450659, 0.5994000064779764, 0.23102867769365362`], 
             290 -> RGBColor[
              0.6129287179190951, 0.6966421711876226, 0.9626711403879157], 
             251 -> RGBColor[
              0.2867137638335649, 0.4186847228646212, 0.9396392967440941], 
             165 -> RGBColor[
              0.9802603651545728, 0.9450757179590131, 0.3778156754531135], 
             100 -> RGBColor[
              0.8501803311271197, 0.38671359097016134`, 0.19568604779889498`],
              235 -> RGBColor[
              0.24203916924704705`, 0.37172889142129484`, 0.937095144672532], 
             70 -> RGBColor[
              0.26423372362278924`, 0.39505677528622424`, 0.9383590917103296],
              234 -> RGBColor[0.817319, 0.134127, 0.164218], 257 -> 
             RGBColor[
              0.39130532114623406`, 0.5133507344247334, 0.9461546069390968], 
             135 -> RGBColor[
              0.9900957369634822, 0.9901723469535194, 0.8138028001335977], 
             265 -> RGBColor[
              0.22246582468563886`, 0.3511560652655316, 0.9359804716559281], 
             111 -> RGBColor[
              0.24301438028138522`, 0.37275390005033504`, 0.937150681498242], 
             182 -> RGBColor[
              0.3071831062866214, 0.4401992996140543, 0.9408049955151171], 
             188 -> RGBColor[
              0.20571498311483435`, 0.33354986870991854`, 0.9350265360091202],
              154 -> RGBColor[
              0.7412000832467709, 0.797750405452433, 0.9748395554555993], 269 -> 
             RGBColor[
              0.2270252964366493, 0.35594835916304945`, 0.9362401268270142], 
             208 -> RGBColor[
              0.28595975701387044`, 0.41789221389032877`, 0.9395963571711656],
              86 -> RGBColor[
              0.9748675947682047, 0.926884637163092, 0.35686578084130904`], 
             119 -> RGBColor[
              0.28222472928714576`, 0.41396646293510553`, 0.9393836528676069],
              140 -> 
             RGBColor[
              0.3280740134091542, 0.4585829537608091, 0.9421255639233401], 85 -> 
             RGBColor[
              0.9196256639800194, 0.938748558156751, 0.9921959108615778], 242 -> 
             RGBColor[
              0.24043240470913427`, 0.3700400800171928, 0.9370036418090929], 
             117 -> RGBColor[
              0.20347429876271564`, 0.33119476738824843`, 0.9348989323500625],
              47 -> RGBColor[
              0.6440597930627512, 0.7218636724671273, 0.9651575191576801], 81 -> 
             RGBColor[
              0.29584127485450173`, 0.42827831566524976`, 0.9401590949937939],
              275 -> RGBColor[
              0.21277857456934213`, 0.34097415118617147`, 0.9354287970928072],
              23 -> RGBColor[
              0.2963741173821658, 0.42883836694599214`, 0.9401894395874745], 
             110 -> RGBColor[
              0.9929459767177286, 0.9913509943397207, 0.7665669512217009], 6 -> 
             RGBColor[
              0.3056730571205615, 0.43861214219787836`, 0.9407190004490276], 
             218 -> RGBColor[
              0.2560427236071457, 0.38644751493038626`, 0.9378926263769374], 
             108 -> RGBColor[
              0.3439204196877902, 0.4723083144158259, 0.943135282918988], 297 -> 
             RGBColor[
              0.7603990286995737, 0.8127487675575523, 0.9767531269139887], 
             157 -> RGBColor[
              0.34598043724619154`, 0.47409259808542004`, 0.9432665454162072],
              270 -> RGBColor[
              0.22825539451058077`, 0.357241270231474, 0.9363101790925575], 
             33 -> RGBColor[
              0.9146626577353835, 0.9347911916944939, 0.9917225348954364], 
             252 -> RGBColor[
              0.30053129972337833`, 0.4332078291671907, 0.9404261849718064], 
             260 -> RGBColor[
              0.8491537797280463, 0.8825561905625664, 0.9854742396306309], 
             159 -> RGBColor[
              0.2473937360801429, 0.37735688066202433`, 0.937400079332305], 
             183 -> RGBColor[
              0.25458949129815345`, 0.38492007563338526`, 0.9378098669468048],
              99 -> RGBColor[
              0.3674883934084197, 0.4927217086918333, 0.9446370133641255], 17 -> 
             RGBColor[
              0.29622239326445615`, 0.42867889527841463`, 0.9401807991234267],
              277 -> RGBColor[
              0.34909505354151776`, 0.4767903221752649, 0.9434650060123984], 
             104 -> RGBColor[
              0.28507184392659923`, 0.4169589609386654, 0.9395457918343952], 
             79 -> 
             RGBColor[
              0.39493077240962093`, 0.5164909180886005, 0.9463856174877392], 
             191 -> RGBColor[
              0.24388899418338073`, 0.37367317471505657`, 0.9372004894660854],
              50 -> RGBColor[
              0.35244904856935166`, 0.4796953840916829, 0.9436787196097506], 
             225 -> RGBColor[
              0.9609628542707439, 0.8799806824768295, 0.3028484896985869], 61 -> 
             RGBColor[
              0.5668393910348319, 0.659224779322463, 0.9590428197448192], 196 -> 
             RGBColor[
              0.2809324202458739, 0.4126081641956031, 0.9393100577795065], 1 -> 
             RGBColor[
              0.41852266255485593`, 0.5369250275695268, 0.9478888718663042], 
             263 -> RGBColor[
              0.26098356523640104`, 0.3916406527501864, 0.9381739999984032], 
             201 -> RGBColor[
              0.32111303850258816`, 0.4525537071655133, 0.9416820167576422], 
             293 -> RGBColor[
              0.20926131084396443`, 0.33727728400339907`, 0.9352284941269724],
              184 -> RGBColor[
              0.23743710807503443`, 0.3668918333419784, 0.9368330640969252], 
             106 -> RGBColor[
              0.6566687686170058, 0.7317139000018745, 0.9664142640033524], 
             206 -> RGBColor[
              0.23667377020378227`, 0.366089516840876, 0.9367895931344146], 
             247 -> RGBColor[
              0.5790882470358998, 0.6691689524288044, 0.9600070945582612], 
             220 -> RGBColor[
              0.25719173910326026`, 0.38765520306859286`, 0.937958061109625], 
             107 -> RGBColor[
              0.8341470216086144, 0.26347454816989946`, 0.18033253249694123`],
              131 -> RGBColor[
              0.324831212684851, 0.4557742027613212, 0.9419189355286837], 127 -> 
             RGBColor[
              0.8327720947194103, 0.2529062576026711, 0.17901590095508144`], 
             210 -> RGBColor[
              0.37855708825470646`, 0.5023088558389079, 0.9453423008120684], 
             181 -> RGBColor[
              0.7138170777657293, 0.7763585934520937, 0.9721102733779844], 
             194 -> RGBColor[
              0.5158331891976378, 0.6178156468678216, 0.9550274246943216], 
             118 -> RGBColor[
              0.17892956896395254`, 0.30539670014399584`, 0.9335011462986966],
              276 -> RGBColor[
              0.23178154572615212`, 0.3609474787299394, 0.9365109881878111], 
             280 -> RGBColor[
              0.2680583595238526, 0.3990767101141639, 0.9385768990668534], 
             189 -> 
             RGBColor[
              0.2318484494359024, 0.3610177987708272, 0.9365147982551062], 
             168 -> RGBColor[
              0.3858730274799788, 0.5086455546860418, 0.9458084659902717], 41 -> 
             RGBColor[
              0.35699077137457635`, 0.483629196111943, 0.9439681141708117], 
             14 -> RGBColor[
              0.8226976998778256, 0.17547004422228246`, 0.1693686490773784], 
             77 -> RGBColor[
              0.2460324096232273, 0.37592604024272347`, 0.9373225538044856], 
             51 -> RGBColor[
              0.993562122803693, 0.9916057865804992, 0.7563558160423134], 179 -> 
             RGBColor[
              0.9936465744084931, 0.9916407094893913, 0.7549562343970292], 
             223 -> RGBColor[
              0.8873547734207121, 0.5813861597120881, 0.22771840056612383`], 
             292 -> RGBColor[
              0.24306150835744214`, 0.3728034346463635, 0.9371533653724538], 
             143 -> RGBColor[
              0.39675004724917656`, 0.5180666825152114, 0.9465015400717941], 
             112 -> RGBColor[
              0.2522134290242518, 0.3824226835324653, 0.9376745537153752], 
             197 -> RGBColor[
              0.2105002400012672, 0.3385794771003698, 0.9352990493096494], 54 -> 
             RGBColor[
              0.4174064139952154, 0.53595818917145, 0.9478177454951437], 71 -> 
             RGBColor[
              0.6295965520330332, 0.7101738697986875, 0.963983293345653], 177 -> 
             RGBColor[
              0.41920763486506846`, 0.5375183161569235, 0.9479325176962138], 
             158 -> RGBColor[
              0.40363205630183896`, 0.524027532856795, 0.9469400556031081], 
             226 -> RGBColor[
              0.178927010221482, 0.30539401074342565`, 0.9335010005820983], 
             203 -> RGBColor[
              0.2595939437592997, 0.3901800724706624, 0.9380948631110431], 
             115 -> RGBColor[
              0.2215913444714862, 0.35023693111520926`, 0.9359306713014096], 
             173 -> RGBColor[
              0.25717362368840185`, 0.38763616261899303`, 0.9379570294635482],
              212 -> RGBColor[
              0.21172080019279638`, 0.3398623632496528, 0.9353685584068999], 
             129 -> RGBColor[
              0.23590943272644063`, 0.36528614969039486`, 0.9367460652458159],
              279 -> RGBColor[
              0.25879261498995565`, 0.3893378251269034, 0.9380492286230886], 
             26 -> RGBColor[
              0.9858349896506369, 0.9884104184434465, 0.8844144095680297], 40 -> 
             RGBColor[
              0.2372124705557414, 0.3666557250663601, 0.9368202713225229], 
             146 -> RGBColor[
              0.23045057360750168`, 0.3595485426447314, 0.9364351912946507], 
             192 -> RGBColor[
              0.8649861375675162, 0.47981540863036076`, 0.20905346250477896`],
              300 -> RGBColor[
              0.2558608387541249, 0.3862563424176957, 0.9378822683036323], 
             221 -> RGBColor[
              0.29461336050310216`, 0.4269876998276622, 0.9400891670880182], 
             62 -> RGBColor[
              0.9948487335515908, 0.9913902868768101, 0.6806946209012268], 
             286 -> RGBColor[
              0.5590358689967736, 0.6528895285873056, 0.9584284979047402], 
             152 -> RGBColor[
              0.25329610735962166`, 0.38356064710871024`, 0.9377362106448954],
              64 -> RGBColor[
              0.23365539790008147`, 0.3629170161738291, 0.9366177012970005], 
             37 -> RGBColor[
              0.6807027709206555, 0.7504894452666685, 0.968809748742459], 148 -> 
             RGBColor[
              0.23881348570074337`, 0.36833849349398035`, 0.9369114467665411],
              261 -> RGBColor[
              0.4006413843936947, 0.5214371631655013, 0.9467494926336685], 15 -> 
             RGBColor[
              0.23892277989457777`, 0.36845336862135236`, 0.9369176709091936],
              136 -> RGBColor[
              0.9929076697798414, 0.9872385477406899, 0.46942180820333496`], 
             198 -> RGBColor[
              0.4642553566460736, 0.5759424388475844, 0.9509670287800365], 63 -> 
             RGBColor[
              0.32451328924336914`, 0.4554988334556064, 0.9418986777281211], 
             171 -> RGBColor[
              0.4183533072547869, 0.5367783405206518, 0.9478780806963388], 59 -> 
             RGBColor[
              0.8328101555207211, 0.25319880959989605`, 0.17905234802140027`],
              229 -> RGBColor[
              0.34638875058307517`, 0.4744462585754037, 0.9432925627809762], 
             102 -> RGBColor[
              0.38532279281260967`, 0.5081689690727651, 0.9457734055238204], 
             299 -> RGBColor[
              0.9944845479757449, 0.9919872330943883, 0.7410688437815899], 
             128 -> RGBColor[
              0.23926061251081787`, 0.3688084521208458, 0.93693690997691], 12 -> 
             RGBColor[
              0.20154157699751735`, 0.32916335427138743`, 0.93478886670474], 
             222 -> RGBColor[
              0.43613267935432526`, 0.5521779390160471, 0.94901096656484], 92 -> 
             RGBColor[
              0.261097249315751, 0.3917601419255701, 0.9381804741385418], 271 -> 
             RGBColor[
              0.9774649456708626, 0.9356461116447503, 0.3669559986295733], 
             132 -> RGBColor[
              0.2067120462521808, 0.3345978452847238, 0.9350833172797693], 80 -> 
             RGBColor[
              0.26782978190622225`, 0.39883646054537636`, 0.9385638819096797],
              244 -> RGBColor[
              0.24251120685435607`, 0.3722250328754895, 0.9371220265159511], 
             150 -> RGBColor[
              0.9620063021321176, 0.9711849428558795, 0.9491975995336027], 
             125 -> RGBColor[
              0.9926251659969516, 0.9866343007146026, 0.4386730148470409], 
             133 -> RGBColor[
              0.35014705105926486`, 0.47770150955020474`, 0.9435320383639844],
              258 -> RGBColor[
              0.9617670348256762, 0.9710064976904998, 0.9496026166724999], 
             255 -> RGBColor[
              0.9589543367125869, 0.8732054811308165, 0.29504577826186157`], 
             176 -> RGBColor[
              0.1789518783186532, 0.305420148690281, 0.9335024167834431], 230 -> 
             RGBColor[
              0.24935218422087857`, 0.37941533383072157`, 0.9375116100566555],
              274 -> RGBColor[
              0.9645754531953188, 0.8921668269279859, 0.3168827543384975], 87 -> 
             RGBColor[
              0.27610729667649436`, 0.4075366533936812, 0.9390352741303609], 
             130 -> RGBColor[0.178927, 0.305394, 0.933501], 35 -> 
             RGBColor[
              0.2262311772849768, 0.3551136895845794, 0.9361949029161204], 31 -> 
             RGBColor[
              0.6188367246795077, 0.7014385572283971, 0.9631362403218372], 18 -> 
             RGBColor[
              0.9464007204285422, 0.9595463255731478, 0.9756137787701872], 24 -> 
             RGBColor[
              0.9556367854010767, 0.9664345677069957, 0.9599795299232305], 
             151 -> RGBColor[
              0.443273542823118, 0.5583629960424816, 0.9494659760706539], 137 -> 
             RGBColor[
              0.8455662065044656, 0.351247407198139, 0.19126755684933291`], 
             296 -> RGBColor[
              0.6962355794932261, 0.7626237933772783, 0.9703579139386239], 
             266 -> RGBColor[
              0.24763395401992835`, 0.3776093649474359, 0.9374137593886052], 
             283 -> RGBColor[
              0.6187231293682252, 0.7013463354372874, 0.9631272976828197], 
             284 -> RGBColor[
              0.25564421936180226`, 0.3860286617019018, 0.9378699321496993], 
             238 -> 
             RGBColor[
              0.2785145923880161, 0.4100668738178543, 0.9391723660598572], 72 -> 
             RGBColor[
              0.6518075404484566, 0.7279162716099014, 0.9659297422102715], 
             288 -> RGBColor[
              0.8619011142240809, 0.46580703815332913`, 0.20647924340617463`],
              172 -> RGBColor[
              0.26949540103514497`, 0.4005871318562264, 0.9386587364550091], 
             243 -> RGBColor[
              0.21816661637866602`, 0.3466373247493527, 0.9357356381029547], 
             88 -> RGBColor[
              0.5042211596463271, 0.6083884781620977, 0.9541132831917766], 
             273 -> RGBColor[
              0.6178350891255162, 0.7006253843624993, 0.9630573879019151], 
             202 -> RGBColor[
              0.22812105044609293`, 0.3571000661017916, 0.9363025283968291], 
             98 -> RGBColor[
              0.4228071955400177, 0.5406360746943846, 0.948161878519455], 30 -> 
             RGBColor[
              0.46219840465570133`, 0.574272512557169, 0.9508050979844909], 
             116 -> RGBColor[
              0.3224078413052081, 0.4536752002744616, 0.941764520447276], 240 -> 
             RGBColor[
              0.9949335587465892, 0.9915717193917691, 0.6899273198963884], 73 -> 
             RGBColor[
              0.3290101239879992, 0.459393765693919, 0.9421852120616541], 29 -> 
             RGBColor[
              0.24282295558358705`, 0.3725527005559224, 0.9371397801448899], 
             75 -> RGBColor[
              0.7305123993392341, 0.7894011055544591, 0.9737743070057807], 
             200 -> RGBColor[
              0.8859959599380017, 0.5752161050460523, 0.226584573288584], 156 -> 
             RGBColor[
              0.2276990046313701, 0.35665646919126776`, 0.9362784935120415], 
             25 -> RGBColor[
              0.2518103509231395, 0.3819990228915686, 0.9376515990138174], 38 -> 
             RGBColor[
              0.4179442959916355, 0.5364240755220139, 0.9478520188603253], 3 -> 
             RGBColor[
              0.3773249031069595, 0.5012415989953558, 0.9452637870640326], 57 -> 
             RGBColor[
              0.24705297562595502`, 0.37699871981921224`, 0.9373806735285489],
              227 -> RGBColor[
              0.25976518882652405`, 0.3903600618938796, 0.9381046152642871], 
             39 -> RGBColor[
              0.8675327116732591, 0.4913788068770457, 0.21117838636085415`], 
             109 -> RGBColor[
              0.9211686584075277, 0.939978900029778, 0.992343083047521], 256 -> 
             RGBColor[
              0.9952479751456992, 0.992244224277091, 0.7241496045864151], 287 -> 
             RGBColor[
              0.9409750107809423, 0.8036926171977683, 0.27136531206102255`], 
             239 -> RGBColor[
              0.4111342730563943, 0.530525575937213, 0.9474180902207585], 285 -> 
             RGBColor[0.382771346863294, 0.50595903483087, 0.945610829644085],
              216 -> RGBColor[
              0.2588379470720171, 0.38938547201937, 0.9380518102180992], 21 -> 
             RGBColor[
              0.38345468665213356`, 0.5065509094103063, 0.9456543714511763], 
             175 -> RGBColor[
              0.2945111830148827, 0.42688030480911665`, 0.9400833482312222], 
             7 -> RGBColor[
              0.394746751143397, 0.516331528116975, 0.946373891815379], 13 -> 
             RGBColor[
              0.30612838775897044`, 0.4390907235684761, 0.9407449308552837], 
             294 -> RGBColor[
              0.209897553009386, 0.33794601485934034`, 0.9352647271770572], 
             193 -> RGBColor[
              0.39949775357450523`, 0.5204466076304757, 0.9466766214891428], 
             60 -> RGBColor[
              0.9260824493199337, 0.7446485736567867, 0.2593824075361489], 65 -> 
             RGBColor[
              0.28791659856684826`, 0.41994897843342893`, 0.9397077964027201],
              69 -> RGBColor[
              0.9930380091079225, 0.9875173303841278, 0.48360843970387296`], 
             217 -> RGBColor[
              0.80703569950506, 0.8491816892426243, 0.9814014344154122], 214 -> 
             RGBColor[
              0.21288213693655111`, 0.34108300180034146`, 0.9354346948164131],
              170 -> RGBColor[
              0.8218934398484693, 0.16928814920765783`, 0.168598488764985], 
             74 -> RGBColor[
              0.6382140736915616, 0.7171699620960075, 0.9646616962176343], 
             246 -> RGBColor[
              0.5988679170367666, 0.6852269795994871, 0.961564222636048], 264 -> 
             RGBColor[
              0.2946613034028385, 0.4270380908550406, 0.940091897365233], 278 -> 
             RGBColor[
              0.6029315110482949, 0.6885259882808699, 0.9618841236420709], 45 -> 
             RGBColor[
              0.8578237913971699, 0.4454645759914146, 0.2030054339855487], 
             237 -> RGBColor[
              0.638779311088947, 0.7176288472788594, 0.9647061937760893], 228 -> 
             RGBColor[
              0.8163432429187892, 0.8564528128973794, 0.9823291233589543], 
             180 -> RGBColor[
              0.23402613491596813`, 0.3633066842836104, 0.936638814221599], 
             53 -> RGBColor[
              0.8317291195209172, 0.2448894931924079, 0.17801714672713256`], 
             48 -> RGBColor[
              0.4136829046946342, 0.5327330725643056, 0.9475804867750808], 5 -> 
             RGBColor[
              0.220958970004222, 0.34957226545525755`, 0.9358946585110132], 
             101 -> RGBColor[
              0.5465902564750337, 0.6427856196737024, 0.9574487336972479], 
             267 -> RGBColor[
              0.467847246129772, 0.578858496543228, 0.9512497954777179], 120 -> 
             RGBColor[
              0.18991457468017128`, 0.31694263764133146`, 0.9341267261233757],
              147 -> RGBColor[
              0.22619261942112945`, 0.35507316282496604`, 0.9361927071028155],
              89 -> RGBColor[
              0.27813245697413447`, 0.40966522526908, 0.9391506040133554], 43 -> 
             RGBColor[
              0.322173741643116, 0.45347243491334854`, 0.9417496038238137], 
             199 -> RGBColor[0.178927, 0.305394, 0.933501], 268 -> 
             RGBColor[
              0.2625163578880115, 0.3932517150116962, 0.938261290272349], 169 -> 
             RGBColor[
              0.2930250557635406, 0.42531829084204614`, 0.9399987154827865], 
             20 -> RGBColor[
              0.865905855945801, 0.8959138414156087, 0.9870720676150353], 4 -> 
             RGBColor[
              0.5396207399250182, 0.6371274521652572, 0.9569000678242504], 
             167 -> RGBColor[
              0.7539264605068086, 0.8076923480920241, 0.9761080018061227], 
             142 -> RGBColor[
              0.6590237495828186, 0.7335536290308857, 0.9666489864974762], 16 -> 
             RGBColor[
              0.9934703621130101, 0.9884420897444159, 0.5306673961342021], 
             281 -> RGBColor[
              0.8360763947567734, 0.2783045556433535, 0.18218010240253352`], 
             289 -> RGBColor[
              0.2909832679823188, 0.4231722424271597, 0.9398824386892002], 
             178 -> RGBColor[
              0.27705635157752495`, 0.4085341702682206, 0.9390893214029737], 
             58 -> RGBColor[
              0.5489231824340144, 0.6446795940643196, 0.9576323901745283], 
             186 -> RGBColor[
              0.2299691131158081, 0.3590424971416032, 0.9364077728319058], 
             122 -> RGBColor[
              0.6241927467762723, 0.7057868172525964, 0.96355788600105], 249 -> 
             RGBColor[
              0.8185799679311427, 0.1438193520784336, 0.16542550431492184`], 
             113 -> 
             RGBColor[
              0.9594092884334661, 0.9692480942916449, 0.9535936663157671], 52 -> 
             RGBColor[
              0.8177080186927622, 0.13711716814164848`, 0.16459052473952288`],
              187 -> RGBColor[
              0.3639294956023307, 0.48963917028760373`, 0.9444102435429313], 
             259 -> RGBColor[
              0.46426084954242974`, 0.5759468982282985, 0.9509674612009588], 
             42 -> RGBColor[
              0.2544378422070241, 0.3847606828235006, 0.9378012307554097], 
             134 -> RGBColor[
              0.27400077350385804`, 0.40532256397795713`, 0.9389153107520011],
              248 -> RGBColor[
              0.20835094833068457`, 0.3363204352816248, 0.9351766503286018], 
             174 -> RGBColor[
              0.3923234880848031, 0.5142326194523638, 0.9462194836360928], 
             215 -> RGBColor[
              0.9951032288756773, 0.9922430735458843, 0.7308157001748675], 83 -> 
             RGBColor[
              0.21628848662157388`, 0.34466329129434453`, 0.9356286813917323],
              95 -> RGBColor[
              0.48864650773140994`, 0.5957442741074949, 0.9528871895412045], 
             166 -> RGBColor[
              0.9927232541779302, 0.9868441014154793, 0.4493493080164732], 
             233 -> RGBColor[
              0.9940884990666902, 0.9897642221851048, 0.5979477888431959], 
             295 -> RGBColor[
              0.8372847792405768, 0.8730921717492939, 0.9843421637685542], 
             141 -> RGBColor[
              0.8990024464838272, 0.6342755227085348, 0.23743750448057996`], 
             205 -> RGBColor[
              0.5294468131435418, 0.6288678000738763, 0.9560991390396908], 
             224 -> RGBColor[
              0.9695247134417432, 0.9088618438807439, 0.33610969580648287`], 
             231 -> RGBColor[
              0.44511934956958094`, 0.5599617410733233, 0.9495835892443556], 
             68 -> RGBColor[
              0.8743662175245639, 0.5224081609419808, 0.2168804311477391], 10 -> 
             RGBColor[
              0.2114327980870659, 0.3395596547761419, 0.9353521571130395], 
             250 -> RGBColor[
              0.22258326386374316`, 0.3512795012877932, 0.9359871596433854], 
             282 -> RGBColor[
              0.9636570397640628, 0.9724160602789496, 0.9464033313040466], 
             232 -> RGBColor[
              0.9940965401504851, 0.9897814212502639, 0.5988230111904562], 
             253 -> RGBColor[
              0.29672537087035056`, 0.42920755663283183`, 0.9402094429539937],
              55 -> 
             RGBColor[
              0.2766948027559306, 0.4081541595332056, 0.9390687317324474], 91 -> 
             RGBColor[
              0.2726124428491967, 0.4038633404346605, 0.9388362473750692], 
             105 -> RGBColor[
              0.28917033221241484`, 0.4212667319862237, 0.9397791946791023], 
             36 -> RGBColor[
              0.7595712694087771, 0.8121021157083784, 0.9766706236037325], 
             123 -> RGBColor[
              0.43622064479054923`, 0.5522541302556329, 0.9490165716446514], 
             94 -> RGBColor[
              0.8619491220774967, 0.8927588492317026, 0.9866946708064583], 96 -> 
             RGBColor[
              0.40546591079173033`, 0.5256159254437323, 0.9470569071895901], 
             2 -> RGBColor[
              0.2307572995292167, 0.3598709310360006, 0.936452658882132], 262 -> 
             RGBColor[
              0.9939797374120591, 0.9895315920033393, 0.5861097539357399], 
             272 -> RGBColor[
              0.22328031209840418`, 0.35201214317783264`, 0.936026855509159], 
             97 -> RGBColor[
              0.2574804300414378, 0.3879586355486801, 0.9379745016314742], 
             209 -> RGBColor[
              0.2651563206276758, 0.3960264832343887, 0.938411632244898], 66 -> 
             RGBColor[
              0.9464558742569554, 0.9595874592080723, 0.9755204177251058], 
             139 -> RGBColor[
              0.25547870703592473`, 0.385854697753317, 0.9378605064675941], 
             56 -> RGBColor[
              0.5476923991281734, 0.6436803887304818, 0.9575354984041846], 
             144 -> RGBColor[
              0.3157094904678022, 0.4478734254480028, 0.9413377074550355], 
             298 -> RGBColor[
              0.28525208052382683`, 0.41714840103001194`, 0.9395560560419711],
              204 -> RGBColor[
              0.23088271225706164`, 0.36000274776459185`, 0.9364598009514513],
              207 -> RGBColor[
              0.7455882739599426, 0.8011784933890475, 0.9752769292959146], 
             149 -> RGBColor[
              0.2939489691399074, 0.4262893823800991, 0.9400513309827632], 
             219 -> RGBColor[
              0.27423499655804673`, 0.4055687472585089, 0.9389286494084351], 
             9 -> RGBColor[
              0.5168296547678491, 0.6186246225079816, 0.9551058701141822], 11 -> 
             RGBColor[
              0.34350580070653963`, 0.47194919229362253`, 0.9431088637641358],
              44 -> RGBColor[
              0.9650552642631052, 0.8937853423246256, 0.3187467297321304], 
             153 -> 
             RGBColor[
              0.27348165172589245`, 0.40477693407509363`, 0.9388857475347178],
              32 -> RGBColor[
              0.2562574704790552, 0.38667322750850125`, 0.9379048558936031], 
             162 -> RGBColor[
              0.2845267439871254, 0.4163860263409461, 0.9395147491992453], 90 -> 
             RGBColor[
              0.4035464690461924, 0.5239534014776945, 0.9469346020588602], 8 -> 
             RGBColor[
              0.6518492866916434, 0.7279488840923621, 0.9659339030856515], 
             163 -> RGBColor[
              0.2413593551772921, 0.3710143637312809, 0.9370564302669542], 49 -> 
             RGBColor[
              0.23655451757503262`, 0.36596417476700677`, 0.9367828018736257],
              76 -> RGBColor[
              0.29429562032882867`, 0.4266537347586102, 0.9400710722551477], 
             82 -> RGBColor[
              0.9950766756732579, 0.9918778320265724, 0.7055047141489801], 67 -> 
             RGBColor[
              0.9123183312358003, 0.932921889378774, 0.9914989309411012], 211 -> 
             RGBColor[
              0.24235927283690456`, 0.3720653405899749, 
               0.9371133740984234]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9mHk4FFzYxsmSfR/LzGBWM2NmbHmlLHNH8aZCu0SWIkQLqbSgomQtVNoX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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 9}], {
             RGBColor[
             0.46767615866135254`, 0.5777748250387542, 0.9514973709902432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 11}], {
             RGBColor[
             0.3810142316306978, 0.5044371099315746, 0.9454988678152201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 20}], {
             RGBColor[
             0.6422142592503285, 0.7164194344925677, 0.9674804697406698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 37}], {
             RGBColor[
             0.5496127167377557, 0.6437072364180976, 0.9583493103043816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 43}], {
             RGBColor[
             0.370348202098986, 0.49519873124143765`, 0.944819237845059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 75}], {
             RGBColor[
             0.5745175309470449, 0.663163066561993, 0.9608315894360424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 102}], {
             RGBColor[
             0.40192272768373283`, 0.5225469983211459, 0.9468311386950623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 142}], {
             RGBColor[
             0.5387732060688373, 0.6352393283002062, 0.9572689291818902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 143}], {
             RGBColor[
             0.4076363549020162, 0.5274958550423691, 0.9471952059690492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 174}], {
             RGBColor[
             0.4054230753198295, 0.5255788235109453, 0.9470541777511985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 185}], {
             RGBColor[
             0.4932964811819127, 0.5985745570433215, 0.9535142966293955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 237}], {
             RGBColor[
             0.5286509868219015, 0.6272769374241931, 0.9562975328211968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 239}], {
             RGBColor[
             0.4148284678056251, 0.5337253017533699, 0.9476534810435313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 283}], {
             RGBColor[
             0.5186228959615405, 0.619135681503407, 0.955508084774562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 295}], {
             RGBColor[
             0.6279037208977163, 0.7050085996594103, 0.9661155178174292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 297}], {
             RGBColor[
             0.5894608456272148, 0.6748368975635395, 0.9623209993901465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 32}], {
             RGBColor[
             0.24350738500413596`, 0.3732720792722509, 0.9371787573878676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 83}], {
             RGBColor[
             0.2235228930753953, 0.35226711116517256`, 0.9360406701369322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 155}], {
             RGBColor[
             0.22153004206728566`, 0.3501724984015976, 0.9359271802201792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 156}], {
             RGBColor[
             0.2292281520802934, 0.3582637001136342, 0.9363655761970868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 178}], {
             RGBColor[
             0.25390682555337085`, 0.3842025506521106, 0.9377709901425528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 184}], {
             RGBColor[
             0.23409720380212556`, 0.3633813821889895, 0.9366428614895286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 202}], {
             RGBColor[
             0.22943917498765481`, 0.3584854985688961, 0.9363775936394806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 208}], {
             RGBColor[
             0.2583585282715436, 0.3888815724631647, 0.9380245080266488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 214}], {
             RGBColor[
             0.2218197182328839, 0.35047696641817105`, 0.9359436768492726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 268}], {
             RGBColor[
             0.2466368287086141, 0.37656132302384837`, 0.9373569745772405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 275}], {
             RGBColor[
             0.2217679370492794, 0.35042254111108606`, 0.9359407279874696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 17}], {
             RGBColor[
             0.3367736481857078, 0.4649602471368852, 0.9427222930937296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 30}], {
             RGBColor[
             0.4197616538813304, 0.5377570557762624, 0.9480344425242617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 38}], {
             RGBColor[
             0.3976345995492975, 0.5188328372586848, 0.9465579029621789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 55}], {
             RGBColor[
             0.327009852931445, 0.45469787926428074`, 0.9421662593982401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 74}], {
             RGBColor[
             0.5077694883992605, 0.6092057805456816, 0.9549627416408335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 90}], {
             RGBColor[
             0.39043568607657597`, 0.5125975002365252, 0.9460991945614463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[
             0.40677277394875433`, 0.5267478646254944, 0.9471401793543419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 144}], {
             RGBColor[
             0.34651719678738085`, 0.4745575122216793, 0.9433007472595341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 157}], {
             RGBColor[
             0.36165267017657554`, 0.4876670985403879, 0.9442651662401199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 229}], {
             RGBColor[
             0.3618568268450173, 0.48784392878537974`, 0.9442781749225044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 252}], {
             RGBColor[
             0.33892810141516894`, 0.46722471408127325`, 0.9428449860179196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 257}], {
             RGBColor[
             0.38431511212659675`, 0.5072961667100446, 0.9457091970015647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 259}], {
             RGBColor[
             0.42079287632469464`, 0.5385942486118271, 0.9481156241324957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 26}], {
             RGBColor[
             0.7627278647878275, 0.8127689353043519, 0.92065723869614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 39}], {
             RGBColor[
             0.7582287210905121, 0.5399616886397829, 0.4597522801819863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 52}], {
             RGBColor[
             0.7250122591035142, 0.3037872628161848, 0.42869370576776544`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 78}], {
             RGBColor[
             0.3598305300482983, 0.47184581112708096`, 0.9452322348805061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 82}], {
             RGBColor[
             0.7673487077991381, 0.8145026420959148, 0.8312023909866153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 107}], {
             RGBColor[
             0.735971594380749, 0.38802551616835207`, 0.43918837760604434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 130}], {
             RGBColor[
             0.3592738699625091, 0.4712607260826286, 0.9452005339121252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 193}], {
             RGBColor[
             0.46955924674976174`, 0.5787870298978665, 0.9517883446566966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 199}], {
             RGBColor[
             0.3592738699625091, 0.4712607260826286, 0.9452005339121252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 220}], {
             RGBColor[
             0.3984062395141392, 0.5123913276169251, 0.9474290644669376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.35927387507325015`, 0.47126073145434144`, 0.9452005342031744]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 228}], {
             RGBColor[
             0.6779819914219037, 0.7467901325313183, 0.9696145955916023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 236}], {
             RGBColor[
             0.5814156950940945, 0.671058479612787, 0.9601903197951254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 266}], {
             RGBColor[
             0.3936273469724733, 0.5073684085563466, 0.9471569136064277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 281}], {
             RGBColor[
             0.7372578431461884, 0.3979121878173214, 0.4404200908764392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.23189096279390453`, 0.36106248300558996`, 0.9365172193279515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[
             0.23349568981372465`, 0.3627491528489905, 0.9366086061577494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 191}], {
             RGBColor[
             0.23242398209380136`, 0.36162272008515706`, 0.9365475739885493]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 248}], {
             RGBColor[
             0.21465495916745328`, 0.3429463503684412, 0.9355356544198075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 21}], {
             RGBColor[
             0.3445638718863475, 0.47258152580409235`, 0.9431866859501019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 34}], {
             RGBColor[
             0.31658612534963915`, 0.4483486079564237, 0.9414039686805327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 46}], {
             RGBColor[
             0.29890559173213627`, 0.4314991069925552, 0.9403336033067247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 50}], {
             RGBColor[
             0.32906105284495657`, 0.4591537631447806, 0.9421988600293891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 101}], {
             RGBColor[
             0.4261316567977976, 0.5406988809357904, 0.9490838670731377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 108}], {
             RGBColor[
             0.32479673840417583`, 0.4554602283068521, 0.9419271416840078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 114}], {
             RGBColor[
             0.30504212315896806`, 0.43794899060072, 0.940683069693298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 145}], {
             RGBColor[
             0.2874384541046572, 0.41944641828755624`, 0.9396805667829495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 169}], {
             RGBColor[
             0.299349056442051, 0.4319652165199622, 0.940358857965907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 187}], {
             RGBColor[
             0.3348012763614461, 0.46412565624274105`, 0.9425646219959795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 205}], {
             RGBColor[
             0.41755993513205164`, 0.5337399711358773, 0.9484090697443592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 213}], {
             RGBColor[
             0.3667758904705204, 0.4918204598931879, 0.9446020161329686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 219}], {
             RGBColor[
             0.2899540268393041, 0.4220904447281936, 0.9398238249287314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 221}], {
             RGBColor[
             0.3001432088118318, 0.4327999210127703, 0.9404040837685228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 231}], {
             RGBColor[
             0.3753962033450712, 0.49928694163560083`, 0.9451512948466916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 264}], {
             RGBColor[
             0.3001671802617, 0.4328251165264595, 0.9404054489071303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 9}], {
             RGBColor[
             0.45578820295562306`, 0.5674780753124783, 0.9507398809647807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 11}], {
             RGBColor[
             0.36912627592496833`, 0.4941403602052988, 0.9447413777897574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 43}], {
             RGBColor[
             0.3584602463932565, 0.4849019815151618, 0.9440617478195963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.40607658256930623`, 0.5261448586442126, 0.9470958186552614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 63}], {
             RGBColor[
             0.3596300201933831, 0.4859151807862907, 0.94413628477175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 106}], {
             RGBColor[
             0.5257077598802015, 0.6240227140594248, 0.9563940779093657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 131}], {
             RGBColor[
             0.359788981914124, 0.4860528654391481, 0.9441464136720313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 143}], {
             RGBColor[
             0.3957483991962868, 0.5171991053160931, 0.9464377159435866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 151}], {
             RGBColor[
             0.4190101469832575, 0.5373472620797284, 0.9479199339430164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 167}], {
             RGBColor[
             0.5743366058251028, 0.6620119381044995, 0.9612409468107508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 174}], {
             RGBColor[
             0.39353511961410004`, 0.5152820737846694, 0.9462966877257359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 185}], {
             RGBColor[
             0.4814085254761833, 0.5882778073170456, 0.9527568066039329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[
             0.4552899701705174, 0.5670735874923983, 0.9507006582548503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 283}], {
             RGBColor[
             0.5067349402558111, 0.6088389317771312, 0.9547505947490993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 297}], {
             RGBColor[
             0.5775728899214854, 0.6645401478372637, 0.9615635093646839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 22}], {
             RGBColor[
             0.7346141321851996, 0.7926054104280515, 0.9741831294029938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 47}], {
             RGBColor[
             0.6479545398771973, 0.7249062782797447, 0.9655457111216659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 61}], {
             RGBColor[
             0.6093443388632377, 0.6935868317074125, 0.9624883614152353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 72}], {
             RGBColor[
             0.6518284135700501, 0.7279325778511317, 0.9659318226479615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 177}], {
             RGBColor[
             0.5355284607783559, 0.6327336001246429, 0.9569332103909327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 217}], {
             RGBColor[
             0.7294424930983517, 0.7885652866674933, 0.9736676687505319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 247}], {
             RGBColor[
             0.6154687668637716, 0.6985589182605833, 0.9629704988219563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 267}], {
             RGBColor[
             0.5598482664107077, 0.6534036903177951, 0.9585918492816847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 271}], {
             RGBColor[
             0.814657116181253, 0.8317974978685563, 0.6664449508576125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 273}], {
             RGBColor[
             0.6348421879085798, 0.7142871342274307, 0.9644956454937833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 285}], {
             RGBColor[
             0.5173103167774687, 0.616953959461616, 0.9557723663648683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.43016772773719436`, 0.545286907400802, 0.949107366939159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 20}], {
             RGBColor[
             0.6913677553568252, 0.7572692319617951, 0.9710889688646087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 37}], {
             RGBColor[
             0.5987662128442524, 0.684557033887325, 0.9619578094283205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 43}], {
             RGBColor[
             0.41950169820548255`, 0.5360485287106651, 0.948427736968998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 63}], {
             RGBColor[
             0.42067147200560917`, 0.537061727981794, 0.9485022739211517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 75}], {
             RGBColor[
             0.6236710270535416, 0.7040128640312203, 0.9644400885599815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.5867492116924276, 0.675169261254928, 0.9607600670587673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 131}], {
             RGBColor[
             0.4208304337263501, 0.5371994126346513, 0.9485124028214329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 142}], {
             RGBColor[
             0.5879267021753338, 0.6760891257694337, 0.9608774283058292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 143}], {
             RGBColor[
             0.4567898510085129, 0.5683456525115964, 0.9508037050929882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 167}], {
             RGBColor[
             0.6353780576373289, 0.7131584853000028, 0.9656069359601525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 174}], {
             RGBColor[
             0.4545765714263261, 0.5664286209801727, 0.9506626768751375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 185}], {
             RGBColor[
             0.5424499772884093, 0.6394243545125489, 0.9571227957533345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 237}], {
             RGBColor[
             0.5778044829283981, 0.6681267348934206, 0.9599060319451358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 239}], {
             RGBColor[
             0.4639819639121217, 0.5745750992225973, 0.9512619801674704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 282}], {
             RGBColor[
             0.740243347265956, 0.7955203413934655, 0.9507546007091144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 283}], {
             RGBColor[
             0.5677763920680372, 0.6599854789726345, 0.959116583898501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 295}], {
             RGBColor[
             0.677057217004213, 0.7458583971286377, 0.9697240169413682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 297}], {
             RGBColor[
             0.6386143417337113, 0.7156866950327669, 0.9659294985140855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 117}], {
             RGBColor[
             0.20745354842489078`, 0.3353772110821952, 0.935125544731551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.22367111540675327`, 0.3524229022332684, 0.9360491111794278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 161}], {
             RGBColor[
             0.21385191803304957`, 0.3421023032204342, 0.935489922415196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 265}], {
             RGBColor[
             0.21694931138635237`, 0.3453578600208368, 0.9356663143844839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 269}], {
             RGBColor[
             0.2192290472618576, 0.3477540069695957, 0.9357961419700269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 43}], {
             RGBColor[
             0.3328397711748278, 0.46271081360348554`, 0.9424292337939748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 63}], {
             RGBColor[
             0.3340095449749544, 0.46372401287461446`, 0.9425037707461285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 131}], {
             RGBColor[
             0.3341685066956953, 0.46386169752747186`, 0.9425138996464097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 139}], {
             RGBColor[
             0.2994922538712322, 0.4289019450234698, 0.940484685115865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 143}], {
             RGBColor[
             0.3701279239778581, 0.49500793740441695`, 0.9448052019179649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 172}], {
             RGBColor[
             0.3065006008708423, 0.43626816207492447`, 0.9408838001095725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 174}], {
             RGBColor[
             0.36791464439567134`, 0.49309090587299315`, 0.9446641737001142]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 183}], {
             RGBColor[
             0.29904764600234657`, 0.4284346339635039, 0.9404593653554703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 185}], {
             RGBColor[
             0.4557880502577546, 0.5660866394053694, 0.9511242925783112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 283}], {
             RGBColor[
             0.4811144650373824, 0.586647763865455, 0.9531180807234778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 248}], {
             RGBColor[
             0.20494626266410096`, 0.3327418947765061, 0.9349827585166709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 58}], {
             RGBColor[
             0.4275257850964924, 0.5418851588163979, 0.949188660514906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 73}], {
             RGBColor[
             0.31756925587348483`, 0.44924224463119755`, 0.9414650714584689]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 95}], {
             RGBColor[
             0.3973874477451902, 0.5174174988379855, 0.946816060198244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 96}], {
             RGBColor[
             0.3557971492753504, 0.4823533245061042, 0.9439009190224369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 105}], {
             RGBColor[
             0.29764935998569264`, 0.4301787277773499, 0.9402620627671929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[
             0.3171012005840623, 0.44883683866464263`, 0.941435247389312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 149}], {
             RGBColor[
             0.30003867844943893`, 0.43269005297428764`, 0.9403981309190235]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 171}], {
             RGBColor[
             0.3622408475068787, 0.48793453204456394`, 0.9443115057758112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 245}], {
             RGBColor[
             0.36526550488349396`, 0.49055433824048805`, 0.9445042342692497]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 289}], {
             RGBColor[
             0.2985558278706446, 0.4311314829978179, 0.940313684772242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 298}], {
             RGBColor[
             0.2956902341413986, 0.428119562299244, 0.9401504934486273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 69}], {
             RGBColor[
             0.8794778029545246, 0.44615247294289756`, 0.27411524595287656`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 113}], {
             RGBColor[
             0.8682682293963724, 0.4400627275787366, 0.4307769881568413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 135}], {
             RGBColor[
             0.8784970455730444, 0.4470374784660281, 0.38418003276278484`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 224}], {
             RGBColor[
             0.8716400377324648, 0.4199339774417696, 0.22494899798707987`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 249}], {
             RGBColor[
             0.8213251225622646, 0.16491981350766619`, 0.16805426748989288`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 254}], {
             RGBColor[
             0.8455724370335723, 0.3167800316408471, 0.18992199194947013`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 288}], {
             RGBColor[
             0.8357655046599107, 0.272249042199298, 0.18173884718697714`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 19}], {
             RGBColor[
             0.265094966907718, 0.3959619965846625, 0.938408138241311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 49}], {
             RGBColor[
             0.2377386487348052, 0.36720877169417954`, 0.9368502363914097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 57}], {
             RGBColor[
             0.2429878777602664, 0.3727260442202823, 0.9371491722188713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 89}], {
             RGBColor[
             0.2585276184343561, 0.3890592969452162, 0.9380341374612745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 111}], {
             RGBColor[
             0.2409685800879815, 0.3706036343358437, 0.9370341762037178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.2455681044594148, 0.3754380260769088, 0.9372961123122845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 115}], {
             RGBColor[
             0.230257062183032, 0.3593451498682808, 0.9364241711053016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 146}], {
             RGBColor[
             0.2346866767510397, 0.3640009556330419, 0.9366764311019222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 175}], {
             RGBColor[
             0.2667169814547302, 0.3976668367152345, 0.9385005095702079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 212}], {
             RGBColor[
             0.22532179004368708`, 0.3541578659355026, 0.9361431146580468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 242}], {
             RGBColor[
             0.23967759230185604`, 0.3692467243192726, 0.9369606563591433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 243}], {
             RGBColor[
             0.2285446981366219, 0.35754534668535254`, 0.9363266545060742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 280}], {
             RGBColor[
             0.2534905697092152, 0.38376503936775813`, 0.9377472849880235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 294}], {
             RGBColor[
             0.2244101664519819, 0.3531996917403464, 0.9360911990431254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.9540665099241967, 0.9616166407194549, 0.7611949655148192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 44}], {
             RGBColor[
             0.9792628131880576, 0.9411137160345208, 0.4247070629331663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 53}], {
             RGBColor[
             0.8856428670516149, 0.492740358709744, 0.2955672298628224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 59}], {
             RGBColor[
             0.8863635577181508, 0.4982799029814027, 0.2962573640590009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 94}], {
             RGBColor[
             0.9277097420952534, 0.9406004694880592, 0.7586810334703302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 124}], {
             RGBColor[
             0.9705820834138202, 0.9744763977304486, 0.7520461602492186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 125}], {
             RGBColor[
             0.9930477640549809, 0.9875381952295093, 0.4846702054906215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 150}], {
             RGBColor[
             0.9777383321225639, 0.9798135163001478, 0.7399324978339024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 170}], {
             RGBColor[
             0.8790857472699829, 0.44233946271991065`, 0.2892881245547241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 192}], {
             RGBColor[
             0.9078142124160141, 0.6493576356683792, 0.31625810704792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 195}], {
             RGBColor[
             0.8772526257012466, 0.4282492870636099, 0.2875327252702875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 200}], {
             RGBColor[
             0.939733161025506, 0.7818290973952341, 0.3786259847113931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 295}], {
             RGBColor[
             0.9153775706767935, 0.9307671307468549, 0.7575047799513781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 30}], {
             RGBColor[
             0.37921039896007874`, 0.5014757039177918, 0.9454929485539587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 38}], {
             RGBColor[
             0.3570833446280458, 0.48255148540021425`, 0.944016408991876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[
             0.2753301177357401, 0.4067197890509576, 0.9389910149394182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 48}], {
             RGBColor[
             0.35495264897954515`, 0.4807059839213601, 0.9438806429492537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 55}], {
             RGBColor[
             0.28645859801019335`, 0.41841652740581015`, 0.939624765427937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 84}], {
             RGBColor[
             0.2984201886260963, 0.4309889175517728, 0.9403059603179251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 90}], {
             RGBColor[
             0.3498844311553243, 0.4763161483780546, 0.9435577005911434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 97}], {
             RGBColor[
             0.27685141165294697`, 0.4083187654135474, 0.9390776503774505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 134}], {
             RGBColor[
             0.2851115833841571, 0.4170007296281859, 0.9395480549377139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 144}], {
             RGBColor[
             0.3059659418661292, 0.4382761603632087, 0.940759253289231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 158}], {
             RGBColor[
             0.34992722478314753`, 0.47635321406760484`, 0.9435604273632674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 159}], {
             RGBColor[
             0.2718080646722995, 0.4030178879702195, 0.9387904392278659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 175}], {
             RGBColor[
             0.29536678813966943`, 0.42777960004376564`, 0.9401320736773244]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 235}], {
             RGBColor[
             0.2691307812557516, 0.40020389334985473`, 0.9386379718979794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 252}], {
             RGBColor[
             0.29837684649391727`, 0.43094336222280266`, 0.9403034920476165]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 253}], {
             RGBColor[
             0.2964738820674033, 0.42894322595562323`, 0.9401951210387102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 292}], {
             RGBColor[
             0.26964195081094916`, 0.4007411649623891, 0.9386670822479402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 24}], {
             RGBColor[
             0.9510187529148094, 0.9629904466400717, 0.9677966543467089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 36}], {
             RGBColor[
             0.8529859949186596, 0.8858242206407632, 0.9761422011869598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 66}], {
             RGBColor[
             0.9464282973427488, 0.95956689239061, 0.9755670982476465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 69}], {
             RGBColor[
             0.9697193647682323, 0.9735318279786378, 0.7296111092370301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 88}], {
             RGBColor[
             0.7253109400374347, 0.7839674018676228, 0.9648635309809819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 113}], {
             RGBColor[
             0.9529050044310041, 0.9643972099323963, 0.9646037225429771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 135}], {
             RGBColor[
             0.9682482286960121, 0.9748593362633335, 0.8947082894518925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.7053280385373079, 0.7677443822103661, 0.9632904037751118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 222}], {
             RGBColor[
             0.6912666998914337, 0.7558621322945974, 0.9623123726675136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.9579627169351427, 0.9342040847269458, 0.6558617372883351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 254}], {
             RGBColor[
             0.918861315886804, 0.779473166025562, 0.6033212282319205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 258}], {
             RGBColor[
             0.9540838776271092, 0.9652764116318238, 0.9626081977213435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 260}], {
             RGBColor[
             0.8977772500782942, 0.9210512580678571, 0.980544009200409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 278}], {
             RGBColor[
             0.7746661157384185, 0.8240361569270088, 0.968748951206129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 288}], {
             RGBColor[
             0.890067649625568, 0.630386800626602, 0.46285742186084555`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 290}], {
             RGBColor[
             0.7796647191738186, 0.8280942483803853, 0.9691424595790514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 48}], {
             RGBColor[
             0.3524750293077462, 0.47810184855613913`, 0.9437395461742546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 49}], {
             RGBColor[
             0.26391083574794544`, 0.39471739965748975`, 0.9383407037235271]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 57}], {
             RGBColor[
             0.2691600647734066, 0.40023467218359243`, 0.9386396395509886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 84}], {
             RGBColor[
             0.2959425689542974, 0.42838478218655185`, 0.940164863542926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 89}], {
             RGBColor[
             0.28469980544749635`, 0.41656792490852634`, 0.9395246047933918]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 111}], {
             RGBColor[
             0.2671407671011217, 0.39811226229915386`, 0.9385246435358352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 112}], {
             RGBColor[
             0.271740291472555, 0.402946654040219, 0.9387865796444018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 158}], {
             RGBColor[
             0.3474496051113486, 0.47374907870238386`, 0.9434193305882683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 175}], {
             RGBColor[
             0.2928891684678705, 0.42517546467854467`, 0.9399909769023254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 177}], {
             RGBColor[
             0.3552373943929633, 0.4804944703524481, 0.9439155616348212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 242}], {
             RGBColor[
             0.26584977931499626`, 0.39675535228258274`, 0.9384511236912607]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 253}], {
             RGBColor[
             0.2939962623956044, 0.42633909059040226`, 0.940054024263711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 280}], {
             RGBColor[
             0.2796627567223554, 0.4112736673310683, 0.939237752320141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 33}], {
             RGBColor[
             0.8902842568405922, 0.9153525165550513, 0.9893973012552358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 37}], {
             RGBColor[
             0.7733043134332283, 0.8232016433411387, 0.9779409081787471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 75}], {
             RGBColor[
             0.7982091276425176, 0.8426574734850338, 0.980423187310408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 124}], {
             RGBColor[
             0.9067998303302157, 0.928212273566045, 0.9802484959896351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 142}], {
             RGBColor[
             0.7624648027643098, 0.8147337352232472, 0.9768605270562558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 150}], {
             RGBColor[
             0.9139560790389594, 0.9335493921357441, 0.968134833574319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 167}], {
             RGBColor[
             0.8099161582263048, 0.8518030947538164, 0.981590034710579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 185}], {
             RGBColor[
             0.7169880778773853, 0.7780689639663625, 0.973105894503761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 200}], {
             RGBColor[
             0.8759509079419014, 0.7355649732308305, 0.6068283204518097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 237}], {
             RGBColor[
             0.752342583517374, 0.8067713443472341, 0.9758891306955624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 282}], {
             RGBColor[
             0.9147814478549319, 0.9341649508472791, 0.9667376994595409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 283}], {
             RGBColor[
             0.7423144926570131, 0.7986300884264481, 0.9750996826489275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 295}], {
             RGBColor[
             0.851595317593189, 0.8845030065824513, 0.9857071156917947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 297}], {
             RGBColor[
             0.8131524423226874, 0.8543313044865806, 0.981912597264512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 34}], {
             RGBColor[
             0.3554769401154252, 0.48231799156263766`, 0.943871654181607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 46}], {
             RGBColor[
             0.3377964064979223, 0.4654684905987692, 0.942801288807799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 50}], {
             RGBColor[
             0.3679518676107426, 0.4931231467509946, 0.9446665455304635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[
             0.32978099166431396`, 0.45704378140199375`, 0.9423448227907686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 101}], {
             RGBColor[
             0.4650224715635836, 0.5746682645420044, 0.9515515525742121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 108}], {
             RGBColor[
             0.3636875531699619, 0.4894296119130661, 0.9443948271850822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[
             0.3439329379247541, 0.47191837420693394`, 0.9431507551943723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 169}], {
             RGBColor[
             0.33823987120783705`, 0.46593460012617627`, 0.9428265434669814]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 187}], {
             RGBColor[
             0.3736920911272321, 0.49809503984895503`, 0.9450323074970538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 205}], {
             RGBColor[
             0.4564507498978377, 0.5677093547420913, 0.9508767552454336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 213}], {
             RGBColor[
             0.40566670523630644`, 0.5257898434994019, 0.9470697016340429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 264}], {
             RGBColor[
             0.339057995027486, 0.46679450013267343`, 0.9428731344082046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 61}], {
             RGBColor[
             0.6921091843567939, 0.7582433580431021, 0.9707375877325777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 72}], {
             RGBColor[
             0.7345932590636062, 0.7925891041868212, 0.9741810489653038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 177}], {
             RGBColor[
             0.6182933062719121, 0.6973901264603323, 0.9651824367082749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 217}], {
             RGBColor[
             0.812207338591908, 0.8532218130031827, 0.981916895067874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 247}], {
             RGBColor[
             0.6982336123573278, 0.7632154445962727, 0.9712197251392987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 267}], {
             RGBColor[
             0.642613111904264, 0.7180602166534845, 0.966841075599027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 271}], {
             RGBColor[
             0.8974219616748091, 0.8964540242042457, 0.6746941771749546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 273}], {
             RGBColor[
             0.717607033402136, 0.7789436605631201, 0.9727448718111256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 274}], {
             RGBColor[
             0.8909772154370372, 0.8747143818458635, 0.6496575550294168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 285}], {
             RGBColor[
             0.6000751622710249, 0.6816104857973055, 0.9640215926822105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[
             0.29610769611833376`, 0.428558341305621, 0.9401742672906341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 180}], {
             RGBColor[
             0.26520012614906696`, 0.3960725256148013, 0.9384141269045367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 267}], {
             RGBColor[
             0.3821106817559689, 0.50384843174461, 0.9457196175325961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 285}], {
             RGBColor[
             0.33957273212272987`, 0.46739870088843105`, 0.9429001346157797]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.7969254295463191, 0.8418022649015016, 0.9623206130704325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 113}], {
             RGBColor[
             0.9575230369172714, 0.9678413309993203, 0.9567865981194988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 135}], {
             RGBColor[
             0.9728662611822794, 0.9783034573302576, 0.8868911650284141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 224}], {
             RGBColor[
             0.9625807494214099, 0.9376482057938698, 0.6480446128648567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 233}], {
             RGBColor[
             0.9748626422338834, 0.9780993949460502, 0.7789636593832132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 254}], {
             RGBColor[
             0.9234793483730712, 0.7829172870924861, 0.5955041038084421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 259}], {
             RGBColor[
             0.7099488174717532, 0.7711907329676471, 0.9554734955620947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 260}], {
             RGBColor[
             0.9023952825645615, 0.924495379134781, 0.9727268847769307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 288}], {
             RGBColor[
             0.8931463379497462, 0.6326828813378846, 0.45764600557852664`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 29}], {
             RGBColor[
             0.24731665325336327`, 0.3772758617237455, 0.9373956895793536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[
             0.2869920462831278, 0.4177357289024586, 0.9397006014188156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 77}], {
             RGBColor[
             0.24892138027318342`, 0.37896253156714604`, 0.9374870764091515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 91}], {
             RGBColor[
             0.2622113968861681, 0.3929311816631146, 0.9382439231944433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 139}], {
             RGBColor[
             0.25364452897953216`, 0.38392686032244283`, 0.9377560527407058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 147}], {
             RGBColor[
             0.2390014851721345, 0.36853609285826733`, 0.9369221530583165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 148}], {
             RGBColor[
             0.24531191831194143`, 0.3751687581927745, 0.9372815228901793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 172}], {
             RGBColor[
             0.2606528759791422, 0.3912930773738975, 0.9381551677344133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 203}], {
             RGBColor[
             0.2557021473412196, 0.3860895476811155, 0.9378732310624303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 206}], {
             RGBColor[
             0.2442420605634609, 0.3740442698662223, 0.937220596074116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 244}], {
             RGBColor[
             0.2471607788887478, 0.37711202788352904`, 0.9373868127648843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 270}], {
             RGBColor[
             0.24003287271686014`, 0.3696201465615213, 0.9369808890531874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 272}], {
             RGBColor[
             0.23754533151077184`, 0.36700558303470066`, 0.9368392272614883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 39}], {
             RGBColor[
             0.906966804332385, 0.6570560107325126, 0.4355903940965794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 59}], {
             RGBColor[
             0.8838184335640263, 0.4982693458810795, 0.4141730352036101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 60}], {
             RGBColor[
             0.9559587194852852, 0.8665294960501166, 0.5718984085520893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 62}], {
             RGBColor[
             0.9903418616011138, 0.9899003526601282, 0.7825545152346283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 82}], {
             RGBColor[
             0.9904558326619474, 0.9901441252350094, 0.7949595618585049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[
             0.8953985506349588, 0.587279200127923, 0.4252621683886066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 127}], {
             RGBColor[
             0.8837930596964858, 0.49807431121626294`, 0.4141487371593976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 130}], {
             RGBColor[
             0.5823809948253185, 0.6469022092217233, 0.9089577047840149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 137}], {
             RGBColor[
             0.8923224675531893, 0.5636350776132415, 0.42231650775556523`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 170}], {
             RGBColor[
             0.8765406231158585, 0.4423289056195874, 0.40720379569933324`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 192}], {
             RGBColor[
             0.9052690882618898, 0.649347078568056, 0.4341737781925292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 195}], {
             RGBColor[
             0.8747075015471222, 0.4282387299632868, 0.4054483964148967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 199}], {
             RGBColor[
             0.5823809948253185, 0.6469022092217233, 0.9089577047840149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 220}], {
             RGBColor[
             0.6215133643769486, 0.6880328107560196, 0.9111862353388274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 226}], {
             RGBColor[
             0.5823809999360594, 0.646902214593436, 0.908957705075064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 228}], {
             RGBColor[
             0.901089116284713, 0.9224316156704129, 0.933371766463492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 266}], {
             RGBColor[
             0.6167344718352826, 0.6830098916954412, 0.9109140844783175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 32}], {
             RGBColor[
             0.25734797909016266`, 0.3878194212010146, 0.9379669587457427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 103}], {
             RGBColor[
             0.2686276829189324, 0.3996751050995809, 0.9386093211919647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 119}], {
             RGBColor[
             0.2703316084942079, 0.40146603891431676`, 0.9387063572327446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 152}], {
             RGBColor[
             0.2558672975304459, 0.3862631310011191, 0.9378826361213889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 268}], {
             RGBColor[
             0.2604774227946408, 0.3911086649526121, 0.9381451759351156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 35}], {
             RGBColor[
             0.2248219115083478, 0.35363246190073133`, 0.9361146473149633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 126}], {
             RGBColor[
             0.22467560955270433`, 0.3534786892692703, 0.9361063156350238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 163}], {
             RGBColor[
             0.23238600045450547`, 0.3615827989740821, 0.9365454109903801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 184}], {
             RGBColor[
             0.23042487690337662`, 0.35952153377943086`, 0.9364337279053656]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 189}], {
             RGBColor[
             0.22763054758381063`, 0.35658451649385525`, 0.9362745949844562]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 197}], {
             RGBColor[
             0.21695644286649302`, 0.3453653556586265, 0.9356667205117277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 211}], {
             RGBColor[
             0.2328859592843117, 0.3621082874034291, 0.9365738829061148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 216}], {
             RGBColor[
             0.24112529640186797`, 0.3707683531181266, 0.9370431009659527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 275}], {
             RGBColor[
             0.21809561015053047`, 0.3465626927015274, 0.9357315944033067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 293}], {
             RGBColor[
             0.21633697828784162`, 0.3447142591101412, 0.9356314429203892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 77}], {
             RGBColor[
             0.2444276826034072, 0.3742393703993229, 0.9372311669746878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 91}], {
             RGBColor[
             0.25771769921639187`, 0.38820802049529146`, 0.9379880137599795]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 148}], {
             RGBColor[
             0.2408182206421652, 0.3704455970249514, 0.9370256134557156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 162}], {
             RGBColor[
             0.2636748497853562, 0.39446936344843425`, 0.9383272646720675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 172}], {
             RGBColor[
             0.256159178309366, 0.3865699162060744, 0.9378992582999495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 191}], {
             RGBColor[
             0.24335597488348387`, 0.37311293763548947`, 0.9371701348054876]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 203}], {
             RGBColor[
             0.25120844967144335`, 0.38136638651329235`, 0.9376173216279664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 206}], {
             RGBColor[
             0.23974836289368467`, 0.3693211086983992, 0.9369646866396522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 244}], {
             RGBColor[
             0.24266708121897157`, 0.3723888667157059, 0.9371309033304205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 270}], {
             RGBColor[
             0.2355391750470839, 0.3648969853936982, 0.9367249796187237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 272}], {
             RGBColor[
             0.23305163384099561`, 0.36228242186687754`, 0.9365833178270244]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 38}], {
             RGBColor[
             0.4400713503236684, 0.5553482940395915, 0.949328558422408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 47}], {
             RGBColor[
             0.5531290988592262, 0.6480680925121483, 0.9579813085710855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 48}], {
             RGBColor[
             0.43794065467516774`, 0.5535027925607373, 0.9491927923797858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 74}], {
             RGBColor[
             0.5502062391736314, 0.6457212373265883, 0.9577333971010626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 90}], {
             RGBColor[
             0.4328724368509469, 0.5491129570174318, 0.9488698500216755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 123}], {
             RGBColor[
             0.44920952472312525`, 0.5632633214064009, 0.9499108348145711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 144}], {
             RGBColor[
             0.3889539475617518, 0.5110729690025859, 0.9460714027197632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 158}], {
             RGBColor[
             0.4329152304787701, 0.5491500227069821, 0.9488725767937995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 252}], {
             RGBColor[
             0.38136485218953986`, 0.5037401708621798, 0.9456156414781487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 257}], {
             RGBColor[
             0.42675186290096767`, 0.5438116234909512, 0.9484798524617939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 259}], {
             RGBColor[
             0.46322962709906557`, 0.5751097053927338, 0.9508862795927249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 36}], {
             RGBColor[
             0.6892039970441424, 0.7567703364683878, 0.9699034319627848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 51}], {
             RGBColor[
             0.8061994237416004, 0.8465221719044482, 0.8597460281820752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 58}], {
             RGBColor[
             0.583879953556761, 0.6730590756463584, 0.9603843152481828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 66}], {
             RGBColor[
             0.7826462994682315, 0.8305130082182347, 0.9693283290234715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 67}], {
             RGBColor[
             0.765577527957654, 0.8171802233035855, 0.9773175856314692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 73}], {
             RGBColor[
             0.47392342433375345`, 0.580416161461158, 0.9526607261917457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 95}], {
             RGBColor[
             0.5537416162054588, 0.648591415667946, 0.9580117149315208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 96}], {
             RGBColor[
             0.512151317735619, 0.6135272413360646, 0.9550965737557137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 109}], {
             RGBColor[
             0.7700026915435176, 0.8207087286290875, 0.9777396616846791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 110}], {
             RGBColor[
             0.8058913506986181, 0.8463947757840589, 0.8648515957717691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 138}], {
             RGBColor[
             0.662760313991049, 0.7361123302878763, 0.9672677727663206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 154}], {
             RGBColor[
             0.6800184039631393, 0.7495944813404151, 0.9689878978887183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 171}], {
             RGBColor[
             0.5185950159671473, 0.6191084488745244, 0.955507160509088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 245}], {
             RGBColor[
             0.5216196733437626, 0.6217282550704486, 0.9556998890025264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 156}], {
             RGBColor[
             0.24197823755521267`, 0.3716648483498845, 0.9370916747028223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 178}], {
             RGBColor[
             0.2666569110282901, 0.3976036988883609, 0.9384970886482884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 182}], {
             RGBColor[
             0.2817202883828383, 0.4134362635612778, 0.9393549257043601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 202}], {
             RGBColor[
             0.24218926046257408`, 0.37188664680514644`, 0.937103692145216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 208}], {
             RGBColor[
             0.27110861374646283`, 0.402282720699415, 0.9387506065323843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 268}], {
             RGBColor[
             0.2593869141835333, 0.38996247126009875`, 0.938083073082976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 37}], {
             RGBColor[
             0.7976827143280194, 0.8426403184805812, 0.9802661418189477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 75}], {
             RGBColor[
             0.8225875285373088, 0.8620961486244765, 0.9827484209506085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 94}], {
             RGBColor[
             0.8883058899064401, 0.9137750204630982, 0.9892086028509474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 124}], {
             RGBColor[
             0.931178231225007, 0.9476509487054876, 0.9825737296298357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 142}], {
             RGBColor[
             0.7868432036591011, 0.8341724103626897, 0.9791857606964562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 150}], {
             RGBColor[
             0.9383344799337505, 0.9529880672751867, 0.9704600672145196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 185}], {
             RGBColor[
             0.7413664787721765, 0.7975076391058051, 0.9754311281439616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 200}], {
             RGBColor[
             0.9003293088366926, 0.7550036483702731, 0.6091535540920102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 237}], {
             RGBColor[
             0.7767209844121652, 0.8262100194866766, 0.9782143643357628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 239}], {
             RGBColor[
             0.6628984653958889, 0.7326583838158534, 0.9695703125580974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 282}], {
             RGBColor[
             0.9391598487497231, 0.9536036259867218, 0.9690629330997416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 295}], {
             RGBColor[
             0.8759737184879801, 0.9039416817218939, 0.9880323493319954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 297}], {
             RGBColor[
             0.8375308432174786, 0.8737699796260231, 0.9842378309047126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 46}], {
             RGBColor[
             0.30981865996121394`, 0.44123557275110054`, 0.9410185715382298]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 50}], {
             RGBColor[
             0.33997412107403424`, 0.46889022890332593`, 0.9428838282608942]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 87}], {
             RGBColor[
             0.3018032451276056, 0.4328108635543251, 0.9405621055211995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 108}], {
             RGBColor[
             0.3357098066332535, 0.46519669406539743`, 0.9426121099155129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 114}], {
             RGBColor[
             0.31595519138804573`, 0.44768545635926527`, 0.9413680379248031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 169}], {
             RGBColor[
             0.3102621246711287, 0.4417016822785076, 0.9410438261974121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 187}], {
             RGBColor[
             0.34571434459052375`, 0.47386212200128636`, 0.9432495902274847]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 205}], {
             RGBColor[
             0.4284730033611293, 0.5434764368944227, 0.9490940379758643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 213}], {
             RGBColor[
             0.37768895869959807`, 0.5015569256517332, 0.9452869843644738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 227}], {
             RGBColor[
             0.2936321912026204, 0.4242225678044243, 0.9400967760881624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 264}], {
             RGBColor[
             0.31108024849077764`, 0.44256158228500475`, 0.9410904171386354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 92}], {
             RGBColor[
             0.24366421330036392`, 0.37343691575507476`, 0.9371876885273311]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 126}], {
             RGBColor[
             0.2260848753293333, 0.35495991695311835`, 0.9361865712361809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 163}], {
             RGBColor[
             0.23379526623113445`, 0.36306402665793014`, 0.9366256665915373]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 184}], {
             RGBColor[
             0.23183414268000563`, 0.3610027614632789, 0.9365139835065228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 189}], {
             RGBColor[
             0.2290398133604396, 0.3580657441777033, 0.9363548505856133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 197}], {
             RGBColor[
             0.218365708643122, 0.3468465833424746, 0.9357469761128849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 211}], {
             RGBColor[
             0.2342952250609407, 0.36358951508727716`, 0.936654138507272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 216}], {
             RGBColor[
             0.24253456217849695`, 0.3722495808019747, 0.9371233565671098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 275}], {
             RGBColor[
             0.21950487592715945`, 0.34804392038537546`, 0.9358118500044639]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 58}], {
             RGBColor[
             0.6542472259213957, 0.728390854886349, 0.9671515068891303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 66}], {
             RGBColor[
             0.8530135718328662, 0.8858447874582254, 0.9760955206644191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 67}], {
             RGBColor[
             0.8359448003222887, 0.8725120025435762, 0.9840847772724168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 69}], {
             RGBColor[
             0.8763046392583498, 0.8998097230462532, 0.7301395316538027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 88}], {
             RGBColor[
             0.6318962145275521, 0.7102452969352381, 0.9653919533977545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 95}], {
             RGBColor[
             0.6241088885700935, 0.7039231949079366, 0.9647789065724686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 96}], {
             RGBColor[
             0.5825185901002536, 0.6688590205760554, 0.9618637653966613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 109}], {
             RGBColor[
             0.8403699639081523, 0.8760405078690783, 0.9845068533256267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 113}], {
             RGBColor[
             0.8594902789211216, 0.8906751050000117, 0.9651321449597499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 138}], {
             RGBColor[
             0.7331275863556836, 0.791444109527867, 0.9740349644072682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 154}], {
             RGBColor[
             0.750385676327774, 0.8049262605804057, 0.9757550895296658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 198}], {
             RGBColor[
             0.6119133130274254, 0.6940222772779814, 0.9638188261918845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 222}], {
             RGBColor[
             0.5978519743815511, 0.6821400273622127, 0.9628407950842862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 224}], {
             RGBColor[
             0.8645479914252601, 0.8604819797945611, 0.6563901597051076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 245}], {
             RGBColor[
             0.5919869457083973, 0.6770600343104392, 0.9624670806434741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 258}], {
             RGBColor[
             0.8606691521172266, 0.8915543066994391, 0.9631366201381162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 260}], {
             RGBColor[
             0.8043625245684116, 0.8473291531354724, 0.9810724316171817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 278}], {
             RGBColor[
             0.681251390228536, 0.7503140519946241, 0.9692773736229017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 290}], {
             RGBColor[
             0.6862499936639361, 0.7543721434480005, 0.9696708819958241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 75}], {
             RGBColor[
             0.7056075851299448, 0.7699452754105638, 0.9712920278741198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 94}], {
             RGBColor[
             0.771325946499076, 0.8216241472491855, 0.9777522097744586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 102}], {
             RGBColor[
             0.5330127818666326, 0.6293292071697167, 0.9572915771331396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 124}], {
             RGBColor[
             0.8141982878176429, 0.8555000754915749, 0.971117336553347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 142}], {
             RGBColor[
             0.669863260251737, 0.742021537148777, 0.9677293676199676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 150}], {
             RGBColor[
             0.8213545365263866, 0.860837194061274, 0.9590036741380308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 185}], {
             RGBColor[
             0.6243865353648125, 0.7053567658918924, 0.9639747350674728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 237}], {
             RGBColor[
             0.6597410410048012, 0.7340591462727639, 0.9667579712592742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 239}], {
             RGBColor[
             0.5459185219885249, 0.6405075106019407, 0.9581139194816087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 282}], {
             RGBColor[
             0.8221799053423591, 0.8614527527728091, 0.9576065400232527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 283}], {
             RGBColor[
             0.6497129501444403, 0.725917890351978, 0.9659685232126394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 295}], {
             RGBColor[
             0.7589937750806162, 0.8117908085079812, 0.9765759562555065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 297}], {
             RGBColor[
             0.7205508998101146, 0.7816191064121104, 0.9727814378282238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 48}], {
             RGBColor[
             0.41581360034313486`, 0.5345785740431597, 0.947716252817703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 55}], {
             RGBColor[
             0.34731954937378307`, 0.4722891175276097, 0.9434603752963864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 74}], {
             RGBColor[
             0.5280791848415985, 0.6267970188090106, 0.9562568575389798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 90}], {
             RGBColor[
             0.41074538251891396`, 0.5301887384998543, 0.9473933104595927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 123}], {
             RGBColor[
             0.4270824703910924, 0.5443391028888234, 0.9484342952524883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 144}], {
             RGBColor[
             0.36682689322971884`, 0.49214875048500833`, 0.9445948631576804]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 158}], {
             RGBColor[
             0.41078817614673724`, 0.5302258041894045, 0.9473960372317167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 252}], {
             RGBColor[
             0.3592377978575069, 0.4848159523446023, 0.9441391019160659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 253}], {
             RGBColor[
             0.35733483343099304`, 0.48281581607742285`, 0.9440307309071595]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 257}], {
             RGBColor[
             0.4046248085689348, 0.5248874049733736, 0.9470033128997111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 259}], {
             RGBColor[
             0.44110257276703263`, 0.5561854868751561, 0.949409740030642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 52}], {
             RGBColor[
             0.8509244806797601, 0.37329159396524664`, 0.19564909915374373`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 59}], {
             RGBColor[
             0.8559585262890798, 0.41198547445132916`, 0.20046970691436952`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 60}], {
             RGBColor[
             0.8870492908888172, 0.5758020624702928, 0.22724639341928574`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 62}], {
             RGBColor[
             0.909971385632703, 0.6580493002103005, 0.3676837978743117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 82}], {
             RGBColor[
             0.9100473663399253, 0.6582118152602212, 0.3759538289568961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 100}], {
             RGBColor[
             0.861748584824546, 0.4564904015747509, 0.20601427350686777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 107}], {
             RGBColor[
             0.8564041483183775, 0.41541072064133033`, 0.20089643507288318`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 127}], {
             RGBColor[
             0.8559458393553094, 0.41188795711892084`, 0.20045755789226324`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 136}], {
             RGBColor[
             0.9093243643754532, 0.6566653871649271, 0.29725952697501445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 137}], {
             RGBColor[
             0.8602105432836612, 0.44466834031741015`, 0.20454144319034706`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 141}], {
             RGBColor[
             0.8780226232767818, 0.5390110454875421, 0.21993142573409608`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 170}], {
             RGBColor[
             0.8523196210649958, 0.3840152543205831, 0.1969850871622311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 192}], {
             RGBColor[
             0.8666838536380115, 0.4875243407948174, 0.2104700784088291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 220}], {
             RGBColor[
             0.6640857208165928, 0.4568042722742281, 0.4534382779437778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 228}], {
             RGBColor[
             0.8504695554217692, 0.6130701422171569, 0.46822863202688747`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 232}], {
             RGBColor[
             0.9097206544990011, 0.6575130116681185, 0.3403932613040548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 266}], {
             RGBColor[
             0.6608997924554822, 0.45345565956717576`, 0.45325684403677113`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 281}], {
             RGBColor[
             0.8570472727010972, 0.420354056465815, 0.2015122917080806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.2625645345612948, 0.39330235174989453`, 0.9382640338626215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.25252112623098183`, 0.38274609280586824`, 0.9376920766161012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 162}], {
             RGBColor[
             0.2608696072714334, 0.3915208757036531, 0.9381675102608841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 191}], {
             RGBColor[
             0.24055073236956107`, 0.37016444989070835`, 0.9370103803943042]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 76}], {
             RGBColor[
             0.32564319585170254`, 0.45514146543527656`, 0.9420195932129798]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.4306059655104517, 0.5460088371370204, 0.9490406986812941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 99}], {
             RGBColor[
             0.362239582391498, 0.48817545240188814`, 0.9443025637674687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 104}], {
             RGBColor[
             0.3210313076505878, 0.45029407852530423`, 0.9417569530026035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 157}], {
             RGBColor[
             0.35148560431038395`, 0.4788608970986815, 0.9436173297935095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 201}], {
             RGBColor[
             0.3390519049385823, 0.4680914516387281, 0.942825065464227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 209}], {
             RGBColor[
             0.3110735460011261, 0.43982783967316585`, 0.9411898732078549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 222}], {
             RGBColor[
             0.3965617253644508, 0.517903567563995, 0.9464895403678258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 229}], {
             RGBColor[
             0.35168976097882576`, 0.47903772734367334`, 0.943630338475894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 259}], {
             RGBColor[
             0.41062581045850305`, 0.5297880471701207, 0.9474677876858852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 261}], {
             RGBColor[
             0.3788160778841355, 0.5025331796387221, 0.9453588034022401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 278}], {
             RGBColor[
             0.4799611412114356, 0.5860775921964064, 0.9529261189064413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 290}], {
             RGBColor[
             0.4849597446468357, 0.5901356836497829, 0.9533196272793637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 55}], {
             RGBColor[
             0.2655663224814774, 0.39645742117835314`, 0.9384349812439285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[
             0.25595913612423093`, 0.3863596591860904, 0.937887866193442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 134}], {
             RGBColor[
             0.26421930785544107`, 0.3950416234007289, 0.9383582707537054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 144}], {
             RGBColor[
             0.28507366633741316`, 0.4163170541357517, 0.9395694691052225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 159}], {
             RGBColor[
             0.2509157891435835, 0.3810587817427625, 0.9376006550438574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 235}], {
             RGBColor[
             0.24823850572703557`, 0.37824478712239773`, 0.9374481877139709]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 252}], {
             RGBColor[
             0.2774845709652012, 0.40898425599534566`, 0.939113707863608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 292}], {
             RGBColor[
             0.24874967528223313`, 0.3787820587349321, 0.9374772980639317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 63}], {
             RGBColor[
             0.3233435154432426, 0.45448563418447746`, 0.9418241407759673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 131}], {
             RGBColor[
             0.3235024771639835, 0.45462331883733487`, 0.9418342696762487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 139}], {
             RGBColor[
             0.2888262243395204, 0.4196635663333328, 0.9398050551457039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 143}], {
             RGBColor[
             0.3594618944461463, 0.48576955871427996`, 0.9441255719478039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 172}], {
             RGBColor[
             0.2958345713391305, 0.4270297833847875, 0.9402041701394114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 174}], {
             RGBColor[
             0.35724861486395953`, 0.48385252718285615`, 0.9439845437299532]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 183}], {
             RGBColor[
             0.28838161647063476`, 0.4191962552733669, 0.9397797353853092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 185}], {
             RGBColor[
             0.4451220207260428, 0.5568482607152324, 0.9504446626081502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 244}], {
             RGBColor[
             0.28234247424873604`, 0.412848733894419, 0.9394358151698824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 59}], {
             RGBColor[
             0.8768918584348492, 0.4667276538414726, 0.225617141924977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 60}], {
             RGBColor[
             0.9455688567915195, 0.8192169579907062, 0.28906456863413965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 94}], {
             RGBColor[
             0.9135021931703009, 0.8932720957781641, 0.6527207002692943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 100}], {
             RGBColor[
             0.8884719755057815, 0.5557375080883161, 0.23670627510997347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 121}], {
             RGBColor[
             0.9798326937990873, 0.9423326330377451, 0.48673505054828914`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 124}], {
             RGBColor[
             0.9563745344888678, 0.9271480240205534, 0.6460858270481826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 125}], {
             RGBColor[
             0.9788402151300284, 0.9402098215196141, 0.37870987228958564`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 137}], {
             RGBColor[
             0.8853958924240121, 0.5320933855736346, 0.23376061447693208`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 150}], {
             RGBColor[
             0.9635307831976114, 0.9324851425902525, 0.6339721646328667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 170}], {
             RGBColor[
             0.8696140479866813, 0.4107872135799805, 0.21864790242070015`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 192}], {
             RGBColor[
             0.8983425131327125, 0.6178053865284491, 0.24561788491389613`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 195}], {
             RGBColor[
             0.8677809264179449, 0.3966970379236798, 0.21689250313626357`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 200}], {
             RGBColor[
             0.9255256121005535, 0.7345007236853389, 0.2726656515103572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 256}], {
             RGBColor[
             0.9801516197044022, 0.9430147833008583, 0.5214481671592728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 299}], {
             RGBColor[
             0.979769906119425, 0.942886287709507, 0.5299077867568601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 53}], {
             RGBColor[
             0.849125567438419, 0.37860621505841235`, 0.19467600489941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 68}], {
             RGBColor[
             0.8633379334396346, 0.4711124376416033, 0.20763043303961218`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 195}], {
             RGBColor[
             0.8449304467632349, 0.34636067923534536`, 0.19065875260314252`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 200}], {
             RGBColor[
             0.8672145142441139, 0.4887150856762938, 0.21086514708656048`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 215}], {
             RGBColor[
             0.9035836038900057, 0.6277240751762379, 0.3789421893819883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 223}], {
             RGBColor[
             0.8676674520716839, 0.4907717705649724, 0.21124308951240708`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 225}], {
             RGBColor[
             0.8922034790216946, 0.5903032781532196, 0.23628645255656144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 234}], {
             RGBColor[
             0.84432219426478, 0.3416853839942764, 0.19007628932369913`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 255}], {
             RGBColor[
             0.8915339731689755, 0.5880448777045486, 0.23368554874431965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 282}], {
             RGBColor[
             0.8931015408528009, 0.6211150707539262, 0.45080473309171465`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 287}], {
             RGBColor[
             0.8855408645250941, 0.5648739230601991, 0.22579206001070665`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 50}], {
             RGBColor[
             0.32229358745653136`, 0.4520407279394575, 0.9418134628870861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 108}], {
             RGBColor[
             0.3180292730157506, 0.448347193101529, 0.9415417445417048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 114}], {
             RGBColor[
             0.29827465777054285`, 0.4308359553953969, 0.9402976725509951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 145}], {
             RGBColor[
             0.280670988716232, 0.4123333830822331, 0.9392951696406466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 169}], {
             RGBColor[
             0.2925815910536258, 0.4248521813146391, 0.9399734608236041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 187}], {
             RGBColor[
             0.32803381097302087`, 0.4570126210374179, 0.9421792248536764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 213}], {
             RGBColor[
             0.3600084250820952, 0.48470742468786476`, 0.9442166189906656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 219}], {
             RGBColor[
             0.2831865614508789, 0.4149774095228705, 0.9394384277864284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 221}], {
             RGBColor[
             0.2933757434234066, 0.4256868858074472, 0.9400186866262199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 264}], {
             RGBColor[
             0.29339971487327476`, 0.42571208132113636`, 0.9400200517648274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 48}], {
             RGBColor[
             0.5288713488786927, 0.6272983725157164, 0.9563690029663805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 74}], {
             RGBColor[
             0.6411369333771564, 0.7195168172815674, 0.9649096076876572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 90}], {
             RGBColor[
             0.5238031310544717, 0.622908536972411, 0.9560460606082701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.5238459246822951, 0.6229456026619612, 0.9560487873803941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 166}], {
             RGBColor[
             0.8183915236203407, 0.8543538869413033, 0.7072534135870767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 177}], {
             RGBColor[
             0.5316337139639098, 0.6296909943120255, 0.956545018426947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 217}], {
             RGBColor[
             0.7255477462839056, 0.7855226808548759, 0.9732794767865461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 233}], {
             RGBColor[
             0.8190741460647206, 0.8558139473261162, 0.781552654000438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 262}], {
             RGBColor[
             0.8190197652374052, 0.8556976322352333, 0.77563363654671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 273}], {
             RGBColor[
             0.6309474410941337, 0.7112445284148133, 0.9641074535297975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 74}], {
             RGBColor[
             0.5259484891930979, 0.6249515173301565, 0.9561210914963576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 84}], {
             RGBColor[
             0.35715044434118537`, 0.4830160061947183, 0.9440058041437522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 90}], {
             RGBColor[
             0.4086146868704133, 0.5283432370210001, 0.9472575444169704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 144}], {
             RGBColor[
             0.3646961975812182, 0.4903032490061542, 0.9444590971150582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 158}], {
             RGBColor[
             0.4086574804982366, 0.5283803027105503, 0.9472602711890945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 175}], {
             RGBColor[
             0.3540970438547585, 0.4798066886867111, 0.9438319175031515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 177}], {
             RGBColor[
             0.4164452697798513, 0.5351256943606145, 0.9477565022356473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 217}], {
             RGBColor[
             0.6103593020998471, 0.6909573809034649, 0.9644909605952465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 252}], {
             RGBColor[
             0.35710710220900627`, 0.48297045086574814`, 0.9440033358734436]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 253}], {
             RGBColor[
             0.3552041377824924, 0.4809703145985687, 0.9438949648645372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 57}], {
             RGBColor[
             0.2418037466004938, 0.3714814472931095, 0.9370817377010874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 84}], {
             RGBColor[
             0.2685862507813846, 0.39963155729606886`, 0.9386069616930247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 112}], {
             RGBColor[
             0.24438397329964223`, 0.374193429149736, 0.9372286777945005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 115}], {
             RGBColor[
             0.22907293102325943`, 0.358100552941108, 0.9363567365875176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 146}], {
             RGBColor[
             0.23350254559126715`, 0.3627563587058691, 0.9366089965841382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 159}], {
             RGBColor[
             0.24197412682758776`, 0.3716605277145155, 0.9370914406029653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 175}], {
             RGBColor[
             0.26553285029495766`, 0.3964222397880617, 0.9384330750524239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 204}], {
             RGBColor[
             0.23371861491604712`, 0.3629834612657993, 0.9366213014125385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 242}], {
             RGBColor[
             0.23849346114208345`, 0.3680021273920998, 0.9368932218413593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 243}], {
             RGBColor[
             0.2273605669768493, 0.3563007497581797, 0.9362592199882902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 253}], {
             RGBColor[
             0.2666399442226916, 0.39758586569991927`, 0.9384961224138098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 280}], {
             RGBColor[
             0.2523064385494426, 0.38252044244058536`, 0.9376798504702395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 292}], {
             RGBColor[
             0.23980801296623738`, 0.36938380470668514`, 0.9369680836230397]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 87}], {
             RGBColor[
             0.314278172622923, 0.4436160187426821, 0.9413569968700557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 108}], {
             RGBColor[
             0.3481847341285709, 0.4760018492537544, 0.9434070012643693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 114}], {
             RGBColor[
             0.32843011888336315`, 0.4584906115476223, 0.9421629292736595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 169}], {
             RGBColor[
             0.3227370521664461, 0.4525068374668645, 0.9418387175462686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 187}], {
             RGBColor[
             0.35818927208584117`, 0.4846672771896433, 0.9440444815763409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 205}], {
             RGBColor[
             0.44094793085644673`, 0.5542815920827796, 0.9498889293247207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 213}], {
             RGBColor[
             0.3901638861949155, 0.5123620808400902, 0.94608187571333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 227}], {
             RGBColor[
             0.30610711869793783`, 0.43502772299278125`, 0.9408916674370189]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 264}], {
             RGBColor[
             0.32355517598609507`, 0.45336673747336176`, 0.9418853084874919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 52}], {
             RGBColor[
             0.8763260533964058, 0.4219467076212655, 0.36184562184045305`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 58}], {
             RGBColor[
             0.7712426526188537, 0.8181426903224094, 0.8569941031084208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 66}], {
             RGBColor[
             0.9700089985303242, 0.9755966228942858, 0.8659381168837096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 67}], {
             RGBColor[
             0.9529402270197467, 0.9622638379796367, 0.8739273734917072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 69}], {
             RGBColor[
             0.9933000659558078, 0.9895615584823135, 0.6199821278730931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 86}], {
             RGBColor[
             0.9842148587859489, 0.9592452118717956, 0.5566107984418112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[
             0.8872853886736406, 0.5061849609734328, 0.372340293678732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 109}], {
             RGBColor[
             0.9573653906056103, 0.9657923433051386, 0.8743494495449171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 110}], {
             RGBColor[
             0.9932540497607107, 0.99147839046011, 0.7614613836320072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 138}], {
             RGBColor[
             0.8501230130531416, 0.8811959449639274, 0.8638775606265587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 141}], {
             RGBColor[
             0.9462822846437602, 0.812940654644517, 0.4968966602614467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 154}], {
             RGBColor[
             0.867381103025232, 0.8946780960164662, 0.8655976857489563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 165}], {
             RGBColor[
             0.986911243979133, 0.9683407522697562, 0.5670857457477134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 179}], {
             RGBColor[
             0.993604348606093, 0.9916232480349453, 0.7556560252196713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 258}], {
             RGBColor[
             0.9776645788146846, 0.9813061421354996, 0.8529792163574066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 281}], {
             RGBColor[
             0.88857163743908, 0.5160716326224021, 0.37357200694912684`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 82}], {
             RGBColor[
             0.8768309043529274, 0.4220373894366231, 0.3448952545426753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 86}], {
             RGBColor[
             0.8700945440512431, 0.4003729911487963, 0.2286822767734516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 107}], {
             RGBColor[
             0.8231876863313796, 0.17923629481773212`, 0.16983786065866233`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 110}], {
             RGBColor[
             0.876120671367751, 0.4218617768743392, 0.3652493335669156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 141}], {
             RGBColor[
             0.8448061612897839, 0.30283661966394393`, 0.18887285131987525`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 165}], {
             RGBColor[
             0.8718921341800324, 0.4064366847474367, 0.2356655749773864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 179}], {
             RGBColor[
             0.8763542039313392, 0.42195834859089604`, 0.36137909462535833`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 193}], {
             RGBColor[
             0.6783045969866766, 0.26489364797125753`, 0.42528589032272945`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 236}], {
             RGBColor[
             0.752875562549565, 0.3264079477812045, 0.43088720708168204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 266}], {
             RGBColor[
             0.6276833304684843, 0.2172812337435776, 0.42219826962255025`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 281}], {
             RGBColor[
             0.8238308107140992, 0.18417963064221682`, 0.17045371729385975`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 59}], {
             RGBColor[
             0.8320894648541852, 0.2476592653282373, 0.1783622138252218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 68}], {
             RGBColor[
             0.8459414855221328, 0.3373957157755989, 0.19097157486733474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 150}], {
             RGBColor[
             0.875154847057984, 0.48698797641356506`, 0.4350772976626226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 170}], {
             RGBColor[
             0.8284505596301013, 0.21968904519749122`, 0.17487759407308337`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 192}], {
             RGBColor[
             0.8428147922031168, 0.3231981316717255, 0.18836258531968136`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 195}], {
             RGBColor[
             0.8275339988457331, 0.2126439573693409, 0.17399989443086508`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 200}], {
             RGBColor[
             0.849818066326612, 0.3549983638102894, 0.19420628891428304`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 225}], {
             RGBColor[
             0.8748070311041928, 0.4565865562872151, 0.219627594384284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 234}], {
             RGBColor[
             0.8269257463472781, 0.20796866212827195`, 0.17341743115142172`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 255}], {
             RGBColor[
             0.8741375252514738, 0.45432815583854413`, 0.2170266905720422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 282}], {
             RGBColor[
             0.8757050929352991, 0.4873983488879218, 0.43414587491943724`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 287}], {
             RGBColor[
             0.8681444166075922, 0.43115720119419465`, 0.20913320183842923`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 72}], {
             RGBColor[
             0.534606977221836, 0.6319372303906756, 0.9568737438527076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 106}], {
             RGBColor[
             0.5370375913061106, 0.6338360445866622, 0.9571160047492481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 151}], {
             RGBColor[
             0.4303399784091667, 0.5471605926069658, 0.9486418607828988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 167}], {
             RGBColor[
             0.585666437251012, 0.671825268631737, 0.9619628736506332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 194}], {
             RGBColor[
             0.4666198015964266, 0.5768869180196359, 0.9514225850947327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 238}], {
             RGBColor[
             0.34796050319161576`, 0.47301253149465217`, 0.9434950557775005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 251}], {
             RGBColor[
             0.3520600889143901, 0.4773214560180356, 0.9437285211196189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 286}], {
             RGBColor[
             0.4882211414959945, 0.5944238588793778, 0.953123121699942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 90}], {
             RGBColor[
             0.3401206359010615, 0.4660537805054501, 0.9430016668956538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 97}], {
             RGBColor[
             0.26708761639868417`, 0.39805639754094285`, 0.9385216166819608]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 134}], {
             RGBColor[
             0.27534778812989436`, 0.40673836175558137`, 0.9389920212422243]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 144}], {
             RGBColor[
             0.2962021466118664, 0.42801379249060423`, 0.9402032195937415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 159}], {
             RGBColor[
             0.26204426941803677`, 0.39275552009761494`, 0.9382344055323761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 235}], {
             RGBColor[
             0.25936698600148883`, 0.38994152547725025`, 0.9380819382024896]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 252}], {
             RGBColor[
             0.2886130512396545, 0.4206809943501981, 0.9397474583521269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 253}], {
             RGBColor[
             0.2867100868131406, 0.4186808580830187, 0.9396390873432205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 292}], {
             RGBColor[
             0.25987815555668636`, 0.39047879708978456`, 0.9381110485524506]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 79}], {
             RGBColor[
             0.47131158576889715`, 0.5800856534095411, 0.9519605579459619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 93}], {
             RGBColor[
             0.5394509250519448, 0.6369895888012234, 0.9568866993753897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 160}], {
             RGBColor[
             0.5689561966042058, 0.6609432974446849, 0.9592094624333546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 164}], {
             RGBColor[
             0.46580833431938506`, 0.5753190136054342, 0.9516098956299331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 168}], {
             RGBColor[
             0.46678271330407606`, 0.5761629717082618, 0.9516719821972282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 246}], {
             RGBColor[
             0.57328015808247, 0.6644536841649844, 0.9595498605201163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 296}], {
             RGBColor[
             0.6219639893106997, 0.70315209105388, 0.9639467061714042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.27383547980684575`, 0.4051488298221716, 0.9389058975204863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 89}], {
             RGBColor[
             0.26259271630004477`, 0.3933319725441461, 0.9382656387709521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 112}], {
             RGBColor[
             0.24963320232510341`, 0.37971070167583876`, 0.9375276136219621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 115}], {
             RGBColor[
             0.2343221600487206, 0.3636178254672108, 0.9366556724149793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 134}], {
             RGBColor[
             0.26052687456490653`, 0.3911606418985847, 0.938147992140275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 146}], {
             RGBColor[
             0.23875177461672836`, 0.3682736312319718, 0.9369079324115999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 159}], {
             RGBColor[
             0.24722335585304894`, 0.3771778002406183, 0.937390376430427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 175}], {
             RGBColor[
             0.27078207932041887`, 0.40193951231416447`, 0.9387320108798856]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 204}], {
             RGBColor[
             0.23896784394150833`, 0.36850073379190207`, 0.9369202372400001]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 235}], {
             RGBColor[
             0.24454607243650103`, 0.3743638056202535, 0.9372379091005405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 242}], {
             RGBColor[
             0.24374269016754463`, 0.3735193999182025, 0.9371921576688209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 243}], {
             RGBColor[
             0.23260979600231052`, 0.3618180222842825, 0.9365581558157519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 253}], {
             RGBColor[
             0.27188917324815276`, 0.40310313822602206`, 0.9387950582412713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 280}], {
             RGBColor[
             0.2575556675749038, 0.38803771496668804`, 0.9379787862977012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 292}], {
             RGBColor[
             0.2450572419916986, 0.37490107723278787`, 0.9372670194505013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 66}], {
             RGBColor[
             0.747689528345485, 0.802133526636196, 0.966576403949817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 67}], {
             RGBColor[
             0.7306207568349073, 0.7888007417215468, 0.9745656605578148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 73}], {
             RGBColor[
             0.4389666532110068, 0.5520366798791193, 0.9499088011180912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 95}], {
             RGBColor[
             0.5187848450827122, 0.6202119340859072, 0.9552597898578664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 96}], {
             RGBColor[
             0.47719454661287236`, 0.585147759754026, 0.9523446486820593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 109}], {
             RGBColor[
             0.7350459204207711, 0.7923292470470489, 0.9749877366110247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 138}], {
             RGBColor[
             0.6278035428683023, 0.7077328487058376, 0.9645158476926661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 140}], {
             RGBColor[
             0.4384985979215843, 0.5516312739125644, 0.9498789770489342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 154}], {
             RGBColor[
             0.6450616328403926, 0.7212149997583763, 0.9662359728150638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 171}], {
             RGBColor[
             0.48363824484440066`, 0.5907289672924857, 0.9527552354354336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 198}], {
             RGBColor[
             0.506589269540044, 0.610311016455952, 0.9542997094772824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[
             0.48666290222101594`, 0.5933487734884098, 0.952947963928872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 62}], {
             RGBColor[
             0.8868230148643443, 0.4992626353588674, 0.34626643898134246`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 100}], {
             RGBColor[
             0.8386002140561873, 0.2977037367233178, 0.18459691461389852`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 125}], {
             RGBColor[
             0.8860818256794646, 0.49767730663813153`, 0.2655925702966138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 137}], {
             RGBColor[
             0.8370621725153026, 0.28588167546597704`, 0.1831240842973778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 170}], {
             RGBColor[
             0.8291712502966372, 0.22522858946914998`, 0.17556772826926184`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 192}], {
             RGBColor[
             0.8435354828696529, 0.32873767594338427`, 0.18905271951585984`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 195}], {
             RGBColor[
             0.828254689512269, 0.21818350164099967`, 0.17469002862704355`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 200}], {
             RGBColor[
             0.850538756993148, 0.3605379080819481, 0.19489642311046151`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 225}], {
             RGBColor[
             0.8755277217707287, 0.4621261005588738, 0.22031772858046247`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 228}], {
             RGBColor[
             0.8273211846534105, 0.45428347736572383`, 0.4468112731339182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 255}], {
             RGBColor[
             0.8748582159180097, 0.45986770011020284`, 0.21771682476822068`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.9605795624965958, 0.8682632028416796, 0.48244356084256446`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 85}], {
             RGBColor[
             0.9228540566499766, 0.8416985659067688, 0.6257891591988634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 100}], {
             RGBColor[
             0.875481037191391, 0.5060252518657031, 0.21691816771131295`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 121}], {
             RGBColor[
             0.9603462863275016, 0.8677642487038257, 0.4570528894502983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 125}], {
             RGBColor[
             0.9593538076584427, 0.8656414371856946, 0.3490277111915949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 127}], {
             RGBColor[
             0.8638755462529181, 0.416820362954043, 0.20580473648210393`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.9594950595498875, 0.8659435606987382, 0.3644021078697419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 137}], {
             RGBColor[
             0.8724049541096216, 0.4823811293510216, 0.2139725070782716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 170}], {
             RGBColor[
             0.8566231096722907, 0.3610749573573675, 0.19885979502203965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 232}], {
             RGBColor[
             0.9600894947352094, 0.8672149974535253, 0.4291027093633025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 240}], {
             RGBColor[
             0.9605080040332614, 0.868110146524278, 0.47465486371626864`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 256}], {
             RGBColor[
             0.9606652122328164, 0.8684463989669389, 0.49176600606128196`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 299}], {
             RGBColor[
             0.9602834986478392, 0.8683179033755875, 0.5002256256588694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 177}], {
             RGBColor[
             0.49302351294995017`, 0.5983715477396933, 0.9534876687205165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 217}], {
             RGBColor[
             0.686937545269946, 0.7542032342825437, 0.9702221270801157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 247}], {
             RGBColor[
             0.5729638190353659, 0.6641968658756336, 0.9595249571515402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 267}], {
             RGBColor[
             0.517343318582302, 0.6190416379328455, 0.9551463076112685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 273}], {
             RGBColor[
             0.5923372400801741, 0.6799250818424811, 0.9610501038233672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 285}], {
             RGBColor[
             0.474805368949063, 0.5825919070766665, 0.9523268246944521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 82}], {
             RGBColor[
             0.9949627046124243, 0.9916340594516913, 0.6930996675251034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 100}], {
             RGBColor[
             0.8984031319352767, 0.588272489605711, 0.35735557216633895`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 127}], {
             RGBColor[
             0.8867976409968038, 0.49906760069405076`, 0.3462421409371299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 130}], {
             RGBColor[
             0.5868878667757954, 0.648392143438405, 0.8070978104506135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 137}], {
             RGBColor[
             0.8953270488535073, 0.5646283670910295, 0.3544099115332976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 170}], {
             RGBColor[
             0.8795452044161765, 0.44332219509737536`, 0.3392971994770656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 192}], {
             RGBColor[
             0.9082736695622077, 0.6503403680458439, 0.3662671819702616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 195}], {
             RGBColor[
             0.8777120828474402, 0.4292320194410746, 0.3375418001926291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 199}], {
             RGBColor[
             0.5868878667757954, 0.648392143438405, 0.8070978104506135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 220}], {
             RGBColor[
             0.6260202363274255, 0.6895227449727015, 0.8093263410054259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 225}], {
             RGBColor[
             0.9779057939111673, 0.9356854846768198, 0.49177155529990685`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 226}], {
             RGBColor[
             0.5868878718865363, 0.6483921488101179, 0.8070978107416625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 228}], {
             RGBColor[
             0.90559598823519, 0.9239215498870947, 0.8315118721300905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 255}], {
             RGBColor[
             0.9769015351320889, 0.9322978840038133, 0.4878701995815442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 131}], {
             RGBColor[
             0.32467225096411007`, 0.4556365181084638, 0.9419088066284024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 139}], {
             RGBColor[
             0.28999599813964694`, 0.42067676560446166`, 0.9398795920978575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 143}], {
             RGBColor[
             0.36063166824627285`, 0.4867827579854089, 0.9442001088999576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 172}], {
             RGBColor[
             0.29700434513925705`, 0.4280429826559164, 0.940278707091565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 174}], {
             RGBColor[
             0.35841838866408615`, 0.48486572645398507`, 0.944059080682107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 183}], {
             RGBColor[
             0.28955139027076127`, 0.4202094545444958, 0.939854272337463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 283}], {
             RGBColor[
             0.4716182093057971, 0.5784225844464469, 0.9525129877054703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 92}], {
             RGBColor[
             0.24737632360791623`, 0.3773385790496996, 0.9373990877177711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 145}], {
             RGBColor[
             0.2514296244944172, 0.3815988552755316, 0.937629917206936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 153}], {
             RGBColor[
             0.253568524812987, 0.38384697512446136`, 0.9377517244158591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 211}], {
             RGBColor[
             0.238007335368493, 0.36749117838190204`, 0.936865537697712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 219}], {
             RGBColor[
             0.2539451972290641, 0.384242881716169, 0.9377731753527179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 221}], {
             RGBColor[
             0.26413437920159183`, 0.3949523580007457, 0.9383534341925093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 80}], {
             RGBColor[
             0.27787319023653523`, 0.40939271948940265`, 0.9391358391561999]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 103}], {
             RGBColor[
             0.2833667383517215, 0.41516678686953135`, 0.9394486885943836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 116}], {
             RGBColor[
             0.3051622199360282, 0.4368120893539453, 0.940736158424998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 133}], {
             RGBColor[
             0.3190318248130566, 0.44882524399181684`, 0.9416199173833522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 152}], {
             RGBColor[
             0.270606352963235, 0.4017548127710696, 0.9387220035238077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 162}], {
             RGBColor[
             0.28622167127698683`, 0.41816750238718753`, 0.9396112728009827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[
             0.33323684341077736`, 0.46112891713616844`, 0.9425250486073942]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 241}], {
             RGBColor[
             0.2834960053804121, 0.4153026547126882, 0.9394560501604341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 277}], {
             RGBColor[
             0.318505826054183, 0.44836965030434695`, 0.9415864012075592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 67}], {
             RGBColor[
             0.9293871027463778, 0.9462546742934231, 0.9835096743331035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 69}], {
             RGBColor[
             0.9697469416824389, 0.9735523947961, 0.7295644287144893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 95}], {
             RGBColor[
             0.7175511909941827, 0.7776658666577836, 0.9642038036331552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 109}], {
             RGBColor[
             0.9338122663322416, 0.9497831796189251, 0.9839317503863134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 110}], {
             RGBColor[
             0.969700925487342, 0.9754692267738965, 0.8710436844734033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 138}], {
             RGBColor[
             0.8265698887797728, 0.8651867812777139, 0.9734598614679548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 154}], {
             RGBColor[
             0.8438279787518632, 0.8786689323302527, 0.9751799865903525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 179}], {
             RGBColor[
             0.9700512243327243, 0.9756140843487318, 0.8652383260610674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 258}], {
             RGBColor[
             0.9541114545413159, 0.9652969784492861, 0.9625615171988029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 69}], {
             RGBColor[
             0.9526781701718614, 0.9602196098814508, 0.7375536853224871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 86}], {
             RGBColor[
             0.9435929630020026, 0.929903263270933, 0.6741823558912051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 95}], {
             RGBColor[
             0.7004824194836051, 0.7643330817431344, 0.9721930602411528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 109}], {
             RGBColor[
             0.916743494821664, 0.9364503947042759, 0.9919210069943111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 110}], {
             RGBColor[
             0.9526321539767644, 0.9621364418592473, 0.8790329410814011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 138}], {
             RGBColor[
             0.8095011172691953, 0.8518539963630647, 0.9814491180759526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 154}], {
             RGBColor[
             0.8267592072412856, 0.8653361474156035, 0.9831692431983503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 179}], {
             RGBColor[
             0.9529824528221467, 0.9622812994340826, 0.8732275826690652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 258}], {
             RGBColor[
             0.9370426830307382, 0.9519641935346369, 0.9705507738068005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 215}], {
             RGBColor[
             0.9347347232001206, 0.7573256172439325, 0.47384806566130333`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 223}], {
             RGBColor[
             0.880860495472638, 0.5518971603270344, 0.22229941585693147`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 234}], {
             RGBColor[
             0.8363347391748547, 0.263554053647327, 0.18177214371591305`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 255}], {
             RGBColor[
             0.9166602771185755, 0.6978068210363987, 0.2559631047048003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 271}], {
             RGBColor[
             0.9259155815977133, 0.7290271362933656, 0.2919182148886562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 274}], {
             RGBColor[
             0.9194708353599413, 0.7072874939349834, 0.2668815927431183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 287}], {
             RGBColor[
             0.9076706141527531, 0.6630503890698746, 0.24412287160438084`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 109}], {
             RGBColor[
             0.957103333757725, 0.9637481152069529, 0.737975761375697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 110}], {
             RGBColor[
             0.9929919929128255, 0.9894341623619243, 0.625087695462787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 113}], {
             RGBColor[
             0.9762236487706943, 0.9783827123378863, 0.71860105300982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 135}], {
             RGBColor[
             0.9915668730357023, 0.9888448386688236, 0.6487056199187353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 138}], {
             RGBColor[
             0.8498609562052564, 0.8791517168657417, 0.7275038724573385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 224}], {
             RGBColor[
             0.9812813612748328, 0.9481895871324358, 0.4098590677551779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 249}], {
             RGBColor[
             0.8767326483234027, 0.4250520115136651, 0.27148648277790555`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 254}], {
             RGBColor[
             0.9421799602264942, 0.7934586684310521, 0.3573185586987633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 258}], {
             RGBColor[
             0.9774025219667993, 0.9792619140373138, 0.7166055281881865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 288}], {
             RGBColor[
             0.9056134125186948, 0.6397104688969287, 0.29885564217207405`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[
             0.27137415800540265`, 0.40256182455203926`, 0.9387657288850935]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 251}], {
             RGBColor[
             0.27547374372817707`, 0.40687074907542276`, 0.9389991942272118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 300}], {
             RGBColor[
             0.2600472811884571, 0.39065655885195993`, 0.938120680006981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 85}], {
             RGBColor[
             0.7746111080065263, 0.8244612139777192, 0.9780896021036154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 98}], {
             RGBColor[
             0.5262018737865255, 0.625404972246536, 0.9560725859325541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 121}], {
             RGBColor[
             0.8121033376840514, 0.8505268967747761, 0.8093533323550504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 122}], {
             RGBColor[
             0.6268946494046528, 0.707980343525642, 0.9637705896733515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 136}], {
             RGBColor[
             0.8112521109064372, 0.8487062087696886, 0.716702550774494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 160}], {
             RGBColor[
             0.6099082730566356, 0.6941900379787878, 0.9624333599040888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 181}], {
             RGBColor[
             0.6717068148993812, 0.7432662316253906, 0.9680467833618187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 207}], {
             RGBColor[
             0.6875924129964879, 0.7556761815938675, 0.9696301113207838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 232}], {
             RGBColor[
             0.8118465460917592, 0.8499776455244756, 0.7814031522680547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 240}], {
             RGBColor[
             0.8122650553898112, 0.8508727945952284, 0.8269553066210207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 246}], {
             RGBColor[
             0.6142322345348998, 0.6977004246990872, 0.9627737579908505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 256}], {
             RGBColor[
             0.8124222635893662, 0.8512090470378892, 0.8440664489660341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 296}], {
             RGBColor[
             0.6629160657631297, 0.7363988315879828, 0.9671706036421385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 299}], {
             RGBColor[
             0.812040550004389, 0.8510805514465378, 0.8525260685636215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 106}], {
             RGBColor[
             0.6542381545327312, 0.7298150858058879, 0.966172003106812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 151}], {
             RGBColor[
             0.5475405416357872, 0.6431396338261914, 0.9576978591404627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 194}], {
             RGBColor[
             0.5838203648230471, 0.6728659592388615, 0.9604785834522965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 215}], {
             RGBColor[
             0.8234553846620669, 0.8600796725778928, 0.8483727211925696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 247}], {
             RGBColor[
             0.6154478937421781, 0.6985426120193529, 0.9629684183842664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 267}], {
             RGBColor[
             0.5598273932891142, 0.6533873840765647, 0.9585897688439947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 286}], {
             RGBColor[
             0.6054217047226151, 0.6904029000986035, 0.9621791200575058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 87}], {
             RGBColor[
             0.3025587103322468, 0.4334652095438001, 0.9406102430960075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 95}], {
             RGBColor[
             0.4088283158597046, 0.5275690199007069, 0.9475362008014293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 96}], {
             RGBColor[
             0.3672380173898648, 0.4925048455688256, 0.9446210596256222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 105}], {
             RGBColor[
             0.30909022810020703`, 0.4403302488400713, 0.9409822033703782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 140}], {
             RGBColor[
             0.3285420686985767, 0.45898835972736407`, 0.9421553879924971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 149}], {
             RGBColor[
             0.3114795465639533, 0.4428415740370091, 0.9411182715222086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 171}], {
             RGBColor[
             0.3736817156213931, 0.4980860531072854, 0.9450316463789965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 245}], {
             RGBColor[
             0.37670637299800835`, 0.5007058593032094, 0.9452243748724349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 289}], {
             RGBColor[
             0.309996695985159, 0.44128300406053933`, 0.9410338253754271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 298}], {
             RGBColor[
             0.307131102255913, 0.43827108336196546`, 0.9408706340518126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 90}], {
             RGBColor[
             0.5208802713688769, 0.620561681786851, 0.9557981491382472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 123}], {
             RGBColor[
             0.5372173592410554, 0.6347120461758202, 0.9568391339311428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 158}], {
             RGBColor[
             0.5209230649967003, 0.6205987474764012, 0.9558008759103712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 233}], {
             RGBColor[
             0.8161512863791258, 0.8534670921405562, 0.7813047425304152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 257}], {
             RGBColor[
             0.5147596974188978, 0.6152603482603705, 0.9554081515783656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 259}], {
             RGBColor[
             0.5512374616169957, 0.646558430162153, 0.9578145787092965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 262}], {
             RGBColor[
             0.8160969055518104, 0.8533507770496733, 0.7753857250766871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 124}], {
             RGBColor[
             0.8391031020269322, 0.8749559056354701, 0.9735996156850079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 142}], {
             RGBColor[
             0.6947680744610263, 0.7614773672926725, 0.9702116467516284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 143}], {
             RGBColor[
             0.5636312232942053, 0.6537338940348352, 0.9601379235387875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 150}], {
             RGBColor[
             0.8462593507356758, 0.8802930242051693, 0.9614859532696918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 167}], {
             RGBColor[
             0.7422194299230214, 0.7985467268232416, 0.9749411544059516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 174}], {
             RGBColor[
             0.5614179437120186, 0.6518168625034114, 0.9599968953209368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 185}], {
             RGBColor[
             0.6492913495741017, 0.7248125960357876, 0.9664570141991338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 237}], {
             RGBColor[
             0.6846458552140906, 0.7535149764166593, 0.969240250390935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 239}], {
             RGBColor[
             0.5708233361978141, 0.6599633407458361, 0.9605961986132696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 282}], {
             RGBColor[
             0.8470847195516484, 0.8809085829167043, 0.9600888191549137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 283}], {
             RGBColor[
             0.6746177643537297, 0.7453737204958732, 0.9684508023443001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 295}], {
             RGBColor[
             0.7838985892899054, 0.8312466386518764, 0.9790582353871675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 297}], {
             RGBColor[
             0.7454557140194038, 0.8010749365560057, 0.9752637169598848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 99}], {
             RGBColor[
             0.3308920068686242, 0.45968772172522177`, 0.9423540428096366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[
             0.2896837321277139, 0.4218063478486378, 0.9398084320447715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 128}], {
             RGBColor[
             0.2667781164198233, 0.397731093439728, 0.9385039911160289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[
             0.3201380287875101, 0.4503731664220151, 0.9416688088356775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 201}], {
             RGBColor[
             0.3077043294157084, 0.43960372096206174`, 0.9408765445063949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 209}], {
             RGBColor[
             0.2797259704782522, 0.4113401089964994, 0.9392413522500229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 218}], {
             RGBColor[
             0.2751691719679872, 0.4065506248444982, 0.9389818493160426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 229}], {
             RGBColor[
             0.32034218545595194`, 0.4505499966670069, 0.9416818175180619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 261}], {
             RGBColor[
             0.3474685023612617, 0.4740454489620557, 0.9434102824444082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 284}], {
             RGBColor[
             0.2749699198453155, 0.406341198230256, 0.9389705022024235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 91}], {
             RGBColor[
             0.25932242623621204`, 0.38989469033869195`, 0.9380794005897775]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 162}], {
             RGBColor[
             0.26527957680517633`, 0.3961560332918348, 0.9384186515018654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 191}], {
             RGBColor[
             0.24496070190330402`, 0.37479960747889, 0.9372615216352855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 203}], {
             RGBColor[
             0.25281317669126346`, 0.38305305635669296`, 0.9377087084577643]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 206}], {
             RGBColor[
             0.2413530899135048, 0.3710077785417997, 0.9370560734694501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 244}], {
             RGBColor[
             0.2442718082387917, 0.3740755365591065, 0.9372222901602183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 270}], {
             RGBColor[
             0.23714390206690406`, 0.36658365523709874`, 0.9368163664485216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 118}], {
             RGBColor[
             0.17948494456776543`, 0.30598043511645023`, 0.9335327741177293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 120}], {
             RGBColor[
             0.1849774474258748, 0.3117534038651181, 0.9338455640300687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 130}], {
             RGBColor[
             0.17948366008578914`, 0.30597908504445237`, 0.9335327009683809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 176}], {
             RGBColor[
             0.17949609924511575`, 0.30599215938959284`, 0.9335334093601024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 193}], {
             RGBColor[
             0.2897690368730418, 0.4135053888596902, 0.9401205117129523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.17948366008578914`, 0.30597908504445237`, 0.9335327009683809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 220}], {
             RGBColor[
             0.21861602963741927`, 0.34710968657874874`, 0.9357612315231933]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 226}], {
             RGBColor[
             0.17948366519653014`, 0.30597909041616517`, 0.9335327012594301]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 236}], {
             RGBColor[
             0.4016254852173745, 0.5057768385746106, 0.9485224868513811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 266}], {
             RGBColor[
             0.21383713709575333`, 0.3420867675181703, 0.9354890806626834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 93}], {
             RGBColor[
             0.46307011169266854`, 0.5733948534802826, 0.9513117589171669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 103}], {
             RGBColor[
             0.33687382527310783`, 0.4634377566971172, 0.9427875991368931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 116}], {
             RGBColor[
             0.3586693068574145, 0.48508305918153105`, 0.9440750689675076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 119}], {
             RGBColor[
             0.3385777508483834, 0.465228690511853, 0.9428846351776731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 164}], {
             RGBColor[
             0.38942752096010885`, 0.5117242782844935, 0.9460349551717104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 168}], {
             RGBColor[
             0.3904018999447999, 0.5125682363873212, 0.9460970417390054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 241}], {
             RGBColor[
             0.3370030923017984, 0.46357362454027395`, 0.9427949607029437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[
             0.3720129129755694, 0.49664062013193266`, 0.9449253117500688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 103}], {
             RGBColor[
             0.2733233300214085, 0.4046105279255051, 0.9388767313478634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 116}], {
             RGBColor[
             0.2951188116057152, 0.426255830409919, 0.9401642011784779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 133}], {
             RGBColor[
             0.30898841648274356`, 0.43826898504779055`, 0.941047960136832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 152}], {
             RGBColor[
             0.26056294463292196`, 0.39119855382704327`, 0.9381500462772876]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 210}], {
             RGBColor[
             0.3231934350804644, 0.45057265819214215`, 0.941953091360874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 241}], {
             RGBColor[
             0.27345259705009906`, 0.4047463957686619, 0.938884092913914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 277}], {
             RGBColor[
             0.30846241772387, 0.4378133913603206, 0.9410144439610391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 180}], {
             RGBColor[
             0.26493370488523493`, 0.3957924999744301, 0.9383989546076965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[
             0.3818442604921369, 0.5035684061042389, 0.9457044452357559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 285}], {
             RGBColor[
             0.33930631085889784`, 0.4671186752480599, 0.9428849623189395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 100}], {
             RGBColor[
             0.898479112642499, 0.5884350046556317, 0.36562560324892335`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 107}], {
             RGBColor[
             0.8877902396301622, 0.5062756427887904, 0.35538992638095424`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 127}], {
             RGBColor[
             0.8868736217040262, 0.4992301157439715, 0.35451217201971436`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 137}], {
             RGBColor[
             0.8954030295607297, 0.5647908821409502, 0.362679942615882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 192}], {
             RGBColor[
             0.90834965026943, 0.6505028830957647, 0.37453721305284604`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 199}], {
             RGBColor[
             0.587001837836629, 0.6486359160132862, 0.81950285707449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 220}], {
             RGBColor[
             0.6261342073882591, 0.6897665175475827, 0.8217313876293025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 226}], {
             RGBColor[
             0.5870018429473699, 0.648635921384999, 0.8195028573655392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 228}], {
             RGBColor[
             0.9057099592960236, 0.9241653224619759, 0.8439169187539672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 266}], {
             RGBColor[
             0.6213553148465931, 0.6847435984870042, 0.8214592367687926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 281}], {
             RGBColor[
             0.8890764883956016, 0.5161623144377598, 0.3566216396513491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 126}], {
             RGBColor[
             0.22111352999763184`, 0.3497347178080009, 0.9359034604739869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 155}], {
             RGBColor[
             0.21429563561346426`, 0.34256867853076955`, 0.9355151914749793]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 156}], {
             RGBColor[
             0.221993745626472, 0.35065988024280614`, 0.935953587451887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 184}], {
             RGBColor[
             0.22686279734830417`, 0.3557775623181615, 0.9362308727443287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[
             0.21339436331142053`, 0.34162138419735716`, 0.9354638653506908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 202}], {
             RGBColor[
             0.22220476853383342`, 0.3508816786980681, 0.9359656048942807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 214}], {
             RGBColor[
             0.21458531177906248`, 0.342873146547343, 0.9355316881040727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 275}], {
             RGBColor[
             0.214533530595458, 0.34281872124025803`, 0.9355287392422698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 293}], {
             RGBColor[
             0.21277489873276917`, 0.34097028764887183`, 0.9354285877593523]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 89}], {
             RGBColor[
             0.2893752204809355, 0.4214820825471055, 0.9397908627628895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.35208222651696447`, 0.4786261706514128, 0.9436828617856419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 112}], {
             RGBColor[
             0.2764157065059942, 0.4078608116787981, 0.9390528376138995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 134}], {
             RGBColor[
             0.2873093787457973, 0.41931075190154404`, 0.9396732161322123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 144}], {
             RGBColor[
             0.30816373722776935`, 0.4405861826365669, 0.9408844144837296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 158}], {
             RGBColor[
             0.35212502014478775`, 0.47866323634096297`, 0.943685588557766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 159}], {
             RGBColor[
             0.27400586003393973`, 0.4053279102435776, 0.9389156004223643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 175}], {
             RGBColor[
             0.29756458350130965`, 0.4300896223171238, 0.940257234871823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 252}], {
             RGBColor[
             0.30057464185555743`, 0.4332533844961608, 0.9404286532421151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 253}], {
             RGBColor[
             0.29867167742904355`, 0.43125324822898137`, 0.9403202822332086]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 280}], {
             RGBColor[
             0.28433817175579457`, 0.41618782496964746`, 0.9395040102896386]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 292}], {
             RGBColor[
             0.2718397461725893, 0.40305118723574723`, 0.9387922434424387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[
             0.9571178936575444, 0.9648142409538079, 0.8234596411130128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 122}], {
             RGBColor[
             0.7719092053781459, 0.8222676877046737, 0.9778768984313139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 136}], {
             RGBColor[
             0.9562666668799304, 0.9629935529487204, 0.7308088595324563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 165}], {
             RGBColor[
             0.9499430145672961, 0.9419121380578821, 0.6850057931573457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 181}], {
             RGBColor[
             0.8167213708728744, 0.8575535758044224, 0.9821530921197811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 207}], {
             RGBColor[
             0.8326069689699811, 0.8699635257728993, 0.9837364200787462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 232}], {
             RGBColor[
             0.9568611020652522, 0.9642649897035074, 0.7955094610260169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 240}], {
             RGBColor[
             0.9572796113633043, 0.9651601387742601, 0.8410616153789832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 246}], {
             RGBColor[
             0.759246790508393, 0.811987768878119, 0.9768800667488129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 256}], {
             RGBColor[
             0.9574368195628593, 0.965496391216921, 0.8581727577239964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 296}], {
             RGBColor[
             0.8079306217366228, 0.8506861757670146, 0.9812769124001008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 299}], {
             RGBColor[
             0.9570551059778822, 0.9653678956255696, 0.8666323773215838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 107}], {
             RGBColor[
             0.8810538793284779, 0.48461124450096366`, 0.2391769486117305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 109}], {
             RGBColor[
             0.9480181265878662, 0.9334317685964351, 0.674604431944415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 110}], {
             RGBColor[
             0.9839067857429666, 0.9591178157514064, 0.561716366031505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 141}], {
             RGBColor[
             0.936935020626016, 0.7805800799358134, 0.2971516426609445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 165}], {
             RGBColor[
             0.9775639799613888, 0.9359801775610526, 0.3673407281472113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 179}], {
             RGBColor[
             0.9842570845883489, 0.9592626733262417, 0.5559110076191691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 240}], {
             RGBColor[
             0.984900576757397, 0.9592281782774306, 0.5233965503688487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 281}], {
             RGBColor[
             0.8823401280939172, 0.49449791614993305`, 0.24040866188212537`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 149}], {
             RGBColor[
             0.2850281329082009, 0.41691301788689017`, 0.939543302556562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 187}], {
             RGBColor[
             0.3200183961394125, 0.4485879118406425, 0.9417227588366461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 227}], {
             RGBColor[
             0.2679362427515092, 0.39894835764378045`, 0.938569944697324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 264}], {
             RGBColor[
             0.2853843000396664, 0.4172873721243609, 0.939563585747797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 99}], {
             RGBColor[
             0.43585477652737337`, 0.5505550934269655, 0.9493751482779511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[
             0.7318152240398965, 0.7888182862268713, 0.9538534747537719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 198}], {
             RGBColor[
             0.48423825814620036`, 0.592165458504841, 0.9525401559859066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 201}], {
             RGBColor[
             0.41266709907445764`, 0.5304710926638055, 0.9478976499747094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 222}], {
             RGBColor[
             0.47017691950032614`, 0.5802832085890723, 0.9515621248783083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 258}], {
             RGBColor[
             0.7329940972360016, 0.7896974879262988, 0.9518579499321382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 260}], {
             RGBColor[
             0.6766874696871867, 0.7454723343623321, 0.9697937614112038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 261}], {
             RGBColor[
             0.4524312720200109, 0.5649128206637994, 0.9504313879127225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 278}], {
             RGBColor[
             0.553576335347311, 0.6484572332214837, 0.9579987034169237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 290}], {
             RGBColor[
             0.558574938782711, 0.6525153246748602, 0.9583922117898461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 111}], {
             RGBColor[
             0.26057341862775985`, 0.3912095626597075, 0.9381506427557986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 112}], {
             RGBColor[
             0.26517294299919314`, 0.39604395440077267`, 0.9384125788643654]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 175}], {
             RGBColor[
             0.28632181999450856`, 0.4182727650390983, 0.9396169761222888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 177}], {
             RGBColor[
             0.3486700459196015, 0.47359177071300174`, 0.9435415608547846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 242}], {
             RGBColor[
             0.2592824308416344, 0.3898526526431364, 0.9380771229112241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.27309540824899353`, 0.40437096769162195`, 0.9388637515401044]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 285}], {
             RGBColor[
             0.3304519019187142, 0.457812130049975, 0.9423807168287202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 123}], {
             RGBColor[
             0.4198835569183708, 0.5381037658666636, 0.9479755868517558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 134}], {
             RGBColor[
             0.3387736212750252, 0.46463798272782586`, 0.9429249564054306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 144}], {
             RGBColor[
             0.35962797975699734`, 0.48591341346284866`, 0.9441361547569478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 158}], {
             RGBColor[
             0.4035892626740157, 0.5239904671672448, 0.9469373288309841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 252}], {
             RGBColor[
             0.35203888438478537`, 0.4785806153224426, 0.9436803935153333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 253}], {
             RGBColor[
             0.3501359199582715, 0.4765804790552632, 0.9435720225064269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[
             0.39742589509621323`, 0.518652067951214, 0.9465446044989785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 102}], {
             RGBColor[
             0.3289676178309032, 0.4560161547537128, 0.9423048264494448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 162}], {
             RGBColor[
             0.27856959341816107`, 0.4101246833878033, 0.9391754982871572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 191}], {
             RGBColor[
             0.2582507185162887, 0.38876825757485856`, 0.9380183684205773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 203}], {
             RGBColor[
             0.2661031933042482, 0.39702170645266144`, 0.9384655552430561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 239}], {
             RGBColor[
             0.3418733579527955, 0.46719445818593675`, 0.9431271687979139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 153}], {
             RGBColor[
             0.26728945052082176`, 0.3982685380003319, 0.9385331108366297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 163}], {
             RGBColor[
             0.25122830224652154`, 0.3813872528284255, 0.937618452202748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 189}], {
             RGBColor[
             0.2464728493758267, 0.3763889703481986, 0.937347636196824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 211}], {
             RGBColor[
             0.2517282610763278, 0.3819127412577725, 0.9376469241184826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 216}], {
             RGBColor[
             0.25996759819388404`, 0.3905728069724701, 0.9381161421783205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 221}], {
             RGBColor[
             0.27785530490942656`, 0.40937392087661617`, 0.9391348206132799]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 94}], {
             RGBColor[
             0.6965792865266065, 0.7615288190518337, 0.9714662855765266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 160}], {
             RGBColor[
             0.5607147225279772, 0.6542524975154264, 0.9585606634045596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 164}], {
             RGBColor[
             0.45756686024315646`, 0.5686282136761757, 0.9509610966011381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 168}], {
             RGBColor[
             0.4585412392278475, 0.5694721717790032, 0.9510231831684333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 277}], {
             RGBColor[
             0.440152252258617, 0.5535445555236148, 0.9498514531794966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 124}], {
             RGBColor[
             0.9048214633960636, 0.926634777474092, 0.9800597975853467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 125}], {
             RGBColor[
             0.9272871440372241, 0.9396965749731525, 0.7126838428267497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 142}], {
             RGBColor[
             0.7604864358301577, 0.8131562391312941, 0.9766718286519673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 150}], {
             RGBColor[
             0.9119777121048072, 0.931971896043791, 0.9679461351700305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 200}], {
             RGBColor[
             0.8739725410077492, 0.7339874771388775, 0.6066396220475212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.7503642165832218, 0.805193848255281, 0.9757004322912739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 295}], {
             RGBColor[
             0.8496169506590368, 0.8829255104904983, 0.9855184172875062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 96}], {
             RGBColor[
             0.44705620926157014`, 0.5606800997756136, 0.9499720483653973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 105}], {
             RGBColor[
             0.3889084199719124, 0.5085055030468593, 0.9463331921101534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 109}], {
             RGBColor[
             0.7049075830694689, 0.7678615870686365, 0.9726151362943627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 138}], {
             RGBColor[
             0.5976652055170001, 0.6832651887274253, 0.9621432473760043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 140}], {
             RGBColor[
             0.4083602605702821, 0.527163613934152, 0.9475063767322723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 154}], {
             RGBColor[
             0.6149232954890904, 0.696747339779964, 0.9638633724984019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 171}], {
             RGBColor[
             0.45349990749309843`, 0.5662613073140733, 0.9503826351187716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 198}], {
             RGBColor[
             0.4764509321887418, 0.5858433564775396, 0.9519271091606205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 245}], {
             RGBColor[
             0.4565245648697137, 0.5688811135099974, 0.9505753636122101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 289}], {
             RGBColor[
             0.38981488785686436`, 0.5094582582673273, 0.9463848141152024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 105}], {
             RGBColor[
             0.3473181215020726, 0.473441328714978, 0.9434180509343462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 138}], {
             RGBColor[
             0.5560749070471602, 0.6482010143955439, 0.959228106200197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 140}], {
             RGBColor[
             0.36676996210044227`, 0.49209943960227065`, 0.9445912355564652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 171}], {
             RGBColor[
             0.4119096090232586, 0.5311971329821921, 0.9474674939429645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 196}], {
             RGBColor[
             0.34319916551880214`, 0.4691120448196677, 0.9431834824845483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 198}], {
             RGBColor[
             0.43486063371890193`, 0.5507791821456584, 0.9490119679848132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 222}], {
             RGBColor[
             0.4207992950730278, 0.5388969322298897, 0.948033936877215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 245}], {
             RGBColor[
             0.41493426639987385`, 0.5338169391781161, 0.9476602224364029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 278}], {
             RGBColor[
             0.5041987109200126, 0.6070709568623011, 0.9544705154158305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 289}], {
             RGBColor[
             0.3482245893870246, 0.47439408393544596`, 0.9434696729393952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 290}], {
             RGBColor[
             0.5091973143554127, 0.6111290483156775, 0.9548640237887529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 298}], {
             RGBColor[
             0.3453589956577786, 0.4713821632368721, 0.9433064816157806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 134}], {
             RGBColor[
             0.2657406017726479, 0.3966405997633186, 0.9384449061917377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 144}], {
             RGBColor[
             0.28659496025462, 0.4179160304983415, 0.9396561045432549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 159}], {
             RGBColor[
             0.2524370830607903, 0.3826577581053522, 0.9376872904818896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 235}], {
             RGBColor[
             0.24975979964424241`, 0.3798437634849875, 0.9375348231520031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 252}], {
             RGBColor[
             0.2790058648824081, 0.41058323235793537`, 0.9392003433016403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 292}], {
             RGBColor[
             0.25027096919944, 0.3803810350975218, 0.937563933501964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 122}], {
             RGBColor[
             0.5234999711581451, 0.6232114459734905, 0.9558598822602524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 160}], {
             RGBColor[
             0.5065135948101279, 0.6094211404266363, 0.9545226524909898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 178}], {
             RGBColor[
             0.34993177355877136`, 0.4745851224813026, 0.9436255999612144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 181}], {
             RGBColor[
             0.5683121366528735, 0.6584973340732392, 0.9601360759487196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 182}], {
             RGBColor[
             0.3649951509133196, 0.4904176871542194, 0.9444834370172861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 208}], {
             RGBColor[
             0.3543834762769441, 0.47926414429235664`, 0.9438791178453103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 246}], {
             RGBColor[
             0.5108375562883921, 0.6129315271469358, 0.9548630505777516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 296}], {
             RGBColor[
             0.559521387516622, 0.6516299340358314, 0.9592598962290395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 104}], {
             RGBColor[
             0.3262801186675095, 0.4548403348152493, 0.9420914025992604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 123}], {
             RGBColor[
             0.40185451909948444`, 0.5224879194737331, 0.9468267925043885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 157}], {
             RGBColor[
             0.35673441532730565`, 0.48340715338862666`, 0.9439517793901664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 201}], {
             RGBColor[
             0.34430071595550393`, 0.4726377079286733, 0.9431595150608838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[
             0.3117655585077827, 0.43958461181110975`, 0.9412648198705315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 222}], {
             RGBColor[
             0.4018105363813725, 0.5224498238539401, 0.9468239899644828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 229}], {
             RGBColor[
             0.3569385719957474, 0.4835839836336185, 0.9439647880725508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 257}], {
             RGBColor[
             0.37939685727732686`, 0.5030362215582833, 0.9453958101516111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 259}], {
             RGBColor[
             0.41587462147542475`, 0.5343343034600658, 0.9478022372825421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 261}], {
             RGBColor[
             0.38406488890105717`, 0.5070794359286672, 0.9456932529988971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 121}], {
             RGBColor[
             0.8983235951964362, 0.5881023685637291, 0.34869848898741257`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 125}], {
             RGBColor[
             0.897661942750397, 0.5866871608849751, 0.27668170348161025`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 127}], {
             RGBColor[
             0.8443775856578832, 0.3421111465143313, 0.19012933218429046`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 136}], {
             RGBColor[
             0.8977561106780269, 0.5868885765603375, 0.28693130126704164`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 137}], {
             RGBColor[
             0.848642289586235, 0.3748915297128206, 0.1942132174823743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 170}], {
             RGBColor[
             0.8407513673675695, 0.3142384437159935, 0.18665686145425833`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 192}], {
             RGBColor[
             0.8551155999405852, 0.4177475301902278, 0.2001418527008563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 228}], {
             RGBColor[
             0.8389013017243429, 0.5432933316125673, 0.4579004063189147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 232}], {
             RGBColor[
             0.8981524008015748, 0.5877362010635289, 0.330065035596082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 240}], {
             RGBColor[
             0.8984314070002761, 0.5883329671106973, 0.36043313849805947`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 256}], {
             RGBColor[
             0.8985362124666462, 0.5885571354058046, 0.3718405667280683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 299}], {
             RGBColor[
             0.8982817367433281, 0.588471471678237, 0.3774803131264599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 108}], {
             RGBColor[
             0.44525533808141193`, 0.5575469670447641, 0.9502920083081179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 114}], {
             RGBColor[
             0.4255007228362041, 0.540035729338632, 0.9490479363174081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 187}], {
             RGBColor[
             0.4552598760386822, 0.566212394980653, 0.9509294886200896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 205}], {
             RGBColor[
             0.5380185348092877, 0.6358267098737893, 0.9567739363684693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 207}], {
             RGBColor[
             0.6460892652174881, 0.7219820565313749, 0.9663628314965813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 213}], {
             RGBColor[
             0.48723449014775655`, 0.5939071986311, 0.9529668827570787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 231}], {
             RGBColor[
             0.49585480302230733`, 0.6013736803735128, 0.9535161614708018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 133}], {
             RGBColor[
             0.36773492193593726`, 0.4929352393114849, 0.9446527219439024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 142}], {
             RGBColor[
             0.5221732711977142, 0.6208612990518254, 0.9562111960106483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 162}], {
             RGBColor[
             0.3349247683998675, 0.4622774977068556, 0.9426440773615328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[
             0.4766965463107896, 0.5841965277949407, 0.9524565634581535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 210}], {
             RGBColor[
             0.3819399405336581, 0.5052389124558365, 0.9455578531679444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 237}], {
             RGBColor[
             0.5120510519507784, 0.6128989081758123, 0.9552397996499549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 239}], {
             RGBColor[
             0.398228532934502, 0.519347272504989, 0.9465957478722895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 295}], {
             RGBColor[
             0.6113037860265932, 0.6906305704110295, 0.9650577846461873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 116}], {
             RGBColor[
             0.3006123597209014, 0.43202989779004775`, 0.9404770506166615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 119}], {
             RGBColor[
             0.28052080371187027`, 0.4121755291203697, 0.939286616826827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 152}], {
             RGBColor[
             0.26605649274810816`, 0.396972621207172, 0.9384628957154713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 164}], {
             RGBColor[
             0.33137057382359575`, 0.4586711168930102, 0.9424369368208644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 168}], {
             RGBColor[
             0.3323449528082868, 0.45951507499583777`, 0.9424990233881594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 241}], {
             RGBColor[
             0.2789461451652853, 0.41052046314879065`, 0.9391969423520976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 277}], {
             RGBColor[
             0.3139559658390563, 0.44358745874044936`, 0.9413272933992227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 128}], {
             RGBColor[
             0.26216622821870855`, 0.39288370652975557`, 0.9382413509056526]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 157}], {
             RGBColor[
             0.3155261405863954, 0.44552577951204275`, 0.9414061686253012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 173}], {
             RGBColor[
             0.2711227338075005, 0.40229756177882925`, 0.9387514106489717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 201}], {
             RGBColor[
             0.30309244121459367`, 0.43475633405208935`, 0.9406139042960187]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 209}], {
             RGBColor[
             0.2751140822771375, 0.4064927220865271, 0.9389787120396467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 218}], {
             RGBColor[
             0.2705572837668725, 0.40170323793452584`, 0.9387192091056663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 229}], {
             RGBColor[
             0.3157302972548372, 0.4457026097570346, 0.9414191773076857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 261}], {
             RGBColor[
             0.34285661416014696`, 0.46919806205208336`, 0.9431476422340319]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 279}], {
             RGBColor[
             0.27193222945827744`, 0.4031483930327844, 0.9387975102287419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 129}], {
             RGBColor[
             0.2625398824694277, 0.39327644083830926`, 0.9382626299624591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 140}], {
             RGBColor[
             0.3086221728107845, 0.4399248428735164, 0.9409523793012212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 149}], {
             RGBColor[
             0.29155965067616113`, 0.4237780571831614, 0.9399152628309327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 171}], {
             RGBColor[
             0.3537618197336009, 0.4790225362534377, 0.9438286376877205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 196}], {
             RGBColor[
             0.28505137622914434`, 0.4169374480909134, 0.9395446262293043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 230}], {
             RGBColor[
             0.2692612582166467, 0.40034103290847267`, 0.938645402367879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 245}], {
             RGBColor[
             0.35678647711021616`, 0.4816423424493619, 0.944021366181159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 263}], {
             RGBColor[
             0.2750769487244079, 0.40645369236820506`, 0.9389765973387527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 289}], {
             RGBColor[
             0.2900768000973668, 0.42221948720669167`, 0.9398308166841512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 298}], {
             RGBColor[
             0.2872112063681208, 0.41920756650811786`, 0.9396676253605367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 151}], {
             RGBColor[
             0.5499711557200619, 0.645038448022178, 0.9579401200370031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 167}], {
             RGBColor[
             0.7052976145619072, 0.7697031240469493, 0.9712611329047376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 194}], {
             RGBColor[
             0.5862509789073218, 0.6747647734348481, 0.960720844348837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 215}], {
             RGBColor[
             0.8258859987463416, 0.8619784867738793, 0.84861498208911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 283}], {
             RGBColor[
             0.6376959489926155, 0.716530117719581, 0.9647707808430861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 286}], {
             RGBColor[
             0.6078523188068897, 0.6923017142945901, 0.9624213809540463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 297}], {
             RGBColor[
             0.7085338986582898, 0.7722313337797134, 0.9715836954586705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 110}], {
             RGBColor[
             0.8870800066449858, 0.5061000302265065, 0.3757440054051945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 127}], {
             RGBColor[
             0.8336887126455463, 0.25995178464749, 0.1798936553163213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 141}], {
             RGBColor[
             0.8557654965670187, 0.3870748730161112, 0.19936752315815415`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 165}], {
             RGBColor[
             0.8828514694572672, 0.490674938099604, 0.2461602468156653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.887313539208574, 0.5061966019430634, 0.37187376646363723`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 240}], {
             RGBColor[
             0.8877425339879393, 0.506173605243856, 0.35019746163009025`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 281}], {
             RGBColor[
             0.834790145991334, 0.26841788399438415`, 0.18094838913213865`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 114}], {
             RGBColor[
             0.32416580444258236`, 0.4547970767096937, 0.9418912109282782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 145}], {
             RGBColor[
             0.3065621353882716, 0.43629450439653, 0.9408887080179298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 169}], {
             RGBColor[
             0.3184727377256654, 0.44881330262893604`, 0.9415669992008873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 187}], {
             RGBColor[
             0.35392495764506043`, 0.4809737423517148, 0.9437727632309596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 205}], {
             RGBColor[
             0.436683616415666, 0.5505880572448512, 0.9496172109793394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 213}], {
             RGBColor[
             0.3858995717541348, 0.5086685460021616, 0.9458101573679487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 219}], {
             RGBColor[
             0.30907770812291846`, 0.4389385308371674, 0.9410319661637115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 221}], {
             RGBColor[
             0.3192668900954462, 0.449648007121744, 0.9416122250035031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 264}], {
             RGBColor[
             0.3192908615453144, 0.4496732026354332, 0.9416135901421105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 110}], {
             RGBColor[
             0.9570573175626281, 0.9656649471847494, 0.8794550171346109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 138}], {
             RGBColor[
             0.8139262808550589, 0.8553825016885668, 0.9818711941291625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 154}], {
             RGBColor[
             0.8311843708271494, 0.8688646527411055, 0.9835913192515602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 179}], {
             RGBColor[
             0.9574076164080104, 0.9658098047595847, 0.8736496587222751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 258}], {
             RGBColor[
             0.941467846616602, 0.9554926988601389, 0.9709728498600104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 138}], {
             RGBColor[
             0.8498149400101593, 0.8810685488435381, 0.8689831282162525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 141}], {
             RGBColor[
             0.9459742116007779, 0.8128132585241278, 0.5020022278511405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 154}], {
             RGBColor[
             0.8670730299822498, 0.8945506998960768, 0.8707032533386501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 165}], {
             RGBColor[
             0.9866031709361507, 0.9682133561493669, 0.5721913133374072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 179}], {
             RGBColor[
             0.9932962755631108, 0.991495851914556, 0.7607615928093651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 281}], {
             RGBColor[
             0.8883662554104251, 0.5159867018754759, 0.3769757186755893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 190}], {
             RGBColor[
             0.2355732429285669, 0.36493279289716524`, 0.9367269197341752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 212}], {
             RGBColor[
             0.2273675902370908, 0.3563081316499939, 0.936259619952571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 242}], {
             RGBColor[
             0.24172339249525976`, 0.3713969900337639, 0.9370771616536675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 250}], {
             RGBColor[
             0.2327988220725642, 0.3620167006690641, 0.9365689205708136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 280}], {
             RGBColor[
             0.2555363699026189, 0.38591530508224947`, 0.9378637902825477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 115}], {
             RGBColor[
             0.236902386747869, 0.36632980732383724`, 0.9368026125083924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 134}], {
             RGBColor[
             0.2631071012640549, 0.3938726237552112, 0.9382949322336882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 146}], {
             RGBColor[
             0.24133200131587673`, 0.37098561308859834`, 0.937054872505013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 159}], {
             RGBColor[
             0.24980358255219737`, 0.3798897820972448, 0.9375373165238401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 175}], {
             RGBColor[
             0.27336230601956724`, 0.40465149417079094`, 0.9388789509732987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 204}], {
             RGBColor[
             0.24154807064065673`, 0.37121271564852854`, 0.9370671773334133]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 235}], {
             RGBColor[
             0.24712629913564943`, 0.3770757874768801, 0.9373848491939536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 242}], {
             RGBColor[
             0.24632291686669305`, 0.37623138177482907`, 0.937339097762234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 252}], {
             RGBColor[
             0.27637236437381507`, 0.40781525634982796`, 0.9390503693435908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 253}], {
             RGBColor[
             0.2744693999473012, 0.40581512008264853`, 0.9389419983346845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 280}], {
             RGBColor[
             0.2601358942740522, 0.3907496968233146, 0.9381257263911142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 292}], {
             RGBColor[
             0.24763746869084696`, 0.3776130590894144, 0.9374139595439145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 135}], {
             RGBColor[
             0.9747525126984742, 0.9797102206225822, 0.8836982332246824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 224}], {
             RGBColor[
             0.9644670009376046, 0.9390549690861945, 0.644851681061125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 249}], {
             RGBColor[
             0.8655230747652505, 0.41896226614950405`, 0.42814822498187033`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 254}], {
             RGBColor[
             0.925365599889266, 0.7843240503848107, 0.5923111720047104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 258}], {
             RGBColor[
             0.9605881616295711, 0.9701272959910724, 0.9515981414941335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 260}], {
             RGBColor[
             0.9042815340807562, 0.9259021424271057, 0.969533952973199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 278}], {
             RGBColor[
             0.7811703997408805, 0.8288870412862575, 0.957738894978919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 288}], {
             RGBColor[
             0.8944038389605427, 0.6336207235327678, 0.45551738437603884`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 290}], {
             RGBColor[
             0.7861690031762806, 0.8329451327396338, 0.9581324033518415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 145}], {
             RGBColor[
             0.28680752014306377`, 0.4187832666903979, 0.9396446360272199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 169}], {
             RGBColor[
             0.2987181224804576, 0.4313020649228039, 0.9403229272101774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 187}], {
             RGBColor[
             0.33417034239985266`, 0.4634625046455827, 0.9425286912402498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 213}], {
             RGBColor[
             0.366144956508927, 0.49115730829602955`, 0.944566085377239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 219}], {
             RGBColor[
             0.28932309287771063`, 0.4214272931310352, 0.9397878941730018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 221}], {
             RGBColor[
             0.29951227485023835`, 0.4321367694156119, 0.9403681530127932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 231}], {
             RGBColor[
             0.37476526938347776`, 0.4986237900384425, 0.945115364090962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 264}], {
             RGBColor[
             0.29953624630010656`, 0.4321619649293011, 0.9403695181514007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 132}], {
             RGBColor[
             0.21415169536183348`, 0.34241738819996653`, 0.9355069942905895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 146}], {
             RGBColor[
             0.22602095903949393`, 0.35489273687997036`, 0.9361829312980301]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 159}], {
             RGBColor[
             0.23449254027581456`, 0.3637969058886168, 0.9366653753168572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 204}], {
             RGBColor[
             0.22623702836427392`, 0.35511983943990055`, 0.9361952361264305]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 242}], {
             RGBColor[
             0.23101187459031025`, 0.36013850556620103`, 0.9364671565552513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 243}], {
             RGBColor[
             0.21987898042507611`, 0.348437127932281, 0.9358331547021821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 294}], {
             RGBColor[
             0.2157444487404361, 0.3440914729872748, 0.9355976992392334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 119}], {
             RGBColor[
             0.30231628529617693`, 0.4338208316047836, 0.9405740866574415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 133}], {
             RGBColor[
             0.3362774461822365, 0.4656883549123332, 0.9426482794056301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 152}], {
             RGBColor[
             0.2878519743324149, 0.4186179236915859, 0.9397503655460857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 164}], {
             RGBColor[
             0.35316605540790247`, 0.4803164193774241, 0.9437244066514788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 168}], {
             RGBColor[
             0.35414043439259346`, 0.4811603774802517, 0.9437864932187738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 210}], {
             RGBColor[
             0.35048246477995726`, 0.4779920280566848, 0.9435534106296721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 241}], {
             RGBColor[
             0.30074162674959204`, 0.4321657656332045, 0.9404844121827121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 277}], {
             RGBColor[
             0.33575144742336294`, 0.46523276122486323`, 0.9426147632298372]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 161}], {
             RGBColor[
             0.20987266837087443`, 0.33791985952648745`, 0.9352633100337076]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 120}], {
             RGBColor[
             0.1844220718220619, 0.3111696688926636, 0.9338139362110361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 130}], {
             RGBColor[
             0.17892828448197629`, 0.3053953500719979, 0.9335010731493483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 176}], {
             RGBColor[
             0.17894072364130287`, 0.30540842441713845`, 0.9335017815410699]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[
             0.17892828448197629`, 0.3053953500719979, 0.9335010731493483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 220}], {
             RGBColor[
             0.21806065403360642`, 0.34652595160629435`, 0.9357296037041608]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 226}], {
             RGBColor[
             0.17892828959271728`, 0.30539535544371077`, 0.9335010734403975]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 228}], {
             RGBColor[
             0.49763640594137093`, 0.5809247565206876, 0.9579151348288255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 266}], {
             RGBColor[
             0.21328176149194045`, 0.3415030325457159, 0.9354574528436509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 152}], {
             RGBColor[
             0.2677604183233837, 0.39876355502190786`, 0.9385599317562512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 164}], {
             RGBColor[
             0.33307449939887124`, 0.46046205070774604`, 0.9425339728616443]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 168}], {
             RGBColor[
             0.3340488783835623, 0.46130600881057365`, 0.9425960594289393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 241}], {
             RGBColor[
             0.2806500707405608, 0.4123113969635265, 0.9392939783928775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 130}], {
             RGBColor[
             0.18442078734008566`, 0.31116831882066576`, 0.9338138630616879]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 176}], {
             RGBColor[
             0.18443322649941224`, 0.31118139316580623`, 0.9338145714534094]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 287}], {
             RGBColor[
             0.5654447927305568, 0.5603176274195498, 0.6027460190921992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 125}], {
             RGBColor[
             0.9936176446660105, 0.9887571122327337, 0.5466981931057444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 127}], {
             RGBColor[
             0.8867181042579634, 0.498897479652069, 0.3375850577582036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 136}], {
             RGBColor[
             0.9937588965574554, 0.9890592357457773, 0.5620725897838914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 137}], {
             RGBColor[
             0.8952475121146669, 0.5644582460490475, 0.34575282835437127`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 160}], {
             RGBColor[
             0.7924150587076538, 0.8345430649548763, 0.8078033989134862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 181}], {
             RGBColor[
             0.8542136005503994, 0.8836192586014792, 0.8134168223712162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 232}], {
             RGBColor[
             0.9943533317427773, 0.9903306725005643, 0.626773191277452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 240}], {
             RGBColor[
             0.9947718410408293, 0.9912258215713169, 0.6723253456304181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 246}], {
             RGBColor[
             0.796739020185918, 0.8380534516751759, 0.8081437970002479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 256}], {
             RGBColor[
             0.9949290492403844, 0.9915620740139779, 0.6894364879754314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 296}], {
             RGBColor[
             0.8454228514141477, 0.8767518585640715, 0.8125406426515358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 299}], {
             RGBColor[
             0.9945473356554072, 0.9914335784226265, 0.6978961075730188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 136}], {
             RGBColor[
             0.8085502082780569, 0.8465126824966431, 0.7164898471021924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 160}], {
             RGBColor[
             0.6072063704282553, 0.6919965117057422, 0.9622206562317872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 181}], {
             RGBColor[
             0.6690049122710009, 0.741072705352345, 0.9678340796895172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 207}], {
             RGBColor[
             0.6848905103681076, 0.7534826553208219, 0.9694174076484823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 231}], {
             RGBColor[
             0.5346560481729267, 0.6328742791629598, 0.9565707376227028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 232}], {
             RGBColor[
             0.8091446434633787, 0.8477841192514302, 0.781190448595753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 240}], {
             RGBColor[
             0.8095631527614308, 0.8486792683221828, 0.8267426029487193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 246}], {
             RGBColor[
             0.6115303319065195, 0.6955068984260417, 0.962561054318549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 256}], {
             RGBColor[
             0.8097203609609858, 0.8490155207648438, 0.8438537452937325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 296}], {
             RGBColor[
             0.6602141631347492, 0.7342053053149373, 0.9669578999698369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 299}], {
             RGBColor[
             0.8093386473760087, 0.8488870251734923, 0.8523133648913199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 144}], {
             RGBColor[
             0.3759650676291757, 0.5000637778518178, 0.9451771395498434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 157}], {
             RGBColor[
             0.3911005410183704, 0.5131733641705265, 0.9461415585304294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 229}], {
             RGBColor[
             0.3913046976868122, 0.5133501944155183, 0.9461545672128138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 257}], {
             RGBColor[
             0.41376298296839165`, 0.5328024323401832, 0.9475855892918741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 259}], {
             RGBColor[
             0.4502407471664895, 0.5641005142419657, 0.9499920164228051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 261}], {
             RGBColor[
             0.41843101459212195`, 0.5368456467105671, 0.9478830321391599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 125}], {
             RGBColor[
             0.970159485355791, 0.9735725032155419, 0.706048969605638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 142}], {
             RGBColor[
             0.8033587771487245, 0.8470321673736835, 0.9700369554308557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 150}], {
             RGBColor[
             0.9548500534233739, 0.9658478242861803, 0.9613112619489188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 200}], {
             RGBColor[
             0.916844882326316, 0.7678634053812667, 0.6000047488264095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 237}], {
             RGBColor[
             0.7932365579017887, 0.8390697764976703, 0.9690655590701622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 282}], {
             RGBColor[
             0.9556754222393467, 0.9664633829977154, 0.9599141278341408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 295}], {
             RGBColor[
             0.8924892919776035, 0.9168014387328876, 0.9788835440663946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 136}], {
             RGBColor[
             0.9927664178883965, 0.9869364242276462, 0.4540474115251879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 150}], {
             RGBColor[
             0.9773157340645346, 0.9789096217852411, 0.6939353071903218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[
             0.8788040152312967, 0.44173686637663945`, 0.258623330792337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 192}], {
             RGBColor[
             0.907532480377328, 0.648755039325108, 0.28559331328553295`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 195}], {
             RGBColor[
             0.8769708936625604, 0.4276466907203388, 0.25686793150790044`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 200}], {
             RGBColor[
             0.9393105629674767, 0.7809252028803274, 0.3326287940678124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 256}], {
             RGBColor[
             0.9939365705713255, 0.9894392624958468, 0.5814113097167279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 299}], {
             RGBColor[
             0.9935548569863483, 0.9893107669044954, 0.5898709293143154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 155}], {
             RGBColor[
             0.21912067898952223`, 0.3476401050444259, 0.9357899705572339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 163}], {
             RGBColor[
             0.23364896427549098`, 0.3629102540264691, 0.9366173349115978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 184}], {
             RGBColor[
             0.23168784072436213`, 0.3608489888318178, 0.9365056518265833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 189}], {
             RGBColor[
             0.22889351140479614`, 0.3579119715462422, 0.9363465189056738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 197}], {
             RGBColor[
             0.21821940668747852`, 0.34669281071101354`, 0.9357386444329454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 214}], {
             RGBColor[
             0.21941035515512047`, 0.34794457306099935`, 0.9358064671863272]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 216}], {
             RGBColor[
             0.24238826022285348`, 0.3720958081705137, 0.9371150248871702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 275}], {
             RGBColor[
             0.21935857397151598`, 0.34789014775391436`, 0.9358035183245244]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 293}], {
             RGBColor[
             0.21759994210882713`, 0.34604171416252816`, 0.9357033668416068]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 136}], {
             RGBColor[
             0.886150619739554, 0.4976836876486773, 0.27581787003783265`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 137}], {
             RGBColor[
             0.837036798647762, 0.2856866408011604, 0.18309978625316525`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 141}], {
             RGBColor[
             0.8548488786408825, 0.38002934597129234`, 0.19848976879691427`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 165}], {
             RGBColor[
             0.8819348515311312, 0.4836294110547851, 0.24528249245442546`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 170}], {
             RGBColor[
             0.8291458764290967, 0.22503355480433335`, 0.17554343022504929`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 192}], {
             RGBColor[
             0.8435101090021122, 0.32854264127856764`, 0.18902842147164728`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 228}], {
             RGBColor[
             0.8272958107858699, 0.4540884427009072, 0.44678697508970566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 232}], {
             RGBColor[
             0.8865469098631019, 0.4985313121518687, 0.318951604366873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 240}], {
             RGBColor[
             0.8868259160618033, 0.4991280781990371, 0.3493197072688504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 256}], {
             RGBColor[
             0.8869307215281732, 0.49935224649414445`, 0.36072713549885926`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 281}], {
             RGBColor[
             0.833873528065198, 0.26137235694956523`, 0.1800706347708988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 299}], {
             RGBColor[
             0.8866762458048552, 0.4992665827665768, 0.36636688189725086`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 173}], {
             RGBColor[
             0.24821711809960986`, 0.3782223073699194, 0.9374469697202291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 209}], {
             RGBColor[
             0.25220846656924684`, 0.38241746767761725`, 0.9376742711109041]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 218}], {
             RGBColor[
             0.24765166805898178`, 0.377627983525616, 0.9374147681769237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 276}], {
             RGBColor[
             0.235521079118485, 0.3648779654253926, 0.9367239490823606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 279}], {
             RGBColor[
             0.24902661375038676`, 0.3790731386238746, 0.9374930692999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 161}], {
             RGBColor[
             0.22609023535273692`, 0.35496555067756064`, 0.9361868764815843]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 230}], {
             RGBColor[
             0.2426308084736596, 0.3723507417605582, 0.9371288376512357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 263}], {
             RGBColor[
             0.24844649898142085`, 0.37846340122029065`, 0.9374600326221096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 265}], {
             RGBColor[
             0.22918762870603976`, 0.3582211074779632, 0.936363268450872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 269}], {
             RGBColor[
             0.23146736458154496`, 0.36061725442672216`, 0.9364930960364151]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 289}], {
             RGBColor[
             0.26344635035437974`, 0.39422919605877726`, 0.9383142519675081]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 298}], {
             RGBColor[
             0.26058075662513375`, 0.3912172753602034, 0.9381510606438935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 176}], {
             RGBColor[
             0.17893943915932659`, 0.3054070743451405, 0.9335017083917216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 199}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 220}], {
             RGBColor[
             0.21805936955163013`, 0.34652460153429643`, 0.9357295305548126]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 226}], {
             RGBColor[
             0.178927005110741, 0.3053940053717128, 0.9335010002910491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 228}], {
             RGBColor[
             0.49763512145939465`, 0.5809234064486897, 0.9579150616794772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 266}], {
             RGBColor[
             0.21328047700996416`, 0.3415016824737179, 0.9354573796943026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 139}], {
             RGBColor[
             0.29015495986038786`, 0.4208144502573191, 0.9398897209981389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 143}], {
             RGBColor[
             0.3607906299670138, 0.4869204426382663, 0.9442102378002388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 172}], {
             RGBColor[
             0.297163306859998, 0.4281806673087738, 0.9402888359918464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 174}], {
             RGBColor[
             0.3585773503848271, 0.4850034111068425, 0.9440692095823882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 183}], {
             RGBColor[
             0.2897103519915022, 0.4203471391973532, 0.9398644012377442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 283}], {
             RGBColor[
             0.47177717102653804`, 0.5785602690993044, 0.9525231166057517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 188}], {
             RGBColor[
             0.20621351468350757`, 0.3340738569973212, 0.9350549266444448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 212}], {
             RGBColor[
             0.20921642322248857`, 0.3372301042671883, 0.9352259378433346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 243}], {
             RGBColor[
             0.21243933131542342`, 0.34061758501703826`, 0.935409477691362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 294}], {
             RGBColor[
             0.2083047996307834, 0.33627193007203204`, 0.9351740222284133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 162}], {
             RGBColor[
             0.31733689752319516`, 0.44704376794557543`, 0.9415233937816148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 164}], {
             RGBColor[
             0.36703566028493084`, 0.49232957401529565`, 0.9446081656098331]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 210}], {
             RGBColor[
             0.36435206965698563`, 0.49000518269455634`, 0.9444371695880264]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 239}], {
             RGBColor[
             0.38064066205782954`, 0.5041135427437089, 0.9454750642923715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 241}], {
             RGBColor[
             0.3146112316266204, 0.4441789202710761, 0.9413681711410662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 277}], {
             RGBColor[
             0.3496210523003913, 0.4772459158627348, 0.9434985221881913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 144}], {
             RGBColor[
             0.29485513198583013`, 0.42659799471298, 0.9401265091035182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 159}], {
             RGBColor[
             0.26069725479200045`, 0.3913397223199907, 0.9381576950421531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 175}], {
             RGBColor[
             0.2842559782593704, 0.41610143439353686`, 0.9394993294916116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 204}], {
             RGBColor[
             0.25244174288045984`, 0.38266265587127446`, 0.9376875558517261]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 235}], {
             RGBColor[
             0.2580199713754525, 0.388525727699626, 0.9380052277122666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 252}], {
             RGBColor[
             0.28726603661361816`, 0.4192651965725739, 0.9396707478619037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 253}], {
             RGBColor[
             0.2853630721871043, 0.41726506030539445`, 0.9395623768529974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 292}], {
             RGBColor[
             0.2585311409306501, 0.3890629993121603, 0.9380343380622274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 224}], {
             RGBColor[
             0.9798102252026126, 0.9495170954171317, 0.5749562479700403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 249}], {
             RGBColor[
             0.8757518909419225, 0.42593701703679554`, 0.3815512695878138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 254}], {
             RGBColor[
             0.940708824154274, 0.7947861767157479, 0.5224157389136257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 258}], {
             RGBColor[
             0.9759313858945792, 0.9805894223220096, 0.8817027084030489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 260}], {
             RGBColor[
             0.9196247583457642, 0.9363642687580429, 0.8996385198821143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 288}], {
             RGBColor[
             0.9046326551372147, 0.6405954744200593, 0.40892042898198233`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 137}], {
             RGBColor[
             0.8946800275962575, 0.5632444540456559, 0.2839856406340002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 165}], {
             RGBColor[
             0.9865840174672071, 0.9661571328498515, 0.42361874182822423`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 181}], {
             RGBColor[
             0.8533623737727853, 0.8817985705963918, 0.7207660407906598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 232}], {
             RGBColor[
             0.9935021049651632, 0.9885099844954769, 0.5341224096968956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 240}], {
             RGBColor[
             0.9939206142632153, 0.9894051335662295, 0.5796745640498617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 256}], {
             RGBColor[
             0.9940778224627702, 0.9897413860088904, 0.596785706394875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 296}], {
             RGBColor[
             0.8445716246365338, 0.8749311705589841, 0.7198898610709794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 299}], {
             RGBColor[
             0.9936961088777931, 0.9896128904175391, 0.6052453259924624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 170}], {
             RGBColor[
             0.8376752842858002, 0.29059432120131196`, 0.18371120082121695`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 192}], {
             RGBColor[
             0.8520395168588157, 0.39410340767554625`, 0.19719619206781494`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 195}], {
             RGBColor[
             0.836758723501432, 0.2835492333731616, 0.18283350117899866`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 220}], {
             RGBColor[
             0.6494413840373972, 0.36338333915495696`, 0.44016439160276355`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 228}], {
             RGBColor[
             0.8358252186425734, 0.5196492090978858, 0.45495474568587335`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 232}], {
             RGBColor[
             0.8950763177198054, 0.5640920785488474, 0.32711937496304067`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 256}], {
             RGBColor[
             0.8954601293848767, 0.5649130128911231, 0.36889490609502695`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 266}], {
             RGBColor[
             0.6462554556762865, 0.36003472644790463`, 0.439982957695757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 299}], {
             RGBColor[
             0.8952056536615587, 0.5648273491635555, 0.37453465249341855`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 154}], {
             RGBColor[
             0.7239419932746806, 0.7842682543998942, 0.9731194303332016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 171}], {
             RGBColor[
             0.5625186052786886, 0.6537822219340037, 0.9596386929535714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 245}], {
             RGBColor[
             0.5655432626553039, 0.6564020281299278, 0.9598314214470098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 258}], {
             RGBColor[
             0.8342254690641332, 0.8708963005189276, 0.9605009609416519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 147}], {
             RGBColor[
             0.2408356632285271, 0.3704639302891415, 0.9370266067852049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 148}], {
             RGBColor[
             0.24714609636833407`, 0.37709659562364867`, 0.9373859766170676]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 172}], {
             RGBColor[
             0.26248705403553485`, 0.3932209148047717, 0.9382596214613016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 183}], {
             RGBColor[
             0.2550340991670391, 0.38538738669335115`, 0.9378351867071995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 206}], {
             RGBColor[
             0.2460762386198535, 0.3759721072970965, 0.9373250498010044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 244}], {
             RGBColor[
             0.2489949569451404, 0.37903986531440326`, 0.9374912664917726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 272}], {
             RGBColor[
             0.23937950956716447`, 0.3689334204655748, 0.9369436809883765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 149}], {
             RGBColor[
             0.3110114912745308, 0.4424361680704541, 0.9410884474530516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 171}], {
             RGBColor[
             0.37321366033197056`, 0.49768064714073046`, 0.9450018223098395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 196}], {
             RGBColor[
             0.304503216827514, 0.4355955589782061, 0.9407178108514234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 198}], {
             RGBColor[
             0.3961646850276139, 0.5172626963041967, 0.9465462963516883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 222}], {
             RGBColor[
             0.3821033463817397, 0.505380446388428, 0.94556826524409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 230}], {
             RGBColor[
             0.2887130988150164, 0.4189991437957653, 0.9398185869899978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 245}], {
             RGBColor[
             0.37623831770858585`, 0.5003004533366545, 0.945194550803278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 263}], {
             RGBColor[
             0.2945287893227776, 0.42511180325549774`, 0.9401497819608717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 289}], {
             RGBColor[
             0.3095286406957365, 0.4408775980939844, 0.9410040013062702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 298}], {
             RGBColor[
             0.3066630469664905, 0.4378656773954105, 0.9408408099826556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 165}], {
             RGBColor[
             0.9396314058192, 0.789675620333774, 0.3076265899668467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 179}], {
             RGBColor[
             0.9463245104461602, 0.8129581160989631, 0.4961968694388046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 232}], {
             RGBColor[
             0.9465494933171561, 0.8120284719793993, 0.41813025783551805`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[
             0.9469680026152082, 0.812923621050152, 0.46368241218848416`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 281}], {
             RGBColor[
             0.857051745332458, 0.3969615446650806, 0.200599236428549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[
             0.810515025857468, 0.8523692859433827, 0.9579232930155395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 185}], {
             RGBColor[
             0.6135470246958941, 0.696888857774001, 0.9628943539449815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 210}], {
             RGBColor[
             0.5187904189187625, 0.6179312424348968, 0.9559956436547723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 237}], {
             RGBColor[
             0.6489015303358828, 0.7255912381548726, 0.9656775901367828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 239}], {
             RGBColor[
             0.5350790113196064, 0.6320396024840493, 0.9570335383591173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 282}], {
             RGBColor[
             0.8113403946734408, 0.8529848446549176, 0.9565261589007614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 283}], {
             RGBColor[
             0.6388734394755219, 0.7174499822340865, 0.964888142090148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 295}], {
             RGBColor[
             0.7481542644116976, 0.8033229003900898, 0.9754955751330152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 297}], {
             RGBColor[
             0.7097113891411961, 0.773151198294219, 0.9717010567057325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 167}], {
             RGBColor[
             0.5753382538779925, 0.6628795153036178, 0.9613047709389584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 172}], {
             RGBColor[
             0.33312272414216076`, 0.4593269071857189, 0.9425801382634016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 174}], {
             RGBColor[
             0.39453676766698986`, 0.5161496509837875, 0.9463605118539434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 185}], {
             RGBColor[
             0.482410173529073, 0.5891453845161638, 0.9528206307321404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 237}], {
             RGBColor[
             0.5177646791690618, 0.6178477648970354, 0.9556038669239417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 239}], {
             RGBColor[
             0.4039421601527854, 0.5242961292262122, 0.9469598151462764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 283}], {
             RGBColor[
             0.5077365883087008, 0.6097065089762495, 0.9548144188773069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 297}], {
             RGBColor[
             0.5785745379743751, 0.6654077250363819, 0.9616273334928914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 158}], {
             RGBColor[
             0.35967077338482056`, 0.4859504791523989, 0.9441388815290719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 235}], {
             RGBColor[
             0.27887432985742466`, 0.4098011584346488, 0.9392164260637837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 252}], {
             RGBColor[
             0.3081203950955903, 0.44054062730759674`, 0.940881946213421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 253}], {
             RGBColor[
             0.30621743066907636`, 0.4385404910404173, 0.9407735752045145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 257}], {
             RGBColor[
             0.3535074058070181, 0.4806120799363681, 0.9437461571970662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 292}], {
             RGBColor[
             0.2793854994126222, 0.4103384300471832, 0.9392455364137446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 169}], {
             RGBColor[
             0.28111445342614677`, 0.4127994926096401, 0.939320424299829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 219}], {
             RGBColor[
             0.27171942382339986`, 0.4029247208178715, 0.9387853912626534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 221}], {
             RGBColor[
             0.2819086057959276, 0.4136341971024482, 0.9393656501024449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 264}], {
             RGBColor[
             0.28193257724579573`, 0.4136593926161374, 0.9393670152410523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 159}], {
             RGBColor[
             0.2389221548438223, 0.3684527116533779, 0.9369176353134778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 204}], {
             RGBColor[
             0.23066664293228167`, 0.35977564520466165`, 0.936447496123051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 235}], {
             RGBColor[
             0.23624487142727435`, 0.3656387170330131, 0.9367651679835913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 242}], {
             RGBColor[
             0.23544148915831797`, 0.3647943113309621, 0.9367194165518717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 243}], {
             RGBColor[
             0.22430859499308387`, 0.3530929336970421, 0.9360854146988027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 292}], {
             RGBColor[
             0.2367560409824719, 0.36617598864554746`, 0.9367942783335522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 148}], {
             RGBColor[
             0.2325030525609364, 0.36170582815947316`, 0.9365520769346783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 172}], {
             RGBColor[
             0.2478440102281372, 0.3778301473405962, 0.9374257217789124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 183}], {
             RGBColor[
             0.24039105535964145`, 0.36999661922917565`, 0.9370012870248101]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 206}], {
             RGBColor[
             0.23143319481245586`, 0.360581339832921, 0.9364911501186151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 244}], {
             RGBColor[
             0.23435191313774276`, 0.3636490978502278, 0.9366573668093834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 270}], {
             RGBColor[
             0.2272240069658551, 0.35615721652822, 0.9362514430976865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 272}], {
             RGBColor[
             0.2247364657597668, 0.3535426530013993, 0.9361097813059873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 172}], {
             RGBColor[
             0.2541544433679442, 0.3844628126751034, 0.9377850916107751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 183}], {
             RGBColor[
             0.2467014884994484, 0.37662928456368283`, 0.937360656856673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 203}], {
             RGBColor[
             0.2492037147300215, 0.37925928298232137`, 0.9375031549387921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 206}], {
             RGBColor[
             0.23774362795226284`, 0.3672140051674282, 0.9368505199504779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 244}], {
             RGBColor[
             0.24066234627754973`, 0.37028176318473494`, 0.9370167366412461]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 270}], {
             RGBColor[
             0.23353444010566207`, 0.3627898818627272, 0.9366108129295494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 272}], {
             RGBColor[
             0.23104689889957378`, 0.3601753183359065, 0.93646915113785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 171}], {
             RGBColor[
             0.3561511381973472, 0.48153386145037547`, 0.943964705839551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 227}], {
             RGBColor[
             0.27685707898321577`, 0.40832472213698934`, 0.9390779731235251]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 245}], {
             RGBColor[
             0.3591757955739624, 0.4841536676462995, 0.9441574343329895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 289}], {
             RGBColor[
             0.29246611856111315`, 0.4247308124036294, 0.9399668848359817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 298}], {
             RGBColor[
             0.28960052483186716`, 0.4217188917050555, 0.9398036935123671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 200}], {
             RGBColor[
             0.9240011310350597, 0.7732005239509658, 0.5878910864110933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 237}], {
             RGBColor[
             0.8003928066105324, 0.8444068950673695, 0.956951896654846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 282}], {
             RGBColor[
             0.9628316709480902, 0.9718005015674145, 0.9478004654188247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 295}], {
             RGBColor[
             0.8996455406863472, 0.9221385573025866, 0.9667698816510785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 167}], {
             RGBColor[
             0.5986000016649633, 0.6830276720672528, 0.9627869889383882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 194}], {
             RGBColor[
             0.4795533660103779, 0.5880893214551517, 0.9522467003824877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 251}], {
             RGBColor[
             0.36499365332834144`, 0.4885238594535514, 0.944552636407374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 286}], {
             RGBColor[
             0.5011547059099458, 0.6056262623148936, 0.953947236987697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 241}], {
             RGBColor[
             0.2661857597767988, 0.3971084890503288, 0.9384702572815218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 277}], {
             RGBColor[
             0.3011955804505697, 0.43017548464198757`, 0.9406006083286469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 163}], {
             RGBColor[
             0.2574205034515923, 0.3878956489031873, 0.9379710889008359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 211}], {
             RGBColor[
             0.25792046228139853`, 0.38842113733253425`, 0.9379995608165705]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 216}], {
             RGBColor[
             0.2661597993989548, 0.3970812030472318, 0.9384687788764086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 219}], {
             RGBColor[
             0.2738583241419696, 0.40517284066680126`, 0.9389071984715764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 221}], {
             RGBColor[
             0.2840475061144973, 0.4158823169513779, 0.939487457311368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 171}], {
             RGBColor[
             0.5797766952507789, 0.6672643729865424, 0.9613588180759691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 179}], {
             RGBColor[
             0.8674233288276321, 0.8946955574709121, 0.8648978949263142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 245}], {
             RGBColor[
             0.5828013526273942, 0.6698841791824666, 0.9615515465694076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 156}], {
             RGBColor[
             0.22000089461836236`, 0.3485652674792311, 0.935840097535134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 184}], {
             RGBColor[
             0.22486994634019453`, 0.35368294955458646`, 0.9361173828275757]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 197}], {
             RGBColor[
             0.21140151230331092`, 0.3395267714337822, 0.9353503754339378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 202}], {
             RGBColor[
             0.22021191752572378`, 0.34878706593449305`, 0.9358521149775277]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 214}], {
             RGBColor[
             0.21259246077095287`, 0.340778533783768, 0.9354181981873197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 275}], {
             RGBColor[
             0.21254067958734837`, 0.340724108476683, 0.9354152493255168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 293}], {
             RGBColor[
             0.21078204772465953`, 0.3388756748852968, 0.9353150978425994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 178}], {
             RGBColor[
             0.25237767810444756`, 0.38259531972974414`, 0.9376839074575076]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 202}], {
             RGBColor[
             0.22791002753873152`, 0.3568782676465297, 0.9362905109544353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 208}], {
             RGBColor[
             0.2568293808226203, 0.38727434154079826`, 0.9379374253416035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 214}], {
             RGBColor[
             0.2202905707839606, 0.3488697354958046, 0.9358565941642273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 268}], {
             RGBColor[
             0.2451076812596908, 0.374954092101482, 0.9372698918921952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 201}], {
             RGBColor[
             0.3335467378743898, 0.46332315262546664`, 0.9424742810869247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 218}], {
             RGBColor[
             0.30101158042666865`, 0.4302700565079032, 0.9405795858965723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 229}], {
             RGBColor[
             0.34618459391463335`, 0.47426942833041186`, 0.9432795540985917]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 257}], {
             RGBColor[
             0.3686428791962128, 0.49372166625507674`, 0.944710576177652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 259}], {
             RGBColor[
             0.40512064339431064`, 0.5250197481568593, 0.947117003308583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 261}], {
             RGBColor[
             0.3733109108199431, 0.49776488062546065`, 0.9450080190249379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 284}], {
             RGBColor[
             0.3008123283039969, 0.4300606298936609, 0.9405682387829533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 175}], {
             RGBColor[
             0.34907161965836087`, 0.47545391883295585`, 0.9435117019171652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 177}], {
             RGBColor[
             0.4114198455834537, 0.5307729245068593, 0.947436286649661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 217}], {
             RGBColor[
             0.6053338779034495, 0.6866046110497097, 0.9641707450092601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 252}], {
             RGBColor[
             0.35208167801260865`, 0.47861768101199287`, 0.9436831202874573]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 253}], {
             RGBColor[
             0.35017871358609476`, 0.47661754474481344`, 0.9435747492785509]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 175}], {
             RGBColor[
             0.2709524595475128, 0.4021185927355705, 0.9387417137817635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 204}], {
             RGBColor[
             0.23913822416860225`, 0.3686798142133081, 0.9369299401418781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 235}], {
             RGBColor[
             0.24471645266359499`, 0.3745428860416596, 0.9372476120024185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 252}], {
             RGBColor[
             0.2739625179017606, 0.4052823549146075, 0.9389131321520556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 253}], {
             RGBColor[
             0.27205955347524674`, 0.4032822186474281, 0.9388047611431494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 292}], {
             RGBColor[
             0.24522762221879252`, 0.3750801576541939, 0.9372767223523794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 168}], {
             RGBColor[
             0.4880465107801085, 0.5934258804224648, 0.9533459462263981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[
             0.6520185359229838, 0.7272823998054908, 0.9664968499202544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 246}], {
             RGBColor[
             0.5945439555585024, 0.6817165928791875, 0.9612238245492863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 256}], {
             RGBColor[
             0.7927339846129686, 0.8352252152179895, 0.8425165155244698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 296}], {
             RGBColor[
             0.6432277867867322, 0.7204149997680831, 0.9656206702005743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 299}], {
             RGBColor[
             0.7923522710279916, 0.8350967196266381, 0.8509761351220573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 186}], {
             RGBColor[
             0.22312007554742067`, 0.3518437244031648, 0.9360177302746292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 230}], {
             RGBColor[
             0.2328116110999559, 0.36203014274772405`, 0.9365696488870041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 265}], {
             RGBColor[
             0.21936843133233605`, 0.34790050846512904`, 0.9358040796866404]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 269}], {
             RGBColor[
             0.22164816720784125`, 0.350296655413888, 0.9359339072721834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 191}], {
             RGBColor[
             0.26420786908525307`, 0.39502960052800135`, 0.9383576193326653]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 203}], {
             RGBColor[
             0.27206034387321254`, 0.4032830494058043, 0.9388048061551442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 210}], {
             RGBColor[
             0.33154191612091594`, 0.45934744108992703`, 0.9424285250056568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 239}], {
             RGBColor[
             0.34783050852175984`, 0.47345580113907954`, 0.9434664197100019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 184}], {
             RGBColor[
             0.23939823162616325`, 0.3689530985366296, 0.9369447471819397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.23660390230659725`, 0.366016081251054, 0.9367856142610302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 197}], {
             RGBColor[
             0.22592979758927967`, 0.35479692041582533`, 0.9361777397883018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 211}], {
             RGBColor[
             0.2418593140070983, 0.3715398521606279, 0.9370849021826888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 216}], {
             RGBColor[
             0.2500986511246546, 0.3801999178753255, 0.9375541202425267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 168}], {
             RGBColor[
             0.38489864849528777`, 0.5078015965832141, 0.9457463794229767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 210}], {
             RGBColor[
             0.3812406788826516, 0.5046332471596473, 0.9455132968338751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 241}], {
             RGBColor[
             0.33149984085228634`, 0.458806984736167, 0.9424442983869149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 277}], {
             RGBColor[
             0.36650966152605724`, 0.4918739803278257, 0.94457464943404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 179}], {
             RGBColor[
             0.986953469781533, 0.9683582137242022, 0.5663859549250714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 207}], {
             RGBColor[
             0.8629243195572578, 0.8731271056740303, 0.676546302374514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 232}], {
             RGBColor[
             0.9871784526525289, 0.9674285696046385, 0.48831934332178484`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 240}], {
             RGBColor[
             0.987596961950581, 0.9683237186753911, 0.533871497674751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 281}], {
             RGBColor[
             0.8841377182227066, 0.5005616097485734, 0.24739196008606018`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 217}], {
             RGBColor[
             0.899879476841495, 0.9180128953290518, 0.7153753712159427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 233}], {
             RGBColor[
             0.9934058766223102, 0.9883041618002921, 0.5236485484298345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 262}], {
             RGBColor[
             0.9933514957949947, 0.9881878467094093, 0.5177295309761065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 271}], {
             RGBColor[
             0.9850940999243964, 0.9612451065301149, 0.40815265332302325`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 291}], {
             RGBColor[
             0.8761797606414349, 0.42138431296305434`, 0.25963779623893113`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 174}], {
             RGBColor[
             0.5731249742958058, 0.6609624837721939, 0.9611637427211077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 185}], {
             RGBColor[
             0.660998380157889, 0.7339582173045702, 0.9676238615993047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 194}], {
             RGBColor[
             0.6348798248522232, 0.7127539974799229, 0.9655677132502221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 215}], {
             RGBColor[
             0.874514844691243, 0.8999677108189541, 0.8534618509904951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 282}], {
             RGBColor[
             0.8587917501354356, 0.8900542041854869, 0.9612556665550847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 283}], {
             RGBColor[
             0.6863247949375169, 0.7545193417646557, 0.9696176497444712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 286}], {
             RGBColor[
             0.6564811647517911, 0.7302909383396649, 0.9672682498554315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 297}], {
             RGBColor[
             0.7571627446031911, 0.8102205578247882, 0.9764305643600557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 182}], {
             RGBColor[
             0.34652806688330007`, 0.474422427150048, 0.9433067307526943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 277}], {
             RGBColor[
             0.3674840405107483, 0.49271793843065337`, 0.944636736001335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 187}], {
             RGBColor[
             0.3284772756829356, 0.4574787305648249, 0.9422044795128589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 213}], {
             RGBColor[
             0.36045188979201, 0.48517353421527176`, 0.944241873649848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 219}], {
             RGBColor[
             0.2836300261607937, 0.41544351905027754`, 0.9394636824456108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 221}], {
             RGBColor[
             0.2938192081333214, 0.4261529953348542, 0.9400439412854023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 264}], {
             RGBColor[
             0.29384317958318956`, 0.42617819084854336`, 0.9400453064240097]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[
             0.836257672421485, 0.2727972356818921, 0.182083480011583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 195}], {
             RGBColor[
             0.8209768790641011, 0.16224306137950753`, 0.16772078912276672`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 200}], {
             RGBColor[
             0.8432609465449801, 0.30459746782045594`, 0.18792718360618468`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 225}], {
             RGBColor[
             0.8682499113225608, 0.4061856602973817, 0.21334848907618564`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 228}], {
             RGBColor[
             0.8200433742052426, 0.3983430371042317, 0.4398420336296414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 255}], {
             RGBColor[
             0.8675804054698418, 0.4039272598487107, 0.21074758526394385`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 198}], {
             RGBColor[
             0.4413043319504303, 0.556360389684118, 0.9494225547381876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 245}], {
             RGBColor[
             0.4213779646314022, 0.5393981467165758, 0.9480708091897773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 289}], {
             RGBColor[
             0.35466828761855285`, 0.4799752914739057, 0.9438802596927696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 298}], {
             RGBColor[
             0.35180269388930685`, 0.47696337077533185`, 0.9437170683691549]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 174}], {
             RGBColor[
             0.33090944455997406`, 0.4574098756542951, 0.9424391100455509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 183}], {
             RGBColor[
             0.2620424461666492, 0.39275360374480583`, 0.9382343017009069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 203}], {
             RGBColor[
             0.26454467239722235`, 0.39538360216344437`, 0.9383767997830261]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 206}], {
             RGBColor[
             0.2530845856194636, 0.3833383243485512, 0.9377241647947119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 244}], {
             RGBColor[
             0.2560033039447505, 0.38640608236585794`, 0.9378903814854801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 270}], {
             RGBColor[
             0.24887539777286288`, 0.3789142010438502, 0.9374844577737833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 272}], {
             RGBColor[
             0.2463878565667746, 0.37629963751702955`, 0.937342795982084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 186}], {
             RGBColor[
             0.24357136840210497`, 0.3733393298802981, 0.937182401147727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 196}], {
             RGBColor[
             0.2690530219671379, 0.40012216340729806`, 0.9386335436215274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 209}], {
             RGBColor[
             0.2611649721580388, 0.3918313229266909, 0.938184330854223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 230}], {
             RGBColor[
             0.25326290395464024`, 0.3835257482248573, 0.9377343197601018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 263}], {
             RGBColor[
             0.25907859446240145`, 0.3896384076845897, 0.9380655147309758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 276}], {
             RGBColor[
             0.24447758470727698`, 0.3742918206744662, 0.9372340088256796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 279}], {
             RGBColor[
             0.2579831193391787, 0.3884869938729482, 0.9380031290433184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 185}], {
             RGBColor[
             0.4801968939468863, 0.58722835298474, 0.9526796025142897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 194}], {
             RGBColor[
             0.45407833864122044`, 0.5660241331600927, 0.9506234541652072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 283}], {
             RGBColor[
             0.5055233087265141, 0.6077894774448256, 0.9546733906594562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 297}], {
             RGBColor[
             0.5763612583921884, 0.663490693504958, 0.9614863052750408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 177}], {
             RGBColor[
             0.3568594089399756, 0.48219931048302006`, 0.944007932963718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 242}], {
             RGBColor[
             0.2674717938620085, 0.3984601924131547, 0.9385434950201575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 252}], {
             RGBColor[
             0.2975212413691305, 0.4300440669881537, 0.9402547666015143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 253}], {
             RGBColor[
             0.29561827694261666`, 0.42804393072097424`, 0.9401463955926079]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 280}], {
             RGBColor[
             0.2812847712693677, 0.4129785074616403, 0.9393301236490378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 199}], {
             RGBColor[
             0.17893943915932659`, 0.3054070743451405, 0.9335017083917216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 226}], {
             RGBColor[
             0.17893944427006758`, 0.3054070797168533, 0.9335017086827707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 287}], {
             RGBColor[
             0.5599634445497977, 0.5545563829440247, 0.6024338644222329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 217}], {
             RGBColor[
             0.6131216671850642, 0.6933500026997739, 0.964666976055813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 247}], {
             RGBColor[
             0.4991479409504841, 0.603343634292864, 0.9539698061272375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 273}], {
             RGBColor[
             0.5185213619952923, 0.6190718502597115, 0.9554949527990644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 285}], {
             RGBColor[
             0.40098949086418123`, 0.5217386754938967, 0.9467716736701495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 182}], {
             RGBColor[
             0.29211972893207316`, 0.4243667349411374, 0.9399471584590454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 202}], {
             RGBColor[
             0.25258870101180897`, 0.3828171181850061, 0.9376959248999015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 208}], {
             RGBColor[
             0.2815080542956977, 0.41321319207927465`, 0.9393428392870697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 268}], {
             RGBColor[
             0.26978635473276824`, 0.4008929426399584, 0.9386753058376613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 281}], {
             RGBColor[
             0.8885997879740133, 0.5160832735920328, 0.3731054797340321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 190}], {
             RGBColor[
             0.23107912024585836`, 0.36020918501380295`, 0.9364709860958538]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 250}], {
             RGBColor[
             0.22830469938985565`, 0.3572930927857018, 0.9363129869324922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 207}], {
             RGBColor[
             0.729702675862836, 0.7887685434205706, 0.9736936013369495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 232}], {
             RGBColor[
             0.8539568089581072, 0.8830700073511788, 0.7854666422842203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 240}], {
             RGBColor[
             0.8543753182561593, 0.8839651564219314, 0.8310187966371865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 246}], {
             RGBColor[
             0.656342497401248, 0.7307927865257904, 0.9668372480070162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 256}], {
             RGBColor[
             0.8545325264557142, 0.8843014088645924, 0.8481299389821997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 296}], {
             RGBColor[
             0.7050263286294778, 0.769491193414686, 0.9712340936583042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 299}], {
             RGBColor[
             0.8541508128707371, 0.884172913273241, 0.8565895585797871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 208}], {
             RGBColor[
             0.2965714316502459, 0.42904575675219153`, 0.9402006763431414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 268}], {
             RGBColor[
             0.28484973208731645`, 0.4167255073128753, 0.939533142893733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 244}], {
             RGBColor[
             0.24855034907625476`, 0.37857255425443737`, 0.937465946731378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 189}], {
             RGBColor[
             0.2346427787554684, 0.3639548160564028, 0.9366739311760157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 197}], {
             RGBColor[
             0.22396867403815082`, 0.3527356552211741, 0.9360660567032872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 202}], {
             RGBColor[
             0.23277907926056368`, 0.361995949721885, 0.9365677962468772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 214}], {
             RGBColor[
             0.22515962250579277`, 0.3539874175711599, 0.9361338794566691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 216}], {
             RGBColor[
             0.24813752757352578`, 0.3781386526806742, 0.9374424371575123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 275}], {
             RGBColor[
             0.22510784132218828`, 0.35393299226407493`, 0.9361309305948662]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 293}], {
             RGBColor[
             0.22334920945949943`, 0.35208455867268873`, 0.9360307791119489]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 237}], {
             RGBColor[
             0.6034248054489583, 0.6889264668979879, 0.961922957584288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 239}], {
             RGBColor[
             0.4896022864326819, 0.5953748312271646, 0.9532789058066227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 282}], {
             RGBColor[
             0.7658636697865162, 0.8163200733980329, 0.9527715263482667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 283}], {
             RGBColor[
             0.5933967145885973, 0.6807852109772019, 0.9611335095376532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 295}], {
             RGBColor[
             0.7026775395247731, 0.7666581291332051, 0.9717409425805205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 297}], {
             RGBColor[
             0.6642346642542716, 0.7364864270373344, 0.9679464241532377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 196}], {
             RGBColor[
             0.255450766680841, 0.38582533066860314`, 0.9378589153057062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 230}], {
             RGBColor[
             0.23966064866834333`, 0.3692289154861624, 0.9369596914442806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 263}], {
             RGBColor[
             0.24547633917610456`, 0.3753415749458948, 0.9372908864151546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 269}], {
             RGBColor[
             0.2284972047762287, 0.3574954281523263, 0.93632394982946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 276}], {
             RGBColor[
             0.2308753294209801, 0.3599949879357713, 0.9364593805098584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 279}], {
             RGBColor[
             0.24438086405288187`, 0.3741901611342533, 0.9372285007274972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 205}], {
             RGBColor[
             0.44668815437293624`, 0.55925348518074, 0.950254691291311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 213}], {
             RGBColor[
             0.395904109711405, 0.5173339739380506, 0.9464476376799205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 264}], {
             RGBColor[
             0.3292953995025846, 0.4583386305713222, 0.9422510704540822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 212}], {
             RGBColor[
             0.20871789165381538`, 0.33670611597978567`, 0.9351975472080101]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 243}], {
             RGBColor[
             0.21194079974675017`, 0.3400935967296356, 0.9353810870560375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 294}], {
             RGBColor[
             0.20780626806211017`, 0.3357479417846294, 0.9351456315930887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 197}], {
             RGBColor[
             0.22117434471858483`, 0.3497986379355985, 0.9359069237823778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 211}], {
             RGBColor[
             0.23710386113640347`, 0.3665415696804011, 0.9368140861767649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 216}], {
             RGBColor[
             0.24534319825395978`, 0.3752016353950986, 0.9372833042366027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 275}], {
             RGBColor[
             0.22231351200262228`, 0.3509959749784993, 0.9359717976739568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 293}], {
             RGBColor[
             0.2205548801399334, 0.3491475413871131, 0.9358716461910392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 212}], {
             RGBColor[
             0.21992645288427248`, 0.3484870244968241, 0.9358358581885042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 250}], {
             RGBColor[
             0.22535768471974588`, 0.35419559351589436`, 0.9361451588067469]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 203}], {
             RGBColor[
             0.2517414689713402, 0.38192662359285945`, 0.9376476762885642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 195}], {
             RGBColor[
             0.8497053442101324, 0.36926123432797614`, 0.19469077161596268`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 200}], {
             RGBColor[
             0.8719894116910114, 0.5116156407689246, 0.21489716609938064`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[
             0.8969783764685921, 0.6132038332458503, 0.2403184715693816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 228}], {
             RGBColor[
             0.8487718393512739, 0.6053612100527003, 0.4668120161228374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 255}], {
             RGBColor[
             0.896308870615873, 0.6109454327971793, 0.23771756775713984`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 199}], {
             RGBColor[
             0.28921237678725265`, 0.4129203038152378, 0.9400888107445714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 220}], {
             RGBColor[
             0.3283447463388828, 0.4540509053495343, 0.9423173412993839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 236}], {
             RGBColor[
             0.511354201918838, 0.6127180573453962, 0.9550785966275717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 249}], {
             RGBColor[
             0.6788858964789302, 0.269361770595781, 0.42584254337299554`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 266}], {
             RGBColor[
             0.3235658537972168, 0.4490279862889558, 0.942045190438874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 283}], {
             RGBColor[
             0.5672781592829315, 0.6595809911525545, 0.9590773611885706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 286}], {
             RGBColor[
             0.5374345290972057, 0.6353525877275636, 0.9567279612995309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 297}], {
             RGBColor[
             0.6381161089486057, 0.715282207212687, 0.9658902758041552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 200}], {
             RGBColor[
             0.8414278249762438, 0.29050729216415533`, 0.1861717843217481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 225}], {
             RGBColor[
             0.8664167897538245, 0.3920954846410811, 0.21159308979174907`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.8657472839011056, 0.38983708419241014`, 0.20899218597950728`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 230}], {
             RGBColor[
             0.2651423022333762, 0.39601174901316233`, 0.938410833918081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 263}], {
             RGBColor[
             0.27095799274113747`, 0.40212440847289477`, 0.9387420288889549]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 279}], {
             RGBColor[
             0.2698625176179148, 0.40097299466125325`, 0.9386796432012976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 289}], {
             RGBColor[
             0.28595784411409636`, 0.4178902033113814, 0.9395962482343534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 298}], {
             RGBColor[
             0.28309225038485036`, 0.4148782826128075, 0.9394330569107388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 214}], {
             RGBColor[
             0.21169118846890916`, 0.33983123945035565`, 0.9353668720630313]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 275}], {
             RGBColor[
             0.21163940728530467`, 0.33977681414327066`, 0.9353639232012283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 293}], {
             RGBColor[
             0.20988077542261582`, 0.33792838055188446`, 0.9352637717183109]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 222}], {
             RGBColor[
             0.4501940180001994, 0.5640601889318158, 0.9499889976724383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 245}], {
             RGBColor[
             0.4443289893270455, 0.5589801958800422, 0.949615283231626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 258}], {
             RGBColor[
             0.7130111957358749, 0.7734744682690422, 0.9502848227262681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 278}], {
             RGBColor[
             0.5335934338471843, 0.6322342135642272, 0.9564255762110536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 290}], {
             RGBColor[
             0.5385920372825843, 0.6362923050176035, 0.9568190845839761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 220}], {
             RGBColor[
             0.21805936955163013`, 0.34652460153429643`, 0.9357295305548126]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 226}], {
             RGBColor[
             0.178927005110741, 0.3053940053717128, 0.9335010002910491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 228}], {
             RGBColor[
             0.49763512145939465`, 0.5809234064486897, 0.9579150616794772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 266}], {
             RGBColor[
             0.21328047700996416`, 0.3415016824737179, 0.9354573796943026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 225}], {
             RGBColor[
             0.9234794071043728, 0.7275983937614409, 0.2647165314935854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 255}], {
             RGBColor[
             0.9224751483252943, 0.7242107930884344, 0.2608151757752228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 282}], {
             RGBColor[
             0.9248264998510323, 0.7738160826625009, 0.5864939522963153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 295}], {
             RGBColor[
             0.8616403695892892, 0.7241541383976731, 0.6054633685285691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 209}], {
             RGBColor[
             0.29313467956513195`, 0.424290095199951, 0.9400468245012701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 218}], {
             RGBColor[
             0.2885778810548669, 0.4195006110479498, 0.9397873215672898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 229}], {
             RGBColor[
             0.3337508945428317, 0.46349998287045846`, 0.9424872897693092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 257}], {
             RGBColor[
             0.35620917982441114`, 0.48295222079512334`, 0.9439183118483695]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 259}], {
             RGBColor[
             0.3926869440225089, 0.5142503026969059, 0.9463247389793005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 261}], {
             RGBColor[
             0.36087721144814144`, 0.48699543516550725`, 0.9442157546956553]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 208}], {
             RGBColor[
             0.2570404037299817, 0.3874961399960602, 0.9379494427839974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 214}], {
             RGBColor[
             0.22050159369132202`, 0.3490915339510665, 0.935868611606621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 268}], {
             RGBColor[
             0.2453187041670522, 0.37517589055674394`, 0.937281909334589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 275}], {
             RGBColor[
             0.22044981250771753`, 0.3490371086439815, 0.9358656627448182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 206}], {
             RGBColor[
             0.24813385698154097`, 0.37813479465576916`, 0.9374422281227288]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 244}], {
             RGBColor[
             0.2510525753068279, 0.38120255267307596`, 0.9376084448134971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 270}], {
             RGBColor[
             0.2439246691349402, 0.37371067135106817`, 0.9372025211018002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 235}], {
             RGBColor[
             0.23646094075205434`, 0.36586581959294334`, 0.9367774728119916]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 253}], {
             RGBColor[
             0.26380404156370607`, 0.39460515219871184`, 0.9383346219527224]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 292}], {
             RGBColor[
             0.2369721103072519, 0.36640309120547765`, 0.9368065831619525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 213}], {
             RGBColor[
             0.4786627684820106, 0.5869482888311869, 0.9522920854283001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 231}], {
             RGBColor[
             0.4872830813565614, 0.5944147705735998, 0.9528413641420233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 244}], {
             RGBColor[
             0.23959248852906917`, 0.3691572748581827, 0.9369558098251829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 270}], {
             RGBColor[
             0.23246458235718154`, 0.361665393536175, 0.936549886113486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 272}], {
             RGBColor[
             0.22997704115109324`, 0.35905083000935434`, 0.9364082243217868]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 231}], {
             RGBColor[
             0.5953538117647618, 0.6805701172311853, 0.962430259270135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 232}], {
             RGBColor[
             0.8698424070552139, 0.8954799573196557, 0.7870499702431855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 240}], {
             RGBColor[
             0.870260916353266, 0.8963751063904083, 0.8326021245961515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 268}], {
             RGBColor[
             0.274238057450941, 0.4055719644510125, 0.9389288237217572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 218}], {
             RGBColor[
             0.2605995221174108, 0.3912369990823875, 0.9381521293109176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 276}], {
             RGBColor[
             0.24846893317691396`, 0.37848698098216405`, 0.9374613102163545]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 279}], {
             RGBColor[
             0.2619744678088157, 0.39268215418064606`, 0.9382304304339932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 239}], {
             RGBColor[
             0.39484568065555037`, 0.5164172158880604, 0.9463801955164135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 277}], {
             RGBColor[
             0.36382607089811214`, 0.48954958900708645`, 0.9444036534122333]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 216}], {
             RGBColor[
             0.2505986099544608, 0.38072540630467244`, 0.9375825921582613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 221}], {
             RGBColor[
             0.26848631667000333`, 0.39952652020881857`, 0.9386012705932207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 243}], {
             RGBColor[
             0.2149437082857312, 0.34324984399950276`, 0.9355520982549272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 250}], {
             RGBColor[
             0.21715203202826977`, 0.34557093226872304`, 0.9356778590251427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 294}], {
             RGBColor[
             0.2108091766010912, 0.3389041890544966, 0.9353166427919786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 231}], {
             RGBColor[
             0.43649903669503015`, 0.5524952593309104, 0.9490343105306326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 264}], {
             RGBColor[
             0.36127001361165895`, 0.48603343422176903`, 0.9442884645910713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 275}], {
             RGBColor[
             0.21283035575294662`, 0.34102857649325646`, 0.9354317459546102]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 293}], {
             RGBColor[
             0.21107172389025777`, 0.33918014290187026`, 0.9353315944716927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 223}], {
             RGBColor[
             0.9412290011481947, 0.7868146166289862, 0.47926705037049566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 234}], {
             RGBColor[
             0.8765804096252258, 0.42016569118196145`, 0.35308390005828916`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 271}], {
             RGBColor[
             0.9862840872732699, 0.9639445925953173, 0.5488858494022204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 274}], {
             RGBColor[
             0.979839341035498, 0.9422049502369351, 0.5238492272566825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 282}], {
             RGBColor[
             0.97938013431987, 0.9823295669124169, 0.8386095157394571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 286}], {
             RGBColor[
             0.7770695489362254, 0.8225663010665949, 0.8446220990398039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 233}], {
             RGBColor[
             0.9005620992858752, 0.9194729557138646, 0.7896746116293041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 247}], {
             RGBColor[
             0.6930619732704799, 0.7591753208357144, 0.9707042644868367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 262}], {
             RGBColor[
             0.9005077184585596, 0.9193566406229818, 0.783755594175576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 273}], {
             RGBColor[
             0.7124353943152881, 0.7749035368025619, 0.9722294111586636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 229}], {
             RGBColor[
             0.3012157370951104, 0.430446886752895, 0.9405925945789568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 284}], {
             RGBColor[
             0.25584347148447395`, 0.38623808831614403`, 0.9378812792633183]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 221}], {
             RGBColor[
             0.28442417853057445`, 0.4162782235430855, 0.9395089082482266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 264}], {
             RGBColor[
             0.28444814998044265`, 0.4163034190567747, 0.9395102733868341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 226}], {
             RGBColor[
             0.21805937466237113`, 0.3465246069060093, 0.9357295308458616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 228}], {
             RGBColor[
             0.5367674910110247, 0.6220540079829862, 0.9601435922342896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 236}], {
             RGBColor[
             0.4402011946832155, 0.5463223550644548, 0.9507193164378127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 266}], {
             RGBColor[
             0.2524128465615943, 0.3826322840080144, 0.9376859102491151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 231}], {
             RGBColor[
             0.3698663550363416, 0.4934747204504928, 0.9448363781661868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 245}], {
             RGBColor[
             0.43026765068117134`, 0.5470979459642735, 0.9486372521240278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 261}], {
             RGBColor[
             0.41838703187400994`, 0.5368075510907742, 0.9478802295992542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 278}], {
             RGBColor[
             0.51953209520131, 0.6203519636484585, 0.9554475451034554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 290}], {
             RGBColor[
             0.5245306986367102, 0.6244100551018348, 0.9558410534763778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 234}], {
             RGBColor[
             0.840664257806904, 0.28321338657069606`, 0.18538480018870795`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 271}], {
             RGBColor[
             0.9324098595457874, 0.7585161356784191, 0.29733719959784854`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 274}], {
             RGBColor[
             0.9259651133080155, 0.7367764933200369, 0.2723005774523107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 287}], {
             RGBColor[
             0.9141648921008272, 0.6925393884549282, 0.24954185631357317`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 291}], {
             RGBColor[
             0.8410569337223622, 0.2862316657285906, 0.18576082708881467`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 249}], {
             RGBColor[
             0.8688948831013429, 0.39883351601253714`, 0.22232023481210886`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 254}], {
             RGBColor[
             0.9304233123934045, 0.7541309251793602, 0.28356918675006826`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 258}], {
             RGBColor[
             0.9656458741337097, 0.9399341707856219, 0.6428561562394914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 260}], {
             RGBColor[
             0.9093392465848947, 0.8957090172216551, 0.6607919677185569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 288}], {
             RGBColor[
             0.897775647296635, 0.6134919733958007, 0.2496893942062774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 234}], {
             RGBColor[
             0.8652002847569147, 0.3827448941589432, 0.21042816323286231`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 255}], {
             RGBColor[
             0.9599585954916654, 0.876593081803823, 0.2989471339802242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 287}], {
             RGBColor[
             0.950968932525843, 0.8418366498372989, 0.2871069008798047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 228}], {
             RGBColor[
             0.4976351265701356, 0.5809234118204025, 0.9579150619705263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 266}], {
             RGBColor[
             0.21328048212070516`, 0.3415016878454308, 0.9354573799853517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 264}], {
             RGBColor[
             0.2772132461146813, 0.4086990763744601, 0.9390982563147601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 266}], {
             RGBColor[
             0.5319885984693589, 0.6170310889224077, 0.9598714413737797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 257}], {
             RGBColor[
             0.3688470358646546, 0.49389849650006856`, 0.9447235848600365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 259}], {
             RGBColor[
             0.40532480006275245`, 0.5251965784018511, 0.9471300119909675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 261}], {
             RGBColor[
             0.3735150674883849, 0.49794171087045247`, 0.9450210277073223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 284}], {
             RGBColor[
             0.3010164849724387, 0.4302374601386527, 0.9405812474653377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 263}], {
             RGBColor[
             0.2551678747286398, 0.38552799329045395`, 0.9378428050275294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 269}], {
             RGBColor[
             0.23818874032876391`, 0.3676818464968855, 0.9368758684418348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 289}], {
             RGBColor[
             0.27016772610159867`, 0.4012937881289406, 0.9386970243729278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 298}], {
             RGBColor[
             0.2673021323723527, 0.39828186743036675`, 0.9385338330493134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 240}], {
             RGBColor[
             0.9945150494485371, 0.9906765703210165, 0.6443751655434223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 256}], {
             RGBColor[
             0.9946722576480922, 0.9910128227636774, 0.6614863078884357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 296}], {
             RGBColor[
             0.8451660598218556, 0.8762026073137711, 0.7845904625645401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 299}], {
             RGBColor[
             0.994290544063115, 0.9908843271723261, 0.6699459274860231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 262}], {
             RGBColor[
             0.9940341182393746, 0.9896479070942221, 0.5920287713894679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 288}], {
             RGBColor[
             0.905963575838284, 0.6404594328305877, 0.3369687585518484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 291}], {
             RGBColor[
             0.8766348422710215, 0.4223576865529295, 0.30917062318117206`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 255}], {
             RGBColor[
             0.8645307789041956, 0.38048649371027216`, 0.20782725942062052`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 271}], {
             RGBColor[
             0.8707009818902876, 0.40130003721491675`, 0.23179733287652443`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 274}], {
             RGBColor[
             0.8664044843984396, 0.3868069423093286, 0.21510625144616582`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 287}], {
             RGBColor[
             0.8585376702603141, 0.3573155390659227, 0.19993377068700752`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 252}], {
             RGBColor[
             0.2712852344852127, 0.40246836029424277`, 0.9387606648221691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 253}], {
             RGBColor[
             0.2693822700586988, 0.40046822402706334`, 0.9386522938132629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 292}], {
             RGBColor[
             0.24255033880224458`, 0.3722661630338292, 0.9371242550224929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 249}], {
             RGBColor[
             0.7534568620418187, 0.33087607040572803`, 0.43144386013194813`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 266}], {
             RGBColor[
             0.43542230214154953`, 0.5412994360038763, 0.9504471655773028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 239}], {
             RGBColor[
             0.5249567920726707, 0.6240772116080362, 0.9560621419984239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 282}], {
             RGBColor[
             0.8012181754265049, 0.8450224537789045, 0.955554762540068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 283}], {
             RGBColor[
             0.6287512202285861, 0.7094875913580734, 0.9639167457294545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 295}], {
             RGBColor[
             0.738032045164762, 0.7953605095140767, 0.9745241787723218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 297}], {
             RGBColor[
             0.6995891698942603, 0.7651888074182058, 0.970729660345039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 251}], {
             RGBColor[
             0.2826141781107905, 0.4143757983412377, 0.9394058314019756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 300}], {
             RGBColor[
             0.2671877155710705, 0.398161608117775, 0.9385273171817448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 295}], {
             RGBColor[
             0.6242095261484855, 0.7018088738432534, 0.9658801269946564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 256}], {
             RGBColor[
             0.9950907669461442, 0.9919079718344301, 0.7070384622414018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 281}], {
             RGBColor[
             0.8890287827533787, 0.5160602768928254, 0.3514291749004852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 299}], {
             RGBColor[
             0.9947090533611671, 0.9917794762430787, 0.7154980818389891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 277}], {
             RGBColor[
             0.3140852328677468, 0.44372332658360614`, 0.9413346549652732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 243}], {
             RGBColor[
             0.22929951054390013`, 0.35833870238327276`, 0.9363696399560237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 280}], {
             RGBColor[
             0.25424538211649345`, 0.38455839506567835`, 0.9377902704379731]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 294}], {
             RGBColor[
             0.22516497885926012`, 0.35399304743826654`, 0.9361341844930751]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 294}], {
             RGBColor[
             0.21403208469402601`, 0.34229166980434655`, 0.935500182640006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 270}], {
             RGBColor[
             0.23538330068246843`, 0.36473315155348174`, 0.9367161028042543]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 272}], {
             RGBColor[
             0.23289575947638014`, 0.3621185880266611, 0.936574441012555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 289}], {
             RGBColor[
             0.3576929449951681, 0.48259509766982983`, 0.944072988186208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 298}], {
             RGBColor[
             0.35482735126592213`, 0.47958317697125596`, 0.9439097968625934]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 256}], {
             RGBColor[
             0.7970579460912328, 0.838735601938289, 0.8428569136112316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 296}], {
             RGBColor[
             0.6475517482649964, 0.7239253864883827, 0.965961068287336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 299}], {
             RGBColor[
             0.7966762325062557, 0.8386071063469377, 0.851316533208819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 267}], {
             RGBColor[
             0.5234677465828359, 0.6240137244860162, 0.9556284450179895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 273}], {
             RGBColor[
             0.598461668080708, 0.6848971683956518, 0.9615322412300882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 285}], {
             RGBColor[
             0.4809297969495969, 0.5875639936298371, 0.952808962101173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 270}], {
             RGBColor[
             0.21830317142063266`, 0.3467808527565494, 0.9357434147105796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 254}], {
             RGBColor[
             0.8428272824024504, 0.2956795702116145, 0.1872932287744991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 288}], {
             RGBColor[
             0.8330203500287888, 0.2511485807700654, 0.1791100840120061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 300}], {
             RGBColor[
             0.27128730129384493`, 0.40247053264115845`, 0.9387607825238632]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 253}], {
             RGBColor[
             0.29862833529686444`, 0.43120769290001126`, 0.9403178139629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 292}], {
             RGBColor[
             0.2717964040404102, 0.4030056319067771, 0.9387897751721301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 292}], {
             RGBColor[
             0.26989343961389634`, 0.40100549563959764`, 0.9386814041632237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 258}], {
             RGBColor[
             0.926544473085371, 0.7852032520842381, 0.5903156471830767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 260}], {
             RGBColor[
             0.870237845536556, 0.7409780985202714, 0.6082514586621423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 288}], {
             RGBColor[
             0.8717080465977426, 0.5103380275948782, 0.21466238816866762`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 287}], {
             RGBColor[
             0.9499646737467646, 0.8384490491642924, 0.28320554516144203`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 296}], {
             RGBColor[
             0.8457417773194627, 0.8774340088271846, 0.8472537592625196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 299}], {
             RGBColor[
             0.994866261560722, 0.9921157286857396, 0.7326092241840025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 259}], {
             RGBColor[
             0.4277830853443319, 0.544648816326516, 0.9485610340700278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 261}], {
             RGBColor[
             0.39597335276996437`, 0.5173939487951174, 0.9464520497863826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 260}], {
             RGBColor[
             0.9054604072768613, 0.9267813441265331, 0.9675384281515653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 278}], {
             RGBColor[
             0.7823492729369855, 0.8297662429856849, 0.9557433701572854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 290}], {
             RGBColor[
             0.7873478763723856, 0.8338243344390612, 0.9561368785302078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 260}], {
             RGBColor[
             0.656707314635238, 0.7292515443954324, 0.9682208504157948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 261}], {
             RGBColor[
             0.4324511169680622, 0.5486920306968999, 0.9488584769173136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 261}], {
             RGBColor[
             0.6248975820608704, 0.7019966768640338, 0.9661118661321497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 278}], {
             RGBColor[
             0.7260426453881705, 0.7855410894217181, 0.9736791816363508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 290}], {
             RGBColor[
             0.7310412488235707, 0.7895991808750945, 0.9740726900092733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 278}], {
             RGBColor[
             0.5017864477209948, 0.6049815757231856, 0.9543168081378697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 290}], {
             RGBColor[
             0.5067850511563949, 0.6090396671765619, 0.9547103165107921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 271}], {
             RGBColor[
             0.9857223415414609, 0.9625888518240449, 0.4765328762826566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 291}], {
             RGBColor[
             0.8765985883861446, 0.42228014315900764`, 0.3052246115453534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 269}], {
             RGBColor[
             0.24400443083652518`, 0.3737945059566179, 0.9372070634127088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 276}], {
             RGBColor[
             0.24638255548127658`, 0.37629406574006286`, 0.9373424940931072]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 279}], {
             RGBColor[
             0.25988809011317837`, 0.3904892389385449, 0.938111614310746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 289}], {
             RGBColor[
             0.27598341660935993`, 0.40740644758867306`, 0.9390282193438018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 298}], {
             RGBColor[
             0.27311782288011394`, 0.40439452689009914`, 0.9388650280201871]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 269}], {
             RGBColor[
             0.2247455605611441, 0.35355221221429056`, 0.9361102992414712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 273}], {
             RGBColor[
             0.5428411676276441, 0.6397419404528637, 0.9571535916898165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 285}], {
             RGBColor[
             0.42530929649653304`, 0.542408765687049, 0.9484303125609015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 286}], {
             RGBColor[
             0.5134415575632728, 0.6158740125652669, 0.954839146691229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 298}], {
             RGBColor[
             0.2561386884802381, 0.3865483800965307, 0.9378980914344927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 272}], {
             RGBColor[
             0.22576785330449248`, 0.35462670670465335`, 0.9361685173008583]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 274}], {
             RGBColor[
             0.9710201994330907, 0.9139064692863681, 0.34191937648403536`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 291}], {
             RGBColor[
             0.8710936578057457, 0.40431831637281135`, 0.23217335977663117`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 285}], {
             RGBColor[
             0.5003032179944051, 0.6032922095966846, 0.9543341087730001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 287}], {
             RGBColor[
             0.9527752319881305, 0.8479297220628771, 0.29412403319976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 293}], {
             RGBColor[
             0.21101994270665328`, 0.33912571759478527`, 0.9353286456098898]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 279}], {
             RGBColor[
             0.24528708035805388`, 0.3751426519284214, 0.9372801084054498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 290}], {
             RGBColor[
             0.607930114483695, 0.6925840797342462, 0.9622776320149933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 283}], {
             RGBColor[
             0.7911900845661439, 0.8368811978581185, 0.9547653144934332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 295}], {
             RGBColor[
             0.9004709095023198, 0.9227541160141217, 0.9653727475363004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 297}], {
             RGBColor[
             0.8620280342318183, 0.892582413918251, 0.9615782291090177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 295}], {
             RGBColor[
             0.728003954304401, 0.7872192535932907, 0.973734730725687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 297}], {
             RGBColor[
             0.6895610790338994, 0.7570475514974199, 0.9699402122984042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 291}], {
             RGBColor[
             0.8472367474404496, 0.3567561650145, 0.19258017572083644`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 298}], {
             RGBColor[
             0.28811767425307283`, 0.4201603217285858, 0.9397192473655857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 297}], {
             RGBColor[
             0.7988419039700752, 0.8429204696534232, 0.9805476453412715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 299}], {
             RGBColor[
             0.8453600637344856, 0.8773055132358333, 0.8557133788601069]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.10302533798448267`], {
             RGBColor[
             0.41852266255485593`, 0.5369250275695268, 0.9478888718663042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.10302533798448267`], {
             RGBColor[
             0.2307572995292167, 0.3598709310360006, 0.936452658882132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.10302533798448267`], {
             RGBColor[
             0.3773249031069595, 0.5012415989953558, 0.9452637870640326]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.10302533798448267`], {
             RGBColor[
             0.5396207399250182, 0.6371274521652572, 0.9569000678242504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.10302533798448267`], {
             RGBColor[
             0.220958970004222, 0.34957226545525755`, 0.9358946585110132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.10302533798448267`], {
             RGBColor[
             0.3056730571205615, 0.43861214219787836`, 0.9407190004490276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.10302533798448267`], {
             RGBColor[
             0.394746751143397, 0.516331528116975, 0.946373891815379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.10302533798448267`], {
             RGBColor[
             0.6518492866916434, 0.7279488840923621, 0.9659339030856515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.10302533798448267`], {
             RGBColor[
             0.5168296547678491, 0.6186246225079816, 0.9551058701141822]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.10302533798448267`], {
             RGBColor[
             0.2114327980870659, 0.3395596547761419, 0.9353521571130395]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.10302533798448267`], {
             RGBColor[
             0.34350580070653963`, 0.47194919229362253`, 0.9431088637641358]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.10302533798448267`], {
             RGBColor[
             0.20154157699751735`, 0.32916335427138743`, 0.93478886670474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.10302533798448267`], {
             RGBColor[
             0.30612838775897044`, 0.4390907235684761, 0.9407449308552837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.10302533798448267`], {
             RGBColor[
             0.8226976998778256, 0.17547004422228246`, 0.1693686490773784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.10302533798448267`], {
             RGBColor[
             0.23892277989457777`, 0.36845336862135236`, 0.9369176709091936]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.10302533798448267`], {
             RGBColor[
             0.9934703621130101, 0.9884420897444159, 0.5306673961342021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.10302533798448267`], {
             RGBColor[
             0.29622239326445615`, 0.42867889527841463`, 0.9401807991234267]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.10302533798448267`], {
             RGBColor[
             0.9464007204285422, 0.9595463255731478, 0.9756137787701872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.10302533798448267`], {
             RGBColor[
             0.2912671539208582, 0.4234706245479727, 0.9398986055734284]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.10302533798448267`], {
             RGBColor[
             0.865905855945801, 0.8959138414156087, 0.9870720676150353]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.10302533798448267`], {
             RGBColor[
             0.38345468665213356`, 0.5065509094103063, 0.9456543714511763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.10302533798448267`], {
             RGBColor[
             0.8173789776787558, 0.8572619367637411, 0.982432355720336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.10302533798448267`], {
             RGBColor[
             0.2963741173821658, 0.42883836694599214`, 0.9401894395874745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.10302533798448267`], {
             RGBColor[
             0.9556367854010767, 0.9664345677069957, 0.9599795299232305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.10302533798448267`], {
             RGBColor[
             0.2518103509231395, 0.3819990228915686, 0.9376515990138174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.10302533798448267`], {
             RGBColor[
             0.9858349896506369, 0.9884104184434465, 0.8844144095680297]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.10302533798448267`], {
             RGBColor[
             0.2584384877012701, 0.38896561489352793`, 0.9380290615978824]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.10302533798448267`], {
             RGBColor[
             0.22341264573171882`, 0.35215123421688327`, 0.9360343917138061]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.10302533798448267`], {
             RGBColor[
             0.24282295558358705`, 0.3725527005559224, 0.9371397801448899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.10302533798448267`], {
             RGBColor[
             0.46219840465570133`, 0.574272512557169, 0.9508050979844909]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.10302533798448267`], {
             RGBColor[
             0.6188367246795077, 0.7014385572283971, 0.9631362403218372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.10302533798448267`], {
             RGBColor[
             0.2562574704790552, 0.38667322750850125`, 0.9379048558936031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.10302533798448267`], {
             RGBColor[
             0.9146626577353835, 0.9347911916944939, 0.9917225348954364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.10302533798448267`], {
             RGBColor[
             0.3274991935787168, 0.458085073714969, 0.9420889369120379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.10302533798448267`], {
             RGBColor[
             0.2262311772849768, 0.3551136895845794, 0.9361949029161204]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.10302533798448267`], {
             RGBColor[
             0.7595712694087771, 0.8121021157083784, 0.9766706236037325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.10302533798448267`], {
             RGBColor[
             0.6807027709206555, 0.7504894452666685, 0.968809748742459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.10302533798448267`], {
             RGBColor[
             0.4179442959916355, 0.5364240755220139, 0.9478520188603253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.10302533798448267`], {
             RGBColor[
             0.8675327116732591, 0.4913788068770457, 0.21117838636085415`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.10302533798448267`], {
             RGBColor[
             0.2372124705557414, 0.3666557250663601, 0.9368202713225229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.10302533798448267`], {
             RGBColor[
             0.35699077137457635`, 0.483629196111943, 0.9439681141708117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.10302533798448267`], {
             RGBColor[
             0.2544378422070241, 0.3847606828235006, 0.9378012307554097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.10302533798448267`], {
             RGBColor[
             0.322173741643116, 0.45347243491334854`, 0.9417496038238137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.10302533798448267`], {
             RGBColor[
             0.9650552642631052, 0.8937853423246256, 0.3187467297321304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.10302533798448267`], {
             RGBColor[
             0.8578237913971699, 0.4454645759914146, 0.2030054339855487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.10302533798448267`], {
             RGBColor[
             0.29213812634371106`, 0.4243860717872321, 0.9399482061644217]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.10302533798448267`], {
             RGBColor[
             0.6440597930627512, 0.7218636724671273, 0.9651575191576801]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.10302533798448267`], {
             RGBColor[
             0.4136829046946342, 0.5327330725643056, 0.9475804867750808]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.10302533798448267`], {
             RGBColor[
             0.23655451757503262`, 0.36596417476700677`, 0.9367828018736257]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.10302533798448267`], {
             RGBColor[
             0.35244904856935166`, 0.4796953840916829, 0.9436787196097506]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.10302533798448267`], {
             RGBColor[
             0.993562122803693, 0.9916057865804992, 0.7563558160423134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.10302533798448267`], {
             RGBColor[
             0.8177080186927622, 0.13711716814164848`, 0.16459052473952288`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.10302533798448267`], {
             RGBColor[
             0.8317291195209172, 0.2448894931924079, 0.17801714672713256`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.10302533798448267`], {
             RGBColor[
             0.4174064139952154, 0.53595818917145, 0.9478177454951437]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.10302533798448267`], {
             RGBColor[
             0.2766948027559306, 0.4081541595332056, 0.9390687317324474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.10302533798448267`], {
             RGBColor[
             0.5476923991281734, 0.6436803887304818, 0.9575354984041846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.10302533798448267`], {
             RGBColor[
             0.24705297562595502`, 0.37699871981921224`, 0.9373806735285489]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.10302533798448267`], {
             RGBColor[
             0.5489231824340144, 0.6446795940643196, 0.9576323901745283]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.10302533798448267`], {
             RGBColor[
             0.8328101555207211, 0.25319880959989605`, 0.17905234802140027`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.10302533798448267`], {
             RGBColor[
             0.9260824493199337, 0.7446485736567867, 0.2593824075361489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.10302533798448267`], {
             RGBColor[
             0.5668393910348319, 0.659224779322463, 0.9590428197448192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.10302533798448267`], {
             RGBColor[
             0.9948487335515908, 0.9913902868768101, 0.6806946209012268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.10302533798448267`], {
             RGBColor[
             0.32451328924336914`, 0.4554988334556064, 0.9418986777281211]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.10302533798448267`], {
             RGBColor[
             0.23365539790008147`, 0.3629170161738291, 0.9366177012970005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.10302533798448267`], {
             RGBColor[
             0.28791659856684826`, 0.41994897843342893`, 0.9397077964027201]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.10302533798448267`], {
             RGBColor[
             0.9464558742569554, 0.9595874592080723, 0.9755204177251058]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.10302533798448267`], {
             RGBColor[
             0.9123183312358003, 0.932921889378774, 0.9914989309411012]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.10302533798448267`], {
             RGBColor[
             0.8743662175245639, 0.5224081609419808, 0.2168804311477391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.10302533798448267`], {
             RGBColor[
             0.9930380091079225, 0.9875173303841278, 0.48360843970387296`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.10302533798448267`], {
             RGBColor[
             0.26423372362278924`, 0.39505677528622424`, 0.9383590917103296]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.10302533798448267`], {
             RGBColor[
             0.6295965520330332, 0.7101738697986875, 0.963983293345653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.10302533798448267`], {
             RGBColor[
             0.6518075404484566, 0.7279162716099014, 0.9659297422102715]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.10302533798448267`], {
             RGBColor[
             0.3290101239879992, 0.459393765693919, 0.9421852120616541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.10302533798448267`], {
             RGBColor[
             0.6382140736915616, 0.7171699620960075, 0.9646616962176343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.10302533798448267`], {
             RGBColor[
             0.7305123993392341, 0.7894011055544591, 0.9737743070057807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.10302533798448267`], {
             RGBColor[
             0.29429562032882867`, 0.4266537347586102, 0.9400710722551477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.10302533798448267`], {
             RGBColor[
             0.2460324096232273, 0.37592604024272347`, 0.9373225538044856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.10302533798448267`], {
             RGBColor[
             0.1800403201715783, 0.3065641700889047, 0.9335644019367618]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.10302533798448267`], {
             RGBColor[
             0.39493077240962093`, 0.5164909180886005, 0.9463856174877392]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.10302533798448267`], {
             RGBColor[
             0.26782978190622225`, 0.39883646054537636`, 0.9385638819096797]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.10302533798448267`], {
             RGBColor[
             0.29584127485450173`, 0.42827831566524976`, 0.9401590949937939]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.10302533798448267`], {
             RGBColor[
             0.9950766756732579, 0.9918778320265724, 0.7055047141489801]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.10302533798448267`], {
             RGBColor[
             0.21628848662157388`, 0.34466329129434453`, 0.9356286813917323]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.10302533798448267`], {
             RGBColor[
             0.30061798398773654`, 0.43329893982513096`, 0.9404311215124237]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.10302533798448267`], {
             RGBColor[
             0.9196256639800194, 0.938748558156751, 0.9921959108615778]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.10302533798448267`], {
             RGBColor[
             0.9748675947682047, 0.926884637163092, 0.35686578084130904`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.10302533798448267`], {
             RGBColor[
             0.27610729667649436`, 0.4075366533936812, 0.9390352741303609]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.10302533798448267`], {
             RGBColor[
             0.5042211596463271, 0.6083884781620977, 0.9541132831917766]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.10302533798448267`], {
             RGBColor[
             0.27813245697413447`, 0.40966522526908, 0.9391506040133554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.10302533798448267`], {
             RGBColor[
             0.4035464690461924, 0.5239534014776945, 0.9469346020588602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.10302533798448267`], {
             RGBColor[
             0.2726124428491967, 0.4038633404346605, 0.9388362473750692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.10302533798448267`], {
             RGBColor[
             0.261097249315751, 0.3917601419255701, 0.9381804741385418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.10302533798448267`], {
             RGBColor[
             0.5312094509757161, 0.6302987888719648, 0.9562379003465947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.10302533798448267`], {
             RGBColor[
             0.8619491220774967, 0.8927588492317026, 0.9866946708064583]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.10302533798448267`], {
             RGBColor[
             0.48864650773140994`, 0.5957442741074949, 0.9528871895412045]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.10302533798448267`], {
             RGBColor[
             0.40546591079173033`, 0.5256159254437323, 0.9470569071895901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.10302533798448267`], {
             RGBColor[
             0.2574804300414378, 0.3879586355486801, 0.9379745016314742]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.10302533798448267`], {
             RGBColor[
             0.4228071955400177, 0.5406360746943846, 0.948161878519455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.10302533798448267`], {
             RGBColor[
             0.3674883934084197, 0.4927217086918333, 0.9446370133641255]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.10302533798448267`], {
             RGBColor[
             0.8501803311271197, 0.38671359097016134`, 0.19568604779889498`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.10302533798448267`], {
             RGBColor[
             0.5465902564750337, 0.6427856196737024, 0.9574487336972479]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.10302533798448267`], {
             RGBColor[
             0.38532279281260967`, 0.5081689690727651, 0.9457734055238204]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.10302533798448267`], {
             RGBColor[
             0.2788168781365947, 0.4103845953056338, 0.9391895807860471]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.10302533798448267`], {
             RGBColor[
             0.28507184392659923`, 0.4169589609386654, 0.9395457918343952]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.10302533798448267`], {
             RGBColor[
             0.28917033221241484`, 0.4212667319862237, 0.9397791946791023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.10302533798448267`], {
             RGBColor[
             0.6566687686170058, 0.7317139000018745, 0.9664142640033524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.10302533798448267`], {
             RGBColor[
             0.8341470216086144, 0.26347454816989946`, 0.18033253249694123`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.10302533798448267`], {
             RGBColor[
             0.3439204196877902, 0.4723083144158259, 0.943135282918988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.10302533798448267`], {
             RGBColor[
             0.9211686584075277, 0.939978900029778, 0.992343083047521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.10302533798448267`], {
             RGBColor[
             0.9929459767177286, 0.9913509943397207, 0.7665669512217009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.10302533798448267`], {
             RGBColor[
             0.24301438028138522`, 0.37275390005033504`, 0.937150681498242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.10302533798448267`], {
             RGBColor[
             0.2522134290242518, 0.3824226835324653, 0.9376745537153752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.10302533798448267`], {
             RGBColor[
             0.9594092884334661, 0.9692480942916449, 0.9535936663157671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.10302533798448267`], {
             RGBColor[
             0.3044111891973746, 0.4372858390035616, 0.9406471389375684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.10302533798448267`], {
             RGBColor[
             0.2215913444714862, 0.35023693111520926`, 0.9359306713014096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.10302533798448267`], {
             RGBColor[
             0.3224078413052081, 0.4536752002744616, 0.941764520447276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.10302533798448267`], {
             RGBColor[
             0.20347429876271564`, 0.33119476738824843`, 0.9348989323500625]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.10302533798448267`], {
             RGBColor[
             0.17892956896395254`, 0.30539670014399584`, 0.9335011462986966]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.10302533798448267`], {
             RGBColor[
             0.28222472928714576`, 0.41396646293510553`, 0.9393836528676069]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.10302533798448267`], {
             RGBColor[
             0.18991457468017128`, 0.31694263764133146`, 0.9341267261233757]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.10302533798448267`], {
             RGBColor[
             0.9946101233350695, 0.9908799237508646, 0.6547233713644478]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.10302533798448267`], {
             RGBColor[
             0.6241927467762723, 0.7057868172525964, 0.96355788600105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.10302533798448267`], {
             RGBColor[
             0.43622064479054923`, 0.5522541302556329, 0.9490165716446514]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.10302533798448267`], {
             RGBColor[
             0.9476938047146304, 0.9605107057164812, 0.973424924364235]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.10302533798448267`], {
             RGBColor[
             0.9926251659969516, 0.9866343007146026, 0.4386730148470409]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.10302533798448267`], {
             RGBColor[
             0.22593857337368983`, 0.3548061443216573, 0.9361782395562414]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.10302533798448267`], {
             RGBColor[
             0.8327720947194103, 0.2529062576026711, 0.17901590095508144`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.10302533798448267`], {
             RGBColor[
             0.23926061251081787`, 0.3688084521208458, 0.93693690997691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.10302533798448267`], {
             RGBColor[
             0.23590943272644063`, 0.36528614969039486`, 0.9367460652458159]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.10302533798448267`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.10302533798448267`], {
             RGBColor[
             0.324831212684851, 0.4557742027613212, 0.9419189355286837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.10302533798448267`], {
             RGBColor[
             0.2067120462521808, 0.3345978452847238, 0.9350833172797693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.10302533798448267`], {
             RGBColor[
             0.35014705105926486`, 0.47770150955020474`, 0.9435320383639844]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.10302533798448267`], {
             RGBColor[
             0.27400077350385804`, 0.40532256397795713`, 0.9389153107520011]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.10302533798448267`], {
             RGBColor[
             0.9900957369634822, 0.9901723469535194, 0.8138028001335977]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.10302533798448267`], {
             RGBColor[
             0.9929076697798414, 0.9872385477406899, 0.46942180820333496`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.10302533798448267`], {
             RGBColor[
             0.8455662065044656, 0.351247407198139, 0.19126755684933291`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.10302533798448267`], {
             RGBColor[
             0.7066839033025902, 0.7707861033473555, 0.971399305210804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.10302533798448267`], {
             RGBColor[
             0.25547870703592473`, 0.385854697753317, 0.9378605064675941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.10302533798448267`], {
             RGBColor[
             0.3280740134091542, 0.4585829537608091, 0.9421255639233401]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.10302533798448267`], {
             RGBColor[
             0.8990024464838272, 0.6342755227085348, 0.23743750448057996`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.10302533798448267`], {
             RGBColor[
             0.6590237495828186, 0.7335536290308857, 0.9666489864974762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.10302533798448267`], {
             RGBColor[
             0.39675004724917656`, 0.5180666825152114, 0.9465015400717941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.10302533798448267`], {
             RGBColor[
             0.3157094904678022, 0.4478734254480028, 0.9413377074550355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.10302533798448267`], {
             RGBColor[
             0.26920385108875294`, 0.4002806943772341, 0.9386421331168716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.10302533798448267`], {
             RGBColor[
             0.23045057360750168`, 0.3595485426447314, 0.9364351912946507]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.10302533798448267`], {
             RGBColor[
             0.22619261942112945`, 0.35507316282496604`, 0.9361927071028155]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.10302533798448267`], {
             RGBColor[
             0.23881348570074337`, 0.36833849349398035`, 0.9369114467665411]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.10302533798448267`], {
             RGBColor[
             0.2939489691399074, 0.4262893823800991, 0.9400513309827632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.10302533798448267`], {
             RGBColor[
             0.9620063021321176, 0.9711849428558795, 0.9491975995336027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.10302533798448267`], {
             RGBColor[
             0.443273542823118, 0.5583629960424816, 0.9494659760706539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.10302533798448267`], {
             RGBColor[
             0.25329610735962166`, 0.38356064710871024`, 0.9377362106448954]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.10302533798448267`], {
             RGBColor[
             0.27348165172589245`, 0.40477693407509363`, 0.9388857475347178]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.10302533798448267`], {
             RGBColor[
             0.7412000832467709, 0.797750405452433, 0.9748395554555993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.10302533798448267`], {
             RGBColor[
             0.21230278460535462`, 0.3404740657671945, 0.9354017015582263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.10302533798448267`], {
             RGBColor[
             0.2276990046313701, 0.35665646919126776`, 0.9362784935120415]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.10302533798448267`], {
             RGBColor[
             0.34598043724619154`, 0.47409259808542004`, 0.9432665454162072]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.10302533798448267`], {
             RGBColor[
             0.40363205630183896`, 0.524027532856795, 0.9469400556031081]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.10302533798448267`], {
             RGBColor[
             0.2473937360801429, 0.37735688066202433`, 0.937400079332305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.10302533798448267`], {
             RGBColor[
             0.5902199940802382, 0.6782062061588879, 0.9608834264625246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.10302533798448267`], {
             RGBColor[
             0.21627103797903324`, 0.3446449516647265, 0.9356276877173526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.10302533798448267`], {
             RGBColor[
             0.2845267439871254, 0.4163860263409461, 0.9395147491992453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.10302533798448267`], {
             RGBColor[
             0.2413593551772921, 0.3710143637312809, 0.9370564302669542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.10302533798448267`], {
             RGBColor[
             0.38392426951059677`, 0.5069576384803866, 0.9456842928556817]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.10302533798448267`], {
             RGBColor[
             0.9802603651545728, 0.9450757179590131, 0.3778156754531135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.10302533798448267`], {
             RGBColor[
             0.9927232541779302, 0.9868441014154793, 0.4493493080164732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.10302533798448267`], {
             RGBColor[
             0.7539264605068086, 0.8076923480920241, 0.9761080018061227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.10302533798448267`], {
             RGBColor[
             0.3858730274799788, 0.5086455546860418, 0.9458084659902717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.10302533798448267`], {
             RGBColor[
             0.2930250557635406, 0.42531829084204614`, 0.9399987154827865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.10302533798448267`], {
             RGBColor[
             0.8218934398484693, 0.16928814920765783`, 0.168598488764985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.10302533798448267`], {
             RGBColor[
             0.4183533072547869, 0.5367783405206518, 0.9478780806963388]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.10302533798448267`], {
             RGBColor[
             0.26949540103514497`, 0.4005871318562264, 0.9386587364550091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.10302533798448267`], {
             RGBColor[
             0.25717362368840185`, 0.38763616261899303`, 0.9379570294635482]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.10302533798448267`], {
             RGBColor[
             0.3923234880848031, 0.5142326194523638, 0.9462194836360928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.10302533798448267`], {
             RGBColor[
             0.2945111830148827, 0.42688030480911665`, 0.9400833482312222]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.10302533798448267`], {
             RGBColor[
             0.1789518783186532, 0.305420148690281, 0.9335024167834431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.10302533798448267`], {
             RGBColor[
             0.41920763486506846`, 0.5375183161569235, 0.9479325176962138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.10302533798448267`], {
             RGBColor[
             0.27705635157752495`, 0.4085341702682206, 0.9390893214029737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.10302533798448267`], {
             RGBColor[
             0.9936465744084931, 0.9916407094893913, 0.7549562343970292]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.10302533798448267`], {
             RGBColor[
             0.23402613491596813`, 0.3633066842836104, 0.936638814221599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.10302533798448267`], {
             RGBColor[
             0.7138170777657293, 0.7763585934520937, 0.9721102733779844]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.10302533798448267`], {
             RGBColor[
             0.3071831062866214, 0.4401992996140543, 0.9408049955151171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.10302533798448267`], {
             RGBColor[
             0.25458949129815345`, 0.38492007563338526`, 0.9378098669468048]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.10302533798448267`], {
             RGBColor[
             0.23743710807503443`, 0.3668918333419784, 0.9368330640969252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.10302533798448267`], {
             RGBColor[
             0.5680702998089695, 0.6602240865171163, 0.9591397213924867]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.10302533798448267`], {
             RGBColor[
             0.2299691131158081, 0.3590424971416032, 0.9364077728319058]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.10302533798448267`], {
             RGBColor[
             0.3639294956023307, 0.48963917028760373`, 0.9444102435429313]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.10302533798448267`], {
             RGBColor[
             0.20571498311483435`, 0.33354986870991854`, 0.9350265360091202]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.10302533798448267`], {
             RGBColor[
             0.2318484494359024, 0.3610177987708272, 0.9365147982551062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.10302533798448267`], {
             RGBColor[
             0.22813210557574862`, 0.35711168574399543`, 0.9363031579701084]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.10302533798448267`], {
             RGBColor[
             0.24388899418338073`, 0.37367317471505657`, 0.9372004894660854]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.10302533798448267`], {
             RGBColor[
             0.8649861375675162, 0.47981540863036076`, 0.20905346250477896`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.10302533798448267`], {
             RGBColor[
             0.39949775357450523`, 0.5204466076304757, 0.9466766214891428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.10302533798448267`], {
             RGBColor[
             0.5158331891976378, 0.6178156468678216, 0.9550274246943216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.10302533798448267`], {
             RGBColor[
             0.8191437574953648, 0.1481528857232069, 0.16596538983833015`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.10302533798448267`], {
             RGBColor[
             0.2809324202458739, 0.4126081641956031, 0.9393100577795065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.10302533798448267`], {
             RGBColor[
             0.2105002400012672, 0.3385794771003698, 0.9352990493096494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.10302533798448267`], {
             RGBColor[
             0.4642553566460736, 0.5759424388475844, 0.9509670287800365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.10302533798448267`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.10302533798448267`], {
             RGBColor[
             0.8859959599380017, 0.5752161050460523, 0.226584573288584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.10302533798448267`], {
             RGBColor[
             0.32111303850258816`, 0.4525537071655133, 0.9416820167576422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.10302533798448267`], {
             RGBColor[
             0.22812105044609293`, 0.3571000661017916, 0.9363025283968291]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.10302533798448267`], {
             RGBColor[
             0.2595939437592997, 0.3901800724706624, 0.9380948631110431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.10302533798448267`], {
             RGBColor[
             0.23088271225706164`, 0.36000274776459185`, 0.9364598009514513]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.10302533798448267`], {
             RGBColor[
             0.5294468131435418, 0.6288678000738763, 0.9560991390396908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.10302533798448267`], {
             RGBColor[
             0.23667377020378227`, 0.366089516840876, 0.9367895931344146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.10302533798448267`], {
             RGBColor[
             0.7455882739599426, 0.8011784933890475, 0.9752769292959146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.10302533798448267`], {
             RGBColor[
             0.28595975701387044`, 0.41789221389032877`, 0.9395963571711656]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.10302533798448267`], {
             RGBColor[
             0.2651563206276758, 0.3960264832343887, 0.938411632244898]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.10302533798448267`], {
             RGBColor[
             0.37855708825470646`, 0.5023088558389079, 0.9453423008120684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.10302533798448267`], {
             RGBColor[
             0.24235927283690456`, 0.3720653405899749, 0.9371133740984234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.10302533798448267`], {
             RGBColor[
             0.21172080019279638`, 0.3398623632496528, 0.9353685584068999]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.10302533798448267`], {
             RGBColor[
             0.42787872382047937`, 0.5450287775884974, 0.9484850318169096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.10302533798448267`], {
             RGBColor[
             0.21288213693655111`, 0.34108300180034146`, 0.9354346948164131]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.10302533798448267`], {
             RGBColor[
             0.9951032288756773, 0.9922430735458843, 0.7308157001748675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.10302533798448267`], {
             RGBColor[
             0.2588379470720171, 0.38938547201937, 0.9380518102180992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.10302533798448267`], {
             RGBColor[
             0.80703569950506, 0.8491816892426243, 0.9814014344154122]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.10302533798448267`], {
             RGBColor[
             0.2560427236071457, 0.38644751493038626`, 0.9378926263769374]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.10302533798448267`], {
             RGBColor[
             0.27423499655804673`, 0.4055687472585089, 0.9389286494084351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.10302533798448267`], {
             RGBColor[
             0.25719173910326026`, 0.38765520306859286`, 0.937958061109625]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.10302533798448267`], {
             RGBColor[
             0.29461336050310216`, 0.4269876998276622, 0.9400891670880182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.10302533798448267`], {
             RGBColor[
             0.43613267935432526`, 0.5521779390160471, 0.94901096656484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.10302533798448267`], {
             RGBColor[
             0.8873547734207121, 0.5813861597120881, 0.22771840056612383`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.10302533798448267`], {
             RGBColor[
             0.9695247134417432, 0.9088618438807439, 0.33610969580648287`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.10302533798448267`], {
             RGBColor[
             0.9609628542707439, 0.8799806824768295, 0.3028484896985869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.10302533798448267`], {
             RGBColor[
             0.178927010221482, 0.30539401074342565`, 0.9335010005820983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.10302533798448267`], {
             RGBColor[
             0.25976518882652405`, 0.3903600618938796, 0.9381046152642871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.10302533798448267`], {
             RGBColor[
             0.8163432429187892, 0.8564528128973794, 0.9823291233589543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.10302533798448267`], {
             RGBColor[
             0.34638875058307517`, 0.4744462585754037, 0.9432925627809762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.10302533798448267`], {
             RGBColor[
             0.24935218422087857`, 0.37941533383072157`, 0.9375116100566555]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.10302533798448267`], {
             RGBColor[
             0.44511934956958094`, 0.5599617410733233, 0.9495835892443556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.10302533798448267`], {
             RGBColor[
             0.9940965401504851, 0.9897814212502639, 0.5988230111904562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.10302533798448267`], {
             RGBColor[
             0.9940884990666902, 0.9897642221851048, 0.5979477888431959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.10302533798448267`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.10302533798448267`], {
             RGBColor[
             0.24203916924704705`, 0.37172889142129484`, 0.937095144672532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.10302533798448267`], {
             RGBColor[
             0.6232106502631707, 0.7049895070603167, 0.9634805717660004]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.10302533798448267`], {
             RGBColor[
             0.638779311088947, 0.7176288472788594, 0.9647061937760893]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.10302533798448267`], {
             RGBColor[
             0.2785145923880161, 0.4100668738178543, 0.9391723660598572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.10302533798448267`], {
             RGBColor[
             0.4111342730563943, 0.530525575937213, 0.9474180902207585]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.10302533798448267`], {
             RGBColor[
             0.9949335587465892, 0.9915717193917691, 0.6899273198963884]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.10302533798448267`], {
             RGBColor[
             0.2790754121939759, 0.4106563309919474, 0.9392043039181481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.10302533798448267`], {
             RGBColor[
             0.24043240470913427`, 0.3700400800171928, 0.9370036418090929]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.10302533798448267`], {
             RGBColor[
             0.21816661637866602`, 0.3466373247493527, 0.9357356381029547]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.10302533798448267`], {
             RGBColor[
             0.24251120685435607`, 0.3722250328754895, 0.9371220265159511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.10302533798448267`], {
             RGBColor[
             0.4244026220080174, 0.5420179529125, 0.9482635376832157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.10302533798448267`], {
             RGBColor[
             0.5988679170367666, 0.6852269795994871, 0.961564222636048]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.10302533798448267`], {
             RGBColor[
             0.5790882470358998, 0.6691689524288044, 0.9600070945582612]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.10302533798448267`], {
             RGBColor[
             0.20835094833068457`, 0.3363204352816248, 0.9351766503286018]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.10302533798448267`], {
             RGBColor[
             0.8185799679311427, 0.1438193520784336, 0.16542550431492184`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.10302533798448267`], {
             RGBColor[
             0.22258326386374316`, 0.3512795012877932, 0.9359871596433854]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.10302533798448267`], {
             RGBColor[
             0.2867137638335649, 0.4186847228646212, 0.9396392967440941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.10302533798448267`], {
             RGBColor[
             0.30053129972337833`, 0.4332078291671907, 0.9404261849718064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.10302533798448267`], {
             RGBColor[
             0.29672537087035056`, 0.42920755663283183`, 0.9402094429539937]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.10302533798448267`], {
             RGBColor[
             0.8913219113450659, 0.5994000064779764, 0.23102867769365362`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.10302533798448267`], {
             RGBColor[
             0.9589543367125869, 0.8732054811308165, 0.29504577826186157`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.10302533798448267`], {
             RGBColor[
             0.9952479751456992, 0.992244224277091, 0.7241496045864151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.10302533798448267`], {
             RGBColor[
             0.39130532114623406`, 0.5133507344247334, 0.9461546069390968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.10302533798448267`], {
             RGBColor[
             0.9617670348256762, 0.9710064976904998, 0.9496026166724999]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.10302533798448267`], {
             RGBColor[
             0.46426084954242974`, 0.5759468982282985, 0.9509674612009588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.10302533798448267`], {
             RGBColor[
             0.8491537797280463, 0.8825561905625664, 0.9854742396306309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.10302533798448267`], {
             RGBColor[
             0.4006413843936947, 0.5214371631655013, 0.9467494926336685]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.10302533798448267`], {
             RGBColor[
             0.9939797374120591, 0.9895315920033393, 0.5861097539357399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.10302533798448267`], {
             RGBColor[
             0.26098356523640104`, 0.3916406527501864, 0.9381739999984032]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.10302533798448267`], {
             RGBColor[
             0.2946613034028385, 0.4270380908550406, 0.940091897365233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.10302533798448267`], {
             RGBColor[
             0.22246582468563886`, 0.3511560652655316, 0.9359804716559281]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.10302533798448267`], {
             RGBColor[
             0.24763395401992835`, 0.3776093649474359, 0.9374137593886052]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.10302533798448267`], {
             RGBColor[
             0.467847246129772, 0.578858496543228, 0.9512497954777179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.10302533798448267`], {
             RGBColor[
             0.2625163578880115, 0.3932517150116962, 0.938261290272349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.10302533798448267`], {
             RGBColor[
             0.2270252964366493, 0.35594835916304945`, 0.9362401268270142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.10302533798448267`], {
             RGBColor[
             0.22825539451058077`, 0.357241270231474, 0.9363101790925575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.10302533798448267`], {
             RGBColor[
             0.9774649456708626, 0.9356461116447503, 0.3669559986295733]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.10302533798448267`], {
             RGBColor[
             0.22328031209840418`, 0.35201214317783264`, 0.936026855509159]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.10302533798448267`], {
             RGBColor[
             0.6178350891255162, 0.7006253843624993, 0.9630573879019151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.10302533798448267`], {
             RGBColor[
             0.9645754531953188, 0.8921668269279859, 0.3168827543384975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.10302533798448267`], {
             RGBColor[
             0.21277857456934213`, 0.34097415118617147`, 0.9354287970928072]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.10302533798448267`], {
             RGBColor[
             0.23178154572615212`, 0.3609474787299394, 0.9365109881878111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.10302533798448267`], {
             RGBColor[
             0.34909505354151776`, 0.4767903221752649, 0.9434650060123984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.10302533798448267`], {
             RGBColor[
             0.6029315110482949, 0.6885259882808699, 0.9618841236420709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.10302533798448267`], {
             RGBColor[
             0.25879261498995565`, 0.3893378251269034, 0.9380492286230886]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.10302533798448267`], {
             RGBColor[
             0.2680583595238526, 0.3990767101141639, 0.9385768990668534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.10302533798448267`], {
             RGBColor[
             0.8360763947567734, 0.2783045556433535, 0.18218010240253352`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.10302533798448267`], {
             RGBColor[
             0.9636570397640628, 0.9724160602789496, 0.9464033313040466]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.10302533798448267`], {
             RGBColor[
             0.6187231293682252, 0.7013463354372874, 0.9631272976828197]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.10302533798448267`], {
             RGBColor[
             0.25564421936180226`, 0.3860286617019018, 0.9378699321496993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.10302533798448267`], {
             RGBColor[
             0.382771346863294, 0.50595903483087, 0.945610829644085]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.10302533798448267`], {
             RGBColor[
             0.5590358689967736, 0.6528895285873056, 0.9584284979047402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.10302533798448267`], {
             RGBColor[
             0.9409750107809423, 0.8036926171977683, 0.27136531206102255`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.10302533798448267`], {
             RGBColor[
             0.8619011142240809, 0.46580703815332913`, 0.20647924340617463`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.10302533798448267`], {
             RGBColor[
             0.2909832679823188, 0.4231722424271597, 0.9398824386892002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.10302533798448267`], {
             RGBColor[
             0.6129287179190951, 0.6966421711876226, 0.9626711403879157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.10302533798448267`], {
             RGBColor[
             0.8179080138731872, 0.1386544187368418, 0.16478204035016009`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.10302533798448267`], {
             RGBColor[
             0.24306150835744214`, 0.3728034346463635, 0.9371533653724538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.10302533798448267`], {
             RGBColor[
             0.20926131084396443`, 0.33727728400339907`, 0.9352284941269724]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.10302533798448267`], {
             RGBColor[
             0.209897553009386, 0.33794601485934034`, 0.9352647271770572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.10302533798448267`], {
             RGBColor[
             0.8372847792405768, 0.8730921717492939, 0.9843421637685542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.10302533798448267`], {
             RGBColor[
             0.6962355794932261, 0.7626237933772783, 0.9703579139386239]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.10302533798448267`], {
             RGBColor[
             0.7603990286995737, 0.8127487675575523, 0.9767531269139887]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.10302533798448267`], {
             RGBColor[
             0.28525208052382683`, 0.41714840103001194`, 0.9395560560419711]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.10302533798448267`], {
             RGBColor[
             0.9944845479757449, 0.9919872330943883, 0.7410688437815899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.10302533798448267`], {
             RGBColor[
             0.2558608387541249, 0.3862563424176957, 0.9378822683036323]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{3.8349504055390835`*^9, 3.834957759852075*^9, 
  3.835018922383715*^9, 3.835019017360054*^9, 3.835020551743785*^9, 
  3.835044643191966*^9, 3.835045032973324*^9, 3.8350454125489206`*^9, 
  3.8350520379659443`*^9},
 CellLabel->
  "Out[414]=",ExpressionUUID->"e7435964-3f5c-4e37-94a7-415ecd80df62"]
}, Open  ]],

Cell["Estimated with Max-Min Deviation v Calculated: (r = 3)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 3.8349503922098827`*^9}, {3.8349504781120467`*^9, 
  3.8349504928656063`*^9}},ExpressionUUID->"280835c7-c823-4f93-a3a7-\
0cd86641e893"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphinf3", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsif3", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}],
      "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"mMDi3f300", ",", "krif3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502554527807`*^9}, {3.8349577716948586`*^9, 
   3.8349577796673746`*^9}, {3.835018835203446*^9, 3.8350188366714215`*^9}, {
   3.8350443464072504`*^9, 3.835044352231003*^9}, {3.8350449386312246`*^9, 
   3.835044944694197*^9}, {3.83504528478615*^9, 3.835045286563032*^9}},
 CellLabel->
  "In[301]:=",ExpressionUUID->"e4c3debb-322e-4fe2-a471-5cd47bb31e4c"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1FO4EAYYBuBzsm2dTrZdW7WsZbtVy3bLtWxr2bat5WVjyzZXrfc8u3i/
//a7+f7gJu2rtAsMCAjIJEJuKEIThrCEIzwRiEgkIhOFqEQjOjGISSxiE4e4
xCM+CUhIIhKThKQkI4jkBJOClKQiNWlISzrSk4GMIX3JTBayko3s5CAnuchN
HvKSj/wUoCCF+IEfKUwRivITxShOCUpSitKUoSzlKE8FfqYilahMFapSjerU
oCa1qE0d6lKP+jSgIY1oTBN+oSnNaM6vtKAlrWhNG9rSjvZ0oCOd6EwXutKN
7vSgJ73ozW/0oS/96M8ABjKIwQzhd4YyjOGMYCSjGM0YxjKO8UxgIpOYzBSm
Mo3pzGAms5jNH8xhLvOYzwIWsojFLGEpy1jOClayitWsYS3rWM8GNrKJzWxh
K9vYzg52sovd7GEv+9jPAQ5yiMMc4U+OcozjnOAkpzjNX5zhLOc4zwUuconL
XOEq17jODW5yi9v8zT/c4S73uM8DHvKIxzzhKc94zgte8orXvOEt73jPBz7y
ic/8yxe+8o3/CBl/IKEITRjCEo7wRCAikYhMFKISjejEICaxiE0c4hKP+CQg
IYlITBKSkowgkhNMClKSitSkIS3pSE8GMgb+/6++Az6VhWw=
          "], {Null, CompressedData["
1:eJxN2nu4llWZB+C1RcxDZpqQRxAUUVHStBgOUSMyo5BNY0aKowyCpqCIyVg4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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[57, 280] -> 
             RGBColor[
              0.8851416842105263, 0.9096315789473685, 0.9162844473684211], 
             UndirectedEdge[46, 187] -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             UndirectedEdge[96, 298] -> 
             RGBColor[
              0.6425212631578948, 0.7141316842105263, 0.9663634473684211], 
             UndirectedEdge[165, 207] -> 
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578], 
             UndirectedEdge[69, 224] -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             UndirectedEdge[51, 110] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[122, 231] -> 
             RGBColor[
              0.5646902631578948, 0.6524394210526316, 0.9611415263157894], 
             UndirectedEdge[71, 246] -> 
             RGBColor[
              0.9911962105263157, 0.9906274210526316, 0.7955651052631578], 
             UndirectedEdge[9, 239] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[99, 229] -> 
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578], 
             UndirectedEdge[49, 112] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[115, 243] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[58, 95] -> 
             RGBColor[
              0.6077486842105264, 0.6864707894736843, 0.9653286842105263], 
             UndirectedEdge[210, 239] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[94, 150] -> 
             RGBColor[
              0.6658008157894737, 0.7176094210526316, 0.6694048947368421], 
             UndirectedEdge[21, 108] -> 
             RGBColor[
              0.8325516842105263, 0.8672602105263159, 0.8526547631578946], 
             UndirectedEdge[83, 202] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[172, 174] -> 
             RGBColor[
              0.7264971578947369, 0.7862643684210526, 0.9733741052631579], 
             UndirectedEdge[3, 157] -> 
             RGBColor[
              0.5542524736842105, 0.6481633157894737, 0.9584598421052631], 
             UndirectedEdge[181, 246] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[159, 253] -> 
             RGBColor[
              0.5995846052631579, 0.6725200789473684, 0.9637894736842105], 
             UndirectedEdge[170, 228] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[151, 194] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[62, 100] -> 
             RGBColor[
              0.9000812894736843, 0.8320507368421053, 0.6255228157894737], 
             UndirectedEdge[76, 99] -> 
             RGBColor[
              0.7163991052631579, 0.7729787368421053, 0.8433312368421051], 
             UndirectedEdge[131, 283] -> 
             RGBColor[
              0.9000812894736843, 0.8320507368421053, 0.6255228157894737], 
             UndirectedEdge[173, 263] -> 
             RGBColor[
              0.8325516842105263, 0.8672602105263159, 0.8526547631578946], 
             UndirectedEdge[20, 75] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[175, 253] -> 
             RGBColor[
              0.9659621842105264, 0.9711721052631579, 0.7710717105263156], 
             UndirectedEdge[52, 193] -> 
             RGBColor[
              0.49545657894736844`, 0.6008597894736842, 0.9535374736842105], 
             UndirectedEdge[282, 283] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[173, 279] -> 
             RGBColor[
              0.7737557894736842, 0.8199566842105264, 0.8477323947368419], 
             UndirectedEdge[95, 198] -> 
             RGBColor[
              0.3467912631578948, 0.4747948947368422, 0.9433182105263158], 
             UndirectedEdge[18, 288] -> 
             RGBColor[
              0.5585891315789474, 0.6294312368421052, 0.9614548421052631], 
             UndirectedEdge[29, 91] -> 
             RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947365], 
             UndirectedEdge[46, 169] -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             UndirectedEdge[34, 264] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[116, 277] -> 
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725], 
             UndirectedEdge[60, 299] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[205, 213] -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 
             UndirectedEdge[240, 299] -> 
             RGBColor[
              0.9317022105263157, 0.9451111578947369, 0.8624326578947367], 
             UndirectedEdge[184, 214] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[39, 59] -> 
             RGBColor[
              0.6272955263157894, 0.6902237105263158, 0.7454524999999999], 
             UndirectedEdge[246, 299] -> 
             RGBColor[
              0.9911962105263157, 0.9906274210526316, 0.7955651052631578], 
             UndirectedEdge[21, 114] -> 
             RGBColor[
              0.8043281578947369, 0.8479566315789474, 0.9785960263157893], 
             UndirectedEdge[204, 253] -> 
             RGBColor[
              0.9034786842105264, 0.9258075789473684, 0.9883739210526314], 
             UndirectedEdge[202, 214] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[26, 39] -> 
             RGBColor[
              0.8320390789473684, 0.8656602631578948, 0.7602590526315788], 
             UndirectedEdge[118, 220] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[28, 126] -> 
             RGBColor[
              0.9941857105263158, 0.9904756842105263, 0.6451304473684207], 
             UndirectedEdge[9, 237] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[174, 297] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.6672426842105263, 0.731987052631579, 0.8984611315789475], 
             UndirectedEdge[63, 139] -> 
             RGBColor[
              0.508598157894737, 0.6086198421052633, 0.9555507894736842], 
             UndirectedEdge[124, 150] -> 
             RGBColor[
              0.9267582368421052, 0.9292853157894737, 0.6914153684210526], 
             UndirectedEdge[127, 165] -> 
             RGBColor[
              0.7608458421052632, 0.8120739473684211, 0.9477517631578947], 
             UndirectedEdge[8, 22] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[127, 137] -> 
             RGBColor[
              0.49545657894736844`, 0.6008597894736842, 0.9535374736842105], 
             UndirectedEdge[21, 213] -> 
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158], 
             UndirectedEdge[41, 278] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[69, 249] -> 
             RGBColor[
              0.9034786842105264, 0.9258075789473684, 0.9883739210526314], 
             UndirectedEdge[100, 136] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[88, 222] -> 
             RGBColor[
              0.9499918684210527, 0.9180226315789473, 0.6476234999999999], 
             UndirectedEdge[153, 216] -> 
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052], 
             UndirectedEdge[60, 121] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[203, 206] -> 
             RGBColor[
              0.9862522368421052, 0.9748015789473685, 0.6245478157894737], 
             UndirectedEdge[50, 108] -> 
             RGBColor[
              0.9470509736842105, 0.8140864210526317, 0.48764921052631566`], 
             UndirectedEdge[98, 181] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[267, 285] -> 
             RGBColor[
              0.9625647894736842, 0.8774152631578948, 0.40822060526315773`], 
             UndirectedEdge[156, 178] -> 
             RGBColor[
              0.9782153947368422, 0.9373262105263158, 0.521682236842105], 
             UndirectedEdge[185, 295] -> 
             RGBColor[
              0.7264971578947369, 0.7862643684210526, 0.9733741052631579], 
             UndirectedEdge[83, 156] -> 
             RGBColor[
              0.965305447368421, 0.9294434736842105, 0.6217016052631578], 
             UndirectedEdge[44, 150] -> 
             RGBColor[
              0.8276077105263158, 0.8514343684210527, 0.6816374736842105], 
             UndirectedEdge[223, 274] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[20, 142] -> 
             RGBColor[
              0.8325516842105263, 0.8672602105263159, 0.8526547631578946], 
             UndirectedEdge[87, 264] -> 
             RGBColor[
              0.7455322631578948, 0.8006531052631579, 0.9736736578947367], 
             UndirectedEdge[16, 192] -> 
             RGBColor[
              0.9906836052631578, 0.9890274736842106, 0.703169394736842], 
             UndirectedEdge[75, 143] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[230, 263] -> 
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158], 
             UndirectedEdge[52, 82] -> 
             RGBColor[
              0.7688118157894737, 0.8041308421052632, 0.6767151052631578], 
             UndirectedEdge[34, 213] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[145, 219] -> 
             RGBColor[
              0.5995846052631579, 0.6725200789473684, 0.9637894736842105], 
             UndirectedEdge[237, 295] -> 
             RGBColor[
              0.8851416842105263, 0.9096315789473685, 0.9162844473684211], 
             UndirectedEdge[257, 259] -> 
             RGBColor[
              0.8604202631578948, 0.8917762105263158, 0.9841867631578947], 
             UndirectedEdge[116, 241] -> 
             RGBColor[
              0.8604202631578948, 0.8917762105263158, 0.9841867631578947], 
             UndirectedEdge[95, 105] -> 
             RGBColor[
              0.3924455789473684, 0.5143383684210527, 0.9462272631578947], 
             UndirectedEdge[115, 146] -> 
             RGBColor[
              0.7455322631578948, 0.8006531052631579, 0.9736736578947367], 
             UndirectedEdge[16, 170] -> 
             RGBColor[
              0.9906836052631578, 0.9890274736842106, 0.703169394736842], 
             UndirectedEdge[199, 226] -> 
             RGBColor[
              0.8930987105263157, 0.5552185789473685, 0.550891447368421], 
             UndirectedEdge[78, 130] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[155, 214] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[185, 297] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[45, 53] -> 
             RGBColor[0.942107, 0.7982605789473685, 0.31663192105263155`], 
             UndirectedEdge[49, 204] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[69, 254] -> 
             RGBColor[
              0.9659621842105264, 0.9711721052631579, 0.7710717105263156], 
             UndirectedEdge[102, 295] -> 
             RGBColor[
              0.8851416842105263, 0.9096315789473685, 0.9162844473684211], 
             UndirectedEdge[14, 254] -> 
             RGBColor[
              0.9311896052631579, 0.9435112105263158, 0.7700369473684209], 
             UndirectedEdge[125, 299] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[16, 44] -> 
             RGBColor[
              0.8320390789473684, 0.8656602631578948, 0.7602590526315788], 
             UndirectedEdge[49, 84] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[186, 230] -> 
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158], 
             UndirectedEdge[215, 282] -> 
             RGBColor[
              0.9000812894736843, 0.8320507368421053, 0.6255228157894737], 
             UndirectedEdge[134, 159] -> 
             RGBColor[
              0.6272955263157894, 0.6902237105263158, 0.7454524999999999], 
             UndirectedEdge[26, 266] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[142, 150] -> 
             RGBColor[
              0.9897543421052631, 0.9762497894736842, 0.5665088684210524], 
             UndirectedEdge[114, 221] -> 
             RGBColor[
              0.9664747894736843, 0.972772052631579, 0.8634674210526314], 
             UndirectedEdge[147, 172] -> 
             RGBColor[
              0.8043281578947369, 0.8479566315789474, 0.9785960263157893], 
             UndirectedEdge[35, 211] -> 
             RGBColor[
              0.9911962105263157, 0.9906274210526316, 0.7955651052631578], 
             UndirectedEdge[124, 295] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[166, 233] -> 
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158], 
             UndirectedEdge[88, 290] -> 
             RGBColor[
              0.8604202631578948, 0.8917762105263158, 0.9841867631578947], 
             UndirectedEdge[134, 235] -> 
             RGBColor[
              0.5863000526315789, 0.6471348684210526, 0.7431178684210524], 
             UndirectedEdge[185, 239] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[260, 278] -> 
             RGBColor[
              0.8851416842105263, 0.9096315789473685, 0.9162844473684211], 
             UndirectedEdge[15, 242] -> 
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052], 
             UndirectedEdge[4, 266] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[3, 123] -> 
             RGBColor[
              0.8043281578947369, 0.8479566315789474, 0.9785960263157893], 
             UndirectedEdge[28, 184] -> 
             RGBColor[
              0.9659621842105264, 0.9711721052631579, 0.7710717105263156], 
             UndirectedEdge[116, 210] -> 
             RGBColor[
              0.9664747894736843, 0.972772052631579, 0.8634674210526314], 
             UndirectedEdge[118, 120] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[15, 89] -> 
             RGBColor[
              0.9311896052631579, 0.9435112105263158, 0.7700369473684209], 
             UndirectedEdge[11, 283] -> 
             RGBColor[
              0.6077486842105264, 0.6864707894736843, 0.9653286842105263], 
             UndirectedEdge[157, 201] -> 
             RGBColor[
              0.7163991052631579, 0.7729787368421053, 0.8433312368421051], 
             UndirectedEdge[196, 279] -> 
             RGBColor[
              0.7608458421052632, 0.8120739473684211, 0.9477517631578947], 
             UndirectedEdge[7, 11] -> 
             RGBColor[
              0.6578348421052632, 0.7255525263157896, 0.9404415526315789], 
             UndirectedEdge[76, 284] -> 
             RGBColor[
              0.9630773947368421, 0.8790152105263158, 0.5006163157894735], 
             UndirectedEdge[34, 108] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[46, 213] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[261, 278] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[58, 66] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[194, 297] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[283, 297] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.6103445789473685, 0.691982894736842, 0.9640505789473683], 
             UndirectedEdge[6, 169] -> 
             RGBColor[
              0.9615308157894737, 0.9569462105263158, 0.6924501315789473], 
             UndirectedEdge[11, 172] -> 
             RGBColor[
              0.508598157894737, 0.6086198421052633, 0.9555507894736842], 
             UndirectedEdge[4, 82] -> 
             RGBColor[
              0.8276077105263158, 0.8514343684210527, 0.6816374736842105], 
             UndirectedEdge[140, 230] -> 
             RGBColor[
              0.7128969999999999, 0.7715305263157894, 0.9013701842105264], 
             UndirectedEdge[207, 232] -> 
             RGBColor[
              0.6103445789473685, 0.691982894736842, 0.9640505789473683], 
             UndirectedEdge[147, 244] -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             UndirectedEdge[56, 296] -> 
             RGBColor[
              0.7128969999999999, 0.7715305263157894, 0.9013701842105264], 
             UndirectedEdge[243, 294] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[211, 216] -> 
             RGBColor[
              0.9317022105263157, 0.9451111578947369, 0.8624326578947367], 
             UndirectedEdge[107, 141] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[19, 175] -> 
             RGBColor[
              0.9311896052631579, 0.9435112105263158, 0.7700369473684209], 
             UndirectedEdge[17, 158] -> 
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578], 
             UndirectedEdge[115, 242] -> 
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725], 
             UndirectedEdge[159, 292] -> 
             RGBColor[
              0.46566150000000006`, 0.5670082368421053, 0.9529768157894737], 
             UndirectedEdge[34, 205] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[23, 180] -> 
             RGBColor[
              0.8009307631578948, 0.7541997894736843, 0.6157449210526316], 
             UndirectedEdge[47, 158] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[130, 199] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[112, 204] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[217, 247] -> 
             RGBColor[
              0.7264971578947369, 0.7862643684210526, 0.9733741052631579], 
             UndirectedEdge[102, 185] -> 
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158], 
             UndirectedEdge[136, 137] -> 
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578], 
             UndirectedEdge[138, 258] -> 
             RGBColor[
              0.6425212631578948, 0.7141316842105263, 0.9663634473684211], 
             UndirectedEdge[79, 277] -> 
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578], 
             UndirectedEdge[41, 259] -> 
             RGBColor[
              0.8604202631578948, 0.8917762105263158, 0.9841867631578947], 
             UndirectedEdge[225, 287] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[167, 194] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[64, 219] -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             UndirectedEdge[83, 293] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[31, 95] -> 
             RGBColor[
              0.6672426842105263, 0.731987052631579, 0.8984611315789475], 
             UndirectedEdge[256, 299] -> 
             RGBColor[
              0.8325516842105263, 0.8672602105263159, 0.8526547631578946], 
             UndirectedEdge[129, 269] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[83, 126] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[23, 81] -> 
             RGBColor[
              0.6847781842105263, 0.6599183157894737, 0.6064213947368421], 
             UndirectedEdge[235, 252] -> 
             RGBColor[
              0.5703297368421052, 0.5939853947368421, 0.6196696578947367], 
             UndirectedEdge[6, 264] -> 
             RGBColor[
              0.9615308157894737, 0.9569462105263158, 0.6924501315789473], 
             UndirectedEdge[167, 215] -> 
             RGBColor[
              0.9501674473684211, 0.8711324736842105, 0.6006356842105263], 
             UndirectedEdge[273, 285] -> 
             RGBColor[
              0.9501674473684211, 0.8711324736842105, 0.6006356842105263], 
             UndirectedEdge[267, 273] -> 
             RGBColor[
              0.9812757631578948, 0.9825929473684211, 0.7451498157894735], 
             UndirectedEdge[66, 109] -> 
             RGBColor[
              0.8881311842105264, 0.9094798421052632, 0.765849789473684], 
             UndirectedEdge[104, 173] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[9, 185] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[233, 288] -> 
             RGBColor[
              0.5833105526315789, 0.647286605263158, 0.8935525263157895], 
             UndirectedEdge[139, 147] -> 
             RGBColor[
              0.6425212631578947, 0.7141316842105263, 0.9663634473684211], 
             UndirectedEdge[65, 103] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[33, 124] -> 
             RGBColor[
              0.6077486842105264, 0.6864707894736843, 0.9653286842105263], 
             UndirectedEdge[82, 226] -> 
             RGBColor[
              0.9010646842105263, 0.5472754736842105, 0.27985478947368414`], 
             UndirectedEdge[6, 221] -> 
             RGBColor[
              0.9897543421052631, 0.9762497894736842, 0.5665088684210524], 
             UndirectedEdge[125, 136] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[112, 292] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[58, 67] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[73, 105] -> 
             RGBColor[
              0.7114551315789474, 0.7571528947368421, 0.672313947368421], 
             UndirectedEdge[263, 298] -> 
             RGBColor[
              0.508598157894737, 0.6086198421052633, 0.9555507894736842], 
             UndirectedEdge[60, 170] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[10, 129] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[53, 234] -> 
             RGBColor[
              0.9615308157894737, 0.9569462105263158, 0.6924501315789473], 
             UndirectedEdge[51, 154] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[17, 84] -> 
             RGBColor[
              0.7128969999999999, 0.7715305263157894, 0.9013701842105264], 
             UndirectedEdge[98, 160] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[25, 147] -> 
             RGBColor[
              0.9348538684210527, 0.8597116315789474, 0.6265575789473683], 
             UndirectedEdge[159, 204] -> 
             RGBColor[
              0.5648120263157894, 0.6448591842105263, 0.9627547105263158], 
             UndirectedEdge[37, 94] -> 
             RGBColor[
              0.5646902631578948, 0.6524394210526316, 0.9611415263157894], 
             UndirectedEdge[37, 283] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[9, 142] -> 
             RGBColor[
              0.9317022105263157, 0.9451111578947369, 0.8624326578947367], 
             UndirectedEdge[51, 109] -> 
             RGBColor[
              0.9812757631578948, 0.9825929473684211, 0.7451498157894735], 
             UndirectedEdge[123, 257] -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             UndirectedEdge[212, 294] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[237, 297] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[163, 197] -> 
             RGBColor[
              0.6677012631578948, 0.7389608421052631, 0.9684517368421053], 
             UndirectedEdge[76, 229] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[18, 24] -> 
             RGBColor[
              0.8043281578947369, 0.8479566315789474, 0.9785960263157893], 
             UndirectedEdge[44, 124] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[26, 82] -> 
             RGBColor[
              0.8276077105263158, 0.8514343684210527, 0.6816374736842105], 
             UndirectedEdge[7, 106] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[53, 255] -> 
             RGBColor[
              0.9862522368421052, 0.9748015789473685, 0.6245478157894737], 
             UndirectedEdge[89, 242] -> 
             RGBColor[0.7158865, 0.7713787894736842, 0.7509355263157893], 
             UndirectedEdge[121, 181] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[217, 273] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[141, 240] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[42, 159] -> 
             RGBColor[
              0.6148981842105263, 0.6839409210526316, 0.9378675789473684], 
             UndirectedEdge[51, 52] -> 
             RGBColor[
              0.7608458421052632, 0.8120739473684211, 0.9477517631578947], 
             UndirectedEdge[170, 225] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[51, 179] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[36, 198] -> 
             RGBColor[
              0.44980226315789484`, 0.5613163157894738, 0.9506284210526316], 
             UndirectedEdge[150, 295] -> 
             RGBColor[
              0.8836998157894738, 0.8952539473684211, 0.6872282105263157], 
             UndirectedEdge[140, 196] -> 
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578], 
             UndirectedEdge[31, 73] -> 
             RGBColor[
              0.9862522368421052, 0.9748015789473685, 0.6245478157894737], 
             UndirectedEdge[188, 212] -> 
             RGBColor[
              0.9317022105263157, 0.9451111578947369, 0.8624326578947367], 
             UndirectedEdge[172, 244] -> 
             RGBColor[
              0.8043281578947369, 0.8479566315789474, 0.9785960263157893], 
             UndirectedEdge[7, 63] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[128, 218] -> 
             RGBColor[
              0.7608458421052632, 0.8120739473684211, 0.9477517631578947], 
             UndirectedEdge[138, 154] -> 
             RGBColor[
              0.9034786842105264, 0.9258075789473684, 0.9883739210526314], 
             UndirectedEdge[1, 297] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[90, 123] -> 
             RGBColor[
              0.6425212631578947, 0.7141316842105263, 0.9663634473684211], 
             UndirectedEdge[8, 61] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[201, 209] -> 
             RGBColor[
              0.9060086578947368, 0.5631013157894738, 0.45087207894736825`], 
             UndirectedEdge[44, 94] -> 
             RGBColor[
              0.508598157894737, 0.6086198421052633, 0.9555507894736842], 
             UndirectedEdge[114, 213] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[82, 107] -> 
             RGBColor[
              0.8836998157894738, 0.8952539473684211, 0.6872282105263157], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.8881311842105264, 0.9094798421052632, 0.765849789473684], 
             UndirectedEdge[182, 268] -> 
             RGBColor[
              0.9911962105263157, 0.9906274210526316, 0.7955651052631578], 
             UndirectedEdge[157, 229] -> 
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578], 
             UndirectedEdge[99, 157] -> 
             RGBColor[
              0.4380998947368421, 0.5538818421052631, 0.9491363157894737], 
             UndirectedEdge[249, 288] -> 
             RGBColor[
              0.523816552631579, 0.6017703421052631, 0.9604200789473685], 
             UndirectedEdge[66, 138] -> 
             RGBColor[
              0.8604202631578948, 0.8917762105263158, 0.9841867631578947], 
             UndirectedEdge[215, 286] -> 
             RGBColor[
              0.6847781842105263, 0.6599183157894737, 0.6064213947368421], 
             UndirectedEdge[83, 275] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[95, 289] -> 
             RGBColor[
              0.6425212631578947, 0.7141316842105263, 0.9663634473684211], 
             UndirectedEdge[37, 75] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[88, 260] -> 
             RGBColor[
              0.8604202631578948, 0.8917762105263158, 0.9841867631578947], 
             UndirectedEdge[60, 82] -> 
             RGBColor[
              0.9768443947368421, 0.968367052631579, 0.6665282368421052], 
             UndirectedEdge[50, 227] -> 
             RGBColor[
              0.6687517631578948, 0.5949895263157896, 0.5934542894736843], 
             UndirectedEdge[12, 248] -> 
             RGBColor[
              0.9664747894736843, 0.972772052631579, 0.8634674210526314], 
             UndirectedEdge[103, 164] -> 
             RGBColor[
              0.6077486842105264, 0.6864707894736843, 0.9653286842105263], 
             UndirectedEdge[127, 228] -> 
             RGBColor[
              0.7455322631578948, 0.8006531052631579, 0.9736736578947367], 
             UndirectedEdge[163, 184] -> 
             RGBColor[
              0.8604202631578948, 0.8917762105263158, 0.9841867631578947], 
             UndirectedEdge[11, 183] -> 
             RGBColor[
              0.5646902631578948, 0.6524394210526316, 0.9611415263157894], 
             UndirectedEdge[226, 266] -> 
             RGBColor[
              0.8930987105263157, 0.5552185789473685, 0.550891447368421], 
             UndirectedEdge[98, 178] -> 
             RGBColor[
              0.8886437894736843, 0.9110797894736842, 0.8582454999999998], 
             UndirectedEdge[200, 255] -> 
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158], 
             UndirectedEdge[223, 234] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[111, 190] -> 
             RGBColor[
              0.7421348684210527, 0.7068962631578948, 0.6108225526315789], 
             UndirectedEdge[85, 181] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[57, 134] -> 
             RGBColor[
              0.9906836052631578, 0.9890274736842106, 0.703169394736842], 
             UndirectedEdge[9, 131] -> 
             RGBColor[
              0.9000812894736843, 0.8320507368421053, 0.6255228157894737], 
             UndirectedEdge[184, 189] -> 
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725], 
             UndirectedEdge[194, 286] -> 
             RGBColor[
              0.5542524736842105, 0.6481633157894737, 0.9584598421052631], 
             UndirectedEdge[171, 298] -> 
             RGBColor[
              0.6391238684210527, 0.6203748421052633, 0.6035123421052632], 
             UndirectedEdge[108, 213] -> 
             RGBColor[
              0.9911962105263157, 0.9906274210526316, 0.7955651052631578], 
             UndirectedEdge[158, 175] -> 
             RGBColor[
              0.9812757631578948, 0.9825929473684211, 0.7451498157894735], 
             UndirectedEdge[37, 297] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[68, 234] -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             UndirectedEdge[38, 252] -> 
             RGBColor[0.9305680526315789, 0.759337, 0.27180528947368415`], 
             UndirectedEdge[42, 252] -> 
             RGBColor[
              0.965305447368421, 0.9294434736842105, 0.6217016052631578], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.7264971578947369, 0.7862643684210526, 0.9733741052631579], 
             UndirectedEdge[184, 216] -> 
             RGBColor[
              0.9034786842105264, 0.9258075789473684, 0.9883739210526314], 
             UndirectedEdge[16, 59] -> 
             RGBColor[
              0.6272955263157894, 0.6902237105263158, 0.7454524999999999], 
             UndirectedEdge[7, 185] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[127, 299] -> 
             RGBColor[
              0.7737557894736842, 0.8199566842105264, 0.8477323947368419], 
             UndirectedEdge[166, 217] -> 
             RGBColor[
              0.7264971578947369, 0.7862643684210526, 0.9733741052631579], 
             UndirectedEdge[101, 207] -> 
             RGBColor[
              0.6103445789473685, 0.691982894736842, 0.9640505789473683], 
             UndirectedEdge[14, 69] -> 
             RGBColor[
              0.9034786842105264, 0.9258075789473684, 0.9883739210526314], 
             UndirectedEdge[51, 107] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[74, 233] -> 
             RGBColor[
              0.6672426842105263, 0.731987052631579, 0.8984611315789475], 
             UndirectedEdge[158, 252] -> 
             RGBColor[
              0.965305447368421, 0.9294434736842105, 0.6217016052631578], 
             UndirectedEdge[86, 110] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[58, 73] -> 
             RGBColor[
              0.9267582368421052, 0.9292853157894737, 0.6914153684210526], 
             UndirectedEdge[13, 96] -> 
             RGBColor[
              0.9659621842105264, 0.9711721052631579, 0.7710717105263156], 
             UndirectedEdge[16, 53] -> 
             RGBColor[
              0.9892417368421053, 0.9746498421052632, 0.4741131578947366], 
             UndirectedEdge[44, 170] -> 
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158], 
             UndirectedEdge[27, 32] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[116, 164] -> 
             RGBColor[
              0.6425212631578948, 0.7141316842105263, 0.9663634473684211], 
             UndirectedEdge[70, 300] -> 
             RGBColor[
              0.308513447368421, 0.42963792105263154`, 0.9413186578947368], 
             UndirectedEdge[79, 116] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[137, 195] -> 
             RGBColor[
              0.7163991052631579, 0.7729787368421053, 0.8433312368421051], 
             UndirectedEdge[156, 214] -> 
             RGBColor[
              0.965305447368421, 0.9294434736842105, 0.6217016052631578], 
             UndirectedEdge[14, 249] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[84, 89] -> 
             RGBColor[
              0.9906836052631578, 0.9890274736842106, 0.703169394736842], 
             UndirectedEdge[98, 246] -> 
             RGBColor[
              0.8851416842105263, 0.9096315789473685, 0.9162844473684211], 
             UndirectedEdge[4, 107] -> 
             RGBColor[
              0.7264971578947369, 0.7862643684210526, 0.9733741052631579], 
             UndirectedEdge[20, 295] -> 
             RGBColor[
              0.7264971578947369, 0.7862643684210526, 0.9733741052631579], 
             UndirectedEdge[57, 175] -> 
             RGBColor[
              0.9906836052631578, 0.9890274736842106, 0.703169394736842], 
             UndirectedEdge[93, 160] -> 
             RGBColor[
              0.9317022105263157, 0.9451111578947369, 0.8624326578947367], 
             UndirectedEdge[13, 149] -> 
             RGBColor[
              0.9311896052631579, 0.9435112105263158, 0.7700369473684209], 
             UndirectedEdge[230, 298] -> 
             RGBColor[
              0.6672426842105263, 0.731987052631579, 0.8984611315789475], 
             UndirectedEdge[96, 198] -> 
             RGBColor[
              0.6425212631578948, 0.7141316842105263, 0.9663634473684211], 
             UndirectedEdge[32, 182] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[80, 241] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[55, 292] -> 
             RGBColor[
              0.5542524736842105, 0.6481633157894737, 0.9584598421052631], 
             UndirectedEdge[121, 160] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[62, 220] -> 
             RGBColor[
              0.9630773947368421, 0.8790152105263158, 0.5006163157894735], 
             UndirectedEdge[28, 189] -> 
             RGBColor[0.7158865, 0.7713787894736842, 0.7509355263157893], 
             UndirectedEdge[25, 91] -> 
             RGBColor[
              0.9630773947368421, 0.8790152105263158, 0.5006163157894735], 
             UndirectedEdge[41, 99] -> 
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725], 
             UndirectedEdge[148, 206] -> 
             RGBColor[0.9747132894736842, 0.935878, 0.5797211842105263], 
             UndirectedEdge[3, 90] -> 
             RGBColor[
              0.508598157894737, 0.6086198421052633, 0.9555507894736842], 
             UndirectedEdge[99, 104] -> 
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578], 
             UndirectedEdge[193, 266] -> 
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578], 
             UndirectedEdge[275, 293] -> 
             RGBColor[
              0.9911962105263157, 0.9906274210526316, 0.7955651052631578], 
             UndirectedEdge[229, 257] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[90, 144] -> 
             RGBColor[
              0.6702321842105263, 0.7318353157894737, 0.7480264736842104], 
             UndirectedEdge[49, 115] -> 
             RGBColor[
              0.9034786842105264, 0.9258075789473684, 0.9883739210526314], 
             UndirectedEdge[77, 244] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[66, 95] -> 
             RGBColor[
              0.5646902631578948, 0.6524394210526316, 0.9611415263157894], 
             UndirectedEdge[94, 125] -> 
             RGBColor[
              0.6578348421052631, 0.7255525263157896, 0.9404415526315789], 
             UndirectedEdge[196, 230] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[138, 245] -> 
             RGBColor[
              0.8604202631578948, 0.8917762105263158, 0.9841867631578947], 
             UndirectedEdge[100, 127] -> 
             RGBColor[
              0.7107596842105264, 0.7729922105263158, 0.9726388947368421], 
             UndirectedEdge[24, 288] -> 
             RGBColor[
              0.42466602631578954`, 0.5239193947368421, 0.9506421842105264], 
             UndirectedEdge[224, 258] -> 
             RGBColor[
              0.6425212631578948, 0.7141316842105263, 0.9663634473684211], 
             UndirectedEdge[25, 203] -> 
             RGBColor[
              0.9581334210526316, 0.8631893684210526, 0.3295990263157894], 
             UndirectedEdge[143, 239] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[142, 282] -> 
             RGBColor[
              0.9317022105263157, 0.9451111578947369, 0.8624326578947367], 
             UndirectedEdge[57, 242] -> 
             RGBColor[
              0.7128969999999999, 0.7715305263157894, 0.9013701842105264], 
             UndirectedEdge[47, 177] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[43, 174] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[5, 29] -> 
             RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947365], 
             UndirectedEdge[167, 282] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[131, 172] -> 
             RGBColor[
              0.8009307631578948, 0.7541997894736843, 0.6157449210526316], 
             UndirectedEdge[21, 101] -> 
             RGBColor[
              0.7264971578947369, 0.7862643684210526, 0.9733741052631579], 
             UndirectedEdge[251, 300] -> 
             RGBColor[
              0.5739027105263158, 0.6408520789473684, 0.9355329473684211], 
             UndirectedEdge[75, 167] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[165, 281] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[63, 174] -> 
             RGBColor[
              0.7264971578947369, 0.7862643684210526, 0.9733741052631579], 
             UndirectedEdge[64, 211] -> 
             RGBColor[
              0.9664747894736843, 0.972772052631579, 0.8634674210526314], 
             UndirectedEdge[124, 237] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[127, 192] -> 
             RGBColor[
              0.7702536842105263, 0.8185084736842105, 0.9057713421052631], 
             UndirectedEdge[62, 228] -> 
             RGBColor[
              0.9348538684210527, 0.8597116315789474, 0.6265575789473683], 
             UndirectedEdge[152, 277] -> 
             RGBColor[
              0.49545657894736844`, 0.6008597894736842, 0.9535374736842105], 
             UndirectedEdge[76, 157] -> 
             RGBColor[
              0.7163991052631579, 0.7729787368421053, 0.8433312368421051], 
             UndirectedEdge[106, 297] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[91, 203] -> 
             RGBColor[
              0.9897543421052631, 0.9762497894736842, 0.5665088684210524], 
             UndirectedEdge[215, 271] -> 
             RGBColor[
              0.9348538684210527, 0.8597116315789474, 0.6265575789473683], 
             UndirectedEdge[181, 296] -> 
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052], 
             UndirectedEdge[27, 119] -> 
             RGBColor[
              0.508598157894737, 0.6086198421052633, 0.9555507894736842], 
             UndirectedEdge[100, 170] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[112, 115] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[75, 282] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[234, 255] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[29, 77] -> 
             RGBColor[
              0.9911962105263157, 0.9906274210526316, 0.7955651052631578], 
             UndirectedEdge[44, 192] -> 
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158], 
             UndirectedEdge[49, 57] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[4, 281] -> 
             RGBColor[
              0.8325516842105263, 0.8672602105263159, 0.8526547631578946], 
             UndirectedEdge[23, 285] -> 
             RGBColor[
              0.9314564736842106, 0.7659547894736842, 0.2637064736842105], 
             UndirectedEdge[86, 109] -> 
             RGBColor[
              0.9906836052631578, 0.9890274736842106, 0.703169394736842], 
             UndirectedEdge[276, 279] -> 
             RGBColor[
              0.7608458421052632, 0.8120739473684211, 0.9477517631578947], 
             UndirectedEdge[139, 183] -> 
             RGBColor[
              0.5646902631578948, 0.6524394210526316, 0.9611415263157894], 
             UndirectedEdge[234, 287] -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             UndirectedEdge[160, 181] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[196, 298] -> 
             RGBColor[
              0.6578348421052632, 0.7255525263157896, 0.9404415526315789], 
             UndirectedEdge[255, 287] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[126, 216] -> 
             RGBColor[
              0.9317022105263157, 0.9451111578947369, 0.8624326578947367], 
             UndirectedEdge[190, 212] -> 
             RGBColor[
              0.9000812894736843, 0.8320507368421053, 0.6255228157894737], 
             UndirectedEdge[39, 137] -> 
             RGBColor[0.7158865, 0.7713787894736842, 0.7509355263157893], 
             UndirectedEdge[170, 195] -> 
             RGBColor[
              0.9911962105263157, 0.9906274210526316, 0.7955651052631578], 
             UndirectedEdge[69, 288] -> 
             RGBColor[
              0.5585891315789474, 0.6294312368421052, 0.9614548421052631], 
             UndirectedEdge[101, 231] -> 
             RGBColor[
              0.7825892631578948, 0.8300839473684211, 0.9789648421052631], 
             UndirectedEdge[57, 253] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[52, 266] -> 
             RGBColor[
              0.7608458421052632, 0.8120739473684211, 0.9477517631578947], 
             UndirectedEdge[28, 275] -> 
             RGBColor[
              0.9941857105263158, 0.9904756842105263, 0.6451304473684207], 
             UndirectedEdge[4, 226] -> 
             RGBColor[
              0.7438620263157896, 0.43828589473684215`, 0.5660006842105263], 
             UndirectedEdge[104, 229] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[189, 293] -> 
             RGBColor[
              0.7128969999999999, 0.7715305263157894, 0.9013701842105264], 
             UndirectedEdge[155, 156] -> 
             RGBColor[
              0.9499918684210527, 0.9180226315789473, 0.6476234999999999], 
             UndirectedEdge[107, 281] -> 
             RGBColor[
              0.8886437894736843, 0.9110797894736842, 0.8582454999999998], 
             UndirectedEdge[107, 240] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[13, 105] -> 
             RGBColor[0.7158865, 0.7713787894736842, 0.7509355263157893], 
             UndirectedEdge[96, 138] -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             UndirectedEdge[254, 260] -> 
             RGBColor[
              0.8881311842105264, 0.9094798421052632, 0.765849789473684], 
             UndirectedEdge[120, 176] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[59, 125] -> 
             RGBColor[
              0.6148981842105263, 0.6839409210526316, 0.9378675789473684], 
             UndirectedEdge[22, 267] -> 
             RGBColor[
              0.9812757631578948, 0.9825929473684211, 0.7451498157894735], 
             UndirectedEdge[28, 197] -> 
             RGBColor[
              0.7732431842105263, 0.8183567368421053, 0.7553366842105261], 
             UndirectedEdge[245, 298] -> 
             RGBColor[
              0.5646902631578948, 0.6524394210526316, 0.9611415263157894], 
             UndirectedEdge[193, 199] -> 
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578], 
             UndirectedEdge[22, 274] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[76, 201] -> 
             RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947365], 
             UndirectedEdge[19, 158] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[61, 267] -> 
             RGBColor[
              0.9812757631578948, 0.9825929473684211, 0.7451498157894735], 
             UndirectedEdge[106, 283] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[174, 283] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[19, 242] -> 
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052], 
             UndirectedEdge[125, 195] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[115, 159] -> 
             RGBColor[
              0.5995846052631579, 0.6725200789473684, 0.9637894736842105], 
             UndirectedEdge[158, 177] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[42, 134] -> 
             RGBColor[
              0.9812757631578948, 0.9825929473684211, 0.7451498157894735], 
             UndirectedEdge[165, 179] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[108, 145] -> 
             RGBColor[
              0.6278081315789473, 0.6918236578947369, 0.8378482105263156], 
             UndirectedEdge[44, 125] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[39, 141] -> 
             RGBColor[
              0.9812757631578948, 0.9825929473684211, 0.7451498157894735], 
             UndirectedEdge[50, 87] -> 
             RGBColor[
              0.7261084473684212, 0.6419674736842107, 0.597855447368421], 
             UndirectedEdge[26, 226] -> 
             RGBColor[
              0.7438620263157896, 0.43828589473684215`, 0.5660006842105263], 
             UndirectedEdge[9, 143] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[136, 299] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[134, 144] -> 
             RGBColor[
              0.9936731052631579, 0.9888757368421053, 0.552734736842105], 
             UndirectedEdge[240, 281] -> 
             RGBColor[
              0.9317022105263157, 0.9451111578947369, 0.8624326578947367], 
             UndirectedEdge[257, 261] -> 
             RGBColor[
              0.9034786842105264, 0.9258075789473684, 0.9883739210526314], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 
             UndirectedEdge[135, 254] -> 
             RGBColor[
              0.8881311842105264, 0.9094798421052632, 0.765849789473684], 
             UndirectedEdge[14, 224] -> 
             RGBColor[
              0.9034786842105264, 0.9258075789473684, 0.9883739210526314], 
             UndirectedEdge[96, 289] -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             UndirectedEdge[92, 189] -> 
             RGBColor[
              0.6687517631578948, 0.5949895263157896, 0.5934542894736843], 
             UndirectedEdge[107, 127] -> 
             RGBColor[
              0.6677012631578948, 0.7389608421052631, 0.9684517368421053], 
             UndirectedEdge[172, 270] -> 
             RGBColor[
              0.42466602631578954`, 0.5239193947368421, 0.9506421842105264], 
             UndirectedEdge[48, 84] -> 
             RGBColor[
              0.6672426842105263, 0.731987052631579, 0.8984611315789475], 
             UndirectedEdge[149, 289] -> 
             RGBColor[
              0.9034786842105264, 0.9258075789473684, 0.9883739210526314], 
             UndirectedEdge[1, 102] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[33, 297] -> 
             RGBColor[
              0.6578348421052631, 0.7255525263157896, 0.9404415526315789], 
             UndirectedEdge[18, 135] -> 
             RGBColor[
              0.8604202631578948, 0.8917762105263158, 0.9841867631578947], 
             UndirectedEdge[60, 137] -> 
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578], 
             UndirectedEdge[156, 208] -> 
             RGBColor[
              0.9152192894736842, 0.8903617368421053, 0.6465887368421052], 
             UndirectedEdge[104, 279] -> 
             RGBColor[
              0.7608458421052632, 0.8120739473684211, 0.9477517631578947], 
             UndirectedEdge[74, 158] -> 
             RGBColor[
              0.6578348421052631, 0.7255525263157896, 0.9404415526315789], 
             UndirectedEdge[80, 277] -> 
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578], 
             UndirectedEdge[223, 291] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[114, 264] -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             UndirectedEdge[1, 237] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[84, 292] -> 
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158], 
             UndirectedEdge[103, 152] -> 
             RGBColor[
              0.7107596842105264, 0.7729922105263158, 0.9726388947368421], 
             UndirectedEdge[10, 269] -> 
             RGBColor[
              0.9034786842105264, 0.9258075789473684, 0.9883739210526314], 
             UndirectedEdge[109, 138] -> 
             RGBColor[
              0.9659621842105264, 0.9711721052631579, 0.7710717105263156], 
             UndirectedEdge[165, 240] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[249, 254] -> 
             RGBColor[
              0.9311896052631579, 0.9435112105263158, 0.7700369473684209], 
             UndirectedEdge[2, 155] -> 
             RGBColor[
              0.8043281578947369, 0.8479566315789474, 0.9785960263157893], 
             UndirectedEdge[117, 161] -> 
             RGBColor[
              0.9812757631578948, 0.9825929473684211, 0.7451498157894735], 
             UndirectedEdge[169, 264] -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             UndirectedEdge[3, 229] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[55, 90] -> 
             RGBColor[
              0.3924455789473684, 0.5143383684210527, 0.9462272631578947], 
             UndirectedEdge[3, 259] -> 
             RGBColor[
              0.7264971578947369, 0.7862643684210526, 0.9733741052631579], 
             UndirectedEdge[113, 254] -> 
             RGBColor[
              0.9906836052631578, 0.9890274736842106, 0.703169394736842], 
             UndirectedEdge[6, 205] -> 
             RGBColor[
              0.9862522368421052, 0.9748015789473685, 0.6245478157894737], 
             UndirectedEdge[120, 287] -> 
             RGBColor[
              0.8043281578947369, 0.8479566315789474, 0.9785960263157893], 
             UndirectedEdge[31, 67] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[141, 232] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             UndirectedEdge[71, 122] -> 
             RGBColor[
              0.6707447894736842, 0.7334352631578949, 0.8404221842105262], 
             UndirectedEdge[78, 120] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[177, 247] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[168, 182] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[26, 228] -> 
             RGBColor[
              0.8043281578947369, 0.8479566315789474, 0.9785960263157893], 
             UndirectedEdge[7, 194] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[206, 244] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[31, 109] -> 
             RGBColor[
              0.9906836052631578, 0.9890274736842106, 0.703169394736842], 
             UndirectedEdge[57, 235] -> 
             RGBColor[
              0.5833105526315789, 0.647286605263158, 0.8935525263157895], 
             UndirectedEdge[24, 135] -> 
             RGBColor[
              0.7264971578947369, 0.7862643684210526, 0.9733741052631579], 
             UndirectedEdge[130, 220] -> 
             RGBColor[
              0.8886437894736843, 0.9110797894736842, 0.8582454999999998], 
             UndirectedEdge[84, 112] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[76, 104] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[21, 87] -> 
             RGBColor[0.6116091578947369, 0.6951412631578948, 0.962861], 
             UndirectedEdge[43, 183] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[11, 131] -> 
             RGBColor[
              0.6391238684210527, 0.6203748421052633, 0.6035123421052632], 
             UndirectedEdge[21, 187] -> 
             RGBColor[
              0.8043281578947369, 0.8479566315789474, 0.9785960263157893], 
             UndirectedEdge[36, 66] -> 
             RGBColor[
              0.6677012631578948, 0.7389608421052631, 0.9684517368421053], 
             UndirectedEdge[124, 125] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[232, 296] -> 
             RGBColor[
              0.6103445789473685, 0.691982894736842, 0.9640505789473683], 
             UndirectedEdge[75, 239] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[108, 114] -> 
             RGBColor[
              0.9664747894736843, 0.972772052631579, 0.8634674210526314], 
             UndirectedEdge[137, 266] -> 
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578], 
             UndirectedEdge[74, 262] -> 
             RGBColor[
              0.6702321842105263, 0.7318353157894737, 0.7480264736842104], 
             UndirectedEdge[48, 90] -> 
             RGBColor[
              0.3467912631578948, 0.4747948947368422, 0.9433182105263158], 
             UndirectedEdge[125, 150] -> 
             RGBColor[
              0.9768443947368421, 0.968367052631579, 0.6665282368421052], 
             UndirectedEdge[38, 55] -> 
             RGBColor[
              0.6687517631578948, 0.5949895263157896, 0.5934542894736843], 
             UndirectedEdge[110, 165] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[114, 145] -> 
             RGBColor[
              0.5995846052631579, 0.6725200789473684, 0.9637894736842105], 
             UndirectedEdge[222, 290] -> 
             RGBColor[
              0.8721608684210527, 0.8563303684210526, 0.6424015789473683], 
             UndirectedEdge[267, 286] -> 
             RGBColor[0.7158865, 0.7713787894736842, 0.7509355263157893], 
             UndirectedEdge[6, 187] -> 
             RGBColor[
              0.9615308157894737, 0.9569462105263158, 0.6924501315789473], 
             UndirectedEdge[221, 231] -> 
             RGBColor[
              0.8886437894736843, 0.9110797894736842, 0.8582454999999998], 
             UndirectedEdge[106, 286] -> 
             RGBColor[
              0.7128969999999999, 0.7715305263157894, 0.9013701842105264], 
             UndirectedEdge[67, 154] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[85, 296] -> 
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578], 
             UndirectedEdge[41, 201] -> 
             RGBColor[
              0.9664747894736843, 0.972772052631579, 0.8634674210526314], 
             UndirectedEdge[42, 235] -> 
             RGBColor[
              0.5739027105263158, 0.6408520789473684, 0.9355329473684211], 
             UndirectedEdge[44, 60] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[199, 228] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[39, 62] -> 
             RGBColor[
              0.9625647894736842, 0.8774152631578948, 0.40822060526315773`], 
             UndirectedEdge[48, 144] -> 
             RGBColor[
              0.6702321842105263, 0.7318353157894737, 0.7480264736842104], 
             UndirectedEdge[68, 215] -> 
             RGBColor[
              0.9348538684210527, 0.8597116315789474, 0.6265575789473683], 
             UndirectedEdge[127, 240] -> 
             RGBColor[
              0.7107596842105264, 0.7729922105263158, 0.9726388947368421], 
             UndirectedEdge[4, 26] -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 
             UndirectedEdge[8, 47] -> 
             RGBColor[
              0.9317022105263157, 0.9451111578947369, 0.8624326578947367], 
             UndirectedEdge[112, 175] -> 
             RGBColor[
              0.9812757631578948, 0.9825929473684211, 0.7451498157894735], 
             UndirectedEdge[162, 203] -> 
             RGBColor[
              0.9768443947368421, 0.968367052631579, 0.6665282368421052], 
             UndirectedEdge[6, 50] -> 
             RGBColor[0.942107, 0.7982605789473685, 0.31663192105263155`], 
             UndirectedEdge[15, 294] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[6, 219] -> 
             RGBColor[
              0.9615308157894737, 0.9569462105263158, 0.6924501315789473], 
             UndirectedEdge[110, 281] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[167, 297] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[122, 246] -> 
             RGBColor[
              0.6672426842105263, 0.731987052631579, 0.8984611315789475], 
             UndirectedEdge[210, 277] -> 
             RGBColor[
              0.7163991052631579, 0.7729787368421053, 0.8433312368421051], 
             UndirectedEdge[225, 234] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[84, 280] -> 
             RGBColor[
              0.8851416842105263, 0.9096315789473685, 0.9162844473684211], 
             UndirectedEdge[67, 95] -> 
             RGBColor[
              0.6077486842105264, 0.6864707894736843, 0.9653286842105263], 
             UndirectedEdge[81, 285] -> 
             RGBColor[
              0.6847781842105263, 0.6599183157894737, 0.6064213947368421], 
             UndirectedEdge[79, 164] -> 
             RGBColor[
              0.6578348421052632, 0.7255525263157896, 0.9404415526315789], 
             UndirectedEdge[123, 157] -> 
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725], 
             UndirectedEdge[85, 165] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[59, 62] -> 
             RGBColor[
              0.5961872105263157, 0.5787632368421053, 0.6009383684210526], 
             UndirectedEdge[38, 48] -> 
             RGBColor[
              0.6230974473684211, 0.5554460526315791, 0.5905452368421054], 
             UndirectedEdge[262, 291] -> 
             RGBColor[
              0.9941857105263158, 0.9904756842105263, 0.6451304473684207], 
             UndirectedEdge[26, 170] -> 
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158], 
             UndirectedEdge[43, 139] -> 
             RGBColor[
              0.6578348421052632, 0.7255525263157896, 0.9404415526315789], 
             UndirectedEdge[52, 281] -> 
             RGBColor[
              0.7737557894736842, 0.8199566842105264, 0.8477323947368419], 
             UndirectedEdge[124, 142] -> 
             RGBColor[
              0.9317022105263157, 0.9451111578947369, 0.8624326578947367], 
             UndirectedEdge[166, 271] -> 
             RGBColor[
              0.8043281578947369, 0.8479566315789474, 0.9785960263157893], 
             UndirectedEdge[37, 150] -> 
             RGBColor[
              0.8836998157894738, 0.8952539473684211, 0.6872282105263157], 
             UndirectedEdge[51, 66] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[60, 125] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[215, 223] -> 
             RGBColor[
              0.9501674473684211, 0.8711324736842105, 0.6006356842105263], 
             UndirectedEdge[237, 282] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[143, 172] -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 
             UndirectedEdge[177, 285] -> 
             RGBColor[
              0.9000812894736843, 0.8320507368421053, 0.6255228157894737], 
             UndirectedEdge[244, 270] -> 
             RGBColor[
              0.5585891315789474, 0.6294312368421052, 0.9614548421052631], 
             UndirectedEdge[147, 272] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[46, 114] -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             UndirectedEdge[104, 128] -> 
             RGBColor[
              0.7608458421052632, 0.8120739473684211, 0.9477517631578947], 
             UndirectedEdge[199, 220] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[112, 146] -> 
             RGBColor[
              0.7608458421052632, 0.8120739473684211, 0.9477517631578947], 
             UndirectedEdge[191, 203] -> 
             RGBColor[
              0.8276077105263158, 0.8514343684210527, 0.6816374736842105], 
             UndirectedEdge[31, 96] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[59, 228] -> 
             RGBColor[
              0.5995846052631579, 0.6725200789473684, 0.9637894736842105], 
             UndirectedEdge[129, 289] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[54, 106] -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 
             UndirectedEdge[102, 142] -> 
             RGBColor[
              0.9911962105263157, 0.9906274210526316, 0.7955651052631578], 
             UndirectedEdge[74, 90] -> 
             RGBColor[
              0.3467912631578948, 0.4747948947368422, 0.9433182105263158], 
             UndirectedEdge[143, 174] -> 
             RGBColor[
              0.7264971578947369, 0.7862643684210526, 0.9733741052631579], 
             UndirectedEdge[144, 292] -> 
             RGBColor[
              0.8320390789473684, 0.8656602631578948, 0.7602590526315788], 
             UndirectedEdge[59, 255] -> 
             RGBColor[
              0.6243060263157894, 0.6903754473684212, 0.8958871578947369], 
             UndirectedEdge[254, 258] -> 
             RGBColor[
              0.6702321842105263, 0.7318353157894737, 0.7480264736842104], 
             UndirectedEdge[46, 108] -> 
             RGBColor[
              0.9664747894736843, 0.972772052631579, 0.8634674210526314], 
             UndirectedEdge[222, 278] -> 
             RGBColor[0.9747132894736842, 0.935878, 0.5797211842105263], 
             UndirectedEdge[115, 294] -> 
             RGBColor[
              0.9034786842105264, 0.9258075789473684, 0.9883739210526314], 
             UndirectedEdge[89, 177] -> 
             RGBColor[
              0.9311896052631579, 0.9435112105263158, 0.7700369473684209], 
             UndirectedEdge[45, 195] -> 
             RGBColor[
              0.9470509736842105, 0.8140864210526317, 0.48764921052631566`], 
             UndirectedEdge[205, 231] -> 
             RGBColor[
              0.8851416842105263, 0.9096315789473685, 0.9162844473684211], 
             UndirectedEdge[148, 244] -> 
             RGBColor[
              0.9499918684210527, 0.9180226315789473, 0.6476234999999999], 
             UndirectedEdge[20, 297] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[6, 34] -> 
             RGBColor[
              0.9768443947368421, 0.968367052631579, 0.6665282368421052], 
             UndirectedEdge[13, 245] -> 
             RGBColor[
              0.8881311842105264, 0.9094798421052632, 0.765849789473684], 
             UndirectedEdge[104, 201] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[55, 253] -> 
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725], 
             UndirectedEdge[52, 141] -> 
             RGBColor[
              0.7608458421052632, 0.8120739473684211, 0.9477517631578947], 
             UndirectedEdge[160, 299] -> 
             RGBColor[
              0.9317022105263157, 0.9451111578947369, 0.8624326578947367], 
             UndirectedEdge[229, 284] -> 
             RGBColor[
              0.9501674473684211, 0.8711324736842105, 0.6006356842105263], 
             UndirectedEdge[27, 268] -> 
             RGBColor[
              0.8325516842105263, 0.8672602105263159, 0.8526547631578946], 
             UndirectedEdge[193, 236] -> 
             RGBColor[
              0.5542524736842105, 0.6481633157894737, 0.9584598421052631], 
             UndirectedEdge[78, 193] -> 
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578], 
             UndirectedEdge[175, 177] -> 
             RGBColor[
              0.9311896052631579, 0.9435112105263158, 0.7700369473684209], 
             UndirectedEdge[36, 67] -> 
             RGBColor[
              0.7107596842105264, 0.7729922105263158, 0.9726388947368421], 
             UndirectedEdge[37, 239] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[49, 280] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[263, 276] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[13, 73] -> 
             RGBColor[
              0.9892417368421053, 0.9746498421052632, 0.4741131578947366], 
             UndirectedEdge[136, 240] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[79, 241] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[78, 226] -> 
             RGBColor[
              0.8930987105263157, 0.5552185789473685, 0.550891447368421], 
             UndirectedEdge[3, 74] -> 
             RGBColor[
              0.508598157894737, 0.6086198421052633, 0.9555507894736842], 
             UndirectedEdge[148, 203] -> 
             RGBColor[
              0.9732714210526316, 0.9215003684210525, 0.3506649473684209], 
             UndirectedEdge[90, 257] -> 
             RGBColor[
              0.6425212631578947, 0.7141316842105263, 0.9663634473684211], 
             UndirectedEdge[34, 87] -> 
             RGBColor[
              0.7608458421052632, 0.8120739473684211, 0.9477517631578947], 
             UndirectedEdge[146, 235] -> 
             RGBColor[
              0.36587013157894743`, 0.47661586842105264`, 0.9457198157894737],
              UndirectedEdge[181, 256] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[68, 287] -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             UndirectedEdge[17, 144] -> 
             RGBColor[0.7158865, 0.7713787894736842, 0.7509355263157893], 
             UndirectedEdge[163, 216] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[67, 258] -> 
             RGBColor[
              0.6077486842105264, 0.6864707894736843, 0.9653286842105263], 
             UndirectedEdge[232, 240] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[133, 210] -> 
             RGBColor[
              0.7737557894736842, 0.8199566842105264, 0.8477323947368419], 
             UndirectedEdge[58, 154] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[94, 124] -> 
             RGBColor[
              0.6077486842105264, 0.6864707894736843, 0.9653286842105263], 
             UndirectedEdge[50, 213] -> 
             RGBColor[
              0.9435488684210527, 0.8126382105263159, 0.5456881578947369], 
             UndirectedEdge[15, 212] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[11, 139] -> 
             RGBColor[
              0.3467912631578948, 0.4747948947368422, 0.9433182105263158], 
             UndirectedEdge[167, 286] -> 
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578], 
             UndirectedEdge[113, 288] -> 
             RGBColor[
              0.5833105526315789, 0.647286605263158, 0.8935525263157895], 
             UndirectedEdge[73, 171] -> 
             RGBColor[
              0.9581334210526316, 0.8631893684210526, 0.3295990263157894], 
             UndirectedEdge[31, 110] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[202, 275] -> 
             RGBColor[
              0.8325516842105263, 0.8672602105263159, 0.8526547631578946], 
             UndirectedEdge[103, 241] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[9, 20] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[71, 207] -> 
             RGBColor[
              0.7163991052631579, 0.7729787368421053, 0.8433312368421051], 
             UndirectedEdge[160, 168] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[6, 114] -> 
             RGBColor[
              0.9615308157894737, 0.9569462105263158, 0.6924501315789473], 
             UndirectedEdge[95, 96] -> 
             RGBColor[
              0.6425212631578947, 0.7141316842105263, 0.9663634473684211], 
             UndirectedEdge[198, 278] -> 
             RGBColor[
              0.6672426842105263, 0.731987052631579, 0.8984611315789475], 
             UndirectedEdge[86, 281] -> 
             RGBColor[
              0.9911962105263157, 0.9906274210526316, 0.7955651052631578], 
             UndirectedEdge[107, 165] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[155, 184] -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             UndirectedEdge[247, 285] -> 
             RGBColor[
              0.8009307631578948, 0.7541997894736843, 0.6157449210526316], 
             UndirectedEdge[34, 227] -> 
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578], 
             UndirectedEdge[116, 152] -> 
             RGBColor[
              0.7455322631578948, 0.8006531052631579, 0.9736736578947367], 
             UndirectedEdge[146, 204] -> 
             RGBColor[
              0.7107596842105264, 0.7729922105263158, 0.9726388947368421], 
             UndirectedEdge[36, 58] -> 
             RGBColor[
              0.7107596842105264, 0.7729922105263158, 0.9726388947368421], 
             UndirectedEdge[105, 129] -> 
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578], 
             UndirectedEdge[87, 187] -> 
             RGBColor[
              0.7455322631578948, 0.8006531052631579, 0.9736736578947367], 
             UndirectedEdge[119, 168] -> 
             RGBColor[
              0.6077486842105264, 0.6864707894736843, 0.9653286842105263], 
             UndirectedEdge[20, 37] -> 
             RGBColor[
              0.7264971578947369, 0.7862643684210526, 0.9733741052631579], 
             UndirectedEdge[150, 200] -> 
             RGBColor[
              0.8276077105263158, 0.8514343684210527, 0.6816374736842105], 
             UndirectedEdge[1, 43] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[187, 213] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[41, 222] -> 
             RGBColor[
              0.9499918684210527, 0.9180226315789473, 0.6476234999999999], 
             UndirectedEdge[196, 263] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[148, 172] -> 
             RGBColor[
              0.8160687631578948, 0.8125107894736843, 0.6368108421052631], 
             UndirectedEdge[96, 171] -> 
             RGBColor[
              0.9348538684210527, 0.8597116315789474, 0.6265575789473683], 
             UndirectedEdge[178, 208] -> 
             RGBColor[
              0.9317022105263157, 0.9451111578947369, 0.8624326578947367], 
             UndirectedEdge[25, 270] -> 
             RGBColor[
              0.5551917368421053, 0.5356743947368421, 0.5986037368421053], 
             UndirectedEdge[47, 217] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[33, 142] -> 
             RGBColor[
              0.6707447894736842, 0.7334352631578949, 0.8404221842105262], 
             UndirectedEdge[26, 62] -> 
             RGBColor[
              0.8009307631578948, 0.7541997894736843, 0.6157449210526316], 
             UndirectedEdge[48, 177] -> 
             RGBColor[
              0.6077486842105264, 0.6864707894736843, 0.9653286842105263], 
             UndirectedEdge[238, 300] -> 
             RGBColor[
              0.5739027105263158, 0.6408520789473684, 0.9355329473684211], 
             UndirectedEdge[25, 139] -> 
             RGBColor[
              0.6391238684210527, 0.6203748421052633, 0.6035123421052632], 
             UndirectedEdge[3, 30] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[95, 171] -> 
             RGBColor[
              0.6391238684210527, 0.6203748421052633, 0.6035123421052632], 
             UndirectedEdge[21, 50] -> 
             RGBColor[
              0.7849043421052633, 0.6892710000000002, 0.6027778157894736], 
             UndirectedEdge[122, 232] -> 
             RGBColor[
              0.5646902631578948, 0.6524394210526316, 0.9611415263157894], 
             UndirectedEdge[127, 136] -> 
             RGBColor[
              0.7608458421052632, 0.8120739473684211, 0.9477517631578947], 
             UndirectedEdge[41, 290] -> 
             RGBColor[
              0.8604202631578948, 0.8917762105263158, 0.9841867631578947], 
             UndirectedEdge[123, 259] -> 
             RGBColor[
              0.8604202631578948, 0.8917762105263158, 0.9841867631578947], 
             UndirectedEdge[20, 185] -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 
             UndirectedEdge[163, 211] -> 
             RGBColor[
              0.8886437894736843, 0.9110797894736842, 0.8582454999999998], 
             UndirectedEdge[33, 37] -> 
             RGBColor[
              0.5646902631578948, 0.6524394210526316, 0.9611415263157894], 
             UndirectedEdge[7, 9] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[105, 263] -> 
             RGBColor[
              0.5542524736842105, 0.6481633157894737, 0.9584598421052631], 
             UndirectedEdge[15, 49] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[20, 237] -> 
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158], 
             UndirectedEdge[26, 220] -> 
             RGBColor[
              0.8325516842105263, 0.8672602105263159, 0.8526547631578946], 
             UndirectedEdge[101, 187] -> 
             RGBColor[
              0.8604202631578948, 0.8917762105263158, 0.9841867631578947], 
             UndirectedEdge[93, 94] -> 
             RGBColor[
              0.6707447894736842, 0.7334352631578949, 0.8404221842105262], 
             UndirectedEdge[143, 297] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[208, 268] -> 
             RGBColor[
              0.9317022105263157, 0.9451111578947369, 0.8624326578947367], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.6702321842105263, 0.7318353157894737, 0.7480264736842104], 
             UndirectedEdge[224, 288] -> 
             RGBColor[
              0.5585891315789474, 0.6294312368421052, 0.9614548421052631], 
             UndirectedEdge[1, 75] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[36, 113] -> 
             RGBColor[
              0.7702536842105263, 0.8185084736842105, 0.9057713421052631], 
             UndirectedEdge[29, 244] -> 
             RGBColor[
              0.9664747894736843, 0.972772052631579, 0.8634674210526314], 
             UndirectedEdge[36, 96] -> 
             RGBColor[
              0.7455322631578948, 0.8006531052631579, 0.9736736578947367], 
             UndirectedEdge[58, 138] -> 
             RGBColor[
              0.9034786842105264, 0.9258075789473684, 0.9883739210526314], 
             UndirectedEdge[71, 136] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[144, 252] -> 
             RGBColor[
              0.9777027894736843, 0.9357262631578946, 0.42928652631578923`], 
             UndirectedEdge[58, 198] -> 
             RGBColor[
              0.6077486842105264, 0.6864707894736843, 0.9653286842105263], 
             UndirectedEdge[110, 154] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[119, 152] -> 
             RGBColor[
              0.44980226315789484`, 0.5613163157894738, 0.9506284210526316], 
             UndirectedEdge[38, 90] -> 
             RGBColor[
              0.6230974473684211, 0.5554460526315791, 0.5905452368421054], 
             UndirectedEdge[66, 179] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[6, 21] -> 
             RGBColor[
              0.8276077105263158, 0.8514343684210527, 0.6816374736842105], 
             UndirectedEdge[176, 287] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[142, 237] -> 
             RGBColor[
              0.9911962105263157, 0.9906274210526316, 0.7955651052631578], 
             UndirectedEdge[108, 221] -> 
             RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947365], 
             UndirectedEdge[44, 256] -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 
             UndirectedEdge[89, 112] -> 
             RGBColor[
              0.9812757631578948, 0.9825929473684211, 0.7451498157894735], 
             UndirectedEdge[83, 184] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[259, 261] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[207, 231] -> 
             RGBColor[
              0.6103445789473685, 0.691982894736842, 0.9640505789473683], 
             UndirectedEdge[112, 280] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[174, 194] -> 
             RGBColor[
              0.7264971578947369, 0.7862643684210526, 0.9733741052631579], 
             UndirectedEdge[125, 200] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[99, 222] -> 
             RGBColor[
              0.6999161842105264, 0.7182293157894737, 0.6274873157894736], 
             UndirectedEdge[108, 169] -> 
             RGBColor[
              0.9664747894736843, 0.972772052631579, 0.8634674210526314], 
             UndirectedEdge[15, 57] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[4, 78] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[52, 86] -> 
             RGBColor[
              0.7702536842105263, 0.8185084736842105, 0.9057713421052631], 
             UndirectedEdge[20, 282] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[42, 55] -> 
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578], 
             UndirectedEdge[136, 165] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[161, 269] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[57, 243] -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 
             UndirectedEdge[57, 146] -> 
             RGBColor[
              0.7702536842105263, 0.8185084736842105, 0.9057713421052631], 
             UndirectedEdge[4, 130] -> 
             RGBColor[
              0.7264971578947369, 0.7862643684210526, 0.9733741052631579], 
             UndirectedEdge[31, 58] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[95, 140] -> 
             RGBColor[
              0.3924455789473684, 0.5143383684210527, 0.9462272631578947], 
             UndirectedEdge[58, 96] -> 
             RGBColor[
              0.9034786842105264, 0.9258075789473684, 0.9883739210526314], 
             UndirectedEdge[16, 94] -> 
             RGBColor[
              0.6702321842105263, 0.7318353157894737, 0.7480264736842104], 
             UndirectedEdge[113, 135] -> 
             RGBColor[
              0.8851416842105263, 0.9096315789473685, 0.9162844473684211], 
             UndirectedEdge[47, 262] -> 
             RGBColor[
              0.9311896052631579, 0.9435112105263158, 0.7700369473684209], 
             UndirectedEdge[153, 211] -> 
             RGBColor[
              0.7163991052631579, 0.7729787368421053, 0.8433312368421051], 
             UndirectedEdge[89, 111] -> 
             RGBColor[
              0.7732431842105263, 0.8183567368421053, 0.7553366842105261], 
             UndirectedEdge[137, 256] -> 
             RGBColor[
              0.5542524736842105, 0.6481633157894737, 0.9584598421052631], 
             UndirectedEdge[136, 181] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[288, 291] -> 
             RGBColor[
              0.5868126578947368, 0.6487348157894737, 0.8355135789473682], 
             UndirectedEdge[121, 296] -> 
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052], 
             UndirectedEdge[241, 277] -> 
             RGBColor[
              0.6103445789473685, 0.691982894736842, 0.9640505789473683], 
             UndirectedEdge[217, 262] -> 
             RGBColor[
              0.8881311842105264, 0.9094798421052632, 0.765849789473684], 
             UndirectedEdge[75, 142] -> 
             RGBColor[
              0.9317022105263157, 0.9451111578947369, 0.8624326578947367], 
             UndirectedEdge[57, 112] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[274, 287] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[97, 252] -> 
             RGBColor[
              0.965305447368421, 0.9294434736842105, 0.6217016052631578], 
             UndirectedEdge[18, 69] -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             UndirectedEdge[106, 167] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[256, 296] -> 
             RGBColor[
              0.5542524736842105, 0.6481633157894737, 0.9584598421052631], 
             UndirectedEdge[131, 183] -> 
             RGBColor[
              0.8570228684210527, 0.7980193684210526, 0.6213356578947369], 
             UndirectedEdge[172, 183] -> 
             RGBColor[
              0.7264971578947369, 0.7862643684210526, 0.9733741052631579], 
             UndirectedEdge[1, 143] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[17, 252] -> 
             RGBColor[
              0.6999161842105264, 0.7182293157894737, 0.6274873157894736], 
             UndirectedEdge[126, 214] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[84, 134] -> 
             RGBColor[
              0.9906836052631578, 0.9890274736842106, 0.703169394736842], 
             UndirectedEdge[45, 234] -> 
             RGBColor[
              0.918827447368421, 0.7947828421052632, 0.6135904736842105], 
             UndirectedEdge[32, 156] -> 
             RGBColor[
              0.965305447368421, 0.9294434736842105, 0.6217016052631578], 
             UndirectedEdge[140, 149] -> 
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052], 
             UndirectedEdge[16, 150] -> 
             RGBColor[
              0.9892417368421053, 0.9746498421052632, 0.4741131578947366], 
             UndirectedEdge[209, 218] -> 
             RGBColor[
              0.8930987105263157, 0.5552185789473685, 0.550891447368421], 
             UndirectedEdge[82, 281] -> 
             RGBColor[
              0.9897543421052631, 0.9762497894736842, 0.5665088684210524], 
             UndirectedEdge[178, 182] -> 
             RGBColor[
              0.9911962105263157, 0.9906274210526316, 0.7955651052631578], 
             UndirectedEdge[41, 157] -> 
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725], 
             UndirectedEdge[254, 288] -> 
             RGBColor[
              0.5863000526315789, 0.6471348684210526, 0.7431178684210524], 
             UndirectedEdge[129, 161] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[20, 283] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[162, 210] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[203, 244] -> 
             RGBColor[
              0.9615308157894737, 0.9569462105263158, 0.6924501315789473], 
             UndirectedEdge[121, 246] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[24, 259] -> 
             RGBColor[
              0.7264971578947369, 0.7862643684210526, 0.9733741052631579], 
             UndirectedEdge[141, 281] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[110, 138] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[67, 109] -> 
             RGBColor[
              0.9311896052631579, 0.9435112105263158, 0.7700369473684209], 
             UndirectedEdge[154, 245] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[193, 249] -> 
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052], 
             UndirectedEdge[82, 137] -> 
             RGBColor[
              0.7114551315789474, 0.7571528947368421, 0.672313947368421], 
             UndirectedEdge[100, 125] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[104, 218] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[73, 149] -> 
             RGBColor[
              0.9267582368421052, 0.9292853157894737, 0.6914153684210526], 
             UndirectedEdge[108, 219] -> 
             RGBColor[
              0.9664747894736843, 0.972772052631579, 0.8634674210526314], 
             UndirectedEdge[58, 140] -> 
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052], 
             UndirectedEdge[9, 63] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[48, 217] -> 
             RGBColor[
              0.5646902631578948, 0.6524394210526316, 0.9611415263157894], 
             UndirectedEdge[8, 271] -> 
             RGBColor[
              0.9664747894736843, 0.972772052631579, 0.8634674210526314], 
             UndirectedEdge[18, 222] -> 
             RGBColor[
              0.9499918684210527, 0.9180226315789473, 0.6476234999999999], 
             UndirectedEdge[215, 234] -> 
             RGBColor[
              0.9348538684210527, 0.8597116315789474, 0.6265575789473683], 
             UndirectedEdge[15, 146] -> 
             RGBColor[
              0.7107596842105264, 0.7729922105263158, 0.9726388947368421], 
             UndirectedEdge[54, 151] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[195, 255] -> 
             RGBColor[
              0.9911962105263157, 0.9906274210526316, 0.7955651052631578], 
             UndirectedEdge[1, 11] -> 
             RGBColor[
              0.6077486842105264, 0.6864707894736843, 0.9653286842105263], 
             UndirectedEdge[32, 178] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[126, 189] -> 
             RGBColor[
              0.7163991052631579, 0.7729787368421053, 0.8433312368421051], 
             UndirectedEdge[61, 273] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[54, 194] -> 
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158], 
             UndirectedEdge[38, 144] -> 
             RGBColor[
              0.9465383684210527, 0.8124864736842106, 0.39525349999999987`], 
             UndirectedEdge[4, 220] -> 
             RGBColor[
              0.8325516842105263, 0.8672602105263159, 0.8526547631578946], 
             UndirectedEdge[45, 200] -> 
             RGBColor[
              0.7849043421052633, 0.6892710000000002, 0.6027778157894736], 
             UndirectedEdge[2, 202] -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 
             UndirectedEdge[17, 175] -> 
             RGBColor[0.7158865, 0.7713787894736842, 0.7509355263157893], 
             UndirectedEdge[233, 262] -> 
             RGBColor[
              0.9906836052631578, 0.9890274736842106, 0.703169394736842], 
             UndirectedEdge[67, 138] -> 
             RGBColor[
              0.9034786842105264, 0.9258075789473684, 0.9883739210526314], 
             UndirectedEdge[39, 192] -> 
             RGBColor[
              0.9906836052631578, 0.9890274736842106, 0.703169394736842], 
             UndirectedEdge[164, 168] -> 
             RGBColor[
              0.6077486842105264, 0.6864707894736843, 0.9653286842105263], 
             UndirectedEdge[19, 253] -> 
             RGBColor[
              0.9034786842105264, 0.9258075789473684, 0.9883739210526314], 
             UndirectedEdge[24, 74] -> 
             RGBColor[
              0.508598157894737, 0.6086198421052633, 0.9555507894736842], 
             UndirectedEdge[80, 133] -> 
             RGBColor[
              0.7608458421052632, 0.8120739473684211, 0.9477517631578947], 
             UndirectedEdge[198, 222] -> 
             RGBColor[
              0.6542618684210526, 0.6786858421052632, 0.6245782631578947], 
             UndirectedEdge[111, 212] -> 
             RGBColor[
              0.7107596842105264, 0.7729922105263158, 0.9726388947368421], 
             UndirectedEdge[126, 184] -> 
             RGBColor[
              0.9664747894736843, 0.972772052631579, 0.8634674210526314], 
             UndirectedEdge[132, 294] -> 
             RGBColor[
              0.9267582368421052, 0.9292853157894737, 0.6914153684210526], 
             UndirectedEdge[39, 136] -> 
             RGBColor[
              0.9812757631578948, 0.9825929473684211, 0.7451498157894735], 
             UndirectedEdge[133, 162] -> 
             RGBColor[
              0.7608458421052632, 0.8120739473684211, 0.9477517631578947], 
             UndirectedEdge[22, 271] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[107, 110] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[40, 191] -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 
             UndirectedEdge[143, 237] -> 
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158], 
             UndirectedEdge[157, 261] -> 
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052], 
             UndirectedEdge[35, 163] -> 
             RGBColor[
              0.8851416842105263, 0.9096315789473685, 0.9162844473684211], 
             UndirectedEdge[89, 175] -> 
             RGBColor[
              0.9936731052631579, 0.9888757368421053, 0.552734736842105], 
             UndirectedEdge[16, 200] -> 
             RGBColor[
              0.8320390789473684, 0.8656602631578948, 0.7602590526315788], 
             UndirectedEdge[35, 189] -> 
             RGBColor[
              0.7128969999999999, 0.7715305263157894, 0.9013701842105264], 
             UndirectedEdge[233, 291] -> 
             RGBColor[
              0.9911962105263157, 0.9906274210526316, 0.7955651052631578], 
             UndirectedEdge[258, 290] -> 
             RGBColor[
              0.5646902631578948, 0.6524394210526316, 0.9611415263157894], 
             UndirectedEdge[157, 259] -> 
             RGBColor[
              0.6103445789473685, 0.691982894736842, 0.9640505789473683], 
             UndirectedEdge[105, 245] -> 
             RGBColor[
              0.6103445789473685, 0.691982894736842, 0.9640505789473683], 
             UndirectedEdge[100, 192] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[258, 278] -> 
             RGBColor[
              0.6672426842105263, 0.731987052631579, 0.8984611315789475], 
             UndirectedEdge[99, 201] -> 
             RGBColor[
              0.7163991052631579, 0.7729787368421053, 0.8433312368421051], 
             UndirectedEdge[9, 282] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[84, 175] -> 
             RGBColor[
              0.9906836052631578, 0.9890274736842106, 0.703169394736842], 
             UndirectedEdge[271, 291] -> 
             RGBColor[
              0.9664747894736843, 0.972772052631579, 0.8634674210526314], 
             UndirectedEdge[127, 256] -> 
             RGBColor[0.6116091578947369, 0.6951412631578948, 0.962861], 
             UndirectedEdge[80, 116] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[202, 268] -> 
             RGBColor[
              0.8325516842105263, 0.8672602105263159, 0.8526547631578946], 
             UndirectedEdge[161, 265] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[22, 72] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[77, 162] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[93, 164] -> 
             RGBColor[
              0.6707447894736842, 0.7334352631578949, 0.8404221842105262], 
             UndirectedEdge[19, 111] -> 
             RGBColor[
              0.7107596842105264, 0.7729922105263158, 0.9726388947368421], 
             UndirectedEdge[37, 142] -> 
             RGBColor[
              0.8886437894736843, 0.9110797894736842, 0.8582454999999998], 
             UndirectedEdge[43, 172] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[61, 285] -> 
             RGBColor[
              0.9501674473684211, 0.8711324736842105, 0.6006356842105263], 
             UndirectedEdge[38, 257] -> 
             RGBColor[
              0.918827447368421, 0.7947828421052632, 0.6135904736842105], 
             UndirectedEdge[174, 185] -> 
             RGBColor[
              0.7264971578947369, 0.7862643684210526, 0.9733741052631579], 
             UndirectedEdge[75, 237] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[30, 48] -> 
             RGBColor[
              0.6077486842105264, 0.6864707894736843, 0.9653286842105263], 
             UndirectedEdge[289, 298] -> 
             RGBColor[
              0.6425212631578948, 0.7141316842105263, 0.9663634473684211], 
             UndirectedEdge[123, 261] -> 
             RGBColor[
              0.9034786842105264, 0.9258075789473684, 0.9883739210526314], 
             UndirectedEdge[77, 206] -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 
             UndirectedEdge[121, 137] -> 
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052], 
             UndirectedEdge[87, 227] -> 
             RGBColor[
              0.49545657894736844`, 0.6008597894736842, 0.9535374736842105], 
             UndirectedEdge[123, 144] -> 
             RGBColor[
              0.9659621842105264, 0.9711721052631579, 0.7710717105263156], 
             UndirectedEdge[9, 37] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[178, 268] -> 
             RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947365], 
             UndirectedEdge[112, 253] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[78, 220] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[66, 67] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[20, 124] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[18, 224] -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             UndirectedEdge[72, 151] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[25, 29] -> 
             RGBColor[
              0.9630773947368421, 0.8790152105263158, 0.5006163157894735], 
             UndirectedEdge[135, 258] -> 
             RGBColor[
              0.5646902631578948, 0.6524394210526316, 0.9611415263157894], 
             UndirectedEdge[130, 176] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[31, 245] -> 
             RGBColor[
              0.8851416842105263, 0.9096315789473685, 0.9162844473684211], 
             UndirectedEdge[295, 297] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[17, 30] -> 
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052], 
             UndirectedEdge[22, 273] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[86, 165] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[124, 200] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[198, 258] -> 
             RGBColor[
              0.3467912631578948, 0.4747948947368422, 0.9433182105263158], 
             UndirectedEdge[177, 217] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[52, 110] -> 
             RGBColor[
              0.7608458421052632, 0.8120739473684211, 0.9477517631578947], 
             UndirectedEdge[121, 299] -> 
             RGBColor[
              0.9317022105263157, 0.9451111578947369, 0.8624326578947367], 
             UndirectedEdge[173, 196] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[238, 251] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[218, 284] -> 
             RGBColor[
              0.9501674473684211, 0.8711324736842105, 0.6006356842105263], 
             UndirectedEdge[209, 276] -> 
             RGBColor[
              0.8930987105263157, 0.5552185789473685, 0.550891447368421], 
             UndirectedEdge[8, 72] -> 
             RGBColor[
              0.9317022105263157, 0.9451111578947369, 0.8624326578947367], 
             UndirectedEdge[56, 168] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[201, 257] -> 
             RGBColor[
              0.9664747894736843, 0.972772052631579, 0.8634674210526314], 
             UndirectedEdge[31, 51] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[53, 282] -> 
             RGBColor[
              0.9267582368421052, 0.9292853157894737, 0.6914153684210526], 
             UndirectedEdge[17, 97] -> 
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578], 
             UndirectedEdge[102, 162] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[36, 260] -> 
             RGBColor[
              0.6677012631578948, 0.7389608421052631, 0.9684517368421053], 
             UndirectedEdge[79, 168] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[142, 297] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[232, 299] -> 
             RGBColor[
              0.8886437894736843, 0.9110797894736842, 0.8582454999999998], 
             UndirectedEdge[50, 169] -> 
             RGBColor[
              0.918827447368421, 0.7947828421052632, 0.6135904736842105], 
             UndirectedEdge[92, 153] -> 
             RGBColor[
              0.6687517631578948, 0.5949895263157896, 0.5934542894736843], 
             UndirectedEdge[44, 299] -> 
             RGBColor[
              0.8325516842105263, 0.8672602105263159, 0.8526547631578946], 
             UndirectedEdge[90, 252] -> 
             RGBColor[
              0.6542618684210526, 0.6786858421052632, 0.6245782631578947], 
             UndirectedEdge[7, 283] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[52, 179] -> 
             RGBColor[
              0.7107596842105264, 0.7729922105263158, 0.9726388947368421], 
             UndirectedEdge[98, 296] -> 
             RGBColor[
              0.6103445789473685, 0.691982894736842, 0.9640505789473683], 
             UndirectedEdge[18, 88] -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             UndirectedEdge[100, 240] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[2, 214] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[114, 169] -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             UndirectedEdge[37, 295] -> 
             RGBColor[
              0.7825892631578948, 0.8300839473684211, 0.9789648421052631], 
             UndirectedEdge[45, 225] -> 
             RGBColor[
              0.9341410263157894, 0.8062036842105265, 0.5876685789473683], 
             UndirectedEdge[38, 74] -> 
             RGBColor[
              0.6230974473684211, 0.5554460526315791, 0.5905452368421054], 
             UndirectedEdge[38, 158] -> 
             RGBColor[
              0.9341410263157894, 0.8062036842105265, 0.5876685789473683], 
             UndirectedEdge[69, 135] -> 
             RGBColor[
              0.8604202631578948, 0.8917762105263158, 0.9841867631578947], 
             UndirectedEdge[113, 224] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[124, 282] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[56, 79] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[49, 146] -> 
             RGBColor[
              0.7107596842105264, 0.7729922105263158, 0.9726388947368421], 
             UndirectedEdge[47, 166] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[189, 197] -> 
             RGBColor[
              0.49545657894736844`, 0.6008597894736842, 0.9535374736842105], 
             UndirectedEdge[125, 256] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[69, 138] -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             UndirectedEdge[170, 255] -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 
             UndirectedEdge[41, 104] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[185, 283] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[103, 277] -> 
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052], 
             UndirectedEdge[45, 282] -> 
             RGBColor[
              0.8840548684210527, 0.7671219473684212, 0.6125557105263157], 
             UndirectedEdge[222, 245] -> 
             RGBColor[
              0.8721608684210527, 0.8563303684210526, 0.6424015789473683], 
             UndirectedEdge[53, 195] -> 
             RGBColor[
              0.9897543421052631, 0.9762497894736842, 0.5665088684210524], 
             UndirectedEdge[121, 136] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[92, 211] -> 
             RGBColor[
              0.9470509736842105, 0.8140864210526317, 0.48764921052631566`], 
             UndirectedEdge[26, 137] -> 
             RGBColor[
              0.5542524736842105, 0.6481633157894737, 0.9584598421052631], 
             UndirectedEdge[139, 148] -> 
             RGBColor[
              0.6542618684210526, 0.6786858421052632, 0.6245782631578947], 
             UndirectedEdge[69, 258] -> 
             RGBColor[
              0.6425212631578948, 0.7141316842105263, 0.9663634473684211], 
             UndirectedEdge[244, 272] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[100, 256] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[29, 206] -> 
             RGBColor[
              0.9911962105263157, 0.9906274210526316, 0.7955651052631578], 
             UndirectedEdge[101, 213] -> 
             RGBColor[
              0.8851416842105263, 0.9096315789473685, 0.9162844473684211], 
             UndirectedEdge[39, 107] -> 
             RGBColor[
              0.8881311842105264, 0.9094798421052632, 0.765849789473684], 
             UndirectedEdge[134, 252] -> 
             RGBColor[
              0.9777027894736843, 0.9357262631578946, 0.42928652631578923`], 
             UndirectedEdge[14, 288] -> 
             RGBColor[
              0.523816552631579, 0.6017703421052631, 0.9604200789473685], 
             UndirectedEdge[155, 202] -> 
             RGBColor[
              0.8043281578947369, 0.8479566315789474, 0.9785960263157893], 
             UndirectedEdge[220, 228] -> 
             RGBColor[
              0.9664747894736843, 0.972772052631579, 0.8634674210526314], 
             UndirectedEdge[228, 266] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[113, 249] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[109, 179] -> 
             RGBColor[
              0.9311896052631579, 0.9435112105263158, 0.7700369473684209], 
             UndirectedEdge[41, 209] -> 
             RGBColor[
              0.8777851315789473, 0.5437977368421052, 0.576813342105263], 
             UndirectedEdge[76, 261] -> 
             RGBColor[
              0.9317022105263157, 0.9451111578947369, 0.8624326578947367], 
             UndirectedEdge[114, 219] -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             UndirectedEdge[130, 266] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[1, 185] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[202, 208] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[8, 285] -> 
             RGBColor[
              0.9630773947368421, 0.8790152105263158, 0.5006163157894735], 
             UndirectedEdge[65, 210] -> 
             RGBColor[
              0.8886437894736843, 0.9110797894736842, 0.8582454999999998], 
             UndirectedEdge[63, 183] -> 
             RGBColor[
              0.7264971578947369, 0.7862643684210526, 0.9733741052631579], 
             UndirectedEdge[51, 86] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[91, 191] -> 
             RGBColor[
              0.8325516842105263, 0.8672602105263159, 0.8526547631578946], 
             UndirectedEdge[122, 181] -> 
             RGBColor[
              0.6077486842105264, 0.6864707894736843, 0.9653286842105263], 
             UndirectedEdge[17, 42] -> 
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578], 
             UndirectedEdge[90, 253] -> 
             RGBColor[
              0.6425212631578947, 0.7141316842105263, 0.9663634473684211], 
             UndirectedEdge[60, 136] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[80, 210] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[229, 259] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[97, 159] -> 
             RGBColor[
              0.6148981842105263, 0.6839409210526316, 0.9378675789473684], 
             UndirectedEdge[242, 280] -> 
             RGBColor[
              0.6103445789473685, 0.691982894736842, 0.9640505789473683], 
             UndirectedEdge[88, 99] -> 
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725], 
             UndirectedEdge[21, 46] -> 
             RGBColor[
              0.8043281578947369, 0.8479566315789474, 0.9785960263157893], 
             UndirectedEdge[246, 256] -> 
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158], 
             UndirectedEdge[14, 135] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[67, 179] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[66, 69] -> 
             RGBColor[
              0.8604202631578948, 0.8917762105263158, 0.9841867631578947], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.6672426842105263, 0.731987052631579, 0.8984611315789475], 
             UndirectedEdge[116, 133] -> 
             RGBColor[
              0.7455322631578948, 0.8006531052631579, 0.9736736578947367], 
             UndirectedEdge[2, 83] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[103, 168] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[26, 199] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[91, 239] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[13, 298] -> 
             RGBColor[
              0.6702321842105263, 0.7318353157894737, 0.7480264736842104], 
             UndirectedEdge[229, 261] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[141, 179] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[59, 195] -> 
             RGBColor[
              0.6278081315789474, 0.6918236578947369, 0.8378482105263156], 
             UndirectedEdge[134, 253] -> 
             RGBColor[
              0.9659621842105264, 0.9711721052631579, 0.7710717105263156], 
             UndirectedEdge[42, 292] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[70, 238] -> 
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578], 
             UndirectedEdge[178, 202] -> 
             RGBColor[
              0.8325516842105263, 0.8672602105263159, 0.8526547631578946], 
             UndirectedEdge[29, 191] -> 
             RGBColor[
              0.8325516842105263, 0.8672602105263159, 0.8526547631578946], 
             UndirectedEdge[17, 38] -> 
             RGBColor[
              0.6687517631578948, 0.5949895263157896, 0.5934542894736843], 
             UndirectedEdge[40, 162] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[13, 95] -> 
             RGBColor[
              0.6702321842105263, 0.7318353157894737, 0.7480264736842104], 
             UndirectedEdge[206, 270] -> 
             RGBColor[
              0.5833105526315789, 0.647286605263158, 0.8935525263157895], 
             UndirectedEdge[16, 295] -> 
             RGBColor[
              0.8881311842105264, 0.9094798421052632, 0.765849789473684], 
             UndirectedEdge[37, 124] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[22, 177] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[115, 204] -> 
             RGBColor[
              0.9034786842105264, 0.9258075789473684, 0.9883739210526314], 
             UndirectedEdge[192, 200] -> 
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158], 
             UndirectedEdge[13, 171] -> 
             RGBColor[
              0.9625647894736842, 0.8774152631578948, 0.40822060526315773`], 
             UndirectedEdge[39, 52] -> 
             RGBColor[
              0.7732431842105263, 0.8183567368421053, 0.7553366842105261], 
             UndirectedEdge[92, 216] -> 
             RGBColor[
              0.8840548684210527, 0.7671219473684212, 0.6125557105263157], 
             UndirectedEdge[82, 127] -> 
             RGBColor[
              0.7688118157894737, 0.8041308421052632, 0.6767151052631578], 
             UndirectedEdge[53, 150] -> 
             RGBColor[
              0.9848103684210526, 0.9604239473684211, 0.3954915789473683], 
             UndirectedEdge[18, 66] -> 
             RGBColor[
              0.8604202631578948, 0.8917762105263158, 0.9841867631578947], 
             UndirectedEdge[31, 36] -> 
             RGBColor[
              0.7702536842105263, 0.8185084736842105, 0.9057713421052631], 
             UndirectedEdge[71, 181] -> 
             RGBColor[
              0.9317022105263157, 0.9451111578947369, 0.8624326578947367], 
             UndirectedEdge[43, 143] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[75, 185] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[46, 145] -> 
             RGBColor[
              0.5995846052631579, 0.6725200789473684, 0.9637894736842105], 
             UndirectedEdge[62, 255] -> 
             RGBColor[0.9595752894736842, 0.877567, 0.5586552631578947], 
             UndirectedEdge[111, 242] -> 
             RGBColor[
              0.49545657894736844`, 0.6008597894736842, 0.9535374736842105], 
             UndirectedEdge[4, 193] -> 
             RGBColor[
              0.5542524736842105, 0.6481633157894737, 0.9584598421052631], 
             UndirectedEdge[18, 258] -> 
             RGBColor[
              0.6425212631578948, 0.7141316842105263, 0.9663634473684211], 
             UndirectedEdge[81, 267] -> 
             RGBColor[0.7158865, 0.7713787894736842, 0.7509355263157893], 
             UndirectedEdge[75, 124] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[72, 106] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[262, 271] -> 
             RGBColor[
              0.9659621842105264, 0.9711721052631579, 0.7710717105263156], 
             UndirectedEdge[17, 235] -> 
             RGBColor[
              0.308513447368421, 0.42963792105263154`, 0.9413186578947368], 
             UndirectedEdge[263, 279] -> 
             RGBColor[0.6116091578947369, 0.6951412631578948, 0.962861], 
             UndirectedEdge[3, 252] -> 
             RGBColor[
              0.8160687631578948, 0.8125107894736843, 0.6368108421052631], 
             UndirectedEdge[48, 158] -> 
             RGBColor[
              0.6578348421052631, 0.7255525263157896, 0.9404415526315789], 
             UndirectedEdge[18, 36] -> 
             RGBColor[
              0.7455322631578948, 0.8006531052631579, 0.9736736578947367], 
             UndirectedEdge[105, 196] -> 
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578], 
             UndirectedEdge[269, 298] -> 
             RGBColor[
              0.6425212631578948, 0.7141316842105263, 0.9663634473684211], 
             UndirectedEdge[85, 207] -> 
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578], 
             UndirectedEdge[79, 103] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[76, 128] -> 
             RGBColor[
              0.7737557894736842, 0.8199566842105264, 0.8477323947368419], 
             UndirectedEdge[10, 265] -> 
             RGBColor[
              0.9317022105263157, 0.9451111578947369, 0.8624326578947367], 
             UndirectedEdge[88, 198] -> 
             RGBColor[
              0.6425212631578948, 0.7141316842105263, 0.9663634473684211], 
             UndirectedEdge[63, 143] -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 
             UndirectedEdge[49, 242] -> 
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052], 
             UndirectedEdge[252, 253] -> 
             RGBColor[
              0.9499918684210527, 0.9180226315789473, 0.6476234999999999], 
             UndirectedEdge[16, 125] -> 
             RGBColor[
              0.9812757631578948, 0.9825929473684211, 0.7451498157894735], 
             UndirectedEdge[59, 100] -> 
             RGBColor[
              0.5648120263157894, 0.6448591842105263, 0.9627547105263158], 
             UndirectedEdge[75, 295] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[94, 295] -> 
             RGBColor[
              0.5646902631578948, 0.6524394210526316, 0.9611415263157894], 
             UndirectedEdge[26, 192] -> 
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158], 
             UndirectedEdge[132, 188] -> 
             RGBColor[
              0.9897543421052631, 0.9762497894736842, 0.5665088684210524], 
             UndirectedEdge[186, 196] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[110, 179] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[61, 177] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[21, 264] -> 
             RGBColor[
              0.8043281578947369, 0.8479566315789474, 0.9785960263157893], 
             UndirectedEdge[200, 225] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[83, 197] -> 
             RGBColor[
              0.7608458421052632, 0.8120739473684211, 0.9477517631578947], 
             UndirectedEdge[220, 226] -> 
             RGBColor[
              0.9060086578947368, 0.5631013157894738, 0.45087207894736825`], 
             UndirectedEdge[13, 140] -> 
             RGBColor[0.7158865, 0.7713787894736842, 0.7509355263157893], 
             UndirectedEdge[144, 158] -> 
             RGBColor[
              0.9812757631578948, 0.9825929473684211, 0.7451498157894735], 
             UndirectedEdge[62, 225] -> 
             RGBColor[
              0.9501674473684211, 0.8711324736842105, 0.6006356842105263], 
             UndirectedEdge[65, 277] -> 
             RGBColor[
              0.6103445789473685, 0.691982894736842, 0.9640505789473683], 
             UndirectedEdge[99, 261] -> 
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052], 
             UndirectedEdge[260, 290] -> 
             RGBColor[
              0.7825892631578948, 0.8300839473684211, 0.9789648421052631], 
             UndirectedEdge[72, 267] -> 
             RGBColor[
              0.9311896052631579, 0.9435112105263158, 0.7700369473684209], 
             UndirectedEdge[39, 170] -> 
             RGBColor[
              0.9906836052631578, 0.9890274736842106, 0.703169394736842], 
             UndirectedEdge[92, 163] -> 
             RGBColor[
              0.840996447368421, 0.7330905789473685, 0.608368552631579], 
             UndirectedEdge[102, 133] -> 
             RGBColor[
              0.7702536842105263, 0.8185084736842105, 0.9057713421052631], 
             UndirectedEdge[184, 197] -> 
             RGBColor[
              0.7455322631578948, 0.8006531052631579, 0.9736736578947367], 
             UndirectedEdge[44, 200] -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 
             UndirectedEdge[115, 132] -> 
             RGBColor[
              0.9615308157894737, 0.9569462105263158, 0.6924501315789473], 
             UndirectedEdge[9, 283] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[52, 165] -> 
             RGBColor[
              0.7608458421052632, 0.8120739473684211, 0.9477517631578947], 
             UndirectedEdge[160, 256] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[45, 215] -> 
             RGBColor[
              0.9154300526315791, 0.7010260000000001, 0.25073936842105266`], 
             UndirectedEdge[16, 124] -> 
             RGBColor[
              0.9311896052631579, 0.9435112105263158, 0.7700369473684209], 
             UndirectedEdge[160, 246] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[57, 204] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[112, 252] -> 
             RGBColor[
              0.965305447368421, 0.9294434736842105, 0.6217016052631578], 
             UndirectedEdge[5, 248] -> 
             RGBColor[
              0.9664747894736843, 0.972772052631579, 0.8634674210526314], 
             UndirectedEdge[186, 276] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[95, 154] -> 
             RGBColor[
              0.6077486842105264, 0.6864707894736843, 0.9653286842105263], 
             UndirectedEdge[198, 290] -> 
             RGBColor[
              0.5646902631578948, 0.6524394210526316, 0.9611415263157894], 
             UndirectedEdge[77, 191] -> 
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158], 
             UndirectedEdge[36, 224] -> 
             RGBColor[
              0.7455322631578948, 0.8006531052631579, 0.9736736578947367], 
             UndirectedEdge[29, 203] -> 
             RGBColor[
              0.9897543421052631, 0.9762497894736842, 0.5665088684210524], 
             UndirectedEdge[25, 172] -> 
             RGBColor[
              0.8009307631578948, 0.7541997894736843, 0.6157449210526316], 
             UndirectedEdge[224, 260] -> 
             RGBColor[
              0.8604202631578948, 0.8917762105263158, 0.9841867631578947], 
             UndirectedEdge[45, 255] -> 
             RGBColor[
              0.9435488684210527, 0.8126382105263159, 0.5456881578947369], 
             UndirectedEdge[102, 239] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[33, 239] -> 
             RGBColor[
              0.6578348421052631, 0.7255525263157896, 0.9404415526315789], 
             UndirectedEdge[64, 92] -> 
             RGBColor[
              0.918827447368421, 0.7947828421052632, 0.6135904736842105], 
             UndirectedEdge[32, 268] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[85, 240] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[1, 174] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[2, 184] -> 
             RGBColor[
              0.8043281578947369, 0.8479566315789474, 0.9785960263157893], 
             UndirectedEdge[60, 85] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[121, 127] -> 
             RGBColor[
              0.7107596842105264, 0.7729922105263158, 0.9726388947368421], 
             UndirectedEdge[132, 212] -> 
             RGBColor[
              0.9267582368421052, 0.9292853157894737, 0.6914153684210526], 
             UndirectedEdge[172, 206] -> 
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158], 
             UndirectedEdge[147, 148] -> 
             RGBColor[
              0.9499918684210527, 0.9180226315789473, 0.6476234999999999], 
             UndirectedEdge[118, 226] -> 
             RGBColor[
              0.8930987105263157, 0.5552185789473685, 0.550891447368421], 
             UndirectedEdge[75, 283] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[188, 243] -> 
             RGBColor[
              0.9911962105263157, 0.9906274210526316, 0.7955651052631578], 
             UndirectedEdge[88, 258] -> 
             RGBColor[
              0.6425212631578948, 0.7141316842105263, 0.9663634473684211], 
             UndirectedEdge[197, 293] -> 
             RGBColor[
              0.7702536842105263, 0.8185084736842105, 0.9057713421052631], 
             UndirectedEdge[86, 179] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[41, 76] -> 
             RGBColor[
              0.9664747894736843, 0.972772052631579, 0.8634674210526314], 
             UndirectedEdge[175, 242] -> 
             RGBColor[0.7158865, 0.7713787894736842, 0.7509355263157893], 
             UndirectedEdge[89, 285] -> 
             RGBColor[
              0.9625647894736842, 0.8774152631578948, 0.40822060526315773`], 
             UndirectedEdge[138, 171] -> 
             RGBColor[
              0.9348538684210527, 0.8597116315789474, 0.6265575789473683], 
             UndirectedEdge[181, 207] -> 
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052], 
             UndirectedEdge[17, 55] -> 
             RGBColor[
              0.4380998947368421, 0.5538818421052631, 0.9491363157894737], 
             UndirectedEdge[142, 295] -> 
             RGBColor[
              0.8886437894736843, 0.9110797894736842, 0.8582454999999998], 
             UndirectedEdge[53, 200] -> 
             RGBColor[
              0.8276077105263158, 0.8514343684210527, 0.6816374736842105], 
             UndirectedEdge[33, 237] -> 
             RGBColor[
              0.6672426842105263, 0.731987052631579, 0.8984611315789475], 
             UndirectedEdge[51, 67] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[47, 48] -> 
             RGBColor[
              0.6077486842105264, 0.6864707894736843, 0.9653286842105263], 
             UndirectedEdge[102, 237] -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 
             UndirectedEdge[150, 282] -> 
             RGBColor[
              0.9267582368421052, 0.9292853157894737, 0.6914153684210526], 
             UndirectedEdge[214, 293] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[73, 245] -> 
             RGBColor[
              0.8836998157894738, 0.8952539473684211, 0.6872282105263157], 
             UndirectedEdge[82, 192] -> 
             RGBColor[
              0.9862522368421052, 0.9748015789473685, 0.6245478157894737], 
             UndirectedEdge[82, 266] -> 
             RGBColor[
              0.9768443947368421, 0.968367052631579, 0.6665282368421052], 
             UndirectedEdge[30, 38] -> 
             RGBColor[
              0.8840548684210527, 0.7671219473684212, 0.6125557105263157], 
             UndirectedEdge[146, 242] -> 
             RGBColor[
              0.49545657894736844`, 0.6008597894736842, 0.9535374736842105], 
             UndirectedEdge[25, 77] -> 
             RGBColor[0.9595752894736842, 0.877567, 0.5586552631578947], 
             UndirectedEdge[68, 271] -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             UndirectedEdge[23, 267] -> 
             RGBColor[
              0.9625647894736842, 0.8774152631578948, 0.40822060526315773`], 
             UndirectedEdge[10, 161] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[223, 287] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.6077486842105264, 0.6864707894736843, 0.9653286842105263], 
             UndirectedEdge[218, 229] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[62, 170] -> 
             RGBColor[0.9595752894736842, 0.877567, 0.5586552631578947], 
             UndirectedEdge[188, 294] -> 
             RGBColor[
              0.9317022105263157, 0.9451111578947369, 0.8624326578947367], 
             UndirectedEdge[181, 299] -> 
             RGBColor[
              0.9317022105263157, 0.9451111578947369, 0.8624326578947367], 
             UndirectedEdge[69, 109] -> 
             RGBColor[
              0.9659621842105264, 0.9711721052631579, 0.7710717105263156], 
             UndirectedEdge[48, 175] -> 
             RGBColor[
              0.6702321842105263, 0.7318353157894737, 0.7480264736842104], 
             UndirectedEdge[248, 270] -> 
             RGBColor[
              0.5585891315789474, 0.6294312368421052, 0.9614548421052631], 
             UndirectedEdge[85, 232] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[65, 152] -> 
             RGBColor[
              0.6677012631578948, 0.7389608421052631, 0.9684517368421053], 
             UndirectedEdge[43, 63] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[184, 293] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[24, 260] -> 
             RGBColor[
              0.7264971578947369, 0.7862643684210526, 0.9733741052631579], 
             UndirectedEdge[201, 229] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[17, 48] -> 
             RGBColor[
              0.3924455789473684, 0.5143383684210527, 0.9462272631578947], 
             UndirectedEdge[153, 163] -> 
             RGBColor[
              0.6103445789473685, 0.691982894736842, 0.9640505789473683], 
             UndirectedEdge[33, 200] -> 
             RGBColor[
              0.508598157894737, 0.6086198421052633, 0.9555507894736842], 
             UndirectedEdge[33, 282] -> 
             RGBColor[
              0.6077486842105264, 0.6864707894736843, 0.9653286842105263], 
             UndirectedEdge[150, 237] -> 
             RGBColor[
              0.9862522368421052, 0.9748015789473685, 0.6245478157894737], 
             UndirectedEdge[172, 203] -> 
             RGBColor[
              0.8276077105263158, 0.8514343684210527, 0.6816374736842105], 
             UndirectedEdge[56, 93] -> 
             RGBColor[
              0.9911962105263157, 0.9906274210526316, 0.7955651052631578], 
             UndirectedEdge[122, 299] -> 
             RGBColor[
              0.6707447894736842, 0.7334352631578949, 0.8404221842105262], 
             UndirectedEdge[44, 100] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[31, 171] -> 
             RGBColor[0.9595752894736842, 0.877567, 0.5586552631578947], 
             UndirectedEdge[136, 256] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[146, 159] -> 
             RGBColor[
              0.40686560526315796`, 0.5197047105263158, 0.948054447368421], 
             UndirectedEdge[65, 133] -> 
             RGBColor[
              0.6677012631578948, 0.7389608421052631, 0.9684517368421053], 
             UndirectedEdge[58, 245] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[172, 272] -> 
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158], 
             UndirectedEdge[99, 218] -> 
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578], 
             UndirectedEdge[18, 113] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[43, 131] -> 
             RGBColor[
              0.9501674473684211, 0.8711324736842105, 0.6006356842105263], 
             UndirectedEdge[2, 156] -> 
             RGBColor[
              0.8160687631578948, 0.8125107894736843, 0.6368108421052631], 
             UndirectedEdge[165, 232] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[173, 186] -> 
             RGBColor[
              0.8325516842105263, 0.8672602105263159, 0.8526547631578946], 
             UndirectedEdge[39, 281] -> 
             RGBColor[
              0.9941857105263158, 0.9904756842105263, 0.6451304473684207], 
             UndirectedEdge[77, 91] -> 
             RGBColor[
              0.9911962105263157, 0.9906274210526316, 0.7955651052631578], 
             UndirectedEdge[15, 19] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[119, 241] -> 
             RGBColor[
              0.5646902631578948, 0.6524394210526316, 0.9611415263157894], 
             UndirectedEdge[103, 116] -> 
             RGBColor[
              0.9034786842105264, 0.9258075789473684, 0.9883739210526314], 
             UndirectedEdge[99, 257] -> 
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725], 
             UndirectedEdge[17, 253] -> 
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725], 
             UndirectedEdge[204, 292] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[65, 241] -> 
             RGBColor[
              0.7825892631578948, 0.8300839473684211, 0.9789648421052631], 
             UndirectedEdge[71, 256] -> 
             RGBColor[
              0.8325516842105263, 0.8672602105263159, 0.8526547631578946], 
             UndirectedEdge[37, 102] -> 
             RGBColor[
              0.8851416842105263, 0.9096315789473685, 0.9162844473684211], 
             UndirectedEdge[61, 217] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[35, 184] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[164, 241] -> 
             RGBColor[
              0.5646902631578948, 0.6524394210526316, 0.9611415263157894], 
             UndirectedEdge[192, 255] -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 
             UndirectedEdge[112, 134] -> 
             RGBColor[
              0.9812757631578948, 0.9825929473684211, 0.7451498157894735], 
             UndirectedEdge[44, 195] -> 
             RGBColor[
              0.8325516842105263, 0.8672602105263159, 0.8526547631578946], 
             UndirectedEdge[127, 281] -> 
             RGBColor[
              0.7737557894736842, 0.8199566842105264, 0.8477323947368419], 
             UndirectedEdge[59, 192] -> 
             RGBColor[
              0.6243060263157894, 0.6903754473684212, 0.8958871578947369], 
             UndirectedEdge[108, 264] -> 
             RGBColor[
              0.9664747894736843, 0.972772052631579, 0.8634674210526314], 
             UndirectedEdge[136, 296] -> 
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578], 
             UndirectedEdge[118, 130] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[85, 136] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[104, 157] -> 
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578], 
             UndirectedEdge[158, 217] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[11, 174] -> 
             RGBColor[
              0.5646902631578948, 0.6524394210526316, 0.9611415263157894], 
             UndirectedEdge[39, 220] -> 
             RGBColor[
              0.9941857105263158, 0.9904756842105263, 0.6451304473684207], 
             UndirectedEdge[32, 208] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[27, 103] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[212, 250] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[129, 298] -> 
             RGBColor[
              0.6578348421052632, 0.7255525263157896, 0.9404415526315789], 
             UndirectedEdge[107, 179] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[261, 290] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[24, 113] -> 
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158], 
             UndirectedEdge[15, 243] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[246, 296] -> 
             RGBColor[
              0.7128969999999999, 0.7715305263157894, 0.9013701842105264], 
             UndirectedEdge[131, 174] -> 
             RGBColor[
              0.8570228684210527, 0.7980193684210526, 0.6213356578947369], 
             UndirectedEdge[44, 121] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[155, 293] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[105, 140] -> 
             RGBColor[
              0.4380998947368421, 0.5538818421052631, 0.9491363157894737], 
             UndirectedEdge[51, 138] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[133, 277] -> 
             RGBColor[
              0.49545657894736844`, 0.6008597894736842, 0.9535374736842105], 
             UndirectedEdge[201, 261] -> 
             RGBColor[
              0.9317022105263157, 0.9451111578947369, 0.8624326578947367], 
             UndirectedEdge[19, 57] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[104, 261] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[15, 111] -> 
             RGBColor[
              0.7107596842105264, 0.7729922105263158, 0.9726388947368421], 
             UndirectedEdge[71, 85] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[84, 158] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[65, 162] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[156, 268] -> 
             RGBColor[
              0.9782153947368422, 0.9373262105263158, 0.521682236842105], 
             UndirectedEdge[48, 252] -> 
             RGBColor[
              0.6542618684210526, 0.6786858421052632, 0.6245782631578947], 
             UndirectedEdge[204, 235] -> 
             RGBColor[
              0.523816552631579, 0.6017703421052631, 0.9604200789473685], 
             UndirectedEdge[62, 130] -> 
             RGBColor[
              0.8570228684210527, 0.7980193684210526, 0.6213356578947369], 
             UndirectedEdge[142, 283] -> 
             RGBColor[
              0.9317022105263157, 0.9451111578947369, 0.8624326578947367], 
             UndirectedEdge[99, 259] -> 
             RGBColor[
              0.6103445789473685, 0.691982894736842, 0.9640505789473683], 
             UndirectedEdge[43, 244] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[36, 154] -> 
             RGBColor[
              0.7107596842105264, 0.7729922105263158, 0.9726388947368421], 
             UndirectedEdge[11, 185] -> 
             RGBColor[
              0.508598157894737, 0.6086198421052633, 0.9555507894736842], 
             UndirectedEdge[20, 150] -> 
             RGBColor[
              0.8276077105263158, 0.8514343684210527, 0.6816374736842105], 
             UndirectedEdge[175, 252] -> 
             RGBColor[
              0.9777027894736843, 0.9357262631578946, 0.42928652631578923`], 
             UndirectedEdge[97, 292] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[176, 226] -> 
             RGBColor[
              0.8930987105263157, 0.5552185789473685, 0.550891447368421], 
             UndirectedEdge[80, 103] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[137, 220] -> 
             RGBColor[
              0.7163991052631579, 0.7729787368421053, 0.8433312368421051], 
             UndirectedEdge[20, 167] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[240, 256] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[113, 278] -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 
             UndirectedEdge[181, 240] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[7, 151] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[6, 101] -> 
             RGBColor[
              0.8836998157894738, 0.8952539473684211, 0.6872282105263157], 
             UndirectedEdge[65, 116] -> 
             RGBColor[
              0.8604202631578948, 0.8917762105263158, 0.9841867631578947], 
             UndirectedEdge[50, 264] -> 
             RGBColor[
              0.918827447368421, 0.7947828421052632, 0.6135904736842105], 
             UndirectedEdge[55, 235] -> 
             RGBColor[
              0.308513447368421, 0.42963792105263154`, 0.9413186578947368], 
             UndirectedEdge[100, 232] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[28, 163] -> 
             RGBColor[
              0.8881311842105264, 0.9094798421052632, 0.765849789473684], 
             UndirectedEdge[11, 63] -> 
             RGBColor[
              0.508598157894737, 0.6086198421052633, 0.9555507894736842], 
             UndirectedEdge[234, 274] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[148, 270] -> 
             RGBColor[
              0.5703297368421053, 0.5939853947368421, 0.6196696578947367], 
             UndirectedEdge[96, 245] -> 
             RGBColor[
              0.8604202631578948, 0.8917762105263158, 0.9841867631578947], 
             UndirectedEdge[159, 235] -> 
             RGBColor[
              0.21992247368421053`, 0.34848284210526315`, 0.9358356315789473],
              UndirectedEdge[53, 287] -> 
             RGBColor[
              0.9615308157894737, 0.9569462105263158, 0.6924501315789473], 
             UndirectedEdge[105, 289] -> 
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725], 
             UndirectedEdge[56, 164] -> 
             RGBColor[
              0.6672426842105263, 0.731987052631579, 0.8984611315789475], 
             UndirectedEdge[112, 235] -> 
             RGBColor[
              0.5739027105263158, 0.6408520789473684, 0.9355329473684211], 
             UndirectedEdge[7, 43] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[242, 243] -> 
             RGBColor[
              0.7128969999999999, 0.7715305263157894, 0.9013701842105264], 
             UndirectedEdge[151, 286] -> 
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052], 
             UndirectedEdge[126, 163] -> 
             RGBColor[
              0.8886437894736843, 0.9110797894736842, 0.8582454999999998], 
             UndirectedEdge[31, 138] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[95, 138] -> 
             RGBColor[
              0.6425212631578947, 0.7141316842105263, 0.9663634473684211], 
             UndirectedEdge[197, 275] -> 
             RGBColor[
              0.7737557894736842, 0.8199566842105264, 0.8477323947368419], 
             UndirectedEdge[198, 245] -> 
             RGBColor[
              0.5646902631578948, 0.6524394210526316, 0.9611415263157894], 
             UndirectedEdge[187, 264] -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             UndirectedEdge[62, 195] -> 
             RGBColor[
              0.9630773947368421, 0.8790152105263158, 0.5006163157894735], 
             UndirectedEdge[169, 187] -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             UndirectedEdge[82, 199] -> 
             RGBColor[
              0.9768443947368421, 0.968367052631579, 0.6665282368421052], 
             UndirectedEdge[126, 155] -> 
             RGBColor[
              0.9664747894736843, 0.972772052631579, 0.8634674210526314], 
             UndirectedEdge[82, 220] -> 
             RGBColor[
              0.9897543421052631, 0.9762497894736842, 0.5665088684210524], 
             UndirectedEdge[32, 202] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[113, 260] -> 
             RGBColor[
              0.8851416842105263, 0.9096315789473685, 0.9162844473684211], 
             UndirectedEdge[105, 230] -> 
             RGBColor[
              0.7128969999999999, 0.7715305263157894, 0.9013701842105264], 
             UndirectedEdge[245, 289] -> 
             RGBColor[
              0.8604202631578948, 0.8917762105263158, 0.9841867631578947], 
             UndirectedEdge[108, 187] -> 
             RGBColor[
              0.9664747894736843, 0.972772052631579, 0.8634674210526314], 
             UndirectedEdge[137, 228] -> 
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725], 
             UndirectedEdge[88, 261] -> 
             RGBColor[
              0.9034786842105264, 0.9258075789473684, 0.9883739210526314], 
             UndirectedEdge[192, 228] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[42, 97] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[121, 240] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[25, 43] -> 
             RGBColor[
              0.9501674473684211, 0.8711324736842105, 0.6006356842105263], 
             UndirectedEdge[77, 270] -> 
             RGBColor[
              0.5833105526315789, 0.647286605263158, 0.8935525263157895], 
             UndirectedEdge[225, 255] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[2, 275] -> 
             RGBColor[
              0.8325516842105263, 0.8672602105263159, 0.8526547631578946], 
             UndirectedEdge[235, 253] -> 
             RGBColor[
              0.5585891315789473, 0.6294312368421053, 0.9614548421052631], 
             UndirectedEdge[73, 95] -> 
             RGBColor[
              0.6658008157894737, 0.7176094210526316, 0.6694048947368421], 
             UndirectedEdge[49, 175] -> 
             RGBColor[
              0.9311896052631579, 0.9435112105263158, 0.7700369473684209], 
             UndirectedEdge[153, 219] -> 
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725], 
             UndirectedEdge[54, 167] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[56, 246] -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 
             UndirectedEdge[192, 225] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[84, 252] -> 
             RGBColor[0.9747132894736842, 0.935878, 0.5797211842105263], 
             UndirectedEdge[119, 164] -> 
             RGBColor[
              0.3467912631578948, 0.4747948947368422, 0.9433182105263158], 
             UndirectedEdge[93, 168] -> 
             RGBColor[
              0.9317022105263157, 0.9451111578947369, 0.8624326578947367], 
             UndirectedEdge[111, 250] -> 
             RGBColor[
              0.7702536842105263, 0.8185084736842105, 0.9057713421052631], 
             UndirectedEdge[54, 286] -> 
             RGBColor[
              0.7128969999999999, 0.7715305263157894, 0.9013701842105264], 
             UndirectedEdge[74, 257] -> 
             RGBColor[
              0.6425212631578947, 0.7141316842105263, 0.9663634473684211], 
             UndirectedEdge[220, 236] -> 
             RGBColor[
              0.8325516842105263, 0.8672602105263159, 0.8526547631578946], 
             UndirectedEdge[130, 228] -> 
             RGBColor[
              0.8604202631578948, 0.8917762105263158, 0.9841867631578947], 
             UndirectedEdge[1, 142] -> 
             RGBColor[
              0.9317022105263157, 0.9451111578947369, 0.8624326578947367], 
             UndirectedEdge[101, 114] -> 
             RGBColor[
              0.8604202631578948, 0.8917762105263158, 0.9841867631578947], 
             UndirectedEdge[199, 266] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[93, 277] -> 
             RGBColor[
              0.7163991052631579, 0.7729787368421053, 0.8433312368421051], 
             UndirectedEdge[19, 112] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[77, 203] -> 
             RGBColor[
              0.9862522368421052, 0.9748015789473685, 0.6245478157894737], 
             UndirectedEdge[26, 60] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[186, 263] -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 
             UndirectedEdge[167, 283] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[170, 200] -> 
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158], 
             UndirectedEdge[17, 292] -> 
             RGBColor[
              0.5542524736842105, 0.6481633157894737, 0.9584598421052631], 
             UndirectedEdge[106, 215] -> 
             RGBColor[0.9595752894736842, 0.877567, 0.5586552631578947], 
             UndirectedEdge[123, 229] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[105, 149] -> 
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052], 
             UndirectedEdge[68, 274] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[149, 171] -> 
             RGBColor[
              0.9000812894736843, 0.8320507368421053, 0.6255228157894737], 
             UndirectedEdge[29, 172] -> 
             RGBColor[
              0.8325516842105263, 0.8672602105263159, 0.8526547631578946], 
             UndirectedEdge[76, 209] -> 
             RGBColor[
              0.9060086578947368, 0.5631013157894738, 0.45087207894736825`], 
             UndirectedEdge[247, 267] -> 
             RGBColor[
              0.8320390789473684, 0.8656602631578948, 0.7602590526315788], 
             UndirectedEdge[164, 210] -> 
             RGBColor[
              0.6707447894736842, 0.7334352631578949, 0.8404221842105262], 
             UndirectedEdge[258, 260] -> 
             RGBColor[
              0.5646902631578948, 0.6524394210526316, 0.9611415263157894], 
             UndirectedEdge[62, 137] -> 
             RGBColor[
              0.6847781842105263, 0.6599183157894737, 0.6064213947368421], 
             UndirectedEdge[175, 280] -> 
             RGBColor[
              0.8881311842105264, 0.9094798421052632, 0.765849789473684], 
             UndirectedEdge[72, 194] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[3, 257] -> 
             RGBColor[
              0.8043281578947369, 0.8479566315789474, 0.9785960263157893], 
             UndirectedEdge[154, 171] -> 
             RGBColor[
              0.9000812894736843, 0.8320507368421053, 0.6255228157894737], 
             UndirectedEdge[168, 277] -> 
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052], 
             UndirectedEdge[146, 243] -> 
             RGBColor[
              0.7702536842105263, 0.8185084736842105, 0.9057713421052631], 
             UndirectedEdge[98, 122] -> 
             RGBColor[
              0.5646902631578948, 0.6524394210526316, 0.9611415263157894], 
             UndirectedEdge[142, 210] -> 
             RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947365], 
             UndirectedEdge[3, 38] -> 
             RGBColor[
              0.7849043421052633, 0.6892710000000002, 0.6027778157894736], 
             UndirectedEdge[21, 205] -> 
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158], 
             UndirectedEdge[153, 221] -> 
             RGBColor[
              0.7163991052631579, 0.7729787368421053, 0.8433312368421051], 
             UndirectedEdge[55, 159] -> 
             RGBColor[
              0.34950892105263154`, 0.47272676315789475`, 0.9436532894736842],
              UndirectedEdge[149, 298] -> 
             RGBColor[
              0.6077486842105264, 0.6864707894736843, 0.9653286842105263], 
             UndirectedEdge[22, 247] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[105, 298] -> 
             RGBColor[
              0.3924455789473684, 0.5143383684210527, 0.9462272631578947], 
             UndirectedEdge[169, 219] -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             UndirectedEdge[53, 225] -> 
             RGBColor[
              0.9768443947368421, 0.968367052631579, 0.6665282368421052], 
             UndirectedEdge[47, 90] -> 
             RGBColor[
              0.6077486842105264, 0.6864707894736843, 0.9653286842105263], 
             UndirectedEdge[100, 137] -> 
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052], 
             UndirectedEdge[15, 175] -> 
             RGBColor[
              0.9311896052631579, 0.9435112105263158, 0.7700369473684209], 
             UndirectedEdge[49, 253] -> 
             RGBColor[
              0.9034786842105264, 0.9258075789473684, 0.9883739210526314], 
             UndirectedEdge[166, 291] -> 
             RGBColor[
              0.8325516842105263, 0.8672602105263159, 0.8526547631578946], 
             UndirectedEdge[161, 230] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[263, 269] -> 
             RGBColor[
              0.8043281578947369, 0.8479566315789474, 0.9785960263157893], 
             UndirectedEdge[122, 160] -> 
             RGBColor[
              0.6077486842105264, 0.6864707894736843, 0.9653286842105263], 
             UndirectedEdge[196, 289] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[30, 158] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[114, 187] -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             UndirectedEdge[49, 159] -> 
             RGBColor[
              0.5648120263157895, 0.6448591842105263, 0.9627547105263158], 
             UndirectedEdge[33, 94] -> 
             RGBColor[
              0.3467912631578948, 0.4747948947368422, 0.9433182105263158], 
             UndirectedEdge[193, 220] -> 
             RGBColor[
              0.7163991052631579, 0.7729787368421053, 0.8433312368421051], 
             UndirectedEdge[60, 127] -> 
             RGBColor[
              0.7608458421052632, 0.8120739473684211, 0.9477517631578947], 
             UndirectedEdge[282, 297] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[97, 235] -> 
             RGBColor[
              0.5739027105263158, 0.6408520789473684, 0.9355329473684211], 
             UndirectedEdge[50, 187] -> 
             RGBColor[
              0.918827447368421, 0.7947828421052632, 0.6135904736842105], 
             UndirectedEdge[271, 274] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[137, 170] -> 
             RGBColor[
              0.7128969999999999, 0.7715305263157894, 0.9013701842105264], 
             UndirectedEdge[84, 253] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[33, 185] -> 
             RGBColor[
              0.508598157894737, 0.6086198421052633, 0.9555507894736842], 
             UndirectedEdge[3, 144] -> 
             RGBColor[
              0.8320390789473684, 0.8656602631578948, 0.7602590526315788], 
             UndirectedEdge[11, 43] -> 
             RGBColor[
              0.6578348421052631, 0.7255525263157896, 0.9404415526315789], 
             UndirectedEdge[29, 272] -> 
             RGBColor[
              0.9911962105263157, 0.9906274210526316, 0.7955651052631578], 
             UndirectedEdge[70, 251] -> 
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578], 
             UndirectedEdge[99, 123] -> 
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725], 
             UndirectedEdge[133, 239] -> 
             RGBColor[
              0.7608458421052632, 0.8120739473684211, 0.9477517631578947], 
             UndirectedEdge[259, 260] -> 
             RGBColor[
              0.7825892631578948, 0.8300839473684211, 0.9789648421052631], 
             UndirectedEdge[125, 192] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[213, 264] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[134, 204] -> 
             RGBColor[
              0.9311896052631579, 0.9435112105263158, 0.7700369473684209], 
             UndirectedEdge[94, 142] -> 
             RGBColor[
              0.6707447894736842, 0.7334352631578949, 0.8404221842105262], 
             UndirectedEdge[134, 175] -> 
             RGBColor[
              0.9936731052631579, 0.9888757368421053, 0.552734736842105], 
             UndirectedEdge[8, 267] -> 
             RGBColor[
              0.9941857105263158, 0.9904756842105263, 0.6451304473684207], 
             UndirectedEdge[195, 225] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[51, 281] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[49, 243] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[212, 243] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[22, 285] -> 
             RGBColor[
              0.9501674473684211, 0.8711324736842105, 0.6006356842105263], 
             UndirectedEdge[20, 33] -> 
             RGBColor[
              0.508598157894737, 0.6086198421052633, 0.9555507894736842], 
             UndirectedEdge[9, 174] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[180, 250] -> 
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158], 
             UndirectedEdge[92, 221] -> 
             RGBColor[
              0.9470509736842105, 0.8140864210526317, 0.48764921052631566`], 
             UndirectedEdge[71, 232] -> 
             RGBColor[
              0.8886437894736843, 0.9110797894736842, 0.8582454999999998], 
             UndirectedEdge[25, 148] -> 
             RGBColor[
              0.9465944736842106, 0.8242657894736842, 0.284772394736842], 
             UndirectedEdge[76, 218] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[20, 200] -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 
             UndirectedEdge[68, 255] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[30, 123] -> 
             RGBColor[
              0.9034786842105264, 0.9258075789473684, 0.9883739210526314], 
             UndirectedEdge[113, 290] -> 
             RGBColor[
              0.8851416842105263, 0.9096315789473685, 0.9162844473684211], 
             UndirectedEdge[230, 269] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[71, 296] -> 
             RGBColor[
              0.7163991052631579, 0.7729787368421053, 0.8433312368421051], 
             UndirectedEdge[37, 237] -> 
             RGBColor[
              0.8851416842105263, 0.9096315789473685, 0.9162844473684211], 
             UndirectedEdge[8, 217] -> 
             RGBColor[
              0.8886437894736843, 0.9110797894736842, 0.8582454999999998], 
             UndirectedEdge[39, 100] -> 
             RGBColor[
              0.9311896052631579, 0.9435112105263158, 0.7700369473684209], 
             UndirectedEdge[35, 216] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[48, 253] -> 
             RGBColor[
              0.6425212631578947, 0.7141316842105263, 0.9663634473684211], 
             UndirectedEdge[72, 247] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[24, 254] -> 
             RGBColor[
              0.8320390789473684, 0.8656602631578948, 0.7602590526315788], 
             UndirectedEdge[247, 273] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[80, 152] -> 
             RGBColor[
              0.7608458421052632, 0.8120739473684211, 0.9477517631578947], 
             UndirectedEdge[121, 125] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[8, 177] -> 
             RGBColor[
              0.9317022105263157, 0.9451111578947369, 0.8624326578947367], 
             UndirectedEdge[38, 253] -> 
             RGBColor[
              0.918827447368421, 0.7947828421052632, 0.6135904736842105], 
             UndirectedEdge[134, 292] -> 
             RGBColor[
              0.8320390789473684, 0.8656602631578948, 0.7602590526315788], 
             UndirectedEdge[19, 177] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[219, 221] -> 
             RGBColor[
              0.9664747894736843, 0.972772052631579, 0.8634674210526314], 
             UndirectedEdge[37, 185] -> 
             RGBColor[
              0.7264971578947369, 0.7862643684210526, 0.9733741052631579], 
             UndirectedEdge[15, 280] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[140, 171] -> 
             RGBColor[
              0.6847781842105263, 0.6599183157894737, 0.6064213947368421], 
             UndirectedEdge[211, 221] -> 
             RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947365], 
             UndirectedEdge[47, 273] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[58, 171] -> 
             RGBColor[
              0.9000812894736843, 0.8320507368421053, 0.6255228157894737], 
             UndirectedEdge[75, 150] -> 
             RGBColor[
              0.9267582368421052, 0.9292853157894737, 0.6914153684210526], 
             UndirectedEdge[9, 167] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[135, 260] -> 
             RGBColor[
              0.7825892631578948, 0.8300839473684211, 0.9789648421052631], 
             UndirectedEdge[184, 202] -> 
             RGBColor[
              0.8043281578947369, 0.8479566315789474, 0.9785960263157893], 
             UndirectedEdge[166, 262] -> 
             RGBColor[
              0.8320390789473684, 0.8656602631578948, 0.7602590526315788], 
             UndirectedEdge[173, 276] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[67, 86] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[25, 272] -> 
             RGBColor[0.9595752894736842, 0.877567, 0.5586552631578947], 
             UndirectedEdge[7, 174] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[88, 113] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[147, 206] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[189, 211] -> 
             RGBColor[
              0.7163991052631579, 0.7729787368421053, 0.8433312368421051], 
             UndirectedEdge[104, 209] -> 
             RGBColor[
              0.8930987105263157, 0.5552185789473685, 0.550891447368421], 
             UndirectedEdge[151, 167] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[215, 274] -> 
             RGBColor[
              0.9501674473684211, 0.8711324736842105, 0.6006356842105263], 
             UndirectedEdge[41, 261] -> 
             RGBColor[
              0.9034786842105264, 0.9258075789473684, 0.9883739210526314], 
             UndirectedEdge[157, 218] -> 
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578], 
             UndirectedEdge[187, 205] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[62, 82] -> 
             RGBColor[
              0.9581334210526316, 0.8631893684210526, 0.3295990263157894], 
             UndirectedEdge[42, 144] -> 
             RGBColor[
              0.9812757631578948, 0.9825929473684211, 0.7451498157894735], 
             UndirectedEdge[33, 150] -> 
             RGBColor[
              0.6658008157894737, 0.7176094210526316, 0.6694048947368421], 
             UndirectedEdge[34, 46] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[220, 266] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[128, 279] -> 
             RGBColor[
              0.5528132631578948, 0.6478377368421053, 0.9579386315789473], 
             UndirectedEdge[147, 270] -> 
             RGBColor[
              0.5585891315789474, 0.6294312368421052, 0.9614548421052631], 
             UndirectedEdge[30, 90] -> 
             RGBColor[
              0.6077486842105264, 0.6864707894736843, 0.9653286842105263], 
             UndirectedEdge[36, 222] -> 
             RGBColor[
              0.7572728684210527, 0.7652072631578948, 0.6318884736842104], 
             UndirectedEdge[127, 170] -> 
             RGBColor[
              0.7702536842105263, 0.8185084736842105, 0.9057713421052631], 
             UndirectedEdge[1, 295] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[96, 140] -> 
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725], 
             UndirectedEdge[206, 272] -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 
             UndirectedEdge[129, 265] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[39, 60] -> 
             RGBColor[
              0.9812757631578948, 0.9825929473684211, 0.7451498157894735], 
             UndirectedEdge[71, 240] -> 
             RGBColor[
              0.9317022105263157, 0.9451111578947369, 0.8624326578947367], 
             UndirectedEdge[30, 144] -> 
             RGBColor[
              0.9311896052631579, 0.9435112105263158, 0.7700369473684209], 
             UndirectedEdge[26, 59] -> 
             RGBColor[
              0.46566150000000006`, 0.5670082368421053, 0.9529768157894737], 
             UndirectedEdge[133, 241] -> 
             RGBColor[
              0.6677012631578948, 0.7389608421052631, 0.9684517368421053], 
             UndirectedEdge[236, 266] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[28, 216] -> 
             RGBColor[
              0.9311896052631579, 0.9435112105263158, 0.7700369473684209], 
             UndirectedEdge[173, 230] -> 
             RGBColor[
              0.9911962105263157, 0.9906274210526316, 0.7955651052631578], 
             UndirectedEdge[39, 266] -> 
             RGBColor[
              0.9812757631578948, 0.9825929473684211, 0.7451498157894735], 
             UndirectedEdge[86, 141] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[25, 206] -> 
             RGBColor[0.9595752894736842, 0.877567, 0.5586552631578947], 
             UndirectedEdge[141, 165] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[152, 241] -> 
             RGBColor[
              0.6677012631578948, 0.7389608421052631, 0.9684517368421053], 
             UndirectedEdge[110, 141] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[97, 134] -> 
             RGBColor[
              0.9812757631578948, 0.9825929473684211, 0.7451498157894735], 
             UndirectedEdge[103, 119] -> 
             RGBColor[
              0.6077486842105264, 0.6864707894736843, 0.9653286842105263], 
             UndirectedEdge[3, 17] -> 
             RGBColor[
              0.5542524736842105, 0.6481633157894737, 0.9584598421052631], 
             UndirectedEdge[203, 270] -> 
             RGBColor[
              0.5818686842105263, 0.6329089736842105, 0.6644962894736841], 
             UndirectedEdge[51, 141] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[184, 275] -> 
             RGBColor[
              0.9664747894736843, 0.972772052631579, 0.8634674210526314], 
             UndirectedEdge[58, 109] -> 
             RGBColor[
              0.9311896052631579, 0.9435112105263158, 0.7700369473684209], 
             UndirectedEdge[179, 281] -> 
             RGBColor[
              0.9317022105263157, 0.9451111578947369, 0.8624326578947367], 
             UndirectedEdge[31, 154] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[122, 296] -> 
             RGBColor[
              0.3924455789473684, 0.5143383684210527, 0.9462272631578947], 
             UndirectedEdge[96, 290] -> 
             RGBColor[
              0.8604202631578948, 0.8917762105263158, 0.9841867631578947], 
             UndirectedEdge[122, 240] -> 
             RGBColor[
              0.6077486842105264, 0.6864707894736843, 0.9653286842105263], 
             UndirectedEdge[97, 144] -> 
             RGBColor[
              0.9812757631578948, 0.9825929473684211, 0.7451498157894735], 
             UndirectedEdge[61, 247] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[45, 287] -> 
             RGBColor[
              0.918827447368421, 0.7947828421052632, 0.6135904736842105], 
             UndirectedEdge[278, 290] -> 
             RGBColor[
              0.8851416842105263, 0.9096315789473685, 0.9162844473684211], 
             UndirectedEdge[109, 110] -> 
             RGBColor[
              0.9812757631578948, 0.9825929473684211, 0.7451498157894735], 
             UndirectedEdge[56, 160] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[146, 292] -> 
             RGBColor[0.6116091578947369, 0.6951412631578948, 0.962861], 
             UndirectedEdge[131, 139] -> 
             RGBColor[
              0.6391238684210527, 0.6203748421052633, 0.6035123421052632], 
             UndirectedEdge[47, 74] -> 
             RGBColor[
              0.6077486842105264, 0.6864707894736843, 0.9653286842105263], 
             UndirectedEdge[46, 221] -> 
             RGBColor[
              0.9664747894736843, 0.972772052631579, 0.8634674210526314], 
             UndirectedEdge[48, 74] -> 
             RGBColor[
              0.3467912631578948, 0.4747948947368422, 0.9433182105263158], 
             UndirectedEdge[90, 134] -> 
             RGBColor[
              0.6702321842105263, 0.7318353157894737, 0.7480264736842104], 
             UndirectedEdge[1, 37] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[33, 295] -> 
             RGBColor[
              0.5646902631578948, 0.6524394210526316, 0.9611415263157894], 
             UndirectedEdge[28, 35] -> 
             RGBColor[
              0.9906836052631578, 0.9890274736842106, 0.703169394736842], 
             UndirectedEdge[21, 169] -> 
             RGBColor[
              0.8043281578947369, 0.8479566315789474, 0.9785960263157893], 
             UndirectedEdge[100, 228] -> 
             RGBColor[
              0.9034786842105264, 0.9258075789473684, 0.9883739210526314], 
             UndirectedEdge[190, 250] -> 
             RGBColor[0.9595752894736842, 0.877567, 0.5586552631578947], 
             UndirectedEdge[81, 180] -> 
             RGBColor[
              0.5542524736842105, 0.6481633157894737, 0.9584598421052631], 
             UndirectedEdge[127, 141] -> 
             RGBColor[
              0.7608458421052632, 0.8120739473684211, 0.9477517631578947], 
             UndirectedEdge[143, 185] -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 
             UndirectedEdge[283, 295] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[26, 100] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[242, 294] -> 
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052], 
             UndirectedEdge[39, 228] -> 
             RGBColor[
              0.9659621842105264, 0.9711721052631579, 0.7710717105263156], 
             UndirectedEdge[39, 82] -> 
             RGBColor[
              0.9892417368421053, 0.9746498421052632, 0.4741131578947366], 
             UndirectedEdge[109, 258] -> 
             RGBColor[
              0.6702321842105263, 0.7318353157894737, 0.7480264736842104], 
             UndirectedEdge[118, 199] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[57, 115] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[96, 222] -> 
             RGBColor[
              0.9499918684210527, 0.9180226315789473, 0.6476234999999999], 
             UndirectedEdge[6, 108] -> 
             RGBColor[
              0.9897543421052631, 0.9762497894736842, 0.5665088684210524], 
             UndirectedEdge[1, 9] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[180, 190] -> 
             RGBColor[
              0.8009307631578948, 0.7541997894736843, 0.6157449210526316], 
             UndirectedEdge[144, 253] -> 
             RGBColor[
              0.9659621842105264, 0.9711721052631579, 0.7710717105263156], 
             UndirectedEdge[53, 192] -> 
             RGBColor[
              0.9862522368421052, 0.9748015789473685, 0.6245478157894737], 
             UndirectedEdge[85, 121] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[36, 278] -> 
             RGBColor[
              0.7702536842105263, 0.8185084736842105, 0.9057713421052631], 
             UndirectedEdge[122, 207] -> 
             RGBColor[
              0.3924455789473684, 0.5143383684210527, 0.9462272631578947], 
             UndirectedEdge[226, 228] -> 
             RGBColor[
              0.8777851315789473, 0.5437977368421052, 0.5768133421052631], 
             UndirectedEdge[7, 143] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[133, 164] -> 
             RGBColor[
              0.44980226315789484`, 0.5613163157894738, 0.9506284210526316], 
             UndirectedEdge[7, 131] -> 
             RGBColor[
              0.9501674473684211, 0.8711324736842105, 0.6006356842105263], 
             UndirectedEdge[111, 280] -> 
             RGBColor[
              0.6677012631578948, 0.7389608421052631, 0.9684517368421053], 
             UndirectedEdge[135, 224] -> 
             RGBColor[
              0.8604202631578948, 0.8917762105263158, 0.9841867631578947], 
             UndirectedEdge[91, 102] -> 
             RGBColor[
              0.9911962105263157, 0.9906274210526316, 0.7955651052631578], 
             UndirectedEdge[200, 282] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[106, 194] -> 
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158], 
             UndirectedEdge[38, 259] -> 
             RGBColor[
              0.840996447368421, 0.7330905789473685, 0.608368552631579], 
             UndirectedEdge[36, 69] -> 
             RGBColor[
              0.7455322631578948, 0.8006531052631579, 0.9736736578947367], 
             UndirectedEdge[64, 153] -> 
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725], 
             UndirectedEdge[159, 175] -> 
             RGBColor[
              0.6272955263157896, 0.6902237105263158, 0.7454524999999999], 
             UndirectedEdge[94, 200] -> 
             RGBColor[
              0.508598157894737, 0.6086198421052633, 0.9555507894736842], 
             UndirectedEdge[88, 201] -> 
             RGBColor[
              0.9664747894736843, 0.972772052631579, 0.8634674210526314], 
             UndirectedEdge[121, 232] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[140, 289] -> 
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725], 
             UndirectedEdge[139, 244] -> 
             RGBColor[
              0.6425212631578947, 0.7141316842105263, 0.9663634473684211], 
             UndirectedEdge[167, 174] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[185, 282] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[236, 249] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[137, 299] -> 
             RGBColor[
              0.7163991052631579, 0.7729787368421053, 0.8433312368421051], 
             UndirectedEdge[201, 218] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[36, 109] -> 
             RGBColor[
              0.7732431842105263, 0.8183567368421053, 0.7553366842105261], 
             UndirectedEdge[4, 52] -> 
             RGBColor[0.6116091578947369, 0.6951412631578948, 0.962861], 
             UndirectedEdge[5, 191] -> 
             RGBColor[
              0.8325516842105263, 0.8672602105263159, 0.8526547631578946], 
             UndirectedEdge[55, 134] -> 
             RGBColor[0.7158865, 0.7713787894736842, 0.7509355263157893], 
             UndirectedEdge[67, 69] -> 
             RGBColor[
              0.9034786842105264, 0.9258075789473684, 0.9883739210526314], 
             UndirectedEdge[232, 256] -> 
             RGBColor[
              0.7264971578947369, 0.7862643684210526, 0.9733741052631579], 
             UndirectedEdge[185, 237] -> 
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158], 
             UndirectedEdge[28, 211] -> 
             RGBColor[
              0.9941857105263158, 0.9904756842105263, 0.6451304473684207], 
             UndirectedEdge[85, 246] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[26, 127] -> 
             RGBColor[0.6116091578947369, 0.6951412631578948, 0.962861], 
             UndirectedEdge[91, 162] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[112, 242] -> 
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578], 
             UndirectedEdge[85, 122] -> 
             RGBColor[
              0.6578348421052632, 0.7255525263157896, 0.9404415526315789], 
             UndirectedEdge[63, 131] -> 
             RGBColor[
              0.8009307631578948, 0.7541997894736843, 0.6157449210526316], 
             UndirectedEdge[140, 222] -> 
             RGBColor[
              0.6999161842105264, 0.7182293157894737, 0.6274873157894736], 
             UndirectedEdge[121, 256] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[171, 198] -> 
             RGBColor[
              0.6391238684210527, 0.6203748421052633, 0.6035123421052632], 
             UndirectedEdge[10, 117] -> 
             RGBColor[
              0.9311896052631579, 0.9435112105263158, 0.7700369473684209], 
             UndirectedEdge[18, 290] -> 
             RGBColor[
              0.8604202631578948, 0.8917762105263158, 0.9841867631578947], 
             UndirectedEdge[207, 240] -> 
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052], 
             UndirectedEdge[219, 264] -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             UndirectedEdge[78, 118] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[2, 208] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[34, 169] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[35, 275] -> 
             RGBColor[
              0.9911962105263157, 0.9906274210526316, 0.7955651052631578], 
             UndirectedEdge[157, 284] -> 
             RGBColor[
              0.6847781842105263, 0.6599183157894737, 0.6064213947368421], 
             UndirectedEdge[30, 259] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[62, 192] -> 
             RGBColor[0.9595752894736842, 0.877567, 0.5586552631578947], 
             UndirectedEdge[95, 245] -> 
             RGBColor[
              0.5646902631578948, 0.6524394210526316, 0.9611415263157894], 
             UndirectedEdge[129, 230] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[35, 92] -> 
             RGBColor[
              0.9435488684210527, 0.8126382105263159, 0.5456881578947369], 
             UndirectedEdge[186, 279] -> 
             RGBColor[0.6116091578947369, 0.6951412631578948, 0.962861], 
             UndirectedEdge[217, 233] -> 
             RGBColor[
              0.8851416842105263, 0.9096315789473685, 0.9162844473684211], 
             UndirectedEdge[28, 293] -> 
             RGBColor[
              0.9906836052631578, 0.9890274736842106, 0.703169394736842], 
             UndirectedEdge[24, 233] -> 
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158], 
             UndirectedEdge[41, 229] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[197, 214] -> 
             RGBColor[
              0.7608458421052632, 0.8120739473684211, 0.9477517631578947], 
             UndirectedEdge[84, 144] -> 
             RGBColor[
              0.9906836052631578, 0.9890274736842106, 0.703169394736842], 
             UndirectedEdge[101, 205] -> 
             RGBColor[
              0.8851416842105263, 0.9096315789473685, 0.9162844473684211], 
             UndirectedEdge[7, 297] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[30, 47] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[140, 298] -> 
             RGBColor[
              0.3924455789473684, 0.5143383684210527, 0.9462272631578947], 
             UndirectedEdge[159, 252] -> 
             RGBColor[
              0.6113252105263158, 0.6370742368421052, 0.6220042894736841], 
             UndirectedEdge[26, 195] -> 
             RGBColor[
              0.8325516842105263, 0.8672602105263159, 0.8526547631578946], 
             UndirectedEdge[43, 185] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[36, 95] -> 
             RGBColor[
              0.44980226315789484`, 0.5613163157894738, 0.9506284210526316], 
             UndirectedEdge[6, 46] -> 
             RGBColor[
              0.9615308157894737, 0.9569462105263158, 0.6924501315789473], 
             UndirectedEdge[148, 183] -> 
             RGBColor[
              0.8721608684210527, 0.8563303684210526, 0.6424015789473683], 
             UndirectedEdge[222, 261] -> 
             RGBColor[
              0.9152192894736842, 0.8903617368421053, 0.6465887368421052], 
             UndirectedEdge[64, 145] -> 
             RGBColor[
              0.5995846052631579, 0.6725200789473684, 0.9637894736842105], 
             UndirectedEdge[8, 247] -> 
             RGBColor[
              0.8325516842105263, 0.8672602105263159, 0.8526547631578946], 
             UndirectedEdge[122, 136] -> 
             RGBColor[
              0.6578348421052631, 0.7255525263157896, 0.9404415526315789], 
             UndirectedEdge[139, 206] -> 
             RGBColor[
              0.6672426842105263, 0.731987052631579, 0.8984611315789475], 
             UndirectedEdge[65, 80] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[171, 245] -> 
             RGBColor[
              0.8570228684210527, 0.7980193684210526, 0.6213356578947369], 
             UndirectedEdge[137, 232] -> 
             RGBColor[
              0.6103445789473685, 0.691982894736842, 0.9640505789473683], 
             UndirectedEdge[64, 221] -> 
             RGBColor[
              0.9664747894736843, 0.972772052631579, 0.8634674210526314], 
             UndirectedEdge[140, 263] -> 
             RGBColor[
              0.5542524736842105, 0.6481633157894737, 0.9584598421052631], 
             UndirectedEdge[200, 295] -> 
             RGBColor[
              0.7264971578947369, 0.7862643684210526, 0.9733741052631579], 
             UndirectedEdge[136, 232] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[45, 68] -> 
             RGBColor[
              0.918827447368421, 0.7947828421052632, 0.6135904736842105], 
             UndirectedEdge[224, 254] -> 
             RGBColor[
              0.9659621842105264, 0.9711721052631579, 0.7710717105263156], 
             UndirectedEdge[148, 272] -> 
             RGBColor[0.9747132894736842, 0.935878, 0.5797211842105263], 
             UndirectedEdge[167, 185] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[59, 137] -> 
             RGBColor[
              0.34950892105263154`, 0.47272676315789475`, 0.9436532894736842],
              UndirectedEdge[55, 97] -> 
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578], 
             UndirectedEdge[156, 202] -> 
             RGBColor[
              0.8160687631578948, 0.8125107894736843, 0.6368108421052631], 
             UndirectedEdge[78, 176] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[131, 143] -> 
             RGBColor[
              0.8009307631578948, 0.7541997894736843, 0.6157449210526316], 
             UndirectedEdge[230, 289] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[35, 126] -> 
             RGBColor[
              0.9911962105263157, 0.9906274210526316, 0.7955651052631578], 
             UndirectedEdge[147, 183] -> 
             RGBColor[
              0.8604202631578948, 0.8917762105263158, 0.9841867631578947], 
             UndirectedEdge[66, 258] -> 
             RGBColor[
              0.5646902631578948, 0.6524394210526316, 0.9611415263157894], 
             UndirectedEdge[60, 232] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[39, 127] -> 
             RGBColor[
              0.7732431842105263, 0.8183567368421053, 0.7553366842105261], 
             UndirectedEdge[113, 258] -> 
             RGBColor[
              0.6672426842105263, 0.731987052631579, 0.8984611315789475], 
             UndirectedEdge[45, 223] -> 
             RGBColor[
              0.9341410263157894, 0.8062036842105265, 0.5876685789473683], 
             UndirectedEdge[40, 80] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[18, 198] -> 
             RGBColor[
              0.6425212631578948, 0.7141316842105263, 0.9663634473684211], 
             UndirectedEdge[13, 58] -> 
             RGBColor[
              0.9311896052631579, 0.9435112105263158, 0.7700369473684209], 
             UndirectedEdge[16, 195] -> 
             RGBColor[
              0.9941857105263158, 0.9904756842105263, 0.6451304473684207], 
             UndirectedEdge[17, 90] -> 
             RGBColor[
              0.3924455789473684, 0.5143383684210527, 0.9462272631578947], 
             UndirectedEdge[8, 273] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[85, 256] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[149, 227] -> 
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052], 
             UndirectedEdge[182, 208] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[82, 100] -> 
             RGBColor[
              0.9267582368421052, 0.9292853157894737, 0.6914153684210526], 
             UndirectedEdge[227, 264] -> 
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725], 
             UndirectedEdge[74, 259] -> 
             RGBColor[
              0.5646902631578948, 0.6524394210526316, 0.9611415263157894], 
             UndirectedEdge[96, 105] -> 
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725], 
             UndirectedEdge[60, 100] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[73, 87] -> 
             RGBColor[
              0.7688118157894737, 0.8041308421052632, 0.6767151052631578], 
             UndirectedEdge[68, 223] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[162, 191] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[87, 149] -> 
             RGBColor[
              0.7107596842105264, 0.7729922105263158, 0.9726388947368421], 
             UndirectedEdge[60, 256] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[145, 169] -> 
             RGBColor[
              0.5995846052631579, 0.6725200789473684, 0.9637894736842105], 
             UndirectedEdge[144, 235] -> 
             RGBColor[
              0.5863000526315789, 0.6471348684210526, 0.7431178684210524], 
             UndirectedEdge[36, 88] -> 
             RGBColor[
              0.7455322631578948, 0.8006531052631579, 0.9736736578947367], 
             UndirectedEdge[38, 123] -> 
             RGBColor[
              0.918827447368421, 0.7947828421052632, 0.6135904736842105], 
             UndirectedEdge[183, 244] -> 
             RGBColor[
              0.8604202631578948, 0.8917762105263158, 0.9841867631578947], 
             UndirectedEdge[2, 32] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[106, 151] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[164, 277] -> 
             RGBColor[
              0.3924455789473684, 0.5143383684210527, 0.9462272631578947], 
             UndirectedEdge[296, 299] -> 
             RGBColor[
              0.7163991052631579, 0.7729787368421053, 0.8433312368421051], 
             UndirectedEdge[75, 174] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[31, 66] -> 
             RGBColor[
              0.8851416842105263, 0.9096315789473685, 0.9162844473684211], 
             UndirectedEdge[2, 268] -> 
             RGBColor[
              0.8325516842105263, 0.8672602105263159, 0.8526547631578946], 
             UndirectedEdge[46, 264] -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             UndirectedEdge[71, 160] -> 
             RGBColor[
              0.9317022105263157, 0.9451111578947369, 0.8624326578947367], 
             UndirectedEdge[50, 114] -> 
             RGBColor[
              0.918827447368421, 0.7947828421052632, 0.6135904736842105], 
             UndirectedEdge[126, 197] -> 
             RGBColor[
              0.7737557894736842, 0.8199566842105264, 0.8477323947368419], 
             UndirectedEdge[265, 269] -> 
             RGBColor[
              0.9664747894736843, 0.972772052631579, 0.8634674210526314], 
             UndirectedEdge[144, 257] -> 
             RGBColor[
              0.9659621842105264, 0.9711721052631579, 0.7710717105263156], 
             UndirectedEdge[86, 107] -> 
             RGBColor[
              0.8851416842105263, 0.9096315789473685, 0.9162844473684211], 
             UndirectedEdge[149, 245] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[143, 283] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[66, 154] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[57, 159] -> 
             RGBColor[
              0.6243060263157895, 0.6903754473684212, 0.8958871578947369], 
             UndirectedEdge[7, 167] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[57, 89] -> 
             RGBColor[
              0.9906836052631578, 0.9890274736842106, 0.703169394736842], 
             UndirectedEdge[122, 256] -> 
             RGBColor[
              0.508598157894737, 0.6086198421052633, 0.9555507894736842], 
             UndirectedEdge[39, 232] -> 
             RGBColor[
              0.8881311842105264, 0.9094798421052632, 0.765849789473684], 
             UndirectedEdge[72, 286] -> 
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052], 
             UndirectedEdge[71, 299] -> 
             RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947365], 
             UndirectedEdge[90, 158] -> 
             RGBColor[
              0.6578348421052631, 0.7255525263157896, 0.9404415526315789], 
             UndirectedEdge[52, 236] -> 
             RGBColor[0.6116091578947369, 0.6951412631578948, 0.962861], 
             UndirectedEdge[17, 134] -> 
             RGBColor[0.7158865, 0.7713787894736842, 0.7509355263157893], 
             UndirectedEdge[54, 72] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[170, 192] -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 
             UndirectedEdge[140, 198] -> 
             RGBColor[
              0.3924455789473684, 0.5143383684210527, 0.9462272631578947], 
             UndirectedEdge[19, 89] -> 
             RGBColor[
              0.9311896052631579, 0.9435112105263158, 0.7700369473684209], 
             UndirectedEdge[239, 295] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[51, 69] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[186, 269] -> 
             RGBColor[
              0.8043281578947369, 0.8479566315789474, 0.9785960263157893], 
             UndirectedEdge[37, 282] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[1, 239] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[59, 200] -> 
             RGBColor[
              0.46566150000000006`, 0.5670082368421053, 0.9529768157894737], 
             UndirectedEdge[145, 221] -> 
             RGBColor[
              0.6278081315789474, 0.6918236578947369, 0.8378482105263156], 
             UndirectedEdge[75, 297] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[142, 185] -> 
             RGBColor[
              0.8325516842105263, 0.8672602105263159, 0.8526547631578946], 
             UndirectedEdge[36, 258] -> 
             RGBColor[
              0.44980226315789484`, 0.5613163157894738, 0.9506284210526316], 
             UndirectedEdge[13, 289] -> 
             RGBColor[
              0.9659621842105264, 0.9711721052631579, 0.7710717105263156], 
             UndirectedEdge[53, 170] -> 
             RGBColor[
              0.9862522368421052, 0.9748015789473685, 0.6245478157894737], 
             UndirectedEdge[130, 226] -> 
             RGBColor[
              0.7999541315789473, 0.48210547368421053`, 0.5715914210526316], 
             UndirectedEdge[224, 249] -> 
             RGBColor[
              0.9034786842105264, 0.9258075789473684, 0.9883739210526314], 
             UndirectedEdge[234, 271] -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             UndirectedEdge[78, 266] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[127, 232] -> 
             RGBColor[
              0.6677012631578948, 0.7389608421052631, 0.9684517368421053], 
             UndirectedEdge[57, 292] -> 
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158], 
             UndirectedEdge[52, 107] -> 
             RGBColor[
              0.6677012631578948, 0.7389608421052631, 0.9684517368421053], 
             UndirectedEdge[26, 130] -> 
             RGBColor[
              0.7264971578947369, 0.7862643684210526, 0.9733741052631579], 
             UndirectedEdge[51, 58] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[192, 195] -> 
             RGBColor[
              0.9911962105263157, 0.9906274210526316, 0.7955651052631578], 
             UndirectedEdge[118, 266] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[171, 289] -> 
             RGBColor[
              0.9348538684210527, 0.8597116315789474, 0.6265575789473683], 
             UndirectedEdge[1, 283] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[44, 59] -> 
             RGBColor[
              0.46566150000000006`, 0.5670082368421053, 0.9529768157894737], 
             UndirectedEdge[62, 127] -> 
             RGBColor[
              0.7421348684210527, 0.7068962631578948, 0.6108225526315789], 
             UndirectedEdge[46, 219] -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             UndirectedEdge[55, 252] -> 
             RGBColor[
              0.6999161842105264, 0.7182293157894737, 0.6274873157894736], 
             UndirectedEdge[55, 144] -> 
             RGBColor[0.7158865, 0.7713787894736842, 0.7509355263157893], 
             UndirectedEdge[160, 296] -> 
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052], 
             UndirectedEdge[154, 179] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[6, 145] -> 
             RGBColor[
              0.6228641578947368, 0.6759978157894737, 0.6668309210526315], 
             UndirectedEdge[132, 243] -> 
             RGBColor[
              0.9862522368421052, 0.9748015789473685, 0.6245478157894737], 
             UndirectedEdge[53, 59] -> 
             RGBColor[
              0.6228641578947368, 0.6759978157894737, 0.6668309210526315], 
             UndirectedEdge[4, 228] -> 
             RGBColor[
              0.8043281578947369, 0.8479566315789474, 0.9785960263157893], 
             UndirectedEdge[71, 98] -> 
             RGBColor[
              0.8886437894736843, 0.9110797894736842, 0.8582454999999998], 
             UndirectedEdge[201, 259] -> 
             RGBColor[
              0.8886437894736843, 0.9110797894736842, 0.8582454999999998], 
             UndirectedEdge[34, 187] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[18, 260] -> 
             RGBColor[
              0.8604202631578948, 0.8917762105263158, 0.9841867631578947], 
             UndirectedEdge[263, 289] -> 
             RGBColor[
              0.8043281578947369, 0.8479566315789474, 0.9785960263157893], 
             UndirectedEdge[173, 209] -> 
             RGBColor[
              0.9060086578947368, 0.5631013157894738, 0.45087207894736825`], 
             UndirectedEdge[4, 199] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[253, 292] -> 
             RGBColor[
              0.8043281578947369, 0.8479566315789474, 0.9785960263157893], 
             UndirectedEdge[128, 209] -> 
             RGBColor[
              0.6850661315789475, 0.39098236842105266`, 0.5610783157894736], 
             UndirectedEdge[44, 137] -> 
             RGBColor[
              0.5542524736842105, 0.6481633157894737, 0.9584598421052631], 
             UndirectedEdge[129, 263] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[73, 289] -> 
             RGBColor[
              0.9615308157894737, 0.9569462105263158, 0.6924501315789473], 
             UndirectedEdge[128, 276] -> 
             RGBColor[
              0.7608458421052632, 0.8120739473684211, 0.9477517631578947], 
             UndirectedEdge[96, 196] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[24, 224] -> 
             RGBColor[
              0.8043281578947369, 0.8479566315789474, 0.9785960263157893], 
             UndirectedEdge[88, 278] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[158, 253] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[67, 110] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[155, 275] -> 
             RGBColor[
              0.9664747894736843, 0.972772052631579, 0.8634674210526314], 
             UndirectedEdge[101, 108] -> 
             RGBColor[
              0.8886437894736843, 0.9110797894736842, 0.8582454999999998], 
             UndirectedEdge[102, 210] -> 
             RGBColor[
              0.9911962105263157, 0.9906274210526316, 0.7955651052631578], 
             UndirectedEdge[176, 199] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[62, 226] -> 
             RGBColor[
              0.8743877368421054, 0.4500408947368421, 0.21396223684210525`], 
             UndirectedEdge[69, 113] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[51, 258] -> 
             RGBColor[
              0.6578348421052632, 0.7255525263157896, 0.9404415526315789], 
             UndirectedEdge[30, 74] -> 
             RGBColor[
              0.6077486842105264, 0.6864707894736843, 0.9653286842105263], 
             UndirectedEdge[118, 228] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[71, 121] -> 
             RGBColor[
              0.9317022105263157, 0.9451111578947369, 0.8624326578947367], 
             UndirectedEdge[1, 20] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[126, 293] -> 
             RGBColor[
              0.9911962105263157, 0.9906274210526316, 0.7955651052631578], 
             UndirectedEdge[112, 159] -> 
             RGBColor[
              0.6148981842105263, 0.6839409210526316, 0.9378675789473684], 
             UndirectedEdge[17, 159] -> 
             RGBColor[
              0.34950892105263154`, 0.47272676315789475`, 0.9436532894736842],
              UndirectedEdge[139, 172] -> 
             RGBColor[
              0.508598157894737, 0.6086198421052633, 0.9555507894736842], 
             UndirectedEdge[47, 233] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[98, 182] -> 
             RGBColor[
              0.8851416842105263, 0.9096315789473685, 0.9162844473684211], 
             UndirectedEdge[84, 159] -> 
             RGBColor[
              0.6243060263157895, 0.6903754473684212, 0.8958871578947369], 
             UndirectedEdge[118, 176] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[18, 278] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[155, 197] -> 
             RGBColor[
              0.7455322631578948, 0.8006531052631579, 0.9736736578947367], 
             UndirectedEdge[72, 215] -> 
             RGBColor[
              0.9000812894736843, 0.8320507368421053, 0.6255228157894737], 
             UndirectedEdge[162, 239] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[139, 272] -> 
             RGBColor[
              0.6672426842105263, 0.731987052631579, 0.8984611315789475], 
             UndirectedEdge[9, 75] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[18, 254] -> 
             RGBColor[
              0.9659621842105264, 0.9711721052631579, 0.7710717105263156], 
             UndirectedEdge[25, 244] -> 
             RGBColor[
              0.9348538684210527, 0.8597116315789474, 0.6265575789473683], 
             UndirectedEdge[30, 257] -> 
             RGBColor[
              0.9034786842105264, 0.9258075789473684, 0.9883739210526314], 
             UndirectedEdge[29, 270] -> 
             RGBColor[
              0.5868126578947368, 0.6487348157894737, 0.8355135789473682], 
             UndirectedEdge[73, 298] -> 
             RGBColor[
              0.6658008157894737, 0.7176094210526316, 0.6694048947368421], 
             UndirectedEdge[73, 96] -> 
             RGBColor[
              0.9615308157894737, 0.9569462105263158, 0.6924501315789473], 
             UndirectedEdge[108, 205] -> 
             RGBColor[
              0.9911962105263157, 0.9906274210526316, 0.7955651052631578], 
             UndirectedEdge[9, 43] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[151, 251] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[209, 279] -> 
             RGBColor[
              0.6850661315789475, 0.39098236842105266`, 0.5610783157894736], 
             UndirectedEdge[53, 68] -> 
             RGBColor[
              0.9615308157894737, 0.9569462105263158, 0.6924501315789473], 
             UndirectedEdge[282, 295] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[35, 197] -> 
             RGBColor[
              0.7702536842105263, 0.8185084736842105, 0.9057713421052631], 
             UndirectedEdge[116, 168] -> 
             RGBColor[
              0.9034786842105264, 0.9258075789473684, 0.9883739210526314], 
             UndirectedEdge[27, 152] -> 
             RGBColor[0.6116091578947369, 0.6951412631578948, 0.962861], 
             UndirectedEdge[114, 231] -> 
             RGBColor[
              0.8604202631578948, 0.8917762105263158, 0.9841867631578947], 
             UndirectedEdge[83, 155] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[62, 199] -> 
             RGBColor[
              0.9501674473684211, 0.8711324736842105, 0.6006356842105263], 
             UndirectedEdge[96, 278] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[2, 178] -> 
             RGBColor[
              0.8325516842105263, 0.8672602105263159, 0.8526547631578946], 
             UndirectedEdge[6, 213] -> 
             RGBColor[
              0.9862522368421052, 0.9748015789473685, 0.6245478157894737], 
             UndirectedEdge[79, 93] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[270, 272] -> 
             RGBColor[
              0.5833105526315789, 0.6472866052631578, 0.8935525263157895], 
             UndirectedEdge[161, 186] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[189, 275] -> 
             RGBColor[
              0.7163991052631579, 0.7729787368421053, 0.8433312368421051], 
             UndirectedEdge[260, 261] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[195, 200] -> 
             RGBColor[
              0.8325516842105263, 0.8672602105263159, 0.8526547631578946], 
             UndirectedEdge[66, 110] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[63, 172] -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 
             UndirectedEdge[4, 236] -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 
             UndirectedEdge[143, 167] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[135, 249] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[135, 288] -> 
             RGBColor[
              0.4807581315789474, 0.5677389736842106, 0.9562329210526316], 
             UndirectedEdge[83, 214] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[36, 290] -> 
             RGBColor[
              0.6677012631578948, 0.7389608421052631, 0.9684517368421053], 
             UndirectedEdge[79, 119] -> 
             RGBColor[
              0.6578348421052632, 0.7255525263157896, 0.9404415526315789], 
             UndirectedEdge[145, 264] -> 
             RGBColor[
              0.5995846052631579, 0.6725200789473684, 0.9637894736842105], 
             UndirectedEdge[54, 238] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[177, 273] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[98, 208] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[125, 170] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[22, 217] -> 
             RGBColor[
              0.8757338421052632, 0.9031970526315789, 0.9582648684210526], 
             UndirectedEdge[78, 236] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[86, 240] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[59, 170] -> 
             RGBColor[
              0.6243060263157894, 0.6903754473684212, 0.8958871578947369], 
             UndirectedEdge[95, 109] -> 
             RGBColor[
              0.6702321842105263, 0.7318353157894737, 0.7480264736842104], 
             UndirectedEdge[30, 252] -> 
             RGBColor[
              0.9152192894736842, 0.8903617368421053, 0.6465887368421052], 
             UndirectedEdge[116, 119] -> 
             RGBColor[
              0.6425212631578948, 0.7141316842105263, 0.9663634473684211], 
             UndirectedEdge[6, 231] -> 
             RGBColor[
              0.8836998157894738, 0.8952539473684211, 0.6872282105263157], 
             UndirectedEdge[214, 275] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[157, 257] -> 
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725], 
             UndirectedEdge[128, 173] -> 
             RGBColor[
              0.7737557894736842, 0.8199566842105264, 0.8477323947368419], 
             UndirectedEdge[14, 113] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[213, 231] -> 
             RGBColor[
              0.8851416842105263, 0.9096315789473685, 0.9162844473684211], 
             UndirectedEdge[29, 148] -> 
             RGBColor[
              0.9782153947368422, 0.9373262105263158, 0.521682236842105], 
             UndirectedEdge[109, 154] -> 
             RGBColor[
              0.9311896052631579, 0.9435112105263158, 0.7700369473684209], 
             UndirectedEdge[74, 123] -> 
             RGBColor[
              0.6425212631578947, 0.7141316842105263, 0.9663634473684211], 
             UndirectedEdge[189, 216] -> 
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052], 
             UndirectedEdge[29, 162] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[73, 140] -> 
             RGBColor[
              0.7114551315789474, 0.7571528947368421, 0.672313947368421], 
             UndirectedEdge[9, 295] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[169, 221] -> 
             RGBColor[
              0.9664747894736843, 0.972772052631579, 0.8634674210526314], 
             UndirectedEdge[22, 61] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[11, 143] -> 
             RGBColor[
              0.508598157894737, 0.6086198421052633, 0.9555507894736842], 
             UndirectedEdge[100, 299] -> 
             RGBColor[
              0.9317022105263157, 0.9451111578947369, 0.8624326578947367], 
             UndirectedEdge[181, 232] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[49, 292] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[4, 39] -> 
             RGBColor[
              0.8320390789473684, 0.8656602631578948, 0.7602590526315788], 
             UndirectedEdge[33, 75] -> 
             RGBColor[
              0.6077486842105264, 0.6864707894736843, 0.9653286842105263], 
             UndirectedEdge[223, 271] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[21, 34] -> 
             RGBColor[
              0.8196417368421053, 0.8593774736842106, 0.9526741315789473], 
             UndirectedEdge[51, 165] -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 
             UndirectedEdge[36, 138] -> 
             RGBColor[
              0.7455322631578948, 0.8006531052631579, 0.9736736578947367], 
             UndirectedEdge[50, 205] -> 
             RGBColor[
              0.9435488684210527, 0.8126382105263159, 0.5456881578947369], 
             UndirectedEdge[237, 283] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[140, 245] -> 
             RGBColor[
              0.6103445789473685, 0.691982894736842, 0.9640505789473683], 
             UndirectedEdge[19, 49] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[235, 292] -> 
             RGBColor[
              0.42466602631578954`, 0.5239193947368421, 0.9506421842105264], 
             UndirectedEdge[15, 115] -> 
             RGBColor[
              0.9034786842105264, 0.9258075789473684, 0.9883739210526314], 
             UndirectedEdge[69, 110] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[34, 50] -> 
             RGBColor[
              0.9341410263157894, 0.8062036842105265, 0.5876685789473683], 
             UndirectedEdge[126, 275] -> 
             RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947365], 
             UndirectedEdge[59, 225] -> 
             RGBColor[
              0.6148981842105263, 0.6839409210526316, 0.9378675789473684], 
             UndirectedEdge[82, 228] -> 
             RGBColor[
              0.9615308157894737, 0.9569462105263158, 0.6924501315789473], 
             UndirectedEdge[19, 280] -> 
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152], 
             UndirectedEdge[194, 283] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[63, 283] -> 
             RGBColor[
              0.7695555789473685, 0.8202957368421053, 0.9775612631578947], 
             UndirectedEdge[36, 245] -> 
             RGBColor[
              0.6677012631578948, 0.7389608421052631, 0.9684517368421053], 
             UndirectedEdge[3, 55] -> 
             RGBColor[
              0.5542524736842105, 0.6481633157894737, 0.9584598421052631], 
             UndirectedEdge[137, 192] -> 
             RGBColor[
              0.7128969999999999, 0.7715305263157894, 0.9013701842105264], 
             UndirectedEdge[54, 251] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[252, 292] -> 
             RGBColor[
              0.8160687631578948, 0.8125107894736843, 0.6368108421052631], 
             UndirectedEdge[100, 121] -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 
             UndirectedEdge[142, 239] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[85, 299] -> 
             RGBColor[
              0.9817883684210527, 0.9841928947368421, 0.8375455263157893], 
             UndirectedEdge[120, 130] -> 
             RGBColor[
              0.7264971578947369, 0.7862643684210526, 0.9733741052631579], 
             UndirectedEdge[9, 297] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[237, 239] -> 
             RGBColor[
              0.9782862631578947, 0.9827446842105263, 0.8955844736842105], 
             UndirectedEdge[169, 213] -> 
             RGBColor[
              0.9629726842105263, 0.9713238421052632, 0.9215063684210526], 
             UndirectedEdge[46, 50] -> 
             RGBColor[
              0.918827447368421, 0.7947828421052632, 0.6135904736842105], 
             UndirectedEdge[105, 171] -> 
             RGBColor[
              0.6847781842105263, 0.6599183157894737, 0.6064213947368421], 
             UndirectedEdge[34, 114] -> 
             RGBColor[
              0.9535648421052632, 0.9648893157894737, 0.963486789473684], 
             UndirectedEdge[60, 240] -> 
             RGBColor[
              0.9187922631578948, 0.9372284210526316, 0.9624520263157894], 
             UndirectedEdge[19, 84] -> 
             RGBColor[
              0.9282001052631579, 0.943662947368421, 0.9204716052631579], 
             UndirectedEdge[19, 48] -> 
             RGBColor[
              0.6077486842105264, 0.6864707894736843, 0.9653286842105263], 
             UndirectedEdge[5, 77] -> 
             RGBColor[
              0.9911962105263157, 0.9906274210526316, 0.7955651052631578]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.26091794736842105`, 0.39157168421052635`, 0.9381702631578948],
              160 -> RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 245 -> 
             RGBColor[
              0.7825892631578948, 0.8300839473684211, 0.9789648421052631], 
             155 -> RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             213 -> RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 27 -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 19 -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 164 -> 
             RGBColor[
              0.3467912631578948, 0.4747948947368422, 0.9433182105263158], 
             190 -> RGBColor[
              0.9314564736842106, 0.7659547894736842, 0.2637064736842105], 
             103 -> RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 138 -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             291 -> RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947365], 
             28 -> 
             RGBColor[
              0.9936731052631579, 0.9888757368421053, 0.552734736842105], 114 -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             195 -> RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947365], 93 -> 
             RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947365], 34 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 161 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 22 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 124 -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 84 -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 46 -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             241 -> RGBColor[
              0.7825892631578948, 0.8300839473684211, 0.9789648421052631], 
             185 -> RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 121 -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 126 -> 
             RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947365], 
             236 -> RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 78 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 254 -> 
             RGBColor[
              0.9936731052631579, 0.9888757368421053, 0.552734736842105], 290 -> 
             RGBColor[
              0.7825892631578948, 0.8300839473684211, 0.9789648421052631], 
             251 -> RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 165 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 100 -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 235 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 70 -> 
             RGBColor[
              0.4380998947368421, 0.5538818421052631, 0.9491363157894737], 
             234 -> RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             257 -> RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             135 -> 
             RGBColor[
              0.7825892631578948, 0.8300839473684211, 0.9789648421052631], 
             265 -> RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947365], 
             111 -> RGBColor[
              0.5528132631578948, 0.6478377368421053, 0.9579386315789473], 
             182 -> RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 188 -> 
             RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947365], 
             154 -> RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 269 -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             208 -> RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 86 -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 119 -> 
             RGBColor[
              0.3467912631578948, 0.4747948947368422, 0.9433182105263158], 
             140 -> RGBColor[
              0.4380998947368421, 0.5538818421052631, 0.9491363157894737], 85 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 242 -> 
             RGBColor[
              0.4380998947368421, 0.5538818421052631, 0.9491363157894737], 
             117 -> RGBColor[
              0.9936731052631579, 0.9888757368421053, 0.552734736842105], 47 -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 81 -> 
             RGBColor[
              0.4380998947368421, 0.5538818421052631, 0.9491363157894737], 
             275 -> RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947365], 23 -> 
             RGBColor[
              0.9314564736842106, 0.7659547894736842, 0.2637064736842105], 
             110 -> RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 6 -> 
             RGBColor[
              0.9848103684210526, 0.9604239473684211, 0.3954915789473683], 
             218 -> RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 108 -> 
             RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947365], 
             297 -> RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 157 -> 
             RGBColor[
              0.4380998947368421, 0.5538818421052631, 0.9491363157894737], 
             270 -> RGBColor[0.178927, 0.305394, 0.933501], 33 -> 
             RGBColor[
              0.3467912631578948, 0.4747948947368422, 0.9433182105263158], 
             252 -> RGBColor[
              0.9617324736842106, 0.8825767894736841, 0.3058383157894735], 
             260 -> RGBColor[
              0.7825892631578948, 0.8300839473684211, 0.9789648421052631], 
             159 -> RGBColor[
              0.26091794736842105`, 0.39157168421052635`, 0.9381702631578948],
              183 -> RGBColor[
              0.7825892631578948, 0.8300839473684211, 0.9789648421052631], 99 -> 
             RGBColor[
              0.4380998947368421, 0.5538818421052631, 0.9491363157894737], 17 -> 
             RGBColor[
              0.4380998947368421, 0.5538818421052631, 0.9491363157894737], 
             277 -> RGBColor[
              0.4380998947368421, 0.5538818421052631, 0.9491363157894737], 
             104 -> RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 79 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 191 -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 50 -> 
             RGBColor[
              0.8994036315789474, 0.636097210526316, 0.2377722631578948], 225 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 61 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 196 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 1 -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 263 -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 201 -> 
             RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947365], 
             293 -> RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 184 -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             106 -> RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 206 -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 247 -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 220 -> 
             RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947365], 
             107 -> RGBColor[
              0.7825892631578948, 0.8300839473684211, 0.9789648421052631], 
             131 -> 
             RGBColor[
              0.9314564736842106, 0.7659547894736842, 0.2637064736842105], 
             127 -> RGBColor[
              0.5528132631578948, 0.6478377368421053, 0.9579386315789473], 
             210 -> RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947365], 
             181 -> RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 194 -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 118 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 276 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 280 -> 
             RGBColor[
              0.7825892631578948, 0.8300839473684211, 0.9789648421052631], 
             189 -> RGBColor[
              0.4380998947368421, 0.5538818421052631, 0.9491363157894737], 
             168 -> RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 41 -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 14 -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 77 -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 51 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 179 -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 223 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 292 -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 143 -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 112 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 197 -> 
             RGBColor[
              0.5528132631578948, 0.6478377368421053, 0.9579386315789473], 54 -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 71 -> 
             RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947365], 
             177 -> RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 158 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 226 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 203 -> 
             RGBColor[
              0.9848103684210526, 0.9604239473684211, 0.3954915789473683], 
             115 -> RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             173 -> RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947365], 
             212 -> RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 129 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 279 -> 
             RGBColor[
              0.5528132631578948, 0.6478377368421053, 0.9579386315789473], 26 -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 40 -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 146 -> 
             RGBColor[
              0.5528132631578948, 0.6478377368421053, 0.9579386315789473], 
             192 -> RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 300 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 221 -> 
             RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947365], 62 -> 
             RGBColor[
              0.9314564736842106, 0.7659547894736842, 0.2637064736842105], 
             286 -> RGBColor[
              0.4380998947368421, 0.5538818421052631, 0.9491363157894737], 
             152 -> RGBColor[
              0.5528132631578948, 0.6478377368421053, 0.9579386315789473], 64 -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 37 -> 
             RGBColor[
              0.7825892631578948, 0.8300839473684211, 0.9789648421052631], 
             148 -> RGBColor[
              0.9617324736842106, 0.8825767894736841, 0.3058383157894735], 
             261 -> RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 15 -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 136 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 198 -> 
             RGBColor[
              0.3467912631578948, 0.4747948947368422, 0.9433182105263158], 63 -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 171 -> 
             RGBColor[
              0.9314564736842106, 0.7659547894736842, 0.2637064736842105], 59 -> 
             RGBColor[
              0.26091794736842105`, 0.39157168421052635`, 0.9381702631578948],
              229 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 102 -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 299 -> 
             RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947365], 
             128 -> RGBColor[
              0.5528132631578948, 0.6478377368421053, 0.9579386315789473], 12 -> 
             RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947365], 
             222 -> RGBColor[
              0.9617324736842106, 0.8825767894736841, 0.3058383157894735], 92 -> 
             RGBColor[
              0.8994036315789474, 0.636097210526316, 0.2377722631578948], 271 -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             132 -> RGBColor[
              0.9848103684210526, 0.9604239473684211, 0.3954915789473683], 80 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 244 -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             150 -> RGBColor[
              0.9848103684210526, 0.9604239473684211, 0.3954915789473683], 
             125 -> RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 133 -> 
             RGBColor[
              0.5528132631578948, 0.6478377368421053, 0.9579386315789473], 
             258 -> RGBColor[
              0.3467912631578948, 0.4747948947368422, 0.9433182105263158], 
             255 -> RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 176 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 230 -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 274 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 87 -> 
             RGBColor[
              0.5528132631578948, 0.6478377368421053, 0.9579386315789473], 
             130 -> RGBColor[
              0.7825892631578948, 0.8300839473684211, 0.9789648421052631], 35 -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 31 -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 18 -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 24 -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 151 -> R\
GBColor[0.868706105263158, 0.8981466842105263, 0.9873391578947368], 137 -> 
             RGBColor[
              0.4380998947368421, 0.5538818421052631, 0.9491363157894737], 
             296 -> RGBColor[
              0.4380998947368421, 0.5538818421052631, 0.9491363157894737], 
             266 -> RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 283 -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 284 -> 
             RGBColor[
              0.9314564736842106, 0.7659547894736842, 0.2637064736842105], 
             238 -> RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 72 -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 288 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 172 -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 243 -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 88 -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             273 -> RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 202 -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 98 -> 
             RGBColor[
              0.7825892631578948, 0.8300839473684211, 0.9789648421052631], 30 -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 116 -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             240 -> RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 73 -> 
             RGBColor[
              0.9848103684210526, 0.9604239473684211, 0.3954915789473683], 29 -> 
             RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947365], 75 -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 200 -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 156 -> 
             RGBColor[
              0.9617324736842106, 0.8825767894736841, 0.3058383157894735], 25 -> 
             RGBColor[
              0.9314564736842106, 0.7659547894736842, 0.2637064736842105], 38 -> 
             RGBColor[
              0.8994036315789474, 0.636097210526316, 0.2377722631578948], 3 -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 57 -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 227 -> 
             RGBColor[
              0.4380998947368421, 0.5538818421052631, 0.9491363157894737], 39 -> 
             RGBColor[
              0.9936731052631579, 0.9888757368421053, 0.552734736842105], 109 -> 
             RGBColor[
              0.9936731052631579, 0.9888757368421053, 0.552734736842105], 256 -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 287 -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             239 -> RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 285 -> 
             RGBColor[
              0.9314564736842106, 0.7659547894736842, 0.2637064736842105], 
             216 -> RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 21 -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 175 -> 
             RGBColor[
              0.9936731052631579, 0.9888757368421053, 0.552734736842105], 7 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 13 -> 
             RGBColor[
              0.9936731052631579, 0.9888757368421053, 0.552734736842105], 294 -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 193 -> 
             RGBColor[
              0.4380998947368421, 0.5538818421052631, 0.9491363157894737], 60 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 65 -> 
             RGBColor[
              0.7825892631578948, 0.8300839473684211, 0.9789648421052631], 69 -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             217 -> RGBColor[
              0.7825892631578948, 0.8300839473684211, 0.9789648421052631], 
             214 -> RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 170 -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 74 -> 
             RGBColor[
              0.3467912631578948, 0.4747948947368422, 0.9433182105263158], 
             246 -> RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 264 -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             278 -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 45 -> 
             RGBColor[
              0.8994036315789474, 0.636097210526316, 0.2377722631578948], 237 -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 228 -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             180 -> RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 53 -> 
             RGBColor[
              0.9848103684210526, 0.9604239473684211, 0.3954915789473683], 48 -> 
             RGBColor[
              0.3467912631578948, 0.4747948947368422, 0.9433182105263158], 5 -> 
             RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947365], 
             101 -> RGBColor[
              0.7825892631578948, 0.8300839473684211, 0.9789648421052631], 
             267 -> RGBColor[
              0.9936731052631579, 0.9888757368421053, 0.552734736842105], 120 -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 147 -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 89 -> 
             RGBColor[
              0.9936731052631579, 0.9888757368421053, 0.552734736842105], 43 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 199 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 268 -> 
             RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947365], 
             169 -> RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 20 -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 4 -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 167 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 142 -> 
             RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947365], 16 -> 
             RGBColor[
              0.9936731052631579, 0.9888757368421053, 0.552734736842105], 281 -> 
             RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947365], 
             289 -> RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             178 -> RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947365], 58 -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 186 -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 122 -> 
             RGBColor[
              0.3467912631578948, 0.4747948947368422, 0.9433182105263158], 
             249 -> RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 113 -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 52 -> 
             RGBColor[
              0.5528132631578948, 0.6478377368421053, 0.9579386315789473], 
             187 -> RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             259 -> RGBColor[
              0.7825892631578948, 0.8300839473684211, 0.9789648421052631], 42 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 134 -> 
             RGBColor[
              0.9936731052631579, 0.9888757368421053, 0.552734736842105], 248 -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             174 -> RGBColor[
              0.7825892631578948, 0.8300839473684211, 0.9789648421052631], 
             215 -> RGBColor[
              0.9314564736842106, 0.7659547894736842, 0.2637064736842105], 83 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 95 -> 
             RGBColor[
              0.3467912631578948, 0.4747948947368422, 0.9433182105263158], 
             166 -> RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 233 -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 295 -> 
             RGBColor[
              0.7825892631578948, 0.8300839473684211, 0.9789648421052631], 
             141 -> RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 205 -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 224 -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 
             231 -> RGBColor[
              0.7825892631578948, 0.8300839473684211, 0.9789648421052631], 68 -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 10 -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 250 -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 282 -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 232 -> 
             RGBColor[
              0.7825892631578948, 0.8300839473684211, 0.9789648421052631], 
             253 -> RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 55 -> 
             RGBColor[
              0.4380998947368421, 0.5538818421052631, 0.9491363157894737], 91 -> 
             RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947365], 
             105 -> RGBColor[
              0.4380998947368421, 0.5538818421052631, 0.9491363157894737], 36 -> 
             RGBColor[
              0.5528132631578948, 0.6478377368421053, 0.9579386315789473], 
             123 -> RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 94 -> 
             RGBColor[
              0.3467912631578948, 0.4747948947368422, 0.9433182105263158], 96 -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 2 -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 262 -> 
             RGBColor[
              0.9936731052631579, 0.9888757368421053, 0.552734736842105], 272 -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 97 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 209 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 66 -> 
             RGBColor[
              0.7825892631578948, 0.8300839473684211, 0.9789648421052631], 
             139 -> RGBColor[
              0.3467912631578948, 0.4747948947368422, 0.9433182105263158], 56 -> 
             RGBColor[
              0.9876941052631578, 0.9891792105263159, 0.853604052631579], 144 -> 
             RGBColor[
              0.9936731052631579, 0.9888757368421053, 0.552734736842105], 298 -> 
             RGBColor[
              0.3467912631578948, 0.4747948947368422, 0.9433182105263158], 
             204 -> RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 207 -> 
             RGBColor[
              0.4380998947368421, 0.5538818421052631, 0.9491363157894737], 
             149 -> RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 219 -> 
             RGBColor[
              0.9382512631578948, 0.9534684736842105, 0.9894086842105262], 9 -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 11 -> 
             RGBColor[
              0.3467912631578948, 0.4747948947368422, 0.9433182105263158], 44 -> 
             RGBColor[
              0.670405052631579, 0.7424447894736843, 0.9677833684210526], 153 -> 
             RGBColor[
              0.4380998947368421, 0.5538818421052631, 0.9491363157894737], 32 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 162 -> 
             RGBColor[
              0.9688784210526316, 0.9763101578947369, 0.937564894736842], 90 -> 
             RGBColor[
              0.3467912631578948, 0.4747948947368422, 0.9433182105263158], 8 -> 
             RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947365], 
             163 -> RGBColor[
              0.7825892631578948, 0.8300839473684211, 0.9789648421052631], 49 -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 76 -> 
             RGBColor[
              0.9946983157894737, 0.9920756315789474, 0.7375261578947365], 82 -> 
             RGBColor[
              0.9848103684210526, 0.9604239473684211, 0.3954915789473683], 67 -> 
             RGBColor[
              0.868706105263158, 0.8981466842105263, 0.9873391578947368], 211 -> 
             RGBColor[
              0.9946983157894737, 0.9920756315789474, 
               0.7375261578947365]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9mHk4FFzYxsmSfR/LzGBWM2NmbHmlLHNH8aZCu0SWIkQLqbSgomQtVNoX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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 9}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 11}], {
             RGBColor[
             0.6077486842105264, 0.6864707894736843, 0.9653286842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 20}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 37}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 43}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 75}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 102}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 142}], {
             RGBColor[
             0.9317022105263157, 0.9451111578947369, 0.8624326578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 143}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 174}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 185}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 237}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 239}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 283}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 295}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 297}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 32}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 83}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 155}], {
             RGBColor[
             0.8043281578947369, 0.8479566315789474, 0.9785960263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 156}], {
             RGBColor[
             0.8160687631578948, 0.8125107894736843, 0.6368108421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 178}], {
             RGBColor[
             0.8325516842105263, 0.8672602105263159, 0.8526547631578946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 184}], {
             RGBColor[
             0.8043281578947369, 0.8479566315789474, 0.9785960263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 202}], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 208}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 214}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 268}], {
             RGBColor[
             0.8325516842105263, 0.8672602105263159, 0.8526547631578946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 275}], {
             RGBColor[
             0.8325516842105263, 0.8672602105263159, 0.8526547631578946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 17}], {
             RGBColor[
             0.5542524736842105, 0.6481633157894737, 0.9584598421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 30}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 38}], {
             RGBColor[
             0.7849043421052633, 0.6892710000000002, 0.6027778157894736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 55}], {
             RGBColor[
             0.5542524736842105, 0.6481633157894737, 0.9584598421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 74}], {
             RGBColor[
             0.508598157894737, 0.6086198421052633, 0.9555507894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 90}], {
             RGBColor[
             0.508598157894737, 0.6086198421052633, 0.9555507894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[
             0.8043281578947369, 0.8479566315789474, 0.9785960263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 144}], {
             RGBColor[
             0.8320390789473684, 0.8656602631578948, 0.7602590526315788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 157}], {
             RGBColor[
             0.5542524736842105, 0.6481633157894737, 0.9584598421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 229}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 252}], {
             RGBColor[
             0.8160687631578948, 0.8125107894736843, 0.6368108421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 257}], {
             RGBColor[
             0.8043281578947369, 0.8479566315789474, 0.9785960263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 259}], {
             RGBColor[
             0.7264971578947369, 0.7862643684210526, 0.9733741052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 26}], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 39}], {
             RGBColor[
             0.8320390789473684, 0.8656602631578948, 0.7602590526315788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 52}], {
             RGBColor[0.6116091578947369, 0.6951412631578948, 0.962861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 78}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 82}], {
             RGBColor[
             0.8276077105263158, 0.8514343684210527, 0.6816374736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 107}], {
             RGBColor[
             0.7264971578947369, 0.7862643684210526, 0.9733741052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 130}], {
             RGBColor[
             0.7264971578947369, 0.7862643684210526, 0.9733741052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 193}], {
             RGBColor[
             0.5542524736842105, 0.6481633157894737, 0.9584598421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 199}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 220}], {
             RGBColor[
             0.8325516842105263, 0.8672602105263159, 0.8526547631578946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.7438620263157896, 0.43828589473684215`, 0.5660006842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 228}], {
             RGBColor[
             0.8043281578947369, 0.8479566315789474, 0.9785960263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 236}], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 266}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 281}], {
             RGBColor[
             0.8325516842105263, 0.8672602105263159, 0.8526547631578946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[
             0.9911962105263157, 0.9906274210526316, 0.7955651052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 191}], {
             RGBColor[
             0.8325516842105263, 0.8672602105263159, 0.8526547631578946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 248}], {
             RGBColor[
             0.9664747894736843, 0.972772052631579, 0.8634674210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 21}], {
             RGBColor[
             0.8276077105263158, 0.8514343684210527, 0.6816374736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 34}], {
             RGBColor[
             0.9768443947368421, 0.968367052631579, 0.6665282368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 46}], {
             RGBColor[
             0.9615308157894737, 0.9569462105263158, 0.6924501315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 50}], {
             RGBColor[0.942107, 0.7982605789473685, 0.31663192105263155`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 101}], {
             RGBColor[
             0.8836998157894738, 0.8952539473684211, 0.6872282105263157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 108}], {
             RGBColor[
             0.9897543421052631, 0.9762497894736842, 0.5665088684210524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 114}], {
             RGBColor[
             0.9615308157894737, 0.9569462105263158, 0.6924501315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 145}], {
             RGBColor[
             0.6228641578947368, 0.6759978157894737, 0.6668309210526315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 169}], {
             RGBColor[
             0.9615308157894737, 0.9569462105263158, 0.6924501315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 187}], {
             RGBColor[
             0.9615308157894737, 0.9569462105263158, 0.6924501315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 205}], {
             RGBColor[
             0.9862522368421052, 0.9748015789473685, 0.6245478157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 213}], {
             RGBColor[
             0.9862522368421052, 0.9748015789473685, 0.6245478157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 219}], {
             RGBColor[
             0.9615308157894737, 0.9569462105263158, 0.6924501315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 221}], {
             RGBColor[
             0.9897543421052631, 0.9762497894736842, 0.5665088684210524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 231}], {
             RGBColor[
             0.8836998157894738, 0.8952539473684211, 0.6872282105263157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 264}], {
             RGBColor[
             0.9615308157894737, 0.9569462105263158, 0.6924501315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 9}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 11}], {
             RGBColor[
             0.6578348421052632, 0.7255525263157896, 0.9404415526315789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 43}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 63}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 106}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 131}], {
             RGBColor[
             0.9501674473684211, 0.8711324736842105, 0.6006356842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 143}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 151}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 167}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 174}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 185}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 283}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 297}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 22}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 47}], {
             RGBColor[
             0.9317022105263157, 0.9451111578947369, 0.8624326578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 61}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 72}], {
             RGBColor[
             0.9317022105263157, 0.9451111578947369, 0.8624326578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 177}], {
             RGBColor[
             0.9317022105263157, 0.9451111578947369, 0.8624326578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 217}], {
             RGBColor[
             0.8886437894736843, 0.9110797894736842, 0.8582454999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 247}], {
             RGBColor[
             0.8325516842105263, 0.8672602105263159, 0.8526547631578946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 267}], {
             RGBColor[
             0.9941857105263158, 0.9904756842105263, 0.6451304473684207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 271}], {
             RGBColor[
             0.9664747894736843, 0.972772052631579, 0.8634674210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 273}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 285}], {
             RGBColor[
             0.9630773947368421, 0.8790152105263158, 0.5006163157894735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.6077486842105264, 0.6864707894736843, 0.9653286842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 20}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 37}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 43}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 63}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 75}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 131}], {
             RGBColor[
             0.9000812894736843, 0.8320507368421053, 0.6255228157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 142}], {
             RGBColor[
             0.9317022105263157, 0.9451111578947369, 0.8624326578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 143}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 167}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 174}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 185}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 237}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 239}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 282}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 283}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 295}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 297}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 117}], {
             RGBColor[
             0.9311896052631579, 0.9435112105263158, 0.7700369473684209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 161}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 265}], {
             RGBColor[
             0.9317022105263157, 0.9451111578947369, 0.8624326578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 269}], {
             RGBColor[
             0.9034786842105264, 0.9258075789473684, 0.9883739210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 43}], {
             RGBColor[
             0.6578348421052631, 0.7255525263157896, 0.9404415526315789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 63}], {
             RGBColor[
             0.508598157894737, 0.6086198421052633, 0.9555507894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 131}], {
             RGBColor[
             0.6391238684210527, 0.6203748421052633, 0.6035123421052632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 139}], {
             RGBColor[
             0.3467912631578948, 0.4747948947368422, 0.9433182105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 143}], {
             RGBColor[
             0.508598157894737, 0.6086198421052633, 0.9555507894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 172}], {
             RGBColor[
             0.508598157894737, 0.6086198421052633, 0.9555507894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 174}], {
             RGBColor[
             0.5646902631578948, 0.6524394210526316, 0.9611415263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 183}], {
             RGBColor[
             0.5646902631578948, 0.6524394210526316, 0.9611415263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 185}], {
             RGBColor[
             0.508598157894737, 0.6086198421052633, 0.9555507894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 283}], {
             RGBColor[
             0.6077486842105264, 0.6864707894736843, 0.9653286842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 248}], {
             RGBColor[
             0.9664747894736843, 0.972772052631579, 0.8634674210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 58}], {
             RGBColor[
             0.9311896052631579, 0.9435112105263158, 0.7700369473684209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 73}], {
             RGBColor[
             0.9892417368421053, 0.9746498421052632, 0.4741131578947366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 95}], {
             RGBColor[
             0.6702321842105263, 0.7318353157894737, 0.7480264736842104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 96}], {
             RGBColor[
             0.9659621842105264, 0.9711721052631579, 0.7710717105263156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 105}], {
             RGBColor[0.7158865, 0.7713787894736842, 0.7509355263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[0.7158865, 0.7713787894736842, 0.7509355263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 149}], {
             RGBColor[
             0.9311896052631579, 0.9435112105263158, 0.7700369473684209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 171}], {
             RGBColor[
             0.9625647894736842, 0.8774152631578948, 0.40822060526315773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 245}], {
             RGBColor[
             0.8881311842105264, 0.9094798421052632, 0.765849789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 289}], {
             RGBColor[
             0.9659621842105264, 0.9711721052631579, 0.7710717105263156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 298}], {
             RGBColor[
             0.6702321842105263, 0.7318353157894737, 0.7480264736842104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 69}], {
             RGBColor[
             0.9034786842105264, 0.9258075789473684, 0.9883739210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 113}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 135}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 224}], {
             RGBColor[
             0.9034786842105264, 0.9258075789473684, 0.9883739210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 249}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 254}], {
             RGBColor[
             0.9311896052631579, 0.9435112105263158, 0.7700369473684209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 288}], {
             RGBColor[
             0.523816552631579, 0.6017703421052631, 0.9604200789473685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 19}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 49}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 57}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 89}], {
             RGBColor[
             0.9311896052631579, 0.9435112105263158, 0.7700369473684209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 111}], {
             RGBColor[
             0.7107596842105264, 0.7729922105263158, 0.9726388947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 115}], {
             RGBColor[
             0.9034786842105264, 0.9258075789473684, 0.9883739210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 146}], {
             RGBColor[
             0.7107596842105264, 0.7729922105263158, 0.9726388947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 175}], {
             RGBColor[
             0.9311896052631579, 0.9435112105263158, 0.7700369473684209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 212}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 242}], {
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 243}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 280}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 294}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.6702321842105263, 0.7318353157894737, 0.7480264736842104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 44}], {
             RGBColor[
             0.8320390789473684, 0.8656602631578948, 0.7602590526315788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 53}], {
             RGBColor[
             0.9892417368421053, 0.9746498421052632, 0.4741131578947366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 59}], {
             RGBColor[
             0.6272955263157894, 0.6902237105263158, 0.7454524999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 94}], {
             RGBColor[
             0.6702321842105263, 0.7318353157894737, 0.7480264736842104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 124}], {
             RGBColor[
             0.9311896052631579, 0.9435112105263158, 0.7700369473684209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 125}], {
             RGBColor[
             0.9812757631578948, 0.9825929473684211, 0.7451498157894735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 150}], {
             RGBColor[
             0.9892417368421053, 0.9746498421052632, 0.4741131578947366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 170}], {
             RGBColor[
             0.9906836052631578, 0.9890274736842106, 0.703169394736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 192}], {
             RGBColor[
             0.9906836052631578, 0.9890274736842106, 0.703169394736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 195}], {
             RGBColor[
             0.9941857105263158, 0.9904756842105263, 0.6451304473684207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 200}], {
             RGBColor[
             0.8320390789473684, 0.8656602631578948, 0.7602590526315788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 295}], {
             RGBColor[
             0.8881311842105264, 0.9094798421052632, 0.765849789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 30}], {
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 38}], {
             RGBColor[
             0.6687517631578948, 0.5949895263157896, 0.5934542894736843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 48}], {
             RGBColor[
             0.3924455789473684, 0.5143383684210527, 0.9462272631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 55}], {
             RGBColor[
             0.4380998947368421, 0.5538818421052631, 0.9491363157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 84}], {
             RGBColor[
             0.7128969999999999, 0.7715305263157894, 0.9013701842105264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 90}], {
             RGBColor[
             0.3924455789473684, 0.5143383684210527, 0.9462272631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 97}], {
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 134}], {
             RGBColor[0.7158865, 0.7713787894736842, 0.7509355263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 144}], {
             RGBColor[0.7158865, 0.7713787894736842, 0.7509355263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 158}], {
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 159}], {
             RGBColor[
             0.34950892105263154`, 0.47272676315789475`, 0.9436532894736842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 175}], {
             RGBColor[0.7158865, 0.7713787894736842, 0.7509355263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 235}], {
             RGBColor[
             0.308513447368421, 0.42963792105263154`, 0.9413186578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 252}], {
             RGBColor[
             0.6999161842105264, 0.7182293157894737, 0.6274873157894736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 253}], {
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 292}], {
             RGBColor[
             0.5542524736842105, 0.6481633157894737, 0.9584598421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 24}], {
             RGBColor[
             0.8043281578947369, 0.8479566315789474, 0.9785960263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 36}], {
             RGBColor[
             0.7455322631578948, 0.8006531052631579, 0.9736736578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 66}], {
             RGBColor[
             0.8604202631578948, 0.8917762105263158, 0.9841867631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 69}], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 88}], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 113}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 135}], {
             RGBColor[
             0.8604202631578948, 0.8917762105263158, 0.9841867631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.6425212631578948, 0.7141316842105263, 0.9663634473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 222}], {
             RGBColor[
             0.9499918684210527, 0.9180226315789473, 0.6476234999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 254}], {
             RGBColor[
             0.9659621842105264, 0.9711721052631579, 0.7710717105263156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 258}], {
             RGBColor[
             0.6425212631578948, 0.7141316842105263, 0.9663634473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 260}], {
             RGBColor[
             0.8604202631578948, 0.8917762105263158, 0.9841867631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 278}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 288}], {
             RGBColor[
             0.5585891315789474, 0.6294312368421052, 0.9614548421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 290}], {
             RGBColor[
             0.8604202631578948, 0.8917762105263158, 0.9841867631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 48}], {
             RGBColor[
             0.6077486842105264, 0.6864707894736843, 0.9653286842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 49}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 57}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 84}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 89}], {
             RGBColor[
             0.9311896052631579, 0.9435112105263158, 0.7700369473684209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 111}], {
             RGBColor[
             0.7107596842105264, 0.7729922105263158, 0.9726388947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 112}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 158}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 175}], {
             RGBColor[
             0.9311896052631579, 0.9435112105263158, 0.7700369473684209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 177}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 242}], {
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 253}], {
             RGBColor[
             0.9034786842105264, 0.9258075789473684, 0.9883739210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 280}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 33}], {
             RGBColor[
             0.508598157894737, 0.6086198421052633, 0.9555507894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 37}], {
             RGBColor[
             0.7264971578947369, 0.7862643684210526, 0.9733741052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 75}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 124}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 142}], {
             RGBColor[
             0.8325516842105263, 0.8672602105263159, 0.8526547631578946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 150}], {
             RGBColor[
             0.8276077105263158, 0.8514343684210527, 0.6816374736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 167}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 185}], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 200}], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 237}], {
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 282}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 283}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 295}], {
             RGBColor[
             0.7264971578947369, 0.7862643684210526, 0.9733741052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 297}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 34}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 46}], {
             RGBColor[
             0.8043281578947369, 0.8479566315789474, 0.9785960263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 50}], {
             RGBColor[
             0.7849043421052633, 0.6892710000000002, 0.6027778157894736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[0.6116091578947369, 0.6951412631578948, 0.962861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 101}], {
             RGBColor[
             0.7264971578947369, 0.7862643684210526, 0.9733741052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 108}], {
             RGBColor[
             0.8325516842105263, 0.8672602105263159, 0.8526547631578946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[
             0.8043281578947369, 0.8479566315789474, 0.9785960263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 169}], {
             RGBColor[
             0.8043281578947369, 0.8479566315789474, 0.9785960263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 187}], {
             RGBColor[
             0.8043281578947369, 0.8479566315789474, 0.9785960263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 205}], {
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 213}], {
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 264}], {
             RGBColor[
             0.8043281578947369, 0.8479566315789474, 0.9785960263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 61}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 72}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 177}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 217}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 247}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 267}], {
             RGBColor[
             0.9812757631578948, 0.9825929473684211, 0.7451498157894735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 271}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 273}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 274}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 285}], {
             RGBColor[
             0.9501674473684211, 0.8711324736842105, 0.6006356842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[
             0.6847781842105263, 0.6599183157894737, 0.6064213947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 180}], {
             RGBColor[
             0.8009307631578948, 0.7541997894736843, 0.6157449210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 267}], {
             RGBColor[
             0.9625647894736842, 0.8774152631578948, 0.40822060526315773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 285}], {
             RGBColor[
             0.9314564736842106, 0.7659547894736842, 0.2637064736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.508598157894737, 0.6086198421052633, 0.9555507894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 113}], {
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 135}], {
             RGBColor[
             0.7264971578947369, 0.7862643684210526, 0.9733741052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 224}], {
             RGBColor[
             0.8043281578947369, 0.8479566315789474, 0.9785960263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 233}], {
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 254}], {
             RGBColor[
             0.8320390789473684, 0.8656602631578948, 0.7602590526315788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 259}], {
             RGBColor[
             0.7264971578947369, 0.7862643684210526, 0.9733741052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 260}], {
             RGBColor[
             0.7264971578947369, 0.7862643684210526, 0.9733741052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 288}], {
             RGBColor[
             0.42466602631578954`, 0.5239193947368421, 0.9506421842105264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 29}], {
             RGBColor[
             0.9630773947368421, 0.8790152105263158, 0.5006163157894735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[
             0.9501674473684211, 0.8711324736842105, 0.6006356842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 77}], {
             RGBColor[0.9595752894736842, 0.877567, 0.5586552631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 91}], {
             RGBColor[
             0.9630773947368421, 0.8790152105263158, 0.5006163157894735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 139}], {
             RGBColor[
             0.6391238684210527, 0.6203748421052633, 0.6035123421052632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 147}], {
             RGBColor[
             0.9348538684210527, 0.8597116315789474, 0.6265575789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 148}], {
             RGBColor[
             0.9465944736842106, 0.8242657894736842, 0.284772394736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 172}], {
             RGBColor[
             0.8009307631578948, 0.7541997894736843, 0.6157449210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 203}], {
             RGBColor[
             0.9581334210526316, 0.8631893684210526, 0.3295990263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 206}], {
             RGBColor[0.9595752894736842, 0.877567, 0.5586552631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 244}], {
             RGBColor[
             0.9348538684210527, 0.8597116315789474, 0.6265575789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 270}], {
             RGBColor[
             0.5551917368421053, 0.5356743947368421, 0.5986037368421053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 272}], {
             RGBColor[0.9595752894736842, 0.877567, 0.5586552631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 39}], {
             RGBColor[
             0.8320390789473684, 0.8656602631578948, 0.7602590526315788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 59}], {
             RGBColor[
             0.46566150000000006`, 0.5670082368421053, 0.9529768157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 60}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 62}], {
             RGBColor[
             0.8009307631578948, 0.7541997894736843, 0.6157449210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 82}], {
             RGBColor[
             0.8276077105263158, 0.8514343684210527, 0.6816374736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 127}], {
             RGBColor[0.6116091578947369, 0.6951412631578948, 0.962861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 130}], {
             RGBColor[
             0.7264971578947369, 0.7862643684210526, 0.9733741052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 137}], {
             RGBColor[
             0.5542524736842105, 0.6481633157894737, 0.9584598421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 170}], {
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 192}], {
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 195}], {
             RGBColor[
             0.8325516842105263, 0.8672602105263159, 0.8526547631578946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 199}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 220}], {
             RGBColor[
             0.8325516842105263, 0.8672602105263159, 0.8526547631578946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 226}], {
             RGBColor[
             0.7438620263157896, 0.43828589473684215`, 0.5660006842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 228}], {
             RGBColor[
             0.8043281578947369, 0.8479566315789474, 0.9785960263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 266}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 32}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 103}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 119}], {
             RGBColor[
             0.508598157894737, 0.6086198421052633, 0.9555507894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 152}], {
             RGBColor[0.6116091578947369, 0.6951412631578948, 0.962861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 268}], {
             RGBColor[
             0.8325516842105263, 0.8672602105263159, 0.8526547631578946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 35}], {
             RGBColor[
             0.9906836052631578, 0.9890274736842106, 0.703169394736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 126}], {
             RGBColor[
             0.9941857105263158, 0.9904756842105263, 0.6451304473684207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 163}], {
             RGBColor[
             0.8881311842105264, 0.9094798421052632, 0.765849789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 184}], {
             RGBColor[
             0.9659621842105264, 0.9711721052631579, 0.7710717105263156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 189}], {
             RGBColor[0.7158865, 0.7713787894736842, 0.7509355263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 197}], {
             RGBColor[
             0.7732431842105263, 0.8183567368421053, 0.7553366842105261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 211}], {
             RGBColor[
             0.9941857105263158, 0.9904756842105263, 0.6451304473684207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 216}], {
             RGBColor[
             0.9311896052631579, 0.9435112105263158, 0.7700369473684209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 275}], {
             RGBColor[
             0.9941857105263158, 0.9904756842105263, 0.6451304473684207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 293}], {
             RGBColor[
             0.9906836052631578, 0.9890274736842106, 0.703169394736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 77}], {
             RGBColor[
             0.9911962105263157, 0.9906274210526316, 0.7955651052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 91}], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 148}], {
             RGBColor[
             0.9782153947368422, 0.9373262105263158, 0.521682236842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 162}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 172}], {
             RGBColor[
             0.8325516842105263, 0.8672602105263159, 0.8526547631578946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 191}], {
             RGBColor[
             0.8325516842105263, 0.8672602105263159, 0.8526547631578946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 203}], {
             RGBColor[
             0.9897543421052631, 0.9762497894736842, 0.5665088684210524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 206}], {
             RGBColor[
             0.9911962105263157, 0.9906274210526316, 0.7955651052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 244}], {
             RGBColor[
             0.9664747894736843, 0.972772052631579, 0.8634674210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 270}], {
             RGBColor[
             0.5868126578947368, 0.6487348157894737, 0.8355135789473682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 272}], {
             RGBColor[
             0.9911962105263157, 0.9906274210526316, 0.7955651052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 38}], {
             RGBColor[
             0.8840548684210527, 0.7671219473684212, 0.6125557105263157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 47}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 48}], {
             RGBColor[
             0.6077486842105264, 0.6864707894736843, 0.9653286842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 74}], {
             RGBColor[
             0.6077486842105264, 0.6864707894736843, 0.9653286842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 90}], {
             RGBColor[
             0.6077486842105264, 0.6864707894736843, 0.9653286842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 123}], {
             RGBColor[
             0.9034786842105264, 0.9258075789473684, 0.9883739210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 144}], {
             RGBColor[
             0.9311896052631579, 0.9435112105263158, 0.7700369473684209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 158}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 252}], {
             RGBColor[
             0.9152192894736842, 0.8903617368421053, 0.6465887368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 257}], {
             RGBColor[
             0.9034786842105264, 0.9258075789473684, 0.9883739210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 259}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 36}], {
             RGBColor[
             0.7702536842105263, 0.8185084736842105, 0.9057713421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 51}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 58}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 66}], {
             RGBColor[
             0.8851416842105263, 0.9096315789473685, 0.9162844473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 67}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 73}], {
             RGBColor[
             0.9862522368421052, 0.9748015789473685, 0.6245478157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 95}], {
             RGBColor[
             0.6672426842105263, 0.731987052631579, 0.8984611315789475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 96}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 109}], {
             RGBColor[
             0.9906836052631578, 0.9890274736842106, 0.703169394736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 110}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 138}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 154}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 171}], {
             RGBColor[0.9595752894736842, 0.877567, 0.5586552631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 245}], {
             RGBColor[
             0.8851416842105263, 0.9096315789473685, 0.9162844473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 156}], {
             RGBColor[
             0.965305447368421, 0.9294434736842105, 0.6217016052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 178}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 182}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 202}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 208}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 268}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 37}], {
             RGBColor[
             0.5646902631578948, 0.6524394210526316, 0.9611415263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 75}], {
             RGBColor[
             0.6077486842105264, 0.6864707894736843, 0.9653286842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 94}], {
             RGBColor[
             0.3467912631578948, 0.4747948947368422, 0.9433182105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 124}], {
             RGBColor[
             0.6077486842105264, 0.6864707894736843, 0.9653286842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 142}], {
             RGBColor[
             0.6707447894736842, 0.7334352631578949, 0.8404221842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 150}], {
             RGBColor[
             0.6658008157894737, 0.7176094210526316, 0.6694048947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 185}], {
             RGBColor[
             0.508598157894737, 0.6086198421052633, 0.9555507894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 200}], {
             RGBColor[
             0.508598157894737, 0.6086198421052633, 0.9555507894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 237}], {
             RGBColor[
             0.6672426842105263, 0.731987052631579, 0.8984611315789475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 239}], {
             RGBColor[
             0.6578348421052631, 0.7255525263157896, 0.9404415526315789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 282}], {
             RGBColor[
             0.6077486842105264, 0.6864707894736843, 0.9653286842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 295}], {
             RGBColor[
             0.5646902631578948, 0.6524394210526316, 0.9611415263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 297}], {
             RGBColor[
             0.6578348421052631, 0.7255525263157896, 0.9404415526315789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 46}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 50}], {
             RGBColor[
             0.9341410263157894, 0.8062036842105265, 0.5876685789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 87}], {
             RGBColor[
             0.7608458421052632, 0.8120739473684211, 0.9477517631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 108}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 114}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 169}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 187}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 205}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 213}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 227}], {
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 264}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 92}], {
             RGBColor[
             0.9435488684210527, 0.8126382105263159, 0.5456881578947369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 126}], {
             RGBColor[
             0.9911962105263157, 0.9906274210526316, 0.7955651052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 163}], {
             RGBColor[
             0.8851416842105263, 0.9096315789473685, 0.9162844473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 184}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 189}], {
             RGBColor[
             0.7128969999999999, 0.7715305263157894, 0.9013701842105264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 197}], {
             RGBColor[
             0.7702536842105263, 0.8185084736842105, 0.9057713421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 211}], {
             RGBColor[
             0.9911962105263157, 0.9906274210526316, 0.7955651052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 216}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 275}], {
             RGBColor[
             0.9911962105263157, 0.9906274210526316, 0.7955651052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 58}], {
             RGBColor[
             0.7107596842105264, 0.7729922105263158, 0.9726388947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 66}], {
             RGBColor[
             0.6677012631578948, 0.7389608421052631, 0.9684517368421053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 67}], {
             RGBColor[
             0.7107596842105264, 0.7729922105263158, 0.9726388947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 69}], {
             RGBColor[
             0.7455322631578948, 0.8006531052631579, 0.9736736578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 88}], {
             RGBColor[
             0.7455322631578948, 0.8006531052631579, 0.9736736578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 95}], {
             RGBColor[
             0.44980226315789484`, 0.5613163157894738, 0.9506284210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 96}], {
             RGBColor[
             0.7455322631578948, 0.8006531052631579, 0.9736736578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 109}], {
             RGBColor[
             0.7732431842105263, 0.8183567368421053, 0.7553366842105261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 113}], {
             RGBColor[
             0.7702536842105263, 0.8185084736842105, 0.9057713421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 138}], {
             RGBColor[
             0.7455322631578948, 0.8006531052631579, 0.9736736578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 154}], {
             RGBColor[
             0.7107596842105264, 0.7729922105263158, 0.9726388947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 198}], {
             RGBColor[
             0.44980226315789484`, 0.5613163157894738, 0.9506284210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 222}], {
             RGBColor[
             0.7572728684210527, 0.7652072631578948, 0.6318884736842104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 224}], {
             RGBColor[
             0.7455322631578948, 0.8006531052631579, 0.9736736578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 245}], {
             RGBColor[
             0.6677012631578948, 0.7389608421052631, 0.9684517368421053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 258}], {
             RGBColor[
             0.44980226315789484`, 0.5613163157894738, 0.9506284210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 260}], {
             RGBColor[
             0.6677012631578948, 0.7389608421052631, 0.9684517368421053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 278}], {
             RGBColor[
             0.7702536842105263, 0.8185084736842105, 0.9057713421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 290}], {
             RGBColor[
             0.6677012631578948, 0.7389608421052631, 0.9684517368421053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 75}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 94}], {
             RGBColor[
             0.5646902631578948, 0.6524394210526316, 0.9611415263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 102}], {
             RGBColor[
             0.8851416842105263, 0.9096315789473685, 0.9162844473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 124}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 142}], {
             RGBColor[
             0.8886437894736843, 0.9110797894736842, 0.8582454999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 150}], {
             RGBColor[
             0.8836998157894738, 0.8952539473684211, 0.6872282105263157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 185}], {
             RGBColor[
             0.7264971578947369, 0.7862643684210526, 0.9733741052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 237}], {
             RGBColor[
             0.8851416842105263, 0.9096315789473685, 0.9162844473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 239}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 282}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 283}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 295}], {
             RGBColor[
             0.7825892631578948, 0.8300839473684211, 0.9789648421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 297}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 48}], {
             RGBColor[
             0.6230974473684211, 0.5554460526315791, 0.5905452368421054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 55}], {
             RGBColor[
             0.6687517631578948, 0.5949895263157896, 0.5934542894736843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 74}], {
             RGBColor[
             0.6230974473684211, 0.5554460526315791, 0.5905452368421054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 90}], {
             RGBColor[
             0.6230974473684211, 0.5554460526315791, 0.5905452368421054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 123}], {
             RGBColor[
             0.918827447368421, 0.7947828421052632, 0.6135904736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 144}], {
             RGBColor[
             0.9465383684210527, 0.8124864736842106, 0.39525349999999987`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 158}], {
             RGBColor[
             0.9341410263157894, 0.8062036842105265, 0.5876685789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 252}], {
             RGBColor[0.9305680526315789, 0.759337, 0.27180528947368415`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 253}], {
             RGBColor[
             0.918827447368421, 0.7947828421052632, 0.6135904736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 257}], {
             RGBColor[
             0.918827447368421, 0.7947828421052632, 0.6135904736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 259}], {
             RGBColor[
             0.840996447368421, 0.7330905789473685, 0.608368552631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 52}], {
             RGBColor[
             0.7732431842105263, 0.8183567368421053, 0.7553366842105261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 59}], {
             RGBColor[
             0.6272955263157894, 0.6902237105263158, 0.7454524999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 60}], {
             RGBColor[
             0.9812757631578948, 0.9825929473684211, 0.7451498157894735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 62}], {
             RGBColor[
             0.9625647894736842, 0.8774152631578948, 0.40822060526315773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 82}], {
             RGBColor[
             0.9892417368421053, 0.9746498421052632, 0.4741131578947366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 100}], {
             RGBColor[
             0.9311896052631579, 0.9435112105263158, 0.7700369473684209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 107}], {
             RGBColor[
             0.8881311842105264, 0.9094798421052632, 0.765849789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 127}], {
             RGBColor[
             0.7732431842105263, 0.8183567368421053, 0.7553366842105261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 136}], {
             RGBColor[
             0.9812757631578948, 0.9825929473684211, 0.7451498157894735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 137}], {
             RGBColor[0.7158865, 0.7713787894736842, 0.7509355263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 141}], {
             RGBColor[
             0.9812757631578948, 0.9825929473684211, 0.7451498157894735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 170}], {
             RGBColor[
             0.9906836052631578, 0.9890274736842106, 0.703169394736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 192}], {
             RGBColor[
             0.9906836052631578, 0.9890274736842106, 0.703169394736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 220}], {
             RGBColor[
             0.9941857105263158, 0.9904756842105263, 0.6451304473684207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 228}], {
             RGBColor[
             0.9659621842105264, 0.9711721052631579, 0.7710717105263156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 232}], {
             RGBColor[
             0.8881311842105264, 0.9094798421052632, 0.765849789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 266}], {
             RGBColor[
             0.9812757631578948, 0.9825929473684211, 0.7451498157894735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 281}], {
             RGBColor[
             0.9941857105263158, 0.9904756842105263, 0.6451304473684207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.7264971578947369, 0.7862643684210526, 0.9733741052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 162}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 191}], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 76}], {
             RGBColor[
             0.9664747894736843, 0.972772052631579, 0.8634674210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 99}], {
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 104}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 157}], {
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 201}], {
             RGBColor[
             0.9664747894736843, 0.972772052631579, 0.8634674210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 209}], {
             RGBColor[
             0.8777851315789473, 0.5437977368421052, 0.576813342105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 222}], {
             RGBColor[
             0.9499918684210527, 0.9180226315789473, 0.6476234999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 229}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 259}], {
             RGBColor[
             0.8604202631578948, 0.8917762105263158, 0.9841867631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 261}], {
             RGBColor[
             0.9034786842105264, 0.9258075789473684, 0.9883739210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 278}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 290}], {
             RGBColor[
             0.8604202631578948, 0.8917762105263158, 0.9841867631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 55}], {
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 134}], {
             RGBColor[
             0.9812757631578948, 0.9825929473684211, 0.7451498157894735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 144}], {
             RGBColor[
             0.9812757631578948, 0.9825929473684211, 0.7451498157894735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 159}], {
             RGBColor[
             0.6148981842105263, 0.6839409210526316, 0.9378675789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 235}], {
             RGBColor[
             0.5739027105263158, 0.6408520789473684, 0.9355329473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 252}], {
             RGBColor[
             0.965305447368421, 0.9294434736842105, 0.6217016052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 292}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 63}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 131}], {
             RGBColor[
             0.9501674473684211, 0.8711324736842105, 0.6006356842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 139}], {
             RGBColor[
             0.6578348421052632, 0.7255525263157896, 0.9404415526315789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 143}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 172}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 174}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 183}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 185}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 244}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 59}], {
             RGBColor[
             0.46566150000000006`, 0.5670082368421053, 0.9529768157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 60}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 94}], {
             RGBColor[
             0.508598157894737, 0.6086198421052633, 0.9555507894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 100}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 121}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 124}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 125}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 137}], {
             RGBColor[
             0.5542524736842105, 0.6481633157894737, 0.9584598421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 150}], {
             RGBColor[
             0.8276077105263158, 0.8514343684210527, 0.6816374736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 170}], {
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 192}], {
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 195}], {
             RGBColor[
             0.8325516842105263, 0.8672602105263159, 0.8526547631578946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 200}], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 256}], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 299}], {
             RGBColor[
             0.8325516842105263, 0.8672602105263159, 0.8526547631578946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 53}], {
             RGBColor[0.942107, 0.7982605789473685, 0.31663192105263155`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 68}], {
             RGBColor[
             0.918827447368421, 0.7947828421052632, 0.6135904736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 195}], {
             RGBColor[
             0.9470509736842105, 0.8140864210526317, 0.48764921052631566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 200}], {
             RGBColor[
             0.7849043421052633, 0.6892710000000002, 0.6027778157894736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 215}], {
             RGBColor[
             0.9154300526315791, 0.7010260000000001, 0.25073936842105266`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 223}], {
             RGBColor[
             0.9341410263157894, 0.8062036842105265, 0.5876685789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 225}], {
             RGBColor[
             0.9341410263157894, 0.8062036842105265, 0.5876685789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 234}], {
             RGBColor[
             0.918827447368421, 0.7947828421052632, 0.6135904736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 255}], {
             RGBColor[
             0.9435488684210527, 0.8126382105263159, 0.5456881578947369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 282}], {
             RGBColor[
             0.8840548684210527, 0.7671219473684212, 0.6125557105263157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 287}], {
             RGBColor[
             0.918827447368421, 0.7947828421052632, 0.6135904736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 50}], {
             RGBColor[
             0.918827447368421, 0.7947828421052632, 0.6135904736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 108}], {
             RGBColor[
             0.9664747894736843, 0.972772052631579, 0.8634674210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 114}], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 145}], {
             RGBColor[
             0.5995846052631579, 0.6725200789473684, 0.9637894736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 169}], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 187}], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 213}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 219}], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 221}], {
             RGBColor[
             0.9664747894736843, 0.972772052631579, 0.8634674210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 264}], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 48}], {
             RGBColor[
             0.6077486842105264, 0.6864707894736843, 0.9653286842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 74}], {
             RGBColor[
             0.6077486842105264, 0.6864707894736843, 0.9653286842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 90}], {
             RGBColor[
             0.6077486842105264, 0.6864707894736843, 0.9653286842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 166}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 177}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 217}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 233}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 262}], {
             RGBColor[
             0.9311896052631579, 0.9435112105263158, 0.7700369473684209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 273}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 74}], {
             RGBColor[
             0.3467912631578948, 0.4747948947368422, 0.9433182105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 84}], {
             RGBColor[
             0.6672426842105263, 0.731987052631579, 0.8984611315789475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 90}], {
             RGBColor[
             0.3467912631578948, 0.4747948947368422, 0.9433182105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 144}], {
             RGBColor[
             0.6702321842105263, 0.7318353157894737, 0.7480264736842104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 158}], {
             RGBColor[
             0.6578348421052631, 0.7255525263157896, 0.9404415526315789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 175}], {
             RGBColor[
             0.6702321842105263, 0.7318353157894737, 0.7480264736842104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 177}], {
             RGBColor[
             0.6077486842105264, 0.6864707894736843, 0.9653286842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 217}], {
             RGBColor[
             0.5646902631578948, 0.6524394210526316, 0.9611415263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 252}], {
             RGBColor[
             0.6542618684210526, 0.6786858421052632, 0.6245782631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 253}], {
             RGBColor[
             0.6425212631578947, 0.7141316842105263, 0.9663634473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 57}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 84}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 112}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 115}], {
             RGBColor[
             0.9034786842105264, 0.9258075789473684, 0.9883739210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 146}], {
             RGBColor[
             0.7107596842105264, 0.7729922105263158, 0.9726388947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 159}], {
             RGBColor[
             0.5648120263157895, 0.6448591842105263, 0.9627547105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 175}], {
             RGBColor[
             0.9311896052631579, 0.9435112105263158, 0.7700369473684209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 204}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 242}], {
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 243}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 253}], {
             RGBColor[
             0.9034786842105264, 0.9258075789473684, 0.9883739210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 280}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 292}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 87}], {
             RGBColor[
             0.7261084473684212, 0.6419674736842107, 0.597855447368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 108}], {
             RGBColor[
             0.9470509736842105, 0.8140864210526317, 0.48764921052631566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 114}], {
             RGBColor[
             0.918827447368421, 0.7947828421052632, 0.6135904736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 169}], {
             RGBColor[
             0.918827447368421, 0.7947828421052632, 0.6135904736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 187}], {
             RGBColor[
             0.918827447368421, 0.7947828421052632, 0.6135904736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 205}], {
             RGBColor[
             0.9435488684210527, 0.8126382105263159, 0.5456881578947369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 213}], {
             RGBColor[
             0.9435488684210527, 0.8126382105263159, 0.5456881578947369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 227}], {
             RGBColor[
             0.6687517631578948, 0.5949895263157896, 0.5934542894736843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 264}], {
             RGBColor[
             0.918827447368421, 0.7947828421052632, 0.6135904736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 52}], {
             RGBColor[
             0.7608458421052632, 0.8120739473684211, 0.9477517631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 58}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 66}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 67}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 69}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 86}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 109}], {
             RGBColor[
             0.9812757631578948, 0.9825929473684211, 0.7451498157894735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 110}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 138}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 141}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 154}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 165}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 179}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 258}], {
             RGBColor[
             0.6578348421052632, 0.7255525263157896, 0.9404415526315789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 281}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 82}], {
             RGBColor[
             0.7688118157894737, 0.8041308421052632, 0.6767151052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 86}], {
             RGBColor[
             0.7702536842105263, 0.8185084736842105, 0.9057713421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 107}], {
             RGBColor[
             0.6677012631578948, 0.7389608421052631, 0.9684517368421053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 110}], {
             RGBColor[
             0.7608458421052632, 0.8120739473684211, 0.9477517631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 141}], {
             RGBColor[
             0.7608458421052632, 0.8120739473684211, 0.9477517631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 165}], {
             RGBColor[
             0.7608458421052632, 0.8120739473684211, 0.9477517631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 179}], {
             RGBColor[
             0.7107596842105264, 0.7729922105263158, 0.9726388947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 193}], {
             RGBColor[
             0.49545657894736844`, 0.6008597894736842, 0.9535374736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 236}], {
             RGBColor[0.6116091578947369, 0.6951412631578948, 0.962861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 266}], {
             RGBColor[
             0.7608458421052632, 0.8120739473684211, 0.9477517631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 281}], {
             RGBColor[
             0.7737557894736842, 0.8199566842105264, 0.8477323947368419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 59}], {
             RGBColor[
             0.6228641578947368, 0.6759978157894737, 0.6668309210526315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 68}], {
             RGBColor[
             0.9615308157894737, 0.9569462105263158, 0.6924501315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 150}], {
             RGBColor[
             0.9848103684210526, 0.9604239473684211, 0.3954915789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 170}], {
             RGBColor[
             0.9862522368421052, 0.9748015789473685, 0.6245478157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 192}], {
             RGBColor[
             0.9862522368421052, 0.9748015789473685, 0.6245478157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 195}], {
             RGBColor[
             0.9897543421052631, 0.9762497894736842, 0.5665088684210524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 200}], {
             RGBColor[
             0.8276077105263158, 0.8514343684210527, 0.6816374736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 225}], {
             RGBColor[
             0.9768443947368421, 0.968367052631579, 0.6665282368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 234}], {
             RGBColor[
             0.9615308157894737, 0.9569462105263158, 0.6924501315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 255}], {
             RGBColor[
             0.9862522368421052, 0.9748015789473685, 0.6245478157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 282}], {
             RGBColor[
             0.9267582368421052, 0.9292853157894737, 0.6914153684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 287}], {
             RGBColor[
             0.9615308157894737, 0.9569462105263158, 0.6924501315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 72}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 106}], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 151}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 167}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 194}], {
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 238}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 251}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 286}], {
             RGBColor[
             0.7128969999999999, 0.7715305263157894, 0.9013701842105264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 90}], {
             RGBColor[
             0.3924455789473684, 0.5143383684210527, 0.9462272631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 97}], {
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 134}], {
             RGBColor[0.7158865, 0.7713787894736842, 0.7509355263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 144}], {
             RGBColor[0.7158865, 0.7713787894736842, 0.7509355263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 159}], {
             RGBColor[
             0.34950892105263154`, 0.47272676315789475`, 0.9436532894736842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 235}], {
             RGBColor[
             0.308513447368421, 0.42963792105263154`, 0.9413186578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 252}], {
             RGBColor[
             0.6999161842105264, 0.7182293157894737, 0.6274873157894736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 253}], {
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 292}], {
             RGBColor[
             0.5542524736842105, 0.6481633157894737, 0.9584598421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 79}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 93}], {
             RGBColor[
             0.9911962105263157, 0.9906274210526316, 0.7955651052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 160}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 164}], {
             RGBColor[
             0.6672426842105263, 0.731987052631579, 0.8984611315789475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 168}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 246}], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 296}], {
             RGBColor[
             0.7128969999999999, 0.7715305263157894, 0.9013701842105264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 89}], {
             RGBColor[
             0.9906836052631578, 0.9890274736842106, 0.703169394736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 112}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 115}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 134}], {
             RGBColor[
             0.9906836052631578, 0.9890274736842106, 0.703169394736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 146}], {
             RGBColor[
             0.7702536842105263, 0.8185084736842105, 0.9057713421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 159}], {
             RGBColor[
             0.6243060263157895, 0.6903754473684212, 0.8958871578947369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 175}], {
             RGBColor[
             0.9906836052631578, 0.9890274736842106, 0.703169394736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 204}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 235}], {
             RGBColor[
             0.5833105526315789, 0.647286605263158, 0.8935525263157895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 242}], {
             RGBColor[
             0.7128969999999999, 0.7715305263157894, 0.9013701842105264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 243}], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 253}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 280}], {
             RGBColor[
             0.8851416842105263, 0.9096315789473685, 0.9162844473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 292}], {
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 66}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 67}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 73}], {
             RGBColor[
             0.9267582368421052, 0.9292853157894737, 0.6914153684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 95}], {
             RGBColor[
             0.6077486842105264, 0.6864707894736843, 0.9653286842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 96}], {
             RGBColor[
             0.9034786842105264, 0.9258075789473684, 0.9883739210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 109}], {
             RGBColor[
             0.9311896052631579, 0.9435112105263158, 0.7700369473684209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 138}], {
             RGBColor[
             0.9034786842105264, 0.9258075789473684, 0.9883739210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 140}], {
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 154}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 171}], {
             RGBColor[
             0.9000812894736843, 0.8320507368421053, 0.6255228157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 198}], {
             RGBColor[
             0.6077486842105264, 0.6864707894736843, 0.9653286842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 62}], {
             RGBColor[
             0.5961872105263157, 0.5787632368421053, 0.6009383684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 100}], {
             RGBColor[
             0.5648120263157894, 0.6448591842105263, 0.9627547105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 125}], {
             RGBColor[
             0.6148981842105263, 0.6839409210526316, 0.9378675789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 137}], {
             RGBColor[
             0.34950892105263154`, 0.47272676315789475`, 0.9436532894736842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 170}], {
             RGBColor[
             0.6243060263157894, 0.6903754473684212, 0.8958871578947369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 192}], {
             RGBColor[
             0.6243060263157894, 0.6903754473684212, 0.8958871578947369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 195}], {
             RGBColor[
             0.6278081315789474, 0.6918236578947369, 0.8378482105263156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 200}], {
             RGBColor[
             0.46566150000000006`, 0.5670082368421053, 0.9529768157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 225}], {
             RGBColor[
             0.6148981842105263, 0.6839409210526316, 0.9378675789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 228}], {
             RGBColor[
             0.5995846052631579, 0.6725200789473684, 0.9637894736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 255}], {
             RGBColor[
             0.6243060263157894, 0.6903754473684212, 0.8958871578947369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.9768443947368421, 0.968367052631579, 0.6665282368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 85}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 100}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 121}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 125}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 127}], {
             RGBColor[
             0.7608458421052632, 0.8120739473684211, 0.9477517631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 137}], {
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 170}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 232}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 240}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 256}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 299}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 177}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 217}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 247}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 267}], {
             RGBColor[
             0.9812757631578948, 0.9825929473684211, 0.7451498157894735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 273}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 285}], {
             RGBColor[
             0.9501674473684211, 0.8711324736842105, 0.6006356842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 82}], {
             RGBColor[
             0.9581334210526316, 0.8631893684210526, 0.3295990263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 100}], {
             RGBColor[
             0.9000812894736843, 0.8320507368421053, 0.6255228157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 127}], {
             RGBColor[
             0.7421348684210527, 0.7068962631578948, 0.6108225526315789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 130}], {
             RGBColor[
             0.8570228684210527, 0.7980193684210526, 0.6213356578947369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 137}], {
             RGBColor[
             0.6847781842105263, 0.6599183157894737, 0.6064213947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 170}], {
             RGBColor[0.9595752894736842, 0.877567, 0.5586552631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 192}], {
             RGBColor[0.9595752894736842, 0.877567, 0.5586552631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 195}], {
             RGBColor[
             0.9630773947368421, 0.8790152105263158, 0.5006163157894735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 199}], {
             RGBColor[
             0.9501674473684211, 0.8711324736842105, 0.6006356842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 220}], {
             RGBColor[
             0.9630773947368421, 0.8790152105263158, 0.5006163157894735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 225}], {
             RGBColor[
             0.9501674473684211, 0.8711324736842105, 0.6006356842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 226}], {
             RGBColor[
             0.8743877368421054, 0.4500408947368421, 0.21396223684210525`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 228}], {
             RGBColor[
             0.9348538684210527, 0.8597116315789474, 0.6265575789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 255}], {
             RGBColor[0.9595752894736842, 0.877567, 0.5586552631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 131}], {
             RGBColor[
             0.8009307631578948, 0.7541997894736843, 0.6157449210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 139}], {
             RGBColor[
             0.508598157894737, 0.6086198421052633, 0.9555507894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 143}], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 172}], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 174}], {
             RGBColor[
             0.7264971578947369, 0.7862643684210526, 0.9733741052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 183}], {
             RGBColor[
             0.7264971578947369, 0.7862643684210526, 0.9733741052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 283}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 92}], {
             RGBColor[
             0.918827447368421, 0.7947828421052632, 0.6135904736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 145}], {
             RGBColor[
             0.5995846052631579, 0.6725200789473684, 0.9637894736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 153}], {
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 211}], {
             RGBColor[
             0.9664747894736843, 0.972772052631579, 0.8634674210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 219}], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 221}], {
             RGBColor[
             0.9664747894736843, 0.972772052631579, 0.8634674210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 80}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 103}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 116}], {
             RGBColor[
             0.8604202631578948, 0.8917762105263158, 0.9841867631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 133}], {
             RGBColor[
             0.6677012631578948, 0.7389608421052631, 0.9684517368421053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 152}], {
             RGBColor[
             0.6677012631578948, 0.7389608421052631, 0.9684517368421053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 162}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[
             0.8886437894736843, 0.9110797894736842, 0.8582454999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 241}], {
             RGBColor[
             0.7825892631578948, 0.8300839473684211, 0.9789648421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 277}], {
             RGBColor[
             0.6103445789473685, 0.691982894736842, 0.9640505789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 67}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 69}], {
             RGBColor[
             0.8604202631578948, 0.8917762105263158, 0.9841867631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 95}], {
             RGBColor[
             0.5646902631578948, 0.6524394210526316, 0.9611415263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 109}], {
             RGBColor[
             0.8881311842105264, 0.9094798421052632, 0.765849789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 110}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 138}], {
             RGBColor[
             0.8604202631578948, 0.8917762105263158, 0.9841867631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 154}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 179}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 258}], {
             RGBColor[
             0.5646902631578948, 0.6524394210526316, 0.9611415263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 69}], {
             RGBColor[
             0.9034786842105264, 0.9258075789473684, 0.9883739210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 86}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 95}], {
             RGBColor[
             0.6077486842105264, 0.6864707894736843, 0.9653286842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 109}], {
             RGBColor[
             0.9311896052631579, 0.9435112105263158, 0.7700369473684209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 110}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 138}], {
             RGBColor[
             0.9034786842105264, 0.9258075789473684, 0.9883739210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 154}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 179}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 258}], {
             RGBColor[
             0.6077486842105264, 0.6864707894736843, 0.9653286842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 215}], {
             RGBColor[
             0.9348538684210527, 0.8597116315789474, 0.6265575789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 223}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 234}], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 255}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 271}], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 274}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 287}], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 109}], {
             RGBColor[
             0.9659621842105264, 0.9711721052631579, 0.7710717105263156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 110}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 113}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 135}], {
             RGBColor[
             0.8604202631578948, 0.8917762105263158, 0.9841867631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 138}], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 224}], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 249}], {
             RGBColor[
             0.9034786842105264, 0.9258075789473684, 0.9883739210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 254}], {
             RGBColor[
             0.9659621842105264, 0.9711721052631579, 0.7710717105263156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 258}], {
             RGBColor[
             0.6425212631578948, 0.7141316842105263, 0.9663634473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 288}], {
             RGBColor[
             0.5585891315789474, 0.6294312368421052, 0.9614548421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 251}], {
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 300}], {
             RGBColor[
             0.308513447368421, 0.42963792105263154`, 0.9413186578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 85}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 98}], {
             RGBColor[
             0.8886437894736843, 0.9110797894736842, 0.8582454999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 121}], {
             RGBColor[
             0.9317022105263157, 0.9451111578947369, 0.8624326578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 122}], {
             RGBColor[
             0.6707447894736842, 0.7334352631578949, 0.8404221842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 136}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 160}], {
             RGBColor[
             0.9317022105263157, 0.9451111578947369, 0.8624326578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 181}], {
             RGBColor[
             0.9317022105263157, 0.9451111578947369, 0.8624326578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 207}], {
             RGBColor[
             0.7163991052631579, 0.7729787368421053, 0.8433312368421051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 232}], {
             RGBColor[
             0.8886437894736843, 0.9110797894736842, 0.8582454999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 240}], {
             RGBColor[
             0.9317022105263157, 0.9451111578947369, 0.8624326578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 246}], {
             RGBColor[
             0.9911962105263157, 0.9906274210526316, 0.7955651052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 256}], {
             RGBColor[
             0.8325516842105263, 0.8672602105263159, 0.8526547631578946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 296}], {
             RGBColor[
             0.7163991052631579, 0.7729787368421053, 0.8433312368421051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 299}], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 106}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 151}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 194}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 215}], {
             RGBColor[
             0.9000812894736843, 0.8320507368421053, 0.6255228157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 247}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 267}], {
             RGBColor[
             0.9311896052631579, 0.9435112105263158, 0.7700369473684209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 286}], {
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 87}], {
             RGBColor[
             0.7688118157894737, 0.8041308421052632, 0.6767151052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 95}], {
             RGBColor[
             0.6658008157894737, 0.7176094210526316, 0.6694048947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 96}], {
             RGBColor[
             0.9615308157894737, 0.9569462105263158, 0.6924501315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 105}], {
             RGBColor[
             0.7114551315789474, 0.7571528947368421, 0.672313947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 140}], {
             RGBColor[
             0.7114551315789474, 0.7571528947368421, 0.672313947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 149}], {
             RGBColor[
             0.9267582368421052, 0.9292853157894737, 0.6914153684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 171}], {
             RGBColor[
             0.9581334210526316, 0.8631893684210526, 0.3295990263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 245}], {
             RGBColor[
             0.8836998157894738, 0.8952539473684211, 0.6872282105263157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 289}], {
             RGBColor[
             0.9615308157894737, 0.9569462105263158, 0.6924501315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 298}], {
             RGBColor[
             0.6658008157894737, 0.7176094210526316, 0.6694048947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 90}], {
             RGBColor[
             0.3467912631578948, 0.4747948947368422, 0.9433182105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 123}], {
             RGBColor[
             0.6425212631578947, 0.7141316842105263, 0.9663634473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 158}], {
             RGBColor[
             0.6578348421052631, 0.7255525263157896, 0.9404415526315789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 233}], {
             RGBColor[
             0.6672426842105263, 0.731987052631579, 0.8984611315789475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 257}], {
             RGBColor[
             0.6425212631578947, 0.7141316842105263, 0.9663634473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 259}], {
             RGBColor[
             0.5646902631578948, 0.6524394210526316, 0.9611415263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 262}], {
             RGBColor[
             0.6702321842105263, 0.7318353157894737, 0.7480264736842104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 124}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 142}], {
             RGBColor[
             0.9317022105263157, 0.9451111578947369, 0.8624326578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 143}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 150}], {
             RGBColor[
             0.9267582368421052, 0.9292853157894737, 0.6914153684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 167}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 174}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 185}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 237}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 239}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 282}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 283}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 295}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 297}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 99}], {
             RGBColor[
             0.7163991052631579, 0.7729787368421053, 0.8433312368421051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 128}], {
             RGBColor[
             0.7737557894736842, 0.8199566842105264, 0.8477323947368419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[
             0.7163991052631579, 0.7729787368421053, 0.8433312368421051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 201}], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 209}], {
             RGBColor[
             0.9060086578947368, 0.5631013157894738, 0.45087207894736825`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 218}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 229}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 261}], {
             RGBColor[
             0.9317022105263157, 0.9451111578947369, 0.8624326578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 284}], {
             RGBColor[
             0.9630773947368421, 0.8790152105263158, 0.5006163157894735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 91}], {
             RGBColor[
             0.9911962105263157, 0.9906274210526316, 0.7955651052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 162}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 191}], {
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 203}], {
             RGBColor[
             0.9862522368421052, 0.9748015789473685, 0.6245478157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 206}], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 244}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 270}], {
             RGBColor[
             0.5833105526315789, 0.647286605263158, 0.8935525263157895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 118}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 120}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 130}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 176}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 193}], {
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 220}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 226}], {
             RGBColor[
             0.8930987105263157, 0.5552185789473685, 0.550891447368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 236}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 266}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 93}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 103}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 116}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 119}], {
             RGBColor[
             0.6578348421052632, 0.7255525263157896, 0.9404415526315789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 164}], {
             RGBColor[
             0.6578348421052632, 0.7255525263157896, 0.9404415526315789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 168}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 241}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 103}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 116}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 133}], {
             RGBColor[
             0.7608458421052632, 0.8120739473684211, 0.9477517631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 152}], {
             RGBColor[
             0.7608458421052632, 0.8120739473684211, 0.9477517631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 210}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 241}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 277}], {
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 180}], {
             RGBColor[
             0.5542524736842105, 0.6481633157894737, 0.9584598421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[0.7158865, 0.7713787894736842, 0.7509355263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 285}], {
             RGBColor[
             0.6847781842105263, 0.6599183157894737, 0.6064213947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 100}], {
             RGBColor[
             0.9267582368421052, 0.9292853157894737, 0.6914153684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 107}], {
             RGBColor[
             0.8836998157894738, 0.8952539473684211, 0.6872282105263157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 127}], {
             RGBColor[
             0.7688118157894737, 0.8041308421052632, 0.6767151052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 137}], {
             RGBColor[
             0.7114551315789474, 0.7571528947368421, 0.672313947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 192}], {
             RGBColor[
             0.9862522368421052, 0.9748015789473685, 0.6245478157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 199}], {
             RGBColor[
             0.9768443947368421, 0.968367052631579, 0.6665282368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 220}], {
             RGBColor[
             0.9897543421052631, 0.9762497894736842, 0.5665088684210524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 226}], {
             RGBColor[
             0.9010646842105263, 0.5472754736842105, 0.27985478947368414`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 228}], {
             RGBColor[
             0.9615308157894737, 0.9569462105263158, 0.6924501315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 266}], {
             RGBColor[
             0.9768443947368421, 0.968367052631579, 0.6665282368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 281}], {
             RGBColor[
             0.9897543421052631, 0.9762497894736842, 0.5665088684210524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 126}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 155}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 156}], {
             RGBColor[
             0.965305447368421, 0.9294434736842105, 0.6217016052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 184}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[
             0.7608458421052632, 0.8120739473684211, 0.9477517631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 202}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 214}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 275}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 293}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 89}], {
             RGBColor[
             0.9906836052631578, 0.9890274736842106, 0.703169394736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.6672426842105263, 0.731987052631579, 0.8984611315789475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 112}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 134}], {
             RGBColor[
             0.9906836052631578, 0.9890274736842106, 0.703169394736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 144}], {
             RGBColor[
             0.9906836052631578, 0.9890274736842106, 0.703169394736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 158}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 159}], {
             RGBColor[
             0.6243060263157895, 0.6903754473684212, 0.8958871578947369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 175}], {
             RGBColor[
             0.9906836052631578, 0.9890274736842106, 0.703169394736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 252}], {
             RGBColor[0.9747132894736842, 0.935878, 0.5797211842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 253}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 280}], {
             RGBColor[
             0.8851416842105263, 0.9096315789473685, 0.9162844473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 292}], {
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 122}], {
             RGBColor[
             0.6578348421052632, 0.7255525263157896, 0.9404415526315789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 136}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 165}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 181}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 207}], {
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 232}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 240}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 246}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 256}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 296}], {
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 299}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 107}], {
             RGBColor[
             0.8851416842105263, 0.9096315789473685, 0.9162844473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 109}], {
             RGBColor[
             0.9906836052631578, 0.9890274736842106, 0.703169394736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 110}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 141}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 165}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 179}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 240}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 281}], {
             RGBColor[
             0.9911962105263157, 0.9906274210526316, 0.7955651052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 149}], {
             RGBColor[
             0.7107596842105264, 0.7729922105263158, 0.9726388947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 187}], {
             RGBColor[
             0.7455322631578948, 0.8006531052631579, 0.9736736578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 227}], {
             RGBColor[
             0.49545657894736844`, 0.6008597894736842, 0.9535374736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 264}], {
             RGBColor[
             0.7455322631578948, 0.8006531052631579, 0.9736736578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 99}], {
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 198}], {
             RGBColor[
             0.6425212631578948, 0.7141316842105263, 0.9663634473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 201}], {
             RGBColor[
             0.9664747894736843, 0.972772052631579, 0.8634674210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 222}], {
             RGBColor[
             0.9499918684210527, 0.9180226315789473, 0.6476234999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 258}], {
             RGBColor[
             0.6425212631578948, 0.7141316842105263, 0.9663634473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 260}], {
             RGBColor[
             0.8604202631578948, 0.8917762105263158, 0.9841867631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 261}], {
             RGBColor[
             0.9034786842105264, 0.9258075789473684, 0.9883739210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 278}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 290}], {
             RGBColor[
             0.8604202631578948, 0.8917762105263158, 0.9841867631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 111}], {
             RGBColor[
             0.7732431842105263, 0.8183567368421053, 0.7553366842105261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 112}], {
             RGBColor[
             0.9812757631578948, 0.9825929473684211, 0.7451498157894735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 175}], {
             RGBColor[
             0.9936731052631579, 0.9888757368421053, 0.552734736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 177}], {
             RGBColor[
             0.9311896052631579, 0.9435112105263158, 0.7700369473684209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 242}], {
             RGBColor[0.7158865, 0.7713787894736842, 0.7509355263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.8881311842105264, 0.9094798421052632, 0.765849789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 285}], {
             RGBColor[
             0.9625647894736842, 0.8774152631578948, 0.40822060526315773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 123}], {
             RGBColor[
             0.6425212631578947, 0.7141316842105263, 0.9663634473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 134}], {
             RGBColor[
             0.6702321842105263, 0.7318353157894737, 0.7480264736842104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 144}], {
             RGBColor[
             0.6702321842105263, 0.7318353157894737, 0.7480264736842104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 158}], {
             RGBColor[
             0.6578348421052631, 0.7255525263157896, 0.9404415526315789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 252}], {
             RGBColor[
             0.6542618684210526, 0.6786858421052632, 0.6245782631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 253}], {
             RGBColor[
             0.6425212631578947, 0.7141316842105263, 0.9663634473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[
             0.6425212631578947, 0.7141316842105263, 0.9663634473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 102}], {
             RGBColor[
             0.9911962105263157, 0.9906274210526316, 0.7955651052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 162}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 191}], {
             RGBColor[
             0.8325516842105263, 0.8672602105263159, 0.8526547631578946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 203}], {
             RGBColor[
             0.9897543421052631, 0.9762497894736842, 0.5665088684210524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 239}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 153}], {
             RGBColor[
             0.6687517631578948, 0.5949895263157896, 0.5934542894736843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 163}], {
             RGBColor[
             0.840996447368421, 0.7330905789473685, 0.608368552631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 189}], {
             RGBColor[
             0.6687517631578948, 0.5949895263157896, 0.5934542894736843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 211}], {
             RGBColor[
             0.9470509736842105, 0.8140864210526317, 0.48764921052631566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 216}], {
             RGBColor[
             0.8840548684210527, 0.7671219473684212, 0.6125557105263157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 221}], {
             RGBColor[
             0.9470509736842105, 0.8140864210526317, 0.48764921052631566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 94}], {
             RGBColor[
             0.6707447894736842, 0.7334352631578949, 0.8404221842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 160}], {
             RGBColor[
             0.9317022105263157, 0.9451111578947369, 0.8624326578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 164}], {
             RGBColor[
             0.6707447894736842, 0.7334352631578949, 0.8404221842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 168}], {
             RGBColor[
             0.9317022105263157, 0.9451111578947369, 0.8624326578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 277}], {
             RGBColor[
             0.7163991052631579, 0.7729787368421053, 0.8433312368421051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 124}], {
             RGBColor[
             0.6077486842105264, 0.6864707894736843, 0.9653286842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 125}], {
             RGBColor[
             0.6578348421052631, 0.7255525263157896, 0.9404415526315789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 142}], {
             RGBColor[
             0.6707447894736842, 0.7334352631578949, 0.8404221842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 150}], {
             RGBColor[
             0.6658008157894737, 0.7176094210526316, 0.6694048947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 200}], {
             RGBColor[
             0.508598157894737, 0.6086198421052633, 0.9555507894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.6672426842105263, 0.731987052631579, 0.8984611315789475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 295}], {
             RGBColor[
             0.5646902631578948, 0.6524394210526316, 0.9611415263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 96}], {
             RGBColor[
             0.6425212631578947, 0.7141316842105263, 0.9663634473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 105}], {
             RGBColor[
             0.3924455789473684, 0.5143383684210527, 0.9462272631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 109}], {
             RGBColor[
             0.6702321842105263, 0.7318353157894737, 0.7480264736842104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 138}], {
             RGBColor[
             0.6425212631578947, 0.7141316842105263, 0.9663634473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 140}], {
             RGBColor[
             0.3924455789473684, 0.5143383684210527, 0.9462272631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 154}], {
             RGBColor[
             0.6077486842105264, 0.6864707894736843, 0.9653286842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 171}], {
             RGBColor[
             0.6391238684210527, 0.6203748421052633, 0.6035123421052632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 198}], {
             RGBColor[
             0.3467912631578948, 0.4747948947368422, 0.9433182105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 245}], {
             RGBColor[
             0.5646902631578948, 0.6524394210526316, 0.9611415263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 289}], {
             RGBColor[
             0.6425212631578947, 0.7141316842105263, 0.9663634473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 105}], {
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 138}], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 140}], {
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 171}], {
             RGBColor[
             0.9348538684210527, 0.8597116315789474, 0.6265575789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 196}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 198}], {
             RGBColor[
             0.6425212631578948, 0.7141316842105263, 0.9663634473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 222}], {
             RGBColor[
             0.9499918684210527, 0.9180226315789473, 0.6476234999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 245}], {
             RGBColor[
             0.8604202631578948, 0.8917762105263158, 0.9841867631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 278}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 289}], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 290}], {
             RGBColor[
             0.8604202631578948, 0.8917762105263158, 0.9841867631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 298}], {
             RGBColor[
             0.6425212631578948, 0.7141316842105263, 0.9663634473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 134}], {
             RGBColor[
             0.9812757631578948, 0.9825929473684211, 0.7451498157894735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 144}], {
             RGBColor[
             0.9812757631578948, 0.9825929473684211, 0.7451498157894735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 159}], {
             RGBColor[
             0.6148981842105263, 0.6839409210526316, 0.9378675789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 235}], {
             RGBColor[
             0.5739027105263158, 0.6408520789473684, 0.9355329473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 252}], {
             RGBColor[
             0.965305447368421, 0.9294434736842105, 0.6217016052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 292}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 122}], {
             RGBColor[
             0.5646902631578948, 0.6524394210526316, 0.9611415263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 160}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 178}], {
             RGBColor[
             0.8886437894736843, 0.9110797894736842, 0.8582454999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 181}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 182}], {
             RGBColor[
             0.8851416842105263, 0.9096315789473685, 0.9162844473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 208}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 246}], {
             RGBColor[
             0.8851416842105263, 0.9096315789473685, 0.9162844473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 296}], {
             RGBColor[
             0.6103445789473685, 0.691982894736842, 0.9640505789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 104}], {
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 123}], {
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 157}], {
             RGBColor[
             0.4380998947368421, 0.5538818421052631, 0.9491363157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 201}], {
             RGBColor[
             0.7163991052631579, 0.7729787368421053, 0.8433312368421051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 222}], {
             RGBColor[
             0.6999161842105264, 0.7182293157894737, 0.6274873157894736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 229}], {
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 257}], {
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 259}], {
             RGBColor[
             0.6103445789473685, 0.691982894736842, 0.9640505789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 261}], {
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 121}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 125}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 127}], {
             RGBColor[
             0.7107596842105264, 0.7729922105263158, 0.9726388947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 136}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 137}], {
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 170}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 192}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 228}], {
             RGBColor[
             0.9034786842105264, 0.9258075789473684, 0.9883739210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 232}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 240}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 256}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 299}], {
             RGBColor[
             0.9317022105263157, 0.9451111578947369, 0.8624326578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 108}], {
             RGBColor[
             0.8886437894736843, 0.9110797894736842, 0.8582454999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 114}], {
             RGBColor[
             0.8604202631578948, 0.8917762105263158, 0.9841867631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 187}], {
             RGBColor[
             0.8604202631578948, 0.8917762105263158, 0.9841867631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 205}], {
             RGBColor[
             0.8851416842105263, 0.9096315789473685, 0.9162844473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 207}], {
             RGBColor[
             0.6103445789473685, 0.691982894736842, 0.9640505789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 213}], {
             RGBColor[
             0.8851416842105263, 0.9096315789473685, 0.9162844473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 231}], {
             RGBColor[
             0.7825892631578948, 0.8300839473684211, 0.9789648421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 133}], {
             RGBColor[
             0.7702536842105263, 0.8185084736842105, 0.9057713421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 142}], {
             RGBColor[
             0.9911962105263157, 0.9906274210526316, 0.7955651052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 162}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 210}], {
             RGBColor[
             0.9911962105263157, 0.9906274210526316, 0.7955651052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 237}], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 239}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 295}], {
             RGBColor[
             0.8851416842105263, 0.9096315789473685, 0.9162844473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 116}], {
             RGBColor[
             0.9034786842105264, 0.9258075789473684, 0.9883739210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 119}], {
             RGBColor[
             0.6077486842105264, 0.6864707894736843, 0.9653286842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 152}], {
             RGBColor[
             0.7107596842105264, 0.7729922105263158, 0.9726388947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 164}], {
             RGBColor[
             0.6077486842105264, 0.6864707894736843, 0.9653286842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 168}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 241}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 277}], {
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 128}], {
             RGBColor[
             0.7608458421052632, 0.8120739473684211, 0.9477517631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 157}], {
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 173}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 201}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 209}], {
             RGBColor[
             0.8930987105263157, 0.5552185789473685, 0.550891447368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 218}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 229}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 261}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 279}], {
             RGBColor[
             0.7608458421052632, 0.8120739473684211, 0.9477517631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 129}], {
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 140}], {
             RGBColor[
             0.4380998947368421, 0.5538818421052631, 0.9491363157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 149}], {
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 171}], {
             RGBColor[
             0.6847781842105263, 0.6599183157894737, 0.6064213947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 196}], {
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 230}], {
             RGBColor[
             0.7128969999999999, 0.7715305263157894, 0.9013701842105264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 245}], {
             RGBColor[
             0.6103445789473685, 0.691982894736842, 0.9640505789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 263}], {
             RGBColor[
             0.5542524736842105, 0.6481633157894737, 0.9584598421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 289}], {
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 298}], {
             RGBColor[
             0.3924455789473684, 0.5143383684210527, 0.9462272631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 151}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 167}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 194}], {
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 215}], {
             RGBColor[0.9595752894736842, 0.877567, 0.5586552631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 283}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 286}], {
             RGBColor[
             0.7128969999999999, 0.7715305263157894, 0.9013701842105264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 297}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 110}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 127}], {
             RGBColor[
             0.6677012631578948, 0.7389608421052631, 0.9684517368421053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 141}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 165}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 240}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 281}], {
             RGBColor[
             0.8886437894736843, 0.9110797894736842, 0.8582454999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 114}], {
             RGBColor[
             0.9664747894736843, 0.972772052631579, 0.8634674210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 145}], {
             RGBColor[
             0.6278081315789473, 0.6918236578947369, 0.8378482105263156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 169}], {
             RGBColor[
             0.9664747894736843, 0.972772052631579, 0.8634674210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 187}], {
             RGBColor[
             0.9664747894736843, 0.972772052631579, 0.8634674210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 205}], {
             RGBColor[
             0.9911962105263157, 0.9906274210526316, 0.7955651052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 213}], {
             RGBColor[
             0.9911962105263157, 0.9906274210526316, 0.7955651052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 219}], {
             RGBColor[
             0.9664747894736843, 0.972772052631579, 0.8634674210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 221}], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 264}], {
             RGBColor[
             0.9664747894736843, 0.972772052631579, 0.8634674210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 110}], {
             RGBColor[
             0.9812757631578948, 0.9825929473684211, 0.7451498157894735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 138}], {
             RGBColor[
             0.9659621842105264, 0.9711721052631579, 0.7710717105263156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 154}], {
             RGBColor[
             0.9311896052631579, 0.9435112105263158, 0.7700369473684209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 179}], {
             RGBColor[
             0.9311896052631579, 0.9435112105263158, 0.7700369473684209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 258}], {
             RGBColor[
             0.6702321842105263, 0.7318353157894737, 0.7480264736842104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 138}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 141}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 154}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 165}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 179}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 281}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 190}], {
             RGBColor[
             0.7421348684210527, 0.7068962631578948, 0.6108225526315789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 212}], {
             RGBColor[
             0.7107596842105264, 0.7729922105263158, 0.9726388947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 242}], {
             RGBColor[
             0.49545657894736844`, 0.6008597894736842, 0.9535374736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 250}], {
             RGBColor[
             0.7702536842105263, 0.8185084736842105, 0.9057713421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 280}], {
             RGBColor[
             0.6677012631578948, 0.7389608421052631, 0.9684517368421053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 115}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 134}], {
             RGBColor[
             0.9812757631578948, 0.9825929473684211, 0.7451498157894735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 146}], {
             RGBColor[
             0.7608458421052632, 0.8120739473684211, 0.9477517631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 159}], {
             RGBColor[
             0.6148981842105263, 0.6839409210526316, 0.9378675789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 175}], {
             RGBColor[
             0.9812757631578948, 0.9825929473684211, 0.7451498157894735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 204}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 235}], {
             RGBColor[
             0.5739027105263158, 0.6408520789473684, 0.9355329473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 242}], {
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 252}], {
             RGBColor[
             0.965305447368421, 0.9294434736842105, 0.6217016052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 253}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 280}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 292}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 135}], {
             RGBColor[
             0.8851416842105263, 0.9096315789473685, 0.9162844473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 224}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 249}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 254}], {
             RGBColor[
             0.9906836052631578, 0.9890274736842106, 0.703169394736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 258}], {
             RGBColor[
             0.6672426842105263, 0.731987052631579, 0.8984611315789475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 260}], {
             RGBColor[
             0.8851416842105263, 0.9096315789473685, 0.9162844473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 278}], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 288}], {
             RGBColor[
             0.5833105526315789, 0.647286605263158, 0.8935525263157895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 290}], {
             RGBColor[
             0.8851416842105263, 0.9096315789473685, 0.9162844473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 145}], {
             RGBColor[
             0.5995846052631579, 0.6725200789473684, 0.9637894736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 169}], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 187}], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 213}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 219}], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 221}], {
             RGBColor[
             0.9664747894736843, 0.972772052631579, 0.8634674210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 231}], {
             RGBColor[
             0.8604202631578948, 0.8917762105263158, 0.9841867631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 264}], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 132}], {
             RGBColor[
             0.9615308157894737, 0.9569462105263158, 0.6924501315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 146}], {
             RGBColor[
             0.7455322631578948, 0.8006531052631579, 0.9736736578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 159}], {
             RGBColor[
             0.5995846052631579, 0.6725200789473684, 0.9637894736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 204}], {
             RGBColor[
             0.9034786842105264, 0.9258075789473684, 0.9883739210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 242}], {
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 243}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 294}], {
             RGBColor[
             0.9034786842105264, 0.9258075789473684, 0.9883739210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 119}], {
             RGBColor[
             0.6425212631578948, 0.7141316842105263, 0.9663634473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 133}], {
             RGBColor[
             0.7455322631578948, 0.8006531052631579, 0.9736736578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 152}], {
             RGBColor[
             0.7455322631578948, 0.8006531052631579, 0.9736736578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 164}], {
             RGBColor[
             0.6425212631578948, 0.7141316842105263, 0.9663634473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 168}], {
             RGBColor[
             0.9034786842105264, 0.9258075789473684, 0.9883739210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 210}], {
             RGBColor[
             0.9664747894736843, 0.972772052631579, 0.8634674210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 241}], {
             RGBColor[
             0.8604202631578948, 0.8917762105263158, 0.9841867631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 277}], {
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 161}], {
             RGBColor[
             0.9812757631578948, 0.9825929473684211, 0.7451498157894735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 120}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 130}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 176}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 220}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 226}], {
             RGBColor[
             0.8930987105263157, 0.5552185789473685, 0.550891447368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 228}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 266}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 152}], {
             RGBColor[
             0.44980226315789484`, 0.5613163157894738, 0.9506284210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 164}], {
             RGBColor[
             0.3467912631578948, 0.4747948947368422, 0.9433182105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 168}], {
             RGBColor[
             0.6077486842105264, 0.6864707894736843, 0.9653286842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 241}], {
             RGBColor[
             0.5646902631578948, 0.6524394210526316, 0.9611415263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 130}], {
             RGBColor[
             0.7264971578947369, 0.7862643684210526, 0.9733741052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 176}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 287}], {
             RGBColor[
             0.8043281578947369, 0.8479566315789474, 0.9785960263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 125}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 127}], {
             RGBColor[
             0.7107596842105264, 0.7729922105263158, 0.9726388947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 136}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 137}], {
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 160}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 181}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 232}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 240}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 246}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 256}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 296}], {
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 299}], {
             RGBColor[
             0.9317022105263157, 0.9451111578947369, 0.8624326578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 136}], {
             RGBColor[
             0.6578348421052631, 0.7255525263157896, 0.9404415526315789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 160}], {
             RGBColor[
             0.6077486842105264, 0.6864707894736843, 0.9653286842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 181}], {
             RGBColor[
             0.6077486842105264, 0.6864707894736843, 0.9653286842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 207}], {
             RGBColor[
             0.3924455789473684, 0.5143383684210527, 0.9462272631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 231}], {
             RGBColor[
             0.5646902631578948, 0.6524394210526316, 0.9611415263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 232}], {
             RGBColor[
             0.5646902631578948, 0.6524394210526316, 0.9611415263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 240}], {
             RGBColor[
             0.6077486842105264, 0.6864707894736843, 0.9653286842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 246}], {
             RGBColor[
             0.6672426842105263, 0.731987052631579, 0.8984611315789475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 256}], {
             RGBColor[
             0.508598157894737, 0.6086198421052633, 0.9555507894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 296}], {
             RGBColor[
             0.3924455789473684, 0.5143383684210527, 0.9462272631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 299}], {
             RGBColor[
             0.6707447894736842, 0.7334352631578949, 0.8404221842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 144}], {
             RGBColor[
             0.9659621842105264, 0.9711721052631579, 0.7710717105263156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 157}], {
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 229}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 257}], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 259}], {
             RGBColor[
             0.8604202631578948, 0.8917762105263158, 0.9841867631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 261}], {
             RGBColor[
             0.9034786842105264, 0.9258075789473684, 0.9883739210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 125}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 142}], {
             RGBColor[
             0.9317022105263157, 0.9451111578947369, 0.8624326578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 150}], {
             RGBColor[
             0.9267582368421052, 0.9292853157894737, 0.6914153684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 200}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 237}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 282}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 295}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 136}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 150}], {
             RGBColor[
             0.9768443947368421, 0.968367052631579, 0.6665282368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 192}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 195}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 200}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 256}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 299}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 155}], {
             RGBColor[
             0.9664747894736843, 0.972772052631579, 0.8634674210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 163}], {
             RGBColor[
             0.8886437894736843, 0.9110797894736842, 0.8582454999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 184}], {
             RGBColor[
             0.9664747894736843, 0.972772052631579, 0.8634674210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 189}], {
             RGBColor[
             0.7163991052631579, 0.7729787368421053, 0.8433312368421051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 197}], {
             RGBColor[
             0.7737557894736842, 0.8199566842105264, 0.8477323947368419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 214}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 216}], {
             RGBColor[
             0.9317022105263157, 0.9451111578947369, 0.8624326578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 275}], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 293}], {
             RGBColor[
             0.9911962105263157, 0.9906274210526316, 0.7955651052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 136}], {
             RGBColor[
             0.7608458421052632, 0.8120739473684211, 0.9477517631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 137}], {
             RGBColor[
             0.49545657894736844`, 0.6008597894736842, 0.9535374736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 141}], {
             RGBColor[
             0.7608458421052632, 0.8120739473684211, 0.9477517631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 165}], {
             RGBColor[
             0.7608458421052632, 0.8120739473684211, 0.9477517631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 170}], {
             RGBColor[
             0.7702536842105263, 0.8185084736842105, 0.9057713421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 192}], {
             RGBColor[
             0.7702536842105263, 0.8185084736842105, 0.9057713421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 228}], {
             RGBColor[
             0.7455322631578948, 0.8006531052631579, 0.9736736578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 232}], {
             RGBColor[
             0.6677012631578948, 0.7389608421052631, 0.9684517368421053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 240}], {
             RGBColor[
             0.7107596842105264, 0.7729922105263158, 0.9726388947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 256}], {
             RGBColor[0.6116091578947369, 0.6951412631578948, 0.962861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 281}], {
             RGBColor[
             0.7737557894736842, 0.8199566842105264, 0.8477323947368419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 299}], {
             RGBColor[
             0.7737557894736842, 0.8199566842105264, 0.8477323947368419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 173}], {
             RGBColor[
             0.7737557894736842, 0.8199566842105264, 0.8477323947368419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 209}], {
             RGBColor[
             0.6850661315789475, 0.39098236842105266`, 0.5610783157894736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 218}], {
             RGBColor[
             0.7608458421052632, 0.8120739473684211, 0.9477517631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 276}], {
             RGBColor[
             0.7608458421052632, 0.8120739473684211, 0.9477517631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 279}], {
             RGBColor[
             0.5528132631578948, 0.6478377368421053, 0.9579386315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 161}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 230}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 263}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 265}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 269}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 289}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 298}], {
             RGBColor[
             0.6578348421052632, 0.7255525263157896, 0.9404415526315789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 176}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 199}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 220}], {
             RGBColor[
             0.8886437894736843, 0.9110797894736842, 0.8582454999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 226}], {
             RGBColor[
             0.7999541315789473, 0.48210547368421053`, 0.5715914210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 228}], {
             RGBColor[
             0.8604202631578948, 0.8917762105263158, 0.9841867631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 266}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 139}], {
             RGBColor[
             0.6391238684210527, 0.6203748421052633, 0.6035123421052632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 143}], {
             RGBColor[
             0.8009307631578948, 0.7541997894736843, 0.6157449210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 172}], {
             RGBColor[
             0.8009307631578948, 0.7541997894736843, 0.6157449210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 174}], {
             RGBColor[
             0.8570228684210527, 0.7980193684210526, 0.6213356578947369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 183}], {
             RGBColor[
             0.8570228684210527, 0.7980193684210526, 0.6213356578947369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 283}], {
             RGBColor[
             0.9000812894736843, 0.8320507368421053, 0.6255228157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 188}], {
             RGBColor[
             0.9897543421052631, 0.9762497894736842, 0.5665088684210524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 212}], {
             RGBColor[
             0.9267582368421052, 0.9292853157894737, 0.6914153684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 243}], {
             RGBColor[
             0.9862522368421052, 0.9748015789473685, 0.6245478157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 294}], {
             RGBColor[
             0.9267582368421052, 0.9292853157894737, 0.6914153684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 162}], {
             RGBColor[
             0.7608458421052632, 0.8120739473684211, 0.9477517631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 164}], {
             RGBColor[
             0.44980226315789484`, 0.5613163157894738, 0.9506284210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 210}], {
             RGBColor[
             0.7737557894736842, 0.8199566842105264, 0.8477323947368419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 239}], {
             RGBColor[
             0.7608458421052632, 0.8120739473684211, 0.9477517631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 241}], {
             RGBColor[
             0.6677012631578948, 0.7389608421052631, 0.9684517368421053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 277}], {
             RGBColor[
             0.49545657894736844`, 0.6008597894736842, 0.9535374736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 144}], {
             RGBColor[
             0.9936731052631579, 0.9888757368421053, 0.552734736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 159}], {
             RGBColor[
             0.6272955263157894, 0.6902237105263158, 0.7454524999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 175}], {
             RGBColor[
             0.9936731052631579, 0.9888757368421053, 0.552734736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 204}], {
             RGBColor[
             0.9311896052631579, 0.9435112105263158, 0.7700369473684209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 235}], {
             RGBColor[
             0.5863000526315789, 0.6471348684210526, 0.7431178684210524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 252}], {
             RGBColor[
             0.9777027894736843, 0.9357262631578946, 0.42928652631578923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 253}], {
             RGBColor[
             0.9659621842105264, 0.9711721052631579, 0.7710717105263156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 292}], {
             RGBColor[
             0.8320390789473684, 0.8656602631578948, 0.7602590526315788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 224}], {
             RGBColor[
             0.8604202631578948, 0.8917762105263158, 0.9841867631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 249}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 254}], {
             RGBColor[
             0.8881311842105264, 0.9094798421052632, 0.765849789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 258}], {
             RGBColor[
             0.5646902631578948, 0.6524394210526316, 0.9611415263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 260}], {
             RGBColor[
             0.7825892631578948, 0.8300839473684211, 0.9789648421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 288}], {
             RGBColor[
             0.4807581315789474, 0.5677389736842106, 0.9562329210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 137}], {
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 165}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 181}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 232}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 240}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 256}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 296}], {
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 299}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 170}], {
             RGBColor[
             0.7128969999999999, 0.7715305263157894, 0.9013701842105264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 192}], {
             RGBColor[
             0.7128969999999999, 0.7715305263157894, 0.9013701842105264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 195}], {
             RGBColor[
             0.7163991052631579, 0.7729787368421053, 0.8433312368421051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 220}], {
             RGBColor[
             0.7163991052631579, 0.7729787368421053, 0.8433312368421051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 228}], {
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 232}], {
             RGBColor[
             0.6103445789473685, 0.691982894736842, 0.9640505789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 256}], {
             RGBColor[
             0.5542524736842105, 0.6481633157894737, 0.9584598421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 266}], {
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 299}], {
             RGBColor[
             0.7163991052631579, 0.7729787368421053, 0.8433312368421051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 154}], {
             RGBColor[
             0.9034786842105264, 0.9258075789473684, 0.9883739210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 171}], {
             RGBColor[
             0.9348538684210527, 0.8597116315789474, 0.6265575789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 245}], {
             RGBColor[
             0.8604202631578948, 0.8917762105263158, 0.9841867631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 258}], {
             RGBColor[
             0.6425212631578948, 0.7141316842105263, 0.9663634473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 147}], {
             RGBColor[
             0.6425212631578947, 0.7141316842105263, 0.9663634473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 148}], {
             RGBColor[
             0.6542618684210526, 0.6786858421052632, 0.6245782631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 172}], {
             RGBColor[
             0.508598157894737, 0.6086198421052633, 0.9555507894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 183}], {
             RGBColor[
             0.5646902631578948, 0.6524394210526316, 0.9611415263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 206}], {
             RGBColor[
             0.6672426842105263, 0.731987052631579, 0.8984611315789475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 244}], {
             RGBColor[
             0.6425212631578947, 0.7141316842105263, 0.9663634473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 272}], {
             RGBColor[
             0.6672426842105263, 0.731987052631579, 0.8984611315789475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 149}], {
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 171}], {
             RGBColor[
             0.6847781842105263, 0.6599183157894737, 0.6064213947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 196}], {
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 198}], {
             RGBColor[
             0.3924455789473684, 0.5143383684210527, 0.9462272631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 222}], {
             RGBColor[
             0.6999161842105264, 0.7182293157894737, 0.6274873157894736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 230}], {
             RGBColor[
             0.7128969999999999, 0.7715305263157894, 0.9013701842105264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 245}], {
             RGBColor[
             0.6103445789473685, 0.691982894736842, 0.9640505789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 263}], {
             RGBColor[
             0.5542524736842105, 0.6481633157894737, 0.9584598421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 289}], {
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 298}], {
             RGBColor[
             0.3924455789473684, 0.5143383684210527, 0.9462272631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 165}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 179}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 232}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 281}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[
             0.9897543421052631, 0.9762497894736842, 0.5665088684210524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 185}], {
             RGBColor[
             0.8325516842105263, 0.8672602105263159, 0.8526547631578946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 210}], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 237}], {
             RGBColor[
             0.9911962105263157, 0.9906274210526316, 0.7955651052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 239}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 282}], {
             RGBColor[
             0.9317022105263157, 0.9451111578947369, 0.8624326578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 283}], {
             RGBColor[
             0.9317022105263157, 0.9451111578947369, 0.8624326578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 295}], {
             RGBColor[
             0.8886437894736843, 0.9110797894736842, 0.8582454999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 297}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 167}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 172}], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 174}], {
             RGBColor[
             0.7264971578947369, 0.7862643684210526, 0.9733741052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 185}], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 237}], {
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 239}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 283}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 297}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 158}], {
             RGBColor[
             0.9812757631578948, 0.9825929473684211, 0.7451498157894735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 235}], {
             RGBColor[
             0.5863000526315789, 0.6471348684210526, 0.7431178684210524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 252}], {
             RGBColor[
             0.9777027894736843, 0.9357262631578946, 0.42928652631578923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 253}], {
             RGBColor[
             0.9659621842105264, 0.9711721052631579, 0.7710717105263156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 257}], {
             RGBColor[
             0.9659621842105264, 0.9711721052631579, 0.7710717105263156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 292}], {
             RGBColor[
             0.8320390789473684, 0.8656602631578948, 0.7602590526315788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 169}], {
             RGBColor[
             0.5995846052631579, 0.6725200789473684, 0.9637894736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 219}], {
             RGBColor[
             0.5995846052631579, 0.6725200789473684, 0.9637894736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 221}], {
             RGBColor[
             0.6278081315789474, 0.6918236578947369, 0.8378482105263156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 264}], {
             RGBColor[
             0.5995846052631579, 0.6725200789473684, 0.9637894736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 159}], {
             RGBColor[
             0.40686560526315796`, 0.5197047105263158, 0.948054447368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 204}], {
             RGBColor[
             0.7107596842105264, 0.7729922105263158, 0.9726388947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 235}], {
             RGBColor[
             0.36587013157894743`, 0.47661586842105264`, 0.9457198157894737]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 242}], {
             RGBColor[
             0.49545657894736844`, 0.6008597894736842, 0.9535374736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 243}], {
             RGBColor[
             0.7702536842105263, 0.8185084736842105, 0.9057713421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 292}], {
             RGBColor[0.6116091578947369, 0.6951412631578948, 0.962861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 148}], {
             RGBColor[
             0.9499918684210527, 0.9180226315789473, 0.6476234999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 172}], {
             RGBColor[
             0.8043281578947369, 0.8479566315789474, 0.9785960263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 183}], {
             RGBColor[
             0.8604202631578948, 0.8917762105263158, 0.9841867631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 206}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 244}], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 270}], {
             RGBColor[
             0.5585891315789474, 0.6294312368421052, 0.9614548421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 272}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 172}], {
             RGBColor[
             0.8160687631578948, 0.8125107894736843, 0.6368108421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 183}], {
             RGBColor[
             0.8721608684210527, 0.8563303684210526, 0.6424015789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 203}], {
             RGBColor[
             0.9732714210526316, 0.9215003684210525, 0.3506649473684209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 206}], {
             RGBColor[0.9747132894736842, 0.935878, 0.5797211842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 244}], {
             RGBColor[
             0.9499918684210527, 0.9180226315789473, 0.6476234999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 270}], {
             RGBColor[
             0.5703297368421053, 0.5939853947368421, 0.6196696578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 272}], {
             RGBColor[0.9747132894736842, 0.935878, 0.5797211842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 171}], {
             RGBColor[
             0.9000812894736843, 0.8320507368421053, 0.6255228157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 227}], {
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 245}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 289}], {
             RGBColor[
             0.9034786842105264, 0.9258075789473684, 0.9883739210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 298}], {
             RGBColor[
             0.6077486842105264, 0.6864707894736843, 0.9653286842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 200}], {
             RGBColor[
             0.8276077105263158, 0.8514343684210527, 0.6816374736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 237}], {
             RGBColor[
             0.9862522368421052, 0.9748015789473685, 0.6245478157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 282}], {
             RGBColor[
             0.9267582368421052, 0.9292853157894737, 0.6914153684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 295}], {
             RGBColor[
             0.8836998157894738, 0.8952539473684211, 0.6872282105263157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 167}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 194}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 251}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 286}], {
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 241}], {
             RGBColor[
             0.6677012631578948, 0.7389608421052631, 0.9684517368421053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 277}], {
             RGBColor[
             0.49545657894736844`, 0.6008597894736842, 0.9535374736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 163}], {
             RGBColor[
             0.6103445789473685, 0.691982894736842, 0.9640505789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 211}], {
             RGBColor[
             0.7163991052631579, 0.7729787368421053, 0.8433312368421051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 216}], {
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 219}], {
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 221}], {
             RGBColor[
             0.7163991052631579, 0.7729787368421053, 0.8433312368421051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 171}], {
             RGBColor[
             0.9000812894736843, 0.8320507368421053, 0.6255228157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 179}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 245}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 156}], {
             RGBColor[
             0.9499918684210527, 0.9180226315789473, 0.6476234999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 184}], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 197}], {
             RGBColor[
             0.7455322631578948, 0.8006531052631579, 0.9736736578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 202}], {
             RGBColor[
             0.8043281578947369, 0.8479566315789474, 0.9785960263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 214}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 275}], {
             RGBColor[
             0.9664747894736843, 0.972772052631579, 0.8634674210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 293}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 178}], {
             RGBColor[
             0.9782153947368422, 0.9373262105263158, 0.521682236842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 202}], {
             RGBColor[
             0.8160687631578948, 0.8125107894736843, 0.6368108421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 208}], {
             RGBColor[
             0.9152192894736842, 0.8903617368421053, 0.6465887368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 214}], {
             RGBColor[
             0.965305447368421, 0.9294434736842105, 0.6217016052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 268}], {
             RGBColor[
             0.9782153947368422, 0.9373262105263158, 0.521682236842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 201}], {
             RGBColor[
             0.7163991052631579, 0.7729787368421053, 0.8433312368421051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 218}], {
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 229}], {
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 257}], {
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 259}], {
             RGBColor[
             0.6103445789473685, 0.691982894736842, 0.9640505789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 261}], {
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 284}], {
             RGBColor[
             0.6847781842105263, 0.6599183157894737, 0.6064213947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 175}], {
             RGBColor[
             0.9812757631578948, 0.9825929473684211, 0.7451498157894735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 177}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 217}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 252}], {
             RGBColor[
             0.965305447368421, 0.9294434736842105, 0.6217016052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 253}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 175}], {
             RGBColor[
             0.6272955263157896, 0.6902237105263158, 0.7454524999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 204}], {
             RGBColor[
             0.5648120263157894, 0.6448591842105263, 0.9627547105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 235}], {
             RGBColor[
             0.21992247368421053`, 0.34848284210526315`, 0.9358356315789473]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 252}], {
             RGBColor[
             0.6113252105263158, 0.6370742368421052, 0.6220042894736841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 253}], {
             RGBColor[
             0.5995846052631579, 0.6725200789473684, 0.9637894736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 292}], {
             RGBColor[
             0.46566150000000006`, 0.5670082368421053, 0.9529768157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 168}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 246}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 256}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 296}], {
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 299}], {
             RGBColor[
             0.9317022105263157, 0.9451111578947369, 0.8624326578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 186}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 230}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 265}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 269}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 191}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 203}], {
             RGBColor[
             0.9768443947368421, 0.968367052631579, 0.6665282368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 210}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 239}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 184}], {
             RGBColor[
             0.8604202631578948, 0.8917762105263158, 0.9841867631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.6103445789473685, 0.691982894736842, 0.9640505789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 197}], {
             RGBColor[
             0.6677012631578948, 0.7389608421052631, 0.9684517368421053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 211}], {
             RGBColor[
             0.8886437894736843, 0.9110797894736842, 0.8582454999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 216}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 168}], {
             RGBColor[
             0.6077486842105264, 0.6864707894736843, 0.9653286842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 210}], {
             RGBColor[
             0.6707447894736842, 0.7334352631578949, 0.8404221842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 241}], {
             RGBColor[
             0.5646902631578948, 0.6524394210526316, 0.9611415263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 277}], {
             RGBColor[
             0.3924455789473684, 0.5143383684210527, 0.9462272631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 179}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 207}], {
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 232}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 240}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 281}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 217}], {
             RGBColor[
             0.7264971578947369, 0.7862643684210526, 0.9733741052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 233}], {
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 262}], {
             RGBColor[
             0.8320390789473684, 0.8656602631578948, 0.7602590526315788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 271}], {
             RGBColor[
             0.8043281578947369, 0.8479566315789474, 0.9785960263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 291}], {
             RGBColor[
             0.8325516842105263, 0.8672602105263159, 0.8526547631578946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 174}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 185}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 194}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 215}], {
             RGBColor[
             0.9501674473684211, 0.8711324736842105, 0.6006356842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 282}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 283}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 286}], {
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 297}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 182}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 277}], {
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 187}], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 213}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 219}], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 221}], {
             RGBColor[
             0.9664747894736843, 0.972772052631579, 0.8634674210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 264}], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 195}], {
             RGBColor[
             0.9911962105263157, 0.9906274210526316, 0.7955651052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 200}], {
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 225}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 228}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 255}], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 198}], {
             RGBColor[
             0.6391238684210527, 0.6203748421052633, 0.6035123421052632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 245}], {
             RGBColor[
             0.8570228684210527, 0.7980193684210526, 0.6213356578947369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 289}], {
             RGBColor[
             0.9348538684210527, 0.8597116315789474, 0.6265575789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 298}], {
             RGBColor[
             0.6391238684210527, 0.6203748421052633, 0.6035123421052632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 174}], {
             RGBColor[
             0.7264971578947369, 0.7862643684210526, 0.9733741052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 183}], {
             RGBColor[
             0.7264971578947369, 0.7862643684210526, 0.9733741052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 203}], {
             RGBColor[
             0.8276077105263158, 0.8514343684210527, 0.6816374736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 206}], {
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 244}], {
             RGBColor[
             0.8043281578947369, 0.8479566315789474, 0.9785960263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 270}], {
             RGBColor[
             0.42466602631578954`, 0.5239193947368421, 0.9506421842105264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 272}], {
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 186}], {
             RGBColor[
             0.8325516842105263, 0.8672602105263159, 0.8526547631578946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 196}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 209}], {
             RGBColor[
             0.9060086578947368, 0.5631013157894738, 0.45087207894736825`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 230}], {
             RGBColor[
             0.9911962105263157, 0.9906274210526316, 0.7955651052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 263}], {
             RGBColor[
             0.8325516842105263, 0.8672602105263159, 0.8526547631578946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 276}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 279}], {
             RGBColor[
             0.7737557894736842, 0.8199566842105264, 0.8477323947368419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 185}], {
             RGBColor[
             0.7264971578947369, 0.7862643684210526, 0.9733741052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 194}], {
             RGBColor[
             0.7264971578947369, 0.7862643684210526, 0.9733741052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 283}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 297}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 177}], {
             RGBColor[
             0.9311896052631579, 0.9435112105263158, 0.7700369473684209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 242}], {
             RGBColor[0.7158865, 0.7713787894736842, 0.7509355263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 252}], {
             RGBColor[
             0.9777027894736843, 0.9357262631578946, 0.42928652631578923`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 253}], {
             RGBColor[
             0.9659621842105264, 0.9711721052631579, 0.7710717105263156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 280}], {
             RGBColor[
             0.8881311842105264, 0.9094798421052632, 0.765849789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 199}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 226}], {
             RGBColor[
             0.8930987105263157, 0.5552185789473685, 0.550891447368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 287}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 217}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 247}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 273}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 285}], {
             RGBColor[
             0.9000812894736843, 0.8320507368421053, 0.6255228157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 182}], {
             RGBColor[
             0.9911962105263157, 0.9906274210526316, 0.7955651052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 202}], {
             RGBColor[
             0.8325516842105263, 0.8672602105263159, 0.8526547631578946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 208}], {
             RGBColor[
             0.9317022105263157, 0.9451111578947369, 0.8624326578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 268}], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 281}], {
             RGBColor[
             0.9317022105263157, 0.9451111578947369, 0.8624326578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 190}], {
             RGBColor[
             0.8009307631578948, 0.7541997894736843, 0.6157449210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 250}], {
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 207}], {
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 232}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 240}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 246}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 256}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 296}], {
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 299}], {
             RGBColor[
             0.9317022105263157, 0.9451111578947369, 0.8624326578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 208}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 268}], {
             RGBColor[
             0.9911962105263157, 0.9906274210526316, 0.7955651052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 244}], {
             RGBColor[
             0.8604202631578948, 0.8917762105263158, 0.9841867631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 189}], {
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 197}], {
             RGBColor[
             0.7455322631578948, 0.8006531052631579, 0.9736736578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 202}], {
             RGBColor[
             0.8043281578947369, 0.8479566315789474, 0.9785960263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 214}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 216}], {
             RGBColor[
             0.9034786842105264, 0.9258075789473684, 0.9883739210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 275}], {
             RGBColor[
             0.9664747894736843, 0.972772052631579, 0.8634674210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 293}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 237}], {
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 239}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 282}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 283}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 295}], {
             RGBColor[
             0.7264971578947369, 0.7862643684210526, 0.9733741052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 297}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 196}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 230}], {
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 263}], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 269}], {
             RGBColor[
             0.8043281578947369, 0.8479566315789474, 0.9785960263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 276}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 279}], {
             RGBColor[0.6116091578947369, 0.6951412631578948, 0.962861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 205}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 213}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 264}], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 212}], {
             RGBColor[
             0.9317022105263157, 0.9451111578947369, 0.8624326578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 243}], {
             RGBColor[
             0.9911962105263157, 0.9906274210526316, 0.7955651052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 294}], {
             RGBColor[
             0.9317022105263157, 0.9451111578947369, 0.8624326578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 197}], {
             RGBColor[
             0.49545657894736844`, 0.6008597894736842, 0.9535374736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 211}], {
             RGBColor[
             0.7163991052631579, 0.7729787368421053, 0.8433312368421051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 216}], {
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 275}], {
             RGBColor[
             0.7163991052631579, 0.7729787368421053, 0.8433312368421051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 293}], {
             RGBColor[
             0.7128969999999999, 0.7715305263157894, 0.9013701842105264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 212}], {
             RGBColor[
             0.9000812894736843, 0.8320507368421053, 0.6255228157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 250}], {
             RGBColor[0.9595752894736842, 0.877567, 0.5586552631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 203}], {
             RGBColor[
             0.8276077105263158, 0.8514343684210527, 0.6816374736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 195}], {
             RGBColor[
             0.9911962105263157, 0.9906274210526316, 0.7955651052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 200}], {
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 228}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 255}], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 199}], {
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 220}], {
             RGBColor[
             0.7163991052631579, 0.7729787368421053, 0.8433312368421051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 236}], {
             RGBColor[
             0.5542524736842105, 0.6481633157894737, 0.9584598421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 249}], {
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 266}], {
             RGBColor[0.7034891578947369, 0.765096, 0.9433506052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 283}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 286}], {
             RGBColor[
             0.5542524736842105, 0.6481633157894737, 0.9584598421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 297}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 200}], {
             RGBColor[
             0.8325516842105263, 0.8672602105263159, 0.8526547631578946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 225}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.9911962105263157, 0.9906274210526316, 0.7955651052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 230}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 263}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 279}], {
             RGBColor[
             0.7608458421052632, 0.8120739473684211, 0.9477517631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 289}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 298}], {
             RGBColor[
             0.6578348421052632, 0.7255525263157896, 0.9404415526315789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 214}], {
             RGBColor[
             0.7608458421052632, 0.8120739473684211, 0.9477517631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 275}], {
             RGBColor[
             0.7737557894736842, 0.8199566842105264, 0.8477323947368419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 293}], {
             RGBColor[
             0.7702536842105263, 0.8185084736842105, 0.9057713421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 222}], {
             RGBColor[
             0.6542618684210526, 0.6786858421052632, 0.6245782631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 245}], {
             RGBColor[
             0.5646902631578948, 0.6524394210526316, 0.9611415263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 258}], {
             RGBColor[
             0.3467912631578948, 0.4747948947368422, 0.9433182105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 278}], {
             RGBColor[
             0.6672426842105263, 0.731987052631579, 0.8984611315789475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 290}], {
             RGBColor[
             0.5646902631578948, 0.6524394210526316, 0.9611415263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 220}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 226}], {
             RGBColor[
             0.8930987105263157, 0.5552185789473685, 0.550891447368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 228}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 266}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 225}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 255}], {
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 282}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 295}], {
             RGBColor[
             0.7264971578947369, 0.7862643684210526, 0.9733741052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 209}], {
             RGBColor[
             0.9060086578947368, 0.5631013157894738, 0.45087207894736825`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 218}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 229}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 257}], {
             RGBColor[
             0.9664747894736843, 0.972772052631579, 0.8634674210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 259}], {
             RGBColor[
             0.8886437894736843, 0.9110797894736842, 0.8582454999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 261}], {
             RGBColor[
             0.9317022105263157, 0.9451111578947369, 0.8624326578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 208}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 214}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 268}], {
             RGBColor[
             0.8325516842105263, 0.8672602105263159, 0.8526547631578946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 275}], {
             RGBColor[
             0.8325516842105263, 0.8672602105263159, 0.8526547631578946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 206}], {
             RGBColor[
             0.9862522368421052, 0.9748015789473685, 0.6245478157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 244}], {
             RGBColor[
             0.9615308157894737, 0.9569462105263158, 0.6924501315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 270}], {
             RGBColor[
             0.5818686842105263, 0.6329089736842105, 0.6644962894736841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 235}], {
             RGBColor[
             0.523816552631579, 0.6017703421052631, 0.9604200789473685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 253}], {
             RGBColor[
             0.9034786842105264, 0.9258075789473684, 0.9883739210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 292}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 213}], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 231}], {
             RGBColor[
             0.8851416842105263, 0.9096315789473685, 0.9162844473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 244}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 270}], {
             RGBColor[
             0.5833105526315789, 0.647286605263158, 0.8935525263157895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 272}], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 231}], {
             RGBColor[
             0.6103445789473685, 0.691982894736842, 0.9640505789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 232}], {
             RGBColor[
             0.6103445789473685, 0.691982894736842, 0.9640505789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 240}], {
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 268}], {
             RGBColor[
             0.9317022105263157, 0.9451111578947369, 0.8624326578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 218}], {
             RGBColor[
             0.8930987105263157, 0.5552185789473685, 0.550891447368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 276}], {
             RGBColor[
             0.8930987105263157, 0.5552185789473685, 0.550891447368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 279}], {
             RGBColor[
             0.6850661315789475, 0.39098236842105266`, 0.5610783157894736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 239}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 277}], {
             RGBColor[
             0.7163991052631579, 0.7729787368421053, 0.8433312368421051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 216}], {
             RGBColor[
             0.9317022105263157, 0.9451111578947369, 0.8624326578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 221}], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 243}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 250}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 294}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 231}], {
             RGBColor[
             0.8851416842105263, 0.9096315789473685, 0.9162844473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 264}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 275}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 293}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 223}], {
             RGBColor[
             0.9501674473684211, 0.8711324736842105, 0.6006356842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 234}], {
             RGBColor[
             0.9348538684210527, 0.8597116315789474, 0.6265575789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 271}], {
             RGBColor[
             0.9348538684210527, 0.8597116315789474, 0.6265575789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 274}], {
             RGBColor[
             0.9501674473684211, 0.8711324736842105, 0.6006356842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 282}], {
             RGBColor[
             0.9000812894736843, 0.8320507368421053, 0.6255228157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 286}], {
             RGBColor[
             0.6847781842105263, 0.6599183157894737, 0.6064213947368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 233}], {
             RGBColor[
             0.8851416842105263, 0.9096315789473685, 0.9162844473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 247}], {
             RGBColor[
             0.7264971578947369, 0.7862643684210526, 0.9733741052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 262}], {
             RGBColor[
             0.8881311842105264, 0.9094798421052632, 0.765849789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 273}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 229}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 284}], {
             RGBColor[
             0.9501674473684211, 0.8711324736842105, 0.6006356842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 221}], {
             RGBColor[
             0.9664747894736843, 0.972772052631579, 0.8634674210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 264}], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 226}], {
             RGBColor[
             0.9060086578947368, 0.5631013157894738, 0.45087207894736825`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 228}], {
             RGBColor[
             0.9664747894736843, 0.972772052631579, 0.8634674210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 236}], {
             RGBColor[
             0.8325516842105263, 0.8672602105263159, 0.8526547631578946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 266}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 231}], {
             RGBColor[
             0.8886437894736843, 0.9110797894736842, 0.8582454999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 245}], {
             RGBColor[
             0.8721608684210527, 0.8563303684210526, 0.6424015789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 261}], {
             RGBColor[
             0.9152192894736842, 0.8903617368421053, 0.6465887368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 278}], {
             RGBColor[0.9747132894736842, 0.935878, 0.5797211842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 290}], {
             RGBColor[
             0.8721608684210527, 0.8563303684210526, 0.6424015789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 234}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 271}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 274}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 287}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 291}], {
             RGBColor[
             0.9817883684210527, 0.9841928947368421, 0.8375455263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 249}], {
             RGBColor[
             0.9034786842105264, 0.9258075789473684, 0.9883739210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 254}], {
             RGBColor[
             0.9659621842105264, 0.9711721052631579, 0.7710717105263156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 258}], {
             RGBColor[
             0.6425212631578948, 0.7141316842105263, 0.9663634473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 260}], {
             RGBColor[
             0.8604202631578948, 0.8917762105263158, 0.9841867631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 288}], {
             RGBColor[
             0.5585891315789474, 0.6294312368421052, 0.9614548421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 234}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 255}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 287}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 228}], {
             RGBColor[
             0.8777851315789473, 0.5437977368421052, 0.5768133421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 266}], {
             RGBColor[
             0.8930987105263157, 0.5552185789473685, 0.550891447368421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 264}], {
             RGBColor[0.6881755789473685, 0.7536751578947368, 0.9692725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 266}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 257}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 259}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 261}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 284}], {
             RGBColor[
             0.9501674473684211, 0.8711324736842105, 0.6006356842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 263}], {
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 269}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 289}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 298}], {
             RGBColor[
             0.6672426842105263, 0.731987052631579, 0.8984611315789475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 240}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 256}], {
             RGBColor[
             0.7264971578947369, 0.7862643684210526, 0.9733741052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 296}], {
             RGBColor[
             0.6103445789473685, 0.691982894736842, 0.9640505789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 299}], {
             RGBColor[
             0.8886437894736843, 0.9110797894736842, 0.8582454999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 262}], {
             RGBColor[
             0.9906836052631578, 0.9890274736842106, 0.703169394736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 288}], {
             RGBColor[
             0.5833105526315789, 0.647286605263158, 0.8935525263157895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 291}], {
             RGBColor[
             0.9911962105263157, 0.9906274210526316, 0.7955651052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 255}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 271}], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 274}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 287}], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 252}], {
             RGBColor[
             0.5703297368421052, 0.5939853947368421, 0.6196696578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 253}], {
             RGBColor[
             0.5585891315789473, 0.6294312368421053, 0.9614548421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 292}], {
             RGBColor[
             0.42466602631578954`, 0.5239193947368421, 0.9506421842105264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 249}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 266}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 239}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 282}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 283}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 295}], {
             RGBColor[
             0.8851416842105263, 0.9096315789473685, 0.9162844473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 297}], {
             RGBColor[
             0.9782862631578947, 0.9827446842105263, 0.8955844736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 251}], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 300}], {
             RGBColor[
             0.5739027105263158, 0.6408520789473684, 0.9355329473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 295}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 256}], {
             RGBColor[
             0.7695555789473685, 0.8202957368421053, 0.9775612631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 281}], {
             RGBColor[
             0.9317022105263157, 0.9451111578947369, 0.8624326578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 299}], {
             RGBColor[
             0.9317022105263157, 0.9451111578947369, 0.8624326578947367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 277}], {
             RGBColor[
             0.6103445789473685, 0.691982894736842, 0.9640505789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 243}], {
             RGBColor[
             0.7128969999999999, 0.7715305263157894, 0.9013701842105264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 280}], {
             RGBColor[
             0.6103445789473685, 0.691982894736842, 0.9640505789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 294}], {
             RGBColor[0.653403, 0.7260142631578947, 0.9682377368421052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 294}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 270}], {
             RGBColor[
             0.5585891315789474, 0.6294312368421052, 0.9614548421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 272}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 289}], {
             RGBColor[
             0.8604202631578948, 0.8917762105263158, 0.9841867631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 298}], {
             RGBColor[
             0.5646902631578948, 0.6524394210526316, 0.9611415263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 256}], {
             RGBColor[0.8290495789473684, 0.865812, 0.9106937105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 296}], {
             RGBColor[
             0.7128969999999999, 0.7715305263157894, 0.9013701842105264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 299}], {
             RGBColor[
             0.9911962105263157, 0.9906274210526316, 0.7955651052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 267}], {
             RGBColor[
             0.8320390789473684, 0.8656602631578948, 0.7602590526315788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 273}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 285}], {
             RGBColor[
             0.8009307631578948, 0.7541997894736843, 0.6157449210526316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 270}], {
             RGBColor[
             0.5585891315789474, 0.6294312368421052, 0.9614548421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 254}], {
             RGBColor[
             0.9311896052631579, 0.9435112105263158, 0.7700369473684209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 288}], {
             RGBColor[
             0.523816552631579, 0.6017703421052631, 0.9604200789473685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 300}], {
             RGBColor[
             0.5739027105263158, 0.6408520789473684, 0.9355329473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 253}], {
             RGBColor[
             0.9499918684210527, 0.9180226315789473, 0.6476234999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 292}], {
             RGBColor[
             0.8160687631578948, 0.8125107894736843, 0.6368108421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 292}], {
             RGBColor[
             0.8043281578947369, 0.8479566315789474, 0.9785960263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 258}], {
             RGBColor[
             0.6702321842105263, 0.7318353157894737, 0.7480264736842104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 260}], {
             RGBColor[
             0.8881311842105264, 0.9094798421052632, 0.765849789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 288}], {
             RGBColor[
             0.5863000526315789, 0.6471348684210526, 0.7431178684210524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 287}], {
             RGBColor[
             0.9629726842105263, 0.9713238421052632, 0.9215063684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 296}], {
             RGBColor[
             0.5542524736842105, 0.6481633157894737, 0.9584598421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 299}], {
             RGBColor[
             0.8325516842105263, 0.8672602105263159, 0.8526547631578946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 259}], {
             RGBColor[
             0.8604202631578948, 0.8917762105263158, 0.9841867631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 261}], {
             RGBColor[
             0.9034786842105264, 0.9258075789473684, 0.9883739210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 260}], {
             RGBColor[
             0.5646902631578948, 0.6524394210526316, 0.9611415263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 278}], {
             RGBColor[
             0.6672426842105263, 0.731987052631579, 0.8984611315789475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 290}], {
             RGBColor[
             0.5646902631578948, 0.6524394210526316, 0.9611415263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 260}], {
             RGBColor[
             0.7825892631578948, 0.8300839473684211, 0.9789648421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 261}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 261}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 278}], {
             RGBColor[
             0.8851416842105263, 0.9096315789473685, 0.9162844473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 290}], {
             RGBColor[
             0.7825892631578948, 0.8300839473684211, 0.9789648421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 278}], {
             RGBColor[
             0.9282001052631579, 0.943662947368421, 0.9204716052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 290}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 271}], {
             RGBColor[
             0.9659621842105264, 0.9711721052631579, 0.7710717105263156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 291}], {
             RGBColor[
             0.9941857105263158, 0.9904756842105263, 0.6451304473684207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 269}], {
             RGBColor[
             0.8043281578947369, 0.8479566315789474, 0.9785960263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 276}], {
             RGBColor[
             0.8196417368421053, 0.8593774736842106, 0.9526741315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 279}], {
             RGBColor[0.6116091578947369, 0.6951412631578948, 0.962861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 289}], {
             RGBColor[
             0.8043281578947369, 0.8479566315789474, 0.9785960263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 298}], {
             RGBColor[
             0.508598157894737, 0.6086198421052633, 0.9555507894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 269}], {
             RGBColor[
             0.9664747894736843, 0.972772052631579, 0.8634674210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 273}], {
             RGBColor[
             0.9812757631578948, 0.9825929473684211, 0.7451498157894735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 285}], {
             RGBColor[
             0.9625647894736842, 0.8774152631578948, 0.40822060526315773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 286}], {
             RGBColor[0.7158865, 0.7713787894736842, 0.7509355263157893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 298}], {
             RGBColor[
             0.6425212631578948, 0.7141316842105263, 0.9663634473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 272}], {
             RGBColor[
             0.5833105526315789, 0.6472866052631578, 0.8935525263157895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 274}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 291}], {
             RGBColor[
             0.9664747894736843, 0.972772052631579, 0.8634674210526314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 285}], {
             RGBColor[
             0.9501674473684211, 0.8711324736842105, 0.6006356842105263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 287}], {
             RGBColor[
             0.9535648421052632, 0.9648893157894737, 0.963486789473684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 293}], {
             RGBColor[
             0.9911962105263157, 0.9906274210526316, 0.7955651052631578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 279}], {
             RGBColor[
             0.7608458421052632, 0.8120739473684211, 0.9477517631578947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 290}], {
             RGBColor[
             0.8851416842105263, 0.9096315789473685, 0.9162844473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 283}], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 295}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 297}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 295}], {
             RGBColor[0.8256476842105264, 0.8641153157894736, 0.983152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 297}], {
             RGBColor[
             0.9187922631578948, 0.9372284210526316, 0.9624520263157894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 291}], {
             RGBColor[
             0.5868126578947368, 0.6487348157894737, 0.8355135789473682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 298}], {
             RGBColor[
             0.6425212631578948, 0.7141316842105263, 0.9663634473684211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 297}], {
             RGBColor[
             0.8757338421052632, 0.9031970526315789, 0.9582648684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 299}], {
             RGBColor[
             0.7163991052631579, 0.7729787368421053, 0.8433312368421051]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.03434177932816089], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.03434177932816089], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.03434177932816089], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.03434177932816089], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.03434177932816089], {
             RGBColor[
             0.9848103684210526, 0.9604239473684211, 0.3954915789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.03434177932816089], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.03434177932816089], {
             RGBColor[
             0.3467912631578948, 0.4747948947368422, 0.9433182105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.03434177932816089], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.03434177932816089], {
             RGBColor[
             0.9936731052631579, 0.9888757368421053, 0.552734736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.03434177932816089], {
             RGBColor[
             0.9936731052631579, 0.9888757368421053, 0.552734736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.03434177932816089], {
             RGBColor[
             0.4380998947368421, 0.5538818421052631, 0.9491363157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.03434177932816089], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.03434177932816089], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.03434177932816089], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.03434177932816089], {
             RGBColor[
             0.9314564736842106, 0.7659547894736842, 0.2637064736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.03434177932816089], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.03434177932816089], {
             RGBColor[
             0.9314564736842106, 0.7659547894736842, 0.2637064736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.03434177932816089], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.03434177932816089], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.03434177932816089], {
             RGBColor[
             0.9936731052631579, 0.9888757368421053, 0.552734736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.03434177932816089], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.03434177932816089], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.03434177932816089], {
             RGBColor[
             0.3467912631578948, 0.4747948947368422, 0.9433182105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.03434177932816089], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.03434177932816089], {
             RGBColor[
             0.5528132631578948, 0.6478377368421053, 0.9579386315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.03434177932816089], {
             RGBColor[
             0.7825892631578948, 0.8300839473684211, 0.9789648421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.03434177932816089], {
             RGBColor[
             0.8994036315789474, 0.636097210526316, 0.2377722631578948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.03434177932816089], {
             RGBColor[
             0.9936731052631579, 0.9888757368421053, 0.552734736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.03434177932816089], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.03434177932816089], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.03434177932816089], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.03434177932816089], {
             RGBColor[
             0.8994036315789474, 0.636097210526316, 0.2377722631578948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.03434177932816089], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.03434177932816089], {
             RGBColor[
             0.3467912631578948, 0.4747948947368422, 0.9433182105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.03434177932816089], {
             RGBColor[
             0.8994036315789474, 0.636097210526316, 0.2377722631578948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.03434177932816089], {
             RGBColor[
             0.5528132631578948, 0.6478377368421053, 0.9579386315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.03434177932816089], {
             RGBColor[
             0.9848103684210526, 0.9604239473684211, 0.3954915789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.03434177932816089], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.03434177932816089], {
             RGBColor[
             0.4380998947368421, 0.5538818421052631, 0.9491363157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.03434177932816089], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.03434177932816089], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.03434177932816089], {
             RGBColor[
             0.26091794736842105`, 0.39157168421052635`, 0.9381702631578948]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.03434177932816089], {
             RGBColor[
             0.9314564736842106, 0.7659547894736842, 0.2637064736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.03434177932816089], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.03434177932816089], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.03434177932816089], {
             RGBColor[
             0.7825892631578948, 0.8300839473684211, 0.9789648421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.03434177932816089], {
             RGBColor[
             0.7825892631578948, 0.8300839473684211, 0.9789648421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.03434177932816089], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.03434177932816089], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.03434177932816089], {
             RGBColor[
             0.4380998947368421, 0.5538818421052631, 0.9491363157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.03434177932816089], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.03434177932816089], {
             RGBColor[
             0.9848103684210526, 0.9604239473684211, 0.3954915789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.03434177932816089], {
             RGBColor[
             0.3467912631578948, 0.4747948947368422, 0.9433182105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.03434177932816089], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.03434177932816089], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.03434177932816089], {
             RGBColor[
             0.4380998947368421, 0.5538818421052631, 0.9491363157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.03434177932816089], {
             RGBColor[
             0.9848103684210526, 0.9604239473684211, 0.3954915789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.03434177932816089], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.03434177932816089], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.03434177932816089], {
             RGBColor[
             0.5528132631578948, 0.6478377368421053, 0.9579386315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.03434177932816089], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.03434177932816089], {
             RGBColor[
             0.9936731052631579, 0.9888757368421053, 0.552734736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.03434177932816089], {
             RGBColor[
             0.3467912631578948, 0.4747948947368422, 0.9433182105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.03434177932816089], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.03434177932816089], {
             RGBColor[
             0.8994036315789474, 0.636097210526316, 0.2377722631578948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.03434177932816089], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.03434177932816089], {
             RGBColor[
             0.3467912631578948, 0.4747948947368422, 0.9433182105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.03434177932816089], {
             RGBColor[
             0.3467912631578948, 0.4747948947368422, 0.9433182105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.03434177932816089], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.03434177932816089], {
             RGBColor[
             0.7825892631578948, 0.8300839473684211, 0.9789648421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.03434177932816089], {
             RGBColor[
             0.4380998947368421, 0.5538818421052631, 0.9491363157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.03434177932816089], {
             RGBColor[
             0.7825892631578948, 0.8300839473684211, 0.9789648421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.03434177932816089], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.03434177932816089], {
             RGBColor[
             0.4380998947368421, 0.5538818421052631, 0.9491363157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.03434177932816089], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.03434177932816089], {
             RGBColor[
             0.7825892631578948, 0.8300839473684211, 0.9789648421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.03434177932816089], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.03434177932816089], {
             RGBColor[
             0.9936731052631579, 0.9888757368421053, 0.552734736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.03434177932816089], {
             RGBColor[
             0.5528132631578948, 0.6478377368421053, 0.9579386315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.03434177932816089], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.03434177932816089], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.03434177932816089], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.03434177932816089], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.03434177932816089], {
             RGBColor[
             0.9936731052631579, 0.9888757368421053, 0.552734736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.03434177932816089], {
             RGBColor[
             0.3467912631578948, 0.4747948947368422, 0.9433182105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.03434177932816089], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.03434177932816089], {
             RGBColor[
             0.3467912631578948, 0.4747948947368422, 0.9433182105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.03434177932816089], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.03434177932816089], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.03434177932816089], {
             RGBColor[
             0.5528132631578948, 0.6478377368421053, 0.9579386315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.03434177932816089], {
             RGBColor[
             0.5528132631578948, 0.6478377368421053, 0.9579386315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.03434177932816089], {
             RGBColor[
             0.7825892631578948, 0.8300839473684211, 0.9789648421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.03434177932816089], {
             RGBColor[
             0.9314564736842106, 0.7659547894736842, 0.2637064736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.03434177932816089], {
             RGBColor[
             0.9848103684210526, 0.9604239473684211, 0.3954915789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.03434177932816089], {
             RGBColor[
             0.5528132631578948, 0.6478377368421053, 0.9579386315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.03434177932816089], {
             RGBColor[
             0.9936731052631579, 0.9888757368421053, 0.552734736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.03434177932816089], {
             RGBColor[
             0.7825892631578948, 0.8300839473684211, 0.9789648421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.03434177932816089], {
             RGBColor[
             0.4380998947368421, 0.5538818421052631, 0.9491363157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.03434177932816089], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.03434177932816089], {
             RGBColor[
             0.3467912631578948, 0.4747948947368422, 0.9433182105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.03434177932816089], {
             RGBColor[
             0.4380998947368421, 0.5538818421052631, 0.9491363157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.03434177932816089], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.03434177932816089], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.03434177932816089], {
             RGBColor[
             0.9936731052631579, 0.9888757368421053, 0.552734736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.03434177932816089], {
             RGBColor[
             0.26091794736842105`, 0.39157168421052635`, 0.9381702631578948]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.03434177932816089], {
             RGBColor[
             0.5528132631578948, 0.6478377368421053, 0.9579386315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.03434177932816089], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.03434177932816089], {
             RGBColor[
             0.9617324736842106, 0.8825767894736841, 0.3058383157894735]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.03434177932816089], {
             RGBColor[
             0.9848103684210526, 0.9604239473684211, 0.3954915789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.03434177932816089], {
             RGBColor[
             0.5528132631578948, 0.6478377368421053, 0.9579386315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.03434177932816089], {
             RGBColor[
             0.4380998947368421, 0.5538818421052631, 0.9491363157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.03434177932816089], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.03434177932816089], {
             RGBColor[
             0.9617324736842106, 0.8825767894736841, 0.3058383157894735]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.03434177932816089], {
             RGBColor[
             0.4380998947368421, 0.5538818421052631, 0.9491363157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.03434177932816089], {
             RGBColor[
             0.26091794736842105`, 0.39157168421052635`, 0.9381702631578948]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.03434177932816089], {
             RGBColor[
             0.7825892631578948, 0.8300839473684211, 0.9789648421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.03434177932816089], {
             RGBColor[
             0.3467912631578948, 0.4747948947368422, 0.9433182105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.03434177932816089], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.03434177932816089], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.03434177932816089], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.03434177932816089], {
             RGBColor[
             0.9314564736842106, 0.7659547894736842, 0.2637064736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.03434177932816089], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.03434177932816089], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.03434177932816089], {
             RGBColor[
             0.7825892631578948, 0.8300839473684211, 0.9789648421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.03434177932816089], {
             RGBColor[
             0.9936731052631579, 0.9888757368421053, 0.552734736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.03434177932816089], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.03434177932816089], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.03434177932816089], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.03434177932816089], {
             RGBColor[
             0.7825892631578948, 0.8300839473684211, 0.9789648421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.03434177932816089], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.03434177932816089], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.03434177932816089], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.03434177932816089], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.03434177932816089], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.03434177932816089], {
             RGBColor[
             0.4380998947368421, 0.5538818421052631, 0.9491363157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.03434177932816089], {
             RGBColor[
             0.9314564736842106, 0.7659547894736842, 0.2637064736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.03434177932816089], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.03434177932816089], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.03434177932816089], {
             RGBColor[
             0.4380998947368421, 0.5538818421052631, 0.9491363157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.03434177932816089], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.03434177932816089], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.03434177932816089], {
             RGBColor[
             0.5528132631578948, 0.6478377368421053, 0.9579386315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.03434177932816089], {
             RGBColor[
             0.3467912631578948, 0.4747948947368422, 0.9433182105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.03434177932816089], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.03434177932816089], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.03434177932816089], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.03434177932816089], {
             RGBColor[
             0.9848103684210526, 0.9604239473684211, 0.3954915789473683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.03434177932816089], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.03434177932816089], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.03434177932816089], {
             RGBColor[
             0.4380998947368421, 0.5538818421052631, 0.9491363157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.03434177932816089], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.03434177932816089], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.03434177932816089], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.03434177932816089], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.03434177932816089], {
             RGBColor[
             0.9314564736842106, 0.7659547894736842, 0.2637064736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.03434177932816089], {
             RGBColor[
             0.7825892631578948, 0.8300839473684211, 0.9789648421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.03434177932816089], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.03434177932816089], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.03434177932816089], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.03434177932816089], {
             RGBColor[
             0.9617324736842106, 0.8825767894736841, 0.3058383157894735]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.03434177932816089], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.03434177932816089], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.03434177932816089], {
             RGBColor[
             0.4380998947368421, 0.5538818421052631, 0.9491363157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.03434177932816089], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.03434177932816089], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.03434177932816089], {
             RGBColor[
             0.7825892631578948, 0.8300839473684211, 0.9789648421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.03434177932816089], {
             RGBColor[
             0.7825892631578948, 0.8300839473684211, 0.9789648421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.03434177932816089], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.03434177932816089], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.03434177932816089], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.03434177932816089], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.03434177932816089], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.03434177932816089], {
             RGBColor[
             0.7825892631578948, 0.8300839473684211, 0.9789648421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.03434177932816089], {
             RGBColor[
             0.4380998947368421, 0.5538818421052631, 0.9491363157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.03434177932816089], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.03434177932816089], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.03434177932816089], {
             RGBColor[
             0.7825892631578948, 0.8300839473684211, 0.9789648421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.03434177932816089], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.03434177932816089], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.03434177932816089], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.03434177932816089], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.03434177932816089], {
             RGBColor[
             0.9617324736842106, 0.8825767894736841, 0.3058383157894735]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.03434177932816089], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.03434177932816089], {
             RGBColor[
             0.9936731052631579, 0.9888757368421053, 0.552734736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.03434177932816089], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.03434177932816089], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.03434177932816089], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.03434177932816089], {
             RGBColor[
             0.3467912631578948, 0.4747948947368422, 0.9433182105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.03434177932816089], {
             RGBColor[
             0.7825892631578948, 0.8300839473684211, 0.9789648421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.03434177932816089], {
             RGBColor[
             0.7825892631578948, 0.8300839473684211, 0.9789648421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.03434177932816089], {
             RGBColor[
             0.9936731052631579, 0.9888757368421053, 0.552734736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.03434177932816089], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.03434177932816089], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.03434177932816089], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.03434177932816089], {
             RGBColor[
             0.9936731052631579, 0.9888757368421053, 0.552734736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.03434177932816089], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.03434177932816089], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.03434177932816089], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.03434177932816089], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.03434177932816089], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.03434177932816089], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.03434177932816089], {
             RGBColor[
             0.4380998947368421, 0.5538818421052631, 0.9491363157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.03434177932816089], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.03434177932816089], {
             RGBColor[
             0.5528132631578948, 0.6478377368421053, 0.9579386315789473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.03434177932816089], {
             RGBColor[
             0.7825892631578948, 0.8300839473684211, 0.9789648421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.03434177932816089], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.03434177932816089], {
             RGBColor[
             0.9314564736842106, 0.7659547894736842, 0.2637064736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.03434177932816089], {
             RGBColor[
             0.9314564736842106, 0.7659547894736842, 0.2637064736842105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.03434177932816089], {
             RGBColor[
             0.4380998947368421, 0.5538818421052631, 0.9491363157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.03434177932816089], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.03434177932816089], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.03434177932816089], {
             RGBColor[
             0.9382512631578948, 0.9534684736842105, 0.9894086842105262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.03434177932816089], {
             RGBColor[
             0.7825892631578948, 0.8300839473684211, 0.9789648421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.03434177932816089], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.03434177932816089], {
             RGBColor[
             0.670405052631579, 0.7424447894736843, 0.9677833684210526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.03434177932816089], {
             RGBColor[
             0.9876941052631578, 0.9891792105263159, 0.853604052631579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.03434177932816089], {
             RGBColor[
             0.868706105263158, 0.8981466842105263, 0.9873391578947368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.03434177932816089], {
             RGBColor[
             0.7825892631578948, 0.8300839473684211, 0.9789648421052631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.03434177932816089], {
             RGBColor[
             0.4380998947368421, 0.5538818421052631, 0.9491363157894737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.03434177932816089], {
             RGBColor[
             0.9688784210526316, 0.9763101578947369, 0.937564894736842]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.03434177932816089], {
             RGBColor[
             0.3467912631578948, 0.4747948947368422, 0.9433182105263158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.03434177932816089], {
             RGBColor[
             0.9946983157894737, 0.9920756315789474, 0.7375261578947365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.03434177932816089], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> 
            False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1FO4EAYYBuBzsm2dTrZdW7WsZbtVy3bLtWxr2bat5WVjyzZXrfc8u3i/
//a7+f7gJu2rtAsMCAjIJEJuKEIThrCEIzwRiEgkIhOFqEQjOjGISSxiE4e4
xCM+CUhIIhKThKQkI4jkBJOClKQiNWlISzrSk4GMIX3JTBayko3s5CAnuchN
HvKSj/wUoCCF+IEfKUwRivITxShOCUpSitKUoSzlKE8FfqYilahMFapSjerU
oCa1qE0d6lKP+jSgIY1oTBN+oSnNaM6vtKAlrWhNG9rSjvZ0oCOd6EwXutKN
7vSgJ73ozW/0oS/96M8ABjKIwQzhd4YyjOGMYCSjGM0YxjKO8UxgIpOYzBSm
Mo3pzGAms5jNH8xhLvOYzwIWsojFLGEpy1jOClayitWsYS3rWM8GNrKJzWxh
K9vYzg52sovd7GEv+9jPAQ5yiMMc4U+OcozjnOAkpzjNX5zhLOc4zwUuconL
XOEq17jODW5yi9v8zT/c4S73uM8DHvKIxzzhKc94zgte8orXvOEt73jPBz7y
ic/8yxe+8o3/CBl/IKEITRjCEo7wRCAikYhMFKISjejEICaxiE0c4hKP+CQg
IYlITBKSkowgkhNMClKSitSkIS3pSE8GMgb+/6++Az6VhWw=
          "], {Null, CompressedData["
1:eJxN2nu4llWZB+C1RcxDZpqQRxAUUVHStBgOUSMyo5BNY0aKowyCpqCIyVg4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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[57, 280] -> 
             RGBColor[
              0.2575556675749038, 0.38803771496668804`, 0.9379787862977012], 
             UndirectedEdge[46, 187] -> 
             RGBColor[
              0.32803381097302087`, 0.4570126210374179, 0.9421792248536764], 
             UndirectedEdge[96, 298] -> 
             RGBColor[
              0.3453589956577786, 0.4713821632368721, 0.9433064816157806], 
             UndirectedEdge[165, 207] -> 
             RGBColor[
              0.8629243195572578, 0.8731271056740303, 0.676546302374514], 
             UndirectedEdge[69, 224] -> 
             RGBColor[
              0.9812813612748328, 0.9481895871324358, 0.4098590677551779], 
             UndirectedEdge[51, 110] -> 
             RGBColor[
              0.9932540497607107, 0.99147839046011, 0.7614613836320072], 
             UndirectedEdge[122, 231] -> 
             RGBColor[
              0.5346560481729267, 0.6328742791629598, 0.9565707376227028], 
             UndirectedEdge[71, 246] -> 
             RGBColor[
              0.6142322345348998, 0.6977004246990872, 0.9627737579908505], 
             UndirectedEdge[9, 239] -> 
             RGBColor[
              0.4639819639121217, 0.5745750992225973, 0.9512619801674704], 
             UndirectedEdge[99, 229] -> 
             RGBColor[
              0.3569385719957474, 0.4835839836336185, 0.9439647880725508], 
             UndirectedEdge[49, 112] -> 
             RGBColor[
              0.24438397329964223`, 0.374193429149736, 0.9372286777945005], 
             UndirectedEdge[115, 243] -> 
             RGBColor[
              0.21987898042507611`, 0.348437127932281, 0.9358331547021821], 
             UndirectedEdge[58, 95] -> 
             RGBColor[
              0.5187848450827122, 0.6202119340859072, 0.9552597898578664], 
             UndirectedEdge[210, 239] -> 
             RGBColor[
              0.39484568065555037`, 0.5164172158880604, 0.9463801955164135], 
             UndirectedEdge[94, 150] -> 
             RGBColor[
              0.9119777121048072, 0.931971896043791, 0.9679461351700305], 
             UndirectedEdge[21, 108] -> 
             RGBColor[
              0.3636875531699619, 0.4894296119130661, 0.9443948271850822], 
             UndirectedEdge[83, 202] -> 
             RGBColor[
              0.22220476853383342`, 0.3508816786980681, 0.9359656048942807], 
             UndirectedEdge[172, 174] -> 
             RGBColor[
              0.33090944455997406`, 0.4574098756542951, 0.9424391100455509], 
             UndirectedEdge[3, 157] -> 
             RGBColor[
              0.36165267017657554`, 0.4876670985403879, 0.9442651662401199], 
             UndirectedEdge[181, 246] -> 
             RGBColor[
              0.656342497401248, 0.7307927865257904, 0.9668372480070162], 
             UndirectedEdge[159, 253] -> 
             RGBColor[
              0.27205955347524674`, 0.4032822186474281, 0.9388047611431494], 
             UndirectedEdge[170, 228] -> 
             RGBColor[
              0.8191183413836293, 0.5128704810525186, 0.5754638060619697], 
             UndirectedEdge[151, 194] -> 
             RGBColor[
              0.4795533660103779, 0.5880893214551517, 0.9522467003824877], 
             UndirectedEdge[62, 100] -> 
             RGBColor[
              0.9225145323393552, 0.6890519389234857, 0.4381903343500609], 
             UndirectedEdge[76, 99] -> 
             RGBColor[
              0.3308920068686242, 0.45968772172522177`, 0.9423540428096366], 
             UndirectedEdge[131, 283] -> 
             RGBColor[
              0.47177717102653804`, 0.5785602690993044, 0.9525231166057517], 
             UndirectedEdge[173, 263] -> 
             RGBColor[
              0.25907859446240145`, 0.3896384076845897, 0.9380655147309758], 
             UndirectedEdge[20, 75] -> 
             RGBColor[
              0.7982091276425176, 0.8426574734850338, 0.980423187310408], 
             UndirectedEdge[175, 253] -> 
             RGBColor[
              0.29561827694261666`, 0.42804393072097424`, 0.9401463955926079],
              UndirectedEdge[52, 193] -> 
             RGBColor[
              0.6086028861336337, 0.3287818878860621, 0.5556335731143328], 
             UndirectedEdge[282, 283] -> 
             RGBColor[
              0.7911900845661439, 0.8368811978581185, 0.9547653144934332], 
             UndirectedEdge[173, 279] -> 
             RGBColor[
              0.2579831193391787, 0.3884869938729482, 0.9380031290433184], 
             UndirectedEdge[95, 198] -> 
             RGBColor[
              0.4764509321887418, 0.5858433564775396, 0.9519271091606205], 
             UndirectedEdge[18, 288] -> 
             RGBColor[
              0.9041509173263116, 0.7126766818632384, 0.5910465110881808], 
             UndirectedEdge[29, 91] -> 
             RGBColor[
              0.25771769921639187`, 0.38820802049529146`, 0.9379880137599795],
              UndirectedEdge[46, 169] -> 
             RGBColor[
              0.2925815910536258, 0.4248521813146391, 0.9399734608236041], 
             UndirectedEdge[34, 264] -> 
             RGBColor[
              0.31108024849077764`, 0.44256158228500475`, 0.9410904171386354],
              UndirectedEdge[116, 277] -> 
             RGBColor[
              0.33575144742336294`, 0.46523276122486323`, 0.9426147632298372],
              UndirectedEdge[60, 299] -> 
             RGBColor[
              0.9602834986478392, 0.8683179033755875, 0.5002256256588694], 
             UndirectedEdge[205, 213] -> 
             RGBColor[
              0.4786627684820106, 0.5869482888311869, 0.9522920854283001], 
             UndirectedEdge[240, 299] -> 
             RGBColor[
              0.9947090533611671, 0.9917794762430787, 0.7154980818389891], 
             UndirectedEdge[184, 214] -> 
             RGBColor[
              0.22515962250579277`, 0.3539874175711599, 0.9361338794566691], 
             UndirectedEdge[39, 59] -> 
             RGBColor[
              0.8501714335969901, 0.3722888082384709, 0.1951153671911272], 
             UndirectedEdge[246, 299] -> 
             RGBColor[
              0.7966762325062557, 0.8386071063469377, 0.851316533208819], 
             UndirectedEdge[21, 114] -> 
             RGBColor[
              0.3439329379247541, 0.47191837420693394`, 0.9431507551943723], 
             UndirectedEdge[204, 253] -> 
             RGBColor[
              0.26380404156370607`, 0.39460515219871184`, 0.9383346219527224],
              UndirectedEdge[202, 214] -> 
             RGBColor[
              0.22050159369132202`, 0.3490915339510665, 0.935868611606621], 
             UndirectedEdge[26, 39] -> 
             RGBColor[
              0.9266838506619479, 0.7398946126602461, 0.547796397964442], 
             UndirectedEdge[118, 220] -> 
             RGBColor[
              0.21806065403360642`, 0.34652595160629435`, 0.9357296037041608],
              UndirectedEdge[28, 126] -> 
             RGBColor[
              0.22467560955270433`, 0.3534786892692703, 0.9361063156350238], 
             UndirectedEdge[9, 237] -> 
             RGBColor[
              0.5778044829283981, 0.6681267348934206, 0.9599060319451358], 
             UndirectedEdge[174, 297] -> 
             RGBColor[
              0.5763612583921884, 0.663490693504958, 0.9614863052750408], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.35208222651696447`, 0.4786261706514128, 0.9436828617856419], 
             UndirectedEdge[63, 139] -> 
             RGBColor[
              0.28999599813964694`, 0.42067676560446166`, 0.9398795920978575],
              UndirectedEdge[124, 150] -> 
             RGBColor[
              0.9548500534233739, 0.9658478242861803, 0.9613112619489188], 
             UndirectedEdge[127, 165] -> 
             RGBColor[
              0.9065162299369915, 0.5989909877808421, 0.27841578820409746`], 
             UndirectedEdge[8, 22] -> 
             RGBColor[
              0.7346141321851996, 0.7926054104280515, 0.9741831294029938], 
             UndirectedEdge[127, 137] -> 
             RGBColor[
              0.8391691506119379, 0.30207683240040506`, 0.18514172890220718`],
              UndirectedEdge[21, 213] -> 
             RGBColor[
              0.40566670523630644`, 0.5257898434994019, 0.9470697016340429], 
             UndirectedEdge[41, 278] -> 
             RGBColor[
              0.4799611412114356, 0.5860775921964064, 0.9529261189064413], 
             UndirectedEdge[69, 249] -> 
             RGBColor[
              0.9058089885195326, 0.5656683412312807, 0.3245169720093974], 
             UndirectedEdge[100, 136] -> 
             RGBColor[
              0.9215440004534805, 0.6869760693554257, 0.33255392800111494`], 
             UndirectedEdge[88, 222] -> 
             RGBColor[
              0.47017691950032614`, 0.5802832085890723, 0.9515621248783083], 
             UndirectedEdge[153, 216] -> 
             RGBColor[
              0.2661597993989548, 0.3970812030472318, 0.9384687788764086], 
             UndirectedEdge[60, 121] -> 
             RGBColor[
              0.9603462863275016, 0.8677642487038257, 0.4570528894502983], 
             UndirectedEdge[203, 206] -> 
             RGBColor[
              0.24813385698154097`, 0.37813479465576916`, 0.9374422281227288],
              UndirectedEdge[50, 108] -> 
             RGBColor[
              0.3481847341285709, 0.4760018492537544, 0.9434070012643693], 
             UndirectedEdge[98, 181] -> 
             RGBColor[
              0.5683121366528735, 0.6584973340732392, 0.9601360759487196], 
             UndirectedEdge[267, 285] -> 
             RGBColor[
              0.42530929649653304`, 0.542408765687049, 0.9484303125609015], 
             UndirectedEdge[156, 178] -> 
             RGBColor[
              0.25237767810444756`, 0.38259531972974414`, 0.9376839074575076],
              UndirectedEdge[185, 295] -> 
             RGBColor[
              0.7026775395247731, 0.7666581291332051, 0.9717409425805205], 
             UndirectedEdge[83, 156] -> 
             RGBColor[
              0.221993745626472, 0.35065988024280614`, 0.935953587451887], 
             UndirectedEdge[44, 150] -> 
             RGBColor[
              0.9635307831976114, 0.9324851425902525, 0.6339721646328667], 
             UndirectedEdge[223, 274] -> 
             RGBColor[
              0.9259651133080155, 0.7367764933200369, 0.2723005774523107], 
             UndirectedEdge[20, 142] -> 
             RGBColor[
              0.7624648027643098, 0.8147337352232472, 0.9768605270562558], 
             UndirectedEdge[87, 264] -> 
             RGBColor[
              0.2853843000396664, 0.4172873721243609, 0.939563585747797], 
             UndirectedEdge[16, 192] -> 
             RGBColor[
              0.9292282498402631, 0.7341287491873884, 0.36986042931949054`], 
             UndirectedEdge[75, 143] -> 
             RGBColor[
              0.5636312232942053, 0.6537338940348352, 0.9601379235387875], 
             UndirectedEdge[230, 263] -> 
             RGBColor[
              0.2551678747286398, 0.38552799329045395`, 0.9378428050275294], 
             UndirectedEdge[52, 82] -> 
             RGBColor[
              0.90639234718301, 0.5644975000841104, 0.4350476194442515], 
             UndirectedEdge[34, 213] -> 
             RGBColor[
              0.37768895869959807`, 0.5015569256517332, 0.9452869843644738], 
             UndirectedEdge[145, 219] -> 
             RGBColor[
              0.27171942382339986`, 0.4029247208178715, 0.9387853912626534], 
             UndirectedEdge[237, 295] -> 
             RGBColor[
              0.738032045164762, 0.7953605095140767, 0.9745241787723218], 
             UndirectedEdge[257, 259] -> 
             RGBColor[
              0.4277830853443319, 0.544648816326516, 0.9485610340700278], 
             UndirectedEdge[116, 241] -> 
             RGBColor[
              0.30074162674959204`, 0.4321657656332045, 0.9404844121827121], 
             UndirectedEdge[95, 105] -> 
             RGBColor[
              0.3889084199719124, 0.5085055030468593, 0.9463331921101534], 
             UndirectedEdge[115, 146] -> 
             RGBColor[
              0.22602095903949393`, 0.35489273687997036`, 0.9361829312980301],
              UndirectedEdge[16, 170] -> 
             RGBColor[
              0.9076819009807398, 0.5788651194760369, 0.34963294244959353`], 
             UndirectedEdge[199, 226] -> 
             RGBColor[
              0.178927005110741, 0.3053940053717128, 0.9335010002910491], 
             UndirectedEdge[78, 130] -> 
             RGBColor[
              0.17948366008578914`, 0.30597908504445237`, 0.9335327009683809],
              UndirectedEdge[155, 214] -> 
             RGBColor[
              0.21259246077095287`, 0.340778533783768, 0.9354181981873197], 
             UndirectedEdge[185, 297] -> 
             RGBColor[
              0.6642346642542716, 0.7364864270373344, 0.9679464241532377], 
             UndirectedEdge[45, 53] -> 
             RGBColor[
              0.8447764554590436, 0.34517703459191124`, 0.19051129035634062`],
              UndirectedEdge[49, 204] -> 
             RGBColor[
              0.23371861491604712`, 0.3629834612657993, 0.9366213014125385], 
             UndirectedEdge[69, 254] -> 
             RGBColor[
              0.9421799602264942, 0.7934586684310521, 0.3573185586987633], 
             UndirectedEdge[102, 295] -> 
             RGBColor[
              0.6113037860265932, 0.6906305704110295, 0.9650577846461873], 
             UndirectedEdge[14, 254] -> 
             RGBColor[
              0.8570098056114457, 0.3874350253501294, 0.200198663385516], 
             UndirectedEdge[125, 299] -> 
             RGBColor[
              0.9935548569863483, 0.9893107669044954, 0.5898709293143154], 
             UndirectedEdge[16, 44] -> 
             RGBColor[
              0.9792628131880576, 0.9411137160345208, 0.4247070629331663], 
             UndirectedEdge[49, 84] -> 
             RGBColor[
              0.2685862507813846, 0.39963155729606886`, 0.9386069616930247], 
             UndirectedEdge[186, 230] -> 
             RGBColor[
              0.23966064866834333`, 0.3692289154861624, 0.9369596914442806], 
             UndirectedEdge[215, 282] -> 
             RGBColor[
              0.97938013431987, 0.9823295669124169, 0.8386095157394571], 
             UndirectedEdge[134, 159] -> 
             RGBColor[
              0.26069725479200045`, 0.3913397223199907, 0.9381576950421531], 
             UndirectedEdge[26, 266] -> 
             RGBColor[
              0.6167344718352826, 0.6830098916954412, 0.9109140844783175], 
             UndirectedEdge[142, 150] -> 
             RGBColor[
              0.810515025857468, 0.8523692859433827, 0.9579232930155395], 
             UndirectedEdge[114, 221] -> 
             RGBColor[
              0.29951227485023835`, 0.4321367694156119, 0.9403681530127932], 
             UndirectedEdge[147, 172] -> 
             RGBColor[
              0.2478440102281372, 0.3778301473405962, 0.9374257217789124], 
             UndirectedEdge[35, 211] -> 
             RGBColor[
              0.2342952250609407, 0.36358951508727716`, 0.936654138507272], 
             UndirectedEdge[124, 295] -> 
             RGBColor[
              0.8924892919776035, 0.9168014387328876, 0.9788835440663946], 
             UndirectedEdge[166, 233] -> 
             RGBColor[
              0.9934058766223102, 0.9883041618002921, 0.5236485484298345], 
             UndirectedEdge[88, 290] -> 
             RGBColor[
              0.558574938782711, 0.6525153246748602, 0.9583922117898461], 
             UndirectedEdge[134, 235] -> 
             RGBColor[
              0.2580199713754525, 0.388525727699626, 0.9380052277122666], 
             UndirectedEdge[185, 239] -> 
             RGBColor[
              0.4896022864326819, 0.5953748312271646, 0.9532789058066227], 
             UndirectedEdge[260, 278] -> 
             RGBColor[
              0.7260426453881705, 0.7855410894217181, 0.9736791816363508], 
             UndirectedEdge[15, 242] -> 
             RGBColor[
              0.23967759230185604`, 0.3692467243192726, 0.9369606563591433], 
             UndirectedEdge[4, 266] -> 
             RGBColor[
              0.3936273469724733, 0.5073684085563466, 0.9471569136064277], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.2455681044594148, 0.3754380260769088, 0.9372961123122845], 
             UndirectedEdge[3, 123] -> 
             RGBColor[
              0.40677277394875433`, 0.5267478646254944, 0.9471401793543419], 
             UndirectedEdge[28, 184] -> 
             RGBColor[
              0.23042487690337662`, 0.35952153377943086`, 0.9364337279053656],
              UndirectedEdge[116, 210] -> 
             RGBColor[
              0.35048246477995726`, 0.4779920280566848, 0.9435534106296721], 
             UndirectedEdge[118, 120] -> 
             RGBColor[
              0.1844220718220619, 0.3111696688926636, 0.9338139362110361], 
             UndirectedEdge[15, 89] -> 
             RGBColor[
              0.2585276184343561, 0.3890592969452162, 0.9380341374612745], 
             UndirectedEdge[11, 283] -> 
             RGBColor[
              0.4811144650373824, 0.586647763865455, 0.9531180807234778], 
             UndirectedEdge[157, 201] -> 
             RGBColor[
              0.3335467378743898, 0.46332315262546664`, 0.9424742810869247], 
             UndirectedEdge[196, 279] -> 
             RGBColor[
              0.2698625176179148, 0.40097299466125325`, 0.9386796432012976], 
             UndirectedEdge[7, 11] -> 
             RGBColor[
              0.36912627592496833`, 0.4941403602052988, 0.9447413777897574], 
             UndirectedEdge[76, 284] -> 
             RGBColor[
              0.2749699198453155, 0.406341198230256, 0.9389705022024235], 
             UndirectedEdge[34, 108] -> 
             RGBColor[
              0.3357098066332535, 0.46519669406539743`, 0.9426121099155129], 
             UndirectedEdge[46, 213] -> 
             RGBColor[
              0.3600084250820952, 0.48470742468786476`, 0.9442166189906656], 
             UndirectedEdge[261, 278] -> 
             RGBColor[
              0.5017864477209948, 0.6049815757231856, 0.9543168081378697], 
             UndirectedEdge[58, 66] -> 
             RGBColor[
              0.747689528345485, 0.802133526636196, 0.966576403949817], 
             UndirectedEdge[194, 297] -> 
             RGBColor[
              0.6381161089486057, 0.715282207212687, 0.9658902758041552], 
             UndirectedEdge[283, 297] -> 
             RGBColor[
              0.6895610790338994, 0.7570475514974199, 0.9699402122984042], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.23660390230659725`, 0.366016081251054, 0.9367856142610302], 
             UndirectedEdge[6, 169] -> 
             RGBColor[
              0.299349056442051, 0.4319652165199622, 0.940358857965907], 
             UndirectedEdge[11, 172] -> 
             RGBColor[
              0.3065006008708423, 0.43626816207492447`, 0.9408838001095725], 
             UndirectedEdge[4, 82] -> 
             RGBColor[
              0.7673487077991381, 0.8145026420959148, 0.8312023909866153], 
             UndirectedEdge[140, 230] -> 
             RGBColor[
              0.2887130988150164, 0.4189991437957653, 0.9398185869899978], 
             UndirectedEdge[207, 232] -> 
             RGBColor[
              0.8698424070552139, 0.8954799573196557, 0.7870499702431855], 
             UndirectedEdge[147, 244] -> 
             RGBColor[
              0.23435191313774276`, 0.3636490978502278, 0.9366573668093834], 
             UndirectedEdge[56, 296] -> 
             RGBColor[
              0.6219639893106997, 0.70315209105388, 0.9639467061714042], 
             UndirectedEdge[243, 294] -> 
             RGBColor[
              0.21403208469402601`, 0.34229166980434655`, 0.935500182640006], 
             UndirectedEdge[211, 216] -> 
             RGBColor[
              0.2505986099544608, 0.38072540630467244`, 0.9375825921582613], 
             UndirectedEdge[107, 141] -> 
             RGBColor[
              0.8665747340462209, 0.44887503543921714`, 0.2088850184887606], 
             UndirectedEdge[19, 175] -> 
             RGBColor[
              0.2928891684678705, 0.42517546467854467`, 0.9399909769023254], 
             UndirectedEdge[17, 158] -> 
             RGBColor[
              0.34992722478314753`, 0.47635321406760484`, 0.9435604273632674],
              UndirectedEdge[115, 242] -> 
             RGBColor[
              0.23101187459031025`, 0.36013850556620103`, 0.9364671565552513],
              UndirectedEdge[159, 292] -> 
             RGBColor[
              0.24522762221879252`, 0.3750801576541939, 0.9372767223523794], 
             UndirectedEdge[34, 205] -> 
             RGBColor[
              0.4284730033611293, 0.5434764368944227, 0.9490940379758643], 
             UndirectedEdge[23, 180] -> 
             RGBColor[
              0.26520012614906696`, 0.3960725256148013, 0.9384141269045367], 
             UndirectedEdge[47, 158] -> 
             RGBColor[
              0.5238459246822951, 0.6229456026619612, 0.9560487873803941], 
             UndirectedEdge[130, 199] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[112, 204] -> 
             RGBColor[
              0.24154807064065673`, 0.37121271564852854`, 0.9370671773334133],
              UndirectedEdge[217, 247] -> 
             RGBColor[
              0.6930619732704799, 0.7591753208357144, 0.9707042644868367], 
             UndirectedEdge[102, 185] -> 
             RGBColor[
              0.4766965463107896, 0.5841965277949407, 0.9524565634581535], 
             UndirectedEdge[136, 137] -> 
             RGBColor[
              0.9192369381421535, 0.6692429774694144, 0.3303446825263339], 
             UndirectedEdge[138, 258] -> 
             RGBColor[
              0.8342254690641332, 0.8708963005189276, 0.9605009609416519], 
             UndirectedEdge[79, 277] -> 
             RGBColor[
              0.3720129129755694, 0.49664062013193266`, 0.9449253117500688], 
             UndirectedEdge[41, 259] -> 
             RGBColor[
              0.41062581045850305`, 0.5297880471701207, 0.9474677876858852], 
             UndirectedEdge[225, 287] -> 
             RGBColor[
              0.950968932525843, 0.8418366498372989, 0.2871069008798047], 
             UndirectedEdge[167, 194] -> 
             RGBColor[
              0.6348798248522232, 0.7127539974799229, 0.9655677132502221], 
             UndirectedEdge[64, 219] -> 
             RGBColor[
              0.2539451972290641, 0.384242881716169, 0.9377731753527179], 
             UndirectedEdge[83, 293] -> 
             RGBColor[
              0.21277489873276917`, 0.34097028764887183`, 0.9354285877593523],
              UndirectedEdge[31, 95] -> 
             RGBColor[
              0.5537416162054588, 0.648591415667946, 0.9580117149315208], 
             UndirectedEdge[256, 299] -> 
             RGBColor[
              0.994866261560722, 0.9921157286857396, 0.7326092241840025], 
             UndirectedEdge[129, 269] -> 
             RGBColor[
              0.23146736458154496`, 0.36061725442672216`, 0.9364930960364151],
              UndirectedEdge[83, 126] -> 
             RGBColor[
              0.22111352999763184`, 0.3497347178080009, 0.9359034604739869], 
             UndirectedEdge[23, 81] -> 
             RGBColor[
              0.29610769611833376`, 0.428558341305621, 0.9401742672906341], 
             UndirectedEdge[235, 252] -> 
             RGBColor[
              0.2712852344852127, 0.40246836029424277`, 0.9387606648221691], 
             UndirectedEdge[6, 264] -> 
             RGBColor[
              0.3001671802617, 0.4328251165264595, 0.9404054489071303], 
             UndirectedEdge[167, 215] -> 
             RGBColor[
              0.874514844691243, 0.8999677108189541, 0.8534618509904951], 
             UndirectedEdge[273, 285] -> 
             RGBColor[
              0.5003032179944051, 0.6032922095966846, 0.9543341087730001], 
             UndirectedEdge[267, 273] -> 
             RGBColor[
              0.5428411676276441, 0.6397419404528637, 0.9571535916898165], 
             UndirectedEdge[66, 109] -> 
             RGBColor[
              0.9338122663322416, 0.9497831796189251, 0.9839317503863134], 
             UndirectedEdge[104, 173] -> 
             RGBColor[
              0.2711227338075005, 0.40229756177882925`, 0.9387514106489717], 
             UndirectedEdge[9, 185] -> 
             RGBColor[
              0.5424499772884093, 0.6394243545125489, 0.9571227957533345], 
             UndirectedEdge[233, 288] -> 
             RGBColor[
              0.9279948066453856, 0.7277856301692169, 0.40221351612468526`], 
             UndirectedEdge[139, 147] -> 
             RGBColor[
              0.2408356632285271, 0.3704639302891415, 0.9370266067852049], 
             UndirectedEdge[65, 103] -> 
             RGBColor[
              0.2833667383517215, 0.41516678686953135`, 0.9394486885943836], 
             UndirectedEdge[33, 124] -> 
             RGBColor[
              0.931178231225007, 0.9476509487054876, 0.9825737296298357], 
             UndirectedEdge[82, 226] -> 
             RGBColor[
              0.5870018429473699, 0.648635921384999, 0.8195028573655392], 
             UndirectedEdge[6, 221] -> 
             RGBColor[
              0.3001432088118318, 0.4327999210127703, 0.9404040837685228], 
             UndirectedEdge[125, 136] -> 
             RGBColor[
              0.9927664178883965, 0.9869364242276462, 0.4540474115251879], 
             UndirectedEdge[112, 292] -> 
             RGBColor[
              0.24763746869084696`, 0.3776130590894144, 0.9374139595439145], 
             UndirectedEdge[58, 67] -> 
             RGBColor[
              0.7306207568349073, 0.7888007417215468, 0.9745656605578148], 
             UndirectedEdge[73, 105] -> 
             RGBColor[
              0.30909022810020703`, 0.4403302488400713, 0.9409822033703782], 
             UndirectedEdge[263, 298] -> 
             RGBColor[
              0.27311782288011394`, 0.40439452689009914`, 0.9388650280201871],
              UndirectedEdge[60, 170] -> 
             RGBColor[
              0.8739879445842015, 0.4569683614322223, 0.21399044815056695`], 
             UndirectedEdge[10, 129] -> 
             RGBColor[
              0.22367111540675327`, 0.3524229022332684, 0.9360491111794278], 
             UndirectedEdge[53, 234] -> 
             RGBColor[
              0.8245240597604586, 0.18950824659620397`, 0.17111757336356628`],
              UndirectedEdge[51, 154] -> 
             RGBColor[
              0.867381103025232, 0.8946780960164662, 0.8655976857489563], 
             UndirectedEdge[17, 84] -> 
             RGBColor[
              0.2984201886260963, 0.4309889175517728, 0.9403059603179251], 
             UndirectedEdge[98, 160] -> 
             RGBColor[
              0.5065135948101279, 0.6094211404266363, 0.9545226524909898], 
             UndirectedEdge[25, 147] -> 
             RGBColor[
              0.2390014851721345, 0.36853609285826733`, 0.9369221530583165], 
             UndirectedEdge[159, 204] -> 
             RGBColor[
              0.23913822416860225`, 0.3686798142133081, 0.9369299401418781], 
             UndirectedEdge[37, 94] -> 
             RGBColor[
              0.771325946499076, 0.8216241472491855, 0.9777522097744586], 
             UndirectedEdge[37, 283] -> 
             RGBColor[
              0.6497129501444403, 0.725917890351978, 0.9659685232126394], 
             UndirectedEdge[9, 142] -> 
             RGBColor[
              0.5879267021753338, 0.6760891257694337, 0.9608774283058292], 
             UndirectedEdge[51, 109] -> 
             RGBColor[
              0.9573653906056103, 0.9657923433051386, 0.8743494495449171], 
             UndirectedEdge[123, 257] -> 
             RGBColor[
              0.41376298296839165`, 0.5328024323401832, 0.9475855892918741], 
             UndirectedEdge[212, 294] -> 
             RGBColor[
              0.2108091766010912, 0.3389041890544966, 0.9353166427919786], 
             UndirectedEdge[237, 297] -> 
             RGBColor[
              0.6995891698942603, 0.7651888074182058, 0.970729660345039], 
             UndirectedEdge[163, 197] -> 
             RGBColor[
              0.22592979758927967`, 0.35479692041582533`, 0.9361777397883018],
              UndirectedEdge[76, 229] -> 
             RGBColor[
              0.32034218545595194`, 0.4505499966670069, 0.9416818175180619], 
             UndirectedEdge[18, 24] -> 
             RGBColor[
              0.9510187529148094, 0.9629904466400717, 0.9677966543467089], 
             UndirectedEdge[44, 124] -> 
             RGBColor[
              0.9563745344888678, 0.9271480240205534, 0.6460858270481826], 
             UndirectedEdge[26, 82] -> 
             RGBColor[
              0.9904558326619474, 0.9901441252350094, 0.7949595618585049], 
             UndirectedEdge[7, 106] -> 
             RGBColor[
              0.5257077598802015, 0.6240227140594248, 0.9563940779093657], 
             UndirectedEdge[53, 255] -> 
             RGBColor[
              0.8953417281167521, 0.5590474871616122, 0.23653146249449708`], 
             UndirectedEdge[89, 242] -> 
             RGBColor[
              0.2592824308416344, 0.3898526526431364, 0.9380771229112241], 
             UndirectedEdge[121, 181] -> 
             RGBColor[
              0.8542136005503994, 0.8836192586014792, 0.8134168223712162], 
             UndirectedEdge[217, 273] -> 
             RGBColor[
              0.7124353943152881, 0.7749035368025619, 0.9722294111586636], 
             UndirectedEdge[141, 240] -> 
             RGBColor[
              0.9469680026152082, 0.812923621050152, 0.46368241218848416`], 
             UndirectedEdge[42, 159] -> 
             RGBColor[
              0.2509157891435835, 0.3810587817427625, 0.9376006550438574], 
             UndirectedEdge[51, 52] -> 
             RGBColor[
              0.9056350707482277, 0.5643614773610739, 0.4604731703909181], 
             UndirectedEdge[170, 225] -> 
             RGBColor[
              0.8914281470596066, 0.5246344158422436, 0.23572348923178596`], 
             UndirectedEdge[51, 179] -> 
             RGBColor[
              0.993604348606093, 0.9916232480349453, 0.7556560252196713], 
             UndirectedEdge[36, 198] -> 
             RGBColor[
              0.6119133130274254, 0.6940222772779814, 0.9638188261918845], 
             UndirectedEdge[150, 295] -> 
             RGBColor[
              0.8996455406863472, 0.9221385573025866, 0.9667698816510785], 
             UndirectedEdge[140, 196] -> 
             RGBColor[
              0.304503216827514, 0.4355955589782061, 0.9407178108514234], 
             UndirectedEdge[31, 73] -> 
             RGBColor[
              0.47392342433375345`, 0.580416161461158, 0.9526607261917457], 
             UndirectedEdge[188, 212] -> 
             RGBColor[
              0.20871789165381538`, 0.33670611597978567`, 0.9351975472080101],
              UndirectedEdge[172, 244] -> 
             RGBColor[
              0.2560033039447505, 0.38640608236585794`, 0.9378903814854801], 
             UndirectedEdge[7, 63] -> 
             RGBColor[
              0.3596300201933831, 0.4859151807862907, 0.94413628477175], 
             UndirectedEdge[128, 218] -> 
             RGBColor[
              0.24765166805898178`, 0.377627983525616, 0.9374147681769237], 
             UndirectedEdge[138, 154] -> 
             RGBColor[
              0.7239419932746806, 0.7842682543998942, 0.9731194303332016], 
             UndirectedEdge[1, 297] -> 
             RGBColor[
              0.5894608456272148, 0.6748368975635395, 0.9623209993901465], 
             UndirectedEdge[90, 123] -> 
             RGBColor[
              0.4198835569183708, 0.5381037658666636, 0.9479755868517558], 
             UndirectedEdge[8, 61] -> 
             RGBColor[
              0.6093443388632377, 0.6935868317074125, 0.9624883614152353], 
             UndirectedEdge[201, 209] -> 
             RGBColor[
              0.29313467956513195`, 0.424290095199951, 0.9400468245012701], 
             UndirectedEdge[44, 94] -> 
             RGBColor[
              0.9135021931703009, 0.8932720957781641, 0.6527207002692943], 
             UndirectedEdge[114, 213] -> 
             RGBColor[
              0.366144956508927, 0.49115730829602955`, 0.944566085377239], 
             UndirectedEdge[82, 107] -> 
             RGBColor[
              0.9146118486409361, 0.6276761900982359, 0.44291862332296067`], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.27309540824899353`, 0.40437096769162195`, 0.9388637515401044],
              UndirectedEdge[182, 268] -> 
             RGBColor[
              0.28484973208731645`, 0.4167255073128753, 0.939533142893733], 
             UndirectedEdge[157, 229] -> 
             RGBColor[
              0.34618459391463335`, 0.47426942833041186`, 0.9432795540985917],
              UndirectedEdge[99, 157] -> 
             RGBColor[
              0.35673441532730565`, 0.48340715338862666`, 0.9439517793901664],
              UndirectedEdge[249, 288] -> 
             RGBColor[
              0.8402405410776118, 0.30481319511588134`, 0.18595237386054825`],
              UndirectedEdge[66, 138] -> 
             RGBColor[
              0.8265698887797728, 0.8651867812777139, 0.9734598614679548], 
             UndirectedEdge[215, 286] -> 
             RGBColor[
              0.7770695489362254, 0.8225663010665949, 0.8446220990398039], 
             UndirectedEdge[83, 275] -> 
             RGBColor[
              0.214533530595458, 0.34281872124025803`, 0.9355287392422698], 
             UndirectedEdge[95, 289] -> 
             RGBColor[
              0.38981488785686436`, 0.5094582582673273, 0.9463848141152024], 
             UndirectedEdge[37, 75] -> 
             RGBColor[
              0.7056075851299448, 0.7699452754105638, 0.9712920278741198], 
             UndirectedEdge[88, 260] -> 
             RGBColor[
              0.6766874696871867, 0.7454723343623321, 0.9697937614112038], 
             UndirectedEdge[60, 82] -> 
             RGBColor[
              0.9605795624965958, 0.8682632028416796, 0.48244356084256446`], 
             UndirectedEdge[50, 227] -> 
             RGBColor[
              0.30610711869793783`, 0.43502772299278125`, 0.9408916674370189],
              UndirectedEdge[12, 248] -> 
             RGBColor[
              0.20494626266410096`, 0.3327418947765061, 0.9349827585166709], 
             UndirectedEdge[103, 164] -> 
             RGBColor[
              0.33137057382359575`, 0.4586711168930102, 0.9424369368208644], 
             UndirectedEdge[127, 228] -> 
             RGBColor[
              0.8245576688190998, 0.5546795352500253, 0.5806725121570179], 
             UndirectedEdge[163, 184] -> 
             RGBColor[
              0.23939823162616325`, 0.3689530985366296, 0.9369447471819397], 
             UndirectedEdge[11, 183] -> 
             RGBColor[
              0.29904764600234657`, 0.4284346339635039, 0.9404593653554703], 
             UndirectedEdge[226, 266] -> 
             RGBColor[
              0.21328048212070516`, 0.3415016878454308, 0.9354573799853517], 
             UndirectedEdge[98, 178] -> 
             RGBColor[
              0.34993177355877136`, 0.4745851224813026, 0.9436255999612144], 
             UndirectedEdge[200, 255] -> 
             RGBColor[
              0.9224751483252943, 0.7242107930884344, 0.2608151757752228], 
             UndirectedEdge[223, 234] -> 
             RGBColor[
              0.852336886710356, 0.35775657985604403`, 0.19596820028306192`], 
             UndirectedEdge[111, 190] -> 
             RGBColor[
              0.2355732429285669, 0.36493279289716524`, 0.9367269197341752], 
             UndirectedEdge[85, 181] -> 
             RGBColor[
              0.8167213708728744, 0.8575535758044224, 0.9821530921197811], 
             UndirectedEdge[57, 134] -> 
             RGBColor[
              0.26052687456490653`, 0.3911606418985847, 0.938147992140275], 
             UndirectedEdge[9, 131] -> 
             RGBColor[
              0.4208304337263501, 0.5371994126346513, 0.9485124028214329], 
             UndirectedEdge[184, 189] -> 
             RGBColor[
              0.2346427787554684, 0.3639548160564028, 0.9366739311760157], 
             UndirectedEdge[194, 286] -> 
             RGBColor[
              0.5374345290972057, 0.6353525877275636, 0.9567279612995309], 
             UndirectedEdge[171, 298] -> 
             RGBColor[
              0.35180269388930685`, 0.47696337077533185`, 0.9437170683691549],
              UndirectedEdge[108, 213] -> 
             RGBColor[
              0.3858995717541348, 0.5086685460021616, 0.9458101573679487], 
             UndirectedEdge[158, 175] -> 
             RGBColor[
              0.34907161965836087`, 0.47545391883295585`, 0.9435117019171652],
              UndirectedEdge[37, 297] -> 
             RGBColor[
              0.7205508998101146, 0.7816191064121104, 0.9727814378282238], 
             UndirectedEdge[68, 234] -> 
             RGBColor[
              0.8458426087622819, 0.3282675804709904, 0.19054921557386956`], 
             UndirectedEdge[38, 252] -> 
             RGBColor[
              0.3592377978575069, 0.4848159523446023, 0.9441391019160659], 
             UndirectedEdge[42, 252] -> 
             RGBColor[
              0.2774845709652012, 0.40898425599534566`, 0.939113707863608], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.2625645345612948, 0.39330235174989453`, 0.9382640338626215], 
             UndirectedEdge[184, 216] -> 
             RGBColor[
              0.24813752757352578`, 0.3781386526806742, 0.9374424371575123], 
             UndirectedEdge[16, 59] -> 
             RGBColor[
              0.9131402588168656, 0.620820449672156, 0.3548598720778012], 
             UndirectedEdge[7, 185] -> 
             RGBColor[
              0.4814085254761833, 0.5882778073170456, 0.9527568066039329], 
             UndirectedEdge[127, 299] -> 
             RGBColor[
              0.9136283213475775, 0.6224467453485296, 0.4600423723683357], 
             UndirectedEdge[166, 217] -> 
             RGBColor[
              0.899879476841495, 0.9180128953290518, 0.7153753712159427], 
             UndirectedEdge[101, 207] -> 
             RGBColor[
              0.6460892652174881, 0.7219820565313749, 0.9663628314965813], 
             UndirectedEdge[14, 69] -> 
             RGBColor[
              0.907867854492874, 0.581493687303205, 0.3264885443906257], 
             UndirectedEdge[51, 107] -> 
             RGBColor[
              0.9138545722061537, 0.6275401673751994, 0.4683441742696273], 
             UndirectedEdge[74, 233] -> 
             RGBColor[
              0.8161512863791258, 0.8534670921405562, 0.7813047425304152], 
             UndirectedEdge[158, 252] -> 
             RGBColor[
              0.35208167801260865`, 0.47861768101199287`, 0.9436831202874573],
              UndirectedEdge[86, 110] -> 
             RGBColor[
              0.9839067857429666, 0.9591178157514064, 0.561716366031505], 
             UndirectedEdge[58, 73] -> 
             RGBColor[
              0.4389666532110068, 0.5520366798791193, 0.9499088011180912], 
             UndirectedEdge[13, 96] -> 
             RGBColor[
              0.3557971492753504, 0.4823533245061042, 0.9439009190224369], 
             UndirectedEdge[16, 53] -> 
             RGBColor[
              0.9125997408169637, 0.6166657914684119, 0.3543422714306673], 
             UndirectedEdge[44, 170] -> 
             RGBColor[
              0.8934743520557873, 0.5315367457661417, 0.24367260924855771`], 
             UndirectedEdge[27, 32] -> 
             RGBColor[
              0.25734797909016266`, 0.3878194212010146, 0.9379669587457427], 
             UndirectedEdge[116, 164] -> 
             RGBColor[
              0.35316605540790247`, 0.4803164193774241, 0.9437244066514788], 
             UndirectedEdge[70, 300] -> 
             RGBColor[
              0.2600472811884571, 0.39065655885195993`, 0.938120680006981], 
             UndirectedEdge[79, 116] -> 
             RGBColor[
              0.3586693068574145, 0.48508305918153105`, 0.9440750689675076], 
             UndirectedEdge[137, 195] -> 
             RGBColor[
              0.8323549819999152, 0.24970014646067296`, 0.17861647334383152`],
              UndirectedEdge[156, 214] -> 
             RGBColor[
              0.2202905707839606, 0.3488697354958046, 0.9358565941642273], 
             UndirectedEdge[14, 249] -> 
             RGBColor[
              0.8206388339044841, 0.15964469815035803`, 0.16739707669615012`],
              UndirectedEdge[84, 89] -> 
             RGBColor[
              0.2893752204809355, 0.4214820825471055, 0.9397908627628895], 
             UndirectedEdge[98, 246] -> 
             RGBColor[
              0.5108375562883921, 0.6129315271469358, 0.9548630505777516], 
             UndirectedEdge[4, 107] -> 
             RGBColor[
              0.6868838807668163, 0.45030100016757835`, 0.5686163001605958], 
             UndirectedEdge[20, 295] -> 
             RGBColor[
              0.851595317593189, 0.8845030065824513, 0.9857071156917947], 
             UndirectedEdge[57, 175] -> 
             RGBColor[
              0.27078207932041887`, 0.40193951231416447`, 0.9387320108798856],
              UndirectedEdge[93, 160] -> 
             RGBColor[
              0.5607147225279772, 0.6542524975154264, 0.9585606634045596], 
             UndirectedEdge[13, 149] -> 
             RGBColor[
              0.30003867844943893`, 0.43269005297428764`, 0.9403981309190235],
              UndirectedEdge[230, 298] -> 
             RGBColor[
              0.2673021323723527, 0.39828186743036675`, 0.9385338330493134], 
             UndirectedEdge[96, 198] -> 
             RGBColor[
              0.43486063371890193`, 0.5507791821456584, 0.9490119679848132], 
             UndirectedEdge[32, 182] -> 
             RGBColor[
              0.2817202883828383, 0.4134362635612778, 0.9393549257043601], 
             UndirectedEdge[80, 241] -> 
             RGBColor[
              0.27345259705009906`, 0.4047463957686619, 0.938884092913914], 
             UndirectedEdge[55, 292] -> 
             RGBColor[
              0.25987815555668636`, 0.39047879708978456`, 0.9381110485524506],
              UndirectedEdge[121, 160] -> 
             RGBColor[
              0.7924150587076538, 0.8345430649548763, 0.8078033989134862], 
             UndirectedEdge[62, 220] -> 
             RGBColor[
              0.6260202363274255, 0.6895227449727015, 0.8093263410054259], 
             UndirectedEdge[28, 189] -> 
             RGBColor[
              0.22763054758381063`, 0.35658451649385525`, 0.9362745949844562],
              UndirectedEdge[25, 91] -> 
             RGBColor[
              0.2622113968861681, 0.3929311816631146, 0.9382439231944433], 
             UndirectedEdge[41, 99] -> 
             RGBColor[
              0.362239582391498, 0.48817545240188814`, 0.9443025637674687], 
             UndirectedEdge[148, 206] -> 
             RGBColor[
              0.23774362795226284`, 0.3672140051674282, 0.9368505199504779], 
             UndirectedEdge[3, 90] -> 
             RGBColor[
              0.39043568607657597`, 0.5125975002365252, 0.9460991945614463], 
             UndirectedEdge[99, 104] -> 
             RGBColor[
              0.3262801186675095, 0.4548403348152493, 0.9420914025992604], 
             UndirectedEdge[193, 266] -> 
             RGBColor[
              0.3235658537972168, 0.4490279862889558, 0.942045190438874], 
             UndirectedEdge[275, 293] -> 
             RGBColor[
              0.21101994270665328`, 0.33912571759478527`, 0.9353286456098898],
              UndirectedEdge[229, 257] -> 
             RGBColor[
              0.3688470358646546, 0.49389849650006856`, 0.9447235848600365], 
             UndirectedEdge[90, 144] -> 
             RGBColor[
              0.35962797975699734`, 0.48591341346284866`, 0.9441361547569478],
              UndirectedEdge[49, 115] -> 
             RGBColor[
              0.22907293102325943`, 0.358100552941108, 0.9363567365875176], 
             UndirectedEdge[77, 244] -> 
             RGBColor[
              0.2442718082387917, 0.3740755365591065, 0.9372222901602183], 
             UndirectedEdge[66, 95] -> 
             RGBColor[
              0.7175511909941827, 0.7776658666577836, 0.9642038036331552], 
             UndirectedEdge[94, 125] -> 
             RGBColor[
              0.9272871440372241, 0.9396965749731525, 0.7126838428267497], 
             UndirectedEdge[196, 230] -> 
             RGBColor[
              0.2651423022333762, 0.39601174901316233`, 0.938410833918081], 
             UndirectedEdge[138, 245] -> 
             RGBColor[
              0.5655432626553039, 0.6564020281299278, 0.9598314214470098], 
             UndirectedEdge[100, 127] -> 
             RGBColor[
              0.8414762129232649, 0.3198099242864162, 0.18735097437698822`], 
             UndirectedEdge[24, 288] -> 
             RGBColor[
              0.9087689498125788, 0.7161208029301624, 0.5832293866647026], 
             UndirectedEdge[224, 258] -> 
             RGBColor[
              0.9656458741337097, 0.9399341707856219, 0.6428561562394914], 
             UndirectedEdge[25, 203] -> 
             RGBColor[
              0.2557021473412196, 0.3860895476811155, 0.9378732310624303], 
             UndirectedEdge[143, 239] -> 
             RGBColor[
              0.4039421601527854, 0.5242961292262122, 0.9469598151462764], 
             UndirectedEdge[142, 282] -> 
             RGBColor[
              0.8113403946734408, 0.8529848446549176, 0.9565261589007614], 
             UndirectedEdge[57, 242] -> 
             RGBColor[
              0.24374269016754463`, 0.3735193999182025, 0.9371921576688209], 
             UndirectedEdge[47, 177] -> 
             RGBColor[
              0.5316337139639098, 0.6296909943120255, 0.956545018426947], 
             UndirectedEdge[43, 174] -> 
             RGBColor[
              0.35724861486395953`, 0.48385252718285615`, 0.9439845437299532],
              UndirectedEdge[5, 29] -> 
             RGBColor[
              0.23189096279390453`, 0.36106248300558996`, 0.9365172193279515],
              UndirectedEdge[167, 282] -> 
             RGBColor[
              0.8587917501354356, 0.8900542041854869, 0.9612556665550847], 
             UndirectedEdge[131, 172] -> 
             RGBColor[
              0.297163306859998, 0.4281806673087738, 0.9402888359918464], 
             UndirectedEdge[21, 101] -> 
             RGBColor[
              0.4650224715635836, 0.5746682645420044, 0.9515515525742121], 
             UndirectedEdge[251, 300] -> 
             RGBColor[
              0.27128730129384493`, 0.40247053264115845`, 0.9387607825238632],
              UndirectedEdge[75, 167] -> 
             RGBColor[
              0.7422194299230214, 0.7985467268232416, 0.9749411544059516], 
             UndirectedEdge[165, 281] -> 
             RGBColor[
              0.9081683799556731, 0.6116901368011833, 0.2799978889278235], 
             UndirectedEdge[63, 174] -> 
             RGBColor[
              0.35841838866408615`, 0.48486572645398507`, 0.944059080682107], 
             UndirectedEdge[64, 211] -> 
             RGBColor[
              0.238007335368493, 0.36749117838190204`, 0.936865537697712], 
             UndirectedEdge[124, 237] -> 
             RGBColor[
              0.7932365579017887, 0.8390697764976703, 0.9690655590701622], 
             UndirectedEdge[127, 192] -> 
             RGBColor[
              0.8488791161434632, 0.3663608331165159, 0.19403468172993021`], 
             UndirectedEdge[62, 228] -> 
             RGBColor[
              0.90559598823519, 0.9239215498870947, 0.8315118721300905], 
             UndirectedEdge[152, 277] -> 
             RGBColor[
              0.3011955804505697, 0.43017548464198757`, 0.9406006083286469], 
             UndirectedEdge[76, 157] -> 
             RGBColor[
              0.3201380287875101, 0.4503731664220151, 0.9416688088356775], 
             UndirectedEdge[106, 297] -> 
             RGBColor[
              0.7085338986582898, 0.7722313337797134, 0.9715836954586705], 
             UndirectedEdge[91, 203] -> 
             RGBColor[
              0.2661031933042482, 0.39702170645266144`, 0.9384655552430561], 
             UndirectedEdge[215, 271] -> 
             RGBColor[
              0.9862840872732699, 0.9639445925953173, 0.5488858494022204], 
             UndirectedEdge[181, 296] -> 
             RGBColor[
              0.7050263286294778, 0.769491193414686, 0.9712340936583042], 
             UndirectedEdge[27, 119] -> 
             RGBColor[
              0.2703316084942079, 0.40146603891431676`, 0.9387063572327446], 
             UndirectedEdge[100, 170] -> 
             RGBColor[
              0.8360368854877944, 0.2780008700889096, 0.18214226828194], 
             UndirectedEdge[112, 115] -> 
             RGBColor[
              0.236902386747869, 0.36632980732383724`, 0.9368026125083924], 
             UndirectedEdge[75, 282] -> 
             RGBColor[
              0.8470847195516484, 0.8809085829167043, 0.9600888191549137], 
             UndirectedEdge[234, 255] -> 
             RGBColor[
              0.8881366683562935, 0.5036662405654082, 0.2296318891309308], 
             UndirectedEdge[29, 77] -> 
             RGBColor[
              0.2444276826034072, 0.3742393703993229, 0.9372311669746878], 
             UndirectedEdge[44, 192] -> 
             RGBColor[
              0.9150207009153106, 0.6868003754774932, 0.26390009611845466`], 
             UndirectedEdge[49, 57] -> 
             RGBColor[
              0.2418037466004938, 0.3714814472931095, 0.9370817377010874], 
             UndirectedEdge[4, 281] -> 
             RGBColor[
              0.6878485673408958, 0.45771600390430534`, 0.5695400851133919], 
             UndirectedEdge[23, 285] -> 
             RGBColor[
              0.33957273212272987`, 0.46739870088843105`, 0.9429001346157797],
              UndirectedEdge[86, 109] -> 
             RGBColor[
              0.9480181265878662, 0.9334317685964351, 0.674604431944415], 
             UndirectedEdge[276, 279] -> 
             RGBColor[
              0.24528708035805388`, 0.3751426519284214, 0.9372801084054498], 
             UndirectedEdge[139, 183] -> 
             RGBColor[
              0.2550340991670391, 0.38538738669335115`, 0.9378351867071995], 
             UndirectedEdge[234, 287] -> 
             RGBColor[
              0.8791470053904711, 0.46890980859888415`, 0.21779165603051126`],
              UndirectedEdge[160, 181] -> 
             RGBColor[
              0.6520185359229838, 0.7272823998054908, 0.9664968499202544], 
             UndirectedEdge[196, 298] -> 
             RGBColor[
              0.28309225038485036`, 0.4148782826128075, 0.9394330569107388], 
             UndirectedEdge[255, 287] -> 
             RGBColor[
              0.9499646737467646, 0.8384490491642924, 0.28320554516144203`], 
             UndirectedEdge[126, 216] -> 
             RGBColor[
              0.24238826022285348`, 0.3720958081705137, 0.9371150248871702], 
             UndirectedEdge[190, 212] -> 
             RGBColor[
              0.21992645288427248`, 0.3484870244968241, 0.9358358581885042], 
             UndirectedEdge[39, 137] -> 
             RGBColor[
              0.8565494590888623, 0.4213131070375924, 0.20122297160509353`], 
             UndirectedEdge[170, 195] -> 
             RGBColor[
              0.820518598671917, 0.15872051746543236`, 0.16728193930165758`], 
             UndirectedEdge[69, 288] -> 
             RGBColor[
              0.9274695616660017, 0.7266621842687284, 0.34504384155502377`], 
             UndirectedEdge[101, 231] -> 
             RGBColor[
              0.49585480302230733`, 0.6013736803735128, 0.9535161614708018], 
             UndirectedEdge[57, 253] -> 
             RGBColor[
              0.27188917324815276`, 0.40310313822602206`, 0.9387950582412713],
              UndirectedEdge[52, 266] -> 
             RGBColor[
              0.5326709863563452, 0.2573632665445422, 0.5510021420640641], 
             UndirectedEdge[28, 275] -> 
             RGBColor[
              0.21809561015053047`, 0.3465626927015274, 0.9357315944033067], 
             UndirectedEdge[4, 226] -> 
             RGBColor[
              0.35927387507325015`, 0.47126073145434144`, 0.9452005342031744],
              UndirectedEdge[104, 229] -> 
             RGBColor[
              0.3157302972548372, 0.4457026097570346, 0.9414191773076857], 
             UndirectedEdge[189, 293] -> 
             RGBColor[
              0.2205548801399334, 0.3491475413871131, 0.9358716461910392], 
             UndirectedEdge[155, 156] -> 
             RGBColor[
              0.22000089461836236`, 0.3485652674792311, 0.935840097535134], 
             UndirectedEdge[107, 281] -> 
             RGBColor[
              0.835111708182694, 0.27088955190662645`, 0.18125631744973736`], 
             UndirectedEdge[107, 240] -> 
             RGBColor[
              0.9145402901776019, 0.6275231337808342, 0.4351299261966648], 
             UndirectedEdge[13, 105] -> 
             RGBColor[
              0.29764935998569264`, 0.4301787277773499, 0.9402620627671929], 
             UndirectedEdge[96, 138] -> 
             RGBColor[
              0.5560749070471602, 0.6482010143955439, 0.959228106200197], 
             UndirectedEdge[254, 260] -> 
             RGBColor[
              0.870237845536556, 0.7409780985202714, 0.6082514586621423], 
             UndirectedEdge[120, 176] -> 
             RGBColor[
              0.18443322649941224`, 0.31118139316580623`, 0.9338145714534094],
              UndirectedEdge[59, 125] -> 
             RGBColor[
              0.9127176607588363, 0.6199165551572493, 0.3088626814342206], 
             UndirectedEdge[22, 267] -> 
             RGBColor[
              0.642613111904264, 0.7180602166534845, 0.966841075599027], 
             UndirectedEdge[28, 197] -> 
             RGBColor[
              0.21695644286649302`, 0.3453653556586265, 0.9356667205117277], 
             UndirectedEdge[245, 298] -> 
             RGBColor[
              0.35482735126592213`, 0.47958317697125596`, 0.9439097968625934],
              UndirectedEdge[193, 199] -> 
             RGBColor[
              0.28921237678725265`, 0.4129203038152378, 0.9400888107445714], 
             UndirectedEdge[22, 274] -> 
             RGBColor[
              0.8909772154370372, 0.8747143818458635, 0.6496575550294168], 
             UndirectedEdge[76, 201] -> 
             RGBColor[
              0.3077043294157084, 0.43960372096206174`, 0.9408765445063949], 
             UndirectedEdge[19, 158] -> 
             RGBColor[
              0.3474496051113486, 0.47374907870238386`, 0.9434193305882683], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.17948366008578914`, 0.30597908504445237`, 0.9335327009683809],
              UndirectedEdge[61, 267] -> 
             RGBColor[
              0.517343318582302, 0.6190416379328455, 0.9551463076112685], 
             UndirectedEdge[106, 283] -> 
             RGBColor[
              0.6376959489926155, 0.716530117719581, 0.9647707808430861], 
             UndirectedEdge[174, 283] -> 
             RGBColor[
              0.5055233087265141, 0.6077894774448256, 0.9546733906594562], 
             UndirectedEdge[19, 242] -> 
             RGBColor[
              0.26584977931499626`, 0.39675535228258274`, 0.9384511236912607],
              UndirectedEdge[125, 195] -> 
             RGBColor[
              0.9058844617461582, 0.5673935932189047, 0.3023192023426855], 
             UndirectedEdge[115, 159] -> 
             RGBColor[
              0.23449254027581456`, 0.3637969058886168, 0.9366653753168572], 
             UndirectedEdge[158, 177] -> 
             RGBColor[
              0.4114198455834537, 0.5307729245068593, 0.947436286649661], 
             UndirectedEdge[42, 134] -> 
             RGBColor[
              0.26421930785544107`, 0.3950416234007289, 0.9383582707537054], 
             UndirectedEdge[165, 179] -> 
             RGBColor[
              0.986953469781533, 0.9683582137242022, 0.5663859549250714], 
             UndirectedEdge[108, 145] -> 
             RGBColor[
              0.3065621353882716, 0.43629450439653, 0.9408887080179298], 
             UndirectedEdge[44, 125] -> 
             RGBColor[
              0.9788402151300284, 0.9402098215196141, 0.37870987228958564`], 
             UndirectedEdge[39, 141] -> 
             RGBColor[
              0.8832675790785431, 0.5628271647927903, 0.22430794542071705`], 
             UndirectedEdge[50, 87] -> 
             RGBColor[
              0.314278172622923, 0.4436160187426821, 0.9413569968700557], 
             UndirectedEdge[26, 226] -> 
             RGBColor[
              0.5823809999360594, 0.646902214593436, 0.908957705075064], 
             UndirectedEdge[9, 143] -> 
             RGBColor[
              0.4567898510085129, 0.5683456525115964, 0.9508037050929882], 
             UndirectedEdge[136, 299] -> 
             RGBColor[
              0.9936961088777931, 0.9896128904175391, 0.6052453259924624], 
             UndirectedEdge[134, 144] -> 
             RGBColor[
              0.29485513198583013`, 0.42659799471298, 0.9401265091035182], 
             UndirectedEdge[240, 281] -> 
             RGBColor[
              0.9155049767516813, 0.6349381375175613, 0.436053711149461], 
             UndirectedEdge[257, 261] -> 
             RGBColor[
              0.39597335276996437`, 0.5173939487951174, 0.9464520497863826], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.27383547980684575`, 0.4051488298221716, 0.9389058975204863], 
             UndirectedEdge[135, 254] -> 
             RGBColor[
              0.940708824154274, 0.7947861767157479, 0.5224157389136257], 
             UndirectedEdge[14, 224] -> 
             RGBColor[
              0.8961112066597844, 0.5421659440515132, 0.2527391724419306], 
             UndirectedEdge[96, 289] -> 
             RGBColor[
              0.3482245893870246, 0.47439408393544596`, 0.9434696729393952], 
             UndirectedEdge[92, 189] -> 
             RGBColor[
              0.2464728493758267, 0.3763889703481986, 0.937347636196824], 
             UndirectedEdge[107, 127] -> 
             RGBColor[
              0.8334595581640123, 0.25819040288628525`, 0.17967421672601133`],
              UndirectedEdge[172, 270] -> 
             RGBColor[
              0.24887539777286288`, 0.3789142010438502, 0.9374844577737833], 
             UndirectedEdge[48, 84] -> 
             RGBColor[
              0.35715044434118537`, 0.4830160061947183, 0.9440058041437522], 
             UndirectedEdge[149, 289] -> 
             RGBColor[
              0.29246611856111315`, 0.4247308124036294, 0.9399668848359817], 
             UndirectedEdge[1, 102] -> 
             RGBColor[
              0.40192272768373283`, 0.5225469983211459, 0.9468311386950623], 
             UndirectedEdge[33, 297] -> 
             RGBColor[
              0.8375308432174786, 0.8737699796260231, 0.9842378309047126], 
             UndirectedEdge[18, 135] -> 
             RGBColor[
              0.9682482286960121, 0.9748593362633335, 0.8947082894518925], 
             UndirectedEdge[60, 137] -> 
             RGBColor[
              0.8858243279121996, 0.5479479904274629, 0.22532498219274089`], 
             UndirectedEdge[156, 208] -> 
             RGBColor[
              0.2568293808226203, 0.38727434154079826`, 0.9379374253416035], 
             UndirectedEdge[104, 279] -> 
             RGBColor[
              0.27193222945827744`, 0.4031483930327844, 0.9387975102287419], 
             UndirectedEdge[74, 158] -> 
             RGBColor[
              0.5209230649967003, 0.6205987474764012, 0.9558008759103712], 
             UndirectedEdge[80, 277] -> 
             RGBColor[
              0.30846241772387, 0.4378133913603206, 0.9410144439610391], 
             UndirectedEdge[223, 291] -> 
             RGBColor[
              0.8526313936469496, 0.36002028922446494`, 0.19625022045814194`],
              UndirectedEdge[114, 264] -> 
             RGBColor[
              0.29953624630010656`, 0.4321619649293011, 0.9403695181514007], 
             UndirectedEdge[1, 237] -> 
             RGBColor[
              0.5286509868219015, 0.6272769374241931, 0.9562975328211968], 
             UndirectedEdge[84, 292] -> 
             RGBColor[
              0.2718397461725893, 0.40305118723574723`, 0.9387922434424387], 
             UndirectedEdge[103, 152] -> 
             RGBColor[
              0.26605649274810816`, 0.396972621207172, 0.9384628957154713], 
             UndirectedEdge[10, 269] -> 
             RGBColor[
              0.2192290472618576, 0.3477540069695957, 0.9357961419700269], 
             UndirectedEdge[109, 138] -> 
             RGBColor[
              0.8139262808550589, 0.8553825016885668, 0.9818711941291625], 
             UndirectedEdge[165, 240] -> 
             RGBColor[
              0.987596961950581, 0.9683237186753911, 0.533871497674751], 
             UndirectedEdge[249, 254] -> 
             RGBColor[
              0.8549509396381043, 0.371609679278205, 0.19822709100428773`], 
             UndirectedEdge[2, 155] -> 
             RGBColor[
              0.22153004206728566`, 0.3501724984015976, 0.9359271802201792], 
             UndirectedEdge[117, 161] -> 
             RGBColor[
              0.20987266837087443`, 0.33791985952648745`, 0.9352633100337076],
              UndirectedEdge[169, 264] -> 
             RGBColor[
              0.29384317958318956`, 0.42617819084854336`, 0.9400453064240097],
              UndirectedEdge[3, 229] -> 
             RGBColor[
              0.3618568268450173, 0.48784392878537974`, 0.9442781749225044], 
             UndirectedEdge[55, 90] -> 
             RGBColor[
              0.3401206359010615, 0.4660537805054501, 0.9430016668956538], 
             UndirectedEdge[3, 259] -> 
             RGBColor[
              0.42079287632469464`, 0.5385942486118271, 0.9481156241324957], 
             UndirectedEdge[113, 254] -> 
             RGBColor[
              0.925365599889266, 0.7843240503848107, 0.5923111720047104], 
             UndirectedEdge[6, 205] -> 
             RGBColor[
              0.41755993513205164`, 0.5337399711358773, 0.9484090697443592], 
             UndirectedEdge[120, 287] -> 
             RGBColor[
              0.5654447927305568, 0.5603176274195498, 0.6027460190921992], 
             UndirectedEdge[31, 67] -> 
             RGBColor[
              0.765577527957654, 0.8171802233035855, 0.9773175856314692], 
             UndirectedEdge[141, 232] -> 
             RGBColor[
              0.9465494933171561, 0.8120284719793993, 0.41813025783551805`], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.4306059655104517, 0.5460088371370204, 0.9490406986812941], 
             UndirectedEdge[71, 122] -> 
             RGBColor[
              0.6268946494046528, 0.707980343525642, 0.9637705896733515], 
             UndirectedEdge[78, 120] -> 
             RGBColor[
              0.1849774474258748, 0.3117534038651181, 0.9338455640300687], 
             UndirectedEdge[177, 247] -> 
             RGBColor[
              0.4991479409504841, 0.603343634292864, 0.9539698061272375], 
             UndirectedEdge[168, 182] -> 
             RGBColor[
              0.34652806688330007`, 0.474422427150048, 0.9433067307526943], 
             UndirectedEdge[26, 228] -> 
             RGBColor[
              0.901089116284713, 0.9224316156704129, 0.933371766463492], 
             UndirectedEdge[7, 194] -> 
             RGBColor[
              0.4552899701705174, 0.5670735874923983, 0.9507006582548503], 
             UndirectedEdge[206, 244] -> 
             RGBColor[
              0.23959248852906917`, 0.3691572748581827, 0.9369558098251829], 
             UndirectedEdge[31, 109] -> 
             RGBColor[
              0.7700026915435176, 0.8207087286290875, 0.9777396616846791], 
             UndirectedEdge[57, 235] -> 
             RGBColor[
              0.24454607243650103`, 0.3743638056202535, 0.9372379091005405], 
             UndirectedEdge[24, 135] -> 
             RGBColor[
              0.9728662611822794, 0.9783034573302576, 0.8868911650284141], 
             UndirectedEdge[130, 220] -> 
             RGBColor[
              0.21805936955163013`, 0.34652460153429643`, 0.9357295305548126],
              UndirectedEdge[84, 112] -> 
             RGBColor[
              0.2764157065059942, 0.4078608116787981, 0.9390528376138995], 
             UndirectedEdge[76, 104] -> 
             RGBColor[
              0.2896837321277139, 0.4218063478486378, 0.9398084320447715], 
             UndirectedEdge[21, 87] -> 
             RGBColor[
              0.32978099166431396`, 0.45704378140199375`, 0.9423448227907686],
              UndirectedEdge[43, 183] -> 
             RGBColor[
              0.28838161647063476`, 0.4191962552733669, 0.9397797353853092], 
             UndirectedEdge[11, 131] -> 
             RGBColor[
              0.3341685066956953, 0.46386169752747186`, 0.9425138996464097], 
             UndirectedEdge[21, 187] -> 
             RGBColor[
              0.3736920911272321, 0.49809503984895503`, 0.9450323074970538], 
             UndirectedEdge[36, 66] -> 
             RGBColor[
              0.8530135718328662, 0.8858447874582254, 0.9760955206644191], 
             UndirectedEdge[124, 125] -> 
             RGBColor[
              0.970159485355791, 0.9735725032155419, 0.706048969605638], 
             UndirectedEdge[232, 296] -> 
             RGBColor[
              0.8451660598218556, 0.8762026073137711, 0.7845904625645401], 
             UndirectedEdge[75, 239] -> 
             RGBColor[
              0.5708233361978141, 0.6599633407458361, 0.9605961986132696], 
             UndirectedEdge[108, 114] -> 
             RGBColor[
              0.32416580444258236`, 0.4547970767096937, 0.9418912109282782], 
             UndirectedEdge[137, 266] -> 
             RGBColor[
              0.546600080262197, 0.3644283860727875, 0.564340658118969], 
             UndirectedEdge[74, 262] -> 
             RGBColor[
              0.8160969055518104, 0.8533507770496733, 0.7753857250766871], 
             UndirectedEdge[48, 90] -> 
             RGBColor[
              0.4086146868704133, 0.5283432370210001, 0.9472575444169704], 
             UndirectedEdge[125, 150] -> 
             RGBColor[
              0.9773157340645346, 0.9789096217852411, 0.6939353071903218], 
             UndirectedEdge[38, 55] -> 
             RGBColor[
              0.34731954937378307`, 0.4722891175276097, 0.9434603752963864], 
             UndirectedEdge[110, 165] -> 
             RGBColor[
              0.9866031709361507, 0.9682133561493669, 0.5721913133374072], 
             UndirectedEdge[114, 145] -> 
             RGBColor[
              0.28680752014306377`, 0.4187832666903979, 0.9396446360272199], 
             UndirectedEdge[222, 290] -> 
             RGBColor[
              0.5245306986367102, 0.6244100551018348, 0.9558410534763778], 
             UndirectedEdge[267, 286] -> 
             RGBColor[
              0.5134415575632728, 0.6158740125652669, 0.954839146691229], 
             UndirectedEdge[6, 187] -> 
             RGBColor[
              0.3348012763614461, 0.46412565624274105`, 0.9425646219959795], 
             UndirectedEdge[221, 231] -> 
             RGBColor[
              0.3698663550363416, 0.4934747204504928, 0.9448363781661868], 
             UndirectedEdge[106, 286] -> 
             RGBColor[
              0.6078523188068897, 0.6923017142945901, 0.9624213809540463], 
             UndirectedEdge[67, 154] -> 
             RGBColor[
              0.8267592072412856, 0.8653361474156035, 0.9831692431983503], 
             UndirectedEdge[85, 296] -> 
             RGBColor[
              0.8079306217366228, 0.8506861757670146, 0.9812769124001008], 
             UndirectedEdge[41, 201] -> 
             RGBColor[
              0.3390519049385823, 0.4680914516387281, 0.942825065464227], 
             UndirectedEdge[42, 235] -> 
             RGBColor[
              0.24823850572703557`, 0.37824478712239773`, 0.9374481877139709],
              UndirectedEdge[44, 60] -> 
             RGBColor[
              0.9455688567915195, 0.8192169579907062, 0.28906456863413965`], 
             UndirectedEdge[199, 228] -> 
             RGBColor[
              0.49763512145939465`, 0.5809234064486897, 0.9579150616794772], 
             UndirectedEdge[39, 62] -> 
             RGBColor[
              0.931190722612425, 0.7413845468769279, 0.4459365036310404], 
             UndirectedEdge[48, 144] -> 
             RGBColor[
              0.3646961975812182, 0.4903032490061542, 0.9444590971150582], 
             UndirectedEdge[68, 215] -> 
             RGBColor[
              0.9347347232001206, 0.7573256172439325, 0.47384806566130333`], 
             UndirectedEdge[127, 240] -> 
             RGBColor[
              0.9138528267329997, 0.6222389884972201, 0.4344716104257349], 
             UndirectedEdge[4, 26] -> 
             RGBColor[
              0.7627278647878275, 0.8127689353043519, 0.92065723869614], 
             UndirectedEdge[8, 47] -> 
             RGBColor[
              0.6479545398771973, 0.7249062782797447, 0.9655457111216659], 
             UndirectedEdge[112, 175] -> 
             RGBColor[
              0.27336230601956724`, 0.40465149417079094`, 0.9388789509732987],
              UndirectedEdge[162, 203] -> 
             RGBColor[
              0.27206034387321254`, 0.4032830494058043, 0.9388048061551442], 
             UndirectedEdge[6, 50] -> 
             RGBColor[
              0.32906105284495657`, 0.4591537631447806, 0.9421988600293891], 
             UndirectedEdge[15, 294] -> 
             RGBColor[
              0.2244101664519819, 0.3531996917403464, 0.9360911990431254], 
             UndirectedEdge[6, 219] -> 
             RGBColor[
              0.2899540268393041, 0.4220904447281936, 0.9398238249287314], 
             UndirectedEdge[110, 281] -> 
             RGBColor[
              0.914511185737251, 0.6348277749915371, 0.4743735268121172], 
             UndirectedEdge[167, 297] -> 
             RGBColor[
              0.7571627446031911, 0.8102205578247882, 0.9764305643600557], 
             UndirectedEdge[122, 246] -> 
             RGBColor[
              0.6115303319065195, 0.6955068984260417, 0.962561054318549], 
             UndirectedEdge[210, 277] -> 
             RGBColor[
              0.36382607089811214`, 0.48954958900708645`, 0.9444036534122333],
              UndirectedEdge[225, 234] -> 
             RGBColor[
              0.889140927135372, 0.5070538412384147, 0.23353324484929344`], 
             UndirectedEdge[84, 280] -> 
             RGBColor[
              0.28433817175579457`, 0.41618782496964746`, 0.9395040102896386],
              UndirectedEdge[67, 95] -> 
             RGBColor[
              0.7004824194836051, 0.7643330817431344, 0.9721930602411528], 
             UndirectedEdge[81, 285] -> 
             RGBColor[
              0.33930631085889784`, 0.4671186752480599, 0.9428849623189395], 
             UndirectedEdge[79, 164] -> 
             RGBColor[
              0.38942752096010885`, 0.5117242782844935, 0.9460349551717104], 
             UndirectedEdge[123, 157] -> 
             RGBColor[
              0.3911005410183704, 0.5131733641705265, 0.9461415585304294], 
             UndirectedEdge[85, 165] -> 
             RGBColor[
              0.9499430145672961, 0.9419121380578821, 0.6850057931573457], 
             UndirectedEdge[59, 62] -> 
             RGBColor[
              0.9138294445361559, 0.6222945482383531, 0.42987348446131357`], 
             UndirectedEdge[38, 48] -> 
             RGBColor[
              0.41581360034313486`, 0.5345785740431597, 0.947716252817703], 
             UndirectedEdge[262, 291] -> 
             RGBColor[
              0.9059438756426232, 0.5640930053700905, 0.37544589714295], 
             UndirectedEdge[26, 170] -> 
             RGBColor[
              0.903864214749553, 0.5788492838255521, 0.5265064491665074], 
             UndirectedEdge[43, 139] -> 
             RGBColor[
              0.2888262243395204, 0.4196635663333328, 0.9398050551457039], 
             UndirectedEdge[52, 281] -> 
             RGBColor[
              0.8268922067247678, 0.207710861892501, 0.1733853135710282], 
             UndirectedEdge[124, 142] -> 
             RGBColor[
              0.8033587771487245, 0.8470321673736835, 0.9700369554308557], 
             UndirectedEdge[166, 271] -> 
             RGBColor[
              0.9850940999243964, 0.9612451065301149, 0.40815265332302325`], 
             UndirectedEdge[37, 150] -> 
             RGBColor[
              0.8213545365263866, 0.860837194061274, 0.9590036741380308], 
             UndirectedEdge[51, 66] -> 
             RGBColor[
              0.9700089985303242, 0.9755966228942858, 0.8659381168837096], 
             UndirectedEdge[60, 125] -> 
             RGBColor[
              0.9593538076584427, 0.8656414371856946, 0.3490277111915949], 
             UndirectedEdge[215, 223] -> 
             RGBColor[
              0.9412290011481947, 0.7868146166289862, 0.47926705037049566`], 
             UndirectedEdge[237, 282] -> 
             RGBColor[
              0.8012181754265049, 0.8450224537789045, 0.955554762540068], 
             UndirectedEdge[143, 172] -> 
             RGBColor[
              0.33312272414216076`, 0.4593269071857189, 0.9425801382634016], 
             UndirectedEdge[177, 285] -> 
             RGBColor[
              0.40098949086418123`, 0.5217386754938967, 0.9467716736701495], 
             UndirectedEdge[244, 270] -> 
             RGBColor[
              0.23538330068246843`, 0.36473315155348174`, 0.9367161028042543],
              UndirectedEdge[147, 272] -> 
             RGBColor[
              0.2247364657597668, 0.3535426530013993, 0.9361097813059873], 
             UndirectedEdge[46, 114] -> 
             RGBColor[
              0.29827465777054285`, 0.4308359553953969, 0.9402976725509951], 
             UndirectedEdge[104, 128] -> 
             RGBColor[
              0.26216622821870855`, 0.39288370652975557`, 0.9382413509056526],
              UndirectedEdge[199, 220] -> 
             RGBColor[
              0.21805936955163013`, 0.34652460153429643`, 0.9357295305548126],
              UndirectedEdge[112, 146] -> 
             RGBColor[
              0.24133200131587673`, 0.37098561308859834`, 0.937054872505013], 
             UndirectedEdge[191, 203] -> 
             RGBColor[
              0.2517414689713402, 0.38192662359285945`, 0.9376476762885642], 
             UndirectedEdge[31, 96] -> 
             RGBColor[
              0.512151317735619, 0.6135272413360646, 0.9550965737557137], 
             UndirectedEdge[59, 228] -> 
             RGBColor[
              0.8245766992197552, 0.5548258112486377, 0.5806907356901773], 
             UndirectedEdge[129, 289] -> 
             RGBColor[
              0.26344635035437974`, 0.39422919605877726`, 0.9383142519675081],
              UndirectedEdge[54, 106] -> 
             RGBColor[
              0.5370375913061106, 0.6338360445866622, 0.9571160047492481], 
             UndirectedEdge[102, 142] -> 
             RGBColor[
              0.5221732711977142, 0.6208612990518254, 0.9562111960106483], 
             UndirectedEdge[74, 90] -> 
             RGBColor[
              0.5208802713688769, 0.620561681786851, 0.9557981491382472], 
             UndirectedEdge[143, 174] -> 
             RGBColor[
              0.39453676766698986`, 0.5161496509837875, 0.9463605118539434], 
             UndirectedEdge[144, 292] -> 
             RGBColor[
              0.2793854994126222, 0.4103384300471832, 0.9392455364137446], 
             UndirectedEdge[59, 255] -> 
             RGBColor[
              0.895882246116654, 0.5632021453653563, 0.23704906314163093`], 
             UndirectedEdge[254, 258] -> 
             RGBColor[
              0.926544473085371, 0.7852032520842381, 0.5903156471830767], 
             UndirectedEdge[46, 108] -> 
             RGBColor[
              0.3180292730157506, 0.448347193101529, 0.9415417445417048], 
             UndirectedEdge[222, 278] -> 
             RGBColor[
              0.51953209520131, 0.6203519636484585, 0.9554475451034554], 
             UndirectedEdge[115, 294] -> 
             RGBColor[
              0.2157444487404361, 0.3440914729872748, 0.9355976992392334], 
             UndirectedEdge[89, 177] -> 
             RGBColor[
              0.3486700459196015, 0.47359177071300174`, 0.9435415608547846], 
             UndirectedEdge[45, 195] -> 
             RGBColor[
              0.8384837744462674, 0.29680873085731074`, 0.18448541191193943`],
              UndirectedEdge[205, 231] -> 
             RGBColor[
              0.4872830813565614, 0.5944147705735998, 0.9528413641420233], 
             UndirectedEdge[148, 244] -> 
             RGBColor[
              0.24066234627754973`, 0.37028176318473494`, 0.9370167366412461],
              UndirectedEdge[20, 297] -> 
             RGBColor[
              0.8131524423226874, 0.8543313044865806, 0.981912597264512], 
             UndirectedEdge[6, 34] -> 
             RGBColor[
              0.31658612534963915`, 0.4483486079564237, 0.9414039686805327], 
             UndirectedEdge[13, 245] -> 
             RGBColor[
              0.36526550488349396`, 0.49055433824048805`, 0.9445042342692497],
              UndirectedEdge[104, 201] -> 
             RGBColor[
              0.30309244121459367`, 0.43475633405208935`, 0.9406139042960187],
              UndirectedEdge[55, 253] -> 
             RGBColor[
              0.2867100868131406, 0.4186808580830187, 0.9396390873432205], 
             UndirectedEdge[52, 141] -> 
             RGBColor[
              0.8583552325882947, 0.3856963454250917, 0.20101401461005142`], 
             UndirectedEdge[160, 299] -> 
             RGBColor[
              0.7923522710279916, 0.8350967196266381, 0.8509761351220573], 
             UndirectedEdge[229, 284] -> 
             RGBColor[
              0.3010164849724387, 0.4302374601386527, 0.9405812474653377], 
             UndirectedEdge[27, 268] -> 
             RGBColor[
              0.2604774227946408, 0.3911086649526121, 0.9381451759351156], 
             UndirectedEdge[193, 236] -> 
             RGBColor[
              0.511354201918838, 0.6127180573453962, 0.9550785966275717], 
             UndirectedEdge[78, 193] -> 
             RGBColor[
              0.2897690368730418, 0.4135053888596902, 0.9401205117129523], 
             UndirectedEdge[175, 177] -> 
             RGBColor[
              0.3568594089399756, 0.48219931048302006`, 0.944007932963718], 
             UndirectedEdge[36, 67] -> 
             RGBColor[
              0.8359448003222887, 0.8725120025435762, 0.9840847772724168], 
             UndirectedEdge[37, 239] -> 
             RGBColor[
              0.5459185219885249, 0.6405075106019407, 0.9581139194816087], 
             UndirectedEdge[49, 280] -> 
             RGBColor[
              0.2523064385494426, 0.38252044244058536`, 0.9376798504702395], 
             UndirectedEdge[263, 276] -> 
             RGBColor[
              0.24638255548127658`, 0.37629406574006286`, 0.9373424940931072],
              UndirectedEdge[13, 73] -> 
             RGBColor[
              0.31756925587348483`, 0.44924224463119755`, 0.9414650714584689],
              UndirectedEdge[136, 240] -> 
             RGBColor[
              0.9939206142632153, 0.9894051335662295, 0.5796745640498617], 
             UndirectedEdge[79, 241] -> 
             RGBColor[
              0.3370030923017984, 0.46357362454027395`, 0.9427949607029437], 
             UndirectedEdge[78, 226] -> 
             RGBColor[
              0.17948366519653014`, 0.30597909041616517`, 0.9335327012594301],
              UndirectedEdge[3, 74] -> 
             RGBColor[
              0.5077694883992605, 0.6092057805456816, 0.9549627416408335], 
             UndirectedEdge[148, 203] -> 
             RGBColor[
              0.2492037147300215, 0.37925928298232137`, 0.9375031549387921], 
             UndirectedEdge[90, 257] -> 
             RGBColor[
              0.39742589509621323`, 0.518652067951214, 0.9465446044989785], 
             UndirectedEdge[34, 87] -> 
             RGBColor[
              0.3018032451276056, 0.4328108635543251, 0.9405621055211995], 
             UndirectedEdge[146, 235] -> 
             RGBColor[
              0.23624487142727435`, 0.3656387170330131, 0.9367651679835913], 
             UndirectedEdge[181, 256] -> 
             RGBColor[
              0.8545325264557142, 0.8843014088645924, 0.8481299389821997], 
             UndirectedEdge[68, 287] -> 
             RGBColor[
              0.9076706141527531, 0.6630503890698746, 0.24412287160438084`], 
             UndirectedEdge[17, 144] -> 
             RGBColor[
              0.3059659418661292, 0.4382761603632087, 0.940759253289231], 
             UndirectedEdge[163, 216] -> 
             RGBColor[
              0.2500986511246546, 0.3801999178753255, 0.9375541202425267], 
             UndirectedEdge[67, 258] -> 
             RGBColor[
              0.9370426830307382, 0.9519641935346369, 0.9705507738068005], 
             UndirectedEdge[232, 240] -> 
             RGBColor[
              0.9945150494485371, 0.9906765703210165, 0.6443751655434223], 
             UndirectedEdge[133, 210] -> 
             RGBColor[
              0.36435206965698563`, 0.49000518269455634`, 0.9444371695880264],
              UndirectedEdge[58, 154] -> 
             RGBColor[
              0.6450616328403926, 0.7212149997583763, 0.9662359728150638], 
             UndirectedEdge[94, 124] -> 
             RGBColor[
              0.9048214633960636, 0.926634777474092, 0.9800597975853467], 
             UndirectedEdge[50, 213] -> 
             RGBColor[
              0.3901638861949155, 0.5123620808400902, 0.94608187571333], 
             UndirectedEdge[15, 212] -> 
             RGBColor[
              0.22532179004368708`, 0.3541578659355026, 0.9361431146580468], 
             UndirectedEdge[11, 139] -> 
             RGBColor[
              0.2994922538712322, 0.4289019450234698, 0.940484685115865], 
             UndirectedEdge[167, 286] -> 
             RGBColor[
              0.6564811647517911, 0.7302909383396649, 0.9672682498554315], 
             UndirectedEdge[113, 288] -> 
             RGBColor[
              0.9106552013287734, 0.717527566222487, 0.5800364548609709], 
             UndirectedEdge[73, 171] -> 
             RGBColor[
              0.3736817156213931, 0.4980860531072854, 0.9450316463789965], 
             UndirectedEdge[31, 110] -> 
             RGBColor[
              0.8058913506986181, 0.8463947757840589, 0.8648515957717691], 
             UndirectedEdge[202, 275] -> 
             RGBColor[
              0.22044981250771753`, 0.3490371086439815, 0.9358656627448182], 
             UndirectedEdge[103, 241] -> 
             RGBColor[
              0.2789461451652853, 0.41052046314879065`, 0.9391969423520976], 
             UndirectedEdge[9, 20] -> 
             RGBColor[
              0.6913677553568252, 0.7572692319617951, 0.9710889688646087], 
             UndirectedEdge[71, 207] -> 
             RGBColor[
              0.6875924129964879, 0.7556761815938675, 0.9696301113207838], 
             UndirectedEdge[160, 168] -> 
             RGBColor[
              0.4880465107801085, 0.5934258804224648, 0.9533459462263981], 
             UndirectedEdge[6, 114] -> 
             RGBColor[
              0.30504212315896806`, 0.43794899060072, 0.940683069693298], 
             UndirectedEdge[95, 96] -> 
             RGBColor[
              0.44705620926157014`, 0.5606800997756136, 0.9499720483653973], 
             UndirectedEdge[198, 278] -> 
             RGBColor[
              0.5335934338471843, 0.6322342135642272, 0.9564255762110536], 
             UndirectedEdge[86, 281] -> 
             RGBColor[
              0.9054719947624891, 0.6025945964032228, 0.26952294162192125`], 
             UndirectedEdge[107, 165] -> 
             RGBColor[
              0.9072036933815937, 0.6042751330644562, 0.27907410397502735`], 
             UndirectedEdge[155, 184] -> 
             RGBColor[
              0.22486994634019453`, 0.35368294955458646`, 0.9361173828275757],
              UndirectedEdge[247, 285] -> 
             RGBColor[
              0.4809297969495969, 0.5875639936298371, 0.952808962101173], 
             UndirectedEdge[34, 227] -> 
             RGBColor[
              0.2936321912026204, 0.4242225678044243, 0.9400967760881624], 
             UndirectedEdge[116, 152] -> 
             RGBColor[
              0.2878519743324149, 0.4186179236915859, 0.9397503655460857], 
             UndirectedEdge[146, 204] -> 
             RGBColor[
              0.23066664293228167`, 0.35977564520466165`, 0.936447496123051], 
             UndirectedEdge[36, 58] -> 
             RGBColor[
              0.6542472259213957, 0.728390854886349, 0.9671515068891303], 
             UndirectedEdge[105, 129] -> 
             RGBColor[
              0.2625398824694277, 0.39327644083830926`, 0.9382626299624591], 
             UndirectedEdge[87, 187] -> 
             RGBColor[
              0.3200183961394125, 0.4485879118406425, 0.9417227588366461], 
             UndirectedEdge[119, 168] -> 
             RGBColor[
              0.3340488783835623, 0.46130600881057365`, 0.9425960594289393], 
             UndirectedEdge[20, 37] -> 
             RGBColor[
              0.7733043134332283, 0.8232016433411387, 0.9779409081787471], 
             UndirectedEdge[150, 200] -> 
             RGBColor[
              0.9240011310350597, 0.7732005239509658, 0.5878910864110933], 
             UndirectedEdge[1, 43] -> 
             RGBColor[
              0.370348202098986, 0.49519873124143765`, 0.944819237845059], 
             UndirectedEdge[187, 213] -> 
             RGBColor[
              0.395904109711405, 0.5173339739380506, 0.9464476376799205], 
             UndirectedEdge[41, 222] -> 
             RGBColor[
              0.3965617253644508, 0.517903567563995, 0.9464895403678258], 
             UndirectedEdge[196, 263] -> 
             RGBColor[
              0.27095799274113747`, 0.40212440847289477`, 0.9387420288889549],
              UndirectedEdge[148, 172] -> 
             RGBColor[
              0.2541544433679442, 0.3844628126751034, 0.9377850916107751], 
             UndirectedEdge[96, 171] -> 
             RGBColor[
              0.4119096090232586, 0.5311971329821921, 0.9474674939429645], 
             UndirectedEdge[178, 208] -> 
             RGBColor[
              0.2815080542956977, 0.41321319207927465`, 0.9393428392870697], 
             UndirectedEdge[25, 270] -> 
             RGBColor[
              0.24003287271686014`, 0.3696201465615213, 0.9369808890531874], 
             UndirectedEdge[47, 217] -> 
             RGBColor[
              0.7255477462839056, 0.7855226808548759, 0.9732794767865461], 
             UndirectedEdge[33, 142] -> 
             RGBColor[
              0.7868432036591011, 0.8341724103626897, 0.9791857606964562], 
             UndirectedEdge[26, 62] -> 
             RGBColor[
              0.9903418616011138, 0.9899003526601282, 0.7825545152346283], 
             UndirectedEdge[48, 177] -> 
             RGBColor[
              0.4164452697798513, 0.5351256943606145, 0.9477565022356473], 
             UndirectedEdge[238, 300] -> 
             RGBColor[
              0.2671877155710705, 0.398161608117775, 0.9385273171817448], 
             UndirectedEdge[25, 139] -> 
             RGBColor[
              0.25364452897953216`, 0.38392686032244283`, 0.9377560527407058],
              UndirectedEdge[3, 30] -> 
             RGBColor[
              0.4197616538813304, 0.5377570557762624, 0.9480344425242617], 
             UndirectedEdge[95, 171] -> 
             RGBColor[
              0.45349990749309843`, 0.5662613073140733, 0.9503826351187716], 
             UndirectedEdge[21, 50] -> 
             RGBColor[
              0.3679518676107426, 0.4931231467509946, 0.9446665455304635], 
             UndirectedEdge[122, 232] -> 
             RGBColor[
              0.8091446434633787, 0.8477841192514302, 0.781190448595753], 
             UndirectedEdge[127, 136] -> 
             RGBColor[
              0.9128398822496258, 0.6200724026716804, 0.3242188545792082], 
             UndirectedEdge[41, 290] -> 
             RGBColor[
              0.4849597446468357, 0.5901356836497829, 0.9533196272793637], 
             UndirectedEdge[123, 259] -> 
             RGBColor[
              0.4502407471664895, 0.5641005142419657, 0.9499920164228051], 
             UndirectedEdge[20, 185] -> 
             RGBColor[
              0.7169880778773853, 0.7780689639663625, 0.973105894503761], 
             UndirectedEdge[163, 211] -> 
             RGBColor[
              0.2418593140070983, 0.3715398521606279, 0.9370849021826888], 
             UndirectedEdge[33, 37] -> 
             RGBColor[
              0.7976827143280194, 0.8426403184805812, 0.9802661418189477], 
             UndirectedEdge[7, 9] -> 
             RGBColor[
              0.45578820295562306`, 0.5674780753124783, 0.9507398809647807], 
             UndirectedEdge[105, 263] -> 
             RGBColor[
              0.2750769487244079, 0.40645369236820506`, 0.9389765973387527], 
             UndirectedEdge[15, 49] -> 
             RGBColor[
              0.2377386487348052, 0.36720877169417954`, 0.9368502363914097], 
             UndirectedEdge[20, 237] -> 
             RGBColor[
              0.752342583517374, 0.8067713443472341, 0.9758891306955624], 
             UndirectedEdge[26, 220] -> 
             RGBColor[
              0.6215133643769486, 0.6880328107560196, 0.9111862353388274], 
             UndirectedEdge[101, 187] -> 
             RGBColor[
              0.4552598760386822, 0.566212394980653, 0.9509294886200896], 
             UndirectedEdge[93, 94] -> 
             RGBColor[
              0.6965792865266065, 0.7615288190518337, 0.9714662855765266], 
             UndirectedEdge[143, 297] -> 
             RGBColor[
              0.5785745379743751, 0.6654077250363819, 0.9616273334928914], 
             UndirectedEdge[208, 268] -> 
             RGBColor[
              0.274238057450941, 0.4055719644510125, 0.9389288237217572], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.9540665099241967, 0.9616166407194549, 0.7611949655148192], 
             UndirectedEdge[224, 288] -> 
             RGBColor[
              0.9157129138329121, 0.6873344410170366, 0.27129446960632875`], 
             UndirectedEdge[1, 75] -> 
             RGBColor[
              0.5745175309470449, 0.663163066561993, 0.9608315894360424], 
             UndirectedEdge[36, 113] -> 
             RGBColor[
              0.8594902789211216, 0.8906751050000117, 0.9651321449597499], 
             UndirectedEdge[29, 244] -> 
             RGBColor[
              0.24266708121897157`, 0.3723888667157059, 0.9371309033304205], 
             UndirectedEdge[36, 96] -> 
             RGBColor[
              0.5825185901002536, 0.6688590205760554, 0.9618637653966613], 
             UndirectedEdge[58, 138] -> 
             RGBColor[
              0.6278035428683023, 0.7077328487058376, 0.9645158476926661], 
             UndirectedEdge[71, 136] -> 
             RGBColor[
              0.8112521109064372, 0.8487062087696886, 0.716702550774494], 
             UndirectedEdge[144, 252] -> 
             RGBColor[
              0.3081203950955903, 0.44054062730759674`, 0.940881946213421], 
             UndirectedEdge[58, 198] -> 
             RGBColor[
              0.506589269540044, 0.610311016455952, 0.9542997094772824], 
             UndirectedEdge[110, 154] -> 
             RGBColor[
              0.8670730299822498, 0.8945506998960768, 0.8707032533386501], 
             UndirectedEdge[119, 152] -> 
             RGBColor[
              0.2677604183233837, 0.39876355502190786`, 0.9385599317562512], 
             UndirectedEdge[38, 90] -> 
             RGBColor[
              0.41074538251891396`, 0.5301887384998543, 0.9473933104595927], 
             UndirectedEdge[66, 179] -> 
             RGBColor[
              0.9700512243327243, 0.9756140843487318, 0.8652383260610674], 
             UndirectedEdge[6, 21] -> 
             RGBColor[
              0.3445638718863475, 0.47258152580409235`, 0.9431866859501019], 
             UndirectedEdge[176, 287] -> 
             RGBColor[
              0.5599634445497977, 0.5545563829440247, 0.6024338644222329], 
             UndirectedEdge[142, 237] -> 
             RGBColor[
              0.6489015303358828, 0.7255912381548726, 0.9656775901367828], 
             UndirectedEdge[108, 221] -> 
             RGBColor[
              0.3192668900954462, 0.449648007121744, 0.9416122250035031], 
             UndirectedEdge[44, 256] -> 
             RGBColor[
              0.9801516197044022, 0.9430147833008583, 0.5214481671592728], 
             UndirectedEdge[89, 112] -> 
             RGBColor[
              0.26517294299919314`, 0.39604395440077267`, 0.9384125788643654],
              UndirectedEdge[83, 184] -> 
             RGBColor[
              0.22686279734830417`, 0.3557775623181615, 0.9362308727443287], 
             UndirectedEdge[259, 261] -> 
             RGBColor[
              0.4324511169680622, 0.5486920306968999, 0.9488584769173136], 
             UndirectedEdge[207, 231] -> 
             RGBColor[
              0.5953538117647618, 0.6805701172311853, 0.962430259270135], 
             UndirectedEdge[112, 280] -> 
             RGBColor[
              0.2601358942740522, 0.3907496968233146, 0.9381257263911142], 
             UndirectedEdge[174, 194] -> 
             RGBColor[
              0.45407833864122044`, 0.5660241331600927, 0.9506234541652072], 
             UndirectedEdge[125, 200] -> 
             RGBColor[
              0.9393105629674767, 0.7809252028803274, 0.3326287940678124], 
             UndirectedEdge[99, 222] -> 
             RGBColor[
              0.4018105363813725, 0.5224498238539401, 0.9468239899644828], 
             UndirectedEdge[108, 169] -> 
             RGBColor[
              0.3184727377256654, 0.44881330262893604`, 0.9415669992008873], 
             UndirectedEdge[15, 57] -> 
             RGBColor[
              0.2429878777602664, 0.3727260442202823, 0.9371491722188713], 
             UndirectedEdge[4, 78] -> 
             RGBColor[
              0.3598305300482983, 0.47184581112708096`, 0.9452322348805061], 
             UndirectedEdge[52, 86] -> 
             RGBColor[
              0.8962878067304835, 0.5320009026523702, 0.26072815279041595`], 
             UndirectedEdge[20, 282] -> 
             RGBColor[
              0.9147814478549319, 0.9341649508472791, 0.9667376994595409], 
             UndirectedEdge[42, 55] -> 
             RGBColor[
              0.2655663224814774, 0.39645742117835314`, 0.9384349812439285], 
             UndirectedEdge[136, 165] -> 
             RGBColor[
              0.9865840174672071, 0.9661571328498515, 0.42361874182822423`], 
             UndirectedEdge[161, 269] -> 
             RGBColor[
              0.22164816720784125`, 0.350296655413888, 0.9359339072721834], 
             UndirectedEdge[57, 243] -> 
             RGBColor[
              0.23260979600231052`, 0.3618180222842825, 0.9365581558157519], 
             UndirectedEdge[57, 146] -> 
             RGBColor[
              0.23875177461672836`, 0.3682736312319718, 0.9369079324115999], 
             UndirectedEdge[4, 130] -> 
             RGBColor[
              0.3592738699625091, 0.4712607260826286, 0.9452005339121252], 
             UndirectedEdge[31, 58] -> 
             RGBColor[
              0.583879953556761, 0.6730590756463584, 0.9603843152481828], 
             UndirectedEdge[95, 140] -> 
             RGBColor[
              0.4083602605702821, 0.527163613934152, 0.9475063767322723], 
             UndirectedEdge[58, 96] -> 
             RGBColor[
              0.47719454661287236`, 0.585147759754026, 0.9523446486820593], 
             UndirectedEdge[16, 94] -> 
             RGBColor[
              0.9277097420952534, 0.9406004694880592, 0.7586810334703302], 
             UndirectedEdge[113, 135] -> 
             RGBColor[
              0.9747525126984742, 0.9797102206225822, 0.8836982332246824], 
             UndirectedEdge[47, 262] -> 
             RGBColor[
              0.8190197652374052, 0.8556976322352333, 0.77563363654671], 
             UndirectedEdge[153, 211] -> 
             RGBColor[
              0.25792046228139853`, 0.38842113733253425`, 0.9379995608165705],
              UndirectedEdge[89, 111] -> 
             RGBColor[
              0.26057341862775985`, 0.3912095626597075, 0.9381506427557986], 
             UndirectedEdge[137, 256] -> 
             RGBColor[
              0.9204070908250823, 0.671745815737615, 0.457708580717874], 
             UndirectedEdge[136, 181] -> 
             RGBColor[
              0.8533623737727853, 0.8817985705963918, 0.7207660407906598], 
             UndirectedEdge[288, 291] -> 
             RGBColor[
              0.839904564048634, 0.3022307284450855, 0.18563064187816736`], 
             UndirectedEdge[121, 296] -> 
             RGBColor[
              0.8454228514141477, 0.8767518585640715, 0.8125406426515358], 
             UndirectedEdge[241, 277] -> 
             RGBColor[
              0.3140852328677468, 0.44372332658360614`, 0.9413346549652732], 
             UndirectedEdge[217, 262] -> 
             RGBColor[
              0.9005077184585596, 0.9193566406229818, 0.783755594175576], 
             UndirectedEdge[75, 142] -> 
             RGBColor[
              0.6947680744610263, 0.7614773672926725, 0.9702116467516284], 
             UndirectedEdge[57, 112] -> 
             RGBColor[
              0.24963320232510341`, 0.37971070167583876`, 0.9375276136219621],
              UndirectedEdge[274, 287] -> 
             RGBColor[
              0.9527752319881305, 0.8479297220628771, 0.29412403319976], 
             UndirectedEdge[97, 252] -> 
             RGBColor[
              0.2790058648824081, 0.41058323235793537`, 0.9392003433016403], 
             UndirectedEdge[18, 69] -> 
             RGBColor[
              0.9697193647682323, 0.9735318279786378, 0.7296111092370301], 
             UndirectedEdge[106, 167] -> 
             RGBColor[
              0.7052976145619072, 0.7697031240469493, 0.9712611329047376], 
             UndirectedEdge[256, 296] -> 
             RGBColor[
              0.8457417773194627, 0.8774340088271846, 0.8472537592625196], 
             UndirectedEdge[131, 183] -> 
             RGBColor[
              0.2897103519915022, 0.4203471391973532, 0.9398644012377442], 
             UndirectedEdge[172, 183] -> 
             RGBColor[
              0.2620424461666492, 0.39275360374480583`, 0.9382343017009069], 
             UndirectedEdge[1, 143] -> 
             RGBColor[
              0.4076363549020162, 0.5274958550423691, 0.9471952059690492], 
             UndirectedEdge[17, 252] -> 
             RGBColor[
              0.29837684649391727`, 0.43094336222280266`, 0.9403034920476165],
              UndirectedEdge[126, 214] -> 
             RGBColor[
              0.21941035515512047`, 0.34794457306099935`, 0.9358064671863272],
              UndirectedEdge[84, 134] -> 
             RGBColor[
              0.2873093787457973, 0.41931075190154404`, 0.9396732161322123], 
             UndirectedEdge[45, 234] -> 
             RGBColor[
              0.837571395698585, 0.28979578799570727`, 0.18361171699277434`], 
             UndirectedEdge[32, 156] -> 
             RGBColor[
              0.24197823755521267`, 0.3716648483498845, 0.9370916747028223], 
             UndirectedEdge[140, 149] -> 
             RGBColor[
              0.3110114912745308, 0.4424361680704541, 0.9410884474530516], 
             UndirectedEdge[16, 150] -> 
             RGBColor[
              0.9777383321225639, 0.9798135163001478, 0.7399324978339024], 
             UndirectedEdge[209, 218] -> 
             RGBColor[
              0.2605995221174108, 0.3912369990823875, 0.9381521293109176], 
             UndirectedEdge[82, 281] -> 
             RGBColor[
              0.9155765352150156, 0.6350911938349629, 0.44384240827575683`], 
             UndirectedEdge[178, 182] -> 
             RGBColor[
              0.29211972893207316`, 0.4243667349411374, 0.9399471584590454], 
             UndirectedEdge[41, 157] -> 
             RGBColor[
              0.35148560431038395`, 0.4788608970986815, 0.9436173297935095], 
             UndirectedEdge[254, 288] -> 
             RGBColor[
              0.8766115127845734, 0.5326035223156528, 0.21875396054991414`], 
             UndirectedEdge[129, 161] -> 
             RGBColor[
              0.22609023535273692`, 0.35496555067756064`, 0.9361868764815843],
              UndirectedEdge[20, 283] -> 
             RGBColor[
              0.7423144926570131, 0.7986300884264481, 0.9750996826489275], 
             UndirectedEdge[162, 210] -> 
             RGBColor[
              0.33154191612091594`, 0.45934744108992703`, 0.9424285250056568],
              UndirectedEdge[203, 244] -> 
             RGBColor[
              0.2510525753068279, 0.38120255267307596`, 0.9376084448134971], 
             UndirectedEdge[121, 246] -> 
             RGBColor[
              0.796739020185918, 0.8380534516751759, 0.8081437970002479], 
             UndirectedEdge[24, 259] -> 
             RGBColor[
              0.7099488174717532, 0.7711907329676471, 0.9554734955620947], 
             UndirectedEdge[141, 281] -> 
             RGBColor[
              0.8675394206203003, 0.45629003917594413`, 0.20980880344155672`],
              UndirectedEdge[110, 138] -> 
             RGBColor[
              0.8498149400101593, 0.8810685488435381, 0.8689831282162525], 
             UndirectedEdge[67, 109] -> 
             RGBColor[
              0.916743494821664, 0.9364503947042759, 0.9919210069943111], 
             UndirectedEdge[154, 245] -> 
             RGBColor[
              0.5828013526273942, 0.6698841791824666, 0.9615515465694076], 
             UndirectedEdge[193, 249] -> 
             RGBColor[
              0.609038860752824, 0.33213297985445467`, 0.5560510629020323], 
             UndirectedEdge[82, 137] -> 
             RGBColor[
              0.9203214410888617, 0.6715626196123557, 0.4483861354991565], 
             UndirectedEdge[100, 125] -> 
             RGBColor[
              0.9214027485620356, 0.686673945842382, 0.31717953132296794`], 
             UndirectedEdge[104, 218] -> 
             RGBColor[
              0.2705572837668725, 0.40170323793452584`, 0.9387192091056663], 
             UndirectedEdge[73, 149] -> 
             RGBColor[
              0.3114795465639533, 0.4428415740370091, 0.9411182715222086], 
             UndirectedEdge[108, 219] -> 
             RGBColor[
              0.30907770812291846`, 0.4389385308371674, 0.9410319661637115], 
             UndirectedEdge[58, 140] -> 
             RGBColor[
              0.4384985979215843, 0.5516312739125644, 0.9498789770489342], 
             UndirectedEdge[9, 63] -> 
             RGBColor[
              0.42067147200560917`, 0.537061727981794, 0.9485022739211517], 
             UndirectedEdge[48, 217] -> 
             RGBColor[
              0.6103593020998471, 0.6909573809034649, 0.9644909605952465], 
             UndirectedEdge[8, 271] -> 
             RGBColor[
              0.814657116181253, 0.8317974978685563, 0.6664449508576125], 
             UndirectedEdge[18, 222] -> 
             RGBColor[
              0.6912666998914337, 0.7558621322945974, 0.9623123726675136], 
             UndirectedEdge[215, 234] -> 
             RGBColor[
              0.9062111144378386, 0.5631850367729421, 0.44751685008743375`], 
             UndirectedEdge[15, 146] -> 
             RGBColor[
              0.2346866767510397, 0.3640009556330419, 0.9366764311019222], 
             UndirectedEdge[54, 151] -> 
             RGBColor[
              0.4303399784091667, 0.5471605926069658, 0.9486418607828988], 
             UndirectedEdge[195, 255] -> 
             RGBColor[
              0.8890490471039758, 0.5106791834270117, 0.23050558405009586`], 
             UndirectedEdge[1, 11] -> 
             RGBColor[
              0.3810142316306978, 0.5044371099315746, 0.9454988678152201], 
             UndirectedEdge[32, 178] -> 
             RGBColor[
              0.2666569110282901, 0.3976036988883609, 0.9384970886482884], 
             UndirectedEdge[126, 189] -> 
             RGBColor[
              0.22889351140479614`, 0.3579119715462422, 0.9363465189056738], 
             UndirectedEdge[61, 273] -> 
             RGBColor[
              0.5923372400801741, 0.6799250818424811, 0.9610501038233672], 
             UndirectedEdge[54, 194] -> 
             RGBColor[
              0.4666198015964266, 0.5768869180196359, 0.9514225850947327], 
             UndirectedEdge[38, 144] -> 
             RGBColor[
              0.36682689322971884`, 0.49214875048500833`, 0.9445948631576804],
              UndirectedEdge[4, 220] -> 
             RGBColor[
              0.3984062395141392, 0.5123913276169251, 0.9474290644669376], 
             UndirectedEdge[45, 200] -> 
             RGBColor[
              0.8719098756675858, 0.5103403405187334, 0.21479500363706636`], 
             UndirectedEdge[2, 202] -> 
             RGBColor[
              0.22943917498765481`, 0.3584854985688961, 0.9363775936394806], 
             UndirectedEdge[17, 175] -> 
             RGBColor[
              0.29536678813966943`, 0.42777960004376564`, 0.9401320736773244],
              UndirectedEdge[233, 262] -> 
             RGBColor[
              0.9940341182393746, 0.9896479070942221, 0.5920287713894679], 
             UndirectedEdge[67, 138] -> 
             RGBColor[
              0.8095011172691953, 0.8518539963630647, 0.9814491180759526], 
             UndirectedEdge[39, 192] -> 
             RGBColor[
              0.8662594246203876, 0.48559710775370324`, 0.21011592443281657`],
              UndirectedEdge[164, 168] -> 
             RGBColor[
              0.38489864849528777`, 0.5078015965832141, 0.9457463794229767], 
             UndirectedEdge[19, 253] -> 
             RGBColor[
              0.2939962623956044, 0.42633909059040226`, 0.940054024263711], 
             UndirectedEdge[24, 74] -> 
             RGBColor[
              0.7969254295463191, 0.8418022649015016, 0.9623206130704325], 
             UndirectedEdge[80, 133] -> 
             RGBColor[
              0.30898841648274356`, 0.43826898504779055`, 0.941047960136832], 
             UndirectedEdge[198, 222] -> 
             RGBColor[
              0.4501940180001994, 0.5640601889318158, 0.9499889976724383], 
             UndirectedEdge[111, 212] -> 
             RGBColor[
              0.2273675902370908, 0.3563081316499939, 0.936259619952571], 
             UndirectedEdge[126, 184] -> 
             RGBColor[
              0.23168784072436213`, 0.3608489888318178, 0.9365056518265833], 
             UndirectedEdge[132, 294] -> 
             RGBColor[
              0.2083047996307834, 0.33627193007203204`, 0.9351740222284133], 
             UndirectedEdge[39, 136] -> 
             RGBColor[
              0.9302201907265502, 0.7393086773088677, 0.34030009728209454`], 
             UndirectedEdge[133, 162] -> 
             RGBColor[
              0.31733689752319516`, 0.44704376794557543`, 0.9415233937816148],
              UndirectedEdge[22, 271] -> 
             RGBColor[
              0.8974219616748091, 0.8964540242042457, 0.6746941771749546], 
             UndirectedEdge[107, 110] -> 
             RGBColor[
              0.9135464991631714, 0.6274127712548101, 0.4734497418593211], 
             UndirectedEdge[40, 191] -> 
             RGBColor[
              0.24055073236956107`, 0.37016444989070835`, 0.9370103803943042],
              UndirectedEdge[143, 237] -> 
             RGBColor[
              0.5177646791690618, 0.6178477648970354, 0.9556038669239417], 
             UndirectedEdge[157, 261] -> 
             RGBColor[
              0.3733109108199431, 0.49776488062546065`, 0.9450080190249379], 
             UndirectedEdge[35, 163] -> 
             RGBColor[
              0.23379526623113445`, 0.36306402665793014`, 0.9366256665915373],
              UndirectedEdge[89, 175] -> 
             RGBColor[
              0.28632181999450856`, 0.4182727650390983, 0.9396169761222888], 
             UndirectedEdge[16, 200] -> 
             RGBColor[
              0.939733161025506, 0.7818290973952341, 0.3786259847113931], 
             UndirectedEdge[35, 189] -> 
             RGBColor[
              0.2290398133604396, 0.3580657441777033, 0.9363548505856133], 
             UndirectedEdge[233, 291] -> 
             RGBColor[
              0.9059982564699387, 0.5642093204609733, 0.381364914596678], 
             UndirectedEdge[258, 290] -> 
             RGBColor[
              0.7873478763723856, 0.8338243344390612, 0.9561368785302078], 
             UndirectedEdge[157, 259] -> 
             RGBColor[
              0.40512064339431064`, 0.5250197481568593, 0.947117003308583], 
             UndirectedEdge[105, 245] -> 
             RGBColor[
              0.35678647711021616`, 0.4816423424493619, 0.944021366181159], 
             UndirectedEdge[100, 192] -> 
             RGBColor[
              0.857583234347318, 0.43326449980026105`, 0.20236975515183697`], 
             UndirectedEdge[258, 278] -> 
             RGBColor[
              0.7823492729369855, 0.8297662429856849, 0.9557433701572854], 
             UndirectedEdge[99, 201] -> 
             RGBColor[
              0.34430071595550393`, 0.4726377079286733, 0.9431595150608838], 
             UndirectedEdge[9, 282] -> 
             RGBColor[
              0.740243347265956, 0.7955203413934655, 0.9507546007091144], 
             UndirectedEdge[84, 175] -> 
             RGBColor[
              0.29756458350130965`, 0.4300896223171238, 0.940257234871823], 
             UndirectedEdge[271, 291] -> 
             RGBColor[
              0.897686479772025, 0.537150265190796, 0.2658690194898667], 
             UndirectedEdge[127, 256] -> 
             RGBColor[
              0.9140100349325547, 0.622575240939881, 0.4515827527707482], 
             UndirectedEdge[80, 116] -> 
             RGBColor[
              0.2951188116057152, 0.426255830409919, 0.9401642011784779], 
             UndirectedEdge[202, 268] -> 
             RGBColor[
              0.2453187041670522, 0.37517589055674394`, 0.937281909334589], 
             UndirectedEdge[161, 265] -> 
             RGBColor[
              0.21936843133233605`, 0.34790050846512904`, 0.9358040796866404],
              UndirectedEdge[22, 72] -> 
             RGBColor[
              0.7345932590636062, 0.7925891041868212, 0.9741810489653038], 
             UndirectedEdge[77, 162] -> 
             RGBColor[
              0.26527957680517633`, 0.3961560332918348, 0.9384186515018654], 
             UndirectedEdge[93, 164] -> 
             RGBColor[
              0.45756686024315646`, 0.5686282136761757, 0.9509610966011381], 
             UndirectedEdge[19, 111] -> 
             RGBColor[
              0.2671407671011217, 0.39811226229915386`, 0.9385246435358352], 
             UndirectedEdge[37, 142] -> 
             RGBColor[
              0.669863260251737, 0.742021537148777, 0.9677293676199676], 
             UndirectedEdge[43, 172] -> 
             RGBColor[
              0.2958345713391305, 0.4270297833847875, 0.9402041701394114], 
             UndirectedEdge[61, 285] -> 
             RGBColor[
              0.474805368949063, 0.5825919070766665, 0.9523268246944521], 
             UndirectedEdge[38, 257] -> 
             RGBColor[
              0.4046248085689348, 0.5248874049733736, 0.9470033128997111], 
             UndirectedEdge[174, 185] -> 
             RGBColor[
              0.4801968939468863, 0.58722835298474, 0.9526796025142897], 
             UndirectedEdge[75, 237] -> 
             RGBColor[
              0.6846458552140906, 0.7535149764166593, 0.969240250390935], 
             UndirectedEdge[30, 48] -> 
             RGBColor[
              0.43794065467516774`, 0.5535027925607373, 0.9491927923797858], 
             UndirectedEdge[289, 298] -> 
             RGBColor[
              0.28811767425307283`, 0.4201603217285858, 0.9397192473655857], 
             UndirectedEdge[123, 261] -> 
             RGBColor[
              0.41843101459212195`, 0.5368456467105671, 0.9478830321391599], 
             UndirectedEdge[77, 206] -> 
             RGBColor[
              0.2413530899135048, 0.3710077785417997, 0.9370560734694501], 
             UndirectedEdge[121, 137] -> 
             RGBColor[
              0.9200881649197675, 0.6710636654745018, 0.4229954641068904], 
             UndirectedEdge[87, 227] -> 
             RGBColor[
              0.2679362427515092, 0.39894835764378045`, 0.938569944697324], 
             UndirectedEdge[123, 144] -> 
             RGBColor[
              0.3759650676291757, 0.5000637778518178, 0.9451771395498434], 
             UndirectedEdge[9, 37] -> 
             RGBColor[
              0.5987662128442524, 0.684557033887325, 0.9619578094283205], 
             UndirectedEdge[178, 268] -> 
             RGBColor[
              0.26978635473276824`, 0.4008929426399584, 0.9386753058376613], 
             UndirectedEdge[112, 253] -> 
             RGBColor[
              0.2744693999473012, 0.40581512008264853`, 0.9389419983346845], 
             UndirectedEdge[78, 220] -> 
             RGBColor[
              0.21861602963741927`, 0.34710968657874874`, 0.9357612315231933],
              UndirectedEdge[66, 67] -> 
             RGBColor[
              0.9293871027463778, 0.9462546742934231, 0.9835096743331035], 
             UndirectedEdge[20, 124] -> 
             RGBColor[
              0.9067998303302157, 0.928212273566045, 0.9802484959896351], 
             UndirectedEdge[18, 224] -> 
             RGBColor[
              0.9579627169351427, 0.9342040847269458, 0.6558617372883351], 
             UndirectedEdge[72, 151] -> 
             RGBColor[
              0.5475405416357872, 0.6431396338261914, 0.9576978591404627], 
             UndirectedEdge[25, 29] -> 
             RGBColor[
              0.24731665325336327`, 0.3772758617237455, 0.9373956895793536], 
             UndirectedEdge[135, 258] -> 
             RGBColor[
              0.9759313858945792, 0.9805894223220096, 0.8817027084030489], 
             UndirectedEdge[130, 176] -> 
             RGBColor[
              0.17893943915932659`, 0.3054070743451405, 0.9335017083917216], 
             UndirectedEdge[31, 245] -> 
             RGBColor[
              0.5216196733437626, 0.6217282550704486, 0.9556998890025264], 
             UndirectedEdge[295, 297] -> 
             RGBColor[
              0.7988419039700752, 0.8429204696534232, 0.9805476453412715], 
             UndirectedEdge[17, 30] -> 
             RGBColor[
              0.37921039896007874`, 0.5014757039177918, 0.9454929485539587], 
             UndirectedEdge[22, 273] -> 
             RGBColor[
              0.717607033402136, 0.7789436605631201, 0.9727448718111256], 
             UndirectedEdge[86, 165] -> 
             RGBColor[
              0.9775639799613888, 0.9359801775610526, 0.3673407281472113], 
             UndirectedEdge[124, 200] -> 
             RGBColor[
              0.916844882326316, 0.7678634053812667, 0.6000047488264095], 
             UndirectedEdge[198, 258] -> 
             RGBColor[
              0.7130111957358749, 0.7734744682690422, 0.9502848227262681], 
             UndirectedEdge[177, 217] -> 
             RGBColor[
              0.6131216671850642, 0.6933500026997739, 0.964666976055813], 
             UndirectedEdge[52, 110] -> 
             RGBColor[
              0.9053269977052454, 0.5642340812406845, 0.4655787379806119], 
             UndirectedEdge[121, 299] -> 
             RGBColor[
              0.9945473356554072, 0.9914335784226265, 0.6978961075730188], 
             UndirectedEdge[173, 196] -> 
             RGBColor[
              0.2690530219671379, 0.40012216340729806`, 0.9386335436215274], 
             UndirectedEdge[238, 251] -> 
             RGBColor[
              0.2826141781107905, 0.4143757983412377, 0.9394058314019756], 
             UndirectedEdge[218, 284] -> 
             RGBColor[
              0.25584347148447395`, 0.38623808831614403`, 0.9378812792633183],
              UndirectedEdge[209, 276] -> 
             RGBColor[
              0.24846893317691396`, 0.37848698098216405`, 0.9374613102163545],
              UndirectedEdge[8, 72] -> 
             RGBColor[
              0.6518284135700501, 0.7279325778511317, 0.9659318226479615], 
             UndirectedEdge[56, 168] -> 
             RGBColor[
              0.46678271330407606`, 0.5761629717082618, 0.9516719821972282], 
             UndirectedEdge[201, 257] -> 
             RGBColor[
              0.35620917982441114`, 0.48295222079512334`, 0.9439183118483695],
              UndirectedEdge[31, 51] -> 
             RGBColor[
              0.8061994237416004, 0.8465221719044482, 0.8597460281820752], 
             UndirectedEdge[53, 282] -> 
             RGBColor[
              0.89769307964249, 0.6086527767356787, 0.5622102390155896], 
             UndirectedEdge[17, 97] -> 
             RGBColor[
              0.27685141165294697`, 0.4083187654135474, 0.9390776503774505], 
             UndirectedEdge[102, 162] -> 
             RGBColor[
              0.3349247683998675, 0.4622774977068556, 0.9426440773615328], 
             UndirectedEdge[36, 260] -> 
             RGBColor[
              0.8043625245684116, 0.8473291531354724, 0.9810724316171817], 
             UndirectedEdge[79, 168] -> 
             RGBColor[
              0.3904018999447999, 0.5125682363873212, 0.9460970417390054], 
             UndirectedEdge[142, 297] -> 
             RGBColor[
              0.7097113891411961, 0.773151198294219, 0.9717010567057325], 
             UndirectedEdge[232, 299] -> 
             RGBColor[
              0.994290544063115, 0.9908843271723261, 0.6699459274860231], 
             UndirectedEdge[50, 169] -> 
             RGBColor[
              0.3227370521664461, 0.4525068374668645, 0.9418387175462686], 
             UndirectedEdge[92, 153] -> 
             RGBColor[
              0.26728945052082176`, 0.3982685380003319, 0.9385331108366297], 
             UndirectedEdge[44, 299] -> 
             RGBColor[
              0.979769906119425, 0.942886287709507, 0.5299077867568601], 
             UndirectedEdge[90, 252] -> 
             RGBColor[
              0.35203888438478537`, 0.4785806153224426, 0.9436803935153333], 
             UndirectedEdge[7, 283] -> 
             RGBColor[
              0.5067349402558111, 0.6088389317771312, 0.9547505947490993], 
             UndirectedEdge[52, 179] -> 
             RGBColor[
              0.9056772965506277, 0.5643789388155198, 0.459773379568276], 
             UndirectedEdge[98, 296] -> 
             RGBColor[
              0.559521387516622, 0.6516299340358314, 0.9592598962290395], 
             UndirectedEdge[18, 88] -> 
             RGBColor[
              0.7253109400374347, 0.7839674018676228, 0.9648635309809819], 
             UndirectedEdge[100, 240] -> 
             RGBColor[
              0.9225569449368545, 0.6891426551809652, 0.4428066838476417], 
             UndirectedEdge[2, 214] -> 
             RGBColor[
              0.2218197182328839, 0.35047696641817105`, 0.9359436768492726], 
             UndirectedEdge[114, 169] -> 
             RGBColor[
              0.2987181224804576, 0.4313020649228039, 0.9403229272101774], 
             UndirectedEdge[37, 295] -> 
             RGBColor[
              0.7589937750806162, 0.8117908085079812, 0.9765759562555065], 
             UndirectedEdge[45, 225] -> 
             RGBColor[
              0.9093933228339569, 0.6627226292341221, 0.2529269618420678], 
             UndirectedEdge[38, 74] -> 
             RGBColor[
              0.5280791848415985, 0.6267970188090106, 0.9562568575389798], 
             UndirectedEdge[38, 158] -> 
             RGBColor[
              0.41078817614673724`, 0.5302258041894045, 0.9473960372317167], 
             UndirectedEdge[69, 135] -> 
             RGBColor[
              0.9915668730357023, 0.9888448386688236, 0.6487056199187353], 
             UndirectedEdge[113, 224] -> 
             RGBColor[
              0.9644670009376046, 0.9390549690861945, 0.644851681061125], 
             UndirectedEdge[124, 282] -> 
             RGBColor[
              0.9556754222393467, 0.9664633829977154, 0.9599141278341408], 
             UndirectedEdge[56, 79] -> 
             RGBColor[
              0.47131158576889715`, 0.5800856534095411, 0.9519605579459619], 
             UndirectedEdge[49, 146] -> 
             RGBColor[
              0.23350254559126715`, 0.3627563587058691, 0.9366089965841382], 
             UndirectedEdge[47, 166] -> 
             RGBColor[
              0.8183915236203407, 0.8543538869413033, 0.7072534135870767], 
             UndirectedEdge[189, 197] -> 
             RGBColor[
              0.22117434471858483`, 0.3497986379355985, 0.9359069237823778], 
             UndirectedEdge[125, 256] -> 
             RGBColor[
              0.9939365705713255, 0.9894392624958468, 0.5814113097167279], 
             UndirectedEdge[69, 138] -> 
             RGBColor[
              0.8498609562052564, 0.8791517168657417, 0.7275038724573385], 
             UndirectedEdge[170, 255] -> 
             RGBColor[
              0.8904238882805281, 0.5212468151692371, 0.2318221335134233], 
             UndirectedEdge[41, 104] -> 
             RGBColor[
              0.3210313076505878, 0.45029407852530423`, 0.9417569530026035], 
             UndirectedEdge[185, 283] -> 
             RGBColor[
              0.5933967145885973, 0.6807852109772019, 0.9611335095376532], 
             UndirectedEdge[103, 277] -> 
             RGBColor[
              0.3139559658390563, 0.44358745874044936`, 0.9413272933992227], 
             UndirectedEdge[45, 282] -> 
             RGBColor[
              0.9107404155806164, 0.7089403181351821, 0.5747043826447977], 
             UndirectedEdge[222, 245] -> 
             RGBColor[
              0.43026765068117134`, 0.5470979459642735, 0.9486372521240278], 
             UndirectedEdge[53, 195] -> 
             RGBColor[
              0.825436438508141, 0.1965211894578074, 0.17199126828273137`], 
             UndirectedEdge[121, 136] -> 
             RGBColor[
              0.9937588965574554, 0.9890592357457773, 0.5620725897838914], 
             UndirectedEdge[92, 211] -> 
             RGBColor[
              0.2517282610763278, 0.3819127412577725, 0.9376469241184826], 
             UndirectedEdge[26, 137] -> 
             RGBColor[
              0.9157005980775512, 0.6698289128207927, 0.5378409832086813], 
             UndirectedEdge[139, 148] -> 
             RGBColor[
              0.24714609636833407`, 0.37709659562364867`, 0.9373859766170676],
              UndirectedEdge[69, 258] -> 
             RGBColor[
              0.9774025219667993, 0.9792619140373138, 0.7166055281881865], 
             UndirectedEdge[244, 272] -> 
             RGBColor[
              0.23289575947638014`, 0.3621185880266611, 0.936574441012555], 
             UndirectedEdge[100, 256] -> 
             RGBColor[
              0.9227141531364094, 0.6894789076236262, 0.45991782619265503`], 
             UndirectedEdge[29, 206] -> 
             RGBColor[
              0.23974836289368467`, 0.3693211086983992, 0.9369646866396522], 
             UndirectedEdge[101, 213] -> 
             RGBColor[
              0.48723449014775655`, 0.5939071986311, 0.9529668827570787], 
             UndirectedEdge[39, 107] -> 
             RGBColor[
              0.8508398666409367, 0.3774266775234726, 0.1957554594288977], 
             UndirectedEdge[134, 252] -> 
             RGBColor[
              0.28726603661361816`, 0.4192651965725739, 0.9396707478619037], 
             UndirectedEdge[14, 288] -> 
             RGBColor[
              0.8422994070509533, 0.32063854118780577`, 0.1879239462417765], 
             UndirectedEdge[155, 202] -> 
             RGBColor[
              0.22021191752572378`, 0.34878706593449305`, 0.9358521149775277],
              UndirectedEdge[220, 228] -> 
             RGBColor[
              0.5367674910110247, 0.6220540079829862, 0.9601435922342896], 
             UndirectedEdge[228, 266] -> 
             RGBColor[
              0.5319885984693589, 0.6170310889224077, 0.9598714413737797], 
             UndirectedEdge[113, 249] -> 
             RGBColor[
              0.8889946281823045, 0.5565337231850392, 0.5595095853153444], 
             UndirectedEdge[109, 179] -> 
             RGBColor[
              0.9574076164080104, 0.9658098047595847, 0.8736496587222751], 
             UndirectedEdge[41, 209] -> 
             RGBColor[
              0.3110735460011261, 0.43982783967316585`, 0.9411898732078549], 
             UndirectedEdge[76, 261] -> 
             RGBColor[
              0.3474685023612617, 0.4740454489620557, 0.9434102824444082], 
             UndirectedEdge[114, 219] -> 
             RGBColor[
              0.28932309287771063`, 0.4214272931310352, 0.9397878941730018], 
             UndirectedEdge[130, 266] -> 
             RGBColor[
              0.21328047700996416`, 0.3415016824737179, 0.9354573796943026], 
             UndirectedEdge[1, 185] -> 
             RGBColor[
              0.4932964811819127, 0.5985745570433215, 0.9535142966293955], 
             UndirectedEdge[202, 208] -> 
             RGBColor[
              0.2570404037299817, 0.3874961399960602, 0.9379494427839974], 
             UndirectedEdge[8, 285] -> 
             RGBColor[
              0.5173103167774687, 0.616953959461616, 0.9557723663648683], 
             UndirectedEdge[65, 210] -> 
             RGBColor[
              0.33323684341077736`, 0.46112891713616844`, 0.9425250486073942],
              UndirectedEdge[63, 183] -> 
             RGBColor[
              0.28955139027076127`, 0.4202094545444958, 0.939854272337463], 
             UndirectedEdge[51, 86] -> 
             RGBColor[
              0.9842148587859489, 0.9592452118717956, 0.5566107984418112], 
             UndirectedEdge[91, 191] -> 
             RGBColor[
              0.2582507185162887, 0.38876825757485856`, 0.9380183684205773], 
             UndirectedEdge[122, 181] -> 
             RGBColor[
              0.6690049122710009, 0.741072705352345, 0.9678340796895172], 
             UndirectedEdge[17, 42] -> 
             RGBColor[
              0.2753301177357401, 0.4067197890509576, 0.9389910149394182], 
             UndirectedEdge[90, 253] -> 
             RGBColor[
              0.3501359199582715, 0.4765804790552632, 0.9435720225064269], 
             UndirectedEdge[60, 136] -> 
             RGBColor[
              0.9594950595498875, 0.8659435606987382, 0.3644021078697419], 
             UndirectedEdge[80, 210] -> 
             RGBColor[
              0.3231934350804644, 0.45057265819214215`, 0.941953091360874], 
             UndirectedEdge[229, 259] -> 
             RGBColor[
              0.40532480006275245`, 0.5251965784018511, 0.9471300119909675], 
             UndirectedEdge[97, 159] -> 
             RGBColor[
              0.2524370830607903, 0.3826577581053522, 0.9376872904818896], 
             UndirectedEdge[242, 280] -> 
             RGBColor[
              0.25424538211649345`, 0.38455839506567835`, 0.9377902704379731],
              UndirectedEdge[88, 99] -> 
             RGBColor[
              0.43585477652737337`, 0.5505550934269655, 0.9493751482779511], 
             UndirectedEdge[21, 46] -> 
             RGBColor[
              0.3377964064979223, 0.4654684905987692, 0.942801288807799], 
             UndirectedEdge[246, 256] -> 
             RGBColor[
              0.7970579460912328, 0.838735601938289, 0.8428569136112316], 
             UndirectedEdge[14, 135] -> 
             RGBColor[
              0.9063967184206538, 0.582821195587901, 0.4915857246054881], 
             UndirectedEdge[67, 179] -> 
             RGBColor[
              0.9529824528221467, 0.9622812994340826, 0.8732275826690652], 
             UndirectedEdge[66, 69] -> 
             RGBColor[
              0.9697469416824389, 0.9735523947961, 0.7295644287144893], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.7503642165832218, 0.805193848255281, 0.9757004322912739], 
             UndirectedEdge[116, 133] -> 
             RGBColor[
              0.3362774461822365, 0.4656883549123332, 0.9426482794056301], 
             UndirectedEdge[2, 83] -> 
             RGBColor[
              0.2235228930753953, 0.35226711116517256`, 0.9360406701369322], 
             UndirectedEdge[103, 168] -> 
             RGBColor[
              0.3323449528082868, 0.45951507499583777`, 0.9424990233881594], 
             UndirectedEdge[26, 199] -> 
             RGBColor[
              0.5823809948253185, 0.6469022092217233, 0.9089577047840149], 
             UndirectedEdge[91, 239] -> 
             RGBColor[
              0.3418733579527955, 0.46719445818593675`, 0.9431271687979139], 
             UndirectedEdge[13, 298] -> 
             RGBColor[
              0.2956902341413986, 0.428119562299244, 0.9401504934486273], 
             UndirectedEdge[229, 261] -> 
             RGBColor[
              0.3735150674883849, 0.49794171087045247`, 0.9450210277073223], 
             UndirectedEdge[141, 179] -> 
             RGBColor[
              0.9463245104461602, 0.8129581160989631, 0.4961968694388046], 
             UndirectedEdge[59, 195] -> 
             RGBColor[
              0.825976956508043, 0.20067584766155147`, 0.17250886892986522`], 
             UndirectedEdge[134, 253] -> 
             RGBColor[
              0.2853630721871043, 0.41726506030539445`, 0.9395623768529974], 
             UndirectedEdge[42, 292] -> 
             RGBColor[
              0.24874967528223313`, 0.3787820587349321, 0.9374772980639317], 
             UndirectedEdge[70, 238] -> 
             RGBColor[
              0.27137415800540265`, 0.40256182455203926`, 0.9387657288850935],
              UndirectedEdge[178, 202] -> 
             RGBColor[
              0.25258870101180897`, 0.3828171181850061, 0.9376959248999015], 
             UndirectedEdge[29, 191] -> 
             RGBColor[
              0.24335597488348387`, 0.37311293763548947`, 0.9371701348054876],
              UndirectedEdge[17, 38] -> 
             RGBColor[
              0.3570833446280458, 0.48255148540021425`, 0.944016408991876], 
             UndirectedEdge[40, 162] -> 
             RGBColor[
              0.2608696072714334, 0.3915208757036531, 0.9381675102608841], 
             UndirectedEdge[13, 95] -> 
             RGBColor[
              0.3973874477451902, 0.5174174988379855, 0.946816060198244], 
             UndirectedEdge[206, 270] -> 
             RGBColor[
              0.23246458235718154`, 0.361665393536175, 0.936549886113486], 
             UndirectedEdge[16, 295] -> 
             RGBColor[
              0.9153775706767935, 0.9307671307468549, 0.7575047799513781], 
             UndirectedEdge[37, 124] -> 
             RGBColor[
              0.8141982878176429, 0.8555000754915749, 0.971117336553347], 
             UndirectedEdge[22, 177] -> 
             RGBColor[
              0.6182933062719121, 0.6973901264603323, 0.9651824367082749], 
             UndirectedEdge[115, 204] -> 
             RGBColor[
              0.22623702836427392`, 0.35511983943990055`, 0.9361952361264305],
              UndirectedEdge[192, 200] -> 
             RGBColor[
              0.875491048752759, 0.5275157568382065, 0.21781901789668148`], 
             UndirectedEdge[13, 171] -> 
             RGBColor[
              0.3622408475068787, 0.48793453204456394`, 0.9443115057758112], 
             UndirectedEdge[39, 52] -> 
             RGBColor[
              0.8426203651830106, 0.3142479875093471, 0.1878844555501885], 
             UndirectedEdge[92, 216] -> 
             RGBColor[
              0.25996759819388404`, 0.3905728069724701, 0.9381161421783205], 
             UndirectedEdge[82, 127] -> 
             RGBColor[
              0.9139243851963341, 0.6223920448146217, 0.4422603075520308], 
             UndirectedEdge[53, 150] -> 
             RGBColor[
              0.8968677108265174, 0.6080372180241437, 0.5636073731303677], 
             UndirectedEdge[18, 66] -> 
             RGBColor[
              0.9464282973427488, 0.95956689239061, 0.9755670982476465], 
             UndirectedEdge[31, 36] -> 
             RGBColor[
              0.6892039970441424, 0.7567703364683878, 0.9699034319627848], 
             UndirectedEdge[71, 181] -> 
             RGBColor[
              0.6717068148993812, 0.7432662316253906, 0.9680467833618187], 
             UndirectedEdge[43, 143] -> 
             RGBColor[
              0.3594618944461463, 0.48576955871427996`, 0.9441255719478039], 
             UndirectedEdge[75, 185] -> 
             RGBColor[
              0.6492913495741017, 0.7248125960357876, 0.9664570141991338], 
             UndirectedEdge[46, 145] -> 
             RGBColor[
              0.280670988716232, 0.4123333830822331, 0.9392951696406466], 
             UndirectedEdge[62, 255] -> 
             RGBColor[
              0.9769015351320889, 0.9322978840038133, 0.4878701995815442], 
             UndirectedEdge[111, 242] -> 
             RGBColor[
              0.24172339249525976`, 0.3713969900337639, 0.9370771616536675], 
             UndirectedEdge[4, 193] -> 
             RGBColor[
              0.46955924674976174`, 0.5787870298978665, 0.9517883446566966], 
             UndirectedEdge[18, 258] -> 
             RGBColor[
              0.9540838776271092, 0.9652764116318238, 0.9626081977213435], 
             UndirectedEdge[81, 267] -> 
             RGBColor[
              0.3818442604921369, 0.5035684061042389, 0.9457044452357559], 
             UndirectedEdge[75, 124] -> 
             RGBColor[
              0.8391031020269322, 0.8749559056354701, 0.9735996156850079], 
             UndirectedEdge[72, 106] -> 
             RGBColor[
              0.6542381545327312, 0.7298150858058879, 0.966172003106812], 
             UndirectedEdge[262, 271] -> 
             RGBColor[
              0.9857223415414609, 0.9625888518240449, 0.4765328762826566], 
             UndirectedEdge[17, 235] -> 
             RGBColor[
              0.2691307812557516, 0.40020389334985473`, 0.9386379718979794], 
             UndirectedEdge[263, 279] -> 
             RGBColor[
              0.25988809011317837`, 0.3904892389385449, 0.938111614310746], 
             UndirectedEdge[3, 252] -> 
             RGBColor[
              0.33892810141516894`, 0.46722471408127325`, 0.9428449860179196],
              UndirectedEdge[48, 158] -> 
             RGBColor[
              0.4086574804982366, 0.5283803027105503, 0.9472602711890945], 
             UndirectedEdge[18, 36] -> 
             RGBColor[
              0.8529859949186596, 0.8858242206407632, 0.9761422011869598], 
             UndirectedEdge[105, 196] -> 
             RGBColor[
              0.28505137622914434`, 0.4169374480909134, 0.9395446262293043], 
             UndirectedEdge[269, 298] -> 
             RGBColor[
              0.2561386884802381, 0.3865483800965307, 0.9378980914344927], 
             UndirectedEdge[85, 207] -> 
             RGBColor[
              0.8326069689699811, 0.8699635257728993, 0.9837364200787462], 
             UndirectedEdge[79, 103] -> 
             RGBColor[
              0.33687382527310783`, 0.4634377566971172, 0.9427875991368931], 
             UndirectedEdge[76, 128] -> 
             RGBColor[
              0.2667781164198233, 0.397731093439728, 0.9385039911160289], 
             UndirectedEdge[10, 265] -> 
             RGBColor[
              0.21694931138635237`, 0.3453578600208368, 0.9356663143844839], 
             UndirectedEdge[88, 198] -> 
             RGBColor[
              0.48423825814620036`, 0.592165458504841, 0.9525401559859066], 
             UndirectedEdge[63, 143] -> 
             RGBColor[
              0.36063166824627285`, 0.4867827579854089, 0.9442001088999576], 
             UndirectedEdge[49, 242] -> 
             RGBColor[
              0.23849346114208345`, 0.3680021273920998, 0.9368932218413593], 
             UndirectedEdge[252, 253] -> 
             RGBColor[
              0.29862833529686444`, 0.43120769290001126`, 0.9403178139629], 
             UndirectedEdge[16, 125] -> 
             RGBColor[
              0.9930477640549809, 0.9875381952295093, 0.4846702054906215], 
             UndirectedEdge[59, 100] -> 
             RGBColor[
              0.8414952433239204, 0.3199562002850287, 0.1873691979101476], 
             UndirectedEdge[75, 295] -> 
             RGBColor[
              0.7838985892899054, 0.8312466386518764, 0.9790582353871675], 
             UndirectedEdge[94, 295] -> 
             RGBColor[
              0.8496169506590368, 0.8829255104904983, 0.9855184172875062], 
             UndirectedEdge[26, 192] -> 
             RGBColor[
              0.9254105636090766, 0.7341129135369036, 0.5467339360364043], 
             UndirectedEdge[132, 188] -> 
             RGBColor[
              0.20621351468350757`, 0.3340738569973212, 0.9350549266444448], 
             UndirectedEdge[186, 196] -> 
             RGBColor[
              0.255450766680841, 0.38582533066860314`, 0.9378589153057062], 
             UndirectedEdge[110, 179] -> 
             RGBColor[
              0.9932962755631108, 0.991495851914556, 0.7607615928093651], 
             UndirectedEdge[61, 177] -> 
             RGBColor[
              0.49302351294995017`, 0.5983715477396933, 0.9534876687205165], 
             UndirectedEdge[21, 264] -> 
             RGBColor[
              0.339057995027486, 0.46679450013267343`, 0.9428731344082046], 
             UndirectedEdge[200, 225] -> 
             RGBColor[
              0.9234794071043728, 0.7275983937614409, 0.2647165314935854], 
             UndirectedEdge[83, 197] -> 
             RGBColor[
              0.21339436331142053`, 0.34162138419735716`, 0.9354638653506908],
              UndirectedEdge[220, 226] -> 
             RGBColor[
              0.21805937466237113`, 0.3465246069060093, 0.9357295308458616], 
             UndirectedEdge[13, 140] -> 
             RGBColor[
              0.3171012005840623, 0.44883683866464263`, 0.941435247389312], 
             UndirectedEdge[144, 158] -> 
             RGBColor[
              0.35967077338482056`, 0.4859504791523989, 0.9441388815290719], 
             UndirectedEdge[62, 225] -> 
             RGBColor[
              0.9779057939111673, 0.9356854846768198, 0.49177155529990685`], 
             UndirectedEdge[65, 277] -> 
             RGBColor[
              0.318505826054183, 0.44836965030434695`, 0.9415864012075592], 
             UndirectedEdge[99, 261] -> 
             RGBColor[
              0.38406488890105717`, 0.5070794359286672, 0.9456932529988971], 
             UndirectedEdge[260, 290] -> 
             RGBColor[
              0.7310412488235707, 0.7895991808750945, 0.9740726900092733], 
             UndirectedEdge[72, 267] -> 
             RGBColor[
              0.5598273932891142, 0.6533873840765647, 0.9585897688439947], 
             UndirectedEdge[39, 170] -> 
             RGBColor[
              0.8447130757608642, 0.3303334780423518, 0.18988843756291957`], 
             UndirectedEdge[92, 163] -> 
             RGBColor[
              0.25122830224652154`, 0.3813872528284255, 0.937618452202748], 
             UndirectedEdge[102, 133] -> 
             RGBColor[
              0.36773492193593726`, 0.4929352393114849, 0.9446527219439024], 
             UndirectedEdge[184, 197] -> 
             RGBColor[
              0.22396867403815082`, 0.3527356552211741, 0.9360660567032872], 
             UndirectedEdge[44, 200] -> 
             RGBColor[
              0.9255256121005535, 0.7345007236853389, 0.2726656515103572], 
             UndirectedEdge[115, 132] -> 
             RGBColor[
              0.21415169536183348`, 0.34241738819996653`, 0.9355069942905895],
              UndirectedEdge[9, 283] -> 
             RGBColor[
              0.5677763920680372, 0.6599854789726345, 0.959116583898501], 
             UndirectedEdge[52, 165] -> 
             RGBColor[
              0.8989841919236675, 0.5410964430503309, 0.2712031000963182], 
             UndirectedEdge[160, 256] -> 
             RGBColor[
              0.7927339846129686, 0.8352252152179895, 0.8425165155244698], 
             UndirectedEdge[45, 215] -> 
             RGBColor[
              0.9264635101364236, 0.7188538247686493, 0.4669105670802081], 
             UndirectedEdge[16, 124] -> 
             RGBColor[
              0.9705820834138202, 0.9744763977304486, 0.7520461602492186], 
             UndirectedEdge[160, 246] -> 
             RGBColor[
              0.5945439555585024, 0.6817165928791875, 0.9612238245492863], 
             UndirectedEdge[57, 204] -> 
             RGBColor[
              0.23896784394150833`, 0.36850073379190207`, 0.9369202372400001],
              UndirectedEdge[112, 252] -> 
             RGBColor[
              0.27637236437381507`, 0.40781525634982796`, 0.9390503693435908],
              UndirectedEdge[5, 248] -> 
             RGBColor[
              0.21465495916745328`, 0.3429463503684412, 0.9355356544198075], 
             UndirectedEdge[186, 276] -> 
             RGBColor[
              0.2308753294209801, 0.3599949879357713, 0.9364593805098584], 
             UndirectedEdge[95, 154] -> 
             RGBColor[
              0.6149232954890904, 0.696747339779964, 0.9638633724984019], 
             UndirectedEdge[198, 290] -> 
             RGBColor[
              0.5385920372825843, 0.6362923050176035, 0.9568190845839761], 
             UndirectedEdge[77, 191] -> 
             RGBColor[
              0.24496070190330402`, 0.37479960747889, 0.9372615216352855], 
             UndirectedEdge[36, 224] -> 
             RGBColor[
              0.8645479914252601, 0.8604819797945611, 0.6563901597051076], 
             UndirectedEdge[29, 203] -> 
             RGBColor[
              0.25120844967144335`, 0.38136638651329235`, 0.9376173216279664],
              UndirectedEdge[25, 172] -> 
             RGBColor[
              0.2606528759791422, 0.3912930773738975, 0.9381551677344133], 
             UndirectedEdge[224, 260] -> 
             RGBColor[
              0.9093392465848947, 0.8957090172216551, 0.6607919677185569], 
             UndirectedEdge[45, 255] -> 
             RGBColor[
              0.9083890640548784, 0.6593350285611156, 0.24902560612370514`], 
             UndirectedEdge[102, 239] -> 
             RGBColor[
              0.398228532934502, 0.519347272504989, 0.9465957478722895], 
             UndirectedEdge[33, 239] -> 
             RGBColor[
              0.6628984653958889, 0.7326583838158534, 0.9695703125580974], 
             UndirectedEdge[64, 92] -> 
             RGBColor[
              0.24737632360791623`, 0.3773385790496996, 0.9373990877177711], 
             UndirectedEdge[32, 268] -> 
             RGBColor[
              0.2593869141835333, 0.38996247126009875`, 0.938083073082976], 
             UndirectedEdge[85, 240] -> 
             RGBColor[
              0.9572796113633043, 0.9651601387742601, 0.8410616153789832], 
             UndirectedEdge[1, 174] -> 
             RGBColor[
              0.4054230753198295, 0.5255788235109453, 0.9470541777511985], 
             UndirectedEdge[2, 184] -> 
             RGBColor[
              0.23409720380212556`, 0.3633813821889895, 0.9366428614895286], 
             UndirectedEdge[60, 85] -> 
             RGBColor[
              0.9228540566499766, 0.8416985659067688, 0.6257891591988634], 
             UndirectedEdge[121, 127] -> 
             RGBColor[
              0.9136911090272399, 0.6218930906767679, 0.41686963615976463`], 
             UndirectedEdge[132, 212] -> 
             RGBColor[
              0.20921642322248857`, 0.3372301042671883, 0.9352259378433346], 
             UndirectedEdge[172, 206] -> 
             RGBColor[
              0.2530845856194636, 0.3833383243485512, 0.9377241647947119], 
             UndirectedEdge[147, 148] -> 
             RGBColor[
              0.2325030525609364, 0.36170582815947316`, 0.9365520769346783], 
             UndirectedEdge[118, 226] -> 
             RGBColor[
              0.17892828959271728`, 0.30539535544371077`, 0.9335010734403975],
              UndirectedEdge[75, 283] -> 
             RGBColor[
              0.6746177643537297, 0.7453737204958732, 0.9684508023443001], 
             UndirectedEdge[188, 243] -> 
             RGBColor[
              0.21194079974675017`, 0.3400935967296356, 0.9353810870560375], 
             UndirectedEdge[88, 258] -> 
             RGBColor[
              0.7329940972360016, 0.7896974879262988, 0.9518579499321382], 
             UndirectedEdge[197, 293] -> 
             RGBColor[
              0.20988077542261582`, 0.33792838055188446`, 0.9352637717183109],
              UndirectedEdge[86, 179] -> 
             RGBColor[
              0.9842570845883489, 0.9592626733262417, 0.5559110076191691], 
             UndirectedEdge[41, 76] -> 
             RGBColor[
              0.32564319585170254`, 0.45514146543527656`, 0.9420195932129798],
              UndirectedEdge[175, 242] -> 
             RGBColor[
              0.2674717938620085, 0.3984601924131547, 0.9385434950201575], 
             UndirectedEdge[89, 285] -> 
             RGBColor[
              0.3304519019187142, 0.457812130049975, 0.9423807168287202], 
             UndirectedEdge[138, 171] -> 
             RGBColor[
              0.5625186052786886, 0.6537822219340037, 0.9596386929535714], 
             UndirectedEdge[181, 207] -> 
             RGBColor[
              0.729702675862836, 0.7887685434205706, 0.9736936013369495], 
             UndirectedEdge[17, 55] -> 
             RGBColor[
              0.28645859801019335`, 0.41841652740581015`, 0.939624765427937], 
             UndirectedEdge[142, 295] -> 
             RGBColor[
              0.7481542644116976, 0.8033229003900898, 0.9754955751330152], 
             UndirectedEdge[53, 200] -> 
             RGBColor[
              0.8588625397294595, 0.4100527991192301, 0.2023008600078583], 
             UndirectedEdge[33, 237] -> 
             RGBColor[
              0.7767209844121652, 0.8262100194866766, 0.9782143643357628], 
             UndirectedEdge[51, 67] -> 
             RGBColor[
              0.9529402270197467, 0.9622638379796367, 0.8739273734917072], 
             UndirectedEdge[47, 48] -> 
             RGBColor[
              0.5288713488786927, 0.6272983725157164, 0.9563690029663805], 
             UndirectedEdge[102, 237] -> 
             RGBColor[
              0.5120510519507784, 0.6128989081758123, 0.9552397996499549], 
             UndirectedEdge[150, 282] -> 
             RGBColor[
              0.9628316709480902, 0.9718005015674145, 0.9478004654188247], 
             UndirectedEdge[214, 293] -> 
             RGBColor[
              0.21107172389025777`, 0.33918014290187026`, 0.9353315944716927],
              UndirectedEdge[73, 245] -> 
             RGBColor[
              0.37670637299800835`, 0.5007058593032094, 0.9452243748724349], 
             UndirectedEdge[82, 192] -> 
             RGBColor[
              0.930031406620387, 0.7358466203284666, 0.4572790883268795], 
             UndirectedEdge[82, 266] -> 
             RGBColor[
              0.6213553148465931, 0.6847435984870042, 0.8214592367687926], 
             UndirectedEdge[30, 38] -> 
             RGBColor[
              0.4400713503236684, 0.5553482940395915, 0.949328558422408], 
             UndirectedEdge[146, 242] -> 
             RGBColor[
              0.23544148915831797`, 0.3647943113309621, 0.9367194165518717], 
             UndirectedEdge[25, 77] -> 
             RGBColor[
              0.24892138027318342`, 0.37896253156714604`, 0.9374870764091515],
              UndirectedEdge[68, 271] -> 
             RGBColor[
              0.9259155815977133, 0.7290271362933656, 0.2919182148886562], 
             UndirectedEdge[23, 267] -> 
             RGBColor[
              0.3821106817559689, 0.50384843174461, 0.9457196175325961], 
             UndirectedEdge[10, 161] -> 
             RGBColor[
              0.21385191803304957`, 0.3421023032204342, 0.935489922415196], 
             UndirectedEdge[223, 287] -> 
             RGBColor[
              0.9141648921008272, 0.6925393884549282, 0.24954185631357317`], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.43016772773719436`, 0.545286907400802, 0.949107366939159], 
             UndirectedEdge[218, 229] -> 
             RGBColor[
              0.3012157370951104, 0.430446886752895, 0.9405925945789568], 
             UndirectedEdge[62, 170] -> 
             RGBColor[
              0.9083710867000301, 0.580339218042234, 0.42464655483310587`], 
             UndirectedEdge[188, 294] -> 
             RGBColor[
              0.20780626806211017`, 0.3357479417846294, 0.9351456315930887], 
             UndirectedEdge[181, 299] -> 
             RGBColor[
              0.8541508128707371, 0.884172913273241, 0.8565895585797871], 
             UndirectedEdge[69, 109] -> 
             RGBColor[
              0.957103333757725, 0.9637481152069529, 0.737975761375697], 
             UndirectedEdge[48, 175] -> 
             RGBColor[
              0.3540970438547585, 0.4798066886867111, 0.9438319175031515], 
             UndirectedEdge[248, 270] -> 
             RGBColor[
              0.21830317142063266`, 0.3467808527565494, 0.9357434147105796], 
             UndirectedEdge[85, 232] -> 
             RGBColor[
              0.9568611020652522, 0.9642649897035074, 0.7955094610260169], 
             UndirectedEdge[65, 152] -> 
             RGBColor[
              0.270606352963235, 0.4017548127710696, 0.9387220035238077], 
             UndirectedEdge[43, 63] -> 
             RGBColor[
              0.3233435154432426, 0.45448563418447746`, 0.9418241407759673], 
             UndirectedEdge[184, 293] -> 
             RGBColor[
              0.22334920945949943`, 0.35208455867268873`, 0.9360307791119489],
              UndirectedEdge[24, 260] -> 
             RGBColor[
              0.9023952825645615, 0.924495379134781, 0.9727268847769307], 
             UndirectedEdge[201, 229] -> 
             RGBColor[
              0.3337508945428317, 0.46349998287045846`, 0.9424872897693092], 
             UndirectedEdge[17, 48] -> 
             RGBColor[
              0.35495264897954515`, 0.4807059839213601, 0.9438806429492537], 
             UndirectedEdge[153, 163] -> 
             RGBColor[
              0.2574205034515923, 0.3878956489031873, 0.9379710889008359], 
             UndirectedEdge[33, 200] -> 
             RGBColor[
              0.9003293088366926, 0.7550036483702731, 0.6091535540920102], 
             UndirectedEdge[33, 282] -> 
             RGBColor[
              0.9391598487497231, 0.9536036259867218, 0.9690629330997416], 
             UndirectedEdge[150, 237] -> 
             RGBColor[
              0.8003928066105324, 0.8444068950673695, 0.956951896654846], 
             UndirectedEdge[172, 203] -> 
             RGBColor[
              0.26454467239722235`, 0.39538360216344437`, 0.9383767997830261],
              UndirectedEdge[56, 93] -> 
             RGBColor[
              0.5394509250519448, 0.6369895888012234, 0.9568866993753897], 
             UndirectedEdge[122, 299] -> 
             RGBColor[
              0.8093386473760087, 0.8488870251734923, 0.8523133648913199], 
             UndirectedEdge[44, 100] -> 
             RGBColor[
              0.9076177976951124, 0.6402494666473935, 0.25721638876551267`], 
             UndirectedEdge[31, 171] -> 
             RGBColor[
              0.5185950159671473, 0.6191084488745244, 0.955507160509088], 
             UndirectedEdge[136, 256] -> 
             RGBColor[
              0.9940778224627702, 0.9897413860088904, 0.596785706394875], 
             UndirectedEdge[146, 159] -> 
             RGBColor[
              0.2389221548438223, 0.3684527116533779, 0.9369176353134778], 
             UndirectedEdge[65, 133] -> 
             RGBColor[
              0.3190318248130566, 0.44882524399181684`, 0.9416199173833522], 
             UndirectedEdge[58, 245] -> 
             RGBColor[
              0.48666290222101594`, 0.5933487734884098, 0.952947963928872], 
             UndirectedEdge[172, 272] -> 
             RGBColor[
              0.2463878565667746, 0.37629963751702955`, 0.937342795982084], 
             UndirectedEdge[99, 218] -> 
             RGBColor[
              0.3117655585077827, 0.43958461181110975`, 0.9412648198705315], 
             UndirectedEdge[18, 113] -> 
             RGBColor[
              0.9529050044310041, 0.9643972099323963, 0.9646037225429771], 
             UndirectedEdge[43, 131] -> 
             RGBColor[
              0.3235024771639835, 0.45462331883733487`, 0.9418342696762487], 
             UndirectedEdge[2, 156] -> 
             RGBColor[
              0.2292281520802934, 0.3582637001136342, 0.9363655761970868], 
             UndirectedEdge[165, 232] -> 
             RGBColor[
              0.9871784526525289, 0.9674285696046385, 0.48831934332178484`], 
             UndirectedEdge[173, 186] -> 
             RGBColor[
              0.24357136840210497`, 0.3733393298802981, 0.937182401147727], 
             UndirectedEdge[39, 281] -> 
             RGBColor[
              0.8518045532150162, 0.3848416812601996, 0.19667924438169382`], 
             UndirectedEdge[77, 91] -> 
             RGBColor[
              0.25932242623621204`, 0.38989469033869195`, 0.9380794005897775],
              UndirectedEdge[15, 19] -> 
             RGBColor[
              0.265094966907718, 0.3959619965846625, 0.938408138241311], 
             UndirectedEdge[119, 241] -> 
             RGBColor[
              0.2806500707405608, 0.4123113969635265, 0.9392939783928775], 
             UndirectedEdge[103, 116] -> 
             RGBColor[
              0.3006123597209014, 0.43202989779004775`, 0.9404770506166615], 
             UndirectedEdge[99, 257] -> 
             RGBColor[
              0.37939685727732686`, 0.5030362215582833, 0.9453958101516111], 
             UndirectedEdge[17, 253] -> 
             RGBColor[
              0.2964738820674033, 0.42894322595562323`, 0.9401951210387102], 
             UndirectedEdge[204, 292] -> 
             RGBColor[
              0.2369721103072519, 0.36640309120547765`, 0.9368065831619525], 
             UndirectedEdge[65, 241] -> 
             RGBColor[
              0.2834960053804121, 0.4153026547126882, 0.9394560501604341], 
             UndirectedEdge[71, 256] -> 
             RGBColor[
              0.8124222635893662, 0.8512090470378892, 0.8440664489660341], 
             UndirectedEdge[37, 102] -> 
             RGBColor[
              0.5330127818666326, 0.6293292071697167, 0.9572915771331396], 
             UndirectedEdge[61, 217] -> 
             RGBColor[
              0.686937545269946, 0.7542032342825437, 0.9702221270801157], 
             UndirectedEdge[35, 184] -> 
             RGBColor[
              0.23183414268000563`, 0.3610027614632789, 0.9365139835065228], 
             UndirectedEdge[164, 241] -> 
             RGBColor[
              0.33149984085228634`, 0.458806984736167, 0.9424442983869149], 
             UndirectedEdge[192, 255] -> 
             RGBColor[
              0.9119702371400515, 0.6765104448805886, 0.25204962038332024`], 
             UndirectedEdge[112, 134] -> 
             RGBColor[
              0.2631071012640549, 0.3938726237552112, 0.9382949322336882], 
             UndirectedEdge[44, 195] -> 
             RGBColor[
              0.892099510879235, 0.5209691140239162, 0.24235605978523028`], 
             UndirectedEdge[127, 281] -> 
             RGBColor[
              0.8344242447380918, 0.2656054066230123, 0.18059800167880746`], 
             UndirectedEdge[59, 192] -> 
             RGBColor[
              0.8488981465441187, 0.3665071091151284, 0.1940529052630896], 
             UndirectedEdge[108, 264] -> 
             RGBColor[
              0.3192908615453144, 0.4496732026354332, 0.9416135901421105], 
             UndirectedEdge[136, 296] -> 
             RGBColor[
              0.8445716246365338, 0.8749311705589841, 0.7198898610709794], 
             UndirectedEdge[118, 130] -> 
             RGBColor[
              0.17892828448197629`, 0.3053953500719979, 0.9335010731493483], 
             UndirectedEdge[85, 136] -> 
             RGBColor[
              0.9562666668799304, 0.9629935529487204, 0.7308088595324563], 
             UndirectedEdge[104, 157] -> 
             RGBColor[
              0.3155261405863954, 0.44552577951204275`, 0.9414061686253012], 
             UndirectedEdge[158, 217] -> 
             RGBColor[
              0.6053338779034495, 0.6866046110497097, 0.9641707450092601], 
             UndirectedEdge[11, 174] -> 
             RGBColor[
              0.36791464439567134`, 0.49309090587299315`, 0.9446641737001142],
              UndirectedEdge[39, 220] -> 
             RGBColor[
              0.5623622253882596, 0.4395170049728193, 0.5745682237352395], 
             UndirectedEdge[32, 208] -> 
             RGBColor[
              0.27110861374646283`, 0.402282720699415, 0.9387506065323843], 
             UndirectedEdge[27, 103] -> 
             RGBColor[
              0.2686276829189324, 0.3996751050995809, 0.9386093211919647], 
             UndirectedEdge[212, 250] -> 
             RGBColor[
              0.21715203202826977`, 0.34557093226872304`, 0.9356778590251427],
              UndirectedEdge[129, 298] -> 
             RGBColor[
              0.26058075662513375`, 0.3912172753602034, 0.9381510606438935], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.9138967980085537, 0.6275576288296454, 0.4676443834469852], 
             UndirectedEdge[261, 290] -> 
             RGBColor[
              0.5067850511563949, 0.6090396671765619, 0.9547103165107921], 
             UndirectedEdge[24, 113] -> 
             RGBColor[
              0.9575230369172714, 0.9678413309993203, 0.9567865981194988], 
             UndirectedEdge[15, 243] -> 
             RGBColor[
              0.2285446981366219, 0.35754534668535254`, 0.9363266545060742], 
             UndirectedEdge[246, 296] -> 
             RGBColor[
              0.6475517482649964, 0.7239253864883827, 0.965961068287336], 
             UndirectedEdge[131, 174] -> 
             RGBColor[
              0.3585773503848271, 0.4850034111068425, 0.9440692095823882], 
             UndirectedEdge[44, 121] -> 
             RGBColor[
              0.9798326937990873, 0.9423326330377451, 0.48673505054828914`], 
             UndirectedEdge[155, 293] -> 
             RGBColor[
              0.21078204772465953`, 0.3388756748852968, 0.9353150978425994], 
             UndirectedEdge[105, 140] -> 
             RGBColor[
              0.3086221728107845, 0.4399248428735164, 0.9409523793012212], 
             UndirectedEdge[51, 138] -> 
             RGBColor[
              0.8501230130531416, 0.8811959449639274, 0.8638775606265587], 
             UndirectedEdge[133, 277] -> 
             RGBColor[
              0.3496210523003913, 0.4772459158627348, 0.9434985221881913], 
             UndirectedEdge[201, 261] -> 
             RGBColor[
              0.36087721144814144`, 0.48699543516550725`, 0.9442157546956553],
              UndirectedEdge[19, 57] -> 
             RGBColor[
              0.2691600647734066, 0.40023467218359243`, 0.9386396395509886], 
             UndirectedEdge[104, 261] -> 
             RGBColor[
              0.34285661416014696`, 0.46919806205208336`, 0.9431476422340319],
              UndirectedEdge[15, 111] -> 
             RGBColor[
              0.2409685800879815, 0.3706036343358437, 0.9370341762037178], 
             UndirectedEdge[71, 85] -> 
             RGBColor[
              0.7746111080065263, 0.8244612139777192, 0.9780896021036154], 
             UndirectedEdge[84, 158] -> 
             RGBColor[
              0.35212502014478775`, 0.47866323634096297`, 0.943685588557766], 
             UndirectedEdge[65, 162] -> 
             RGBColor[
              0.28622167127698683`, 0.41816750238718753`, 0.9396112728009827],
              UndirectedEdge[156, 268] -> 
             RGBColor[
              0.2451076812596908, 0.374954092101482, 0.9372698918921952], 
             UndirectedEdge[48, 252] -> 
             RGBColor[
              0.35710710220900627`, 0.48297045086574814`, 0.9440033358734436],
              UndirectedEdge[204, 235] -> 
             RGBColor[
              0.23646094075205434`, 0.36586581959294334`, 0.9367774728119916],
              UndirectedEdge[62, 130] -> 
             RGBColor[
              0.5868878667757954, 0.648392143438405, 0.8070978104506135], 
             UndirectedEdge[142, 283] -> 
             RGBColor[
              0.6388734394755219, 0.7174499822340865, 0.964888142090148], 
             UndirectedEdge[99, 259] -> 
             RGBColor[
              0.41587462147542475`, 0.5343343034600658, 0.9478022372825421], 
             UndirectedEdge[43, 244] -> 
             RGBColor[
              0.28234247424873604`, 0.412848733894419, 0.9394358151698824], 
             UndirectedEdge[36, 154] -> 
             RGBColor[
              0.750385676327774, 0.8049262605804057, 0.9757550895296658], 
             UndirectedEdge[11, 185] -> 
             RGBColor[
              0.4557880502577546, 0.5660866394053694, 0.9511242925783112], 
             UndirectedEdge[20, 150] -> 
             RGBColor[
              0.9139560790389594, 0.9335493921357441, 0.968134833574319], 
             UndirectedEdge[175, 252] -> 
             RGBColor[
              0.2975212413691305, 0.4300440669881537, 0.9402547666015143], 
             UndirectedEdge[97, 292] -> 
             RGBColor[
              0.25027096919944, 0.3803810350975218, 0.937563933501964], 
             UndirectedEdge[176, 226] -> 
             RGBColor[
              0.17893944427006758`, 0.3054070797168533, 0.9335017086827707], 
             UndirectedEdge[80, 103] -> 
             RGBColor[
              0.2733233300214085, 0.4046105279255051, 0.9388767313478634], 
             UndirectedEdge[137, 220] -> 
             RGBColor[
              0.5513789728038629, 0.36945130513336594`, 0.564612808979479], 
             UndirectedEdge[20, 167] -> 
             RGBColor[
              0.8099161582263048, 0.8518030947538164, 0.981590034710579], 
             UndirectedEdge[240, 256] -> 
             RGBColor[
              0.9950907669461442, 0.9919079718344301, 0.7070384622414018], 
             UndirectedEdge[113, 278] -> 
             RGBColor[
              0.7811703997408805, 0.8288870412862575, 0.957738894978919], 
             UndirectedEdge[181, 240] -> 
             RGBColor[
              0.8543753182561593, 0.8839651564219314, 0.8310187966371865], 
             UndirectedEdge[7, 151] -> 
             RGBColor[
              0.4190101469832575, 0.5373472620797284, 0.9479199339430164], 
             UndirectedEdge[6, 101] -> 
             RGBColor[
              0.4261316567977976, 0.5406988809357904, 0.9490838670731377], 
             UndirectedEdge[65, 116] -> 
             RGBColor[
              0.3051622199360282, 0.4368120893539453, 0.940736158424998], 
             UndirectedEdge[50, 264] -> 
             RGBColor[
              0.32355517598609507`, 0.45336673747336176`, 0.9418853084874919],
              UndirectedEdge[55, 235] -> 
             RGBColor[
              0.25936698600148883`, 0.38994152547725025`, 0.9380819382024896],
              UndirectedEdge[100, 232] -> 
             RGBColor[
              0.9221384356388024, 0.6882475061102127, 0.3972545294946756], 
             UndirectedEdge[28, 163] -> 
             RGBColor[
              0.23238600045450547`, 0.3615827989740821, 0.9365454109903801], 
             UndirectedEdge[11, 63] -> 
             RGBColor[
              0.3340095449749544, 0.46372401287461446`, 0.9425037707461285], 
             UndirectedEdge[234, 274] -> 
             RGBColor[
              0.8909472265976595, 0.513146913463993, 0.24055037716924876`], 
             UndirectedEdge[148, 270] -> 
             RGBColor[
              0.23353444010566207`, 0.3627898818627272, 0.9366108129295494], 
             UndirectedEdge[96, 245] -> 
             RGBColor[
              0.41493426639987385`, 0.5338169391781161, 0.9476602224364029], 
             UndirectedEdge[159, 235] -> 
             RGBColor[
              0.24471645266359499`, 0.3745428860416596, 0.9372476120024185], 
             UndirectedEdge[53, 287] -> 
             RGBColor[
              0.8863520651509298, 0.5242910551950881, 0.22469122939407754`], 
             UndirectedEdge[105, 289] -> 
             RGBColor[
              0.2900768000973668, 0.42221948720669167`, 0.9398308166841512], 
             UndirectedEdge[56, 164] -> 
             RGBColor[
              0.46580833431938506`, 0.5753190136054342, 0.9516098956299331], 
             UndirectedEdge[112, 235] -> 
             RGBColor[
              0.24712629913564943`, 0.3770757874768801, 0.9373848491939536], 
             UndirectedEdge[7, 43] -> 
             RGBColor[
              0.3584602463932565, 0.4849019815151618, 0.9440617478195963], 
             UndirectedEdge[242, 243] -> 
             RGBColor[
              0.22929951054390013`, 0.35833870238327276`, 0.9363696399560237],
              UndirectedEdge[151, 286] -> 
             RGBColor[
              0.5011547059099458, 0.6056262623148936, 0.953947236987697], 
             UndirectedEdge[126, 163] -> 
             RGBColor[
              0.23364896427549098`, 0.3629102540264691, 0.9366173349115978], 
             UndirectedEdge[31, 138] -> 
             RGBColor[
              0.662760313991049, 0.7361123302878763, 0.9672677727663206], 
             UndirectedEdge[95, 138] -> 
             RGBColor[
              0.5976652055170001, 0.6832651887274253, 0.9621432473760043], 
             UndirectedEdge[197, 275] -> 
             RGBColor[
              0.21163940728530467`, 0.33977681414327066`, 0.9353639232012283],
              UndirectedEdge[198, 245] -> 
             RGBColor[
              0.4443289893270455, 0.5589801958800422, 0.949615283231626], 
             UndirectedEdge[187, 264] -> 
             RGBColor[
              0.3292953995025846, 0.4583386305713222, 0.9422510704540822], 
             UndirectedEdge[62, 195] -> 
             RGBColor[
              0.9069962455234778, 0.5697715863000085, 0.4233300053697785], 
             UndirectedEdge[169, 187] -> 
             RGBColor[
              0.3284772756829356, 0.4574787305648249, 0.9422044795128589], 
             UndirectedEdge[82, 199] -> 
             RGBColor[
              0.587001837836629, 0.6486359160132862, 0.81950285707449], 
             UndirectedEdge[126, 155] -> 
             RGBColor[
              0.21912067898952223`, 0.3476401050444259, 0.9357899705572339], 
             UndirectedEdge[82, 220] -> 
             RGBColor[
              0.6261342073882591, 0.6897665175475827, 0.8217313876293025], 
             UndirectedEdge[32, 202] -> 
             RGBColor[
              0.24218926046257408`, 0.37188664680514644`, 0.937103692145216], 
             UndirectedEdge[113, 260] -> 
             RGBColor[
              0.9042815340807562, 0.9259021424271057, 0.969533952973199], 
             UndirectedEdge[105, 230] -> 
             RGBColor[
              0.2692612582166467, 0.40034103290847267`, 0.938645402367879], 
             UndirectedEdge[245, 289] -> 
             RGBColor[
              0.3576929449951681, 0.48259509766982983`, 0.944072988186208], 
             UndirectedEdge[108, 187] -> 
             RGBColor[
              0.35392495764506043`, 0.4809737423517148, 0.9437727632309596], 
             UndirectedEdge[137, 228] -> 
             RGBColor[
              0.8309547247116273, 0.6038501100477591, 0.5867983401041436], 
             UndirectedEdge[88, 261] -> 
             RGBColor[
              0.4524312720200109, 0.5649128206637994, 0.9504313879127225], 
             UndirectedEdge[192, 228] -> 
             RGBColor[
              0.8406646902431527, 0.6681341107638701, 0.5956912929318666], 
             UndirectedEdge[42, 97] -> 
             RGBColor[
              0.25595913612423093`, 0.3863596591860904, 0.937887866193442], 
             UndirectedEdge[121, 240] -> 
             RGBColor[
              0.9947718410408293, 0.9912258215713169, 0.6723253456304181], 
             UndirectedEdge[25, 43] -> 
             RGBColor[
              0.2869920462831278, 0.4177357289024586, 0.9397006014188156], 
             UndirectedEdge[77, 270] -> 
             RGBColor[
              0.23714390206690406`, 0.36658365523709874`, 0.9368163664485216],
              UndirectedEdge[225, 255] -> 
             RGBColor[
              0.9599585954916654, 0.876593081803823, 0.2989471339802242], 
             UndirectedEdge[2, 275] -> 
             RGBColor[
              0.2217679370492794, 0.35042254111108606`, 0.9359407279874696], 
             UndirectedEdge[235, 253] -> 
             RGBColor[
              0.2693822700586988, 0.40046822402706334`, 0.9386522938132629], 
             UndirectedEdge[73, 95] -> 
             RGBColor[
              0.4088283158597046, 0.5275690199007069, 0.9475362008014293], 
             UndirectedEdge[49, 175] -> 
             RGBColor[
              0.26553285029495766`, 0.3964222397880617, 0.9384330750524239], 
             UndirectedEdge[153, 219] -> 
             RGBColor[
              0.2738583241419696, 0.40517284066680126`, 0.9389071984715764], 
             UndirectedEdge[54, 167] -> 
             RGBColor[
              0.585666437251012, 0.671825268631737, 0.9619628736506332], 
             UndirectedEdge[56, 246] -> 
             RGBColor[
              0.57328015808247, 0.6644536841649844, 0.9595498605201163], 
             UndirectedEdge[192, 225] -> 
             RGBColor[
              0.91297449591913, 0.6798980455535951, 0.25595097610168294`], 
             UndirectedEdge[84, 252] -> 
             RGBColor[
              0.30057464185555743`, 0.4332533844961608, 0.9404286532421151], 
             UndirectedEdge[119, 164] -> 
             RGBColor[
              0.33307449939887124`, 0.46046205070774604`, 0.9425339728616443],
              UndirectedEdge[93, 168] -> 
             RGBColor[
              0.4585412392278475, 0.5694721717790032, 0.9510231831684333], 
             UndirectedEdge[111, 250] -> 
             RGBColor[
              0.2327988220725642, 0.3620167006690641, 0.9365689205708136], 
             UndirectedEdge[54, 286] -> 
             RGBColor[
              0.4882211414959945, 0.5944238588793778, 0.953123121699942], 
             UndirectedEdge[74, 257] -> 
             RGBColor[
              0.5147596974188978, 0.6152603482603705, 0.9554081515783656], 
             UndirectedEdge[220, 236] -> 
             RGBColor[
              0.4402011946832155, 0.5463223550644548, 0.9507193164378127], 
             UndirectedEdge[130, 228] -> 
             RGBColor[
              0.49763512145939465`, 0.5809234064486897, 0.9579150616794772], 
             UndirectedEdge[1, 142] -> 
             RGBColor[
              0.5387732060688373, 0.6352393283002062, 0.9572689291818902], 
             UndirectedEdge[101, 114] -> 
             RGBColor[
              0.4255007228362041, 0.540035729338632, 0.9490479363174081], 
             UndirectedEdge[199, 266] -> 
             RGBColor[
              0.21328047700996416`, 0.3415016824737179, 0.9354573796943026], 
             UndirectedEdge[93, 277] -> 
             RGBColor[
              0.440152252258617, 0.5535445555236148, 0.9498514531794966], 
             UndirectedEdge[19, 112] -> 
             RGBColor[
              0.271740291472555, 0.402946654040219, 0.9387865796444018], 
             UndirectedEdge[77, 203] -> 
             RGBColor[
              0.25281317669126346`, 0.38305305635669296`, 0.9377087084577643],
              UndirectedEdge[26, 60] -> 
             RGBColor[
              0.9559587194852852, 0.8665294960501166, 0.5718984085520893], 
             UndirectedEdge[186, 263] -> 
             RGBColor[
              0.24547633917610456`, 0.3753415749458948, 0.9372908864151546], 
             UndirectedEdge[167, 283] -> 
             RGBColor[
              0.6863247949375169, 0.7545193417646557, 0.9696176497444712], 
             UndirectedEdge[170, 200] -> 
             RGBColor[
              0.8539446998932355, 0.37225212712685507`, 0.1975915310267845], 
             UndirectedEdge[17, 292] -> 
             RGBColor[
              0.26964195081094916`, 0.4007411649623891, 0.9386670822479402], 
             UndirectedEdge[106, 215] -> 
             RGBColor[
              0.8258859987463416, 0.8619784867738793, 0.84861498208911], 
             UndirectedEdge[123, 229] -> 
             RGBColor[
              0.3913046976868122, 0.5133501944155183, 0.9461545672128138], 
             UndirectedEdge[105, 149] -> 
             RGBColor[
              0.29155965067616113`, 0.4237780571831614, 0.9399152628309327], 
             UndirectedEdge[68, 274] -> 
             RGBColor[
              0.9194708353599413, 0.7072874939349834, 0.2668815927431183], 
             UndirectedEdge[149, 171] -> 
             RGBColor[
              0.3561511381973472, 0.48153386145037547`, 0.943964705839551], 
             UndirectedEdge[29, 172] -> 
             RGBColor[
              0.256159178309366, 0.3865699162060744, 0.9378992582999495], 
             UndirectedEdge[76, 209] -> 
             RGBColor[
              0.2797259704782522, 0.4113401089964994, 0.9392413522500229], 
             UndirectedEdge[247, 267] -> 
             RGBColor[
              0.5234677465828359, 0.6240137244860162, 0.9556284450179895], 
             UndirectedEdge[164, 210] -> 
             RGBColor[
              0.3812406788826516, 0.5046332471596473, 0.9455132968338751], 
             UndirectedEdge[258, 260] -> 
             RGBColor[
              0.9054604072768613, 0.9267813441265331, 0.9675384281515653], 
             UndirectedEdge[62, 137] -> 
             RGBColor[
              0.9202074700280282, 0.6713188470374746, 0.43598108887527987`], 
             UndirectedEdge[175, 280] -> 
             RGBColor[
              0.2812847712693677, 0.4129785074616403, 0.9393301236490378], 
             UndirectedEdge[72, 194] -> 
             RGBColor[
              0.5838203648230471, 0.6728659592388615, 0.9604785834522965], 
             UndirectedEdge[3, 257] -> 
             RGBColor[
              0.38431511212659675`, 0.5072961667100446, 0.9457091970015647], 
             UndirectedEdge[154, 171] -> 
             RGBColor[
              0.5797766952507789, 0.6672643729865424, 0.9613588180759691], 
             UndirectedEdge[168, 277] -> 
             RGBColor[
              0.3674840405107483, 0.49271793843065337`, 0.944636736001335], 
             UndirectedEdge[146, 243] -> 
             RGBColor[
              0.22430859499308387`, 0.3530929336970421, 0.9360854146988027], 
             UndirectedEdge[98, 122] -> 
             RGBColor[
              0.5234999711581451, 0.6232114459734905, 0.9558598822602524], 
             UndirectedEdge[142, 210] -> 
             RGBColor[
              0.5187904189187625, 0.6179312424348968, 0.9559956436547723], 
             UndirectedEdge[3, 38] -> 
             RGBColor[
              0.3976345995492975, 0.5188328372586848, 0.9465579029621789], 
             UndirectedEdge[21, 205] -> 
             RGBColor[
              0.4564507498978377, 0.5677093547420913, 0.9508767552454336], 
             UndirectedEdge[153, 221] -> 
             RGBColor[
              0.2840475061144973, 0.4158823169513779, 0.939487457311368], 
             UndirectedEdge[55, 159] -> 
             RGBColor[
              0.26204426941803677`, 0.39275552009761494`, 0.9382344055323761],
              UndirectedEdge[149, 298] -> 
             RGBColor[
              0.28960052483186716`, 0.4217188917050555, 0.9398036935123671], 
             UndirectedEdge[22, 247] -> 
             RGBColor[
              0.6982336123573278, 0.7632154445962727, 0.9712197251392987], 
             UndirectedEdge[105, 298] -> 
             RGBColor[
              0.2872112063681208, 0.41920756650811786`, 0.9396676253605367], 
             UndirectedEdge[169, 219] -> 
             RGBColor[
              0.2836300261607937, 0.41544351905027754`, 0.9394636824456108], 
             UndirectedEdge[53, 225] -> 
             RGBColor[
              0.8963459868958306, 0.5624350878346187, 0.24043281821285972`], 
             UndirectedEdge[47, 90] -> 
             RGBColor[
              0.5238031310544717, 0.622908536972411, 0.9560460606082701], 
             UndirectedEdge[100, 137] -> 
             RGBColor[
              0.8478732688157926, 0.3689804990841502, 0.19347680232411396`], 
             UndirectedEdge[15, 175] -> 
             RGBColor[
              0.2667169814547302, 0.3976668367152345, 0.9385005095702079], 
             UndirectedEdge[49, 253] -> 
             RGBColor[
              0.2666399442226916, 0.39758586569991927`, 0.9384961224138098], 
             UndirectedEdge[166, 291] -> 
             RGBColor[
              0.9053156340255587, 0.5627492600761606, 0.30706567418331665`], 
             UndirectedEdge[161, 230] -> 
             RGBColor[
              0.2328116110999559, 0.36203014274772405`, 0.9365696488870041], 
             UndirectedEdge[263, 269] -> 
             RGBColor[
              0.24400443083652518`, 0.3737945059566179, 0.9372070634127088], 
             UndirectedEdge[122, 160] -> 
             RGBColor[
              0.6072063704282553, 0.6919965117057422, 0.9622206562317872], 
             UndirectedEdge[196, 289] -> 
             RGBColor[
              0.28595784411409636`, 0.4178902033113814, 0.9395962482343534], 
             UndirectedEdge[30, 158] -> 
             RGBColor[
              0.4329152304787701, 0.5491500227069821, 0.9488725767937995], 
             UndirectedEdge[114, 187] -> 
             RGBColor[
              0.33417034239985266`, 0.4634625046455827, 0.9425286912402498], 
             UndirectedEdge[49, 159] -> 
             RGBColor[
              0.24197412682758776`, 0.3716605277145155, 0.9370914406029653], 
             UndirectedEdge[33, 94] -> 
             RGBColor[
              0.8883058899064401, 0.9137750204630982, 0.9892086028509474], 
             UndirectedEdge[193, 220] -> 
             RGBColor[
              0.3283447463388828, 0.4540509053495343, 0.9423173412993839], 
             UndirectedEdge[60, 127] -> 
             RGBColor[
              0.879427272019672, 0.4987774156297289, 0.21919915424561515`], 
             UndirectedEdge[282, 297] -> 
             RGBColor[
              0.8620280342318183, 0.892582413918251, 0.9615782291090177], 
             UndirectedEdge[97, 235] -> 
             RGBColor[
              0.24975979964424241`, 0.3798437634849875, 0.9375348231520031], 
             UndirectedEdge[50, 187] -> 
             RGBColor[
              0.35818927208584117`, 0.4846672771896433, 0.9440444815763409], 
             UndirectedEdge[271, 274] -> 
             RGBColor[
              0.9710201994330907, 0.9139064692863681, 0.34191937648403536`], 
             UndirectedEdge[137, 170] -> 
             RGBColor[
              0.8337298231764674, 0.2602677782028984, 0.17993302280715895`], 
             UndirectedEdge[84, 253] -> 
             RGBColor[
              0.29867167742904355`, 0.43125324822898137`, 0.9403202822332086],
              UndirectedEdge[33, 185] -> 
             RGBColor[
              0.7413664787721765, 0.7975076391058051, 0.9754311281439616], 
             UndirectedEdge[3, 144] -> 
             RGBColor[
              0.34651719678738085`, 0.4745575122216793, 0.9433007472595341], 
             UndirectedEdge[11, 43] -> 
             RGBColor[
              0.3328397711748278, 0.46271081360348554`, 0.9424292337939748], 
             UndirectedEdge[29, 272] -> 
             RGBColor[
              0.23305163384099561`, 0.36228242186687754`, 0.9365833178270244],
              UndirectedEdge[70, 251] -> 
             RGBColor[
              0.27547374372817707`, 0.40687074907542276`, 0.9389991942272118],
              UndirectedEdge[99, 123] -> 
             RGBColor[
              0.40185451909948444`, 0.5224879194737331, 0.9468267925043885], 
             UndirectedEdge[133, 239] -> 
             RGBColor[
              0.38064066205782954`, 0.5041135427437089, 0.9454750642923715], 
             UndirectedEdge[259, 260] -> 
             RGBColor[
              0.656707314635238, 0.7292515443954324, 0.9682208504157948], 
             UndirectedEdge[125, 192] -> 
             RGBColor[
              0.9288056517822338, 0.7332248546724817, 0.32386323867590994`], 
             UndirectedEdge[213, 264] -> 
             RGBColor[
              0.36127001361165895`, 0.48603343422176903`, 0.9442884645910713],
              UndirectedEdge[134, 204] -> 
             RGBColor[
              0.25244174288045984`, 0.38266265587127446`, 0.9376875558517261],
              UndirectedEdge[94, 142] -> 
             RGBColor[
              0.7604864358301577, 0.8131562391312941, 0.9766718286519673], 
             UndirectedEdge[134, 175] -> 
             RGBColor[
              0.2842559782593704, 0.41610143439353686`, 0.9394993294916116], 
             UndirectedEdge[8, 267] -> 
             RGBColor[
              0.5598482664107077, 0.6534036903177951, 0.9585918492816847], 
             UndirectedEdge[195, 225] -> 
             RGBColor[
              0.8900533058830544, 0.5140667841000182, 0.23440693976845853`], 
             UndirectedEdge[51, 281] -> 
             RGBColor[
              0.9148192587802333, 0.6349551711119263, 0.4692679592224235], 
             UndirectedEdge[49, 243] -> 
             RGBColor[
              0.2273605669768493, 0.3563007497581797, 0.9362592199882902], 
             UndirectedEdge[212, 243] -> 
             RGBColor[
              0.2149437082857312, 0.34324984399950276`, 0.9355520982549272], 
             UndirectedEdge[22, 285] -> 
             RGBColor[
              0.6000751622710249, 0.6816104857973055, 0.9640215926822105], 
             UndirectedEdge[20, 33] -> 
             RGBColor[
              0.8902842568405922, 0.9153525165550513, 0.9893973012552358], 
             UndirectedEdge[9, 174] -> 
             RGBColor[
              0.4545765714263261, 0.5664286209801727, 0.9506626768751375], 
             UndirectedEdge[180, 250] -> 
             RGBColor[
              0.22830469938985565`, 0.3572930927857018, 0.9363129869324922], 
             UndirectedEdge[92, 221] -> 
             RGBColor[
              0.27785530490942656`, 0.40937392087661617`, 0.9391348206132799],
              UndirectedEdge[71, 232] -> 
             RGBColor[
              0.8118465460917592, 0.8499776455244756, 0.7814031522680547], 
             UndirectedEdge[25, 148] -> 
             RGBColor[
              0.24531191831194143`, 0.3751687581927745, 0.9372815228901793], 
             UndirectedEdge[76, 218] -> 
             RGBColor[
              0.2751691719679872, 0.4065506248444982, 0.9389818493160426], 
             UndirectedEdge[20, 200] -> 
             RGBColor[
              0.8759509079419014, 0.7355649732308305, 0.6068283204518097], 
             UndirectedEdge[68, 255] -> 
             RGBColor[
              0.9166602771185755, 0.6978068210363987, 0.2559631047048003], 
             UndirectedEdge[30, 123] -> 
             RGBColor[
              0.44920952472312525`, 0.5632633214064009, 0.9499108348145711], 
             UndirectedEdge[113, 290] -> 
             RGBColor[
              0.7861690031762806, 0.8329451327396338, 0.9581324033518415], 
             UndirectedEdge[230, 269] -> 
             RGBColor[
              0.23818874032876391`, 0.3676818464968855, 0.9368758684418348], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.40607658256930623`, 0.5261448586442126, 0.9470958186552614], 
             UndirectedEdge[71, 296] -> 
             RGBColor[
              0.6629160657631297, 0.7363988315879828, 0.9671706036421385], 
             UndirectedEdge[37, 237] -> 
             RGBColor[
              0.6597410410048012, 0.7340591462727639, 0.9667579712592742], 
             UndirectedEdge[8, 217] -> 
             RGBColor[
              0.7294424930983517, 0.7885652866674933, 0.9736676687505319], 
             UndirectedEdge[39, 100] -> 
             RGBColor[
              0.8588565214001893, 0.4390461989236035, 0.20343221707987458`], 
             UndirectedEdge[35, 216] -> 
             RGBColor[
              0.24253456217849695`, 0.3722495808019747, 0.9371233565671098], 
             UndirectedEdge[48, 253] -> 
             RGBColor[
              0.3552041377824924, 0.4809703145985687, 0.9438949648645372], 
             UndirectedEdge[72, 247] -> 
             RGBColor[
              0.6154478937421781, 0.6985426120193529, 0.9629684183842664], 
             UndirectedEdge[24, 254] -> 
             RGBColor[
              0.9234793483730712, 0.7829172870924861, 0.5955041038084421], 
             UndirectedEdge[247, 273] -> 
             RGBColor[
              0.598461668080708, 0.6848971683956518, 0.9615322412300882], 
             UndirectedEdge[80, 152] -> 
             RGBColor[
              0.26056294463292196`, 0.39119855382704327`, 0.9381500462772876],
              UndirectedEdge[121, 125] -> 
             RGBColor[
              0.9936176446660105, 0.9887571122327337, 0.5466981931057444], 
             UndirectedEdge[8, 177] -> 
             RGBColor[
              0.5355284607783559, 0.6327336001246429, 0.9569332103909327], 
             UndirectedEdge[38, 253] -> 
             RGBColor[
              0.35733483343099304`, 0.48281581607742285`, 0.9440307309071595],
              UndirectedEdge[134, 292] -> 
             RGBColor[
              0.2585311409306501, 0.3890629993121603, 0.9380343380622274], 
             UndirectedEdge[19, 177] -> 
             RGBColor[
              0.3552373943929633, 0.4804944703524481, 0.9439155616348212], 
             UndirectedEdge[219, 221] -> 
             RGBColor[
              0.28442417853057445`, 0.4162782235430855, 0.9395089082482266], 
             UndirectedEdge[37, 185] -> 
             RGBColor[
              0.6243865353648125, 0.7053567658918924, 0.9639747350674728], 
             UndirectedEdge[15, 280] -> 
             RGBColor[
              0.2534905697092152, 0.38376503936775813`, 0.9377472849880235], 
             UndirectedEdge[140, 171] -> 
             RGBColor[
              0.37321366033197056`, 0.49768064714073046`, 0.9450018223098395],
              UndirectedEdge[211, 221] -> 
             RGBColor[
              0.26848631667000333`, 0.39952652020881857`, 0.9386012705932207],
              UndirectedEdge[47, 273] -> 
             RGBColor[
              0.6309474410941337, 0.7112445284148133, 0.9641074535297975], 
             UndirectedEdge[58, 171] -> 
             RGBColor[
              0.48363824484440066`, 0.5907289672924857, 0.9527552354354336], 
             UndirectedEdge[75, 150] -> 
             RGBColor[
              0.8462593507356758, 0.8802930242051693, 0.9614859532696918], 
             UndirectedEdge[9, 167] -> 
             RGBColor[
              0.6353780576373289, 0.7131584853000028, 0.9656069359601525], 
             UndirectedEdge[135, 260] -> 
             RGBColor[
              0.9196247583457642, 0.9363642687580429, 0.8996385198821143], 
             UndirectedEdge[184, 202] -> 
             RGBColor[
              0.23277907926056368`, 0.361995949721885, 0.9365677962468772], 
             UndirectedEdge[166, 262] -> 
             RGBColor[
              0.9933514957949947, 0.9881878467094093, 0.5177295309761065], 
             UndirectedEdge[173, 276] -> 
             RGBColor[
              0.24447758470727698`, 0.3742918206744662, 0.9372340088256796], 
             UndirectedEdge[67, 86] -> 
             RGBColor[
              0.9435929630020026, 0.929903263270933, 0.6741823558912051], 
             UndirectedEdge[25, 272] -> 
             RGBColor[
              0.23754533151077184`, 0.36700558303470066`, 0.9368392272614883],
              UndirectedEdge[7, 174] -> 
             RGBColor[
              0.39353511961410004`, 0.5152820737846694, 0.9462966877257359], 
             UndirectedEdge[88, 113] -> 
             RGBColor[
              0.7318152240398965, 0.7888182862268713, 0.9538534747537719], 
             UndirectedEdge[147, 206] -> 
             RGBColor[
              0.23143319481245586`, 0.360581339832921, 0.9364911501186151], 
             UndirectedEdge[189, 211] -> 
             RGBColor[
              0.23710386113640347`, 0.3665415696804011, 0.9368140861767649], 
             UndirectedEdge[104, 209] -> 
             RGBColor[
              0.2751140822771375, 0.4064927220865271, 0.9389787120396467], 
             UndirectedEdge[151, 167] -> 
             RGBColor[
              0.5986000016649633, 0.6830276720672528, 0.9627869889383882], 
             UndirectedEdge[215, 274] -> 
             RGBColor[
              0.979839341035498, 0.9422049502369351, 0.5238492272566825], 
             UndirectedEdge[41, 261] -> 
             RGBColor[
              0.3788160778841355, 0.5025331796387221, 0.9453588034022401], 
             UndirectedEdge[157, 218] -> 
             RGBColor[
              0.30101158042666865`, 0.4302700565079032, 0.9405795858965723], 
             UndirectedEdge[187, 205] -> 
             RGBColor[
              0.44668815437293624`, 0.55925348518074, 0.950254691291311], 
             UndirectedEdge[62, 82] -> 
             RGBColor[
              0.9949627046124243, 0.9916340594516913, 0.6930996675251034], 
             UndirectedEdge[42, 144] -> 
             RGBColor[
              0.28507366633741316`, 0.4163170541357517, 0.9395694691052225], 
             UndirectedEdge[33, 150] -> 
             RGBColor[
              0.9383344799337505, 0.9529880672751867, 0.9704600672145196], 
             UndirectedEdge[34, 46] -> 
             RGBColor[
              0.30981865996121394`, 0.44123557275110054`, 0.9410185715382298],
              UndirectedEdge[220, 266] -> 
             RGBColor[
              0.2524128465615943, 0.3826322840080144, 0.9376859102491151], 
             UndirectedEdge[128, 279] -> 
             RGBColor[
              0.24902661375038676`, 0.3790731386238746, 0.9374930692999993], 
             UndirectedEdge[147, 270] -> 
             RGBColor[
              0.2272240069658551, 0.35615721652822, 0.9362514430976865], 
             UndirectedEdge[30, 90] -> 
             RGBColor[
              0.4328724368509469, 0.5491129570174318, 0.9488698500216755], 
             UndirectedEdge[36, 222] -> 
             RGBColor[
              0.5978519743815511, 0.6821400273622127, 0.9628407950842862], 
             UndirectedEdge[127, 170] -> 
             RGBColor[
              0.8273327672839398, 0.21109720340516447`, 0.1738071948600332], 
             UndirectedEdge[1, 295] -> 
             RGBColor[
              0.6279037208977163, 0.7050085996594103, 0.9661155178174292], 
             UndirectedEdge[96, 140] -> 
             RGBColor[
              0.36676996210044227`, 0.49209943960227065`, 0.9445912355564652],
              UndirectedEdge[206, 272] -> 
             RGBColor[
              0.22997704115109324`, 0.35905083000935434`, 0.9364082243217868],
              UndirectedEdge[129, 265] -> 
             RGBColor[
              0.22918762870603976`, 0.3582211074779632, 0.936363268450872], 
             UndirectedEdge[39, 60] -> 
             RGBColor[
              0.8968075804965964, 0.6180136902669162, 0.2352803969485015], 
             UndirectedEdge[71, 240] -> 
             RGBColor[
              0.8122650553898112, 0.8508727945952284, 0.8269553066210207], 
             UndirectedEdge[30, 144] -> 
             RGBColor[
              0.3889539475617518, 0.5110729690025859, 0.9460714027197632], 
             UndirectedEdge[26, 59] -> 
             RGBColor[
              0.9093225725856791, 0.6208046140216712, 0.5317333787947149], 
             UndirectedEdge[133, 241] -> 
             RGBColor[
              0.3146112316266204, 0.4441789202710761, 0.9413681711410662], 
             UndirectedEdge[236, 266] -> 
             RGBColor[
              0.43542230214154953`, 0.5412994360038763, 0.9504471655773028], 
             UndirectedEdge[28, 216] -> 
             RGBColor[
              0.24112529640186797`, 0.3707683531181266, 0.9370431009659527], 
             UndirectedEdge[173, 230] -> 
             RGBColor[
              0.25326290395464024`, 0.3835257482248573, 0.9377343197601018], 
             UndirectedEdge[39, 266] -> 
             RGBColor[
              0.5575833328465938, 0.4344940859122408, 0.5742960728747296], 
             UndirectedEdge[86, 141] -> 
             RGBColor[
              0.936935020626016, 0.7805800799358134, 0.2971516426609445], 
             UndirectedEdge[25, 206] -> 
             RGBColor[
              0.2442420605634609, 0.3740442698662223, 0.937220596074116], 
             UndirectedEdge[141, 165] -> 
             RGBColor[0.9396314058192, 0.789675620333774, 0.3076265899668467],
              UndirectedEdge[152, 241] -> 
             RGBColor[
              0.2661857597767988, 0.3971084890503288, 0.9384702572815218], 
             UndirectedEdge[110, 141] -> 
             RGBColor[
              0.9459742116007779, 0.8128132585241278, 0.5020022278511405], 
             UndirectedEdge[97, 134] -> 
             RGBColor[
              0.2657406017726479, 0.3966405997633186, 0.9384449061917377], 
             UndirectedEdge[103, 119] -> 
             RGBColor[
              0.28052080371187027`, 0.4121755291203697, 0.939286616826827], 
             UndirectedEdge[3, 17] -> 
             RGBColor[
              0.3367736481857078, 0.4649602471368852, 0.9427222930937296], 
             UndirectedEdge[203, 270] -> 
             RGBColor[
              0.2439246691349402, 0.37371067135106817`, 0.9372025211018002], 
             UndirectedEdge[51, 141] -> 
             RGBColor[
              0.9462822846437602, 0.812940654644517, 0.4968966602614467], 
             UndirectedEdge[184, 275] -> 
             RGBColor[
              0.22510784132218828`, 0.35393299226407493`, 0.9361309305948662],
              UndirectedEdge[58, 109] -> 
             RGBColor[
              0.7350459204207711, 0.7923292470470489, 0.9749877366110247], 
             UndirectedEdge[179, 281] -> 
             RGBColor[
              0.9148614845826333, 0.6349726325663724, 0.4685681683997813], 
             UndirectedEdge[31, 154] -> 
             RGBColor[
              0.6800184039631393, 0.7495944813404151, 0.9689878978887183], 
             UndirectedEdge[122, 296] -> 
             RGBColor[
              0.6602141631347492, 0.7342053053149373, 0.9669578999698369], 
             UndirectedEdge[96, 290] -> 
             RGBColor[
              0.5091973143554127, 0.6111290483156775, 0.9548640237887529], 
             UndirectedEdge[122, 240] -> 
             RGBColor[
              0.8095631527614308, 0.8486792683221828, 0.8267426029487193], 
             UndirectedEdge[97, 144] -> 
             RGBColor[
              0.28659496025462, 0.4179160304983415, 0.9396561045432549], 
             UndirectedEdge[61, 247] -> 
             RGBColor[
              0.5729638190353659, 0.6641968658756336, 0.9595249571515402], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.5867492116924276, 0.675169261254928, 0.9607600670587673], 
             UndirectedEdge[45, 287] -> 
             RGBColor[
              0.899399401089056, 0.6245785965945915, 0.23718537302328563`], 
             UndirectedEdge[278, 290] -> 
             RGBColor[
              0.607930114483695, 0.6925840797342462, 0.9622776320149933], 
             UndirectedEdge[109, 110] -> 
             RGBColor[
              0.9570573175626281, 0.9656649471847494, 0.8794550171346109], 
             UndirectedEdge[56, 160] -> 
             RGBColor[
              0.5689561966042058, 0.6609432974446849, 0.9592094624333546], 
             UndirectedEdge[146, 292] -> 
             RGBColor[
              0.2367560409824719, 0.36617598864554746`, 0.9367942783335522], 
             UndirectedEdge[131, 139] -> 
             RGBColor[
              0.29015495986038786`, 0.4208144502573191, 0.9398897209981389], 
             UndirectedEdge[47, 74] -> 
             RGBColor[
              0.6411369333771564, 0.7195168172815674, 0.9649096076876572], 
             UndirectedEdge[46, 221] -> 
             RGBColor[
              0.2933757434234066, 0.4256868858074472, 0.9400186866262199], 
             UndirectedEdge[48, 74] -> 
             RGBColor[
              0.5259484891930979, 0.6249515173301565, 0.9561210914963576], 
             UndirectedEdge[90, 134] -> 
             RGBColor[
              0.3387736212750252, 0.46463798272782586`, 0.9429249564054306], 
             UndirectedEdge[1, 37] -> 
             RGBColor[
              0.5496127167377557, 0.6437072364180976, 0.9583493103043816], 
             UndirectedEdge[33, 295] -> 
             RGBColor[
              0.8759737184879801, 0.9039416817218939, 0.9880323493319954], 
             UndirectedEdge[28, 35] -> 
             RGBColor[
              0.2248219115083478, 0.35363246190073133`, 0.9361146473149633], 
             UndirectedEdge[21, 169] -> 
             RGBColor[
              0.33823987120783705`, 0.46593460012617627`, 0.9428265434669814],
              UndirectedEdge[100, 228] -> 
             RGBColor[
              0.8332617870229544, 0.6215832019337704, 0.5890075855789246], 
             UndirectedEdge[190, 250] -> 
             RGBColor[
              0.22535768471974588`, 0.35419559351589436`, 0.9361451588067469],
              UndirectedEdge[81, 180] -> 
             RGBColor[
              0.26493370488523493`, 0.3957924999744301, 0.9383989546076965], 
             UndirectedEdge[127, 141] -> 
             RGBColor[
              0.8658872706016187, 0.44359089015560293`, 0.2082267027178307], 
             UndirectedEdge[143, 185] -> 
             RGBColor[
              0.482410173529073, 0.5891453845161638, 0.9528206307321404], 
             UndirectedEdge[283, 295] -> 
             RGBColor[
              0.728003954304401, 0.7872192535932907, 0.973734730725687], 
             UndirectedEdge[26, 100] -> 
             RGBColor[
              0.9180076603888783, 0.6875620047068038, 0.5400502286834623], 
             UndirectedEdge[242, 294] -> 
             RGBColor[
              0.22516497885926012`, 0.35399304743826654`, 0.9361341844930751],
              UndirectedEdge[39, 228] -> 
             RGBColor[
              0.8419379772960242, 0.6739158098872126, 0.5967537548599042], 
             UndirectedEdge[39, 82] -> 
             RGBColor[
              0.9313046936732585, 0.7416283194518091, 0.4583415502549171], 
             UndirectedEdge[109, 258] -> 
             RGBColor[
              0.941467846616602, 0.9554926988601389, 0.9709728498600104], 
             UndirectedEdge[118, 199] -> 
             RGBColor[
              0.17892828448197629`, 0.3053953500719979, 0.9335010731493483], 
             UndirectedEdge[57, 115] -> 
             RGBColor[
              0.2343221600487206, 0.3636178254672108, 0.9366556724149793], 
             UndirectedEdge[96, 222] -> 
             RGBColor[
              0.4207992950730278, 0.5388969322298897, 0.948033936877215], 
             UndirectedEdge[6, 108] -> 
             RGBColor[
              0.32479673840417583`, 0.4554602283068521, 0.9419271416840078], 
             UndirectedEdge[1, 9] -> 
             RGBColor[
              0.46767615866135254`, 0.5777748250387542, 0.9514973709902432], 
             UndirectedEdge[180, 190] -> 
             RGBColor[
              0.23107912024585836`, 0.36020918501380295`, 0.9364709860958538],
              UndirectedEdge[144, 253] -> 
             RGBColor[
              0.30621743066907636`, 0.4385404910404173, 0.9407735752045145], 
             UndirectedEdge[53, 192] -> 
             RGBColor[
              0.8483576285442167, 0.36235245091138435`, 0.19353530461595575`],
              UndirectedEdge[85, 121] -> 
             RGBColor[
              0.9571178936575444, 0.9648142409538079, 0.8234596411130128], 
             UndirectedEdge[36, 278] -> 
             RGBColor[
              0.681251390228536, 0.7503140519946241, 0.9692773736229017], 
             UndirectedEdge[122, 207] -> 
             RGBColor[
              0.6848905103681076, 0.7534826553208219, 0.9694174076484823], 
             UndirectedEdge[226, 228] -> 
             RGBColor[
              0.4976351265701356, 0.5809234118204025, 0.9579150619705263], 
             UndirectedEdge[7, 143] -> 
             RGBColor[
              0.3957483991962868, 0.5171991053160931, 0.9464377159435866], 
             UndirectedEdge[133, 164] -> 
             RGBColor[
              0.36703566028493084`, 0.49232957401529565`, 0.9446081656098331],
              UndirectedEdge[7, 131] -> 
             RGBColor[
              0.359788981914124, 0.4860528654391481, 0.9441464136720313], 
             UndirectedEdge[111, 280] -> 
             RGBColor[
              0.2555363699026189, 0.38591530508224947`, 0.9378637902825477], 
             UndirectedEdge[135, 224] -> 
             RGBColor[
              0.9798102252026126, 0.9495170954171317, 0.5749562479700403], 
             UndirectedEdge[91, 102] -> 
             RGBColor[
              0.3289676178309032, 0.4560161547537128, 0.9423048264494448], 
             UndirectedEdge[200, 282] -> 
             RGBColor[
              0.9248264998510323, 0.7738160826625009, 0.5864939522963153], 
             UndirectedEdge[106, 194] -> 
             RGBColor[
              0.5862509789073218, 0.6747647734348481, 0.960720844348837], 
             UndirectedEdge[38, 259] -> 
             RGBColor[
              0.44110257276703263`, 0.5561854868751561, 0.949409740030642], 
             UndirectedEdge[36, 69] -> 
             RGBColor[
              0.8763046392583498, 0.8998097230462532, 0.7301395316538027], 
             UndirectedEdge[64, 153] -> 
             RGBColor[
              0.253568524812987, 0.38384697512446136`, 0.9377517244158591], 
             UndirectedEdge[159, 175] -> 
             RGBColor[
              0.2709524595475128, 0.4021185927355705, 0.9387417137817635], 
             UndirectedEdge[94, 200] -> 
             RGBColor[
              0.8739725410077492, 0.7339874771388775, 0.6066396220475212], 
             UndirectedEdge[88, 201] -> 
             RGBColor[
              0.41266709907445764`, 0.5304710926638055, 0.9478976499747094], 
             UndirectedEdge[121, 232] -> 
             RGBColor[
              0.9943533317427773, 0.9903306725005643, 0.626773191277452], 
             UndirectedEdge[140, 289] -> 
             RGBColor[
              0.3095286406957365, 0.4408775980939844, 0.9410040013062702], 
             UndirectedEdge[139, 244] -> 
             RGBColor[
              0.2489949569451404, 0.37903986531440326`, 0.9374912664917726], 
             UndirectedEdge[167, 174] -> 
             RGBColor[
              0.5731249742958058, 0.6609624837721939, 0.9611637427211077], 
             UndirectedEdge[185, 282] -> 
             RGBColor[
              0.7658636697865162, 0.8163200733980329, 0.9527715263482667], 
             UndirectedEdge[236, 249] -> 
             RGBColor[
              0.7208953090971567, 0.4244044295693752, 0.5644530380404611], 
             UndirectedEdge[137, 299] -> 
             RGBColor[
              0.9200253772401052, 0.6716173201462636, 0.46616820031546136`], 
             UndirectedEdge[201, 218] -> 
             RGBColor[
              0.2885778810548669, 0.4195006110479498, 0.9397873215672898], 
             UndirectedEdge[36, 109] -> 
             RGBColor[
              0.8403699639081523, 0.8760405078690783, 0.9845068533256267], 
             UndirectedEdge[4, 52] -> 
             RGBColor[
              0.6786643793088902, 0.3871223101534529, 0.5607452962818866], 
             UndirectedEdge[5, 191] -> 
             RGBColor[
              0.23242398209380136`, 0.36162272008515706`, 0.9365475739885493],
              UndirectedEdge[55, 134] -> 
             RGBColor[
              0.27534778812989436`, 0.40673836175558137`, 0.9389920212422243],
              UndirectedEdge[67, 69] -> 
             RGBColor[
              0.9526781701718614, 0.9602196098814508, 0.7375536853224871], 
             UndirectedEdge[232, 256] -> 
             RGBColor[
              0.9946722576480922, 0.9910128227636774, 0.6614863078884357], 
             UndirectedEdge[185, 237] -> 
             RGBColor[
              0.6034248054489583, 0.6889264668979879, 0.961922957584288], 
             UndirectedEdge[28, 211] -> 
             RGBColor[
              0.2328859592843117, 0.3621082874034291, 0.9365738829061148], 
             UndirectedEdge[85, 246] -> 
             RGBColor[
              0.759246790508393, 0.811987768878119, 0.9768800667488129], 
             UndirectedEdge[26, 127] -> 
             RGBColor[
              0.9093035421850235, 0.6206583380230588, 0.5317151552615555], 
             UndirectedEdge[91, 162] -> 
             RGBColor[
              0.27856959341816107`, 0.4101246833878033, 0.9391754982871572], 
             UndirectedEdge[112, 242] -> 
             RGBColor[
              0.24632291686669305`, 0.37623138177482907`, 0.937339097762234], 
             UndirectedEdge[85, 122] -> 
             RGBColor[
              0.7719092053781459, 0.8222676877046737, 0.9778768984313139], 
             UndirectedEdge[63, 131] -> 
             RGBColor[
              0.32467225096411007`, 0.4556365181084638, 0.9419088066284024], 
             UndirectedEdge[140, 222] -> 
             RGBColor[
              0.3821033463817397, 0.505380446388428, 0.94556826524409], 
             UndirectedEdge[121, 256] -> 
             RGBColor[
              0.9949290492403844, 0.9915620740139779, 0.6894364879754314], 
             UndirectedEdge[171, 198] -> 
             RGBColor[
              0.4413043319504303, 0.556360389684118, 0.9494225547381876], 
             UndirectedEdge[10, 117] -> 
             RGBColor[
              0.20745354842489078`, 0.3353772110821952, 0.935125544731551], 
             UndirectedEdge[18, 290] -> 
             RGBColor[
              0.7796647191738186, 0.8280942483803853, 0.9691424595790514], 
             UndirectedEdge[207, 240] -> 
             RGBColor[
              0.870260916353266, 0.8963751063904083, 0.8326021245961515], 
             UndirectedEdge[219, 264] -> 
             RGBColor[
              0.28444814998044265`, 0.4163034190567747, 0.9395102733868341], 
             UndirectedEdge[78, 118] -> 
             RGBColor[
              0.17948494456776543`, 0.30598043511645023`, 0.9335327741177293],
              UndirectedEdge[2, 208] -> 
             RGBColor[
              0.2583585282715436, 0.3888815724631647, 0.9380245080266488], 
             UndirectedEdge[34, 169] -> 
             RGBColor[
              0.3102621246711287, 0.4417016822785076, 0.9410438261974121], 
             UndirectedEdge[35, 275] -> 
             RGBColor[
              0.21950487592715945`, 0.34804392038537546`, 0.9358118500044639],
              UndirectedEdge[157, 284] -> 
             RGBColor[
              0.3008123283039969, 0.4300606298936609, 0.9405682387829533], 
             UndirectedEdge[30, 259] -> 
             RGBColor[
              0.46322962709906557`, 0.5751097053927338, 0.9508862795927249], 
             UndirectedEdge[62, 192] -> 
             RGBColor[
              0.9299174355595534, 0.7356028477535854, 0.4448740417030029], 
             UndirectedEdge[95, 245] -> 
             RGBColor[
              0.4565245648697137, 0.5688811135099974, 0.9505753636122101], 
             UndirectedEdge[129, 230] -> 
             RGBColor[
              0.2426308084736596, 0.3723507417605582, 0.9371288376512357], 
             UndirectedEdge[35, 92] -> 
             RGBColor[
              0.24366421330036392`, 0.37343691575507476`, 0.9371876885273311],
              UndirectedEdge[186, 279] -> 
             RGBColor[
              0.24438086405288187`, 0.3741901611342533, 0.9372285007274972], 
             UndirectedEdge[217, 233] -> 
             RGBColor[
              0.9005620992858752, 0.9194729557138646, 0.7896746116293041], 
             UndirectedEdge[28, 293] -> 
             RGBColor[
              0.21633697828784162`, 0.3447142591101412, 0.9356314429203892], 
             UndirectedEdge[24, 233] -> 
             RGBColor[
              0.9748626422338834, 0.9780993949460502, 0.7789636593832132], 
             UndirectedEdge[41, 229] -> 
             RGBColor[
              0.35168976097882576`, 0.47903772734367334`, 0.943630338475894], 
             UndirectedEdge[197, 214] -> 
             RGBColor[
              0.21169118846890916`, 0.33983123945035565`, 0.9353668720630313],
              UndirectedEdge[84, 144] -> 
             RGBColor[
              0.30816373722776935`, 0.4405861826365669, 0.9408844144837296], 
             UndirectedEdge[101, 205] -> 
             RGBColor[
              0.5380185348092877, 0.6358267098737893, 0.9567739363684693], 
             UndirectedEdge[7, 297] -> 
             RGBColor[
              0.5775728899214854, 0.6645401478372637, 0.9615635093646839], 
             UndirectedEdge[30, 47] -> 
             RGBColor[
              0.5531290988592262, 0.6480680925121483, 0.9579813085710855], 
             UndirectedEdge[140, 298] -> 
             RGBColor[
              0.3066630469664905, 0.4378656773954105, 0.9408408099826556], 
             UndirectedEdge[159, 252] -> 
             RGBColor[
              0.2739625179017606, 0.4052823549146075, 0.9389131321520556], 
             UndirectedEdge[26, 195] -> 
             RGBColor[
              0.9024893735730009, 0.5682816520833267, 0.52518989970318], 
             UndirectedEdge[43, 185] -> 
             RGBColor[
              0.4451220207260428, 0.5568482607152324, 0.9504446626081502], 
             UndirectedEdge[36, 95] -> 
             RGBColor[
              0.6241088885700935, 0.7039231949079366, 0.9647789065724686], 
             UndirectedEdge[6, 46] -> 
             RGBColor[
              0.29890559173213627`, 0.4314991069925552, 0.9403336033067247], 
             UndirectedEdge[148, 183] -> 
             RGBColor[
              0.2467014884994484, 0.37662928456368283`, 0.937360656856673], 
             UndirectedEdge[222, 261] -> 
             RGBColor[
              0.41838703187400994`, 0.5368075510907742, 0.9478802295992542], 
             UndirectedEdge[64, 145] -> 
             RGBColor[
              0.2514296244944172, 0.3815988552755316, 0.937629917206936], 
             UndirectedEdge[8, 247] -> 
             RGBColor[
              0.6154687668637716, 0.6985589182605833, 0.9629704988219563], 
             UndirectedEdge[122, 136] -> 
             RGBColor[
              0.8085502082780569, 0.8465126824966431, 0.7164898471021924], 
             UndirectedEdge[139, 206] -> 
             RGBColor[
              0.2460762386198535, 0.3759721072970965, 0.9373250498010044], 
             UndirectedEdge[65, 80] -> 
             RGBColor[
              0.27787319023653523`, 0.40939271948940265`, 0.9391358391561999],
              UndirectedEdge[171, 245] -> 
             RGBColor[
              0.4213779646314022, 0.5393981467165758, 0.9480708091897773], 
             UndirectedEdge[137, 232] -> 
             RGBColor[
              0.9198313733274753, 0.6705144142242014, 0.3950452840198946], 
             UndirectedEdge[64, 221] -> 
             RGBColor[
              0.26413437920159183`, 0.3949523580007457, 0.9383534341925093], 
             UndirectedEdge[140, 263] -> 
             RGBColor[
              0.2945287893227776, 0.42511180325549774`, 0.9401497819608717], 
             UndirectedEdge[200, 295] -> 
             RGBColor[
              0.8616403695892892, 0.7241541383976731, 0.6054633685285691], 
             UndirectedEdge[136, 232] -> 
             RGBColor[
              0.9935021049651632, 0.9885099844954769, 0.5341224096968956], 
             UndirectedEdge[45, 68] -> 
             RGBColor[
              0.8660950044608668, 0.48393636846669774`, 0.20994293256664392`],
              UndirectedEdge[224, 254] -> 
             RGBColor[
              0.9304233123934045, 0.7541309251793602, 0.28356918675006826`], 
             UndirectedEdge[148, 272] -> 
             RGBColor[
              0.23104689889957378`, 0.3601753183359065, 0.93646915113785], 
             UndirectedEdge[167, 185] -> 
             RGBColor[
              0.660998380157889, 0.7339582173045702, 0.9676238615993047], 
             UndirectedEdge[59, 137] -> 
             RGBColor[
              0.8391881810125934, 0.30222310839901756`, 0.1851599524353666], 
             UndirectedEdge[55, 97] -> 
             RGBColor[
              0.26708761639868417`, 0.39805639754094285`, 0.9385216166819608],
              UndirectedEdge[156, 202] -> 
             RGBColor[
              0.22791002753873152`, 0.3568782676465297, 0.9362905109544353], 
             UndirectedEdge[78, 176] -> 
             RGBColor[
              0.17949609924511575`, 0.30599215938959284`, 0.9335334093601024],
              UndirectedEdge[131, 143] -> 
             RGBColor[
              0.3607906299670138, 0.4869204426382663, 0.9442102378002388], 
             UndirectedEdge[230, 289] -> 
             RGBColor[
              0.27016772610159867`, 0.4012937881289406, 0.9386970243729278], 
             UndirectedEdge[35, 126] -> 
             RGBColor[
              0.2260848753293333, 0.35495991695311835`, 0.9361865712361809], 
             UndirectedEdge[147, 183] -> 
             RGBColor[
              0.24039105535964145`, 0.36999661922917565`, 0.9370012870248101],
              UndirectedEdge[66, 258] -> 
             RGBColor[
              0.9541114545413159, 0.9652969784492861, 0.9625615171988029], 
             UndirectedEdge[60, 232] -> 
             RGBColor[
              0.9600894947352094, 0.8672149974535253, 0.4291027093633025], 
             UndirectedEdge[39, 127] -> 
             RGBColor[
              0.8501524031963347, 0.3721425322398584, 0.1950971436579678], 
             UndirectedEdge[113, 258] -> 
             RGBColor[
              0.9605881616295711, 0.9701272959910724, 0.9515981414941335], 
             UndirectedEdge[45, 223] -> 
             RGBColor[
              0.872589282408941, 0.5134253678517513, 0.21536191727583626`], 
             UndirectedEdge[40, 80] -> 
             RGBColor[
              0.25252112623098183`, 0.38274609280586824`, 0.9376920766161012],
              UndirectedEdge[18, 198] -> 
             RGBColor[
              0.7053280385373079, 0.7677443822103661, 0.9632904037751118], 
             UndirectedEdge[13, 58] -> 
             RGBColor[
              0.4275257850964924, 0.5418851588163979, 0.949188660514906], 
             UndirectedEdge[16, 195] -> 
             RGBColor[
              0.9063070598041875, 0.5682974877338114, 0.34831639298626615`], 
             UndirectedEdge[17, 90] -> 
             RGBColor[
              0.3498844311553243, 0.4763161483780546, 0.9435577005911434], 
             UndirectedEdge[8, 273] -> 
             RGBColor[
              0.6348421879085798, 0.7142871342274307, 0.9644956454937833], 
             UndirectedEdge[85, 256] -> 
             RGBColor[
              0.9574368195628593, 0.965496391216921, 0.8581727577239964], 
             UndirectedEdge[149, 227] -> 
             RGBColor[
              0.27685707898321577`, 0.40832472213698934`, 0.9390779731235251],
              UndirectedEdge[182, 208] -> 
             RGBColor[
              0.2965714316502459, 0.42904575675219153`, 0.9402006763431414], 
             UndirectedEdge[82, 100] -> 
             RGBColor[
              0.9226285034001888, 0.6892957114983669, 0.45059538097393753`], 
             UndirectedEdge[227, 264] -> 
             RGBColor[
              0.2772132461146813, 0.4086990763744601, 0.9390982563147601], 
             UndirectedEdge[74, 259] -> 
             RGBColor[
              0.5512374616169957, 0.646558430162153, 0.9578145787092965], 
             UndirectedEdge[96, 105] -> 
             RGBColor[
              0.3473181215020726, 0.473441328714978, 0.9434180509343462], 
             UndirectedEdge[60, 100] -> 
             RGBColor[
              0.8881313902235266, 0.565681082313474, 0.22753422766752193`], 
             UndirectedEdge[73, 87] -> 
             RGBColor[
              0.3025587103322468, 0.4334652095438001, 0.9406102430960075], 
             UndirectedEdge[68, 223] -> 
             RGBColor[
              0.880860495472638, 0.5518971603270344, 0.22229941585693147`], 
             UndirectedEdge[162, 191] -> 
             RGBColor[
              0.26420786908525307`, 0.39502960052800135`, 0.9383576193326653],
              UndirectedEdge[87, 149] -> 
             RGBColor[
              0.2850281329082009, 0.41691301788689017`, 0.939543302556562], 
             UndirectedEdge[60, 256] -> 
             RGBColor[
              0.9606652122328164, 0.8684463989669389, 0.49176600606128196`], 
             UndirectedEdge[145, 169] -> 
             RGBColor[
              0.28111445342614677`, 0.4127994926096401, 0.939320424299829], 
             UndirectedEdge[144, 235] -> 
             RGBColor[
              0.27887432985742466`, 0.4098011584346488, 0.9392164260637837], 
             UndirectedEdge[36, 88] -> 
             RGBColor[
              0.6318962145275521, 0.7102452969352381, 0.9653919533977545], 
             UndirectedEdge[38, 123] -> 
             RGBColor[
              0.4270824703910924, 0.5443391028888234, 0.9484342952524883], 
             UndirectedEdge[183, 244] -> 
             RGBColor[
              0.24855034907625476`, 0.37857255425443737`, 0.937465946731378], 
             UndirectedEdge[2, 32] -> 
             RGBColor[
              0.24350738500413596`, 0.3732720792722509, 0.9371787573878676], 
             UndirectedEdge[106, 151] -> 
             RGBColor[
              0.5499711557200619, 0.645038448022178, 0.9579401200370031], 
             UndirectedEdge[164, 277] -> 
             RGBColor[
              0.36650966152605724`, 0.4918739803278257, 0.94457464943404], 
             UndirectedEdge[296, 299] -> 
             RGBColor[
              0.8453600637344856, 0.8773055132358333, 0.8557133788601069], 
             UndirectedEdge[75, 174] -> 
             RGBColor[
              0.5614179437120186, 0.6518168625034114, 0.9599968953209368], 
             UndirectedEdge[31, 66] -> 
             RGBColor[
              0.7826462994682315, 0.8305130082182347, 0.9693283290234715], 
             UndirectedEdge[2, 268] -> 
             RGBColor[
              0.2466368287086141, 0.37656132302384837`, 0.9373569745772405], 
             UndirectedEdge[46, 264] -> 
             RGBColor[
              0.29339971487327476`, 0.42571208132113636`, 0.9400200517648274],
              UndirectedEdge[71, 160] -> 
             RGBColor[
              0.6099082730566356, 0.6941900379787878, 0.9624333599040888], 
             UndirectedEdge[50, 114] -> 
             RGBColor[
              0.32843011888336315`, 0.4584906115476223, 0.9421629292736595], 
             UndirectedEdge[126, 197] -> 
             RGBColor[
              0.21821940668747852`, 0.34669281071101354`, 0.9357386444329454],
              UndirectedEdge[265, 269] -> 
             RGBColor[
              0.2247455605611441, 0.35355221221429056`, 0.9361102992414712], 
             UndirectedEdge[144, 257] -> 
             RGBColor[
              0.3535074058070181, 0.4806120799363681, 0.9437461571970662], 
             UndirectedEdge[86, 107] -> 
             RGBColor[
              0.9045073081884096, 0.5951795926664958, 0.26859915666912515`], 
             UndirectedEdge[149, 245] -> 
             RGBColor[
              0.3591757955739624, 0.4841536676462995, 0.9441574343329895], 
             UndirectedEdge[143, 283] -> 
             RGBColor[
              0.5077365883087008, 0.6097065089762495, 0.9548144188773069], 
             UndirectedEdge[66, 154] -> 
             RGBColor[
              0.8438279787518632, 0.8786689323302527, 0.9751799865903525], 
             UndirectedEdge[57, 159] -> 
             RGBColor[
              0.24722335585304894`, 0.3771778002406183, 0.937390376430427], 
             UndirectedEdge[7, 167] -> 
             RGBColor[
              0.5743366058251028, 0.6620119381044995, 0.9612409468107508], 
             UndirectedEdge[57, 89] -> 
             RGBColor[
              0.26259271630004477`, 0.3933319725441461, 0.9382656387709521], 
             UndirectedEdge[122, 256] -> 
             RGBColor[
              0.8097203609609858, 0.8490155207648438, 0.8438537452937325], 
             UndirectedEdge[39, 232] -> 
             RGBColor[
              0.9308146259118721, 0.7405801140636548, 0.40500069877565514`], 
             UndirectedEdge[72, 286] -> 
             RGBColor[
              0.6054217047226151, 0.6904029000986035, 0.9621791200575058], 
             UndirectedEdge[71, 299] -> 
             RGBColor[
              0.812040550004389, 0.8510805514465378, 0.8525260685636215], 
             UndirectedEdge[90, 158] -> 
             RGBColor[
              0.4035892626740157, 0.5239904671672448, 0.9469373288309841], 
             UndirectedEdge[52, 236] -> 
             RGBColor[
              0.7204593344779664, 0.42105333760098257`, 0.5640355482527617], 
             UndirectedEdge[17, 134] -> 
             RGBColor[
              0.2851115833841571, 0.4170007296281859, 0.9395480549377139], 
             UndirectedEdge[54, 72] -> 
             RGBColor[
              0.534606977221836, 0.6319372303906756, 0.9568737438527076], 
             UndirectedEdge[170, 192] -> 
             RGBColor[
              0.8434397887079927, 0.3245517789190093, 0.188825975634882], 
             UndirectedEdge[140, 198] -> 
             RGBColor[
              0.3961646850276139, 0.5172626963041967, 0.9465462963516883], 
             UndirectedEdge[19, 89] -> 
             RGBColor[
              0.28469980544749635`, 0.41656792490852634`, 0.9395246047933918],
              UndirectedEdge[239, 295] -> 
             RGBColor[
              0.6242095261484855, 0.7018088738432534, 0.9658801269946564], 
             UndirectedEdge[51, 69] -> 
             RGBColor[
              0.9933000659558078, 0.9895615584823135, 0.6199821278730931], 
             UndirectedEdge[186, 269] -> 
             RGBColor[
              0.2284972047762287, 0.3574954281523263, 0.93632394982946], 
             UndirectedEdge[37, 282] -> 
             RGBColor[
              0.8221799053423591, 0.8614527527728091, 0.9576065400232527], 
             UndirectedEdge[1, 239] -> 
             RGBColor[
              0.4148284678056251, 0.5337253017533699, 0.9476534810435313], 
             UndirectedEdge[59, 200] -> 
             RGBColor[
              0.8594030577293614, 0.41420745732297415`, 0.20281846065499215`],
              UndirectedEdge[145, 221] -> 
             RGBColor[
              0.2819086057959276, 0.4136341971024482, 0.9393656501024449], 
             UndirectedEdge[75, 297] -> 
             RGBColor[
              0.7454557140194038, 0.8010749365560057, 0.9752637169598848], 
             UndirectedEdge[142, 185] -> 
             RGBColor[
              0.6135470246958941, 0.696888857774001, 0.9628943539449815], 
             UndirectedEdge[36, 258] -> 
             RGBColor[
              0.8606691521172266, 0.8915543066994391, 0.9631366201381162], 
             UndirectedEdge[13, 289] -> 
             RGBColor[
              0.2985558278706446, 0.4311314829978179, 0.940313684772242], 
             UndirectedEdge[53, 170] -> 
             RGBColor[
              0.8268112796846933, 0.20708882120003286`, 0.1733078177460588], 
             UndirectedEdge[130, 226] -> 
             RGBColor[
              0.178927005110741, 0.3053940053717128, 0.9335010002910491], 
             UndirectedEdge[224, 249] -> 
             RGBColor[
              0.8940523406864429, 0.5263405979795888, 0.25076760006070237`], 
             UndirectedEdge[234, 271] -> 
             RGBColor[
              0.8973919728354314, 0.5348865558223752, 0.26558699931478663`], 
             UndirectedEdge[78, 266] -> 
             RGBColor[
              0.21383713709575333`, 0.3420867675181703, 0.9354890806626834], 
             UndirectedEdge[127, 232] -> 
             RGBColor[
              0.9134343174349477, 0.6213438394264674, 0.3889194560727688], 
             UndirectedEdge[57, 292] -> 
             RGBColor[
              0.2450572419916986, 0.37490107723278787`, 0.9372670194505013], 
             UndirectedEdge[52, 107] -> 
             RGBColor[
              0.8259275201506884, 0.20029585815577397`, 0.17246152861823205`],
              UndirectedEdge[26, 130] -> 
             RGBColor[
              0.5823809948253185, 0.6469022092217233, 0.9089577047840149], 
             UndirectedEdge[51, 58] -> 
             RGBColor[
              0.7712426526188537, 0.8181426903224094, 0.8569941031084208], 
             UndirectedEdge[192, 195] -> 
             RGBColor[
              0.8420649475314406, 0.3139841471767838, 0.18750942617155456`], 
             UndirectedEdge[118, 266] -> 
             RGBColor[
              0.21328176149194045`, 0.3415030325457159, 0.9354574528436509], 
             UndirectedEdge[171, 289] -> 
             RGBColor[
              0.35466828761855285`, 0.4799752914739057, 0.9438802596927696], 
             UndirectedEdge[1, 283] -> 
             RGBColor[
              0.5186228959615405, 0.619135681503407, 0.955508084774562], 
             UndirectedEdge[44, 59] -> 
             RGBColor[
              0.8989327098919131, 0.5734920759622608, 0.24889953887676536`], 
             UndirectedEdge[62, 127] -> 
             RGBColor[
              0.9138104141355006, 0.6221482722397406, 0.4298552609281541], 
             UndirectedEdge[46, 219] -> 
             RGBColor[
              0.2831865614508789, 0.4149774095228705, 0.9394384277864284], 
             UndirectedEdge[55, 252] -> 
             RGBColor[
              0.2886130512396545, 0.4206809943501981, 0.9397474583521269], 
             UndirectedEdge[55, 144] -> 
             RGBColor[
              0.2962021466118664, 0.42801379249060423`, 0.9402032195937415], 
             UndirectedEdge[160, 296] -> 
             RGBColor[
              0.6432277867867322, 0.7204149997680831, 0.9656206702005743], 
             UndirectedEdge[154, 179] -> 
             RGBColor[
              0.8674233288276321, 0.8946955574709121, 0.8648978949263142], 
             UndirectedEdge[6, 145] -> 
             RGBColor[
              0.2874384541046572, 0.41944641828755624`, 0.9396805667829495], 
             UndirectedEdge[132, 243] -> 
             RGBColor[
              0.21243933131542342`, 0.34061758501703826`, 0.935409477691362], 
             UndirectedEdge[53, 59] -> 
             RGBColor[
              0.8322696375208192, 0.249044151396152, 0.17853474737426642`], 
             UndirectedEdge[4, 228] -> 
             RGBColor[
              0.6779819914219037, 0.7467901325313183, 0.9696145955916023], 
             UndirectedEdge[71, 98] -> 
             RGBColor[
              0.5262018737865255, 0.625404972246536, 0.9560725859325541], 
             UndirectedEdge[201, 259] -> 
             RGBColor[
              0.3926869440225089, 0.5142503026969059, 0.9463247389793005], 
             UndirectedEdge[34, 187] -> 
             RGBColor[
              0.34571434459052375`, 0.47386212200128636`, 0.9432495902274847],
              UndirectedEdge[18, 260] -> 
             RGBColor[
              0.8977772500782942, 0.9210512580678571, 0.980544009200409], 
             UndirectedEdge[263, 289] -> 
             RGBColor[
              0.27598341660935993`, 0.40740644758867306`, 0.9390282193438018],
              UndirectedEdge[173, 209] -> 
             RGBColor[
              0.2611649721580388, 0.3918313229266909, 0.938184330854223], 
             UndirectedEdge[4, 199] -> 
             RGBColor[
              0.3592738699625091, 0.4712607260826286, 0.9452005339121252], 
             UndirectedEdge[253, 292] -> 
             RGBColor[
              0.26989343961389634`, 0.40100549563959764`, 0.9386814041632237],
              UndirectedEdge[128, 209] -> 
             RGBColor[
              0.25220846656924684`, 0.38241746767761725`, 0.9376742711109041],
              UndirectedEdge[44, 137] -> 
             RGBColor[
              0.9053107353837854, 0.6225163747613823, 0.25500714329073165`], 
             UndirectedEdge[129, 263] -> 
             RGBColor[
              0.24844649898142085`, 0.37846340122029065`, 0.9374600326221096],
              UndirectedEdge[73, 289] -> 
             RGBColor[
              0.309996695985159, 0.44128300406053933`, 0.9410338253754271], 
             UndirectedEdge[128, 276] -> 
             RGBColor[
              0.235521079118485, 0.3648779654253926, 0.9367239490823606], 
             UndirectedEdge[96, 196] -> 
             RGBColor[
              0.34319916551880214`, 0.4691120448196677, 0.9431834824845483], 
             UndirectedEdge[24, 224] -> 
             RGBColor[
              0.9625807494214099, 0.9376482057938698, 0.6480446128648567], 
             UndirectedEdge[88, 278] -> 
             RGBColor[
              0.553576335347311, 0.6484572332214837, 0.9579987034169237], 
             UndirectedEdge[158, 253] -> 
             RGBColor[
              0.35017871358609476`, 0.47661754474481344`, 0.9435747492785509],
              UndirectedEdge[67, 110] -> 
             RGBColor[
              0.9526321539767644, 0.9621364418592473, 0.8790329410814011], 
             UndirectedEdge[155, 275] -> 
             RGBColor[
              0.21254067958734837`, 0.340724108476683, 0.9354152493255168], 
             UndirectedEdge[101, 108] -> 
             RGBColor[
              0.44525533808141193`, 0.5575469670447641, 0.9502920083081179], 
             UndirectedEdge[102, 210] -> 
             RGBColor[
              0.3819399405336581, 0.5052389124558365, 0.9455578531679444], 
             UndirectedEdge[176, 199] -> 
             RGBColor[
              0.17893943915932659`, 0.3054070743451405, 0.9335017083917216], 
             UndirectedEdge[62, 226] -> 
             RGBColor[
              0.5868878718865363, 0.6483921488101179, 0.8070978107416625], 
             UndirectedEdge[69, 113] -> 
             RGBColor[
              0.9762236487706943, 0.9783827123378863, 0.71860105300982], 
             UndirectedEdge[51, 258] -> 
             RGBColor[
              0.9776645788146846, 0.9813061421354996, 0.8529792163574066], 
             UndirectedEdge[30, 74] -> 
             RGBColor[
              0.5502062391736314, 0.6457212373265883, 0.9577333971010626], 
             UndirectedEdge[118, 228] -> 
             RGBColor[
              0.49763640594137093`, 0.5809247565206876, 0.9579151348288255], 
             UndirectedEdge[71, 121] -> 
             RGBColor[
              0.8121033376840514, 0.8505268967747761, 0.8093533323550504], 
             UndirectedEdge[1, 20] -> 
             RGBColor[
              0.6422142592503285, 0.7164194344925677, 0.9674804697406698], 
             UndirectedEdge[126, 293] -> 
             RGBColor[
              0.21759994210882713`, 0.34604171416252816`, 0.9357033668416068],
              UndirectedEdge[112, 159] -> 
             RGBColor[
              0.24980358255219737`, 0.3798897820972448, 0.9375373165238401], 
             UndirectedEdge[17, 159] -> 
             RGBColor[
              0.2718080646722995, 0.4030178879702195, 0.9387904392278659], 
             UndirectedEdge[139, 172] -> 
             RGBColor[
              0.26248705403553485`, 0.3932209148047717, 0.9382596214613016], 
             UndirectedEdge[47, 233] -> 
             RGBColor[
              0.8190741460647206, 0.8558139473261162, 0.781552654000438], 
             UndirectedEdge[98, 182] -> 
             RGBColor[
              0.3649951509133196, 0.4904176871542194, 0.9444834370172861], 
             UndirectedEdge[84, 159] -> 
             RGBColor[
              0.27400586003393973`, 0.4053279102435776, 0.9389156004223643], 
             UndirectedEdge[118, 176] -> 
             RGBColor[
              0.17894072364130287`, 0.30540842441713845`, 0.9335017815410699],
              UndirectedEdge[18, 278] -> 
             RGBColor[
              0.7746661157384185, 0.8240361569270088, 0.968748951206129], 
             UndirectedEdge[155, 197] -> 
             RGBColor[
              0.21140151230331092`, 0.3395267714337822, 0.9353503754339378], 
             UndirectedEdge[72, 215] -> 
             RGBColor[
              0.8234553846620669, 0.8600796725778928, 0.8483727211925696], 
             UndirectedEdge[162, 239] -> 
             RGBColor[
              0.34783050852175984`, 0.47345580113907954`, 0.9434664197100019],
              UndirectedEdge[139, 272] -> 
             RGBColor[
              0.23937950956716447`, 0.3689334204655748, 0.9369436809883765], 
             UndirectedEdge[9, 75] -> 
             RGBColor[
              0.6236710270535416, 0.7040128640312203, 0.9644400885599815], 
             UndirectedEdge[18, 254] -> 
             RGBColor[
              0.918861315886804, 0.779473166025562, 0.6033212282319205], 
             UndirectedEdge[25, 244] -> 
             RGBColor[
              0.2471607788887478, 0.37711202788352904`, 0.9373868127648843], 
             UndirectedEdge[30, 257] -> 
             RGBColor[
              0.42675186290096767`, 0.5438116234909512, 0.9484798524617939], 
             UndirectedEdge[29, 270] -> 
             RGBColor[
              0.2355391750470839, 0.3648969853936982, 0.9367249796187237], 
             UndirectedEdge[73, 298] -> 
             RGBColor[
              0.307131102255913, 0.43827108336196546`, 0.9408706340518126], 
             UndirectedEdge[73, 96] -> 
             RGBColor[
              0.3672380173898648, 0.4925048455688256, 0.9446210596256222], 
             UndirectedEdge[108, 205] -> 
             RGBColor[
              0.436683616415666, 0.5505880572448512, 0.9496172109793394], 
             UndirectedEdge[9, 43] -> 
             RGBColor[
              0.41950169820548255`, 0.5360485287106651, 0.948427736968998], 
             UndirectedEdge[151, 251] -> 
             RGBColor[
              0.36499365332834144`, 0.4885238594535514, 0.944552636407374], 
             UndirectedEdge[209, 279] -> 
             RGBColor[
              0.2619744678088157, 0.39268215418064606`, 0.9382304304339932], 
             UndirectedEdge[53, 68] -> 
             RGBColor[
              0.8530476685227406, 0.3836488270671944, 0.19744878893743584`], 
             UndirectedEdge[282, 295] -> 
             RGBColor[
              0.9004709095023198, 0.9227541160141217, 0.9653727475363004], 
             UndirectedEdge[35, 197] -> 
             RGBColor[
              0.218365708643122, 0.3468465833424746, 0.9357469761128849], 
             UndirectedEdge[116, 168] -> 
             RGBColor[
              0.35414043439259346`, 0.4811603774802517, 0.9437864932187738], 
             UndirectedEdge[27, 152] -> 
             RGBColor[
              0.2558672975304459, 0.3862631310011191, 0.9378826361213889], 
             UndirectedEdge[114, 231] -> 
             RGBColor[
              0.37476526938347776`, 0.4986237900384425, 0.945115364090962], 
             UndirectedEdge[83, 155] -> 
             RGBColor[
              0.21429563561346426`, 0.34256867853076955`, 0.9355151914749793],
              UndirectedEdge[62, 199] -> 
             RGBColor[
              0.5868878667757954, 0.648392143438405, 0.8070978104506135], 
             UndirectedEdge[96, 278] -> 
             RGBColor[
              0.5041987109200126, 0.6070709568623011, 0.9544705154158305], 
             UndirectedEdge[2, 178] -> 
             RGBColor[
              0.25390682555337085`, 0.3842025506521106, 0.9377709901425528], 
             UndirectedEdge[6, 213] -> 
             RGBColor[
              0.3667758904705204, 0.4918204598931879, 0.9446020161329686], 
             UndirectedEdge[79, 93] -> 
             RGBColor[
              0.46307011169266854`, 0.5733948534802826, 0.9513117589171669], 
             UndirectedEdge[270, 272] -> 
             RGBColor[
              0.22576785330449248`, 0.35462670670465335`, 0.9361685173008583],
              UndirectedEdge[161, 186] -> 
             RGBColor[
              0.22312007554742067`, 0.3518437244031648, 0.9360177302746292], 
             UndirectedEdge[189, 275] -> 
             RGBColor[
              0.22231351200262228`, 0.3509959749784993, 0.9359717976739568], 
             UndirectedEdge[260, 261] -> 
             RGBColor[
              0.6248975820608704, 0.7019966768640338, 0.9661118661321497], 
             UndirectedEdge[195, 200] -> 
             RGBColor[
              0.8525698587166832, 0.36168449538462955`, 0.19627498156345707`],
              UndirectedEdge[66, 110] -> 
             RGBColor[
              0.969700925487342, 0.9754692267738965, 0.8710436844734033], 
             UndirectedEdge[63, 172] -> 
             RGBColor[
              0.29700434513925705`, 0.4280429826559164, 0.940278707091565], 
             UndirectedEdge[4, 236] -> 
             RGBColor[
              0.5814156950940945, 0.671058479612787, 0.9601903197951254], 
             UndirectedEdge[143, 167] -> 
             RGBColor[
              0.5753382538779925, 0.6628795153036178, 0.9613047709389584], 
             UndirectedEdge[135, 249] -> 
             RGBColor[
              0.9043378524473125, 0.5669958495159765, 0.4896141522242598], 
             UndirectedEdge[135, 288] -> 
             RGBColor[
              0.9259984255937815, 0.7279896925534243, 0.5101410217698862], 
             UndirectedEdge[83, 214] -> 
             RGBColor[
              0.21458531177906248`, 0.342873146547343, 0.9355316881040727], 
             UndirectedEdge[36, 290] -> 
             RGBColor[
              0.6862499936639361, 0.7543721434480005, 0.9696708819958241], 
             UndirectedEdge[79, 119] -> 
             RGBColor[
              0.3385777508483834, 0.465228690511853, 0.9428846351776731], 
             UndirectedEdge[145, 264] -> 
             RGBColor[
              0.28193257724579573`, 0.4136593926161374, 0.9393670152410523], 
             UndirectedEdge[54, 238] -> 
             RGBColor[
              0.34796050319161576`, 0.47301253149465217`, 0.9434950557775005],
              UndirectedEdge[177, 273] -> 
             RGBColor[
              0.5185213619952923, 0.6190718502597115, 0.9554949527990644], 
             UndirectedEdge[98, 208] -> 
             RGBColor[
              0.3543834762769441, 0.47926414429235664`, 0.9438791178453103], 
             UndirectedEdge[125, 170] -> 
             RGBColor[
              0.9072593029227105, 0.5779612249611302, 0.303635751806013], 
             UndirectedEdge[22, 217] -> 
             RGBColor[
              0.812207338591908, 0.8532218130031827, 0.981916895067874], 
             UndirectedEdge[78, 236] -> 
             RGBColor[
              0.4016254852173745, 0.5057768385746106, 0.9485224868513811], 
             UndirectedEdge[86, 240] -> 
             RGBColor[
              0.984900576757397, 0.9592281782774306, 0.5233965503688487], 
             UndirectedEdge[59, 170] -> 
             RGBColor[
              0.8273517976845952, 0.21124347940377694`, 0.17382541839319265`],
              UndirectedEdge[95, 109] -> 
             RGBColor[
              0.7049075830694689, 0.7678615870686365, 0.9726151362943627], 
             UndirectedEdge[30, 252] -> 
             RGBColor[
              0.38136485218953986`, 0.5037401708621798, 0.9456156414781487], 
             UndirectedEdge[116, 119] -> 
             RGBColor[
              0.30231628529617693`, 0.4338208316047836, 0.9405740866574415], 
             UndirectedEdge[6, 231] -> 
             RGBColor[
              0.3753962033450712, 0.49928694163560083`, 0.9451512948466916], 
             UndirectedEdge[214, 275] -> 
             RGBColor[
              0.21283035575294662`, 0.34102857649325646`, 0.9354317459546102],
              UndirectedEdge[157, 257] -> 
             RGBColor[
              0.3686428791962128, 0.49372166625507674`, 0.944710576177652], 
             UndirectedEdge[128, 173] -> 
             RGBColor[
              0.24821711809960986`, 0.3782223073699194, 0.9374469697202291], 
             UndirectedEdge[14, 113] -> 
             RGBColor[
              0.8910534941556458, 0.5723590692569638, 0.5614811576965728], 
             UndirectedEdge[213, 231] -> 
             RGBColor[
              0.43649903669503015`, 0.5524952593309104, 0.9490343105306326], 
             UndirectedEdge[29, 148] -> 
             RGBColor[
              0.2408182206421652, 0.3704455970249514, 0.9370256134557156], 
             UndirectedEdge[109, 154] -> 
             RGBColor[
              0.8311843708271494, 0.8688646527411055, 0.9835913192515602], 
             UndirectedEdge[74, 123] -> 
             RGBColor[
              0.5372173592410554, 0.6347120461758202, 0.9568391339311428], 
             UndirectedEdge[189, 216] -> 
             RGBColor[
              0.24534319825395978`, 0.3752016353950986, 0.9372833042366027], 
             UndirectedEdge[29, 162] -> 
             RGBColor[
              0.2636748497853562, 0.39446936344843425`, 0.9383272646720675], 
             UndirectedEdge[73, 140] -> 
             RGBColor[
              0.3285420686985767, 0.45898835972736407`, 0.9421553879924971], 
             UndirectedEdge[9, 295] -> 
             RGBColor[
              0.677057217004213, 0.7458583971286377, 0.9697240169413682], 
             UndirectedEdge[169, 221] -> 
             RGBColor[
              0.2938192081333214, 0.4261529953348542, 0.9400439412854023], 
             UndirectedEdge[22, 61] -> 
             RGBColor[
              0.6921091843567939, 0.7582433580431021, 0.9707375877325777], 
             UndirectedEdge[11, 143] -> 
             RGBColor[
              0.3701279239778581, 0.49500793740441695`, 0.9448052019179649], 
             UndirectedEdge[100, 299] -> 
             RGBColor[
              0.9223324395514323, 0.6893504120322749, 0.46837744579024243`], 
             UndirectedEdge[181, 232] -> 
             RGBColor[
              0.8539568089581072, 0.8830700073511788, 0.7854666422842203], 
             UndirectedEdge[49, 292] -> 
             RGBColor[
              0.23980801296623738`, 0.36938380470668514`, 0.9369680836230397],
              UndirectedEdge[4, 39] -> 
             RGBColor[
              0.7035767257991387, 0.5642531295211515, 0.5840392270925523], 
             UndirectedEdge[33, 75] -> 
             RGBColor[
              0.8225875285373088, 0.8620961486244765, 0.9827484209506085], 
             UndirectedEdge[223, 271] -> 
             RGBColor[
              0.9324098595457874, 0.7585161356784191, 0.29733719959784854`], 
             UndirectedEdge[21, 34] -> 
             RGBColor[
              0.3554769401154252, 0.48231799156263766`, 0.943871654181607], 
             UndirectedEdge[51, 165] -> 
             RGBColor[
              0.986911243979133, 0.9683407522697562, 0.5670857457477134], 
             UndirectedEdge[36, 138] -> 
             RGBColor[
              0.7331275863556836, 0.791444109527867, 0.9740349644072682], 
             UndirectedEdge[50, 205] -> 
             RGBColor[
              0.44094793085644673`, 0.5542815920827796, 0.9498889293247207], 
             UndirectedEdge[237, 283] -> 
             RGBColor[
              0.6287512202285861, 0.7094875913580734, 0.9639167457294545], 
             UndirectedEdge[140, 245] -> 
             RGBColor[
              0.37623831770858585`, 0.5003004533366545, 0.945194550803278], 
             UndirectedEdge[19, 49] -> 
             RGBColor[
              0.26391083574794544`, 0.39471739965748975`, 0.9383407037235271],
              UndirectedEdge[235, 292] -> 
             RGBColor[
              0.24255033880224458`, 0.3722661630338292, 0.9371242550224929], 
             UndirectedEdge[15, 115] -> 
             RGBColor[
              0.230257062183032, 0.3593451498682808, 0.9364241711053016], 
             UndirectedEdge[69, 110] -> 
             RGBColor[
              0.9929919929128255, 0.9894341623619243, 0.625087695462787], 
             UndirectedEdge[34, 50] -> 
             RGBColor[
              0.33997412107403424`, 0.46889022890332593`, 0.9428838282608942],
              UndirectedEdge[126, 275] -> 
             RGBColor[
              0.21935857397151598`, 0.34789014775391436`, 0.9358035183245244],
              UndirectedEdge[59, 225] -> 
             RGBColor[
              0.8968865048957325, 0.5665897460383628, 0.24095041885999358`], 
             UndirectedEdge[82, 228] -> 
             RGBColor[
              0.9057099592960236, 0.9241653224619759, 0.8439169187539672], 
             UndirectedEdge[19, 280] -> 
             RGBColor[
              0.2796627567223554, 0.4112736673310683, 0.939237752320141], 
             UndirectedEdge[194, 283] -> 
             RGBColor[
              0.5672781592829315, 0.6595809911525545, 0.9590773611885706], 
             UndirectedEdge[63, 283] -> 
             RGBColor[
              0.4716182093057971, 0.5784225844464469, 0.9525129877054703], 
             UndirectedEdge[36, 245] -> 
             RGBColor[
              0.5919869457083973, 0.6770600343104392, 0.9624670806434741], 
             UndirectedEdge[3, 55] -> 
             RGBColor[
              0.327009852931445, 0.45469787926428074`, 0.9421662593982401], 
             UndirectedEdge[137, 192] -> 
             RGBColor[
              0.8552761720359909, 0.4155314079142499, 0.20016050967705595`], 
             UndirectedEdge[54, 251] -> 
             RGBColor[
              0.3520600889143901, 0.4773214560180356, 0.9437285211196189], 
             UndirectedEdge[252, 292] -> 
             RGBColor[
              0.2717964040404102, 0.4030056319067771, 0.9387897751721301], 
             UndirectedEdge[100, 121] -> 
             RGBColor[
              0.9223952272310946, 0.6887967573605129, 0.4252047095816714], 
             UndirectedEdge[142, 239] -> 
             RGBColor[
              0.5350790113196064, 0.6320396024840493, 0.9570335383591173], 
             UndirectedEdge[85, 299] -> 
             RGBColor[
              0.9570551059778822, 0.9653678956255696, 0.8666323773215838], 
             UndirectedEdge[120, 130] -> 
             RGBColor[
              0.18442078734008566`, 0.31116831882066576`, 0.9338138630616879],
              UndirectedEdge[9, 297] -> 
             RGBColor[
              0.6386143417337113, 0.7156866950327669, 0.9659294985140855], 
             UndirectedEdge[237, 239] -> 
             RGBColor[
              0.5249567920726707, 0.6240772116080362, 0.9560621419984239], 
             UndirectedEdge[169, 213] -> 
             RGBColor[
              0.36045188979201, 0.48517353421527176`, 0.944241873649848], 
             UndirectedEdge[46, 50] -> 
             RGBColor[
              0.32229358745653136`, 0.4520407279394575, 0.9418134628870861], 
             UndirectedEdge[105, 171] -> 
             RGBColor[
              0.3537618197336009, 0.4790225362534377, 0.9438286376877205], 
             UndirectedEdge[34, 114] -> 
             RGBColor[
              0.31595519138804573`, 0.44768545635926527`, 0.9413680379248031],
              UndirectedEdge[60, 240] -> 
             RGBColor[
              0.9605080040332614, 0.868110146524278, 0.47465486371626864`], 
             UndirectedEdge[19, 84] -> 
             RGBColor[
              0.2959425689542974, 0.42838478218655185`, 0.940164863542926], 
             UndirectedEdge[19, 48] -> 
             RGBColor[
              0.3524750293077462, 0.47810184855613913`, 0.9437395461742546], 
             UndirectedEdge[5, 77] -> 
             RGBColor[
              0.23349568981372465`, 0.3627491528489905, 0.9366086061577494]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.26920385108875294`, 0.4002806943772341, 0.9386421331168716], 
             160 -> RGBColor[
              0.5902199940802382, 0.6782062061588879, 0.9608834264625246], 
             245 -> RGBColor[
              0.4244026220080174, 0.5420179529125, 0.9482635376832157], 155 -> 
             RGBColor[
              0.21230278460535462`, 0.3404740657671945, 0.9354017015582263], 
             213 -> RGBColor[
              0.42787872382047937`, 0.5450287775884974, 0.9484850318169096], 
             27 -> RGBColor[
              0.2584384877012701, 0.38896561489352793`, 0.9380290615978824], 
             19 -> RGBColor[
              0.2912671539208582, 0.4234706245479727, 0.9398986055734284], 
             164 -> RGBColor[
              0.38392426951059677`, 0.5069576384803866, 0.9456842928556817], 
             190 -> RGBColor[
              0.22813210557574862`, 0.35711168574399543`, 0.9363031579701084],
              103 -> RGBColor[
              0.2788168781365947, 0.4103845953056338, 0.9391895807860471], 
             138 -> RGBColor[
              0.7066839033025902, 0.7707861033473555, 0.971399305210804], 291 -> 
             RGBColor[
              0.8179080138731872, 0.1386544187368418, 0.16478204035016009`], 
             28 -> RGBColor[
              0.22341264573171882`, 0.35215123421688327`, 0.9360343917138061],
              114 -> RGBColor[
              0.3044111891973746, 0.4372858390035616, 0.9406471389375684], 
             195 -> RGBColor[
              0.8191437574953648, 0.1481528857232069, 0.16596538983833015`], 
             93 -> RGBColor[
              0.5312094509757161, 0.6302987888719648, 0.9562379003465947], 34 -> 
             RGBColor[
              0.3274991935787168, 0.458085073714969, 0.9420889369120379], 161 -> 
             RGBColor[
              0.21627103797903324`, 0.3446449516647265, 0.9356276877173526], 
             22 -> RGBColor[
              0.8173789776787558, 0.8572619367637411, 0.982432355720336], 124 -> 
             RGBColor[
              0.9476938047146304, 0.9605107057164812, 0.973424924364235], 84 -> 
             RGBColor[
              0.30061798398773654`, 0.43329893982513096`, 0.9404311215124237],
              46 -> RGBColor[
              0.29213812634371106`, 0.4243860717872321, 0.9399482061644217], 
             241 -> RGBColor[
              0.2790754121939759, 0.4106563309919474, 0.9392043039181481], 
             185 -> RGBColor[
              0.5680702998089695, 0.6602240865171163, 0.9591397213924867], 
             121 -> RGBColor[
              0.9946101233350695, 0.9908799237508646, 0.6547233713644478], 
             126 -> RGBColor[
              0.22593857337368983`, 0.3548061443216573, 0.9361782395562414], 
             236 -> RGBColor[
              0.6232106502631707, 0.7049895070603167, 0.9634805717660004], 78 -> 
             RGBColor[
              0.1800403201715783, 0.3065641700889047, 0.9335644019367618], 
             254 -> RGBColor[
              0.8913219113450659, 0.5994000064779764, 0.23102867769365362`], 
             290 -> RGBColor[
              0.6129287179190951, 0.6966421711876226, 0.9626711403879157], 
             251 -> RGBColor[
              0.2867137638335649, 0.4186847228646212, 0.9396392967440941], 
             165 -> 
             RGBColor[
              0.9802603651545728, 0.9450757179590131, 0.3778156754531135], 
             100 -> RGBColor[
              0.8501803311271197, 0.38671359097016134`, 0.19568604779889498`],
              235 -> RGBColor[
              0.24203916924704705`, 0.37172889142129484`, 0.937095144672532], 
             70 -> RGBColor[
              0.26423372362278924`, 0.39505677528622424`, 0.9383590917103296],
              234 -> RGBColor[0.817319, 0.134127, 0.164218], 257 -> 
             RGBColor[
              0.39130532114623406`, 0.5133507344247334, 0.9461546069390968], 
             135 -> RGBColor[
              0.9900957369634822, 0.9901723469535194, 0.8138028001335977], 
             265 -> RGBColor[
              0.22246582468563886`, 0.3511560652655316, 0.9359804716559281], 
             111 -> RGBColor[
              0.24301438028138522`, 0.37275390005033504`, 0.937150681498242], 
             182 -> RGBColor[
              0.3071831062866214, 0.4401992996140543, 0.9408049955151171], 
             188 -> RGBColor[
              0.20571498311483435`, 0.33354986870991854`, 0.9350265360091202],
              154 -> RGBColor[
              0.7412000832467709, 0.797750405452433, 0.9748395554555993], 269 -> 
             RGBColor[
              0.2270252964366493, 0.35594835916304945`, 0.9362401268270142], 
             208 -> RGBColor[
              0.28595975701387044`, 0.41789221389032877`, 0.9395963571711656],
              86 -> RGBColor[
              0.9748675947682047, 0.926884637163092, 0.35686578084130904`], 
             119 -> RGBColor[
              0.28222472928714576`, 0.41396646293510553`, 0.9393836528676069],
              140 -> RGBColor[
              0.3280740134091542, 0.4585829537608091, 0.9421255639233401], 85 -> 
             RGBColor[
              0.9196256639800194, 0.938748558156751, 0.9921959108615778], 242 -> 
             RGBColor[
              0.24043240470913427`, 0.3700400800171928, 0.9370036418090929], 
             117 -> RGBColor[
              0.20347429876271564`, 0.33119476738824843`, 0.9348989323500625],
              47 -> RGBColor[
              0.6440597930627512, 0.7218636724671273, 0.9651575191576801], 81 -> 
             RGBColor[
              0.29584127485450173`, 0.42827831566524976`, 0.9401590949937939],
              275 -> RGBColor[
              0.21277857456934213`, 0.34097415118617147`, 0.9354287970928072],
              23 -> RGBColor[
              0.2963741173821658, 0.42883836694599214`, 0.9401894395874745], 
             110 -> 
             RGBColor[
              0.9929459767177286, 0.9913509943397207, 0.7665669512217009], 6 -> 
             RGBColor[
              0.3056730571205615, 0.43861214219787836`, 0.9407190004490276], 
             218 -> RGBColor[
              0.2560427236071457, 0.38644751493038626`, 0.9378926263769374], 
             108 -> RGBColor[
              0.3439204196877902, 0.4723083144158259, 0.943135282918988], 297 -> 
             RGBColor[
              0.7603990286995737, 0.8127487675575523, 0.9767531269139887], 
             157 -> RGBColor[
              0.34598043724619154`, 0.47409259808542004`, 0.9432665454162072],
              270 -> RGBColor[
              0.22825539451058077`, 0.357241270231474, 0.9363101790925575], 
             33 -> RGBColor[
              0.9146626577353835, 0.9347911916944939, 0.9917225348954364], 
             252 -> RGBColor[
              0.30053129972337833`, 0.4332078291671907, 0.9404261849718064], 
             260 -> RGBColor[
              0.8491537797280463, 0.8825561905625664, 0.9854742396306309], 
             159 -> RGBColor[
              0.2473937360801429, 0.37735688066202433`, 0.937400079332305], 
             183 -> RGBColor[
              0.25458949129815345`, 0.38492007563338526`, 0.9378098669468048],
              99 -> RGBColor[
              0.3674883934084197, 0.4927217086918333, 0.9446370133641255], 17 -> 
             RGBColor[
              0.29622239326445615`, 0.42867889527841463`, 0.9401807991234267],
              277 -> RGBColor[
              0.34909505354151776`, 0.4767903221752649, 0.9434650060123984], 
             104 -> RGBColor[
              0.28507184392659923`, 0.4169589609386654, 0.9395457918343952], 
             79 -> RGBColor[
              0.39493077240962093`, 0.5164909180886005, 0.9463856174877392], 
             191 -> RGBColor[
              0.24388899418338073`, 0.37367317471505657`, 0.9372004894660854],
              50 -> RGBColor[
              0.35244904856935166`, 0.4796953840916829, 0.9436787196097506], 
             225 -> RGBColor[
              0.9609628542707439, 0.8799806824768295, 0.3028484896985869], 61 -> 
             RGBColor[
              0.5668393910348319, 0.659224779322463, 0.9590428197448192], 196 -> 
             RGBColor[
              0.2809324202458739, 0.4126081641956031, 0.9393100577795065], 1 -> 
             RGBColor[
              0.41852266255485593`, 0.5369250275695268, 0.9478888718663042], 
             263 -> RGBColor[
              0.26098356523640104`, 0.3916406527501864, 0.9381739999984032], 
             201 -> 
             RGBColor[
              0.32111303850258816`, 0.4525537071655133, 0.9416820167576422], 
             293 -> RGBColor[
              0.20926131084396443`, 0.33727728400339907`, 0.9352284941269724],
              184 -> RGBColor[
              0.23743710807503443`, 0.3668918333419784, 0.9368330640969252], 
             106 -> RGBColor[
              0.6566687686170058, 0.7317139000018745, 0.9664142640033524], 
             206 -> RGBColor[
              0.23667377020378227`, 0.366089516840876, 0.9367895931344146], 
             247 -> RGBColor[
              0.5790882470358998, 0.6691689524288044, 0.9600070945582612], 
             220 -> RGBColor[
              0.25719173910326026`, 0.38765520306859286`, 0.937958061109625], 
             107 -> RGBColor[
              0.8341470216086144, 0.26347454816989946`, 0.18033253249694123`],
              131 -> RGBColor[
              0.324831212684851, 0.4557742027613212, 0.9419189355286837], 127 -> 
             RGBColor[
              0.8327720947194103, 0.2529062576026711, 0.17901590095508144`], 
             210 -> RGBColor[
              0.37855708825470646`, 0.5023088558389079, 0.9453423008120684], 
             181 -> RGBColor[
              0.7138170777657293, 0.7763585934520937, 0.9721102733779844], 
             194 -> RGBColor[
              0.5158331891976378, 0.6178156468678216, 0.9550274246943216], 
             118 -> RGBColor[
              0.17892956896395254`, 0.30539670014399584`, 0.9335011462986966],
              276 -> RGBColor[
              0.23178154572615212`, 0.3609474787299394, 0.9365109881878111], 
             280 -> RGBColor[
              0.2680583595238526, 0.3990767101141639, 0.9385768990668534], 
             189 -> RGBColor[
              0.2318484494359024, 0.3610177987708272, 0.9365147982551062], 
             168 -> RGBColor[
              0.3858730274799788, 0.5086455546860418, 0.9458084659902717], 41 -> 
             RGBColor[
              0.35699077137457635`, 0.483629196111943, 0.9439681141708117], 
             14 -> RGBColor[
              0.8226976998778256, 0.17547004422228246`, 0.1693686490773784], 
             77 -> RGBColor[
              0.2460324096232273, 0.37592604024272347`, 0.9373225538044856], 
             51 -> RGBColor[
              0.993562122803693, 0.9916057865804992, 0.7563558160423134], 179 -> 
             RGBColor[
              0.9936465744084931, 0.9916407094893913, 0.7549562343970292], 
             223 -> RGBColor[
              0.8873547734207121, 0.5813861597120881, 0.22771840056612383`], 
             292 -> 
             RGBColor[
              0.24306150835744214`, 0.3728034346463635, 0.9371533653724538], 
             143 -> RGBColor[
              0.39675004724917656`, 0.5180666825152114, 0.9465015400717941], 
             112 -> RGBColor[
              0.2522134290242518, 0.3824226835324653, 0.9376745537153752], 
             197 -> RGBColor[
              0.2105002400012672, 0.3385794771003698, 0.9352990493096494], 54 -> 
             RGBColor[
              0.4174064139952154, 0.53595818917145, 0.9478177454951437], 71 -> 
             RGBColor[
              0.6295965520330332, 0.7101738697986875, 0.963983293345653], 177 -> 
             RGBColor[
              0.41920763486506846`, 0.5375183161569235, 0.9479325176962138], 
             158 -> RGBColor[
              0.40363205630183896`, 0.524027532856795, 0.9469400556031081], 
             226 -> RGBColor[
              0.178927010221482, 0.30539401074342565`, 0.9335010005820983], 
             203 -> RGBColor[
              0.2595939437592997, 0.3901800724706624, 0.9380948631110431], 
             115 -> RGBColor[
              0.2215913444714862, 0.35023693111520926`, 0.9359306713014096], 
             173 -> RGBColor[
              0.25717362368840185`, 0.38763616261899303`, 0.9379570294635482],
              212 -> RGBColor[
              0.21172080019279638`, 0.3398623632496528, 0.9353685584068999], 
             129 -> RGBColor[
              0.23590943272644063`, 0.36528614969039486`, 0.9367460652458159],
              279 -> RGBColor[
              0.25879261498995565`, 0.3893378251269034, 0.9380492286230886], 
             26 -> RGBColor[
              0.9858349896506369, 0.9884104184434465, 0.8844144095680297], 40 -> 
             RGBColor[
              0.2372124705557414, 0.3666557250663601, 0.9368202713225229], 
             146 -> RGBColor[
              0.23045057360750168`, 0.3595485426447314, 0.9364351912946507], 
             192 -> RGBColor[
              0.8649861375675162, 0.47981540863036076`, 0.20905346250477896`],
              300 -> RGBColor[
              0.2558608387541249, 0.3862563424176957, 0.9378822683036323], 
             221 -> RGBColor[
              0.29461336050310216`, 0.4269876998276622, 0.9400891670880182], 
             62 -> RGBColor[
              0.9948487335515908, 0.9913902868768101, 0.6806946209012268], 
             286 -> RGBColor[
              0.5590358689967736, 0.6528895285873056, 0.9584284979047402], 
             152 -> RGBColor[
              0.25329610735962166`, 0.38356064710871024`, 0.9377362106448954],
              64 -> 
             RGBColor[
              0.23365539790008147`, 0.3629170161738291, 0.9366177012970005], 
             37 -> RGBColor[
              0.6807027709206555, 0.7504894452666685, 0.968809748742459], 148 -> 
             RGBColor[
              0.23881348570074337`, 0.36833849349398035`, 0.9369114467665411],
              261 -> RGBColor[
              0.4006413843936947, 0.5214371631655013, 0.9467494926336685], 15 -> 
             RGBColor[
              0.23892277989457777`, 0.36845336862135236`, 0.9369176709091936],
              136 -> RGBColor[
              0.9929076697798414, 0.9872385477406899, 0.46942180820333496`], 
             198 -> RGBColor[
              0.4642553566460736, 0.5759424388475844, 0.9509670287800365], 63 -> 
             RGBColor[
              0.32451328924336914`, 0.4554988334556064, 0.9418986777281211], 
             171 -> RGBColor[
              0.4183533072547869, 0.5367783405206518, 0.9478780806963388], 59 -> 
             RGBColor[
              0.8328101555207211, 0.25319880959989605`, 0.17905234802140027`],
              229 -> RGBColor[
              0.34638875058307517`, 0.4744462585754037, 0.9432925627809762], 
             102 -> RGBColor[
              0.38532279281260967`, 0.5081689690727651, 0.9457734055238204], 
             299 -> RGBColor[
              0.9944845479757449, 0.9919872330943883, 0.7410688437815899], 
             128 -> RGBColor[
              0.23926061251081787`, 0.3688084521208458, 0.93693690997691], 12 -> 
             RGBColor[
              0.20154157699751735`, 0.32916335427138743`, 0.93478886670474], 
             222 -> RGBColor[
              0.43613267935432526`, 0.5521779390160471, 0.94901096656484], 92 -> 
             RGBColor[
              0.261097249315751, 0.3917601419255701, 0.9381804741385418], 271 -> 
             RGBColor[
              0.9774649456708626, 0.9356461116447503, 0.3669559986295733], 
             132 -> RGBColor[
              0.2067120462521808, 0.3345978452847238, 0.9350833172797693], 80 -> 
             RGBColor[
              0.26782978190622225`, 0.39883646054537636`, 0.9385638819096797],
              244 -> RGBColor[
              0.24251120685435607`, 0.3722250328754895, 0.9371220265159511], 
             150 -> RGBColor[
              0.9620063021321176, 0.9711849428558795, 0.9491975995336027], 
             125 -> RGBColor[
              0.9926251659969516, 0.9866343007146026, 0.4386730148470409], 
             133 -> RGBColor[
              0.35014705105926486`, 0.47770150955020474`, 0.9435320383639844],
              258 -> 
             RGBColor[
              0.9617670348256762, 0.9710064976904998, 0.9496026166724999], 
             255 -> RGBColor[
              0.9589543367125869, 0.8732054811308165, 0.29504577826186157`], 
             176 -> RGBColor[
              0.1789518783186532, 0.305420148690281, 0.9335024167834431], 230 -> 
             RGBColor[
              0.24935218422087857`, 0.37941533383072157`, 0.9375116100566555],
              274 -> RGBColor[
              0.9645754531953188, 0.8921668269279859, 0.3168827543384975], 87 -> 
             RGBColor[
              0.27610729667649436`, 0.4075366533936812, 0.9390352741303609], 
             130 -> RGBColor[0.178927, 0.305394, 0.933501], 35 -> 
             RGBColor[
              0.2262311772849768, 0.3551136895845794, 0.9361949029161204], 31 -> 
             RGBColor[
              0.6188367246795077, 0.7014385572283971, 0.9631362403218372], 18 -> 
             RGBColor[
              0.9464007204285422, 0.9595463255731478, 0.9756137787701872], 24 -> 
             RGBColor[
              0.9556367854010767, 0.9664345677069957, 0.9599795299232305], 
             151 -> RGBColor[
              0.443273542823118, 0.5583629960424816, 0.9494659760706539], 137 -> 
             RGBColor[
              0.8455662065044656, 0.351247407198139, 0.19126755684933291`], 
             296 -> RGBColor[
              0.6962355794932261, 0.7626237933772783, 0.9703579139386239], 
             266 -> RGBColor[
              0.24763395401992835`, 0.3776093649474359, 0.9374137593886052], 
             283 -> RGBColor[
              0.6187231293682252, 0.7013463354372874, 0.9631272976828197], 
             284 -> RGBColor[
              0.25564421936180226`, 0.3860286617019018, 0.9378699321496993], 
             238 -> RGBColor[
              0.2785145923880161, 0.4100668738178543, 0.9391723660598572], 72 -> 
             RGBColor[
              0.6518075404484566, 0.7279162716099014, 0.9659297422102715], 
             288 -> RGBColor[
              0.8619011142240809, 0.46580703815332913`, 0.20647924340617463`],
              172 -> RGBColor[
              0.26949540103514497`, 0.4005871318562264, 0.9386587364550091], 
             243 -> RGBColor[
              0.21816661637866602`, 0.3466373247493527, 0.9357356381029547], 
             88 -> RGBColor[
              0.5042211596463271, 0.6083884781620977, 0.9541132831917766], 
             273 -> RGBColor[
              0.6178350891255162, 0.7006253843624993, 0.9630573879019151], 
             202 -> RGBColor[
              0.22812105044609293`, 0.3571000661017916, 0.9363025283968291], 
             98 -> 
             RGBColor[
              0.4228071955400177, 0.5406360746943846, 0.948161878519455], 30 -> 
             RGBColor[
              0.46219840465570133`, 0.574272512557169, 0.9508050979844909], 
             116 -> RGBColor[
              0.3224078413052081, 0.4536752002744616, 0.941764520447276], 240 -> 
             RGBColor[
              0.9949335587465892, 0.9915717193917691, 0.6899273198963884], 73 -> 
             RGBColor[
              0.3290101239879992, 0.459393765693919, 0.9421852120616541], 29 -> 
             RGBColor[
              0.24282295558358705`, 0.3725527005559224, 0.9371397801448899], 
             75 -> RGBColor[
              0.7305123993392341, 0.7894011055544591, 0.9737743070057807], 
             200 -> RGBColor[
              0.8859959599380017, 0.5752161050460523, 0.226584573288584], 156 -> 
             RGBColor[
              0.2276990046313701, 0.35665646919126776`, 0.9362784935120415], 
             25 -> RGBColor[
              0.2518103509231395, 0.3819990228915686, 0.9376515990138174], 38 -> 
             RGBColor[
              0.4179442959916355, 0.5364240755220139, 0.9478520188603253], 3 -> 
             RGBColor[
              0.3773249031069595, 0.5012415989953558, 0.9452637870640326], 57 -> 
             RGBColor[
              0.24705297562595502`, 0.37699871981921224`, 0.9373806735285489],
              227 -> RGBColor[
              0.25976518882652405`, 0.3903600618938796, 0.9381046152642871], 
             39 -> RGBColor[
              0.8675327116732591, 0.4913788068770457, 0.21117838636085415`], 
             109 -> RGBColor[
              0.9211686584075277, 0.939978900029778, 0.992343083047521], 256 -> 
             RGBColor[
              0.9952479751456992, 0.992244224277091, 0.7241496045864151], 287 -> 
             RGBColor[
              0.9409750107809423, 0.8036926171977683, 0.27136531206102255`], 
             239 -> RGBColor[
              0.4111342730563943, 0.530525575937213, 0.9474180902207585], 285 -> 
             RGBColor[0.382771346863294, 0.50595903483087, 0.945610829644085],
              216 -> RGBColor[
              0.2588379470720171, 0.38938547201937, 0.9380518102180992], 21 -> 
             RGBColor[
              0.38345468665213356`, 0.5065509094103063, 0.9456543714511763], 
             175 -> RGBColor[
              0.2945111830148827, 0.42688030480911665`, 0.9400833482312222], 
             7 -> RGBColor[
              0.394746751143397, 0.516331528116975, 0.946373891815379], 13 -> 
             RGBColor[
              0.30612838775897044`, 0.4390907235684761, 0.9407449308552837], 
             294 -> RGBColor[
              0.209897553009386, 0.33794601485934034`, 0.9352647271770572], 
             193 -> RGBColor[
              0.39949775357450523`, 0.5204466076304757, 0.9466766214891428], 
             60 -> RGBColor[
              0.9260824493199337, 0.7446485736567867, 0.2593824075361489], 65 -> 
             RGBColor[
              0.28791659856684826`, 0.41994897843342893`, 0.9397077964027201],
              69 -> RGBColor[
              0.9930380091079225, 0.9875173303841278, 0.48360843970387296`], 
             217 -> RGBColor[
              0.80703569950506, 0.8491816892426243, 0.9814014344154122], 214 -> 
             RGBColor[
              0.21288213693655111`, 0.34108300180034146`, 0.9354346948164131],
              170 -> RGBColor[
              0.8218934398484693, 0.16928814920765783`, 0.168598488764985], 
             74 -> RGBColor[
              0.6382140736915616, 0.7171699620960075, 0.9646616962176343], 
             246 -> RGBColor[
              0.5988679170367666, 0.6852269795994871, 0.961564222636048], 264 -> 
             RGBColor[
              0.2946613034028385, 0.4270380908550406, 0.940091897365233], 278 -> 
             RGBColor[
              0.6029315110482949, 0.6885259882808699, 0.9618841236420709], 45 -> 
             RGBColor[
              0.8578237913971699, 0.4454645759914146, 0.2030054339855487], 
             237 -> RGBColor[
              0.638779311088947, 0.7176288472788594, 0.9647061937760893], 228 -> 
             RGBColor[
              0.8163432429187892, 0.8564528128973794, 0.9823291233589543], 
             180 -> RGBColor[
              0.23402613491596813`, 0.3633066842836104, 0.936638814221599], 
             53 -> RGBColor[
              0.8317291195209172, 0.2448894931924079, 0.17801714672713256`], 
             48 -> RGBColor[
              0.4136829046946342, 0.5327330725643056, 0.9475804867750808], 5 -> 
             RGBColor[
              0.220958970004222, 0.34957226545525755`, 0.9358946585110132], 
             101 -> RGBColor[
              0.5465902564750337, 0.6427856196737024, 0.9574487336972479], 
             267 -> RGBColor[
              0.467847246129772, 0.578858496543228, 0.9512497954777179], 120 -> 
             RGBColor[
              0.18991457468017128`, 0.31694263764133146`, 0.9341267261233757],
              147 -> RGBColor[
              0.22619261942112945`, 0.35507316282496604`, 0.9361927071028155],
              89 -> RGBColor[
              0.27813245697413447`, 0.40966522526908, 0.9391506040133554], 43 -> 
             RGBColor[
              0.322173741643116, 0.45347243491334854`, 0.9417496038238137], 
             199 -> RGBColor[0.178927, 0.305394, 0.933501], 268 -> 
             RGBColor[
              0.2625163578880115, 0.3932517150116962, 0.938261290272349], 169 -> 
             RGBColor[
              0.2930250557635406, 0.42531829084204614`, 0.9399987154827865], 
             20 -> RGBColor[
              0.865905855945801, 0.8959138414156087, 0.9870720676150353], 4 -> 
             RGBColor[
              0.5396207399250182, 0.6371274521652572, 0.9569000678242504], 
             167 -> RGBColor[
              0.7539264605068086, 0.8076923480920241, 0.9761080018061227], 
             142 -> RGBColor[
              0.6590237495828186, 0.7335536290308857, 0.9666489864974762], 16 -> 
             RGBColor[
              0.9934703621130101, 0.9884420897444159, 0.5306673961342021], 
             281 -> RGBColor[
              0.8360763947567734, 0.2783045556433535, 0.18218010240253352`], 
             289 -> RGBColor[
              0.2909832679823188, 0.4231722424271597, 0.9398824386892002], 
             178 -> RGBColor[
              0.27705635157752495`, 0.4085341702682206, 0.9390893214029737], 
             58 -> RGBColor[
              0.5489231824340144, 0.6446795940643196, 0.9576323901745283], 
             186 -> RGBColor[
              0.2299691131158081, 0.3590424971416032, 0.9364077728319058], 
             122 -> RGBColor[
              0.6241927467762723, 0.7057868172525964, 0.96355788600105], 249 -> 
             RGBColor[
              0.8185799679311427, 0.1438193520784336, 0.16542550431492184`], 
             113 -> RGBColor[
              0.9594092884334661, 0.9692480942916449, 0.9535936663157671], 52 -> 
             RGBColor[
              0.8177080186927622, 0.13711716814164848`, 0.16459052473952288`],
              187 -> RGBColor[
              0.3639294956023307, 0.48963917028760373`, 0.9444102435429313], 
             259 -> RGBColor[
              0.46426084954242974`, 0.5759468982282985, 0.9509674612009588], 
             42 -> RGBColor[
              0.2544378422070241, 0.3847606828235006, 0.9378012307554097], 
             134 -> RGBColor[
              0.27400077350385804`, 0.40532256397795713`, 0.9389153107520011],
              248 -> RGBColor[
              0.20835094833068457`, 0.3363204352816248, 0.9351766503286018], 
             174 -> RGBColor[
              0.3923234880848031, 0.5142326194523638, 0.9462194836360928], 
             215 -> 
             RGBColor[
              0.9951032288756773, 0.9922430735458843, 0.7308157001748675], 83 -> 
             RGBColor[
              0.21628848662157388`, 0.34466329129434453`, 0.9356286813917323],
              95 -> RGBColor[
              0.48864650773140994`, 0.5957442741074949, 0.9528871895412045], 
             166 -> RGBColor[
              0.9927232541779302, 0.9868441014154793, 0.4493493080164732], 
             233 -> RGBColor[
              0.9940884990666902, 0.9897642221851048, 0.5979477888431959], 
             295 -> RGBColor[
              0.8372847792405768, 0.8730921717492939, 0.9843421637685542], 
             141 -> RGBColor[
              0.8990024464838272, 0.6342755227085348, 0.23743750448057996`], 
             205 -> RGBColor[
              0.5294468131435418, 0.6288678000738763, 0.9560991390396908], 
             224 -> RGBColor[
              0.9695247134417432, 0.9088618438807439, 0.33610969580648287`], 
             231 -> RGBColor[
              0.44511934956958094`, 0.5599617410733233, 0.9495835892443556], 
             68 -> RGBColor[
              0.8743662175245639, 0.5224081609419808, 0.2168804311477391], 10 -> 
             RGBColor[
              0.2114327980870659, 0.3395596547761419, 0.9353521571130395], 
             250 -> RGBColor[
              0.22258326386374316`, 0.3512795012877932, 0.9359871596433854], 
             282 -> RGBColor[
              0.9636570397640628, 0.9724160602789496, 0.9464033313040466], 
             232 -> RGBColor[
              0.9940965401504851, 0.9897814212502639, 0.5988230111904562], 
             253 -> RGBColor[
              0.29672537087035056`, 0.42920755663283183`, 0.9402094429539937],
              55 -> RGBColor[
              0.2766948027559306, 0.4081541595332056, 0.9390687317324474], 91 -> 
             RGBColor[
              0.2726124428491967, 0.4038633404346605, 0.9388362473750692], 
             105 -> RGBColor[
              0.28917033221241484`, 0.4212667319862237, 0.9397791946791023], 
             36 -> RGBColor[
              0.7595712694087771, 0.8121021157083784, 0.9766706236037325], 
             123 -> RGBColor[
              0.43622064479054923`, 0.5522541302556329, 0.9490165716446514], 
             94 -> RGBColor[
              0.8619491220774967, 0.8927588492317026, 0.9866946708064583], 96 -> 
             RGBColor[
              0.40546591079173033`, 0.5256159254437323, 0.9470569071895901], 
             2 -> RGBColor[
              0.2307572995292167, 0.3598709310360006, 0.936452658882132], 262 -> 
             RGBColor[
              0.9939797374120591, 0.9895315920033393, 0.5861097539357399], 
             272 -> RGBColor[
              0.22328031209840418`, 0.35201214317783264`, 0.936026855509159], 
             97 -> RGBColor[
              0.2574804300414378, 0.3879586355486801, 0.9379745016314742], 
             209 -> RGBColor[
              0.2651563206276758, 0.3960264832343887, 0.938411632244898], 66 -> 
             RGBColor[
              0.9464558742569554, 0.9595874592080723, 0.9755204177251058], 
             139 -> RGBColor[
              0.25547870703592473`, 0.385854697753317, 0.9378605064675941], 
             56 -> RGBColor[
              0.5476923991281734, 0.6436803887304818, 0.9575354984041846], 
             144 -> RGBColor[
              0.3157094904678022, 0.4478734254480028, 0.9413377074550355], 
             298 -> RGBColor[
              0.28525208052382683`, 0.41714840103001194`, 0.9395560560419711],
              204 -> RGBColor[
              0.23088271225706164`, 0.36000274776459185`, 0.9364598009514513],
              207 -> RGBColor[
              0.7455882739599426, 0.8011784933890475, 0.9752769292959146], 
             149 -> RGBColor[
              0.2939489691399074, 0.4262893823800991, 0.9400513309827632], 
             219 -> RGBColor[
              0.27423499655804673`, 0.4055687472585089, 0.9389286494084351], 
             9 -> RGBColor[
              0.5168296547678491, 0.6186246225079816, 0.9551058701141822], 11 -> 
             RGBColor[
              0.34350580070653963`, 0.47194919229362253`, 0.9431088637641358],
              44 -> RGBColor[
              0.9650552642631052, 0.8937853423246256, 0.3187467297321304], 
             153 -> RGBColor[
              0.27348165172589245`, 0.40477693407509363`, 0.9388857475347178],
              32 -> RGBColor[
              0.2562574704790552, 0.38667322750850125`, 0.9379048558936031], 
             162 -> RGBColor[
              0.2845267439871254, 0.4163860263409461, 0.9395147491992453], 90 -> 
             RGBColor[
              0.4035464690461924, 0.5239534014776945, 0.9469346020588602], 8 -> 
             RGBColor[
              0.6518492866916434, 0.7279488840923621, 0.9659339030856515], 
             163 -> RGBColor[
              0.2413593551772921, 0.3710143637312809, 0.9370564302669542], 49 -> 
             RGBColor[
              0.23655451757503262`, 0.36596417476700677`, 0.9367828018736257],
              76 -> RGBColor[
              0.29429562032882867`, 0.4266537347586102, 0.9400710722551477], 
             82 -> 
             RGBColor[
              0.9950766756732579, 0.9918778320265724, 0.7055047141489801], 67 -> 
             RGBColor[
              0.9123183312358003, 0.932921889378774, 0.9914989309411012], 211 -> 
             RGBColor[
              0.24235927283690456`, 0.3720653405899749, 
               0.9371133740984234]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9mHk4FFzYxsmSfR/LzGBWM2NmbHmlLHNH8aZCu0SWIkQLqbSgomQtVNoX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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 9}], {
             RGBColor[
             0.46767615866135254`, 0.5777748250387542, 0.9514973709902432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 11}], {
             RGBColor[
             0.3810142316306978, 0.5044371099315746, 0.9454988678152201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 20}], {
             RGBColor[
             0.6422142592503285, 0.7164194344925677, 0.9674804697406698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 37}], {
             RGBColor[
             0.5496127167377557, 0.6437072364180976, 0.9583493103043816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 43}], {
             RGBColor[
             0.370348202098986, 0.49519873124143765`, 0.944819237845059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 75}], {
             RGBColor[
             0.5745175309470449, 0.663163066561993, 0.9608315894360424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 102}], {
             RGBColor[
             0.40192272768373283`, 0.5225469983211459, 0.9468311386950623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 142}], {
             RGBColor[
             0.5387732060688373, 0.6352393283002062, 0.9572689291818902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 143}], {
             RGBColor[
             0.4076363549020162, 0.5274958550423691, 0.9471952059690492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 174}], {
             RGBColor[
             0.4054230753198295, 0.5255788235109453, 0.9470541777511985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 185}], {
             RGBColor[
             0.4932964811819127, 0.5985745570433215, 0.9535142966293955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 237}], {
             RGBColor[
             0.5286509868219015, 0.6272769374241931, 0.9562975328211968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 239}], {
             RGBColor[
             0.4148284678056251, 0.5337253017533699, 0.9476534810435313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 283}], {
             RGBColor[
             0.5186228959615405, 0.619135681503407, 0.955508084774562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 295}], {
             RGBColor[
             0.6279037208977163, 0.7050085996594103, 0.9661155178174292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 297}], {
             RGBColor[
             0.5894608456272148, 0.6748368975635395, 0.9623209993901465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 32}], {
             RGBColor[
             0.24350738500413596`, 0.3732720792722509, 0.9371787573878676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 83}], {
             RGBColor[
             0.2235228930753953, 0.35226711116517256`, 0.9360406701369322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 155}], {
             RGBColor[
             0.22153004206728566`, 0.3501724984015976, 0.9359271802201792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 156}], {
             RGBColor[
             0.2292281520802934, 0.3582637001136342, 0.9363655761970868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 178}], {
             RGBColor[
             0.25390682555337085`, 0.3842025506521106, 0.9377709901425528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 184}], {
             RGBColor[
             0.23409720380212556`, 0.3633813821889895, 0.9366428614895286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 202}], {
             RGBColor[
             0.22943917498765481`, 0.3584854985688961, 0.9363775936394806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 208}], {
             RGBColor[
             0.2583585282715436, 0.3888815724631647, 0.9380245080266488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 214}], {
             RGBColor[
             0.2218197182328839, 0.35047696641817105`, 0.9359436768492726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 268}], {
             RGBColor[
             0.2466368287086141, 0.37656132302384837`, 0.9373569745772405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 275}], {
             RGBColor[
             0.2217679370492794, 0.35042254111108606`, 0.9359407279874696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 17}], {
             RGBColor[
             0.3367736481857078, 0.4649602471368852, 0.9427222930937296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 30}], {
             RGBColor[
             0.4197616538813304, 0.5377570557762624, 0.9480344425242617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 38}], {
             RGBColor[
             0.3976345995492975, 0.5188328372586848, 0.9465579029621789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 55}], {
             RGBColor[
             0.327009852931445, 0.45469787926428074`, 0.9421662593982401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 74}], {
             RGBColor[
             0.5077694883992605, 0.6092057805456816, 0.9549627416408335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 90}], {
             RGBColor[
             0.39043568607657597`, 0.5125975002365252, 0.9460991945614463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[
             0.40677277394875433`, 0.5267478646254944, 0.9471401793543419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 144}], {
             RGBColor[
             0.34651719678738085`, 0.4745575122216793, 0.9433007472595341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 157}], {
             RGBColor[
             0.36165267017657554`, 0.4876670985403879, 0.9442651662401199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 229}], {
             RGBColor[
             0.3618568268450173, 0.48784392878537974`, 0.9442781749225044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 252}], {
             RGBColor[
             0.33892810141516894`, 0.46722471408127325`, 0.9428449860179196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 257}], {
             RGBColor[
             0.38431511212659675`, 0.5072961667100446, 0.9457091970015647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 259}], {
             RGBColor[
             0.42079287632469464`, 0.5385942486118271, 0.9481156241324957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 26}], {
             RGBColor[
             0.7627278647878275, 0.8127689353043519, 0.92065723869614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 39}], {
             RGBColor[
             0.7035767257991387, 0.5642531295211515, 0.5840392270925523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 52}], {
             RGBColor[
             0.6786643793088902, 0.3871223101534529, 0.5607452962818866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 78}], {
             RGBColor[
             0.3598305300482983, 0.47184581112708096`, 0.9452322348805061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 82}], {
             RGBColor[
             0.7673487077991381, 0.8145026420959148, 0.8312023909866153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 107}], {
             RGBColor[
             0.6868838807668163, 0.45030100016757835`, 0.5686163001605958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 130}], {
             RGBColor[
             0.3592738699625091, 0.4712607260826286, 0.9452005339121252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 193}], {
             RGBColor[
             0.46955924674976174`, 0.5787870298978665, 0.9517883446566966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 199}], {
             RGBColor[
             0.3592738699625091, 0.4712607260826286, 0.9452005339121252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 220}], {
             RGBColor[
             0.3984062395141392, 0.5123913276169251, 0.9474290644669376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.35927387507325015`, 0.47126073145434144`, 0.9452005342031744]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 228}], {
             RGBColor[
             0.6779819914219037, 0.7467901325313183, 0.9696145955916023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 236}], {
             RGBColor[
             0.5814156950940945, 0.671058479612787, 0.9601903197951254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 266}], {
             RGBColor[
             0.3936273469724733, 0.5073684085563466, 0.9471569136064277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 281}], {
             RGBColor[
             0.6878485673408958, 0.45771600390430534`, 0.5695400851133919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.23189096279390453`, 0.36106248300558996`, 0.9365172193279515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[
             0.23349568981372465`, 0.3627491528489905, 0.9366086061577494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 191}], {
             RGBColor[
             0.23242398209380136`, 0.36162272008515706`, 0.9365475739885493]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 248}], {
             RGBColor[
             0.21465495916745328`, 0.3429463503684412, 0.9355356544198075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 21}], {
             RGBColor[
             0.3445638718863475, 0.47258152580409235`, 0.9431866859501019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 34}], {
             RGBColor[
             0.31658612534963915`, 0.4483486079564237, 0.9414039686805327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 46}], {
             RGBColor[
             0.29890559173213627`, 0.4314991069925552, 0.9403336033067247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 50}], {
             RGBColor[
             0.32906105284495657`, 0.4591537631447806, 0.9421988600293891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 101}], {
             RGBColor[
             0.4261316567977976, 0.5406988809357904, 0.9490838670731377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 108}], {
             RGBColor[
             0.32479673840417583`, 0.4554602283068521, 0.9419271416840078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 114}], {
             RGBColor[
             0.30504212315896806`, 0.43794899060072, 0.940683069693298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 145}], {
             RGBColor[
             0.2874384541046572, 0.41944641828755624`, 0.9396805667829495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 169}], {
             RGBColor[
             0.299349056442051, 0.4319652165199622, 0.940358857965907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 187}], {
             RGBColor[
             0.3348012763614461, 0.46412565624274105`, 0.9425646219959795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 205}], {
             RGBColor[
             0.41755993513205164`, 0.5337399711358773, 0.9484090697443592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 213}], {
             RGBColor[
             0.3667758904705204, 0.4918204598931879, 0.9446020161329686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 219}], {
             RGBColor[
             0.2899540268393041, 0.4220904447281936, 0.9398238249287314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 221}], {
             RGBColor[
             0.3001432088118318, 0.4327999210127703, 0.9404040837685228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 231}], {
             RGBColor[
             0.3753962033450712, 0.49928694163560083`, 0.9451512948466916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 264}], {
             RGBColor[
             0.3001671802617, 0.4328251165264595, 0.9404054489071303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 9}], {
             RGBColor[
             0.45578820295562306`, 0.5674780753124783, 0.9507398809647807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 11}], {
             RGBColor[
             0.36912627592496833`, 0.4941403602052988, 0.9447413777897574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 43}], {
             RGBColor[
             0.3584602463932565, 0.4849019815151618, 0.9440617478195963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.40607658256930623`, 0.5261448586442126, 0.9470958186552614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 63}], {
             RGBColor[
             0.3596300201933831, 0.4859151807862907, 0.94413628477175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 106}], {
             RGBColor[
             0.5257077598802015, 0.6240227140594248, 0.9563940779093657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 131}], {
             RGBColor[
             0.359788981914124, 0.4860528654391481, 0.9441464136720313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 143}], {
             RGBColor[
             0.3957483991962868, 0.5171991053160931, 0.9464377159435866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 151}], {
             RGBColor[
             0.4190101469832575, 0.5373472620797284, 0.9479199339430164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 167}], {
             RGBColor[
             0.5743366058251028, 0.6620119381044995, 0.9612409468107508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 174}], {
             RGBColor[
             0.39353511961410004`, 0.5152820737846694, 0.9462966877257359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 185}], {
             RGBColor[
             0.4814085254761833, 0.5882778073170456, 0.9527568066039329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[
             0.4552899701705174, 0.5670735874923983, 0.9507006582548503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 283}], {
             RGBColor[
             0.5067349402558111, 0.6088389317771312, 0.9547505947490993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 297}], {
             RGBColor[
             0.5775728899214854, 0.6645401478372637, 0.9615635093646839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 22}], {
             RGBColor[
             0.7346141321851996, 0.7926054104280515, 0.9741831294029938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 47}], {
             RGBColor[
             0.6479545398771973, 0.7249062782797447, 0.9655457111216659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 61}], {
             RGBColor[
             0.6093443388632377, 0.6935868317074125, 0.9624883614152353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 72}], {
             RGBColor[
             0.6518284135700501, 0.7279325778511317, 0.9659318226479615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 177}], {
             RGBColor[
             0.5355284607783559, 0.6327336001246429, 0.9569332103909327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 217}], {
             RGBColor[
             0.7294424930983517, 0.7885652866674933, 0.9736676687505319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 247}], {
             RGBColor[
             0.6154687668637716, 0.6985589182605833, 0.9629704988219563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 267}], {
             RGBColor[
             0.5598482664107077, 0.6534036903177951, 0.9585918492816847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 271}], {
             RGBColor[
             0.814657116181253, 0.8317974978685563, 0.6664449508576125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 273}], {
             RGBColor[
             0.6348421879085798, 0.7142871342274307, 0.9644956454937833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 285}], {
             RGBColor[
             0.5173103167774687, 0.616953959461616, 0.9557723663648683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.43016772773719436`, 0.545286907400802, 0.949107366939159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 20}], {
             RGBColor[
             0.6913677553568252, 0.7572692319617951, 0.9710889688646087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 37}], {
             RGBColor[
             0.5987662128442524, 0.684557033887325, 0.9619578094283205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 43}], {
             RGBColor[
             0.41950169820548255`, 0.5360485287106651, 0.948427736968998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 63}], {
             RGBColor[
             0.42067147200560917`, 0.537061727981794, 0.9485022739211517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 75}], {
             RGBColor[
             0.6236710270535416, 0.7040128640312203, 0.9644400885599815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.5867492116924276, 0.675169261254928, 0.9607600670587673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 131}], {
             RGBColor[
             0.4208304337263501, 0.5371994126346513, 0.9485124028214329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 142}], {
             RGBColor[
             0.5879267021753338, 0.6760891257694337, 0.9608774283058292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 143}], {
             RGBColor[
             0.4567898510085129, 0.5683456525115964, 0.9508037050929882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 167}], {
             RGBColor[
             0.6353780576373289, 0.7131584853000028, 0.9656069359601525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 174}], {
             RGBColor[
             0.4545765714263261, 0.5664286209801727, 0.9506626768751375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 185}], {
             RGBColor[
             0.5424499772884093, 0.6394243545125489, 0.9571227957533345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 237}], {
             RGBColor[
             0.5778044829283981, 0.6681267348934206, 0.9599060319451358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 239}], {
             RGBColor[
             0.4639819639121217, 0.5745750992225973, 0.9512619801674704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 282}], {
             RGBColor[
             0.740243347265956, 0.7955203413934655, 0.9507546007091144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 283}], {
             RGBColor[
             0.5677763920680372, 0.6599854789726345, 0.959116583898501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 295}], {
             RGBColor[
             0.677057217004213, 0.7458583971286377, 0.9697240169413682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 297}], {
             RGBColor[
             0.6386143417337113, 0.7156866950327669, 0.9659294985140855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 117}], {
             RGBColor[
             0.20745354842489078`, 0.3353772110821952, 0.935125544731551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.22367111540675327`, 0.3524229022332684, 0.9360491111794278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 161}], {
             RGBColor[
             0.21385191803304957`, 0.3421023032204342, 0.935489922415196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 265}], {
             RGBColor[
             0.21694931138635237`, 0.3453578600208368, 0.9356663143844839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 269}], {
             RGBColor[
             0.2192290472618576, 0.3477540069695957, 0.9357961419700269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 43}], {
             RGBColor[
             0.3328397711748278, 0.46271081360348554`, 0.9424292337939748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 63}], {
             RGBColor[
             0.3340095449749544, 0.46372401287461446`, 0.9425037707461285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 131}], {
             RGBColor[
             0.3341685066956953, 0.46386169752747186`, 0.9425138996464097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 139}], {
             RGBColor[
             0.2994922538712322, 0.4289019450234698, 0.940484685115865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 143}], {
             RGBColor[
             0.3701279239778581, 0.49500793740441695`, 0.9448052019179649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 172}], {
             RGBColor[
             0.3065006008708423, 0.43626816207492447`, 0.9408838001095725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 174}], {
             RGBColor[
             0.36791464439567134`, 0.49309090587299315`, 0.9446641737001142]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 183}], {
             RGBColor[
             0.29904764600234657`, 0.4284346339635039, 0.9404593653554703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 185}], {
             RGBColor[
             0.4557880502577546, 0.5660866394053694, 0.9511242925783112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 283}], {
             RGBColor[
             0.4811144650373824, 0.586647763865455, 0.9531180807234778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 248}], {
             RGBColor[
             0.20494626266410096`, 0.3327418947765061, 0.9349827585166709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 58}], {
             RGBColor[
             0.4275257850964924, 0.5418851588163979, 0.949188660514906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 73}], {
             RGBColor[
             0.31756925587348483`, 0.44924224463119755`, 0.9414650714584689]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 95}], {
             RGBColor[
             0.3973874477451902, 0.5174174988379855, 0.946816060198244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 96}], {
             RGBColor[
             0.3557971492753504, 0.4823533245061042, 0.9439009190224369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 105}], {
             RGBColor[
             0.29764935998569264`, 0.4301787277773499, 0.9402620627671929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[
             0.3171012005840623, 0.44883683866464263`, 0.941435247389312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 149}], {
             RGBColor[
             0.30003867844943893`, 0.43269005297428764`, 0.9403981309190235]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 171}], {
             RGBColor[
             0.3622408475068787, 0.48793453204456394`, 0.9443115057758112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 245}], {
             RGBColor[
             0.36526550488349396`, 0.49055433824048805`, 0.9445042342692497]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 289}], {
             RGBColor[
             0.2985558278706446, 0.4311314829978179, 0.940313684772242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 298}], {
             RGBColor[
             0.2956902341413986, 0.428119562299244, 0.9401504934486273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 69}], {
             RGBColor[
             0.907867854492874, 0.581493687303205, 0.3264885443906257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 113}], {
             RGBColor[
             0.8910534941556458, 0.5723590692569638, 0.5614811576965728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 135}], {
             RGBColor[
             0.9063967184206538, 0.582821195587901, 0.4915857246054881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 224}], {
             RGBColor[
             0.8961112066597844, 0.5421659440515132, 0.2527391724419306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 249}], {
             RGBColor[
             0.8206388339044841, 0.15964469815035803`, 0.16739707669615012`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 254}], {
             RGBColor[
             0.8570098056114457, 0.3874350253501294, 0.200198663385516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 288}], {
             RGBColor[
             0.8422994070509533, 0.32063854118780577`, 0.1879239462417765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 19}], {
             RGBColor[
             0.265094966907718, 0.3959619965846625, 0.938408138241311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 49}], {
             RGBColor[
             0.2377386487348052, 0.36720877169417954`, 0.9368502363914097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 57}], {
             RGBColor[
             0.2429878777602664, 0.3727260442202823, 0.9371491722188713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 89}], {
             RGBColor[
             0.2585276184343561, 0.3890592969452162, 0.9380341374612745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 111}], {
             RGBColor[
             0.2409685800879815, 0.3706036343358437, 0.9370341762037178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.2455681044594148, 0.3754380260769088, 0.9372961123122845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 115}], {
             RGBColor[
             0.230257062183032, 0.3593451498682808, 0.9364241711053016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 146}], {
             RGBColor[
             0.2346866767510397, 0.3640009556330419, 0.9366764311019222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 175}], {
             RGBColor[
             0.2667169814547302, 0.3976668367152345, 0.9385005095702079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 212}], {
             RGBColor[
             0.22532179004368708`, 0.3541578659355026, 0.9361431146580468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 242}], {
             RGBColor[
             0.23967759230185604`, 0.3692467243192726, 0.9369606563591433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 243}], {
             RGBColor[
             0.2285446981366219, 0.35754534668535254`, 0.9363266545060742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 280}], {
             RGBColor[
             0.2534905697092152, 0.38376503936775813`, 0.9377472849880235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 294}], {
             RGBColor[
             0.2244101664519819, 0.3531996917403464, 0.9360911990431254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.9540665099241967, 0.9616166407194549, 0.7611949655148192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 44}], {
             RGBColor[
             0.9792628131880576, 0.9411137160345208, 0.4247070629331663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 53}], {
             RGBColor[
             0.9125997408169637, 0.6166657914684119, 0.3543422714306673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 59}], {
             RGBColor[
             0.9131402588168656, 0.620820449672156, 0.3548598720778012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 94}], {
             RGBColor[
             0.9277097420952534, 0.9406004694880592, 0.7586810334703302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 124}], {
             RGBColor[
             0.9705820834138202, 0.9744763977304486, 0.7520461602492186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 125}], {
             RGBColor[
             0.9930477640549809, 0.9875381952295093, 0.4846702054906215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 150}], {
             RGBColor[
             0.9777383321225639, 0.9798135163001478, 0.7399324978339024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 170}], {
             RGBColor[
             0.9076819009807398, 0.5788651194760369, 0.34963294244959353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 192}], {
             RGBColor[
             0.9292282498402631, 0.7341287491873884, 0.36986042931949054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 195}], {
             RGBColor[
             0.9063070598041875, 0.5682974877338114, 0.34831639298626615`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 200}], {
             RGBColor[
             0.939733161025506, 0.7818290973952341, 0.3786259847113931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 295}], {
             RGBColor[
             0.9153775706767935, 0.9307671307468549, 0.7575047799513781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 30}], {
             RGBColor[
             0.37921039896007874`, 0.5014757039177918, 0.9454929485539587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 38}], {
             RGBColor[
             0.3570833446280458, 0.48255148540021425`, 0.944016408991876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[
             0.2753301177357401, 0.4067197890509576, 0.9389910149394182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 48}], {
             RGBColor[
             0.35495264897954515`, 0.4807059839213601, 0.9438806429492537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 55}], {
             RGBColor[
             0.28645859801019335`, 0.41841652740581015`, 0.939624765427937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 84}], {
             RGBColor[
             0.2984201886260963, 0.4309889175517728, 0.9403059603179251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 90}], {
             RGBColor[
             0.3498844311553243, 0.4763161483780546, 0.9435577005911434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 97}], {
             RGBColor[
             0.27685141165294697`, 0.4083187654135474, 0.9390776503774505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 134}], {
             RGBColor[
             0.2851115833841571, 0.4170007296281859, 0.9395480549377139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 144}], {
             RGBColor[
             0.3059659418661292, 0.4382761603632087, 0.940759253289231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 158}], {
             RGBColor[
             0.34992722478314753`, 0.47635321406760484`, 0.9435604273632674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 159}], {
             RGBColor[
             0.2718080646722995, 0.4030178879702195, 0.9387904392278659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 175}], {
             RGBColor[
             0.29536678813966943`, 0.42777960004376564`, 0.9401320736773244]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 235}], {
             RGBColor[
             0.2691307812557516, 0.40020389334985473`, 0.9386379718979794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 252}], {
             RGBColor[
             0.29837684649391727`, 0.43094336222280266`, 0.9403034920476165]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 253}], {
             RGBColor[
             0.2964738820674033, 0.42894322595562323`, 0.9401951210387102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 292}], {
             RGBColor[
             0.26964195081094916`, 0.4007411649623891, 0.9386670822479402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 24}], {
             RGBColor[
             0.9510187529148094, 0.9629904466400717, 0.9677966543467089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 36}], {
             RGBColor[
             0.8529859949186596, 0.8858242206407632, 0.9761422011869598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 66}], {
             RGBColor[
             0.9464282973427488, 0.95956689239061, 0.9755670982476465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 69}], {
             RGBColor[
             0.9697193647682323, 0.9735318279786378, 0.7296111092370301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 88}], {
             RGBColor[
             0.7253109400374347, 0.7839674018676228, 0.9648635309809819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 113}], {
             RGBColor[
             0.9529050044310041, 0.9643972099323963, 0.9646037225429771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 135}], {
             RGBColor[
             0.9682482286960121, 0.9748593362633335, 0.8947082894518925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.7053280385373079, 0.7677443822103661, 0.9632904037751118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 222}], {
             RGBColor[
             0.6912666998914337, 0.7558621322945974, 0.9623123726675136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.9579627169351427, 0.9342040847269458, 0.6558617372883351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 254}], {
             RGBColor[
             0.918861315886804, 0.779473166025562, 0.6033212282319205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 258}], {
             RGBColor[
             0.9540838776271092, 0.9652764116318238, 0.9626081977213435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 260}], {
             RGBColor[
             0.8977772500782942, 0.9210512580678571, 0.980544009200409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 278}], {
             RGBColor[
             0.7746661157384185, 0.8240361569270088, 0.968748951206129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 288}], {
             RGBColor[
             0.9041509173263116, 0.7126766818632384, 0.5910465110881808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 290}], {
             RGBColor[
             0.7796647191738186, 0.8280942483803853, 0.9691424595790514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 48}], {
             RGBColor[
             0.3524750293077462, 0.47810184855613913`, 0.9437395461742546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 49}], {
             RGBColor[
             0.26391083574794544`, 0.39471739965748975`, 0.9383407037235271]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 57}], {
             RGBColor[
             0.2691600647734066, 0.40023467218359243`, 0.9386396395509886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 84}], {
             RGBColor[
             0.2959425689542974, 0.42838478218655185`, 0.940164863542926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 89}], {
             RGBColor[
             0.28469980544749635`, 0.41656792490852634`, 0.9395246047933918]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 111}], {
             RGBColor[
             0.2671407671011217, 0.39811226229915386`, 0.9385246435358352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 112}], {
             RGBColor[
             0.271740291472555, 0.402946654040219, 0.9387865796444018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 158}], {
             RGBColor[
             0.3474496051113486, 0.47374907870238386`, 0.9434193305882683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 175}], {
             RGBColor[
             0.2928891684678705, 0.42517546467854467`, 0.9399909769023254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 177}], {
             RGBColor[
             0.3552373943929633, 0.4804944703524481, 0.9439155616348212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 242}], {
             RGBColor[
             0.26584977931499626`, 0.39675535228258274`, 0.9384511236912607]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 253}], {
             RGBColor[
             0.2939962623956044, 0.42633909059040226`, 0.940054024263711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 280}], {
             RGBColor[
             0.2796627567223554, 0.4112736673310683, 0.939237752320141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 33}], {
             RGBColor[
             0.8902842568405922, 0.9153525165550513, 0.9893973012552358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 37}], {
             RGBColor[
             0.7733043134332283, 0.8232016433411387, 0.9779409081787471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 75}], {
             RGBColor[
             0.7982091276425176, 0.8426574734850338, 0.980423187310408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 124}], {
             RGBColor[
             0.9067998303302157, 0.928212273566045, 0.9802484959896351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 142}], {
             RGBColor[
             0.7624648027643098, 0.8147337352232472, 0.9768605270562558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 150}], {
             RGBColor[
             0.9139560790389594, 0.9335493921357441, 0.968134833574319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 167}], {
             RGBColor[
             0.8099161582263048, 0.8518030947538164, 0.981590034710579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 185}], {
             RGBColor[
             0.7169880778773853, 0.7780689639663625, 0.973105894503761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 200}], {
             RGBColor[
             0.8759509079419014, 0.7355649732308305, 0.6068283204518097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 237}], {
             RGBColor[
             0.752342583517374, 0.8067713443472341, 0.9758891306955624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 282}], {
             RGBColor[
             0.9147814478549319, 0.9341649508472791, 0.9667376994595409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 283}], {
             RGBColor[
             0.7423144926570131, 0.7986300884264481, 0.9750996826489275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 295}], {
             RGBColor[
             0.851595317593189, 0.8845030065824513, 0.9857071156917947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 297}], {
             RGBColor[
             0.8131524423226874, 0.8543313044865806, 0.981912597264512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 34}], {
             RGBColor[
             0.3554769401154252, 0.48231799156263766`, 0.943871654181607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 46}], {
             RGBColor[
             0.3377964064979223, 0.4654684905987692, 0.942801288807799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 50}], {
             RGBColor[
             0.3679518676107426, 0.4931231467509946, 0.9446665455304635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[
             0.32978099166431396`, 0.45704378140199375`, 0.9423448227907686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 101}], {
             RGBColor[
             0.4650224715635836, 0.5746682645420044, 0.9515515525742121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 108}], {
             RGBColor[
             0.3636875531699619, 0.4894296119130661, 0.9443948271850822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[
             0.3439329379247541, 0.47191837420693394`, 0.9431507551943723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 169}], {
             RGBColor[
             0.33823987120783705`, 0.46593460012617627`, 0.9428265434669814]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 187}], {
             RGBColor[
             0.3736920911272321, 0.49809503984895503`, 0.9450323074970538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 205}], {
             RGBColor[
             0.4564507498978377, 0.5677093547420913, 0.9508767552454336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 213}], {
             RGBColor[
             0.40566670523630644`, 0.5257898434994019, 0.9470697016340429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 264}], {
             RGBColor[
             0.339057995027486, 0.46679450013267343`, 0.9428731344082046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 61}], {
             RGBColor[
             0.6921091843567939, 0.7582433580431021, 0.9707375877325777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 72}], {
             RGBColor[
             0.7345932590636062, 0.7925891041868212, 0.9741810489653038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 177}], {
             RGBColor[
             0.6182933062719121, 0.6973901264603323, 0.9651824367082749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 217}], {
             RGBColor[
             0.812207338591908, 0.8532218130031827, 0.981916895067874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 247}], {
             RGBColor[
             0.6982336123573278, 0.7632154445962727, 0.9712197251392987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 267}], {
             RGBColor[
             0.642613111904264, 0.7180602166534845, 0.966841075599027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 271}], {
             RGBColor[
             0.8974219616748091, 0.8964540242042457, 0.6746941771749546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 273}], {
             RGBColor[
             0.717607033402136, 0.7789436605631201, 0.9727448718111256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 274}], {
             RGBColor[
             0.8909772154370372, 0.8747143818458635, 0.6496575550294168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 285}], {
             RGBColor[
             0.6000751622710249, 0.6816104857973055, 0.9640215926822105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[
             0.29610769611833376`, 0.428558341305621, 0.9401742672906341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 180}], {
             RGBColor[
             0.26520012614906696`, 0.3960725256148013, 0.9384141269045367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 267}], {
             RGBColor[
             0.3821106817559689, 0.50384843174461, 0.9457196175325961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 285}], {
             RGBColor[
             0.33957273212272987`, 0.46739870088843105`, 0.9429001346157797]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.7969254295463191, 0.8418022649015016, 0.9623206130704325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 113}], {
             RGBColor[
             0.9575230369172714, 0.9678413309993203, 0.9567865981194988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 135}], {
             RGBColor[
             0.9728662611822794, 0.9783034573302576, 0.8868911650284141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 224}], {
             RGBColor[
             0.9625807494214099, 0.9376482057938698, 0.6480446128648567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 233}], {
             RGBColor[
             0.9748626422338834, 0.9780993949460502, 0.7789636593832132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 254}], {
             RGBColor[
             0.9234793483730712, 0.7829172870924861, 0.5955041038084421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 259}], {
             RGBColor[
             0.7099488174717532, 0.7711907329676471, 0.9554734955620947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 260}], {
             RGBColor[
             0.9023952825645615, 0.924495379134781, 0.9727268847769307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 288}], {
             RGBColor[
             0.9087689498125788, 0.7161208029301624, 0.5832293866647026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 29}], {
             RGBColor[
             0.24731665325336327`, 0.3772758617237455, 0.9373956895793536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[
             0.2869920462831278, 0.4177357289024586, 0.9397006014188156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 77}], {
             RGBColor[
             0.24892138027318342`, 0.37896253156714604`, 0.9374870764091515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 91}], {
             RGBColor[
             0.2622113968861681, 0.3929311816631146, 0.9382439231944433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 139}], {
             RGBColor[
             0.25364452897953216`, 0.38392686032244283`, 0.9377560527407058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 147}], {
             RGBColor[
             0.2390014851721345, 0.36853609285826733`, 0.9369221530583165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 148}], {
             RGBColor[
             0.24531191831194143`, 0.3751687581927745, 0.9372815228901793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 172}], {
             RGBColor[
             0.2606528759791422, 0.3912930773738975, 0.9381551677344133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 203}], {
             RGBColor[
             0.2557021473412196, 0.3860895476811155, 0.9378732310624303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 206}], {
             RGBColor[
             0.2442420605634609, 0.3740442698662223, 0.937220596074116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 244}], {
             RGBColor[
             0.2471607788887478, 0.37711202788352904`, 0.9373868127648843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 270}], {
             RGBColor[
             0.24003287271686014`, 0.3696201465615213, 0.9369808890531874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 272}], {
             RGBColor[
             0.23754533151077184`, 0.36700558303470066`, 0.9368392272614883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 39}], {
             RGBColor[
             0.9266838506619479, 0.7398946126602461, 0.547796397964442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 59}], {
             RGBColor[
             0.9093225725856791, 0.6208046140216712, 0.5317333787947149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 60}], {
             RGBColor[
             0.9559587194852852, 0.8665294960501166, 0.5718984085520893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 62}], {
             RGBColor[
             0.9903418616011138, 0.9899003526601282, 0.7825545152346283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 82}], {
             RGBColor[
             0.9904558326619474, 0.9901441252350094, 0.7949595618585049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[
             0.9180076603888783, 0.6875620047068038, 0.5400502286834623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 127}], {
             RGBColor[
             0.9093035421850235, 0.6206583380230588, 0.5317151552615555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 130}], {
             RGBColor[
             0.5823809948253185, 0.6469022092217233, 0.9089577047840149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 137}], {
             RGBColor[
             0.9157005980775512, 0.6698289128207927, 0.5378409832086813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 170}], {
             RGBColor[
             0.903864214749553, 0.5788492838255521, 0.5265064491665074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 192}], {
             RGBColor[
             0.9254105636090766, 0.7341129135369036, 0.5467339360364043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 195}], {
             RGBColor[
             0.9024893735730009, 0.5682816520833267, 0.52518989970318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 199}], {
             RGBColor[
             0.5823809948253185, 0.6469022092217233, 0.9089577047840149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 220}], {
             RGBColor[
             0.6215133643769486, 0.6880328107560196, 0.9111862353388274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 226}], {
             RGBColor[
             0.5823809999360594, 0.646902214593436, 0.908957705075064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 228}], {
             RGBColor[
             0.901089116284713, 0.9224316156704129, 0.933371766463492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 266}], {
             RGBColor[
             0.6167344718352826, 0.6830098916954412, 0.9109140844783175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 32}], {
             RGBColor[
             0.25734797909016266`, 0.3878194212010146, 0.9379669587457427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 103}], {
             RGBColor[
             0.2686276829189324, 0.3996751050995809, 0.9386093211919647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 119}], {
             RGBColor[
             0.2703316084942079, 0.40146603891431676`, 0.9387063572327446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 152}], {
             RGBColor[
             0.2558672975304459, 0.3862631310011191, 0.9378826361213889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 268}], {
             RGBColor[
             0.2604774227946408, 0.3911086649526121, 0.9381451759351156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 35}], {
             RGBColor[
             0.2248219115083478, 0.35363246190073133`, 0.9361146473149633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 126}], {
             RGBColor[
             0.22467560955270433`, 0.3534786892692703, 0.9361063156350238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 163}], {
             RGBColor[
             0.23238600045450547`, 0.3615827989740821, 0.9365454109903801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 184}], {
             RGBColor[
             0.23042487690337662`, 0.35952153377943086`, 0.9364337279053656]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 189}], {
             RGBColor[
             0.22763054758381063`, 0.35658451649385525`, 0.9362745949844562]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 197}], {
             RGBColor[
             0.21695644286649302`, 0.3453653556586265, 0.9356667205117277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 211}], {
             RGBColor[
             0.2328859592843117, 0.3621082874034291, 0.9365738829061148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 216}], {
             RGBColor[
             0.24112529640186797`, 0.3707683531181266, 0.9370431009659527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 275}], {
             RGBColor[
             0.21809561015053047`, 0.3465626927015274, 0.9357315944033067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 293}], {
             RGBColor[
             0.21633697828784162`, 0.3447142591101412, 0.9356314429203892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 77}], {
             RGBColor[
             0.2444276826034072, 0.3742393703993229, 0.9372311669746878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 91}], {
             RGBColor[
             0.25771769921639187`, 0.38820802049529146`, 0.9379880137599795]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 148}], {
             RGBColor[
             0.2408182206421652, 0.3704455970249514, 0.9370256134557156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 162}], {
             RGBColor[
             0.2636748497853562, 0.39446936344843425`, 0.9383272646720675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 172}], {
             RGBColor[
             0.256159178309366, 0.3865699162060744, 0.9378992582999495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 191}], {
             RGBColor[
             0.24335597488348387`, 0.37311293763548947`, 0.9371701348054876]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 203}], {
             RGBColor[
             0.25120844967144335`, 0.38136638651329235`, 0.9376173216279664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 206}], {
             RGBColor[
             0.23974836289368467`, 0.3693211086983992, 0.9369646866396522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 244}], {
             RGBColor[
             0.24266708121897157`, 0.3723888667157059, 0.9371309033304205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 270}], {
             RGBColor[
             0.2355391750470839, 0.3648969853936982, 0.9367249796187237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 272}], {
             RGBColor[
             0.23305163384099561`, 0.36228242186687754`, 0.9365833178270244]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 38}], {
             RGBColor[
             0.4400713503236684, 0.5553482940395915, 0.949328558422408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 47}], {
             RGBColor[
             0.5531290988592262, 0.6480680925121483, 0.9579813085710855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 48}], {
             RGBColor[
             0.43794065467516774`, 0.5535027925607373, 0.9491927923797858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 74}], {
             RGBColor[
             0.5502062391736314, 0.6457212373265883, 0.9577333971010626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 90}], {
             RGBColor[
             0.4328724368509469, 0.5491129570174318, 0.9488698500216755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 123}], {
             RGBColor[
             0.44920952472312525`, 0.5632633214064009, 0.9499108348145711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 144}], {
             RGBColor[
             0.3889539475617518, 0.5110729690025859, 0.9460714027197632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 158}], {
             RGBColor[
             0.4329152304787701, 0.5491500227069821, 0.9488725767937995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 252}], {
             RGBColor[
             0.38136485218953986`, 0.5037401708621798, 0.9456156414781487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 257}], {
             RGBColor[
             0.42675186290096767`, 0.5438116234909512, 0.9484798524617939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 259}], {
             RGBColor[
             0.46322962709906557`, 0.5751097053927338, 0.9508862795927249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 36}], {
             RGBColor[
             0.6892039970441424, 0.7567703364683878, 0.9699034319627848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 51}], {
             RGBColor[
             0.8061994237416004, 0.8465221719044482, 0.8597460281820752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 58}], {
             RGBColor[
             0.583879953556761, 0.6730590756463584, 0.9603843152481828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 66}], {
             RGBColor[
             0.7826462994682315, 0.8305130082182347, 0.9693283290234715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 67}], {
             RGBColor[
             0.765577527957654, 0.8171802233035855, 0.9773175856314692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 73}], {
             RGBColor[
             0.47392342433375345`, 0.580416161461158, 0.9526607261917457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 95}], {
             RGBColor[
             0.5537416162054588, 0.648591415667946, 0.9580117149315208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 96}], {
             RGBColor[
             0.512151317735619, 0.6135272413360646, 0.9550965737557137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 109}], {
             RGBColor[
             0.7700026915435176, 0.8207087286290875, 0.9777396616846791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 110}], {
             RGBColor[
             0.8058913506986181, 0.8463947757840589, 0.8648515957717691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 138}], {
             RGBColor[
             0.662760313991049, 0.7361123302878763, 0.9672677727663206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 154}], {
             RGBColor[
             0.6800184039631393, 0.7495944813404151, 0.9689878978887183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 171}], {
             RGBColor[
             0.5185950159671473, 0.6191084488745244, 0.955507160509088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 245}], {
             RGBColor[
             0.5216196733437626, 0.6217282550704486, 0.9556998890025264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 156}], {
             RGBColor[
             0.24197823755521267`, 0.3716648483498845, 0.9370916747028223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 178}], {
             RGBColor[
             0.2666569110282901, 0.3976036988883609, 0.9384970886482884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 182}], {
             RGBColor[
             0.2817202883828383, 0.4134362635612778, 0.9393549257043601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 202}], {
             RGBColor[
             0.24218926046257408`, 0.37188664680514644`, 0.937103692145216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 208}], {
             RGBColor[
             0.27110861374646283`, 0.402282720699415, 0.9387506065323843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 268}], {
             RGBColor[
             0.2593869141835333, 0.38996247126009875`, 0.938083073082976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 37}], {
             RGBColor[
             0.7976827143280194, 0.8426403184805812, 0.9802661418189477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 75}], {
             RGBColor[
             0.8225875285373088, 0.8620961486244765, 0.9827484209506085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 94}], {
             RGBColor[
             0.8883058899064401, 0.9137750204630982, 0.9892086028509474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 124}], {
             RGBColor[
             0.931178231225007, 0.9476509487054876, 0.9825737296298357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 142}], {
             RGBColor[
             0.7868432036591011, 0.8341724103626897, 0.9791857606964562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 150}], {
             RGBColor[
             0.9383344799337505, 0.9529880672751867, 0.9704600672145196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 185}], {
             RGBColor[
             0.7413664787721765, 0.7975076391058051, 0.9754311281439616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 200}], {
             RGBColor[
             0.9003293088366926, 0.7550036483702731, 0.6091535540920102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 237}], {
             RGBColor[
             0.7767209844121652, 0.8262100194866766, 0.9782143643357628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 239}], {
             RGBColor[
             0.6628984653958889, 0.7326583838158534, 0.9695703125580974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 282}], {
             RGBColor[
             0.9391598487497231, 0.9536036259867218, 0.9690629330997416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 295}], {
             RGBColor[
             0.8759737184879801, 0.9039416817218939, 0.9880323493319954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 297}], {
             RGBColor[
             0.8375308432174786, 0.8737699796260231, 0.9842378309047126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 46}], {
             RGBColor[
             0.30981865996121394`, 0.44123557275110054`, 0.9410185715382298]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 50}], {
             RGBColor[
             0.33997412107403424`, 0.46889022890332593`, 0.9428838282608942]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 87}], {
             RGBColor[
             0.3018032451276056, 0.4328108635543251, 0.9405621055211995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 108}], {
             RGBColor[
             0.3357098066332535, 0.46519669406539743`, 0.9426121099155129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 114}], {
             RGBColor[
             0.31595519138804573`, 0.44768545635926527`, 0.9413680379248031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 169}], {
             RGBColor[
             0.3102621246711287, 0.4417016822785076, 0.9410438261974121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 187}], {
             RGBColor[
             0.34571434459052375`, 0.47386212200128636`, 0.9432495902274847]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 205}], {
             RGBColor[
             0.4284730033611293, 0.5434764368944227, 0.9490940379758643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 213}], {
             RGBColor[
             0.37768895869959807`, 0.5015569256517332, 0.9452869843644738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 227}], {
             RGBColor[
             0.2936321912026204, 0.4242225678044243, 0.9400967760881624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 264}], {
             RGBColor[
             0.31108024849077764`, 0.44256158228500475`, 0.9410904171386354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 92}], {
             RGBColor[
             0.24366421330036392`, 0.37343691575507476`, 0.9371876885273311]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 126}], {
             RGBColor[
             0.2260848753293333, 0.35495991695311835`, 0.9361865712361809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 163}], {
             RGBColor[
             0.23379526623113445`, 0.36306402665793014`, 0.9366256665915373]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 184}], {
             RGBColor[
             0.23183414268000563`, 0.3610027614632789, 0.9365139835065228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 189}], {
             RGBColor[
             0.2290398133604396, 0.3580657441777033, 0.9363548505856133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 197}], {
             RGBColor[
             0.218365708643122, 0.3468465833424746, 0.9357469761128849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 211}], {
             RGBColor[
             0.2342952250609407, 0.36358951508727716`, 0.936654138507272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 216}], {
             RGBColor[
             0.24253456217849695`, 0.3722495808019747, 0.9371233565671098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 275}], {
             RGBColor[
             0.21950487592715945`, 0.34804392038537546`, 0.9358118500044639]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 58}], {
             RGBColor[
             0.6542472259213957, 0.728390854886349, 0.9671515068891303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 66}], {
             RGBColor[
             0.8530135718328662, 0.8858447874582254, 0.9760955206644191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 67}], {
             RGBColor[
             0.8359448003222887, 0.8725120025435762, 0.9840847772724168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 69}], {
             RGBColor[
             0.8763046392583498, 0.8998097230462532, 0.7301395316538027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 88}], {
             RGBColor[
             0.6318962145275521, 0.7102452969352381, 0.9653919533977545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 95}], {
             RGBColor[
             0.6241088885700935, 0.7039231949079366, 0.9647789065724686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 96}], {
             RGBColor[
             0.5825185901002536, 0.6688590205760554, 0.9618637653966613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 109}], {
             RGBColor[
             0.8403699639081523, 0.8760405078690783, 0.9845068533256267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 113}], {
             RGBColor[
             0.8594902789211216, 0.8906751050000117, 0.9651321449597499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 138}], {
             RGBColor[
             0.7331275863556836, 0.791444109527867, 0.9740349644072682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 154}], {
             RGBColor[
             0.750385676327774, 0.8049262605804057, 0.9757550895296658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 198}], {
             RGBColor[
             0.6119133130274254, 0.6940222772779814, 0.9638188261918845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 222}], {
             RGBColor[
             0.5978519743815511, 0.6821400273622127, 0.9628407950842862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 224}], {
             RGBColor[
             0.8645479914252601, 0.8604819797945611, 0.6563901597051076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 245}], {
             RGBColor[
             0.5919869457083973, 0.6770600343104392, 0.9624670806434741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 258}], {
             RGBColor[
             0.8606691521172266, 0.8915543066994391, 0.9631366201381162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 260}], {
             RGBColor[
             0.8043625245684116, 0.8473291531354724, 0.9810724316171817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 278}], {
             RGBColor[
             0.681251390228536, 0.7503140519946241, 0.9692773736229017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 290}], {
             RGBColor[
             0.6862499936639361, 0.7543721434480005, 0.9696708819958241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 75}], {
             RGBColor[
             0.7056075851299448, 0.7699452754105638, 0.9712920278741198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 94}], {
             RGBColor[
             0.771325946499076, 0.8216241472491855, 0.9777522097744586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 102}], {
             RGBColor[
             0.5330127818666326, 0.6293292071697167, 0.9572915771331396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 124}], {
             RGBColor[
             0.8141982878176429, 0.8555000754915749, 0.971117336553347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 142}], {
             RGBColor[
             0.669863260251737, 0.742021537148777, 0.9677293676199676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 150}], {
             RGBColor[
             0.8213545365263866, 0.860837194061274, 0.9590036741380308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 185}], {
             RGBColor[
             0.6243865353648125, 0.7053567658918924, 0.9639747350674728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 237}], {
             RGBColor[
             0.6597410410048012, 0.7340591462727639, 0.9667579712592742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 239}], {
             RGBColor[
             0.5459185219885249, 0.6405075106019407, 0.9581139194816087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 282}], {
             RGBColor[
             0.8221799053423591, 0.8614527527728091, 0.9576065400232527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 283}], {
             RGBColor[
             0.6497129501444403, 0.725917890351978, 0.9659685232126394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 295}], {
             RGBColor[
             0.7589937750806162, 0.8117908085079812, 0.9765759562555065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 297}], {
             RGBColor[
             0.7205508998101146, 0.7816191064121104, 0.9727814378282238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 48}], {
             RGBColor[
             0.41581360034313486`, 0.5345785740431597, 0.947716252817703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 55}], {
             RGBColor[
             0.34731954937378307`, 0.4722891175276097, 0.9434603752963864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 74}], {
             RGBColor[
             0.5280791848415985, 0.6267970188090106, 0.9562568575389798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 90}], {
             RGBColor[
             0.41074538251891396`, 0.5301887384998543, 0.9473933104595927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 123}], {
             RGBColor[
             0.4270824703910924, 0.5443391028888234, 0.9484342952524883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 144}], {
             RGBColor[
             0.36682689322971884`, 0.49214875048500833`, 0.9445948631576804]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 158}], {
             RGBColor[
             0.41078817614673724`, 0.5302258041894045, 0.9473960372317167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 252}], {
             RGBColor[
             0.3592377978575069, 0.4848159523446023, 0.9441391019160659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 253}], {
             RGBColor[
             0.35733483343099304`, 0.48281581607742285`, 0.9440307309071595]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 257}], {
             RGBColor[
             0.4046248085689348, 0.5248874049733736, 0.9470033128997111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 259}], {
             RGBColor[
             0.44110257276703263`, 0.5561854868751561, 0.949409740030642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 52}], {
             RGBColor[
             0.8426203651830106, 0.3142479875093471, 0.1878844555501885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 59}], {
             RGBColor[
             0.8501714335969901, 0.3722888082384709, 0.1951153671911272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 60}], {
             RGBColor[
             0.8968075804965964, 0.6180136902669162, 0.2352803969485015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 62}], {
             RGBColor[
             0.931190722612425, 0.7413845468769279, 0.4459365036310404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 82}], {
             RGBColor[
             0.9313046936732585, 0.7416283194518091, 0.4583415502549171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 100}], {
             RGBColor[
             0.8588565214001893, 0.4390461989236035, 0.20343221707987458`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 107}], {
             RGBColor[
             0.8508398666409367, 0.3774266775234726, 0.1957554594288977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 127}], {
             RGBColor[
             0.8501524031963347, 0.3721425322398584, 0.1950971436579678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 136}], {
             RGBColor[
             0.9302201907265502, 0.7393086773088677, 0.34030009728209454`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 137}], {
             RGBColor[
             0.8565494590888623, 0.4213131070375924, 0.20122297160509353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 141}], {
             RGBColor[
             0.8832675790785431, 0.5628271647927903, 0.22430794542071705`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 170}], {
             RGBColor[
             0.8447130757608642, 0.3303334780423518, 0.18988843756291957`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 192}], {
             RGBColor[
             0.8662594246203876, 0.48559710775370324`, 0.21011592443281657`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 220}], {
             RGBColor[
             0.5623622253882596, 0.4395170049728193, 0.5745682237352395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 228}], {
             RGBColor[
             0.8419379772960242, 0.6739158098872126, 0.5967537548599042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 232}], {
             RGBColor[
             0.9308146259118721, 0.7405801140636548, 0.40500069877565514`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 266}], {
             RGBColor[
             0.5575833328465938, 0.4344940859122408, 0.5742960728747296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 281}], {
             RGBColor[
             0.8518045532150162, 0.3848416812601996, 0.19667924438169382`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.2625645345612948, 0.39330235174989453`, 0.9382640338626215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.25252112623098183`, 0.38274609280586824`, 0.9376920766161012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 162}], {
             RGBColor[
             0.2608696072714334, 0.3915208757036531, 0.9381675102608841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 191}], {
             RGBColor[
             0.24055073236956107`, 0.37016444989070835`, 0.9370103803943042]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 76}], {
             RGBColor[
             0.32564319585170254`, 0.45514146543527656`, 0.9420195932129798]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.4306059655104517, 0.5460088371370204, 0.9490406986812941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 99}], {
             RGBColor[
             0.362239582391498, 0.48817545240188814`, 0.9443025637674687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 104}], {
             RGBColor[
             0.3210313076505878, 0.45029407852530423`, 0.9417569530026035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 157}], {
             RGBColor[
             0.35148560431038395`, 0.4788608970986815, 0.9436173297935095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 201}], {
             RGBColor[
             0.3390519049385823, 0.4680914516387281, 0.942825065464227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 209}], {
             RGBColor[
             0.3110735460011261, 0.43982783967316585`, 0.9411898732078549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 222}], {
             RGBColor[
             0.3965617253644508, 0.517903567563995, 0.9464895403678258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 229}], {
             RGBColor[
             0.35168976097882576`, 0.47903772734367334`, 0.943630338475894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 259}], {
             RGBColor[
             0.41062581045850305`, 0.5297880471701207, 0.9474677876858852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 261}], {
             RGBColor[
             0.3788160778841355, 0.5025331796387221, 0.9453588034022401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 278}], {
             RGBColor[
             0.4799611412114356, 0.5860775921964064, 0.9529261189064413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 290}], {
             RGBColor[
             0.4849597446468357, 0.5901356836497829, 0.9533196272793637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 55}], {
             RGBColor[
             0.2655663224814774, 0.39645742117835314`, 0.9384349812439285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[
             0.25595913612423093`, 0.3863596591860904, 0.937887866193442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 134}], {
             RGBColor[
             0.26421930785544107`, 0.3950416234007289, 0.9383582707537054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 144}], {
             RGBColor[
             0.28507366633741316`, 0.4163170541357517, 0.9395694691052225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 159}], {
             RGBColor[
             0.2509157891435835, 0.3810587817427625, 0.9376006550438574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 235}], {
             RGBColor[
             0.24823850572703557`, 0.37824478712239773`, 0.9374481877139709]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 252}], {
             RGBColor[
             0.2774845709652012, 0.40898425599534566`, 0.939113707863608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 292}], {
             RGBColor[
             0.24874967528223313`, 0.3787820587349321, 0.9374772980639317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 63}], {
             RGBColor[
             0.3233435154432426, 0.45448563418447746`, 0.9418241407759673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 131}], {
             RGBColor[
             0.3235024771639835, 0.45462331883733487`, 0.9418342696762487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 139}], {
             RGBColor[
             0.2888262243395204, 0.4196635663333328, 0.9398050551457039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 143}], {
             RGBColor[
             0.3594618944461463, 0.48576955871427996`, 0.9441255719478039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 172}], {
             RGBColor[
             0.2958345713391305, 0.4270297833847875, 0.9402041701394114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 174}], {
             RGBColor[
             0.35724861486395953`, 0.48385252718285615`, 0.9439845437299532]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 183}], {
             RGBColor[
             0.28838161647063476`, 0.4191962552733669, 0.9397797353853092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 185}], {
             RGBColor[
             0.4451220207260428, 0.5568482607152324, 0.9504446626081502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 244}], {
             RGBColor[
             0.28234247424873604`, 0.412848733894419, 0.9394358151698824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 59}], {
             RGBColor[
             0.8989327098919131, 0.5734920759622608, 0.24889953887676536`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 60}], {
             RGBColor[
             0.9455688567915195, 0.8192169579907062, 0.28906456863413965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 94}], {
             RGBColor[
             0.9135021931703009, 0.8932720957781641, 0.6527207002692943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 100}], {
             RGBColor[
             0.9076177976951124, 0.6402494666473935, 0.25721638876551267`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 121}], {
             RGBColor[
             0.9798326937990873, 0.9423326330377451, 0.48673505054828914`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 124}], {
             RGBColor[
             0.9563745344888678, 0.9271480240205534, 0.6460858270481826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 125}], {
             RGBColor[
             0.9788402151300284, 0.9402098215196141, 0.37870987228958564`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 137}], {
             RGBColor[
             0.9053107353837854, 0.6225163747613823, 0.25500714329073165`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 150}], {
             RGBColor[
             0.9635307831976114, 0.9324851425902525, 0.6339721646328667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 170}], {
             RGBColor[
             0.8934743520557873, 0.5315367457661417, 0.24367260924855771`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 192}], {
             RGBColor[
             0.9150207009153106, 0.6868003754774932, 0.26390009611845466`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 195}], {
             RGBColor[
             0.892099510879235, 0.5209691140239162, 0.24235605978523028`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 200}], {
             RGBColor[
             0.9255256121005535, 0.7345007236853389, 0.2726656515103572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 256}], {
             RGBColor[
             0.9801516197044022, 0.9430147833008583, 0.5214481671592728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 299}], {
             RGBColor[
             0.979769906119425, 0.942886287709507, 0.5299077867568601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 53}], {
             RGBColor[
             0.8447764554590436, 0.34517703459191124`, 0.19051129035634062`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 68}], {
             RGBColor[
             0.8660950044608668, 0.48393636846669774`, 0.20994293256664392`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 195}], {
             RGBColor[
             0.8384837744462674, 0.29680873085731074`, 0.18448541191193943`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 200}], {
             RGBColor[
             0.8719098756675858, 0.5103403405187334, 0.21479500363706636`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 215}], {
             RGBColor[
             0.9264635101364236, 0.7188538247686493, 0.4669105670802081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 223}], {
             RGBColor[
             0.872589282408941, 0.5134253678517513, 0.21536191727583626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 225}], {
             RGBColor[
             0.9093933228339569, 0.6627226292341221, 0.2529269618420678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 234}], {
             RGBColor[
             0.837571395698585, 0.28979578799570727`, 0.18361171699277434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 255}], {
             RGBColor[
             0.9083890640548784, 0.6593350285611156, 0.24902560612370514`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 282}], {
             RGBColor[
             0.9107404155806164, 0.7089403181351821, 0.5747043826447977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 287}], {
             RGBColor[
             0.899399401089056, 0.6245785965945915, 0.23718537302328563`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 50}], {
             RGBColor[
             0.32229358745653136`, 0.4520407279394575, 0.9418134628870861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 108}], {
             RGBColor[
             0.3180292730157506, 0.448347193101529, 0.9415417445417048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 114}], {
             RGBColor[
             0.29827465777054285`, 0.4308359553953969, 0.9402976725509951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 145}], {
             RGBColor[
             0.280670988716232, 0.4123333830822331, 0.9392951696406466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 169}], {
             RGBColor[
             0.2925815910536258, 0.4248521813146391, 0.9399734608236041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 187}], {
             RGBColor[
             0.32803381097302087`, 0.4570126210374179, 0.9421792248536764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 213}], {
             RGBColor[
             0.3600084250820952, 0.48470742468786476`, 0.9442166189906656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 219}], {
             RGBColor[
             0.2831865614508789, 0.4149774095228705, 0.9394384277864284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 221}], {
             RGBColor[
             0.2933757434234066, 0.4256868858074472, 0.9400186866262199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 264}], {
             RGBColor[
             0.29339971487327476`, 0.42571208132113636`, 0.9400200517648274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 48}], {
             RGBColor[
             0.5288713488786927, 0.6272983725157164, 0.9563690029663805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 74}], {
             RGBColor[
             0.6411369333771564, 0.7195168172815674, 0.9649096076876572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 90}], {
             RGBColor[
             0.5238031310544717, 0.622908536972411, 0.9560460606082701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.5238459246822951, 0.6229456026619612, 0.9560487873803941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 166}], {
             RGBColor[
             0.8183915236203407, 0.8543538869413033, 0.7072534135870767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 177}], {
             RGBColor[
             0.5316337139639098, 0.6296909943120255, 0.956545018426947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 217}], {
             RGBColor[
             0.7255477462839056, 0.7855226808548759, 0.9732794767865461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 233}], {
             RGBColor[
             0.8190741460647206, 0.8558139473261162, 0.781552654000438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 262}], {
             RGBColor[
             0.8190197652374052, 0.8556976322352333, 0.77563363654671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 273}], {
             RGBColor[
             0.6309474410941337, 0.7112445284148133, 0.9641074535297975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 74}], {
             RGBColor[
             0.5259484891930979, 0.6249515173301565, 0.9561210914963576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 84}], {
             RGBColor[
             0.35715044434118537`, 0.4830160061947183, 0.9440058041437522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 90}], {
             RGBColor[
             0.4086146868704133, 0.5283432370210001, 0.9472575444169704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 144}], {
             RGBColor[
             0.3646961975812182, 0.4903032490061542, 0.9444590971150582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 158}], {
             RGBColor[
             0.4086574804982366, 0.5283803027105503, 0.9472602711890945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 175}], {
             RGBColor[
             0.3540970438547585, 0.4798066886867111, 0.9438319175031515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 177}], {
             RGBColor[
             0.4164452697798513, 0.5351256943606145, 0.9477565022356473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 217}], {
             RGBColor[
             0.6103593020998471, 0.6909573809034649, 0.9644909605952465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 252}], {
             RGBColor[
             0.35710710220900627`, 0.48297045086574814`, 0.9440033358734436]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 253}], {
             RGBColor[
             0.3552041377824924, 0.4809703145985687, 0.9438949648645372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 57}], {
             RGBColor[
             0.2418037466004938, 0.3714814472931095, 0.9370817377010874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 84}], {
             RGBColor[
             0.2685862507813846, 0.39963155729606886`, 0.9386069616930247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 112}], {
             RGBColor[
             0.24438397329964223`, 0.374193429149736, 0.9372286777945005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 115}], {
             RGBColor[
             0.22907293102325943`, 0.358100552941108, 0.9363567365875176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 146}], {
             RGBColor[
             0.23350254559126715`, 0.3627563587058691, 0.9366089965841382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 159}], {
             RGBColor[
             0.24197412682758776`, 0.3716605277145155, 0.9370914406029653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 175}], {
             RGBColor[
             0.26553285029495766`, 0.3964222397880617, 0.9384330750524239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 204}], {
             RGBColor[
             0.23371861491604712`, 0.3629834612657993, 0.9366213014125385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 242}], {
             RGBColor[
             0.23849346114208345`, 0.3680021273920998, 0.9368932218413593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 243}], {
             RGBColor[
             0.2273605669768493, 0.3563007497581797, 0.9362592199882902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 253}], {
             RGBColor[
             0.2666399442226916, 0.39758586569991927`, 0.9384961224138098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 280}], {
             RGBColor[
             0.2523064385494426, 0.38252044244058536`, 0.9376798504702395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 292}], {
             RGBColor[
             0.23980801296623738`, 0.36938380470668514`, 0.9369680836230397]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 87}], {
             RGBColor[
             0.314278172622923, 0.4436160187426821, 0.9413569968700557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 108}], {
             RGBColor[
             0.3481847341285709, 0.4760018492537544, 0.9434070012643693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 114}], {
             RGBColor[
             0.32843011888336315`, 0.4584906115476223, 0.9421629292736595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 169}], {
             RGBColor[
             0.3227370521664461, 0.4525068374668645, 0.9418387175462686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 187}], {
             RGBColor[
             0.35818927208584117`, 0.4846672771896433, 0.9440444815763409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 205}], {
             RGBColor[
             0.44094793085644673`, 0.5542815920827796, 0.9498889293247207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 213}], {
             RGBColor[
             0.3901638861949155, 0.5123620808400902, 0.94608187571333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 227}], {
             RGBColor[
             0.30610711869793783`, 0.43502772299278125`, 0.9408916674370189]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 264}], {
             RGBColor[
             0.32355517598609507`, 0.45336673747336176`, 0.9418853084874919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 52}], {
             RGBColor[
             0.9056350707482277, 0.5643614773610739, 0.4604731703909181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 58}], {
             RGBColor[
             0.7712426526188537, 0.8181426903224094, 0.8569941031084208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 66}], {
             RGBColor[
             0.9700089985303242, 0.9755966228942858, 0.8659381168837096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 67}], {
             RGBColor[
             0.9529402270197467, 0.9622638379796367, 0.8739273734917072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 69}], {
             RGBColor[
             0.9933000659558078, 0.9895615584823135, 0.6199821278730931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 86}], {
             RGBColor[
             0.9842148587859489, 0.9592452118717956, 0.5566107984418112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[
             0.9138545722061537, 0.6275401673751994, 0.4683441742696273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 109}], {
             RGBColor[
             0.9573653906056103, 0.9657923433051386, 0.8743494495449171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 110}], {
             RGBColor[
             0.9932540497607107, 0.99147839046011, 0.7614613836320072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 138}], {
             RGBColor[
             0.8501230130531416, 0.8811959449639274, 0.8638775606265587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 141}], {
             RGBColor[
             0.9462822846437602, 0.812940654644517, 0.4968966602614467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 154}], {
             RGBColor[
             0.867381103025232, 0.8946780960164662, 0.8655976857489563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 165}], {
             RGBColor[
             0.986911243979133, 0.9683407522697562, 0.5670857457477134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 179}], {
             RGBColor[
             0.993604348606093, 0.9916232480349453, 0.7556560252196713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 258}], {
             RGBColor[
             0.9776645788146846, 0.9813061421354996, 0.8529792163574066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 281}], {
             RGBColor[
             0.9148192587802333, 0.6349551711119263, 0.4692679592224235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 82}], {
             RGBColor[
             0.90639234718301, 0.5644975000841104, 0.4350476194442515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 86}], {
             RGBColor[
             0.8962878067304835, 0.5320009026523702, 0.26072815279041595`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 107}], {
             RGBColor[
             0.8259275201506884, 0.20029585815577397`, 0.17246152861823205`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 110}], {
             RGBColor[
             0.9053269977052454, 0.5642340812406845, 0.4655787379806119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 141}], {
             RGBColor[
             0.8583552325882947, 0.3856963454250917, 0.20101401461005142`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 165}], {
             RGBColor[
             0.8989841919236675, 0.5410964430503309, 0.2712031000963182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 179}], {
             RGBColor[
             0.9056772965506277, 0.5643789388155198, 0.459773379568276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 193}], {
             RGBColor[
             0.6086028861336337, 0.3287818878860621, 0.5556335731143328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 236}], {
             RGBColor[
             0.7204593344779664, 0.42105333760098257`, 0.5640355482527617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 266}], {
             RGBColor[
             0.5326709863563452, 0.2573632665445422, 0.5510021420640641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 281}], {
             RGBColor[
             0.8268922067247678, 0.207710861892501, 0.1733853135710282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 59}], {
             RGBColor[
             0.8322696375208192, 0.249044151396152, 0.17853474737426642`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 68}], {
             RGBColor[
             0.8530476685227406, 0.3836488270671944, 0.19744878893743584`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 150}], {
             RGBColor[
             0.8968677108265174, 0.6080372180241437, 0.5636073731303677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 170}], {
             RGBColor[
             0.8268112796846933, 0.20708882120003286`, 0.1733078177460588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 192}], {
             RGBColor[
             0.8483576285442167, 0.36235245091138435`, 0.19353530461595575`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 195}], {
             RGBColor[
             0.825436438508141, 0.1965211894578074, 0.17199126828273137`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 200}], {
             RGBColor[
             0.8588625397294595, 0.4100527991192301, 0.2023008600078583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 225}], {
             RGBColor[
             0.8963459868958306, 0.5624350878346187, 0.24043281821285972`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 234}], {
             RGBColor[
             0.8245240597604586, 0.18950824659620397`, 0.17111757336356628`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 255}], {
             RGBColor[
             0.8953417281167521, 0.5590474871616122, 0.23653146249449708`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 282}], {
             RGBColor[
             0.89769307964249, 0.6086527767356787, 0.5622102390155896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 287}], {
             RGBColor[
             0.8863520651509298, 0.5242910551950881, 0.22469122939407754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 72}], {
             RGBColor[
             0.534606977221836, 0.6319372303906756, 0.9568737438527076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 106}], {
             RGBColor[
             0.5370375913061106, 0.6338360445866622, 0.9571160047492481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 151}], {
             RGBColor[
             0.4303399784091667, 0.5471605926069658, 0.9486418607828988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 167}], {
             RGBColor[
             0.585666437251012, 0.671825268631737, 0.9619628736506332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 194}], {
             RGBColor[
             0.4666198015964266, 0.5768869180196359, 0.9514225850947327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 238}], {
             RGBColor[
             0.34796050319161576`, 0.47301253149465217`, 0.9434950557775005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 251}], {
             RGBColor[
             0.3520600889143901, 0.4773214560180356, 0.9437285211196189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 286}], {
             RGBColor[
             0.4882211414959945, 0.5944238588793778, 0.953123121699942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 90}], {
             RGBColor[
             0.3401206359010615, 0.4660537805054501, 0.9430016668956538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 97}], {
             RGBColor[
             0.26708761639868417`, 0.39805639754094285`, 0.9385216166819608]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 134}], {
             RGBColor[
             0.27534778812989436`, 0.40673836175558137`, 0.9389920212422243]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 144}], {
             RGBColor[
             0.2962021466118664, 0.42801379249060423`, 0.9402032195937415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 159}], {
             RGBColor[
             0.26204426941803677`, 0.39275552009761494`, 0.9382344055323761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 235}], {
             RGBColor[
             0.25936698600148883`, 0.38994152547725025`, 0.9380819382024896]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 252}], {
             RGBColor[
             0.2886130512396545, 0.4206809943501981, 0.9397474583521269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 253}], {
             RGBColor[
             0.2867100868131406, 0.4186808580830187, 0.9396390873432205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 292}], {
             RGBColor[
             0.25987815555668636`, 0.39047879708978456`, 0.9381110485524506]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 79}], {
             RGBColor[
             0.47131158576889715`, 0.5800856534095411, 0.9519605579459619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 93}], {
             RGBColor[
             0.5394509250519448, 0.6369895888012234, 0.9568866993753897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 160}], {
             RGBColor[
             0.5689561966042058, 0.6609432974446849, 0.9592094624333546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 164}], {
             RGBColor[
             0.46580833431938506`, 0.5753190136054342, 0.9516098956299331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 168}], {
             RGBColor[
             0.46678271330407606`, 0.5761629717082618, 0.9516719821972282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 246}], {
             RGBColor[
             0.57328015808247, 0.6644536841649844, 0.9595498605201163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 296}], {
             RGBColor[
             0.6219639893106997, 0.70315209105388, 0.9639467061714042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.27383547980684575`, 0.4051488298221716, 0.9389058975204863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 89}], {
             RGBColor[
             0.26259271630004477`, 0.3933319725441461, 0.9382656387709521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 112}], {
             RGBColor[
             0.24963320232510341`, 0.37971070167583876`, 0.9375276136219621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 115}], {
             RGBColor[
             0.2343221600487206, 0.3636178254672108, 0.9366556724149793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 134}], {
             RGBColor[
             0.26052687456490653`, 0.3911606418985847, 0.938147992140275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 146}], {
             RGBColor[
             0.23875177461672836`, 0.3682736312319718, 0.9369079324115999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 159}], {
             RGBColor[
             0.24722335585304894`, 0.3771778002406183, 0.937390376430427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 175}], {
             RGBColor[
             0.27078207932041887`, 0.40193951231416447`, 0.9387320108798856]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 204}], {
             RGBColor[
             0.23896784394150833`, 0.36850073379190207`, 0.9369202372400001]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 235}], {
             RGBColor[
             0.24454607243650103`, 0.3743638056202535, 0.9372379091005405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 242}], {
             RGBColor[
             0.24374269016754463`, 0.3735193999182025, 0.9371921576688209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 243}], {
             RGBColor[
             0.23260979600231052`, 0.3618180222842825, 0.9365581558157519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 253}], {
             RGBColor[
             0.27188917324815276`, 0.40310313822602206`, 0.9387950582412713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 280}], {
             RGBColor[
             0.2575556675749038, 0.38803771496668804`, 0.9379787862977012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 292}], {
             RGBColor[
             0.2450572419916986, 0.37490107723278787`, 0.9372670194505013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 66}], {
             RGBColor[
             0.747689528345485, 0.802133526636196, 0.966576403949817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 67}], {
             RGBColor[
             0.7306207568349073, 0.7888007417215468, 0.9745656605578148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 73}], {
             RGBColor[
             0.4389666532110068, 0.5520366798791193, 0.9499088011180912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 95}], {
             RGBColor[
             0.5187848450827122, 0.6202119340859072, 0.9552597898578664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 96}], {
             RGBColor[
             0.47719454661287236`, 0.585147759754026, 0.9523446486820593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 109}], {
             RGBColor[
             0.7350459204207711, 0.7923292470470489, 0.9749877366110247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 138}], {
             RGBColor[
             0.6278035428683023, 0.7077328487058376, 0.9645158476926661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 140}], {
             RGBColor[
             0.4384985979215843, 0.5516312739125644, 0.9498789770489342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 154}], {
             RGBColor[
             0.6450616328403926, 0.7212149997583763, 0.9662359728150638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 171}], {
             RGBColor[
             0.48363824484440066`, 0.5907289672924857, 0.9527552354354336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 198}], {
             RGBColor[
             0.506589269540044, 0.610311016455952, 0.9542997094772824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[
             0.48666290222101594`, 0.5933487734884098, 0.952947963928872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 62}], {
             RGBColor[
             0.9138294445361559, 0.6222945482383531, 0.42987348446131357`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 100}], {
             RGBColor[
             0.8414952433239204, 0.3199562002850287, 0.1873691979101476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 125}], {
             RGBColor[
             0.9127176607588363, 0.6199165551572493, 0.3088626814342206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 137}], {
             RGBColor[
             0.8391881810125934, 0.30222310839901756`, 0.1851599524353666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 170}], {
             RGBColor[
             0.8273517976845952, 0.21124347940377694`, 0.17382541839319265`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 192}], {
             RGBColor[
             0.8488981465441187, 0.3665071091151284, 0.1940529052630896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 195}], {
             RGBColor[
             0.825976956508043, 0.20067584766155147`, 0.17250886892986522`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 200}], {
             RGBColor[
             0.8594030577293614, 0.41420745732297415`, 0.20281846065499215`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 225}], {
             RGBColor[
             0.8968865048957325, 0.5665897460383628, 0.24095041885999358`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 228}], {
             RGBColor[
             0.8245766992197552, 0.5548258112486377, 0.5806907356901773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 255}], {
             RGBColor[
             0.895882246116654, 0.5632021453653563, 0.23704906314163093`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.9605795624965958, 0.8682632028416796, 0.48244356084256446`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 85}], {
             RGBColor[
             0.9228540566499766, 0.8416985659067688, 0.6257891591988634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 100}], {
             RGBColor[
             0.8881313902235266, 0.565681082313474, 0.22753422766752193`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 121}], {
             RGBColor[
             0.9603462863275016, 0.8677642487038257, 0.4570528894502983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 125}], {
             RGBColor[
             0.9593538076584427, 0.8656414371856946, 0.3490277111915949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 127}], {
             RGBColor[
             0.879427272019672, 0.4987774156297289, 0.21919915424561515`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.9594950595498875, 0.8659435606987382, 0.3644021078697419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 137}], {
             RGBColor[
             0.8858243279121996, 0.5479479904274629, 0.22532498219274089`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 170}], {
             RGBColor[
             0.8739879445842015, 0.4569683614322223, 0.21399044815056695`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 232}], {
             RGBColor[
             0.9600894947352094, 0.8672149974535253, 0.4291027093633025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 240}], {
             RGBColor[
             0.9605080040332614, 0.868110146524278, 0.47465486371626864`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 256}], {
             RGBColor[
             0.9606652122328164, 0.8684463989669389, 0.49176600606128196`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 299}], {
             RGBColor[
             0.9602834986478392, 0.8683179033755875, 0.5002256256588694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 177}], {
             RGBColor[
             0.49302351294995017`, 0.5983715477396933, 0.9534876687205165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 217}], {
             RGBColor[
             0.686937545269946, 0.7542032342825437, 0.9702221270801157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 247}], {
             RGBColor[
             0.5729638190353659, 0.6641968658756336, 0.9595249571515402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 267}], {
             RGBColor[
             0.517343318582302, 0.6190416379328455, 0.9551463076112685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 273}], {
             RGBColor[
             0.5923372400801741, 0.6799250818424811, 0.9610501038233672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 285}], {
             RGBColor[
             0.474805368949063, 0.5825919070766665, 0.9523268246944521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 82}], {
             RGBColor[
             0.9949627046124243, 0.9916340594516913, 0.6930996675251034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 100}], {
             RGBColor[
             0.9225145323393552, 0.6890519389234857, 0.4381903343500609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 127}], {
             RGBColor[
             0.9138104141355006, 0.6221482722397406, 0.4298552609281541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 130}], {
             RGBColor[
             0.5868878667757954, 0.648392143438405, 0.8070978104506135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 137}], {
             RGBColor[
             0.9202074700280282, 0.6713188470374746, 0.43598108887527987`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 170}], {
             RGBColor[
             0.9083710867000301, 0.580339218042234, 0.42464655483310587`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 192}], {
             RGBColor[
             0.9299174355595534, 0.7356028477535854, 0.4448740417030029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 195}], {
             RGBColor[
             0.9069962455234778, 0.5697715863000085, 0.4233300053697785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 199}], {
             RGBColor[
             0.5868878667757954, 0.648392143438405, 0.8070978104506135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 220}], {
             RGBColor[
             0.6260202363274255, 0.6895227449727015, 0.8093263410054259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 225}], {
             RGBColor[
             0.9779057939111673, 0.9356854846768198, 0.49177155529990685`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 226}], {
             RGBColor[
             0.5868878718865363, 0.6483921488101179, 0.8070978107416625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 228}], {
             RGBColor[
             0.90559598823519, 0.9239215498870947, 0.8315118721300905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 255}], {
             RGBColor[
             0.9769015351320889, 0.9322978840038133, 0.4878701995815442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 131}], {
             RGBColor[
             0.32467225096411007`, 0.4556365181084638, 0.9419088066284024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 139}], {
             RGBColor[
             0.28999599813964694`, 0.42067676560446166`, 0.9398795920978575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 143}], {
             RGBColor[
             0.36063166824627285`, 0.4867827579854089, 0.9442001088999576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 172}], {
             RGBColor[
             0.29700434513925705`, 0.4280429826559164, 0.940278707091565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 174}], {
             RGBColor[
             0.35841838866408615`, 0.48486572645398507`, 0.944059080682107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 183}], {
             RGBColor[
             0.28955139027076127`, 0.4202094545444958, 0.939854272337463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 283}], {
             RGBColor[
             0.4716182093057971, 0.5784225844464469, 0.9525129877054703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 92}], {
             RGBColor[
             0.24737632360791623`, 0.3773385790496996, 0.9373990877177711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 145}], {
             RGBColor[
             0.2514296244944172, 0.3815988552755316, 0.937629917206936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 153}], {
             RGBColor[
             0.253568524812987, 0.38384697512446136`, 0.9377517244158591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 211}], {
             RGBColor[
             0.238007335368493, 0.36749117838190204`, 0.936865537697712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 219}], {
             RGBColor[
             0.2539451972290641, 0.384242881716169, 0.9377731753527179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 221}], {
             RGBColor[
             0.26413437920159183`, 0.3949523580007457, 0.9383534341925093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 80}], {
             RGBColor[
             0.27787319023653523`, 0.40939271948940265`, 0.9391358391561999]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 103}], {
             RGBColor[
             0.2833667383517215, 0.41516678686953135`, 0.9394486885943836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 116}], {
             RGBColor[
             0.3051622199360282, 0.4368120893539453, 0.940736158424998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 133}], {
             RGBColor[
             0.3190318248130566, 0.44882524399181684`, 0.9416199173833522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 152}], {
             RGBColor[
             0.270606352963235, 0.4017548127710696, 0.9387220035238077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 162}], {
             RGBColor[
             0.28622167127698683`, 0.41816750238718753`, 0.9396112728009827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[
             0.33323684341077736`, 0.46112891713616844`, 0.9425250486073942]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 241}], {
             RGBColor[
             0.2834960053804121, 0.4153026547126882, 0.9394560501604341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 277}], {
             RGBColor[
             0.318505826054183, 0.44836965030434695`, 0.9415864012075592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 67}], {
             RGBColor[
             0.9293871027463778, 0.9462546742934231, 0.9835096743331035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 69}], {
             RGBColor[
             0.9697469416824389, 0.9735523947961, 0.7295644287144893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 95}], {
             RGBColor[
             0.7175511909941827, 0.7776658666577836, 0.9642038036331552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 109}], {
             RGBColor[
             0.9338122663322416, 0.9497831796189251, 0.9839317503863134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 110}], {
             RGBColor[
             0.969700925487342, 0.9754692267738965, 0.8710436844734033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 138}], {
             RGBColor[
             0.8265698887797728, 0.8651867812777139, 0.9734598614679548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 154}], {
             RGBColor[
             0.8438279787518632, 0.8786689323302527, 0.9751799865903525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 179}], {
             RGBColor[
             0.9700512243327243, 0.9756140843487318, 0.8652383260610674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 258}], {
             RGBColor[
             0.9541114545413159, 0.9652969784492861, 0.9625615171988029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 69}], {
             RGBColor[
             0.9526781701718614, 0.9602196098814508, 0.7375536853224871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 86}], {
             RGBColor[
             0.9435929630020026, 0.929903263270933, 0.6741823558912051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 95}], {
             RGBColor[
             0.7004824194836051, 0.7643330817431344, 0.9721930602411528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 109}], {
             RGBColor[
             0.916743494821664, 0.9364503947042759, 0.9919210069943111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 110}], {
             RGBColor[
             0.9526321539767644, 0.9621364418592473, 0.8790329410814011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 138}], {
             RGBColor[
             0.8095011172691953, 0.8518539963630647, 0.9814491180759526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 154}], {
             RGBColor[
             0.8267592072412856, 0.8653361474156035, 0.9831692431983503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 179}], {
             RGBColor[
             0.9529824528221467, 0.9622812994340826, 0.8732275826690652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 258}], {
             RGBColor[
             0.9370426830307382, 0.9519641935346369, 0.9705507738068005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 215}], {
             RGBColor[
             0.9347347232001206, 0.7573256172439325, 0.47384806566130333`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 223}], {
             RGBColor[
             0.880860495472638, 0.5518971603270344, 0.22229941585693147`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 234}], {
             RGBColor[
             0.8458426087622819, 0.3282675804709904, 0.19054921557386956`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 255}], {
             RGBColor[
             0.9166602771185755, 0.6978068210363987, 0.2559631047048003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 271}], {
             RGBColor[
             0.9259155815977133, 0.7290271362933656, 0.2919182148886562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 274}], {
             RGBColor[
             0.9194708353599413, 0.7072874939349834, 0.2668815927431183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 287}], {
             RGBColor[
             0.9076706141527531, 0.6630503890698746, 0.24412287160438084`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 109}], {
             RGBColor[
             0.957103333757725, 0.9637481152069529, 0.737975761375697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 110}], {
             RGBColor[
             0.9929919929128255, 0.9894341623619243, 0.625087695462787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 113}], {
             RGBColor[
             0.9762236487706943, 0.9783827123378863, 0.71860105300982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 135}], {
             RGBColor[
             0.9915668730357023, 0.9888448386688236, 0.6487056199187353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 138}], {
             RGBColor[
             0.8498609562052564, 0.8791517168657417, 0.7275038724573385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 224}], {
             RGBColor[
             0.9812813612748328, 0.9481895871324358, 0.4098590677551779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 249}], {
             RGBColor[
             0.9058089885195326, 0.5656683412312807, 0.3245169720093974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 254}], {
             RGBColor[
             0.9421799602264942, 0.7934586684310521, 0.3573185586987633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 258}], {
             RGBColor[
             0.9774025219667993, 0.9792619140373138, 0.7166055281881865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 288}], {
             RGBColor[
             0.9274695616660017, 0.7266621842687284, 0.34504384155502377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[
             0.27137415800540265`, 0.40256182455203926`, 0.9387657288850935]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 251}], {
             RGBColor[
             0.27547374372817707`, 0.40687074907542276`, 0.9389991942272118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 300}], {
             RGBColor[
             0.2600472811884571, 0.39065655885195993`, 0.938120680006981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 85}], {
             RGBColor[
             0.7746111080065263, 0.8244612139777192, 0.9780896021036154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 98}], {
             RGBColor[
             0.5262018737865255, 0.625404972246536, 0.9560725859325541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 121}], {
             RGBColor[
             0.8121033376840514, 0.8505268967747761, 0.8093533323550504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 122}], {
             RGBColor[
             0.6268946494046528, 0.707980343525642, 0.9637705896733515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 136}], {
             RGBColor[
             0.8112521109064372, 0.8487062087696886, 0.716702550774494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 160}], {
             RGBColor[
             0.6099082730566356, 0.6941900379787878, 0.9624333599040888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 181}], {
             RGBColor[
             0.6717068148993812, 0.7432662316253906, 0.9680467833618187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 207}], {
             RGBColor[
             0.6875924129964879, 0.7556761815938675, 0.9696301113207838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 232}], {
             RGBColor[
             0.8118465460917592, 0.8499776455244756, 0.7814031522680547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 240}], {
             RGBColor[
             0.8122650553898112, 0.8508727945952284, 0.8269553066210207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 246}], {
             RGBColor[
             0.6142322345348998, 0.6977004246990872, 0.9627737579908505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 256}], {
             RGBColor[
             0.8124222635893662, 0.8512090470378892, 0.8440664489660341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 296}], {
             RGBColor[
             0.6629160657631297, 0.7363988315879828, 0.9671706036421385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 299}], {
             RGBColor[
             0.812040550004389, 0.8510805514465378, 0.8525260685636215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 106}], {
             RGBColor[
             0.6542381545327312, 0.7298150858058879, 0.966172003106812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 151}], {
             RGBColor[
             0.5475405416357872, 0.6431396338261914, 0.9576978591404627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 194}], {
             RGBColor[
             0.5838203648230471, 0.6728659592388615, 0.9604785834522965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 215}], {
             RGBColor[
             0.8234553846620669, 0.8600796725778928, 0.8483727211925696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 247}], {
             RGBColor[
             0.6154478937421781, 0.6985426120193529, 0.9629684183842664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 267}], {
             RGBColor[
             0.5598273932891142, 0.6533873840765647, 0.9585897688439947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 286}], {
             RGBColor[
             0.6054217047226151, 0.6904029000986035, 0.9621791200575058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 87}], {
             RGBColor[
             0.3025587103322468, 0.4334652095438001, 0.9406102430960075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 95}], {
             RGBColor[
             0.4088283158597046, 0.5275690199007069, 0.9475362008014293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 96}], {
             RGBColor[
             0.3672380173898648, 0.4925048455688256, 0.9446210596256222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 105}], {
             RGBColor[
             0.30909022810020703`, 0.4403302488400713, 0.9409822033703782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 140}], {
             RGBColor[
             0.3285420686985767, 0.45898835972736407`, 0.9421553879924971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 149}], {
             RGBColor[
             0.3114795465639533, 0.4428415740370091, 0.9411182715222086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 171}], {
             RGBColor[
             0.3736817156213931, 0.4980860531072854, 0.9450316463789965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 245}], {
             RGBColor[
             0.37670637299800835`, 0.5007058593032094, 0.9452243748724349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 289}], {
             RGBColor[
             0.309996695985159, 0.44128300406053933`, 0.9410338253754271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 298}], {
             RGBColor[
             0.307131102255913, 0.43827108336196546`, 0.9408706340518126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 90}], {
             RGBColor[
             0.5208802713688769, 0.620561681786851, 0.9557981491382472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 123}], {
             RGBColor[
             0.5372173592410554, 0.6347120461758202, 0.9568391339311428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 158}], {
             RGBColor[
             0.5209230649967003, 0.6205987474764012, 0.9558008759103712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 233}], {
             RGBColor[
             0.8161512863791258, 0.8534670921405562, 0.7813047425304152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 257}], {
             RGBColor[
             0.5147596974188978, 0.6152603482603705, 0.9554081515783656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 259}], {
             RGBColor[
             0.5512374616169957, 0.646558430162153, 0.9578145787092965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 262}], {
             RGBColor[
             0.8160969055518104, 0.8533507770496733, 0.7753857250766871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 124}], {
             RGBColor[
             0.8391031020269322, 0.8749559056354701, 0.9735996156850079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 142}], {
             RGBColor[
             0.6947680744610263, 0.7614773672926725, 0.9702116467516284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 143}], {
             RGBColor[
             0.5636312232942053, 0.6537338940348352, 0.9601379235387875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 150}], {
             RGBColor[
             0.8462593507356758, 0.8802930242051693, 0.9614859532696918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 167}], {
             RGBColor[
             0.7422194299230214, 0.7985467268232416, 0.9749411544059516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 174}], {
             RGBColor[
             0.5614179437120186, 0.6518168625034114, 0.9599968953209368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 185}], {
             RGBColor[
             0.6492913495741017, 0.7248125960357876, 0.9664570141991338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 237}], {
             RGBColor[
             0.6846458552140906, 0.7535149764166593, 0.969240250390935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 239}], {
             RGBColor[
             0.5708233361978141, 0.6599633407458361, 0.9605961986132696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 282}], {
             RGBColor[
             0.8470847195516484, 0.8809085829167043, 0.9600888191549137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 283}], {
             RGBColor[
             0.6746177643537297, 0.7453737204958732, 0.9684508023443001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 295}], {
             RGBColor[
             0.7838985892899054, 0.8312466386518764, 0.9790582353871675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 297}], {
             RGBColor[
             0.7454557140194038, 0.8010749365560057, 0.9752637169598848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 99}], {
             RGBColor[
             0.3308920068686242, 0.45968772172522177`, 0.9423540428096366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[
             0.2896837321277139, 0.4218063478486378, 0.9398084320447715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 128}], {
             RGBColor[
             0.2667781164198233, 0.397731093439728, 0.9385039911160289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[
             0.3201380287875101, 0.4503731664220151, 0.9416688088356775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 201}], {
             RGBColor[
             0.3077043294157084, 0.43960372096206174`, 0.9408765445063949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 209}], {
             RGBColor[
             0.2797259704782522, 0.4113401089964994, 0.9392413522500229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 218}], {
             RGBColor[
             0.2751691719679872, 0.4065506248444982, 0.9389818493160426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 229}], {
             RGBColor[
             0.32034218545595194`, 0.4505499966670069, 0.9416818175180619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 261}], {
             RGBColor[
             0.3474685023612617, 0.4740454489620557, 0.9434102824444082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 284}], {
             RGBColor[
             0.2749699198453155, 0.406341198230256, 0.9389705022024235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 91}], {
             RGBColor[
             0.25932242623621204`, 0.38989469033869195`, 0.9380794005897775]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 162}], {
             RGBColor[
             0.26527957680517633`, 0.3961560332918348, 0.9384186515018654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 191}], {
             RGBColor[
             0.24496070190330402`, 0.37479960747889, 0.9372615216352855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 203}], {
             RGBColor[
             0.25281317669126346`, 0.38305305635669296`, 0.9377087084577643]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 206}], {
             RGBColor[
             0.2413530899135048, 0.3710077785417997, 0.9370560734694501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 244}], {
             RGBColor[
             0.2442718082387917, 0.3740755365591065, 0.9372222901602183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 270}], {
             RGBColor[
             0.23714390206690406`, 0.36658365523709874`, 0.9368163664485216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 118}], {
             RGBColor[
             0.17948494456776543`, 0.30598043511645023`, 0.9335327741177293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 120}], {
             RGBColor[
             0.1849774474258748, 0.3117534038651181, 0.9338455640300687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 130}], {
             RGBColor[
             0.17948366008578914`, 0.30597908504445237`, 0.9335327009683809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 176}], {
             RGBColor[
             0.17949609924511575`, 0.30599215938959284`, 0.9335334093601024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 193}], {
             RGBColor[
             0.2897690368730418, 0.4135053888596902, 0.9401205117129523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.17948366008578914`, 0.30597908504445237`, 0.9335327009683809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 220}], {
             RGBColor[
             0.21861602963741927`, 0.34710968657874874`, 0.9357612315231933]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 226}], {
             RGBColor[
             0.17948366519653014`, 0.30597909041616517`, 0.9335327012594301]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 236}], {
             RGBColor[
             0.4016254852173745, 0.5057768385746106, 0.9485224868513811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 266}], {
             RGBColor[
             0.21383713709575333`, 0.3420867675181703, 0.9354890806626834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 93}], {
             RGBColor[
             0.46307011169266854`, 0.5733948534802826, 0.9513117589171669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 103}], {
             RGBColor[
             0.33687382527310783`, 0.4634377566971172, 0.9427875991368931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 116}], {
             RGBColor[
             0.3586693068574145, 0.48508305918153105`, 0.9440750689675076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 119}], {
             RGBColor[
             0.3385777508483834, 0.465228690511853, 0.9428846351776731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 164}], {
             RGBColor[
             0.38942752096010885`, 0.5117242782844935, 0.9460349551717104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 168}], {
             RGBColor[
             0.3904018999447999, 0.5125682363873212, 0.9460970417390054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 241}], {
             RGBColor[
             0.3370030923017984, 0.46357362454027395`, 0.9427949607029437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[
             0.3720129129755694, 0.49664062013193266`, 0.9449253117500688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 103}], {
             RGBColor[
             0.2733233300214085, 0.4046105279255051, 0.9388767313478634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 116}], {
             RGBColor[
             0.2951188116057152, 0.426255830409919, 0.9401642011784779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 133}], {
             RGBColor[
             0.30898841648274356`, 0.43826898504779055`, 0.941047960136832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 152}], {
             RGBColor[
             0.26056294463292196`, 0.39119855382704327`, 0.9381500462772876]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 210}], {
             RGBColor[
             0.3231934350804644, 0.45057265819214215`, 0.941953091360874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 241}], {
             RGBColor[
             0.27345259705009906`, 0.4047463957686619, 0.938884092913914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 277}], {
             RGBColor[
             0.30846241772387, 0.4378133913603206, 0.9410144439610391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 180}], {
             RGBColor[
             0.26493370488523493`, 0.3957924999744301, 0.9383989546076965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[
             0.3818442604921369, 0.5035684061042389, 0.9457044452357559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 285}], {
             RGBColor[
             0.33930631085889784`, 0.4671186752480599, 0.9428849623189395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 100}], {
             RGBColor[
             0.9226285034001888, 0.6892957114983669, 0.45059538097393753`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 107}], {
             RGBColor[
             0.9146118486409361, 0.6276761900982359, 0.44291862332296067`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 127}], {
             RGBColor[
             0.9139243851963341, 0.6223920448146217, 0.4422603075520308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 137}], {
             RGBColor[
             0.9203214410888617, 0.6715626196123557, 0.4483861354991565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 192}], {
             RGBColor[
             0.930031406620387, 0.7358466203284666, 0.4572790883268795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 199}], {
             RGBColor[
             0.587001837836629, 0.6486359160132862, 0.81950285707449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 220}], {
             RGBColor[
             0.6261342073882591, 0.6897665175475827, 0.8217313876293025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 226}], {
             RGBColor[
             0.5870018429473699, 0.648635921384999, 0.8195028573655392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 228}], {
             RGBColor[
             0.9057099592960236, 0.9241653224619759, 0.8439169187539672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 266}], {
             RGBColor[
             0.6213553148465931, 0.6847435984870042, 0.8214592367687926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 281}], {
             RGBColor[
             0.9155765352150156, 0.6350911938349629, 0.44384240827575683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 126}], {
             RGBColor[
             0.22111352999763184`, 0.3497347178080009, 0.9359034604739869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 155}], {
             RGBColor[
             0.21429563561346426`, 0.34256867853076955`, 0.9355151914749793]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 156}], {
             RGBColor[
             0.221993745626472, 0.35065988024280614`, 0.935953587451887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 184}], {
             RGBColor[
             0.22686279734830417`, 0.3557775623181615, 0.9362308727443287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[
             0.21339436331142053`, 0.34162138419735716`, 0.9354638653506908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 202}], {
             RGBColor[
             0.22220476853383342`, 0.3508816786980681, 0.9359656048942807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 214}], {
             RGBColor[
             0.21458531177906248`, 0.342873146547343, 0.9355316881040727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 275}], {
             RGBColor[
             0.214533530595458, 0.34281872124025803`, 0.9355287392422698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 293}], {
             RGBColor[
             0.21277489873276917`, 0.34097028764887183`, 0.9354285877593523]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 89}], {
             RGBColor[
             0.2893752204809355, 0.4214820825471055, 0.9397908627628895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.35208222651696447`, 0.4786261706514128, 0.9436828617856419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 112}], {
             RGBColor[
             0.2764157065059942, 0.4078608116787981, 0.9390528376138995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 134}], {
             RGBColor[
             0.2873093787457973, 0.41931075190154404`, 0.9396732161322123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 144}], {
             RGBColor[
             0.30816373722776935`, 0.4405861826365669, 0.9408844144837296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 158}], {
             RGBColor[
             0.35212502014478775`, 0.47866323634096297`, 0.943685588557766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 159}], {
             RGBColor[
             0.27400586003393973`, 0.4053279102435776, 0.9389156004223643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 175}], {
             RGBColor[
             0.29756458350130965`, 0.4300896223171238, 0.940257234871823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 252}], {
             RGBColor[
             0.30057464185555743`, 0.4332533844961608, 0.9404286532421151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 253}], {
             RGBColor[
             0.29867167742904355`, 0.43125324822898137`, 0.9403202822332086]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 280}], {
             RGBColor[
             0.28433817175579457`, 0.41618782496964746`, 0.9395040102896386]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 292}], {
             RGBColor[
             0.2718397461725893, 0.40305118723574723`, 0.9387922434424387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[
             0.9571178936575444, 0.9648142409538079, 0.8234596411130128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 122}], {
             RGBColor[
             0.7719092053781459, 0.8222676877046737, 0.9778768984313139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 136}], {
             RGBColor[
             0.9562666668799304, 0.9629935529487204, 0.7308088595324563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 165}], {
             RGBColor[
             0.9499430145672961, 0.9419121380578821, 0.6850057931573457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 181}], {
             RGBColor[
             0.8167213708728744, 0.8575535758044224, 0.9821530921197811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 207}], {
             RGBColor[
             0.8326069689699811, 0.8699635257728993, 0.9837364200787462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 232}], {
             RGBColor[
             0.9568611020652522, 0.9642649897035074, 0.7955094610260169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 240}], {
             RGBColor[
             0.9572796113633043, 0.9651601387742601, 0.8410616153789832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 246}], {
             RGBColor[
             0.759246790508393, 0.811987768878119, 0.9768800667488129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 256}], {
             RGBColor[
             0.9574368195628593, 0.965496391216921, 0.8581727577239964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 296}], {
             RGBColor[
             0.8079306217366228, 0.8506861757670146, 0.9812769124001008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 299}], {
             RGBColor[
             0.9570551059778822, 0.9653678956255696, 0.8666323773215838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 107}], {
             RGBColor[
             0.9045073081884096, 0.5951795926664958, 0.26859915666912515`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 109}], {
             RGBColor[
             0.9480181265878662, 0.9334317685964351, 0.674604431944415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 110}], {
             RGBColor[
             0.9839067857429666, 0.9591178157514064, 0.561716366031505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 141}], {
             RGBColor[
             0.936935020626016, 0.7805800799358134, 0.2971516426609445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 165}], {
             RGBColor[
             0.9775639799613888, 0.9359801775610526, 0.3673407281472113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 179}], {
             RGBColor[
             0.9842570845883489, 0.9592626733262417, 0.5559110076191691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 240}], {
             RGBColor[
             0.984900576757397, 0.9592281782774306, 0.5233965503688487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 281}], {
             RGBColor[
             0.9054719947624891, 0.6025945964032228, 0.26952294162192125`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 149}], {
             RGBColor[
             0.2850281329082009, 0.41691301788689017`, 0.939543302556562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 187}], {
             RGBColor[
             0.3200183961394125, 0.4485879118406425, 0.9417227588366461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 227}], {
             RGBColor[
             0.2679362427515092, 0.39894835764378045`, 0.938569944697324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 264}], {
             RGBColor[
             0.2853843000396664, 0.4172873721243609, 0.939563585747797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 99}], {
             RGBColor[
             0.43585477652737337`, 0.5505550934269655, 0.9493751482779511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[
             0.7318152240398965, 0.7888182862268713, 0.9538534747537719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 198}], {
             RGBColor[
             0.48423825814620036`, 0.592165458504841, 0.9525401559859066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 201}], {
             RGBColor[
             0.41266709907445764`, 0.5304710926638055, 0.9478976499747094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 222}], {
             RGBColor[
             0.47017691950032614`, 0.5802832085890723, 0.9515621248783083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 258}], {
             RGBColor[
             0.7329940972360016, 0.7896974879262988, 0.9518579499321382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 260}], {
             RGBColor[
             0.6766874696871867, 0.7454723343623321, 0.9697937614112038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 261}], {
             RGBColor[
             0.4524312720200109, 0.5649128206637994, 0.9504313879127225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 278}], {
             RGBColor[
             0.553576335347311, 0.6484572332214837, 0.9579987034169237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 290}], {
             RGBColor[
             0.558574938782711, 0.6525153246748602, 0.9583922117898461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 111}], {
             RGBColor[
             0.26057341862775985`, 0.3912095626597075, 0.9381506427557986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 112}], {
             RGBColor[
             0.26517294299919314`, 0.39604395440077267`, 0.9384125788643654]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 175}], {
             RGBColor[
             0.28632181999450856`, 0.4182727650390983, 0.9396169761222888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 177}], {
             RGBColor[
             0.3486700459196015, 0.47359177071300174`, 0.9435415608547846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 242}], {
             RGBColor[
             0.2592824308416344, 0.3898526526431364, 0.9380771229112241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.27309540824899353`, 0.40437096769162195`, 0.9388637515401044]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 285}], {
             RGBColor[
             0.3304519019187142, 0.457812130049975, 0.9423807168287202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 123}], {
             RGBColor[
             0.4198835569183708, 0.5381037658666636, 0.9479755868517558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 134}], {
             RGBColor[
             0.3387736212750252, 0.46463798272782586`, 0.9429249564054306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 144}], {
             RGBColor[
             0.35962797975699734`, 0.48591341346284866`, 0.9441361547569478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 158}], {
             RGBColor[
             0.4035892626740157, 0.5239904671672448, 0.9469373288309841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 252}], {
             RGBColor[
             0.35203888438478537`, 0.4785806153224426, 0.9436803935153333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 253}], {
             RGBColor[
             0.3501359199582715, 0.4765804790552632, 0.9435720225064269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[
             0.39742589509621323`, 0.518652067951214, 0.9465446044989785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 102}], {
             RGBColor[
             0.3289676178309032, 0.4560161547537128, 0.9423048264494448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 162}], {
             RGBColor[
             0.27856959341816107`, 0.4101246833878033, 0.9391754982871572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 191}], {
             RGBColor[
             0.2582507185162887, 0.38876825757485856`, 0.9380183684205773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 203}], {
             RGBColor[
             0.2661031933042482, 0.39702170645266144`, 0.9384655552430561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 239}], {
             RGBColor[
             0.3418733579527955, 0.46719445818593675`, 0.9431271687979139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 153}], {
             RGBColor[
             0.26728945052082176`, 0.3982685380003319, 0.9385331108366297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 163}], {
             RGBColor[
             0.25122830224652154`, 0.3813872528284255, 0.937618452202748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 189}], {
             RGBColor[
             0.2464728493758267, 0.3763889703481986, 0.937347636196824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 211}], {
             RGBColor[
             0.2517282610763278, 0.3819127412577725, 0.9376469241184826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 216}], {
             RGBColor[
             0.25996759819388404`, 0.3905728069724701, 0.9381161421783205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 221}], {
             RGBColor[
             0.27785530490942656`, 0.40937392087661617`, 0.9391348206132799]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 94}], {
             RGBColor[
             0.6965792865266065, 0.7615288190518337, 0.9714662855765266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 160}], {
             RGBColor[
             0.5607147225279772, 0.6542524975154264, 0.9585606634045596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 164}], {
             RGBColor[
             0.45756686024315646`, 0.5686282136761757, 0.9509610966011381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 168}], {
             RGBColor[
             0.4585412392278475, 0.5694721717790032, 0.9510231831684333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 277}], {
             RGBColor[
             0.440152252258617, 0.5535445555236148, 0.9498514531794966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 124}], {
             RGBColor[
             0.9048214633960636, 0.926634777474092, 0.9800597975853467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 125}], {
             RGBColor[
             0.9272871440372241, 0.9396965749731525, 0.7126838428267497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 142}], {
             RGBColor[
             0.7604864358301577, 0.8131562391312941, 0.9766718286519673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 150}], {
             RGBColor[
             0.9119777121048072, 0.931971896043791, 0.9679461351700305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 200}], {
             RGBColor[
             0.8739725410077492, 0.7339874771388775, 0.6066396220475212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.7503642165832218, 0.805193848255281, 0.9757004322912739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 295}], {
             RGBColor[
             0.8496169506590368, 0.8829255104904983, 0.9855184172875062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 96}], {
             RGBColor[
             0.44705620926157014`, 0.5606800997756136, 0.9499720483653973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 105}], {
             RGBColor[
             0.3889084199719124, 0.5085055030468593, 0.9463331921101534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 109}], {
             RGBColor[
             0.7049075830694689, 0.7678615870686365, 0.9726151362943627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 138}], {
             RGBColor[
             0.5976652055170001, 0.6832651887274253, 0.9621432473760043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 140}], {
             RGBColor[
             0.4083602605702821, 0.527163613934152, 0.9475063767322723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 154}], {
             RGBColor[
             0.6149232954890904, 0.696747339779964, 0.9638633724984019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 171}], {
             RGBColor[
             0.45349990749309843`, 0.5662613073140733, 0.9503826351187716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 198}], {
             RGBColor[
             0.4764509321887418, 0.5858433564775396, 0.9519271091606205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 245}], {
             RGBColor[
             0.4565245648697137, 0.5688811135099974, 0.9505753636122101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 289}], {
             RGBColor[
             0.38981488785686436`, 0.5094582582673273, 0.9463848141152024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 105}], {
             RGBColor[
             0.3473181215020726, 0.473441328714978, 0.9434180509343462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 138}], {
             RGBColor[
             0.5560749070471602, 0.6482010143955439, 0.959228106200197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 140}], {
             RGBColor[
             0.36676996210044227`, 0.49209943960227065`, 0.9445912355564652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 171}], {
             RGBColor[
             0.4119096090232586, 0.5311971329821921, 0.9474674939429645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 196}], {
             RGBColor[
             0.34319916551880214`, 0.4691120448196677, 0.9431834824845483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 198}], {
             RGBColor[
             0.43486063371890193`, 0.5507791821456584, 0.9490119679848132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 222}], {
             RGBColor[
             0.4207992950730278, 0.5388969322298897, 0.948033936877215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 245}], {
             RGBColor[
             0.41493426639987385`, 0.5338169391781161, 0.9476602224364029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 278}], {
             RGBColor[
             0.5041987109200126, 0.6070709568623011, 0.9544705154158305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 289}], {
             RGBColor[
             0.3482245893870246, 0.47439408393544596`, 0.9434696729393952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 290}], {
             RGBColor[
             0.5091973143554127, 0.6111290483156775, 0.9548640237887529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 298}], {
             RGBColor[
             0.3453589956577786, 0.4713821632368721, 0.9433064816157806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 134}], {
             RGBColor[
             0.2657406017726479, 0.3966405997633186, 0.9384449061917377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 144}], {
             RGBColor[
             0.28659496025462, 0.4179160304983415, 0.9396561045432549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 159}], {
             RGBColor[
             0.2524370830607903, 0.3826577581053522, 0.9376872904818896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 235}], {
             RGBColor[
             0.24975979964424241`, 0.3798437634849875, 0.9375348231520031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 252}], {
             RGBColor[
             0.2790058648824081, 0.41058323235793537`, 0.9392003433016403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 292}], {
             RGBColor[
             0.25027096919944, 0.3803810350975218, 0.937563933501964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 122}], {
             RGBColor[
             0.5234999711581451, 0.6232114459734905, 0.9558598822602524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 160}], {
             RGBColor[
             0.5065135948101279, 0.6094211404266363, 0.9545226524909898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 178}], {
             RGBColor[
             0.34993177355877136`, 0.4745851224813026, 0.9436255999612144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 181}], {
             RGBColor[
             0.5683121366528735, 0.6584973340732392, 0.9601360759487196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 182}], {
             RGBColor[
             0.3649951509133196, 0.4904176871542194, 0.9444834370172861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 208}], {
             RGBColor[
             0.3543834762769441, 0.47926414429235664`, 0.9438791178453103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 246}], {
             RGBColor[
             0.5108375562883921, 0.6129315271469358, 0.9548630505777516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 296}], {
             RGBColor[
             0.559521387516622, 0.6516299340358314, 0.9592598962290395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 104}], {
             RGBColor[
             0.3262801186675095, 0.4548403348152493, 0.9420914025992604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 123}], {
             RGBColor[
             0.40185451909948444`, 0.5224879194737331, 0.9468267925043885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 157}], {
             RGBColor[
             0.35673441532730565`, 0.48340715338862666`, 0.9439517793901664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 201}], {
             RGBColor[
             0.34430071595550393`, 0.4726377079286733, 0.9431595150608838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[
             0.3117655585077827, 0.43958461181110975`, 0.9412648198705315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 222}], {
             RGBColor[
             0.4018105363813725, 0.5224498238539401, 0.9468239899644828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 229}], {
             RGBColor[
             0.3569385719957474, 0.4835839836336185, 0.9439647880725508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 257}], {
             RGBColor[
             0.37939685727732686`, 0.5030362215582833, 0.9453958101516111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 259}], {
             RGBColor[
             0.41587462147542475`, 0.5343343034600658, 0.9478022372825421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 261}], {
             RGBColor[
             0.38406488890105717`, 0.5070794359286672, 0.9456932529988971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 121}], {
             RGBColor[
             0.9223952272310946, 0.6887967573605129, 0.4252047095816714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 125}], {
             RGBColor[
             0.9214027485620356, 0.686673945842382, 0.31717953132296794`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 127}], {
             RGBColor[
             0.8414762129232649, 0.3198099242864162, 0.18735097437698822`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 136}], {
             RGBColor[
             0.9215440004534805, 0.6869760693554257, 0.33255392800111494`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 137}], {
             RGBColor[
             0.8478732688157926, 0.3689804990841502, 0.19347680232411396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 170}], {
             RGBColor[
             0.8360368854877944, 0.2780008700889096, 0.18214226828194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 192}], {
             RGBColor[
             0.857583234347318, 0.43326449980026105`, 0.20236975515183697`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 228}], {
             RGBColor[
             0.8332617870229544, 0.6215832019337704, 0.5890075855789246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 232}], {
             RGBColor[
             0.9221384356388024, 0.6882475061102127, 0.3972545294946756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 240}], {
             RGBColor[
             0.9225569449368545, 0.6891426551809652, 0.4428066838476417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 256}], {
             RGBColor[
             0.9227141531364094, 0.6894789076236262, 0.45991782619265503`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 299}], {
             RGBColor[
             0.9223324395514323, 0.6893504120322749, 0.46837744579024243`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 108}], {
             RGBColor[
             0.44525533808141193`, 0.5575469670447641, 0.9502920083081179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 114}], {
             RGBColor[
             0.4255007228362041, 0.540035729338632, 0.9490479363174081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 187}], {
             RGBColor[
             0.4552598760386822, 0.566212394980653, 0.9509294886200896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 205}], {
             RGBColor[
             0.5380185348092877, 0.6358267098737893, 0.9567739363684693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 207}], {
             RGBColor[
             0.6460892652174881, 0.7219820565313749, 0.9663628314965813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 213}], {
             RGBColor[
             0.48723449014775655`, 0.5939071986311, 0.9529668827570787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 231}], {
             RGBColor[
             0.49585480302230733`, 0.6013736803735128, 0.9535161614708018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 133}], {
             RGBColor[
             0.36773492193593726`, 0.4929352393114849, 0.9446527219439024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 142}], {
             RGBColor[
             0.5221732711977142, 0.6208612990518254, 0.9562111960106483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 162}], {
             RGBColor[
             0.3349247683998675, 0.4622774977068556, 0.9426440773615328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[
             0.4766965463107896, 0.5841965277949407, 0.9524565634581535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 210}], {
             RGBColor[
             0.3819399405336581, 0.5052389124558365, 0.9455578531679444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 237}], {
             RGBColor[
             0.5120510519507784, 0.6128989081758123, 0.9552397996499549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 239}], {
             RGBColor[
             0.398228532934502, 0.519347272504989, 0.9465957478722895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 295}], {
             RGBColor[
             0.6113037860265932, 0.6906305704110295, 0.9650577846461873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 116}], {
             RGBColor[
             0.3006123597209014, 0.43202989779004775`, 0.9404770506166615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 119}], {
             RGBColor[
             0.28052080371187027`, 0.4121755291203697, 0.939286616826827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 152}], {
             RGBColor[
             0.26605649274810816`, 0.396972621207172, 0.9384628957154713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 164}], {
             RGBColor[
             0.33137057382359575`, 0.4586711168930102, 0.9424369368208644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 168}], {
             RGBColor[
             0.3323449528082868, 0.45951507499583777`, 0.9424990233881594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 241}], {
             RGBColor[
             0.2789461451652853, 0.41052046314879065`, 0.9391969423520976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 277}], {
             RGBColor[
             0.3139559658390563, 0.44358745874044936`, 0.9413272933992227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 128}], {
             RGBColor[
             0.26216622821870855`, 0.39288370652975557`, 0.9382413509056526]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 157}], {
             RGBColor[
             0.3155261405863954, 0.44552577951204275`, 0.9414061686253012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 173}], {
             RGBColor[
             0.2711227338075005, 0.40229756177882925`, 0.9387514106489717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 201}], {
             RGBColor[
             0.30309244121459367`, 0.43475633405208935`, 0.9406139042960187]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 209}], {
             RGBColor[
             0.2751140822771375, 0.4064927220865271, 0.9389787120396467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 218}], {
             RGBColor[
             0.2705572837668725, 0.40170323793452584`, 0.9387192091056663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 229}], {
             RGBColor[
             0.3157302972548372, 0.4457026097570346, 0.9414191773076857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 261}], {
             RGBColor[
             0.34285661416014696`, 0.46919806205208336`, 0.9431476422340319]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 279}], {
             RGBColor[
             0.27193222945827744`, 0.4031483930327844, 0.9387975102287419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 129}], {
             RGBColor[
             0.2625398824694277, 0.39327644083830926`, 0.9382626299624591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 140}], {
             RGBColor[
             0.3086221728107845, 0.4399248428735164, 0.9409523793012212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 149}], {
             RGBColor[
             0.29155965067616113`, 0.4237780571831614, 0.9399152628309327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 171}], {
             RGBColor[
             0.3537618197336009, 0.4790225362534377, 0.9438286376877205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 196}], {
             RGBColor[
             0.28505137622914434`, 0.4169374480909134, 0.9395446262293043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 230}], {
             RGBColor[
             0.2692612582166467, 0.40034103290847267`, 0.938645402367879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 245}], {
             RGBColor[
             0.35678647711021616`, 0.4816423424493619, 0.944021366181159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 263}], {
             RGBColor[
             0.2750769487244079, 0.40645369236820506`, 0.9389765973387527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 289}], {
             RGBColor[
             0.2900768000973668, 0.42221948720669167`, 0.9398308166841512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 298}], {
             RGBColor[
             0.2872112063681208, 0.41920756650811786`, 0.9396676253605367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 151}], {
             RGBColor[
             0.5499711557200619, 0.645038448022178, 0.9579401200370031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 167}], {
             RGBColor[
             0.7052976145619072, 0.7697031240469493, 0.9712611329047376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 194}], {
             RGBColor[
             0.5862509789073218, 0.6747647734348481, 0.960720844348837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 215}], {
             RGBColor[
             0.8258859987463416, 0.8619784867738793, 0.84861498208911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 283}], {
             RGBColor[
             0.6376959489926155, 0.716530117719581, 0.9647707808430861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 286}], {
             RGBColor[
             0.6078523188068897, 0.6923017142945901, 0.9624213809540463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 297}], {
             RGBColor[
             0.7085338986582898, 0.7722313337797134, 0.9715836954586705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 110}], {
             RGBColor[
             0.9135464991631714, 0.6274127712548101, 0.4734497418593211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 127}], {
             RGBColor[
             0.8334595581640123, 0.25819040288628525`, 0.17967421672601133`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 141}], {
             RGBColor[
             0.8665747340462209, 0.44887503543921714`, 0.2088850184887606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 165}], {
             RGBColor[
             0.9072036933815937, 0.6042751330644562, 0.27907410397502735`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.9138967980085537, 0.6275576288296454, 0.4676443834469852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 240}], {
             RGBColor[
             0.9145402901776019, 0.6275231337808342, 0.4351299261966648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 281}], {
             RGBColor[
             0.835111708182694, 0.27088955190662645`, 0.18125631744973736`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 114}], {
             RGBColor[
             0.32416580444258236`, 0.4547970767096937, 0.9418912109282782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 145}], {
             RGBColor[
             0.3065621353882716, 0.43629450439653, 0.9408887080179298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 169}], {
             RGBColor[
             0.3184727377256654, 0.44881330262893604`, 0.9415669992008873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 187}], {
             RGBColor[
             0.35392495764506043`, 0.4809737423517148, 0.9437727632309596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 205}], {
             RGBColor[
             0.436683616415666, 0.5505880572448512, 0.9496172109793394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 213}], {
             RGBColor[
             0.3858995717541348, 0.5086685460021616, 0.9458101573679487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 219}], {
             RGBColor[
             0.30907770812291846`, 0.4389385308371674, 0.9410319661637115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 221}], {
             RGBColor[
             0.3192668900954462, 0.449648007121744, 0.9416122250035031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 264}], {
             RGBColor[
             0.3192908615453144, 0.4496732026354332, 0.9416135901421105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 110}], {
             RGBColor[
             0.9570573175626281, 0.9656649471847494, 0.8794550171346109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 138}], {
             RGBColor[
             0.8139262808550589, 0.8553825016885668, 0.9818711941291625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 154}], {
             RGBColor[
             0.8311843708271494, 0.8688646527411055, 0.9835913192515602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 179}], {
             RGBColor[
             0.9574076164080104, 0.9658098047595847, 0.8736496587222751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 258}], {
             RGBColor[
             0.941467846616602, 0.9554926988601389, 0.9709728498600104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 138}], {
             RGBColor[
             0.8498149400101593, 0.8810685488435381, 0.8689831282162525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 141}], {
             RGBColor[
             0.9459742116007779, 0.8128132585241278, 0.5020022278511405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 154}], {
             RGBColor[
             0.8670730299822498, 0.8945506998960768, 0.8707032533386501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 165}], {
             RGBColor[
             0.9866031709361507, 0.9682133561493669, 0.5721913133374072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 179}], {
             RGBColor[
             0.9932962755631108, 0.991495851914556, 0.7607615928093651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 281}], {
             RGBColor[
             0.914511185737251, 0.6348277749915371, 0.4743735268121172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 190}], {
             RGBColor[
             0.2355732429285669, 0.36493279289716524`, 0.9367269197341752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 212}], {
             RGBColor[
             0.2273675902370908, 0.3563081316499939, 0.936259619952571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 242}], {
             RGBColor[
             0.24172339249525976`, 0.3713969900337639, 0.9370771616536675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 250}], {
             RGBColor[
             0.2327988220725642, 0.3620167006690641, 0.9365689205708136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 280}], {
             RGBColor[
             0.2555363699026189, 0.38591530508224947`, 0.9378637902825477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 115}], {
             RGBColor[
             0.236902386747869, 0.36632980732383724`, 0.9368026125083924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 134}], {
             RGBColor[
             0.2631071012640549, 0.3938726237552112, 0.9382949322336882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 146}], {
             RGBColor[
             0.24133200131587673`, 0.37098561308859834`, 0.937054872505013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 159}], {
             RGBColor[
             0.24980358255219737`, 0.3798897820972448, 0.9375373165238401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 175}], {
             RGBColor[
             0.27336230601956724`, 0.40465149417079094`, 0.9388789509732987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 204}], {
             RGBColor[
             0.24154807064065673`, 0.37121271564852854`, 0.9370671773334133]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 235}], {
             RGBColor[
             0.24712629913564943`, 0.3770757874768801, 0.9373848491939536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 242}], {
             RGBColor[
             0.24632291686669305`, 0.37623138177482907`, 0.937339097762234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 252}], {
             RGBColor[
             0.27637236437381507`, 0.40781525634982796`, 0.9390503693435908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 253}], {
             RGBColor[
             0.2744693999473012, 0.40581512008264853`, 0.9389419983346845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 280}], {
             RGBColor[
             0.2601358942740522, 0.3907496968233146, 0.9381257263911142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 292}], {
             RGBColor[
             0.24763746869084696`, 0.3776130590894144, 0.9374139595439145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 135}], {
             RGBColor[
             0.9747525126984742, 0.9797102206225822, 0.8836982332246824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 224}], {
             RGBColor[
             0.9644670009376046, 0.9390549690861945, 0.644851681061125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 249}], {
             RGBColor[
             0.8889946281823045, 0.5565337231850392, 0.5595095853153444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 254}], {
             RGBColor[
             0.925365599889266, 0.7843240503848107, 0.5923111720047104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 258}], {
             RGBColor[
             0.9605881616295711, 0.9701272959910724, 0.9515981414941335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 260}], {
             RGBColor[
             0.9042815340807562, 0.9259021424271057, 0.969533952973199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 278}], {
             RGBColor[
             0.7811703997408805, 0.8288870412862575, 0.957738894978919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 288}], {
             RGBColor[
             0.9106552013287734, 0.717527566222487, 0.5800364548609709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 290}], {
             RGBColor[
             0.7861690031762806, 0.8329451327396338, 0.9581324033518415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 145}], {
             RGBColor[
             0.28680752014306377`, 0.4187832666903979, 0.9396446360272199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 169}], {
             RGBColor[
             0.2987181224804576, 0.4313020649228039, 0.9403229272101774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 187}], {
             RGBColor[
             0.33417034239985266`, 0.4634625046455827, 0.9425286912402498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 213}], {
             RGBColor[
             0.366144956508927, 0.49115730829602955`, 0.944566085377239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 219}], {
             RGBColor[
             0.28932309287771063`, 0.4214272931310352, 0.9397878941730018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 221}], {
             RGBColor[
             0.29951227485023835`, 0.4321367694156119, 0.9403681530127932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 231}], {
             RGBColor[
             0.37476526938347776`, 0.4986237900384425, 0.945115364090962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 264}], {
             RGBColor[
             0.29953624630010656`, 0.4321619649293011, 0.9403695181514007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 132}], {
             RGBColor[
             0.21415169536183348`, 0.34241738819996653`, 0.9355069942905895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 146}], {
             RGBColor[
             0.22602095903949393`, 0.35489273687997036`, 0.9361829312980301]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 159}], {
             RGBColor[
             0.23449254027581456`, 0.3637969058886168, 0.9366653753168572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 204}], {
             RGBColor[
             0.22623702836427392`, 0.35511983943990055`, 0.9361952361264305]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 242}], {
             RGBColor[
             0.23101187459031025`, 0.36013850556620103`, 0.9364671565552513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 243}], {
             RGBColor[
             0.21987898042507611`, 0.348437127932281, 0.9358331547021821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 294}], {
             RGBColor[
             0.2157444487404361, 0.3440914729872748, 0.9355976992392334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 119}], {
             RGBColor[
             0.30231628529617693`, 0.4338208316047836, 0.9405740866574415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 133}], {
             RGBColor[
             0.3362774461822365, 0.4656883549123332, 0.9426482794056301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 152}], {
             RGBColor[
             0.2878519743324149, 0.4186179236915859, 0.9397503655460857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 164}], {
             RGBColor[
             0.35316605540790247`, 0.4803164193774241, 0.9437244066514788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 168}], {
             RGBColor[
             0.35414043439259346`, 0.4811603774802517, 0.9437864932187738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 210}], {
             RGBColor[
             0.35048246477995726`, 0.4779920280566848, 0.9435534106296721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 241}], {
             RGBColor[
             0.30074162674959204`, 0.4321657656332045, 0.9404844121827121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 277}], {
             RGBColor[
             0.33575144742336294`, 0.46523276122486323`, 0.9426147632298372]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 161}], {
             RGBColor[
             0.20987266837087443`, 0.33791985952648745`, 0.9352633100337076]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 120}], {
             RGBColor[
             0.1844220718220619, 0.3111696688926636, 0.9338139362110361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 130}], {
             RGBColor[
             0.17892828448197629`, 0.3053953500719979, 0.9335010731493483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 176}], {
             RGBColor[
             0.17894072364130287`, 0.30540842441713845`, 0.9335017815410699]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[
             0.17892828448197629`, 0.3053953500719979, 0.9335010731493483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 220}], {
             RGBColor[
             0.21806065403360642`, 0.34652595160629435`, 0.9357296037041608]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 226}], {
             RGBColor[
             0.17892828959271728`, 0.30539535544371077`, 0.9335010734403975]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 228}], {
             RGBColor[
             0.49763640594137093`, 0.5809247565206876, 0.9579151348288255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 266}], {
             RGBColor[
             0.21328176149194045`, 0.3415030325457159, 0.9354574528436509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 152}], {
             RGBColor[
             0.2677604183233837, 0.39876355502190786`, 0.9385599317562512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 164}], {
             RGBColor[
             0.33307449939887124`, 0.46046205070774604`, 0.9425339728616443]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 168}], {
             RGBColor[
             0.3340488783835623, 0.46130600881057365`, 0.9425960594289393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 241}], {
             RGBColor[
             0.2806500707405608, 0.4123113969635265, 0.9392939783928775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 130}], {
             RGBColor[
             0.18442078734008566`, 0.31116831882066576`, 0.9338138630616879]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 176}], {
             RGBColor[
             0.18443322649941224`, 0.31118139316580623`, 0.9338145714534094]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 287}], {
             RGBColor[
             0.5654447927305568, 0.5603176274195498, 0.6027460190921992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 125}], {
             RGBColor[
             0.9936176446660105, 0.9887571122327337, 0.5466981931057444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 127}], {
             RGBColor[
             0.9136911090272399, 0.6218930906767679, 0.41686963615976463`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 136}], {
             RGBColor[
             0.9937588965574554, 0.9890592357457773, 0.5620725897838914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 137}], {
             RGBColor[
             0.9200881649197675, 0.6710636654745018, 0.4229954641068904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 160}], {
             RGBColor[
             0.7924150587076538, 0.8345430649548763, 0.8078033989134862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 181}], {
             RGBColor[
             0.8542136005503994, 0.8836192586014792, 0.8134168223712162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 232}], {
             RGBColor[
             0.9943533317427773, 0.9903306725005643, 0.626773191277452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 240}], {
             RGBColor[
             0.9947718410408293, 0.9912258215713169, 0.6723253456304181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 246}], {
             RGBColor[
             0.796739020185918, 0.8380534516751759, 0.8081437970002479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 256}], {
             RGBColor[
             0.9949290492403844, 0.9915620740139779, 0.6894364879754314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 296}], {
             RGBColor[
             0.8454228514141477, 0.8767518585640715, 0.8125406426515358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 299}], {
             RGBColor[
             0.9945473356554072, 0.9914335784226265, 0.6978961075730188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 136}], {
             RGBColor[
             0.8085502082780569, 0.8465126824966431, 0.7164898471021924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 160}], {
             RGBColor[
             0.6072063704282553, 0.6919965117057422, 0.9622206562317872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 181}], {
             RGBColor[
             0.6690049122710009, 0.741072705352345, 0.9678340796895172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 207}], {
             RGBColor[
             0.6848905103681076, 0.7534826553208219, 0.9694174076484823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 231}], {
             RGBColor[
             0.5346560481729267, 0.6328742791629598, 0.9565707376227028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 232}], {
             RGBColor[
             0.8091446434633787, 0.8477841192514302, 0.781190448595753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 240}], {
             RGBColor[
             0.8095631527614308, 0.8486792683221828, 0.8267426029487193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 246}], {
             RGBColor[
             0.6115303319065195, 0.6955068984260417, 0.962561054318549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 256}], {
             RGBColor[
             0.8097203609609858, 0.8490155207648438, 0.8438537452937325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 296}], {
             RGBColor[
             0.6602141631347492, 0.7342053053149373, 0.9669578999698369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 299}], {
             RGBColor[
             0.8093386473760087, 0.8488870251734923, 0.8523133648913199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 144}], {
             RGBColor[
             0.3759650676291757, 0.5000637778518178, 0.9451771395498434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 157}], {
             RGBColor[
             0.3911005410183704, 0.5131733641705265, 0.9461415585304294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 229}], {
             RGBColor[
             0.3913046976868122, 0.5133501944155183, 0.9461545672128138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 257}], {
             RGBColor[
             0.41376298296839165`, 0.5328024323401832, 0.9475855892918741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 259}], {
             RGBColor[
             0.4502407471664895, 0.5641005142419657, 0.9499920164228051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 261}], {
             RGBColor[
             0.41843101459212195`, 0.5368456467105671, 0.9478830321391599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 125}], {
             RGBColor[
             0.970159485355791, 0.9735725032155419, 0.706048969605638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 142}], {
             RGBColor[
             0.8033587771487245, 0.8470321673736835, 0.9700369554308557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 150}], {
             RGBColor[
             0.9548500534233739, 0.9658478242861803, 0.9613112619489188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 200}], {
             RGBColor[
             0.916844882326316, 0.7678634053812667, 0.6000047488264095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 237}], {
             RGBColor[
             0.7932365579017887, 0.8390697764976703, 0.9690655590701622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 282}], {
             RGBColor[
             0.9556754222393467, 0.9664633829977154, 0.9599141278341408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 295}], {
             RGBColor[
             0.8924892919776035, 0.9168014387328876, 0.9788835440663946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 136}], {
             RGBColor[
             0.9927664178883965, 0.9869364242276462, 0.4540474115251879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 150}], {
             RGBColor[
             0.9773157340645346, 0.9789096217852411, 0.6939353071903218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[
             0.9072593029227105, 0.5779612249611302, 0.303635751806013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 192}], {
             RGBColor[
             0.9288056517822338, 0.7332248546724817, 0.32386323867590994`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 195}], {
             RGBColor[
             0.9058844617461582, 0.5673935932189047, 0.3023192023426855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 200}], {
             RGBColor[
             0.9393105629674767, 0.7809252028803274, 0.3326287940678124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 256}], {
             RGBColor[
             0.9939365705713255, 0.9894392624958468, 0.5814113097167279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 299}], {
             RGBColor[
             0.9935548569863483, 0.9893107669044954, 0.5898709293143154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 155}], {
             RGBColor[
             0.21912067898952223`, 0.3476401050444259, 0.9357899705572339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 163}], {
             RGBColor[
             0.23364896427549098`, 0.3629102540264691, 0.9366173349115978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 184}], {
             RGBColor[
             0.23168784072436213`, 0.3608489888318178, 0.9365056518265833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 189}], {
             RGBColor[
             0.22889351140479614`, 0.3579119715462422, 0.9363465189056738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 197}], {
             RGBColor[
             0.21821940668747852`, 0.34669281071101354`, 0.9357386444329454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 214}], {
             RGBColor[
             0.21941035515512047`, 0.34794457306099935`, 0.9358064671863272]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 216}], {
             RGBColor[
             0.24238826022285348`, 0.3720958081705137, 0.9371150248871702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 275}], {
             RGBColor[
             0.21935857397151598`, 0.34789014775391436`, 0.9358035183245244]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 293}], {
             RGBColor[
             0.21759994210882713`, 0.34604171416252816`, 0.9357033668416068]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 136}], {
             RGBColor[
             0.9128398822496258, 0.6200724026716804, 0.3242188545792082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 137}], {
             RGBColor[
             0.8391691506119379, 0.30207683240040506`, 0.18514172890220718`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 141}], {
             RGBColor[
             0.8658872706016187, 0.44359089015560293`, 0.2082267027178307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 165}], {
             RGBColor[
             0.9065162299369915, 0.5989909877808421, 0.27841578820409746`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 170}], {
             RGBColor[
             0.8273327672839398, 0.21109720340516447`, 0.1738071948600332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 192}], {
             RGBColor[
             0.8488791161434632, 0.3663608331165159, 0.19403468172993021`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 228}], {
             RGBColor[
             0.8245576688190998, 0.5546795352500253, 0.5806725121570179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 232}], {
             RGBColor[
             0.9134343174349477, 0.6213438394264674, 0.3889194560727688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 240}], {
             RGBColor[
             0.9138528267329997, 0.6222389884972201, 0.4344716104257349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 256}], {
             RGBColor[
             0.9140100349325547, 0.622575240939881, 0.4515827527707482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 281}], {
             RGBColor[
             0.8344242447380918, 0.2656054066230123, 0.18059800167880746`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 299}], {
             RGBColor[
             0.9136283213475775, 0.6224467453485296, 0.4600423723683357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 173}], {
             RGBColor[
             0.24821711809960986`, 0.3782223073699194, 0.9374469697202291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 209}], {
             RGBColor[
             0.25220846656924684`, 0.38241746767761725`, 0.9376742711109041]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 218}], {
             RGBColor[
             0.24765166805898178`, 0.377627983525616, 0.9374147681769237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 276}], {
             RGBColor[
             0.235521079118485, 0.3648779654253926, 0.9367239490823606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 279}], {
             RGBColor[
             0.24902661375038676`, 0.3790731386238746, 0.9374930692999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 161}], {
             RGBColor[
             0.22609023535273692`, 0.35496555067756064`, 0.9361868764815843]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 230}], {
             RGBColor[
             0.2426308084736596, 0.3723507417605582, 0.9371288376512357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 263}], {
             RGBColor[
             0.24844649898142085`, 0.37846340122029065`, 0.9374600326221096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 265}], {
             RGBColor[
             0.22918762870603976`, 0.3582211074779632, 0.936363268450872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 269}], {
             RGBColor[
             0.23146736458154496`, 0.36061725442672216`, 0.9364930960364151]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 289}], {
             RGBColor[
             0.26344635035437974`, 0.39422919605877726`, 0.9383142519675081]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 298}], {
             RGBColor[
             0.26058075662513375`, 0.3912172753602034, 0.9381510606438935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 176}], {
             RGBColor[
             0.17893943915932659`, 0.3054070743451405, 0.9335017083917216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 199}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 220}], {
             RGBColor[
             0.21805936955163013`, 0.34652460153429643`, 0.9357295305548126]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 226}], {
             RGBColor[
             0.178927005110741, 0.3053940053717128, 0.9335010002910491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 228}], {
             RGBColor[
             0.49763512145939465`, 0.5809234064486897, 0.9579150616794772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 266}], {
             RGBColor[
             0.21328047700996416`, 0.3415016824737179, 0.9354573796943026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 139}], {
             RGBColor[
             0.29015495986038786`, 0.4208144502573191, 0.9398897209981389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 143}], {
             RGBColor[
             0.3607906299670138, 0.4869204426382663, 0.9442102378002388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 172}], {
             RGBColor[
             0.297163306859998, 0.4281806673087738, 0.9402888359918464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 174}], {
             RGBColor[
             0.3585773503848271, 0.4850034111068425, 0.9440692095823882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 183}], {
             RGBColor[
             0.2897103519915022, 0.4203471391973532, 0.9398644012377442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 283}], {
             RGBColor[
             0.47177717102653804`, 0.5785602690993044, 0.9525231166057517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 188}], {
             RGBColor[
             0.20621351468350757`, 0.3340738569973212, 0.9350549266444448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 212}], {
             RGBColor[
             0.20921642322248857`, 0.3372301042671883, 0.9352259378433346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 243}], {
             RGBColor[
             0.21243933131542342`, 0.34061758501703826`, 0.935409477691362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 294}], {
             RGBColor[
             0.2083047996307834, 0.33627193007203204`, 0.9351740222284133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 162}], {
             RGBColor[
             0.31733689752319516`, 0.44704376794557543`, 0.9415233937816148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 164}], {
             RGBColor[
             0.36703566028493084`, 0.49232957401529565`, 0.9446081656098331]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 210}], {
             RGBColor[
             0.36435206965698563`, 0.49000518269455634`, 0.9444371695880264]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 239}], {
             RGBColor[
             0.38064066205782954`, 0.5041135427437089, 0.9454750642923715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 241}], {
             RGBColor[
             0.3146112316266204, 0.4441789202710761, 0.9413681711410662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 277}], {
             RGBColor[
             0.3496210523003913, 0.4772459158627348, 0.9434985221881913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 144}], {
             RGBColor[
             0.29485513198583013`, 0.42659799471298, 0.9401265091035182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 159}], {
             RGBColor[
             0.26069725479200045`, 0.3913397223199907, 0.9381576950421531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 175}], {
             RGBColor[
             0.2842559782593704, 0.41610143439353686`, 0.9394993294916116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 204}], {
             RGBColor[
             0.25244174288045984`, 0.38266265587127446`, 0.9376875558517261]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 235}], {
             RGBColor[
             0.2580199713754525, 0.388525727699626, 0.9380052277122666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 252}], {
             RGBColor[
             0.28726603661361816`, 0.4192651965725739, 0.9396707478619037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 253}], {
             RGBColor[
             0.2853630721871043, 0.41726506030539445`, 0.9395623768529974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 292}], {
             RGBColor[
             0.2585311409306501, 0.3890629993121603, 0.9380343380622274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 224}], {
             RGBColor[
             0.9798102252026126, 0.9495170954171317, 0.5749562479700403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 249}], {
             RGBColor[
             0.9043378524473125, 0.5669958495159765, 0.4896141522242598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 254}], {
             RGBColor[
             0.940708824154274, 0.7947861767157479, 0.5224157389136257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 258}], {
             RGBColor[
             0.9759313858945792, 0.9805894223220096, 0.8817027084030489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 260}], {
             RGBColor[
             0.9196247583457642, 0.9363642687580429, 0.8996385198821143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 288}], {
             RGBColor[
             0.9259984255937815, 0.7279896925534243, 0.5101410217698862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 137}], {
             RGBColor[
             0.9192369381421535, 0.6692429774694144, 0.3303446825263339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 165}], {
             RGBColor[
             0.9865840174672071, 0.9661571328498515, 0.42361874182822423`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 181}], {
             RGBColor[
             0.8533623737727853, 0.8817985705963918, 0.7207660407906598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 232}], {
             RGBColor[
             0.9935021049651632, 0.9885099844954769, 0.5341224096968956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 240}], {
             RGBColor[
             0.9939206142632153, 0.9894051335662295, 0.5796745640498617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 256}], {
             RGBColor[
             0.9940778224627702, 0.9897413860088904, 0.596785706394875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 296}], {
             RGBColor[
             0.8445716246365338, 0.8749311705589841, 0.7198898610709794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 299}], {
             RGBColor[
             0.9936961088777931, 0.9896128904175391, 0.6052453259924624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 170}], {
             RGBColor[
             0.8337298231764674, 0.2602677782028984, 0.17993302280715895`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 192}], {
             RGBColor[
             0.8552761720359909, 0.4155314079142499, 0.20016050967705595`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 195}], {
             RGBColor[
             0.8323549819999152, 0.24970014646067296`, 0.17861647334383152`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 220}], {
             RGBColor[
             0.5513789728038629, 0.36945130513336594`, 0.564612808979479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 228}], {
             RGBColor[
             0.8309547247116273, 0.6038501100477591, 0.5867983401041436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 232}], {
             RGBColor[
             0.9198313733274753, 0.6705144142242014, 0.3950452840198946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 256}], {
             RGBColor[
             0.9204070908250823, 0.671745815737615, 0.457708580717874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 266}], {
             RGBColor[
             0.546600080262197, 0.3644283860727875, 0.564340658118969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 299}], {
             RGBColor[
             0.9200253772401052, 0.6716173201462636, 0.46616820031546136`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 154}], {
             RGBColor[
             0.7239419932746806, 0.7842682543998942, 0.9731194303332016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 171}], {
             RGBColor[
             0.5625186052786886, 0.6537822219340037, 0.9596386929535714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 245}], {
             RGBColor[
             0.5655432626553039, 0.6564020281299278, 0.9598314214470098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 258}], {
             RGBColor[
             0.8342254690641332, 0.8708963005189276, 0.9605009609416519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 147}], {
             RGBColor[
             0.2408356632285271, 0.3704639302891415, 0.9370266067852049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 148}], {
             RGBColor[
             0.24714609636833407`, 0.37709659562364867`, 0.9373859766170676]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 172}], {
             RGBColor[
             0.26248705403553485`, 0.3932209148047717, 0.9382596214613016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 183}], {
             RGBColor[
             0.2550340991670391, 0.38538738669335115`, 0.9378351867071995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 206}], {
             RGBColor[
             0.2460762386198535, 0.3759721072970965, 0.9373250498010044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 244}], {
             RGBColor[
             0.2489949569451404, 0.37903986531440326`, 0.9374912664917726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 272}], {
             RGBColor[
             0.23937950956716447`, 0.3689334204655748, 0.9369436809883765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 149}], {
             RGBColor[
             0.3110114912745308, 0.4424361680704541, 0.9410884474530516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 171}], {
             RGBColor[
             0.37321366033197056`, 0.49768064714073046`, 0.9450018223098395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 196}], {
             RGBColor[
             0.304503216827514, 0.4355955589782061, 0.9407178108514234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 198}], {
             RGBColor[
             0.3961646850276139, 0.5172626963041967, 0.9465462963516883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 222}], {
             RGBColor[
             0.3821033463817397, 0.505380446388428, 0.94556826524409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 230}], {
             RGBColor[
             0.2887130988150164, 0.4189991437957653, 0.9398185869899978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 245}], {
             RGBColor[
             0.37623831770858585`, 0.5003004533366545, 0.945194550803278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 263}], {
             RGBColor[
             0.2945287893227776, 0.42511180325549774`, 0.9401497819608717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 289}], {
             RGBColor[
             0.3095286406957365, 0.4408775980939844, 0.9410040013062702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 298}], {
             RGBColor[
             0.3066630469664905, 0.4378656773954105, 0.9408408099826556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 165}], {
             RGBColor[
             0.9396314058192, 0.789675620333774, 0.3076265899668467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 179}], {
             RGBColor[
             0.9463245104461602, 0.8129581160989631, 0.4961968694388046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 232}], {
             RGBColor[
             0.9465494933171561, 0.8120284719793993, 0.41813025783551805`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[
             0.9469680026152082, 0.812923621050152, 0.46368241218848416`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 281}], {
             RGBColor[
             0.8675394206203003, 0.45629003917594413`, 0.20980880344155672`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[
             0.810515025857468, 0.8523692859433827, 0.9579232930155395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 185}], {
             RGBColor[
             0.6135470246958941, 0.696888857774001, 0.9628943539449815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 210}], {
             RGBColor[
             0.5187904189187625, 0.6179312424348968, 0.9559956436547723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 237}], {
             RGBColor[
             0.6489015303358828, 0.7255912381548726, 0.9656775901367828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 239}], {
             RGBColor[
             0.5350790113196064, 0.6320396024840493, 0.9570335383591173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 282}], {
             RGBColor[
             0.8113403946734408, 0.8529848446549176, 0.9565261589007614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 283}], {
             RGBColor[
             0.6388734394755219, 0.7174499822340865, 0.964888142090148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 295}], {
             RGBColor[
             0.7481542644116976, 0.8033229003900898, 0.9754955751330152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 297}], {
             RGBColor[
             0.7097113891411961, 0.773151198294219, 0.9717010567057325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 167}], {
             RGBColor[
             0.5753382538779925, 0.6628795153036178, 0.9613047709389584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 172}], {
             RGBColor[
             0.33312272414216076`, 0.4593269071857189, 0.9425801382634016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 174}], {
             RGBColor[
             0.39453676766698986`, 0.5161496509837875, 0.9463605118539434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 185}], {
             RGBColor[
             0.482410173529073, 0.5891453845161638, 0.9528206307321404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 237}], {
             RGBColor[
             0.5177646791690618, 0.6178477648970354, 0.9556038669239417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 239}], {
             RGBColor[
             0.4039421601527854, 0.5242961292262122, 0.9469598151462764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 283}], {
             RGBColor[
             0.5077365883087008, 0.6097065089762495, 0.9548144188773069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 297}], {
             RGBColor[
             0.5785745379743751, 0.6654077250363819, 0.9616273334928914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 158}], {
             RGBColor[
             0.35967077338482056`, 0.4859504791523989, 0.9441388815290719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 235}], {
             RGBColor[
             0.27887432985742466`, 0.4098011584346488, 0.9392164260637837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 252}], {
             RGBColor[
             0.3081203950955903, 0.44054062730759674`, 0.940881946213421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 253}], {
             RGBColor[
             0.30621743066907636`, 0.4385404910404173, 0.9407735752045145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 257}], {
             RGBColor[
             0.3535074058070181, 0.4806120799363681, 0.9437461571970662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 292}], {
             RGBColor[
             0.2793854994126222, 0.4103384300471832, 0.9392455364137446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 169}], {
             RGBColor[
             0.28111445342614677`, 0.4127994926096401, 0.939320424299829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 219}], {
             RGBColor[
             0.27171942382339986`, 0.4029247208178715, 0.9387853912626534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 221}], {
             RGBColor[
             0.2819086057959276, 0.4136341971024482, 0.9393656501024449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 264}], {
             RGBColor[
             0.28193257724579573`, 0.4136593926161374, 0.9393670152410523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 159}], {
             RGBColor[
             0.2389221548438223, 0.3684527116533779, 0.9369176353134778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 204}], {
             RGBColor[
             0.23066664293228167`, 0.35977564520466165`, 0.936447496123051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 235}], {
             RGBColor[
             0.23624487142727435`, 0.3656387170330131, 0.9367651679835913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 242}], {
             RGBColor[
             0.23544148915831797`, 0.3647943113309621, 0.9367194165518717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 243}], {
             RGBColor[
             0.22430859499308387`, 0.3530929336970421, 0.9360854146988027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 292}], {
             RGBColor[
             0.2367560409824719, 0.36617598864554746`, 0.9367942783335522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 148}], {
             RGBColor[
             0.2325030525609364, 0.36170582815947316`, 0.9365520769346783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 172}], {
             RGBColor[
             0.2478440102281372, 0.3778301473405962, 0.9374257217789124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 183}], {
             RGBColor[
             0.24039105535964145`, 0.36999661922917565`, 0.9370012870248101]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 206}], {
             RGBColor[
             0.23143319481245586`, 0.360581339832921, 0.9364911501186151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 244}], {
             RGBColor[
             0.23435191313774276`, 0.3636490978502278, 0.9366573668093834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 270}], {
             RGBColor[
             0.2272240069658551, 0.35615721652822, 0.9362514430976865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 272}], {
             RGBColor[
             0.2247364657597668, 0.3535426530013993, 0.9361097813059873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 172}], {
             RGBColor[
             0.2541544433679442, 0.3844628126751034, 0.9377850916107751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 183}], {
             RGBColor[
             0.2467014884994484, 0.37662928456368283`, 0.937360656856673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 203}], {
             RGBColor[
             0.2492037147300215, 0.37925928298232137`, 0.9375031549387921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 206}], {
             RGBColor[
             0.23774362795226284`, 0.3672140051674282, 0.9368505199504779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 244}], {
             RGBColor[
             0.24066234627754973`, 0.37028176318473494`, 0.9370167366412461]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 270}], {
             RGBColor[
             0.23353444010566207`, 0.3627898818627272, 0.9366108129295494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 272}], {
             RGBColor[
             0.23104689889957378`, 0.3601753183359065, 0.93646915113785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 171}], {
             RGBColor[
             0.3561511381973472, 0.48153386145037547`, 0.943964705839551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 227}], {
             RGBColor[
             0.27685707898321577`, 0.40832472213698934`, 0.9390779731235251]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 245}], {
             RGBColor[
             0.3591757955739624, 0.4841536676462995, 0.9441574343329895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 289}], {
             RGBColor[
             0.29246611856111315`, 0.4247308124036294, 0.9399668848359817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 298}], {
             RGBColor[
             0.28960052483186716`, 0.4217188917050555, 0.9398036935123671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 200}], {
             RGBColor[
             0.9240011310350597, 0.7732005239509658, 0.5878910864110933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 237}], {
             RGBColor[
             0.8003928066105324, 0.8444068950673695, 0.956951896654846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 282}], {
             RGBColor[
             0.9628316709480902, 0.9718005015674145, 0.9478004654188247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 295}], {
             RGBColor[
             0.8996455406863472, 0.9221385573025866, 0.9667698816510785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 167}], {
             RGBColor[
             0.5986000016649633, 0.6830276720672528, 0.9627869889383882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 194}], {
             RGBColor[
             0.4795533660103779, 0.5880893214551517, 0.9522467003824877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 251}], {
             RGBColor[
             0.36499365332834144`, 0.4885238594535514, 0.944552636407374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 286}], {
             RGBColor[
             0.5011547059099458, 0.6056262623148936, 0.953947236987697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 241}], {
             RGBColor[
             0.2661857597767988, 0.3971084890503288, 0.9384702572815218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 277}], {
             RGBColor[
             0.3011955804505697, 0.43017548464198757`, 0.9406006083286469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 163}], {
             RGBColor[
             0.2574205034515923, 0.3878956489031873, 0.9379710889008359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 211}], {
             RGBColor[
             0.25792046228139853`, 0.38842113733253425`, 0.9379995608165705]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 216}], {
             RGBColor[
             0.2661597993989548, 0.3970812030472318, 0.9384687788764086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 219}], {
             RGBColor[
             0.2738583241419696, 0.40517284066680126`, 0.9389071984715764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 221}], {
             RGBColor[
             0.2840475061144973, 0.4158823169513779, 0.939487457311368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 171}], {
             RGBColor[
             0.5797766952507789, 0.6672643729865424, 0.9613588180759691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 179}], {
             RGBColor[
             0.8674233288276321, 0.8946955574709121, 0.8648978949263142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 245}], {
             RGBColor[
             0.5828013526273942, 0.6698841791824666, 0.9615515465694076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 156}], {
             RGBColor[
             0.22000089461836236`, 0.3485652674792311, 0.935840097535134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 184}], {
             RGBColor[
             0.22486994634019453`, 0.35368294955458646`, 0.9361173828275757]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 197}], {
             RGBColor[
             0.21140151230331092`, 0.3395267714337822, 0.9353503754339378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 202}], {
             RGBColor[
             0.22021191752572378`, 0.34878706593449305`, 0.9358521149775277]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 214}], {
             RGBColor[
             0.21259246077095287`, 0.340778533783768, 0.9354181981873197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 275}], {
             RGBColor[
             0.21254067958734837`, 0.340724108476683, 0.9354152493255168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 293}], {
             RGBColor[
             0.21078204772465953`, 0.3388756748852968, 0.9353150978425994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 178}], {
             RGBColor[
             0.25237767810444756`, 0.38259531972974414`, 0.9376839074575076]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 202}], {
             RGBColor[
             0.22791002753873152`, 0.3568782676465297, 0.9362905109544353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 208}], {
             RGBColor[
             0.2568293808226203, 0.38727434154079826`, 0.9379374253416035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 214}], {
             RGBColor[
             0.2202905707839606, 0.3488697354958046, 0.9358565941642273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 268}], {
             RGBColor[
             0.2451076812596908, 0.374954092101482, 0.9372698918921952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 201}], {
             RGBColor[
             0.3335467378743898, 0.46332315262546664`, 0.9424742810869247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 218}], {
             RGBColor[
             0.30101158042666865`, 0.4302700565079032, 0.9405795858965723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 229}], {
             RGBColor[
             0.34618459391463335`, 0.47426942833041186`, 0.9432795540985917]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 257}], {
             RGBColor[
             0.3686428791962128, 0.49372166625507674`, 0.944710576177652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 259}], {
             RGBColor[
             0.40512064339431064`, 0.5250197481568593, 0.947117003308583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 261}], {
             RGBColor[
             0.3733109108199431, 0.49776488062546065`, 0.9450080190249379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 284}], {
             RGBColor[
             0.3008123283039969, 0.4300606298936609, 0.9405682387829533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 175}], {
             RGBColor[
             0.34907161965836087`, 0.47545391883295585`, 0.9435117019171652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 177}], {
             RGBColor[
             0.4114198455834537, 0.5307729245068593, 0.947436286649661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 217}], {
             RGBColor[
             0.6053338779034495, 0.6866046110497097, 0.9641707450092601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 252}], {
             RGBColor[
             0.35208167801260865`, 0.47861768101199287`, 0.9436831202874573]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 253}], {
             RGBColor[
             0.35017871358609476`, 0.47661754474481344`, 0.9435747492785509]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 175}], {
             RGBColor[
             0.2709524595475128, 0.4021185927355705, 0.9387417137817635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 204}], {
             RGBColor[
             0.23913822416860225`, 0.3686798142133081, 0.9369299401418781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 235}], {
             RGBColor[
             0.24471645266359499`, 0.3745428860416596, 0.9372476120024185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 252}], {
             RGBColor[
             0.2739625179017606, 0.4052823549146075, 0.9389131321520556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 253}], {
             RGBColor[
             0.27205955347524674`, 0.4032822186474281, 0.9388047611431494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 292}], {
             RGBColor[
             0.24522762221879252`, 0.3750801576541939, 0.9372767223523794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 168}], {
             RGBColor[
             0.4880465107801085, 0.5934258804224648, 0.9533459462263981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[
             0.6520185359229838, 0.7272823998054908, 0.9664968499202544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 246}], {
             RGBColor[
             0.5945439555585024, 0.6817165928791875, 0.9612238245492863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 256}], {
             RGBColor[
             0.7927339846129686, 0.8352252152179895, 0.8425165155244698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 296}], {
             RGBColor[
             0.6432277867867322, 0.7204149997680831, 0.9656206702005743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 299}], {
             RGBColor[
             0.7923522710279916, 0.8350967196266381, 0.8509761351220573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 186}], {
             RGBColor[
             0.22312007554742067`, 0.3518437244031648, 0.9360177302746292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 230}], {
             RGBColor[
             0.2328116110999559, 0.36203014274772405`, 0.9365696488870041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 265}], {
             RGBColor[
             0.21936843133233605`, 0.34790050846512904`, 0.9358040796866404]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 269}], {
             RGBColor[
             0.22164816720784125`, 0.350296655413888, 0.9359339072721834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 191}], {
             RGBColor[
             0.26420786908525307`, 0.39502960052800135`, 0.9383576193326653]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 203}], {
             RGBColor[
             0.27206034387321254`, 0.4032830494058043, 0.9388048061551442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 210}], {
             RGBColor[
             0.33154191612091594`, 0.45934744108992703`, 0.9424285250056568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 239}], {
             RGBColor[
             0.34783050852175984`, 0.47345580113907954`, 0.9434664197100019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 184}], {
             RGBColor[
             0.23939823162616325`, 0.3689530985366296, 0.9369447471819397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.23660390230659725`, 0.366016081251054, 0.9367856142610302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 197}], {
             RGBColor[
             0.22592979758927967`, 0.35479692041582533`, 0.9361777397883018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 211}], {
             RGBColor[
             0.2418593140070983, 0.3715398521606279, 0.9370849021826888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 216}], {
             RGBColor[
             0.2500986511246546, 0.3801999178753255, 0.9375541202425267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 168}], {
             RGBColor[
             0.38489864849528777`, 0.5078015965832141, 0.9457463794229767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 210}], {
             RGBColor[
             0.3812406788826516, 0.5046332471596473, 0.9455132968338751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 241}], {
             RGBColor[
             0.33149984085228634`, 0.458806984736167, 0.9424442983869149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 277}], {
             RGBColor[
             0.36650966152605724`, 0.4918739803278257, 0.94457464943404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 179}], {
             RGBColor[
             0.986953469781533, 0.9683582137242022, 0.5663859549250714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 207}], {
             RGBColor[
             0.8629243195572578, 0.8731271056740303, 0.676546302374514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 232}], {
             RGBColor[
             0.9871784526525289, 0.9674285696046385, 0.48831934332178484`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 240}], {
             RGBColor[
             0.987596961950581, 0.9683237186753911, 0.533871497674751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 281}], {
             RGBColor[
             0.9081683799556731, 0.6116901368011833, 0.2799978889278235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 217}], {
             RGBColor[
             0.899879476841495, 0.9180128953290518, 0.7153753712159427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 233}], {
             RGBColor[
             0.9934058766223102, 0.9883041618002921, 0.5236485484298345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 262}], {
             RGBColor[
             0.9933514957949947, 0.9881878467094093, 0.5177295309761065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 271}], {
             RGBColor[
             0.9850940999243964, 0.9612451065301149, 0.40815265332302325`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 291}], {
             RGBColor[
             0.9053156340255587, 0.5627492600761606, 0.30706567418331665`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 174}], {
             RGBColor[
             0.5731249742958058, 0.6609624837721939, 0.9611637427211077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 185}], {
             RGBColor[
             0.660998380157889, 0.7339582173045702, 0.9676238615993047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 194}], {
             RGBColor[
             0.6348798248522232, 0.7127539974799229, 0.9655677132502221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 215}], {
             RGBColor[
             0.874514844691243, 0.8999677108189541, 0.8534618509904951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 282}], {
             RGBColor[
             0.8587917501354356, 0.8900542041854869, 0.9612556665550847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 283}], {
             RGBColor[
             0.6863247949375169, 0.7545193417646557, 0.9696176497444712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 286}], {
             RGBColor[
             0.6564811647517911, 0.7302909383396649, 0.9672682498554315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 297}], {
             RGBColor[
             0.7571627446031911, 0.8102205578247882, 0.9764305643600557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 182}], {
             RGBColor[
             0.34652806688330007`, 0.474422427150048, 0.9433067307526943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 277}], {
             RGBColor[
             0.3674840405107483, 0.49271793843065337`, 0.944636736001335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 187}], {
             RGBColor[
             0.3284772756829356, 0.4574787305648249, 0.9422044795128589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 213}], {
             RGBColor[
             0.36045188979201, 0.48517353421527176`, 0.944241873649848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 219}], {
             RGBColor[
             0.2836300261607937, 0.41544351905027754`, 0.9394636824456108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 221}], {
             RGBColor[
             0.2938192081333214, 0.4261529953348542, 0.9400439412854023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 264}], {
             RGBColor[
             0.29384317958318956`, 0.42617819084854336`, 0.9400453064240097]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[
             0.8434397887079927, 0.3245517789190093, 0.188825975634882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 195}], {
             RGBColor[
             0.820518598671917, 0.15872051746543236`, 0.16728193930165758`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 200}], {
             RGBColor[
             0.8539446998932355, 0.37225212712685507`, 0.1975915310267845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 225}], {
             RGBColor[
             0.8914281470596066, 0.5246344158422436, 0.23572348923178596`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 228}], {
             RGBColor[
             0.8191183413836293, 0.5128704810525186, 0.5754638060619697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 255}], {
             RGBColor[
             0.8904238882805281, 0.5212468151692371, 0.2318221335134233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 198}], {
             RGBColor[
             0.4413043319504303, 0.556360389684118, 0.9494225547381876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 245}], {
             RGBColor[
             0.4213779646314022, 0.5393981467165758, 0.9480708091897773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 289}], {
             RGBColor[
             0.35466828761855285`, 0.4799752914739057, 0.9438802596927696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 298}], {
             RGBColor[
             0.35180269388930685`, 0.47696337077533185`, 0.9437170683691549]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 174}], {
             RGBColor[
             0.33090944455997406`, 0.4574098756542951, 0.9424391100455509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 183}], {
             RGBColor[
             0.2620424461666492, 0.39275360374480583`, 0.9382343017009069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 203}], {
             RGBColor[
             0.26454467239722235`, 0.39538360216344437`, 0.9383767997830261]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 206}], {
             RGBColor[
             0.2530845856194636, 0.3833383243485512, 0.9377241647947119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 244}], {
             RGBColor[
             0.2560033039447505, 0.38640608236585794`, 0.9378903814854801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 270}], {
             RGBColor[
             0.24887539777286288`, 0.3789142010438502, 0.9374844577737833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 272}], {
             RGBColor[
             0.2463878565667746, 0.37629963751702955`, 0.937342795982084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 186}], {
             RGBColor[
             0.24357136840210497`, 0.3733393298802981, 0.937182401147727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 196}], {
             RGBColor[
             0.2690530219671379, 0.40012216340729806`, 0.9386335436215274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 209}], {
             RGBColor[
             0.2611649721580388, 0.3918313229266909, 0.938184330854223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 230}], {
             RGBColor[
             0.25326290395464024`, 0.3835257482248573, 0.9377343197601018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 263}], {
             RGBColor[
             0.25907859446240145`, 0.3896384076845897, 0.9380655147309758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 276}], {
             RGBColor[
             0.24447758470727698`, 0.3742918206744662, 0.9372340088256796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 279}], {
             RGBColor[
             0.2579831193391787, 0.3884869938729482, 0.9380031290433184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 185}], {
             RGBColor[
             0.4801968939468863, 0.58722835298474, 0.9526796025142897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 194}], {
             RGBColor[
             0.45407833864122044`, 0.5660241331600927, 0.9506234541652072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 283}], {
             RGBColor[
             0.5055233087265141, 0.6077894774448256, 0.9546733906594562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 297}], {
             RGBColor[
             0.5763612583921884, 0.663490693504958, 0.9614863052750408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 177}], {
             RGBColor[
             0.3568594089399756, 0.48219931048302006`, 0.944007932963718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 242}], {
             RGBColor[
             0.2674717938620085, 0.3984601924131547, 0.9385434950201575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 252}], {
             RGBColor[
             0.2975212413691305, 0.4300440669881537, 0.9402547666015143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 253}], {
             RGBColor[
             0.29561827694261666`, 0.42804393072097424`, 0.9401463955926079]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 280}], {
             RGBColor[
             0.2812847712693677, 0.4129785074616403, 0.9393301236490378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 199}], {
             RGBColor[
             0.17893943915932659`, 0.3054070743451405, 0.9335017083917216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 226}], {
             RGBColor[
             0.17893944427006758`, 0.3054070797168533, 0.9335017086827707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 287}], {
             RGBColor[
             0.5599634445497977, 0.5545563829440247, 0.6024338644222329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 217}], {
             RGBColor[
             0.6131216671850642, 0.6933500026997739, 0.964666976055813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 247}], {
             RGBColor[
             0.4991479409504841, 0.603343634292864, 0.9539698061272375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 273}], {
             RGBColor[
             0.5185213619952923, 0.6190718502597115, 0.9554949527990644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 285}], {
             RGBColor[
             0.40098949086418123`, 0.5217386754938967, 0.9467716736701495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 182}], {
             RGBColor[
             0.29211972893207316`, 0.4243667349411374, 0.9399471584590454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 202}], {
             RGBColor[
             0.25258870101180897`, 0.3828171181850061, 0.9376959248999015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 208}], {
             RGBColor[
             0.2815080542956977, 0.41321319207927465`, 0.9393428392870697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 268}], {
             RGBColor[
             0.26978635473276824`, 0.4008929426399584, 0.9386753058376613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 281}], {
             RGBColor[
             0.9148614845826333, 0.6349726325663724, 0.4685681683997813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 190}], {
             RGBColor[
             0.23107912024585836`, 0.36020918501380295`, 0.9364709860958538]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 250}], {
             RGBColor[
             0.22830469938985565`, 0.3572930927857018, 0.9363129869324922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 207}], {
             RGBColor[
             0.729702675862836, 0.7887685434205706, 0.9736936013369495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 232}], {
             RGBColor[
             0.8539568089581072, 0.8830700073511788, 0.7854666422842203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 240}], {
             RGBColor[
             0.8543753182561593, 0.8839651564219314, 0.8310187966371865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 246}], {
             RGBColor[
             0.656342497401248, 0.7307927865257904, 0.9668372480070162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 256}], {
             RGBColor[
             0.8545325264557142, 0.8843014088645924, 0.8481299389821997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 296}], {
             RGBColor[
             0.7050263286294778, 0.769491193414686, 0.9712340936583042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 299}], {
             RGBColor[
             0.8541508128707371, 0.884172913273241, 0.8565895585797871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 208}], {
             RGBColor[
             0.2965714316502459, 0.42904575675219153`, 0.9402006763431414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 268}], {
             RGBColor[
             0.28484973208731645`, 0.4167255073128753, 0.939533142893733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 244}], {
             RGBColor[
             0.24855034907625476`, 0.37857255425443737`, 0.937465946731378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 189}], {
             RGBColor[
             0.2346427787554684, 0.3639548160564028, 0.9366739311760157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 197}], {
             RGBColor[
             0.22396867403815082`, 0.3527356552211741, 0.9360660567032872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 202}], {
             RGBColor[
             0.23277907926056368`, 0.361995949721885, 0.9365677962468772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 214}], {
             RGBColor[
             0.22515962250579277`, 0.3539874175711599, 0.9361338794566691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 216}], {
             RGBColor[
             0.24813752757352578`, 0.3781386526806742, 0.9374424371575123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 275}], {
             RGBColor[
             0.22510784132218828`, 0.35393299226407493`, 0.9361309305948662]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 293}], {
             RGBColor[
             0.22334920945949943`, 0.35208455867268873`, 0.9360307791119489]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 237}], {
             RGBColor[
             0.6034248054489583, 0.6889264668979879, 0.961922957584288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 239}], {
             RGBColor[
             0.4896022864326819, 0.5953748312271646, 0.9532789058066227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 282}], {
             RGBColor[
             0.7658636697865162, 0.8163200733980329, 0.9527715263482667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 283}], {
             RGBColor[
             0.5933967145885973, 0.6807852109772019, 0.9611335095376532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 295}], {
             RGBColor[
             0.7026775395247731, 0.7666581291332051, 0.9717409425805205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 297}], {
             RGBColor[
             0.6642346642542716, 0.7364864270373344, 0.9679464241532377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 196}], {
             RGBColor[
             0.255450766680841, 0.38582533066860314`, 0.9378589153057062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 230}], {
             RGBColor[
             0.23966064866834333`, 0.3692289154861624, 0.9369596914442806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 263}], {
             RGBColor[
             0.24547633917610456`, 0.3753415749458948, 0.9372908864151546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 269}], {
             RGBColor[
             0.2284972047762287, 0.3574954281523263, 0.93632394982946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 276}], {
             RGBColor[
             0.2308753294209801, 0.3599949879357713, 0.9364593805098584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 279}], {
             RGBColor[
             0.24438086405288187`, 0.3741901611342533, 0.9372285007274972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 205}], {
             RGBColor[
             0.44668815437293624`, 0.55925348518074, 0.950254691291311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 213}], {
             RGBColor[
             0.395904109711405, 0.5173339739380506, 0.9464476376799205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 264}], {
             RGBColor[
             0.3292953995025846, 0.4583386305713222, 0.9422510704540822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 212}], {
             RGBColor[
             0.20871789165381538`, 0.33670611597978567`, 0.9351975472080101]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 243}], {
             RGBColor[
             0.21194079974675017`, 0.3400935967296356, 0.9353810870560375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 294}], {
             RGBColor[
             0.20780626806211017`, 0.3357479417846294, 0.9351456315930887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 197}], {
             RGBColor[
             0.22117434471858483`, 0.3497986379355985, 0.9359069237823778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 211}], {
             RGBColor[
             0.23710386113640347`, 0.3665415696804011, 0.9368140861767649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 216}], {
             RGBColor[
             0.24534319825395978`, 0.3752016353950986, 0.9372833042366027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 275}], {
             RGBColor[
             0.22231351200262228`, 0.3509959749784993, 0.9359717976739568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 293}], {
             RGBColor[
             0.2205548801399334, 0.3491475413871131, 0.9358716461910392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 212}], {
             RGBColor[
             0.21992645288427248`, 0.3484870244968241, 0.9358358581885042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 250}], {
             RGBColor[
             0.22535768471974588`, 0.35419559351589436`, 0.9361451588067469]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 203}], {
             RGBColor[
             0.2517414689713402, 0.38192662359285945`, 0.9376476762885642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 195}], {
             RGBColor[
             0.8420649475314406, 0.3139841471767838, 0.18750942617155456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 200}], {
             RGBColor[
             0.875491048752759, 0.5275157568382065, 0.21781901789668148`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[
             0.91297449591913, 0.6798980455535951, 0.25595097610168294`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 228}], {
             RGBColor[
             0.8406646902431527, 0.6681341107638701, 0.5956912929318666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 255}], {
             RGBColor[
             0.9119702371400515, 0.6765104448805886, 0.25204962038332024`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 199}], {
             RGBColor[
             0.28921237678725265`, 0.4129203038152378, 0.9400888107445714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 220}], {
             RGBColor[
             0.3283447463388828, 0.4540509053495343, 0.9423173412993839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 236}], {
             RGBColor[
             0.511354201918838, 0.6127180573453962, 0.9550785966275717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 249}], {
             RGBColor[
             0.609038860752824, 0.33213297985445467`, 0.5560510629020323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 266}], {
             RGBColor[
             0.3235658537972168, 0.4490279862889558, 0.942045190438874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 283}], {
             RGBColor[
             0.5672781592829315, 0.6595809911525545, 0.9590773611885706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 286}], {
             RGBColor[
             0.5374345290972057, 0.6353525877275636, 0.9567279612995309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 297}], {
             RGBColor[
             0.6381161089486057, 0.715282207212687, 0.9658902758041552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 200}], {
             RGBColor[
             0.8525698587166832, 0.36168449538462955`, 0.19627498156345707`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 225}], {
             RGBColor[
             0.8900533058830544, 0.5140667841000182, 0.23440693976845853`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.8890490471039758, 0.5106791834270117, 0.23050558405009586`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 230}], {
             RGBColor[
             0.2651423022333762, 0.39601174901316233`, 0.938410833918081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 263}], {
             RGBColor[
             0.27095799274113747`, 0.40212440847289477`, 0.9387420288889549]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 279}], {
             RGBColor[
             0.2698625176179148, 0.40097299466125325`, 0.9386796432012976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 289}], {
             RGBColor[
             0.28595784411409636`, 0.4178902033113814, 0.9395962482343534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 298}], {
             RGBColor[
             0.28309225038485036`, 0.4148782826128075, 0.9394330569107388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 214}], {
             RGBColor[
             0.21169118846890916`, 0.33983123945035565`, 0.9353668720630313]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 275}], {
             RGBColor[
             0.21163940728530467`, 0.33977681414327066`, 0.9353639232012283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 293}], {
             RGBColor[
             0.20988077542261582`, 0.33792838055188446`, 0.9352637717183109]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 222}], {
             RGBColor[
             0.4501940180001994, 0.5640601889318158, 0.9499889976724383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 245}], {
             RGBColor[
             0.4443289893270455, 0.5589801958800422, 0.949615283231626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 258}], {
             RGBColor[
             0.7130111957358749, 0.7734744682690422, 0.9502848227262681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 278}], {
             RGBColor[
             0.5335934338471843, 0.6322342135642272, 0.9564255762110536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 290}], {
             RGBColor[
             0.5385920372825843, 0.6362923050176035, 0.9568190845839761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 220}], {
             RGBColor[
             0.21805936955163013`, 0.34652460153429643`, 0.9357295305548126]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 226}], {
             RGBColor[
             0.178927005110741, 0.3053940053717128, 0.9335010002910491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 228}], {
             RGBColor[
             0.49763512145939465`, 0.5809234064486897, 0.9579150616794772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 266}], {
             RGBColor[
             0.21328047700996416`, 0.3415016824737179, 0.9354573796943026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 225}], {
             RGBColor[
             0.9234794071043728, 0.7275983937614409, 0.2647165314935854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 255}], {
             RGBColor[
             0.9224751483252943, 0.7242107930884344, 0.2608151757752228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 282}], {
             RGBColor[
             0.9248264998510323, 0.7738160826625009, 0.5864939522963153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 295}], {
             RGBColor[
             0.8616403695892892, 0.7241541383976731, 0.6054633685285691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 209}], {
             RGBColor[
             0.29313467956513195`, 0.424290095199951, 0.9400468245012701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 218}], {
             RGBColor[
             0.2885778810548669, 0.4195006110479498, 0.9397873215672898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 229}], {
             RGBColor[
             0.3337508945428317, 0.46349998287045846`, 0.9424872897693092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 257}], {
             RGBColor[
             0.35620917982441114`, 0.48295222079512334`, 0.9439183118483695]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 259}], {
             RGBColor[
             0.3926869440225089, 0.5142503026969059, 0.9463247389793005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 261}], {
             RGBColor[
             0.36087721144814144`, 0.48699543516550725`, 0.9442157546956553]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 208}], {
             RGBColor[
             0.2570404037299817, 0.3874961399960602, 0.9379494427839974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 214}], {
             RGBColor[
             0.22050159369132202`, 0.3490915339510665, 0.935868611606621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 268}], {
             RGBColor[
             0.2453187041670522, 0.37517589055674394`, 0.937281909334589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 275}], {
             RGBColor[
             0.22044981250771753`, 0.3490371086439815, 0.9358656627448182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 206}], {
             RGBColor[
             0.24813385698154097`, 0.37813479465576916`, 0.9374422281227288]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 244}], {
             RGBColor[
             0.2510525753068279, 0.38120255267307596`, 0.9376084448134971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 270}], {
             RGBColor[
             0.2439246691349402, 0.37371067135106817`, 0.9372025211018002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 235}], {
             RGBColor[
             0.23646094075205434`, 0.36586581959294334`, 0.9367774728119916]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 253}], {
             RGBColor[
             0.26380404156370607`, 0.39460515219871184`, 0.9383346219527224]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 292}], {
             RGBColor[
             0.2369721103072519, 0.36640309120547765`, 0.9368065831619525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 213}], {
             RGBColor[
             0.4786627684820106, 0.5869482888311869, 0.9522920854283001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 231}], {
             RGBColor[
             0.4872830813565614, 0.5944147705735998, 0.9528413641420233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 244}], {
             RGBColor[
             0.23959248852906917`, 0.3691572748581827, 0.9369558098251829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 270}], {
             RGBColor[
             0.23246458235718154`, 0.361665393536175, 0.936549886113486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 272}], {
             RGBColor[
             0.22997704115109324`, 0.35905083000935434`, 0.9364082243217868]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 231}], {
             RGBColor[
             0.5953538117647618, 0.6805701172311853, 0.962430259270135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 232}], {
             RGBColor[
             0.8698424070552139, 0.8954799573196557, 0.7870499702431855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 240}], {
             RGBColor[
             0.870260916353266, 0.8963751063904083, 0.8326021245961515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 268}], {
             RGBColor[
             0.274238057450941, 0.4055719644510125, 0.9389288237217572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 218}], {
             RGBColor[
             0.2605995221174108, 0.3912369990823875, 0.9381521293109176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 276}], {
             RGBColor[
             0.24846893317691396`, 0.37848698098216405`, 0.9374613102163545]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 279}], {
             RGBColor[
             0.2619744678088157, 0.39268215418064606`, 0.9382304304339932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 239}], {
             RGBColor[
             0.39484568065555037`, 0.5164172158880604, 0.9463801955164135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 277}], {
             RGBColor[
             0.36382607089811214`, 0.48954958900708645`, 0.9444036534122333]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 216}], {
             RGBColor[
             0.2505986099544608, 0.38072540630467244`, 0.9375825921582613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 221}], {
             RGBColor[
             0.26848631667000333`, 0.39952652020881857`, 0.9386012705932207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 243}], {
             RGBColor[
             0.2149437082857312, 0.34324984399950276`, 0.9355520982549272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 250}], {
             RGBColor[
             0.21715203202826977`, 0.34557093226872304`, 0.9356778590251427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 294}], {
             RGBColor[
             0.2108091766010912, 0.3389041890544966, 0.9353166427919786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 231}], {
             RGBColor[
             0.43649903669503015`, 0.5524952593309104, 0.9490343105306326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 264}], {
             RGBColor[
             0.36127001361165895`, 0.48603343422176903`, 0.9442884645910713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 275}], {
             RGBColor[
             0.21283035575294662`, 0.34102857649325646`, 0.9354317459546102]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 293}], {
             RGBColor[
             0.21107172389025777`, 0.33918014290187026`, 0.9353315944716927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 223}], {
             RGBColor[
             0.9412290011481947, 0.7868146166289862, 0.47926705037049566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 234}], {
             RGBColor[
             0.9062111144378386, 0.5631850367729421, 0.44751685008743375`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 271}], {
             RGBColor[
             0.9862840872732699, 0.9639445925953173, 0.5488858494022204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 274}], {
             RGBColor[
             0.979839341035498, 0.9422049502369351, 0.5238492272566825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 282}], {
             RGBColor[
             0.97938013431987, 0.9823295669124169, 0.8386095157394571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 286}], {
             RGBColor[
             0.7770695489362254, 0.8225663010665949, 0.8446220990398039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 233}], {
             RGBColor[
             0.9005620992858752, 0.9194729557138646, 0.7896746116293041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 247}], {
             RGBColor[
             0.6930619732704799, 0.7591753208357144, 0.9707042644868367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 262}], {
             RGBColor[
             0.9005077184585596, 0.9193566406229818, 0.783755594175576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 273}], {
             RGBColor[
             0.7124353943152881, 0.7749035368025619, 0.9722294111586636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 229}], {
             RGBColor[
             0.3012157370951104, 0.430446886752895, 0.9405925945789568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 284}], {
             RGBColor[
             0.25584347148447395`, 0.38623808831614403`, 0.9378812792633183]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 221}], {
             RGBColor[
             0.28442417853057445`, 0.4162782235430855, 0.9395089082482266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 264}], {
             RGBColor[
             0.28444814998044265`, 0.4163034190567747, 0.9395102733868341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 226}], {
             RGBColor[
             0.21805937466237113`, 0.3465246069060093, 0.9357295308458616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 228}], {
             RGBColor[
             0.5367674910110247, 0.6220540079829862, 0.9601435922342896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 236}], {
             RGBColor[
             0.4402011946832155, 0.5463223550644548, 0.9507193164378127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 266}], {
             RGBColor[
             0.2524128465615943, 0.3826322840080144, 0.9376859102491151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 231}], {
             RGBColor[
             0.3698663550363416, 0.4934747204504928, 0.9448363781661868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 245}], {
             RGBColor[
             0.43026765068117134`, 0.5470979459642735, 0.9486372521240278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 261}], {
             RGBColor[
             0.41838703187400994`, 0.5368075510907742, 0.9478802295992542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 278}], {
             RGBColor[
             0.51953209520131, 0.6203519636484585, 0.9554475451034554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 290}], {
             RGBColor[
             0.5245306986367102, 0.6244100551018348, 0.9558410534763778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 234}], {
             RGBColor[
             0.852336886710356, 0.35775657985604403`, 0.19596820028306192`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 271}], {
             RGBColor[
             0.9324098595457874, 0.7585161356784191, 0.29733719959784854`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 274}], {
             RGBColor[
             0.9259651133080155, 0.7367764933200369, 0.2723005774523107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 287}], {
             RGBColor[
             0.9141648921008272, 0.6925393884549282, 0.24954185631357317`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 291}], {
             RGBColor[
             0.8526313936469496, 0.36002028922446494`, 0.19625022045814194`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 249}], {
             RGBColor[
             0.8940523406864429, 0.5263405979795888, 0.25076760006070237`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 254}], {
             RGBColor[
             0.9304233123934045, 0.7541309251793602, 0.28356918675006826`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 258}], {
             RGBColor[
             0.9656458741337097, 0.9399341707856219, 0.6428561562394914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 260}], {
             RGBColor[
             0.9093392465848947, 0.8957090172216551, 0.6607919677185569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 288}], {
             RGBColor[
             0.9157129138329121, 0.6873344410170366, 0.27129446960632875`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 234}], {
             RGBColor[
             0.889140927135372, 0.5070538412384147, 0.23353324484929344`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 255}], {
             RGBColor[
             0.9599585954916654, 0.876593081803823, 0.2989471339802242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 287}], {
             RGBColor[
             0.950968932525843, 0.8418366498372989, 0.2871069008798047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 228}], {
             RGBColor[
             0.4976351265701356, 0.5809234118204025, 0.9579150619705263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 266}], {
             RGBColor[
             0.21328048212070516`, 0.3415016878454308, 0.9354573799853517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 264}], {
             RGBColor[
             0.2772132461146813, 0.4086990763744601, 0.9390982563147601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 266}], {
             RGBColor[
             0.5319885984693589, 0.6170310889224077, 0.9598714413737797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 257}], {
             RGBColor[
             0.3688470358646546, 0.49389849650006856`, 0.9447235848600365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 259}], {
             RGBColor[
             0.40532480006275245`, 0.5251965784018511, 0.9471300119909675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 261}], {
             RGBColor[
             0.3735150674883849, 0.49794171087045247`, 0.9450210277073223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 284}], {
             RGBColor[
             0.3010164849724387, 0.4302374601386527, 0.9405812474653377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 263}], {
             RGBColor[
             0.2551678747286398, 0.38552799329045395`, 0.9378428050275294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 269}], {
             RGBColor[
             0.23818874032876391`, 0.3676818464968855, 0.9368758684418348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 289}], {
             RGBColor[
             0.27016772610159867`, 0.4012937881289406, 0.9386970243729278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 298}], {
             RGBColor[
             0.2673021323723527, 0.39828186743036675`, 0.9385338330493134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 240}], {
             RGBColor[
             0.9945150494485371, 0.9906765703210165, 0.6443751655434223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 256}], {
             RGBColor[
             0.9946722576480922, 0.9910128227636774, 0.6614863078884357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 296}], {
             RGBColor[
             0.8451660598218556, 0.8762026073137711, 0.7845904625645401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 299}], {
             RGBColor[
             0.994290544063115, 0.9908843271723261, 0.6699459274860231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 262}], {
             RGBColor[
             0.9940341182393746, 0.9896479070942221, 0.5920287713894679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 288}], {
             RGBColor[
             0.9279948066453856, 0.7277856301692169, 0.40221351612468526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 291}], {
             RGBColor[
             0.9059982564699387, 0.5642093204609733, 0.381364914596678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 255}], {
             RGBColor[
             0.8881366683562935, 0.5036662405654082, 0.2296318891309308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 271}], {
             RGBColor[
             0.8973919728354314, 0.5348865558223752, 0.26558699931478663`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 274}], {
             RGBColor[
             0.8909472265976595, 0.513146913463993, 0.24055037716924876`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 287}], {
             RGBColor[
             0.8791470053904711, 0.46890980859888415`, 0.21779165603051126`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 252}], {
             RGBColor[
             0.2712852344852127, 0.40246836029424277`, 0.9387606648221691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 253}], {
             RGBColor[
             0.2693822700586988, 0.40046822402706334`, 0.9386522938132629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 292}], {
             RGBColor[
             0.24255033880224458`, 0.3722661630338292, 0.9371242550224929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 249}], {
             RGBColor[
             0.7208953090971567, 0.4244044295693752, 0.5644530380404611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 266}], {
             RGBColor[
             0.43542230214154953`, 0.5412994360038763, 0.9504471655773028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 239}], {
             RGBColor[
             0.5249567920726707, 0.6240772116080362, 0.9560621419984239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 282}], {
             RGBColor[
             0.8012181754265049, 0.8450224537789045, 0.955554762540068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 283}], {
             RGBColor[
             0.6287512202285861, 0.7094875913580734, 0.9639167457294545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 295}], {
             RGBColor[
             0.738032045164762, 0.7953605095140767, 0.9745241787723218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 297}], {
             RGBColor[
             0.6995891698942603, 0.7651888074182058, 0.970729660345039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 251}], {
             RGBColor[
             0.2826141781107905, 0.4143757983412377, 0.9394058314019756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 300}], {
             RGBColor[
             0.2671877155710705, 0.398161608117775, 0.9385273171817448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 295}], {
             RGBColor[
             0.6242095261484855, 0.7018088738432534, 0.9658801269946564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 256}], {
             RGBColor[
             0.9950907669461442, 0.9919079718344301, 0.7070384622414018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 281}], {
             RGBColor[
             0.9155049767516813, 0.6349381375175613, 0.436053711149461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 299}], {
             RGBColor[
             0.9947090533611671, 0.9917794762430787, 0.7154980818389891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 277}], {
             RGBColor[
             0.3140852328677468, 0.44372332658360614`, 0.9413346549652732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 243}], {
             RGBColor[
             0.22929951054390013`, 0.35833870238327276`, 0.9363696399560237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 280}], {
             RGBColor[
             0.25424538211649345`, 0.38455839506567835`, 0.9377902704379731]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 294}], {
             RGBColor[
             0.22516497885926012`, 0.35399304743826654`, 0.9361341844930751]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 294}], {
             RGBColor[
             0.21403208469402601`, 0.34229166980434655`, 0.935500182640006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 270}], {
             RGBColor[
             0.23538330068246843`, 0.36473315155348174`, 0.9367161028042543]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 272}], {
             RGBColor[
             0.23289575947638014`, 0.3621185880266611, 0.936574441012555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 289}], {
             RGBColor[
             0.3576929449951681, 0.48259509766982983`, 0.944072988186208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 298}], {
             RGBColor[
             0.35482735126592213`, 0.47958317697125596`, 0.9439097968625934]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 256}], {
             RGBColor[
             0.7970579460912328, 0.838735601938289, 0.8428569136112316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 296}], {
             RGBColor[
             0.6475517482649964, 0.7239253864883827, 0.965961068287336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 299}], {
             RGBColor[
             0.7966762325062557, 0.8386071063469377, 0.851316533208819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 267}], {
             RGBColor[
             0.5234677465828359, 0.6240137244860162, 0.9556284450179895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 273}], {
             RGBColor[
             0.598461668080708, 0.6848971683956518, 0.9615322412300882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 285}], {
             RGBColor[
             0.4809297969495969, 0.5875639936298371, 0.952808962101173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 270}], {
             RGBColor[
             0.21830317142063266`, 0.3467808527565494, 0.9357434147105796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 254}], {
             RGBColor[
             0.8549509396381043, 0.371609679278205, 0.19822709100428773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 288}], {
             RGBColor[
             0.8402405410776118, 0.30481319511588134`, 0.18595237386054825`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 300}], {
             RGBColor[
             0.27128730129384493`, 0.40247053264115845`, 0.9387607825238632]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 253}], {
             RGBColor[
             0.29862833529686444`, 0.43120769290001126`, 0.9403178139629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 292}], {
             RGBColor[
             0.2717964040404102, 0.4030056319067771, 0.9387897751721301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 292}], {
             RGBColor[
             0.26989343961389634`, 0.40100549563959764`, 0.9386814041632237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 258}], {
             RGBColor[
             0.926544473085371, 0.7852032520842381, 0.5903156471830767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 260}], {
             RGBColor[
             0.870237845536556, 0.7409780985202714, 0.6082514586621423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 288}], {
             RGBColor[
             0.8766115127845734, 0.5326035223156528, 0.21875396054991414`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 287}], {
             RGBColor[
             0.9499646737467646, 0.8384490491642924, 0.28320554516144203`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 296}], {
             RGBColor[
             0.8457417773194627, 0.8774340088271846, 0.8472537592625196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 299}], {
             RGBColor[
             0.994866261560722, 0.9921157286857396, 0.7326092241840025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 259}], {
             RGBColor[
             0.4277830853443319, 0.544648816326516, 0.9485610340700278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 261}], {
             RGBColor[
             0.39597335276996437`, 0.5173939487951174, 0.9464520497863826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 260}], {
             RGBColor[
             0.9054604072768613, 0.9267813441265331, 0.9675384281515653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 278}], {
             RGBColor[
             0.7823492729369855, 0.8297662429856849, 0.9557433701572854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 290}], {
             RGBColor[
             0.7873478763723856, 0.8338243344390612, 0.9561368785302078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 260}], {
             RGBColor[
             0.656707314635238, 0.7292515443954324, 0.9682208504157948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 261}], {
             RGBColor[
             0.4324511169680622, 0.5486920306968999, 0.9488584769173136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 261}], {
             RGBColor[
             0.6248975820608704, 0.7019966768640338, 0.9661118661321497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 278}], {
             RGBColor[
             0.7260426453881705, 0.7855410894217181, 0.9736791816363508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 290}], {
             RGBColor[
             0.7310412488235707, 0.7895991808750945, 0.9740726900092733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 278}], {
             RGBColor[
             0.5017864477209948, 0.6049815757231856, 0.9543168081378697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 290}], {
             RGBColor[
             0.5067850511563949, 0.6090396671765619, 0.9547103165107921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 271}], {
             RGBColor[
             0.9857223415414609, 0.9625888518240449, 0.4765328762826566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 291}], {
             RGBColor[
             0.9059438756426232, 0.5640930053700905, 0.37544589714295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 269}], {
             RGBColor[
             0.24400443083652518`, 0.3737945059566179, 0.9372070634127088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 276}], {
             RGBColor[
             0.24638255548127658`, 0.37629406574006286`, 0.9373424940931072]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 279}], {
             RGBColor[
             0.25988809011317837`, 0.3904892389385449, 0.938111614310746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 289}], {
             RGBColor[
             0.27598341660935993`, 0.40740644758867306`, 0.9390282193438018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 298}], {
             RGBColor[
             0.27311782288011394`, 0.40439452689009914`, 0.9388650280201871]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 269}], {
             RGBColor[
             0.2247455605611441, 0.35355221221429056`, 0.9361102992414712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 273}], {
             RGBColor[
             0.5428411676276441, 0.6397419404528637, 0.9571535916898165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 285}], {
             RGBColor[
             0.42530929649653304`, 0.542408765687049, 0.9484303125609015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 286}], {
             RGBColor[
             0.5134415575632728, 0.6158740125652669, 0.954839146691229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 298}], {
             RGBColor[
             0.2561386884802381, 0.3865483800965307, 0.9378980914344927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 272}], {
             RGBColor[
             0.22576785330449248`, 0.35462670670465335`, 0.9361685173008583]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 274}], {
             RGBColor[
             0.9710201994330907, 0.9139064692863681, 0.34191937648403536`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 291}], {
             RGBColor[
             0.897686479772025, 0.537150265190796, 0.2658690194898667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 285}], {
             RGBColor[
             0.5003032179944051, 0.6032922095966846, 0.9543341087730001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 287}], {
             RGBColor[
             0.9527752319881305, 0.8479297220628771, 0.29412403319976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 293}], {
             RGBColor[
             0.21101994270665328`, 0.33912571759478527`, 0.9353286456098898]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 279}], {
             RGBColor[
             0.24528708035805388`, 0.3751426519284214, 0.9372801084054498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 290}], {
             RGBColor[
             0.607930114483695, 0.6925840797342462, 0.9622776320149933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 283}], {
             RGBColor[
             0.7911900845661439, 0.8368811978581185, 0.9547653144934332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 295}], {
             RGBColor[
             0.9004709095023198, 0.9227541160141217, 0.9653727475363004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 297}], {
             RGBColor[
             0.8620280342318183, 0.892582413918251, 0.9615782291090177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 295}], {
             RGBColor[
             0.728003954304401, 0.7872192535932907, 0.973734730725687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 297}], {
             RGBColor[
             0.6895610790338994, 0.7570475514974199, 0.9699402122984042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 291}], {
             RGBColor[
             0.839904564048634, 0.3022307284450855, 0.18563064187816736`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 298}], {
             RGBColor[
             0.28811767425307283`, 0.4201603217285858, 0.9397192473655857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 297}], {
             RGBColor[
             0.7988419039700752, 0.8429204696534232, 0.9805476453412715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 299}], {
             RGBColor[
             0.8453600637344856, 0.8773055132358333, 0.8557133788601069]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.03434177932816089], {
             RGBColor[
             0.41852266255485593`, 0.5369250275695268, 0.9478888718663042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.03434177932816089], {
             RGBColor[
             0.2307572995292167, 0.3598709310360006, 0.936452658882132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.03434177932816089], {
             RGBColor[
             0.3773249031069595, 0.5012415989953558, 0.9452637870640326]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.03434177932816089], {
             RGBColor[
             0.5396207399250182, 0.6371274521652572, 0.9569000678242504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.03434177932816089], {
             RGBColor[
             0.220958970004222, 0.34957226545525755`, 0.9358946585110132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.03434177932816089], {
             RGBColor[
             0.3056730571205615, 0.43861214219787836`, 0.9407190004490276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.03434177932816089], {
             RGBColor[
             0.394746751143397, 0.516331528116975, 0.946373891815379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.03434177932816089], {
             RGBColor[
             0.6518492866916434, 0.7279488840923621, 0.9659339030856515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.03434177932816089], {
             RGBColor[
             0.5168296547678491, 0.6186246225079816, 0.9551058701141822]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.03434177932816089], {
             RGBColor[
             0.2114327980870659, 0.3395596547761419, 0.9353521571130395]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.03434177932816089], {
             RGBColor[
             0.34350580070653963`, 0.47194919229362253`, 0.9431088637641358]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.03434177932816089], {
             RGBColor[
             0.20154157699751735`, 0.32916335427138743`, 0.93478886670474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.03434177932816089], {
             RGBColor[
             0.30612838775897044`, 0.4390907235684761, 0.9407449308552837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.03434177932816089], {
             RGBColor[
             0.8226976998778256, 0.17547004422228246`, 0.1693686490773784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.03434177932816089], {
             RGBColor[
             0.23892277989457777`, 0.36845336862135236`, 0.9369176709091936]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.03434177932816089], {
             RGBColor[
             0.9934703621130101, 0.9884420897444159, 0.5306673961342021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.03434177932816089], {
             RGBColor[
             0.29622239326445615`, 0.42867889527841463`, 0.9401807991234267]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.03434177932816089], {
             RGBColor[
             0.9464007204285422, 0.9595463255731478, 0.9756137787701872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.03434177932816089], {
             RGBColor[
             0.2912671539208582, 0.4234706245479727, 0.9398986055734284]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.03434177932816089], {
             RGBColor[
             0.865905855945801, 0.8959138414156087, 0.9870720676150353]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.03434177932816089], {
             RGBColor[
             0.38345468665213356`, 0.5065509094103063, 0.9456543714511763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.03434177932816089], {
             RGBColor[
             0.8173789776787558, 0.8572619367637411, 0.982432355720336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.03434177932816089], {
             RGBColor[
             0.2963741173821658, 0.42883836694599214`, 0.9401894395874745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.03434177932816089], {
             RGBColor[
             0.9556367854010767, 0.9664345677069957, 0.9599795299232305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.03434177932816089], {
             RGBColor[
             0.2518103509231395, 0.3819990228915686, 0.9376515990138174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.03434177932816089], {
             RGBColor[
             0.9858349896506369, 0.9884104184434465, 0.8844144095680297]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.03434177932816089], {
             RGBColor[
             0.2584384877012701, 0.38896561489352793`, 0.9380290615978824]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.03434177932816089], {
             RGBColor[
             0.22341264573171882`, 0.35215123421688327`, 0.9360343917138061]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.03434177932816089], {
             RGBColor[
             0.24282295558358705`, 0.3725527005559224, 0.9371397801448899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.03434177932816089], {
             RGBColor[
             0.46219840465570133`, 0.574272512557169, 0.9508050979844909]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.03434177932816089], {
             RGBColor[
             0.6188367246795077, 0.7014385572283971, 0.9631362403218372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.03434177932816089], {
             RGBColor[
             0.2562574704790552, 0.38667322750850125`, 0.9379048558936031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.03434177932816089], {
             RGBColor[
             0.9146626577353835, 0.9347911916944939, 0.9917225348954364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.03434177932816089], {
             RGBColor[
             0.3274991935787168, 0.458085073714969, 0.9420889369120379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.03434177932816089], {
             RGBColor[
             0.2262311772849768, 0.3551136895845794, 0.9361949029161204]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.03434177932816089], {
             RGBColor[
             0.7595712694087771, 0.8121021157083784, 0.9766706236037325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.03434177932816089], {
             RGBColor[
             0.6807027709206555, 0.7504894452666685, 0.968809748742459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.03434177932816089], {
             RGBColor[
             0.4179442959916355, 0.5364240755220139, 0.9478520188603253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.03434177932816089], {
             RGBColor[
             0.8675327116732591, 0.4913788068770457, 0.21117838636085415`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.03434177932816089], {
             RGBColor[
             0.2372124705557414, 0.3666557250663601, 0.9368202713225229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.03434177932816089], {
             RGBColor[
             0.35699077137457635`, 0.483629196111943, 0.9439681141708117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.03434177932816089], {
             RGBColor[
             0.2544378422070241, 0.3847606828235006, 0.9378012307554097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.03434177932816089], {
             RGBColor[
             0.322173741643116, 0.45347243491334854`, 0.9417496038238137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.03434177932816089], {
             RGBColor[
             0.9650552642631052, 0.8937853423246256, 0.3187467297321304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.03434177932816089], {
             RGBColor[
             0.8578237913971699, 0.4454645759914146, 0.2030054339855487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.03434177932816089], {
             RGBColor[
             0.29213812634371106`, 0.4243860717872321, 0.9399482061644217]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.03434177932816089], {
             RGBColor[
             0.6440597930627512, 0.7218636724671273, 0.9651575191576801]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.03434177932816089], {
             RGBColor[
             0.4136829046946342, 0.5327330725643056, 0.9475804867750808]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.03434177932816089], {
             RGBColor[
             0.23655451757503262`, 0.36596417476700677`, 0.9367828018736257]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.03434177932816089], {
             RGBColor[
             0.35244904856935166`, 0.4796953840916829, 0.9436787196097506]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.03434177932816089], {
             RGBColor[
             0.993562122803693, 0.9916057865804992, 0.7563558160423134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.03434177932816089], {
             RGBColor[
             0.8177080186927622, 0.13711716814164848`, 0.16459052473952288`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.03434177932816089], {
             RGBColor[
             0.8317291195209172, 0.2448894931924079, 0.17801714672713256`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.03434177932816089], {
             RGBColor[
             0.4174064139952154, 0.53595818917145, 0.9478177454951437]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.03434177932816089], {
             RGBColor[
             0.2766948027559306, 0.4081541595332056, 0.9390687317324474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.03434177932816089], {
             RGBColor[
             0.5476923991281734, 0.6436803887304818, 0.9575354984041846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.03434177932816089], {
             RGBColor[
             0.24705297562595502`, 0.37699871981921224`, 0.9373806735285489]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.03434177932816089], {
             RGBColor[
             0.5489231824340144, 0.6446795940643196, 0.9576323901745283]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.03434177932816089], {
             RGBColor[
             0.8328101555207211, 0.25319880959989605`, 0.17905234802140027`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.03434177932816089], {
             RGBColor[
             0.9260824493199337, 0.7446485736567867, 0.2593824075361489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.03434177932816089], {
             RGBColor[
             0.5668393910348319, 0.659224779322463, 0.9590428197448192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.03434177932816089], {
             RGBColor[
             0.9948487335515908, 0.9913902868768101, 0.6806946209012268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.03434177932816089], {
             RGBColor[
             0.32451328924336914`, 0.4554988334556064, 0.9418986777281211]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.03434177932816089], {
             RGBColor[
             0.23365539790008147`, 0.3629170161738291, 0.9366177012970005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.03434177932816089], {
             RGBColor[
             0.28791659856684826`, 0.41994897843342893`, 0.9397077964027201]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.03434177932816089], {
             RGBColor[
             0.9464558742569554, 0.9595874592080723, 0.9755204177251058]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.03434177932816089], {
             RGBColor[
             0.9123183312358003, 0.932921889378774, 0.9914989309411012]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.03434177932816089], {
             RGBColor[
             0.8743662175245639, 0.5224081609419808, 0.2168804311477391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.03434177932816089], {
             RGBColor[
             0.9930380091079225, 0.9875173303841278, 0.48360843970387296`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.03434177932816089], {
             RGBColor[
             0.26423372362278924`, 0.39505677528622424`, 0.9383590917103296]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.03434177932816089], {
             RGBColor[
             0.6295965520330332, 0.7101738697986875, 0.963983293345653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.03434177932816089], {
             RGBColor[
             0.6518075404484566, 0.7279162716099014, 0.9659297422102715]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.03434177932816089], {
             RGBColor[
             0.3290101239879992, 0.459393765693919, 0.9421852120616541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.03434177932816089], {
             RGBColor[
             0.6382140736915616, 0.7171699620960075, 0.9646616962176343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.03434177932816089], {
             RGBColor[
             0.7305123993392341, 0.7894011055544591, 0.9737743070057807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.03434177932816089], {
             RGBColor[
             0.29429562032882867`, 0.4266537347586102, 0.9400710722551477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.03434177932816089], {
             RGBColor[
             0.2460324096232273, 0.37592604024272347`, 0.9373225538044856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.03434177932816089], {
             RGBColor[
             0.1800403201715783, 0.3065641700889047, 0.9335644019367618]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.03434177932816089], {
             RGBColor[
             0.39493077240962093`, 0.5164909180886005, 0.9463856174877392]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.03434177932816089], {
             RGBColor[
             0.26782978190622225`, 0.39883646054537636`, 0.9385638819096797]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.03434177932816089], {
             RGBColor[
             0.29584127485450173`, 0.42827831566524976`, 0.9401590949937939]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.03434177932816089], {
             RGBColor[
             0.9950766756732579, 0.9918778320265724, 0.7055047141489801]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.03434177932816089], {
             RGBColor[
             0.21628848662157388`, 0.34466329129434453`, 0.9356286813917323]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.03434177932816089], {
             RGBColor[
             0.30061798398773654`, 0.43329893982513096`, 0.9404311215124237]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.03434177932816089], {
             RGBColor[
             0.9196256639800194, 0.938748558156751, 0.9921959108615778]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.03434177932816089], {
             RGBColor[
             0.9748675947682047, 0.926884637163092, 0.35686578084130904`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.03434177932816089], {
             RGBColor[
             0.27610729667649436`, 0.4075366533936812, 0.9390352741303609]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.03434177932816089], {
             RGBColor[
             0.5042211596463271, 0.6083884781620977, 0.9541132831917766]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.03434177932816089], {
             RGBColor[
             0.27813245697413447`, 0.40966522526908, 0.9391506040133554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.03434177932816089], {
             RGBColor[
             0.4035464690461924, 0.5239534014776945, 0.9469346020588602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.03434177932816089], {
             RGBColor[
             0.2726124428491967, 0.4038633404346605, 0.9388362473750692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.03434177932816089], {
             RGBColor[
             0.261097249315751, 0.3917601419255701, 0.9381804741385418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.03434177932816089], {
             RGBColor[
             0.5312094509757161, 0.6302987888719648, 0.9562379003465947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.03434177932816089], {
             RGBColor[
             0.8619491220774967, 0.8927588492317026, 0.9866946708064583]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.03434177932816089], {
             RGBColor[
             0.48864650773140994`, 0.5957442741074949, 0.9528871895412045]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.03434177932816089], {
             RGBColor[
             0.40546591079173033`, 0.5256159254437323, 0.9470569071895901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.03434177932816089], {
             RGBColor[
             0.2574804300414378, 0.3879586355486801, 0.9379745016314742]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.03434177932816089], {
             RGBColor[
             0.4228071955400177, 0.5406360746943846, 0.948161878519455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.03434177932816089], {
             RGBColor[
             0.3674883934084197, 0.4927217086918333, 0.9446370133641255]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.03434177932816089], {
             RGBColor[
             0.8501803311271197, 0.38671359097016134`, 0.19568604779889498`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.03434177932816089], {
             RGBColor[
             0.5465902564750337, 0.6427856196737024, 0.9574487336972479]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.03434177932816089], {
             RGBColor[
             0.38532279281260967`, 0.5081689690727651, 0.9457734055238204]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.03434177932816089], {
             RGBColor[
             0.2788168781365947, 0.4103845953056338, 0.9391895807860471]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.03434177932816089], {
             RGBColor[
             0.28507184392659923`, 0.4169589609386654, 0.9395457918343952]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.03434177932816089], {
             RGBColor[
             0.28917033221241484`, 0.4212667319862237, 0.9397791946791023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.03434177932816089], {
             RGBColor[
             0.6566687686170058, 0.7317139000018745, 0.9664142640033524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.03434177932816089], {
             RGBColor[
             0.8341470216086144, 0.26347454816989946`, 0.18033253249694123`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.03434177932816089], {
             RGBColor[
             0.3439204196877902, 0.4723083144158259, 0.943135282918988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.03434177932816089], {
             RGBColor[
             0.9211686584075277, 0.939978900029778, 0.992343083047521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.03434177932816089], {
             RGBColor[
             0.9929459767177286, 0.9913509943397207, 0.7665669512217009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.03434177932816089], {
             RGBColor[
             0.24301438028138522`, 0.37275390005033504`, 0.937150681498242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.03434177932816089], {
             RGBColor[
             0.2522134290242518, 0.3824226835324653, 0.9376745537153752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.03434177932816089], {
             RGBColor[
             0.9594092884334661, 0.9692480942916449, 0.9535936663157671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.03434177932816089], {
             RGBColor[
             0.3044111891973746, 0.4372858390035616, 0.9406471389375684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.03434177932816089], {
             RGBColor[
             0.2215913444714862, 0.35023693111520926`, 0.9359306713014096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.03434177932816089], {
             RGBColor[
             0.3224078413052081, 0.4536752002744616, 0.941764520447276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.03434177932816089], {
             RGBColor[
             0.20347429876271564`, 0.33119476738824843`, 0.9348989323500625]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.03434177932816089], {
             RGBColor[
             0.17892956896395254`, 0.30539670014399584`, 0.9335011462986966]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.03434177932816089], {
             RGBColor[
             0.28222472928714576`, 0.41396646293510553`, 0.9393836528676069]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.03434177932816089], {
             RGBColor[
             0.18991457468017128`, 0.31694263764133146`, 0.9341267261233757]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.03434177932816089], {
             RGBColor[
             0.9946101233350695, 0.9908799237508646, 0.6547233713644478]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.03434177932816089], {
             RGBColor[
             0.6241927467762723, 0.7057868172525964, 0.96355788600105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.03434177932816089], {
             RGBColor[
             0.43622064479054923`, 0.5522541302556329, 0.9490165716446514]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.03434177932816089], {
             RGBColor[
             0.9476938047146304, 0.9605107057164812, 0.973424924364235]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.03434177932816089], {
             RGBColor[
             0.9926251659969516, 0.9866343007146026, 0.4386730148470409]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.03434177932816089], {
             RGBColor[
             0.22593857337368983`, 0.3548061443216573, 0.9361782395562414]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.03434177932816089], {
             RGBColor[
             0.8327720947194103, 0.2529062576026711, 0.17901590095508144`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.03434177932816089], {
             RGBColor[
             0.23926061251081787`, 0.3688084521208458, 0.93693690997691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.03434177932816089], {
             RGBColor[
             0.23590943272644063`, 0.36528614969039486`, 0.9367460652458159]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.03434177932816089], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.03434177932816089], {
             RGBColor[
             0.324831212684851, 0.4557742027613212, 0.9419189355286837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.03434177932816089], {
             RGBColor[
             0.2067120462521808, 0.3345978452847238, 0.9350833172797693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.03434177932816089], {
             RGBColor[
             0.35014705105926486`, 0.47770150955020474`, 0.9435320383639844]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.03434177932816089], {
             RGBColor[
             0.27400077350385804`, 0.40532256397795713`, 0.9389153107520011]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.03434177932816089], {
             RGBColor[
             0.9900957369634822, 0.9901723469535194, 0.8138028001335977]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.03434177932816089], {
             RGBColor[
             0.9929076697798414, 0.9872385477406899, 0.46942180820333496`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.03434177932816089], {
             RGBColor[
             0.8455662065044656, 0.351247407198139, 0.19126755684933291`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.03434177932816089], {
             RGBColor[
             0.7066839033025902, 0.7707861033473555, 0.971399305210804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.03434177932816089], {
             RGBColor[
             0.25547870703592473`, 0.385854697753317, 0.9378605064675941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.03434177932816089], {
             RGBColor[
             0.3280740134091542, 0.4585829537608091, 0.9421255639233401]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.03434177932816089], {
             RGBColor[
             0.8990024464838272, 0.6342755227085348, 0.23743750448057996`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.03434177932816089], {
             RGBColor[
             0.6590237495828186, 0.7335536290308857, 0.9666489864974762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.03434177932816089], {
             RGBColor[
             0.39675004724917656`, 0.5180666825152114, 0.9465015400717941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.03434177932816089], {
             RGBColor[
             0.3157094904678022, 0.4478734254480028, 0.9413377074550355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.03434177932816089], {
             RGBColor[
             0.26920385108875294`, 0.4002806943772341, 0.9386421331168716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.03434177932816089], {
             RGBColor[
             0.23045057360750168`, 0.3595485426447314, 0.9364351912946507]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.03434177932816089], {
             RGBColor[
             0.22619261942112945`, 0.35507316282496604`, 0.9361927071028155]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.03434177932816089], {
             RGBColor[
             0.23881348570074337`, 0.36833849349398035`, 0.9369114467665411]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.03434177932816089], {
             RGBColor[
             0.2939489691399074, 0.4262893823800991, 0.9400513309827632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.03434177932816089], {
             RGBColor[
             0.9620063021321176, 0.9711849428558795, 0.9491975995336027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.03434177932816089], {
             RGBColor[
             0.443273542823118, 0.5583629960424816, 0.9494659760706539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.03434177932816089], {
             RGBColor[
             0.25329610735962166`, 0.38356064710871024`, 0.9377362106448954]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.03434177932816089], {
             RGBColor[
             0.27348165172589245`, 0.40477693407509363`, 0.9388857475347178]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.03434177932816089], {
             RGBColor[
             0.7412000832467709, 0.797750405452433, 0.9748395554555993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.03434177932816089], {
             RGBColor[
             0.21230278460535462`, 0.3404740657671945, 0.9354017015582263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.03434177932816089], {
             RGBColor[
             0.2276990046313701, 0.35665646919126776`, 0.9362784935120415]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.03434177932816089], {
             RGBColor[
             0.34598043724619154`, 0.47409259808542004`, 0.9432665454162072]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.03434177932816089], {
             RGBColor[
             0.40363205630183896`, 0.524027532856795, 0.9469400556031081]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.03434177932816089], {
             RGBColor[
             0.2473937360801429, 0.37735688066202433`, 0.937400079332305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.03434177932816089], {
             RGBColor[
             0.5902199940802382, 0.6782062061588879, 0.9608834264625246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.03434177932816089], {
             RGBColor[
             0.21627103797903324`, 0.3446449516647265, 0.9356276877173526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.03434177932816089], {
             RGBColor[
             0.2845267439871254, 0.4163860263409461, 0.9395147491992453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.03434177932816089], {
             RGBColor[
             0.2413593551772921, 0.3710143637312809, 0.9370564302669542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.03434177932816089], {
             RGBColor[
             0.38392426951059677`, 0.5069576384803866, 0.9456842928556817]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.03434177932816089], {
             RGBColor[
             0.9802603651545728, 0.9450757179590131, 0.3778156754531135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.03434177932816089], {
             RGBColor[
             0.9927232541779302, 0.9868441014154793, 0.4493493080164732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.03434177932816089], {
             RGBColor[
             0.7539264605068086, 0.8076923480920241, 0.9761080018061227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.03434177932816089], {
             RGBColor[
             0.3858730274799788, 0.5086455546860418, 0.9458084659902717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.03434177932816089], {
             RGBColor[
             0.2930250557635406, 0.42531829084204614`, 0.9399987154827865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.03434177932816089], {
             RGBColor[
             0.8218934398484693, 0.16928814920765783`, 0.168598488764985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.03434177932816089], {
             RGBColor[
             0.4183533072547869, 0.5367783405206518, 0.9478780806963388]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.03434177932816089], {
             RGBColor[
             0.26949540103514497`, 0.4005871318562264, 0.9386587364550091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.03434177932816089], {
             RGBColor[
             0.25717362368840185`, 0.38763616261899303`, 0.9379570294635482]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.03434177932816089], {
             RGBColor[
             0.3923234880848031, 0.5142326194523638, 0.9462194836360928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.03434177932816089], {
             RGBColor[
             0.2945111830148827, 0.42688030480911665`, 0.9400833482312222]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.03434177932816089], {
             RGBColor[
             0.1789518783186532, 0.305420148690281, 0.9335024167834431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.03434177932816089], {
             RGBColor[
             0.41920763486506846`, 0.5375183161569235, 0.9479325176962138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.03434177932816089], {
             RGBColor[
             0.27705635157752495`, 0.4085341702682206, 0.9390893214029737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.03434177932816089], {
             RGBColor[
             0.9936465744084931, 0.9916407094893913, 0.7549562343970292]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.03434177932816089], {
             RGBColor[
             0.23402613491596813`, 0.3633066842836104, 0.936638814221599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.03434177932816089], {
             RGBColor[
             0.7138170777657293, 0.7763585934520937, 0.9721102733779844]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.03434177932816089], {
             RGBColor[
             0.3071831062866214, 0.4401992996140543, 0.9408049955151171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.03434177932816089], {
             RGBColor[
             0.25458949129815345`, 0.38492007563338526`, 0.9378098669468048]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.03434177932816089], {
             RGBColor[
             0.23743710807503443`, 0.3668918333419784, 0.9368330640969252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.03434177932816089], {
             RGBColor[
             0.5680702998089695, 0.6602240865171163, 0.9591397213924867]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.03434177932816089], {
             RGBColor[
             0.2299691131158081, 0.3590424971416032, 0.9364077728319058]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.03434177932816089], {
             RGBColor[
             0.3639294956023307, 0.48963917028760373`, 0.9444102435429313]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.03434177932816089], {
             RGBColor[
             0.20571498311483435`, 0.33354986870991854`, 0.9350265360091202]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.03434177932816089], {
             RGBColor[
             0.2318484494359024, 0.3610177987708272, 0.9365147982551062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.03434177932816089], {
             RGBColor[
             0.22813210557574862`, 0.35711168574399543`, 0.9363031579701084]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.03434177932816089], {
             RGBColor[
             0.24388899418338073`, 0.37367317471505657`, 0.9372004894660854]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.03434177932816089], {
             RGBColor[
             0.8649861375675162, 0.47981540863036076`, 0.20905346250477896`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.03434177932816089], {
             RGBColor[
             0.39949775357450523`, 0.5204466076304757, 0.9466766214891428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.03434177932816089], {
             RGBColor[
             0.5158331891976378, 0.6178156468678216, 0.9550274246943216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.03434177932816089], {
             RGBColor[
             0.8191437574953648, 0.1481528857232069, 0.16596538983833015`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.03434177932816089], {
             RGBColor[
             0.2809324202458739, 0.4126081641956031, 0.9393100577795065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.03434177932816089], {
             RGBColor[
             0.2105002400012672, 0.3385794771003698, 0.9352990493096494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.03434177932816089], {
             RGBColor[
             0.4642553566460736, 0.5759424388475844, 0.9509670287800365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.03434177932816089], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.03434177932816089], {
             RGBColor[
             0.8859959599380017, 0.5752161050460523, 0.226584573288584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.03434177932816089], {
             RGBColor[
             0.32111303850258816`, 0.4525537071655133, 0.9416820167576422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.03434177932816089], {
             RGBColor[
             0.22812105044609293`, 0.3571000661017916, 0.9363025283968291]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.03434177932816089], {
             RGBColor[
             0.2595939437592997, 0.3901800724706624, 0.9380948631110431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.03434177932816089], {
             RGBColor[
             0.23088271225706164`, 0.36000274776459185`, 0.9364598009514513]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.03434177932816089], {
             RGBColor[
             0.5294468131435418, 0.6288678000738763, 0.9560991390396908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.03434177932816089], {
             RGBColor[
             0.23667377020378227`, 0.366089516840876, 0.9367895931344146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.03434177932816089], {
             RGBColor[
             0.7455882739599426, 0.8011784933890475, 0.9752769292959146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.03434177932816089], {
             RGBColor[
             0.28595975701387044`, 0.41789221389032877`, 0.9395963571711656]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.03434177932816089], {
             RGBColor[
             0.2651563206276758, 0.3960264832343887, 0.938411632244898]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.03434177932816089], {
             RGBColor[
             0.37855708825470646`, 0.5023088558389079, 0.9453423008120684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.03434177932816089], {
             RGBColor[
             0.24235927283690456`, 0.3720653405899749, 0.9371133740984234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.03434177932816089], {
             RGBColor[
             0.21172080019279638`, 0.3398623632496528, 0.9353685584068999]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.03434177932816089], {
             RGBColor[
             0.42787872382047937`, 0.5450287775884974, 0.9484850318169096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.03434177932816089], {
             RGBColor[
             0.21288213693655111`, 0.34108300180034146`, 0.9354346948164131]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.03434177932816089], {
             RGBColor[
             0.9951032288756773, 0.9922430735458843, 0.7308157001748675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.03434177932816089], {
             RGBColor[
             0.2588379470720171, 0.38938547201937, 0.9380518102180992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.03434177932816089], {
             RGBColor[
             0.80703569950506, 0.8491816892426243, 0.9814014344154122]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.03434177932816089], {
             RGBColor[
             0.2560427236071457, 0.38644751493038626`, 0.9378926263769374]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.03434177932816089], {
             RGBColor[
             0.27423499655804673`, 0.4055687472585089, 0.9389286494084351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.03434177932816089], {
             RGBColor[
             0.25719173910326026`, 0.38765520306859286`, 0.937958061109625]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.03434177932816089], {
             RGBColor[
             0.29461336050310216`, 0.4269876998276622, 0.9400891670880182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.03434177932816089], {
             RGBColor[
             0.43613267935432526`, 0.5521779390160471, 0.94901096656484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.03434177932816089], {
             RGBColor[
             0.8873547734207121, 0.5813861597120881, 0.22771840056612383`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.03434177932816089], {
             RGBColor[
             0.9695247134417432, 0.9088618438807439, 0.33610969580648287`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.03434177932816089], {
             RGBColor[
             0.9609628542707439, 0.8799806824768295, 0.3028484896985869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.03434177932816089], {
             RGBColor[
             0.178927010221482, 0.30539401074342565`, 0.9335010005820983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.03434177932816089], {
             RGBColor[
             0.25976518882652405`, 0.3903600618938796, 0.9381046152642871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.03434177932816089], {
             RGBColor[
             0.8163432429187892, 0.8564528128973794, 0.9823291233589543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.03434177932816089], {
             RGBColor[
             0.34638875058307517`, 0.4744462585754037, 0.9432925627809762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.03434177932816089], {
             RGBColor[
             0.24935218422087857`, 0.37941533383072157`, 0.9375116100566555]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.03434177932816089], {
             RGBColor[
             0.44511934956958094`, 0.5599617410733233, 0.9495835892443556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.03434177932816089], {
             RGBColor[
             0.9940965401504851, 0.9897814212502639, 0.5988230111904562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.03434177932816089], {
             RGBColor[
             0.9940884990666902, 0.9897642221851048, 0.5979477888431959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.03434177932816089], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.03434177932816089], {
             RGBColor[
             0.24203916924704705`, 0.37172889142129484`, 0.937095144672532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.03434177932816089], {
             RGBColor[
             0.6232106502631707, 0.7049895070603167, 0.9634805717660004]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.03434177932816089], {
             RGBColor[
             0.638779311088947, 0.7176288472788594, 0.9647061937760893]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.03434177932816089], {
             RGBColor[
             0.2785145923880161, 0.4100668738178543, 0.9391723660598572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.03434177932816089], {
             RGBColor[
             0.4111342730563943, 0.530525575937213, 0.9474180902207585]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.03434177932816089], {
             RGBColor[
             0.9949335587465892, 0.9915717193917691, 0.6899273198963884]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.03434177932816089], {
             RGBColor[
             0.2790754121939759, 0.4106563309919474, 0.9392043039181481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.03434177932816089], {
             RGBColor[
             0.24043240470913427`, 0.3700400800171928, 0.9370036418090929]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.03434177932816089], {
             RGBColor[
             0.21816661637866602`, 0.3466373247493527, 0.9357356381029547]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.03434177932816089], {
             RGBColor[
             0.24251120685435607`, 0.3722250328754895, 0.9371220265159511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.03434177932816089], {
             RGBColor[
             0.4244026220080174, 0.5420179529125, 0.9482635376832157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.03434177932816089], {
             RGBColor[
             0.5988679170367666, 0.6852269795994871, 0.961564222636048]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.03434177932816089], {
             RGBColor[
             0.5790882470358998, 0.6691689524288044, 0.9600070945582612]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.03434177932816089], {
             RGBColor[
             0.20835094833068457`, 0.3363204352816248, 0.9351766503286018]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.03434177932816089], {
             RGBColor[
             0.8185799679311427, 0.1438193520784336, 0.16542550431492184`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.03434177932816089], {
             RGBColor[
             0.22258326386374316`, 0.3512795012877932, 0.9359871596433854]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.03434177932816089], {
             RGBColor[
             0.2867137638335649, 0.4186847228646212, 0.9396392967440941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.03434177932816089], {
             RGBColor[
             0.30053129972337833`, 0.4332078291671907, 0.9404261849718064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.03434177932816089], {
             RGBColor[
             0.29672537087035056`, 0.42920755663283183`, 0.9402094429539937]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.03434177932816089], {
             RGBColor[
             0.8913219113450659, 0.5994000064779764, 0.23102867769365362`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.03434177932816089], {
             RGBColor[
             0.9589543367125869, 0.8732054811308165, 0.29504577826186157`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.03434177932816089], {
             RGBColor[
             0.9952479751456992, 0.992244224277091, 0.7241496045864151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.03434177932816089], {
             RGBColor[
             0.39130532114623406`, 0.5133507344247334, 0.9461546069390968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.03434177932816089], {
             RGBColor[
             0.9617670348256762, 0.9710064976904998, 0.9496026166724999]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.03434177932816089], {
             RGBColor[
             0.46426084954242974`, 0.5759468982282985, 0.9509674612009588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.03434177932816089], {
             RGBColor[
             0.8491537797280463, 0.8825561905625664, 0.9854742396306309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.03434177932816089], {
             RGBColor[
             0.4006413843936947, 0.5214371631655013, 0.9467494926336685]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.03434177932816089], {
             RGBColor[
             0.9939797374120591, 0.9895315920033393, 0.5861097539357399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.03434177932816089], {
             RGBColor[
             0.26098356523640104`, 0.3916406527501864, 0.9381739999984032]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.03434177932816089], {
             RGBColor[
             0.2946613034028385, 0.4270380908550406, 0.940091897365233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.03434177932816089], {
             RGBColor[
             0.22246582468563886`, 0.3511560652655316, 0.9359804716559281]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.03434177932816089], {
             RGBColor[
             0.24763395401992835`, 0.3776093649474359, 0.9374137593886052]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.03434177932816089], {
             RGBColor[
             0.467847246129772, 0.578858496543228, 0.9512497954777179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.03434177932816089], {
             RGBColor[
             0.2625163578880115, 0.3932517150116962, 0.938261290272349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.03434177932816089], {
             RGBColor[
             0.2270252964366493, 0.35594835916304945`, 0.9362401268270142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.03434177932816089], {
             RGBColor[
             0.22825539451058077`, 0.357241270231474, 0.9363101790925575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.03434177932816089], {
             RGBColor[
             0.9774649456708626, 0.9356461116447503, 0.3669559986295733]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.03434177932816089], {
             RGBColor[
             0.22328031209840418`, 0.35201214317783264`, 0.936026855509159]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.03434177932816089], {
             RGBColor[
             0.6178350891255162, 0.7006253843624993, 0.9630573879019151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.03434177932816089], {
             RGBColor[
             0.9645754531953188, 0.8921668269279859, 0.3168827543384975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.03434177932816089], {
             RGBColor[
             0.21277857456934213`, 0.34097415118617147`, 0.9354287970928072]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.03434177932816089], {
             RGBColor[
             0.23178154572615212`, 0.3609474787299394, 0.9365109881878111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.03434177932816089], {
             RGBColor[
             0.34909505354151776`, 0.4767903221752649, 0.9434650060123984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.03434177932816089], {
             RGBColor[
             0.6029315110482949, 0.6885259882808699, 0.9618841236420709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.03434177932816089], {
             RGBColor[
             0.25879261498995565`, 0.3893378251269034, 0.9380492286230886]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.03434177932816089], {
             RGBColor[
             0.2680583595238526, 0.3990767101141639, 0.9385768990668534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.03434177932816089], {
             RGBColor[
             0.8360763947567734, 0.2783045556433535, 0.18218010240253352`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.03434177932816089], {
             RGBColor[
             0.9636570397640628, 0.9724160602789496, 0.9464033313040466]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.03434177932816089], {
             RGBColor[
             0.6187231293682252, 0.7013463354372874, 0.9631272976828197]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.03434177932816089], {
             RGBColor[
             0.25564421936180226`, 0.3860286617019018, 0.9378699321496993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.03434177932816089], {
             RGBColor[
             0.382771346863294, 0.50595903483087, 0.945610829644085]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.03434177932816089], {
             RGBColor[
             0.5590358689967736, 0.6528895285873056, 0.9584284979047402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.03434177932816089], {
             RGBColor[
             0.9409750107809423, 0.8036926171977683, 0.27136531206102255`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.03434177932816089], {
             RGBColor[
             0.8619011142240809, 0.46580703815332913`, 0.20647924340617463`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.03434177932816089], {
             RGBColor[
             0.2909832679823188, 0.4231722424271597, 0.9398824386892002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.03434177932816089], {
             RGBColor[
             0.6129287179190951, 0.6966421711876226, 0.9626711403879157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.03434177932816089], {
             RGBColor[
             0.8179080138731872, 0.1386544187368418, 0.16478204035016009`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.03434177932816089], {
             RGBColor[
             0.24306150835744214`, 0.3728034346463635, 0.9371533653724538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.03434177932816089], {
             RGBColor[
             0.20926131084396443`, 0.33727728400339907`, 0.9352284941269724]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.03434177932816089], {
             RGBColor[
             0.209897553009386, 0.33794601485934034`, 0.9352647271770572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.03434177932816089], {
             RGBColor[
             0.8372847792405768, 0.8730921717492939, 0.9843421637685542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.03434177932816089], {
             RGBColor[
             0.6962355794932261, 0.7626237933772783, 0.9703579139386239]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.03434177932816089], {
             RGBColor[
             0.7603990286995737, 0.8127487675575523, 0.9767531269139887]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.03434177932816089], {
             RGBColor[
             0.28525208052382683`, 0.41714840103001194`, 0.9395560560419711]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.03434177932816089], {
             RGBColor[
             0.9944845479757449, 0.9919872330943883, 0.7410688437815899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.03434177932816089], {
             RGBColor[
             0.2558608387541249, 0.3862563424176957, 0.9378822683036323]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{{3.8349502435193233`*^9, 3.8349502581408367`*^9}, 
   3.8349577843740606`*^9, 3.83501892289773*^9, 3.8350190217900667`*^9, 
   3.835020556050778*^9, 3.835044646730012*^9, 3.835045035421321*^9, 
   3.8350454161219234`*^9},
 CellLabel->
  "Out[301]=",ExpressionUUID->"bf46630e-b634-4e07-95a2-e8b33b19dc35"]
}, Open  ]],

Cell["Estimated with Max-Min Deviation v Calculated: (r = 6)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 3.8349503922098827`*^9}, {3.8349504781120467`*^9, 
  3.834950521977162*^9}},ExpressionUUID->"1bb26158-719f-4919-b31b-\
594eb5cd317d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphinf3", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsif3", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}],
      "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"mMDi6f300", ",", "krif3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502554527807`*^9}, {3.8349505249112787`*^9, 3.834950525026289*^9}, {
   3.834957796266032*^9, 3.834957804349044*^9}, {3.835018837121126*^9, 
   3.835018838508815*^9}, {3.8350443533371973`*^9, 3.835044357496614*^9}, {
   3.8350449455086536`*^9, 3.835044948398612*^9}, {3.8350452870303855`*^9, 
   3.835045288563345*^9}},
 CellLabel->
  "In[302]:=",ExpressionUUID->"4f878fbd-a4c0-4fdc-8f89-b35fb84bf10d"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1FO4EAYYBuBzsm2dTrZdW7WsZbtVy3bLtWxr2bat5WVjyzZXrfc8u3i/
//a7+f7gJu2rtAsMCAjIJEJuKEIThrCEIzwRiEgkIhOFqEQjOjGISSxiE4e4
xCM+CUhIIhKThKQkI4jkBJOClKQiNWlISzrSk4GMIX3JTBayko3s5CAnuchN
HvKSj/wUoCCF+IEfKUwRivITxShOCUpSitKUoSzlKE8FfqYilahMFapSjerU
oCa1qE0d6lKP+jSgIY1oTBN+oSnNaM6vtKAlrWhNG9rSjvZ0oCOd6EwXutKN
7vSgJ73ozW/0oS/96M8ABjKIwQzhd4YyjOGMYCSjGM0YxjKO8UxgIpOYzBSm
Mo3pzGAms5jNH8xhLvOYzwIWsojFLGEpy1jOClayitWsYS3rWM8GNrKJzWxh
K9vYzg52sovd7GEv+9jPAQ5yiMMc4U+OcozjnOAkpzjNX5zhLOc4zwUuconL
XOEq17jODW5yi9v8zT/c4S73uM8DHvKIxzzhKc94zgte8orXvOEt73jPBz7y
ic/8yxe+8o3/CBl/IKEITRjCEo7wRCAikYhMFKISjejEICaxiE0c4hKP+CQg
IYlITBKSkowgkhNMClKSitSkIS3pSE8GMgb+/6++Az6VhWw=
          "], {Null, CompressedData["
1:eJxN2nu4llWZB+C1RcxDZpqQRxAUUVHStBgOUSMyo5BNY0aKowyCpqCIyVg4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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[57, 280] -> 
             RGBColor[0.9713409, 0.9551671999999999, 0.6565364999999999], 
             UndirectedEdge[46, 187] -> 
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998], 
             UndirectedEdge[96, 298] -> 
             RGBColor[
              0.8310380000000002, 0.8680092000000001, 0.9400858999999999], 
             UndirectedEdge[165, 207] -> 
             RGBColor[0.9536411, 0.9621198, 0.8294395999999999], 
             UndirectedEdge[69, 224] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999], 
             UndirectedEdge[51, 110] -> 
             RGBColor[0.9905655, 0.9879692, 0.6317514999999998], 
             UndirectedEdge[122, 231] -> 
             RGBColor[0.5432972, 0.6353392, 0.9591734000000001], 
             UndirectedEdge[71, 246] -> 
             RGBColor[0.9616423, 0.9479339999999998, 0.6729536999999998], 
             UndirectedEdge[9, 239] -> 
             RGBColor[0.7943714000000002, 0.8387858000000001, 0.9368273], 
             UndirectedEdge[99, 229] -> 
             RGBColor[0.7229105, 0.776718, 0.6877409999999999], 
             UndirectedEdge[49, 112] -> 
             RGBColor[0.9058337999999999, 0.9275012, 0.9822093], 
             UndirectedEdge[115, 243] -> 
             RGBColor[0.9528099999999999, 0.9622556, 0.8780663], 
             UndirectedEdge[58, 95] -> 
             RGBColor[0.866563, 0.8957615999999999, 0.9436267], 
             UndirectedEdge[210, 239] -> 
             RGBColor[0.9737315, 0.9377487999999998, 0.6117290999999998], 
             UndirectedEdge[94, 150] -> 
             RGBColor[0.7587812, 0.8090086000000001, 0.8970928999999999], 
             UndirectedEdge[21, 108] -> 
             RGBColor[0.9155324, 0.9347344, 0.9657921], 
             UndirectedEdge[83, 202] -> 
             RGBColor[0.948374, 0.9604212000000001, 0.9515823], 
             UndirectedEdge[172, 174] -> 
             RGBColor[0.9789294, 0.9823322000000001, 0.8545442000000001], 
             UndirectedEdge[3, 157] -> 
             RGBColor[0.870999, 0.8975960000000001, 0.8701107], 
             UndirectedEdge[181, 246] -> 
             RGBColor[0.9616423, 0.9479339999999998, 0.6729536999999998], 
             UndirectedEdge[159, 253] -> 
             RGBColor[0.9155324, 0.9347344, 0.9657921], 
             UndirectedEdge[170, 228] -> 
             RGBColor[0.9155324, 0.9347344, 0.9657921], 
             UndirectedEdge[151, 194] -> 
             RGBColor[0.9372631, 0.7821688, 0.5323149999999999], 
             UndirectedEdge[62, 100] -> 
             RGBColor[0.9927835, 0.9888863999999999, 0.5949935], 
             UndirectedEdge[76, 99] -> 
             RGBColor[0.659794, 0.7316336, 0.9686064], 
             UndirectedEdge[131, 283] -> 
             RGBColor[0.9253465, 0.7740184, 0.5854902], 
             UndirectedEdge[173, 263] -> 
             RGBColor[0.9299423, 0.9424774, 0.7667367999999997], 
             UndirectedEdge[20, 75] -> 
             RGBColor[
              0.7585534000000002, 0.8114760000000001, 0.9767665999999999], 
             UndirectedEdge[175, 253] -> 
             RGBColor[
              0.9792046999999999, 0.9810076000000001, 0.7454220999999996], 
             UndirectedEdge[52, 193] -> 
             RGBColor[0.7534107, 0.7827607999999999, 0.6623271999999998], 
             UndirectedEdge[282, 283] -> 
             RGBColor[
              0.9792046999999999, 0.9810076000000001, 0.7454220999999996], 
             UndirectedEdge[173, 279] -> 
             RGBColor[0.8357493000000001, 0.868519, 0.7574477999999996], 
             UndirectedEdge[95, 198] -> 
             RGBColor[0.6389342, 0.7161219999999999, 0.9658346], 
             UndirectedEdge[18, 288] -> 
             RGBColor[
              0.7585534000000002, 0.8114760000000001, 0.9767665999999999], 
             UndirectedEdge[29, 91] -> 
             RGBColor[0.9927835, 0.9888863999999999, 0.5949935], 
             UndirectedEdge[46, 169] -> 
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998], 
             UndirectedEdge[34, 264] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999], 
             UndirectedEdge[116, 277] -> 
             RGBColor[
              0.9689502999999999, 0.9725855999999999, 0.7013438999999999], 
             UndirectedEdge[60, 299] -> 
             RGBColor[0.9525295, 0.9597422, 0.7084487999999999], 
             UndirectedEdge[205, 213] -> 
             RGBColor[0.9304981, 0.9436662, 0.8272321999999999], 
             UndirectedEdge[240, 299] -> 
             RGBColor[0.9905655, 0.9879692, 0.6317514999999998], 
             UndirectedEdge[184, 214] -> 
             RGBColor[0.9253465, 0.7740184, 0.5854902], 
             UndirectedEdge[39, 59] -> 
             RGBColor[
              0.8472748999999999, 0.8129419999999998, 0.6253548999999999], 
             UndirectedEdge[246, 299] -> 
             RGBColor[0.985195, 0.9617213999999998, 0.3969857999999997], 
             UndirectedEdge[21, 114] -> 
             RGBColor[0.9155324, 0.9347344, 0.9657921], 
             UndirectedEdge[204, 253] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[202, 214] -> 
             RGBColor[0.8992271000000001, 0.7539418, 0.6090123000000001], 
             UndirectedEdge[26, 39] -> 
             RGBColor[0.6994669, 0.6945773999999998, 0.6126027], 
             UndirectedEdge[118, 220] -> 
             RGBColor[0.988628, 0.9895654, 0.8381270000000001], 
             UndirectedEdge[28, 126] -> 
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998], 
             UndirectedEdge[9, 237] -> 
             RGBColor[
              0.7996385000000001, 0.8404844000000001, 0.8146845999999999], 
             UndirectedEdge[174, 297] -> 
             RGBColor[
              0.9792046999999999, 0.9810076000000001, 0.7454220999999996], 
             UndirectedEdge[84, 90] -> 
             RGBColor[0.5324126, 0.44008309999999995`, 0.580002], 
             UndirectedEdge[63, 139] -> 
             RGBColor[0.7618303, 0.80979, 0.8117081999999999], 
             UndirectedEdge[124, 150] -> 
             RGBColor[
              0.6920586000000002, 0.7532700000000001, 0.8922740999999998], 
             UndirectedEdge[127, 165] -> 
             RGBColor[0.8363051000000001, 0.8697078, 0.8179431999999999], 
             UndirectedEdge[8, 22] -> 
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996], 
             UndirectedEdge[127, 137] -> 
             RGBColor[
              0.5077722000000002, 0.6075868000000001, 0.9556325999999999], 
             UndirectedEdge[21, 213] -> 
             RGBColor[0.9304981, 0.9436662, 0.8272321999999999], 
             UndirectedEdge[41, 278] -> 
             RGBColor[0.950592, 0.9613384, 0.9148242999999998], 
             UndirectedEdge[69, 249] -> 
             RGBColor[0.988628, 0.9895654, 0.8381270000000001], 
             UndirectedEdge[100, 136] -> 
             RGBColor[0.835474, 0.8698436, 0.8665699], 
             UndirectedEdge[88, 222] -> 
             RGBColor[0.9304981, 0.9436662, 0.8272321999999999], 
             UndirectedEdge[153, 216] -> 
             RGBColor[0.835474, 0.8698436, 0.8665699], 
             UndirectedEdge[60, 121] -> 
             RGBColor[0.948374, 0.9604212000000001, 0.9515823], 
             UndirectedEdge[203, 206] -> 
             RGBColor[0.8568644, 0.8885284, 0.9600439000000001], 
             UndirectedEdge[50, 108] -> 
             RGBColor[0.8910568999999999, 0.5536958000000001, 0.5543477], 
             UndirectedEdge[98, 181] -> 
             RGBColor[0.8116408000000002, 0.8535428, 0.9729203], 
             UndirectedEdge[267, 285] -> 
             RGBColor[0.8826908, 0.9090476000000001, 0.9800019], 
             UndirectedEdge[156, 178] -> 
             RGBColor[
              0.9857507999999999, 0.9629101999999998, 0.4574811999999995], 
             UndirectedEdge[185, 295] -> 
             RGBColor[0.9737315, 0.9377487999999998, 0.6117290999999998], 
             UndirectedEdge[83, 156] -> 
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996], 
             UndirectedEdge[44, 150] -> 
             RGBColor[0.950592, 0.9613384, 0.9148242999999998], 
             UndirectedEdge[223, 274] -> 
             RGBColor[0.7587812, 0.8090086000000001, 0.8970928999999999], 
             UndirectedEdge[20, 142] -> 
             RGBColor[
              0.7191521000000001, 0.47514479999999987`, 0.5709835999999999], 
             UndirectedEdge[87, 264] -> 
             RGBColor[
              0.9689502999999999, 0.9725855999999999, 0.7013438999999999], 
             UndirectedEdge[16, 192] -> 
             RGBColor[0.9065240000000001, 0.9253484000000001, 0.8736515], 
             UndirectedEdge[75, 143] -> 
             RGBColor[0.950592, 0.9613384, 0.9148242999999998], 
             UndirectedEdge[230, 263] -> 
             RGBColor[0.927449, 0.9428848000000001, 0.9126168999999998], 
             UndirectedEdge[52, 82] -> 
             RGBColor[0.9863066, 0.9640989999999998, 0.5179765999999997], 
             UndirectedEdge[34, 213] -> 
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998], 
             UndirectedEdge[145, 219] -> 
             RGBColor[0.585715, 0.6458835, 0.6794385], 
             UndirectedEdge[237, 295] -> 
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998], 
             UndirectedEdge[257, 259] -> 
             RGBColor[0.988628, 0.9895654, 0.8381270000000001], 
             UndirectedEdge[116, 241] -> 
             RGBColor[0.7985269000000002, 0.8381068, 0.6936937999999999], 
             UndirectedEdge[95, 105] -> 
             RGBColor[0.6767424000000002, 0.7468164000000002, 0.968811], 
             UndirectedEdge[115, 146] -> 
             RGBColor[0.9927835, 0.9888863999999999, 0.5949935], 
             UndirectedEdge[16, 170] -> 
             RGBColor[0.9789294, 0.9823322000000001, 0.8545442000000001], 
             UndirectedEdge[199, 226] -> 
             RGBColor[0.5722116000000002, 0.6603834000000001, 0.9610158], 
             UndirectedEdge[78, 130] -> 
             RGBColor[0.8350858999999999, 0.6230339999999995, 0.5891926], 
             UndirectedEdge[155, 214] -> 
             RGBColor[0.8760840999999999, 0.7354882, 0.6068049], 
             UndirectedEdge[185, 297] -> 
             RGBColor[0.9784428, 0.9382585999999997, 0.4290909999999994], 
             UndirectedEdge[45, 53] -> 
             RGBColor[0.9299423, 0.9424774, 0.7667367999999997], 
             UndirectedEdge[49, 204] -> 
             RGBColor[0.9155324, 0.9347344, 0.9657921], 
             UndirectedEdge[69, 254] -> 
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996], 
             UndirectedEdge[102, 295] -> 
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996], 
             UndirectedEdge[14, 254] -> 
             RGBColor[0.9530853, 0.960931, 0.7689441999999996], 
             UndirectedEdge[125, 299] -> 
             RGBColor[0.7229105, 0.776718, 0.6877409999999999], 
             UndirectedEdge[16, 44] -> 
             RGBColor[0.9528099999999999, 0.9622556, 0.8780663], 
             UndirectedEdge[49, 84] -> 
             RGBColor[0.8760840999999999, 0.7354882, 0.6068049], 
             UndirectedEdge[186, 230] -> 
             RGBColor[0.950592, 0.9613384, 0.9148242999999998], 
             UndirectedEdge[215, 282] -> 
             RGBColor[0.9530853, 0.960931, 0.7689441999999996], 
             UndirectedEdge[134, 159] -> 
             RGBColor[0.9155324, 0.9347344, 0.9657921], 
             UndirectedEdge[26, 266] -> 
             RGBColor[0.7090563999999999, 0.7701638, 0.9472917000000001], 
             UndirectedEdge[142, 150] -> 
             RGBColor[
              0.9111906999999999, 0.6250071999999998, 0.5090412999999998], 
             UndirectedEdge[114, 221] -> 
             RGBColor[0.9744934, 0.9804978, 0.9280602], 
             UndirectedEdge[147, 172] -> 
             RGBColor[0.9589927, 0.8657226, 0.5115296], 
             UndirectedEdge[35, 211] -> 
             RGBColor[0.9536411, 0.9621198, 0.8294395999999999], 
             UndirectedEdge[124, 295] -> 
             RGBColor[0.6898406000000001, 0.7523528000000002, 0.9290321], 
             UndirectedEdge[166, 233] -> 
             RGBColor[0.9908459999999999, 0.9904826, 0.8013689999999999], 
             UndirectedEdge[88, 290] -> 
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999], 
             UndirectedEdge[134, 235] -> 
             RGBColor[0.7468646, 0.8008582, 0.9502681], 
             UndirectedEdge[185, 239] -> 
             RGBColor[0.9737315, 0.9377487999999998, 0.6117290999999998], 
             UndirectedEdge[260, 278] -> 
             RGBColor[
              0.9452214999999999, 0.9350905999999999, 0.6800585999999997], 
             UndirectedEdge[15, 242] -> 
             RGBColor[0.8307450000000001, 0.8684518, 0.9835659999999999], 
             UndirectedEdge[4, 266] -> 
             RGBColor[0.9550962, 0.9660314000000001, 0.9608946], 
             UndirectedEdge[15, 112] -> 
             RGBColor[0.8471658, 0.8812952000000001, 0.9764611], 
             UndirectedEdge[3, 123] -> 
             RGBColor[0.7609992, 0.8099258, 0.8603349], 
             UndirectedEdge[28, 184] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[116, 210] -> 
             RGBColor[0.977887, 0.9370697999999997, 0.3685955999999997], 
             UndirectedEdge[118, 120] -> 
             RGBColor[0.866563, 0.8957615999999999, 0.9436267], 
             UndirectedEdge[15, 89] -> 
             RGBColor[0.8568644, 0.8885284, 0.9600439000000001], 
             UndirectedEdge[11, 283] -> 
             RGBColor[0.9550962, 0.9660314000000001, 0.9608946], 
             UndirectedEdge[157, 201] -> 
             RGBColor[0.8707185, 0.8950826, 0.7004931999999999], 
             UndirectedEdge[196, 279] -> 
             RGBColor[
              0.8332560000000001, 0.8689264000000001, 0.9033278999999999], 
             UndirectedEdge[7, 11] -> 
             RGBColor[0.9351594999999999, 0.8494218, 0.61788], 
             UndirectedEdge[76, 284] -> 
             RGBColor[0.8076019999999999, 0.8499981999999999, 0.9813586], 
             UndirectedEdge[34, 108] -> 
             RGBColor[0.9744934, 0.9804978, 0.9280602], 
             UndirectedEdge[46, 213] -> 
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998], 
             UndirectedEdge[261, 278] -> 
             RGBColor[0.9289768, 0.9459548, 0.9844166999999999], 
             UndirectedEdge[58, 66] -> 
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998], 
             UndirectedEdge[194, 297] -> 
             RGBColor[0.9911213, 0.989158, 0.6922468999999996], 
             UndirectedEdge[283, 297] -> 
             RGBColor[
              0.9792046999999999, 0.9810076000000001, 0.7454220999999996], 
             UndirectedEdge[163, 189] -> 
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998], 
             UndirectedEdge[6, 169] -> 
             RGBColor[
              0.9701709999999999, 0.9066099999999998, 0.47122849999999983`], 
             UndirectedEdge[11, 172] -> 
             RGBColor[0.9692308, 0.975099, 0.8709614], UndirectedEdge[4, 82] -> 
             RGBColor[0.9700618999999999, 0.9749632, 0.8223346999999999], 
             UndirectedEdge[140, 230] -> 
             RGBColor[
              0.8332560000000001, 0.8689264000000001, 0.9033278999999999], 
             UndirectedEdge[207, 232] -> 
             RGBColor[0.682937, 0.7500872000000001, 0.9708138], 
             UndirectedEdge[147, 244] -> 
             RGBColor[0.9598238, 0.8655868, 0.4629028999999999], 
             UndirectedEdge[56, 296] -> 
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999], 
             UndirectedEdge[243, 294] -> 
             RGBColor[0.9289768, 0.9459548, 0.9844166999999999], 
             UndirectedEdge[211, 216] -> 
             RGBColor[0.9528099999999999, 0.9622556, 0.8780663], 
             UndirectedEdge[107, 141] -> 
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998], 
             UndirectedEdge[19, 175] -> 
             RGBColor[0.9530853, 0.960931, 0.7689441999999996], 
             UndirectedEdge[17, 158] -> 
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999], 
             UndirectedEdge[115, 242] -> 
             RGBColor[0.9528099999999999, 0.9622556, 0.8780663], 
             UndirectedEdge[159, 292] -> 
             RGBColor[0.659794, 0.7316336, 0.9686064], 
             UndirectedEdge[34, 205] -> 
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749], 
             UndirectedEdge[23, 180] -> 
             RGBColor[0.9767113999999999, 0.981415, 0.8913021999999999], 
             UndirectedEdge[47, 158] -> 
             RGBColor[0.8431270000000001, 0.8777506, 0.9848994], 
             UndirectedEdge[130, 199] -> 
             RGBColor[
              0.6077366000000002, 0.6881358000000002, 0.9645566000000001], 
             UndirectedEdge[112, 204] -> 
             RGBColor[0.9550962, 0.9660314000000001, 0.9608946], 
             UndirectedEdge[217, 247] -> 
             RGBColor[0.9696152, 0.9054211999999998, 0.4107330999999996], 
             UndirectedEdge[102, 185] -> 
             RGBColor[0.9784428, 0.9382585999999997, 0.4290909999999994], 
             UndirectedEdge[136, 137] -> 
             RGBColor[
              0.5077722000000002, 0.6075868000000001, 0.9556325999999999], 
             UndirectedEdge[138, 258] -> 
             RGBColor[0.9692308, 0.975099, 0.8709614], 
             UndirectedEdge[79, 277] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[41, 259] -> 
             RGBColor[0.9908459999999999, 0.9904826, 0.8013689999999999], 
             UndirectedEdge[225, 287] -> 
             RGBColor[
              0.9067993000000001, 0.9240238000000001, 0.7645293999999996], 
             UndirectedEdge[167, 194] -> 
             RGBColor[0.9767113999999999, 0.981415, 0.8913021999999999], 
             UndirectedEdge[64, 219] -> 
             RGBColor[0.9927835, 0.9888863999999999, 0.5949935], 
             UndirectedEdge[83, 293] -> 
             RGBColor[0.988628, 0.9895654, 0.8381270000000001], 
             UndirectedEdge[31, 95] -> 
             RGBColor[0.8307450000000001, 0.8684518, 0.9835659999999999], 
             UndirectedEdge[256, 299] -> 
             RGBColor[
              0.9062435000000001, 0.9228350000000001, 0.7040339999999999], 
             UndirectedEdge[129, 269] -> 
             RGBColor[0.9530853, 0.960931, 0.7689441999999996], 
             UndirectedEdge[83, 126] -> 
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998], 
             UndirectedEdge[23, 81] -> 
             RGBColor[0.9908459999999999, 0.9904826, 0.8013689999999999], 
             UndirectedEdge[235, 252] -> 
             RGBColor[0.7565632, 0.8080914, 0.9338508999999999], 
             UndirectedEdge[6, 264] -> 
             RGBColor[
              0.9690593999999999, 0.9042323999999997, 0.3502376999999999], 
             UndirectedEdge[167, 215] -> 
             RGBColor[0.9386753999999999, 0.953188, 0.9679995], 
             UndirectedEdge[273, 285] -> 
             RGBColor[0.9550962, 0.9660314000000001, 0.9608946], 
             UndirectedEdge[267, 273] -> 
             RGBColor[0.8923894000000001, 0.9162808, 0.9635847], 
             UndirectedEdge[66, 109] -> 
             RGBColor[0.9941704, 0.9899394, 0.6068621999999995], 
             UndirectedEdge[104, 173] -> 
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996], 
             UndirectedEdge[9, 185] -> 
             RGBColor[
              0.7839109000000001, 0.7888035999999998, 0.6369133999999997], 
             UndirectedEdge[233, 288] -> 
             RGBColor[0.7988074000000001, 0.8406202000000002, 0.8633113], 
             UndirectedEdge[139, 147] -> 
             RGBColor[0.7269279, 0.6842486, 0.6072535], 
             UndirectedEdge[65, 103] -> 
             RGBColor[0.7647361000000001, 0.7149430000000001, 0.6102299], 
             UndirectedEdge[33, 124] -> 
             RGBColor[0.6308796000000001, 0.7065894000000001, 0.966764], 
             UndirectedEdge[82, 226] -> 
             RGBColor[0.8718300999999999, 0.8974602, 0.8214839999999999], 
             UndirectedEdge[6, 221] -> 
             RGBColor[0.9649038999999999, 0.9049113999999998, 0.5933712], 
             UndirectedEdge[125, 136] -> 
             RGBColor[0.5656010000000001, 0.6576752000000001, 0.9593174], 
             UndirectedEdge[112, 292] -> 
             RGBColor[0.6993578, 0.7629306, 0.9637089], 
             UndirectedEdge[58, 67] -> 
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999], 
             UndirectedEdge[73, 105] -> 
             RGBColor[
              0.7965894000000001, 0.8397030000000001, 0.9000692999999999], 
             UndirectedEdge[263, 298] -> 
             RGBColor[0.7720770000000001, 0.8222458000000001, 0.9778178], 
             UndirectedEdge[60, 170] -> 
             RGBColor[0.9386753999999999, 0.953188, 0.9679995], 
             UndirectedEdge[10, 129] -> 
             RGBColor[
              0.9792046999999999, 0.9810076000000001, 0.7454220999999996], 
             UndirectedEdge[53, 234] -> 
             RGBColor[0.9941704, 0.9899394, 0.6068621999999995], 
             UndirectedEdge[51, 154] -> 
             RGBColor[0.8707185, 0.8950826, 0.7004931999999999], 
             UndirectedEdge[17, 84] -> 
             RGBColor[0.8992271000000001, 0.7539418, 0.6090123000000001], 
             UndirectedEdge[98, 160] -> 
             RGBColor[0.7952200000000001, 0.8406994000000001, 0.9800252], 
             UndirectedEdge[25, 147] -> 
             RGBColor[0.9187387, 0.8365784, 0.6249849000000001], 
             UndirectedEdge[159, 204] -> 
             RGBColor[0.9155324, 0.9347344, 0.9657921], 
             UndirectedEdge[37, 94] -> 
             RGBColor[0.7612745000000001, 0.8086012, 0.7512127999999996], 
             UndirectedEdge[37, 283] -> 
             RGBColor[
              0.9792046999999999, 0.9810076000000001, 0.7454220999999996], 
             UndirectedEdge[9, 142] -> 
             RGBColor[
              0.7191521000000001, 0.47514479999999987`, 0.5709835999999999], 
             UndirectedEdge[51, 109] -> 
             RGBColor[0.9930588, 0.9875617999999999, 0.4858713999999995], 
             UndirectedEdge[123, 257] -> 
             RGBColor[0.7565632, 0.8080914, 0.9338508999999999], 
             UndirectedEdge[212, 294] -> 
             RGBColor[0.6704434000000001, 0.7378864, 0.9618665], 
             UndirectedEdge[237, 297] -> 
             RGBColor[0.9941704, 0.9899394, 0.6068621999999995], 
             UndirectedEdge[163, 197] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[76, 229] -> 
             RGBColor[0.9293865, 0.9412886, 0.7062413999999999], 
             UndirectedEdge[18, 24] -> 
             RGBColor[0.950592, 0.9613384, 0.9148242999999998], 
             UndirectedEdge[44, 124] -> 
             RGBColor[0.6540226000000001, 0.7250430000000001, 0.9689714], 
             UndirectedEdge[26, 82] -> 
             RGBColor[0.7240221, 0.7790956, 0.8087317999999999], 
             UndirectedEdge[7, 106] -> 
             RGBColor[0.959268, 0.864398, 0.40240749999999964`], 
             UndirectedEdge[53, 255] -> 
             RGBColor[
              0.7990827000000001, 0.8392956000000001, 0.7541891999999997], 
             UndirectedEdge[89, 242] -> 
             RGBColor[0.9386753999999999, 0.953188, 0.9679995], 
             UndirectedEdge[121, 181] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[217, 273] -> 
             RGBColor[
              0.9792046999999999, 0.9810076000000001, 0.7454220999999996], 
             UndirectedEdge[141, 240] -> 
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998], 
             UndirectedEdge[42, 159] -> 
             RGBColor[0.9304981, 0.9436662, 0.8272321999999999], 
             UndirectedEdge[51, 52] -> 
             RGBColor[0.985195, 0.9617213999999998, 0.3969857999999997], 
             UndirectedEdge[170, 225] -> 
             RGBColor[0.8923894000000001, 0.9162808, 0.9635847], 
             UndirectedEdge[51, 179] -> 
             RGBColor[0.9392005999999999, 0.7805726, 0.3259394999999999], 
             UndirectedEdge[36, 198] -> 
             RGBColor[0.7468646, 0.8008582, 0.9502681], 
             UndirectedEdge[150, 295] -> 
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999], 
             UndirectedEdge[140, 196] -> 
             RGBColor[
              0.8332560000000001, 0.8689264000000001, 0.9033278999999999], 
             UndirectedEdge[31, 73] -> 
             RGBColor[0.950592, 0.9613384, 0.9148242999999998], 
             UndirectedEdge[188, 212] -> 
             RGBColor[0.6951077000000001, 0.7540514, 0.8068894], 
             UndirectedEdge[172, 244] -> 
             RGBColor[0.9938951, 0.991264, 0.7159842999999999], 
             UndirectedEdge[7, 63] -> 
             RGBColor[0.9598238, 0.8655868, 0.4629028999999999], 
             UndirectedEdge[128, 218] -> 
             RGBColor[0.9616423, 0.9479339999999998, 0.6729536999999999], 
             UndirectedEdge[138, 154] -> 
             RGBColor[0.870999, 0.8975960000000001, 0.8701107], 
             UndirectedEdge[1, 297] -> 
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996], 
             UndirectedEdge[90, 123] -> 
             RGBColor[0.35393070000000004`, 0.46692290000000003`, 0.9447799], 
             UndirectedEdge[8, 61] -> 
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749], 
             UndirectedEdge[201, 209] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999], 
             UndirectedEdge[44, 94] -> 
             RGBColor[0.7207452000000001, 0.7807816000000001, 0.9737902], 
             UndirectedEdge[114, 213] -> 
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998], 
             UndirectedEdge[82, 107] -> 
             RGBColor[0.9916771, 0.9903468, 0.7527422999999998], 
             UndirectedEdge[89, 280] -> 
             RGBColor[0.9713409, 0.9551671999999999, 0.6565364999999999], 
             UndirectedEdge[182, 268] -> 
             RGBColor[0.9394811, 0.783086, 0.495557], 
             UndirectedEdge[157, 229] -> 
             RGBColor[0.8707185, 0.8950826, 0.7004931999999999], 
             UndirectedEdge[99, 157] -> 
             RGBColor[0.601126, 0.6854275999999999, 0.9628582], 
             UndirectedEdge[249, 288] -> 
             RGBColor[0.7988074000000001, 0.8406202000000002, 0.8633113], 
             UndirectedEdge[66, 138] -> 
             RGBColor[0.9938951, 0.991264, 0.7159842999999999], 
             UndirectedEdge[215, 286] -> 
             RGBColor[0.682937, 0.7500872000000001, 0.9708138], 
             UndirectedEdge[83, 275] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[95, 289] -> 
             RGBColor[0.748934, 0.8037922, 0.9756104], UndirectedEdge[37, 75] -> 
             RGBColor[0.9530853, 0.960931, 0.7689441999999996], 
             UndirectedEdge[88, 260] -> 
             RGBColor[0.9220785, 0.9166369999999999, 0.6778511999999998], 
             UndirectedEdge[60, 82] -> 
             RGBColor[0.9536411, 0.9621198, 0.8294395999999999], 
             UndirectedEdge[50, 227] -> 
             RGBColor[0.8417945, 0.5151656, 0.5756624], 
             UndirectedEdge[12, 248] -> 
             RGBColor[0.8431270000000001, 0.8777506, 0.9848994], 
             UndirectedEdge[103, 164] -> 
             RGBColor[
              0.7750833000000001, 0.7559661999999999, 0.6185554999999999], 
             UndirectedEdge[127, 228] -> 
             RGBColor[0.7720770000000001, 0.8222458000000001, 0.9778178], 
             UndirectedEdge[163, 184] -> 
             RGBColor[0.9550962, 0.9660314000000001, 0.9608946], 
             UndirectedEdge[11, 183] -> 
             RGBColor[0.8116408000000002, 0.8535428, 0.9729203], 
             UndirectedEdge[226, 266] -> 
             RGBColor[0.8568644, 0.8885284, 0.9600439000000001], 
             UndirectedEdge[98, 178] -> 
             RGBColor[0.8278855, 0.8426785999999999, 0.6685621999999998], 
             UndirectedEdge[200, 255] -> 
             RGBColor[0.5289344000000001, 0.6284518000000001, 0.9560588], 
             UndirectedEdge[223, 234] -> 
             RGBColor[0.7618303, 0.80979, 0.8117081999999999], 
             UndirectedEdge[111, 190] -> 
             RGBColor[0.9253465, 0.7740184, 0.5854902], 
             UndirectedEdge[85, 181] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[57, 134] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[9, 131] -> 
             RGBColor[0.7452245000000002, 0.6323064, 0.5942573], 
             UndirectedEdge[184, 189] -> 
             RGBColor[0.9767113999999999, 0.981415, 0.8913021999999999], 
             UndirectedEdge[194, 286] -> 
             RGBColor[0.720973, 0.7783142000000001, 0.8941164999999999], 
             UndirectedEdge[171, 298] -> 
             RGBColor[
              0.8332560000000001, 0.8689264000000001, 0.9033278999999999], 
             UndirectedEdge[108, 213] -> 
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998], 
             UndirectedEdge[158, 175] -> 
             RGBColor[0.9299423, 0.9424774, 0.7667367999999997], 
             UndirectedEdge[37, 297] -> 
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993], 
             UndirectedEdge[68, 234] -> 
             RGBColor[0.9304981, 0.9436662, 0.8272321999999999], 
             UndirectedEdge[38, 252] -> 
             RGBColor[0.9810395, 0.9624003999999999, 0.6401192999999998], 
             UndirectedEdge[42, 252] -> 
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998], 
             UndirectedEdge[40, 65] -> 
             RGBColor[0.8369276999999999, 0.7719187999999999, 0.6170293], 
             UndirectedEdge[184, 216] -> 
             RGBColor[0.9789294, 0.9823322000000001, 0.8545442000000001], 
             UndirectedEdge[16, 59] -> 
             RGBColor[0.870999, 0.8975960000000001, 0.8701107], 
             UndirectedEdge[7, 185] -> 
             RGBColor[
              0.9440961999999999, 0.8139059999999998, 0.28513169999999977`], 
             UndirectedEdge[127, 299] -> 
             RGBColor[0.8351935000000001, 0.8673302, 0.6969523999999999], 
             UndirectedEdge[166, 217] -> 
             RGBColor[0.9911213, 0.989158, 0.6922468999999996], 
             UndirectedEdge[101, 207] -> 
             RGBColor[0.8307450000000001, 0.8684518, 0.9835659999999999], 
             UndirectedEdge[14, 69] -> 
             RGBColor[0.948374, 0.9604212000000001, 0.9515823], 
             UndirectedEdge[51, 107] -> 
             RGBColor[0.9905655, 0.9879692, 0.6317514999999998], 
             UndirectedEdge[74, 233] -> 
             RGBColor[0.9692308, 0.975099, 0.8709614], 
             UndirectedEdge[158, 252] -> 
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749], 
             UndirectedEdge[86, 110] -> 
             RGBColor[0.988628, 0.9895654, 0.8381269999999997], 
             UndirectedEdge[58, 73] -> 
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999], 
             UndirectedEdge[13, 96] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999], 
             UndirectedEdge[16, 53] -> 
             RGBColor[0.9933392999999999, 0.9900752, 0.6554888999999997], 
             UndirectedEdge[44, 170] -> 
             RGBColor[0.9386753999999999, 0.953188, 0.9679995], 
             UndirectedEdge[27, 32] -> 
             RGBColor[0.7720770000000001, 0.8222458000000001, 0.9778178], 
             UndirectedEdge[116, 164] -> 
             RGBColor[
              0.9690593999999999, 0.9042323999999997, 0.3502376999999999], 
             UndirectedEdge[70, 300] -> 
             RGBColor[0.6696081, 0.5709176, 0.5883045], 
             UndirectedEdge[79, 116] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999], 
             UndirectedEdge[137, 195] -> 
             RGBColor[0.6609262, 0.7273086, 0.9271897], 
             UndirectedEdge[156, 214] -> 
             RGBColor[0.9397564, 0.7817613999999999, 0.38643489999999964`], 
             UndirectedEdge[14, 249] -> 
             RGBColor[0.9528099999999999, 0.9622556, 0.8780663], 
             UndirectedEdge[84, 89] -> 
             RGBColor[0.9253465, 0.7740184, 0.5854902], 
             UndirectedEdge[98, 246] -> 
             RGBColor[0.8278855, 0.8426785999999999, 0.6685621999999998], 
             UndirectedEdge[4, 107] -> 
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998], 
             UndirectedEdge[20, 295] -> 
             RGBColor[0.7943714000000002, 0.8387858000000001, 0.9368273], 
             UndirectedEdge[57, 175] -> 
             RGBColor[
              0.9792046999999999, 0.9810076000000001, 0.7454220999999996], 
             UndirectedEdge[93, 160] -> 
             RGBColor[0.9525295, 0.9597422, 0.7084488], 
             UndirectedEdge[13, 149] -> 
             RGBColor[
              0.9483649999999999, 0.8221859999999999, 0.3335864999999999], 
             UndirectedEdge[230, 298] -> 
             RGBColor[
              0.8332560000000001, 0.8689264000000001, 0.9033278999999999], 
             UndirectedEdge[96, 198] -> 
             RGBColor[0.7565632, 0.8080914, 0.9338508999999999], 
             UndirectedEdge[32, 182] -> 
             RGBColor[0.835474, 0.8698436, 0.8665699], 
             UndirectedEdge[80, 241] -> 
             RGBColor[
              0.7965894000000001, 0.8397030000000001, 0.9000692999999999], 
             UndirectedEdge[55, 292] -> 
             RGBColor[0.45331800000000005`, 0.567063, 0.950106], 
             UndirectedEdge[121, 160] -> 
             RGBColor[0.948374, 0.9604212000000001, 0.9515823], 
             UndirectedEdge[62, 220] -> 
             RGBColor[0.9927835, 0.9888863999999999, 0.5949935], 
             UndirectedEdge[28, 189] -> 
             RGBColor[0.9767113999999999, 0.981415, 0.8913021999999999], 
             UndirectedEdge[25, 91] -> 
             RGBColor[0.9525295, 0.9597422, 0.7084487999999999], 
             UndirectedEdge[41, 99] -> 
             RGBColor[0.720973, 0.7783142000000001, 0.8941164999999999], 
             UndirectedEdge[148, 206] -> 
             RGBColor[0.8718300999999999, 0.8974602, 0.8214839999999999], 
             UndirectedEdge[3, 90] -> 
             RGBColor[0.5859955, 0.6483969, 0.849056], 
             UndirectedEdge[99, 104] -> 
             RGBColor[0.718755, 0.777397, 0.9308745], 
             UndirectedEdge[193, 266] -> 
             RGBColor[0.7468646, 0.8008582, 0.9502681], 
             UndirectedEdge[275, 293] -> 
             RGBColor[0.988628, 0.9895654, 0.8381270000000001], 
             UndirectedEdge[229, 257] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999], 
             UndirectedEdge[90, 144] -> 
             RGBColor[0.5815595, 0.6465624999999999, 0.922572], 
             UndirectedEdge[49, 115] -> 
             RGBColor[0.929667, 0.943802, 0.8758589], UndirectedEdge[77, 244] -> 
             RGBColor[
              0.7996385000000001, 0.8404844000000001, 0.8146845999999999], 
             UndirectedEdge[66, 95] -> 
             RGBColor[0.8718300999999999, 0.8974602, 0.8214839999999999], 
             UndirectedEdge[94, 125] -> 
             RGBColor[0.49112620000000007`, 0.5977574, 0.9530824], 
             UndirectedEdge[196, 230] -> 
             RGBColor[0.988628, 0.9895654, 0.8381269999999997], 
             UndirectedEdge[138, 245] -> 
             RGBColor[0.9692308, 0.975099, 0.8709614], 
             UndirectedEdge[100, 127] -> 
             RGBColor[0.835474, 0.8698436, 0.8665699], 
             UndirectedEdge[24, 288] -> 
             RGBColor[
              0.7965894000000001, 0.8397030000000001, 0.9000692999999999], 
             UndirectedEdge[224, 258] -> 
             RGBColor[
              0.9689502999999999, 0.9725855999999999, 0.7013438999999999], 
             UndirectedEdge[25, 203] -> 
             RGBColor[0.9386753999999999, 0.953188, 0.9679995], 
             UndirectedEdge[143, 239] -> 
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999], 
             UndirectedEdge[142, 282] -> 
             RGBColor[
              0.9136839999999999, 0.6245997999999997, 0.36316119999999963`], 
             UndirectedEdge[57, 242] -> 
             RGBColor[0.9386753999999999, 0.953188, 0.9679995], 
             UndirectedEdge[47, 177] -> 
             RGBColor[0.7489340000000002, 0.8037922000000002, 0.9756104], 
             UndirectedEdge[43, 174] -> 
             RGBColor[0.9155324, 0.9347344, 0.9657921], UndirectedEdge[5, 29] -> 
             RGBColor[0.988628, 0.9895654, 0.8381270000000001], 
             UndirectedEdge[167, 282] -> 
             RGBColor[
              0.9792046999999999, 0.9810076000000001, 0.7454220999999996], 
             UndirectedEdge[131, 172] -> 
             RGBColor[0.9394811, 0.783086, 0.495557], UndirectedEdge[21, 101] -> 
             RGBColor[0.8076019999999999, 0.8499981999999999, 0.9813586], 
             UndirectedEdge[251, 300] -> 
             RGBColor[0.720973, 0.7783142000000001, 0.8941164999999999], 
             UndirectedEdge[75, 167] -> 
             RGBColor[0.9386753999999999, 0.953188, 0.9679995], 
             UndirectedEdge[165, 281] -> 
             RGBColor[0.9073551000000001, 0.9252126, 0.8250247999999999], 
             UndirectedEdge[63, 174] -> 
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998], 
             UndirectedEdge[64, 211] -> 
             RGBColor[0.9528099999999999, 0.9622556, 0.8780663], 
             UndirectedEdge[124, 237] -> 
             RGBColor[0.6951077000000001, 0.7540514, 0.8068894], 
             UndirectedEdge[127, 192] -> 
             RGBColor[0.7489340000000002, 0.8037922000000002, 0.9756104], 
             UndirectedEdge[62, 228] -> 
             RGBColor[0.9293865, 0.9412886, 0.7062413999999999], 
             UndirectedEdge[152, 277] -> 
             RGBColor[0.9058337999999999, 0.9275012, 0.9822093], 
             UndirectedEdge[76, 157] -> 
             RGBColor[0.8076019999999999, 0.8499981999999999, 0.9813586], 
             UndirectedEdge[106, 297] -> 
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993], 
             UndirectedEdge[91, 203] -> 
             RGBColor[0.9786489, 0.9798188, 0.6849266999999999], 
             UndirectedEdge[215, 271] -> 
             RGBColor[0.912556, 0.9331114, 0.9915216], 
             UndirectedEdge[181, 296] -> 
             RGBColor[0.9289768, 0.9459548, 0.9844166999999999], 
             UndirectedEdge[27, 119] -> 
             RGBColor[0.6019652, 0.6815452000000001, 0.9649216], 
             UndirectedEdge[100, 170] -> 
             RGBColor[0.9789294, 0.9823322000000001, 0.8545442000000001], 
             UndirectedEdge[112, 115] -> 
             RGBColor[0.9692308, 0.975099, 0.8709614], 
             UndirectedEdge[75, 282] -> 
             RGBColor[0.9530853, 0.960931, 0.7689441999999996], 
             UndirectedEdge[234, 255] -> 
             RGBColor[
              0.7996385000000001, 0.8404844000000001, 0.8146845999999999], 
             UndirectedEdge[29, 77] -> 
             RGBColor[0.7988074000000001, 0.8406202000000002, 0.8633113], 
             UndirectedEdge[44, 192] -> 
             RGBColor[
              0.8662700000000001, 0.8962042000000001, 0.9871068000000001], 
             UndirectedEdge[49, 57] -> 
             RGBColor[0.9155324, 0.9347344, 0.9657921], 
             UndirectedEdge[4, 281] -> 
             RGBColor[0.8826908, 0.9090476000000001, 0.9800019], 
             UndirectedEdge[23, 285] -> 
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998], 
             UndirectedEdge[86, 109] -> 
             RGBColor[0.9911213, 0.989158, 0.6922468999999996], 
             UndirectedEdge[276, 279] -> 
             RGBColor[0.6778840000000003, 0.7482874000000002, 0.9685288], 
             UndirectedEdge[139, 183] -> 
             RGBColor[0.6034092000000002, 0.6883696000000001, 0.9622938], 
             UndirectedEdge[234, 287] -> 
             RGBColor[0.9941704, 0.9899394, 0.6068621999999995], 
             UndirectedEdge[160, 181] -> 
             RGBColor[0.9289768, 0.9459548, 0.9844166999999999], 
             UndirectedEdge[196, 298] -> 
             RGBColor[
              0.8332560000000001, 0.8689264000000001, 0.9033278999999999], 
             UndirectedEdge[255, 287] -> 
             RGBColor[
              0.7990827000000001, 0.8392956000000001, 0.7541891999999997], 
             UndirectedEdge[126, 216] -> 
             RGBColor[0.9938951, 0.991264, 0.7159842999999999], 
             UndirectedEdge[190, 212] -> 
             RGBColor[0.6406937000000001, 0.5458734000000001, 0.5864621], 
             UndirectedEdge[39, 137] -> 
             RGBColor[0.6416381, 0.6444889999999999, 0.6089179], 
             UndirectedEdge[170, 195] -> 
             RGBColor[0.9744934, 0.9804978, 0.9280602], 
             UndirectedEdge[69, 288] -> 
             RGBColor[0.7943714000000002, 0.8387858000000001, 0.9368273], 
             UndirectedEdge[101, 231] -> 
             RGBColor[0.748934, 0.8037922, 0.9756104], 
             UndirectedEdge[57, 253] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[52, 266] -> 
             RGBColor[0.9713409, 0.9551671999999999, 0.6565364999999999], 
             UndirectedEdge[28, 275] -> 
             RGBColor[0.9744934, 0.9804978, 0.9280602], 
             UndirectedEdge[4, 226] -> 
             RGBColor[0.8471658, 0.8812952000000001, 0.9764611], 
             UndirectedEdge[104, 229] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999], 
             UndirectedEdge[189, 293] -> 
             RGBColor[0.9908459999999999, 0.9904826, 0.8013689999999999], 
             UndirectedEdge[155, 156] -> 
             RGBColor[0.9299423, 0.9424774, 0.7667367999999997], 
             UndirectedEdge[107, 281] -> 
             RGBColor[0.904306, 0.9244312000000001, 0.9104094999999999], 
             UndirectedEdge[107, 240] -> 
             RGBColor[0.988628, 0.9895654, 0.8381269999999997], 
             UndirectedEdge[13, 105] -> 
             RGBColor[0.7985269000000002, 0.8381068, 0.6936937999999999], 
             UndirectedEdge[96, 138] -> 
             RGBColor[0.988628, 0.9895654, 0.8381270000000001], 
             UndirectedEdge[254, 260] -> 
             RGBColor[
              0.9857507999999999, 0.9629101999999998, 0.4574811999999995], 
             UndirectedEdge[120, 176] -> 
             RGBColor[0.868781, 0.8966788, 0.9068686999999999], 
             UndirectedEdge[59, 125] -> 
             RGBColor[0.601126, 0.6854275999999999, 0.9628582], 
             UndirectedEdge[22, 267] -> 
             RGBColor[
              0.9067993000000001, 0.9240238000000001, 0.7645293999999996], 
             UndirectedEdge[28, 197] -> 
             RGBColor[0.9744934, 0.9804978, 0.9280602], 
             UndirectedEdge[245, 298] -> 
             RGBColor[0.8116408000000002, 0.8535428, 0.9729203], 
             UndirectedEdge[193, 199] -> 
             RGBColor[
              0.4622118000000002, 0.5727132000000001, 0.9512400000000001], 
             UndirectedEdge[22, 274] -> 
             RGBColor[0.9911213, 0.989158, 0.6922468999999996], 
             UndirectedEdge[76, 201] -> 
             RGBColor[0.9293865, 0.9412886, 0.7062413999999999], 
             UndirectedEdge[19, 158] -> 
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.6228385000000001, 0.4518727999999996, 0.5710571999999999], 
             UndirectedEdge[61, 267] -> 
             RGBColor[0.8431270000000001, 0.8777506, 0.9848994], 
             UndirectedEdge[106, 283] -> 
             RGBColor[
              0.9792046999999999, 0.9810076000000001, 0.7454220999999996], 
             UndirectedEdge[174, 283] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[19, 242] -> 
             RGBColor[0.912556, 0.9331114, 0.9915216], 
             UndirectedEdge[125, 195] -> 
             RGBColor[0.718755, 0.777397, 0.9308745], 
             UndirectedEdge[115, 159] -> 
             RGBColor[0.929667, 0.943802, 0.8758589], 
             UndirectedEdge[158, 177] -> 
             RGBColor[0.7720770000000001, 0.8222458000000001, 0.9778178], 
             UndirectedEdge[42, 134] -> 
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998], 
             UndirectedEdge[165, 179] -> 
             RGBColor[
              0.9403121999999999, 0.7829501999999999, 0.4469302999999999], 
             UndirectedEdge[108, 145] -> 
             RGBColor[0.5718609, 0.6393293, 0.9389892], 
             UndirectedEdge[44, 125] -> 
             RGBColor[0.682937, 0.7500872000000001, 0.9708138], 
             UndirectedEdge[39, 141] -> 
             RGBColor[
              0.9455066999999999, 0.8904449999999998, 0.6262055999999999], 
             UndirectedEdge[50, 87] -> 
             RGBColor[0.8813583, 0.5464626, 0.5707649], 
             UndirectedEdge[26, 226] -> 
             RGBColor[0.601126, 0.6854275999999999, 0.9628582], 
             UndirectedEdge[9, 143] -> 
             RGBColor[
              0.7965894000000001, 0.8397030000000001, 0.9000692999999999], 
             UndirectedEdge[136, 299] -> 
             RGBColor[0.8351935000000001, 0.8673302, 0.6969523999999999], 
             UndirectedEdge[134, 144] -> 
             RGBColor[0.9744934, 0.9804978, 0.9280602], 
             UndirectedEdge[240, 281] -> 
             RGBColor[0.904306, 0.9244312000000001, 0.9104094999999999], 
             UndirectedEdge[257, 261] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[57, 84] -> 
             RGBColor[0.9253465, 0.7740184, 0.5854902], 
             UndirectedEdge[135, 254] -> 
             RGBColor[
              0.9792046999999999, 0.9810076000000001, 0.7454220999999996], 
             UndirectedEdge[14, 224] -> 
             RGBColor[0.9525295, 0.9597422, 0.7084487999999999], 
             UndirectedEdge[96, 289] -> 
             RGBColor[0.866563, 0.8957615999999999, 0.9436267], 
             UndirectedEdge[92, 189] -> 
             RGBColor[0.9671219, 0.9058285999999998, 0.5566131999999998], 
             UndirectedEdge[107, 127] -> 
             RGBColor[
              0.8332560000000001, 0.8689264000000001, 0.9033278999999999], 
             UndirectedEdge[172, 270] -> 
             RGBColor[0.723191, 0.7792314, 0.8573585], UndirectedEdge[48, 84] -> 
             RGBColor[0.9253465, 0.7740184, 0.5854902], 
             UndirectedEdge[149, 289] -> 
             RGBColor[0.8265804999999999, 0.7308955999999999, 0.6087037], 
             UndirectedEdge[1, 102] -> 
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996], 
             UndirectedEdge[33, 297] -> 
             RGBColor[0.9299423, 0.9424774, 0.7667367999999997], 
             UndirectedEdge[18, 135] -> 
             RGBColor[0.9386753999999999, 0.953188, 0.9679995], 
             UndirectedEdge[60, 137] -> 
             RGBColor[0.6251082000000001, 0.6999988, 0.967129], 
             UndirectedEdge[156, 208] -> 
             RGBColor[0.8712743000000001, 0.8962714, 0.7609885999999997], 
             UndirectedEdge[104, 279] -> 
             RGBColor[
              0.8310380000000002, 0.8680092000000001, 0.9400858999999999], 
             UndirectedEdge[74, 158] -> 
             RGBColor[0.9058337999999999, 0.9275012, 0.9822093], 
             UndirectedEdge[80, 277] -> 
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998], 
             UndirectedEdge[223, 291] -> 
             RGBColor[0.7609992, 0.8099258, 0.8603349], 
             UndirectedEdge[114, 264] -> 
             RGBColor[0.9786489, 0.9798188, 0.6849266999999999], 
             UndirectedEdge[1, 237] -> 
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998], 
             UndirectedEdge[84, 292] -> 
             RGBColor[0.6696081, 0.5709176, 0.5883045], 
             UndirectedEdge[103, 152] -> 
             RGBColor[0.7354104000000001, 0.7930224000000001, 0.9745592], 
             UndirectedEdge[10, 269] -> 
             RGBColor[0.9386753999999999, 0.953188, 0.9679995], 
             UndirectedEdge[109, 138] -> 
             RGBColor[0.9933392999999999, 0.9900752, 0.6554888999999997], 
             UndirectedEdge[165, 240] -> 
             RGBColor[0.9916771, 0.9903468, 0.7527422999999998], 
             UndirectedEdge[249, 254] -> 
             RGBColor[0.9933392999999999, 0.9900752, 0.6554888999999997], 
             UndirectedEdge[2, 155] -> 
             RGBColor[0.8076019999999999, 0.8499981999999999, 0.9813586], 
             UndirectedEdge[117, 161] -> 
             RGBColor[0.8213394, 0.8607760000000001, 0.9565030999999999], 
             UndirectedEdge[169, 264] -> 
             RGBColor[0.9936146, 0.9887505999999999, 0.5463667999999998], 
             UndirectedEdge[3, 229] -> 
             RGBColor[0.9927835, 0.9888863999999999, 0.5949935], 
             UndirectedEdge[55, 90] -> 
             RGBColor[0.31612250000000003`, 0.4362285, 0.9418035], 
             UndirectedEdge[3, 259] -> 
             RGBColor[0.993064, 0.9913998, 0.764611], 
             UndirectedEdge[113, 254] -> 
             RGBColor[
              0.9792046999999999, 0.9810076000000001, 0.7454220999999996], 
             UndirectedEdge[6, 205] -> 
             RGBColor[
              0.9059428999999999, 0.8591479999999998, 0.6311030999999999], 
             UndirectedEdge[120, 287] -> 
             RGBColor[0.8712743000000001, 0.8962714, 0.7609885999999997], 
             UndirectedEdge[31, 67] -> 
             RGBColor[0.950592, 0.9613384, 0.9148242999999998], 
             UndirectedEdge[141, 232] -> 
             RGBColor[0.6993578, 0.7629306, 0.9637089], 
             UndirectedEdge[41, 88] -> 
             RGBColor[0.927449, 0.9428848000000001, 0.9126168999999998], 
             UndirectedEdge[71, 122] -> 
             RGBColor[0.641529, 0.7128422000000001, 0.9600241], 
             UndirectedEdge[78, 120] -> 
             RGBColor[0.7995608999999999, 0.5952815999999994, 0.5856518], 
             UndirectedEdge[177, 247] -> 
             RGBColor[
              0.8117499000000001, 0.7851895999999998, 0.6218140999999999], 
             UndirectedEdge[168, 182] -> 
             RGBColor[0.9908459999999999, 0.9904826, 0.8013689999999999], 
             UndirectedEdge[26, 228] -> 
             RGBColor[0.659794, 0.7316336, 0.9686064], UndirectedEdge[7, 194] -> 
             RGBColor[0.9567747, 0.8648054000000001, 0.5482875999999999], 
             UndirectedEdge[206, 244] -> 
             RGBColor[0.8718300999999999, 0.8974602, 0.8214839999999999], 
             UndirectedEdge[31, 109] -> 
             RGBColor[0.9530853, 0.960931, 0.7689441999999996], 
             UndirectedEdge[57, 235] -> 
             RGBColor[0.7468646, 0.8008582, 0.9502681], 
             UndirectedEdge[24, 135] -> 
             RGBColor[0.9767113999999999, 0.981415, 0.8913021999999999], 
             UndirectedEdge[130, 220] -> 
             RGBColor[0.9065240000000001, 0.9253484000000001, 0.8736515], 
             UndirectedEdge[84, 112] -> 
             RGBColor[0.9156479, 0.7667852, 0.6019074], 
             UndirectedEdge[76, 104] -> 
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749], 
             UndirectedEdge[21, 87] -> 
             RGBColor[0.9058337999999999, 0.9275012, 0.9822093], 
             UndirectedEdge[43, 183] -> 
             RGBColor[0.7720770000000001, 0.8222458000000001, 0.9778178], 
             UndirectedEdge[11, 131] -> 
             RGBColor[0.9156479, 0.7667852, 0.6019074], 
             UndirectedEdge[21, 187] -> 
             RGBColor[0.9304981, 0.9436662, 0.8272321999999999], 
             UndirectedEdge[36, 66] -> 
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998], 
             UndirectedEdge[124, 125] -> 
             RGBColor[0.42440360000000016`, 0.5420188000000001, 0.9482636], 
             UndirectedEdge[232, 296] -> 
             RGBColor[0.682937, 0.7500872000000001, 0.9708138], 
             UndirectedEdge[75, 239] -> 
             RGBColor[0.948374, 0.9604212000000001, 0.9515823], 
             UndirectedEdge[108, 114] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[137, 266] -> 
             RGBColor[0.6512276, 0.7200754, 0.9436069], 
             UndirectedEdge[74, 262] -> 
             RGBColor[0.9695061, 0.9737744, 0.7618392999999997], 
             UndirectedEdge[48, 90] -> 
             RGBColor[0.5718609, 0.6393293, 0.9389892], 
             UndirectedEdge[125, 150] -> 
             RGBColor[
              0.7209730000000001, 0.7783142000000001, 0.8941164999999999], 
             UndirectedEdge[38, 55] -> 
             RGBColor[0.7156025, 0.7520663999999999, 0.6593507999999999], 
             UndirectedEdge[110, 165] -> 
             RGBColor[0.9916771, 0.9903468, 0.7527422999999998], 
             UndirectedEdge[114, 145] -> 
             RGBColor[0.5718609, 0.6393293, 0.9389892], 
             UndirectedEdge[222, 290] -> 
             RGBColor[0.9536411, 0.9621198, 0.8294395999999999], 
             UndirectedEdge[267, 286] -> 
             RGBColor[0.6366510000000001, 0.71318, 0.966399], 
             UndirectedEdge[6, 187] -> 
             RGBColor[
              0.9701709999999999, 0.9066099999999998, 0.47122849999999983`], 
             UndirectedEdge[221, 231] -> 
             RGBColor[0.866563, 0.8957615999999999, 0.9436267], 
             UndirectedEdge[106, 286] -> 
             RGBColor[0.7234663, 0.7779068, 0.7482363999999997], 
             UndirectedEdge[67, 154] -> 
             RGBColor[0.868781, 0.8966788, 0.9068686999999999], 
             UndirectedEdge[85, 296] -> 
             RGBColor[0.948374, 0.9604212000000001, 0.9515823], 
             UndirectedEdge[41, 201] -> 
             RGBColor[0.9905655, 0.9879692, 0.6317514999999998], 
             UndirectedEdge[42, 235] -> 
             RGBColor[0.7618303, 0.80979, 0.8117081999999999], 
             UndirectedEdge[44, 60] -> 
             RGBColor[0.912556, 0.9331114, 0.9915216], 
             UndirectedEdge[199, 228] -> 
             RGBColor[0.6308796000000001, 0.7065894000000001, 0.966764], 
             UndirectedEdge[39, 62] -> 
             RGBColor[
              0.9690593999999999, 0.9042323999999997, 0.3502376999999999], 
             UndirectedEdge[48, 144] -> 
             RGBColor[0.9744934, 0.9804978, 0.9280602], 
             UndirectedEdge[68, 215] -> 
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999], 
             UndirectedEdge[127, 240] -> 
             RGBColor[
              0.8332560000000001, 0.8689264000000001, 0.9033278999999999], 
             UndirectedEdge[4, 26] -> 
             RGBColor[0.6993578, 0.7629306, 0.9637089], UndirectedEdge[8, 47] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[112, 175] -> 
             RGBColor[0.9695061, 0.9737744, 0.7618392999999997], 
             UndirectedEdge[162, 203] -> 
             RGBColor[0.9744934, 0.9804978, 0.9280602], UndirectedEdge[6, 50] -> 
             RGBColor[0.8814674, 0.4781093999999998, 0.21965869999999993`], 
             UndirectedEdge[15, 294] -> 
             RGBColor[0.8471658, 0.8812952000000001, 0.9764611], 
             UndirectedEdge[6, 219] -> 
             RGBColor[
              0.9690593999999999, 0.9042323999999997, 0.3502376999999999], 
             UndirectedEdge[110, 281] -> 
             RGBColor[0.904306, 0.9244312000000001, 0.9104094999999999], 
             UndirectedEdge[167, 297] -> 
             RGBColor[
              0.9792046999999999, 0.9810076000000001, 0.7454220999999996], 
             UndirectedEdge[122, 246] -> 
             RGBColor[0.6577737, 0.7019779999999999, 0.6556659999999999], 
             UndirectedEdge[210, 277] -> 
             RGBColor[0.9543343, 0.9232823999999997, 0.6445634999999997], 
             UndirectedEdge[225, 234] -> 
             RGBColor[0.9073551000000001, 0.9252126, 0.8250247999999999], 
             UndirectedEdge[84, 280] -> 
             RGBColor[0.9318926, 0.7559209999999998, 0.2975492999999998], 
             UndirectedEdge[67, 95] -> 
             RGBColor[0.868781, 0.8966788, 0.9068686999999999], 
             UndirectedEdge[81, 285] -> 
             RGBColor[0.9692308, 0.975099, 0.8709614], 
             UndirectedEdge[79, 164] -> 
             RGBColor[0.9649038999999999, 0.9049113999999998, 0.5933712], 
             UndirectedEdge[123, 157] -> 
             RGBColor[0.6389342, 0.7161219999999999, 0.9658346], 
             UndirectedEdge[85, 165] -> 
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998], 
             UndirectedEdge[59, 62] -> 
             RGBColor[0.8707185, 0.8950826, 0.7004931999999999], 
             UndirectedEdge[38, 48] -> 
             RGBColor[0.9713409, 0.9551671999999999, 0.6565364999999999], 
             UndirectedEdge[262, 291] -> 
             RGBColor[0.9933392999999999, 0.9900752, 0.6554888999999997], 
             UndirectedEdge[26, 170] -> 
             RGBColor[0.7090563999999999, 0.7701638, 0.9472917000000001], 
             UndirectedEdge[43, 139] -> 
             RGBColor[0.6976022, 0.762328, 0.9715828], 
             UndirectedEdge[52, 281] -> 
             RGBColor[0.8989355000000001, 0.8981834, 0.6756437999999998], 
             UndirectedEdge[124, 142] -> 
             RGBColor[0.6146213000000001, 0.38871179999999983`, 0.5631884], 
             UndirectedEdge[166, 271] -> 
             RGBColor[0.950592, 0.9613384, 0.9148242999999998], 
             UndirectedEdge[37, 150] -> 
             RGBColor[0.9911213, 0.989158, 0.6922468999999996], 
             UndirectedEdge[51, 66] -> 
             RGBColor[0.9936146, 0.9887505999999999, 0.5463667999999998], 
             UndirectedEdge[60, 125] -> 
             RGBColor[0.682937, 0.7500872000000001, 0.9708138], 
             UndirectedEdge[215, 223] -> 
             RGBColor[0.7207452000000001, 0.7807816000000001, 0.9737902], 
             UndirectedEdge[237, 282] -> 
             RGBColor[0.9941704, 0.9899394, 0.6068621999999995], 
             UndirectedEdge[143, 172] -> 
             RGBColor[0.9908459999999999, 0.9904826, 0.8013689999999999], 
             UndirectedEdge[177, 285] -> 
             RGBColor[0.8116408000000002, 0.8535428, 0.9729203], 
             UndirectedEdge[244, 270] -> 
             RGBColor[0.7240221, 0.7790956, 0.8087317999999999], 
             UndirectedEdge[147, 272] -> 
             RGBColor[0.7647361000000001, 0.7149430000000001, 0.6102299], 
             UndirectedEdge[46, 114] -> 
             RGBColor[0.9744934, 0.9804978, 0.9280602], 
             UndirectedEdge[104, 128] -> 
             RGBColor[0.9810395, 0.9624003999999999, 0.6401192999999998], 
             UndirectedEdge[199, 220] -> 
             RGBColor[0.6942766, 0.7541872000000001, 0.8555161], 
             UndirectedEdge[112, 146] -> 
             RGBColor[
              0.9689502999999999, 0.9725855999999999, 0.7013438999999999], 
             UndirectedEdge[191, 203] -> 
             RGBColor[0.8923894000000001, 0.9162808, 0.9635847], 
             UndirectedEdge[31, 96] -> 
             RGBColor[0.948374, 0.9604212000000001, 0.9515823], 
             UndirectedEdge[59, 228] -> 
             RGBColor[0.8076019999999999, 0.8499981999999999, 0.9813586], 
             UndirectedEdge[129, 289] -> 
             RGBColor[0.8712743000000001, 0.8962714, 0.7609885999999997], 
             UndirectedEdge[54, 106] -> 
             RGBColor[0.9530853, 0.960931, 0.7689441999999996], 
             UndirectedEdge[102, 142] -> 
             RGBColor[
              0.9136839999999999, 0.6245997999999997, 0.36316119999999963`], 
             UndirectedEdge[74, 90] -> 
             RGBColor[0.5621623, 0.6320961, 0.9554064], 
             UndirectedEdge[143, 174] -> 
             RGBColor[0.9767113999999999, 0.981415, 0.8913021999999999], 
             UndirectedEdge[144, 292] -> 
             RGBColor[0.718755, 0.777397, 0.9308745], UndirectedEdge[59, 255] -> 
             RGBColor[0.6767424000000002, 0.7468164000000002, 0.968811], 
             UndirectedEdge[254, 258] -> 
             RGBColor[0.9695061, 0.9737744, 0.7618392999999997], 
             UndirectedEdge[46, 108] -> 
             RGBColor[0.9744934, 0.9804978, 0.9280602], 
             UndirectedEdge[222, 278] -> 
             RGBColor[0.9536411, 0.9621198, 0.8294395999999999], 
             UndirectedEdge[115, 294] -> 
             RGBColor[0.9692308, 0.975099, 0.8709614], 
             UndirectedEdge[89, 177] -> 
             RGBColor[0.8213394, 0.8607760000000001, 0.9565030999999999], 
             UndirectedEdge[45, 195] -> 
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749], 
             UndirectedEdge[205, 231] -> 
             RGBColor[0.8076019999999999, 0.8499981999999999, 0.9813586], 
             UndirectedEdge[148, 244] -> 
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998], 
             UndirectedEdge[20, 297] -> 
             RGBColor[
              0.7990827000000001, 0.8392956000000001, 0.7541891999999997], 
             UndirectedEdge[6, 34] -> 
             RGBColor[0.9649038999999999, 0.9049113999999998, 0.5933712], 
             UndirectedEdge[13, 245] -> 
             RGBColor[
              0.9689502999999999, 0.9725855999999999, 0.7013438999999999], 
             UndirectedEdge[104, 201] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999], 
             UndirectedEdge[55, 253] -> 
             RGBColor[0.7090563999999999, 0.7701638, 0.9472917000000001], 
             UndirectedEdge[52, 141] -> 
             RGBColor[0.9616423, 0.9479339999999998, 0.6729536999999999], 
             UndirectedEdge[160, 299] -> 
             RGBColor[0.9525295, 0.9597422, 0.7084487999999999], 
             UndirectedEdge[229, 284] -> 
             RGBColor[0.8707185, 0.8950826, 0.7004931999999999], 
             UndirectedEdge[27, 268] -> 
             RGBColor[0.8760840999999999, 0.7354882, 0.6068049], 
             UndirectedEdge[193, 236] -> 
             RGBColor[0.7565632, 0.8080914, 0.9338508999999999], 
             UndirectedEdge[78, 193] -> 
             RGBColor[
              0.6895610999999999, 0.5076113999999995, 0.5758759999999999], 
             UndirectedEdge[175, 177] -> 
             RGBColor[0.8357493000000001, 0.868519, 0.7574477999999996], 
             UndirectedEdge[36, 67] -> 
             RGBColor[0.9767113999999999, 0.981415, 0.8913021999999999], 
             UndirectedEdge[37, 239] -> 
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996], 
             UndirectedEdge[49, 280] -> 
             RGBColor[0.9220785, 0.9166369999999999, 0.6778511999999998], 
             UndirectedEdge[263, 276] -> 
             RGBColor[0.7720770000000001, 0.8222458000000001, 0.9778178], 
             UndirectedEdge[13, 73] -> 
             RGBColor[0.9905655, 0.9879692, 0.6317514999999998], 
             UndirectedEdge[136, 240] -> 
             RGBColor[
              0.8332560000000001, 0.8689264000000001, 0.9033278999999999], 
             UndirectedEdge[79, 241] -> 
             RGBColor[0.7943714000000002, 0.8387858000000001, 0.9368273], 
             UndirectedEdge[78, 226] -> 
             RGBColor[0.7995608999999999, 0.5952815999999994, 0.5856518], 
             UndirectedEdge[3, 74] -> 
             RGBColor[0.9692308, 0.975099, 0.8709614], 
             UndirectedEdge[148, 203] -> 
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998], 
             UndirectedEdge[90, 257] -> 
             RGBColor[0.5815595, 0.6465624999999999, 0.922572], 
             UndirectedEdge[34, 87] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[146, 235] -> 
             RGBColor[0.7607187, 0.8074124, 0.6907173999999998], 
             UndirectedEdge[181, 256] -> 
             RGBColor[0.8826908, 0.9090476000000001, 0.9800019], 
             UndirectedEdge[68, 287] -> 
             RGBColor[0.9299423, 0.9424774, 0.7667367999999997], 
             UndirectedEdge[17, 144] -> 
             RGBColor[0.948374, 0.9604212000000001, 0.9515823], 
             UndirectedEdge[163, 216] -> 
             RGBColor[0.9692308, 0.975099, 0.8709614], 
             UndirectedEdge[67, 258] -> 
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998], 
             UndirectedEdge[232, 240] -> 
             RGBColor[
              0.7209730000000001, 0.7783142000000001, 0.8941164999999999], 
             UndirectedEdge[133, 210] -> 
             RGBColor[
              0.8205775000000001, 0.8180269999999998, 0.6401719999999997], 
             UndirectedEdge[58, 154] -> 
             RGBColor[0.866563, 0.8957615999999999, 0.9436267], 
             UndirectedEdge[94, 124] -> 
             RGBColor[
              0.4622118000000002, 0.5727132000000001, 0.9512400000000001], 
             UndirectedEdge[50, 213] -> 
             RGBColor[0.9060226, 0.5626276, 0.41578779999999993`], 
             UndirectedEdge[15, 212] -> 
             RGBColor[0.5722116000000002, 0.6603834000000001, 0.9610158], 
             UndirectedEdge[11, 139] -> 
             RGBColor[0.737166, 0.793625, 0.9666853], 
             UndirectedEdge[167, 286] -> 
             RGBColor[0.7090564, 0.7701638, 0.9472917000000001], 
             UndirectedEdge[113, 288] -> 
             RGBColor[0.7846728000000001, 0.8315526000000002, 0.9532445], 
             UndirectedEdge[73, 171] -> 
             RGBColor[0.988628, 0.9895654, 0.8381269999999997], 
             UndirectedEdge[31, 110] -> 
             RGBColor[0.950592, 0.9613384, 0.9148242999999998], 
             UndirectedEdge[202, 275] -> 
             RGBColor[0.948374, 0.9604212000000001, 0.9515823], 
             UndirectedEdge[103, 241] -> 
             RGBColor[0.6045508000000003, 0.6898406000000002, 0.9620116], 
             UndirectedEdge[9, 20] -> 
             RGBColor[0.6045508000000003, 0.6898406000000002, 0.9620116], 
             UndirectedEdge[71, 207] -> 
             RGBColor[0.9289768, 0.9459548, 0.9844166999999999], 
             UndirectedEdge[160, 168] -> 
             RGBColor[0.950592, 0.9613384, 0.9148242999999998], 
             UndirectedEdge[6, 114] -> 
             RGBColor[0.9552052999999999, 0.8976781999999999, 0.6097884], 
             UndirectedEdge[95, 96] -> 
             RGBColor[0.866563, 0.8957615999999999, 0.9436267], 
             UndirectedEdge[198, 278] -> 
             RGBColor[0.7207452000000001, 0.7807816000000001, 0.9737902], 
             UndirectedEdge[86, 281] -> 
             RGBColor[0.904306, 0.9244312000000001, 0.9104094999999999], 
             UndirectedEdge[107, 165] -> 
             RGBColor[0.9916771, 0.9903468, 0.7527422999999998], 
             UndirectedEdge[155, 184] -> 
             RGBColor[0.9155324, 0.9347344, 0.9657921], 
             UndirectedEdge[247, 285] -> 
             RGBColor[
              0.9455066999999999, 0.8904449999999998, 0.6262055999999999], 
             UndirectedEdge[34, 227] -> 
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749], 
             UndirectedEdge[116, 152] -> 
             RGBColor[0.9293865, 0.9412886, 0.7062413999999999], 
             UndirectedEdge[146, 204] -> 
             RGBColor[0.9786489, 0.9798188, 0.6849266999999999], 
             UndirectedEdge[36, 58] -> 
             RGBColor[0.9744934, 0.9804978, 0.9280602], 
             UndirectedEdge[105, 129] -> 
             RGBColor[
              0.7990827000000001, 0.8392956000000001, 0.7541891999999997], 
             UndirectedEdge[87, 187] -> 
             RGBColor[0.9700618999999999, 0.9749632, 0.8223346999999999], 
             UndirectedEdge[119, 168] -> 
             RGBColor[
              0.6631442000000001, 0.7282258000000001, 0.8904316999999999], 
             UndirectedEdge[20, 37] -> 
             RGBColor[
              0.7990827000000001, 0.8392956000000001, 0.7541891999999997], 
             UndirectedEdge[150, 200] -> 
             RGBColor[0.720973, 0.7783142000000001, 0.8941164999999999], 
             UndirectedEdge[1, 43] -> 
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749], 
             UndirectedEdge[187, 213] -> 
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998], 
             UndirectedEdge[41, 222] -> 
             RGBColor[0.9916771, 0.9903468, 0.7527422999999998], 
             UndirectedEdge[196, 263] -> 
             RGBColor[0.927449, 0.9428848000000001, 0.9126168999999998], 
             UndirectedEdge[148, 172] -> 
             RGBColor[0.9938951, 0.991264, 0.7159842999999999], 
             UndirectedEdge[96, 171] -> 
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999], 
             UndirectedEdge[178, 208] -> 
             RGBColor[0.8634105, 0.8704309999999998, 0.6721029999999999], 
             UndirectedEdge[25, 270] -> 
             RGBColor[0.682937, 0.7500872000000001, 0.9708138], 
             UndirectedEdge[47, 217] -> 
             RGBColor[
              0.9067993000000001, 0.9240238000000001, 0.7645293999999996], 
             UndirectedEdge[33, 142] -> 
             RGBColor[0.8500117, 0.5783265999999998, 0.5835311999999999], 
             UndirectedEdge[26, 62] -> 
             RGBColor[0.7229105, 0.776718, 0.6877409999999999], 
             UndirectedEdge[48, 177] -> 
             RGBColor[0.8213394, 0.8607760000000001, 0.9565030999999999], 
             UndirectedEdge[238, 300] -> 
             RGBColor[0.718755, 0.777397, 0.9308745], UndirectedEdge[25, 139] -> 
             RGBColor[0.7207452000000001, 0.7807816000000001, 0.9737902], 
             UndirectedEdge[3, 30] -> 
             RGBColor[0.988628, 0.9895654, 0.8381270000000001], 
             UndirectedEdge[95, 171] -> 
             RGBColor[0.868781, 0.8966788, 0.9068686999999999], 
             UndirectedEdge[21, 50] -> 
             RGBColor[0.8417945, 0.5151656, 0.5756623999999999], 
             UndirectedEdge[122, 232] -> 
             RGBColor[
              0.3954892000000001, 0.5169746000000001, 0.9464212000000001], 
             UndirectedEdge[127, 136] -> 
             RGBColor[0.6778840000000003, 0.7482874000000002, 0.9685288], 
             UndirectedEdge[41, 290] -> 
             RGBColor[0.950592, 0.9613384, 0.9148242999999998], 
             UndirectedEdge[123, 259] -> 
             RGBColor[0.7609992, 0.8099258, 0.8603349], 
             UndirectedEdge[20, 185] -> 
             RGBColor[
              0.7839109000000001, 0.7888035999999998, 0.6369133999999997], 
             UndirectedEdge[163, 211] -> 
             RGBColor[0.9289768, 0.9459548, 0.9844166999999999], 
             UndirectedEdge[33, 37] -> 
             RGBColor[0.9299423, 0.9424774, 0.7667367999999997], 
             UndirectedEdge[7, 9] -> 
             RGBColor[0.7647361000000001, 0.7149430000000001, 0.6102299], 
             UndirectedEdge[105, 263] -> 
             RGBColor[0.7354104000000001, 0.7930224000000001, 0.9745592], 
             UndirectedEdge[15, 49] -> 
             RGBColor[0.8076019999999999, 0.8499981999999999, 0.9813586], 
             UndirectedEdge[20, 237] -> 
             RGBColor[
              0.7996385000000001, 0.8404844000000001, 0.8146845999999999], 
             UndirectedEdge[26, 220] -> 
             RGBColor[0.7231909999999999, 0.7792314, 0.8573585], 
             UndirectedEdge[101, 187] -> 
             RGBColor[0.8718300999999999, 0.8974602, 0.8214839999999999], 
             UndirectedEdge[93, 94] -> 
             RGBColor[0.7607187, 0.8074124, 0.6907173999999998], 
             UndirectedEdge[143, 297] -> 
             RGBColor[0.9911213, 0.989158, 0.6922468999999996], 
             UndirectedEdge[208, 268] -> 
             RGBColor[0.8174161, 0.6892822, 0.6010567], 
             UndirectedEdge[16, 33] -> 
             RGBColor[0.929667, 0.943802, 0.8758589], 
             UndirectedEdge[224, 288] -> 
             RGBColor[0.7985269000000002, 0.8381068, 0.6936937999999999], 
             UndirectedEdge[1, 75] -> 
             RGBColor[0.948374, 0.9604212000000001, 0.9515823], 
             UndirectedEdge[36, 113] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[29, 244] -> 
             RGBColor[0.9938951, 0.991264, 0.7159842999999999], 
             UndirectedEdge[36, 96] -> 
             RGBColor[0.9744934, 0.9804978, 0.9280602], 
             UndirectedEdge[58, 138] -> 
             RGBColor[0.988628, 0.9895654, 0.8381270000000001], 
             UndirectedEdge[71, 136] -> 
             RGBColor[0.8116408000000002, 0.8535428, 0.9729203], 
             UndirectedEdge[144, 252] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[58, 198] -> 
             RGBColor[0.7565632, 0.8080914, 0.9338508999999999], 
             UndirectedEdge[110, 154] -> 
             RGBColor[0.868781, 0.8966788, 0.9068686999999999], 
             UndirectedEdge[119, 152] -> 
             RGBColor[0.6019652, 0.6815452000000001, 0.9649216], 
             UndirectedEdge[38, 90] -> 
             RGBColor[0.578407, 0.6212318999999998, 0.6510482999999998], 
             UndirectedEdge[66, 179] -> 
             RGBColor[
              0.9403121999999999, 0.7829501999999999, 0.4469302999999999], 
             UndirectedEdge[6, 21] -> 
             RGBColor[
              0.9059428999999999, 0.8591479999999998, 0.6311030999999999], 
             UndirectedEdge[176, 287] -> 
             RGBColor[0.9911213, 0.989158, 0.6922468999999996], 
             UndirectedEdge[142, 237] -> 
             RGBColor[0.9142398, 0.6257885999999997, 0.42365659999999983`], 
             UndirectedEdge[108, 221] -> 
             RGBColor[0.9744934, 0.9804978, 0.9280602], 
             UndirectedEdge[44, 256] -> 
             RGBColor[
              0.8662700000000001, 0.8962042000000001, 0.9871068000000001], 
             UndirectedEdge[89, 112] -> 
             RGBColor[0.9550962, 0.9660314000000001, 0.9608946], 
             UndirectedEdge[83, 184] -> 
             RGBColor[0.9744934, 0.9804978, 0.9280602], 
             UndirectedEdge[259, 261] -> 
             RGBColor[0.9692308, 0.975099, 0.8709614], 
             UndirectedEdge[207, 231] -> 
             RGBColor[0.8307450000000001, 0.8684518, 0.9835659999999999], 
             UndirectedEdge[112, 280] -> 
             RGBColor[0.9616423, 0.9479339999999998, 0.6729536999999998], 
             UndirectedEdge[174, 194] -> 
             RGBColor[0.9767113999999999, 0.981415, 0.8913021999999999], 
             UndirectedEdge[125, 200] -> 
             RGBColor[0.45331800000000005`, 0.567063, 0.950106], 
             UndirectedEdge[99, 222] -> 
             RGBColor[0.7240221, 0.7790956, 0.8087317999999999], 
             UndirectedEdge[108, 169] -> 
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998], 
             UndirectedEdge[15, 57] -> 
             RGBColor[0.8568644, 0.8885284, 0.9600439000000001], 
             UndirectedEdge[4, 78] -> 
             RGBColor[
              0.8977926999999999, 0.6727845999999995, 0.5865024999999999], 
             UndirectedEdge[52, 86] -> 
             RGBColor[
              0.9832574999999999, 0.9633175999999999, 0.6033612999999997], 
             UndirectedEdge[20, 282] -> 
             RGBColor[
              0.7990827000000001, 0.8392956000000001, 0.7541891999999997], 
             UndirectedEdge[42, 55] -> 
             RGBColor[0.7240221, 0.7790956, 0.8087317999999999], 
             UndirectedEdge[136, 165] -> 
             RGBColor[0.8363051000000001, 0.8697078, 0.8179431999999999], 
             UndirectedEdge[161, 269] -> 
             RGBColor[0.7952200000000001, 0.8406994000000001, 0.9800252], 
             UndirectedEdge[57, 243] -> 
             RGBColor[0.9386753999999999, 0.953188, 0.9679995], 
             UndirectedEdge[57, 146] -> 
             RGBColor[0.9786489, 0.9798188, 0.6849266999999999], 
             UndirectedEdge[4, 130] -> 
             RGBColor[0.8826908, 0.9090476000000001, 0.9800019], 
             UndirectedEdge[31, 58] -> 
             RGBColor[0.948374, 0.9604212000000001, 0.9515823], 
             UndirectedEdge[95, 140] -> 
             RGBColor[0.7134090000000002, 0.7760398000000001, 0.9720696], 
             UndirectedEdge[58, 96] -> RGBColor[0.984192, 0.987731, 0.911643],
              UndirectedEdge[16, 94] -> 
             RGBColor[0.7609992, 0.8099258, 0.8603349], 
             UndirectedEdge[113, 135] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[47, 262] -> 
             RGBColor[
              0.9067993000000001, 0.9240238000000001, 0.7645293999999996], 
             UndirectedEdge[153, 211] -> 
             RGBColor[0.7952200000000001, 0.8406994000000001, 0.9800252], 
             UndirectedEdge[89, 111] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[137, 256] -> 
             RGBColor[0.5788222000000001, 0.6630916000000001, 0.9627142], 
             UndirectedEdge[136, 181] -> 
             RGBColor[0.8116408000000002, 0.8535428, 0.9729203], 
             UndirectedEdge[288, 291] -> 
             RGBColor[0.7988074000000001, 0.8406202000000002, 0.8633113], 
             UndirectedEdge[121, 296] -> 
             RGBColor[0.948374, 0.9604212000000001, 0.9515823], 
             UndirectedEdge[241, 277] -> 
             RGBColor[0.7749742000000002, 0.8243194000000001, 0.9696617], 
             UndirectedEdge[217, 262] -> 
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993], 
             UndirectedEdge[75, 142] -> 
             RGBColor[0.8731547, 0.5967801999999998, 0.5857386], 
             UndirectedEdge[57, 112] -> 
             RGBColor[0.9550962, 0.9660314000000001, 0.9608946], 
             UndirectedEdge[274, 287] -> 
             RGBColor[0.9911213, 0.989158, 0.6922468999999996], 
             UndirectedEdge[97, 252] -> 
             RGBColor[
              0.8310380000000002, 0.8680092000000001, 0.9400858999999999], 
             UndirectedEdge[18, 69] -> 
             RGBColor[0.948374, 0.9604212000000001, 0.9515823], 
             UndirectedEdge[106, 167] -> 
             RGBColor[
              0.9792046999999999, 0.9810076000000001, 0.7454220999999996], 
             UndirectedEdge[256, 296] -> 
             RGBColor[
              0.8662700000000001, 0.8962042000000001, 0.9871068000000001], 
             UndirectedEdge[131, 183] -> 
             RGBColor[0.7818911000000002, 0.6615298000000001, 0.5975159], 
             UndirectedEdge[172, 183] -> 
             RGBColor[0.835474, 0.8698436, 0.8665699], UndirectedEdge[1, 143] -> 
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999], 
             UndirectedEdge[17, 252] -> 
             RGBColor[0.948374, 0.9604212000000001, 0.9515823], 
             UndirectedEdge[126, 214] -> 
             RGBColor[
              0.9403121999999999, 0.7829501999999999, 0.4469302999999999], 
             UndirectedEdge[84, 134] -> 
             RGBColor[0.9253465, 0.7740184, 0.5854902], 
             UndirectedEdge[45, 234] -> 
             RGBColor[0.9304981, 0.9436662, 0.8272321999999999], 
             UndirectedEdge[32, 156] -> 
             RGBColor[0.8357493000000001, 0.868519, 0.7574477999999996], 
             UndirectedEdge[140, 149] -> 
             RGBColor[0.7910555000000001, 0.7031432, 0.6051629], 
             UndirectedEdge[16, 150] -> 
             RGBColor[0.9908459999999999, 0.9904826, 0.8013689999999999], 
             UndirectedEdge[209, 218] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[82, 281] -> 
             RGBColor[0.9073551000000001, 0.9252126, 0.8250247999999999], 
             UndirectedEdge[178, 182] -> 
             RGBColor[0.9854755, 0.9642347999999998, 0.5666032999999998], 
             UndirectedEdge[41, 157] -> 
             RGBColor[0.868781, 0.8966788, 0.9068686999999999], 
             UndirectedEdge[254, 288] -> 
             RGBColor[
              0.7990827000000001, 0.8392956000000001, 0.7541891999999997], 
             UndirectedEdge[129, 161] -> 
             RGBColor[0.8357493000000001, 0.868519, 0.7574477999999996], 
             UndirectedEdge[20, 283] -> 
             RGBColor[0.7846728000000001, 0.8315526000000002, 0.9532445], 
             UndirectedEdge[162, 210] -> 
             RGBColor[0.9737315, 0.9377487999999998, 0.6117290999999998], 
             UndirectedEdge[203, 244] -> 
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998], 
             UndirectedEdge[121, 246] -> 
             RGBColor[0.9810395, 0.9624003999999999, 0.6401192999999998], 
             UndirectedEdge[24, 259] -> 
             RGBColor[0.9908459999999999, 0.9904826, 0.8013689999999999], 
             UndirectedEdge[141, 281] -> 
             RGBColor[0.8826908, 0.9090476000000001, 0.9800019], 
             UndirectedEdge[110, 138] -> 
             RGBColor[0.9908459999999999, 0.9904826, 0.8013689999999999], 
             UndirectedEdge[67, 109] -> 
             RGBColor[0.9911213, 0.989158, 0.6922468999999996], 
             UndirectedEdge[154, 245] -> 
             RGBColor[0.8471658, 0.8812952000000001, 0.9764611], 
             UndirectedEdge[193, 249] -> 
             RGBColor[0.7609992, 0.8099258, 0.8603349], 
             UndirectedEdge[82, 137] -> 
             RGBColor[0.6661933, 0.7290072000000001, 0.8050469999999998], 
             UndirectedEdge[100, 125] -> 
             RGBColor[0.723191, 0.7792314, 0.8573585], 
             UndirectedEdge[104, 218] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[73, 149] -> 
             RGBColor[0.9464275, 0.8237821999999999, 0.5399619999999998], 
             UndirectedEdge[108, 219] -> 
             RGBColor[0.9786489, 0.9798188, 0.6849266999999999], 
             UndirectedEdge[58, 140] -> 
             RGBColor[
              0.8310380000000002, 0.8680092000000001, 0.9400858999999999], 
             UndirectedEdge[9, 63] -> 
             RGBColor[
              0.7996385000000001, 0.8404844000000001, 0.8146845999999999], 
             UndirectedEdge[48, 217] -> 
             RGBColor[
              0.9792046999999999, 0.9810076000000001, 0.7454220999999996], 
             UndirectedEdge[8, 271] -> 
             RGBColor[0.948374, 0.9604212000000001, 0.9515823], 
             UndirectedEdge[18, 222] -> 
             RGBColor[0.9536411, 0.9621198, 0.8294395999999999], 
             UndirectedEdge[215, 234] -> 
             RGBColor[0.9536411, 0.9621198, 0.8294395999999999], 
             UndirectedEdge[15, 146] -> 
             RGBColor[0.8707185, 0.8950826, 0.7004931999999999], 
             UndirectedEdge[54, 151] -> 
             RGBColor[0.8992271000000001, 0.7539418, 0.6090123000000001], 
             UndirectedEdge[195, 255] -> 
             RGBColor[0.7943714000000002, 0.8387858000000001, 0.9368273], 
             UndirectedEdge[1, 11] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[32, 178] -> 
             RGBColor[0.8278855, 0.8426785999999999, 0.6685621999999998], 
             UndirectedEdge[126, 189] -> 
             RGBColor[0.9916771, 0.9903468, 0.7527422999999998], 
             UndirectedEdge[61, 273] -> 
             RGBColor[0.9155324, 0.9347344, 0.9657921], 
             UndirectedEdge[54, 194] -> 
             RGBColor[0.950592, 0.9613384, 0.9148242999999998], 
             UndirectedEdge[38, 144] -> 
             RGBColor[0.9810395, 0.9624003999999999, 0.6401192999999998], 
             UndirectedEdge[4, 220] -> 
             RGBColor[0.9692308, 0.975099, 0.8709614], 
             UndirectedEdge[45, 200] -> 
             RGBColor[0.659794, 0.7316336, 0.9686064], UndirectedEdge[2, 202] -> 
             RGBColor[0.8307450000000001, 0.8684518, 0.9835659999999999], 
             UndirectedEdge[17, 175] -> 
             RGBColor[0.9530853, 0.960931, 0.7689441999999996], 
             UndirectedEdge[233, 262] -> 
             RGBColor[0.9933392999999999, 0.9900752, 0.6554888999999997], 
             UndirectedEdge[67, 138] -> 
             RGBColor[0.9908459999999999, 0.9904826, 0.8013689999999999], 
             UndirectedEdge[39, 192] -> 
             RGBColor[0.8827999, 0.8406943999999998, 0.6288957], 
             UndirectedEdge[164, 168] -> 
             RGBColor[0.9671219, 0.9058285999999998, 0.5566131999999998], 
             UndirectedEdge[19, 253] -> 
             RGBColor[0.9386753999999999, 0.953188, 0.9679995], 
             UndirectedEdge[24, 74] -> 
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998], 
             UndirectedEdge[80, 133] -> 
             RGBColor[
              0.8332560000000001, 0.8689264000000001, 0.9033278999999999], 
             UndirectedEdge[198, 222] -> 
             RGBColor[0.7618303, 0.80979, 0.8117081999999999], 
             UndirectedEdge[111, 212] -> 
             RGBColor[0.6801420000000001, 0.7451196000000001, 0.9454493], 
             UndirectedEdge[126, 184] -> 
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998], 
             UndirectedEdge[132, 294] -> 
             RGBColor[0.8813583, 0.5464626, 0.5707649], 
             UndirectedEdge[39, 136] -> 
             RGBColor[
              0.8117499000000001, 0.7851895999999998, 0.6218140999999999], 
             UndirectedEdge[133, 162] -> 
             RGBColor[
              0.8310380000000002, 0.8680092000000001, 0.9400858999999999], 
             UndirectedEdge[22, 271] -> 
             RGBColor[0.9530853, 0.960931, 0.7689441999999996], 
             UndirectedEdge[107, 110] -> 
             RGBColor[0.988628, 0.9895654, 0.8381269999999997], 
             UndirectedEdge[40, 191] -> 
             RGBColor[0.784459, 0.8315446, 0.9791512], 
             UndirectedEdge[143, 237] -> 
             RGBColor[0.9916771, 0.9903468, 0.7527422999999998], 
             UndirectedEdge[157, 261] -> 
             RGBColor[0.8471658, 0.8812952000000001, 0.9764611], 
             UndirectedEdge[35, 163] -> 
             RGBColor[0.9700618999999999, 0.9749632, 0.8223346999999999], 
             UndirectedEdge[89, 175] -> 
             RGBColor[
              0.9792046999999999, 0.9810076000000001, 0.7454220999999996], 
             UndirectedEdge[16, 200] -> 
             RGBColor[0.723191, 0.7792314, 0.8573585], 
             UndirectedEdge[35, 189] -> 
             RGBColor[0.9916771, 0.9903468, 0.7527422999999998], 
             UndirectedEdge[233, 291] -> 
             RGBColor[0.993064, 0.9913998, 0.764611], 
             UndirectedEdge[258, 290] -> 
             RGBColor[0.9289768, 0.9459548, 0.9844166999999999], 
             UndirectedEdge[157, 259] -> 
             RGBColor[0.870999, 0.8975960000000001, 0.8701107], 
             UndirectedEdge[105, 245] -> 
             RGBColor[0.7749742000000002, 0.8243194000000001, 0.9696617], 
             UndirectedEdge[100, 192] -> 
             RGBColor[0.9065240000000001, 0.9253484000000001, 0.8736515], 
             UndirectedEdge[258, 278] -> 
             RGBColor[0.9289768, 0.9459548, 0.9844166999999999], 
             UndirectedEdge[99, 201] -> 
             RGBColor[0.7229105, 0.776718, 0.6877409999999999], 
             UndirectedEdge[9, 282] -> 
             RGBColor[
              0.7990827000000001, 0.8392956000000001, 0.7541891999999997], 
             UndirectedEdge[84, 175] -> 
             RGBColor[0.9397564, 0.7817613999999999, 0.3864348999999996], 
             UndirectedEdge[271, 291] -> 
             RGBColor[0.9528099999999999, 0.9622556, 0.8780663], 
             UndirectedEdge[127, 256] -> 
             RGBColor[0.7489340000000002, 0.8037922000000002, 0.9756104], 
             UndirectedEdge[80, 116] -> 
             RGBColor[0.9905655, 0.9879692, 0.6317514999999998], 
             UndirectedEdge[202, 268] -> 
             RGBColor[0.8992271000000001, 0.7539418, 0.6090123000000001], 
             UndirectedEdge[161, 265] -> 
             RGBColor[0.7818911000000002, 0.6615298000000001, 0.5975159], 
             UndirectedEdge[22, 72] -> 
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996], 
             UndirectedEdge[77, 162] -> 
             RGBColor[0.7943714000000002, 0.8387858000000001, 0.9368273], 
             UndirectedEdge[93, 164] -> 
             RGBColor[
              0.9690593999999999, 0.9042323999999997, 0.3502376999999999], 
             UndirectedEdge[19, 111] -> 
             RGBColor[0.9386753999999999, 0.953188, 0.9679995], 
             UndirectedEdge[37, 142] -> 
             RGBColor[
              0.9136839999999999, 0.6245997999999997, 0.36316119999999963`], 
             UndirectedEdge[43, 172] -> 
             RGBColor[0.929667, 0.943802, 0.8758589], UndirectedEdge[61, 285] -> 
             RGBColor[0.9058337999999999, 0.9275012, 0.9822093], 
             UndirectedEdge[38, 257] -> 
             RGBColor[0.9810395, 0.9624003999999999, 0.6401192999999998], 
             UndirectedEdge[174, 185] -> 
             RGBColor[
              0.9640328999999999, 0.9305155999999998, 0.6281462999999998], 
             UndirectedEdge[75, 237] -> 
             RGBColor[0.9536411, 0.9621198, 0.8294395999999999], 
             UndirectedEdge[30, 48] -> 
             RGBColor[0.9744934, 0.9804978, 0.9280602], 
             UndirectedEdge[289, 298] -> 
             RGBColor[0.7134090000000002, 0.7760398000000001, 0.9720696], 
             UndirectedEdge[123, 261] -> 
             RGBColor[0.737166, 0.793625, 0.9666853], UndirectedEdge[77, 206] -> 
             RGBColor[0.6767424000000002, 0.7468164000000002, 0.968811], 
             UndirectedEdge[121, 137] -> 
             RGBColor[0.6609262, 0.7273086000000001, 0.9271897], 
             UndirectedEdge[87, 227] -> 
             RGBColor[0.9058337999999999, 0.9275012, 0.9822093], 
             UndirectedEdge[123, 144] -> 
             RGBColor[0.7565632, 0.8080914, 0.9338508999999999], 
             UndirectedEdge[9, 37] -> 
             RGBColor[
              0.7990827000000001, 0.8392956000000001, 0.7541891999999997], 
             UndirectedEdge[178, 268] -> 
             RGBColor[0.9318926, 0.7559209999999998, 0.2975492999999998], 
             UndirectedEdge[112, 253] -> 
             RGBColor[0.9550962, 0.9660314000000001, 0.9608946], 
             UndirectedEdge[78, 220] -> 
             RGBColor[
              0.9216258999999999, 0.6890853999999995, 0.48015209999999997`], 
             UndirectedEdge[66, 67] -> 
             RGBColor[0.9916771, 0.9903468, 0.7527422999999998], 
             UndirectedEdge[20, 124] -> 
             RGBColor[0.5000200000000002, 0.6034076000000002, 0.9542164], 
             UndirectedEdge[18, 224] -> 
             RGBColor[0.9525295, 0.9597422, 0.7084487999999999], 
             UndirectedEdge[72, 151] -> 
             RGBColor[0.9350451, 0.7812516, 0.5690729999999999], 
             UndirectedEdge[25, 29] -> 
             RGBColor[0.9528099999999999, 0.9622556, 0.8780663], 
             UndirectedEdge[135, 258] -> 
             RGBColor[0.9550962, 0.9660314000000001, 0.9608946], 
             UndirectedEdge[130, 176] -> 
             RGBColor[0.904306, 0.9244312000000001, 0.9104094999999999], 
             UndirectedEdge[31, 245] -> 
             RGBColor[0.9289768, 0.9459548, 0.9844166999999999], 
             UndirectedEdge[295, 297] -> 
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996], 
             UndirectedEdge[17, 30] -> 
             RGBColor[0.948374, 0.9604212000000001, 0.9515823], 
             UndirectedEdge[22, 273] -> 
             RGBColor[
              0.9792046999999999, 0.9810076000000001, 0.7454220999999996], 
             UndirectedEdge[86, 165] -> 
             RGBColor[0.9916771, 0.9903468, 0.7527422999999998], 
             UndirectedEdge[124, 200] -> 
             RGBColor[0.42440360000000016`, 0.5420188000000001, 0.9482636], 
             UndirectedEdge[198, 258] -> 
             RGBColor[0.737166, 0.793625, 0.9666853], 
             UndirectedEdge[177, 217] -> 
             RGBColor[0.8357493000000001, 0.868519, 0.7574477999999996], 
             UndirectedEdge[52, 110] -> 
             RGBColor[
              0.9832574999999999, 0.9633175999999999, 0.6033612999999997], 
             UndirectedEdge[121, 299] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999], 
             UndirectedEdge[173, 196] -> 
             RGBColor[0.9911213, 0.989158, 0.6922468999999996], 
             UndirectedEdge[238, 251] -> 
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999], 
             UndirectedEdge[218, 284] -> 
             RGBColor[0.8471658, 0.8812952000000001, 0.9764611], 
             UndirectedEdge[209, 276] -> 
             RGBColor[
              0.8310380000000002, 0.8680092000000001, 0.9400858999999999], 
             UndirectedEdge[8, 72] -> RGBColor[0.984192, 0.987731, 0.911643], 
             UndirectedEdge[56, 168] -> 
             RGBColor[0.927449, 0.9428848000000001, 0.9126168999999998], 
             UndirectedEdge[201, 257] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999], 
             UndirectedEdge[31, 51] -> 
             RGBColor[0.9525295, 0.9597422, 0.7084487999999999], 
             UndirectedEdge[53, 282] -> 
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993], 
             UndirectedEdge[17, 97] -> 
             RGBColor[0.7952200000000001, 0.8406994000000001, 0.9800252], 
             UndirectedEdge[102, 162] -> 
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996], 
             UndirectedEdge[36, 260] -> 
             RGBColor[0.9713409, 0.9551671999999999, 0.6565364999999999], 
             UndirectedEdge[79, 168] -> 
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999], 
             UndirectedEdge[142, 297] -> 
             RGBColor[
              0.9136839999999999, 0.6245997999999997, 0.36316119999999963`], 
             UndirectedEdge[232, 299] -> 
             RGBColor[0.7229105, 0.776718, 0.6877409999999999], 
             UndirectedEdge[50, 169] -> 
             RGBColor[0.9060226, 0.5626276, 0.41578779999999993`], 
             UndirectedEdge[92, 153] -> 
             RGBColor[
              0.8117499000000001, 0.7851895999999998, 0.6218140999999999], 
             UndirectedEdge[44, 299] -> 
             RGBColor[0.9525295, 0.9597422, 0.7084487999999999], 
             UndirectedEdge[90, 252] -> 
             RGBColor[0.5815595, 0.6465624999999999, 0.922572], 
             UndirectedEdge[7, 283] -> 
             RGBColor[0.9448581, 0.8566549999999999, 0.6014628], 
             UndirectedEdge[52, 179] -> 
             RGBColor[0.9318926, 0.7559209999999998, 0.2975492999999998], 
             UndirectedEdge[98, 296] -> 
             RGBColor[0.7952200000000001, 0.8406994000000001, 0.9800252], 
             UndirectedEdge[18, 88] -> 
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999], 
             UndirectedEdge[100, 240] -> 
             RGBColor[0.9908459999999999, 0.9904826, 0.8013689999999999], 
             UndirectedEdge[2, 214] -> 
             RGBColor[0.8174161, 0.6892822, 0.6010567], 
             UndirectedEdge[114, 169] -> 
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998], 
             UndirectedEdge[37, 295] -> 
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996], 
             UndirectedEdge[45, 225] -> 
             RGBColor[0.8431270000000001, 0.8777506, 0.9848994], 
             UndirectedEdge[38, 74] -> 
             RGBColor[0.9616423, 0.9479339999999998, 0.6729536999999999], 
             UndirectedEdge[38, 158] -> 
             RGBColor[0.9220785, 0.9166369999999999, 0.6778511999999999], 
             UndirectedEdge[69, 135] -> 
             RGBColor[0.9744934, 0.9804978, 0.9280602], 
             UndirectedEdge[113, 224] -> 
             RGBColor[0.9786489, 0.9798188, 0.6849266999999999], 
             UndirectedEdge[124, 282] -> 
             RGBColor[0.6945519000000002, 0.7528626, 0.7463939999999997], 
             UndirectedEdge[56, 79] -> 
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749], 
             UndirectedEdge[49, 146] -> 
             RGBColor[0.9293865, 0.9412886, 0.7062413999999999], 
             UndirectedEdge[47, 166] -> 
             RGBColor[0.904306, 0.9244312000000001, 0.9104094999999999], 
             UndirectedEdge[189, 197] -> 
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999], 
             UndirectedEdge[125, 256] -> 
             RGBColor[0.6366510000000001, 0.71318, 0.966399], 
             UndirectedEdge[69, 138] -> 
             RGBColor[0.988628, 0.9895654, 0.8381270000000001], 
             UndirectedEdge[170, 255] -> 
             RGBColor[0.7846728000000001, 0.8315526000000002, 0.9532445], 
             UndirectedEdge[41, 104] -> 
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999], 
             UndirectedEdge[185, 283] -> 
             RGBColor[
              0.9640328999999999, 0.9305155999999998, 0.6281462999999998], 
             UndirectedEdge[103, 277] -> 
             RGBColor[0.7749742000000002, 0.8243194000000001, 0.9696617], 
             UndirectedEdge[45, 282] -> 
             RGBColor[0.9299423, 0.9424774, 0.7667367999999997], 
             UndirectedEdge[222, 245] -> 
             RGBColor[0.9700618999999999, 0.9749632, 0.8223346999999999], 
             UndirectedEdge[53, 195] -> 
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996], 
             UndirectedEdge[121, 136] -> 
             RGBColor[
              0.8310380000000002, 0.8680092000000001, 0.9400858999999999], 
             UndirectedEdge[92, 211] -> 
             RGBColor[0.9290859, 0.8776015999999998, 0.6333104999999999], 
             UndirectedEdge[26, 137] -> 
             RGBColor[
              0.3954892000000001, 0.5169746000000001, 0.9464212000000001], 
             UndirectedEdge[139, 148] -> 
             RGBColor[0.7618303, 0.80979, 0.8117081999999999], 
             UndirectedEdge[69, 258] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[244, 272] -> 
             RGBColor[
              0.7996385000000001, 0.8404844000000001, 0.8146845999999999], 
             UndirectedEdge[100, 256] -> 
             RGBColor[0.9065240000000001, 0.9253484000000001, 0.8736515], 
             UndirectedEdge[29, 206] -> 
             RGBColor[0.870999, 0.8975960000000001, 0.8701107], 
             UndirectedEdge[101, 213] -> 
             RGBColor[0.8718300999999999, 0.8974602, 0.8214839999999999], 
             UndirectedEdge[39, 107] -> 
             RGBColor[0.9671219, 0.9058285999999998, 0.5566131999999998], 
             UndirectedEdge[134, 252] -> 
             RGBColor[0.9744934, 0.9804978, 0.9280602], 
             UndirectedEdge[14, 288] -> 
             RGBColor[
              0.7585534000000002, 0.8114760000000001, 0.9767665999999999], 
             UndirectedEdge[155, 202] -> 
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999], 
             UndirectedEdge[220, 228] -> 
             RGBColor[0.929667, 0.943802, 0.8758589], 
             UndirectedEdge[228, 266] -> 
             RGBColor[0.9155324, 0.9347344, 0.9657921], 
             UndirectedEdge[113, 249] -> 
             RGBColor[0.9789294, 0.9823322000000001, 0.8545442000000001], 
             UndirectedEdge[109, 179] -> 
             RGBColor[0.9397564, 0.7817613999999999, 0.38643489999999964`], 
             UndirectedEdge[41, 209] -> 
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999], 
             UndirectedEdge[76, 261] -> 
             RGBColor[0.9058337999999999, 0.9275012, 0.9822093], 
             UndirectedEdge[114, 219] -> 
             RGBColor[0.9786489, 0.9798188, 0.6849266999999999], 
             UndirectedEdge[130, 266] -> 
             RGBColor[0.8923894000000001, 0.9162808, 0.9635847], 
             UndirectedEdge[1, 185] -> 
             RGBColor[0.9737315, 0.9377487999999998, 0.6117290999999998], 
             UndirectedEdge[202, 208] -> 
             RGBColor[0.8307450000000001, 0.8684518, 0.9835659999999999], 
             UndirectedEdge[8, 285] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[65, 210] -> 
             RGBColor[
              0.9440961999999999, 0.8139059999999998, 0.28513169999999977`], 
             UndirectedEdge[63, 183] -> 
             RGBColor[0.8363051000000001, 0.8697078, 0.8179431999999999], 
             UndirectedEdge[51, 86] -> 
             RGBColor[0.9905655, 0.9879692, 0.6317514999999998], 
             UndirectedEdge[91, 191] -> 
             RGBColor[
              0.9062435000000001, 0.9228350000000001, 0.7040339999999998], 
             UndirectedEdge[122, 181] -> 
             RGBColor[0.641529, 0.7128422000000001, 0.9600241], 
             UndirectedEdge[17, 42] -> 
             RGBColor[0.9536411, 0.9621198, 0.8294395999999999], 
             UndirectedEdge[90, 253] -> 
             RGBColor[0.5718608999999999, 0.6393293, 0.9389892], 
             UndirectedEdge[60, 136] -> 
             RGBColor[0.7952200000000001, 0.8406994000000001, 0.9800252], 
             UndirectedEdge[80, 210] -> 
             RGBColor[
              0.9759494999999999, 0.9386659999999998, 0.5749710999999996], 
             UndirectedEdge[229, 259] -> 
             RGBColor[0.9927835, 0.9888863999999999, 0.5949935], 
             UndirectedEdge[97, 159] -> 
             RGBColor[0.7720770000000001, 0.8222458000000001, 0.9778178], 
             UndirectedEdge[242, 280] -> 
             RGBColor[
              0.9452214999999999, 0.9350905999999999, 0.6800585999999998], 
             UndirectedEdge[88, 99] -> 
             RGBColor[0.659794, 0.7316336, 0.9686064], UndirectedEdge[21, 46] -> 
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749], 
             UndirectedEdge[246, 256] -> 
             RGBColor[0.8989355000000001, 0.8981834, 0.6756437999999998], 
             UndirectedEdge[14, 135] -> 
             RGBColor[0.9386753999999999, 0.953188, 0.9679995], 
             UndirectedEdge[67, 179] -> 
             RGBColor[0.9372631, 0.7821688, 0.5323149999999999], 
             UndirectedEdge[66, 69] -> 
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998], 
             UndirectedEdge[94, 237] -> 
             RGBColor[0.7618303, 0.80979, 0.8117081999999999], 
             UndirectedEdge[116, 133] -> 
             RGBColor[0.8351935000000001, 0.8673302, 0.6969523999999998], 
             UndirectedEdge[2, 83] -> 
             RGBColor[0.866563, 0.8957615999999999, 0.9436267], 
             UndirectedEdge[103, 168] -> 
             RGBColor[
              0.7965894000000001, 0.8397030000000001, 0.9000692999999999], 
             UndirectedEdge[26, 199] -> 
             RGBColor[0.42440360000000016`, 0.5420188000000001, 0.9482636], 
             UndirectedEdge[91, 239] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999], 
             UndirectedEdge[13, 298] -> 
             RGBColor[0.8351935000000001, 0.8673302, 0.6969523999999998], 
             UndirectedEdge[229, 261] -> 
             RGBColor[
              0.9689502999999999, 0.9725855999999999, 0.7013438999999999], 
             UndirectedEdge[141, 179] -> 
             RGBColor[0.9156479, 0.7667852, 0.6019074], 
             UndirectedEdge[59, 195] -> 
             RGBColor[0.866563, 0.8957615999999999, 0.9436267], 
             UndirectedEdge[134, 253] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[42, 292] -> 
             RGBColor[0.7240221, 0.7790956, 0.8087317999999999], 
             UndirectedEdge[70, 238] -> 
             RGBColor[0.9350451, 0.7812516, 0.5690729999999999], 
             UndirectedEdge[178, 202] -> 
             RGBColor[
              0.9452214999999999, 0.9350905999999999, 0.6800585999999997], 
             UndirectedEdge[29, 191] -> 
             RGBColor[0.9065240000000001, 0.9253484000000001, 0.8736515], 
             UndirectedEdge[17, 38] -> 
             RGBColor[
              0.9452214999999999, 0.9350905999999999, 0.6800585999999998], 
             UndirectedEdge[40, 162] -> 
             RGBColor[0.866563, 0.8957615999999999, 0.9436267], 
             UndirectedEdge[13, 95] -> 
             RGBColor[0.8707185, 0.8950826, 0.7004931999999999], 
             UndirectedEdge[206, 270] -> 
             RGBColor[0.601126, 0.6854275999999999, 0.9628582], 
             UndirectedEdge[16, 295] -> 
             RGBColor[0.988628, 0.9895654, 0.8381270000000001], 
             UndirectedEdge[37, 124] -> 
             RGBColor[0.6945519000000001, 0.7528626, 0.7463939999999997], 
             UndirectedEdge[22, 177] -> 
             RGBColor[0.8357493000000001, 0.868519, 0.7574477999999996], 
             UndirectedEdge[115, 204] -> 
             RGBColor[0.9789294, 0.9823322000000001, 0.8545442000000001], 
             UndirectedEdge[192, 200] -> 
             RGBColor[0.6366510000000001, 0.71318, 0.966399], 
             UndirectedEdge[13, 171] -> 
             RGBColor[0.9905655, 0.9879692, 0.6317514999999998], 
             UndirectedEdge[39, 52] -> 
             RGBColor[
              0.9617513999999999, 0.8795807999999996, 0.32184749999999973`], 
             UndirectedEdge[92, 216] -> 
             RGBColor[0.9693398999999999, 0.9067457999999998, 0.5198552], 
             UndirectedEdge[82, 127] -> 
             RGBColor[0.8363051000000001, 0.8697078, 0.8179431999999999], 
             UndirectedEdge[53, 150] -> 
             RGBColor[0.9911213, 0.989158, 0.6922468999999996], 
             UndirectedEdge[18, 66] -> 
             RGBColor[0.9536411, 0.9621198, 0.8294395999999999], 
             UndirectedEdge[31, 36] -> 
             RGBColor[0.9386753999999999, 0.953188, 0.9679995], 
             UndirectedEdge[71, 181] -> 
             RGBColor[0.9453976, 0.9587982, 0.9773118], 
             UndirectedEdge[43, 143] -> 
             RGBColor[0.927449, 0.9428848000000001, 0.9126168999999998], 
             UndirectedEdge[75, 185] -> 
             RGBColor[0.9379135, 0.9104389999999998, 0.6516683999999997], 
             UndirectedEdge[46, 145] -> 
             RGBColor[0.5815595, 0.6465625, 0.922572], 
             UndirectedEdge[62, 255] -> 
             RGBColor[0.7985269000000002, 0.8381068, 0.6936937999999999], 
             UndirectedEdge[111, 242] -> 
             RGBColor[0.9386753999999999, 0.953188, 0.9679995], 
             UndirectedEdge[4, 193] -> 
             RGBColor[0.737166, 0.793625, 0.9666853], UndirectedEdge[18, 258] -> 
             RGBColor[0.9289768, 0.9459548, 0.9844166999999999], 
             UndirectedEdge[81, 267] -> 
             RGBColor[0.9065240000000001, 0.9253484000000001, 0.8736515], 
             UndirectedEdge[75, 124] -> 
             RGBColor[0.6540226000000001, 0.7250430000000001, 0.9689714], 
             UndirectedEdge[72, 106] -> 
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996], 
             UndirectedEdge[262, 271] -> 
             RGBColor[0.9530853, 0.960931, 0.7689441999999996], 
             UndirectedEdge[17, 235] -> 
             RGBColor[0.7207452000000001, 0.7807816000000001, 0.9737902], 
             UndirectedEdge[263, 279] -> 
             RGBColor[0.7720770000000001, 0.8222458000000001, 0.9778178], 
             UndirectedEdge[3, 252] -> 
             RGBColor[0.988628, 0.9895654, 0.8381270000000001], 
             UndirectedEdge[48, 158] -> 
             RGBColor[0.9155324, 0.9347344, 0.9657921], 
             UndirectedEdge[18, 36] -> 
             RGBColor[0.9386753999999999, 0.953188, 0.9679995], 
             UndirectedEdge[105, 196] -> 
             RGBColor[
              0.7965894000000001, 0.8397030000000001, 0.9000692999999999], 
             UndirectedEdge[269, 298] -> 
             RGBColor[0.7952200000000001, 0.8406994000000001, 0.9800252], 
             UndirectedEdge[85, 207] -> 
             RGBColor[0.948374, 0.9604212000000001, 0.9515823], 
             UndirectedEdge[79, 103] -> 
             RGBColor[0.7943714000000002, 0.8387858000000001, 0.9368273], 
             UndirectedEdge[76, 128] -> 
             RGBColor[0.9220785, 0.9166369999999999, 0.6778511999999998], 
             UndirectedEdge[10, 265] -> 
             RGBColor[0.9253465, 0.7740184, 0.5854902], 
             UndirectedEdge[88, 198] -> 
             RGBColor[0.6976022, 0.762328, 0.9715828], 
             UndirectedEdge[63, 143] -> 
             RGBColor[0.9916771, 0.9903468, 0.7527422999999998], 
             UndirectedEdge[49, 242] -> 
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999], 
             UndirectedEdge[252, 253] -> 
             RGBColor[0.9744934, 0.9804978, 0.9280602], 
             UndirectedEdge[16, 125] -> 
             RGBColor[0.723191, 0.7792314, 0.8573585], 
             UndirectedEdge[59, 100] -> 
             RGBColor[0.870999, 0.8975960000000001, 0.8701107], 
             UndirectedEdge[75, 295] -> 
             RGBColor[0.948374, 0.9604212000000001, 0.9515823], 
             UndirectedEdge[94, 295] -> 
             RGBColor[0.7565632, 0.8080914, 0.9338508999999999], 
             UndirectedEdge[26, 192] -> 
             RGBColor[0.6366510000000001, 0.71318, 0.966399], 
             UndirectedEdge[132, 188] -> 
             RGBColor[0.9060226, 0.5626276, 0.41578779999999993`], 
             UndirectedEdge[186, 196] -> 
             RGBColor[0.950592, 0.9613384, 0.9148242999999998], 
             UndirectedEdge[110, 179] -> 
             RGBColor[0.9372631, 0.7821688, 0.5323149999999999], 
             UndirectedEdge[61, 177] -> 
             RGBColor[0.7720770000000001, 0.8222458000000001, 0.9778178], 
             UndirectedEdge[21, 264] -> 
             RGBColor[0.9293865, 0.9412886, 0.7062413999999999], 
             UndirectedEdge[200, 225] -> 
             RGBColor[0.6366510000000001, 0.71318, 0.966399], 
             UndirectedEdge[83, 197] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[220, 226] -> 
             RGBColor[0.870999, 0.8975960000000001, 0.8701107], 
             UndirectedEdge[13, 140] -> 
             RGBColor[0.8351935000000001, 0.8673302, 0.6969523999999998], 
             UndirectedEdge[144, 158] -> 
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749], 
             UndirectedEdge[62, 225] -> 
             RGBColor[
              0.9062435000000001, 0.9228350000000001, 0.7040339999999998], 
             UndirectedEdge[65, 277] -> 
             RGBColor[0.9351594999999999, 0.8494218, 0.61788], 
             UndirectedEdge[99, 261] -> 
             RGBColor[0.6993578, 0.7629306, 0.9637089], 
             UndirectedEdge[260, 290] -> 
             RGBColor[
              0.9452214999999999, 0.9350905999999999, 0.6800585999999997], 
             UndirectedEdge[72, 267] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[39, 170] -> 
             RGBColor[0.9552052999999999, 0.8976781999999999, 0.6097884], 
             UndirectedEdge[92, 163] -> 
             RGBColor[
              0.9455066999999999, 0.8904449999999998, 0.6262055999999999], 
             UndirectedEdge[102, 133] -> 
             RGBColor[0.8357493000000001, 0.868519, 0.7574477999999996], 
             UndirectedEdge[184, 197] -> 
             RGBColor[0.9744934, 0.9804978, 0.9280602], 
             UndirectedEdge[44, 200] -> 
             RGBColor[0.682937, 0.7500872000000001, 0.9708138], 
             UndirectedEdge[115, 132] -> 
             RGBColor[0.9051914999999999, 0.5627634, 0.4644145], 
             UndirectedEdge[9, 283] -> 
             RGBColor[0.7846728000000001, 0.8315526000000002, 0.9532445], 
             UndirectedEdge[52, 165] -> 
             RGBColor[0.9863066, 0.9640989999999998, 0.5179765999999997], 
             UndirectedEdge[160, 256] -> 
             RGBColor[
              0.8662700000000001, 0.8962042000000001, 0.9871068000000001], 
             UndirectedEdge[45, 215] -> 
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999], 
             UndirectedEdge[16, 124] -> 
             RGBColor[0.6942766000000001, 0.7541872000000001, 0.8555161], 
             UndirectedEdge[160, 246] -> 
             RGBColor[
              0.9452214999999999, 0.9350905999999999, 0.6800585999999998], 
             UndirectedEdge[57, 204] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[112, 252] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[5, 248] -> 
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749], 
             UndirectedEdge[186, 276] -> 
             RGBColor[0.7952200000000001, 0.8406994000000001, 0.9800252], 
             UndirectedEdge[95, 154] -> 
             RGBColor[0.748934, 0.8037922, 0.9756104], 
             UndirectedEdge[198, 290] -> 
             RGBColor[0.7207452000000001, 0.7807816000000001, 0.9737902], 
             UndirectedEdge[77, 191] -> 
             RGBColor[0.7122674000000002, 0.7745688000000002, 0.9723518], 
             UndirectedEdge[36, 224] -> 
             RGBColor[0.9786489, 0.9798188, 0.6849266999999999], 
             UndirectedEdge[29, 203] -> 
             RGBColor[0.9789294, 0.9823322000000001, 0.8545442000000001], 
             UndirectedEdge[25, 172] -> 
             RGBColor[0.9528099999999999, 0.9622556, 0.8780663], 
             UndirectedEdge[224, 260] -> 
             RGBColor[0.985195, 0.9617213999999998, 0.3969857999999997], 
             UndirectedEdge[45, 255] -> 
             RGBColor[0.7354104000000001, 0.7930224000000001, 0.9745592], 
             UndirectedEdge[102, 239] -> 
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996], 
             UndirectedEdge[33, 239] -> 
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749], 
             UndirectedEdge[64, 92] -> 
             RGBColor[0.9693398999999999, 0.9067457999999998, 0.5198552], 
             UndirectedEdge[32, 268] -> 
             RGBColor[0.7818911000000002, 0.6615298000000001, 0.5975159], 
             UndirectedEdge[85, 240] -> 
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999], 
             UndirectedEdge[1, 174] -> 
             RGBColor[0.9744934, 0.9804978, 0.9280602], 
             UndirectedEdge[2, 184] -> 
             RGBColor[0.8568644, 0.8885284, 0.9600439000000001], 
             UndirectedEdge[60, 85] -> 
             RGBColor[0.948374, 0.9604212000000001, 0.9515823], 
             UndirectedEdge[121, 127] -> 
             RGBColor[
              0.8310380000000002, 0.8680092000000001, 0.9400858999999999], 
             UndirectedEdge[132, 212] -> 
             RGBColor[0.6064041000000001, 0.3255508000000001, 0.5553196], 
             UndirectedEdge[172, 206] -> 
             RGBColor[0.870999, 0.8975960000000001, 0.8701107], 
             UndirectedEdge[147, 148] -> 
             RGBColor[0.9598238, 0.8655868, 0.4629028999999999], 
             UndirectedEdge[118, 226] -> 
             RGBColor[0.866563, 0.8957615999999999, 0.9436267], 
             UndirectedEdge[75, 283] -> 
             RGBColor[0.9386753999999999, 0.953188, 0.9679995], 
             UndirectedEdge[188, 243] -> 
             RGBColor[0.9536411, 0.9621198, 0.8294395999999999], 
             UndirectedEdge[88, 258] -> 
             RGBColor[0.9058337999999999, 0.9275012, 0.9822093], 
             UndirectedEdge[197, 293] -> 
             RGBColor[0.988628, 0.9895654, 0.8381270000000001], 
             UndirectedEdge[86, 179] -> 
             RGBColor[0.9372631, 0.7821688, 0.5323149999999999], 
             UndirectedEdge[41, 76] -> 
             RGBColor[0.927449, 0.9428848000000001, 0.9126168999999998], 
             UndirectedEdge[175, 242] -> 
             RGBColor[0.9530853, 0.960931, 0.7689441999999996], 
             UndirectedEdge[89, 285] -> 
             RGBColor[0.9550962, 0.9660314000000001, 0.9608946], 
             UndirectedEdge[138, 171] -> 
             RGBColor[0.9908459999999999, 0.9904826, 0.8013689999999999], 
             UndirectedEdge[181, 207] -> 
             RGBColor[0.9289768, 0.9459548, 0.9844166999999999], 
             UndirectedEdge[17, 55] -> 
             RGBColor[0.682937, 0.7500872000000001, 0.9708138], 
             UndirectedEdge[142, 295] -> 
             RGBColor[0.9089727, 0.6240899999999998, 0.5457992999999999], 
             UndirectedEdge[53, 200] -> 
             RGBColor[0.7234663, 0.7779068, 0.7482363999999997], 
             UndirectedEdge[33, 237] -> 
             RGBColor[0.9304981, 0.9436662, 0.8272321999999999], 
             UndirectedEdge[51, 67] -> 
             RGBColor[0.9905655, 0.9879692, 0.6317514999999998], 
             UndirectedEdge[47, 48] -> 
             RGBColor[0.8923894000000001, 0.9162808, 0.9635847], 
             UndirectedEdge[102, 237] -> 
             RGBColor[0.9941704, 0.9899394, 0.6068621999999995], 
             UndirectedEdge[150, 282] -> 
             RGBColor[0.9911213, 0.989158, 0.6922468999999996], 
             UndirectedEdge[214, 293] -> 
             RGBColor[0.9394811, 0.783086, 0.495557], UndirectedEdge[73, 245] -> 
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998], 
             UndirectedEdge[82, 192] -> 
             RGBColor[0.9073551000000001, 0.9252126, 0.8250247999999999], 
             UndirectedEdge[82, 266] -> 
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998], 
             UndirectedEdge[30, 38] -> 
             RGBColor[0.9810395, 0.9624003999999999, 0.6401192999999998], 
             UndirectedEdge[146, 242] -> 
             RGBColor[0.9525295, 0.9597422, 0.7084488], 
             UndirectedEdge[25, 77] -> 
             RGBColor[
              0.7585534000000002, 0.8114760000000001, 0.9767665999999999], 
             UndirectedEdge[68, 271] -> 
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999], 
             UndirectedEdge[23, 267] -> 
             RGBColor[0.904306, 0.9244312000000001, 0.9104094999999999], 
             UndirectedEdge[10, 161] -> 
             RGBColor[0.8213394, 0.8607760000000001, 0.9565030999999999], 
             UndirectedEdge[223, 287] -> 
             RGBColor[0.7612745000000001, 0.8086012, 0.7512127999999996], 
             UndirectedEdge[9, 11] -> 
             RGBColor[0.7749742000000002, 0.8243194000000001, 0.9696617], 
             UndirectedEdge[218, 229] -> 
             RGBColor[
              0.9689502999999999, 0.9725855999999999, 0.7013438999999999], 
             UndirectedEdge[62, 170] -> 
             RGBColor[0.9786489, 0.9798188, 0.6849266999999999], 
             UndirectedEdge[188, 294] -> 
             RGBColor[0.9700618999999999, 0.9749632, 0.8223346999999999], 
             UndirectedEdge[181, 299] -> 
             RGBColor[
              0.9689502999999999, 0.9725855999999999, 0.7013438999999999], 
             UndirectedEdge[69, 109] -> 
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996], 
             UndirectedEdge[48, 175] -> 
             RGBColor[
              0.9792046999999999, 0.9810076000000001, 0.7454220999999996], 
             UndirectedEdge[248, 270] -> 
             RGBColor[0.659794, 0.7316336, 0.9686064], 
             UndirectedEdge[85, 232] -> 
             RGBColor[0.718755, 0.777397, 0.9308745], UndirectedEdge[65, 152] -> 
             RGBColor[0.8955957, 0.8181248, 0.6227775], 
             UndirectedEdge[43, 63] -> 
             RGBColor[0.9304981, 0.9436662, 0.8272321999999999], 
             UndirectedEdge[184, 293] -> 
             RGBColor[0.9789294, 0.9823322000000001, 0.8545442000000001], 
             UndirectedEdge[24, 260] -> 
             RGBColor[
              0.9832574999999999, 0.9633175999999999, 0.6033612999999997], 
             UndirectedEdge[201, 229] -> 
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998], 
             UndirectedEdge[17, 48] -> 
             RGBColor[0.9386753999999999, 0.953188, 0.9679995], 
             UndirectedEdge[153, 163] -> 
             RGBColor[0.8116408000000002, 0.8535428, 0.9729203], 
             UndirectedEdge[33, 200] -> 
             RGBColor[0.659794, 0.7316336, 0.9686064], 
             UndirectedEdge[33, 282] -> 
             RGBColor[0.9299423, 0.9424774, 0.7667367999999997], 
             UndirectedEdge[150, 237] -> 
             RGBColor[0.9916771, 0.9903468, 0.7527422999999998], 
             UndirectedEdge[172, 203] -> 
             RGBColor[0.9789294, 0.9823322000000001, 0.8545442000000001], 
             UndirectedEdge[56, 93] -> 
             RGBColor[0.9293865, 0.9412886, 0.7062413999999999], 
             UndirectedEdge[122, 299] -> 
             RGBColor[0.6650817, 0.7266296000000001, 0.6840561999999999], 
             UndirectedEdge[44, 100] -> 
             RGBColor[0.9528099999999999, 0.9622556, 0.8780663], 
             UndirectedEdge[31, 171] -> 
             RGBColor[0.950592, 0.9613384, 0.9148242999999998], 
             UndirectedEdge[136, 256] -> 
             RGBColor[0.7489340000000002, 0.8037922000000002, 0.9756104], 
             UndirectedEdge[146, 159] -> 
             RGBColor[0.9293865, 0.9412886, 0.7062413999999999], 
             UndirectedEdge[65, 133] -> 
             RGBColor[0.8014027000000001, 0.7441664000000001, 0.6134885], 
             UndirectedEdge[58, 245] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[172, 272] -> 
             RGBColor[0.7988074000000001, 0.8406202000000002, 0.8633113], 
             UndirectedEdge[99, 218] -> 
             RGBColor[0.6993578, 0.7629306, 0.9637089], 
             UndirectedEdge[18, 113] -> 
             RGBColor[0.9386753999999999, 0.953188, 0.9679995], 
             UndirectedEdge[43, 131] -> 
             RGBColor[0.8760840999999999, 0.7354882, 0.6068049], 
             UndirectedEdge[2, 156] -> 
             RGBColor[0.8712743000000001, 0.8962714, 0.7609885999999997], 
             UndirectedEdge[165, 232] -> 
             RGBColor[0.7240221, 0.7790956, 0.8087317999999999], 
             UndirectedEdge[173, 186] -> 
             RGBColor[0.9530853, 0.960931, 0.7689441999999996], 
             UndirectedEdge[39, 281] -> 
             RGBColor[0.8827999, 0.8406943999999998, 0.6288957], 
             UndirectedEdge[77, 91] -> 
             RGBColor[0.7985269000000002, 0.8381068, 0.6936937999999999], 
             UndirectedEdge[15, 19] -> 
             RGBColor[0.8307450000000001, 0.8684518, 0.9835659999999999], 
             UndirectedEdge[119, 241] -> 
             RGBColor[0.4711056000000002, 0.5783634000000002, 0.952374], 
             UndirectedEdge[103, 116] -> 
             RGBColor[0.7985269000000002, 0.8381068, 0.6936937999999999], 
             UndirectedEdge[99, 257] -> 
             RGBColor[0.718755, 0.777397, 0.9308745], UndirectedEdge[17, 253] -> 
             RGBColor[0.9386753999999999, 0.953188, 0.9679995], 
             UndirectedEdge[204, 292] -> 
             RGBColor[0.7090564, 0.7701638, 0.9472917000000001], 
             UndirectedEdge[65, 241] -> 
             RGBColor[0.7647361000000001, 0.7149430000000001, 0.6102299], 
             UndirectedEdge[71, 256] -> 
             RGBColor[0.8826908, 0.9090476000000001, 0.9800019], 
             UndirectedEdge[37, 102] -> 
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993], 
             UndirectedEdge[61, 217] -> 
             RGBColor[0.9299423, 0.9424774, 0.7667367999999997], 
             UndirectedEdge[35, 184] -> 
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998], 
             UndirectedEdge[164, 241] -> 
             RGBColor[
              0.7750833000000001, 0.7559661999999999, 0.6185554999999999], 
             UndirectedEdge[192, 255] -> 
             RGBColor[0.7122674000000002, 0.7745688000000002, 0.9723518], 
             UndirectedEdge[112, 134] -> 
             RGBColor[0.9550962, 0.9660314000000001, 0.9608946], 
             UndirectedEdge[44, 195] -> 
             RGBColor[0.948374, 0.9604212000000001, 0.9515823], 
             UndirectedEdge[127, 281] -> 
             RGBColor[0.7489340000000002, 0.8037922000000002, 0.9756104], 
             UndirectedEdge[59, 192] -> 
             RGBColor[0.784459, 0.8315446, 0.9791512], 
             UndirectedEdge[108, 264] -> 
             RGBColor[0.9786489, 0.9798188, 0.6849266999999999], 
             UndirectedEdge[136, 296] -> 
             RGBColor[0.7952200000000001, 0.8406994000000001, 0.9800252], 
             UndirectedEdge[118, 130] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[85, 136] -> 
             RGBColor[
              0.8310380000000002, 0.8680092000000001, 0.9400858999999999], 
             UndirectedEdge[104, 157] -> 
             RGBColor[0.866563, 0.8957615999999999, 0.9436267], 
             UndirectedEdge[158, 217] -> 
             RGBColor[0.9299423, 0.9424774, 0.7667367999999997], 
             UndirectedEdge[11, 174] -> 
             RGBColor[0.9550962, 0.9660314000000001, 0.9608946], 
             UndirectedEdge[39, 220] -> 
             RGBColor[0.9693398999999999, 0.9067457999999998, 0.5198552], 
             UndirectedEdge[32, 208] -> 
             RGBColor[0.7134090000000002, 0.7760398000000001, 0.9720696], 
             UndirectedEdge[27, 103] -> 
             RGBColor[0.7354104000000001, 0.7930224000000001, 0.9745592], 
             UndirectedEdge[212, 250] -> 
             RGBColor[0.6945519000000002, 0.7528626, 0.7463939999999997], 
             UndirectedEdge[129, 298] -> 
             RGBColor[0.8357493000000001, 0.868519, 0.7574477999999996], 
             UndirectedEdge[107, 179] -> 
             RGBColor[0.9372631, 0.7821688, 0.5323149999999999], 
             UndirectedEdge[261, 290] -> 
             RGBColor[0.9289768, 0.9459548, 0.9844166999999999], 
             UndirectedEdge[24, 113] -> 
             RGBColor[0.9767113999999999, 0.981415, 0.8913021999999999], 
             UndirectedEdge[15, 243] -> 
             RGBColor[0.8307450000000001, 0.8684518, 0.9835659999999999], 
             UndirectedEdge[246, 296] -> 
             RGBColor[
              0.9452214999999999, 0.9350905999999999, 0.6800585999999997], 
             UndirectedEdge[131, 174] -> 
             RGBColor[0.9253465, 0.7740184, 0.5854902], 
             UndirectedEdge[44, 121] -> 
             RGBColor[0.948374, 0.9604212000000001, 0.9515823], 
             UndirectedEdge[155, 293] -> 
             RGBColor[0.929667, 0.943802, 0.8758589], 
             UndirectedEdge[105, 140] -> 
             RGBColor[0.6412174000000003, 0.7190640000000001, 0.9652702], 
             UndirectedEdge[51, 138] -> 
             RGBColor[0.9927835, 0.9888863999999999, 0.5949935], 
             UndirectedEdge[133, 277] -> 
             RGBColor[0.8116408000000002, 0.8535428, 0.9729203], 
             UndirectedEdge[201, 261] -> 
             RGBColor[
              0.9689502999999999, 0.9725855999999999, 0.7013438999999999], 
             UndirectedEdge[19, 57] -> 
             RGBColor[0.9386753999999999, 0.953188, 0.9679995], 
             UndirectedEdge[104, 261] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[15, 111] -> 
             RGBColor[0.8568644, 0.8885284, 0.9600439000000001], 
             UndirectedEdge[71, 85] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[84, 158] -> 
             RGBColor[0.8760840999999999, 0.7354882, 0.6068049], 
             UndirectedEdge[65, 162] -> 
             RGBColor[0.9545566999999999, 0.8638882, 0.5850455999999999], 
             UndirectedEdge[156, 268] -> 
             RGBColor[0.9397564, 0.7817613999999999, 0.38643489999999964`], 
             UndirectedEdge[48, 252] -> 
             RGBColor[0.9744934, 0.9804978, 0.9280602], 
             UndirectedEdge[204, 235] -> 
             RGBColor[0.7468646, 0.8008582, 0.9502681], 
             UndirectedEdge[62, 130] -> 
             RGBColor[
              0.9062435000000001, 0.9228350000000001, 0.7040339999999998], 
             UndirectedEdge[142, 283] -> 
             RGBColor[0.8992741, 0.6168567999999998, 0.5622164999999999], 
             UndirectedEdge[99, 259] -> 
             RGBColor[0.7231909999999999, 0.7792314, 0.8573585], 
             UndirectedEdge[43, 244] -> 
             RGBColor[0.9304981, 0.9436662, 0.8272321999999999], 
             UndirectedEdge[36, 154] -> 
             RGBColor[0.8568644, 0.8885284, 0.9600439000000001], 
             UndirectedEdge[11, 185] -> 
             RGBColor[0.9543343, 0.9232823999999997, 0.6445634999999997], 
             UndirectedEdge[20, 150] -> 
             RGBColor[
              0.7965894000000001, 0.8397030000000001, 0.9000692999999999], 
             UndirectedEdge[175, 252] -> 
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996], 
             UndirectedEdge[97, 292] -> 
             RGBColor[0.5656010000000001, 0.6576752000000001, 0.9593174], 
             UndirectedEdge[176, 226] -> 
             RGBColor[0.868781, 0.8966788, 0.9068686999999999], 
             UndirectedEdge[80, 103] -> 
             RGBColor[
              0.7965894000000001, 0.8397030000000001, 0.9000692999999999], 
             UndirectedEdge[137, 220] -> 
             RGBColor[0.6653622, 0.7291430000000001, 0.8536737000000001], 
             UndirectedEdge[20, 167] -> 
             RGBColor[0.7846728000000001, 0.8315526000000002, 0.9532445], 
             UndirectedEdge[240, 256] -> 
             RGBColor[0.904306, 0.9244312000000001, 0.9104094999999999], 
             UndirectedEdge[113, 278] -> 
             RGBColor[0.9386753999999999, 0.953188, 0.9679995], 
             UndirectedEdge[181, 240] -> 
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998], 
             UndirectedEdge[7, 151] -> 
             RGBColor[0.9054097999999999, 0.6574088, 0.2424756], 
             UndirectedEdge[6, 101] -> 
             RGBColor[
              0.8472748999999999, 0.8129419999999998, 0.6253548999999999], 
             UndirectedEdge[65, 116] -> 
             RGBColor[0.9587122, 0.8632092, 0.34191209999999994`], 
             UndirectedEdge[50, 264] -> 
             RGBColor[0.904911, 0.5602499999999999, 0.29479699999999986`], 
             UndirectedEdge[55, 235] -> 
             RGBColor[0.49112620000000007`, 0.5977574, 0.9530824], 
             UndirectedEdge[100, 232] -> 
             RGBColor[0.723191, 0.7792314, 0.8573585], 
             UndirectedEdge[28, 163] -> 
             RGBColor[0.9550962, 0.9660314000000001, 0.9608946], 
             UndirectedEdge[11, 63] -> 
             RGBColor[0.9700618999999999, 0.9749632, 0.8223346999999999], 
             UndirectedEdge[234, 274] -> 
             RGBColor[0.9916771, 0.9903468, 0.7527422999999998], 
             UndirectedEdge[148, 270] -> 
             RGBColor[0.7240221, 0.7790956, 0.8087317999999999], 
             UndirectedEdge[96, 245] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[159, 235] -> 
             RGBColor[0.6976022, 0.762328, 0.9715828], 
             UndirectedEdge[53, 287] -> 
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993], 
             UndirectedEdge[105, 289] -> 
             RGBColor[0.6767424000000002, 0.7468164000000002, 0.968811], 
             UndirectedEdge[56, 164] -> 
             RGBColor[
              0.9059428999999999, 0.8591479999999998, 0.6311030999999999], 
             UndirectedEdge[112, 235] -> 
             RGBColor[0.737166, 0.793625, 0.9666853], UndirectedEdge[7, 43] -> 
             RGBColor[0.8955957, 0.8181248, 0.6227775], 
             UndirectedEdge[242, 243] -> 
             RGBColor[0.912556, 0.9331114, 0.9915216], 
             UndirectedEdge[151, 286] -> 
             RGBColor[0.6696081, 0.5709176, 0.5883045], 
             UndirectedEdge[126, 163] -> 
             RGBColor[0.9700618999999999, 0.9749632, 0.8223346999999999], 
             UndirectedEdge[31, 138] -> 
             RGBColor[0.9528099999999999, 0.9622556, 0.8780663], 
             UndirectedEdge[95, 138] -> 
             RGBColor[0.870999, 0.8975960000000001, 0.8701107], 
             UndirectedEdge[197, 275] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[198, 245] -> 
             RGBColor[0.737166, 0.793625, 0.9666853], 
             UndirectedEdge[187, 264] -> 
             RGBColor[0.9936146, 0.9887505999999999, 0.5463667999999998], 
             UndirectedEdge[62, 195] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999], 
             UndirectedEdge[169, 187] -> 
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998], 
             UndirectedEdge[82, 199] -> 
             RGBColor[0.6951077000000001, 0.7540514, 0.8068894], 
             UndirectedEdge[126, 155] -> 
             RGBColor[0.9304981, 0.9436662, 0.8272321999999999], 
             UndirectedEdge[82, 220] -> 
             RGBColor[0.9938951, 0.991264, 0.7159842999999999], 
             UndirectedEdge[32, 202] -> 
             RGBColor[0.7952200000000001, 0.8406994000000001, 0.9800252], 
             UndirectedEdge[113, 260] -> 
             RGBColor[0.9713409, 0.9551671999999999, 0.6565364999999999], 
             UndirectedEdge[105, 230] -> 
             RGBColor[
              0.7965894000000001, 0.8397030000000001, 0.9000692999999999], 
             UndirectedEdge[245, 289] -> 
             RGBColor[0.8471658, 0.8812952000000001, 0.9764611], 
             UndirectedEdge[108, 187] -> 
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998], 
             UndirectedEdge[137, 228] -> 
             RGBColor[0.6019652, 0.6815452000000001, 0.9649216], 
             UndirectedEdge[88, 261] -> 
             RGBColor[0.9058337999999999, 0.9275012, 0.9822093], 
             UndirectedEdge[192, 228] -> 
             RGBColor[0.8431270000000001, 0.8777506, 0.9848994], 
             UndirectedEdge[42, 97] -> 
             RGBColor[0.8363051000000001, 0.8697078, 0.8179431999999999], 
             UndirectedEdge[121, 240] -> 
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999], 
             UndirectedEdge[25, 43] -> 
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999], 
             UndirectedEdge[77, 270] -> 
             RGBColor[0.5289344000000001, 0.6284518000000001, 0.9560588], 
             UndirectedEdge[225, 255] -> 
             RGBColor[0.7122674000000002, 0.7745688000000002, 0.9723518], 
             UndirectedEdge[2, 275] -> 
             RGBColor[0.866563, 0.8957615999999999, 0.9436267], 
             UndirectedEdge[235, 253] -> 
             RGBColor[0.7468646, 0.8008582, 0.9502681], 
             UndirectedEdge[73, 95] -> 
             RGBColor[0.868781, 0.8966788, 0.9068686999999999], 
             UndirectedEdge[49, 175] -> 
             RGBColor[0.9299423, 0.9424774, 0.7667367999999997], 
             UndirectedEdge[153, 219] -> 
             RGBColor[0.8351935000000001, 0.8673302, 0.6969523999999999], 
             UndirectedEdge[54, 167] -> 
             RGBColor[0.9386753999999999, 0.953188, 0.9679995], 
             UndirectedEdge[56, 246] -> 
             RGBColor[0.9220785, 0.9166369999999999, 0.6778511999999998], 
             UndirectedEdge[192, 225] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[84, 252] -> 
             RGBColor[0.9350451, 0.7812516, 0.5690729999999999], 
             UndirectedEdge[119, 164] -> 
             RGBColor[0.6416381, 0.6444889999999999, 0.6089179], 
             UndirectedEdge[93, 168] -> 
             RGBColor[0.9905655, 0.9879692, 0.6317514999999998], 
             UndirectedEdge[111, 250] -> 
             RGBColor[
              0.9792046999999999, 0.9810076000000001, 0.7454220999999996], 
             UndirectedEdge[54, 286] -> 
             RGBColor[0.682937, 0.7500872000000001, 0.9708138], 
             UndirectedEdge[74, 257] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[220, 236] -> 
             RGBColor[0.988628, 0.9895654, 0.8381270000000001], 
             UndirectedEdge[130, 228] -> 
             RGBColor[0.8431270000000001, 0.8777506, 0.9848994], 
             UndirectedEdge[1, 142] -> 
             RGBColor[0.9089727, 0.6240899999999998, 0.5457993], 
             UndirectedEdge[101, 114] -> 
             RGBColor[0.8568644, 0.8885284, 0.9600439000000001], 
             UndirectedEdge[199, 266] -> 
             RGBColor[0.680142, 0.7451196000000001, 0.9454493], 
             UndirectedEdge[93, 277] -> 
             RGBColor[
              0.9689502999999999, 0.9725855999999999, 0.7013438999999999], 
             UndirectedEdge[19, 112] -> 
             RGBColor[0.9289768, 0.9459548, 0.9844166999999999], 
             UndirectedEdge[77, 203] -> 
             RGBColor[0.7846728000000001, 0.8315526000000002, 0.9532445], 
             UndirectedEdge[26, 60] -> 
             RGBColor[0.682937, 0.7500872000000001, 0.9708138], 
             UndirectedEdge[186, 263] -> 
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999], 
             UndirectedEdge[167, 283] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[170, 200] -> 
             RGBColor[0.7090564, 0.7701638, 0.9472917000000001], 
             UndirectedEdge[17, 292] -> 
             RGBColor[0.682937, 0.7500872000000001, 0.9708138], 
             UndirectedEdge[106, 215] -> 
             RGBColor[0.9530853, 0.960931, 0.7689441999999996], 
             UndirectedEdge[123, 229] -> 
             RGBColor[0.7607187, 0.8074124, 0.6907173999999999], 
             UndirectedEdge[105, 149] -> 
             RGBColor[0.7543889000000001, 0.6739198, 0.6019043], 
             UndirectedEdge[68, 274] -> 
             RGBColor[0.927449, 0.9428848000000001, 0.9126168999999998], 
             UndirectedEdge[149, 171] -> 
             RGBColor[0.9464275, 0.8237821999999999, 0.5399619999999998], 
             UndirectedEdge[29, 172] -> 
             RGBColor[0.993064, 0.9913998, 0.764611], UndirectedEdge[76, 209] -> 
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749], 
             UndirectedEdge[247, 267] -> 
             RGBColor[0.8827999, 0.8406943999999998, 0.6288957], 
             UndirectedEdge[164, 210] -> 
             RGBColor[
              0.9544433999999999, 0.8549291999999995, 0.2934572999999997], 
             UndirectedEdge[258, 260] -> 
             RGBColor[0.9616423, 0.9479339999999998, 0.6729536999999998], 
             UndirectedEdge[62, 137] -> 
             RGBColor[0.6650817, 0.7266296, 0.6840561999999999], 
             UndirectedEdge[175, 280] -> 
             RGBColor[
              0.9857507999999999, 0.9629101999999998, 0.4574811999999995], 
             UndirectedEdge[72, 194] -> 
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999], 
             UndirectedEdge[3, 257] -> 
             RGBColor[0.988628, 0.9895654, 0.8381270000000001], 
             UndirectedEdge[154, 171] -> 
             RGBColor[0.868781, 0.8966788, 0.9068686999999999], 
             UndirectedEdge[168, 277] -> 
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998], 
             UndirectedEdge[146, 243] -> 
             RGBColor[0.9525295, 0.9597422, 0.7084488], 
             UndirectedEdge[98, 122] -> 
             RGBColor[
              0.5077722000000002, 0.6075868000000001, 0.9556325999999999], 
             UndirectedEdge[142, 210] -> 
             RGBColor[
              0.8985121999999999, 0.5741077999999995, 0.24588539999999973`], 
             UndirectedEdge[3, 38] -> 
             RGBColor[0.9854755, 0.9642347999999998, 0.5666032999999998], 
             UndirectedEdge[21, 205] -> 
             RGBColor[0.86627, 0.8962042, 0.9871068], 
             UndirectedEdge[153, 221] -> 
             RGBColor[
              0.8310380000000002, 0.8680092000000001, 0.9400858999999999], 
             UndirectedEdge[55, 159] -> 
             RGBColor[0.659794, 0.7316336, 0.9686064], 
             UndirectedEdge[149, 298] -> 
             RGBColor[0.7910555000000001, 0.7031432, 0.6051629], 
             UndirectedEdge[22, 247] -> 
             RGBColor[0.9696152, 0.9054211999999998, 0.4107330999999996], 
             UndirectedEdge[105, 298] -> 
             RGBColor[0.6412174000000003, 0.7190640000000001, 0.9652702], 
             UndirectedEdge[169, 219] -> 
             RGBColor[0.9936146, 0.9887505999999999, 0.5463667999999998], 
             UndirectedEdge[53, 225] -> 
             RGBColor[
              0.9067993000000001, 0.9240238000000001, 0.7645293999999996], 
             UndirectedEdge[47, 90] -> 
             RGBColor[0.49945550000000005`, 0.5823455000000001, 0.9580965], 
             UndirectedEdge[100, 137] -> 
             RGBColor[0.6653622, 0.7291430000000001, 0.8536737000000001], 
             UndirectedEdge[15, 175] -> 
             RGBColor[0.8712743000000001, 0.8962714, 0.7609885999999997], 
             UndirectedEdge[49, 253] -> 
             RGBColor[0.9155324, 0.9347344, 0.9657921], 
             UndirectedEdge[166, 291] -> 
             RGBColor[0.9908459999999999, 0.9904826, 0.8013689999999999], 
             UndirectedEdge[161, 230] -> 
             RGBColor[
              0.8332560000000001, 0.8689264000000001, 0.9033278999999999], 
             UndirectedEdge[263, 269] -> 
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999], 
             UndirectedEdge[122, 160] -> 
             RGBColor[0.6251082000000001, 0.6999988, 0.967129], 
             UndirectedEdge[196, 289] -> 
             RGBColor[0.868781, 0.8966788, 0.9068686999999999], 
             UndirectedEdge[30, 158] -> 
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749], 
             UndirectedEdge[114, 187] -> 
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998], 
             UndirectedEdge[49, 159] -> 
             RGBColor[0.86627, 0.8962042, 0.9871068], UndirectedEdge[33, 94] -> 
             RGBColor[0.6976022, 0.762328, 0.9715828], 
             UndirectedEdge[193, 220] -> 
             RGBColor[0.7609992, 0.8099258, 0.8603349], 
             UndirectedEdge[60, 127] -> 
             RGBColor[0.7952200000000001, 0.8406994000000001, 0.9800252], 
             UndirectedEdge[282, 297] -> 
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993], 
             UndirectedEdge[97, 235] -> 
             RGBColor[0.6034092000000002, 0.6883696000000001, 0.9622938], 
             UndirectedEdge[50, 187] -> 
             RGBColor[0.9060226, 0.5626276, 0.41578779999999993`], 
             UndirectedEdge[271, 274] -> 
             RGBColor[0.950592, 0.9613384, 0.9148242999999998], 
             UndirectedEdge[137, 170] -> 
             RGBColor[0.6512276, 0.7200754, 0.9436069], 
             UndirectedEdge[84, 253] -> 
             RGBColor[0.9253465, 0.7740184, 0.5854902], 
             UndirectedEdge[33, 185] -> 
             RGBColor[
              0.9147704999999999, 0.8919853999999998, 0.6494609999999997], 
             UndirectedEdge[3, 144] -> 
             RGBColor[0.988628, 0.9895654, 0.8381270000000001], 
             UndirectedEdge[11, 43] -> 
             RGBColor[0.9058337999999999, 0.9275012, 0.9822093], 
             UndirectedEdge[29, 272] -> 
             RGBColor[0.7988074000000001, 0.8406202000000002, 0.8633113], 
             UndirectedEdge[70, 251] -> 
             RGBColor[0.9372631, 0.7821688, 0.5323149999999999], 
             UndirectedEdge[99, 123] -> 
             RGBColor[0.49112620000000007`, 0.5977574, 0.9530824], 
             UndirectedEdge[133, 239] -> 
             RGBColor[
              0.8310380000000002, 0.8680092000000001, 0.9400858999999999], 
             UndirectedEdge[259, 260] -> 
             RGBColor[0.9854755, 0.9642347999999998, 0.5666032999999998], 
             UndirectedEdge[125, 192] -> 
             RGBColor[0.6366510000000001, 0.71318, 0.966399], 
             UndirectedEdge[213, 264] -> 
             RGBColor[0.9936146, 0.9887505999999999, 0.5463667999999998], 
             UndirectedEdge[134, 204] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[94, 142] -> 
             RGBColor[0.6813439, 0.44445039999999975`, 0.5680071999999999], 
             UndirectedEdge[134, 175] -> 
             RGBColor[
              0.9792046999999999, 0.9810076000000001, 0.7454220999999996], 
             UndirectedEdge[8, 267] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[195, 225] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[51, 281] -> 
             RGBColor[
              0.9062435000000001, 0.9228350000000001, 0.7040339999999998], 
             UndirectedEdge[49, 243] -> 
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999], 
             UndirectedEdge[212, 243] -> 
             RGBColor[0.6540226000000002, 0.7250430000000001, 0.9689714], 
             UndirectedEdge[22, 285] -> 
             RGBColor[0.9695061, 0.9737744, 0.7618392999999997], 
             UndirectedEdge[20, 33] -> 
             RGBColor[0.7354104000000001, 0.7930224000000001, 0.9745592], 
             UndirectedEdge[9, 174] -> 
             RGBColor[0.7846728000000001, 0.8315526000000002, 0.9532445], 
             UndirectedEdge[180, 250] -> 
             RGBColor[
              0.9792046999999999, 0.9810076000000001, 0.7454220999999996], 
             UndirectedEdge[92, 221] -> 
             RGBColor[0.9649038999999999, 0.9049113999999998, 0.5933712], 
             UndirectedEdge[71, 232] -> 
             RGBColor[0.6993578, 0.7629306, 0.9637089], 
             UndirectedEdge[25, 148] -> 
             RGBColor[0.9536411, 0.9621198, 0.8294395999999999], 
             UndirectedEdge[76, 218] -> 
             RGBColor[0.9058337999999999, 0.9275012, 0.9822093], 
             UndirectedEdge[20, 200] -> 
             RGBColor[0.5289344000000001, 0.6284518000000001, 0.9560588], 
             UndirectedEdge[68, 255] -> 
             RGBColor[0.7354104000000001, 0.7930224000000001, 0.9745592], 
             UndirectedEdge[30, 123] -> 
             RGBColor[0.7565632, 0.8080914, 0.9338508999999999], 
             UndirectedEdge[113, 290] -> 
             RGBColor[0.9386753999999999, 0.953188, 0.9679995], 
             UndirectedEdge[230, 269] -> 
             RGBColor[0.950592, 0.9613384, 0.9148242999999998], 
             UndirectedEdge[7, 54] -> 
             RGBColor[0.9187387, 0.8365784, 0.6249849000000001], 
             UndirectedEdge[71, 296] -> 
             RGBColor[0.9289768, 0.9459548, 0.9844166999999999], 
             UndirectedEdge[37, 237] -> 
             RGBColor[0.9941704, 0.9899394, 0.6068621999999995], 
             UndirectedEdge[8, 217] -> 
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996], 
             UndirectedEdge[39, 100] -> 
             RGBColor[0.9693398999999999, 0.9067457999999998, 0.5198552], 
             UndirectedEdge[35, 216] -> 
             RGBColor[0.9938951, 0.991264, 0.7159842999999999], 
             UndirectedEdge[48, 253] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[72, 247] -> 
             RGBColor[0.9649038999999999, 0.9049113999999998, 0.5933712], 
             UndirectedEdge[24, 254] -> 
             RGBColor[0.9911213, 0.989158, 0.6922468999999996], 
             UndirectedEdge[247, 273] -> 
             RGBColor[0.9552052999999999, 0.8976781999999999, 0.6097884], 
             UndirectedEdge[80, 152] -> 
             RGBColor[0.927449, 0.9428848000000001, 0.9126168999999998], 
             UndirectedEdge[121, 125] -> 
             RGBColor[0.718755, 0.777397, 0.9308745], UndirectedEdge[8, 177] -> 
             RGBColor[
              0.8310380000000002, 0.8680092000000001, 0.9400858999999999], 
             UndirectedEdge[38, 253] -> 
             RGBColor[0.9713409, 0.9551671999999999, 0.6565364999999999], 
             UndirectedEdge[134, 292] -> 
             RGBColor[0.7090564, 0.7701638, 0.9472917000000001], 
             UndirectedEdge[19, 177] -> 
             RGBColor[0.7952200000000001, 0.8406994000000001, 0.9800252], 
             UndirectedEdge[219, 221] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999], 
             UndirectedEdge[37, 185] -> 
             RGBColor[0.9784428, 0.9382585999999997, 0.4290909999999994], 
             UndirectedEdge[15, 280] -> 
             RGBColor[0.8634105, 0.8704309999999998, 0.6721029999999998], 
             UndirectedEdge[140, 171] -> 
             RGBColor[
              0.8332560000000001, 0.8689264000000001, 0.9033278999999999], 
             UndirectedEdge[211, 221] -> 
             RGBColor[0.948374, 0.9604212000000001, 0.9515823], 
             UndirectedEdge[47, 273] -> 
             RGBColor[0.8923894000000001, 0.9162808, 0.9635847], 
             UndirectedEdge[58, 171] -> 
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999], 
             UndirectedEdge[75, 150] -> 
             RGBColor[0.950592, 0.9613384, 0.9148242999999998], 
             UndirectedEdge[9, 167] -> 
             RGBColor[0.7846728000000001, 0.8315526000000002, 0.9532445], 
             UndirectedEdge[135, 260] -> 
             RGBColor[0.9713409, 0.9551671999999999, 0.6565364999999999], 
             UndirectedEdge[184, 202] -> 
             RGBColor[0.9386753999999999, 0.953188, 0.9679995], 
             UndirectedEdge[166, 262] -> 
             RGBColor[0.9911213, 0.989158, 0.6922468999999996], 
             UndirectedEdge[173, 276] -> 
             RGBColor[0.8357493000000001, 0.868519, 0.7574477999999996], 
             UndirectedEdge[67, 86] -> 
             RGBColor[0.988628, 0.9895654, 0.8381269999999997], 
             UndirectedEdge[25, 272] -> 
             RGBColor[
              0.7585534000000002, 0.8114760000000001, 0.9767665999999999], 
             UndirectedEdge[7, 174] -> 
             RGBColor[0.9448581, 0.8566549999999999, 0.6014628], 
             UndirectedEdge[88, 113] -> 
             RGBColor[0.9155324, 0.9347344, 0.9657921], 
             UndirectedEdge[147, 206] -> 
             RGBColor[0.8369276999999999, 0.7719187999999999, 0.6170293], 
             UndirectedEdge[189, 211] -> 
             RGBColor[0.950592, 0.9613384, 0.9148242999999998], 
             UndirectedEdge[104, 209] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[151, 167] -> 
             RGBColor[0.9253465, 0.7740184, 0.5854902], 
             UndirectedEdge[215, 274] -> 
             RGBColor[0.950592, 0.9613384, 0.9148242999999998], 
             UndirectedEdge[41, 261] -> 
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998], 
             UndirectedEdge[157, 218] -> 
             RGBColor[0.8471658, 0.8812952000000001, 0.9764611], 
             UndirectedEdge[187, 205] -> 
             RGBColor[0.9304981, 0.9436662, 0.8272321999999999], 
             UndirectedEdge[62, 82] -> 
             RGBColor[0.9936146, 0.9887505999999999, 0.5463667999999998], 
             UndirectedEdge[42, 144] -> 
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998], 
             UndirectedEdge[33, 150] -> 
             RGBColor[0.927449, 0.9428848000000001, 0.9126168999999998], 
             UndirectedEdge[34, 46] -> RGBColor[0.984192, 0.987731, 0.911643],
              UndirectedEdge[220, 266] -> 
             RGBColor[0.9789294, 0.9823322000000001, 0.8545442000000001], 
             UndirectedEdge[128, 279] -> 
             RGBColor[0.8278855, 0.8426785999999999, 0.6685621999999998], 
             UndirectedEdge[147, 270] -> 
             RGBColor[0.6891197, 0.6535542, 0.6042771], 
             UndirectedEdge[30, 90] -> 
             RGBColor[0.5815595, 0.6465625, 0.922572], 
             UndirectedEdge[36, 222] -> 
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998], 
             UndirectedEdge[127, 170] -> 
             RGBColor[0.8213394, 0.8607760000000001, 0.9565030999999999], 
             UndirectedEdge[1, 295] -> RGBColor[0.984192, 0.987731, 0.911643],
              UndirectedEdge[96, 140] -> 
             RGBColor[
              0.8310380000000002, 0.8680092000000001, 0.9400858999999999], 
             UndirectedEdge[206, 272] -> 
             RGBColor[0.6767424000000002, 0.7468164000000002, 0.968811], 
             UndirectedEdge[129, 265] -> 
             RGBColor[0.9397564, 0.7817613999999999, 0.38643489999999964`], 
             UndirectedEdge[39, 60] -> 
             RGBColor[0.9290859, 0.8776015999999998, 0.6333104999999999], 
             UndirectedEdge[71, 240] -> 
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998], 
             UndirectedEdge[30, 144] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[26, 59] -> 
             RGBColor[0.601126, 0.6854275999999999, 0.9628582], 
             UndirectedEdge[133, 241] -> 
             RGBColor[0.6412174000000003, 0.7190640000000001, 0.9652702], 
             UndirectedEdge[236, 266] -> 
             RGBColor[0.9744934, 0.9804978, 0.9280602], 
             UndirectedEdge[28, 216] -> 
             RGBColor[0.9789294, 0.9823322000000001, 0.8545442000000001], 
             UndirectedEdge[173, 230] -> 
             RGBColor[0.9911213, 0.989158, 0.6922468999999996], 
             UndirectedEdge[39, 266] -> 
             RGBColor[0.9552052999999999, 0.8976781999999999, 0.6097884], 
             UndirectedEdge[86, 141] -> 
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998], 
             UndirectedEdge[25, 206] -> 
             RGBColor[0.8307450000000001, 0.8684518, 0.9835659999999999], 
             UndirectedEdge[141, 165] -> 
             RGBColor[0.9700618999999999, 0.9749632, 0.8223346999999999], 
             UndirectedEdge[152, 241] -> 
             RGBColor[0.7354104000000001, 0.7930224000000001, 0.9745592], 
             UndirectedEdge[110, 141] -> 
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998], 
             UndirectedEdge[97, 134] -> 
             RGBColor[0.8213394, 0.8607760000000001, 0.9565030999999999], 
             UndirectedEdge[103, 119] -> 
             RGBColor[0.4711056000000002, 0.5783634000000002, 0.952374], 
             UndirectedEdge[3, 17] -> 
             RGBColor[0.9528099999999999, 0.9622556, 0.8780663], 
             UndirectedEdge[203, 270] -> 
             RGBColor[0.7090564, 0.7701638, 0.9472917000000001], 
             UndirectedEdge[51, 141] -> 
             RGBColor[
              0.9689502999999999, 0.9725855999999999, 0.7013438999999999], 
             UndirectedEdge[184, 275] -> 
             RGBColor[0.9744934, 0.9804978, 0.9280602], 
             UndirectedEdge[58, 109] -> 
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996], 
             UndirectedEdge[179, 281] -> 
             RGBColor[0.8529411, 0.7170346000000001, 0.6045975], 
             UndirectedEdge[31, 154] -> 
             RGBColor[0.8307450000000001, 0.8684518, 0.9835659999999999], 
             UndirectedEdge[122, 296] -> 
             RGBColor[0.6251082000000001, 0.6999988, 0.967129], 
             UndirectedEdge[96, 290] -> 
             RGBColor[0.948374, 0.9604212000000001, 0.9515823], 
             UndirectedEdge[122, 240] -> 
             RGBColor[
              0.6631442000000001, 0.7282258000000001, 0.8904316999999999], 
             UndirectedEdge[97, 144] -> 
             RGBColor[
              0.8310380000000002, 0.8680092000000001, 0.9400858999999999], 
             UndirectedEdge[61, 247] -> 
             RGBColor[
              0.9059428999999999, 0.8591479999999998, 0.6311030999999999], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.7990827000000001, 0.8392956000000001, 0.7541891999999997], 
             UndirectedEdge[45, 287] -> 
             RGBColor[0.9299423, 0.9424774, 0.7667367999999997], 
             UndirectedEdge[278, 290] -> 
             RGBColor[0.912556, 0.9331114, 0.9915216], 
             UndirectedEdge[109, 110] -> 
             RGBColor[0.9911213, 0.989158, 0.6922468999999996], 
             UndirectedEdge[56, 160] -> 
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999], 
             UndirectedEdge[146, 292] -> 
             RGBColor[0.7229105, 0.776718, 0.6877409999999999], 
             UndirectedEdge[131, 139] -> 
             RGBColor[0.7074163, 0.601612, 0.5912809], UndirectedEdge[47, 74] -> 
             RGBColor[0.8826908, 0.9090476000000001, 0.9800019], 
             UndirectedEdge[46, 221] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[48, 74] -> 
             RGBColor[0.9550962, 0.9660314000000001, 0.9608946], 
             UndirectedEdge[90, 134] -> 
             RGBColor[0.5718608999999999, 0.6393293, 0.9389892], 
             UndirectedEdge[1, 37] -> 
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996], 
             UndirectedEdge[33, 295] -> 
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749], 
             UndirectedEdge[28, 35] -> 
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998], 
             UndirectedEdge[21, 169] -> 
             RGBColor[0.9304981, 0.9436662, 0.8272321999999999], 
             UndirectedEdge[100, 228] -> 
             RGBColor[0.929667, 0.943802, 0.8758589], 
             UndirectedEdge[190, 250] -> 
             RGBColor[0.9397564, 0.7817613999999999, 0.3864348999999996], 
             UndirectedEdge[81, 180] -> 
             RGBColor[0.9789294, 0.9823322000000001, 0.8545442000000001], 
             UndirectedEdge[127, 141] -> 
             RGBColor[0.8116408000000002, 0.8535428, 0.9729203], 
             UndirectedEdge[143, 185] -> 
             RGBColor[
              0.9759494999999999, 0.9386659999999998, 0.5749710999999996], 
             UndirectedEdge[283, 295] -> 
             RGBColor[0.9744934, 0.9804978, 0.9280602], 
             UndirectedEdge[26, 100] -> 
             RGBColor[0.7231909999999999, 0.7792314, 0.8573585], 
             UndirectedEdge[242, 294] -> 
             RGBColor[0.9289768, 0.9459548, 0.9844166999999999], 
             UndirectedEdge[39, 228] -> 
             RGBColor[
              0.9059428999999999, 0.8591479999999998, 0.6311030999999999], 
             UndirectedEdge[39, 82] -> 
             RGBColor[
              0.9701709999999999, 0.9066099999999998, 0.47122849999999983`], 
             UndirectedEdge[109, 258] -> 
             RGBColor[0.9695061, 0.9737744, 0.7618392999999997], 
             UndirectedEdge[118, 199] -> 
             RGBColor[0.6898406000000001, 0.7523528000000002, 0.9290321], 
             UndirectedEdge[57, 115] -> 
             RGBColor[0.9789294, 0.9823322000000001, 0.8545442000000001], 
             UndirectedEdge[96, 222] -> 
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998], 
             UndirectedEdge[6, 108] -> 
             RGBColor[0.9552052999999999, 0.8976781999999999, 0.6097884], 
             UndirectedEdge[1, 9] -> 
             RGBColor[0.7943714000000002, 0.8387858000000001, 0.9368273], 
             UndirectedEdge[180, 190] -> 
             RGBColor[0.9253465, 0.7740184, 0.5854902], 
             UndirectedEdge[144, 253] -> 
             RGBColor[0.9744934, 0.9804978, 0.9280602], 
             UndirectedEdge[53, 192] -> 
             RGBColor[
              0.9067993000000001, 0.9240238000000001, 0.7645293999999996], 
             UndirectedEdge[85, 121] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[36, 278] -> 
             RGBColor[0.9386753999999999, 0.953188, 0.9679995], 
             UndirectedEdge[122, 207] -> 
             RGBColor[0.6251082000000001, 0.6999988, 0.967129], 
             UndirectedEdge[226, 228] -> 
             RGBColor[0.8076019999999999, 0.8499981999999999, 0.9813586], 
             UndirectedEdge[7, 143] -> 
             RGBColor[0.9567747, 0.8648054000000001, 0.5482875999999999], 
             UndirectedEdge[133, 164] -> 
             RGBColor[
              0.8117499000000001, 0.7851895999999998, 0.6218140999999999], 
             UndirectedEdge[7, 131] -> 
             RGBColor[0.9054097999999999, 0.6574088, 0.2424756], 
             UndirectedEdge[111, 280] -> 
             RGBColor[0.9713409, 0.9551671999999999, 0.6565364999999999], 
             UndirectedEdge[135, 224] -> 
             RGBColor[0.9786489, 0.9798188, 0.6849266999999999], 
             UndirectedEdge[91, 102] -> 
             RGBColor[0.9930588, 0.9875617999999999, 0.4858713999999995], 
             UndirectedEdge[200, 282] -> 
             RGBColor[0.7234663000000001, 0.7779068, 0.7482363999999997], 
             UndirectedEdge[106, 194] -> 
             RGBColor[0.9911213, 0.989158, 0.6922468999999996], 
             UndirectedEdge[38, 259] -> 
             RGBColor[0.9854755, 0.9642347999999998, 0.5666032999999998], 
             UndirectedEdge[36, 69] -> 
             RGBColor[0.9744934, 0.9804978, 0.9280602], 
             UndirectedEdge[64, 153] -> 
             RGBColor[0.835474, 0.8698436, 0.8665699], 
             UndirectedEdge[159, 175] -> 
             RGBColor[0.9299423, 0.9424774, 0.7667367999999997], 
             UndirectedEdge[94, 200] -> 
             RGBColor[0.49112620000000007`, 0.5977574, 0.9530824], 
             UndirectedEdge[88, 201] -> 
             RGBColor[0.9293865, 0.9412886, 0.7062413999999999], 
             UndirectedEdge[121, 232] -> 
             RGBColor[0.718755, 0.777397, 0.9308745], 
             UndirectedEdge[140, 289] -> 
             RGBColor[0.7134090000000002, 0.7760398000000001, 0.9720696], 
             UndirectedEdge[139, 244] -> 
             RGBColor[0.7618303, 0.80979, 0.8117081999999999], 
             UndirectedEdge[167, 174] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[185, 282] -> 
             RGBColor[0.9784428, 0.9382585999999997, 0.4290909999999994], 
             UndirectedEdge[236, 249] -> 
             RGBColor[0.988628, 0.9895654, 0.8381270000000001], 
             UndirectedEdge[137, 299] -> 
             RGBColor[0.6650817, 0.7266296000000001, 0.6840561999999999], 
             UndirectedEdge[201, 218] -> 
             RGBColor[
              0.9689502999999999, 0.9725855999999999, 0.7013438999999999], 
             UndirectedEdge[36, 109] -> 
             RGBColor[
              0.9792046999999999, 0.9810076000000001, 0.7454220999999996], 
             UndirectedEdge[4, 52] -> 
             RGBColor[0.9616423, 0.9479339999999998, 0.6729536999999998], 
             UndirectedEdge[5, 191] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[55, 134] -> 
             RGBColor[0.7090563999999999, 0.7701638, 0.9472917000000001], 
             UndirectedEdge[67, 69] -> 
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999], 
             UndirectedEdge[232, 256] -> 
             RGBColor[0.6366510000000001, 0.71318, 0.966399], 
             UndirectedEdge[185, 237] -> 
             RGBColor[
              0.9789985999999999, 0.9394473999999997, 0.48958639999999964`], 
             UndirectedEdge[28, 211] -> 
             RGBColor[0.9386753999999999, 0.953188, 0.9679995], 
             UndirectedEdge[85, 246] -> 
             RGBColor[0.9810395, 0.9624003999999999, 0.6401192999999998], 
             UndirectedEdge[26, 127] -> 
             RGBColor[0.5656010000000001, 0.6576752000000001, 0.9593174], 
             UndirectedEdge[91, 162] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999], 
             UndirectedEdge[112, 242] -> 
             RGBColor[0.9289768, 0.9459548, 0.9844166999999999], 
             UndirectedEdge[85, 122] -> 
             RGBColor[0.6609262, 0.7273086000000001, 0.9271897], 
             UndirectedEdge[63, 131] -> 
             RGBColor[
              0.9403121999999999, 0.7829501999999999, 0.4469302999999999], 
             UndirectedEdge[140, 222] -> 
             RGBColor[0.8363051000000001, 0.8697078, 0.8179431999999999], 
             UndirectedEdge[121, 256] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[171, 198] -> 
             RGBColor[0.7587812, 0.8090086000000001, 0.8970928999999999], 
             UndirectedEdge[10, 117] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[18, 290] -> 
             RGBColor[0.912556, 0.9331114, 0.9915216], 
             UndirectedEdge[207, 240] -> 
             RGBColor[0.950592, 0.9613384, 0.9148242999999998], 
             UndirectedEdge[219, 264] -> 
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998], 
             UndirectedEdge[78, 118] -> 
             RGBColor[
              0.9171898999999999, 0.6872509999999995, 0.5536680999999999], 
             UndirectedEdge[2, 208] -> 
             RGBColor[0.748934, 0.8037922, 0.9756104], 
             UndirectedEdge[34, 169] -> 
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998], 
             UndirectedEdge[35, 275] -> 
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998], 
             UndirectedEdge[157, 284] -> 
             RGBColor[0.748934, 0.8037922, 0.9756104], 
             UndirectedEdge[30, 259] -> 
             RGBColor[0.988628, 0.9895654, 0.8381270000000001], 
             UndirectedEdge[62, 192] -> 
             RGBColor[
              0.9062435000000001, 0.9228350000000001, 0.7040339999999998], 
             UndirectedEdge[95, 245] -> 
             RGBColor[0.8471658, 0.8812952000000001, 0.9764611], 
             UndirectedEdge[129, 230] -> 
             RGBColor[0.9911213, 0.989158, 0.6922468999999996], 
             UndirectedEdge[35, 92] -> 
             RGBColor[
              0.9701709999999999, 0.9066099999999998, 0.47122849999999983`], 
             UndirectedEdge[186, 279] -> 
             RGBColor[0.7952200000000001, 0.8406994000000001, 0.9800252], 
             UndirectedEdge[217, 233] -> 
             RGBColor[0.9933392999999999, 0.9900752, 0.6554888999999997], 
             UndirectedEdge[28, 293] -> 
             RGBColor[0.9789294, 0.9823322000000001, 0.8545442000000001], 
             UndirectedEdge[24, 233] -> 
             RGBColor[0.9908459999999999, 0.9904826, 0.8013689999999999], 
             UndirectedEdge[41, 229] -> 
             RGBColor[0.9905655, 0.9879692, 0.6317514999999998], 
             UndirectedEdge[197, 214] -> 
             RGBColor[0.9350451, 0.7812516, 0.5690729999999999], 
             UndirectedEdge[84, 144] -> 
             RGBColor[0.9350451, 0.7812516, 0.5690729999999999], 
             UndirectedEdge[101, 205] -> 
             RGBColor[0.8076019999999999, 0.8499981999999999, 0.9813586], 
             UndirectedEdge[7, 297] -> 
             RGBColor[0.959268, 0.864398, 0.40240749999999964`], 
             UndirectedEdge[30, 47] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[140, 298] -> 
             RGBColor[0.6778840000000003, 0.7482874000000002, 0.9685288], 
             UndirectedEdge[159, 252] -> 
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749], 
             UndirectedEdge[26, 195] -> 
             RGBColor[0.718755, 0.777397, 0.9308745], UndirectedEdge[43, 185] -> 
             RGBColor[
              0.9147704999999999, 0.8919853999999998, 0.6494609999999997], 
             UndirectedEdge[36, 95] -> 
             RGBColor[0.8568644, 0.8885284, 0.9600439000000001], 
             UndirectedEdge[6, 46] -> 
             RGBColor[0.9649038999999999, 0.9049113999999998, 0.5933712], 
             UndirectedEdge[148, 183] -> 
             RGBColor[0.8363051000000001, 0.8697078, 0.8179431999999999], 
             UndirectedEdge[222, 261] -> 
             RGBColor[0.9700618999999999, 0.9749632, 0.8223346999999999], 
             UndirectedEdge[64, 145] -> 
             RGBColor[0.5859955, 0.6483969, 0.849056], UndirectedEdge[8, 247] -> 
             RGBColor[0.9649038999999999, 0.9049113999999998, 0.5933712], 
             UndirectedEdge[122, 136] -> 
             RGBColor[
              0.5077722000000002, 0.6075868000000001, 0.9556325999999999], 
             UndirectedEdge[139, 206] -> 
             RGBColor[0.6389342, 0.7161219999999999, 0.9658346], 
             UndirectedEdge[65, 80] -> 
             RGBColor[0.9567747, 0.8648054000000001, 0.5482875999999999], 
             UndirectedEdge[171, 245] -> 
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998], 
             UndirectedEdge[137, 232] -> 
             RGBColor[
              0.3954892000000001, 0.5169746000000001, 0.9464212000000001], 
             UndirectedEdge[64, 221] -> 
             RGBColor[0.988628, 0.9895654, 0.8381270000000001], 
             UndirectedEdge[140, 263] -> 
             RGBColor[0.7720770000000001, 0.8222458000000001, 0.9778178], 
             UndirectedEdge[200, 295] -> 
             RGBColor[0.718755, 0.777397, 0.9308745], 
             UndirectedEdge[136, 232] -> 
             RGBColor[0.5656010000000001, 0.6576752000000001, 0.9593174], 
             UndirectedEdge[45, 68] -> 
             RGBColor[0.86627, 0.8962042, 0.9871068], 
             UndirectedEdge[224, 254] -> 
             RGBColor[0.9930588, 0.9875617999999999, 0.4858713999999995], 
             UndirectedEdge[148, 272] -> 
             RGBColor[
              0.7996385000000001, 0.8404844000000001, 0.8146845999999999], 
             UndirectedEdge[167, 185] -> 
             RGBColor[
              0.9640328999999999, 0.9305155999999998, 0.6281462999999998], 
             UndirectedEdge[59, 137] -> 
             RGBColor[0.5432972, 0.6353392, 0.9591734000000001], 
             UndirectedEdge[55, 97] -> 
             RGBColor[0.5656010000000001, 0.6576752000000001, 0.9593174], 
             UndirectedEdge[156, 202] -> 
             RGBColor[0.9530853, 0.960931, 0.7689441999999996], 
             UndirectedEdge[78, 176] -> 
             RGBColor[0.9194079, 0.6881681999999996, 0.5169100999999998], 
             UndirectedEdge[131, 143] -> 
             RGBColor[0.9372631, 0.7821688, 0.5323149999999999], 
             UndirectedEdge[230, 289] -> 
             RGBColor[0.868781, 0.8966788, 0.9068686999999999], 
             UndirectedEdge[35, 126] -> 
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998], 
             UndirectedEdge[147, 183] -> 
             RGBColor[0.8014027000000001, 0.7441664000000001, 0.6134885], 
             UndirectedEdge[66, 258] -> 
             RGBColor[0.9700618999999999, 0.9749632, 0.8223346999999999], 
             UndirectedEdge[60, 232] -> 
             RGBColor[0.682937, 0.7500872000000001, 0.9708138], 
             UndirectedEdge[39, 127] -> 
             RGBColor[
              0.8117499000000001, 0.7851895999999998, 0.6218140999999999], 
             UndirectedEdge[113, 258] -> 
             RGBColor[0.9550962, 0.9660314000000001, 0.9608946], 
             UndirectedEdge[45, 223] -> 
             RGBColor[0.6976022, 0.762328, 0.9715828], UndirectedEdge[40, 80] -> 
             RGBColor[0.868781, 0.8966788, 0.9068686999999999], 
             UndirectedEdge[18, 198] -> 
             RGBColor[0.7207452000000001, 0.7807816000000001, 0.9737902], 
             UndirectedEdge[13, 58] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999], 
             UndirectedEdge[16, 195] -> 
             RGBColor[0.988628, 0.9895654, 0.8381270000000001], 
             UndirectedEdge[17, 90] -> 
             RGBColor[0.5457415, 0.6192527, 0.9625113000000001], 
             UndirectedEdge[8, 273] -> 
             RGBColor[0.9744934, 0.9804978, 0.9280602], 
             UndirectedEdge[85, 256] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[149, 227] -> 
             RGBColor[0.8852484999999999, 0.7771016, 0.6144518999999999], 
             UndirectedEdge[182, 208] -> 
             RGBColor[0.870999, 0.8975960000000001, 0.8701107], 
             UndirectedEdge[82, 100] -> 
             RGBColor[0.9938951, 0.991264, 0.7159842999999999], 
             UndirectedEdge[227, 264] -> 
             RGBColor[0.9293865, 0.9412886, 0.7062413999999999], 
             UndirectedEdge[74, 259] -> 
             RGBColor[0.9692308, 0.975099, 0.8709614], 
             UndirectedEdge[96, 105] -> 
             RGBColor[0.7943714000000002, 0.8387858000000001, 0.9368273], 
             UndirectedEdge[60, 100] -> 
             RGBColor[0.9528099999999999, 0.9622556, 0.8780663], 
             UndirectedEdge[73, 87] -> 
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998], 
             UndirectedEdge[68, 223] -> 
             RGBColor[0.6976022, 0.762328, 0.9715828], 
             UndirectedEdge[162, 191] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[87, 149] -> 
             RGBColor[
              0.9248122999999999, 0.8083985999999999, 0.6095543999999999], 
             UndirectedEdge[60, 256] -> 
             RGBColor[
              0.8662700000000001, 0.8962042000000001, 0.9871068000000001], 
             UndirectedEdge[145, 169] -> 
             RGBColor[0.5868266, 0.6482611, 0.8004292999999999], 
             UndirectedEdge[144, 235] -> 
             RGBColor[0.7565632, 0.8080914, 0.9338508999999999], 
             UndirectedEdge[36, 88] -> 
             RGBColor[0.9155324, 0.9347344, 0.9657921], 
             UndirectedEdge[38, 123] -> 
             RGBColor[0.7534107, 0.7827607999999999, 0.6623271999999998], 
             UndirectedEdge[183, 244] -> 
             RGBColor[0.8363051000000001, 0.8697078, 0.8179431999999999], 
             UndirectedEdge[2, 32] -> 
             RGBColor[0.7134090000000002, 0.7760398000000001, 0.9720696], 
             UndirectedEdge[106, 151] -> 
             RGBColor[0.9397564, 0.7817613999999999, 0.38643489999999964`], 
             UndirectedEdge[164, 277] -> 
             RGBColor[
              0.9455066999999999, 0.8904449999999998, 0.6262055999999999], 
             UndirectedEdge[296, 299] -> 
             RGBColor[0.9525295, 0.9597422, 0.7084487999999999], 
             UndirectedEdge[75, 174] -> 
             RGBColor[0.9386753999999999, 0.953188, 0.9679995], 
             UndirectedEdge[31, 66] -> 
             RGBColor[0.9536411, 0.9621198, 0.8294395999999999], 
             UndirectedEdge[2, 268] -> 
             RGBColor[0.8174161, 0.6892822, 0.6010567], 
             UndirectedEdge[46, 264] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999], 
             UndirectedEdge[71, 160] -> 
             RGBColor[0.9289768, 0.9459548, 0.9844166999999999], 
             UndirectedEdge[50, 114] -> 
             RGBColor[0.8910568999999999, 0.5536958000000001, 0.5543477], 
             UndirectedEdge[126, 197] -> 
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998], 
             UndirectedEdge[265, 269] -> 
             RGBColor[0.8992271000000001, 0.7539418, 0.6090123], 
             UndirectedEdge[144, 257] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[86, 107] -> 
             RGBColor[0.988628, 0.9895654, 0.8381269999999997], 
             UndirectedEdge[149, 245] -> 
             RGBColor[
              0.9248122999999999, 0.8083985999999999, 0.6095543999999999], 
             UndirectedEdge[143, 283] -> 
             RGBColor[0.9767113999999999, 0.981415, 0.8913021999999999], 
             UndirectedEdge[66, 154] -> 
             RGBColor[0.8718300999999999, 0.8974602, 0.8214839999999999], 
             UndirectedEdge[57, 159] -> 
             RGBColor[0.9155324, 0.9347344, 0.9657921], 
             UndirectedEdge[7, 167] -> 
             RGBColor[0.9448581, 0.8566549999999999, 0.6014628], 
             UndirectedEdge[57, 89] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[122, 256] -> 
             RGBColor[0.5788222000000001, 0.6630916000000001, 0.9627142], 
             UndirectedEdge[39, 232] -> 
             RGBColor[0.6994669, 0.6945773999999998, 0.6126027], 
             UndirectedEdge[72, 286] -> 
             RGBColor[0.718755, 0.777397, 0.9308745], UndirectedEdge[71, 299] -> 
             RGBColor[
              0.9689502999999999, 0.9725855999999999, 0.7013438999999999], 
             UndirectedEdge[90, 158] -> 
             RGBColor[0.5225985, 0.6007990999999999, 0.9603039], 
             UndirectedEdge[52, 236] -> 
             RGBColor[0.9810395, 0.9624003999999999, 0.6401192999999998], 
             UndirectedEdge[17, 134] -> 
             RGBColor[0.9386753999999999, 0.953188, 0.9679995], 
             UndirectedEdge[54, 72] -> 
             RGBColor[0.948374, 0.9604212000000001, 0.9515823], 
             UndirectedEdge[170, 192] -> 
             RGBColor[0.8923894000000001, 0.9162808, 0.9635847], 
             UndirectedEdge[140, 198] -> 
             RGBColor[0.6034092000000002, 0.6883696000000001, 0.9622938], 
             UndirectedEdge[19, 89] -> 
             RGBColor[0.9386753999999999, 0.953188, 0.9679995], 
             UndirectedEdge[239, 295] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[51, 69] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999], 
             UndirectedEdge[186, 269] -> 
             RGBColor[0.912556, 0.9331114, 0.9915216], 
             UndirectedEdge[37, 282] -> 
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993], 
             UndirectedEdge[1, 239] -> RGBColor[0.984192, 0.987731, 0.911643],
              UndirectedEdge[59, 200] -> 
             RGBColor[0.601126, 0.6854275999999999, 0.9628582], 
             UndirectedEdge[145, 221] -> 
             RGBColor[0.5815595, 0.6465624999999999, 0.922572], 
             UndirectedEdge[75, 297] -> 
             RGBColor[0.9530853, 0.960931, 0.7689441999999996], 
             UndirectedEdge[142, 185] -> 
             RGBColor[
              0.8985121999999999, 0.5741077999999995, 0.24588539999999973`], 
             UndirectedEdge[36, 258] -> 
             RGBColor[0.9550962, 0.9660314000000001, 0.9608946], 
             UndirectedEdge[13, 289] -> 
             RGBColor[0.8707185, 0.8950826, 0.7004931999999999], 
             UndirectedEdge[53, 170] -> 
             RGBColor[
              0.9792046999999999, 0.9810076000000001, 0.7454220999999996], 
             UndirectedEdge[130, 226] -> 
             RGBColor[0.784459, 0.8315446, 0.9791512], 
             UndirectedEdge[224, 249] -> 
             RGBColor[0.9927835, 0.9888863999999999, 0.5949935], 
             UndirectedEdge[234, 271] -> 
             RGBColor[0.9536411, 0.9621198, 0.8294395999999999], 
             UndirectedEdge[78, 266] -> 
             RGBColor[
              0.9074912999999999, 0.6800177999999995, 0.5700852999999999], 
             UndirectedEdge[127, 232] -> 
             RGBColor[0.5656010000000001, 0.6576752000000001, 0.9593174], 
             UndirectedEdge[57, 292] -> 
             RGBColor[0.7090564, 0.7701638, 0.9472917000000001], 
             UndirectedEdge[52, 107] -> 
             RGBColor[
              0.9832574999999999, 0.9633175999999999, 0.6033612999999997], 
             UndirectedEdge[26, 130] -> 
             RGBColor[0.6366510000000001, 0.71318, 0.966399], 
             UndirectedEdge[51, 58] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999], 
             UndirectedEdge[192, 195] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[118, 266] -> 
             RGBColor[0.9744934, 0.9804978, 0.9280602], 
             UndirectedEdge[171, 289] -> 
             RGBColor[0.868781, 0.8966788, 0.9068686999999999], 
             UndirectedEdge[1, 283] -> 
             RGBColor[0.9744934, 0.9804978, 0.9280602], 
             UndirectedEdge[44, 59] -> 
             RGBColor[0.8307450000000001, 0.8684518, 0.9835659999999999], 
             UndirectedEdge[62, 127] -> 
             RGBColor[0.8351935000000001, 0.8673302, 0.6969523999999998], 
             UndirectedEdge[46, 219] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999], 
             UndirectedEdge[55, 252] -> 
             RGBColor[0.718755, 0.777397, 0.9308745], UndirectedEdge[55, 144] -> 
             RGBColor[0.718755, 0.777397, 0.9308745], 
             UndirectedEdge[160, 296] -> 
             RGBColor[0.912556, 0.9331114, 0.9915216], 
             UndirectedEdge[154, 179] -> 
             RGBColor[0.8174161, 0.6892822, 0.6010567], 
             UndirectedEdge[6, 145] -> 
             RGBColor[0.5622714, 0.5637428999999998, 0.6043002], 
             UndirectedEdge[132, 243] -> 
             RGBColor[0.8649375, 0.5336192, 0.5778698], 
             UndirectedEdge[53, 59] -> 
             RGBColor[0.8712743000000001, 0.8962714, 0.7609885999999997], 
             UndirectedEdge[4, 228] -> 
             RGBColor[0.9058337999999999, 0.9275012, 0.9822093], 
             UndirectedEdge[71, 98] -> 
             RGBColor[0.8116408000000002, 0.8535428, 0.9729203], 
             UndirectedEdge[201, 259] -> 
             RGBColor[0.9927835, 0.9888863999999999, 0.5949935], 
             UndirectedEdge[34, 187] -> 
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998], 
             UndirectedEdge[18, 260] -> 
             RGBColor[
              0.9452214999999999, 0.9350905999999999, 0.6800585999999998], 
             UndirectedEdge[263, 289] -> 
             RGBColor[0.8076019999999999, 0.8499981999999999, 0.9813586], 
             UndirectedEdge[173, 209] -> 
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996], 
             UndirectedEdge[4, 199] -> 
             RGBColor[0.6704434000000001, 0.7378864, 0.9618665], 
             UndirectedEdge[253, 292] -> 
             RGBColor[0.7090564, 0.7701638, 0.9472917000000001], 
             UndirectedEdge[128, 209] -> 
             RGBColor[0.9810395, 0.9624003999999999, 0.6401192999999998], 
             UndirectedEdge[44, 137] -> 
             RGBColor[0.6251082000000001, 0.6999988, 0.967129], 
             UndirectedEdge[129, 263] -> 
             RGBColor[0.9299423, 0.9424774, 0.7667367999999997], 
             UndirectedEdge[73, 289] -> 
             RGBColor[0.868781, 0.8966788, 0.9068686999999999], 
             UndirectedEdge[128, 276] -> 
             RGBColor[0.8278855, 0.8426785999999999, 0.6685621999999998], 
             UndirectedEdge[96, 196] -> 
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999], 
             UndirectedEdge[24, 224] -> 
             RGBColor[0.9905655, 0.9879692, 0.6317514999999998], 
             UndirectedEdge[88, 278] -> 
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999], 
             UndirectedEdge[158, 253] -> 
             RGBColor[0.9155324, 0.9347344, 0.9657921], 
             UndirectedEdge[67, 110] -> 
             RGBColor[0.988628, 0.9895654, 0.8381269999999997], 
             UndirectedEdge[155, 275] -> 
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749], 
             UndirectedEdge[101, 108] -> 
             RGBColor[0.8568644, 0.8885284, 0.9600439000000001], 
             UndirectedEdge[102, 210] -> 
             RGBColor[0.9784428, 0.9382585999999997, 0.4290909999999994], 
             UndirectedEdge[176, 199] -> 
             RGBColor[
              0.6920586000000001, 0.7532700000000001, 0.8922740999999998], 
             UndirectedEdge[62, 226] -> 
             RGBColor[0.8707185, 0.8950826, 0.7004931999999999], 
             UndirectedEdge[69, 113] -> 
             RGBColor[0.9744934, 0.9804978, 0.9280602], 
             UndirectedEdge[51, 258] -> 
             RGBColor[
              0.9689502999999999, 0.9725855999999999, 0.7013438999999999], 
             UndirectedEdge[30, 74] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[118, 228] -> 
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749], 
             UndirectedEdge[71, 121] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], UndirectedEdge[1, 20] -> 
             RGBColor[0.7943714000000002, 0.8387858000000001, 0.9368273], 
             UndirectedEdge[126, 293] -> 
             RGBColor[0.9938951, 0.991264, 0.7159842999999999], 
             UndirectedEdge[112, 159] -> 
             RGBColor[0.9058337999999999, 0.9275012, 0.9822093], 
             UndirectedEdge[17, 159] -> 
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999], 
             UndirectedEdge[139, 172] -> 
             RGBColor[0.7609992, 0.8099258, 0.8603349], 
             UndirectedEdge[47, 233] -> 
             RGBColor[0.9065240000000001, 0.9253484000000001, 0.8736515], 
             UndirectedEdge[98, 182] -> 
             RGBColor[0.835474, 0.8698436, 0.8665699], 
             UndirectedEdge[84, 159] -> 
             RGBColor[0.8760840999999999, 0.7354882, 0.6068049], 
             UndirectedEdge[118, 176] -> 
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999], 
             UndirectedEdge[18, 278] -> 
             RGBColor[0.912556, 0.9331114, 0.9915216], 
             UndirectedEdge[155, 197] -> 
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749], 
             UndirectedEdge[72, 215] -> 
             RGBColor[0.948374, 0.9604212000000001, 0.9515823], 
             UndirectedEdge[162, 239] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[139, 272] -> 
             RGBColor[0.5667426000000002, 0.6591462000000001, 0.9590352], 
             UndirectedEdge[9, 75] -> 
             RGBColor[
              0.7585534000000002, 0.8114760000000001, 0.9767665999999999], 
             UndirectedEdge[18, 254] -> 
             RGBColor[0.9530853, 0.960931, 0.7689441999999996], 
             UndirectedEdge[25, 244] -> 
             RGBColor[0.9536411, 0.9621198, 0.8294395999999999], 
             UndirectedEdge[30, 257] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[29, 270] -> 
             RGBColor[0.723191, 0.7792314, 0.8573585], 
             UndirectedEdge[73, 298] -> 
             RGBColor[
              0.8332560000000001, 0.8689264000000001, 0.9033278999999999], 
             UndirectedEdge[73, 96] -> 
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999], 
             UndirectedEdge[108, 205] -> 
             RGBColor[0.9155324, 0.9347344, 0.9657921], UndirectedEdge[9, 43] -> 
             RGBColor[0.7354104000000001, 0.7930224000000001, 0.9745592], 
             UndirectedEdge[151, 251] -> 
             RGBColor[0.9372631, 0.7821688, 0.5323149999999999], 
             UndirectedEdge[209, 279] -> 
             RGBColor[
              0.8310380000000002, 0.8680092000000001, 0.9400858999999999], 
             UndirectedEdge[53, 68] -> 
             RGBColor[0.9299423, 0.9424774, 0.7667367999999997], 
             UndirectedEdge[282, 295] -> 
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996], 
             UndirectedEdge[35, 197] -> 
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998], 
             UndirectedEdge[116, 168] -> 
             RGBColor[0.9905655, 0.9879692, 0.6317514999999998], 
             UndirectedEdge[27, 152] -> 
             RGBColor[0.86627, 0.8962042, 0.9871068], 
             UndirectedEdge[114, 231] -> 
             RGBColor[0.8568644, 0.8885284, 0.9600439000000001], 
             UndirectedEdge[83, 155] -> 
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749], 
             UndirectedEdge[62, 199] -> 
             RGBColor[0.6939961000000001, 0.7516738000000001, 0.6858986], 
             UndirectedEdge[96, 278] -> 
             RGBColor[0.948374, 0.9604212000000001, 0.9515823], 
             UndirectedEdge[2, 178] -> 
             RGBColor[0.8634105, 0.8704309999999998, 0.6721029999999998], 
             UndirectedEdge[6, 213] -> 
             RGBColor[
              0.9701709999999999, 0.9066099999999998, 0.47122849999999983`], 
             UndirectedEdge[79, 93] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999], 
             UndirectedEdge[270, 272] -> 
             RGBColor[0.5289344000000001, 0.6284518000000001, 0.9560588], 
             UndirectedEdge[161, 186] -> 
             RGBColor[0.7952200000000001, 0.8406994000000001, 0.9800252], 
             UndirectedEdge[189, 275] -> 
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999], 
             UndirectedEdge[260, 261] -> 
             RGBColor[0.9616423, 0.9479339999999998, 0.6729536999999999], 
             UndirectedEdge[195, 200] -> 
             RGBColor[0.718755, 0.777397, 0.9308745], UndirectedEdge[66, 110] -> 
             RGBColor[0.9916771, 0.9903468, 0.7527422999999998], 
             UndirectedEdge[63, 172] -> 
             RGBColor[0.9938951, 0.991264, 0.7159842999999999], 
             UndirectedEdge[4, 236] -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 
             UndirectedEdge[143, 167] -> 
             RGBColor[0.9767113999999999, 0.981415, 0.8913021999999999], 
             UndirectedEdge[135, 249] -> 
             RGBColor[0.9789294, 0.9823322000000001, 0.8545442000000001], 
             UndirectedEdge[135, 288] -> 
             RGBColor[0.7846728000000001, 0.8315526000000002, 0.9532445], 
             UndirectedEdge[83, 214] -> 
             RGBColor[0.9350451, 0.7812516, 0.5690729999999999], 
             UndirectedEdge[36, 290] -> 
             RGBColor[0.9386753999999999, 0.953188, 0.9679995], 
             UndirectedEdge[79, 119] -> 
             RGBColor[0.6609262, 0.7273086000000001, 0.9271897], 
             UndirectedEdge[145, 264] -> 
             RGBColor[0.585715, 0.6458835, 0.6794385], 
             UndirectedEdge[54, 238] -> 
             RGBColor[0.948374, 0.9604212000000001, 0.9515823], 
             UndirectedEdge[177, 273] -> 
             RGBColor[0.8213394, 0.8607760000000001, 0.9565030999999999], 
             UndirectedEdge[98, 208] -> 
             RGBColor[0.7134090000000002, 0.7760398000000001, 0.9720696], 
             UndirectedEdge[125, 170] -> 
             RGBColor[0.7090563999999999, 0.7701638, 0.9472917000000001], 
             UndirectedEdge[22, 217] -> 
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993], 
             UndirectedEdge[78, 236] -> 
             RGBColor[
              0.9171898999999999, 0.6872509999999995, 0.5536680999999999], 
             UndirectedEdge[86, 240] -> 
             RGBColor[0.988628, 0.9895654, 0.8381269999999997], 
             UndirectedEdge[59, 170] -> 
             RGBColor[0.8568644, 0.8885284, 0.9600439000000001], 
             UndirectedEdge[95, 109] -> 
             RGBColor[0.8712743000000001, 0.8962714, 0.7609885999999997], 
             UndirectedEdge[30, 252] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[116, 119] -> 
             RGBColor[0.6650817, 0.7266296, 0.6840561999999999], 
             UndirectedEdge[6, 231] -> 
             RGBColor[
              0.8472748999999999, 0.8129419999999998, 0.6253548999999999], 
             UndirectedEdge[214, 275] -> 
             RGBColor[0.9350451, 0.7812516, 0.5690729999999999], 
             UndirectedEdge[157, 257] -> 
             RGBColor[0.866563, 0.8957615999999999, 0.9436267], 
             UndirectedEdge[128, 173] -> 
             RGBColor[
              0.9857507999999999, 0.9629101999999998, 0.4574811999999995], 
             UndirectedEdge[14, 113] -> 
             RGBColor[0.9386753999999999, 0.953188, 0.9679995], 
             UndirectedEdge[213, 231] -> 
             RGBColor[0.8718300999999999, 0.8974602, 0.8214839999999999], 
             UndirectedEdge[29, 148] -> 
             RGBColor[0.9938951, 0.991264, 0.7159842999999999], 
             UndirectedEdge[109, 154] -> 
             RGBColor[0.8712743000000001, 0.8962714, 0.7609885999999997], 
             UndirectedEdge[74, 123] -> 
             RGBColor[0.737166, 0.793625, 0.9666853], 
             UndirectedEdge[189, 216] -> 
             RGBColor[0.9908459999999999, 0.9904826, 0.8013689999999999], 
             UndirectedEdge[29, 162] -> 
             RGBColor[0.988628, 0.9895654, 0.8381270000000001], 
             UndirectedEdge[73, 140] -> 
             RGBColor[
              0.8332560000000001, 0.8689264000000001, 0.9033278999999999], 
             UndirectedEdge[9, 295] -> 
             RGBColor[0.7943714000000002, 0.8387858000000001, 0.9368273], 
             UndirectedEdge[169, 221] -> 
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998], 
             UndirectedEdge[22, 61] -> 
             RGBColor[0.9299423, 0.9424774, 0.7667367999999997], 
             UndirectedEdge[11, 143] -> 
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998], 
             UndirectedEdge[100, 299] -> 
             RGBColor[0.9927835, 0.9888863999999999, 0.5949935], 
             UndirectedEdge[181, 232] -> 
             RGBColor[0.6993578, 0.7629306, 0.9637089], 
             UndirectedEdge[49, 292] -> 
             RGBColor[0.659794, 0.7316336, 0.9686064], UndirectedEdge[4, 39] -> 
             RGBColor[
              0.9455066999999999, 0.8904449999999998, 0.6262055999999999], 
             UndirectedEdge[33, 75] -> 
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999], 
             UndirectedEdge[223, 271] -> 
             RGBColor[0.7207452000000001, 0.7807816000000001, 0.9737902], 
             UndirectedEdge[21, 34] -> 
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749], 
             UndirectedEdge[51, 165] -> 
             RGBColor[0.9936146, 0.9887505999999999, 0.5463667999999998], 
             UndirectedEdge[36, 138] -> 
             RGBColor[0.9789294, 0.9823322000000001, 0.8545442000000001], 
             UndirectedEdge[50, 205] -> 
             RGBColor[0.8417945, 0.5151656, 0.5756624], 
             UndirectedEdge[237, 283] -> 
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998], 
             UndirectedEdge[140, 245] -> 
             RGBColor[0.8116408000000002, 0.8535428, 0.9729203], 
             UndirectedEdge[19, 49] -> 
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999], 
             UndirectedEdge[235, 292] -> 
             RGBColor[0.49112620000000007`, 0.5977574, 0.9530824], 
             UndirectedEdge[15, 115] -> 
             RGBColor[0.870999, 0.8975960000000001, 0.8701107], 
             UndirectedEdge[69, 110] -> 
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999], 
             UndirectedEdge[34, 50] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[126, 275] -> 
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998], 
             UndirectedEdge[59, 225] -> 
             RGBColor[0.784459, 0.8315446, 0.9791512], 
             UndirectedEdge[82, 228] -> 
             RGBColor[0.9304981, 0.9436662, 0.8272321999999999], 
             UndirectedEdge[19, 280] -> 
             RGBColor[
              0.9452214999999999, 0.9350905999999999, 0.6800585999999998], 
             UndirectedEdge[194, 283] -> 
             RGBColor[0.9767113999999999, 0.981415, 0.8913021999999999], 
             UndirectedEdge[63, 283] -> 
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998], 
             UndirectedEdge[36, 245] -> 
             RGBColor[0.9550962, 0.9660314000000001, 0.9608946], 
             UndirectedEdge[3, 55] -> 
             RGBColor[0.723191, 0.7792314, 0.8573585], 
             UndirectedEdge[137, 192] -> 
             RGBColor[0.5788222000000001, 0.6630916000000001, 0.9627142], 
             UndirectedEdge[54, 251] -> 
             RGBColor[0.950592, 0.9613384, 0.9148242999999998], 
             UndirectedEdge[252, 292] -> 
             RGBColor[0.718755, 0.777397, 0.9308745], 
             UndirectedEdge[100, 121] -> 
             RGBColor[0.988628, 0.9895654, 0.8381270000000001], 
             UndirectedEdge[142, 239] -> 
             RGBColor[0.9089727, 0.6240899999999998, 0.5457992999999999], 
             UndirectedEdge[85, 299] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999], 
             UndirectedEdge[120, 130] -> 
             RGBColor[0.784459, 0.8315446, 0.9791512], UndirectedEdge[9, 297] -> 
             RGBColor[
              0.7990827000000001, 0.8392956000000001, 0.7541891999999997], 
             UndirectedEdge[237, 239] -> 
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998], 
             UndirectedEdge[169, 213] -> 
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998], 
             UndirectedEdge[46, 50] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[105, 171] -> 
             RGBColor[
              0.7965894000000001, 0.8397030000000001, 0.9000692999999999], 
             UndirectedEdge[34, 114] -> 
             RGBColor[0.9744934, 0.9804978, 0.9280602], 
             UndirectedEdge[60, 240] -> 
             RGBColor[0.950592, 0.9613384, 0.9148242999999998], 
             UndirectedEdge[19, 84] -> 
             RGBColor[0.8992271000000001, 0.7539418, 0.6090123000000001], 
             UndirectedEdge[19, 48] -> 
             RGBColor[0.9386753999999999, 0.953188, 0.9679995], 
             UndirectedEdge[5, 77] -> 
             RGBColor[0.7943714000000002, 0.8387858000000001, 0.9368273]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> RGBColor[0.178927, 0.305394, 0.933501], 
             160 -> RGBColor[0.912556, 0.9331114, 0.9915216], 245 -> 
             RGBColor[0.9453976, 0.9587982, 0.9773118], 155 -> 
             RGBColor[0.86627, 0.8962042, 0.9871068], 213 -> 
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998], 27 -> 
             RGBColor[0.86627, 0.8962042, 0.9871068], 19 -> 
             RGBColor[0.912556, 0.9331114, 0.9915216], 164 -> 
             RGBColor[
              0.9456157999999999, 0.8220917999999996, 0.2750993999999999], 
             190 -> RGBColor[0.8858982, 0.5747722, 0.22650299999999998`], 103 -> 
             RGBColor[0.6045508000000003, 0.6898406000000002, 0.9620116], 138 -> 
             RGBColor[0.993064, 0.9913998, 0.764611], 291 -> 
             RGBColor[0.993064, 0.9913998, 0.764611], 28 -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 114 -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 195 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 93 -> 
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998], 34 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 161 -> 
             RGBColor[0.6778840000000003, 0.7482874000000002, 0.9685288], 22 -> 
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993], 124 -> 
             RGBColor[
              0.39548920000000026`, 0.5169746000000002, 0.9464212000000001], 
             84 -> RGBColor[0.8858982, 0.5747722, 0.22650299999999998`], 46 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 241 -> 
             RGBColor[0.6045508000000003, 0.6898406000000002, 0.9620116], 185 -> 
             RGBColor[
              0.9632709999999999, 0.8877665999999995, 0.3118151999999995], 
             121 -> RGBColor[0.984192, 0.987731, 0.911643], 126 -> 
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998], 236 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 78 -> 
             RGBColor[
              0.8501877999999998, 0.386770999999999, 0.19569319999999987`], 
             254 -> RGBColor[0.9936146, 0.9887506, 0.5463667999999993], 290 -> 
             RGBColor[0.912556, 0.9331114, 0.9915216], 251 -> 
             RGBColor[0.988628, 0.9895654, 0.8381269999999997], 165 -> 
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998], 100 -> 
             RGBColor[0.993064, 0.9913998, 0.764611], 235 -> 
             RGBColor[0.5289344, 0.6284518, 0.9560588], 70 -> 
             RGBColor[0.8858982, 0.5747722, 0.22650299999999998`], 234 -> 
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998], 257 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 135 -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 265 -> 
             RGBColor[0.8858982, 0.5747722, 0.22650299999999998`], 111 -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 182 -> 
             RGBColor[0.993064, 0.9913998, 0.764611], 188 -> 
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998], 154 -> 
             RGBColor[0.748934, 0.8037922, 0.9756104], 269 -> 
             RGBColor[0.912556, 0.9331114, 0.9915216], 208 -> 
             RGBColor[0.748934, 0.8037922, 0.9756104], 86 -> 
             RGBColor[0.988628, 0.9895654, 0.8381269999999997], 119 -> 
             RGBColor[0.3376604000000001, 0.4668862000000001, 0.9427364], 140 -> 
             RGBColor[0.6778840000000003, 0.7482874000000002, 0.9685288], 85 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 242 -> 
             RGBColor[0.912556, 0.9331114, 0.9915216], 117 -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 47 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 81 -> 
             RGBColor[0.993064, 0.9913998, 0.764611], 275 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 23 -> 
             RGBColor[0.988628, 0.9895654, 0.8381269999999997], 110 -> 
             RGBColor[0.988628, 0.9895654, 0.8381269999999997], 6 -> 
             RGBColor[
              0.9456157999999999, 0.8220917999999996, 0.2750993999999999], 
             218 -> RGBColor[0.9453976, 0.9587982, 0.9773118], 108 -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 297 -> 
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993], 157 -> 
             RGBColor[0.748934, 0.8037922, 0.9756104], 270 -> 
             RGBColor[0.45331800000000005`, 0.567063, 0.950106], 33 -> 
             RGBColor[0.86627, 0.8962042, 0.9871068], 252 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 260 -> 
             RGBColor[0.977887, 0.9370697999999997, 0.36859559999999963`], 
             159 -> RGBColor[0.86627, 0.8962042, 0.9871068], 183 -> 
             RGBColor[0.6778840000000003, 0.7482874000000002, 0.9685288], 99 -> 
             RGBColor[0.45331800000000005`, 0.567063, 0.950106], 17 -> 
             RGBColor[0.912556, 0.9331114, 0.9915216], 277 -> 
             RGBColor[0.9453976, 0.9587982, 0.9773118], 104 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 79 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 191 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 50 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 225 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 61 -> 
             RGBColor[0.86627, 0.8962042, 0.9871068], 196 -> 
             RGBColor[0.988628, 0.9895654, 0.8381269999999997], 1 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 263 -> 
             RGBColor[0.86627, 0.8962042, 0.9871068], 201 -> 
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998], 293 -> 
             RGBColor[0.993064, 0.9913998, 0.764611], 184 -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 106 -> 
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993], 206 -> 
             RGBColor[0.748934, 0.8037922, 0.9756104], 247 -> 
             RGBColor[
              0.9456157999999999, 0.8220917999999996, 0.2750993999999999], 
             220 -> RGBColor[0.993064, 0.9913998, 0.764611], 107 -> 
             RGBColor[0.988628, 0.9895654, 0.8381269999999997], 131 -> 
             RGBColor[0.8858982, 0.5747722, 0.22650299999999998`], 127 -> 
             RGBColor[0.6778840000000003, 0.7482874000000002, 0.9685288], 210 -> 
             RGBColor[
              0.9632709999999999, 0.8877665999999995, 0.3118151999999995], 
             181 -> RGBColor[0.9453976, 0.9587982, 0.9773118], 194 -> 
             RGBColor[0.988628, 0.9895654, 0.8381269999999997], 118 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 276 -> 
             RGBColor[0.6778840000000003, 0.7482874000000002, 0.9685288], 280 -> 
             RGBColor[0.977887, 0.9370697999999997, 0.36859559999999963`], 
             189 -> RGBColor[0.988628, 0.9895654, 0.8381269999999997], 168 -> 
             RGBColor[0.988628, 0.9895654, 0.8381269999999997], 41 -> 
             RGBColor[0.988628, 0.9895654, 0.8381269999999997], 14 -> 
             RGBColor[0.912556, 0.9331114, 0.9915216], 77 -> 
             RGBColor[0.6045508000000003, 0.6898406000000002, 0.9620116], 51 -> 
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998], 179 -> 
             RGBColor[0.8858982, 0.5747722, 0.22650299999999998`], 223 -> 
             RGBColor[0.5289344, 0.6284518, 0.9560588], 292 -> 
             RGBColor[0.45331800000000005`, 0.567063, 0.950106], 143 -> 
             RGBColor[0.988628, 0.9895654, 0.8381269999999997], 112 -> 
             RGBColor[0.9453976, 0.9587982, 0.9773118], 197 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 54 -> 
             RGBColor[0.912556, 0.9331114, 0.9915216], 71 -> 
             RGBColor[0.9453976, 0.9587982, 0.9773118], 177 -> 
             RGBColor[0.6778840000000003, 0.7482874000000002, 0.9685288], 158 -> 
             RGBColor[0.86627, 0.8962042, 0.9871068], 226 -> 
             RGBColor[0.748934, 0.8037922, 0.9756104], 203 -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 115 -> 
             RGBColor[0.993064, 0.9913998, 0.764611], 173 -> 
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993], 212 -> 
             RGBColor[
              0.39548920000000026`, 0.5169746000000002, 0.9464212000000001], 
             129 -> RGBColor[0.9936146, 0.9887506, 0.5463667999999993], 279 -> 
             RGBColor[0.6778840000000003, 0.7482874000000002, 0.9685288], 26 -> 
             RGBColor[0.45331800000000005`, 0.567063, 0.950106], 40 -> 
             RGBColor[0.748934, 0.8037922, 0.9756104], 146 -> 
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998], 192 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 300 -> 
             RGBColor[0.45331800000000005`, 0.567063, 0.950106], 221 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 62 -> 
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998], 286 -> 
             RGBColor[0.45331800000000005`, 0.567063, 0.950106], 152 -> 
             RGBColor[0.86627, 0.8962042, 0.9871068], 64 -> 
             RGBColor[0.993064, 0.9913998, 0.764611], 37 -> 
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993], 148 -> 
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998], 261 -> 
             RGBColor[0.9453976, 0.9587982, 0.9773118], 15 -> 
             RGBColor[0.748934, 0.8037922, 0.9756104], 136 -> 
             RGBColor[0.6778840000000003, 0.7482874000000002, 0.9685288], 198 -> 
             RGBColor[0.5289344, 0.6284518, 0.9560588], 63 -> 
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998], 171 -> 
             RGBColor[0.988628, 0.9895654, 0.8381269999999997], 59 -> 
             RGBColor[0.748934, 0.8037922, 0.9756104], 229 -> 
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998], 102 -> 
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993], 299 -> 
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998], 128 -> 
             RGBColor[0.977887, 0.9370697999999997, 0.36859559999999963`], 12 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 222 -> 
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998], 92 -> 
             RGBColor[
              0.9456157999999999, 0.8220917999999996, 0.2750993999999999], 
             271 -> RGBColor[0.912556, 0.9331114, 0.9915216], 132 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 80 -> 
             RGBColor[0.988628, 0.9895654, 0.8381269999999997], 244 -> 
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998], 150 -> 
             RGBColor[0.988628, 0.9895654, 0.8381269999999997], 125 -> 
             RGBColor[0.45331800000000005`, 0.567063, 0.950106], 133 -> 
             RGBColor[0.6778840000000003, 0.7482874000000002, 0.9685288], 258 -> 
             RGBColor[0.9453976, 0.9587982, 0.9773118], 255 -> 
             RGBColor[0.6045508000000003, 0.6898406000000002, 0.9620116], 176 -> 
             RGBColor[0.988628, 0.9895654, 0.8381269999999997], 230 -> 
             RGBColor[0.988628, 0.9895654, 0.8381269999999997], 274 -> 
             RGBColor[0.988628, 0.9895654, 0.8381269999999997], 87 -> 
             RGBColor[0.9453976, 0.9587982, 0.9773118], 130 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 35 -> 
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998], 31 -> 
             RGBColor[0.912556, 0.9331114, 0.9915216], 18 -> 
             RGBColor[0.912556, 0.9331114, 0.9915216], 24 -> 
             RGBColor[0.988628, 0.9895654, 0.8381269999999997], 151 -> 
             RGBColor[0.8858982, 0.5747722, 0.22650299999999998`], 137 -> 
             RGBColor[0.3376604000000001, 0.4668862000000001, 0.9427364], 296 -> 
             RGBColor[0.912556, 0.9331114, 0.9915216], 266 -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 283 -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 284 -> 
             RGBColor[0.748934, 0.8037922, 0.9756104], 238 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 72 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 288 -> 
             RGBColor[0.6045508000000003, 0.6898406000000002, 0.9620116], 172 -> 
             RGBColor[0.993064, 0.9913998, 0.764611], 243 -> 
             RGBColor[0.912556, 0.9331114, 0.9915216], 88 -> 
             RGBColor[0.86627, 0.8962042, 0.9871068], 273 -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 202 -> 
             RGBColor[0.912556, 0.9331114, 0.9915216], 98 -> 
             RGBColor[0.6778840000000003, 0.7482874000000002, 0.9685288], 30 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 116 -> 
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998], 240 -> 
             RGBColor[0.988628, 0.9895654, 0.8381269999999997], 73 -> 
             RGBColor[0.988628, 0.9895654, 0.8381269999999997], 29 -> 
             RGBColor[0.993064, 0.9913998, 0.764611], 75 -> 
             RGBColor[0.912556, 0.9331114, 0.9915216], 200 -> 
             RGBColor[0.45331800000000005`, 0.567063, 0.950106], 156 -> 
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993], 25 -> 
             RGBColor[0.912556, 0.9331114, 0.9915216], 38 -> 
             RGBColor[0.977887, 0.9370697999999997, 0.36859559999999963`], 3 -> 
             RGBColor[0.993064, 0.9913998, 0.764611], 57 -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 227 -> 
             RGBColor[0.86627, 0.8962042, 0.9871068], 39 -> 
             RGBColor[
              0.9456157999999999, 0.8220917999999996, 0.2750993999999999], 
             109 -> RGBColor[0.9936146, 0.9887506, 0.5463667999999993], 256 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 287 -> 
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993], 239 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 285 -> 
             RGBColor[0.9453976, 0.9587982, 0.9773118], 216 -> 
             RGBColor[0.993064, 0.9913998, 0.764611], 21 -> 
             RGBColor[0.86627, 0.8962042, 0.9871068], 175 -> 
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993], 7 -> 
             RGBColor[0.9249214, 0.7400454, 0.2584482], 13 -> 
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998], 294 -> 
             RGBColor[0.9453976, 0.9587982, 0.9773118], 193 -> 
             RGBColor[0.5289344, 0.6284518, 0.9560588], 60 -> 
             RGBColor[0.912556, 0.9331114, 0.9915216], 65 -> 
             RGBColor[0.9249214, 0.7400454, 0.2584482], 69 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 217 -> 
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993], 214 -> 
             RGBColor[0.8858982, 0.5747722, 0.22650299999999998`], 170 -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 74 -> 
             RGBColor[0.9453976, 0.9587982, 0.9773118], 246 -> 
             RGBColor[0.977887, 0.9370697999999997, 0.36859559999999963`], 
             264 -> RGBColor[
              0.992503, 0.9863729999999999, 0.4253759999999998], 278 -> 
             RGBColor[0.912556, 0.9331114, 0.9915216], 45 -> 
             RGBColor[0.86627, 0.8962042, 0.9871068], 237 -> 
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998], 228 -> 
             RGBColor[0.86627, 0.8962042, 0.9871068], 180 -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 53 -> 
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993], 48 -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 5 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 101 -> 
             RGBColor[0.748934, 0.8037922, 0.9756104], 267 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 120 -> 
             RGBColor[0.748934, 0.8037922, 0.9756104], 147 -> 
             RGBColor[0.9249214, 0.7400454, 0.2584482], 89 -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 43 -> 
             RGBColor[0.86627, 0.8962042, 0.9871068], 199 -> 
             RGBColor[
              0.39548920000000026`, 0.5169746000000002, 0.9464212000000001], 
             268 -> RGBColor[0.8858982, 0.5747722, 0.22650299999999998`], 169 -> 
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998], 20 -> 
             RGBColor[0.6045508000000003, 0.6898406000000002, 0.9620116], 4 -> 
             RGBColor[0.9453976, 0.9587982, 0.9773118], 167 -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 142 -> 
             RGBColor[0.8337534, 0.2604489999999995, 0.17995559999999994`], 
             16 -> RGBColor[0.993064, 0.9913998, 0.764611], 281 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 289 -> 
             RGBColor[0.748934, 0.8037922, 0.9756104], 178 -> 
             RGBColor[0.977887, 0.9370697999999997, 0.36859559999999963`], 58 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 186 -> 
             RGBColor[0.912556, 0.9331114, 0.9915216], 122 -> 
             RGBColor[0.3376604000000001, 0.4668862000000001, 0.9427364], 249 -> 
             RGBColor[0.993064, 0.9913998, 0.764611], 113 -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 52 -> 
             RGBColor[0.977887, 0.9370697999999997, 0.36859559999999963`], 
             187 -> RGBColor[0.9947262, 0.9911282, 0.6673575999999998], 259 -> 
             RGBColor[0.993064, 0.9913998, 0.764611], 42 -> 
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998], 134 -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 248 -> 
             RGBColor[0.86627, 0.8962042, 0.9871068], 174 -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 215 -> 
             RGBColor[0.912556, 0.9331114, 0.9915216], 83 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 95 -> 
             RGBColor[0.748934, 0.8037922, 0.9756104], 166 -> 
             RGBColor[0.988628, 0.9895654, 0.8381269999999997], 233 -> 
             RGBColor[0.993064, 0.9913998, 0.764611], 295 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 141 -> 
             RGBColor[0.9453976, 0.9587982, 0.9773118], 205 -> 
             RGBColor[0.86627, 0.8962042, 0.9871068], 224 -> 
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998], 231 -> 
             RGBColor[0.748934, 0.8037922, 0.9756104], 68 -> 
             RGBColor[0.86627, 0.8962042, 0.9871068], 10 -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 250 -> 
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993], 282 -> 
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993], 232 -> 
             RGBColor[0.45331800000000005`, 0.567063, 0.950106], 253 -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 55 -> 
             RGBColor[0.45331800000000005`, 0.567063, 0.950106], 91 -> 
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998], 105 -> 
             RGBColor[0.6045508000000003, 0.6898406000000002, 0.9620116], 36 -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 123 -> 
             RGBColor[0.5289344, 0.6284518, 0.9560588], 94 -> 
             RGBColor[0.5289344, 0.6284518, 0.9560588], 96 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 2 -> 
             RGBColor[0.748934, 0.8037922, 0.9756104], 262 -> 
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993], 272 -> 
             RGBColor[0.6045508000000003, 0.6898406000000002, 0.9620116], 97 -> 
             RGBColor[0.6778840000000003, 0.7482874000000002, 0.9685288], 209 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 66 -> 
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998], 139 -> 
             RGBColor[0.5289344, 0.6284518, 0.9560588], 56 -> 
             RGBColor[0.86627, 0.8962042, 0.9871068], 144 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 298 -> 
             RGBColor[0.6778840000000003, 0.7482874000000002, 0.9685288], 204 -> 
             RGBColor[0.9647948, 0.9732646, 0.9444774], 207 -> 
             RGBColor[0.912556, 0.9331114, 0.9915216], 149 -> 
             RGBColor[
              0.9042269999999999, 0.6579989999999998, 0.24179699999999996`], 
             219 -> RGBColor[
              0.992503, 0.9863729999999999, 0.4253759999999998], 9 -> 
             RGBColor[0.6045508000000003, 0.6898406000000002, 0.9620116], 11 -> 
             RGBColor[0.9453976, 0.9587982, 0.9773118], 44 -> 
             RGBColor[0.912556, 0.9331114, 0.9915216], 153 -> 
             RGBColor[0.6778840000000003, 0.7482874000000002, 0.9685288], 32 -> 
             RGBColor[0.6778840000000003, 0.7482874000000002, 0.9685288], 162 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 90 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 8 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 163 -> 
             RGBColor[0.9453976, 0.9587982, 0.9773118], 49 -> 
             RGBColor[0.86627, 0.8962042, 0.9871068], 76 -> 
             RGBColor[0.86627, 0.8962042, 0.9871068], 82 -> 
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998], 67 -> 
             RGBColor[0.988628, 0.9895654, 0.8381269999999997], 211 -> 
             RGBColor[0.912556, 0.9331114, 0.9915216]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9mHk4FFzYxsmSfR/LzGBWM2NmbHmlLHNH8aZCu0SWIkQLqbSgomQtVNoX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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 9}], {
             RGBColor[0.7943714000000002, 0.8387858000000001, 0.9368273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 11}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{1, 20}], {
             RGBColor[0.7943714000000002, 0.8387858000000001, 0.9368273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 37}], {
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 43}], {
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 75}], {
             RGBColor[0.948374, 0.9604212000000001, 0.9515823]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{1, 102}], {
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 142}], {
             RGBColor[0.9089727, 0.6240899999999998, 0.5457993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 143}], {
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 174}], {
             RGBColor[0.9744934, 0.9804978, 0.9280602]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{1, 185}], {
             RGBColor[0.9737315, 0.9377487999999998, 0.6117290999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 237}], {
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 239}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 283}], {
             RGBColor[0.9744934, 0.9804978, 0.9280602]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{1, 295}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 297}], {
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 32}], {
             RGBColor[0.7134090000000002, 0.7760398000000001, 0.9720696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 83}], {
             RGBColor[0.866563, 0.8957615999999999, 0.9436267]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{2, 155}], {
             RGBColor[0.8076019999999999, 0.8499981999999999, 0.9813586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 156}], {
             RGBColor[0.8712743000000001, 0.8962714, 0.7609885999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 178}], {
             RGBColor[0.8634105, 0.8704309999999998, 0.6721029999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 184}], {
             RGBColor[0.8568644, 0.8885284, 0.9600439000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 202}], {
             RGBColor[0.8307450000000001, 0.8684518, 0.9835659999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 208}], {
             RGBColor[0.748934, 0.8037922, 0.9756104]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{2, 214}], {
             RGBColor[0.8174161, 0.6892822, 0.6010567]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{2, 268}], {
             RGBColor[0.8174161, 0.6892822, 0.6010567]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{2, 275}], {
             RGBColor[0.866563, 0.8957615999999999, 0.9436267]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{3, 17}], {
             RGBColor[0.9528099999999999, 0.9622556, 0.8780663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 30}], {
             RGBColor[0.988628, 0.9895654, 0.8381270000000001]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{3, 38}], {
             RGBColor[0.9854755, 0.9642347999999998, 0.5666032999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 55}], {
             RGBColor[0.723191, 0.7792314, 0.8573585]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{3, 74}], {
             RGBColor[0.9692308, 0.975099, 0.8709614]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{3, 90}], {
             RGBColor[0.5859955, 0.6483969, 0.849056]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[0.7609992, 0.8099258, 0.8603349]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{3, 144}], {
             RGBColor[0.988628, 0.9895654, 0.8381270000000001]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{3, 157}], {
             RGBColor[0.870999, 0.8975960000000001, 0.8701107]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{3, 229}], {
             RGBColor[0.9927835, 0.9888863999999999, 0.5949935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 252}], {
             RGBColor[0.988628, 0.9895654, 0.8381270000000001]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{3, 257}], {
             RGBColor[0.988628, 0.9895654, 0.8381270000000001]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{3, 259}], {
             RGBColor[0.993064, 0.9913998, 0.764611]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 26}], {
             RGBColor[0.6993578, 0.7629306, 0.9637089]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{4, 39}], {
             RGBColor[
             0.9455066999999999, 0.8904449999999998, 0.6262055999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 52}], {
             RGBColor[0.9616423, 0.9479339999999998, 0.6729536999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 78}], {
             RGBColor[
             0.8977926999999999, 0.6727845999999995, 0.5865024999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 82}], {
             RGBColor[0.9700618999999999, 0.9749632, 0.8223346999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 107}], {
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 130}], {
             RGBColor[0.8826908, 0.9090476000000001, 0.9800019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 193}], {
             RGBColor[0.737166, 0.793625, 0.9666853]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 199}], {
             RGBColor[0.6704434000000001, 0.7378864, 0.9618665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 220}], {
             RGBColor[0.9692308, 0.975099, 0.8709614]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[0.8471658, 0.8812952000000001, 0.9764611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 228}], {
             RGBColor[0.9058337999999999, 0.9275012, 0.9822093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 236}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{4, 266}], {
             RGBColor[0.9550962, 0.9660314000000001, 0.9608946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 281}], {
             RGBColor[0.8826908, 0.9090476000000001, 0.9800019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[0.988628, 0.9895654, 0.8381270000000001]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[0.7943714000000002, 0.8387858000000001, 0.9368273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 191}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 248}], {
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 21}], {
             RGBColor[
             0.9059428999999999, 0.8591479999999998, 0.6311030999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 34}], {
             RGBColor[0.9649038999999999, 0.9049113999999998, 0.5933712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 46}], {
             RGBColor[0.9649038999999999, 0.9049113999999998, 0.5933712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 50}], {
             RGBColor[0.8814674, 0.4781093999999998, 0.21965869999999993`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 101}], {
             RGBColor[
             0.8472748999999999, 0.8129419999999998, 0.6253548999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 108}], {
             RGBColor[0.9552052999999999, 0.8976781999999999, 0.6097884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 114}], {
             RGBColor[0.9552052999999999, 0.8976781999999999, 0.6097884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 145}], {
             RGBColor[0.5622714, 0.5637428999999998, 0.6043002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 169}], {
             RGBColor[
             0.9701709999999999, 0.9066099999999998, 0.47122849999999983`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 187}], {
             RGBColor[
             0.9701709999999999, 0.9066099999999998, 0.47122849999999983`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 205}], {
             RGBColor[
             0.9059428999999999, 0.8591479999999998, 0.6311030999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 213}], {
             RGBColor[
             0.9701709999999999, 0.9066099999999998, 0.47122849999999983`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 219}], {
             RGBColor[
             0.9690593999999999, 0.9042323999999997, 0.3502376999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 221}], {
             RGBColor[0.9649038999999999, 0.9049113999999998, 0.5933712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 231}], {
             RGBColor[
             0.8472748999999999, 0.8129419999999998, 0.6253548999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 264}], {
             RGBColor[
             0.9690593999999999, 0.9042323999999997, 0.3502376999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 9}], {
             RGBColor[0.7647361000000001, 0.7149430000000001, 0.6102299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 11}], {
             RGBColor[0.9351594999999999, 0.8494218, 0.61788]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{7, 43}], {
             RGBColor[0.8955957, 0.8181248, 0.6227775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[0.9187387, 0.8365784, 0.6249849000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 63}], {
             RGBColor[0.9598238, 0.8655868, 0.4629028999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 106}], {
             RGBColor[0.959268, 0.864398, 0.40240749999999964`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 131}], {
             RGBColor[0.9054097999999999, 0.6574088, 0.2424756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 143}], {
             RGBColor[0.9567747, 0.8648054000000001, 0.5482875999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 151}], {
             RGBColor[0.9054097999999999, 0.6574088, 0.2424756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 167}], {
             RGBColor[0.9448581, 0.8566549999999999, 0.6014628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 174}], {
             RGBColor[0.9448581, 0.8566549999999999, 0.6014628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 185}], {
             RGBColor[
             0.9440961999999999, 0.8139059999999998, 0.28513169999999977`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[0.9567747, 0.8648054000000001, 0.5482875999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 283}], {
             RGBColor[0.9448581, 0.8566549999999999, 0.6014628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 297}], {
             RGBColor[0.959268, 0.864398, 0.40240749999999964`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 22}], {
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 47}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 61}], {
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 72}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 177}], {
             RGBColor[
             0.8310380000000002, 0.8680092000000001, 0.9400858999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 217}], {
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 247}], {
             RGBColor[0.9649038999999999, 0.9049113999999998, 0.5933712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 267}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 271}], {
             RGBColor[0.948374, 0.9604212000000001, 0.9515823]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{8, 273}], {
             RGBColor[0.9744934, 0.9804978, 0.9280602]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{8, 285}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[0.7749742000000002, 0.8243194000000001, 0.9696617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 20}], {
             RGBColor[0.6045508000000003, 0.6898406000000002, 0.9620116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 37}], {
             RGBColor[
             0.7990827000000001, 0.8392956000000001, 0.7541891999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 43}], {
             RGBColor[0.7354104000000001, 0.7930224000000001, 0.9745592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 63}], {
             RGBColor[
             0.7996385000000001, 0.8404844000000001, 0.8146845999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 75}], {
             RGBColor[
             0.7585534000000002, 0.8114760000000001, 0.9767665999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.7990827000000001, 0.8392956000000001, 0.7541891999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 131}], {
             RGBColor[0.7452245000000002, 0.6323064, 0.5942573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 142}], {
             RGBColor[
             0.7191521000000001, 0.47514479999999987`, 0.5709835999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 143}], {
             RGBColor[
             0.7965894000000001, 0.8397030000000001, 0.9000692999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 167}], {
             RGBColor[0.7846728000000001, 0.8315526000000002, 0.9532445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 174}], {
             RGBColor[0.7846728000000001, 0.8315526000000002, 0.9532445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 185}], {
             RGBColor[
             0.7839109000000001, 0.7888035999999998, 0.6369133999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 237}], {
             RGBColor[
             0.7996385000000001, 0.8404844000000001, 0.8146845999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 239}], {
             RGBColor[0.7943714000000002, 0.8387858000000001, 0.9368273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 282}], {
             RGBColor[
             0.7990827000000001, 0.8392956000000001, 0.7541891999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 283}], {
             RGBColor[0.7846728000000001, 0.8315526000000002, 0.9532445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 295}], {
             RGBColor[0.7943714000000002, 0.8387858000000001, 0.9368273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 297}], {
             RGBColor[
             0.7990827000000001, 0.8392956000000001, 0.7541891999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 117}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.9792046999999999, 0.9810076000000001, 0.7454220999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 161}], {
             RGBColor[0.8213394, 0.8607760000000001, 0.9565030999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 265}], {
             RGBColor[0.9253465, 0.7740184, 0.5854902]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{10, 269}], {
             RGBColor[0.9386753999999999, 0.953188, 0.9679995]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{11, 43}], {
             RGBColor[0.9058337999999999, 0.9275012, 0.9822093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 63}], {
             RGBColor[0.9700618999999999, 0.9749632, 0.8223346999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 131}], {
             RGBColor[0.9156479, 0.7667852, 0.6019074]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{11, 139}], {
             RGBColor[0.737166, 0.793625, 0.9666853]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 143}], {
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 172}], {
             RGBColor[0.9692308, 0.975099, 0.8709614]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{11, 174}], {
             RGBColor[0.9550962, 0.9660314000000001, 0.9608946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 183}], {
             RGBColor[0.8116408000000002, 0.8535428, 0.9729203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 185}], {
             RGBColor[0.9543343, 0.9232823999999997, 0.6445634999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 283}], {
             RGBColor[0.9550962, 0.9660314000000001, 0.9608946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 248}], {
             RGBColor[0.8431270000000001, 0.8777506, 0.9848994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 58}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 73}], {
             RGBColor[0.9905655, 0.9879692, 0.6317514999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 95}], {
             RGBColor[0.8707185, 0.8950826, 0.7004931999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 96}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 105}], {
             RGBColor[0.7985269000000002, 0.8381068, 0.6936937999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[0.8351935000000001, 0.8673302, 0.6969523999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 149}], {
             RGBColor[
             0.9483649999999999, 0.8221859999999999, 0.3335864999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 171}], {
             RGBColor[0.9905655, 0.9879692, 0.6317514999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 245}], {
             RGBColor[
             0.9689502999999999, 0.9725855999999999, 0.7013438999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 289}], {
             RGBColor[0.8707185, 0.8950826, 0.7004931999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 298}], {
             RGBColor[0.8351935000000001, 0.8673302, 0.6969523999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 69}], {
             RGBColor[0.948374, 0.9604212000000001, 0.9515823]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{14, 113}], {
             RGBColor[0.9386753999999999, 0.953188, 0.9679995]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{14, 135}], {
             RGBColor[0.9386753999999999, 0.953188, 0.9679995]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{14, 224}], {
             RGBColor[0.9525295, 0.9597422, 0.7084487999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 249}], {
             RGBColor[0.9528099999999999, 0.9622556, 0.8780663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 254}], {
             RGBColor[0.9530853, 0.960931, 0.7689441999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{14, 288}], {
             RGBColor[
             0.7585534000000002, 0.8114760000000001, 0.9767665999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 19}], {
             RGBColor[0.8307450000000001, 0.8684518, 0.9835659999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 49}], {
             RGBColor[0.8076019999999999, 0.8499981999999999, 0.9813586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 57}], {
             RGBColor[0.8568644, 0.8885284, 0.9600439000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 89}], {
             RGBColor[0.8568644, 0.8885284, 0.9600439000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 111}], {
             RGBColor[0.8568644, 0.8885284, 0.9600439000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[0.8471658, 0.8812952000000001, 0.9764611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 115}], {
             RGBColor[0.870999, 0.8975960000000001, 0.8701107]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{15, 146}], {
             RGBColor[0.8707185, 0.8950826, 0.7004931999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 175}], {
             RGBColor[0.8712743000000001, 0.8962714, 0.7609885999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 212}], {
             RGBColor[0.5722116000000002, 0.6603834000000001, 0.9610158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 242}], {
             RGBColor[0.8307450000000001, 0.8684518, 0.9835659999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 243}], {
             RGBColor[0.8307450000000001, 0.8684518, 0.9835659999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 280}], {
             RGBColor[0.8634105, 0.8704309999999998, 0.6721029999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 294}], {
             RGBColor[0.8471658, 0.8812952000000001, 0.9764611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[0.929667, 0.943802, 0.8758589]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 44}], {
             RGBColor[0.9528099999999999, 0.9622556, 0.8780663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 53}], {
             RGBColor[0.9933392999999999, 0.9900752, 0.6554888999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 59}], {
             RGBColor[0.870999, 0.8975960000000001, 0.8701107]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{16, 94}], {
             RGBColor[0.7609992, 0.8099258, 0.8603349]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{16, 124}], {
             RGBColor[0.6942766000000001, 0.7541872000000001, 0.8555161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 125}], {
             RGBColor[0.723191, 0.7792314, 0.8573585]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{16, 150}], {
             RGBColor[0.9908459999999999, 0.9904826, 0.8013689999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 170}], {
             RGBColor[0.9789294, 0.9823322000000001, 0.8545442000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 192}], {
             RGBColor[0.9065240000000001, 0.9253484000000001, 0.8736515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 195}], {
             RGBColor[0.988628, 0.9895654, 0.8381270000000001]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{16, 200}], {
             RGBColor[0.723191, 0.7792314, 0.8573585]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{16, 295}], {
             RGBColor[0.988628, 0.9895654, 0.8381270000000001]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{17, 30}], {
             RGBColor[0.948374, 0.9604212000000001, 0.9515823]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{17, 38}], {
             RGBColor[
             0.9452214999999999, 0.9350905999999999, 0.6800585999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[0.9536411, 0.9621198, 0.8294395999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 48}], {
             RGBColor[0.9386753999999999, 0.953188, 0.9679995]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{17, 55}], {
             RGBColor[0.682937, 0.7500872000000001, 0.9708138]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{17, 84}], {
             RGBColor[0.8992271000000001, 0.7539418, 0.6090123000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 90}], {
             RGBColor[0.5457415, 0.6192527, 0.9625113000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 97}], {
             RGBColor[0.7952200000000001, 0.8406994000000001, 0.9800252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 134}], {
             RGBColor[0.9386753999999999, 0.953188, 0.9679995]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{17, 144}], {
             RGBColor[0.948374, 0.9604212000000001, 0.9515823]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{17, 158}], {
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 159}], {
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 175}], {
             RGBColor[0.9530853, 0.960931, 0.7689441999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{17, 235}], {
             RGBColor[0.7207452000000001, 0.7807816000000001, 0.9737902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 252}], {
             RGBColor[0.948374, 0.9604212000000001, 0.9515823]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{17, 253}], {
             RGBColor[0.9386753999999999, 0.953188, 0.9679995]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{17, 292}], {
             RGBColor[0.682937, 0.7500872000000001, 0.9708138]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{18, 24}], {
             RGBColor[0.950592, 0.9613384, 0.9148242999999998]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{18, 36}], {
             RGBColor[0.9386753999999999, 0.953188, 0.9679995]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{18, 66}], {
             RGBColor[0.9536411, 0.9621198, 0.8294395999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 69}], {
             RGBColor[0.948374, 0.9604212000000001, 0.9515823]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{18, 88}], {
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 113}], {
             RGBColor[0.9386753999999999, 0.953188, 0.9679995]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{18, 135}], {
             RGBColor[0.9386753999999999, 0.953188, 0.9679995]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[0.7207452000000001, 0.7807816000000001, 0.9737902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 222}], {
             RGBColor[0.9536411, 0.9621198, 0.8294395999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[0.9525295, 0.9597422, 0.7084487999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 254}], {
             RGBColor[0.9530853, 0.960931, 0.7689441999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{18, 258}], {
             RGBColor[0.9289768, 0.9459548, 0.9844166999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 260}], {
             RGBColor[
             0.9452214999999999, 0.9350905999999999, 0.6800585999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 278}], {
             RGBColor[0.912556, 0.9331114, 0.9915216]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{18, 288}], {
             RGBColor[
             0.7585534000000002, 0.8114760000000001, 0.9767665999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 290}], {
             RGBColor[0.912556, 0.9331114, 0.9915216]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{19, 48}], {
             RGBColor[0.9386753999999999, 0.953188, 0.9679995]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{19, 49}], {
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 57}], {
             RGBColor[0.9386753999999999, 0.953188, 0.9679995]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{19, 84}], {
             RGBColor[0.8992271000000001, 0.7539418, 0.6090123000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 89}], {
             RGBColor[0.9386753999999999, 0.953188, 0.9679995]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{19, 111}], {
             RGBColor[0.9386753999999999, 0.953188, 0.9679995]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{19, 112}], {
             RGBColor[0.9289768, 0.9459548, 0.9844166999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 158}], {
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 175}], {
             RGBColor[0.9530853, 0.960931, 0.7689441999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{19, 177}], {
             RGBColor[0.7952200000000001, 0.8406994000000001, 0.9800252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 242}], {
             RGBColor[0.912556, 0.9331114, 0.9915216]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{19, 253}], {
             RGBColor[0.9386753999999999, 0.953188, 0.9679995]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{19, 280}], {
             RGBColor[
             0.9452214999999999, 0.9350905999999999, 0.6800585999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 33}], {
             RGBColor[0.7354104000000001, 0.7930224000000001, 0.9745592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 37}], {
             RGBColor[
             0.7990827000000001, 0.8392956000000001, 0.7541891999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 75}], {
             RGBColor[
             0.7585534000000002, 0.8114760000000001, 0.9767665999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 124}], {
             RGBColor[0.5000200000000002, 0.6034076000000002, 0.9542164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 142}], {
             RGBColor[
             0.7191521000000001, 0.47514479999999987`, 0.5709835999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 150}], {
             RGBColor[
             0.7965894000000001, 0.8397030000000001, 0.9000692999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 167}], {
             RGBColor[0.7846728000000001, 0.8315526000000002, 0.9532445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 185}], {
             RGBColor[
             0.7839109000000001, 0.7888035999999998, 0.6369133999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 200}], {
             RGBColor[0.5289344000000001, 0.6284518000000001, 0.9560588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 237}], {
             RGBColor[
             0.7996385000000001, 0.8404844000000001, 0.8146845999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 282}], {
             RGBColor[
             0.7990827000000001, 0.8392956000000001, 0.7541891999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 283}], {
             RGBColor[0.7846728000000001, 0.8315526000000002, 0.9532445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 295}], {
             RGBColor[0.7943714000000002, 0.8387858000000001, 0.9368273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 297}], {
             RGBColor[
             0.7990827000000001, 0.8392956000000001, 0.7541891999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 34}], {
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 46}], {
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 50}], {
             RGBColor[0.8417945, 0.5151656, 0.5756623999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[0.9058337999999999, 0.9275012, 0.9822093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 101}], {
             RGBColor[0.8076019999999999, 0.8499981999999999, 0.9813586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 108}], {
             RGBColor[0.9155324, 0.9347344, 0.9657921]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[0.9155324, 0.9347344, 0.9657921]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{21, 169}], {
             RGBColor[0.9304981, 0.9436662, 0.8272321999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 187}], {
             RGBColor[0.9304981, 0.9436662, 0.8272321999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 205}], {
             RGBColor[0.86627, 0.8962042, 0.9871068]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 213}], {
             RGBColor[0.9304981, 0.9436662, 0.8272321999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 264}], {
             RGBColor[0.9293865, 0.9412886, 0.7062413999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 61}], {
             RGBColor[0.9299423, 0.9424774, 0.7667367999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 72}], {
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 177}], {
             RGBColor[0.8357493000000001, 0.868519, 0.7574477999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 217}], {
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 247}], {
             RGBColor[0.9696152, 0.9054211999999998, 0.4107330999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 267}], {
             RGBColor[
             0.9067993000000001, 0.9240238000000001, 0.7645293999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 271}], {
             RGBColor[0.9530853, 0.960931, 0.7689441999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{22, 273}], {
             RGBColor[
             0.9792046999999999, 0.9810076000000001, 0.7454220999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 274}], {
             RGBColor[0.9911213, 0.989158, 0.6922468999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{22, 285}], {
             RGBColor[0.9695061, 0.9737744, 0.7618392999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[0.9908459999999999, 0.9904826, 0.8013689999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 180}], {
             RGBColor[0.9767113999999999, 0.981415, 0.8913021999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 267}], {
             RGBColor[0.904306, 0.9244312000000001, 0.9104094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 285}], {
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 113}], {
             RGBColor[0.9767113999999999, 0.981415, 0.8913021999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 135}], {
             RGBColor[0.9767113999999999, 0.981415, 0.8913021999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 224}], {
             RGBColor[0.9905655, 0.9879692, 0.6317514999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 233}], {
             RGBColor[0.9908459999999999, 0.9904826, 0.8013689999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 254}], {
             RGBColor[0.9911213, 0.989158, 0.6922468999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{24, 259}], {
             RGBColor[0.9908459999999999, 0.9904826, 0.8013689999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 260}], {
             RGBColor[
             0.9832574999999999, 0.9633175999999999, 0.6033612999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 288}], {
             RGBColor[
             0.7965894000000001, 0.8397030000000001, 0.9000692999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 29}], {
             RGBColor[0.9528099999999999, 0.9622556, 0.8780663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 77}], {
             RGBColor[
             0.7585534000000002, 0.8114760000000001, 0.9767665999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 91}], {
             RGBColor[0.9525295, 0.9597422, 0.7084487999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 139}], {
             RGBColor[0.7207452000000001, 0.7807816000000001, 0.9737902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 147}], {
             RGBColor[0.9187387, 0.8365784, 0.6249849000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 148}], {
             RGBColor[0.9536411, 0.9621198, 0.8294395999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 172}], {
             RGBColor[0.9528099999999999, 0.9622556, 0.8780663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 203}], {
             RGBColor[0.9386753999999999, 0.953188, 0.9679995]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{25, 206}], {
             RGBColor[0.8307450000000001, 0.8684518, 0.9835659999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 244}], {
             RGBColor[0.9536411, 0.9621198, 0.8294395999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 270}], {
             RGBColor[0.682937, 0.7500872000000001, 0.9708138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 272}], {
             RGBColor[
             0.7585534000000002, 0.8114760000000001, 0.9767665999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 39}], {
             RGBColor[0.6994669, 0.6945773999999998, 0.6126027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 59}], {
             RGBColor[0.601126, 0.6854275999999999, 0.9628582]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{26, 60}], {
             RGBColor[0.682937, 0.7500872000000001, 0.9708138]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{26, 62}], {
             RGBColor[0.7229105, 0.776718, 0.6877409999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{26, 82}], {
             RGBColor[0.7240221, 0.7790956, 0.8087317999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[0.7231909999999999, 0.7792314, 0.8573585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 127}], {
             RGBColor[0.5656010000000001, 0.6576752000000001, 0.9593174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 130}], {
             RGBColor[0.6366510000000001, 0.71318, 0.966399]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{26, 137}], {
             RGBColor[
             0.3954892000000001, 0.5169746000000001, 0.9464212000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 170}], {
             RGBColor[0.7090563999999999, 0.7701638, 0.9472917000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 192}], {
             RGBColor[0.6366510000000001, 0.71318, 0.966399]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{26, 195}], {
             RGBColor[0.718755, 0.777397, 0.9308745]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 199}], {
             RGBColor[0.42440360000000016`, 0.5420188000000001, 0.9482636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 220}], {
             RGBColor[0.7231909999999999, 0.7792314, 0.8573585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 226}], {
             RGBColor[0.601126, 0.6854275999999999, 0.9628582]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{26, 228}], {
             RGBColor[0.659794, 0.7316336, 0.9686064]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{26, 266}], {
             RGBColor[0.7090563999999999, 0.7701638, 0.9472917000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 32}], {
             RGBColor[0.7720770000000001, 0.8222458000000001, 0.9778178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 103}], {
             RGBColor[0.7354104000000001, 0.7930224000000001, 0.9745592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 119}], {
             RGBColor[0.6019652, 0.6815452000000001, 0.9649216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 152}], {
             RGBColor[0.86627, 0.8962042, 0.9871068]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 268}], {
             RGBColor[0.8760840999999999, 0.7354882, 0.6068049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 35}], {
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 126}], {
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 163}], {
             RGBColor[0.9550962, 0.9660314000000001, 0.9608946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 184}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{28, 189}], {
             RGBColor[0.9767113999999999, 0.981415, 0.8913021999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 197}], {
             RGBColor[0.9744934, 0.9804978, 0.9280602]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{28, 211}], {
             RGBColor[0.9386753999999999, 0.953188, 0.9679995]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{28, 216}], {
             RGBColor[0.9789294, 0.9823322000000001, 0.8545442000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 275}], {
             RGBColor[0.9744934, 0.9804978, 0.9280602]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{28, 293}], {
             RGBColor[0.9789294, 0.9823322000000001, 0.8545442000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 77}], {
             RGBColor[0.7988074000000001, 0.8406202000000002, 0.8633113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 91}], {
             RGBColor[0.9927835, 0.9888863999999999, 0.5949935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 148}], {
             RGBColor[0.9938951, 0.991264, 0.7159842999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{29, 162}], {
             RGBColor[0.988628, 0.9895654, 0.8381270000000001]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{29, 172}], {
             RGBColor[0.993064, 0.9913998, 0.764611]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 191}], {
             RGBColor[0.9065240000000001, 0.9253484000000001, 0.8736515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 203}], {
             RGBColor[0.9789294, 0.9823322000000001, 0.8545442000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 206}], {
             RGBColor[0.870999, 0.8975960000000001, 0.8701107]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{29, 244}], {
             RGBColor[0.9938951, 0.991264, 0.7159842999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{29, 270}], {
             RGBColor[0.723191, 0.7792314, 0.8573585]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{29, 272}], {
             RGBColor[0.7988074000000001, 0.8406202000000002, 0.8633113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 38}], {
             RGBColor[0.9810395, 0.9624003999999999, 0.6401192999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 47}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 48}], {
             RGBColor[0.9744934, 0.9804978, 0.9280602]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{30, 74}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{30, 90}], {
             RGBColor[0.5815595, 0.6465625, 0.922572]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{30, 123}], {
             RGBColor[0.7565632, 0.8080914, 0.9338508999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 144}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 158}], {
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 252}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 257}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 259}], {
             RGBColor[0.988628, 0.9895654, 0.8381270000000001]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{31, 36}], {
             RGBColor[0.9386753999999999, 0.953188, 0.9679995]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{31, 51}], {
             RGBColor[0.9525295, 0.9597422, 0.7084487999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 58}], {
             RGBColor[0.948374, 0.9604212000000001, 0.9515823]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{31, 66}], {
             RGBColor[0.9536411, 0.9621198, 0.8294395999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 67}], {
             RGBColor[0.950592, 0.9613384, 0.9148242999999998]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{31, 73}], {
             RGBColor[0.950592, 0.9613384, 0.9148242999999998]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{31, 95}], {
             RGBColor[0.8307450000000001, 0.8684518, 0.9835659999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 96}], {
             RGBColor[0.948374, 0.9604212000000001, 0.9515823]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{31, 109}], {
             RGBColor[0.9530853, 0.960931, 0.7689441999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{31, 110}], {
             RGBColor[0.950592, 0.9613384, 0.9148242999999998]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{31, 138}], {
             RGBColor[0.9528099999999999, 0.9622556, 0.8780663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 154}], {
             RGBColor[0.8307450000000001, 0.8684518, 0.9835659999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 171}], {
             RGBColor[0.950592, 0.9613384, 0.9148242999999998]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{31, 245}], {
             RGBColor[0.9289768, 0.9459548, 0.9844166999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 156}], {
             RGBColor[0.8357493000000001, 0.868519, 0.7574477999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 178}], {
             RGBColor[0.8278855, 0.8426785999999999, 0.6685621999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 182}], {
             RGBColor[0.835474, 0.8698436, 0.8665699]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{32, 202}], {
             RGBColor[0.7952200000000001, 0.8406994000000001, 0.9800252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 208}], {
             RGBColor[0.7134090000000002, 0.7760398000000001, 0.9720696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 268}], {
             RGBColor[0.7818911000000002, 0.6615298000000001, 0.5975159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 37}], {
             RGBColor[0.9299423, 0.9424774, 0.7667367999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 75}], {
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 94}], {
             RGBColor[0.6976022, 0.762328, 0.9715828]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{33, 124}], {
             RGBColor[0.6308796000000001, 0.7065894000000001, 0.966764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 142}], {
             RGBColor[0.8500117, 0.5783265999999998, 0.5835311999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 150}], {
             RGBColor[0.927449, 0.9428848000000001, 0.9126168999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 185}], {
             RGBColor[
             0.9147704999999999, 0.8919853999999998, 0.6494609999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 200}], {
             RGBColor[0.659794, 0.7316336, 0.9686064]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{33, 237}], {
             RGBColor[0.9304981, 0.9436662, 0.8272321999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 239}], {
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 282}], {
             RGBColor[0.9299423, 0.9424774, 0.7667367999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 295}], {
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 297}], {
             RGBColor[0.9299423, 0.9424774, 0.7667367999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 46}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 50}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{34, 87}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{34, 108}], {
             RGBColor[0.9744934, 0.9804978, 0.9280602]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{34, 114}], {
             RGBColor[0.9744934, 0.9804978, 0.9280602]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{34, 169}], {
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 187}], {
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 205}], {
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 213}], {
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 227}], {
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 264}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 92}], {
             RGBColor[
             0.9701709999999999, 0.9066099999999998, 0.47122849999999983`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 126}], {
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 163}], {
             RGBColor[0.9700618999999999, 0.9749632, 0.8223346999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 184}], {
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 189}], {
             RGBColor[0.9916771, 0.9903468, 0.7527422999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 197}], {
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 211}], {
             RGBColor[0.9536411, 0.9621198, 0.8294395999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 216}], {
             RGBColor[0.9938951, 0.991264, 0.7159842999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{35, 275}], {
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 58}], {
             RGBColor[0.9744934, 0.9804978, 0.9280602]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{36, 66}], {
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 67}], {
             RGBColor[0.9767113999999999, 0.981415, 0.8913021999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 69}], {
             RGBColor[0.9744934, 0.9804978, 0.9280602]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{36, 88}], {
             RGBColor[0.9155324, 0.9347344, 0.9657921]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{36, 95}], {
             RGBColor[0.8568644, 0.8885284, 0.9600439000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 96}], {
             RGBColor[0.9744934, 0.9804978, 0.9280602]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{36, 109}], {
             RGBColor[
             0.9792046999999999, 0.9810076000000001, 0.7454220999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 113}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{36, 138}], {
             RGBColor[0.9789294, 0.9823322000000001, 0.8545442000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 154}], {
             RGBColor[0.8568644, 0.8885284, 0.9600439000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 198}], {
             RGBColor[0.7468646, 0.8008582, 0.9502681]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{36, 222}], {
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 224}], {
             RGBColor[0.9786489, 0.9798188, 0.6849266999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 245}], {
             RGBColor[0.9550962, 0.9660314000000001, 0.9608946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 258}], {
             RGBColor[0.9550962, 0.9660314000000001, 0.9608946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 260}], {
             RGBColor[0.9713409, 0.9551671999999999, 0.6565364999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 278}], {
             RGBColor[0.9386753999999999, 0.953188, 0.9679995]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{36, 290}], {
             RGBColor[0.9386753999999999, 0.953188, 0.9679995]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{37, 75}], {
             RGBColor[0.9530853, 0.960931, 0.7689441999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{37, 94}], {
             RGBColor[0.7612745000000001, 0.8086012, 0.7512127999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 102}], {
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 124}], {
             RGBColor[0.6945519000000001, 0.7528626, 0.7463939999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 142}], {
             RGBColor[
             0.9136839999999999, 0.6245997999999997, 0.36316119999999963`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 150}], {
             RGBColor[0.9911213, 0.989158, 0.6922468999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{37, 185}], {
             RGBColor[0.9784428, 0.9382585999999997, 0.4290909999999994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 237}], {
             RGBColor[0.9941704, 0.9899394, 0.6068621999999995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 239}], {
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 282}], {
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 283}], {
             RGBColor[
             0.9792046999999999, 0.9810076000000001, 0.7454220999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 295}], {
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 297}], {
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 48}], {
             RGBColor[0.9713409, 0.9551671999999999, 0.6565364999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 55}], {
             RGBColor[0.7156025, 0.7520663999999999, 0.6593507999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 74}], {
             RGBColor[0.9616423, 0.9479339999999998, 0.6729536999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 90}], {
             RGBColor[0.578407, 0.6212318999999998, 0.6510482999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 123}], {
             RGBColor[0.7534107, 0.7827607999999999, 0.6623271999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 144}], {
             RGBColor[0.9810395, 0.9624003999999999, 0.6401192999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 158}], {
             RGBColor[0.9220785, 0.9166369999999999, 0.6778511999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 252}], {
             RGBColor[0.9810395, 0.9624003999999999, 0.6401192999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 253}], {
             RGBColor[0.9713409, 0.9551671999999999, 0.6565364999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 257}], {
             RGBColor[0.9810395, 0.9624003999999999, 0.6401192999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 259}], {
             RGBColor[0.9854755, 0.9642347999999998, 0.5666032999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 52}], {
             RGBColor[
             0.9617513999999999, 0.8795807999999996, 0.32184749999999973`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 59}], {
             RGBColor[
             0.8472748999999999, 0.8129419999999998, 0.6253548999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 60}], {
             RGBColor[0.9290859, 0.8776015999999998, 0.6333104999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 62}], {
             RGBColor[
             0.9690593999999999, 0.9042323999999997, 0.3502376999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 82}], {
             RGBColor[
             0.9701709999999999, 0.9066099999999998, 0.47122849999999983`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 100}], {
             RGBColor[0.9693398999999999, 0.9067457999999998, 0.5198552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 107}], {
             RGBColor[0.9671219, 0.9058285999999998, 0.5566131999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 127}], {
             RGBColor[
             0.8117499000000001, 0.7851895999999998, 0.6218140999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 136}], {
             RGBColor[
             0.8117499000000001, 0.7851895999999998, 0.6218140999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 137}], {
             RGBColor[0.6416381, 0.6444889999999999, 0.6089179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 141}], {
             RGBColor[
             0.9455066999999999, 0.8904449999999998, 0.6262055999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 170}], {
             RGBColor[0.9552052999999999, 0.8976781999999999, 0.6097884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 192}], {
             RGBColor[0.8827999, 0.8406943999999998, 0.6288957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 220}], {
             RGBColor[0.9693398999999999, 0.9067457999999998, 0.5198552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 228}], {
             RGBColor[
             0.9059428999999999, 0.8591479999999998, 0.6311030999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 232}], {
             RGBColor[0.6994669, 0.6945773999999998, 0.6126027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 266}], {
             RGBColor[0.9552052999999999, 0.8976781999999999, 0.6097884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 281}], {
             RGBColor[0.8827999, 0.8406943999999998, 0.6288957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[0.8369276999999999, 0.7719187999999999, 0.6170293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[0.868781, 0.8966788, 0.9068686999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{40, 162}], {
             RGBColor[0.866563, 0.8957615999999999, 0.9436267]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{40, 191}], {
             RGBColor[0.784459, 0.8315446, 0.9791512]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{41, 76}], {
             RGBColor[0.927449, 0.9428848000000001, 0.9126168999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[0.927449, 0.9428848000000001, 0.9126168999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 99}], {
             RGBColor[0.720973, 0.7783142000000001, 0.8941164999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 104}], {
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 157}], {
             RGBColor[0.868781, 0.8966788, 0.9068686999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{41, 201}], {
             RGBColor[0.9905655, 0.9879692, 0.6317514999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 209}], {
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 222}], {
             RGBColor[0.9916771, 0.9903468, 0.7527422999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 229}], {
             RGBColor[0.9905655, 0.9879692, 0.6317514999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 259}], {
             RGBColor[0.9908459999999999, 0.9904826, 0.8013689999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 261}], {
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 278}], {
             RGBColor[0.950592, 0.9613384, 0.9148242999999998]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{41, 290}], {
             RGBColor[0.950592, 0.9613384, 0.9148242999999998]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{42, 55}], {
             RGBColor[0.7240221, 0.7790956, 0.8087317999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[0.8363051000000001, 0.8697078, 0.8179431999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 134}], {
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 144}], {
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 159}], {
             RGBColor[0.9304981, 0.9436662, 0.8272321999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 235}], {
             RGBColor[0.7618303, 0.80979, 0.8117081999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{42, 252}], {
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 292}], {
             RGBColor[0.7240221, 0.7790956, 0.8087317999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 63}], {
             RGBColor[0.9304981, 0.9436662, 0.8272321999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 131}], {
             RGBColor[0.8760840999999999, 0.7354882, 0.6068049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 139}], {
             RGBColor[0.6976022, 0.762328, 0.9715828]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{43, 143}], {
             RGBColor[0.927449, 0.9428848000000001, 0.9126168999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 172}], {
             RGBColor[0.929667, 0.943802, 0.8758589]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 174}], {
             RGBColor[0.9155324, 0.9347344, 0.9657921]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{43, 183}], {
             RGBColor[0.7720770000000001, 0.8222458000000001, 0.9778178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 185}], {
             RGBColor[
             0.9147704999999999, 0.8919853999999998, 0.6494609999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 244}], {
             RGBColor[0.9304981, 0.9436662, 0.8272321999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 59}], {
             RGBColor[0.8307450000000001, 0.8684518, 0.9835659999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 60}], {
             RGBColor[0.912556, 0.9331114, 0.9915216]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{44, 94}], {
             RGBColor[0.7207452000000001, 0.7807816000000001, 0.9737902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 100}], {
             RGBColor[0.9528099999999999, 0.9622556, 0.8780663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 121}], {
             RGBColor[0.948374, 0.9604212000000001, 0.9515823]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{44, 124}], {
             RGBColor[0.6540226000000001, 0.7250430000000001, 0.9689714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 125}], {
             RGBColor[0.682937, 0.7500872000000001, 0.9708138]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{44, 137}], {
             RGBColor[0.6251082000000001, 0.6999988, 0.967129]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{44, 150}], {
             RGBColor[0.950592, 0.9613384, 0.9148242999999998]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{44, 170}], {
             RGBColor[0.9386753999999999, 0.953188, 0.9679995]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{44, 192}], {
             RGBColor[
             0.8662700000000001, 0.8962042000000001, 0.9871068000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 195}], {
             RGBColor[0.948374, 0.9604212000000001, 0.9515823]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{44, 200}], {
             RGBColor[0.682937, 0.7500872000000001, 0.9708138]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{44, 256}], {
             RGBColor[
             0.8662700000000001, 0.8962042000000001, 0.9871068000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 299}], {
             RGBColor[0.9525295, 0.9597422, 0.7084487999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 53}], {
             RGBColor[0.9299423, 0.9424774, 0.7667367999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 68}], {
             RGBColor[0.86627, 0.8962042, 0.9871068]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 195}], {
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 200}], {
             RGBColor[0.659794, 0.7316336, 0.9686064]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{45, 215}], {
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 223}], {
             RGBColor[0.6976022, 0.762328, 0.9715828]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{45, 225}], {
             RGBColor[0.8431270000000001, 0.8777506, 0.9848994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 234}], {
             RGBColor[0.9304981, 0.9436662, 0.8272321999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 255}], {
             RGBColor[0.7354104000000001, 0.7930224000000001, 0.9745592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 282}], {
             RGBColor[0.9299423, 0.9424774, 0.7667367999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 287}], {
             RGBColor[0.9299423, 0.9424774, 0.7667367999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 50}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{46, 108}], {
             RGBColor[0.9744934, 0.9804978, 0.9280602]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{46, 114}], {
             RGBColor[0.9744934, 0.9804978, 0.9280602]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{46, 145}], {
             RGBColor[0.5815595, 0.6465625, 0.922572]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{46, 169}], {
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 187}], {
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 213}], {
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 219}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 221}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 264}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 48}], {
             RGBColor[0.8923894000000001, 0.9162808, 0.9635847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 74}], {
             RGBColor[0.8826908, 0.9090476000000001, 0.9800019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 90}], {
             RGBColor[0.49945550000000005`, 0.5823455000000001, 0.9580965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[0.8431270000000001, 0.8777506, 0.9848994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 166}], {
             RGBColor[0.904306, 0.9244312000000001, 0.9104094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 177}], {
             RGBColor[0.7489340000000002, 0.8037922000000002, 0.9756104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 217}], {
             RGBColor[
             0.9067993000000001, 0.9240238000000001, 0.7645293999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 233}], {
             RGBColor[0.9065240000000001, 0.9253484000000001, 0.8736515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 262}], {
             RGBColor[
             0.9067993000000001, 0.9240238000000001, 0.7645293999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 273}], {
             RGBColor[0.8923894000000001, 0.9162808, 0.9635847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 74}], {
             RGBColor[0.9550962, 0.9660314000000001, 0.9608946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 84}], {
             RGBColor[0.9253465, 0.7740184, 0.5854902]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{48, 90}], {
             RGBColor[0.5718609, 0.6393293, 0.9389892]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{48, 144}], {
             RGBColor[0.9744934, 0.9804978, 0.9280602]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{48, 158}], {
             RGBColor[0.9155324, 0.9347344, 0.9657921]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{48, 175}], {
             RGBColor[
             0.9792046999999999, 0.9810076000000001, 0.7454220999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 177}], {
             RGBColor[0.8213394, 0.8607760000000001, 0.9565030999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 217}], {
             RGBColor[
             0.9792046999999999, 0.9810076000000001, 0.7454220999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 252}], {
             RGBColor[0.9744934, 0.9804978, 0.9280602]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{48, 253}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{49, 57}], {
             RGBColor[0.9155324, 0.9347344, 0.9657921]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{49, 84}], {
             RGBColor[0.8760840999999999, 0.7354882, 0.6068049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 112}], {
             RGBColor[0.9058337999999999, 0.9275012, 0.9822093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 115}], {
             RGBColor[0.929667, 0.943802, 0.8758589]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 146}], {
             RGBColor[0.9293865, 0.9412886, 0.7062413999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 159}], {
             RGBColor[0.86627, 0.8962042, 0.9871068]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 175}], {
             RGBColor[0.9299423, 0.9424774, 0.7667367999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 204}], {
             RGBColor[0.9155324, 0.9347344, 0.9657921]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{49, 242}], {
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 243}], {
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 253}], {
             RGBColor[0.9155324, 0.9347344, 0.9657921]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{49, 280}], {
             RGBColor[0.9220785, 0.9166369999999999, 0.6778511999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 292}], {
             RGBColor[0.659794, 0.7316336, 0.9686064]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{50, 87}], {
             RGBColor[0.8813583, 0.5464626, 0.5707649]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{50, 108}], {
             RGBColor[0.8910568999999999, 0.5536958000000001, 0.5543477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 114}], {
             RGBColor[0.8910568999999999, 0.5536958000000001, 0.5543477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 169}], {
             RGBColor[0.9060226, 0.5626276, 0.41578779999999993`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 187}], {
             RGBColor[0.9060226, 0.5626276, 0.41578779999999993`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 205}], {
             RGBColor[0.8417945, 0.5151656, 0.5756624]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{50, 213}], {
             RGBColor[0.9060226, 0.5626276, 0.41578779999999993`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 227}], {
             RGBColor[0.8417945, 0.5151656, 0.5756624]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{50, 264}], {
             RGBColor[0.904911, 0.5602499999999999, 0.29479699999999986`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 52}], {
             RGBColor[0.985195, 0.9617213999999998, 0.3969857999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 58}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 66}], {
             RGBColor[0.9936146, 0.9887505999999999, 0.5463667999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 67}], {
             RGBColor[0.9905655, 0.9879692, 0.6317514999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 69}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 86}], {
             RGBColor[0.9905655, 0.9879692, 0.6317514999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[0.9905655, 0.9879692, 0.6317514999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 109}], {
             RGBColor[0.9930588, 0.9875617999999999, 0.4858713999999995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 110}], {
             RGBColor[0.9905655, 0.9879692, 0.6317514999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 138}], {
             RGBColor[0.9927835, 0.9888863999999999, 0.5949935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 141}], {
             RGBColor[
             0.9689502999999999, 0.9725855999999999, 0.7013438999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 154}], {
             RGBColor[0.8707185, 0.8950826, 0.7004931999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 165}], {
             RGBColor[0.9936146, 0.9887505999999999, 0.5463667999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 179}], {
             RGBColor[0.9392005999999999, 0.7805726, 0.3259394999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 258}], {
             RGBColor[
             0.9689502999999999, 0.9725855999999999, 0.7013438999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 281}], {
             RGBColor[
             0.9062435000000001, 0.9228350000000001, 0.7040339999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 82}], {
             RGBColor[0.9863066, 0.9640989999999998, 0.5179765999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 86}], {
             RGBColor[
             0.9832574999999999, 0.9633175999999999, 0.6033612999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 107}], {
             RGBColor[
             0.9832574999999999, 0.9633175999999999, 0.6033612999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 110}], {
             RGBColor[
             0.9832574999999999, 0.9633175999999999, 0.6033612999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 141}], {
             RGBColor[0.9616423, 0.9479339999999998, 0.6729536999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 165}], {
             RGBColor[0.9863066, 0.9640989999999998, 0.5179765999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 179}], {
             RGBColor[0.9318926, 0.7559209999999998, 0.2975492999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 193}], {
             RGBColor[0.7534107, 0.7827607999999999, 0.6623271999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 236}], {
             RGBColor[0.9810395, 0.9624003999999999, 0.6401192999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 266}], {
             RGBColor[0.9713409, 0.9551671999999999, 0.6565364999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 281}], {
             RGBColor[0.8989355000000001, 0.8981834, 0.6756437999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 59}], {
             RGBColor[0.8712743000000001, 0.8962714, 0.7609885999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 68}], {
             RGBColor[0.9299423, 0.9424774, 0.7667367999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 150}], {
             RGBColor[0.9911213, 0.989158, 0.6922468999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{53, 170}], {
             RGBColor[
             0.9792046999999999, 0.9810076000000001, 0.7454220999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 192}], {
             RGBColor[
             0.9067993000000001, 0.9240238000000001, 0.7645293999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 195}], {
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 200}], {
             RGBColor[0.7234663, 0.7779068, 0.7482363999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 225}], {
             RGBColor[
             0.9067993000000001, 0.9240238000000001, 0.7645293999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 234}], {
             RGBColor[0.9941704, 0.9899394, 0.6068621999999995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 255}], {
             RGBColor[
             0.7990827000000001, 0.8392956000000001, 0.7541891999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 282}], {
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 287}], {
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 72}], {
             RGBColor[0.948374, 0.9604212000000001, 0.9515823]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{54, 106}], {
             RGBColor[0.9530853, 0.960931, 0.7689441999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{54, 151}], {
             RGBColor[0.8992271000000001, 0.7539418, 0.6090123000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 167}], {
             RGBColor[0.9386753999999999, 0.953188, 0.9679995]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{54, 194}], {
             RGBColor[0.950592, 0.9613384, 0.9148242999999998]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{54, 238}], {
             RGBColor[0.948374, 0.9604212000000001, 0.9515823]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{54, 251}], {
             RGBColor[0.950592, 0.9613384, 0.9148242999999998]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{54, 286}], {
             RGBColor[0.682937, 0.7500872000000001, 0.9708138]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{55, 90}], {
             RGBColor[0.31612250000000003`, 0.4362285, 0.9418035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 97}], {
             RGBColor[0.5656010000000001, 0.6576752000000001, 0.9593174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 134}], {
             RGBColor[0.7090563999999999, 0.7701638, 0.9472917000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 144}], {
             RGBColor[0.718755, 0.777397, 0.9308745]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 159}], {
             RGBColor[0.659794, 0.7316336, 0.9686064]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{55, 235}], {
             RGBColor[0.49112620000000007`, 0.5977574, 0.9530824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 252}], {
             RGBColor[0.718755, 0.777397, 0.9308745]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 253}], {
             RGBColor[0.7090563999999999, 0.7701638, 0.9472917000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 292}], {
             RGBColor[0.45331800000000005`, 0.567063, 0.950106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 79}], {
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 93}], {
             RGBColor[0.9293865, 0.9412886, 0.7062413999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 160}], {
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 164}], {
             RGBColor[
             0.9059428999999999, 0.8591479999999998, 0.6311030999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 168}], {
             RGBColor[0.927449, 0.9428848000000001, 0.9126168999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 246}], {
             RGBColor[0.9220785, 0.9166369999999999, 0.6778511999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 296}], {
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[0.9253465, 0.7740184, 0.5854902]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{57, 89}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{57, 112}], {
             RGBColor[0.9550962, 0.9660314000000001, 0.9608946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 115}], {
             RGBColor[0.9789294, 0.9823322000000001, 0.8545442000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 134}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{57, 146}], {
             RGBColor[0.9786489, 0.9798188, 0.6849266999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 159}], {
             RGBColor[0.9155324, 0.9347344, 0.9657921]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{57, 175}], {
             RGBColor[
             0.9792046999999999, 0.9810076000000001, 0.7454220999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 204}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{57, 235}], {
             RGBColor[0.7468646, 0.8008582, 0.9502681]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{57, 242}], {
             RGBColor[0.9386753999999999, 0.953188, 0.9679995]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{57, 243}], {
             RGBColor[0.9386753999999999, 0.953188, 0.9679995]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{57, 253}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{57, 280}], {
             RGBColor[0.9713409, 0.9551671999999999, 0.6565364999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 292}], {
             RGBColor[0.7090564, 0.7701638, 0.9472917000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 66}], {
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 67}], {
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 73}], {
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 95}], {
             RGBColor[0.866563, 0.8957615999999999, 0.9436267]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{58, 96}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 109}], {
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 138}], {
             RGBColor[0.988628, 0.9895654, 0.8381270000000001]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{58, 140}], {
             RGBColor[
             0.8310380000000002, 0.8680092000000001, 0.9400858999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 154}], {
             RGBColor[0.866563, 0.8957615999999999, 0.9436267]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{58, 171}], {
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 198}], {
             RGBColor[0.7565632, 0.8080914, 0.9338508999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{59, 62}], {
             RGBColor[0.8707185, 0.8950826, 0.7004931999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 100}], {
             RGBColor[0.870999, 0.8975960000000001, 0.8701107]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{59, 125}], {
             RGBColor[0.601126, 0.6854275999999999, 0.9628582]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{59, 137}], {
             RGBColor[0.5432972, 0.6353392, 0.9591734000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 170}], {
             RGBColor[0.8568644, 0.8885284, 0.9600439000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 192}], {
             RGBColor[0.784459, 0.8315446, 0.9791512]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{59, 195}], {
             RGBColor[0.866563, 0.8957615999999999, 0.9436267]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{59, 200}], {
             RGBColor[0.601126, 0.6854275999999999, 0.9628582]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{59, 225}], {
             RGBColor[0.784459, 0.8315446, 0.9791512]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{59, 228}], {
             RGBColor[0.8076019999999999, 0.8499981999999999, 0.9813586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 255}], {
             RGBColor[0.6767424000000002, 0.7468164000000002, 0.968811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[0.9536411, 0.9621198, 0.8294395999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 85}], {
             RGBColor[0.948374, 0.9604212000000001, 0.9515823]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{60, 100}], {
             RGBColor[0.9528099999999999, 0.9622556, 0.8780663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 121}], {
             RGBColor[0.948374, 0.9604212000000001, 0.9515823]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{60, 125}], {
             RGBColor[0.682937, 0.7500872000000001, 0.9708138]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{60, 127}], {
             RGBColor[0.7952200000000001, 0.8406994000000001, 0.9800252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[0.7952200000000001, 0.8406994000000001, 0.9800252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 137}], {
             RGBColor[0.6251082000000001, 0.6999988, 0.967129]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{60, 170}], {
             RGBColor[0.9386753999999999, 0.953188, 0.9679995]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{60, 232}], {
             RGBColor[0.682937, 0.7500872000000001, 0.9708138]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{60, 240}], {
             RGBColor[0.950592, 0.9613384, 0.9148242999999998]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{60, 256}], {
             RGBColor[
             0.8662700000000001, 0.8962042000000001, 0.9871068000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 299}], {
             RGBColor[0.9525295, 0.9597422, 0.7084487999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 177}], {
             RGBColor[0.7720770000000001, 0.8222458000000001, 0.9778178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 217}], {
             RGBColor[0.9299423, 0.9424774, 0.7667367999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 247}], {
             RGBColor[
             0.9059428999999999, 0.8591479999999998, 0.6311030999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 267}], {
             RGBColor[0.8431270000000001, 0.8777506, 0.9848994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 273}], {
             RGBColor[0.9155324, 0.9347344, 0.9657921]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{61, 285}], {
             RGBColor[0.9058337999999999, 0.9275012, 0.9822093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 82}], {
             RGBColor[0.9936146, 0.9887505999999999, 0.5463667999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 100}], {
             RGBColor[0.9927835, 0.9888863999999999, 0.5949935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 127}], {
             RGBColor[0.8351935000000001, 0.8673302, 0.6969523999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 130}], {
             RGBColor[
             0.9062435000000001, 0.9228350000000001, 0.7040339999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 137}], {
             RGBColor[0.6650817, 0.7266296, 0.6840561999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 170}], {
             RGBColor[0.9786489, 0.9798188, 0.6849266999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 192}], {
             RGBColor[
             0.9062435000000001, 0.9228350000000001, 0.7040339999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 195}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 199}], {
             RGBColor[0.6939961000000001, 0.7516738000000001, 0.6858986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 220}], {
             RGBColor[0.9927835, 0.9888863999999999, 0.5949935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 225}], {
             RGBColor[
             0.9062435000000001, 0.9228350000000001, 0.7040339999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 226}], {
             RGBColor[0.8707185, 0.8950826, 0.7004931999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 228}], {
             RGBColor[0.9293865, 0.9412886, 0.7062413999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 255}], {
             RGBColor[0.7985269000000002, 0.8381068, 0.6936937999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 131}], {
             RGBColor[
             0.9403121999999999, 0.7829501999999999, 0.4469302999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 139}], {
             RGBColor[0.7618303, 0.80979, 0.8117081999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{63, 143}], {
             RGBColor[0.9916771, 0.9903468, 0.7527422999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 172}], {
             RGBColor[0.9938951, 0.991264, 0.7159842999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{63, 174}], {
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 183}], {
             RGBColor[0.8363051000000001, 0.8697078, 0.8179431999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 283}], {
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 92}], {
             RGBColor[0.9693398999999999, 0.9067457999999998, 0.5198552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 145}], {
             RGBColor[0.5859955, 0.6483969, 0.849056]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{64, 153}], {
             RGBColor[0.835474, 0.8698436, 0.8665699]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{64, 211}], {
             RGBColor[0.9528099999999999, 0.9622556, 0.8780663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 219}], {
             RGBColor[0.9927835, 0.9888863999999999, 0.5949935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 221}], {
             RGBColor[0.988628, 0.9895654, 0.8381270000000001]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{65, 80}], {
             RGBColor[0.9567747, 0.8648054000000001, 0.5482875999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 103}], {
             RGBColor[0.7647361000000001, 0.7149430000000001, 0.6102299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 116}], {
             RGBColor[0.9587122, 0.8632092, 0.34191209999999994`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 133}], {
             RGBColor[0.8014027000000001, 0.7441664000000001, 0.6134885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 152}], {
             RGBColor[0.8955957, 0.8181248, 0.6227775]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{65, 162}], {
             RGBColor[0.9545566999999999, 0.8638882, 0.5850455999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[
             0.9440961999999999, 0.8139059999999998, 0.28513169999999977`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 241}], {
             RGBColor[0.7647361000000001, 0.7149430000000001, 0.6102299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 277}], {
             RGBColor[0.9351594999999999, 0.8494218, 0.61788]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{66, 67}], {
             RGBColor[0.9916771, 0.9903468, 0.7527422999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 69}], {
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 95}], {
             RGBColor[0.8718300999999999, 0.8974602, 0.8214839999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 109}], {
             RGBColor[0.9941704, 0.9899394, 0.6068621999999995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 110}], {
             RGBColor[0.9916771, 0.9903468, 0.7527422999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 138}], {
             RGBColor[0.9938951, 0.991264, 0.7159842999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{66, 154}], {
             RGBColor[0.8718300999999999, 0.8974602, 0.8214839999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 179}], {
             RGBColor[
             0.9403121999999999, 0.7829501999999999, 0.4469302999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 258}], {
             RGBColor[0.9700618999999999, 0.9749632, 0.8223346999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 69}], {
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 86}], {
             RGBColor[0.988628, 0.9895654, 0.8381269999999997]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{67, 95}], {
             RGBColor[0.868781, 0.8966788, 0.9068686999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{67, 109}], {
             RGBColor[0.9911213, 0.989158, 0.6922468999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{67, 110}], {
             RGBColor[0.988628, 0.9895654, 0.8381269999999997]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{67, 138}], {
             RGBColor[0.9908459999999999, 0.9904826, 0.8013689999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 154}], {
             RGBColor[0.868781, 0.8966788, 0.9068686999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{67, 179}], {
             RGBColor[0.9372631, 0.7821688, 0.5323149999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 258}], {
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 215}], {
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 223}], {
             RGBColor[0.6976022, 0.762328, 0.9715828]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{68, 234}], {
             RGBColor[0.9304981, 0.9436662, 0.8272321999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 255}], {
             RGBColor[0.7354104000000001, 0.7930224000000001, 0.9745592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 271}], {
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 274}], {
             RGBColor[0.927449, 0.9428848000000001, 0.9126168999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 287}], {
             RGBColor[0.9299423, 0.9424774, 0.7667367999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 109}], {
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 110}], {
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 113}], {
             RGBColor[0.9744934, 0.9804978, 0.9280602]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{69, 135}], {
             RGBColor[0.9744934, 0.9804978, 0.9280602]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{69, 138}], {
             RGBColor[0.988628, 0.9895654, 0.8381270000000001]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{69, 224}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 249}], {
             RGBColor[0.988628, 0.9895654, 0.8381270000000001]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{69, 254}], {
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 258}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{69, 288}], {
             RGBColor[0.7943714000000002, 0.8387858000000001, 0.9368273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[0.9350451, 0.7812516, 0.5690729999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 251}], {
             RGBColor[0.9372631, 0.7821688, 0.5323149999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 300}], {
             RGBColor[0.6696081, 0.5709176, 0.5883045]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{71, 85}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{71, 98}], {
             RGBColor[0.8116408000000002, 0.8535428, 0.9729203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 121}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{71, 122}], {
             RGBColor[0.641529, 0.7128422000000001, 0.9600241]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{71, 136}], {
             RGBColor[0.8116408000000002, 0.8535428, 0.9729203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 160}], {
             RGBColor[0.9289768, 0.9459548, 0.9844166999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 181}], {
             RGBColor[0.9453976, 0.9587982, 0.9773118]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{71, 207}], {
             RGBColor[0.9289768, 0.9459548, 0.9844166999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 232}], {
             RGBColor[0.6993578, 0.7629306, 0.9637089]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{71, 240}], {
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 246}], {
             RGBColor[0.9616423, 0.9479339999999998, 0.6729536999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 256}], {
             RGBColor[0.8826908, 0.9090476000000001, 0.9800019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 296}], {
             RGBColor[0.9289768, 0.9459548, 0.9844166999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 299}], {
             RGBColor[
             0.9689502999999999, 0.9725855999999999, 0.7013438999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 106}], {
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 151}], {
             RGBColor[0.9350451, 0.7812516, 0.5690729999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 194}], {
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 215}], {
             RGBColor[0.948374, 0.9604212000000001, 0.9515823]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{72, 247}], {
             RGBColor[0.9649038999999999, 0.9049113999999998, 0.5933712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 267}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 286}], {
             RGBColor[0.718755, 0.777397, 0.9308745]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 87}], {
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 95}], {
             RGBColor[0.868781, 0.8966788, 0.9068686999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{73, 96}], {
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 105}], {
             RGBColor[
             0.7965894000000001, 0.8397030000000001, 0.9000692999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 140}], {
             RGBColor[
             0.8332560000000001, 0.8689264000000001, 0.9033278999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 149}], {
             RGBColor[0.9464275, 0.8237821999999999, 0.5399619999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 171}], {
             RGBColor[0.988628, 0.9895654, 0.8381269999999997]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{73, 245}], {
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 289}], {
             RGBColor[0.868781, 0.8966788, 0.9068686999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{73, 298}], {
             RGBColor[
             0.8332560000000001, 0.8689264000000001, 0.9033278999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 90}], {
             RGBColor[0.5621623, 0.6320961, 0.9554064]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{74, 123}], {
             RGBColor[0.737166, 0.793625, 0.9666853]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 158}], {
             RGBColor[0.9058337999999999, 0.9275012, 0.9822093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 233}], {
             RGBColor[0.9692308, 0.975099, 0.8709614]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{74, 257}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{74, 259}], {
             RGBColor[0.9692308, 0.975099, 0.8709614]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{74, 262}], {
             RGBColor[0.9695061, 0.9737744, 0.7618392999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 124}], {
             RGBColor[0.6540226000000001, 0.7250430000000001, 0.9689714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 142}], {
             RGBColor[0.8731547, 0.5967801999999998, 0.5857386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 143}], {
             RGBColor[0.950592, 0.9613384, 0.9148242999999998]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{75, 150}], {
             RGBColor[0.950592, 0.9613384, 0.9148242999999998]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{75, 167}], {
             RGBColor[0.9386753999999999, 0.953188, 0.9679995]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{75, 174}], {
             RGBColor[0.9386753999999999, 0.953188, 0.9679995]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{75, 185}], {
             RGBColor[0.9379135, 0.9104389999999998, 0.6516683999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 237}], {
             RGBColor[0.9536411, 0.9621198, 0.8294395999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 239}], {
             RGBColor[0.948374, 0.9604212000000001, 0.9515823]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{75, 282}], {
             RGBColor[0.9530853, 0.960931, 0.7689441999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{75, 283}], {
             RGBColor[0.9386753999999999, 0.953188, 0.9679995]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{75, 295}], {
             RGBColor[0.948374, 0.9604212000000001, 0.9515823]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{75, 297}], {
             RGBColor[0.9530853, 0.960931, 0.7689441999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{76, 99}], {
             RGBColor[0.659794, 0.7316336, 0.9686064]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 128}], {
             RGBColor[0.9220785, 0.9166369999999999, 0.6778511999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[0.8076019999999999, 0.8499981999999999, 0.9813586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 201}], {
             RGBColor[0.9293865, 0.9412886, 0.7062413999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 209}], {
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 218}], {
             RGBColor[0.9058337999999999, 0.9275012, 0.9822093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 229}], {
             RGBColor[0.9293865, 0.9412886, 0.7062413999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 261}], {
             RGBColor[0.9058337999999999, 0.9275012, 0.9822093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 284}], {
             RGBColor[0.8076019999999999, 0.8499981999999999, 0.9813586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 91}], {
             RGBColor[0.7985269000000002, 0.8381068, 0.6936937999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 162}], {
             RGBColor[0.7943714000000002, 0.8387858000000001, 0.9368273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 191}], {
             RGBColor[0.7122674000000002, 0.7745688000000002, 0.9723518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 203}], {
             RGBColor[0.7846728000000001, 0.8315526000000002, 0.9532445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 206}], {
             RGBColor[0.6767424000000002, 0.7468164000000002, 0.968811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 244}], {
             RGBColor[
             0.7996385000000001, 0.8404844000000001, 0.8146845999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 270}], {
             RGBColor[0.5289344000000001, 0.6284518000000001, 0.9560588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 118}], {
             RGBColor[
             0.9171898999999999, 0.6872509999999995, 0.5536680999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 120}], {
             RGBColor[0.7995608999999999, 0.5952815999999994, 0.5856518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 130}], {
             RGBColor[0.8350858999999999, 0.6230339999999995, 0.5891926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 176}], {
             RGBColor[0.9194079, 0.6881681999999996, 0.5169100999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 193}], {
             RGBColor[
             0.6895610999999999, 0.5076113999999995, 0.5758759999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.6228385000000001, 0.4518727999999996, 0.5710571999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 220}], {
             RGBColor[
             0.9216258999999999, 0.6890853999999995, 0.48015209999999997`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 226}], {
             RGBColor[0.7995608999999999, 0.5952815999999994, 0.5856518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 236}], {
             RGBColor[
             0.9171898999999999, 0.6872509999999995, 0.5536680999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 266}], {
             RGBColor[
             0.9074912999999999, 0.6800177999999995, 0.5700852999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 93}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 103}], {
             RGBColor[0.7943714000000002, 0.8387858000000001, 0.9368273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 116}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 119}], {
             RGBColor[0.6609262, 0.7273086000000001, 0.9271897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 164}], {
             RGBColor[0.9649038999999999, 0.9049113999999998, 0.5933712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 168}], {
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 241}], {
             RGBColor[0.7943714000000002, 0.8387858000000001, 0.9368273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{80, 103}], {
             RGBColor[
             0.7965894000000001, 0.8397030000000001, 0.9000692999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 116}], {
             RGBColor[0.9905655, 0.9879692, 0.6317514999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 133}], {
             RGBColor[
             0.8332560000000001, 0.8689264000000001, 0.9033278999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 152}], {
             RGBColor[0.927449, 0.9428848000000001, 0.9126168999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 210}], {
             RGBColor[
             0.9759494999999999, 0.9386659999999998, 0.5749710999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 241}], {
             RGBColor[
             0.7965894000000001, 0.8397030000000001, 0.9000692999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 277}], {
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 180}], {
             RGBColor[0.9789294, 0.9823322000000001, 0.8545442000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[0.9065240000000001, 0.9253484000000001, 0.8736515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 285}], {
             RGBColor[0.9692308, 0.975099, 0.8709614]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{82, 100}], {
             RGBColor[0.9938951, 0.991264, 0.7159842999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{82, 107}], {
             RGBColor[0.9916771, 0.9903468, 0.7527422999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 127}], {
             RGBColor[0.8363051000000001, 0.8697078, 0.8179431999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 137}], {
             RGBColor[0.6661933, 0.7290072000000001, 0.8050469999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 192}], {
             RGBColor[0.9073551000000001, 0.9252126, 0.8250247999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 199}], {
             RGBColor[0.6951077000000001, 0.7540514, 0.8068894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 220}], {
             RGBColor[0.9938951, 0.991264, 0.7159842999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{82, 226}], {
             RGBColor[0.8718300999999999, 0.8974602, 0.8214839999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 228}], {
             RGBColor[0.9304981, 0.9436662, 0.8272321999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 266}], {
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 281}], {
             RGBColor[0.9073551000000001, 0.9252126, 0.8250247999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 126}], {
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 155}], {
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 156}], {
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 184}], {
             RGBColor[0.9744934, 0.9804978, 0.9280602]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 202}], {
             RGBColor[0.948374, 0.9604212000000001, 0.9515823]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{83, 214}], {
             RGBColor[0.9350451, 0.7812516, 0.5690729999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 275}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 293}], {
             RGBColor[0.988628, 0.9895654, 0.8381270000000001]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{84, 89}], {
             RGBColor[0.9253465, 0.7740184, 0.5854902]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[0.5324126, 0.44008309999999995`, 0.580002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 112}], {
             RGBColor[0.9156479, 0.7667852, 0.6019074]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{84, 134}], {
             RGBColor[0.9253465, 0.7740184, 0.5854902]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{84, 144}], {
             RGBColor[0.9350451, 0.7812516, 0.5690729999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 158}], {
             RGBColor[0.8760840999999999, 0.7354882, 0.6068049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 159}], {
             RGBColor[0.8760840999999999, 0.7354882, 0.6068049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 175}], {
             RGBColor[0.9397564, 0.7817613999999999, 0.3864348999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 252}], {
             RGBColor[0.9350451, 0.7812516, 0.5690729999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 253}], {
             RGBColor[0.9253465, 0.7740184, 0.5854902]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{84, 280}], {
             RGBColor[0.9318926, 0.7559209999999998, 0.2975492999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 292}], {
             RGBColor[0.6696081, 0.5709176, 0.5883045]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 122}], {
             RGBColor[0.6609262, 0.7273086000000001, 0.9271897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 136}], {
             RGBColor[
             0.8310380000000002, 0.8680092000000001, 0.9400858999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 165}], {
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 181}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{85, 207}], {
             RGBColor[0.948374, 0.9604212000000001, 0.9515823]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{85, 232}], {
             RGBColor[0.718755, 0.777397, 0.9308745]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 240}], {
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 246}], {
             RGBColor[0.9810395, 0.9624003999999999, 0.6401192999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 256}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 296}], {
             RGBColor[0.948374, 0.9604212000000001, 0.9515823]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{85, 299}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 107}], {
             RGBColor[0.988628, 0.9895654, 0.8381269999999997]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{86, 109}], {
             RGBColor[0.9911213, 0.989158, 0.6922468999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{86, 110}], {
             RGBColor[0.988628, 0.9895654, 0.8381269999999997]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{86, 141}], {
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 165}], {
             RGBColor[0.9916771, 0.9903468, 0.7527422999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 179}], {
             RGBColor[0.9372631, 0.7821688, 0.5323149999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 240}], {
             RGBColor[0.988628, 0.9895654, 0.8381269999999997]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{86, 281}], {
             RGBColor[0.904306, 0.9244312000000001, 0.9104094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 149}], {
             RGBColor[
             0.9248122999999999, 0.8083985999999999, 0.6095543999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 187}], {
             RGBColor[0.9700618999999999, 0.9749632, 0.8223346999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 227}], {
             RGBColor[0.9058337999999999, 0.9275012, 0.9822093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 264}], {
             RGBColor[
             0.9689502999999999, 0.9725855999999999, 0.7013438999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 99}], {
             RGBColor[0.659794, 0.7316336, 0.9686064]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[0.9155324, 0.9347344, 0.9657921]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{88, 198}], {
             RGBColor[0.6976022, 0.762328, 0.9715828]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{88, 201}], {
             RGBColor[0.9293865, 0.9412886, 0.7062413999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 222}], {
             RGBColor[0.9304981, 0.9436662, 0.8272321999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 258}], {
             RGBColor[0.9058337999999999, 0.9275012, 0.9822093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 260}], {
             RGBColor[0.9220785, 0.9166369999999999, 0.6778511999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 261}], {
             RGBColor[0.9058337999999999, 0.9275012, 0.9822093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 278}], {
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 290}], {
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 111}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{89, 112}], {
             RGBColor[0.9550962, 0.9660314000000001, 0.9608946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 175}], {
             RGBColor[
             0.9792046999999999, 0.9810076000000001, 0.7454220999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 177}], {
             RGBColor[0.8213394, 0.8607760000000001, 0.9565030999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 242}], {
             RGBColor[0.9386753999999999, 0.953188, 0.9679995]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[0.9713409, 0.9551671999999999, 0.6565364999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 285}], {
             RGBColor[0.9550962, 0.9660314000000001, 0.9608946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 123}], {
             RGBColor[0.35393070000000004`, 0.46692290000000003`, 0.9447799]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 134}], {
             RGBColor[0.5718608999999999, 0.6393293, 0.9389892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 144}], {
             RGBColor[0.5815595, 0.6465624999999999, 0.922572]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{90, 158}], {
             RGBColor[0.5225985, 0.6007990999999999, 0.9603039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 252}], {
             RGBColor[0.5815595, 0.6465624999999999, 0.922572]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{90, 253}], {
             RGBColor[0.5718608999999999, 0.6393293, 0.9389892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[0.5815595, 0.6465624999999999, 0.922572]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{91, 102}], {
             RGBColor[0.9930588, 0.9875617999999999, 0.4858713999999995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 162}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 191}], {
             RGBColor[
             0.9062435000000001, 0.9228350000000001, 0.7040339999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 203}], {
             RGBColor[0.9786489, 0.9798188, 0.6849266999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 239}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 153}], {
             RGBColor[
             0.8117499000000001, 0.7851895999999998, 0.6218140999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 163}], {
             RGBColor[
             0.9455066999999999, 0.8904449999999998, 0.6262055999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 189}], {
             RGBColor[0.9671219, 0.9058285999999998, 0.5566131999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 211}], {
             RGBColor[0.9290859, 0.8776015999999998, 0.6333104999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 216}], {
             RGBColor[0.9693398999999999, 0.9067457999999998, 0.5198552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 221}], {
             RGBColor[0.9649038999999999, 0.9049113999999998, 0.5933712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 94}], {
             RGBColor[0.7607187, 0.8074124, 0.6907173999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 160}], {
             RGBColor[0.9525295, 0.9597422, 0.7084488]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{93, 164}], {
             RGBColor[
             0.9690593999999999, 0.9042323999999997, 0.3502376999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 168}], {
             RGBColor[0.9905655, 0.9879692, 0.6317514999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 277}], {
             RGBColor[
             0.9689502999999999, 0.9725855999999999, 0.7013438999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 124}], {
             RGBColor[
             0.4622118000000002, 0.5727132000000001, 0.9512400000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 125}], {
             RGBColor[0.49112620000000007`, 0.5977574, 0.9530824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 142}], {
             RGBColor[0.6813439, 0.44445039999999975`, 0.5680071999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 150}], {
             RGBColor[0.7587812, 0.8090086000000001, 0.8970928999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 200}], {
             RGBColor[0.49112620000000007`, 0.5977574, 0.9530824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[0.7618303, 0.80979, 0.8117081999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{94, 295}], {
             RGBColor[0.7565632, 0.8080914, 0.9338508999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 96}], {
             RGBColor[0.866563, 0.8957615999999999, 0.9436267]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{95, 105}], {
             RGBColor[0.6767424000000002, 0.7468164000000002, 0.968811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 109}], {
             RGBColor[0.8712743000000001, 0.8962714, 0.7609885999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 138}], {
             RGBColor[0.870999, 0.8975960000000001, 0.8701107]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{95, 140}], {
             RGBColor[0.7134090000000002, 0.7760398000000001, 0.9720696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 154}], {
             RGBColor[0.748934, 0.8037922, 0.9756104]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{95, 171}], {
             RGBColor[0.868781, 0.8966788, 0.9068686999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{95, 198}], {
             RGBColor[0.6389342, 0.7161219999999999, 0.9658346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 245}], {
             RGBColor[0.8471658, 0.8812952000000001, 0.9764611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 289}], {
             RGBColor[0.748934, 0.8037922, 0.9756104]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{96, 105}], {
             RGBColor[0.7943714000000002, 0.8387858000000001, 0.9368273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 138}], {
             RGBColor[0.988628, 0.9895654, 0.8381270000000001]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{96, 140}], {
             RGBColor[
             0.8310380000000002, 0.8680092000000001, 0.9400858999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 171}], {
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 196}], {
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 198}], {
             RGBColor[0.7565632, 0.8080914, 0.9338508999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 222}], {
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 245}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{96, 278}], {
             RGBColor[0.948374, 0.9604212000000001, 0.9515823]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{96, 289}], {
             RGBColor[0.866563, 0.8957615999999999, 0.9436267]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{96, 290}], {
             RGBColor[0.948374, 0.9604212000000001, 0.9515823]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{96, 298}], {
             RGBColor[
             0.8310380000000002, 0.8680092000000001, 0.9400858999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 134}], {
             RGBColor[0.8213394, 0.8607760000000001, 0.9565030999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 144}], {
             RGBColor[
             0.8310380000000002, 0.8680092000000001, 0.9400858999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 159}], {
             RGBColor[0.7720770000000001, 0.8222458000000001, 0.9778178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 235}], {
             RGBColor[0.6034092000000002, 0.6883696000000001, 0.9622938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 252}], {
             RGBColor[
             0.8310380000000002, 0.8680092000000001, 0.9400858999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 292}], {
             RGBColor[0.5656010000000001, 0.6576752000000001, 0.9593174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 122}], {
             RGBColor[
             0.5077722000000002, 0.6075868000000001, 0.9556325999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 160}], {
             RGBColor[0.7952200000000001, 0.8406994000000001, 0.9800252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 178}], {
             RGBColor[0.8278855, 0.8426785999999999, 0.6685621999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 181}], {
             RGBColor[0.8116408000000002, 0.8535428, 0.9729203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 182}], {
             RGBColor[0.835474, 0.8698436, 0.8665699]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{98, 208}], {
             RGBColor[0.7134090000000002, 0.7760398000000001, 0.9720696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 246}], {
             RGBColor[0.8278855, 0.8426785999999999, 0.6685621999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 296}], {
             RGBColor[0.7952200000000001, 0.8406994000000001, 0.9800252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 104}], {
             RGBColor[0.718755, 0.777397, 0.9308745]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 123}], {
             RGBColor[0.49112620000000007`, 0.5977574, 0.9530824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 157}], {
             RGBColor[0.601126, 0.6854275999999999, 0.9628582]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{99, 201}], {
             RGBColor[0.7229105, 0.776718, 0.6877409999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[0.6993578, 0.7629306, 0.9637089]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{99, 222}], {
             RGBColor[0.7240221, 0.7790956, 0.8087317999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 229}], {
             RGBColor[0.7229105, 0.776718, 0.6877409999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{99, 257}], {
             RGBColor[0.718755, 0.777397, 0.9308745]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 259}], {
             RGBColor[0.7231909999999999, 0.7792314, 0.8573585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 261}], {
             RGBColor[0.6993578, 0.7629306, 0.9637089]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{100, 121}], {
             RGBColor[0.988628, 0.9895654, 0.8381270000000001]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{100, 125}], {
             RGBColor[0.723191, 0.7792314, 0.8573585]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{100, 127}], {
             RGBColor[0.835474, 0.8698436, 0.8665699]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{100, 136}], {
             RGBColor[0.835474, 0.8698436, 0.8665699]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{100, 137}], {
             RGBColor[0.6653622, 0.7291430000000001, 0.8536737000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 170}], {
             RGBColor[0.9789294, 0.9823322000000001, 0.8545442000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 192}], {
             RGBColor[0.9065240000000001, 0.9253484000000001, 0.8736515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 228}], {
             RGBColor[0.929667, 0.943802, 0.8758589]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 232}], {
             RGBColor[0.723191, 0.7792314, 0.8573585]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{100, 240}], {
             RGBColor[0.9908459999999999, 0.9904826, 0.8013689999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 256}], {
             RGBColor[0.9065240000000001, 0.9253484000000001, 0.8736515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 299}], {
             RGBColor[0.9927835, 0.9888863999999999, 0.5949935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 108}], {
             RGBColor[0.8568644, 0.8885284, 0.9600439000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 114}], {
             RGBColor[0.8568644, 0.8885284, 0.9600439000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 187}], {
             RGBColor[0.8718300999999999, 0.8974602, 0.8214839999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 205}], {
             RGBColor[0.8076019999999999, 0.8499981999999999, 0.9813586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 207}], {
             RGBColor[0.8307450000000001, 0.8684518, 0.9835659999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 213}], {
             RGBColor[0.8718300999999999, 0.8974602, 0.8214839999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 231}], {
             RGBColor[0.748934, 0.8037922, 0.9756104]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{102, 133}], {
             RGBColor[0.8357493000000001, 0.868519, 0.7574477999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 142}], {
             RGBColor[
             0.9136839999999999, 0.6245997999999997, 0.36316119999999963`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 162}], {
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[0.9784428, 0.9382585999999997, 0.4290909999999994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 210}], {
             RGBColor[0.9784428, 0.9382585999999997, 0.4290909999999994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 237}], {
             RGBColor[0.9941704, 0.9899394, 0.6068621999999995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 239}], {
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 295}], {
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 116}], {
             RGBColor[0.7985269000000002, 0.8381068, 0.6936937999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 119}], {
             RGBColor[0.4711056000000002, 0.5783634000000002, 0.952374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 152}], {
             RGBColor[0.7354104000000001, 0.7930224000000001, 0.9745592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 164}], {
             RGBColor[
             0.7750833000000001, 0.7559661999999999, 0.6185554999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 168}], {
             RGBColor[
             0.7965894000000001, 0.8397030000000001, 0.9000692999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 241}], {
             RGBColor[0.6045508000000003, 0.6898406000000002, 0.9620116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 277}], {
             RGBColor[0.7749742000000002, 0.8243194000000001, 0.9696617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 128}], {
             RGBColor[0.9810395, 0.9624003999999999, 0.6401192999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 157}], {
             RGBColor[0.866563, 0.8957615999999999, 0.9436267]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{104, 173}], {
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 201}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 209}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 218}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{104, 229}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 261}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{104, 279}], {
             RGBColor[
             0.8310380000000002, 0.8680092000000001, 0.9400858999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 129}], {
             RGBColor[
             0.7990827000000001, 0.8392956000000001, 0.7541891999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 140}], {
             RGBColor[0.6412174000000003, 0.7190640000000001, 0.9652702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 149}], {
             RGBColor[0.7543889000000001, 0.6739198, 0.6019043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 171}], {
             RGBColor[
             0.7965894000000001, 0.8397030000000001, 0.9000692999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 196}], {
             RGBColor[
             0.7965894000000001, 0.8397030000000001, 0.9000692999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 230}], {
             RGBColor[
             0.7965894000000001, 0.8397030000000001, 0.9000692999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 245}], {
             RGBColor[0.7749742000000002, 0.8243194000000001, 0.9696617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 263}], {
             RGBColor[0.7354104000000001, 0.7930224000000001, 0.9745592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 289}], {
             RGBColor[0.6767424000000002, 0.7468164000000002, 0.968811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 298}], {
             RGBColor[0.6412174000000003, 0.7190640000000001, 0.9652702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 151}], {
             RGBColor[0.9397564, 0.7817613999999999, 0.38643489999999964`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 167}], {
             RGBColor[
             0.9792046999999999, 0.9810076000000001, 0.7454220999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 194}], {
             RGBColor[0.9911213, 0.989158, 0.6922468999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{106, 215}], {
             RGBColor[0.9530853, 0.960931, 0.7689441999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{106, 283}], {
             RGBColor[
             0.9792046999999999, 0.9810076000000001, 0.7454220999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 286}], {
             RGBColor[0.7234663, 0.7779068, 0.7482363999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 297}], {
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 110}], {
             RGBColor[0.988628, 0.9895654, 0.8381269999999997]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{107, 127}], {
             RGBColor[
             0.8332560000000001, 0.8689264000000001, 0.9033278999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 141}], {
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 165}], {
             RGBColor[0.9916771, 0.9903468, 0.7527422999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[0.9372631, 0.7821688, 0.5323149999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 240}], {
             RGBColor[0.988628, 0.9895654, 0.8381269999999997]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{107, 281}], {
             RGBColor[0.904306, 0.9244312000000001, 0.9104094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 114}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{108, 145}], {
             RGBColor[0.5718609, 0.6393293, 0.9389892]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{108, 169}], {
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 187}], {
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 205}], {
             RGBColor[0.9155324, 0.9347344, 0.9657921]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{108, 213}], {
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 219}], {
             RGBColor[0.9786489, 0.9798188, 0.6849266999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 221}], {
             RGBColor[0.9744934, 0.9804978, 0.9280602]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{108, 264}], {
             RGBColor[0.9786489, 0.9798188, 0.6849266999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 110}], {
             RGBColor[0.9911213, 0.989158, 0.6922468999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{109, 138}], {
             RGBColor[0.9933392999999999, 0.9900752, 0.6554888999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 154}], {
             RGBColor[0.8712743000000001, 0.8962714, 0.7609885999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 179}], {
             RGBColor[0.9397564, 0.7817613999999999, 0.38643489999999964`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 258}], {
             RGBColor[0.9695061, 0.9737744, 0.7618392999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 138}], {
             RGBColor[0.9908459999999999, 0.9904826, 0.8013689999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 141}], {
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 154}], {
             RGBColor[0.868781, 0.8966788, 0.9068686999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{110, 165}], {
             RGBColor[0.9916771, 0.9903468, 0.7527422999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 179}], {
             RGBColor[0.9372631, 0.7821688, 0.5323149999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 281}], {
             RGBColor[0.904306, 0.9244312000000001, 0.9104094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 190}], {
             RGBColor[0.9253465, 0.7740184, 0.5854902]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{111, 212}], {
             RGBColor[0.6801420000000001, 0.7451196000000001, 0.9454493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 242}], {
             RGBColor[0.9386753999999999, 0.953188, 0.9679995]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{111, 250}], {
             RGBColor[
             0.9792046999999999, 0.9810076000000001, 0.7454220999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 280}], {
             RGBColor[0.9713409, 0.9551671999999999, 0.6565364999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 115}], {
             RGBColor[0.9692308, 0.975099, 0.8709614]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{112, 134}], {
             RGBColor[0.9550962, 0.9660314000000001, 0.9608946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 146}], {
             RGBColor[
             0.9689502999999999, 0.9725855999999999, 0.7013438999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 159}], {
             RGBColor[0.9058337999999999, 0.9275012, 0.9822093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 175}], {
             RGBColor[0.9695061, 0.9737744, 0.7618392999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 204}], {
             RGBColor[0.9550962, 0.9660314000000001, 0.9608946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 235}], {
             RGBColor[0.737166, 0.793625, 0.9666853]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 242}], {
             RGBColor[0.9289768, 0.9459548, 0.9844166999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 252}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{112, 253}], {
             RGBColor[0.9550962, 0.9660314000000001, 0.9608946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 280}], {
             RGBColor[0.9616423, 0.9479339999999998, 0.6729536999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 292}], {
             RGBColor[0.6993578, 0.7629306, 0.9637089]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{113, 135}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{113, 224}], {
             RGBColor[0.9786489, 0.9798188, 0.6849266999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 249}], {
             RGBColor[0.9789294, 0.9823322000000001, 0.8545442000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 254}], {
             RGBColor[
             0.9792046999999999, 0.9810076000000001, 0.7454220999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 258}], {
             RGBColor[0.9550962, 0.9660314000000001, 0.9608946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 260}], {
             RGBColor[0.9713409, 0.9551671999999999, 0.6565364999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 278}], {
             RGBColor[0.9386753999999999, 0.953188, 0.9679995]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{113, 288}], {
             RGBColor[0.7846728000000001, 0.8315526000000002, 0.9532445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 290}], {
             RGBColor[0.9386753999999999, 0.953188, 0.9679995]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{114, 145}], {
             RGBColor[0.5718609, 0.6393293, 0.9389892]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{114, 169}], {
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 187}], {
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 213}], {
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 219}], {
             RGBColor[0.9786489, 0.9798188, 0.6849266999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 221}], {
             RGBColor[0.9744934, 0.9804978, 0.9280602]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{114, 231}], {
             RGBColor[0.8568644, 0.8885284, 0.9600439000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 264}], {
             RGBColor[0.9786489, 0.9798188, 0.6849266999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 132}], {
             RGBColor[0.9051914999999999, 0.5627634, 0.4644145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 146}], {
             RGBColor[0.9927835, 0.9888863999999999, 0.5949935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 159}], {
             RGBColor[0.929667, 0.943802, 0.8758589]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 204}], {
             RGBColor[0.9789294, 0.9823322000000001, 0.8545442000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 242}], {
             RGBColor[0.9528099999999999, 0.9622556, 0.8780663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 243}], {
             RGBColor[0.9528099999999999, 0.9622556, 0.8780663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 294}], {
             RGBColor[0.9692308, 0.975099, 0.8709614]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{116, 119}], {
             RGBColor[0.6650817, 0.7266296, 0.6840561999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 133}], {
             RGBColor[0.8351935000000001, 0.8673302, 0.6969523999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 152}], {
             RGBColor[0.9293865, 0.9412886, 0.7062413999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 164}], {
             RGBColor[
             0.9690593999999999, 0.9042323999999997, 0.3502376999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 168}], {
             RGBColor[0.9905655, 0.9879692, 0.6317514999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 210}], {
             RGBColor[0.977887, 0.9370697999999997, 0.3685955999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 241}], {
             RGBColor[0.7985269000000002, 0.8381068, 0.6936937999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 277}], {
             RGBColor[
             0.9689502999999999, 0.9725855999999999, 0.7013438999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 161}], {
             RGBColor[0.8213394, 0.8607760000000001, 0.9565030999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 120}], {
             RGBColor[0.866563, 0.8957615999999999, 0.9436267]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{118, 130}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 176}], {
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[0.6898406000000001, 0.7523528000000002, 0.9290321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 220}], {
             RGBColor[0.988628, 0.9895654, 0.8381270000000001]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{118, 226}], {
             RGBColor[0.866563, 0.8957615999999999, 0.9436267]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{118, 228}], {
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 266}], {
             RGBColor[0.9744934, 0.9804978, 0.9280602]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{119, 152}], {
             RGBColor[0.6019652, 0.6815452000000001, 0.9649216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 164}], {
             RGBColor[0.6416381, 0.6444889999999999, 0.6089179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 168}], {
             RGBColor[
             0.6631442000000001, 0.7282258000000001, 0.8904316999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 241}], {
             RGBColor[0.4711056000000002, 0.5783634000000002, 0.952374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 130}], {
             RGBColor[0.784459, 0.8315446, 0.9791512]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{120, 176}], {
             RGBColor[0.868781, 0.8966788, 0.9068686999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{120, 287}], {
             RGBColor[0.8712743000000001, 0.8962714, 0.7609885999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 125}], {
             RGBColor[0.718755, 0.777397, 0.9308745]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 127}], {
             RGBColor[
             0.8310380000000002, 0.8680092000000001, 0.9400858999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 136}], {
             RGBColor[
             0.8310380000000002, 0.8680092000000001, 0.9400858999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 137}], {
             RGBColor[0.6609262, 0.7273086000000001, 0.9271897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 160}], {
             RGBColor[0.948374, 0.9604212000000001, 0.9515823]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{121, 181}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{121, 232}], {
             RGBColor[0.718755, 0.777397, 0.9308745]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 240}], {
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 246}], {
             RGBColor[0.9810395, 0.9624003999999999, 0.6401192999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 256}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 296}], {
             RGBColor[0.948374, 0.9604212000000001, 0.9515823]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{121, 299}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 136}], {
             RGBColor[
             0.5077722000000002, 0.6075868000000001, 0.9556325999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 160}], {
             RGBColor[0.6251082000000001, 0.6999988, 0.967129]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{122, 181}], {
             RGBColor[0.641529, 0.7128422000000001, 0.9600241]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{122, 207}], {
             RGBColor[0.6251082000000001, 0.6999988, 0.967129]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{122, 231}], {
             RGBColor[0.5432972, 0.6353392, 0.9591734000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 232}], {
             RGBColor[
             0.3954892000000001, 0.5169746000000001, 0.9464212000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 240}], {
             RGBColor[
             0.6631442000000001, 0.7282258000000001, 0.8904316999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 246}], {
             RGBColor[0.6577737, 0.7019779999999999, 0.6556659999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 256}], {
             RGBColor[0.5788222000000001, 0.6630916000000001, 0.9627142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 296}], {
             RGBColor[0.6251082000000001, 0.6999988, 0.967129]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{122, 299}], {
             RGBColor[0.6650817, 0.7266296000000001, 0.6840561999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 144}], {
             RGBColor[0.7565632, 0.8080914, 0.9338508999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 157}], {
             RGBColor[0.6389342, 0.7161219999999999, 0.9658346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 229}], {
             RGBColor[0.7607187, 0.8074124, 0.6907173999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 257}], {
             RGBColor[0.7565632, 0.8080914, 0.9338508999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 259}], {
             RGBColor[0.7609992, 0.8099258, 0.8603349]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{123, 261}], {
             RGBColor[0.737166, 0.793625, 0.9666853]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 125}], {
             RGBColor[0.42440360000000016`, 0.5420188000000001, 0.9482636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 142}], {
             RGBColor[0.6146213000000001, 0.38871179999999983`, 0.5631884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 150}], {
             RGBColor[
             0.6920586000000002, 0.7532700000000001, 0.8922740999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 200}], {
             RGBColor[0.42440360000000016`, 0.5420188000000001, 0.9482636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 237}], {
             RGBColor[0.6951077000000001, 0.7540514, 0.8068894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 282}], {
             RGBColor[0.6945519000000002, 0.7528626, 0.7463939999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 295}], {
             RGBColor[0.6898406000000001, 0.7523528000000002, 0.9290321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 136}], {
             RGBColor[0.5656010000000001, 0.6576752000000001, 0.9593174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 150}], {
             RGBColor[
             0.7209730000000001, 0.7783142000000001, 0.8941164999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[0.7090563999999999, 0.7701638, 0.9472917000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 192}], {
             RGBColor[0.6366510000000001, 0.71318, 0.966399]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{125, 195}], {
             RGBColor[0.718755, 0.777397, 0.9308745]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 200}], {
             RGBColor[0.45331800000000005`, 0.567063, 0.950106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 256}], {
             RGBColor[0.6366510000000001, 0.71318, 0.966399]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{125, 299}], {
             RGBColor[0.7229105, 0.776718, 0.6877409999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{126, 155}], {
             RGBColor[0.9304981, 0.9436662, 0.8272321999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 163}], {
             RGBColor[0.9700618999999999, 0.9749632, 0.8223346999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 184}], {
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 189}], {
             RGBColor[0.9916771, 0.9903468, 0.7527422999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 197}], {
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 214}], {
             RGBColor[
             0.9403121999999999, 0.7829501999999999, 0.4469302999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 216}], {
             RGBColor[0.9938951, 0.991264, 0.7159842999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{126, 275}], {
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 293}], {
             RGBColor[0.9938951, 0.991264, 0.7159842999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{127, 136}], {
             RGBColor[0.6778840000000003, 0.7482874000000002, 0.9685288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 137}], {
             RGBColor[
             0.5077722000000002, 0.6075868000000001, 0.9556325999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 141}], {
             RGBColor[0.8116408000000002, 0.8535428, 0.9729203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 165}], {
             RGBColor[0.8363051000000001, 0.8697078, 0.8179431999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 170}], {
             RGBColor[0.8213394, 0.8607760000000001, 0.9565030999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 192}], {
             RGBColor[0.7489340000000002, 0.8037922000000002, 0.9756104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 228}], {
             RGBColor[0.7720770000000001, 0.8222458000000001, 0.9778178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 232}], {
             RGBColor[0.5656010000000001, 0.6576752000000001, 0.9593174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 240}], {
             RGBColor[
             0.8332560000000001, 0.8689264000000001, 0.9033278999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 256}], {
             RGBColor[0.7489340000000002, 0.8037922000000002, 0.9756104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 281}], {
             RGBColor[0.7489340000000002, 0.8037922000000002, 0.9756104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 299}], {
             RGBColor[0.8351935000000001, 0.8673302, 0.6969523999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 173}], {
             RGBColor[
             0.9857507999999999, 0.9629101999999998, 0.4574811999999995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 209}], {
             RGBColor[0.9810395, 0.9624003999999999, 0.6401192999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 218}], {
             RGBColor[0.9616423, 0.9479339999999998, 0.6729536999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 276}], {
             RGBColor[0.8278855, 0.8426785999999999, 0.6685621999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 279}], {
             RGBColor[0.8278855, 0.8426785999999999, 0.6685621999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 161}], {
             RGBColor[0.8357493000000001, 0.868519, 0.7574477999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 230}], {
             RGBColor[0.9911213, 0.989158, 0.6922468999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{129, 263}], {
             RGBColor[0.9299423, 0.9424774, 0.7667367999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 265}], {
             RGBColor[0.9397564, 0.7817613999999999, 0.38643489999999964`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 269}], {
             RGBColor[0.9530853, 0.960931, 0.7689441999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{129, 289}], {
             RGBColor[0.8712743000000001, 0.8962714, 0.7609885999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 298}], {
             RGBColor[0.8357493000000001, 0.868519, 0.7574477999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 176}], {
             RGBColor[0.904306, 0.9244312000000001, 0.9104094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 199}], {
             RGBColor[
             0.6077366000000002, 0.6881358000000002, 0.9645566000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 220}], {
             RGBColor[0.9065240000000001, 0.9253484000000001, 0.8736515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 226}], {
             RGBColor[0.784459, 0.8315446, 0.9791512]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{130, 228}], {
             RGBColor[0.8431270000000001, 0.8777506, 0.9848994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 266}], {
             RGBColor[0.8923894000000001, 0.9162808, 0.9635847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 139}], {
             RGBColor[0.7074163, 0.601612, 0.5912809]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{131, 143}], {
             RGBColor[0.9372631, 0.7821688, 0.5323149999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 172}], {
             RGBColor[0.9394811, 0.783086, 0.495557]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 174}], {
             RGBColor[0.9253465, 0.7740184, 0.5854902]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{131, 183}], {
             RGBColor[0.7818911000000002, 0.6615298000000001, 0.5975159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 283}], {
             RGBColor[0.9253465, 0.7740184, 0.5854902]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{132, 188}], {
             RGBColor[0.9060226, 0.5626276, 0.41578779999999993`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 212}], {
             RGBColor[0.6064041000000001, 0.3255508000000001, 0.5553196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 243}], {
             RGBColor[0.8649375, 0.5336192, 0.5778698]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{132, 294}], {
             RGBColor[0.8813583, 0.5464626, 0.5707649]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{133, 162}], {
             RGBColor[
             0.8310380000000002, 0.8680092000000001, 0.9400858999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 164}], {
             RGBColor[
             0.8117499000000001, 0.7851895999999998, 0.6218140999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 210}], {
             RGBColor[
             0.8205775000000001, 0.8180269999999998, 0.6401719999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 239}], {
             RGBColor[
             0.8310380000000002, 0.8680092000000001, 0.9400858999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 241}], {
             RGBColor[0.6412174000000003, 0.7190640000000001, 0.9652702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 277}], {
             RGBColor[0.8116408000000002, 0.8535428, 0.9729203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 144}], {
             RGBColor[0.9744934, 0.9804978, 0.9280602]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{134, 159}], {
             RGBColor[0.9155324, 0.9347344, 0.9657921]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{134, 175}], {
             RGBColor[
             0.9792046999999999, 0.9810076000000001, 0.7454220999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 204}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{134, 235}], {
             RGBColor[0.7468646, 0.8008582, 0.9502681]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{134, 252}], {
             RGBColor[0.9744934, 0.9804978, 0.9280602]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{134, 253}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{134, 292}], {
             RGBColor[0.7090564, 0.7701638, 0.9472917000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 224}], {
             RGBColor[0.9786489, 0.9798188, 0.6849266999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 249}], {
             RGBColor[0.9789294, 0.9823322000000001, 0.8545442000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 254}], {
             RGBColor[
             0.9792046999999999, 0.9810076000000001, 0.7454220999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 258}], {
             RGBColor[0.9550962, 0.9660314000000001, 0.9608946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 260}], {
             RGBColor[0.9713409, 0.9551671999999999, 0.6565364999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 288}], {
             RGBColor[0.7846728000000001, 0.8315526000000002, 0.9532445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 137}], {
             RGBColor[
             0.5077722000000002, 0.6075868000000001, 0.9556325999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 165}], {
             RGBColor[0.8363051000000001, 0.8697078, 0.8179431999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 181}], {
             RGBColor[0.8116408000000002, 0.8535428, 0.9729203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 232}], {
             RGBColor[0.5656010000000001, 0.6576752000000001, 0.9593174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 240}], {
             RGBColor[
             0.8332560000000001, 0.8689264000000001, 0.9033278999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 256}], {
             RGBColor[0.7489340000000002, 0.8037922000000002, 0.9756104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 296}], {
             RGBColor[0.7952200000000001, 0.8406994000000001, 0.9800252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 299}], {
             RGBColor[0.8351935000000001, 0.8673302, 0.6969523999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 170}], {
             RGBColor[0.6512276, 0.7200754, 0.9436069]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{137, 192}], {
             RGBColor[0.5788222000000001, 0.6630916000000001, 0.9627142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 195}], {
             RGBColor[0.6609262, 0.7273086, 0.9271897]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{137, 220}], {
             RGBColor[0.6653622, 0.7291430000000001, 0.8536737000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 228}], {
             RGBColor[0.6019652, 0.6815452000000001, 0.9649216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 232}], {
             RGBColor[
             0.3954892000000001, 0.5169746000000001, 0.9464212000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 256}], {
             RGBColor[0.5788222000000001, 0.6630916000000001, 0.9627142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 266}], {
             RGBColor[0.6512276, 0.7200754, 0.9436069]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{137, 299}], {
             RGBColor[0.6650817, 0.7266296000000001, 0.6840561999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 154}], {
             RGBColor[0.870999, 0.8975960000000001, 0.8701107]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{138, 171}], {
             RGBColor[0.9908459999999999, 0.9904826, 0.8013689999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 245}], {
             RGBColor[0.9692308, 0.975099, 0.8709614]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{138, 258}], {
             RGBColor[0.9692308, 0.975099, 0.8709614]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{139, 147}], {
             RGBColor[0.7269279, 0.6842486, 0.6072535]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{139, 148}], {
             RGBColor[0.7618303, 0.80979, 0.8117081999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{139, 172}], {
             RGBColor[0.7609992, 0.8099258, 0.8603349]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{139, 183}], {
             RGBColor[0.6034092000000002, 0.6883696000000001, 0.9622938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 206}], {
             RGBColor[0.6389342, 0.7161219999999999, 0.9658346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 244}], {
             RGBColor[0.7618303, 0.80979, 0.8117081999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{139, 272}], {
             RGBColor[0.5667426000000002, 0.6591462000000001, 0.9590352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 149}], {
             RGBColor[0.7910555000000001, 0.7031432, 0.6051629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 171}], {
             RGBColor[
             0.8332560000000001, 0.8689264000000001, 0.9033278999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 196}], {
             RGBColor[
             0.8332560000000001, 0.8689264000000001, 0.9033278999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 198}], {
             RGBColor[0.6034092000000002, 0.6883696000000001, 0.9622938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 222}], {
             RGBColor[0.8363051000000001, 0.8697078, 0.8179431999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 230}], {
             RGBColor[
             0.8332560000000001, 0.8689264000000001, 0.9033278999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 245}], {
             RGBColor[0.8116408000000002, 0.8535428, 0.9729203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 263}], {
             RGBColor[0.7720770000000001, 0.8222458000000001, 0.9778178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 289}], {
             RGBColor[0.7134090000000002, 0.7760398000000001, 0.9720696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 298}], {
             RGBColor[0.6778840000000003, 0.7482874000000002, 0.9685288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 165}], {
             RGBColor[0.9700618999999999, 0.9749632, 0.8223346999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 179}], {
             RGBColor[0.9156479, 0.7667852, 0.6019074]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{141, 232}], {
             RGBColor[0.6993578, 0.7629306, 0.9637089]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 281}], {
             RGBColor[0.8826908, 0.9090476000000001, 0.9800019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[
             0.9111906999999999, 0.6250071999999998, 0.5090412999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 185}], {
             RGBColor[
             0.8985121999999999, 0.5741077999999995, 0.24588539999999973`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 210}], {
             RGBColor[
             0.8985121999999999, 0.5741077999999995, 0.24588539999999973`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 237}], {
             RGBColor[0.9142398, 0.6257885999999997, 0.42365659999999983`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 239}], {
             RGBColor[0.9089727, 0.6240899999999998, 0.5457992999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 282}], {
             RGBColor[
             0.9136839999999999, 0.6245997999999997, 0.36316119999999963`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 283}], {
             RGBColor[0.8992741, 0.6168567999999998, 0.5622164999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 295}], {
             RGBColor[0.9089727, 0.6240899999999998, 0.5457992999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 297}], {
             RGBColor[
             0.9136839999999999, 0.6245997999999997, 0.36316119999999963`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 167}], {
             RGBColor[0.9767113999999999, 0.981415, 0.8913021999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 172}], {
             RGBColor[0.9908459999999999, 0.9904826, 0.8013689999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 174}], {
             RGBColor[0.9767113999999999, 0.981415, 0.8913021999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 185}], {
             RGBColor[
             0.9759494999999999, 0.9386659999999998, 0.5749710999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 237}], {
             RGBColor[0.9916771, 0.9903468, 0.7527422999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 239}], {
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 283}], {
             RGBColor[0.9767113999999999, 0.981415, 0.8913021999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 297}], {
             RGBColor[0.9911213, 0.989158, 0.6922468999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{144, 158}], {
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 235}], {
             RGBColor[0.7565632, 0.8080914, 0.9338508999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 252}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 253}], {
             RGBColor[0.9744934, 0.9804978, 0.9280602]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{144, 257}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 292}], {
             RGBColor[0.718755, 0.777397, 0.9308745]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 169}], {
             RGBColor[0.5868266, 0.6482611, 0.8004292999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 219}], {
             RGBColor[0.585715, 0.6458835, 0.6794385]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{145, 221}], {
             RGBColor[0.5815595, 0.6465624999999999, 0.922572]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{145, 264}], {
             RGBColor[0.585715, 0.6458835, 0.6794385]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{146, 159}], {
             RGBColor[0.9293865, 0.9412886, 0.7062413999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 204}], {
             RGBColor[0.9786489, 0.9798188, 0.6849266999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 235}], {
             RGBColor[0.7607187, 0.8074124, 0.6907173999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 242}], {
             RGBColor[0.9525295, 0.9597422, 0.7084488]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{146, 243}], {
             RGBColor[0.9525295, 0.9597422, 0.7084488]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{146, 292}], {
             RGBColor[0.7229105, 0.776718, 0.6877409999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{147, 148}], {
             RGBColor[0.9598238, 0.8655868, 0.4629028999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 172}], {
             RGBColor[0.9589927, 0.8657226, 0.5115296]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{147, 183}], {
             RGBColor[0.8014027000000001, 0.7441664000000001, 0.6134885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 206}], {
             RGBColor[0.8369276999999999, 0.7719187999999999, 0.6170293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 244}], {
             RGBColor[0.9598238, 0.8655868, 0.4629028999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 270}], {
             RGBColor[0.6891197, 0.6535542, 0.6042771]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{147, 272}], {
             RGBColor[0.7647361000000001, 0.7149430000000001, 0.6102299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 172}], {
             RGBColor[0.9938951, 0.991264, 0.7159842999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{148, 183}], {
             RGBColor[0.8363051000000001, 0.8697078, 0.8179431999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 203}], {
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 206}], {
             RGBColor[0.8718300999999999, 0.8974602, 0.8214839999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 244}], {
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 270}], {
             RGBColor[0.7240221, 0.7790956, 0.8087317999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 272}], {
             RGBColor[
             0.7996385000000001, 0.8404844000000001, 0.8146845999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 171}], {
             RGBColor[0.9464275, 0.8237821999999999, 0.5399619999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 227}], {
             RGBColor[0.8852484999999999, 0.7771016, 0.6144518999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 245}], {
             RGBColor[
             0.9248122999999999, 0.8083985999999999, 0.6095543999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 289}], {
             RGBColor[0.8265804999999999, 0.7308955999999999, 0.6087037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 298}], {
             RGBColor[0.7910555000000001, 0.7031432, 0.6051629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 200}], {
             RGBColor[0.720973, 0.7783142000000001, 0.8941164999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 237}], {
             RGBColor[0.9916771, 0.9903468, 0.7527422999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 282}], {
             RGBColor[0.9911213, 0.989158, 0.6922468999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{150, 295}], {
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 167}], {
             RGBColor[0.9253465, 0.7740184, 0.5854902]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{151, 194}], {
             RGBColor[0.9372631, 0.7821688, 0.5323149999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 251}], {
             RGBColor[0.9372631, 0.7821688, 0.5323149999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 286}], {
             RGBColor[0.6696081, 0.5709176, 0.5883045]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{152, 241}], {
             RGBColor[0.7354104000000001, 0.7930224000000001, 0.9745592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 277}], {
             RGBColor[0.9058337999999999, 0.9275012, 0.9822093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 163}], {
             RGBColor[0.8116408000000002, 0.8535428, 0.9729203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 211}], {
             RGBColor[0.7952200000000001, 0.8406994000000001, 0.9800252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 216}], {
             RGBColor[0.835474, 0.8698436, 0.8665699]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{153, 219}], {
             RGBColor[0.8351935000000001, 0.8673302, 0.6969523999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 221}], {
             RGBColor[
             0.8310380000000002, 0.8680092000000001, 0.9400858999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 171}], {
             RGBColor[0.868781, 0.8966788, 0.9068686999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{154, 179}], {
             RGBColor[0.8174161, 0.6892822, 0.6010567]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{154, 245}], {
             RGBColor[0.8471658, 0.8812952000000001, 0.9764611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 156}], {
             RGBColor[0.9299423, 0.9424774, 0.7667367999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 184}], {
             RGBColor[0.9155324, 0.9347344, 0.9657921]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{155, 197}], {
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 202}], {
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 214}], {
             RGBColor[0.8760840999999999, 0.7354882, 0.6068049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 275}], {
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 293}], {
             RGBColor[0.929667, 0.943802, 0.8758589]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 178}], {
             RGBColor[
             0.9857507999999999, 0.9629101999999998, 0.4574811999999995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 202}], {
             RGBColor[0.9530853, 0.960931, 0.7689441999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{156, 208}], {
             RGBColor[0.8712743000000001, 0.8962714, 0.7609885999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 214}], {
             RGBColor[0.9397564, 0.7817613999999999, 0.38643489999999964`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 268}], {
             RGBColor[0.9397564, 0.7817613999999999, 0.38643489999999964`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 201}], {
             RGBColor[0.8707185, 0.8950826, 0.7004931999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 218}], {
             RGBColor[0.8471658, 0.8812952000000001, 0.9764611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 229}], {
             RGBColor[0.8707185, 0.8950826, 0.7004931999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 257}], {
             RGBColor[0.866563, 0.8957615999999999, 0.9436267]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{157, 259}], {
             RGBColor[0.870999, 0.8975960000000001, 0.8701107]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{157, 261}], {
             RGBColor[0.8471658, 0.8812952000000001, 0.9764611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 284}], {
             RGBColor[0.748934, 0.8037922, 0.9756104]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{158, 175}], {
             RGBColor[0.9299423, 0.9424774, 0.7667367999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 177}], {
             RGBColor[0.7720770000000001, 0.8222458000000001, 0.9778178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 217}], {
             RGBColor[0.9299423, 0.9424774, 0.7667367999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 252}], {
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 253}], {
             RGBColor[0.9155324, 0.9347344, 0.9657921]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{159, 175}], {
             RGBColor[0.9299423, 0.9424774, 0.7667367999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 204}], {
             RGBColor[0.9155324, 0.9347344, 0.9657921]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{159, 235}], {
             RGBColor[0.6976022, 0.762328, 0.9715828]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{159, 252}], {
             RGBColor[0.9252309999999999, 0.9419676, 0.9493749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 253}], {
             RGBColor[0.9155324, 0.9347344, 0.9657921]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{159, 292}], {
             RGBColor[0.659794, 0.7316336, 0.9686064]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{160, 168}], {
             RGBColor[0.950592, 0.9613384, 0.9148242999999998]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[0.9289768, 0.9459548, 0.9844166999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 246}], {
             RGBColor[
             0.9452214999999999, 0.9350905999999999, 0.6800585999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 256}], {
             RGBColor[
             0.8662700000000001, 0.8962042000000001, 0.9871068000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 296}], {
             RGBColor[0.912556, 0.9331114, 0.9915216]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{160, 299}], {
             RGBColor[0.9525295, 0.9597422, 0.7084487999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 186}], {
             RGBColor[0.7952200000000001, 0.8406994000000001, 0.9800252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 230}], {
             RGBColor[
             0.8332560000000001, 0.8689264000000001, 0.9033278999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 265}], {
             RGBColor[0.7818911000000002, 0.6615298000000001, 0.5975159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 269}], {
             RGBColor[0.7952200000000001, 0.8406994000000001, 0.9800252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 191}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 203}], {
             RGBColor[0.9744934, 0.9804978, 0.9280602]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{162, 210}], {
             RGBColor[0.9737315, 0.9377487999999998, 0.6117290999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 239}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 184}], {
             RGBColor[0.9550962, 0.9660314000000001, 0.9608946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 197}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{163, 211}], {
             RGBColor[0.9289768, 0.9459548, 0.9844166999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 216}], {
             RGBColor[0.9692308, 0.975099, 0.8709614]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{164, 168}], {
             RGBColor[0.9671219, 0.9058285999999998, 0.5566131999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 210}], {
             RGBColor[
             0.9544433999999999, 0.8549291999999995, 0.2934572999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 241}], {
             RGBColor[
             0.7750833000000001, 0.7559661999999999, 0.6185554999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 277}], {
             RGBColor[
             0.9455066999999999, 0.8904449999999998, 0.6262055999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 179}], {
             RGBColor[
             0.9403121999999999, 0.7829501999999999, 0.4469302999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 207}], {
             RGBColor[0.9536411, 0.9621198, 0.8294395999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 232}], {
             RGBColor[0.7240221, 0.7790956, 0.8087317999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 240}], {
             RGBColor[0.9916771, 0.9903468, 0.7527422999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 281}], {
             RGBColor[0.9073551000000001, 0.9252126, 0.8250247999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 217}], {
             RGBColor[0.9911213, 0.989158, 0.6922468999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{166, 233}], {
             RGBColor[0.9908459999999999, 0.9904826, 0.8013689999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 262}], {
             RGBColor[0.9911213, 0.989158, 0.6922468999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{166, 271}], {
             RGBColor[0.950592, 0.9613384, 0.9148242999999998]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{166, 291}], {
             RGBColor[0.9908459999999999, 0.9904826, 0.8013689999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 174}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{167, 185}], {
             RGBColor[
             0.9640328999999999, 0.9305155999999998, 0.6281462999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 194}], {
             RGBColor[0.9767113999999999, 0.981415, 0.8913021999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 215}], {
             RGBColor[0.9386753999999999, 0.953188, 0.9679995]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{167, 282}], {
             RGBColor[
             0.9792046999999999, 0.9810076000000001, 0.7454220999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 283}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{167, 286}], {
             RGBColor[0.7090564, 0.7701638, 0.9472917000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 297}], {
             RGBColor[
             0.9792046999999999, 0.9810076000000001, 0.7454220999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 182}], {
             RGBColor[0.9908459999999999, 0.9904826, 0.8013689999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 277}], {
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 187}], {
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 213}], {
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 219}], {
             RGBColor[0.9936146, 0.9887505999999999, 0.5463667999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 221}], {
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 264}], {
             RGBColor[0.9936146, 0.9887505999999999, 0.5463667999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[0.8923894000000001, 0.9162808, 0.9635847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 195}], {
             RGBColor[0.9744934, 0.9804978, 0.9280602]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{170, 200}], {
             RGBColor[0.7090564, 0.7701638, 0.9472917000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 225}], {
             RGBColor[0.8923894000000001, 0.9162808, 0.9635847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 228}], {
             RGBColor[0.9155324, 0.9347344, 0.9657921]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{170, 255}], {
             RGBColor[0.7846728000000001, 0.8315526000000002, 0.9532445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 198}], {
             RGBColor[0.7587812, 0.8090086000000001, 0.8970928999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 245}], {
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 289}], {
             RGBColor[0.868781, 0.8966788, 0.9068686999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{171, 298}], {
             RGBColor[
             0.8332560000000001, 0.8689264000000001, 0.9033278999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 174}], {
             RGBColor[0.9789294, 0.9823322000000001, 0.8545442000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 183}], {
             RGBColor[0.835474, 0.8698436, 0.8665699]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{172, 203}], {
             RGBColor[0.9789294, 0.9823322000000001, 0.8545442000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 206}], {
             RGBColor[0.870999, 0.8975960000000001, 0.8701107]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{172, 244}], {
             RGBColor[0.9938951, 0.991264, 0.7159842999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{172, 270}], {
             RGBColor[0.723191, 0.7792314, 0.8573585]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{172, 272}], {
             RGBColor[0.7988074000000001, 0.8406202000000002, 0.8633113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 186}], {
             RGBColor[0.9530853, 0.960931, 0.7689441999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{173, 196}], {
             RGBColor[0.9911213, 0.989158, 0.6922468999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{173, 209}], {
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 230}], {
             RGBColor[0.9911213, 0.989158, 0.6922468999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{173, 263}], {
             RGBColor[0.9299423, 0.9424774, 0.7667367999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 276}], {
             RGBColor[0.8357493000000001, 0.868519, 0.7574477999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 279}], {
             RGBColor[0.8357493000000001, 0.868519, 0.7574477999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 185}], {
             RGBColor[
             0.9640328999999999, 0.9305155999999998, 0.6281462999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 194}], {
             RGBColor[0.9767113999999999, 0.981415, 0.8913021999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 283}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{174, 297}], {
             RGBColor[
             0.9792046999999999, 0.9810076000000001, 0.7454220999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 177}], {
             RGBColor[0.8357493000000001, 0.868519, 0.7574477999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 242}], {
             RGBColor[0.9530853, 0.960931, 0.7689441999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{175, 252}], {
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 253}], {
             RGBColor[
             0.9792046999999999, 0.9810076000000001, 0.7454220999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 280}], {
             RGBColor[
             0.9857507999999999, 0.9629101999999998, 0.4574811999999995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 199}], {
             RGBColor[
             0.6920586000000001, 0.7532700000000001, 0.8922740999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 226}], {
             RGBColor[0.868781, 0.8966788, 0.9068686999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{176, 287}], {
             RGBColor[0.9911213, 0.989158, 0.6922468999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{177, 217}], {
             RGBColor[0.8357493000000001, 0.868519, 0.7574477999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 247}], {
             RGBColor[
             0.8117499000000001, 0.7851895999999998, 0.6218140999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 273}], {
             RGBColor[0.8213394, 0.8607760000000001, 0.9565030999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 285}], {
             RGBColor[0.8116408000000002, 0.8535428, 0.9729203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 182}], {
             RGBColor[0.9854755, 0.9642347999999998, 0.5666032999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 202}], {
             RGBColor[
             0.9452214999999999, 0.9350905999999999, 0.6800585999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 208}], {
             RGBColor[0.8634105, 0.8704309999999998, 0.6721029999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 268}], {
             RGBColor[0.9318926, 0.7559209999999998, 0.2975492999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 281}], {
             RGBColor[0.8529411, 0.7170346000000001, 0.6045975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 190}], {
             RGBColor[0.9253465, 0.7740184, 0.5854902]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{180, 250}], {
             RGBColor[
             0.9792046999999999, 0.9810076000000001, 0.7454220999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 207}], {
             RGBColor[0.9289768, 0.9459548, 0.9844166999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 232}], {
             RGBColor[0.6993578, 0.7629306, 0.9637089]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{181, 240}], {
             RGBColor[0.9670128, 0.9741818, 0.9077193999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 246}], {
             RGBColor[0.9616423, 0.9479339999999998, 0.6729536999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 256}], {
             RGBColor[0.8826908, 0.9090476000000001, 0.9800019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 296}], {
             RGBColor[0.9289768, 0.9459548, 0.9844166999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 299}], {
             RGBColor[
             0.9689502999999999, 0.9725855999999999, 0.7013438999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 208}], {
             RGBColor[0.870999, 0.8975960000000001, 0.8701107]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{182, 268}], {
             RGBColor[0.9394811, 0.783086, 0.495557]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 244}], {
             RGBColor[0.8363051000000001, 0.8697078, 0.8179431999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 189}], {
             RGBColor[0.9767113999999999, 0.981415, 0.8913021999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 197}], {
             RGBColor[0.9744934, 0.9804978, 0.9280602]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{184, 202}], {
             RGBColor[0.9386753999999999, 0.953188, 0.9679995]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{184, 214}], {
             RGBColor[0.9253465, 0.7740184, 0.5854902]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{184, 216}], {
             RGBColor[0.9789294, 0.9823322000000001, 0.8545442000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 275}], {
             RGBColor[0.9744934, 0.9804978, 0.9280602]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{184, 293}], {
             RGBColor[0.9789294, 0.9823322000000001, 0.8545442000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 237}], {
             RGBColor[
             0.9789985999999999, 0.9394473999999997, 0.48958639999999964`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 239}], {
             RGBColor[0.9737315, 0.9377487999999998, 0.6117290999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 282}], {
             RGBColor[0.9784428, 0.9382585999999997, 0.4290909999999994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 283}], {
             RGBColor[
             0.9640328999999999, 0.9305155999999998, 0.6281462999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 295}], {
             RGBColor[0.9737315, 0.9377487999999998, 0.6117290999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 297}], {
             RGBColor[0.9784428, 0.9382585999999997, 0.4290909999999994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 196}], {
             RGBColor[0.950592, 0.9613384, 0.9148242999999998]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{186, 230}], {
             RGBColor[0.950592, 0.9613384, 0.9148242999999998]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{186, 263}], {
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 269}], {
             RGBColor[0.912556, 0.9331114, 0.9915216]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{186, 276}], {
             RGBColor[0.7952200000000001, 0.8406994000000001, 0.9800252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 279}], {
             RGBColor[0.7952200000000001, 0.8406994000000001, 0.9800252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 205}], {
             RGBColor[0.9304981, 0.9436662, 0.8272321999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 213}], {
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 264}], {
             RGBColor[0.9936146, 0.9887505999999999, 0.5463667999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 212}], {
             RGBColor[0.6951077000000001, 0.7540514, 0.8068894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 243}], {
             RGBColor[0.9536411, 0.9621198, 0.8294395999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 294}], {
             RGBColor[0.9700618999999999, 0.9749632, 0.8223346999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 197}], {
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 211}], {
             RGBColor[0.950592, 0.9613384, 0.9148242999999998]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{189, 216}], {
             RGBColor[0.9908459999999999, 0.9904826, 0.8013689999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 275}], {
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 293}], {
             RGBColor[0.9908459999999999, 0.9904826, 0.8013689999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 212}], {
             RGBColor[0.6406937000000001, 0.5458734000000001, 0.5864621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 250}], {
             RGBColor[0.9397564, 0.7817613999999999, 0.3864348999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 203}], {
             RGBColor[0.8923894000000001, 0.9162808, 0.9635847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 195}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 200}], {
             RGBColor[0.6366510000000001, 0.71318, 0.966399]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 228}], {
             RGBColor[0.8431270000000001, 0.8777506, 0.9848994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 255}], {
             RGBColor[0.7122674000000002, 0.7745688000000002, 0.9723518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 199}], {
             RGBColor[
             0.4622118000000002, 0.5727132000000001, 0.9512400000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 220}], {
             RGBColor[0.7609992, 0.8099258, 0.8603349]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{193, 236}], {
             RGBColor[0.7565632, 0.8080914, 0.9338508999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 249}], {
             RGBColor[0.7609992, 0.8099258, 0.8603349]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{193, 266}], {
             RGBColor[0.7468646, 0.8008582, 0.9502681]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{194, 283}], {
             RGBColor[0.9767113999999999, 0.981415, 0.8913021999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 286}], {
             RGBColor[0.720973, 0.7783142000000001, 0.8941164999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 297}], {
             RGBColor[0.9911213, 0.989158, 0.6922468999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{195, 200}], {
             RGBColor[0.718755, 0.777397, 0.9308745]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 225}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[0.7943714000000002, 0.8387858000000001, 0.9368273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 230}], {
             RGBColor[0.988628, 0.9895654, 0.8381269999999997]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{196, 263}], {
             RGBColor[0.927449, 0.9428848000000001, 0.9126168999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 279}], {
             RGBColor[
             0.8332560000000001, 0.8689264000000001, 0.9033278999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 289}], {
             RGBColor[0.868781, 0.8966788, 0.9068686999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{196, 298}], {
             RGBColor[
             0.8332560000000001, 0.8689264000000001, 0.9033278999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 214}], {
             RGBColor[0.9350451, 0.7812516, 0.5690729999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 275}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 293}], {
             RGBColor[0.988628, 0.9895654, 0.8381270000000001]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{198, 222}], {
             RGBColor[0.7618303, 0.80979, 0.8117081999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{198, 245}], {
             RGBColor[0.737166, 0.793625, 0.9666853]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 258}], {
             RGBColor[0.737166, 0.793625, 0.9666853]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 278}], {
             RGBColor[0.7207452000000001, 0.7807816000000001, 0.9737902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 290}], {
             RGBColor[0.7207452000000001, 0.7807816000000001, 0.9737902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 220}], {
             RGBColor[0.6942766, 0.7541872000000001, 0.8555161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 226}], {
             RGBColor[0.5722116000000002, 0.6603834000000001, 0.9610158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 228}], {
             RGBColor[0.6308796000000001, 0.7065894000000001, 0.966764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 266}], {
             RGBColor[0.680142, 0.7451196000000001, 0.9454493]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{200, 225}], {
             RGBColor[0.6366510000000001, 0.71318, 0.966399]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{200, 255}], {
             RGBColor[0.5289344000000001, 0.6284518000000001, 0.9560588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 282}], {
             RGBColor[0.7234663000000001, 0.7779068, 0.7482363999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 295}], {
             RGBColor[0.718755, 0.777397, 0.9308745]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 209}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 218}], {
             RGBColor[
             0.9689502999999999, 0.9725855999999999, 0.7013438999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 229}], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 257}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 259}], {
             RGBColor[0.9927835, 0.9888863999999999, 0.5949935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 261}], {
             RGBColor[
             0.9689502999999999, 0.9725855999999999, 0.7013438999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 208}], {
             RGBColor[0.8307450000000001, 0.8684518, 0.9835659999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 214}], {
             RGBColor[0.8992271000000001, 0.7539418, 0.6090123000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 268}], {
             RGBColor[0.8992271000000001, 0.7539418, 0.6090123000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 275}], {
             RGBColor[0.948374, 0.9604212000000001, 0.9515823]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{203, 206}], {
             RGBColor[0.8568644, 0.8885284, 0.9600439000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 244}], {
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 270}], {
             RGBColor[0.7090564, 0.7701638, 0.9472917000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 235}], {
             RGBColor[0.7468646, 0.8008582, 0.9502681]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{204, 253}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{204, 292}], {
             RGBColor[0.7090564, 0.7701638, 0.9472917000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 213}], {
             RGBColor[0.9304981, 0.9436662, 0.8272321999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 231}], {
             RGBColor[0.8076019999999999, 0.8499981999999999, 0.9813586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 244}], {
             RGBColor[0.8718300999999999, 0.8974602, 0.8214839999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 270}], {
             RGBColor[0.601126, 0.6854275999999999, 0.9628582]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{206, 272}], {
             RGBColor[0.6767424000000002, 0.7468164000000002, 0.968811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 231}], {
             RGBColor[0.8307450000000001, 0.8684518, 0.9835659999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 232}], {
             RGBColor[0.682937, 0.7500872000000001, 0.9708138]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{207, 240}], {
             RGBColor[0.950592, 0.9613384, 0.9148242999999998]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{208, 268}], {
             RGBColor[0.8174161, 0.6892822, 0.6010567]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{209, 218}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{209, 276}], {
             RGBColor[
             0.8310380000000002, 0.8680092000000001, 0.9400858999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 279}], {
             RGBColor[
             0.8310380000000002, 0.8680092000000001, 0.9400858999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 239}], {
             RGBColor[0.9737315, 0.9377487999999998, 0.6117290999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 277}], {
             RGBColor[0.9543343, 0.9232823999999997, 0.6445634999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 216}], {
             RGBColor[0.9528099999999999, 0.9622556, 0.8780663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 221}], {
             RGBColor[0.948374, 0.9604212000000001, 0.9515823]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{212, 243}], {
             RGBColor[0.6540226000000002, 0.7250430000000001, 0.9689714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 250}], {
             RGBColor[0.6945519000000002, 0.7528626, 0.7463939999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 294}], {
             RGBColor[0.6704434000000001, 0.7378864, 0.9618665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 231}], {
             RGBColor[0.8718300999999999, 0.8974602, 0.8214839999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 264}], {
             RGBColor[0.9936146, 0.9887505999999999, 0.5463667999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 275}], {
             RGBColor[0.9350451, 0.7812516, 0.5690729999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 293}], {
             RGBColor[0.9394811, 0.783086, 0.495557]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 223}], {
             RGBColor[0.7207452000000001, 0.7807816000000001, 0.9737902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 234}], {
             RGBColor[0.9536411, 0.9621198, 0.8294395999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 271}], {
             RGBColor[0.912556, 0.9331114, 0.9915216]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{215, 274}], {
             RGBColor[0.950592, 0.9613384, 0.9148242999999998]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{215, 282}], {
             RGBColor[0.9530853, 0.960931, 0.7689441999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{215, 286}], {
             RGBColor[0.682937, 0.7500872000000001, 0.9708138]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{217, 233}], {
             RGBColor[0.9933392999999999, 0.9900752, 0.6554888999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 247}], {
             RGBColor[0.9696152, 0.9054211999999998, 0.4107330999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 262}], {
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 273}], {
             RGBColor[
             0.9792046999999999, 0.9810076000000001, 0.7454220999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 229}], {
             RGBColor[
             0.9689502999999999, 0.9725855999999999, 0.7013438999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 284}], {
             RGBColor[0.8471658, 0.8812952000000001, 0.9764611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 221}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 264}], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 226}], {
             RGBColor[0.870999, 0.8975960000000001, 0.8701107]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{220, 228}], {
             RGBColor[0.929667, 0.943802, 0.8758589]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 236}], {
             RGBColor[0.988628, 0.9895654, 0.8381270000000001]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{220, 266}], {
             RGBColor[0.9789294, 0.9823322000000001, 0.8545442000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 231}], {
             RGBColor[0.866563, 0.8957615999999999, 0.9436267]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{222, 245}], {
             RGBColor[0.9700618999999999, 0.9749632, 0.8223346999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 261}], {
             RGBColor[0.9700618999999999, 0.9749632, 0.8223346999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 278}], {
             RGBColor[0.9536411, 0.9621198, 0.8294395999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 290}], {
             RGBColor[0.9536411, 0.9621198, 0.8294395999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 234}], {
             RGBColor[0.7618303, 0.80979, 0.8117081999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{223, 271}], {
             RGBColor[0.7207452000000001, 0.7807816000000001, 0.9737902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 274}], {
             RGBColor[0.7587812, 0.8090086000000001, 0.8970928999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 287}], {
             RGBColor[0.7612745000000001, 0.8086012, 0.7512127999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 291}], {
             RGBColor[0.7609992, 0.8099258, 0.8603349]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{224, 249}], {
             RGBColor[0.9927835, 0.9888863999999999, 0.5949935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 254}], {
             RGBColor[0.9930588, 0.9875617999999999, 0.4858713999999995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 258}], {
             RGBColor[
             0.9689502999999999, 0.9725855999999999, 0.7013438999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 260}], {
             RGBColor[0.985195, 0.9617213999999998, 0.3969857999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 288}], {
             RGBColor[0.7985269000000002, 0.8381068, 0.6936937999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 234}], {
             RGBColor[0.9073551000000001, 0.9252126, 0.8250247999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 255}], {
             RGBColor[0.7122674000000002, 0.7745688000000002, 0.9723518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 287}], {
             RGBColor[
             0.9067993000000001, 0.9240238000000001, 0.7645293999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 228}], {
             RGBColor[0.8076019999999999, 0.8499981999999999, 0.9813586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 266}], {
             RGBColor[0.8568644, 0.8885284, 0.9600439000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 264}], {
             RGBColor[0.9293865, 0.9412886, 0.7062413999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 266}], {
             RGBColor[0.9155324, 0.9347344, 0.9657921]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{229, 257}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 259}], {
             RGBColor[0.9927835, 0.9888863999999999, 0.5949935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 261}], {
             RGBColor[
             0.9689502999999999, 0.9725855999999999, 0.7013438999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 284}], {
             RGBColor[0.8707185, 0.8950826, 0.7004931999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 263}], {
             RGBColor[0.927449, 0.9428848000000001, 0.9126168999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 269}], {
             RGBColor[0.950592, 0.9613384, 0.9148242999999998]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{230, 289}], {
             RGBColor[0.868781, 0.8966788, 0.9068686999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{230, 298}], {
             RGBColor[
             0.8332560000000001, 0.8689264000000001, 0.9033278999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 240}], {
             RGBColor[
             0.7209730000000001, 0.7783142000000001, 0.8941164999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 256}], {
             RGBColor[0.6366510000000001, 0.71318, 0.966399]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{232, 296}], {
             RGBColor[0.682937, 0.7500872000000001, 0.9708138]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{232, 299}], {
             RGBColor[0.7229105, 0.776718, 0.6877409999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{233, 262}], {
             RGBColor[0.9933392999999999, 0.9900752, 0.6554888999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 288}], {
             RGBColor[0.7988074000000001, 0.8406202000000002, 0.8633113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 291}], {
             RGBColor[0.993064, 0.9913998, 0.764611]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 255}], {
             RGBColor[
             0.7996385000000001, 0.8404844000000001, 0.8146845999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 271}], {
             RGBColor[0.9536411, 0.9621198, 0.8294395999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 274}], {
             RGBColor[0.9916771, 0.9903468, 0.7527422999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 287}], {
             RGBColor[0.9941704, 0.9899394, 0.6068621999999995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 252}], {
             RGBColor[0.7565632, 0.8080914, 0.9338508999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 253}], {
             RGBColor[0.7468646, 0.8008582, 0.9502681]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{235, 292}], {
             RGBColor[0.49112620000000007`, 0.5977574, 0.9530824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 249}], {
             RGBColor[0.988628, 0.9895654, 0.8381270000000001]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{236, 266}], {
             RGBColor[0.9744934, 0.9804978, 0.9280602]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{237, 239}], {
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 282}], {
             RGBColor[0.9941704, 0.9899394, 0.6068621999999995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 283}], {
             RGBColor[0.9797605, 0.9821964000000001, 0.8059174999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 295}], {
             RGBColor[0.9894590999999999, 0.9894296, 0.7895002999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 297}], {
             RGBColor[0.9941704, 0.9899394, 0.6068621999999995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 251}], {
             RGBColor[0.98641, 0.9886482000000001, 0.8748849999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 300}], {
             RGBColor[0.718755, 0.777397, 0.9308745]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 295}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 256}], {
             RGBColor[0.904306, 0.9244312000000001, 0.9104094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 281}], {
             RGBColor[0.904306, 0.9244312000000001, 0.9104094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 299}], {
             RGBColor[0.9905655, 0.9879692, 0.6317514999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 277}], {
             RGBColor[0.7749742000000002, 0.8243194000000001, 0.9696617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 243}], {
             RGBColor[0.912556, 0.9331114, 0.9915216]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{242, 280}], {
             RGBColor[
             0.9452214999999999, 0.9350905999999999, 0.6800585999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 294}], {
             RGBColor[0.9289768, 0.9459548, 0.9844166999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 294}], {
             RGBColor[0.9289768, 0.9459548, 0.9844166999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 270}], {
             RGBColor[0.7240221, 0.7790956, 0.8087317999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 272}], {
             RGBColor[
             0.7996385000000001, 0.8404844000000001, 0.8146845999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 289}], {
             RGBColor[0.8471658, 0.8812952000000001, 0.9764611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 298}], {
             RGBColor[0.8116408000000002, 0.8535428, 0.9729203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 256}], {
             RGBColor[0.8989355000000001, 0.8981834, 0.6756437999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 296}], {
             RGBColor[
             0.9452214999999999, 0.9350905999999999, 0.6800585999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 299}], {
             RGBColor[0.985195, 0.9617213999999998, 0.3969857999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 267}], {
             RGBColor[0.8827999, 0.8406943999999998, 0.6288957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 273}], {
             RGBColor[0.9552052999999999, 0.8976781999999999, 0.6097884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 285}], {
             RGBColor[
             0.9455066999999999, 0.8904449999999998, 0.6262055999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 270}], {
             RGBColor[0.659794, 0.7316336, 0.9686064]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{249, 254}], {
             RGBColor[0.9933392999999999, 0.9900752, 0.6554888999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 288}], {
             RGBColor[0.7988074000000001, 0.8406202000000002, 0.8633113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 300}], {
             RGBColor[0.720973, 0.7783142000000001, 0.8941164999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 253}], {
             RGBColor[0.9744934, 0.9804978, 0.9280602]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{252, 292}], {
             RGBColor[0.718755, 0.777397, 0.9308745]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 292}], {
             RGBColor[0.7090564, 0.7701638, 0.9472917000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 258}], {
             RGBColor[0.9695061, 0.9737744, 0.7618392999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 260}], {
             RGBColor[
             0.9857507999999999, 0.9629101999999998, 0.4574811999999995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 288}], {
             RGBColor[
             0.7990827000000001, 0.8392956000000001, 0.7541891999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 287}], {
             RGBColor[
             0.7990827000000001, 0.8392956000000001, 0.7541891999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 296}], {
             RGBColor[
             0.8662700000000001, 0.8962042000000001, 0.9871068000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 299}], {
             RGBColor[
             0.9062435000000001, 0.9228350000000001, 0.7040339999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 259}], {
             RGBColor[0.988628, 0.9895654, 0.8381270000000001]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{257, 261}], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{258, 260}], {
             RGBColor[0.9616423, 0.9479339999999998, 0.6729536999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 278}], {
             RGBColor[0.9289768, 0.9459548, 0.9844166999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 290}], {
             RGBColor[0.9289768, 0.9459548, 0.9844166999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 260}], {
             RGBColor[0.9854755, 0.9642347999999998, 0.5666032999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 261}], {
             RGBColor[0.9692308, 0.975099, 0.8709614]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{260, 261}], {
             RGBColor[0.9616423, 0.9479339999999998, 0.6729536999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 278}], {
             RGBColor[
             0.9452214999999999, 0.9350905999999999, 0.6800585999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 290}], {
             RGBColor[
             0.9452214999999999, 0.9350905999999999, 0.6800585999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 278}], {
             RGBColor[0.9289768, 0.9459548, 0.9844166999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 290}], {
             RGBColor[0.9289768, 0.9459548, 0.9844166999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 271}], {
             RGBColor[0.9530853, 0.960931, 0.7689441999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{262, 291}], {
             RGBColor[0.9933392999999999, 0.9900752, 0.6554888999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 269}], {
             RGBColor[0.889413, 0.9146578000000001, 0.9893141999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 276}], {
             RGBColor[0.7720770000000001, 0.8222458000000001, 0.9778178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 279}], {
             RGBColor[0.7720770000000001, 0.8222458000000001, 0.9778178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 289}], {
             RGBColor[0.8076019999999999, 0.8499981999999999, 0.9813586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 298}], {
             RGBColor[0.7720770000000001, 0.8222458000000001, 0.9778178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 269}], {
             RGBColor[0.8992271000000001, 0.7539418, 0.6090123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 273}], {
             RGBColor[0.8923894000000001, 0.9162808, 0.9635847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 285}], {
             RGBColor[0.8826908, 0.9090476000000001, 0.9800019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 286}], {
             RGBColor[0.6366510000000001, 0.71318, 0.966399]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{269, 298}], {
             RGBColor[0.7952200000000001, 0.8406994000000001, 0.9800252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 272}], {
             RGBColor[0.5289344000000001, 0.6284518000000001, 0.9560588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 274}], {
             RGBColor[0.950592, 0.9613384, 0.9148242999999998]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{271, 291}], {
             RGBColor[0.9528099999999999, 0.9622556, 0.8780663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 285}], {
             RGBColor[0.9550962, 0.9660314000000001, 0.9608946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 287}], {
             RGBColor[0.9911213, 0.989158, 0.6922468999999996]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{275, 293}], {
             RGBColor[0.988628, 0.9895654, 0.8381270000000001]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{276, 279}], {
             RGBColor[0.6778840000000003, 0.7482874000000002, 0.9685288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 290}], {
             RGBColor[0.912556, 0.9331114, 0.9915216]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{282, 283}], {
             RGBColor[
             0.9792046999999999, 0.9810076000000001, 0.7454220999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 295}], {
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 297}], {
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 295}], {
             RGBColor[0.9744934, 0.9804978, 0.9280602]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{283, 297}], {
             RGBColor[
             0.9792046999999999, 0.9810076000000001, 0.7454220999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 291}], {
             RGBColor[0.7988074000000001, 0.8406202000000002, 0.8633113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 298}], {
             RGBColor[0.7134090000000002, 0.7760398000000001, 0.9720696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 297}], {
             RGBColor[0.9889033, 0.9882408, 0.7290048999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 299}], {
             RGBColor[0.9525295, 0.9597422, 0.7084487999999999]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.03434177932816089], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.03434177932816089], {
             RGBColor[0.748934, 0.8037922, 0.9756104]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[3, 0.03434177932816089], {
             RGBColor[0.993064, 0.9913998, 0.764611]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.03434177932816089], {
             RGBColor[0.9453976, 0.9587982, 0.9773118]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[5, 0.03434177932816089], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.03434177932816089], {
             RGBColor[
             0.9456157999999999, 0.8220917999999996, 0.2750993999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.03434177932816089], {
             RGBColor[0.9249214, 0.7400454, 0.2584482]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[8, 0.03434177932816089], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.03434177932816089], {
             RGBColor[0.6045508000000003, 0.6898406000000002, 0.9620116]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.03434177932816089], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[11, 0.03434177932816089], {
             RGBColor[0.9453976, 0.9587982, 0.9773118]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[12, 0.03434177932816089], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.03434177932816089], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.03434177932816089], {
             RGBColor[0.912556, 0.9331114, 0.9915216]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[15, 0.03434177932816089], {
             RGBColor[0.748934, 0.8037922, 0.9756104]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[16, 0.03434177932816089], {
             RGBColor[0.993064, 0.9913998, 0.764611]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.03434177932816089], {
             RGBColor[0.912556, 0.9331114, 0.9915216]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[18, 0.03434177932816089], {
             RGBColor[0.912556, 0.9331114, 0.9915216]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[19, 0.03434177932816089], {
             RGBColor[0.912556, 0.9331114, 0.9915216]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[20, 0.03434177932816089], {
             RGBColor[0.6045508000000003, 0.6898406000000002, 0.9620116]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.03434177932816089], {
             RGBColor[0.86627, 0.8962042, 0.9871068]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.03434177932816089], {
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.03434177932816089], {
             RGBColor[0.988628, 0.9895654, 0.8381269999999997]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[24, 0.03434177932816089], {
             RGBColor[0.988628, 0.9895654, 0.8381269999999997]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[25, 0.03434177932816089], {
             RGBColor[0.912556, 0.9331114, 0.9915216]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[26, 0.03434177932816089], {
             RGBColor[0.45331800000000005`, 0.567063, 0.950106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.03434177932816089], {
             RGBColor[0.86627, 0.8962042, 0.9871068]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.03434177932816089], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[29, 0.03434177932816089], {
             RGBColor[0.993064, 0.9913998, 0.764611]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.03434177932816089], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.03434177932816089], {
             RGBColor[0.912556, 0.9331114, 0.9915216]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[32, 0.03434177932816089], {
             RGBColor[0.6778840000000003, 0.7482874000000002, 0.9685288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.03434177932816089], {
             RGBColor[0.86627, 0.8962042, 0.9871068]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.03434177932816089], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.03434177932816089], {
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.03434177932816089], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[37, 0.03434177932816089], {
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.03434177932816089], {
             RGBColor[0.977887, 0.9370697999999997, 0.36859559999999963`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.03434177932816089], {
             RGBColor[
             0.9456157999999999, 0.8220917999999996, 0.2750993999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.03434177932816089], {
             RGBColor[0.748934, 0.8037922, 0.9756104]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[41, 0.03434177932816089], {
             RGBColor[0.988628, 0.9895654, 0.8381269999999997]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[42, 0.03434177932816089], {
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.03434177932816089], {
             RGBColor[0.86627, 0.8962042, 0.9871068]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.03434177932816089], {
             RGBColor[0.912556, 0.9331114, 0.9915216]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[45, 0.03434177932816089], {
             RGBColor[0.86627, 0.8962042, 0.9871068]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.03434177932816089], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.03434177932816089], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.03434177932816089], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[49, 0.03434177932816089], {
             RGBColor[0.86627, 0.8962042, 0.9871068]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.03434177932816089], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.03434177932816089], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.03434177932816089], {
             RGBColor[0.977887, 0.9370697999999997, 0.36859559999999963`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.03434177932816089], {
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.03434177932816089], {
             RGBColor[0.912556, 0.9331114, 0.9915216]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[55, 0.03434177932816089], {
             RGBColor[0.45331800000000005`, 0.567063, 0.950106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.03434177932816089], {
             RGBColor[0.86627, 0.8962042, 0.9871068]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.03434177932816089], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[58, 0.03434177932816089], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.03434177932816089], {
             RGBColor[0.748934, 0.8037922, 0.9756104]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[60, 0.03434177932816089], {
             RGBColor[0.912556, 0.9331114, 0.9915216]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[61, 0.03434177932816089], {
             RGBColor[0.86627, 0.8962042, 0.9871068]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.03434177932816089], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.03434177932816089], {
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.03434177932816089], {
             RGBColor[0.993064, 0.9913998, 0.764611]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.03434177932816089], {
             RGBColor[0.9249214, 0.7400454, 0.2584482]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[66, 0.03434177932816089], {
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.03434177932816089], {
             RGBColor[0.988628, 0.9895654, 0.8381269999999997]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[68, 0.03434177932816089], {
             RGBColor[0.86627, 0.8962042, 0.9871068]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.03434177932816089], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.03434177932816089], {
             RGBColor[0.8858982, 0.5747722, 0.22650299999999998`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.03434177932816089], {
             RGBColor[0.9453976, 0.9587982, 0.9773118]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[72, 0.03434177932816089], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.03434177932816089], {
             RGBColor[0.988628, 0.9895654, 0.8381269999999997]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[74, 0.03434177932816089], {
             RGBColor[0.9453976, 0.9587982, 0.9773118]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[75, 0.03434177932816089], {
             RGBColor[0.912556, 0.9331114, 0.9915216]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[76, 0.03434177932816089], {
             RGBColor[0.86627, 0.8962042, 0.9871068]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.03434177932816089], {
             RGBColor[0.6045508000000003, 0.6898406000000002, 0.9620116]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.03434177932816089], {
             RGBColor[
             0.8501877999999998, 0.386770999999999, 0.19569319999999987`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.03434177932816089], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.03434177932816089], {
             RGBColor[0.988628, 0.9895654, 0.8381269999999997]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[81, 0.03434177932816089], {
             RGBColor[0.993064, 0.9913998, 0.764611]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.03434177932816089], {
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.03434177932816089], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.03434177932816089], {
             RGBColor[0.8858982, 0.5747722, 0.22650299999999998`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.03434177932816089], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.03434177932816089], {
             RGBColor[0.988628, 0.9895654, 0.8381269999999997]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[87, 0.03434177932816089], {
             RGBColor[0.9453976, 0.9587982, 0.9773118]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[88, 0.03434177932816089], {
             RGBColor[0.86627, 0.8962042, 0.9871068]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.03434177932816089], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[90, 0.03434177932816089], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.03434177932816089], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.03434177932816089], {
             RGBColor[
             0.9456157999999999, 0.8220917999999996, 0.2750993999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.03434177932816089], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.03434177932816089], {
             RGBColor[0.5289344, 0.6284518, 0.9560588]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[95, 0.03434177932816089], {
             RGBColor[0.748934, 0.8037922, 0.9756104]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[96, 0.03434177932816089], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.03434177932816089], {
             RGBColor[0.6778840000000003, 0.7482874000000002, 0.9685288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.03434177932816089], {
             RGBColor[0.6778840000000003, 0.7482874000000002, 0.9685288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.03434177932816089], {
             RGBColor[0.45331800000000005`, 0.567063, 0.950106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.03434177932816089], {
             RGBColor[0.993064, 0.9913998, 0.764611]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.03434177932816089], {
             RGBColor[0.748934, 0.8037922, 0.9756104]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[102, 0.03434177932816089], {
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.03434177932816089], {
             RGBColor[0.6045508000000003, 0.6898406000000002, 0.9620116]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.03434177932816089], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.03434177932816089], {
             RGBColor[0.6045508000000003, 0.6898406000000002, 0.9620116]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.03434177932816089], {
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.03434177932816089], {
             RGBColor[0.988628, 0.9895654, 0.8381269999999997]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[108, 0.03434177932816089], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[109, 0.03434177932816089], {
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.03434177932816089], {
             RGBColor[0.988628, 0.9895654, 0.8381269999999997]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[111, 0.03434177932816089], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[112, 0.03434177932816089], {
             RGBColor[0.9453976, 0.9587982, 0.9773118]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[113, 0.03434177932816089], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[114, 0.03434177932816089], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[115, 0.03434177932816089], {
             RGBColor[0.993064, 0.9913998, 0.764611]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.03434177932816089], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.03434177932816089], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[118, 0.03434177932816089], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.03434177932816089], {
             RGBColor[0.3376604000000001, 0.4668862000000001, 0.9427364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.03434177932816089], {
             RGBColor[0.748934, 0.8037922, 0.9756104]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[121, 0.03434177932816089], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.03434177932816089], {
             RGBColor[0.3376604000000001, 0.4668862000000001, 0.9427364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.03434177932816089], {
             RGBColor[0.5289344, 0.6284518, 0.9560588]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[124, 0.03434177932816089], {
             RGBColor[
             0.39548920000000026`, 0.5169746000000002, 0.9464212000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.03434177932816089], {
             RGBColor[0.45331800000000005`, 0.567063, 0.950106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.03434177932816089], {
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.03434177932816089], {
             RGBColor[0.6778840000000003, 0.7482874000000002, 0.9685288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.03434177932816089], {
             RGBColor[0.977887, 0.9370697999999997, 0.36859559999999963`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.03434177932816089], {
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.03434177932816089], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.03434177932816089], {
             RGBColor[0.8858982, 0.5747722, 0.22650299999999998`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.03434177932816089], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.03434177932816089], {
             RGBColor[0.6778840000000003, 0.7482874000000002, 0.9685288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.03434177932816089], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[135, 0.03434177932816089], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[136, 0.03434177932816089], {
             RGBColor[0.6778840000000003, 0.7482874000000002, 0.9685288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.03434177932816089], {
             RGBColor[0.3376604000000001, 0.4668862000000001, 0.9427364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.03434177932816089], {
             RGBColor[0.993064, 0.9913998, 0.764611]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.03434177932816089], {
             RGBColor[0.5289344, 0.6284518, 0.9560588]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[140, 0.03434177932816089], {
             RGBColor[0.6778840000000003, 0.7482874000000002, 0.9685288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.03434177932816089], {
             RGBColor[0.9453976, 0.9587982, 0.9773118]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[142, 0.03434177932816089], {
             RGBColor[0.8337534, 0.2604489999999995, 0.17995559999999994`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.03434177932816089], {
             RGBColor[0.988628, 0.9895654, 0.8381269999999997]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[144, 0.03434177932816089], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.03434177932816089], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.03434177932816089], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.03434177932816089], {
             RGBColor[0.9249214, 0.7400454, 0.2584482]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[148, 0.03434177932816089], {
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.03434177932816089], {
             RGBColor[
             0.9042269999999999, 0.6579989999999998, 0.24179699999999996`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.03434177932816089], {
             RGBColor[0.988628, 0.9895654, 0.8381269999999997]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[151, 0.03434177932816089], {
             RGBColor[0.8858982, 0.5747722, 0.22650299999999998`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.03434177932816089], {
             RGBColor[0.86627, 0.8962042, 0.9871068]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.03434177932816089], {
             RGBColor[0.6778840000000003, 0.7482874000000002, 0.9685288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.03434177932816089], {
             RGBColor[0.748934, 0.8037922, 0.9756104]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[155, 0.03434177932816089], {
             RGBColor[0.86627, 0.8962042, 0.9871068]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.03434177932816089], {
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.03434177932816089], {
             RGBColor[0.748934, 0.8037922, 0.9756104]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[158, 0.03434177932816089], {
             RGBColor[0.86627, 0.8962042, 0.9871068]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.03434177932816089], {
             RGBColor[0.86627, 0.8962042, 0.9871068]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.03434177932816089], {
             RGBColor[0.912556, 0.9331114, 0.9915216]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[161, 0.03434177932816089], {
             RGBColor[0.6778840000000003, 0.7482874000000002, 0.9685288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.03434177932816089], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.03434177932816089], {
             RGBColor[0.9453976, 0.9587982, 0.9773118]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[164, 0.03434177932816089], {
             RGBColor[
             0.9456157999999999, 0.8220917999999996, 0.2750993999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.03434177932816089], {
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.03434177932816089], {
             RGBColor[0.988628, 0.9895654, 0.8381269999999997]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[167, 0.03434177932816089], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[168, 0.03434177932816089], {
             RGBColor[0.988628, 0.9895654, 0.8381269999999997]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[169, 0.03434177932816089], {
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.03434177932816089], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[171, 0.03434177932816089], {
             RGBColor[0.988628, 0.9895654, 0.8381269999999997]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[172, 0.03434177932816089], {
             RGBColor[0.993064, 0.9913998, 0.764611]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.03434177932816089], {
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.03434177932816089], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[175, 0.03434177932816089], {
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.03434177932816089], {
             RGBColor[0.988628, 0.9895654, 0.8381269999999997]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[177, 0.03434177932816089], {
             RGBColor[0.6778840000000003, 0.7482874000000002, 0.9685288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.03434177932816089], {
             RGBColor[0.977887, 0.9370697999999997, 0.36859559999999963`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.03434177932816089], {
             RGBColor[0.8858982, 0.5747722, 0.22650299999999998`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.03434177932816089], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[181, 0.03434177932816089], {
             RGBColor[0.9453976, 0.9587982, 0.9773118]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[182, 0.03434177932816089], {
             RGBColor[0.993064, 0.9913998, 0.764611]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.03434177932816089], {
             RGBColor[0.6778840000000003, 0.7482874000000002, 0.9685288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.03434177932816089], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[185, 0.03434177932816089], {
             RGBColor[
             0.9632709999999999, 0.8877665999999995, 0.3118151999999995]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.03434177932816089], {
             RGBColor[0.912556, 0.9331114, 0.9915216]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[187, 0.03434177932816089], {
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.03434177932816089], {
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.03434177932816089], {
             RGBColor[0.988628, 0.9895654, 0.8381269999999997]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[190, 0.03434177932816089], {
             RGBColor[0.8858982, 0.5747722, 0.22650299999999998`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.03434177932816089], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.03434177932816089], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.03434177932816089], {
             RGBColor[0.5289344, 0.6284518, 0.9560588]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[194, 0.03434177932816089], {
             RGBColor[0.988628, 0.9895654, 0.8381269999999997]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[195, 0.03434177932816089], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.03434177932816089], {
             RGBColor[0.988628, 0.9895654, 0.8381269999999997]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[197, 0.03434177932816089], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.03434177932816089], {
             RGBColor[0.5289344, 0.6284518, 0.9560588]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[199, 0.03434177932816089], {
             RGBColor[
             0.39548920000000026`, 0.5169746000000002, 0.9464212000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.03434177932816089], {
             RGBColor[0.45331800000000005`, 0.567063, 0.950106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.03434177932816089], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.03434177932816089], {
             RGBColor[0.912556, 0.9331114, 0.9915216]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[203, 0.03434177932816089], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[204, 0.03434177932816089], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[205, 0.03434177932816089], {
             RGBColor[0.86627, 0.8962042, 0.9871068]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.03434177932816089], {
             RGBColor[0.748934, 0.8037922, 0.9756104]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[207, 0.03434177932816089], {
             RGBColor[0.912556, 0.9331114, 0.9915216]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[208, 0.03434177932816089], {
             RGBColor[0.748934, 0.8037922, 0.9756104]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[209, 0.03434177932816089], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.03434177932816089], {
             RGBColor[
             0.9632709999999999, 0.8877665999999995, 0.3118151999999995]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.03434177932816089], {
             RGBColor[0.912556, 0.9331114, 0.9915216]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[212, 0.03434177932816089], {
             RGBColor[
             0.39548920000000026`, 0.5169746000000002, 0.9464212000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.03434177932816089], {
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.03434177932816089], {
             RGBColor[0.8858982, 0.5747722, 0.22650299999999998`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.03434177932816089], {
             RGBColor[0.912556, 0.9331114, 0.9915216]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[216, 0.03434177932816089], {
             RGBColor[0.993064, 0.9913998, 0.764611]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.03434177932816089], {
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.03434177932816089], {
             RGBColor[0.9453976, 0.9587982, 0.9773118]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[219, 0.03434177932816089], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.03434177932816089], {
             RGBColor[0.993064, 0.9913998, 0.764611]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.03434177932816089], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.03434177932816089], {
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.03434177932816089], {
             RGBColor[0.5289344, 0.6284518, 0.9560588]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[224, 0.03434177932816089], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.03434177932816089], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.03434177932816089], {
             RGBColor[0.748934, 0.8037922, 0.9756104]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[227, 0.03434177932816089], {
             RGBColor[0.86627, 0.8962042, 0.9871068]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.03434177932816089], {
             RGBColor[0.86627, 0.8962042, 0.9871068]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.03434177932816089], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.03434177932816089], {
             RGBColor[0.988628, 0.9895654, 0.8381269999999997]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[231, 0.03434177932816089], {
             RGBColor[0.748934, 0.8037922, 0.9756104]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[232, 0.03434177932816089], {
             RGBColor[0.45331800000000005`, 0.567063, 0.950106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.03434177932816089], {
             RGBColor[0.993064, 0.9913998, 0.764611]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.03434177932816089], {
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.03434177932816089], {
             RGBColor[0.5289344, 0.6284518, 0.9560588]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[236, 0.03434177932816089], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.03434177932816089], {
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.03434177932816089], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.03434177932816089], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.03434177932816089], {
             RGBColor[0.988628, 0.9895654, 0.8381269999999997]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[241, 0.03434177932816089], {
             RGBColor[0.6045508000000003, 0.6898406000000002, 0.9620116]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.03434177932816089], {
             RGBColor[0.912556, 0.9331114, 0.9915216]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[243, 0.03434177932816089], {
             RGBColor[0.912556, 0.9331114, 0.9915216]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[244, 0.03434177932816089], {
             RGBColor[0.9947262, 0.9911282, 0.6673575999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.03434177932816089], {
             RGBColor[0.9453976, 0.9587982, 0.9773118]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[246, 0.03434177932816089], {
             RGBColor[0.977887, 0.9370697999999997, 0.36859559999999963`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.03434177932816089], {
             RGBColor[
             0.9456157999999999, 0.8220917999999996, 0.2750993999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.03434177932816089], {
             RGBColor[0.86627, 0.8962042, 0.9871068]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.03434177932816089], {
             RGBColor[0.993064, 0.9913998, 0.764611]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.03434177932816089], {
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.03434177932816089], {
             RGBColor[0.988628, 0.9895654, 0.8381269999999997]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[252, 0.03434177932816089], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.03434177932816089], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[254, 0.03434177932816089], {
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.03434177932816089], {
             RGBColor[0.6045508000000003, 0.6898406000000002, 0.9620116]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.03434177932816089], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.03434177932816089], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.03434177932816089], {
             RGBColor[0.9453976, 0.9587982, 0.9773118]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[259, 0.03434177932816089], {
             RGBColor[0.993064, 0.9913998, 0.764611]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.03434177932816089], {
             RGBColor[0.977887, 0.9370697999999997, 0.36859559999999963`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.03434177932816089], {
             RGBColor[0.9453976, 0.9587982, 0.9773118]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[262, 0.03434177932816089], {
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.03434177932816089], {
             RGBColor[0.86627, 0.8962042, 0.9871068]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.03434177932816089], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.03434177932816089], {
             RGBColor[0.8858982, 0.5747722, 0.22650299999999998`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.03434177932816089], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[267, 0.03434177932816089], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.03434177932816089], {
             RGBColor[0.8858982, 0.5747722, 0.22650299999999998`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.03434177932816089], {
             RGBColor[0.912556, 0.9331114, 0.9915216]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[270, 0.03434177932816089], {
             RGBColor[0.45331800000000005`, 0.567063, 0.950106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.03434177932816089], {
             RGBColor[0.912556, 0.9331114, 0.9915216]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[272, 0.03434177932816089], {
             RGBColor[0.6045508000000003, 0.6898406000000002, 0.9620116]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.03434177932816089], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[274, 0.03434177932816089], {
             RGBColor[0.988628, 0.9895654, 0.8381269999999997]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[275, 0.03434177932816089], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.03434177932816089], {
             RGBColor[0.6778840000000003, 0.7482874000000002, 0.9685288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.03434177932816089], {
             RGBColor[0.9453976, 0.9587982, 0.9773118]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[278, 0.03434177932816089], {
             RGBColor[0.912556, 0.9331114, 0.9915216]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[279, 0.03434177932816089], {
             RGBColor[0.6778840000000003, 0.7482874000000002, 0.9685288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.03434177932816089], {
             RGBColor[0.977887, 0.9370697999999997, 0.36859559999999963`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.03434177932816089], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.03434177932816089], {
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.03434177932816089], {
             RGBColor[0.9647948, 0.9732646, 0.9444774]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[284, 0.03434177932816089], {
             RGBColor[0.748934, 0.8037922, 0.9756104]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[285, 0.03434177932816089], {
             RGBColor[0.9453976, 0.9587982, 0.9773118]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[286, 0.03434177932816089], {
             RGBColor[0.45331800000000005`, 0.567063, 0.950106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.03434177932816089], {
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.03434177932816089], {
             RGBColor[0.6045508000000003, 0.6898406000000002, 0.9620116]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.03434177932816089], {
             RGBColor[0.748934, 0.8037922, 0.9756104]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[290, 0.03434177932816089], {
             RGBColor[0.912556, 0.9331114, 0.9915216]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[291, 0.03434177932816089], {
             RGBColor[0.993064, 0.9913998, 0.764611]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.03434177932816089], {
             RGBColor[0.45331800000000005`, 0.567063, 0.950106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.03434177932816089], {
             RGBColor[0.993064, 0.9913998, 0.764611]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.03434177932816089], {
             RGBColor[0.9453976, 0.9587982, 0.9773118]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[295, 0.03434177932816089], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.03434177932816089], {
             RGBColor[0.912556, 0.9331114, 0.9915216]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[297, 0.03434177932816089], {
             RGBColor[0.9936146, 0.9887506, 0.5463667999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.03434177932816089], {
             RGBColor[0.6778840000000003, 0.7482874000000002, 0.9685288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.03434177932816089], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.03434177932816089], {
             RGBColor[0.45331800000000005`, 0.567063, 0.950106]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1FO4EAYYBuBzsm2dTrZdW7WsZbtVy3bLtWxr2bat5WVjyzZXrfc8u3i/
//a7+f7gJu2rtAsMCAjIJEJuKEIThrCEIzwRiEgkIhOFqEQjOjGISSxiE4e4
xCM+CUhIIhKThKQkI4jkBJOClKQiNWlISzrSk4GMIX3JTBayko3s5CAnuchN
HvKSj/wUoCCF+IEfKUwRivITxShOCUpSitKUoSzlKE8FfqYilahMFapSjerU
oCa1qE0d6lKP+jSgIY1oTBN+oSnNaM6vtKAlrWhNG9rSjvZ0oCOd6EwXutKN
7vSgJ73ozW/0oS/96M8ABjKIwQzhd4YyjOGMYCSjGM0YxjKO8UxgIpOYzBSm
Mo3pzGAms5jNH8xhLvOYzwIWsojFLGEpy1jOClayitWsYS3rWM8GNrKJzWxh
K9vYzg52sovd7GEv+9jPAQ5yiMMc4U+OcozjnOAkpzjNX5zhLOc4zwUuconL
XOEq17jODW5yi9v8zT/c4S73uM8DHvKIxzzhKc94zgte8orXvOEt73jPBz7y
ic/8yxe+8o3/CBl/IKEITRjCEo7wRCAikYhMFKISjejEICaxiE0c4hKP+CQg
IYlITBKSkowgkhNMClKSitSkIS3pSE8GMgb+/6++Az6VhWw=
          "], {Null, CompressedData["
1:eJxN2nu4llWZB+C1RcxDZpqQRxAUUVHStBgOUSMyo5BNY0aKowyCpqCIyVg4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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[57, 280] -> 
             RGBColor[
              0.2575556675749038, 0.38803771496668804`, 0.9379787862977012], 
             UndirectedEdge[46, 187] -> 
             RGBColor[
              0.32803381097302087`, 0.4570126210374179, 0.9421792248536764], 
             UndirectedEdge[96, 298] -> 
             RGBColor[
              0.3453589956577786, 0.4713821632368721, 0.9433064816157806], 
             UndirectedEdge[165, 207] -> 
             RGBColor[
              0.8629243195572578, 0.8731271056740303, 0.676546302374514], 
             UndirectedEdge[69, 224] -> 
             RGBColor[
              0.9812813612748328, 0.9481895871324358, 0.4098590677551779], 
             UndirectedEdge[51, 110] -> 
             RGBColor[
              0.9932540497607107, 0.99147839046011, 0.7614613836320072], 
             UndirectedEdge[122, 231] -> 
             RGBColor[
              0.5346560481729267, 0.6328742791629598, 0.9565707376227028], 
             UndirectedEdge[71, 246] -> 
             RGBColor[
              0.6142322345348998, 0.6977004246990872, 0.9627737579908505], 
             UndirectedEdge[9, 239] -> 
             RGBColor[
              0.4639819639121217, 0.5745750992225973, 0.9512619801674704], 
             UndirectedEdge[99, 229] -> 
             RGBColor[
              0.3569385719957474, 0.4835839836336185, 0.9439647880725508], 
             UndirectedEdge[49, 112] -> 
             RGBColor[
              0.24438397329964223`, 0.374193429149736, 0.9372286777945005], 
             UndirectedEdge[115, 243] -> 
             RGBColor[
              0.21987898042507611`, 0.348437127932281, 0.9358331547021821], 
             UndirectedEdge[58, 95] -> 
             RGBColor[
              0.5187848450827122, 0.6202119340859072, 0.9552597898578664], 
             UndirectedEdge[210, 239] -> 
             RGBColor[
              0.39484568065555037`, 0.5164172158880604, 0.9463801955164135], 
             UndirectedEdge[94, 150] -> 
             RGBColor[
              0.9119777121048072, 0.931971896043791, 0.9679461351700305], 
             UndirectedEdge[21, 108] -> 
             RGBColor[
              0.3636875531699619, 0.4894296119130661, 0.9443948271850822], 
             UndirectedEdge[83, 202] -> 
             RGBColor[
              0.22220476853383342`, 0.3508816786980681, 0.9359656048942807], 
             UndirectedEdge[172, 174] -> 
             RGBColor[
              0.33090944455997406`, 0.4574098756542951, 0.9424391100455509], 
             UndirectedEdge[3, 157] -> 
             RGBColor[
              0.36165267017657554`, 0.4876670985403879, 0.9442651662401199], 
             UndirectedEdge[181, 246] -> 
             RGBColor[
              0.656342497401248, 0.7307927865257904, 0.9668372480070162], 
             UndirectedEdge[159, 253] -> 
             RGBColor[
              0.27205955347524674`, 0.4032822186474281, 0.9388047611431494], 
             UndirectedEdge[170, 228] -> 
             RGBColor[
              0.8191183413836293, 0.5128704810525186, 0.5754638060619697], 
             UndirectedEdge[151, 194] -> 
             RGBColor[
              0.4795533660103779, 0.5880893214551517, 0.9522467003824877], 
             UndirectedEdge[62, 100] -> 
             RGBColor[
              0.9225145323393552, 0.6890519389234857, 0.4381903343500609], 
             UndirectedEdge[76, 99] -> 
             RGBColor[
              0.3308920068686242, 0.45968772172522177`, 0.9423540428096366], 
             UndirectedEdge[131, 283] -> 
             RGBColor[
              0.47177717102653804`, 0.5785602690993044, 0.9525231166057517], 
             UndirectedEdge[173, 263] -> 
             RGBColor[
              0.25907859446240145`, 0.3896384076845897, 0.9380655147309758], 
             UndirectedEdge[20, 75] -> 
             RGBColor[
              0.7982091276425176, 0.8426574734850338, 0.980423187310408], 
             UndirectedEdge[175, 253] -> 
             RGBColor[
              0.29561827694261666`, 0.42804393072097424`, 0.9401463955926079],
              UndirectedEdge[52, 193] -> 
             RGBColor[
              0.6086028861336337, 0.3287818878860621, 0.5556335731143328], 
             UndirectedEdge[282, 283] -> 
             RGBColor[
              0.7911900845661439, 0.8368811978581185, 0.9547653144934332], 
             UndirectedEdge[173, 279] -> 
             RGBColor[
              0.2579831193391787, 0.3884869938729482, 0.9380031290433184], 
             UndirectedEdge[95, 198] -> 
             RGBColor[
              0.4764509321887418, 0.5858433564775396, 0.9519271091606205], 
             UndirectedEdge[18, 288] -> 
             RGBColor[
              0.9041509173263116, 0.7126766818632384, 0.5910465110881808], 
             UndirectedEdge[29, 91] -> 
             RGBColor[
              0.25771769921639187`, 0.38820802049529146`, 0.9379880137599795],
              UndirectedEdge[46, 169] -> 
             RGBColor[
              0.2925815910536258, 0.4248521813146391, 0.9399734608236041], 
             UndirectedEdge[34, 264] -> 
             RGBColor[
              0.31108024849077764`, 0.44256158228500475`, 0.9410904171386354],
              UndirectedEdge[116, 277] -> 
             RGBColor[
              0.33575144742336294`, 0.46523276122486323`, 0.9426147632298372],
              UndirectedEdge[60, 299] -> 
             RGBColor[
              0.9602834986478392, 0.8683179033755875, 0.5002256256588694], 
             UndirectedEdge[205, 213] -> 
             RGBColor[
              0.4786627684820106, 0.5869482888311869, 0.9522920854283001], 
             UndirectedEdge[240, 299] -> 
             RGBColor[
              0.9947090533611671, 0.9917794762430787, 0.7154980818389891], 
             UndirectedEdge[184, 214] -> 
             RGBColor[
              0.22515962250579277`, 0.3539874175711599, 0.9361338794566691], 
             UndirectedEdge[39, 59] -> 
             RGBColor[
              0.8501714335969901, 0.3722888082384709, 0.1951153671911272], 
             UndirectedEdge[246, 299] -> 
             RGBColor[
              0.7966762325062557, 0.8386071063469377, 0.851316533208819], 
             UndirectedEdge[21, 114] -> 
             RGBColor[
              0.3439329379247541, 0.47191837420693394`, 0.9431507551943723], 
             UndirectedEdge[204, 253] -> 
             RGBColor[
              0.26380404156370607`, 0.39460515219871184`, 0.9383346219527224],
              UndirectedEdge[202, 214] -> 
             RGBColor[
              0.22050159369132202`, 0.3490915339510665, 0.935868611606621], 
             UndirectedEdge[26, 39] -> 
             RGBColor[
              0.9266838506619479, 0.7398946126602461, 0.547796397964442], 
             UndirectedEdge[118, 220] -> 
             RGBColor[
              0.21806065403360642`, 0.34652595160629435`, 0.9357296037041608],
              UndirectedEdge[28, 126] -> 
             RGBColor[
              0.22467560955270433`, 0.3534786892692703, 0.9361063156350238], 
             UndirectedEdge[9, 237] -> 
             RGBColor[
              0.5778044829283981, 0.6681267348934206, 0.9599060319451358], 
             UndirectedEdge[174, 297] -> 
             RGBColor[
              0.5763612583921884, 0.663490693504958, 0.9614863052750408], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.35208222651696447`, 0.4786261706514128, 0.9436828617856419], 
             UndirectedEdge[63, 139] -> 
             RGBColor[
              0.28999599813964694`, 0.42067676560446166`, 0.9398795920978575],
              UndirectedEdge[124, 150] -> 
             RGBColor[
              0.9548500534233739, 0.9658478242861803, 0.9613112619489188], 
             UndirectedEdge[127, 165] -> 
             RGBColor[
              0.9065162299369915, 0.5989909877808421, 0.27841578820409746`], 
             UndirectedEdge[8, 22] -> 
             RGBColor[
              0.7346141321851996, 0.7926054104280515, 0.9741831294029938], 
             UndirectedEdge[127, 137] -> 
             RGBColor[
              0.8391691506119379, 0.30207683240040506`, 0.18514172890220718`],
              UndirectedEdge[21, 213] -> 
             RGBColor[
              0.40566670523630644`, 0.5257898434994019, 0.9470697016340429], 
             UndirectedEdge[41, 278] -> 
             RGBColor[
              0.4799611412114356, 0.5860775921964064, 0.9529261189064413], 
             UndirectedEdge[69, 249] -> 
             RGBColor[
              0.9058089885195326, 0.5656683412312807, 0.3245169720093974], 
             UndirectedEdge[100, 136] -> 
             RGBColor[
              0.9215440004534805, 0.6869760693554257, 0.33255392800111494`], 
             UndirectedEdge[88, 222] -> 
             RGBColor[
              0.47017691950032614`, 0.5802832085890723, 0.9515621248783083], 
             UndirectedEdge[153, 216] -> 
             RGBColor[
              0.2661597993989548, 0.3970812030472318, 0.9384687788764086], 
             UndirectedEdge[60, 121] -> 
             RGBColor[
              0.9603462863275016, 0.8677642487038257, 0.4570528894502983], 
             UndirectedEdge[203, 206] -> 
             RGBColor[
              0.24813385698154097`, 0.37813479465576916`, 0.9374422281227288],
              UndirectedEdge[50, 108] -> 
             RGBColor[
              0.3481847341285709, 0.4760018492537544, 0.9434070012643693], 
             UndirectedEdge[98, 181] -> 
             RGBColor[
              0.5683121366528735, 0.6584973340732392, 0.9601360759487196], 
             UndirectedEdge[267, 285] -> 
             RGBColor[
              0.42530929649653304`, 0.542408765687049, 0.9484303125609015], 
             UndirectedEdge[156, 178] -> 
             RGBColor[
              0.25237767810444756`, 0.38259531972974414`, 0.9376839074575076],
              UndirectedEdge[185, 295] -> 
             RGBColor[
              0.7026775395247731, 0.7666581291332051, 0.9717409425805205], 
             UndirectedEdge[83, 156] -> 
             RGBColor[
              0.221993745626472, 0.35065988024280614`, 0.935953587451887], 
             UndirectedEdge[44, 150] -> 
             RGBColor[
              0.9635307831976114, 0.9324851425902525, 0.6339721646328667], 
             UndirectedEdge[223, 274] -> 
             RGBColor[
              0.9259651133080155, 0.7367764933200369, 0.2723005774523107], 
             UndirectedEdge[20, 142] -> 
             RGBColor[
              0.7624648027643098, 0.8147337352232472, 0.9768605270562558], 
             UndirectedEdge[87, 264] -> 
             RGBColor[
              0.2853843000396664, 0.4172873721243609, 0.939563585747797], 
             UndirectedEdge[16, 192] -> 
             RGBColor[
              0.9292282498402631, 0.7341287491873884, 0.36986042931949054`], 
             UndirectedEdge[75, 143] -> 
             RGBColor[
              0.5636312232942053, 0.6537338940348352, 0.9601379235387875], 
             UndirectedEdge[230, 263] -> 
             RGBColor[
              0.2551678747286398, 0.38552799329045395`, 0.9378428050275294], 
             UndirectedEdge[52, 82] -> 
             RGBColor[
              0.90639234718301, 0.5644975000841104, 0.4350476194442515], 
             UndirectedEdge[34, 213] -> 
             RGBColor[
              0.37768895869959807`, 0.5015569256517332, 0.9452869843644738], 
             UndirectedEdge[145, 219] -> 
             RGBColor[
              0.27171942382339986`, 0.4029247208178715, 0.9387853912626534], 
             UndirectedEdge[237, 295] -> 
             RGBColor[
              0.738032045164762, 0.7953605095140767, 0.9745241787723218], 
             UndirectedEdge[257, 259] -> 
             RGBColor[
              0.4277830853443319, 0.544648816326516, 0.9485610340700278], 
             UndirectedEdge[116, 241] -> 
             RGBColor[
              0.30074162674959204`, 0.4321657656332045, 0.9404844121827121], 
             UndirectedEdge[95, 105] -> 
             RGBColor[
              0.3889084199719124, 0.5085055030468593, 0.9463331921101534], 
             UndirectedEdge[115, 146] -> 
             RGBColor[
              0.22602095903949393`, 0.35489273687997036`, 0.9361829312980301],
              UndirectedEdge[16, 170] -> 
             RGBColor[
              0.9076819009807398, 0.5788651194760369, 0.34963294244959353`], 
             UndirectedEdge[199, 226] -> 
             RGBColor[
              0.178927005110741, 0.3053940053717128, 0.9335010002910491], 
             UndirectedEdge[78, 130] -> 
             RGBColor[
              0.17948366008578914`, 0.30597908504445237`, 0.9335327009683809],
              UndirectedEdge[155, 214] -> 
             RGBColor[
              0.21259246077095287`, 0.340778533783768, 0.9354181981873197], 
             UndirectedEdge[185, 297] -> 
             RGBColor[
              0.6642346642542716, 0.7364864270373344, 0.9679464241532377], 
             UndirectedEdge[45, 53] -> 
             RGBColor[
              0.8447764554590436, 0.34517703459191124`, 0.19051129035634062`],
              UndirectedEdge[49, 204] -> 
             RGBColor[
              0.23371861491604712`, 0.3629834612657993, 0.9366213014125385], 
             UndirectedEdge[69, 254] -> 
             RGBColor[
              0.9421799602264942, 0.7934586684310521, 0.3573185586987633], 
             UndirectedEdge[102, 295] -> 
             RGBColor[
              0.6113037860265932, 0.6906305704110295, 0.9650577846461873], 
             UndirectedEdge[14, 254] -> 
             RGBColor[
              0.8570098056114457, 0.3874350253501294, 0.200198663385516], 
             UndirectedEdge[125, 299] -> 
             RGBColor[
              0.9935548569863483, 0.9893107669044954, 0.5898709293143154], 
             UndirectedEdge[16, 44] -> 
             RGBColor[
              0.9792628131880576, 0.9411137160345208, 0.4247070629331663], 
             UndirectedEdge[49, 84] -> 
             RGBColor[
              0.2685862507813846, 0.39963155729606886`, 0.9386069616930247], 
             UndirectedEdge[186, 230] -> 
             RGBColor[
              0.23966064866834333`, 0.3692289154861624, 0.9369596914442806], 
             UndirectedEdge[215, 282] -> 
             RGBColor[
              0.97938013431987, 0.9823295669124169, 0.8386095157394571], 
             UndirectedEdge[134, 159] -> 
             RGBColor[
              0.26069725479200045`, 0.3913397223199907, 0.9381576950421531], 
             UndirectedEdge[26, 266] -> 
             RGBColor[
              0.6167344718352826, 0.6830098916954412, 0.9109140844783175], 
             UndirectedEdge[142, 150] -> 
             RGBColor[
              0.810515025857468, 0.8523692859433827, 0.9579232930155395], 
             UndirectedEdge[114, 221] -> 
             RGBColor[
              0.29951227485023835`, 0.4321367694156119, 0.9403681530127932], 
             UndirectedEdge[147, 172] -> 
             RGBColor[
              0.2478440102281372, 0.3778301473405962, 0.9374257217789124], 
             UndirectedEdge[35, 211] -> 
             RGBColor[
              0.2342952250609407, 0.36358951508727716`, 0.936654138507272], 
             UndirectedEdge[124, 295] -> 
             RGBColor[
              0.8924892919776035, 0.9168014387328876, 0.9788835440663946], 
             UndirectedEdge[166, 233] -> 
             RGBColor[
              0.9934058766223102, 0.9883041618002921, 0.5236485484298345], 
             UndirectedEdge[88, 290] -> 
             RGBColor[
              0.558574938782711, 0.6525153246748602, 0.9583922117898461], 
             UndirectedEdge[134, 235] -> 
             RGBColor[
              0.2580199713754525, 0.388525727699626, 0.9380052277122666], 
             UndirectedEdge[185, 239] -> 
             RGBColor[
              0.4896022864326819, 0.5953748312271646, 0.9532789058066227], 
             UndirectedEdge[260, 278] -> 
             RGBColor[
              0.7260426453881705, 0.7855410894217181, 0.9736791816363508], 
             UndirectedEdge[15, 242] -> 
             RGBColor[
              0.23967759230185604`, 0.3692467243192726, 0.9369606563591433], 
             UndirectedEdge[4, 266] -> 
             RGBColor[
              0.3936273469724733, 0.5073684085563466, 0.9471569136064277], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.2455681044594148, 0.3754380260769088, 0.9372961123122845], 
             UndirectedEdge[3, 123] -> 
             RGBColor[
              0.40677277394875433`, 0.5267478646254944, 0.9471401793543419], 
             UndirectedEdge[28, 184] -> 
             RGBColor[
              0.23042487690337662`, 0.35952153377943086`, 0.9364337279053656],
              UndirectedEdge[116, 210] -> 
             RGBColor[
              0.35048246477995726`, 0.4779920280566848, 0.9435534106296721], 
             UndirectedEdge[118, 120] -> 
             RGBColor[
              0.1844220718220619, 0.3111696688926636, 0.9338139362110361], 
             UndirectedEdge[15, 89] -> 
             RGBColor[
              0.2585276184343561, 0.3890592969452162, 0.9380341374612745], 
             UndirectedEdge[11, 283] -> 
             RGBColor[
              0.4811144650373824, 0.586647763865455, 0.9531180807234778], 
             UndirectedEdge[157, 201] -> 
             RGBColor[
              0.3335467378743898, 0.46332315262546664`, 0.9424742810869247], 
             UndirectedEdge[196, 279] -> 
             RGBColor[
              0.2698625176179148, 0.40097299466125325`, 0.9386796432012976], 
             UndirectedEdge[7, 11] -> 
             RGBColor[
              0.36912627592496833`, 0.4941403602052988, 0.9447413777897574], 
             UndirectedEdge[76, 284] -> 
             RGBColor[
              0.2749699198453155, 0.406341198230256, 0.9389705022024235], 
             UndirectedEdge[34, 108] -> 
             RGBColor[
              0.3357098066332535, 0.46519669406539743`, 0.9426121099155129], 
             UndirectedEdge[46, 213] -> 
             RGBColor[
              0.3600084250820952, 0.48470742468786476`, 0.9442166189906656], 
             UndirectedEdge[261, 278] -> 
             RGBColor[
              0.5017864477209948, 0.6049815757231856, 0.9543168081378697], 
             UndirectedEdge[58, 66] -> 
             RGBColor[
              0.747689528345485, 0.802133526636196, 0.966576403949817], 
             UndirectedEdge[194, 297] -> 
             RGBColor[
              0.6381161089486057, 0.715282207212687, 0.9658902758041552], 
             UndirectedEdge[283, 297] -> 
             RGBColor[
              0.6895610790338994, 0.7570475514974199, 0.9699402122984042], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.23660390230659725`, 0.366016081251054, 0.9367856142610302], 
             UndirectedEdge[6, 169] -> 
             RGBColor[
              0.299349056442051, 0.4319652165199622, 0.940358857965907], 
             UndirectedEdge[11, 172] -> 
             RGBColor[
              0.3065006008708423, 0.43626816207492447`, 0.9408838001095725], 
             UndirectedEdge[4, 82] -> 
             RGBColor[
              0.7673487077991381, 0.8145026420959148, 0.8312023909866153], 
             UndirectedEdge[140, 230] -> 
             RGBColor[
              0.2887130988150164, 0.4189991437957653, 0.9398185869899978], 
             UndirectedEdge[207, 232] -> 
             RGBColor[
              0.8698424070552139, 0.8954799573196557, 0.7870499702431855], 
             UndirectedEdge[147, 244] -> 
             RGBColor[
              0.23435191313774276`, 0.3636490978502278, 0.9366573668093834], 
             UndirectedEdge[56, 296] -> 
             RGBColor[
              0.6219639893106997, 0.70315209105388, 0.9639467061714042], 
             UndirectedEdge[243, 294] -> 
             RGBColor[
              0.21403208469402601`, 0.34229166980434655`, 0.935500182640006], 
             UndirectedEdge[211, 216] -> 
             RGBColor[
              0.2505986099544608, 0.38072540630467244`, 0.9375825921582613], 
             UndirectedEdge[107, 141] -> 
             RGBColor[
              0.8665747340462209, 0.44887503543921714`, 0.2088850184887606], 
             UndirectedEdge[19, 175] -> 
             RGBColor[
              0.2928891684678705, 0.42517546467854467`, 0.9399909769023254], 
             UndirectedEdge[17, 158] -> 
             RGBColor[
              0.34992722478314753`, 0.47635321406760484`, 0.9435604273632674],
              UndirectedEdge[115, 242] -> 
             RGBColor[
              0.23101187459031025`, 0.36013850556620103`, 0.9364671565552513],
              UndirectedEdge[159, 292] -> 
             RGBColor[
              0.24522762221879252`, 0.3750801576541939, 0.9372767223523794], 
             UndirectedEdge[34, 205] -> 
             RGBColor[
              0.4284730033611293, 0.5434764368944227, 0.9490940379758643], 
             UndirectedEdge[23, 180] -> 
             RGBColor[
              0.26520012614906696`, 0.3960725256148013, 0.9384141269045367], 
             UndirectedEdge[47, 158] -> 
             RGBColor[
              0.5238459246822951, 0.6229456026619612, 0.9560487873803941], 
             UndirectedEdge[130, 199] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[112, 204] -> 
             RGBColor[
              0.24154807064065673`, 0.37121271564852854`, 0.9370671773334133],
              UndirectedEdge[217, 247] -> 
             RGBColor[
              0.6930619732704799, 0.7591753208357144, 0.9707042644868367], 
             UndirectedEdge[102, 185] -> 
             RGBColor[
              0.4766965463107896, 0.5841965277949407, 0.9524565634581535], 
             UndirectedEdge[136, 137] -> 
             RGBColor[
              0.9192369381421535, 0.6692429774694144, 0.3303446825263339], 
             UndirectedEdge[138, 258] -> 
             RGBColor[
              0.8342254690641332, 0.8708963005189276, 0.9605009609416519], 
             UndirectedEdge[79, 277] -> 
             RGBColor[
              0.3720129129755694, 0.49664062013193266`, 0.9449253117500688], 
             UndirectedEdge[41, 259] -> 
             RGBColor[
              0.41062581045850305`, 0.5297880471701207, 0.9474677876858852], 
             UndirectedEdge[225, 287] -> 
             RGBColor[
              0.950968932525843, 0.8418366498372989, 0.2871069008798047], 
             UndirectedEdge[167, 194] -> 
             RGBColor[
              0.6348798248522232, 0.7127539974799229, 0.9655677132502221], 
             UndirectedEdge[64, 219] -> 
             RGBColor[
              0.2539451972290641, 0.384242881716169, 0.9377731753527179], 
             UndirectedEdge[83, 293] -> 
             RGBColor[
              0.21277489873276917`, 0.34097028764887183`, 0.9354285877593523],
              UndirectedEdge[31, 95] -> 
             RGBColor[
              0.5537416162054588, 0.648591415667946, 0.9580117149315208], 
             UndirectedEdge[256, 299] -> 
             RGBColor[
              0.994866261560722, 0.9921157286857396, 0.7326092241840025], 
             UndirectedEdge[129, 269] -> 
             RGBColor[
              0.23146736458154496`, 0.36061725442672216`, 0.9364930960364151],
              UndirectedEdge[83, 126] -> 
             RGBColor[
              0.22111352999763184`, 0.3497347178080009, 0.9359034604739869], 
             UndirectedEdge[23, 81] -> 
             RGBColor[
              0.29610769611833376`, 0.428558341305621, 0.9401742672906341], 
             UndirectedEdge[235, 252] -> 
             RGBColor[
              0.2712852344852127, 0.40246836029424277`, 0.9387606648221691], 
             UndirectedEdge[6, 264] -> 
             RGBColor[
              0.3001671802617, 0.4328251165264595, 0.9404054489071303], 
             UndirectedEdge[167, 215] -> 
             RGBColor[
              0.874514844691243, 0.8999677108189541, 0.8534618509904951], 
             UndirectedEdge[273, 285] -> 
             RGBColor[
              0.5003032179944051, 0.6032922095966846, 0.9543341087730001], 
             UndirectedEdge[267, 273] -> 
             RGBColor[
              0.5428411676276441, 0.6397419404528637, 0.9571535916898165], 
             UndirectedEdge[66, 109] -> 
             RGBColor[
              0.9338122663322416, 0.9497831796189251, 0.9839317503863134], 
             UndirectedEdge[104, 173] -> 
             RGBColor[
              0.2711227338075005, 0.40229756177882925`, 0.9387514106489717], 
             UndirectedEdge[9, 185] -> 
             RGBColor[
              0.5424499772884093, 0.6394243545125489, 0.9571227957533345], 
             UndirectedEdge[233, 288] -> 
             RGBColor[
              0.9279948066453856, 0.7277856301692169, 0.40221351612468526`], 
             UndirectedEdge[139, 147] -> 
             RGBColor[
              0.2408356632285271, 0.3704639302891415, 0.9370266067852049], 
             UndirectedEdge[65, 103] -> 
             RGBColor[
              0.2833667383517215, 0.41516678686953135`, 0.9394486885943836], 
             UndirectedEdge[33, 124] -> 
             RGBColor[
              0.931178231225007, 0.9476509487054876, 0.9825737296298357], 
             UndirectedEdge[82, 226] -> 
             RGBColor[
              0.5870018429473699, 0.648635921384999, 0.8195028573655392], 
             UndirectedEdge[6, 221] -> 
             RGBColor[
              0.3001432088118318, 0.4327999210127703, 0.9404040837685228], 
             UndirectedEdge[125, 136] -> 
             RGBColor[
              0.9927664178883965, 0.9869364242276462, 0.4540474115251879], 
             UndirectedEdge[112, 292] -> 
             RGBColor[
              0.24763746869084696`, 0.3776130590894144, 0.9374139595439145], 
             UndirectedEdge[58, 67] -> 
             RGBColor[
              0.7306207568349073, 0.7888007417215468, 0.9745656605578148], 
             UndirectedEdge[73, 105] -> 
             RGBColor[
              0.30909022810020703`, 0.4403302488400713, 0.9409822033703782], 
             UndirectedEdge[263, 298] -> 
             RGBColor[
              0.27311782288011394`, 0.40439452689009914`, 0.9388650280201871],
              UndirectedEdge[60, 170] -> 
             RGBColor[
              0.8739879445842015, 0.4569683614322223, 0.21399044815056695`], 
             UndirectedEdge[10, 129] -> 
             RGBColor[
              0.22367111540675327`, 0.3524229022332684, 0.9360491111794278], 
             UndirectedEdge[53, 234] -> 
             RGBColor[
              0.8245240597604586, 0.18950824659620397`, 0.17111757336356628`],
              UndirectedEdge[51, 154] -> 
             RGBColor[
              0.867381103025232, 0.8946780960164662, 0.8655976857489563], 
             UndirectedEdge[17, 84] -> 
             RGBColor[
              0.2984201886260963, 0.4309889175517728, 0.9403059603179251], 
             UndirectedEdge[98, 160] -> 
             RGBColor[
              0.5065135948101279, 0.6094211404266363, 0.9545226524909898], 
             UndirectedEdge[25, 147] -> 
             RGBColor[
              0.2390014851721345, 0.36853609285826733`, 0.9369221530583165], 
             UndirectedEdge[159, 204] -> 
             RGBColor[
              0.23913822416860225`, 0.3686798142133081, 0.9369299401418781], 
             UndirectedEdge[37, 94] -> 
             RGBColor[
              0.771325946499076, 0.8216241472491855, 0.9777522097744586], 
             UndirectedEdge[37, 283] -> 
             RGBColor[
              0.6497129501444403, 0.725917890351978, 0.9659685232126394], 
             UndirectedEdge[9, 142] -> 
             RGBColor[
              0.5879267021753338, 0.6760891257694337, 0.9608774283058292], 
             UndirectedEdge[51, 109] -> 
             RGBColor[
              0.9573653906056103, 0.9657923433051386, 0.8743494495449171], 
             UndirectedEdge[123, 257] -> 
             RGBColor[
              0.41376298296839165`, 0.5328024323401832, 0.9475855892918741], 
             UndirectedEdge[212, 294] -> 
             RGBColor[
              0.2108091766010912, 0.3389041890544966, 0.9353166427919786], 
             UndirectedEdge[237, 297] -> 
             RGBColor[
              0.6995891698942603, 0.7651888074182058, 0.970729660345039], 
             UndirectedEdge[163, 197] -> 
             RGBColor[
              0.22592979758927967`, 0.35479692041582533`, 0.9361777397883018],
              UndirectedEdge[76, 229] -> 
             RGBColor[
              0.32034218545595194`, 0.4505499966670069, 0.9416818175180619], 
             UndirectedEdge[18, 24] -> 
             RGBColor[
              0.9510187529148094, 0.9629904466400717, 0.9677966543467089], 
             UndirectedEdge[44, 124] -> 
             RGBColor[
              0.9563745344888678, 0.9271480240205534, 0.6460858270481826], 
             UndirectedEdge[26, 82] -> 
             RGBColor[
              0.9904558326619474, 0.9901441252350094, 0.7949595618585049], 
             UndirectedEdge[7, 106] -> 
             RGBColor[
              0.5257077598802015, 0.6240227140594248, 0.9563940779093657], 
             UndirectedEdge[53, 255] -> 
             RGBColor[
              0.8953417281167521, 0.5590474871616122, 0.23653146249449708`], 
             UndirectedEdge[89, 242] -> 
             RGBColor[
              0.2592824308416344, 0.3898526526431364, 0.9380771229112241], 
             UndirectedEdge[121, 181] -> 
             RGBColor[
              0.8542136005503994, 0.8836192586014792, 0.8134168223712162], 
             UndirectedEdge[217, 273] -> 
             RGBColor[
              0.7124353943152881, 0.7749035368025619, 0.9722294111586636], 
             UndirectedEdge[141, 240] -> 
             RGBColor[
              0.9469680026152082, 0.812923621050152, 0.46368241218848416`], 
             UndirectedEdge[42, 159] -> 
             RGBColor[
              0.2509157891435835, 0.3810587817427625, 0.9376006550438574], 
             UndirectedEdge[51, 52] -> 
             RGBColor[
              0.9056350707482277, 0.5643614773610739, 0.4604731703909181], 
             UndirectedEdge[170, 225] -> 
             RGBColor[
              0.8914281470596066, 0.5246344158422436, 0.23572348923178596`], 
             UndirectedEdge[51, 179] -> 
             RGBColor[
              0.993604348606093, 0.9916232480349453, 0.7556560252196713], 
             UndirectedEdge[36, 198] -> 
             RGBColor[
              0.6119133130274254, 0.6940222772779814, 0.9638188261918845], 
             UndirectedEdge[150, 295] -> 
             RGBColor[
              0.8996455406863472, 0.9221385573025866, 0.9667698816510785], 
             UndirectedEdge[140, 196] -> 
             RGBColor[
              0.304503216827514, 0.4355955589782061, 0.9407178108514234], 
             UndirectedEdge[31, 73] -> 
             RGBColor[
              0.47392342433375345`, 0.580416161461158, 0.9526607261917457], 
             UndirectedEdge[188, 212] -> 
             RGBColor[
              0.20871789165381538`, 0.33670611597978567`, 0.9351975472080101],
              UndirectedEdge[172, 244] -> 
             RGBColor[
              0.2560033039447505, 0.38640608236585794`, 0.9378903814854801], 
             UndirectedEdge[7, 63] -> 
             RGBColor[
              0.3596300201933831, 0.4859151807862907, 0.94413628477175], 
             UndirectedEdge[128, 218] -> 
             RGBColor[
              0.24765166805898178`, 0.377627983525616, 0.9374147681769237], 
             UndirectedEdge[138, 154] -> 
             RGBColor[
              0.7239419932746806, 0.7842682543998942, 0.9731194303332016], 
             UndirectedEdge[1, 297] -> 
             RGBColor[
              0.5894608456272148, 0.6748368975635395, 0.9623209993901465], 
             UndirectedEdge[90, 123] -> 
             RGBColor[
              0.4198835569183708, 0.5381037658666636, 0.9479755868517558], 
             UndirectedEdge[8, 61] -> 
             RGBColor[
              0.6093443388632377, 0.6935868317074125, 0.9624883614152353], 
             UndirectedEdge[201, 209] -> 
             RGBColor[
              0.29313467956513195`, 0.424290095199951, 0.9400468245012701], 
             UndirectedEdge[44, 94] -> 
             RGBColor[
              0.9135021931703009, 0.8932720957781641, 0.6527207002692943], 
             UndirectedEdge[114, 213] -> 
             RGBColor[
              0.366144956508927, 0.49115730829602955`, 0.944566085377239], 
             UndirectedEdge[82, 107] -> 
             RGBColor[
              0.9146118486409361, 0.6276761900982359, 0.44291862332296067`], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.27309540824899353`, 0.40437096769162195`, 0.9388637515401044],
              UndirectedEdge[182, 268] -> 
             RGBColor[
              0.28484973208731645`, 0.4167255073128753, 0.939533142893733], 
             UndirectedEdge[157, 229] -> 
             RGBColor[
              0.34618459391463335`, 0.47426942833041186`, 0.9432795540985917],
              UndirectedEdge[99, 157] -> 
             RGBColor[
              0.35673441532730565`, 0.48340715338862666`, 0.9439517793901664],
              UndirectedEdge[249, 288] -> 
             RGBColor[
              0.8402405410776118, 0.30481319511588134`, 0.18595237386054825`],
              UndirectedEdge[66, 138] -> 
             RGBColor[
              0.8265698887797728, 0.8651867812777139, 0.9734598614679548], 
             UndirectedEdge[215, 286] -> 
             RGBColor[
              0.7770695489362254, 0.8225663010665949, 0.8446220990398039], 
             UndirectedEdge[83, 275] -> 
             RGBColor[
              0.214533530595458, 0.34281872124025803`, 0.9355287392422698], 
             UndirectedEdge[95, 289] -> 
             RGBColor[
              0.38981488785686436`, 0.5094582582673273, 0.9463848141152024], 
             UndirectedEdge[37, 75] -> 
             RGBColor[
              0.7056075851299448, 0.7699452754105638, 0.9712920278741198], 
             UndirectedEdge[88, 260] -> 
             RGBColor[
              0.6766874696871867, 0.7454723343623321, 0.9697937614112038], 
             UndirectedEdge[60, 82] -> 
             RGBColor[
              0.9605795624965958, 0.8682632028416796, 0.48244356084256446`], 
             UndirectedEdge[50, 227] -> 
             RGBColor[
              0.30610711869793783`, 0.43502772299278125`, 0.9408916674370189],
              UndirectedEdge[12, 248] -> 
             RGBColor[
              0.20494626266410096`, 0.3327418947765061, 0.9349827585166709], 
             UndirectedEdge[103, 164] -> 
             RGBColor[
              0.33137057382359575`, 0.4586711168930102, 0.9424369368208644], 
             UndirectedEdge[127, 228] -> 
             RGBColor[
              0.8245576688190998, 0.5546795352500253, 0.5806725121570179], 
             UndirectedEdge[163, 184] -> 
             RGBColor[
              0.23939823162616325`, 0.3689530985366296, 0.9369447471819397], 
             UndirectedEdge[11, 183] -> 
             RGBColor[
              0.29904764600234657`, 0.4284346339635039, 0.9404593653554703], 
             UndirectedEdge[226, 266] -> 
             RGBColor[
              0.21328048212070516`, 0.3415016878454308, 0.9354573799853517], 
             UndirectedEdge[98, 178] -> 
             RGBColor[
              0.34993177355877136`, 0.4745851224813026, 0.9436255999612144], 
             UndirectedEdge[200, 255] -> 
             RGBColor[
              0.9224751483252943, 0.7242107930884344, 0.2608151757752228], 
             UndirectedEdge[223, 234] -> 
             RGBColor[
              0.852336886710356, 0.35775657985604403`, 0.19596820028306192`], 
             UndirectedEdge[111, 190] -> 
             RGBColor[
              0.2355732429285669, 0.36493279289716524`, 0.9367269197341752], 
             UndirectedEdge[85, 181] -> 
             RGBColor[
              0.8167213708728744, 0.8575535758044224, 0.9821530921197811], 
             UndirectedEdge[57, 134] -> 
             RGBColor[
              0.26052687456490653`, 0.3911606418985847, 0.938147992140275], 
             UndirectedEdge[9, 131] -> 
             RGBColor[
              0.4208304337263501, 0.5371994126346513, 0.9485124028214329], 
             UndirectedEdge[184, 189] -> 
             RGBColor[
              0.2346427787554684, 0.3639548160564028, 0.9366739311760157], 
             UndirectedEdge[194, 286] -> 
             RGBColor[
              0.5374345290972057, 0.6353525877275636, 0.9567279612995309], 
             UndirectedEdge[171, 298] -> 
             RGBColor[
              0.35180269388930685`, 0.47696337077533185`, 0.9437170683691549],
              UndirectedEdge[108, 213] -> 
             RGBColor[
              0.3858995717541348, 0.5086685460021616, 0.9458101573679487], 
             UndirectedEdge[158, 175] -> 
             RGBColor[
              0.34907161965836087`, 0.47545391883295585`, 0.9435117019171652],
              UndirectedEdge[37, 297] -> 
             RGBColor[
              0.7205508998101146, 0.7816191064121104, 0.9727814378282238], 
             UndirectedEdge[68, 234] -> 
             RGBColor[
              0.8458426087622819, 0.3282675804709904, 0.19054921557386956`], 
             UndirectedEdge[38, 252] -> 
             RGBColor[
              0.3592377978575069, 0.4848159523446023, 0.9441391019160659], 
             UndirectedEdge[42, 252] -> 
             RGBColor[
              0.2774845709652012, 0.40898425599534566`, 0.939113707863608], 
             UndirectedEdge[40, 65] -> 
             RGBColor[
              0.2625645345612948, 0.39330235174989453`, 0.9382640338626215], 
             UndirectedEdge[184, 216] -> 
             RGBColor[
              0.24813752757352578`, 0.3781386526806742, 0.9374424371575123], 
             UndirectedEdge[16, 59] -> 
             RGBColor[
              0.9131402588168656, 0.620820449672156, 0.3548598720778012], 
             UndirectedEdge[7, 185] -> 
             RGBColor[
              0.4814085254761833, 0.5882778073170456, 0.9527568066039329], 
             UndirectedEdge[127, 299] -> 
             RGBColor[
              0.9136283213475775, 0.6224467453485296, 0.4600423723683357], 
             UndirectedEdge[166, 217] -> 
             RGBColor[
              0.899879476841495, 0.9180128953290518, 0.7153753712159427], 
             UndirectedEdge[101, 207] -> 
             RGBColor[
              0.6460892652174881, 0.7219820565313749, 0.9663628314965813], 
             UndirectedEdge[14, 69] -> 
             RGBColor[
              0.907867854492874, 0.581493687303205, 0.3264885443906257], 
             UndirectedEdge[51, 107] -> 
             RGBColor[
              0.9138545722061537, 0.6275401673751994, 0.4683441742696273], 
             UndirectedEdge[74, 233] -> 
             RGBColor[
              0.8161512863791258, 0.8534670921405562, 0.7813047425304152], 
             UndirectedEdge[158, 252] -> 
             RGBColor[
              0.35208167801260865`, 0.47861768101199287`, 0.9436831202874573],
              UndirectedEdge[86, 110] -> 
             RGBColor[
              0.9839067857429666, 0.9591178157514064, 0.561716366031505], 
             UndirectedEdge[58, 73] -> 
             RGBColor[
              0.4389666532110068, 0.5520366798791193, 0.9499088011180912], 
             UndirectedEdge[13, 96] -> 
             RGBColor[
              0.3557971492753504, 0.4823533245061042, 0.9439009190224369], 
             UndirectedEdge[16, 53] -> 
             RGBColor[
              0.9125997408169637, 0.6166657914684119, 0.3543422714306673], 
             UndirectedEdge[44, 170] -> 
             RGBColor[
              0.8934743520557873, 0.5315367457661417, 0.24367260924855771`], 
             UndirectedEdge[27, 32] -> 
             RGBColor[
              0.25734797909016266`, 0.3878194212010146, 0.9379669587457427], 
             UndirectedEdge[116, 164] -> 
             RGBColor[
              0.35316605540790247`, 0.4803164193774241, 0.9437244066514788], 
             UndirectedEdge[70, 300] -> 
             RGBColor[
              0.2600472811884571, 0.39065655885195993`, 0.938120680006981], 
             UndirectedEdge[79, 116] -> 
             RGBColor[
              0.3586693068574145, 0.48508305918153105`, 0.9440750689675076], 
             UndirectedEdge[137, 195] -> 
             RGBColor[
              0.8323549819999152, 0.24970014646067296`, 0.17861647334383152`],
              UndirectedEdge[156, 214] -> 
             RGBColor[
              0.2202905707839606, 0.3488697354958046, 0.9358565941642273], 
             UndirectedEdge[14, 249] -> 
             RGBColor[
              0.8206388339044841, 0.15964469815035803`, 0.16739707669615012`],
              UndirectedEdge[84, 89] -> 
             RGBColor[
              0.2893752204809355, 0.4214820825471055, 0.9397908627628895], 
             UndirectedEdge[98, 246] -> 
             RGBColor[
              0.5108375562883921, 0.6129315271469358, 0.9548630505777516], 
             UndirectedEdge[4, 107] -> 
             RGBColor[
              0.6868838807668163, 0.45030100016757835`, 0.5686163001605958], 
             UndirectedEdge[20, 295] -> 
             RGBColor[
              0.851595317593189, 0.8845030065824513, 0.9857071156917947], 
             UndirectedEdge[57, 175] -> 
             RGBColor[
              0.27078207932041887`, 0.40193951231416447`, 0.9387320108798856],
              UndirectedEdge[93, 160] -> 
             RGBColor[
              0.5607147225279772, 0.6542524975154264, 0.9585606634045596], 
             UndirectedEdge[13, 149] -> 
             RGBColor[
              0.30003867844943893`, 0.43269005297428764`, 0.9403981309190235],
              UndirectedEdge[230, 298] -> 
             RGBColor[
              0.2673021323723527, 0.39828186743036675`, 0.9385338330493134], 
             UndirectedEdge[96, 198] -> 
             RGBColor[
              0.43486063371890193`, 0.5507791821456584, 0.9490119679848132], 
             UndirectedEdge[32, 182] -> 
             RGBColor[
              0.2817202883828383, 0.4134362635612778, 0.9393549257043601], 
             UndirectedEdge[80, 241] -> 
             RGBColor[
              0.27345259705009906`, 0.4047463957686619, 0.938884092913914], 
             UndirectedEdge[55, 292] -> 
             RGBColor[
              0.25987815555668636`, 0.39047879708978456`, 0.9381110485524506],
              UndirectedEdge[121, 160] -> 
             RGBColor[
              0.7924150587076538, 0.8345430649548763, 0.8078033989134862], 
             UndirectedEdge[62, 220] -> 
             RGBColor[
              0.6260202363274255, 0.6895227449727015, 0.8093263410054259], 
             UndirectedEdge[28, 189] -> 
             RGBColor[
              0.22763054758381063`, 0.35658451649385525`, 0.9362745949844562],
              UndirectedEdge[25, 91] -> 
             RGBColor[
              0.2622113968861681, 0.3929311816631146, 0.9382439231944433], 
             UndirectedEdge[41, 99] -> 
             RGBColor[
              0.362239582391498, 0.48817545240188814`, 0.9443025637674687], 
             UndirectedEdge[148, 206] -> 
             RGBColor[
              0.23774362795226284`, 0.3672140051674282, 0.9368505199504779], 
             UndirectedEdge[3, 90] -> 
             RGBColor[
              0.39043568607657597`, 0.5125975002365252, 0.9460991945614463], 
             UndirectedEdge[99, 104] -> 
             RGBColor[
              0.3262801186675095, 0.4548403348152493, 0.9420914025992604], 
             UndirectedEdge[193, 266] -> 
             RGBColor[
              0.3235658537972168, 0.4490279862889558, 0.942045190438874], 
             UndirectedEdge[275, 293] -> 
             RGBColor[
              0.21101994270665328`, 0.33912571759478527`, 0.9353286456098898],
              UndirectedEdge[229, 257] -> 
             RGBColor[
              0.3688470358646546, 0.49389849650006856`, 0.9447235848600365], 
             UndirectedEdge[90, 144] -> 
             RGBColor[
              0.35962797975699734`, 0.48591341346284866`, 0.9441361547569478],
              UndirectedEdge[49, 115] -> 
             RGBColor[
              0.22907293102325943`, 0.358100552941108, 0.9363567365875176], 
             UndirectedEdge[77, 244] -> 
             RGBColor[
              0.2442718082387917, 0.3740755365591065, 0.9372222901602183], 
             UndirectedEdge[66, 95] -> 
             RGBColor[
              0.7175511909941827, 0.7776658666577836, 0.9642038036331552], 
             UndirectedEdge[94, 125] -> 
             RGBColor[
              0.9272871440372241, 0.9396965749731525, 0.7126838428267497], 
             UndirectedEdge[196, 230] -> 
             RGBColor[
              0.2651423022333762, 0.39601174901316233`, 0.938410833918081], 
             UndirectedEdge[138, 245] -> 
             RGBColor[
              0.5655432626553039, 0.6564020281299278, 0.9598314214470098], 
             UndirectedEdge[100, 127] -> 
             RGBColor[
              0.8414762129232649, 0.3198099242864162, 0.18735097437698822`], 
             UndirectedEdge[24, 288] -> 
             RGBColor[
              0.9087689498125788, 0.7161208029301624, 0.5832293866647026], 
             UndirectedEdge[224, 258] -> 
             RGBColor[
              0.9656458741337097, 0.9399341707856219, 0.6428561562394914], 
             UndirectedEdge[25, 203] -> 
             RGBColor[
              0.2557021473412196, 0.3860895476811155, 0.9378732310624303], 
             UndirectedEdge[143, 239] -> 
             RGBColor[
              0.4039421601527854, 0.5242961292262122, 0.9469598151462764], 
             UndirectedEdge[142, 282] -> 
             RGBColor[
              0.8113403946734408, 0.8529848446549176, 0.9565261589007614], 
             UndirectedEdge[57, 242] -> 
             RGBColor[
              0.24374269016754463`, 0.3735193999182025, 0.9371921576688209], 
             UndirectedEdge[47, 177] -> 
             RGBColor[
              0.5316337139639098, 0.6296909943120255, 0.956545018426947], 
             UndirectedEdge[43, 174] -> 
             RGBColor[
              0.35724861486395953`, 0.48385252718285615`, 0.9439845437299532],
              UndirectedEdge[5, 29] -> 
             RGBColor[
              0.23189096279390453`, 0.36106248300558996`, 0.9365172193279515],
              UndirectedEdge[167, 282] -> 
             RGBColor[
              0.8587917501354356, 0.8900542041854869, 0.9612556665550847], 
             UndirectedEdge[131, 172] -> 
             RGBColor[
              0.297163306859998, 0.4281806673087738, 0.9402888359918464], 
             UndirectedEdge[21, 101] -> 
             RGBColor[
              0.4650224715635836, 0.5746682645420044, 0.9515515525742121], 
             UndirectedEdge[251, 300] -> 
             RGBColor[
              0.27128730129384493`, 0.40247053264115845`, 0.9387607825238632],
              UndirectedEdge[75, 167] -> 
             RGBColor[
              0.7422194299230214, 0.7985467268232416, 0.9749411544059516], 
             UndirectedEdge[165, 281] -> 
             RGBColor[
              0.9081683799556731, 0.6116901368011833, 0.2799978889278235], 
             UndirectedEdge[63, 174] -> 
             RGBColor[
              0.35841838866408615`, 0.48486572645398507`, 0.944059080682107], 
             UndirectedEdge[64, 211] -> 
             RGBColor[
              0.238007335368493, 0.36749117838190204`, 0.936865537697712], 
             UndirectedEdge[124, 237] -> 
             RGBColor[
              0.7932365579017887, 0.8390697764976703, 0.9690655590701622], 
             UndirectedEdge[127, 192] -> 
             RGBColor[
              0.8488791161434632, 0.3663608331165159, 0.19403468172993021`], 
             UndirectedEdge[62, 228] -> 
             RGBColor[
              0.90559598823519, 0.9239215498870947, 0.8315118721300905], 
             UndirectedEdge[152, 277] -> 
             RGBColor[
              0.3011955804505697, 0.43017548464198757`, 0.9406006083286469], 
             UndirectedEdge[76, 157] -> 
             RGBColor[
              0.3201380287875101, 0.4503731664220151, 0.9416688088356775], 
             UndirectedEdge[106, 297] -> 
             RGBColor[
              0.7085338986582898, 0.7722313337797134, 0.9715836954586705], 
             UndirectedEdge[91, 203] -> 
             RGBColor[
              0.2661031933042482, 0.39702170645266144`, 0.9384655552430561], 
             UndirectedEdge[215, 271] -> 
             RGBColor[
              0.9862840872732699, 0.9639445925953173, 0.5488858494022204], 
             UndirectedEdge[181, 296] -> 
             RGBColor[
              0.7050263286294778, 0.769491193414686, 0.9712340936583042], 
             UndirectedEdge[27, 119] -> 
             RGBColor[
              0.2703316084942079, 0.40146603891431676`, 0.9387063572327446], 
             UndirectedEdge[100, 170] -> 
             RGBColor[
              0.8360368854877944, 0.2780008700889096, 0.18214226828194], 
             UndirectedEdge[112, 115] -> 
             RGBColor[
              0.236902386747869, 0.36632980732383724`, 0.9368026125083924], 
             UndirectedEdge[75, 282] -> 
             RGBColor[
              0.8470847195516484, 0.8809085829167043, 0.9600888191549137], 
             UndirectedEdge[234, 255] -> 
             RGBColor[
              0.8881366683562935, 0.5036662405654082, 0.2296318891309308], 
             UndirectedEdge[29, 77] -> 
             RGBColor[
              0.2444276826034072, 0.3742393703993229, 0.9372311669746878], 
             UndirectedEdge[44, 192] -> 
             RGBColor[
              0.9150207009153106, 0.6868003754774932, 0.26390009611845466`], 
             UndirectedEdge[49, 57] -> 
             RGBColor[
              0.2418037466004938, 0.3714814472931095, 0.9370817377010874], 
             UndirectedEdge[4, 281] -> 
             RGBColor[
              0.6878485673408958, 0.45771600390430534`, 0.5695400851133919], 
             UndirectedEdge[23, 285] -> 
             RGBColor[
              0.33957273212272987`, 0.46739870088843105`, 0.9429001346157797],
              UndirectedEdge[86, 109] -> 
             RGBColor[
              0.9480181265878662, 0.9334317685964351, 0.674604431944415], 
             UndirectedEdge[276, 279] -> 
             RGBColor[
              0.24528708035805388`, 0.3751426519284214, 0.9372801084054498], 
             UndirectedEdge[139, 183] -> 
             RGBColor[
              0.2550340991670391, 0.38538738669335115`, 0.9378351867071995], 
             UndirectedEdge[234, 287] -> 
             RGBColor[
              0.8791470053904711, 0.46890980859888415`, 0.21779165603051126`],
              UndirectedEdge[160, 181] -> 
             RGBColor[
              0.6520185359229838, 0.7272823998054908, 0.9664968499202544], 
             UndirectedEdge[196, 298] -> 
             RGBColor[
              0.28309225038485036`, 0.4148782826128075, 0.9394330569107388], 
             UndirectedEdge[255, 287] -> 
             RGBColor[
              0.9499646737467646, 0.8384490491642924, 0.28320554516144203`], 
             UndirectedEdge[126, 216] -> 
             RGBColor[
              0.24238826022285348`, 0.3720958081705137, 0.9371150248871702], 
             UndirectedEdge[190, 212] -> 
             RGBColor[
              0.21992645288427248`, 0.3484870244968241, 0.9358358581885042], 
             UndirectedEdge[39, 137] -> 
             RGBColor[
              0.8565494590888623, 0.4213131070375924, 0.20122297160509353`], 
             UndirectedEdge[170, 195] -> 
             RGBColor[
              0.820518598671917, 0.15872051746543236`, 0.16728193930165758`], 
             UndirectedEdge[69, 288] -> 
             RGBColor[
              0.9274695616660017, 0.7266621842687284, 0.34504384155502377`], 
             UndirectedEdge[101, 231] -> 
             RGBColor[
              0.49585480302230733`, 0.6013736803735128, 0.9535161614708018], 
             UndirectedEdge[57, 253] -> 
             RGBColor[
              0.27188917324815276`, 0.40310313822602206`, 0.9387950582412713],
              UndirectedEdge[52, 266] -> 
             RGBColor[
              0.5326709863563452, 0.2573632665445422, 0.5510021420640641], 
             UndirectedEdge[28, 275] -> 
             RGBColor[
              0.21809561015053047`, 0.3465626927015274, 0.9357315944033067], 
             UndirectedEdge[4, 226] -> 
             RGBColor[
              0.35927387507325015`, 0.47126073145434144`, 0.9452005342031744],
              UndirectedEdge[104, 229] -> 
             RGBColor[
              0.3157302972548372, 0.4457026097570346, 0.9414191773076857], 
             UndirectedEdge[189, 293] -> 
             RGBColor[
              0.2205548801399334, 0.3491475413871131, 0.9358716461910392], 
             UndirectedEdge[155, 156] -> 
             RGBColor[
              0.22000089461836236`, 0.3485652674792311, 0.935840097535134], 
             UndirectedEdge[107, 281] -> 
             RGBColor[
              0.835111708182694, 0.27088955190662645`, 0.18125631744973736`], 
             UndirectedEdge[107, 240] -> 
             RGBColor[
              0.9145402901776019, 0.6275231337808342, 0.4351299261966648], 
             UndirectedEdge[13, 105] -> 
             RGBColor[
              0.29764935998569264`, 0.4301787277773499, 0.9402620627671929], 
             UndirectedEdge[96, 138] -> 
             RGBColor[
              0.5560749070471602, 0.6482010143955439, 0.959228106200197], 
             UndirectedEdge[254, 260] -> 
             RGBColor[
              0.870237845536556, 0.7409780985202714, 0.6082514586621423], 
             UndirectedEdge[120, 176] -> 
             RGBColor[
              0.18443322649941224`, 0.31118139316580623`, 0.9338145714534094],
              UndirectedEdge[59, 125] -> 
             RGBColor[
              0.9127176607588363, 0.6199165551572493, 0.3088626814342206], 
             UndirectedEdge[22, 267] -> 
             RGBColor[
              0.642613111904264, 0.7180602166534845, 0.966841075599027], 
             UndirectedEdge[28, 197] -> 
             RGBColor[
              0.21695644286649302`, 0.3453653556586265, 0.9356667205117277], 
             UndirectedEdge[245, 298] -> 
             RGBColor[
              0.35482735126592213`, 0.47958317697125596`, 0.9439097968625934],
              UndirectedEdge[193, 199] -> 
             RGBColor[
              0.28921237678725265`, 0.4129203038152378, 0.9400888107445714], 
             UndirectedEdge[22, 274] -> 
             RGBColor[
              0.8909772154370372, 0.8747143818458635, 0.6496575550294168], 
             UndirectedEdge[76, 201] -> 
             RGBColor[
              0.3077043294157084, 0.43960372096206174`, 0.9408765445063949], 
             UndirectedEdge[19, 158] -> 
             RGBColor[
              0.3474496051113486, 0.47374907870238386`, 0.9434193305882683], 
             UndirectedEdge[78, 199] -> 
             RGBColor[
              0.17948366008578914`, 0.30597908504445237`, 0.9335327009683809],
              UndirectedEdge[61, 267] -> 
             RGBColor[
              0.517343318582302, 0.6190416379328455, 0.9551463076112685], 
             UndirectedEdge[106, 283] -> 
             RGBColor[
              0.6376959489926155, 0.716530117719581, 0.9647707808430861], 
             UndirectedEdge[174, 283] -> 
             RGBColor[
              0.5055233087265141, 0.6077894774448256, 0.9546733906594562], 
             UndirectedEdge[19, 242] -> 
             RGBColor[
              0.26584977931499626`, 0.39675535228258274`, 0.9384511236912607],
              UndirectedEdge[125, 195] -> 
             RGBColor[
              0.9058844617461582, 0.5673935932189047, 0.3023192023426855], 
             UndirectedEdge[115, 159] -> 
             RGBColor[
              0.23449254027581456`, 0.3637969058886168, 0.9366653753168572], 
             UndirectedEdge[158, 177] -> 
             RGBColor[
              0.4114198455834537, 0.5307729245068593, 0.947436286649661], 
             UndirectedEdge[42, 134] -> 
             RGBColor[
              0.26421930785544107`, 0.3950416234007289, 0.9383582707537054], 
             UndirectedEdge[165, 179] -> 
             RGBColor[
              0.986953469781533, 0.9683582137242022, 0.5663859549250714], 
             UndirectedEdge[108, 145] -> 
             RGBColor[
              0.3065621353882716, 0.43629450439653, 0.9408887080179298], 
             UndirectedEdge[44, 125] -> 
             RGBColor[
              0.9788402151300284, 0.9402098215196141, 0.37870987228958564`], 
             UndirectedEdge[39, 141] -> 
             RGBColor[
              0.8832675790785431, 0.5628271647927903, 0.22430794542071705`], 
             UndirectedEdge[50, 87] -> 
             RGBColor[
              0.314278172622923, 0.4436160187426821, 0.9413569968700557], 
             UndirectedEdge[26, 226] -> 
             RGBColor[
              0.5823809999360594, 0.646902214593436, 0.908957705075064], 
             UndirectedEdge[9, 143] -> 
             RGBColor[
              0.4567898510085129, 0.5683456525115964, 0.9508037050929882], 
             UndirectedEdge[136, 299] -> 
             RGBColor[
              0.9936961088777931, 0.9896128904175391, 0.6052453259924624], 
             UndirectedEdge[134, 144] -> 
             RGBColor[
              0.29485513198583013`, 0.42659799471298, 0.9401265091035182], 
             UndirectedEdge[240, 281] -> 
             RGBColor[
              0.9155049767516813, 0.6349381375175613, 0.436053711149461], 
             UndirectedEdge[257, 261] -> 
             RGBColor[
              0.39597335276996437`, 0.5173939487951174, 0.9464520497863826], 
             UndirectedEdge[57, 84] -> 
             RGBColor[
              0.27383547980684575`, 0.4051488298221716, 0.9389058975204863], 
             UndirectedEdge[135, 254] -> 
             RGBColor[
              0.940708824154274, 0.7947861767157479, 0.5224157389136257], 
             UndirectedEdge[14, 224] -> 
             RGBColor[
              0.8961112066597844, 0.5421659440515132, 0.2527391724419306], 
             UndirectedEdge[96, 289] -> 
             RGBColor[
              0.3482245893870246, 0.47439408393544596`, 0.9434696729393952], 
             UndirectedEdge[92, 189] -> 
             RGBColor[
              0.2464728493758267, 0.3763889703481986, 0.937347636196824], 
             UndirectedEdge[107, 127] -> 
             RGBColor[
              0.8334595581640123, 0.25819040288628525`, 0.17967421672601133`],
              UndirectedEdge[172, 270] -> 
             RGBColor[
              0.24887539777286288`, 0.3789142010438502, 0.9374844577737833], 
             UndirectedEdge[48, 84] -> 
             RGBColor[
              0.35715044434118537`, 0.4830160061947183, 0.9440058041437522], 
             UndirectedEdge[149, 289] -> 
             RGBColor[
              0.29246611856111315`, 0.4247308124036294, 0.9399668848359817], 
             UndirectedEdge[1, 102] -> 
             RGBColor[
              0.40192272768373283`, 0.5225469983211459, 0.9468311386950623], 
             UndirectedEdge[33, 297] -> 
             RGBColor[
              0.8375308432174786, 0.8737699796260231, 0.9842378309047126], 
             UndirectedEdge[18, 135] -> 
             RGBColor[
              0.9682482286960121, 0.9748593362633335, 0.8947082894518925], 
             UndirectedEdge[60, 137] -> 
             RGBColor[
              0.8858243279121996, 0.5479479904274629, 0.22532498219274089`], 
             UndirectedEdge[156, 208] -> 
             RGBColor[
              0.2568293808226203, 0.38727434154079826`, 0.9379374253416035], 
             UndirectedEdge[104, 279] -> 
             RGBColor[
              0.27193222945827744`, 0.4031483930327844, 0.9387975102287419], 
             UndirectedEdge[74, 158] -> 
             RGBColor[
              0.5209230649967003, 0.6205987474764012, 0.9558008759103712], 
             UndirectedEdge[80, 277] -> 
             RGBColor[
              0.30846241772387, 0.4378133913603206, 0.9410144439610391], 
             UndirectedEdge[223, 291] -> 
             RGBColor[
              0.8526313936469496, 0.36002028922446494`, 0.19625022045814194`],
              UndirectedEdge[114, 264] -> 
             RGBColor[
              0.29953624630010656`, 0.4321619649293011, 0.9403695181514007], 
             UndirectedEdge[1, 237] -> 
             RGBColor[
              0.5286509868219015, 0.6272769374241931, 0.9562975328211968], 
             UndirectedEdge[84, 292] -> 
             RGBColor[
              0.2718397461725893, 0.40305118723574723`, 0.9387922434424387], 
             UndirectedEdge[103, 152] -> 
             RGBColor[
              0.26605649274810816`, 0.396972621207172, 0.9384628957154713], 
             UndirectedEdge[10, 269] -> 
             RGBColor[
              0.2192290472618576, 0.3477540069695957, 0.9357961419700269], 
             UndirectedEdge[109, 138] -> 
             RGBColor[
              0.8139262808550589, 0.8553825016885668, 0.9818711941291625], 
             UndirectedEdge[165, 240] -> 
             RGBColor[
              0.987596961950581, 0.9683237186753911, 0.533871497674751], 
             UndirectedEdge[249, 254] -> 
             RGBColor[
              0.8549509396381043, 0.371609679278205, 0.19822709100428773`], 
             UndirectedEdge[2, 155] -> 
             RGBColor[
              0.22153004206728566`, 0.3501724984015976, 0.9359271802201792], 
             UndirectedEdge[117, 161] -> 
             RGBColor[
              0.20987266837087443`, 0.33791985952648745`, 0.9352633100337076],
              UndirectedEdge[169, 264] -> 
             RGBColor[
              0.29384317958318956`, 0.42617819084854336`, 0.9400453064240097],
              UndirectedEdge[3, 229] -> 
             RGBColor[
              0.3618568268450173, 0.48784392878537974`, 0.9442781749225044], 
             UndirectedEdge[55, 90] -> 
             RGBColor[
              0.3401206359010615, 0.4660537805054501, 0.9430016668956538], 
             UndirectedEdge[3, 259] -> 
             RGBColor[
              0.42079287632469464`, 0.5385942486118271, 0.9481156241324957], 
             UndirectedEdge[113, 254] -> 
             RGBColor[
              0.925365599889266, 0.7843240503848107, 0.5923111720047104], 
             UndirectedEdge[6, 205] -> 
             RGBColor[
              0.41755993513205164`, 0.5337399711358773, 0.9484090697443592], 
             UndirectedEdge[120, 287] -> 
             RGBColor[
              0.5654447927305568, 0.5603176274195498, 0.6027460190921992], 
             UndirectedEdge[31, 67] -> 
             RGBColor[
              0.765577527957654, 0.8171802233035855, 0.9773175856314692], 
             UndirectedEdge[141, 232] -> 
             RGBColor[
              0.9465494933171561, 0.8120284719793993, 0.41813025783551805`], 
             UndirectedEdge[41, 88] -> 
             RGBColor[
              0.4306059655104517, 0.5460088371370204, 0.9490406986812941], 
             UndirectedEdge[71, 122] -> 
             RGBColor[
              0.6268946494046528, 0.707980343525642, 0.9637705896733515], 
             UndirectedEdge[78, 120] -> 
             RGBColor[
              0.1849774474258748, 0.3117534038651181, 0.9338455640300687], 
             UndirectedEdge[177, 247] -> 
             RGBColor[
              0.4991479409504841, 0.603343634292864, 0.9539698061272375], 
             UndirectedEdge[168, 182] -> 
             RGBColor[
              0.34652806688330007`, 0.474422427150048, 0.9433067307526943], 
             UndirectedEdge[26, 228] -> 
             RGBColor[
              0.901089116284713, 0.9224316156704129, 0.933371766463492], 
             UndirectedEdge[7, 194] -> 
             RGBColor[
              0.4552899701705174, 0.5670735874923983, 0.9507006582548503], 
             UndirectedEdge[206, 244] -> 
             RGBColor[
              0.23959248852906917`, 0.3691572748581827, 0.9369558098251829], 
             UndirectedEdge[31, 109] -> 
             RGBColor[
              0.7700026915435176, 0.8207087286290875, 0.9777396616846791], 
             UndirectedEdge[57, 235] -> 
             RGBColor[
              0.24454607243650103`, 0.3743638056202535, 0.9372379091005405], 
             UndirectedEdge[24, 135] -> 
             RGBColor[
              0.9728662611822794, 0.9783034573302576, 0.8868911650284141], 
             UndirectedEdge[130, 220] -> 
             RGBColor[
              0.21805936955163013`, 0.34652460153429643`, 0.9357295305548126],
              UndirectedEdge[84, 112] -> 
             RGBColor[
              0.2764157065059942, 0.4078608116787981, 0.9390528376138995], 
             UndirectedEdge[76, 104] -> 
             RGBColor[
              0.2896837321277139, 0.4218063478486378, 0.9398084320447715], 
             UndirectedEdge[21, 87] -> 
             RGBColor[
              0.32978099166431396`, 0.45704378140199375`, 0.9423448227907686],
              UndirectedEdge[43, 183] -> 
             RGBColor[
              0.28838161647063476`, 0.4191962552733669, 0.9397797353853092], 
             UndirectedEdge[11, 131] -> 
             RGBColor[
              0.3341685066956953, 0.46386169752747186`, 0.9425138996464097], 
             UndirectedEdge[21, 187] -> 
             RGBColor[
              0.3736920911272321, 0.49809503984895503`, 0.9450323074970538], 
             UndirectedEdge[36, 66] -> 
             RGBColor[
              0.8530135718328662, 0.8858447874582254, 0.9760955206644191], 
             UndirectedEdge[124, 125] -> 
             RGBColor[
              0.970159485355791, 0.9735725032155419, 0.706048969605638], 
             UndirectedEdge[232, 296] -> 
             RGBColor[
              0.8451660598218556, 0.8762026073137711, 0.7845904625645401], 
             UndirectedEdge[75, 239] -> 
             RGBColor[
              0.5708233361978141, 0.6599633407458361, 0.9605961986132696], 
             UndirectedEdge[108, 114] -> 
             RGBColor[
              0.32416580444258236`, 0.4547970767096937, 0.9418912109282782], 
             UndirectedEdge[137, 266] -> 
             RGBColor[
              0.546600080262197, 0.3644283860727875, 0.564340658118969], 
             UndirectedEdge[74, 262] -> 
             RGBColor[
              0.8160969055518104, 0.8533507770496733, 0.7753857250766871], 
             UndirectedEdge[48, 90] -> 
             RGBColor[
              0.4086146868704133, 0.5283432370210001, 0.9472575444169704], 
             UndirectedEdge[125, 150] -> 
             RGBColor[
              0.9773157340645346, 0.9789096217852411, 0.6939353071903218], 
             UndirectedEdge[38, 55] -> 
             RGBColor[
              0.34731954937378307`, 0.4722891175276097, 0.9434603752963864], 
             UndirectedEdge[110, 165] -> 
             RGBColor[
              0.9866031709361507, 0.9682133561493669, 0.5721913133374072], 
             UndirectedEdge[114, 145] -> 
             RGBColor[
              0.28680752014306377`, 0.4187832666903979, 0.9396446360272199], 
             UndirectedEdge[222, 290] -> 
             RGBColor[
              0.5245306986367102, 0.6244100551018348, 0.9558410534763778], 
             UndirectedEdge[267, 286] -> 
             RGBColor[
              0.5134415575632728, 0.6158740125652669, 0.954839146691229], 
             UndirectedEdge[6, 187] -> 
             RGBColor[
              0.3348012763614461, 0.46412565624274105`, 0.9425646219959795], 
             UndirectedEdge[221, 231] -> 
             RGBColor[
              0.3698663550363416, 0.4934747204504928, 0.9448363781661868], 
             UndirectedEdge[106, 286] -> 
             RGBColor[
              0.6078523188068897, 0.6923017142945901, 0.9624213809540463], 
             UndirectedEdge[67, 154] -> 
             RGBColor[
              0.8267592072412856, 0.8653361474156035, 0.9831692431983503], 
             UndirectedEdge[85, 296] -> 
             RGBColor[
              0.8079306217366228, 0.8506861757670146, 0.9812769124001008], 
             UndirectedEdge[41, 201] -> 
             RGBColor[
              0.3390519049385823, 0.4680914516387281, 0.942825065464227], 
             UndirectedEdge[42, 235] -> 
             RGBColor[
              0.24823850572703557`, 0.37824478712239773`, 0.9374481877139709],
              UndirectedEdge[44, 60] -> 
             RGBColor[
              0.9455688567915195, 0.8192169579907062, 0.28906456863413965`], 
             UndirectedEdge[199, 228] -> 
             RGBColor[
              0.49763512145939465`, 0.5809234064486897, 0.9579150616794772], 
             UndirectedEdge[39, 62] -> 
             RGBColor[
              0.931190722612425, 0.7413845468769279, 0.4459365036310404], 
             UndirectedEdge[48, 144] -> 
             RGBColor[
              0.3646961975812182, 0.4903032490061542, 0.9444590971150582], 
             UndirectedEdge[68, 215] -> 
             RGBColor[
              0.9347347232001206, 0.7573256172439325, 0.47384806566130333`], 
             UndirectedEdge[127, 240] -> 
             RGBColor[
              0.9138528267329997, 0.6222389884972201, 0.4344716104257349], 
             UndirectedEdge[4, 26] -> 
             RGBColor[
              0.7627278647878275, 0.8127689353043519, 0.92065723869614], 
             UndirectedEdge[8, 47] -> 
             RGBColor[
              0.6479545398771973, 0.7249062782797447, 0.9655457111216659], 
             UndirectedEdge[112, 175] -> 
             RGBColor[
              0.27336230601956724`, 0.40465149417079094`, 0.9388789509732987],
              UndirectedEdge[162, 203] -> 
             RGBColor[
              0.27206034387321254`, 0.4032830494058043, 0.9388048061551442], 
             UndirectedEdge[6, 50] -> 
             RGBColor[
              0.32906105284495657`, 0.4591537631447806, 0.9421988600293891], 
             UndirectedEdge[15, 294] -> 
             RGBColor[
              0.2244101664519819, 0.3531996917403464, 0.9360911990431254], 
             UndirectedEdge[6, 219] -> 
             RGBColor[
              0.2899540268393041, 0.4220904447281936, 0.9398238249287314], 
             UndirectedEdge[110, 281] -> 
             RGBColor[
              0.914511185737251, 0.6348277749915371, 0.4743735268121172], 
             UndirectedEdge[167, 297] -> 
             RGBColor[
              0.7571627446031911, 0.8102205578247882, 0.9764305643600557], 
             UndirectedEdge[122, 246] -> 
             RGBColor[
              0.6115303319065195, 0.6955068984260417, 0.962561054318549], 
             UndirectedEdge[210, 277] -> 
             RGBColor[
              0.36382607089811214`, 0.48954958900708645`, 0.9444036534122333],
              UndirectedEdge[225, 234] -> 
             RGBColor[
              0.889140927135372, 0.5070538412384147, 0.23353324484929344`], 
             UndirectedEdge[84, 280] -> 
             RGBColor[
              0.28433817175579457`, 0.41618782496964746`, 0.9395040102896386],
              UndirectedEdge[67, 95] -> 
             RGBColor[
              0.7004824194836051, 0.7643330817431344, 0.9721930602411528], 
             UndirectedEdge[81, 285] -> 
             RGBColor[
              0.33930631085889784`, 0.4671186752480599, 0.9428849623189395], 
             UndirectedEdge[79, 164] -> 
             RGBColor[
              0.38942752096010885`, 0.5117242782844935, 0.9460349551717104], 
             UndirectedEdge[123, 157] -> 
             RGBColor[
              0.3911005410183704, 0.5131733641705265, 0.9461415585304294], 
             UndirectedEdge[85, 165] -> 
             RGBColor[
              0.9499430145672961, 0.9419121380578821, 0.6850057931573457], 
             UndirectedEdge[59, 62] -> 
             RGBColor[
              0.9138294445361559, 0.6222945482383531, 0.42987348446131357`], 
             UndirectedEdge[38, 48] -> 
             RGBColor[
              0.41581360034313486`, 0.5345785740431597, 0.947716252817703], 
             UndirectedEdge[262, 291] -> 
             RGBColor[
              0.9059438756426232, 0.5640930053700905, 0.37544589714295], 
             UndirectedEdge[26, 170] -> 
             RGBColor[
              0.903864214749553, 0.5788492838255521, 0.5265064491665074], 
             UndirectedEdge[43, 139] -> 
             RGBColor[
              0.2888262243395204, 0.4196635663333328, 0.9398050551457039], 
             UndirectedEdge[52, 281] -> 
             RGBColor[
              0.8268922067247678, 0.207710861892501, 0.1733853135710282], 
             UndirectedEdge[124, 142] -> 
             RGBColor[
              0.8033587771487245, 0.8470321673736835, 0.9700369554308557], 
             UndirectedEdge[166, 271] -> 
             RGBColor[
              0.9850940999243964, 0.9612451065301149, 0.40815265332302325`], 
             UndirectedEdge[37, 150] -> 
             RGBColor[
              0.8213545365263866, 0.860837194061274, 0.9590036741380308], 
             UndirectedEdge[51, 66] -> 
             RGBColor[
              0.9700089985303242, 0.9755966228942858, 0.8659381168837096], 
             UndirectedEdge[60, 125] -> 
             RGBColor[
              0.9593538076584427, 0.8656414371856946, 0.3490277111915949], 
             UndirectedEdge[215, 223] -> 
             RGBColor[
              0.9412290011481947, 0.7868146166289862, 0.47926705037049566`], 
             UndirectedEdge[237, 282] -> 
             RGBColor[
              0.8012181754265049, 0.8450224537789045, 0.955554762540068], 
             UndirectedEdge[143, 172] -> 
             RGBColor[
              0.33312272414216076`, 0.4593269071857189, 0.9425801382634016], 
             UndirectedEdge[177, 285] -> 
             RGBColor[
              0.40098949086418123`, 0.5217386754938967, 0.9467716736701495], 
             UndirectedEdge[244, 270] -> 
             RGBColor[
              0.23538330068246843`, 0.36473315155348174`, 0.9367161028042543],
              UndirectedEdge[147, 272] -> 
             RGBColor[
              0.2247364657597668, 0.3535426530013993, 0.9361097813059873], 
             UndirectedEdge[46, 114] -> 
             RGBColor[
              0.29827465777054285`, 0.4308359553953969, 0.9402976725509951], 
             UndirectedEdge[104, 128] -> 
             RGBColor[
              0.26216622821870855`, 0.39288370652975557`, 0.9382413509056526],
              UndirectedEdge[199, 220] -> 
             RGBColor[
              0.21805936955163013`, 0.34652460153429643`, 0.9357295305548126],
              UndirectedEdge[112, 146] -> 
             RGBColor[
              0.24133200131587673`, 0.37098561308859834`, 0.937054872505013], 
             UndirectedEdge[191, 203] -> 
             RGBColor[
              0.2517414689713402, 0.38192662359285945`, 0.9376476762885642], 
             UndirectedEdge[31, 96] -> 
             RGBColor[
              0.512151317735619, 0.6135272413360646, 0.9550965737557137], 
             UndirectedEdge[59, 228] -> 
             RGBColor[
              0.8245766992197552, 0.5548258112486377, 0.5806907356901773], 
             UndirectedEdge[129, 289] -> 
             RGBColor[
              0.26344635035437974`, 0.39422919605877726`, 0.9383142519675081],
              UndirectedEdge[54, 106] -> 
             RGBColor[
              0.5370375913061106, 0.6338360445866622, 0.9571160047492481], 
             UndirectedEdge[102, 142] -> 
             RGBColor[
              0.5221732711977142, 0.6208612990518254, 0.9562111960106483], 
             UndirectedEdge[74, 90] -> 
             RGBColor[
              0.5208802713688769, 0.620561681786851, 0.9557981491382472], 
             UndirectedEdge[143, 174] -> 
             RGBColor[
              0.39453676766698986`, 0.5161496509837875, 0.9463605118539434], 
             UndirectedEdge[144, 292] -> 
             RGBColor[
              0.2793854994126222, 0.4103384300471832, 0.9392455364137446], 
             UndirectedEdge[59, 255] -> 
             RGBColor[
              0.895882246116654, 0.5632021453653563, 0.23704906314163093`], 
             UndirectedEdge[254, 258] -> 
             RGBColor[
              0.926544473085371, 0.7852032520842381, 0.5903156471830767], 
             UndirectedEdge[46, 108] -> 
             RGBColor[
              0.3180292730157506, 0.448347193101529, 0.9415417445417048], 
             UndirectedEdge[222, 278] -> 
             RGBColor[
              0.51953209520131, 0.6203519636484585, 0.9554475451034554], 
             UndirectedEdge[115, 294] -> 
             RGBColor[
              0.2157444487404361, 0.3440914729872748, 0.9355976992392334], 
             UndirectedEdge[89, 177] -> 
             RGBColor[
              0.3486700459196015, 0.47359177071300174`, 0.9435415608547846], 
             UndirectedEdge[45, 195] -> 
             RGBColor[
              0.8384837744462674, 0.29680873085731074`, 0.18448541191193943`],
              UndirectedEdge[205, 231] -> 
             RGBColor[
              0.4872830813565614, 0.5944147705735998, 0.9528413641420233], 
             UndirectedEdge[148, 244] -> 
             RGBColor[
              0.24066234627754973`, 0.37028176318473494`, 0.9370167366412461],
              UndirectedEdge[20, 297] -> 
             RGBColor[
              0.8131524423226874, 0.8543313044865806, 0.981912597264512], 
             UndirectedEdge[6, 34] -> 
             RGBColor[
              0.31658612534963915`, 0.4483486079564237, 0.9414039686805327], 
             UndirectedEdge[13, 245] -> 
             RGBColor[
              0.36526550488349396`, 0.49055433824048805`, 0.9445042342692497],
              UndirectedEdge[104, 201] -> 
             RGBColor[
              0.30309244121459367`, 0.43475633405208935`, 0.9406139042960187],
              UndirectedEdge[55, 253] -> 
             RGBColor[
              0.2867100868131406, 0.4186808580830187, 0.9396390873432205], 
             UndirectedEdge[52, 141] -> 
             RGBColor[
              0.8583552325882947, 0.3856963454250917, 0.20101401461005142`], 
             UndirectedEdge[160, 299] -> 
             RGBColor[
              0.7923522710279916, 0.8350967196266381, 0.8509761351220573], 
             UndirectedEdge[229, 284] -> 
             RGBColor[
              0.3010164849724387, 0.4302374601386527, 0.9405812474653377], 
             UndirectedEdge[27, 268] -> 
             RGBColor[
              0.2604774227946408, 0.3911086649526121, 0.9381451759351156], 
             UndirectedEdge[193, 236] -> 
             RGBColor[
              0.511354201918838, 0.6127180573453962, 0.9550785966275717], 
             UndirectedEdge[78, 193] -> 
             RGBColor[
              0.2897690368730418, 0.4135053888596902, 0.9401205117129523], 
             UndirectedEdge[175, 177] -> 
             RGBColor[
              0.3568594089399756, 0.48219931048302006`, 0.944007932963718], 
             UndirectedEdge[36, 67] -> 
             RGBColor[
              0.8359448003222887, 0.8725120025435762, 0.9840847772724168], 
             UndirectedEdge[37, 239] -> 
             RGBColor[
              0.5459185219885249, 0.6405075106019407, 0.9581139194816087], 
             UndirectedEdge[49, 280] -> 
             RGBColor[
              0.2523064385494426, 0.38252044244058536`, 0.9376798504702395], 
             UndirectedEdge[263, 276] -> 
             RGBColor[
              0.24638255548127658`, 0.37629406574006286`, 0.9373424940931072],
              UndirectedEdge[13, 73] -> 
             RGBColor[
              0.31756925587348483`, 0.44924224463119755`, 0.9414650714584689],
              UndirectedEdge[136, 240] -> 
             RGBColor[
              0.9939206142632153, 0.9894051335662295, 0.5796745640498617], 
             UndirectedEdge[79, 241] -> 
             RGBColor[
              0.3370030923017984, 0.46357362454027395`, 0.9427949607029437], 
             UndirectedEdge[78, 226] -> 
             RGBColor[
              0.17948366519653014`, 0.30597909041616517`, 0.9335327012594301],
              UndirectedEdge[3, 74] -> 
             RGBColor[
              0.5077694883992605, 0.6092057805456816, 0.9549627416408335], 
             UndirectedEdge[148, 203] -> 
             RGBColor[
              0.2492037147300215, 0.37925928298232137`, 0.9375031549387921], 
             UndirectedEdge[90, 257] -> 
             RGBColor[
              0.39742589509621323`, 0.518652067951214, 0.9465446044989785], 
             UndirectedEdge[34, 87] -> 
             RGBColor[
              0.3018032451276056, 0.4328108635543251, 0.9405621055211995], 
             UndirectedEdge[146, 235] -> 
             RGBColor[
              0.23624487142727435`, 0.3656387170330131, 0.9367651679835913], 
             UndirectedEdge[181, 256] -> 
             RGBColor[
              0.8545325264557142, 0.8843014088645924, 0.8481299389821997], 
             UndirectedEdge[68, 287] -> 
             RGBColor[
              0.9076706141527531, 0.6630503890698746, 0.24412287160438084`], 
             UndirectedEdge[17, 144] -> 
             RGBColor[
              0.3059659418661292, 0.4382761603632087, 0.940759253289231], 
             UndirectedEdge[163, 216] -> 
             RGBColor[
              0.2500986511246546, 0.3801999178753255, 0.9375541202425267], 
             UndirectedEdge[67, 258] -> 
             RGBColor[
              0.9370426830307382, 0.9519641935346369, 0.9705507738068005], 
             UndirectedEdge[232, 240] -> 
             RGBColor[
              0.9945150494485371, 0.9906765703210165, 0.6443751655434223], 
             UndirectedEdge[133, 210] -> 
             RGBColor[
              0.36435206965698563`, 0.49000518269455634`, 0.9444371695880264],
              UndirectedEdge[58, 154] -> 
             RGBColor[
              0.6450616328403926, 0.7212149997583763, 0.9662359728150638], 
             UndirectedEdge[94, 124] -> 
             RGBColor[
              0.9048214633960636, 0.926634777474092, 0.9800597975853467], 
             UndirectedEdge[50, 213] -> 
             RGBColor[
              0.3901638861949155, 0.5123620808400902, 0.94608187571333], 
             UndirectedEdge[15, 212] -> 
             RGBColor[
              0.22532179004368708`, 0.3541578659355026, 0.9361431146580468], 
             UndirectedEdge[11, 139] -> 
             RGBColor[
              0.2994922538712322, 0.4289019450234698, 0.940484685115865], 
             UndirectedEdge[167, 286] -> 
             RGBColor[
              0.6564811647517911, 0.7302909383396649, 0.9672682498554315], 
             UndirectedEdge[113, 288] -> 
             RGBColor[
              0.9106552013287734, 0.717527566222487, 0.5800364548609709], 
             UndirectedEdge[73, 171] -> 
             RGBColor[
              0.3736817156213931, 0.4980860531072854, 0.9450316463789965], 
             UndirectedEdge[31, 110] -> 
             RGBColor[
              0.8058913506986181, 0.8463947757840589, 0.8648515957717691], 
             UndirectedEdge[202, 275] -> 
             RGBColor[
              0.22044981250771753`, 0.3490371086439815, 0.9358656627448182], 
             UndirectedEdge[103, 241] -> 
             RGBColor[
              0.2789461451652853, 0.41052046314879065`, 0.9391969423520976], 
             UndirectedEdge[9, 20] -> 
             RGBColor[
              0.6913677553568252, 0.7572692319617951, 0.9710889688646087], 
             UndirectedEdge[71, 207] -> 
             RGBColor[
              0.6875924129964879, 0.7556761815938675, 0.9696301113207838], 
             UndirectedEdge[160, 168] -> 
             RGBColor[
              0.4880465107801085, 0.5934258804224648, 0.9533459462263981], 
             UndirectedEdge[6, 114] -> 
             RGBColor[
              0.30504212315896806`, 0.43794899060072, 0.940683069693298], 
             UndirectedEdge[95, 96] -> 
             RGBColor[
              0.44705620926157014`, 0.5606800997756136, 0.9499720483653973], 
             UndirectedEdge[198, 278] -> 
             RGBColor[
              0.5335934338471843, 0.6322342135642272, 0.9564255762110536], 
             UndirectedEdge[86, 281] -> 
             RGBColor[
              0.9054719947624891, 0.6025945964032228, 0.26952294162192125`], 
             UndirectedEdge[107, 165] -> 
             RGBColor[
              0.9072036933815937, 0.6042751330644562, 0.27907410397502735`], 
             UndirectedEdge[155, 184] -> 
             RGBColor[
              0.22486994634019453`, 0.35368294955458646`, 0.9361173828275757],
              UndirectedEdge[247, 285] -> 
             RGBColor[
              0.4809297969495969, 0.5875639936298371, 0.952808962101173], 
             UndirectedEdge[34, 227] -> 
             RGBColor[
              0.2936321912026204, 0.4242225678044243, 0.9400967760881624], 
             UndirectedEdge[116, 152] -> 
             RGBColor[
              0.2878519743324149, 0.4186179236915859, 0.9397503655460857], 
             UndirectedEdge[146, 204] -> 
             RGBColor[
              0.23066664293228167`, 0.35977564520466165`, 0.936447496123051], 
             UndirectedEdge[36, 58] -> 
             RGBColor[
              0.6542472259213957, 0.728390854886349, 0.9671515068891303], 
             UndirectedEdge[105, 129] -> 
             RGBColor[
              0.2625398824694277, 0.39327644083830926`, 0.9382626299624591], 
             UndirectedEdge[87, 187] -> 
             RGBColor[
              0.3200183961394125, 0.4485879118406425, 0.9417227588366461], 
             UndirectedEdge[119, 168] -> 
             RGBColor[
              0.3340488783835623, 0.46130600881057365`, 0.9425960594289393], 
             UndirectedEdge[20, 37] -> 
             RGBColor[
              0.7733043134332283, 0.8232016433411387, 0.9779409081787471], 
             UndirectedEdge[150, 200] -> 
             RGBColor[
              0.9240011310350597, 0.7732005239509658, 0.5878910864110933], 
             UndirectedEdge[1, 43] -> 
             RGBColor[
              0.370348202098986, 0.49519873124143765`, 0.944819237845059], 
             UndirectedEdge[187, 213] -> 
             RGBColor[
              0.395904109711405, 0.5173339739380506, 0.9464476376799205], 
             UndirectedEdge[41, 222] -> 
             RGBColor[
              0.3965617253644508, 0.517903567563995, 0.9464895403678258], 
             UndirectedEdge[196, 263] -> 
             RGBColor[
              0.27095799274113747`, 0.40212440847289477`, 0.9387420288889549],
              UndirectedEdge[148, 172] -> 
             RGBColor[
              0.2541544433679442, 0.3844628126751034, 0.9377850916107751], 
             UndirectedEdge[96, 171] -> 
             RGBColor[
              0.4119096090232586, 0.5311971329821921, 0.9474674939429645], 
             UndirectedEdge[178, 208] -> 
             RGBColor[
              0.2815080542956977, 0.41321319207927465`, 0.9393428392870697], 
             UndirectedEdge[25, 270] -> 
             RGBColor[
              0.24003287271686014`, 0.3696201465615213, 0.9369808890531874], 
             UndirectedEdge[47, 217] -> 
             RGBColor[
              0.7255477462839056, 0.7855226808548759, 0.9732794767865461], 
             UndirectedEdge[33, 142] -> 
             RGBColor[
              0.7868432036591011, 0.8341724103626897, 0.9791857606964562], 
             UndirectedEdge[26, 62] -> 
             RGBColor[
              0.9903418616011138, 0.9899003526601282, 0.7825545152346283], 
             UndirectedEdge[48, 177] -> 
             RGBColor[
              0.4164452697798513, 0.5351256943606145, 0.9477565022356473], 
             UndirectedEdge[238, 300] -> 
             RGBColor[
              0.2671877155710705, 0.398161608117775, 0.9385273171817448], 
             UndirectedEdge[25, 139] -> 
             RGBColor[
              0.25364452897953216`, 0.38392686032244283`, 0.9377560527407058],
              UndirectedEdge[3, 30] -> 
             RGBColor[
              0.4197616538813304, 0.5377570557762624, 0.9480344425242617], 
             UndirectedEdge[95, 171] -> 
             RGBColor[
              0.45349990749309843`, 0.5662613073140733, 0.9503826351187716], 
             UndirectedEdge[21, 50] -> 
             RGBColor[
              0.3679518676107426, 0.4931231467509946, 0.9446665455304635], 
             UndirectedEdge[122, 232] -> 
             RGBColor[
              0.8091446434633787, 0.8477841192514302, 0.781190448595753], 
             UndirectedEdge[127, 136] -> 
             RGBColor[
              0.9128398822496258, 0.6200724026716804, 0.3242188545792082], 
             UndirectedEdge[41, 290] -> 
             RGBColor[
              0.4849597446468357, 0.5901356836497829, 0.9533196272793637], 
             UndirectedEdge[123, 259] -> 
             RGBColor[
              0.4502407471664895, 0.5641005142419657, 0.9499920164228051], 
             UndirectedEdge[20, 185] -> 
             RGBColor[
              0.7169880778773853, 0.7780689639663625, 0.973105894503761], 
             UndirectedEdge[163, 211] -> 
             RGBColor[
              0.2418593140070983, 0.3715398521606279, 0.9370849021826888], 
             UndirectedEdge[33, 37] -> 
             RGBColor[
              0.7976827143280194, 0.8426403184805812, 0.9802661418189477], 
             UndirectedEdge[7, 9] -> 
             RGBColor[
              0.45578820295562306`, 0.5674780753124783, 0.9507398809647807], 
             UndirectedEdge[105, 263] -> 
             RGBColor[
              0.2750769487244079, 0.40645369236820506`, 0.9389765973387527], 
             UndirectedEdge[15, 49] -> 
             RGBColor[
              0.2377386487348052, 0.36720877169417954`, 0.9368502363914097], 
             UndirectedEdge[20, 237] -> 
             RGBColor[
              0.752342583517374, 0.8067713443472341, 0.9758891306955624], 
             UndirectedEdge[26, 220] -> 
             RGBColor[
              0.6215133643769486, 0.6880328107560196, 0.9111862353388274], 
             UndirectedEdge[101, 187] -> 
             RGBColor[
              0.4552598760386822, 0.566212394980653, 0.9509294886200896], 
             UndirectedEdge[93, 94] -> 
             RGBColor[
              0.6965792865266065, 0.7615288190518337, 0.9714662855765266], 
             UndirectedEdge[143, 297] -> 
             RGBColor[
              0.5785745379743751, 0.6654077250363819, 0.9616273334928914], 
             UndirectedEdge[208, 268] -> 
             RGBColor[
              0.274238057450941, 0.4055719644510125, 0.9389288237217572], 
             UndirectedEdge[16, 33] -> 
             RGBColor[
              0.9540665099241967, 0.9616166407194549, 0.7611949655148192], 
             UndirectedEdge[224, 288] -> 
             RGBColor[
              0.9157129138329121, 0.6873344410170366, 0.27129446960632875`], 
             UndirectedEdge[1, 75] -> 
             RGBColor[
              0.5745175309470449, 0.663163066561993, 0.9608315894360424], 
             UndirectedEdge[36, 113] -> 
             RGBColor[
              0.8594902789211216, 0.8906751050000117, 0.9651321449597499], 
             UndirectedEdge[29, 244] -> 
             RGBColor[
              0.24266708121897157`, 0.3723888667157059, 0.9371309033304205], 
             UndirectedEdge[36, 96] -> 
             RGBColor[
              0.5825185901002536, 0.6688590205760554, 0.9618637653966613], 
             UndirectedEdge[58, 138] -> 
             RGBColor[
              0.6278035428683023, 0.7077328487058376, 0.9645158476926661], 
             UndirectedEdge[71, 136] -> 
             RGBColor[
              0.8112521109064372, 0.8487062087696886, 0.716702550774494], 
             UndirectedEdge[144, 252] -> 
             RGBColor[
              0.3081203950955903, 0.44054062730759674`, 0.940881946213421], 
             UndirectedEdge[58, 198] -> 
             RGBColor[
              0.506589269540044, 0.610311016455952, 0.9542997094772824], 
             UndirectedEdge[110, 154] -> 
             RGBColor[
              0.8670730299822498, 0.8945506998960768, 0.8707032533386501], 
             UndirectedEdge[119, 152] -> 
             RGBColor[
              0.2677604183233837, 0.39876355502190786`, 0.9385599317562512], 
             UndirectedEdge[38, 90] -> 
             RGBColor[
              0.41074538251891396`, 0.5301887384998543, 0.9473933104595927], 
             UndirectedEdge[66, 179] -> 
             RGBColor[
              0.9700512243327243, 0.9756140843487318, 0.8652383260610674], 
             UndirectedEdge[6, 21] -> 
             RGBColor[
              0.3445638718863475, 0.47258152580409235`, 0.9431866859501019], 
             UndirectedEdge[176, 287] -> 
             RGBColor[
              0.5599634445497977, 0.5545563829440247, 0.6024338644222329], 
             UndirectedEdge[142, 237] -> 
             RGBColor[
              0.6489015303358828, 0.7255912381548726, 0.9656775901367828], 
             UndirectedEdge[108, 221] -> 
             RGBColor[
              0.3192668900954462, 0.449648007121744, 0.9416122250035031], 
             UndirectedEdge[44, 256] -> 
             RGBColor[
              0.9801516197044022, 0.9430147833008583, 0.5214481671592728], 
             UndirectedEdge[89, 112] -> 
             RGBColor[
              0.26517294299919314`, 0.39604395440077267`, 0.9384125788643654],
              UndirectedEdge[83, 184] -> 
             RGBColor[
              0.22686279734830417`, 0.3557775623181615, 0.9362308727443287], 
             UndirectedEdge[259, 261] -> 
             RGBColor[
              0.4324511169680622, 0.5486920306968999, 0.9488584769173136], 
             UndirectedEdge[207, 231] -> 
             RGBColor[
              0.5953538117647618, 0.6805701172311853, 0.962430259270135], 
             UndirectedEdge[112, 280] -> 
             RGBColor[
              0.2601358942740522, 0.3907496968233146, 0.9381257263911142], 
             UndirectedEdge[174, 194] -> 
             RGBColor[
              0.45407833864122044`, 0.5660241331600927, 0.9506234541652072], 
             UndirectedEdge[125, 200] -> 
             RGBColor[
              0.9393105629674767, 0.7809252028803274, 0.3326287940678124], 
             UndirectedEdge[99, 222] -> 
             RGBColor[
              0.4018105363813725, 0.5224498238539401, 0.9468239899644828], 
             UndirectedEdge[108, 169] -> 
             RGBColor[
              0.3184727377256654, 0.44881330262893604`, 0.9415669992008873], 
             UndirectedEdge[15, 57] -> 
             RGBColor[
              0.2429878777602664, 0.3727260442202823, 0.9371491722188713], 
             UndirectedEdge[4, 78] -> 
             RGBColor[
              0.3598305300482983, 0.47184581112708096`, 0.9452322348805061], 
             UndirectedEdge[52, 86] -> 
             RGBColor[
              0.8962878067304835, 0.5320009026523702, 0.26072815279041595`], 
             UndirectedEdge[20, 282] -> 
             RGBColor[
              0.9147814478549319, 0.9341649508472791, 0.9667376994595409], 
             UndirectedEdge[42, 55] -> 
             RGBColor[
              0.2655663224814774, 0.39645742117835314`, 0.9384349812439285], 
             UndirectedEdge[136, 165] -> 
             RGBColor[
              0.9865840174672071, 0.9661571328498515, 0.42361874182822423`], 
             UndirectedEdge[161, 269] -> 
             RGBColor[
              0.22164816720784125`, 0.350296655413888, 0.9359339072721834], 
             UndirectedEdge[57, 243] -> 
             RGBColor[
              0.23260979600231052`, 0.3618180222842825, 0.9365581558157519], 
             UndirectedEdge[57, 146] -> 
             RGBColor[
              0.23875177461672836`, 0.3682736312319718, 0.9369079324115999], 
             UndirectedEdge[4, 130] -> 
             RGBColor[
              0.3592738699625091, 0.4712607260826286, 0.9452005339121252], 
             UndirectedEdge[31, 58] -> 
             RGBColor[
              0.583879953556761, 0.6730590756463584, 0.9603843152481828], 
             UndirectedEdge[95, 140] -> 
             RGBColor[
              0.4083602605702821, 0.527163613934152, 0.9475063767322723], 
             UndirectedEdge[58, 96] -> 
             RGBColor[
              0.47719454661287236`, 0.585147759754026, 0.9523446486820593], 
             UndirectedEdge[16, 94] -> 
             RGBColor[
              0.9277097420952534, 0.9406004694880592, 0.7586810334703302], 
             UndirectedEdge[113, 135] -> 
             RGBColor[
              0.9747525126984742, 0.9797102206225822, 0.8836982332246824], 
             UndirectedEdge[47, 262] -> 
             RGBColor[
              0.8190197652374052, 0.8556976322352333, 0.77563363654671], 
             UndirectedEdge[153, 211] -> 
             RGBColor[
              0.25792046228139853`, 0.38842113733253425`, 0.9379995608165705],
              UndirectedEdge[89, 111] -> 
             RGBColor[
              0.26057341862775985`, 0.3912095626597075, 0.9381506427557986], 
             UndirectedEdge[137, 256] -> 
             RGBColor[
              0.9204070908250823, 0.671745815737615, 0.457708580717874], 
             UndirectedEdge[136, 181] -> 
             RGBColor[
              0.8533623737727853, 0.8817985705963918, 0.7207660407906598], 
             UndirectedEdge[288, 291] -> 
             RGBColor[
              0.839904564048634, 0.3022307284450855, 0.18563064187816736`], 
             UndirectedEdge[121, 296] -> 
             RGBColor[
              0.8454228514141477, 0.8767518585640715, 0.8125406426515358], 
             UndirectedEdge[241, 277] -> 
             RGBColor[
              0.3140852328677468, 0.44372332658360614`, 0.9413346549652732], 
             UndirectedEdge[217, 262] -> 
             RGBColor[
              0.9005077184585596, 0.9193566406229818, 0.783755594175576], 
             UndirectedEdge[75, 142] -> 
             RGBColor[
              0.6947680744610263, 0.7614773672926725, 0.9702116467516284], 
             UndirectedEdge[57, 112] -> 
             RGBColor[
              0.24963320232510341`, 0.37971070167583876`, 0.9375276136219621],
              UndirectedEdge[274, 287] -> 
             RGBColor[
              0.9527752319881305, 0.8479297220628771, 0.29412403319976], 
             UndirectedEdge[97, 252] -> 
             RGBColor[
              0.2790058648824081, 0.41058323235793537`, 0.9392003433016403], 
             UndirectedEdge[18, 69] -> 
             RGBColor[
              0.9697193647682323, 0.9735318279786378, 0.7296111092370301], 
             UndirectedEdge[106, 167] -> 
             RGBColor[
              0.7052976145619072, 0.7697031240469493, 0.9712611329047376], 
             UndirectedEdge[256, 296] -> 
             RGBColor[
              0.8457417773194627, 0.8774340088271846, 0.8472537592625196], 
             UndirectedEdge[131, 183] -> 
             RGBColor[
              0.2897103519915022, 0.4203471391973532, 0.9398644012377442], 
             UndirectedEdge[172, 183] -> 
             RGBColor[
              0.2620424461666492, 0.39275360374480583`, 0.9382343017009069], 
             UndirectedEdge[1, 143] -> 
             RGBColor[
              0.4076363549020162, 0.5274958550423691, 0.9471952059690492], 
             UndirectedEdge[17, 252] -> 
             RGBColor[
              0.29837684649391727`, 0.43094336222280266`, 0.9403034920476165],
              UndirectedEdge[126, 214] -> 
             RGBColor[
              0.21941035515512047`, 0.34794457306099935`, 0.9358064671863272],
              UndirectedEdge[84, 134] -> 
             RGBColor[
              0.2873093787457973, 0.41931075190154404`, 0.9396732161322123], 
             UndirectedEdge[45, 234] -> 
             RGBColor[
              0.837571395698585, 0.28979578799570727`, 0.18361171699277434`], 
             UndirectedEdge[32, 156] -> 
             RGBColor[
              0.24197823755521267`, 0.3716648483498845, 0.9370916747028223], 
             UndirectedEdge[140, 149] -> 
             RGBColor[
              0.3110114912745308, 0.4424361680704541, 0.9410884474530516], 
             UndirectedEdge[16, 150] -> 
             RGBColor[
              0.9777383321225639, 0.9798135163001478, 0.7399324978339024], 
             UndirectedEdge[209, 218] -> 
             RGBColor[
              0.2605995221174108, 0.3912369990823875, 0.9381521293109176], 
             UndirectedEdge[82, 281] -> 
             RGBColor[
              0.9155765352150156, 0.6350911938349629, 0.44384240827575683`], 
             UndirectedEdge[178, 182] -> 
             RGBColor[
              0.29211972893207316`, 0.4243667349411374, 0.9399471584590454], 
             UndirectedEdge[41, 157] -> 
             RGBColor[
              0.35148560431038395`, 0.4788608970986815, 0.9436173297935095], 
             UndirectedEdge[254, 288] -> 
             RGBColor[
              0.8766115127845734, 0.5326035223156528, 0.21875396054991414`], 
             UndirectedEdge[129, 161] -> 
             RGBColor[
              0.22609023535273692`, 0.35496555067756064`, 0.9361868764815843],
              UndirectedEdge[20, 283] -> 
             RGBColor[
              0.7423144926570131, 0.7986300884264481, 0.9750996826489275], 
             UndirectedEdge[162, 210] -> 
             RGBColor[
              0.33154191612091594`, 0.45934744108992703`, 0.9424285250056568],
              UndirectedEdge[203, 244] -> 
             RGBColor[
              0.2510525753068279, 0.38120255267307596`, 0.9376084448134971], 
             UndirectedEdge[121, 246] -> 
             RGBColor[
              0.796739020185918, 0.8380534516751759, 0.8081437970002479], 
             UndirectedEdge[24, 259] -> 
             RGBColor[
              0.7099488174717532, 0.7711907329676471, 0.9554734955620947], 
             UndirectedEdge[141, 281] -> 
             RGBColor[
              0.8675394206203003, 0.45629003917594413`, 0.20980880344155672`],
              UndirectedEdge[110, 138] -> 
             RGBColor[
              0.8498149400101593, 0.8810685488435381, 0.8689831282162525], 
             UndirectedEdge[67, 109] -> 
             RGBColor[
              0.916743494821664, 0.9364503947042759, 0.9919210069943111], 
             UndirectedEdge[154, 245] -> 
             RGBColor[
              0.5828013526273942, 0.6698841791824666, 0.9615515465694076], 
             UndirectedEdge[193, 249] -> 
             RGBColor[
              0.609038860752824, 0.33213297985445467`, 0.5560510629020323], 
             UndirectedEdge[82, 137] -> 
             RGBColor[
              0.9203214410888617, 0.6715626196123557, 0.4483861354991565], 
             UndirectedEdge[100, 125] -> 
             RGBColor[
              0.9214027485620356, 0.686673945842382, 0.31717953132296794`], 
             UndirectedEdge[104, 218] -> 
             RGBColor[
              0.2705572837668725, 0.40170323793452584`, 0.9387192091056663], 
             UndirectedEdge[73, 149] -> 
             RGBColor[
              0.3114795465639533, 0.4428415740370091, 0.9411182715222086], 
             UndirectedEdge[108, 219] -> 
             RGBColor[
              0.30907770812291846`, 0.4389385308371674, 0.9410319661637115], 
             UndirectedEdge[58, 140] -> 
             RGBColor[
              0.4384985979215843, 0.5516312739125644, 0.9498789770489342], 
             UndirectedEdge[9, 63] -> 
             RGBColor[
              0.42067147200560917`, 0.537061727981794, 0.9485022739211517], 
             UndirectedEdge[48, 217] -> 
             RGBColor[
              0.6103593020998471, 0.6909573809034649, 0.9644909605952465], 
             UndirectedEdge[8, 271] -> 
             RGBColor[
              0.814657116181253, 0.8317974978685563, 0.6664449508576125], 
             UndirectedEdge[18, 222] -> 
             RGBColor[
              0.6912666998914337, 0.7558621322945974, 0.9623123726675136], 
             UndirectedEdge[215, 234] -> 
             RGBColor[
              0.9062111144378386, 0.5631850367729421, 0.44751685008743375`], 
             UndirectedEdge[15, 146] -> 
             RGBColor[
              0.2346866767510397, 0.3640009556330419, 0.9366764311019222], 
             UndirectedEdge[54, 151] -> 
             RGBColor[
              0.4303399784091667, 0.5471605926069658, 0.9486418607828988], 
             UndirectedEdge[195, 255] -> 
             RGBColor[
              0.8890490471039758, 0.5106791834270117, 0.23050558405009586`], 
             UndirectedEdge[1, 11] -> 
             RGBColor[
              0.3810142316306978, 0.5044371099315746, 0.9454988678152201], 
             UndirectedEdge[32, 178] -> 
             RGBColor[
              0.2666569110282901, 0.3976036988883609, 0.9384970886482884], 
             UndirectedEdge[126, 189] -> 
             RGBColor[
              0.22889351140479614`, 0.3579119715462422, 0.9363465189056738], 
             UndirectedEdge[61, 273] -> 
             RGBColor[
              0.5923372400801741, 0.6799250818424811, 0.9610501038233672], 
             UndirectedEdge[54, 194] -> 
             RGBColor[
              0.4666198015964266, 0.5768869180196359, 0.9514225850947327], 
             UndirectedEdge[38, 144] -> 
             RGBColor[
              0.36682689322971884`, 0.49214875048500833`, 0.9445948631576804],
              UndirectedEdge[4, 220] -> 
             RGBColor[
              0.3984062395141392, 0.5123913276169251, 0.9474290644669376], 
             UndirectedEdge[45, 200] -> 
             RGBColor[
              0.8719098756675858, 0.5103403405187334, 0.21479500363706636`], 
             UndirectedEdge[2, 202] -> 
             RGBColor[
              0.22943917498765481`, 0.3584854985688961, 0.9363775936394806], 
             UndirectedEdge[17, 175] -> 
             RGBColor[
              0.29536678813966943`, 0.42777960004376564`, 0.9401320736773244],
              UndirectedEdge[233, 262] -> 
             RGBColor[
              0.9940341182393746, 0.9896479070942221, 0.5920287713894679], 
             UndirectedEdge[67, 138] -> 
             RGBColor[
              0.8095011172691953, 0.8518539963630647, 0.9814491180759526], 
             UndirectedEdge[39, 192] -> 
             RGBColor[
              0.8662594246203876, 0.48559710775370324`, 0.21011592443281657`],
              UndirectedEdge[164, 168] -> 
             RGBColor[
              0.38489864849528777`, 0.5078015965832141, 0.9457463794229767], 
             UndirectedEdge[19, 253] -> 
             RGBColor[
              0.2939962623956044, 0.42633909059040226`, 0.940054024263711], 
             UndirectedEdge[24, 74] -> 
             RGBColor[
              0.7969254295463191, 0.8418022649015016, 0.9623206130704325], 
             UndirectedEdge[80, 133] -> 
             RGBColor[
              0.30898841648274356`, 0.43826898504779055`, 0.941047960136832], 
             UndirectedEdge[198, 222] -> 
             RGBColor[
              0.4501940180001994, 0.5640601889318158, 0.9499889976724383], 
             UndirectedEdge[111, 212] -> 
             RGBColor[
              0.2273675902370908, 0.3563081316499939, 0.936259619952571], 
             UndirectedEdge[126, 184] -> 
             RGBColor[
              0.23168784072436213`, 0.3608489888318178, 0.9365056518265833], 
             UndirectedEdge[132, 294] -> 
             RGBColor[
              0.2083047996307834, 0.33627193007203204`, 0.9351740222284133], 
             UndirectedEdge[39, 136] -> 
             RGBColor[
              0.9302201907265502, 0.7393086773088677, 0.34030009728209454`], 
             UndirectedEdge[133, 162] -> 
             RGBColor[
              0.31733689752319516`, 0.44704376794557543`, 0.9415233937816148],
              UndirectedEdge[22, 271] -> 
             RGBColor[
              0.8974219616748091, 0.8964540242042457, 0.6746941771749546], 
             UndirectedEdge[107, 110] -> 
             RGBColor[
              0.9135464991631714, 0.6274127712548101, 0.4734497418593211], 
             UndirectedEdge[40, 191] -> 
             RGBColor[
              0.24055073236956107`, 0.37016444989070835`, 0.9370103803943042],
              UndirectedEdge[143, 237] -> 
             RGBColor[
              0.5177646791690618, 0.6178477648970354, 0.9556038669239417], 
             UndirectedEdge[157, 261] -> 
             RGBColor[
              0.3733109108199431, 0.49776488062546065`, 0.9450080190249379], 
             UndirectedEdge[35, 163] -> 
             RGBColor[
              0.23379526623113445`, 0.36306402665793014`, 0.9366256665915373],
              UndirectedEdge[89, 175] -> 
             RGBColor[
              0.28632181999450856`, 0.4182727650390983, 0.9396169761222888], 
             UndirectedEdge[16, 200] -> 
             RGBColor[
              0.939733161025506, 0.7818290973952341, 0.3786259847113931], 
             UndirectedEdge[35, 189] -> 
             RGBColor[
              0.2290398133604396, 0.3580657441777033, 0.9363548505856133], 
             UndirectedEdge[233, 291] -> 
             RGBColor[
              0.9059982564699387, 0.5642093204609733, 0.381364914596678], 
             UndirectedEdge[258, 290] -> 
             RGBColor[
              0.7873478763723856, 0.8338243344390612, 0.9561368785302078], 
             UndirectedEdge[157, 259] -> 
             RGBColor[
              0.40512064339431064`, 0.5250197481568593, 0.947117003308583], 
             UndirectedEdge[105, 245] -> 
             RGBColor[
              0.35678647711021616`, 0.4816423424493619, 0.944021366181159], 
             UndirectedEdge[100, 192] -> 
             RGBColor[
              0.857583234347318, 0.43326449980026105`, 0.20236975515183697`], 
             UndirectedEdge[258, 278] -> 
             RGBColor[
              0.7823492729369855, 0.8297662429856849, 0.9557433701572854], 
             UndirectedEdge[99, 201] -> 
             RGBColor[
              0.34430071595550393`, 0.4726377079286733, 0.9431595150608838], 
             UndirectedEdge[9, 282] -> 
             RGBColor[
              0.740243347265956, 0.7955203413934655, 0.9507546007091144], 
             UndirectedEdge[84, 175] -> 
             RGBColor[
              0.29756458350130965`, 0.4300896223171238, 0.940257234871823], 
             UndirectedEdge[271, 291] -> 
             RGBColor[
              0.897686479772025, 0.537150265190796, 0.2658690194898667], 
             UndirectedEdge[127, 256] -> 
             RGBColor[
              0.9140100349325547, 0.622575240939881, 0.4515827527707482], 
             UndirectedEdge[80, 116] -> 
             RGBColor[
              0.2951188116057152, 0.426255830409919, 0.9401642011784779], 
             UndirectedEdge[202, 268] -> 
             RGBColor[
              0.2453187041670522, 0.37517589055674394`, 0.937281909334589], 
             UndirectedEdge[161, 265] -> 
             RGBColor[
              0.21936843133233605`, 0.34790050846512904`, 0.9358040796866404],
              UndirectedEdge[22, 72] -> 
             RGBColor[
              0.7345932590636062, 0.7925891041868212, 0.9741810489653038], 
             UndirectedEdge[77, 162] -> 
             RGBColor[
              0.26527957680517633`, 0.3961560332918348, 0.9384186515018654], 
             UndirectedEdge[93, 164] -> 
             RGBColor[
              0.45756686024315646`, 0.5686282136761757, 0.9509610966011381], 
             UndirectedEdge[19, 111] -> 
             RGBColor[
              0.2671407671011217, 0.39811226229915386`, 0.9385246435358352], 
             UndirectedEdge[37, 142] -> 
             RGBColor[
              0.669863260251737, 0.742021537148777, 0.9677293676199676], 
             UndirectedEdge[43, 172] -> 
             RGBColor[
              0.2958345713391305, 0.4270297833847875, 0.9402041701394114], 
             UndirectedEdge[61, 285] -> 
             RGBColor[
              0.474805368949063, 0.5825919070766665, 0.9523268246944521], 
             UndirectedEdge[38, 257] -> 
             RGBColor[
              0.4046248085689348, 0.5248874049733736, 0.9470033128997111], 
             UndirectedEdge[174, 185] -> 
             RGBColor[
              0.4801968939468863, 0.58722835298474, 0.9526796025142897], 
             UndirectedEdge[75, 237] -> 
             RGBColor[
              0.6846458552140906, 0.7535149764166593, 0.969240250390935], 
             UndirectedEdge[30, 48] -> 
             RGBColor[
              0.43794065467516774`, 0.5535027925607373, 0.9491927923797858], 
             UndirectedEdge[289, 298] -> 
             RGBColor[
              0.28811767425307283`, 0.4201603217285858, 0.9397192473655857], 
             UndirectedEdge[123, 261] -> 
             RGBColor[
              0.41843101459212195`, 0.5368456467105671, 0.9478830321391599], 
             UndirectedEdge[77, 206] -> 
             RGBColor[
              0.2413530899135048, 0.3710077785417997, 0.9370560734694501], 
             UndirectedEdge[121, 137] -> 
             RGBColor[
              0.9200881649197675, 0.6710636654745018, 0.4229954641068904], 
             UndirectedEdge[87, 227] -> 
             RGBColor[
              0.2679362427515092, 0.39894835764378045`, 0.938569944697324], 
             UndirectedEdge[123, 144] -> 
             RGBColor[
              0.3759650676291757, 0.5000637778518178, 0.9451771395498434], 
             UndirectedEdge[9, 37] -> 
             RGBColor[
              0.5987662128442524, 0.684557033887325, 0.9619578094283205], 
             UndirectedEdge[178, 268] -> 
             RGBColor[
              0.26978635473276824`, 0.4008929426399584, 0.9386753058376613], 
             UndirectedEdge[112, 253] -> 
             RGBColor[
              0.2744693999473012, 0.40581512008264853`, 0.9389419983346845], 
             UndirectedEdge[78, 220] -> 
             RGBColor[
              0.21861602963741927`, 0.34710968657874874`, 0.9357612315231933],
              UndirectedEdge[66, 67] -> 
             RGBColor[
              0.9293871027463778, 0.9462546742934231, 0.9835096743331035], 
             UndirectedEdge[20, 124] -> 
             RGBColor[
              0.9067998303302157, 0.928212273566045, 0.9802484959896351], 
             UndirectedEdge[18, 224] -> 
             RGBColor[
              0.9579627169351427, 0.9342040847269458, 0.6558617372883351], 
             UndirectedEdge[72, 151] -> 
             RGBColor[
              0.5475405416357872, 0.6431396338261914, 0.9576978591404627], 
             UndirectedEdge[25, 29] -> 
             RGBColor[
              0.24731665325336327`, 0.3772758617237455, 0.9373956895793536], 
             UndirectedEdge[135, 258] -> 
             RGBColor[
              0.9759313858945792, 0.9805894223220096, 0.8817027084030489], 
             UndirectedEdge[130, 176] -> 
             RGBColor[
              0.17893943915932659`, 0.3054070743451405, 0.9335017083917216], 
             UndirectedEdge[31, 245] -> 
             RGBColor[
              0.5216196733437626, 0.6217282550704486, 0.9556998890025264], 
             UndirectedEdge[295, 297] -> 
             RGBColor[
              0.7988419039700752, 0.8429204696534232, 0.9805476453412715], 
             UndirectedEdge[17, 30] -> 
             RGBColor[
              0.37921039896007874`, 0.5014757039177918, 0.9454929485539587], 
             UndirectedEdge[22, 273] -> 
             RGBColor[
              0.717607033402136, 0.7789436605631201, 0.9727448718111256], 
             UndirectedEdge[86, 165] -> 
             RGBColor[
              0.9775639799613888, 0.9359801775610526, 0.3673407281472113], 
             UndirectedEdge[124, 200] -> 
             RGBColor[
              0.916844882326316, 0.7678634053812667, 0.6000047488264095], 
             UndirectedEdge[198, 258] -> 
             RGBColor[
              0.7130111957358749, 0.7734744682690422, 0.9502848227262681], 
             UndirectedEdge[177, 217] -> 
             RGBColor[
              0.6131216671850642, 0.6933500026997739, 0.964666976055813], 
             UndirectedEdge[52, 110] -> 
             RGBColor[
              0.9053269977052454, 0.5642340812406845, 0.4655787379806119], 
             UndirectedEdge[121, 299] -> 
             RGBColor[
              0.9945473356554072, 0.9914335784226265, 0.6978961075730188], 
             UndirectedEdge[173, 196] -> 
             RGBColor[
              0.2690530219671379, 0.40012216340729806`, 0.9386335436215274], 
             UndirectedEdge[238, 251] -> 
             RGBColor[
              0.2826141781107905, 0.4143757983412377, 0.9394058314019756], 
             UndirectedEdge[218, 284] -> 
             RGBColor[
              0.25584347148447395`, 0.38623808831614403`, 0.9378812792633183],
              UndirectedEdge[209, 276] -> 
             RGBColor[
              0.24846893317691396`, 0.37848698098216405`, 0.9374613102163545],
              UndirectedEdge[8, 72] -> 
             RGBColor[
              0.6518284135700501, 0.7279325778511317, 0.9659318226479615], 
             UndirectedEdge[56, 168] -> 
             RGBColor[
              0.46678271330407606`, 0.5761629717082618, 0.9516719821972282], 
             UndirectedEdge[201, 257] -> 
             RGBColor[
              0.35620917982441114`, 0.48295222079512334`, 0.9439183118483695],
              UndirectedEdge[31, 51] -> 
             RGBColor[
              0.8061994237416004, 0.8465221719044482, 0.8597460281820752], 
             UndirectedEdge[53, 282] -> 
             RGBColor[
              0.89769307964249, 0.6086527767356787, 0.5622102390155896], 
             UndirectedEdge[17, 97] -> 
             RGBColor[
              0.27685141165294697`, 0.4083187654135474, 0.9390776503774505], 
             UndirectedEdge[102, 162] -> 
             RGBColor[
              0.3349247683998675, 0.4622774977068556, 0.9426440773615328], 
             UndirectedEdge[36, 260] -> 
             RGBColor[
              0.8043625245684116, 0.8473291531354724, 0.9810724316171817], 
             UndirectedEdge[79, 168] -> 
             RGBColor[
              0.3904018999447999, 0.5125682363873212, 0.9460970417390054], 
             UndirectedEdge[142, 297] -> 
             RGBColor[
              0.7097113891411961, 0.773151198294219, 0.9717010567057325], 
             UndirectedEdge[232, 299] -> 
             RGBColor[
              0.994290544063115, 0.9908843271723261, 0.6699459274860231], 
             UndirectedEdge[50, 169] -> 
             RGBColor[
              0.3227370521664461, 0.4525068374668645, 0.9418387175462686], 
             UndirectedEdge[92, 153] -> 
             RGBColor[
              0.26728945052082176`, 0.3982685380003319, 0.9385331108366297], 
             UndirectedEdge[44, 299] -> 
             RGBColor[
              0.979769906119425, 0.942886287709507, 0.5299077867568601], 
             UndirectedEdge[90, 252] -> 
             RGBColor[
              0.35203888438478537`, 0.4785806153224426, 0.9436803935153333], 
             UndirectedEdge[7, 283] -> 
             RGBColor[
              0.5067349402558111, 0.6088389317771312, 0.9547505947490993], 
             UndirectedEdge[52, 179] -> 
             RGBColor[
              0.9056772965506277, 0.5643789388155198, 0.459773379568276], 
             UndirectedEdge[98, 296] -> 
             RGBColor[
              0.559521387516622, 0.6516299340358314, 0.9592598962290395], 
             UndirectedEdge[18, 88] -> 
             RGBColor[
              0.7253109400374347, 0.7839674018676228, 0.9648635309809819], 
             UndirectedEdge[100, 240] -> 
             RGBColor[
              0.9225569449368545, 0.6891426551809652, 0.4428066838476417], 
             UndirectedEdge[2, 214] -> 
             RGBColor[
              0.2218197182328839, 0.35047696641817105`, 0.9359436768492726], 
             UndirectedEdge[114, 169] -> 
             RGBColor[
              0.2987181224804576, 0.4313020649228039, 0.9403229272101774], 
             UndirectedEdge[37, 295] -> 
             RGBColor[
              0.7589937750806162, 0.8117908085079812, 0.9765759562555065], 
             UndirectedEdge[45, 225] -> 
             RGBColor[
              0.9093933228339569, 0.6627226292341221, 0.2529269618420678], 
             UndirectedEdge[38, 74] -> 
             RGBColor[
              0.5280791848415985, 0.6267970188090106, 0.9562568575389798], 
             UndirectedEdge[38, 158] -> 
             RGBColor[
              0.41078817614673724`, 0.5302258041894045, 0.9473960372317167], 
             UndirectedEdge[69, 135] -> 
             RGBColor[
              0.9915668730357023, 0.9888448386688236, 0.6487056199187353], 
             UndirectedEdge[113, 224] -> 
             RGBColor[
              0.9644670009376046, 0.9390549690861945, 0.644851681061125], 
             UndirectedEdge[124, 282] -> 
             RGBColor[
              0.9556754222393467, 0.9664633829977154, 0.9599141278341408], 
             UndirectedEdge[56, 79] -> 
             RGBColor[
              0.47131158576889715`, 0.5800856534095411, 0.9519605579459619], 
             UndirectedEdge[49, 146] -> 
             RGBColor[
              0.23350254559126715`, 0.3627563587058691, 0.9366089965841382], 
             UndirectedEdge[47, 166] -> 
             RGBColor[
              0.8183915236203407, 0.8543538869413033, 0.7072534135870767], 
             UndirectedEdge[189, 197] -> 
             RGBColor[
              0.22117434471858483`, 0.3497986379355985, 0.9359069237823778], 
             UndirectedEdge[125, 256] -> 
             RGBColor[
              0.9939365705713255, 0.9894392624958468, 0.5814113097167279], 
             UndirectedEdge[69, 138] -> 
             RGBColor[
              0.8498609562052564, 0.8791517168657417, 0.7275038724573385], 
             UndirectedEdge[170, 255] -> 
             RGBColor[
              0.8904238882805281, 0.5212468151692371, 0.2318221335134233], 
             UndirectedEdge[41, 104] -> 
             RGBColor[
              0.3210313076505878, 0.45029407852530423`, 0.9417569530026035], 
             UndirectedEdge[185, 283] -> 
             RGBColor[
              0.5933967145885973, 0.6807852109772019, 0.9611335095376532], 
             UndirectedEdge[103, 277] -> 
             RGBColor[
              0.3139559658390563, 0.44358745874044936`, 0.9413272933992227], 
             UndirectedEdge[45, 282] -> 
             RGBColor[
              0.9107404155806164, 0.7089403181351821, 0.5747043826447977], 
             UndirectedEdge[222, 245] -> 
             RGBColor[
              0.43026765068117134`, 0.5470979459642735, 0.9486372521240278], 
             UndirectedEdge[53, 195] -> 
             RGBColor[
              0.825436438508141, 0.1965211894578074, 0.17199126828273137`], 
             UndirectedEdge[121, 136] -> 
             RGBColor[
              0.9937588965574554, 0.9890592357457773, 0.5620725897838914], 
             UndirectedEdge[92, 211] -> 
             RGBColor[
              0.2517282610763278, 0.3819127412577725, 0.9376469241184826], 
             UndirectedEdge[26, 137] -> 
             RGBColor[
              0.9157005980775512, 0.6698289128207927, 0.5378409832086813], 
             UndirectedEdge[139, 148] -> 
             RGBColor[
              0.24714609636833407`, 0.37709659562364867`, 0.9373859766170676],
              UndirectedEdge[69, 258] -> 
             RGBColor[
              0.9774025219667993, 0.9792619140373138, 0.7166055281881865], 
             UndirectedEdge[244, 272] -> 
             RGBColor[
              0.23289575947638014`, 0.3621185880266611, 0.936574441012555], 
             UndirectedEdge[100, 256] -> 
             RGBColor[
              0.9227141531364094, 0.6894789076236262, 0.45991782619265503`], 
             UndirectedEdge[29, 206] -> 
             RGBColor[
              0.23974836289368467`, 0.3693211086983992, 0.9369646866396522], 
             UndirectedEdge[101, 213] -> 
             RGBColor[
              0.48723449014775655`, 0.5939071986311, 0.9529668827570787], 
             UndirectedEdge[39, 107] -> 
             RGBColor[
              0.8508398666409367, 0.3774266775234726, 0.1957554594288977], 
             UndirectedEdge[134, 252] -> 
             RGBColor[
              0.28726603661361816`, 0.4192651965725739, 0.9396707478619037], 
             UndirectedEdge[14, 288] -> 
             RGBColor[
              0.8422994070509533, 0.32063854118780577`, 0.1879239462417765], 
             UndirectedEdge[155, 202] -> 
             RGBColor[
              0.22021191752572378`, 0.34878706593449305`, 0.9358521149775277],
              UndirectedEdge[220, 228] -> 
             RGBColor[
              0.5367674910110247, 0.6220540079829862, 0.9601435922342896], 
             UndirectedEdge[228, 266] -> 
             RGBColor[
              0.5319885984693589, 0.6170310889224077, 0.9598714413737797], 
             UndirectedEdge[113, 249] -> 
             RGBColor[
              0.8889946281823045, 0.5565337231850392, 0.5595095853153444], 
             UndirectedEdge[109, 179] -> 
             RGBColor[
              0.9574076164080104, 0.9658098047595847, 0.8736496587222751], 
             UndirectedEdge[41, 209] -> 
             RGBColor[
              0.3110735460011261, 0.43982783967316585`, 0.9411898732078549], 
             UndirectedEdge[76, 261] -> 
             RGBColor[
              0.3474685023612617, 0.4740454489620557, 0.9434102824444082], 
             UndirectedEdge[114, 219] -> 
             RGBColor[
              0.28932309287771063`, 0.4214272931310352, 0.9397878941730018], 
             UndirectedEdge[130, 266] -> 
             RGBColor[
              0.21328047700996416`, 0.3415016824737179, 0.9354573796943026], 
             UndirectedEdge[1, 185] -> 
             RGBColor[
              0.4932964811819127, 0.5985745570433215, 0.9535142966293955], 
             UndirectedEdge[202, 208] -> 
             RGBColor[
              0.2570404037299817, 0.3874961399960602, 0.9379494427839974], 
             UndirectedEdge[8, 285] -> 
             RGBColor[
              0.5173103167774687, 0.616953959461616, 0.9557723663648683], 
             UndirectedEdge[65, 210] -> 
             RGBColor[
              0.33323684341077736`, 0.46112891713616844`, 0.9425250486073942],
              UndirectedEdge[63, 183] -> 
             RGBColor[
              0.28955139027076127`, 0.4202094545444958, 0.939854272337463], 
             UndirectedEdge[51, 86] -> 
             RGBColor[
              0.9842148587859489, 0.9592452118717956, 0.5566107984418112], 
             UndirectedEdge[91, 191] -> 
             RGBColor[
              0.2582507185162887, 0.38876825757485856`, 0.9380183684205773], 
             UndirectedEdge[122, 181] -> 
             RGBColor[
              0.6690049122710009, 0.741072705352345, 0.9678340796895172], 
             UndirectedEdge[17, 42] -> 
             RGBColor[
              0.2753301177357401, 0.4067197890509576, 0.9389910149394182], 
             UndirectedEdge[90, 253] -> 
             RGBColor[
              0.3501359199582715, 0.4765804790552632, 0.9435720225064269], 
             UndirectedEdge[60, 136] -> 
             RGBColor[
              0.9594950595498875, 0.8659435606987382, 0.3644021078697419], 
             UndirectedEdge[80, 210] -> 
             RGBColor[
              0.3231934350804644, 0.45057265819214215`, 0.941953091360874], 
             UndirectedEdge[229, 259] -> 
             RGBColor[
              0.40532480006275245`, 0.5251965784018511, 0.9471300119909675], 
             UndirectedEdge[97, 159] -> 
             RGBColor[
              0.2524370830607903, 0.3826577581053522, 0.9376872904818896], 
             UndirectedEdge[242, 280] -> 
             RGBColor[
              0.25424538211649345`, 0.38455839506567835`, 0.9377902704379731],
              UndirectedEdge[88, 99] -> 
             RGBColor[
              0.43585477652737337`, 0.5505550934269655, 0.9493751482779511], 
             UndirectedEdge[21, 46] -> 
             RGBColor[
              0.3377964064979223, 0.4654684905987692, 0.942801288807799], 
             UndirectedEdge[246, 256] -> 
             RGBColor[
              0.7970579460912328, 0.838735601938289, 0.8428569136112316], 
             UndirectedEdge[14, 135] -> 
             RGBColor[
              0.9063967184206538, 0.582821195587901, 0.4915857246054881], 
             UndirectedEdge[67, 179] -> 
             RGBColor[
              0.9529824528221467, 0.9622812994340826, 0.8732275826690652], 
             UndirectedEdge[66, 69] -> 
             RGBColor[
              0.9697469416824389, 0.9735523947961, 0.7295644287144893], 
             UndirectedEdge[94, 237] -> 
             RGBColor[
              0.7503642165832218, 0.805193848255281, 0.9757004322912739], 
             UndirectedEdge[116, 133] -> 
             RGBColor[
              0.3362774461822365, 0.4656883549123332, 0.9426482794056301], 
             UndirectedEdge[2, 83] -> 
             RGBColor[
              0.2235228930753953, 0.35226711116517256`, 0.9360406701369322], 
             UndirectedEdge[103, 168] -> 
             RGBColor[
              0.3323449528082868, 0.45951507499583777`, 0.9424990233881594], 
             UndirectedEdge[26, 199] -> 
             RGBColor[
              0.5823809948253185, 0.6469022092217233, 0.9089577047840149], 
             UndirectedEdge[91, 239] -> 
             RGBColor[
              0.3418733579527955, 0.46719445818593675`, 0.9431271687979139], 
             UndirectedEdge[13, 298] -> 
             RGBColor[
              0.2956902341413986, 0.428119562299244, 0.9401504934486273], 
             UndirectedEdge[229, 261] -> 
             RGBColor[
              0.3735150674883849, 0.49794171087045247`, 0.9450210277073223], 
             UndirectedEdge[141, 179] -> 
             RGBColor[
              0.9463245104461602, 0.8129581160989631, 0.4961968694388046], 
             UndirectedEdge[59, 195] -> 
             RGBColor[
              0.825976956508043, 0.20067584766155147`, 0.17250886892986522`], 
             UndirectedEdge[134, 253] -> 
             RGBColor[
              0.2853630721871043, 0.41726506030539445`, 0.9395623768529974], 
             UndirectedEdge[42, 292] -> 
             RGBColor[
              0.24874967528223313`, 0.3787820587349321, 0.9374772980639317], 
             UndirectedEdge[70, 238] -> 
             RGBColor[
              0.27137415800540265`, 0.40256182455203926`, 0.9387657288850935],
              UndirectedEdge[178, 202] -> 
             RGBColor[
              0.25258870101180897`, 0.3828171181850061, 0.9376959248999015], 
             UndirectedEdge[29, 191] -> 
             RGBColor[
              0.24335597488348387`, 0.37311293763548947`, 0.9371701348054876],
              UndirectedEdge[17, 38] -> 
             RGBColor[
              0.3570833446280458, 0.48255148540021425`, 0.944016408991876], 
             UndirectedEdge[40, 162] -> 
             RGBColor[
              0.2608696072714334, 0.3915208757036531, 0.9381675102608841], 
             UndirectedEdge[13, 95] -> 
             RGBColor[
              0.3973874477451902, 0.5174174988379855, 0.946816060198244], 
             UndirectedEdge[206, 270] -> 
             RGBColor[
              0.23246458235718154`, 0.361665393536175, 0.936549886113486], 
             UndirectedEdge[16, 295] -> 
             RGBColor[
              0.9153775706767935, 0.9307671307468549, 0.7575047799513781], 
             UndirectedEdge[37, 124] -> 
             RGBColor[
              0.8141982878176429, 0.8555000754915749, 0.971117336553347], 
             UndirectedEdge[22, 177] -> 
             RGBColor[
              0.6182933062719121, 0.6973901264603323, 0.9651824367082749], 
             UndirectedEdge[115, 204] -> 
             RGBColor[
              0.22623702836427392`, 0.35511983943990055`, 0.9361952361264305],
              UndirectedEdge[192, 200] -> 
             RGBColor[
              0.875491048752759, 0.5275157568382065, 0.21781901789668148`], 
             UndirectedEdge[13, 171] -> 
             RGBColor[
              0.3622408475068787, 0.48793453204456394`, 0.9443115057758112], 
             UndirectedEdge[39, 52] -> 
             RGBColor[
              0.8426203651830106, 0.3142479875093471, 0.1878844555501885], 
             UndirectedEdge[92, 216] -> 
             RGBColor[
              0.25996759819388404`, 0.3905728069724701, 0.9381161421783205], 
             UndirectedEdge[82, 127] -> 
             RGBColor[
              0.9139243851963341, 0.6223920448146217, 0.4422603075520308], 
             UndirectedEdge[53, 150] -> 
             RGBColor[
              0.8968677108265174, 0.6080372180241437, 0.5636073731303677], 
             UndirectedEdge[18, 66] -> 
             RGBColor[
              0.9464282973427488, 0.95956689239061, 0.9755670982476465], 
             UndirectedEdge[31, 36] -> 
             RGBColor[
              0.6892039970441424, 0.7567703364683878, 0.9699034319627848], 
             UndirectedEdge[71, 181] -> 
             RGBColor[
              0.6717068148993812, 0.7432662316253906, 0.9680467833618187], 
             UndirectedEdge[43, 143] -> 
             RGBColor[
              0.3594618944461463, 0.48576955871427996`, 0.9441255719478039], 
             UndirectedEdge[75, 185] -> 
             RGBColor[
              0.6492913495741017, 0.7248125960357876, 0.9664570141991338], 
             UndirectedEdge[46, 145] -> 
             RGBColor[
              0.280670988716232, 0.4123333830822331, 0.9392951696406466], 
             UndirectedEdge[62, 255] -> 
             RGBColor[
              0.9769015351320889, 0.9322978840038133, 0.4878701995815442], 
             UndirectedEdge[111, 242] -> 
             RGBColor[
              0.24172339249525976`, 0.3713969900337639, 0.9370771616536675], 
             UndirectedEdge[4, 193] -> 
             RGBColor[
              0.46955924674976174`, 0.5787870298978665, 0.9517883446566966], 
             UndirectedEdge[18, 258] -> 
             RGBColor[
              0.9540838776271092, 0.9652764116318238, 0.9626081977213435], 
             UndirectedEdge[81, 267] -> 
             RGBColor[
              0.3818442604921369, 0.5035684061042389, 0.9457044452357559], 
             UndirectedEdge[75, 124] -> 
             RGBColor[
              0.8391031020269322, 0.8749559056354701, 0.9735996156850079], 
             UndirectedEdge[72, 106] -> 
             RGBColor[
              0.6542381545327312, 0.7298150858058879, 0.966172003106812], 
             UndirectedEdge[262, 271] -> 
             RGBColor[
              0.9857223415414609, 0.9625888518240449, 0.4765328762826566], 
             UndirectedEdge[17, 235] -> 
             RGBColor[
              0.2691307812557516, 0.40020389334985473`, 0.9386379718979794], 
             UndirectedEdge[263, 279] -> 
             RGBColor[
              0.25988809011317837`, 0.3904892389385449, 0.938111614310746], 
             UndirectedEdge[3, 252] -> 
             RGBColor[
              0.33892810141516894`, 0.46722471408127325`, 0.9428449860179196],
              UndirectedEdge[48, 158] -> 
             RGBColor[
              0.4086574804982366, 0.5283803027105503, 0.9472602711890945], 
             UndirectedEdge[18, 36] -> 
             RGBColor[
              0.8529859949186596, 0.8858242206407632, 0.9761422011869598], 
             UndirectedEdge[105, 196] -> 
             RGBColor[
              0.28505137622914434`, 0.4169374480909134, 0.9395446262293043], 
             UndirectedEdge[269, 298] -> 
             RGBColor[
              0.2561386884802381, 0.3865483800965307, 0.9378980914344927], 
             UndirectedEdge[85, 207] -> 
             RGBColor[
              0.8326069689699811, 0.8699635257728993, 0.9837364200787462], 
             UndirectedEdge[79, 103] -> 
             RGBColor[
              0.33687382527310783`, 0.4634377566971172, 0.9427875991368931], 
             UndirectedEdge[76, 128] -> 
             RGBColor[
              0.2667781164198233, 0.397731093439728, 0.9385039911160289], 
             UndirectedEdge[10, 265] -> 
             RGBColor[
              0.21694931138635237`, 0.3453578600208368, 0.9356663143844839], 
             UndirectedEdge[88, 198] -> 
             RGBColor[
              0.48423825814620036`, 0.592165458504841, 0.9525401559859066], 
             UndirectedEdge[63, 143] -> 
             RGBColor[
              0.36063166824627285`, 0.4867827579854089, 0.9442001088999576], 
             UndirectedEdge[49, 242] -> 
             RGBColor[
              0.23849346114208345`, 0.3680021273920998, 0.9368932218413593], 
             UndirectedEdge[252, 253] -> 
             RGBColor[
              0.29862833529686444`, 0.43120769290001126`, 0.9403178139629], 
             UndirectedEdge[16, 125] -> 
             RGBColor[
              0.9930477640549809, 0.9875381952295093, 0.4846702054906215], 
             UndirectedEdge[59, 100] -> 
             RGBColor[
              0.8414952433239204, 0.3199562002850287, 0.1873691979101476], 
             UndirectedEdge[75, 295] -> 
             RGBColor[
              0.7838985892899054, 0.8312466386518764, 0.9790582353871675], 
             UndirectedEdge[94, 295] -> 
             RGBColor[
              0.8496169506590368, 0.8829255104904983, 0.9855184172875062], 
             UndirectedEdge[26, 192] -> 
             RGBColor[
              0.9254105636090766, 0.7341129135369036, 0.5467339360364043], 
             UndirectedEdge[132, 188] -> 
             RGBColor[
              0.20621351468350757`, 0.3340738569973212, 0.9350549266444448], 
             UndirectedEdge[186, 196] -> 
             RGBColor[
              0.255450766680841, 0.38582533066860314`, 0.9378589153057062], 
             UndirectedEdge[110, 179] -> 
             RGBColor[
              0.9932962755631108, 0.991495851914556, 0.7607615928093651], 
             UndirectedEdge[61, 177] -> 
             RGBColor[
              0.49302351294995017`, 0.5983715477396933, 0.9534876687205165], 
             UndirectedEdge[21, 264] -> 
             RGBColor[
              0.339057995027486, 0.46679450013267343`, 0.9428731344082046], 
             UndirectedEdge[200, 225] -> 
             RGBColor[
              0.9234794071043728, 0.7275983937614409, 0.2647165314935854], 
             UndirectedEdge[83, 197] -> 
             RGBColor[
              0.21339436331142053`, 0.34162138419735716`, 0.9354638653506908],
              UndirectedEdge[220, 226] -> 
             RGBColor[
              0.21805937466237113`, 0.3465246069060093, 0.9357295308458616], 
             UndirectedEdge[13, 140] -> 
             RGBColor[
              0.3171012005840623, 0.44883683866464263`, 0.941435247389312], 
             UndirectedEdge[144, 158] -> 
             RGBColor[
              0.35967077338482056`, 0.4859504791523989, 0.9441388815290719], 
             UndirectedEdge[62, 225] -> 
             RGBColor[
              0.9779057939111673, 0.9356854846768198, 0.49177155529990685`], 
             UndirectedEdge[65, 277] -> 
             RGBColor[
              0.318505826054183, 0.44836965030434695`, 0.9415864012075592], 
             UndirectedEdge[99, 261] -> 
             RGBColor[
              0.38406488890105717`, 0.5070794359286672, 0.9456932529988971], 
             UndirectedEdge[260, 290] -> 
             RGBColor[
              0.7310412488235707, 0.7895991808750945, 0.9740726900092733], 
             UndirectedEdge[72, 267] -> 
             RGBColor[
              0.5598273932891142, 0.6533873840765647, 0.9585897688439947], 
             UndirectedEdge[39, 170] -> 
             RGBColor[
              0.8447130757608642, 0.3303334780423518, 0.18988843756291957`], 
             UndirectedEdge[92, 163] -> 
             RGBColor[
              0.25122830224652154`, 0.3813872528284255, 0.937618452202748], 
             UndirectedEdge[102, 133] -> 
             RGBColor[
              0.36773492193593726`, 0.4929352393114849, 0.9446527219439024], 
             UndirectedEdge[184, 197] -> 
             RGBColor[
              0.22396867403815082`, 0.3527356552211741, 0.9360660567032872], 
             UndirectedEdge[44, 200] -> 
             RGBColor[
              0.9255256121005535, 0.7345007236853389, 0.2726656515103572], 
             UndirectedEdge[115, 132] -> 
             RGBColor[
              0.21415169536183348`, 0.34241738819996653`, 0.9355069942905895],
              UndirectedEdge[9, 283] -> 
             RGBColor[
              0.5677763920680372, 0.6599854789726345, 0.959116583898501], 
             UndirectedEdge[52, 165] -> 
             RGBColor[
              0.8989841919236675, 0.5410964430503309, 0.2712031000963182], 
             UndirectedEdge[160, 256] -> 
             RGBColor[
              0.7927339846129686, 0.8352252152179895, 0.8425165155244698], 
             UndirectedEdge[45, 215] -> 
             RGBColor[
              0.9264635101364236, 0.7188538247686493, 0.4669105670802081], 
             UndirectedEdge[16, 124] -> 
             RGBColor[
              0.9705820834138202, 0.9744763977304486, 0.7520461602492186], 
             UndirectedEdge[160, 246] -> 
             RGBColor[
              0.5945439555585024, 0.6817165928791875, 0.9612238245492863], 
             UndirectedEdge[57, 204] -> 
             RGBColor[
              0.23896784394150833`, 0.36850073379190207`, 0.9369202372400001],
              UndirectedEdge[112, 252] -> 
             RGBColor[
              0.27637236437381507`, 0.40781525634982796`, 0.9390503693435908],
              UndirectedEdge[5, 248] -> 
             RGBColor[
              0.21465495916745328`, 0.3429463503684412, 0.9355356544198075], 
             UndirectedEdge[186, 276] -> 
             RGBColor[
              0.2308753294209801, 0.3599949879357713, 0.9364593805098584], 
             UndirectedEdge[95, 154] -> 
             RGBColor[
              0.6149232954890904, 0.696747339779964, 0.9638633724984019], 
             UndirectedEdge[198, 290] -> 
             RGBColor[
              0.5385920372825843, 0.6362923050176035, 0.9568190845839761], 
             UndirectedEdge[77, 191] -> 
             RGBColor[
              0.24496070190330402`, 0.37479960747889, 0.9372615216352855], 
             UndirectedEdge[36, 224] -> 
             RGBColor[
              0.8645479914252601, 0.8604819797945611, 0.6563901597051076], 
             UndirectedEdge[29, 203] -> 
             RGBColor[
              0.25120844967144335`, 0.38136638651329235`, 0.9376173216279664],
              UndirectedEdge[25, 172] -> 
             RGBColor[
              0.2606528759791422, 0.3912930773738975, 0.9381551677344133], 
             UndirectedEdge[224, 260] -> 
             RGBColor[
              0.9093392465848947, 0.8957090172216551, 0.6607919677185569], 
             UndirectedEdge[45, 255] -> 
             RGBColor[
              0.9083890640548784, 0.6593350285611156, 0.24902560612370514`], 
             UndirectedEdge[102, 239] -> 
             RGBColor[
              0.398228532934502, 0.519347272504989, 0.9465957478722895], 
             UndirectedEdge[33, 239] -> 
             RGBColor[
              0.6628984653958889, 0.7326583838158534, 0.9695703125580974], 
             UndirectedEdge[64, 92] -> 
             RGBColor[
              0.24737632360791623`, 0.3773385790496996, 0.9373990877177711], 
             UndirectedEdge[32, 268] -> 
             RGBColor[
              0.2593869141835333, 0.38996247126009875`, 0.938083073082976], 
             UndirectedEdge[85, 240] -> 
             RGBColor[
              0.9572796113633043, 0.9651601387742601, 0.8410616153789832], 
             UndirectedEdge[1, 174] -> 
             RGBColor[
              0.4054230753198295, 0.5255788235109453, 0.9470541777511985], 
             UndirectedEdge[2, 184] -> 
             RGBColor[
              0.23409720380212556`, 0.3633813821889895, 0.9366428614895286], 
             UndirectedEdge[60, 85] -> 
             RGBColor[
              0.9228540566499766, 0.8416985659067688, 0.6257891591988634], 
             UndirectedEdge[121, 127] -> 
             RGBColor[
              0.9136911090272399, 0.6218930906767679, 0.41686963615976463`], 
             UndirectedEdge[132, 212] -> 
             RGBColor[
              0.20921642322248857`, 0.3372301042671883, 0.9352259378433346], 
             UndirectedEdge[172, 206] -> 
             RGBColor[
              0.2530845856194636, 0.3833383243485512, 0.9377241647947119], 
             UndirectedEdge[147, 148] -> 
             RGBColor[
              0.2325030525609364, 0.36170582815947316`, 0.9365520769346783], 
             UndirectedEdge[118, 226] -> 
             RGBColor[
              0.17892828959271728`, 0.30539535544371077`, 0.9335010734403975],
              UndirectedEdge[75, 283] -> 
             RGBColor[
              0.6746177643537297, 0.7453737204958732, 0.9684508023443001], 
             UndirectedEdge[188, 243] -> 
             RGBColor[
              0.21194079974675017`, 0.3400935967296356, 0.9353810870560375], 
             UndirectedEdge[88, 258] -> 
             RGBColor[
              0.7329940972360016, 0.7896974879262988, 0.9518579499321382], 
             UndirectedEdge[197, 293] -> 
             RGBColor[
              0.20988077542261582`, 0.33792838055188446`, 0.9352637717183109],
              UndirectedEdge[86, 179] -> 
             RGBColor[
              0.9842570845883489, 0.9592626733262417, 0.5559110076191691], 
             UndirectedEdge[41, 76] -> 
             RGBColor[
              0.32564319585170254`, 0.45514146543527656`, 0.9420195932129798],
              UndirectedEdge[175, 242] -> 
             RGBColor[
              0.2674717938620085, 0.3984601924131547, 0.9385434950201575], 
             UndirectedEdge[89, 285] -> 
             RGBColor[
              0.3304519019187142, 0.457812130049975, 0.9423807168287202], 
             UndirectedEdge[138, 171] -> 
             RGBColor[
              0.5625186052786886, 0.6537822219340037, 0.9596386929535714], 
             UndirectedEdge[181, 207] -> 
             RGBColor[
              0.729702675862836, 0.7887685434205706, 0.9736936013369495], 
             UndirectedEdge[17, 55] -> 
             RGBColor[
              0.28645859801019335`, 0.41841652740581015`, 0.939624765427937], 
             UndirectedEdge[142, 295] -> 
             RGBColor[
              0.7481542644116976, 0.8033229003900898, 0.9754955751330152], 
             UndirectedEdge[53, 200] -> 
             RGBColor[
              0.8588625397294595, 0.4100527991192301, 0.2023008600078583], 
             UndirectedEdge[33, 237] -> 
             RGBColor[
              0.7767209844121652, 0.8262100194866766, 0.9782143643357628], 
             UndirectedEdge[51, 67] -> 
             RGBColor[
              0.9529402270197467, 0.9622638379796367, 0.8739273734917072], 
             UndirectedEdge[47, 48] -> 
             RGBColor[
              0.5288713488786927, 0.6272983725157164, 0.9563690029663805], 
             UndirectedEdge[102, 237] -> 
             RGBColor[
              0.5120510519507784, 0.6128989081758123, 0.9552397996499549], 
             UndirectedEdge[150, 282] -> 
             RGBColor[
              0.9628316709480902, 0.9718005015674145, 0.9478004654188247], 
             UndirectedEdge[214, 293] -> 
             RGBColor[
              0.21107172389025777`, 0.33918014290187026`, 0.9353315944716927],
              UndirectedEdge[73, 245] -> 
             RGBColor[
              0.37670637299800835`, 0.5007058593032094, 0.9452243748724349], 
             UndirectedEdge[82, 192] -> 
             RGBColor[
              0.930031406620387, 0.7358466203284666, 0.4572790883268795], 
             UndirectedEdge[82, 266] -> 
             RGBColor[
              0.6213553148465931, 0.6847435984870042, 0.8214592367687926], 
             UndirectedEdge[30, 38] -> 
             RGBColor[
              0.4400713503236684, 0.5553482940395915, 0.949328558422408], 
             UndirectedEdge[146, 242] -> 
             RGBColor[
              0.23544148915831797`, 0.3647943113309621, 0.9367194165518717], 
             UndirectedEdge[25, 77] -> 
             RGBColor[
              0.24892138027318342`, 0.37896253156714604`, 0.9374870764091515],
              UndirectedEdge[68, 271] -> 
             RGBColor[
              0.9259155815977133, 0.7290271362933656, 0.2919182148886562], 
             UndirectedEdge[23, 267] -> 
             RGBColor[
              0.3821106817559689, 0.50384843174461, 0.9457196175325961], 
             UndirectedEdge[10, 161] -> 
             RGBColor[
              0.21385191803304957`, 0.3421023032204342, 0.935489922415196], 
             UndirectedEdge[223, 287] -> 
             RGBColor[
              0.9141648921008272, 0.6925393884549282, 0.24954185631357317`], 
             UndirectedEdge[9, 11] -> 
             RGBColor[
              0.43016772773719436`, 0.545286907400802, 0.949107366939159], 
             UndirectedEdge[218, 229] -> 
             RGBColor[
              0.3012157370951104, 0.430446886752895, 0.9405925945789568], 
             UndirectedEdge[62, 170] -> 
             RGBColor[
              0.9083710867000301, 0.580339218042234, 0.42464655483310587`], 
             UndirectedEdge[188, 294] -> 
             RGBColor[
              0.20780626806211017`, 0.3357479417846294, 0.9351456315930887], 
             UndirectedEdge[181, 299] -> 
             RGBColor[
              0.8541508128707371, 0.884172913273241, 0.8565895585797871], 
             UndirectedEdge[69, 109] -> 
             RGBColor[
              0.957103333757725, 0.9637481152069529, 0.737975761375697], 
             UndirectedEdge[48, 175] -> 
             RGBColor[
              0.3540970438547585, 0.4798066886867111, 0.9438319175031515], 
             UndirectedEdge[248, 270] -> 
             RGBColor[
              0.21830317142063266`, 0.3467808527565494, 0.9357434147105796], 
             UndirectedEdge[85, 232] -> 
             RGBColor[
              0.9568611020652522, 0.9642649897035074, 0.7955094610260169], 
             UndirectedEdge[65, 152] -> 
             RGBColor[
              0.270606352963235, 0.4017548127710696, 0.9387220035238077], 
             UndirectedEdge[43, 63] -> 
             RGBColor[
              0.3233435154432426, 0.45448563418447746`, 0.9418241407759673], 
             UndirectedEdge[184, 293] -> 
             RGBColor[
              0.22334920945949943`, 0.35208455867268873`, 0.9360307791119489],
              UndirectedEdge[24, 260] -> 
             RGBColor[
              0.9023952825645615, 0.924495379134781, 0.9727268847769307], 
             UndirectedEdge[201, 229] -> 
             RGBColor[
              0.3337508945428317, 0.46349998287045846`, 0.9424872897693092], 
             UndirectedEdge[17, 48] -> 
             RGBColor[
              0.35495264897954515`, 0.4807059839213601, 0.9438806429492537], 
             UndirectedEdge[153, 163] -> 
             RGBColor[
              0.2574205034515923, 0.3878956489031873, 0.9379710889008359], 
             UndirectedEdge[33, 200] -> 
             RGBColor[
              0.9003293088366926, 0.7550036483702731, 0.6091535540920102], 
             UndirectedEdge[33, 282] -> 
             RGBColor[
              0.9391598487497231, 0.9536036259867218, 0.9690629330997416], 
             UndirectedEdge[150, 237] -> 
             RGBColor[
              0.8003928066105324, 0.8444068950673695, 0.956951896654846], 
             UndirectedEdge[172, 203] -> 
             RGBColor[
              0.26454467239722235`, 0.39538360216344437`, 0.9383767997830261],
              UndirectedEdge[56, 93] -> 
             RGBColor[
              0.5394509250519448, 0.6369895888012234, 0.9568866993753897], 
             UndirectedEdge[122, 299] -> 
             RGBColor[
              0.8093386473760087, 0.8488870251734923, 0.8523133648913199], 
             UndirectedEdge[44, 100] -> 
             RGBColor[
              0.9076177976951124, 0.6402494666473935, 0.25721638876551267`], 
             UndirectedEdge[31, 171] -> 
             RGBColor[
              0.5185950159671473, 0.6191084488745244, 0.955507160509088], 
             UndirectedEdge[136, 256] -> 
             RGBColor[
              0.9940778224627702, 0.9897413860088904, 0.596785706394875], 
             UndirectedEdge[146, 159] -> 
             RGBColor[
              0.2389221548438223, 0.3684527116533779, 0.9369176353134778], 
             UndirectedEdge[65, 133] -> 
             RGBColor[
              0.3190318248130566, 0.44882524399181684`, 0.9416199173833522], 
             UndirectedEdge[58, 245] -> 
             RGBColor[
              0.48666290222101594`, 0.5933487734884098, 0.952947963928872], 
             UndirectedEdge[172, 272] -> 
             RGBColor[
              0.2463878565667746, 0.37629963751702955`, 0.937342795982084], 
             UndirectedEdge[99, 218] -> 
             RGBColor[
              0.3117655585077827, 0.43958461181110975`, 0.9412648198705315], 
             UndirectedEdge[18, 113] -> 
             RGBColor[
              0.9529050044310041, 0.9643972099323963, 0.9646037225429771], 
             UndirectedEdge[43, 131] -> 
             RGBColor[
              0.3235024771639835, 0.45462331883733487`, 0.9418342696762487], 
             UndirectedEdge[2, 156] -> 
             RGBColor[
              0.2292281520802934, 0.3582637001136342, 0.9363655761970868], 
             UndirectedEdge[165, 232] -> 
             RGBColor[
              0.9871784526525289, 0.9674285696046385, 0.48831934332178484`], 
             UndirectedEdge[173, 186] -> 
             RGBColor[
              0.24357136840210497`, 0.3733393298802981, 0.937182401147727], 
             UndirectedEdge[39, 281] -> 
             RGBColor[
              0.8518045532150162, 0.3848416812601996, 0.19667924438169382`], 
             UndirectedEdge[77, 91] -> 
             RGBColor[
              0.25932242623621204`, 0.38989469033869195`, 0.9380794005897775],
              UndirectedEdge[15, 19] -> 
             RGBColor[
              0.265094966907718, 0.3959619965846625, 0.938408138241311], 
             UndirectedEdge[119, 241] -> 
             RGBColor[
              0.2806500707405608, 0.4123113969635265, 0.9392939783928775], 
             UndirectedEdge[103, 116] -> 
             RGBColor[
              0.3006123597209014, 0.43202989779004775`, 0.9404770506166615], 
             UndirectedEdge[99, 257] -> 
             RGBColor[
              0.37939685727732686`, 0.5030362215582833, 0.9453958101516111], 
             UndirectedEdge[17, 253] -> 
             RGBColor[
              0.2964738820674033, 0.42894322595562323`, 0.9401951210387102], 
             UndirectedEdge[204, 292] -> 
             RGBColor[
              0.2369721103072519, 0.36640309120547765`, 0.9368065831619525], 
             UndirectedEdge[65, 241] -> 
             RGBColor[
              0.2834960053804121, 0.4153026547126882, 0.9394560501604341], 
             UndirectedEdge[71, 256] -> 
             RGBColor[
              0.8124222635893662, 0.8512090470378892, 0.8440664489660341], 
             UndirectedEdge[37, 102] -> 
             RGBColor[
              0.5330127818666326, 0.6293292071697167, 0.9572915771331396], 
             UndirectedEdge[61, 217] -> 
             RGBColor[
              0.686937545269946, 0.7542032342825437, 0.9702221270801157], 
             UndirectedEdge[35, 184] -> 
             RGBColor[
              0.23183414268000563`, 0.3610027614632789, 0.9365139835065228], 
             UndirectedEdge[164, 241] -> 
             RGBColor[
              0.33149984085228634`, 0.458806984736167, 0.9424442983869149], 
             UndirectedEdge[192, 255] -> 
             RGBColor[
              0.9119702371400515, 0.6765104448805886, 0.25204962038332024`], 
             UndirectedEdge[112, 134] -> 
             RGBColor[
              0.2631071012640549, 0.3938726237552112, 0.9382949322336882], 
             UndirectedEdge[44, 195] -> 
             RGBColor[
              0.892099510879235, 0.5209691140239162, 0.24235605978523028`], 
             UndirectedEdge[127, 281] -> 
             RGBColor[
              0.8344242447380918, 0.2656054066230123, 0.18059800167880746`], 
             UndirectedEdge[59, 192] -> 
             RGBColor[
              0.8488981465441187, 0.3665071091151284, 0.1940529052630896], 
             UndirectedEdge[108, 264] -> 
             RGBColor[
              0.3192908615453144, 0.4496732026354332, 0.9416135901421105], 
             UndirectedEdge[136, 296] -> 
             RGBColor[
              0.8445716246365338, 0.8749311705589841, 0.7198898610709794], 
             UndirectedEdge[118, 130] -> 
             RGBColor[
              0.17892828448197629`, 0.3053953500719979, 0.9335010731493483], 
             UndirectedEdge[85, 136] -> 
             RGBColor[
              0.9562666668799304, 0.9629935529487204, 0.7308088595324563], 
             UndirectedEdge[104, 157] -> 
             RGBColor[
              0.3155261405863954, 0.44552577951204275`, 0.9414061686253012], 
             UndirectedEdge[158, 217] -> 
             RGBColor[
              0.6053338779034495, 0.6866046110497097, 0.9641707450092601], 
             UndirectedEdge[11, 174] -> 
             RGBColor[
              0.36791464439567134`, 0.49309090587299315`, 0.9446641737001142],
              UndirectedEdge[39, 220] -> 
             RGBColor[
              0.5623622253882596, 0.4395170049728193, 0.5745682237352395], 
             UndirectedEdge[32, 208] -> 
             RGBColor[
              0.27110861374646283`, 0.402282720699415, 0.9387506065323843], 
             UndirectedEdge[27, 103] -> 
             RGBColor[
              0.2686276829189324, 0.3996751050995809, 0.9386093211919647], 
             UndirectedEdge[212, 250] -> 
             RGBColor[
              0.21715203202826977`, 0.34557093226872304`, 0.9356778590251427],
              UndirectedEdge[129, 298] -> 
             RGBColor[
              0.26058075662513375`, 0.3912172753602034, 0.9381510606438935], 
             UndirectedEdge[107, 179] -> 
             RGBColor[
              0.9138967980085537, 0.6275576288296454, 0.4676443834469852], 
             UndirectedEdge[261, 290] -> 
             RGBColor[
              0.5067850511563949, 0.6090396671765619, 0.9547103165107921], 
             UndirectedEdge[24, 113] -> 
             RGBColor[
              0.9575230369172714, 0.9678413309993203, 0.9567865981194988], 
             UndirectedEdge[15, 243] -> 
             RGBColor[
              0.2285446981366219, 0.35754534668535254`, 0.9363266545060742], 
             UndirectedEdge[246, 296] -> 
             RGBColor[
              0.6475517482649964, 0.7239253864883827, 0.965961068287336], 
             UndirectedEdge[131, 174] -> 
             RGBColor[
              0.3585773503848271, 0.4850034111068425, 0.9440692095823882], 
             UndirectedEdge[44, 121] -> 
             RGBColor[
              0.9798326937990873, 0.9423326330377451, 0.48673505054828914`], 
             UndirectedEdge[155, 293] -> 
             RGBColor[
              0.21078204772465953`, 0.3388756748852968, 0.9353150978425994], 
             UndirectedEdge[105, 140] -> 
             RGBColor[
              0.3086221728107845, 0.4399248428735164, 0.9409523793012212], 
             UndirectedEdge[51, 138] -> 
             RGBColor[
              0.8501230130531416, 0.8811959449639274, 0.8638775606265587], 
             UndirectedEdge[133, 277] -> 
             RGBColor[
              0.3496210523003913, 0.4772459158627348, 0.9434985221881913], 
             UndirectedEdge[201, 261] -> 
             RGBColor[
              0.36087721144814144`, 0.48699543516550725`, 0.9442157546956553],
              UndirectedEdge[19, 57] -> 
             RGBColor[
              0.2691600647734066, 0.40023467218359243`, 0.9386396395509886], 
             UndirectedEdge[104, 261] -> 
             RGBColor[
              0.34285661416014696`, 0.46919806205208336`, 0.9431476422340319],
              UndirectedEdge[15, 111] -> 
             RGBColor[
              0.2409685800879815, 0.3706036343358437, 0.9370341762037178], 
             UndirectedEdge[71, 85] -> 
             RGBColor[
              0.7746111080065263, 0.8244612139777192, 0.9780896021036154], 
             UndirectedEdge[84, 158] -> 
             RGBColor[
              0.35212502014478775`, 0.47866323634096297`, 0.943685588557766], 
             UndirectedEdge[65, 162] -> 
             RGBColor[
              0.28622167127698683`, 0.41816750238718753`, 0.9396112728009827],
              UndirectedEdge[156, 268] -> 
             RGBColor[
              0.2451076812596908, 0.374954092101482, 0.9372698918921952], 
             UndirectedEdge[48, 252] -> 
             RGBColor[
              0.35710710220900627`, 0.48297045086574814`, 0.9440033358734436],
              UndirectedEdge[204, 235] -> 
             RGBColor[
              0.23646094075205434`, 0.36586581959294334`, 0.9367774728119916],
              UndirectedEdge[62, 130] -> 
             RGBColor[
              0.5868878667757954, 0.648392143438405, 0.8070978104506135], 
             UndirectedEdge[142, 283] -> 
             RGBColor[
              0.6388734394755219, 0.7174499822340865, 0.964888142090148], 
             UndirectedEdge[99, 259] -> 
             RGBColor[
              0.41587462147542475`, 0.5343343034600658, 0.9478022372825421], 
             UndirectedEdge[43, 244] -> 
             RGBColor[
              0.28234247424873604`, 0.412848733894419, 0.9394358151698824], 
             UndirectedEdge[36, 154] -> 
             RGBColor[
              0.750385676327774, 0.8049262605804057, 0.9757550895296658], 
             UndirectedEdge[11, 185] -> 
             RGBColor[
              0.4557880502577546, 0.5660866394053694, 0.9511242925783112], 
             UndirectedEdge[20, 150] -> 
             RGBColor[
              0.9139560790389594, 0.9335493921357441, 0.968134833574319], 
             UndirectedEdge[175, 252] -> 
             RGBColor[
              0.2975212413691305, 0.4300440669881537, 0.9402547666015143], 
             UndirectedEdge[97, 292] -> 
             RGBColor[
              0.25027096919944, 0.3803810350975218, 0.937563933501964], 
             UndirectedEdge[176, 226] -> 
             RGBColor[
              0.17893944427006758`, 0.3054070797168533, 0.9335017086827707], 
             UndirectedEdge[80, 103] -> 
             RGBColor[
              0.2733233300214085, 0.4046105279255051, 0.9388767313478634], 
             UndirectedEdge[137, 220] -> 
             RGBColor[
              0.5513789728038629, 0.36945130513336594`, 0.564612808979479], 
             UndirectedEdge[20, 167] -> 
             RGBColor[
              0.8099161582263048, 0.8518030947538164, 0.981590034710579], 
             UndirectedEdge[240, 256] -> 
             RGBColor[
              0.9950907669461442, 0.9919079718344301, 0.7070384622414018], 
             UndirectedEdge[113, 278] -> 
             RGBColor[
              0.7811703997408805, 0.8288870412862575, 0.957738894978919], 
             UndirectedEdge[181, 240] -> 
             RGBColor[
              0.8543753182561593, 0.8839651564219314, 0.8310187966371865], 
             UndirectedEdge[7, 151] -> 
             RGBColor[
              0.4190101469832575, 0.5373472620797284, 0.9479199339430164], 
             UndirectedEdge[6, 101] -> 
             RGBColor[
              0.4261316567977976, 0.5406988809357904, 0.9490838670731377], 
             UndirectedEdge[65, 116] -> 
             RGBColor[
              0.3051622199360282, 0.4368120893539453, 0.940736158424998], 
             UndirectedEdge[50, 264] -> 
             RGBColor[
              0.32355517598609507`, 0.45336673747336176`, 0.9418853084874919],
              UndirectedEdge[55, 235] -> 
             RGBColor[
              0.25936698600148883`, 0.38994152547725025`, 0.9380819382024896],
              UndirectedEdge[100, 232] -> 
             RGBColor[
              0.9221384356388024, 0.6882475061102127, 0.3972545294946756], 
             UndirectedEdge[28, 163] -> 
             RGBColor[
              0.23238600045450547`, 0.3615827989740821, 0.9365454109903801], 
             UndirectedEdge[11, 63] -> 
             RGBColor[
              0.3340095449749544, 0.46372401287461446`, 0.9425037707461285], 
             UndirectedEdge[234, 274] -> 
             RGBColor[
              0.8909472265976595, 0.513146913463993, 0.24055037716924876`], 
             UndirectedEdge[148, 270] -> 
             RGBColor[
              0.23353444010566207`, 0.3627898818627272, 0.9366108129295494], 
             UndirectedEdge[96, 245] -> 
             RGBColor[
              0.41493426639987385`, 0.5338169391781161, 0.9476602224364029], 
             UndirectedEdge[159, 235] -> 
             RGBColor[
              0.24471645266359499`, 0.3745428860416596, 0.9372476120024185], 
             UndirectedEdge[53, 287] -> 
             RGBColor[
              0.8863520651509298, 0.5242910551950881, 0.22469122939407754`], 
             UndirectedEdge[105, 289] -> 
             RGBColor[
              0.2900768000973668, 0.42221948720669167`, 0.9398308166841512], 
             UndirectedEdge[56, 164] -> 
             RGBColor[
              0.46580833431938506`, 0.5753190136054342, 0.9516098956299331], 
             UndirectedEdge[112, 235] -> 
             RGBColor[
              0.24712629913564943`, 0.3770757874768801, 0.9373848491939536], 
             UndirectedEdge[7, 43] -> 
             RGBColor[
              0.3584602463932565, 0.4849019815151618, 0.9440617478195963], 
             UndirectedEdge[242, 243] -> 
             RGBColor[
              0.22929951054390013`, 0.35833870238327276`, 0.9363696399560237],
              UndirectedEdge[151, 286] -> 
             RGBColor[
              0.5011547059099458, 0.6056262623148936, 0.953947236987697], 
             UndirectedEdge[126, 163] -> 
             RGBColor[
              0.23364896427549098`, 0.3629102540264691, 0.9366173349115978], 
             UndirectedEdge[31, 138] -> 
             RGBColor[
              0.662760313991049, 0.7361123302878763, 0.9672677727663206], 
             UndirectedEdge[95, 138] -> 
             RGBColor[
              0.5976652055170001, 0.6832651887274253, 0.9621432473760043], 
             UndirectedEdge[197, 275] -> 
             RGBColor[
              0.21163940728530467`, 0.33977681414327066`, 0.9353639232012283],
              UndirectedEdge[198, 245] -> 
             RGBColor[
              0.4443289893270455, 0.5589801958800422, 0.949615283231626], 
             UndirectedEdge[187, 264] -> 
             RGBColor[
              0.3292953995025846, 0.4583386305713222, 0.9422510704540822], 
             UndirectedEdge[62, 195] -> 
             RGBColor[
              0.9069962455234778, 0.5697715863000085, 0.4233300053697785], 
             UndirectedEdge[169, 187] -> 
             RGBColor[
              0.3284772756829356, 0.4574787305648249, 0.9422044795128589], 
             UndirectedEdge[82, 199] -> 
             RGBColor[
              0.587001837836629, 0.6486359160132862, 0.81950285707449], 
             UndirectedEdge[126, 155] -> 
             RGBColor[
              0.21912067898952223`, 0.3476401050444259, 0.9357899705572339], 
             UndirectedEdge[82, 220] -> 
             RGBColor[
              0.6261342073882591, 0.6897665175475827, 0.8217313876293025], 
             UndirectedEdge[32, 202] -> 
             RGBColor[
              0.24218926046257408`, 0.37188664680514644`, 0.937103692145216], 
             UndirectedEdge[113, 260] -> 
             RGBColor[
              0.9042815340807562, 0.9259021424271057, 0.969533952973199], 
             UndirectedEdge[105, 230] -> 
             RGBColor[
              0.2692612582166467, 0.40034103290847267`, 0.938645402367879], 
             UndirectedEdge[245, 289] -> 
             RGBColor[
              0.3576929449951681, 0.48259509766982983`, 0.944072988186208], 
             UndirectedEdge[108, 187] -> 
             RGBColor[
              0.35392495764506043`, 0.4809737423517148, 0.9437727632309596], 
             UndirectedEdge[137, 228] -> 
             RGBColor[
              0.8309547247116273, 0.6038501100477591, 0.5867983401041436], 
             UndirectedEdge[88, 261] -> 
             RGBColor[
              0.4524312720200109, 0.5649128206637994, 0.9504313879127225], 
             UndirectedEdge[192, 228] -> 
             RGBColor[
              0.8406646902431527, 0.6681341107638701, 0.5956912929318666], 
             UndirectedEdge[42, 97] -> 
             RGBColor[
              0.25595913612423093`, 0.3863596591860904, 0.937887866193442], 
             UndirectedEdge[121, 240] -> 
             RGBColor[
              0.9947718410408293, 0.9912258215713169, 0.6723253456304181], 
             UndirectedEdge[25, 43] -> 
             RGBColor[
              0.2869920462831278, 0.4177357289024586, 0.9397006014188156], 
             UndirectedEdge[77, 270] -> 
             RGBColor[
              0.23714390206690406`, 0.36658365523709874`, 0.9368163664485216],
              UndirectedEdge[225, 255] -> 
             RGBColor[
              0.9599585954916654, 0.876593081803823, 0.2989471339802242], 
             UndirectedEdge[2, 275] -> 
             RGBColor[
              0.2217679370492794, 0.35042254111108606`, 0.9359407279874696], 
             UndirectedEdge[235, 253] -> 
             RGBColor[
              0.2693822700586988, 0.40046822402706334`, 0.9386522938132629], 
             UndirectedEdge[73, 95] -> 
             RGBColor[
              0.4088283158597046, 0.5275690199007069, 0.9475362008014293], 
             UndirectedEdge[49, 175] -> 
             RGBColor[
              0.26553285029495766`, 0.3964222397880617, 0.9384330750524239], 
             UndirectedEdge[153, 219] -> 
             RGBColor[
              0.2738583241419696, 0.40517284066680126`, 0.9389071984715764], 
             UndirectedEdge[54, 167] -> 
             RGBColor[
              0.585666437251012, 0.671825268631737, 0.9619628736506332], 
             UndirectedEdge[56, 246] -> 
             RGBColor[
              0.57328015808247, 0.6644536841649844, 0.9595498605201163], 
             UndirectedEdge[192, 225] -> 
             RGBColor[
              0.91297449591913, 0.6798980455535951, 0.25595097610168294`], 
             UndirectedEdge[84, 252] -> 
             RGBColor[
              0.30057464185555743`, 0.4332533844961608, 0.9404286532421151], 
             UndirectedEdge[119, 164] -> 
             RGBColor[
              0.33307449939887124`, 0.46046205070774604`, 0.9425339728616443],
              UndirectedEdge[93, 168] -> 
             RGBColor[
              0.4585412392278475, 0.5694721717790032, 0.9510231831684333], 
             UndirectedEdge[111, 250] -> 
             RGBColor[
              0.2327988220725642, 0.3620167006690641, 0.9365689205708136], 
             UndirectedEdge[54, 286] -> 
             RGBColor[
              0.4882211414959945, 0.5944238588793778, 0.953123121699942], 
             UndirectedEdge[74, 257] -> 
             RGBColor[
              0.5147596974188978, 0.6152603482603705, 0.9554081515783656], 
             UndirectedEdge[220, 236] -> 
             RGBColor[
              0.4402011946832155, 0.5463223550644548, 0.9507193164378127], 
             UndirectedEdge[130, 228] -> 
             RGBColor[
              0.49763512145939465`, 0.5809234064486897, 0.9579150616794772], 
             UndirectedEdge[1, 142] -> 
             RGBColor[
              0.5387732060688373, 0.6352393283002062, 0.9572689291818902], 
             UndirectedEdge[101, 114] -> 
             RGBColor[
              0.4255007228362041, 0.540035729338632, 0.9490479363174081], 
             UndirectedEdge[199, 266] -> 
             RGBColor[
              0.21328047700996416`, 0.3415016824737179, 0.9354573796943026], 
             UndirectedEdge[93, 277] -> 
             RGBColor[
              0.440152252258617, 0.5535445555236148, 0.9498514531794966], 
             UndirectedEdge[19, 112] -> 
             RGBColor[
              0.271740291472555, 0.402946654040219, 0.9387865796444018], 
             UndirectedEdge[77, 203] -> 
             RGBColor[
              0.25281317669126346`, 0.38305305635669296`, 0.9377087084577643],
              UndirectedEdge[26, 60] -> 
             RGBColor[
              0.9559587194852852, 0.8665294960501166, 0.5718984085520893], 
             UndirectedEdge[186, 263] -> 
             RGBColor[
              0.24547633917610456`, 0.3753415749458948, 0.9372908864151546], 
             UndirectedEdge[167, 283] -> 
             RGBColor[
              0.6863247949375169, 0.7545193417646557, 0.9696176497444712], 
             UndirectedEdge[170, 200] -> 
             RGBColor[
              0.8539446998932355, 0.37225212712685507`, 0.1975915310267845], 
             UndirectedEdge[17, 292] -> 
             RGBColor[
              0.26964195081094916`, 0.4007411649623891, 0.9386670822479402], 
             UndirectedEdge[106, 215] -> 
             RGBColor[
              0.8258859987463416, 0.8619784867738793, 0.84861498208911], 
             UndirectedEdge[123, 229] -> 
             RGBColor[
              0.3913046976868122, 0.5133501944155183, 0.9461545672128138], 
             UndirectedEdge[105, 149] -> 
             RGBColor[
              0.29155965067616113`, 0.4237780571831614, 0.9399152628309327], 
             UndirectedEdge[68, 274] -> 
             RGBColor[
              0.9194708353599413, 0.7072874939349834, 0.2668815927431183], 
             UndirectedEdge[149, 171] -> 
             RGBColor[
              0.3561511381973472, 0.48153386145037547`, 0.943964705839551], 
             UndirectedEdge[29, 172] -> 
             RGBColor[
              0.256159178309366, 0.3865699162060744, 0.9378992582999495], 
             UndirectedEdge[76, 209] -> 
             RGBColor[
              0.2797259704782522, 0.4113401089964994, 0.9392413522500229], 
             UndirectedEdge[247, 267] -> 
             RGBColor[
              0.5234677465828359, 0.6240137244860162, 0.9556284450179895], 
             UndirectedEdge[164, 210] -> 
             RGBColor[
              0.3812406788826516, 0.5046332471596473, 0.9455132968338751], 
             UndirectedEdge[258, 260] -> 
             RGBColor[
              0.9054604072768613, 0.9267813441265331, 0.9675384281515653], 
             UndirectedEdge[62, 137] -> 
             RGBColor[
              0.9202074700280282, 0.6713188470374746, 0.43598108887527987`], 
             UndirectedEdge[175, 280] -> 
             RGBColor[
              0.2812847712693677, 0.4129785074616403, 0.9393301236490378], 
             UndirectedEdge[72, 194] -> 
             RGBColor[
              0.5838203648230471, 0.6728659592388615, 0.9604785834522965], 
             UndirectedEdge[3, 257] -> 
             RGBColor[
              0.38431511212659675`, 0.5072961667100446, 0.9457091970015647], 
             UndirectedEdge[154, 171] -> 
             RGBColor[
              0.5797766952507789, 0.6672643729865424, 0.9613588180759691], 
             UndirectedEdge[168, 277] -> 
             RGBColor[
              0.3674840405107483, 0.49271793843065337`, 0.944636736001335], 
             UndirectedEdge[146, 243] -> 
             RGBColor[
              0.22430859499308387`, 0.3530929336970421, 0.9360854146988027], 
             UndirectedEdge[98, 122] -> 
             RGBColor[
              0.5234999711581451, 0.6232114459734905, 0.9558598822602524], 
             UndirectedEdge[142, 210] -> 
             RGBColor[
              0.5187904189187625, 0.6179312424348968, 0.9559956436547723], 
             UndirectedEdge[3, 38] -> 
             RGBColor[
              0.3976345995492975, 0.5188328372586848, 0.9465579029621789], 
             UndirectedEdge[21, 205] -> 
             RGBColor[
              0.4564507498978377, 0.5677093547420913, 0.9508767552454336], 
             UndirectedEdge[153, 221] -> 
             RGBColor[
              0.2840475061144973, 0.4158823169513779, 0.939487457311368], 
             UndirectedEdge[55, 159] -> 
             RGBColor[
              0.26204426941803677`, 0.39275552009761494`, 0.9382344055323761],
              UndirectedEdge[149, 298] -> 
             RGBColor[
              0.28960052483186716`, 0.4217188917050555, 0.9398036935123671], 
             UndirectedEdge[22, 247] -> 
             RGBColor[
              0.6982336123573278, 0.7632154445962727, 0.9712197251392987], 
             UndirectedEdge[105, 298] -> 
             RGBColor[
              0.2872112063681208, 0.41920756650811786`, 0.9396676253605367], 
             UndirectedEdge[169, 219] -> 
             RGBColor[
              0.2836300261607937, 0.41544351905027754`, 0.9394636824456108], 
             UndirectedEdge[53, 225] -> 
             RGBColor[
              0.8963459868958306, 0.5624350878346187, 0.24043281821285972`], 
             UndirectedEdge[47, 90] -> 
             RGBColor[
              0.5238031310544717, 0.622908536972411, 0.9560460606082701], 
             UndirectedEdge[100, 137] -> 
             RGBColor[
              0.8478732688157926, 0.3689804990841502, 0.19347680232411396`], 
             UndirectedEdge[15, 175] -> 
             RGBColor[
              0.2667169814547302, 0.3976668367152345, 0.9385005095702079], 
             UndirectedEdge[49, 253] -> 
             RGBColor[
              0.2666399442226916, 0.39758586569991927`, 0.9384961224138098], 
             UndirectedEdge[166, 291] -> 
             RGBColor[
              0.9053156340255587, 0.5627492600761606, 0.30706567418331665`], 
             UndirectedEdge[161, 230] -> 
             RGBColor[
              0.2328116110999559, 0.36203014274772405`, 0.9365696488870041], 
             UndirectedEdge[263, 269] -> 
             RGBColor[
              0.24400443083652518`, 0.3737945059566179, 0.9372070634127088], 
             UndirectedEdge[122, 160] -> 
             RGBColor[
              0.6072063704282553, 0.6919965117057422, 0.9622206562317872], 
             UndirectedEdge[196, 289] -> 
             RGBColor[
              0.28595784411409636`, 0.4178902033113814, 0.9395962482343534], 
             UndirectedEdge[30, 158] -> 
             RGBColor[
              0.4329152304787701, 0.5491500227069821, 0.9488725767937995], 
             UndirectedEdge[114, 187] -> 
             RGBColor[
              0.33417034239985266`, 0.4634625046455827, 0.9425286912402498], 
             UndirectedEdge[49, 159] -> 
             RGBColor[
              0.24197412682758776`, 0.3716605277145155, 0.9370914406029653], 
             UndirectedEdge[33, 94] -> 
             RGBColor[
              0.8883058899064401, 0.9137750204630982, 0.9892086028509474], 
             UndirectedEdge[193, 220] -> 
             RGBColor[
              0.3283447463388828, 0.4540509053495343, 0.9423173412993839], 
             UndirectedEdge[60, 127] -> 
             RGBColor[
              0.879427272019672, 0.4987774156297289, 0.21919915424561515`], 
             UndirectedEdge[282, 297] -> 
             RGBColor[
              0.8620280342318183, 0.892582413918251, 0.9615782291090177], 
             UndirectedEdge[97, 235] -> 
             RGBColor[
              0.24975979964424241`, 0.3798437634849875, 0.9375348231520031], 
             UndirectedEdge[50, 187] -> 
             RGBColor[
              0.35818927208584117`, 0.4846672771896433, 0.9440444815763409], 
             UndirectedEdge[271, 274] -> 
             RGBColor[
              0.9710201994330907, 0.9139064692863681, 0.34191937648403536`], 
             UndirectedEdge[137, 170] -> 
             RGBColor[
              0.8337298231764674, 0.2602677782028984, 0.17993302280715895`], 
             UndirectedEdge[84, 253] -> 
             RGBColor[
              0.29867167742904355`, 0.43125324822898137`, 0.9403202822332086],
              UndirectedEdge[33, 185] -> 
             RGBColor[
              0.7413664787721765, 0.7975076391058051, 0.9754311281439616], 
             UndirectedEdge[3, 144] -> 
             RGBColor[
              0.34651719678738085`, 0.4745575122216793, 0.9433007472595341], 
             UndirectedEdge[11, 43] -> 
             RGBColor[
              0.3328397711748278, 0.46271081360348554`, 0.9424292337939748], 
             UndirectedEdge[29, 272] -> 
             RGBColor[
              0.23305163384099561`, 0.36228242186687754`, 0.9365833178270244],
              UndirectedEdge[70, 251] -> 
             RGBColor[
              0.27547374372817707`, 0.40687074907542276`, 0.9389991942272118],
              UndirectedEdge[99, 123] -> 
             RGBColor[
              0.40185451909948444`, 0.5224879194737331, 0.9468267925043885], 
             UndirectedEdge[133, 239] -> 
             RGBColor[
              0.38064066205782954`, 0.5041135427437089, 0.9454750642923715], 
             UndirectedEdge[259, 260] -> 
             RGBColor[
              0.656707314635238, 0.7292515443954324, 0.9682208504157948], 
             UndirectedEdge[125, 192] -> 
             RGBColor[
              0.9288056517822338, 0.7332248546724817, 0.32386323867590994`], 
             UndirectedEdge[213, 264] -> 
             RGBColor[
              0.36127001361165895`, 0.48603343422176903`, 0.9442884645910713],
              UndirectedEdge[134, 204] -> 
             RGBColor[
              0.25244174288045984`, 0.38266265587127446`, 0.9376875558517261],
              UndirectedEdge[94, 142] -> 
             RGBColor[
              0.7604864358301577, 0.8131562391312941, 0.9766718286519673], 
             UndirectedEdge[134, 175] -> 
             RGBColor[
              0.2842559782593704, 0.41610143439353686`, 0.9394993294916116], 
             UndirectedEdge[8, 267] -> 
             RGBColor[
              0.5598482664107077, 0.6534036903177951, 0.9585918492816847], 
             UndirectedEdge[195, 225] -> 
             RGBColor[
              0.8900533058830544, 0.5140667841000182, 0.23440693976845853`], 
             UndirectedEdge[51, 281] -> 
             RGBColor[
              0.9148192587802333, 0.6349551711119263, 0.4692679592224235], 
             UndirectedEdge[49, 243] -> 
             RGBColor[
              0.2273605669768493, 0.3563007497581797, 0.9362592199882902], 
             UndirectedEdge[212, 243] -> 
             RGBColor[
              0.2149437082857312, 0.34324984399950276`, 0.9355520982549272], 
             UndirectedEdge[22, 285] -> 
             RGBColor[
              0.6000751622710249, 0.6816104857973055, 0.9640215926822105], 
             UndirectedEdge[20, 33] -> 
             RGBColor[
              0.8902842568405922, 0.9153525165550513, 0.9893973012552358], 
             UndirectedEdge[9, 174] -> 
             RGBColor[
              0.4545765714263261, 0.5664286209801727, 0.9506626768751375], 
             UndirectedEdge[180, 250] -> 
             RGBColor[
              0.22830469938985565`, 0.3572930927857018, 0.9363129869324922], 
             UndirectedEdge[92, 221] -> 
             RGBColor[
              0.27785530490942656`, 0.40937392087661617`, 0.9391348206132799],
              UndirectedEdge[71, 232] -> 
             RGBColor[
              0.8118465460917592, 0.8499776455244756, 0.7814031522680547], 
             UndirectedEdge[25, 148] -> 
             RGBColor[
              0.24531191831194143`, 0.3751687581927745, 0.9372815228901793], 
             UndirectedEdge[76, 218] -> 
             RGBColor[
              0.2751691719679872, 0.4065506248444982, 0.9389818493160426], 
             UndirectedEdge[20, 200] -> 
             RGBColor[
              0.8759509079419014, 0.7355649732308305, 0.6068283204518097], 
             UndirectedEdge[68, 255] -> 
             RGBColor[
              0.9166602771185755, 0.6978068210363987, 0.2559631047048003], 
             UndirectedEdge[30, 123] -> 
             RGBColor[
              0.44920952472312525`, 0.5632633214064009, 0.9499108348145711], 
             UndirectedEdge[113, 290] -> 
             RGBColor[
              0.7861690031762806, 0.8329451327396338, 0.9581324033518415], 
             UndirectedEdge[230, 269] -> 
             RGBColor[
              0.23818874032876391`, 0.3676818464968855, 0.9368758684418348], 
             UndirectedEdge[7, 54] -> 
             RGBColor[
              0.40607658256930623`, 0.5261448586442126, 0.9470958186552614], 
             UndirectedEdge[71, 296] -> 
             RGBColor[
              0.6629160657631297, 0.7363988315879828, 0.9671706036421385], 
             UndirectedEdge[37, 237] -> 
             RGBColor[
              0.6597410410048012, 0.7340591462727639, 0.9667579712592742], 
             UndirectedEdge[8, 217] -> 
             RGBColor[
              0.7294424930983517, 0.7885652866674933, 0.9736676687505319], 
             UndirectedEdge[39, 100] -> 
             RGBColor[
              0.8588565214001893, 0.4390461989236035, 0.20343221707987458`], 
             UndirectedEdge[35, 216] -> 
             RGBColor[
              0.24253456217849695`, 0.3722495808019747, 0.9371233565671098], 
             UndirectedEdge[48, 253] -> 
             RGBColor[
              0.3552041377824924, 0.4809703145985687, 0.9438949648645372], 
             UndirectedEdge[72, 247] -> 
             RGBColor[
              0.6154478937421781, 0.6985426120193529, 0.9629684183842664], 
             UndirectedEdge[24, 254] -> 
             RGBColor[
              0.9234793483730712, 0.7829172870924861, 0.5955041038084421], 
             UndirectedEdge[247, 273] -> 
             RGBColor[
              0.598461668080708, 0.6848971683956518, 0.9615322412300882], 
             UndirectedEdge[80, 152] -> 
             RGBColor[
              0.26056294463292196`, 0.39119855382704327`, 0.9381500462772876],
              UndirectedEdge[121, 125] -> 
             RGBColor[
              0.9936176446660105, 0.9887571122327337, 0.5466981931057444], 
             UndirectedEdge[8, 177] -> 
             RGBColor[
              0.5355284607783559, 0.6327336001246429, 0.9569332103909327], 
             UndirectedEdge[38, 253] -> 
             RGBColor[
              0.35733483343099304`, 0.48281581607742285`, 0.9440307309071595],
              UndirectedEdge[134, 292] -> 
             RGBColor[
              0.2585311409306501, 0.3890629993121603, 0.9380343380622274], 
             UndirectedEdge[19, 177] -> 
             RGBColor[
              0.3552373943929633, 0.4804944703524481, 0.9439155616348212], 
             UndirectedEdge[219, 221] -> 
             RGBColor[
              0.28442417853057445`, 0.4162782235430855, 0.9395089082482266], 
             UndirectedEdge[37, 185] -> 
             RGBColor[
              0.6243865353648125, 0.7053567658918924, 0.9639747350674728], 
             UndirectedEdge[15, 280] -> 
             RGBColor[
              0.2534905697092152, 0.38376503936775813`, 0.9377472849880235], 
             UndirectedEdge[140, 171] -> 
             RGBColor[
              0.37321366033197056`, 0.49768064714073046`, 0.9450018223098395],
              UndirectedEdge[211, 221] -> 
             RGBColor[
              0.26848631667000333`, 0.39952652020881857`, 0.9386012705932207],
              UndirectedEdge[47, 273] -> 
             RGBColor[
              0.6309474410941337, 0.7112445284148133, 0.9641074535297975], 
             UndirectedEdge[58, 171] -> 
             RGBColor[
              0.48363824484440066`, 0.5907289672924857, 0.9527552354354336], 
             UndirectedEdge[75, 150] -> 
             RGBColor[
              0.8462593507356758, 0.8802930242051693, 0.9614859532696918], 
             UndirectedEdge[9, 167] -> 
             RGBColor[
              0.6353780576373289, 0.7131584853000028, 0.9656069359601525], 
             UndirectedEdge[135, 260] -> 
             RGBColor[
              0.9196247583457642, 0.9363642687580429, 0.8996385198821143], 
             UndirectedEdge[184, 202] -> 
             RGBColor[
              0.23277907926056368`, 0.361995949721885, 0.9365677962468772], 
             UndirectedEdge[166, 262] -> 
             RGBColor[
              0.9933514957949947, 0.9881878467094093, 0.5177295309761065], 
             UndirectedEdge[173, 276] -> 
             RGBColor[
              0.24447758470727698`, 0.3742918206744662, 0.9372340088256796], 
             UndirectedEdge[67, 86] -> 
             RGBColor[
              0.9435929630020026, 0.929903263270933, 0.6741823558912051], 
             UndirectedEdge[25, 272] -> 
             RGBColor[
              0.23754533151077184`, 0.36700558303470066`, 0.9368392272614883],
              UndirectedEdge[7, 174] -> 
             RGBColor[
              0.39353511961410004`, 0.5152820737846694, 0.9462966877257359], 
             UndirectedEdge[88, 113] -> 
             RGBColor[
              0.7318152240398965, 0.7888182862268713, 0.9538534747537719], 
             UndirectedEdge[147, 206] -> 
             RGBColor[
              0.23143319481245586`, 0.360581339832921, 0.9364911501186151], 
             UndirectedEdge[189, 211] -> 
             RGBColor[
              0.23710386113640347`, 0.3665415696804011, 0.9368140861767649], 
             UndirectedEdge[104, 209] -> 
             RGBColor[
              0.2751140822771375, 0.4064927220865271, 0.9389787120396467], 
             UndirectedEdge[151, 167] -> 
             RGBColor[
              0.5986000016649633, 0.6830276720672528, 0.9627869889383882], 
             UndirectedEdge[215, 274] -> 
             RGBColor[
              0.979839341035498, 0.9422049502369351, 0.5238492272566825], 
             UndirectedEdge[41, 261] -> 
             RGBColor[
              0.3788160778841355, 0.5025331796387221, 0.9453588034022401], 
             UndirectedEdge[157, 218] -> 
             RGBColor[
              0.30101158042666865`, 0.4302700565079032, 0.9405795858965723], 
             UndirectedEdge[187, 205] -> 
             RGBColor[
              0.44668815437293624`, 0.55925348518074, 0.950254691291311], 
             UndirectedEdge[62, 82] -> 
             RGBColor[
              0.9949627046124243, 0.9916340594516913, 0.6930996675251034], 
             UndirectedEdge[42, 144] -> 
             RGBColor[
              0.28507366633741316`, 0.4163170541357517, 0.9395694691052225], 
             UndirectedEdge[33, 150] -> 
             RGBColor[
              0.9383344799337505, 0.9529880672751867, 0.9704600672145196], 
             UndirectedEdge[34, 46] -> 
             RGBColor[
              0.30981865996121394`, 0.44123557275110054`, 0.9410185715382298],
              UndirectedEdge[220, 266] -> 
             RGBColor[
              0.2524128465615943, 0.3826322840080144, 0.9376859102491151], 
             UndirectedEdge[128, 279] -> 
             RGBColor[
              0.24902661375038676`, 0.3790731386238746, 0.9374930692999993], 
             UndirectedEdge[147, 270] -> 
             RGBColor[
              0.2272240069658551, 0.35615721652822, 0.9362514430976865], 
             UndirectedEdge[30, 90] -> 
             RGBColor[
              0.4328724368509469, 0.5491129570174318, 0.9488698500216755], 
             UndirectedEdge[36, 222] -> 
             RGBColor[
              0.5978519743815511, 0.6821400273622127, 0.9628407950842862], 
             UndirectedEdge[127, 170] -> 
             RGBColor[
              0.8273327672839398, 0.21109720340516447`, 0.1738071948600332], 
             UndirectedEdge[1, 295] -> 
             RGBColor[
              0.6279037208977163, 0.7050085996594103, 0.9661155178174292], 
             UndirectedEdge[96, 140] -> 
             RGBColor[
              0.36676996210044227`, 0.49209943960227065`, 0.9445912355564652],
              UndirectedEdge[206, 272] -> 
             RGBColor[
              0.22997704115109324`, 0.35905083000935434`, 0.9364082243217868],
              UndirectedEdge[129, 265] -> 
             RGBColor[
              0.22918762870603976`, 0.3582211074779632, 0.936363268450872], 
             UndirectedEdge[39, 60] -> 
             RGBColor[
              0.8968075804965964, 0.6180136902669162, 0.2352803969485015], 
             UndirectedEdge[71, 240] -> 
             RGBColor[
              0.8122650553898112, 0.8508727945952284, 0.8269553066210207], 
             UndirectedEdge[30, 144] -> 
             RGBColor[
              0.3889539475617518, 0.5110729690025859, 0.9460714027197632], 
             UndirectedEdge[26, 59] -> 
             RGBColor[
              0.9093225725856791, 0.6208046140216712, 0.5317333787947149], 
             UndirectedEdge[133, 241] -> 
             RGBColor[
              0.3146112316266204, 0.4441789202710761, 0.9413681711410662], 
             UndirectedEdge[236, 266] -> 
             RGBColor[
              0.43542230214154953`, 0.5412994360038763, 0.9504471655773028], 
             UndirectedEdge[28, 216] -> 
             RGBColor[
              0.24112529640186797`, 0.3707683531181266, 0.9370431009659527], 
             UndirectedEdge[173, 230] -> 
             RGBColor[
              0.25326290395464024`, 0.3835257482248573, 0.9377343197601018], 
             UndirectedEdge[39, 266] -> 
             RGBColor[
              0.5575833328465938, 0.4344940859122408, 0.5742960728747296], 
             UndirectedEdge[86, 141] -> 
             RGBColor[
              0.936935020626016, 0.7805800799358134, 0.2971516426609445], 
             UndirectedEdge[25, 206] -> 
             RGBColor[
              0.2442420605634609, 0.3740442698662223, 0.937220596074116], 
             UndirectedEdge[141, 165] -> 
             RGBColor[0.9396314058192, 0.789675620333774, 0.3076265899668467],
              UndirectedEdge[152, 241] -> 
             RGBColor[
              0.2661857597767988, 0.3971084890503288, 0.9384702572815218], 
             UndirectedEdge[110, 141] -> 
             RGBColor[
              0.9459742116007779, 0.8128132585241278, 0.5020022278511405], 
             UndirectedEdge[97, 134] -> 
             RGBColor[
              0.2657406017726479, 0.3966405997633186, 0.9384449061917377], 
             UndirectedEdge[103, 119] -> 
             RGBColor[
              0.28052080371187027`, 0.4121755291203697, 0.939286616826827], 
             UndirectedEdge[3, 17] -> 
             RGBColor[
              0.3367736481857078, 0.4649602471368852, 0.9427222930937296], 
             UndirectedEdge[203, 270] -> 
             RGBColor[
              0.2439246691349402, 0.37371067135106817`, 0.9372025211018002], 
             UndirectedEdge[51, 141] -> 
             RGBColor[
              0.9462822846437602, 0.812940654644517, 0.4968966602614467], 
             UndirectedEdge[184, 275] -> 
             RGBColor[
              0.22510784132218828`, 0.35393299226407493`, 0.9361309305948662],
              UndirectedEdge[58, 109] -> 
             RGBColor[
              0.7350459204207711, 0.7923292470470489, 0.9749877366110247], 
             UndirectedEdge[179, 281] -> 
             RGBColor[
              0.9148614845826333, 0.6349726325663724, 0.4685681683997813], 
             UndirectedEdge[31, 154] -> 
             RGBColor[
              0.6800184039631393, 0.7495944813404151, 0.9689878978887183], 
             UndirectedEdge[122, 296] -> 
             RGBColor[
              0.6602141631347492, 0.7342053053149373, 0.9669578999698369], 
             UndirectedEdge[96, 290] -> 
             RGBColor[
              0.5091973143554127, 0.6111290483156775, 0.9548640237887529], 
             UndirectedEdge[122, 240] -> 
             RGBColor[
              0.8095631527614308, 0.8486792683221828, 0.8267426029487193], 
             UndirectedEdge[97, 144] -> 
             RGBColor[
              0.28659496025462, 0.4179160304983415, 0.9396561045432549], 
             UndirectedEdge[61, 247] -> 
             RGBColor[
              0.5729638190353659, 0.6641968658756336, 0.9595249571515402], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.5867492116924276, 0.675169261254928, 0.9607600670587673], 
             UndirectedEdge[45, 287] -> 
             RGBColor[
              0.899399401089056, 0.6245785965945915, 0.23718537302328563`], 
             UndirectedEdge[278, 290] -> 
             RGBColor[
              0.607930114483695, 0.6925840797342462, 0.9622776320149933], 
             UndirectedEdge[109, 110] -> 
             RGBColor[
              0.9570573175626281, 0.9656649471847494, 0.8794550171346109], 
             UndirectedEdge[56, 160] -> 
             RGBColor[
              0.5689561966042058, 0.6609432974446849, 0.9592094624333546], 
             UndirectedEdge[146, 292] -> 
             RGBColor[
              0.2367560409824719, 0.36617598864554746`, 0.9367942783335522], 
             UndirectedEdge[131, 139] -> 
             RGBColor[
              0.29015495986038786`, 0.4208144502573191, 0.9398897209981389], 
             UndirectedEdge[47, 74] -> 
             RGBColor[
              0.6411369333771564, 0.7195168172815674, 0.9649096076876572], 
             UndirectedEdge[46, 221] -> 
             RGBColor[
              0.2933757434234066, 0.4256868858074472, 0.9400186866262199], 
             UndirectedEdge[48, 74] -> 
             RGBColor[
              0.5259484891930979, 0.6249515173301565, 0.9561210914963576], 
             UndirectedEdge[90, 134] -> 
             RGBColor[
              0.3387736212750252, 0.46463798272782586`, 0.9429249564054306], 
             UndirectedEdge[1, 37] -> 
             RGBColor[
              0.5496127167377557, 0.6437072364180976, 0.9583493103043816], 
             UndirectedEdge[33, 295] -> 
             RGBColor[
              0.8759737184879801, 0.9039416817218939, 0.9880323493319954], 
             UndirectedEdge[28, 35] -> 
             RGBColor[
              0.2248219115083478, 0.35363246190073133`, 0.9361146473149633], 
             UndirectedEdge[21, 169] -> 
             RGBColor[
              0.33823987120783705`, 0.46593460012617627`, 0.9428265434669814],
              UndirectedEdge[100, 228] -> 
             RGBColor[
              0.8332617870229544, 0.6215832019337704, 0.5890075855789246], 
             UndirectedEdge[190, 250] -> 
             RGBColor[
              0.22535768471974588`, 0.35419559351589436`, 0.9361451588067469],
              UndirectedEdge[81, 180] -> 
             RGBColor[
              0.26493370488523493`, 0.3957924999744301, 0.9383989546076965], 
             UndirectedEdge[127, 141] -> 
             RGBColor[
              0.8658872706016187, 0.44359089015560293`, 0.2082267027178307], 
             UndirectedEdge[143, 185] -> 
             RGBColor[
              0.482410173529073, 0.5891453845161638, 0.9528206307321404], 
             UndirectedEdge[283, 295] -> 
             RGBColor[
              0.728003954304401, 0.7872192535932907, 0.973734730725687], 
             UndirectedEdge[26, 100] -> 
             RGBColor[
              0.9180076603888783, 0.6875620047068038, 0.5400502286834623], 
             UndirectedEdge[242, 294] -> 
             RGBColor[
              0.22516497885926012`, 0.35399304743826654`, 0.9361341844930751],
              UndirectedEdge[39, 228] -> 
             RGBColor[
              0.8419379772960242, 0.6739158098872126, 0.5967537548599042], 
             UndirectedEdge[39, 82] -> 
             RGBColor[
              0.9313046936732585, 0.7416283194518091, 0.4583415502549171], 
             UndirectedEdge[109, 258] -> 
             RGBColor[
              0.941467846616602, 0.9554926988601389, 0.9709728498600104], 
             UndirectedEdge[118, 199] -> 
             RGBColor[
              0.17892828448197629`, 0.3053953500719979, 0.9335010731493483], 
             UndirectedEdge[57, 115] -> 
             RGBColor[
              0.2343221600487206, 0.3636178254672108, 0.9366556724149793], 
             UndirectedEdge[96, 222] -> 
             RGBColor[
              0.4207992950730278, 0.5388969322298897, 0.948033936877215], 
             UndirectedEdge[6, 108] -> 
             RGBColor[
              0.32479673840417583`, 0.4554602283068521, 0.9419271416840078], 
             UndirectedEdge[1, 9] -> 
             RGBColor[
              0.46767615866135254`, 0.5777748250387542, 0.9514973709902432], 
             UndirectedEdge[180, 190] -> 
             RGBColor[
              0.23107912024585836`, 0.36020918501380295`, 0.9364709860958538],
              UndirectedEdge[144, 253] -> 
             RGBColor[
              0.30621743066907636`, 0.4385404910404173, 0.9407735752045145], 
             UndirectedEdge[53, 192] -> 
             RGBColor[
              0.8483576285442167, 0.36235245091138435`, 0.19353530461595575`],
              UndirectedEdge[85, 121] -> 
             RGBColor[
              0.9571178936575444, 0.9648142409538079, 0.8234596411130128], 
             UndirectedEdge[36, 278] -> 
             RGBColor[
              0.681251390228536, 0.7503140519946241, 0.9692773736229017], 
             UndirectedEdge[122, 207] -> 
             RGBColor[
              0.6848905103681076, 0.7534826553208219, 0.9694174076484823], 
             UndirectedEdge[226, 228] -> 
             RGBColor[
              0.4976351265701356, 0.5809234118204025, 0.9579150619705263], 
             UndirectedEdge[7, 143] -> 
             RGBColor[
              0.3957483991962868, 0.5171991053160931, 0.9464377159435866], 
             UndirectedEdge[133, 164] -> 
             RGBColor[
              0.36703566028493084`, 0.49232957401529565`, 0.9446081656098331],
              UndirectedEdge[7, 131] -> 
             RGBColor[
              0.359788981914124, 0.4860528654391481, 0.9441464136720313], 
             UndirectedEdge[111, 280] -> 
             RGBColor[
              0.2555363699026189, 0.38591530508224947`, 0.9378637902825477], 
             UndirectedEdge[135, 224] -> 
             RGBColor[
              0.9798102252026126, 0.9495170954171317, 0.5749562479700403], 
             UndirectedEdge[91, 102] -> 
             RGBColor[
              0.3289676178309032, 0.4560161547537128, 0.9423048264494448], 
             UndirectedEdge[200, 282] -> 
             RGBColor[
              0.9248264998510323, 0.7738160826625009, 0.5864939522963153], 
             UndirectedEdge[106, 194] -> 
             RGBColor[
              0.5862509789073218, 0.6747647734348481, 0.960720844348837], 
             UndirectedEdge[38, 259] -> 
             RGBColor[
              0.44110257276703263`, 0.5561854868751561, 0.949409740030642], 
             UndirectedEdge[36, 69] -> 
             RGBColor[
              0.8763046392583498, 0.8998097230462532, 0.7301395316538027], 
             UndirectedEdge[64, 153] -> 
             RGBColor[
              0.253568524812987, 0.38384697512446136`, 0.9377517244158591], 
             UndirectedEdge[159, 175] -> 
             RGBColor[
              0.2709524595475128, 0.4021185927355705, 0.9387417137817635], 
             UndirectedEdge[94, 200] -> 
             RGBColor[
              0.8739725410077492, 0.7339874771388775, 0.6066396220475212], 
             UndirectedEdge[88, 201] -> 
             RGBColor[
              0.41266709907445764`, 0.5304710926638055, 0.9478976499747094], 
             UndirectedEdge[121, 232] -> 
             RGBColor[
              0.9943533317427773, 0.9903306725005643, 0.626773191277452], 
             UndirectedEdge[140, 289] -> 
             RGBColor[
              0.3095286406957365, 0.4408775980939844, 0.9410040013062702], 
             UndirectedEdge[139, 244] -> 
             RGBColor[
              0.2489949569451404, 0.37903986531440326`, 0.9374912664917726], 
             UndirectedEdge[167, 174] -> 
             RGBColor[
              0.5731249742958058, 0.6609624837721939, 0.9611637427211077], 
             UndirectedEdge[185, 282] -> 
             RGBColor[
              0.7658636697865162, 0.8163200733980329, 0.9527715263482667], 
             UndirectedEdge[236, 249] -> 
             RGBColor[
              0.7208953090971567, 0.4244044295693752, 0.5644530380404611], 
             UndirectedEdge[137, 299] -> 
             RGBColor[
              0.9200253772401052, 0.6716173201462636, 0.46616820031546136`], 
             UndirectedEdge[201, 218] -> 
             RGBColor[
              0.2885778810548669, 0.4195006110479498, 0.9397873215672898], 
             UndirectedEdge[36, 109] -> 
             RGBColor[
              0.8403699639081523, 0.8760405078690783, 0.9845068533256267], 
             UndirectedEdge[4, 52] -> 
             RGBColor[
              0.6786643793088902, 0.3871223101534529, 0.5607452962818866], 
             UndirectedEdge[5, 191] -> 
             RGBColor[
              0.23242398209380136`, 0.36162272008515706`, 0.9365475739885493],
              UndirectedEdge[55, 134] -> 
             RGBColor[
              0.27534778812989436`, 0.40673836175558137`, 0.9389920212422243],
              UndirectedEdge[67, 69] -> 
             RGBColor[
              0.9526781701718614, 0.9602196098814508, 0.7375536853224871], 
             UndirectedEdge[232, 256] -> 
             RGBColor[
              0.9946722576480922, 0.9910128227636774, 0.6614863078884357], 
             UndirectedEdge[185, 237] -> 
             RGBColor[
              0.6034248054489583, 0.6889264668979879, 0.961922957584288], 
             UndirectedEdge[28, 211] -> 
             RGBColor[
              0.2328859592843117, 0.3621082874034291, 0.9365738829061148], 
             UndirectedEdge[85, 246] -> 
             RGBColor[
              0.759246790508393, 0.811987768878119, 0.9768800667488129], 
             UndirectedEdge[26, 127] -> 
             RGBColor[
              0.9093035421850235, 0.6206583380230588, 0.5317151552615555], 
             UndirectedEdge[91, 162] -> 
             RGBColor[
              0.27856959341816107`, 0.4101246833878033, 0.9391754982871572], 
             UndirectedEdge[112, 242] -> 
             RGBColor[
              0.24632291686669305`, 0.37623138177482907`, 0.937339097762234], 
             UndirectedEdge[85, 122] -> 
             RGBColor[
              0.7719092053781459, 0.8222676877046737, 0.9778768984313139], 
             UndirectedEdge[63, 131] -> 
             RGBColor[
              0.32467225096411007`, 0.4556365181084638, 0.9419088066284024], 
             UndirectedEdge[140, 222] -> 
             RGBColor[
              0.3821033463817397, 0.505380446388428, 0.94556826524409], 
             UndirectedEdge[121, 256] -> 
             RGBColor[
              0.9949290492403844, 0.9915620740139779, 0.6894364879754314], 
             UndirectedEdge[171, 198] -> 
             RGBColor[
              0.4413043319504303, 0.556360389684118, 0.9494225547381876], 
             UndirectedEdge[10, 117] -> 
             RGBColor[
              0.20745354842489078`, 0.3353772110821952, 0.935125544731551], 
             UndirectedEdge[18, 290] -> 
             RGBColor[
              0.7796647191738186, 0.8280942483803853, 0.9691424595790514], 
             UndirectedEdge[207, 240] -> 
             RGBColor[
              0.870260916353266, 0.8963751063904083, 0.8326021245961515], 
             UndirectedEdge[219, 264] -> 
             RGBColor[
              0.28444814998044265`, 0.4163034190567747, 0.9395102733868341], 
             UndirectedEdge[78, 118] -> 
             RGBColor[
              0.17948494456776543`, 0.30598043511645023`, 0.9335327741177293],
              UndirectedEdge[2, 208] -> 
             RGBColor[
              0.2583585282715436, 0.3888815724631647, 0.9380245080266488], 
             UndirectedEdge[34, 169] -> 
             RGBColor[
              0.3102621246711287, 0.4417016822785076, 0.9410438261974121], 
             UndirectedEdge[35, 275] -> 
             RGBColor[
              0.21950487592715945`, 0.34804392038537546`, 0.9358118500044639],
              UndirectedEdge[157, 284] -> 
             RGBColor[
              0.3008123283039969, 0.4300606298936609, 0.9405682387829533], 
             UndirectedEdge[30, 259] -> 
             RGBColor[
              0.46322962709906557`, 0.5751097053927338, 0.9508862795927249], 
             UndirectedEdge[62, 192] -> 
             RGBColor[
              0.9299174355595534, 0.7356028477535854, 0.4448740417030029], 
             UndirectedEdge[95, 245] -> 
             RGBColor[
              0.4565245648697137, 0.5688811135099974, 0.9505753636122101], 
             UndirectedEdge[129, 230] -> 
             RGBColor[
              0.2426308084736596, 0.3723507417605582, 0.9371288376512357], 
             UndirectedEdge[35, 92] -> 
             RGBColor[
              0.24366421330036392`, 0.37343691575507476`, 0.9371876885273311],
              UndirectedEdge[186, 279] -> 
             RGBColor[
              0.24438086405288187`, 0.3741901611342533, 0.9372285007274972], 
             UndirectedEdge[217, 233] -> 
             RGBColor[
              0.9005620992858752, 0.9194729557138646, 0.7896746116293041], 
             UndirectedEdge[28, 293] -> 
             RGBColor[
              0.21633697828784162`, 0.3447142591101412, 0.9356314429203892], 
             UndirectedEdge[24, 233] -> 
             RGBColor[
              0.9748626422338834, 0.9780993949460502, 0.7789636593832132], 
             UndirectedEdge[41, 229] -> 
             RGBColor[
              0.35168976097882576`, 0.47903772734367334`, 0.943630338475894], 
             UndirectedEdge[197, 214] -> 
             RGBColor[
              0.21169118846890916`, 0.33983123945035565`, 0.9353668720630313],
              UndirectedEdge[84, 144] -> 
             RGBColor[
              0.30816373722776935`, 0.4405861826365669, 0.9408844144837296], 
             UndirectedEdge[101, 205] -> 
             RGBColor[
              0.5380185348092877, 0.6358267098737893, 0.9567739363684693], 
             UndirectedEdge[7, 297] -> 
             RGBColor[
              0.5775728899214854, 0.6645401478372637, 0.9615635093646839], 
             UndirectedEdge[30, 47] -> 
             RGBColor[
              0.5531290988592262, 0.6480680925121483, 0.9579813085710855], 
             UndirectedEdge[140, 298] -> 
             RGBColor[
              0.3066630469664905, 0.4378656773954105, 0.9408408099826556], 
             UndirectedEdge[159, 252] -> 
             RGBColor[
              0.2739625179017606, 0.4052823549146075, 0.9389131321520556], 
             UndirectedEdge[26, 195] -> 
             RGBColor[
              0.9024893735730009, 0.5682816520833267, 0.52518989970318], 
             UndirectedEdge[43, 185] -> 
             RGBColor[
              0.4451220207260428, 0.5568482607152324, 0.9504446626081502], 
             UndirectedEdge[36, 95] -> 
             RGBColor[
              0.6241088885700935, 0.7039231949079366, 0.9647789065724686], 
             UndirectedEdge[6, 46] -> 
             RGBColor[
              0.29890559173213627`, 0.4314991069925552, 0.9403336033067247], 
             UndirectedEdge[148, 183] -> 
             RGBColor[
              0.2467014884994484, 0.37662928456368283`, 0.937360656856673], 
             UndirectedEdge[222, 261] -> 
             RGBColor[
              0.41838703187400994`, 0.5368075510907742, 0.9478802295992542], 
             UndirectedEdge[64, 145] -> 
             RGBColor[
              0.2514296244944172, 0.3815988552755316, 0.937629917206936], 
             UndirectedEdge[8, 247] -> 
             RGBColor[
              0.6154687668637716, 0.6985589182605833, 0.9629704988219563], 
             UndirectedEdge[122, 136] -> 
             RGBColor[
              0.8085502082780569, 0.8465126824966431, 0.7164898471021924], 
             UndirectedEdge[139, 206] -> 
             RGBColor[
              0.2460762386198535, 0.3759721072970965, 0.9373250498010044], 
             UndirectedEdge[65, 80] -> 
             RGBColor[
              0.27787319023653523`, 0.40939271948940265`, 0.9391358391561999],
              UndirectedEdge[171, 245] -> 
             RGBColor[
              0.4213779646314022, 0.5393981467165758, 0.9480708091897773], 
             UndirectedEdge[137, 232] -> 
             RGBColor[
              0.9198313733274753, 0.6705144142242014, 0.3950452840198946], 
             UndirectedEdge[64, 221] -> 
             RGBColor[
              0.26413437920159183`, 0.3949523580007457, 0.9383534341925093], 
             UndirectedEdge[140, 263] -> 
             RGBColor[
              0.2945287893227776, 0.42511180325549774`, 0.9401497819608717], 
             UndirectedEdge[200, 295] -> 
             RGBColor[
              0.8616403695892892, 0.7241541383976731, 0.6054633685285691], 
             UndirectedEdge[136, 232] -> 
             RGBColor[
              0.9935021049651632, 0.9885099844954769, 0.5341224096968956], 
             UndirectedEdge[45, 68] -> 
             RGBColor[
              0.8660950044608668, 0.48393636846669774`, 0.20994293256664392`],
              UndirectedEdge[224, 254] -> 
             RGBColor[
              0.9304233123934045, 0.7541309251793602, 0.28356918675006826`], 
             UndirectedEdge[148, 272] -> 
             RGBColor[
              0.23104689889957378`, 0.3601753183359065, 0.93646915113785], 
             UndirectedEdge[167, 185] -> 
             RGBColor[
              0.660998380157889, 0.7339582173045702, 0.9676238615993047], 
             UndirectedEdge[59, 137] -> 
             RGBColor[
              0.8391881810125934, 0.30222310839901756`, 0.1851599524353666], 
             UndirectedEdge[55, 97] -> 
             RGBColor[
              0.26708761639868417`, 0.39805639754094285`, 0.9385216166819608],
              UndirectedEdge[156, 202] -> 
             RGBColor[
              0.22791002753873152`, 0.3568782676465297, 0.9362905109544353], 
             UndirectedEdge[78, 176] -> 
             RGBColor[
              0.17949609924511575`, 0.30599215938959284`, 0.9335334093601024],
              UndirectedEdge[131, 143] -> 
             RGBColor[
              0.3607906299670138, 0.4869204426382663, 0.9442102378002388], 
             UndirectedEdge[230, 289] -> 
             RGBColor[
              0.27016772610159867`, 0.4012937881289406, 0.9386970243729278], 
             UndirectedEdge[35, 126] -> 
             RGBColor[
              0.2260848753293333, 0.35495991695311835`, 0.9361865712361809], 
             UndirectedEdge[147, 183] -> 
             RGBColor[
              0.24039105535964145`, 0.36999661922917565`, 0.9370012870248101],
              UndirectedEdge[66, 258] -> 
             RGBColor[
              0.9541114545413159, 0.9652969784492861, 0.9625615171988029], 
             UndirectedEdge[60, 232] -> 
             RGBColor[
              0.9600894947352094, 0.8672149974535253, 0.4291027093633025], 
             UndirectedEdge[39, 127] -> 
             RGBColor[
              0.8501524031963347, 0.3721425322398584, 0.1950971436579678], 
             UndirectedEdge[113, 258] -> 
             RGBColor[
              0.9605881616295711, 0.9701272959910724, 0.9515981414941335], 
             UndirectedEdge[45, 223] -> 
             RGBColor[
              0.872589282408941, 0.5134253678517513, 0.21536191727583626`], 
             UndirectedEdge[40, 80] -> 
             RGBColor[
              0.25252112623098183`, 0.38274609280586824`, 0.9376920766161012],
              UndirectedEdge[18, 198] -> 
             RGBColor[
              0.7053280385373079, 0.7677443822103661, 0.9632904037751118], 
             UndirectedEdge[13, 58] -> 
             RGBColor[
              0.4275257850964924, 0.5418851588163979, 0.949188660514906], 
             UndirectedEdge[16, 195] -> 
             RGBColor[
              0.9063070598041875, 0.5682974877338114, 0.34831639298626615`], 
             UndirectedEdge[17, 90] -> 
             RGBColor[
              0.3498844311553243, 0.4763161483780546, 0.9435577005911434], 
             UndirectedEdge[8, 273] -> 
             RGBColor[
              0.6348421879085798, 0.7142871342274307, 0.9644956454937833], 
             UndirectedEdge[85, 256] -> 
             RGBColor[
              0.9574368195628593, 0.965496391216921, 0.8581727577239964], 
             UndirectedEdge[149, 227] -> 
             RGBColor[
              0.27685707898321577`, 0.40832472213698934`, 0.9390779731235251],
              UndirectedEdge[182, 208] -> 
             RGBColor[
              0.2965714316502459, 0.42904575675219153`, 0.9402006763431414], 
             UndirectedEdge[82, 100] -> 
             RGBColor[
              0.9226285034001888, 0.6892957114983669, 0.45059538097393753`], 
             UndirectedEdge[227, 264] -> 
             RGBColor[
              0.2772132461146813, 0.4086990763744601, 0.9390982563147601], 
             UndirectedEdge[74, 259] -> 
             RGBColor[
              0.5512374616169957, 0.646558430162153, 0.9578145787092965], 
             UndirectedEdge[96, 105] -> 
             RGBColor[
              0.3473181215020726, 0.473441328714978, 0.9434180509343462], 
             UndirectedEdge[60, 100] -> 
             RGBColor[
              0.8881313902235266, 0.565681082313474, 0.22753422766752193`], 
             UndirectedEdge[73, 87] -> 
             RGBColor[
              0.3025587103322468, 0.4334652095438001, 0.9406102430960075], 
             UndirectedEdge[68, 223] -> 
             RGBColor[
              0.880860495472638, 0.5518971603270344, 0.22229941585693147`], 
             UndirectedEdge[162, 191] -> 
             RGBColor[
              0.26420786908525307`, 0.39502960052800135`, 0.9383576193326653],
              UndirectedEdge[87, 149] -> 
             RGBColor[
              0.2850281329082009, 0.41691301788689017`, 0.939543302556562], 
             UndirectedEdge[60, 256] -> 
             RGBColor[
              0.9606652122328164, 0.8684463989669389, 0.49176600606128196`], 
             UndirectedEdge[145, 169] -> 
             RGBColor[
              0.28111445342614677`, 0.4127994926096401, 0.939320424299829], 
             UndirectedEdge[144, 235] -> 
             RGBColor[
              0.27887432985742466`, 0.4098011584346488, 0.9392164260637837], 
             UndirectedEdge[36, 88] -> 
             RGBColor[
              0.6318962145275521, 0.7102452969352381, 0.9653919533977545], 
             UndirectedEdge[38, 123] -> 
             RGBColor[
              0.4270824703910924, 0.5443391028888234, 0.9484342952524883], 
             UndirectedEdge[183, 244] -> 
             RGBColor[
              0.24855034907625476`, 0.37857255425443737`, 0.937465946731378], 
             UndirectedEdge[2, 32] -> 
             RGBColor[
              0.24350738500413596`, 0.3732720792722509, 0.9371787573878676], 
             UndirectedEdge[106, 151] -> 
             RGBColor[
              0.5499711557200619, 0.645038448022178, 0.9579401200370031], 
             UndirectedEdge[164, 277] -> 
             RGBColor[
              0.36650966152605724`, 0.4918739803278257, 0.94457464943404], 
             UndirectedEdge[296, 299] -> 
             RGBColor[
              0.8453600637344856, 0.8773055132358333, 0.8557133788601069], 
             UndirectedEdge[75, 174] -> 
             RGBColor[
              0.5614179437120186, 0.6518168625034114, 0.9599968953209368], 
             UndirectedEdge[31, 66] -> 
             RGBColor[
              0.7826462994682315, 0.8305130082182347, 0.9693283290234715], 
             UndirectedEdge[2, 268] -> 
             RGBColor[
              0.2466368287086141, 0.37656132302384837`, 0.9373569745772405], 
             UndirectedEdge[46, 264] -> 
             RGBColor[
              0.29339971487327476`, 0.42571208132113636`, 0.9400200517648274],
              UndirectedEdge[71, 160] -> 
             RGBColor[
              0.6099082730566356, 0.6941900379787878, 0.9624333599040888], 
             UndirectedEdge[50, 114] -> 
             RGBColor[
              0.32843011888336315`, 0.4584906115476223, 0.9421629292736595], 
             UndirectedEdge[126, 197] -> 
             RGBColor[
              0.21821940668747852`, 0.34669281071101354`, 0.9357386444329454],
              UndirectedEdge[265, 269] -> 
             RGBColor[
              0.2247455605611441, 0.35355221221429056`, 0.9361102992414712], 
             UndirectedEdge[144, 257] -> 
             RGBColor[
              0.3535074058070181, 0.4806120799363681, 0.9437461571970662], 
             UndirectedEdge[86, 107] -> 
             RGBColor[
              0.9045073081884096, 0.5951795926664958, 0.26859915666912515`], 
             UndirectedEdge[149, 245] -> 
             RGBColor[
              0.3591757955739624, 0.4841536676462995, 0.9441574343329895], 
             UndirectedEdge[143, 283] -> 
             RGBColor[
              0.5077365883087008, 0.6097065089762495, 0.9548144188773069], 
             UndirectedEdge[66, 154] -> 
             RGBColor[
              0.8438279787518632, 0.8786689323302527, 0.9751799865903525], 
             UndirectedEdge[57, 159] -> 
             RGBColor[
              0.24722335585304894`, 0.3771778002406183, 0.937390376430427], 
             UndirectedEdge[7, 167] -> 
             RGBColor[
              0.5743366058251028, 0.6620119381044995, 0.9612409468107508], 
             UndirectedEdge[57, 89] -> 
             RGBColor[
              0.26259271630004477`, 0.3933319725441461, 0.9382656387709521], 
             UndirectedEdge[122, 256] -> 
             RGBColor[
              0.8097203609609858, 0.8490155207648438, 0.8438537452937325], 
             UndirectedEdge[39, 232] -> 
             RGBColor[
              0.9308146259118721, 0.7405801140636548, 0.40500069877565514`], 
             UndirectedEdge[72, 286] -> 
             RGBColor[
              0.6054217047226151, 0.6904029000986035, 0.9621791200575058], 
             UndirectedEdge[71, 299] -> 
             RGBColor[
              0.812040550004389, 0.8510805514465378, 0.8525260685636215], 
             UndirectedEdge[90, 158] -> 
             RGBColor[
              0.4035892626740157, 0.5239904671672448, 0.9469373288309841], 
             UndirectedEdge[52, 236] -> 
             RGBColor[
              0.7204593344779664, 0.42105333760098257`, 0.5640355482527617], 
             UndirectedEdge[17, 134] -> 
             RGBColor[
              0.2851115833841571, 0.4170007296281859, 0.9395480549377139], 
             UndirectedEdge[54, 72] -> 
             RGBColor[
              0.534606977221836, 0.6319372303906756, 0.9568737438527076], 
             UndirectedEdge[170, 192] -> 
             RGBColor[
              0.8434397887079927, 0.3245517789190093, 0.188825975634882], 
             UndirectedEdge[140, 198] -> 
             RGBColor[
              0.3961646850276139, 0.5172626963041967, 0.9465462963516883], 
             UndirectedEdge[19, 89] -> 
             RGBColor[
              0.28469980544749635`, 0.41656792490852634`, 0.9395246047933918],
              UndirectedEdge[239, 295] -> 
             RGBColor[
              0.6242095261484855, 0.7018088738432534, 0.9658801269946564], 
             UndirectedEdge[51, 69] -> 
             RGBColor[
              0.9933000659558078, 0.9895615584823135, 0.6199821278730931], 
             UndirectedEdge[186, 269] -> 
             RGBColor[
              0.2284972047762287, 0.3574954281523263, 0.93632394982946], 
             UndirectedEdge[37, 282] -> 
             RGBColor[
              0.8221799053423591, 0.8614527527728091, 0.9576065400232527], 
             UndirectedEdge[1, 239] -> 
             RGBColor[
              0.4148284678056251, 0.5337253017533699, 0.9476534810435313], 
             UndirectedEdge[59, 200] -> 
             RGBColor[
              0.8594030577293614, 0.41420745732297415`, 0.20281846065499215`],
              UndirectedEdge[145, 221] -> 
             RGBColor[
              0.2819086057959276, 0.4136341971024482, 0.9393656501024449], 
             UndirectedEdge[75, 297] -> 
             RGBColor[
              0.7454557140194038, 0.8010749365560057, 0.9752637169598848], 
             UndirectedEdge[142, 185] -> 
             RGBColor[
              0.6135470246958941, 0.696888857774001, 0.9628943539449815], 
             UndirectedEdge[36, 258] -> 
             RGBColor[
              0.8606691521172266, 0.8915543066994391, 0.9631366201381162], 
             UndirectedEdge[13, 289] -> 
             RGBColor[
              0.2985558278706446, 0.4311314829978179, 0.940313684772242], 
             UndirectedEdge[53, 170] -> 
             RGBColor[
              0.8268112796846933, 0.20708882120003286`, 0.1733078177460588], 
             UndirectedEdge[130, 226] -> 
             RGBColor[
              0.178927005110741, 0.3053940053717128, 0.9335010002910491], 
             UndirectedEdge[224, 249] -> 
             RGBColor[
              0.8940523406864429, 0.5263405979795888, 0.25076760006070237`], 
             UndirectedEdge[234, 271] -> 
             RGBColor[
              0.8973919728354314, 0.5348865558223752, 0.26558699931478663`], 
             UndirectedEdge[78, 266] -> 
             RGBColor[
              0.21383713709575333`, 0.3420867675181703, 0.9354890806626834], 
             UndirectedEdge[127, 232] -> 
             RGBColor[
              0.9134343174349477, 0.6213438394264674, 0.3889194560727688], 
             UndirectedEdge[57, 292] -> 
             RGBColor[
              0.2450572419916986, 0.37490107723278787`, 0.9372670194505013], 
             UndirectedEdge[52, 107] -> 
             RGBColor[
              0.8259275201506884, 0.20029585815577397`, 0.17246152861823205`],
              UndirectedEdge[26, 130] -> 
             RGBColor[
              0.5823809948253185, 0.6469022092217233, 0.9089577047840149], 
             UndirectedEdge[51, 58] -> 
             RGBColor[
              0.7712426526188537, 0.8181426903224094, 0.8569941031084208], 
             UndirectedEdge[192, 195] -> 
             RGBColor[
              0.8420649475314406, 0.3139841471767838, 0.18750942617155456`], 
             UndirectedEdge[118, 266] -> 
             RGBColor[
              0.21328176149194045`, 0.3415030325457159, 0.9354574528436509], 
             UndirectedEdge[171, 289] -> 
             RGBColor[
              0.35466828761855285`, 0.4799752914739057, 0.9438802596927696], 
             UndirectedEdge[1, 283] -> 
             RGBColor[
              0.5186228959615405, 0.619135681503407, 0.955508084774562], 
             UndirectedEdge[44, 59] -> 
             RGBColor[
              0.8989327098919131, 0.5734920759622608, 0.24889953887676536`], 
             UndirectedEdge[62, 127] -> 
             RGBColor[
              0.9138104141355006, 0.6221482722397406, 0.4298552609281541], 
             UndirectedEdge[46, 219] -> 
             RGBColor[
              0.2831865614508789, 0.4149774095228705, 0.9394384277864284], 
             UndirectedEdge[55, 252] -> 
             RGBColor[
              0.2886130512396545, 0.4206809943501981, 0.9397474583521269], 
             UndirectedEdge[55, 144] -> 
             RGBColor[
              0.2962021466118664, 0.42801379249060423`, 0.9402032195937415], 
             UndirectedEdge[160, 296] -> 
             RGBColor[
              0.6432277867867322, 0.7204149997680831, 0.9656206702005743], 
             UndirectedEdge[154, 179] -> 
             RGBColor[
              0.8674233288276321, 0.8946955574709121, 0.8648978949263142], 
             UndirectedEdge[6, 145] -> 
             RGBColor[
              0.2874384541046572, 0.41944641828755624`, 0.9396805667829495], 
             UndirectedEdge[132, 243] -> 
             RGBColor[
              0.21243933131542342`, 0.34061758501703826`, 0.935409477691362], 
             UndirectedEdge[53, 59] -> 
             RGBColor[
              0.8322696375208192, 0.249044151396152, 0.17853474737426642`], 
             UndirectedEdge[4, 228] -> 
             RGBColor[
              0.6779819914219037, 0.7467901325313183, 0.9696145955916023], 
             UndirectedEdge[71, 98] -> 
             RGBColor[
              0.5262018737865255, 0.625404972246536, 0.9560725859325541], 
             UndirectedEdge[201, 259] -> 
             RGBColor[
              0.3926869440225089, 0.5142503026969059, 0.9463247389793005], 
             UndirectedEdge[34, 187] -> 
             RGBColor[
              0.34571434459052375`, 0.47386212200128636`, 0.9432495902274847],
              UndirectedEdge[18, 260] -> 
             RGBColor[
              0.8977772500782942, 0.9210512580678571, 0.980544009200409], 
             UndirectedEdge[263, 289] -> 
             RGBColor[
              0.27598341660935993`, 0.40740644758867306`, 0.9390282193438018],
              UndirectedEdge[173, 209] -> 
             RGBColor[
              0.2611649721580388, 0.3918313229266909, 0.938184330854223], 
             UndirectedEdge[4, 199] -> 
             RGBColor[
              0.3592738699625091, 0.4712607260826286, 0.9452005339121252], 
             UndirectedEdge[253, 292] -> 
             RGBColor[
              0.26989343961389634`, 0.40100549563959764`, 0.9386814041632237],
              UndirectedEdge[128, 209] -> 
             RGBColor[
              0.25220846656924684`, 0.38241746767761725`, 0.9376742711109041],
              UndirectedEdge[44, 137] -> 
             RGBColor[
              0.9053107353837854, 0.6225163747613823, 0.25500714329073165`], 
             UndirectedEdge[129, 263] -> 
             RGBColor[
              0.24844649898142085`, 0.37846340122029065`, 0.9374600326221096],
              UndirectedEdge[73, 289] -> 
             RGBColor[
              0.309996695985159, 0.44128300406053933`, 0.9410338253754271], 
             UndirectedEdge[128, 276] -> 
             RGBColor[
              0.235521079118485, 0.3648779654253926, 0.9367239490823606], 
             UndirectedEdge[96, 196] -> 
             RGBColor[
              0.34319916551880214`, 0.4691120448196677, 0.9431834824845483], 
             UndirectedEdge[24, 224] -> 
             RGBColor[
              0.9625807494214099, 0.9376482057938698, 0.6480446128648567], 
             UndirectedEdge[88, 278] -> 
             RGBColor[
              0.553576335347311, 0.6484572332214837, 0.9579987034169237], 
             UndirectedEdge[158, 253] -> 
             RGBColor[
              0.35017871358609476`, 0.47661754474481344`, 0.9435747492785509],
              UndirectedEdge[67, 110] -> 
             RGBColor[
              0.9526321539767644, 0.9621364418592473, 0.8790329410814011], 
             UndirectedEdge[155, 275] -> 
             RGBColor[
              0.21254067958734837`, 0.340724108476683, 0.9354152493255168], 
             UndirectedEdge[101, 108] -> 
             RGBColor[
              0.44525533808141193`, 0.5575469670447641, 0.9502920083081179], 
             UndirectedEdge[102, 210] -> 
             RGBColor[
              0.3819399405336581, 0.5052389124558365, 0.9455578531679444], 
             UndirectedEdge[176, 199] -> 
             RGBColor[
              0.17893943915932659`, 0.3054070743451405, 0.9335017083917216], 
             UndirectedEdge[62, 226] -> 
             RGBColor[
              0.5868878718865363, 0.6483921488101179, 0.8070978107416625], 
             UndirectedEdge[69, 113] -> 
             RGBColor[
              0.9762236487706943, 0.9783827123378863, 0.71860105300982], 
             UndirectedEdge[51, 258] -> 
             RGBColor[
              0.9776645788146846, 0.9813061421354996, 0.8529792163574066], 
             UndirectedEdge[30, 74] -> 
             RGBColor[
              0.5502062391736314, 0.6457212373265883, 0.9577333971010626], 
             UndirectedEdge[118, 228] -> 
             RGBColor[
              0.49763640594137093`, 0.5809247565206876, 0.9579151348288255], 
             UndirectedEdge[71, 121] -> 
             RGBColor[
              0.8121033376840514, 0.8505268967747761, 0.8093533323550504], 
             UndirectedEdge[1, 20] -> 
             RGBColor[
              0.6422142592503285, 0.7164194344925677, 0.9674804697406698], 
             UndirectedEdge[126, 293] -> 
             RGBColor[
              0.21759994210882713`, 0.34604171416252816`, 0.9357033668416068],
              UndirectedEdge[112, 159] -> 
             RGBColor[
              0.24980358255219737`, 0.3798897820972448, 0.9375373165238401], 
             UndirectedEdge[17, 159] -> 
             RGBColor[
              0.2718080646722995, 0.4030178879702195, 0.9387904392278659], 
             UndirectedEdge[139, 172] -> 
             RGBColor[
              0.26248705403553485`, 0.3932209148047717, 0.9382596214613016], 
             UndirectedEdge[47, 233] -> 
             RGBColor[
              0.8190741460647206, 0.8558139473261162, 0.781552654000438], 
             UndirectedEdge[98, 182] -> 
             RGBColor[
              0.3649951509133196, 0.4904176871542194, 0.9444834370172861], 
             UndirectedEdge[84, 159] -> 
             RGBColor[
              0.27400586003393973`, 0.4053279102435776, 0.9389156004223643], 
             UndirectedEdge[118, 176] -> 
             RGBColor[
              0.17894072364130287`, 0.30540842441713845`, 0.9335017815410699],
              UndirectedEdge[18, 278] -> 
             RGBColor[
              0.7746661157384185, 0.8240361569270088, 0.968748951206129], 
             UndirectedEdge[155, 197] -> 
             RGBColor[
              0.21140151230331092`, 0.3395267714337822, 0.9353503754339378], 
             UndirectedEdge[72, 215] -> 
             RGBColor[
              0.8234553846620669, 0.8600796725778928, 0.8483727211925696], 
             UndirectedEdge[162, 239] -> 
             RGBColor[
              0.34783050852175984`, 0.47345580113907954`, 0.9434664197100019],
              UndirectedEdge[139, 272] -> 
             RGBColor[
              0.23937950956716447`, 0.3689334204655748, 0.9369436809883765], 
             UndirectedEdge[9, 75] -> 
             RGBColor[
              0.6236710270535416, 0.7040128640312203, 0.9644400885599815], 
             UndirectedEdge[18, 254] -> 
             RGBColor[
              0.918861315886804, 0.779473166025562, 0.6033212282319205], 
             UndirectedEdge[25, 244] -> 
             RGBColor[
              0.2471607788887478, 0.37711202788352904`, 0.9373868127648843], 
             UndirectedEdge[30, 257] -> 
             RGBColor[
              0.42675186290096767`, 0.5438116234909512, 0.9484798524617939], 
             UndirectedEdge[29, 270] -> 
             RGBColor[
              0.2355391750470839, 0.3648969853936982, 0.9367249796187237], 
             UndirectedEdge[73, 298] -> 
             RGBColor[
              0.307131102255913, 0.43827108336196546`, 0.9408706340518126], 
             UndirectedEdge[73, 96] -> 
             RGBColor[
              0.3672380173898648, 0.4925048455688256, 0.9446210596256222], 
             UndirectedEdge[108, 205] -> 
             RGBColor[
              0.436683616415666, 0.5505880572448512, 0.9496172109793394], 
             UndirectedEdge[9, 43] -> 
             RGBColor[
              0.41950169820548255`, 0.5360485287106651, 0.948427736968998], 
             UndirectedEdge[151, 251] -> 
             RGBColor[
              0.36499365332834144`, 0.4885238594535514, 0.944552636407374], 
             UndirectedEdge[209, 279] -> 
             RGBColor[
              0.2619744678088157, 0.39268215418064606`, 0.9382304304339932], 
             UndirectedEdge[53, 68] -> 
             RGBColor[
              0.8530476685227406, 0.3836488270671944, 0.19744878893743584`], 
             UndirectedEdge[282, 295] -> 
             RGBColor[
              0.9004709095023198, 0.9227541160141217, 0.9653727475363004], 
             UndirectedEdge[35, 197] -> 
             RGBColor[
              0.218365708643122, 0.3468465833424746, 0.9357469761128849], 
             UndirectedEdge[116, 168] -> 
             RGBColor[
              0.35414043439259346`, 0.4811603774802517, 0.9437864932187738], 
             UndirectedEdge[27, 152] -> 
             RGBColor[
              0.2558672975304459, 0.3862631310011191, 0.9378826361213889], 
             UndirectedEdge[114, 231] -> 
             RGBColor[
              0.37476526938347776`, 0.4986237900384425, 0.945115364090962], 
             UndirectedEdge[83, 155] -> 
             RGBColor[
              0.21429563561346426`, 0.34256867853076955`, 0.9355151914749793],
              UndirectedEdge[62, 199] -> 
             RGBColor[
              0.5868878667757954, 0.648392143438405, 0.8070978104506135], 
             UndirectedEdge[96, 278] -> 
             RGBColor[
              0.5041987109200126, 0.6070709568623011, 0.9544705154158305], 
             UndirectedEdge[2, 178] -> 
             RGBColor[
              0.25390682555337085`, 0.3842025506521106, 0.9377709901425528], 
             UndirectedEdge[6, 213] -> 
             RGBColor[
              0.3667758904705204, 0.4918204598931879, 0.9446020161329686], 
             UndirectedEdge[79, 93] -> 
             RGBColor[
              0.46307011169266854`, 0.5733948534802826, 0.9513117589171669], 
             UndirectedEdge[270, 272] -> 
             RGBColor[
              0.22576785330449248`, 0.35462670670465335`, 0.9361685173008583],
              UndirectedEdge[161, 186] -> 
             RGBColor[
              0.22312007554742067`, 0.3518437244031648, 0.9360177302746292], 
             UndirectedEdge[189, 275] -> 
             RGBColor[
              0.22231351200262228`, 0.3509959749784993, 0.9359717976739568], 
             UndirectedEdge[260, 261] -> 
             RGBColor[
              0.6248975820608704, 0.7019966768640338, 0.9661118661321497], 
             UndirectedEdge[195, 200] -> 
             RGBColor[
              0.8525698587166832, 0.36168449538462955`, 0.19627498156345707`],
              UndirectedEdge[66, 110] -> 
             RGBColor[
              0.969700925487342, 0.9754692267738965, 0.8710436844734033], 
             UndirectedEdge[63, 172] -> 
             RGBColor[
              0.29700434513925705`, 0.4280429826559164, 0.940278707091565], 
             UndirectedEdge[4, 236] -> 
             RGBColor[
              0.5814156950940945, 0.671058479612787, 0.9601903197951254], 
             UndirectedEdge[143, 167] -> 
             RGBColor[
              0.5753382538779925, 0.6628795153036178, 0.9613047709389584], 
             UndirectedEdge[135, 249] -> 
             RGBColor[
              0.9043378524473125, 0.5669958495159765, 0.4896141522242598], 
             UndirectedEdge[135, 288] -> 
             RGBColor[
              0.9259984255937815, 0.7279896925534243, 0.5101410217698862], 
             UndirectedEdge[83, 214] -> 
             RGBColor[
              0.21458531177906248`, 0.342873146547343, 0.9355316881040727], 
             UndirectedEdge[36, 290] -> 
             RGBColor[
              0.6862499936639361, 0.7543721434480005, 0.9696708819958241], 
             UndirectedEdge[79, 119] -> 
             RGBColor[
              0.3385777508483834, 0.465228690511853, 0.9428846351776731], 
             UndirectedEdge[145, 264] -> 
             RGBColor[
              0.28193257724579573`, 0.4136593926161374, 0.9393670152410523], 
             UndirectedEdge[54, 238] -> 
             RGBColor[
              0.34796050319161576`, 0.47301253149465217`, 0.9434950557775005],
              UndirectedEdge[177, 273] -> 
             RGBColor[
              0.5185213619952923, 0.6190718502597115, 0.9554949527990644], 
             UndirectedEdge[98, 208] -> 
             RGBColor[
              0.3543834762769441, 0.47926414429235664`, 0.9438791178453103], 
             UndirectedEdge[125, 170] -> 
             RGBColor[
              0.9072593029227105, 0.5779612249611302, 0.303635751806013], 
             UndirectedEdge[22, 217] -> 
             RGBColor[
              0.812207338591908, 0.8532218130031827, 0.981916895067874], 
             UndirectedEdge[78, 236] -> 
             RGBColor[
              0.4016254852173745, 0.5057768385746106, 0.9485224868513811], 
             UndirectedEdge[86, 240] -> 
             RGBColor[
              0.984900576757397, 0.9592281782774306, 0.5233965503688487], 
             UndirectedEdge[59, 170] -> 
             RGBColor[
              0.8273517976845952, 0.21124347940377694`, 0.17382541839319265`],
              UndirectedEdge[95, 109] -> 
             RGBColor[
              0.7049075830694689, 0.7678615870686365, 0.9726151362943627], 
             UndirectedEdge[30, 252] -> 
             RGBColor[
              0.38136485218953986`, 0.5037401708621798, 0.9456156414781487], 
             UndirectedEdge[116, 119] -> 
             RGBColor[
              0.30231628529617693`, 0.4338208316047836, 0.9405740866574415], 
             UndirectedEdge[6, 231] -> 
             RGBColor[
              0.3753962033450712, 0.49928694163560083`, 0.9451512948466916], 
             UndirectedEdge[214, 275] -> 
             RGBColor[
              0.21283035575294662`, 0.34102857649325646`, 0.9354317459546102],
              UndirectedEdge[157, 257] -> 
             RGBColor[
              0.3686428791962128, 0.49372166625507674`, 0.944710576177652], 
             UndirectedEdge[128, 173] -> 
             RGBColor[
              0.24821711809960986`, 0.3782223073699194, 0.9374469697202291], 
             UndirectedEdge[14, 113] -> 
             RGBColor[
              0.8910534941556458, 0.5723590692569638, 0.5614811576965728], 
             UndirectedEdge[213, 231] -> 
             RGBColor[
              0.43649903669503015`, 0.5524952593309104, 0.9490343105306326], 
             UndirectedEdge[29, 148] -> 
             RGBColor[
              0.2408182206421652, 0.3704455970249514, 0.9370256134557156], 
             UndirectedEdge[109, 154] -> 
             RGBColor[
              0.8311843708271494, 0.8688646527411055, 0.9835913192515602], 
             UndirectedEdge[74, 123] -> 
             RGBColor[
              0.5372173592410554, 0.6347120461758202, 0.9568391339311428], 
             UndirectedEdge[189, 216] -> 
             RGBColor[
              0.24534319825395978`, 0.3752016353950986, 0.9372833042366027], 
             UndirectedEdge[29, 162] -> 
             RGBColor[
              0.2636748497853562, 0.39446936344843425`, 0.9383272646720675], 
             UndirectedEdge[73, 140] -> 
             RGBColor[
              0.3285420686985767, 0.45898835972736407`, 0.9421553879924971], 
             UndirectedEdge[9, 295] -> 
             RGBColor[
              0.677057217004213, 0.7458583971286377, 0.9697240169413682], 
             UndirectedEdge[169, 221] -> 
             RGBColor[
              0.2938192081333214, 0.4261529953348542, 0.9400439412854023], 
             UndirectedEdge[22, 61] -> 
             RGBColor[
              0.6921091843567939, 0.7582433580431021, 0.9707375877325777], 
             UndirectedEdge[11, 143] -> 
             RGBColor[
              0.3701279239778581, 0.49500793740441695`, 0.9448052019179649], 
             UndirectedEdge[100, 299] -> 
             RGBColor[
              0.9223324395514323, 0.6893504120322749, 0.46837744579024243`], 
             UndirectedEdge[181, 232] -> 
             RGBColor[
              0.8539568089581072, 0.8830700073511788, 0.7854666422842203], 
             UndirectedEdge[49, 292] -> 
             RGBColor[
              0.23980801296623738`, 0.36938380470668514`, 0.9369680836230397],
              UndirectedEdge[4, 39] -> 
             RGBColor[
              0.7035767257991387, 0.5642531295211515, 0.5840392270925523], 
             UndirectedEdge[33, 75] -> 
             RGBColor[
              0.8225875285373088, 0.8620961486244765, 0.9827484209506085], 
             UndirectedEdge[223, 271] -> 
             RGBColor[
              0.9324098595457874, 0.7585161356784191, 0.29733719959784854`], 
             UndirectedEdge[21, 34] -> 
             RGBColor[
              0.3554769401154252, 0.48231799156263766`, 0.943871654181607], 
             UndirectedEdge[51, 165] -> 
             RGBColor[
              0.986911243979133, 0.9683407522697562, 0.5670857457477134], 
             UndirectedEdge[36, 138] -> 
             RGBColor[
              0.7331275863556836, 0.791444109527867, 0.9740349644072682], 
             UndirectedEdge[50, 205] -> 
             RGBColor[
              0.44094793085644673`, 0.5542815920827796, 0.9498889293247207], 
             UndirectedEdge[237, 283] -> 
             RGBColor[
              0.6287512202285861, 0.7094875913580734, 0.9639167457294545], 
             UndirectedEdge[140, 245] -> 
             RGBColor[
              0.37623831770858585`, 0.5003004533366545, 0.945194550803278], 
             UndirectedEdge[19, 49] -> 
             RGBColor[
              0.26391083574794544`, 0.39471739965748975`, 0.9383407037235271],
              UndirectedEdge[235, 292] -> 
             RGBColor[
              0.24255033880224458`, 0.3722661630338292, 0.9371242550224929], 
             UndirectedEdge[15, 115] -> 
             RGBColor[
              0.230257062183032, 0.3593451498682808, 0.9364241711053016], 
             UndirectedEdge[69, 110] -> 
             RGBColor[
              0.9929919929128255, 0.9894341623619243, 0.625087695462787], 
             UndirectedEdge[34, 50] -> 
             RGBColor[
              0.33997412107403424`, 0.46889022890332593`, 0.9428838282608942],
              UndirectedEdge[126, 275] -> 
             RGBColor[
              0.21935857397151598`, 0.34789014775391436`, 0.9358035183245244],
              UndirectedEdge[59, 225] -> 
             RGBColor[
              0.8968865048957325, 0.5665897460383628, 0.24095041885999358`], 
             UndirectedEdge[82, 228] -> 
             RGBColor[
              0.9057099592960236, 0.9241653224619759, 0.8439169187539672], 
             UndirectedEdge[19, 280] -> 
             RGBColor[
              0.2796627567223554, 0.4112736673310683, 0.939237752320141], 
             UndirectedEdge[194, 283] -> 
             RGBColor[
              0.5672781592829315, 0.6595809911525545, 0.9590773611885706], 
             UndirectedEdge[63, 283] -> 
             RGBColor[
              0.4716182093057971, 0.5784225844464469, 0.9525129877054703], 
             UndirectedEdge[36, 245] -> 
             RGBColor[
              0.5919869457083973, 0.6770600343104392, 0.9624670806434741], 
             UndirectedEdge[3, 55] -> 
             RGBColor[
              0.327009852931445, 0.45469787926428074`, 0.9421662593982401], 
             UndirectedEdge[137, 192] -> 
             RGBColor[
              0.8552761720359909, 0.4155314079142499, 0.20016050967705595`], 
             UndirectedEdge[54, 251] -> 
             RGBColor[
              0.3520600889143901, 0.4773214560180356, 0.9437285211196189], 
             UndirectedEdge[252, 292] -> 
             RGBColor[
              0.2717964040404102, 0.4030056319067771, 0.9387897751721301], 
             UndirectedEdge[100, 121] -> 
             RGBColor[
              0.9223952272310946, 0.6887967573605129, 0.4252047095816714], 
             UndirectedEdge[142, 239] -> 
             RGBColor[
              0.5350790113196064, 0.6320396024840493, 0.9570335383591173], 
             UndirectedEdge[85, 299] -> 
             RGBColor[
              0.9570551059778822, 0.9653678956255696, 0.8666323773215838], 
             UndirectedEdge[120, 130] -> 
             RGBColor[
              0.18442078734008566`, 0.31116831882066576`, 0.9338138630616879],
              UndirectedEdge[9, 297] -> 
             RGBColor[
              0.6386143417337113, 0.7156866950327669, 0.9659294985140855], 
             UndirectedEdge[237, 239] -> 
             RGBColor[
              0.5249567920726707, 0.6240772116080362, 0.9560621419984239], 
             UndirectedEdge[169, 213] -> 
             RGBColor[
              0.36045188979201, 0.48517353421527176`, 0.944241873649848], 
             UndirectedEdge[46, 50] -> 
             RGBColor[
              0.32229358745653136`, 0.4520407279394575, 0.9418134628870861], 
             UndirectedEdge[105, 171] -> 
             RGBColor[
              0.3537618197336009, 0.4790225362534377, 0.9438286376877205], 
             UndirectedEdge[34, 114] -> 
             RGBColor[
              0.31595519138804573`, 0.44768545635926527`, 0.9413680379248031],
              UndirectedEdge[60, 240] -> 
             RGBColor[
              0.9605080040332614, 0.868110146524278, 0.47465486371626864`], 
             UndirectedEdge[19, 84] -> 
             RGBColor[
              0.2959425689542974, 0.42838478218655185`, 0.940164863542926], 
             UndirectedEdge[19, 48] -> 
             RGBColor[
              0.3524750293077462, 0.47810184855613913`, 0.9437395461742546], 
             UndirectedEdge[5, 77] -> 
             RGBColor[
              0.23349568981372465`, 0.3627491528489905, 0.9366086061577494]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.26920385108875294`, 0.4002806943772341, 0.9386421331168716], 
             160 -> RGBColor[
              0.5902199940802382, 0.6782062061588879, 0.9608834264625246], 
             245 -> RGBColor[
              0.4244026220080174, 0.5420179529125, 0.9482635376832157], 155 -> 
             RGBColor[
              0.21230278460535462`, 0.3404740657671945, 0.9354017015582263], 
             213 -> RGBColor[
              0.42787872382047937`, 0.5450287775884974, 0.9484850318169096], 
             27 -> RGBColor[
              0.2584384877012701, 0.38896561489352793`, 0.9380290615978824], 
             19 -> RGBColor[
              0.2912671539208582, 0.4234706245479727, 0.9398986055734284], 
             164 -> RGBColor[
              0.38392426951059677`, 0.5069576384803866, 0.9456842928556817], 
             190 -> RGBColor[
              0.22813210557574862`, 0.35711168574399543`, 0.9363031579701084],
              103 -> RGBColor[
              0.2788168781365947, 0.4103845953056338, 0.9391895807860471], 
             138 -> RGBColor[
              0.7066839033025902, 0.7707861033473555, 0.971399305210804], 291 -> 
             RGBColor[
              0.8179080138731872, 0.1386544187368418, 0.16478204035016009`], 
             28 -> RGBColor[
              0.22341264573171882`, 0.35215123421688327`, 0.9360343917138061],
              114 -> RGBColor[
              0.3044111891973746, 0.4372858390035616, 0.9406471389375684], 
             195 -> RGBColor[
              0.8191437574953648, 0.1481528857232069, 0.16596538983833015`], 
             93 -> RGBColor[
              0.5312094509757161, 0.6302987888719648, 0.9562379003465947], 34 -> 
             RGBColor[
              0.3274991935787168, 0.458085073714969, 0.9420889369120379], 161 -> 
             RGBColor[
              0.21627103797903324`, 0.3446449516647265, 0.9356276877173526], 
             22 -> RGBColor[
              0.8173789776787558, 0.8572619367637411, 0.982432355720336], 124 -> 
             RGBColor[
              0.9476938047146304, 0.9605107057164812, 0.973424924364235], 84 -> 
             RGBColor[
              0.30061798398773654`, 0.43329893982513096`, 0.9404311215124237],
              46 -> RGBColor[
              0.29213812634371106`, 0.4243860717872321, 0.9399482061644217], 
             241 -> RGBColor[
              0.2790754121939759, 0.4106563309919474, 0.9392043039181481], 
             185 -> RGBColor[
              0.5680702998089695, 0.6602240865171163, 0.9591397213924867], 
             121 -> RGBColor[
              0.9946101233350695, 0.9908799237508646, 0.6547233713644478], 
             126 -> RGBColor[
              0.22593857337368983`, 0.3548061443216573, 0.9361782395562414], 
             236 -> RGBColor[
              0.6232106502631707, 0.7049895070603167, 0.9634805717660004], 78 -> 
             RGBColor[
              0.1800403201715783, 0.3065641700889047, 0.9335644019367618], 
             254 -> RGBColor[
              0.8913219113450659, 0.5994000064779764, 0.23102867769365362`], 
             290 -> RGBColor[
              0.6129287179190951, 0.6966421711876226, 0.9626711403879157], 
             251 -> RGBColor[
              0.2867137638335649, 0.4186847228646212, 0.9396392967440941], 
             165 -> RGBColor[
              0.9802603651545728, 0.9450757179590131, 0.3778156754531135], 
             100 -> RGBColor[
              0.8501803311271197, 0.38671359097016134`, 0.19568604779889498`],
              235 -> RGBColor[
              0.24203916924704705`, 0.37172889142129484`, 0.937095144672532], 
             70 -> RGBColor[
              0.26423372362278924`, 0.39505677528622424`, 0.9383590917103296],
              234 -> RGBColor[0.817319, 0.134127, 0.164218], 257 -> 
             RGBColor[
              0.39130532114623406`, 0.5133507344247334, 0.9461546069390968], 
             135 -> 
             RGBColor[
              0.9900957369634822, 0.9901723469535194, 0.8138028001335977], 
             265 -> RGBColor[
              0.22246582468563886`, 0.3511560652655316, 0.9359804716559281], 
             111 -> RGBColor[
              0.24301438028138522`, 0.37275390005033504`, 0.937150681498242], 
             182 -> RGBColor[
              0.3071831062866214, 0.4401992996140543, 0.9408049955151171], 
             188 -> RGBColor[
              0.20571498311483435`, 0.33354986870991854`, 0.9350265360091202],
              154 -> RGBColor[
              0.7412000832467709, 0.797750405452433, 0.9748395554555993], 269 -> 
             RGBColor[
              0.2270252964366493, 0.35594835916304945`, 0.9362401268270142], 
             208 -> RGBColor[
              0.28595975701387044`, 0.41789221389032877`, 0.9395963571711656],
              86 -> RGBColor[
              0.9748675947682047, 0.926884637163092, 0.35686578084130904`], 
             119 -> RGBColor[
              0.28222472928714576`, 0.41396646293510553`, 0.9393836528676069],
              140 -> RGBColor[
              0.3280740134091542, 0.4585829537608091, 0.9421255639233401], 85 -> 
             RGBColor[
              0.9196256639800194, 0.938748558156751, 0.9921959108615778], 242 -> 
             RGBColor[
              0.24043240470913427`, 0.3700400800171928, 0.9370036418090929], 
             117 -> RGBColor[
              0.20347429876271564`, 0.33119476738824843`, 0.9348989323500625],
              47 -> RGBColor[
              0.6440597930627512, 0.7218636724671273, 0.9651575191576801], 81 -> 
             RGBColor[
              0.29584127485450173`, 0.42827831566524976`, 0.9401590949937939],
              275 -> RGBColor[
              0.21277857456934213`, 0.34097415118617147`, 0.9354287970928072],
              23 -> RGBColor[
              0.2963741173821658, 0.42883836694599214`, 0.9401894395874745], 
             110 -> RGBColor[
              0.9929459767177286, 0.9913509943397207, 0.7665669512217009], 6 -> 
             RGBColor[
              0.3056730571205615, 0.43861214219787836`, 0.9407190004490276], 
             218 -> RGBColor[
              0.2560427236071457, 0.38644751493038626`, 0.9378926263769374], 
             108 -> RGBColor[
              0.3439204196877902, 0.4723083144158259, 0.943135282918988], 297 -> 
             RGBColor[
              0.7603990286995737, 0.8127487675575523, 0.9767531269139887], 
             157 -> RGBColor[
              0.34598043724619154`, 0.47409259808542004`, 0.9432665454162072],
              270 -> 
             RGBColor[
              0.22825539451058077`, 0.357241270231474, 0.9363101790925575], 
             33 -> RGBColor[
              0.9146626577353835, 0.9347911916944939, 0.9917225348954364], 
             252 -> RGBColor[
              0.30053129972337833`, 0.4332078291671907, 0.9404261849718064], 
             260 -> RGBColor[
              0.8491537797280463, 0.8825561905625664, 0.9854742396306309], 
             159 -> RGBColor[
              0.2473937360801429, 0.37735688066202433`, 0.937400079332305], 
             183 -> RGBColor[
              0.25458949129815345`, 0.38492007563338526`, 0.9378098669468048],
              99 -> RGBColor[
              0.3674883934084197, 0.4927217086918333, 0.9446370133641255], 17 -> 
             RGBColor[
              0.29622239326445615`, 0.42867889527841463`, 0.9401807991234267],
              277 -> RGBColor[
              0.34909505354151776`, 0.4767903221752649, 0.9434650060123984], 
             104 -> RGBColor[
              0.28507184392659923`, 0.4169589609386654, 0.9395457918343952], 
             79 -> RGBColor[
              0.39493077240962093`, 0.5164909180886005, 0.9463856174877392], 
             191 -> RGBColor[
              0.24388899418338073`, 0.37367317471505657`, 0.9372004894660854],
              50 -> RGBColor[
              0.35244904856935166`, 0.4796953840916829, 0.9436787196097506], 
             225 -> RGBColor[
              0.9609628542707439, 0.8799806824768295, 0.3028484896985869], 61 -> 
             RGBColor[
              0.5668393910348319, 0.659224779322463, 0.9590428197448192], 196 -> 
             RGBColor[
              0.2809324202458739, 0.4126081641956031, 0.9393100577795065], 1 -> 
             RGBColor[
              0.41852266255485593`, 0.5369250275695268, 0.9478888718663042], 
             263 -> RGBColor[
              0.26098356523640104`, 0.3916406527501864, 0.9381739999984032], 
             201 -> RGBColor[
              0.32111303850258816`, 0.4525537071655133, 0.9416820167576422], 
             293 -> RGBColor[
              0.20926131084396443`, 0.33727728400339907`, 0.9352284941269724],
              184 -> RGBColor[
              0.23743710807503443`, 0.3668918333419784, 0.9368330640969252], 
             106 -> RGBColor[
              0.6566687686170058, 0.7317139000018745, 0.9664142640033524], 
             206 -> RGBColor[
              0.23667377020378227`, 0.366089516840876, 0.9367895931344146], 
             247 -> RGBColor[
              0.5790882470358998, 0.6691689524288044, 0.9600070945582612], 
             220 -> 
             RGBColor[
              0.25719173910326026`, 0.38765520306859286`, 0.937958061109625], 
             107 -> RGBColor[
              0.8341470216086144, 0.26347454816989946`, 0.18033253249694123`],
              131 -> RGBColor[
              0.324831212684851, 0.4557742027613212, 0.9419189355286837], 127 -> 
             RGBColor[
              0.8327720947194103, 0.2529062576026711, 0.17901590095508144`], 
             210 -> RGBColor[
              0.37855708825470646`, 0.5023088558389079, 0.9453423008120684], 
             181 -> RGBColor[
              0.7138170777657293, 0.7763585934520937, 0.9721102733779844], 
             194 -> RGBColor[
              0.5158331891976378, 0.6178156468678216, 0.9550274246943216], 
             118 -> RGBColor[
              0.17892956896395254`, 0.30539670014399584`, 0.9335011462986966],
              276 -> RGBColor[
              0.23178154572615212`, 0.3609474787299394, 0.9365109881878111], 
             280 -> RGBColor[
              0.2680583595238526, 0.3990767101141639, 0.9385768990668534], 
             189 -> RGBColor[
              0.2318484494359024, 0.3610177987708272, 0.9365147982551062], 
             168 -> RGBColor[
              0.3858730274799788, 0.5086455546860418, 0.9458084659902717], 41 -> 
             RGBColor[
              0.35699077137457635`, 0.483629196111943, 0.9439681141708117], 
             14 -> RGBColor[
              0.8226976998778256, 0.17547004422228246`, 0.1693686490773784], 
             77 -> RGBColor[
              0.2460324096232273, 0.37592604024272347`, 0.9373225538044856], 
             51 -> RGBColor[
              0.993562122803693, 0.9916057865804992, 0.7563558160423134], 179 -> 
             RGBColor[
              0.9936465744084931, 0.9916407094893913, 0.7549562343970292], 
             223 -> RGBColor[
              0.8873547734207121, 0.5813861597120881, 0.22771840056612383`], 
             292 -> RGBColor[
              0.24306150835744214`, 0.3728034346463635, 0.9371533653724538], 
             143 -> RGBColor[
              0.39675004724917656`, 0.5180666825152114, 0.9465015400717941], 
             112 -> RGBColor[
              0.2522134290242518, 0.3824226835324653, 0.9376745537153752], 
             197 -> RGBColor[
              0.2105002400012672, 0.3385794771003698, 0.9352990493096494], 54 -> 
             RGBColor[
              0.4174064139952154, 0.53595818917145, 0.9478177454951437], 71 -> 
             RGBColor[
              0.6295965520330332, 0.7101738697986875, 0.963983293345653], 177 -> 
             RGBColor[
              0.41920763486506846`, 0.5375183161569235, 0.9479325176962138], 
             158 -> RGBColor[
              0.40363205630183896`, 0.524027532856795, 0.9469400556031081], 
             226 -> RGBColor[
              0.178927010221482, 0.30539401074342565`, 0.9335010005820983], 
             203 -> RGBColor[
              0.2595939437592997, 0.3901800724706624, 0.9380948631110431], 
             115 -> RGBColor[
              0.2215913444714862, 0.35023693111520926`, 0.9359306713014096], 
             173 -> RGBColor[
              0.25717362368840185`, 0.38763616261899303`, 0.9379570294635482],
              212 -> RGBColor[
              0.21172080019279638`, 0.3398623632496528, 0.9353685584068999], 
             129 -> RGBColor[
              0.23590943272644063`, 0.36528614969039486`, 0.9367460652458159],
              279 -> RGBColor[
              0.25879261498995565`, 0.3893378251269034, 0.9380492286230886], 
             26 -> RGBColor[
              0.9858349896506369, 0.9884104184434465, 0.8844144095680297], 40 -> 
             RGBColor[
              0.2372124705557414, 0.3666557250663601, 0.9368202713225229], 
             146 -> RGBColor[
              0.23045057360750168`, 0.3595485426447314, 0.9364351912946507], 
             192 -> RGBColor[
              0.8649861375675162, 0.47981540863036076`, 0.20905346250477896`],
              300 -> RGBColor[
              0.2558608387541249, 0.3862563424176957, 0.9378822683036323], 
             221 -> RGBColor[
              0.29461336050310216`, 0.4269876998276622, 0.9400891670880182], 
             62 -> RGBColor[
              0.9948487335515908, 0.9913902868768101, 0.6806946209012268], 
             286 -> RGBColor[
              0.5590358689967736, 0.6528895285873056, 0.9584284979047402], 
             152 -> RGBColor[
              0.25329610735962166`, 0.38356064710871024`, 0.9377362106448954],
              64 -> RGBColor[
              0.23365539790008147`, 0.3629170161738291, 0.9366177012970005], 
             37 -> RGBColor[
              0.6807027709206555, 0.7504894452666685, 0.968809748742459], 148 -> 
             RGBColor[
              0.23881348570074337`, 0.36833849349398035`, 0.9369114467665411],
              261 -> RGBColor[
              0.4006413843936947, 0.5214371631655013, 0.9467494926336685], 15 -> 
             RGBColor[
              0.23892277989457777`, 0.36845336862135236`, 0.9369176709091936],
              136 -> RGBColor[
              0.9929076697798414, 0.9872385477406899, 0.46942180820333496`], 
             198 -> 
             RGBColor[
              0.4642553566460736, 0.5759424388475844, 0.9509670287800365], 63 -> 
             RGBColor[
              0.32451328924336914`, 0.4554988334556064, 0.9418986777281211], 
             171 -> RGBColor[
              0.4183533072547869, 0.5367783405206518, 0.9478780806963388], 59 -> 
             RGBColor[
              0.8328101555207211, 0.25319880959989605`, 0.17905234802140027`],
              229 -> RGBColor[
              0.34638875058307517`, 0.4744462585754037, 0.9432925627809762], 
             102 -> RGBColor[
              0.38532279281260967`, 0.5081689690727651, 0.9457734055238204], 
             299 -> RGBColor[
              0.9944845479757449, 0.9919872330943883, 0.7410688437815899], 
             128 -> RGBColor[
              0.23926061251081787`, 0.3688084521208458, 0.93693690997691], 12 -> 
             RGBColor[
              0.20154157699751735`, 0.32916335427138743`, 0.93478886670474], 
             222 -> RGBColor[
              0.43613267935432526`, 0.5521779390160471, 0.94901096656484], 92 -> 
             RGBColor[
              0.261097249315751, 0.3917601419255701, 0.9381804741385418], 271 -> 
             RGBColor[
              0.9774649456708626, 0.9356461116447503, 0.3669559986295733], 
             132 -> RGBColor[
              0.2067120462521808, 0.3345978452847238, 0.9350833172797693], 80 -> 
             RGBColor[
              0.26782978190622225`, 0.39883646054537636`, 0.9385638819096797],
              244 -> RGBColor[
              0.24251120685435607`, 0.3722250328754895, 0.9371220265159511], 
             150 -> RGBColor[
              0.9620063021321176, 0.9711849428558795, 0.9491975995336027], 
             125 -> RGBColor[
              0.9926251659969516, 0.9866343007146026, 0.4386730148470409], 
             133 -> RGBColor[
              0.35014705105926486`, 0.47770150955020474`, 0.9435320383639844],
              258 -> RGBColor[
              0.9617670348256762, 0.9710064976904998, 0.9496026166724999], 
             255 -> RGBColor[
              0.9589543367125869, 0.8732054811308165, 0.29504577826186157`], 
             176 -> RGBColor[
              0.1789518783186532, 0.305420148690281, 0.9335024167834431], 230 -> 
             RGBColor[
              0.24935218422087857`, 0.37941533383072157`, 0.9375116100566555],
              274 -> RGBColor[
              0.9645754531953188, 0.8921668269279859, 0.3168827543384975], 87 -> 
             RGBColor[
              0.27610729667649436`, 0.4075366533936812, 0.9390352741303609], 
             130 -> RGBColor[0.178927, 0.305394, 0.933501], 35 -> 
             RGBColor[
              0.2262311772849768, 0.3551136895845794, 0.9361949029161204], 31 -> 
             RGBColor[
              0.6188367246795077, 0.7014385572283971, 0.9631362403218372], 18 -> 
             RGBColor[
              0.9464007204285422, 0.9595463255731478, 0.9756137787701872], 24 -> 
             RGBColor[
              0.9556367854010767, 0.9664345677069957, 0.9599795299232305], 
             151 -> RGBColor[
              0.443273542823118, 0.5583629960424816, 0.9494659760706539], 137 -> 
             RGBColor[
              0.8455662065044656, 0.351247407198139, 0.19126755684933291`], 
             296 -> RGBColor[
              0.6962355794932261, 0.7626237933772783, 0.9703579139386239], 
             266 -> RGBColor[
              0.24763395401992835`, 0.3776093649474359, 0.9374137593886052], 
             283 -> RGBColor[
              0.6187231293682252, 0.7013463354372874, 0.9631272976828197], 
             284 -> RGBColor[
              0.25564421936180226`, 0.3860286617019018, 0.9378699321496993], 
             238 -> RGBColor[
              0.2785145923880161, 0.4100668738178543, 0.9391723660598572], 72 -> 
             RGBColor[
              0.6518075404484566, 0.7279162716099014, 0.9659297422102715], 
             288 -> RGBColor[
              0.8619011142240809, 0.46580703815332913`, 0.20647924340617463`],
              172 -> RGBColor[
              0.26949540103514497`, 0.4005871318562264, 0.9386587364550091], 
             243 -> RGBColor[
              0.21816661637866602`, 0.3466373247493527, 0.9357356381029547], 
             88 -> RGBColor[
              0.5042211596463271, 0.6083884781620977, 0.9541132831917766], 
             273 -> RGBColor[
              0.6178350891255162, 0.7006253843624993, 0.9630573879019151], 
             202 -> RGBColor[
              0.22812105044609293`, 0.3571000661017916, 0.9363025283968291], 
             98 -> RGBColor[
              0.4228071955400177, 0.5406360746943846, 0.948161878519455], 30 -> 
             RGBColor[
              0.46219840465570133`, 0.574272512557169, 0.9508050979844909], 
             116 -> RGBColor[
              0.3224078413052081, 0.4536752002744616, 0.941764520447276], 240 -> 
             RGBColor[
              0.9949335587465892, 0.9915717193917691, 0.6899273198963884], 73 -> 
             RGBColor[
              0.3290101239879992, 0.459393765693919, 0.9421852120616541], 29 -> 
             RGBColor[
              0.24282295558358705`, 0.3725527005559224, 0.9371397801448899], 
             75 -> 
             RGBColor[
              0.7305123993392341, 0.7894011055544591, 0.9737743070057807], 
             200 -> RGBColor[
              0.8859959599380017, 0.5752161050460523, 0.226584573288584], 156 -> 
             RGBColor[
              0.2276990046313701, 0.35665646919126776`, 0.9362784935120415], 
             25 -> RGBColor[
              0.2518103509231395, 0.3819990228915686, 0.9376515990138174], 38 -> 
             RGBColor[
              0.4179442959916355, 0.5364240755220139, 0.9478520188603253], 3 -> 
             RGBColor[
              0.3773249031069595, 0.5012415989953558, 0.9452637870640326], 57 -> 
             RGBColor[
              0.24705297562595502`, 0.37699871981921224`, 0.9373806735285489],
              227 -> RGBColor[
              0.25976518882652405`, 0.3903600618938796, 0.9381046152642871], 
             39 -> RGBColor[
              0.8675327116732591, 0.4913788068770457, 0.21117838636085415`], 
             109 -> RGBColor[
              0.9211686584075277, 0.939978900029778, 0.992343083047521], 256 -> 
             RGBColor[
              0.9952479751456992, 0.992244224277091, 0.7241496045864151], 287 -> 
             RGBColor[
              0.9409750107809423, 0.8036926171977683, 0.27136531206102255`], 
             239 -> RGBColor[
              0.4111342730563943, 0.530525575937213, 0.9474180902207585], 285 -> 
             RGBColor[0.382771346863294, 0.50595903483087, 0.945610829644085],
              216 -> RGBColor[
              0.2588379470720171, 0.38938547201937, 0.9380518102180992], 21 -> 
             RGBColor[
              0.38345468665213356`, 0.5065509094103063, 0.9456543714511763], 
             175 -> RGBColor[
              0.2945111830148827, 0.42688030480911665`, 0.9400833482312222], 
             7 -> RGBColor[
              0.394746751143397, 0.516331528116975, 0.946373891815379], 13 -> 
             RGBColor[
              0.30612838775897044`, 0.4390907235684761, 0.9407449308552837], 
             294 -> RGBColor[
              0.209897553009386, 0.33794601485934034`, 0.9352647271770572], 
             193 -> RGBColor[
              0.39949775357450523`, 0.5204466076304757, 0.9466766214891428], 
             60 -> RGBColor[
              0.9260824493199337, 0.7446485736567867, 0.2593824075361489], 65 -> 
             RGBColor[
              0.28791659856684826`, 0.41994897843342893`, 0.9397077964027201],
              69 -> RGBColor[
              0.9930380091079225, 0.9875173303841278, 0.48360843970387296`], 
             217 -> RGBColor[
              0.80703569950506, 0.8491816892426243, 0.9814014344154122], 214 -> 
             RGBColor[
              0.21288213693655111`, 0.34108300180034146`, 0.9354346948164131],
              170 -> RGBColor[
              0.8218934398484693, 0.16928814920765783`, 0.168598488764985], 
             74 -> RGBColor[
              0.6382140736915616, 0.7171699620960075, 0.9646616962176343], 
             246 -> RGBColor[
              0.5988679170367666, 0.6852269795994871, 0.961564222636048], 264 -> 
             RGBColor[
              0.2946613034028385, 0.4270380908550406, 0.940091897365233], 278 -> 
             RGBColor[
              0.6029315110482949, 0.6885259882808699, 0.9618841236420709], 45 -> 
             RGBColor[
              0.8578237913971699, 0.4454645759914146, 0.2030054339855487], 
             237 -> RGBColor[
              0.638779311088947, 0.7176288472788594, 0.9647061937760893], 228 -> 
             RGBColor[
              0.8163432429187892, 0.8564528128973794, 0.9823291233589543], 
             180 -> RGBColor[
              0.23402613491596813`, 0.3633066842836104, 0.936638814221599], 
             53 -> RGBColor[
              0.8317291195209172, 0.2448894931924079, 0.17801714672713256`], 
             48 -> RGBColor[
              0.4136829046946342, 0.5327330725643056, 0.9475804867750808], 5 -> 
             RGBColor[
              0.220958970004222, 0.34957226545525755`, 0.9358946585110132], 
             101 -> RGBColor[
              0.5465902564750337, 0.6427856196737024, 0.9574487336972479], 
             267 -> RGBColor[
              0.467847246129772, 0.578858496543228, 0.9512497954777179], 120 -> 
             RGBColor[
              0.18991457468017128`, 0.31694263764133146`, 0.9341267261233757],
              147 -> RGBColor[
              0.22619261942112945`, 0.35507316282496604`, 0.9361927071028155],
              89 -> RGBColor[
              0.27813245697413447`, 0.40966522526908, 0.9391506040133554], 43 -> 
             RGBColor[
              0.322173741643116, 0.45347243491334854`, 0.9417496038238137], 
             199 -> RGBColor[0.178927, 0.305394, 0.933501], 268 -> 
             RGBColor[
              0.2625163578880115, 0.3932517150116962, 0.938261290272349], 169 -> 
             RGBColor[
              0.2930250557635406, 0.42531829084204614`, 0.9399987154827865], 
             20 -> RGBColor[
              0.865905855945801, 0.8959138414156087, 0.9870720676150353], 4 -> 
             RGBColor[
              0.5396207399250182, 0.6371274521652572, 0.9569000678242504], 
             167 -> 
             RGBColor[
              0.7539264605068086, 0.8076923480920241, 0.9761080018061227], 
             142 -> RGBColor[
              0.6590237495828186, 0.7335536290308857, 0.9666489864974762], 16 -> 
             RGBColor[
              0.9934703621130101, 0.9884420897444159, 0.5306673961342021], 
             281 -> RGBColor[
              0.8360763947567734, 0.2783045556433535, 0.18218010240253352`], 
             289 -> RGBColor[
              0.2909832679823188, 0.4231722424271597, 0.9398824386892002], 
             178 -> RGBColor[
              0.27705635157752495`, 0.4085341702682206, 0.9390893214029737], 
             58 -> RGBColor[
              0.5489231824340144, 0.6446795940643196, 0.9576323901745283], 
             186 -> RGBColor[
              0.2299691131158081, 0.3590424971416032, 0.9364077728319058], 
             122 -> RGBColor[
              0.6241927467762723, 0.7057868172525964, 0.96355788600105], 249 -> 
             RGBColor[
              0.8185799679311427, 0.1438193520784336, 0.16542550431492184`], 
             113 -> RGBColor[
              0.9594092884334661, 0.9692480942916449, 0.9535936663157671], 52 -> 
             RGBColor[
              0.8177080186927622, 0.13711716814164848`, 0.16459052473952288`],
              187 -> RGBColor[
              0.3639294956023307, 0.48963917028760373`, 0.9444102435429313], 
             259 -> RGBColor[
              0.46426084954242974`, 0.5759468982282985, 0.9509674612009588], 
             42 -> RGBColor[
              0.2544378422070241, 0.3847606828235006, 0.9378012307554097], 
             134 -> RGBColor[
              0.27400077350385804`, 0.40532256397795713`, 0.9389153107520011],
              248 -> RGBColor[
              0.20835094833068457`, 0.3363204352816248, 0.9351766503286018], 
             174 -> RGBColor[
              0.3923234880848031, 0.5142326194523638, 0.9462194836360928], 
             215 -> RGBColor[
              0.9951032288756773, 0.9922430735458843, 0.7308157001748675], 83 -> 
             RGBColor[
              0.21628848662157388`, 0.34466329129434453`, 0.9356286813917323],
              95 -> RGBColor[
              0.48864650773140994`, 0.5957442741074949, 0.9528871895412045], 
             166 -> RGBColor[
              0.9927232541779302, 0.9868441014154793, 0.4493493080164732], 
             233 -> RGBColor[
              0.9940884990666902, 0.9897642221851048, 0.5979477888431959], 
             295 -> RGBColor[
              0.8372847792405768, 0.8730921717492939, 0.9843421637685542], 
             141 -> 
             RGBColor[
              0.8990024464838272, 0.6342755227085348, 0.23743750448057996`], 
             205 -> RGBColor[
              0.5294468131435418, 0.6288678000738763, 0.9560991390396908], 
             224 -> RGBColor[
              0.9695247134417432, 0.9088618438807439, 0.33610969580648287`], 
             231 -> RGBColor[
              0.44511934956958094`, 0.5599617410733233, 0.9495835892443556], 
             68 -> RGBColor[
              0.8743662175245639, 0.5224081609419808, 0.2168804311477391], 10 -> 
             RGBColor[
              0.2114327980870659, 0.3395596547761419, 0.9353521571130395], 
             250 -> RGBColor[
              0.22258326386374316`, 0.3512795012877932, 0.9359871596433854], 
             282 -> RGBColor[
              0.9636570397640628, 0.9724160602789496, 0.9464033313040466], 
             232 -> RGBColor[
              0.9940965401504851, 0.9897814212502639, 0.5988230111904562], 
             253 -> RGBColor[
              0.29672537087035056`, 0.42920755663283183`, 0.9402094429539937],
              55 -> RGBColor[
              0.2766948027559306, 0.4081541595332056, 0.9390687317324474], 91 -> 
             RGBColor[
              0.2726124428491967, 0.4038633404346605, 0.9388362473750692], 
             105 -> RGBColor[
              0.28917033221241484`, 0.4212667319862237, 0.9397791946791023], 
             36 -> RGBColor[
              0.7595712694087771, 0.8121021157083784, 0.9766706236037325], 
             123 -> RGBColor[
              0.43622064479054923`, 0.5522541302556329, 0.9490165716446514], 
             94 -> RGBColor[
              0.8619491220774967, 0.8927588492317026, 0.9866946708064583], 96 -> 
             RGBColor[
              0.40546591079173033`, 0.5256159254437323, 0.9470569071895901], 
             2 -> RGBColor[
              0.2307572995292167, 0.3598709310360006, 0.936452658882132], 262 -> 
             RGBColor[
              0.9939797374120591, 0.9895315920033393, 0.5861097539357399], 
             272 -> RGBColor[
              0.22328031209840418`, 0.35201214317783264`, 0.936026855509159], 
             97 -> RGBColor[
              0.2574804300414378, 0.3879586355486801, 0.9379745016314742], 
             209 -> RGBColor[
              0.2651563206276758, 0.3960264832343887, 0.938411632244898], 66 -> 
             RGBColor[
              0.9464558742569554, 0.9595874592080723, 0.9755204177251058], 
             139 -> RGBColor[
              0.25547870703592473`, 0.385854697753317, 0.9378605064675941], 
             56 -> 
             RGBColor[
              0.5476923991281734, 0.6436803887304818, 0.9575354984041846], 
             144 -> RGBColor[
              0.3157094904678022, 0.4478734254480028, 0.9413377074550355], 
             298 -> RGBColor[
              0.28525208052382683`, 0.41714840103001194`, 0.9395560560419711],
              204 -> RGBColor[
              0.23088271225706164`, 0.36000274776459185`, 0.9364598009514513],
              207 -> RGBColor[
              0.7455882739599426, 0.8011784933890475, 0.9752769292959146], 
             149 -> RGBColor[
              0.2939489691399074, 0.4262893823800991, 0.9400513309827632], 
             219 -> RGBColor[
              0.27423499655804673`, 0.4055687472585089, 0.9389286494084351], 
             9 -> RGBColor[
              0.5168296547678491, 0.6186246225079816, 0.9551058701141822], 11 -> 
             RGBColor[
              0.34350580070653963`, 0.47194919229362253`, 0.9431088637641358],
              44 -> RGBColor[
              0.9650552642631052, 0.8937853423246256, 0.3187467297321304], 
             153 -> RGBColor[
              0.27348165172589245`, 0.40477693407509363`, 0.9388857475347178],
              32 -> RGBColor[
              0.2562574704790552, 0.38667322750850125`, 0.9379048558936031], 
             162 -> RGBColor[
              0.2845267439871254, 0.4163860263409461, 0.9395147491992453], 90 -> 
             RGBColor[
              0.4035464690461924, 0.5239534014776945, 0.9469346020588602], 8 -> 
             RGBColor[
              0.6518492866916434, 0.7279488840923621, 0.9659339030856515], 
             163 -> RGBColor[
              0.2413593551772921, 0.3710143637312809, 0.9370564302669542], 49 -> 
             RGBColor[
              0.23655451757503262`, 0.36596417476700677`, 0.9367828018736257],
              76 -> RGBColor[
              0.29429562032882867`, 0.4266537347586102, 0.9400710722551477], 
             82 -> RGBColor[
              0.9950766756732579, 0.9918778320265724, 0.7055047141489801], 67 -> 
             RGBColor[
              0.9123183312358003, 0.932921889378774, 0.9914989309411012], 211 -> 
             RGBColor[
              0.24235927283690456`, 0.3720653405899749, 
               0.9371133740984234]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9mHk4FFzYxsmSfR/LzGBWM2NmbHmlLHNH8aZCu0SWIkQLqbSgomQtVNoX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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 9}], {
             RGBColor[
             0.46767615866135254`, 0.5777748250387542, 0.9514973709902432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 11}], {
             RGBColor[
             0.3810142316306978, 0.5044371099315746, 0.9454988678152201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 20}], {
             RGBColor[
             0.6422142592503285, 0.7164194344925677, 0.9674804697406698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 37}], {
             RGBColor[
             0.5496127167377557, 0.6437072364180976, 0.9583493103043816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 43}], {
             RGBColor[
             0.370348202098986, 0.49519873124143765`, 0.944819237845059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 75}], {
             RGBColor[
             0.5745175309470449, 0.663163066561993, 0.9608315894360424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 102}], {
             RGBColor[
             0.40192272768373283`, 0.5225469983211459, 0.9468311386950623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 142}], {
             RGBColor[
             0.5387732060688373, 0.6352393283002062, 0.9572689291818902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 143}], {
             RGBColor[
             0.4076363549020162, 0.5274958550423691, 0.9471952059690492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 174}], {
             RGBColor[
             0.4054230753198295, 0.5255788235109453, 0.9470541777511985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 185}], {
             RGBColor[
             0.4932964811819127, 0.5985745570433215, 0.9535142966293955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 237}], {
             RGBColor[
             0.5286509868219015, 0.6272769374241931, 0.9562975328211968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 239}], {
             RGBColor[
             0.4148284678056251, 0.5337253017533699, 0.9476534810435313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 283}], {
             RGBColor[
             0.5186228959615405, 0.619135681503407, 0.955508084774562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 295}], {
             RGBColor[
             0.6279037208977163, 0.7050085996594103, 0.9661155178174292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 297}], {
             RGBColor[
             0.5894608456272148, 0.6748368975635395, 0.9623209993901465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 32}], {
             RGBColor[
             0.24350738500413596`, 0.3732720792722509, 0.9371787573878676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 83}], {
             RGBColor[
             0.2235228930753953, 0.35226711116517256`, 0.9360406701369322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 155}], {
             RGBColor[
             0.22153004206728566`, 0.3501724984015976, 0.9359271802201792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 156}], {
             RGBColor[
             0.2292281520802934, 0.3582637001136342, 0.9363655761970868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 178}], {
             RGBColor[
             0.25390682555337085`, 0.3842025506521106, 0.9377709901425528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 184}], {
             RGBColor[
             0.23409720380212556`, 0.3633813821889895, 0.9366428614895286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 202}], {
             RGBColor[
             0.22943917498765481`, 0.3584854985688961, 0.9363775936394806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 208}], {
             RGBColor[
             0.2583585282715436, 0.3888815724631647, 0.9380245080266488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 214}], {
             RGBColor[
             0.2218197182328839, 0.35047696641817105`, 0.9359436768492726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 268}], {
             RGBColor[
             0.2466368287086141, 0.37656132302384837`, 0.9373569745772405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 275}], {
             RGBColor[
             0.2217679370492794, 0.35042254111108606`, 0.9359407279874696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 17}], {
             RGBColor[
             0.3367736481857078, 0.4649602471368852, 0.9427222930937296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 30}], {
             RGBColor[
             0.4197616538813304, 0.5377570557762624, 0.9480344425242617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 38}], {
             RGBColor[
             0.3976345995492975, 0.5188328372586848, 0.9465579029621789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 55}], {
             RGBColor[
             0.327009852931445, 0.45469787926428074`, 0.9421662593982401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 74}], {
             RGBColor[
             0.5077694883992605, 0.6092057805456816, 0.9549627416408335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 90}], {
             RGBColor[
             0.39043568607657597`, 0.5125975002365252, 0.9460991945614463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 123}], {
             RGBColor[
             0.40677277394875433`, 0.5267478646254944, 0.9471401793543419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 144}], {
             RGBColor[
             0.34651719678738085`, 0.4745575122216793, 0.9433007472595341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 157}], {
             RGBColor[
             0.36165267017657554`, 0.4876670985403879, 0.9442651662401199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 229}], {
             RGBColor[
             0.3618568268450173, 0.48784392878537974`, 0.9442781749225044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 252}], {
             RGBColor[
             0.33892810141516894`, 0.46722471408127325`, 0.9428449860179196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 257}], {
             RGBColor[
             0.38431511212659675`, 0.5072961667100446, 0.9457091970015647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 259}], {
             RGBColor[
             0.42079287632469464`, 0.5385942486118271, 0.9481156241324957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 26}], {
             RGBColor[
             0.7627278647878275, 0.8127689353043519, 0.92065723869614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 39}], {
             RGBColor[
             0.7035767257991387, 0.5642531295211515, 0.5840392270925523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 52}], {
             RGBColor[
             0.6786643793088902, 0.3871223101534529, 0.5607452962818866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 78}], {
             RGBColor[
             0.3598305300482983, 0.47184581112708096`, 0.9452322348805061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 82}], {
             RGBColor[
             0.7673487077991381, 0.8145026420959148, 0.8312023909866153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 107}], {
             RGBColor[
             0.6868838807668163, 0.45030100016757835`, 0.5686163001605958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 130}], {
             RGBColor[
             0.3592738699625091, 0.4712607260826286, 0.9452005339121252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 193}], {
             RGBColor[
             0.46955924674976174`, 0.5787870298978665, 0.9517883446566966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 199}], {
             RGBColor[
             0.3592738699625091, 0.4712607260826286, 0.9452005339121252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 220}], {
             RGBColor[
             0.3984062395141392, 0.5123913276169251, 0.9474290644669376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 226}], {
             RGBColor[
             0.35927387507325015`, 0.47126073145434144`, 0.9452005342031744]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 228}], {
             RGBColor[
             0.6779819914219037, 0.7467901325313183, 0.9696145955916023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 236}], {
             RGBColor[
             0.5814156950940945, 0.671058479612787, 0.9601903197951254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 266}], {
             RGBColor[
             0.3936273469724733, 0.5073684085563466, 0.9471569136064277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 281}], {
             RGBColor[
             0.6878485673408958, 0.45771600390430534`, 0.5695400851133919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 29}], {
             RGBColor[
             0.23189096279390453`, 0.36106248300558996`, 0.9365172193279515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 77}], {
             RGBColor[
             0.23349568981372465`, 0.3627491528489905, 0.9366086061577494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 191}], {
             RGBColor[
             0.23242398209380136`, 0.36162272008515706`, 0.9365475739885493]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 248}], {
             RGBColor[
             0.21465495916745328`, 0.3429463503684412, 0.9355356544198075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 21}], {
             RGBColor[
             0.3445638718863475, 0.47258152580409235`, 0.9431866859501019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 34}], {
             RGBColor[
             0.31658612534963915`, 0.4483486079564237, 0.9414039686805327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 46}], {
             RGBColor[
             0.29890559173213627`, 0.4314991069925552, 0.9403336033067247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 50}], {
             RGBColor[
             0.32906105284495657`, 0.4591537631447806, 0.9421988600293891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 101}], {
             RGBColor[
             0.4261316567977976, 0.5406988809357904, 0.9490838670731377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 108}], {
             RGBColor[
             0.32479673840417583`, 0.4554602283068521, 0.9419271416840078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 114}], {
             RGBColor[
             0.30504212315896806`, 0.43794899060072, 0.940683069693298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 145}], {
             RGBColor[
             0.2874384541046572, 0.41944641828755624`, 0.9396805667829495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 169}], {
             RGBColor[
             0.299349056442051, 0.4319652165199622, 0.940358857965907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 187}], {
             RGBColor[
             0.3348012763614461, 0.46412565624274105`, 0.9425646219959795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 205}], {
             RGBColor[
             0.41755993513205164`, 0.5337399711358773, 0.9484090697443592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 213}], {
             RGBColor[
             0.3667758904705204, 0.4918204598931879, 0.9446020161329686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 219}], {
             RGBColor[
             0.2899540268393041, 0.4220904447281936, 0.9398238249287314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 221}], {
             RGBColor[
             0.3001432088118318, 0.4327999210127703, 0.9404040837685228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 231}], {
             RGBColor[
             0.3753962033450712, 0.49928694163560083`, 0.9451512948466916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 264}], {
             RGBColor[
             0.3001671802617, 0.4328251165264595, 0.9404054489071303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 9}], {
             RGBColor[
             0.45578820295562306`, 0.5674780753124783, 0.9507398809647807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 11}], {
             RGBColor[
             0.36912627592496833`, 0.4941403602052988, 0.9447413777897574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 43}], {
             RGBColor[
             0.3584602463932565, 0.4849019815151618, 0.9440617478195963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 54}], {
             RGBColor[
             0.40607658256930623`, 0.5261448586442126, 0.9470958186552614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 63}], {
             RGBColor[
             0.3596300201933831, 0.4859151807862907, 0.94413628477175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 106}], {
             RGBColor[
             0.5257077598802015, 0.6240227140594248, 0.9563940779093657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 131}], {
             RGBColor[
             0.359788981914124, 0.4860528654391481, 0.9441464136720313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 143}], {
             RGBColor[
             0.3957483991962868, 0.5171991053160931, 0.9464377159435866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 151}], {
             RGBColor[
             0.4190101469832575, 0.5373472620797284, 0.9479199339430164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 167}], {
             RGBColor[
             0.5743366058251028, 0.6620119381044995, 0.9612409468107508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 174}], {
             RGBColor[
             0.39353511961410004`, 0.5152820737846694, 0.9462966877257359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 185}], {
             RGBColor[
             0.4814085254761833, 0.5882778073170456, 0.9527568066039329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[
             0.4552899701705174, 0.5670735874923983, 0.9507006582548503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 283}], {
             RGBColor[
             0.5067349402558111, 0.6088389317771312, 0.9547505947490993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 297}], {
             RGBColor[
             0.5775728899214854, 0.6645401478372637, 0.9615635093646839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 22}], {
             RGBColor[
             0.7346141321851996, 0.7926054104280515, 0.9741831294029938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 47}], {
             RGBColor[
             0.6479545398771973, 0.7249062782797447, 0.9655457111216659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 61}], {
             RGBColor[
             0.6093443388632377, 0.6935868317074125, 0.9624883614152353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 72}], {
             RGBColor[
             0.6518284135700501, 0.7279325778511317, 0.9659318226479615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 177}], {
             RGBColor[
             0.5355284607783559, 0.6327336001246429, 0.9569332103909327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 217}], {
             RGBColor[
             0.7294424930983517, 0.7885652866674933, 0.9736676687505319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 247}], {
             RGBColor[
             0.6154687668637716, 0.6985589182605833, 0.9629704988219563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 267}], {
             RGBColor[
             0.5598482664107077, 0.6534036903177951, 0.9585918492816847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 271}], {
             RGBColor[
             0.814657116181253, 0.8317974978685563, 0.6664449508576125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 273}], {
             RGBColor[
             0.6348421879085798, 0.7142871342274307, 0.9644956454937833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 285}], {
             RGBColor[
             0.5173103167774687, 0.616953959461616, 0.9557723663648683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 11}], {
             RGBColor[
             0.43016772773719436`, 0.545286907400802, 0.949107366939159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 20}], {
             RGBColor[
             0.6913677553568252, 0.7572692319617951, 0.9710889688646087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 37}], {
             RGBColor[
             0.5987662128442524, 0.684557033887325, 0.9619578094283205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 43}], {
             RGBColor[
             0.41950169820548255`, 0.5360485287106651, 0.948427736968998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 63}], {
             RGBColor[
             0.42067147200560917`, 0.537061727981794, 0.9485022739211517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 75}], {
             RGBColor[
             0.6236710270535416, 0.7040128640312203, 0.9644400885599815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.5867492116924276, 0.675169261254928, 0.9607600670587673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 131}], {
             RGBColor[
             0.4208304337263501, 0.5371994126346513, 0.9485124028214329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 142}], {
             RGBColor[
             0.5879267021753338, 0.6760891257694337, 0.9608774283058292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 143}], {
             RGBColor[
             0.4567898510085129, 0.5683456525115964, 0.9508037050929882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 167}], {
             RGBColor[
             0.6353780576373289, 0.7131584853000028, 0.9656069359601525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 174}], {
             RGBColor[
             0.4545765714263261, 0.5664286209801727, 0.9506626768751375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 185}], {
             RGBColor[
             0.5424499772884093, 0.6394243545125489, 0.9571227957533345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 237}], {
             RGBColor[
             0.5778044829283981, 0.6681267348934206, 0.9599060319451358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 239}], {
             RGBColor[
             0.4639819639121217, 0.5745750992225973, 0.9512619801674704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 282}], {
             RGBColor[
             0.740243347265956, 0.7955203413934655, 0.9507546007091144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 283}], {
             RGBColor[
             0.5677763920680372, 0.6599854789726345, 0.959116583898501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 295}], {
             RGBColor[
             0.677057217004213, 0.7458583971286377, 0.9697240169413682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 297}], {
             RGBColor[
             0.6386143417337113, 0.7156866950327669, 0.9659294985140855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 117}], {
             RGBColor[
             0.20745354842489078`, 0.3353772110821952, 0.935125544731551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 129}], {
             RGBColor[
             0.22367111540675327`, 0.3524229022332684, 0.9360491111794278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 161}], {
             RGBColor[
             0.21385191803304957`, 0.3421023032204342, 0.935489922415196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 265}], {
             RGBColor[
             0.21694931138635237`, 0.3453578600208368, 0.9356663143844839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 269}], {
             RGBColor[
             0.2192290472618576, 0.3477540069695957, 0.9357961419700269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 43}], {
             RGBColor[
             0.3328397711748278, 0.46271081360348554`, 0.9424292337939748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 63}], {
             RGBColor[
             0.3340095449749544, 0.46372401287461446`, 0.9425037707461285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 131}], {
             RGBColor[
             0.3341685066956953, 0.46386169752747186`, 0.9425138996464097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 139}], {
             RGBColor[
             0.2994922538712322, 0.4289019450234698, 0.940484685115865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 143}], {
             RGBColor[
             0.3701279239778581, 0.49500793740441695`, 0.9448052019179649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 172}], {
             RGBColor[
             0.3065006008708423, 0.43626816207492447`, 0.9408838001095725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 174}], {
             RGBColor[
             0.36791464439567134`, 0.49309090587299315`, 0.9446641737001142]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 183}], {
             RGBColor[
             0.29904764600234657`, 0.4284346339635039, 0.9404593653554703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 185}], {
             RGBColor[
             0.4557880502577546, 0.5660866394053694, 0.9511242925783112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 283}], {
             RGBColor[
             0.4811144650373824, 0.586647763865455, 0.9531180807234778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 248}], {
             RGBColor[
             0.20494626266410096`, 0.3327418947765061, 0.9349827585166709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 58}], {
             RGBColor[
             0.4275257850964924, 0.5418851588163979, 0.949188660514906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 73}], {
             RGBColor[
             0.31756925587348483`, 0.44924224463119755`, 0.9414650714584689]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 95}], {
             RGBColor[
             0.3973874477451902, 0.5174174988379855, 0.946816060198244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 96}], {
             RGBColor[
             0.3557971492753504, 0.4823533245061042, 0.9439009190224369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 105}], {
             RGBColor[
             0.29764935998569264`, 0.4301787277773499, 0.9402620627671929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[
             0.3171012005840623, 0.44883683866464263`, 0.941435247389312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 149}], {
             RGBColor[
             0.30003867844943893`, 0.43269005297428764`, 0.9403981309190235]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 171}], {
             RGBColor[
             0.3622408475068787, 0.48793453204456394`, 0.9443115057758112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 245}], {
             RGBColor[
             0.36526550488349396`, 0.49055433824048805`, 0.9445042342692497]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 289}], {
             RGBColor[
             0.2985558278706446, 0.4311314829978179, 0.940313684772242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 298}], {
             RGBColor[
             0.2956902341413986, 0.428119562299244, 0.9401504934486273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 69}], {
             RGBColor[
             0.907867854492874, 0.581493687303205, 0.3264885443906257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 113}], {
             RGBColor[
             0.8910534941556458, 0.5723590692569638, 0.5614811576965728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 135}], {
             RGBColor[
             0.9063967184206538, 0.582821195587901, 0.4915857246054881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 224}], {
             RGBColor[
             0.8961112066597844, 0.5421659440515132, 0.2527391724419306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 249}], {
             RGBColor[
             0.8206388339044841, 0.15964469815035803`, 0.16739707669615012`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 254}], {
             RGBColor[
             0.8570098056114457, 0.3874350253501294, 0.200198663385516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 288}], {
             RGBColor[
             0.8422994070509533, 0.32063854118780577`, 0.1879239462417765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 19}], {
             RGBColor[
             0.265094966907718, 0.3959619965846625, 0.938408138241311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 49}], {
             RGBColor[
             0.2377386487348052, 0.36720877169417954`, 0.9368502363914097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 57}], {
             RGBColor[
             0.2429878777602664, 0.3727260442202823, 0.9371491722188713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 89}], {
             RGBColor[
             0.2585276184343561, 0.3890592969452162, 0.9380341374612745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 111}], {
             RGBColor[
             0.2409685800879815, 0.3706036343358437, 0.9370341762037178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.2455681044594148, 0.3754380260769088, 0.9372961123122845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 115}], {
             RGBColor[
             0.230257062183032, 0.3593451498682808, 0.9364241711053016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 146}], {
             RGBColor[
             0.2346866767510397, 0.3640009556330419, 0.9366764311019222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 175}], {
             RGBColor[
             0.2667169814547302, 0.3976668367152345, 0.9385005095702079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 212}], {
             RGBColor[
             0.22532179004368708`, 0.3541578659355026, 0.9361431146580468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 242}], {
             RGBColor[
             0.23967759230185604`, 0.3692467243192726, 0.9369606563591433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 243}], {
             RGBColor[
             0.2285446981366219, 0.35754534668535254`, 0.9363266545060742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 280}], {
             RGBColor[
             0.2534905697092152, 0.38376503936775813`, 0.9377472849880235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 294}], {
             RGBColor[
             0.2244101664519819, 0.3531996917403464, 0.9360911990431254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 33}], {
             RGBColor[
             0.9540665099241967, 0.9616166407194549, 0.7611949655148192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 44}], {
             RGBColor[
             0.9792628131880576, 0.9411137160345208, 0.4247070629331663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 53}], {
             RGBColor[
             0.9125997408169637, 0.6166657914684119, 0.3543422714306673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 59}], {
             RGBColor[
             0.9131402588168656, 0.620820449672156, 0.3548598720778012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 94}], {
             RGBColor[
             0.9277097420952534, 0.9406004694880592, 0.7586810334703302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 124}], {
             RGBColor[
             0.9705820834138202, 0.9744763977304486, 0.7520461602492186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 125}], {
             RGBColor[
             0.9930477640549809, 0.9875381952295093, 0.4846702054906215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 150}], {
             RGBColor[
             0.9777383321225639, 0.9798135163001478, 0.7399324978339024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 170}], {
             RGBColor[
             0.9076819009807398, 0.5788651194760369, 0.34963294244959353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 192}], {
             RGBColor[
             0.9292282498402631, 0.7341287491873884, 0.36986042931949054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 195}], {
             RGBColor[
             0.9063070598041875, 0.5682974877338114, 0.34831639298626615`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 200}], {
             RGBColor[
             0.939733161025506, 0.7818290973952341, 0.3786259847113931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 295}], {
             RGBColor[
             0.9153775706767935, 0.9307671307468549, 0.7575047799513781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 30}], {
             RGBColor[
             0.37921039896007874`, 0.5014757039177918, 0.9454929485539587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 38}], {
             RGBColor[
             0.3570833446280458, 0.48255148540021425`, 0.944016408991876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 42}], {
             RGBColor[
             0.2753301177357401, 0.4067197890509576, 0.9389910149394182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 48}], {
             RGBColor[
             0.35495264897954515`, 0.4807059839213601, 0.9438806429492537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 55}], {
             RGBColor[
             0.28645859801019335`, 0.41841652740581015`, 0.939624765427937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 84}], {
             RGBColor[
             0.2984201886260963, 0.4309889175517728, 0.9403059603179251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 90}], {
             RGBColor[
             0.3498844311553243, 0.4763161483780546, 0.9435577005911434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 97}], {
             RGBColor[
             0.27685141165294697`, 0.4083187654135474, 0.9390776503774505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 134}], {
             RGBColor[
             0.2851115833841571, 0.4170007296281859, 0.9395480549377139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 144}], {
             RGBColor[
             0.3059659418661292, 0.4382761603632087, 0.940759253289231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 158}], {
             RGBColor[
             0.34992722478314753`, 0.47635321406760484`, 0.9435604273632674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 159}], {
             RGBColor[
             0.2718080646722995, 0.4030178879702195, 0.9387904392278659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 175}], {
             RGBColor[
             0.29536678813966943`, 0.42777960004376564`, 0.9401320736773244]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 235}], {
             RGBColor[
             0.2691307812557516, 0.40020389334985473`, 0.9386379718979794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 252}], {
             RGBColor[
             0.29837684649391727`, 0.43094336222280266`, 0.9403034920476165]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 253}], {
             RGBColor[
             0.2964738820674033, 0.42894322595562323`, 0.9401951210387102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 292}], {
             RGBColor[
             0.26964195081094916`, 0.4007411649623891, 0.9386670822479402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 24}], {
             RGBColor[
             0.9510187529148094, 0.9629904466400717, 0.9677966543467089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 36}], {
             RGBColor[
             0.8529859949186596, 0.8858242206407632, 0.9761422011869598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 66}], {
             RGBColor[
             0.9464282973427488, 0.95956689239061, 0.9755670982476465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 69}], {
             RGBColor[
             0.9697193647682323, 0.9735318279786378, 0.7296111092370301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 88}], {
             RGBColor[
             0.7253109400374347, 0.7839674018676228, 0.9648635309809819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 113}], {
             RGBColor[
             0.9529050044310041, 0.9643972099323963, 0.9646037225429771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 135}], {
             RGBColor[
             0.9682482286960121, 0.9748593362633335, 0.8947082894518925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.7053280385373079, 0.7677443822103661, 0.9632904037751118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 222}], {
             RGBColor[
             0.6912666998914337, 0.7558621322945974, 0.9623123726675136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.9579627169351427, 0.9342040847269458, 0.6558617372883351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 254}], {
             RGBColor[
             0.918861315886804, 0.779473166025562, 0.6033212282319205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 258}], {
             RGBColor[
             0.9540838776271092, 0.9652764116318238, 0.9626081977213435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 260}], {
             RGBColor[
             0.8977772500782942, 0.9210512580678571, 0.980544009200409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 278}], {
             RGBColor[
             0.7746661157384185, 0.8240361569270088, 0.968748951206129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 288}], {
             RGBColor[
             0.9041509173263116, 0.7126766818632384, 0.5910465110881808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 290}], {
             RGBColor[
             0.7796647191738186, 0.8280942483803853, 0.9691424595790514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 48}], {
             RGBColor[
             0.3524750293077462, 0.47810184855613913`, 0.9437395461742546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 49}], {
             RGBColor[
             0.26391083574794544`, 0.39471739965748975`, 0.9383407037235271]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 57}], {
             RGBColor[
             0.2691600647734066, 0.40023467218359243`, 0.9386396395509886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 84}], {
             RGBColor[
             0.2959425689542974, 0.42838478218655185`, 0.940164863542926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 89}], {
             RGBColor[
             0.28469980544749635`, 0.41656792490852634`, 0.9395246047933918]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 111}], {
             RGBColor[
             0.2671407671011217, 0.39811226229915386`, 0.9385246435358352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 112}], {
             RGBColor[
             0.271740291472555, 0.402946654040219, 0.9387865796444018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 158}], {
             RGBColor[
             0.3474496051113486, 0.47374907870238386`, 0.9434193305882683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 175}], {
             RGBColor[
             0.2928891684678705, 0.42517546467854467`, 0.9399909769023254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 177}], {
             RGBColor[
             0.3552373943929633, 0.4804944703524481, 0.9439155616348212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 242}], {
             RGBColor[
             0.26584977931499626`, 0.39675535228258274`, 0.9384511236912607]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 253}], {
             RGBColor[
             0.2939962623956044, 0.42633909059040226`, 0.940054024263711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 280}], {
             RGBColor[
             0.2796627567223554, 0.4112736673310683, 0.939237752320141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 33}], {
             RGBColor[
             0.8902842568405922, 0.9153525165550513, 0.9893973012552358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 37}], {
             RGBColor[
             0.7733043134332283, 0.8232016433411387, 0.9779409081787471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 75}], {
             RGBColor[
             0.7982091276425176, 0.8426574734850338, 0.980423187310408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 124}], {
             RGBColor[
             0.9067998303302157, 0.928212273566045, 0.9802484959896351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 142}], {
             RGBColor[
             0.7624648027643098, 0.8147337352232472, 0.9768605270562558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 150}], {
             RGBColor[
             0.9139560790389594, 0.9335493921357441, 0.968134833574319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 167}], {
             RGBColor[
             0.8099161582263048, 0.8518030947538164, 0.981590034710579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 185}], {
             RGBColor[
             0.7169880778773853, 0.7780689639663625, 0.973105894503761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 200}], {
             RGBColor[
             0.8759509079419014, 0.7355649732308305, 0.6068283204518097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 237}], {
             RGBColor[
             0.752342583517374, 0.8067713443472341, 0.9758891306955624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 282}], {
             RGBColor[
             0.9147814478549319, 0.9341649508472791, 0.9667376994595409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 283}], {
             RGBColor[
             0.7423144926570131, 0.7986300884264481, 0.9750996826489275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 295}], {
             RGBColor[
             0.851595317593189, 0.8845030065824513, 0.9857071156917947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 297}], {
             RGBColor[
             0.8131524423226874, 0.8543313044865806, 0.981912597264512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 34}], {
             RGBColor[
             0.3554769401154252, 0.48231799156263766`, 0.943871654181607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 46}], {
             RGBColor[
             0.3377964064979223, 0.4654684905987692, 0.942801288807799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 50}], {
             RGBColor[
             0.3679518676107426, 0.4931231467509946, 0.9446665455304635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 87}], {
             RGBColor[
             0.32978099166431396`, 0.45704378140199375`, 0.9423448227907686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 101}], {
             RGBColor[
             0.4650224715635836, 0.5746682645420044, 0.9515515525742121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 108}], {
             RGBColor[
             0.3636875531699619, 0.4894296119130661, 0.9443948271850822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 114}], {
             RGBColor[
             0.3439329379247541, 0.47191837420693394`, 0.9431507551943723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 169}], {
             RGBColor[
             0.33823987120783705`, 0.46593460012617627`, 0.9428265434669814]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 187}], {
             RGBColor[
             0.3736920911272321, 0.49809503984895503`, 0.9450323074970538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 205}], {
             RGBColor[
             0.4564507498978377, 0.5677093547420913, 0.9508767552454336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 213}], {
             RGBColor[
             0.40566670523630644`, 0.5257898434994019, 0.9470697016340429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 264}], {
             RGBColor[
             0.339057995027486, 0.46679450013267343`, 0.9428731344082046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 61}], {
             RGBColor[
             0.6921091843567939, 0.7582433580431021, 0.9707375877325777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 72}], {
             RGBColor[
             0.7345932590636062, 0.7925891041868212, 0.9741810489653038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 177}], {
             RGBColor[
             0.6182933062719121, 0.6973901264603323, 0.9651824367082749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 217}], {
             RGBColor[
             0.812207338591908, 0.8532218130031827, 0.981916895067874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 247}], {
             RGBColor[
             0.6982336123573278, 0.7632154445962727, 0.9712197251392987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 267}], {
             RGBColor[
             0.642613111904264, 0.7180602166534845, 0.966841075599027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 271}], {
             RGBColor[
             0.8974219616748091, 0.8964540242042457, 0.6746941771749546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 273}], {
             RGBColor[
             0.717607033402136, 0.7789436605631201, 0.9727448718111256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 274}], {
             RGBColor[
             0.8909772154370372, 0.8747143818458635, 0.6496575550294168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 285}], {
             RGBColor[
             0.6000751622710249, 0.6816104857973055, 0.9640215926822105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[
             0.29610769611833376`, 0.428558341305621, 0.9401742672906341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 180}], {
             RGBColor[
             0.26520012614906696`, 0.3960725256148013, 0.9384141269045367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 267}], {
             RGBColor[
             0.3821106817559689, 0.50384843174461, 0.9457196175325961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 285}], {
             RGBColor[
             0.33957273212272987`, 0.46739870088843105`, 0.9429001346157797]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 74}], {
             RGBColor[
             0.7969254295463191, 0.8418022649015016, 0.9623206130704325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 113}], {
             RGBColor[
             0.9575230369172714, 0.9678413309993203, 0.9567865981194988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 135}], {
             RGBColor[
             0.9728662611822794, 0.9783034573302576, 0.8868911650284141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 224}], {
             RGBColor[
             0.9625807494214099, 0.9376482057938698, 0.6480446128648567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 233}], {
             RGBColor[
             0.9748626422338834, 0.9780993949460502, 0.7789636593832132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 254}], {
             RGBColor[
             0.9234793483730712, 0.7829172870924861, 0.5955041038084421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 259}], {
             RGBColor[
             0.7099488174717532, 0.7711907329676471, 0.9554734955620947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 260}], {
             RGBColor[
             0.9023952825645615, 0.924495379134781, 0.9727268847769307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 288}], {
             RGBColor[
             0.9087689498125788, 0.7161208029301624, 0.5832293866647026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 29}], {
             RGBColor[
             0.24731665325336327`, 0.3772758617237455, 0.9373956895793536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 43}], {
             RGBColor[
             0.2869920462831278, 0.4177357289024586, 0.9397006014188156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 77}], {
             RGBColor[
             0.24892138027318342`, 0.37896253156714604`, 0.9374870764091515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 91}], {
             RGBColor[
             0.2622113968861681, 0.3929311816631146, 0.9382439231944433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 139}], {
             RGBColor[
             0.25364452897953216`, 0.38392686032244283`, 0.9377560527407058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 147}], {
             RGBColor[
             0.2390014851721345, 0.36853609285826733`, 0.9369221530583165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 148}], {
             RGBColor[
             0.24531191831194143`, 0.3751687581927745, 0.9372815228901793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 172}], {
             RGBColor[
             0.2606528759791422, 0.3912930773738975, 0.9381551677344133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 203}], {
             RGBColor[
             0.2557021473412196, 0.3860895476811155, 0.9378732310624303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 206}], {
             RGBColor[
             0.2442420605634609, 0.3740442698662223, 0.937220596074116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 244}], {
             RGBColor[
             0.2471607788887478, 0.37711202788352904`, 0.9373868127648843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 270}], {
             RGBColor[
             0.24003287271686014`, 0.3696201465615213, 0.9369808890531874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 272}], {
             RGBColor[
             0.23754533151077184`, 0.36700558303470066`, 0.9368392272614883]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 39}], {
             RGBColor[
             0.9266838506619479, 0.7398946126602461, 0.547796397964442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 59}], {
             RGBColor[
             0.9093225725856791, 0.6208046140216712, 0.5317333787947149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 60}], {
             RGBColor[
             0.9559587194852852, 0.8665294960501166, 0.5718984085520893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 62}], {
             RGBColor[
             0.9903418616011138, 0.9899003526601282, 0.7825545152346283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 82}], {
             RGBColor[
             0.9904558326619474, 0.9901441252350094, 0.7949595618585049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 100}], {
             RGBColor[
             0.9180076603888783, 0.6875620047068038, 0.5400502286834623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 127}], {
             RGBColor[
             0.9093035421850235, 0.6206583380230588, 0.5317151552615555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 130}], {
             RGBColor[
             0.5823809948253185, 0.6469022092217233, 0.9089577047840149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 137}], {
             RGBColor[
             0.9157005980775512, 0.6698289128207927, 0.5378409832086813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 170}], {
             RGBColor[
             0.903864214749553, 0.5788492838255521, 0.5265064491665074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 192}], {
             RGBColor[
             0.9254105636090766, 0.7341129135369036, 0.5467339360364043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 195}], {
             RGBColor[
             0.9024893735730009, 0.5682816520833267, 0.52518989970318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 199}], {
             RGBColor[
             0.5823809948253185, 0.6469022092217233, 0.9089577047840149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 220}], {
             RGBColor[
             0.6215133643769486, 0.6880328107560196, 0.9111862353388274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 226}], {
             RGBColor[
             0.5823809999360594, 0.646902214593436, 0.908957705075064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 228}], {
             RGBColor[
             0.901089116284713, 0.9224316156704129, 0.933371766463492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 266}], {
             RGBColor[
             0.6167344718352826, 0.6830098916954412, 0.9109140844783175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 32}], {
             RGBColor[
             0.25734797909016266`, 0.3878194212010146, 0.9379669587457427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 103}], {
             RGBColor[
             0.2686276829189324, 0.3996751050995809, 0.9386093211919647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 119}], {
             RGBColor[
             0.2703316084942079, 0.40146603891431676`, 0.9387063572327446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 152}], {
             RGBColor[
             0.2558672975304459, 0.3862631310011191, 0.9378826361213889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 268}], {
             RGBColor[
             0.2604774227946408, 0.3911086649526121, 0.9381451759351156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 35}], {
             RGBColor[
             0.2248219115083478, 0.35363246190073133`, 0.9361146473149633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 126}], {
             RGBColor[
             0.22467560955270433`, 0.3534786892692703, 0.9361063156350238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 163}], {
             RGBColor[
             0.23238600045450547`, 0.3615827989740821, 0.9365454109903801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 184}], {
             RGBColor[
             0.23042487690337662`, 0.35952153377943086`, 0.9364337279053656]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 189}], {
             RGBColor[
             0.22763054758381063`, 0.35658451649385525`, 0.9362745949844562]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 197}], {
             RGBColor[
             0.21695644286649302`, 0.3453653556586265, 0.9356667205117277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 211}], {
             RGBColor[
             0.2328859592843117, 0.3621082874034291, 0.9365738829061148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 216}], {
             RGBColor[
             0.24112529640186797`, 0.3707683531181266, 0.9370431009659527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 275}], {
             RGBColor[
             0.21809561015053047`, 0.3465626927015274, 0.9357315944033067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 293}], {
             RGBColor[
             0.21633697828784162`, 0.3447142591101412, 0.9356314429203892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 77}], {
             RGBColor[
             0.2444276826034072, 0.3742393703993229, 0.9372311669746878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 91}], {
             RGBColor[
             0.25771769921639187`, 0.38820802049529146`, 0.9379880137599795]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 148}], {
             RGBColor[
             0.2408182206421652, 0.3704455970249514, 0.9370256134557156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 162}], {
             RGBColor[
             0.2636748497853562, 0.39446936344843425`, 0.9383272646720675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 172}], {
             RGBColor[
             0.256159178309366, 0.3865699162060744, 0.9378992582999495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 191}], {
             RGBColor[
             0.24335597488348387`, 0.37311293763548947`, 0.9371701348054876]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 203}], {
             RGBColor[
             0.25120844967144335`, 0.38136638651329235`, 0.9376173216279664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 206}], {
             RGBColor[
             0.23974836289368467`, 0.3693211086983992, 0.9369646866396522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 244}], {
             RGBColor[
             0.24266708121897157`, 0.3723888667157059, 0.9371309033304205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 270}], {
             RGBColor[
             0.2355391750470839, 0.3648969853936982, 0.9367249796187237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 272}], {
             RGBColor[
             0.23305163384099561`, 0.36228242186687754`, 0.9365833178270244]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 38}], {
             RGBColor[
             0.4400713503236684, 0.5553482940395915, 0.949328558422408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 47}], {
             RGBColor[
             0.5531290988592262, 0.6480680925121483, 0.9579813085710855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 48}], {
             RGBColor[
             0.43794065467516774`, 0.5535027925607373, 0.9491927923797858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 74}], {
             RGBColor[
             0.5502062391736314, 0.6457212373265883, 0.9577333971010626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 90}], {
             RGBColor[
             0.4328724368509469, 0.5491129570174318, 0.9488698500216755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 123}], {
             RGBColor[
             0.44920952472312525`, 0.5632633214064009, 0.9499108348145711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 144}], {
             RGBColor[
             0.3889539475617518, 0.5110729690025859, 0.9460714027197632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 158}], {
             RGBColor[
             0.4329152304787701, 0.5491500227069821, 0.9488725767937995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 252}], {
             RGBColor[
             0.38136485218953986`, 0.5037401708621798, 0.9456156414781487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 257}], {
             RGBColor[
             0.42675186290096767`, 0.5438116234909512, 0.9484798524617939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 259}], {
             RGBColor[
             0.46322962709906557`, 0.5751097053927338, 0.9508862795927249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 36}], {
             RGBColor[
             0.6892039970441424, 0.7567703364683878, 0.9699034319627848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 51}], {
             RGBColor[
             0.8061994237416004, 0.8465221719044482, 0.8597460281820752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 58}], {
             RGBColor[
             0.583879953556761, 0.6730590756463584, 0.9603843152481828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 66}], {
             RGBColor[
             0.7826462994682315, 0.8305130082182347, 0.9693283290234715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 67}], {
             RGBColor[
             0.765577527957654, 0.8171802233035855, 0.9773175856314692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 73}], {
             RGBColor[
             0.47392342433375345`, 0.580416161461158, 0.9526607261917457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 95}], {
             RGBColor[
             0.5537416162054588, 0.648591415667946, 0.9580117149315208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 96}], {
             RGBColor[
             0.512151317735619, 0.6135272413360646, 0.9550965737557137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 109}], {
             RGBColor[
             0.7700026915435176, 0.8207087286290875, 0.9777396616846791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 110}], {
             RGBColor[
             0.8058913506986181, 0.8463947757840589, 0.8648515957717691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 138}], {
             RGBColor[
             0.662760313991049, 0.7361123302878763, 0.9672677727663206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 154}], {
             RGBColor[
             0.6800184039631393, 0.7495944813404151, 0.9689878978887183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 171}], {
             RGBColor[
             0.5185950159671473, 0.6191084488745244, 0.955507160509088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 245}], {
             RGBColor[
             0.5216196733437626, 0.6217282550704486, 0.9556998890025264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 156}], {
             RGBColor[
             0.24197823755521267`, 0.3716648483498845, 0.9370916747028223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 178}], {
             RGBColor[
             0.2666569110282901, 0.3976036988883609, 0.9384970886482884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 182}], {
             RGBColor[
             0.2817202883828383, 0.4134362635612778, 0.9393549257043601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 202}], {
             RGBColor[
             0.24218926046257408`, 0.37188664680514644`, 0.937103692145216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 208}], {
             RGBColor[
             0.27110861374646283`, 0.402282720699415, 0.9387506065323843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 268}], {
             RGBColor[
             0.2593869141835333, 0.38996247126009875`, 0.938083073082976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 37}], {
             RGBColor[
             0.7976827143280194, 0.8426403184805812, 0.9802661418189477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 75}], {
             RGBColor[
             0.8225875285373088, 0.8620961486244765, 0.9827484209506085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 94}], {
             RGBColor[
             0.8883058899064401, 0.9137750204630982, 0.9892086028509474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 124}], {
             RGBColor[
             0.931178231225007, 0.9476509487054876, 0.9825737296298357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 142}], {
             RGBColor[
             0.7868432036591011, 0.8341724103626897, 0.9791857606964562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 150}], {
             RGBColor[
             0.9383344799337505, 0.9529880672751867, 0.9704600672145196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 185}], {
             RGBColor[
             0.7413664787721765, 0.7975076391058051, 0.9754311281439616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 200}], {
             RGBColor[
             0.9003293088366926, 0.7550036483702731, 0.6091535540920102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 237}], {
             RGBColor[
             0.7767209844121652, 0.8262100194866766, 0.9782143643357628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 239}], {
             RGBColor[
             0.6628984653958889, 0.7326583838158534, 0.9695703125580974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 282}], {
             RGBColor[
             0.9391598487497231, 0.9536036259867218, 0.9690629330997416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 295}], {
             RGBColor[
             0.8759737184879801, 0.9039416817218939, 0.9880323493319954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 297}], {
             RGBColor[
             0.8375308432174786, 0.8737699796260231, 0.9842378309047126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 46}], {
             RGBColor[
             0.30981865996121394`, 0.44123557275110054`, 0.9410185715382298]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 50}], {
             RGBColor[
             0.33997412107403424`, 0.46889022890332593`, 0.9428838282608942]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 87}], {
             RGBColor[
             0.3018032451276056, 0.4328108635543251, 0.9405621055211995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 108}], {
             RGBColor[
             0.3357098066332535, 0.46519669406539743`, 0.9426121099155129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 114}], {
             RGBColor[
             0.31595519138804573`, 0.44768545635926527`, 0.9413680379248031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 169}], {
             RGBColor[
             0.3102621246711287, 0.4417016822785076, 0.9410438261974121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 187}], {
             RGBColor[
             0.34571434459052375`, 0.47386212200128636`, 0.9432495902274847]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 205}], {
             RGBColor[
             0.4284730033611293, 0.5434764368944227, 0.9490940379758643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 213}], {
             RGBColor[
             0.37768895869959807`, 0.5015569256517332, 0.9452869843644738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 227}], {
             RGBColor[
             0.2936321912026204, 0.4242225678044243, 0.9400967760881624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 264}], {
             RGBColor[
             0.31108024849077764`, 0.44256158228500475`, 0.9410904171386354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 92}], {
             RGBColor[
             0.24366421330036392`, 0.37343691575507476`, 0.9371876885273311]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 126}], {
             RGBColor[
             0.2260848753293333, 0.35495991695311835`, 0.9361865712361809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 163}], {
             RGBColor[
             0.23379526623113445`, 0.36306402665793014`, 0.9366256665915373]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 184}], {
             RGBColor[
             0.23183414268000563`, 0.3610027614632789, 0.9365139835065228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 189}], {
             RGBColor[
             0.2290398133604396, 0.3580657441777033, 0.9363548505856133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 197}], {
             RGBColor[
             0.218365708643122, 0.3468465833424746, 0.9357469761128849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 211}], {
             RGBColor[
             0.2342952250609407, 0.36358951508727716`, 0.936654138507272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 216}], {
             RGBColor[
             0.24253456217849695`, 0.3722495808019747, 0.9371233565671098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 275}], {
             RGBColor[
             0.21950487592715945`, 0.34804392038537546`, 0.9358118500044639]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 58}], {
             RGBColor[
             0.6542472259213957, 0.728390854886349, 0.9671515068891303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 66}], {
             RGBColor[
             0.8530135718328662, 0.8858447874582254, 0.9760955206644191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 67}], {
             RGBColor[
             0.8359448003222887, 0.8725120025435762, 0.9840847772724168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 69}], {
             RGBColor[
             0.8763046392583498, 0.8998097230462532, 0.7301395316538027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 88}], {
             RGBColor[
             0.6318962145275521, 0.7102452969352381, 0.9653919533977545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 95}], {
             RGBColor[
             0.6241088885700935, 0.7039231949079366, 0.9647789065724686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 96}], {
             RGBColor[
             0.5825185901002536, 0.6688590205760554, 0.9618637653966613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 109}], {
             RGBColor[
             0.8403699639081523, 0.8760405078690783, 0.9845068533256267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 113}], {
             RGBColor[
             0.8594902789211216, 0.8906751050000117, 0.9651321449597499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 138}], {
             RGBColor[
             0.7331275863556836, 0.791444109527867, 0.9740349644072682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 154}], {
             RGBColor[
             0.750385676327774, 0.8049262605804057, 0.9757550895296658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 198}], {
             RGBColor[
             0.6119133130274254, 0.6940222772779814, 0.9638188261918845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 222}], {
             RGBColor[
             0.5978519743815511, 0.6821400273622127, 0.9628407950842862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 224}], {
             RGBColor[
             0.8645479914252601, 0.8604819797945611, 0.6563901597051076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 245}], {
             RGBColor[
             0.5919869457083973, 0.6770600343104392, 0.9624670806434741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 258}], {
             RGBColor[
             0.8606691521172266, 0.8915543066994391, 0.9631366201381162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 260}], {
             RGBColor[
             0.8043625245684116, 0.8473291531354724, 0.9810724316171817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 278}], {
             RGBColor[
             0.681251390228536, 0.7503140519946241, 0.9692773736229017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 290}], {
             RGBColor[
             0.6862499936639361, 0.7543721434480005, 0.9696708819958241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 75}], {
             RGBColor[
             0.7056075851299448, 0.7699452754105638, 0.9712920278741198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 94}], {
             RGBColor[
             0.771325946499076, 0.8216241472491855, 0.9777522097744586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 102}], {
             RGBColor[
             0.5330127818666326, 0.6293292071697167, 0.9572915771331396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 124}], {
             RGBColor[
             0.8141982878176429, 0.8555000754915749, 0.971117336553347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 142}], {
             RGBColor[
             0.669863260251737, 0.742021537148777, 0.9677293676199676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 150}], {
             RGBColor[
             0.8213545365263866, 0.860837194061274, 0.9590036741380308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 185}], {
             RGBColor[
             0.6243865353648125, 0.7053567658918924, 0.9639747350674728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 237}], {
             RGBColor[
             0.6597410410048012, 0.7340591462727639, 0.9667579712592742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 239}], {
             RGBColor[
             0.5459185219885249, 0.6405075106019407, 0.9581139194816087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 282}], {
             RGBColor[
             0.8221799053423591, 0.8614527527728091, 0.9576065400232527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 283}], {
             RGBColor[
             0.6497129501444403, 0.725917890351978, 0.9659685232126394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 295}], {
             RGBColor[
             0.7589937750806162, 0.8117908085079812, 0.9765759562555065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 297}], {
             RGBColor[
             0.7205508998101146, 0.7816191064121104, 0.9727814378282238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 48}], {
             RGBColor[
             0.41581360034313486`, 0.5345785740431597, 0.947716252817703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 55}], {
             RGBColor[
             0.34731954937378307`, 0.4722891175276097, 0.9434603752963864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 74}], {
             RGBColor[
             0.5280791848415985, 0.6267970188090106, 0.9562568575389798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 90}], {
             RGBColor[
             0.41074538251891396`, 0.5301887384998543, 0.9473933104595927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 123}], {
             RGBColor[
             0.4270824703910924, 0.5443391028888234, 0.9484342952524883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 144}], {
             RGBColor[
             0.36682689322971884`, 0.49214875048500833`, 0.9445948631576804]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 158}], {
             RGBColor[
             0.41078817614673724`, 0.5302258041894045, 0.9473960372317167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 252}], {
             RGBColor[
             0.3592377978575069, 0.4848159523446023, 0.9441391019160659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 253}], {
             RGBColor[
             0.35733483343099304`, 0.48281581607742285`, 0.9440307309071595]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 257}], {
             RGBColor[
             0.4046248085689348, 0.5248874049733736, 0.9470033128997111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 259}], {
             RGBColor[
             0.44110257276703263`, 0.5561854868751561, 0.949409740030642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 52}], {
             RGBColor[
             0.8426203651830106, 0.3142479875093471, 0.1878844555501885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 59}], {
             RGBColor[
             0.8501714335969901, 0.3722888082384709, 0.1951153671911272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 60}], {
             RGBColor[
             0.8968075804965964, 0.6180136902669162, 0.2352803969485015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 62}], {
             RGBColor[
             0.931190722612425, 0.7413845468769279, 0.4459365036310404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 82}], {
             RGBColor[
             0.9313046936732585, 0.7416283194518091, 0.4583415502549171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 100}], {
             RGBColor[
             0.8588565214001893, 0.4390461989236035, 0.20343221707987458`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 107}], {
             RGBColor[
             0.8508398666409367, 0.3774266775234726, 0.1957554594288977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 127}], {
             RGBColor[
             0.8501524031963347, 0.3721425322398584, 0.1950971436579678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 136}], {
             RGBColor[
             0.9302201907265502, 0.7393086773088677, 0.34030009728209454`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 137}], {
             RGBColor[
             0.8565494590888623, 0.4213131070375924, 0.20122297160509353`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 141}], {
             RGBColor[
             0.8832675790785431, 0.5628271647927903, 0.22430794542071705`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 170}], {
             RGBColor[
             0.8447130757608642, 0.3303334780423518, 0.18988843756291957`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 192}], {
             RGBColor[
             0.8662594246203876, 0.48559710775370324`, 0.21011592443281657`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 220}], {
             RGBColor[
             0.5623622253882596, 0.4395170049728193, 0.5745682237352395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 228}], {
             RGBColor[
             0.8419379772960242, 0.6739158098872126, 0.5967537548599042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 232}], {
             RGBColor[
             0.9308146259118721, 0.7405801140636548, 0.40500069877565514`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 266}], {
             RGBColor[
             0.5575833328465938, 0.4344940859122408, 0.5742960728747296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 281}], {
             RGBColor[
             0.8518045532150162, 0.3848416812601996, 0.19667924438169382`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 65}], {
             RGBColor[
             0.2625645345612948, 0.39330235174989453`, 0.9382640338626215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.25252112623098183`, 0.38274609280586824`, 0.9376920766161012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 162}], {
             RGBColor[
             0.2608696072714334, 0.3915208757036531, 0.9381675102608841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 191}], {
             RGBColor[
             0.24055073236956107`, 0.37016444989070835`, 0.9370103803943042]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 76}], {
             RGBColor[
             0.32564319585170254`, 0.45514146543527656`, 0.9420195932129798]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 88}], {
             RGBColor[
             0.4306059655104517, 0.5460088371370204, 0.9490406986812941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 99}], {
             RGBColor[
             0.362239582391498, 0.48817545240188814`, 0.9443025637674687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 104}], {
             RGBColor[
             0.3210313076505878, 0.45029407852530423`, 0.9417569530026035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 157}], {
             RGBColor[
             0.35148560431038395`, 0.4788608970986815, 0.9436173297935095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 201}], {
             RGBColor[
             0.3390519049385823, 0.4680914516387281, 0.942825065464227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 209}], {
             RGBColor[
             0.3110735460011261, 0.43982783967316585`, 0.9411898732078549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 222}], {
             RGBColor[
             0.3965617253644508, 0.517903567563995, 0.9464895403678258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 229}], {
             RGBColor[
             0.35168976097882576`, 0.47903772734367334`, 0.943630338475894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 259}], {
             RGBColor[
             0.41062581045850305`, 0.5297880471701207, 0.9474677876858852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 261}], {
             RGBColor[
             0.3788160778841355, 0.5025331796387221, 0.9453588034022401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 278}], {
             RGBColor[
             0.4799611412114356, 0.5860775921964064, 0.9529261189064413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 290}], {
             RGBColor[
             0.4849597446468357, 0.5901356836497829, 0.9533196272793637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 55}], {
             RGBColor[
             0.2655663224814774, 0.39645742117835314`, 0.9384349812439285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[
             0.25595913612423093`, 0.3863596591860904, 0.937887866193442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 134}], {
             RGBColor[
             0.26421930785544107`, 0.3950416234007289, 0.9383582707537054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 144}], {
             RGBColor[
             0.28507366633741316`, 0.4163170541357517, 0.9395694691052225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 159}], {
             RGBColor[
             0.2509157891435835, 0.3810587817427625, 0.9376006550438574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 235}], {
             RGBColor[
             0.24823850572703557`, 0.37824478712239773`, 0.9374481877139709]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 252}], {
             RGBColor[
             0.2774845709652012, 0.40898425599534566`, 0.939113707863608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 292}], {
             RGBColor[
             0.24874967528223313`, 0.3787820587349321, 0.9374772980639317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 63}], {
             RGBColor[
             0.3233435154432426, 0.45448563418447746`, 0.9418241407759673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 131}], {
             RGBColor[
             0.3235024771639835, 0.45462331883733487`, 0.9418342696762487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 139}], {
             RGBColor[
             0.2888262243395204, 0.4196635663333328, 0.9398050551457039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 143}], {
             RGBColor[
             0.3594618944461463, 0.48576955871427996`, 0.9441255719478039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 172}], {
             RGBColor[
             0.2958345713391305, 0.4270297833847875, 0.9402041701394114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 174}], {
             RGBColor[
             0.35724861486395953`, 0.48385252718285615`, 0.9439845437299532]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 183}], {
             RGBColor[
             0.28838161647063476`, 0.4191962552733669, 0.9397797353853092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 185}], {
             RGBColor[
             0.4451220207260428, 0.5568482607152324, 0.9504446626081502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 244}], {
             RGBColor[
             0.28234247424873604`, 0.412848733894419, 0.9394358151698824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 59}], {
             RGBColor[
             0.8989327098919131, 0.5734920759622608, 0.24889953887676536`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 60}], {
             RGBColor[
             0.9455688567915195, 0.8192169579907062, 0.28906456863413965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 94}], {
             RGBColor[
             0.9135021931703009, 0.8932720957781641, 0.6527207002692943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 100}], {
             RGBColor[
             0.9076177976951124, 0.6402494666473935, 0.25721638876551267`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 121}], {
             RGBColor[
             0.9798326937990873, 0.9423326330377451, 0.48673505054828914`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 124}], {
             RGBColor[
             0.9563745344888678, 0.9271480240205534, 0.6460858270481826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 125}], {
             RGBColor[
             0.9788402151300284, 0.9402098215196141, 0.37870987228958564`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 137}], {
             RGBColor[
             0.9053107353837854, 0.6225163747613823, 0.25500714329073165`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 150}], {
             RGBColor[
             0.9635307831976114, 0.9324851425902525, 0.6339721646328667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 170}], {
             RGBColor[
             0.8934743520557873, 0.5315367457661417, 0.24367260924855771`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 192}], {
             RGBColor[
             0.9150207009153106, 0.6868003754774932, 0.26390009611845466`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 195}], {
             RGBColor[
             0.892099510879235, 0.5209691140239162, 0.24235605978523028`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 200}], {
             RGBColor[
             0.9255256121005535, 0.7345007236853389, 0.2726656515103572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 256}], {
             RGBColor[
             0.9801516197044022, 0.9430147833008583, 0.5214481671592728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 299}], {
             RGBColor[
             0.979769906119425, 0.942886287709507, 0.5299077867568601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 53}], {
             RGBColor[
             0.8447764554590436, 0.34517703459191124`, 0.19051129035634062`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 68}], {
             RGBColor[
             0.8660950044608668, 0.48393636846669774`, 0.20994293256664392`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 195}], {
             RGBColor[
             0.8384837744462674, 0.29680873085731074`, 0.18448541191193943`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 200}], {
             RGBColor[
             0.8719098756675858, 0.5103403405187334, 0.21479500363706636`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 215}], {
             RGBColor[
             0.9264635101364236, 0.7188538247686493, 0.4669105670802081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 223}], {
             RGBColor[
             0.872589282408941, 0.5134253678517513, 0.21536191727583626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 225}], {
             RGBColor[
             0.9093933228339569, 0.6627226292341221, 0.2529269618420678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 234}], {
             RGBColor[
             0.837571395698585, 0.28979578799570727`, 0.18361171699277434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 255}], {
             RGBColor[
             0.9083890640548784, 0.6593350285611156, 0.24902560612370514`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 282}], {
             RGBColor[
             0.9107404155806164, 0.7089403181351821, 0.5747043826447977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 287}], {
             RGBColor[
             0.899399401089056, 0.6245785965945915, 0.23718537302328563`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 50}], {
             RGBColor[
             0.32229358745653136`, 0.4520407279394575, 0.9418134628870861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 108}], {
             RGBColor[
             0.3180292730157506, 0.448347193101529, 0.9415417445417048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 114}], {
             RGBColor[
             0.29827465777054285`, 0.4308359553953969, 0.9402976725509951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 145}], {
             RGBColor[
             0.280670988716232, 0.4123333830822331, 0.9392951696406466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 169}], {
             RGBColor[
             0.2925815910536258, 0.4248521813146391, 0.9399734608236041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 187}], {
             RGBColor[
             0.32803381097302087`, 0.4570126210374179, 0.9421792248536764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 213}], {
             RGBColor[
             0.3600084250820952, 0.48470742468786476`, 0.9442166189906656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 219}], {
             RGBColor[
             0.2831865614508789, 0.4149774095228705, 0.9394384277864284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 221}], {
             RGBColor[
             0.2933757434234066, 0.4256868858074472, 0.9400186866262199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 264}], {
             RGBColor[
             0.29339971487327476`, 0.42571208132113636`, 0.9400200517648274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 48}], {
             RGBColor[
             0.5288713488786927, 0.6272983725157164, 0.9563690029663805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 74}], {
             RGBColor[
             0.6411369333771564, 0.7195168172815674, 0.9649096076876572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 90}], {
             RGBColor[
             0.5238031310544717, 0.622908536972411, 0.9560460606082701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.5238459246822951, 0.6229456026619612, 0.9560487873803941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 166}], {
             RGBColor[
             0.8183915236203407, 0.8543538869413033, 0.7072534135870767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 177}], {
             RGBColor[
             0.5316337139639098, 0.6296909943120255, 0.956545018426947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 217}], {
             RGBColor[
             0.7255477462839056, 0.7855226808548759, 0.9732794767865461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 233}], {
             RGBColor[
             0.8190741460647206, 0.8558139473261162, 0.781552654000438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 262}], {
             RGBColor[
             0.8190197652374052, 0.8556976322352333, 0.77563363654671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 273}], {
             RGBColor[
             0.6309474410941337, 0.7112445284148133, 0.9641074535297975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 74}], {
             RGBColor[
             0.5259484891930979, 0.6249515173301565, 0.9561210914963576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 84}], {
             RGBColor[
             0.35715044434118537`, 0.4830160061947183, 0.9440058041437522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 90}], {
             RGBColor[
             0.4086146868704133, 0.5283432370210001, 0.9472575444169704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 144}], {
             RGBColor[
             0.3646961975812182, 0.4903032490061542, 0.9444590971150582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 158}], {
             RGBColor[
             0.4086574804982366, 0.5283803027105503, 0.9472602711890945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 175}], {
             RGBColor[
             0.3540970438547585, 0.4798066886867111, 0.9438319175031515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 177}], {
             RGBColor[
             0.4164452697798513, 0.5351256943606145, 0.9477565022356473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 217}], {
             RGBColor[
             0.6103593020998471, 0.6909573809034649, 0.9644909605952465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 252}], {
             RGBColor[
             0.35710710220900627`, 0.48297045086574814`, 0.9440033358734436]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 253}], {
             RGBColor[
             0.3552041377824924, 0.4809703145985687, 0.9438949648645372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 57}], {
             RGBColor[
             0.2418037466004938, 0.3714814472931095, 0.9370817377010874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 84}], {
             RGBColor[
             0.2685862507813846, 0.39963155729606886`, 0.9386069616930247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 112}], {
             RGBColor[
             0.24438397329964223`, 0.374193429149736, 0.9372286777945005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 115}], {
             RGBColor[
             0.22907293102325943`, 0.358100552941108, 0.9363567365875176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 146}], {
             RGBColor[
             0.23350254559126715`, 0.3627563587058691, 0.9366089965841382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 159}], {
             RGBColor[
             0.24197412682758776`, 0.3716605277145155, 0.9370914406029653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 175}], {
             RGBColor[
             0.26553285029495766`, 0.3964222397880617, 0.9384330750524239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 204}], {
             RGBColor[
             0.23371861491604712`, 0.3629834612657993, 0.9366213014125385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 242}], {
             RGBColor[
             0.23849346114208345`, 0.3680021273920998, 0.9368932218413593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 243}], {
             RGBColor[
             0.2273605669768493, 0.3563007497581797, 0.9362592199882902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 253}], {
             RGBColor[
             0.2666399442226916, 0.39758586569991927`, 0.9384961224138098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 280}], {
             RGBColor[
             0.2523064385494426, 0.38252044244058536`, 0.9376798504702395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 292}], {
             RGBColor[
             0.23980801296623738`, 0.36938380470668514`, 0.9369680836230397]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 87}], {
             RGBColor[
             0.314278172622923, 0.4436160187426821, 0.9413569968700557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 108}], {
             RGBColor[
             0.3481847341285709, 0.4760018492537544, 0.9434070012643693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 114}], {
             RGBColor[
             0.32843011888336315`, 0.4584906115476223, 0.9421629292736595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 169}], {
             RGBColor[
             0.3227370521664461, 0.4525068374668645, 0.9418387175462686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 187}], {
             RGBColor[
             0.35818927208584117`, 0.4846672771896433, 0.9440444815763409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 205}], {
             RGBColor[
             0.44094793085644673`, 0.5542815920827796, 0.9498889293247207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 213}], {
             RGBColor[
             0.3901638861949155, 0.5123620808400902, 0.94608187571333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 227}], {
             RGBColor[
             0.30610711869793783`, 0.43502772299278125`, 0.9408916674370189]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 264}], {
             RGBColor[
             0.32355517598609507`, 0.45336673747336176`, 0.9418853084874919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 52}], {
             RGBColor[
             0.9056350707482277, 0.5643614773610739, 0.4604731703909181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 58}], {
             RGBColor[
             0.7712426526188537, 0.8181426903224094, 0.8569941031084208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 66}], {
             RGBColor[
             0.9700089985303242, 0.9755966228942858, 0.8659381168837096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 67}], {
             RGBColor[
             0.9529402270197467, 0.9622638379796367, 0.8739273734917072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 69}], {
             RGBColor[
             0.9933000659558078, 0.9895615584823135, 0.6199821278730931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 86}], {
             RGBColor[
             0.9842148587859489, 0.9592452118717956, 0.5566107984418112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[
             0.9138545722061537, 0.6275401673751994, 0.4683441742696273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 109}], {
             RGBColor[
             0.9573653906056103, 0.9657923433051386, 0.8743494495449171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 110}], {
             RGBColor[
             0.9932540497607107, 0.99147839046011, 0.7614613836320072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 138}], {
             RGBColor[
             0.8501230130531416, 0.8811959449639274, 0.8638775606265587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 141}], {
             RGBColor[
             0.9462822846437602, 0.812940654644517, 0.4968966602614467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 154}], {
             RGBColor[
             0.867381103025232, 0.8946780960164662, 0.8655976857489563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 165}], {
             RGBColor[
             0.986911243979133, 0.9683407522697562, 0.5670857457477134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 179}], {
             RGBColor[
             0.993604348606093, 0.9916232480349453, 0.7556560252196713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 258}], {
             RGBColor[
             0.9776645788146846, 0.9813061421354996, 0.8529792163574066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 281}], {
             RGBColor[
             0.9148192587802333, 0.6349551711119263, 0.4692679592224235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 82}], {
             RGBColor[
             0.90639234718301, 0.5644975000841104, 0.4350476194442515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 86}], {
             RGBColor[
             0.8962878067304835, 0.5320009026523702, 0.26072815279041595`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 107}], {
             RGBColor[
             0.8259275201506884, 0.20029585815577397`, 0.17246152861823205`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 110}], {
             RGBColor[
             0.9053269977052454, 0.5642340812406845, 0.4655787379806119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 141}], {
             RGBColor[
             0.8583552325882947, 0.3856963454250917, 0.20101401461005142`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 165}], {
             RGBColor[
             0.8989841919236675, 0.5410964430503309, 0.2712031000963182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 179}], {
             RGBColor[
             0.9056772965506277, 0.5643789388155198, 0.459773379568276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 193}], {
             RGBColor[
             0.6086028861336337, 0.3287818878860621, 0.5556335731143328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 236}], {
             RGBColor[
             0.7204593344779664, 0.42105333760098257`, 0.5640355482527617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 266}], {
             RGBColor[
             0.5326709863563452, 0.2573632665445422, 0.5510021420640641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 281}], {
             RGBColor[
             0.8268922067247678, 0.207710861892501, 0.1733853135710282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 59}], {
             RGBColor[
             0.8322696375208192, 0.249044151396152, 0.17853474737426642`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 68}], {
             RGBColor[
             0.8530476685227406, 0.3836488270671944, 0.19744878893743584`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 150}], {
             RGBColor[
             0.8968677108265174, 0.6080372180241437, 0.5636073731303677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 170}], {
             RGBColor[
             0.8268112796846933, 0.20708882120003286`, 0.1733078177460588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 192}], {
             RGBColor[
             0.8483576285442167, 0.36235245091138435`, 0.19353530461595575`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 195}], {
             RGBColor[
             0.825436438508141, 0.1965211894578074, 0.17199126828273137`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 200}], {
             RGBColor[
             0.8588625397294595, 0.4100527991192301, 0.2023008600078583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 225}], {
             RGBColor[
             0.8963459868958306, 0.5624350878346187, 0.24043281821285972`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 234}], {
             RGBColor[
             0.8245240597604586, 0.18950824659620397`, 0.17111757336356628`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 255}], {
             RGBColor[
             0.8953417281167521, 0.5590474871616122, 0.23653146249449708`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 282}], {
             RGBColor[
             0.89769307964249, 0.6086527767356787, 0.5622102390155896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 287}], {
             RGBColor[
             0.8863520651509298, 0.5242910551950881, 0.22469122939407754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 72}], {
             RGBColor[
             0.534606977221836, 0.6319372303906756, 0.9568737438527076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 106}], {
             RGBColor[
             0.5370375913061106, 0.6338360445866622, 0.9571160047492481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 151}], {
             RGBColor[
             0.4303399784091667, 0.5471605926069658, 0.9486418607828988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 167}], {
             RGBColor[
             0.585666437251012, 0.671825268631737, 0.9619628736506332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 194}], {
             RGBColor[
             0.4666198015964266, 0.5768869180196359, 0.9514225850947327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 238}], {
             RGBColor[
             0.34796050319161576`, 0.47301253149465217`, 0.9434950557775005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 251}], {
             RGBColor[
             0.3520600889143901, 0.4773214560180356, 0.9437285211196189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 286}], {
             RGBColor[
             0.4882211414959945, 0.5944238588793778, 0.953123121699942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 90}], {
             RGBColor[
             0.3401206359010615, 0.4660537805054501, 0.9430016668956538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 97}], {
             RGBColor[
             0.26708761639868417`, 0.39805639754094285`, 0.9385216166819608]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 134}], {
             RGBColor[
             0.27534778812989436`, 0.40673836175558137`, 0.9389920212422243]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 144}], {
             RGBColor[
             0.2962021466118664, 0.42801379249060423`, 0.9402032195937415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 159}], {
             RGBColor[
             0.26204426941803677`, 0.39275552009761494`, 0.9382344055323761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 235}], {
             RGBColor[
             0.25936698600148883`, 0.38994152547725025`, 0.9380819382024896]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 252}], {
             RGBColor[
             0.2886130512396545, 0.4206809943501981, 0.9397474583521269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 253}], {
             RGBColor[
             0.2867100868131406, 0.4186808580830187, 0.9396390873432205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 292}], {
             RGBColor[
             0.25987815555668636`, 0.39047879708978456`, 0.9381110485524506]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 79}], {
             RGBColor[
             0.47131158576889715`, 0.5800856534095411, 0.9519605579459619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 93}], {
             RGBColor[
             0.5394509250519448, 0.6369895888012234, 0.9568866993753897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 160}], {
             RGBColor[
             0.5689561966042058, 0.6609432974446849, 0.9592094624333546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 164}], {
             RGBColor[
             0.46580833431938506`, 0.5753190136054342, 0.9516098956299331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 168}], {
             RGBColor[
             0.46678271330407606`, 0.5761629717082618, 0.9516719821972282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 246}], {
             RGBColor[
             0.57328015808247, 0.6644536841649844, 0.9595498605201163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 296}], {
             RGBColor[
             0.6219639893106997, 0.70315209105388, 0.9639467061714042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 84}], {
             RGBColor[
             0.27383547980684575`, 0.4051488298221716, 0.9389058975204863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 89}], {
             RGBColor[
             0.26259271630004477`, 0.3933319725441461, 0.9382656387709521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 112}], {
             RGBColor[
             0.24963320232510341`, 0.37971070167583876`, 0.9375276136219621]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 115}], {
             RGBColor[
             0.2343221600487206, 0.3636178254672108, 0.9366556724149793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 134}], {
             RGBColor[
             0.26052687456490653`, 0.3911606418985847, 0.938147992140275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 146}], {
             RGBColor[
             0.23875177461672836`, 0.3682736312319718, 0.9369079324115999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 159}], {
             RGBColor[
             0.24722335585304894`, 0.3771778002406183, 0.937390376430427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 175}], {
             RGBColor[
             0.27078207932041887`, 0.40193951231416447`, 0.9387320108798856]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 204}], {
             RGBColor[
             0.23896784394150833`, 0.36850073379190207`, 0.9369202372400001]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 235}], {
             RGBColor[
             0.24454607243650103`, 0.3743638056202535, 0.9372379091005405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 242}], {
             RGBColor[
             0.24374269016754463`, 0.3735193999182025, 0.9371921576688209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 243}], {
             RGBColor[
             0.23260979600231052`, 0.3618180222842825, 0.9365581558157519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 253}], {
             RGBColor[
             0.27188917324815276`, 0.40310313822602206`, 0.9387950582412713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 280}], {
             RGBColor[
             0.2575556675749038, 0.38803771496668804`, 0.9379787862977012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 292}], {
             RGBColor[
             0.2450572419916986, 0.37490107723278787`, 0.9372670194505013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 66}], {
             RGBColor[
             0.747689528345485, 0.802133526636196, 0.966576403949817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 67}], {
             RGBColor[
             0.7306207568349073, 0.7888007417215468, 0.9745656605578148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 73}], {
             RGBColor[
             0.4389666532110068, 0.5520366798791193, 0.9499088011180912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 95}], {
             RGBColor[
             0.5187848450827122, 0.6202119340859072, 0.9552597898578664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 96}], {
             RGBColor[
             0.47719454661287236`, 0.585147759754026, 0.9523446486820593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 109}], {
             RGBColor[
             0.7350459204207711, 0.7923292470470489, 0.9749877366110247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 138}], {
             RGBColor[
             0.6278035428683023, 0.7077328487058376, 0.9645158476926661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 140}], {
             RGBColor[
             0.4384985979215843, 0.5516312739125644, 0.9498789770489342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 154}], {
             RGBColor[
             0.6450616328403926, 0.7212149997583763, 0.9662359728150638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 171}], {
             RGBColor[
             0.48363824484440066`, 0.5907289672924857, 0.9527552354354336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 198}], {
             RGBColor[
             0.506589269540044, 0.610311016455952, 0.9542997094772824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 245}], {
             RGBColor[
             0.48666290222101594`, 0.5933487734884098, 0.952947963928872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 62}], {
             RGBColor[
             0.9138294445361559, 0.6222945482383531, 0.42987348446131357`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 100}], {
             RGBColor[
             0.8414952433239204, 0.3199562002850287, 0.1873691979101476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 125}], {
             RGBColor[
             0.9127176607588363, 0.6199165551572493, 0.3088626814342206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 137}], {
             RGBColor[
             0.8391881810125934, 0.30222310839901756`, 0.1851599524353666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 170}], {
             RGBColor[
             0.8273517976845952, 0.21124347940377694`, 0.17382541839319265`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 192}], {
             RGBColor[
             0.8488981465441187, 0.3665071091151284, 0.1940529052630896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 195}], {
             RGBColor[
             0.825976956508043, 0.20067584766155147`, 0.17250886892986522`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 200}], {
             RGBColor[
             0.8594030577293614, 0.41420745732297415`, 0.20281846065499215`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 225}], {
             RGBColor[
             0.8968865048957325, 0.5665897460383628, 0.24095041885999358`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 228}], {
             RGBColor[
             0.8245766992197552, 0.5548258112486377, 0.5806907356901773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 255}], {
             RGBColor[
             0.895882246116654, 0.5632021453653563, 0.23704906314163093`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 82}], {
             RGBColor[
             0.9605795624965958, 0.8682632028416796, 0.48244356084256446`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 85}], {
             RGBColor[
             0.9228540566499766, 0.8416985659067688, 0.6257891591988634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 100}], {
             RGBColor[
             0.8881313902235266, 0.565681082313474, 0.22753422766752193`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 121}], {
             RGBColor[
             0.9603462863275016, 0.8677642487038257, 0.4570528894502983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 125}], {
             RGBColor[
             0.9593538076584427, 0.8656414371856946, 0.3490277111915949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 127}], {
             RGBColor[
             0.879427272019672, 0.4987774156297289, 0.21919915424561515`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 136}], {
             RGBColor[
             0.9594950595498875, 0.8659435606987382, 0.3644021078697419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 137}], {
             RGBColor[
             0.8858243279121996, 0.5479479904274629, 0.22532498219274089`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 170}], {
             RGBColor[
             0.8739879445842015, 0.4569683614322223, 0.21399044815056695`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 232}], {
             RGBColor[
             0.9600894947352094, 0.8672149974535253, 0.4291027093633025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 240}], {
             RGBColor[
             0.9605080040332614, 0.868110146524278, 0.47465486371626864`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 256}], {
             RGBColor[
             0.9606652122328164, 0.8684463989669389, 0.49176600606128196`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 299}], {
             RGBColor[
             0.9602834986478392, 0.8683179033755875, 0.5002256256588694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 177}], {
             RGBColor[
             0.49302351294995017`, 0.5983715477396933, 0.9534876687205165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 217}], {
             RGBColor[
             0.686937545269946, 0.7542032342825437, 0.9702221270801157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 247}], {
             RGBColor[
             0.5729638190353659, 0.6641968658756336, 0.9595249571515402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 267}], {
             RGBColor[
             0.517343318582302, 0.6190416379328455, 0.9551463076112685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 273}], {
             RGBColor[
             0.5923372400801741, 0.6799250818424811, 0.9610501038233672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 285}], {
             RGBColor[
             0.474805368949063, 0.5825919070766665, 0.9523268246944521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 82}], {
             RGBColor[
             0.9949627046124243, 0.9916340594516913, 0.6930996675251034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 100}], {
             RGBColor[
             0.9225145323393552, 0.6890519389234857, 0.4381903343500609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 127}], {
             RGBColor[
             0.9138104141355006, 0.6221482722397406, 0.4298552609281541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 130}], {
             RGBColor[
             0.5868878667757954, 0.648392143438405, 0.8070978104506135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 137}], {
             RGBColor[
             0.9202074700280282, 0.6713188470374746, 0.43598108887527987`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 170}], {
             RGBColor[
             0.9083710867000301, 0.580339218042234, 0.42464655483310587`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 192}], {
             RGBColor[
             0.9299174355595534, 0.7356028477535854, 0.4448740417030029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 195}], {
             RGBColor[
             0.9069962455234778, 0.5697715863000085, 0.4233300053697785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 199}], {
             RGBColor[
             0.5868878667757954, 0.648392143438405, 0.8070978104506135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 220}], {
             RGBColor[
             0.6260202363274255, 0.6895227449727015, 0.8093263410054259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 225}], {
             RGBColor[
             0.9779057939111673, 0.9356854846768198, 0.49177155529990685`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 226}], {
             RGBColor[
             0.5868878718865363, 0.6483921488101179, 0.8070978107416625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 228}], {
             RGBColor[
             0.90559598823519, 0.9239215498870947, 0.8315118721300905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 255}], {
             RGBColor[
             0.9769015351320889, 0.9322978840038133, 0.4878701995815442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 131}], {
             RGBColor[
             0.32467225096411007`, 0.4556365181084638, 0.9419088066284024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 139}], {
             RGBColor[
             0.28999599813964694`, 0.42067676560446166`, 0.9398795920978575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 143}], {
             RGBColor[
             0.36063166824627285`, 0.4867827579854089, 0.9442001088999576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 172}], {
             RGBColor[
             0.29700434513925705`, 0.4280429826559164, 0.940278707091565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 174}], {
             RGBColor[
             0.35841838866408615`, 0.48486572645398507`, 0.944059080682107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 183}], {
             RGBColor[
             0.28955139027076127`, 0.4202094545444958, 0.939854272337463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 283}], {
             RGBColor[
             0.4716182093057971, 0.5784225844464469, 0.9525129877054703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 92}], {
             RGBColor[
             0.24737632360791623`, 0.3773385790496996, 0.9373990877177711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 145}], {
             RGBColor[
             0.2514296244944172, 0.3815988552755316, 0.937629917206936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 153}], {
             RGBColor[
             0.253568524812987, 0.38384697512446136`, 0.9377517244158591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 211}], {
             RGBColor[
             0.238007335368493, 0.36749117838190204`, 0.936865537697712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 219}], {
             RGBColor[
             0.2539451972290641, 0.384242881716169, 0.9377731753527179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 221}], {
             RGBColor[
             0.26413437920159183`, 0.3949523580007457, 0.9383534341925093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 80}], {
             RGBColor[
             0.27787319023653523`, 0.40939271948940265`, 0.9391358391561999]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 103}], {
             RGBColor[
             0.2833667383517215, 0.41516678686953135`, 0.9394486885943836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 116}], {
             RGBColor[
             0.3051622199360282, 0.4368120893539453, 0.940736158424998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 133}], {
             RGBColor[
             0.3190318248130566, 0.44882524399181684`, 0.9416199173833522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 152}], {
             RGBColor[
             0.270606352963235, 0.4017548127710696, 0.9387220035238077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 162}], {
             RGBColor[
             0.28622167127698683`, 0.41816750238718753`, 0.9396112728009827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[
             0.33323684341077736`, 0.46112891713616844`, 0.9425250486073942]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 241}], {
             RGBColor[
             0.2834960053804121, 0.4153026547126882, 0.9394560501604341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 277}], {
             RGBColor[
             0.318505826054183, 0.44836965030434695`, 0.9415864012075592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 67}], {
             RGBColor[
             0.9293871027463778, 0.9462546742934231, 0.9835096743331035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 69}], {
             RGBColor[
             0.9697469416824389, 0.9735523947961, 0.7295644287144893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 95}], {
             RGBColor[
             0.7175511909941827, 0.7776658666577836, 0.9642038036331552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 109}], {
             RGBColor[
             0.9338122663322416, 0.9497831796189251, 0.9839317503863134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 110}], {
             RGBColor[
             0.969700925487342, 0.9754692267738965, 0.8710436844734033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 138}], {
             RGBColor[
             0.8265698887797728, 0.8651867812777139, 0.9734598614679548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 154}], {
             RGBColor[
             0.8438279787518632, 0.8786689323302527, 0.9751799865903525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 179}], {
             RGBColor[
             0.9700512243327243, 0.9756140843487318, 0.8652383260610674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 258}], {
             RGBColor[
             0.9541114545413159, 0.9652969784492861, 0.9625615171988029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 69}], {
             RGBColor[
             0.9526781701718614, 0.9602196098814508, 0.7375536853224871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 86}], {
             RGBColor[
             0.9435929630020026, 0.929903263270933, 0.6741823558912051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 95}], {
             RGBColor[
             0.7004824194836051, 0.7643330817431344, 0.9721930602411528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 109}], {
             RGBColor[
             0.916743494821664, 0.9364503947042759, 0.9919210069943111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 110}], {
             RGBColor[
             0.9526321539767644, 0.9621364418592473, 0.8790329410814011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 138}], {
             RGBColor[
             0.8095011172691953, 0.8518539963630647, 0.9814491180759526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 154}], {
             RGBColor[
             0.8267592072412856, 0.8653361474156035, 0.9831692431983503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 179}], {
             RGBColor[
             0.9529824528221467, 0.9622812994340826, 0.8732275826690652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 258}], {
             RGBColor[
             0.9370426830307382, 0.9519641935346369, 0.9705507738068005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 215}], {
             RGBColor[
             0.9347347232001206, 0.7573256172439325, 0.47384806566130333`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 223}], {
             RGBColor[
             0.880860495472638, 0.5518971603270344, 0.22229941585693147`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 234}], {
             RGBColor[
             0.8458426087622819, 0.3282675804709904, 0.19054921557386956`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 255}], {
             RGBColor[
             0.9166602771185755, 0.6978068210363987, 0.2559631047048003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 271}], {
             RGBColor[
             0.9259155815977133, 0.7290271362933656, 0.2919182148886562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 274}], {
             RGBColor[
             0.9194708353599413, 0.7072874939349834, 0.2668815927431183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 287}], {
             RGBColor[
             0.9076706141527531, 0.6630503890698746, 0.24412287160438084`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 109}], {
             RGBColor[
             0.957103333757725, 0.9637481152069529, 0.737975761375697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 110}], {
             RGBColor[
             0.9929919929128255, 0.9894341623619243, 0.625087695462787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 113}], {
             RGBColor[
             0.9762236487706943, 0.9783827123378863, 0.71860105300982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 135}], {
             RGBColor[
             0.9915668730357023, 0.9888448386688236, 0.6487056199187353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 138}], {
             RGBColor[
             0.8498609562052564, 0.8791517168657417, 0.7275038724573385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 224}], {
             RGBColor[
             0.9812813612748328, 0.9481895871324358, 0.4098590677551779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 249}], {
             RGBColor[
             0.9058089885195326, 0.5656683412312807, 0.3245169720093974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 254}], {
             RGBColor[
             0.9421799602264942, 0.7934586684310521, 0.3573185586987633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 258}], {
             RGBColor[
             0.9774025219667993, 0.9792619140373138, 0.7166055281881865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 288}], {
             RGBColor[
             0.9274695616660017, 0.7266621842687284, 0.34504384155502377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[
             0.27137415800540265`, 0.40256182455203926`, 0.9387657288850935]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 251}], {
             RGBColor[
             0.27547374372817707`, 0.40687074907542276`, 0.9389991942272118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 300}], {
             RGBColor[
             0.2600472811884571, 0.39065655885195993`, 0.938120680006981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 85}], {
             RGBColor[
             0.7746111080065263, 0.8244612139777192, 0.9780896021036154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 98}], {
             RGBColor[
             0.5262018737865255, 0.625404972246536, 0.9560725859325541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 121}], {
             RGBColor[
             0.8121033376840514, 0.8505268967747761, 0.8093533323550504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 122}], {
             RGBColor[
             0.6268946494046528, 0.707980343525642, 0.9637705896733515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 136}], {
             RGBColor[
             0.8112521109064372, 0.8487062087696886, 0.716702550774494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 160}], {
             RGBColor[
             0.6099082730566356, 0.6941900379787878, 0.9624333599040888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 181}], {
             RGBColor[
             0.6717068148993812, 0.7432662316253906, 0.9680467833618187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 207}], {
             RGBColor[
             0.6875924129964879, 0.7556761815938675, 0.9696301113207838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 232}], {
             RGBColor[
             0.8118465460917592, 0.8499776455244756, 0.7814031522680547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 240}], {
             RGBColor[
             0.8122650553898112, 0.8508727945952284, 0.8269553066210207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 246}], {
             RGBColor[
             0.6142322345348998, 0.6977004246990872, 0.9627737579908505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 256}], {
             RGBColor[
             0.8124222635893662, 0.8512090470378892, 0.8440664489660341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 296}], {
             RGBColor[
             0.6629160657631297, 0.7363988315879828, 0.9671706036421385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 299}], {
             RGBColor[
             0.812040550004389, 0.8510805514465378, 0.8525260685636215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 106}], {
             RGBColor[
             0.6542381545327312, 0.7298150858058879, 0.966172003106812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 151}], {
             RGBColor[
             0.5475405416357872, 0.6431396338261914, 0.9576978591404627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 194}], {
             RGBColor[
             0.5838203648230471, 0.6728659592388615, 0.9604785834522965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 215}], {
             RGBColor[
             0.8234553846620669, 0.8600796725778928, 0.8483727211925696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 247}], {
             RGBColor[
             0.6154478937421781, 0.6985426120193529, 0.9629684183842664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 267}], {
             RGBColor[
             0.5598273932891142, 0.6533873840765647, 0.9585897688439947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 286}], {
             RGBColor[
             0.6054217047226151, 0.6904029000986035, 0.9621791200575058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 87}], {
             RGBColor[
             0.3025587103322468, 0.4334652095438001, 0.9406102430960075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 95}], {
             RGBColor[
             0.4088283158597046, 0.5275690199007069, 0.9475362008014293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 96}], {
             RGBColor[
             0.3672380173898648, 0.4925048455688256, 0.9446210596256222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 105}], {
             RGBColor[
             0.30909022810020703`, 0.4403302488400713, 0.9409822033703782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 140}], {
             RGBColor[
             0.3285420686985767, 0.45898835972736407`, 0.9421553879924971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 149}], {
             RGBColor[
             0.3114795465639533, 0.4428415740370091, 0.9411182715222086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 171}], {
             RGBColor[
             0.3736817156213931, 0.4980860531072854, 0.9450316463789965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 245}], {
             RGBColor[
             0.37670637299800835`, 0.5007058593032094, 0.9452243748724349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 289}], {
             RGBColor[
             0.309996695985159, 0.44128300406053933`, 0.9410338253754271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 298}], {
             RGBColor[
             0.307131102255913, 0.43827108336196546`, 0.9408706340518126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 90}], {
             RGBColor[
             0.5208802713688769, 0.620561681786851, 0.9557981491382472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 123}], {
             RGBColor[
             0.5372173592410554, 0.6347120461758202, 0.9568391339311428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 158}], {
             RGBColor[
             0.5209230649967003, 0.6205987474764012, 0.9558008759103712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 233}], {
             RGBColor[
             0.8161512863791258, 0.8534670921405562, 0.7813047425304152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 257}], {
             RGBColor[
             0.5147596974188978, 0.6152603482603705, 0.9554081515783656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 259}], {
             RGBColor[
             0.5512374616169957, 0.646558430162153, 0.9578145787092965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 262}], {
             RGBColor[
             0.8160969055518104, 0.8533507770496733, 0.7753857250766871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 124}], {
             RGBColor[
             0.8391031020269322, 0.8749559056354701, 0.9735996156850079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 142}], {
             RGBColor[
             0.6947680744610263, 0.7614773672926725, 0.9702116467516284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 143}], {
             RGBColor[
             0.5636312232942053, 0.6537338940348352, 0.9601379235387875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 150}], {
             RGBColor[
             0.8462593507356758, 0.8802930242051693, 0.9614859532696918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 167}], {
             RGBColor[
             0.7422194299230214, 0.7985467268232416, 0.9749411544059516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 174}], {
             RGBColor[
             0.5614179437120186, 0.6518168625034114, 0.9599968953209368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 185}], {
             RGBColor[
             0.6492913495741017, 0.7248125960357876, 0.9664570141991338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 237}], {
             RGBColor[
             0.6846458552140906, 0.7535149764166593, 0.969240250390935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 239}], {
             RGBColor[
             0.5708233361978141, 0.6599633407458361, 0.9605961986132696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 282}], {
             RGBColor[
             0.8470847195516484, 0.8809085829167043, 0.9600888191549137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 283}], {
             RGBColor[
             0.6746177643537297, 0.7453737204958732, 0.9684508023443001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 295}], {
             RGBColor[
             0.7838985892899054, 0.8312466386518764, 0.9790582353871675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 297}], {
             RGBColor[
             0.7454557140194038, 0.8010749365560057, 0.9752637169598848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 99}], {
             RGBColor[
             0.3308920068686242, 0.45968772172522177`, 0.9423540428096366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[
             0.2896837321277139, 0.4218063478486378, 0.9398084320447715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 128}], {
             RGBColor[
             0.2667781164198233, 0.397731093439728, 0.9385039911160289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[
             0.3201380287875101, 0.4503731664220151, 0.9416688088356775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 201}], {
             RGBColor[
             0.3077043294157084, 0.43960372096206174`, 0.9408765445063949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 209}], {
             RGBColor[
             0.2797259704782522, 0.4113401089964994, 0.9392413522500229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 218}], {
             RGBColor[
             0.2751691719679872, 0.4065506248444982, 0.9389818493160426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 229}], {
             RGBColor[
             0.32034218545595194`, 0.4505499966670069, 0.9416818175180619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 261}], {
             RGBColor[
             0.3474685023612617, 0.4740454489620557, 0.9434102824444082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 284}], {
             RGBColor[
             0.2749699198453155, 0.406341198230256, 0.9389705022024235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 91}], {
             RGBColor[
             0.25932242623621204`, 0.38989469033869195`, 0.9380794005897775]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 162}], {
             RGBColor[
             0.26527957680517633`, 0.3961560332918348, 0.9384186515018654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 191}], {
             RGBColor[
             0.24496070190330402`, 0.37479960747889, 0.9372615216352855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 203}], {
             RGBColor[
             0.25281317669126346`, 0.38305305635669296`, 0.9377087084577643]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 206}], {
             RGBColor[
             0.2413530899135048, 0.3710077785417997, 0.9370560734694501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 244}], {
             RGBColor[
             0.2442718082387917, 0.3740755365591065, 0.9372222901602183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 270}], {
             RGBColor[
             0.23714390206690406`, 0.36658365523709874`, 0.9368163664485216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 118}], {
             RGBColor[
             0.17948494456776543`, 0.30598043511645023`, 0.9335327741177293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 120}], {
             RGBColor[
             0.1849774474258748, 0.3117534038651181, 0.9338455640300687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 130}], {
             RGBColor[
             0.17948366008578914`, 0.30597908504445237`, 0.9335327009683809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 176}], {
             RGBColor[
             0.17949609924511575`, 0.30599215938959284`, 0.9335334093601024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 193}], {
             RGBColor[
             0.2897690368730418, 0.4135053888596902, 0.9401205117129523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 199}], {
             RGBColor[
             0.17948366008578914`, 0.30597908504445237`, 0.9335327009683809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 220}], {
             RGBColor[
             0.21861602963741927`, 0.34710968657874874`, 0.9357612315231933]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 226}], {
             RGBColor[
             0.17948366519653014`, 0.30597909041616517`, 0.9335327012594301]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 236}], {
             RGBColor[
             0.4016254852173745, 0.5057768385746106, 0.9485224868513811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 266}], {
             RGBColor[
             0.21383713709575333`, 0.3420867675181703, 0.9354890806626834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 93}], {
             RGBColor[
             0.46307011169266854`, 0.5733948534802826, 0.9513117589171669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 103}], {
             RGBColor[
             0.33687382527310783`, 0.4634377566971172, 0.9427875991368931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 116}], {
             RGBColor[
             0.3586693068574145, 0.48508305918153105`, 0.9440750689675076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 119}], {
             RGBColor[
             0.3385777508483834, 0.465228690511853, 0.9428846351776731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 164}], {
             RGBColor[
             0.38942752096010885`, 0.5117242782844935, 0.9460349551717104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 168}], {
             RGBColor[
             0.3904018999447999, 0.5125682363873212, 0.9460970417390054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 241}], {
             RGBColor[
             0.3370030923017984, 0.46357362454027395`, 0.9427949607029437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 277}], {
             RGBColor[
             0.3720129129755694, 0.49664062013193266`, 0.9449253117500688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 103}], {
             RGBColor[
             0.2733233300214085, 0.4046105279255051, 0.9388767313478634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 116}], {
             RGBColor[
             0.2951188116057152, 0.426255830409919, 0.9401642011784779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 133}], {
             RGBColor[
             0.30898841648274356`, 0.43826898504779055`, 0.941047960136832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 152}], {
             RGBColor[
             0.26056294463292196`, 0.39119855382704327`, 0.9381500462772876]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 210}], {
             RGBColor[
             0.3231934350804644, 0.45057265819214215`, 0.941953091360874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 241}], {
             RGBColor[
             0.27345259705009906`, 0.4047463957686619, 0.938884092913914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 277}], {
             RGBColor[
             0.30846241772387, 0.4378133913603206, 0.9410144439610391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 180}], {
             RGBColor[
             0.26493370488523493`, 0.3957924999744301, 0.9383989546076965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[
             0.3818442604921369, 0.5035684061042389, 0.9457044452357559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 285}], {
             RGBColor[
             0.33930631085889784`, 0.4671186752480599, 0.9428849623189395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 100}], {
             RGBColor[
             0.9226285034001888, 0.6892957114983669, 0.45059538097393753`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 107}], {
             RGBColor[
             0.9146118486409361, 0.6276761900982359, 0.44291862332296067`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 127}], {
             RGBColor[
             0.9139243851963341, 0.6223920448146217, 0.4422603075520308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 137}], {
             RGBColor[
             0.9203214410888617, 0.6715626196123557, 0.4483861354991565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 192}], {
             RGBColor[
             0.930031406620387, 0.7358466203284666, 0.4572790883268795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 199}], {
             RGBColor[
             0.587001837836629, 0.6486359160132862, 0.81950285707449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 220}], {
             RGBColor[
             0.6261342073882591, 0.6897665175475827, 0.8217313876293025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 226}], {
             RGBColor[
             0.5870018429473699, 0.648635921384999, 0.8195028573655392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 228}], {
             RGBColor[
             0.9057099592960236, 0.9241653224619759, 0.8439169187539672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 266}], {
             RGBColor[
             0.6213553148465931, 0.6847435984870042, 0.8214592367687926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 281}], {
             RGBColor[
             0.9155765352150156, 0.6350911938349629, 0.44384240827575683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 126}], {
             RGBColor[
             0.22111352999763184`, 0.3497347178080009, 0.9359034604739869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 155}], {
             RGBColor[
             0.21429563561346426`, 0.34256867853076955`, 0.9355151914749793]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 156}], {
             RGBColor[
             0.221993745626472, 0.35065988024280614`, 0.935953587451887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 184}], {
             RGBColor[
             0.22686279734830417`, 0.3557775623181615, 0.9362308727443287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[
             0.21339436331142053`, 0.34162138419735716`, 0.9354638653506908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 202}], {
             RGBColor[
             0.22220476853383342`, 0.3508816786980681, 0.9359656048942807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 214}], {
             RGBColor[
             0.21458531177906248`, 0.342873146547343, 0.9355316881040727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 275}], {
             RGBColor[
             0.214533530595458, 0.34281872124025803`, 0.9355287392422698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 293}], {
             RGBColor[
             0.21277489873276917`, 0.34097028764887183`, 0.9354285877593523]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 89}], {
             RGBColor[
             0.2893752204809355, 0.4214820825471055, 0.9397908627628895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.35208222651696447`, 0.4786261706514128, 0.9436828617856419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 112}], {
             RGBColor[
             0.2764157065059942, 0.4078608116787981, 0.9390528376138995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 134}], {
             RGBColor[
             0.2873093787457973, 0.41931075190154404`, 0.9396732161322123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 144}], {
             RGBColor[
             0.30816373722776935`, 0.4405861826365669, 0.9408844144837296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 158}], {
             RGBColor[
             0.35212502014478775`, 0.47866323634096297`, 0.943685588557766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 159}], {
             RGBColor[
             0.27400586003393973`, 0.4053279102435776, 0.9389156004223643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 175}], {
             RGBColor[
             0.29756458350130965`, 0.4300896223171238, 0.940257234871823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 252}], {
             RGBColor[
             0.30057464185555743`, 0.4332533844961608, 0.9404286532421151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 253}], {
             RGBColor[
             0.29867167742904355`, 0.43125324822898137`, 0.9403202822332086]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 280}], {
             RGBColor[
             0.28433817175579457`, 0.41618782496964746`, 0.9395040102896386]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 292}], {
             RGBColor[
             0.2718397461725893, 0.40305118723574723`, 0.9387922434424387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 121}], {
             RGBColor[
             0.9571178936575444, 0.9648142409538079, 0.8234596411130128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 122}], {
             RGBColor[
             0.7719092053781459, 0.8222676877046737, 0.9778768984313139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 136}], {
             RGBColor[
             0.9562666668799304, 0.9629935529487204, 0.7308088595324563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 165}], {
             RGBColor[
             0.9499430145672961, 0.9419121380578821, 0.6850057931573457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 181}], {
             RGBColor[
             0.8167213708728744, 0.8575535758044224, 0.9821530921197811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 207}], {
             RGBColor[
             0.8326069689699811, 0.8699635257728993, 0.9837364200787462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 232}], {
             RGBColor[
             0.9568611020652522, 0.9642649897035074, 0.7955094610260169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 240}], {
             RGBColor[
             0.9572796113633043, 0.9651601387742601, 0.8410616153789832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 246}], {
             RGBColor[
             0.759246790508393, 0.811987768878119, 0.9768800667488129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 256}], {
             RGBColor[
             0.9574368195628593, 0.965496391216921, 0.8581727577239964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 296}], {
             RGBColor[
             0.8079306217366228, 0.8506861757670146, 0.9812769124001008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 299}], {
             RGBColor[
             0.9570551059778822, 0.9653678956255696, 0.8666323773215838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 107}], {
             RGBColor[
             0.9045073081884096, 0.5951795926664958, 0.26859915666912515`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 109}], {
             RGBColor[
             0.9480181265878662, 0.9334317685964351, 0.674604431944415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 110}], {
             RGBColor[
             0.9839067857429666, 0.9591178157514064, 0.561716366031505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 141}], {
             RGBColor[
             0.936935020626016, 0.7805800799358134, 0.2971516426609445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 165}], {
             RGBColor[
             0.9775639799613888, 0.9359801775610526, 0.3673407281472113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 179}], {
             RGBColor[
             0.9842570845883489, 0.9592626733262417, 0.5559110076191691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 240}], {
             RGBColor[
             0.984900576757397, 0.9592281782774306, 0.5233965503688487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 281}], {
             RGBColor[
             0.9054719947624891, 0.6025945964032228, 0.26952294162192125`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 149}], {
             RGBColor[
             0.2850281329082009, 0.41691301788689017`, 0.939543302556562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 187}], {
             RGBColor[
             0.3200183961394125, 0.4485879118406425, 0.9417227588366461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 227}], {
             RGBColor[
             0.2679362427515092, 0.39894835764378045`, 0.938569944697324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 264}], {
             RGBColor[
             0.2853843000396664, 0.4172873721243609, 0.939563585747797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 99}], {
             RGBColor[
             0.43585477652737337`, 0.5505550934269655, 0.9493751482779511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[
             0.7318152240398965, 0.7888182862268713, 0.9538534747537719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 198}], {
             RGBColor[
             0.48423825814620036`, 0.592165458504841, 0.9525401559859066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 201}], {
             RGBColor[
             0.41266709907445764`, 0.5304710926638055, 0.9478976499747094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 222}], {
             RGBColor[
             0.47017691950032614`, 0.5802832085890723, 0.9515621248783083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 258}], {
             RGBColor[
             0.7329940972360016, 0.7896974879262988, 0.9518579499321382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 260}], {
             RGBColor[
             0.6766874696871867, 0.7454723343623321, 0.9697937614112038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 261}], {
             RGBColor[
             0.4524312720200109, 0.5649128206637994, 0.9504313879127225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 278}], {
             RGBColor[
             0.553576335347311, 0.6484572332214837, 0.9579987034169237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 290}], {
             RGBColor[
             0.558574938782711, 0.6525153246748602, 0.9583922117898461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 111}], {
             RGBColor[
             0.26057341862775985`, 0.3912095626597075, 0.9381506427557986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 112}], {
             RGBColor[
             0.26517294299919314`, 0.39604395440077267`, 0.9384125788643654]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 175}], {
             RGBColor[
             0.28632181999450856`, 0.4182727650390983, 0.9396169761222888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 177}], {
             RGBColor[
             0.3486700459196015, 0.47359177071300174`, 0.9435415608547846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 242}], {
             RGBColor[
             0.2592824308416344, 0.3898526526431364, 0.9380771229112241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.27309540824899353`, 0.40437096769162195`, 0.9388637515401044]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 285}], {
             RGBColor[
             0.3304519019187142, 0.457812130049975, 0.9423807168287202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 123}], {
             RGBColor[
             0.4198835569183708, 0.5381037658666636, 0.9479755868517558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 134}], {
             RGBColor[
             0.3387736212750252, 0.46463798272782586`, 0.9429249564054306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 144}], {
             RGBColor[
             0.35962797975699734`, 0.48591341346284866`, 0.9441361547569478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 158}], {
             RGBColor[
             0.4035892626740157, 0.5239904671672448, 0.9469373288309841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 252}], {
             RGBColor[
             0.35203888438478537`, 0.4785806153224426, 0.9436803935153333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 253}], {
             RGBColor[
             0.3501359199582715, 0.4765804790552632, 0.9435720225064269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[
             0.39742589509621323`, 0.518652067951214, 0.9465446044989785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 102}], {
             RGBColor[
             0.3289676178309032, 0.4560161547537128, 0.9423048264494448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 162}], {
             RGBColor[
             0.27856959341816107`, 0.4101246833878033, 0.9391754982871572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 191}], {
             RGBColor[
             0.2582507185162887, 0.38876825757485856`, 0.9380183684205773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 203}], {
             RGBColor[
             0.2661031933042482, 0.39702170645266144`, 0.9384655552430561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 239}], {
             RGBColor[
             0.3418733579527955, 0.46719445818593675`, 0.9431271687979139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 153}], {
             RGBColor[
             0.26728945052082176`, 0.3982685380003319, 0.9385331108366297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 163}], {
             RGBColor[
             0.25122830224652154`, 0.3813872528284255, 0.937618452202748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 189}], {
             RGBColor[
             0.2464728493758267, 0.3763889703481986, 0.937347636196824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 211}], {
             RGBColor[
             0.2517282610763278, 0.3819127412577725, 0.9376469241184826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 216}], {
             RGBColor[
             0.25996759819388404`, 0.3905728069724701, 0.9381161421783205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 221}], {
             RGBColor[
             0.27785530490942656`, 0.40937392087661617`, 0.9391348206132799]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 94}], {
             RGBColor[
             0.6965792865266065, 0.7615288190518337, 0.9714662855765266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 160}], {
             RGBColor[
             0.5607147225279772, 0.6542524975154264, 0.9585606634045596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 164}], {
             RGBColor[
             0.45756686024315646`, 0.5686282136761757, 0.9509610966011381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 168}], {
             RGBColor[
             0.4585412392278475, 0.5694721717790032, 0.9510231831684333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 277}], {
             RGBColor[
             0.440152252258617, 0.5535445555236148, 0.9498514531794966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 124}], {
             RGBColor[
             0.9048214633960636, 0.926634777474092, 0.9800597975853467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 125}], {
             RGBColor[
             0.9272871440372241, 0.9396965749731525, 0.7126838428267497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 142}], {
             RGBColor[
             0.7604864358301577, 0.8131562391312941, 0.9766718286519673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 150}], {
             RGBColor[
             0.9119777121048072, 0.931971896043791, 0.9679461351700305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 200}], {
             RGBColor[
             0.8739725410077492, 0.7339874771388775, 0.6066396220475212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 237}], {
             RGBColor[
             0.7503642165832218, 0.805193848255281, 0.9757004322912739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 295}], {
             RGBColor[
             0.8496169506590368, 0.8829255104904983, 0.9855184172875062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 96}], {
             RGBColor[
             0.44705620926157014`, 0.5606800997756136, 0.9499720483653973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 105}], {
             RGBColor[
             0.3889084199719124, 0.5085055030468593, 0.9463331921101534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 109}], {
             RGBColor[
             0.7049075830694689, 0.7678615870686365, 0.9726151362943627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 138}], {
             RGBColor[
             0.5976652055170001, 0.6832651887274253, 0.9621432473760043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 140}], {
             RGBColor[
             0.4083602605702821, 0.527163613934152, 0.9475063767322723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 154}], {
             RGBColor[
             0.6149232954890904, 0.696747339779964, 0.9638633724984019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 171}], {
             RGBColor[
             0.45349990749309843`, 0.5662613073140733, 0.9503826351187716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 198}], {
             RGBColor[
             0.4764509321887418, 0.5858433564775396, 0.9519271091606205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 245}], {
             RGBColor[
             0.4565245648697137, 0.5688811135099974, 0.9505753636122101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 289}], {
             RGBColor[
             0.38981488785686436`, 0.5094582582673273, 0.9463848141152024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 105}], {
             RGBColor[
             0.3473181215020726, 0.473441328714978, 0.9434180509343462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 138}], {
             RGBColor[
             0.5560749070471602, 0.6482010143955439, 0.959228106200197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 140}], {
             RGBColor[
             0.36676996210044227`, 0.49209943960227065`, 0.9445912355564652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 171}], {
             RGBColor[
             0.4119096090232586, 0.5311971329821921, 0.9474674939429645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 196}], {
             RGBColor[
             0.34319916551880214`, 0.4691120448196677, 0.9431834824845483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 198}], {
             RGBColor[
             0.43486063371890193`, 0.5507791821456584, 0.9490119679848132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 222}], {
             RGBColor[
             0.4207992950730278, 0.5388969322298897, 0.948033936877215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 245}], {
             RGBColor[
             0.41493426639987385`, 0.5338169391781161, 0.9476602224364029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 278}], {
             RGBColor[
             0.5041987109200126, 0.6070709568623011, 0.9544705154158305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 289}], {
             RGBColor[
             0.3482245893870246, 0.47439408393544596`, 0.9434696729393952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 290}], {
             RGBColor[
             0.5091973143554127, 0.6111290483156775, 0.9548640237887529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 298}], {
             RGBColor[
             0.3453589956577786, 0.4713821632368721, 0.9433064816157806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 134}], {
             RGBColor[
             0.2657406017726479, 0.3966405997633186, 0.9384449061917377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 144}], {
             RGBColor[
             0.28659496025462, 0.4179160304983415, 0.9396561045432549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 159}], {
             RGBColor[
             0.2524370830607903, 0.3826577581053522, 0.9376872904818896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 235}], {
             RGBColor[
             0.24975979964424241`, 0.3798437634849875, 0.9375348231520031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 252}], {
             RGBColor[
             0.2790058648824081, 0.41058323235793537`, 0.9392003433016403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 292}], {
             RGBColor[
             0.25027096919944, 0.3803810350975218, 0.937563933501964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 122}], {
             RGBColor[
             0.5234999711581451, 0.6232114459734905, 0.9558598822602524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 160}], {
             RGBColor[
             0.5065135948101279, 0.6094211404266363, 0.9545226524909898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 178}], {
             RGBColor[
             0.34993177355877136`, 0.4745851224813026, 0.9436255999612144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 181}], {
             RGBColor[
             0.5683121366528735, 0.6584973340732392, 0.9601360759487196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 182}], {
             RGBColor[
             0.3649951509133196, 0.4904176871542194, 0.9444834370172861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 208}], {
             RGBColor[
             0.3543834762769441, 0.47926414429235664`, 0.9438791178453103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 246}], {
             RGBColor[
             0.5108375562883921, 0.6129315271469358, 0.9548630505777516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 296}], {
             RGBColor[
             0.559521387516622, 0.6516299340358314, 0.9592598962290395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 104}], {
             RGBColor[
             0.3262801186675095, 0.4548403348152493, 0.9420914025992604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 123}], {
             RGBColor[
             0.40185451909948444`, 0.5224879194737331, 0.9468267925043885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 157}], {
             RGBColor[
             0.35673441532730565`, 0.48340715338862666`, 0.9439517793901664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 201}], {
             RGBColor[
             0.34430071595550393`, 0.4726377079286733, 0.9431595150608838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[
             0.3117655585077827, 0.43958461181110975`, 0.9412648198705315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 222}], {
             RGBColor[
             0.4018105363813725, 0.5224498238539401, 0.9468239899644828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 229}], {
             RGBColor[
             0.3569385719957474, 0.4835839836336185, 0.9439647880725508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 257}], {
             RGBColor[
             0.37939685727732686`, 0.5030362215582833, 0.9453958101516111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 259}], {
             RGBColor[
             0.41587462147542475`, 0.5343343034600658, 0.9478022372825421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 261}], {
             RGBColor[
             0.38406488890105717`, 0.5070794359286672, 0.9456932529988971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 121}], {
             RGBColor[
             0.9223952272310946, 0.6887967573605129, 0.4252047095816714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 125}], {
             RGBColor[
             0.9214027485620356, 0.686673945842382, 0.31717953132296794`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 127}], {
             RGBColor[
             0.8414762129232649, 0.3198099242864162, 0.18735097437698822`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 136}], {
             RGBColor[
             0.9215440004534805, 0.6869760693554257, 0.33255392800111494`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 137}], {
             RGBColor[
             0.8478732688157926, 0.3689804990841502, 0.19347680232411396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 170}], {
             RGBColor[
             0.8360368854877944, 0.2780008700889096, 0.18214226828194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 192}], {
             RGBColor[
             0.857583234347318, 0.43326449980026105`, 0.20236975515183697`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 228}], {
             RGBColor[
             0.8332617870229544, 0.6215832019337704, 0.5890075855789246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 232}], {
             RGBColor[
             0.9221384356388024, 0.6882475061102127, 0.3972545294946756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 240}], {
             RGBColor[
             0.9225569449368545, 0.6891426551809652, 0.4428066838476417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 256}], {
             RGBColor[
             0.9227141531364094, 0.6894789076236262, 0.45991782619265503`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 299}], {
             RGBColor[
             0.9223324395514323, 0.6893504120322749, 0.46837744579024243`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 108}], {
             RGBColor[
             0.44525533808141193`, 0.5575469670447641, 0.9502920083081179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 114}], {
             RGBColor[
             0.4255007228362041, 0.540035729338632, 0.9490479363174081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 187}], {
             RGBColor[
             0.4552598760386822, 0.566212394980653, 0.9509294886200896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 205}], {
             RGBColor[
             0.5380185348092877, 0.6358267098737893, 0.9567739363684693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 207}], {
             RGBColor[
             0.6460892652174881, 0.7219820565313749, 0.9663628314965813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 213}], {
             RGBColor[
             0.48723449014775655`, 0.5939071986311, 0.9529668827570787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 231}], {
             RGBColor[
             0.49585480302230733`, 0.6013736803735128, 0.9535161614708018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 133}], {
             RGBColor[
             0.36773492193593726`, 0.4929352393114849, 0.9446527219439024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 142}], {
             RGBColor[
             0.5221732711977142, 0.6208612990518254, 0.9562111960106483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 162}], {
             RGBColor[
             0.3349247683998675, 0.4622774977068556, 0.9426440773615328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[
             0.4766965463107896, 0.5841965277949407, 0.9524565634581535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 210}], {
             RGBColor[
             0.3819399405336581, 0.5052389124558365, 0.9455578531679444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 237}], {
             RGBColor[
             0.5120510519507784, 0.6128989081758123, 0.9552397996499549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 239}], {
             RGBColor[
             0.398228532934502, 0.519347272504989, 0.9465957478722895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 295}], {
             RGBColor[
             0.6113037860265932, 0.6906305704110295, 0.9650577846461873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 116}], {
             RGBColor[
             0.3006123597209014, 0.43202989779004775`, 0.9404770506166615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 119}], {
             RGBColor[
             0.28052080371187027`, 0.4121755291203697, 0.939286616826827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 152}], {
             RGBColor[
             0.26605649274810816`, 0.396972621207172, 0.9384628957154713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 164}], {
             RGBColor[
             0.33137057382359575`, 0.4586711168930102, 0.9424369368208644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 168}], {
             RGBColor[
             0.3323449528082868, 0.45951507499583777`, 0.9424990233881594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 241}], {
             RGBColor[
             0.2789461451652853, 0.41052046314879065`, 0.9391969423520976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 277}], {
             RGBColor[
             0.3139559658390563, 0.44358745874044936`, 0.9413272933992227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 128}], {
             RGBColor[
             0.26216622821870855`, 0.39288370652975557`, 0.9382413509056526]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 157}], {
             RGBColor[
             0.3155261405863954, 0.44552577951204275`, 0.9414061686253012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 173}], {
             RGBColor[
             0.2711227338075005, 0.40229756177882925`, 0.9387514106489717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 201}], {
             RGBColor[
             0.30309244121459367`, 0.43475633405208935`, 0.9406139042960187]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 209}], {
             RGBColor[
             0.2751140822771375, 0.4064927220865271, 0.9389787120396467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 218}], {
             RGBColor[
             0.2705572837668725, 0.40170323793452584`, 0.9387192091056663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 229}], {
             RGBColor[
             0.3157302972548372, 0.4457026097570346, 0.9414191773076857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 261}], {
             RGBColor[
             0.34285661416014696`, 0.46919806205208336`, 0.9431476422340319]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 279}], {
             RGBColor[
             0.27193222945827744`, 0.4031483930327844, 0.9387975102287419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 129}], {
             RGBColor[
             0.2625398824694277, 0.39327644083830926`, 0.9382626299624591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 140}], {
             RGBColor[
             0.3086221728107845, 0.4399248428735164, 0.9409523793012212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 149}], {
             RGBColor[
             0.29155965067616113`, 0.4237780571831614, 0.9399152628309327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 171}], {
             RGBColor[
             0.3537618197336009, 0.4790225362534377, 0.9438286376877205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 196}], {
             RGBColor[
             0.28505137622914434`, 0.4169374480909134, 0.9395446262293043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 230}], {
             RGBColor[
             0.2692612582166467, 0.40034103290847267`, 0.938645402367879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 245}], {
             RGBColor[
             0.35678647711021616`, 0.4816423424493619, 0.944021366181159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 263}], {
             RGBColor[
             0.2750769487244079, 0.40645369236820506`, 0.9389765973387527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 289}], {
             RGBColor[
             0.2900768000973668, 0.42221948720669167`, 0.9398308166841512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 298}], {
             RGBColor[
             0.2872112063681208, 0.41920756650811786`, 0.9396676253605367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 151}], {
             RGBColor[
             0.5499711557200619, 0.645038448022178, 0.9579401200370031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 167}], {
             RGBColor[
             0.7052976145619072, 0.7697031240469493, 0.9712611329047376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 194}], {
             RGBColor[
             0.5862509789073218, 0.6747647734348481, 0.960720844348837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 215}], {
             RGBColor[
             0.8258859987463416, 0.8619784867738793, 0.84861498208911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 283}], {
             RGBColor[
             0.6376959489926155, 0.716530117719581, 0.9647707808430861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 286}], {
             RGBColor[
             0.6078523188068897, 0.6923017142945901, 0.9624213809540463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 297}], {
             RGBColor[
             0.7085338986582898, 0.7722313337797134, 0.9715836954586705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 110}], {
             RGBColor[
             0.9135464991631714, 0.6274127712548101, 0.4734497418593211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 127}], {
             RGBColor[
             0.8334595581640123, 0.25819040288628525`, 0.17967421672601133`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 141}], {
             RGBColor[
             0.8665747340462209, 0.44887503543921714`, 0.2088850184887606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 165}], {
             RGBColor[
             0.9072036933815937, 0.6042751330644562, 0.27907410397502735`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 179}], {
             RGBColor[
             0.9138967980085537, 0.6275576288296454, 0.4676443834469852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 240}], {
             RGBColor[
             0.9145402901776019, 0.6275231337808342, 0.4351299261966648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 281}], {
             RGBColor[
             0.835111708182694, 0.27088955190662645`, 0.18125631744973736`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 114}], {
             RGBColor[
             0.32416580444258236`, 0.4547970767096937, 0.9418912109282782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 145}], {
             RGBColor[
             0.3065621353882716, 0.43629450439653, 0.9408887080179298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 169}], {
             RGBColor[
             0.3184727377256654, 0.44881330262893604`, 0.9415669992008873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 187}], {
             RGBColor[
             0.35392495764506043`, 0.4809737423517148, 0.9437727632309596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 205}], {
             RGBColor[
             0.436683616415666, 0.5505880572448512, 0.9496172109793394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 213}], {
             RGBColor[
             0.3858995717541348, 0.5086685460021616, 0.9458101573679487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 219}], {
             RGBColor[
             0.30907770812291846`, 0.4389385308371674, 0.9410319661637115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 221}], {
             RGBColor[
             0.3192668900954462, 0.449648007121744, 0.9416122250035031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 264}], {
             RGBColor[
             0.3192908615453144, 0.4496732026354332, 0.9416135901421105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 110}], {
             RGBColor[
             0.9570573175626281, 0.9656649471847494, 0.8794550171346109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 138}], {
             RGBColor[
             0.8139262808550589, 0.8553825016885668, 0.9818711941291625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 154}], {
             RGBColor[
             0.8311843708271494, 0.8688646527411055, 0.9835913192515602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 179}], {
             RGBColor[
             0.9574076164080104, 0.9658098047595847, 0.8736496587222751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 258}], {
             RGBColor[
             0.941467846616602, 0.9554926988601389, 0.9709728498600104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 138}], {
             RGBColor[
             0.8498149400101593, 0.8810685488435381, 0.8689831282162525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 141}], {
             RGBColor[
             0.9459742116007779, 0.8128132585241278, 0.5020022278511405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 154}], {
             RGBColor[
             0.8670730299822498, 0.8945506998960768, 0.8707032533386501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 165}], {
             RGBColor[
             0.9866031709361507, 0.9682133561493669, 0.5721913133374072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 179}], {
             RGBColor[
             0.9932962755631108, 0.991495851914556, 0.7607615928093651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 281}], {
             RGBColor[
             0.914511185737251, 0.6348277749915371, 0.4743735268121172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 190}], {
             RGBColor[
             0.2355732429285669, 0.36493279289716524`, 0.9367269197341752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 212}], {
             RGBColor[
             0.2273675902370908, 0.3563081316499939, 0.936259619952571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 242}], {
             RGBColor[
             0.24172339249525976`, 0.3713969900337639, 0.9370771616536675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 250}], {
             RGBColor[
             0.2327988220725642, 0.3620167006690641, 0.9365689205708136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 280}], {
             RGBColor[
             0.2555363699026189, 0.38591530508224947`, 0.9378637902825477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 115}], {
             RGBColor[
             0.236902386747869, 0.36632980732383724`, 0.9368026125083924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 134}], {
             RGBColor[
             0.2631071012640549, 0.3938726237552112, 0.9382949322336882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 146}], {
             RGBColor[
             0.24133200131587673`, 0.37098561308859834`, 0.937054872505013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 159}], {
             RGBColor[
             0.24980358255219737`, 0.3798897820972448, 0.9375373165238401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 175}], {
             RGBColor[
             0.27336230601956724`, 0.40465149417079094`, 0.9388789509732987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 204}], {
             RGBColor[
             0.24154807064065673`, 0.37121271564852854`, 0.9370671773334133]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 235}], {
             RGBColor[
             0.24712629913564943`, 0.3770757874768801, 0.9373848491939536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 242}], {
             RGBColor[
             0.24632291686669305`, 0.37623138177482907`, 0.937339097762234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 252}], {
             RGBColor[
             0.27637236437381507`, 0.40781525634982796`, 0.9390503693435908]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 253}], {
             RGBColor[
             0.2744693999473012, 0.40581512008264853`, 0.9389419983346845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 280}], {
             RGBColor[
             0.2601358942740522, 0.3907496968233146, 0.9381257263911142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 292}], {
             RGBColor[
             0.24763746869084696`, 0.3776130590894144, 0.9374139595439145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 135}], {
             RGBColor[
             0.9747525126984742, 0.9797102206225822, 0.8836982332246824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 224}], {
             RGBColor[
             0.9644670009376046, 0.9390549690861945, 0.644851681061125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 249}], {
             RGBColor[
             0.8889946281823045, 0.5565337231850392, 0.5595095853153444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 254}], {
             RGBColor[
             0.925365599889266, 0.7843240503848107, 0.5923111720047104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 258}], {
             RGBColor[
             0.9605881616295711, 0.9701272959910724, 0.9515981414941335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 260}], {
             RGBColor[
             0.9042815340807562, 0.9259021424271057, 0.969533952973199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 278}], {
             RGBColor[
             0.7811703997408805, 0.8288870412862575, 0.957738894978919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 288}], {
             RGBColor[
             0.9106552013287734, 0.717527566222487, 0.5800364548609709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 290}], {
             RGBColor[
             0.7861690031762806, 0.8329451327396338, 0.9581324033518415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 145}], {
             RGBColor[
             0.28680752014306377`, 0.4187832666903979, 0.9396446360272199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 169}], {
             RGBColor[
             0.2987181224804576, 0.4313020649228039, 0.9403229272101774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 187}], {
             RGBColor[
             0.33417034239985266`, 0.4634625046455827, 0.9425286912402498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 213}], {
             RGBColor[
             0.366144956508927, 0.49115730829602955`, 0.944566085377239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 219}], {
             RGBColor[
             0.28932309287771063`, 0.4214272931310352, 0.9397878941730018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 221}], {
             RGBColor[
             0.29951227485023835`, 0.4321367694156119, 0.9403681530127932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 231}], {
             RGBColor[
             0.37476526938347776`, 0.4986237900384425, 0.945115364090962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 264}], {
             RGBColor[
             0.29953624630010656`, 0.4321619649293011, 0.9403695181514007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 132}], {
             RGBColor[
             0.21415169536183348`, 0.34241738819996653`, 0.9355069942905895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 146}], {
             RGBColor[
             0.22602095903949393`, 0.35489273687997036`, 0.9361829312980301]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 159}], {
             RGBColor[
             0.23449254027581456`, 0.3637969058886168, 0.9366653753168572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 204}], {
             RGBColor[
             0.22623702836427392`, 0.35511983943990055`, 0.9361952361264305]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 242}], {
             RGBColor[
             0.23101187459031025`, 0.36013850556620103`, 0.9364671565552513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 243}], {
             RGBColor[
             0.21987898042507611`, 0.348437127932281, 0.9358331547021821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 294}], {
             RGBColor[
             0.2157444487404361, 0.3440914729872748, 0.9355976992392334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 119}], {
             RGBColor[
             0.30231628529617693`, 0.4338208316047836, 0.9405740866574415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 133}], {
             RGBColor[
             0.3362774461822365, 0.4656883549123332, 0.9426482794056301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 152}], {
             RGBColor[
             0.2878519743324149, 0.4186179236915859, 0.9397503655460857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 164}], {
             RGBColor[
             0.35316605540790247`, 0.4803164193774241, 0.9437244066514788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 168}], {
             RGBColor[
             0.35414043439259346`, 0.4811603774802517, 0.9437864932187738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 210}], {
             RGBColor[
             0.35048246477995726`, 0.4779920280566848, 0.9435534106296721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 241}], {
             RGBColor[
             0.30074162674959204`, 0.4321657656332045, 0.9404844121827121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 277}], {
             RGBColor[
             0.33575144742336294`, 0.46523276122486323`, 0.9426147632298372]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 161}], {
             RGBColor[
             0.20987266837087443`, 0.33791985952648745`, 0.9352633100337076]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 120}], {
             RGBColor[
             0.1844220718220619, 0.3111696688926636, 0.9338139362110361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 130}], {
             RGBColor[
             0.17892828448197629`, 0.3053953500719979, 0.9335010731493483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 176}], {
             RGBColor[
             0.17894072364130287`, 0.30540842441713845`, 0.9335017815410699]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[
             0.17892828448197629`, 0.3053953500719979, 0.9335010731493483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 220}], {
             RGBColor[
             0.21806065403360642`, 0.34652595160629435`, 0.9357296037041608]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 226}], {
             RGBColor[
             0.17892828959271728`, 0.30539535544371077`, 0.9335010734403975]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 228}], {
             RGBColor[
             0.49763640594137093`, 0.5809247565206876, 0.9579151348288255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 266}], {
             RGBColor[
             0.21328176149194045`, 0.3415030325457159, 0.9354574528436509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 152}], {
             RGBColor[
             0.2677604183233837, 0.39876355502190786`, 0.9385599317562512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 164}], {
             RGBColor[
             0.33307449939887124`, 0.46046205070774604`, 0.9425339728616443]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 168}], {
             RGBColor[
             0.3340488783835623, 0.46130600881057365`, 0.9425960594289393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 241}], {
             RGBColor[
             0.2806500707405608, 0.4123113969635265, 0.9392939783928775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 130}], {
             RGBColor[
             0.18442078734008566`, 0.31116831882066576`, 0.9338138630616879]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 176}], {
             RGBColor[
             0.18443322649941224`, 0.31118139316580623`, 0.9338145714534094]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 287}], {
             RGBColor[
             0.5654447927305568, 0.5603176274195498, 0.6027460190921992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 125}], {
             RGBColor[
             0.9936176446660105, 0.9887571122327337, 0.5466981931057444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 127}], {
             RGBColor[
             0.9136911090272399, 0.6218930906767679, 0.41686963615976463`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 136}], {
             RGBColor[
             0.9937588965574554, 0.9890592357457773, 0.5620725897838914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 137}], {
             RGBColor[
             0.9200881649197675, 0.6710636654745018, 0.4229954641068904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 160}], {
             RGBColor[
             0.7924150587076538, 0.8345430649548763, 0.8078033989134862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 181}], {
             RGBColor[
             0.8542136005503994, 0.8836192586014792, 0.8134168223712162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 232}], {
             RGBColor[
             0.9943533317427773, 0.9903306725005643, 0.626773191277452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 240}], {
             RGBColor[
             0.9947718410408293, 0.9912258215713169, 0.6723253456304181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 246}], {
             RGBColor[
             0.796739020185918, 0.8380534516751759, 0.8081437970002479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 256}], {
             RGBColor[
             0.9949290492403844, 0.9915620740139779, 0.6894364879754314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 296}], {
             RGBColor[
             0.8454228514141477, 0.8767518585640715, 0.8125406426515358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 299}], {
             RGBColor[
             0.9945473356554072, 0.9914335784226265, 0.6978961075730188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 136}], {
             RGBColor[
             0.8085502082780569, 0.8465126824966431, 0.7164898471021924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 160}], {
             RGBColor[
             0.6072063704282553, 0.6919965117057422, 0.9622206562317872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 181}], {
             RGBColor[
             0.6690049122710009, 0.741072705352345, 0.9678340796895172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 207}], {
             RGBColor[
             0.6848905103681076, 0.7534826553208219, 0.9694174076484823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 231}], {
             RGBColor[
             0.5346560481729267, 0.6328742791629598, 0.9565707376227028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 232}], {
             RGBColor[
             0.8091446434633787, 0.8477841192514302, 0.781190448595753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 240}], {
             RGBColor[
             0.8095631527614308, 0.8486792683221828, 0.8267426029487193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 246}], {
             RGBColor[
             0.6115303319065195, 0.6955068984260417, 0.962561054318549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 256}], {
             RGBColor[
             0.8097203609609858, 0.8490155207648438, 0.8438537452937325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 296}], {
             RGBColor[
             0.6602141631347492, 0.7342053053149373, 0.9669578999698369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 299}], {
             RGBColor[
             0.8093386473760087, 0.8488870251734923, 0.8523133648913199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 144}], {
             RGBColor[
             0.3759650676291757, 0.5000637778518178, 0.9451771395498434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 157}], {
             RGBColor[
             0.3911005410183704, 0.5131733641705265, 0.9461415585304294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 229}], {
             RGBColor[
             0.3913046976868122, 0.5133501944155183, 0.9461545672128138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 257}], {
             RGBColor[
             0.41376298296839165`, 0.5328024323401832, 0.9475855892918741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 259}], {
             RGBColor[
             0.4502407471664895, 0.5641005142419657, 0.9499920164228051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 261}], {
             RGBColor[
             0.41843101459212195`, 0.5368456467105671, 0.9478830321391599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 125}], {
             RGBColor[
             0.970159485355791, 0.9735725032155419, 0.706048969605638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 142}], {
             RGBColor[
             0.8033587771487245, 0.8470321673736835, 0.9700369554308557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 150}], {
             RGBColor[
             0.9548500534233739, 0.9658478242861803, 0.9613112619489188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 200}], {
             RGBColor[
             0.916844882326316, 0.7678634053812667, 0.6000047488264095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 237}], {
             RGBColor[
             0.7932365579017887, 0.8390697764976703, 0.9690655590701622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 282}], {
             RGBColor[
             0.9556754222393467, 0.9664633829977154, 0.9599141278341408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 295}], {
             RGBColor[
             0.8924892919776035, 0.9168014387328876, 0.9788835440663946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 136}], {
             RGBColor[
             0.9927664178883965, 0.9869364242276462, 0.4540474115251879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 150}], {
             RGBColor[
             0.9773157340645346, 0.9789096217852411, 0.6939353071903218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 170}], {
             RGBColor[
             0.9072593029227105, 0.5779612249611302, 0.303635751806013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 192}], {
             RGBColor[
             0.9288056517822338, 0.7332248546724817, 0.32386323867590994`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 195}], {
             RGBColor[
             0.9058844617461582, 0.5673935932189047, 0.3023192023426855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 200}], {
             RGBColor[
             0.9393105629674767, 0.7809252028803274, 0.3326287940678124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 256}], {
             RGBColor[
             0.9939365705713255, 0.9894392624958468, 0.5814113097167279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 299}], {
             RGBColor[
             0.9935548569863483, 0.9893107669044954, 0.5898709293143154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 155}], {
             RGBColor[
             0.21912067898952223`, 0.3476401050444259, 0.9357899705572339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 163}], {
             RGBColor[
             0.23364896427549098`, 0.3629102540264691, 0.9366173349115978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 184}], {
             RGBColor[
             0.23168784072436213`, 0.3608489888318178, 0.9365056518265833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 189}], {
             RGBColor[
             0.22889351140479614`, 0.3579119715462422, 0.9363465189056738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 197}], {
             RGBColor[
             0.21821940668747852`, 0.34669281071101354`, 0.9357386444329454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 214}], {
             RGBColor[
             0.21941035515512047`, 0.34794457306099935`, 0.9358064671863272]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 216}], {
             RGBColor[
             0.24238826022285348`, 0.3720958081705137, 0.9371150248871702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 275}], {
             RGBColor[
             0.21935857397151598`, 0.34789014775391436`, 0.9358035183245244]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 293}], {
             RGBColor[
             0.21759994210882713`, 0.34604171416252816`, 0.9357033668416068]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 136}], {
             RGBColor[
             0.9128398822496258, 0.6200724026716804, 0.3242188545792082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 137}], {
             RGBColor[
             0.8391691506119379, 0.30207683240040506`, 0.18514172890220718`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 141}], {
             RGBColor[
             0.8658872706016187, 0.44359089015560293`, 0.2082267027178307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 165}], {
             RGBColor[
             0.9065162299369915, 0.5989909877808421, 0.27841578820409746`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 170}], {
             RGBColor[
             0.8273327672839398, 0.21109720340516447`, 0.1738071948600332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 192}], {
             RGBColor[
             0.8488791161434632, 0.3663608331165159, 0.19403468172993021`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 228}], {
             RGBColor[
             0.8245576688190998, 0.5546795352500253, 0.5806725121570179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 232}], {
             RGBColor[
             0.9134343174349477, 0.6213438394264674, 0.3889194560727688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 240}], {
             RGBColor[
             0.9138528267329997, 0.6222389884972201, 0.4344716104257349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 256}], {
             RGBColor[
             0.9140100349325547, 0.622575240939881, 0.4515827527707482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 281}], {
             RGBColor[
             0.8344242447380918, 0.2656054066230123, 0.18059800167880746`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 299}], {
             RGBColor[
             0.9136283213475775, 0.6224467453485296, 0.4600423723683357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 173}], {
             RGBColor[
             0.24821711809960986`, 0.3782223073699194, 0.9374469697202291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 209}], {
             RGBColor[
             0.25220846656924684`, 0.38241746767761725`, 0.9376742711109041]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 218}], {
             RGBColor[
             0.24765166805898178`, 0.377627983525616, 0.9374147681769237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 276}], {
             RGBColor[
             0.235521079118485, 0.3648779654253926, 0.9367239490823606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 279}], {
             RGBColor[
             0.24902661375038676`, 0.3790731386238746, 0.9374930692999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 161}], {
             RGBColor[
             0.22609023535273692`, 0.35496555067756064`, 0.9361868764815843]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 230}], {
             RGBColor[
             0.2426308084736596, 0.3723507417605582, 0.9371288376512357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 263}], {
             RGBColor[
             0.24844649898142085`, 0.37846340122029065`, 0.9374600326221096]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 265}], {
             RGBColor[
             0.22918762870603976`, 0.3582211074779632, 0.936363268450872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 269}], {
             RGBColor[
             0.23146736458154496`, 0.36061725442672216`, 0.9364930960364151]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 289}], {
             RGBColor[
             0.26344635035437974`, 0.39422919605877726`, 0.9383142519675081]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 298}], {
             RGBColor[
             0.26058075662513375`, 0.3912172753602034, 0.9381510606438935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 176}], {
             RGBColor[
             0.17893943915932659`, 0.3054070743451405, 0.9335017083917216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 199}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 220}], {
             RGBColor[
             0.21805936955163013`, 0.34652460153429643`, 0.9357295305548126]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 226}], {
             RGBColor[
             0.178927005110741, 0.3053940053717128, 0.9335010002910491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 228}], {
             RGBColor[
             0.49763512145939465`, 0.5809234064486897, 0.9579150616794772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 266}], {
             RGBColor[
             0.21328047700996416`, 0.3415016824737179, 0.9354573796943026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 139}], {
             RGBColor[
             0.29015495986038786`, 0.4208144502573191, 0.9398897209981389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 143}], {
             RGBColor[
             0.3607906299670138, 0.4869204426382663, 0.9442102378002388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 172}], {
             RGBColor[
             0.297163306859998, 0.4281806673087738, 0.9402888359918464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 174}], {
             RGBColor[
             0.3585773503848271, 0.4850034111068425, 0.9440692095823882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 183}], {
             RGBColor[
             0.2897103519915022, 0.4203471391973532, 0.9398644012377442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 283}], {
             RGBColor[
             0.47177717102653804`, 0.5785602690993044, 0.9525231166057517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 188}], {
             RGBColor[
             0.20621351468350757`, 0.3340738569973212, 0.9350549266444448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 212}], {
             RGBColor[
             0.20921642322248857`, 0.3372301042671883, 0.9352259378433346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 243}], {
             RGBColor[
             0.21243933131542342`, 0.34061758501703826`, 0.935409477691362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 294}], {
             RGBColor[
             0.2083047996307834, 0.33627193007203204`, 0.9351740222284133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 162}], {
             RGBColor[
             0.31733689752319516`, 0.44704376794557543`, 0.9415233937816148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 164}], {
             RGBColor[
             0.36703566028493084`, 0.49232957401529565`, 0.9446081656098331]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 210}], {
             RGBColor[
             0.36435206965698563`, 0.49000518269455634`, 0.9444371695880264]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 239}], {
             RGBColor[
             0.38064066205782954`, 0.5041135427437089, 0.9454750642923715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 241}], {
             RGBColor[
             0.3146112316266204, 0.4441789202710761, 0.9413681711410662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 277}], {
             RGBColor[
             0.3496210523003913, 0.4772459158627348, 0.9434985221881913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 144}], {
             RGBColor[
             0.29485513198583013`, 0.42659799471298, 0.9401265091035182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 159}], {
             RGBColor[
             0.26069725479200045`, 0.3913397223199907, 0.9381576950421531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 175}], {
             RGBColor[
             0.2842559782593704, 0.41610143439353686`, 0.9394993294916116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 204}], {
             RGBColor[
             0.25244174288045984`, 0.38266265587127446`, 0.9376875558517261]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 235}], {
             RGBColor[
             0.2580199713754525, 0.388525727699626, 0.9380052277122666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 252}], {
             RGBColor[
             0.28726603661361816`, 0.4192651965725739, 0.9396707478619037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 253}], {
             RGBColor[
             0.2853630721871043, 0.41726506030539445`, 0.9395623768529974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 292}], {
             RGBColor[
             0.2585311409306501, 0.3890629993121603, 0.9380343380622274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 224}], {
             RGBColor[
             0.9798102252026126, 0.9495170954171317, 0.5749562479700403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 249}], {
             RGBColor[
             0.9043378524473125, 0.5669958495159765, 0.4896141522242598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 254}], {
             RGBColor[
             0.940708824154274, 0.7947861767157479, 0.5224157389136257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 258}], {
             RGBColor[
             0.9759313858945792, 0.9805894223220096, 0.8817027084030489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 260}], {
             RGBColor[
             0.9196247583457642, 0.9363642687580429, 0.8996385198821143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 288}], {
             RGBColor[
             0.9259984255937815, 0.7279896925534243, 0.5101410217698862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 137}], {
             RGBColor[
             0.9192369381421535, 0.6692429774694144, 0.3303446825263339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 165}], {
             RGBColor[
             0.9865840174672071, 0.9661571328498515, 0.42361874182822423`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 181}], {
             RGBColor[
             0.8533623737727853, 0.8817985705963918, 0.7207660407906598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 232}], {
             RGBColor[
             0.9935021049651632, 0.9885099844954769, 0.5341224096968956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 240}], {
             RGBColor[
             0.9939206142632153, 0.9894051335662295, 0.5796745640498617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 256}], {
             RGBColor[
             0.9940778224627702, 0.9897413860088904, 0.596785706394875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 296}], {
             RGBColor[
             0.8445716246365338, 0.8749311705589841, 0.7198898610709794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 299}], {
             RGBColor[
             0.9936961088777931, 0.9896128904175391, 0.6052453259924624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 170}], {
             RGBColor[
             0.8337298231764674, 0.2602677782028984, 0.17993302280715895`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 192}], {
             RGBColor[
             0.8552761720359909, 0.4155314079142499, 0.20016050967705595`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 195}], {
             RGBColor[
             0.8323549819999152, 0.24970014646067296`, 0.17861647334383152`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 220}], {
             RGBColor[
             0.5513789728038629, 0.36945130513336594`, 0.564612808979479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 228}], {
             RGBColor[
             0.8309547247116273, 0.6038501100477591, 0.5867983401041436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 232}], {
             RGBColor[
             0.9198313733274753, 0.6705144142242014, 0.3950452840198946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 256}], {
             RGBColor[
             0.9204070908250823, 0.671745815737615, 0.457708580717874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 266}], {
             RGBColor[
             0.546600080262197, 0.3644283860727875, 0.564340658118969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 299}], {
             RGBColor[
             0.9200253772401052, 0.6716173201462636, 0.46616820031546136`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 154}], {
             RGBColor[
             0.7239419932746806, 0.7842682543998942, 0.9731194303332016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 171}], {
             RGBColor[
             0.5625186052786886, 0.6537822219340037, 0.9596386929535714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 245}], {
             RGBColor[
             0.5655432626553039, 0.6564020281299278, 0.9598314214470098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 258}], {
             RGBColor[
             0.8342254690641332, 0.8708963005189276, 0.9605009609416519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 147}], {
             RGBColor[
             0.2408356632285271, 0.3704639302891415, 0.9370266067852049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 148}], {
             RGBColor[
             0.24714609636833407`, 0.37709659562364867`, 0.9373859766170676]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 172}], {
             RGBColor[
             0.26248705403553485`, 0.3932209148047717, 0.9382596214613016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 183}], {
             RGBColor[
             0.2550340991670391, 0.38538738669335115`, 0.9378351867071995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 206}], {
             RGBColor[
             0.2460762386198535, 0.3759721072970965, 0.9373250498010044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 244}], {
             RGBColor[
             0.2489949569451404, 0.37903986531440326`, 0.9374912664917726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 272}], {
             RGBColor[
             0.23937950956716447`, 0.3689334204655748, 0.9369436809883765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 149}], {
             RGBColor[
             0.3110114912745308, 0.4424361680704541, 0.9410884474530516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 171}], {
             RGBColor[
             0.37321366033197056`, 0.49768064714073046`, 0.9450018223098395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 196}], {
             RGBColor[
             0.304503216827514, 0.4355955589782061, 0.9407178108514234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 198}], {
             RGBColor[
             0.3961646850276139, 0.5172626963041967, 0.9465462963516883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 222}], {
             RGBColor[
             0.3821033463817397, 0.505380446388428, 0.94556826524409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 230}], {
             RGBColor[
             0.2887130988150164, 0.4189991437957653, 0.9398185869899978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 245}], {
             RGBColor[
             0.37623831770858585`, 0.5003004533366545, 0.945194550803278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 263}], {
             RGBColor[
             0.2945287893227776, 0.42511180325549774`, 0.9401497819608717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 289}], {
             RGBColor[
             0.3095286406957365, 0.4408775980939844, 0.9410040013062702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 298}], {
             RGBColor[
             0.3066630469664905, 0.4378656773954105, 0.9408408099826556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 165}], {
             RGBColor[
             0.9396314058192, 0.789675620333774, 0.3076265899668467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 179}], {
             RGBColor[
             0.9463245104461602, 0.8129581160989631, 0.4961968694388046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 232}], {
             RGBColor[
             0.9465494933171561, 0.8120284719793993, 0.41813025783551805`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[
             0.9469680026152082, 0.812923621050152, 0.46368241218848416`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 281}], {
             RGBColor[
             0.8675394206203003, 0.45629003917594413`, 0.20980880344155672`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 150}], {
             RGBColor[
             0.810515025857468, 0.8523692859433827, 0.9579232930155395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 185}], {
             RGBColor[
             0.6135470246958941, 0.696888857774001, 0.9628943539449815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 210}], {
             RGBColor[
             0.5187904189187625, 0.6179312424348968, 0.9559956436547723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 237}], {
             RGBColor[
             0.6489015303358828, 0.7255912381548726, 0.9656775901367828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 239}], {
             RGBColor[
             0.5350790113196064, 0.6320396024840493, 0.9570335383591173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 282}], {
             RGBColor[
             0.8113403946734408, 0.8529848446549176, 0.9565261589007614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 283}], {
             RGBColor[
             0.6388734394755219, 0.7174499822340865, 0.964888142090148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 295}], {
             RGBColor[
             0.7481542644116976, 0.8033229003900898, 0.9754955751330152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 297}], {
             RGBColor[
             0.7097113891411961, 0.773151198294219, 0.9717010567057325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 167}], {
             RGBColor[
             0.5753382538779925, 0.6628795153036178, 0.9613047709389584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 172}], {
             RGBColor[
             0.33312272414216076`, 0.4593269071857189, 0.9425801382634016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 174}], {
             RGBColor[
             0.39453676766698986`, 0.5161496509837875, 0.9463605118539434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 185}], {
             RGBColor[
             0.482410173529073, 0.5891453845161638, 0.9528206307321404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 237}], {
             RGBColor[
             0.5177646791690618, 0.6178477648970354, 0.9556038669239417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 239}], {
             RGBColor[
             0.4039421601527854, 0.5242961292262122, 0.9469598151462764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 283}], {
             RGBColor[
             0.5077365883087008, 0.6097065089762495, 0.9548144188773069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 297}], {
             RGBColor[
             0.5785745379743751, 0.6654077250363819, 0.9616273334928914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 158}], {
             RGBColor[
             0.35967077338482056`, 0.4859504791523989, 0.9441388815290719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 235}], {
             RGBColor[
             0.27887432985742466`, 0.4098011584346488, 0.9392164260637837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 252}], {
             RGBColor[
             0.3081203950955903, 0.44054062730759674`, 0.940881946213421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 253}], {
             RGBColor[
             0.30621743066907636`, 0.4385404910404173, 0.9407735752045145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 257}], {
             RGBColor[
             0.3535074058070181, 0.4806120799363681, 0.9437461571970662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 292}], {
             RGBColor[
             0.2793854994126222, 0.4103384300471832, 0.9392455364137446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 169}], {
             RGBColor[
             0.28111445342614677`, 0.4127994926096401, 0.939320424299829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 219}], {
             RGBColor[
             0.27171942382339986`, 0.4029247208178715, 0.9387853912626534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 221}], {
             RGBColor[
             0.2819086057959276, 0.4136341971024482, 0.9393656501024449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 264}], {
             RGBColor[
             0.28193257724579573`, 0.4136593926161374, 0.9393670152410523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 159}], {
             RGBColor[
             0.2389221548438223, 0.3684527116533779, 0.9369176353134778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 204}], {
             RGBColor[
             0.23066664293228167`, 0.35977564520466165`, 0.936447496123051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 235}], {
             RGBColor[
             0.23624487142727435`, 0.3656387170330131, 0.9367651679835913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 242}], {
             RGBColor[
             0.23544148915831797`, 0.3647943113309621, 0.9367194165518717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 243}], {
             RGBColor[
             0.22430859499308387`, 0.3530929336970421, 0.9360854146988027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 292}], {
             RGBColor[
             0.2367560409824719, 0.36617598864554746`, 0.9367942783335522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 148}], {
             RGBColor[
             0.2325030525609364, 0.36170582815947316`, 0.9365520769346783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 172}], {
             RGBColor[
             0.2478440102281372, 0.3778301473405962, 0.9374257217789124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 183}], {
             RGBColor[
             0.24039105535964145`, 0.36999661922917565`, 0.9370012870248101]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 206}], {
             RGBColor[
             0.23143319481245586`, 0.360581339832921, 0.9364911501186151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 244}], {
             RGBColor[
             0.23435191313774276`, 0.3636490978502278, 0.9366573668093834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 270}], {
             RGBColor[
             0.2272240069658551, 0.35615721652822, 0.9362514430976865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 272}], {
             RGBColor[
             0.2247364657597668, 0.3535426530013993, 0.9361097813059873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 172}], {
             RGBColor[
             0.2541544433679442, 0.3844628126751034, 0.9377850916107751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 183}], {
             RGBColor[
             0.2467014884994484, 0.37662928456368283`, 0.937360656856673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 203}], {
             RGBColor[
             0.2492037147300215, 0.37925928298232137`, 0.9375031549387921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 206}], {
             RGBColor[
             0.23774362795226284`, 0.3672140051674282, 0.9368505199504779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 244}], {
             RGBColor[
             0.24066234627754973`, 0.37028176318473494`, 0.9370167366412461]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 270}], {
             RGBColor[
             0.23353444010566207`, 0.3627898818627272, 0.9366108129295494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 272}], {
             RGBColor[
             0.23104689889957378`, 0.3601753183359065, 0.93646915113785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 171}], {
             RGBColor[
             0.3561511381973472, 0.48153386145037547`, 0.943964705839551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 227}], {
             RGBColor[
             0.27685707898321577`, 0.40832472213698934`, 0.9390779731235251]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 245}], {
             RGBColor[
             0.3591757955739624, 0.4841536676462995, 0.9441574343329895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 289}], {
             RGBColor[
             0.29246611856111315`, 0.4247308124036294, 0.9399668848359817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 298}], {
             RGBColor[
             0.28960052483186716`, 0.4217188917050555, 0.9398036935123671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 200}], {
             RGBColor[
             0.9240011310350597, 0.7732005239509658, 0.5878910864110933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 237}], {
             RGBColor[
             0.8003928066105324, 0.8444068950673695, 0.956951896654846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 282}], {
             RGBColor[
             0.9628316709480902, 0.9718005015674145, 0.9478004654188247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 295}], {
             RGBColor[
             0.8996455406863472, 0.9221385573025866, 0.9667698816510785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 167}], {
             RGBColor[
             0.5986000016649633, 0.6830276720672528, 0.9627869889383882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 194}], {
             RGBColor[
             0.4795533660103779, 0.5880893214551517, 0.9522467003824877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 251}], {
             RGBColor[
             0.36499365332834144`, 0.4885238594535514, 0.944552636407374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 286}], {
             RGBColor[
             0.5011547059099458, 0.6056262623148936, 0.953947236987697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 241}], {
             RGBColor[
             0.2661857597767988, 0.3971084890503288, 0.9384702572815218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 277}], {
             RGBColor[
             0.3011955804505697, 0.43017548464198757`, 0.9406006083286469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 163}], {
             RGBColor[
             0.2574205034515923, 0.3878956489031873, 0.9379710889008359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 211}], {
             RGBColor[
             0.25792046228139853`, 0.38842113733253425`, 0.9379995608165705]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 216}], {
             RGBColor[
             0.2661597993989548, 0.3970812030472318, 0.9384687788764086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 219}], {
             RGBColor[
             0.2738583241419696, 0.40517284066680126`, 0.9389071984715764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 221}], {
             RGBColor[
             0.2840475061144973, 0.4158823169513779, 0.939487457311368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 171}], {
             RGBColor[
             0.5797766952507789, 0.6672643729865424, 0.9613588180759691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 179}], {
             RGBColor[
             0.8674233288276321, 0.8946955574709121, 0.8648978949263142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 245}], {
             RGBColor[
             0.5828013526273942, 0.6698841791824666, 0.9615515465694076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 156}], {
             RGBColor[
             0.22000089461836236`, 0.3485652674792311, 0.935840097535134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 184}], {
             RGBColor[
             0.22486994634019453`, 0.35368294955458646`, 0.9361173828275757]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 197}], {
             RGBColor[
             0.21140151230331092`, 0.3395267714337822, 0.9353503754339378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 202}], {
             RGBColor[
             0.22021191752572378`, 0.34878706593449305`, 0.9358521149775277]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 214}], {
             RGBColor[
             0.21259246077095287`, 0.340778533783768, 0.9354181981873197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 275}], {
             RGBColor[
             0.21254067958734837`, 0.340724108476683, 0.9354152493255168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 293}], {
             RGBColor[
             0.21078204772465953`, 0.3388756748852968, 0.9353150978425994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 178}], {
             RGBColor[
             0.25237767810444756`, 0.38259531972974414`, 0.9376839074575076]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 202}], {
             RGBColor[
             0.22791002753873152`, 0.3568782676465297, 0.9362905109544353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 208}], {
             RGBColor[
             0.2568293808226203, 0.38727434154079826`, 0.9379374253416035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 214}], {
             RGBColor[
             0.2202905707839606, 0.3488697354958046, 0.9358565941642273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 268}], {
             RGBColor[
             0.2451076812596908, 0.374954092101482, 0.9372698918921952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 201}], {
             RGBColor[
             0.3335467378743898, 0.46332315262546664`, 0.9424742810869247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 218}], {
             RGBColor[
             0.30101158042666865`, 0.4302700565079032, 0.9405795858965723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 229}], {
             RGBColor[
             0.34618459391463335`, 0.47426942833041186`, 0.9432795540985917]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 257}], {
             RGBColor[
             0.3686428791962128, 0.49372166625507674`, 0.944710576177652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 259}], {
             RGBColor[
             0.40512064339431064`, 0.5250197481568593, 0.947117003308583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 261}], {
             RGBColor[
             0.3733109108199431, 0.49776488062546065`, 0.9450080190249379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 284}], {
             RGBColor[
             0.3008123283039969, 0.4300606298936609, 0.9405682387829533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 175}], {
             RGBColor[
             0.34907161965836087`, 0.47545391883295585`, 0.9435117019171652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 177}], {
             RGBColor[
             0.4114198455834537, 0.5307729245068593, 0.947436286649661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 217}], {
             RGBColor[
             0.6053338779034495, 0.6866046110497097, 0.9641707450092601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 252}], {
             RGBColor[
             0.35208167801260865`, 0.47861768101199287`, 0.9436831202874573]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 253}], {
             RGBColor[
             0.35017871358609476`, 0.47661754474481344`, 0.9435747492785509]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 175}], {
             RGBColor[
             0.2709524595475128, 0.4021185927355705, 0.9387417137817635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 204}], {
             RGBColor[
             0.23913822416860225`, 0.3686798142133081, 0.9369299401418781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 235}], {
             RGBColor[
             0.24471645266359499`, 0.3745428860416596, 0.9372476120024185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 252}], {
             RGBColor[
             0.2739625179017606, 0.4052823549146075, 0.9389131321520556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 253}], {
             RGBColor[
             0.27205955347524674`, 0.4032822186474281, 0.9388047611431494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 292}], {
             RGBColor[
             0.24522762221879252`, 0.3750801576541939, 0.9372767223523794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 168}], {
             RGBColor[
             0.4880465107801085, 0.5934258804224648, 0.9533459462263981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 181}], {
             RGBColor[
             0.6520185359229838, 0.7272823998054908, 0.9664968499202544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 246}], {
             RGBColor[
             0.5945439555585024, 0.6817165928791875, 0.9612238245492863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 256}], {
             RGBColor[
             0.7927339846129686, 0.8352252152179895, 0.8425165155244698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 296}], {
             RGBColor[
             0.6432277867867322, 0.7204149997680831, 0.9656206702005743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 299}], {
             RGBColor[
             0.7923522710279916, 0.8350967196266381, 0.8509761351220573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 186}], {
             RGBColor[
             0.22312007554742067`, 0.3518437244031648, 0.9360177302746292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 230}], {
             RGBColor[
             0.2328116110999559, 0.36203014274772405`, 0.9365696488870041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 265}], {
             RGBColor[
             0.21936843133233605`, 0.34790050846512904`, 0.9358040796866404]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 269}], {
             RGBColor[
             0.22164816720784125`, 0.350296655413888, 0.9359339072721834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 191}], {
             RGBColor[
             0.26420786908525307`, 0.39502960052800135`, 0.9383576193326653]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 203}], {
             RGBColor[
             0.27206034387321254`, 0.4032830494058043, 0.9388048061551442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 210}], {
             RGBColor[
             0.33154191612091594`, 0.45934744108992703`, 0.9424285250056568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 239}], {
             RGBColor[
             0.34783050852175984`, 0.47345580113907954`, 0.9434664197100019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 184}], {
             RGBColor[
             0.23939823162616325`, 0.3689530985366296, 0.9369447471819397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.23660390230659725`, 0.366016081251054, 0.9367856142610302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 197}], {
             RGBColor[
             0.22592979758927967`, 0.35479692041582533`, 0.9361777397883018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 211}], {
             RGBColor[
             0.2418593140070983, 0.3715398521606279, 0.9370849021826888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 216}], {
             RGBColor[
             0.2500986511246546, 0.3801999178753255, 0.9375541202425267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 168}], {
             RGBColor[
             0.38489864849528777`, 0.5078015965832141, 0.9457463794229767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 210}], {
             RGBColor[
             0.3812406788826516, 0.5046332471596473, 0.9455132968338751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 241}], {
             RGBColor[
             0.33149984085228634`, 0.458806984736167, 0.9424442983869149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 277}], {
             RGBColor[
             0.36650966152605724`, 0.4918739803278257, 0.94457464943404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 179}], {
             RGBColor[
             0.986953469781533, 0.9683582137242022, 0.5663859549250714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 207}], {
             RGBColor[
             0.8629243195572578, 0.8731271056740303, 0.676546302374514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 232}], {
             RGBColor[
             0.9871784526525289, 0.9674285696046385, 0.48831934332178484`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 240}], {
             RGBColor[
             0.987596961950581, 0.9683237186753911, 0.533871497674751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 281}], {
             RGBColor[
             0.9081683799556731, 0.6116901368011833, 0.2799978889278235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 217}], {
             RGBColor[
             0.899879476841495, 0.9180128953290518, 0.7153753712159427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 233}], {
             RGBColor[
             0.9934058766223102, 0.9883041618002921, 0.5236485484298345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 262}], {
             RGBColor[
             0.9933514957949947, 0.9881878467094093, 0.5177295309761065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 271}], {
             RGBColor[
             0.9850940999243964, 0.9612451065301149, 0.40815265332302325`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 291}], {
             RGBColor[
             0.9053156340255587, 0.5627492600761606, 0.30706567418331665`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 174}], {
             RGBColor[
             0.5731249742958058, 0.6609624837721939, 0.9611637427211077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 185}], {
             RGBColor[
             0.660998380157889, 0.7339582173045702, 0.9676238615993047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 194}], {
             RGBColor[
             0.6348798248522232, 0.7127539974799229, 0.9655677132502221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 215}], {
             RGBColor[
             0.874514844691243, 0.8999677108189541, 0.8534618509904951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 282}], {
             RGBColor[
             0.8587917501354356, 0.8900542041854869, 0.9612556665550847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 283}], {
             RGBColor[
             0.6863247949375169, 0.7545193417646557, 0.9696176497444712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 286}], {
             RGBColor[
             0.6564811647517911, 0.7302909383396649, 0.9672682498554315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 297}], {
             RGBColor[
             0.7571627446031911, 0.8102205578247882, 0.9764305643600557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 182}], {
             RGBColor[
             0.34652806688330007`, 0.474422427150048, 0.9433067307526943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 277}], {
             RGBColor[
             0.3674840405107483, 0.49271793843065337`, 0.944636736001335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 187}], {
             RGBColor[
             0.3284772756829356, 0.4574787305648249, 0.9422044795128589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 213}], {
             RGBColor[
             0.36045188979201, 0.48517353421527176`, 0.944241873649848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 219}], {
             RGBColor[
             0.2836300261607937, 0.41544351905027754`, 0.9394636824456108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 221}], {
             RGBColor[
             0.2938192081333214, 0.4261529953348542, 0.9400439412854023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 264}], {
             RGBColor[
             0.29384317958318956`, 0.42617819084854336`, 0.9400453064240097]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 192}], {
             RGBColor[
             0.8434397887079927, 0.3245517789190093, 0.188825975634882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 195}], {
             RGBColor[
             0.820518598671917, 0.15872051746543236`, 0.16728193930165758`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 200}], {
             RGBColor[
             0.8539446998932355, 0.37225212712685507`, 0.1975915310267845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 225}], {
             RGBColor[
             0.8914281470596066, 0.5246344158422436, 0.23572348923178596`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 228}], {
             RGBColor[
             0.8191183413836293, 0.5128704810525186, 0.5754638060619697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 255}], {
             RGBColor[
             0.8904238882805281, 0.5212468151692371, 0.2318221335134233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 198}], {
             RGBColor[
             0.4413043319504303, 0.556360389684118, 0.9494225547381876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 245}], {
             RGBColor[
             0.4213779646314022, 0.5393981467165758, 0.9480708091897773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 289}], {
             RGBColor[
             0.35466828761855285`, 0.4799752914739057, 0.9438802596927696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 298}], {
             RGBColor[
             0.35180269388930685`, 0.47696337077533185`, 0.9437170683691549]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 174}], {
             RGBColor[
             0.33090944455997406`, 0.4574098756542951, 0.9424391100455509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 183}], {
             RGBColor[
             0.2620424461666492, 0.39275360374480583`, 0.9382343017009069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 203}], {
             RGBColor[
             0.26454467239722235`, 0.39538360216344437`, 0.9383767997830261]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 206}], {
             RGBColor[
             0.2530845856194636, 0.3833383243485512, 0.9377241647947119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 244}], {
             RGBColor[
             0.2560033039447505, 0.38640608236585794`, 0.9378903814854801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 270}], {
             RGBColor[
             0.24887539777286288`, 0.3789142010438502, 0.9374844577737833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 272}], {
             RGBColor[
             0.2463878565667746, 0.37629963751702955`, 0.937342795982084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 186}], {
             RGBColor[
             0.24357136840210497`, 0.3733393298802981, 0.937182401147727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 196}], {
             RGBColor[
             0.2690530219671379, 0.40012216340729806`, 0.9386335436215274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 209}], {
             RGBColor[
             0.2611649721580388, 0.3918313229266909, 0.938184330854223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 230}], {
             RGBColor[
             0.25326290395464024`, 0.3835257482248573, 0.9377343197601018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 263}], {
             RGBColor[
             0.25907859446240145`, 0.3896384076845897, 0.9380655147309758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 276}], {
             RGBColor[
             0.24447758470727698`, 0.3742918206744662, 0.9372340088256796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 279}], {
             RGBColor[
             0.2579831193391787, 0.3884869938729482, 0.9380031290433184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 185}], {
             RGBColor[
             0.4801968939468863, 0.58722835298474, 0.9526796025142897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 194}], {
             RGBColor[
             0.45407833864122044`, 0.5660241331600927, 0.9506234541652072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 283}], {
             RGBColor[
             0.5055233087265141, 0.6077894774448256, 0.9546733906594562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 297}], {
             RGBColor[
             0.5763612583921884, 0.663490693504958, 0.9614863052750408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 177}], {
             RGBColor[
             0.3568594089399756, 0.48219931048302006`, 0.944007932963718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 242}], {
             RGBColor[
             0.2674717938620085, 0.3984601924131547, 0.9385434950201575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 252}], {
             RGBColor[
             0.2975212413691305, 0.4300440669881537, 0.9402547666015143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 253}], {
             RGBColor[
             0.29561827694261666`, 0.42804393072097424`, 0.9401463955926079]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 280}], {
             RGBColor[
             0.2812847712693677, 0.4129785074616403, 0.9393301236490378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 199}], {
             RGBColor[
             0.17893943915932659`, 0.3054070743451405, 0.9335017083917216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 226}], {
             RGBColor[
             0.17893944427006758`, 0.3054070797168533, 0.9335017086827707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 287}], {
             RGBColor[
             0.5599634445497977, 0.5545563829440247, 0.6024338644222329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 217}], {
             RGBColor[
             0.6131216671850642, 0.6933500026997739, 0.964666976055813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 247}], {
             RGBColor[
             0.4991479409504841, 0.603343634292864, 0.9539698061272375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 273}], {
             RGBColor[
             0.5185213619952923, 0.6190718502597115, 0.9554949527990644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 285}], {
             RGBColor[
             0.40098949086418123`, 0.5217386754938967, 0.9467716736701495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 182}], {
             RGBColor[
             0.29211972893207316`, 0.4243667349411374, 0.9399471584590454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 202}], {
             RGBColor[
             0.25258870101180897`, 0.3828171181850061, 0.9376959248999015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 208}], {
             RGBColor[
             0.2815080542956977, 0.41321319207927465`, 0.9393428392870697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 268}], {
             RGBColor[
             0.26978635473276824`, 0.4008929426399584, 0.9386753058376613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 281}], {
             RGBColor[
             0.9148614845826333, 0.6349726325663724, 0.4685681683997813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 190}], {
             RGBColor[
             0.23107912024585836`, 0.36020918501380295`, 0.9364709860958538]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 250}], {
             RGBColor[
             0.22830469938985565`, 0.3572930927857018, 0.9363129869324922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 207}], {
             RGBColor[
             0.729702675862836, 0.7887685434205706, 0.9736936013369495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 232}], {
             RGBColor[
             0.8539568089581072, 0.8830700073511788, 0.7854666422842203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 240}], {
             RGBColor[
             0.8543753182561593, 0.8839651564219314, 0.8310187966371865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 246}], {
             RGBColor[
             0.656342497401248, 0.7307927865257904, 0.9668372480070162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 256}], {
             RGBColor[
             0.8545325264557142, 0.8843014088645924, 0.8481299389821997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 296}], {
             RGBColor[
             0.7050263286294778, 0.769491193414686, 0.9712340936583042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 299}], {
             RGBColor[
             0.8541508128707371, 0.884172913273241, 0.8565895585797871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 208}], {
             RGBColor[
             0.2965714316502459, 0.42904575675219153`, 0.9402006763431414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 268}], {
             RGBColor[
             0.28484973208731645`, 0.4167255073128753, 0.939533142893733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 244}], {
             RGBColor[
             0.24855034907625476`, 0.37857255425443737`, 0.937465946731378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 189}], {
             RGBColor[
             0.2346427787554684, 0.3639548160564028, 0.9366739311760157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 197}], {
             RGBColor[
             0.22396867403815082`, 0.3527356552211741, 0.9360660567032872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 202}], {
             RGBColor[
             0.23277907926056368`, 0.361995949721885, 0.9365677962468772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 214}], {
             RGBColor[
             0.22515962250579277`, 0.3539874175711599, 0.9361338794566691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 216}], {
             RGBColor[
             0.24813752757352578`, 0.3781386526806742, 0.9374424371575123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 275}], {
             RGBColor[
             0.22510784132218828`, 0.35393299226407493`, 0.9361309305948662]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 293}], {
             RGBColor[
             0.22334920945949943`, 0.35208455867268873`, 0.9360307791119489]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 237}], {
             RGBColor[
             0.6034248054489583, 0.6889264668979879, 0.961922957584288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 239}], {
             RGBColor[
             0.4896022864326819, 0.5953748312271646, 0.9532789058066227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 282}], {
             RGBColor[
             0.7658636697865162, 0.8163200733980329, 0.9527715263482667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 283}], {
             RGBColor[
             0.5933967145885973, 0.6807852109772019, 0.9611335095376532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 295}], {
             RGBColor[
             0.7026775395247731, 0.7666581291332051, 0.9717409425805205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 297}], {
             RGBColor[
             0.6642346642542716, 0.7364864270373344, 0.9679464241532377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 196}], {
             RGBColor[
             0.255450766680841, 0.38582533066860314`, 0.9378589153057062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 230}], {
             RGBColor[
             0.23966064866834333`, 0.3692289154861624, 0.9369596914442806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 263}], {
             RGBColor[
             0.24547633917610456`, 0.3753415749458948, 0.9372908864151546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 269}], {
             RGBColor[
             0.2284972047762287, 0.3574954281523263, 0.93632394982946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 276}], {
             RGBColor[
             0.2308753294209801, 0.3599949879357713, 0.9364593805098584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 279}], {
             RGBColor[
             0.24438086405288187`, 0.3741901611342533, 0.9372285007274972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 205}], {
             RGBColor[
             0.44668815437293624`, 0.55925348518074, 0.950254691291311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 213}], {
             RGBColor[
             0.395904109711405, 0.5173339739380506, 0.9464476376799205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 264}], {
             RGBColor[
             0.3292953995025846, 0.4583386305713222, 0.9422510704540822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 212}], {
             RGBColor[
             0.20871789165381538`, 0.33670611597978567`, 0.9351975472080101]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 243}], {
             RGBColor[
             0.21194079974675017`, 0.3400935967296356, 0.9353810870560375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 294}], {
             RGBColor[
             0.20780626806211017`, 0.3357479417846294, 0.9351456315930887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 197}], {
             RGBColor[
             0.22117434471858483`, 0.3497986379355985, 0.9359069237823778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 211}], {
             RGBColor[
             0.23710386113640347`, 0.3665415696804011, 0.9368140861767649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 216}], {
             RGBColor[
             0.24534319825395978`, 0.3752016353950986, 0.9372833042366027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 275}], {
             RGBColor[
             0.22231351200262228`, 0.3509959749784993, 0.9359717976739568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 293}], {
             RGBColor[
             0.2205548801399334, 0.3491475413871131, 0.9358716461910392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 212}], {
             RGBColor[
             0.21992645288427248`, 0.3484870244968241, 0.9358358581885042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 250}], {
             RGBColor[
             0.22535768471974588`, 0.35419559351589436`, 0.9361451588067469]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 203}], {
             RGBColor[
             0.2517414689713402, 0.38192662359285945`, 0.9376476762885642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 195}], {
             RGBColor[
             0.8420649475314406, 0.3139841471767838, 0.18750942617155456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 200}], {
             RGBColor[
             0.875491048752759, 0.5275157568382065, 0.21781901789668148`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[
             0.91297449591913, 0.6798980455535951, 0.25595097610168294`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 228}], {
             RGBColor[
             0.8406646902431527, 0.6681341107638701, 0.5956912929318666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 255}], {
             RGBColor[
             0.9119702371400515, 0.6765104448805886, 0.25204962038332024`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 199}], {
             RGBColor[
             0.28921237678725265`, 0.4129203038152378, 0.9400888107445714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 220}], {
             RGBColor[
             0.3283447463388828, 0.4540509053495343, 0.9423173412993839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 236}], {
             RGBColor[
             0.511354201918838, 0.6127180573453962, 0.9550785966275717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 249}], {
             RGBColor[
             0.609038860752824, 0.33213297985445467`, 0.5560510629020323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 266}], {
             RGBColor[
             0.3235658537972168, 0.4490279862889558, 0.942045190438874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 283}], {
             RGBColor[
             0.5672781592829315, 0.6595809911525545, 0.9590773611885706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 286}], {
             RGBColor[
             0.5374345290972057, 0.6353525877275636, 0.9567279612995309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 297}], {
             RGBColor[
             0.6381161089486057, 0.715282207212687, 0.9658902758041552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 200}], {
             RGBColor[
             0.8525698587166832, 0.36168449538462955`, 0.19627498156345707`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 225}], {
             RGBColor[
             0.8900533058830544, 0.5140667841000182, 0.23440693976845853`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 255}], {
             RGBColor[
             0.8890490471039758, 0.5106791834270117, 0.23050558405009586`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 230}], {
             RGBColor[
             0.2651423022333762, 0.39601174901316233`, 0.938410833918081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 263}], {
             RGBColor[
             0.27095799274113747`, 0.40212440847289477`, 0.9387420288889549]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 279}], {
             RGBColor[
             0.2698625176179148, 0.40097299466125325`, 0.9386796432012976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 289}], {
             RGBColor[
             0.28595784411409636`, 0.4178902033113814, 0.9395962482343534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 298}], {
             RGBColor[
             0.28309225038485036`, 0.4148782826128075, 0.9394330569107388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 214}], {
             RGBColor[
             0.21169118846890916`, 0.33983123945035565`, 0.9353668720630313]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 275}], {
             RGBColor[
             0.21163940728530467`, 0.33977681414327066`, 0.9353639232012283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 293}], {
             RGBColor[
             0.20988077542261582`, 0.33792838055188446`, 0.9352637717183109]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 222}], {
             RGBColor[
             0.4501940180001994, 0.5640601889318158, 0.9499889976724383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 245}], {
             RGBColor[
             0.4443289893270455, 0.5589801958800422, 0.949615283231626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 258}], {
             RGBColor[
             0.7130111957358749, 0.7734744682690422, 0.9502848227262681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 278}], {
             RGBColor[
             0.5335934338471843, 0.6322342135642272, 0.9564255762110536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 290}], {
             RGBColor[
             0.5385920372825843, 0.6362923050176035, 0.9568190845839761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 220}], {
             RGBColor[
             0.21805936955163013`, 0.34652460153429643`, 0.9357295305548126]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 226}], {
             RGBColor[
             0.178927005110741, 0.3053940053717128, 0.9335010002910491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 228}], {
             RGBColor[
             0.49763512145939465`, 0.5809234064486897, 0.9579150616794772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 266}], {
             RGBColor[
             0.21328047700996416`, 0.3415016824737179, 0.9354573796943026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 225}], {
             RGBColor[
             0.9234794071043728, 0.7275983937614409, 0.2647165314935854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 255}], {
             RGBColor[
             0.9224751483252943, 0.7242107930884344, 0.2608151757752228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 282}], {
             RGBColor[
             0.9248264998510323, 0.7738160826625009, 0.5864939522963153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 295}], {
             RGBColor[
             0.8616403695892892, 0.7241541383976731, 0.6054633685285691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 209}], {
             RGBColor[
             0.29313467956513195`, 0.424290095199951, 0.9400468245012701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 218}], {
             RGBColor[
             0.2885778810548669, 0.4195006110479498, 0.9397873215672898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 229}], {
             RGBColor[
             0.3337508945428317, 0.46349998287045846`, 0.9424872897693092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 257}], {
             RGBColor[
             0.35620917982441114`, 0.48295222079512334`, 0.9439183118483695]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 259}], {
             RGBColor[
             0.3926869440225089, 0.5142503026969059, 0.9463247389793005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 261}], {
             RGBColor[
             0.36087721144814144`, 0.48699543516550725`, 0.9442157546956553]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 208}], {
             RGBColor[
             0.2570404037299817, 0.3874961399960602, 0.9379494427839974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 214}], {
             RGBColor[
             0.22050159369132202`, 0.3490915339510665, 0.935868611606621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 268}], {
             RGBColor[
             0.2453187041670522, 0.37517589055674394`, 0.937281909334589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 275}], {
             RGBColor[
             0.22044981250771753`, 0.3490371086439815, 0.9358656627448182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 206}], {
             RGBColor[
             0.24813385698154097`, 0.37813479465576916`, 0.9374422281227288]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 244}], {
             RGBColor[
             0.2510525753068279, 0.38120255267307596`, 0.9376084448134971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 270}], {
             RGBColor[
             0.2439246691349402, 0.37371067135106817`, 0.9372025211018002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 235}], {
             RGBColor[
             0.23646094075205434`, 0.36586581959294334`, 0.9367774728119916]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 253}], {
             RGBColor[
             0.26380404156370607`, 0.39460515219871184`, 0.9383346219527224]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 292}], {
             RGBColor[
             0.2369721103072519, 0.36640309120547765`, 0.9368065831619525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 213}], {
             RGBColor[
             0.4786627684820106, 0.5869482888311869, 0.9522920854283001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 231}], {
             RGBColor[
             0.4872830813565614, 0.5944147705735998, 0.9528413641420233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 244}], {
             RGBColor[
             0.23959248852906917`, 0.3691572748581827, 0.9369558098251829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 270}], {
             RGBColor[
             0.23246458235718154`, 0.361665393536175, 0.936549886113486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 272}], {
             RGBColor[
             0.22997704115109324`, 0.35905083000935434`, 0.9364082243217868]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 231}], {
             RGBColor[
             0.5953538117647618, 0.6805701172311853, 0.962430259270135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 232}], {
             RGBColor[
             0.8698424070552139, 0.8954799573196557, 0.7870499702431855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 240}], {
             RGBColor[
             0.870260916353266, 0.8963751063904083, 0.8326021245961515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 268}], {
             RGBColor[
             0.274238057450941, 0.4055719644510125, 0.9389288237217572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 218}], {
             RGBColor[
             0.2605995221174108, 0.3912369990823875, 0.9381521293109176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 276}], {
             RGBColor[
             0.24846893317691396`, 0.37848698098216405`, 0.9374613102163545]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 279}], {
             RGBColor[
             0.2619744678088157, 0.39268215418064606`, 0.9382304304339932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 239}], {
             RGBColor[
             0.39484568065555037`, 0.5164172158880604, 0.9463801955164135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 277}], {
             RGBColor[
             0.36382607089811214`, 0.48954958900708645`, 0.9444036534122333]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 216}], {
             RGBColor[
             0.2505986099544608, 0.38072540630467244`, 0.9375825921582613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 221}], {
             RGBColor[
             0.26848631667000333`, 0.39952652020881857`, 0.9386012705932207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 243}], {
             RGBColor[
             0.2149437082857312, 0.34324984399950276`, 0.9355520982549272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 250}], {
             RGBColor[
             0.21715203202826977`, 0.34557093226872304`, 0.9356778590251427]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 294}], {
             RGBColor[
             0.2108091766010912, 0.3389041890544966, 0.9353166427919786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 231}], {
             RGBColor[
             0.43649903669503015`, 0.5524952593309104, 0.9490343105306326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 264}], {
             RGBColor[
             0.36127001361165895`, 0.48603343422176903`, 0.9442884645910713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 275}], {
             RGBColor[
             0.21283035575294662`, 0.34102857649325646`, 0.9354317459546102]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 293}], {
             RGBColor[
             0.21107172389025777`, 0.33918014290187026`, 0.9353315944716927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 223}], {
             RGBColor[
             0.9412290011481947, 0.7868146166289862, 0.47926705037049566`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 234}], {
             RGBColor[
             0.9062111144378386, 0.5631850367729421, 0.44751685008743375`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 271}], {
             RGBColor[
             0.9862840872732699, 0.9639445925953173, 0.5488858494022204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 274}], {
             RGBColor[
             0.979839341035498, 0.9422049502369351, 0.5238492272566825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 282}], {
             RGBColor[
             0.97938013431987, 0.9823295669124169, 0.8386095157394571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 286}], {
             RGBColor[
             0.7770695489362254, 0.8225663010665949, 0.8446220990398039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 233}], {
             RGBColor[
             0.9005620992858752, 0.9194729557138646, 0.7896746116293041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 247}], {
             RGBColor[
             0.6930619732704799, 0.7591753208357144, 0.9707042644868367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 262}], {
             RGBColor[
             0.9005077184585596, 0.9193566406229818, 0.783755594175576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 273}], {
             RGBColor[
             0.7124353943152881, 0.7749035368025619, 0.9722294111586636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 229}], {
             RGBColor[
             0.3012157370951104, 0.430446886752895, 0.9405925945789568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 284}], {
             RGBColor[
             0.25584347148447395`, 0.38623808831614403`, 0.9378812792633183]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 221}], {
             RGBColor[
             0.28442417853057445`, 0.4162782235430855, 0.9395089082482266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 264}], {
             RGBColor[
             0.28444814998044265`, 0.4163034190567747, 0.9395102733868341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 226}], {
             RGBColor[
             0.21805937466237113`, 0.3465246069060093, 0.9357295308458616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 228}], {
             RGBColor[
             0.5367674910110247, 0.6220540079829862, 0.9601435922342896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 236}], {
             RGBColor[
             0.4402011946832155, 0.5463223550644548, 0.9507193164378127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 266}], {
             RGBColor[
             0.2524128465615943, 0.3826322840080144, 0.9376859102491151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 231}], {
             RGBColor[
             0.3698663550363416, 0.4934747204504928, 0.9448363781661868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 245}], {
             RGBColor[
             0.43026765068117134`, 0.5470979459642735, 0.9486372521240278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 261}], {
             RGBColor[
             0.41838703187400994`, 0.5368075510907742, 0.9478802295992542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 278}], {
             RGBColor[
             0.51953209520131, 0.6203519636484585, 0.9554475451034554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 290}], {
             RGBColor[
             0.5245306986367102, 0.6244100551018348, 0.9558410534763778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 234}], {
             RGBColor[
             0.852336886710356, 0.35775657985604403`, 0.19596820028306192`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 271}], {
             RGBColor[
             0.9324098595457874, 0.7585161356784191, 0.29733719959784854`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 274}], {
             RGBColor[
             0.9259651133080155, 0.7367764933200369, 0.2723005774523107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 287}], {
             RGBColor[
             0.9141648921008272, 0.6925393884549282, 0.24954185631357317`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 291}], {
             RGBColor[
             0.8526313936469496, 0.36002028922446494`, 0.19625022045814194`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 249}], {
             RGBColor[
             0.8940523406864429, 0.5263405979795888, 0.25076760006070237`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 254}], {
             RGBColor[
             0.9304233123934045, 0.7541309251793602, 0.28356918675006826`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 258}], {
             RGBColor[
             0.9656458741337097, 0.9399341707856219, 0.6428561562394914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 260}], {
             RGBColor[
             0.9093392465848947, 0.8957090172216551, 0.6607919677185569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 288}], {
             RGBColor[
             0.9157129138329121, 0.6873344410170366, 0.27129446960632875`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 234}], {
             RGBColor[
             0.889140927135372, 0.5070538412384147, 0.23353324484929344`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 255}], {
             RGBColor[
             0.9599585954916654, 0.876593081803823, 0.2989471339802242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 287}], {
             RGBColor[
             0.950968932525843, 0.8418366498372989, 0.2871069008798047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 228}], {
             RGBColor[
             0.4976351265701356, 0.5809234118204025, 0.9579150619705263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 266}], {
             RGBColor[
             0.21328048212070516`, 0.3415016878454308, 0.9354573799853517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 264}], {
             RGBColor[
             0.2772132461146813, 0.4086990763744601, 0.9390982563147601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 266}], {
             RGBColor[
             0.5319885984693589, 0.6170310889224077, 0.9598714413737797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 257}], {
             RGBColor[
             0.3688470358646546, 0.49389849650006856`, 0.9447235848600365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 259}], {
             RGBColor[
             0.40532480006275245`, 0.5251965784018511, 0.9471300119909675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 261}], {
             RGBColor[
             0.3735150674883849, 0.49794171087045247`, 0.9450210277073223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 284}], {
             RGBColor[
             0.3010164849724387, 0.4302374601386527, 0.9405812474653377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 263}], {
             RGBColor[
             0.2551678747286398, 0.38552799329045395`, 0.9378428050275294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 269}], {
             RGBColor[
             0.23818874032876391`, 0.3676818464968855, 0.9368758684418348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 289}], {
             RGBColor[
             0.27016772610159867`, 0.4012937881289406, 0.9386970243729278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 298}], {
             RGBColor[
             0.2673021323723527, 0.39828186743036675`, 0.9385338330493134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 240}], {
             RGBColor[
             0.9945150494485371, 0.9906765703210165, 0.6443751655434223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 256}], {
             RGBColor[
             0.9946722576480922, 0.9910128227636774, 0.6614863078884357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 296}], {
             RGBColor[
             0.8451660598218556, 0.8762026073137711, 0.7845904625645401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 299}], {
             RGBColor[
             0.994290544063115, 0.9908843271723261, 0.6699459274860231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 262}], {
             RGBColor[
             0.9940341182393746, 0.9896479070942221, 0.5920287713894679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 288}], {
             RGBColor[
             0.9279948066453856, 0.7277856301692169, 0.40221351612468526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 291}], {
             RGBColor[
             0.9059982564699387, 0.5642093204609733, 0.381364914596678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 255}], {
             RGBColor[
             0.8881366683562935, 0.5036662405654082, 0.2296318891309308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 271}], {
             RGBColor[
             0.8973919728354314, 0.5348865558223752, 0.26558699931478663`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 274}], {
             RGBColor[
             0.8909472265976595, 0.513146913463993, 0.24055037716924876`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 287}], {
             RGBColor[
             0.8791470053904711, 0.46890980859888415`, 0.21779165603051126`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 252}], {
             RGBColor[
             0.2712852344852127, 0.40246836029424277`, 0.9387606648221691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 253}], {
             RGBColor[
             0.2693822700586988, 0.40046822402706334`, 0.9386522938132629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 292}], {
             RGBColor[
             0.24255033880224458`, 0.3722661630338292, 0.9371242550224929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 249}], {
             RGBColor[
             0.7208953090971567, 0.4244044295693752, 0.5644530380404611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 266}], {
             RGBColor[
             0.43542230214154953`, 0.5412994360038763, 0.9504471655773028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 239}], {
             RGBColor[
             0.5249567920726707, 0.6240772116080362, 0.9560621419984239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 282}], {
             RGBColor[
             0.8012181754265049, 0.8450224537789045, 0.955554762540068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 283}], {
             RGBColor[
             0.6287512202285861, 0.7094875913580734, 0.9639167457294545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 295}], {
             RGBColor[
             0.738032045164762, 0.7953605095140767, 0.9745241787723218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 297}], {
             RGBColor[
             0.6995891698942603, 0.7651888074182058, 0.970729660345039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 251}], {
             RGBColor[
             0.2826141781107905, 0.4143757983412377, 0.9394058314019756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 300}], {
             RGBColor[
             0.2671877155710705, 0.398161608117775, 0.9385273171817448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 295}], {
             RGBColor[
             0.6242095261484855, 0.7018088738432534, 0.9658801269946564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 256}], {
             RGBColor[
             0.9950907669461442, 0.9919079718344301, 0.7070384622414018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 281}], {
             RGBColor[
             0.9155049767516813, 0.6349381375175613, 0.436053711149461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 299}], {
             RGBColor[
             0.9947090533611671, 0.9917794762430787, 0.7154980818389891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 277}], {
             RGBColor[
             0.3140852328677468, 0.44372332658360614`, 0.9413346549652732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 243}], {
             RGBColor[
             0.22929951054390013`, 0.35833870238327276`, 0.9363696399560237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 280}], {
             RGBColor[
             0.25424538211649345`, 0.38455839506567835`, 0.9377902704379731]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 294}], {
             RGBColor[
             0.22516497885926012`, 0.35399304743826654`, 0.9361341844930751]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 294}], {
             RGBColor[
             0.21403208469402601`, 0.34229166980434655`, 0.935500182640006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 270}], {
             RGBColor[
             0.23538330068246843`, 0.36473315155348174`, 0.9367161028042543]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 272}], {
             RGBColor[
             0.23289575947638014`, 0.3621185880266611, 0.936574441012555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 289}], {
             RGBColor[
             0.3576929449951681, 0.48259509766982983`, 0.944072988186208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 298}], {
             RGBColor[
             0.35482735126592213`, 0.47958317697125596`, 0.9439097968625934]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 256}], {
             RGBColor[
             0.7970579460912328, 0.838735601938289, 0.8428569136112316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 296}], {
             RGBColor[
             0.6475517482649964, 0.7239253864883827, 0.965961068287336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 299}], {
             RGBColor[
             0.7966762325062557, 0.8386071063469377, 0.851316533208819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 267}], {
             RGBColor[
             0.5234677465828359, 0.6240137244860162, 0.9556284450179895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 273}], {
             RGBColor[
             0.598461668080708, 0.6848971683956518, 0.9615322412300882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 285}], {
             RGBColor[
             0.4809297969495969, 0.5875639936298371, 0.952808962101173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 270}], {
             RGBColor[
             0.21830317142063266`, 0.3467808527565494, 0.9357434147105796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 254}], {
             RGBColor[
             0.8549509396381043, 0.371609679278205, 0.19822709100428773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 288}], {
             RGBColor[
             0.8402405410776118, 0.30481319511588134`, 0.18595237386054825`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 300}], {
             RGBColor[
             0.27128730129384493`, 0.40247053264115845`, 0.9387607825238632]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 253}], {
             RGBColor[
             0.29862833529686444`, 0.43120769290001126`, 0.9403178139629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 292}], {
             RGBColor[
             0.2717964040404102, 0.4030056319067771, 0.9387897751721301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 292}], {
             RGBColor[
             0.26989343961389634`, 0.40100549563959764`, 0.9386814041632237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 258}], {
             RGBColor[
             0.926544473085371, 0.7852032520842381, 0.5903156471830767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 260}], {
             RGBColor[
             0.870237845536556, 0.7409780985202714, 0.6082514586621423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 288}], {
             RGBColor[
             0.8766115127845734, 0.5326035223156528, 0.21875396054991414`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 287}], {
             RGBColor[
             0.9499646737467646, 0.8384490491642924, 0.28320554516144203`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 296}], {
             RGBColor[
             0.8457417773194627, 0.8774340088271846, 0.8472537592625196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 299}], {
             RGBColor[
             0.994866261560722, 0.9921157286857396, 0.7326092241840025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 259}], {
             RGBColor[
             0.4277830853443319, 0.544648816326516, 0.9485610340700278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 261}], {
             RGBColor[
             0.39597335276996437`, 0.5173939487951174, 0.9464520497863826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 260}], {
             RGBColor[
             0.9054604072768613, 0.9267813441265331, 0.9675384281515653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 278}], {
             RGBColor[
             0.7823492729369855, 0.8297662429856849, 0.9557433701572854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 290}], {
             RGBColor[
             0.7873478763723856, 0.8338243344390612, 0.9561368785302078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 260}], {
             RGBColor[
             0.656707314635238, 0.7292515443954324, 0.9682208504157948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 261}], {
             RGBColor[
             0.4324511169680622, 0.5486920306968999, 0.9488584769173136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 261}], {
             RGBColor[
             0.6248975820608704, 0.7019966768640338, 0.9661118661321497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 278}], {
             RGBColor[
             0.7260426453881705, 0.7855410894217181, 0.9736791816363508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 290}], {
             RGBColor[
             0.7310412488235707, 0.7895991808750945, 0.9740726900092733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 278}], {
             RGBColor[
             0.5017864477209948, 0.6049815757231856, 0.9543168081378697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 290}], {
             RGBColor[
             0.5067850511563949, 0.6090396671765619, 0.9547103165107921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 271}], {
             RGBColor[
             0.9857223415414609, 0.9625888518240449, 0.4765328762826566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 291}], {
             RGBColor[
             0.9059438756426232, 0.5640930053700905, 0.37544589714295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 269}], {
             RGBColor[
             0.24400443083652518`, 0.3737945059566179, 0.9372070634127088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 276}], {
             RGBColor[
             0.24638255548127658`, 0.37629406574006286`, 0.9373424940931072]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 279}], {
             RGBColor[
             0.25988809011317837`, 0.3904892389385449, 0.938111614310746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 289}], {
             RGBColor[
             0.27598341660935993`, 0.40740644758867306`, 0.9390282193438018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 298}], {
             RGBColor[
             0.27311782288011394`, 0.40439452689009914`, 0.9388650280201871]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 269}], {
             RGBColor[
             0.2247455605611441, 0.35355221221429056`, 0.9361102992414712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 273}], {
             RGBColor[
             0.5428411676276441, 0.6397419404528637, 0.9571535916898165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 285}], {
             RGBColor[
             0.42530929649653304`, 0.542408765687049, 0.9484303125609015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 286}], {
             RGBColor[
             0.5134415575632728, 0.6158740125652669, 0.954839146691229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 298}], {
             RGBColor[
             0.2561386884802381, 0.3865483800965307, 0.9378980914344927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 272}], {
             RGBColor[
             0.22576785330449248`, 0.35462670670465335`, 0.9361685173008583]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 274}], {
             RGBColor[
             0.9710201994330907, 0.9139064692863681, 0.34191937648403536`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 291}], {
             RGBColor[
             0.897686479772025, 0.537150265190796, 0.2658690194898667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 285}], {
             RGBColor[
             0.5003032179944051, 0.6032922095966846, 0.9543341087730001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 287}], {
             RGBColor[
             0.9527752319881305, 0.8479297220628771, 0.29412403319976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 293}], {
             RGBColor[
             0.21101994270665328`, 0.33912571759478527`, 0.9353286456098898]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 279}], {
             RGBColor[
             0.24528708035805388`, 0.3751426519284214, 0.9372801084054498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 290}], {
             RGBColor[
             0.607930114483695, 0.6925840797342462, 0.9622776320149933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 283}], {
             RGBColor[
             0.7911900845661439, 0.8368811978581185, 0.9547653144934332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 295}], {
             RGBColor[
             0.9004709095023198, 0.9227541160141217, 0.9653727475363004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 297}], {
             RGBColor[
             0.8620280342318183, 0.892582413918251, 0.9615782291090177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 295}], {
             RGBColor[
             0.728003954304401, 0.7872192535932907, 0.973734730725687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 297}], {
             RGBColor[
             0.6895610790338994, 0.7570475514974199, 0.9699402122984042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 291}], {
             RGBColor[
             0.839904564048634, 0.3022307284450855, 0.18563064187816736`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 298}], {
             RGBColor[
             0.28811767425307283`, 0.4201603217285858, 0.9397192473655857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 297}], {
             RGBColor[
             0.7988419039700752, 0.8429204696534232, 0.9805476453412715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 299}], {
             RGBColor[
             0.8453600637344856, 0.8773055132358333, 0.8557133788601069]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.03434177932816089], {
             RGBColor[
             0.41852266255485593`, 0.5369250275695268, 0.9478888718663042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.03434177932816089], {
             RGBColor[
             0.2307572995292167, 0.3598709310360006, 0.936452658882132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.03434177932816089], {
             RGBColor[
             0.3773249031069595, 0.5012415989953558, 0.9452637870640326]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.03434177932816089], {
             RGBColor[
             0.5396207399250182, 0.6371274521652572, 0.9569000678242504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.03434177932816089], {
             RGBColor[
             0.220958970004222, 0.34957226545525755`, 0.9358946585110132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.03434177932816089], {
             RGBColor[
             0.3056730571205615, 0.43861214219787836`, 0.9407190004490276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.03434177932816089], {
             RGBColor[
             0.394746751143397, 0.516331528116975, 0.946373891815379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.03434177932816089], {
             RGBColor[
             0.6518492866916434, 0.7279488840923621, 0.9659339030856515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.03434177932816089], {
             RGBColor[
             0.5168296547678491, 0.6186246225079816, 0.9551058701141822]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.03434177932816089], {
             RGBColor[
             0.2114327980870659, 0.3395596547761419, 0.9353521571130395]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.03434177932816089], {
             RGBColor[
             0.34350580070653963`, 0.47194919229362253`, 0.9431088637641358]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.03434177932816089], {
             RGBColor[
             0.20154157699751735`, 0.32916335427138743`, 0.93478886670474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.03434177932816089], {
             RGBColor[
             0.30612838775897044`, 0.4390907235684761, 0.9407449308552837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.03434177932816089], {
             RGBColor[
             0.8226976998778256, 0.17547004422228246`, 0.1693686490773784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.03434177932816089], {
             RGBColor[
             0.23892277989457777`, 0.36845336862135236`, 0.9369176709091936]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.03434177932816089], {
             RGBColor[
             0.9934703621130101, 0.9884420897444159, 0.5306673961342021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.03434177932816089], {
             RGBColor[
             0.29622239326445615`, 0.42867889527841463`, 0.9401807991234267]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.03434177932816089], {
             RGBColor[
             0.9464007204285422, 0.9595463255731478, 0.9756137787701872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.03434177932816089], {
             RGBColor[
             0.2912671539208582, 0.4234706245479727, 0.9398986055734284]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.03434177932816089], {
             RGBColor[
             0.865905855945801, 0.8959138414156087, 0.9870720676150353]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.03434177932816089], {
             RGBColor[
             0.38345468665213356`, 0.5065509094103063, 0.9456543714511763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.03434177932816089], {
             RGBColor[
             0.8173789776787558, 0.8572619367637411, 0.982432355720336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.03434177932816089], {
             RGBColor[
             0.2963741173821658, 0.42883836694599214`, 0.9401894395874745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.03434177932816089], {
             RGBColor[
             0.9556367854010767, 0.9664345677069957, 0.9599795299232305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.03434177932816089], {
             RGBColor[
             0.2518103509231395, 0.3819990228915686, 0.9376515990138174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.03434177932816089], {
             RGBColor[
             0.9858349896506369, 0.9884104184434465, 0.8844144095680297]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.03434177932816089], {
             RGBColor[
             0.2584384877012701, 0.38896561489352793`, 0.9380290615978824]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.03434177932816089], {
             RGBColor[
             0.22341264573171882`, 0.35215123421688327`, 0.9360343917138061]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.03434177932816089], {
             RGBColor[
             0.24282295558358705`, 0.3725527005559224, 0.9371397801448899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.03434177932816089], {
             RGBColor[
             0.46219840465570133`, 0.574272512557169, 0.9508050979844909]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.03434177932816089], {
             RGBColor[
             0.6188367246795077, 0.7014385572283971, 0.9631362403218372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.03434177932816089], {
             RGBColor[
             0.2562574704790552, 0.38667322750850125`, 0.9379048558936031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.03434177932816089], {
             RGBColor[
             0.9146626577353835, 0.9347911916944939, 0.9917225348954364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.03434177932816089], {
             RGBColor[
             0.3274991935787168, 0.458085073714969, 0.9420889369120379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.03434177932816089], {
             RGBColor[
             0.2262311772849768, 0.3551136895845794, 0.9361949029161204]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.03434177932816089], {
             RGBColor[
             0.7595712694087771, 0.8121021157083784, 0.9766706236037325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.03434177932816089], {
             RGBColor[
             0.6807027709206555, 0.7504894452666685, 0.968809748742459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.03434177932816089], {
             RGBColor[
             0.4179442959916355, 0.5364240755220139, 0.9478520188603253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.03434177932816089], {
             RGBColor[
             0.8675327116732591, 0.4913788068770457, 0.21117838636085415`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.03434177932816089], {
             RGBColor[
             0.2372124705557414, 0.3666557250663601, 0.9368202713225229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.03434177932816089], {
             RGBColor[
             0.35699077137457635`, 0.483629196111943, 0.9439681141708117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.03434177932816089], {
             RGBColor[
             0.2544378422070241, 0.3847606828235006, 0.9378012307554097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.03434177932816089], {
             RGBColor[
             0.322173741643116, 0.45347243491334854`, 0.9417496038238137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.03434177932816089], {
             RGBColor[
             0.9650552642631052, 0.8937853423246256, 0.3187467297321304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.03434177932816089], {
             RGBColor[
             0.8578237913971699, 0.4454645759914146, 0.2030054339855487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.03434177932816089], {
             RGBColor[
             0.29213812634371106`, 0.4243860717872321, 0.9399482061644217]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.03434177932816089], {
             RGBColor[
             0.6440597930627512, 0.7218636724671273, 0.9651575191576801]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.03434177932816089], {
             RGBColor[
             0.4136829046946342, 0.5327330725643056, 0.9475804867750808]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.03434177932816089], {
             RGBColor[
             0.23655451757503262`, 0.36596417476700677`, 0.9367828018736257]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.03434177932816089], {
             RGBColor[
             0.35244904856935166`, 0.4796953840916829, 0.9436787196097506]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.03434177932816089], {
             RGBColor[
             0.993562122803693, 0.9916057865804992, 0.7563558160423134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.03434177932816089], {
             RGBColor[
             0.8177080186927622, 0.13711716814164848`, 0.16459052473952288`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.03434177932816089], {
             RGBColor[
             0.8317291195209172, 0.2448894931924079, 0.17801714672713256`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.03434177932816089], {
             RGBColor[
             0.4174064139952154, 0.53595818917145, 0.9478177454951437]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.03434177932816089], {
             RGBColor[
             0.2766948027559306, 0.4081541595332056, 0.9390687317324474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.03434177932816089], {
             RGBColor[
             0.5476923991281734, 0.6436803887304818, 0.9575354984041846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.03434177932816089], {
             RGBColor[
             0.24705297562595502`, 0.37699871981921224`, 0.9373806735285489]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.03434177932816089], {
             RGBColor[
             0.5489231824340144, 0.6446795940643196, 0.9576323901745283]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.03434177932816089], {
             RGBColor[
             0.8328101555207211, 0.25319880959989605`, 0.17905234802140027`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.03434177932816089], {
             RGBColor[
             0.9260824493199337, 0.7446485736567867, 0.2593824075361489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.03434177932816089], {
             RGBColor[
             0.5668393910348319, 0.659224779322463, 0.9590428197448192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.03434177932816089], {
             RGBColor[
             0.9948487335515908, 0.9913902868768101, 0.6806946209012268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.03434177932816089], {
             RGBColor[
             0.32451328924336914`, 0.4554988334556064, 0.9418986777281211]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.03434177932816089], {
             RGBColor[
             0.23365539790008147`, 0.3629170161738291, 0.9366177012970005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.03434177932816089], {
             RGBColor[
             0.28791659856684826`, 0.41994897843342893`, 0.9397077964027201]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.03434177932816089], {
             RGBColor[
             0.9464558742569554, 0.9595874592080723, 0.9755204177251058]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.03434177932816089], {
             RGBColor[
             0.9123183312358003, 0.932921889378774, 0.9914989309411012]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.03434177932816089], {
             RGBColor[
             0.8743662175245639, 0.5224081609419808, 0.2168804311477391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.03434177932816089], {
             RGBColor[
             0.9930380091079225, 0.9875173303841278, 0.48360843970387296`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.03434177932816089], {
             RGBColor[
             0.26423372362278924`, 0.39505677528622424`, 0.9383590917103296]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.03434177932816089], {
             RGBColor[
             0.6295965520330332, 0.7101738697986875, 0.963983293345653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.03434177932816089], {
             RGBColor[
             0.6518075404484566, 0.7279162716099014, 0.9659297422102715]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.03434177932816089], {
             RGBColor[
             0.3290101239879992, 0.459393765693919, 0.9421852120616541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.03434177932816089], {
             RGBColor[
             0.6382140736915616, 0.7171699620960075, 0.9646616962176343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.03434177932816089], {
             RGBColor[
             0.7305123993392341, 0.7894011055544591, 0.9737743070057807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.03434177932816089], {
             RGBColor[
             0.29429562032882867`, 0.4266537347586102, 0.9400710722551477]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.03434177932816089], {
             RGBColor[
             0.2460324096232273, 0.37592604024272347`, 0.9373225538044856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.03434177932816089], {
             RGBColor[
             0.1800403201715783, 0.3065641700889047, 0.9335644019367618]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.03434177932816089], {
             RGBColor[
             0.39493077240962093`, 0.5164909180886005, 0.9463856174877392]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.03434177932816089], {
             RGBColor[
             0.26782978190622225`, 0.39883646054537636`, 0.9385638819096797]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.03434177932816089], {
             RGBColor[
             0.29584127485450173`, 0.42827831566524976`, 0.9401590949937939]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.03434177932816089], {
             RGBColor[
             0.9950766756732579, 0.9918778320265724, 0.7055047141489801]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.03434177932816089], {
             RGBColor[
             0.21628848662157388`, 0.34466329129434453`, 0.9356286813917323]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.03434177932816089], {
             RGBColor[
             0.30061798398773654`, 0.43329893982513096`, 0.9404311215124237]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.03434177932816089], {
             RGBColor[
             0.9196256639800194, 0.938748558156751, 0.9921959108615778]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.03434177932816089], {
             RGBColor[
             0.9748675947682047, 0.926884637163092, 0.35686578084130904`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.03434177932816089], {
             RGBColor[
             0.27610729667649436`, 0.4075366533936812, 0.9390352741303609]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.03434177932816089], {
             RGBColor[
             0.5042211596463271, 0.6083884781620977, 0.9541132831917766]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.03434177932816089], {
             RGBColor[
             0.27813245697413447`, 0.40966522526908, 0.9391506040133554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.03434177932816089], {
             RGBColor[
             0.4035464690461924, 0.5239534014776945, 0.9469346020588602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.03434177932816089], {
             RGBColor[
             0.2726124428491967, 0.4038633404346605, 0.9388362473750692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.03434177932816089], {
             RGBColor[
             0.261097249315751, 0.3917601419255701, 0.9381804741385418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.03434177932816089], {
             RGBColor[
             0.5312094509757161, 0.6302987888719648, 0.9562379003465947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.03434177932816089], {
             RGBColor[
             0.8619491220774967, 0.8927588492317026, 0.9866946708064583]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.03434177932816089], {
             RGBColor[
             0.48864650773140994`, 0.5957442741074949, 0.9528871895412045]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.03434177932816089], {
             RGBColor[
             0.40546591079173033`, 0.5256159254437323, 0.9470569071895901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.03434177932816089], {
             RGBColor[
             0.2574804300414378, 0.3879586355486801, 0.9379745016314742]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.03434177932816089], {
             RGBColor[
             0.4228071955400177, 0.5406360746943846, 0.948161878519455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.03434177932816089], {
             RGBColor[
             0.3674883934084197, 0.4927217086918333, 0.9446370133641255]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.03434177932816089], {
             RGBColor[
             0.8501803311271197, 0.38671359097016134`, 0.19568604779889498`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.03434177932816089], {
             RGBColor[
             0.5465902564750337, 0.6427856196737024, 0.9574487336972479]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.03434177932816089], {
             RGBColor[
             0.38532279281260967`, 0.5081689690727651, 0.9457734055238204]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.03434177932816089], {
             RGBColor[
             0.2788168781365947, 0.4103845953056338, 0.9391895807860471]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.03434177932816089], {
             RGBColor[
             0.28507184392659923`, 0.4169589609386654, 0.9395457918343952]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.03434177932816089], {
             RGBColor[
             0.28917033221241484`, 0.4212667319862237, 0.9397791946791023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.03434177932816089], {
             RGBColor[
             0.6566687686170058, 0.7317139000018745, 0.9664142640033524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.03434177932816089], {
             RGBColor[
             0.8341470216086144, 0.26347454816989946`, 0.18033253249694123`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.03434177932816089], {
             RGBColor[
             0.3439204196877902, 0.4723083144158259, 0.943135282918988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.03434177932816089], {
             RGBColor[
             0.9211686584075277, 0.939978900029778, 0.992343083047521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.03434177932816089], {
             RGBColor[
             0.9929459767177286, 0.9913509943397207, 0.7665669512217009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.03434177932816089], {
             RGBColor[
             0.24301438028138522`, 0.37275390005033504`, 0.937150681498242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.03434177932816089], {
             RGBColor[
             0.2522134290242518, 0.3824226835324653, 0.9376745537153752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.03434177932816089], {
             RGBColor[
             0.9594092884334661, 0.9692480942916449, 0.9535936663157671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.03434177932816089], {
             RGBColor[
             0.3044111891973746, 0.4372858390035616, 0.9406471389375684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.03434177932816089], {
             RGBColor[
             0.2215913444714862, 0.35023693111520926`, 0.9359306713014096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.03434177932816089], {
             RGBColor[
             0.3224078413052081, 0.4536752002744616, 0.941764520447276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.03434177932816089], {
             RGBColor[
             0.20347429876271564`, 0.33119476738824843`, 0.9348989323500625]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.03434177932816089], {
             RGBColor[
             0.17892956896395254`, 0.30539670014399584`, 0.9335011462986966]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.03434177932816089], {
             RGBColor[
             0.28222472928714576`, 0.41396646293510553`, 0.9393836528676069]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.03434177932816089], {
             RGBColor[
             0.18991457468017128`, 0.31694263764133146`, 0.9341267261233757]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.03434177932816089], {
             RGBColor[
             0.9946101233350695, 0.9908799237508646, 0.6547233713644478]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.03434177932816089], {
             RGBColor[
             0.6241927467762723, 0.7057868172525964, 0.96355788600105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.03434177932816089], {
             RGBColor[
             0.43622064479054923`, 0.5522541302556329, 0.9490165716446514]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.03434177932816089], {
             RGBColor[
             0.9476938047146304, 0.9605107057164812, 0.973424924364235]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.03434177932816089], {
             RGBColor[
             0.9926251659969516, 0.9866343007146026, 0.4386730148470409]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.03434177932816089], {
             RGBColor[
             0.22593857337368983`, 0.3548061443216573, 0.9361782395562414]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.03434177932816089], {
             RGBColor[
             0.8327720947194103, 0.2529062576026711, 0.17901590095508144`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.03434177932816089], {
             RGBColor[
             0.23926061251081787`, 0.3688084521208458, 0.93693690997691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.03434177932816089], {
             RGBColor[
             0.23590943272644063`, 0.36528614969039486`, 0.9367460652458159]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.03434177932816089], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.03434177932816089], {
             RGBColor[
             0.324831212684851, 0.4557742027613212, 0.9419189355286837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.03434177932816089], {
             RGBColor[
             0.2067120462521808, 0.3345978452847238, 0.9350833172797693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.03434177932816089], {
             RGBColor[
             0.35014705105926486`, 0.47770150955020474`, 0.9435320383639844]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.03434177932816089], {
             RGBColor[
             0.27400077350385804`, 0.40532256397795713`, 0.9389153107520011]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.03434177932816089], {
             RGBColor[
             0.9900957369634822, 0.9901723469535194, 0.8138028001335977]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.03434177932816089], {
             RGBColor[
             0.9929076697798414, 0.9872385477406899, 0.46942180820333496`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.03434177932816089], {
             RGBColor[
             0.8455662065044656, 0.351247407198139, 0.19126755684933291`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.03434177932816089], {
             RGBColor[
             0.7066839033025902, 0.7707861033473555, 0.971399305210804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.03434177932816089], {
             RGBColor[
             0.25547870703592473`, 0.385854697753317, 0.9378605064675941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.03434177932816089], {
             RGBColor[
             0.3280740134091542, 0.4585829537608091, 0.9421255639233401]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.03434177932816089], {
             RGBColor[
             0.8990024464838272, 0.6342755227085348, 0.23743750448057996`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.03434177932816089], {
             RGBColor[
             0.6590237495828186, 0.7335536290308857, 0.9666489864974762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.03434177932816089], {
             RGBColor[
             0.39675004724917656`, 0.5180666825152114, 0.9465015400717941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.03434177932816089], {
             RGBColor[
             0.3157094904678022, 0.4478734254480028, 0.9413377074550355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.03434177932816089], {
             RGBColor[
             0.26920385108875294`, 0.4002806943772341, 0.9386421331168716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.03434177932816089], {
             RGBColor[
             0.23045057360750168`, 0.3595485426447314, 0.9364351912946507]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.03434177932816089], {
             RGBColor[
             0.22619261942112945`, 0.35507316282496604`, 0.9361927071028155]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.03434177932816089], {
             RGBColor[
             0.23881348570074337`, 0.36833849349398035`, 0.9369114467665411]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.03434177932816089], {
             RGBColor[
             0.2939489691399074, 0.4262893823800991, 0.9400513309827632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.03434177932816089], {
             RGBColor[
             0.9620063021321176, 0.9711849428558795, 0.9491975995336027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.03434177932816089], {
             RGBColor[
             0.443273542823118, 0.5583629960424816, 0.9494659760706539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.03434177932816089], {
             RGBColor[
             0.25329610735962166`, 0.38356064710871024`, 0.9377362106448954]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.03434177932816089], {
             RGBColor[
             0.27348165172589245`, 0.40477693407509363`, 0.9388857475347178]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.03434177932816089], {
             RGBColor[
             0.7412000832467709, 0.797750405452433, 0.9748395554555993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.03434177932816089], {
             RGBColor[
             0.21230278460535462`, 0.3404740657671945, 0.9354017015582263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.03434177932816089], {
             RGBColor[
             0.2276990046313701, 0.35665646919126776`, 0.9362784935120415]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.03434177932816089], {
             RGBColor[
             0.34598043724619154`, 0.47409259808542004`, 0.9432665454162072]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.03434177932816089], {
             RGBColor[
             0.40363205630183896`, 0.524027532856795, 0.9469400556031081]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.03434177932816089], {
             RGBColor[
             0.2473937360801429, 0.37735688066202433`, 0.937400079332305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.03434177932816089], {
             RGBColor[
             0.5902199940802382, 0.6782062061588879, 0.9608834264625246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.03434177932816089], {
             RGBColor[
             0.21627103797903324`, 0.3446449516647265, 0.9356276877173526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.03434177932816089], {
             RGBColor[
             0.2845267439871254, 0.4163860263409461, 0.9395147491992453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.03434177932816089], {
             RGBColor[
             0.2413593551772921, 0.3710143637312809, 0.9370564302669542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.03434177932816089], {
             RGBColor[
             0.38392426951059677`, 0.5069576384803866, 0.9456842928556817]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.03434177932816089], {
             RGBColor[
             0.9802603651545728, 0.9450757179590131, 0.3778156754531135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.03434177932816089], {
             RGBColor[
             0.9927232541779302, 0.9868441014154793, 0.4493493080164732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.03434177932816089], {
             RGBColor[
             0.7539264605068086, 0.8076923480920241, 0.9761080018061227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.03434177932816089], {
             RGBColor[
             0.3858730274799788, 0.5086455546860418, 0.9458084659902717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.03434177932816089], {
             RGBColor[
             0.2930250557635406, 0.42531829084204614`, 0.9399987154827865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.03434177932816089], {
             RGBColor[
             0.8218934398484693, 0.16928814920765783`, 0.168598488764985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.03434177932816089], {
             RGBColor[
             0.4183533072547869, 0.5367783405206518, 0.9478780806963388]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.03434177932816089], {
             RGBColor[
             0.26949540103514497`, 0.4005871318562264, 0.9386587364550091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.03434177932816089], {
             RGBColor[
             0.25717362368840185`, 0.38763616261899303`, 0.9379570294635482]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.03434177932816089], {
             RGBColor[
             0.3923234880848031, 0.5142326194523638, 0.9462194836360928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.03434177932816089], {
             RGBColor[
             0.2945111830148827, 0.42688030480911665`, 0.9400833482312222]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.03434177932816089], {
             RGBColor[
             0.1789518783186532, 0.305420148690281, 0.9335024167834431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.03434177932816089], {
             RGBColor[
             0.41920763486506846`, 0.5375183161569235, 0.9479325176962138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.03434177932816089], {
             RGBColor[
             0.27705635157752495`, 0.4085341702682206, 0.9390893214029737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.03434177932816089], {
             RGBColor[
             0.9936465744084931, 0.9916407094893913, 0.7549562343970292]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.03434177932816089], {
             RGBColor[
             0.23402613491596813`, 0.3633066842836104, 0.936638814221599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.03434177932816089], {
             RGBColor[
             0.7138170777657293, 0.7763585934520937, 0.9721102733779844]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.03434177932816089], {
             RGBColor[
             0.3071831062866214, 0.4401992996140543, 0.9408049955151171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.03434177932816089], {
             RGBColor[
             0.25458949129815345`, 0.38492007563338526`, 0.9378098669468048]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.03434177932816089], {
             RGBColor[
             0.23743710807503443`, 0.3668918333419784, 0.9368330640969252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.03434177932816089], {
             RGBColor[
             0.5680702998089695, 0.6602240865171163, 0.9591397213924867]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.03434177932816089], {
             RGBColor[
             0.2299691131158081, 0.3590424971416032, 0.9364077728319058]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.03434177932816089], {
             RGBColor[
             0.3639294956023307, 0.48963917028760373`, 0.9444102435429313]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.03434177932816089], {
             RGBColor[
             0.20571498311483435`, 0.33354986870991854`, 0.9350265360091202]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.03434177932816089], {
             RGBColor[
             0.2318484494359024, 0.3610177987708272, 0.9365147982551062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.03434177932816089], {
             RGBColor[
             0.22813210557574862`, 0.35711168574399543`, 0.9363031579701084]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.03434177932816089], {
             RGBColor[
             0.24388899418338073`, 0.37367317471505657`, 0.9372004894660854]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.03434177932816089], {
             RGBColor[
             0.8649861375675162, 0.47981540863036076`, 0.20905346250477896`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.03434177932816089], {
             RGBColor[
             0.39949775357450523`, 0.5204466076304757, 0.9466766214891428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.03434177932816089], {
             RGBColor[
             0.5158331891976378, 0.6178156468678216, 0.9550274246943216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.03434177932816089], {
             RGBColor[
             0.8191437574953648, 0.1481528857232069, 0.16596538983833015`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.03434177932816089], {
             RGBColor[
             0.2809324202458739, 0.4126081641956031, 0.9393100577795065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.03434177932816089], {
             RGBColor[
             0.2105002400012672, 0.3385794771003698, 0.9352990493096494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.03434177932816089], {
             RGBColor[
             0.4642553566460736, 0.5759424388475844, 0.9509670287800365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.03434177932816089], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.03434177932816089], {
             RGBColor[
             0.8859959599380017, 0.5752161050460523, 0.226584573288584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.03434177932816089], {
             RGBColor[
             0.32111303850258816`, 0.4525537071655133, 0.9416820167576422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.03434177932816089], {
             RGBColor[
             0.22812105044609293`, 0.3571000661017916, 0.9363025283968291]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.03434177932816089], {
             RGBColor[
             0.2595939437592997, 0.3901800724706624, 0.9380948631110431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.03434177932816089], {
             RGBColor[
             0.23088271225706164`, 0.36000274776459185`, 0.9364598009514513]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.03434177932816089], {
             RGBColor[
             0.5294468131435418, 0.6288678000738763, 0.9560991390396908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.03434177932816089], {
             RGBColor[
             0.23667377020378227`, 0.366089516840876, 0.9367895931344146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.03434177932816089], {
             RGBColor[
             0.7455882739599426, 0.8011784933890475, 0.9752769292959146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.03434177932816089], {
             RGBColor[
             0.28595975701387044`, 0.41789221389032877`, 0.9395963571711656]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.03434177932816089], {
             RGBColor[
             0.2651563206276758, 0.3960264832343887, 0.938411632244898]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.03434177932816089], {
             RGBColor[
             0.37855708825470646`, 0.5023088558389079, 0.9453423008120684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.03434177932816089], {
             RGBColor[
             0.24235927283690456`, 0.3720653405899749, 0.9371133740984234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.03434177932816089], {
             RGBColor[
             0.21172080019279638`, 0.3398623632496528, 0.9353685584068999]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.03434177932816089], {
             RGBColor[
             0.42787872382047937`, 0.5450287775884974, 0.9484850318169096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.03434177932816089], {
             RGBColor[
             0.21288213693655111`, 0.34108300180034146`, 0.9354346948164131]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.03434177932816089], {
             RGBColor[
             0.9951032288756773, 0.9922430735458843, 0.7308157001748675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.03434177932816089], {
             RGBColor[
             0.2588379470720171, 0.38938547201937, 0.9380518102180992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.03434177932816089], {
             RGBColor[
             0.80703569950506, 0.8491816892426243, 0.9814014344154122]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.03434177932816089], {
             RGBColor[
             0.2560427236071457, 0.38644751493038626`, 0.9378926263769374]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.03434177932816089], {
             RGBColor[
             0.27423499655804673`, 0.4055687472585089, 0.9389286494084351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.03434177932816089], {
             RGBColor[
             0.25719173910326026`, 0.38765520306859286`, 0.937958061109625]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.03434177932816089], {
             RGBColor[
             0.29461336050310216`, 0.4269876998276622, 0.9400891670880182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.03434177932816089], {
             RGBColor[
             0.43613267935432526`, 0.5521779390160471, 0.94901096656484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.03434177932816089], {
             RGBColor[
             0.8873547734207121, 0.5813861597120881, 0.22771840056612383`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.03434177932816089], {
             RGBColor[
             0.9695247134417432, 0.9088618438807439, 0.33610969580648287`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.03434177932816089], {
             RGBColor[
             0.9609628542707439, 0.8799806824768295, 0.3028484896985869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.03434177932816089], {
             RGBColor[
             0.178927010221482, 0.30539401074342565`, 0.9335010005820983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.03434177932816089], {
             RGBColor[
             0.25976518882652405`, 0.3903600618938796, 0.9381046152642871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.03434177932816089], {
             RGBColor[
             0.8163432429187892, 0.8564528128973794, 0.9823291233589543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.03434177932816089], {
             RGBColor[
             0.34638875058307517`, 0.4744462585754037, 0.9432925627809762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.03434177932816089], {
             RGBColor[
             0.24935218422087857`, 0.37941533383072157`, 0.9375116100566555]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.03434177932816089], {
             RGBColor[
             0.44511934956958094`, 0.5599617410733233, 0.9495835892443556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.03434177932816089], {
             RGBColor[
             0.9940965401504851, 0.9897814212502639, 0.5988230111904562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.03434177932816089], {
             RGBColor[
             0.9940884990666902, 0.9897642221851048, 0.5979477888431959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.03434177932816089], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.03434177932816089], {
             RGBColor[
             0.24203916924704705`, 0.37172889142129484`, 0.937095144672532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.03434177932816089], {
             RGBColor[
             0.6232106502631707, 0.7049895070603167, 0.9634805717660004]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.03434177932816089], {
             RGBColor[
             0.638779311088947, 0.7176288472788594, 0.9647061937760893]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.03434177932816089], {
             RGBColor[
             0.2785145923880161, 0.4100668738178543, 0.9391723660598572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.03434177932816089], {
             RGBColor[
             0.4111342730563943, 0.530525575937213, 0.9474180902207585]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.03434177932816089], {
             RGBColor[
             0.9949335587465892, 0.9915717193917691, 0.6899273198963884]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.03434177932816089], {
             RGBColor[
             0.2790754121939759, 0.4106563309919474, 0.9392043039181481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.03434177932816089], {
             RGBColor[
             0.24043240470913427`, 0.3700400800171928, 0.9370036418090929]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.03434177932816089], {
             RGBColor[
             0.21816661637866602`, 0.3466373247493527, 0.9357356381029547]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.03434177932816089], {
             RGBColor[
             0.24251120685435607`, 0.3722250328754895, 0.9371220265159511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.03434177932816089], {
             RGBColor[
             0.4244026220080174, 0.5420179529125, 0.9482635376832157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.03434177932816089], {
             RGBColor[
             0.5988679170367666, 0.6852269795994871, 0.961564222636048]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.03434177932816089], {
             RGBColor[
             0.5790882470358998, 0.6691689524288044, 0.9600070945582612]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.03434177932816089], {
             RGBColor[
             0.20835094833068457`, 0.3363204352816248, 0.9351766503286018]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.03434177932816089], {
             RGBColor[
             0.8185799679311427, 0.1438193520784336, 0.16542550431492184`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.03434177932816089], {
             RGBColor[
             0.22258326386374316`, 0.3512795012877932, 0.9359871596433854]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.03434177932816089], {
             RGBColor[
             0.2867137638335649, 0.4186847228646212, 0.9396392967440941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.03434177932816089], {
             RGBColor[
             0.30053129972337833`, 0.4332078291671907, 0.9404261849718064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.03434177932816089], {
             RGBColor[
             0.29672537087035056`, 0.42920755663283183`, 0.9402094429539937]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.03434177932816089], {
             RGBColor[
             0.8913219113450659, 0.5994000064779764, 0.23102867769365362`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.03434177932816089], {
             RGBColor[
             0.9589543367125869, 0.8732054811308165, 0.29504577826186157`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.03434177932816089], {
             RGBColor[
             0.9952479751456992, 0.992244224277091, 0.7241496045864151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.03434177932816089], {
             RGBColor[
             0.39130532114623406`, 0.5133507344247334, 0.9461546069390968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.03434177932816089], {
             RGBColor[
             0.9617670348256762, 0.9710064976904998, 0.9496026166724999]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.03434177932816089], {
             RGBColor[
             0.46426084954242974`, 0.5759468982282985, 0.9509674612009588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.03434177932816089], {
             RGBColor[
             0.8491537797280463, 0.8825561905625664, 0.9854742396306309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.03434177932816089], {
             RGBColor[
             0.4006413843936947, 0.5214371631655013, 0.9467494926336685]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.03434177932816089], {
             RGBColor[
             0.9939797374120591, 0.9895315920033393, 0.5861097539357399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.03434177932816089], {
             RGBColor[
             0.26098356523640104`, 0.3916406527501864, 0.9381739999984032]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.03434177932816089], {
             RGBColor[
             0.2946613034028385, 0.4270380908550406, 0.940091897365233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.03434177932816089], {
             RGBColor[
             0.22246582468563886`, 0.3511560652655316, 0.9359804716559281]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.03434177932816089], {
             RGBColor[
             0.24763395401992835`, 0.3776093649474359, 0.9374137593886052]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.03434177932816089], {
             RGBColor[
             0.467847246129772, 0.578858496543228, 0.9512497954777179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.03434177932816089], {
             RGBColor[
             0.2625163578880115, 0.3932517150116962, 0.938261290272349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.03434177932816089], {
             RGBColor[
             0.2270252964366493, 0.35594835916304945`, 0.9362401268270142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.03434177932816089], {
             RGBColor[
             0.22825539451058077`, 0.357241270231474, 0.9363101790925575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.03434177932816089], {
             RGBColor[
             0.9774649456708626, 0.9356461116447503, 0.3669559986295733]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.03434177932816089], {
             RGBColor[
             0.22328031209840418`, 0.35201214317783264`, 0.936026855509159]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.03434177932816089], {
             RGBColor[
             0.6178350891255162, 0.7006253843624993, 0.9630573879019151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.03434177932816089], {
             RGBColor[
             0.9645754531953188, 0.8921668269279859, 0.3168827543384975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.03434177932816089], {
             RGBColor[
             0.21277857456934213`, 0.34097415118617147`, 0.9354287970928072]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.03434177932816089], {
             RGBColor[
             0.23178154572615212`, 0.3609474787299394, 0.9365109881878111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.03434177932816089], {
             RGBColor[
             0.34909505354151776`, 0.4767903221752649, 0.9434650060123984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.03434177932816089], {
             RGBColor[
             0.6029315110482949, 0.6885259882808699, 0.9618841236420709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.03434177932816089], {
             RGBColor[
             0.25879261498995565`, 0.3893378251269034, 0.9380492286230886]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.03434177932816089], {
             RGBColor[
             0.2680583595238526, 0.3990767101141639, 0.9385768990668534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.03434177932816089], {
             RGBColor[
             0.8360763947567734, 0.2783045556433535, 0.18218010240253352`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.03434177932816089], {
             RGBColor[
             0.9636570397640628, 0.9724160602789496, 0.9464033313040466]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.03434177932816089], {
             RGBColor[
             0.6187231293682252, 0.7013463354372874, 0.9631272976828197]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.03434177932816089], {
             RGBColor[
             0.25564421936180226`, 0.3860286617019018, 0.9378699321496993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.03434177932816089], {
             RGBColor[
             0.382771346863294, 0.50595903483087, 0.945610829644085]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.03434177932816089], {
             RGBColor[
             0.5590358689967736, 0.6528895285873056, 0.9584284979047402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.03434177932816089], {
             RGBColor[
             0.9409750107809423, 0.8036926171977683, 0.27136531206102255`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.03434177932816089], {
             RGBColor[
             0.8619011142240809, 0.46580703815332913`, 0.20647924340617463`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.03434177932816089], {
             RGBColor[
             0.2909832679823188, 0.4231722424271597, 0.9398824386892002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.03434177932816089], {
             RGBColor[
             0.6129287179190951, 0.6966421711876226, 0.9626711403879157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.03434177932816089], {
             RGBColor[
             0.8179080138731872, 0.1386544187368418, 0.16478204035016009`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.03434177932816089], {
             RGBColor[
             0.24306150835744214`, 0.3728034346463635, 0.9371533653724538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.03434177932816089], {
             RGBColor[
             0.20926131084396443`, 0.33727728400339907`, 0.9352284941269724]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.03434177932816089], {
             RGBColor[
             0.209897553009386, 0.33794601485934034`, 0.9352647271770572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.03434177932816089], {
             RGBColor[
             0.8372847792405768, 0.8730921717492939, 0.9843421637685542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.03434177932816089], {
             RGBColor[
             0.6962355794932261, 0.7626237933772783, 0.9703579139386239]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.03434177932816089], {
             RGBColor[
             0.7603990286995737, 0.8127487675575523, 0.9767531269139887]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.03434177932816089], {
             RGBColor[
             0.28525208052382683`, 0.41714840103001194`, 0.9395560560419711]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.03434177932816089], {
             RGBColor[
             0.9944845479757449, 0.9919872330943883, 0.7410688437815899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.03434177932816089], {
             RGBColor[
             0.2558608387541249, 0.3862563424176957, 0.9378822683036323]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{{3.8349502435193233`*^9, 3.8349502581408367`*^9}, 
   3.834950528174912*^9, 3.8349578088972807`*^9, 3.835018923470682*^9, 
   3.835019026079196*^9, 3.8350205603927774`*^9, 3.835044649527498*^9, 
   3.835045037805329*^9, 3.8350454195109205`*^9},
 CellLabel->
  "Out[302]=",ExpressionUUID->"c88d001b-50cb-4cfe-924c-1b2cfd3fe79d"]
}, Open  ]],

Cell["r = 3 :", "Text",
 CellChangeTimes->{{3.834793779215767*^9, 3.8347938725231647`*^9}, {
  3.8347953347101345`*^9, 3.8347953431477337`*^9}, {3.8348851911359825`*^9, 
  3.83488519180678*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"3c7c8ddb-37cd-4a5c-a829-31cd8949965f"],

Cell["Cubic Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.834795179278664*^9}},ExpressionUUID->"feede5ba-18df-4d32-a93c-\
90cc71fd9359"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c\[Rho]3if3", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"CMDi3f300", ",", "krif3"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.834947911760502*^9, 
   3.834947914304406*^9}, {3.834947957535968*^9, 3.8349479704802837`*^9}, {
   3.8349480487781425`*^9, 3.834948105065866*^9}, {3.8349497992119355`*^9, 
   3.83494980454772*^9}, {3.8349578354451995`*^9, 3.83495784069214*^9}, {
   3.835018838991932*^9, 3.8350188405169106`*^9}, {3.8350443590646524`*^9, 
   3.8350443609005165`*^9}, {3.835044949683157*^9, 3.8350449510226583`*^9}, {
   3.835045289916173*^9, 3.835045290700967*^9}},
 CellLabel->
  "In[303]:=",ExpressionUUID->"7a48aefa-4ea7-4be6-a2f9-1ca3541d7893"],

Cell[BoxData[
 RowBox[{"-", "0.012337874754716607`"}]], "Output",
 CellChangeTimes->{3.835045420057926*^9},
 CellLabel->
  "Out[303]=",ExpressionUUID->"f84c09d4-f2a1-4e56-86b8-58b64dd53d71"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CP3if3", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"CMDi3f300", ",", "krif3"}], "}"}], "]"}], ",", "c\[Rho]3if3"}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.8349481210775223`*^9, 3.834948150679065*^9}, {
  3.8349481924167476`*^9, 3.8349481986802473`*^9}, {3.834949807949147*^9, 
  3.834949815491851*^9}, {3.8349578438231587`*^9, 3.8349578533989754`*^9}, {
  3.835018846742407*^9, 3.835018849961266*^9}, {3.835044361707146*^9, 
  3.835044363446494*^9}, {3.835044955607832*^9, 3.835044963462711*^9}, {
  3.835045291150058*^9, 3.83504529239456*^9}},
 CellLabel->
  "In[304]:=",ExpressionUUID->"bec5ba1b-1582-4e1e-8884-56017445ca14"],

Cell[BoxData["0.403106653318984`"], "Output",
 CellChangeTimes->{3.835045420088925*^9},
 CellLabel->
  "Out[304]=",ExpressionUUID->"cbde283f-24fd-4976-b594-c8a468b3b470"]
}, Open  ]],

Cell["Absolute Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.8347951985065947`*^9}},ExpressionUUID->"001e26e5-3f71-450d-9060-\
6d6966e8a326"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a\[Rho]3if3", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"AMDi3f300", ",", "krif3"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.8348873709111376`*^9, 
   3.8348873755217657`*^9}, {3.8349481641806583`*^9, 
   3.8349481824982553`*^9}, {3.834949818653184*^9, 3.8349498238056817`*^9}, {
   3.834957866337153*^9, 3.834957872254816*^9}, {3.8350188531986103`*^9, 
   3.8350188546829796`*^9}, {3.8350443646261296`*^9, 3.835044365855239*^9}, {
   3.8350449644881577`*^9, 3.8350449665516605`*^9}, {3.8350452953539734`*^9, 
   3.835045296241315*^9}},
 CellLabel->
  "In[316]:=",ExpressionUUID->"de53270d-ca1b-48b1-a1d8-44e998010a66"],

Cell[BoxData[
 RowBox[{"-", "0.05051886983298341`"}]], "Output",
 CellChangeTimes->{{3.835045420120922*^9, 3.8350454351967278`*^9}},
 CellLabel->
  "Out[316]=",ExpressionUUID->"d48c0c20-8732-4deb-beb1-a7bf11501aff"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"aP3if3", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"AMDi3f300", ",", "krif3"}], "}"}], "]"}], ",", "a\[Rho]3if3"}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8349482041094093`*^9, 
  3.8349482202691827`*^9}, {3.8349498269490285`*^9, 3.8349498405604887`*^9}, {
  3.8349578796796703`*^9, 3.834957886620027*^9}, {3.8350188593392305`*^9, 
  3.835018861313801*^9}, {3.8350443665470304`*^9, 3.835044368736087*^9}, {
  3.835044972843706*^9, 3.835044975243416*^9}, {3.8350452972403584`*^9, 
  3.8350452983946238`*^9}},
 CellLabel->
  "In[317]:=",ExpressionUUID->"b42f852d-9f41-4d91-afe7-e5fd89976480"],

Cell[BoxData["0.26750334147269667`"], "Output",
 CellChangeTimes->{{3.835045420151927*^9, 3.8350454365219784`*^9}},
 CellLabel->
  "Out[317]=",ExpressionUUID->"a5f8cc94-06c8-4a7e-91b2-a34eb95b4555"]
}, Open  ]],

Cell["Max-min Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 3.8347951985065947`*^9}, {
  3.8348543263190746`*^9, 
  3.834854330052075*^9}},ExpressionUUID->"7d5d6436-17dd-4962-b56e-\
5493a271d6a6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mM\[Rho]3if3", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"mMDi3f300", ",", "krif3"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8348874651734295`*^9, 3.8348874872060013`*^9}, {
  3.8349482319487157`*^9, 3.834948245258479*^9}, {3.834949844516972*^9, 
  3.8349498489188633`*^9}, {3.834957895209076*^9, 3.834957899999796*^9}, {
  3.83501886583329*^9, 3.835018866821826*^9}, {3.835044369483486*^9, 
  3.835044370515362*^9}, {3.8350449764211473`*^9, 3.835044978468176*^9}, {
  3.83504530068464*^9, 3.8350453016969304`*^9}},
 CellLabel->
  "In[307]:=",ExpressionUUID->"b88baa71-3cca-4447-98fb-0caea92f78f8"],

Cell[BoxData["0.009313510093258188`"], "Output",
 CellChangeTimes->{3.8350454201819253`*^9},
 CellLabel->
  "Out[307]=",ExpressionUUID->"73c06800-e265-42cd-98c0-a523e354f529"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mMP3if3", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"mMDi3f300", ",", "krif3"}], "}"}], "]"}], ",", 
    "mM\[Rho]3if3"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8348875260806427`*^9, 
  3.8348875488478312`*^9}, {3.8349482525846663`*^9, 3.8349482707073736`*^9}, {
  3.8349498532537427`*^9, 3.834949860995207*^9}, {3.834957902898573*^9, 
  3.8349579090270967`*^9}, {3.8350188699780455`*^9, 3.835018871634328*^9}, {
  3.835044378315168*^9, 3.8350443808084726`*^9}, {3.8350449818572917`*^9, 
  3.835044984227113*^9}, {3.835045303707653*^9, 3.835045305160867*^9}},
 CellLabel->
  "In[308]:=",ExpressionUUID->"05cdcac9-9a65-4901-8252-107fe25d4edd"],

Cell[BoxData["0.3440792084225885`"], "Output",
 CellChangeTimes->{3.835045420214927*^9},
 CellLabel->
  "Out[308]=",ExpressionUUID->"d7b060e6-53ca-4c6e-a333-a504086541f9"]
}, Open  ]],

Cell["r = 6 :", "Text",
 CellChangeTimes->{{3.834793779215767*^9, 3.8347938725231647`*^9}, {
  3.8347953347101345`*^9, 3.8347953431477337`*^9}, {3.8348851911359825`*^9, 
  3.83488519180678*^9}, {3.834948305866973*^9, 3.8349483068980722`*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"2fd1598a-a323-4bf5-890a-c146bf0916be"],

Cell["Cubic Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.834795179278664*^9}},ExpressionUUID->"f2e329f0-a822-407d-8854-\
f40cf282ea36"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c\[Rho]6if3", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"CMDi6f300", ",", "krif3"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.834947911760502*^9, 
   3.834947914304406*^9}, {3.834947957535968*^9, 3.8349479704802837`*^9}, {
   3.8349480487781425`*^9, 3.834948105065866*^9}, {3.8349483158342133`*^9, 
   3.8349483193845987`*^9}, {3.834949864783629*^9, 3.834949869574106*^9}, {
   3.834957963470776*^9, 3.834957967378231*^9}, {3.835018875109179*^9, 
   3.8350188762029247`*^9}, {3.83504438203627*^9, 3.8350443836235657`*^9}, {
   3.8350449852346697`*^9, 3.8350449865535607`*^9}, {3.835045305833229*^9, 
   3.8350453066738987`*^9}},
 CellLabel->
  "In[309]:=",ExpressionUUID->"7fa5a6a6-a381-434c-a149-aef232283536"],

Cell[BoxData[
 RowBox[{"-", "0.012954928888790684`"}]], "Output",
 CellChangeTimes->{3.8350454202469263`*^9},
 CellLabel->
  "Out[309]=",ExpressionUUID->"75d38084-9276-47e3-be31-1c355027cafb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CP6if3", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"CMDi6f300", ",", "krif3"}], "}"}], "]"}], ",", "c\[Rho]6if3"}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.8349481210775223`*^9, 3.834948150679065*^9}, {
  3.8349481924167476`*^9, 3.8349481986802473`*^9}, {3.8349483230197706`*^9, 
  3.834948338654296*^9}, {3.8349498724373255`*^9, 3.8349498802583637`*^9}, {
  3.8349579696959915`*^9, 3.834957975592292*^9}, {3.8350188769841766`*^9, 
  3.835018878671647*^9}, {3.835044384544117*^9, 3.8350443867509155`*^9}, {
  3.8350449903821464`*^9, 3.83504499270442*^9}, {3.8350453079175425`*^9, 
  3.835045309140333*^9}},
 CellLabel->
  "In[310]:=",ExpressionUUID->"02a5414b-19ba-4376-a656-85af6eadd63a"],

Cell[BoxData["0.798550491256895`"], "Output",
 CellChangeTimes->{3.8350454202779236`*^9},
 CellLabel->
  "Out[310]=",ExpressionUUID->"0d59a7e4-2c87-440a-ba1f-e14724e0bb07"]
}, Open  ]],

Cell["Absolute Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.8347951985065947`*^9}},ExpressionUUID->"fcef3faf-6078-4a1f-9a22-\
22b88b9d99c4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a\[Rho]6if3", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"AMDi6f300", ",", "krif3"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.8348873709111376`*^9, 
   3.8348873755217657`*^9}, {3.8349481641806583`*^9, 
   3.8349481824982553`*^9}, {3.834948329127375*^9, 3.834948332212267*^9}, {
   3.834949883458797*^9, 3.8349498875077024`*^9}, {3.834957978394422*^9, 
   3.8349579827581863`*^9}, {3.8350188795779624`*^9, 3.83501888042175*^9}, {
   3.8350443900912123`*^9, 3.835044391591655*^9}, {3.8350449954828196`*^9, 
   3.835044996992873*^9}, {3.8350453095650387`*^9, 3.8350453101209903`*^9}},
 CellLabel->
  "In[311]:=",ExpressionUUID->"c90c08b5-2733-4b15-82ec-9299bedbd6ce"],

Cell[BoxData[
 RowBox[{"-", "0.036182633609915554`"}]], "Output",
 CellChangeTimes->{3.8350454203069253`*^9},
 CellLabel->
  "Out[311]=",ExpressionUUID->"a84c7970-0d10-46e4-9081-1a5256e961fb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"aP6if3", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"AMDi6f300", ",", "krif3"}], "}"}], "]"}], ",", "a\[Rho]6if3"}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8349482041094093`*^9, 
  3.8349482202691827`*^9}, {3.834948340881687*^9, 3.834948354997751*^9}, {
  3.8349498907390194`*^9, 3.8349498979971194`*^9}, {3.8349579853563895`*^9, 
  3.8349579919125147`*^9}, {3.8350188832810483`*^9, 3.83501888448921*^9}, {
  3.835044392264258*^9, 3.835044393785404*^9}, {3.835044997778226*^9, 
  3.835044999929602*^9}, {3.835045310857601*^9, 3.8350453114746556`*^9}},
 CellLabel->
  "In[312]:=",ExpressionUUID->"24d332b9-6cfb-4524-99c2-1053da95ac63"],

Cell[BoxData["0.7252348660710883`"], "Output",
 CellChangeTimes->{3.8350454203399253`*^9},
 CellLabel->
  "Out[312]=",ExpressionUUID->"95da2fe4-a330-40b4-b4d2-f8c3468ace04"]
}, Open  ]],

Cell["Max-min Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 3.8347951985065947`*^9}, {
  3.8348543263190746`*^9, 
  3.834854330052075*^9}},ExpressionUUID->"8a8e2b29-ae19-47a5-8325-\
81e1227bdaf6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mM\[Rho]6if3", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"mMDi6f300", ",", "krif3"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8348874651734295`*^9, 3.8348874872060013`*^9}, {
   3.8349482319487157`*^9, 3.834948245258479*^9}, 3.8349483527075925`*^9, {
   3.8349499042423377`*^9, 3.8349499090679235`*^9}, {3.834949978751977*^9, 
   3.8349499794842105`*^9}, {3.834957994342047*^9, 3.834957998175455*^9}, {
   3.835018886286111*^9, 3.8350188870361056`*^9}, {3.835044395189496*^9, 
   3.835044396222158*^9}, {3.8350450026406775`*^9, 3.8350450038650913`*^9}, {
   3.835045313176186*^9, 3.835045313923186*^9}},
 CellLabel->
  "In[313]:=",ExpressionUUID->"f2ca6b21-67d2-4826-849e-1188b80131f2"],

Cell[BoxData[
 RowBox[{"-", "0.031885961371897004`"}]], "Output",
 CellChangeTimes->{3.835045420370926*^9},
 CellLabel->
  "Out[313]=",ExpressionUUID->"06336cd6-c14d-4998-8869-598740b9d5ec"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mMP6if3", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"mMDi6f300", ",", "krif3"}], "}"}], "]"}], ",", 
    "mM\[Rho]6if3"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8348875260806427`*^9, 
  3.8348875488478312`*^9}, {3.8349482525846663`*^9, 3.8349482707073736`*^9}, {
  3.83494834565068*^9, 3.8349483504716325`*^9}, {3.8349499122654495`*^9, 
  3.83494991854418*^9}, {3.834958000997678*^9, 3.8349580074869604`*^9}, {
  3.8350188877705455`*^9, 3.8350189082569094`*^9}, {3.8350443974385123`*^9, 
  3.8350443985852137`*^9}, {3.8350450046283274`*^9, 3.835045006371921*^9}, {
  3.8350453144561853`*^9, 3.835045331274891*^9}},
 CellLabel->
  "In[314]:=",ExpressionUUID->"8eb9c716-c50c-40a9-991b-e7e7ad8b4114"],

Cell[BoxData["0.34815715430653227`"], "Output",
 CellChangeTimes->{3.8350454204009285`*^9},
 CellLabel->
  "Out[314]=",ExpressionUUID->"aa38ac65-86e3-494e-ad51-febee2470858"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4th imported file", "Subsubsection",
 CellChangeTimes->{{3.834947473073307*^9, 3.8349474798089457`*^9}, {
   3.8349497159535103`*^9, 3.8349497173354855`*^9}, {3.834956622993673*^9, 
   3.834956623710862*^9}, {3.8350187834860272`*^9, 3.835018783813758*^9}, {
   3.835044179773861*^9, 3.8350441837622757`*^9}, {3.8350447472475395`*^9, 
   3.8350447488425937`*^9}, {3.8350455598331027`*^9, 3.835045564155232*^9}, 
   3.835201709435259*^9},
 Background->RGBColor[
  1, 1, 0],ExpressionUUID->"114d7fd3-fd5e-4ff7-856a-d43e52796c84"],

Cell["Dividing stuff", "Text",
 CellChangeTimes->{{3.83494752022309*^9, 
  3.834947523245259*^9}},ExpressionUUID->"a888e8e8-018c-4a79-96d3-\
c8174daf9465"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dataf4", "=", 
   RowBox[{"StringSplit", "[", 
    RowBox[{
     RowBox[{"Import", "[", "\"\<ariadnaComputationf4.txt\>\"", "]"}], ",", 
     "\"\<]\n{\>\""}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8349434033501863`*^9, 3.834943479535334*^9}, {
   3.834943567297134*^9, 3.8349435736474867`*^9}, {3.8349441109152327`*^9, 
   3.8349441401892223`*^9}, 3.834944204627252*^9, {3.834949720382628*^9, 
   3.8349497230261507`*^9}, {3.834956627593688*^9, 3.834956631231691*^9}, {
   3.8350187858989725`*^9, 3.8350187908769827`*^9}, {3.835044188339929*^9, 
   3.835044192375786*^9}, {3.835044770661966*^9, 3.8350447715129805`*^9}, {
   3.8350455738505306`*^9, 3.835045575197592*^9}},
 CellLabel->
  "In[319]:=",ExpressionUUID->"5db6ca12-1026-4523-9b36-8f9a8d13b937"],

Cell[BoxData[
 RowBox[{
  RowBox[{"graphif4", "=", 
   RowBox[{"ToExpression", "@", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
      "dataf4", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "<>", 
      "\"\<]\>\""}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834944474381714*^9, 3.83494454689666*^9}, 
   3.8349475108233376`*^9, {3.834949726505718*^9, 3.8349497324197383`*^9}, {
   3.8349566345564103`*^9, 3.834956636582815*^9}, {3.8350188037132354`*^9, 
   3.8350188065525265`*^9}, {3.835044199446479*^9, 3.8350442063533845`*^9}, {
   3.8350447722871337`*^9, 3.835044772707575*^9}, {3.835045575945426*^9, 
   3.8350455767503777`*^9}},
 CellLabel->
  "In[320]:=",ExpressionUUID->"19275f9c-42ad-4738-9ccb-049a720cb7af"],

Cell[BoxData[
 RowBox[{
  RowBox[{"otherif4", "=", 
   RowBox[{"ToExpression", "@", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "<>", "\"\<}}\>\""}], "&"}], ",", 
      RowBox[{"StringSplit", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\"\<{\>\"", "<>", 
          RowBox[{
          "dataf4", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
         ")"}], ",", "\"\<}}\>\""}], "]"}]}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834944518155362*^9, 3.8349445533517303`*^9}, 
   3.8349446259294133`*^9, {3.8349447635371876`*^9, 3.8349447780382657`*^9}, {
   3.834944820013957*^9, 3.8349448816359477`*^9}, {3.834944915595456*^9, 
   3.834944918286141*^9}, {3.8349449615053425`*^9, 3.834944967406804*^9}, {
   3.834945029266304*^9, 3.834945031628281*^9}, {3.834945108799203*^9, 
   3.8349451822852197`*^9}, 3.834945584171259*^9, {3.834949734758335*^9, 
   3.8349497379503355`*^9}, {3.834956638769047*^9, 3.8349566423540664`*^9}, {
   3.8350188094708586`*^9, 3.8350188125204616`*^9}, {3.8350442096862793`*^9, 
   3.835044210497281*^9}, 3.8350442469097853`*^9, {3.835044779420373*^9, 
   3.835044781545072*^9}, {3.8350455774187374`*^9, 3.8350455783186817`*^9}},
 CellLabel->
  "In[321]:=",ExpressionUUID->"ce738fb6-4f56-4ea0-8280-d7f349ea4c02"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "CMDi3f400", "}"}], ",", 
     RowBox[{"{", "AMDi3f400", "}"}], ",", 
     RowBox[{"{", "mMDi3f400", "}"}], ",", 
     RowBox[{"{", "CMDi6f400", "}"}], ",", 
     RowBox[{"{", "AMDi6f400", "}"}], ",", 
     RowBox[{"{", "mMDi6f400", "}"}]}], "}"}], "=", "otherif4"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.834945694541313*^9, 3.834945753140644*^9}, {
  3.8349459487260857`*^9, 3.8349459670133495`*^9}, {3.8349471029719105`*^9, 
  3.8349471182020655`*^9}, {3.83494974203613*^9, 3.8349497544188104`*^9}, {
  3.834956647753375*^9, 3.8349566844693546`*^9}, {3.8350188134722548`*^9, 
  3.835018816812196*^9}, {3.835044228572632*^9, 3.835044233700058*^9}, {
  3.8350447829709044`*^9, 3.835044786739727*^9}, {3.8350455804482784`*^9, 
  3.835045582889475*^9}},
 CellLabel->
  "In[322]:=",ExpressionUUID->"88298bea-6872-4804-93e3-857215cb835d"],

Cell["\[OpenCurlyDoubleQuote]Cleaning\[CloseCurlyDoubleQuote] the graph:", \
"Text",
 CellChangeTimes->{{3.8349477786156034`*^9, 
  3.8349478283202667`*^9}},ExpressionUUID->"8a0b0f10-cf73-49c6-961e-\
1cc1af3b15bc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"graphinf4", "=", 
   RowBox[{"IndexGraph", "@", "graphif4"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834946654863307*^9, 3.834946693639777*^9}, {
  3.834949757637121*^9, 3.834949759707878*^9}, {3.8349566892836237`*^9, 
  3.834956691608691*^9}, {3.83501881773997*^9, 3.8350188182388163`*^9}, {
  3.8350442520120163`*^9, 3.8350442531771507`*^9}, {3.835044787881835*^9, 
  3.8350447894788456`*^9}, {3.835045583706751*^9, 3.835045584330986*^9}},
 CellLabel->
  "In[323]:=",ExpressionUUID->"ca8cb445-24fb-4e93-8eb0-b50180356b8a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pointsif4", "=", 
   RowBox[{"VertexList", "@", "graphinf4"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834784420352569*^9, 3.8347844264642625`*^9}, {
  3.8348756828269844`*^9, 3.8348756865131674`*^9}, {3.834878831782991*^9, 
  3.8348788488376627`*^9}, {3.8349467020325813`*^9, 3.834946739879963*^9}, {
  3.8349497621629615`*^9, 3.8349497641865125`*^9}, {3.834956695197647*^9, 
  3.834956697830969*^9}, {3.835018818796376*^9, 3.8350188192932053`*^9}, {
  3.835044292816033*^9, 3.8350442934580317`*^9}, {3.835044790599271*^9, 
  3.835044791093337*^9}, {3.8350455847893662`*^9, 3.8350455852439384`*^9}},
 CellLabel->
  "In[324]:=",ExpressionUUID->"995ad1dc-2414-4186-97a1-2520641747e1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"coordpointsif4", "=", 
   RowBox[{"VertexList", "@", "graphif4"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834879134322084*^9, 3.834879146224797*^9}, {
  3.834946724882841*^9, 3.834946736706849*^9}, {3.834949767417904*^9, 
  3.8349497706963253`*^9}, {3.8349567000470257`*^9, 3.8349567019660654`*^9}, {
  3.835018819834511*^9, 3.835018820572505*^9}, {3.835044294376539*^9, 
  3.8350442977248926`*^9}, {3.835044791824248*^9, 3.8350447923863506`*^9}, {
  3.8350455858029118`*^9, 3.8350455862985897`*^9}},
 CellLabel->
  "In[325]:=",ExpressionUUID->"251b0aab-3cdc-447f-bac8-b00ec0a64fca"],

Cell["Kretchmann \[OpenCurlyDoubleQuote]real\[CloseCurlyDoubleQuote] \
values:", "Text",
 CellChangeTimes->{
  3.8347933561184683`*^9, {3.8347935444076195`*^9, 
   3.834793546974228*^9}},ExpressionUUID->"b1b0d1b5-6876-4ab9-b0de-\
438b9c3846c7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rvalif4", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1"}], "+", "r"}]]}], "\[Equal]", "#"}], ",", 
       RowBox[{"{", "r", "}"}]}], "]"}], "&"}], "/@", 
    RowBox[{"coordpointsif4", "\[LeftDoubleBracket]", 
     RowBox[{";;", ",", "3"}], "\[RightDoubleBracket]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834105426841242*^9, 3.8341054487325706`*^9}, {
   3.8341407674337025`*^9, 3.834140799285215*^9}, {3.8341408938375945`*^9, 
   3.834140946496229*^9}, {3.8341410168099756`*^9, 3.8341410671886864`*^9}, {
   3.8341411610986195`*^9, 3.834141210381962*^9}, {3.834141332672348*^9, 
   3.834141336755044*^9}, {3.834141461053176*^9, 3.834141468978607*^9}, {
   3.834141967115094*^9, 3.8341420256686225`*^9}, {3.8341640069512*^9, 
   3.834164012603241*^9}, {3.834164792400744*^9, 3.8341647947633886`*^9}, {
   3.83466546628111*^9, 3.834665483801684*^9}, {3.8347933895124626`*^9, 
   3.834793417249506*^9}, 3.8347960586942053`*^9, 3.834879156483405*^9, {
   3.8348862453609915`*^9, 3.8348862641404076`*^9}, 3.834886374221485*^9, {
   3.834946768449996*^9, 3.8349467823353415`*^9}, {3.8349468446168528`*^9, 
   3.834946857637892*^9}, 3.8349474594107084`*^9, {3.834949773350379*^9, 
   3.8349497766098785`*^9}, {3.8349567056279964`*^9, 
   3.8349567091770997`*^9}, {3.8350188215027976`*^9, 3.835018822410869*^9}, {
   3.835044298874358*^9, 3.8350443004592457`*^9}, 3.8350444868602533`*^9, {
   3.835044793477209*^9, 3.8350448005204644`*^9}, {3.835045587457754*^9, 
   3.8350455910161066`*^9}},
 CellLabel->
  "In[326]:=",ExpressionUUID->"2304350e-9807-4d85-8077-329c813db2ea"],

Cell[BoxData[
 RowBox[{
  RowBox[{"krif4", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"KHFlamm", "/.", "rvalif4"}], ")"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834792366597866*^9, 3.834792376019791*^9}, {
   3.834793346399704*^9, 3.8347933590872536`*^9}, {3.834793445378667*^9, 
   3.8347934527754736`*^9}, {3.834793487784485*^9, 3.834793489659489*^9}, 
   3.8348550102643666`*^9, {3.8348863808528233`*^9, 3.83488645374378*^9}, {
   3.834886485165092*^9, 3.834886521271514*^9}, 3.8348865820814276`*^9, {
   3.83494679091998*^9, 3.8349467979310513`*^9}, {3.8349468742957215`*^9, 
   3.834946904080855*^9}, 3.8349474644429636`*^9, {3.834949779141443*^9, 
   3.834949781745859*^9}, {3.8349567110647635`*^9, 3.8349567138998594`*^9}, {
   3.8350188233356256`*^9, 3.8350188239955263`*^9}, {3.8350443047283278`*^9, 
   3.8350443056932993`*^9}, {3.835044525959175*^9, 3.835044526610751*^9}, {
   3.8350448048490252`*^9, 3.835044806579857*^9}, {3.8350455920142765`*^9, 
   3.835045592997998*^9}},
 CellLabel->
  "In[327]:=",ExpressionUUID->"7a8cf8a0-28be-4658-83c8-aa934dfb0672"],

Cell["Estimated with cubic Mean Deviation v Calculated: (r=3)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 
  3.8349503319477153`*^9}},ExpressionUUID->"aacd7fb4-7216-4f65-af8d-\
50a1dd7c0102"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraphb", "[", 
     RowBox[{"graphinf4", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsif4", ",", "#"}], "}"}], "]"}], ",", "500", ",", "3"}],
      "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"CMDi3f400", ",", "krif4"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349567344957485`*^9, 3.834956749729442*^9}, {
   3.8349587420893497`*^9, 3.834958755264699*^9}, {3.835018825281867*^9, 
   3.835018828052806*^9}, {3.835044306768691*^9, 3.8350443152608557`*^9}, {
   3.8350445713666224`*^9, 3.835044576386869*^9}, {3.8350448259670086`*^9, 
   3.8350448323754845`*^9}, {3.835045595956773*^9, 3.835045598251114*^9}, 
   3.8350457514276457`*^9, 3.8350458103509226`*^9, {3.83505205253205*^9, 
   3.8350520556646357`*^9}},
 Background->RGBColor[1, 1, 0.85],
 CellLabel->
  "In[415]:=",ExpressionUUID->"5e421fc3-5b16-4f9a-8412-1e4dc51f87f4"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN2wucz2W+wPHn16rdrWxoc2ntsSnFoptQYTEuNY3rMEhyNxmZGTMj4zII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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[105, 155] -> 
             RGBColor[
              0.9914219683516854, 0.990553574100701, 0.7796697761761131], 
             UndirectedEdge[1, 203] -> 
             RGBColor[
              0.5681492662591182, 0.6395579840424156, 0.9624488693479908], 
             UndirectedEdge[187, 193] -> 
             RGBColor[
              0.6284366040664211, 0.7034809979866246, 0.9670651914842516], 
             UndirectedEdge[209, 371] -> 
             RGBColor[
              0.5743535923132054, 0.6572676100925557, 0.962937590261526], 
             UndirectedEdge[23, 245] -> 
             RGBColor[
              0.4445813468358175, 0.5524985584308048, 0.9508256312934031], 
             UndirectedEdge[201, 236] -> 
             RGBColor[
              0.6905520163429424, 0.7567406107159694, 0.9708709424203719], 
             UndirectedEdge[258, 369] -> 
             RGBColor[
              0.8372495979970664, 0.8736648795045987, 0.9813594213440029], 
             UndirectedEdge[161, 312] -> 
             RGBColor[
              0.8022621163265784, 0.8457521768889009, 0.9808461311272553], 
             UndirectedEdge[74, 132] -> 
             RGBColor[
              0.5832501586286303, 0.6585021625174985, 0.9646738005757265], 
             UndirectedEdge[89, 169] -> 
             RGBColor[
              0.4329635941246126, 0.5492537594667746, 0.9488585700825309], 
             UndirectedEdge[124, 137] -> 
             RGBColor[
              0.6859383599460923, 0.7528078196064429, 0.9707232218259894], 
             UndirectedEdge[186, 393] -> 
             RGBColor[
              0.5518729231696745, 0.6317151981771052, 0.9619487923693422], 
             UndirectedEdge[84, 261] -> 
             RGBColor[
              0.4110405121542, 0.5300389316597283, 0.9475241382868101], 
             UndirectedEdge[58, 243] -> 
             RGBColor[
              0.30535706136050167`, 0.43105115303434016`, 0.9409656888455661],
              UndirectedEdge[205, 250] -> 
             RGBColor[
              0.5932630539730043, 0.6797769347346972, 0.961738161209945], 
             UndirectedEdge[327, 337] -> 
             RGBColor[
              0.36242758359981964`, 0.4819526626409805, 0.94470861610523], 
             UndirectedEdge[38, 224] -> 
             RGBColor[
              0.6441228657434601, 0.7218286049865765, 0.965221469602823], 
             UndirectedEdge[49, 301] -> 
             RGBColor[
              0.4740284838592157, 0.571943513633066, 0.9540642321503823], 
             UndirectedEdge[22, 97] -> 
             RGBColor[
              0.44424774628344615`, 0.5588378693623259, 0.9496299886724715], 
             UndirectedEdge[163, 169] -> 
             RGBColor[
              0.6260613685316944, 0.7050084434648488, 0.9652743717601738], 
             UndirectedEdge[126, 318] -> 
             RGBColor[
              0.4371531084567508, 0.5487618253517016, 0.9500320530752355], 
             UndirectedEdge[126, 149] -> 
             RGBColor[
              0.7499511104588834, 0.8044103907639903, 0.9761836421538276], 
             UndirectedEdge[28, 47] -> 
             RGBColor[
              0.6140999059946637, 0.6808830288365936, 0.9251043284610685], 
             UndirectedEdge[203, 392] -> 
             RGBColor[
              0.5453871541321326, 0.6214606571876746, 0.9621002081157097], 
             UndirectedEdge[116, 387] -> 
             RGBColor[
              0.27949192024468317`, 0.4110941073613764, 0.9392280234354674], 
             UndirectedEdge[114, 203] -> 
             RGBColor[
              0.5269378045857942, 0.6067496466536769, 0.9603404926860512], 
             UndirectedEdge[38, 207] -> 
             RGBColor[
              0.5600820357813578, 0.6537388539123077, 0.9585108559862578], 
             UndirectedEdge[4, 73] -> 
             RGBColor[
              0.6165378247103154, 0.6955995206246621, 0.9651908134662917], 
             UndirectedEdge[143, 223] -> 
             RGBColor[
              0.5562351087893764, 0.6454806057269553, 0.9604484492526557], 
             UndirectedEdge[70, 164] -> 
             RGBColor[
              0.7945307601988778, 0.840056435672901, 0.9674500024374728], 
             UndirectedEdge[291, 331] -> 
             RGBColor[
              0.5004703928737121, 0.6013361874442893, 0.9551360802736617], 
             UndirectedEdge[317, 381] -> 
             RGBColor[
              0.7792392145469608, 0.8243622511914672, 0.8462358841897273], 
             UndirectedEdge[120, 349] -> 
             RGBColor[
              0.6771564244144472, 0.7475138382564043, 0.9685965607633271], 
             UndirectedEdge[102, 160] -> 
             RGBColor[
              0.49082214559682924`, 0.5838065943705634, 0.9559369510798653], 
             UndirectedEdge[84, 381] -> 
             RGBColor[
              0.4586898724694406, 0.5687228289428605, 0.951275270476184], 
             UndirectedEdge[110, 203] -> 
             RGBColor[
              0.31240314452792023`, 0.43482229533982575`, 0.9415000384161312],
              UndirectedEdge[316, 355] -> 
             RGBColor[
              0.7186764435755708, 0.7794610718035494, 0.9732141588336016], 
             UndirectedEdge[62, 77] -> 
             RGBColor[
              0.37181821762115086`, 0.49647198480160837`, 0.9449129059342476],
              UndirectedEdge[188, 361] -> 
             RGBColor[
              0.6989887257535399, 0.7219079304782234, 0.6342592105218108], 
             UndirectedEdge[168, 282] -> 
             RGBColor[
              0.3326237742544784, 0.4567287941717509, 0.9426276515731876], 
             UndirectedEdge[271, 394] -> 
             RGBColor[
              0.6509180845710292, 0.7271580210088221, 0.9658844371089488], 
             UndirectedEdge[160, 224] -> 
             RGBColor[
              0.696647747518929, 0.7629457821715504, 0.9703989949954968], 
             UndirectedEdge[97, 168] -> 
             RGBColor[
              0.33382940010248263`, 0.45777304668477503`, 0.9427044729861294],
              UndirectedEdge[88, 132] -> 
             RGBColor[
              0.6552476548025516, 0.7260567686937631, 0.9690712398146526], 
             UndirectedEdge[329, 353] -> 
             RGBColor[
              0.3306109842267364, 0.4555592000679707, 0.9424783893495172], 
             UndirectedEdge[189, 339] -> 
             RGBColor[
              0.5671677196308924, 0.6514201305919971, 0.9622700199418004], 
             UndirectedEdge[316, 380] -> 
             RGBColor[
              0.7232824979445462, 0.7832004742406684, 0.9735767643060604], 
             UndirectedEdge[156, 295] -> 
             RGBColor[
              0.5454194257341849, 0.6418350865329576, 0.957356561612434], 
             UndirectedEdge[154, 228] -> 
             RGBColor[
              0.3144027521544478, 0.4449070086042116, 0.94132161641812], 
             UndirectedEdge[29, 91] -> 
             RGBColor[
              0.5697111256068084, 0.6547371880351953, 0.9623173354401187], 
             UndirectedEdge[6, 198] -> 
             RGBColor[
              0.6904371948077299, 0.7563064834905191, 0.9712542843259669], 
             UndirectedEdge[56, 254] -> 
             RGBColor[
              0.7300450590064502, 0.7885952347022249, 0.9742189314737963], 
             UndirectedEdge[245, 315] -> 
             RGBColor[
              0.4467764872008, 0.5548057901343392, 0.9509506412897697], 
             UndirectedEdge[174, 281] -> 
             RGBColor[
              0.47729050878360135`, 0.5853280667122176, 0.9523239095999885], 
             UndirectedEdge[89, 329] -> 
             RGBColor[
              0.40747686835411234`, 0.5273577158106015, 0.9471850436272451], 
             UndirectedEdge[260, 267] -> 
             RGBColor[
              0.4872205818230427, 0.5899135242030824, 0.95416573498813], 
             UndirectedEdge[202, 363] -> 
             RGBColor[
              0.7326219779918828, 0.7902175711044143, 0.9738808219361663], 
             UndirectedEdge[43, 238] -> 
             RGBColor[
              0.6282720687670866, 0.7060968867268224, 0.9657913316578237], 
             UndirectedEdge[276, 377] -> 
             RGBColor[
              0.7667940665085519, 0.7674114764849629, 0.6244273853207714], 
             UndirectedEdge[284, 369] -> 
             RGBColor[
              0.7256847561089013, 0.7856297139714756, 0.9732931326454721], 
             UndirectedEdge[53, 249] -> 
             RGBColor[
              0.6311873853308925, 0.6963320364793647, 0.8629917947030269], 
             UndirectedEdge[15, 105] -> 
             RGBColor[
              0.800137676557607, 0.8427573669804738, 0.9076106529878243], 
             UndirectedEdge[97, 112] -> 
             RGBColor[
              0.6809628128875526, 0.7473023934547947, 0.9669823456373661], 
             UndirectedEdge[120, 246] -> 
             RGBColor[
              0.7142969028221718, 0.7767334364329921, 0.9721580978553904], 
             UndirectedEdge[53, 308] -> 
             RGBColor[
              0.7509734132369263, 0.8020585676130425, 0.8709226949645765], 
             UndirectedEdge[188, 392] -> 
             RGBColor[
              0.9287605075066439, 0.9057640220127086, 0.6546546999031781], 
             UndirectedEdge[91, 273] -> 
             RGBColor[
              0.45386906879099576`, 0.5634951752910823, 0.9512421694158917], 
             UndirectedEdge[327, 354] -> 
             RGBColor[
              0.3073657707973515, 0.4349295234766839, 0.9410153800747716], 
             UndirectedEdge[51, 376] -> 
             RGBColor[
              0.7383910911875181, 0.7955559995066144, 0.9745595813786563], 
             UndirectedEdge[202, 214] -> 
             RGBColor[
              0.706433945888759, 0.7689569468856965, 0.971819204119086], 
             UndirectedEdge[69, 132] -> 
             RGBColor[
              0.624891162511616, 0.6997635008330207, 0.9671369509690663], 
             UndirectedEdge[130, 387] -> 
             RGBColor[
              0.4681883983247673, 0.5699556167163752, 0.9530745781747385], 
             UndirectedEdge[61, 306] -> 
             RGBColor[
              0.39587166483801906`, 0.5097806639166862, 0.9472798693065702], 
             UndirectedEdge[312, 356] -> 
             RGBColor[
              0.645903605472637, 0.721802546048524, 0.9663678951435759], 
             UndirectedEdge[18, 247] -> 
             RGBColor[
              0.3914548842218762, 0.5134802784435959, 0.9461641369660233], 
             UndirectedEdge[56, 320] -> 
             RGBColor[
              0.8631426486011866, 0.8937105348842784, 0.9868085104317617], 
             UndirectedEdge[43, 124] -> 
             RGBColor[
              0.6569875205412729, 0.7289606384433103, 0.9685390393988128], 
             UndirectedEdge[259, 318] -> 
             RGBColor[
              0.36630486596619394`, 0.490728565448351, 0.9445970444084638], 
             UndirectedEdge[267, 384] -> 
             RGBColor[
              0.25914348630019535`, 0.3897066131204912, 0.9380692102251391], 
             UndirectedEdge[44, 324] -> 
             RGBColor[
              0.757315134777288, 0.8074934950791708, 0.8833959294172117], 
             UndirectedEdge[62, 204] -> 
             RGBColor[
              0.33839705058122904`, 0.46752424970832585`, 0.9427833387236414],
              UndirectedEdge[42, 109] -> 
             RGBColor[
              0.4961322178132587, 0.6007638786096222, 0.953768718979616], 
             UndirectedEdge[8, 21] -> 
             RGBColor[
              0.7358995517283213, 0.3108431606080988, 0.42932286014931975`], 
             UndirectedEdge[48, 349] -> 
             RGBColor[
              0.4675795259571827, 0.5744104063629669, 0.9523411262275032], 
             UndirectedEdge[222, 332] -> 
             RGBColor[
              0.6862589101054142, 0.7545632738496608, 0.9695458562170984], 
             UndirectedEdge[58, 167] -> 
             RGBColor[
              0.5878312597204502, 0.6580862728836865, 0.9511965126553145], 
             UndirectedEdge[76, 144] -> 
             RGBColor[
              0.7420397154661247, 0.7939770790511607, 0.8309653152893506], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.3529620592030486, 0.48013972811792704`, 0.9437114081936924], 
             UndirectedEdge[6, 166] -> 
             RGBColor[
              0.594762988389229, 0.6730612686154169, 0.9649570097202043], 
             UndirectedEdge[79, 343] -> 
             RGBColor[
              0.42428517775792585`, 0.5402096509986418, 0.9487275867171132], 
             UndirectedEdge[142, 257] -> 
             RGBColor[
              0.7459297873490013, 0.8010499797721338, 0.9756936623773169], 
             UndirectedEdge[175, 256] -> 
             RGBColor[
              0.4574297337173456, 0.566403606223784, 0.9515208647680704], 
             UndirectedEdge[8, 171] -> 
             RGBColor[
              0.7241839604289806, 0.7838428760809513, 0.9737506814577559], 
             UndirectedEdge[31, 214] -> 
             RGBColor[
              0.36980838352241846`, 0.4899430333582985, 0.9451077615763981], 
             UndirectedEdge[41, 114] -> 
             RGBColor[
              0.8423870328914074, 0.8771605703134804, 0.984828821276606], 
             UndirectedEdge[72, 399] -> 
             RGBColor[
              0.6310870566817235, 0.7102218942726441, 0.9648951205605258], 
             UndirectedEdge[278, 392] -> 
             RGBColor[
              0.7735251219955066, 0.8235867725552333, 0.977906490347674], 
             UndirectedEdge[6, 323] -> 
             RGBColor[
              0.8682402745579291, 0.5891936213829003, 0.46352327011156513`], 
             UndirectedEdge[132, 323] -> 
             RGBColor[
              0.8747006179012536, 0.5943449238035189, 0.46413946342686796`], 
             UndirectedEdge[200, 355] -> 
             RGBColor[
              0.5674512010865496, 0.6597214742841762, 0.9590909836732244], 
             UndirectedEdge[98, 215] -> 
             RGBColor[
              0.28215133383499913`, 0.40706249391714455`, 0.9396294366377143],
              UndirectedEdge[12, 367] -> 
             RGBColor[
              0.6606555865516766, 0.7302848650600569, 0.9696257421447607], 
             UndirectedEdge[88, 140] -> 
             RGBColor[
              0.5057899388327537, 0.60812106583946, 0.9546625710839367], 
             UndirectedEdge[195, 327] -> 
             RGBColor[
              0.3804057150848329, 0.49654811968610807`, 0.9461239204717958], 
             UndirectedEdge[142, 381] -> 
             RGBColor[
              0.5597010517070127, 0.6534295538776173, 0.9584808635243347], 
             UndirectedEdge[313, 359] -> 
             RGBColor[
              0.22134243076747473`, 0.3499753070302528, 0.935916496034201], 
             UndirectedEdge[64, 82] -> 
             RGBColor[
              0.6009433964428095, 0.6851668128139775, 0.9628900004955714], 
             UndirectedEdge[98, 297] -> 
             RGBColor[
              0.663262732732075, 0.7317544896111948, 0.9626877563547387], 
             UndirectedEdge[139, 305] -> 
             RGBColor[
              0.3248591148671768, 0.45060333071161207`, 0.9421109292763392], 
             UndirectedEdge[288, 375] -> 
             RGBColor[
              0.6182124820687912, 0.6975649225973971, 0.9650736748529836], 
             UndirectedEdge[136, 194] -> 
             RGBColor[
              0.863424685538389, 0.8921904298188723, 0.8925512422733333], 
             UndirectedEdge[254, 349] -> 
             RGBColor[
              0.6064632792766806, 0.6913932368330189, 0.9621621573743027], 
             UndirectedEdge[348, 351] -> 
             RGBColor[
              0.5144438745789837, 0.6109880779381577, 0.9569095723018982], 
             UndirectedEdge[65, 282] -> 
             RGBColor[
              0.7025183692089757, 0.7629566089539355, 0.9159818097589658], 
             UndirectedEdge[131, 215] -> 
             RGBColor[
              0.28071406449126907`, 0.40581760345086326`, 0.9395378551060591],
              UndirectedEdge[230, 250] -> 
             RGBColor[
              0.6201350428387049, 0.7015928258651759, 0.9638536226087916], 
             UndirectedEdge[26, 111] -> 
             RGBColor[
              0.5645418395367089, 0.6526147463501281, 0.9610034514689749], 
             UndirectedEdge[301, 390] -> 
             RGBColor[
              0.7942708621763097, 0.8397718687138309, 0.9799799727794423], 
             UndirectedEdge[3, 309] -> 
             RGBColor[
              0.42141938946058805`, 0.5370386767358399, 0.9486978419587173], 
             UndirectedEdge[90, 268] -> 
             RGBColor[
              0.6658778629181163, 0.7318700271773412, 0.9314828604822887], 
             UndirectedEdge[17, 187] -> 
             RGBColor[
              0.3204213483884867, 0.449213446496704, 0.9417383099311541], 
             UndirectedEdge[4, 206] -> 
             RGBColor[
              0.4513750414195363, 0.5642674746061942, 0.9502896200244795], 
             UndirectedEdge[19, 231] -> 
             RGBColor[
              0.6299208789836888, 0.7008512492821077, 0.9451456040608204], 
             UndirectedEdge[76, 138] -> 
             RGBColor[
              0.647977891731887, 0.7225748043944371, 0.9671545526419876], 
             UndirectedEdge[28, 390] -> 
             RGBColor[
              0.5671603673135337, 0.6446851953937099, 0.9632887268687529], 
             UndirectedEdge[123, 174] -> 
             RGBColor[
              0.7013686615215994, 0.7586940578357109, 0.740599544172098], 
             UndirectedEdge[2, 98] -> 
             RGBColor[
              0.6030506674097312, 0.6839555741434731, 0.9643139526666902], 
             UndirectedEdge[20, 364] -> 
             RGBColor[
              0.25029442546800623`, 0.38040568912299827`, 0.9375652693017584],
              UndirectedEdge[56, 196] -> 
             RGBColor[
              0.785848940850358, 0.8330842304778556, 0.9791693122457652], 
             UndirectedEdge[360, 374] -> 
             RGBColor[
              0.6861359356655947, 0.7176659730278627, 0.6439421478168035], 
             UndirectedEdge[39, 360] -> 
             RGBColor[
              0.4801163549545537, 0.5874112403631535, 0.9526046637415588], 
             UndirectedEdge[261, 264] -> 
             RGBColor[
              0.4831871948034481, 0.5913121579333308, 0.9524574124293932], 
             UndirectedEdge[101, 253] -> 
             RGBColor[
              0.36751092956074977`, 0.49157850271436526`, 0.9446810224299861],
              UndirectedEdge[141, 273] -> 
             RGBColor[
              0.794778716230354, 0.8379965966050114, 0.890043943491297], 
             UndirectedEdge[171, 182] -> 
             RGBColor[
              0.6277296423647784, 0.7035502875367632, 0.9667063554299866], 
             UndirectedEdge[156, 175] -> 
             RGBColor[
              0.5374826780422429, 0.6353916772102302, 0.9567317517608596], 
             UndirectedEdge[121, 250] -> 
             RGBColor[
              0.7701786074159738, 0.8205444653409251, 0.9776865150002947], 
             UndirectedEdge[68, 308] -> 
             RGBColor[
              0.39124442394032644`, 0.5083768951950799, 0.9467014263777693], 
             UndirectedEdge[39, 390] -> 
             RGBColor[
              0.7241510445066783, 0.7837131889365324, 0.9738666004650648], 
             UndirectedEdge[54, 181] -> 
             RGBColor[
              0.8581938722653898, 0.8896043893897054, 0.9620693660724258], 
             UndirectedEdge[196, 313] -> 
             RGBColor[
              0.4796634342070468, 0.5783298379227618, 0.9543117341391647], 
             UndirectedEdge[200, 241] -> 
             RGBColor[
              0.7428269125268313, 0.7986173387637592, 0.9756335115864574], 
             UndirectedEdge[186, 255] -> 
             RGBColor[
              0.3974160766070578, 0.5093677145964082, 0.9475531710464491], 
             UndirectedEdge[11, 38] -> 
             RGBColor[
              0.4721726794779267, 0.5782946268660459, 0.9526885804946463], 
             UndirectedEdge[173, 310] -> 
             RGBColor[
              0.365967464527182, 0.4914043565390135, 0.9445401011207177], 
             UndirectedEdge[106, 173] -> 
             RGBColor[
              0.44298415636980804`, 0.5553605652936879, 0.9502078612887241], 
             UndirectedEdge[51, 396] -> 
             RGBColor[
              0.7339447495227696, 0.7920824836046647, 0.9741164115949394], 
             UndirectedEdge[6, 18] -> 
             RGBColor[
              0.6299426833902961, 0.704805357736919, 0.9671520104873859], 
             UndirectedEdge[238, 287] -> 
             RGBColor[
              0.8348882481324911, 0.8712144129638846, 0.9841047781758756], 
             UndirectedEdge[93, 225] -> 
             RGBColor[
              0.8007316500363519, 0.8439606988437603, 0.9376327288719387], 
             UndirectedEdge[116, 276] -> 
             RGBColor[
              0.4335110952188029, 0.5449171139226505, 0.9498261681862341], 
             UndirectedEdge[135, 276] -> 
             RGBColor[
              0.7830200214526783, 0.8284394288074424, 0.8886613535521181], 
             UndirectedEdge[147, 172] -> 
             RGBColor[
              0.2390919061370471, 0.3686311310254108, 0.9369273023985025], 
             UndirectedEdge[185, 224] -> 
             RGBColor[
              0.5253071833894488, 0.6238998464157539, 0.9562737073525366], 
             UndirectedEdge[160, 166] -> 
             RGBColor[
              0.5184391254904871, 0.612833791256457, 0.9575096972291486], 
             UndirectedEdge[63, 156] -> 
             RGBColor[
              0.3880496133708574, 0.5100424766434235, 0.9460622137034923], 
             UndirectedEdge[247, 302] -> 
             RGBColor[
              0.34469795288522265`, 0.4695677798942129, 0.9433098297165163], 
             UndirectedEdge[81, 240] -> 
             RGBColor[
              0.414951483786949, 0.5200440670685171, 0.9492576468425226], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.7764276211405543, 0.8256665154954856, 0.9742596527716847], 
             UndirectedEdge[12, 212] -> 
             RGBColor[
              0.4781679549958182, 0.5856299376232896, 0.9525064020757575], 
             UndirectedEdge[18, 74] -> 
             RGBColor[
              0.308951540008609, 0.43682603473492587`, 0.9410972743799868], 
             UndirectedEdge[1, 7] -> 
             RGBColor[
              0.6576418870840319, 0.7272593336078772, 0.9677782516110388], 
             UndirectedEdge[231, 331] -> 
             RGBColor[
              0.3115500848675711, 0.4433053834739665, 0.9411080208757203], 
             UndirectedEdge[58, 351] -> 
             RGBColor[
              0.4741209374322735, 0.5686061143750868, 0.9546132406838328], 
             UndirectedEdge[142, 279] -> 
             RGBColor[
              0.6361872071712591, 0.7143883959177965, 0.965278867451098], 
             UndirectedEdge[303, 344] -> 
             RGBColor[
              0.6136271643626432, 0.6936834580876978, 0.9647433648161599], 
             UndirectedEdge[302, 323] -> 
             RGBColor[
              0.6606635845968037, 0.4172858395822151, 0.44651890779670356`], 
             UndirectedEdge[144, 366] -> 
             RGBColor[
              0.7478388256758346, 0.7986850579663409, 0.8314218424878996], 
             UndirectedEdge[56, 342] -> 
             RGBColor[
              0.847791191236561, 0.8814739872580964, 0.9853431368810213], 
             UndirectedEdge[137, 293] -> 
             RGBColor[
              0.6784243836546143, 0.7468163788730714, 0.9700065320595024], 
             UndirectedEdge[39, 374] -> 
             RGBColor[
              0.7647851147631233, 0.782924791165464, 0.6497447002228691], 
             UndirectedEdge[4, 278] -> 
             RGBColor[
              0.531645902232067, 0.6292438267537239, 0.956739525722475], 
             UndirectedEdge[238, 396] -> 
             RGBColor[
              0.7475587717538584, 0.8027178612419924, 0.9754733301006633], 
             UndirectedEdge[118, 293] -> 
             RGBColor[
              0.8508378109561248, 0.5387141967695308, 0.4572822351924833], 
             UndirectedEdge[201, 228] -> 
             RGBColor[
              0.59367025290552, 0.6750081237524055, 0.9640949320535159], 
             UndirectedEdge[212, 336] -> 
             RGBColor[
              0.6540652595150536, 0.728452335088739, 0.966994144676754], 
             UndirectedEdge[186, 200] -> 
             RGBColor[
              0.39956452024335987`, 0.511111917926641, 0.9477223043995071], 
             UndirectedEdge[7, 356] -> 
             RGBColor[
              0.46094319068273526`, 0.5711960973114487, 0.9512747420601121], 
             UndirectedEdge[215, 269] -> 
             RGBColor[
              0.3201502229412343, 0.4398322984075235, 0.942090182404471], 
             UndirectedEdge[36, 122] -> 
             RGBColor[
              0.48536334873940745`, 0.5900019038017579, 0.9534788987777827], 
             UndirectedEdge[297, 352] -> 
             RGBColor[
              0.8324601481632794, 0.8698328129690808, 0.9763003549577338], 
             UndirectedEdge[228, 243] -> 
             RGBColor[
              0.3634172118144061, 0.4891954558186354, 0.9443776012729596], 
             UndirectedEdge[100, 271] -> 
             RGBColor[
              0.6918723021427347, 0.7591517670394202, 0.9699663707775735], 
             UndirectedEdge[157, 298] -> 
             RGBColor[
              0.5480348844046323, 0.6439584337066971, 0.9575624600997124], 
             UndirectedEdge[272, 384] -> 
             RGBColor[
              0.5082808865626348, 0.5937608081413112, 0.9582604153008594], 
             UndirectedEdge[35, 114] -> 
             RGBColor[
              0.5757422765045646, 0.6580462410225472, 0.9631198351620791], 
             UndirectedEdge[15, 155] -> 
             RGBColor[
              0.8038038908731594, 0.8441062372029327, 0.8346980562424668], 
             UndirectedEdge[36, 262] -> 
             RGBColor[
              0.3993982147148157, 0.5202115353154393, 0.9467114085267051], 
             UndirectedEdge[111, 185] -> 
             RGBColor[
              0.37643569654302217`, 0.5004714129624948, 0.9452071276080729], 
             UndirectedEdge[26, 400] -> 
             RGBColor[
              0.5414631401176022, 0.6325092016828566, 0.9595371421052621], 
             UndirectedEdge[61, 131] -> 
             RGBColor[
              0.3161389707217317, 0.4430514259678613, 0.9415552511094316], 
             UndirectedEdge[168, 350] -> 
             RGBColor[
              0.2135277250804749, 0.34176155587225787`, 0.9354714601061475], 
             UndirectedEdge[16, 208] -> 
             RGBColor[
              0.42565088481033464`, 0.540994181603919, 0.9489246808941683], 
             UndirectedEdge[125, 303] -> 
             RGBColor[
              0.5970441322835273, 0.6793200691881947, 0.963686708675878], 
             UndirectedEdge[145, 164] -> 
             RGBColor[
              0.7076323379345049, 0.769508381749372, 0.9606090403174121], 
             UndirectedEdge[152, 256] -> 
             RGBColor[
              0.37160675840554536`, 0.49623316197054357`, 0.9449014701993993],
              UndirectedEdge[237, 246] -> 
             RGBColor[
              0.5196803921011843, 0.6168239146600012, 0.9568472858259717], 
             UndirectedEdge[16, 284] -> 
             RGBColor[
              0.5180797024804324, 0.6149085772305488, 0.9569691470715032], 
             UndirectedEdge[240, 309] -> 
             RGBColor[
              0.46404333757096783`, 0.5716427179988263, 0.952053355290633], 
             UndirectedEdge[151, 249] -> 
             RGBColor[
              0.5564432291769413, 0.6394240573811418, 0.9617689500899813], 
             UndirectedEdge[47, 311] -> 
             RGBColor[
              0.9224014252034067, 0.9397313942486343, 0.9497991319345045], 
             UndirectedEdge[29, 190] -> 
             RGBColor[
              0.7046623656340105, 0.768311891352174, 0.9718484041357076], 
             UndirectedEdge[99, 384] -> 
             RGBColor[
              0.232169471942209, 0.36135521377895785`, 0.93653308001193], 
             UndirectedEdge[5, 398] -> 
             RGBColor[
              0.39472086425706343`, 0.5161298289909952, 0.9464217771520889], 
             UndirectedEdge[36, 157] -> 
             RGBColor[
              0.4687375362172823, 0.576504320211978, 0.952170053913683], 
             UndirectedEdge[40, 55] -> 
             RGBColor[
              0.6476038477124906, 0.7164696154280739, 0.936559346812813], 
             UndirectedEdge[163, 319] -> 
             RGBColor[
              0.6126116765013878, 0.6935382734355247, 0.9643678344508821], 
             UndirectedEdge[13, 74] -> 
             RGBColor[
              0.27645484805753096`, 0.40790195193118095`, 0.9390550666673547],
              UndirectedEdge[47, 158] -> 
             RGBColor[
              0.7168027638404271, 0.7757527896198493, 0.9314319339526896], 
             UndirectedEdge[252, 330] -> 
             RGBColor[
              0.6481031573484914, 0.7202064357083122, 0.9684604578906895], 
             UndirectedEdge[102, 185] -> 
             RGBColor[
              0.31948158146734906`, 0.4447606586147669, 0.9418116634369051], 
             UndirectedEdge[41, 356] -> 
             RGBColor[
              0.6868997981634348, 0.7539056714057906, 0.9704336883876189], 
             UndirectedEdge[33, 175] -> 
             RGBColor[
              0.62307213299537, 0.7048770525021844, 0.9634696671792737], 
             UndirectedEdge[12, 126] -> 
             RGBColor[
              0.4850749535124754, 0.591237350175849, 0.9530501463001579], 
             UndirectedEdge[18, 191] -> 
             RGBColor[
              0.6434392761816612, 0.7155671744735017, 0.968439327556377], 
             UndirectedEdge[64, 171] -> 
             RGBColor[
              0.6629218519857836, 0.7340320106985918, 0.968948771907788], 
             UndirectedEdge[73, 184] -> 
             RGBColor[
              0.7531277605279747, 0.8071058764266377, 0.976018449127813], 
             UndirectedEdge[93, 316] -> 
             RGBColor[
              0.7402807597379569, 0.7970004289275263, 0.9749149297411224], 
             UndirectedEdge[20, 362] -> 
             RGBColor[
              0.3708573465948838, 0.48845241702413456`, 0.9454035424791327], 
             UndirectedEdge[32, 330] -> 
             RGBColor[
              0.9171600476284912, 0.9367825426054153, 0.9919607381728873], 
             UndirectedEdge[124, 277] -> 
             RGBColor[
              0.7240230968753725, 0.7837267247434794, 0.9737213918260504], 
             UndirectedEdge[267, 331] -> 
             RGBColor[
              0.31532491229101, 0.4472729664338829, 0.9413229917131285], 
             UndirectedEdge[134, 167] -> 
             RGBColor[
              0.7628701219081004, 0.8142786706157044, 0.9629665408369976], 
             UndirectedEdge[143, 398] -> 
             RGBColor[
              0.6169624490701591, 0.6979002984271483, 0.9643674765024848], 
             UndirectedEdge[109, 320] -> 
             RGBColor[
              0.7140273193582052, 0.7757792512469499, 0.9727416417821142], 
             UndirectedEdge[28, 147] -> 
             RGBColor[
              0.2280825606179811, 0.35705961085205007`, 0.9363003364580589], 
             UndirectedEdge[54, 311] -> 
             RGBColor[
              0.9120349131152357, 0.9320000665068819, 0.9673469328804061], 
             UndirectedEdge[160, 289] -> 
             RGBColor[
              0.5518238426760897, 0.6430231608124118, 0.9595903235971655], 
             UndirectedEdge[209, 240] -> 
             RGBColor[
              0.4598958883252, 0.5672834858780541, 0.9518171641916879], 
             UndirectedEdge[31, 261] -> 
             RGBColor[
              0.36593429051296633`, 0.486797870127324, 0.9448027787834237], 
             UndirectedEdge[245, 248] -> 
             RGBColor[
              0.5836735018584862, 0.6728914688571559, 0.960368062614237], 
             UndirectedEdge[81, 245] -> 
             RGBColor[
              0.4094685154728096, 0.5155927463861911, 0.9488260074920588], 
             UndirectedEdge[308, 386] -> 
             RGBColor[
              0.5345074334451243, 0.6329762396130476, 0.9564975296074943], 
             UndirectedEdge[320, 349] -> 
             RGBColor[
              0.739560868871417, 0.7965085370150724, 0.974751736332268], 
             UndirectedEdge[222, 356] -> 
             RGBColor[
              0.584645439996236, 0.6736805320226953, 0.9604445771447674], 
             UndirectedEdge[200, 374] -> 
             RGBColor[
              0.7656501951437512, 0.7836271023898848, 0.649812802519326], 
             UndirectedEdge[73, 348] -> 
             RGBColor[
              0.5645243292817197, 0.6501487886059114, 0.9618911782695141], 
             UndirectedEdge[23, 81] -> 
             RGBColor[
              0.24398524125963283`, 0.37377433649461467`, 0.9372059705946931],
              UndirectedEdge[25, 233] -> 
             RGBColor[
              0.7761664143568067, 0.8251117980917346, 0.9783126170960326], 
             UndirectedEdge[168, 170] -> 
             RGBColor[
              0.4644450238685994, 0.5640543545254171, 0.9531727620712884], 
             UndirectedEdge[73, 284] -> 
             RGBColor[
              0.7701602143416578, 0.8204117587973303, 0.9777160849466304], 
             UndirectedEdge[143, 234] -> 
             RGBColor[
              0.5188863483920749, 0.608972503985311, 0.958220881688419], 
             UndirectedEdge[288, 374] -> 
             RGBColor[
              0.6978073263331076, 0.7277751450029106, 0.644685838509532], 
             UndirectedEdge[254, 344] -> 
             RGBColor[
              0.5008610895766507, 0.6046951642570098, 0.9541155249936819], 
             UndirectedEdge[6, 102] -> 
             RGBColor[
              0.5671460084955712, 0.6440340717295233, 0.9633842635709209], 
             UndirectedEdge[205, 276] -> 
             RGBColor[
              0.5308004923042078, 0.6299667777990562, 0.9562057056219087], 
             UndirectedEdge[101, 244] -> 
             RGBColor[
              0.5664733228316478, 0.6506554289628084, 0.9622357540862636], 
             UndirectedEdge[58, 80] -> 
             RGBColor[
              0.28329709430336963`, 0.4119439183356355, 0.9395600472515486], 
             UndirectedEdge[23, 292] -> 
             RGBColor[
              0.357582292901515, 0.4814003888705103, 0.9441061724553914], 
             UndirectedEdge[101, 397] -> 
             RGBColor[
              0.4777683621291558, 0.5812227117784039, 0.9534304905570141], 
             UndirectedEdge[105, 168] -> 
             RGBColor[
              0.6169122858340104, 0.6825845056232345, 0.8949535000540944], 
             UndirectedEdge[166, 340] -> 
             RGBColor[
              0.4765527477067347, 0.5801118345835279, 0.9533348545421195], 
             UndirectedEdge[138, 317] -> 
             RGBColor[
              0.9009576086576079, 0.9206568618399606, 0.857542214945461], 
             UndirectedEdge[71, 120] -> 
             RGBColor[
              0.5843961628332708, 0.6719387983628715, 0.9613682046867684], 
             UndirectedEdge[231, 290] -> 
             RGBColor[
              0.39651657930296513`, 0.5157746980898162, 0.9468326837174472], 
             UndirectedEdge[13, 224] -> 
             RGBColor[
              0.47586681486155846`, 0.5803000025751206, 0.9531518635511349], 
             UndirectedEdge[40, 159] -> 
             RGBColor[
              0.6297198760792928, 0.7031317786663508, 0.9668322459009842], 
             UndirectedEdge[20, 265] -> 
             RGBColor[
              0.5927195667821548, 0.6648234981962396, 0.9606416292237937], 
             UndirectedEdge[43, 299] -> 
             RGBColor[
              0.3448753421335629, 0.46761950801293234`, 0.9433980942999183], 
             UndirectedEdge[219, 220] -> 
             RGBColor[
              0.7753098311306987, 0.8242157451227123, 0.9595996556224058], 
             UndirectedEdge[56, 290] -> 
             RGBColor[
              0.685428690373947, 0.7523736567018572, 0.9707065674999023], 
             UndirectedEdge[64, 157] -> 
             RGBColor[
              0.5240076806958338, 0.624376541401065, 0.9556918186463865], 
             UndirectedEdge[13, 340] -> 
             RGBColor[
              0.47923575075672387`, 0.582931840901285, 0.9534876475966692], 
             UndirectedEdge[16, 188] -> 
             RGBColor[
              0.6428839120361073, 0.6733127607461133, 0.6306842614032748], 
             UndirectedEdge[171, 308] -> 
             RGBColor[
              0.6927782992555818, 0.7583463455314732, 0.9712783127674585], 
             UndirectedEdge[288, 379] -> 
             RGBColor[
              0.6356102903617737, 0.7113698192240385, 0.9667510438323548], 
             UndirectedEdge[81, 353] -> 
             RGBColor[
              0.23057359402317107`, 0.3596778449015448, 0.9364421971253307], 
             UndirectedEdge[153, 188] -> 
             RGBColor[
              0.6547275158538362, 0.6835710950961937, 0.6314389253656528], 
             UndirectedEdge[148, 356] -> 
             RGBColor[
              0.5055587831288759, 0.609474421164482, 0.9542185858121991], 
             UndirectedEdge[198, 247] -> 
             RGBColor[
              0.4519493956393099, 0.5649814041971961, 0.9502664108046044], 
             UndirectedEdge[94, 375] -> 
             RGBColor[
              0.5166327145504751, 0.601529052262955, 0.9588959463365647], 
             UndirectedEdge[298, 307] -> 
             RGBColor[
              0.5062282766935337, 0.6100179462006126, 0.9542712907980447], 
             UndirectedEdge[9, 142] -> 
             RGBColor[
              0.5815708902877016, 0.6711844740624211, 0.9602025373292649], 
             UndirectedEdge[203, 284] -> 
             RGBColor[
              0.4571303240000354, 0.5519299495588337, 0.9534585149708495], 
             UndirectedEdge[370, 400] -> 
             RGBColor[
              0.3165758681758709, 0.44850790307372057`, 0.941397157232066], 
             UndirectedEdge[63, 381] -> 
             RGBColor[
              0.435698973686098, 0.5487263739265558, 0.9498133458928661], 
             UndirectedEdge[222, 251] -> 
             RGBColor[
              0.483844390880827, 0.5888431892916781, 0.9533387517775018], 
             UndirectedEdge[103, 234] -> 
             RGBColor[
              0.5485332026418004, 0.6322404636705602, 0.9611472461859134], 
             UndirectedEdge[150, 399] -> 
             RGBColor[
              0.584704431680237, 0.6737284241293122, 0.9604492211862257], 
             UndirectedEdge[321, 338] -> 
             RGBColor[
              0.5547452425088691, 0.6494062047139042, 0.9580907240705296], 
             UndirectedEdge[154, 203] -> 
             RGBColor[
              0.24373228008835496`, 0.37350845826493695`, 0.9371915648302114],
              UndirectedEdge[225, 390] -> 
             RGBColor[
              0.9366922576747225, 0.9511153675965605, 0.9507756770527152], 
             UndirectedEdge[54, 121] -> 
             RGBColor[
              0.9009722833729059, 0.9231790258374329, 0.9662917693798565], 
             UndirectedEdge[234, 346] -> 
             RGBColor[
              0.3800886184952294, 0.4983068915150016, 0.9459154299357888], 
             UndirectedEdge[358, 391] -> 
             RGBColor[
              0.4879305229411818, 0.5915566560772065, 0.953879150626576], 
             UndirectedEdge[74, 357] -> 
             RGBColor[
              0.5103834881914628, 0.6008188205345781, 0.9576126387206683], 
             UndirectedEdge[130, 364] -> 
             RGBColor[
              0.46239864442027423`, 0.5638702182711532, 0.952744860255051], 
             UndirectedEdge[202, 381] -> 
             RGBColor[
              0.7502092131945474, 0.8044956809378543, 0.9752653535154854], 
             UndirectedEdge[98, 307] -> 
             RGBColor[
              0.44822484378493366`, 0.5610075518570454, 0.9502357140641073], 
             UndirectedEdge[242, 317] -> 
             RGBColor[
              0.9694738860508811, 0.9749702974926946, 0.8566676785438636], 
             UndirectedEdge[9, 279] -> 
             RGBColor[
              0.6619045116764481, 0.7352668622664741, 0.9673034278673369], 
             UndirectedEdge[200, 399] -> 
             RGBColor[
              0.5522268435695643, 0.6473616550023972, 0.9578924664808282], 
             UndirectedEdge[275, 306] -> 
             RGBColor[
              0.48299560972103783`, 0.5904370396873528, 0.9526411524814464], 
             UndirectedEdge[121, 181] -> 
             RGBColor[
              0.7964835474911034, 0.8410940844525656, 0.9803083455933423], 
             UndirectedEdge[239, 271] -> 
             RGBColor[
              0.6917469637192964, 0.759053851710423, 0.9699538782148793], 
             UndirectedEdge[35, 354] -> 
             RGBColor[
              0.331994917038989, 0.4608163177547091, 0.9424179735176762], 
             UndirectedEdge[31, 310] -> 
             RGBColor[
              0.332124649337983, 0.4579190915600929, 0.9425364359166156], 
             UndirectedEdge[146, 154] -> 
             RGBColor[
              0.54076978014322, 0.6294594118363277, 0.9598651085282877], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.6117722690246012, 0.6952970361828734, 0.9628578747735294], 
             UndirectedEdge[265, 322] -> 
             RGBColor[
              0.9681311415589986, 0.9736162506342394, 0.8329826874405315], 
             UndirectedEdge[115, 284] -> 
             RGBColor[
              0.6565024410000412, 0.7308938001298491, 0.9668695545570842], 
             UndirectedEdge[38, 391] -> 
             RGBColor[
              0.6437626871937745, 0.7215472307661038, 0.9651855703710501], 
             UndirectedEdge[116, 328] -> 
             RGBColor[
              0.6079943015634695, 0.6830885587473734, 0.9662982550587073], 
             UndirectedEdge[92, 278] -> 
             RGBColor[
              0.8223535129587842, 0.8601809803445457, 0.891888519579787], 
             UndirectedEdge[215, 217] -> 
             RGBColor[
              0.3579283738362491, 0.4705023031903998, 0.945064216828853], 
             UndirectedEdge[159, 210] -> 
             RGBColor[
              0.844420924291563, 0.8793033000521602, 0.9839028814099521], 
             UndirectedEdge[165, 298] -> 
             RGBColor[
              0.7008913812414033, 0.764731134940914, 0.9721492448182306], 
             UndirectedEdge[83, 254] -> 
             RGBColor[
              0.4804844503009359, 0.5870459434760544, 0.952817143557388], 
             UndirectedEdge[103, 231] -> 
             RGBColor[
              0.5658013087373104, 0.650390338038104, 0.9621306392821789], 
             UndirectedEdge[245, 319] -> 
             RGBColor[
              0.5215429394165686, 0.6218999751794658, 0.9556291888622395], 
             UndirectedEdge[58, 263] -> 
             RGBColor[
              0.4953680273918492, 0.5852045025353718, 0.9567309520456588], 
             UndirectedEdge[206, 258] -> 
             RGBColor[
              0.716562272939044, 0.7771148783119854, 0.970881180203349], 
             UndirectedEdge[213, 391] -> 
             RGBColor[
              0.7674187216489088, 0.8187513591337099, 0.9773151229184969], 
             UndirectedEdge[78, 370] -> 
             RGBColor[
              0.3165758681758709, 0.44850790307372057`, 0.941397157232066], 
             UndirectedEdge[101, 270] -> 
             RGBColor[
              0.3421865141449788, 0.4696437669233528, 0.9430673730731944], 
             UndirectedEdge[135, 377] -> 
             RGBColor[
              0.973643955065495, 0.9290510093821305, 0.5533113689491462], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.6998990030548622, 0.7576065409323163, 0.756354121739119], 
             UndirectedEdge[19, 83] -> 
             RGBColor[
              0.6692723813491565, 0.7359009166679782, 0.9476176999268671], 
             UndirectedEdge[100, 112] -> 
             RGBColor[
              0.8429300163062121, 0.8780757936008337, 0.9805754671851212], 
             UndirectedEdge[10, 296] -> 
             RGBColor[
              0.3448343313259931, 0.4708388945195995, 0.94327630300083], 
             UndirectedEdge[85, 369] -> 
             RGBColor[
              0.8073079933745493, 0.8498709747126917, 0.9813021077808521], 
             UndirectedEdge[79, 246] -> 
             RGBColor[
              0.5178233424040262, 0.6152154315503545, 0.9567289562613933], 
             UndirectedEdge[227, 280] -> 
             RGBColor[
              0.7327899972952484, 0.7855935486671177, 0.7585884778157173], 
             UndirectedEdge[112, 326] -> 
             RGBColor[
              0.7152161571857962, 0.7759722915119867, 0.9694408621041857], 
             UndirectedEdge[34, 308] -> 
             RGBColor[
              0.5371289732767499, 0.6351045237473848, 0.9567039068260568], 
             UndirectedEdge[29, 226] -> 
             RGBColor[
              0.7417020333300657, 0.7982350182608533, 0.9748650423174249], 
             UndirectedEdge[204, 345] -> 
             RGBColor[
              0.501748761637466, 0.6031672141340616, 0.9549112039145239], 
             UndirectedEdge[54, 265] -> 
             RGBColor[
              0.9520425829569994, 0.9637540174091692, 0.9660635771429226], 
             UndirectedEdge[22, 100] -> 
             RGBColor[
              0.6062149497021057, 0.6896112695083649, 0.9632231102202266], 
             UndirectedEdge[126, 336] -> 
             RGBColor[
              0.6609722580317108, 0.7340597476412984, 0.9675378889011544], 
             UndirectedEdge[82, 157] -> 
             RGBColor[
              0.6744146388400731, 0.7448896031554649, 0.9686530577939347], 
             UndirectedEdge[344, 349] -> 
             RGBColor[
              0.5233631256620026, 0.6229633308562721, 0.955886967701995], 
             UndirectedEdge[343, 349] -> 
             RGBColor[
              0.572567629123657, 0.6638752210571564, 0.959493767630399], 
             UndirectedEdge[2, 66] -> 
             RGBColor[
              0.553647177391712, 0.6388561995165655, 0.9612505334635497], 
             UndirectedEdge[211, 387] -> 
             RGBColor[
              0.36771391727778907`, 0.48878244739360843`, 0.9448937419240441],
              UndirectedEdge[250, 265] -> 
             RGBColor[
              0.8212489070000673, 0.8611194569126613, 0.9774583227633606], 
             UndirectedEdge[217, 306] -> 
             RGBColor[
              0.5366564446727744, 0.6347209037395065, 0.9566667076434224], 
             UndirectedEdge[374, 375] -> 
             RGBColor[
              0.8912098512098479, 0.8829693014246596, 0.6614700206415656], 
             UndirectedEdge[38, 247] -> 
             RGBColor[
              0.5272142431526997, 0.6260847980513069, 0.9561915353050792], 
             UndirectedEdge[204, 310] -> 
             RGBColor[
              0.3725121015914763, 0.4970729922210819, 0.9449571196072593], 
             UndirectedEdge[226, 266] -> 
             RGBColor[
              0.6462944667273398, 0.7235826452350178, 0.9653985542167761], 
             UndirectedEdge[319, 334] -> 
             RGBColor[
              0.3645718082992855, 0.4890283673827175, 0.9444939059215977], 
             UndirectedEdge[73, 206] -> 
             RGBColor[
              0.6594581775736647, 0.7316623407078899, 0.9682330840249023], 
             UndirectedEdge[200, 255] -> 
             RGBColor[
              0.5583472511770361, 0.6523304776193635, 0.9583742873874802], 
             UndirectedEdge[296, 383] -> 
             RGBColor[
              0.40300393929753575`, 0.5234834894777463, 0.9469000325430159], 
             UndirectedEdge[235, 281] -> 
             RGBColor[
              0.4448687309325377, 0.5572459523035628, 0.9502580225847711], 
             UndirectedEdge[174, 272] -> 
             RGBColor[
              0.6066831761426899, 0.6878967514133966, 0.9642044728823113], 
             UndirectedEdge[9, 131] -> 
             RGBColor[
              0.4934988180021988, 0.5976849532311219, 0.9538214127344969], 
             UndirectedEdge[228, 361] -> 
             RGBColor[
              0.3862858444451214, 0.5090031159924642, 0.9458347703222509], 
             UndirectedEdge[149, 199] -> 
             RGBColor[
              0.5837943865549418, 0.657813326113432, 0.964895804324426], 
             UndirectedEdge[102, 400] -> 
             RGBColor[
              0.27361664565237814`, 0.4049188212509393, 0.9388934352391255], 
             UndirectedEdge[45, 350] -> 
             RGBColor[
              0.49600052191087296`, 0.5799243467533673, 0.9577081441244019], 
             UndirectedEdge[369, 392] -> 
             RGBColor[
              0.8139415862409984, 0.8551604216003167, 0.9819348257903322], 
             UndirectedEdge[82, 151] -> 
             RGBColor[
              0.7967797679574162, 0.8413493154363382, 0.9803315486394085], 
             UndirectedEdge[260, 342] -> 
             RGBColor[
              0.7440201818855748, 0.7999534879426101, 0.9751206365325952], 
             UndirectedEdge[296, 380] -> 
             RGBColor[
              0.4944980900208593, 0.5991931515538609, 0.9537075113067902], 
             UndirectedEdge[105, 148] -> 
             RGBColor[
              0.7272666803797203, 0.7835974094822982, 0.9018739812334466], 
             UndirectedEdge[94, 288] -> 
             RGBColor[
              0.3232301896737349, 0.44633489584120606`, 0.942111764204531], 
             UndirectedEdge[195, 258] -> 
             RGBColor[
              0.7263643751147018, 0.7850726664378553, 0.9716528375929001], 
             UndirectedEdge[339, 374] -> 
             RGBColor[
              0.6343191650959692, 0.6717759680173168, 0.6406773706193445], 
             UndirectedEdge[199, 367] -> 
             RGBColor[
              0.5854542149759259, 0.6591368282414825, 0.9650541202409657], 
             UndirectedEdge[36, 298] -> 
             RGBColor[
              0.41929349752881717`, 0.5363634221761227, 0.9482776380686455], 
             UndirectedEdge[147, 347] -> 
             RGBColor[
              0.3356507917074627, 0.4559642361920945, 0.9429874940567051], 
             UndirectedEdge[38, 205] -> 
             RGBColor[
              0.5611420746797946, 0.6545994412442668, 0.9585943061313932], 
             UndirectedEdge[16, 73] -> 
             RGBColor[
              0.5725404490032184, 0.6574912051595763, 0.9623873395915872], 
             UndirectedEdge[108, 290] -> 
             RGBColor[
              0.4734989572110816, 0.5834183384879299, 0.9517025856973947], 
             UndirectedEdge[225, 296] -> 
             RGBColor[
              0.6946126621660886, 0.7565068232177694, 0.9296383171928386], 
             UndirectedEdge[24, 144] -> 
             RGBColor[
              0.8987234816541725, 0.9187293445696636, 0.84497557478425], 
             UndirectedEdge[209, 319] -> 
             RGBColor[
              0.36589123837863496`, 0.4904151720528126, 0.9445690455126947], 
             UndirectedEdge[80, 192] -> 
             RGBColor[
              0.4810722337027308, 0.5865946501657363, 0.9531199584610652], 
             UndirectedEdge[42, 221] -> 
             RGBColor[
              0.5918520541424317, 0.6765283992402927, 0.9626340479733289], 
             UndirectedEdge[22, 365] -> 
             RGBColor[
              0.5482236171076944, 0.6441116554173543, 0.9575773178294482], 
             UndirectedEdge[80, 201] -> 
             RGBColor[
              0.5951253733494095, 0.6762684759444225, 0.9641876510414882], 
             UndirectedEdge[39, 375] -> 
             RGBColor[
              0.6851902704988069, 0.7527145687599504, 0.9701325365663209], 
             UndirectedEdge[15, 326] -> 
             RGBColor[
              0.551308135124323, 0.6466158060992064, 0.9578201423866789], 
             UndirectedEdge[86, 95] -> 
             RGBColor[
              0.32563012397877966`, 0.45413093756269185`, 0.9420553460992246],
              UndirectedEdge[59, 194] -> 
             RGBColor[
              0.839366403403794, 0.8733959169656103, 0.890153337547586], 
             UndirectedEdge[296, 324] -> 
             RGBColor[
              0.6978183268233231, 0.7578896054145013, 0.8790717865237949], 
             UndirectedEdge[169, 245] -> 
             RGBColor[
              0.5349926314468753, 0.6333701452087899, 0.956535726171531], 
             UndirectedEdge[258, 284] -> 
             RGBColor[
              0.8272643097070371, 0.865864296401426, 0.9803641811250772], 
             UndirectedEdge[33, 152] -> 
             RGBColor[
              0.5372491576835698, 0.6347066082489439, 0.9568502726106025], 
             UndirectedEdge[246, 349] -> 
             RGBColor[
              0.6661057937697572, 0.7388810016088689, 0.9674951371746792], 
             UndirectedEdge[27, 395] -> 
             RGBColor[
              0.6436141161344391, 0.7166269960960047, 0.9680322891322788], 
             UndirectedEdge[185, 340] -> 
             RGBColor[
              0.5286761192846142, 0.6265316847419182, 0.9566094913980707], 
             UndirectedEdge[223, 321] -> 
             RGBColor[
              0.4581820888093998, 0.5678933842954244, 0.9513505703174716], 
             UndirectedEdge[274, 373] -> 
             RGBColor[
              0.4664478222559699, 0.573839286124893, 0.9522125384428193], 
             UndirectedEdge[156, 214] -> 
             RGBColor[
              0.4721238900104835, 0.582330468706201, 0.9515864685498703], 
             UndirectedEdge[205, 221] -> 
             RGBColor[
              0.6273843703533175, 0.7064327664226073, 0.965139055144904], 
             UndirectedEdge[97, 105] -> 
             RGBColor[
              0.7046728683046053, 0.7643932449397828, 0.9003333458535057], 
             UndirectedEdge[130, 158] -> 
             RGBColor[
              0.5592174545296793, 0.6525554718133224, 0.958737377932755], 
             UndirectedEdge[108, 143] -> 
             RGBColor[
              0.6131368323957014, 0.6947660187509683, 0.9640741767646321], 
             UndirectedEdge[176, 399] -> 
             RGBColor[
              0.6281912259969415, 0.7079596493325643, 0.9646064912209431], 
             UndirectedEdge[150, 189] -> 
             RGBColor[
              0.7309763377893471, 0.7896380340914803, 0.9739622065471795], 
             UndirectedEdge[253, 386] -> 
             RGBColor[
              0.49880863457742114`, 0.6036015534711902, 0.953795719270194], 
             UndirectedEdge[46, 59] -> 
             RGBColor[
              0.8258108036381346, 0.8642978560745316, 0.9584046736161747], 
             UndirectedEdge[186, 241] -> 
             RGBColor[
              0.581895737956853, 0.6556545757408039, 0.9648123952454264], 
             UndirectedEdge[39, 93] -> 
             RGBColor[
              0.5881904368683077, 0.6765585201837323, 0.9607236522842884], 
             UndirectedEdge[214, 264] -> 
             RGBColor[
              0.48706128781290026`, 0.5944573211643052, 0.9527623952223676], 
             UndirectedEdge[234, 290] -> 
             RGBColor[
              0.37924847320745514`, 0.49762482372227257`, 0.9458492906211815],
              UndirectedEdge[148, 170] -> 
             RGBColor[
              0.5747994184143094, 0.6650672583844809, 0.9600932432506408], 
             UndirectedEdge[50, 362] -> 
             RGBColor[
              0.641955845302446, 0.7180037258902578, 0.9664631319055441], 
             UndirectedEdge[271, 326] -> 
             RGBColor[
              0.5641584430223189, 0.6570482649505732, 0.958831765696638], 
             UndirectedEdge[61, 352] -> 
             RGBColor[
              0.4867736554966661, 0.5823746397920285, 0.9552594312440819], 
             UndirectedEdge[256, 333] -> 
             RGBColor[
              0.6497902168267049, 0.7159679804452954, 0.8662210896419063], 
             UndirectedEdge[100, 394] -> 
             RGBColor[
              0.7045701718386911, 0.7691348402628033, 0.971188628212426], 
             UndirectedEdge[1, 114] -> 
             RGBColor[
              0.8965258906637135, 0.9202768624467282, 0.9881702245188893], 
             UndirectedEdge[218, 269] -> 
             RGBColor[
              0.48535965279777615`, 0.5930758572012436, 0.9526284362806825], 
             UndirectedEdge[182, 253] -> 
             RGBColor[
              0.4095018770796599, 0.5291116765887729, 0.9473140753925922], 
             UndirectedEdge[57, 354] -> 
             RGBColor[
              0.3698733551756838, 0.4947874427029736, 0.9447889810189968], 
             UndirectedEdge[40, 192] -> 
             RGBColor[
              0.4709915919938916, 0.5778633049853241, 0.9524776288853395], 
             UndirectedEdge[262, 314] -> 
             RGBColor[
              0.5277523279441019, 0.6274921406532827, 0.9559657429576871], 
             UndirectedEdge[244, 253] -> 
             RGBColor[
              0.637814128373658, 0.7136099746900687, 0.9667389540490412], 
             UndirectedEdge[277, 330] -> 
             RGBColor[
              0.7394209142107394, 0.7960045263240838, 0.9751900493892915], 
             UndirectedEdge[304, 329] -> 
             RGBColor[
              0.5667036208813635, 0.6566521000868515, 0.9602248983866023], 
             UndirectedEdge[103, 223] -> 
             RGBColor[
              0.5858819630391019, 0.6687485654122045, 0.9633748137501501], 
             UndirectedEdge[92, 337] -> 
             RGBColor[
              0.7339066228368981, 0.7885669592777582, 0.8847949669047768], 
             UndirectedEdge[226, 341] -> 
             RGBColor[
              0.6519409391639044, 0.728020483700277, 0.9659430381475455], 
             UndirectedEdge[193, 260] -> 
             RGBColor[
              0.7818577200490545, 0.8301198260293949, 0.9787307525434916], 
             UndirectedEdge[9, 214] -> 
             RGBColor[
              0.5416430889064131, 0.638769286174137, 0.9570592745441742], 
             UndirectedEdge[8, 157] -> 
             RGBColor[
              0.5852697891390308, 0.6741874067834244, 0.9604937281963545], 
             UndirectedEdge[103, 342] -> 
             RGBColor[
              0.8263757362232815, 0.864397884737548, 0.9833005116640523], 
             UndirectedEdge[165, 314] -> 
             RGBColor[
              0.7499481462833395, 0.8045576267840382, 0.9760111730631833], 
             UndirectedEdge[115, 392] -> 
             RGBColor[
              0.7447592711321382, 0.80042450775869, 0.9755112477019443], 
             UndirectedEdge[104, 233] -> 
             RGBColor[
              0.6767598500769322, 0.7471707304835666, 0.9685798019373937], 
             UndirectedEdge[67, 139] -> 
             RGBColor[
              0.33379995103723337`, 0.45834743362262287`, 0.9426806314510242],
              UndirectedEdge[116, 364] -> 
             RGBColor[
              0.2737021663401902, 0.40500870891615454`, 0.9388983055157798], 
             UndirectedEdge[74, 220] -> 
             RGBColor[
              0.4232002893066409, 0.5319672724008156, 0.9494312787327901], 
             UndirectedEdge[100, 168] -> 
             RGBColor[
              0.4957966035211421, 0.588546446830814, 0.9562975945338845], 
             UndirectedEdge[129, 308] -> 
             RGBColor[
              0.7270880256306379, 0.7854918198268215, 0.9671947309548423], 
             UndirectedEdge[26, 185] -> 
             RGBColor[
              0.5873280759325731, 0.6723510390466843, 0.9624553703030417], 
             UndirectedEdge[197, 215] -> 
             RGBColor[
              0.22915428223562018`, 0.3581860582232639, 0.9363613694187133], 
             UndirectedEdge[178, 240] -> 
             RGBColor[
              0.6639021133373082, 0.7370379193386871, 0.9673585995540226], 
             UndirectedEdge[52, 223] -> 
             RGBColor[
              0.5283410411604237, 0.6236895480924515, 0.9576682292762841], 
             UndirectedEdge[192, 243] -> 
             RGBColor[
              0.5031322007598629, 0.6057018848644411, 0.9545256000550828], 
             UndirectedEdge[124, 252] -> 
             RGBColor[
              0.6327053400131244, 0.7079286341277078, 0.9669918003274482], 
             UndirectedEdge[194, 396] -> 
             RGBColor[
              0.8347594456992022, 0.8697969265926078, 0.8896941590580598], 
             UndirectedEdge[269, 279] -> 
             RGBColor[
              0.5875512933357215, 0.6749035700431575, 0.9614500701547419], 
             UndirectedEdge[57, 208] -> 
             RGBColor[
              0.4513844163854027, 0.5632832732493386, 0.9505643987708632], 
             UndirectedEdge[169, 304] -> 
             RGBColor[
              0.5921903466518638, 0.6785481437430244, 0.961898424841888], 
             UndirectedEdge[209, 280] -> 
             RGBColor[
              0.6462763393391913, 0.7102381235476785, 0.7529711344785746], 
             UndirectedEdge[226, 399] -> 
             RGBColor[
              0.5979677720267547, 0.6843488573842964, 0.9615940997834305], 
             UndirectedEdge[206, 392] -> 
             RGBColor[
              0.693254261182976, 0.7586104204077035, 0.9714565846496783], 
             UndirectedEdge[48, 343] -> 
             RGBColor[
              0.4111818397188071, 0.528624223987842, 0.9479012937752865], 
             UndirectedEdge[159, 263] -> 
             RGBColor[
              0.8518714508766114, 0.8851237080464993, 0.9846454802708202], 
             UndirectedEdge[261, 295] -> 
             RGBColor[
              0.5454194257341849, 0.6418350865329576, 0.957356561612434], 
             UndirectedEdge[33, 204] -> 
             RGBColor[
              0.49191119771958663`, 0.5954371460802672, 0.9539613778924814], 
             UndirectedEdge[64, 151] -> 
             RGBColor[
              0.6463728098131769, 0.7208362536819383, 0.9673703094918604], 
             UndirectedEdge[210, 263] -> 
             RGBColor[
              0.7595037047930744, 0.8120493337170813, 0.9766638893942665], 
             UndirectedEdge[19, 303] -> 
             RGBColor[
              0.8855152490255417, 0.9109683372563684, 0.9658191108579468], 
             UndirectedEdge[248, 315] -> 
             RGBColor[
              0.4203853680102919, 0.5333802906691139, 0.948873035713238], 
             UndirectedEdge[236, 351] -> 
             RGBColor[
              0.6290628513236003, 0.7084829041229459, 0.9648011634780822], 
             UndirectedEdge[53, 386] -> 
             RGBColor[
              0.7752315138438842, 0.8217523865007497, 0.8728323815047065], 
             UndirectedEdge[93, 301] -> 
             RGBColor[
              0.6583102545379391, 0.7326171999610307, 0.9668370245986657], 
             UndirectedEdge[37, 159] -> 
             RGBColor[
              0.8122664383886282, 0.8541839712816435, 0.9806980227559026], 
             UndirectedEdge[148, 326] -> 
             RGBColor[
              0.47843713894643625`, 0.5874558486010308, 0.9520834706323013], 
             UndirectedEdge[13, 357] -> 
             RGBColor[
              0.5342698360170375, 0.6259248865811815, 0.9589729308926499], 
             UndirectedEdge[162, 231] -> 
             RGBColor[
              0.610370348184198, 0.6859284802987048, 0.9663816740518743], 
             UndirectedEdge[33, 84] -> 
             RGBColor[
              0.49662996710732704`, 0.5995243069516825, 0.9542620537052243], 
             UndirectedEdge[199, 293] -> 
             RGBColor[
              0.5509999685928535, 0.6316639474112243, 0.9617678434632795], 
             UndirectedEdge[96, 167] -> 
             RGBColor[
              0.6636502992356335, 0.7316124327851441, 0.9557400057901236], 
             UndirectedEdge[131, 307] -> 
             RGBColor[
              0.4467875744412036, 0.5597626613907641, 0.9501441325324522], 
             UndirectedEdge[174, 291] -> 
             RGBColor[
              0.5426912564629525, 0.6379057774029829, 0.9578263563671243], 
             UndirectedEdge[207, 250] -> 
             RGBColor[
              0.5922030150745674, 0.6789163474027381, 0.9616547110648097], 
             UndirectedEdge[364, 387] -> 
             RGBColor[
              0.26234202904300274`, 0.39306848434250485`, 0.9382513625025222],
              UndirectedEdge[103, 346] -> 
             RGBColor[
              0.664853380648442, 0.7359796219740379, 0.9687300815975405], 
             UndirectedEdge[31, 106] -> 
             RGBColor[
              0.4091413411806091, 0.5218753003147674, 0.9482041960846221], 
             UndirectedEdge[128, 316] -> 
             RGBColor[
              0.8494572019845126, 0.8827981312336949, 0.9855031803163208], 
             UndirectedEdge[185, 289] -> 
             RGBColor[
              0.38048327854660946`, 0.5039772250566154, 0.9454650359542053], 
             UndirectedEdge[20, 172] -> 
             RGBColor[
              0.2554197232507139, 0.3857927020552724, 0.9378571474282851], 
             UndirectedEdge[70, 234] -> 
             RGBColor[
              0.45159857369793666`, 0.5563618946353295, 0.9515449555589429], 
             UndirectedEdge[119, 383] -> 
             RGBColor[
              0.3969533808599707, 0.5182427998690368, 0.946514496309673], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.6019475158704537, 0.6859365204932296, 0.9629963111120772], 
             UndirectedEdge[20, 54] -> 
             RGBColor[
              0.6033595919723476, 0.6727588115616432, 0.9426308419398111], 
             UndirectedEdge[229, 334] -> 
             RGBColor[
              0.2961462414165838, 0.42859885485799476`, 0.9401764623883468], 
             UndirectedEdge[63, 142] -> 
             RGBColor[
              0.43185150776159803`, 0.545602827762682, 0.9495104592815573], 
             UndirectedEdge[230, 358] -> 
             RGBColor[
              0.4321818992929025, 0.5464247576858482, 0.9494033477857655], 
             UndirectedEdge[119, 296] -> 
             RGBColor[
              0.3993268055064416, 0.5202985410060186, 0.9466657288294091], 
             UndirectedEdge[218, 262] -> 
             RGBColor[
              0.4854689137861395, 0.5931645601937485, 0.9526370377059227], 
             UndirectedEdge[100, 170] -> 
             RGBColor[
              0.7141728097578539, 0.7766364939880046, 0.9721457294184548], 
             UndirectedEdge[97, 357] -> 
             RGBColor[
              0.5948942293620234, 0.679211770592951, 0.9628074108657521], 
             UndirectedEdge[375, 399] -> 
             RGBColor[
              0.6777864996356608, 0.746703854037172, 0.9695496846030678], 
             UndirectedEdge[199, 252] -> 
             RGBColor[
              0.31790825316157595`, 0.44376549468982807`, 0.9416979536646433],
              UndirectedEdge[175, 345] -> 
             RGBColor[
              0.6329096969132493, 0.7126071205559787, 0.9644194932013161], 
             UndirectedEdge[176, 186] -> 
             RGBColor[
              0.4755289026707372, 0.5717099122568081, 0.9544363291396221], 
             UndirectedEdge[309, 371] -> 
             RGBColor[
              0.5785010415589732, 0.661626842213328, 0.9631737813604713], 
             UndirectedEdge[326, 354] -> 
             RGBColor[
              0.42895819061440166`, 0.5449651303190104, 0.9488297381436619], 
             UndirectedEdge[38, 289] -> 
             RGBColor[
              0.4992989609006207, 0.601905983627438, 0.9544127982044917], 
             UndirectedEdge[120, 237] -> 
             RGBColor[
              0.5307310227458742, 0.6254567513075365, 0.9579487094146196], 
             UndirectedEdge[275, 384] -> 
             RGBColor[
              0.31962452753594933`, 0.4423596079002245, 0.9419132194519475], 
             UndirectedEdge[216, 220] -> 
             RGBColor[
              0.4981664542868162, 0.6020931902874249, 0.9540178789229599], 
             UndirectedEdge[50, 276] -> 
             RGBColor[
              0.6812018530541812, 0.7498654029956175, 0.9695527213986241], 
             UndirectedEdge[143, 321] -> 
             RGBColor[
              0.6759512363155853, 0.745790053327567, 0.9690112899174923], 
             UndirectedEdge[225, 316] -> 
             RGBColor[
              0.9233970700897757, 0.9405141459045769, 0.949507570192109], 
             UndirectedEdge[40, 332] -> 
             RGBColor[
              0.535108990768143, 0.6283050469238323, 0.95862707986955], 
             UndirectedEdge[254, 343] -> 
             RGBColor[
              0.5500655930383049, 0.645607054457894, 0.957722324922086], 
             UndirectedEdge[37, 167] -> 
             RGBColor[
              0.8198124512187406, 0.8598117752948793, 0.9679245913498726], 
             UndirectedEdge[26, 204] -> 
             RGBColor[
              0.5599139537290738, 0.6486063042678585, 0.9607085666775912], 
             UndirectedEdge[141, 189] -> 
             RGBColor[
              0.9131584178519658, 0.9312620584347353, 0.9013611523424835], 
             UndirectedEdge[55, 210] -> 
             RGBColor[
              0.862304895924761, 0.8926411368138834, 0.9536299823217809], 
             UndirectedEdge[41, 312] -> 
             RGBColor[
              0.7884634441016275, 0.8347494902117045, 0.9795300014522194], 
             UndirectedEdge[102, 247] -> 
             RGBColor[
              0.3286582093271512, 0.45270899243620033`, 0.9423963900495583], 
             UndirectedEdge[30, 400] -> 
             RGBColor[
              0.4043872167776808, 0.5232633345456914, 0.9473522605645516], 
             UndirectedEdge[57, 195] -> 
             RGBColor[
              0.44291329946316527`, 0.5564060389123977, 0.949897521416021], 
             UndirectedEdge[301, 324] -> 
             RGBColor[
              0.8446322295469924, 0.8775136991348131, 0.8908631343806086], 
             UndirectedEdge[290, 331] -> 
             RGBColor[
              0.40976201149092834`, 0.5282125996171714, 0.9476413238764747], 
             UndirectedEdge[49, 347] -> 
             RGBColor[
              0.35448622008592134`, 0.47576146565298943`, 0.9440601438383391],
              UndirectedEdge[92, 258] -> 
             RGBColor[
              0.9643495308024118, 0.9719892118195794, 0.9029879035020505], 
             UndirectedEdge[234, 313] -> 
             RGBColor[
              0.2637631510117686, 0.3945621736360148, 0.9383322932962819], 
             UndirectedEdge[376, 377] -> 
             RGBColor[
              0.8227740493855374, 0.8121573935990177, 0.6293137180379831], 
             UndirectedEdge[223, 272] -> 
             RGBColor[
              0.5712975346672778, 0.6572474873014484, 0.9619497310977921], 
             UndirectedEdge[213, 302] -> 
             RGBColor[
              0.577993041834566, 0.6567523330112082, 0.9638024179015963], 
             UndirectedEdge[121, 158] -> 
             RGBColor[
              0.6447259269779697, 0.7195111569409571, 0.9672187144195079], 
             UndirectedEdge[240, 248] -> 
             RGBColor[
              0.5891564701726255, 0.6773427895394819, 0.9607997019647008], 
             UndirectedEdge[18, 132] -> 
             RGBColor[
              0.639633198405283, 0.7125323113678468, 0.9680763004603402], 
             UndirectedEdge[59, 79] -> 
             RGBColor[
              0.5104258716799817, 0.609436471197871, 0.9559916455129149], 
             UndirectedEdge[109, 207] -> 
             RGBColor[
              0.5306044951257078, 0.6298076584599777, 0.9561902760060557], 
             UndirectedEdge[190, 365] -> 
             RGBColor[
              0.6037199702785914, 0.6891660950037081, 0.9619461940409011], 
             UndirectedEdge[78, 391] -> 
             RGBColor[
              0.47908206902479245`, 0.5837766348314537, 0.9533195799229842], 
             UndirectedEdge[159, 236] -> 
             RGBColor[
              0.7352271607816647, 0.7923352586183099, 0.9741578668555937], 
             UndirectedEdge[95, 334] -> 
             RGBColor[
              0.33194712670969084`, 0.4607705079539856, 0.9424150900595819], 
             UndirectedEdge[20, 147] -> 
             RGBColor[
              0.22770875868383597`, 0.356666721318852, 0.9362790489908996], 
             UndirectedEdge[229, 388] -> 
             RGBColor[
              0.29994697693464456`, 0.43259366886802686`, 0.9403929086534162],
              UndirectedEdge[15, 271] -> 
             RGBColor[
              0.625369906977077, 0.7067424889340722, 0.9636505563641371], 
             UndirectedEdge[53, 151] -> 
             RGBColor[
              0.9169533374817349, 0.9339267354025218, 0.8860347022487431], 
             UndirectedEdge[178, 309] -> 
             RGBColor[
              0.506914893231003, 0.6054610276504802, 0.9561030079529593], 
             UndirectedEdge[309, 386] -> 
             RGBColor[
              0.4329108257583725, 0.546367942405687, 0.9496024899185971], 
             UndirectedEdge[199, 299] -> 
             RGBColor[
              0.24640176647662163`, 0.376314257714218, 0.937343588130872], 
             UndirectedEdge[33, 90] -> 
             RGBColor[
              0.495760799003007, 0.5987714772253796, 0.9542066710821921], 
             UndirectedEdge[191, 216] -> 
             RGBColor[
              0.6620224013851839, 0.7316629435097626, 0.969623427861933], 
             UndirectedEdge[188, 203] -> 
             RGBColor[
              0.5819345335557102, 0.6103341330743982, 0.6271736293026211], 
             UndirectedEdge[87, 263] -> 
             RGBColor[
              0.7791295822031614, 0.8273812183120342, 0.9786200134402521], 
             UndirectedEdge[25, 76] -> 
             RGBColor[
              0.6572875267311225, 0.729892991033869, 0.968070394589553], 
             UndirectedEdge[329, 334] -> 
             RGBColor[
              0.3525347745590919, 0.47860249375586866`, 0.9437269167756035], 
             UndirectedEdge[42, 376] -> 
             RGBColor[
              0.5512481589703075, 0.6448083277307964, 0.9585870311675454], 
             UndirectedEdge[54, 130] -> 
             RGBColor[
              0.8154638109246155, 0.8562233407097981, 0.9578104328931036], 
             UndirectedEdge[90, 256] -> 
             RGBColor[
              0.3301183997249826, 0.4602980309469792, 0.9422578686709889], 
             UndirectedEdge[160, 302] -> 
             RGBColor[
              0.5068618891549007, 0.6006653818285759, 0.9568503907468233], 
             UndirectedEdge[299, 367] -> 
             RGBColor[
              0.5881391234197644, 0.6619588372489843, 0.9652070218048763], 
             UndirectedEdge[16, 96] -> 
             RGBColor[
              0.34793991978896754`, 0.4757898033775164, 0.9433914019111306], 
             UndirectedEdge[5, 223] -> 
             RGBColor[
              0.3339935239762808, 0.46371013629080227`, 0.9425027499022598], 
             UndirectedEdge[40, 228] -> 
             RGBColor[
              0.3312766030484349, 0.46135687593951846`, 0.9423296301032162], 
             UndirectedEdge[154, 222] -> 
             RGBColor[
              0.45692715022676933`, 0.5636942425416451, 0.9516907821779148], 
             UndirectedEdge[85, 188] -> 
             RGBColor[
              0.9221269146401947, 0.9004745751250836, 0.654021981893698], 
             UndirectedEdge[281, 384] -> 
             RGBColor[
              0.3788882192035462, 0.49119212344013213`, 0.9463798520185365], 
             UndirectedEdge[249, 334] -> 
             RGBColor[
              0.2833998179202635, 0.41520155559343475`, 0.9394505724268751], 
             UndirectedEdge[203, 243] -> 
             RGBColor[
              0.29274673974831333`, 0.41779690547936077`, 0.940247549685051], 
             UndirectedEdge[49, 147] -> 
             RGBColor[
              0.23021636994862782`, 0.3593023797498854, 0.9364218537427511], 
             UndirectedEdge[99, 232] -> 
             RGBColor[
              0.4175731136201196, 0.5273196699178533, 0.9489954968326286], 
             UndirectedEdge[84, 389] -> 
             RGBColor[
              0.3304938515426093, 0.46053193355254685`, 0.9422851348818817], 
             UndirectedEdge[76, 242] -> 
             RGBColor[
              0.7164941691251604, 0.776888240047171, 0.9662800162403902], 
             UndirectedEdge[129, 397] -> 
             RGBColor[
              0.8016466593313407, 0.8457613427490027, 0.97324238874457], 
             UndirectedEdge[177, 390] -> 
             RGBColor[
              0.755591675212743, 0.8092381093279879, 0.9763417220850713], 
             UndirectedEdge[138, 144] -> 
             RGBColor[
              0.9010471295870442, 0.9205445959952014, 0.8452071742944741], 
             UndirectedEdge[184, 325] -> 
             RGBColor[
              0.6692093331878455, 0.7415106843564353, 0.9676641902815348], 
             UndirectedEdge[69, 140] -> 
             RGBColor[
              0.47543344654181807`, 0.5818277979787178, 0.9527282822383505], 
             UndirectedEdge[247, 391] -> 
             RGBColor[
              0.5341236326995655, 0.6315668060167147, 0.956822534733417], 
             UndirectedEdge[14, 391] -> 
             RGBColor[
              0.45916578315287504`, 0.5628433556146104, 0.9521853769060831], 
             UndirectedEdge[229, 240] -> 
             RGBColor[
              0.45860034084800627`, 0.5659217833370691, 0.9517433846794524], 
             UndirectedEdge[166, 400] -> 
             RGBColor[
              0.30123362554603594`, 0.4339460181368329, 0.9404661813884088], 
             UndirectedEdge[281, 386] -> 
             RGBColor[
              0.552054653692635, 0.6472218635032404, 0.957878911062964], 
             UndirectedEdge[150, 255] -> 
             RGBColor[
              0.5908248392877088, 0.6786972467462786, 0.9609310420928776], 
             UndirectedEdge[103, 290] -> 
             RGBColor[
              0.6640132353606677, 0.7352975541813087, 0.9686639422829333], 
             UndirectedEdge[212, 299] -> 
             RGBColor[
              0.40565149186390614`, 0.517303909812217, 0.9480876817358732], 
             UndirectedEdge[206, 208] -> 
             RGBColor[
              0.512568613380781, 0.6151653171522327, 0.9547704253274834], 
             UndirectedEdge[75, 169] -> 
             RGBColor[
              0.45411238539209475`, 0.5675717794935112, 0.9502061523609531], 
             UndirectedEdge[110, 167] -> 
             RGBColor[
              0.6890629024549833, 0.7536235524191686, 0.957359274395778], 
             UndirectedEdge[33, 214] -> 
             RGBColor[
              0.5577133449636106, 0.6518158439981552, 0.9583243839682845], 
             UndirectedEdge[98, 107] -> 
             RGBColor[
              0.5257323098059263, 0.6235253267496706, 0.9566151599872831], 
             UndirectedEdge[238, 252] -> 
             RGBColor[
              0.6039898882389382, 0.68506488241122, 0.9642440925864593], 
             UndirectedEdge[91, 241] -> 
             RGBColor[
              0.6165769332607645, 0.6921067109200003, 0.9667874380117534], 
             UndirectedEdge[74, 219] -> 
             RGBColor[
              0.6046780420560142, 0.6750443586064743, 0.9478631513849889], 
             UndirectedEdge[45, 180] -> 
             RGBColor[
              0.7147161224168723, 0.7766941858309103, 0.9724506294500983], 
             UndirectedEdge[187, 235] -> 
             RGBColor[
              0.3530691563431102, 0.48023249027778964`, 0.9437182323287547], 
             UndirectedEdge[114, 188] -> 
             RGBColor[
              0.9103111579603056, 0.8910530114787107, 0.6528949844735197], 
             UndirectedEdge[81, 378] -> 
             RGBColor[
              0.4962514791687499, 0.5838829658977737, 0.9571374872421277], 
             UndirectedEdge[19, 313] -> 
             RGBColor[
              0.6126474834113596, 0.6826958153390549, 0.9441619097366749], 
             UndirectedEdge[195, 284] -> 
             RGBColor[
              0.6147995332265366, 0.6970375009047323, 0.9635865488943693], 
             UndirectedEdge[64, 253] -> 
             RGBColor[
              0.44469408670066507`, 0.5595933997506016, 0.9495564918703935], 
             UndirectedEdge[55, 122] -> 
             RGBColor[
              0.8016435808894219, 0.8450739234135685, 0.9477056198915563], 
             UndirectedEdge[99, 275] -> 
             RGBColor[
              0.3393613344042535, 0.4631042433046442, 0.9430372014051083], 
             UndirectedEdge[118, 367] -> 
             RGBColor[
              0.8738073085448397, 0.5570294506563696, 0.4594730863776075], 
             UndirectedEdge[7, 96] -> 
             RGBColor[
              0.37648316213348415`, 0.5005125252712629, 0.945210152073525], 
             UndirectedEdge[110, 115] -> 
             RGBColor[
              0.511775261527926, 0.6137861459108411, 0.954911078002366], 
             UndirectedEdge[68, 95] -> 
             RGBColor[
              0.32000570482372004`, 0.44821931642195295`, 0.9417350437489265],
              UndirectedEdge[289, 302] -> 
             RGBColor[
              0.31678267063314364`, 0.4453889654703439, 0.9415310926159287], 
             UndirectedEdge[260, 321] -> 
             RGBColor[
              0.6232425362276042, 0.7046136162178783, 0.9637577792835296], 
             UndirectedEdge[191, 220] -> 
             RGBColor[
              0.757688025479693, 0.8107084121393915, 0.97677333190918], 
             UndirectedEdge[169, 209] -> 
             RGBColor[
              0.37934093040894157`, 0.5018853420821368, 0.9454755828219863], 
             UndirectedEdge[32, 252] -> 
             RGBColor[
              0.6611565385703686, 0.7306148475700429, 0.969705501044523], 
             UndirectedEdge[75, 280] -> 
             RGBColor[
              0.7210477943223443, 0.775924560959053, 0.7577017040175411], 
             UndirectedEdge[14, 224] -> 
             RGBColor[
              0.45952596170256055`, 0.563124729835083, 0.9522212761378559], 
             UndirectedEdge[128, 311] -> 
             RGBColor[
              0.8486777211304619, 0.882176594359119, 0.9854288327366107], 
             UndirectedEdge[132, 198] -> 
             RGBColor[
              0.7001277098227168, 0.764033437121447, 0.9721785742989213], 
             UndirectedEdge[245, 388] -> 
             RGBColor[
              0.45689422544977193`, 0.565440174535665, 0.9515268315151963], 
             UndirectedEdge[183, 273] -> 
             RGBColor[
              0.6648544192395143, 0.7374557605424558, 0.9676764779202662], 
             UndirectedEdge[69, 220] -> 
             RGBColor[
              0.46484129318962664`, 0.5732286107163379, 0.9518944291261298], 
             UndirectedEdge[37, 263] -> 
             RGBColor[
              0.7273492188901396, 0.7869300049465646, 0.9734590307402169], 
             UndirectedEdge[235, 384] -> 
             RGBColor[
              0.27841317680289634`, 0.4066644072379688, 0.939287268625004], 
             UndirectedEdge[132, 216] -> 
             RGBColor[
              0.6582163236088057, 0.7286280804041076, 0.9692604007658963], 
             UndirectedEdge[225, 380] -> 
             RGBColor[
              0.7837333882429414, 0.8301607441569023, 0.9362945634368769], 
             UndirectedEdge[3, 371] -> 
             RGBColor[
              0.6928643135548986, 0.7585996926385485, 0.9710738596296189], 
             UndirectedEdge[269, 314] -> 
             RGBColor[
              0.5276430669557386, 0.6274034376607779, 0.9559571415324469], 
             UndirectedEdge[16, 206] -> 
             RGBColor[
              0.4073776657124394, 0.5261591591411083, 0.947486146149775], 
             UndirectedEdge[84, 256] -> 
             RGBColor[
              0.3309875678293026, 0.46105086067328205`, 0.9423132512940211], 
             UndirectedEdge[58, 348] -> 
             RGBColor[
              0.2641047605522857, 0.3949212269223941, 0.9383517474542482], 
             UndirectedEdge[177, 360] -> 
             RGBColor[
              0.5115569856606184, 0.612936160754609, 0.9550797853615653], 
             UndirectedEdge[2, 106] -> 
             RGBColor[
              0.689090626628406, 0.7557272835766758, 0.9705566674529365], 
             UndirectedEdge[256, 317] -> 
             RGBColor[
              0.6515369099068228, 0.7166902829218889, 0.8372738650075644], 
             UndirectedEdge[87, 351] -> 
             RGBColor[
              0.7578824922435857, 0.8107828301517491, 0.9765023020784261], 
             UndirectedEdge[48, 103] -> 
             RGBColor[
              0.5697458506736729, 0.6545363017116246, 0.9623552751100279], 
             UndirectedEdge[256, 381] -> 
             RGBColor[
              0.4358462129913746, 0.5488811317719127, 0.9498217309534805], 
             UndirectedEdge[91, 226] -> 
             RGBColor[
              0.47998664400446167`, 0.5845512554877367, 0.9533989804684364], 
             UndirectedEdge[105, 113] -> 
             RGBColor[
              0.8799984120412351, 0.905602282069367, 0.9152579019233682], 
             UndirectedEdge[223, 291] -> 
             RGBColor[
              0.5073056149875403, 0.6072565132910348, 0.9555716145826052], 
             UndirectedEdge[203, 348] -> 
             RGBColor[
              0.2514944389400974, 0.38166697936741467`, 0.9376336082937331], 
             UndirectedEdge[259, 367] -> 
             RGBColor[
              0.6807626963893108, 0.7477006329886904, 0.9709069494035956], 
             UndirectedEdge[188, 206] -> 
             RGBColor[
              0.7298016406065536, 0.747483896294427, 0.6365300058365898], 
             UndirectedEdge[250, 289] -> 
             RGBColor[
              0.5314199401938303, 0.6270834771178684, 0.9575566532830435], 
             UndirectedEdge[194, 377] -> 
             RGBColor[
              0.9738497380997818, 0.9291361059551908, 0.5499010115215929], 
             UndirectedEdge[83, 231] -> 
             RGBColor[
              0.3376561550450756, 0.46591714933248185`, 0.9427714765827395], 
             UndirectedEdge[276, 376] -> 
             RGBColor[
              0.6321501157727207, 0.7115458130243297, 0.964663702640955], 
             UndirectedEdge[83, 120] -> 
             RGBColor[
              0.5511775954387025, 0.6431665448994398, 0.9592515469464122], 
             UndirectedEdge[40, 243] -> 
             RGBColor[
              0.3547916905494565, 0.4817244628302403, 0.943827990685206], 
             UndirectedEdge[4, 392] -> 
             RGBColor[
              0.6503339083196267, 0.7225476003244757, 0.9684143140910677], 
             UndirectedEdge[81, 329] -> 
             RGBColor[
              0.3089098001001903, 0.43274987961642686`, 0.9412425390175353], 
             UndirectedEdge[131, 363] -> 
             RGBColor[
              0.45404174421884524`, 0.5656519232128779, 0.9507152073502476], 
             UndirectedEdge[167, 192] -> 
             RGBColor[
              0.7856063991198114, 0.8327370047137874, 0.9647564238648312], 
             UndirectedEdge[41, 327] -> 
             RGBColor[
              0.5381857341639449, 0.6218514920000128, 0.9604842151388309], 
             UndirectedEdge[24, 382] -> 
             RGBColor[
              0.7583481206394704, 0.8111465825935211, 0.9765487115653831], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.5352047043546936, 0.6259311888882938, 0.9591807334470905], 
             UndirectedEdge[90, 261] -> 
             RGBColor[
              0.41017134404988, 0.5292861019334254, 0.947468755663778], 
             UndirectedEdge[146, 297] -> 
             RGBColor[
              0.868288832928056, 0.8978224538154138, 0.9798714234169913], 
             UndirectedEdge[5, 291] -> 
             RGBColor[
              0.5028331776806303, 0.6033827128870244, 0.95528663483223], 
             UndirectedEdge[229, 315] -> 
             RGBColor[
              0.2898292386856726, 0.421959284466701, 0.9398167184279895], 
             UndirectedEdge[241, 360] -> 
             RGBColor[
              0.6633126530486748, 0.7326562094017371, 0.9697628568839349], 
             UndirectedEdge[59, 237] -> 
             RGBColor[
              0.5122829213771398, 0.6110449543075178, 0.9561099750774933], 
             UndirectedEdge[257, 381] -> 
             RGBColor[
              0.7497772532735012, 0.8041735259360077, 0.9759965489886256], 
             UndirectedEdge[270, 308] -> 
             RGBColor[
              0.4492261185546923, 0.5619729987924706, 0.9502723833732722], 
             UndirectedEdge[317, 382] -> 
             RGBColor[
              0.8546440713771434, 0.8844763745205417, 0.8529261143739573], 
             UndirectedEdge[23, 89] -> 
             RGBColor[
              0.34255230951355486`, 0.4683821726887894, 0.943148475204403], 
             UndirectedEdge[57, 327] -> 
             RGBColor[
              0.30941941591379685`, 0.43670828765734415`, 0.9411462365256245],
              UndirectedEdge[347, 362] -> 
             RGBColor[
              0.4787993796185105, 0.587749931897377, 0.9521119875449382], 
             UndirectedEdge[43, 293] -> 
             RGBColor[
              0.6494735442497949, 0.7229691977099386, 0.9678223496323258], 
             UndirectedEdge[73, 208] -> 
             RGBColor[
              0.6777313966715599, 0.7464973631707006, 0.9696716187692955], 
             UndirectedEdge[53, 129] -> 
             RGBColor[
              0.9678121060293978, 0.9742679667145235, 0.8835295828520545], 
             UndirectedEdge[324, 383] -> 
             RGBColor[
              0.6954449021768523, 0.7558338642775195, 0.8789205540040588], 
             UndirectedEdge[368, 399] -> 
             RGBColor[
              0.5686669256074247, 0.6607084542179881, 0.9591866899608534], 
             UndirectedEdge[51, 136] -> 
             RGBColor[
              0.7626099893619565, 0.8144759868309293, 0.9769734948102129], 
             UndirectedEdge[145, 359] -> 
             RGBColor[
              0.3222794311892698, 0.4412269741060385, 0.9422881961768015], 
             UndirectedEdge[222, 297] -> 
             RGBColor[
              0.7844462030116053, 0.8320572845207312, 0.9716970970666183], 
             UndirectedEdge[81, 209] -> 
             RGBColor[
              0.25381681443487597`, 0.38410794325953795`, 0.9377658641425142],
              UndirectedEdge[31, 345] -> 
             RGBColor[
              0.4613613093839727, 0.5640133134730726, 0.9524905202238803], 
             UndirectedEdge[155, 180] -> 
             RGBColor[
              0.8067530081041492, 0.8465004634272675, 0.8349302215538628], 
             UndirectedEdge[4, 369] -> 
             RGBColor[
              0.5720623664775588, 0.6608174757988075, 0.9607678611651334], 
             UndirectedEdge[102, 289] -> 
             RGBColor[
              0.30074292707507216`, 0.42853017801233134`, 0.9406176529489707],
              UndirectedEdge[70, 103] -> 
             RGBColor[
              0.7363633358511492, 0.7940346250943657, 0.9743596072206946], 
             UndirectedEdge[177, 375] -> 
             RGBColor[
              0.7166309012048715, 0.778239489151406, 0.9726076581863274], 
             UndirectedEdge[171, 253] -> 
             RGBColor[
              0.6570795003878784, 0.7289716593896158, 0.9685765024301582], 
             UndirectedEdge[150, 241] -> 
             RGBColor[
              0.775304500637504, 0.8249841078906743, 0.9781902662918548], 
             UndirectedEdge[24, 317] -> 
             RGBColor[
              0.898633960724736, 0.9188416104144228, 0.8573106154352368], 
             UndirectedEdge[80, 110] -> 
             RGBColor[
              0.3845287370379026, 0.5074811978711175, 0.945722808992012], 
             UndirectedEdge[176, 341] -> 
             RGBColor[
              0.6821643931340915, 0.751631275648545, 0.9689554295850582], 
             UndirectedEdge[154, 192] -> 
             RGBColor[
              0.45411774109990444`, 0.5614134376500173, 0.9514696152002432], 
             UndirectedEdge[121, 322] -> 
             RGBColor[
              0.9170608419749051, 0.933041259062503, 0.8332108796774654], 
             UndirectedEdge[268, 381] -> 
             RGBColor[
              0.7716056761845085, 0.8204531280022747, 0.9390467227647803], 
             UndirectedEdge[76, 104] -> 
             RGBColor[
              0.557880962451248, 0.651951923425701, 0.9583375794309144], 
             UndirectedEdge[91, 186] -> 
             RGBColor[
              0.273314540977293, 0.40460129008288215`, 0.9388762308248032], 
             UndirectedEdge[216, 357] -> 
             RGBColor[
              0.5853496531716381, 0.6709447384211873, 0.962199238910838], 
             UndirectedEdge[210, 236] -> 
             RGBColor[
              0.6428594146981276, 0.7192608842888919, 0.96617627597904], 
             UndirectedEdge[26, 173] -> 
             RGBColor[
              0.5533693166647795, 0.6429376685857902, 0.9602915481910497], 
             UndirectedEdge[10, 374] -> 
             RGBColor[
              0.6275479970910719, 0.6646590411273221, 0.640291762618511], 
             UndirectedEdge[289, 340] -> 
             RGBColor[
              0.5099374648923374, 0.6103012041394827, 0.9554154809101363], 
             UndirectedEdge[65, 168] -> 
             RGBColor[
              0.6159634125863849, 0.6821921221504111, 0.9106787853724962], 
             UndirectedEdge[40, 203] -> 
             RGBColor[
              0.2606061309823421, 0.38995832560024385`, 0.9381995785153077], 
             UndirectedEdge[167, 201] -> 
             RGBColor[
              0.8996595387664902, 0.9224108304924736, 0.9758241164452541], 
             UndirectedEdge[41, 57] -> 
             RGBColor[
              0.6006933185422773, 0.6817094112263025, 0.9642578160830559], 
             UndirectedEdge[214, 363] -> 
             RGBColor[
              0.5021860151230595, 0.6067362561558931, 0.953953069159925], 
             UndirectedEdge[22, 189] -> 
             RGBColor[
              0.6517036572689128, 0.7252809008514312, 0.9677215707512141], 
             UndirectedEdge[41, 96] -> 
             RGBColor[
              0.6024397696141837, 0.6832220993656046, 0.9643690984010318], 
             UndirectedEdge[31, 197] -> 
             RGBColor[
              0.27010433036255527`, 0.4012271551876839, 0.9386934140793749], 
             UndirectedEdge[275, 281] -> 
             RGBColor[
              0.4860800816655907, 0.5929411529658185, 0.9528839734117147], 
             UndirectedEdge[89, 353] -> 
             RGBColor[
              0.32914066227709315`, 0.45428568109571954`, 0.9423847017350405],
              UndirectedEdge[324, 375] -> 
             RGBColor[
              0.9009371483240856, 0.9214995296167103, 0.8964750824849275], 
             UndirectedEdge[5, 174] -> 
             RGBColor[
              0.36937916545169286`, 0.4943594004027504, 0.9447574916867789], 
             UndirectedEdge[36, 314] -> 
             RGBColor[
              0.4683502625707534, 0.5761899140192468, 0.9521395663135982], 
             UndirectedEdge[220, 357] -> 
             RGBColor[
              0.6810152772661473, 0.7499902070508162, 0.9693491429580852], 
             UndirectedEdge[291, 342] -> 
             RGBColor[
              0.74779938817172, 0.8029058326163783, 0.9754973124965074], 
             UndirectedEdge[21, 159] -> 
             RGBColor[
              0.8571422234583668, 0.4068772247938594, 0.44010682409550195`], 
             UndirectedEdge[220, 394] -> 
             RGBColor[
              0.6287240163241555, 0.7091398765746295, 0.9641372387570041], 
             UndirectedEdge[129, 249] -> 
             RGBColor[
              0.6073019977246041, 0.6797652886931437, 0.9592638306932927], 
             UndirectedEdge[37, 58] -> 
             RGBColor[
              0.45576301490386595`, 0.554264765770516, 0.9527834945307411], 
             UndirectedEdge[118, 259] -> 
             RGBColor[
              0.709521391525001, 0.425642267464664, 0.4447993500366912], 
             UndirectedEdge[201, 243] -> 
             RGBColor[
              0.6171853404065416, 0.6953757106431272, 0.9655932926355058], 
             UndirectedEdge[40, 110] -> 
             RGBColor[
              0.3744480953290634, 0.49874985269070526`, 0.9450804794162861], 
             UndirectedEdge[35, 278] -> 
             RGBColor[
              0.4755036199633433, 0.5794534779857932, 0.9532047622231448], 
             UndirectedEdge[164, 315] -> 
             RGBColor[
              0.616560583421538, 0.6886257136164821, 0.954799151334996], 
             UndirectedEdge[81, 304] -> 
             RGBColor[
              0.4666662306777982, 0.5607707449204257, 0.9541887061624158], 
             UndirectedEdge[12, 299] -> 
             RGBColor[
              0.32160313805237223`, 0.44746229453279246`, 0.9419152100346668],
              UndirectedEdge[203, 258] -> 
             RGBColor[
              0.5686951658882006, 0.6399651150919567, 0.9615248036693804], 
             UndirectedEdge[250, 276] -> 
             RGBColor[
              0.6386326945645315, 0.716610052845916, 0.9653098255117796], 
             UndirectedEdge[124, 238] -> 
             RGBColor[
              0.8445955799616938, 0.8789547758659878, 0.9850306721515824], 
             UndirectedEdge[96, 154] -> 
             RGBColor[
              0.3321616412157265, 0.4602888657213739, 0.9424531971255357], 
             UndirectedEdge[126, 238] -> 
             RGBColor[
              0.695955217014087, 0.7613887010786664, 0.9710246633181789], 
             UndirectedEdge[103, 108] -> 
             RGBColor[
              0.6427836866454268, 0.7180339784362175, 0.9670005412621265], 
             UndirectedEdge[122, 210] -> 
             RGBColor[
              0.6913918631726867, 0.7586617123224273, 0.9699969281031738], 
             UndirectedEdge[108, 234] -> 
             RGBColor[
              0.3580189244922143, 0.4803612479771814, 0.9441858896003748], 
             UndirectedEdge[222, 361] -> 
             RGBColor[
              0.5288102425174429, 0.6277903499298977, 0.9562039360820457], 
             UndirectedEdge[12, 274] -> 
             RGBColor[
              0.5083543278258114, 0.6101365949672768, 0.9548827839212617], 
             UndirectedEdge[141, 219] -> 
             RGBColor[
              0.9733013075199966, 0.9786745496091538, 0.8882431750082729], 
             UndirectedEdge[179, 344] -> 
             RGBColor[
              0.35628637657767864`, 0.4817307743361465, 0.9439704021121568], 
             UndirectedEdge[14, 230] -> 
             RGBColor[
              0.4034171595045958, 0.517711457223252, 0.9477095740652727], 
             UndirectedEdge[12, 118] -> 
             RGBColor[
              0.6961166516332449, 0.41403175551224175`, 0.4439452118641346], 
             UndirectedEdge[44, 49] -> 
             RGBColor[
              0.38671138908951136`, 0.5019233095774237, 0.9465970271869854], 
             UndirectedEdge[224, 247] -> 
             RGBColor[
              0.5344838112492509, 0.6318481802371874, 0.9568584339651898], 
             UndirectedEdge[161, 222] -> 
             RGBColor[
              0.7410039508501773, 0.7976301628630722, 0.9749228131284469], 
             UndirectedEdge[148, 168] -> 
             RGBColor[
              0.35642321217759765`, 0.47697721122729037`, 0.9442451083660703],
              UndirectedEdge[219, 323] -> 
             RGBColor[
              0.8889858735195095, 0.6053730545295027, 0.45293236396637626`], 
             UndirectedEdge[309, 334] -> 
             RGBColor[
              0.30158923813954536`, 0.434319789519752, 0.9404864329995275], 
             UndirectedEdge[170, 326] -> 
             RGBColor[
              0.586458950637438, 0.6745329918991576, 0.9610111243375192], 
             UndirectedEdge[239, 354] -> 
             RGBColor[
              0.5565467113113792, 0.6469707170788602, 0.9599518506619031], 
             UndirectedEdge[11, 221] -> 
             RGBColor[
              0.5384149751514495, 0.6301279520443864, 0.9592333295081571], 
             UndirectedEdge[47, 322] -> 
             RGBColor[
              0.9891376788373625, 0.9892828917413952, 0.7974240992106472], 
             UndirectedEdge[155, 271] -> 
             RGBColor[
              0.8166541987711553, 0.8545386960542993, 0.8357096795524259], 
             UndirectedEdge[106, 363] -> 
             RGBColor[
              0.5415189727812502, 0.638668523112362, 0.957049503668149], 
             UndirectedEdge[245, 378] -> 
             RGBColor[
              0.6968475847449346, 0.7626071878339638, 0.9707571479408377], 
             UndirectedEdge[155, 326] -> 
             RGBColor[
              0.7425924269184013, 0.7944120132194337, 0.8298792655749676], 
             UndirectedEdge[10, 39] -> 
             RGBColor[
              0.4215284163800309, 0.5344043084626128, 0.9489542785432663], 
             UndirectedEdge[25, 382] -> 
             RGBColor[
              0.7699814035715777, 0.8202800206584907, 0.9776961530231729], 
             UndirectedEdge[177, 383] -> 
             RGBColor[
              0.5111386550576382, 0.612573823812215, 0.9550531297054586], 
             UndirectedEdge[177, 296] -> 
             RGBColor[
              0.5135120797041091, 0.6146295649491968, 0.9552043622251948], 
             UndirectedEdge[103, 143] -> 
             RGBColor[
              0.8036511105452875, 0.8466452344443471, 0.9810355333501707], 
             UndirectedEdge[84, 317] -> 
             RGBColor[
              0.6743805693848888, 0.7365319800928367, 0.8387274045302677], 
             UndirectedEdge[50, 328] -> 
             RGBColor[
              0.8556850593988476, 0.8880368478203404, 0.9860248082710972], 
             UndirectedEdge[332, 385] -> 
             RGBColor[
              0.48877706054926373`, 0.5808928704679585, 0.955941472146224], 
             UndirectedEdge[242, 257] -> 
             RGBColor[
              0.9400119247774217, 0.9547815722372349, 0.9864283433427621], 
             UndirectedEdge[214, 217] -> 
             RGBColor[
              0.5050680214607014, 0.6090759987336967, 0.9541799512559612], 
             UndirectedEdge[51, 59] -> 
             RGBColor[
              0.7385517072273614, 0.7956814739776672, 0.9745755900844656], 
             UndirectedEdge[66, 131] -> 
             RGBColor[
              0.3317432205372179, 0.4594524818905187, 0.9424438900520047], 
             UndirectedEdge[66, 98] -> 
             RGBColor[
              0.33318048988094795`, 0.4606973723568, 0.9425354715836598], 
             UndirectedEdge[70, 346] -> 
             RGBColor[
              0.5679187517045783, 0.6601010529388072, 0.95912779097057], 
             UndirectedEdge[151, 253] -> 
             RGBColor[
              0.6405304582152719, 0.7157759023729623, 0.9669980400142306], 
             UndirectedEdge[384, 398] -> 
             RGBColor[
              0.3361766534593305, 0.4565169502348683, 0.9430174411055313], 
             UndirectedEdge[123, 218] -> 
             RGBColor[
              0.7528188131466493, 0.8016605045953672, 0.744319182681787], 
             UndirectedEdge[169, 280] -> 
             RGBColor[
              0.7268560507750057, 0.7807761035607403, 0.7581213358088814], 
             UndirectedEdge[71, 109] -> 
             RGBColor[
              0.5106715042676443, 0.6133570777706259, 0.9546951494559033], 
             UndirectedEdge[166, 302] -> 
             RGBColor[
              0.28339795344754104`, 0.41519959591438904`, 0.939450466247912], 
             UndirectedEdge[89, 163] -> 
             RGBColor[
              0.5991043208115509, 0.6818388808364249, 0.9635071576904115], 
             UndirectedEdge[102, 340] -> 
             RGBColor[
              0.4489357678130769, 0.5510846376976343, 0.9517621083928363], 
             UndirectedEdge[380, 390] -> 
             RGBColor[
              0.7365776855294932, 0.7938016959326519, 0.9748448711666667], 
             UndirectedEdge[172, 387] -> 
             RGBColor[
              0.2674673268257104, 0.3984554972747789, 0.9385432406290488], 
             UndirectedEdge[61, 298] -> 
             RGBColor[
              0.3755796729740618, 0.4933067107777097, 0.945682409375024], 
             UndirectedEdge[10, 216] -> 
             RGBColor[
              0.34339606445014326`, 0.4695931400411334, 0.9431846579073104], 
             UndirectedEdge[209, 229] -> 
             RGBColor[
              0.2974656714959333, 0.42998565952808987`, 0.940251601979444], 
             UndirectedEdge[39, 119] -> 
             RGBColor[
              0.47602089056047936`, 0.5838639549490319, 0.9523437043718453], 
             UndirectedEdge[33, 261] -> 
             RGBColor[
              0.5538392519541584, 0.6486706807671807, 0.95801940117531], 
             UndirectedEdge[102, 213] -> 
             RGBColor[
              0.5619532982764945, 0.6398935455531956, 0.9628889782346381], 
             UndirectedEdge[155, 335] -> 
             RGBColor[
              0.8019223123099988, 0.8425786869612106, 0.8345499314855254], 
             UndirectedEdge[76, 317] -> 
             RGBColor[
              0.7419501945366882, 0.7940893448959199, 0.8433003559403376], 
             UndirectedEdge[19, 179] -> 
             RGBColor[
              0.6281744612405771, 0.6990156535048171, 0.9450461481539436], 
             UndirectedEdge[48, 83] -> 
             RGBColor[
              0.341600696981438, 0.4700631130060025, 0.9429961124105886], 
             UndirectedEdge[288, 355] -> 
             RGBColor[
              0.4996083322759059, 0.603869516897202, 0.9539640196634303], 
             UndirectedEdge[7, 192] -> 
             RGBColor[
              0.4984392620176621, 0.6016370971999063, 0.9542265701482325], 
             UndirectedEdge[341, 393] -> 
             RGBColor[
              0.7585084136330287, 0.8116365615688421, 0.9764678928147782], 
             UndirectedEdge[244, 270] -> 
             RGBColor[
              0.612489712957887, 0.6916752388990562, 0.9651253046922497], 
             UndirectedEdge[121, 265] -> 
             RGBColor[
              0.8903322581827131, 0.9152437124720294, 0.9843025566638393], 
             UndirectedEdge[156, 363] -> 
             RGBColor[
              0.4983119221136074, 0.6035910929249186, 0.9536480863669505], 
             UndirectedEdge[133, 280] -> 
             RGBColor[
              0.9473302009477984, 0.9564606711827968, 0.7780118827292124], 
             UndirectedEdge[44, 362] -> 
             RGBColor[
              0.5110245486221006, 0.6139117758218113, 0.9546488708935844], 
             UndirectedEdge[116, 147] -> 
             RGBColor[
              0.2511164995560199, 0.3812697411120083, 0.9376120852049211], 
             UndirectedEdge[83, 196] -> 
             RGBColor[
              0.5362883321448437, 0.6315349392516851, 0.9577675243293569], 
             UndirectedEdge[109, 233] -> 
             RGBColor[
              0.6523132345989722, 0.7273238667310818, 0.9666552748160655], 
             UndirectedEdge[19, 125] -> 
             RGBColor[
              0.6730659885457552, 0.7391867485494303, 0.9478594252228792], 
             UndirectedEdge[26, 160] -> 
             RGBColor[
              0.7586686400620533, 0.8113969748024807, 0.9765806579460019], 
             UndirectedEdge[224, 302] -> 
             RGBColor[
              0.461606575475983, 0.5653115868294825, 0.95233976401426], 
             UndirectedEdge[58, 60] -> 
             RGBColor[
              0.4563499023621506, 0.5547232467134379, 0.9528419899878078], 
             UndirectedEdge[165, 332] -> 
             RGBColor[
              0.82537940825972, 0.8641844725537637, 0.9830512928027118], 
             UndirectedEdge[43, 252] -> 
             RGBColor[
              0.41638182881851726`, 0.5350707449885423, 0.9477524598336897], 
             UndirectedEdge[292, 304] -> 
             RGBColor[
              0.5802632823196803, 0.6683967972963213, 0.961088908023114], 
             UndirectedEdge[63, 257] -> 
             RGBColor[
              0.6219277093280866, 0.6963467998210724, 0.9670261447458484], 
             UndirectedEdge[94, 355] -> 
             RGBColor[
              0.39802856475758985`, 0.50783364656276, 0.9477862911470114], 
             UndirectedEdge[223, 290] -> 
             RGBColor[
              0.41659723360475664`, 0.5341329254639169, 0.9480768581854182], 
             UndirectedEdge[141, 150] -> 
             RGBColor[
              0.8076329510973023, 0.8484322435466816, 0.891055875946637], 
             UndirectedEdge[131, 306] -> 
             RGBColor[
              0.45944213532779443`, 0.5700362039999699, 0.9511403459206286], 
             UndirectedEdge[151, 182] -> 
             RGBColor[
              0.6111806001921718, 0.6903545305201095, 0.9651278930140591], 
             UndirectedEdge[87, 201] -> 
             RGBColor[
              0.8193716572629277, 0.8590405367447727, 0.9825720810207158], 
             UndirectedEdge[72, 379] -> 
             RGBColor[
              0.7823133722845765, 0.8300820158812596, 0.9788806619218464], 
             UndirectedEdge[23, 378] -> 
             RGBColor[
              0.5313643105317578, 0.6207887779423873, 0.9591371110434719], 
             UndirectedEdge[116, 322] -> 
             RGBColor[
              0.6428558914465307, 0.7072240645798695, 0.8108829884514415], 
             UndirectedEdge[90, 175] -> 
             RGBColor[
              0.47940422509109154`, 0.585492473668429, 0.9529190216677417], 
             UndirectedEdge[348, 369] -> 
             RGBColor[
              0.5200488710489632, 0.6153667437800567, 0.9574682259683558], 
             UndirectedEdge[134, 243] -> 
             RGBColor[
              0.4803959235481518, 0.587243550766358, 0.9527357170272492], 
             UndirectedEdge[211, 372] -> 
             RGBColor[
              0.5399078253435817, 0.6373605210410977, 0.9569226682400283], 
             UndirectedEdge[73, 188] -> 
             RGBColor[
              0.8949644238973327, 0.878815942312895, 0.6514311992784021], 
             UndirectedEdge[55, 228] -> 
             RGBColor[
              0.6562293689774403, 0.723940608416469, 0.9371089574005667], 
             UndirectedEdge[260, 384] -> 
             RGBColor[
              0.4405097605967522, 0.5408174894571294, 0.9515056228217602], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.44297816880018837`, 0.5577416980308146, 0.9495481327525399], 
             UndirectedEdge[153, 203] -> 
             RGBColor[
              0.2713541624793248, 0.39926773027115986`, 0.9388844335781843], 
             UndirectedEdge[65, 148] -> 
             RGBColor[
              0.7263178071320948, 0.783205026009475, 0.9175992665518485], 
             UndirectedEdge[42, 366] -> 
             RGBColor[
              0.4574674586606481, 0.5693740853019827, 0.950724887505443], 
             UndirectedEdge[48, 313] -> 
             RGBColor[
              0.2849757990436411, 0.41685801167707914`, 0.9395403222203964], 
             UndirectedEdge[166, 213] -> 
             RGBColor[
              0.5895702781701524, 0.6689207424390892, 0.9644617243839215], 
             UndirectedEdge[11, 78] -> 
             RGBColor[
              0.3074920613089446, 0.44052403093139575`, 0.9408225900465804], 
             UndirectedEdge[228, 348] -> 
             RGBColor[
              0.32216491100619016`, 0.45306552970668934`, 0.9417636598816417],
              UndirectedEdge[199, 336] -> 
             RGBColor[
              0.4948155341277691, 0.58746268299074, 0.9562500510717529], 
             UndirectedEdge[249, 309] -> 
             RGBColor[
              0.2888666972453807, 0.42094759238430207`, 0.9397619031169173], 
             UndirectedEdge[190, 273] -> 
             RGBColor[
              0.5888203088181978, 0.677069878608061, 0.9607732381114806], 
             UndirectedEdge[298, 314] -> 
             RGBColor[
              0.5476476107581034, 0.6436440275139661, 0.9575319724996276], 
             UndirectedEdge[7, 385] -> 
             RGBColor[
              0.3037668215883765, 0.43024749870983164`, 0.9408433530550298], 
             UndirectedEdge[27, 194] -> 
             RGBColor[
              0.691190562184282, 0.7521439477618352, 0.8784649215438558], 
             UndirectedEdge[39, 128] -> 
             RGBColor[
              0.6973668791148635, 0.7623562224899008, 0.9713119028594868], 
             UndirectedEdge[116, 265] -> 
             RGBColor[
              0.6161273076543385, 0.6894265179893959, 0.9619746654378152], 
             UndirectedEdge[231, 313] -> 
             RGBColor[
              0.2810312571072787, 0.41271204800355854`, 0.9393156863925474], 
             UndirectedEdge[96, 284] -> 
             RGBColor[
              0.5455596851274069, 0.6387103570152706, 0.9587201472661738], 
             UndirectedEdge[279, 300] -> 
             RGBColor[
              0.7749093966775094, 0.824191989125723, 0.9781708279184176], 
             UndirectedEdge[22, 190] -> 
             RGBColor[
              0.5224018631647117, 0.6231483923096822, 0.9555445347708552], 
             UndirectedEdge[24, 207] -> 
             RGBColor[
              0.6428243919514349, 0.7184621517556607, 0.966700176828233], 
             UndirectedEdge[315, 329] -> 
             RGBColor[
              0.3462177718281807, 0.4719629233645749, 0.9433671728152462], 
             UndirectedEdge[239, 335] -> 
             RGBColor[
              0.67701507725814, 0.7470938426173341, 0.9687941301479789], 
             UndirectedEdge[142, 300] -> 
             RGBColor[
              0.6945757752887628, 0.7601096009216699, 0.9710699373803455], 
             UndirectedEdge[13, 88] -> 
             RGBColor[
              0.34845234423145227`, 0.4754565581074456, 0.9434525059062808], 
             UndirectedEdge[18, 302] -> 
             RGBColor[
              0.3185776484486082, 0.4469436850358911, 0.9416454670150936], 
             UndirectedEdge[148, 251] -> 
             RGBColor[
              0.40475773401346693`, 0.5246370784334649, 0.9471127604449335], 
             UndirectedEdge[90, 257] -> 
             RGBColor[
              0.6440494400071093, 0.7155904251110742, 0.968432686706134], 
             UndirectedEdge[134, 348] -> 
             RGBColor[
              0.43914362273993585`, 0.5511136246544119, 0.9501217756359315], 
             UndirectedEdge[158, 322] -> 
             RGBColor[
              0.7225248103542553, 0.7778836951031671, 0.8158988451962002], 
             UndirectedEdge[40, 385] -> 
             RGBColor[
              0.27631915156460596`, 0.4064737064952495, 0.9390944117921367], 
             UndirectedEdge[228, 385] -> 
             RGBColor[
              0.2849446728295556, 0.41394469948364465`, 0.9396440223798903], 
             UndirectedEdge[175, 214] -> 
             RGBColor[
              0.5413567710516951, 0.6385368404412046, 0.957036734553834], 
             UndirectedEdge[7, 41] -> 
             RGBColor[
              0.6035030293117258, 0.6841430414746293, 0.9644368483687555], 
             UndirectedEdge[176, 379] -> 
             RGBColor[
              0.7794175415997947, 0.8278197709411798, 0.9785920325822637], 
             UndirectedEdge[259, 336] -> 
             RGBColor[
              0.5901240155411539, 0.6760264877379478, 0.9621028802343827], 
             UndirectedEdge[213, 340] -> 
             RGBColor[
              0.7711478360937597, 0.821664571680347, 0.9776868061958038], 
             UndirectedEdge[55, 165] -> 
             RGBColor[
              0.9378742652040677, 0.9523490410580053, 0.9609835597459748], 
             UndirectedEdge[108, 231] -> 
             RGBColor[
              0.37528703058772434`, 0.49851112234472506`, 0.9451692826966405],
              UndirectedEdge[38, 230] -> 
             RGBColor[
              0.5880140635454953, 0.6764153323747455, 0.9607097675302397], 
             UndirectedEdge[39, 316] -> 
             RGBColor[
              0.7108558569217315, 0.7731119672445488, 0.9725984936044585], 
             UndirectedEdge[85, 167] -> 
             RGBColor[
              0.9154133191927465, 0.9349724673793924, 0.9773267260858762], 
             UndirectedEdge[28, 328] -> 
             RGBColor[
              0.5849603626254306, 0.6588784284874152, 0.964986506311845], 
             UndirectedEdge[79, 120] -> 
             RGBColor[
              0.5288739730487161, 0.6238482681978899, 0.9578303798500413], 
             UndirectedEdge[130, 347] -> 
             RGBColor[
              0.5640828277733975, 0.6565903363701111, 0.9590969300397804], 
             UndirectedEdge[77, 160] -> 
             RGBColor[
              0.576569541904789, 0.6644566417293041, 0.9611670976702555], 
             UndirectedEdge[108, 179] -> 
             RGBColor[
              0.37354061284461265`, 0.4966755265674343, 0.9450698267897637], 
             UndirectedEdge[318, 373] -> 
             RGBColor[
              0.3042912505587183, 0.43701548867733375`, 0.9406455916711864], 
             UndirectedEdge[48, 331] -> 
             RGBColor[
              0.3154946268039336, 0.44745134714748713`, 0.9413326567035694], 
             UndirectedEdge[222, 312] -> 
             RGBColor[
              0.6862090859344288, 0.7545243508286092, 0.9695408902093678], 
             UndirectedEdge[292, 353] -> 
             RGBColor[
              0.34417064566505323`, 0.4673038972774405, 0.9433423989860289], 
             UndirectedEdge[175, 204] -> 
             RGBColor[
              0.47555462380767116`, 0.5821581425233167, 0.9526737284780309], 
             UndirectedEdge[198, 340] -> 
             RGBColor[
              0.5722269541252356, 0.66335704945863, 0.9596321291478822], 
             UndirectedEdge[14, 207] -> 
             RGBColor[
              0.3754851317404584, 0.49503497876081415`, 0.9455106625212908], 
             UndirectedEdge[45, 271] -> 
             RGBColor[
              0.7246173130838783, 0.7847324184579423, 0.9732300874486615], 
             UndirectedEdge[112, 183] -> 
             RGBColor[
              0.8351510401901345, 0.8719987983365456, 0.9798001315445355], 
             UndirectedEdge[85, 139] -> 
             RGBColor[
              0.5657515655281714, 0.644547824552262, 0.96300498650901], 
             UndirectedEdge[45, 97] -> 
             RGBColor[
              0.6163021969328807, 0.6959358375658845, 0.9649411570043838], 
             UndirectedEdge[130, 181] -> 
             RGBColor[
              0.7109750750428131, 0.7741383993249308, 0.9718270091065895], 
             UndirectedEdge[63, 90] -> 
             RGBColor[
              0.329971160419706, 0.4601432731016224, 0.9422494836103745], 
             UndirectedEdge[114, 361] -> 
             RGBColor[
              0.6439919967836238, 0.7183234440575021, 0.9674260739052407], 
             UndirectedEdge[75, 209] -> 
             RGBColor[
              0.37353267395628015`, 0.49703379948044946`, 0.9450559510306461],
              UndirectedEdge[42, 276] -> 
             RGBColor[
              0.49526817609332197`, 0.6000624106167416, 0.9537006984503336], 
             UndirectedEdge[205, 358] -> 
             RGBColor[
              0.4053099104272018, 0.5246088665553695, 0.947287886386919], 
             UndirectedEdge[76, 358] -> 
             RGBColor[
              0.4070797233763453, 0.526045680436649, 0.947427212545314], 
             UndirectedEdge[90, 142] -> 
             RGBColor[
              0.4539732384406206, 0.5648464530526838, 0.9509170012418431], 
             UndirectedEdge[152, 381] -> 
             RGBColor[
              0.49930906304568334`, 0.6039051302401219, 0.9538634893815622], 
             UndirectedEdge[86, 309] -> 
             RGBColor[
              0.2952722354086342, 0.4276802191284582, 0.9401266890391702], 
             UndirectedEdge[104, 358] -> 
             RGBColor[
              0.47599020821662585`, 0.5819903164119535, 0.9528520983393642], 
             UndirectedEdge[16, 369] -> 
             RGBColor[
              0.5280649907704619, 0.6227091603337216, 0.9579643872904289], 
             UndirectedEdge[278, 337] -> 
             RGBColor[
              0.5663902257860609, 0.6586689779176941, 0.9591381493040709], 
             UndirectedEdge[100, 350] -> 
             RGBColor[
              0.4632555109697294, 0.5543436953348453, 0.9544444274533139], 
             UndirectedEdge[90, 202] -> 
             RGBColor[
              0.6444813999281553, 0.7159125801129209, 0.9677014912329938], 
             UndirectedEdge[126, 367] -> 
             RGBColor[
              0.7516109388798675, 0.8057338928920409, 0.9763419580703674], 
             UndirectedEdge[278, 327] -> 
             RGBColor[
              0.45087447372170575`, 0.553566683707768, 0.9518021687802403], 
             UndirectedEdge[10, 200] -> 
             RGBColor[
              0.42239349676065885`, 0.5351066196870335, 0.9490223808397231], 
             UndirectedEdge[149, 299] -> 
             RGBColor[
              0.5864792949987803, 0.6606353351209338, 0.9650487058883365], 
             UndirectedEdge[57, 284] -> 
             RGBColor[
              0.5438132340555006, 0.6371976688759684, 0.9586088649481981], 
             UndirectedEdge[125, 313] -> 
             RGBColor[
              0.32417636666934513`, 0.45104754727088103`, 0.9420295075546063],
              UndirectedEdge[125, 196] -> 
             RGBColor[
              0.5400819393414424, 0.6348207711331373, 0.958009249625369], 
             UndirectedEdge[21, 210] -> 
             RGBColor[
              0.795563726069342, 0.35816097524091406`, 0.43478576351113274`], 
             UndirectedEdge[186, 374] -> 
             RGBColor[
              0.6047190205737729, 0.6406643393669293, 0.6389916861782949], 
             UndirectedEdge[6, 74] -> 
             RGBColor[
              0.5735596436136434, 0.6507752088865707, 0.9637495106027723], 
             UndirectedEdge[7, 312] -> 
             RGBColor[
              0.562506836620928, 0.6520399161173628, 0.9603710551247125], 
             UndirectedEdge[238, 299] -> 
             RGBColor[
              0.5324834015539839, 0.6176136454356098, 0.9598897270526878], 
             UndirectedEdge[155, 239] -> 
             RGBColor[
              0.8701809476153789, 0.8964175999792834, 0.8410013780932091], 
             UndirectedEdge[108, 331] -> 
             RGBColor[
              0.38853246277568754`, 0.5109490238720802, 0.945977922855668], 
             UndirectedEdge[55, 87] -> 
             RGBColor[
              0.881930773334848, 0.9079730214088362, 0.9555861063677664], 
             UndirectedEdge[186, 288] -> 
             RGBColor[
              0.33172165143271626`, 0.4552599605396669, 0.942595340389713], 
             UndirectedEdge[178, 371] -> 
             RGBColor[
              0.7783598173253135, 0.8270220435531889, 0.9784790256238608], 
             UndirectedEdge[212, 238] -> 
             RGBColor[
              0.6890482184974298, 0.755781288526107, 0.9704809190937785], 
             UndirectedEdge[292, 329] -> 
             RGBColor[
              0.4225068517420725, 0.5403759319923225, 0.9481427408782335], 
             UndirectedEdge[268, 338] -> 
             RGBColor[
              0.755627551709817, 0.8074813667474153, 0.9377888662763341], 
             UndirectedEdge[68, 309] -> 
             RGBColor[
              0.2896478162535745, 0.4217685979877193, 0.939806386688872], 
             UndirectedEdge[129, 309] -> 
             RGBColor[
              0.625491417943886, 0.698883522619461, 0.9602996912659449], 
             UndirectedEdge[137, 330] -> 
             RGBColor[
              0.7013361772814594, 0.7650856211870474, 0.9721918793892306], 
             UndirectedEdge[111, 400] -> 
             RGBColor[
              0.33057076072805125`, 0.46062957559866713`, 0.9422888994102934],
              UndirectedEdge[62, 370] -> 
             RGBColor[
              0.32903004383668377`, 0.4594110192656488, 0.9421864813367978], 
             UndirectedEdge[163, 280] -> 
             RGBColor[
              0.8929967774619441, 0.9133612249303906, 0.772769923416762], 
             UndirectedEdge[316, 383] -> 
             RGBColor[
              0.6317883472212227, 0.7074908121645536, 0.9667692855422861], 
             UndirectedEdge[307, 314] -> 
             RGBColor[
              0.5552850417354699, 0.6498444380437367, 0.9581332190429974], 
             UndirectedEdge[126, 259] -> 
             RGBColor[
              0.5051820633501096, 0.6086531181044825, 0.954331353558993], 
             UndirectedEdge[44, 372] -> 
             RGBColor[
              0.5684452894655087, 0.6605285200133862, 0.9591692419518818], 
             UndirectedEdge[202, 279] -> 
             RGBColor[
              0.8266953686587939, 0.8654545229780335, 0.9820633574422487], 
             UndirectedEdge[148, 312] -> 
             RGBColor[
              0.6071224290670687, 0.690318239970396, 0.9633148988767996], 
             UndirectedEdge[109, 358] -> 
             RGBColor[
              0.45154359273866596`, 0.5621434526594687, 0.9509275712180361], 
             UndirectedEdge[142, 275] -> 
             RGBColor[
              0.4913349878902532, 0.5972073225698271, 0.9532976588790758], 
             UndirectedEdge[296, 375] -> 
             RGBColor[
              0.608496185444769, 0.6891491548169371, 0.9644545610238846], 
             UndirectedEdge[92, 195] -> 
             RGBColor[
              0.7518847543219114, 0.8031624163228859, 0.8862102712713427], 
             UndirectedEdge[178, 248] -> 
             RGBColor[
              0.6320280258326607, 0.7111610991911359, 0.9648493546270271], 
             UndirectedEdge[41, 222] -> 
             RGBColor[
              0.7272052786252265, 0.7866274761858758, 0.973606683453411], 
             UndirectedEdge[154, 356] -> 
             RGBColor[
              0.4166216697649776, 0.5309724377615598, 0.9485177871121228], 
             UndirectedEdge[70, 133] -> 
             RGBColor[
              0.7701488245488135, 0.8209742566992232, 0.9775820972933397], 
             UndirectedEdge[7, 80] -> 
             RGBColor[
              0.36017939351609496`, 0.4863910203461177, 0.9441712903540815], 
             UndirectedEdge[152, 261] -> 
             RGBColor[
              0.45165970273044276`, 0.5652212329569897, 0.9501123571921883], 
             UndirectedEdge[95, 229] -> 
             RGBColor[
              0.3319710093118466, 0.4607956100830957, 0.9424164501384436], 
             UndirectedEdge[30, 204] -> 
             RGBColor[
              0.4228380303891524, 0.5393604371306933, 0.9485236851368807], 
             UndirectedEdge[133, 223] -> 
             RGBColor[
              0.6196674517367662, 0.6956881970170621, 0.9665973038227951], 
             UndirectedEdge[298, 306] -> 
             RGBColor[
              0.5188828375801245, 0.6202914888098183, 0.9552675041862211], 
             UndirectedEdge[40, 96] -> 
             RGBColor[
              0.34903549210971363`, 0.4767387330566808, 0.943461210810632], 
             UndirectedEdge[122, 146] -> 
             RGBColor[
              0.7116833642141384, 0.774513587157129, 0.9720193952921273], 
             UndirectedEdge[223, 267] -> 
             RGBColor[
              0.32216013440483837`, 0.45319329228062843`, 0.941758526022072], 
             UndirectedEdge[54, 322] -> 
             RGBColor[
              0.9787711667491914, 0.9815515639996428, 0.8149719001565487], 
             UndirectedEdge[41, 154] -> 
             RGBColor[
              0.5591815083939682, 0.6439193819247404, 0.9616798934207662], 
             UndirectedEdge[245, 353] -> 
             RGBColor[
              0.43116969959935575`, 0.538402066837735, 0.9500618578240407], 
             UndirectedEdge[26, 62] -> 
             RGBColor[
              0.5539173157784151, 0.6434123178747849, 0.960326466209994], 
             UndirectedEdge[217, 269] -> 
             RGBColor[
              0.4963599090064523, 0.6020063607473418, 0.9534944167446957], 
             UndirectedEdge[172, 347] -> 
             RGBColor[
              0.3633617562743406, 0.48509021692851484`, 0.9445655924940906], 
             UndirectedEdge[63, 261] -> 
             RGBColor[
              0.3880496133708574, 0.5100424766434235, 0.9460622137034923], 
             UndirectedEdge[195, 369] -> 
             RGBColor[
              0.624784821516566, 0.704838084007905, 0.9645817891132951], 
             UndirectedEdge[65, 180] -> 
             RGBColor[
              0.8021379205409714, 0.8447592097319854, 0.9235681036176221], 
             UndirectedEdge[49, 211] -> 
             RGBColor[
              0.35817392496758443`, 0.47875531060513526`, 0.9443504534751318],
              UndirectedEdge[285, 387] -> 
             RGBColor[
              0.521653610953196, 0.6117230471723696, 0.9584034909087215], 
             UndirectedEdge[329, 388] -> 
             RGBColor[
              0.3563355100771526, 0.48259730776590076`, 0.9439433630406728], 
             UndirectedEdge[38, 102] -> 
             RGBColor[
              0.43829726382136025`, 0.5426894171855895, 0.9507594256871914], 
             UndirectedEdge[92, 188] -> 
             RGBColor[
              0.9775888984699215, 0.942358229802021, 0.5686367291352913], 
             UndirectedEdge[114, 153] -> 
             RGBColor[
              0.5997307868839201, 0.6799866086754724, 0.9646057887490829], 
             UndirectedEdge[326, 337] -> 
             RGBColor[
              0.4840200034168698, 0.591988269483307, 0.9525229741741201], 
             UndirectedEdge[38, 221] -> 
             RGBColor[
              0.7030955933204317, 0.7678985479790366, 0.971099319956223], 
             UndirectedEdge[350, 394] -> 
             RGBColor[
              0.4223012933980239, 0.5223499493042472, 0.9503624937846891], 
             UndirectedEdge[286, 349] -> 
             RGBColor[
              0.6021439905713244, 0.687886643680272, 0.9618221271453412], 
             UndirectedEdge[246, 320] -> 
             RGBColor[
              0.7767013472791418, 0.8257281351916602, 0.9783132734243314], 
             UndirectedEdge[322, 362] -> 
             RGBColor[
              0.7462689213717277, 0.7972451694621343, 0.8177446006958704], 
             UndirectedEdge[80, 348] -> 
             RGBColor[
              0.3236200314500797, 0.4543258818987064, 0.9418563788696139], 
             UndirectedEdge[78, 230] -> 
             RGBColor[
              0.4233334453765132, 0.5386447364400953, 0.9488437770821738], 
             UndirectedEdge[248, 329] -> 
             RGBColor[
              0.4831147864858669, 0.5900486020873916, 0.9527845941397135], 
             UndirectedEdge[43, 330] -> 
             RGBColor[
              0.6723853378766398, 0.7412384400239147, 0.9700076969620539], 
             UndirectedEdge[63, 217] -> 
             RGBColor[
              0.42099374482107527`, 0.5367880066709193, 0.9486556964095832], 
             UndirectedEdge[79, 136] -> 
             RGBColor[
              0.5344841538145767, 0.6282309840511332, 0.9583895502386622], 
             UndirectedEdge[159, 243] -> 
             RGBColor[
              0.6618604848452639, 0.7309703585454677, 0.9688802170707276], 
             UndirectedEdge[1, 327] -> 
             RGBColor[
              0.592324591936251, 0.6649677841332606, 0.9638256183811141], 
             UndirectedEdge[304, 353] -> 
             RGBColor[
              0.4883674148043443, 0.5835800653719695, 0.9554245564943977], 
             UndirectedEdge[240, 329] -> 
             RGBColor[
              0.5149888739905143, 0.615925422234943, 0.9552938390667091], 
             UndirectedEdge[10, 311] -> 
             RGBColor[
              0.5728392583956293, 0.654224680331831, 0.9630712084203902], 
             UndirectedEdge[353, 378] -> 
             RGBColor[
              0.517952663295296, 0.6066922863493175, 0.9583733375741095], 
             UndirectedEdge[167, 243] -> 
             RGBColor[
              0.6694064976753763, 0.7365981625587035, 0.9561067856646976], 
             UndirectedEdge[169, 292] -> 
             RGBColor[
              0.44799357751257274`, 0.5622719756484954, 0.9498162673335193], 
             UndirectedEdge[211, 347] -> 
             RGBColor[
              0.46360834672641926`, 0.5754171670473444, 0.9509160937890859], 
             UndirectedEdge[224, 340] -> 
             RGBColor[
              0.6547613697351767, 0.7302238254986213, 0.9662241523084676], 
             UndirectedEdge[144, 233] -> 
             RGBColor[
              0.8609186030918088, 0.8891958861090263, 0.8412075377958301], 
             UndirectedEdge[273, 394] -> 
             RGBColor[
              0.6316791777838864, 0.7115390097761456, 0.9643698798922271], 
             UndirectedEdge[93, 94] -> 
             RGBColor[
              0.419632880919976, 0.5253730036867369, 0.9494870620545321], 
             UndirectedEdge[358, 366] -> 
             RGBColor[
              0.41287883358605526`, 0.5307536593518293, 0.947883739743863], 
             UndirectedEdge[245, 329] -> 
             RGBColor[
              0.509505905676375, 0.6114741015526169, 0.9548621997162453], 
             UndirectedEdge[44, 93] -> 
             RGBColor[
              0.5709931597682347, 0.6625969959053885, 0.9593698196352689], 
             UndirectedEdge[218, 314] -> 
             RGBColor[
              0.5544209616420772, 0.649142938897556, 0.9580651954928158], 
             UndirectedEdge[133, 346] -> 
             RGBColor[
              0.6986388693461062, 0.7629192535788953, 0.9719525716701856], 
             UndirectedEdge[143, 272] -> 
             RGBColor[
              0.7890666821734633, 0.8351441563335911, 0.9796104506978127], 
             UndirectedEdge[272, 346] -> 
             RGBColor[
              0.6502689522766179, 0.7244785438632817, 0.9673049989451825], 
             UndirectedEdge[61, 269] -> 
             RGBColor[
              0.35557512917169687`, 0.4770661209245215, 0.9441075784078434], 
             UndirectedEdge[158, 362] -> 
             RGBColor[
              0.4739340063747923, 0.5837150673405884, 0.951752435437913], 
             UndirectedEdge[294, 393] -> 
             RGBColor[
              0.5838526089154632, 0.6653278755251159, 0.9637699881628594], 
             UndirectedEdge[17, 298] -> 
             RGBColor[
              0.38884445916940397`, 0.5072488421050351, 0.9464378193253562], 
             UndirectedEdge[83, 179] -> 
             RGBColor[
              0.33590973730196394`, 0.4640815535551911, 0.9426720206758628], 
             UndirectedEdge[223, 398] -> 
             RGBColor[
              0.39919330156397353`, 0.5200036293950056, 0.9467067569024641], 
             UndirectedEdge[52, 272] -> 
             RGBColor[
              0.7611726145445106, 0.8133530986990872, 0.9768302307214414], 
             UndirectedEdge[52, 174] -> 
             RGBColor[
              0.5637266826358358, 0.6543388122043996, 0.9599229710608033], 
             UndirectedEdge[63, 317] -> 
             RGBColor[
              0.6513896706015462, 0.716535525076532, 0.8372654799469499], 
             UndirectedEdge[145, 280] -> 
             RGBColor[
              0.7297116610418976, 0.7830944166191796, 0.7583461399095361], 
             UndirectedEdge[152, 317] -> 
             RGBColor[
              0.7149997599611315, 0.7717142813900981, 0.841315623435646], 
             UndirectedEdge[102, 391] -> 
             RGBColor[
              0.445206653368226, 0.5481714251509973, 0.9513904251155293], 
             UndirectedEdge[168, 251] -> 
             RGBColor[
              0.294403339467757, 0.42362417457440116`, 0.9401922792655812], 
             UndirectedEdge[89, 245] -> 
             RGBColor[
              0.5080355837267316, 0.6102005825803658, 0.9547685121017686], 
             UndirectedEdge[293, 330] -> 
             RGBColor[
              0.8811948727797689, 0.9081048884297085, 0.9885303476893256], 
             UndirectedEdge[166, 247] -> 
             RGBColor[
              0.35627518922080903`, 0.48173618932209394`, 0.9439691361988416],
              UndirectedEdge[8, 182] -> 
             RGBColor[
              0.47660633712076195`, 0.5839828932801083, 0.9524882544201898], 
             UndirectedEdge[2, 215] -> 
             RGBColor[
              0.5026180213457632, 0.58522132107691, 0.9583444985176042], 
             UndirectedEdge[61, 107] -> 
             RGBColor[
              0.46072456997242095`, 0.5620248962001057, 0.9526631018415695], 
             UndirectedEdge[192, 361] -> 
             RGBColor[
              0.526000833390578, 0.6255095450382699, 0.9559827691043741], 
             UndirectedEdge[71, 321] -> 
             RGBColor[
              0.5106715042676443, 0.6133570777706259, 0.9546951494559033], 
             UndirectedEdge[26, 389] -> 
             RGBColor[
              0.541295347352055, 0.6323328408475907, 0.9595275865554913], 
             UndirectedEdge[134, 263] -> 
             RGBColor[
              0.6704068895794993, 0.7413969002673897, 0.9685009802273419], 
             UndirectedEdge[105, 282] -> 
             RGBColor[
              0.7034672424566011, 0.7633489924267587, 0.9002565244405639], 
             UndirectedEdge[323, 340] -> 
             RGBColor[
              0.7894334474362663, 0.5272273320283076, 0.4557751666595086], 
             UndirectedEdge[311, 323] -> 
             RGBColor[
              0.8571857515872453, 0.5803790448331094, 0.46246887984213214`], 
             UndirectedEdge[29, 365] -> 
             RGBColor[
              0.7304841195769931, 0.789275154459846, 0.9738811871943006], 
             UndirectedEdge[321, 384] -> 
             RGBColor[
              0.3951654407047568, 0.5044067051352871, 0.9476612545205387], 
             UndirectedEdge[115, 195] -> 
             RGBColor[
              0.5556025064077059, 0.6501021701662784, 0.9581582110249072], 
             UndirectedEdge[162, 359] -> 
             RGBColor[
              0.550681521844394, 0.6231917393253991, 0.9629824836935279], 
             UndirectedEdge[106, 295] -> 
             RGBColor[
              0.5886264764018276, 0.6769125167204009, 0.9607579789136325], 
             UndirectedEdge[24, 242] -> 
             RGBColor[
              0.8731779353132083, 0.901640505565674, 0.9802902757352894], 
             UndirectedEdge[109, 286] -> 
             RGBColor[
              0.5766104410581123, 0.6671573579121494, 0.9598120325951874], 
             UndirectedEdge[287, 367] -> 
             RGBColor[
              0.8905439699982717, 0.9155596047772591, 0.9894220729280641], 
             UndirectedEdge[74, 140] -> 
             RGBColor[
              0.4337924426588324, 0.5405664596631955, 0.9502651318450107], 
             UndirectedEdge[168, 394] -> 
             RGBColor[
              0.4548423859494366, 0.5565527008002159, 0.9522156608652597], 
             UndirectedEdge[68, 249] -> 
             RGBColor[
              0.2714583960342926, 0.4026503640614021, 0.9387705261162197], 
             UndirectedEdge[389, 400] -> 
             RGBColor[
              0.3073242685433973, 0.44034767009612974`, 0.9408130344968098], 
             UndirectedEdge[267, 346] -> 
             RGBColor[
              0.4011315520141784, 0.5204243488424618, 0.9471137938694625], 
             UndirectedEdge[16, 392] -> 
             RGBColor[
              0.6063365326125296, 0.6844392848593899, 0.9656108402163632], 
             UndirectedEdge[13, 191] -> 
             RGBColor[
              0.6109425842305831, 0.6866430916697568, 0.9663971198437449], 
             UndirectedEdge[312, 327] -> 
             RGBColor[
              0.4971895414731471, 0.5897483666427462, 0.9564184218947879], 
             UndirectedEdge[260, 291] -> 
             RGBColor[
              0.6723660624057447, 0.7439767452134888, 0.9679788235486633], 
             UndirectedEdge[83, 344] -> 
             RGBColor[
              0.39738429668625797`, 0.5186160374993076, 0.9465419538850801], 
             UndirectedEdge[200, 288] -> 
             RGBColor[
              0.49265282600269455`, 0.5982227235626223, 0.9534164567307442], 
             UndirectedEdge[297, 332] -> 
             RGBColor[
              0.8457541926589919, 0.8802182215676116, 0.9776253810731572], 
             UndirectedEdge[189, 241] -> 
             RGBColor[
              0.8808299673921676, 0.9078139227787281, 0.9884955426877012], 
             UndirectedEdge[276, 358] -> 
             RGBColor[
              0.45067955101872914`, 0.5614419846665882, 0.9508595506887536], 
             UndirectedEdge[11, 102] -> 
             RGBColor[
              0.27361664565237814`, 0.4049188212509393, 0.9388934352391255], 
             UndirectedEdge[96, 243] -> 
             RGBColor[
              0.3811761008756849, 0.5045773129357977, 0.9455091819803753], 
             UndirectedEdge[171, 397] -> 
             RGBColor[
              0.7673369329562845, 0.8186158684536545, 0.9773259705571863], 
             UndirectedEdge[314, 385] -> 
             RGBColor[
              0.41334579857288317`, 0.521266024698233, 0.9489013524066956], 
             UndirectedEdge[11, 213] -> 
             RGBColor[
              0.5958287139330609, 0.675498755233652, 0.9648181330420931], 
             UndirectedEdge[68, 129] -> 
             RGBColor[
              0.6080831167327978, 0.6805862942965609, 0.9593083142652473], 
             UndirectedEdge[137, 277] -> 
             RGBColor[
              0.5366504250855848, 0.6347160167674466, 0.9566662337594685], 
             UndirectedEdge[35, 327] -> 
             RGBColor[
              0.27154097777710207`, 0.40273716270907967`, 0.9387752290243039],
              UndirectedEdge[155, 183] -> 
             RGBColor[
              0.8625273099227396, 0.8904385200439926, 0.8402385350153174], 
             UndirectedEdge[63, 256] -> 
             RGBColor[
              0.30799666904596, 0.4410544056569774, 0.9408513267107033], 
             UndirectedEdge[144, 358] -> 
             RGBColor[
              0.6601489612315025, 0.7240154720374132, 0.8254798341978006], 
             UndirectedEdge[192, 332] -> 
             RGBColor[
              0.6834495009785493, 0.7522824689580331, 0.9693246892394268], 
             UndirectedEdge[149, 259] -> 
             RGBColor[
              0.6791028679683266, 0.7463771308606398, 0.9707486334870559], 
             UndirectedEdge[146, 165] -> 
             RGBColor[
              0.8479140485287842, 0.881788704801566, 0.9852973351465458], 
             UndirectedEdge[164, 280] -> 
             RGBColor[
              0.9717121365978627, 0.9755428501564746, 0.7678797878733454], 
             UndirectedEdge[65, 105] -> 
             RGBColor[
              0.9868068807885075, 0.9888123204054189, 0.8683076582398725], 
             UndirectedEdge[73, 369] -> 
             RGBColor[
              0.7801455026316872, 0.8282123419005031, 0.9787113251655561], 
             UndirectedEdge[187, 281] -> 
             RGBColor[
              0.4535441987437601, 0.564760206479953, 0.9508108157222872], 
             UndirectedEdge[53, 253] -> 
             RGBColor[
              0.715274614369223, 0.7726838814711852, 0.8682208846272762], 
             UndirectedEdge[132, 191] -> 
             RGBColor[
              0.9177378948016826, 0.9372433022560743, 0.9920158537521166], 
             UndirectedEdge[29, 273] -> 
             RGBColor[
              0.7155844581165998, 0.7771789380641989, 0.97270823126488], 
             UndirectedEdge[138, 366] -> 
             RGBColor[
              0.653777001941597, 0.7272827833096175, 0.9676110798405365], 
             UndirectedEdge[229, 309] -> 
             RGBColor[
              0.3016131207417011, 0.4343448916488621, 0.940487793078389], 
             UndirectedEdge[274, 287] -> 
             RGBColor[
              0.7382427112724066, 0.795411334684479, 0.974679114704565], 
             UndirectedEdge[251, 312] -> 
             RGBColor[
              0.545102556357228, 0.6369652033175068, 0.9592620697763103], 
             UndirectedEdge[339, 360] -> 
             RGBColor[
              0.34965040528739955`, 0.4762624172150063, 0.9435373341380341], 
             UndirectedEdge[150, 365] -> 
             RGBColor[
              0.6274962976281288, 0.7084687886574033, 0.9638179536254136], 
             UndirectedEdge[61, 300] -> 
             RGBColor[
              0.5429332325134846, 0.626354540007087, 0.9608283361715191], 
             UndirectedEdge[62, 389] -> 
             RGBColor[
              0.3197784442042102, 0.45125078628805804`, 0.9416023586015416], 
             UndirectedEdge[374, 399] -> 
             RGBColor[
              0.7573813438999772, 0.7769140764426856, 0.649161848259616], 
             UndirectedEdge[27, 51] -> 
             RGBColor[
              0.5903758660078493, 0.6744295047738922, 0.9628871740807354], 
             UndirectedEdge[58, 159] -> 
             RGBColor[
              0.5802852468903379, 0.6524584688704507, 0.9639699440613443], 
             UndirectedEdge[57, 153] -> 
             RGBColor[
              0.35803707253478995`, 0.48453544958829464`, 0.9440347835555328],
              UndirectedEdge[84, 264] -> 
             RGBColor[
              0.4259779099566167, 0.5421657841178324, 0.9487000649593075], 
             UndirectedEdge[159, 201] -> 
             RGBColor[
              0.8921135259363778, 0.9167830264792378, 0.988597547851284], 
             UndirectedEdge[80, 87] -> 
             RGBColor[
              0.5670586491146818, 0.6541206341122978, 0.9614491086461419], 
             UndirectedEdge[39, 288] -> 
             RGBColor[
              0.4917877456220666, 0.5975204123382014, 0.9533483544342872], 
             UndirectedEdge[91, 365] -> 
             RGBColor[
              0.4687687302513892, 0.5755913916867293, 0.9524151253453121], 
             UndirectedEdge[5, 384] -> 
             RGBColor[
              0.27097687587163777`, 0.400223457130665, 0.9388134341053269], 
             UndirectedEdge[156, 381] -> 
             RGBColor[
              0.515899157316272, 0.6178692027583588, 0.9550326179462696], 
             UndirectedEdge[2, 197] -> 
             RGBColor[
              0.5500536158103523, 0.6350791384495924, 0.9610458854476891], 
             UndirectedEdge[238, 293] -> 
             RGBColor[
              0.8370816036702158, 0.8729633351326163, 0.9843139823850954], 
             UndirectedEdge[85, 325] -> 
             RGBColor[
              0.7678650242671766, 0.819057827468344, 0.9773708012357322], 
             UndirectedEdge[146, 332] -> 
             RGBColor[
              0.7701015400218649, 0.8203284431443434, 0.9777201825674713], 
             UndirectedEdge[197, 204] -> 
             RGBColor[
              0.31049178261604854`, 0.4403810558486729, 0.9411140977700185], 
             UndirectedEdge[20, 130] -> 
             RGBColor[
              0.45614079474977076`, 0.5572928214968687, 0.9523884849739748], 
             UndirectedEdge[167, 348] -> 
             RGBColor[
              0.6281541968671603, 0.7004682364467575, 0.9534928442733799], 
             UndirectedEdge[83, 237] -> 
             RGBColor[
              0.35656108471771497`, 0.483257023126449, 0.9439407349169935], 
             UndirectedEdge[178, 334] -> 
             RGBColor[
              0.5014480139058857, 0.5997149908596129, 0.9557916772629171], 
             UndirectedEdge[178, 388] -> 
             RGBColor[
              0.5052487494239464, 0.603709804869645, 0.9560081235279863], 
             UndirectedEdge[115, 184] -> 
             RGBColor[
              0.6394699871863581, 0.7175879177591563, 0.9651719187382668], 
             UndirectedEdge[165, 385] -> 
             RGBColor[
              0.566589569056183, 0.642353132125181, 0.9635186247252986], 
             UndirectedEdge[202, 257] -> 
             RGBColor[
              0.936437948836536, 0.9521161068323709, 0.9924781523684676], 
             UndirectedEdge[35, 57] -> 
             RGBColor[
              0.3340485621554344, 0.46259508193536936`, 0.9425488299685291], 
             UndirectedEdge[115, 206] -> 
             RGBColor[
              0.545800404232048, 0.6421443820404086, 0.9573865536353561], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.6622055048860065, 0.7349776781963369, 0.9676919100455392], 
             UndirectedEdge[61, 98] -> 
             RGBColor[
              0.31757624006546176`, 0.4442963164341426, 0.9416468326410867], 
             UndirectedEdge[33, 173] -> 
             RGBColor[
              0.4853665606552924, 0.5897685103981988, 0.9535443594059398], 
             UndirectedEdge[6, 185] -> 
             RGBColor[
              0.6468863599671085, 0.7194811187738073, 0.9682316465761555], 
             UndirectedEdge[300, 363] -> 
             RGBColor[
              0.6808360060105982, 0.7489550372521037, 0.9699882924123352], 
             UndirectedEdge[34, 270] -> 
             RGBColor[
              0.4761057589932758, 0.5837951018145149, 0.9523884471319648], 
             UndirectedEdge[162, 179] -> 
             RGBColor[
              0.6086239304410863, 0.684092884521414, 0.9662822181449975], 
             UndirectedEdge[11, 250] -> 
             RGBColor[
              0.5042936587711363, 0.6034721203564763, 0.9558324355731982], 
             UndirectedEdge[66, 314] -> 
             RGBColor[
              0.4402406878314842, 0.5495342585434912, 0.9504329765625498], 
             UndirectedEdge[153, 327] -> 
             RGBColor[
              0.29552948815645763`, 0.42467753036200495`, 0.9402611826113076],
              UndirectedEdge[153, 392] -> 
             RGBColor[
              0.6181801364302584, 0.6946976192094702, 0.9663655041787413], 
             UndirectedEdge[110, 369] -> 
             RGBColor[
              0.580957576636786, 0.6685220597524678, 0.9613346560907539], 
             UndirectedEdge[321, 398] -> 
             RGBColor[
              0.5189094290901825, 0.6203130769956173, 0.9552695975673007], 
             UndirectedEdge[188, 278] -> 
             RGBColor[
              0.8100725014190843, 0.8124602484419567, 0.6429799115345853], 
             UndirectedEdge[213, 289] -> 
             RGBColor[
              0.6229549953557549, 0.699110111995044, 0.9665423507519384], 
             UndirectedEdge[236, 263] -> 
             RGBColor[
              0.6503099412831761, 0.725081292283231, 0.9669188748399081], 
             UndirectedEdge[93, 383] -> 
             RGBColor[
              0.509122927167799, 0.6109373651037371, 0.9548944442221159], 
             UndirectedEdge[56, 286] -> 
             RGBColor[
              0.725725770301094, 0.785088641549478, 0.9738789012448348], 
             UndirectedEdge[25, 144] -> 
             RGBColor[
              0.9103567645862797, 0.9278627826346332, 0.8461230162420397], 
             UndirectedEdge[143, 331] -> 
             RGBColor[
              0.5493998866755482, 0.6395602798802098, 0.9600129149437121], 
             UndirectedEdge[76, 257] -> 
             RGBColor[
              0.7124882332632286, 0.7739006196404603, 0.973061020739236], 
             UndirectedEdge[91, 189] -> 
             RGBColor[
              0.5722487704126076, 0.6567606371208063, 0.962559378267078], 
             UndirectedEdge[133, 145] -> 
             RGBColor[
              0.6832504022844406, 0.7504262027756943, 0.970741135173279], 
             UndirectedEdge[207, 230] -> 
             RGBColor[
              0.5112428016799444, 0.614088963486357, 0.9546660525737851], 
             UndirectedEdge[238, 336] -> 
             RGBColor[
              0.7808971692051313, 0.8287620707121319, 0.9787961899935687], 
             UndirectedEdge[123, 306] -> 
             RGBColor[
              0.7663374541266328, 0.8126355463507537, 0.7453834196201449], 
             UndirectedEdge[272, 338] -> 
             RGBColor[
              0.6678606883667472, 0.7387603077199283, 0.9686898848508501], 
             UndirectedEdge[11, 289] -> 
             RGBColor[
              0.3346183427316386, 0.4641353876927878, 0.9425468077564256], 
             UndirectedEdge[215, 300] -> 
             RGBColor[
              0.507508326283022, 0.589120717490089, 0.9588109401681466], 
             UndirectedEdge[224, 289] -> 
             RGBColor[
              0.506568528997172, 0.6076693658133183, 0.9550796968646021], 
             UndirectedEdge[65, 161] -> 
             RGBColor[
              0.9214574943916046, 0.9386389629279797, 0.9351304988023043], 
             UndirectedEdge[14, 247] -> 
             RGBColor[
              0.34261733911180026`, 0.4673809228998135, 0.9431913418401121], 
             UndirectedEdge[150, 226] -> 
             RGBColor[
              0.6387142113812012, 0.7174286524584106, 0.9648018087485378], 
             UndirectedEdge[15, 180] -> 
             RGBColor[
              0.6154687163100709, 0.6987042563070403, 0.9628710983655739], 
             UndirectedEdge[7, 114] -> 
             RGBColor[
              0.6164304254107079, 0.6944509962191385, 0.9656698749490992], 
             UndirectedEdge[108, 313] -> 
             RGBColor[
              0.35801363501539507`, 0.4803556884016722, 0.944185588372495], 
             UndirectedEdge[227, 315] -> 
             RGBColor[
              0.37763844411892356`, 0.49867641212712516`, 0.9455078412773678],
              UndirectedEdge[174, 384] -> 
             RGBColor[
              0.31083495465395994`, 0.43474652164662353`, 0.9413531556402213],
              UndirectedEdge[104, 138] -> 
             RGBColor[
              0.7168883765721676, 0.7785194403697417, 0.9725794384360378], 
             UndirectedEdge[313, 344] -> 
             RGBColor[
              0.34075939874846106`, 0.4654109361703843, 0.9430861636948881], 
             UndirectedEdge[255, 374] -> 
             RGBColor[
              0.7635017515074491, 0.7818828990596519, 0.649643669166268], 
             UndirectedEdge[87, 167] -> 
             RGBColor[
              0.8715928145317624, 0.9002629886603489, 0.9730855740499078], 
             UndirectedEdge[114, 312] -> 
             RGBColor[
              0.8013908402006096, 0.8450574449562138, 0.980763028032563], 
             UndirectedEdge[50, 265] -> 
             RGBColor[
              0.863818065489717, 0.8943748070623629, 0.9817012186502052], 
             UndirectedEdge[310, 345] -> 
             RGBColor[
              0.5298671746970545, 0.627521970253744, 0.9567028843305445], 
             UndirectedEdge[315, 334] -> 
             RGBColor[
              0.2898053560835169, 0.4219341823375909, 0.939815358349128], 
             UndirectedEdge[102, 302] -> 
             RGBColor[
              0.2557809735538832, 0.38617239902849543`, 0.9378777200986286], 
             UndirectedEdge[172, 211] -> 
             RGBColor[
              0.3670494611560037, 0.48808406188066067`, 0.9448559021308831], 
             UndirectedEdge[264, 381] -> 
             RGBColor[
              0.5308365551186887, 0.6299960552164631, 0.9562085446187669], 
             UndirectedEdge[270, 397] -> 
             RGBColor[
              0.5237847522553951, 0.6222425217146519, 0.9563200411630002], 
             UndirectedEdge[48, 290] -> 
             RGBColor[
              0.40046112123932764`, 0.519920661763337, 0.9470573195452962], 
             UndirectedEdge[224, 323] -> 
             RGBColor[
              0.7871874901728226, 0.525472773144198, 0.45555131062915255`], 
             UndirectedEdge[10, 339] -> 
             RGBColor[
              0.29106246671287683`, 0.4232554853144656, 0.9398869489397415], 
             UndirectedEdge[254, 320] -> 
             RGBColor[
              0.7170588327860651, 0.7782403704158101, 0.972980293623955], 
             UndirectedEdge[92, 392] -> 
             RGBColor[
              0.9410415190463438, 0.9534847539152975, 0.9035633079483798], 
             UndirectedEdge[166, 224] -> 
             RGBColor[
              0.4731838118115693, 0.5774799962573635, 0.9529990704965854], 
             UndirectedEdge[108, 344] -> 
             RGBColor[
              0.43501517222890673`, 0.5512100105115509, 0.9489397599989811], 
             UndirectedEdge[180, 271] -> 
             RGBColor[
              0.6283190242080667, 0.709136715158407, 0.963882721675533], 
             UndirectedEdge[104, 207] -> 
             RGBColor[
              0.5550511106036677, 0.6496545222124623, 0.9581148031273838], 
             UndirectedEdge[45, 266] -> 
             RGBColor[
              0.7258128965098223, 0.7857030469435432, 0.9733242081555182], 
             UndirectedEdge[59, 373] -> 
             RGBColor[
              0.49937896038699714`, 0.5998681918697937, 0.955287746093726], 
             UndirectedEdge[107, 352] -> 
             RGBColor[
              0.6949297252371307, 0.7616036501075566, 0.9702277585902781], 
             UndirectedEdge[99, 338] -> 
             RGBColor[
              0.3917492737463214, 0.506354713357575, 0.9469625495619209], 
             UndirectedEdge[186, 341] -> 
             RGBColor[
              0.4452688361367358, 0.5480705182954225, 0.9514202885039122], 
             UndirectedEdge[90, 156] -> 
             RGBColor[
              0.41017134404988, 0.5292861019334254, 0.947468755663778], 
             UndirectedEdge[34, 151] -> 
             RGBColor[
              0.7031088975215587, 0.766972691536864, 0.9718159141102234], 
             UndirectedEdge[174, 260] -> 
             RGBColor[
              0.5389120501768073, 0.6349534327292148, 0.9574496804032121], 
             UndirectedEdge[13, 216] -> 
             RGBColor[
              0.3514210130377063, 0.4780278698177901, 0.9436416668575245], 
             UndirectedEdge[9, 217] -> 
             RGBColor[
              0.5707131273471788, 0.6623696529706584, 0.9593477744572908], 
             UndirectedEdge[87, 159] -> 
             RGBColor[
              0.86404680170165, 0.8946351846471131, 0.9858590054559376], 
             UndirectedEdge[184, 305] -> 
             RGBColor[
              0.5393978006098422, 0.6348200153981762, 0.9577151745104381], 
             UndirectedEdge[12, 259] -> 
             RGBColor[
              0.41422671102191855`, 0.5332040902724985, 0.9476151376333862], 
             UndirectedEdge[27, 287] -> 
             RGBColor[
              0.6229980081839217, 0.7001882712256047, 0.9660659063517416], 
             UndirectedEdge[188, 284] -> 
             RGBColor[
              0.8405036773745467, 0.8362333143838675, 0.6460130067583181], 
             UndirectedEdge[118, 126] -> 
             RGBColor[
              0.7567535531853723, 0.46433110740023104`, 0.44842268914787237`],
              UndirectedEdge[209, 304] -> 
             RGBColor[
              0.5116106352160492, 0.6080101637299626, 0.9567482235115812], 
             UndirectedEdge[48, 108] -> 
             RGBColor[
              0.3792315725240868, 0.5026570860182458, 0.9453939185244894], 
             UndirectedEdge[136, 376] -> 
             RGBColor[
              0.7123489968241447, 0.7752117174626993, 0.9719639487897236], 
             UndirectedEdge[48, 344] -> 
             RGBColor[
              0.3619773362571528, 0.4877123337869579, 0.9442944938468825], 
             UndirectedEdge[13, 198] -> 
             RGBColor[
              0.3933323992516174, 0.5134332265351295, 0.9465598403905495], 
             UndirectedEdge[286, 320] -> 
             RGBColor[
              0.7127395440807088, 0.7747337772630631, 0.9726402633949935], 
             UndirectedEdge[176, 368] -> 
             RGBColor[
              0.6529001592785759, 0.7280194744953543, 0.9665516689606783], 
             UndirectedEdge[248, 388] -> 
             RGBColor[
              0.43050310625926386`, 0.5440146750704398, 0.9494492259386645], 
             UndirectedEdge[57, 188] -> 
             RGBColor[
              0.6686174436111754, 0.6956018523915329, 0.6323239792799696], 
             UndirectedEdge[39, 225] -> 
             RGBColor[
              0.7713067472201265, 0.8200722371607827, 0.935316292735275], 
             UndirectedEdge[355, 379] -> 
             RGBColor[
              0.7104086654456288, 0.7728685699455924, 0.972425570774835], 
             UndirectedEdge[85, 348] -> 
             RGBColor[0.591686820024582, 0.6718074214181, 0.96448196088481], 
             UndirectedEdge[118, 336] -> 
             RGBColor[
              0.8133815213127351, 0.5092466871558746, 0.4536037069314655], 
             UndirectedEdge[195, 392] -> 
             RGBColor[
              0.7030563633586338, 0.7665682085335733, 0.9722282420392294], 
             UndirectedEdge[193, 281] -> 
             RGBColor[
              0.7202361786558485, 0.7804944600123978, 0.9736049817402679], 
             UndirectedEdge[154, 312] -> 
             RGBColor[
              0.5181853157031704, 0.6118162565674738, 0.9576141001767232], 
             UndirectedEdge[53, 171] -> 
             RGBColor[
              0.9335023796543416, 0.9471224924191752, 0.8876131646646708], 
             UndirectedEdge[115, 188] -> 
             RGBColor[
              0.781306650555716, 0.7892979836454136, 0.6405846688888559], 
             UndirectedEdge[319, 329] -> 
             RGBColor[
              0.4209842240439493, 0.5390571084097016, 0.948045720387716], 
             UndirectedEdge[231, 359] -> 
             RGBColor[
              0.23861582633980397`, 0.36813074097330567`, 0.9369001903583465],
              UndirectedEdge[288, 399] -> 
             RGBColor[
              0.48438397475892064`, 0.591509697615423, 0.9527655024710341], 
             UndirectedEdge[140, 220] -> 
             RGBColor[
              0.6044242317335169, 0.6897378461794337, 0.9620016360824275], 
             UndirectedEdge[9, 215] -> 
             RGBColor[
              0.3945034412819608, 0.5001955906308402, 0.947943540117066], 
             UndirectedEdge[309, 329] -> 
             RGBColor[
              0.3580016538842091, 0.484348530546736, 0.9440382474656457], 
             UndirectedEdge[9, 61] -> 
             RGBColor[
              0.4299283475124234, 0.5374294131478381, 0.9499609361204385], 
             UndirectedEdge[21, 82] -> 
             RGBColor[
              0.7953294515290162, 0.3579779581894591, 0.43476241321437314`], 
             UndirectedEdge[154, 361] -> 
             RGBColor[
              0.36078647228618455`, 0.48508225566876223`, 0.944277146049401], 
             UndirectedEdge[160, 213] -> 
             RGBColor[
              0.813034213877512, 0.8543865283532761, 0.9818616488828329], 
             UndirectedEdge[331, 342] -> 
             RGBColor[
              0.5721245123535422, 0.6573129301734106, 0.9622778932575937], 
             UndirectedEdge[122, 159] -> 
             RGBColor[
              0.783759609256224, 0.8317360866518453, 0.9779785189797275], 
             UndirectedEdge[258, 278] -> 
             RGBColor[
              0.7968331337515746, 0.8420912304595153, 0.9773310859013447], 
             UndirectedEdge[37, 201] -> 
             RGBColor[
              0.7675912939499059, 0.8185893233793029, 0.9774110983206807], 
             UndirectedEdge[61, 314] -> 
             RGBColor[
              0.424636438015998, 0.5331332026208339, 0.9495443376199767], 
             UndirectedEdge[297, 314] -> 
             RGBColor[
              0.7703229306826114, 0.8205913757978862, 0.9705852613336288], 
             UndirectedEdge[84, 175] -> 
             RGBColor[
              0.48027339319541157`, 0.5862453033947319, 0.9529744042907738], 
             UndirectedEdge[72, 374] -> 
             RGBColor[
              0.8445104082559104, 0.8464873416601317, 0.6568154565990236], 
             UndirectedEdge[168, 180] -> 
             RGBColor[
              0.43224332558647416`, 0.5385313949498008, 0.9502139454318439], 
             UndirectedEdge[36, 60] -> 
             RGBColor[
              0.5144570653300964, 0.612908269374478, 0.9562568980110244], 
             UndirectedEdge[347, 387] -> 
             RGBColor[
              0.364026212396126, 0.4857886024414626, 0.9446034322872514], 
             UndirectedEdge[140, 141] -> 
             RGBColor[
              0.8024157081228147, 0.8441966506658751, 0.8906451554682946], 
             UndirectedEdge[233, 382] -> 
             RGBColor[
              0.7205432420771067, 0.7816131241328839, 0.9727806745769633], 
             UndirectedEdge[21, 122] -> 
             RGBColor[
              0.7551228493791159, 0.32644949964070413`, 0.4308361885576497], 
             UndirectedEdge[202, 268] -> 
             RGBColor[
              0.9582663717475433, 0.9683957088986379, 0.9555283261446221], 
             UndirectedEdge[196, 344] -> 
             RGBColor[
              0.5566649714205585, 0.6491841600326405, 0.9590659057656508], 
             UndirectedEdge[109, 343] -> 
             RGBColor[
              0.547034079610445, 0.6431459352890337, 0.9574836730802452], 
             UndirectedEdge[52, 117] -> 
             RGBColor[
              0.6165955363743625, 0.6984570252515784, 0.9637542949977423], 
             UndirectedEdge[51, 194] -> 
             RGBColor[
              0.8894667799017625, 0.9125347118627876, 0.895146874862266], 
             UndirectedEdge[223, 342] -> 
             RGBColor[
              0.5789597344673705, 0.6632332560201561, 0.9627134275665372], 
             UndirectedEdge[241, 374] -> 
             RGBColor[
              0.9479814128572444, 0.9281697602040476, 0.6669028933652452], 
             UndirectedEdge[76, 109] -> 
             RGBColor[
              0.5334343469732881, 0.6321050596732163, 0.9564130523095862], 
             UndirectedEdge[90, 381] -> 
             RGBColor[
              0.45782070436512057`, 0.5679699992165577, 0.9512198878531518], 
             UndirectedEdge[75, 227] -> 
             RGBColor[
              0.46004633191233735`, 0.5723892245998885, 0.9506732943677888], 
             UndirectedEdge[209, 329] -> 
             RGBColor[
              0.3538542046384413, 0.47998929842596383`, 0.9438020563667007], 
             UndirectedEdge[24, 358] -> 
             RGBColor[
              0.5637634895643931, 0.650797945955152, 0.9614374720402132], 
             UndirectedEdge[208, 369] -> 
             RGBColor[
              0.6332559384388035, 0.7117153183448459, 0.9652486664681372], 
             UndirectedEdge[62, 400] -> 
             RGBColor[
              0.31994623696975744`, 0.451427147123324, 0.9416119141513123], 
             UndirectedEdge[127, 325] -> 
             RGBColor[
              0.6841476060120038, 0.7531805766217461, 0.9691530977105504], 
             UndirectedEdge[43, 277] -> 
             RGBColor[
              0.5076995856807652, 0.6108688356043139, 0.9544820513322918], 
             UndirectedEdge[70, 227] -> 
             RGBColor[
              0.5556086208962634, 0.650107134183544, 0.9581586923798445], 
             UndirectedEdge[25, 366] -> 
             RGBColor[
              0.6630866369408325, 0.7346009699490492, 0.9685269217881021], 
             UndirectedEdge[20, 387] -> 
             RGBColor[
              0.2560841793724993, 0.38649108756822015`, 0.9378949872214459], 
             UndirectedEdge[328, 387] -> 
             RGBColor[
              0.596634164266282, 0.6711483341737237, 0.9656513120454495], 
             UndirectedEdge[249, 386] -> 
             RGBColor[
              0.41472140553909054`, 0.5272497084793697, 0.9485666293459447], 
             UndirectedEdge[110, 243] -> 
             RGBColor[
              0.4065887040950346, 0.5265884325698222, 0.9471284505860296], 
             UndirectedEdge[47, 121] -> 
             RGBColor[
              0.911338795461077, 0.9309103535791853, 0.9487439684339549], 
             UndirectedEdge[31, 156] -> 
             RGBColor[
              0.36593429051296633`, 0.486797870127324, 0.9448027787834237], 
             UndirectedEdge[98, 283] -> 
             RGBColor[
              0.32128524979534234`, 0.4481947208250464, 0.9418580552582152], 
             UndirectedEdge[38, 358] -> 
             RGBColor[
              0.48102113339431596`, 0.5860746481117988, 0.9532481511982381], 
             UndirectedEdge[126, 199] -> 
             RGBColor[
              0.4098735819367248, 0.5200893133572746, 0.9484785243963632], 
             UndirectedEdge[39, 200] -> 
             RGBColor[
              0.5596306144327102, 0.6533723697251754, 0.9584753184440813], 
             UndirectedEdge[227, 304] -> 
             RGBColor[
              0.5981242931721065, 0.6833655888494017, 0.9623655668487239], 
             UndirectedEdge[242, 333] -> 
             RGBColor[
              0.9677271929707634, 0.9742479950161012, 0.8856149031782055], 
             UndirectedEdge[30, 333] -> 
             RGBColor[
              0.7463594487742952, 0.7983647177741219, 0.8727321992975088], 
             UndirectedEdge[85, 96] -> 
             RGBColor[
              0.627182922393055, 0.7029516177564865, 0.9667291224015537], 
             UndirectedEdge[39, 94] -> 
             RGBColor[
              0.3902079781037506, 0.5014845420037592, 0.9471706259178683], 
             UndirectedEdge[63, 138] -> 
             RGBColor[
              0.5574173677967451, 0.6450209845750492, 0.9611196766485999], 
             UndirectedEdge[119, 324] -> 
             RGBColor[
              0.6917677683857582, 0.7526489158057919, 0.878686250290452], 
             UndirectedEdge[18, 224] -> 
             RGBColor[
              0.5083635068126365, 0.6092240853788655, 0.955194071263767], 
             UndirectedEdge[84, 204] -> 
             RGBColor[
              0.3491124579196282, 0.47680539697281465`, 0.9434661150039816], 
             UndirectedEdge[241, 288] -> 
             RGBColor[
              0.6749840437161877, 0.7427653813767852, 0.9705065475766632], 
             UndirectedEdge[91, 266] -> 
             RGBColor[
              0.47430355900408266`, 0.5800848150093597, 0.9528508473394699], 
             UndirectedEdge[201, 263] -> 
             RGBColor[
              0.8071963064378891, 0.8495290601441589, 0.9813585558355984], 
             UndirectedEdge[29, 266] -> 
             RGBColor[
              0.7360189483296866, 0.7937685777824763, 0.9743169091884584], 
             UndirectedEdge[161, 326] -> 
             RGBColor[
              0.6735768262059459, 0.7428897855195356, 0.969614702882757], 
             UndirectedEdge[174, 235] -> 
             RGBColor[
              0.3768154663829514, 0.5008003505100542, 0.945231326206456], 
             UndirectedEdge[207, 233] -> 
             RGBColor[
              0.6050195133890713, 0.6889286932950234, 0.9629321398398131], 
             UndirectedEdge[199, 212] -> 
             RGBColor[
              0.40296658342006764`, 0.5144819008047151, 0.9479347801719626], 
             UndirectedEdge[127, 184] -> 
             RGBColor[
              0.696572833015664, 0.7628872583922284, 0.9703915282179272], 
             UndirectedEdge[261, 381] -> 
             RGBColor[
              0.515899157316272, 0.6178692027583588, 0.9550326179462696], 
             UndirectedEdge[221, 230] -> 
             RGBColor[
              0.6542563592190181, 0.728248657553086, 0.9672545165437505], 
             UndirectedEdge[22, 273] -> 
             RGBColor[
              0.5333239556473008, 0.6320154390217072, 0.9564043619000276], 
             UndirectedEdge[240, 292] -> 
             RGBColor[
              0.5285485354288311, 0.6276701194444128, 0.9561578487032207], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.7272392934573331, 0.786844130362992, 0.9734480744003863], 
             UndirectedEdge[120, 343] -> 
             RGBColor[
              0.6207587381760715, 0.7017276558812794, 0.9641567283111103], 
             UndirectedEdge[175, 310] -> 
             RGBColor[
              0.5036730368672597, 0.6065128986429991, 0.9544654088940515], 
             UndirectedEdge[55, 201] -> 
             RGBColor[
              0.9099974975695757, 0.9301208632409608, 0.9583246487631127], 
             UndirectedEdge[264, 333] -> 
             RGBColor[
              0.7447805589540191, 0.7970829038898459, 0.8726079033071927], 
             UndirectedEdge[107, 197] -> 
             RGBColor[
              0.47273525820654744`, 0.57464889105579, 0.9533470927682821], 
             UndirectedEdge[131, 300] -> 
             RGBColor[
              0.6065037030032601, 0.6866100800903707, 0.9646888127855775], 
             UndirectedEdge[164, 227] -> 
             RGBColor[
              0.7107106741878557, 0.7720075137973101, 0.960851378223593], 
             UndirectedEdge[75, 315] -> 
             RGBColor[
              0.3658962411460195, 0.48900742441906053`, 0.9446210674791917], 
             UndirectedEdge[123, 193] -> 
             RGBColor[
              0.9443143313938467, 0.953860451135891, 0.7618806163123775], 
             UndirectedEdge[157, 253] -> 
             RGBColor[
              0.5181653290979287, 0.619316190092089, 0.9553195491687567], 
             UndirectedEdge[87, 110] -> 
             RGBColor[
              0.6087750209514208, 0.6902532586714676, 0.9641072389712396], 
             UndirectedEdge[112, 273] -> 
             RGBColor[
              0.7700390222514073, 0.8204799631141759, 0.9737567188649223], 
             UndirectedEdge[193, 384] -> 
             RGBColor[
              0.5537806245262071, 0.6299129149468037, 0.9626342277805009], 
             UndirectedEdge[95, 249] -> 
             RGBColor[
              0.31922458581552626`, 0.4473983108185357, 0.9416905601769718], 
             UndirectedEdge[61, 66] -> 
             RGBColor[
              0.2681727500474425, 0.399196941807235, 0.9385834134379463], 
             UndirectedEdge[113, 251] -> 
             RGBColor[
              0.5574894656749817, 0.6466419510205337, 0.9604966811348551], 
             UndirectedEdge[107, 131] -> 
             RGBColor[
              0.5242950404621963, 0.6222804362833894, 0.956523578455628], 
             UndirectedEdge[71, 343] -> 
             RGBColor[
              0.47980736754248066`, 0.5883001811636235, 0.9522654115538404], 
             UndirectedEdge[113, 168] -> 
             RGBColor[
              0.5091549438391124, 0.5989820838143591, 0.9576290290559919], 
             UndirectedEdge[58, 201] -> 
             RGBColor[
              0.5356101024516156, 0.6168638209681103, 0.9606830196261225], 
             UndirectedEdge[47, 130] -> 
             RGBColor[
              0.8258303230127866, 0.8639546684515504, 0.940262631947202], 
             UndirectedEdge[17, 82] -> 
             RGBColor[
              0.5152242136048447, 0.6081800115538029, 0.9575284170195785], 
             UndirectedEdge[11, 25] -> 
             RGBColor[
              0.566548318580111, 0.6521513627743686, 0.9620253427944112], 
             UndirectedEdge[73, 392] -> 
             RGBColor[
              0.8584170444737549, 0.8899424664261714, 0.9863577780914905], 
             UndirectedEdge[155, 337] -> 
             RGBColor[
              0.7365157591657063, 0.7894787005870332, 0.8294008880299081], 
             UndirectedEdge[159, 165] -> 
             RGBColor[
              0.9199902935708697, 0.9390112042962823, 0.991256458834146], 
             UndirectedEdge[226, 368] -> 
             RGBColor[
              0.622676705308389, 0.7044086825470864, 0.9635392775231656], 
             UndirectedEdge[188, 258] -> 
             RGBColor[
              0.9520685192627119, 0.9242684799169905, 0.6540792954568488], 
             UndirectedEdge[140, 350] -> 
             RGBColor[
              0.3980015088073853, 0.5029479189090512, 0.9482268911101126], 
             UndirectedEdge[14, 38] -> 
             RGBColor[
              0.45225639360600933`, 0.5573613476492026, 0.9515543774777453], 
             UndirectedEdge[242, 268] -> 
             RGBColor[
              0.9618403476884289, 0.9710611743035019, 0.9494785171189166], 
             UndirectedEdge[20, 50] -> 
             RGBColor[
              0.5151350745050649, 0.6033796012148369, 0.9582684834470936], 
             UndirectedEdge[149, 212] -> 
             RGBColor[
              0.7430441119422263, 0.798802978211431, 0.9756398979294272], 
             UndirectedEdge[80, 361] -> 
             RGBColor[
              0.3877409648890109, 0.5102634681844813, 0.9459274893102231], 
             UndirectedEdge[31, 204] -> 
             RGBColor[
              0.3040062362783945, 0.4335643354404105, 0.940744755500595], 
             UndirectedEdge[209, 245] -> 
             RGBColor[
              0.45441292001106065`, 0.5628321651957281, 0.9513855248412242], 
             UndirectedEdge[113, 148] -> 
             RGBColor[
              0.6195093383848224, 0.6999949876734228, 0.9645495102353443], 
             UndirectedEdge[48, 231] -> 
             RGBColor[
              0.3022491946159704, 0.43501344562013206`, 0.9405240165445419], 
             UndirectedEdge[198, 224] -> 
             RGBColor[
              0.5688580182300702, 0.6607252111324657, 0.9592963451023481], 
             UndirectedEdge[1, 188] -> 
             RGBColor[
              0.9515226196336295, 0.9238613488674494, 0.6550033611354593], 
             UndirectedEdge[256, 264] -> 
             RGBColor[
              0.4031342504785507, 0.5223240869468847, 0.947246525436604], 
             UndirectedEdge[15, 170] -> 
             RGBColor[
              0.6476704145921961, 0.7242272158826566, 0.9658299150050185], 
             UndirectedEdge[20, 322] -> 
             RGBColor[
              0.6194481505743468, 0.6826210447867134, 0.8095499522374199], 
             UndirectedEdge[92, 153] -> 
             RGBColor[
              0.667008527393536, 0.7312918269987827, 0.8803475334108545], 
             UndirectedEdge[189, 360] -> 
             RGBColor[
              0.6189844902005179, 0.6973101356025431, 0.9655347971392596], 
             UndirectedEdge[272, 342] -> 
             RGBColor[
              0.8117913078514574, 0.8528968066267919, 0.9818754290116943], 
             UndirectedEdge[69, 219] -> 
             RGBColor[
              0.6463190459389998, 0.7163056969219965, 0.9503263017783287], 
             UndirectedEdge[86, 151] -> 
             RGBColor[
              0.5628487673401947, 0.646156684125298, 0.9621337360122342], 
             UndirectedEdge[72, 288] -> 
             RGBColor[
              0.5715130391148537, 0.6610829628328692, 0.9604191108104416], 
             UndirectedEdge[266, 273] -> 
             RGBColor[
              0.6201768915138739, 0.7025265650383634, 0.9632417431642313], 
             UndirectedEdge[131, 297] -> 
             RGBColor[
              0.661825463388345, 0.7305095991449135, 0.9625961748230836], 
             UndirectedEdge[219, 360] -> 
             RGBColor[
              0.6791273798685485, 0.7447226267769615, 0.9524168198050489], 
             UndirectedEdge[58, 236] -> 
             RGBColor[
              0.37872373729690245`, 0.4924160531071824, 0.9462433386304323], 
             UndirectedEdge[272, 321] -> 
             RGBColor[
              0.6910136621934867, 0.7575569349020601, 0.9705125717626287], 
             UndirectedEdge[250, 391] -> 
             RGBColor[
              0.6758836664869842, 0.7467247242565342, 0.968329425449602], 
             UndirectedEdge[122, 298] -> 
             RGBColor[
              0.5646606969267575, 0.6574560172964772, 0.9588713049638121], 
             UndirectedEdge[113, 282] -> 
             RGBColor[
              0.5957099004617031, 0.6797465706178833, 0.9629320534424615], 
             UndirectedEdge[237, 343] -> 
             RGBColor[
              0.42614222745508407`, 0.5418181341082886, 0.9488459162816916], 
             UndirectedEdge[174, 398] -> 
             RGBColor[
              0.4345789430393856, 0.5506528935069537, 0.9489614986869832], 
             UndirectedEdge[223, 384] -> 
             RGBColor[
              0.27544931317854787`, 0.4040972575346754, 0.9390984138557021], 
             UndirectedEdge[143, 260] -> 
             RGBColor[
              0.7212955562075808, 0.7822008376494093, 0.9728556582187136], 
             UndirectedEdge[148, 161] -> 
             RGBColor[
              0.6619172939828173, 0.7334240520048589, 0.9686968217958785], 
             UndirectedEdge[137, 199] -> 
             RGBColor[
              0.3711412730945439, 0.4886446801685632, 0.9454293751631844], 
             UndirectedEdge[147, 387] -> 
             RGBColor[
              0.23975636225883246`, 0.36932951653835855`, 0.9369651421916634],
              UndirectedEdge[138, 381] -> 
             RGBColor[
              0.6852669117421597, 0.7528477106899845, 0.9700900808913773], 
             UndirectedEdge[42, 207] -> 
             RGBColor[
              0.44883849660335784`, 0.5623687051735637, 0.9500455840033636], 
             UndirectedEdge[185, 247] -> 
             RGBColor[
              0.4083985607986885, 0.5281560394804843, 0.9472437730547929], 
             UndirectedEdge[49, 380] -> 
             RGBColor[
              0.4163353072123992, 0.5259733408518871, 0.9489291305376067], 
             UndirectedEdge[63, 242] -> 
             RGBColor[
              0.6259336451900184, 0.6993344202277831, 0.9602451402470025], 
             UndirectedEdge[12, 238] -> 
             RGBColor[
              0.604999864685896, 0.6859396732466825, 0.9643084473925723], 
             UndirectedEdge[109, 382] -> 
             RGBColor[
              0.6461282238137432, 0.7224920892978379, 0.9660388107432059], 
             UndirectedEdge[4, 115] -> 
             RGBColor[
              0.5028800513686987, 0.6060815619571808, 0.9543442830767455], 
             UndirectedEdge[187, 279] -> 
             RGBColor[
              0.5391327263571691, 0.6331087642880147, 0.9583253917277205], 
             UndirectedEdge[152, 156] -> 
             RGBColor[
              0.45165970273044276`, 0.5652212329569897, 0.9501123571921883], 
             UndirectedEdge[143, 290] -> 
             RGBColor[
              0.6343663811109422, 0.7120295944960595, 0.9657375777854389], 
             UndirectedEdge[48, 234] -> 
             RGBColor[
              0.28498108852046034`, 0.4168635712525883, 0.9395406234482762], 
             UndirectedEdge[294, 341] -> 
             RGBColor[
              0.47724852188252453`, 0.5816831956434332, 0.9532414842974295], 
             UndirectedEdge[243, 351] -> 
             RGBColor[
              0.5556961753871996, 0.6471180040501037, 0.9595235136932161], 
             UndirectedEdge[241, 399] -> 
             RGBColor[
              0.7345580612830573, 0.79190431281656, 0.9749825573267474], 
             UndirectedEdge[78, 207] -> 
             RGBColor[
              0.39540141761237574`, 0.5159682579776574, 0.9466448655381918], 
             UndirectedEdge[174, 267] -> 
             RGBColor[
              0.3575457758802504, 0.4838425563925766, 0.9440132678065911], 
             UndirectedEdge[124, 293] -> 
             RGBColor[
              0.865797055444402, 0.8958270868491041, 0.9870616901260845], 
             UndirectedEdge[57, 392] -> 
             RGBColor[
              0.6320700641875977, 0.7067283765048094, 0.9672505580930582], 
             UndirectedEdge[272, 331] -> 
             RGBColor[
              0.5644623125534495, 0.6513271614547029, 0.9615141967888485], 
             UndirectedEdge[91, 255] -> 
             RGBColor[
              0.43209727191096925`, 0.5458198497756046, 0.9495282138127763], 
             UndirectedEdge[35, 337] -> 
             RGBColor[
              0.38705672984145717`, 0.5078394569190057, 0.9461112095481345], 
             UndirectedEdge[219, 339] -> 
             RGBColor[
              0.627310609298923, 0.6988326217664156, 0.9491520426075899], 
             UndirectedEdge[166, 185] -> 
             RGBColor[
              0.34709856136100686`, 0.4737878555006605, 0.9433844095861885], 
             UndirectedEdge[137, 238] -> 
             RGBColor[
              0.6572229081719061, 0.7299440678899551, 0.9679755140850004], 
             UndirectedEdge[218, 300] -> 
             RGBColor[
              0.6727177561395639, 0.7423642762838091, 0.9693491940443582], 
             UndirectedEdge[96, 110] -> 
             RGBColor[
              0.40083250565529177`, 0.5216027027962626, 0.9467616707114554], 
             UndirectedEdge[225, 375] -> 
             RGBColor[
              0.8977314836668511, 0.9201167474199785, 0.9470416131539713], 
             UndirectedEdge[24, 25] -> 
             RGBColor[
              0.8139712929191703, 0.8546452565523719, 0.9820806540844524], 
             UndirectedEdge[40, 361] -> 
             RGBColor[
              0.37766032318017173`, 0.5015321230040691, 0.9452851597344973], 
             UndirectedEdge[141, 394] -> 
             RGBColor[
              0.8267154927134532, 0.863598681061071, 0.8927807581428712], 
             UndirectedEdge[200, 360] -> 
             RGBColor[
              0.4809814353351816, 0.5881135515875743, 0.9526727660380157], 
             UndirectedEdge[68, 229] -> 
             RGBColor[
              0.28420481953061294`, 0.4160476633259621, 0.9394964160776914], 
             UndirectedEdge[96, 258] -> 
             RGBColor[
              0.6571245270155721, 0.7267455225483936, 0.9667864359647047], 
             UndirectedEdge[106, 310] -> 
             RGBColor[
              0.47764720649369086`, 0.5853839570954387, 0.9524165601912863], 
             UndirectedEdge[15, 394] -> 
             RGBColor[
              0.6380677766730334, 0.7167255621574553, 0.9648728137989897], 
             UndirectedEdge[115, 203] -> 
             RGBColor[
              0.3979332971812047, 0.5049946188203798, 0.9480301771013874], 
             UndirectedEdge[218, 298] -> 
             RGBColor[
              0.505364196600141, 0.6093164470544318, 0.9542032672478631], 
             UndirectedEdge[165, 262] -> 
             RGBColor[
              0.6809960984274017, 0.7485792480802307, 0.9705830152762902], 
             UndirectedEdge[141, 357] -> 
             RGBColor[
              0.8790067536554451, 0.9044490115372577, 0.8979926623439523], 
             UndirectedEdge[15, 239] -> 
             RGBColor[
              0.6788966558213005, 0.7486213928590562, 0.9689422549049203], 
             UndirectedEdge[80, 228] -> 
             RGBColor[
              0.34135724475727414`, 0.47008822111993065`, 0.9429719596789421],
              UndirectedEdge[260, 272] -> 
             RGBColor[
              0.7363579820854822, 0.7939677192239024, 0.9743569400638501], 
             UndirectedEdge[7, 361] -> 
             RGBColor[
              0.4051079932039422, 0.5253059152186512, 0.9470341009973904], 
             UndirectedEdge[22, 255] -> 
             RGBColor[
              0.5115521587672744, 0.6143401135062295, 0.9546904062969122], 
             UndirectedEdge[28, 380] -> 
             RGBColor[
              0.4142014978817525, 0.5237305719540517, 0.9488076132529144], 
             UndirectedEdge[53, 397] -> 
             RGBColor[
              0.825532046937629, 0.8623280905352237, 0.8769703527543042], 
             UndirectedEdge[187, 306] -> 
             RGBColor[
              0.4504597267992072, 0.5622560932014873, 0.9505679947920189], 
             UndirectedEdge[208, 392] -> 
             RGBColor[
              0.7115274802808712, 0.7734454428705142, 0.9728951193940717], 
             UndirectedEdge[33, 381] -> 
             RGBColor[
              0.601488612269399, 0.687354578050313, 0.9617705333646838], 
             UndirectedEdge[290, 321] -> 
             RGBColor[
              0.5363133611309655, 0.6344423730645286, 0.9566396988502548], 
             UndirectedEdge[20, 116] -> 
             RGBColor[
              0.2674443166696867, 0.3984313121418699, 0.9385419302347037], 
             UndirectedEdge[33, 156] -> 
             RGBColor[
              0.5538392519541584, 0.6486706807671807, 0.95801940117531], 
             UndirectedEdge[9, 202] -> 
             RGBColor[
              0.7720790517752363, 0.8222506011226582, 0.9769870273204155], 
             UndirectedEdge[76, 233] -> 
             RGBColor[
              0.6078493652366516, 0.691226094508262, 0.9631549161433435], 
             UndirectedEdge[115, 369] -> 
             RGBColor[
              0.6664877292900706, 0.7386943832330217, 0.96786479477601], 
             UndirectedEdge[183, 335] -> 
             RGBColor[
              0.6693614395655008, 0.7411147626820435, 0.9680312870700873], 
             UndirectedEdge[39, 296] -> 
             RGBColor[
              0.4820714489980445, 0.5891046445577414, 0.9527292406051883], 
             UndirectedEdge[10, 219] -> 
             RGBColor[
              0.6205394412940257, 0.6917156948764209, 0.9487664346067564], 
             UndirectedEdge[71, 143] -> 
             RGBColor[
              0.6087245242476209, 0.6909442992021568, 0.9637930283910874], 
             UndirectedEdge[232, 384] -> 
             RGBColor[
              0.39783630675181547`, 0.5065750345134337, 0.947871514879468], 
             UndirectedEdge[1, 57] -> 
             RGBColor[
              0.6548321763145833, 0.7248257033595504, 0.9675992193253393], 
             UndirectedEdge[288, 393] -> 
             RGBColor[
              0.6449612289290092, 0.7188260038130865, 0.967642944700579], 
             UndirectedEdge[328, 372] -> 
             RGBColor[
              0.7688280723320746, 0.819726407821213, 0.9776802383614337], 
             UndirectedEdge[16, 115] -> 
             RGBColor[
              0.45888267566160174`, 0.5679732464920949, 0.951540809202041], 
             UndirectedEdge[34, 244] -> 
             RGBColor[
              0.7003925676799447, 0.7648067638539704, 0.9715568281450341], 
             UndirectedEdge[233, 366] -> 
             RGBColor[
              0.6136484754463616, 0.6959340734234424, 0.9636114433418925], 
             UndirectedEdge[100, 105] -> 
             RGBColor[
              0.8666400717232647, 0.8951666450858218, 0.9139264674012608], 
             UndirectedEdge[88, 282] -> 
             RGBColor[
              0.40787111172843404`, 0.5276991896061909, 0.9472101644664412], 
             UndirectedEdge[189, 219] -> 
             RGBColor[
              0.8966446942120414, 0.9198803401539524, 0.9711495056088153], 
             UndirectedEdge[44, 328] -> 
             RGBColor[
              0.7247537627185022, 0.7839448977518939, 0.9742105472591375], 
             UndirectedEdge[153, 154] -> 
             RGBColor[
              0.3165252623864808, 0.4467454202867325, 0.941456860893243], 
             UndirectedEdge[73, 258] -> 
             RGBColor[
              0.8817250562298229, 0.9084469243304534, 0.9857823736451612], 
             UndirectedEdge[22, 141] -> 
             RGBColor[
              0.7283602705768679, 0.7840751103066326, 0.8848152401506717], 
             UndirectedEdge[100, 273] -> 
             RGBColor[
              0.6726333953555919, 0.7435327558067437, 0.968451813560852], 
             UndirectedEdge[230, 391] -> 
             RGBColor[
              0.594923453092361, 0.6818973403401531, 0.9613407669585776], 
             UndirectedEdge[338, 384] -> 
             RGBColor[
              0.37201246687801726`, 0.4856100779531553, 0.9458385676087602], 
             UndirectedEdge[76, 207] -> 
             RGBColor[
              0.4861406257633871, 0.5937098862371578, 0.9526899173333336], 
             UndirectedEdge[144, 370] -> 
             RGBColor[
              0.6603843141820395, 0.724219322933985, 0.8254948306796943], 
             UndirectedEdge[6, 340] -> 
             RGBColor[
              0.7763405463128363, 0.8258050978566747, 0.9781820915320865], 
             UndirectedEdge[30, 370] -> 
             RGBColor[
              0.4134710236446071, 0.5312472066880162, 0.9479268277500371], 
             UndirectedEdge[164, 245] -> 
             RGBColor[
              0.7798487172697322, 0.8281368918045241, 0.9662941782359951], 
             UndirectedEdge[56, 108] -> 
             RGBColor[
              0.6641991416587063, 0.735110080956766, 0.9690431664790955], 
             UndirectedEdge[50, 322] -> 
             RGBColor[
              0.890546649281909, 0.9121723536528367, 0.8306095416638314], 
             UndirectedEdge[379, 399] -> 
             RGBColor[
              0.6951843079286435, 0.7605087506638135, 0.9712270535824388], 
             UndirectedEdge[6, 13] -> 
             RGBColor[
              0.5974459914392181, 0.6758812749331741, 0.9651098027747538], 
             UndirectedEdge[55, 60] -> 
             RGBColor[
              0.8307372974801108, 0.8679802889862884, 0.9504836191247981], 
             UndirectedEdge[44, 47] -> 
             RGBColor[
              0.7538933060877353, 0.8059494981010722, 0.9343283694083611], 
             UndirectedEdge[156, 264] -> 
             RGBColor[
              0.4831871948034481, 0.5913121579333308, 0.9524574124293932], 
             UndirectedEdge[32, 43] -> 
             RGBColor[
              0.6854387190985171, 0.7516468518856454, 0.9712527401158876], 
             UndirectedEdge[144, 207] -> 
             RGBColor[
              0.7392098636185443, 0.791679677837922, 0.8307425389858203], 
             UndirectedEdge[14, 213] -> 
             RGBColor[
              0.5759124280611436, 0.6545654760168087, 0.963683930025192], 
             UndirectedEdge[127, 139] -> 
             RGBColor[
              0.4820341472729985, 0.5786705737056641, 0.9547872829838282], 
             UndirectedEdge[321, 342] -> 
             RGBColor[
              0.6986758619935793, 0.7635427036207678, 0.9712762682313738], 
             UndirectedEdge[82, 182] -> 
             RGBColor[
              0.5657511868218043, 0.6546850896521488, 0.9606475840177701], 
             UndirectedEdge[50, 172] -> 
             RGBColor[
              0.5265182219582761, 0.6153440109213957, 0.9589167368546965], 
             UndirectedEdge[80, 96] -> 
             RGBColor[
              0.35911613381855284`, 0.485470078237093, 0.9441035403863578], 
             UndirectedEdge[78, 160] -> 
             RGBColor[
              0.5246975612533957, 0.6194118040510198, 0.9578661058873202], 
             UndirectedEdge[32, 293] -> 
             RGBColor[
              0.8942482540016463, 0.9185133002914392, 0.9897753908431592], 
             UndirectedEdge[322, 328] -> 
             RGBColor[
              0.9599981354681295, 0.9672782913922169, 0.8373062770614235], 
             UndirectedEdge[120, 254] -> 
             RGBColor[
              0.6546543883290952, 0.7292456716571419, 0.966825118055014], 
             UndirectedEdge[291, 321] -> 
             RGBColor[
              0.6270217425137492, 0.7075659608916465, 0.9641344552474418], 
             UndirectedEdge[65, 312] -> 
             RGBColor[
              0.8666626294758559, 0.8955331508935168, 0.9297485758832253], 
             UndirectedEdge[209, 334] -> 
             RGBColor[
              0.29744178889377754`, 0.42996055739897976`, 0.9402502419005824],
              UndirectedEdge[295, 310] -> 
             RGBColor[
              0.5116097845592016, 0.6129563079657265, 0.9550902187456259], 
             UndirectedEdge[109, 205] -> 
             RGBColor[
              0.5316645340241446, 0.6306682457919368, 0.9562737261511911], 
             UndirectedEdge[194, 376] -> 
             RGBColor[
              0.8392057873639507, 0.8732704424945575, 0.8901373288417767], 
             UndirectedEdge[142, 338] -> 
             RGBColor[
              0.5437229272323212, 0.6404577926227579, 0.9572230070358885], 
             UndirectedEdge[232, 386] -> 
             RGBColor[
              0.5710027412409042, 0.6626047745765419, 0.9593705739238956], 
             UndirectedEdge[169, 378] -> 
             RGBColor[
              0.6217755951428156, 0.7016603647203725, 0.9648472059215998], 
             UndirectedEdge[94, 324] -> 
             RGBColor[
              0.6059548559290292, 0.6702695028605192, 0.8735131718364749], 
             UndirectedEdge[196, 231] -> 
             RGBColor[
              0.4969368297793761, 0.5964852718658147, 0.9552954284633102], 
             UndirectedEdge[207, 366] -> 
             RGBColor[
              0.49193973597309715`, 0.5984178651523382, 0.9531464445318827], 
             UndirectedEdge[156, 310] -> 
             RGBColor[
              0.4344401558260481, 0.5503065269079954, 0.9490151428900878], 
             UndirectedEdge[206, 369] -> 
             RGBColor[
              0.6149827193409082, 0.6968802958820353, 0.963810131723744], 
             UndirectedEdge[119, 225] -> 
             RGBColor[
              0.6885621037285237, 0.75126613360906, 0.9292527809594957], 
             UndirectedEdge[69, 100] -> 
             RGBColor[
              0.5406874487041622, 0.6332235744045117, 0.9589458185815518], 
             UndirectedEdge[64, 182] -> 
             RGBColor[
              0.41534422867756493`, 0.5341720278977489, 0.947686344870222], 
             UndirectedEdge[217, 268] -> 
             RGBColor[
              0.7569004473194857, 0.8085147607466381, 0.9378890732814974], 
             UndirectedEdge[235, 275] -> 
             RGBColor[
              0.38560503926494083`, 0.5084134367636551, 0.9457913900181822], 
             UndirectedEdge[5, 99] -> 
             RGBColor[
              0.2907136827399419, 0.4209680925350847, 0.9399374160584877], 
             UndirectedEdge[52, 267] -> 
             RGBColor[
              0.5120352142820712, 0.6092989036782672, 0.9566390256457211], 
             UndirectedEdge[290, 346] -> 
             RGBColor[
              0.49556865121409666`, 0.6013639820257501, 0.9534321260328087], 
             UndirectedEdge[19, 108] -> 
             RGBColor[
              0.7069032568918052, 0.7684948896802215, 0.950015506040768], 
             UndirectedEdge[92, 327] -> 
             RGBColor[
              0.618390870772543, 0.6834646650678322, 0.8774589863809461], 
             UndirectedEdge[151, 244] -> 
             RGBColor[
              0.8394928514861699, 0.8748528286214053, 0.9845527716705083], 
             UndirectedEdge[114, 327] -> 
             RGBColor[
              0.5511131302629271, 0.632159446744522, 0.9617172417191745], 
             UndirectedEdge[99, 174] -> 
             RGBColor[
              0.3305717615222641, 0.45549115705104326`, 0.942477137593382], 
             UndirectedEdge[180, 282] -> 
             RGBColor[
              0.518798282209065, 0.6192958817533252, 0.9555169698183135], 
             UndirectedEdge[199, 277] -> 
             RGBColor[
              0.40922601002382397`, 0.5195635853055995, 0.9484275451632455], 
             UndirectedEdge[237, 286] -> 
             RGBColor[
              0.4557185889027514, 0.5658295567314042, 0.9511742757966337], 
             UndirectedEdge[290, 313] -> 
             RGBColor[
              0.3792431837306359, 0.4976192641467634, 0.9458489893933018], 
             UndirectedEdge[56, 237] -> 
             RGBColor[
              0.6061216934232292, 0.6848063143526195, 0.9653425228334019], 
             UndirectedEdge[203, 361] -> 
             RGBColor[
              0.31561537237902854`, 0.4376045656531896, 0.9417047187343424], 
             UndirectedEdge[169, 315] -> 
             RGBColor[
              0.37170449759868096`, 0.49385896702074783`, 0.945040699270532], 
             UndirectedEdge[23, 304] -> 
             RGBColor[
              0.501779062040806, 0.5976765569650393, 0.9561883299637601], 
             UndirectedEdge[129, 270] -> 
             RGBColor[
              0.6660648113471638, 0.7341823978939517, 0.9628792712607503], 
             UndirectedEdge[85, 284] -> 
             RGBColor[
              0.79732270508452, 0.8420703916095189, 0.9803068675619264], 
             UndirectedEdge[203, 369] -> 
             RGBColor[
              0.4671156122900648, 0.5597305326620063, 0.9544537551897753], 
             UndirectedEdge[1, 222] -> 
             RGBColor[
              0.7813441363975326, 0.8297437683191238, 0.9769480866956941], 
             UndirectedEdge[25, 205] -> 
             RGBColor[
              0.655517713781979, 0.7284561771525895, 0.9679310684311581], 
             UndirectedEdge[301, 380] -> 
             RGBColor[
              0.6413119927445284, 0.7188172452741727, 0.9654988591636038], 
             UndirectedEdge[169, 329] -> 
             RGBColor[
              0.4344339160742559, 0.5505272784390256, 0.9489522576970075], 
             UndirectedEdge[302, 340] -> 
             RGBColor[
              0.4649755113711484, 0.5679434251556468, 0.9526755480597942], 
             UndirectedEdge[205, 391] -> 
             RGBColor[
              0.5680514642266604, 0.6600814492096745, 0.9592253055597311], 
             UndirectedEdge[96, 203] -> 
             RGBColor[
              0.2869905413085705, 0.4128111757058013, 0.939880769810477], 
             UndirectedEdge[4, 195] -> 
             RGBColor[
              0.4611771435951942, 0.5722252627320641, 0.9510612774140306], 
             UndirectedEdge[269, 298] -> 
             RGBColor[
              0.47858630191380236`, 0.5875769458176536, 0.9520952132874942], 
             UndirectedEdge[168, 220] -> 
             RGBColor[
              0.4199504480066065, 0.5285514831426402, 0.9492462050784625], 
             UndirectedEdge[291, 338] -> 
             RGBColor[
              0.6038687686870097, 0.6887693337095147, 0.9623117683356632], 
             UndirectedEdge[10, 360] -> 
             RGBColor[
              0.3428792372825023, 0.46914549032501157`, 0.9431517261372007], 
             UndirectedEdge[87, 348] -> 
             RGBColor[
              0.5478663153635979, 0.6370979426990565, 0.9602408088488416], 
             UndirectedEdge[259, 274] -> 
             RGBColor[
              0.5284614376634456, 0.6275523628959103, 0.9561639911800967], 
             UndirectedEdge[293, 336] -> 
             RGBColor[
              0.8020986446878395, 0.8456343816952482, 0.9808272079680709], 
             UndirectedEdge[229, 245] -> 
             RGBColor[
              0.4531173725338669, 0.5614704626547431, 0.9513117453289887], 
             UndirectedEdge[173, 197] -> 
             RGBColor[
              0.3039471455517543, 0.4347124201666045, 0.940697079283477], 
             UndirectedEdge[19, 344] -> 
             RGBColor[
              0.6896490206248711, 0.7535501374489336, 0.948916081363161], 
             UndirectedEdge[83, 125] -> 
             RGBColor[
              0.38080126460714203`, 0.5042526485998045, 0.9454852977447984], 
             UndirectedEdge[240, 315] -> 
             RGBColor[
              0.45225945551493935`, 0.5592571108166652, 0.9513822806402334], 
             UndirectedEdge[7, 154] -> 
             RGBColor[
              0.3332249009132686, 0.4612098078303986, 0.9425209470932594], 
             UndirectedEdge[200, 225] -> 
             RGBColor[
              0.7721718276007544, 0.8207745483852036, 0.9353843950317318], 
             UndirectedEdge[13, 140] -> 
             RGBColor[
              0.457678790484407, 0.5656725257097989, 0.9516254240169923], 
             UndirectedEdge[104, 366] -> 
             RGBColor[
              0.563680072660958, 0.6566599023408812, 0.9587941066294633], 
             UndirectedEdge[116, 172] -> 
             RGBColor[
              0.27882746412289783`, 0.41039572184842865`, 0.9391901836423064],
              UndirectedEdge[143, 267] -> 
             RGBColor[
              0.539929281911024, 0.6310899613127712, 0.9594192456220927], 
             UndirectedEdge[51, 395] -> 
             RGBColor[
              0.8418903338519197, 0.8770177601969569, 0.984714242450689], 
             UndirectedEdge[213, 224] -> 
             RGBColor[
              0.7677789001985943, 0.8190327333541826, 0.9773510221502697], 
             UndirectedEdge[130, 362] -> 
             RGBColor[
              0.5829615655471518, 0.6719169461722896, 0.9605831334324253], 
             UndirectedEdge[153, 278] -> 
             RGBColor[
              0.49949213034269885`, 0.6013938456387184, 0.9546907158101485], 
             UndirectedEdge[83, 303] -> 
             RGBColor[
              0.5932505250869285, 0.6760342373067425, 0.963444983379866], 
             UndirectedEdge[94, 296] -> 
             RGBColor[
              0.3135138930497128, 0.437919128060746, 0.9414926503754321], 
             UndirectedEdge[147, 328] -> 
             RGBColor[
              0.5682587435776187, 0.6413239679243555, 0.9640353738149032], 
             UndirectedEdge[78, 102] -> 
             RGBColor[
              0.27361664565237814`, 0.4049188212509393, 0.9388934352391255], 
             UndirectedEdge[22, 45] -> 
             RGBColor[
              0.6389599606432492, 0.715191920926887, 0.9664868268913145], 
             UndirectedEdge[199, 238] -> 
             RGBColor[
              0.5297984931101454, 0.6147916364281081, 0.9597368254887774], 
             UndirectedEdge[21, 182] -> 
             RGBColor[
              0.6715966730188533, 0.25731476824530675`, 0.42462664279747353`],
              UndirectedEdge[126, 212] -> 
             RGBColor[
              0.5691233073240094, 0.6610789654552736, 0.9592226180013643], 
             UndirectedEdge[273, 365] -> 
             RGBColor[
              0.6146420627611805, 0.698033141715733, 0.9628060211700735], 
             UndirectedEdge[149, 367] -> 
             RGBColor[
              0.9255317434980845, 0.9434579056481982, 0.9927592379984302], 
             UndirectedEdge[81, 89] -> 
             RGBColor[
              0.307439478150547, 0.4314763606441757, 0.9411488514030586], 
             UndirectedEdge[57, 337] -> 
             RGBColor[
              0.424935167978152, 0.5418105818672703, 0.9484822170494551], 
             UndirectedEdge[255, 288] -> 
             RGBColor[
              0.4905043823663925, 0.5964785202323895, 0.9532473233776861], 
             UndirectedEdge[2, 283] -> 
             RGBColor[
              0.5417519373061064, 0.6263535479848119, 0.9605731171381051], 
             UndirectedEdge[94, 128] -> 
             RGBColor[
              0.5288093231665317, 0.6111707059929055, 0.9600753126297306], 
             UndirectedEdge[176, 393] -> 
             RGBColor[
              0.7887684801670302, 0.8352759555302277, 0.9794839334504881], 
             UndirectedEdge[65, 326] -> 
             RGBColor[
              0.7379773393552235, 0.7926707595241516, 0.918517147638727], 
             UndirectedEdge[97, 282] -> 
             RGBColor[
              0.42038435672507335`, 0.5385375334882994, 0.9480074973725989], 
             UndirectedEdge[12, 149] -> 
             RGBColor[
              0.6589957581306924, 0.7289613629320064, 0.9694674262282208], 
             UndirectedEdge[78, 144] -> 
             RGBColor[
              0.6513005073151132, 0.7162354507916604, 0.8249202634942088], 
             UndirectedEdge[201, 348] -> 
             RGBColor[
              0.5759330395983256, 0.6592457845311811, 0.9629793512441879], 
             UndirectedEdge[242, 381] -> 
             RGBColor[
              0.753783189135433, 0.8071611463427184, 0.9692155444897799], 
             UndirectedEdge[43, 367] -> 
             RGBColor[
              0.6839277906328671, 0.7504420785401968, 0.9711086264100122], 
             UndirectedEdge[111, 197] -> 
             RGBColor[
              0.31511966842368366`, 0.4443894979309424, 0.9414089825614023], 
             UndirectedEdge[69, 216] -> 
             RGBColor[
              0.36917566909511734`, 0.494183142086709, 0.9447445250788826], 
             UndirectedEdge[197, 295] -> 
             RGBColor[
              0.4495894655837739, 0.5562643715933174, 0.9512471969083852], 
             UndirectedEdge[193, 275] -> 
             RGBColor[
              0.6609724869882516, 0.7316619444724901, 0.969138349173679], 
             UndirectedEdge[149, 238] -> 
             RGBColor[
              0.869876021632304, 0.8991127138348238, 0.9874419432462418], 
             UndirectedEdge[79, 349] -> 
             RGBColor[
              0.48068286399630145`, 0.5859958333737667, 0.95316741916933], 
             UndirectedEdge[16, 110] -> 
             RGBColor[
              0.3733525230083173, 0.49780092301154094`, 0.9450106705167849], 
             UndirectedEdge[49, 372] -> 
             RGBColor[
              0.4307856987030838, 0.5377048196467429, 0.9500667182892816], 
             UndirectedEdge[320, 343] -> 
             RGBColor[
              0.6831631826330415, 0.7507223546399475, 0.9703119038800513], 
             UndirectedEdge[221, 358] -> 
             RGBColor[
              0.5472634290678389, 0.6379079732901393, 0.9597929002117489], 
             UndirectedEdge[240, 245] -> 
             RGBColor[
              0.6155475893631337, 0.6987682890047072, 0.9628773075412326], 
             UndirectedEdge[85, 115] -> 
             RGBColor[
              0.7381256782656892, 0.795135060871065, 0.9748785296924642], 
             UndirectedEdge[70, 280] -> 
             RGBColor[
              0.8166100833062704, 0.8536424705427086, 0.7651871020295968], 
             UndirectedEdge[151, 171] -> 
             RGBColor[
              0.8587582235003903, 0.8902145133209525, 0.9863903200516251], 
             UndirectedEdge[23, 163] -> 
             RGBColor[
              0.5356500839206366, 0.6241368566868637, 0.9595642768820459], 
             UndirectedEdge[255, 360] -> 
             RGBColor[
              0.47883299169887955`, 0.5863693482573414, 0.9525036326849576], 
             UndirectedEdge[165, 307] -> 
             RGBColor[
              0.7085288122187696, 0.7709315454706848, 0.9727504913616004], 
             UndirectedEdge[81, 169] -> 
             RGBColor[
              0.3343965258706906, 0.4546459232725998, 0.942916065472821], 
             UndirectedEdge[44, 316] -> 
             RGBColor[
              0.6936585798216585, 0.759150442966205, 0.971244660955439], 
             UndirectedEdge[195, 337] -> 
             RGBColor[
              0.49592146714918806`, 0.6016504138960341, 0.9534599009956264], 
             UndirectedEdge[316, 390] -> 
             RGBColor[
              0.8762413673763276, 0.9041550976803265, 0.9880578779218988], 
             UndirectedEdge[39, 177] -> 
             RGBColor[
              0.5902061647581469, 0.6781949788922101, 0.960882337767631], 
             UndirectedEdge[45, 190] -> 
             RGBColor[
              0.6944563138141462, 0.7602463605132408, 0.9708557031027676], 
             UndirectedEdge[287, 396] -> 
             RGBColor[
              0.766566891698842, 0.8178412500563772, 0.9772951438659456], 
             UndirectedEdge[136, 343] -> 
             RGBColor[
              0.6263689189419321, 0.7061103717345227, 0.9647158986997313], 
             UndirectedEdge[296, 360] -> 
             RGBColor[
              0.4034222699005159, 0.5238458264201402, 0.9469266881991226], 
             UndirectedEdge[167, 228] -> 
             RGBColor[
              0.6458914101743547, 0.7162305756679818, 0.9546084250827079], 
             UndirectedEdge[123, 279] -> 
             RGBColor[
              0.8550104536845947, 0.8834882174372811, 0.7531408165558464], 
             UndirectedEdge[33, 333] -> 
             RGBColor[
              0.8154326161047294, 0.8544414267236958, 0.8781698920531096], 
             UndirectedEdge[164, 209] -> 
             RGBColor[
              0.6241970162317986, 0.696652088677871, 0.9552340348864503], 
             UndirectedEdge[22, 29] -> 
             RGBColor[
              0.6491660124631136, 0.7232574517658201, 0.9674795279242547], 
             UndirectedEdge[24, 366] -> 
             RGBColor[
              0.6514533540087253, 0.7254675318840798, 0.9673794803303124], 
             UndirectedEdge[178, 319] -> 
             RGBColor[
              0.5698974633907431, 0.6601696055134457, 0.9601104808750294], 
             UndirectedEdge[294, 368] -> 
             RGBColor[
              0.44798428802700907`, 0.5580713944902425, 0.9508377236730496], 
             UndirectedEdge[13, 69] -> 
             RGBColor[
              0.3180958519405167, 0.4491632902467032, 0.9415182170606945], 
             UndirectedEdge[214, 295] -> 
             RGBColor[
              0.5492935187436371, 0.644980249763932, 0.9576615444054084], 
             UndirectedEdge[80, 146] -> 
             RGBColor[
              0.5677242727460463, 0.6546406243520467, 0.9615154517891098], 
             UndirectedEdge[56, 231] -> 
             RGBColor[
              0.5872167637505898, 0.6674664405586523, 0.9641732644991479], 
             UndirectedEdge[134, 351] -> 
             RGBColor[
              0.6491597996199236, 0.7247985121071046, 0.9663832688655161], 
             UndirectedEdge[143, 291] -> 
             RGBColor[
              0.7250747624937259, 0.7851531823231774, 0.9732323341826259], 
             UndirectedEdge[120, 320] -> 
             RGBColor[
              0.7877519779238317, 0.8343609718391956, 0.9794146970129793], 
             UndirectedEdge[132, 220] -> 
             RGBColor[
              0.753881947703315, 0.8076735490337366, 0.9764103048131434], 
             UndirectedEdge[6, 247] -> 
             RGBColor[
              0.6560629878269106, 0.7274294525952407, 0.9688163731888086], 
             UndirectedEdge[166, 289] -> 
             RGBColor[
              0.32835990696872996`, 0.45755737489822496`, 0.9421903990982541],
              UndirectedEdge[114, 392] -> 
             RGBColor[
              0.8737637785367278, 0.9021795355919873, 0.9878215632866081], 
             UndirectedEdge[305, 325] -> 
             RGBColor[
              0.526972573606182, 0.6251133336276942, 0.9564767440030613], 
             UndirectedEdge[44, 128] -> 
             RGBColor[
              0.6801696020147905, 0.748394698211557, 0.9699580702104673], 
             UndirectedEdge[90, 242] -> 
             RGBColor[
              0.648055375869041, 0.7185780455177849, 0.9616516822072882], 
             UndirectedEdge[1, 337] -> 
             RGBColor[
              0.7078403440006061, 0.7700700783431867, 0.9711615989049447], 
             UndirectedEdge[74, 224] -> 
             RGBColor[
              0.4519804670359838, 0.5551939365285172, 0.9517915713791534], 
             UndirectedEdge[160, 370] -> 
             RGBColor[
              0.533781368120322, 0.6273956761933446, 0.9584406730728058], 
             UndirectedEdge[30, 84] -> 
             RGBColor[
              0.4275567997768928, 0.5434475980021085, 0.9488243609496236], 
             UndirectedEdge[293, 299] -> 
             RGBColor[
              0.5536848770366921, 0.6344859564187262, 0.96192074502719], 
             UndirectedEdge[186, 399] -> 
             RGBColor[
              0.39129566899958595`, 0.5043988919794419, 0.9470713501397972], 
             UndirectedEdge[163, 371] -> 
             RGBColor[
              0.8210740304359582, 0.8603907114752678, 0.9827363791997136], 
             UndirectedEdge[90, 138] -> 
             RGBColor[
              0.5795390984757676, 0.6642646098650511, 0.9625262186088857], 
             UndirectedEdge[71, 286] -> 
             RGBColor[
              0.5093837289901479, 0.6123116037867391, 0.9545937710687826], 
             UndirectedEdge[60, 201] -> 
             RGBColor[
              0.7681781814081905, 0.8190478043222249, 0.9774695937777473], 
             UndirectedEdge[128, 380] -> 
             RGBColor[
              0.7097935201376783, 0.7724447294860204, 0.9722901735610887], 
             UndirectedEdge[54, 128] -> 
             RGBColor[
              0.8993254161624185, 0.9218658586268098, 0.9661346897151446], 
             UndirectedEdge[25, 138] -> 
             RGBColor[
              0.8162949408520421, 0.8564605079779097, 0.9823122535946766], 
             UndirectedEdge[95, 129] -> 
             RGBColor[
              0.6558493065140315, 0.7253342410536945, 0.9622283483259995], 
             UndirectedEdge[132, 302] -> 
             RGBColor[
              0.5928762670686295, 0.6686198128184637, 0.9652219932108332], 
             UndirectedEdge[15, 100] -> 
             RGBColor[
              0.6790219942447389, 0.7487193081880534, 0.9689547474676145], 
             UndirectedEdge[33, 63] -> 
             RGBColor[
              0.47363906832398445`, 0.5795278519353777, 0.9528001291219065], 
             UndirectedEdge[275, 338] -> 
             RGBColor[
              0.47920432934006174`, 0.5873591074788417, 0.9523426890019384], 
             UndirectedEdge[252, 277] -> 
             RGBColor[
              0.48341740515261683`, 0.5898368312887114, 0.9529348122609274], 
             UndirectedEdge[146, 192] -> 
             RGBColor[
              0.7059841412476134, 0.7698867012058352, 0.9715707315832609], 
             UndirectedEdge[237, 254] -> 
             RGBColor[
              0.46003787760810766`, 0.5693361498841512, 0.9515143060255953], 
             UndirectedEdge[37, 236] -> 
             RGBColor[
              0.6107049287951928, 0.6941415555183752, 0.9629714173249904], 
             UndirectedEdge[265, 362] -> 
             RGBColor[
              0.7195403375795357, 0.7794476228716606, 0.9688362776822442], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.9096647734010234, 0.9284657886367905, 0.9005705659383776], 
             UndirectedEdge[341, 379] -> 
             RGBColor[
              0.7491574750657932, 0.8041803769797942, 0.9755759919465539], 
             UndirectedEdge[324, 380] -> 
             RGBColor[
              0.7869390529001759, 0.8315435263536342, 0.8857280327678331], 
             UndirectedEdge[63, 264] -> 
             RGBColor[
              0.4029870111732741, 0.5221693291015278, 0.9472381403759896], 
             UndirectedEdge[153, 337] -> 
             RGBColor[
              0.41104524022081274`, 0.529779824571931, 0.9475971631351383], 
             UndirectedEdge[112, 155] -> 
             RGBColor[
              0.9677119129346327, 0.9734627226157128, 0.8463187759599735], 
             UndirectedEdge[10, 177] -> 
             RGBColor[
              0.45296904708609553`, 0.5599292288540683, 0.9514294001632728], 
             UndirectedEdge[238, 367] -> 
             RGBColor[
              0.8715358500532882, 0.9004362159628743, 0.9876002591627817], 
             UndirectedEdge[87, 228] -> 
             RGBColor[
              0.5656035286707923, 0.6528602819202808, 0.9613563896581696], 
             UndirectedEdge[66, 352] -> 
             RGBColor[
              0.5023779053121523, 0.5987756957146859, 0.9561480701866549], 
             UndirectedEdge[86, 386] -> 
             RGBColor[
              0.421126943702344, 0.5339823352235259, 0.9489314152681976], 
             UndirectedEdge[52, 133] -> 
             RGBColor[
              0.809542531613999, 0.8517938084147009, 0.9814778034464442], 
             UndirectedEdge[105, 112] -> 
             RGBColor[
              0.9640456986190803, 0.972113852393254, 0.9192313727053311], 
             UndirectedEdge[4, 258] -> 
             RGBColor[
              0.6736419200756947, 0.7410520582287576, 0.9678389096447384], 
             UndirectedEdge[141, 339] -> 
             RGBColor[
              0.6438243329388476, 0.7102143400471985, 0.879363689341258], 
             UndirectedEdge[251, 282] -> 
             RGBColor[
              0.3809582960903477, 0.5043886613779254, 0.9454953036520508], 
             UndirectedEdge[94, 390] -> 
             RGBColor[
              0.5555934885583467, 0.632527672439537, 0.9626300102353086], 
             UndirectedEdge[239, 337] -> 
             RGBColor[
              0.6116085241138474, 0.6939938562431568, 0.9636450866923616], 
             UndirectedEdge[80, 243] -> 
             RGBColor[
              0.3648723322582957, 0.49045580801065247`, 0.9444703202609317], 
             UndirectedEdge[366, 382] -> 
             RGBColor[
              0.6074634646611325, 0.6911022959901985, 0.9629949792690329], 
             UndirectedEdge[99, 306] -> 
             RGBColor[
              0.3955405541272975, 0.5094326455660863, 0.947261013041429], 
             UndirectedEdge[214, 261] -> 
             RGBColor[
              0.4721238900104835, 0.582330468706201, 0.9515864685498703], 
             UndirectedEdge[21, 60] -> 
             RGBColor[
              0.7745186604395752, 0.34172041002251746`, 0.43268818804647746`],
              UndirectedEdge[60, 159] -> 
             RGBColor[
              0.8128533258469128, 0.8546424522245654, 0.9807565182129692], 
             UndirectedEdge[9, 300] -> 
             RGBColor[
              0.7202930797939517, 0.7809880672703475, 0.9730944977965845], 
             UndirectedEdge[114, 369] -> 
             RGBColor[
              0.7954922366946602, 0.840449411066319, 0.9801751103606737], 
             UndirectedEdge[112, 350] -> 
             RGBColor[
              0.5606611378655448, 0.6312909026422774, 0.9597493327573842], 
             UndirectedEdge[18, 357] -> 
             RGBColor[
              0.5667665279681156, 0.6548489693849264, 0.961015138605282], 
             UndirectedEdge[71, 320] -> 
             RGBColor[
              0.6468006072902408, 0.7209334971215396, 0.9675233802557094], 
             UndirectedEdge[226, 255] -> 
             RGBColor[
              0.6040881796342265, 0.6893176800012627, 0.9620759206900824], 
             UndirectedEdge[208, 258] -> 
             RGBColor[
              0.7348354920369392, 0.7919499007747961, 0.9723197149477424], 
             UndirectedEdge[11, 358] -> 
             RGBColor[
              0.3163405152253339, 0.44830405217714864`, 0.9413821607501722], 
             UndirectedEdge[274, 299] -> 
             RGBColor[
              0.4358378646938993, 0.5418105671562042, 0.9504640635813772], 
             UndirectedEdge[147, 372] -> 
             RGBColor[
              0.4119502703246251, 0.5179075901858479, 0.9489940685076476], 
             UndirectedEdge[335, 337] -> 
             RGBColor[
              0.5433498888084674, 0.6401549432250839, 0.9571936400846779], 
             UndirectedEdge[36, 218] -> 
             RGBColor[
              0.42606684841279097`, 0.5418623335597126, 0.9488108610618338], 
             UndirectedEdge[262, 300] -> 
             RGBColor[
              0.6460491224415885, 0.7207134780395359, 0.9672497415092296], 
             UndirectedEdge[109, 136] -> 
             RGBColor[
              0.6572330556670958, 0.7311672683415251, 0.9671456366017943], 
             UndirectedEdge[219, 241] -> 
             RGBColor[
              0.9409728570601983, 0.9552264139531464, 0.9753775653534906], 
             UndirectedEdge[37, 348] -> 
             RGBColor[
              0.49608595205057604`, 0.5966467293335869, 0.9550798261488065], 
             UndirectedEdge[291, 384] -> 
             RGBColor[
              0.4442889668828973, 0.5437698341308975, 0.9518822987856724], 
             UndirectedEdge[10, 241] -> 
             RGBColor[
              0.604724714474152, 0.6796492775011964, 0.9661124716856423], 
             UndirectedEdge[131, 314] -> 
             RGBColor[
              0.48820690850577336`, 0.5933887427041176, 0.9534048142340351], 
             UndirectedEdge[1, 41] -> 
             RGBColor[
              0.8835984945647314, 0.909968907702219, 0.9869371979385456], 
             UndirectedEdge[78, 400] -> 
             RGBColor[
              0.3074920613089446, 0.44052403093139575`, 0.9408225900465804], 
             UndirectedEdge[191, 357] -> 
             RGBColor[
              0.8448712243645149, 0.879559960273154, 0.9849546918970584], 
             UndirectedEdge[215, 352] -> 
             RGBColor[
              0.4513487492662035, 0.5451408172750305, 0.9532420352407094], 
             UndirectedEdge[96, 369] -> 
             RGBColor[
              0.5555449734174364, 0.6465109401184432, 0.9597153874850995], 
             UndirectedEdge[212, 293] -> 
             RGBColor[
              0.7102496939801382, 0.7726535995092233, 0.9725119370682807], 
             UndirectedEdge[66, 107] -> 
             RGBColor[
              0.47632881978790714`, 0.578425952122763, 0.9535517407841426], 
             UndirectedEdge[146, 159] -> 
             RGBColor[
              0.8647124253330145, 0.895155174886862, 0.9859253485989056], 
             UndirectedEdge[11, 207] -> 
             RGBColor[
              0.39540141761237574`, 0.5159682579776574, 0.9466448655381918], 
             UndirectedEdge[99, 218] -> 
             RGBColor[
              0.38202191314731393`, 0.49845760381069965`, 0.9461967761030711],
              UndirectedEdge[131, 217] -> 
             RGBColor[
              0.4569237505564871, 0.5679916657906816, 0.9509420894462839], 
             UndirectedEdge[81, 163] -> 
             RGBColor[
              0.5005372525576288, 0.58723104464225, 0.9575646530807016], 
             UndirectedEdge[50, 54] -> 
             RGBColor[
              0.8744580906799098, 0.9023101204277666, 0.9636904313662225], 
             UndirectedEdge[120, 286] -> 
             RGBColor[
              0.6503350996237389, 0.725739078504395, 0.9664850878260525], 
             UndirectedEdge[17, 253] -> 
             RGBColor[
              0.35897490386270037`, 0.482606598490427, 0.9441949083944006], 
             UndirectedEdge[45, 365] -> 
             RGBColor[
              0.7202780677571289, 0.7812096236209128, 0.9728884861613605], 
             UndirectedEdge[35, 188] -> 
             RGBColor[
              0.6307390054744806, 0.6616307274432685, 0.6299529717786491], 
             UndirectedEdge[99, 279] -> 
             RGBColor[
              0.4842135536852594, 0.5802853166526135, 0.9550184099771304], 
             UndirectedEdge[107, 363] -> 
             RGBColor[
              0.5986273434695345, 0.6846253934451223, 0.9618230580823857], 
             UndirectedEdge[105, 271] -> 
             RGBColor[
              0.8129879844556029, 0.8531898258318407, 0.9086222762977834], 
             UndirectedEdge[191, 219] -> 
             RGBColor[
              0.9391657782290663, 0.95378549834505, 0.975205204561379], 
             UndirectedEdge[177, 339] -> 
             RGBColor[
              0.45974021509099283`, 0.567046155744063, 0.9518150081641062], 
             UndirectedEdge[80, 167] -> 
             RGBColor[
              0.6473465306182442, 0.7174909278599988, 0.9547011440706801], 
             UndirectedEdge[48, 56] -> 
             RGBColor[
              0.5911613056869522, 0.6716124042321729, 0.9643979003269969], 
             UndirectedEdge[42, 136] -> 
             RGBColor[
              0.5754670571447459, 0.6637283150551112, 0.9610009445991021], 
             UndirectedEdge[77, 102] -> 
             RGBColor[
              0.3254886263037715, 0.44996365892922363`, 0.9421944270220608], 
             UndirectedEdge[73, 203] -> 
             RGBColor[
              0.5115910705228213, 0.594512577487861, 0.9588767074909336], 
             UndirectedEdge[35, 284] -> 
             RGBColor[
              0.5059347959188057, 0.6032265439277039, 0.9562378574468775], 
             UndirectedEdge[274, 367] -> 
             RGBColor[
              0.7748903131932036, 0.8246331376834687, 0.9781745956914711], 
             UndirectedEdge[33, 310] -> 
             RGBColor[
              0.5200296107791751, 0.6197919021999496, 0.955753058308502], 
             UndirectedEdge[175, 295] -> 
             RGBColor[
              0.6146523067753965, 0.6980414582679613, 0.9628068276163977], 
             UndirectedEdge[70, 75] -> 
             RGBColor[
              0.5438664179233594, 0.6404381464754794, 0.9572719185816685], 
             UndirectedEdge[57, 258] -> 
             RGBColor[
              0.6553780759436657, 0.7252328344090915, 0.9666751536467288], 
             UndirectedEdge[70, 145] -> 
             RGBColor[
              0.5525302846429125, 0.6476080021356059, 0.9579163544736635], 
             UndirectedEdge[12, 336] -> 
             RGBColor[
              0.5700169057035197, 0.6586107198093145, 0.9608216729755477], 
             UndirectedEdge[18, 216] -> 
             RGBColor[
              0.38391770498878436`, 0.506951952621535, 0.9456838745701566], 
             UndirectedEdge[158, 311] -> 
             RGBColor[
              0.6557885567202995, 0.7283321976104062, 0.9682738779200575], 
             UndirectedEdge[8, 36] -> 
             RGBColor[
              0.45652840226321567`, 0.5665923952528499, 0.9512089061652876], 
             UndirectedEdge[119, 200] -> 
             RGBColor[
              0.4768859709411073, 0.5845662661734528, 0.9524118066683023], 
             UndirectedEdge[181, 362] -> 
             RGBColor[
              0.6256916268879261, 0.7052979948521967, 0.9648420666117474], 
             UndirectedEdge[9, 306] -> 
             RGBColor[
              0.5732315121184861, 0.6644141911799468, 0.9595460309316355], 
             UndirectedEdge[82, 253] -> 
             RGBColor[
              0.5951010448449043, 0.6801064615050015, 0.9625177310179416], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.7006984703883856, 0.7649083580829869, 0.9717498180626548], 
             UndirectedEdge[146, 314] -> 
             RGBColor[
              0.6946702780454843, 0.760701597374618, 0.9706800628279428], 
             UndirectedEdge[27, 277] -> 
             RGBColor[
              0.48341740515261683`, 0.5898368312887114, 0.9529348122609274], 
             UndirectedEdge[6, 302] -> 
             RGBColor[
              0.5831857520536426, 0.6608928591875359, 0.9642977032378789], 
             UndirectedEdge[93, 296] -> 
             RGBColor[
              0.5114963518142699, 0.612993106240719, 0.955045676741852], 
             UndirectedEdge[153, 284] -> 
             RGBColor[
              0.5299233062981613, 0.6251669115806292, 0.9577238110338813], 
             UndirectedEdge[43, 199] -> 
             RGBColor[
              0.34219043368972435`, 0.4647974990054305, 0.9432451927360078], 
             UndirectedEdge[213, 250] -> 
             RGBColor[
              0.7926303113952526, 0.8384468446587326, 0.979827978568711], 
             UndirectedEdge[3, 232] -> 
             RGBColor[
              0.5595113049431197, 0.6532755089066948, 0.9584659259640158], 
             UndirectedEdge[5, 235] -> 
             RGBColor[
              0.3369573876006292, 0.4662772859940957, 0.9426916046715615], 
             UndirectedEdge[25, 391] -> 
             RGBColor[
              0.7381383262959589, 0.7954039666744266, 0.974522332670815], 
             UndirectedEdge[288, 341] -> 
             RGBColor[
              0.5383571418960704, 0.6351813239314038, 0.9571144408351491], 
             UndirectedEdge[181, 265] -> 
             RGBColor[
              0.847553847075197, 0.8816690760243018, 0.9800801533564083], 
             UndirectedEdge[295, 363] -> 
             RGBColor[
              0.575481550846761, 0.6662408739826498, 0.9597231622224887], 
             UndirectedEdge[278, 284] -> 
             RGBColor[
              0.6852682918634094, 0.7540560649263923, 0.9692647972028138], 
             UndirectedEdge[167, 351] -> 
             RGBColor[
              0.8381703737471482, 0.8741531238994501, 0.9697543375029645], 
             UndirectedEdge[198, 311] -> 
             RGBColor[
              0.6738554103517042, 0.7430846186658329, 0.9696726989218175], 
             UndirectedEdge[54, 328] -> 
             RGBColor[
              0.9439095768661302, 0.9574160581671467, 0.9703871667638146], 
             UndirectedEdge[261, 310] -> 
             RGBColor[
              0.4344401558260481, 0.5503065269079954, 0.9490151428900878], 
             UndirectedEdge[68, 319] -> 
             RGBColor[
              0.3526303864133147, 0.47647717585068483`, 0.9438138596109422], 
             UndirectedEdge[100, 141] -> 
             RGBColor[
              0.8676697102851587, 0.8955924270916691, 0.8968626918114959], 
             UndirectedEdge[139, 325] -> 
             RGBColor[
              0.45467064744518004`, 0.5572939996698711, 0.9520599450474359], 
             UndirectedEdge[123, 338] -> 
             RGBColor[
              0.7625461737456567, 0.8095576141422426, 0.7450849561406367], 
             UndirectedEdge[317, 370] -> 
             RGBColor[
              0.6602947932526031, 0.7243315887787444, 0.8378298713306813], 
             UndirectedEdge[160, 400] -> 
             RGBColor[
              0.5246975612533957, 0.6194118040510198, 0.9578661058873202], 
             UndirectedEdge[150, 266] -> 
             RGBColor[
              0.6330311263808222, 0.7129622119800336, 0.9642536756195713], 
             UndirectedEdge[134, 201] -> 
             RGBColor[
              0.7106489646392657, 0.7730562187001281, 0.9724530478078057], 
             UndirectedEdge[161, 251] -> 
             RGBColor[
              0.5998974212729766, 0.6800710153519697, 0.9646439926953893], 
             UndirectedEdge[86, 371] -> 
             RGBColor[
              0.5667171595029448, 0.6492412350311669, 0.9625027067100718], 
             UndirectedEdge[105, 350] -> 
             RGBColor[
              0.5843711932825976, 0.6483817541272656, 0.8931003329735238], 
             UndirectedEdge[54, 362] -> 
             RGBColor[
              0.7301803627697285, 0.7873829362370641, 0.9508254903982616], 
             UndirectedEdge[4, 208] -> 
             RGBColor[
              0.46964826051743164`, 0.5791024970690049, 0.9517281547688727], 
             UndirectedEdge[176, 294] -> 
             RGBColor[
              0.507508588416526, 0.6053225896048187, 0.9562575249331393], 
             UndirectedEdge[113, 170] -> 
             RGBColor[
              0.7275311500758241, 0.7870721309715496, 0.9734771639405624], 
             UndirectedEdge[14, 205] -> 
             RGBColor[
              0.37654517063889514`, 0.4958955660927733, 0.9455941126664261], 
             UndirectedEdge[262, 306] -> 
             RGBColor[
              0.498987554766123, 0.604139601949135, 0.9537012746442806], 
             UndirectedEdge[47, 128] -> 
             RGBColor[
              0.9096919282505895, 0.9295971863685621, 0.9485868887692428], 
             UndirectedEdge[257, 382] -> 
             RGBColor[
              0.8251821101036838, 0.8642876492650821, 0.9826867791728557], 
             UndirectedEdge[165, 228] -> 
             RGBColor[
              0.6215470205400119, 0.6972363015694499, 0.966753843036378], 
             UndirectedEdge[72, 341] -> 
             RGBColor[
              0.6850602238188732, 0.7538935205886248, 0.9692440589246408], 
             UndirectedEdge[50, 116] -> 
             RGBColor[
              0.5385428153772489, 0.6279826210079933, 0.9596015196611152], 
             UndirectedEdge[230, 247] -> 
             RGBColor[
              0.4783750090512862, 0.5864349076253563, 0.9523467318926067], 
             UndirectedEdge[45, 100] -> 
             RGBColor[
              0.7782694003515402, 0.8267092377119235, 0.9785342785521389], 
             UndirectedEdge[95, 386] -> 
             RGBColor[
              0.46326871432851796`, 0.5728186608399206, 0.9515311469786515], 
             UndirectedEdge[182, 244] -> 
             RGBColor[
              0.6084642703505578, 0.688188602837216, 0.9648688070488698], 
             UndirectedEdge[104, 382] -> 
             RGBColor[
              0.6705748392917033, 0.7423389530503227, 0.967963337864534], 
             UndirectedEdge[58, 210] -> 
             RGBColor[
              0.48791750080680074`, 0.5793840945410327, 0.9559883531847906], 
             UndirectedEdge[102, 370] -> 
             RGBColor[
              0.2827004525193044, 0.41290269339326413`, 0.939468002424611], 
             UndirectedEdge[1, 161] -> 
             RGBColor[
              0.8973971667896823, 0.9209715943794153, 0.9882533276135815], 
             UndirectedEdge[153, 356] -> 
             RGBColor[
              0.44424355215594746`, 0.5567317097677826, 0.9502106558600958], 
             UndirectedEdge[1, 154] -> 
             RGBColor[
              0.6133203661662743, 0.6870356740579883, 0.9650212966630495], 
             UndirectedEdge[341, 399] -> 
             RGBColor[
              0.5979311594629402, 0.6843202553711787, 0.9615904505852333], 
             UndirectedEdge[373, 395] -> 
             RGBColor[
              0.6027175870115555, 0.6812044780890834, 0.9654263984599494], 
             UndirectedEdge[190, 266] -> 
             RGBColor[
              0.6092547990312848, 0.6936595183263384, 0.9623819160350588], 
             UndirectedEdge[73, 85] -> 
             RGBColor[
              0.8517834516073058, 0.8846530195385464, 0.9857250600820104], 
             UndirectedEdge[221, 250] -> 
             RGBColor[
              0.7352165726136413, 0.7930760414694671, 0.9742431750347749], 
             UndirectedEdge[23, 353] -> 
             RGBColor[
              0.2656864253861789, 0.3965836569461585, 0.9384418209266749], 
             UndirectedEdge[171, 270] -> 
             RGBColor[
              0.6317550849721075, 0.7070369235986034, 0.9669628530733665], 
             UndirectedEdge[277, 396] -> 
             RGBColor[
              0.626986288667537, 0.707489810119484, 0.9641640497751314], 
             UndirectedEdge[315, 371] -> 
             RGBColor[
              0.5667171595029448, 0.6492412350311669, 0.9625027067100718], 
             UndirectedEdge[207, 391] -> 
             RGBColor[
              0.5669914253282236, 0.6592208618777153, 0.9591418554145956], 
             UndirectedEdge[160, 247] -> 
             RGBColor[
              0.5797391249281687, 0.6672019752362808, 0.9613690606977531], 
             UndirectedEdge[193, 232] -> 
             RGBColor[
              0.7391842662041178, 0.7958773710856992, 0.9750966446011995], 
             UndirectedEdge[22, 91] -> 
             RGBColor[
              0.3874506231375096, 0.5095736889927035, 0.9460134660752663], 
             UndirectedEdge[78, 247] -> 
             RGBColor[
              0.3625336249837176, 0.48831420211665677`, 0.9443255448570133], 
             UndirectedEdge[87, 192] -> 
             RGBColor[
              0.705318517616249, 0.7693667109660864, 0.971504388440293], 
             UndirectedEdge[226, 294] -> 
             RGBColor[
              0.477285134446339, 0.5817117976565508, 0.9532451334956267], 
             UndirectedEdge[177, 311] -> 
             RGBColor[
              0.7415170067737453, 0.7980153507614285, 0.974999267644755], 
             UndirectedEdge[189, 200] -> 
             RGBColor[
              0.6984987496786744, 0.7632712649645652, 0.9714054518417821], 
             UndirectedEdge[67, 184] -> 
             RGBColor[
              0.5483386367798988, 0.642564118309187, 0.9582848766851231], 
             UndirectedEdge[33, 256] -> 
             RGBColor[
              0.47378630762926105`, 0.5796826097807346, 0.9528085141825209], 
             UndirectedEdge[176, 226] -> 
             RGBColor[
              0.6822010056979059, 0.7516598776616626, 0.9689590787832554], 
             UndirectedEdge[145, 162] -> 
             RGBColor[
              0.6940339530336639, 0.7590247134314376, 0.9717696798703293], 
             UndirectedEdge[286, 343] -> 
             RGBColor[
              0.5457463043329487, 0.6421004613051471, 0.9573822946931245], 
             UndirectedEdge[13, 18] -> 
             RGBColor[
              0.33283788783418367`, 0.46193210078152924`, 0.9424575665519684],
              UndirectedEdge[86, 308] -> 
             RGBColor[
              0.39686884309538606`, 0.5142885163358188, 0.9470217287280674], 
             UndirectedEdge[364, 377] -> 
             RGBColor[
              0.6069851376299391, 0.627503071478467, 0.613499522650317], 
             UndirectedEdge[90, 152] -> 
             RGBColor[
              0.3935812497792913, 0.5153220294151886, 0.9462996270990706], 
             UndirectedEdge[1, 153] -> 
             RGBColor[
              0.640942248557244, 0.7127949460642111, 0.9667141654110225], 
             UndirectedEdge[92, 114] -> 
             RGBColor[
              0.9225921695000054, 0.9387737433812997, 0.9018035925187213], 
             UndirectedEdge[132, 219] -> 
             RGBColor[
              0.9353597004526881, 0.9507506352393951, 0.9748421774653423], 
             UndirectedEdge[107, 215] -> 
             RGBColor[
              0.4252996637419583, 0.5247910736831076, 0.9506457058381971], 
             UndirectedEdge[240, 319] -> 
             RGBColor[
              0.527025907730708, 0.6263512958617918, 0.9560608282127032], 
             UndirectedEdge[58, 110] -> 
             RGBColor[
              0.32501346614010856`, 0.44807654289480525`, 0.9422181775766463],
              UndirectedEdge[67, 85] -> 
             RGBColor[
              0.64699432785923, 0.7201112614210958, 0.9679914876393205], 
             UndirectedEdge[125, 344] -> 
             RGBColor[
              0.40117790388285673`, 0.5219018693807598, 0.9467836791810924], 
             UndirectedEdge[198, 219] -> 
             RGBColor[
              0.7215555932501005, 0.7805756332104227, 0.9553679251081837], 
             UndirectedEdge[16, 325] -> 
             RGBColor[
              0.48862202166308916`, 0.5918960130893739, 0.954033080745309], 
             UndirectedEdge[119, 390] -> 
             RGBColor[
              0.6414064010150755, 0.7149070853848096, 0.9678030886892857], 
             UndirectedEdge[7, 153] -> 
             RGBColor[
              0.36084678330423847`, 0.4869690798366215, 0.9442138158412323], 
             UndirectedEdge[23, 164] -> 
             RGBColor[
              0.6143654430565555, 0.6863184819129476, 0.9546741413386294], 
             UndirectedEdge[46, 373] -> 
             RGBColor[
              0.6367384332957389, 0.7076233688638354, 0.9441103669401152], 
             UndirectedEdge[301, 316] -> 
             RGBColor[
              0.7809756745913627, 0.8291706470218472, 0.9787118659188359], 
             UndirectedEdge[22, 150] -> 
             RGBColor[
              0.5461781905142491, 0.6424510859633774, 0.9574162943553677], 
             UndirectedEdge[161, 327] -> 
             RGBColor[
              0.5519844063888958, 0.6328541786772091, 0.9618003448138668], 
             UndirectedEdge[123, 281] -> 
             RGBColor[
              0.7694219260711856, 0.8151396596292194, 0.745626240550413], 
             UndirectedEdge[111, 160] -> 
             RGBColor[
              0.5477762606725024, 0.6395173487182912, 0.9593324152510332], 
             UndirectedEdge[277, 287] -> 
             RGBColor[
              0.7143157650461698, 0.7759863618413761, 0.9727954978503437], 
             UndirectedEdge[48, 120] -> 
             RGBColor[
              0.5157706350095973, 0.6122628411870901, 0.9570040869082146], 
             UndirectedEdge[6, 224] -> 
             RGBColor[
              0.7729716104176709, 0.8231732595305103, 0.9778463074865523], 
             UndirectedEdge[103, 313] -> 
             RGBColor[
              0.5485279131649812, 0.632234904095051, 0.9611469449580335], 
             UndirectedEdge[8, 60] -> 
             RGBColor[
              0.6309893182518449, 0.7105913559459245, 0.9645805722936958], 
             UndirectedEdge[284, 392] -> 
             RGBColor[
              0.8039562979509691, 0.8473598384971439, 0.9809395855714065], 
             UndirectedEdge[218, 279] -> 
             RGBColor[
              0.6143291880220603, 0.6966430712799356, 0.9635581241151108], 
             UndirectedEdge[135, 221] -> 
             RGBColor[
              0.879603899501788, 0.9049054174309935, 0.8975947030751134], 
             UndirectedEdge[95, 309] -> 
             RGBColor[
              0.33741400603480814`, 0.46651654474485293`, 0.9427264207496241],
              UndirectedEdge[80, 385] -> 
             RGBColor[
              0.28639979327344517`, 0.4152050516756617, 0.9397367413678626], 
             UndirectedEdge[272, 398] -> 
             RGBColor[
              0.6320248749480605, 0.7096671800016414, 0.9658687583476213], 
             UndirectedEdge[33, 264] -> 
             RGBColor[
              0.5687766497565752, 0.660797533225285, 0.9591953278478074], 
             UndirectedEdge[76, 366] -> 
             RGBColor[
              0.49476958782067737`, 0.6007152663655768, 0.953369220835413], 
             UndirectedEdge[41, 258] -> 
             RGBColor[
              0.8841443941938137, 0.9103760387517601, 0.9860131322599353], 
             UndirectedEdge[174, 232] -> 
             RGBColor[
              0.4962385963318706, 0.6007109777855191, 0.9538155724609199], 
             UndirectedEdge[61, 307] -> 
             RGBColor[
              0.3832171039514282, 0.49950712130748043`, 0.9462836559183938], 
             UndirectedEdge[35, 392] -> 
             RGBColor[
              0.5941916260509028, 0.672757251556545, 0.9648795505917376], 
             UndirectedEdge[212, 259] -> 
             RGBColor[
              0.49827506483345246`, 0.6030457055519229, 0.9537876093345925], 
             UndirectedEdge[73, 110] -> 
             RGBColor[
              0.6254330348695426, 0.7033041045783225, 0.9657576083919122], 
             UndirectedEdge[122, 228] -> 
             RGBColor[
              0.4853163362253662, 0.589961183925013, 0.9534759031819595], 
             UndirectedEdge[41, 203] -> 
             RGBColor[
              0.5140104084868121, 0.5964416919091677, 0.9591074661057075], 
             UndirectedEdge[361, 385] -> 
             RGBColor[
              0.33132839296129246`, 0.45411994654819526`, 0.9425995520111714],
              UndirectedEdge[9, 269] -> 
             RGBColor[
              0.532934976452164, 0.6316996481877821, 0.9563737400329088], 
             UndirectedEdge[192, 228] -> 
             RGBColor[
              0.47961711325884127`, 0.5853342979737193, 0.9530272394730931], 
             UndirectedEdge[47, 265] -> 
             RGBColor[
              0.9624090950451705, 0.9714853451509216, 0.9485157761970209], 
             UndirectedEdge[338, 398] -> 
             RGBColor[
              0.4957564552634429, 0.6015164498134855, 0.9534469106555221], 
             UndirectedEdge[71, 79] -> 
             RGBColor[
              0.3879226024151251, 0.510420793480234, 0.9459390630927713], 
             UndirectedEdge[77, 78] -> 
             RGBColor[
              0.35936404196033794`, 0.48556886860968007`, 0.9441235818295157],
              UndirectedEdge[89, 164] -> 
             RGBColor[
              0.6778196799474696, 0.7440205060625087, 0.958617022146995], 
             UndirectedEdge[123, 235] -> 
             RGBColor[
              0.6689468836705358, 0.730611943427056, 0.7385336571568806], 
             UndirectedEdge[72, 393] -> 
             RGBColor[
              0.791664310851812, 0.8375382004703076, 0.9797725627900707], 
             UndirectedEdge[240, 371] -> 
             RGBColor[
              0.7354882616652784, 0.793203733901535, 0.9744293729615345], 
             UndirectedEdge[196, 303] -> 
             RGBColor[
              0.752531199821229, 0.8066023598400753, 0.9759689352604366], 
             UndirectedEdge[105, 170] -> 
             RGBColor[
              0.8352884920707221, 0.8706745527804249, 0.9108016349386647], 
             UndirectedEdge[195, 208] -> 
             RGBColor[
              0.5223707155564388, 0.6231231052781026, 0.9555420827170344], 
             UndirectedEdge[100, 180] -> 
             RGBColor[
              0.6819711114757286, 0.7511135344123883, 0.9691869127790104], 
             UndirectedEdge[39, 355] -> 
             RGBColor[
              0.5665861207059215, 0.6590191630597553, 0.9590228813767676], 
             UndirectedEdge[244, 397] -> 
             RGBColor[
              0.7480715609420641, 0.8032541837541074, 0.9754884221760693], 
             UndirectedEdge[225, 355] -> 
             RGBColor[
              0.7791273338739657, 0.8264213417197834, 0.935931957964418], 
             UndirectedEdge[335, 354] -> 
             RGBColor[
              0.48828807600599916`, 0.5931318040607874, 0.9535004040542197], 
             UndirectedEdge[97, 100] -> 
             RGBColor[
              0.583557185991737, 0.6703551861473624, 0.9616774403332957], 
             UndirectedEdge[2, 107] -> 
             RGBColor[
              0.7461989973166905, 0.8016841539094361, 0.9753302218671729], 
             UndirectedEdge[128, 225] -> 
             RGBColor[
              0.9099080922829077, 0.9297584011499289, 0.9482209794471372], 
             UndirectedEdge[96, 228] -> 
             RGBColor[
              0.3576610133746633, 0.4842097260450759, 0.9440108213983855], 
             UndirectedEdge[262, 307] -> 
             RGBColor[
              0.48633299387953216`, 0.5938660593399292, 0.9527050612561043], 
             UndirectedEdge[86, 334] -> 
             RGBColor[
              0.2898053560835169, 0.4219341823375909, 0.939815358349128], 
             UndirectedEdge[255, 399] -> 
             RGBColor[
              0.5500783999332621, 0.6456174516721643, 0.9577233331277701], 
             UndirectedEdge[138, 242] -> 
             RGBColor[
              0.8755015832460801, 0.9034557569912118, 0.9805218752455136], 
             UndirectedEdge[27, 396] -> 
             RGBColor[
              0.5356685318052891, 0.6316917195037124, 0.9574344582765292], 
             UndirectedEdge[163, 209] -> 
             RGBColor[
              0.5454816570958798, 0.634470463451787, 0.9601241704298669], 
             UndirectedEdge[63, 202] -> 
             RGBColor[
              0.6223596692491328, 0.696668954822919, 0.966294949272708], 
             UndirectedEdge[347, 372] -> 
             RGBColor[
              0.5362201204619186, 0.6343666760889519, 0.9566323586032357], 
             UndirectedEdge[174, 275] -> 
             RGBColor[
              0.4180268171160044, 0.53649555117231, 0.9478572770333995], 
             UndirectedEdge[209, 315] -> 
             RGBColor[
              0.29112478616286636`, 0.42332098700768606`, 0.9398904979402251],
              UndirectedEdge[177, 374] -> 
             RGBColor[
              0.7962257454691879, 0.8084497115569195, 0.6522198218428756], 
             UndirectedEdge[214, 215] -> 
             RGBColor[
              0.32885833539548337`, 0.44690193639387843`, 0.9427757169157365],
              UndirectedEdge[160, 185] -> 
             RGBColor[
              0.5705624970683666, 0.6592536414148473, 0.9607843340850999], 
             UndirectedEdge[63, 268] -> 
             RGBColor[
              0.6437561322390939, 0.7126264018873394, 0.9300763185220029], 
             UndirectedEdge[48, 196] -> 
             RGBColor[
              0.5008813717157385, 0.6006312355393353, 0.9555200642911592], 
             UndirectedEdge[34, 95] -> 
             RGBColor[
              0.46589025416014357`, 0.5749469449742579, 0.9517375241972139], 
             UndirectedEdge[84, 333] -> 
             RGBColor[
              0.672633876304771, 0.7358096776162433, 0.8676746291646096], 
             UndirectedEdge[102, 224] -> 
             RGBColor[
              0.4455668319179115, 0.5484527993714698, 0.951426324347302], 
             UndirectedEdge[105, 326] -> 
             RGBColor[
              0.738926212602849, 0.7930631429969748, 0.9027918623203253], 
             UndirectedEdge[134, 236] -> 
             RGBColor[
              0.5537625994845525, 0.6486084508392003, 0.9580133668121154], 
             UndirectedEdge[92, 161] -> 
             RGBColor[
              0.9234634456259743, 0.9394684753139868, 0.9018866956134135], 
             UndirectedEdge[77, 185] -> 
             RGBColor[
              0.40522897777530886`, 0.5254107059735076, 0.9470418100272954], 
             UndirectedEdge[178, 329] -> 
             RGBColor[
              0.5578604296505495, 0.6497437318865968, 0.9593434917290353], 
             UndirectedEdge[185, 400] -> 
             RGBColor[
              0.35335699712391544`, 0.4803658682952233, 0.9437408182443601], 
             UndirectedEdge[317, 333] -> 
             RGBColor[
              0.9931832183822911, 0.9914490998648501, 0.7626352428781529], 
             UndirectedEdge[106, 215] -> 
             RGBColor[
              0.368191293053674, 0.4788342033503473, 0.9458721514239605], 
             UndirectedEdge[14, 340] -> 
             RGBColor[
              0.46289489759772595`, 0.5657565681612474, 0.95255706018339], 
             UndirectedEdge[233, 358] -> 
             RGBColor[
              0.5259586110020295, 0.6212644874945146, 0.9576694350517934], 
             UndirectedEdge[74, 191] -> 
             RGBColor[
              0.5870562364050085, 0.6615370256231534, 0.9650368276717632], 
             UndirectedEdge[53, 244] -> 
             RGBColor[
              0.9142370076401211, 0.9317608077196282, 0.8857756162835537], 
             UndirectedEdge[4, 16] -> 
             RGBColor[
              0.36445731284909005`, 0.4900963390578805, 0.9444438755911644], 
             UndirectedEdge[149, 274] -> 
             RGBColor[
              0.7732304847722195, 0.8233096355554181, 0.9780162797749312], 
             UndirectedEdge[326, 335] -> 
             RGBColor[
              0.5494265565611623, 0.6450882558574844, 0.9576720176297375], 
             UndirectedEdge[30, 77] -> 
             RGBColor[
              0.45625919742907417`, 0.5683081722239758, 0.9506532523474869], 
             UndirectedEdge[129, 229] -> 
             RGBColor[
              0.6200484212209245, 0.6931625879577037, 0.9599897206547644], 
             UndirectedEdge[216, 219] -> 
             RGBColor[
              0.6796442070361894, 0.7451702764930834, 0.9524497515751587], 
             UndirectedEdge[138, 233] -> 
             RGBColor[
              0.7668567793575712, 0.8177936114523028, 0.9773967751484669], 
             UndirectedEdge[28, 44] -> 
             RGBColor[
              0.38457757975886464`, 0.4996805406795884, 0.946475509902293], 
             UndirectedEdge[163, 227] -> 
             RGBColor[
              0.6319953150519371, 0.7098258885712261, 0.9657415137670096], 
             UndirectedEdge[15, 335] -> 
             RGBColor[
              0.6106380205159205, 0.6947824798409834, 0.9624908082972367], 
             UndirectedEdge[257, 268] -> 
             RGBColor[
              0.9578344118264971, 0.9680735538967912, 0.9562595216177625], 
             UndirectedEdge[217, 279] -> 
             RGBColor[
              0.6253294442307364, 0.7055735748260338, 0.964424104579124], 
             UndirectedEdge[93, 119] -> 
             RGBColor[
              0.5054457933767048, 0.6077524166320095, 0.9546601405085091], 
             UndirectedEdge[67, 305] -> 
             RGBColor[
              0.4061018771982353, 0.5261667675804459, 0.9470974304066496], 
             UndirectedEdge[153, 195] -> 
             RGBColor[
              0.429023371705826, 0.5443752816170585, 0.9490124675017042], 
             UndirectedEdge[50, 135] -> 
             RGBColor[
              0.8880517416111243, 0.9115049358927851, 0.898436705026999], 
             UndirectedEdge[68, 334] -> 
             RGBColor[
              0.28418093692845725`, 0.416022561196852, 0.9394950559988298], 
             UndirectedEdge[95, 308] -> 
             RGBColor[
              0.43901061372156003`, 0.5531248419522135, 0.9496214604385214], 
             UndirectedEdge[17, 36] -> 
             RGBColor[
              0.3095471109820539, 0.4397947286103159, 0.9410454131393269], 
             UndirectedEdge[41, 361] -> 
             RGBColor[
              0.6310646006846418, 0.708015489312993, 0.9661930473248972], 
             UndirectedEdge[117, 371] -> 
             RGBColor[
              0.6824604586821761, 0.7501533745645516, 0.970254830063462], 
             UndirectedEdge[89, 304] -> 
             RGBColor[
              0.5652332989317203, 0.6553785811146005, 0.9601312107721256], 
             UndirectedEdge[267, 272] -> 
             RGBColor[
              0.5549917077889253, 0.6428568428872643, 0.9609205274672291], 
             UndirectedEdge[20, 158] -> 
             RGBColor[
              0.34711323557741136`, 0.46909094266516743`, 0.9435577869794625],
              UndirectedEdge[30, 62] -> 
             RGBColor[
              0.4168413924384937, 0.5341664507376196, 0.9481415846692834], 
             UndirectedEdge[197, 310] -> 
             RGBColor[
              0.33861019567563705`, 0.46473581196835534`, 0.942905778186039], 
             UndirectedEdge[142, 268] -> 
             RGBColor[
              0.7677582102600085, 0.8173295818384008, 0.9387438361534715], 
             UndirectedEdge[78, 213] -> 
             RGBColor[
              0.5958287139330609, 0.675498755233652, 0.9648181330420931], 
             UndirectedEdge[48, 71] -> 
             RGBColor[
              0.3748192643760064, 0.49883536646943416`, 0.9451127701509446], 
             UndirectedEdge[262, 269] -> 
             RGBColor[
              0.4586910190998008, 0.5714250589569704, 0.9505289837455538], 
             UndirectedEdge[27, 376] -> 
             RGBColor[
              0.5401148734700376, 0.6351652354056623, 0.957877628060246], 
             UndirectedEdge[245, 292] -> 
             RGBColor[
              0.5230655671146918, 0.6232187987620867, 0.955726209352757], 
             UndirectedEdge[142, 217] -> 
             RGBColor[
              0.5449958228419899, 0.6414911866219808, 0.9573232140410519], 
             UndirectedEdge[142, 363] -> 
             RGBColor[
              0.542113816504348, 0.6391514440441772, 0.9570963319450156], 
             UndirectedEdge[121, 130] -> 
             RGBColor[
              0.7537534861503292, 0.8077130357726583, 0.9760494124140203], 
             UndirectedEdge[217, 300] -> 
             RGBColor[
              0.68371801234824, 0.7512947798299072, 0.9702151745083714], 
             UndirectedEdge[25, 109] -> 
             RGBColor[
              0.7017513960934432, 0.7659907632566887, 0.9715707532622752], 
             UndirectedEdge[40, 146] -> 
             RGBColor[
              0.5576436310372072, 0.6459092791716345, 0.960873122213384], 
             UndirectedEdge[18, 140] -> 
             RGBColor[
              0.4901754824354851, 0.5945966085135438, 0.9536676317296244], 
             UndirectedEdge[170, 239] -> 
             RGBColor[
              0.7140474713344156, 0.7765385786590073, 0.9721332368557607], 
             UndirectedEdge[152, 333] -> 
             RGBColor[
              0.7132530668810138, 0.7709919789135049, 0.8702628480699879], 
             UndirectedEdge[14, 250] -> 
             RGBColor[
              0.4843773728992189, 0.5825388411396331, 0.9546982325562972], 
             UndirectedEdge[55, 159] -> 
             RGBColor[
              0.954672642008298, 0.9657155111433013, 0.9616115731983346], 
             UndirectedEdge[234, 331] -> 
             RGBColor[
              0.2942819787720611, 0.42515550910642275`, 0.9401246277794548], 
             UndirectedEdge[370, 389] -> 
             RGBColor[
              0.31640807541032356`, 0.44833154223845456`, 0.9413876016822953],
              UndirectedEdge[119, 316] -> 
             RGBColor[
              0.6281112134301285, 0.7043058636928261, 0.9665349818286794], 
             UndirectedEdge[89, 227] -> 
             RGBColor[
              0.4388975406448552, 0.5540712045731518, 0.9493257120893667], 
             UndirectedEdge[246, 254] -> 
             RGBColor[
              0.6436037576844053, 0.7206128350096066, 0.9657236944663661], 
             UndirectedEdge[197, 345] -> 
             RGBColor[
              0.4678468557216267, 0.570830033881335, 0.9528598624933038], 
             UndirectedEdge[231, 234] -> 
             RGBColor[
              0.2810365465840979, 0.4127176075790677, 0.9393159876204272], 
             UndirectedEdge[89, 209] -> 
             RGBColor[
              0.35238388268879806`, 0.4787157794537127, 0.943708368752224], 
             UndirectedEdge[233, 317] -> 
             RGBColor[
              0.8608290821623723, 0.8893081519537855, 0.8535425784468169], 
             UndirectedEdge[48, 342] -> 
             RGBColor[
              0.5628236221019415, 0.6490209923195762, 0.961693888926415], 
             UndirectedEdge[24, 104] -> 
             RGBColor[
              0.7145647286392958, 0.7767041889442039, 0.9723478389258136], 
             UndirectedEdge[118, 149] -> 
             RGBColor[
              0.8727007562641836, 0.556147115904336, 0.4593675424332476], 
             UndirectedEdge[34, 53] -> 
             RGBColor[
              0.7778530536755098, 0.8238806706350869, 0.8730387587232691], 
             UndirectedEdge[29, 45] -> 
             RGBColor[
              0.8212204631125481, 0.8603554199693788, 0.982790696256167], 
             UndirectedEdge[35, 208] -> 
             RGBColor[
              0.4135059782487079, 0.5293121483010741, 0.9481933912695426], 
             UndirectedEdge[69, 191] -> 
             RGBColor[
              0.6286972402879942, 0.7027983639386757, 0.967499978065103], 
             UndirectedEdge[102, 166] -> 
             RGBColor[
              0.26735820988946957`, 0.3983408084563765, 0.9385370265809538], 
             UndirectedEdge[185, 213] -> 
             RGBColor[
              0.6416936497480318, 0.7153405925974796, 0.9677363612398728], 
             UndirectedEdge[172, 364] -> 
             RGBColor[
              0.26167757292121735`, 0.39237009882955703`, 0.9382135227093612],
              UndirectedEdge[36, 55] -> 
             RGBColor[
              0.6562763814914816, 0.7239813282932139, 0.9371119529963898], 
             UndirectedEdge[192, 203] -> 
             RGBColor[
              0.40894664119274843`, 0.5139357476344446, 0.9488971878851845], 
             UndirectedEdge[105, 394] -> 
             RGBColor[
              0.8256858541515593, 0.8631728990552237, 0.909844533732636], 
             UndirectedEdge[256, 261] -> 
             RGBColor[
              0.388196852676134, 0.5101972344887804, 0.9460705987641067], 
             UndirectedEdge[215, 295] -> 
             RGBColor[
              0.40215387111918477`, 0.5064065542206351, 0.9485458099783002], 
             UndirectedEdge[219, 357] -> 
             RGBColor[
              0.8624930300155207, 0.8930672932564747, 0.9677810156102841], 
             UndirectedEdge[204, 295] -> 
             RGBColor[
              0.48349137149961313`, 0.588601551846044, 0.9532985383296053], 
             UndirectedEdge[24, 138] -> 
             RGBColor[
              0.8046616579199348, 0.84732706991294, 0.9811648121368868], 
             UndirectedEdge[135, 376] -> 
             RGBColor[
              0.8390000043296639, 0.8731853459214972, 0.8935476862693299], 
             UndirectedEdge[127, 305] -> 
             RGBColor[
              0.5543360734340005, 0.6464899076634871, 0.9592040819394536], 
             UndirectedEdge[54, 158] -> 
             RGBColor[
              0.706436251752256, 0.768021461878097, 0.9489797348985913], 
             UndirectedEdge[180, 350] -> 
             RGBColor[
              0.39970223303506147`, 0.5043286434538321, 0.9483607783512733], 
             UndirectedEdge[46, 287] -> 
             RGBColor[
              0.9085333223121755, 0.9291954174234214, 0.9665769432018609], 
             UndirectedEdge[41, 153] -> 
             RGBColor[
              0.5868033907849379, 0.6696786539309633, 0.9633727621687391], 
             UndirectedEdge[163, 315] -> 
             RGBColor[
              0.5378452242856191, 0.6264440883903981, 0.9596892868784126], 
             UndirectedEdge[17, 64] -> 
             RGBColor[
              0.3648172554606054, 0.48766694979940295`, 0.9445671778720304], 
             UndirectedEdge[67, 127] -> 
             RGBColor[
              0.5632769096040571, 0.6542340105744979, 0.9597737841141387], 
             UndirectedEdge[83, 246] -> 
             RGBColor[
              0.5401269647940126, 0.6345337082519045, 0.9581501233577643], 
             UndirectedEdge[44, 383] -> 
             RGBColor[
              0.46250074725150053`, 0.5730873791424157, 0.9512241754364327], 
             UndirectedEdge[5, 275] -> 
             RGBColor[
              0.37816873833368225`, 0.5019724866563513, 0.9453175554985052], 
             UndirectedEdge[99, 123] -> 
             RGBColor[
              0.6227031788098485, 0.6853027499680451, 0.7357794685438067], 
             UndirectedEdge[278, 354] -> 
             RGBColor[
              0.5113284129835927, 0.6116458387533975, 0.9554449132736125], 
             UndirectedEdge[61, 215] -> 
             RGBColor[
              0.2171435940014937, 0.34556206336757955`, 0.9356773784920007], 
             UndirectedEdge[115, 208] -> 
             RGBColor[
              0.5640736233299433, 0.6569794045032192, 0.9588250883797493], 
             UndirectedEdge[167, 203] -> 
             RGBColor[
              0.5752209381082619, 0.6448320253287071, 0.9504783734947994], 
             UndirectedEdge[242, 256] -> 
             RGBColor[
              0.626080884495295, 0.6994891780731399, 0.960253525307617], 
             UndirectedEdge[136, 254] -> 
             RGBColor[
              0.6602645690949558, 0.7336283875103853, 0.967384288443635], 
             UndirectedEdge[65, 170] -> 
             RGBColor[
              0.8343396188230967, 0.8702821693076017, 0.9265269202570665], 
             UndirectedEdge[247, 340] -> 
             RGBColor[
              0.5378527471444163, 0.6344800185633517, 0.957194218010724], 
             UndirectedEdge[8, 17] -> 
             RGBColor[
              0.4260793639038024, 0.5374778151817623, 0.9493690874219982], 
             UndirectedEdge[269, 300] -> 
             RGBColor[
              0.6459398614532252, 0.7206247750470309, 0.9672411400839893], 
             UndirectedEdge[233, 242] -> 
             RGBColor[
              0.8353730567508446, 0.8721070471050367, 0.9765222387468695], 
             UndirectedEdge[242, 382] -> 
             RGBColor[
              0.8291880459656156, 0.8672752696717928, 0.9759057746740099], 
             UndirectedEdge[144, 242] -> 
             RGBColor[
              0.9695634069803176, 0.9748580316479353, 0.8443326378928767], 
             UndirectedEdge[81, 227] -> 
             RGBColor[
              0.34033047239093317`, 0.45946336837897706`, 0.9433832074796569],
              UndirectedEdge[224, 230] -> 
             RGBColor[
              0.5952836316420466, 0.6821787145606258, 0.9613766661903502], 
             UndirectedEdge[81, 248] -> 
             RGBColor[
              0.38307739628230153`, 0.4941672469209658, 0.946748401915527], 
             UndirectedEdge[13, 323] -> 
             RGBColor[
              0.6701704108538541, 0.4272781167459739, 0.44706030748795345`], 
             UndirectedEdge[10, 189] -> 
             RGBColor[
              0.5603965516259951, 0.6443032037020024, 0.961884411940967], 
             UndirectedEdge[135, 364] -> 
             RGBColor[
              0.6232110925740656, 0.6885310238009464, 0.8777334908816637], 
             UndirectedEdge[39, 383] -> 
             RGBColor[
              0.47969802435157355`, 0.5870489034207595, 0.9525780080854521], 
             UndirectedEdge[108, 196] -> 
             RGBColor[
              0.5739192076874925, 0.6641289122639283, 0.9601653304432578], 
             UndirectedEdge[75, 89] -> 
             RGBColor[
              0.42715533767195113`, 0.5444022168650873, 0.9484389382911906], 
             UndirectedEdge[131, 269] -> 
             RGBColor[
              0.41914559966147225`, 0.5373216610078053, 0.9479680550219018], 
             UndirectedEdge[36, 165] -> 
             RGBColor[
              0.6215940330540533, 0.6972770214461949, 0.9667568386322012], 
             UndirectedEdge[40, 41] -> 
             RGBColor[
              0.5760553592879554, 0.6603692492600473, 0.9626879071058625], 
             UndirectedEdge[86, 249] -> 
             RGBColor[
              0.2770828151893523, 0.408561985202141, 0.9390908284665178], 
             UndirectedEdge[287, 395] -> 
             RGBColor[
              0.8745124760279921, 0.9027765266486694, 0.9878929747216951], 
             UndirectedEdge[177, 225] -> 
             RGBColor[
              0.8027473779261911, 0.8455971575522383, 0.9377914143552815], 
             UndirectedEdge[74, 216] -> 
             RGBColor[
              0.32753466521213165`, 0.45292180377118674`, 0.942281374685543], 
             UndirectedEdge[229, 371] -> 
             RGBColor[
              0.5730580448360116, 0.6559059075515707, 0.9628638107492906], 
             UndirectedEdge[319, 371] -> 
             RGBColor[
              0.6414836117187133, 0.7163354200762935, 0.9671812542825413], 
             UndirectedEdge[169, 353] -> 
             RGBColor[
              0.35609770999723667`, 0.4774552437241436, 0.9441519158048028], 
             UndirectedEdge[47, 362] -> 
             RGBColor[
              0.7405468748578996, 0.7951142639788165, 0.9332776894523599], 
             UndirectedEdge[83, 313] -> 
             RGBColor[
              0.32038275947274636`, 0.447761715389429, 0.941787782258594], 
             UndirectedEdge[87, 210] -> 
             RGBColor[
              0.771679055618113, 0.821560810317695, 0.9778774145793839], 
             UndirectedEdge[91, 150] -> 
             RGBColor[
              0.466723303657944, 0.5739308222327526, 0.9522541018712316], 
             UndirectedEdge[16, 258] -> 
             RGBColor[
              0.6296445443685976, 0.7029437427636718, 0.9650354357700339], 
             UndirectedEdge[334, 388] -> 
             RGBColor[
              0.2999230943324888, 0.43256856673891675`, 0.9403915485745545], 
             UndirectedEdge[67, 325] -> 
             RGBColor[
              0.5359134097762386, 0.632857436538705, 0.9570464461777464], 
             UndirectedEdge[279, 363] -> 
             RGBColor[
              0.6224474378930945, 0.7032338322482301, 0.9641972224830877], 
             UndirectedEdge[192, 385] -> 
             RGBColor[
              0.4246596617750123, 0.5304511285294503, 0.9497920211620137], 
             UndirectedEdge[216, 339] -> 
             RGBColor[
              0.35016723245504056`, 0.4767100669311281, 0.9435702659081439], 
             UndirectedEdge[74, 323] -> 
             RGBColor[
              0.6542461789701377, 0.4105407393815716, 0.4461534460399658], 
             UndirectedEdge[60, 87] -> 
             RGBColor[
              0.7401114571734628, 0.7968999624901002, 0.974731051382401], 
             UndirectedEdge[74, 198] -> 
             RGBColor[
              0.36944605142604275`, 0.488327160488526, 0.945199548218568], 
             UndirectedEdge[16, 348] -> 
             RGBColor[
              0.31244381742049443`, 0.4446456070391298, 0.9411442403943868], 
             UndirectedEdge[88, 283] -> 
             RGBColor[
              0.3282750061357582, 0.454248896451746, 0.9423034363514278], 
             UndirectedEdge[292, 388] -> 
             RGBColor[
              0.3698951715154694, 0.49434200497537056`, 0.9448073726771845], 
             UndirectedEdge[76, 382] -> 
             RGBColor[
              0.6016643544514226, 0.6863943170750182, 0.9625384520704838], 
             UndirectedEdge[131, 352] -> 
             RGBColor[
              0.5503441259864414, 0.6426301798753122, 0.9591199078581403], 
             UndirectedEdge[123, 232] -> 
             RGBColor[
              0.7883700136194549, 0.8305225707025209, 0.7471179034113447], 
             UndirectedEdge[69, 357] -> 
             RGBColor[
              0.5520244920744485, 0.6420801588501004, 0.960075789114008], 
             UndirectedEdge[241, 339] -> 
             RGBColor[
              0.6114958824790493, 0.6867662043911912, 0.9664980796864757], 
             UndirectedEdge[181, 322] -> 
             RGBColor[
              0.8742824308673891, 0.8994666226147755, 0.8289884763700346], 
             UndirectedEdge[140, 168] -> 
             RGBColor[
              0.43054260135879807`, 0.53715067040502, 0.9500800581906832], 
             UndirectedEdge[88, 357] -> 
             RGBColor[
              0.5823809843653841, 0.6683734267108428, 0.9620100779595944], 
             UndirectedEdge[125, 179] -> 
             RGBColor[
              0.33970334449856265`, 0.4673673854366432, 0.942913745971875], 
             UndirectedEdge[316, 324] -> 
             RGBColor[
              0.9266027347470102, 0.9418969281013088, 0.8989410395230651], 
             UndirectedEdge[128, 390] -> 
             RGBColor[
              0.8627523895694595, 0.8933993529256785, 0.9867712871769272], 
             UndirectedEdge[200, 339] -> 
             RGBColor[
              0.42916466476555615`, 0.5422235465770283, 0.9494079888405567], 
             UndirectedEdge[85, 110] -> 
             RGBColor[
              0.6525955256124047, 0.7249627373905111, 0.968348391007208], 
             UndirectedEdge[178, 209] -> 
             RGBColor[
              0.5027674439852352, 0.601101795529708, 0.9558668168540141], 
             UndirectedEdge[380, 383] -> 
             RGBColor[
              0.49212466537438837`, 0.5971374104168791, 0.9535562787870541], 
             UndirectedEdge[350, 357] -> 
             RGBColor[
              0.47459255434001574`, 0.5632002797804339, 0.9555743979857702], 
             UndirectedEdge[98, 352] -> 
             RGBColor[
              0.5517813953301716, 0.6438750703415935, 0.9592114893897954], 
             UndirectedEdge[68, 151] -> 
             RGBColor[
              0.5572243481851351, 0.6402450629845591, 0.961813433661936], 
             UndirectedEdge[307, 385] -> 
             RGBColor[
              0.3719264645083134, 0.4876399433848795, 0.9456406707051127], 
             UndirectedEdge[94, 119] -> 
             RGBColor[
              0.30746333461214764`, 0.4326784384520366, 0.9411071141420891], 
             UndirectedEdge[116, 121] -> 
             RGBColor[
              0.5650570080702451, 0.6488515264176596, 0.9622028576747492], 
             UndirectedEdge[1, 361] -> 
             RGBColor[
              0.6852034584569479, 0.7511317814462408, 0.9695344505671804], 
             UndirectedEdge[180, 239] -> 
             RGBColor[
              0.6818457730522904, 0.751015619083391, 0.9691744202163162], 
             UndirectedEdge[45, 394] -> 
             RGBColor[
              0.7373151827798348, 0.7947154916813254, 0.9744523448835141], 
             UndirectedEdge[32, 124] -> 
             RGBColor[
              0.9017622302931243, 0.9245047410248108, 0.9904920806096462], 
             UndirectedEdge[87, 243] -> 
             RGBColor[
              0.5891186161718138, 0.6732278688110025, 0.9628547502401594], 
             UndirectedEdge[188, 195] -> 
             RGBColor[
              0.7396037427822114, 0.7554416844202969, 0.637301663226141], 
             UndirectedEdge[122, 262] -> 
             RGBColor[
              0.544765414112756, 0.6413041304357938, 0.9573050754218717], 
             UndirectedEdge[118, 212] -> 
             RGBColor[
              0.7521488875076009, 0.4605928323651914, 0.44806019299827204`], 
             UndirectedEdge[35, 258] -> 
             RGBColor[
              0.6174996378069708, 0.6912617094608269, 0.9643041461454083], 
             UndirectedEdge[183, 271] -> 
             RGBColor[
              0.6840933260266572, 0.7530747717751323, 0.9691910351369878], 
             UndirectedEdge[130, 147] -> 
             RGBColor[
              0.439812977636104, 0.540131250467007, 0.9514586399441922], 
             UndirectedEdge[124, 330] -> 
             RGBColor[
              0.8887088490712469, 0.9140963291630801, 0.9892470374558126], 
             UndirectedEdge[46, 395] -> 
             RGBColor[
              0.9291494302626929, 0.9456341422938214, 0.9685433259823981], 
             UndirectedEdge[206, 284] -> 
             RGBColor[
              0.6049974310508788, 0.6890797127788625, 0.9628148915048182], 
             UndirectedEdge[179, 313] -> 
             RGBColor[
              0.27928483936416704`, 0.4108764522262678, 0.9392162304856707], 
             UndirectedEdge[215, 363] -> 
             RGBColor[
              0.35504636749860724`, 0.4681625606125962, 0.9448373347328167], 
             UndirectedEdge[260, 338] -> 
             RGBColor[
              0.6000895624008646, 0.6858169890357466, 0.9619350923717509], 
             UndirectedEdge[88, 113] -> 
             RGBColor[
              0.584402281313068, 0.6699524792487992, 0.9622115419492455], 
             UndirectedEdge[95, 270] -> 
             RGBColor[
              0.3779873994380859, 0.5018154200193436, 0.9453060007444294], 
             UndirectedEdge[16, 184] -> 
             RGBColor[
              0.5010472486667494, 0.6016026948598561, 0.9552715112526857], 
             UndirectedEdge[38, 78] -> 
             RGBColor[
              0.4721726794779267, 0.5782946268660459, 0.9526885804946463], 
             UndirectedEdge[8, 210] -> 
             RGBColor[
              0.6625569166964951, 0.7352522037735193, 0.9677269354906788], 
             UndirectedEdge[1, 96] -> 
             RGBColor[
              0.6565786273864898, 0.7263383914988526, 0.9677105016433151], 
             UndirectedEdge[213, 247] -> 
             RGBColor[
              0.6508702776078339, 0.7232889264189131, 0.9683210878525259], 
             UndirectedEdge[109, 366] -> 
             RGBColor[
              0.539233457182998, 0.6368130385883966, 0.9568695795081351], 
             UndirectedEdge[223, 260] -> 
             RGBColor[
              0.5035264087013952, 0.6043041686172667, 0.955194938618693], 
             UndirectedEdge[393, 399] -> 
             RGBColor[
              0.704535246495879, 0.7679649352528615, 0.9721189544506632], 
             UndirectedEdge[25, 358] -> 
             RGBColor[
              0.5753967724965003, 0.6599313840201215, 0.962584913498003], 
             UndirectedEdge[207, 358] -> 
             RGBColor[
              0.404249871528765, 0.5237482792234104, 0.9472044362417835], 
             UndirectedEdge[31, 33] -> 
             RGBColor[
              0.45152374546609336`, 0.5562832454192782, 0.9515406942018378], 
             UndirectedEdge[355, 375] -> 
             RGBColor[
              0.6930108571526461, 0.759063673318951, 0.970748201795464], 
             UndirectedEdge[25, 104] -> 
             RGBColor[
              0.7261980115714031, 0.7858376270091735, 0.9734952803836033], 
             UndirectedEdge[360, 375] -> 
             RGBColor[
              0.6065410914012783, 0.6874557506223491, 0.9643299841602553], 
             UndirectedEdge[28, 347] -> 
             RGBColor[
              0.35235241075527457`, 0.4735186967551541, 0.9439386265536469], 
             UndirectedEdge[56, 143] -> 
             RGBColor[
              0.8250665655585669, 0.8637213369648956, 0.9830781585671396], 
             UndirectedEdge[73, 115] -> 
             RGBColor[
              0.7109631875228271, 0.7734764280588764, 0.9722877470771683], 
             UndirectedEdge[157, 218] -> 
             RGBColor[
              0.5548082352886061, 0.6494573450902871, 0.9580956830929006], 
             UndirectedEdge[267, 321] -> 
             RGBColor[
              0.44187626193104723`, 0.5535027398812402, 0.9503213666869086], 
             UndirectedEdge[93, 324] -> 
             RGBColor[
              0.8039373146935864, 0.8453434810404923, 0.8870661982028949], 
             UndirectedEdge[178, 245] -> 
             RGBColor[
              0.6584191450231688, 0.7325865986563611, 0.9669269602035588], 
             UndirectedEdge[223, 331] -> 
             RGBColor[
              0.3316307391693626, 0.46166361084806706`, 0.9423521953436915], 
             UndirectedEdge[318, 367] -> 
             RGBColor[
              0.612733741495952, 0.6878093402359093, 0.9666076489198383], 
             UndirectedEdge[158, 265] -> 
             RGBColor[
              0.6957962265620632, 0.7600861485126935, 0.966990522182574], 
             UndirectedEdge[124, 199] -> 
             RGBColor[
              0.5585139448843315, 0.6376553881445959, 0.9624845332297665], 
             UndirectedEdge[38, 213] -> 
             RGBColor[
              0.7605093321020431, 0.8132693511683022, 0.9766841234901591], 
             UndirectedEdge[128, 296] -> 
             RGBColor[
              0.6206727940608256, 0.6987908085468875, 0.9656339273170507], 
             UndirectedEdge[89, 315] -> 
             RGBColor[
              0.34474744987853734`, 0.4706894043923238, 0.9432734852007696], 
             UndirectedEdge[129, 178] -> 
             RGBColor[
              0.8253501937102263, 0.8642787239593218, 0.9756049355293346], 
             UndirectedEdge[61, 279] -> 
             RGBColor[
              0.484544664395981, 0.5806333350032135, 0.9550372662422717], 
             UndirectedEdge[7, 332] -> 
             RGBColor[
              0.5625566607919135, 0.6520788391384145, 0.960376021132443], 
             UndirectedEdge[105, 180] -> 
             RGBColor[
              0.8030867937885968, 0.8451515932048086, 0.9078428182992202], 
             UndirectedEdge[75, 163] -> 
             RGBColor[
              0.6202531120790329, 0.7001569008631615, 0.9648547399688336], 
             UndirectedEdge[15, 273] -> 
             RGBColor[
              0.606131000189934, 0.6911234777013957, 0.9621359991474155], 
             UndirectedEdge[149, 287] -> 
             RGBColor[
              0.8888841415772876, 0.9142361026492085, 0.9892637570115241], 
             UndirectedEdge[123, 275] -> 
             RGBColor[
              0.7101582344035888, 0.7663071440893118, 0.7411596079838242], 
             UndirectedEdge[186, 226] -> 
             RGBColor[
              0.4453054487005502, 0.5480991203085402, 0.9514239377021094], 
             UndirectedEdge[15, 183] -> 
             RGBColor[
              0.6712430181286613, 0.7426423129237655, 0.9681794118270287], 
             UndirectedEdge[35, 41] -> 
             RGBColor[
              0.5628148804055824, 0.647738286278038, 0.9618868085817354], 
             UndirectedEdge[47, 54] -> 
             RGBColor[
              0.9730491202353633, 0.9794206585163251, 0.9305049889130382], 
             UndirectedEdge[19, 196] -> 
             RGBColor[
              0.8285530560834569, 0.866469039201311, 0.9601416518074377], 
             UndirectedEdge[211, 328] -> 
             RGBColor[
              0.6962162985965753, 0.7607768987796054, 0.9719639735472839], 
             UndirectedEdge[3, 86] -> 
             RGBColor[
              0.40963550740455956`, 0.5246530695536789, 0.9480267673083178], 
             UndirectedEdge[55, 58] -> 
             RGBColor[
              0.5981692185235359, 0.6657963056321738, 0.9336970449731732], 
             UndirectedEdge[63, 214] -> 
             RGBColor[
              0.39192370638030954`, 0.513187639874398, 0.9463671964964666], 
             UndirectedEdge[26, 106] -> 
             RGBColor[
              0.6650490586312884, 0.7369172691422153, 0.9681680072616183], 
             UndirectedEdge[89, 378] -> 
             RGBColor[
              0.5948185474226719, 0.6784908020919485, 0.9630799918518375], 
             UndirectedEdge[191, 311] -> 
             RGBColor[
              0.8914655953306698, 0.9162944838004602, 0.9895099783750128], 
             UndirectedEdge[147, 364] -> 
             RGBColor[
              0.23396660835433944`, 0.36324411809313667`, 0.9366354242719759],
              UndirectedEdge[137, 285] -> 
             RGBColor[
              0.6368705635576004, 0.7140446615937114, 0.9659469825773204], 
             UndirectedEdge[104, 205] -> 
             RGBColor[
              0.5561111495021045, 0.6505151095444215, 0.9581982532725193], 
             UndirectedEdge[191, 339] -> 
             RGBColor[
              0.6096888036479173, 0.6853252887830947, 0.9663257188943641], 
             UndirectedEdge[40, 167] -> 
             RGBColor[
              0.6372658889094052, 0.7087595826795867, 0.9540588144949543], 
             UndirectedEdge[17, 262] -> 
             RGBColor[
              0.3689491763554025, 0.49109695524435176`, 0.9448715897834157], 
             UndirectedEdge[96, 348] -> 
             RGBColor[
              0.3399238000674689, 0.46844738682385156`, 0.9428952405890574], 
             UndirectedEdge[60, 122] -> 
             RGBColor[
              0.6598242647280367, 0.7340008644948324, 0.9668505649061909], 
             UndirectedEdge[99, 187] -> 
             RGBColor[
              0.3068254514824229, 0.4349232968187787, 0.9409640437156808], 
             UndirectedEdge[111, 166] -> 
             RGBColor[
              0.3243123249651427, 0.4540515628041043, 0.9419324907521217], 
             UndirectedEdge[130, 172] -> 
             RGBColor[
              0.4675239422029819, 0.5692572312034274, 0.9530367383815777], 
             UndirectedEdge[205, 230] -> 
             RGBColor[
              0.5123028405783812, 0.6149495508183161, 0.9547495027189206], 
             UndirectedEdge[248, 319] -> 
             RGBColor[
              0.4951518202260605, 0.6004744757142404, 0.9535515832857077], 
             UndirectedEdge[77, 111] -> 
             RGBColor[
              0.3824427413794447, 0.5056744132769515, 0.9455898911932286], 
             UndirectedEdge[41, 188] -> 
             RGBColor[
              0.8973837618613234, 0.8807450567342016, 0.6516619578931759], 
             UndirectedEdge[57, 278] -> 
             RGBColor[
              0.5133820581000381, 0.6134246029340578, 0.9555757697244653], 
             UndirectedEdge[56, 331] -> 
             RGBColor[
              0.600462195938553, 0.6799043420860074, 0.9649819046581755], 
             UndirectedEdge[40, 87] -> 
             RGBColor[
              0.5569780074058427, 0.6453892889318856, 0.960806779070416], 
             UndirectedEdge[142, 214] -> 
             RGBColor[
              0.5159257844012242, 0.6178908198254593, 0.9550347141279353], 
             UndirectedEdge[341, 368] -> 
             RGBColor[
              0.6226400927445745, 0.7043800805339688, 0.9635356283249684], 
             UndirectedEdge[96, 188] -> 
             RGBColor[
              0.6703638946830818, 0.6971145405308351, 0.6324352615979454], 
             UndirectedEdge[142, 202] -> 
             RGBColor[
              0.7463617472700474, 0.8013721347739806, 0.9749624669041767], 
             UndirectedEdge[37, 351] -> 
             RGBColor[
              0.7061021289305638, 0.7703316167862795, 0.9713413193783911], 
             UndirectedEdge[83, 108] -> 
             RGBColor[
              0.414638532953192, 0.5335607897305955, 0.9476413785626872], 
             UndirectedEdge[72, 119] -> 
             RGBColor[
              0.5557461840532665, 0.6474265054436997, 0.9594144607479997], 
             UndirectedEdge[170, 180] -> 
             RGBColor[
              0.650619531823186, 0.7266214421069914, 0.9660620803164144], 
             UndirectedEdge[196, 234] -> 
             RGBColor[
              0.47966872368386604`, 0.578335397498271, 0.9543120353670446], 
             UndirectedEdge[218, 306] -> 
             RGBColor[
              0.5256561884640982, 0.6257904001934083, 0.9558007271794092], 
             UndirectedEdge[186, 189] -> 
             RGBColor[
              0.5375675751086961, 0.6203085019416099, 0.9605843355007511], 
             UndirectedEdge[20, 135] -> 
             RGBColor[
              0.616953242903562, 0.6819536270266617, 0.8773771156005876], 
             UndirectedEdge[79, 254] -> 
             RGBColor[
              0.4581808279109495, 0.5677276667745044, 0.9513959764610169], 
             UndirectedEdge[93, 355] -> 
             RGBColor[
              0.596011023522147, 0.6829076247427328, 0.9613393175134314], 
             UndirectedEdge[211, 301] -> 
             RGBColor[
              0.5831506104997137, 0.6715992150274208, 0.9609201821011288], 
             UndirectedEdge[145, 227] -> 
             RGBColor[
              0.46871019863189056`, 0.579559080260015, 0.9513177302597838], 
             UndirectedEdge[26, 345] -> 
             RGBColor[
              0.717269026834652, 0.7790552823005206, 0.9724543314008764], 
             UndirectedEdge[132, 140] -> 
             RGBColor[
              0.7644741010555064, 0.8162727362961164, 0.9772441579253641], 
             UndirectedEdge[153, 258] -> 
             RGBColor[
              0.6414881481863264, 0.7132020771137522, 0.965790099732412], 
             UndirectedEdge[56, 344] -> 
             RGBColor[
              0.6469449053917722, 0.7201653287254781, 0.9679437418014886], 
             UndirectedEdge[44, 390] -> 
             RGBColor[
              0.7069537674066053, 0.7697516646581886, 0.9725127678160453], 
             UndirectedEdge[223, 346] -> 
             RGBColor[
              0.41743737889253096`, 0.5348149932566459, 0.9481429975000255], 
             UndirectedEdge[114, 222] -> 
             RGBColor[
              0.7401326747242086, 0.7969354309303851, 0.9748397100337545], 
             UndirectedEdge[85, 203] -> 
             RGBColor[
              0.5387535612656835, 0.6161712103000496, 0.9614674901062294], 
             UndirectedEdge[156, 261] -> 
             RGBColor[
              0.46824979700103136`, 0.5791853054752265, 0.9512814857568959], 
             UndirectedEdge[33, 295] -> 
             RGBColor[
              0.631008880687312, 0.7113204618249118, 0.9640944770308482], 
             UndirectedEdge[59, 395] -> 
             RGBColor[
              0.7917899573539512, 0.8378789652997796, 0.979720705136009], 
             UndirectedEdge[334, 371] -> 
             RGBColor[
              0.573034162233856, 0.6558808054224606, 0.9628624506704291], 
             UndirectedEdge[40, 154] -> 
             RGBColor[
              0.30577723088949815`, 0.43743601561581646`, 0.9407720058303664],
              UndirectedEdge[300, 306] -> 
             RGBColor[
              0.6862363971195473, 0.7533393180391956, 0.9704134309827162], 
             UndirectedEdge[61, 297] -> 
             RGBColor[
              0.5982549928985696, 0.6702540590616297, 0.9587356982090252], 
             UndirectedEdge[97, 350] -> 
             RGBColor[
              0.30128830755106983`, 0.4235702951888063, 0.9408513059055588], 
             UndirectedEdge[178, 229] -> 
             RGBColor[
              0.5014718965080414, 0.599740092988723, 0.9557930373417787], 
             UndirectedEdge[130, 265] -> 
             RGBColor[
              0.8048237857344227, 0.8482880273443947, 0.9758212201770864], 
             UndirectedEdge[110, 134] -> 
             RGBColor[
              0.5000523283277587, 0.6042689406268231, 0.9539882057583295], 
             UndirectedEdge[147, 211] -> 
             RGBColor[
              0.3393384965891258, 0.4589580811442403, 0.9432778036934978], 
             UndirectedEdge[78, 185] -> 
             RGBColor[
              0.35335699712391544`, 0.4803658682952233, 0.9437408182443601], 
             UndirectedEdge[130, 135] -> 
             RGBColor[
              0.8290574618558302, 0.8654181561748168, 0.8925567065538802], 
             UndirectedEdge[52, 384] -> 
             RGBColor[
              0.46532439305578066`, 0.5602028689323142, 0.9539789134793514], 
             UndirectedEdge[77, 166] -> 
             RGBColor[
              0.35310560619742937`, 0.47899085581511724`, 0.9437671731713442],
              UndirectedEdge[24, 76] -> 
             RGBColor[
              0.6456542437990153, 0.7207595529688994, 0.9669229531317634], 
             UndirectedEdge[100, 220] -> 
             RGBColor[
              0.669678233895861, 0.7411336226052276, 0.9682191724256288], 
             UndirectedEdge[41, 369] -> 
             RGBColor[
              0.782564840595678, 0.8301414563218097, 0.9789420837803301], 
             UndirectedEdge[12, 318] -> 
             RGBColor[
              0.34619775612855974`, 0.47331279751971755`, 0.9433158371496289],
              UndirectedEdge[118, 199] -> 
             RGBColor[
              0.6459824039160779, 0.36659973096652543`, 0.4408974639282713], 
             UndirectedEdge[11, 205] -> 
             RGBColor[
              0.39646145651081255`, 0.5168288453096166, 0.9467283156833273], 
             UndirectedEdge[120, 136] -> 
             RGBColor[
              0.7309577142327224, 0.7897489889337708, 0.9738186918326593], 
             UndirectedEdge[66, 215] -> 
             RGBColor[
              0.23274784381697988`, 0.36196311929023695`, 0.9365660174345738],
              UndirectedEdge[199, 287] -> 
             RGBColor[
              0.5488066130551289, 0.6299150252424928, 0.9615586392540597], 
             UndirectedEdge[8, 64] -> 
             RGBColor[
              0.5117985467417672, 0.614464616441937, 0.9547306708979912], 
             UndirectedEdge[312, 361] -> 
             RGBColor[
              0.590068407993844, 0.6759123639557264, 0.9621272540808541], 
             UndirectedEdge[5, 193] -> 
             RGBColor[
              0.6123248353239401, 0.6895257937029307, 0.9660385638270583], 
             UndirectedEdge[187, 232] -> 
             RGBColor[
              0.4724922862920294, 0.5801431175532544, 0.9523024785832187], 
             UndirectedEdge[115, 325] -> 
             RGBColor[
              0.6270447601826978, 0.7078812359886741, 0.9639334882308901], 
             UndirectedEdge[137, 252] -> 
             RGBColor[
              0.4453326682233367, 0.5589179261516751, 0.9499366422608663], 
             UndirectedEdge[296, 390] -> 
             RGBColor[
              0.6474569594526406, 0.7201477749935191, 0.9681886249226286], 
             UndirectedEdge[101, 171] -> 
             RGBColor[
              0.5857386948458683, 0.6660171136623554, 0.9640733024673807], 
             UndirectedEdge[234, 342] -> 
             RGBColor[
              0.541610974070069, 0.6267251542785118, 0.9604858600023005], 
             UndirectedEdge[56, 343] -> 
             RGBColor[
              0.6961494088534266, 0.7610772189263624, 0.9715505417298926], 
             UndirectedEdge[60, 146] -> 
             RGBColor[
              0.7407770808048273, 0.7974199527298491, 0.974797394525369], 
             UndirectedEdge[149, 336] -> 
             RGBColor[
              0.8348930626499278, 0.8717837603974559, 0.9839551688292173], 
             UndirectedEdge[12, 199] -> 
             RGBColor[
              0.31891822960853367`, 0.4446402855252906, 0.9417623084707564], 
             UndirectedEdge[42, 104] -> 
             RGBColor[
              0.5205788332912187, 0.620610742362107, 0.9556932461009442], 
             UndirectedEdge[216, 323] -> 
             RGBColor[
              0.7042236222902545, 0.45729135130597776`, 0.449211179500079], 
             UndirectedEdge[110, 192] -> 
             RGBColor[
              0.5227886055394697, 0.6227272747249061, 0.9557780887861631], 
             UndirectedEdge[93, 380] -> 
             RGBColor[
              0.6006170778911226, 0.6866470271798518, 0.9617019229858903], 
             UndirectedEdge[34, 397] -> 
             RGBColor[
              0.6116876069774528, 0.6953740466695661, 0.9627515646157846], 
             UndirectedEdge[249, 308] -> 
             RGBColor[
              0.39046330493213266`, 0.5075558895916626, 0.9466569428058147], 
             UndirectedEdge[116, 130] -> 
             RGBColor[
              0.4795485356219547, 0.5818958412900248, 0.9537215211879964], 
             UndirectedEdge[81, 315] -> 
             RGBColor[
              0.2461803816246153, 0.3760815681981491, 0.9373309805910597], 
             UndirectedEdge[99, 193] -> 
             RGBColor[
              0.5735174313945113, 0.6506575503512235, 0.9637582097336616], 
             UndirectedEdge[116, 135] -> 
             RGBColor[
              0.640360983775746, 0.7065566468198181, 0.878710151814609], 
             UndirectedEdge[304, 378] -> 
             RGBColor[
              0.7540452999499232, 0.8077851863681984, 0.9761198466111947], 
             UndirectedEdge[56, 120] -> 
             RGBColor[
              0.8007382041442168, 0.8447158361256103, 0.9806533348628207], 
             UndirectedEdge[255, 393] -> 
             RGBColor[
              0.7106556541033507, 0.7729337578698278, 0.9726007753573152], 
             UndirectedEdge[106, 214] -> 
             RGBColor[
              0.5153309406781263, 0.6174078988936442, 0.9549878858510688], 
             UndirectedEdge[130, 328] -> 
             RGBColor[
              0.7966907796435535, 0.8419500681023722, 0.9801448097979784], 
             UndirectedEdge[181, 250] -> 
             RGBColor[
              0.7274001963084578, 0.7869698288931974, 0.9734641116928637], 
             UndirectedEdge[102, 230] -> 
             RGBColor[
              0.38945802971994675`, 0.5030395267596388, 0.9469146222747189], 
             UndirectedEdge[45, 141] -> 
             RGBColor[
              0.9004147212263024, 0.9211730785101911, 0.900126408482584], 
             UndirectedEdge[225, 288] -> 
             RGBColor[
              0.7043289587901108, 0.7649225909982296, 0.9302574310219376], 
             UndirectedEdge[208, 278] -> 
             RGBColor[
              0.5928394741933116, 0.6801416692997624, 0.961220331025479], 
             UndirectedEdge[342, 346] -> 
             RGBColor[
              0.6579311520767106, 0.7304643125819894, 0.9680686954139277], 
             UndirectedEdge[133, 164] -> 
             RGBColor[
              0.9252508778404058, 0.9428746363129892, 0.9802747831370882], 
             UndirectedEdge[287, 373] -> 
             RGBColor[
              0.582101479061038, 0.6647657532186834, 0.9634600156794122], 
             UndirectedEdge[122, 314] -> 
             RGBColor[
              0.6137174619686937, 0.6972825091396013, 0.9627332332087648], 
             UndirectedEdge[85, 351] -> 
             RGBColor[
              0.8017029969045697, 0.8454923088707926, 0.9807434541143946], 
             UndirectedEdge[5, 338] -> 
             RGBColor[
              0.4305566776757501, 0.5452229567092821, 0.9492429036553177], 
             UndirectedEdge[311, 339] -> 
             RGBColor[
              0.5796104264005266, 0.6613416072218257, 0.9634568164212236], 
             UndirectedEdge[39, 324] -> 
             RGBColor[
              0.774512411877361, 0.8214550193575146, 0.8847497620662311], 
             UndirectedEdge[52, 346] -> 
             RGBColor[
              0.6073124587697638, 0.6909206046542848, 0.9630234971236746], 
             UndirectedEdge[272, 291] -> 
             RGBColor[
              0.7401371883716272, 0.7969200638976706, 0.9747336160277624], 
             UndirectedEdge[191, 323] -> 
             RGBColor[
              0.8772380030855058, 0.5963681658739555, 0.46438148149089253`], 
             UndirectedEdge[60, 165] -> 
             RGBColor[
              0.7960549490426825, 0.8412759821392694, 0.9801285047606094], 
             UndirectedEdge[44, 301] -> 
             RGBColor[
              0.6116880746216407, 0.6947672139997093, 0.9631667558129824], 
             UndirectedEdge[11, 144] -> 
             RGBColor[
              0.6513005073151132, 0.7162354507916604, 0.8249202634942088], 
             UndirectedEdge[333, 381] -> 
             RGBColor[
              0.7774925214668429, 0.8236399487148739, 0.8751831088240691], 
             UndirectedEdge[9, 363] -> 
             RGBColor[
              0.567831121009537, 0.6600299103928549, 0.9591208923612546], 
             UndirectedEdge[153, 312] -> 
             RGBColor[
              0.5458071980941401, 0.6375755285736967, 0.9593069689246962], 
             UndirectedEdge[55, 80] -> 
             RGBColor[
              0.6576844894213298, 0.725200960608486, 0.9372016763885389], 
             UndirectedEdge[7, 40] -> 
             RGBColor[
              0.3500987518072558, 0.4776596751657055, 0.9435289607783557], 
             UndirectedEdge[51, 377] -> 
             RGBColor[
              0.8730350419233492, 0.8514216629672477, 0.6343232640584725], 
             UndirectedEdge[112, 170] -> 
             RGBColor[
              0.8115784366536694, 0.8535837012954367, 0.9774506347225251], 
             UndirectedEdge[200, 375] -> 
             RGBColor[
              0.6860553508794348, 0.7534168799843712, 0.9702006388627777], 
             UndirectedEdge[94, 200] -> 
             RGBColor[
              0.39107305848437846`, 0.5021868532281801, 0.9472387282143251], 
             UndirectedEdge[8, 253] -> 
             RGBColor[
              0.505956195143862, 0.609404265132961, 0.9543584014203614], 
             UndirectedEdge[31, 295] -> 
             RGBColor[
              0.44310391924611986`, 0.5494476511850551, 0.9508778546389618], 
             UndirectedEdge[301, 383] -> 
             RGBColor[
              0.5498178420212049, 0.6431075831980579, 0.9586913803998296], 
             UndirectedEdge[327, 392] -> 
             RGBColor[
              0.5695624798092653, 0.6468704572785198, 0.9634769571488331], 
             UndirectedEdge[119, 375] -> 
             RGBColor[
              0.6024456270072039, 0.6839084652082277, 0.9640690247905417], 
             UndirectedEdge[160, 340] -> 
             RGBColor[
              0.7000166834140944, 0.7655776204977147, 0.970734779041031], 
             UndirectedEdge[151, 308] -> 
             RGBColor[
              0.6762292570829751, 0.7451505885148197, 0.9696998503515308], 
             UndirectedEdge[221, 276] -> 
             RGBColor[
              0.6727540109448449, 0.743265884533826, 0.9687107194467385], 
             UndirectedEdge[94, 316] -> 
             RGBColor[
              0.5422983009733997, 0.6219264507475535, 0.9613619033747023], 
             UndirectedEdge[195, 206] -> 
             RGBColor[
              0.5040974964585435, 0.6082880828152919, 0.9541035479726412], 
             UndirectedEdge[159, 192] -> 
             RGBColor[
              0.7780603862896991, 0.8271092007005516, 0.9775298552708611], 
             UndirectedEdge[220, 350] -> 
             RGBColor[
              0.38740935545519384`, 0.4943487316466715, 0.9473930379978919], 
             UndirectedEdge[229, 319] -> 
             RGBColor[
              0.3645956909014412, 0.4890534695118276, 0.9444952660004593], 
             UndirectedEdge[69, 97] -> 
             RGBColor[
              0.37872024528550263`, 0.5024501742584727, 0.9453526970337967], 
             UndirectedEdge[90, 317] -> 
             RGBColor[
              0.6735114012805687, 0.7357791503665339, 0.8386720219072357], 
             UndirectedEdge[136, 237] -> 
             RGBColor[
              0.5363412035117349, 0.6298394671607799, 0.9585078798032406], 
             UndirectedEdge[69, 141] -> 
             RGBColor[
              0.6628327695789245, 0.7276874152027795, 0.8805379485119968], 
             UndirectedEdge[48, 143] -> 
             RGBColor[
              0.5400989964239474, 0.6312683420263754, 0.9594289106125335], 
             UndirectedEdge[51, 246] -> 
             RGBColor[
              0.7459491779514059, 0.8014604343301506, 0.975312900832944], 
             UndirectedEdge[97, 132] -> 
             RGBColor[
              0.667760899799191, 0.7368951125758714, 0.9698685727208103], 
             UndirectedEdge[94, 383] -> 
             RGBColor[
              0.31114046840324183`, 0.43586338692376414`, 0.9413414178556959],
              UndirectedEdge[246, 344] -> 
             RGBColor[
              0.5605036040697273, 0.6521829290328599, 0.9594485047940583], 
             UndirectedEdge[155, 354] -> 
             RGBColor[
              0.6814539463632381, 0.7424555614227366, 0.8257076519994497], 
             UndirectedEdge[107, 307] -> 
             RGBColor[
              0.5913731736918928, 0.6787361316230085, 0.9612519832645903], 
             UndirectedEdge[310, 363] -> 
             RGBColor[
              0.4645022809386241, 0.5747123143576875, 0.9513817435001426], 
             UndirectedEdge[99, 281] -> 
             RGBColor[
              0.39862502607185035`, 0.5119367588445518, 0.9475038339716972], 
             UndirectedEdge[123, 187] -> 
             RGBColor[
              0.6776223514817582, 0.7381261976034462, 0.7390864502943968], 
             UndirectedEdge[23, 227] -> 
             RGBColor[
              0.3754433037539411, 0.49636918042359074`, 0.9453828312810011], 
             UndirectedEdge[28, 211] -> 
             RGBColor[
              0.3560401156369377, 0.47651254170729995`, 0.9442289361904395], 
             UndirectedEdge[327, 356] -> 
             RGBColor[
              0.3956258955349544, 0.5089045478368321, 0.9473221088301874], 
             UndirectedEdge[140, 219] -> 
             RGBColor[
              0.7859019844828903, 0.8328149323850922, 0.9604335087346265], 
             UndirectedEdge[104, 144] -> 
             RGBColor[
              0.8109502003064052, 0.8499217150264652, 0.8363902010834009], 
             UndirectedEdge[49, 328] -> 
             RGBColor[
              0.5870941719560774, 0.6611211973852504, 0.9651080235965372], 
             UndirectedEdge[112, 271] -> 
             RGBColor[
              0.7892779290385502, 0.8360989743468523, 0.9752712760816438], 
             UndirectedEdge[106, 197] -> 
             RGBColor[
              0.4156268875182631, 0.5286920207230297, 0.9485735383540456], 
             UndirectedEdge[106, 204] -> 
             RGBColor[
              0.44952879343410235`, 0.5610292009757563, 0.9506248797752657], 
             UndirectedEdge[50, 158] -> 
             RGBColor[
              0.6182117342849736, 0.6986422515312908, 0.9646173764058739], 
             UndirectedEdge[259, 299] -> 
             RGBColor[
              0.3417102478900065, 0.4648780624614259, 0.9431964172935019], 
             UndirectedEdge[79, 286] -> 
             RGBColor[
              0.45386153920559325`, 0.5642210736217574, 0.9510559462320554], 
             UndirectedEdge[240, 388] -> 
             RGBColor[
              0.4623771937639113, 0.569891495217991, 0.9519584708656601], 
             UndirectedEdge[118, 299] -> 
             RGBColor[
              0.6477723428786368, 0.36848107030486, 0.44099939830421164`], 
             UndirectedEdge[138, 257] -> 
             RGBColor[
              0.8714956473841483, 0.9004681365845011, 0.9873028797443595], 
             UndirectedEdge[171, 244] -> 
             RGBColor[
              0.8560418936587765, 0.8880485856380589, 0.9861312340864358], 
             UndirectedEdge[161, 337] -> 
             RGBColor[
              0.667500158453251, 0.7379564728871352, 0.9691363253376974], 
             UndirectedEdge[119, 355] -> 
             RGBColor[
              0.4838414772143187, 0.5902130595080326, 0.9529593696009884], 
             UndirectedEdge[248, 292] -> 
             RGBColor[
              0.4966744479241837, 0.6017932992968614, 0.9536486037762253], 
             UndirectedEdge[68, 386] -> 
             RGBColor[
              0.4155025245472843, 0.5280707140827869, 0.9486111129178993], 
             UndirectedEdge[126, 299] -> 
             RGBColor[
              0.41255849038056336`, 0.5229113223647764, 0.9486314259602736], 
             UndirectedEdge[128, 383] -> 
             RGBColor[
              0.6182993694143547, 0.6967350674099055, 0.9654826947973145], 
             UndirectedEdge[229, 248] -> 
             RGBColor[
              0.42672625334335884`, 0.5400449631895177, 0.9492341397524569], 
             UndirectedEdge[395, 396] -> 
             RGBColor[
              0.7871829996493593, 0.8342799749267771, 0.9792615266464828], 
             UndirectedEdge[81, 292] -> 
             RGBColor[
              0.3224694615385071, 0.44449457682589666`, 0.942106548654047], 
             UndirectedEdge[34, 253] -> 
             RGBColor[
              0.5014301744090468, 0.6057298376055273, 0.9540020964887566], 
             UndirectedEdge[130, 322] -> 
             RGBColor[
              0.8315523695266147, 0.8660855739348683, 0.8247295431907126], 
             UndirectedEdge[74, 311] -> 
             RGBColor[
              0.5569778591576178, 0.6375533440618844, 0.9621679251986228], 
             UndirectedEdge[232, 235] -> 
             RGBColor[
              0.46381681848080697`, 0.5726288633768642, 0.9517496854457026], 
             UndirectedEdge[207, 221] -> 
             RGBColor[
              0.6263243314548808, 0.7055721790906482, 0.9650556049997685], 
             UndirectedEdge[140, 216] -> 
             RGBColor[
              0.5087586076390077, 0.6106923775498047, 0.9548517320351805], 
             UndirectedEdge[31, 173] -> 
             RGBColor[
              0.2974615992141002, 0.4278956997583421, 0.9403277370140535], 
             UndirectedEdge[37, 243] -> 
             RGBColor[
              0.537338252858792, 0.632776655445533, 0.9576937675401243], 
             UndirectedEdge[1, 35] -> 
             RGBColor[
              0.6169537381778885, 0.6908545784112858, 0.9652282118240187], 
             UndirectedEdge[60, 210] -> 
             RGBColor[
              0.7204855797633758, 0.7815680778951473, 0.9727749273364155], 
             UndirectedEdge[35, 92] -> 
             RGBColor[
              0.6430200170141804, 0.7093514593458574, 0.8788615798238507], 
             UndirectedEdge[52, 291] -> 
             RGBColor[
              0.6971806948647732, 0.7633621246886736, 0.9704521142062544], 
             UndirectedEdge[77, 400] -> 
             RGBColor[
              0.35936404196033794`, 0.48556886860968007`, 0.9441235818295157],
              UndirectedEdge[77, 389] -> 
             RGBColor[
              0.35919624919479065`, 0.4853925077744141, 0.944114026279745], 
             UndirectedEdge[96, 361] -> 
             RGBColor[
              0.40404473350640013`, 0.5243849731096265, 0.9469663510296666], 
             UndirectedEdge[150, 374] -> 
             RGBColor[
              0.7981277832544239, 0.8099938715167998, 0.6523695572247235], 
             UndirectedEdge[80, 154] -> 
             RGBColor[
              0.3158578725983373, 0.44616736079622865`, 0.9414143354060922], 
             UndirectedEdge[200, 383] -> 
             RGBColor[
              0.4805631047322015, 0.5877512146451803, 0.952646110381909], 
             UndirectedEdge[144, 391] -> 
             RGBColor[
              0.8228905150309611, 0.8594880546917183, 0.8374172533706126], 
             UndirectedEdge[196, 290] -> 
             RGBColor[
              0.5951487564027333, 0.6813924880090195, 0.9618287314640646], 
             UndirectedEdge[159, 228] -> 
             RGBColor[
              0.6383453973442423, 0.710602771654746, 0.9673818564887378], 
             UndirectedEdge[27, 377] -> 
             RGBColor[
              0.6747588242058686, 0.6910308988662954, 0.6176413107400622], 
             UndirectedEdge[24, 233] -> 
             RGBColor[
              0.7645331314246995, 0.8159783600267649, 0.9771651756382428], 
             UndirectedEdge[24, 109] -> 
             RGBColor[
              0.6901181131613359, 0.7568573251917192, 0.9704233118044854], 
             UndirectedEdge[189, 255] -> 
             RGBColor[
              0.6963503060423724, 0.7615270616343324, 0.971236318488724], 
             UndirectedEdge[262, 298] -> 
             RGBColor[
              0.47869556290216575`, 0.5876656488101586, 0.9521038147127345], 
             UndirectedEdge[249, 397] -> 
             RGBColor[
              0.4650219386328355, 0.567825412513844, 0.9527046005955424], 
             UndirectedEdge[128, 324] -> 
             RGBColor[
              0.9131137569401422, 0.9311411833466607, 0.8976544487780935], 
             UndirectedEdge[7, 228] -> 
             RGBColor[
              0.35872427307220545`, 0.4851306681541006, 0.9440785713661093], 
             UndirectedEdge[115, 258] -> 
             RGBColor[
              0.7680672828882062, 0.8189289656629721, 0.974935843255615], 
             UndirectedEdge[375, 383] -> 
             RGBColor[
              0.6061227607982982, 0.6870934136799551, 0.9643033285041485], 
             UndirectedEdge[257, 338] -> 
             RGBColor[
              0.7337991287988097, 0.7912017646811483, 0.9747386925001794], 
             UndirectedEdge[5, 321] -> 
             RGBColor[
              0.45370965150248965`, 0.5640195838914139, 0.9510655905670964], 
             UndirectedEdge[65, 239] -> 
             RGBColor[
              0.8655658600522012, 0.8946763462840013, 0.9296392601569684], 
             UndirectedEdge[56, 71] -> 
             RGBColor[
              0.6597868335106258, 0.7312883614079544, 0.9687620181055507], 
             UndirectedEdge[276, 322] -> 
             RGBColor[
              0.7855149291234629, 0.829106846567494, 0.8208341901889504], 
             UndirectedEdge[239, 326] -> 
             RGBColor[
              0.6176851918665425, 0.6989271688755572, 0.9641234642374211], 
             UndirectedEdge[379, 393] -> 
             RGBColor[
              0.855761562098732, 0.887825056861477, 0.9861044958119838], 
             UndirectedEdge[131, 262] -> 
             RGBColor[
              0.41925486064983564`, 0.5374103640003101, 0.947976656447142], 
             UndirectedEdge[201, 210] -> 
             RGBColor[
              0.7997457798528407, 0.8437086521498197, 0.9806159569747303], 
             UndirectedEdge[301, 372] -> 
             RGBColor[
              0.6557623842352129, 0.7305487240690285, 0.9666364469152786], 
             UndirectedEdge[291, 398] -> 
             RGBColor[
              0.568032955268323, 0.6596762059912278, 0.9594906418324344], 
             UndirectedEdge[28, 49] -> 
             RGBColor[
              0.24691798899643974`, 0.37685684031294503`, 0.9373729862396929],
              UndirectedEdge[6, 160] -> 
             RGBColor[
              0.8182269240965887, 0.8585270545296038, 0.9823569342191156], 
             UndirectedEdge[375, 379] -> 
             RGBColor[
              0.829012815238514, 0.8665639756457875, 0.9835352259643884], 
             UndirectedEdge[45, 112] -> 
             RGBColor[
              0.8756750272473557, 0.9036564450193556, 0.9838391838562092], 
             UndirectedEdge[324, 390] -> 
             RGBColor[
              0.939897922331957, 0.9524981497932924, 0.9002091463836714], 
             UndirectedEdge[169, 227] -> 
             RGBColor[
              0.4658545883649988, 0.5772407672015758, 0.951092926159129], 
             UndirectedEdge[44, 380] -> 
             RGBColor[
              0.5539948979748242, 0.6487970412185304, 0.958031654200207], 
             UndirectedEdge[288, 360] -> 
             RGBColor[
              0.413138566524538, 0.5322615942006002, 0.9475458020282216], 
             UndirectedEdge[87, 134] -> 
             RGBColor[
              0.682582240404538, 0.7509083768680034, 0.9697145054124594], 
             UndirectedEdge[85, 258] -> 
             RGBColor[
              0.9088875469726851, 0.930105557142642, 0.9883731562604572], 
             UndirectedEdge[26, 77] -> 
             RGBColor[
              0.5933351207689956, 0.677554039361141, 0.9628381338881974], 
             UndirectedEdge[90, 333] -> 
             RGBColor[
              0.671764708200451, 0.7350568478899404, 0.8676192465415775], 
             UndirectedEdge[45, 91] -> 
             RGBColor[
              0.5595050737869441, 0.6466716571962621, 0.9613246344071786], 
             UndirectedEdge[103, 133] -> 
             RGBColor[
              0.8670834534926772, 0.8968528257344539, 0.9871843879203102], 
             UndirectedEdge[143, 342] -> 
             RGBColor[
              0.7967288819735561, 0.8411299250522988, 0.9803741471665579], 
             UndirectedEdge[75, 164] -> 
             RGBColor[
              0.6989684712149518, 0.7623385260892455, 0.9599646044254171], 
             UndirectedEdge[44, 211] -> 
             RGBColor[
              0.49583351573000933`, 0.6015790109717787, 0.953452977137732], 
             UndirectedEdge[82, 171] -> 
             RGBColor[
              0.8133288101300229, 0.8545450724529917, 0.981910011055336], 
             UndirectedEdge[17, 122] -> 
             RGBColor[
              0.4549143103799942, 0.5608873237306704, 0.9516390800344934], 
             UndirectedEdge[150, 186] -> 
             RGBColor[
              0.43204210835403256`, 0.5374786870535561, 0.9502790591049046], 
             UndirectedEdge[180, 394] -> 
             RGBColor[
              0.6410168939040232, 0.7191197883817901, 0.9651049791103856], 
             UndirectedEdge[156, 202] -> 
             RGBColor[
              0.7025598528793068, 0.765811783654722, 0.9715142213261116], 
             UndirectedEdge[86, 178] -> 
             RGBColor[
              0.4951310111749745, 0.5930754204683191, 0.9554319333025598], 
             UndirectedEdge[102, 250] -> 
             RGBColor[
              0.47041824311456987`, 0.5678669106760199, 0.9539032807657433], 
             UndirectedEdge[7, 222] -> 
             RGBColor[
              0.501248671144527, 0.6039179020915341, 0.9544477371259041], 
             UndirectedEdge[97, 220] -> 
             RGBColor[
              0.5077110304772015, 0.6103602224591886, 0.9546260508778738], 
             UndirectedEdge[230, 289] -> 
             RGBColor[
              0.4504597267992072, 0.5622560932014873, 0.9505679947920189], 
             UndirectedEdge[14, 289] -> 
             RGBColor[
              0.3147020568597212, 0.4432021084759445, 0.9414126047395246], 
             UndirectedEdge[77, 370] -> 
             RGBColor[
              0.3684478488272642, 0.4935527407520049, 0.9446981490150013], 
             UndirectedEdge[151, 270] -> 
             RGBColor[
              0.615206042799501, 0.6938411665819498, 0.965384390657439], 
             UndirectedEdge[173, 214] -> 
             RGBColor[
              0.4036511987116175, 0.5234282983372189, 0.9471114267805001], 
             UndirectedEdge[144, 317] -> 
             RGBColor[
              0.9950194323918453, 0.9920591364966842, 0.7213529775928241], 
             UndirectedEdge[31, 175] -> 
             RGBColor[
              0.4351671715541779, 0.5430042418623277, 0.9502530447873874], 
             UndirectedEdge[163, 240] -> 
             RGBColor[
              0.7066163264479528, 0.7704065872607662, 0.9716159531298754], 
             UndirectedEdge[329, 371] -> 
             RGBColor[
              0.6294465779785197, 0.7059095464494447, 0.9664142651365473], 
             UndirectedEdge[72, 375] -> 
             RGBColor[
              0.764915563991594, 0.8162771192546181, 0.9772032929424753], 
             UndirectedEdge[32, 238] -> 
             RGBColor[
              0.873046778518938, 0.9016409893083229, 0.9877443728686571], 
             UndirectedEdge[11, 14] -> 
             RGBColor[
              0.28757577543702717`, 0.41959075171455246`, 0.9396883870296793],
              UndirectedEdge[79, 237] -> 
             RGBColor[
              0.33425746232772857`, 0.46393874642489896`, 0.9425195678206225],
              UndirectedEdge[69, 74] -> 
             RGBColor[
              0.29420950411494207`, 0.4240572242000998, 0.9401579248887129], 
             UndirectedEdge[16, 203] -> 
             RGBColor[
              0.259510558661596, 0.3890093959210795, 0.9381297696158063], 
             UndirectedEdge[315, 319] -> 
             RGBColor[
              0.3582548055683743, 0.48238879699142373`, 0.9441341619612403], 
             UndirectedEdge[40, 80] -> 
             RGBColor[
              0.3327317234923245, 0.46261722813153555`, 0.9424223490911885], 
             UndirectedEdge[18, 198] -> 
             RGBColor[
              0.42582909120269546`, 0.5423573093388743, 0.9486020481031816], 
             UndirectedEdge[300, 307] -> 
             RGBColor[
              0.6735818362329565, 0.7430657754299899, 0.9694172175945398], 
             UndirectedEdge[191, 198] -> 
             RGBColor[
              0.703933787599095, 0.7670683002271019, 0.9725416013949579], 
             UndirectedEdge[289, 391] -> 
             RGBColor[
              0.5062083504474865, 0.6073879915928457, 0.9550437976328294], 
             UndirectedEdge[132, 357] -> 
             RGBColor[
              0.8410651465881368, 0.876525097167499, 0.9845916648010217], 
             UndirectedEdge[157, 187] -> 
             RGBColor[
              0.47961177362371504`, 0.5859230380983661, 0.9528629507055104], 
             UndirectedEdge[38, 250] -> 
             RGBColor[
              0.6689742769401184, 0.7412427162911266, 0.9676984260212642], 
             UndirectedEdge[140, 191] -> 
             RGBColor[
              0.7682801788318845, 0.8193075994017713, 0.9776071850214008], 
             UndirectedEdge[204, 261] -> 
             RGBColor[
              0.4063217427664596, 0.525951770788313, 0.9472234624740672], 
             UndirectedEdge[337, 354] -> 
             RGBColor[
              0.4228815228617066, 0.54003181768661, 0.9483513605986023], 
             UndirectedEdge[300, 314] -> 
             RGBColor[
              0.7150011702975263, 0.7766918567433434, 0.9726778992961227], 
             UndirectedEdge[292, 378] -> 
             RGBColor[
              0.6098485308106321, 0.6915090182736694, 0.9640376891028258], 
             UndirectedEdge[153, 361] -> 
             RGBColor[
              0.3884083546771544, 0.5108415276749851, 0.945970014797374], 
             UndirectedEdge[240, 334] -> 
             RGBColor[
              0.4585764582458505, 0.5658966812079589, 0.9517420246005908], 
             UndirectedEdge[52, 260] -> 
             RGBColor[
              0.693401488578628, 0.7604097800149054, 0.9700754382423422], 
             UndirectedEdge[128, 177] -> 
             RGBColor[
              0.7288075098209281, 0.7878811428813564, 0.9737870244794933], 
             UndirectedEdge[16, 85] -> 
             RGBColor[
              0.5997029397460805, 0.6791498379717649, 0.9649781222068832], 
             UndirectedEdge[179, 303] -> 
             RGBColor[
              0.5521526049783492, 0.6391489741435813, 0.9608734316069425], 
             UndirectedEdge[48, 320] -> 
             RGBColor[
              0.5781750794665672, 0.6612575399457582, 0.9631592624771556], 
             UndirectedEdge[136, 320] -> 
             RGBColor[
              0.7933621586896923, 0.8387436876924389, 0.9799738674016003], 
             UndirectedEdge[96, 192] -> 
             RGBColor[
              0.49737600232011997`, 0.6007161550908815, 0.9541588201805088], 
             UndirectedEdge[140, 357] -> 
             RGBColor[
              0.6916074306183388, 0.758589394313196, 0.9701829960703059], 
             UndirectedEdge[202, 306] -> 
             RGBColor[
              0.738022369100832, 0.7946018518915062, 0.9743059605065472], 
             UndirectedEdge[114, 258] -> 
             RGBColor[
              0.8970717902927958, 0.9206839934962693, 0.9872461588402788], 
             UndirectedEdge[87, 236] -> 
             RGBColor[
              0.6624852921082147, 0.7345927688838447, 0.9681324000250255], 
             UndirectedEdge[116, 362] -> 
             RGBColor[
              0.3942650874670677, 0.5130554368172908, 0.9467365786931542], 
             UndirectedEdge[36, 64] -> 
             RGBColor[
              0.39526629382001865`, 0.5167815298704905, 0.9464069966153197], 
             UndirectedEdge[245, 304] -> 
             RGBColor[
              0.6672623362539829, 0.7394949668566158, 0.9678083668611258], 
             UndirectedEdge[187, 218] -> 
             RGBColor[
              0.4369410858192237, 0.5512810514461007, 0.9495037578536611], 
             UndirectedEdge[26, 370] -> 
             RGBColor[
              0.5505469469845286, 0.6404930738251815, 0.9601117092907476], 
             UndirectedEdge[91, 141] -> 
             RGBColor[
              0.6489053837205627, 0.7155548465760078, 0.8796530476665356], 
             UndirectedEdge[55, 385] -> 
             RGBColor[
              0.6012719174936114, 0.6690574389722, 0.9338737390894871], 
             UndirectedEdge[179, 231] -> 
             RGBColor[
              0.29655823493649625`, 0.42903188616932064`, 0.9401999248098161],
              UndirectedEdge[94, 177] -> 
             RGBColor[
              0.42164860880981514`, 0.5270094623952148, 0.9496457475378748], 
             UndirectedEdge[225, 383] -> 
             RGBColor[
              0.6922392375196178, 0.7544510820807876, 0.9294870846731025], 
             UndirectedEdge[37, 134] -> 
             RGBColor[
              0.630801877091516, 0.7104571635025339, 0.9645535227124242], 
             UndirectedEdge[255, 341] -> 
             RGBColor[
              0.6040515670704121, 0.6892890779881451, 0.9620722714918852], 
             UndirectedEdge[206, 278] -> 
             RGBColor[
              0.5745662550954164, 0.6653066468369517, 0.9597817962810855], 
             UndirectedEdge[131, 279] -> 
             RGBColor[
              0.5481151348857564, 0.6408888750864972, 0.9588977428563301], 
             UndirectedEdge[7, 203] -> 
             RGBColor[
              0.2880538010061126, 0.413732117814826, 0.9399485197782007], 
             UndirectedEdge[101, 151] -> 
             RGBColor[
              0.5691896526732616, 0.652821356645702, 0.962494840051453], 
             UndirectedEdge[200, 296] -> 
             RGBColor[
              0.48293652937867243`, 0.5898069557821621, 0.9527973429016452], 
             UndirectedEdge[86, 229] -> 
             RGBColor[
              0.2898292386856726, 0.421959284466701, 0.9398167184279895], 
             UndirectedEdge[138, 382] -> 
             RGBColor[
              0.7606717685723423, 0.812961834019059, 0.9767803110756073], 
             UndirectedEdge[195, 278] -> 
             RGBColor[
              0.5843683572710742, 0.6732644349628216, 0.9605534536706367], 
             UndirectedEdge[65, 113] -> 
             RGBColor[
              0.8790495387936097, 0.9052098985965437, 0.9309831872417701], 
             UndirectedEdge[249, 270] -> 
             RGBColor[
              0.3294400906486585, 0.4562464676587928, 0.9423414831117227], 
             UndirectedEdge[319, 388] -> 
             RGBColor[
              0.36837254381734624`, 0.4930231813927496, 0.9447103521866669], 
             UndirectedEdge[138, 256] -> 
             RGBColor[
              0.5575646071020217, 0.6451757424204061, 0.9611280617092144], 
             UndirectedEdge[246, 286] -> 
             RGBColor[
              0.639284468979049, 0.7171062418568597, 0.9653836642374045], 
             UndirectedEdge[188, 208] -> 
             RGBColor[
              0.7480748597044489, 0.7623189187572377, 0.6379685405809832], 
             UndirectedEdge[173, 345] -> 
             RGBColor[
              0.49520412457317164`, 0.5974985784519932, 0.9544941854279824], 
             UndirectedEdge[84, 156] -> 
             RGBColor[
              0.4110405121542, 0.5300389316597283, 0.9475241382868101], 
             UndirectedEdge[136, 349] -> 
             RGBColor[
              0.6827666051803079, 0.7518965541096476, 0.9691557311519481], 
             UndirectedEdge[117, 346] -> 
             RGBColor[
              0.5056918741064698, 0.6095824704157728, 0.9542290632214836], 
             UndirectedEdge[26, 197] -> 
             RGBColor[
              0.5260120478132346, 0.6162691240151319, 0.958657225256371], 
             UndirectedEdge[328, 362] -> 
             RGBColor[
              0.7114073314886665, 0.7731096636296381, 0.9731598673031363], 
             UndirectedEdge[187, 275] -> 
             RGBColor[
              0.39428050707616324`, 0.5159276909400453, 0.9463441831556982], 
             UndirectedEdge[20, 121] -> 
             RGBColor[
              0.5416492671980611, 0.6242485066245034, 0.9608698214607276], 
             UndirectedEdge[198, 302] -> 
             RGBColor[
              0.3790721598660419, 0.49844481078949127`, 0.9457477408536746], 
             UndirectedEdge[1, 312] -> 
             RGBColor[
              0.8426023018739336, 0.8778657823449525, 0.9828714046945026], 
             UndirectedEdge[89, 292] -> 
             RGBColor[
              0.4210365297924291, 0.5391024130200714, 0.9480490532637569], 
             UndirectedEdge[304, 315] -> 
             RGBColor[
              0.5039742024057885, 0.5999837886685737, 0.9563133399601267], 
             UndirectedEdge[21, 64] -> 
             RGBColor[
              0.6950581460995234, 0.2776359170198592, 0.4261215871160078], 
             UndirectedEdge[201, 351] -> 
             RGBColor[
              0.7859492164783135, 0.8329306719838738, 0.9792408444737725], 
             UndirectedEdge[17, 218] -> 
             RGBColor[
              0.3956178100533777, 0.512747753488625, 0.9469710423185445], 
             UndirectedEdge[266, 365] -> 
             RGBColor[
              0.6350765529742675, 0.7146227814340105, 0.9644146990936519], 
             UndirectedEdge[112, 180] -> 
             RGBColor[
              0.7793767383715442, 0.8280607417198205, 0.9744918180830806], 
             UndirectedEdge[247, 289] -> 
             RGBColor[
              0.3896599064064116, 0.5119255588780488, 0.9460497625668585], 
             UndirectedEdge[15, 45] -> 
             RGBColor[
              0.7117670051858824, 0.7742999596065755, 0.9722184641387024], 
             UndirectedEdge[57, 92] -> 
             RGBColor[
              0.6808984551508753, 0.7433225842941219, 0.8812325873251713], 
             UndirectedEdge[53, 86] -> 
             RGBColor[
              0.637592923494146, 0.7030646632235209, 0.8633565806252796], 
             UndirectedEdge[114, 154] -> 
             RGBColor[
              0.5721089044929503, 0.6542273366692496, 0.9629129200011098], 
             UndirectedEdge[71, 237] -> 
             RGBColor[
              0.3897796521122833, 0.5120292765898806, 0.9460573926573497], 
             UndirectedEdge[241, 375] -> 
             RGBColor[
              0.868386568592928, 0.8979595377985341, 0.9872907297086969], 
             UndirectedEdge[100, 282] -> 
             RGBColor[
              0.5823515601437329, 0.6693109336343384, 0.9616006189203541], 
             UndirectedEdge[55, 146] -> 
             RGBColor[
              0.8825963969662125, 0.908493011648585, 0.9556524495107344], 
             UndirectedEdge[309, 319] -> 
             RGBColor[
              0.3700386876244028, 0.4947744041735848, 0.9448052366116398], 
             UndirectedEdge[13, 302] -> 
             RGBColor[
              0.2860809564975301, 0.4180196022321462, 0.9396032593024615], 
             UndirectedEdge[110, 348] -> 
             RGBColor[
              0.36533640328681866`, 0.49045850645787614`, 0.9445145091947117],
              UndirectedEdge[217, 363] -> 
             RGBColor[
              0.5312560535638253, 0.6303366229524145, 0.9562415690730415], 
             UndirectedEdge[39, 380] -> 
             RGBColor[
              0.5711921750748972, 0.6627585654968742, 0.9593854868492264], 
             UndirectedEdge[248, 304] -> 
             RGBColor[
              0.6408712170634747, 0.7180694673913904, 0.965730761284594], 
             UndirectedEdge[204, 400] -> 
             RGBColor[
              0.3259428749204162, 0.4566211335163976, 0.9419940146189095], 
             UndirectedEdge[69, 168] -> 
             RGBColor[
              0.2909596628149077, 0.4206414349419243, 0.9399728512343853], 
             UndirectedEdge[68, 86] -> 
             RGBColor[
              0.27786393419754607`, 0.40938299080555823`, 0.9391353120384724],
              UndirectedEdge[175, 264] -> 
             RGBColor[
              0.5524200758446597, 0.6475185296683345, 0.9579076784333569], 
             UndirectedEdge[1, 92] -> 
             RGBColor[
              0.9638036311733295, 0.9715820807700384, 0.903911969180661], 
             UndirectedEdge[368, 393] -> 
             RGBColor[
              0.7292441797775133, 0.7880247604156515, 0.9740641321903983], 
             UndirectedEdge[332, 361] -> 
             RGBColor[
              0.5901182321648295, 0.6759512869767781, 0.9621322200885847], 
             UndirectedEdge[80, 203] -> 
             RGBColor[
              0.2706867726911813, 0.39868967078065604`, 0.9388419080910335], 
             UndirectedEdge[20, 347] -> 
             RGBColor[
              0.35197860882112947`, 0.4731258072219561, 0.9439173390864877], 
             UndirectedEdge[18, 311] -> 
             RGBColor[
              0.6133608989342705, 0.6915834929122326, 0.9655704250832364], 
             UndirectedEdge[170, 282] -> 
             RGBColor[
              0.5509999804911901, 0.6448188413289414, 0.958475786457758], 
             UndirectedEdge[198, 323] -> 
             RGBColor[
              0.7321645464328619, 0.4808949224508706, 0.4511566285220956], 
             UndirectedEdge[168, 357] -> 
             RGBColor[
              0.5071336468914285, 0.5974030312764027, 0.9574275650663407], 
             UndirectedEdge[180, 326] -> 
             RGBColor[
              0.5542572523553128, 0.6490100323235413, 0.9580523076980748], 
             UndirectedEdge[18, 340] -> 
             RGBColor[
              0.5117324427078019, 0.6118559237050298, 0.9555298553093012], 
             UndirectedEdge[74, 340] -> 
             RGBColor[
              0.4553494029311492, 0.5578257748546815, 0.9521273554246875], 
             UndirectedEdge[173, 204] -> 
             RGBColor[
              0.3378490514675935, 0.4670496004193311, 0.9427484207046971], 
             UndirectedEdge[26, 30] -> 
             RGBColor[
              0.6383582955863385, 0.7152485052971522, 0.9660668126232332], 
             UndirectedEdge[169, 240] -> 
             RGBColor[
              0.5404755997610146, 0.6378214658911159, 0.9569673655219948], 
             UndirectedEdge[95, 371] -> 
             RGBColor[
              0.6088589301291187, 0.6880775606475615, 0.9651024384205256], 
             UndirectedEdge[65, 356] -> 
             RGBColor[
              0.7650989835376631, 0.8146893320876027, 0.9206522628186249], 
             UndirectedEdge[264, 310] -> 
             RGBColor[
              0.4493775536284648, 0.5624333793660997, 0.9501910695625851], 
             UndirectedEdge[96, 114] -> 
             RGBColor[
              0.6153671657131659, 0.6935300541101139, 0.9656021249813754], 
             UndirectedEdge[244, 308] -> 
             RGBColor[
              0.6735129272413611, 0.7429846608319262, 0.9694407643863415], 
             UndirectedEdge[187, 298] -> 
             RGBColor[
              0.43016773493524996`, 0.5457821400625108, 0.9489705348604729], 
             UndirectedEdge[58, 228] -> 
             RGBColor[
              0.28184197385948007`, 0.41068356614361845`, 0.9394673282635764],
              UndirectedEdge[36, 82] -> 
             RGBColor[
              0.545673251964258, 0.6372945916248904, 0.9593682357628679], 
             UndirectedEdge[72, 355] -> 
             RGBColor[
              0.6463114141987087, 0.722581713554423, 0.966093637752922], 
             UndirectedEdge[22, 350] -> 
             RGBColor[
              0.3239460712614385, 0.4428263785498088, 0.9423969757924895], 
             UndirectedEdge[58, 192] -> 
             RGBColor[
              0.42155696280493676`, 0.5271899951894241, 0.9496153270456996], 
             UndirectedEdge[3, 174] -> 
             RGBColor[
              0.4725099528452642, 0.5814469960398847, 0.9519475667247692], 
             UndirectedEdge[44, 54] -> 
             RGBColor[
              0.7435267939995642, 0.7982181703593199, 0.9518761703542628], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.6582113831138224, 0.2457211028938011, 0.4237737439608721], 
             UndirectedEdge[170, 271] -> 
             RGBColor[
              0.660520722490192, 0.7346596747340233, 0.9668415383149775], 
             UndirectedEdge[192, 201] -> 
             RGBColor[
              0.7333852418509768, 0.791514552798211, 0.9742429308356393], 
             UndirectedEdge[274, 395] -> 
             RGBColor[
              0.758858819222924, 0.811850059554879, 0.9766454974851022], 
             UndirectedEdge[208, 284] -> 
             RGBColor[
              0.6232706501487741, 0.7039147352416731, 0.9642534262492115], 
             UndirectedEdge[237, 320] -> 
             RGBColor[
              0.5931354672028442, 0.6744514500662047, 0.9641038849835606], 
             UndirectedEdge[119, 380] -> 
             RGBColor[
              0.48844753158329424`, 0.5939524619451515, 0.9533219750734473], 
             UndirectedEdge[342, 398] -> 
             RGBColor[
              0.6396870747481531, 0.7156529487203491, 0.9666324548163663], 
             UndirectedEdge[90, 264] -> 
             RGBColor[
              0.4251087418522967, 0.5414129543915296, 0.9486446823362753], 
             UndirectedEdge[212, 367] -> 
             RGBColor[
              0.7447039403632104, 0.8001264803394814, 0.9757982138459669], 
             UndirectedEdge[92, 284] -> 
             RGBColor[
              0.8527846889142467, 0.8839540462864565, 0.8949216148035197], 
             UndirectedEdge[267, 342] -> 
             RGBColor[
              0.562653907589018, 0.648842611605972, 0.9616842239359742], 
             UndirectedEdge[107, 297] -> 
             RGBColor[
              0.8064110626390343, 0.8494830693771579, 0.9737040255552216], 
             UndirectedEdge[163, 245] -> 
             RGBColor[
              0.7011333581338135, 0.7659552665784402, 0.9711843137794116], 
             UndirectedEdge[72, 200] -> 
             RGBColor[
              0.6393559079254973, 0.7169349202198433, 0.9655460748202358], 
             UndirectedEdge[254, 286] -> 
             RGBColor[
              0.5796419544859723, 0.6696184770810096, 0.9600506844370282], 
             UndirectedEdge[269, 307] -> 
             RGBColor[
              0.4862237328911688, 0.5937773563474245, 0.952696459830864], 
             UndirectedEdge[240, 304] -> 
             RGBColor[
              0.6727453045681222, 0.7439462875389418, 0.9682400062115896], 
             UndirectedEdge[228, 332] -> 
             RGBColor[
              0.5437345120330926, 0.6357760399122274, 0.9591766904573036], 
             UndirectedEdge[104, 109] -> 
             RGBColor[
              0.6023448318135687, 0.6880496956485207, 0.9618379381036364], 
             UndirectedEdge[28, 372] -> 
             RGBColor[
              0.42865188937243703`, 0.5354620507489076, 0.9499452010045892], 
             UndirectedEdge[28, 362] -> 
             RGBColor[
              0.37123114852902894`, 0.4888453065573326, 0.945424829946292], 
             UndirectedEdge[209, 227] -> 
             RGBColor[
              0.3852748769291842, 0.506702787188514, 0.9459427248288221], 
             UndirectedEdge[245, 371] -> 
             RGBColor[
              0.730005293351139, 0.788752413219209, 0.9739977336110708], 
             UndirectedEdge[308, 397] -> 
             RGBColor[
              0.5848079665388692, 0.6735519436475217, 0.960635500857092], 
             UndirectedEdge[58, 87] -> 
             RGBColor[
              0.5075433782168879, 0.5947159791359856, 0.9579444772307761], 
             UndirectedEdge[154, 332] -> 
             RGBColor[
              0.5182351398741558, 0.6118551795885254, 0.9576190661844537], 
             UndirectedEdge[97, 180] -> 
             RGBColor[
              0.5200039080570691, 0.6203401342663493, 0.9555937912312553], 
             UndirectedEdge[202, 300] -> 
             RGBColor[
              0.8850839367762975, 0.911175727981907, 0.9878544273714962], 
             UndirectedEdge[25, 317] -> 
             RGBColor[
              0.9102672436568433, 0.9279750484793925, 0.8584580568930266], 
             UndirectedEdge[93, 128] -> 
             RGBColor[
              0.726791781931089, 0.7862446841728783, 0.9736283389961506], 
             UndirectedEdge[68, 178] -> 
             RGBColor[
              0.48950659201991487`, 0.5871637993275802, 0.9551116309522616], 
             UndirectedEdge[271, 273] -> 
             RGBColor[
              0.61898130808793, 0.7015559365527625, 0.9631476224573746], 
             UndirectedEdge[149, 318] -> 
             RGBColor[
              0.6110739130749678, 0.6864858381078589, 0.9664493330032984], 
             UndirectedEdge[42, 358] -> 
             RGBColor[
              0.36977759421631595`, 0.49470449937305494`, 0.9447828792153439],
              UndirectedEdge[155, 170] -> 
             RGBColor[
              0.8389547063862745, 0.8720234230028837, 0.8378890381933072], 
             UndirectedEdge[193, 338] -> 
             RGBColor[
              0.7133604263303195, 0.7749124145254209, 0.9730636973304916], 
             UndirectedEdge[79, 109] -> 
             RGBColor[
              0.4551493144830895, 0.5652665476056442, 0.9511573246191762], 
             UndirectedEdge[173, 175] -> 
             RGBColor[
              0.4690099867433769, 0.5764895068412482, 0.9522567099914894], 
             UndirectedEdge[95, 178] -> 
             RGBColor[
              0.5372727818011485, 0.6319117460847139, 0.9580316650130136], 
             UndirectedEdge[243, 348] -> 
             RGBColor[
              0.34567999850721176`, 0.47343311659741105`, 0.9432620204636315],
              UndirectedEdge[56, 83] -> 
             RGBColor[
              0.6265682661160575, 0.7025161079445228, 0.9666453603651946], 
             UndirectedEdge[205, 207] -> 
             RGBColor[
              0.48437081281424366`, 0.5922730723558783, 0.9525505911749386], 
             UndirectedEdge[74, 302] -> 
             RGBColor[
              0.2621946086719555, 0.3929135361855428, 0.9382429671304799], 
             UndirectedEdge[179, 196] -> 
             RGBColor[
              0.4951904120362644, 0.5946496760885239, 0.9551959725564334], 
             UndirectedEdge[174, 338] -> 
             RGBColor[
              0.4704147564580723, 0.5797460212252408, 0.9517826251902122], 
             UndirectedEdge[159, 167] -> 
             RGBColor[
              0.9443346832052125, 0.9580054783948141, 0.979111040880476], 
             UndirectedEdge[251, 356] -> 
             RGBColor[
              0.44353891041903526`, 0.5561213845115928, 0.9501657567117099], 
             UndirectedEdge[238, 277] -> 
             RGBColor[
              0.6953076451011861, 0.7608629730269914, 0.9709736840850614], 
             UndirectedEdge[163, 164] -> 
             RGBColor[
              0.8709174543545514, 0.899775190060583, 0.9750328238246379], 
             UndirectedEdge[213, 230] -> 
             RGBColor[
              0.7116700980006295, 0.7736194607423516, 0.9728393200776865], 
             UndirectedEdge[246, 343] -> 
             RGBColor[
              0.6097081075313817, 0.693094819233744, 0.9630553047224624], 
             UndirectedEdge[53, 95] -> 
             RGBColor[
              0.67973469412032, 0.7419009888399155, 0.8659563123357337], 
             UndirectedEdge[139, 184] -> 
             RGBColor[
              0.46709587444884026`, 0.5670006814403532, 0.9532983755548127], 
             UndirectedEdge[101, 308] -> 
             RGBColor[
              0.403209728428453, 0.5209531888562227, 0.9473828327672864], 
             UndirectedEdge[3, 52] -> 
             RGBColor[
              0.626999391247085, 0.7069033433255754, 0.9645733245638992], 
             UndirectedEdge[136, 286] -> 
             RGBColor[
              0.6559452803895995, 0.7301217943576384, 0.9670442582146734], 
             UndirectedEdge[164, 169] -> 
             RGBColor[
              0.7047767276676131, 0.7671900686909328, 0.9603842362167573], 
             UndirectedEdge[14, 102] -> 
             RGBColor[
              0.2537003597804608, 0.383985542034096, 0.9377592322222243], 
             UndirectedEdge[232, 281] -> 
             RGBColor[
              0.5642918608814569, 0.6571565795790276, 0.9588422688392351], 
             UndirectedEdge[56, 349] -> 
             RGBColor[
              0.7525470950918022, 0.8068634013014873, 0.9759903741821094], 
             UndirectedEdge[225, 324] -> 
             RGBColor[
              0.9870536250454052, 0.9888571980175427, 0.8616588386538815], 
             UndirectedEdge[5, 272] -> 
             RGBColor[
              0.5668250973603677, 0.653373686897438, 0.9616647513474168], 
             UndirectedEdge[68, 371] -> 
             RGBColor[
              0.5610927403478851, 0.643329613890428, 0.9621824043597735], 
             UndirectedEdge[151, 397] -> 
             RGBColor[
              0.7507878907836779, 0.805420111437001, 0.9757475081412588], 
             UndirectedEdge[1, 356] -> 
             RGBColor[
              0.7410386559357409, 0.7970219635390384, 0.9737750916299022], 
             UndirectedEdge[96, 115] -> 
             RGBColor[
              0.4863626583085762, 0.5917750262768167, 0.9532918093967117], 
             UndirectedEdge[328, 347] -> 
             RGBColor[
              0.6925285937149122, 0.7577830538274596, 0.9716736639104913], 
             UndirectedEdge[80, 159] -> 
             RGBColor[
              0.6398005177881319, 0.711863123846763, 0.96747457547671], 
             UndirectedEdge[50, 121] -> 
             RGBColor[
              0.8127477659056234, 0.8537998154906268, 0.9819294108871391], 
             UndirectedEdge[108, 342] -> 
             RGBColor[
              0.6358614580736954, 0.7125186690441692, 0.9663391550785136], 
             UndirectedEdge[178, 315] -> 
             RGBColor[
              0.4951310111749745, 0.5930754204683191, 0.9554319333025598], 
             UndirectedEdge[146, 228] -> 
             RGBColor[
              0.5662691523021568, 0.6533802721600297, 0.9614227328011375], 
             UndirectedEdge[63, 152] -> 
             RGBColor[
              0.37145951910026875`, 0.4960784041251868, 0.9448930851387849], 
             UndirectedEdge[43, 137] -> 
             RGBColor[
              0.4696148487514852, 0.5799499304672775, 0.9514838813322308], 
             UndirectedEdge[97, 141] -> 
             RGBColor[
              0.7057025068664993, 0.7648190269456301, 0.8832695702637409], 
             UndirectedEdge[25, 207] -> 
             RGBColor[
              0.6544576748835422, 0.7275955898206303, 0.9678476182860227], 
             UndirectedEdge[214, 310] -> 
             RGBColor[
              0.43831424883550024`, 0.5534516901389699, 0.9493201256830621], 
             UndirectedEdge[37, 87] -> 
             RGBColor[
              0.7395245697151782, 0.7964414815471783, 0.9746725559253344], 
             UndirectedEdge[146, 262] -> 
             RGBColor[
              0.6257182301895465, 0.7047232186708104, 0.9652519050410497], 
             UndirectedEdge[322, 364] -> 
             RGBColor[
              0.6257060002448502, 0.689198441560998, 0.8099063275184961], 
             UndirectedEdge[219, 311] -> 
             RGBColor[
              0.9090874009816756, 0.9298018167837809, 0.9723363020882385], 
             UndirectedEdge[5, 260] -> 
             RGBColor[
              0.49905397139448515`, 0.6004303682132562, 0.9549099588683176], 
             UndirectedEdge[204, 389] -> 
             RGBColor[
              0.3257750821548689, 0.4564447726811316, 0.9419844590691389], 
             UndirectedEdge[275, 279] -> 
             RGBColor[
              0.5716686092789998, 0.6612897107738802, 0.9603985494171479], 
             UndirectedEdge[78, 289] -> 
             RGBColor[
              0.3346183427316386, 0.4641353876927878, 0.9425468077564256], 
             UndirectedEdge[163, 329] -> 
             RGBColor[
              0.6005746427611941, 0.6831123998086759, 0.9636008453048881], 
             UndirectedEdge[47, 181] -> 
             RGBColor[
              0.8685603843535609, 0.8973357171314578, 0.944521565126524], 
             UndirectedEdge[267, 291] -> 
             RGBColor[
              0.4909997881091878, 0.5928658688768507, 0.9545424109520422], 
             UndirectedEdge[28, 301] -> 
             RGBColor[
              0.471894674528569, 0.5697007447352307, 0.9539427148656899], 
             UndirectedEdge[174, 193] -> 
             RGBColor[
              0.6521829141062623, 0.7240488582188891, 0.9685782853619528], 
             UndirectedEdge[60, 263] -> 
             RGBColor[
              0.7279361063484242, 0.7873884858894864, 0.9735175261972836], 
             UndirectedEdge[122, 385] -> 
             RGBColor[
              0.4303588847415372, 0.5350780144807441, 0.9502406848708801], 
             UndirectedEdge[282, 350] -> 
             RGBColor[
              0.3000826817030657, 0.4225260426757821, 0.940774484492617], 
             UndirectedEdge[142, 306] -> 
             RGBColor[
              0.5475142076132973, 0.6435357248312692, 0.9575214705153965], 
             UndirectedEdge[6, 289] -> 
             RGBColor[
              0.6281477055748317, 0.7032506381713718, 0.967037636088221], 
             UndirectedEdge[3, 117] -> 
             RGBColor[
              0.525378806583791, 0.6255652090870635, 0.9557788906617082], 
             UndirectedEdge[6, 132] -> 
             RGBColor[
              0.9042413020103175, 0.9264814855194916, 0.9907285366831255], 
             UndirectedEdge[22, 394] -> 
             RGBColor[
              0.5652607321304002, 0.6576175234777668, 0.9591411765516018], 
             UndirectedEdge[11, 391] -> 
             RGBColor[
              0.47908206902479245`, 0.5837766348314537, 0.9533195799229842], 
             UndirectedEdge[34, 249] -> 
             RGBColor[
              0.41734294537071615`, 0.529377992613707, 0.9487730065645072], 
             UndirectedEdge[269, 306] -> 
             RGBColor[
              0.4988782937777596, 0.6040508989566302, 0.9536926732190404], 
             UndirectedEdge[69, 394] -> 
             RGBColor[
              0.4997332311324567, 0.6012298283739136, 0.954863884912927], 
             UndirectedEdge[361, 369] -> 
             RGBColor[
              0.5841698044878945, 0.6713043300658317, 0.9615393364089648], 
             UndirectedEdge[85, 184] -> 
             RGBColor[
              0.7802902512708368, 0.8287645092388263, 0.978609231743109], 
             UndirectedEdge[73, 96] -> 
             RGBColor[
              0.6000204316501929, 0.6812929849442979, 0.9641383397862578], 
             UndirectedEdge[71, 382] -> 
             RGBColor[
              0.5789015117457789, 0.6676463351724278, 0.960820549216801], 
             UndirectedEdge[122, 165] -> 
             RGBColor[
              0.7669612324519934, 0.8183696165665493, 0.9773505055273678], 
             UndirectedEdge[321, 331] -> 
             RGBColor[
              0.45134686669557145`, 0.5619730584486788, 0.9509150360085281], 
             UndirectedEdge[296, 374] -> 
             RGBColor[
              0.6880910297090854, 0.7193593772224507, 0.644066724680433], 
             UndirectedEdge[66, 297] -> 
             RGBColor[
              0.6138592427140559, 0.6866551149842872, 0.9596243371515982], 
             UndirectedEdge[75, 145] -> 
             RGBColor[
              0.4569679956589865, 0.5698900925519504, 0.9504309564616078], 
             UndirectedEdge[105, 239] -> 
             RGBColor[
              0.8665147332998265, 0.8950687297568246, 0.9139139748385665], 
             UndirectedEdge[92, 354] -> 
             RGBColor[
              0.67884481003443, 0.7415438201134616, 0.8811017308743184], 
             UndirectedEdge[188, 369] -> 
             RGBColor[
              0.8504889656645761, 0.8440338974870403, 0.6470082469772438], 
             UndirectedEdge[170, 251] -> 
             RGBColor[
              0.5127795457044687, 0.6117142217315916, 0.9560404141501515], 
             UndirectedEdge[53, 68] -> 
             RGBColor[
              0.6319685043390862, 0.697153042082782, 0.8630362782749815], 
             UndirectedEdge[274, 318] -> 
             RGBColor[
              0.46043248277008686`, 0.5676610701431294, 0.9518646906963393], 
             UndirectedEdge[179, 359] -> 
             RGBColor[
              0.23686940859669228`, 0.3662951451960149, 0.9368007344514697], 
             UndirectedEdge[20, 328] -> 
             RGBColor[
              0.5845865606912855, 0.6584855389542171, 0.9649652188446858], 
             UndirectedEdge[307, 352] -> 
             RGBColor[
              0.617422259216138, 0.6990858752149314, 0.9638483126671025], 
             UndirectedEdge[6, 216] -> 
             RGBColor[
              0.6485258085938188, 0.7209011267731799, 0.968336110792942], 
             UndirectedEdge[297, 385] -> 
             RGBColor[
              0.5869643534554548, 0.6583868811390289, 0.9580927129957441], 
             UndirectedEdge[40, 348] -> 
             RGBColor[
              0.3135393897412405, 0.4455945367182942, 0.9412140492938881], 
             UndirectedEdge[229, 329] -> 
             RGBColor[
              0.35255865716124757`, 0.4786275958849788, 0.9437282768544651], 
             UndirectedEdge[6, 213] -> 
             RGBColor[
              0.8893580767762539, 0.9146140057122361, 0.9893089613738886], 
             UndirectedEdge[189, 374] -> 
             RGBColor[
              0.9036532500090875, 0.8928236864048535, 0.6626748336205699], 
             UndirectedEdge[97, 140] -> 
             RGBColor[
              0.518303183829393, 0.6189594097215685, 0.9554599039900944], 
             UndirectedEdge[34, 386] -> 
             RGBColor[
              0.5613870738837079, 0.6547983426350918, 0.9586135933661869], 
             UndirectedEdge[162, 313] -> 
             RGBColor[
              0.5930969526118688, 0.6677730463556519, 0.9653979797277288], 
             UndirectedEdge[258, 392] -> 
             RGBColor[
              0.9155211398391342, 0.935395004030267, 0.9890058742699374], 
             UndirectedEdge[45, 273] -> 
             RGBColor[
              0.7053784062967354, 0.7691134072252658, 0.97171553023194], 
             UndirectedEdge[226, 393] -> 
             RGBColor[
              0.7585450261968432, 0.8116651635819598, 0.9764715420129754], 
             UndirectedEdge[88, 168] -> 
             RGBColor[
              0.3213161551058433, 0.4469347028026667, 0.9419071400799717], 
             UndirectedEdge[188, 327] -> 
             RGBColor[
              0.606109859232843, 0.6357439331652432, 0.6285503783357445], 
             UndirectedEdge[59, 349] -> 
             RGBColor[
              0.6587083230457127, 0.7331020412563856, 0.9667578264262007], 
             UndirectedEdge[260, 398] -> 
             RGBColor[
              0.5642537489821778, 0.6567238613174595, 0.9591139658685222], 
             UndirectedEdge[248, 353] -> 
             RGBColor[
              0.4047785804088477, 0.5169765673725096, 0.9479842522475089], 
             UndirectedEdge[30, 389] -> 
             RGBColor[
              0.4042194240121335, 0.5230869737104253, 0.9473427050147809], 
             UndirectedEdge[216, 311] -> 
             RGBColor[
              0.631944024137793, 0.7076792619484935, 0.9667545253887926], 
             UndirectedEdge[66, 307] -> 
             RGBColor[
              0.3988213537669144, 0.5159081772301378, 0.9471722948609669], 
             UndirectedEdge[94, 225] -> 
             RGBColor[
              0.6027491912717947, 0.6688867206637874, 0.9240797025055187], 
             UndirectedEdge[177, 324] -> 
             RGBColor[
              0.8059530425834256, 0.8469799397489701, 0.8872248836862376], 
             UndirectedEdge[79, 320] -> 
             RGBColor[
              0.591278417505686, 0.672842966956558, 0.9639855554189822], 
             UndirectedEdge[133, 234] -> 
             RGBColor[
              0.5823186913394647, 0.6591800952754178, 0.9643697362585584], 
             UndirectedEdge[35, 195] -> 
             RGBColor[
              0.40503486132647043`, 0.5224349139641333, 0.9475265139147004], 
             UndirectedEdge[34, 86] -> 
             RGBColor[
              0.4237484835339696, 0.5361106193578631, 0.94913779248676], 
             UndirectedEdge[98, 131] -> 
             RGBColor[
              0.38114671055523713`, 0.5045518565174263, 0.9455073092551451], 
             UndirectedEdge[173, 261] -> 
             RGBColor[
              0.3997771057021653, 0.5202831351062446, 0.9468064439875257], 
             UndirectedEdge[103, 331] -> 
             RGBColor[
              0.5790467409252736, 0.662828239565459, 0.9629392794412065], 
             UndirectedEdge[135, 322] -> 
             RGBColor[
              0.9923648176804061, 0.9907463794646615, 0.7497181738173253], 
             UndirectedEdge[50, 181] -> 
             RGBColor[
              0.7699693547981072, 0.8202251790428992, 0.9777070075797083], 
             UndirectedEdge[35, 153] -> 
             RGBColor[
              0.3201586343980951, 0.45056432464003016`, 0.9416637760542123], 
             UndirectedEdge[121, 362] -> 
             RGBColor[
              0.6684700379954421, 0.7388726312999243, 0.9690644699191782], 
             UndirectedEdge[84, 152] -> 
             RGBColor[
              0.39445041788361135`, 0.5160748591414914, 0.9463550097221027], 
             UndirectedEdge[295, 345] -> 
             RGBColor[
              0.6408464446051914, 0.7190505298787062, 0.9650443030528906], 
             UndirectedEdge[22, 266] -> 
             RGBColor[
              0.5537584458603878, 0.6486050787399846, 0.958013039823606], 
             UndirectedEdge[271, 335] -> 
             RGBColor[
              0.6234883284139163, 0.7052149386923502, 0.9635024316071957], 
             UndirectedEdge[175, 261] -> 
             RGBColor[
              0.5374826780422429, 0.6353916772102302, 0.9567317517608596], 
             UndirectedEdge[59, 254] -> 
             RGBColor[
              0.6362062869603607, 0.7148338746571232, 0.9649863837178876], 
             UndirectedEdge[53, 270] -> 
             RGBColor[
              0.6899501989534521, 0.7507491456801727, 0.8666072352704846], 
             UndirectedEdge[214, 300] -> 
             RGBColor[
              0.6546479739074743, 0.7276944130333859, 0.9679266745952548], 
             UndirectedEdge[3, 386] -> 
             RGBColor[
              0.5472740977542978, 0.6433407928309076, 0.9575025681877447], 
             UndirectedEdge[299, 336] -> 
             RGBColor[
              0.49750044257160764`, 0.5902846919982419, 0.9564029526356633], 
             UndirectedEdge[110, 351] -> 
             RGBColor[
              0.5753525801668065, 0.6641433939105688, 0.9607760024242963], 
             UndirectedEdge[172, 328] -> 
             RGBColor[
              0.5959697081444966, 0.6704499486607759, 0.9656134722522887], 
             UndirectedEdge[185, 302] -> 
             RGBColor[
              0.33552132502542054`, 0.46161944607277944`, 0.9427251031038631],
              UndirectedEdge[370, 391] -> 
             RGBColor[
              0.4881658758917188, 0.5917605069737785, 0.9538941471084698], 
             UndirectedEdge[50, 364] -> 
             RGBColor[
              0.5213929241755685, 0.6099569979891216, 0.9586248587281698], 
             UndirectedEdge[73, 195] -> 
             RGBColor[
              0.6692602797493226, 0.7396201288337597, 0.9690047414144534], 
             UndirectedEdge[80, 332] -> 
             RGBColor[
              0.5451896324769823, 0.6370363921042445, 0.9592694094452758], 
             UndirectedEdge[5, 267] -> 
             RGBColor[
              0.3176876970979282, 0.44931949187661807`, 0.9414735462716968], 
             UndirectedEdge[136, 246] -> 
             RGBColor[
              0.7199070835880325, 0.7811161522862354, 0.9727172682440114], 
             UndirectedEdge[59, 246] -> 
             RGBColor[
              0.6958488014534374, 0.7623216394329733, 0.9703193635182641], 
             UndirectedEdge[177, 200] -> 
             RGBColor[
              0.5910712451387748, 0.678897290116631, 0.9609504400640878], 
             UndirectedEdge[17, 157] -> 
             RGBColor[
              0.43828849785786905`, 0.5473897401408904, 0.9503302351703937], 
             UndirectedEdge[151, 386] -> 
             RGBColor[
              0.7004873576899331, 0.7648444074025268, 0.9716095368916611], 
             UndirectedEdge[4, 188] -> 
             RGBColor[
              0.6868812877432042, 0.7114210762111992, 0.6334877352779793], 
             UndirectedEdge[241, 255] -> 
             RGBColor[
              0.7406784688905292, 0.7968731354335263, 0.9754643782333994], 
             UndirectedEdge[62, 345] -> 
             RGBColor[
              0.4957521236868072, 0.5979732277409879, 0.9545291034469267], 
             UndirectedEdge[57, 114] -> 
             RGBColor[
              0.6136207146412593, 0.6920173659708118, 0.9654908426633997], 
             UndirectedEdge[32, 137] -> 
             RGBColor[
              0.7143895585033366, 0.7754940330487781, 0.9734369225430641], 
             UndirectedEdge[152, 175] -> 
             RGBColor[
              0.5208925837716543, 0.6214276046919933, 0.955562623196152], 
             UndirectedEdge[99, 235] -> 
             RGBColor[
              0.2981499836712005, 0.42740904264238855`, 0.9404112505781648], 
             UndirectedEdge[156, 256] -> 
             RGBColor[
              0.388196852676134, 0.5101972344887804, 0.9460705987641067], 
             UndirectedEdge[48, 286] -> 
             RGBColor[
              0.44075820116647446`, 0.5526356466109577, 0.9502296532902288], 
             UndirectedEdge[61, 262] -> 
             RGBColor[
              0.35568439016006026`, 0.47715482391702635`, 0.9441161798330836],
              UndirectedEdge[146, 385] -> 
             RGBColor[
              0.5113117008183279, 0.5984971027157606, 0.9581875144900581], 
             UndirectedEdge[29, 150] -> 
             RGBColor[
              0.728438692983548, 0.7876145850058692, 0.9737201637202201], 
             UndirectedEdge[141, 220] -> 
             RGBColor[
              0.7918235547706232, 0.8355974634034953, 0.889811302356074], 
             UndirectedEdge[152, 242] -> 
             RGBColor[
              0.6895437345496038, 0.7545131765413493, 0.9642952837356986], 
             UndirectedEdge[95, 151] -> 
             RGBColor[
              0.6049905379663687, 0.6849930097416927, 0.964733467722688], 
             UndirectedEdge[252, 293] -> 
             RGBColor[
              0.6251913637216464, 0.7019371933943362, 0.9662751105609613], 
             UndirectedEdge[93, 390] -> 
             RGBColor[
              0.7535759473229038, 0.8076016506195101, 0.9761830366017286], 
             UndirectedEdge[229, 249] -> 
             RGBColor[
              0.28342370052241916`, 0.41522665772254486`, 0.9394519325057368],
              UndirectedEdge[96, 153] -> 
             RGBColor[
              0.35978352360669635`, 0.4860481377275968, 0.9441460658735086], 
             UndirectedEdge[202, 217] -> 
             RGBColor[
              0.7355039843295246, 0.7925573136822179, 0.9741077040322026], 
             UndirectedEdge[163, 304] -> 
             RGBColor[
              0.758331073338802, 0.8111332651126747, 0.9765470124497686], 
             UndirectedEdge[18, 323] -> 
             RGBColor[
              0.6918348721545728, 0.4465608386151371, 0.44842177929637483`], 
             UndirectedEdge[152, 264] -> 
             RGBColor[
              0.46659710053285947`, 0.5773480854150941, 0.9512882838646857], 
             UndirectedEdge[23, 169] -> 
             RGBColor[
              0.36950935723369843`, 0.4915517353172134, 0.9449156892741654], 
             UndirectedEdge[290, 342] -> 
             RGBColor[
              0.6570910067889363, 0.7297822447892603, 0.9680025560993204], 
             UndirectedEdge[285, 330] -> 
             RGBColor[
              0.8396410526827551, 0.8753331711503485, 0.9844707982071434], 
             UndirectedEdge[55, 192] -> 
             RGBColor[
              0.795944357922897, 0.8404470374622747, 0.9472569561826899], 
             UndirectedEdge[161, 170] -> 
             RGBColor[
              0.7699391056738192, 0.8205011953029857, 0.9776244755010965], 
             UndirectedEdge[42, 205] -> 
             RGBColor[
              0.4498985355017946, 0.5632292925055229, 0.9501290341484989], 
             UndirectedEdge[267, 398] -> 
             RGBColor[
              0.382887474685621, 0.5056129849808214, 0.9456775532719011], 
             UndirectedEdge[32, 199] -> 
             RGBColor[
              0.5869651434415758, 0.660341601586931, 0.9651982339468412], 
             UndirectedEdge[154, 385] -> 
             RGBColor[
              0.25944530067061883`, 0.39002383915994265`, 0.9380863981070404],
              UndirectedEdge[91, 190] -> 
             RGBColor[
              0.44294697630840657`, 0.5546281285790573, 0.9503823422867193], 
             UndirectedEdge[94, 380] -> 
             RGBColor[
              0.4026346191265654, 0.5115730489998789, 0.9481488966194702], 
             UndirectedEdge[119, 288] -> 
             RGBColor[
              0.4090431021304637, 0.5287143087864787, 0.9472848426585081], 
             UndirectedEdge[65, 251] -> 
             RGBColor[
              0.6642979344222542, 0.7298519893565857, 0.9135464374513593], 
             UndirectedEdge[198, 216] -> 
             RGBColor[
              0.4444122164062181, 0.5584530783751351, 0.9497861484087378], 
             UndirectedEdge[101, 182] -> 
             RGBColor[
              0.3381610715376496, 0.46615713086151256`, 0.9428108754298146], 
             UndirectedEdge[11, 230] -> 
             RGBColor[
              0.4233334453765132, 0.5386447364400953, 0.9488437770821738], 
             UndirectedEdge[53, 101] -> 
             RGBColor[
              0.6439338088272129, 0.7097293357439247, 0.8637176846644986], 
             UndirectedEdge[202, 264] -> 
             RGBColor[
              0.7174972506817234, 0.7779386361128264, 0.972690147998609], 
             UndirectedEdge[336, 367] -> 
             RGBColor[
              0.8365528910709119, 0.8731072625255063, 0.9841134847457571], 
             UndirectedEdge[13, 132] -> 
             RGBColor[
              0.6071365064542049, 0.6836082285641019, 0.9660340927477081], 
             UndirectedEdge[146, 307] -> 
             RGBColor[
              0.6532509439809145, 0.7270755160612645, 0.96741938112636], 
             UndirectedEdge[75, 133] -> 
             RGBColor[
              0.6745865355648873, 0.7432563471155678, 0.970096699281284], 
             UndirectedEdge[153, 369] -> 
             RGBColor[
              0.5399085945881907, 0.6329674946838019, 0.958719051252807], 
             UndirectedEdge[20, 181] -> 
             RGBColor[
              0.4988708560905451, 0.5906738701767758, 0.9566474181532969], 
             UndirectedEdge[112, 394] -> 
             RGBColor[
              0.8019757987345066, 0.8460820475702355, 0.9764935335164964], 
             UndirectedEdge[279, 306] -> 
             RGBColor[
              0.6278478290020437, 0.7076181130353221, 0.9646223610534685], 
             UndirectedEdge[34, 68] -> 
             RGBColor[
              0.4181240643789099, 0.5301989982171242, 0.9488174901364619], 
             UndirectedEdge[4, 284] -> 
             RGBColor[
              0.5620770781875295, 0.6530168926956347, 0.9597726209462076], 
             UndirectedEdge[193, 235] -> 
             RGBColor[
              0.6197611362551987, 0.6959667438102344, 0.9665123983467354], 
             UndirectedEdge[296, 316] -> 
             RGBColor[
              0.6341617718676937, 0.7095465533015355, 0.9669205180620223], 
             UndirectedEdge[117, 223] -> 
             RGBColor[
              0.42672045649712975`, 0.5423514138539396, 0.9488737953740931], 
             UndirectedEdge[37, 110] -> 
             RGBColor[
              0.5569946576383988, 0.6498020453059979, 0.9589462562712046], 
             UndirectedEdge[83, 349] -> 
             RGBColor[
              0.502986486386288, 0.6053141100753168, 0.954588586265701], 
             UndirectedEdge[192, 348] -> 
             RGBColor[
              0.46187989995164686`, 0.569571958752495, 0.951911658663765], 
             UndirectedEdge[97, 394] -> 
             RGBColor[
              0.5426029684200315, 0.6383614401167643, 0.957595506664671], 
             UndirectedEdge[2, 352] -> 
             RGBColor[
              0.7722480828409356, 0.822033897501359, 0.9779265512696852], 
             UndirectedEdge[69, 350] -> 
             RGBColor[
              0.25841857026349496`, 0.38643868344595556`, 0.9381196841538147],
              UndirectedEdge[164, 304] -> 
             RGBColor[
              0.8370464324747208, 0.8733148903387586, 0.971656876906352], 
             UndirectedEdge[141, 350] -> 
             RGBColor[
              0.5854008318444915, 0.6488075361331129, 0.876036557383759], 
             UndirectedEdge[114, 356] -> 
             RGBColor[
              0.6998271942624169, 0.7642136261502998, 0.9716667149679625], 
             UndirectedEdge[383, 390] -> 
             RGBColor[
              0.6450835348061696, 0.7180920338565373, 0.9680373924028924], 
             UndirectedEdge[297, 307] -> 
             RGBColor[
              0.7289035966180415, 0.7869652944845327, 0.9673245796320459], 
             UndirectedEdge[40, 58] -> 
             RGBColor[
              0.2732164525945304, 0.4032125731552233, 0.9389177176758228], 
             UndirectedEdge[173, 295] -> 
             RGBColor[
              0.4769467344353189, 0.5829329161639756, 0.9528815198430638], 
             UndirectedEdge[161, 239] -> 
             RGBColor[
              0.8011653469029236, 0.8448953722793854, 0.9807368154009983], 
             UndirectedEdge[35, 369] -> 
             RGBColor[
              0.5159200842088352, 0.6110271270308767, 0.9572330976658032], 
             UndirectedEdge[303, 313] -> 
             RGBColor[
              0.5366256271491316, 0.6228291359778192, 0.9599891931896738], 
             UndirectedEdge[237, 349] -> 
             RGBColor[
              0.48253991369345967`, 0.5876043164834135, 0.9532857487339084], 
             UndirectedEdge[21, 263] -> 
             RGBColor[
              0.8005307437927076, 0.36204124723714015`, 0.4352808294183782], 
             UndirectedEdge[126, 274] -> 
             RGBColor[
              0.5993096801540025, 0.6855856227992608, 0.9615989998468684], 
             UndirectedEdge[331, 346] -> 
             RGBColor[
              0.4106021567787026, 0.5288946674099004, 0.9477074631910819], 
             UndirectedEdge[106, 345] -> 
             RGBColor[
              0.6068838665396805, 0.6914781790084183, 0.9623706444985509]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {3}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.4656318623785397, 0.577059948212077, 0.9510753923536028], 316 -> 
             RGBColor[
              0.8629461797913807, 0.8935538759883429, 0.9867897710612925], 
             308 -> RGBColor[
              0.5102493328381664, 0.6132824207253404, 0.9545878430673642], 
             160 -> RGBColor[
              0.7419030611978468, 0.7982995771706438, 0.9749096217280601], 
             245 -> RGBColor[
              0.6100646210489943, 0.6943169683223812, 0.9624456681907688], 
             155 -> RGBColor[
              0.9950881826672378, 0.9919024443231598, 0.7067571794307556], 
             213 -> RGBColor[
              0.8841653665571773, 0.9104734795359083, 0.9888136760376058], 
             352 -> RGBColor[
              0.7209788107613759, 0.7819533936994795, 0.9728240879927904], 27 -> 
             RGBColor[
              0.3920996482903688, 0.51403874067294, 0.9462052207623252], 367 -> 
             RGBColor[
              0.9271915719190686, 0.9447814077762487, 0.99291755391497], 19 -> 
             RGBColor[
              0.9615371052877696, 0.9708350166176042, 0.9499918274049479], 
             164 -> RGBColor[
              0.9496328134904701, 0.961956815286667, 0.9701426882812213], 190 -> 
             RGBColor[
              0.5778982163356087, 0.668202831896036, 0.9599134109823082], 103 -> 
             RGBColor[
              0.833297964795013, 0.8699131941295964, 0.9839618978476651], 138 -> 
             RGBColor[
              0.8069853058528067, 0.8491423213384779, 0.981396411647111], 291 -> 
             RGBColor[
              0.6761452686918898, 0.7469290898872569, 0.9683554995125755], 28 -> 
             RGBColor[
              0.24478417966579302`, 0.3746140714151097, 0.9372514689550006], 
             337 -> RGBColor[
              0.4779433356641748, 0.5870549568509066, 0.9520445966290606], 
             195 -> RGBColor[
              0.5138995986342013, 0.6162458709411617, 0.9548752053621923], 
             114 -> RGBColor[
              0.8553144289903896, 0.8874685250579896, 0.9860618478569496], 93 -> 
             RGBColor[
              0.6176153396845332, 0.7004469818667098, 0.9630400884209521], 34 -> 
             RGBColor[
              0.5640086137153335, 0.6569266267694291, 0.9588199705847493], 
             161 -> RGBColor[
              0.8570569812423271, 0.8888579889233638, 0.9862280540463342], 22 -> 
             RGBColor[
              0.46690550999381475`, 0.5780939527233284, 0.9511756585594022], 
             124 -> RGBColor[
              0.87331103173588, 0.9018185275824757, 0.9877783798925714], 84 -> 
             RGBColor[
              0.3538312273073686, 0.4808925578442299, 0.9437667908167244], 46 -> 
             RGBColor[
              0.9631702765468764, 0.9720530330685734, 0.9472272944625638], 
             241 -> RGBColor[
              0.9251581302403244, 0.943159996577922, 0.9927236024323766], 185 -> 
             RGBColor[
              0.39922193293888636`, 0.5202077056590508, 0.9466590464421397], 
             390 -> RGBColor[
              0.8895365549612745, 0.9147563193723102, 0.9893259847825051], 
             121 -> RGBColor[
              0.8392619585986195, 0.8746687209002931, 0.9845307489007732], 
             322 -> RGBColor[
              0.9948597253511907, 0.991413797224713, 0.6818910104541577], 126 -> 
             RGBColor[
              0.5760303058406665, 0.666686378007833, 0.9597663622257647], 236 -> 
             RGBColor[
              0.5336656511882293, 0.6322928428550416, 0.9564312614246816], 78 -> 
             RGBColor[
              0.3074920613089446, 0.44052403093139575`, 0.9408225900465804], 
             376 -> RGBColor[
              0.6881300986497063, 0.7562917301383845, 0.9695500353581669], 
             254 -> RGBColor[
              0.5839612431913286, 0.6731250702337566, 0.9603907146659897], 
             290 -> RGBColor[
              0.4947285059263224, 0.6006819142330211, 0.9533659867182015], 
             251 -> RGBColor[
              0.34273786130362627`, 0.47128404178057565`, 0.9430599313444443],
              165 -> RGBColor[
              0.9031919167666392, 0.9256447342109863, 0.9906284453817863], 
             100 -> RGBColor[
              0.7455243894103966, 0.8011285862934014, 0.9752705618810509], 
             235 -> RGBColor[
              0.3443936885318878, 0.47271823610139946`, 0.9431654391912386], 
             70 -> RGBColor[
              0.6394287069072855, 0.7181560560591349, 0.9647573165937242], 
             234 -> RGBColor[
              0.26376844048858783`, 0.394567733211524, 0.9383325945241616], 
             257 -> RGBColor[
              0.9360059889154899, 0.9517939518305242, 0.9932093478416079], 
             135 -> RGBColor[
              0.9898699100096214, 0.99007896170461, 0.8175453371804929], 265 -> 
             RGBColor[
              0.9414025577668066, 0.9558187040437657, 0.9840743644269052], 
             111 -> RGBColor[
              0.353649460147158, 0.48073512026593856`, 0.9437552087740062], 
             381 -> RGBColor[
              0.5635485176315126, 0.656553100041491, 0.9587837501356434], 182 -> 
             RGBColor[
              0.38015201905655976`, 0.5036903047359202, 0.9454439283924206], 
             188 -> RGBColor[
              0.9653078869302215, 0.894637497899432, 0.31972812109008963`], 
             154 -> RGBColor[
              0.28890337999551097`, 0.4209861482805096, 0.9397639921452701], 
             336 -> RGBColor[
              0.7459142102227551, 0.8014331172747639, 0.9753094155765442], 
             315 -> RGBColor[
              0.2834883533526057, 0.41529461194629713`, 0.9394556143887707], 
             368 -> RGBColor[
              0.5933758588890591, 0.6807682793807781, 0.9611318677005886], 
             269 -> RGBColor[
              0.4585817581114375, 0.5713363559644655, 0.9505203823203137], 
             208 -> RGBColor[
              0.5308418324786762, 0.6300003396150433, 0.9562089600718767], 86 -> 
             RGBColor[
              0.2834883533526057, 0.41529461194629713`, 0.9394556143887707], 
             119 -> RGBColor[
              0.3932762470688765, 0.5150578513973092, 0.9462801925960662], 
             377 -> RGBColor[
              0.9574180001213686, 0.868023057059651, 0.2890774007177994], 140 -> 
             RGBColor[
              0.6150163850857084, 0.6983370334418134, 0.9628354891946482], 85 -> 
             RGBColor[
              0.878945942350168, 0.906311652350735, 0.9883158426973063], 351 -> 
             RGBColor[
              0.7244600514589714, 0.7846729653908503, 0.9731710655314828], 
             242 -> RGBColor[
              0.9440178606393534, 0.9577691926439457, 0.9796473388439162], 
             117 -> RGBColor[
              0.5149749517110686, 0.6171188910130665, 0.9549598610955513], 47 -> 
             RGBColor[
              0.9834156323235343, 0.9871519862580774, 0.9129571879671365], 81 -> 
             RGBColor[
              0.20887240989662495`, 0.336868524450001, 0.9352063467933488], 
             275 -> RGBColor[
              0.4268163899979938, 0.5441086374259109, 0.9484173408451257], 23 -> 
             RGBColor[
              0.2790980726226407, 0.4106801485392283, 0.9392055943960375], 
             328 -> RGBColor[
              0.9251365455850682, 0.9431427855597206, 0.9927215436686894], 
             110 -> RGBColor[
              0.4262451088746415, 0.5436138224302872, 0.9483809393171098], 6 -> 
             RGBColor[
              0.8945507869953306, 0.9187545318885638, 0.9898042467101712], 
             218 -> RGBColor[
              0.5121375474841148, 0.6148153584380217, 0.9547364902410513], 
             108 -> RGBColor[
              0.45226940849584074`, 0.5661547627428387, 0.950039184676588], 
             297 -> RGBColor[
              0.943941485565183, 0.9577122322386821, 0.9797766219226772], 157 -> 
             RGBColor[
              0.5974789230930975, 0.6840993317425524, 0.9614548759447499], 
             354 -> RGBColor[
              0.3678197100592384, 0.4930086785223134, 0.9446581245681439], 
             385 -> RGBColor[
              0.2299872213457267, 0.3590615300393757, 0.9364088040688109], 
             270 -> RGBColor[
              0.3882029042712181, 0.5106635768596007, 0.9459569236791804], 
             392 -> RGBColor[
              0.8922131280830662, 0.916890546125985, 0.9895812787162667], 33 -> 
             RGBColor[
              0.6394287069072855, 0.7181560560591349, 0.9647573165937242], 
             252 -> RGBColor[
              0.3920996482903688, 0.51403874067294, 0.9462052207623252], 394 -> 
             RGBColor[
              0.6636159542669856, 0.7371410942322052, 0.9671066945438013], 
             260 -> RGBColor[
              0.6685868561195996, 0.7410244005397206, 0.9676021475847509], 
             159 -> RGBColor[
              0.9367886703751002, 0.9523776743815783, 0.9918844722865058], 
             183 -> RGBColor[
              0.7299664371782415, 0.7889745957648255, 0.9737198905998794], 99 -> 
             RGBColor[
              0.25190627881051314`, 0.3820998491833776, 0.9376570619650908], 
             329 -> RGBColor[
              0.40894719030375565`, 0.5286312347828527, 0.9472787312417218], 
             309 -> RGBColor[
              0.30705611746466266`, 0.4400658263106193, 0.9407977636895697], 
             17 -> 
             RGBColor[
              0.2790980726226407, 0.4106801485392283, 0.9392055943960375], 
             349 -> RGBColor[
              0.6289653153620326, 0.7096614034322812, 0.9639336000826157], 
             347 -> RGBColor[
              0.4599206418447562, 0.5724233220951985, 0.9506257841522933], 
             340 -> RGBColor[
              0.6581303056303421, 0.7328556638247856, 0.9665599363540018], 
             277 -> RGBColor[
              0.5747351620148649, 0.6656349219044829, 0.9596644037595294], 
             104 -> RGBColor[
              0.6267914472915286, 0.7078965594010055, 0.9637624652249646], 79 -> 
             RGBColor[
              0.33240041263057035`, 0.4623302633152523, 0.9424012382560442], 
             327 -> RGBColor[
              0.24691183153546453`, 0.37685036843105446`, 0.9373726355813994],
              191 -> RGBColor[
              0.9215439725780606, 0.9402781653617293, 0.9923788808481533], 50 -> 
             RGBColor[
              0.7862335732126272, 0.8329309100809603, 0.9793280728735051], 
             225 -> RGBColor[
              0.9838479603881707, 0.9874744158208109, 0.9122253693229253], 61 -> 
             RGBColor[
              0.2525685002319563, 0.3827958858845775, 0.9376947744953732], 
             196 -> RGBColor[
              0.6955690068791442, 0.762103061785018, 0.9702914762099275], 1 -> 
             RGBColor[
              0.9377373523370375, 0.9530851998354669, 0.9902786011808289], 
             263 -> RGBColor[
              0.7669542313781228, 0.8178697417114205, 0.9774064882551347], 
             201 -> RGBColor[
              0.8474383814976555, 0.8811883785768972, 0.9853106234160621], 
             371 -> RGBColor[
              0.8499459656532837, 0.8831878581160366, 0.9855497990313727], 
             293 -> RGBColor[
              0.858283079152924, 0.8898356461157325, 0.9863450003595975], 362 -> 
             RGBColor[
              0.4976781173922648, 0.6030765416995555, 0.9535981909375832], 
             184 -> RGBColor[
              0.6816345601915057, 0.7512173661269175, 0.9689026207889115], 
             106 -> RGBColor[
              0.5546638983363169, 0.6493401658501131, 0.9580843203592928], 
             206 -> RGBColor[
              0.49429539428288566`, 0.600330294689422, 0.95333189058309], 358 -> 
             RGBColor[
              0.3251889691417232, 0.4560840734229015, 0.9419417314537639], 
             247 -> RGBColor[
              0.41757518865849064`, 0.5361043733019177, 0.9478284996674461], 
             220 -> RGBColor[
              0.5938320783813255, 0.6811386589170538, 0.9611677829702069], 
             107 -> RGBColor[
              0.6688806397128856, 0.7412539065156337, 0.9676314291877659], 
             375 -> RGBColor[
              0.8116150069455315, 0.852759079019146, 0.9818578569850173], 131 -> 
             RGBColor[
              0.37970944121150707`, 0.503306966051145, 0.94541572772349], 127 -> 
             RGBColor[
              0.7115111058398221, 0.7745571506575392, 0.9718804356469427], 
             210 -> RGBColor[
              0.7520531782080259, 0.8062289257227422, 0.9759212905333984], 
             357 -> RGBColor[
              0.7681984761509693, 0.8188417551845787, 0.9775305029459634], 
             181 -> RGBColor[
              0.7537051363835874, 0.807519448004838, 0.9760859422859115], 194 -> 
             RGBColor[
              0.990281476078195, 0.9902491548507306, 0.8107246223253863], 118 -> 
             RGBColor[
              0.8471151768577252, 0.36315347209643006`, 0.19275085260892622`],
              348 -> RGBColor[
              0.3044276976989958, 0.437303190485465, 0.9406480790723136], 276 -> 
             RGBColor[
              0.5761701328957352, 0.6667998959102749, 0.9597773699237432], 
             305 -> RGBColor[
              0.3971610410281788, 0.5184226646694351, 0.9465277282319646], 
             343 -> RGBColor[
              0.5161699428852814, 0.6180890386820315, 0.9550539351781823], 
             280 -> RGBColor[
              0.9937914597052554, 0.9891288850262822, 0.5656168874654696], 
             189 -> RGBColor[
              0.8365018045440107, 0.872467848979534, 0.9842674829430259], 168 -> 
             RGBColor[
              0.24606881763188765`, 0.3759643073682266, 0.937324627186718], 
             363 -> RGBColor[
              0.5283740472261834, 0.6279968803746109, 0.9560146869770053], 41 -> 
             RGBColor[
              0.8294596367924253, 0.8668526155689711, 0.9835957946962623], 14 -> 
             RGBColor[
              0.2676594895651098, 0.39865747249770916`, 0.9385541840127782], 
             77 -> RGBColor[
              0.4112360226117313, 0.5306137062879644, 0.947424573612451], 51 -> 
             RGBColor[
              0.7886520837253299, 0.8348202688748444, 0.9795691273991456], 
             179 -> RGBColor[
              0.29481181719338456`, 0.4271962903920299, 0.9401004689029394], 
             223 -> RGBColor[
              0.3384659612831909, 0.46758393669481263`, 0.942787729652635], 
             323 -> RGBColor[
              0.8550850183392283, 0.42441316613006863`, 0.20038278181226205`],
              292 -> 
             RGBColor[
              0.43606651318038925`, 0.5521206292017923, 0.9490067505147453], 
             396 -> RGBColor[
              0.6792374153202093, 0.7493446983344849, 0.9686636957907332], 
             321 -> RGBColor[
              0.5778982163356087, 0.668202831896036, 0.9599134109823082], 143 -> 
             RGBColor[
              0.774004256295562, 0.8233772747590979, 0.9781091688526763], 112 -> 
             RGBColor[
              0.9403356432020276, 0.9550230009082658, 0.9858803724891915], 
             197 -> RGBColor[
              0.2765898767002093, 0.4080438755959463, 0.9390627563487983], 54 -> 
             RGBColor[
              0.9626826081471922, 0.9716893307745728, 0.9480527898589399], 71 -> 
             RGBColor[
              0.4434447921996799, 0.5585113236452156, 0.9494768879294985], 
             177 -> RGBColor[
              0.6216467954642115, 0.7037198992836657, 0.9633574593876375], 
             158 -> RGBColor[
              0.4501898953573199, 0.5643535929816212, 0.9499066799382427], 
             226 -> RGBColor[
              0.6519775517277189, 0.7280490857133948, 0.9659466873457426], 
             350 -> RGBColor[
              0.18098663252906216`, 0.3075588043762891, 0.9336182930255769], 
             203 -> RGBColor[
              0.19856118018119892`, 0.32603076824936433`, 0.9346191375151527],
              115 -> RGBColor[
              0.5973054141812104, 0.6839584693913952, 0.9614412166876221], 
             173 -> RGBColor[
              0.3313044144032992, 0.46138096473726264`, 0.9423314022181556], 
             212 -> RGBColor[
              0.5622163088073522, 0.6554715529027141, 0.9586788737769638], 
             129 -> RGBColor[
              0.9439267184231094, 0.9577012189283025, 0.9798016188423203], 
             279 -> RGBColor[
              0.7165208285600057, 0.7784707841218494, 0.9723797579891701], 26 -> 
             RGBColor[
              0.7754342189262599, 0.8244943724343176, 0.9782516941639438], 40 -> 
             RGBColor[
              0.3226510817834853, 0.45388588295112337`, 0.9417800195154626], 
             146 -> RGBColor[
              0.792636180290929, 0.8379326753921457, 0.9799662249113054], 386 -> 
             RGBColor[
              0.5587655340520823, 0.6526700585007547, 0.9584072161476245], 
             192 -> RGBColor[
              0.6193321022042979, 0.7018407270195249, 0.9631752382552163], 
             300 -> RGBColor[
              0.833297964795013, 0.8699131941295964, 0.9839618978476651], 221 -> 
             RGBColor[
              0.7693378889939545, 0.8197318731573771, 0.9776440689697338], 62 -> 
             RGBColor[
              0.33240041263057035`, 0.4623302633152523, 0.9424012382560442], 
             286 -> RGBColor[
              0.5753226657806161, 0.6661118839282627, 0.9597106542080667], 
             152 -> RGBColor[
              0.4350696084598541, 0.551257160438753, 0.9489432286274809], 64 -> 
             RGBColor[
              0.45053643829857015`, 0.5646537510595776, 0.9499287613480233], 
             307 -> RGBColor[
              0.5138657076709001, 0.6162183567303833, 0.9548725373414145], 37 -> 
             RGBColor[
              0.6877442064021563, 0.7559902681817087, 0.9695115732252992], 
             148 -> RGBColor[
              0.4667776067233076, 0.5779901150863541, 0.9511655895454227], 
             261 -> RGBColor[
              0.46824979700103136`, 0.5791853054752265, 0.9512814857568959], 
             387 -> RGBColor[
              0.26813178294749573`, 0.39915388278772673`, 0.9385810804222097],
              15 -> RGBColor[
              0.612519599079081, 0.6963100300827054, 0.962638933054178], 136 -> 
             RGBColor[
              0.736567894998583, 0.7941317047870141, 0.9743778622212803], 198 -> 
             RGBColor[
              0.4863236026201292, 0.5938584350924745, 0.9527043219417627], 63 -> 
             RGBColor[
              0.3078494297406834, 0.44089964781162055`, 0.9408429416500887], 
             310 -> RGBColor[
              0.4006305146510648, 0.5214277483407643, 0.9467488000232798], 
             171 -> RGBColor[
              0.875307265672997, 0.903410270337606, 0.9879687824675527], 395 -> 
             RGBColor[
              0.8951285839785095, 0.9192152515190694, 0.9898593575022323], 
             311 -> RGBColor[
              0.8613872180832791, 0.8923108022391911, 0.9866410759018723], 
             353 -> RGBColor[
              0.2522747781497172, 0.38248716535308863`, 0.9376780474573125], 
             59 -> RGBColor[
              0.6884513307293929, 0.7565426790804899, 0.9695820527697856], 
             397 -> RGBColor[
              0.659366600239572, 0.733821466569703, 0.9666831586468199], 229 -> 
             RGBColor[
              0.29617012401873954`, 0.42862395698710487`, 0.9401778224672085],
              102 -> RGBColor[
              0.2397412299958117, 0.36931361157048287`, 0.9369642804316706], 
             299 -> RGBColor[
              0.24908667492046016`, 0.37913626672171985`, 0.9374964896947825],
              128 -> 
             RGBColor[
              0.8359682241776446, 0.8720423864790469, 0.9842165895713492], 12 -> 
             RGBColor[
              0.3941196011842843, 0.5157883223438651, 0.9463339303745513], 
             222 -> RGBColor[
              0.6249509204580277, 0.7064023368027805, 0.9636175722105594], 92 -> 
             RGBColor[
              0.9898699100096214, 0.99007896170461, 0.8175453371804929], 271 -> 
             RGBColor[
              0.6382202148750729, 0.717174947785439, 0.9646621796740962], 361 -> 
             RGBColor[
              0.4326695645768582, 0.5491783630570148, 0.9487902999535319], 
             344 -> RGBColor[
              0.4177609359619727, 0.5362652582802631, 0.9478403353213741], 
             132 -> RGBColor[
              0.9139318170253043, 0.9342084391504194, 0.9916528266560799], 80 -> 
             RGBColor[
              0.34281236520116365`, 0.47134857331194774`, 0.9430646786669142],
              324 -> RGBColor[
              0.9902592897026397, 0.9902399802142746, 0.8110923079848378], 
             244 -> RGBColor[
              0.836776521644556, 0.8726869009385118, 0.9842936857053188], 150 -> 
             RGBColor[
              0.6254508710346836, 0.7068082192034265, 0.963656930151333], 125 -> 
             RGBColor[
              0.38459487180374075`, 0.5075384804812565, 0.9457270230408106], 
             258 -> RGBColor[
              0.9388291515952022, 0.953899461934549, 0.988430469823608], 133 -> 
             RGBColor[
              0.9008689421903414, 0.9237924573393115, 0.9904068779929551], 
             255 -> RGBColor[
              0.556198807540734, 0.6505862742891306, 0.9582051540344222], 326 -> 
             RGBColor[
              0.49009667116956485`, 0.5969215821157074, 0.9530013517191798], 
             176 -> RGBColor[
              0.7124244596680929, 0.7752706696099305, 0.971971470220768], 230 -> 
             RGBColor[
              0.5391748294440818, 0.6367654419487948, 0.9568649641177671], 
             274 -> RGBColor[
              0.6225890544673385, 0.7044848675906886, 0.9634316374679721], 87 -> 
             RGBColor[0.7913049330282, 0.836892694912648, 0.9798335386253695],
              130 -> RGBColor[
              0.6682450137020388, 0.7407573506450236, 0.9675680759272675], 35 -> 
             RGBColor[
              0.29617012401873954`, 0.42862395698710487`, 0.9401778224672085],
              379 -> RGBColor[
              0.8464106235314965, 0.880368872272429, 0.9852125949437595], 31 -> 
             RGBColor[
              0.26361878402490124`, 0.39441043477942156`, 0.9383240718099515],
              18 -> RGBColor[
              0.36533457978526174`, 0.49085618358527416`, 0.9444997742646005],
              24 -> RGBColor[
              0.8023380099870631, 0.8455118184874023, 0.9809332126266627], 
             151 -> RGBColor[
              0.8422091813277838, 0.8770187563042989, 0.9848118576356976], 
             137 -> RGBColor[
              0.4985656881563047, 0.6037971116304103, 0.9536680637594074], 
             330 -> RGBColor[
              0.904106666406614, 0.9263741307436846, 0.9907156950190537], 296 -> 
             RGBColor[
              0.4053773639440067, 0.5255392306147281, 0.9470512650627521], 
             266 -> RGBColor[
              0.6406113817269609, 0.7191162047566408, 0.9648504210878096], 
             302 -> RGBColor[
              0.27182071711195466`, 0.40303118648650804`, 0.9387911597655866],
              283 -> RGBColor[
              0.2599865196917175, 0.39059269466638524`, 0.9381172197296302], 
             388 -> RGBColor[
              0.3037238298505496, 0.43656338074894885`, 0.9406079948396238], 
             284 -> RGBColor[
              0.715699467818872, 0.777829130868303, 0.9722978924265464], 318 -> 
             RGBColor[
              0.2982759110728352, 0.4308372726955701, 0.9402977439247064], 
             238 -> RGBColor[
              0.8158801281875075, 0.8560910241494999, 0.9822829644105933], 72 -> 
             RGBColor[
              0.7182161210376565, 0.7797951594900903, 0.9725487288999334], 
             288 -> RGBColor[
              0.42480995719205095`, 0.5423707661756482, 0.94828949272095], 
             382 -> RGBColor[
              0.7143582312918778, 0.7767813466996399, 0.9721642105041036], 
             389 -> RGBColor[
              0.30715647577785, 0.4401713092608638, 0.940803478947039], 172 -> 
             RGBColor[
              0.266802870703925, 0.39775711176183115`, 0.9385054008358878], 
             243 -> RGBColor[
              0.3869322993154277, 0.5095630427093572, 0.9458759618549493], 88 -> 
             RGBColor[
              0.39656349257979895`, 0.5179050982371067, 0.9464896529732252], 
             273 -> RGBColor[
              0.599742401300787, 0.685936925320086, 0.9616330652406531], 202 -> 
             RGBColor[
              0.9368699087575821, 0.9524382618342176, 0.9917469568953273], 
             393 -> RGBColor[
              0.8651125006659675, 0.8952812414505249, 0.9869963966802081], 98 -> 
             RGBColor[
              0.3825839798989672, 0.5057967469837076, 0.9455988907868003], 30 -> 
             RGBColor[
              0.501282372246417, 0.606002638159987, 0.9538819310825227], 116 -> 
             RGBColor[
              0.2908520575418706, 0.42303433193502615`, 0.9398749664487251], 
             373 -> RGBColor[
              0.3103065900446014, 0.4431937046590974, 0.9409934394176664], 
             240 -> RGBColor[
              0.621030557677273, 0.7032196096870332, 0.9633089468916963], 317 -> 
             RGBColor[
              0.994929911462409, 0.9921714023414434, 0.733688018243811], 391 -> 
             RGBColor[
              0.6506720767406403, 0.7270292387315116, 0.965816569799388], 73 -> 
             RGBColor[
              0.8246209608644437, 0.8629943867263578, 0.9831342774667144], 
             303 -> RGBColor[
              0.8094933927633138, 0.8511016578951327, 0.9816463943109456], 29 -> 
             RGBColor[
              0.8314265149324124, 0.8684209508083119, 0.9837833972891071], 
             360 -> RGBColor[
              0.40146717585702507`, 0.5221524222255522, 0.9468021113354932], 
             320 -> RGBColor[
              0.8501564223808016, 0.8833556705978637, 0.9855698725819203], 75 -> 
             RGBColor[
              0.4483041289394333, 0.5627202368918239, 0.9497865205696128], 
             200 -> RGBColor[
              0.5604956948133382, 0.6540746809495963, 0.9585434207405382], 
             301 -> RGBColor[
              0.6990051693913449, 0.7647874180553516, 0.9706339607763793], 
             156 -> RGBColor[
              0.46824979700103136`, 0.5791853054752265, 0.9512814857568959], 
             25 -> RGBColor[
              0.8256045758512776, 0.8637786946173415, 0.9832280955422421], 38 -> 
             RGBColor[
              0.6368532976469088, 0.7160652228006961, 0.9645545709427124], 
             365 -> RGBColor[
              0.629541724221574, 0.7101293581113801, 0.9639789770994941], 380 -> 
             RGBColor[
              0.5836188160977119, 0.6728470724929938, 0.9603637575508284], 
             370 -> RGBColor[
              0.3256596750427972, 0.45649177521604534`, 0.9419717244175515], 
             3 -> RGBColor[
              0.5357826614565134, 0.6340115271610605, 0.956597920227865], 57 -> 
             RGBColor[
              0.3719270002921292, 0.49656620688363384`, 0.9449198374698496], 
             227 -> RGBColor[
              0.4717885348852414, 0.5820582123079532, 0.9515600681659648], 39 -> 
             RGBColor[
              0.5587655340520823, 0.6526700585007547, 0.9584072161476245], 
             109 -> RGBColor[
              0.5778982163356087, 0.668202831896036, 0.9599134109823082], 256 -> 
             RGBColor[
              0.3081439083512366, 0.44120916350233425`, 0.9408597117713177], 
             339 -> RGBColor[
              0.2978336347177741, 0.4303724122044603, 0.940272556940575], 287 -> 
             RGBColor[
              0.8538963680774747, 0.8863378017782694, 0.985926591941158], 239 -> 
             RGBColor[
              0.74527371256352, 0.800932755635407, 0.9752455767556625], 285 -> 
             RGBColor[
              0.7751754389588962, 0.8242922115570125, 0.9782259013952332], 
             345 -> RGBColor[
              0.6591038347430441, 0.7336161921667237, 0.9666569686378091], 
             366 -> RGBColor[
              0.5005686980303874, 0.6054232452807571, 0.953825748033962], 216 -> 
             RGBColor[
              0.402500830192307, 0.5230477216577959, 0.9468679748757127], 21 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 355 -> 
             RGBColor[
              0.5744067073597608, 0.6653682676187559, 0.9596385466059106], 
             175 -> RGBColor[
              0.6067155590834545, 0.6915980489452338, 0.9621820177648233], 7 -> 
             RGBColor[
              0.37754642183102627`, 0.5014334673802876, 0.9452779020412487], 
             13 -> RGBColor[
              0.3003411958831056, 0.4330080179777844, 0.9404153588393364], 
             294 -> RGBColor[
              0.3025927171649591, 0.4353745095997068, 0.9405435796455106], 
             193 -> RGBColor[
              0.8951285839785095, 0.9192152515190694, 0.9898593575022323], 60 -> 
             RGBColor[
              0.6889179813187256, 0.7569072300675525, 0.9696285641394325], 65 -> 
             RGBColor[
              0.9858580075408822, 0.9884199369325957, 0.8840329435582743], 69 -> 
             RGBColor[
              0.33585050799792776`, 0.46531856251562204`, 0.9426210752820526],
              217 -> RGBColor[
              0.5341380599014671, 0.6326763655302181, 0.9564684511690777], 
             214 -> RGBColor[
              0.4759979830199357, 0.5854756319371753, 0.9518914513428446], 
             170 -> RGBColor[
              0.6828212301053111, 0.7521444016826077, 0.9690208969558588], 
             359 -> RGBColor[0.178927, 0.305394, 0.933501], 74 -> 
             RGBColor[
              0.2525685002319563, 0.3827958858845775, 0.9376947744953732], 
             246 -> RGBColor[
              0.7032462721774819, 0.7681005997854568, 0.9710566742667425], 
             264 -> RGBColor[
              0.49812459260586484`, 0.6034390103914351, 0.9536333391018905], 
             278 -> RGBColor[
              0.654837115907947, 0.7302829989844816, 0.9662317019790811], 45 -> 
             RGBColor[
              0.8110144112926838, 0.8522898891304456, 0.9817979952232269], 
             306 -> RGBColor[
              0.5391748294440818, 0.6367654419487948, 0.9568649641177671], 
             237 -> RGBColor[
              0.33611451202488674`, 0.4655472295345457, 0.9426378973852009], 
             228 -> RGBColor[
              0.33990212431338457`, 0.4688278689279136, 0.9428792406909698], 
             180 -> RGBColor[
              0.6184178335410607, 0.7010984825313751, 0.9631032636769699], 
             383 -> RGBColor[
              0.4006305146510648, 0.5214277483407643, 0.9467488000232798], 53 -> 
             RGBColor[
              0.9916974936356862, 0.9908347145007446, 0.7872575468617887], 
             304 -> RGBColor[
              0.7244600514589714, 0.7846729653908503, 0.9731710655314828], 48 -> 
             RGBColor[
              0.30619373655233284`, 0.4391594092936527, 0.9407486523723908], 
             5 -> RGBColor[
              0.3295210866693707, 0.45983633588679185`, 0.9422177701518845], 
             101 -> RGBColor[
              0.29617012401873954`, 0.42862395698710487`, 0.9401778224672085],
              333 -> RGBColor[
              0.9914365253021733, 0.9907267973882568, 0.7915824675124948], 
             267 -> RGBColor[
              0.3058543075264858, 0.4388026478664443, 0.940729322391509], 120 -> 
             RGBColor[
              0.7253475334668618, 0.7853662730805273, 0.9732595214440384], 
             147 -> RGBColor[
              0.21138094157016918`, 0.3395051502889904, 0.9353492039611171], 
             89 -> RGBColor[
              0.40600654640446904`, 0.5260841968383505, 0.9470913560127685], 
             43 -> RGBColor[
              0.44066400934666566`, 0.5561027493041448, 0.9492996989050542], 
             199 -> RGBColor[
              0.2437168580327831, 0.37349224870671616`, 0.9371906865669615], 
             268 -> RGBColor[
              0.9796628347375043, 0.9843531559630582, 0.919309695393917], 169 -> 
             RGBColor[
              0.4599206418447562, 0.5724233220951985, 0.9506257841522933], 20 -> 
             RGBColor[
              0.24403657579750276`, 0.3738282923487136, 0.9372088940206822], 
             4 -> RGBColor[
              0.40845468855618705`, 0.5282046545229664, 0.9472473494658689], 
             167 -> RGBColor[
              0.9518806960353249, 0.9636332824080499, 0.966337609474446], 142 -> 
             RGBColor[
              0.5558535857825126, 0.6503060077137435, 0.958177976913026], 16 -> 
             RGBColor[
              0.32045993714199306`, 0.45198802359279466`, 0.9416404017164599],
              281 -> RGBColor[
              0.5453437733331876, 0.6417736685057261, 0.9573506059783036], 
             289 -> RGBColor[
              0.3617446241543326, 0.4877467444541798, 0.9442710254662708], 
             398 -> RGBColor[
              0.4599206418447562, 0.5724233220951985, 0.9506257841522933], 
             178 -> RGBColor[
              0.7067736689973433, 0.7708562289903411, 0.9714082522163489], 58 -> 
             RGBColor[
              0.22378182340557562`, 0.35253926335932323`, 0.9360554158361829],
              186 -> RGBColor[
              0.23863334567338157`, 0.36814915490368566`, 0.9369011880584761],
              122 -> RGBColor[
              0.6307305481373477, 0.7110944989221124, 0.9640725656729493], 
             249 -> RGBColor[
              0.27067727702609884`, 0.40182935845798484`, 0.9387260425442651],
              113 -> RGBColor[
              0.7722410700463371, 0.8219998602604917, 0.9779334309252659], 52 -> 
             RGBColor[
              0.7182161210376565, 0.7797951594900903, 0.9725487288999334], 
             187 -> RGBColor[
              0.3617446241543326, 0.4877467444541798, 0.9442710254662708], 
             259 -> RGBColor[
              0.43433382085955274`, 0.5506198582011319, 0.9488963448922212], 
             42 -> RGBColor[
              0.4143662192909088, 0.5333249253232084, 0.9476240269769239], 
             134 -> RGBColor[
              0.5738595477808759, 0.6649240588233589, 0.9595954721995492], 
             313 -> RGBColor[
              0.26375786153494946`, 0.39455661406050563`, 0.938331992068402], 
             248 -> RGBColor[
              0.5572823826679781, 0.6514659693919306, 0.9582904570377053], 
             174 -> RGBColor[
              0.40923724423401503`, 0.5288824649187089, 0.9472972132216733], 
             215 -> RGBColor[
              0.18171868777103106`, 0.3083282408505815, 0.9336599824886282], 
             399 -> RGBColor[
              0.5439579923257903, 0.640648629055198, 0.9572415122211182], 83 -> 
             RGBColor[
              0.37700765741054326`, 0.5009668167183523, 0.9452435724487862], 
             95 -> 
             RGBColor[
              0.36777189460495363`, 0.49296726317908657`, 0.9446550778096785],
              166 -> RGBColor[
              0.29497518978312737`, 0.4273680053422701, 0.9401097727302372], 
             384 -> RGBColor[
              0.21243266507390485`, 0.3406105783745381, 0.9354090980587694], 
             233 -> RGBColor[
              0.7267282528623358, 0.7864449015661277, 0.9733971386498229], 
             295 -> RGBColor[
              0.6225890544673385, 0.7044848675906886, 0.9634316374679721], 
             141 -> RGBColor[
              0.989815031159921, 0.9900562678899367, 0.8184548217419411], 319 -> 
             RGBColor[
              0.4330212577841429, 0.5494829820365503, 0.94881270953371], 205 -> 
             RGBColor[
              0.48543085171268047`, 0.5931336596878375, 0.952634041320074], 
             224 -> RGBColor[
              0.6513924338400113, 0.7275919871724569, 0.9658883682629334], 
             231 -> RGBColor[
              0.29830465267960793`, 0.4308674819466114, 0.9402993807166928], 
             332 -> RGBColor[
              0.7475668997528008, 0.8027242108965412, 0.9754741402236373], 68 -> 
             RGBColor[
              0.2722395150424864, 0.40347136966481933`, 0.9388150096881743], 
             10 -> RGBColor[
              0.28429129870797953`, 0.4161385584244709, 0.939501340938908], 
             250 -> RGBColor[
              0.701095256233328, 0.766420209781557, 0.9708422810998161], 282 -> 
             RGBColor[
              0.4191787308770692, 0.5374932809752752, 0.9479306759596572], 
             374 -> RGBColor[
              0.9708046954741643, 0.9131795238301732, 0.3410821842981139], 
             232 -> RGBColor[
              0.5832399484297262, 0.6725394906523291, 0.9603339317001666], 
             253 -> RGBColor[
              0.43885173510276, 0.5545330484416257, 0.9491842223927637], 55 -> 
             RGBColor[
              0.972556613641496, 0.9790533479050244, 0.9313386741101635], 325 -> 
             RGBColor[
              0.6567841061841853, 0.7318040025859531, 0.966425759774158], 91 -> 
             RGBColor[
              0.30799573628120447`, 0.44105342526207864`, 0.9408512735911303],
              105 -> RGBColor[
              0.987755754036133, 0.9892047038782422, 0.8525823729214707], 36 -> 
             RGBColor[
              0.33999614934146716`, 0.4689093086814034, 0.9428852318826162], 
             123 -> RGBColor[
              0.9935000788091838, 0.9885056507527127, 0.5339018751225226], 94 -> 
             RGBColor[
              0.22165042215541883`, 0.35029902550676395`, 0.9359340356881121],
              312 -> RGBColor[
              0.7474672514108297, 0.802646364854438, 0.9754642082081764], 96 -> 
             RGBColor[
              0.37541990243594203`, 0.4995915831622382, 0.9451424021058012], 
             2 -> RGBColor[
              0.8235173549204953, 0.8621144013032386, 0.98302901454658], 262 -> 
             RGBColor[
              0.4588002800881642, 0.5715137619494752, 0.950537585170794], 272 -> 
             RGBColor[
              0.8041291080513647, 0.8469110379080842, 0.9811117325429493], 97 -> 
             RGBColor[
              0.42158998257307756`, 0.5395817860013234, 0.9480843187855407], 
             372 -> RGBColor[
              0.612519599079081, 0.6963100300827054, 0.962638933054178], 356 -> 
             RGBColor[
              0.5443399595344443, 0.6409587272426099, 0.9572715820789754], 
             346 -> RGBColor[
              0.496408796501871, 0.6020460498184793, 0.9534982653474159], 341 -> 
             RGBColor[
              0.65190432660009, 0.7279918816871594, 0.9659393889493483], 209 -> 
             RGBColor[
              0.298761218973127, 0.4313473620690749, 0.9403253814916794], 378 -> 
             RGBColor[
              0.7836305484408749, 0.8308974073455464, 0.9790686276909064], 66 -> 
             RGBColor[
              0.2837769998629287, 0.41559799772989237`, 0.9394720523805193], 
             139 -> RGBColor[
              0.25255718870617483`, 0.38278399675378905`, 0.9376941303207138],
              56 -> RGBColor[
              0.8761288748215718, 0.9040653991706933, 0.988047148281603], 335 -> 
             RGBColor[
              0.6087564419527599, 0.6932549295992614, 0.9623426835402953], 
             314 -> RGBColor[
              0.5967043758000397, 0.6834705193570902, 0.9613939007445802], 
             144 -> RGBColor[
              0.9951089533212818, 0.9919468706519249, 0.7090179369418372], 
             298 -> RGBColor[
              0.49859084571616724`, 0.6038175356708418, 0.9536700442546749], 
             204 -> RGBColor[
              0.3443936885318878, 0.47271823610139946`, 0.9431654391912386], 
             207 -> RGBColor[
              0.4833107739158069, 0.5914124850239192, 0.9524671410298032], 
             334 -> RGBColor[
              0.29612235881442805`, 0.42857375272888465`, 0.9401751023094853],
              149 -> RGBColor[
              0.9238719150771004, 0.9421344035201478, 0.9926009220818904], 
             219 -> RGBColor[
              0.956787583880072, 0.9672928313283709, 0.9580315282746047], 400 -> 
             RGBColor[
              0.3074920613089446, 0.44052403093139575`, 0.9408225900465804], 
             9 -> RGBColor[
              0.6072881947928905, 0.6920629404110987, 0.9622270977455039], 11 -> 
             RGBColor[
              0.3074920613089446, 0.44052403093139575`, 0.9408225900465804], 
             44 -> RGBColor[
              0.5243709798519363, 0.6247470099440671, 0.9556995508495856], 
             153 -> RGBColor[
              0.3441471447774507, 0.4725046922929554, 0.943149729641216], 32 -> 
             RGBColor[
              0.9302134288503685, 0.947190954467146, 0.993205781326721], 162 -> 
             RGBColor[
              0.9224360436887881, 0.9409894786507982, 0.9924639673870557], 90 -> 
             RGBColor[
              0.35209289109872854`, 0.4793868983916242, 0.9436560255706602], 
             331 -> RGBColor[
              0.3247955170555343, 0.45574328500132155`, 0.9419166610347479], 
             8 -> RGBColor[
              0.5730606551849642, 0.6642754818242964, 0.9595325804479591], 
             364 -> RGBColor[
              0.2565522751385097, 0.3869830858972829, 0.9379216445828346], 
             342 -> RGBColor[
              0.8194535076515501, 0.8588825753454996, 0.9826391254804394], 
             163 -> RGBColor[
              0.7922020952186326, 0.8375935648344991, 0.9799229593680544], 49 -> 
             RGBColor[
              0.2490517983270865, 0.37909960921078034`, 0.9374945035243851], 
             338 -> RGBColor[
              0.5315922686821296, 0.6306095775317725, 0.956268037158751], 76 -> 
             RGBColor[
              0.4889704776109674, 0.5960072874503964, 0.952912693636864], 369 -> 
             RGBColor[
              0.7356700443989307, 0.7934302970746484, 0.9742883728643978], 82 -> 
             RGBColor[
              0.7513503545870487, 0.8056798745683774, 0.9758512396431195], 67 -> 
             RGBColor[
              0.4150427133682919, 0.5339108704914567, 0.9476671325813346], 
             211 -> RGBColor[
              0.4672960516080824, 0.5784110119994902, 
               0.9512064034258785]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9l3k0VX/Yxa95Hq55dufJNVwqktwdKpWiSIU0EZFIxkiFhGRKk6SkQSmp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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 7}], {
             RGBColor[
             0.6576418870840319, 0.7272593336078772, 0.9677782516110388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 35}], {
             RGBColor[
             0.6169537381778885, 0.6908545784112858, 0.9652282118240187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 41}], {
             RGBColor[
             0.8835984945647314, 0.909968907702219, 0.9869371979385456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 57}], {
             RGBColor[
             0.6548321763145833, 0.7248257033595504, 0.9675992193253393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 92}], {
             RGBColor[
             0.9638036311733295, 0.9715820807700384, 0.903911969180661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 96}], {
             RGBColor[
             0.6565786273864898, 0.7263383914988526, 0.9677105016433151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 114}], {
             RGBColor[
             0.8965258906637135, 0.9202768624467282, 0.9881702245188893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 153}], {
             RGBColor[
             0.640942248557244, 0.7127949460642111, 0.9667141654110225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 154}], {
             RGBColor[
             0.6133203661662743, 0.6870356740579883, 0.9650212966630495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 161}], {
             RGBColor[
             0.8973971667896823, 0.9209715943794153, 0.9882533276135815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 188}], {
             RGBColor[
             0.9515226196336295, 0.9238613488674494, 0.6550033611354593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 203}], {
             RGBColor[
             0.5681492662591182, 0.6395579840424156, 0.9624488693479908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 222}], {
             RGBColor[
             0.7813441363975326, 0.8297437683191238, 0.9769480866956941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 312}], {
             RGBColor[
             0.8426023018739336, 0.8778657823449525, 0.9828714046945026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 327}], {
             RGBColor[
             0.592324591936251, 0.6649677841332606, 0.9638256183811141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 337}], {
             RGBColor[
             0.7078403440006061, 0.7700700783431867, 0.9711615989049447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 356}], {
             RGBColor[
             0.7410386559357409, 0.7970219635390384, 0.9737750916299022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 361}], {
             RGBColor[
             0.6852034584569479, 0.7511317814462408, 0.9695344505671804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[
             0.553647177391712, 0.6388561995165655, 0.9612505334635497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 98}], {
             RGBColor[
             0.6030506674097312, 0.6839555741434731, 0.9643139526666902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 106}], {
             RGBColor[
             0.689090626628406, 0.7557272835766758, 0.9705566674529365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 107}], {
             RGBColor[
             0.7461989973166905, 0.8016841539094361, 0.9753302218671729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 197}], {
             RGBColor[
             0.5500536158103523, 0.6350791384495924, 0.9610458854476891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 215}], {
             RGBColor[
             0.5026180213457632, 0.58522132107691, 0.9583444985176042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 283}], {
             RGBColor[
             0.5417519373061064, 0.6263535479848119, 0.9605731171381051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 352}], {
             RGBColor[
             0.7722480828409356, 0.822033897501359, 0.9779265512696852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 52}], {
             RGBColor[
             0.626999391247085, 0.7069033433255754, 0.9645733245638992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 86}], {
             RGBColor[
             0.40963550740455956`, 0.5246530695536789, 0.9480267673083178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 117}], {
             RGBColor[
             0.525378806583791, 0.6255652090870635, 0.9557788906617082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 174}], {
             RGBColor[
             0.4725099528452642, 0.5814469960398847, 0.9519475667247692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 232}], {
             RGBColor[
             0.5595113049431197, 0.6532755089066948, 0.9584659259640158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 309}], {
             RGBColor[
             0.42141938946058805`, 0.5370386767358399, 0.9486978419587173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 371}], {
             RGBColor[
             0.6928643135548986, 0.7585996926385485, 0.9710738596296189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 386}], {
             RGBColor[
             0.5472740977542978, 0.6433407928309076, 0.9575025681877447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 16}], {
             RGBColor[
             0.36445731284909005`, 0.4900963390578805, 0.9444438755911644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 73}], {
             RGBColor[
             0.6165378247103154, 0.6955995206246621, 0.9651908134662917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 115}], {
             RGBColor[
             0.5028800513686987, 0.6060815619571808, 0.9543442830767455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 188}], {
             RGBColor[
             0.6868812877432042, 0.7114210762111992, 0.6334877352779793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 195}], {
             RGBColor[
             0.4611771435951942, 0.5722252627320641, 0.9510612774140306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 206}], {
             RGBColor[
             0.4513750414195363, 0.5642674746061942, 0.9502896200244795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 208}], {
             RGBColor[
             0.46964826051743164`, 0.5791024970690049, 0.9517281547688727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 258}], {
             RGBColor[
             0.6736419200756947, 0.7410520582287576, 0.9678389096447384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 278}], {
             RGBColor[
             0.531645902232067, 0.6292438267537239, 0.956739525722475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 284}], {
             RGBColor[
             0.5620770781875295, 0.6530168926956347, 0.9597726209462076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 369}], {
             RGBColor[
             0.5720623664775588, 0.6608174757988075, 0.9607678611651334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 392}], {
             RGBColor[
             0.6503339083196267, 0.7225476003244757, 0.9684143140910677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 99}], {
             RGBColor[
             0.2907136827399419, 0.4209680925350847, 0.9399374160584877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 174}], {
             RGBColor[
             0.36937916545169286`, 0.4943594004027504, 0.9447574916867789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 193}], {
             RGBColor[
             0.6123248353239401, 0.6895257937029307, 0.9660385638270583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 223}], {
             RGBColor[
             0.3339935239762808, 0.46371013629080227`, 0.9425027499022598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 235}], {
             RGBColor[
             0.3369573876006292, 0.4662772859940957, 0.9426916046715615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 260}], {
             RGBColor[
             0.49905397139448515`, 0.6004303682132562, 0.9549099588683176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 267}], {
             RGBColor[
             0.3176876970979282, 0.44931949187661807`, 0.9414735462716968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 272}], {
             RGBColor[
             0.5668250973603677, 0.653373686897438, 0.9616647513474168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 275}], {
             RGBColor[
             0.37816873833368225`, 0.5019724866563513, 0.9453175554985052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 291}], {
             RGBColor[
             0.5028331776806303, 0.6033827128870244, 0.95528663483223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 321}], {
             RGBColor[
             0.45370965150248965`, 0.5640195838914139, 0.9510655905670964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 338}], {
             RGBColor[
             0.4305566776757501, 0.5452229567092821, 0.9492429036553177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 384}], {
             RGBColor[
             0.27097687587163777`, 0.400223457130665, 0.9388134341053269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 398}], {
             RGBColor[
             0.39472086425706343`, 0.5161298289909952, 0.9464217771520889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 13}], {
             RGBColor[
             0.5974459914392181, 0.6758812749331741, 0.9651098027747538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 18}], {
             RGBColor[
             0.6299426833902961, 0.704805357736919, 0.9671520104873859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 74}], {
             RGBColor[
             0.5735596436136434, 0.6507752088865707, 0.9637495106027723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 102}], {
             RGBColor[
             0.5671460084955712, 0.6440340717295233, 0.9633842635709209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 132}], {
             RGBColor[
             0.9042413020103175, 0.9264814855194916, 0.9907285366831255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 160}], {
             RGBColor[
             0.8182269240965887, 0.8585270545296038, 0.9823569342191156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 166}], {
             RGBColor[
             0.594762988389229, 0.6730612686154169, 0.9649570097202043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 185}], {
             RGBColor[
             0.6468863599671085, 0.7194811187738073, 0.9682316465761555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 198}], {
             RGBColor[
             0.6904371948077299, 0.7563064834905191, 0.9712542843259669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 213}], {
             RGBColor[
             0.8893580767762539, 0.9146140057122361, 0.9893089613738886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 216}], {
             RGBColor[
             0.6485258085938188, 0.7209011267731799, 0.968336110792942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 224}], {
             RGBColor[
             0.7729716104176709, 0.8231732595305103, 0.9778463074865523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 247}], {
             RGBColor[
             0.6560629878269106, 0.7274294525952407, 0.9688163731888086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 289}], {
             RGBColor[
             0.6281477055748317, 0.7032506381713718, 0.967037636088221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 302}], {
             RGBColor[
             0.5831857520536426, 0.6608928591875359, 0.9642977032378789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 323}], {
             RGBColor[
             0.8682402745579291, 0.5891936213829003, 0.46352327011156513`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 340}], {
             RGBColor[
             0.7763405463128363, 0.8258050978566747, 0.9781820915320865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 40}], {
             RGBColor[
             0.3500987518072558, 0.4776596751657055, 0.9435289607783557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 41}], {
             RGBColor[
             0.6035030293117258, 0.6841430414746293, 0.9644368483687555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 80}], {
             RGBColor[
             0.36017939351609496`, 0.4863910203461177, 0.9441712903540815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 96}], {
             RGBColor[
             0.37648316213348415`, 0.5005125252712629, 0.945210152073525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 114}], {
             RGBColor[
             0.6164304254107079, 0.6944509962191385, 0.9656698749490992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 153}], {
             RGBColor[
             0.36084678330423847`, 0.4869690798366215, 0.9442138158412323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 154}], {
             RGBColor[
             0.3332249009132686, 0.4612098078303986, 0.9425209470932594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 192}], {
             RGBColor[
             0.4984392620176621, 0.6016370971999063, 0.9542265701482325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 203}], {
             RGBColor[
             0.2880538010061126, 0.413732117814826, 0.9399485197782007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 222}], {
             RGBColor[
             0.501248671144527, 0.6039179020915341, 0.9544477371259041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 228}], {
             RGBColor[
             0.35872427307220545`, 0.4851306681541006, 0.9440785713661093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 312}], {
             RGBColor[
             0.562506836620928, 0.6520399161173628, 0.9603710551247125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 332}], {
             RGBColor[
             0.5625566607919135, 0.6520788391384145, 0.960376021132443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 356}], {
             RGBColor[
             0.46094319068273526`, 0.5711960973114487, 0.9512747420601121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 361}], {
             RGBColor[
             0.4051079932039422, 0.5253059152186512, 0.9470341009973904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 385}], {
             RGBColor[
             0.3037668215883765, 0.43024749870983164`, 0.9408433530550298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 17}], {
             RGBColor[
             0.4260793639038024, 0.5374778151817623, 0.9493690874219982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.7358995517283213, 0.3108431606080988, 0.42932286014931975`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 36}], {
             RGBColor[
             0.45652840226321567`, 0.5665923952528499, 0.9512089061652876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 60}], {
             RGBColor[
             0.6309893182518449, 0.7105913559459245, 0.9645805722936958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 64}], {
             RGBColor[
             0.5117985467417672, 0.614464616441937, 0.9547306708979912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.6622055048860065, 0.7349776781963369, 0.9676919100455392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 157}], {
             RGBColor[
             0.5852697891390308, 0.6741874067834244, 0.9604937281963545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 171}], {
             RGBColor[
             0.7241839604289806, 0.7838428760809513, 0.9737506814577559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 182}], {
             RGBColor[
             0.47660633712076195`, 0.5839828932801083, 0.9524882544201898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 210}], {
             RGBColor[
             0.6625569166964951, 0.7352522037735193, 0.9677269354906788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 253}], {
             RGBColor[
             0.505956195143862, 0.609404265132961, 0.9543584014203614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 61}], {
             RGBColor[
             0.4299283475124234, 0.5374294131478381, 0.9499609361204385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 131}], {
             RGBColor[
             0.4934988180021988, 0.5976849532311219, 0.9538214127344969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 142}], {
             RGBColor[
             0.5815708902877016, 0.6711844740624211, 0.9602025373292649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 202}], {
             RGBColor[
             0.7720790517752363, 0.8222506011226582, 0.9769870273204155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 214}], {
             RGBColor[
             0.5416430889064131, 0.638769286174137, 0.9570592745441742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 215}], {
             RGBColor[
             0.3945034412819608, 0.5001955906308402, 0.947943540117066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 217}], {
             RGBColor[
             0.5707131273471788, 0.6623696529706584, 0.9593477744572908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 269}], {
             RGBColor[
             0.532934976452164, 0.6316996481877821, 0.9563737400329088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 279}], {
             RGBColor[
             0.6619045116764481, 0.7352668622664741, 0.9673034278673369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 300}], {
             RGBColor[
             0.7202930797939517, 0.7809880672703475, 0.9730944977965845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 306}], {
             RGBColor[
             0.5732315121184861, 0.6644141911799468, 0.9595460309316355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 363}], {
             RGBColor[
             0.567831121009537, 0.6600299103928549, 0.9591208923612546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 39}], {
             RGBColor[
             0.4215284163800309, 0.5344043084626128, 0.9489542785432663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 177}], {
             RGBColor[
             0.45296904708609553`, 0.5599292288540683, 0.9514294001632728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.5603965516259951, 0.6443032037020024, 0.961884411940967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 200}], {
             RGBColor[
             0.42239349676065885`, 0.5351066196870335, 0.9490223808397231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 216}], {
             RGBColor[
             0.34339606445014326`, 0.4695931400411334, 0.9431846579073104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 219}], {
             RGBColor[
             0.6205394412940257, 0.6917156948764209, 0.9487664346067564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 241}], {
             RGBColor[
             0.604724714474152, 0.6796492775011964, 0.9661124716856423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 296}], {
             RGBColor[
             0.3448343313259931, 0.4708388945195995, 0.94327630300083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 311}], {
             RGBColor[
             0.5728392583956293, 0.654224680331831, 0.9630712084203902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 339}], {
             RGBColor[
             0.29106246671287683`, 0.4232554853144656, 0.9398869489397415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 360}], {
             RGBColor[
             0.3428792372825023, 0.46914549032501157`, 0.9431517261372007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 374}], {
             RGBColor[
             0.6275479970910719, 0.6646590411273221, 0.640291762618511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 14}], {
             RGBColor[
             0.28757577543702717`, 0.41959075171455246`, 0.9396883870296793]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 25}], {
             RGBColor[
             0.566548318580111, 0.6521513627743686, 0.9620253427944112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 38}], {
             RGBColor[
             0.4721726794779267, 0.5782946268660459, 0.9526885804946463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 78}], {
             RGBColor[
             0.3074920613089446, 0.44052403093139575`, 0.9408225900465804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 102}], {
             RGBColor[
             0.27361664565237814`, 0.4049188212509393, 0.9388934352391255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 144}], {
             RGBColor[
             0.6513005073151132, 0.7162354507916604, 0.8249202634942088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 205}], {
             RGBColor[
             0.39646145651081255`, 0.5168288453096166, 0.9467283156833273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 207}], {
             RGBColor[
             0.39540141761237574`, 0.5159682579776574, 0.9466448655381918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 213}], {
             RGBColor[
             0.5958287139330609, 0.675498755233652, 0.9648181330420931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 221}], {
             RGBColor[
             0.5384149751514495, 0.6301279520443864, 0.9592333295081571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 230}], {
             RGBColor[
             0.4233334453765132, 0.5386447364400953, 0.9488437770821738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 250}], {
             RGBColor[
             0.5042936587711363, 0.6034721203564763, 0.9558324355731982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 289}], {
             RGBColor[
             0.3346183427316386, 0.4641353876927878, 0.9425468077564256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 358}], {
             RGBColor[
             0.3163405152253339, 0.44830405217714864`, 0.9413821607501722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 391}], {
             RGBColor[
             0.47908206902479245`, 0.5837766348314537, 0.9533195799229842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 118}], {
             RGBColor[
             0.6961166516332449, 0.41403175551224175`, 0.4439452118641346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 126}], {
             RGBColor[
             0.4850749535124754, 0.591237350175849, 0.9530501463001579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 149}], {
             RGBColor[
             0.6589957581306924, 0.7289613629320064, 0.9694674262282208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 199}], {
             RGBColor[
             0.31891822960853367`, 0.4446402855252906, 0.9417623084707564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 212}], {
             RGBColor[
             0.4781679549958182, 0.5856299376232896, 0.9525064020757575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 238}], {
             RGBColor[
             0.604999864685896, 0.6859396732466825, 0.9643084473925723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 259}], {
             RGBColor[
             0.41422671102191855`, 0.5332040902724985, 0.9476151376333862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 274}], {
             RGBColor[
             0.5083543278258114, 0.6101365949672768, 0.9548827839212617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 299}], {
             RGBColor[
             0.32160313805237223`, 0.44746229453279246`, 0.9419152100346668]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 318}], {
             RGBColor[
             0.34619775612855974`, 0.47331279751971755`, 0.9433158371496289]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 336}], {
             RGBColor[
             0.5700169057035197, 0.6586107198093145, 0.9608216729755477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 367}], {
             RGBColor[
             0.6606555865516766, 0.7302848650600569, 0.9696257421447607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 18}], {
             RGBColor[
             0.33283788783418367`, 0.46193210078152924`, 0.9424575665519684]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 69}], {
             RGBColor[
             0.3180958519405167, 0.4491632902467032, 0.9415182170606945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 74}], {
             RGBColor[
             0.27645484805753096`, 0.40790195193118095`, 0.9390550666673547]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 88}], {
             RGBColor[
             0.34845234423145227`, 0.4754565581074456, 0.9434525059062808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 132}], {
             RGBColor[
             0.6071365064542049, 0.6836082285641019, 0.9660340927477081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[
             0.457678790484407, 0.5656725257097989, 0.9516254240169923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 191}], {
             RGBColor[
             0.6109425842305831, 0.6866430916697568, 0.9663971198437449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 198}], {
             RGBColor[
             0.3933323992516174, 0.5134332265351295, 0.9465598403905495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 216}], {
             RGBColor[
             0.3514210130377063, 0.4780278698177901, 0.9436416668575245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 224}], {
             RGBColor[
             0.47586681486155846`, 0.5803000025751206, 0.9531518635511349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 302}], {
             RGBColor[
             0.2860809564975301, 0.4180196022321462, 0.9396032593024615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 323}], {
             RGBColor[
             0.6701704108538541, 0.4272781167459739, 0.44706030748795345`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 340}], {
             RGBColor[
             0.47923575075672387`, 0.582931840901285, 0.9534876475966692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 357}], {
             RGBColor[
             0.5342698360170375, 0.6259248865811815, 0.9589729308926499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 38}], {
             RGBColor[
             0.45225639360600933`, 0.5573613476492026, 0.9515543774777453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 102}], {
             RGBColor[
             0.2537003597804608, 0.383985542034096, 0.9377592322222243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 205}], {
             RGBColor[
             0.37654517063889514`, 0.4958955660927733, 0.9455941126664261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 207}], {
             RGBColor[
             0.3754851317404584, 0.49503497876081415`, 0.9455106625212908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.5759124280611436, 0.6545654760168087, 0.963683930025192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 224}], {
             RGBColor[
             0.45952596170256055`, 0.563124729835083, 0.9522212761378559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 230}], {
             RGBColor[
             0.4034171595045958, 0.517711457223252, 0.9477095740652727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 247}], {
             RGBColor[
             0.34261733911180026`, 0.4673809228998135, 0.9431913418401121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 250}], {
             RGBColor[
             0.4843773728992189, 0.5825388411396331, 0.9546982325562972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 289}], {
             RGBColor[
             0.3147020568597212, 0.4432021084759445, 0.9414126047395246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 340}], {
             RGBColor[
             0.46289489759772595`, 0.5657565681612474, 0.95255706018339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 391}], {
             RGBColor[
             0.45916578315287504`, 0.5628433556146104, 0.9521853769060831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 45}], {
             RGBColor[
             0.7117670051858824, 0.7742999596065755, 0.9722184641387024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 100}], {
             RGBColor[
             0.6790219942447389, 0.7487193081880534, 0.9689547474676145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 105}], {
             RGBColor[
             0.800137676557607, 0.8427573669804738, 0.9076106529878243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.7764276211405543, 0.8256665154954856, 0.9742596527716847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 155}], {
             RGBColor[
             0.8038038908731594, 0.8441062372029327, 0.8346980562424668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 170}], {
             RGBColor[
             0.6476704145921961, 0.7242272158826566, 0.9658299150050185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 180}], {
             RGBColor[
             0.6154687163100709, 0.6987042563070403, 0.9628710983655739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 183}], {
             RGBColor[
             0.6712430181286613, 0.7426423129237655, 0.9681794118270287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 239}], {
             RGBColor[
             0.6788966558213005, 0.7486213928590562, 0.9689422549049203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 271}], {
             RGBColor[
             0.625369906977077, 0.7067424889340722, 0.9636505563641371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 273}], {
             RGBColor[
             0.606131000189934, 0.6911234777013957, 0.9621359991474155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 326}], {
             RGBColor[
             0.551308135124323, 0.6466158060992064, 0.9578201423866789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 335}], {
             RGBColor[
             0.6106380205159205, 0.6947824798409834, 0.9624908082972367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 394}], {
             RGBColor[
             0.6380677766730334, 0.7167255621574553, 0.9648728137989897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 73}], {
             RGBColor[
             0.5725404490032184, 0.6574912051595763, 0.9623873395915872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 85}], {
             RGBColor[
             0.5997029397460805, 0.6791498379717649, 0.9649781222068832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 96}], {
             RGBColor[
             0.34793991978896754`, 0.4757898033775164, 0.9433914019111306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 110}], {
             RGBColor[
             0.3733525230083173, 0.49780092301154094`, 0.9450106705167849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 115}], {
             RGBColor[
             0.45888267566160174`, 0.5679732464920949, 0.951540809202041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 184}], {
             RGBColor[
             0.5010472486667494, 0.6016026948598561, 0.9552715112526857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 188}], {
             RGBColor[
             0.6428839120361073, 0.6733127607461133, 0.6306842614032748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 203}], {
             RGBColor[
             0.259510558661596, 0.3890093959210795, 0.9381297696158063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 206}], {
             RGBColor[
             0.4073776657124394, 0.5261591591411083, 0.947486146149775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 208}], {
             RGBColor[
             0.42565088481033464`, 0.540994181603919, 0.9489246808941683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 258}], {
             RGBColor[
             0.6296445443685976, 0.7029437427636718, 0.9650354357700339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 284}], {
             RGBColor[
             0.5180797024804324, 0.6149085772305488, 0.9569691470715032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 325}], {
             RGBColor[
             0.48862202166308916`, 0.5918960130893739, 0.954033080745309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 348}], {
             RGBColor[
             0.31244381742049443`, 0.4446456070391298, 0.9411442403943868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 369}], {
             RGBColor[
             0.5280649907704619, 0.6227091603337216, 0.9579643872904289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 392}], {
             RGBColor[
             0.6063365326125296, 0.6844392848593899, 0.9656108402163632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 36}], {
             RGBColor[
             0.3095471109820539, 0.4397947286103159, 0.9410454131393269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 64}], {
             RGBColor[
             0.3648172554606054, 0.48766694979940295`, 0.9445671778720304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 82}], {
             RGBColor[
             0.5152242136048447, 0.6081800115538029, 0.9575284170195785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 122}], {
             RGBColor[
             0.4549143103799942, 0.5608873237306704, 0.9516390800344934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 157}], {
             RGBColor[
             0.43828849785786905`, 0.5473897401408904, 0.9503302351703937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 187}], {
             RGBColor[
             0.3204213483884867, 0.449213446496704, 0.9417383099311541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 218}], {
             RGBColor[
             0.3956178100533777, 0.512747753488625, 0.9469710423185445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 253}], {
             RGBColor[
             0.35897490386270037`, 0.482606598490427, 0.9441949083944006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 262}], {
             RGBColor[
             0.3689491763554025, 0.49109695524435176`, 0.9448715897834157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 298}], {
             RGBColor[
             0.38884445916940397`, 0.5072488421050351, 0.9464378193253562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 74}], {
             RGBColor[
             0.308951540008609, 0.43682603473492587`, 0.9410972743799868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 132}], {
             RGBColor[
             0.639633198405283, 0.7125323113678468, 0.9680763004603402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 140}], {
             RGBColor[
             0.4901754824354851, 0.5945966085135438, 0.9536676317296244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 191}], {
             RGBColor[
             0.6434392761816612, 0.7155671744735017, 0.968439327556377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.42582909120269546`, 0.5423573093388743, 0.9486020481031816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 216}], {
             RGBColor[
             0.38391770498878436`, 0.506951952621535, 0.9456838745701566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.5083635068126365, 0.6092240853788655, 0.955194071263767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 247}], {
             RGBColor[
             0.3914548842218762, 0.5134802784435959, 0.9461641369660233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 302}], {
             RGBColor[
             0.3185776484486082, 0.4469436850358911, 0.9416454670150936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 311}], {
             RGBColor[
             0.6133608989342705, 0.6915834929122326, 0.9655704250832364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 323}], {
             RGBColor[
             0.6918348721545728, 0.4465608386151371, 0.44842177929637483`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 340}], {
             RGBColor[
             0.5117324427078019, 0.6118559237050298, 0.9555298553093012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 357}], {
             RGBColor[
             0.5667665279681156, 0.6548489693849264, 0.961015138605282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 83}], {
             RGBColor[
             0.6692723813491565, 0.7359009166679782, 0.9476176999268671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 108}], {
             RGBColor[
             0.7069032568918052, 0.7684948896802215, 0.950015506040768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 125}], {
             RGBColor[
             0.6730659885457552, 0.7391867485494303, 0.9478594252228792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 179}], {
             RGBColor[
             0.6281744612405771, 0.6990156535048171, 0.9450461481539436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 196}], {
             RGBColor[
             0.8285530560834569, 0.866469039201311, 0.9601416518074377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 231}], {
             RGBColor[
             0.6299208789836888, 0.7008512492821077, 0.9451456040608204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 303}], {
             RGBColor[
             0.8855152490255417, 0.9109683372563684, 0.9658191108579468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 313}], {
             RGBColor[
             0.6126474834113596, 0.6826958153390549, 0.9441619097366749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 344}], {
             RGBColor[
             0.6896490206248711, 0.7535501374489336, 0.948916081363161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 50}], {
             RGBColor[
             0.5151350745050649, 0.6033796012148369, 0.9582684834470936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 54}], {
             RGBColor[
             0.6033595919723476, 0.6727588115616432, 0.9426308419398111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 116}], {
             RGBColor[
             0.2674443166696867, 0.3984313121418699, 0.9385419302347037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 121}], {
             RGBColor[
             0.5416492671980611, 0.6242485066245034, 0.9608698214607276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 130}], {
             RGBColor[
             0.45614079474977076`, 0.5572928214968687, 0.9523884849739748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 135}], {
             RGBColor[
             0.616953242903562, 0.6819536270266617, 0.8773771156005876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 147}], {
             RGBColor[
             0.22770875868383597`, 0.356666721318852, 0.9362790489908996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 158}], {
             RGBColor[
             0.34711323557741136`, 0.46909094266516743`, 0.9435577869794625]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 172}], {
             RGBColor[
             0.2554197232507139, 0.3857927020552724, 0.9378571474282851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 181}], {
             RGBColor[
             0.4988708560905451, 0.5906738701767758, 0.9566474181532969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 265}], {
             RGBColor[
             0.5927195667821548, 0.6648234981962396, 0.9606416292237937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 322}], {
             RGBColor[
             0.6194481505743468, 0.6826210447867134, 0.8095499522374199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 328}], {
             RGBColor[
             0.5845865606912855, 0.6584855389542171, 0.9649652188446858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 347}], {
             RGBColor[
             0.35197860882112947`, 0.4731258072219561, 0.9439173390864877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 362}], {
             RGBColor[
             0.3708573465948838, 0.48845241702413456`, 0.9454035424791327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 364}], {
             RGBColor[
             0.25029442546800623`, 0.38040568912299827`, 0.9375652693017584]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 387}], {
             RGBColor[
             0.2560841793724993, 0.38649108756822015`, 0.9378949872214459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.6582113831138224, 0.2457211028938011, 0.4237737439608721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 60}], {
             RGBColor[
             0.7745186604395752, 0.34172041002251746`, 0.43268818804647746`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 64}], {
             RGBColor[
             0.6950581460995234, 0.2776359170198592, 0.4261215871160078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 82}], {
             RGBColor[
             0.7953294515290162, 0.3579779581894591, 0.43476241321437314`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 122}], {
             RGBColor[
             0.7551228493791159, 0.32644949964070413`, 0.4308361885576497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 159}], {
             RGBColor[
             0.8571422234583668, 0.4068772247938594, 0.44010682409550195`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 182}], {
             RGBColor[
             0.6715966730188533, 0.25731476824530675`, 0.42462664279747353`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 210}], {
             RGBColor[
             0.795563726069342, 0.35816097524091406`, 0.43478576351113274`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 263}], {
             RGBColor[
             0.8005307437927076, 0.36204124723714015`, 0.4352808294183782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 29}], {
             RGBColor[
             0.6491660124631136, 0.7232574517658201, 0.9674795279242547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 45}], {
             RGBColor[
             0.6389599606432492, 0.715191920926887, 0.9664868268913145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 91}], {
             RGBColor[
             0.3874506231375096, 0.5095736889927035, 0.9460134660752663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 97}], {
             RGBColor[
             0.44424774628344615`, 0.5588378693623259, 0.9496299886724715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 100}], {
             RGBColor[
             0.6062149497021057, 0.6896112695083649, 0.9632231102202266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 141}], {
             RGBColor[
             0.7283602705768679, 0.7840751103066326, 0.8848152401506717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 150}], {
             RGBColor[
             0.5461781905142491, 0.6424510859633774, 0.9574162943553677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 189}], {
             RGBColor[
             0.6517036572689128, 0.7252809008514312, 0.9677215707512141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 190}], {
             RGBColor[
             0.5224018631647117, 0.6231483923096822, 0.9555445347708552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 255}], {
             RGBColor[
             0.5115521587672744, 0.6143401135062295, 0.9546904062969122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 266}], {
             RGBColor[
             0.5537584458603878, 0.6486050787399846, 0.958013039823606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 273}], {
             RGBColor[
             0.5333239556473008, 0.6320154390217072, 0.9564043619000276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 350}], {
             RGBColor[
             0.3239460712614385, 0.4428263785498088, 0.9423969757924895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 365}], {
             RGBColor[
             0.5482236171076944, 0.6441116554173543, 0.9575773178294482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 394}], {
             RGBColor[
             0.5652607321304002, 0.6576175234777668, 0.9591411765516018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[
             0.24398524125963283`, 0.37377433649461467`, 0.9372059705946931]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 89}], {
             RGBColor[
             0.34255230951355486`, 0.4683821726887894, 0.943148475204403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 163}], {
             RGBColor[
             0.5356500839206366, 0.6241368566868637, 0.9595642768820459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 164}], {
             RGBColor[
             0.6143654430565555, 0.6863184819129476, 0.9546741413386294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 169}], {
             RGBColor[
             0.36950935723369843`, 0.4915517353172134, 0.9449156892741654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 227}], {
             RGBColor[
             0.3754433037539411, 0.49636918042359074`, 0.9453828312810011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 245}], {
             RGBColor[
             0.4445813468358175, 0.5524985584308048, 0.9508256312934031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 292}], {
             RGBColor[
             0.357582292901515, 0.4814003888705103, 0.9441061724553914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 304}], {
             RGBColor[
             0.501779062040806, 0.5976765569650393, 0.9561883299637601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 353}], {
             RGBColor[
             0.2656864253861789, 0.3965836569461585, 0.9384418209266749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 378}], {
             RGBColor[
             0.5313643105317578, 0.6207887779423873, 0.9591371110434719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 25}], {
             RGBColor[
             0.8139712929191703, 0.8546452565523719, 0.9820806540844524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 76}], {
             RGBColor[
             0.6456542437990153, 0.7207595529688994, 0.9669229531317634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 104}], {
             RGBColor[
             0.7145647286392958, 0.7767041889442039, 0.9723478389258136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 109}], {
             RGBColor[
             0.6901181131613359, 0.7568573251917192, 0.9704233118044854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 138}], {
             RGBColor[
             0.8046616579199348, 0.84732706991294, 0.9811648121368868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 144}], {
             RGBColor[
             0.8987234816541725, 0.9187293445696636, 0.84497557478425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 207}], {
             RGBColor[
             0.6428243919514349, 0.7184621517556607, 0.966700176828233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 233}], {
             RGBColor[
             0.7645331314246995, 0.8159783600267649, 0.9771651756382428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 242}], {
             RGBColor[
             0.8731779353132083, 0.901640505565674, 0.9802902757352894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 317}], {
             RGBColor[
             0.898633960724736, 0.9188416104144228, 0.8573106154352368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 358}], {
             RGBColor[
             0.5637634895643931, 0.650797945955152, 0.9614374720402132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 366}], {
             RGBColor[
             0.6514533540087253, 0.7254675318840798, 0.9673794803303124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 382}], {
             RGBColor[
             0.7583481206394704, 0.8111465825935211, 0.9765487115653831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[
             0.6572875267311225, 0.729892991033869, 0.968070394589553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 104}], {
             RGBColor[
             0.7261980115714031, 0.7858376270091735, 0.9734952803836033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 109}], {
             RGBColor[
             0.7017513960934432, 0.7659907632566887, 0.9715707532622752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 138}], {
             RGBColor[
             0.8162949408520421, 0.8564605079779097, 0.9823122535946766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 144}], {
             RGBColor[
             0.9103567645862797, 0.9278627826346332, 0.8461230162420397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 205}], {
             RGBColor[
             0.655517713781979, 0.7284561771525895, 0.9679310684311581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 207}], {
             RGBColor[
             0.6544576748835422, 0.7275955898206303, 0.9678476182860227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 233}], {
             RGBColor[
             0.7761664143568067, 0.8251117980917346, 0.9783126170960326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 317}], {
             RGBColor[
             0.9102672436568433, 0.9279750484793925, 0.8584580568930266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 358}], {
             RGBColor[
             0.5753967724965003, 0.6599313840201215, 0.962584913498003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 366}], {
             RGBColor[
             0.6630866369408325, 0.7346009699490492, 0.9685269217881021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 382}], {
             RGBColor[
             0.7699814035715777, 0.8202800206584907, 0.9776961530231729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 391}], {
             RGBColor[
             0.7381383262959589, 0.7954039666744266, 0.974522332670815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 30}], {
             RGBColor[
             0.6383582955863385, 0.7152485052971522, 0.9660668126232332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 62}], {
             RGBColor[
             0.5539173157784151, 0.6434123178747849, 0.960326466209994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 77}], {
             RGBColor[
             0.5933351207689956, 0.677554039361141, 0.9628381338881974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 106}], {
             RGBColor[
             0.6650490586312884, 0.7369172691422153, 0.9681680072616183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 111}], {
             RGBColor[
             0.5645418395367089, 0.6526147463501281, 0.9610034514689749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 160}], {
             RGBColor[
             0.7586686400620533, 0.8113969748024807, 0.9765806579460019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.5352047043546936, 0.6259311888882938, 0.9591807334470905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 173}], {
             RGBColor[
             0.5533693166647795, 0.6429376685857902, 0.9602915481910497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 185}], {
             RGBColor[
             0.5873280759325731, 0.6723510390466843, 0.9624553703030417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 197}], {
             RGBColor[
             0.5260120478132346, 0.6162691240151319, 0.958657225256371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 204}], {
             RGBColor[
             0.5599139537290738, 0.6486063042678585, 0.9607085666775912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 345}], {
             RGBColor[
             0.717269026834652, 0.7790552823005206, 0.9724543314008764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 370}], {
             RGBColor[
             0.5505469469845286, 0.6404930738251815, 0.9601117092907476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 389}], {
             RGBColor[
             0.541295347352055, 0.6323328408475907, 0.9595275865554913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 400}], {
             RGBColor[
             0.5414631401176022, 0.6325092016828566, 0.9595371421052621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 51}], {
             RGBColor[
             0.5903758660078493, 0.6744295047738922, 0.9628871740807354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[
             0.691190562184282, 0.7521439477618352, 0.8784649215438558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 277}], {
             RGBColor[
             0.48341740515261683`, 0.5898368312887114, 0.9529348122609274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 287}], {
             RGBColor[
             0.6229980081839217, 0.7001882712256047, 0.9660659063517416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 376}], {
             RGBColor[
             0.5401148734700376, 0.6351652354056623, 0.957877628060246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 377}], {
             RGBColor[
             0.6747588242058686, 0.6910308988662954, 0.6176413107400622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 395}], {
             RGBColor[
             0.6436141161344391, 0.7166269960960047, 0.9680322891322788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 396}], {
             RGBColor[
             0.5356685318052891, 0.6316917195037124, 0.9574344582765292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 44}], {
             RGBColor[
             0.38457757975886464`, 0.4996805406795884, 0.946475509902293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 47}], {
             RGBColor[
             0.6140999059946637, 0.6808830288365936, 0.9251043284610685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 49}], {
             RGBColor[
             0.24691798899643974`, 0.37685684031294503`, 0.9373729862396929]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 147}], {
             RGBColor[
             0.2280825606179811, 0.35705961085205007`, 0.9363003364580589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 211}], {
             RGBColor[
             0.3560401156369377, 0.47651254170729995`, 0.9442289361904395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 301}], {
             RGBColor[
             0.471894674528569, 0.5697007447352307, 0.9539427148656899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 328}], {
             RGBColor[
             0.5849603626254306, 0.6588784284874152, 0.964986506311845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 347}], {
             RGBColor[
             0.35235241075527457`, 0.4735186967551541, 0.9439386265536469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 362}], {
             RGBColor[
             0.37123114852902894`, 0.4888453065573326, 0.945424829946292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 372}], {
             RGBColor[
             0.42865188937243703`, 0.5354620507489076, 0.9499452010045892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 380}], {
             RGBColor[
             0.4142014978817525, 0.5237305719540517, 0.9488076132529144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 390}], {
             RGBColor[
             0.5671603673135337, 0.6446851953937099, 0.9632887268687529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 45}], {
             RGBColor[
             0.8212204631125481, 0.8603554199693788, 0.982790696256167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 91}], {
             RGBColor[
             0.5697111256068084, 0.6547371880351953, 0.9623173354401187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 150}], {
             RGBColor[
             0.728438692983548, 0.7876145850058692, 0.9737201637202201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 190}], {
             RGBColor[
             0.7046623656340105, 0.768311891352174, 0.9718484041357076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 226}], {
             RGBColor[
             0.7417020333300657, 0.7982350182608533, 0.9748650423174249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 266}], {
             RGBColor[
             0.7360189483296866, 0.7937685777824763, 0.9743169091884584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 273}], {
             RGBColor[
             0.7155844581165998, 0.7771789380641989, 0.97270823126488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 365}], {
             RGBColor[
             0.7304841195769931, 0.789275154459846, 0.9738811871943006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 62}], {
             RGBColor[
             0.4168413924384937, 0.5341664507376196, 0.9481415846692834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 77}], {
             RGBColor[
             0.45625919742907417`, 0.5683081722239758, 0.9506532523474869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 84}], {
             RGBColor[
             0.4275567997768928, 0.5434475980021085, 0.9488243609496236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 204}], {
             RGBColor[
             0.4228380303891524, 0.5393604371306933, 0.9485236851368807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 333}], {
             RGBColor[
             0.7463594487742952, 0.7983647177741219, 0.8727321992975088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 370}], {
             RGBColor[
             0.4134710236446071, 0.5312472066880162, 0.9479268277500371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 389}], {
             RGBColor[
             0.4042194240121335, 0.5230869737104253, 0.9473427050147809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 400}], {
             RGBColor[
             0.4043872167776808, 0.5232633345456914, 0.9473522605645516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 33}], {
             RGBColor[
             0.45152374546609336`, 0.5562832454192782, 0.9515406942018378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 106}], {
             RGBColor[
             0.4091413411806091, 0.5218753003147674, 0.9482041960846221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 156}], {
             RGBColor[
             0.36593429051296633`, 0.486797870127324, 0.9448027787834237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 173}], {
             RGBColor[
             0.2974615992141002, 0.4278956997583421, 0.9403277370140535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 175}], {
             RGBColor[
             0.4351671715541779, 0.5430042418623277, 0.9502530447873874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 197}], {
             RGBColor[
             0.27010433036255527`, 0.4012271551876839, 0.9386934140793749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 204}], {
             RGBColor[
             0.3040062362783945, 0.4335643354404105, 0.940744755500595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 214}], {
             RGBColor[
             0.36980838352241846`, 0.4899430333582985, 0.9451077615763981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 261}], {
             RGBColor[
             0.36593429051296633`, 0.486797870127324, 0.9448027787834237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 295}], {
             RGBColor[
             0.44310391924611986`, 0.5494476511850551, 0.9508778546389618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 310}], {
             RGBColor[
             0.332124649337983, 0.4579190915600929, 0.9425364359166156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 345}], {
             RGBColor[
             0.4613613093839727, 0.5640133134730726, 0.9524905202238803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 43}], {
             RGBColor[
             0.6854387190985171, 0.7516468518856454, 0.9712527401158876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 124}], {
             RGBColor[
             0.9017622302931243, 0.9245047410248108, 0.9904920806096462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 137}], {
             RGBColor[
             0.7143895585033366, 0.7754940330487781, 0.9734369225430641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 199}], {
             RGBColor[
             0.5869651434415758, 0.660341601586931, 0.9651982339468412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 238}], {
             RGBColor[
             0.873046778518938, 0.9016409893083229, 0.9877443728686571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 252}], {
             RGBColor[
             0.6611565385703686, 0.7306148475700429, 0.969705501044523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 293}], {
             RGBColor[
             0.8942482540016463, 0.9185133002914392, 0.9897753908431592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 330}], {
             RGBColor[
             0.9171600476284912, 0.9367825426054153, 0.9919607381728873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 63}], {
             RGBColor[
             0.47363906832398445`, 0.5795278519353777, 0.9528001291219065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 84}], {
             RGBColor[
             0.49662996710732704`, 0.5995243069516825, 0.9542620537052243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 90}], {
             RGBColor[
             0.495760799003007, 0.5987714772253796, 0.9542066710821921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 152}], {
             RGBColor[
             0.5372491576835698, 0.6347066082489439, 0.9568502726106025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 156}], {
             RGBColor[
             0.5538392519541584, 0.6486706807671807, 0.95801940117531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 173}], {
             RGBColor[
             0.4853665606552924, 0.5897685103981988, 0.9535443594059398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 175}], {
             RGBColor[
             0.62307213299537, 0.7048770525021844, 0.9634696671792737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 204}], {
             RGBColor[
             0.49191119771958663`, 0.5954371460802672, 0.9539613778924814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 214}], {
             RGBColor[
             0.5577133449636106, 0.6518158439981552, 0.9583243839682845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 256}], {
             RGBColor[
             0.47378630762926105`, 0.5796826097807346, 0.9528085141825209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 261}], {
             RGBColor[
             0.5538392519541584, 0.6486706807671807, 0.95801940117531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 264}], {
             RGBColor[
             0.5687766497565752, 0.660797533225285, 0.9591953278478074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 295}], {
             RGBColor[
             0.631008880687312, 0.7113204618249118, 0.9640944770308482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 310}], {
             RGBColor[
             0.5200296107791751, 0.6197919021999496, 0.955753058308502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 333}], {
             RGBColor[
             0.8154326161047294, 0.8544414267236958, 0.8781698920531096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 381}], {
             RGBColor[
             0.601488612269399, 0.687354578050313, 0.9617705333646838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 53}], {
             RGBColor[
             0.7778530536755098, 0.8238806706350869, 0.8730387587232691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 68}], {
             RGBColor[
             0.4181240643789099, 0.5301989982171242, 0.9488174901364619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 86}], {
             RGBColor[
             0.4237484835339696, 0.5361106193578631, 0.94913779248676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 95}], {
             RGBColor[
             0.46589025416014357`, 0.5749469449742579, 0.9517375241972139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 151}], {
             RGBColor[
             0.7031088975215587, 0.766972691536864, 0.9718159141102234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 244}], {
             RGBColor[
             0.7003925676799447, 0.7648067638539704, 0.9715568281450341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 249}], {
             RGBColor[
             0.41734294537071615`, 0.529377992613707, 0.9487730065645072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 253}], {
             RGBColor[
             0.5014301744090468, 0.6057298376055273, 0.9540020964887566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 270}], {
             RGBColor[
             0.4761057589932758, 0.5837951018145149, 0.9523884471319648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 308}], {
             RGBColor[
             0.5371289732767499, 0.6351045237473848, 0.9567039068260568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 386}], {
             RGBColor[
             0.5613870738837079, 0.6547983426350918, 0.9586135933661869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 397}], {
             RGBColor[
             0.6116876069774528, 0.6953740466695661, 0.9627515646157846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 41}], {
             RGBColor[
             0.5628148804055824, 0.647738286278038, 0.9618868085817354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 57}], {
             RGBColor[
             0.3340485621554344, 0.46259508193536936`, 0.9425488299685291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 92}], {
             RGBColor[
             0.6430200170141804, 0.7093514593458574, 0.8788615798238507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 114}], {
             RGBColor[
             0.5757422765045646, 0.6580462410225472, 0.9631198351620791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 153}], {
             RGBColor[
             0.3201586343980951, 0.45056432464003016`, 0.9416637760542123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 188}], {
             RGBColor[
             0.6307390054744806, 0.6616307274432685, 0.6299529717786491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 195}], {
             RGBColor[
             0.40503486132647043`, 0.5224349139641333, 0.9475265139147004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 208}], {
             RGBColor[
             0.4135059782487079, 0.5293121483010741, 0.9481933912695426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 258}], {
             RGBColor[
             0.6174996378069708, 0.6912617094608269, 0.9643041461454083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 278}], {
             RGBColor[
             0.4755036199633433, 0.5794534779857932, 0.9532047622231448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 284}], {
             RGBColor[
             0.5059347959188057, 0.6032265439277039, 0.9562378574468775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 327}], {
             RGBColor[
             0.27154097777710207`, 0.40273716270907967`, 0.9387752290243039]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 337}], {
             RGBColor[
             0.38705672984145717`, 0.5078394569190057, 0.9461112095481345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 354}], {
             RGBColor[
             0.331994917038989, 0.4608163177547091, 0.9424179735176762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 369}], {
             RGBColor[
             0.5159200842088352, 0.6110271270308767, 0.9572330976658032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 392}], {
             RGBColor[
             0.5941916260509028, 0.672757251556545, 0.9648795505917376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 55}], {
             RGBColor[
             0.6562763814914816, 0.7239813282932139, 0.9371119529963898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 60}], {
             RGBColor[
             0.5144570653300964, 0.612908269374478, 0.9562568980110244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 64}], {
             RGBColor[
             0.39526629382001865`, 0.5167815298704905, 0.9464069966153197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 82}], {
             RGBColor[
             0.545673251964258, 0.6372945916248904, 0.9593682357628679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 122}], {
             RGBColor[
             0.48536334873940745`, 0.5900019038017579, 0.9534788987777827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 157}], {
             RGBColor[
             0.4687375362172823, 0.576504320211978, 0.952170053913683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 165}], {
             RGBColor[
             0.6215940330540533, 0.6972770214461949, 0.9667568386322012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 218}], {
             RGBColor[
             0.42606684841279097`, 0.5418623335597126, 0.9488108610618338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 262}], {
             RGBColor[
             0.3993982147148157, 0.5202115353154393, 0.9467114085267051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 298}], {
             RGBColor[
             0.41929349752881717`, 0.5363634221761227, 0.9482776380686455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 314}], {
             RGBColor[
             0.4683502625707534, 0.5761899140192468, 0.9521395663135982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 58}], {
             RGBColor[
             0.45576301490386595`, 0.554264765770516, 0.9527834945307411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 87}], {
             RGBColor[
             0.7395245697151782, 0.7964414815471783, 0.9746725559253344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 110}], {
             RGBColor[
             0.5569946576383988, 0.6498020453059979, 0.9589462562712046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 134}], {
             RGBColor[
             0.630801877091516, 0.7104571635025339, 0.9645535227124242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 159}], {
             RGBColor[
             0.8122664383886282, 0.8541839712816435, 0.9806980227559026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 167}], {
             RGBColor[
             0.8198124512187406, 0.8598117752948793, 0.9679245913498726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 201}], {
             RGBColor[
             0.7675912939499059, 0.8185893233793029, 0.9774110983206807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 236}], {
             RGBColor[
             0.6107049287951928, 0.6941415555183752, 0.9629714173249904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 243}], {
             RGBColor[
             0.537338252858792, 0.632776655445533, 0.9576937675401243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 263}], {
             RGBColor[
             0.7273492188901396, 0.7869300049465646, 0.9734590307402169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 348}], {
             RGBColor[
             0.49608595205057604`, 0.5966467293335869, 0.9550798261488065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 351}], {
             RGBColor[
             0.7061021289305638, 0.7703316167862795, 0.9713413193783911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 78}], {
             RGBColor[
             0.4721726794779267, 0.5782946268660459, 0.9526885804946463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 102}], {
             RGBColor[
             0.43829726382136025`, 0.5426894171855895, 0.9507594256871914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 205}], {
             RGBColor[
             0.5611420746797946, 0.6545994412442668, 0.9585943061313932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 207}], {
             RGBColor[
             0.5600820357813578, 0.6537388539123077, 0.9585108559862578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 213}], {
             RGBColor[
             0.7605093321020431, 0.8132693511683022, 0.9766841234901591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 221}], {
             RGBColor[
             0.7030955933204317, 0.7678985479790366, 0.971099319956223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 224}], {
             RGBColor[
             0.6441228657434601, 0.7218286049865765, 0.965221469602823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 230}], {
             RGBColor[
             0.5880140635454953, 0.6764153323747455, 0.9607097675302397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 247}], {
             RGBColor[
             0.5272142431526997, 0.6260847980513069, 0.9561915353050792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 250}], {
             RGBColor[
             0.6689742769401184, 0.7412427162911266, 0.9676984260212642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 289}], {
             RGBColor[
             0.4992989609006207, 0.601905983627438, 0.9544127982044917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 358}], {
             RGBColor[
             0.48102113339431596`, 0.5860746481117988, 0.9532481511982381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 391}], {
             RGBColor[
             0.6437626871937745, 0.7215472307661038, 0.9651855703710501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 93}], {
             RGBColor[
             0.5881904368683077, 0.6765585201837323, 0.9607236522842884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 94}], {
             RGBColor[
             0.3902079781037506, 0.5014845420037592, 0.9471706259178683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 119}], {
             RGBColor[
             0.47602089056047936`, 0.5838639549490319, 0.9523437043718453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 128}], {
             RGBColor[
             0.6973668791148635, 0.7623562224899008, 0.9713119028594868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 177}], {
             RGBColor[
             0.5902061647581469, 0.6781949788922101, 0.960882337767631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 200}], {
             RGBColor[
             0.5596306144327102, 0.6533723697251754, 0.9584753184440813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 225}], {
             RGBColor[
             0.7713067472201265, 0.8200722371607827, 0.935316292735275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 288}], {
             RGBColor[
             0.4917877456220666, 0.5975204123382014, 0.9533483544342872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 296}], {
             RGBColor[
             0.4820714489980445, 0.5891046445577414, 0.9527292406051883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 316}], {
             RGBColor[
             0.7108558569217315, 0.7731119672445488, 0.9725984936044585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 324}], {
             RGBColor[
             0.774512411877361, 0.8214550193575146, 0.8847497620662311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 355}], {
             RGBColor[
             0.5665861207059215, 0.6590191630597553, 0.9590228813767676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 360}], {
             RGBColor[
             0.4801163549545537, 0.5874112403631535, 0.9526046637415588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 374}], {
             RGBColor[
             0.7647851147631233, 0.782924791165464, 0.6497447002228691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 375}], {
             RGBColor[
             0.6851902704988069, 0.7527145687599504, 0.9701325365663209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 380}], {
             RGBColor[
             0.5711921750748972, 0.6627585654968742, 0.9593854868492264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 383}], {
             RGBColor[
             0.47969802435157355`, 0.5870489034207595, 0.9525780080854521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 390}], {
             RGBColor[
             0.7241510445066783, 0.7837131889365324, 0.9738666004650648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 41}], {
             RGBColor[
             0.5760553592879554, 0.6603692492600473, 0.9626879071058625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 55}], {
             RGBColor[
             0.6476038477124906, 0.7164696154280739, 0.936559346812813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 58}], {
             RGBColor[
             0.2732164525945304, 0.4032125731552233, 0.9389177176758228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.3327317234923245, 0.46261722813153555`, 0.9424223490911885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 87}], {
             RGBColor[
             0.5569780074058427, 0.6453892889318856, 0.960806779070416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 96}], {
             RGBColor[
             0.34903549210971363`, 0.4767387330566808, 0.943461210810632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 110}], {
             RGBColor[
             0.3744480953290634, 0.49874985269070526`, 0.9450804794162861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 146}], {
             RGBColor[
             0.5576436310372072, 0.6459092791716345, 0.960873122213384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 154}], {
             RGBColor[
             0.30577723088949815`, 0.43743601561581646`, 0.9407720058303664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 159}], {
             RGBColor[
             0.6297198760792928, 0.7031317786663508, 0.9668322459009842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 167}], {
             RGBColor[
             0.6372658889094052, 0.7087595826795867, 0.9540588144949543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 192}], {
             RGBColor[
             0.4709915919938916, 0.5778633049853241, 0.9524776288853395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 203}], {
             RGBColor[
             0.2606061309823421, 0.38995832560024385`, 0.9381995785153077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 228}], {
             RGBColor[
             0.3312766030484349, 0.46135687593951846`, 0.9423296301032162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 243}], {
             RGBColor[
             0.3547916905494565, 0.4817244628302403, 0.943827990685206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 332}], {
             RGBColor[
             0.535108990768143, 0.6283050469238323, 0.95862707986955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 348}], {
             RGBColor[
             0.3135393897412405, 0.4455945367182942, 0.9412140492938881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 361}], {
             RGBColor[
             0.37766032318017173`, 0.5015321230040691, 0.9452851597344973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 385}], {
             RGBColor[
             0.27631915156460596`, 0.4064737064952495, 0.9390944117921367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 57}], {
             RGBColor[
             0.6006933185422773, 0.6817094112263025, 0.9642578160830559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.9096647734010234, 0.9284657886367905, 0.9005705659383776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 96}], {
             RGBColor[
             0.6024397696141837, 0.6832220993656046, 0.9643690984010318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 114}], {
             RGBColor[
             0.8423870328914074, 0.8771605703134804, 0.984828821276606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 153}], {
             RGBColor[
             0.5868033907849379, 0.6696786539309633, 0.9633727621687391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 154}], {
             RGBColor[
             0.5591815083939682, 0.6439193819247404, 0.9616798934207662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 188}], {
             RGBColor[
             0.8973837618613234, 0.8807450567342016, 0.6516619578931759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 203}], {
             RGBColor[
             0.5140104084868121, 0.5964416919091677, 0.9591074661057075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 222}], {
             RGBColor[
             0.7272052786252265, 0.7866274761858758, 0.973606683453411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 258}], {
             RGBColor[
             0.8841443941938137, 0.9103760387517601, 0.9860131322599353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 312}], {
             RGBColor[
             0.7884634441016275, 0.8347494902117045, 0.9795300014522194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 327}], {
             RGBColor[
             0.5381857341639449, 0.6218514920000128, 0.9604842151388309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 356}], {
             RGBColor[
             0.6868997981634348, 0.7539056714057906, 0.9704336883876189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 361}], {
             RGBColor[
             0.6310646006846418, 0.708015489312993, 0.9661930473248972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 369}], {
             RGBColor[
             0.782564840595678, 0.8301414563218097, 0.9789420837803301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 104}], {
             RGBColor[
             0.5205788332912187, 0.620610742362107, 0.9556932461009442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 109}], {
             RGBColor[
             0.4961322178132587, 0.6007638786096222, 0.953768718979616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 136}], {
             RGBColor[
             0.5754670571447459, 0.6637283150551112, 0.9610009445991021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 205}], {
             RGBColor[
             0.4498985355017946, 0.5632292925055229, 0.9501290341484989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 207}], {
             RGBColor[
             0.44883849660335784`, 0.5623687051735637, 0.9500455840033636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 221}], {
             RGBColor[
             0.5918520541424317, 0.6765283992402927, 0.9626340479733289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 276}], {
             RGBColor[
             0.49526817609332197`, 0.6000624106167416, 0.9537006984503336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 358}], {
             RGBColor[
             0.36977759421631595`, 0.49470449937305494`, 0.9447828792153439]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 366}], {
             RGBColor[
             0.4574674586606481, 0.5693740853019827, 0.950724887505443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 376}], {
             RGBColor[
             0.5512481589703075, 0.6448083277307964, 0.9585870311675454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 124}], {
             RGBColor[
             0.6569875205412729, 0.7289606384433103, 0.9685390393988128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 137}], {
             RGBColor[
             0.4696148487514852, 0.5799499304672775, 0.9514838813322308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 199}], {
             RGBColor[
             0.34219043368972435`, 0.4647974990054305, 0.9432451927360078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 238}], {
             RGBColor[
             0.6282720687670866, 0.7060968867268224, 0.9657913316578237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 252}], {
             RGBColor[
             0.41638182881851726`, 0.5350707449885423, 0.9477524598336897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 277}], {
             RGBColor[
             0.5076995856807652, 0.6108688356043139, 0.9544820513322918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 293}], {
             RGBColor[
             0.6494735442497949, 0.7229691977099386, 0.9678223496323258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 299}], {
             RGBColor[
             0.3448753421335629, 0.46761950801293234`, 0.9433980942999183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 330}], {
             RGBColor[
             0.6723853378766398, 0.7412384400239147, 0.9700076969620539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 367}], {
             RGBColor[
             0.6839277906328671, 0.7504420785401968, 0.9711086264100122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 47}], {
             RGBColor[
             0.7538933060877353, 0.8059494981010722, 0.9343283694083611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 49}], {
             RGBColor[
             0.38671138908951136`, 0.5019233095774237, 0.9465970271869854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 54}], {
             RGBColor[
             0.7435267939995642, 0.7982181703593199, 0.9518761703542628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 93}], {
             RGBColor[
             0.5709931597682347, 0.6625969959053885, 0.9593698196352689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[
             0.6801696020147905, 0.748394698211557, 0.9699580702104673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 211}], {
             RGBColor[
             0.49583351573000933`, 0.6015790109717787, 0.953452977137732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 301}], {
             RGBColor[
             0.6116880746216407, 0.6947672139997093, 0.9631667558129824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 316}], {
             RGBColor[
             0.6936585798216585, 0.759150442966205, 0.971244660955439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 324}], {
             RGBColor[
             0.757315134777288, 0.8074934950791708, 0.8833959294172117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 328}], {
             RGBColor[
             0.7247537627185022, 0.7839448977518939, 0.9742105472591375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 362}], {
             RGBColor[
             0.5110245486221006, 0.6139117758218113, 0.9546488708935844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 372}], {
             RGBColor[
             0.5684452894655087, 0.6605285200133862, 0.9591692419518818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 380}], {
             RGBColor[
             0.5539948979748242, 0.6487970412185304, 0.958031654200207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 383}], {
             RGBColor[
             0.46250074725150053`, 0.5730873791424157, 0.9512241754364327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 390}], {
             RGBColor[
             0.7069537674066053, 0.7697516646581886, 0.9725127678160453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 91}], {
             RGBColor[
             0.5595050737869441, 0.6466716571962621, 0.9613246344071786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 97}], {
             RGBColor[
             0.6163021969328807, 0.6959358375658845, 0.9649411570043838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 100}], {
             RGBColor[
             0.7782694003515402, 0.8267092377119235, 0.9785342785521389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 112}], {
             RGBColor[
             0.8756750272473557, 0.9036564450193556, 0.9838391838562092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 141}], {
             RGBColor[
             0.9004147212263024, 0.9211730785101911, 0.900126408482584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 180}], {
             RGBColor[
             0.7147161224168723, 0.7766941858309103, 0.9724506294500983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 190}], {
             RGBColor[
             0.6944563138141462, 0.7602463605132408, 0.9708557031027676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 266}], {
             RGBColor[
             0.7258128965098223, 0.7857030469435432, 0.9733242081555182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 271}], {
             RGBColor[
             0.7246173130838783, 0.7847324184579423, 0.9732300874486615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 273}], {
             RGBColor[
             0.7053784062967354, 0.7691134072252658, 0.97171553023194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 350}], {
             RGBColor[
             0.49600052191087296`, 0.5799243467533673, 0.9577081441244019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 365}], {
             RGBColor[
             0.7202780677571289, 0.7812096236209128, 0.9728884861613605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 394}], {
             RGBColor[
             0.7373151827798348, 0.7947154916813254, 0.9744523448835141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 59}], {
             RGBColor[
             0.8258108036381346, 0.8642978560745316, 0.9584046736161747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 287}], {
             RGBColor[
             0.9085333223121755, 0.9291954174234214, 0.9665769432018609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 373}], {
             RGBColor[
             0.6367384332957389, 0.7076233688638354, 0.9441103669401152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 395}], {
             RGBColor[
             0.9291494302626929, 0.9456341422938214, 0.9685433259823981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 54}], {
             RGBColor[
             0.9730491202353633, 0.9794206585163251, 0.9305049889130382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 121}], {
             RGBColor[
             0.911338795461077, 0.9309103535791853, 0.9487439684339549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 128}], {
             RGBColor[
             0.9096919282505895, 0.9295971863685621, 0.9485868887692428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 130}], {
             RGBColor[
             0.8258303230127866, 0.8639546684515504, 0.940262631947202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.7168027638404271, 0.7757527896198493, 0.9314319339526896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 181}], {
             RGBColor[
             0.8685603843535609, 0.8973357171314578, 0.944521565126524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 265}], {
             RGBColor[
             0.9624090950451705, 0.9714853451509216, 0.9485157761970209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 311}], {
             RGBColor[
             0.9224014252034067, 0.9397313942486343, 0.9497991319345045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 322}], {
             RGBColor[
             0.9891376788373625, 0.9892828917413952, 0.7974240992106472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 362}], {
             RGBColor[
             0.7405468748578996, 0.7951142639788165, 0.9332776894523599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 56}], {
             RGBColor[
             0.5911613056869522, 0.6716124042321729, 0.9643979003269969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 71}], {
             RGBColor[
             0.3748192643760064, 0.49883536646943416`, 0.9451127701509446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 83}], {
             RGBColor[
             0.341600696981438, 0.4700631130060025, 0.9429961124105886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 103}], {
             RGBColor[
             0.5697458506736729, 0.6545363017116246, 0.9623552751100279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 108}], {
             RGBColor[
             0.3792315725240868, 0.5026570860182458, 0.9453939185244894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 120}], {
             RGBColor[
             0.5157706350095973, 0.6122628411870901, 0.9570040869082146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 143}], {
             RGBColor[
             0.5400989964239474, 0.6312683420263754, 0.9594289106125335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 196}], {
             RGBColor[
             0.5008813717157385, 0.6006312355393353, 0.9555200642911592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 231}], {
             RGBColor[
             0.3022491946159704, 0.43501344562013206`, 0.9405240165445419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 234}], {
             RGBColor[
             0.28498108852046034`, 0.4168635712525883, 0.9395406234482762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 286}], {
             RGBColor[
             0.44075820116647446`, 0.5526356466109577, 0.9502296532902288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 290}], {
             RGBColor[
             0.40046112123932764`, 0.519920661763337, 0.9470573195452962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 313}], {
             RGBColor[
             0.2849757990436411, 0.41685801167707914`, 0.9395403222203964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 320}], {
             RGBColor[
             0.5781750794665672, 0.6612575399457582, 0.9631592624771556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 331}], {
             RGBColor[
             0.3154946268039336, 0.44745134714748713`, 0.9413326567035694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 342}], {
             RGBColor[
             0.5628236221019415, 0.6490209923195762, 0.961693888926415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 343}], {
             RGBColor[
             0.4111818397188071, 0.528624223987842, 0.9479012937752865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 344}], {
             RGBColor[
             0.3619773362571528, 0.4877123337869579, 0.9442944938468825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 349}], {
             RGBColor[
             0.4675795259571827, 0.5744104063629669, 0.9523411262275032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 147}], {
             RGBColor[
             0.23021636994862782`, 0.3593023797498854, 0.9364218537427511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 211}], {
             RGBColor[
             0.35817392496758443`, 0.47875531060513526`, 0.9443504534751318]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 301}], {
             RGBColor[
             0.4740284838592157, 0.571943513633066, 0.9540642321503823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 328}], {
             RGBColor[
             0.5870941719560774, 0.6611211973852504, 0.9651080235965372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 347}], {
             RGBColor[
             0.35448622008592134`, 0.47576146565298943`, 0.9440601438383391]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 372}], {
             RGBColor[
             0.4307856987030838, 0.5377048196467429, 0.9500667182892816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 380}], {
             RGBColor[
             0.4163353072123992, 0.5259733408518871, 0.9489291305376067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 54}], {
             RGBColor[
             0.8744580906799098, 0.9023101204277666, 0.9636904313662225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 116}], {
             RGBColor[
             0.5385428153772489, 0.6279826210079933, 0.9596015196611152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 121}], {
             RGBColor[
             0.8127477659056234, 0.8537998154906268, 0.9819294108871391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.7272392934573331, 0.786844130362992, 0.9734480744003863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 135}], {
             RGBColor[
             0.8880517416111243, 0.9115049358927851, 0.898436705026999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 158}], {
             RGBColor[
             0.6182117342849736, 0.6986422515312908, 0.9646173764058739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 172}], {
             RGBColor[
             0.5265182219582761, 0.6153440109213957, 0.9589167368546965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 181}], {
             RGBColor[
             0.7699693547981072, 0.8202251790428992, 0.9777070075797083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 265}], {
             RGBColor[
             0.863818065489717, 0.8943748070623629, 0.9817012186502052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 276}], {
             RGBColor[
             0.6812018530541812, 0.7498654029956175, 0.9695527213986241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 322}], {
             RGBColor[
             0.890546649281909, 0.9121723536528367, 0.8306095416638314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 328}], {
             RGBColor[
             0.8556850593988476, 0.8880368478203404, 0.9860248082710972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 362}], {
             RGBColor[
             0.641955845302446, 0.7180037258902578, 0.9664631319055441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 364}], {
             RGBColor[
             0.5213929241755685, 0.6099569979891216, 0.9586248587281698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 59}], {
             RGBColor[
             0.7385517072273614, 0.7956814739776672, 0.9745755900844656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 136}], {
             RGBColor[
             0.7626099893619565, 0.8144759868309293, 0.9769734948102129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 194}], {
             RGBColor[
             0.8894667799017625, 0.9125347118627876, 0.895146874862266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 246}], {
             RGBColor[
             0.7459491779514059, 0.8014604343301506, 0.975312900832944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 376}], {
             RGBColor[
             0.7383910911875181, 0.7955559995066144, 0.9745595813786563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 377}], {
             RGBColor[
             0.8730350419233492, 0.8514216629672477, 0.6343232640584725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 395}], {
             RGBColor[
             0.8418903338519197, 0.8770177601969569, 0.984714242450689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 396}], {
             RGBColor[
             0.7339447495227696, 0.7920824836046647, 0.9741164115949394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 117}], {
             RGBColor[
             0.6165955363743625, 0.6984570252515784, 0.9637542949977423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 133}], {
             RGBColor[
             0.809542531613999, 0.8517938084147009, 0.9814778034464442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 174}], {
             RGBColor[
             0.5637266826358358, 0.6543388122043996, 0.9599229710608033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 223}], {
             RGBColor[
             0.5283410411604237, 0.6236895480924515, 0.9576682292762841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 260}], {
             RGBColor[
             0.693401488578628, 0.7604097800149054, 0.9700754382423422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 267}], {
             RGBColor[
             0.5120352142820712, 0.6092989036782672, 0.9566390256457211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 272}], {
             RGBColor[
             0.7611726145445106, 0.8133530986990872, 0.9768302307214414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 291}], {
             RGBColor[
             0.6971806948647732, 0.7633621246886736, 0.9704521142062544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 346}], {
             RGBColor[
             0.6073124587697638, 0.6909206046542848, 0.9630234971236746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 384}], {
             RGBColor[
             0.46532439305578066`, 0.5602028689323142, 0.9539789134793514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 68}], {
             RGBColor[
             0.6319685043390862, 0.697153042082782, 0.8630362782749815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 86}], {
             RGBColor[
             0.637592923494146, 0.7030646632235209, 0.8633565806252796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 95}], {
             RGBColor[
             0.67973469412032, 0.7419009888399155, 0.8659563123357337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 101}], {
             RGBColor[
             0.6439338088272129, 0.7097293357439247, 0.8637176846644986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 129}], {
             RGBColor[
             0.9678121060293978, 0.9742679667145235, 0.8835295828520545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 151}], {
             RGBColor[
             0.9169533374817349, 0.9339267354025218, 0.8860347022487431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 171}], {
             RGBColor[
             0.9335023796543416, 0.9471224924191752, 0.8876131646646708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 244}], {
             RGBColor[
             0.9142370076401211, 0.9317608077196282, 0.8857756162835537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 249}], {
             RGBColor[
             0.6311873853308925, 0.6963320364793647, 0.8629917947030269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 253}], {
             RGBColor[
             0.715274614369223, 0.7726838814711852, 0.8682208846272762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 270}], {
             RGBColor[
             0.6899501989534521, 0.7507491456801727, 0.8666072352704846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 308}], {
             RGBColor[
             0.7509734132369263, 0.8020585676130425, 0.8709226949645765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 386}], {
             RGBColor[
             0.7752315138438842, 0.8217523865007497, 0.8728323815047065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 397}], {
             RGBColor[
             0.825532046937629, 0.8623280905352237, 0.8769703527543042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 121}], {
             RGBColor[
             0.9009722833729059, 0.9231790258374329, 0.9662917693798565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 128}], {
             RGBColor[
             0.8993254161624185, 0.9218658586268098, 0.9661346897151446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 130}], {
             RGBColor[
             0.8154638109246155, 0.8562233407097981, 0.9578104328931036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 158}], {
             RGBColor[
             0.706436251752256, 0.768021461878097, 0.9489797348985913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 181}], {
             RGBColor[
             0.8581938722653898, 0.8896043893897054, 0.9620693660724258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 265}], {
             RGBColor[
             0.9520425829569994, 0.9637540174091692, 0.9660635771429226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 311}], {
             RGBColor[
             0.9120349131152357, 0.9320000665068819, 0.9673469328804061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 322}], {
             RGBColor[
             0.9787711667491914, 0.9815515639996428, 0.8149719001565487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 328}], {
             RGBColor[
             0.9439095768661302, 0.9574160581671467, 0.9703871667638146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 362}], {
             RGBColor[
             0.7301803627697285, 0.7873829362370641, 0.9508254903982616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 58}], {
             RGBColor[
             0.5981692185235359, 0.6657963056321738, 0.9336970449731732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 60}], {
             RGBColor[
             0.8307372974801108, 0.8679802889862884, 0.9504836191247981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 80}], {
             RGBColor[
             0.6576844894213298, 0.725200960608486, 0.9372016763885389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 87}], {
             RGBColor[
             0.881930773334848, 0.9079730214088362, 0.9555861063677664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 122}], {
             RGBColor[
             0.8016435808894219, 0.8450739234135685, 0.9477056198915563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 146}], {
             RGBColor[
             0.8825963969662125, 0.908493011648585, 0.9556524495107344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 159}], {
             RGBColor[
             0.954672642008298, 0.9657155111433013, 0.9616115731983346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.9378742652040677, 0.9523490410580053, 0.9609835597459748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 192}], {
             RGBColor[
             0.795944357922897, 0.8404470374622747, 0.9472569561826899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 201}], {
             RGBColor[
             0.9099974975695757, 0.9301208632409608, 0.9583246487631127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 210}], {
             RGBColor[
             0.862304895924761, 0.8926411368138834, 0.9536299823217809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 228}], {
             RGBColor[
             0.6562293689774403, 0.723940608416469, 0.9371089574005667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 385}], {
             RGBColor[
             0.6012719174936114, 0.6690574389722, 0.9338737390894871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 71}], {
             RGBColor[
             0.6597868335106258, 0.7312883614079544, 0.9687620181055507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 83}], {
             RGBColor[
             0.6265682661160575, 0.7025161079445228, 0.9666453603651946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 108}], {
             RGBColor[
             0.6641991416587063, 0.735110080956766, 0.9690431664790955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 120}], {
             RGBColor[
             0.8007382041442168, 0.8447158361256103, 0.9806533348628207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 143}], {
             RGBColor[
             0.8250665655585669, 0.8637213369648956, 0.9830781585671396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 196}], {
             RGBColor[
             0.785848940850358, 0.8330842304778556, 0.9791693122457652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 231}], {
             RGBColor[
             0.5872167637505898, 0.6674664405586523, 0.9641732644991479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 237}], {
             RGBColor[
             0.6061216934232292, 0.6848063143526195, 0.9653425228334019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 254}], {
             RGBColor[
             0.7300450590064502, 0.7885952347022249, 0.9742189314737963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 286}], {
             RGBColor[
             0.725725770301094, 0.785088641549478, 0.9738789012448348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 290}], {
             RGBColor[
             0.685428690373947, 0.7523736567018572, 0.9707065674999023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 320}], {
             RGBColor[
             0.8631426486011866, 0.8937105348842784, 0.9868085104317617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 331}], {
             RGBColor[
             0.600462195938553, 0.6799043420860074, 0.9649819046581755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 342}], {
             RGBColor[
             0.847791191236561, 0.8814739872580964, 0.9853431368810213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 343}], {
             RGBColor[
             0.6961494088534266, 0.7610772189263624, 0.9715505417298926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 344}], {
             RGBColor[
             0.6469449053917722, 0.7201653287254781, 0.9679437418014886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 349}], {
             RGBColor[
             0.7525470950918022, 0.8068634013014873, 0.9759903741821094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 92}], {
             RGBColor[
             0.6808984551508753, 0.7433225842941219, 0.8812325873251713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 114}], {
             RGBColor[
             0.6136207146412593, 0.6920173659708118, 0.9654908426633997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 153}], {
             RGBColor[
             0.35803707253478995`, 0.48453544958829464`, 0.9440347835555328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 188}], {
             RGBColor[
             0.6686174436111754, 0.6956018523915329, 0.6323239792799696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 195}], {
             RGBColor[
             0.44291329946316527`, 0.5564060389123977, 0.949897521416021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 208}], {
             RGBColor[
             0.4513844163854027, 0.5632832732493386, 0.9505643987708632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 258}], {
             RGBColor[
             0.6553780759436657, 0.7252328344090915, 0.9666751536467288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 278}], {
             RGBColor[
             0.5133820581000381, 0.6134246029340578, 0.9555757697244653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 284}], {
             RGBColor[
             0.5438132340555006, 0.6371976688759684, 0.9586088649481981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 327}], {
             RGBColor[
             0.30941941591379685`, 0.43670828765734415`, 0.9411462365256245]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 337}], {
             RGBColor[
             0.424935167978152, 0.5418105818672703, 0.9484822170494551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 354}], {
             RGBColor[
             0.3698733551756838, 0.4947874427029736, 0.9447889810189968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 392}], {
             RGBColor[
             0.6320700641875977, 0.7067283765048094, 0.9672505580930582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 60}], {
             RGBColor[
             0.4563499023621506, 0.5547232467134379, 0.9528419899878078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 80}], {
             RGBColor[
             0.28329709430336963`, 0.4119439183356355, 0.9395600472515486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 87}], {
             RGBColor[
             0.5075433782168879, 0.5947159791359856, 0.9579444772307761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 110}], {
             RGBColor[
             0.32501346614010856`, 0.44807654289480525`, 0.9422181775766463]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 159}], {
             RGBColor[
             0.5802852468903379, 0.6524584688704507, 0.9639699440613443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 167}], {
             RGBColor[
             0.5878312597204502, 0.6580862728836865, 0.9511965126553145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 192}], {
             RGBColor[
             0.42155696280493676`, 0.5271899951894241, 0.9496153270456996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 201}], {
             RGBColor[
             0.5356101024516156, 0.6168638209681103, 0.9606830196261225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 210}], {
             RGBColor[
             0.48791750080680074`, 0.5793840945410327, 0.9559883531847906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 228}], {
             RGBColor[
             0.28184197385948007`, 0.41068356614361845`, 0.9394673282635764]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 236}], {
             RGBColor[
             0.37872373729690245`, 0.4924160531071824, 0.9462433386304323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 243}], {
             RGBColor[
             0.30535706136050167`, 0.43105115303434016`, 0.9409656888455661]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 263}], {
             RGBColor[
             0.4953680273918492, 0.5852045025353718, 0.9567309520456588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 348}], {
             RGBColor[
             0.2641047605522857, 0.3949212269223941, 0.9383517474542482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 351}], {
             RGBColor[
             0.4741209374322735, 0.5686061143750868, 0.9546132406838328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 79}], {
             RGBColor[
             0.5104258716799817, 0.609436471197871, 0.9559916455129149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[
             0.839366403403794, 0.8733959169656103, 0.890153337547586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 237}], {
             RGBColor[
             0.5122829213771398, 0.6110449543075178, 0.9561099750774933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 246}], {
             RGBColor[
             0.6958488014534374, 0.7623216394329733, 0.9703193635182641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 254}], {
             RGBColor[
             0.6362062869603607, 0.7148338746571232, 0.9649863837178876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 349}], {
             RGBColor[
             0.6587083230457127, 0.7331020412563856, 0.9667578264262007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 373}], {
             RGBColor[
             0.49937896038699714`, 0.5998681918697937, 0.955287746093726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 395}], {
             RGBColor[
             0.7917899573539512, 0.8378789652997796, 0.979720705136009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 87}], {
             RGBColor[
             0.7401114571734628, 0.7968999624901002, 0.974731051382401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 122}], {
             RGBColor[
             0.6598242647280367, 0.7340008644948324, 0.9668505649061909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 146}], {
             RGBColor[
             0.7407770808048273, 0.7974199527298491, 0.974797394525369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 159}], {
             RGBColor[
             0.8128533258469128, 0.8546424522245654, 0.9807565182129692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 165}], {
             RGBColor[
             0.7960549490426825, 0.8412759821392694, 0.9801285047606094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 201}], {
             RGBColor[
             0.7681781814081905, 0.8190478043222249, 0.9774695937777473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 210}], {
             RGBColor[
             0.7204855797633758, 0.7815680778951473, 0.9727749273364155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 263}], {
             RGBColor[
             0.7279361063484242, 0.7873884858894864, 0.9735175261972836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 66}], {
             RGBColor[
             0.2681727500474425, 0.399196941807235, 0.9385834134379463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 98}], {
             RGBColor[
             0.31757624006546176`, 0.4442963164341426, 0.9416468326410867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 107}], {
             RGBColor[
             0.46072456997242095`, 0.5620248962001057, 0.9526631018415695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 131}], {
             RGBColor[
             0.3161389707217317, 0.4430514259678613, 0.9415552511094316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 215}], {
             RGBColor[
             0.2171435940014937, 0.34556206336757955`, 0.9356773784920007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 262}], {
             RGBColor[
             0.35568439016006026`, 0.47715482391702635`, 0.9441161798330836]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 269}], {
             RGBColor[
             0.35557512917169687`, 0.4770661209245215, 0.9441075784078434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 279}], {
             RGBColor[
             0.484544664395981, 0.5806333350032135, 0.9550372662422717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 297}], {
             RGBColor[
             0.5982549928985696, 0.6702540590616297, 0.9587356982090252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 298}], {
             RGBColor[
             0.3755796729740618, 0.4933067107777097, 0.945682409375024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 300}], {
             RGBColor[
             0.5429332325134846, 0.626354540007087, 0.9608283361715191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 306}], {
             RGBColor[
             0.39587166483801906`, 0.5097806639166862, 0.9472798693065702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 307}], {
             RGBColor[
             0.3832171039514282, 0.49950712130748043`, 0.9462836559183938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 314}], {
             RGBColor[
             0.424636438015998, 0.5331332026208339, 0.9495443376199767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 352}], {
             RGBColor[
             0.4867736554966661, 0.5823746397920285, 0.9552594312440819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 77}], {
             RGBColor[
             0.37181821762115086`, 0.49647198480160837`, 0.9449129059342476]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 204}], {
             RGBColor[
             0.33839705058122904`, 0.46752424970832585`, 0.9427833387236414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 345}], {
             RGBColor[
             0.4957521236868072, 0.5979732277409879, 0.9545291034469267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 370}], {
             RGBColor[
             0.32903004383668377`, 0.4594110192656488, 0.9421864813367978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 389}], {
             RGBColor[
             0.3197784442042102, 0.45125078628805804`, 0.9416023586015416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 400}], {
             RGBColor[
             0.31994623696975744`, 0.451427147123324, 0.9416119141513123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 90}], {
             RGBColor[
             0.329971160419706, 0.4601432731016224, 0.9422494836103745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 138}], {
             RGBColor[
             0.5574173677967451, 0.6450209845750492, 0.9611196766485999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 142}], {
             RGBColor[
             0.43185150776159803`, 0.545602827762682, 0.9495104592815573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 152}], {
             RGBColor[
             0.37145951910026875`, 0.4960784041251868, 0.9448930851387849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 156}], {
             RGBColor[
             0.3880496133708574, 0.5100424766434235, 0.9460622137034923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 202}], {
             RGBColor[
             0.6223596692491328, 0.696668954822919, 0.966294949272708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 214}], {
             RGBColor[
             0.39192370638030954`, 0.513187639874398, 0.9463671964964666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 217}], {
             RGBColor[
             0.42099374482107527`, 0.5367880066709193, 0.9486556964095832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 242}], {
             RGBColor[
             0.6259336451900184, 0.6993344202277831, 0.9602451402470025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 256}], {
             RGBColor[
             0.30799666904596, 0.4410544056569774, 0.9408513267107033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 257}], {
             RGBColor[
             0.6219277093280866, 0.6963467998210724, 0.9670261447458484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 261}], {
             RGBColor[
             0.3880496133708574, 0.5100424766434235, 0.9460622137034923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 264}], {
             RGBColor[
             0.4029870111732741, 0.5221693291015278, 0.9472381403759896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 268}], {
             RGBColor[
             0.6437561322390939, 0.7126264018873394, 0.9300763185220029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 317}], {
             RGBColor[
             0.6513896706015462, 0.716535525076532, 0.8372654799469499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 381}], {
             RGBColor[
             0.435698973686098, 0.5487263739265558, 0.9498133458928661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 82}], {
             RGBColor[
             0.6009433964428095, 0.6851668128139775, 0.9628900004955714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 151}], {
             RGBColor[
             0.6463728098131769, 0.7208362536819383, 0.9673703094918604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 157}], {
             RGBColor[
             0.5240076806958338, 0.624376541401065, 0.9556918186463865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 171}], {
             RGBColor[
             0.6629218519857836, 0.7340320106985918, 0.968948771907788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 182}], {
             RGBColor[
             0.41534422867756493`, 0.5341720278977489, 0.947686344870222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 253}], {
             RGBColor[
             0.44469408670066507`, 0.5595933997506016, 0.9495564918703935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 105}], {
             RGBColor[
             0.9868068807885075, 0.9888123204054189, 0.8683076582398725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 113}], {
             RGBColor[
             0.8790495387936097, 0.9052098985965437, 0.9309831872417701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 148}], {
             RGBColor[
             0.7263178071320948, 0.783205026009475, 0.9175992665518485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 161}], {
             RGBColor[
             0.9214574943916046, 0.9386389629279797, 0.9351304988023043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 168}], {
             RGBColor[
             0.6159634125863849, 0.6821921221504111, 0.9106787853724962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 170}], {
             RGBColor[
             0.8343396188230967, 0.8702821693076017, 0.9265269202570665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 180}], {
             RGBColor[
             0.8021379205409714, 0.8447592097319854, 0.9235681036176221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 239}], {
             RGBColor[
             0.8655658600522012, 0.8946763462840013, 0.9296392601569684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 251}], {
             RGBColor[
             0.6642979344222542, 0.7298519893565857, 0.9135464374513593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 282}], {
             RGBColor[
             0.7025183692089757, 0.7629566089539355, 0.9159818097589658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 312}], {
             RGBColor[
             0.8666626294758559, 0.8955331508935168, 0.9297485758832253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 326}], {
             RGBColor[
             0.7379773393552235, 0.7926707595241516, 0.918517147638727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 356}], {
             RGBColor[
             0.7650989835376631, 0.8146893320876027, 0.9206522628186249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[
             0.33318048988094795`, 0.4606973723568, 0.9425354715836598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 107}], {
             RGBColor[
             0.47632881978790714`, 0.578425952122763, 0.9535517407841426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 131}], {
             RGBColor[
             0.3317432205372179, 0.4594524818905187, 0.9424438900520047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 215}], {
             RGBColor[
             0.23274784381697988`, 0.36196311929023695`, 0.9365660174345738]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 297}], {
             RGBColor[
             0.6138592427140559, 0.6866551149842872, 0.9596243371515982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 307}], {
             RGBColor[
             0.3988213537669144, 0.5159081772301378, 0.9471722948609669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 314}], {
             RGBColor[
             0.4402406878314842, 0.5495342585434912, 0.9504329765625498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 352}], {
             RGBColor[
             0.5023779053121523, 0.5987756957146859, 0.9561480701866549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 85}], {
             RGBColor[
             0.64699432785923, 0.7201112614210958, 0.9679914876393205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 127}], {
             RGBColor[
             0.5632769096040571, 0.6542340105744979, 0.9597737841141387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 139}], {
             RGBColor[
             0.33379995103723337`, 0.45834743362262287`, 0.9426806314510242]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 184}], {
             RGBColor[
             0.5483386367798988, 0.642564118309187, 0.9582848766851231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 305}], {
             RGBColor[
             0.4061018771982353, 0.5261667675804459, 0.9470974304066496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 325}], {
             RGBColor[
             0.5359134097762386, 0.632857436538705, 0.9570464461777464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 86}], {
             RGBColor[
             0.27786393419754607`, 0.40938299080555823`, 0.9391353120384724]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 95}], {
             RGBColor[
             0.32000570482372004`, 0.44821931642195295`, 0.9417350437489265]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 129}], {
             RGBColor[
             0.6080831167327978, 0.6805862942965609, 0.9593083142652473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 151}], {
             RGBColor[
             0.5572243481851351, 0.6402450629845591, 0.961813433661936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 178}], {
             RGBColor[
             0.48950659201991487`, 0.5871637993275802, 0.9551116309522616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 229}], {
             RGBColor[
             0.28420481953061294`, 0.4160476633259621, 0.9394964160776914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 249}], {
             RGBColor[
             0.2714583960342926, 0.4026503640614021, 0.9387705261162197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 308}], {
             RGBColor[
             0.39124442394032644`, 0.5083768951950799, 0.9467014263777693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 309}], {
             RGBColor[
             0.2896478162535745, 0.4217685979877193, 0.939806386688872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 319}], {
             RGBColor[
             0.3526303864133147, 0.47647717585068483`, 0.9438138596109422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 334}], {
             RGBColor[
             0.28418093692845725`, 0.416022561196852, 0.9394950559988298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 371}], {
             RGBColor[
             0.5610927403478851, 0.643329613890428, 0.9621824043597735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 386}], {
             RGBColor[
             0.4155025245472843, 0.5280707140827869, 0.9486111129178993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 74}], {
             RGBColor[
             0.29420950411494207`, 0.4240572242000998, 0.9401579248887129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 97}], {
             RGBColor[
             0.37872024528550263`, 0.5024501742584727, 0.9453526970337967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 100}], {
             RGBColor[
             0.5406874487041622, 0.6332235744045117, 0.9589458185815518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 132}], {
             RGBColor[
             0.624891162511616, 0.6997635008330207, 0.9671369509690663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 140}], {
             RGBColor[
             0.47543344654181807`, 0.5818277979787178, 0.9527282822383505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 141}], {
             RGBColor[
             0.6628327695789245, 0.7276874152027795, 0.8805379485119968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 168}], {
             RGBColor[
             0.2909596628149077, 0.4206414349419243, 0.9399728512343853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 191}], {
             RGBColor[
             0.6286972402879942, 0.7027983639386757, 0.967499978065103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 216}], {
             RGBColor[
             0.36917566909511734`, 0.494183142086709, 0.9447445250788826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 219}], {
             RGBColor[
             0.6463190459389998, 0.7163056969219965, 0.9503263017783287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 220}], {
             RGBColor[
             0.46484129318962664`, 0.5732286107163379, 0.9518944291261298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 350}], {
             RGBColor[
             0.25841857026349496`, 0.38643868344595556`, 0.9381196841538147]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 357}], {
             RGBColor[
             0.5520244920744485, 0.6420801588501004, 0.960075789114008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 394}], {
             RGBColor[
             0.4997332311324567, 0.6012298283739136, 0.954863884912927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 75}], {
             RGBColor[
             0.5438664179233594, 0.6404381464754794, 0.9572719185816685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 103}], {
             RGBColor[
             0.7363633358511492, 0.7940346250943657, 0.9743596072206946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 133}], {
             RGBColor[
             0.7701488245488135, 0.8209742566992232, 0.9775820972933397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.5525302846429125, 0.6476080021356059, 0.9579163544736635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 164}], {
             RGBColor[
             0.7945307601988778, 0.840056435672901, 0.9674500024374728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 227}], {
             RGBColor[
             0.5556086208962634, 0.650107134183544, 0.9581586923798445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 234}], {
             RGBColor[
             0.45159857369793666`, 0.5563618946353295, 0.9515449555589429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 280}], {
             RGBColor[
             0.8166100833062704, 0.8536424705427086, 0.7651871020295968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 346}], {
             RGBColor[
             0.5679187517045783, 0.6601010529388072, 0.95912779097057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 79}], {
             RGBColor[
             0.3879226024151251, 0.510420793480234, 0.9459390630927713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 109}], {
             RGBColor[
             0.5106715042676443, 0.6133570777706259, 0.9546951494559033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 120}], {
             RGBColor[
             0.5843961628332708, 0.6719387983628715, 0.9613682046867684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 143}], {
             RGBColor[
             0.6087245242476209, 0.6909442992021568, 0.9637930283910874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 237}], {
             RGBColor[
             0.3897796521122833, 0.5120292765898806, 0.9460573926573497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 286}], {
             RGBColor[
             0.5093837289901479, 0.6123116037867391, 0.9545937710687826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 320}], {
             RGBColor[
             0.6468006072902408, 0.7209334971215396, 0.9675233802557094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 321}], {
             RGBColor[
             0.5106715042676443, 0.6133570777706259, 0.9546951494559033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 343}], {
             RGBColor[
             0.47980736754248066`, 0.5883001811636235, 0.9522654115538404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 382}], {
             RGBColor[
             0.5789015117457789, 0.6676463351724278, 0.960820549216801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 119}], {
             RGBColor[
             0.5557461840532665, 0.6474265054436997, 0.9594144607479997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 200}], {
             RGBColor[
             0.6393559079254973, 0.7169349202198433, 0.9655460748202358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 288}], {
             RGBColor[
             0.5715130391148537, 0.6610829628328692, 0.9604191108104416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 341}], {
             RGBColor[
             0.6850602238188732, 0.7538935205886248, 0.9692440589246408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 355}], {
             RGBColor[
             0.6463114141987087, 0.722581713554423, 0.966093637752922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 374}], {
             RGBColor[
             0.8445104082559104, 0.8464873416601317, 0.6568154565990236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 375}], {
             RGBColor[
             0.764915563991594, 0.8162771192546181, 0.9772032929424753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 379}], {
             RGBColor[
             0.7823133722845765, 0.8300820158812596, 0.9788806619218464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 393}], {
             RGBColor[
             0.791664310851812, 0.8375382004703076, 0.9797725627900707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 399}], {
             RGBColor[
             0.6310870566817235, 0.7102218942726441, 0.9648951205605258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 85}], {
             RGBColor[
             0.8517834516073058, 0.8846530195385464, 0.9857250600820104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 96}], {
             RGBColor[
             0.6000204316501929, 0.6812929849442979, 0.9641383397862578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 110}], {
             RGBColor[
             0.6254330348695426, 0.7033041045783225, 0.9657576083919122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 115}], {
             RGBColor[
             0.7109631875228271, 0.7734764280588764, 0.9722877470771683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 184}], {
             RGBColor[
             0.7531277605279747, 0.8071058764266377, 0.976018449127813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 188}], {
             RGBColor[
             0.8949644238973327, 0.878815942312895, 0.6514311992784021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 195}], {
             RGBColor[
             0.6692602797493226, 0.7396201288337597, 0.9690047414144534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 203}], {
             RGBColor[
             0.5115910705228213, 0.594512577487861, 0.9588767074909336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 206}], {
             RGBColor[
             0.6594581775736647, 0.7316623407078899, 0.9682330840249023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 208}], {
             RGBColor[
             0.6777313966715599, 0.7464973631707006, 0.9696716187692955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 258}], {
             RGBColor[
             0.8817250562298229, 0.9084469243304534, 0.9857823736451612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 284}], {
             RGBColor[
             0.7701602143416578, 0.8204117587973303, 0.9777160849466304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 348}], {
             RGBColor[
             0.5645243292817197, 0.6501487886059114, 0.9618911782695141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 369}], {
             RGBColor[
             0.7801455026316872, 0.8282123419005031, 0.9787113251655561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 392}], {
             RGBColor[
             0.8584170444737549, 0.8899424664261714, 0.9863577780914905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 132}], {
             RGBColor[
             0.5832501586286303, 0.6585021625174985, 0.9646738005757265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 140}], {
             RGBColor[
             0.4337924426588324, 0.5405664596631955, 0.9502651318450107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 191}], {
             RGBColor[
             0.5870562364050085, 0.6615370256231534, 0.9650368276717632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 198}], {
             RGBColor[
             0.36944605142604275`, 0.488327160488526, 0.945199548218568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 216}], {
             RGBColor[
             0.32753466521213165`, 0.45292180377118674`, 0.942281374685543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 219}], {
             RGBColor[
             0.6046780420560142, 0.6750443586064743, 0.9478631513849889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 220}], {
             RGBColor[
             0.4232002893066409, 0.5319672724008156, 0.9494312787327901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 224}], {
             RGBColor[
             0.4519804670359838, 0.5551939365285172, 0.9517915713791534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 302}], {
             RGBColor[
             0.2621946086719555, 0.3929135361855428, 0.9382429671304799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 311}], {
             RGBColor[
             0.5569778591576178, 0.6375533440618844, 0.9621679251986228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 323}], {
             RGBColor[
             0.6542461789701377, 0.4105407393815716, 0.4461534460399658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 340}], {
             RGBColor[
             0.4553494029311492, 0.5578257748546815, 0.9521273554246875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 357}], {
             RGBColor[
             0.5103834881914628, 0.6008188205345781, 0.9576126387206683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 89}], {
             RGBColor[
             0.42715533767195113`, 0.5444022168650873, 0.9484389382911906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 133}], {
             RGBColor[
             0.6745865355648873, 0.7432563471155678, 0.970096699281284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 145}], {
             RGBColor[
             0.4569679956589865, 0.5698900925519504, 0.9504309564616078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.6202531120790329, 0.7001569008631615, 0.9648547399688336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 164}], {
             RGBColor[
             0.6989684712149518, 0.7623385260892455, 0.9599646044254171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 169}], {
             RGBColor[
             0.45411238539209475`, 0.5675717794935112, 0.9502061523609531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 209}], {
             RGBColor[
             0.37353267395628015`, 0.49703379948044946`, 0.9450559510306461]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 227}], {
             RGBColor[
             0.46004633191233735`, 0.5723892245998885, 0.9506732943677888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 280}], {
             RGBColor[
             0.7210477943223443, 0.775924560959053, 0.7577017040175411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 315}], {
             RGBColor[
             0.3658962411460195, 0.48900742441906053`, 0.9446210674791917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[
             0.557880962451248, 0.651951923425701, 0.9583375794309144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 109}], {
             RGBColor[
             0.5334343469732881, 0.6321050596732163, 0.9564130523095862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 138}], {
             RGBColor[
             0.647977891731887, 0.7225748043944371, 0.9671545526419876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 144}], {
             RGBColor[
             0.7420397154661247, 0.7939770790511607, 0.8309653152893506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 207}], {
             RGBColor[
             0.4861406257633871, 0.5937098862371578, 0.9526899173333336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 233}], {
             RGBColor[
             0.6078493652366516, 0.691226094508262, 0.9631549161433435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 242}], {
             RGBColor[
             0.7164941691251604, 0.776888240047171, 0.9662800162403902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 257}], {
             RGBColor[
             0.7124882332632286, 0.7739006196404603, 0.973061020739236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 317}], {
             RGBColor[
             0.7419501945366882, 0.7940893448959199, 0.8433003559403376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 358}], {
             RGBColor[
             0.4070797233763453, 0.526045680436649, 0.947427212545314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 366}], {
             RGBColor[
             0.49476958782067737`, 0.6007152663655768, 0.953369220835413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 382}], {
             RGBColor[
             0.6016643544514226, 0.6863943170750182, 0.9625384520704838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 78}], {
             RGBColor[
             0.35936404196033794`, 0.48556886860968007`, 0.9441235818295157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 102}], {
             RGBColor[
             0.3254886263037715, 0.44996365892922363`, 0.9421944270220608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 111}], {
             RGBColor[
             0.3824427413794447, 0.5056744132769515, 0.9455898911932286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 160}], {
             RGBColor[
             0.576569541904789, 0.6644566417293041, 0.9611670976702555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 166}], {
             RGBColor[
             0.35310560619742937`, 0.47899085581511724`, 0.9437671731713442]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 185}], {
             RGBColor[
             0.40522897777530886`, 0.5254107059735076, 0.9470418100272954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 370}], {
             RGBColor[
             0.3684478488272642, 0.4935527407520049, 0.9446981490150013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 389}], {
             RGBColor[
             0.35919624919479065`, 0.4853925077744141, 0.944114026279745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 400}], {
             RGBColor[
             0.35936404196033794`, 0.48556886860968007`, 0.9441235818295157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 102}], {
             RGBColor[
             0.27361664565237814`, 0.4049188212509393, 0.9388934352391255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 144}], {
             RGBColor[
             0.6513005073151132, 0.7162354507916604, 0.8249202634942088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 160}], {
             RGBColor[
             0.5246975612533957, 0.6194118040510198, 0.9578661058873202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 185}], {
             RGBColor[
             0.35335699712391544`, 0.4803658682952233, 0.9437408182443601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 207}], {
             RGBColor[
             0.39540141761237574`, 0.5159682579776574, 0.9466448655381918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 213}], {
             RGBColor[
             0.5958287139330609, 0.675498755233652, 0.9648181330420931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 230}], {
             RGBColor[
             0.4233334453765132, 0.5386447364400953, 0.9488437770821738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 247}], {
             RGBColor[
             0.3625336249837176, 0.48831420211665677`, 0.9443255448570133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 289}], {
             RGBColor[
             0.3346183427316386, 0.4641353876927878, 0.9425468077564256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 370}], {
             RGBColor[
             0.3165758681758709, 0.44850790307372057`, 0.941397157232066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 391}], {
             RGBColor[
             0.47908206902479245`, 0.5837766348314537, 0.9533195799229842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 400}], {
             RGBColor[
             0.3074920613089446, 0.44052403093139575`, 0.9408225900465804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 109}], {
             RGBColor[
             0.4551493144830895, 0.5652665476056442, 0.9511573246191762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 120}], {
             RGBColor[
             0.5288739730487161, 0.6238482681978899, 0.9578303798500413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 136}], {
             RGBColor[
             0.5344841538145767, 0.6282309840511332, 0.9583895502386622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 237}], {
             RGBColor[
             0.33425746232772857`, 0.46393874642489896`, 0.9425195678206225]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 246}], {
             RGBColor[
             0.5178233424040262, 0.6152154315503545, 0.9567289562613933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 254}], {
             RGBColor[
             0.4581808279109495, 0.5677276667745044, 0.9513959764610169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 286}], {
             RGBColor[
             0.45386153920559325`, 0.5642210736217574, 0.9510559462320554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 320}], {
             RGBColor[
             0.591278417505686, 0.672842966956558, 0.9639855554189822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 343}], {
             RGBColor[
             0.42428517775792585`, 0.5402096509986418, 0.9487275867171132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 349}], {
             RGBColor[
             0.48068286399630145`, 0.5859958333737667, 0.95316741916933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 87}], {
             RGBColor[
             0.5670586491146818, 0.6541206341122978, 0.9614491086461419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 96}], {
             RGBColor[
             0.35911613381855284`, 0.485470078237093, 0.9441035403863578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 110}], {
             RGBColor[
             0.3845287370379026, 0.5074811978711175, 0.945722808992012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 146}], {
             RGBColor[
             0.5677242727460463, 0.6546406243520467, 0.9615154517891098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 154}], {
             RGBColor[
             0.3158578725983373, 0.44616736079622865`, 0.9414143354060922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 159}], {
             RGBColor[
             0.6398005177881319, 0.711863123846763, 0.96747457547671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 167}], {
             RGBColor[
             0.6473465306182442, 0.7174909278599988, 0.9547011440706801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 192}], {
             RGBColor[
             0.4810722337027308, 0.5865946501657363, 0.9531199584610652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 201}], {
             RGBColor[
             0.5951253733494095, 0.6762684759444225, 0.9641876510414882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 203}], {
             RGBColor[
             0.2706867726911813, 0.39868967078065604`, 0.9388419080910335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 228}], {
             RGBColor[
             0.34135724475727414`, 0.47008822111993065`, 0.9429719596789421]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 243}], {
             RGBColor[
             0.3648723322582957, 0.49045580801065247`, 0.9444703202609317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 332}], {
             RGBColor[
             0.5451896324769823, 0.6370363921042445, 0.9592694094452758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 348}], {
             RGBColor[
             0.3236200314500797, 0.4543258818987064, 0.9418563788696139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 361}], {
             RGBColor[
             0.3877409648890109, 0.5102634681844813, 0.9459274893102231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 385}], {
             RGBColor[
             0.28639979327344517`, 0.4152050516756617, 0.9397367413678626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 89}], {
             RGBColor[
             0.307439478150547, 0.4314763606441757, 0.9411488514030586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 163}], {
             RGBColor[
             0.5005372525576288, 0.58723104464225, 0.9575646530807016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 169}], {
             RGBColor[
             0.3343965258706906, 0.4546459232725998, 0.942916065472821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 209}], {
             RGBColor[
             0.25381681443487597`, 0.38410794325953795`, 0.9377658641425142]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 227}], {
             RGBColor[
             0.34033047239093317`, 0.45946336837897706`, 0.9433832074796569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 240}], {
             RGBColor[
             0.414951483786949, 0.5200440670685171, 0.9492576468425226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 245}], {
             RGBColor[
             0.4094685154728096, 0.5155927463861911, 0.9488260074920588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 248}], {
             RGBColor[
             0.38307739628230153`, 0.4941672469209658, 0.946748401915527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 292}], {
             RGBColor[
             0.3224694615385071, 0.44449457682589666`, 0.942106548654047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 304}], {
             RGBColor[
             0.4666662306777982, 0.5607707449204257, 0.9541887061624158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 315}], {
             RGBColor[
             0.2461803816246153, 0.3760815681981491, 0.9373309805910597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 329}], {
             RGBColor[
             0.3089098001001903, 0.43274987961642686`, 0.9412425390175353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 353}], {
             RGBColor[
             0.23057359402317107`, 0.3596778449015448, 0.9364421971253307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 378}], {
             RGBColor[
             0.4962514791687499, 0.5838829658977737, 0.9571374872421277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 151}], {
             RGBColor[
             0.7967797679574162, 0.8413493154363382, 0.9803315486394085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 157}], {
             RGBColor[
             0.6744146388400731, 0.7448896031554649, 0.9686530577939347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 171}], {
             RGBColor[
             0.8133288101300229, 0.8545450724529917, 0.981910011055336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 182}], {
             RGBColor[
             0.5657511868218043, 0.6546850896521488, 0.9606475840177701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 253}], {
             RGBColor[
             0.5951010448449043, 0.6801064615050015, 0.9625177310179416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 108}], {
             RGBColor[
             0.414638532953192, 0.5335607897305955, 0.9476413785626872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 120}], {
             RGBColor[
             0.5511775954387025, 0.6431665448994398, 0.9592515469464122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 125}], {
             RGBColor[
             0.38080126460714203`, 0.5042526485998045, 0.9454852977447984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 179}], {
             RGBColor[
             0.33590973730196394`, 0.4640815535551911, 0.9426720206758628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 196}], {
             RGBColor[
             0.5362883321448437, 0.6315349392516851, 0.9577675243293569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 231}], {
             RGBColor[
             0.3376561550450756, 0.46591714933248185`, 0.9427714765827395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 237}], {
             RGBColor[
             0.35656108471771497`, 0.483257023126449, 0.9439407349169935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 246}], {
             RGBColor[
             0.5401269647940126, 0.6345337082519045, 0.9581501233577643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 254}], {
             RGBColor[
             0.4804844503009359, 0.5870459434760544, 0.952817143557388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 303}], {
             RGBColor[
             0.5932505250869285, 0.6760342373067425, 0.963444983379866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 313}], {
             RGBColor[
             0.32038275947274636`, 0.447761715389429, 0.941787782258594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 344}], {
             RGBColor[
             0.39738429668625797`, 0.5186160374993076, 0.9465419538850801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 349}], {
             RGBColor[
             0.502986486386288, 0.6053141100753168, 0.954588586265701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.3529620592030486, 0.48013972811792704`, 0.9437114081936924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 152}], {
             RGBColor[
             0.39445041788361135`, 0.5160748591414914, 0.9463550097221027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 156}], {
             RGBColor[
             0.4110405121542, 0.5300389316597283, 0.9475241382868101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 175}], {
             RGBColor[
             0.48027339319541157`, 0.5862453033947319, 0.9529744042907738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 204}], {
             RGBColor[
             0.3491124579196282, 0.47680539697281465`, 0.9434661150039816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 256}], {
             RGBColor[
             0.3309875678293026, 0.46105086067328205`, 0.9423132512940211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 261}], {
             RGBColor[
             0.4110405121542, 0.5300389316597283, 0.9475241382868101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 264}], {
             RGBColor[
             0.4259779099566167, 0.5421657841178324, 0.9487000649593075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 317}], {
             RGBColor[
             0.6743805693848888, 0.7365319800928367, 0.8387274045302677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 333}], {
             RGBColor[
             0.672633876304771, 0.7358096776162433, 0.8676746291646096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 381}], {
             RGBColor[
             0.4586898724694406, 0.5687228289428605, 0.951275270476184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 389}], {
             RGBColor[
             0.3304938515426093, 0.46053193355254685`, 0.9422851348818817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 96}], {
             RGBColor[
             0.627182922393055, 0.7029516177564865, 0.9667291224015537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 110}], {
             RGBColor[
             0.6525955256124047, 0.7249627373905111, 0.968348391007208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 115}], {
             RGBColor[
             0.7381256782656892, 0.795135060871065, 0.9748785296924642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 139}], {
             RGBColor[
             0.5657515655281714, 0.644547824552262, 0.96300498650901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 167}], {
             RGBColor[
             0.9154133191927465, 0.9349724673793924, 0.9773267260858762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 184}], {
             RGBColor[
             0.7802902512708368, 0.8287645092388263, 0.978609231743109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 188}], {
             RGBColor[
             0.9221269146401947, 0.9004745751250836, 0.654021981893698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 203}], {
             RGBColor[
             0.5387535612656835, 0.6161712103000496, 0.9614674901062294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 258}], {
             RGBColor[
             0.9088875469726851, 0.930105557142642, 0.9883731562604572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 284}], {
             RGBColor[
             0.79732270508452, 0.8420703916095189, 0.9803068675619264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 325}], {
             RGBColor[
             0.7678650242671766, 0.819057827468344, 0.9773708012357322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 348}], {
             RGBColor[0.591686820024582, 0.6718074214181, 0.96448196088481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 351}], {
             RGBColor[
             0.8017029969045697, 0.8454923088707926, 0.9807434541143946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 369}], {
             RGBColor[
             0.8073079933745493, 0.8498709747126917, 0.9813021077808521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 95}], {
             RGBColor[
             0.32563012397877966`, 0.45413093756269185`, 0.9420553460992246]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 151}], {
             RGBColor[
             0.5628487673401947, 0.646156684125298, 0.9621337360122342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[
             0.4951310111749745, 0.5930754204683191, 0.9554319333025598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 229}], {
             RGBColor[
             0.2898292386856726, 0.421959284466701, 0.9398167184279895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 249}], {
             RGBColor[
             0.2770828151893523, 0.408561985202141, 0.9390908284665178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 308}], {
             RGBColor[
             0.39686884309538606`, 0.5142885163358188, 0.9470217287280674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 309}], {
             RGBColor[
             0.2952722354086342, 0.4276802191284582, 0.9401266890391702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 334}], {
             RGBColor[
             0.2898053560835169, 0.4219341823375909, 0.939815358349128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 371}], {
             RGBColor[
             0.5667171595029448, 0.6492412350311669, 0.9625027067100718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 386}], {
             RGBColor[
             0.421126943702344, 0.5339823352235259, 0.9489314152681976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 110}], {
             RGBColor[
             0.6087750209514208, 0.6902532586714676, 0.9641072389712396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 134}], {
             RGBColor[
             0.682582240404538, 0.7509083768680034, 0.9697145054124594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 159}], {
             RGBColor[
             0.86404680170165, 0.8946351846471131, 0.9858590054559376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 167}], {
             RGBColor[
             0.8715928145317624, 0.9002629886603489, 0.9730855740499078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 192}], {
             RGBColor[
             0.705318517616249, 0.7693667109660864, 0.971504388440293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 201}], {
             RGBColor[
             0.8193716572629277, 0.8590405367447727, 0.9825720810207158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 210}], {
             RGBColor[
             0.771679055618113, 0.821560810317695, 0.9778774145793839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 228}], {
             RGBColor[
             0.5656035286707923, 0.6528602819202808, 0.9613563896581696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 236}], {
             RGBColor[
             0.6624852921082147, 0.7345927688838447, 0.9681324000250255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 243}], {
             RGBColor[
             0.5891186161718138, 0.6732278688110025, 0.9628547502401594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 263}], {
             RGBColor[
             0.7791295822031614, 0.8273812183120342, 0.9786200134402521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 348}], {
             RGBColor[
             0.5478663153635979, 0.6370979426990565, 0.9602408088488416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 351}], {
             RGBColor[
             0.7578824922435857, 0.8107828301517491, 0.9765023020784261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[
             0.584402281313068, 0.6699524792487992, 0.9622115419492455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 132}], {
             RGBColor[
             0.6552476548025516, 0.7260567686937631, 0.9690712398146526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 140}], {
             RGBColor[
             0.5057899388327537, 0.60812106583946, 0.9546625710839367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 168}], {
             RGBColor[
             0.3213161551058433, 0.4469347028026667, 0.9419071400799717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 282}], {
             RGBColor[
             0.40787111172843404`, 0.5276991896061909, 0.9472101644664412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 283}], {
             RGBColor[
             0.3282750061357582, 0.454248896451746, 0.9423034363514278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 357}], {
             RGBColor[
             0.5823809843653841, 0.6683734267108428, 0.9620100779595944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 163}], {
             RGBColor[
             0.5991043208115509, 0.6818388808364249, 0.9635071576904115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 164}], {
             RGBColor[
             0.6778196799474696, 0.7440205060625087, 0.958617022146995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 169}], {
             RGBColor[
             0.4329635941246126, 0.5492537594667746, 0.9488585700825309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 209}], {
             RGBColor[
             0.35238388268879806`, 0.4787157794537127, 0.943708368752224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 227}], {
             RGBColor[
             0.4388975406448552, 0.5540712045731518, 0.9493257120893667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 245}], {
             RGBColor[
             0.5080355837267316, 0.6102005825803658, 0.9547685121017686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.6998990030548622, 0.7576065409323163, 0.756354121739119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 292}], {
             RGBColor[
             0.4210365297924291, 0.5391024130200714, 0.9480490532637569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 304}], {
             RGBColor[
             0.5652332989317203, 0.6553785811146005, 0.9601312107721256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 315}], {
             RGBColor[
             0.34474744987853734`, 0.4706894043923238, 0.9432734852007696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 329}], {
             RGBColor[
             0.40747686835411234`, 0.5273577158106015, 0.9471850436272451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 353}], {
             RGBColor[
             0.32914066227709315`, 0.45428568109571954`, 0.9423847017350405]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 378}], {
             RGBColor[
             0.5948185474226719, 0.6784908020919485, 0.9630799918518375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 138}], {
             RGBColor[
             0.5795390984757676, 0.6642646098650511, 0.9625262186088857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 142}], {
             RGBColor[
             0.4539732384406206, 0.5648464530526838, 0.9509170012418431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 152}], {
             RGBColor[
             0.3935812497792913, 0.5153220294151886, 0.9462996270990706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 156}], {
             RGBColor[
             0.41017134404988, 0.5292861019334254, 0.947468755663778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 175}], {
             RGBColor[
             0.47940422509109154`, 0.585492473668429, 0.9529190216677417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 202}], {
             RGBColor[
             0.6444813999281553, 0.7159125801129209, 0.9677014912329938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 242}], {
             RGBColor[
             0.648055375869041, 0.7185780455177849, 0.9616516822072882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 256}], {
             RGBColor[
             0.3301183997249826, 0.4602980309469792, 0.9422578686709889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[
             0.6440494400071093, 0.7155904251110742, 0.968432686706134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 261}], {
             RGBColor[
             0.41017134404988, 0.5292861019334254, 0.947468755663778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 264}], {
             RGBColor[
             0.4251087418522967, 0.5414129543915296, 0.9486446823362753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 268}], {
             RGBColor[
             0.6658778629181163, 0.7318700271773412, 0.9314828604822887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 317}], {
             RGBColor[
             0.6735114012805687, 0.7357791503665339, 0.8386720219072357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 333}], {
             RGBColor[
             0.671764708200451, 0.7350568478899404, 0.8676192465415775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 381}], {
             RGBColor[
             0.45782070436512057`, 0.5679699992165577, 0.9512198878531518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 141}], {
             RGBColor[
             0.6489053837205627, 0.7155548465760078, 0.8796530476665356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 150}], {
             RGBColor[
             0.466723303657944, 0.5739308222327526, 0.9522541018712316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 186}], {
             RGBColor[
             0.273314540977293, 0.40460129008288215`, 0.9388762308248032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 189}], {
             RGBColor[
             0.5722487704126076, 0.6567606371208063, 0.962559378267078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 190}], {
             RGBColor[
             0.44294697630840657`, 0.5546281285790573, 0.9503823422867193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 226}], {
             RGBColor[
             0.47998664400446167`, 0.5845512554877367, 0.9533989804684364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 241}], {
             RGBColor[
             0.6165769332607645, 0.6921067109200003, 0.9667874380117534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 255}], {
             RGBColor[
             0.43209727191096925`, 0.5458198497756046, 0.9495282138127763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 266}], {
             RGBColor[
             0.47430355900408266`, 0.5800848150093597, 0.9528508473394699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 273}], {
             RGBColor[
             0.45386906879099576`, 0.5634951752910823, 0.9512421694158917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 365}], {
             RGBColor[
             0.4687687302513892, 0.5755913916867293, 0.9524151253453121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 114}], {
             RGBColor[
             0.9225921695000054, 0.9387737433812997, 0.9018035925187213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 153}], {
             RGBColor[
             0.667008527393536, 0.7312918269987827, 0.8803475334108545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 161}], {
             RGBColor[
             0.9234634456259743, 0.9394684753139868, 0.9018866956134135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 188}], {
             RGBColor[
             0.9775888984699215, 0.942358229802021, 0.5686367291352913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 195}], {
             RGBColor[
             0.7518847543219114, 0.8031624163228859, 0.8862102712713427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 258}], {
             RGBColor[
             0.9643495308024118, 0.9719892118195794, 0.9029879035020505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 278}], {
             RGBColor[
             0.8223535129587842, 0.8601809803445457, 0.891888519579787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 284}], {
             RGBColor[
             0.8527846889142467, 0.8839540462864565, 0.8949216148035197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 327}], {
             RGBColor[
             0.618390870772543, 0.6834646650678322, 0.8774589863809461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 337}], {
             RGBColor[
             0.7339066228368981, 0.7885669592777582, 0.8847949669047768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 354}], {
             RGBColor[
             0.67884481003443, 0.7415438201134616, 0.8811017308743184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 392}], {
             RGBColor[
             0.9410415190463438, 0.9534847539152975, 0.9035633079483798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 94}], {
             RGBColor[
             0.419632880919976, 0.5253730036867369, 0.9494870620545321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 119}], {
             RGBColor[
             0.5054457933767048, 0.6077524166320095, 0.9546601405085091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 128}], {
             RGBColor[
             0.726791781931089, 0.7862446841728783, 0.9736283389961506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 225}], {
             RGBColor[
             0.8007316500363519, 0.8439606988437603, 0.9376327288719387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 296}], {
             RGBColor[
             0.5114963518142699, 0.612993106240719, 0.955045676741852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 301}], {
             RGBColor[
             0.6583102545379391, 0.7326171999610307, 0.9668370245986657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 316}], {
             RGBColor[
             0.7402807597379569, 0.7970004289275263, 0.9749149297411224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 324}], {
             RGBColor[
             0.8039373146935864, 0.8453434810404923, 0.8870661982028949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 355}], {
             RGBColor[
             0.596011023522147, 0.6829076247427328, 0.9613393175134314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 380}], {
             RGBColor[
             0.6006170778911226, 0.6866470271798518, 0.9617019229858903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 383}], {
             RGBColor[
             0.509122927167799, 0.6109373651037371, 0.9548944442221159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 390}], {
             RGBColor[
             0.7535759473229038, 0.8076016506195101, 0.9761830366017286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 119}], {
             RGBColor[
             0.30746333461214764`, 0.4326784384520366, 0.9411071141420891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 128}], {
             RGBColor[
             0.5288093231665317, 0.6111707059929055, 0.9600753126297306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 177}], {
             RGBColor[
             0.42164860880981514`, 0.5270094623952148, 0.9496457475378748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 200}], {
             RGBColor[
             0.39107305848437846`, 0.5021868532281801, 0.9472387282143251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 225}], {
             RGBColor[
             0.6027491912717947, 0.6688867206637874, 0.9240797025055187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 288}], {
             RGBColor[
             0.3232301896737349, 0.44633489584120606`, 0.942111764204531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 296}], {
             RGBColor[
             0.3135138930497128, 0.437919128060746, 0.9414926503754321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 316}], {
             RGBColor[
             0.5422983009733997, 0.6219264507475535, 0.9613619033747023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 324}], {
             RGBColor[
             0.6059548559290292, 0.6702695028605192, 0.8735131718364749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 355}], {
             RGBColor[
             0.39802856475758985`, 0.50783364656276, 0.9477862911470114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 375}], {
             RGBColor[
             0.5166327145504751, 0.601529052262955, 0.9588959463365647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 380}], {
             RGBColor[
             0.4026346191265654, 0.5115730489998789, 0.9481488966194702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 383}], {
             RGBColor[
             0.31114046840324183`, 0.43586338692376414`, 0.9413414178556959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 390}], {
             RGBColor[
             0.5555934885583467, 0.632527672439537, 0.9626300102353086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 129}], {
             RGBColor[
             0.6558493065140315, 0.7253342410536945, 0.9622283483259995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 151}], {
             RGBColor[
             0.6049905379663687, 0.6849930097416927, 0.964733467722688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 178}], {
             RGBColor[
             0.5372727818011485, 0.6319117460847139, 0.9580316650130136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 229}], {
             RGBColor[
             0.3319710093118466, 0.4607956100830957, 0.9424164501384436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 249}], {
             RGBColor[
             0.31922458581552626`, 0.4473983108185357, 0.9416905601769718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 270}], {
             RGBColor[
             0.3779873994380859, 0.5018154200193436, 0.9453060007444294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 308}], {
             RGBColor[
             0.43901061372156003`, 0.5531248419522135, 0.9496214604385214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 309}], {
             RGBColor[
             0.33741400603480814`, 0.46651654474485293`, 0.9427264207496241]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 334}], {
             RGBColor[
             0.33194712670969084`, 0.4607705079539856, 0.9424150900595819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 371}], {
             RGBColor[
             0.6088589301291187, 0.6880775606475615, 0.9651024384205256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 386}], {
             RGBColor[
             0.46326871432851796`, 0.5728186608399206, 0.9515311469786515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 110}], {
             RGBColor[
             0.40083250565529177`, 0.5216027027962626, 0.9467616707114554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 114}], {
             RGBColor[
             0.6153671657131659, 0.6935300541101139, 0.9656021249813754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 115}], {
             RGBColor[
             0.4863626583085762, 0.5917750262768167, 0.9532918093967117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 153}], {
             RGBColor[
             0.35978352360669635`, 0.4860481377275968, 0.9441460658735086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 154}], {
             RGBColor[
             0.3321616412157265, 0.4602888657213739, 0.9424531971255357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 167}], {
             RGBColor[
             0.6636502992356335, 0.7316124327851441, 0.9557400057901236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 188}], {
             RGBColor[
             0.6703638946830818, 0.6971145405308351, 0.6324352615979454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 192}], {
             RGBColor[
             0.49737600232011997`, 0.6007161550908815, 0.9541588201805088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 203}], {
             RGBColor[
             0.2869905413085705, 0.4128111757058013, 0.939880769810477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 228}], {
             RGBColor[
             0.3576610133746633, 0.4842097260450759, 0.9440108213983855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 243}], {
             RGBColor[
             0.3811761008756849, 0.5045773129357977, 0.9455091819803753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 258}], {
             RGBColor[
             0.6571245270155721, 0.7267455225483936, 0.9667864359647047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 284}], {
             RGBColor[
             0.5455596851274069, 0.6387103570152706, 0.9587201472661738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 348}], {
             RGBColor[
             0.3399238000674689, 0.46844738682385156`, 0.9428952405890574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 361}], {
             RGBColor[
             0.40404473350640013`, 0.5243849731096265, 0.9469663510296666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 369}], {
             RGBColor[
             0.5555449734174364, 0.6465109401184432, 0.9597153874850995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 100}], {
             RGBColor[
             0.583557185991737, 0.6703551861473624, 0.9616774403332957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 105}], {
             RGBColor[
             0.7046728683046053, 0.7643932449397828, 0.9003333458535057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 112}], {
             RGBColor[
             0.6809628128875526, 0.7473023934547947, 0.9669823456373661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 132}], {
             RGBColor[
             0.667760899799191, 0.7368951125758714, 0.9698685727208103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 140}], {
             RGBColor[
             0.518303183829393, 0.6189594097215685, 0.9554599039900944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 141}], {
             RGBColor[
             0.7057025068664993, 0.7648190269456301, 0.8832695702637409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 168}], {
             RGBColor[
             0.33382940010248263`, 0.45777304668477503`, 0.9427044729861294]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 180}], {
             RGBColor[
             0.5200039080570691, 0.6203401342663493, 0.9555937912312553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 220}], {
             RGBColor[
             0.5077110304772015, 0.6103602224591886, 0.9546260508778738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 282}], {
             RGBColor[
             0.42038435672507335`, 0.5385375334882994, 0.9480074973725989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 350}], {
             RGBColor[
             0.30128830755106983`, 0.4235702951888063, 0.9408513059055588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 357}], {
             RGBColor[
             0.5948942293620234, 0.679211770592951, 0.9628074108657521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 394}], {
             RGBColor[
             0.5426029684200315, 0.6383614401167643, 0.957595506664671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 107}], {
             RGBColor[
             0.5257323098059263, 0.6235253267496706, 0.9566151599872831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 131}], {
             RGBColor[
             0.38114671055523713`, 0.5045518565174263, 0.9455073092551451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 215}], {
             RGBColor[
             0.28215133383499913`, 0.40706249391714455`, 0.9396294366377143]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 283}], {
             RGBColor[
             0.32128524979534234`, 0.4481947208250464, 0.9418580552582152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 297}], {
             RGBColor[
             0.663262732732075, 0.7317544896111948, 0.9626877563547387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 307}], {
             RGBColor[
             0.44822484378493366`, 0.5610075518570454, 0.9502357140641073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 352}], {
             RGBColor[
             0.5517813953301716, 0.6438750703415935, 0.9592114893897954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 123}], {
             RGBColor[
             0.6227031788098485, 0.6853027499680451, 0.7357794685438067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 174}], {
             RGBColor[
             0.3305717615222641, 0.45549115705104326`, 0.942477137593382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 187}], {
             RGBColor[
             0.3068254514824229, 0.4349232968187787, 0.9409640437156808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 193}], {
             RGBColor[
             0.5735174313945113, 0.6506575503512235, 0.9637582097336616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[
             0.38202191314731393`, 0.49845760381069965`, 0.9461967761030711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 232}], {
             RGBColor[
             0.4175731136201196, 0.5273196699178533, 0.9489954968326286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 235}], {
             RGBColor[
             0.2981499836712005, 0.42740904264238855`, 0.9404112505781648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 275}], {
             RGBColor[
             0.3393613344042535, 0.4631042433046442, 0.9430372014051083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 279}], {
             RGBColor[
             0.4842135536852594, 0.5802853166526135, 0.9550184099771304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 281}], {
             RGBColor[
             0.39862502607185035`, 0.5119367588445518, 0.9475038339716972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 306}], {
             RGBColor[
             0.3955405541272975, 0.5094326455660863, 0.947261013041429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 338}], {
             RGBColor[
             0.3917492737463214, 0.506354713357575, 0.9469625495619209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 384}], {
             RGBColor[
             0.232169471942209, 0.36135521377895785`, 0.93653308001193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 105}], {
             RGBColor[
             0.8666400717232647, 0.8951666450858218, 0.9139264674012608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 112}], {
             RGBColor[
             0.8429300163062121, 0.8780757936008337, 0.9805754671851212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 141}], {
             RGBColor[
             0.8676697102851587, 0.8955924270916691, 0.8968626918114959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 168}], {
             RGBColor[
             0.4957966035211421, 0.588546446830814, 0.9562975945338845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 170}], {
             RGBColor[
             0.7141728097578539, 0.7766364939880046, 0.9721457294184548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 180}], {
             RGBColor[
             0.6819711114757286, 0.7511135344123883, 0.9691869127790104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 220}], {
             RGBColor[
             0.669678233895861, 0.7411336226052276, 0.9682191724256288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 271}], {
             RGBColor[
             0.6918723021427347, 0.7591517670394202, 0.9699663707775735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 273}], {
             RGBColor[
             0.6726333953555919, 0.7435327558067437, 0.968451813560852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 282}], {
             RGBColor[
             0.5823515601437329, 0.6693109336343384, 0.9616006189203541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 350}], {
             RGBColor[
             0.4632555109697294, 0.5543436953348453, 0.9544444274533139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 394}], {
             RGBColor[
             0.7045701718386911, 0.7691348402628033, 0.971188628212426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 151}], {
             RGBColor[
             0.5691896526732616, 0.652821356645702, 0.962494840051453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 171}], {
             RGBColor[
             0.5857386948458683, 0.6660171136623554, 0.9640733024673807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 182}], {
             RGBColor[
             0.3381610715376496, 0.46615713086151256`, 0.9428108754298146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 244}], {
             RGBColor[
             0.5664733228316478, 0.6506554289628084, 0.9622357540862636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 253}], {
             RGBColor[
             0.36751092956074977`, 0.49157850271436526`, 0.9446810224299861]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 270}], {
             RGBColor[
             0.3421865141449788, 0.4696437669233528, 0.9430673730731944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 308}], {
             RGBColor[
             0.403209728428453, 0.5209531888562227, 0.9473828327672864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 397}], {
             RGBColor[
             0.4777683621291558, 0.5812227117784039, 0.9534304905570141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 160}], {
             RGBColor[
             0.49082214559682924`, 0.5838065943705634, 0.9559369510798653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 166}], {
             RGBColor[
             0.26735820988946957`, 0.3983408084563765, 0.9385370265809538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[
             0.31948158146734906`, 0.4447606586147669, 0.9418116634369051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 213}], {
             RGBColor[
             0.5619532982764945, 0.6398935455531956, 0.9628889782346381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 224}], {
             RGBColor[
             0.4455668319179115, 0.5484527993714698, 0.951426324347302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 230}], {
             RGBColor[
             0.38945802971994675`, 0.5030395267596388, 0.9469146222747189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 247}], {
             RGBColor[
             0.3286582093271512, 0.45270899243620033`, 0.9423963900495583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 250}], {
             RGBColor[
             0.47041824311456987`, 0.5678669106760199, 0.9539032807657433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 289}], {
             RGBColor[
             0.30074292707507216`, 0.42853017801233134`, 0.9406176529489707]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 302}], {
             RGBColor[
             0.2557809735538832, 0.38617239902849543`, 0.9378777200986286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 340}], {
             RGBColor[
             0.4489357678130769, 0.5510846376976343, 0.9517621083928363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 370}], {
             RGBColor[
             0.2827004525193044, 0.41290269339326413`, 0.939468002424611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 391}], {
             RGBColor[
             0.445206653368226, 0.5481714251509973, 0.9513904251155293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 400}], {
             RGBColor[
             0.27361664565237814`, 0.4049188212509393, 0.9388934352391255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 108}], {
             RGBColor[
             0.6427836866454268, 0.7180339784362175, 0.9670005412621265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 133}], {
             RGBColor[
             0.8670834534926772, 0.8968528257344539, 0.9871843879203102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 143}], {
             RGBColor[
             0.8036511105452875, 0.8466452344443471, 0.9810355333501707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 223}], {
             RGBColor[
             0.5858819630391019, 0.6687485654122045, 0.9633748137501501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 231}], {
             RGBColor[
             0.5658013087373104, 0.650390338038104, 0.9621306392821789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 234}], {
             RGBColor[
             0.5485332026418004, 0.6322404636705602, 0.9611472461859134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 290}], {
             RGBColor[
             0.6640132353606677, 0.7352975541813087, 0.9686639422829333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 313}], {
             RGBColor[
             0.5485279131649812, 0.632234904095051, 0.9611469449580335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 331}], {
             RGBColor[
             0.5790467409252736, 0.662828239565459, 0.9629392794412065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 342}], {
             RGBColor[
             0.8263757362232815, 0.864397884737548, 0.9833005116640523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 346}], {
             RGBColor[
             0.664853380648442, 0.7359796219740379, 0.9687300815975405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 109}], {
             RGBColor[
             0.6023448318135687, 0.6880496956485207, 0.9618379381036364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 138}], {
             RGBColor[
             0.7168883765721676, 0.7785194403697417, 0.9725794384360378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 144}], {
             RGBColor[
             0.8109502003064052, 0.8499217150264652, 0.8363902010834009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 205}], {
             RGBColor[
             0.5561111495021045, 0.6505151095444215, 0.9581982532725193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 207}], {
             RGBColor[
             0.5550511106036677, 0.6496545222124623, 0.9581148031273838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 233}], {
             RGBColor[
             0.6767598500769322, 0.7471707304835666, 0.9685798019373937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 358}], {
             RGBColor[
             0.47599020821662585`, 0.5819903164119535, 0.9528520983393642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 366}], {
             RGBColor[
             0.563680072660958, 0.6566599023408812, 0.9587941066294633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 382}], {
             RGBColor[
             0.6705748392917033, 0.7423389530503227, 0.967963337864534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 112}], {
             RGBColor[
             0.9640456986190803, 0.972113852393254, 0.9192313727053311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 113}], {
             RGBColor[
             0.8799984120412351, 0.905602282069367, 0.9152579019233682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 148}], {
             RGBColor[
             0.7272666803797203, 0.7835974094822982, 0.9018739812334466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 155}], {
             RGBColor[
             0.9914219683516854, 0.990553574100701, 0.7796697761761131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 168}], {
             RGBColor[
             0.6169122858340104, 0.6825845056232345, 0.8949535000540944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 170}], {
             RGBColor[
             0.8352884920707221, 0.8706745527804249, 0.9108016349386647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 180}], {
             RGBColor[
             0.8030867937885968, 0.8451515932048086, 0.9078428182992202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 239}], {
             RGBColor[
             0.8665147332998265, 0.8950687297568246, 0.9139139748385665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 271}], {
             RGBColor[
             0.8129879844556029, 0.8531898258318407, 0.9086222762977834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 282}], {
             RGBColor[
             0.7034672424566011, 0.7633489924267587, 0.9002565244405639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 326}], {
             RGBColor[
             0.738926212602849, 0.7930631429969748, 0.9027918623203253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 350}], {
             RGBColor[
             0.5843711932825976, 0.6483817541272656, 0.8931003329735238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 394}], {
             RGBColor[
             0.8256858541515593, 0.8631728990552237, 0.909844533732636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.6117722690246012, 0.6952970361828734, 0.9628578747735294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 173}], {
             RGBColor[
             0.44298415636980804`, 0.5553605652936879, 0.9502078612887241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 197}], {
             RGBColor[
             0.4156268875182631, 0.5286920207230297, 0.9485735383540456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 204}], {
             RGBColor[
             0.44952879343410235`, 0.5610292009757563, 0.9506248797752657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 214}], {
             RGBColor[
             0.5153309406781263, 0.6174078988936442, 0.9549878858510688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 215}], {
             RGBColor[
             0.368191293053674, 0.4788342033503473, 0.9458721514239605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 295}], {
             RGBColor[
             0.5886264764018276, 0.6769125167204009, 0.9607579789136325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 310}], {
             RGBColor[
             0.47764720649369086`, 0.5853839570954387, 0.9524165601912863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 345}], {
             RGBColor[
             0.6068838665396805, 0.6914781790084183, 0.9623706444985509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 363}], {
             RGBColor[
             0.5415189727812502, 0.638668523112362, 0.957049503668149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 131}], {
             RGBColor[
             0.5242950404621963, 0.6222804362833894, 0.956523578455628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 197}], {
             RGBColor[
             0.47273525820654744`, 0.57464889105579, 0.9533470927682821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 215}], {
             RGBColor[
             0.4252996637419583, 0.5247910736831076, 0.9506457058381971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 297}], {
             RGBColor[
             0.8064110626390343, 0.8494830693771579, 0.9737040255552216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 307}], {
             RGBColor[
             0.5913731736918928, 0.6787361316230085, 0.9612519832645903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 352}], {
             RGBColor[
             0.6949297252371307, 0.7616036501075566, 0.9702277585902781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 363}], {
             RGBColor[
             0.5986273434695345, 0.6846253934451223, 0.9618230580823857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 143}], {
             RGBColor[
             0.6131368323957014, 0.6947660187509683, 0.9640741767646321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 179}], {
             RGBColor[
             0.37354061284461265`, 0.4966755265674343, 0.9450698267897637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 196}], {
             RGBColor[
             0.5739192076874925, 0.6641289122639283, 0.9601653304432578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 231}], {
             RGBColor[
             0.37528703058772434`, 0.49851112234472506`, 0.9451692826966405]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 234}], {
             RGBColor[
             0.3580189244922143, 0.4803612479771814, 0.9441858896003748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 290}], {
             RGBColor[
             0.4734989572110816, 0.5834183384879299, 0.9517025856973947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 313}], {
             RGBColor[
             0.35801363501539507`, 0.4803556884016722, 0.944185588372495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 331}], {
             RGBColor[
             0.38853246277568754`, 0.5109490238720802, 0.945977922855668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 342}], {
             RGBColor[
             0.6358614580736954, 0.7125186690441692, 0.9663391550785136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 344}], {
             RGBColor[
             0.43501517222890673`, 0.5512100105115509, 0.9489397599989811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 136}], {
             RGBColor[
             0.6572330556670958, 0.7311672683415251, 0.9671456366017943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 205}], {
             RGBColor[
             0.5316645340241446, 0.6306682457919368, 0.9562737261511911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 207}], {
             RGBColor[
             0.5306044951257078, 0.6298076584599777, 0.9561902760060557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 233}], {
             RGBColor[
             0.6523132345989722, 0.7273238667310818, 0.9666552748160655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 286}], {
             RGBColor[
             0.5766104410581123, 0.6671573579121494, 0.9598120325951874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 320}], {
             RGBColor[
             0.7140273193582052, 0.7757792512469499, 0.9727416417821142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 343}], {
             RGBColor[
             0.547034079610445, 0.6431459352890337, 0.9574836730802452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 358}], {
             RGBColor[
             0.45154359273866596`, 0.5621434526594687, 0.9509275712180361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 366}], {
             RGBColor[
             0.539233457182998, 0.6368130385883966, 0.9568695795081351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 382}], {
             RGBColor[
             0.6461282238137432, 0.7224920892978379, 0.9660388107432059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 115}], {
             RGBColor[
             0.511775261527926, 0.6137861459108411, 0.954911078002366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 134}], {
             RGBColor[
             0.5000523283277587, 0.6042689406268231, 0.9539882057583295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 167}], {
             RGBColor[
             0.6890629024549833, 0.7536235524191686, 0.957359274395778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 192}], {
             RGBColor[
             0.5227886055394697, 0.6227272747249061, 0.9557780887861631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 203}], {
             RGBColor[
             0.31240314452792023`, 0.43482229533982575`, 0.9415000384161312]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 243}], {
             RGBColor[
             0.4065887040950346, 0.5265884325698222, 0.9471284505860296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 348}], {
             RGBColor[
             0.36533640328681866`, 0.49045850645787614`, 0.9445145091947117]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 351}], {
             RGBColor[
             0.5753525801668065, 0.6641433939105688, 0.9607760024242963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 369}], {
             RGBColor[
             0.580957576636786, 0.6685220597524678, 0.9613346560907539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 160}], {
             RGBColor[
             0.5477762606725024, 0.6395173487182912, 0.9593324152510332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 166}], {
             RGBColor[
             0.3243123249651427, 0.4540515628041043, 0.9419324907521217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.37643569654302217`, 0.5004714129624948, 0.9452071276080729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 197}], {
             RGBColor[
             0.31511966842368366`, 0.4443894979309424, 0.9414089825614023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[
             0.33057076072805125`, 0.46062957559866713`, 0.9422888994102934]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 155}], {
             RGBColor[
             0.9677119129346327, 0.9734627226157128, 0.8463187759599735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 170}], {
             RGBColor[
             0.8115784366536694, 0.8535837012954367, 0.9774506347225251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 180}], {
             RGBColor[
             0.7793767383715442, 0.8280607417198205, 0.9744918180830806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 183}], {
             RGBColor[
             0.8351510401901345, 0.8719987983365456, 0.9798001315445355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 271}], {
             RGBColor[
             0.7892779290385502, 0.8360989743468523, 0.9752712760816438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 273}], {
             RGBColor[
             0.7700390222514073, 0.8204799631141759, 0.9737567188649223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 326}], {
             RGBColor[
             0.7152161571857962, 0.7759722915119867, 0.9694408621041857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 350}], {
             RGBColor[
             0.5606611378655448, 0.6312909026422774, 0.9597493327573842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 394}], {
             RGBColor[
             0.8019757987345066, 0.8460820475702355, 0.9764935335164964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 148}], {
             RGBColor[
             0.6195093383848224, 0.6999949876734228, 0.9645495102353443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 168}], {
             RGBColor[
             0.5091549438391124, 0.5989820838143591, 0.9576290290559919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 170}], {
             RGBColor[
             0.7275311500758241, 0.7870721309715496, 0.9734771639405624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 251}], {
             RGBColor[
             0.5574894656749817, 0.6466419510205337, 0.9604966811348551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 282}], {
             RGBColor[
             0.5957099004617031, 0.6797465706178833, 0.9629320534424615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 153}], {
             RGBColor[
             0.5997307868839201, 0.6799866086754724, 0.9646057887490829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 154}], {
             RGBColor[
             0.5721089044929503, 0.6542273366692496, 0.9629129200011098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 188}], {
             RGBColor[
             0.9103111579603056, 0.8910530114787107, 0.6528949844735197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 203}], {
             RGBColor[
             0.5269378045857942, 0.6067496466536769, 0.9603404926860512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 222}], {
             RGBColor[
             0.7401326747242086, 0.7969354309303851, 0.9748397100337545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 258}], {
             RGBColor[
             0.8970717902927958, 0.9206839934962693, 0.9872461588402788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 312}], {
             RGBColor[
             0.8013908402006096, 0.8450574449562138, 0.980763028032563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 327}], {
             RGBColor[
             0.5511131302629271, 0.632159446744522, 0.9617172417191745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 356}], {
             RGBColor[
             0.6998271942624169, 0.7642136261502998, 0.9716667149679625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 361}], {
             RGBColor[
             0.6439919967836238, 0.7183234440575021, 0.9674260739052407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 369}], {
             RGBColor[
             0.7954922366946602, 0.840449411066319, 0.9801751103606737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 392}], {
             RGBColor[
             0.8737637785367278, 0.9021795355919873, 0.9878215632866081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 184}], {
             RGBColor[
             0.6394699871863581, 0.7175879177591563, 0.9651719187382668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 188}], {
             RGBColor[
             0.781306650555716, 0.7892979836454136, 0.6405846688888559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 195}], {
             RGBColor[
             0.5556025064077059, 0.6501021701662784, 0.9581582110249072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 203}], {
             RGBColor[
             0.3979332971812047, 0.5049946188203798, 0.9480301771013874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 206}], {
             RGBColor[
             0.545800404232048, 0.6421443820404086, 0.9573865536353561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 208}], {
             RGBColor[
             0.5640736233299433, 0.6569794045032192, 0.9588250883797493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 258}], {
             RGBColor[
             0.7680672828882062, 0.8189289656629721, 0.974935843255615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 284}], {
             RGBColor[
             0.6565024410000412, 0.7308938001298491, 0.9668695545570842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 325}], {
             RGBColor[
             0.6270447601826978, 0.7078812359886741, 0.9639334882308901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 369}], {
             RGBColor[
             0.6664877292900706, 0.7386943832330217, 0.96786479477601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 392}], {
             RGBColor[
             0.7447592711321382, 0.80042450775869, 0.9755112477019443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 121}], {
             RGBColor[
             0.5650570080702451, 0.6488515264176596, 0.9622028576747492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 130}], {
             RGBColor[
             0.4795485356219547, 0.5818958412900248, 0.9537215211879964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 135}], {
             RGBColor[
             0.640360983775746, 0.7065566468198181, 0.878710151814609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 147}], {
             RGBColor[
             0.2511164995560199, 0.3812697411120083, 0.9376120852049211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 172}], {
             RGBColor[
             0.27882746412289783`, 0.41039572184842865`, 0.9391901836423064]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 265}], {
             RGBColor[
             0.6161273076543385, 0.6894265179893959, 0.9619746654378152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 276}], {
             RGBColor[
             0.4335110952188029, 0.5449171139226505, 0.9498261681862341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 322}], {
             RGBColor[
             0.6428558914465307, 0.7072240645798695, 0.8108829884514415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 328}], {
             RGBColor[
             0.6079943015634695, 0.6830885587473734, 0.9662982550587073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 362}], {
             RGBColor[
             0.3942650874670677, 0.5130554368172908, 0.9467365786931542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 364}], {
             RGBColor[
             0.2737021663401902, 0.40500870891615454`, 0.9388983055157798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 387}], {
             RGBColor[
             0.27949192024468317`, 0.4110941073613764, 0.9392280234354674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 223}], {
             RGBColor[
             0.42672045649712975`, 0.5423514138539396, 0.9488737953740931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 346}], {
             RGBColor[
             0.5056918741064698, 0.6095824704157728, 0.9542290632214836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 371}], {
             RGBColor[
             0.6824604586821761, 0.7501533745645516, 0.970254830063462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 126}], {
             RGBColor[
             0.7567535531853723, 0.46433110740023104`, 0.44842268914787237`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 149}], {
             RGBColor[
             0.8727007562641836, 0.556147115904336, 0.4593675424332476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[
             0.6459824039160779, 0.36659973096652543`, 0.4408974639282713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 212}], {
             RGBColor[
             0.7521488875076009, 0.4605928323651914, 0.44806019299827204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 259}], {
             RGBColor[
             0.709521391525001, 0.425642267464664, 0.4447993500366912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 293}], {
             RGBColor[
             0.8508378109561248, 0.5387141967695308, 0.4572822351924833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 299}], {
             RGBColor[
             0.6477723428786368, 0.36848107030486, 0.44099939830421164`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 336}], {
             RGBColor[
             0.8133815213127351, 0.5092466871558746, 0.4536037069314655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 367}], {
             RGBColor[
             0.8738073085448397, 0.5570294506563696, 0.4594730863776075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 200}], {
             RGBColor[
             0.4768859709411073, 0.5845662661734528, 0.9524118066683023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 225}], {
             RGBColor[
             0.6885621037285237, 0.75126613360906, 0.9292527809594957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 288}], {
             RGBColor[
             0.4090431021304637, 0.5287143087864787, 0.9472848426585081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 296}], {
             RGBColor[
             0.3993268055064416, 0.5202985410060186, 0.9466657288294091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 316}], {
             RGBColor[
             0.6281112134301285, 0.7043058636928261, 0.9665349818286794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 324}], {
             RGBColor[
             0.6917677683857582, 0.7526489158057919, 0.878686250290452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 355}], {
             RGBColor[
             0.4838414772143187, 0.5902130595080326, 0.9529593696009884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 375}], {
             RGBColor[
             0.6024456270072039, 0.6839084652082277, 0.9640690247905417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 380}], {
             RGBColor[
             0.48844753158329424`, 0.5939524619451515, 0.9533219750734473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 383}], {
             RGBColor[
             0.3969533808599707, 0.5182427998690368, 0.946514496309673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 390}], {
             RGBColor[
             0.6414064010150755, 0.7149070853848096, 0.9678030886892857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 136}], {
             RGBColor[
             0.7309577142327224, 0.7897489889337708, 0.9738186918326593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 237}], {
             RGBColor[
             0.5307310227458742, 0.6254567513075365, 0.9579487094146196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 246}], {
             RGBColor[
             0.7142969028221718, 0.7767334364329921, 0.9721580978553904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 254}], {
             RGBColor[
             0.6546543883290952, 0.7292456716571419, 0.966825118055014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 286}], {
             RGBColor[
             0.6503350996237389, 0.725739078504395, 0.9664850878260525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 320}], {
             RGBColor[
             0.7877519779238317, 0.8343609718391956, 0.9794146970129793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 343}], {
             RGBColor[
             0.6207587381760715, 0.7017276558812794, 0.9641567283111103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 349}], {
             RGBColor[
             0.6771564244144472, 0.7475138382564043, 0.9685965607633271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 130}], {
             RGBColor[
             0.7537534861503292, 0.8077130357726583, 0.9760494124140203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 158}], {
             RGBColor[
             0.6447259269779697, 0.7195111569409571, 0.9672187144195079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 181}], {
             RGBColor[
             0.7964835474911034, 0.8410940844525656, 0.9803083455933423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 250}], {
             RGBColor[
             0.7701786074159738, 0.8205444653409251, 0.9776865150002947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 265}], {
             RGBColor[
             0.8903322581827131, 0.9152437124720294, 0.9843025566638393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 322}], {
             RGBColor[
             0.9170608419749051, 0.933041259062503, 0.8332108796774654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 362}], {
             RGBColor[
             0.6684700379954421, 0.7388726312999243, 0.9690644699191782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 146}], {
             RGBColor[
             0.7116833642141384, 0.774513587157129, 0.9720193952921273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.783759609256224, 0.8317360866518453, 0.9779785189797275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 165}], {
             RGBColor[
             0.7669612324519934, 0.8183696165665493, 0.9773505055273678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 210}], {
             RGBColor[
             0.6913918631726867, 0.7586617123224273, 0.9699969281031738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 228}], {
             RGBColor[
             0.4853163362253662, 0.589961183925013, 0.9534759031819595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 262}], {
             RGBColor[
             0.544765414112756, 0.6413041304357938, 0.9573050754218717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 298}], {
             RGBColor[
             0.5646606969267575, 0.6574560172964772, 0.9588713049638121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 314}], {
             RGBColor[
             0.6137174619686937, 0.6972825091396013, 0.9627332332087648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 385}], {
             RGBColor[
             0.4303588847415372, 0.5350780144807441, 0.9502406848708801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 174}], {
             RGBColor[
             0.7013686615215994, 0.7586940578357109, 0.740599544172098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 187}], {
             RGBColor[
             0.6776223514817582, 0.7381261976034462, 0.7390864502943968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 193}], {
             RGBColor[
             0.9443143313938467, 0.953860451135891, 0.7618806163123775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 218}], {
             RGBColor[
             0.7528188131466493, 0.8016605045953672, 0.744319182681787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 232}], {
             RGBColor[
             0.7883700136194549, 0.8305225707025209, 0.7471179034113447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 235}], {
             RGBColor[
             0.6689468836705358, 0.730611943427056, 0.7385336571568806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 275}], {
             RGBColor[
             0.7101582344035888, 0.7663071440893118, 0.7411596079838242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 279}], {
             RGBColor[
             0.8550104536845947, 0.8834882174372811, 0.7531408165558464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 281}], {
             RGBColor[
             0.7694219260711856, 0.8151396596292194, 0.745626240550413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 306}], {
             RGBColor[
             0.7663374541266328, 0.8126355463507537, 0.7453834196201449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 338}], {
             RGBColor[
             0.7625461737456567, 0.8095576141422426, 0.7450849561406367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.6859383599460923, 0.7528078196064429, 0.9707232218259894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 199}], {
             RGBColor[
             0.5585139448843315, 0.6376553881445959, 0.9624845332297665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 238}], {
             RGBColor[
             0.8445955799616938, 0.8789547758659878, 0.9850306721515824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 252}], {
             RGBColor[
             0.6327053400131244, 0.7079286341277078, 0.9669918003274482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 277}], {
             RGBColor[
             0.7240230968753725, 0.7837267247434794, 0.9737213918260504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 293}], {
             RGBColor[
             0.865797055444402, 0.8958270868491041, 0.9870616901260845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 330}], {
             RGBColor[
             0.8887088490712469, 0.9140963291630801, 0.9892470374558126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 179}], {
             RGBColor[
             0.33970334449856265`, 0.4673673854366432, 0.942913745971875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 196}], {
             RGBColor[
             0.5400819393414424, 0.6348207711331373, 0.958009249625369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 303}], {
             RGBColor[
             0.5970441322835273, 0.6793200691881947, 0.963686708675878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 313}], {
             RGBColor[
             0.32417636666934513`, 0.45104754727088103`, 0.9420295075546063]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 344}], {
             RGBColor[
             0.40117790388285673`, 0.5219018693807598, 0.9467836791810924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 149}], {
             RGBColor[
             0.7499511104588834, 0.8044103907639903, 0.9761836421538276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 199}], {
             RGBColor[
             0.4098735819367248, 0.5200893133572746, 0.9484785243963632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 212}], {
             RGBColor[
             0.5691233073240094, 0.6610789654552736, 0.9592226180013643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 238}], {
             RGBColor[
             0.695955217014087, 0.7613887010786664, 0.9710246633181789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 259}], {
             RGBColor[
             0.5051820633501096, 0.6086531181044825, 0.954331353558993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 274}], {
             RGBColor[
             0.5993096801540025, 0.6855856227992608, 0.9615989998468684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 299}], {
             RGBColor[
             0.41255849038056336`, 0.5229113223647764, 0.9486314259602736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 318}], {
             RGBColor[
             0.4371531084567508, 0.5487618253517016, 0.9500320530752355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 336}], {
             RGBColor[
             0.6609722580317108, 0.7340597476412984, 0.9675378889011544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 367}], {
             RGBColor[
             0.7516109388798675, 0.8057338928920409, 0.9763419580703674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 139}], {
             RGBColor[
             0.4820341472729985, 0.5786705737056641, 0.9547872829838282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 184}], {
             RGBColor[
             0.696572833015664, 0.7628872583922284, 0.9703915282179272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 305}], {
             RGBColor[
             0.5543360734340005, 0.6464899076634871, 0.9592040819394536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 325}], {
             RGBColor[
             0.6841476060120038, 0.7531805766217461, 0.9691530977105504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 177}], {
             RGBColor[
             0.7288075098209281, 0.7878811428813564, 0.9737870244794933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 225}], {
             RGBColor[
             0.9099080922829077, 0.9297584011499289, 0.9482209794471372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 296}], {
             RGBColor[
             0.6206727940608256, 0.6987908085468875, 0.9656339273170507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 311}], {
             RGBColor[
             0.8486777211304619, 0.882176594359119, 0.9854288327366107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 316}], {
             RGBColor[
             0.8494572019845126, 0.8827981312336949, 0.9855031803163208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 324}], {
             RGBColor[
             0.9131137569401422, 0.9311411833466607, 0.8976544487780935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 380}], {
             RGBColor[
             0.7097935201376783, 0.7724447294860204, 0.9722901735610887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 383}], {
             RGBColor[
             0.6182993694143547, 0.6967350674099055, 0.9654826947973145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 390}], {
             RGBColor[
             0.8627523895694595, 0.8933993529256785, 0.9867712871769272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 178}], {
             RGBColor[
             0.8253501937102263, 0.8642787239593218, 0.9756049355293346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 229}], {
             RGBColor[
             0.6200484212209245, 0.6931625879577037, 0.9599897206547644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 249}], {
             RGBColor[
             0.6073019977246041, 0.6797652886931437, 0.9592638306932927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 270}], {
             RGBColor[
             0.6660648113471638, 0.7341823978939517, 0.9628792712607503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 308}], {
             RGBColor[
             0.7270880256306379, 0.7854918198268215, 0.9671947309548423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 309}], {
             RGBColor[
             0.625491417943886, 0.698883522619461, 0.9602996912659449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 397}], {
             RGBColor[
             0.8016466593313407, 0.8457613427490027, 0.97324238874457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 135}], {
             RGBColor[
             0.8290574618558302, 0.8654181561748168, 0.8925567065538802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 147}], {
             RGBColor[
             0.439812977636104, 0.540131250467007, 0.9514586399441922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 158}], {
             RGBColor[
             0.5592174545296793, 0.6525554718133224, 0.958737377932755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 172}], {
             RGBColor[
             0.4675239422029819, 0.5692572312034274, 0.9530367383815777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 181}], {
             RGBColor[
             0.7109750750428131, 0.7741383993249308, 0.9718270091065895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 265}], {
             RGBColor[
             0.8048237857344227, 0.8482880273443947, 0.9758212201770864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 322}], {
             RGBColor[
             0.8315523695266147, 0.8660855739348683, 0.8247295431907126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 328}], {
             RGBColor[
             0.7966907796435535, 0.8419500681023722, 0.9801448097979784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 347}], {
             RGBColor[
             0.5640828277733975, 0.6565903363701111, 0.9590969300397804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 362}], {
             RGBColor[
             0.5829615655471518, 0.6719169461722896, 0.9605831334324253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 364}], {
             RGBColor[
             0.46239864442027423`, 0.5638702182711532, 0.952744860255051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 387}], {
             RGBColor[
             0.4681883983247673, 0.5699556167163752, 0.9530745781747385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 215}], {
             RGBColor[
             0.28071406449126907`, 0.40581760345086326`, 0.9395378551060591]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 217}], {
             RGBColor[
             0.4569237505564871, 0.5679916657906816, 0.9509420894462839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 262}], {
             RGBColor[
             0.41925486064983564`, 0.5374103640003101, 0.947976656447142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 269}], {
             RGBColor[
             0.41914559966147225`, 0.5373216610078053, 0.9479680550219018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 279}], {
             RGBColor[
             0.5481151348857564, 0.6408888750864972, 0.9588977428563301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 297}], {
             RGBColor[
             0.661825463388345, 0.7305095991449135, 0.9625961748230836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 300}], {
             RGBColor[
             0.6065037030032601, 0.6866100800903707, 0.9646888127855775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 306}], {
             RGBColor[
             0.45944213532779443`, 0.5700362039999699, 0.9511403459206286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 307}], {
             RGBColor[
             0.4467875744412036, 0.5597626613907641, 0.9501441325324522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 314}], {
             RGBColor[
             0.48820690850577336`, 0.5933887427041176, 0.9534048142340351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 352}], {
             RGBColor[
             0.5503441259864414, 0.6426301798753122, 0.9591199078581403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 363}], {
             RGBColor[
             0.45404174421884524`, 0.5656519232128779, 0.9507152073502476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 140}], {
             RGBColor[
             0.7644741010555064, 0.8162727362961164, 0.9772441579253641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 191}], {
             RGBColor[
             0.9177378948016826, 0.9372433022560743, 0.9920158537521166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 198}], {
             RGBColor[
             0.7001277098227168, 0.764033437121447, 0.9721785742989213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 216}], {
             RGBColor[
             0.6582163236088057, 0.7286280804041076, 0.9692604007658963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 219}], {
             RGBColor[
             0.9353597004526881, 0.9507506352393951, 0.9748421774653423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 220}], {
             RGBColor[
             0.753881947703315, 0.8076735490337366, 0.9764103048131434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 302}], {
             RGBColor[
             0.5928762670686295, 0.6686198128184637, 0.9652219932108332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 323}], {
             RGBColor[
             0.8747006179012536, 0.5943449238035189, 0.46413946342686796`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 357}], {
             RGBColor[
             0.8410651465881368, 0.876525097167499, 0.9845916648010217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 145}], {
             RGBColor[
             0.6832504022844406, 0.7504262027756943, 0.970741135173279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 164}], {
             RGBColor[
             0.9252508778404058, 0.9428746363129892, 0.9802747831370882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 223}], {
             RGBColor[
             0.6196674517367662, 0.6956881970170621, 0.9665973038227951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 234}], {
             RGBColor[
             0.5823186913394647, 0.6591800952754178, 0.9643697362585584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 280}], {
             RGBColor[
             0.9473302009477984, 0.9564606711827968, 0.7780118827292124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 346}], {
             RGBColor[
             0.6986388693461062, 0.7629192535788953, 0.9719525716701856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 167}], {
             RGBColor[
             0.7628701219081004, 0.8142786706157044, 0.9629665408369976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 201}], {
             RGBColor[
             0.7106489646392657, 0.7730562187001281, 0.9724530478078057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 236}], {
             RGBColor[
             0.5537625994845525, 0.6486084508392003, 0.9580133668121154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 243}], {
             RGBColor[
             0.4803959235481518, 0.587243550766358, 0.9527357170272492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 263}], {
             RGBColor[
             0.6704068895794993, 0.7413969002673897, 0.9685009802273419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 348}], {
             RGBColor[
             0.43914362273993585`, 0.5511136246544119, 0.9501217756359315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 351}], {
             RGBColor[
             0.6491597996199236, 0.7247985121071046, 0.9663832688655161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 221}], {
             RGBColor[
             0.879603899501788, 0.9049054174309935, 0.8975947030751134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 276}], {
             RGBColor[
             0.7830200214526783, 0.8284394288074424, 0.8886613535521181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 322}], {
             RGBColor[
             0.9923648176804061, 0.9907463794646615, 0.7497181738173253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 364}], {
             RGBColor[
             0.6232110925740656, 0.6885310238009464, 0.8777334908816637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 376}], {
             RGBColor[
             0.8390000043296639, 0.8731853459214972, 0.8935476862693299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 377}], {
             RGBColor[
             0.973643955065495, 0.9290510093821305, 0.5533113689491462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 194}], {
             RGBColor[
             0.863424685538389, 0.8921904298188723, 0.8925512422733333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 237}], {
             RGBColor[
             0.5363412035117349, 0.6298394671607799, 0.9585078798032406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 246}], {
             RGBColor[
             0.7199070835880325, 0.7811161522862354, 0.9727172682440114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 254}], {
             RGBColor[
             0.6602645690949558, 0.7336283875103853, 0.967384288443635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 286}], {
             RGBColor[
             0.6559452803895995, 0.7301217943576384, 0.9670442582146734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 320}], {
             RGBColor[
             0.7933621586896923, 0.8387436876924389, 0.9799738674016003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 343}], {
             RGBColor[
             0.6263689189419321, 0.7061103717345227, 0.9647158986997313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 349}], {
             RGBColor[
             0.6827666051803079, 0.7518965541096476, 0.9691557311519481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 376}], {
             RGBColor[
             0.7123489968241447, 0.7752117174626993, 0.9719639487897236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 199}], {
             RGBColor[
             0.3711412730945439, 0.4886446801685632, 0.9454293751631844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 238}], {
             RGBColor[
             0.6572229081719061, 0.7299440678899551, 0.9679755140850004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 252}], {
             RGBColor[
             0.4453326682233367, 0.5589179261516751, 0.9499366422608663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 277}], {
             RGBColor[
             0.5366504250855848, 0.6347160167674466, 0.9566662337594685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 285}], {
             RGBColor[
             0.6368705635576004, 0.7140446615937114, 0.9659469825773204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 293}], {
             RGBColor[
             0.6784243836546143, 0.7468163788730714, 0.9700065320595024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 330}], {
             RGBColor[
             0.7013361772814594, 0.7650856211870474, 0.9721918793892306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 144}], {
             RGBColor[
             0.9010471295870442, 0.9205445959952014, 0.8452071742944741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 233}], {
             RGBColor[
             0.7668567793575712, 0.8177936114523028, 0.9773967751484669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 242}], {
             RGBColor[
             0.8755015832460801, 0.9034557569912118, 0.9805218752455136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 256}], {
             RGBColor[
             0.5575646071020217, 0.6451757424204061, 0.9611280617092144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 257}], {
             RGBColor[
             0.8714956473841483, 0.9004681365845011, 0.9873028797443595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 317}], {
             RGBColor[
             0.9009576086576079, 0.9206568618399606, 0.857542214945461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 366}], {
             RGBColor[
             0.653777001941597, 0.7272827833096175, 0.9676110798405365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 381}], {
             RGBColor[
             0.6852669117421597, 0.7528477106899845, 0.9700900808913773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 382}], {
             RGBColor[
             0.7606717685723423, 0.812961834019059, 0.9767803110756073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 184}], {
             RGBColor[
             0.46709587444884026`, 0.5670006814403532, 0.9532983755548127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 305}], {
             RGBColor[
             0.3248591148671768, 0.45060333071161207`, 0.9421109292763392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 325}], {
             RGBColor[
             0.45467064744518004`, 0.5572939996698711, 0.9520599450474359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 141}], {
             RGBColor[
             0.8024157081228147, 0.8441966506658751, 0.8906451554682946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 168}], {
             RGBColor[
             0.43054260135879807`, 0.53715067040502, 0.9500800581906832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 191}], {
             RGBColor[
             0.7682801788318845, 0.8193075994017713, 0.9776071850214008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 216}], {
             RGBColor[
             0.5087586076390077, 0.6106923775498047, 0.9548517320351805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 219}], {
             RGBColor[
             0.7859019844828903, 0.8328149323850922, 0.9604335087346265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 220}], {
             RGBColor[
             0.6044242317335169, 0.6897378461794337, 0.9620016360824275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 350}], {
             RGBColor[
             0.3980015088073853, 0.5029479189090512, 0.9482268911101126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 357}], {
             RGBColor[
             0.6916074306183388, 0.758589394313196, 0.9701829960703059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 150}], {
             RGBColor[
             0.8076329510973023, 0.8484322435466816, 0.891055875946637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 189}], {
             RGBColor[
             0.9131584178519658, 0.9312620584347353, 0.9013611523424835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 219}], {
             RGBColor[
             0.9733013075199966, 0.9786745496091538, 0.8882431750082729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 220}], {
             RGBColor[
             0.7918235547706232, 0.8355974634034953, 0.889811302356074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 273}], {
             RGBColor[
             0.794778716230354, 0.8379965966050114, 0.890043943491297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 339}], {
             RGBColor[
             0.6438243329388476, 0.7102143400471985, 0.879363689341258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 350}], {
             RGBColor[
             0.5854008318444915, 0.6488075361331129, 0.876036557383759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 357}], {
             RGBColor[
             0.8790067536554451, 0.9044490115372577, 0.8979926623439523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 394}], {
             RGBColor[
             0.8267154927134532, 0.863598681061071, 0.8927807581428712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 202}], {
             RGBColor[
             0.7463617472700474, 0.8013721347739806, 0.9749624669041767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 214}], {
             RGBColor[
             0.5159257844012242, 0.6178908198254593, 0.9550347141279353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 217}], {
             RGBColor[
             0.5449958228419899, 0.6414911866219808, 0.9573232140410519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 257}], {
             RGBColor[
             0.7459297873490013, 0.8010499797721338, 0.9756936623773169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 268}], {
             RGBColor[
             0.7677582102600085, 0.8173295818384008, 0.9387438361534715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 275}], {
             RGBColor[
             0.4913349878902532, 0.5972073225698271, 0.9532976588790758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 279}], {
             RGBColor[
             0.6361872071712591, 0.7143883959177965, 0.965278867451098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 300}], {
             RGBColor[
             0.6945757752887628, 0.7601096009216699, 0.9710699373803455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 306}], {
             RGBColor[
             0.5475142076132973, 0.6435357248312692, 0.9575214705153965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 338}], {
             RGBColor[
             0.5437229272323212, 0.6404577926227579, 0.9572230070358885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 363}], {
             RGBColor[
             0.542113816504348, 0.6391514440441772, 0.9570963319450156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 381}], {
             RGBColor[
             0.5597010517070127, 0.6534295538776173, 0.9584808635243347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 223}], {
             RGBColor[
             0.5562351087893764, 0.6454806057269553, 0.9604484492526557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 234}], {
             RGBColor[
             0.5188863483920749, 0.608972503985311, 0.958220881688419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 260}], {
             RGBColor[
             0.7212955562075808, 0.7822008376494093, 0.9728556582187136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 267}], {
             RGBColor[
             0.539929281911024, 0.6310899613127712, 0.9594192456220927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 272}], {
             RGBColor[
             0.7890666821734633, 0.8351441563335911, 0.9796104506978127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 290}], {
             RGBColor[
             0.6343663811109422, 0.7120295944960595, 0.9657375777854389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 291}], {
             RGBColor[
             0.7250747624937259, 0.7851531823231774, 0.9732323341826259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 321}], {
             RGBColor[
             0.6759512363155853, 0.745790053327567, 0.9690112899174923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 331}], {
             RGBColor[
             0.5493998866755482, 0.6395602798802098, 0.9600129149437121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 342}], {
             RGBColor[
             0.7967288819735561, 0.8411299250522988, 0.9803741471665579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 398}], {
             RGBColor[
             0.6169624490701591, 0.6979002984271483, 0.9643674765024848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 207}], {
             RGBColor[
             0.7392098636185443, 0.791679677837922, 0.8307425389858203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 233}], {
             RGBColor[
             0.8609186030918088, 0.8891958861090263, 0.8412075377958301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 242}], {
             RGBColor[
             0.9695634069803176, 0.9748580316479353, 0.8443326378928767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 317}], {
             RGBColor[
             0.9950194323918453, 0.9920591364966842, 0.7213529775928241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 358}], {
             RGBColor[
             0.6601489612315025, 0.7240154720374132, 0.8254798341978006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 366}], {
             RGBColor[
             0.7478388256758346, 0.7986850579663409, 0.8314218424878996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 370}], {
             RGBColor[
             0.6603843141820395, 0.724219322933985, 0.8254948306796943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 391}], {
             RGBColor[
             0.8228905150309611, 0.8594880546917183, 0.8374172533706126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 162}], {
             RGBColor[
             0.6940339530336639, 0.7590247134314376, 0.9717696798703293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 164}], {
             RGBColor[
             0.7076323379345049, 0.769508381749372, 0.9606090403174121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 227}], {
             RGBColor[
             0.46871019863189056`, 0.579559080260015, 0.9513177302597838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 280}], {
             RGBColor[
             0.7297116610418976, 0.7830944166191796, 0.7583461399095361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 359}], {
             RGBColor[
             0.3222794311892698, 0.4412269741060385, 0.9422881961768015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 154}], {
             RGBColor[
             0.54076978014322, 0.6294594118363277, 0.9598651085282877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 159}], {
             RGBColor[
             0.8647124253330145, 0.895155174886862, 0.9859253485989056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 165}], {
             RGBColor[
             0.8479140485287842, 0.881788704801566, 0.9852973351465458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 192}], {
             RGBColor[
             0.7059841412476134, 0.7698867012058352, 0.9715707315832609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 228}], {
             RGBColor[
             0.5662691523021568, 0.6533802721600297, 0.9614227328011375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 262}], {
             RGBColor[
             0.6257182301895465, 0.7047232186708104, 0.9652519050410497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 297}], {
             RGBColor[
             0.868288832928056, 0.8978224538154138, 0.9798714234169913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 307}], {
             RGBColor[
             0.6532509439809145, 0.7270755160612645, 0.96741938112636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 314}], {
             RGBColor[
             0.6946702780454843, 0.760701597374618, 0.9706800628279428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 332}], {
             RGBColor[
             0.7701015400218649, 0.8203284431443434, 0.9777201825674713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 385}], {
             RGBColor[
             0.5113117008183279, 0.5984971027157606, 0.9581875144900581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 172}], {
             RGBColor[
             0.2390919061370471, 0.3686311310254108, 0.9369273023985025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 211}], {
             RGBColor[
             0.3393384965891258, 0.4589580811442403, 0.9432778036934978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 328}], {
             RGBColor[
             0.5682587435776187, 0.6413239679243555, 0.9640353738149032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 347}], {
             RGBColor[
             0.3356507917074627, 0.4559642361920945, 0.9429874940567051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 364}], {
             RGBColor[
             0.23396660835433944`, 0.36324411809313667`, 0.9366354242719759]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 372}], {
             RGBColor[
             0.4119502703246251, 0.5179075901858479, 0.9489940685076476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 387}], {
             RGBColor[
             0.23975636225883246`, 0.36932951653835855`, 0.9369651421916634]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 161}], {
             RGBColor[
             0.6619172939828173, 0.7334240520048589, 0.9686968217958785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 168}], {
             RGBColor[
             0.35642321217759765`, 0.47697721122729037`, 0.9442451083660703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 170}], {
             RGBColor[
             0.5747994184143094, 0.6650672583844809, 0.9600932432506408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 251}], {
             RGBColor[
             0.40475773401346693`, 0.5246370784334649, 0.9471127604449335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.44297816880018837`, 0.5577416980308146, 0.9495481327525399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 312}], {
             RGBColor[
             0.6071224290670687, 0.690318239970396, 0.9633148988767996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 326}], {
             RGBColor[
             0.47843713894643625`, 0.5874558486010308, 0.9520834706323013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 356}], {
             RGBColor[
             0.5055587831288759, 0.609474421164482, 0.9542185858121991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 199}], {
             RGBColor[
             0.5837943865549418, 0.657813326113432, 0.964895804324426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 212}], {
             RGBColor[
             0.7430441119422263, 0.798802978211431, 0.9756398979294272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 238}], {
             RGBColor[
             0.869876021632304, 0.8991127138348238, 0.9874419432462418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 259}], {
             RGBColor[
             0.6791028679683266, 0.7463771308606398, 0.9707486334870559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 274}], {
             RGBColor[
             0.7732304847722195, 0.8233096355554181, 0.9780162797749312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 287}], {
             RGBColor[
             0.8888841415772876, 0.9142361026492085, 0.9892637570115241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 299}], {
             RGBColor[
             0.5864792949987803, 0.6606353351209338, 0.9650487058883365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 318}], {
             RGBColor[
             0.6110739130749678, 0.6864858381078589, 0.9664493330032984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 336}], {
             RGBColor[
             0.8348930626499278, 0.8717837603974559, 0.9839551688292173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 367}], {
             RGBColor[
             0.9255317434980845, 0.9434579056481982, 0.9927592379984302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 186}], {
             RGBColor[
             0.43204210835403256`, 0.5374786870535561, 0.9502790591049046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 189}], {
             RGBColor[
             0.7309763377893471, 0.7896380340914803, 0.9739622065471795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 226}], {
             RGBColor[
             0.6387142113812012, 0.7174286524584106, 0.9648018087485378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 241}], {
             RGBColor[
             0.775304500637504, 0.8249841078906743, 0.9781902662918548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 255}], {
             RGBColor[
             0.5908248392877088, 0.6786972467462786, 0.9609310420928776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 266}], {
             RGBColor[
             0.6330311263808222, 0.7129622119800336, 0.9642536756195713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 365}], {
             RGBColor[
             0.6274962976281288, 0.7084687886574033, 0.9638179536254136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 374}], {
             RGBColor[
             0.7981277832544239, 0.8099938715167998, 0.6523695572247235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 399}], {
             RGBColor[
             0.584704431680237, 0.6737284241293122, 0.9604492211862257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 171}], {
             RGBColor[
             0.8587582235003903, 0.8902145133209525, 0.9863903200516251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 182}], {
             RGBColor[
             0.6111806001921718, 0.6903545305201095, 0.9651278930140591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 244}], {
             RGBColor[
             0.8394928514861699, 0.8748528286214053, 0.9845527716705083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 249}], {
             RGBColor[
             0.5564432291769413, 0.6394240573811418, 0.9617689500899813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 253}], {
             RGBColor[
             0.6405304582152719, 0.7157759023729623, 0.9669980400142306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 270}], {
             RGBColor[
             0.615206042799501, 0.6938411665819498, 0.965384390657439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 308}], {
             RGBColor[
             0.6762292570829751, 0.7451505885148197, 0.9696998503515308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 386}], {
             RGBColor[
             0.7004873576899331, 0.7648444074025268, 0.9716095368916611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 397}], {
             RGBColor[
             0.7507878907836779, 0.805420111437001, 0.9757475081412588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 156}], {
             RGBColor[
             0.45165970273044276`, 0.5652212329569897, 0.9501123571921883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 175}], {
             RGBColor[
             0.5208925837716543, 0.6214276046919933, 0.955562623196152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 242}], {
             RGBColor[
             0.6895437345496038, 0.7545131765413493, 0.9642952837356986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 256}], {
             RGBColor[
             0.37160675840554536`, 0.49623316197054357`, 0.9449014701993993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 261}], {
             RGBColor[
             0.45165970273044276`, 0.5652212329569897, 0.9501123571921883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 264}], {
             RGBColor[
             0.46659710053285947`, 0.5773480854150941, 0.9512882838646857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 317}], {
             RGBColor[
             0.7149997599611315, 0.7717142813900981, 0.841315623435646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 333}], {
             RGBColor[
             0.7132530668810138, 0.7709919789135049, 0.8702628480699879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 381}], {
             RGBColor[
             0.49930906304568334`, 0.6039051302401219, 0.9538634893815622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 154}], {
             RGBColor[
             0.3165252623864808, 0.4467454202867325, 0.941456860893243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 188}], {
             RGBColor[
             0.6547275158538362, 0.6835710950961937, 0.6314389253656528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 195}], {
             RGBColor[
             0.429023371705826, 0.5443752816170585, 0.9490124675017042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 203}], {
             RGBColor[
             0.2713541624793248, 0.39926773027115986`, 0.9388844335781843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 258}], {
             RGBColor[
             0.6414881481863264, 0.7132020771137522, 0.965790099732412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 278}], {
             RGBColor[
             0.49949213034269885`, 0.6013938456387184, 0.9546907158101485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 284}], {
             RGBColor[
             0.5299233062981613, 0.6251669115806292, 0.9577238110338813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 312}], {
             RGBColor[
             0.5458071980941401, 0.6375755285736967, 0.9593069689246962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 327}], {
             RGBColor[
             0.29552948815645763`, 0.42467753036200495`, 0.9402611826113076]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 337}], {
             RGBColor[
             0.41104524022081274`, 0.529779824571931, 0.9475971631351383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[
             0.44424355215594746`, 0.5567317097677826, 0.9502106558600958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 361}], {
             RGBColor[
             0.3884083546771544, 0.5108415276749851, 0.945970014797374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 369}], {
             RGBColor[
             0.5399085945881907, 0.6329674946838019, 0.958719051252807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 392}], {
             RGBColor[
             0.6181801364302584, 0.6946976192094702, 0.9663655041787413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 192}], {
             RGBColor[
             0.45411774109990444`, 0.5614134376500173, 0.9514696152002432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[
             0.24373228008835496`, 0.37350845826493695`, 0.9371915648302114]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 222}], {
             RGBColor[
             0.45692715022676933`, 0.5636942425416451, 0.9516907821779148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 228}], {
             RGBColor[
             0.3144027521544478, 0.4449070086042116, 0.94132161641812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 312}], {
             RGBColor[
             0.5181853157031704, 0.6118162565674738, 0.9576141001767232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 332}], {
             RGBColor[
             0.5182351398741558, 0.6118551795885254, 0.9576190661844537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 356}], {
             RGBColor[
             0.4166216697649776, 0.5309724377615598, 0.9485177871121228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 361}], {
             RGBColor[
             0.36078647228618455`, 0.48508225566876223`, 0.944277146049401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 385}], {
             RGBColor[
             0.25944530067061883`, 0.39002383915994265`, 0.9380863981070404]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 170}], {
             RGBColor[
             0.8389547063862745, 0.8720234230028837, 0.8378890381933072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 180}], {
             RGBColor[
             0.8067530081041492, 0.8465004634272675, 0.8349302215538628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 183}], {
             RGBColor[
             0.8625273099227396, 0.8904385200439926, 0.8402385350153174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 239}], {
             RGBColor[
             0.8701809476153789, 0.8964175999792834, 0.8410013780932091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 271}], {
             RGBColor[
             0.8166541987711553, 0.8545386960542993, 0.8357096795524259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 326}], {
             RGBColor[
             0.7425924269184013, 0.7944120132194337, 0.8298792655749676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 335}], {
             RGBColor[
             0.8019223123099988, 0.8425786869612106, 0.8345499314855254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 337}], {
             RGBColor[
             0.7365157591657063, 0.7894787005870332, 0.8294008880299081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 354}], {
             RGBColor[
             0.6814539463632381, 0.7424555614227366, 0.8257076519994497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 175}], {
             RGBColor[
             0.5374826780422429, 0.6353916772102302, 0.9567317517608596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 202}], {
             RGBColor[
             0.7025598528793068, 0.765811783654722, 0.9715142213261116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 214}], {
             RGBColor[
             0.4721238900104835, 0.582330468706201, 0.9515864685498703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 256}], {
             RGBColor[
             0.388196852676134, 0.5101972344887804, 0.9460705987641067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 261}], {
             RGBColor[
             0.46824979700103136`, 0.5791853054752265, 0.9512814857568959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 264}], {
             RGBColor[
             0.4831871948034481, 0.5913121579333308, 0.9524574124293932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 295}], {
             RGBColor[
             0.5454194257341849, 0.6418350865329576, 0.957356561612434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 310}], {
             RGBColor[
             0.4344401558260481, 0.5503065269079954, 0.9490151428900878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 363}], {
             RGBColor[
             0.4983119221136074, 0.6035910929249186, 0.9536480863669505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 381}], {
             RGBColor[
             0.515899157316272, 0.6178692027583588, 0.9550326179462696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 187}], {
             RGBColor[
             0.47961177362371504`, 0.5859230380983661, 0.9528629507055104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 218}], {
             RGBColor[
             0.5548082352886061, 0.6494573450902871, 0.9580956830929006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 253}], {
             RGBColor[
             0.5181653290979287, 0.619316190092089, 0.9553195491687567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 298}], {
             RGBColor[
             0.5480348844046323, 0.6439584337066971, 0.9575624600997124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.6019475158704537, 0.6859365204932296, 0.9629963111120772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 265}], {
             RGBColor[
             0.6957962265620632, 0.7600861485126935, 0.966990522182574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 311}], {
             RGBColor[
             0.6557885567202995, 0.7283321976104062, 0.9682738779200575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 322}], {
             RGBColor[
             0.7225248103542553, 0.7778836951031671, 0.8158988451962002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 362}], {
             RGBColor[
             0.4739340063747923, 0.5837150673405884, 0.951752435437913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 165}], {
             RGBColor[
             0.9199902935708697, 0.9390112042962823, 0.991256458834146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 167}], {
             RGBColor[
             0.9443346832052125, 0.9580054783948141, 0.979111040880476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 192}], {
             RGBColor[
             0.7780603862896991, 0.8271092007005516, 0.9775298552708611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 201}], {
             RGBColor[
             0.8921135259363778, 0.9167830264792378, 0.988597547851284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 210}], {
             RGBColor[
             0.844420924291563, 0.8793033000521602, 0.9839028814099521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 228}], {
             RGBColor[
             0.6383453973442423, 0.710602771654746, 0.9673818564887378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 236}], {
             RGBColor[
             0.7352271607816647, 0.7923352586183099, 0.9741578668555937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 243}], {
             RGBColor[
             0.6618604848452639, 0.7309703585454677, 0.9688802170707276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 263}], {
             RGBColor[
             0.8518714508766114, 0.8851237080464993, 0.9846454802708202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 166}], {
             RGBColor[
             0.5184391254904871, 0.612833791256457, 0.9575096972291486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 185}], {
             RGBColor[
             0.5705624970683666, 0.6592536414148473, 0.9607843340850999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 213}], {
             RGBColor[
             0.813034213877512, 0.8543865283532761, 0.9818616488828329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 224}], {
             RGBColor[
             0.696647747518929, 0.7629457821715504, 0.9703989949954968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 247}], {
             RGBColor[
             0.5797391249281687, 0.6672019752362808, 0.9613690606977531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 289}], {
             RGBColor[
             0.5518238426760897, 0.6430231608124118, 0.9595903235971655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 302}], {
             RGBColor[
             0.5068618891549007, 0.6006653818285759, 0.9568503907468233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 340}], {
             RGBColor[
             0.7000166834140944, 0.7655776204977147, 0.970734779041031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 370}], {
             RGBColor[
             0.533781368120322, 0.6273956761933446, 0.9584406730728058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 400}], {
             RGBColor[
             0.5246975612533957, 0.6194118040510198, 0.9578661058873202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 170}], {
             RGBColor[
             0.7699391056738192, 0.8205011953029857, 0.9776244755010965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 222}], {
             RGBColor[
             0.7410039508501773, 0.7976301628630722, 0.9749228131284469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 239}], {
             RGBColor[
             0.8011653469029236, 0.8448953722793854, 0.9807368154009983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 251}], {
             RGBColor[
             0.5998974212729766, 0.6800710153519697, 0.9646439926953893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 312}], {
             RGBColor[
             0.8022621163265784, 0.8457521768889009, 0.9808461311272553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 326}], {
             RGBColor[
             0.6735768262059459, 0.7428897855195356, 0.969614702882757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 327}], {
             RGBColor[
             0.5519844063888958, 0.6328541786772091, 0.9618003448138668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 337}], {
             RGBColor[
             0.667500158453251, 0.7379564728871352, 0.9691363253376974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.7006984703883856, 0.7649083580829869, 0.9717498180626548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 179}], {
             RGBColor[
             0.6086239304410863, 0.684092884521414, 0.9662822181449975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 231}], {
             RGBColor[
             0.610370348184198, 0.6859284802987048, 0.9663816740518743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 313}], {
             RGBColor[
             0.5930969526118688, 0.6677730463556519, 0.9653979797277288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 359}], {
             RGBColor[
             0.550681521844394, 0.6231917393253991, 0.9629824836935279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 164}], {
             RGBColor[
             0.8709174543545514, 0.899775190060583, 0.9750328238246379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 169}], {
             RGBColor[
             0.6260613685316944, 0.7050084434648488, 0.9652743717601738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 209}], {
             RGBColor[
             0.5454816570958798, 0.634470463451787, 0.9601241704298669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 227}], {
             RGBColor[
             0.6319953150519371, 0.7098258885712261, 0.9657415137670096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 240}], {
             RGBColor[
             0.7066163264479528, 0.7704065872607662, 0.9716159531298754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 245}], {
             RGBColor[
             0.7011333581338135, 0.7659552665784402, 0.9711843137794116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 280}], {
             RGBColor[
             0.8929967774619441, 0.9133612249303906, 0.772769923416762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 304}], {
             RGBColor[
             0.758331073338802, 0.8111332651126747, 0.9765470124497686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 315}], {
             RGBColor[
             0.5378452242856191, 0.6264440883903981, 0.9596892868784126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 319}], {
             RGBColor[
             0.6126116765013878, 0.6935382734355247, 0.9643678344508821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 329}], {
             RGBColor[
             0.6005746427611941, 0.6831123998086759, 0.9636008453048881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 371}], {
             RGBColor[
             0.8210740304359582, 0.8603907114752678, 0.9827363791997136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 169}], {
             RGBColor[
             0.7047767276676131, 0.7671900686909328, 0.9603842362167573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 209}], {
             RGBColor[
             0.6241970162317986, 0.696652088677871, 0.9552340348864503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 227}], {
             RGBColor[
             0.7107106741878557, 0.7720075137973101, 0.960851378223593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 245}], {
             RGBColor[
             0.7798487172697322, 0.8281368918045241, 0.9662941782359951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 280}], {
             RGBColor[
             0.9717121365978627, 0.9755428501564746, 0.7678797878733454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 304}], {
             RGBColor[
             0.8370464324747208, 0.8733148903387586, 0.971656876906352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 315}], {
             RGBColor[
             0.616560583421538, 0.6886257136164821, 0.954799151334996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 228}], {
             RGBColor[
             0.6215470205400119, 0.6972363015694499, 0.966753843036378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 262}], {
             RGBColor[
             0.6809960984274017, 0.7485792480802307, 0.9705830152762902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 298}], {
             RGBColor[
             0.7008913812414033, 0.764731134940914, 0.9721492448182306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 307}], {
             RGBColor[
             0.7085288122187696, 0.7709315454706848, 0.9727504913616004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 314}], {
             RGBColor[
             0.7499481462833395, 0.8045576267840382, 0.9760111730631833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 332}], {
             RGBColor[
             0.82537940825972, 0.8641844725537637, 0.9830512928027118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 385}], {
             RGBColor[
             0.566589569056183, 0.642353132125181, 0.9635186247252986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 185}], {
             RGBColor[
             0.34709856136100686`, 0.4737878555006605, 0.9433844095861885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 213}], {
             RGBColor[
             0.5895702781701524, 0.6689207424390892, 0.9644617243839215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 224}], {
             RGBColor[
             0.4731838118115693, 0.5774799962573635, 0.9529990704965854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 247}], {
             RGBColor[
             0.35627518922080903`, 0.48173618932209394`, 0.9439691361988416]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 289}], {
             RGBColor[
             0.32835990696872996`, 0.45755737489822496`, 0.9421903990982541]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 302}], {
             RGBColor[
             0.28339795344754104`, 0.41519959591438904`, 0.939450466247912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 340}], {
             RGBColor[
             0.4765527477067347, 0.5801118345835279, 0.9533348545421195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 400}], {
             RGBColor[
             0.30123362554603594`, 0.4339460181368329, 0.9404661813884088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 192}], {
             RGBColor[
             0.7856063991198114, 0.8327370047137874, 0.9647564238648312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[
             0.8996595387664902, 0.9224108304924736, 0.9758241164452541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.5752209381082619, 0.6448320253287071, 0.9504783734947994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 228}], {
             RGBColor[
             0.6458914101743547, 0.7162305756679818, 0.9546084250827079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 243}], {
             RGBColor[
             0.6694064976753763, 0.7365981625587035, 0.9561067856646976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 348}], {
             RGBColor[
             0.6281541968671603, 0.7004682364467575, 0.9534928442733799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 351}], {
             RGBColor[
             0.8381703737471482, 0.8741531238994501, 0.9697543375029645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 170}], {
             RGBColor[
             0.4644450238685994, 0.5640543545254171, 0.9531727620712884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 180}], {
             RGBColor[
             0.43224332558647416`, 0.5385313949498008, 0.9502139454318439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 220}], {
             RGBColor[
             0.4199504480066065, 0.5285514831426402, 0.9492462050784625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 251}], {
             RGBColor[
             0.294403339467757, 0.42362417457440116`, 0.9401922792655812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 282}], {
             RGBColor[
             0.3326237742544784, 0.4567287941717509, 0.9426276515731876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 350}], {
             RGBColor[
             0.2135277250804749, 0.34176155587225787`, 0.9354714601061475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 357}], {
             RGBColor[
             0.5071336468914285, 0.5974030312764027, 0.9574275650663407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 394}], {
             RGBColor[
             0.4548423859494366, 0.5565527008002159, 0.9522156608652597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 209}], {
             RGBColor[
             0.37934093040894157`, 0.5018853420821368, 0.9454755828219863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 227}], {
             RGBColor[
             0.4658545883649988, 0.5772407672015758, 0.951092926159129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 240}], {
             RGBColor[
             0.5404755997610146, 0.6378214658911159, 0.9569673655219948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 245}], {
             RGBColor[
             0.5349926314468753, 0.6333701452087899, 0.956535726171531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 280}], {
             RGBColor[
             0.7268560507750057, 0.7807761035607403, 0.7581213358088814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 292}], {
             RGBColor[
             0.44799357751257274`, 0.5622719756484954, 0.9498162673335193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 304}], {
             RGBColor[
             0.5921903466518638, 0.6785481437430244, 0.961898424841888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 315}], {
             RGBColor[
             0.37170449759868096`, 0.49385896702074783`, 0.945040699270532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 329}], {
             RGBColor[
             0.4344339160742559, 0.5505272784390256, 0.9489522576970075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 353}], {
             RGBColor[
             0.35609770999723667`, 0.4774552437241436, 0.9441519158048028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 378}], {
             RGBColor[
             0.6217755951428156, 0.7016603647203725, 0.9648472059215998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 180}], {
             RGBColor[
             0.650619531823186, 0.7266214421069914, 0.9660620803164144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 239}], {
             RGBColor[
             0.7140474713344156, 0.7765385786590073, 0.9721332368557607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 251}], {
             RGBColor[
             0.5127795457044687, 0.6117142217315916, 0.9560404141501515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 271}], {
             RGBColor[
             0.660520722490192, 0.7346596747340233, 0.9668415383149775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 282}], {
             RGBColor[
             0.5509999804911901, 0.6448188413289414, 0.958475786457758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 326}], {
             RGBColor[
             0.586458950637438, 0.6745329918991576, 0.9610111243375192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 182}], {
             RGBColor[
             0.6277296423647784, 0.7035502875367632, 0.9667063554299866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 244}], {
             RGBColor[
             0.8560418936587765, 0.8880485856380589, 0.9861312340864358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 253}], {
             RGBColor[
             0.6570795003878784, 0.7289716593896158, 0.9685765024301582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 270}], {
             RGBColor[
             0.6317550849721075, 0.7070369235986034, 0.9669628530733665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 308}], {
             RGBColor[
             0.6927782992555818, 0.7583463455314732, 0.9712783127674585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 397}], {
             RGBColor[
             0.7673369329562845, 0.8186158684536545, 0.9773259705571863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 211}], {
             RGBColor[
             0.3670494611560037, 0.48808406188066067`, 0.9448559021308831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 328}], {
             RGBColor[
             0.5959697081444966, 0.6704499486607759, 0.9656134722522887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 347}], {
             RGBColor[
             0.3633617562743406, 0.48509021692851484`, 0.9445655924940906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 364}], {
             RGBColor[
             0.26167757292121735`, 0.39237009882955703`, 0.9382135227093612]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 387}], {
             RGBColor[
             0.2674673268257104, 0.3984554972747789, 0.9385432406290488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 175}], {
             RGBColor[
             0.4690099867433769, 0.5764895068412482, 0.9522567099914894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 197}], {
             RGBColor[
             0.3039471455517543, 0.4347124201666045, 0.940697079283477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 204}], {
             RGBColor[
             0.3378490514675935, 0.4670496004193311, 0.9427484207046971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 214}], {
             RGBColor[
             0.4036511987116175, 0.5234282983372189, 0.9471114267805001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 261}], {
             RGBColor[
             0.3997771057021653, 0.5202831351062446, 0.9468064439875257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 295}], {
             RGBColor[
             0.4769467344353189, 0.5829329161639756, 0.9528815198430638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 310}], {
             RGBColor[
             0.365967464527182, 0.4914043565390135, 0.9445401011207177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 345}], {
             RGBColor[
             0.49520412457317164`, 0.5974985784519932, 0.9544941854279824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 193}], {
             RGBColor[
             0.6521829141062623, 0.7240488582188891, 0.9685782853619528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 232}], {
             RGBColor[
             0.4962385963318706, 0.6007109777855191, 0.9538155724609199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 235}], {
             RGBColor[
             0.3768154663829514, 0.5008003505100542, 0.945231326206456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 260}], {
             RGBColor[
             0.5389120501768073, 0.6349534327292148, 0.9574496804032121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 267}], {
             RGBColor[
             0.3575457758802504, 0.4838425563925766, 0.9440132678065911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 272}], {
             RGBColor[
             0.6066831761426899, 0.6878967514133966, 0.9642044728823113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 275}], {
             RGBColor[
             0.4180268171160044, 0.53649555117231, 0.9478572770333995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 281}], {
             RGBColor[
             0.47729050878360135`, 0.5853280667122176, 0.9523239095999885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 291}], {
             RGBColor[
             0.5426912564629525, 0.6379057774029829, 0.9578263563671243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 338}], {
             RGBColor[
             0.4704147564580723, 0.5797460212252408, 0.9517826251902122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 384}], {
             RGBColor[
             0.31083495465395994`, 0.43474652164662353`, 0.9413531556402213]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 398}], {
             RGBColor[
             0.4345789430393856, 0.5506528935069537, 0.9489614986869832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 204}], {
             RGBColor[
             0.47555462380767116`, 0.5821581425233167, 0.9526737284780309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 214}], {
             RGBColor[
             0.5413567710516951, 0.6385368404412046, 0.957036734553834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 256}], {
             RGBColor[
             0.4574297337173456, 0.566403606223784, 0.9515208647680704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 261}], {
             RGBColor[
             0.5374826780422429, 0.6353916772102302, 0.9567317517608596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 264}], {
             RGBColor[
             0.5524200758446597, 0.6475185296683345, 0.9579076784333569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 295}], {
             RGBColor[
             0.6146523067753965, 0.6980414582679613, 0.9628068276163977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 310}], {
             RGBColor[
             0.5036730368672597, 0.6065128986429991, 0.9544654088940515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 345}], {
             RGBColor[
             0.6329096969132493, 0.7126071205559787, 0.9644194932013161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 186}], {
             RGBColor[
             0.4755289026707372, 0.5717099122568081, 0.9544363291396221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 226}], {
             RGBColor[
             0.6822010056979059, 0.7516598776616626, 0.9689590787832554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 294}], {
             RGBColor[
             0.507508588416526, 0.6053225896048187, 0.9562575249331393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 341}], {
             RGBColor[
             0.6821643931340915, 0.751631275648545, 0.9689554295850582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 368}], {
             RGBColor[
             0.6529001592785759, 0.7280194744953543, 0.9665516689606783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 379}], {
             RGBColor[
             0.7794175415997947, 0.8278197709411798, 0.9785920325822637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 393}], {
             RGBColor[
             0.7887684801670302, 0.8352759555302277, 0.9794839334504881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 399}], {
             RGBColor[
             0.6281912259969415, 0.7079596493325643, 0.9646064912209431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 200}], {
             RGBColor[
             0.5910712451387748, 0.678897290116631, 0.9609504400640878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 225}], {
             RGBColor[
             0.8027473779261911, 0.8455971575522383, 0.9377914143552815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 296}], {
             RGBColor[
             0.5135120797041091, 0.6146295649491968, 0.9552043622251948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 311}], {
             RGBColor[
             0.7415170067737453, 0.7980153507614285, 0.974999267644755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 324}], {
             RGBColor[
             0.8059530425834256, 0.8469799397489701, 0.8872248836862376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 339}], {
             RGBColor[
             0.45974021509099283`, 0.567046155744063, 0.9518150081641062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 360}], {
             RGBColor[
             0.5115569856606184, 0.612936160754609, 0.9550797853615653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 374}], {
             RGBColor[
             0.7962257454691879, 0.8084497115569195, 0.6522198218428756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 375}], {
             RGBColor[
             0.7166309012048715, 0.778239489151406, 0.9726076581863274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 383}], {
             RGBColor[
             0.5111386550576382, 0.612573823812215, 0.9550531297054586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 390}], {
             RGBColor[
             0.755591675212743, 0.8092381093279879, 0.9763417220850713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 209}], {
             RGBColor[
             0.5027674439852352, 0.601101795529708, 0.9558668168540141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 229}], {
             RGBColor[
             0.5014718965080414, 0.599740092988723, 0.9557930373417787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 240}], {
             RGBColor[
             0.6639021133373082, 0.7370379193386871, 0.9673585995540226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 245}], {
             RGBColor[
             0.6584191450231688, 0.7325865986563611, 0.9669269602035588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 248}], {
             RGBColor[
             0.6320280258326607, 0.7111610991911359, 0.9648493546270271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 309}], {
             RGBColor[
             0.506914893231003, 0.6054610276504802, 0.9561030079529593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 315}], {
             RGBColor[
             0.4951310111749745, 0.5930754204683191, 0.9554319333025598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 319}], {
             RGBColor[
             0.5698974633907431, 0.6601696055134457, 0.9601104808750294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 329}], {
             RGBColor[
             0.5578604296505495, 0.6497437318865968, 0.9593434917290353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 334}], {
             RGBColor[
             0.5014480139058857, 0.5997149908596129, 0.9557916772629171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 371}], {
             RGBColor[
             0.7783598173253135, 0.8270220435531889, 0.9784790256238608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 388}], {
             RGBColor[
             0.5052487494239464, 0.603709804869645, 0.9560081235279863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 196}], {
             RGBColor[
             0.4951904120362644, 0.5946496760885239, 0.9551959725564334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 231}], {
             RGBColor[
             0.29655823493649625`, 0.42903188616932064`, 0.9401999248098161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 303}], {
             RGBColor[
             0.5521526049783492, 0.6391489741435813, 0.9608734316069425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 313}], {
             RGBColor[
             0.27928483936416704`, 0.4108764522262678, 0.9392162304856707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 344}], {
             RGBColor[
             0.35628637657767864`, 0.4817307743361465, 0.9439704021121568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 359}], {
             RGBColor[
             0.23686940859669228`, 0.3662951451960149, 0.9368007344514697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 239}], {
             RGBColor[
             0.6818457730522904, 0.751015619083391, 0.9691744202163162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 271}], {
             RGBColor[
             0.6283190242080667, 0.709136715158407, 0.963882721675533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 282}], {
             RGBColor[
             0.518798282209065, 0.6192958817533252, 0.9555169698183135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 326}], {
             RGBColor[
             0.5542572523553128, 0.6490100323235413, 0.9580523076980748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 350}], {
             RGBColor[
             0.39970223303506147`, 0.5043286434538321, 0.9483607783512733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 394}], {
             RGBColor[
             0.6410168939040232, 0.7191197883817901, 0.9651049791103856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 250}], {
             RGBColor[
             0.7274001963084578, 0.7869698288931974, 0.9734641116928637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 265}], {
             RGBColor[
             0.847553847075197, 0.8816690760243018, 0.9800801533564083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 322}], {
             RGBColor[
             0.8742824308673891, 0.8994666226147755, 0.8289884763700346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 362}], {
             RGBColor[
             0.6256916268879261, 0.7052979948521967, 0.9648420666117474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 244}], {
             RGBColor[
             0.6084642703505578, 0.688188602837216, 0.9648688070488698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 253}], {
             RGBColor[
             0.4095018770796599, 0.5291116765887729, 0.9473140753925922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 271}], {
             RGBColor[
             0.6840933260266572, 0.7530747717751323, 0.9691910351369878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 273}], {
             RGBColor[
             0.6648544192395143, 0.7374557605424558, 0.9676764779202662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 335}], {
             RGBColor[
             0.6693614395655008, 0.7411147626820435, 0.9680312870700873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 305}], {
             RGBColor[
             0.5393978006098422, 0.6348200153981762, 0.9577151745104381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 325}], {
             RGBColor[
             0.6692093331878455, 0.7415106843564353, 0.9676641902815348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 213}], {
             RGBColor[
             0.6416936497480318, 0.7153405925974796, 0.9677363612398728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 224}], {
             RGBColor[
             0.5253071833894488, 0.6238998464157539, 0.9562737073525366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 247}], {
             RGBColor[
             0.4083985607986885, 0.5281560394804843, 0.9472437730547929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 289}], {
             RGBColor[
             0.38048327854660946`, 0.5039772250566154, 0.9454650359542053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 302}], {
             RGBColor[
             0.33552132502542054`, 0.46161944607277944`, 0.9427251031038631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 340}], {
             RGBColor[
             0.5286761192846142, 0.6265316847419182, 0.9566094913980707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 400}], {
             RGBColor[
             0.35335699712391544`, 0.4803658682952233, 0.9437408182443601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 189}], {
             RGBColor[
             0.5375675751086961, 0.6203085019416099, 0.9605843355007511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 200}], {
             RGBColor[
             0.39956452024335987`, 0.511111917926641, 0.9477223043995071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 226}], {
             RGBColor[
             0.4453054487005502, 0.5480991203085402, 0.9514239377021094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 241}], {
             RGBColor[
             0.581895737956853, 0.6556545757408039, 0.9648123952454264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 255}], {
             RGBColor[
             0.3974160766070578, 0.5093677145964082, 0.9475531710464491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 288}], {
             RGBColor[
             0.33172165143271626`, 0.4552599605396669, 0.942595340389713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 341}], {
             RGBColor[
             0.4452688361367358, 0.5480705182954225, 0.9514202885039122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 374}], {
             RGBColor[
             0.6047190205737729, 0.6406643393669293, 0.6389916861782949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 393}], {
             RGBColor[
             0.5518729231696745, 0.6317151981771052, 0.9619487923693422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 399}], {
             RGBColor[
             0.39129566899958595`, 0.5043988919794419, 0.9470713501397972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 193}], {
             RGBColor[
             0.6284366040664211, 0.7034809979866246, 0.9670651914842516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 218}], {
             RGBColor[
             0.4369410858192237, 0.5512810514461007, 0.9495037578536611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 232}], {
             RGBColor[
             0.4724922862920294, 0.5801431175532544, 0.9523024785832187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 235}], {
             RGBColor[
             0.3530691563431102, 0.48023249027778964`, 0.9437182323287547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 275}], {
             RGBColor[
             0.39428050707616324`, 0.5159276909400453, 0.9463441831556982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 279}], {
             RGBColor[
             0.5391327263571691, 0.6331087642880147, 0.9583253917277205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 281}], {
             RGBColor[
             0.4535441987437601, 0.564760206479953, 0.9508108157222872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 298}], {
             RGBColor[
             0.43016773493524996`, 0.5457821400625108, 0.9489705348604729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 306}], {
             RGBColor[
             0.4504597267992072, 0.5622560932014873, 0.9505679947920189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 195}], {
             RGBColor[
             0.7396037427822114, 0.7554416844202969, 0.637301663226141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 203}], {
             RGBColor[
             0.5819345335557102, 0.6103341330743982, 0.6271736293026211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 206}], {
             RGBColor[
             0.7298016406065536, 0.747483896294427, 0.6365300058365898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 208}], {
             RGBColor[
             0.7480748597044489, 0.7623189187572377, 0.6379685405809832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 258}], {
             RGBColor[
             0.9520685192627119, 0.9242684799169905, 0.6540792954568488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 278}], {
             RGBColor[
             0.8100725014190843, 0.8124602484419567, 0.6429799115345853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 284}], {
             RGBColor[
             0.8405036773745467, 0.8362333143838675, 0.6460130067583181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 327}], {
             RGBColor[
             0.606109859232843, 0.6357439331652432, 0.6285503783357445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 361}], {
             RGBColor[
             0.6989887257535399, 0.7219079304782234, 0.6342592105218108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 369}], {
             RGBColor[
             0.8504889656645761, 0.8440338974870403, 0.6470082469772438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 392}], {
             RGBColor[
             0.9287605075066439, 0.9057640220127086, 0.6546546999031781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 200}], {
             RGBColor[
             0.6984987496786744, 0.7632712649645652, 0.9714054518417821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 219}], {
             RGBColor[
             0.8966446942120414, 0.9198803401539524, 0.9711495056088153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 241}], {
             RGBColor[
             0.8808299673921676, 0.9078139227787281, 0.9884955426877012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 255}], {
             RGBColor[
             0.6963503060423724, 0.7615270616343324, 0.971236318488724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 339}], {
             RGBColor[
             0.5671677196308924, 0.6514201305919971, 0.9622700199418004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 360}], {
             RGBColor[
             0.6189844902005179, 0.6973101356025431, 0.9655347971392596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 374}], {
             RGBColor[
             0.9036532500090875, 0.8928236864048535, 0.6626748336205699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 266}], {
             RGBColor[
             0.6092547990312848, 0.6936595183263384, 0.9623819160350588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 273}], {
             RGBColor[
             0.5888203088181978, 0.677069878608061, 0.9607732381114806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 365}], {
             RGBColor[
             0.6037199702785914, 0.6891660950037081, 0.9619461940409011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 198}], {
             RGBColor[
             0.703933787599095, 0.7670683002271019, 0.9725416013949579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 216}], {
             RGBColor[
             0.6620224013851839, 0.7316629435097626, 0.969623427861933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 219}], {
             RGBColor[
             0.9391657782290663, 0.95378549834505, 0.975205204561379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 220}], {
             RGBColor[
             0.757688025479693, 0.8107084121393915, 0.97677333190918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 311}], {
             RGBColor[
             0.8914655953306698, 0.9162944838004602, 0.9895099783750128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 323}], {
             RGBColor[
             0.8772380030855058, 0.5963681658739555, 0.46438148149089253`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 339}], {
             RGBColor[
             0.6096888036479173, 0.6853252887830947, 0.9663257188943641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 357}], {
             RGBColor[
             0.8448712243645149, 0.879559960273154, 0.9849546918970584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 201}], {
             RGBColor[
             0.7333852418509768, 0.791514552798211, 0.9742429308356393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 203}], {
             RGBColor[
             0.40894664119274843`, 0.5139357476344446, 0.9488971878851845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 228}], {
             RGBColor[
             0.47961711325884127`, 0.5853342979737193, 0.9530272394730931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 243}], {
             RGBColor[
             0.5031322007598629, 0.6057018848644411, 0.9545256000550828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 332}], {
             RGBColor[
             0.6834495009785493, 0.7522824689580331, 0.9693246892394268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 348}], {
             RGBColor[
             0.46187989995164686`, 0.569571958752495, 0.951911658663765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 361}], {
             RGBColor[
             0.526000833390578, 0.6255095450382699, 0.9559827691043741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 385}], {
             RGBColor[
             0.4246596617750123, 0.5304511285294503, 0.9497920211620137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 232}], {
             RGBColor[
             0.7391842662041178, 0.7958773710856992, 0.9750966446011995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 235}], {
             RGBColor[
             0.6197611362551987, 0.6959667438102344, 0.9665123983467354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 260}], {
             RGBColor[
             0.7818577200490545, 0.8301198260293949, 0.9787307525434916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 275}], {
             RGBColor[
             0.6609724869882516, 0.7316619444724901, 0.969138349173679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 281}], {
             RGBColor[
             0.7202361786558485, 0.7804944600123978, 0.9736049817402679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 338}], {
             RGBColor[
             0.7133604263303195, 0.7749124145254209, 0.9730636973304916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 384}], {
             RGBColor[
             0.5537806245262071, 0.6299129149468037, 0.9626342277805009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 376}], {
             RGBColor[
             0.8392057873639507, 0.8732704424945575, 0.8901373288417767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 377}], {
             RGBColor[
             0.9738497380997818, 0.9291361059551908, 0.5499010115215929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 396}], {
             RGBColor[
             0.8347594456992022, 0.8697969265926078, 0.8896941590580598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 206}], {
             RGBColor[
             0.5040974964585435, 0.6082880828152919, 0.9541035479726412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 208}], {
             RGBColor[
             0.5223707155564388, 0.6231231052781026, 0.9555420827170344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 258}], {
             RGBColor[
             0.7263643751147018, 0.7850726664378553, 0.9716528375929001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 278}], {
             RGBColor[
             0.5843683572710742, 0.6732644349628216, 0.9605534536706367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 284}], {
             RGBColor[
             0.6147995332265366, 0.6970375009047323, 0.9635865488943693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 327}], {
             RGBColor[
             0.3804057150848329, 0.49654811968610807`, 0.9461239204717958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 337}], {
             RGBColor[
             0.49592146714918806`, 0.6016504138960341, 0.9534599009956264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 369}], {
             RGBColor[
             0.624784821516566, 0.704838084007905, 0.9645817891132951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 392}], {
             RGBColor[
             0.7030563633586338, 0.7665682085335733, 0.9722282420392294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 231}], {
             RGBColor[
             0.4969368297793761, 0.5964852718658147, 0.9552954284633102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 234}], {
             RGBColor[
             0.47966872368386604`, 0.578335397498271, 0.9543120353670446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 290}], {
             RGBColor[
             0.5951487564027333, 0.6813924880090195, 0.9618287314640646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 303}], {
             RGBColor[
             0.752531199821229, 0.8066023598400753, 0.9759689352604366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 313}], {
             RGBColor[
             0.4796634342070468, 0.5783298379227618, 0.9543117341391647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 344}], {
             RGBColor[
             0.5566649714205585, 0.6491841600326405, 0.9590659057656508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 204}], {
             RGBColor[
             0.31049178261604854`, 0.4403810558486729, 0.9411140977700185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 215}], {
             RGBColor[
             0.22915428223562018`, 0.3581860582232639, 0.9363613694187133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 295}], {
             RGBColor[
             0.4495894655837739, 0.5562643715933174, 0.9512471969083852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 310}], {
             RGBColor[
             0.33861019567563705`, 0.46473581196835534`, 0.942905778186039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 345}], {
             RGBColor[
             0.4678468557216267, 0.570830033881335, 0.9528598624933038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 216}], {
             RGBColor[
             0.4444122164062181, 0.5584530783751351, 0.9497861484087378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 219}], {
             RGBColor[
             0.7215555932501005, 0.7805756332104227, 0.9553679251081837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 224}], {
             RGBColor[
             0.5688580182300702, 0.6607252111324657, 0.9592963451023481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 247}], {
             RGBColor[
             0.4519493956393099, 0.5649814041971961, 0.9502664108046044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 302}], {
             RGBColor[
             0.3790721598660419, 0.49844481078949127`, 0.9457477408536746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 311}], {
             RGBColor[
             0.6738554103517042, 0.7430846186658329, 0.9696726989218175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 323}], {
             RGBColor[
             0.7321645464328619, 0.4808949224508706, 0.4511566285220956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 340}], {
             RGBColor[
             0.5722269541252356, 0.66335704945863, 0.9596321291478822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 212}], {
             RGBColor[
             0.40296658342006764`, 0.5144819008047151, 0.9479347801719626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 238}], {
             RGBColor[
             0.5297984931101454, 0.6147916364281081, 0.9597368254887774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 252}], {
             RGBColor[
             0.31790825316157595`, 0.44376549468982807`, 0.9416979536646433]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 277}], {
             RGBColor[
             0.40922601002382397`, 0.5195635853055995, 0.9484275451632455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 287}], {
             RGBColor[
             0.5488066130551289, 0.6299150252424928, 0.9615586392540597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 293}], {
             RGBColor[
             0.5509999685928535, 0.6316639474112243, 0.9617678434632795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 299}], {
             RGBColor[
             0.24640176647662163`, 0.376314257714218, 0.937343588130872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 336}], {
             RGBColor[
             0.4948155341277691, 0.58746268299074, 0.9562500510717529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 367}], {
             RGBColor[
             0.5854542149759259, 0.6591368282414825, 0.9650541202409657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 225}], {
             RGBColor[
             0.7721718276007544, 0.8207745483852036, 0.9353843950317318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 241}], {
             RGBColor[
             0.7428269125268313, 0.7986173387637592, 0.9756335115864574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 255}], {
             RGBColor[
             0.5583472511770361, 0.6523304776193635, 0.9583742873874802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 288}], {
             RGBColor[
             0.49265282600269455`, 0.5982227235626223, 0.9534164567307442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 296}], {
             RGBColor[
             0.48293652937867243`, 0.5898069557821621, 0.9527973429016452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 339}], {
             RGBColor[
             0.42916466476555615`, 0.5422235465770283, 0.9494079888405567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 355}], {
             RGBColor[
             0.5674512010865496, 0.6597214742841762, 0.9590909836732244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 360}], {
             RGBColor[
             0.4809814353351816, 0.5881135515875743, 0.9526727660380157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 374}], {
             RGBColor[
             0.7656501951437512, 0.7836271023898848, 0.649812802519326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 375}], {
             RGBColor[
             0.6860553508794348, 0.7534168799843712, 0.9702006388627777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 383}], {
             RGBColor[
             0.4805631047322015, 0.5877512146451803, 0.952646110381909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 399}], {
             RGBColor[
             0.5522268435695643, 0.6473616550023972, 0.9578924664808282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 210}], {
             RGBColor[
             0.7997457798528407, 0.8437086521498197, 0.9806159569747303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 228}], {
             RGBColor[
             0.59367025290552, 0.6750081237524055, 0.9640949320535159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 236}], {
             RGBColor[
             0.6905520163429424, 0.7567406107159694, 0.9708709424203719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 243}], {
             RGBColor[
             0.6171853404065416, 0.6953757106431272, 0.9655932926355058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 263}], {
             RGBColor[
             0.8071963064378891, 0.8495290601441589, 0.9813585558355984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 348}], {
             RGBColor[
             0.5759330395983256, 0.6592457845311811, 0.9629793512441879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 351}], {
             RGBColor[
             0.7859492164783135, 0.8329306719838738, 0.9792408444737725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 214}], {
             RGBColor[
             0.706433945888759, 0.7689569468856965, 0.971819204119086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 217}], {
             RGBColor[
             0.7355039843295246, 0.7925573136822179, 0.9741077040322026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 257}], {
             RGBColor[
             0.936437948836536, 0.9521161068323709, 0.9924781523684676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 264}], {
             RGBColor[
             0.7174972506817234, 0.7779386361128264, 0.972690147998609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 268}], {
             RGBColor[
             0.9582663717475433, 0.9683957088986379, 0.9555283261446221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 279}], {
             RGBColor[
             0.8266953686587939, 0.8654545229780335, 0.9820633574422487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 300}], {
             RGBColor[
             0.8850839367762975, 0.911175727981907, 0.9878544273714962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 306}], {
             RGBColor[
             0.738022369100832, 0.7946018518915062, 0.9743059605065472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 363}], {
             RGBColor[
             0.7326219779918828, 0.7902175711044143, 0.9738808219361663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 381}], {
             RGBColor[
             0.7502092131945474, 0.8044956809378543, 0.9752653535154854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 243}], {
             RGBColor[
             0.29274673974831333`, 0.41779690547936077`, 0.940247549685051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 258}], {
             RGBColor[
             0.5686951658882006, 0.6399651150919567, 0.9615248036693804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 284}], {
             RGBColor[
             0.4571303240000354, 0.5519299495588337, 0.9534585149708495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 348}], {
             RGBColor[
             0.2514944389400974, 0.38166697936741467`, 0.9376336082937331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 361}], {
             RGBColor[
             0.31561537237902854`, 0.4376045656531896, 0.9417047187343424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 369}], {
             RGBColor[
             0.4671156122900648, 0.5597305326620063, 0.9544537551897753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 392}], {
             RGBColor[
             0.5453871541321326, 0.6214606571876746, 0.9621002081157097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 261}], {
             RGBColor[
             0.4063217427664596, 0.525951770788313, 0.9472234624740672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 295}], {
             RGBColor[
             0.48349137149961313`, 0.588601551846044, 0.9532985383296053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 310}], {
             RGBColor[
             0.3725121015914763, 0.4970729922210819, 0.9449571196072593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 345}], {
             RGBColor[
             0.501748761637466, 0.6031672141340616, 0.9549112039145239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 389}], {
             RGBColor[
             0.3257750821548689, 0.4564447726811316, 0.9419844590691389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 400}], {
             RGBColor[
             0.3259428749204162, 0.4566211335163976, 0.9419940146189095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 207}], {
             RGBColor[
             0.48437081281424366`, 0.5922730723558783, 0.9525505911749386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 221}], {
             RGBColor[
             0.6273843703533175, 0.7064327664226073, 0.965139055144904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 230}], {
             RGBColor[
             0.5123028405783812, 0.6149495508183161, 0.9547495027189206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 250}], {
             RGBColor[
             0.5932630539730043, 0.6797769347346972, 0.961738161209945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 276}], {
             RGBColor[
             0.5308004923042078, 0.6299667777990562, 0.9562057056219087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 358}], {
             RGBColor[
             0.4053099104272018, 0.5246088665553695, 0.947287886386919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 391}], {
             RGBColor[
             0.5680514642266604, 0.6600814492096745, 0.9592253055597311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 208}], {
             RGBColor[
             0.512568613380781, 0.6151653171522327, 0.9547704253274834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 258}], {
             RGBColor[
             0.716562272939044, 0.7771148783119854, 0.970881180203349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 278}], {
             RGBColor[
             0.5745662550954164, 0.6653066468369517, 0.9597817962810855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 284}], {
             RGBColor[
             0.6049974310508788, 0.6890797127788625, 0.9628148915048182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 369}], {
             RGBColor[
             0.6149827193409082, 0.6968802958820353, 0.963810131723744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 392}], {
             RGBColor[
             0.693254261182976, 0.7586104204077035, 0.9714565846496783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 221}], {
             RGBColor[
             0.6263243314548808, 0.7055721790906482, 0.9650556049997685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 230}], {
             RGBColor[
             0.5112428016799444, 0.614088963486357, 0.9546660525737851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 233}], {
             RGBColor[
             0.6050195133890713, 0.6889286932950234, 0.9629321398398131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 250}], {
             RGBColor[
             0.5922030150745674, 0.6789163474027381, 0.9616547110648097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 358}], {
             RGBColor[
             0.404249871528765, 0.5237482792234104, 0.9472044362417835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 366}], {
             RGBColor[
             0.49193973597309715`, 0.5984178651523382, 0.9531464445318827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 391}], {
             RGBColor[
             0.5669914253282236, 0.6592208618777153, 0.9591418554145956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[
             0.7348354920369392, 0.7919499007747961, 0.9723197149477424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 278}], {
             RGBColor[
             0.5928394741933116, 0.6801416692997624, 0.961220331025479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 284}], {
             RGBColor[
             0.6232706501487741, 0.7039147352416731, 0.9642534262492115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 369}], {
             RGBColor[
             0.6332559384388035, 0.7117153183448459, 0.9652486664681372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 392}], {
             RGBColor[
             0.7115274802808712, 0.7734454428705142, 0.9728951193940717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 227}], {
             RGBColor[
             0.3852748769291842, 0.506702787188514, 0.9459427248288221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 229}], {
             RGBColor[
             0.2974656714959333, 0.42998565952808987`, 0.940251601979444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 240}], {
             RGBColor[
             0.4598958883252, 0.5672834858780541, 0.9518171641916879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 245}], {
             RGBColor[
             0.45441292001106065`, 0.5628321651957281, 0.9513855248412242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 280}], {
             RGBColor[
             0.6462763393391913, 0.7102381235476785, 0.7529711344785746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 304}], {
             RGBColor[
             0.5116106352160492, 0.6080101637299626, 0.9567482235115812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 315}], {
             RGBColor[
             0.29112478616286636`, 0.42332098700768606`, 0.9398904979402251]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 319}], {
             RGBColor[
             0.36589123837863496`, 0.4904151720528126, 0.9445690455126947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 329}], {
             RGBColor[
             0.3538542046384413, 0.47998929842596383`, 0.9438020563667007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 334}], {
             RGBColor[
             0.29744178889377754`, 0.42996055739897976`, 0.9402502419005824]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 371}], {
             RGBColor[
             0.5743535923132054, 0.6572676100925557, 0.962937590261526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 236}], {
             RGBColor[
             0.6428594146981276, 0.7192608842888919, 0.96617627597904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 263}], {
             RGBColor[
             0.7595037047930744, 0.8120493337170813, 0.9766638893942665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 301}], {
             RGBColor[
             0.5831506104997137, 0.6715992150274208, 0.9609201821011288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 328}], {
             RGBColor[
             0.6962162985965753, 0.7607768987796054, 0.9719639735472839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 347}], {
             RGBColor[
             0.46360834672641926`, 0.5754171670473444, 0.9509160937890859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 372}], {
             RGBColor[
             0.5399078253435817, 0.6373605210410977, 0.9569226682400283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 387}], {
             RGBColor[
             0.36771391727778907`, 0.48878244739360843`, 0.9448937419240441]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 238}], {
             RGBColor[
             0.6890482184974298, 0.755781288526107, 0.9704809190937785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 259}], {
             RGBColor[
             0.49827506483345246`, 0.6030457055519229, 0.9537876093345925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 293}], {
             RGBColor[
             0.7102496939801382, 0.7726535995092233, 0.9725119370682807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 299}], {
             RGBColor[
             0.40565149186390614`, 0.517303909812217, 0.9480876817358732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 336}], {
             RGBColor[
             0.6540652595150536, 0.728452335088739, 0.966994144676754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 367}], {
             RGBColor[
             0.7447039403632104, 0.8001264803394814, 0.9757982138459669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 224}], {
             RGBColor[
             0.7677789001985943, 0.8190327333541826, 0.9773510221502697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 230}], {
             RGBColor[
             0.7116700980006295, 0.7736194607423516, 0.9728393200776865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 247}], {
             RGBColor[
             0.6508702776078339, 0.7232889264189131, 0.9683210878525259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 250}], {
             RGBColor[
             0.7926303113952526, 0.8384468446587326, 0.979827978568711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 289}], {
             RGBColor[
             0.6229549953557549, 0.699110111995044, 0.9665423507519384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 302}], {
             RGBColor[
             0.577993041834566, 0.6567523330112082, 0.9638024179015963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 340}], {
             RGBColor[
             0.7711478360937597, 0.821664571680347, 0.9776868061958038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 391}], {
             RGBColor[
             0.7674187216489088, 0.8187513591337099, 0.9773151229184969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 215}], {
             RGBColor[
             0.32885833539548337`, 0.44690193639387843`, 0.9427757169157365]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 217}], {
             RGBColor[
             0.5050680214607014, 0.6090759987336967, 0.9541799512559612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 261}], {
             RGBColor[
             0.4721238900104835, 0.582330468706201, 0.9515864685498703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 264}], {
             RGBColor[
             0.48706128781290026`, 0.5944573211643052, 0.9527623952223676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 295}], {
             RGBColor[
             0.5492935187436371, 0.644980249763932, 0.9576615444054084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 300}], {
             RGBColor[
             0.6546479739074743, 0.7276944130333859, 0.9679266745952548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 310}], {
             RGBColor[
             0.43831424883550024`, 0.5534516901389699, 0.9493201256830621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 363}], {
             RGBColor[
             0.5021860151230595, 0.6067362561558931, 0.953953069159925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 217}], {
             RGBColor[
             0.3579283738362491, 0.4705023031903998, 0.945064216828853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 269}], {
             RGBColor[
             0.3201502229412343, 0.4398322984075235, 0.942090182404471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 295}], {
             RGBColor[
             0.40215387111918477`, 0.5064065542206351, 0.9485458099783002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 300}], {
             RGBColor[
             0.507508326283022, 0.589120717490089, 0.9588109401681466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 352}], {
             RGBColor[
             0.4513487492662035, 0.5451408172750305, 0.9532420352407094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 363}], {
             RGBColor[
             0.35504636749860724`, 0.4681625606125962, 0.9448373347328167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 219}], {
             RGBColor[
             0.6796442070361894, 0.7451702764930834, 0.9524497515751587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 220}], {
             RGBColor[
             0.4981664542868162, 0.6020931902874249, 0.9540178789229599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 311}], {
             RGBColor[
             0.631944024137793, 0.7076792619484935, 0.9667545253887926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 323}], {
             RGBColor[
             0.7042236222902545, 0.45729135130597776`, 0.449211179500079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 339}], {
             RGBColor[
             0.35016723245504056`, 0.4767100669311281, 0.9435702659081439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 357}], {
             RGBColor[
             0.5853496531716381, 0.6709447384211873, 0.962199238910838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 268}], {
             RGBColor[
             0.7569004473194857, 0.8085147607466381, 0.9378890732814974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 269}], {
             RGBColor[
             0.4963599090064523, 0.6020063607473418, 0.9534944167446957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 279}], {
             RGBColor[
             0.6253294442307364, 0.7055735748260338, 0.964424104579124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 300}], {
             RGBColor[
             0.68371801234824, 0.7512947798299072, 0.9702151745083714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 306}], {
             RGBColor[
             0.5366564446727744, 0.6347209037395065, 0.9566667076434224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 363}], {
             RGBColor[
             0.5312560535638253, 0.6303366229524145, 0.9562415690730415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 262}], {
             RGBColor[
             0.4854689137861395, 0.5931645601937485, 0.9526370377059227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 269}], {
             RGBColor[
             0.48535965279777615`, 0.5930758572012436, 0.9526284362806825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 279}], {
             RGBColor[
             0.6143291880220603, 0.6966430712799356, 0.9635581241151108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 298}], {
             RGBColor[
             0.505364196600141, 0.6093164470544318, 0.9542032672478631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.6727177561395639, 0.7423642762838091, 0.9693491940443582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 306}], {
             RGBColor[
             0.5256561884640982, 0.6257904001934083, 0.9558007271794092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 314}], {
             RGBColor[
             0.5544209616420772, 0.649142938897556, 0.9580651954928158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 220}], {
             RGBColor[
             0.7753098311306987, 0.8242157451227123, 0.9595996556224058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 241}], {
             RGBColor[
             0.9409728570601983, 0.9552264139531464, 0.9753775653534906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 311}], {
             RGBColor[
             0.9090874009816756, 0.9298018167837809, 0.9723363020882385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 323}], {
             RGBColor[
             0.8889858735195095, 0.6053730545295027, 0.45293236396637626`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 339}], {
             RGBColor[
             0.627310609298923, 0.6988326217664156, 0.9491520426075899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 357}], {
             RGBColor[
             0.8624930300155207, 0.8930672932564747, 0.9677810156102841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 360}], {
             RGBColor[
             0.6791273798685485, 0.7447226267769615, 0.9524168198050489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 350}], {
             RGBColor[
             0.38740935545519384`, 0.4943487316466715, 0.9473930379978919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 357}], {
             RGBColor[
             0.6810152772661473, 0.7499902070508162, 0.9693491429580852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 394}], {
             RGBColor[
             0.6287240163241555, 0.7091398765746295, 0.9641372387570041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 230}], {
             RGBColor[
             0.6542563592190181, 0.728248657553086, 0.9672545165437505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 250}], {
             RGBColor[
             0.7352165726136413, 0.7930760414694671, 0.9742431750347749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 276}], {
             RGBColor[
             0.6727540109448449, 0.743265884533826, 0.9687107194467385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 358}], {
             RGBColor[
             0.5472634290678389, 0.6379079732901393, 0.9597929002117489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 251}], {
             RGBColor[
             0.483844390880827, 0.5888431892916781, 0.9533387517775018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 297}], {
             RGBColor[
             0.7844462030116053, 0.8320572845207312, 0.9716970970666183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 312}], {
             RGBColor[
             0.6862090859344288, 0.7545243508286092, 0.9695408902093678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 332}], {
             RGBColor[
             0.6862589101054142, 0.7545632738496608, 0.9695458562170984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 356}], {
             RGBColor[
             0.584645439996236, 0.6736805320226953, 0.9604445771447674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 361}], {
             RGBColor[
             0.5288102425174429, 0.6277903499298977, 0.9562039360820457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 260}], {
             RGBColor[
             0.5035264087013952, 0.6043041686172667, 0.955194938618693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 267}], {
             RGBColor[
             0.32216013440483837`, 0.45319329228062843`, 0.941758526022072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 272}], {
             RGBColor[
             0.5712975346672778, 0.6572474873014484, 0.9619497310977921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 290}], {
             RGBColor[
             0.41659723360475664`, 0.5341329254639169, 0.9480768581854182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 291}], {
             RGBColor[
             0.5073056149875403, 0.6072565132910348, 0.9555716145826052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 321}], {
             RGBColor[
             0.4581820888093998, 0.5678933842954244, 0.9513505703174716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 331}], {
             RGBColor[
             0.3316307391693626, 0.46166361084806706`, 0.9423521953436915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 342}], {
             RGBColor[
             0.5789597344673705, 0.6632332560201561, 0.9627134275665372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 346}], {
             RGBColor[
             0.41743737889253096`, 0.5348149932566459, 0.9481429975000255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 384}], {
             RGBColor[
             0.27544931317854787`, 0.4040972575346754, 0.9390984138557021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 398}], {
             RGBColor[
             0.39919330156397353`, 0.5200036293950056, 0.9467067569024641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 230}], {
             RGBColor[
             0.5952836316420466, 0.6821787145606258, 0.9613766661903502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 247}], {
             RGBColor[
             0.5344838112492509, 0.6318481802371874, 0.9568584339651898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 289}], {
             RGBColor[
             0.506568528997172, 0.6076693658133183, 0.9550796968646021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 302}], {
             RGBColor[
             0.461606575475983, 0.5653115868294825, 0.95233976401426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 323}], {
             RGBColor[
             0.7871874901728226, 0.525472773144198, 0.45555131062915255`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 340}], {
             RGBColor[
             0.6547613697351767, 0.7302238254986213, 0.9662241523084676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 288}], {
             RGBColor[
             0.7043289587901108, 0.7649225909982296, 0.9302574310219376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 296}], {
             RGBColor[
             0.6946126621660886, 0.7565068232177694, 0.9296383171928386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 316}], {
             RGBColor[
             0.9233970700897757, 0.9405141459045769, 0.949507570192109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 324}], {
             RGBColor[
             0.9870536250454052, 0.9888571980175427, 0.8616588386538815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 355}], {
             RGBColor[
             0.7791273338739657, 0.8264213417197834, 0.935931957964418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 375}], {
             RGBColor[
             0.8977314836668511, 0.9201167474199785, 0.9470416131539713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 380}], {
             RGBColor[
             0.7837333882429414, 0.8301607441569023, 0.9362945634368769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 383}], {
             RGBColor[
             0.6922392375196178, 0.7544510820807876, 0.9294870846731025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 390}], {
             RGBColor[
             0.9366922576747225, 0.9511153675965605, 0.9507756770527152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 255}], {
             RGBColor[
             0.6040881796342265, 0.6893176800012627, 0.9620759206900824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 266}], {
             RGBColor[
             0.6462944667273398, 0.7235826452350178, 0.9653985542167761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 294}], {
             RGBColor[
             0.477285134446339, 0.5817117976565508, 0.9532451334956267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 341}], {
             RGBColor[
             0.6519409391639044, 0.728020483700277, 0.9659430381475455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 368}], {
             RGBColor[
             0.622676705308389, 0.7044086825470864, 0.9635392775231656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 393}], {
             RGBColor[
             0.7585450261968432, 0.8116651635819598, 0.9764715420129754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 399}], {
             RGBColor[
             0.5979677720267547, 0.6843488573842964, 0.9615940997834305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 280}], {
             RGBColor[
             0.7327899972952484, 0.7855935486671177, 0.7585884778157173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 304}], {
             RGBColor[
             0.5981242931721065, 0.6833655888494017, 0.9623655668487239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 315}], {
             RGBColor[
             0.37763844411892356`, 0.49867641212712516`, 0.9455078412773678]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 243}], {
             RGBColor[
             0.3634172118144061, 0.4891954558186354, 0.9443776012729596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 332}], {
             RGBColor[
             0.5437345120330926, 0.6357760399122274, 0.9591766904573036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 348}], {
             RGBColor[
             0.32216491100619016`, 0.45306552970668934`, 0.9417636598816417]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 361}], {
             RGBColor[
             0.3862858444451214, 0.5090031159924642, 0.9458347703222509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 385}], {
             RGBColor[
             0.2849446728295556, 0.41394469948364465`, 0.9396440223798903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 240}], {
             RGBColor[
             0.45860034084800627`, 0.5659217833370691, 0.9517433846794524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 245}], {
             RGBColor[
             0.4531173725338669, 0.5614704626547431, 0.9513117453289887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 248}], {
             RGBColor[
             0.42672625334335884`, 0.5400449631895177, 0.9492341397524569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 249}], {
             RGBColor[
             0.28342370052241916`, 0.41522665772254486`, 0.9394519325057368]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 309}], {
             RGBColor[
             0.3016131207417011, 0.4343448916488621, 0.940487793078389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 315}], {
             RGBColor[
             0.2898292386856726, 0.421959284466701, 0.9398167184279895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 319}], {
             RGBColor[
             0.3645956909014412, 0.4890534695118276, 0.9444952660004593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[
             0.35255865716124757`, 0.4786275958849788, 0.9437282768544651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 334}], {
             RGBColor[
             0.2961462414165838, 0.42859885485799476`, 0.9401764623883468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 371}], {
             RGBColor[
             0.5730580448360116, 0.6559059075515707, 0.9628638107492906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 388}], {
             RGBColor[
             0.29994697693464456`, 0.43259366886802686`, 0.9403929086534162]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 247}], {
             RGBColor[
             0.4783750090512862, 0.5864349076253563, 0.9523467318926067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 250}], {
             RGBColor[
             0.6201350428387049, 0.7015928258651759, 0.9638536226087916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 289}], {
             RGBColor[
             0.4504597267992072, 0.5622560932014873, 0.9505679947920189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 358}], {
             RGBColor[
             0.4321818992929025, 0.5464247576858482, 0.9494033477857655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 391}], {
             RGBColor[
             0.594923453092361, 0.6818973403401531, 0.9613407669585776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 234}], {
             RGBColor[
             0.2810365465840979, 0.4127176075790677, 0.9393159876204272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 290}], {
             RGBColor[
             0.39651657930296513`, 0.5157746980898162, 0.9468326837174472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 313}], {
             RGBColor[
             0.2810312571072787, 0.41271204800355854`, 0.9393156863925474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 331}], {
             RGBColor[
             0.3115500848675711, 0.4433053834739665, 0.9411080208757203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 359}], {
             RGBColor[
             0.23861582633980397`, 0.36813074097330567`, 0.9369001903583465]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 235}], {
             RGBColor[
             0.46381681848080697`, 0.5726288633768642, 0.9517496854457026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 281}], {
             RGBColor[
             0.5642918608814569, 0.6571565795790276, 0.9588422688392351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 384}], {
             RGBColor[
             0.39783630675181547`, 0.5065750345134337, 0.947871514879468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 386}], {
             RGBColor[
             0.5710027412409042, 0.6626047745765419, 0.9593705739238956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 242}], {
             RGBColor[
             0.8353730567508446, 0.8721070471050367, 0.9765222387468695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 317}], {
             RGBColor[
             0.8608290821623723, 0.8893081519537855, 0.8535425784468169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 358}], {
             RGBColor[
             0.5259586110020295, 0.6212644874945146, 0.9576694350517934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 366}], {
             RGBColor[
             0.6136484754463616, 0.6959340734234424, 0.9636114433418925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 382}], {
             RGBColor[
             0.7205432420771067, 0.7816131241328839, 0.9727806745769633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 290}], {
             RGBColor[
             0.37924847320745514`, 0.49762482372227257`, 0.9458492906211815]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 313}], {
             RGBColor[
             0.2637631510117686, 0.3945621736360148, 0.9383322932962819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 331}], {
             RGBColor[
             0.2942819787720611, 0.42515550910642275`, 0.9401246277794548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 342}], {
             RGBColor[
             0.541610974070069, 0.6267251542785118, 0.9604858600023005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 346}], {
             RGBColor[
             0.3800886184952294, 0.4983068915150016, 0.9459154299357888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 275}], {
             RGBColor[
             0.38560503926494083`, 0.5084134367636551, 0.9457913900181822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 281}], {
             RGBColor[
             0.4448687309325377, 0.5572459523035628, 0.9502580225847711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 384}], {
             RGBColor[
             0.27841317680289634`, 0.4066644072379688, 0.939287268625004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 263}], {
             RGBColor[
             0.6503099412831761, 0.725081292283231, 0.9669188748399081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 351}], {
             RGBColor[
             0.6290628513236003, 0.7084829041229459, 0.9648011634780822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 246}], {
             RGBColor[
             0.5196803921011843, 0.6168239146600012, 0.9568472858259717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 254}], {
             RGBColor[
             0.46003787760810766`, 0.5693361498841512, 0.9515143060255953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 286}], {
             RGBColor[
             0.4557185889027514, 0.5658295567314042, 0.9511742757966337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 320}], {
             RGBColor[
             0.5931354672028442, 0.6744514500662047, 0.9641038849835606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 343}], {
             RGBColor[
             0.42614222745508407`, 0.5418181341082886, 0.9488459162816916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 349}], {
             RGBColor[
             0.48253991369345967`, 0.5876043164834135, 0.9532857487339084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 252}], {
             RGBColor[
             0.6039898882389382, 0.68506488241122, 0.9642440925864593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 277}], {
             RGBColor[
             0.6953076451011861, 0.7608629730269914, 0.9709736840850614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 287}], {
             RGBColor[
             0.8348882481324911, 0.8712144129638846, 0.9841047781758756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 293}], {
             RGBColor[
             0.8370816036702158, 0.8729633351326163, 0.9843139823850954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 299}], {
             RGBColor[
             0.5324834015539839, 0.6176136454356098, 0.9598897270526878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 336}], {
             RGBColor[
             0.7808971692051313, 0.8287620707121319, 0.9787961899935687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 367}], {
             RGBColor[
             0.8715358500532882, 0.9004362159628743, 0.9876002591627817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 396}], {
             RGBColor[
             0.7475587717538584, 0.8027178612419924, 0.9754733301006633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 271}], {
             RGBColor[
             0.6917469637192964, 0.759053851710423, 0.9699538782148793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 326}], {
             RGBColor[
             0.6176851918665425, 0.6989271688755572, 0.9641234642374211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 335}], {
             RGBColor[
             0.67701507725814, 0.7470938426173341, 0.9687941301479789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 337}], {
             RGBColor[
             0.6116085241138474, 0.6939938562431568, 0.9636450866923616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 354}], {
             RGBColor[
             0.5565467113113792, 0.6469707170788602, 0.9599518506619031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 245}], {
             RGBColor[
             0.6155475893631337, 0.6987682890047072, 0.9628773075412326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 248}], {
             RGBColor[
             0.5891564701726255, 0.6773427895394819, 0.9607997019647008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 292}], {
             RGBColor[
             0.5285485354288311, 0.6276701194444128, 0.9561578487032207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 304}], {
             RGBColor[
             0.6727453045681222, 0.7439462875389418, 0.9682400062115896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 309}], {
             RGBColor[
             0.46404333757096783`, 0.5716427179988263, 0.952053355290633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 315}], {
             RGBColor[
             0.45225945551493935`, 0.5592571108166652, 0.9513822806402334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 319}], {
             RGBColor[
             0.527025907730708, 0.6263512958617918, 0.9560608282127032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 329}], {
             RGBColor[
             0.5149888739905143, 0.615925422234943, 0.9552938390667091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 334}], {
             RGBColor[
             0.4585764582458505, 0.5658966812079589, 0.9517420246005908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 371}], {
             RGBColor[
             0.7354882616652784, 0.793203733901535, 0.9744293729615345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 388}], {
             RGBColor[
             0.4623771937639113, 0.569891495217991, 0.9519584708656601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 255}], {
             RGBColor[
             0.7406784688905292, 0.7968731354335263, 0.9754643782333994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 288}], {
             RGBColor[
             0.6749840437161877, 0.7427653813767852, 0.9705065475766632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 339}], {
             RGBColor[
             0.6114958824790493, 0.6867662043911912, 0.9664980796864757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 360}], {
             RGBColor[
             0.6633126530486748, 0.7326562094017371, 0.9697628568839349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 374}], {
             RGBColor[
             0.9479814128572444, 0.9281697602040476, 0.6669028933652452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 375}], {
             RGBColor[
             0.868386568592928, 0.8979595377985341, 0.9872907297086969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 399}], {
             RGBColor[
             0.7345580612830573, 0.79190431281656, 0.9749825573267474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 256}], {
             RGBColor[
             0.626080884495295, 0.6994891780731399, 0.960253525307617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 257}], {
             RGBColor[
             0.9400119247774217, 0.9547815722372349, 0.9864283433427621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 268}], {
             RGBColor[
             0.9618403476884289, 0.9710611743035019, 0.9494785171189166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 317}], {
             RGBColor[
             0.9694738860508811, 0.9749702974926946, 0.8566676785438636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 333}], {
             RGBColor[
             0.9677271929707634, 0.9742479950161012, 0.8856149031782055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 381}], {
             RGBColor[
             0.753783189135433, 0.8071611463427184, 0.9692155444897799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 382}], {
             RGBColor[
             0.8291880459656156, 0.8672752696717928, 0.9759057746740099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 348}], {
             RGBColor[
             0.34567999850721176`, 0.47343311659741105`, 0.9432620204636315]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 351}], {
             RGBColor[
             0.5556961753871996, 0.6471180040501037, 0.9595235136932161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 253}], {
             RGBColor[
             0.637814128373658, 0.7136099746900687, 0.9667389540490412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 270}], {
             RGBColor[
             0.612489712957887, 0.6916752388990562, 0.9651253046922497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 308}], {
             RGBColor[
             0.6735129272413611, 0.7429846608319262, 0.9694407643863415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 397}], {
             RGBColor[
             0.7480715609420641, 0.8032541837541074, 0.9754884221760693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 248}], {
             RGBColor[
             0.5836735018584862, 0.6728914688571559, 0.960368062614237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 292}], {
             RGBColor[
             0.5230655671146918, 0.6232187987620867, 0.955726209352757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 304}], {
             RGBColor[
             0.6672623362539829, 0.7394949668566158, 0.9678083668611258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 315}], {
             RGBColor[
             0.4467764872008, 0.5548057901343392, 0.9509506412897697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 319}], {
             RGBColor[
             0.5215429394165686, 0.6218999751794658, 0.9556291888622395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 329}], {
             RGBColor[
             0.509505905676375, 0.6114741015526169, 0.9548621997162453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 353}], {
             RGBColor[
             0.43116969959935575`, 0.538402066837735, 0.9500618578240407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 371}], {
             RGBColor[
             0.730005293351139, 0.788752413219209, 0.9739977336110708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 378}], {
             RGBColor[
             0.6968475847449346, 0.7626071878339638, 0.9707571479408377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 388}], {
             RGBColor[
             0.45689422544977193`, 0.565440174535665, 0.9515268315151963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 254}], {
             RGBColor[
             0.6436037576844053, 0.7206128350096066, 0.9657236944663661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 286}], {
             RGBColor[
             0.639284468979049, 0.7171062418568597, 0.9653836642374045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 320}], {
             RGBColor[
             0.7767013472791418, 0.8257281351916602, 0.9783132734243314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 343}], {
             RGBColor[
             0.6097081075313817, 0.693094819233744, 0.9630553047224624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 344}], {
             RGBColor[
             0.5605036040697273, 0.6521829290328599, 0.9594485047940583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 349}], {
             RGBColor[
             0.6661057937697572, 0.7388810016088689, 0.9674951371746792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 289}], {
             RGBColor[
             0.3896599064064116, 0.5119255588780488, 0.9460497625668585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 302}], {
             RGBColor[
             0.34469795288522265`, 0.4695677798942129, 0.9433098297165163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 340}], {
             RGBColor[
             0.5378527471444163, 0.6344800185633517, 0.957194218010724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 391}], {
             RGBColor[
             0.5341236326995655, 0.6315668060167147, 0.956822534733417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 292}], {
             RGBColor[
             0.4966744479241837, 0.6017932992968614, 0.9536486037762253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 304}], {
             RGBColor[
             0.6408712170634747, 0.7180694673913904, 0.965730761284594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 315}], {
             RGBColor[
             0.4203853680102919, 0.5333802906691139, 0.948873035713238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 319}], {
             RGBColor[
             0.4951518202260605, 0.6004744757142404, 0.9535515832857077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 329}], {
             RGBColor[
             0.4831147864858669, 0.5900486020873916, 0.9527845941397135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 353}], {
             RGBColor[
             0.4047785804088477, 0.5169765673725096, 0.9479842522475089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 388}], {
             RGBColor[
             0.43050310625926386`, 0.5440146750704398, 0.9494492259386645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 270}], {
             RGBColor[
             0.3294400906486585, 0.4562464676587928, 0.9423414831117227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 308}], {
             RGBColor[
             0.39046330493213266`, 0.5075558895916626, 0.9466569428058147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 309}], {
             RGBColor[
             0.2888666972453807, 0.42094759238430207`, 0.9397619031169173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 334}], {
             RGBColor[
             0.2833998179202635, 0.41520155559343475`, 0.9394505724268751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 386}], {
             RGBColor[
             0.41472140553909054`, 0.5272497084793697, 0.9485666293459447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 397}], {
             RGBColor[
             0.4650219386328355, 0.567825412513844, 0.9527046005955424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 265}], {
             RGBColor[
             0.8212489070000673, 0.8611194569126613, 0.9774583227633606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 276}], {
             RGBColor[
             0.6386326945645315, 0.716610052845916, 0.9653098255117796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 289}], {
             RGBColor[
             0.5314199401938303, 0.6270834771178684, 0.9575566532830435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 391}], {
             RGBColor[
             0.6758836664869842, 0.7467247242565342, 0.968329425449602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 282}], {
             RGBColor[
             0.3809582960903477, 0.5043886613779254, 0.9454953036520508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 312}], {
             RGBColor[
             0.545102556357228, 0.6369652033175068, 0.9592620697763103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 356}], {
             RGBColor[
             0.44353891041903526`, 0.5561213845115928, 0.9501657567117099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 277}], {
             RGBColor[
             0.48341740515261683`, 0.5898368312887114, 0.9529348122609274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 293}], {
             RGBColor[
             0.6251913637216464, 0.7019371933943362, 0.9662751105609613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 330}], {
             RGBColor[
             0.6481031573484914, 0.7202064357083122, 0.9684604578906895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 386}], {
             RGBColor[
             0.49880863457742114`, 0.6036015534711902, 0.953795719270194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 286}], {
             RGBColor[
             0.5796419544859723, 0.6696184770810096, 0.9600506844370282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 320}], {
             RGBColor[
             0.7170588327860651, 0.7782403704158101, 0.972980293623955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 343}], {
             RGBColor[
             0.5500655930383049, 0.645607054457894, 0.957722324922086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 344}], {
             RGBColor[
             0.5008610895766507, 0.6046951642570098, 0.9541155249936819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 349}], {
             RGBColor[
             0.6064632792766806, 0.6913932368330189, 0.9621621573743027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 288}], {
             RGBColor[
             0.4905043823663925, 0.5964785202323895, 0.9532473233776861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 341}], {
             RGBColor[
             0.6040515670704121, 0.6892890779881451, 0.9620722714918852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 360}], {
             RGBColor[
             0.47883299169887955`, 0.5863693482573414, 0.9525036326849576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 374}], {
             RGBColor[
             0.7635017515074491, 0.7818828990596519, 0.649643669166268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 393}], {
             RGBColor[
             0.7106556541033507, 0.7729337578698278, 0.9726007753573152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 399}], {
             RGBColor[
             0.5500783999332621, 0.6456174516721643, 0.9577233331277701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 261}], {
             RGBColor[
             0.388196852676134, 0.5101972344887804, 0.9460705987641067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 264}], {
             RGBColor[
             0.4031342504785507, 0.5223240869468847, 0.947246525436604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 317}], {
             RGBColor[
             0.6515369099068228, 0.7166902829218889, 0.8372738650075644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 333}], {
             RGBColor[
             0.6497902168267049, 0.7159679804452954, 0.8662210896419063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 381}], {
             RGBColor[
             0.4358462129913746, 0.5488811317719127, 0.9498217309534805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 268}], {
             RGBColor[
             0.9578344118264971, 0.9680735538967912, 0.9562595216177625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 338}], {
             RGBColor[
             0.7337991287988097, 0.7912017646811483, 0.9747386925001794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 381}], {
             RGBColor[
             0.7497772532735012, 0.8041735259360077, 0.9759965489886256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 382}], {
             RGBColor[
             0.8251821101036838, 0.8642876492650821, 0.9826867791728557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 278}], {
             RGBColor[
             0.7968331337515746, 0.8420912304595153, 0.9773310859013447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 284}], {
             RGBColor[
             0.8272643097070371, 0.865864296401426, 0.9803641811250772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 369}], {
             RGBColor[
             0.8372495979970664, 0.8736648795045987, 0.9813594213440029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 392}], {
             RGBColor[
             0.9155211398391342, 0.935395004030267, 0.9890058742699374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 274}], {
             RGBColor[
             0.5284614376634456, 0.6275523628959103, 0.9561639911800967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 299}], {
             RGBColor[
             0.3417102478900065, 0.4648780624614259, 0.9431964172935019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 318}], {
             RGBColor[
             0.36630486596619394`, 0.490728565448351, 0.9445970444084638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 336}], {
             RGBColor[
             0.5901240155411539, 0.6760264877379478, 0.9621028802343827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 367}], {
             RGBColor[
             0.6807626963893108, 0.7477006329886904, 0.9709069494035956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 267}], {
             RGBColor[
             0.4872205818230427, 0.5899135242030824, 0.95416573498813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 272}], {
             RGBColor[
             0.7363579820854822, 0.7939677192239024, 0.9743569400638501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 291}], {
             RGBColor[
             0.6723660624057447, 0.7439767452134888, 0.9679788235486633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 321}], {
             RGBColor[
             0.6232425362276042, 0.7046136162178783, 0.9637577792835296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 338}], {
             RGBColor[
             0.6000895624008646, 0.6858169890357466, 0.9619350923717509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 342}], {
             RGBColor[
             0.7440201818855748, 0.7999534879426101, 0.9751206365325952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 384}], {
             RGBColor[
             0.4405097605967522, 0.5408174894571294, 0.9515056228217602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 398}], {
             RGBColor[
             0.5642537489821778, 0.6567238613174595, 0.9591139658685222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 264}], {
             RGBColor[
             0.4831871948034481, 0.5913121579333308, 0.9524574124293932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 295}], {
             RGBColor[
             0.5454194257341849, 0.6418350865329576, 0.957356561612434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 310}], {
             RGBColor[
             0.4344401558260481, 0.5503065269079954, 0.9490151428900878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 381}], {
             RGBColor[
             0.515899157316272, 0.6178692027583588, 0.9550326179462696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 269}], {
             RGBColor[
             0.4586910190998008, 0.5714250589569704, 0.9505289837455538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 298}], {
             RGBColor[
             0.47869556290216575`, 0.5876656488101586, 0.9521038147127345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 300}], {
             RGBColor[
             0.6460491224415885, 0.7207134780395359, 0.9672497415092296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 306}], {
             RGBColor[
             0.498987554766123, 0.604139601949135, 0.9537012746442806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 307}], {
             RGBColor[
             0.48633299387953216`, 0.5938660593399292, 0.9527050612561043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 314}], {
             RGBColor[
             0.5277523279441019, 0.6274921406532827, 0.9559657429576871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 310}], {
             RGBColor[
             0.4493775536284648, 0.5624333793660997, 0.9501910695625851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 333}], {
             RGBColor[
             0.7447805589540191, 0.7970829038898459, 0.8726079033071927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 381}], {
             RGBColor[
             0.5308365551186887, 0.6299960552164631, 0.9562085446187669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 322}], {
             RGBColor[
             0.9681311415589986, 0.9736162506342394, 0.8329826874405315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 362}], {
             RGBColor[
             0.7195403375795357, 0.7794476228716606, 0.9688362776822442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 273}], {
             RGBColor[
             0.6201768915138739, 0.7025265650383634, 0.9632417431642313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 365}], {
             RGBColor[
             0.6350765529742675, 0.7146227814340105, 0.9644146990936519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 272}], {
             RGBColor[
             0.5549917077889253, 0.6428568428872643, 0.9609205274672291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 291}], {
             RGBColor[
             0.4909997881091878, 0.5928658688768507, 0.9545424109520422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 321}], {
             RGBColor[
             0.44187626193104723`, 0.5535027398812402, 0.9503213666869086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 331}], {
             RGBColor[
             0.31532491229101, 0.4472729664338829, 0.9413229917131285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 342}], {
             RGBColor[
             0.562653907589018, 0.648842611605972, 0.9616842239359742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 346}], {
             RGBColor[
             0.4011315520141784, 0.5204243488424618, 0.9471137938694625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 384}], {
             RGBColor[
             0.25914348630019535`, 0.3897066131204912, 0.9380692102251391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 398}], {
             RGBColor[
             0.382887474685621, 0.5056129849808214, 0.9456775532719011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 338}], {
             RGBColor[
             0.755627551709817, 0.8074813667474153, 0.9377888662763341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 381}], {
             RGBColor[
             0.7716056761845085, 0.8204531280022747, 0.9390467227647803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 279}], {
             RGBColor[
             0.5875512933357215, 0.6749035700431575, 0.9614500701547419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 298}], {
             RGBColor[
             0.47858630191380236`, 0.5875769458176536, 0.9520952132874942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 300}], {
             RGBColor[
             0.6459398614532252, 0.7206247750470309, 0.9672411400839893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 306}], {
             RGBColor[
             0.4988782937777596, 0.6040508989566302, 0.9536926732190404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 307}], {
             RGBColor[
             0.4862237328911688, 0.5937773563474245, 0.952696459830864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 314}], {
             RGBColor[
             0.5276430669557386, 0.6274034376607779, 0.9559571415324469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 308}], {
             RGBColor[
             0.4492261185546923, 0.5619729987924706, 0.9502723833732722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 397}], {
             RGBColor[
             0.5237847522553951, 0.6222425217146519, 0.9563200411630002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 273}], {
             RGBColor[
             0.61898130808793, 0.7015559365527625, 0.9631476224573746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 326}], {
             RGBColor[
             0.5641584430223189, 0.6570482649505732, 0.958831765696638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 335}], {
             RGBColor[
             0.6234883284139163, 0.7052149386923502, 0.9635024316071957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 394}], {
             RGBColor[
             0.6509180845710292, 0.7271580210088221, 0.9658844371089488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 291}], {
             RGBColor[
             0.7401371883716272, 0.7969200638976706, 0.9747336160277624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 321}], {
             RGBColor[
             0.6910136621934867, 0.7575569349020601, 0.9705125717626287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 331}], {
             RGBColor[
             0.5644623125534495, 0.6513271614547029, 0.9615141967888485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 338}], {
             RGBColor[
             0.6678606883667472, 0.7387603077199283, 0.9686898848508501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 342}], {
             RGBColor[
             0.8117913078514574, 0.8528968066267919, 0.9818754290116943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 346}], {
             RGBColor[
             0.6502689522766179, 0.7244785438632817, 0.9673049989451825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 384}], {
             RGBColor[
             0.5082808865626348, 0.5937608081413112, 0.9582604153008594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 398}], {
             RGBColor[
             0.6320248749480605, 0.7096671800016414, 0.9658687583476213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 365}], {
             RGBColor[
             0.6146420627611805, 0.698033141715733, 0.9628060211700735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 394}], {
             RGBColor[
             0.6316791777838864, 0.7115390097761456, 0.9643698798922271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 287}], {
             RGBColor[
             0.7382427112724066, 0.795411334684479, 0.974679114704565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 299}], {
             RGBColor[
             0.4358378646938993, 0.5418105671562042, 0.9504640635813772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 318}], {
             RGBColor[
             0.46043248277008686`, 0.5676610701431294, 0.9518646906963393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 367}], {
             RGBColor[
             0.7748903131932036, 0.8246331376834687, 0.9781745956914711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 373}], {
             RGBColor[
             0.4664478222559699, 0.573839286124893, 0.9522125384428193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 395}], {
             RGBColor[
             0.758858819222924, 0.811850059554879, 0.9766454974851022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 279}], {
             RGBColor[
             0.5716686092789998, 0.6612897107738802, 0.9603985494171479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 281}], {
             RGBColor[
             0.4860800816655907, 0.5929411529658185, 0.9528839734117147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 306}], {
             RGBColor[
             0.48299560972103783`, 0.5904370396873528, 0.9526411524814464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 338}], {
             RGBColor[
             0.47920432934006174`, 0.5873591074788417, 0.9523426890019384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 384}], {
             RGBColor[
             0.31962452753594933`, 0.4423596079002245, 0.9419132194519475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 322}], {
             RGBColor[
             0.7855149291234629, 0.829106846567494, 0.8208341901889504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 358}], {
             RGBColor[
             0.45067955101872914`, 0.5614419846665882, 0.9508595506887536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 376}], {
             RGBColor[
             0.6321501157727207, 0.7115458130243297, 0.964663702640955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 377}], {
             RGBColor[
             0.7667940665085519, 0.7674114764849629, 0.6244273853207714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 287}], {
             RGBColor[
             0.7143157650461698, 0.7759863618413761, 0.9727954978503437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 330}], {
             RGBColor[
             0.7394209142107394, 0.7960045263240838, 0.9751900493892915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 396}], {
             RGBColor[
             0.626986288667537, 0.707489810119484, 0.9641640497751314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 284}], {
             RGBColor[
             0.6852682918634094, 0.7540560649263923, 0.9692647972028138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 327}], {
             RGBColor[
             0.45087447372170575`, 0.553566683707768, 0.9518021687802403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 337}], {
             RGBColor[
             0.5663902257860609, 0.6586689779176941, 0.9591381493040709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 354}], {
             RGBColor[
             0.5113284129835927, 0.6116458387533975, 0.9554449132736125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 392}], {
             RGBColor[
             0.7735251219955066, 0.8235867725552333, 0.977906490347674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 300}], {
             RGBColor[
             0.7749093966775094, 0.824191989125723, 0.9781708279184176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 306}], {
             RGBColor[
             0.6278478290020437, 0.7076181130353221, 0.9646223610534685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 363}], {
             RGBColor[
             0.6224474378930945, 0.7032338322482301, 0.9641972224830877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 384}], {
             RGBColor[
             0.3788882192035462, 0.49119212344013213`, 0.9463798520185365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 386}], {
             RGBColor[
             0.552054653692635, 0.6472218635032404, 0.957878911062964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 350}], {
             RGBColor[
             0.3000826817030657, 0.4225260426757821, 0.940774484492617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 369}], {
             RGBColor[
             0.7256847561089013, 0.7856297139714756, 0.9732931326454721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 392}], {
             RGBColor[
             0.8039562979509691, 0.8473598384971439, 0.9809395855714065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 330}], {
             RGBColor[
             0.8396410526827551, 0.8753331711503485, 0.9844707982071434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 387}], {
             RGBColor[
             0.521653610953196, 0.6117230471723696, 0.9584034909087215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 320}], {
             RGBColor[
             0.7127395440807088, 0.7747337772630631, 0.9726402633949935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 343}], {
             RGBColor[
             0.5457463043329487, 0.6421004613051471, 0.9573822946931245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 349}], {
             RGBColor[
             0.6021439905713244, 0.687886643680272, 0.9618221271453412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 367}], {
             RGBColor[
             0.8905439699982717, 0.9155596047772591, 0.9894220729280641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 373}], {
             RGBColor[
             0.582101479061038, 0.6647657532186834, 0.9634600156794122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 395}], {
             RGBColor[
             0.8745124760279921, 0.9027765266486694, 0.9878929747216951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 396}], {
             RGBColor[
             0.766566891698842, 0.8178412500563772, 0.9772951438659456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 341}], {
             RGBColor[
             0.5383571418960704, 0.6351813239314038, 0.9571144408351491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 355}], {
             RGBColor[
             0.4996083322759059, 0.603869516897202, 0.9539640196634303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 360}], {
             RGBColor[
             0.413138566524538, 0.5322615942006002, 0.9475458020282216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 374}], {
             RGBColor[
             0.6978073263331076, 0.7277751450029106, 0.644685838509532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 375}], {
             RGBColor[
             0.6182124820687912, 0.6975649225973971, 0.9650736748529836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 379}], {
             RGBColor[
             0.6356102903617737, 0.7113698192240385, 0.9667510438323548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 393}], {
             RGBColor[
             0.6449612289290092, 0.7188260038130865, 0.967642944700579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 399}], {
             RGBColor[
             0.48438397475892064`, 0.591509697615423, 0.9527655024710341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 302}], {
             RGBColor[
             0.31678267063314364`, 0.4453889654703439, 0.9415310926159287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 340}], {
             RGBColor[
             0.5099374648923374, 0.6103012041394827, 0.9554154809101363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 391}], {
             RGBColor[
             0.5062083504474865, 0.6073879915928457, 0.9550437976328294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 313}], {
             RGBColor[
             0.3792431837306359, 0.4976192641467634, 0.9458489893933018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 321}], {
             RGBColor[
             0.5363133611309655, 0.6344423730645286, 0.9566396988502548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 331}], {
             RGBColor[
             0.40976201149092834`, 0.5282125996171714, 0.9476413238764747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 342}], {
             RGBColor[
             0.6570910067889363, 0.7297822447892603, 0.9680025560993204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 346}], {
             RGBColor[
             0.49556865121409666`, 0.6013639820257501, 0.9534321260328087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 321}], {
             RGBColor[
             0.6270217425137492, 0.7075659608916465, 0.9641344552474418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 331}], {
             RGBColor[
             0.5004703928737121, 0.6013361874442893, 0.9551360802736617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 338}], {
             RGBColor[
             0.6038687686870097, 0.6887693337095147, 0.9623117683356632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 342}], {
             RGBColor[
             0.74779938817172, 0.8029058326163783, 0.9754973124965074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 384}], {
             RGBColor[
             0.4442889668828973, 0.5437698341308975, 0.9518822987856724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 398}], {
             RGBColor[
             0.568032955268323, 0.6596762059912278, 0.9594906418324344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 304}], {
             RGBColor[
             0.5802632823196803, 0.6683967972963213, 0.961088908023114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 329}], {
             RGBColor[
             0.4225068517420725, 0.5403759319923225, 0.9481427408782335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 353}], {
             RGBColor[
             0.34417064566505323`, 0.4673038972774405, 0.9433423989860289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 378}], {
             RGBColor[
             0.6098485308106321, 0.6915090182736694, 0.9640376891028258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 388}], {
             RGBColor[
             0.3698951715154694, 0.49434200497537056`, 0.9448073726771845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 299}], {
             RGBColor[
             0.5536848770366921, 0.6344859564187262, 0.96192074502719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 330}], {
             RGBColor[
             0.8811948727797689, 0.9081048884297085, 0.9885303476893256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 336}], {
             RGBColor[
             0.8020986446878395, 0.8456343816952482, 0.9808272079680709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 341}], {
             RGBColor[
             0.47724852188252453`, 0.5816831956434332, 0.9532414842974295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 368}], {
             RGBColor[
             0.44798428802700907`, 0.5580713944902425, 0.9508377236730496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 393}], {
             RGBColor[
             0.5838526089154632, 0.6653278755251159, 0.9637699881628594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 310}], {
             RGBColor[
             0.5116097845592016, 0.6129563079657265, 0.9550902187456259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 345}], {
             RGBColor[
             0.6408464446051914, 0.7190505298787062, 0.9650443030528906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 363}], {
             RGBColor[
             0.575481550846761, 0.6662408739826498, 0.9597231622224887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 316}], {
             RGBColor[
             0.6341617718676937, 0.7095465533015355, 0.9669205180620223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 324}], {
             RGBColor[
             0.6978183268233231, 0.7578896054145013, 0.8790717865237949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 360}], {
             RGBColor[
             0.4034222699005159, 0.5238458264201402, 0.9469266881991226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 374}], {
             RGBColor[
             0.6880910297090854, 0.7193593772224507, 0.644066724680433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 375}], {
             RGBColor[
             0.608496185444769, 0.6891491548169371, 0.9644545610238846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 380}], {
             RGBColor[
             0.4944980900208593, 0.5991931515538609, 0.9537075113067902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 383}], {
             RGBColor[
             0.40300393929753575`, 0.5234834894777463, 0.9469000325430159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 390}], {
             RGBColor[
             0.6474569594526406, 0.7201477749935191, 0.9681886249226286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 307}], {
             RGBColor[
             0.7289035966180415, 0.7869652944845327, 0.9673245796320459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 314}], {
             RGBColor[
             0.7703229306826114, 0.8205913757978862, 0.9705852613336288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 332}], {
             RGBColor[
             0.8457541926589919, 0.8802182215676116, 0.9776253810731572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 352}], {
             RGBColor[
             0.8324601481632794, 0.8698328129690808, 0.9763003549577338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 385}], {
             RGBColor[
             0.5869643534554548, 0.6583868811390289, 0.9580927129957441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 306}], {
             RGBColor[
             0.5188828375801245, 0.6202914888098183, 0.9552675041862211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 307}], {
             RGBColor[
             0.5062282766935337, 0.6100179462006126, 0.9542712907980447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 314}], {
             RGBColor[
             0.5476476107581034, 0.6436440275139661, 0.9575319724996276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 336}], {
             RGBColor[
             0.49750044257160764`, 0.5902846919982419, 0.9564029526356633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 367}], {
             RGBColor[
             0.5881391234197644, 0.6619588372489843, 0.9652070218048763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 306}], {
             RGBColor[
             0.6862363971195473, 0.7533393180391956, 0.9704134309827162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 307}], {
             RGBColor[
             0.6735818362329565, 0.7430657754299899, 0.9694172175945398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 314}], {
             RGBColor[
             0.7150011702975263, 0.7766918567433434, 0.9726778992961227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 363}], {
             RGBColor[
             0.6808360060105982, 0.7489550372521037, 0.9699882924123352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 316}], {
             RGBColor[
             0.7809756745913627, 0.8291706470218472, 0.9787118659188359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 324}], {
             RGBColor[
             0.8446322295469924, 0.8775136991348131, 0.8908631343806086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 372}], {
             RGBColor[
             0.6557623842352129, 0.7305487240690285, 0.9666364469152786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 380}], {
             RGBColor[
             0.6413119927445284, 0.7188172452741727, 0.9654988591636038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 383}], {
             RGBColor[
             0.5498178420212049, 0.6431075831980579, 0.9586913803998296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 390}], {
             RGBColor[
             0.7942708621763097, 0.8397718687138309, 0.9799799727794423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 323}], {
             RGBColor[
             0.6606635845968037, 0.4172858395822151, 0.44651890779670356`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 340}], {
             RGBColor[
             0.4649755113711484, 0.5679434251556468, 0.9526755480597942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 313}], {
             RGBColor[
             0.5366256271491316, 0.6228291359778192, 0.9599891931896738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 344}], {
             RGBColor[
             0.6136271643626432, 0.6936834580876978, 0.9647433648161599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 315}], {
             RGBColor[
             0.5039742024057885, 0.5999837886685737, 0.9563133399601267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 329}], {
             RGBColor[
             0.5667036208813635, 0.6566521000868515, 0.9602248983866023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 353}], {
             RGBColor[
             0.4883674148043443, 0.5835800653719695, 0.9554245564943977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 378}], {
             RGBColor[
             0.7540452999499232, 0.8077851863681984, 0.9761198466111947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 325}], {
             RGBColor[
             0.526972573606182, 0.6251133336276942, 0.9564767440030613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 314}], {
             RGBColor[
             0.5552850417354699, 0.6498444380437367, 0.9581332190429974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 352}], {
             RGBColor[
             0.617422259216138, 0.6990858752149314, 0.9638483126671025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 385}], {
             RGBColor[
             0.3719264645083134, 0.4876399433848795, 0.9456406707051127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 386}], {
             RGBColor[
             0.5345074334451243, 0.6329762396130476, 0.9564975296074943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 397}], {
             RGBColor[
             0.5848079665388692, 0.6735519436475217, 0.960635500857092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 319}], {
             RGBColor[
             0.3700386876244028, 0.4947744041735848, 0.9448052366116398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 329}], {
             RGBColor[
             0.3580016538842091, 0.484348530546736, 0.9440382474656457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 334}], {
             RGBColor[
             0.30158923813954536`, 0.434319789519752, 0.9404864329995275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 371}], {
             RGBColor[
             0.5785010415589732, 0.661626842213328, 0.9631737813604713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 386}], {
             RGBColor[
             0.4329108257583725, 0.546367942405687, 0.9496024899185971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 345}], {
             RGBColor[
             0.5298671746970545, 0.627521970253744, 0.9567028843305445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 363}], {
             RGBColor[
             0.4645022809386241, 0.5747123143576875, 0.9513817435001426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 323}], {
             RGBColor[
             0.8571857515872453, 0.5803790448331094, 0.46246887984213214`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 339}], {
             RGBColor[
             0.5796104264005266, 0.6613416072218257, 0.9634568164212236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 327}], {
             RGBColor[
             0.4971895414731471, 0.5897483666427462, 0.9564184218947879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 356}], {
             RGBColor[
             0.645903605472637, 0.721802546048524, 0.9663678951435759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 361}], {
             RGBColor[
             0.590068407993844, 0.6759123639557264, 0.9621272540808541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 344}], {
             RGBColor[
             0.34075939874846106`, 0.4654109361703843, 0.9430861636948881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 359}], {
             RGBColor[
             0.22134243076747473`, 0.3499753070302528, 0.935916496034201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 385}], {
             RGBColor[
             0.41334579857288317`, 0.521266024698233, 0.9489013524066956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 319}], {
             RGBColor[
             0.3582548055683743, 0.48238879699142373`, 0.9441341619612403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 329}], {
             RGBColor[
             0.3462177718281807, 0.4719629233645749, 0.9433671728152462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 334}], {
             RGBColor[
             0.2898053560835169, 0.4219341823375909, 0.939815358349128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 371}], {
             RGBColor[
             0.5667171595029448, 0.6492412350311669, 0.9625027067100718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 324}], {
             RGBColor[
             0.9266027347470102, 0.9418969281013088, 0.8989410395230651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 355}], {
             RGBColor[
             0.7186764435755708, 0.7794610718035494, 0.9732141588336016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 380}], {
             RGBColor[
             0.7232824979445462, 0.7832004742406684, 0.9735767643060604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 383}], {
             RGBColor[
             0.6317883472212227, 0.7074908121645536, 0.9667692855422861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 390}], {
             RGBColor[
             0.8762413673763276, 0.9041550976803265, 0.9880578779218988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 333}], {
             RGBColor[
             0.9931832183822911, 0.9914490998648501, 0.7626352428781529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 370}], {
             RGBColor[
             0.6602947932526031, 0.7243315887787444, 0.8378298713306813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 381}], {
             RGBColor[
             0.7792392145469608, 0.8243622511914672, 0.8462358841897273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 382}], {
             RGBColor[
             0.8546440713771434, 0.8844763745205417, 0.8529261143739573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 367}], {
             RGBColor[
             0.612733741495952, 0.6878093402359093, 0.9666076489198383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 373}], {
             RGBColor[
             0.3042912505587183, 0.43701548867733375`, 0.9406455916711864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 329}], {
             RGBColor[
             0.4209842240439493, 0.5390571084097016, 0.948045720387716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 334}], {
             RGBColor[
             0.3645718082992855, 0.4890283673827175, 0.9444939059215977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 371}], {
             RGBColor[
             0.6414836117187133, 0.7163354200762935, 0.9671812542825413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 388}], {
             RGBColor[
             0.36837254381734624`, 0.4930231813927496, 0.9447103521866669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 343}], {
             RGBColor[
             0.6831631826330415, 0.7507223546399475, 0.9703119038800513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 349}], {
             RGBColor[
             0.739560868871417, 0.7965085370150724, 0.974751736332268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 331}], {
             RGBColor[
             0.45134686669557145`, 0.5619730584486788, 0.9509150360085281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 338}], {
             RGBColor[
             0.5547452425088691, 0.6494062047139042, 0.9580907240705296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 342}], {
             RGBColor[
             0.6986758619935793, 0.7635427036207678, 0.9712762682313738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 384}], {
             RGBColor[
             0.3951654407047568, 0.5044067051352871, 0.9476612545205387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 398}], {
             RGBColor[
             0.5189094290901825, 0.6203130769956173, 0.9552695975673007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 328}], {
             RGBColor[
             0.9599981354681295, 0.9672782913922169, 0.8373062770614235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 362}], {
             RGBColor[
             0.7462689213717277, 0.7972451694621343, 0.8177446006958704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 364}], {
             RGBColor[
             0.6257060002448502, 0.689198441560998, 0.8099063275184961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 340}], {
             RGBColor[
             0.7894334474362663, 0.5272273320283076, 0.4557751666595086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 375}], {
             RGBColor[
             0.9009371483240856, 0.9214995296167103, 0.8964750824849275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 380}], {
             RGBColor[
             0.7869390529001759, 0.8315435263536342, 0.8857280327678331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 383}], {
             RGBColor[
             0.6954449021768523, 0.7558338642775195, 0.8789205540040588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 390}], {
             RGBColor[
             0.939897922331957, 0.9524981497932924, 0.9002091463836714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 335}], {
             RGBColor[
             0.5494265565611623, 0.6450882558574844, 0.9576720176297375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 337}], {
             RGBColor[
             0.4840200034168698, 0.591988269483307, 0.9525229741741201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 354}], {
             RGBColor[
             0.42895819061440166`, 0.5449651303190104, 0.9488297381436619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 337}], {
             RGBColor[
             0.36242758359981964`, 0.4819526626409805, 0.94470861610523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 354}], {
             RGBColor[
             0.3073657707973515, 0.4349295234766839, 0.9410153800747716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 356}], {
             RGBColor[
             0.3956258955349544, 0.5089045478368321, 0.9473221088301874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 392}], {
             RGBColor[
             0.5695624798092653, 0.6468704572785198, 0.9634769571488331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 347}], {
             RGBColor[
             0.6925285937149122, 0.7577830538274596, 0.9716736639104913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 362}], {
             RGBColor[
             0.7114073314886665, 0.7731096636296381, 0.9731598673031363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 372}], {
             RGBColor[
             0.7688280723320746, 0.819726407821213, 0.9776802383614337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 387}], {
             RGBColor[
             0.596634164266282, 0.6711483341737237, 0.9656513120454495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 334}], {
             RGBColor[
             0.3525347745590919, 0.47860249375586866`, 0.9437269167756035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 353}], {
             RGBColor[
             0.3306109842267364, 0.4555592000679707, 0.9424783893495172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 371}], {
             RGBColor[
             0.6294465779785197, 0.7059095464494447, 0.9664142651365473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 388}], {
             RGBColor[
             0.3563355100771526, 0.48259730776590076`, 0.9439433630406728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 342}], {
             RGBColor[
             0.5721245123535422, 0.6573129301734106, 0.9622778932575937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 346}], {
             RGBColor[
             0.4106021567787026, 0.5288946674099004, 0.9477074631910819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 361}], {
             RGBColor[
             0.5901182321648295, 0.6759512869767781, 0.9621322200885847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 385}], {
             RGBColor[
             0.48877706054926373`, 0.5808928704679585, 0.955941472146224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 381}], {
             RGBColor[
             0.7774925214668429, 0.8236399487148739, 0.8751831088240691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 371}], {
             RGBColor[
             0.573034162233856, 0.6558808054224606, 0.9628624506704291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 388}], {
             RGBColor[
             0.2999230943324888, 0.43256856673891675`, 0.9403915485745545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 337}], {
             RGBColor[
             0.5433498888084674, 0.6401549432250839, 0.9571936400846779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 354}], {
             RGBColor[
             0.48828807600599916`, 0.5931318040607874, 0.9535004040542197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 367}], {
             RGBColor[
             0.8365528910709119, 0.8731072625255063, 0.9841134847457571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 354}], {
             RGBColor[
             0.4228815228617066, 0.54003181768661, 0.9483513605986023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 384}], {
             RGBColor[
             0.37201246687801726`, 0.4856100779531553, 0.9458385676087602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 398}], {
             RGBColor[
             0.4957564552634429, 0.6015164498134855, 0.9534469106555221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 360}], {
             RGBColor[
             0.34965040528739955`, 0.4762624172150063, 0.9435373341380341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 374}], {
             RGBColor[
             0.6343191650959692, 0.6717759680173168, 0.6406773706193445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 368}], {
             RGBColor[
             0.6226400927445745, 0.7043800805339688, 0.9635356283249684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 379}], {
             RGBColor[
             0.7491574750657932, 0.8041803769797942, 0.9755759919465539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 393}], {
             RGBColor[
             0.7585084136330287, 0.8116365615688421, 0.9764678928147782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 399}], {
             RGBColor[
             0.5979311594629402, 0.6843202553711787, 0.9615904505852333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 346}], {
             RGBColor[
             0.6579311520767106, 0.7304643125819894, 0.9680686954139277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 398}], {
             RGBColor[
             0.6396870747481531, 0.7156529487203491, 0.9666324548163663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 349}], {
             RGBColor[
             0.572567629123657, 0.6638752210571564, 0.959493767630399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 349}], {
             RGBColor[
             0.5233631256620026, 0.6229633308562721, 0.955886967701995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 362}], {
             RGBColor[
             0.4787993796185105, 0.587749931897377, 0.9521119875449382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 372}], {
             RGBColor[
             0.5362201204619186, 0.6343666760889519, 0.9566323586032357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 387}], {
             RGBColor[
             0.364026212396126, 0.4857886024414626, 0.9446034322872514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 351}], {
             RGBColor[
             0.5144438745789837, 0.6109880779381577, 0.9569095723018982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 369}], {
             RGBColor[
             0.5200488710489632, 0.6153667437800567, 0.9574682259683558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 357}], {
             RGBColor[
             0.47459255434001574`, 0.5632002797804339, 0.9555743979857702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 394}], {
             RGBColor[
             0.4223012933980239, 0.5223499493042472, 0.9503624937846891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 378}], {
             RGBColor[
             0.517952663295296, 0.6066922863493175, 0.9583733375741095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 375}], {
             RGBColor[
             0.6930108571526461, 0.759063673318951, 0.970748201795464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 379}], {
             RGBColor[
             0.7104086654456288, 0.7728685699455924, 0.972425570774835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 366}], {
             RGBColor[
             0.41287883358605526`, 0.5307536593518293, 0.947883739743863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 391}], {
             RGBColor[
             0.4879305229411818, 0.5915566560772065, 0.953879150626576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 374}], {
             RGBColor[
             0.6861359356655947, 0.7176659730278627, 0.6439421478168035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 375}], {
             RGBColor[
             0.6065410914012783, 0.6874557506223491, 0.9643299841602553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 369}], {
             RGBColor[
             0.5841698044878945, 0.6713043300658317, 0.9615393364089648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 385}], {
             RGBColor[
             0.33132839296129246`, 0.45411994654819526`, 0.9425995520111714]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 377}], {
             RGBColor[
             0.6069851376299391, 0.627503071478467, 0.613499522650317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 387}], {
             RGBColor[
             0.26234202904300274`, 0.39306848434250485`, 0.9382513625025222]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 382}], {
             RGBColor[
             0.6074634646611325, 0.6911022959901985, 0.9629949792690329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 393}], {
             RGBColor[
             0.7292441797775133, 0.7880247604156515, 0.9740641321903983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 399}], {
             RGBColor[
             0.5686669256074247, 0.6607084542179881, 0.9591866899608534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 392}], {
             RGBColor[
             0.8139415862409984, 0.8551604216003167, 0.9819348257903322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 389}], {
             RGBColor[
             0.31640807541032356`, 0.44833154223845456`, 0.9413876016822953]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 391}], {
             RGBColor[
             0.4881658758917188, 0.5917605069737785, 0.9538941471084698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 400}], {
             RGBColor[
             0.3165758681758709, 0.44850790307372057`, 0.941397157232066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 395}], {
             RGBColor[
             0.6027175870115555, 0.6812044780890834, 0.9654263984599494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 375}], {
             RGBColor[
             0.8912098512098479, 0.8829693014246596, 0.6614700206415656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 399}], {
             RGBColor[
             0.7573813438999772, 0.7769140764426856, 0.649161848259616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 379}], {
             RGBColor[
             0.829012815238514, 0.8665639756457875, 0.9835352259643884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 383}], {
             RGBColor[
             0.6061227607982982, 0.6870934136799551, 0.9643033285041485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 399}], {
             RGBColor[
             0.6777864996356608, 0.746703854037172, 0.9695496846030678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 377}], {
             RGBColor[
             0.8227740493855374, 0.8121573935990177, 0.6293137180379831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 393}], {
             RGBColor[
             0.855761562098732, 0.887825056861477, 0.9861044958119838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 399}], {
             RGBColor[
             0.6951843079286435, 0.7605087506638135, 0.9712270535824388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 383}], {
             RGBColor[
             0.49212466537438837`, 0.5971374104168791, 0.9535562787870541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 390}], {
             RGBColor[
             0.7365776855294932, 0.7938016959326519, 0.9748448711666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 390}], {
             RGBColor[
             0.6450835348061696, 0.7180920338565373, 0.9680373924028924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 398}], {
             RGBColor[
             0.3361766534593305, 0.4565169502348683, 0.9430174411055313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 400}], {
             RGBColor[
             0.3073242685433973, 0.44034767009612974`, 0.9408130344968098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 399}], {
             RGBColor[
             0.704535246495879, 0.7679649352528615, 0.9721189544506632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 396}], {
             RGBColor[
             0.7871829996493593, 0.8342799749267771, 0.9792615266464828]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.09653745999529093], {
             RGBColor[
             0.9377373523370375, 0.9530851998354669, 0.9902786011808289]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.09653745999529093], {
             RGBColor[
             0.8235173549204953, 0.8621144013032386, 0.98302901454658]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.09653745999529093], {
             RGBColor[
             0.5357826614565134, 0.6340115271610605, 0.956597920227865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.09653745999529093], {
             RGBColor[
             0.40845468855618705`, 0.5282046545229664, 0.9472473494658689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.09653745999529093], {
             RGBColor[
             0.3295210866693707, 0.45983633588679185`, 0.9422177701518845]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.09653745999529093], {
             RGBColor[
             0.8945507869953306, 0.9187545318885638, 0.9898042467101712]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.09653745999529093], {
             RGBColor[
             0.37754642183102627`, 0.5014334673802876, 0.9452779020412487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.09653745999529093], {
             RGBColor[
             0.5730606551849642, 0.6642754818242964, 0.9595325804479591]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.09653745999529093], {
             RGBColor[
             0.6072881947928905, 0.6920629404110987, 0.9622270977455039]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.09653745999529093], {
             RGBColor[
             0.28429129870797953`, 0.4161385584244709, 0.939501340938908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.09653745999529093], {
             RGBColor[
             0.3074920613089446, 0.44052403093139575`, 0.9408225900465804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.09653745999529093], {
             RGBColor[
             0.3941196011842843, 0.5157883223438651, 0.9463339303745513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.09653745999529093], {
             RGBColor[
             0.3003411958831056, 0.4330080179777844, 0.9404153588393364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.09653745999529093], {
             RGBColor[
             0.2676594895651098, 0.39865747249770916`, 0.9385541840127782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.09653745999529093], {
             RGBColor[
             0.612519599079081, 0.6963100300827054, 0.962638933054178]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.09653745999529093], {
             RGBColor[
             0.32045993714199306`, 0.45198802359279466`, 0.9416404017164599]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.09653745999529093], {
             RGBColor[
             0.2790980726226407, 0.4106801485392283, 0.9392055943960375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.09653745999529093], {
             RGBColor[
             0.36533457978526174`, 0.49085618358527416`, 0.9444997742646005]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.09653745999529093], {
             RGBColor[
             0.9615371052877696, 0.9708350166176042, 0.9499918274049479]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.09653745999529093], {
             RGBColor[
             0.24403657579750276`, 0.3738282923487136, 0.9372088940206822]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.09653745999529093], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.09653745999529093], {
             RGBColor[
             0.46690550999381475`, 0.5780939527233284, 0.9511756585594022]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.09653745999529093], {
             RGBColor[
             0.2790980726226407, 0.4106801485392283, 0.9392055943960375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.09653745999529093], {
             RGBColor[
             0.8023380099870631, 0.8455118184874023, 0.9809332126266627]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.09653745999529093], {
             RGBColor[
             0.8256045758512776, 0.8637786946173415, 0.9832280955422421]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.09653745999529093], {
             RGBColor[
             0.7754342189262599, 0.8244943724343176, 0.9782516941639438]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.09653745999529093], {
             RGBColor[
             0.3920996482903688, 0.51403874067294, 0.9462052207623252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.09653745999529093], {
             RGBColor[
             0.24478417966579302`, 0.3746140714151097, 0.9372514689550006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.09653745999529093], {
             RGBColor[
             0.8314265149324124, 0.8684209508083119, 0.9837833972891071]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.09653745999529093], {
             RGBColor[
             0.501282372246417, 0.606002638159987, 0.9538819310825227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.09653745999529093], {
             RGBColor[
             0.26361878402490124`, 0.39441043477942156`, 0.9383240718099515]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.09653745999529093], {
             RGBColor[
             0.9302134288503685, 0.947190954467146, 0.993205781326721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.09653745999529093], {
             RGBColor[
             0.6394287069072855, 0.7181560560591349, 0.9647573165937242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.09653745999529093], {
             RGBColor[
             0.5640086137153335, 0.6569266267694291, 0.9588199705847493]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.09653745999529093], {
             RGBColor[
             0.29617012401873954`, 0.42862395698710487`, 0.9401778224672085]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.09653745999529093], {
             RGBColor[
             0.33999614934146716`, 0.4689093086814034, 0.9428852318826162]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.09653745999529093], {
             RGBColor[
             0.6877442064021563, 0.7559902681817087, 0.9695115732252992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.09653745999529093], {
             RGBColor[
             0.6368532976469088, 0.7160652228006961, 0.9645545709427124]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.09653745999529093], {
             RGBColor[
             0.5587655340520823, 0.6526700585007547, 0.9584072161476245]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.09653745999529093], {
             RGBColor[
             0.3226510817834853, 0.45388588295112337`, 0.9417800195154626]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.09653745999529093], {
             RGBColor[
             0.8294596367924253, 0.8668526155689711, 0.9835957946962623]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.09653745999529093], {
             RGBColor[
             0.4143662192909088, 0.5333249253232084, 0.9476240269769239]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.09653745999529093], {
             RGBColor[
             0.44066400934666566`, 0.5561027493041448, 0.9492996989050542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.09653745999529093], {
             RGBColor[
             0.5243709798519363, 0.6247470099440671, 0.9556995508495856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.09653745999529093], {
             RGBColor[
             0.8110144112926838, 0.8522898891304456, 0.9817979952232269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.09653745999529093], {
             RGBColor[
             0.9631702765468764, 0.9720530330685734, 0.9472272944625638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.09653745999529093], {
             RGBColor[
             0.9834156323235343, 0.9871519862580774, 0.9129571879671365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.09653745999529093], {
             RGBColor[
             0.30619373655233284`, 0.4391594092936527, 0.9407486523723908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.09653745999529093], {
             RGBColor[
             0.2490517983270865, 0.37909960921078034`, 0.9374945035243851]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.09653745999529093], {
             RGBColor[
             0.7862335732126272, 0.8329309100809603, 0.9793280728735051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.09653745999529093], {
             RGBColor[
             0.7886520837253299, 0.8348202688748444, 0.9795691273991456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.09653745999529093], {
             RGBColor[
             0.7182161210376565, 0.7797951594900903, 0.9725487288999334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.09653745999529093], {
             RGBColor[
             0.9916974936356862, 0.9908347145007446, 0.7872575468617887]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.09653745999529093], {
             RGBColor[
             0.9626826081471922, 0.9716893307745728, 0.9480527898589399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.09653745999529093], {
             RGBColor[
             0.972556613641496, 0.9790533479050244, 0.9313386741101635]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.09653745999529093], {
             RGBColor[
             0.8761288748215718, 0.9040653991706933, 0.988047148281603]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.09653745999529093], {
             RGBColor[
             0.3719270002921292, 0.49656620688363384`, 0.9449198374698496]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.09653745999529093], {
             RGBColor[
             0.22378182340557562`, 0.35253926335932323`, 0.9360554158361829]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.09653745999529093], {
             RGBColor[
             0.6884513307293929, 0.7565426790804899, 0.9695820527697856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.09653745999529093], {
             RGBColor[
             0.6889179813187256, 0.7569072300675525, 0.9696285641394325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.09653745999529093], {
             RGBColor[
             0.2525685002319563, 0.3827958858845775, 0.9376947744953732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.09653745999529093], {
             RGBColor[
             0.33240041263057035`, 0.4623302633152523, 0.9424012382560442]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.09653745999529093], {
             RGBColor[
             0.3078494297406834, 0.44089964781162055`, 0.9408429416500887]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.09653745999529093], {
             RGBColor[
             0.45053643829857015`, 0.5646537510595776, 0.9499287613480233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.09653745999529093], {
             RGBColor[
             0.9858580075408822, 0.9884199369325957, 0.8840329435582743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.09653745999529093], {
             RGBColor[
             0.2837769998629287, 0.41559799772989237`, 0.9394720523805193]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.09653745999529093], {
             RGBColor[
             0.4150427133682919, 0.5339108704914567, 0.9476671325813346]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.09653745999529093], {
             RGBColor[
             0.2722395150424864, 0.40347136966481933`, 0.9388150096881743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.09653745999529093], {
             RGBColor[
             0.33585050799792776`, 0.46531856251562204`, 0.9426210752820526]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.09653745999529093], {
             RGBColor[
             0.6394287069072855, 0.7181560560591349, 0.9647573165937242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.09653745999529093], {
             RGBColor[
             0.4434447921996799, 0.5585113236452156, 0.9494768879294985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.09653745999529093], {
             RGBColor[
             0.7182161210376565, 0.7797951594900903, 0.9725487288999334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.09653745999529093], {
             RGBColor[
             0.8246209608644437, 0.8629943867263578, 0.9831342774667144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.09653745999529093], {
             RGBColor[
             0.2525685002319563, 0.3827958858845775, 0.9376947744953732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.09653745999529093], {
             RGBColor[
             0.4483041289394333, 0.5627202368918239, 0.9497865205696128]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.09653745999529093], {
             RGBColor[
             0.4889704776109674, 0.5960072874503964, 0.952912693636864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.09653745999529093], {
             RGBColor[
             0.4112360226117313, 0.5306137062879644, 0.947424573612451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.09653745999529093], {
             RGBColor[
             0.3074920613089446, 0.44052403093139575`, 0.9408225900465804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.09653745999529093], {
             RGBColor[
             0.33240041263057035`, 0.4623302633152523, 0.9424012382560442]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.09653745999529093], {
             RGBColor[
             0.34281236520116365`, 0.47134857331194774`, 0.9430646786669142]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.09653745999529093], {
             RGBColor[
             0.20887240989662495`, 0.336868524450001, 0.9352063467933488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.09653745999529093], {
             RGBColor[
             0.7513503545870487, 0.8056798745683774, 0.9758512396431195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.09653745999529093], {
             RGBColor[
             0.37700765741054326`, 0.5009668167183523, 0.9452435724487862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.09653745999529093], {
             RGBColor[
             0.3538312273073686, 0.4808925578442299, 0.9437667908167244]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.09653745999529093], {
             RGBColor[
             0.878945942350168, 0.906311652350735, 0.9883158426973063]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.09653745999529093], {
             RGBColor[
             0.2834883533526057, 0.41529461194629713`, 0.9394556143887707]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.09653745999529093], {
             RGBColor[
             0.7913049330282, 0.836892694912648, 0.9798335386253695]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.09653745999529093], {
             RGBColor[
             0.39656349257979895`, 0.5179050982371067, 0.9464896529732252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.09653745999529093], {
             RGBColor[
             0.40600654640446904`, 0.5260841968383505, 0.9470913560127685]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.09653745999529093], {
             RGBColor[
             0.35209289109872854`, 0.4793868983916242, 0.9436560255706602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.09653745999529093], {
             RGBColor[
             0.30799573628120447`, 0.44105342526207864`, 0.9408512735911303]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.09653745999529093], {
             RGBColor[
             0.9898699100096214, 0.99007896170461, 0.8175453371804929]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.09653745999529093], {
             RGBColor[
             0.6176153396845332, 0.7004469818667098, 0.9630400884209521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.09653745999529093], {
             RGBColor[
             0.22165042215541883`, 0.35029902550676395`, 0.9359340356881121]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.09653745999529093], {
             RGBColor[
             0.36777189460495363`, 0.49296726317908657`, 0.9446550778096785]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.09653745999529093], {
             RGBColor[
             0.37541990243594203`, 0.4995915831622382, 0.9451424021058012]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.09653745999529093], {
             RGBColor[
             0.42158998257307756`, 0.5395817860013234, 0.9480843187855407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.09653745999529093], {
             RGBColor[
             0.3825839798989672, 0.5057967469837076, 0.9455988907868003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.09653745999529093], {
             RGBColor[
             0.25190627881051314`, 0.3820998491833776, 0.9376570619650908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.09653745999529093], {
             RGBColor[
             0.7455243894103966, 0.8011285862934014, 0.9752705618810509]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.09653745999529093], {
             RGBColor[
             0.29617012401873954`, 0.42862395698710487`, 0.9401778224672085]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.09653745999529093], {
             RGBColor[
             0.2397412299958117, 0.36931361157048287`, 0.9369642804316706]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.09653745999529093], {
             RGBColor[
             0.833297964795013, 0.8699131941295964, 0.9839618978476651]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.09653745999529093], {
             RGBColor[
             0.6267914472915286, 0.7078965594010055, 0.9637624652249646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.09653745999529093], {
             RGBColor[
             0.987755754036133, 0.9892047038782422, 0.8525823729214707]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.09653745999529093], {
             RGBColor[
             0.5546638983363169, 0.6493401658501131, 0.9580843203592928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.09653745999529093], {
             RGBColor[
             0.6688806397128856, 0.7412539065156337, 0.9676314291877659]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.09653745999529093], {
             RGBColor[
             0.45226940849584074`, 0.5661547627428387, 0.950039184676588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.09653745999529093], {
             RGBColor[
             0.5778982163356087, 0.668202831896036, 0.9599134109823082]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.09653745999529093], {
             RGBColor[
             0.4262451088746415, 0.5436138224302872, 0.9483809393171098]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.09653745999529093], {
             RGBColor[
             0.353649460147158, 0.48073512026593856`, 0.9437552087740062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.09653745999529093], {
             RGBColor[
             0.9403356432020276, 0.9550230009082658, 0.9858803724891915]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.09653745999529093], {
             RGBColor[
             0.7722410700463371, 0.8219998602604917, 0.9779334309252659]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.09653745999529093], {
             RGBColor[
             0.8553144289903896, 0.8874685250579896, 0.9860618478569496]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.09653745999529093], {
             RGBColor[
             0.5973054141812104, 0.6839584693913952, 0.9614412166876221]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.09653745999529093], {
             RGBColor[
             0.2908520575418706, 0.42303433193502615`, 0.9398749664487251]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.09653745999529093], {
             RGBColor[
             0.5149749517110686, 0.6171188910130665, 0.9549598610955513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.09653745999529093], {
             RGBColor[
             0.8471151768577252, 0.36315347209643006`, 0.19275085260892622`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.09653745999529093], {
             RGBColor[
             0.3932762470688765, 0.5150578513973092, 0.9462801925960662]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.09653745999529093], {
             RGBColor[
             0.7253475334668618, 0.7853662730805273, 0.9732595214440384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.09653745999529093], {
             RGBColor[
             0.8392619585986195, 0.8746687209002931, 0.9845307489007732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.09653745999529093], {
             RGBColor[
             0.6307305481373477, 0.7110944989221124, 0.9640725656729493]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.09653745999529093], {
             RGBColor[
             0.9935000788091838, 0.9885056507527127, 0.5339018751225226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.09653745999529093], {
             RGBColor[
             0.87331103173588, 0.9018185275824757, 0.9877783798925714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.09653745999529093], {
             RGBColor[
             0.38459487180374075`, 0.5075384804812565, 0.9457270230408106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.09653745999529093], {
             RGBColor[
             0.5760303058406665, 0.666686378007833, 0.9597663622257647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.09653745999529093], {
             RGBColor[
             0.7115111058398221, 0.7745571506575392, 0.9718804356469427]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.09653745999529093], {
             RGBColor[
             0.8359682241776446, 0.8720423864790469, 0.9842165895713492]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.09653745999529093], {
             RGBColor[
             0.9439267184231094, 0.9577012189283025, 0.9798016188423203]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.09653745999529093], {
             RGBColor[
             0.6682450137020388, 0.7407573506450236, 0.9675680759272675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.09653745999529093], {
             RGBColor[
             0.37970944121150707`, 0.503306966051145, 0.94541572772349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.09653745999529093], {
             RGBColor[
             0.9139318170253043, 0.9342084391504194, 0.9916528266560799]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.09653745999529093], {
             RGBColor[
             0.9008689421903414, 0.9237924573393115, 0.9904068779929551]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.09653745999529093], {
             RGBColor[
             0.5738595477808759, 0.6649240588233589, 0.9595954721995492]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.09653745999529093], {
             RGBColor[
             0.9898699100096214, 0.99007896170461, 0.8175453371804929]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.09653745999529093], {
             RGBColor[
             0.736567894998583, 0.7941317047870141, 0.9743778622212803]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.09653745999529093], {
             RGBColor[
             0.4985656881563047, 0.6037971116304103, 0.9536680637594074]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.09653745999529093], {
             RGBColor[
             0.8069853058528067, 0.8491423213384779, 0.981396411647111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.09653745999529093], {
             RGBColor[
             0.25255718870617483`, 0.38278399675378905`, 0.9376941303207138]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.09653745999529093], {
             RGBColor[
             0.6150163850857084, 0.6983370334418134, 0.9628354891946482]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.09653745999529093], {
             RGBColor[
             0.989815031159921, 0.9900562678899367, 0.8184548217419411]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.09653745999529093], {
             RGBColor[
             0.5558535857825126, 0.6503060077137435, 0.958177976913026]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.09653745999529093], {
             RGBColor[
             0.774004256295562, 0.8233772747590979, 0.9781091688526763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.09653745999529093], {
             RGBColor[
             0.9951089533212818, 0.9919468706519249, 0.7090179369418372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.09653745999529093], {
             RGBColor[
             0.4656318623785397, 0.577059948212077, 0.9510753923536028]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.09653745999529093], {
             RGBColor[
             0.792636180290929, 0.8379326753921457, 0.9799662249113054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.09653745999529093], {
             RGBColor[
             0.21138094157016918`, 0.3395051502889904, 0.9353492039611171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.09653745999529093], {
             RGBColor[
             0.4667776067233076, 0.5779901150863541, 0.9511655895454227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.09653745999529093], {
             RGBColor[
             0.9238719150771004, 0.9421344035201478, 0.9926009220818904]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.09653745999529093], {
             RGBColor[
             0.6254508710346836, 0.7068082192034265, 0.963656930151333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.09653745999529093], {
             RGBColor[
             0.8422091813277838, 0.8770187563042989, 0.9848118576356976]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.09653745999529093], {
             RGBColor[
             0.4350696084598541, 0.551257160438753, 0.9489432286274809]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.09653745999529093], {
             RGBColor[
             0.3441471447774507, 0.4725046922929554, 0.943149729641216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.09653745999529093], {
             RGBColor[
             0.28890337999551097`, 0.4209861482805096, 0.9397639921452701]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.09653745999529093], {
             RGBColor[
             0.9950881826672378, 0.9919024443231598, 0.7067571794307556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.09653745999529093], {
             RGBColor[
             0.46824979700103136`, 0.5791853054752265, 0.9512814857568959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.09653745999529093], {
             RGBColor[
             0.5974789230930975, 0.6840993317425524, 0.9614548759447499]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.09653745999529093], {
             RGBColor[
             0.4501898953573199, 0.5643535929816212, 0.9499066799382427]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.09653745999529093], {
             RGBColor[
             0.9367886703751002, 0.9523776743815783, 0.9918844722865058]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.09653745999529093], {
             RGBColor[
             0.7419030611978468, 0.7982995771706438, 0.9749096217280601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.09653745999529093], {
             RGBColor[
             0.8570569812423271, 0.8888579889233638, 0.9862280540463342]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.09653745999529093], {
             RGBColor[
             0.9224360436887881, 0.9409894786507982, 0.9924639673870557]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.09653745999529093], {
             RGBColor[
             0.7922020952186326, 0.8375935648344991, 0.9799229593680544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.09653745999529093], {
             RGBColor[
             0.9496328134904701, 0.961956815286667, 0.9701426882812213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.09653745999529093], {
             RGBColor[
             0.9031919167666392, 0.9256447342109863, 0.9906284453817863]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.09653745999529093], {
             RGBColor[
             0.29497518978312737`, 0.4273680053422701, 0.9401097727302372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.09653745999529093], {
             RGBColor[
             0.9518806960353249, 0.9636332824080499, 0.966337609474446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.09653745999529093], {
             RGBColor[
             0.24606881763188765`, 0.3759643073682266, 0.937324627186718]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.09653745999529093], {
             RGBColor[
             0.4599206418447562, 0.5724233220951985, 0.9506257841522933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.09653745999529093], {
             RGBColor[
             0.6828212301053111, 0.7521444016826077, 0.9690208969558588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.09653745999529093], {
             RGBColor[
             0.875307265672997, 0.903410270337606, 0.9879687824675527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.09653745999529093], {
             RGBColor[
             0.266802870703925, 0.39775711176183115`, 0.9385054008358878]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.09653745999529093], {
             RGBColor[
             0.3313044144032992, 0.46138096473726264`, 0.9423314022181556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.09653745999529093], {
             RGBColor[
             0.40923724423401503`, 0.5288824649187089, 0.9472972132216733]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.09653745999529093], {
             RGBColor[
             0.6067155590834545, 0.6915980489452338, 0.9621820177648233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.09653745999529093], {
             RGBColor[
             0.7124244596680929, 0.7752706696099305, 0.971971470220768]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.09653745999529093], {
             RGBColor[
             0.6216467954642115, 0.7037198992836657, 0.9633574593876375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.09653745999529093], {
             RGBColor[
             0.7067736689973433, 0.7708562289903411, 0.9714082522163489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.09653745999529093], {
             RGBColor[
             0.29481181719338456`, 0.4271962903920299, 0.9401004689029394]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.09653745999529093], {
             RGBColor[
             0.6184178335410607, 0.7010984825313751, 0.9631032636769699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.09653745999529093], {
             RGBColor[
             0.7537051363835874, 0.807519448004838, 0.9760859422859115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.09653745999529093], {
             RGBColor[
             0.38015201905655976`, 0.5036903047359202, 0.9454439283924206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.09653745999529093], {
             RGBColor[
             0.7299664371782415, 0.7889745957648255, 0.9737198905998794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.09653745999529093], {
             RGBColor[
             0.6816345601915057, 0.7512173661269175, 0.9689026207889115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.09653745999529093], {
             RGBColor[
             0.39922193293888636`, 0.5202077056590508, 0.9466590464421397]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.09653745999529093], {
             RGBColor[
             0.23863334567338157`, 0.36814915490368566`, 0.9369011880584761]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.09653745999529093], {
             RGBColor[
             0.3617446241543326, 0.4877467444541798, 0.9442710254662708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.09653745999529093], {
             RGBColor[
             0.9653078869302215, 0.894637497899432, 0.31972812109008963`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.09653745999529093], {
             RGBColor[
             0.8365018045440107, 0.872467848979534, 0.9842674829430259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.09653745999529093], {
             RGBColor[
             0.5778982163356087, 0.668202831896036, 0.9599134109823082]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.09653745999529093], {
             RGBColor[
             0.9215439725780606, 0.9402781653617293, 0.9923788808481533]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.09653745999529093], {
             RGBColor[
             0.6193321022042979, 0.7018407270195249, 0.9631752382552163]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.09653745999529093], {
             RGBColor[
             0.8951285839785095, 0.9192152515190694, 0.9898593575022323]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.09653745999529093], {
             RGBColor[
             0.990281476078195, 0.9902491548507306, 0.8107246223253863]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.09653745999529093], {
             RGBColor[
             0.5138995986342013, 0.6162458709411617, 0.9548752053621923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.09653745999529093], {
             RGBColor[
             0.6955690068791442, 0.762103061785018, 0.9702914762099275]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.09653745999529093], {
             RGBColor[
             0.2765898767002093, 0.4080438755959463, 0.9390627563487983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.09653745999529093], {
             RGBColor[
             0.4863236026201292, 0.5938584350924745, 0.9527043219417627]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.09653745999529093], {
             RGBColor[
             0.2437168580327831, 0.37349224870671616`, 0.9371906865669615]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.09653745999529093], {
             RGBColor[
             0.5604956948133382, 0.6540746809495963, 0.9585434207405382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.09653745999529093], {
             RGBColor[
             0.8474383814976555, 0.8811883785768972, 0.9853106234160621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.09653745999529093], {
             RGBColor[
             0.9368699087575821, 0.9524382618342176, 0.9917469568953273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.09653745999529093], {
             RGBColor[
             0.19856118018119892`, 0.32603076824936433`, 0.9346191375151527]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.09653745999529093], {
             RGBColor[
             0.3443936885318878, 0.47271823610139946`, 0.9431654391912386]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.09653745999529093], {
             RGBColor[
             0.48543085171268047`, 0.5931336596878375, 0.952634041320074]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.09653745999529093], {
             RGBColor[
             0.49429539428288566`, 0.600330294689422, 0.95333189058309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.09653745999529093], {
             RGBColor[
             0.4833107739158069, 0.5914124850239192, 0.9524671410298032]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.09653745999529093], {
             RGBColor[
             0.5308418324786762, 0.6300003396150433, 0.9562089600718767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.09653745999529093], {
             RGBColor[
             0.298761218973127, 0.4313473620690749, 0.9403253814916794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.09653745999529093], {
             RGBColor[
             0.7520531782080259, 0.8062289257227422, 0.9759212905333984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.09653745999529093], {
             RGBColor[
             0.4672960516080824, 0.5784110119994902, 0.9512064034258785]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.09653745999529093], {
             RGBColor[
             0.5622163088073522, 0.6554715529027141, 0.9586788737769638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.09653745999529093], {
             RGBColor[
             0.8841653665571773, 0.9104734795359083, 0.9888136760376058]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.09653745999529093], {
             RGBColor[
             0.4759979830199357, 0.5854756319371753, 0.9518914513428446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.09653745999529093], {
             RGBColor[
             0.18171868777103106`, 0.3083282408505815, 0.9336599824886282]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.09653745999529093], {
             RGBColor[
             0.402500830192307, 0.5230477216577959, 0.9468679748757127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.09653745999529093], {
             RGBColor[
             0.5341380599014671, 0.6326763655302181, 0.9564684511690777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.09653745999529093], {
             RGBColor[
             0.5121375474841148, 0.6148153584380217, 0.9547364902410513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.09653745999529093], {
             RGBColor[
             0.956787583880072, 0.9672928313283709, 0.9580315282746047]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.09653745999529093], {
             RGBColor[
             0.5938320783813255, 0.6811386589170538, 0.9611677829702069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.09653745999529093], {
             RGBColor[
             0.7693378889939545, 0.8197318731573771, 0.9776440689697338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.09653745999529093], {
             RGBColor[
             0.6249509204580277, 0.7064023368027805, 0.9636175722105594]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.09653745999529093], {
             RGBColor[
             0.3384659612831909, 0.46758393669481263`, 0.942787729652635]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.09653745999529093], {
             RGBColor[
             0.6513924338400113, 0.7275919871724569, 0.9658883682629334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.09653745999529093], {
             RGBColor[
             0.9838479603881707, 0.9874744158208109, 0.9122253693229253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.09653745999529093], {
             RGBColor[
             0.6519775517277189, 0.7280490857133948, 0.9659466873457426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.09653745999529093], {
             RGBColor[
             0.4717885348852414, 0.5820582123079532, 0.9515600681659648]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.09653745999529093], {
             RGBColor[
             0.33990212431338457`, 0.4688278689279136, 0.9428792406909698]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.09653745999529093], {
             RGBColor[
             0.29617012401873954`, 0.42862395698710487`, 0.9401778224672085]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.09653745999529093], {
             RGBColor[
             0.5391748294440818, 0.6367654419487948, 0.9568649641177671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.09653745999529093], {
             RGBColor[
             0.29830465267960793`, 0.4308674819466114, 0.9402993807166928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.09653745999529093], {
             RGBColor[
             0.5832399484297262, 0.6725394906523291, 0.9603339317001666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.09653745999529093], {
             RGBColor[
             0.7267282528623358, 0.7864449015661277, 0.9733971386498229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.09653745999529093], {
             RGBColor[
             0.26376844048858783`, 0.394567733211524, 0.9383325945241616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.09653745999529093], {
             RGBColor[
             0.3443936885318878, 0.47271823610139946`, 0.9431654391912386]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.09653745999529093], {
             RGBColor[
             0.5336656511882293, 0.6322928428550416, 0.9564312614246816]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.09653745999529093], {
             RGBColor[
             0.33611451202488674`, 0.4655472295345457, 0.9426378973852009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.09653745999529093], {
             RGBColor[
             0.8158801281875075, 0.8560910241494999, 0.9822829644105933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.09653745999529093], {
             RGBColor[
             0.74527371256352, 0.800932755635407, 0.9752455767556625]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.09653745999529093], {
             RGBColor[
             0.621030557677273, 0.7032196096870332, 0.9633089468916963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.09653745999529093], {
             RGBColor[
             0.9251581302403244, 0.943159996577922, 0.9927236024323766]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.09653745999529093], {
             RGBColor[
             0.9440178606393534, 0.9577691926439457, 0.9796473388439162]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.09653745999529093], {
             RGBColor[
             0.3869322993154277, 0.5095630427093572, 0.9458759618549493]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.09653745999529093], {
             RGBColor[
             0.836776521644556, 0.8726869009385118, 0.9842936857053188]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.09653745999529093], {
             RGBColor[
             0.6100646210489943, 0.6943169683223812, 0.9624456681907688]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.09653745999529093], {
             RGBColor[
             0.7032462721774819, 0.7681005997854568, 0.9710566742667425]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.09653745999529093], {
             RGBColor[
             0.41757518865849064`, 0.5361043733019177, 0.9478284996674461]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.09653745999529093], {
             RGBColor[
             0.5572823826679781, 0.6514659693919306, 0.9582904570377053]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.09653745999529093], {
             RGBColor[
             0.27067727702609884`, 0.40182935845798484`, 0.9387260425442651]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.09653745999529093], {
             RGBColor[
             0.701095256233328, 0.766420209781557, 0.9708422810998161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.09653745999529093], {
             RGBColor[
             0.34273786130362627`, 0.47128404178057565`, 0.9430599313444443]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.09653745999529093], {
             RGBColor[
             0.3920996482903688, 0.51403874067294, 0.9462052207623252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.09653745999529093], {
             RGBColor[
             0.43885173510276, 0.5545330484416257, 0.9491842223927637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.09653745999529093], {
             RGBColor[
             0.5839612431913286, 0.6731250702337566, 0.9603907146659897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.09653745999529093], {
             RGBColor[
             0.556198807540734, 0.6505862742891306, 0.9582051540344222]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.09653745999529093], {
             RGBColor[
             0.3081439083512366, 0.44120916350233425`, 0.9408597117713177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.09653745999529093], {
             RGBColor[
             0.9360059889154899, 0.9517939518305242, 0.9932093478416079]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.09653745999529093], {
             RGBColor[
             0.9388291515952022, 0.953899461934549, 0.988430469823608]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.09653745999529093], {
             RGBColor[
             0.43433382085955274`, 0.5506198582011319, 0.9488963448922212]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.09653745999529093], {
             RGBColor[
             0.6685868561195996, 0.7410244005397206, 0.9676021475847509]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.09653745999529093], {
             RGBColor[
             0.46824979700103136`, 0.5791853054752265, 0.9512814857568959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.09653745999529093], {
             RGBColor[
             0.4588002800881642, 0.5715137619494752, 0.950537585170794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.09653745999529093], {
             RGBColor[
             0.7669542313781228, 0.8178697417114205, 0.9774064882551347]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.09653745999529093], {
             RGBColor[
             0.49812459260586484`, 0.6034390103914351, 0.9536333391018905]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.09653745999529093], {
             RGBColor[
             0.9414025577668066, 0.9558187040437657, 0.9840743644269052]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.09653745999529093], {
             RGBColor[
             0.6406113817269609, 0.7191162047566408, 0.9648504210878096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.09653745999529093], {
             RGBColor[
             0.3058543075264858, 0.4388026478664443, 0.940729322391509]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.09653745999529093], {
             RGBColor[
             0.9796628347375043, 0.9843531559630582, 0.919309695393917]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.09653745999529093], {
             RGBColor[
             0.4585817581114375, 0.5713363559644655, 0.9505203823203137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.09653745999529093], {
             RGBColor[
             0.3882029042712181, 0.5106635768596007, 0.9459569236791804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.09653745999529093], {
             RGBColor[
             0.6382202148750729, 0.717174947785439, 0.9646621796740962]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.09653745999529093], {
             RGBColor[
             0.8041291080513647, 0.8469110379080842, 0.9811117325429493]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.09653745999529093], {
             RGBColor[
             0.599742401300787, 0.685936925320086, 0.9616330652406531]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.09653745999529093], {
             RGBColor[
             0.6225890544673385, 0.7044848675906886, 0.9634316374679721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.09653745999529093], {
             RGBColor[
             0.4268163899979938, 0.5441086374259109, 0.9484173408451257]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.09653745999529093], {
             RGBColor[
             0.5761701328957352, 0.6667998959102749, 0.9597773699237432]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.09653745999529093], {
             RGBColor[
             0.5747351620148649, 0.6656349219044829, 0.9596644037595294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.09653745999529093], {
             RGBColor[
             0.654837115907947, 0.7302829989844816, 0.9662317019790811]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.09653745999529093], {
             RGBColor[
             0.7165208285600057, 0.7784707841218494, 0.9723797579891701]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.09653745999529093], {
             RGBColor[
             0.9937914597052554, 0.9891288850262822, 0.5656168874654696]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.09653745999529093], {
             RGBColor[
             0.5453437733331876, 0.6417736685057261, 0.9573506059783036]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.09653745999529093], {
             RGBColor[
             0.4191787308770692, 0.5374932809752752, 0.9479306759596572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.09653745999529093], {
             RGBColor[
             0.2599865196917175, 0.39059269466638524`, 0.9381172197296302]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.09653745999529093], {
             RGBColor[
             0.715699467818872, 0.777829130868303, 0.9722978924265464]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.09653745999529093], {
             RGBColor[
             0.7751754389588962, 0.8242922115570125, 0.9782259013952332]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.09653745999529093], {
             RGBColor[
             0.5753226657806161, 0.6661118839282627, 0.9597106542080667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.09653745999529093], {
             RGBColor[
             0.8538963680774747, 0.8863378017782694, 0.985926591941158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.09653745999529093], {
             RGBColor[
             0.42480995719205095`, 0.5423707661756482, 0.94828949272095]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.09653745999529093], {
             RGBColor[
             0.3617446241543326, 0.4877467444541798, 0.9442710254662708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.09653745999529093], {
             RGBColor[
             0.4947285059263224, 0.6006819142330211, 0.9533659867182015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.09653745999529093], {
             RGBColor[
             0.6761452686918898, 0.7469290898872569, 0.9683554995125755]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.09653745999529093], {
             RGBColor[
             0.43606651318038925`, 0.5521206292017923, 0.9490067505147453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.09653745999529093], {
             RGBColor[
             0.858283079152924, 0.8898356461157325, 0.9863450003595975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.09653745999529093], {
             RGBColor[
             0.3025927171649591, 0.4353745095997068, 0.9405435796455106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.09653745999529093], {
             RGBColor[
             0.6225890544673385, 0.7044848675906886, 0.9634316374679721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.09653745999529093], {
             RGBColor[
             0.4053773639440067, 0.5255392306147281, 0.9470512650627521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.09653745999529093], {
             RGBColor[
             0.943941485565183, 0.9577122322386821, 0.9797766219226772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.09653745999529093], {
             RGBColor[
             0.49859084571616724`, 0.6038175356708418, 0.9536700442546749]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.09653745999529093], {
             RGBColor[
             0.24908667492046016`, 0.37913626672171985`, 0.9374964896947825]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.09653745999529093], {
             RGBColor[
             0.833297964795013, 0.8699131941295964, 0.9839618978476651]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.09653745999529093], {
             RGBColor[
             0.6990051693913449, 0.7647874180553516, 0.9706339607763793]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.09653745999529093], {
             RGBColor[
             0.27182071711195466`, 0.40303118648650804`, 0.9387911597655866]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.09653745999529093], {
             RGBColor[
             0.8094933927633138, 0.8511016578951327, 0.9816463943109456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.09653745999529093], {
             RGBColor[
             0.7244600514589714, 0.7846729653908503, 0.9731710655314828]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.09653745999529093], {
             RGBColor[
             0.3971610410281788, 0.5184226646694351, 0.9465277282319646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.09653745999529093], {
             RGBColor[
             0.5391748294440818, 0.6367654419487948, 0.9568649641177671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.09653745999529093], {
             RGBColor[
             0.5138657076709001, 0.6162183567303833, 0.9548725373414145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.09653745999529093], {
             RGBColor[
             0.5102493328381664, 0.6132824207253404, 0.9545878430673642]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.09653745999529093], {
             RGBColor[
             0.30705611746466266`, 0.4400658263106193, 0.9407977636895697]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.09653745999529093], {
             RGBColor[
             0.4006305146510648, 0.5214277483407643, 0.9467488000232798]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.09653745999529093], {
             RGBColor[
             0.8613872180832791, 0.8923108022391911, 0.9866410759018723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.09653745999529093], {
             RGBColor[
             0.7474672514108297, 0.802646364854438, 0.9754642082081764]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.09653745999529093], {
             RGBColor[
             0.26375786153494946`, 0.39455661406050563`, 0.938331992068402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.09653745999529093], {
             RGBColor[
             0.5967043758000397, 0.6834705193570902, 0.9613939007445802]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.09653745999529093], {
             RGBColor[
             0.2834883533526057, 0.41529461194629713`, 0.9394556143887707]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.09653745999529093], {
             RGBColor[
             0.8629461797913807, 0.8935538759883429, 0.9867897710612925]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.09653745999529093], {
             RGBColor[
             0.994929911462409, 0.9921714023414434, 0.733688018243811]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.09653745999529093], {
             RGBColor[
             0.2982759110728352, 0.4308372726955701, 0.9402977439247064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.09653745999529093], {
             RGBColor[
             0.4330212577841429, 0.5494829820365503, 0.94881270953371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.09653745999529093], {
             RGBColor[
             0.8501564223808016, 0.8833556705978637, 0.9855698725819203]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.09653745999529093], {
             RGBColor[
             0.5778982163356087, 0.668202831896036, 0.9599134109823082]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.09653745999529093], {
             RGBColor[
             0.9948597253511907, 0.991413797224713, 0.6818910104541577]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.09653745999529093], {
             RGBColor[
             0.8550850183392283, 0.42441316613006863`, 0.20038278181226205`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.09653745999529093], {
             RGBColor[
             0.9902592897026397, 0.9902399802142746, 0.8110923079848378]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.09653745999529093], {
             RGBColor[
             0.6567841061841853, 0.7318040025859531, 0.966425759774158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.09653745999529093], {
             RGBColor[
             0.49009667116956485`, 0.5969215821157074, 0.9530013517191798]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.09653745999529093], {
             RGBColor[
             0.24691183153546453`, 0.37685036843105446`, 0.9373726355813994]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.09653745999529093], {
             RGBColor[
             0.9251365455850682, 0.9431427855597206, 0.9927215436686894]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.09653745999529093], {
             RGBColor[
             0.40894719030375565`, 0.5286312347828527, 0.9472787312417218]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.09653745999529093], {
             RGBColor[
             0.904106666406614, 0.9263741307436846, 0.9907156950190537]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.09653745999529093], {
             RGBColor[
             0.3247955170555343, 0.45574328500132155`, 0.9419166610347479]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.09653745999529093], {
             RGBColor[
             0.7475668997528008, 0.8027242108965412, 0.9754741402236373]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.09653745999529093], {
             RGBColor[
             0.9914365253021733, 0.9907267973882568, 0.7915824675124948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.09653745999529093], {
             RGBColor[
             0.29612235881442805`, 0.42857375272888465`, 0.9401751023094853]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.09653745999529093], {
             RGBColor[
             0.6087564419527599, 0.6932549295992614, 0.9623426835402953]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.09653745999529093], {
             RGBColor[
             0.7459142102227551, 0.8014331172747639, 0.9753094155765442]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.09653745999529093], {
             RGBColor[
             0.4779433356641748, 0.5870549568509066, 0.9520445966290606]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.09653745999529093], {
             RGBColor[
             0.5315922686821296, 0.6306095775317725, 0.956268037158751]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.09653745999529093], {
             RGBColor[
             0.2978336347177741, 0.4303724122044603, 0.940272556940575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.09653745999529093], {
             RGBColor[
             0.6581303056303421, 0.7328556638247856, 0.9665599363540018]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.09653745999529093], {
             RGBColor[
             0.65190432660009, 0.7279918816871594, 0.9659393889493483]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.09653745999529093], {
             RGBColor[
             0.8194535076515501, 0.8588825753454996, 0.9826391254804394]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.09653745999529093], {
             RGBColor[
             0.5161699428852814, 0.6180890386820315, 0.9550539351781823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.09653745999529093], {
             RGBColor[
             0.4177609359619727, 0.5362652582802631, 0.9478403353213741]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.09653745999529093], {
             RGBColor[
             0.6591038347430441, 0.7336161921667237, 0.9666569686378091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.09653745999529093], {
             RGBColor[
             0.496408796501871, 0.6020460498184793, 0.9534982653474159]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.09653745999529093], {
             RGBColor[
             0.4599206418447562, 0.5724233220951985, 0.9506257841522933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.09653745999529093], {
             RGBColor[
             0.3044276976989958, 0.437303190485465, 0.9406480790723136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.09653745999529093], {
             RGBColor[
             0.6289653153620326, 0.7096614034322812, 0.9639336000826157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.09653745999529093], {
             RGBColor[
             0.18098663252906216`, 0.3075588043762891, 0.9336182930255769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.09653745999529093], {
             RGBColor[
             0.7244600514589714, 0.7846729653908503, 0.9731710655314828]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.09653745999529093], {
             RGBColor[
             0.7209788107613759, 0.7819533936994795, 0.9728240879927904]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.09653745999529093], {
             RGBColor[
             0.2522747781497172, 0.38248716535308863`, 0.9376780474573125]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.09653745999529093], {
             RGBColor[
             0.3678197100592384, 0.4930086785223134, 0.9446581245681439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.09653745999529093], {
             RGBColor[
             0.5744067073597608, 0.6653682676187559, 0.9596385466059106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.09653745999529093], {
             RGBColor[
             0.5443399595344443, 0.6409587272426099, 0.9572715820789754]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.09653745999529093], {
             RGBColor[
             0.7681984761509693, 0.8188417551845787, 0.9775305029459634]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.09653745999529093], {
             RGBColor[
             0.3251889691417232, 0.4560840734229015, 0.9419417314537639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.09653745999529093], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.09653745999529093], {
             RGBColor[
             0.40146717585702507`, 0.5221524222255522, 0.9468021113354932]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.09653745999529093], {
             RGBColor[
             0.4326695645768582, 0.5491783630570148, 0.9487902999535319]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.09653745999529093], {
             RGBColor[
             0.4976781173922648, 0.6030765416995555, 0.9535981909375832]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.09653745999529093], {
             RGBColor[
             0.5283740472261834, 0.6279968803746109, 0.9560146869770053]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.09653745999529093], {
             RGBColor[
             0.2565522751385097, 0.3869830858972829, 0.9379216445828346]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.09653745999529093], {
             RGBColor[
             0.629541724221574, 0.7101293581113801, 0.9639789770994941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.09653745999529093], {
             RGBColor[
             0.5005686980303874, 0.6054232452807571, 0.953825748033962]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.09653745999529093], {
             RGBColor[
             0.9271915719190686, 0.9447814077762487, 0.99291755391497]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.09653745999529093], {
             RGBColor[
             0.5933758588890591, 0.6807682793807781, 0.9611318677005886]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.09653745999529093], {
             RGBColor[
             0.7356700443989307, 0.7934302970746484, 0.9742883728643978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.09653745999529093], {
             RGBColor[
             0.3256596750427972, 0.45649177521604534`, 0.9419717244175515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.09653745999529093], {
             RGBColor[
             0.8499459656532837, 0.8831878581160366, 0.9855497990313727]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.09653745999529093], {
             RGBColor[
             0.612519599079081, 0.6963100300827054, 0.962638933054178]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.09653745999529093], {
             RGBColor[
             0.3103065900446014, 0.4431937046590974, 0.9409934394176664]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.09653745999529093], {
             RGBColor[
             0.9708046954741643, 0.9131795238301732, 0.3410821842981139]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.09653745999529093], {
             RGBColor[
             0.8116150069455315, 0.852759079019146, 0.9818578569850173]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.09653745999529093], {
             RGBColor[
             0.6881300986497063, 0.7562917301383845, 0.9695500353581669]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.09653745999529093], {
             RGBColor[
             0.9574180001213686, 0.868023057059651, 0.2890774007177994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.09653745999529093], {
             RGBColor[
             0.7836305484408749, 0.8308974073455464, 0.9790686276909064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.09653745999529093], {
             RGBColor[
             0.8464106235314965, 0.880368872272429, 0.9852125949437595]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.09653745999529093], {
             RGBColor[
             0.5836188160977119, 0.6728470724929938, 0.9603637575508284]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.09653745999529093], {
             RGBColor[
             0.5635485176315126, 0.656553100041491, 0.9587837501356434]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.09653745999529093], {
             RGBColor[
             0.7143582312918778, 0.7767813466996399, 0.9721642105041036]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.09653745999529093], {
             RGBColor[
             0.4006305146510648, 0.5214277483407643, 0.9467488000232798]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.09653745999529093], {
             RGBColor[
             0.21243266507390485`, 0.3406105783745381, 0.9354090980587694]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.09653745999529093], {
             RGBColor[
             0.2299872213457267, 0.3590615300393757, 0.9364088040688109]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.09653745999529093], {
             RGBColor[
             0.5587655340520823, 0.6526700585007547, 0.9584072161476245]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.09653745999529093], {
             RGBColor[
             0.26813178294749573`, 0.39915388278772673`, 0.9385810804222097]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.09653745999529093], {
             RGBColor[
             0.3037238298505496, 0.43656338074894885`, 0.9406079948396238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.09653745999529093], {
             RGBColor[
             0.30715647577785, 0.4401713092608638, 0.940803478947039]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.09653745999529093], {
             RGBColor[
             0.8895365549612745, 0.9147563193723102, 0.9893259847825051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.09653745999529093], {
             RGBColor[
             0.6506720767406403, 0.7270292387315116, 0.965816569799388]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.09653745999529093], {
             RGBColor[
             0.8922131280830662, 0.916890546125985, 0.9895812787162667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.09653745999529093], {
             RGBColor[
             0.8651125006659675, 0.8952812414505249, 0.9869963966802081]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.09653745999529093], {
             RGBColor[
             0.6636159542669856, 0.7371410942322052, 0.9671066945438013]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.09653745999529093], {
             RGBColor[
             0.8951285839785095, 0.9192152515190694, 0.9898593575022323]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.09653745999529093], {
             RGBColor[
             0.6792374153202093, 0.7493446983344849, 0.9686636957907332]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.09653745999529093], {
             RGBColor[
             0.659366600239572, 0.733821466569703, 0.9666831586468199]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.09653745999529093], {
             RGBColor[
             0.4599206418447562, 0.5724233220951985, 0.9506257841522933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.09653745999529093], {
             RGBColor[
             0.5439579923257903, 0.640648629055198, 0.9572415122211182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.09653745999529093], {
             RGBColor[
             0.3074920613089446, 0.44052403093139575`, 0.9408225900465804]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN2wucz2W+wPHn16rdrWxoc2ntsSnFoptQYTEuNY3rMEhyNxmZGTMj4zII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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[105, 155] -> 
             RGBColor[
              0.3609448647521152, 0.4866656792120809, 0.9442342850410239], 
             UndirectedEdge[1, 203] -> 
             RGBColor[
              0.32569030455946724`, 0.45491432460487713`, 0.9420324056815049],
              UndirectedEdge[187, 193] -> 
             RGBColor[
              0.8331367258093362, 0.8697846265391334, 0.9839465187292714], 
             UndirectedEdge[209, 371] -> 
             RGBColor[
              0.26203929742842424`, 0.3927502942212898, 0.9382341223849231], 
             UndirectedEdge[23, 245] -> 
             RGBColor[
              0.22165838805798918`, 0.35030739817543277`, 0.9359344893344789],
              UndirectedEdge[201, 236] -> 
             RGBColor[
              0.26347424346046877`, 0.3942585134818019, 0.9383158404386357], 
             UndirectedEdge[258, 369] -> 
             RGBColor[
              0.2551936052438994, 0.3855550376934007, 0.9378442703423086], 
             UndirectedEdge[161, 312] -> 
             RGBColor[
              0.44719691052756494`, 0.5614994937585587, 0.949788285319064], 
             UndirectedEdge[74, 132] -> 
             RGBColor[
              0.8119479189165777, 0.8530570556731545, 0.981880980170774], 
             UndirectedEdge[89, 169] -> 
             RGBColor[
              0.2196406470513075, 0.3481866244452415, 0.9358195819691286], 
             UndirectedEdge[124, 137] -> 
             RGBColor[
              0.22241368079166546`, 0.3511012587268517, 0.9359775021383063], 
             UndirectedEdge[186, 393] -> 
             RGBColor[
              0.23564383540018752`, 0.36500699006065973`, 0.9367309398710019],
              UndirectedEdge[84, 261] -> 
             RGBColor[
              0.17918769193352976`, 0.30566800375096304`, 0.9335158460199553],
              UndirectedEdge[58, 243] -> 
             RGBColor[
              0.2935914724788655, 0.42591363072274663`, 0.9400309720767858], 
             UndirectedEdge[205, 250] -> 
             RGBColor[
              0.9917478646376758, 0.990855544204543, 0.7864227690028461], 
             UndirectedEdge[327, 337] -> 
             RGBColor[
              0.3016677329619616, 0.43349195021963505`, 0.9405242352558603], 
             UndirectedEdge[38, 224] -> 
             RGBColor[
              0.970726359968221, 0.9129152797745752, 0.34077786564994345`], 
             UndirectedEdge[49, 301] -> 
             RGBColor[
              0.2562771522862687, 0.3866939143357813, 0.9379059767434073], 
             UndirectedEdge[22, 97] -> 
             RGBColor[
              0.36730142212889694`, 0.4910409193978484, 0.9446807120447999], 
             UndirectedEdge[163, 169] -> 
             RGBColor[
              0.23283585906700827`, 0.36205562889850595`, 0.936571029772856], 
             UndirectedEdge[126, 318] -> 
             RGBColor[
              0.2179296081019373, 0.3463882140233181, 0.9357221408322174], 
             UndirectedEdge[126, 149] -> 
             RGBColor[
              0.21613019133913786`, 0.3444969129160037, 0.9356196667095744], 
             UndirectedEdge[28, 47] -> 
             RGBColor[
              0.3610905157265072, 0.4852888096589335, 0.9442985989042187], 
             UndirectedEdge[203, 392] -> 
             RGBColor[
              0.26967339396164935`, 0.4007742137073859, 0.9386688728888566], 
             UndirectedEdge[116, 387] -> 
             RGBColor[
              0.35489504602512995`, 0.4804107437728069, 0.9438859559088182], 
             UndirectedEdge[114, 203] -> 
             RGBColor[
              0.3101377282501396, 0.4414434647009515, 0.9410414092716778], 
             UndirectedEdge[38, 207] -> 
             RGBColor[
              0.9528235149386215, 0.8477616286807421, 0.29603526485507003`], 
             UndirectedEdge[4, 73] -> 
             RGBColor[
              0.23765623707057423`, 0.3671221518098715, 0.9368455431690489], 
             UndirectedEdge[143, 223] -> 
             RGBColor[
              0.5393557196395969, 0.6369122967585245, 0.9568792044565808], 
             UndirectedEdge[70, 164] -> 
             RGBColor[
              0.26017432145076, 0.3907900862224582, 0.9381279147619799], 
             UndirectedEdge[291, 331] -> 
             RGBColor[
              0.5742920250264498, 0.6644126452364563, 0.9602056699966387], 
             UndirectedEdge[317, 381] -> 
             RGBColor[
              0.99188704610358, 0.9909130993174948, 0.7841161719227241], 
             UndirectedEdge[120, 349] -> 
             RGBColor[
              0.5058787275831391, 0.6095186078416714, 0.9543033325072602], 
             UndirectedEdge[102, 160] -> 
             RGBColor[
              0.8226905508662201, 0.17541509378636602`, 0.16936180317579133`],
              UndirectedEdge[84, 381] -> 
             RGBColor[
              0.5860370216699882, 0.6484140748343261, 0.8483679973313716], 
             UndirectedEdge[110, 203] -> 
             RGBColor[
              0.2734877597794271, 0.40478335402663146`, 0.9388860953793305], 
             UndirectedEdge[316, 355] -> 
             RGBColor[
              0.2426003366300466, 0.37231871392089444`, 0.937127102324821], 
             UndirectedEdge[62, 77] -> 
             RGBColor[
              0.5042166815429454, 0.5861598549701907, 0.9585479112851663], 
             UndirectedEdge[188, 361] -> 
             RGBColor[
              0.3113562197109362, 0.44025108193646334`, 0.9412013526638779], 
             UndirectedEdge[168, 282] -> 
             RGBColor[
              0.6585061316418895, 0.73314926196139, 0.9665973951785392], 
             UndirectedEdge[271, 394] -> 
             RGBColor[
              0.3328279171819992, 0.4625195049765876, 0.9424351072766638], 
             UndirectedEdge[160, 224] -> 
             RGBColor[
              0.8782055573021286, 0.46157635638612377`, 0.23722404279685397`],
              UndirectedEdge[97, 168] -> 
             RGBColor[
              0.5562174687857758, 0.6498761073301125, 0.9585804738963757], 
             UndirectedEdge[88, 132] -> 
             RGBColor[
              0.8947680641910523, 0.9166701790551881, 0.8954060764061295], 
             UndirectedEdge[329, 353] -> 
             RGBColor[
              0.22275923690238936`, 0.35146446010874544`, 0.9359971810476075],
              UndirectedEdge[189, 339] -> 
             RGBColor[
              0.333153622737486, 0.4622245787566195, 0.942476989061352], 
             UndirectedEdge[316, 380] -> 
             RGBColor[
              0.25988508585516024`, 0.3904860812728869, 0.9381114432226962], 
             UndirectedEdge[156, 295] -> 
             RGBColor[
              0.2141734445733891, 0.3424402480002911, 0.9355082328760125], 
             UndirectedEdge[154, 228] -> 
             RGBColor[
              0.39900760332101687`, 0.520022064116572, 0.9466453895484133], 
             UndirectedEdge[29, 91] -> 
             RGBColor[
              0.25152521102249714`, 0.3816993227770795, 0.9376353607183026], 
             UndirectedEdge[6, 198] -> 
             RGBColor[
              0.9099185860419527, 0.9263319020393368, 0.75030590143584], 
             UndirectedEdge[56, 254] -> 
             RGBColor[
              0.46022321075082034`, 0.5726042579779009, 0.9506674811679487], 
             UndirectedEdge[245, 315] -> 
             RGBColor[
              0.23658653725822024`, 0.3659978294842021, 0.9367846253472143], 
             UndirectedEdge[174, 281] -> 
             RGBColor[
              0.6802997161269625, 0.7500157979571946, 0.9688781332846546], 
             UndirectedEdge[89, 329] -> 
             RGBColor[
              0.22686082544463082`, 0.3557754897223749, 0.9362307604473317], 
             UndirectedEdge[260, 267] -> 
             RGBColor[
              0.6900764896095811, 0.7567221842679797, 0.9704893279445472], 
             UndirectedEdge[202, 363] -> 
             RGBColor[
              0.8583972484613908, 0.44556547598681506`, 0.20338592805907718`],
              UndirectedEdge[43, 238] -> 
             RGBColor[
              0.22832917766795519`, 0.3573188210079969, 0.9363143809342176], 
             UndirectedEdge[276, 377] -> 
             RGBColor[
              0.590222766132432, 0.6752773818608311, 0.9624624311800029], 
             UndirectedEdge[284, 369] -> 
             RGBColor[
              0.25072601947789425`, 0.3808593217920313, 0.9375898479421354], 
             UndirectedEdge[53, 249] -> 
             RGBColor[
              0.279406621010689, 0.4110044524581648, 0.9392231657702803], 
             UndirectedEdge[15, 105] -> 
             RGBColor[
              0.36060251301143975`, 0.486305845826277, 0.9442147886158565], 
             UndirectedEdge[97, 112] -> 
             RGBColor[
              0.38560280932821134`, 0.5084115053045399, 0.9457912479285857], 
             UndirectedEdge[120, 246] -> 
             RGBColor[
              0.505090585435528, 0.6088359587265868, 0.9542531127865411], 
             UndirectedEdge[53, 308] -> 
             RGBColor[
              0.27516616979901054`, 0.4065474693745552, 0.9389816783469607], 
             UndirectedEdge[188, 392] -> 
             RGBColor[
              0.25751756533120074`, 0.38799766709273437`, 0.9379766164312895],
              UndirectedEdge[91, 273] -> 
             RGBColor[
              0.26902930475390907`, 0.40009723511243644`, 0.9386321929613204],
              UndirectedEdge[327, 354] -> 
             RGBColor[
              0.2991827847858058, 0.430880112131681, 0.9403827211333795], 
             UndirectedEdge[51, 376] -> 
             RGBColor[
              0.405658343586251, 0.5257826010583926, 0.9470691688370954], 
             UndirectedEdge[202, 214] -> 
             RGBColor[
              0.8988174484699203, 0.6185106129520341, 0.43850682995064416`], 
             UndirectedEdge[69, 132] -> 
             RGBColor[
              0.6437204915353074, 0.7192373735289359, 0.9667380893382732], 
             UndirectedEdge[130, 387] -> 
             RGBColor[
              0.35198717062244894`, 0.47789208825307206`, 0.9437006686594926],
              UndirectedEdge[61, 306] -> 
             RGBColor[
              0.9818610097196364, 0.9499548547858537, 0.42826904779571534`], 
             UndirectedEdge[312, 356] -> 
             RGBColor[
              0.4906677898927829, 0.5973852420238213, 0.9530463122771483], 
             UndirectedEdge[18, 247] -> 
             RGBColor[
              0.926107052730001, 0.8138393200274576, 0.6108347292188259], 
             UndirectedEdge[56, 320] -> 
             RGBColor[
              0.5804145257698448, 0.6691464316920486, 0.9608367095033534], 
             UndirectedEdge[43, 124] -> 
             RGBColor[
              0.22535325774935577`, 0.3541909404893282, 0.9361449066973324], 
             UndirectedEdge[259, 318] -> 
             RGBColor[
              0.2174190793227137, 0.34585161590696, 0.9356930669735002], 
             UndirectedEdge[267, 384] -> 
             RGBColor[
              0.6598133920654725, 0.7330804224584619, 0.9674729852060762], 
             UndirectedEdge[44, 324] -> 
             RGBColor[
              0.2889570987994522, 0.4210426101494208, 0.9397670513516847], 
             UndirectedEdge[62, 204] -> 
             RGBColor[
              0.17899762953989296`, 0.30546823612459895`, 0.9335050222478098],
              UndirectedEdge[42, 109] -> 
             RGBColor[
              0.9631611562508396, 0.9703111795583055, 0.8704491819362283], 
             UndirectedEdge[8, 21] -> 
             RGBColor[
              0.3116185481608299, 0.44433005683844234`, 0.9410770362287135], 
             UndirectedEdge[48, 349] -> 
             RGBColor[
              0.43541101780241814`, 0.5515528720515495, 0.9489649829288928], 
             UndirectedEdge[222, 332] -> 
             RGBColor[
              0.5660742539559687, 0.6586036065728093, 0.9589825853511816], 
             UndirectedEdge[58, 167] -> 
             RGBColor[
              0.2911802301180382, 0.4233792621199214, 0.9398936553914501], 
             UndirectedEdge[76, 144] -> 
             RGBColor[
              0.8574423259589508, 0.4215266069305636, 0.20181760551077696`], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.44236640792617826`, 0.5377470693075241, 0.9524063925246276], 
             UndirectedEdge[6, 166] -> 
             RGBColor[
              0.8809619169447186, 0.4569876396612623, 0.28666791534630426`], 
             UndirectedEdge[79, 343] -> 
             RGBColor[
              0.6565032648608529, 0.7307948803461315, 0.9669377087053699], 
             UndirectedEdge[142, 257] -> 
             RGBColor[
              0.8219250388987569, 0.16953103335496109`, 0.16862874805122652`],
              UndirectedEdge[175, 256] -> 
             RGBColor[
              0.20212025348377827`, 0.329771579948656, 0.9348218214745575], 
             UndirectedEdge[8, 171] -> 
             RGBColor[
              0.2917662705538139, 0.42384970493064567`, 0.9399323578314926], 
             UndirectedEdge[31, 214] -> 
             RGBColor[
              0.5834952534993698, 0.6486610383850888, 0.9230487158880236], 
             UndirectedEdge[41, 114] -> 
             RGBColor[
              0.3348490984330268, 0.46445119188281303`, 0.9425572663500889], 
             UndirectedEdge[72, 399] -> 
             RGBColor[
              0.23130276285488832`, 0.3604442475756538, 0.9364837222115884], 
             UndirectedEdge[278, 392] -> 
             RGBColor[
              0.2501824179205401, 0.3802879620889227, 0.9375588906376304], 
             UndirectedEdge[6, 323] -> 
             RGBColor[
              0.9117788938600264, 0.9278152609967583, 0.7504833392562442], 
             UndirectedEdge[132, 323] -> 
             RGBColor[
              0.8147163030891271, 0.8552644900665589, 0.9821450311245175], 
             UndirectedEdge[200, 355] -> 
             RGBColor[
              0.2507904105311417, 0.380927000871623, 0.9375935149173598], 
             UndirectedEdge[98, 215] -> 
             RGBColor[
              0.8720488320627787, 0.4115090172033815, 0.2331906407405301], 
             UndirectedEdge[12, 367] -> 
             RGBColor[
              0.21887583976336028`, 0.3473827634940262, 0.9357760273255111], 
             UndirectedEdge[88, 140] -> 
             RGBColor[
              0.8311193811821351, 0.8669473441407145, 0.8890621705145608], 
             UndirectedEdge[195, 327] -> 
             RGBColor[
              0.2821434199050674, 0.41297065928389304`, 0.9394123545109028], 
             UndirectedEdge[142, 381] -> 
             RGBColor[
              0.8787716586784301, 0.4417510150187816, 0.3666130935731935], 
             UndirectedEdge[313, 359] -> 
             RGBColor[
              0.2641882368664749, 0.39500896582131095`, 0.9383565013068491], 
             UndirectedEdge[64, 82] -> 
             RGBColor[
              0.38908871359710695`, 0.5114308203756144, 0.9460133666661356], 
             UndirectedEdge[98, 297] -> 
             RGBColor[
              0.9621045612745434, 0.9478624391979251, 0.6712874553374975], 
             UndirectedEdge[139, 305] -> 
             RGBColor[
              0.20703664012749182`, 0.3349390140281161, 0.9351018024207747], 
             UndirectedEdge[288, 375] -> 
             RGBColor[
              0.24993566591258726`, 0.38002861008358335`, 0.9375448384758145],
              UndirectedEdge[136, 194] -> 
             RGBColor[
              0.5033185862068833, 0.6058836865205527, 0.954531849750919], 
             UndirectedEdge[254, 349] -> 
             RGBColor[
              0.45744526540329744`, 0.5701981413414695, 0.9504904729468453], 
             UndirectedEdge[348, 351] -> 
             RGBColor[
              0.2543498568494185, 0.38466820463406326`, 0.9377962201194567], 
             UndirectedEdge[65, 282] -> 
             RGBColor[
              0.5810969797016021, 0.6707307553552915, 0.9602123891284602], 
             UndirectedEdge[131, 215] -> 
             RGBColor[
              0.8536808578489179, 0.34294583045453636`, 0.1962266941808688], 
             UndirectedEdge[230, 250] -> 
             RGBColor[
              0.9785422248709081, 0.9480049704007043, 0.5891428358439234], 
             UndirectedEdge[26, 111] -> 
             RGBColor[
              0.6645955027358419, 0.5448101324102603, 0.5834436797495368], 
             UndirectedEdge[301, 390] -> 
             RGBColor[
              0.26155859013835736`, 0.392245040380827, 0.9382067468158966], 
             UndirectedEdge[3, 309] -> 
             RGBColor[
              0.32043505349243634`, 0.4484572206151509, 0.9417673069857059], 
             UndirectedEdge[90, 268] -> 
             RGBColor[
              0.7801479338525283, 0.346118041196779, 0.4332492614117297], 
             UndirectedEdge[17, 187] -> 
             RGBColor[
              0.6897252223294911, 0.7560947412907055, 0.9707766661911668], 
             UndirectedEdge[4, 206] -> 
             RGBColor[
              0.23187928370438585`, 0.3610502075420088, 0.9365165542210812], 
             UndirectedEdge[19, 231] -> 
             RGBColor[
              0.2915341164557601, 0.4237512190985569, 0.9399138086948555], 
             UndirectedEdge[76, 138] -> 
             RGBColor[
              0.8377439161121089, 0.2911218554929793, 0.18377692273559879`], 
             UndirectedEdge[28, 390] -> 
             RGBColor[
              0.2772941937947283, 0.40878415751856884`, 0.9391028661653874], 
             UndirectedEdge[123, 174] -> 
             RGBColor[
              0.8514507591880022, 0.8841310051490996, 0.9509891763922267], 
             UndirectedEdge[2, 98] -> 
             RGBColor[
              0.8714908303389601, 0.407219971436197, 0.23265629765962853`], 
             UndirectedEdge[20, 364] -> 
             RGBColor[
              0.37859437323609996`, 0.5023411502157933, 0.945344676578113], 
             UndirectedEdge[56, 196] -> 
             RGBColor[
              0.3744295737159023, 0.4977332530910004, 0.9451159345325955], 
             UndirectedEdge[360, 374] -> 
             RGBColor[
              0.293247724709362, 0.42540017170025574`, 0.9400169674113716], 
             UndirectedEdge[39, 360] -> 
             RGBColor[
              0.29174189371093673`, 0.42381744784571107`, 0.9399312125636886],
              UndirectedEdge[261, 264] -> 
             RGBColor[
              0.1847396920189574, 0.3115035078578844, 0.9338320242113725], 
             UndirectedEdge[101, 253] -> 
             RGBColor[
              0.3012788054166666, 0.43094522374745403`, 0.9405803668258977], 
             UndirectedEdge[141, 273] -> 
             RGBColor[
              0.31775067217972763`, 0.44656178652298995`, 0.9415805292809634],
              UndirectedEdge[171, 182] -> 
             RGBColor[
              0.2806534492526592, 0.41231494799395196`, 0.9392941707941435], 
             UndirectedEdge[156, 175] -> 
             RGBColor[
              0.18244584031582461`, 0.30909252427929373`, 0.9337013927503286],
              UndirectedEdge[121, 250] -> 
             RGBColor[
              0.7707116790518824, 0.8187741201767487, 0.9013688926659322], 
             UndirectedEdge[68, 308] -> 
             RGBColor[
              0.26890650081077455`, 0.39996816038198235`, 0.938625199458431], 
             UndirectedEdge[39, 390] -> 
             RGBColor[
              0.26969566944831447`, 0.40079762665621843`, 0.9386701414448686],
              UndirectedEdge[54, 181] -> 
             RGBColor[
              0.5096518890083631, 0.6127613709392468, 0.9545507619731439], 
             UndirectedEdge[196, 313] -> 
             RGBColor[
              0.2903662346350581, 0.4225237012570149, 0.9398472995528928], 
             UndirectedEdge[200, 241] -> 
             RGBColor[
              0.2808108014657587, 0.41248033514662596`, 0.9393031317698977], 
             UndirectedEdge[186, 255] -> 
             RGBColor[
              0.2544713249858168, 0.38479587534694254`, 0.9378031375501286], 
             UndirectedEdge[11, 38] -> 
             RGBColor[
              0.9446269367354516, 0.8152649274529434, 0.2894401056343812], 
             UndirectedEdge[173, 310] -> 
             RGBColor[
              0.20447288081658893`, 0.33224434044062834`, 0.9349558001207607],
              UndirectedEdge[106, 173] -> 
             RGBColor[
              0.5874312139478495, 0.658182594689114, 0.9541358462016971], 
             UndirectedEdge[51, 396] -> 
             RGBColor[
              0.3256114518738936, 0.4536350211799036, 0.9420717220904409], 
             UndirectedEdge[6, 18] -> 
             RGBColor[
              0.9692770544063248, 0.9734175595259907, 0.7474672305772001], 
             UndirectedEdge[238, 287] -> 
             RGBColor[
              0.24471825055354252`, 0.3745447757379873, 0.9372477143895912], 
             UndirectedEdge[93, 225] -> 
             RGBColor[
              0.25117310830966183`, 0.38132924050128825`, 0.9376153089896959],
              UndirectedEdge[116, 276] -> 
             RGBColor[
              0.5908937430052579, 0.6758585483037947, 0.9625051852330178], 
             UndirectedEdge[135, 276] -> 
             RGBColor[
              0.6344220971523353, 0.7122040883931675, 0.9656535874330512], 
             UndirectedEdge[147, 172] -> 
             RGBColor[
              0.29308124725627194`, 0.4253773516636531, 0.9400019155051696], 
             UndirectedEdge[185, 224] -> 
             RGBColor[
              0.8743474919137393, 0.4319215751959308, 0.2335295550238708], 
             UndirectedEdge[160, 166] -> 
             RGBColor[
              0.8279080891724726, 0.21551937954808684`, 0.17435812375022539`],
              UndirectedEdge[63, 156] -> 
             RGBColor[
              0.5722602959769347, 0.592332243346744, 0.6137097186204522], 
             UndirectedEdge[247, 302] -> 
             RGBColor[
              0.9471422868502191, 0.8188837514344283, 0.3245541983516868], 
             UndirectedEdge[81, 240] -> 
             RGBColor[
              0.22946097871463872`, 0.3585084156683923, 0.9363788353294766], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.3163910437219365, 0.4480120932607672, 0.9413976728873965], 
             UndirectedEdge[12, 212] -> 
             RGBColor[
              0.2146670795751315, 0.34295908968538924`, 0.9355363446590942], 
             UndirectedEdge[18, 74] -> 
             RGBColor[
              0.8849400211257357, 0.9108459941170431, 0.9803872287207334], 
             UndirectedEdge[1, 7] -> 
             RGBColor[
              0.37469401379728373`, 0.4989628549076562, 0.945096149123624], 
             UndirectedEdge[231, 331] -> 
             RGBColor[
              0.38038829696430865`, 0.5038892359163952, 0.9454591932807552], 
             UndirectedEdge[58, 351] -> 
             RGBColor[
              0.27227774194596055`, 0.4035115485640963, 0.9388171866537756], 
             UndirectedEdge[142, 279] -> 
             RGBColor[
              0.8629391956473363, 0.38534829151509464`, 0.20391030509684882`],
              UndirectedEdge[303, 344] -> 
             RGBColor[
              0.3051201948561256, 0.4369324167818024, 0.9407277420647475], 
             UndirectedEdge[302, 323] -> 
             RGBColor[
              0.9087436394185031, 0.9180978599174181, 0.6943707488073377], 
             UndirectedEdge[144, 366] -> 
             RGBColor[
              0.8898592758254438, 0.5927585201905767, 0.22980821876360358`], 
             UndirectedEdge[56, 342] -> 
             RGBColor[
              0.5271466154555224, 0.626935692782203, 0.9559359367348119], 
             UndirectedEdge[137, 293] -> 
             RGBColor[
              0.2163935789679292, 0.34477375001360355`, 0.9356346662453872], 
             UndirectedEdge[39, 374] -> 
             RGBColor[
              0.2745978955714905, 0.40595017713076464`, 0.9389493159703898], 
             UndirectedEdge[4, 278] -> 
             RGBColor[
              0.24230606056995913`, 0.37200941112356267`, 0.9371103437385414],
              UndirectedEdge[238, 396] -> 
             RGBColor[
              0.25376131131834845`, 0.3840496059649667, 0.9377627033221374], 
             UndirectedEdge[118, 293] -> 
             RGBColor[
              0.20864634306607288`, 0.33663091387762584`, 0.9351934726217848],
              UndirectedEdge[201, 228] -> 
             RGBColor[
              0.3221417320475673, 0.45045653149250003`, 0.9418569760468667], 
             UndirectedEdge[212, 336] -> 
             RGBColor[
              0.21095186783418274`, 0.3390541665876225, 0.9353247688466104], 
             UndirectedEdge[186, 200] -> 
             RGBColor[
              0.2595636633022175, 0.3901482457903771, 0.9380931386838082], 
             UndirectedEdge[7, 356] -> 
             RGBColor[
              0.4538916995859768, 0.5657933672154302, 0.9506306565950378], 
             UndirectedEdge[215, 269] -> 
             RGBColor[
              0.8772117743486348, 0.4286960994750255, 0.27269761678998694`], 
             UndirectedEdge[36, 122] -> 
             RGBColor[
              0.4828824410191481, 0.5908684223901826, 0.952487665639901], 
             UndirectedEdge[297, 352] -> 
             RGBColor[
              0.970396577990795, 0.974814330666099, 0.7901511578367646], 
             UndirectedEdge[228, 243] -> 
             RGBColor[
              0.3281145647549416, 0.45673435736741674`, 0.9421971200335375], 
             UndirectedEdge[100, 271] -> 
             RGBColor[
              0.3417009842764249, 0.4702049097204598, 0.9430004912657755], 
             UndirectedEdge[157, 298] -> 
             RGBColor[
              0.6463369873520685, 0.7210185843298552, 0.9671902179184984], 
             UndirectedEdge[272, 384] -> 
             RGBColor[
              0.6977223834801167, 0.763785295951966, 0.9705061046650639], 
             UndirectedEdge[35, 114] -> 
             RGBColor[
              0.30495946572485455`, 0.43600078246607, 0.9407465148814157], 
             UndirectedEdge[15, 155] -> 
             RGBColor[
              0.30420326810120896`, 0.4370673007485326, 0.9406352981387334], 
             UndirectedEdge[36, 262] -> 
             RGBColor[
              0.7291600782306236, 0.787348496129779, 0.9720379295278863], 
             UndirectedEdge[111, 185] -> 
             RGBColor[
              0.840486373071854, 0.29576738444586437`, 0.18575958067824674`], 
             UndirectedEdge[26, 400] -> 
             RGBColor[
              0.4223618806328297, 0.5402016308185901, 0.9481469689308566], 
             UndirectedEdge[61, 131] -> 
             RGBColor[
              0.9579060415796807, 0.8592435772757068, 0.3867967672286041], 
             UndirectedEdge[168, 350] -> 
             RGBColor[
              0.5514466203488134, 0.6457438382038303, 0.9582764796526682], 
             UndirectedEdge[16, 208] -> 
             RGBColor[
              0.2374736143413805, 0.36693020374253915`, 0.9368351430747874], 
             UndirectedEdge[125, 303] -> 
             RGBColor[
              0.28379884955745593`, 0.41562096314419106`, 0.9394732966882988],
              UndirectedEdge[145, 164] -> 
             RGBColor[
              0.2402812832877892, 0.36988124182170756`, 0.9369950356677115], 
             UndirectedEdge[152, 256] -> 
             RGBColor[
              0.2044622657846265, 0.33223318336900387`, 0.9349551956103941], 
             UndirectedEdge[237, 246] -> 
             RGBColor[
              0.5111109439056949, 0.6137235569467266, 0.9547270574586124], 
             UndirectedEdge[16, 284] -> 
             RGBColor[
              0.24292930031788273`, 0.3726644756143127, 0.9371458363201851], 
             UndirectedEdge[240, 309] -> 
             RGBColor[
              0.2549984797573888, 0.3853499484354077, 0.9378331582345141], 
             UndirectedEdge[151, 249] -> 
             RGBColor[
              0.2927023996318287, 0.42432368443317114`, 0.9400043408205379], 
             UndirectedEdge[47, 311] -> 
             RGBColor[
              0.47663297852550124`, 0.5854636862286419, 0.9520871802976505], 
             UndirectedEdge[29, 190] -> 
             RGBColor[
              0.2407660977459846, 0.370390812556283, 0.937022645133887], 
             UndirectedEdge[99, 384] -> 
             RGBColor[
              0.863277719993484, 0.893302482160574, 0.9487341980321153], 
             UndirectedEdge[5, 398] -> 
             RGBColor[
              0.8904342144946242, 0.9153759950567726, 0.9860799767962038], 
             UndirectedEdge[36, 157] -> 
             RGBColor[
              0.49446056893751156`, 0.6004643909150807, 0.9533448937369567], 
             UndirectedEdge[40, 55] -> 
             RGBColor[
              0.37142239221905604`, 0.496129140733077, 0.9448876842896408], 
             UndirectedEdge[163, 319] -> 
             RGBColor[
              0.2432784612852803, 0.3730314659291315, 0.9371657205207411], 
             UndirectedEdge[13, 74] -> 
             RGBColor[
              0.8942268027978797, 0.9177720606824189, 0.9646671297303714], 
             UndirectedEdge[47, 158] -> 
             RGBColor[
              0.468503909528975, 0.5788641418068768, 0.9514472302084831], 
             UndirectedEdge[252, 330] -> 
             RGBColor[
              0.2245525377985933, 0.3533493330524997, 0.9360993068806954], 
             UndirectedEdge[102, 185] -> 
             RGBColor[
              0.8207615181720255, 0.16058770319126955`, 0.16751455928929976`],
              UndirectedEdge[41, 356] -> 
             RGBColor[
              0.4295993605310475, 0.5447525640945126, 0.9490827702313296], 
             UndirectedEdge[33, 175] -> 
             RGBColor[
              0.17893676407552545`, 0.30540426266245535`, 0.9335015560496566],
              UndirectedEdge[12, 126] -> 
             RGBColor[
              0.2152393660615204, 0.3435605990676429, 0.935568935527872], 
             UndirectedEdge[18, 191] -> 
             RGBColor[
              0.8120299641162554, 0.853850200152278, 0.9731302939895274], 
             UndirectedEdge[64, 171] -> 
             RGBColor[
              0.3360864294513485, 0.46223759897173367`, 0.9427563991656658], 
             UndirectedEdge[73, 184] -> 
             RGBColor[
              0.230439447723778, 0.35953684863551605`, 0.9364345576920319], 
             UndirectedEdge[93, 316] -> 
             RGBColor[
              0.2497588091651779, 0.37984272242869066`, 0.9375347667456857], 
             UndirectedEdge[20, 362] -> 
             RGBColor[
              0.406159003588231, 0.5262162475882044, 0.9471010704497052], 
             UndirectedEdge[32, 330] -> 
             RGBColor[
              0.2205286799485376, 0.349120003324768, 0.935870154128899], 
             UndirectedEdge[124, 277] -> 
             RGBColor[
              0.24054204876353127`, 0.3701553228701986, 0.9370098858757869], 
             UndirectedEdge[267, 331] -> 
             RGBColor[
              0.511645707636986, 0.6143827846807824, 0.9547069650679356], 
             UndirectedEdge[134, 167] -> 
             RGBColor[
              0.25893816716997997`, 0.3894908096966502, 0.9380575176044159], 
             UndirectedEdge[143, 398] -> 
             RGBColor[
              0.7820348247548993, 0.8302487551810782, 0.97550730112162], 
             UndirectedEdge[109, 320] -> 
             RGBColor[
              0.8519952349988198, 0.8825603077930796, 0.8596099472355513], 
             UndirectedEdge[28, 147] -> 
             RGBColor[
              0.2865134731880893, 0.418474204697066, 0.9396278904881377], 
             UndirectedEdge[54, 311] -> 
             RGBColor[
              0.48568276233296276`, 0.5933021541073054, 0.9526638245194523], 
             UndirectedEdge[160, 289] -> 
             RGBColor[
              0.8522361572582982, 0.36125661754027083`, 0.19603911206005595`],
              UndirectedEdge[209, 240] -> 
             RGBColor[
              0.24561974977362988`, 0.37549230857665095`, 0.9372990534365266],
              UndirectedEdge[31, 261] -> 
             RGBColor[
              0.18133289143212553`, 0.3079227444374911, 0.9336380119578622], 
             UndirectedEdge[245, 248] -> 
             RGBColor[
              0.2230533686520324, 0.3517736112266503, 0.9360139314156208], 
             UndirectedEdge[81, 245] -> 
             RGBColor[
              0.22480714766170556`, 0.3536169441618284, 0.9361138065357382], 
             UndirectedEdge[308, 386] -> 
             RGBColor[
              0.30022575986843436`, 0.4300559235597101, 0.9405124330603728], 
             UndirectedEdge[320, 349] -> 
             RGBColor[
              0.5776365804223218, 0.666740315055617, 0.9606597012822499], 
             UndirectedEdge[222, 356] -> 
             RGBColor[
              0.5616526527416191, 0.6550139515161355, 0.9586345007067291], 
             UndirectedEdge[200, 374] -> 
             RGBColor[
              0.27338169058223005`, 0.4046718685752019, 0.9388800548954654], 
             UndirectedEdge[73, 348] -> 
             RGBColor[
              0.2530355996274438, 0.3832868369650472, 0.9377213751149346], 
             UndirectedEdge[23, 81] -> 
             RGBColor[
              0.2165666874460731, 0.34495569799984427`, 0.9356445245171263], 
             UndirectedEdge[25, 233] -> 
             RGBColor[
              0.8382934875111977, 0.29534610209009887`, 0.1843031929280184], 
             UndirectedEdge[168, 170] -> 
             RGBColor[
              0.5575600626847299, 0.651038994684655, 0.958666022792408], 
             UndirectedEdge[73, 284] -> 
             RGBColor[
              0.24355703331110456`, 0.3733242627907594, 0.9371815847855014], 
             UndirectedEdge[143, 234] -> 
             RGBColor[
              0.4816918202752083, 0.5869870677287701, 0.9531992911334777], 
             UndirectedEdge[288, 374] -> 
             RGBColor[
              0.26056485892169184`, 0.3912005658659134, 0.9381501552932011], 
             UndirectedEdge[254, 344] -> 
             RGBColor[
              0.39507001975859724`, 0.5161718386350326, 0.946515977450629], 
             UndirectedEdge[6, 102] -> 
             RGBColor[
              0.8773138712581801, 0.4289471619307136, 0.2831745426769966], 
             UndirectedEdge[205, 276] -> 
             RGBColor[
              0.8804173286055655, 0.9045483902483498, 0.8526723312886473], 
             UndirectedEdge[101, 244] -> 
             RGBColor[
              0.2604390037563816, 0.39106828410749395`, 0.9381429880277227], 
             UndirectedEdge[58, 80] -> 
             RGBColor[
              0.31661369550810525`, 0.44773804311104304`, 0.9414289555561544],
              UndirectedEdge[23, 292] -> 
             RGBColor[
              0.21221830344661968`, 0.3403852707129492, 0.9353968904812151], 
             UndirectedEdge[101, 397] -> 
             RGBColor[
              0.2550956906132599, 0.3854521232084524, 0.9378386942489454], 
             UndirectedEdge[105, 168] -> 
             RGBColor[
              0.5437472998304071, 0.6390750737498879, 0.957785885757477], 
             UndirectedEdge[166, 340] -> 
             RGBColor[
              0.8811054453751566, 0.4572946324610186, 0.30229009924467354`], 
             UndirectedEdge[138, 317] -> 
             RGBColor[
              0.8764376053277974, 0.429919621971069, 0.3791031608899539], 
             UndirectedEdge[71, 120] -> 
             RGBColor[
              0.7187491637803132, 0.7794609626924269, 0.9732879603430942], 
             UndirectedEdge[231, 290] -> 
             RGBColor[
              0.3569089205700484, 0.48355258019145775`, 0.9439631081789103], 
             UndirectedEdge[13, 224] -> 
             RGBColor[
              0.9697208187554422, 0.9510352770851425, 0.6530724790472836], 
             UndirectedEdge[40, 159] -> 
             RGBColor[
              0.33537336280871854`, 0.46490528333474357`, 0.9425906720125191],
              UndirectedEdge[20, 265] -> 
             RGBColor[
              0.49977683892029745`, 0.6035406289522859, 0.9541059564454999], 
             UndirectedEdge[43, 299] -> 
             RGBColor[
              0.22078197517346282`, 0.34938623266600927`, 0.9358845789172419],
              UndirectedEdge[219, 220] -> 
             RGBColor[
              0.4613111794873067, 0.5733857750910603, 0.9507812424766675], 
             UndirectedEdge[56, 290] -> 
             RGBColor[
              0.42803437429076585`, 0.5451635942026395, 0.9484949497272399], 
             UndirectedEdge[64, 157] -> 
             RGBColor[
              0.43410205704708005`, 0.5499866920911975, 0.9490010571312653], 
             UndirectedEdge[13, 340] -> 
             RGBColor[
              0.9787791287241259, 0.9808041152910011, 0.7551804074343922], 
             UndirectedEdge[16, 188] -> 
             RGBColor[
              0.25447321455412675`, 0.38479786140304184`, 0.9378032451582485],
              UndirectedEdge[171, 308] -> 
             RGBColor[
              0.26715048285961845`, 0.3981224741773486, 0.9385251968339084], 
             UndirectedEdge[288, 379] -> 
             RGBColor[
              0.23299167582952007`, 0.3622194021952592, 0.9365799033069708], 
             UndirectedEdge[81, 353] -> 
             RGBColor[
              0.2150475477536689, 0.34335898586410785`, 0.9355580117590097], 
             UndirectedEdge[153, 188] -> 
             RGBColor[
              0.2922583395910017, 0.4237094580639409, 0.939984452630228], 
             UndirectedEdge[148, 356] -> 
             RGBColor[
              0.5711332147381206, 0.6627106988393463, 0.9593808452755366], 
             UndirectedEdge[198, 247] -> 
             RGBColor[
              0.866748584365629, 0.7667536625408037, 0.6136734000774657], 
             UndirectedEdge[94, 375] -> 
             RGBColor[
              0.25748465436672835`, 0.3879630755823982, 0.9379747422005502], 
             UndirectedEdge[298, 307] -> 
             RGBColor[
              0.9043350538106595, 0.9251046086494896, 0.9386480207606034], 
             UndirectedEdge[9, 142] -> 
             RGBColor[
              0.824306283123464, 0.18783431993393215`, 0.17090903021003664`], 
             UndirectedEdge[203, 284] -> 
             RGBColor[
              0.26769783285159876`, 0.3986977737229138, 0.93855636760622], 
             UndirectedEdge[370, 400] -> 
             RGBColor[
              0.6104137657145253, 0.6900683539569277, 0.9649050090474223], 
             UndirectedEdge[63, 381] -> 
             RGBColor[
              0.975854040924288, 0.9316564884007599, 0.528376469194335], 
             UndirectedEdge[222, 251] -> 
             RGBColor[
              0.7136213718875605, 0.7756511419302459, 0.9724778106511085], 
             UndirectedEdge[103, 234] -> 
             RGBColor[
              0.34165277525472826`, 0.4703441947830308, 0.9429907906209125], 
             UndirectedEdge[150, 399] -> 
             RGBColor[
              0.2527398969113101, 0.3829760346617555, 0.9377045352827038], 
             UndirectedEdge[321, 338] -> 
             RGBColor[
              0.9060374188254435, 0.923886001186349, 0.8010879565228419], 
             UndirectedEdge[154, 203] -> 
             RGBColor[
              0.36077780249875213`, 0.4853053517709617, 0.9442681500235399], 
             UndirectedEdge[225, 390] -> 
             RGBColor[
              0.26170368970244295`, 0.3923975492225247, 0.9382150100214157], 
             UndirectedEdge[54, 121] -> 
             RGBColor[
              0.502593813473784, 0.607031307257596, 0.9539951244124792], 
             UndirectedEdge[234, 346] -> 
             RGBColor[
              0.34188570275875485`, 0.4705459448797419, 0.9430056325554994], 
             UndirectedEdge[358, 391] -> 
             RGBColor[
              0.8697860843549728, 0.40704671039684404`, 0.22224861189590023`],
              UndirectedEdge[74, 357] -> 
             RGBColor[
              0.7501817896070486, 0.8048048860165811, 0.9757247096384958], 
             UndirectedEdge[130, 364] -> 
             RGBColor[
              0.379967678176128, 0.5035306379305324, 0.9454321823545258], 
             UndirectedEdge[202, 381] -> 
             RGBColor[
              0.9019420935827297, 0.6198491310425445, 0.38880112820481405`], 
             UndirectedEdge[98, 307] -> 
             RGBColor[
              0.9814050384421338, 0.9620825967866911, 0.6308199289588313], 
             UndirectedEdge[242, 317] -> 
             RGBColor[
              0.954486951543472, 0.8521857620679489, 0.5290777523178287], 
             UndirectedEdge[9, 279] -> 
             RGBColor[
              0.8656615052757575, 0.40627315624282495`, 0.20651719187143383`],
              UndirectedEdge[200, 399] -> 
             RGBColor[
              0.2527693356026074, 0.3830069765928298, 0.9377062117726225], 
             UndirectedEdge[275, 306] -> 
             RGBColor[
              0.9812383782660234, 0.9513676250265612, 0.559996794380909], 
             UndirectedEdge[121, 181] -> 
             RGBColor[
              0.5602542166801026, 0.6538786381225696, 0.9585244106973264], 
             UndirectedEdge[239, 271] -> 
             RGBColor[
              0.31565140111640955`, 0.4476420700773734, 0.9413406348615612], 
             UndirectedEdge[35, 354] -> 
             RGBColor[
              0.2804072432672092, 0.41205616989288285`, 0.9392801497275012], 
             UndirectedEdge[31, 310] -> 
             RGBColor[
              0.18289778193115996`, 0.30956754357176464`, 0.9337271301567341],
              UndirectedEdge[146, 154] -> 
             RGBColor[
              0.48274463326921224`, 0.5903240190384458, 0.9525963248033308], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.8756433920758676, 0.5220025985586171, 0.4474818068679641], 
             UndirectedEdge[265, 322] -> 
             RGBColor[
              0.5501554119867256, 0.6456799735265193, 0.9577293957987232], 
             UndirectedEdge[115, 284] -> 
             RGBColor[
              0.24130209476909242`, 0.37095417941174347`, 0.9370531693714164],
              UndirectedEdge[38, 391] -> 
             RGBColor[
              0.8688575973668984, 0.40391470576695665`, 0.21864161527728607`],
              UndirectedEdge[116, 328] -> 
             RGBColor[
              0.3628292631493686, 0.48868620423613895`, 0.944340137703926], 
             UndirectedEdge[92, 278] -> 
             RGBColor[
              0.2700397327532974, 0.4011592590046289, 0.9386897353410912], 
             UndirectedEdge[215, 217] -> 
             RGBColor[
              0.8204673545206362, 0.1583266324633574, 0.16723286784451905`], 
             UndirectedEdge[159, 210] -> 
             RGBColor[
              0.3156791522092831, 0.44703146697688845`, 0.9413656404050212], 
             UndirectedEdge[165, 298] -> 
             RGBColor[
              0.6780894534855002, 0.7467966667692734, 0.969689888365638], 
             UndirectedEdge[83, 254] -> 
             RGBColor[
              0.4111965295816905, 0.5301398109018447, 0.9475435443964437], 
             UndirectedEdge[103, 231] -> 
             RGBColor[
              0.3266251404157554, 0.4573222919288569, 0.942033452486374], 
             UndirectedEdge[245, 319] -> 
             RGBColor[
              0.2357412606353747, 0.36510939015995814`, 0.9367364880940181], 
             UndirectedEdge[58, 263] -> 
             RGBColor[
              0.28044730154374703`, 0.41209827368136553`, 0.9392824309870891],
              UndirectedEdge[206, 258] -> 
             RGBColor[
              0.24224766571092132`, 0.37194803442426605`, 0.9371070182377067],
              UndirectedEdge[213, 391] -> 
             RGBColor[
              0.8505832314147017, 0.33340050715280367`, 0.19384671932522138`],
              UndirectedEdge[78, 370] -> 
             RGBColor[
              0.8383015076692176, 0.504508869387615, 0.4530565388424428], 
             UndirectedEdge[101, 270] -> 
             RGBColor[
              0.2552144898783262, 0.38557698876834556`, 0.937845459691343], 
             UndirectedEdge[135, 377] -> 
             RGBColor[
              0.4590787183907463, 0.5706961122538062, 0.9508478818462491], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.22879801729426974`, 0.3578116011814027, 0.9363410806573501], 
             UndirectedEdge[19, 83] -> 
             RGBColor[
              0.31363288900734776`, 0.44289778603368235`, 0.9413217134716801],
              UndirectedEdge[100, 112] -> 
             RGBColor[
              0.35276762831000186`, 0.47997132185075075`, 0.9436990192291159],
              UndirectedEdge[10, 296] -> 
             RGBColor[
              0.331723708667086, 0.46107618573568054`, 0.9423825762220581], 
             UndirectedEdge[85, 369] -> 
             RGBColor[
              0.24938070758750824`, 0.3794453136975352, 0.9375132344201885], 
             UndirectedEdge[79, 246] -> 
             RGBColor[
              0.5173044068287108, 0.618751689159956, 0.9552146295473145], 
             UndirectedEdge[227, 280] -> 
             RGBColor[
              0.23696761026347307`, 0.36639836137414694`, 0.9368063268911165],
              UndirectedEdge[112, 326] -> 
             RGBColor[
              0.3341557033790634, 0.4638506079381187, 0.9425130838303954], 
             UndirectedEdge[34, 308] -> 
             RGBColor[
              0.2866886948098787, 0.4183307981986623, 0.9396498632451982], 
             UndirectedEdge[29, 226] -> 
             RGBColor[
              0.23953161826969796`, 0.36909329635618626`, 0.936952343353961], 
             UndirectedEdge[204, 345] -> 
             RGBColor[
              0.1904371972329284, 0.3174919470804629, 0.9341564887046044], 
             UndirectedEdge[54, 265] -> 
             RGBColor[
              0.5219430916057815, 0.622739922920198, 0.9555183704657713], 
             UndirectedEdge[22, 100] -> 
             RGBColor[
              0.3344662411106874, 0.46260073594405915`, 0.9425884833453301], 
             UndirectedEdge[126, 336] -> 
             RGBColor[
              0.21152415432057162`, 0.33965567596987617`, 0.9353573597153882],
              UndirectedEdge[82, 157] -> 
             RGBColor[
              0.4242304983845992, 0.5414364441367214, 0.9483720501423687], 
             UndirectedEdge[344, 349] -> 
             RGBColor[
              0.3830038950089686, 0.5061604563464437, 0.9456256474062932], 
             UndirectedEdge[343, 349] -> 
             RGBColor[
              0.5837898565381997, 0.6715473011239714, 0.9612730023398459], 
             UndirectedEdge[2, 66] -> 
             RGBColor[
              0.8698950919669056, 0.4018371712100696, 0.22645715541410283`], 
             UndirectedEdge[211, 387] -> 
             RGBColor[
              0.27812297420375887`, 0.4096552582761729, 0.939150063983611], 
             UndirectedEdge[250, 265] -> 
             RGBColor[
              0.7900609571838799, 0.8344827358393506, 0.9028921387192244], 
             UndirectedEdge[217, 306] -> 
             RGBColor[
              0.8720091515943377, 0.4215470578596804, 0.22613320631901165`], 
             UndirectedEdge[374, 375] -> 
             RGBColor[
              0.26547453356081113`, 0.3963609452029792, 0.9384297540006862], 
             UndirectedEdge[38, 247] -> 
             RGBColor[
              0.9363993756149239, 0.7826453892822661, 0.2828200168311238], 
             UndirectedEdge[204, 310] -> 
             RGBColor[
              0.18075257528517846`, 0.3073127953728809, 0.9336049638117943], 
             UndirectedEdge[226, 266] -> 
             RGBColor[
              0.24681597923856835`, 0.37674962158963, 0.9373671769348919], 
             UndirectedEdge[319, 334] -> 
             RGBColor[
              0.25149135479282314`, 0.3816637377330832, 0.9376334326561084], 
             UndirectedEdge[73, 206] -> 
             RGBColor[
              0.23733902327111464`, 0.366788739994123, 0.9368274783124455], 
             UndirectedEdge[200, 255] -> 
             RGBColor[
              0.26556731627814384`, 0.3964584657216599, 0.9384350378391786], 
             UndirectedEdge[296, 383] -> 
             RGBColor[
              0.2908789334455868, 0.4230625802138626, 0.9398764969916824], 
             UndirectedEdge[235, 281] -> 
             RGBColor[
              0.6860438629162344, 0.7545031690861064, 0.9694506561545053], 
             UndirectedEdge[174, 272] -> 
             RGBColor[
              0.6878111560407678, 0.756042569748228, 0.9695182461395961], 
             UndirectedEdge[9, 131] -> 
             RGBColor[
              0.8579336851220932, 0.37563492447695607`, 0.2002992063805429], 
             UndirectedEdge[228, 361] -> 
             RGBColor[
              0.3617418491636495, 0.4877443408967252, 0.9442708486463184], 
             UndirectedEdge[149, 199] -> 
             RGBColor[
              0.2230106997449548, 0.3517287634999468, 0.9360115014844858], 
             UndirectedEdge[102, 400] -> 
             RGBColor[
              0.6760683261322689, 0.2701817374487175, 0.4260903260925494], 
             UndirectedEdge[45, 350] -> 
             RGBColor[
              0.36412092231360993`, 0.48858020750687353`, 0.9444672858023867],
              UndirectedEdge[369, 392] -> 
             RGBColor[
              0.2527015805879449, 0.38293576177650346`, 0.937702353224772], 
             UndirectedEdge[82, 151] -> 
             RGBColor[
              0.34752633634939933`, 0.4754315781894705, 0.9433650487400788], 
             UndirectedEdge[260, 342] -> 
             RGBColor[
              0.706156116764429, 0.7697763499712335, 0.9717551750957918], 
             UndirectedEdge[296, 380] -> 
             RGBColor[
              0.28350610283773925`, 0.41531326778055483`, 0.939456625195691], 
             UndirectedEdge[105, 148] -> 
             RGBColor[
              0.520616067080279, 0.620721827134755, 0.9556738363326167], 
             UndirectedEdge[94, 288] -> 
             RGBColor[
              0.25257497972760906`, 0.38280269624533236`, 0.9376951434930652],
              UndirectedEdge[195, 258] -> 
             RGBColor[
              0.24931398381106837`, 0.3793751827779651, 0.9375094345998292], 
             UndirectedEdge[339, 374] -> 
             RGBColor[
              0.3209321143289635, 0.44937899853087393`, 0.9417809922375882], 
             UndirectedEdge[199, 367] -> 
             RGBColor[
              0.2225587298907346, 0.35125371452661747`, 0.9359857624699174], 
             UndirectedEdge[36, 298] -> 
             RGBColor[
              0.6715537144550077, 0.7414906593926315, 0.9691753710479567], 
             UndirectedEdge[147, 347] -> 
             RGBColor[
              0.28239395908436904`, 0.4141443341817761, 0.9393932902542057], 
             UndirectedEdge[38, 205] -> 
             RGBColor[
              0.9805298619657696, 0.9442896440229023, 0.524841136015259], 
             UndirectedEdge[16, 73] -> 
             RGBColor[
              0.24248824364408117`, 0.372200897085539, 0.937120718795097], 
             UndirectedEdge[108, 290] -> 
             RGBColor[
              0.3863513979794556, 0.5090598951690881, 0.945838947335492], 
             UndirectedEdge[225, 296] -> 
             RGBColor[
              0.2793148229194171, 0.41090796684390285`, 0.9392179380047856], 
             UndirectedEdge[24, 144] -> 
             RGBColor[
              0.8902955651891483, 0.5947396082931894, 0.23017226930310958`], 
             UndirectedEdge[209, 319] -> 
             RGBColor[
              0.24680833108244982`, 0.37674158289262827`, 0.9373667413837155],
              UndirectedEdge[80, 192] -> 
             RGBColor[
              0.3394530711598287, 0.46843892165637124`, 0.9428506274211075], 
             UndirectedEdge[42, 221] -> 
             RGBColor[
              0.9270423893059134, 0.944662453609973, 0.9929033247441504], 
             UndirectedEdge[22, 365] -> 
             RGBColor[
              0.27427955709376345`, 0.40561558320684826`, 0.9389311870650228],
              UndirectedEdge[80, 201] -> 
             RGBColor[
              0.30542134246892777`, 0.4359741704306982, 0.9407915676081757], 
             UndirectedEdge[39, 375] -> 
             RGBColor[
              0.2639687025623859, 0.39477822134843454`, 0.9383439991530031], 
             UndirectedEdge[15, 326] -> 
             RGBColor[
              0.3216255760176605, 0.45254598204008034`, 0.9417312126565649], 
             UndirectedEdge[86, 95] -> 
             RGBColor[
              0.2911574427094625, 0.42335531110870317`, 0.9398923576822427], 
             UndirectedEdge[59, 194] -> 
             RGBColor[
              0.3610366257463029, 0.4871335118181791, 0.9442259124337696], 
             UndirectedEdge[296, 324] -> 
             RGBColor[
              0.2907395975741168, 0.42291612937854317`, 0.9398685620199312], 
             UndirectedEdge[169, 245] -> 
             RGBColor[
              0.22529865841710267`, 0.3541335531293326, 0.936141797346133], 
             UndirectedEdge[258, 284] -> 
             RGBColor[
              0.24846567575091127`, 0.3784835572209025, 0.9374611247107626], 
             UndirectedEdge[33, 152] -> 
             RGBColor[
              0.18127877637637368`, 0.30786586608280325`, 0.9336349301854932],
              UndirectedEdge[246, 349] -> 
             RGBColor[
              0.44459099850605766`, 0.559504109937796, 0.9495499231817904], 
             UndirectedEdge[27, 395] -> 
             RGBColor[
              0.28524240829505776`, 0.41713823490432095`, 0.9395555052228516],
              UndirectedEdge[185, 340] -> 
             RGBColor[
              0.880386365226195, 0.45176746733316986`, 0.3016015072819431], 
             UndirectedEdge[223, 321] -> 
             RGBColor[
              0.6359268279774656, 0.7126257479828174, 0.9663189746381065], 
             UndirectedEdge[274, 373] -> 
             RGBColor[
              0.24052488712014738`, 0.3701372848948911, 0.9370089085455846], 
             UndirectedEdge[156, 214] -> 
             RGBColor[
              0.5848663164286375, 0.6501021124541597, 0.9231267958935396], 
             UndirectedEdge[205, 221] -> 
             RGBColor[
              0.9585637141169614, 0.9664203575638242, 0.8602427231177231], 
             UndirectedEdge[97, 105] -> 
             RGBColor[
              0.42981427861771465`, 0.5467052578700499, 0.9486083636570456], 
             UndirectedEdge[130, 158] -> 
             RGBColor[
              0.4567607455909806, 0.5686928034323673, 0.9506989661864262], 
             UndirectedEdge[108, 143] -> 
             RGBColor[
              0.49610666284564264`, 0.5994724798522266, 0.954117792155521], 
             UndirectedEdge[176, 399] -> 
             RGBColor[
              0.22535125221155355`, 0.3541888325419396, 0.9361447924849214], 
             UndirectedEdge[150, 189] -> 
             RGBColor[
              0.28557376029945525`, 0.4174865068698732, 0.9395743752293106], 
             UndirectedEdge[253, 386] -> 
             RGBColor[
              0.3405394596215219, 0.4693798967384182, 0.942919851133231], 
             UndirectedEdge[46, 59] -> 
             RGBColor[
              0.30916725287120805`, 0.4399481765928165, 0.9410035436196971], 
             UndirectedEdge[186, 241] -> 
             RGBColor[
              0.2697148101734317, 0.4008177447719086, 0.9386712314808479], 
             UndirectedEdge[39, 93] -> 
             RGBColor[
              0.2591650880555334, 0.38972931793498194`, 0.9380704404131488], 
             UndirectedEdge[214, 264] -> 
             RGBColor[
              0.5869020540862017, 0.6522418018054821, 0.9232427281415339], 
             UndirectedEdge[234, 290] -> 
             RGBColor[
              0.37193655540902126`, 0.4965744830456317, 0.9449204463134487], 
             UndirectedEdge[148, 170] -> 
             RGBColor[
              0.5344288299346016, 0.632685748069522, 0.9565539733675475], 
             UndirectedEdge[50, 362] -> 
             RGBColor[
              0.4294033294821849, 0.5463267879239184, 0.948588402469489], 
             UndirectedEdge[271, 326] -> 
             RGBColor[
              0.3230890593454866, 0.4540841958078278, 0.941814555867055], 
             UndirectedEdge[61, 352] -> 
             RGBColor[
              0.9937500196167237, 0.9890402488671484, 0.5611063895673631], 
             UndirectedEdge[256, 333] -> 
             RGBColor[
              0.21043441051870343`, 0.338510286140365, 0.9352953004180034], 
             UndirectedEdge[100, 394] -> 
             RGBColor[
              0.3677410184422385, 0.49294051979882375`, 0.944653110407893], 
             UndirectedEdge[1, 114] -> 
             RGBColor[
              0.3444304570913155, 0.4727500831795342, 0.9431677820513322], 
             UndirectedEdge[218, 269] -> 
             RGBColor[
              0.9515613514707596, 0.9593431212476458, 0.7385846645144882], 
             UndirectedEdge[182, 253] -> 
             RGBColor[
              0.31490504522225604`, 0.4452672657366318, 0.9413563610246107], 
             UndirectedEdge[57, 354] -> 
             RGBColor[
              0.27649042962059545`, 0.4079393504099632, 0.939057092984733], 
             UndirectedEdge[40, 192] -> 
             RGBColor[
              0.34190093761815415`, 0.4705591405492272, 0.9430066033072686], 
             UndirectedEdge[262, 314] -> 
             RGBColor[
              0.9322274207027686, 0.9487209428474576, 0.9907658897447179], 
             UndirectedEdge[244, 253] -> 
             RGBColor[
              0.30087597692201773`, 0.4305218254587764, 0.9405574263390588], 
             UndirectedEdge[277, 330] -> 
             RGBColor[
              0.24129239010618297`, 0.3709439791957144, 0.9370526167052204], 
             UndirectedEdge[304, 329] -> 
             RGBColor[
              0.2271186296842969, 0.35604645832399684`, 0.9362454420173936], 
             UndirectedEdge[103, 223] -> 
             RGBColor[
              0.3993166746191169, 0.5202694238127852, 0.9466707039440156], 
             UndirectedEdge[92, 337] -> 
             RGBColor[
              0.2862035870447653, 0.41814849471251614`, 0.9396102429307109], 
             UndirectedEdge[226, 341] -> 
             RGBColor[
              0.23010886985563692`, 0.3591893903362524, 0.9364157317714874], 
             UndirectedEdge[193, 260] -> 
             RGBColor[
              0.8156468227717713, 0.8559278037169716, 0.9822546582008858], 
             UndirectedEdge[9, 214] -> 
             RGBColor[
              0.8783693231940418, 0.4613373616560016, 0.41892568209360864`], 
             UndirectedEdge[8, 157] -> 
             RGBColor[
              0.38978189814954545`, 0.5115987980501094, 0.9461770157970921], 
             UndirectedEdge[103, 342] -> 
             RGBColor[
              0.4739621782432806, 0.580870006396498, 0.9525470714247991], 
             UndirectedEdge[165, 314] -> 
             RGBColor[
              0.7292803775430885, 0.7876149200721775, 0.9745725244009281], 
             UndirectedEdge[115, 392] -> 
             RGBColor[
              0.24327765587914302`, 0.37303061939621557`, 0.937165674654053], 
             UndirectedEdge[104, 233] -> 
             RGBColor[
              0.8562635175692925, 0.3486447429220402, 0.19811813370937414`], 
             UndirectedEdge[67, 139] -> 
             RGBColor[
              0.21205827028800195`, 0.34021706571655375`, 0.9353877768295796],
              UndirectedEdge[116, 364] -> 
             RGBColor[
              0.382875553578809, 0.5060492934502673, 0.9456174696038513], 
             UndirectedEdge[74, 220] -> 
             RGBColor[
              0.6500539956476187, 0.724027222159205, 0.9674931897567542], 
             UndirectedEdge[100, 168] -> 
             RGBColor[
              0.5233822877675662, 0.6214359238763232, 0.9564882451969059], 
             UndirectedEdge[129, 308] -> 
             RGBColor[
              0.2493864248848615, 0.3794513229395511, 0.9375135600118147], 
             UndirectedEdge[26, 185] -> 
             RGBColor[
              0.7008312736981772, 0.31157405821960193`, 0.4302953258159472], 
             UndirectedEdge[197, 215] -> 
             RGBColor[
              0.87577594264947, 0.4293808885383422, 0.3894295971862648], 
             UndirectedEdge[178, 240] -> 
             RGBColor[
              0.24159747707370743`, 0.3712646449422136, 0.9370699909566852], 
             UndirectedEdge[52, 223] -> 
             RGBColor[
              0.42035633884682855`, 0.5384929234825571, 0.9480113327439608], 
             UndirectedEdge[192, 243] -> 
             RGBColor[
              0.31643084813058897`, 0.44661450926807483`, 0.9414526439417388],
              UndirectedEdge[124, 252] -> 
             RGBColor[
              0.22380219645594157`, 0.3525606767269839, 0.936056576051262], 
             UndirectedEdge[194, 396] -> 
             RGBColor[
              0.3331772870037427, 0.4601881672994485, 0.9425538104147095], 
             UndirectedEdge[269, 279] -> 
             RGBColor[
              0.9693542844710024, 0.9048940200148108, 0.380506034096984], 
             UndirectedEdge[57, 208] -> 
             RGBColor[
              0.2531470707031978, 0.383404000133339, 0.9377277232277921], 
             UndirectedEdge[169, 304] -> 
             RGBColor[
              0.21989845129097363`, 0.3484575930468634, 0.9358342635391905], 
             UndirectedEdge[209, 280] -> 
             RGBColor[
              0.24552309910713999`, 0.37539072259816386`, 0.9372935493240518],
              UndirectedEdge[226, 399] -> 
             RGBColor[
              0.23675652181007376`, 0.36617649402584324`, 0.9367943057159729],
              UndirectedEdge[206, 392] -> 
             RGBColor[
              0.23975564105496683`, 0.3693287585073688, 0.9369651011201702], 
             UndirectedEdge[48, 343] -> 
             RGBColor[
              0.5738217336869491, 0.6629134141226403, 0.9606378423662292], 
             UndirectedEdge[159, 263] -> 
             RGBColor[
              0.29675910238603487`, 0.4271452950122101, 0.9402881715572926], 
             UndirectedEdge[261, 295] -> 
             RGBColor[
              0.2109178597842839, 0.3390184219709439, 0.935322832138479], 
             UndirectedEdge[33, 204] -> 
             RGBColor[
              0.1789341933349501, 0.3054015606511163, 0.9335014096497838], 
             UndirectedEdge[64, 151] -> 
             RGBColor[
              0.35739789501188024`, 0.48398182614394664`, 0.9439940557289754],
              UndirectedEdge[210, 263] -> 
             RGBColor[
              0.2810036601000736, 0.41268304179923465`, 0.9393141147838132], 
             UndirectedEdge[19, 303] -> 
             RGBColor[
              0.2819979246761117, 0.4137280769086658, 0.939370736680536], 
             UndirectedEdge[248, 315] -> 
             RGBColor[
              0.229741057636631, 0.35880279637343554`, 0.9363947854097444], 
             UndirectedEdge[236, 351] -> 
             RGBColor[
              0.2481333456349381, 0.37813425719806837`, 0.9374421990022963], 
             UndirectedEdge[53, 386] -> 
             RGBColor[
              0.3143035505913172, 0.444852574192945, 0.9413141424158159], 
             UndirectedEdge[93, 301] -> 
             RGBColor[
              0.25102800874557624`, 0.38117673165959054`, 0.9376070457841768],
              UndirectedEdge[37, 159] -> 
             RGBColor[
              0.29061706023566036`, 0.4206896192842019, 0.9399383913431659], 
             UndirectedEdge[148, 326] -> 
             RGBColor[
              0.4816391300864997, 0.5869619633485583, 0.9531902603733251], 
             UndirectedEdge[13, 357] -> 
             RGBColor[
              0.8197351159980406, 0.8595406855045937, 0.9572525529228332], 
             UndirectedEdge[162, 231] -> 
             RGBColor[
              0.27738405997012383`, 0.4088786125667542, 0.9391079839111312], 
             UndirectedEdge[33, 84] -> 
             RGBColor[
              0.17893420048233583`, 0.30540156816347186`, 0.9335014100568169],
              UndirectedEdge[199, 293] -> 
             RGBColor[
              0.21851691429369074`, 0.3470055100682143, 0.9357555870509962], 
             UndirectedEdge[96, 167] -> 
             RGBColor[
              0.28523047788544853`, 0.41712569528738996`, 0.9395548258036737],
              UndirectedEdge[131, 307] -> 
             RGBColor[
              0.9538530771213425, 0.8592378166634234, 0.5753740091193393], 
             UndirectedEdge[174, 291] -> 
             RGBColor[
              0.7125484820155874, 0.7753675568103979, 0.9719838316093115], 
             UndirectedEdge[207, 250] -> 
             RGBColor[
              0.9640415176105277, 0.8943275288623829, 0.5576168978426572], 
             UndirectedEdge[364, 387] -> 
             RGBColor[
              0.3215492584874442, 0.4515282986156772, 0.941761191813439], 
             UndirectedEdge[103, 346] -> 
             RGBColor[
              0.3447990844282577, 0.4730693696510448, 0.9431912706592778], 
             UndirectedEdge[31, 106] -> 
             RGBColor[
              0.5658561150624204, 0.6355057978202503, 0.9529071762376704], 
             UndirectedEdge[128, 316] -> 
             RGBColor[
              0.29024632988181515`, 0.4207827161213608, 0.9398996026647567], 
             UndirectedEdge[185, 289] -> 
             RGBColor[
              0.8483780918699089, 0.3316018363500779, 0.1923446242870728], 
             UndirectedEdge[20, 172] -> 
             RGBColor[
              0.3545418209166673, 0.4808311305362721, 0.9438368541227812], 
             UndirectedEdge[70, 234] -> 
             RGBColor[
              0.30827476436067847`, 0.438573607296341, 0.9409687003893238], 
             UndirectedEdge[119, 383] -> 
             RGBColor[
              0.2603673467577916, 0.3909929680586598, 0.93813890726766], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.5352140965427551, 0.633549940550514, 0.9565531607151321], 
             UndirectedEdge[20, 54] -> 
             RGBColor[
              0.4298252331165606, 0.5467147461063611, 0.9486090616680254], 
             UndirectedEdge[229, 334] -> 
             RGBColor[
              0.25414759898597045`, 0.3844556187956901, 0.9377847018333471], 
             UndirectedEdge[63, 142] -> 
             RGBColor[
              0.8672429999311523, 0.40189925085666073`, 0.21004074380363202`],
              UndirectedEdge[230, 358] -> 
             RGBColor[
              0.9687169526811137, 0.9061370771638947, 0.3329716977842575], 
             UndirectedEdge[119, 296] -> 
             RGBColor[
              0.27100995406971695`, 0.4021790231237703, 0.9387449880097476], 
             UndirectedEdge[218, 262] -> 
             RGBColor[
              0.9243533171861171, 0.9424423464401257, 0.9900148507220045], 
             UndirectedEdge[100, 170] -> 
             RGBColor[
              0.4107918604538279, 0.5302289953510277, 0.9473962719925066], 
             UndirectedEdge[97, 357] -> 
             RGBColor[
              0.5589872751901463, 0.652039901144515, 0.958856542313451], 
             UndirectedEdge[375, 399] -> 
             RGBColor[
              0.24486217858118842`, 0.3746960532206071, 0.9372559108778432], 
             UndirectedEdge[199, 252] -> 
             RGBColor[
              0.2250679449332263, 0.3538910586296987, 0.9361286585545363], 
             UndirectedEdge[175, 345] -> 
             RGBColor[
              0.1904397679735038, 0.31749464909180203`, 0.9341566351044772], 
             UndirectedEdge[176, 186] -> 
             RGBColor[
              0.23214557991116364`, 0.36133010173948693`, 0.9365317193961071],
              UndirectedEdge[309, 371] -> 
             RGBColor[
              0.2714180274121831, 0.4026079340800466, 0.9387682271829105], 
             UndirectedEdge[326, 354] -> 
             RGBColor[
              0.3095818357707423, 0.4398872474233331, 0.94104533946662], 
             UndirectedEdge[38, 289] -> 
             RGBColor[
              0.9317722599024755, 0.7624356715057958, 0.27900046954474644`], 
             UndirectedEdge[120, 237] -> 
             RGBColor[
              0.5723986729827764, 0.663738054850602, 0.9594804667840822], 
             UndirectedEdge[275, 384] -> 
             RGBColor[
              0.8702642398197578, 0.8971991046411623, 0.8780681531351799], 
             UndirectedEdge[216, 220] -> 
             RGBColor[
              0.5672680445778805, 0.6593163046949915, 0.9592519182010989], 
             UndirectedEdge[50, 276] -> 
             RGBColor[
              0.6098568885565028, 0.6922609454050347, 0.9637197242270632], 
             UndirectedEdge[143, 321] -> 
             RGBColor[
              0.7212153553030598, 0.7818668166701053, 0.973033199931347], 
             UndirectedEdge[225, 316] -> 
             RGBColor[
              0.2556938059368381, 0.38608078033623494`, 0.9378727560317908], 
             UndirectedEdge[40, 332] -> 
             RGBColor[
              0.43326686926446056`, 0.5476890621459892, 0.9493828047697146], 
             UndirectedEdge[254, 343] -> 
             RGBColor[
              0.5958559812878284, 0.6815586834125604, 0.9621633323841816], 
             UndirectedEdge[37, 167] -> 
             RGBColor[
              0.26667449670074206`, 0.39762218254510395`, 0.9384980901263189],
              UndirectedEdge[26, 204] -> 
             RGBColor[
              0.3170199268376633, 0.4369570715354334, 0.9418741487280438], 
             UndirectedEdge[141, 189] -> 
             RGBColor[
              0.33030534537683665`, 0.4597575440654077, 0.9422954993465642], 
             UndirectedEdge[55, 210] -> 
             RGBColor[
              0.3517281816196206, 0.4782553243752219, 0.9436626526821428], 
             UndirectedEdge[41, 312] -> 
             RGBColor[
              0.40188874544580117`, 0.5222558384193261, 0.9469012891044913], 
             UndirectedEdge[102, 247] -> 
             RGBColor[
              0.8485338701406309, 0.3225616689316914, 0.19208620843808044`], 
             UndirectedEdge[30, 400] -> 
             RGBColor[
              0.284268969836752, 0.4086385761438802, 0.9397738211163575], 
             UndirectedEdge[57, 195] -> 
             RGBColor[
              0.25945106473985713`, 0.3900298975621752, 0.9380867263622563], 
             UndirectedEdge[301, 324] -> 
             RGBColor[
              0.2683877801719362, 0.39942295210177514`, 0.9385956590854276], 
             UndirectedEdge[290, 331] -> 
             RGBColor[
              0.42861309362707734`, 0.5456648518044729, 0.9485318252116084], 
             UndirectedEdge[49, 347] -> 
             RGBColor[
              0.2678932418389194, 0.3989031609582332, 0.9385674958589661], 
             UndirectedEdge[92, 258] -> 
             RGBColor[
              0.2702985516937192, 0.40143129412108086`, 0.93870447469686], 
             UndirectedEdge[234, 313] -> 
             RGBColor[
              0.3107738733861259, 0.4412003293347502, 0.9411110209512226], 
             UndirectedEdge[376, 377] -> 
             RGBColor[
              0.4266363429774569, 0.5439526897461481, 0.9484058684081864], 
             UndirectedEdge[223, 272] -> 
             RGBColor[
              0.5505420601979628, 0.6459225184451997, 0.9578086189518668], 
             UndirectedEdge[213, 302] -> 
             RGBColor[
              0.9491225739214294, 0.8267349297802298, 0.3261475838124945], 
             UndirectedEdge[121, 158] -> 
             RGBColor[
              0.5281560210081759, 0.6278198768688632, 0.9559975231544674], 
             UndirectedEdge[240, 248] -> 
             RGBColor[
              0.22770719970496556`, 0.3566650827332143, 0.9362789602093593], 
             UndirectedEdge[18, 132] -> 
             RGBColor[
              0.8722144636354254, 0.9008667885957915, 0.9791289224454733], 
             UndirectedEdge[59, 79] -> 
             RGBColor[
              0.46241207497172554`, 0.5712067102742551, 0.9517169387007705], 
             UndirectedEdge[109, 207] -> 
             RGBColor[
              0.9669761340347394, 0.8955410681699965, 0.508982709149612], 
             UndirectedEdge[190, 365] -> 
             RGBColor[
              0.24867185173243342`, 0.3787002612497945, 0.9374728661279003], 
             UndirectedEdge[78, 391] -> 
             RGBColor[
              0.8346928964706893, 0.26767038156369644`, 0.18085526288134157`],
              UndirectedEdge[159, 236] -> 
             RGBColor[
              0.2909783973419341, 0.4210694074929913, 0.9399589689568179], 
             UndirectedEdge[95, 334] -> 
             RGBColor[
              0.27158878350233817`, 0.4027874095573609, 0.9387779514896339], 
             UndirectedEdge[20, 147] -> 
             RGBColor[
              0.34619840677068126`, 0.47206167326583015`, 0.9433617090301424],
              UndirectedEdge[229, 388] -> 
             RGBColor[
              0.23513063549537086`, 0.3644675844219441, 0.9367017138956337], 
             UndirectedEdge[15, 271] -> 
             RGBColor[
              0.3053243996883596, 0.43824568113047624`, 0.940699144924056], 
             UndirectedEdge[53, 151] -> 
             RGBColor[
              0.302539739143033, 0.43466335198279643`, 0.9405645627526612], 
             UndirectedEdge[178, 309] -> 
             RGBColor[
              0.2573894464516083, 0.38786300602707646`, 0.9379693202506316], 
             UndirectedEdge[309, 386] -> 
             RGBColor[
              0.30507679489801537`, 0.4351546689491852, 0.9407886923288442], 
             UndirectedEdge[199, 299] -> 
             RGBColor[
              0.21996573354153404`, 0.3485283109581435, 0.9358380951638248], 
             UndirectedEdge[33, 90] -> 
             RGBColor[
              0.44237359411374266`, 0.5377546224462848, 0.9524068017673784], 
             UndirectedEdge[191, 216] -> 
             RGBColor[
              0.6689774683276695, 0.7413295497654275, 0.9676410801591727], 
             UndirectedEdge[188, 203] -> 
             RGBColor[
              0.2792417470878428, 0.4108311595116429, 0.9392137764442834], 
             UndirectedEdge[87, 263] -> 
             RGBColor[
              0.2761111635451054, 0.407540717717765, 0.9390354943428079], 
             UndirectedEdge[25, 76] -> 
             RGBColor[
              0.8481222219407366, 0.3708940618944248, 0.19371520011771268`], 
             UndirectedEdge[329, 334] -> 
             RGBColor[
              0.2482689309678744, 0.37827676597959103`, 0.9374499203864265], 
             UndirectedEdge[42, 376] -> 
             RGBColor[
              0.6853095806395425, 0.7514657941798157, 0.9712763701432583], 
             UndirectedEdge[54, 130] -> 
             RGBColor[
              0.43119853805658864`, 0.5479042338211002, 0.9486965674444381], 
             UndirectedEdge[90, 256] -> 
             RGBColor[
              0.46555708352199543`, 0.5621219397324855, 0.9537270671922793], 
             UndirectedEdge[160, 302] -> 
             RGBColor[
              0.8820773992231308, 0.47463698833737966`, 0.25226541752395265`],
              UndirectedEdge[299, 367] -> 
             RGBColor[
              0.21672169883755696`, 0.34511862480058364`, 0.9356533521865525],
              UndirectedEdge[16, 96] -> 
             RGBColor[
              0.2643859994981743, 0.3952168268861021, 0.9383677635961609], 
             UndirectedEdge[5, 223] -> 
             RGBColor[
              0.6477551093793219, 0.7220395366342189, 0.9674518801311646], 
             UndirectedEdge[40, 228] -> 
             RGBColor[
              0.35358465424250685`, 0.48067898864856917`, 0.9437510793990673],
              UndirectedEdge[154, 222] -> 
             RGBColor[
              0.5175424648922109, 0.6185744663744461, 0.9553357375773506], 
             UndirectedEdge[85, 188] -> 
             RGBColor[
              0.25419669233076414`, 0.38450721901376617`, 0.937787497626706], 
             UndirectedEdge[281, 384] -> 
             RGBColor[
              0.6902109435663115, 0.7577585241609326, 0.9698659918101223], 
             UndirectedEdge[249, 334] -> 
             RGBColor[
              0.2654841590440016, 0.39637106219610324`, 0.9384303021577143], 
             UndirectedEdge[203, 243] -> 
             RGBColor[
              0.28988476393267687`, 0.4220176450218065, 0.9398198805086642], 
             UndirectedEdge[49, 147] -> 
             RGBColor[
              0.2702371158648362, 0.4013667211696683, 0.9387009760172913], 
             UndirectedEdge[99, 232] -> 
             RGBColor[
              0.7518421224806613, 0.804458883314896, 0.9388506680687247], 
             UndirectedEdge[84, 389] -> 
             RGBColor[
              0.1790075704625178, 0.3054786846645686, 0.933505588368647], 
             UndirectedEdge[76, 242] -> 
             RGBColor[
              0.8707452372835323, 0.4792205418875693, 0.2127776188363791], 
             UndirectedEdge[129, 397] -> 
             RGBColor[
              0.24351700983454236`, 0.3732821955792575, 0.9371793055077206], 
             UndirectedEdge[177, 390] -> 
             RGBColor[
              0.2941038875347629, 0.4252352483079229, 0.9401047123377103], 
             UndirectedEdge[138, 144] -> 
             RGBColor[
              0.8390412862575602, 0.28008815239866347`, 0.1841967491117235], 
             UndirectedEdge[184, 325] -> 
             RGBColor[
              0.2146653182782982, 0.3429572384507447, 0.9355362443558451], 
             UndirectedEdge[69, 140] -> 
             RGBColor[
              0.5800718085263902, 0.6695145386144623, 0.9603941834467046], 
             UndirectedEdge[247, 391] -> 
             RGBColor[
              0.8492630400338947, 0.3281663882556027, 0.1927844623513496], 
             UndirectedEdge[14, 391] -> 
             RGBColor[
              0.8783795527545815, 0.43527164554719366`, 0.32050000788288985`],
              UndirectedEdge[229, 240] -> 
             RGBColor[
              0.24305133588145522`, 0.372792742729129, 0.9371527860649951], 
             UndirectedEdge[166, 400] -> 
             RGBColor[
              0.6797163718188075, 0.2982222151792662, 0.42958369876185704`], 
             UndirectedEdge[281, 386] -> 
             RGBColor[
              0.4856785944575267, 0.5902406468075978, 0.9535084650798691], 
             UndirectedEdge[150, 255] -> 
             RGBColor[
              0.26553787758684655`, 0.39642752379058566`, 0.9384333613492598],
              UndirectedEdge[103, 290] -> 
             RGBColor[
              0.3748499370785241, 0.4990979078169345, 0.9451060844172272], 
             UndirectedEdge[212, 299] -> 
             RGBColor[
              0.2125129386493282, 0.3406949509919467, 0.9354136695201356], 
             UndirectedEdge[206, 208] -> 
             RGBColor[
              0.23232439396841398`, 0.3615180466511231, 0.9365419025921359], 
             UndirectedEdge[75, 169] -> 
             RGBColor[
              0.2324382955275915, 0.3616377644115946, 0.9365483891174288], 
             UndirectedEdge[110, 167] -> 
             RGBColor[
              0.26956370563298526`, 0.40065892431931827`, 0.9386626263008084],
              UndirectedEdge[33, 214] -> 
             RGBColor[
              0.5813572401883383, 0.6464138508373214, 0.9229269591928677], 
             UndirectedEdge[98, 107] -> 
             RGBColor[
              0.8853351538424127, 0.5136335085049757, 0.24591363748146172`], 
             UndirectedEdge[238, 252] -> 
             RGBColor[
              0.22677811637454098`, 0.3556885572456525, 0.9362260502881472], 
             UndirectedEdge[91, 241] -> 
             RGBColor[
              0.2767915804260243, 0.40825587900053273`, 0.9390742430775896], 
             UndirectedEdge[74, 219] -> 
             RGBColor[
              0.6359306602465759, 0.7123948141262615, 0.9664273391659474], 
             UndirectedEdge[45, 180] -> 
             RGBColor[
              0.33088455801292704`, 0.4597925392578639, 0.9423494940589101], 
             UndirectedEdge[187, 235] -> 
             RGBColor[
              0.792013758809907, 0.8376400126416226, 0.9798528182009743], 
             UndirectedEdge[114, 188] -> 
             RGBColor[0.297981899619691, 0.4286669180863, 0.9403491528141107],
              UndirectedEdge[81, 378] -> 
             RGBColor[
              0.21412094136701804`, 0.3423850638014996, 0.9355052428960813], 
             UndirectedEdge[19, 313] -> 
             RGBColor[
              0.27859623109563336`, 0.41015268127575305`, 0.9391770152634824],
              UndirectedEdge[195, 284] -> 
             RGBColor[
              0.24484639804506322`, 0.3746794668765958, 0.9372550121996561], 
             UndirectedEdge[64, 253] -> 
             RGBColor[
              0.3703380254209453, 0.4951899167144135, 0.9448185893961331], 
             UndirectedEdge[55, 122] -> 
             RGBColor[
              0.4248101196568824, 0.5423709068945195, 0.9482895030730654], 
             UndirectedEdge[99, 275] -> 
             RGBColor[
              0.9851141209349312, 0.987104803716967, 0.8512424005775606], 
             UndirectedEdge[118, 367] -> 
             RGBColor[
              0.21268815866311674`, 0.340879118336029, 0.9354236480407061], 
             UndirectedEdge[7, 96] -> 
             RGBColor[
              0.3381582412697068, 0.46529865529748227`, 0.9428420383243149], 
             UndirectedEdge[110, 115] -> 
             RGBColor[
              0.2470920216969208, 0.3770397597154611, 0.9373828971445268], 
             UndirectedEdge[68, 95] -> 
             RGBColor[
              0.2792515764807897, 0.4108414908268496, 0.9392143362136705], 
             UndirectedEdge[289, 302] -> 
             RGBColor[
              0.9425151711377706, 0.798674033657958, 0.3207346510653094], 
             UndirectedEdge[260, 321] -> 
             RGBColor[
              0.813370248803728, 0.8541302872991015, 0.9820328030897745], 
             UndirectedEdge[191, 220] -> 
             RGBColor[
              0.5771439386381384, 0.6670314281944398, 0.9602362550255482], 
             UndirectedEdge[169, 209] -> 
             RGBColor[
              0.23636572886417778`, 0.36576574586200267`, 0.9367720506358304],
              UndirectedEdge[32, 252] -> 
             RGBColor[
              0.2203092674216852, 0.34888938684748844`, 0.9358576589100864], 
             UndirectedEdge[75, 280] -> 
             RGBColor[
              0.24159566577055375`, 0.3712627411477558, 0.9370698878056503], 
             UndirectedEdge[14, 224] -> 
             RGBColor[
              0.9850092930497456, 0.9599506894449308, 0.4935654545583491], 
             UndirectedEdge[128, 311] -> 
             RGBColor[
              0.4227935959175786, 0.5388307190597109, 0.9486565824461703], 
             UndirectedEdge[132, 198] -> 
             RGBColor[
              0.8128559952710535, 0.8537811311091374, 0.9819675933041132], 
             UndirectedEdge[245, 388] -> 
             RGBColor[
              0.22663197894047044`, 0.3555349575367959, 0.9362177279774678], 
             UndirectedEdge[183, 273] -> 
             RGBColor[
              0.26718551324119244`, 0.3981592933294373, 0.9385271917623162], 
             UndirectedEdge[69, 220] -> 
             RGBColor[
              0.4818265682663484, 0.5902075400149862, 0.9523502989242535], 
             UndirectedEdge[37, 263] -> 
             RGBColor[
              0.25594156812645086`, 0.3863411941065481, 0.9378868657219579], 
             UndirectedEdge[235, 384] -> 
             RGBColor[
              0.7442607582282336, 0.800141428009943, 0.9751446149341176], 
             UndirectedEdge[132, 216] -> 
             RGBColor[
              0.7291619678468395, 0.7883461382089411, 0.9736397086151186], 
             UndirectedEdge[225, 380] -> 
             RGBColor[
              0.2612993849996442, 0.39197259934548456`, 0.9381919854667065], 
             UndirectedEdge[3, 371] -> 
             RGBColor[
              0.3210626317693298, 0.4491168451749269, 0.9418030466401561], 
             UndirectedEdge[269, 314] -> 
             RGBColor[
              0.9594354549874111, 0.9656217176549777, 0.7393357035372017], 
             UndirectedEdge[16, 206] -> 
             RGBColor[
              0.23671129027789278`, 0.36612895281767627`, 0.9367917298471292],
              UndirectedEdge[84, 256] -> 
             RGBColor[
              0.20211768989058865`, 0.32976888544967253`, 0.9348216754817178],
              UndirectedEdge[58, 348] -> 
             RGBColor[
              0.28088310771412667`, 0.4125563335981417, 0.9393072495037748], 
             UndirectedEdge[177, 360] -> 
             RGBColor[
              0.31615011179738517`, 0.4482550694974156, 0.9413657834565303], 
             UndirectedEdge[2, 106] -> 
             RGBColor[
              0.8617990685724151, 0.41558906148983843`, 0.4342244670461309], 
             UndirectedEdge[256, 317] -> 
             RGBColor[
              0.6079677143241806, 0.6722679099328412, 0.8705698500730703], 
             UndirectedEdge[87, 351] -> 
             RGBColor[
              0.2679416039473189, 0.3989539926004958, 0.9385702500094941], 
             UndirectedEdge[48, 103] -> 
             RGBColor[
              0.3850045259376993, 0.5078933023022759, 0.9457531258399835], 
             UndirectedEdge[256, 381] -> 
             RGBColor[
              0.6092276972658053, 0.6727889452592876, 0.8496886719990233], 
             UndirectedEdge[91, 226] -> 
             RGBColor[
              0.25062761976227643`, 0.38075589745201466`, 0.9375842442239002],
              UndirectedEdge[105, 113] -> 
             RGBColor[
              0.6069298774587211, 0.6884337835985022, 0.9640833346207096], 
             UndirectedEdge[223, 291] -> 
             RGBColor[
              0.5752793861727824, 0.6652475055073694, 0.9602742044215822], 
             UndirectedEdge[203, 348] -> 
             RGBColor[
              0.277176399167938, 0.4086603478972015, 0.9390961579356532], 
             UndirectedEdge[259, 367] -> 
             RGBColor[
              0.21516769270569408`, 0.3434852658263162, 0.935564853836289], 
             UndirectedEdge[188, 206] -> 
             RGBColor[
              0.2493239941811602, 0.37938570431162577`, 0.937510004675597], 
             UndirectedEdge[250, 289] -> 
             RGBColor[
              0.9429902625743816, 0.8090015716874366, 0.5405821025323335], 
             UndirectedEdge[194, 377] -> 
             RGBColor[
              0.40146722310948635`, 0.5221524631532592, 0.9468021143463783], 
             UndirectedEdge[83, 231] -> 
             RGBColor[
              0.3307828964588674, 0.4609235312385056, 0.9422983810248817], 
             UndirectedEdge[276, 376] -> 
             RGBColor[
              0.6019797217390458, 0.6854606658855094, 0.9632115739949887], 
             UndirectedEdge[83, 120] -> 
             RGBColor[
              0.45962999176153224`, 0.5694602774020465, 0.9513564039568587], 
             UndirectedEdge[40, 243] -> 
             RGBColor[
              0.3138420416346276, 0.4443722151984709, 0.9412876874810078], 
             UndirectedEdge[4, 392] -> 
             RGBColor[
              0.24007285485442642`, 0.3696621703231174, 0.9369831659767736], 
             UndirectedEdge[81, 329] -> 
             RGBColor[
              0.22742713619850993`, 0.35637071823087746`, 0.9362630110069835],
              UndirectedEdge[131, 363] -> 
             RGBColor[
              0.8824970556177689, 0.5558258692629264, 0.22348381958996794`], 
             UndirectedEdge[167, 192] -> 
             RGBColor[
              0.3140196057697616, 0.4440801406652496, 0.941315327256403], 
             UndirectedEdge[41, 327] -> 
             RGBColor[
              0.32970622489449014`, 0.4599966933120725, 0.9422295669958778], 
             UndirectedEdge[24, 382] -> 
             RGBColor[
              0.9004669733536322, 0.6409255971753784, 0.23865954159958375`], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.7015503538471387, 0.3171012233474507, 0.4309839177786776], 
             UndirectedEdge[90, 261] -> 
             RGBColor[
              0.4426270855649366, 0.538021058033776, 0.9524212377305169], 
             UndirectedEdge[146, 297] -> 
             RGBColor[
              0.7409851288378926, 0.7966845449876518, 0.9658863907552364], 
             UndirectedEdge[5, 291] -> 
             RGBColor[
              0.7689673032381015, 0.8196158140703518, 0.9775611053894065], 
             UndirectedEdge[229, 315] -> 
             RGBColor[
              0.24508519381312066`, 0.3749304563693503, 0.9372686112653803], 
             UndirectedEdge[241, 360] -> 
             RGBColor[
              0.3006768355928906, 0.4332086382716799, 0.9404400442858039], 
             UndirectedEdge[59, 237] -> 
             RGBColor[
              0.4562186120487096, 0.5661785780610258, 0.9512293666120685], 
             UndirectedEdge[257, 381] -> 
             RGBColor[
              0.8794537894858583, 0.44699417131630015`, 0.36726630280474326`],
              UndirectedEdge[270, 308] -> 
             RGBColor[
              0.2553377632908749, 0.38570655694091993`, 0.9378524799298211], 
             UndirectedEdge[317, 382] -> 
             RGBColor[
              0.9447039927210837, 0.8118308485146293, 0.5211250046258997], 
             UndirectedEdge[23, 89] -> 
             RGBColor[
              0.21600037669219402`, 0.3443604694913417, 0.9356122739574746], 
             UndirectedEdge[57, 327] -> 
             RGBColor[
              0.2958997785397042, 0.4274294644124098, 0.9401957587844365], 
             UndirectedEdge[347, 362] -> 
             RGBColor[
              0.3423545559019188, 0.4682989085041503, 0.9431326516737686], 
             UndirectedEdge[43, 293] -> 
             RGBColor[
              0.21933315592561953`, 0.34786343177608003`, 0.9358020708044131],
              UndirectedEdge[73, 208] -> 
             RGBColor[
              0.23810134733460236`, 0.3675899909189858, 0.9368708915401036], 
             UndirectedEdge[53, 129] -> 
             RGBColor[
              0.26346421560774436`, 0.39424797357278596`, 0.9383152693672578],
              UndirectedEdge[324, 383] -> 
             RGBColor[
              0.2800969902621915, 0.41173007431343256`, 0.9392624812778436], 
             UndirectedEdge[368, 399] -> 
             RGBColor[
              0.22383026101092823`, 0.35259017435367035`, 0.9360581742861507],
              UndirectedEdge[51, 136] -> 
             RGBColor[
              0.4957527510770341, 0.5993305404010079, 0.9540497614266502], 
             UndirectedEdge[145, 359] -> 
             RGBColor[
              0.24179608967805666`, 0.37147339938215107`, 0.9370813016506819],
              UndirectedEdge[222, 297] -> 
             RGBColor[
              0.7757829604608912, 0.8249349923236523, 0.9686258035292561], 
             UndirectedEdge[81, 209] -> 
             RGBColor[
              0.23587421810878062`, 0.36524913689449845`, 0.9367440598254355],
              UndirectedEdge[31, 345] -> 
             RGBColor[
              0.1925824038789099, 0.3197466952793466, 0.9342786550495443], 
             UndirectedEdge[155, 180] -> 
             RGBColor[
              0.33540782096983857`, 0.46454677541701367`, 0.9426070871927383],
              UndirectedEdge[4, 369] -> 
             RGBColor[
              0.2448252232373639, 0.37465721081114345`, 0.937253806325683], 
             UndirectedEdge[102, 289] -> 
             RGBColor[
              0.8454491263323318, 0.30908852374737794`, 0.18953984358049555`],
              UndirectedEdge[70, 103] -> 
             RGBColor[
              0.3111881460301813, 0.44109703206764383`, 0.9411543384931023], 
             UndirectedEdge[177, 375] -> 
             RGBColor[
              0.28837692064883436`, 0.4192158430001391, 0.939778570045845], 
             UndirectedEdge[171, 253] -> 
             RGBColor[
              0.30746418261270597`, 0.43744644735605664`, 0.9409326149067666],
              UndirectedEdge[150, 241] -> 
             RGBColor[
              0.2807813627744614, 0.41244939321555174`, 0.939301455279979], 
             UndirectedEdge[24, 317] -> 
             RGBColor[
              0.946390043794504, 0.8194868126517976, 0.5225318869704552], 
             UndirectedEdge[80, 110] -> 
             RGBColor[
              0.29499717102305234`, 0.4250177053104399, 0.9401979264655129], 
             UndirectedEdge[176, 341] -> 
             RGBColor[
              0.21870360025711671`, 0.3472017288523488, 0.9357662185404361], 
             UndirectedEdge[154, 192] -> 
             RGBColor[
              0.3873238866966642, 0.5099022160172301, 0.9459009134566145], 
             UndirectedEdge[121, 322] -> 
             RGBColor[
              0.5308061338547281, 0.6299713578639174, 0.9562061497454312], 
             UndirectedEdge[268, 381] -> 
             RGBColor[
              0.8759283430150683, 0.4198960448813137, 0.3638903312828924], 
             UndirectedEdge[76, 104] -> 
             RGBColor[
              0.8759209864283702, 0.49974066253069205`, 0.2169421480887627], 
             UndirectedEdge[91, 186] -> 
             RGBColor[
              0.2555444422624831, 0.38592378964428387`, 0.9378642499915], 
             UndirectedEdge[216, 357] -> 
             RGBColor[
              0.6673958385373104, 0.7400939685523675, 0.9674834380828405], 
             UndirectedEdge[210, 236] -> 
             RGBColor[
              0.27522295505597283`, 0.4066071542800159, 0.9389849121833385], 
             UndirectedEdge[26, 173] -> 
             RGBColor[
              0.34074023236907375`, 0.46188861660318076`, 0.9432249850370102],
              UndirectedEdge[10, 374] -> 
             RGBColor[
              0.31901480157328777`, 0.4477183185888486, 0.9416588227642095], 
             UndirectedEdge[289, 340] -> 
             RGBColor[
              0.9457657182249508, 0.8088519239369327, 0.40028051736176995`], 
             UndirectedEdge[65, 168] -> 
             RGBColor[
              0.592741338058181, 0.6798274166038522, 0.9613729899467283], 
             UndirectedEdge[40, 203] -> 
             RGBColor[
              0.31535485342024205`, 0.44596227630295887`, 0.941373839874194], 
             UndirectedEdge[167, 201] -> 
             RGBColor[
              0.27998787707886075`, 0.41161538943957654`, 0.9392562674434715],
              UndirectedEdge[41, 57] -> 
             RGBColor[
              0.3070138697292798, 0.4370559315903547, 0.9409039388472313], 
             UndirectedEdge[214, 363] -> 
             RGBColor[
              0.9029326936897176, 0.6415283064419719, 0.4421102953030337], 
             UndirectedEdge[22, 189] -> 
             RGBColor[
              0.29643257003583556`, 0.4288998043911114, 0.9401927683796281], 
             UndirectedEdge[41, 96] -> 
             RGBColor[
              0.3138659022147775, 0.44425785217656466`, 0.9412941519606068], 
             UndirectedEdge[31, 197] -> 
             RGBColor[
              0.5859844235922751, 0.6497599697422292, 0.884913356826519], 
             UndirectedEdge[275, 281] -> 
             RGBColor[
              0.8120473445077586, 0.8515608457173255, 0.8723741943555676], 
             UndirectedEdge[89, 353] -> 
             RGBColor[
              0.21448123699978983`, 0.34276375735560527`, 0.9355257611993579],
              UndirectedEdge[324, 375] -> 
             RGBColor[
              0.267401497471214, 0.3983863064493811, 0.938539491744696], 
             UndirectedEdge[5, 174] -> 
             RGBColor[
              0.7850242052221269, 0.8321595879372474, 0.979161507318894], 
             UndirectedEdge[36, 314] -> 
             RGBColor[
              0.7227446385125958, 0.7823089126955356, 0.9740580070832467], 
             UndirectedEdge[220, 357] -> 
             RGBColor[
              0.5755623088477795, 0.6657958469813797, 0.960078612949216], 
             UndirectedEdge[291, 342] -> 
             RGBColor[
              0.6499248897969461, 0.7258480880910823, 0.9661505719023658], 
             UndirectedEdge[21, 159] -> 
             RGBColor[
              0.3221758681761928, 0.45347427680941704`, 0.9417497393246208], 
             UndirectedEdge[220, 394] -> 
             RGBColor[
              0.4171512331180811, 0.5351366490894776, 0.9479674097431279], 
             UndirectedEdge[129, 249] -> 
             RGBColor[
              0.25362687609654, 0.3839083060231606, 0.9377550474351345], 
             UndirectedEdge[37, 58] -> 
             RGBColor[
              0.2743052593933725, 0.40564259795335733`, 0.9389326507729624], 
             UndirectedEdge[118, 259] -> 
             RGBColor[
              0.20854115618205327`, 0.33652035579328765`, 0.9351874823843499],
              UndirectedEdge[201, 243] -> 
             RGBColor[
              0.2823991194396881, 0.4141497580424017, 0.9393935841288071], 
             UndirectedEdge[40, 110] -> 
             RGBColor[
              0.29744503748137785`, 0.4271379242032959, 0.940353902351674], 
             UndirectedEdge[35, 278] -> 
             RGBColor[
              0.26672833715189703`, 0.3976787722729497, 0.9385011562603622], 
             UndirectedEdge[164, 315] -> 
             RGBColor[
              0.2429063670041037, 0.37264037124747484`, 0.9371445303018922], 
             UndirectedEdge[81, 304] -> 
             RGBColor[
              0.21940694053557647`, 0.34794098407935925`, 0.9358062727287957],
              UndirectedEdge[12, 299] -> 
             RGBColor[
              0.21628284341415968`, 0.3446573599255522, 0.9356283600194184], 
             UndirectedEdge[203, 258] -> 
             RGBColor[
              0.2721654186176039, 0.4033934896242831, 0.9388107900063931], 
             UndirectedEdge[250, 276] -> 
             RGBColor[
              0.8768966809261312, 0.9030925119563854, 0.9110185744810039], 
             UndirectedEdge[124, 238] -> 
             RGBColor[
              0.22624718755874168`, 0.35513051739741625`, 0.9361958146775262],
              UndirectedEdge[96, 154] -> 
             RGBColor[
              0.3585347588123511, 0.48294777063937044`, 0.9441404120038852], 
             UndirectedEdge[126, 238] -> 
             RGBColor[
              0.2206324276302094, 0.349229048716188, 0.9358760624058893], 
             UndirectedEdge[103, 108] -> 
             RGBColor[
              0.3560676178251626, 0.48282960690648735`, 0.9439092916429558], 
             UndirectedEdge[122, 210] -> 
             RGBColor[
              0.3730056479605837, 0.4966847962832106, 0.9450184340224643], 
             UndirectedEdge[108, 234] -> 
             RGBColor[
              0.3531542361556598, 0.4803061821351844, 0.9437236535391773], 
             UndirectedEdge[222, 361] -> 
             RGBColor[
              0.48027671073484357`, 0.5862967431545993, 0.9529611966752556], 
             UndirectedEdge[12, 274] -> 
             RGBColor[
              0.2245824786939262, 0.35338080283185697`, 0.936101011970391], 
             UndirectedEdge[141, 219] -> 
             RGBColor[
              0.4036258957264883, 0.5240221968760659, 0.9469396630566943], 
             UndirectedEdge[179, 344] -> 
             RGBColor[
              0.29513590341832135`, 0.4264382934400302, 0.9401591514378], 
             UndirectedEdge[14, 230] -> 
             RGBColor[
              0.9816071552805266, 0.9484744798894191, 0.4803487917647419], 
             UndirectedEdge[12, 118] -> 
             RGBColor[
              0.21224930323971947`, 0.34041785346099757`, 0.9353986558735721],
              UndirectedEdge[44, 49] -> 
             RGBColor[
              0.2768464709137847, 0.4083135723834269, 0.9390773690096643], 
             UndirectedEdge[224, 247] -> 
             RGBColor[
              0.9413345239687156, 0.7992928035075443, 0.30199213626103877`], 
             UndirectedEdge[161, 222] -> 
             RGBColor[
              0.5181817733764011, 0.6191282032508729, 0.9553764737486448], 
             UndirectedEdge[148, 168] -> 
             RGBColor[
              0.6470192572483401, 0.7238926765948177, 0.9656459465719469], 
             UndirectedEdge[219, 323] -> 
             RGBColor[
              0.6386990444191253, 0.7146022485196659, 0.9666913901196909], 
             UndirectedEdge[309, 334] -> 
             RGBColor[
              0.26609474286190404`, 0.39701282450196873`, 0.9384650740028659],
              UndirectedEdge[170, 326] -> 
             RGBColor[
              0.39217993552288943`, 0.5141082814383957, 0.9462103365937862], 
             UndirectedEdge[239, 354] -> 
             RGBColor[
              0.3021441775416652, 0.43344512169287874`, 0.940571418461126], 
             UndirectedEdge[11, 221] -> 
             RGBColor[
              0.9226607888866434, 0.8373956409938654, 0.6248416927368453], 
             UndirectedEdge[47, 322] -> 
             RGBColor[
              0.47115402237552717`, 0.5810156228019311, 0.9516558567994469], 
             UndirectedEdge[155, 271] -> 
             RGBColor[
              0.305666751429035, 0.4386055145162801, 0.9407186413492236], 
             UndirectedEdge[106, 363] -> 
             RGBColor[
              0.8911732680650847, 0.632758146065413, 0.46201593553613163`], 
             UndirectedEdge[245, 378] -> 
             RGBColor[
              0.2192126419789341, 0.3477367639770881, 0.9357952077134337], 
             UndirectedEdge[155, 326] -> 
             RGBColor[
              0.32196792775833594`, 0.4529058154258842, 0.9417507090817323], 
             UndirectedEdge[10, 39] -> 
             RGBColor[
              0.3175089705748625, 0.446135594734304, 0.9415730679165266], 
             UndirectedEdge[25, 382] -> 
             RGBColor[
              0.8654010507132059, 0.4613702453208517, 0.2086036362243469], 
             UndirectedEdge[177, 383] -> 
             RGBColor[
              0.3010724134398118, 0.43255961086419054`, 0.9405015595789926], 
             UndirectedEdge[177, 296] -> 
             RGBColor[
              0.3117150207517371, 0.4437456659293011, 0.9411076403210801], 
             UndirectedEdge[103, 143] -> 
             RGBColor[
              0.48460520194471113`, 0.589510492500073, 0.9533849292372562], 
             UndirectedEdge[84, 317] -> 
             RGBColor[
              0.5847770387283635, 0.6478930395078799, 0.8692491754054186], 
             UndirectedEdge[50, 328] -> 
             RGBColor[
              0.38179240870061343`, 0.505088601337379, 0.9455546766979714], 
             UndirectedEdge[332, 385] -> 
             RGBColor[
              0.5513213263478973, 0.6466265153287621, 0.9578211808481198], 
             UndirectedEdge[242, 257] -> 
             RGBColor[
              0.8545203931124529, 0.3545092798166029, 0.19724068973481296`], 
             UndirectedEdge[214, 217] -> 
             RGBColor[
              0.8764748109063158, 0.44677531003196125`, 0.4171114949873367], 
             UndirectedEdge[51, 59] -> 
             RGBColor[
              0.3534707906164537, 0.48058036569863427`, 0.9437438241095009], 
             UndirectedEdge[66, 131] -> 
             RGBColor[
              0.9476245332536402, 0.8250818486193503, 0.3026198784181737], 
             UndirectedEdge[66, 98] -> 
             RGBColor[
              0.9751764945744315, 0.9279266287426179, 0.3580657982576656], 
             UndirectedEdge[70, 346] -> 
             RGBColor[
              0.3114210735342079, 0.4412987821643549, 0.9411691804276892], 
             UndirectedEdge[151, 253] -> 
             RGBColor[
              0.3287756481732377, 0.4591906745282696, 0.9421702714700763], 
             UndirectedEdge[384, 398] -> 
             RGBColor[
              0.8439266207114591, 0.8788704640005567, 0.9814905615415767], 
             UndirectedEdge[123, 218] -> 
             RGBColor[
              0.9421799541639146, 0.955737423109728, 0.959839004250153], 
             UndirectedEdge[169, 280] -> 
             RGBColor[
              0.229855838803546, 0.3589234386574095, 0.9364013220273968], 
             UndirectedEdge[71, 109] -> 
             RGBColor[
              0.932608231427341, 0.9459491066410988, 0.8675350166916449], 
             UndirectedEdge[166, 302] -> 
             RGBColor[
              0.878938413983703, 0.4505093722750355, 0.24925952171369992`], 
             UndirectedEdge[89, 163] -> 
             RGBColor[
              0.23177803755773202`, 0.36094379142249916`, 0.9365107884028094],
              UndirectedEdge[102, 340] -> 
             RGBColor[
              0.8774573996886179, 0.42925415473046985`, 0.29879672657536593`],
              UndirectedEdge[380, 390] -> 
             RGBColor[
              0.2658949696207651, 0.39680285015917666`, 0.9384536972123212], 
             UndirectedEdge[172, 387] -> 
             RGBColor[
              0.29749670616801155`, 0.43001827893615596`, 0.9402533693581072],
              UndirectedEdge[61, 298] -> 
             RGBColor[
              0.9083880182689977, 0.925110369261773, 0.7500707788698681], 
             UndirectedEdge[10, 216] -> 
             RGBColor[
              0.5105137254220357, 0.6107590812291837, 0.9554696590225349], 
             UndirectedEdge[209, 229] -> 
             RGBColor[
              0.24946457527559712`, 0.37953346395523513`, 0.937518010560954], 
             UndirectedEdge[39, 119] -> 
             RGBColor[
              0.2567952159774935, 0.3872384321223937, 0.9379354797042159], 
             UndirectedEdge[33, 261] -> 
             RGBColor[
              0.17919487812109408`, 0.3056755568897237, 0.9335162552627061], 
             UndirectedEdge[102, 213] -> 
             RGBColor[
              0.8498540615214377, 0.3277957878288924, 0.19314846541195224`], 
             UndirectedEdge[155, 335] -> 
             RGBColor[
              0.29253189959404885`, 0.42479995244000324`, 0.9399706309684931],
              UndirectedEdge[76, 317] -> 
             RGBColor[
              0.8948386450291879, 0.5713580765029691, 0.3967240172890074], 
             UndirectedEdge[19, 179] -> 
             RGBColor[
              0.2720136332383074, 0.4032339535668936, 0.9388021460535885], 
             UndirectedEdge[48, 83] -> 
             RGBColor[
              0.38916228198081126`, 0.5114945416119245, 0.9460180543784913], 
             UndirectedEdge[288, 355] -> 
             RGBColor[
              0.2379735788706035, 0.36745569816233453`, 0.9368636153150954], 
             UndirectedEdge[7, 192] -> 
             RGBColor[
              0.36694736915401993`, 0.4922531006753419, 0.9446025397770442], 
             UndirectedEdge[341, 393] -> 
             RGBColor[
              0.2222018557461406, 0.35087861717352153`, 0.9359654390153307], 
             UndirectedEdge[244, 270] -> 
             RGBColor[
              0.2548116613836774, 0.3851535904796679, 0.9378225192045042], 
             UndirectedEdge[121, 265] -> 
             RGBColor[
              0.5725454192775208, 0.6638571901035208, 0.9594920191899539], 
             UndirectedEdge[156, 363] -> 
             RGBColor[
              0.6369948421709581, 0.41665066116313826`, 0.44929342650794835`],
              UndirectedEdge[133, 280] -> 
             RGBColor[
              0.26813571605602704`, 0.3991580167341666, 0.938581304406922], 
             UndirectedEdge[44, 362] -> 
             RGBColor[
              0.35130778497678417`, 0.477709319929344, 0.9436425248244668], 
             UndirectedEdge[116, 147] -> 
             RGBColor[
              0.35047958711339033`, 0.47576981650030403`, 0.9436345020558807],
              UndirectedEdge[83, 196] -> 
             RGBColor[
              0.32540289254677246`, 0.4552688060149441, 0.9419919977610904], 
             UndirectedEdge[109, 233] -> 
             RGBColor[
              0.8763376383850133, 0.4207403837399031, 0.35873443118039927`], 
             UndirectedEdge[19, 125] -> 
             RGBColor[
              0.27618503388558474`, 0.4076183601292589, 0.9390397011494167], 
             UndirectedEdge[26, 160] -> 
             RGBColor[
              0.7046893390865665, 0.34122883940979487`, 0.4339898135889303], 
             UndirectedEdge[224, 302] -> 
             RGBColor[
              0.981469271203516, 0.9491536419267372, 0.38251204717050646`], 
             UndirectedEdge[58, 60] -> 
             RGBColor[
              0.3281696676840872, 0.4577472453898289, 0.942165291884663], 
             UndirectedEdge[165, 332] -> 
             RGBColor[
              0.5299851907540822, 0.6293048792717479, 0.9561415220973347], 
             UndirectedEdge[43, 252] -> 
             RGBColor[
              0.2258841865651551, 0.3547489803375645, 0.9361751423079533], 
             UndirectedEdge[292, 304] -> 
             RGBColor[
              0.21505855653612305`, 0.3433705567924642, 0.9355586386928844], 
             UndirectedEdge[63, 257] -> 
             RGBColor[
              0.8679251307385805, 0.4071424071541793, 0.2106939530351818], 
             UndirectedEdge[94, 355] -> 
             RGBColor[
              0.2455225673247446, 0.37539016366114936`, 0.937293519039831], 
             UndirectedEdge[223, 290] -> 
             RGBColor[
              0.4296004547734099, 0.5464997120753861, 0.9486003596365518], 
             UndirectedEdge[141, 150] -> 
             RGBColor[
              0.3153323622893313, 0.4440199894984804, 0.9414428101102743], 
             UndirectedEdge[131, 306] -> 
             RGBColor[
              0.9464211476308863, 0.8210225463454206, 0.2979449525140816], 
             UndirectedEdge[151, 182] -> 
             RGBColor[
              0.301964914813191, 0.43405917516616493`, 0.9405318273574531], 
             UndirectedEdge[87, 201] -> 
             RGBColor[
              0.2832825017728496, 0.4150782488842294, 0.9394438914458336], 
             UndirectedEdge[72, 379] -> 
             RGBColor[
              0.22434193474233927`, 0.3531279758873717, 0.9360873133482011], 
             UndirectedEdge[23, 378] -> 
             RGBColor[
              0.21097218176330165`, 0.339075517815104, 0.9353259256948219], 
             UndirectedEdge[116, 322] -> 
             RGBColor[
              0.46231873384021377`, 0.5733629399471565, 0.9510928800267155], 
             UndirectedEdge[90, 175] -> 
             RGBColor[
              0.44236897151936794`, 0.5377497638065076, 0.9524065385174674], 
             UndirectedEdge[348, 369] -> 
             RGBColor[
              0.2602045857942335, 0.3908218959663191, 0.9381296382715687], 
             UndirectedEdge[134, 243] -> 
             RGBColor[
              0.2613494095308073, 0.3920251782994754, 0.9381948342897516], 
             UndirectedEdge[211, 372] -> 
             RGBColor[
              0.257077351430105, 0.3875349743715093, 0.9379515469008601], 
             UndirectedEdge[73, 188] -> 
             RGBColor[
              0.2551009475473486, 0.3854576485794885, 0.9378389936235647], 
             UndirectedEdge[55, 228] -> 
             RGBColor[
              0.38569491533937006`, 0.508491282902023, 0.9457971168421706], 
             UndirectedEdge[260, 384] -> 
             RGBColor[
              0.7786909364224193, 0.827038544894287, 0.9785762933282055], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.6353748988917614, 0.714796015346257, 0.9644853457536787], 
             UndirectedEdge[153, 203] -> 
             RGBColor[
              0.3044141682214503, 0.43648600467859244`, 0.9406767090877951], 
             UndirectedEdge[65, 148] -> 
             RGBColor[
              0.5696101053080527, 0.6614741699887192, 0.9592609405218679], 
             UndirectedEdge[42, 366] -> 
             RGBColor[
              0.9167531541973288, 0.7967074998480634, 0.6163680259642358], 
             UndirectedEdge[48, 313] -> 
             RGBColor[
              0.35412562406909687`, 0.4787494368539953, 0.9438733561702934], 
             UndirectedEdge[166, 213] -> 
             RGBColor[
              0.8535021072079764, 0.35583626555944115`, 0.1966418380812599], 
             UndirectedEdge[11, 78] -> 
             RGBColor[
              0.8690501870084697, 0.4598450027239643, 0.2108935679622813], 
             UndirectedEdge[228, 348] -> 
             RGBColor[
              0.31540619999020275`, 0.44337706024281187`, 0.9414733974605265],
              UndirectedEdge[199, 336] -> 
             RGBColor[
              0.2184046627263886, 0.34688752655381927`, 0.9357491944902996], 
             UndirectedEdge[249, 309] -> 
             RGBColor[
              0.2701798653173872, 0.40130654721440506`, 0.9386977156833087], 
             UndirectedEdge[190, 273] -> 
             RGBColor[
              0.2582701914773965, 0.38878872489163985`, 0.9380194773769047], 
             UndirectedEdge[298, 314] -> 
             RGBColor[
              0.8746210569271528, 0.9028631061103101, 0.9879033312647884], 
             UndirectedEdge[7, 385] -> 
             RGBColor[
              0.4824130197414953, 0.5889482597885108, 0.9528759593947184], 
             UndirectedEdge[27, 194] -> 
             RGBColor[
              0.3427358884343137, 0.47023486345331306`, 0.943098158625497], 
             UndirectedEdge[39, 128] -> 
             RGBColor[
              0.2996526087721707, 0.4306693116276521, 0.9404352763322198], 
             UndirectedEdge[116, 265] -> 
             RGBColor[
              0.5040580192630065, 0.6072487721867599, 0.9543787494712381], 
             UndirectedEdge[231, 313] -> 
             RGBColor[
              0.295746238547153, 0.4281784264805763, 0.9401536828166841], 
             UndirectedEdge[96, 284] -> 
             RGBColor[
              0.2654547891651977, 0.3963401925913225, 0.9384286295865651], 
             UndirectedEdge[279, 300] -> 
             RGBColor[
              0.9178232089422185, 0.7078044246386144, 0.2525247911559355], 
             UndirectedEdge[22, 190] -> 
             RGBColor[
              0.26671069132338054`, 0.3976602253883686, 0.938500151356533], 
             UndirectedEdge[24, 207] -> 
             RGBColor[
              0.9210044213449331, 0.723918476562367, 0.2552656037171254], 
             UndirectedEdge[315, 329] -> 
             RGBColor[
              0.2392065257950246, 0.3687516035532512, 0.9369338298184597], 
             UndirectedEdge[239, 335] -> 
             RGBColor[
              0.3025165492814234, 0.4338365080010965, 0.9405926244808307], 
             UndirectedEdge[142, 300] -> 
             RGBColor[
              0.8443882416408665, 0.30906726518558403`, 0.18884241358771037`],
              UndirectedEdge[13, 88] -> 
             RGBColor[
              0.9770469480723544, 0.9813851840644524, 0.8781922259657269], 
             UndirectedEdge[18, 302] -> 
             RGBColor[
              0.9662417999648014, 0.9637001584466507, 0.6913546401282936], 
             UndirectedEdge[148, 251] -> 
             RGBColor[
              0.723101933884062, 0.7833478892534567, 0.9732241552199159], 
             UndirectedEdge[90, 257] -> 
             RGBColor[
              0.7836733803233185, 0.3732161676317655, 0.4366252329335806], 
             UndirectedEdge[134, 348] -> 
             RGBColor[
              0.24864104476606846`, 0.3786678811748705, 0.9374711117167406], 
             UndirectedEdge[158, 322] -> 
             RGBColor[
              0.5057660137173806, 0.6096426602918618, 0.9542348997632368], 
             UndirectedEdge[40, 385] -> 
             RGBColor[
              0.4573665882056296, 0.5672542996623962, 0.9512800229249427], 
             UndirectedEdge[228, 385] -> 
             RGBColor[
              0.4716391113259436, 0.5796164418313421, 0.9521894554774726], 
             UndirectedEdge[175, 214] -> 
             RGBColor[
              0.5813526175939636, 0.6464089921975442, 0.9229266959429565], 
             UndirectedEdge[7, 41] -> 
             RGBColor[
              0.36511265513899505`, 0.490663963610935, 0.9444856334223808], 
             UndirectedEdge[176, 379] -> 
             RGBColor[
              0.2183904240990045, 0.34687256085365753`, 0.9357483836215341], 
             UndirectedEdge[259, 336] -> 
             RGBColor[
              0.21101362554134806`, 0.339119077853518, 0.9353282858566712], 
             UndirectedEdge[213, 340] -> 
             RGBColor[
              0.9523731210086097, 0.8369128200592044, 0.40569345010895497`], 
             UndirectedEdge[55, 165] -> 
             RGBColor[
              0.4681407137086776, 0.5777449578588358, 0.9516464016172608], 
             UndirectedEdge[108, 231] -> 
             RGBColor[
              0.3381266013166869, 0.4672842792810106, 0.9427663154046388], 
             UndirectedEdge[38, 230] -> 
             RGBColor[
              0.9673242221990019, 0.9014390702190636, 0.3275612028563362], 
             UndirectedEdge[39, 316] -> 
             RGBColor[
              0.26368578568270973`, 0.3944808577699287, 0.9383278874552436], 
             UndirectedEdge[85, 167] -> 
             RGBColor[
              0.2624284668147709, 0.39315933592110447`, 0.9382562850057511], 
             UndirectedEdge[28, 328] -> 
             RGBColor[
              0.2988631492240676, 0.4313905924329009, 0.9403335261361829], 
             UndirectedEdge[79, 120] -> 
             RGBColor[
              0.5785921359057922, 0.6687661870638313, 0.9599680388727843], 
             UndirectedEdge[130, 347] -> 
             RGBColor[
              0.34522783768479254`, 0.47078760076913406`, 0.9433157346482299],
              UndirectedEdge[77, 160] -> 
             RGBColor[
              0.829440089196826, 0.4406478709499005, 0.44510297379513875`], 
             UndirectedEdge[108, 179] -> 
             RGBColor[
              0.3186061180992342, 0.4467670137493473, 0.9416546527633719], 
             UndirectedEdge[318, 373] -> 
             RGBColor[
              0.2370696348066011, 0.3665055956377041, 0.9368121370379159], 
             UndirectedEdge[48, 331] -> 
             RGBColor[
              0.43876768248625253`, 0.5544602462898143, 0.9491788666343646], 
             UndirectedEdge[222, 312] -> 
             RGBColor[
              0.5339420376563727, 0.632517225840949, 0.9564530195798908], 
             UndirectedEdge[292, 353] -> 
             RGBColor[
              0.2106991637542155, 0.3387885585772128, 0.9353103777230984], 
             UndirectedEdge[175, 204] -> 
             RGBColor[
              0.17892957074057536`, 0.30539670201133906`, 0.9335011463998728],
              UndirectedEdge[198, 340] -> 
             RGBColor[
              0.9101338786876096, 0.9267923912389714, 0.7737391772833939], 
             UndirectedEdge[14, 207] -> 
             RGBColor[
              0.9671064480201461, 0.8947970383510977, 0.44882285376347564`], 
             UndirectedEdge[45, 271] -> 
             RGBColor[
              0.30114348847212347`, 0.43385127835713033`, 0.9404610482153953],
              UndirectedEdge[112, 183] -> 
             RGBColor[
              0.2939274002864909, 0.42440137973285763`, 0.9401184016257302], 
             UndirectedEdge[85, 139] -> 
             RGBColor[
              0.2262390695271757, 0.3551219848315275, 0.9361953523676381], 
             UndirectedEdge[45, 97] -> 
             RGBColor[
              0.36889177075057233`, 0.4927124766331557, 0.9447712800460943], 
             UndirectedEdge[130, 181] -> 
             RGBColor[
              0.48885894126290724`, 0.5947515646860737, 0.9532258537292853], 
             UndirectedEdge[63, 90] -> 
             RGBColor[
              0.8321834271804781, 0.8209894828739578, 0.632414864387591], 
             UndirectedEdge[114, 361] -> 
             RGBColor[
              0.342252200873233, 0.470863387125772, 0.9430289854912723], 
             UndirectedEdge[75, 209] -> 
             RGBColor[
              0.24810555583118551`, 0.37810504835234904`, 0.9374406164140838],
              UndirectedEdge[42, 276] -> 
             RGBColor[
              0.8488960037945177, 0.8827904862944987, 0.9853329329150746], 
             UndirectedEdge[205, 358] -> 
             RGBColor[
              0.9819225924478814, 0.9489876509677333, 0.5302516309431803], 
             UndirectedEdge[76, 358] -> 
             RGBColor[
              0.8874885148347537, 0.5431153483189393, 0.239200479315374], 
             UndirectedEdge[90, 142] -> 
             RGBColor[
              0.7829912495158903, 0.3679730113342469, 0.4359720237020308], 
             UndirectedEdge[152, 381] -> 
             RGBColor[
              0.588381597564026, 0.6508783727536576, 0.8485015174600479], 
             UndirectedEdge[86, 309] -> 
             RGBColor[
              0.28566340206902835`, 0.417580726053311, 0.9395794801954747], 
             UndirectedEdge[104, 358] -> 
             RGBColor[
              0.9512253799690775, 0.8406018507565884, 0.299039239235954], 
             UndirectedEdge[16, 369] -> 
             RGBColor[
              0.24965722981087085`, 0.3797359560868109, 0.9375289819517311], 
             UndirectedEdge[278, 337] -> 
             RGBColor[
              0.26857947792754067`, 0.39962443859725516`, 0.9386065759890179],
              UndirectedEdge[100, 350] -> 
             RGBColor[
              0.4046784181179114, 0.524933838870203, 0.9470067288527668], 
             UndirectedEdge[90, 202] -> 
             RGBColor[
              0.8061616844201898, 0.5460711273580099, 0.45816005833365137`], 
             UndirectedEdge[126, 367] -> 
             RGBColor[
              0.21567822148491766`, 0.34402186394267437`, 0.935593927695006], 
             UndirectedEdge[278, 327] -> 
             RGBColor[
              0.28550387867049365`, 0.4165027145117478, 0.9396037276662406], 
             UndirectedEdge[10, 200] -> 
             RGBColor[
              0.31629276558560215`, 0.4448572861787412, 0.9415038068416022], 
             UndirectedEdge[149, 299] -> 
             RGBColor[
              0.21717366869177715`, 0.345593673773913, 0.9356790912011209], 
             UndirectedEdge[57, 284] -> 
             RGBColor[
              0.2586027566797, 0.38913827200511253`, 0.9380384164731898], 
             UndirectedEdge[125, 313] -> 
             RGBColor[
              0.2803971559769777, 0.4120455675112783, 0.9392795752712453], 
             UndirectedEdge[125, 196] -> 
             RGBColor[
              0.2879550374250095, 0.4199893801105207, 0.9397099854388271], 
             UndirectedEdge[21, 210] -> 
             RGBColor[
              0.30642042589023155`, 0.43901202359644165`, 0.9407756825511414],
              UndirectedEdge[186, 374] -> 
             RGBColor[
              0.2622856992899031, 0.3930092782004845, 0.9382481546064155], 
             UndirectedEdge[6, 74] -> 
             RGBColor[
              0.909010509687477, 0.9256078266033538, 0.7502192883025007], 
             UndirectedEdge[7, 312] -> 
             RGBColor[
              0.42618108450073044`, 0.5432966415402436, 0.9484491754681994], 
             UndirectedEdge[238, 299] -> 
             RGBColor[
              0.22167590498284873`, 0.3503258095740973, 0.9359354868974357], 
             UndirectedEdge[155, 239] -> 
             RGBColor[
              0.3145302695292589, 0.4464636896954298, 0.9412767880762385], 
             UndirectedEdge[108, 331] -> 
             RGBColor[
              0.40983077437371584`, 0.5293965508940257, 0.9473350324373369], 
             UndirectedEdge[55, 87] -> 
             RGBColor[
              0.34683568506465234`, 0.47311300029375225`, 0.9433840322411374],
              UndirectedEdge[186, 288] -> 
             RGBColor[
              0.2467468316416792, 0.3766769430810886, 0.9373632390815438], 
             UndirectedEdge[178, 371] -> 
             RGBColor[
              0.25801702472850174`, 0.38852263058685255`, 0.9380050599050818],
              UndirectedEdge[212, 238] -> 
             RGBColor[
              0.22006014114382055`, 0.3486275393339343, 0.9358434715371114], 
             UndirectedEdge[292, 329] -> 
             RGBColor[
              0.22307875219905648`, 0.35180029094398246`, 0.9360153769710722],
              UndirectedEdge[268, 338] -> 
             RGBColor[
              0.876308791336653, 0.41948191149276653`, 0.31604631431093705`], 
             UndirectedEdge[68, 309] -> 
             RGBColor[
              0.27375753584035556`, 0.40506690577145743`, 0.9389014587269024],
              UndirectedEdge[129, 309] -> 
             RGBColor[
              0.25423745991444247`, 0.38455006832902616`, 0.9377898192802863],
              UndirectedEdge[137, 330] -> 
             RGBColor[
              0.22316402213431713`, 0.35188991505236755`, 0.9360202329677398],
              UndirectedEdge[111, 400] -> 
             RGBColor[
              0.631844529693345, 0.5164916201579837, 0.581343351224306], 
             UndirectedEdge[62, 370] -> 
             RGBColor[
              0.5051424414592518, 0.5868980307983699, 0.9586362110924191], 
             UndirectedEdge[163, 280] -> 
             RGBColor[
              0.24199322930997053`, 0.37168060563466715`, 0.9370925284610774],
              UndirectedEdge[316, 383] -> 
             RGBColor[
              0.2672579164630078, 0.3982353937061947, 0.9385313150186878], 
             UndirectedEdge[307, 314] -> 
             RGBColor[
              0.9555259778682477, 0.9659228619523936, 0.9435306567958934], 
             UndirectedEdge[126, 259] -> 
             RGBColor[
              0.2115312190038542, 0.33966310139993294`, 0.93535776203865], 
             UndirectedEdge[44, 372] -> 
             RGBColor[
              0.27471702429732014`, 0.4060753889748091, 0.9389561001750906], 
             UndirectedEdge[202, 279] -> 
             RGBColor[
              0.8861096305516358, 0.5634464075388576, 0.22609833972846935`], 
             UndirectedEdge[148, 312] -> 
             RGBColor[
              0.5434225996528742, 0.6402139731641597, 0.9571993641486982], 
             UndirectedEdge[109, 358] -> 
             RGBColor[
              0.9813365611926588, 0.9487453119833825, 0.5399636854424916], 
             UndirectedEdge[142, 275] -> 
             RGBColor[
              0.8784228625837636, 0.4416067788699862, 0.3723935475171762], 
             UndirectedEdge[296, 375] -> 
             RGBColor[
              0.2781834406546093, 0.40971881234981117`, 0.9391535074585348], 
             UndirectedEdge[92, 195] -> 
             RGBColor[
              0.26667927398787117`, 0.3976272037767742, 0.9384983621857534], 
             UndirectedEdge[178, 248] -> 
             RGBColor[
              0.230098166399185, 0.35917814032488304`, 0.9364151222254768], 
             UndirectedEdge[41, 222] -> 
             RGBColor[
              0.4728736082946373, 0.5798845479116403, 0.9524894775340721], 
             UndirectedEdge[154, 356] -> 
             RGBColor[
              0.4742682171286211, 0.5834424825573183, 0.951929030274608], 
             UndirectedEdge[70, 133] -> 
             RGBColor[
              0.28753417910083867`, 0.4195470313278583, 0.9396860181798696], 
             UndirectedEdge[7, 80] -> 
             RGBColor[
              0.36191069619973304`, 0.48789058771288196`, 0.9442816074301521],
              UndirectedEdge[152, 261] -> 
             RGBColor[
              0.18153226782756765`, 0.3081323016702944, 0.9336493661486316], 
             UndirectedEdge[95, 229] -> 
             RGBColor[
              0.2643373458997902, 0.3951656888693841, 0.9383649928457094], 
             UndirectedEdge[30, 204] -> 
             RGBColor[
              0.17892701604158556`, 0.30539401686072354`, 0.9335010009135446],
              UndirectedEdge[133, 223] -> 
             RGBColor[
              0.3756627076897743, 0.49871942307299955`, 0.945202383630783], 
             UndirectedEdge[298, 306] -> 
             RGBColor[
              0.8969031243202032, 0.8868893383314866, 0.6612189641553454], 
             UndirectedEdge[40, 96] -> 
             RGBColor[
              0.313111809733841, 0.4436046951713676, 0.9412461018545393], 
             UndirectedEdge[122, 146] -> 
             RGBColor[
              0.49070941162852855`, 0.5972227097318854, 0.9531038334374095], 
             UndirectedEdge[223, 267] -> 
             RGBColor[
              0.5126330687833186, 0.6152176449516955, 0.954775499492879], 
             UndirectedEdge[54, 322] -> 
             RGBColor[
              0.48020380618298864`, 0.5888540906805946, 0.9522325010212487], 
             UndirectedEdge[41, 154] -> 
             RGBColor[
              0.3854891726816393, 0.5083130789528232, 0.945784007101951], 
             UndirectedEdge[245, 353] -> 
             RGBColor[
              0.220139248365585, 0.34871068603969635`, 0.9358479765763623], 
             UndirectedEdge[26, 62] -> 
             RGBColor[
              0.31709055637755623`, 0.43703130766003234`, 0.9418781709758536],
              UndirectedEdge[217, 269] -> 
             RGBColor[
              0.8795700893340841, 0.446823141873405, 0.274955941883389], 
             UndirectedEdge[172, 347] -> 
             RGBColor[
              0.29073737323035515`, 0.422913791452218, 0.9398684353468445], 
             UndirectedEdge[63, 261] -> 
             RGBColor[
              0.5690047111878296, 0.5889104173173967, 0.6135243178829187], 
             UndirectedEdge[195, 369] -> 
             RGBColor[
              0.2515743275380513, 0.381750947349094, 0.9376381578312021], 
             UndirectedEdge[65, 180] -> 
             RGBColor[
              0.4408011041078431, 0.5545376633487222, 0.9497736818591127], 
             UndirectedEdge[49, 211] -> 
             RGBColor[
              0.25920679804656954`, 0.3897731577801271, 0.9380728157354339], 
             UndirectedEdge[285, 387] -> 
             RGBColor[
              0.2661419288540897, 0.3970624199715206, 0.9384677611753156], 
             UndirectedEdge[329, 388] -> 
             RGBColor[
              0.22925196747727483`, 0.358288731605845, 0.9363669324487132], 
             UndirectedEdge[38, 102] -> 
             RGBColor[
              0.8681284274736344, 0.39830998644304544`, 0.21794336136401693`],
              UndirectedEdge[92, 188] -> 
             RGBColor[
              0.27737488016395806`, 0.40886896400844064`, 0.9391074611347503],
              UndirectedEdge[114, 153] -> 
             RGBColor[
              0.32315432075329853`, 0.4543217632532496, 0.9418120854576224], 
             UndirectedEdge[326, 337] -> 
             RGBColor[
              0.312066783946898, 0.44249908551128714`, 0.9411868535891006], 
             UndirectedEdge[38, 221] -> 
             RGBColor[
              0.9438250637656209, 0.9183985790902189, 0.6570073333224926], 
             UndirectedEdge[350, 394] -> 
             RGBColor[
              0.3958053510234857, 0.5172484341263308, 0.9464413448636552], 
             UndirectedEdge[286, 349] -> 
             RGBColor[
              0.5858145101958898, 0.6731289759492968, 0.9614748008949803], 
             UndirectedEdge[246, 320] -> 
             RGBColor[
              0.5768484382747107, 0.6660576659405324, 0.9606094815615308], 
             UndirectedEdge[322, 362] -> 
             RGBColor[
              0.45653757665465905`, 0.5683555921624378, 0.9507245098029286], 
             UndirectedEdge[80, 348] -> 
             RGBColor[
              0.2986858104115632, 0.42889469918101, 0.9404079890218355], 
             UndirectedEdge[78, 230] -> 
             RGBColor[
              0.8841817106508366, 0.517294431234711, 0.23630763277691794`], 
             UndirectedEdge[248, 329] -> 
             RGBColor[
              0.22567335718883677`, 0.3545273852956994, 0.9361631358868661], 
             UndirectedEdge[43, 330] -> 
             RGBColor[
              0.2261035990920075, 0.35497959681484403`, 0.9361876375267658], 
             UndirectedEdge[63, 217] -> 
             RGBColor[
              0.8680707972718473, 0.4082620639603508, 0.21083344347194502`], 
             UndirectedEdge[79, 136] -> 
             RGBColor[
              0.6046940354323059, 0.6899568849766287, 0.9620228760179198], 
             UndirectedEdge[159, 243] -> 
             RGBColor[
              0.3099032733211534, 0.44096065205359114`, 0.9410367126469893], 
             UndirectedEdge[1, 327] -> 
             RGBColor[
              0.3392875835527789, 0.4682955846087937, 0.9428400826971212], 
             UndirectedEdge[304, 353] -> 
             RGBColor[
              0.21473904123945592`, 0.3430347259572272, 0.9355404427694197], 
             UndirectedEdge[240, 329] -> 
             RGBColor[
              0.23717266786335917`, 0.3666138899130299, 0.9368180046180745], 
             UndirectedEdge[10, 311] -> 
             RGBColor[
              0.4406499577202704, 0.5542970021663628, 0.9497943740304772], 
             UndirectedEdge[353, 378] -> 
             RGBColor[
              0.20945304207089746`, 0.33747880567936756`, 0.9352394129367053],
              UndirectedEdge[167, 243] -> 
             RGBColor[
              0.28596070978623506`, 0.41789321531449325`, 0.9395964114301423],
              UndirectedEdge[169, 292] -> 
             RGBColor[
              0.21585857380573317`, 0.34421142566684904`, 0.9356041984928691],
              UndirectedEdge[211, 347] -> 
             RGBColor[
              0.27136364126610246`, 0.4025507707922349, 0.9387651299723484], 
             UndirectedEdge[224, 340] -> 
             RGBColor[
              0.9847198182906963, 0.959331532205712, 0.46205791346696695`], 
             UndirectedEdge[144, 233] -> 
             RGBColor[
              0.837784857099873, 0.2704306873219118, 0.18299359113138844`], 
             UndirectedEdge[273, 394] -> 
             RGBColor[
              0.3171526741702776, 0.4460438307034582, 0.9415424253765902], 
             UndirectedEdge[93, 94] -> 
             RGBColor[
              0.2526810398598759, 0.3829141721689455, 0.9377011834606958], 
             UndirectedEdge[358, 366] -> 
             RGBColor[
              0.934928559139148, 0.7751416322731404, 0.28588252947049914`], 
             UndirectedEdge[245, 329] -> 
             RGBColor[
              0.232518836810426, 0.36172241840646596`, 0.936552975824336], 
             UndirectedEdge[44, 93] -> 
             RGBColor[
              0.2715973273730923, 0.4027963897072362, 0.9387784380504338], 
             UndirectedEdge[218, 314] -> 
             RGBColor[
              0.9179378774680893, 0.9374027630058823, 0.9920349282773651], 
             UndirectedEdge[133, 346] -> 
             RGBColor[
              0.32114511749891506`, 0.4515193689112592, 0.9417229503460453], 
             UndirectedEdge[143, 272] -> 
             RGBColor[
              0.635830587523557, 0.7151635871324875, 0.9645228442451073], 
             UndirectedEdge[272, 346] -> 
             RGBColor[
              0.4960244700071036, 0.5987224642834593, 0.954329185667129], 
             UndirectedEdge[61, 269] -> 
             RGBColor[
              0.9932024163292561, 0.9878689808064407, 0.5015031511422814], 
             UndirectedEdge[158, 362] -> 
             RGBColor[
              0.4538874638081069, 0.5662041111673836, 0.9505158832119648], 
             UndirectedEdge[294, 393] -> 
             RGBColor[
              0.21778977524310467`, 0.34624124082276975`, 0.9357141775577711],
              UndirectedEdge[17, 298] -> 
             RGBColor[
              0.6794733687434446, 0.7479201915203444, 0.969798835244192], 
             UndirectedEdge[83, 179] -> 
             RGBColor[
              0.3112624132414147, 0.4404062657068423, 0.9411867183836149], 
             UndirectedEdge[223, 398] -> 
             RGBColor[
              0.696746297429305, 0.7610076864937902, 0.9687930758283795], 
             UndirectedEdge[52, 272] -> 
             RGBColor[
              0.5168312067307885, 0.6167442138565202, 0.9556549725324873], 
             UndirectedEdge[52, 174] -> 
             RGBColor[
              0.5576254346896334, 0.6486129747855855, 0.95972095993169], 
             UndirectedEdge[63, 317] -> 
             RGBColor[
              0.9745940579826633, 0.9311354530743134, 0.5492576472683819], 
             UndirectedEdge[145, 280] -> 
             RGBColor[
              0.23851863392834902`, 0.36802858558651175`, 0.9368946553942974],
              UndirectedEdge[152, 317] -> 
             RGBColor[
              0.5871216146224013, 0.6503573374272111, 0.8693826955340949], 
             UndirectedEdge[102, 391] -> 
             RGBColor[
              0.8196616203498689, 0.15213340655187516`, 0.16646129589264572`],
              UndirectedEdge[168, 251] -> 
             RGBColor[
              0.7462331666341901, 0.8017011358685895, 0.9753362046447762], 
             UndirectedEdge[89, 245] -> 
             RGBColor[
              0.22424083690782642`, 0.3530217156533258, 0.9360815559760864], 
             UndirectedEdge[293, 330] -> 
             RGBColor[
              0.21800150715905772`, 0.3464637844910152, 0.9357262353771553], 
             UndirectedEdge[166, 247] -> 
             RGBColor[
              0.8521819158271694, 0.35060214666224016`, 0.1955795811073881], 
             UndirectedEdge[8, 182] -> 
             RGBColor[
              0.29920713316336395`, 0.4316705233112208, 0.9403561039493367], 
             UndirectedEdge[2, 215] -> 
             RGBColor[
              0.818730195304093, 0.14497406549698325`, 0.16556936221691648`], 
             UndirectedEdge[61, 107] -> 
             RGBColor[
              0.8905937543543853, 0.5310251940497527, 0.2958324211095563], 
             UndirectedEdge[192, 361] -> 
             RGBColor[
              0.35005813253929685`, 0.4776244927973833, 0.9435263725545195], 
             UndirectedEdge[71, 321] -> 
             RGBColor[
              0.8444532383444727, 0.878825868324395, 0.985021184343525], 
             UndirectedEdge[26, 389] -> 
             RGBColor[
              0.31710049015279534`, 0.4370417486876464, 0.9418787366896577], 
             UndirectedEdge[134, 263] -> 
             RGBColor[
              0.24820523859568883`, 0.3782098212580943, 0.9374462932000549], 
             UndirectedEdge[105, 282] -> 
             RGBColor[
              0.5321029414738284, 0.6299784125013272, 0.956625284939209], 
             UndirectedEdge[323, 340] -> 
             RGBColor[
              0.9119941865056833, 0.9282757501963927, 0.7739166151037982], 
             UndirectedEdge[311, 323] -> 
             RGBColor[
              0.6747921418079339, 0.7440706990607763, 0.9694867808520644], 
             UndirectedEdge[29, 365] -> 
             RGBColor[
              0.24833496351636752`, 0.37834617037476265`, 0.9374536808423768],
              UndirectedEdge[321, 384] -> 
             RGBColor[
              0.7831071512596195, 0.8304885254895837, 0.9790164603513036], 
             UndirectedEdge[115, 195] -> 
             RGBColor[
              0.2421504028292495, 0.3718458049688061, 0.937101479260483], 
             UndirectedEdge[162, 359] -> 
             RGBColor[
              0.24582605828944576`, 0.3757091519074889, 0.9373108024012962], 
             UndirectedEdge[106, 295] -> 
             RGBColor[
              0.5954410834145789, 0.6666014753537031, 0.9545919964182874], 
             UndirectedEdge[24, 242] -> 
             RGBColor[
              0.9102499321760205, 0.681280510728698, 0.24661228929151274`], 
             UndirectedEdge[109, 286] -> 
             RGBColor[
              0.8601731647723879, 0.8889489686867593, 0.8604250468482817], 
             UndirectedEdge[287, 367] -> 
             RGBColor[
              0.23976404440825078`, 0.3693375909644736, 0.936965579678708], 
             UndirectedEdge[74, 140] -> 
             RGBColor[
              0.7482992359076605, 0.8033342207586809, 0.9755370742792053], 
             UndirectedEdge[168, 394] -> 
             RGBColor[
              0.5145092206731405, 0.613750519132451, 0.9559228612077943], 
             UndirectedEdge[68, 249] -> 
             RGBColor[
              0.2731469520224531, 0.4044251434655919, 0.9388666868817508], 
             UndirectedEdge[389, 400] -> 
             RGBColor[
              0.2843495171102985, 0.40872323643536973`, 0.9397784081644269], 
             UndirectedEdge[267, 346] -> 
             RGBColor[
              0.4581154785924594, 0.5680175907899552, 0.9512960662081413], 
             UndirectedEdge[16, 392] -> 
             RGBColor[
              0.24490486142793333`, 0.37474091559878486`, 0.9372583416028217],
              UndirectedEdge[13, 191] -> 
             RGBColor[
              0.8213167457883995, 0.8607762667176537, 0.9574101949991654], 
             UndirectedEdge[312, 327] -> 
             RGBColor[
              0.39077465425622554`, 0.5126293712413812, 0.9461931090416965], 
             UndirectedEdge[260, 291] -> 
             RGBColor[
              0.7527228069990448, 0.8067520448236535, 0.9759880328732503], 
             UndirectedEdge[83, 344] -> 
             RGBColor[
              0.33675515918736176`, 0.4661021259068189, 0.9426787188558917], 
             UndirectedEdge[200, 288] -> 
             RGBColor[
              0.25784282293400623`, 0.38833953345580596`, 0.9379951393705938],
              UndirectedEdge[297, 332] -> 
             RGBColor[
              0.736930313911651, 0.7933926635631983, 0.9655671808709663], 
             UndirectedEdge[189, 241] -> 
             RGBColor[
              0.2957543458619668, 0.428186947782479, 0.9401541445162689], 
             UndirectedEdge[276, 358] -> 
             RGBColor[
              0.8670714087363368, 0.8612246187195758, 0.654847436421338], 
             UndirectedEdge[11, 102] -> 
             RGBColor[
              0.8540189108876494, 0.344308027712143, 0.19649960097358543`], 
             UndirectedEdge[96, 243] -> 
             RGBColor[
              0.2876417202462759, 0.4196600638902152, 0.9396921424890095], 
             UndirectedEdge[171, 397] -> 
             RGBColor[
              0.26128106780929927`, 0.39195334681705507`, 0.9381909423298143],
              UndirectedEdge[314, 385] -> 
             RGBColor[
              0.7506165131369036, 0.8049365561291917, 0.9762521831517132], 
             UndirectedEdge[11, 213] -> 
             RGBColor[
              0.9172153878071567, 0.709493629531714, 0.2522477617062842], 
             UndirectedEdge[68, 129] -> 
             RGBColor[
              0.25720454661950837`, 0.38766866458021304`, 0.9379587904787283],
              UndirectedEdge[137, 277] -> 
             RGBColor[
              0.23968446191505444`, 0.36925394471830275`, 0.9369610475734522],
              UndirectedEdge[35, 327] -> 
             RGBColor[
              0.29981659218631795`, 0.43154628389532945`, 0.9404188155272046],
              UndirectedEdge[155, 183] -> 
             RGBColor[
              0.2817396246657633, 0.4134565872206231, 0.9393560268770672], 
             UndirectedEdge[63, 256] -> 
             RGBColor[
              0.5919347091448884, 0.6130112990161062, 0.6148301473446811], 
             UndirectedEdge[144, 358] -> 
             RGBColor[
              0.9235073892649484, 0.7232807673563957, 0.2763524253689754], 
             UndirectedEdge[192, 332] -> 
             RGBColor[
              0.43585567576042195`, 0.5499313562155932, 0.9495477612304457], 
             UndirectedEdge[149, 259] -> 
             RGBColor[
              0.21561966255991427`, 0.3439603147996455, 0.9355905928508573], 
             UndirectedEdge[146, 165] -> 
             RGBColor[
              0.5340400056803238, 0.6325967606962016, 0.956460731981605], 
             UndirectedEdge[164, 280] -> 
             RGBColor[
              0.2407758584059484, 0.37040107162876656`, 0.9370232009890322], 
             UndirectedEdge[65, 105] -> 
             RGBColor[
              0.46633814789011974`, 0.5766565671437895, 0.9514008797073982], 
             UndirectedEdge[73, 369] -> 
             RGBColor[
              0.2502849628040927, 0.38039574326325765`, 0.9375647304170474], 
             UndirectedEdge[187, 281] -> 
             RGBColor[
              0.7379639441479849, 0.795257108792612, 0.9745741950769791], 
             UndirectedEdge[53, 253] -> 
             RGBColor[
              0.31547986955209806`, 0.4458714425532633, 0.9413890964198188], 
             UndirectedEdge[132, 191] -> 
             RGBColor[
              0.7390378619070974, 0.7960612617083893, 0.9746240454395679], 
             UndirectedEdge[29, 273] -> 
             RGBColor[
              0.25793330326133057`, 0.388434634016608, 0.9380002920913812], 
             UndirectedEdge[138, 366] -> 
             RGBColor[
              0.8466553995070266, 0.31466206234315997`, 0.19055015184607266`],
              UndirectedEdge[229, 309] -> 
             RGBColor[
              0.25884330525935606`, 0.3893911038139919, 0.9380521153589414], 
             UndirectedEdge[274, 287] -> 
             RGBColor[
              0.2454706833388167, 0.37533563030230443`, 0.937290564323588], 
             UndirectedEdge[251, 312] -> 
             RGBColor[
              0.6426365090387243, 0.7180224324379316, 0.9668896222215277], 
             UndirectedEdge[339, 360] -> 
             RGBColor[
              0.3380761124684098, 0.46724626924582036`, 0.942762888830887], 
             UndirectedEdge[150, 365] -> 
             RGBColor[
              0.26342074735738313`, 0.39420228568561005`, 0.9383127939147053],
              UndirectedEdge[61, 300] -> 
             RGBColor[
              0.9416713408004723, 0.7907793854302443, 0.3735219082012329], 
             UndirectedEdge[62, 389] -> 
             RGBColor[
              0.17907819285502502`, 0.305552913276812, 0.9335096102094239], 
             UndirectedEdge[374, 399] -> 
             RGBColor[
              0.255491371590293, 0.38586800900293716`, 0.9378612276952298], 
             UndirectedEdge[27, 51] -> 
             RGBColor[
              0.33517005330446453`, 0.4636817173337682, 0.9426160703012283], 
             UndirectedEdge[58, 159] -> 
             RGBColor[
              0.31512279365295653`, 0.44644669885901933`, 0.9413339566082971],
              UndirectedEdge[57, 153] -> 
             RGBColor[
              0.2953190920495516, 0.42692650296079127`, 0.9401587579547649], 
             UndirectedEdge[84, 264] -> 
             RGBColor[
              0.18447901438019912`, 0.31122951913163255`, 0.9338171790054831],
              UndirectedEdge[159, 201] -> 
             RGBColor[
              0.30393044061377905`, 0.43468282617867443`, 0.9406965686603185],
              UndirectedEdge[80, 87] -> 
             RGBColor[
              0.3122775575094636, 0.4431804871474425, 0.9411820189118731], 
             UndirectedEdge[39, 288] -> 
             RGBColor[
              0.2590590279232666, 0.38961784201136873`, 0.9380644004455181], 
             UndirectedEdge[91, 365] -> 
             RGBColor[
              0.259430965008946, 0.3900087714705911, 0.9380855817123159], 
             UndirectedEdge[5, 384] -> 
             RGBColor[
              0.7949354326614759, 0.8399023141409853, 0.9801493658443617], 
             UndirectedEdge[156, 381] -> 
             RGBColor[
              0.5895532840978516, 0.6521098895899253, 0.8485682432747944], 
             UndirectedEdge[2, 197] -> 
             RGBColor[
              0.8752179409256514, 0.4250918427711577, 0.3888952541053632], 
             UndirectedEdge[238, 293] -> 
             RGBColor[
              0.22022708573500543`, 0.3488030086841681, 0.935852978784607], 
             UndirectedEdge[85, 325] -> 
             RGBColor[
              0.22643759197523877`, 0.355330644511492, 0.9362066579273677], 
             UndirectedEdge[146, 332] -> 
             RGBColor[
              0.53127642233297, 0.6303531592368088, 0.9562431725771618], 
             UndirectedEdge[197, 204] -> 
             RGBColor[
              0.5838392169462935, 0.6475052215433456, 0.8847911904815791], 
             UndirectedEdge[20, 130] -> 
             RGBColor[
              0.4090322853711047, 0.5287049398531881, 0.9472841534241666], 
             UndirectedEdge[167, 348] -> 
             RGBColor[
              0.2732523450214962, 0.4045359181898883, 0.9388726888571313], 
             UndirectedEdge[83, 237] -> 
             RGBColor[
              0.4656503502316991, 0.5743478756221865, 0.9518303486289299], 
             UndirectedEdge[178, 334] -> 
             RGBColor[
              0.25269374017822266`, 0.3829275210087747, 0.9377019067250372], 
             UndirectedEdge[178, 388] -> 
             RGBColor[
              0.23367677668762307`, 0.36293948663502873`, 0.9366189187873238],
              UndirectedEdge[115, 184] -> 
             RGBColor[
              0.22818450918176583`, 0.35716676525650004`, 0.936306142277947], 
             UndirectedEdge[165, 385] -> 
             RGBColor[
              0.5540849096952511, 0.648870116788155, 0.9580387402525627], 
             UndirectedEdge[202, 257] -> 
             RGBColor[
              0.8450954738030565, 0.347629149378724, 0.19081678268284705`], 
             UndirectedEdge[35, 57] -> 
             RGBColor[
              0.2771242370211076, 0.4086055221736117, 0.9390931873785582], 
             UndirectedEdge[115, 206] -> 
             RGBColor[
              0.23508408472910247`, 0.364418656615107, 0.9366990628983605], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.34476855469957235`, 0.4730429263345264, 0.9431893253319623], 
             UndirectedEdge[61, 98] -> 
             RGBColor[
              0.985458002900472, 0.9620883573989745, 0.44224268706809605`], 
             UndirectedEdge[33, 173] -> 
             RGBColor[
              0.20265449886636056`, 0.33033310571886365`, 0.9348522459587503],
              UndirectedEdge[6, 185] -> 
             RGBColor[
              0.8802428367957571, 0.45146047453341354`, 0.28597932338357385`],
              UndirectedEdge[300, 363] -> 
             RGBColor[
              0.8716739217649633, 0.5101830746992847, 0.2146339135717204], 
             UndirectedEdge[34, 270] -> 
             RGBColor[
              0.28093807902462586`, 0.41228653639826196`, 0.9393223741835017],
              UndirectedEdge[162, 179] -> 
             RGBColor[
              0.25786357675267113`, 0.38836134703509095`, 0.9379963212698641],
              UndirectedEdge[11, 250] -> 
             RGBColor[
              0.9558449394073578, 0.8618308276345842, 0.5510217386219683], 
             UndirectedEdge[66, 314] -> 
             RGBColor[
              0.9492974340005453, 0.9317668939083206, 0.6707765260947278], 
             UndirectedEdge[153, 327] -> 
             RGBColor[
              0.31801144721476193`, 0.44986726468250904`, 0.9414843861034113],
              UndirectedEdge[153, 392] -> 
             RGBColor[
              0.28268998646480836`, 0.4136525122596839, 0.9394395490748012], 
             UndirectedEdge[110, 369] -> 
             RGBColor[
              0.2565159464057226, 0.38694490209574905`, 0.9379195757152459], 
             UndirectedEdge[321, 398] -> 
             RGBColor[
              0.8786059330927678, 0.9059622064053712, 0.9849470713031456], 
             UndirectedEdge[188, 278] -> 
             RGBColor[
              0.2597507710467335, 0.39034490789317966`, 0.9381037941930572], 
             UndirectedEdge[213, 289] -> 
             RGBColor[
              0.9043607109741805, 0.6566643735845665, 0.24180812561664938`], 
             UndirectedEdge[236, 263] -> 
             RGBColor[
              0.2563029052327246, 0.3867209823153376, 0.9379074433356098], 
             UndirectedEdge[93, 383] -> 
             RGBColor[
              0.2627372188358315, 0.39348385387124796`, 0.9382738679765928], 
             UndirectedEdge[56, 286] -> 
             RGBColor[
              0.5885924555434128, 0.6755350925857282, 0.9616518091160838], 
             UndirectedEdge[25, 144] -> 
             RGBColor[
              0.8586201119368833, 0.430579586066059, 0.2029454546933641], 
             UndirectedEdge[143, 331] -> 
             RGBColor[
              0.5383683584932644, 0.6360774364876114, 0.9568106700316372], 
             UndirectedEdge[76, 257] -> 
             RGBColor[
              0.8388320138772645, 0.2994854517234461, 0.18481888638434243`], 
             UndirectedEdge[91, 189] -> 
             RGBColor[
              0.28158397795101814`, 0.4132929926548542, 0.9393471630269211], 
             UndirectedEdge[133, 145] -> 
             RGBColor[
              0.26764114093786784`, 0.3986381869271076, 0.9385531390856012], 
             UndirectedEdge[207, 230] -> 
             RGBColor[
              0.9543565255231943, 0.8529328333505086, 0.30199072149137773`], 
             UndirectedEdge[238, 336] -> 
             RGBColor[
              0.22011483416770328`, 0.34868502516977307`, 0.9358465862239105],
              UndirectedEdge[123, 306] -> 
             RGBColor[
              0.9723361250736168, 0.9460422517382365, 0.6339056761634236], 
             UndirectedEdge[272, 338] -> 
             RGBColor[
              0.8206526510459409, 0.8571827716487312, 0.7925776008366022], 
             UndirectedEdge[11, 289] -> 
             RGBColor[
              0.9106079850234978, 0.6814327334094423, 0.24683482895909917`], 
             UndirectedEdge[215, 300] -> 
             RGBColor[
              0.8428577239961123, 0.2973030358908946, 0.18737678816262127`], 
             UndirectedEdge[224, 289] -> 
             RGBColor[
              0.9367074082562672, 0.779083085731074, 0.29817258897466137`], 
             UndirectedEdge[65, 161] -> 
             RGBColor[
              0.4733844161827434, 0.5827596905831183, 0.9518498616922337], 
             UndirectedEdge[14, 247] -> 
             RGBColor[
              0.9506823086964485, 0.8296807989526216, 0.43560760573952945`], 
             UndirectedEdge[150, 226] -> 
             RGBColor[
              0.2546174021107136, 0.38494941166703367`, 0.9378114564262897], 
             UndirectedEdge[15, 180] -> 
             RGBColor[
              0.33506546922916314`, 0.4641869420312098, 0.9425875907675709], 
             UndirectedEdge[7, 114] -> 
             RGBColor[
              0.359141437487956, 0.48549199500373064`, 0.9441051527137969], 
             UndirectedEdge[108, 313] -> 
             RGBColor[
              0.3251887159565602, 0.4536857414582067, 0.9420295219732657], 
             UndirectedEdge[227, 315] -> 
             RGBColor[
              0.2390981188616284, 0.3686376609928552, 0.9369276562039764], 
             UndirectedEdge[174, 384] -> 
             RGBColor[
              0.7385166114389616, 0.7956540568810313, 0.9745720920642666], 
             UndirectedEdge[104, 138] -> 
             RGBColor[
              0.8575199467269797, 0.3583022079987919, 0.19932129168970925`], 
             UndirectedEdge[313, 344] -> 
             RGBColor[
              0.30171850127564737`, 0.43335702114888963`, 0.940534020647694], 
             UndirectedEdge[255, 374] -> 
             RGBColor[
              0.2682893522658295, 0.3993194981317673, 0.938590053761786], 
             UndirectedEdge[87, 167] -> 
             RGBColor[
              0.28684409211939654`, 0.41882170615632086`, 0.9396467187471687],
              UndirectedEdge[114, 312] -> 
             RGBColor[
              0.3959175277947622, 0.5170838698121216, 0.9465208083959076], 
             UndirectedEdge[50, 265] -> 
             RGBColor[
              0.5230211648142513, 0.6236511692879999, 0.9555932884652836], 
             UndirectedEdge[310, 345] -> 
             RGBColor[
              0.19226277251810686`, 0.3194107424533439, 0.9342604525163987], 
             UndirectedEdge[315, 334] -> 
             RGBColor[
              0.25233663141566864`, 0.38255217705732714`, 0.9376815699093048],
              UndirectedEdge[102, 302] -> 
             RGBColor[
              0.8752903682971644, 0.4224688945444868, 0.24576614904439226`], 
             UndirectedEdge[172, 211] -> 
             RGBColor[
              0.2820509294380053, 0.413783788274112, 0.9393737552233123], 
             UndirectedEdge[264, 381] -> 
             RGBColor[
              0.5915890217554157, 0.6542495789412477, 0.8486841755227887], 
             UndirectedEdge[270, 397] -> 
             RGBColor[
              0.2494683482405557, 0.3795374295806264, 0.9375182254257268], 
             UndirectedEdge[48, 290] -> 
             RGBColor[
              0.4152883060919923, 0.5341235905648768, 0.9476827815325197], 
             UndirectedEdge[224, 323] -> 
             RGBColor[
              0.9029358765369997, 0.8985069119905342, 0.6718086867166897], 
             UndirectedEdge[10, 339] -> 
             RGBColor[
              0.3638431893323356, 0.48956441613441326`, 0.9444047441837249], 
             UndirectedEdge[254, 320] -> 
             RGBColor[
              0.5897027051719504, 0.6767516973442059, 0.9615500313265857], 
             UndirectedEdge[92, 392] -> 
             RGBColor[
              0.26780652703776464`, 0.39881201820418366`, 0.9385625575793235],
              UndirectedEdge[166, 224] -> 
             RGBColor[
              0.8750665720627008, 0.43744874032377956`, 0.2342181469866012], 
             UndirectedEdge[108, 344] -> 
             RGBColor[
              0.3440988640451813, 0.47246287394932385`, 0.9431466532356487], 
             UndirectedEdge[180, 271] -> 
             RGBColor[
              0.3365289525569892, 0.46572515579895724`, 0.942670933978061], 
             UndirectedEdge[104, 207] -> 
             RGBColor[
              0.9368649528111581, 0.7873976069432023, 0.2680582629430743], 
             UndirectedEdge[45, 266] -> 
             RGBColor[
              0.2752485126978604, 0.4066340169820878, 0.9389863676532347], 
             UndirectedEdge[59, 373] -> 
             RGBColor[
              0.2921699969184407, 0.4220829828981863, 0.9400355750383738], 
             UndirectedEdge[107, 352] -> 
             RGBColor[
              0.8908631649865804, 0.5316014361504249, 0.3251561058143065], 
             UndirectedEdge[99, 338] -> 
             RGBColor[
              0.9862079875593082, 0.9866999578573392, 0.7708056942036536], 
             UndirectedEdge[186, 341] -> 
             RGBColor[
              0.23502569235584353`, 0.3643572825285215, 0.9366957375390872], 
             UndirectedEdge[90, 156] -> 
             RGBColor[
              0.4458826703540418, 0.5414428840631231, 0.9526066384680504], 
             UndirectedEdge[34, 151] -> 
             RGBColor[
              0.31406226415390115`, 0.44644668080690353`, 0.9412327476508988],
              UndirectedEdge[174, 260] -> 
             RGBColor[
              0.7687797089830702, 0.819295818690549, 0.9775884348027377], 
             UndirectedEdge[13, 216] -> 
             RGBColor[
              0.8114408517281416, 0.8530611432182054, 0.956425858174716], 
             UndirectedEdge[9, 217] -> 
             RGBColor[
              0.8247201817938115, 0.19101572648577717`, 0.17130538004419316`],
              UndirectedEdge[87, 159] -> 
             RGBColor[
              0.3107866556543149, 0.4418891428954188, 0.9410870199640158], 
             UndirectedEdge[184, 305] -> 
             RGBColor[
              0.21033276310750965`, 0.33840344826638225`, 0.9352895117483098],
              UndirectedEdge[12, 259] -> 
             RGBColor[
              0.2147288372822968, 0.3430240009512847, 0.9355398616691548], 
             UndirectedEdge[27, 287] -> 
             RGBColor[
              0.27881505582512084`, 0.4103826799407336, 0.9391894770081045], 
             UndirectedEdge[188, 284] -> 
             RGBColor[
              0.25554200422115014`, 0.38592122710826227`, 0.9378641111486529],
              UndirectedEdge[118, 126] -> 
             RGBColor[
              0.20905168496127685`, 0.33705695390964574`, 0.935216556243067], 
             UndirectedEdge[209, 304] -> 
             RGBColor[
              0.23556571159456763`, 0.3649248769876179, 0.9367264908358456], 
             UndirectedEdge[48, 108] -> 
             RGBColor[
              0.3965059868386308, 0.5178552896544295, 0.9464859887582483], 
             UndirectedEdge[136, 376] -> 
             RGBColor[
              0.5284877060748537, 0.6276839131134415, 0.9561356038127271], 
             UndirectedEdge[48, 344] -> 
             RGBColor[
              0.373035772157718, 0.49752656934511247`, 0.9449904874326764], 
             UndirectedEdge[13, 198] -> 
             RGBColor[
              0.8951348791523555, 0.9184961361184019, 0.9647537428637106], 
             UndirectedEdge[286, 320] -> 
             RGBColor[
              0.7180719499645429, 0.7796825319520332, 0.9725343592747207], 
             UndirectedEdge[176, 368] -> 
             RGBColor[
              0.2143024966118115, 0.34257588987504495`, 0.9355155821986852], 
             UndirectedEdge[248, 388] -> 
             RGBColor[
              0.21978649931888122`, 0.34833992442602935`, 0.935827888039998], 
             UndirectedEdge[57, 188] -> 
             RGBColor[
              0.270146670915944, 0.40127165779384166`, 0.9386958253112532], 
             UndirectedEdge[39, 225] -> 
             RGBColor[
              0.26510008482719366`, 0.3959673758425263, 0.9384084296992539], 
             UndirectedEdge[355, 379] -> 
             RGBColor[
              0.2259392634266556, 0.3548068696110762, 0.9361782788537368], 
             UndirectedEdge[85, 348] -> 
             RGBColor[
              0.2521313444108594, 0.3823364073993248, 0.9376698791180758], 
             UndirectedEdge[118, 336] -> 
             RGBColor[
              0.20853409149877072`, 0.3365129303632308, 0.9351870800610882], 
             UndirectedEdge[195, 392] -> 
             RGBColor[
              0.24682195915511385`, 0.3767559068610679, 0.9373675174822926], 
             UndirectedEdge[193, 281] -> 
             RGBColor[
              0.7271668299156635, 0.7866477829836171, 0.9735443566828026], 
             UndirectedEdge[154, 312] -> 
             RGBColor[
              0.4465576020433747, 0.5609457568821319, 0.9497475491477698], 
             UndirectedEdge[53, 171] -> 
             RGBColor[
              0.28122827358250124`, 0.41291912481058346`, 0.9393269061893516],
              UndirectedEdge[115, 188] -> 
             RGBColor[
              0.25284600900533644`, 0.38308756520047255`, 0.9377105782094798],
              UndirectedEdge[319, 329] -> 
             RGBColor[
              0.2383612491721791, 0.3678631642290072, 0.9368856925652633], 
             UndirectedEdge[231, 359] -> 
             RGBColor[
              0.2771261222266016, 0.4086075036441148, 0.9390932947382222], 
             UndirectedEdge[288, 399] -> 
             RGBColor[
              0.23995250394206913`, 0.3695356738835413, 0.9369763121703581], 
             UndirectedEdge[140, 220] -> 
             RGBColor[
              0.5736797551483913, 0.6643251817234797, 0.9598909775899255], 
             UndirectedEdge[9, 215] -> 
             RGBColor[
              0.8235410243010869, 0.18195220528658743`, 0.17017621749749212`],
              UndirectedEdge[309, 329] -> 
             RGBColor[
              0.25296463724126, 0.3832122509978928, 0.9377173339120208], 
             UndirectedEdge[9, 61] -> 
             RGBColor[
              0.8815602598479266, 0.4615897967705782, 0.2871819365682987], 
             UndirectedEdge[21, 82] -> 
             RGBColor[
              0.34606714839588365`, 0.4741677029250543, 0.94327207057399], 
             UndirectedEdge[154, 361] -> 
             RGBColor[
              0.39289227512184555`, 0.5147252741957822, 0.9462557262431346], 
             UndirectedEdge[160, 213] -> 
             RGBColor[
              0.856641092447404, 0.37996388162178535`, 0.19964773389151264`], 
             UndirectedEdge[331, 342] -> 
             RGBColor[
              0.5277253347918338, 0.6274369503840362, 0.9559728122191802], 
             UndirectedEdge[122, 159] -> 
             RGBColor[
              0.3887610902465449, 0.5111470494961861, 0.9459924907959437], 
             UndirectedEdge[258, 278] -> 
             RGBColor[
              0.25267444257649463`, 0.38290723800581994`, 0.937700807755167], 
             UndirectedEdge[37, 201] -> 
             RGBColor[
              0.26311290635419504`, 0.3938787252730125, 0.9382952628249838], 
             UndirectedEdge[61, 314] -> 
             RGBColor[
              0.9595789423265859, 0.965928622564677, 0.7549534149051582], 
             UndirectedEdge[297, 314] -> 
             RGBColor[
              0.9362255007006572, 0.9517027043636277, 0.9839981831745597], 
             UndirectedEdge[84, 175] -> 
             RGBColor[
              0.1789295778879611, 0.3053967095236947, 0.9335011468069058], 
             UndirectedEdge[72, 374] -> 
             RGBColor[
              0.25191511783451104`, 0.3821091395580259, 0.9376575653344313], 
             UndirectedEdge[168, 180] -> 
             RGBColor[
              0.5182102560481305, 0.6169561699548207, 0.9561586879091916], 
             UndirectedEdge[36, 60] -> 
             RGBColor[
              0.4386028192989782, 0.5525156396146701, 0.9496662072988238], 
             UndirectedEdge[347, 387] -> 
             RGBColor[
              0.2868094179961087, 0.41878526145427897`, 0.9396447441071433], 
             UndirectedEdge[140, 141] -> 
             RGBColor[
              0.5159944713875729, 0.6149616035084853, 0.9560493981699523], 
             UndirectedEdge[233, 382] -> 
             RGBColor[
              0.8445657958761956, 0.3012213465767044, 0.18865177266237124`], 
             UndirectedEdge[21, 122] -> 
             RGBColor[
              0.37950236392749337`, 0.5031276061157393, 0.9454025329420639], 
             UndirectedEdge[202, 268] -> 
             RGBColor[
              0.8433327505676614, 0.3340800861612308, 0.18912879692192164`], 
             UndirectedEdge[196, 344] -> 
             RGBColor[
              0.3092763827236792, 0.441300833748132, 0.9409644308152758], 
             UndirectedEdge[109, 343] -> 
             RGBColor[
              0.8581485111146978, 0.8873672938614341, 0.8602232482931473], 
             UndirectedEdge[52, 117] -> 
             RGBColor[
              0.36808130040816744`, 0.4932352549346425, 0.9446747928738624], 
             UndirectedEdge[51, 194] -> 
             RGBColor[
              0.38048922371828053`, 0.5039823744655038, 0.945465414775287], 
             UndirectedEdge[223, 342] -> 
             RGBColor[
              0.5287126959381665, 0.6282718106549494, 0.9560413466441238], 
             UndirectedEdge[241, 374] -> 
             RGBColor[
              0.2835328374534444, 0.4153413675567334, 0.939458147692505], 
             UndirectedEdge[76, 109] -> 
             RGBColor[
              0.895995107244091, 0.5718363033485547, 0.3775584455597878], 
             UndirectedEdge[90, 381] -> 
             RGBColor[
              0.849476415301395, 0.8807671291171392, 0.8672733890419332], 
             UndirectedEdge[75, 227] -> 
             RGBColor[
              0.2395500669875186, 0.36911268712833206`, 0.9369533939811485], 
             UndirectedEdge[209, 329] -> 
             RGBColor[
              0.24358590725750107`, 0.37335461113913604`, 0.9371832291140334],
              UndirectedEdge[24, 358] -> 
             RGBColor[
              0.9353648485028525, 0.777122720375753, 0.28624658001000514`], 
             UndirectedEdge[208, 369] -> 
             RGBColor[
              0.24527033350139205`, 0.37512504992025775`, 0.9372791546967377],
              UndirectedEdge[62, 400] -> 
             RGBColor[
              0.2843395833350594, 0.4087127954077557, 0.9397778424506229], 
             UndirectedEdge[127, 325] -> 
             RGBColor[
              0.21103171786447747`, 0.3391380940322466, 0.9353293161877081], 
             UndirectedEdge[43, 277] -> 
             RGBColor[
              0.2426240388727448, 0.37234362648077923`, 0.9371284521324783], 
             UndirectedEdge[70, 227] -> 
             RGBColor[
              0.25636607330828476`, 0.3867873759678386, 0.9379110406640643], 
             UndirectedEdge[25, 366] -> 
             RGBColor[
              0.8662342251863496, 0.4651534960105555, 0.20929885742771326`], 
             UndirectedEdge[20, 387] -> 
             RGBColor[
              0.3506138656824209, 0.476702600538333, 0.94361316288308], 
             UndirectedEdge[328, 387] -> 
             RGBColor[
              0.30150296805800375`, 0.4341652094015489, 0.9404838599135137], 
             UndirectedEdge[249, 386] -> 
             RGBColor[
              0.3044662110801129, 0.4345129066433197, 0.9407539204836926], 
             UndirectedEdge[110, 243] -> 
             RGBColor[
              0.2719749479938126, 0.4031932929221435, 0.9387999429861442], 
             UndirectedEdge[47, 121] -> 
             RGBColor[
              0.4935440296663224, 0.5991928393789325, 0.9534184801906773], 
             UndirectedEdge[31, 156] -> 
             RGBColor[
              0.18458847622123073`, 0.3113445704668384, 0.9338234126953957], 
             UndirectedEdge[98, 283] -> 
             RGBColor[
              0.9432427006605664, 0.8062936865407971, 0.3064669136008217], 
             UndirectedEdge[38, 358] -> 
             RGBColor[
              0.9671839420965409, 0.9009658724941282, 0.3270162411479497], 
             UndirectedEdge[126, 199] -> 
             RGBColor[
              0.21892225618889471`, 0.3474315501002342, 0.9357786706722784], 
             UndirectedEdge[39, 200] -> 
             RGBColor[
              0.27187585958380484`, 0.4030891447206572, 0.9387943000477824], 
             UndirectedEdge[227, 304] -> 
             RGBColor[
              0.22701022275090071`, 0.35593251576360085`, 0.9362392684029103],
              UndirectedEdge[242, 333] -> 
             RGBColor[
              0.5569536477379948, 0.5184281382754727, 0.5938032026627618], 
             UndirectedEdge[30, 333] -> 
             RGBColor[
              0.1872437438170861, 0.31413542506377157`, 0.9339746262568631], 
             UndirectedEdge[85, 96] -> 
             RGBColor[
              0.2641094772748117, 0.3949261844968264, 0.9383520160646184], 
             UndirectedEdge[39, 94] -> 
             RGBColor[
              0.2666080163774077, 0.39755230751018356`, 0.9384943041702538], 
             UndirectedEdge[63, 138] -> 
             RGBColor[
              0.8657489352082692, 0.3904152146932457, 0.2086100257376945], 
             UndirectedEdge[119, 324] -> 
             RGBColor[
              0.26022801088632164`, 0.3908465172233403, 0.9381309722959088], 
             UndirectedEdge[18, 224] -> 
             RGBColor[
              0.960434037083298, 0.9441092105197667, 0.6687925780376456], 
             UndirectedEdge[84, 204] -> 
             RGBColor[
              0.17892700714738574`, 0.30539400751235557`, 0.933501000407033], 
             UndirectedEdge[241, 288] -> 
             RGBColor[
              0.2679939698052205, 0.39900903243733754`, 0.9385732321676334], 
             UndirectedEdge[91, 266] -> 
             RGBColor[
              0.25880957199136756`, 0.38935564801052325`, 0.9380501942992334],
              UndirectedEdge[201, 263] -> 
             RGBColor[
              0.26925494850456955`, 0.4003344010010207, 0.9386450430391104], 
             UndirectedEdge[29, 266] -> 
             RGBColor[
              0.2477135704987891, 0.37769304691469485`, 0.9374182934292943], 
             UndirectedEdge[161, 326] -> 
             RGBColor[
              0.3854134409611904, 0.5082474839429573, 0.9457791815436909], 
             UndirectedEdge[174, 235] -> 
             RGBColor[
              0.7343495307888845, 0.7923987018062052, 0.9741567564086497], 
             UndirectedEdge[207, 233] -> 
             RGBColor[
              0.8582574278703963, 0.3565499328346968, 0.19972248074073234`], 
             UndirectedEdge[199, 212] -> 
             RGBColor[
              0.21834996970250586`, 0.3468300407179805, 0.9357460798035004], 
             UndirectedEdge[127, 184] -> 
             RGBColor[
              0.21412931839643223`, 0.34239386859054827`, 0.9355057199555137],
              UndirectedEdge[261, 381] -> 
             RGBColor[
              0.5862976993087463, 0.6486880635605781, 0.8483828425372609], 
             UndirectedEdge[221, 230] -> 
             RGBColor[
              0.9453580743501937, 0.9235697837599854, 0.6629627899588003], 
             UndirectedEdge[22, 273] -> 
             RGBColor[
              0.28387789683872655`, 0.4157040468486936, 0.9394777983140272], 
             UndirectedEdge[240, 292] -> 
             RGBColor[
              0.2251125947151853, 0.3539379883814973, 0.9361312012935654], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.4322766112650586, 0.5488154801889021, 0.9487714854439504], 
             UndirectedEdge[120, 343] -> 
             RGBColor[
              0.64428944346767, 0.7208791499127623, 0.9659761919445966], 
             UndirectedEdge[175, 310] -> 
             RGBColor[
              0.18075514602575382`, 0.30731549738422004`, 0.933605110211667], 
             UndirectedEdge[55, 201] -> 
             RGBColor[
              0.33997947002411655`, 0.46590668357700793`, 0.9429935809374401],
              UndirectedEdge[264, 333] -> 
             RGBColor[
              0.19279573500831393`, 0.31997091982232506`, 0.9342908039417687],
              UndirectedEdge[107, 197] -> 
             RGBColor[
              0.889062264429104, 0.5315053798399363, 0.4021525939271964], 
             UndirectedEdge[131, 300] -> 
             RGBColor[
              0.9062314787117222, 0.661847076989811, 0.24319781291959908`], 
             UndirectedEdge[164, 227] -> 
             RGBColor[
              0.23873025962291325`, 0.36825101760934276`, 0.9369067071645306],
              UndirectedEdge[75, 315] -> 
             RGBColor[
              0.24372617436870905`, 0.3735020407664642, 0.9371912171185102], 
             UndirectedEdge[123, 193] -> 
             RGBColor[
              0.8983178729767032, 0.9207629901755221, 0.9556553997903747], 
             UndirectedEdge[157, 253] -> 
             RGBColor[
              0.40547981020843754`, 0.5251955404755204, 0.9471772728723662], 
             UndirectedEdge[87, 110] -> 
             RGBColor[
              0.27285833032697415`, 0.4041217837639711, 0.9388502503031707], 
             UndirectedEdge[112, 273] -> 
             RGBColor[
              0.30217928403804095`, 0.4330746327553852, 0.940588334197813], 
             UndirectedEdge[193, 384] -> 
             RGBColor[
              0.7853837252276628, 0.8322860419074539, 0.9792383154624147], 
             UndirectedEdge[95, 249] -> 
             RGBColor[
              0.2756739059578213, 0.4070811322697972, 0.9390105931700766], 
             UndirectedEdge[61, 66] -> 
             RGBColor[
              0.9830643953423903, 0.9540141570597834, 0.4329439736998075], 
             UndirectedEdge[113, 251] -> 
             RGBColor[
              0.8094157442625041, 0.8510598457172036, 0.9816336535080088], 
             UndirectedEdge[107, 131] -> 
             RGBColor[
              0.8669671796285517, 0.4450703217561305, 0.20894969092180046`], 
             UndirectedEdge[71, 343] -> 
             RGBColor[
              0.7966602927353739, 0.841489655974727, 0.98025763017568], 
             UndirectedEdge[113, 168] -> 
             RGBColor[
              0.7333330676267822, 0.7916046330585647, 0.9740554448600397], 
             UndirectedEdge[58, 201] -> 
             RGBColor[
              0.2876186397714912, 0.4196358048478299, 0.939690828090115], 
             UndirectedEdge[47, 130] -> 
             RGBColor[
              0.4221487542491271, 0.5400657659424366, 0.9481199232226362], 
             UndirectedEdge[17, 82] -> 
             RGBColor[
              0.4573668797759753, 0.5683380513272105, 0.9509806674680623], 
             UndirectedEdge[11, 25] -> 
             RGBColor[
              0.8736282972386266, 0.495034364093645, 0.2152775714889155], 
             UndirectedEdge[73, 392] -> 
             RGBColor[
              0.24553259442115521`, 0.3754007027752315, 0.9372940900681379], 
             UndirectedEdge[155, 337] -> 
             RGBColor[
              0.29464447603044647`, 0.42702040421973947`, 0.9400909390712692],
              UndirectedEdge[159, 165] -> 
             RGBColor[
              0.43209168429834016`, 0.5465211004605023, 0.9493493893401392], 
             UndirectedEdge[226, 368] -> 
             RGBColor[
              0.2257077662103317, 0.35456355135894857`, 0.9361650954297367], 
             UndirectedEdge[188, 258] -> 
             RGBColor[
              0.2600095899871553, 0.39061694300963157`, 0.938118533548826], 
             UndirectedEdge[140, 350] -> 
             RGBColor[
              0.5523338730537959, 0.6464369667603329, 0.9583649127104528], 
             UndirectedEdge[14, 38] -> 
             RGBColor[
              0.9800741446959539, 0.9433032752196526, 0.4743933351284341], 
             UndirectedEdge[242, 268] -> 
             RGBColor[
              0.8509949466416629, 0.3274111533816164, 0.19386471821296208`], 
             UndirectedEdge[20, 50] -> 
             RGBColor[
              0.4309033063250306, 0.5476259924741631, 0.9486839796675377], 
             UndirectedEdge[149, 212] -> 
             RGBColor[
              0.21555790485274898`, 0.34389540353375003`, 0.9355870758407967],
              UndirectedEdge[80, 361] -> 
             RGBColor[
              0.34502145958500996`, 0.47326197983492335`, 0.9432054402076274],
              UndirectedEdge[31, 204] -> 
             RGBColor[
              0.1810722066459815, 0.3076487481988837, 0.9336231663449399], 
             UndirectedEdge[209, 245] -> 
             RGBColor[
              0.2409659187206967, 0.37060083707008695`, 0.9370340246427882], 
             UndirectedEdge[113, 148] -> 
             RGBColor[
              0.7102018348766541, 0.7732513864434318, 0.9719433954351793], 
             UndirectedEdge[48, 231] -> 
             RGBColor[
              0.3670635094292236, 0.49234797467679914`, 0.9446101496016666], 
             UndirectedEdge[198, 224] -> 
             RGBColor[
              0.901075568718926, 0.8970235530331128, 0.6716312488962854], 
             UndirectedEdge[1, 188] -> 
             RGBColor[
              0.3135344759290187, 0.4421377779902256, 0.9413401492239378], 
             UndirectedEdge[256, 264] -> 
             RGBColor[
              0.2076696899760163, 0.3356043895565939, 0.9351378536731348], 
             UndirectedEdge[15, 170] -> 
             RGBColor[
              0.3744152758657625, 0.49826976676104406`, 0.9450949256507872], 
             UndirectedEdge[20, 322] -> 
             RGBColor[
              0.45803755349750475`, 0.5696547967126826, 0.9508200870009773], 
             UndirectedEdge[92, 153] -> 
             RGBColor[
              0.30254730129756563`, 0.4345238091753902, 0.940570393778262], 
             UndirectedEdge[189, 360] -> 
             RGBColor[
              0.30546923311788443`, 0.43824575192600135`, 0.9407129642351355],
              UndirectedEdge[272, 342] -> 
             RGBColor[
              0.6251875638221265, 0.7065231010289125, 0.9636849864326502], 
             UndirectedEdge[69, 219] -> 
             RGBColor[
              0.4677032328653056, 0.5785751319820428, 0.9512844483334466], 
             UndirectedEdge[86, 151] -> 
             RGBColor[
              0.30818593638346986`, 0.44059786327207706`, 0.9408861053327038],
              UndirectedEdge[72, 288] -> 
             RGBColor[
              0.2363762501862872, 0.36577680443863003`, 0.9367726498095597], 
             UndirectedEdge[266, 273] -> 
             RGBColor[
              0.265217664230201, 0.3960909592500517, 0.938415125672312], 
             UndirectedEdge[131, 297] -> 
             RGBColor[
              0.9345525999537521, 0.8450176590746574, 0.6158415354980056], 
             UndirectedEdge[219, 360] -> 
             RGBColor[
              0.37878978346753606`, 0.5025104047366595, 0.9453571279452656], 
             UndirectedEdge[58, 236] -> 
             RGBColor[
              0.27466659649964625`, 0.4060223861621468, 0.9389532283866143], 
             UndirectedEdge[272, 321] -> 
             RGBColor[
              0.7324016958614257, 0.7908770383567805, 0.9739626144266329], 
             UndirectedEdge[250, 391] -> 
             RGBColor[
              0.8763362658148357, 0.4349586392213838, 0.39302937060234416`], 
             UndirectedEdge[122, 298] -> 
             RGBColor[
              0.634758859433705, 0.711422615804957, 0.9663329898214426], 
             UndirectedEdge[113, 282] -> 
             RGBColor[
              0.7216887092702036, 0.7825079718100041, 0.9728948440417715], 
             UndirectedEdge[237, 343] -> 
             RGBColor[
              0.6503098019378368, 0.7257667481329021, 0.9664501366166679], 
             UndirectedEdge[174, 398] -> 
             RGBColor[
              0.83401539327211, 0.8711277377968187, 0.9805027030161089], 
             UndirectedEdge[223, 384] -> 
             RGBColor[
              0.6012475155961567, 0.6855340055780029, 0.9628624648765374], 
             UndirectedEdge[143, 260] -> 
             RGBColor[
              0.7167991404658595, 0.7784168360748085, 0.9725930329082488], 
             UndirectedEdge[148, 161] -> 
             RGBColor[
              0.5276623353729026, 0.6268249505740837, 0.9561228183174523], 
             UndirectedEdge[137, 199] -> 
             RGBColor[
              0.22367942926895015`, 0.3524316406295666, 0.9360495846415806], 
             UndirectedEdge[147, 387] -> 
             RGBColor[
              0.28915329202202544`, 0.42124882166571403`, 0.9397782242654684],
              UndirectedEdge[138, 381] -> 
             RGBColor[
              0.8772775939555472, 0.4302669788553665, 0.36518237550725596`], 
             UndirectedEdge[42, 207] -> 
             RGBColor[
              0.9360408404789141, 0.8740255032004962, 0.6319312562767279], 
             UndirectedEdge[185, 247] -> 
             RGBColor[
              0.8514628356782079, 0.3450749815343914, 0.1948909891446577], 
             UndirectedEdge[49, 380] -> 
             RGBColor[
              0.2606135317686764, 0.39125172411413095`, 0.9381529271398318], 
             UndirectedEdge[63, 242] -> 
             RGBColor[
              0.9384539463641798, 0.7929291511512139, 0.2733380495894395], 
             UndirectedEdge[12, 238] -> 
             RGBColor[
              0.22383004590865202`, 0.3525899482675398, 0.9360581620363942], 
             UndirectedEdge[109, 382] -> 
             RGBColor[
              0.9464386860434384, 0.8125481887830079, 0.4923766470320703], 
             UndirectedEdge[4, 115] -> 
             RGBColor[
              0.23540129852856206`, 0.36475206843085556`, 0.936717127754964], 
             UndirectedEdge[187, 279] -> 
             RGBColor[
              0.8947917399967904, 0.8503099582405043, 0.6300514927715455], 
             UndirectedEdge[152, 156] -> 
             RGBColor[
              0.18478785261667285`, 0.31155412769964164`, 0.9338347668861651],
              UndirectedEdge[143, 290] -> 
             RGBColor[
              0.5148889820990041, 0.6157407807626738, 0.9553145849297924], 
             UndirectedEdge[48, 234] -> 
             RGBColor[
              0.38209114426819646`, 0.5053698775309731, 0.945567487736205], 
             UndirectedEdge[294, 341] -> 
             RGBColor[
              0.21717163219876068`, 0.3455915332906315, 0.9356789752258563], 
             UndirectedEdge[243, 351] -> 
             RGBColor[
              0.26705822161415743`, 0.39802550175866824`, 0.9385199426924677],
              UndirectedEdge[241, 399] -> 
             RGBColor[
              0.2629204824738216, 0.3936764755743613, 0.938284304569662], 
             UndirectedEdge[78, 207] -> 
             RGBColor[
              0.8745145724772496, 0.48150947020916335`, 0.2152903407760738], 
             UndirectedEdge[174, 267] -> 
             RGBColor[
              0.6499021646261236, 0.725337696254724, 0.9664851266806084], 
             UndirectedEdge[124, 293] -> 
             RGBColor[
              0.21725116581640602`, 0.3456751281654994, 0.9356835045477219], 
             UndirectedEdge[57, 392] -> 
             RGBColor[
              0.2605783177897506, 0.3912147119895847, 0.9381509217558264], 
             UndirectedEdge[272, 331] -> 
             RGBColor[
              0.5495546990516302, 0.6450876581742866, 0.9577400845269233], 
             UndirectedEdge[91, 255] -> 
             RGBColor[
              0.26154809523840944`, 0.39223400957556664`, 0.9382061491468703],
              UndirectedEdge[35, 337] -> 
             RGBColor[
              0.28289219144336497`, 0.41466800798083686`, 0.9394216638499819],
              UndirectedEdge[219, 339] -> 
             RGBColor[
              0.4064741730871376, 0.5264892315672777, 0.9471211527714821], 
             UndirectedEdge[166, 185] -> 
             RGBColor[
              0.824409563858564, 0.1886281809218183, 0.17100793195860742`], 
             UndirectedEdge[137, 238] -> 
             RGBColor[
              0.22538960071026484`, 0.3542291392455204, 0.9361469763751915], 
             UndirectedEdge[218, 300] -> 
             RGBColor[
              0.9000302759419758, 0.7622535258714493, 0.6106034215734397], 
             UndirectedEdge[96, 110] -> 
             RGBColor[
              0.2712447160930261, 0.4024257728950402, 0.9387583573596757], 
             UndirectedEdge[225, 375] -> 
             RGBColor[
              0.2559767228165143, 0.3863781439147409, 0.9378888677295503], 
             UndirectedEdge[24, 25] -> 
             RGBColor[
              0.8665250847621527, 0.4664742214122973, 0.20954155778738393`], 
             UndirectedEdge[40, 361] -> 
             RGBColor[
              0.34746932604333547`, 0.4753821987277793, 0.9433614160937887], 
             UndirectedEdge[141, 394] -> 
             RGBColor[
              0.3594659493572627, 0.4857730708744833, 0.9441258303231546], 
             UndirectedEdge[200, 360] -> 
             RGBColor[
              0.29052568872167633`, 0.4225391392901483, 0.9398619514887643], 
             UndirectedEdge[68, 229] -> 
             RGBColor[
              0.2618103919644219, 0.39250970006517877`, 0.9382210865573835], 
             UndirectedEdge[96, 258] -> 
             RGBColor[
              0.26992237493120286`, 0.4010359084926919, 0.9386830519867384], 
             UndirectedEdge[106, 310] -> 
             RGBColor[
              0.5655364837016175, 0.6351698449942476, 0.952888973704525], 
             UndirectedEdge[15, 394] -> 
             RGBColor[
              0.33136443385417313`, 0.4609812912088401, 0.9423517640661736], 
             UndirectedEdge[115, 203] -> 
             RGBColor[
              0.265001837635785, 0.3958641118151241, 0.9384028346670469], 
             UndirectedEdge[218, 298] -> 
             RGBColor[
              0.8667469534105012, 0.8965845097029781, 0.9871522922420749], 
             UndirectedEdge[165, 262] -> 
             RGBColor[
              0.7356958172611161, 0.7926545035064209, 0.9725524468455675], 
             UndirectedEdge[141, 357] -> 
             RGBColor[
              0.5178770250869611, 0.6164322687663853, 0.9562370335292427], 
             UndirectedEdge[15, 239] -> 
             RGBColor[
              0.3141879177885835, 0.4461038563096259, 0.9412572916510711], 
             UndirectedEdge[80, 228] -> 
             RGBColor[
              0.35113678778418134`, 0.4785587697557132, 0.9435951035129062], 
             UndirectedEdge[260, 272] -> 
             RGBColor[
              0.7279854810242253, 0.7874270577614837, 0.9735224474035349], 
             UndirectedEdge[7, 361] -> 
             RGBColor[
              0.3725157575792012, 0.497076158853894, 0.9449573525635642], 
             UndirectedEdge[22, 255] -> 
             RGBColor[
              0.27639668732322686`, 0.40784082131182386`, 0.9390517544995772],
              UndirectedEdge[28, 380] -> 
             RGBColor[
              0.2768898890919296, 0.40835920764152867`, 0.9390798416106783], 
             UndirectedEdge[53, 397] -> 
             RGBColor[
              0.26929675474869136`, 0.4003783420142617, 0.9386474238428664], 
             UndirectedEdge[187, 306] -> 
             RGBColor[
              0.9071549779062498, 0.8950638881018478, 0.6621967951023203], 
             UndirectedEdge[208, 392] -> 
             RGBColor[
              0.24051796511845452`, 0.3701300094322317, 0.9370085143478284], 
             UndirectedEdge[33, 381] -> 
             RGBColor[
              0.5860442078575524, 0.648421627973087, 0.8483684065741224], 
             UndirectedEdge[290, 321] -> 
             RGBColor[
              0.6114600904368728, 0.6914542319869668, 0.964754355111318], 
             UndirectedEdge[20, 116] -> 
             RGBColor[
              0.4119401607737857, 0.531223595372923, 0.9474694406734923], 
             UndirectedEdge[33, 156] -> 
             RGBColor[
              0.18245046291019928`, 0.30909738291907096`, 0.9337016560002396],
              UndirectedEdge[9, 202] -> 
             RGBColor[
              0.8358915005756137, 0.2768833779458136, 0.18200304752584692`], 
             UndirectedEdge[76, 233] -> 
             RGBColor[
              0.8371157015332652, 0.2862931229546034, 0.18317534374543126`], 
             UndirectedEdge[115, 369] -> 
             RGBColor[
              0.24803002426208054`, 0.37802565988424164`, 0.9374363150029623],
              UndirectedEdge[183, 335] -> 
             RGBColor[
              0.2697259044179279, 0.4008294055262898, 0.9386718632816594], 
             UndirectedEdge[39, 296] -> 
             RGBColor[
              0.2873068026652887, 0.4193080442775966, 0.9396730694282384], 
             UndirectedEdge[10, 219] -> 
             RGBColor[
              0.4045568603314619, 0.5248285516252523, 0.9469989832981036], 
             UndirectedEdge[71, 143] -> 
             RGBColor[
              0.7478821300066041, 0.8031124171001021, 0.9755814141619994], 
             UndirectedEdge[232, 384] -> 
             RGBColor[
              0.6369922413654878, 0.7145531842390913, 0.965676420626344], 
             UndirectedEdge[1, 57] -> 
             RGBColor[
              0.31659522838756854`, 0.44535482288707584`, 0.9415144545484747],
              UndirectedEdge[288, 393] -> 
             RGBColor[
              0.23392299503197628`, 0.3631982777260886, 0.9366329405577875], 
             UndirectedEdge[328, 372] -> 
             RGBColor[
              0.2804573452843499, 0.4120449254968854, 0.9392853428307628], 
             UndirectedEdge[16, 115] -> 
             RGBColor[
              0.240233305102069, 0.36983081370652304`, 0.936992303381012], 
             UndirectedEdge[34, 244] -> 
             RGBColor[
              0.2861625929026812, 0.4177778317374103, 0.9396199025198813], 
             UndirectedEdge[233, 366] -> 
             RGBColor[
              0.8453989703493394, 0.3050045972664083, 0.18934699386573758`], 
             UndirectedEdge[100, 105] -> 
             RGBColor[
              0.3969790975995051, 0.5182650744162607, 0.9465161349575758], 
             UndirectedEdge[88, 282] -> 
             RGBColor[
              0.8185877701205739, 0.8571575543356513, 0.887813136638508], 
             UndirectedEdge[189, 219] -> 
             RGBColor[
              0.37386729373661226`, 0.4974887142474586, 0.9450712281757306], 
             UndirectedEdge[44, 328] -> 
             RGBColor[
              0.3036968641952127, 0.4364711333428047, 0.9406087990529493], 
             UndirectedEdge[153, 154] -> 
             RGBColor[
              0.3737943950019111, 0.49818365032325973`, 0.9450388262094847], 
             UndirectedEdge[73, 258] -> 
             RGBColor[
              0.2480246190771097, 0.3780199786921288, 0.9374360071856744], 
             UndirectedEdge[22, 141] -> 
             RGBColor[
              0.32619117202571163`, 0.45543328701971864`, 0.9420612032605917],
              UndirectedEdge[100, 273] -> 
             RGBColor[
              0.3260257412647034, 0.4537292354473304, 0.9421078093657018], 
             UndirectedEdge[230, 391] -> 
             RGBColor[
              0.8698796044232802, 0.407362175546801, 0.22261191970149125`], 
             UndirectedEdge[338, 384] -> 
             RGBColor[
              0.8713581064441347, 0.8967942587815345, 0.7976314467612728], 
             UndirectedEdge[76, 207] -> 
             RGBColor[
              0.877914896729474, 0.5076458524433486, 0.21854649512012086`], 
             UndirectedEdge[144, 370] -> 
             RGBColor[
              0.8548273648949809, 0.7045756223106869, 0.6020207461756493], 
             UndirectedEdge[6, 340] -> 
             RGBColor[
              0.9935628356137232, 0.988639881211936, 0.5407325660065214], 
             UndirectedEdge[30, 370] -> 
             RGBColor[
              0.5050718279609444, 0.5868238115344944, 0.9586321897581539], 
             UndirectedEdge[164, 245] -> 
             RGBColor[
              0.23621867801950508`, 0.36561118610068966`, 0.9367636763077685],
              UndirectedEdge[56, 108] -> 
             RGBColor[
              0.40925205503740436`, 0.5288952932921922, 0.9472981569529686], 
             UndirectedEdge[50, 322] -> 
             RGBColor[
              0.4812818793914586, 0.5897653370483966, 0.952307419020761], 
             UndirectedEdge[379, 399] -> 
             RGBColor[
              0.22791818849812123`, 0.356886845332283, 0.9362909757089996], 
             UndirectedEdge[6, 13] -> 
             RGBColor[
              0.978563836078469, 0.9803436260913665, 0.7317471315868381], 
             UndirectedEdge[55, 60] -> 
             RGBColor[
              0.38053049793671245`, 0.5040181241190069, 0.9454680447319882], 
             UndirectedEdge[44, 47] -> 
             RGBColor[
              0.36592423069765223`, 0.4903693505688373, 0.9445738718209851], 
             UndirectedEdge[156, 264] -> 
             RGBColor[
              0.1879952768080626, 0.31492533388723165`, 0.9340174249489059], 
             UndirectedEdge[32, 43] -> 
             RGBColor[
              0.2218603287150994, 0.3505196506098328, 0.9359459895561568], 
             UndirectedEdge[144, 207] -> 
             RGBColor[
              0.9091469621070289, 0.6700765235430096, 0.2453714490760957], 
             UndirectedEdge[14, 213] -> 
             RGBColor[
              0.9526625957676589, 0.8375319772984231, 0.4372009912003371], 
             UndirectedEdge[127, 139] -> 
             RGBColor[
              0.2108331954164144, 0.3389294343522821, 0.9353180106279786], 
             UndirectedEdge[321, 342] -> 
             RGBColor[
              0.7105723316016292, 0.7732263305665302, 0.9721953421188899], 
             UndirectedEdge[82, 182] -> 
             RGBColor[
              0.3336557333984177, 0.4615081693978327, 0.9425511382946132], 
             UndirectedEdge[50, 172] -> 
             RGBColor[
              0.3777861468106212, 0.500941670871986, 0.945324186142565], 
             UndirectedEdge[80, 96] -> 
             RGBColor[
              0.31066394327551555`, 0.4414844762785116, 0.9410901259683782], 
             UndirectedEdge[78, 160] -> 
             RGBColor[
              0.8377218269870405, 0.2909520687981873, 0.18375577016448721`], 
             UndirectedEdge[32, 293] -> 
             RGBColor[
              0.2137582367821496, 0.342003838286004, 0.9354845874065463], 
             UndirectedEdge[322, 328] -> 
             RGBColor[
              0.4089266558730876, 0.5271174055758985, 0.947690784031411], 
             UndirectedEdge[120, 254] -> 
             RGBColor[
              0.5179448523327678, 0.6195299901302602, 0.955193662551596], 
             UndirectedEdge[291, 321] -> 
             RGBColor[
              0.7571390218362452, 0.8102020254189503, 0.9764281998963484], 
             UndirectedEdge[65, 312] -> 
             RGBColor[
              0.4891446804627151, 0.5961487131731942, 0.9529264075234798], 
             UndirectedEdge[209, 334] -> 
             RGBColor[
              0.2567160128781451, 0.387155184643212, 0.9379309692048785], 
             UndirectedEdge[295, 310] -> 
             RGBColor[
              0.2124827502833183, 0.3406632211052174, 0.935411950337351], 
             UndirectedEdge[109, 205] -> 
             RGBColor[
              0.9946824810618875, 0.9920690835121566, 0.737788580309801], 
             UndirectedEdge[194, 376] -> 
             RGBColor[
              0.4132241787161002, 0.5323357471779375, 0.947551257161364], 
             UndirectedEdge[142, 338] -> 
             RGBColor[
              0.8791521070000148, 0.44133688163023443`, 0.3187690766012381], 
             UndirectedEdge[232, 386] -> 
             RGBColor[
              0.4324598922567031, 0.5470353068857565, 0.9493188938960907], 
             UndirectedEdge[169, 378] -> 
             RGBColor[
              0.21461245212241514`, 0.34290167276900374`, 0.9355332337064761],
              UndirectedEdge[94, 324] -> 
             RGBColor[
              0.2700408112862358, 0.4011603926111301, 0.9386897967619465], 
             UndirectedEdge[196, 231] -> 
             RGBColor[
              0.3033041199951848, 0.43612223907981873`, 0.9405840929842658], 
             UndirectedEdge[207, 366] -> 
             RGBColor[
              0.9205681319812286, 0.7219373884597544, 0.2549015531776194], 
             UndirectedEdge[156, 310] -> 
             RGBColor[
              0.1842688448604277, 0.3110086176408356, 0.93380521016225], 
             UndirectedEdge[206, 369] -> 
             RGBColor[
              0.2445080094379043, 0.3743237989953949, 0.9372357414690795], 
             UndirectedEdge[119, 225] -> 
             RGBColor[
              0.24880323623162193`, 0.37883835468870003`, 0.9374803482807631],
              UndirectedEdge[69, 100] -> 
             RGBColor[
              0.4324163535905058, 0.5480114107243323, 0.9490359995890186], 
             UndirectedEdge[64, 182] -> 
             RGBColor[
              0.34352729206089855`, 0.4700584173523088, 0.9431801452835099], 
             UndirectedEdge[217, 268] -> 
             RGBColor[
              0.820990113004057, 0.1623447832411579, 0.16773346195861408`], 
             UndirectedEdge[235, 275] -> 
             RGBColor[
              0.8660971591696807, 0.893943749566336, 0.8776528174795629], 
             UndirectedEdge[5, 99] -> 
             RGBColor[
              0.9097853137766493, 0.92980801321679, 0.9533236132867424], 
             UndirectedEdge[52, 267] -> 
             RGBColor[
              0.4789222153161444, 0.5860393403630161, 0.9526218530734996], 
             UndirectedEdge[290, 346] -> 
             RGBColor[
              0.3750828645825507, 0.4992996579136456, 0.9451209263518141], 
             UndirectedEdge[19, 108] -> 
             RGBColor[
              0.3209765938651673, 0.4492585340761873, 0.9417896478514372], 
             UndirectedEdge[92, 327] -> 
             RGBColor[
              0.3031279877877182, 0.4350267706270088, 0.9406073946079336], 
             UndirectedEdge[151, 244] -> 
             RGBColor[
              0.28793584651295273`, 0.41931373488830953`, 0.9397328926719012],
              UndirectedEdge[114, 327] -> 
             RGBColor[
              0.32373500724345117`, 0.4548247247048681, 0.941849086287294], 
             UndirectedEdge[99, 174] -> 
             RGBColor[
              0.8533664925541351, 0.885559755956836, 0.9477463395066474], 
             UndirectedEdge[180, 282] -> 
             RGBColor[
              0.5065658976915518, 0.60785950870626, 0.9549980870909234], 
             UndirectedEdge[199, 277] -> 
             RGBColor[
              0.24180779724081597`, 0.3714857047729135, 0.9370819683790612], 
             UndirectedEdge[237, 286] -> 
             RGBColor[
              0.652334455595527, 0.7273484229582274, 0.9666519351718024], 
             UndirectedEdge[290, 313] -> 
             RGBColor[
              0.34397103520992167`, 0.4699540423686539, 0.9432263147475373], 
             UndirectedEdge[56, 237] -> 
             RGBColor[
              0.5146770314008289, 0.6168123226982427, 0.9549542854004349], 
             UndirectedEdge[203, 361] -> 
             RGBColor[
              0.32351204834138475`, 0.4530276285511149, 0.941893609121445], 
             UndirectedEdge[169, 315] -> 
             RGBColor[
              0.23198634740170132`, 0.3611627382761178, 0.9365226513402567], 
             UndirectedEdge[23, 304] -> 
             RGBColor[
              0.2162581809318601, 0.34463143809296365`, 0.9356269555275363], 
             UndirectedEdge[129, 270] -> 
             RGBColor[
              0.24363580909960866`, 0.3734070611391507, 0.9371860709501183], 
             UndirectedEdge[85, 284] -> 
             RGBColor[
              0.24265277809452013`, 0.37237383322503703`, 0.9371300887886426],
              UndirectedEdge[203, 369] -> 
             RGBColor[
              0.2744257623445868, 0.405769254195412, 0.9389395132377659], 
             UndirectedEdge[1, 222] -> 
             RGBColor[
              0.48245496695292606`, 0.5881834392083616, 0.9530999932353155], 
             UndirectedEdge[25, 205] -> 
             RGBColor[
              0.8975635807255052, 0.5810508418069508, 0.372211591742834], 
             UndirectedEdge[301, 380] -> 
             RGBColor[
              0.26115428543555863`, 0.39182009050378686`, 0.9381837222611874],
              UndirectedEdge[169, 329] -> 
             RGBColor[
              0.22791864695390707`, 0.3568873271983817, 0.9362910018173783], 
             UndirectedEdge[302, 340] -> 
             RGBColor[
              0.9905275811721996, 0.978922480132596, 0.484619975557615], 
             UndirectedEdge[205, 391] -> 
             RGBColor[
              0.8786833642677919, 0.43592922474936013`, 0.3541318751407731], 
             UndirectedEdge[96, 203] -> 
             RGBColor[
              0.28915453203189034`, 0.42125012499470316`, 0.9397782948821958],
              UndirectedEdge[4, 195] -> 
             RGBColor[
              0.2389456018045329, 0.3684773558957079, 0.9369189705832036], 
             UndirectedEdge[269, 298] -> 
             RGBColor[
              0.908244530929823, 0.9248034643520736, 0.7344530675019115], 
             UndirectedEdge[168, 220] -> 
             RGBColor[
              0.5727925024434088, 0.663632053166977, 0.9598025445321408], 
             UndirectedEdge[291, 338] -> 
             RGBColor[
              0.8453899770207604, 0.8765077587109009, 0.7950431863063177], 
             UndirectedEdge[10, 360] -> 
             RGBColor[
              0.336158799712734, 0.4655855893037951, 0.9426407193575084], 
             UndirectedEdge[87, 348] -> 
             RGBColor[
              0.27654696971548504`, 0.4079987776345412, 0.9390603128594934], 
             UndirectedEdge[259, 274] -> 
             RGBColor[
              0.22087433163626, 0.34948330516414705`, 0.9358898384811689], 
             UndirectedEdge[293, 336] -> 
             RGBColor[
              0.21111881242536762`, 0.33922963593785627`, 0.935334276094106], 
             UndirectedEdge[229, 245] -> 
             RGBColor[
              0.238397504828522, 0.36790127122256505`, 0.9368877572712566], 
             UndirectedEdge[173, 197] -> 
             RGBColor[
              0.607559522477704, 0.6724367666110929, 0.8861420267905455], 
             UndirectedEdge[19, 344] -> 
             RGBColor[
              0.2975063791842545, 0.4289298137668702, 0.9402941465258654], 
             UndirectedEdge[83, 125] -> 
             RGBColor[
              0.315433813888692, 0.4447906722692076, 0.9414242734794431], 
             UndirectedEdge[240, 315] -> 
             RGBColor[
              0.24124036831115342`, 0.3708893009907661, 0.9370496541409528], 
             UndirectedEdge[7, 154] -> 
             RGBColor[
              0.40978151173656857`, 0.5293538820737408, 0.9473318934656592], 
             UndirectedEdge[200, 225] -> 
             RGBColor[
              0.26388387983793327`, 0.3946890672869635, 0.9383391686243296], 
             UndirectedEdge[13, 140] -> 
             RGBColor[
              0.8178525622986523, 0.8580700202466935, 0.9570649175635426], 
             UndirectedEdge[104, 366] -> 
             RGBColor[
              0.9175772665295729, 0.7100796035907695, 0.25249503263058215`], 
             UndirectedEdge[116, 172] -> 
             RGBColor[
              0.3588230012593764, 0.484539273770746, 0.9441096471485195], 
             UndirectedEdge[143, 267] -> 
             RGBColor[
              0.5979215961089128, 0.6844587136389835, 0.9614897247861196], 
             UndirectedEdge[51, 395] -> 
             RGBColor[
              0.3229957435790246, 0.45088574591651165`, 0.9419227613726417], 
             UndirectedEdge[213, 224] -> 
             RGBColor[
              0.9433148110399261, 0.8071439818533458, 0.30358552172184644`], 
             UndirectedEdge[130, 362] -> 
             RGBColor[
              0.40753230852825906`, 0.5274057353029433, 0.9471885762261179], 
             UndirectedEdge[153, 278] -> 
             RGBColor[
              0.284923192180341, 0.41599975306012926`, 0.939566726836569], 
             UndirectedEdge[83, 303] -> 
             RGBColor[
              0.32124670467921895`, 0.4509003890486145, 0.9417553090105623], 
             UndirectedEdge[94, 296] -> 
             RGBColor[
              0.2808227544696311, 0.4124928985115602, 0.9393038124757853], 
             UndirectedEdge[147, 328] -> 
             RGBColor[
              0.29708750914626414`, 0.42952428212904603`, 0.9402324060605761],
              UndirectedEdge[78, 102] -> 
             RGBColor[
              0.8343283115240573, 0.26486802190174086`, 0.180506135924707], 
             UndirectedEdge[22, 45] -> 
             RGBColor[
              0.2939087453063859, 0.4262471045807297, 0.94004904029495], 
             UndirectedEdge[199, 238] -> 
             RGBColor[
              0.22751293603602638`, 0.35646089930013114`, 0.9362678971808005],
              UndirectedEdge[21, 182] -> 
             RGBColor[
              0.30050572685967525`, 0.4327952999017487, 0.9404388491913643], 
             UndirectedEdge[126, 212] -> 
             RGBColor[
              0.21146946129668887`, 0.3395981901340374, 0.9353542450285892], 
             UndirectedEdge[273, 365] -> 
             RGBColor[
              0.26583905724777945`, 0.3967440827101195, 0.9384505130853945], 
             UndirectedEdge[149, 367] -> 
             RGBColor[
              0.21976666504097775`, 0.348319077342387, 0.9358267585072135], 
             UndirectedEdge[81, 89] -> 
             RGBColor[
              0.21914913629591037`, 0.3476700154777373, 0.9357915911587338], 
             UndirectedEdge[57, 337] -> 
             RGBColor[
              0.27897537779675124`, 0.41055118849791716`, 0.9391986071072138],
              UndirectedEdge[255, 288] -> 
             RGBColor[
              0.25275048461760563`, 0.38298716301237146`, 0.9377051382369141],
              UndirectedEdge[2, 283] -> 
             RGBColor[
              0.8486058960243289, 0.3207485430755225, 0.1920578989762069], 
             UndirectedEdge[94, 128] -> 
             RGBColor[
              0.29316856057651314`, 0.42385416586161573`, 0.9400660193797667],
              UndirectedEdge[176, 393] -> 
             RGBColor[
              0.2193217433014607, 0.3478514363844869, 0.9358014208723507], 
             UndirectedEdge[65, 326] -> 
             RGBColor[
              0.4273612108963405, 0.5428967033575929, 0.9489173037481067], 
             UndirectedEdge[97, 282] -> 
             RGBColor[
              0.5445731104291971, 0.6407794460815519, 0.9574198730781076], 
             UndirectedEdge[12, 149] -> 
             RGBColor[
              0.21932780961758047`, 0.3478578124673555, 0.9358017663400795], 
             UndirectedEdge[78, 144] -> 
             RGBColor[
              0.8540420017067264, 0.3953902246963783, 0.1985614511667299], 
             UndirectedEdge[201, 348] -> 
             RGBColor[
              0.2696907546749492, 0.40079246091779686`, 0.9386698615557961], 
             UndirectedEdge[242, 381] -> 
             RGBColor[
              0.9557469344850966, 0.8527067973943953, 0.5081965742437817], 
             UndirectedEdge[43, 367] -> 
             RGBColor[
              0.22337497152266345`, 0.35211163623448327`, 0.9360322462233344],
              UndirectedEdge[111, 197] -> 
             RGBColor[
              0.931414792844472, 0.7553582824181725, 0.5263607215030722], 
             UndirectedEdge[69, 216] -> 
             RGBColor[
              0.5736600979558795, 0.6645056615859741, 0.959755124057878], 
             UndirectedEdge[197, 295] -> 
             RGBColor[
              0.6155693919444334, 0.6808556472756819, 0.8865981770071358], 
             UndirectedEdge[193, 275] -> 
             RGBColor[
              0.9072201261691099, 0.9260883634638468, 0.8817465180078601], 
             UndirectedEdge[149, 238] -> 
             RGBColor[
              0.2247208711862695, 0.3535262621159006, 0.9361088932180968], 
             UndirectedEdge[79, 349] -> 
             RGBColor[
              0.518092548976322, 0.6194343382750406, 0.9552648492680336], 
             UndirectedEdge[16, 110] -> 
             RGBColor[
              0.2487192272457111, 0.3787500559180304, 0.9374755640932957], 
             UndirectedEdge[49, 372] -> 
             RGBColor[
              0.25360695200292194`, 0.3838873645375076, 0.9377539127874779], 
             UndirectedEdge[320, 343] -> 
             RGBColor[
              0.7160472963068527, 0.7781008571267078, 0.9723325607195863], 
             UndirectedEdge[221, 358] -> 
             RGBColor[
              0.9452177942477327, 0.9230965860350502, 0.6624178282504138], 
             UndirectedEdge[240, 245] -> 
             RGBColor[
              0.2345526793265548, 0.3638601158439808, 0.9366688001468292], 
             UndirectedEdge[85, 115] -> 
             RGBColor[
              0.2399567828787064, 0.36954017131724737`, 0.9369765558494695], 
             UndirectedEdge[70, 280] -> 
             RGBColor[
              0.2584116720913199, 0.38893742998726233`, 0.9380275344885658], 
             UndirectedEdge[151, 171] -> 
             RGBColor[
              0.294524052203641, 0.4262383567855898, 0.940108081239609], 
             UndirectedEdge[23, 163] -> 
             RGBColor[
              0.22919558870789478`, 0.35822947394460614`, 0.9363637217612019],
              UndirectedEdge[255, 360] -> 
             RGBColor[
              0.28543335040527573`, 0.4171867688467138, 0.9395719503550848], 
             UndirectedEdge[165, 307] -> 
             RGBColor[
              0.7589943744265952, 0.8098564226113569, 0.9253172138967432], 
             UndirectedEdge[81, 169] -> 
             RGBColor[
              0.22020695780518662`, 0.3487818529537441, 0.9358518325287805], 
             UndirectedEdge[44, 316] -> 
             RGBColor[
              0.27611802500026855`, 0.4075479295421829, 0.9390358850925288], 
             UndirectedEdge[195, 337] -> 
             RGBColor[
              0.26521901916211443`, 0.39609238336940045`, 0.9384152028336801],
              UndirectedEdge[316, 390] -> 
             RGBColor[
              0.26028939055795897`, 0.3909110311499271, 0.9381344677774055], 
             UndirectedEdge[39, 177] -> 
             RGBColor[
              0.29750028265951367`, 0.4288050749279245, 0.9402981320155486], 
             UndirectedEdge[45, 190] -> 
             RGBColor[
              0.2683010399450559, 0.3993317826236759, 0.9385907193578275], 
             UndirectedEdge[287, 396] -> 
             RGBColor[
              0.2692564543945499, 0.400335983786869, 0.9386451287973171], 
             UndirectedEdge[136, 343] -> 
             RGBColor[
              0.6703913429941837, 0.7420698478255596, 0.9680310290897323], 
             UndirectedEdge[296, 360] -> 
             RGBColor[
              0.3059566318031602, 0.4387580388470877, 0.9407407208692202], 
             UndirectedEdge[167, 228] -> 
             RGBColor[
              0.32570332239411426`, 0.45419998876459156`, 0.9420598033482018],
              UndirectedEdge[123, 279] -> 
             RGBColor[
              0.9599728871641575, 0.901288321876893, 0.6017603738326488], 
             UndirectedEdge[33, 333] -> 
             RGBColor[
              0.1872509211104506, 0.3141429688541644, 0.9339750349931024], 
             UndirectedEdge[164, 209] -> 
             RGBColor[
              0.24728574846658016`, 0.37724337883335973`, 0.9373939295974659],
              UndirectedEdge[22, 29] -> 
             RGBColor[
              0.2663738031073146, 0.39730613451333674`, 0.9384809660710094], 
             UndirectedEdge[24, 366] -> 
             RGBColor[
              0.9017167350633479, 0.6466004732099342, 0.2397023734046333], 
             UndirectedEdge[178, 319] -> 
             RGBColor[
              0.24278605838252734`, 0.37251391925819094`, 0.9371376789038741],
              UndirectedEdge[294, 368] -> 
             RGBColor[
              0.21277052855345546`, 0.3409656943133277, 0.9354283388841056], 
             UndirectedEdge[13, 69] -> 
             RGBColor[
              0.7259993754166094, 0.7839523785382002, 0.9495242388978706], 
             UndirectedEdge[214, 295] -> 
             RGBColor[
              0.6130802218515281, 0.6797567159185416, 0.9247335360686406], 
             UndirectedEdge[80, 146] -> 
             RGBColor[
              0.4348738177323767, 0.548860724677587, 0.9495460387678236], 
             UndirectedEdge[56, 231] -> 
             RGBColor[
              0.37980957762799716`, 0.5033879783145618, 0.9454223177963867], 
             UndirectedEdge[134, 351] -> 
             RGBColor[
              0.24003567899790235`, 0.3696230961408251, 0.9369810488667414], 
             UndirectedEdge[143, 291] -> 
             RGBColor[
              0.6605679134983766, 0.7344885741946573, 0.9669884297148228], 
             UndirectedEdge[120, 320] -> 
             RGBColor[
              0.6381361673517921, 0.7160721638444079, 0.9653628908870006], 
             UndirectedEdge[132, 220] -> 
             RGBColor[
              0.6373284381573086, 0.7140480166379533, 0.9662348834814941], 
             UndirectedEdge[6, 247] -> 
             RGBColor[
              0.9501775412917424, 0.8286011525137683, 0.3806667888005933], 
             UndirectedEdge[166, 289] -> 
             RGBColor[
              0.8490971720188705, 0.3371290014779267, 0.1930332162498032], 
             UndirectedEdge[114, 392] -> 
             RGBColor[
              0.2884135464934976, 0.418609972282043, 0.9398042492586839], 
             UndirectedEdge[305, 325] -> 
             RGBColor[
              0.20723516257555488`, 0.3351476737080805, 0.9351131079805042], 
             UndirectedEdge[44, 128] -> 
             RGBColor[
              0.3120848480897295, 0.44373638339990634`, 0.9411432739695049], 
             UndirectedEdge[90, 242] -> 
             RGBColor[
              0.8120763207412868, 0.7420397918675932, 0.6122349694370377], 
             UndirectedEdge[1, 337] -> 
             RGBColor[
              0.3223631828098259, 0.4514173086943011, 0.9418429310198984], 
             UndirectedEdge[74, 224] -> 
             RGBColor[
              0.9001674923644503, 0.8962994775971298, 0.6715446357629462], 
             UndirectedEdge[160, 370] -> 
             RGBColor[
              0.8300572624743635, 0.4411399881686866, 0.44516184033330736`], 
             UndirectedEdge[30, 84] -> 
             RGBColor[
              0.1789270231889713, 0.3053940243730791, 0.9335010013205776], 
             UndirectedEdge[293, 299] -> 
             RGBColor[
              0.21267988324051307`, 0.34087042034218046`, 0.9354231767676313],
              UndirectedEdge[186, 399] -> 
             RGBColor[
              0.24167334431028037`, 0.3713443862181124, 0.9370743114835726], 
             UndirectedEdge[163, 371] -> 
             RGBColor[
              0.25850942763125473`, 0.3890401772577931, 0.9380331015219487], 
             UndirectedEdge[90, 138] -> 
             RGBColor[
              0.7814971847930072, 0.3564889751708319, 0.4345413056360933], 
             UndirectedEdge[71, 286] -> 
             RGBColor[
              0.798684946393064, 0.8430713308000524, 0.9804594287308144], 
             UndirectedEdge[60, 201] -> 
             RGBColor[
              0.3169773146449097, 0.44598337270948407`, 0.9415279039366844], 
             UndirectedEdge[128, 380] -> 
             RGBColor[
              0.2958519089446212, 0.4266745351306104, 0.9402188320996724], 
             UndirectedEdge[54, 128] -> 
             RGBColor[
              0.3891023193866603, 0.5114426050266787, 0.9460142336150148], 
             UndirectedEdge[25, 138] -> 
             RGBColor[
              0.8389217020900414, 0.3001748346284747, 0.18490477191818594`], 
             UndirectedEdge[95, 129] -> 
             RGBColor[
              0.2597315005548766, 0.39032465338441835`, 0.9381026967670542], 
             UndirectedEdge[132, 302] -> 
             RGBColor[
              0.8932496977556434, 0.905911220002762, 0.6928483915783341], 
             UndirectedEdge[15, 100] -> 
             RGBColor[
              0.34023750094859895`, 0.4686666959527124, 0.9429171480552854], 
             UndirectedEdge[33, 63] -> 
             RGBColor[
              0.5687512197366357, 0.5886439817299056, 0.6135098819197802], 
             UndirectedEdge[275, 338] -> 
             RGBColor[
              0.9931945073855819, 0.9905965803379274, 0.7001396493067182], 
             UndirectedEdge[252, 277] -> 
             RGBColor[
              0.2410729775793306, 0.3707133627184349, 0.9370401214864079], 
             UndirectedEdge[146, 192] -> 
             RGBColor[
              0.43991049068666355`, 0.5532232376400468, 0.9498669711147159], 
             UndirectedEdge[237, 254] -> 
             RGBColor[
              0.5239652108029346, 0.6244175883504002, 0.9556676072236672], 
             UndirectedEdge[37, 236] -> 
             RGBColor[
              0.2501608630823501, 0.3802653065873294, 0.9375576631214831], 
             UndirectedEdge[265, 362] -> 
             RGBColor[
              0.4982768620774518, 0.6022414244020411, 0.9540103792474512], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.31424207897729384`, 0.44465323780495364`, 0.9413155746707285],
              UndirectedEdge[341, 379] -> 
             RGBColor[
              0.2212705365436844, 0.3498997416426921, 0.9359124017645142], 
             UndirectedEdge[324, 380] -> 
             RGBColor[
              0.27272415965434393`, 0.4039807618801248, 0.9388426094818522], 
             UndirectedEdge[63, 264] -> 
             RGBColor[
              0.5742960336344989, 0.5944719326980662, 0.6138256508684465], 
             UndirectedEdge[153, 337] -> 
             RGBColor[
              0.30108704647180895`, 0.43298898876801645`, 0.9404872344261885],
              UndirectedEdge[112, 155] -> 
             RGBColor[
              0.31673339546261187`, 0.44837192664657105`, 0.9414171693125639],
              UndirectedEdge[10, 177] -> 
             RGBColor[
              0.34191718866131093`, 0.47057321638600846`, 0.9430076388093683],
              UndirectedEdge[238, 367] -> 
             RGBColor[
              0.2242689013320493, 0.35305121314257126`, 0.9360831542035284], 
             UndirectedEdge[87, 228] -> 
             RGBColor[
              0.32899794708810315`, 0.4576628482092444, 0.9422474273505641], 
             UndirectedEdge[66, 352] -> 
             RGBColor[
              0.983468511290683, 0.9548785202107917, 0.47692950075693274`], 
             UndirectedEdge[86, 386] -> 
             RGBColor[
              0.31994974783175406`, 0.4507870854822257, 0.9416356849958585], 
             UndirectedEdge[52, 133] -> 
             RGBColor[
              0.34195185422260005`, 0.4695411184843201, 0.9430487372114036], 
             UndirectedEdge[105, 112] -> 
             RGBColor[
              0.37313264037284266`, 0.49761047172431544`, 0.944996659789687], 
             UndirectedEdge[4, 258] -> 
             RGBColor[
              0.24256487951038092`, 0.3722814462400146, 0.9371250830943101], 
             UndirectedEdge[141, 339] -> 
             RGBColor[
              0.36291222472736206`, 0.48875806138522676`, 0.9443454239423157],
              UndirectedEdge[251, 282] -> 
             RGBColor[
              0.7345888082776114, 0.7926044746200289, 0.9741756038265081], 
             UndirectedEdge[94, 390] -> 
             RGBColor[
              0.26321162125265696`, 0.393982480890182, 0.9383008844924156], 
             UndirectedEdge[239, 337] -> 
             RGBColor[
              0.304629125717821, 0.43605695978083275`, 0.9407129325836068], 
             UndirectedEdge[80, 243] -> 
             RGBColor[
              0.3113941751763021, 0.44225199630561496`, 0.9411317115948465], 
             UndirectedEdge[366, 382] -> 
             RGBColor[
              0.9000306839899277, 0.6389445090727658, 0.23829549106007777`], 
             UndirectedEdge[99, 306] -> 
             RGBColor[
              0.9742518584397497, 0.947471002545973, 0.6306628392778444], 
             UndirectedEdge[214, 261] -> 
             RGBColor[
              0.5816107316395323, 0.6466802864248125, 0.9229413951560062], 
             UndirectedEdge[21, 60] -> 
             RGBColor[
              0.33522274220732345`, 0.4647748233402267, 0.9425810746009868], 
             UndirectedEdge[60, 159] -> 
             RGBColor[
              0.344481468526375, 0.4727942667206735, 0.9431710324548666], 
             UndirectedEdge[9, 300] -> 
             RGBColor[
              0.8471105512692876, 0.32999212991331434`, 0.19144930036229538`],
              UndirectedEdge[114, 369] -> 
             RGBColor[
              0.29316591487643506`, 0.4236050127700691, 0.9400748896075932], 
             UndirectedEdge[112, 350] -> 
             RGBColor[
              0.380831960891249, 0.5042792361782578, 0.945487253684878], 
             UndirectedEdge[18, 357] -> 
             RGBColor[
              0.8104483343258964, 0.8526146189392179, 0.9729726519131952], 
             UndirectedEdge[71, 320] -> 
             RGBColor[
              0.7905070166194959, 0.8366826699063725, 0.9796443291180839], 
             UndirectedEdge[226, 255] -> 
             RGBColor[
              0.24955450248561023`, 0.3796279831546734, 0.9375231317825289], 
             UndirectedEdge[208, 258] -> 
             RGBColor[
              0.24300998977440907`, 0.3727492853491289, 0.9371504314653649], 
             UndirectedEdge[11, 358] -> 
             RGBColor[
              0.9460196672175634, 0.8199629343977746, 0.2948506005623025], 
             UndirectedEdge[274, 299] -> 
             RGBColor[
              0.22242833776812287`, 0.35111666413841447`, 0.9359783368314325],
              UndirectedEdge[147, 372] -> 
             RGBColor[
              0.2681076692483716, 0.3991285377610505, 0.9385797071827175], 
             UndirectedEdge[335, 337] -> 
             RGBColor[
              0.282630755782611, 0.41439322252540617`, 0.9394067754758614], 
             UndirectedEdge[36, 218] -> 
             RGBColor[
              0.7148705349959443, 0.7760303162882036, 0.9733069680605333], 
             UndirectedEdge[262, 300] -> 
             RGBColor[
              0.9143198191766551, 0.7735717057130247, 0.6093343830407926], 
             UndirectedEdge[109, 136] -> 
             RGBColor[
              0.8063392816861509, 0.8465292984919313, 0.8553084156056971], 
             UndirectedEdge[219, 241] -> 
             RGBColor[
              0.36907489621161843`, 0.49245160059313714`, 0.9447983082263991],
              UndirectedEdge[37, 348] -> 
             RGBColor[
              0.2563773742968305, 0.38679925402332427`, 0.9379116842386436], 
             UndirectedEdge[291, 384] -> 
             RGBColor[
              0.7224597094549363, 0.7831102830141358, 0.9729716901347794], 
             UndirectedEdge[10, 241] -> 
             RGBColor[
              0.32644391245681637`, 0.4555267851602728, 0.9420818996386419], 
             UndirectedEdge[131, 314] -> 
             RGBColor[
              0.9241390802378358, 0.8369963141242439, 0.6246293196235244], 
             UndirectedEdge[1, 41] -> 
             RGBColor[
              0.3504016747423545, 0.4779220517867386, 0.943548262759916], 
             UndirectedEdge[78, 400] -> 
             RGBColor[
              0.6910996022530893, 0.3857187124605388, 0.44048429308124526`], 
             UndirectedEdge[191, 357] -> 
             RGBColor[
              0.6772717325975683, 0.7478090920518159, 0.9684677749072899], 
             UndirectedEdge[215, 352] -> 
             RGBColor[
              0.8775768432069465, 0.42947694484883064`, 0.31243310907337485`],
              UndirectedEdge[96, 369] -> 
             RGBColor[
              0.27218271865818583`, 0.40341167306382075`, 0.9388117752181111],
              UndirectedEdge[212, 293] -> 
             RGBColor[
              0.2110641194014849, 0.3391721501020175, 0.935331161407307], 
             UndirectedEdge[66, 107] -> 
             RGBColor[
              0.8837394154703582, 0.5082507082788483, 0.23971449523593602`], 
             UndirectedEdge[146, 159] -> 
             RGBColor[
              0.433382915877228, 0.5475693804255631, 0.9494510398199664], 
             UndirectedEdge[11, 207] -> 
             RGBColor[
              0.931659240059644, 0.7667586905843885, 0.26386962426942273`], 
             UndirectedEdge[99, 218] -> 
             RGBColor[
              0.9440956875300477, 0.9571661739174645, 0.9565961673645738], 
             UndirectedEdge[131, 217] -> 
             RGBColor[
              0.8560391728343671, 0.3610728728529158, 0.19848501927427087`], 
             UndirectedEdge[81, 163] -> 
             RGBColor[
              0.23234434831161116`, 0.36153901993100174`, 0.9365430389624612],
              UndirectedEdge[50, 54] -> 
             RGBColor[
              0.4530695590105145, 0.5668252864420751, 0.9500963936878091], 
             UndirectedEdge[120, 286] -> 
             RGBColor[
              0.6463140971253603, 0.7224608247380875, 0.966177990499731], 
             UndirectedEdge[17, 253] -> 
             RGBColor[
              0.43861619159981363`, 0.5520971476660097, 0.9497858901980598], 
             UndirectedEdge[45, 365] -> 
             RGBColor[
              0.2758699057154388, 0.4072871404421556, 0.9390217550663172], 
             UndirectedEdge[35, 188] -> 
             RGBColor[
              0.27406348456255775`, 0.4053884772767613, 0.9389188820540213], 
             UndirectedEdge[99, 279] -> 
             RGBColor[
              0.9618886205302903, 0.9027170726846294, 0.5985175369470697], 
             UndirectedEdge[107, 363] -> 
             RGBColor[
              0.8469826176919709, 0.3578276219699569, 0.19245526474329921`], 
             UndirectedEdge[105, 271] -> 
             RGBColor[
              0.36206599633926584`, 0.4878440595940245, 0.9442981318263466], 
             UndirectedEdge[191, 219] -> 
             RGBColor[
              0.5630206032370957, 0.6553990201614963, 0.9591704044347413], 
             UndirectedEdge[177, 339] -> 
             RGBColor[
              0.34383450141698674`, 0.4722338963280338, 0.9431298082827468], 
             UndirectedEdge[80, 167] -> 
             RGBColor[
              0.30898293281547473`, 0.43971762770278966`, 0.9409943949095109],
              UndirectedEdge[48, 56] -> 
             RGBColor[
              0.43818896314994105`, 0.5539589886879809, 0.9491419911499963], 
             UndirectedEdge[42, 136] -> 
             RGBColor[
              0.7754039881303256, 0.825013733522431, 0.9782569627328132], 
             UndirectedEdge[77, 102] -> 
             RGBColor[
              0.8226530582708597, 0.3884797771570075, 0.43860370531557835`], 
             UndirectedEdge[73, 203] -> 
             RGBColor[
              0.2672567761777972, 0.39823419519414005`, 0.9385312500811318], 
             UndirectedEdge[35, 284] -> 
             RGBColor[
              0.26251957032631373`, 0.3932550914880322, 0.9382614732159579], 
             UndirectedEdge[274, 367] -> 
             RGBColor[
              0.22502133411732347`, 0.3538420677068884, 0.9361260041375251], 
             UndirectedEdge[33, 310] -> 
             RGBColor[
              0.18075976862012855`, 0.3073203560239972, 0.9336053734615781], 
             UndirectedEdge[175, 295] -> 
             RGBColor[
              0.21065974573871524`, 0.33874712774367555`, 0.9353081329254295],
              UndirectedEdge[70, 75] -> 
             RGBColor[
              0.2609941288153654, 0.3916517557414475, 0.9381746015785979], 
             UndirectedEdge[57, 258] -> 
             RGBColor[
              0.26307034244570515`, 0.39383398790648194`, 0.9382928388733629],
              UndirectedEdge[70, 145] -> 
             RGBColor[
              0.2579170969731607, 0.3884176001802034, 0.937999369167245], 
             UndirectedEdge[12, 336] -> 
             RGBColor[
              0.21472177259901426`, 0.343016575521228, 0.9355394593458932], 
             UndirectedEdge[18, 216] -> 
             RGBColor[
              0.8021540700559975, 0.8461350766528297, 0.9721459571650781], 
             UndirectedEdge[158, 311] -> 
             RGBColor[
              0.5112449698673547, 0.6140907237185725, 0.9546662232614405], 
             UndirectedEdge[8, 36] -> 
             RGBColor[
              0.41499862525248465`, 0.5320708731128857, 0.9481621689265505], 
             UndirectedEdge[119, 200] -> 
             RGBColor[
              0.2555790109882331, 0.38596012356683096`, 0.9378662186292916], 
             UndirectedEdge[181, 362] -> 
             RGBColor[
              0.4859856594800335, 0.59226287242109, 0.9530427707548238], 
             UndirectedEdge[9, 306] -> 
             RGBColor[
              0.8739036638820636, 0.43610910948372067`, 0.2279473934252837], 
             UndirectedEdge[82, 253] -> 
             RGBColor[
              0.3604664667584644, 0.48663966875993736`, 0.9441895824072364], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.47490752561281135`, 0.5839962194337451, 0.9519697664459024], 
             UndirectedEdge[146, 314] -> 
             RGBColor[
              0.7305716091219763, 0.7886632000372383, 0.9746741748807553], 
             UndirectedEdge[27, 277] -> 
             RGBColor[
              0.277614773953709, 0.4091211075916136, 0.9391211227311855], 
             UndirectedEdge[6, 302] -> 
             RGBColor[
              0.9903122885265428, 0.9784619909329613, 0.461186699710061], 
             UndirectedEdge[93, 296] -> 
             RGBColor[
              0.27337982614775685`, 0.40466990893635857`, 0.9388799487186803],
              UndirectedEdge[153, 284] -> 
             RGBColor[
              0.2807144253547577, 0.4115760722752118, 0.9393270437921646], 
             UndirectedEdge[43, 199] -> 
             RGBColor[
              0.2266190062266405, 0.3555213223920431, 0.9362169892006067], 
             UndirectedEdge[213, 250] -> 
             RGBColor[
              0.9495976653580405, 0.8370624678097084, 0.5459950352795185], 
             UndirectedEdge[3, 232] -> 
             RGBColor[
              0.4478181508511241, 0.5603378585517222, 0.9502975085529524], 
             UndirectedEdge[5, 235] -> 
             RGBColor[
              0.7907683520113988, 0.8366469590661592, 0.9797340301887447], 
             UndirectedEdge[25, 391] -> 
             RGBColor[
              0.8392710067008462, 0.30285974293337714`, 0.18523926640797578`],
              UndirectedEdge[288, 341] -> 
             RGBColor[
              0.2333048519876323, 0.3625485701939505, 0.9365977382258728], 
             UndirectedEdge[181, 265] -> 
             RGBColor[
              0.5796034948121, 0.6695872537851715, 0.9600476567506184], 
             UndirectedEdge[295, 363] -> 
             RGBColor[
              0.6558041124528853, 0.4364203968060595, 0.4503645866246823], 
             UndirectedEdge[278, 284] -> 
             RGBColor[
              0.24820685681048946`, 0.3782115221044505, 0.9374463853549939], 
             UndirectedEdge[167, 351] -> 
             RGBColor[
              0.2646469792533301, 0.39549113315584294`, 0.938382626007132], 
             UndirectedEdge[198, 311] -> 
             RGBColor[
              0.6729318339898602, 0.7425873401033549, 0.9693093430316602], 
             UndirectedEdge[54, 328] -> 
             RGBColor[
              0.38071433549214345`, 0.504177354969577, 0.9454797586984591], 
             UndirectedEdge[261, 310] -> 
             RGBColor[
              0.18101326007132248`, 0.3075867916114884, 0.9336198094247166], 
             UndirectedEdge[68, 319] -> 
             RGBColor[
              0.2591541477712746, 0.38971781900257185`, 0.9380698173801449], 
             UndirectedEdge[100, 141] -> 
             RGBColor[
              0.3683390164516885, 0.49345847561835543`, 0.9446912143122663], 
             UndirectedEdge[139, 325] -> 
             RGBColor[
              0.21136919529828035`, 0.33949280421247857`, 0.9353485350283102],
              UndirectedEdge[123, 338] -> 
             RGBColor[
              0.9842922541931751, 0.9852712070496027, 0.7740485310892328], 
             UndirectedEdge[317, 370] -> 
             RGBColor[
              0.9109218435003366, 0.9293228266692952, 0.8943803638429948], 
             UndirectedEdge[160, 400] -> 
             RGBColor[
              0.6828553570582352, 0.32234983124161043`, 0.43258959457210977`],
              UndirectedEdge[150, 266] -> 
             RGBColor[
              0.2627993543398047, 0.39354916222554226`, 0.9382774065016228], 
             UndirectedEdge[134, 201] -> 
             RGBColor[
              0.255376576823433, 0.3857473524245587, 0.9378546903030808], 
             UndirectedEdge[161, 251] -> 
             RGBColor[
              0.6268762447587527, 0.7046334098478555, 0.9658130763902817], 
             UndirectedEdge[86, 371] -> 
             RGBColor[
              0.2862909803459218, 0.418240350613087, 0.9396152198499249], 
             UndirectedEdge[105, 350] -> 
             RGBColor[
              0.4250434301807523, 0.5425729887437677, 0.948304369413338], 
             UndirectedEdge[54, 362] -> 
             RGBColor[
              0.4283252562737149, 0.5454155415561164, 0.9485134844699766], 
             UndirectedEdge[4, 208] -> 
             RGBColor[
              0.23264160776787357`, 0.36185145846687167`, 0.9365599674487393],
              UndirectedEdge[176, 294] -> 
             RGBColor[
              0.21429151975408078`, 0.34256435250159695`, 0.9355149570828762],
              UndirectedEdge[113, 170] -> 
             RGBColor[
              0.6207426403130438, 0.7003977045332692, 0.9649634716556403], 
             UndirectedEdge[14, 205] -> 
             RGBColor[
              0.9948127950472943, 0.9913250536932577, 0.6776287249236647], 
             UndirectedEdge[262, 306] -> 
             RGBColor[
              0.9545094880958191, 0.9327471750686342, 0.664081522635275], 
             UndirectedEdge[47, 128] -> 
             RGBColor[
              0.3800525355791988, 0.5036041371480152, 0.945437589393213], 
             UndirectedEdge[257, 382] -> 
             RGBColor[
              0.847998420564194, 0.3276060041143898, 0.1919388579401936], 
             UndirectedEdge[165, 228] -> 
             RGBColor[
              0.4503029757321284, 0.5622948057743279, 0.9505097967266875], 
             UndirectedEdge[72, 341] -> 
             RGBColor[
              0.22465511090045148`, 0.353457143886063, 0.936105148267103], 
             UndirectedEdge[50, 116] -> 
             RGBColor[
              0.4351844866677396, 0.551334135708637, 0.9489567726932759], 
             UndirectedEdge[230, 247] -> 
             RGBColor[
              0.9379323861994966, 0.7878165939520326, 0.28877547346743154`], 
             UndirectedEdge[45, 100] -> 
             RGBColor[
              0.33605658973236274`, 0.46427229317936647`, 0.9426790513466246],
              UndirectedEdge[95, 386] -> 
             RGBColor[
              0.3105708355384495, 0.4409292540045774, 0.9411015698156122], 
             UndirectedEdge[182, 244] -> 
             RGBColor[
              0.27406524356197104`, 0.4053903260966717, 0.9389189822264357], 
             UndirectedEdge[104, 382] -> 
             RGBColor[
              0.9163275048198573, 0.7044047275562138, 0.25145220082553266`], 
             UndirectedEdge[58, 210] -> 
             RGBColor[
              0.2993673513669953, 0.4319844456460439, 0.9403598998348177], 
             UndirectedEdge[102, 370] -> 
             RGBColor[
              0.8232702315483972, 0.3889718943757936, 0.4386625718537469], 
             UndirectedEdge[1, 161] -> 
             RGBColor[
              0.3957098398241182, 0.5171657071259712, 0.9464352589744887], 
             UndirectedEdge[153, 356] -> 
             RGBColor[
              0.4179045828513193, 0.5346231354649491, 0.9483375893388631], 
             UndirectedEdge[1, 154] -> 
             RGBColor[
              0.39507053133992803`, 0.5166119702495444, 0.9463945228031945], 
             UndirectedEdge[341, 399] -> 
             RGBColor[
              0.22823136465623345`, 0.3572160133309742, 0.9363088106279014], 
             UndirectedEdge[373, 395] -> 
             RGBColor[
              0.2616949498810116, 0.3923883631160637, 0.9382145123015146], 
             UndirectedEdge[190, 266] -> 
             RGBColor[
              0.24805045871485498`, 0.3780471377897267, 0.9374374787148178], 
             UndirectedEdge[73, 85] -> 
             RGBColor[
              0.24221172142071856`, 0.3719102546962633, 0.9371049712635544], 
             UndirectedEdge[221, 250] -> 
             RGBColor[
              0.955043066437527, 0.9649644792718597, 0.9185889663100797], 
             UndirectedEdge[23, 353] -> 
             RGBColor[
              0.21189878814995255`, 0.34004943987771225`, 0.9353786945577505],
              UndirectedEdge[171, 270] -> 
             RGBColor[
              0.2613998670743656, 0.3920782123769482, 0.9381977077722119], 
             UndirectedEdge[277, 396] -> 
             RGBColor[
              0.26805617252313807`, 0.399074411437749, 0.9385767745203981], 
             UndirectedEdge[315, 371] -> 
             RGBColor[
              0.25765991596594773`, 0.388147286635405, 0.9379847230893494], 
             UndirectedEdge[207, 391] -> 
             RGBColor[
              0.8602124662496932, 0.37157721452125336`, 0.2015946277006471], 
             UndirectedEdge[160, 247] -> 
             RGBColor[
              0.8553209010665972, 0.37472976272458436`, 0.19858547691764086`],
              UndirectedEdge[193, 232] -> 
             RGBColor[
              0.6739481277148399, 0.7434424430617759, 0.9693547854990241], 
             UndirectedEdge[22, 91] -> 
             RGBColor[
              0.2774698045998931, 0.40896873560916513`, 0.9391128669409485], 
             UndirectedEdge[78, 247] -> 
             RGBColor[
              0.8635651462614512, 0.4380986439435127, 0.20648017542677632`], 
             UndirectedEdge[87, 192] -> 
             RGBColor[
              0.3173142304637505, 0.44754300010990244`, 0.9415029512587653], 
             UndirectedEdge[226, 294] -> 
             RGBColor[
              0.22569678935260098`, 0.35455201398550057`, 0.9361644703139277],
              UndirectedEdge[177, 311] -> 
             RGBColor[
              0.42064126980492156`, 0.5369664823599833, 0.9485194381294991], 
             UndirectedEdge[189, 200] -> 
             RGBColor[
              0.28560319899075254`, 0.41751744880094743`, 0.9395760517192293],
              UndirectedEdge[67, 184] -> 
             RGBColor[
              0.2153543932680198, 0.3436814999548199, 0.9355754861571146], 
             UndirectedEdge[33, 256] -> 
             RGBColor[
              0.202124876078153, 0.3297764385884332, 0.9348220847244686], 
             UndirectedEdge[176, 226] -> 
             RGBColor[
              0.22722875741095702`, 0.3561622095472178, 0.9362517136285073], 
             UndirectedEdge[145, 162] -> 
             RGBColor[
              0.2420540274215789, 0.3717445083047905, 0.9370959908235907], 
             UndirectedEdge[286, 343] -> 
             RGBColor[
              0.7242252260804207, 0.7844895180203877, 0.9731476603323168], 
             UndirectedEdge[13, 18] -> 
             RGBColor[
              0.9544933475167275, 0.9655817936050558, 0.9619150720050708], 
             UndirectedEdge[86, 308] -> 
             RGBColor[
              0.28081236703944734`, 0.4124819806638359, 0.9393032209270034], 
             UndirectedEdge[364, 377] -> 
             RGBColor[
              0.3822045767059832, 0.5054681270073037, 0.9455747155508364], 
             UndirectedEdge[90, 152] -> 
             RGBColor[
              0.4447109838202162, 0.5402113672268555, 0.9525399126533038], 
             UndirectedEdge[1, 153] -> 
             RGBColor[
              0.33870689706262624`, 0.4677926231571751, 0.9428030818674495], 
             UndirectedEdge[92, 114] -> 
             RGBColor[
              0.3082708613262549, 0.43948126919774927`, 0.9409350939621447], 
             UndirectedEdge[132, 219] -> 
             RGBColor[
              0.6232051027562657, 0.7024156086050097, 0.9651690328906872], 
             UndirectedEdge[107, 215] -> 
             RGBColor[
              0.8325745188075454, 0.25138760256576187`, 0.17882670203874967`],
              UndirectedEdge[240, 319] -> 
             RGBColor[
              0.24039509168830792`, 0.37000086166652213`, 0.9370015168877566],
              UndirectedEdge[58, 110] -> 
             RGBColor[
              0.2771944683256158, 0.40867933972757164`, 0.939097186947452], 
             UndirectedEdge[67, 85] -> 
             RGBColor[
              0.22712666696496037`, 0.35605490601556716`, 0.9362458997286371],
              UndirectedEdge[125, 344] -> 
             RGBColor[
              0.2993073040655987, 0.4308227000023955, 0.9403967065336283], 
             UndirectedEdge[198, 219] -> 
             RGBColor[
              0.6368387366010516, 0.7131188895622445, 0.9665139522992866], 
             UndirectedEdge[16, 325] -> 
             RGBColor[
              0.22671411419860138`, 0.35562128690076766`, 0.9362224054589102],
              UndirectedEdge[119, 390] -> 
             RGBColor[
              0.2533988208527428, 0.3836686055023921, 0.9377420600263777], 
             UndirectedEdge[7, 153] -> 
             RGBColor[
              0.3534178774592668, 0.48053453498137155`, 0.9437404525299142], 
             UndirectedEdge[23, 164] -> 
             RGBColor[
              0.22797821780387265`, 0.3569499399387055, 0.9362943942891566], 
             UndirectedEdge[46, 373] -> 
             RGBColor[
              0.26731905714517273`, 0.3982996564396932, 0.9385347968900875], 
             UndirectedEdge[301, 316] -> 
             RGBColor[
              0.2555487063727525, 0.3859282714945373, 0.9378644928262717], 
             UndirectedEdge[22, 150] -> 
             RGBColor[
              0.28145958694833023`, 0.41316224982418415`, 0.9393400791433381],
              UndirectedEdge[161, 327] -> 
             RGBColor[
              0.3750143899762539, 0.4992403486513052, 0.9451165632104506], 
             UndirectedEdge[123, 281] -> 
             RGBColor[
              0.8031450913153519, 0.8462354724290008, 0.9462830761380823], 
             UndirectedEdge[111, 160] -> 
             RGBColor[
              0.8443444384602433, 0.3254221656360573, 0.18945406845122992`], 
             UndirectedEdge[277, 287] -> 
             RGBColor[
              0.25901311175833214`, 0.3895695812107696, 0.9380617855878519], 
             UndirectedEdge[48, 120] -> 
             RGBColor[
              0.49591060473188847`, 0.6008847208403402, 0.9536681725336434], 
             UndirectedEdge[6, 224] -> 
             RGBColor[
              0.9845045256450395, 0.9588710430060774, 0.43862463761941295`], 
             UndirectedEdge[103, 313] -> 
             RGBColor[
              0.31368725505562867`, 0.4437237541060531, 0.9412966590550009], 
             UndirectedEdge[8, 60] -> 
             RGBColor[
              0.33392414851101215`, 0.4636500467496988, 0.9424983293589592], 
             UndirectedEdge[284, 392] -> 
             RGBColor[
              0.24597365109495675`, 0.3758642813040053, 0.9373192075932261], 
             UndirectedEdge[218, 279] -> 
             RGBColor[
              0.9278567069516805, 0.8766750653657154, 0.6332052588371474], 
             UndirectedEdge[135, 221] -> 
             RGBColor[
              0.7125684826637311, 0.7740760557086418, 0.9732239792621271], 
             UndirectedEdge[95, 309] -> 
             RGBColor[
              0.2762844897757238, 0.4077228945756627, 0.9390453650152284], 
             UndirectedEdge[80, 385] -> 
             RGBColor[
              0.4549187217473041, 0.5651340807695402, 0.9511240470387816], 
             UndirectedEdge[272, 398] -> 
             RGBColor[
              0.7932211653132651, 0.8392589768677534, 0.976436715616906], 
             UndirectedEdge[33, 264] -> 
             RGBColor[
              0.18448620056776344`, 0.31123707227039327`, 0.9338175882482339],
              UndirectedEdge[76, 366] -> 
             RGBColor[
              0.8650564392084171, 0.45610051687506004`, 0.2081710082451261], 
             UndirectedEdge[41, 258] -> 
             RGBColor[
              0.29687678880049106`, 0.4264012168061446, 0.9403266470848042], 
             UndirectedEdge[174, 232] -> 
             RGBColor[
              0.6270810139261389, 0.7068104580353534, 0.9646885621008761], 
             UndirectedEdge[61, 307] -> 
             RGBColor[
              0.9892929392100926, 0.9881701251038566, 0.7056981044009731], 
             UndirectedEdge[35, 392] -> 
             RGBColor[
              0.2644951314363644, 0.3953315314725043, 0.9383739784985945], 
             UndirectedEdge[212, 259] -> 
             RGBColor[
              0.2109589325174653, 0.33906159201767927`, 0.935325171169872], 
             UndirectedEdge[73, 110] -> 
             RGBColor[
              0.24934696023893294`, 0.3794098430944771, 0.9375113125586119], 
             UndirectedEdge[122, 228] -> 
             RGBColor[
              0.40697238168033323`, 0.5269207548100117, 0.9471528981824919], 
             UndirectedEdge[41, 203] -> 
             RGBColor[
              0.31610894590117855`, 0.4466154333081559, 0.9414218899802616], 
             UndirectedEdge[361, 385] -> 
             RGBColor[
              0.46552378312677223`, 0.5743196519105522, 0.9517997921721937], 
             UndirectedEdge[9, 269] -> 
             RGBColor[
              0.8814646016218102, 0.4613851934974453, 0.276770128989661], 
             UndirectedEdge[192, 228] -> 
             RGBColor[
              0.35617346073846823`, 0.48292128271817314`, 0.9439160358597984],
              UndirectedEdge[47, 265] -> 
             RGBColor[
              0.5128933077983199, 0.6149014550415344, 0.9549417262439694], 
             UndirectedEdge[338, 398] -> 
             RGBColor[
              0.966856888277283, 0.9722679396973218, 0.803562057713115], 
             UndirectedEdge[71, 79] -> 
             RGBColor[
              0.730962985173496, 0.7893766931257962, 0.9742494771038676], 
             UndirectedEdge[77, 78] -> 
             RGBColor[
              0.83768433439168, 0.5040167521688288, 0.45299767230427423`], 
             UndirectedEdge[89, 164] -> 
             RGBColor[
              0.2305606666537099, 0.3596642574165986, 0.9364414609307642], 
             UndirectedEdge[123, 235] -> 
             RGBColor[
              0.8571949059772741, 0.8886183762780113, 0.9515616992620775], 
             UndirectedEdge[72, 393] -> 
             RGBColor[
              0.22527325394479547`, 0.3541068514182011, 0.9361403505990177], 
             UndirectedEdge[240, 371] -> 
             RGBColor[
              0.2556260580342823, 0.3860095729951837, 0.9378688978889642], 
             UndirectedEdge[196, 303] -> 
             RGBColor[
              0.29376792821553643`, 0.42609909688992764`, 0.9400410209699464],
              UndirectedEdge[105, 170] -> 
             RGBColor[
              0.4311568725166687, 0.5478681452245924, 0.9486939125530778], 
             UndirectedEdge[195, 208] -> 
             RGBColor[
              0.239390712068561, 0.3689451950048222, 0.9369443189542583], 
             UndirectedEdge[100, 180] -> 
             RGBColor[
              0.3714420538172285, 0.49614617062119337`, 0.9448889371092903], 
             UndirectedEdge[39, 355] -> 
             RGBColor[
              0.25200661552040216`, 0.3822053094271858, 0.9376627759922841], 
             UndirectedEdge[244, 397] -> 
             RGBColor[
              0.2546928621186111, 0.3850287249197748, 0.9378157537621064], 
             UndirectedEdge[225, 355] -> 
             RGBColor[
              0.24401463577453056`, 0.373805231993492, 0.9372076445688313], 
             UndirectedEdge[335, 354] -> 
             RGBColor[
              0.28014580760645524`, 0.41178138443745216`, 0.9392652613533807],
              UndirectedEdge[97, 100] -> 
             RGBColor[
              0.4094492665548738, 0.5290661079964851, 0.9473107230964745], 
             UndirectedEdge[2, 107] -> 
             RGBColor[
              0.8253733561939098, 0.19603631114778033`, 0.17193086058738233`],
              UndirectedEdge[128, 225] -> 
             RGBColor[
              0.2916606290262991, 0.42226923419395845`, 0.939980144908767], 
             UndirectedEdge[96, 228] -> 
             RGBColor[
              0.3273843328541551, 0.4559668373403135, 0.9421555344070691], 
             UndirectedEdge[262, 307] -> 
             RGBColor[
              0.9619414175862754, 0.970962445386637, 0.9415105792405329], 
             UndirectedEdge[86, 334] -> 
             RGBColor[
              0.28096769579564274`, 0.4126452410350092, 0.9393120666698803], 
             UndirectedEdge[255, 399] -> 
             RGBColor[
              0.24767699728620676`, 0.3776546061493952, 0.937416210638943], 
             UndirectedEdge[138, 242] -> 
             RGBColor[
              0.8523441975821417, 0.33778208735566917`, 0.19515676243732563`],
              UndirectedEdge[27, 396] -> 
             RGBColor[
              0.28785811658992677`, 0.419887510167713, 0.9397044659406507], 
             UndirectedEdge[163, 209] -> 
             RGBColor[
              0.2485031193706023, 0.3785229128392603, 0.9374632570695112], 
             UndirectedEdge[63, 202] -> 
             RGBColor[
              0.8904134348354518, 0.5799973668804237, 0.23222877843525258`], 
             UndirectedEdge[347, 372] -> 
             RGBColor[
              0.26576379522245486`, 0.3966649775496154, 0.9384462270243925], 
             UndirectedEdge[174, 275] -> 
             RGBColor[
              0.8603530123804088, 0.8894563784374243, 0.877080294609712], 
             UndirectedEdge[209, 315] -> 
             RGBColor[
              0.24765360770529532`, 0.37763002221687225`, 0.9374148786369118],
              UndirectedEdge[177, 374] -> 
             RGBColor[
              0.29900611365793894`, 0.43038779878246913`, 0.9403838868632315],
              UndirectedEdge[214, 215] -> 
             RGBColor[
              0.8741164959208666, 0.4286482676335819, 0.4148531698939346], 
             UndirectedEdge[160, 185] -> 
             RGBColor[
              0.8275485490979918, 0.21275579698416247`, 0.17401382776886018`],
              UndirectedEdge[63, 268] -> 
             RGBColor[
              0.8643996842677903, 0.38004428071919283`, 0.20731798151333095`],
              UndirectedEdge[48, 196] -> 
             RGBColor[
              0.3616835055171287, 0.4866932494532377, 0.9443037663378753], 
             UndirectedEdge[34, 95] -> 
             RGBColor[
              0.29703377047989377`, 0.4292041286435296, 0.9402390000004376], 
             UndirectedEdge[84, 333] -> 
             RGBColor[
              0.18724373492288626`, 0.3141354157154036, 0.9339746257503516], 
             UndirectedEdge[102, 224] -> 
             RGBColor[
              0.8714185263761622, 0.40940826259323077`, 0.23072477431729355`],
              UndirectedEdge[105, 326] -> 
             RGBColor[
              0.37836717266856673`, 0.5021443605036287, 0.9453301995588554], 
             UndirectedEdge[134, 236] -> 
             RGBColor[
              0.24242453355158805`, 0.3721339337388756, 0.9371170905995801], 
             UndirectedEdge[92, 161] -> 
             RGBColor[
              0.35955024405905767`, 0.48389689314418627`, 0.9442025708853012],
              UndirectedEdge[77, 185] -> 
             RGBColor[
              0.8255820238084367, 0.4109930897597075, 0.44140848602215565`], 
             UndirectedEdge[178, 329] -> 
             RGBColor[
              0.23956363455757862`, 0.36912694750469877`, 0.9369541666341921],
              UndirectedEdge[185, 400] -> 
             RGBColor[
              0.6789972916698459, 0.2926950500514175, 0.4288951067991266], 
             UndirectedEdge[317, 333] -> 
             RGBColor[
              0.5930937593564782, 0.6566344401985723, 0.8697228003417041], 
             UndirectedEdge[106, 215] -> 
             RGBColor[
              0.8623570702962337, 0.4198781072570229, 0.43475881012703244`], 
             UndirectedEdge[14, 340] -> 
             RGBColor[
              0.9940676030184292, 0.9897195276507893, 0.5956733829454577], 
             UndirectedEdge[233, 358] -> 
             RGBColor[
              0.8678310459756758, 0.39201942871028744`, 0.22037646493598545`],
              UndirectedEdge[74, 191] -> 
             RGBColor[
              0.7517634193974077, 0.8060404672296411, 0.9758823517148281], 
             UndirectedEdge[53, 244] -> 
             RGBColor[
              0.27464006789181306`, 0.4059945029133032, 0.9389517176216438], 
             UndirectedEdge[4, 16] -> 
             RGBColor[
              0.23702850407735238`, 0.36646236463342485`, 0.9368097947037326],
              UndirectedEdge[149, 274] -> 
             RGBColor[
              0.22547330397154366`, 0.35431711668021776`, 0.9361517431520935],
              UndirectedEdge[326, 335] -> 
             RGBColor[
              0.3099542075105004, 0.4402786337315509, 0.9410665454863245], 
             UndirectedEdge[30, 77] -> 
             RGBColor[
              0.5041460680446381, 0.5860856357063153, 0.9585438899509009], 
             UndirectedEdge[129, 229] -> 
             RGBColor[
              0.24229031603850887`, 0.3719928626227475, 0.9371094471107673], 
             UndirectedEdge[216, 219] -> 
             RGBColor[
              0.5531447091768378, 0.647683896662048, 0.958186067610292], 
             UndirectedEdge[138, 233] -> 
             RGBColor[
              0.8187146618318747, 0.1448546684227033, 0.1655544873463778], 
             UndirectedEdge[28, 44] -> 
             RGBColor[
              0.29312282823703784`, 0.42542105591082463`, 0.9400042834805107],
              UndirectedEdge[163, 227] -> 
             RGBColor[
              0.23994763052693538`, 0.3695305516152434, 0.9369760346365759], 
             UndirectedEdge[15, 335] -> 
             RGBColor[
              0.2921895478533735, 0.4244401190541993, 0.9399511345433256], 
             UndirectedEdge[257, 268] -> 
             RGBColor[
              0.82084444647079, 0.16122512643498643`, 0.16759397152185085`], 
             UndirectedEdge[217, 279] -> 
             RGBColor[
              0.8637669929880314, 0.39171110461878467`, 0.2047030047651618], 
             UndirectedEdge[93, 119] -> 
             RGBColor[
              0.24286823945996167`, 0.3726002967811557, 0.9371423589946579], 
             UndirectedEdge[67, 305] -> 
             RGBColor[
              0.20792423756527648`, 0.33587193521215575`, 0.9351523497817738],
              UndirectedEdge[153, 195] -> 
             RGBColor[
              0.2815627334149148, 0.41246769783227444`, 0.9393753536812313], 
             UndirectedEdge[50, 135] -> 
             RGBColor[
              0.478712840814817, 0.5876796757980098, 0.9521051748933094], 
             UndirectedEdge[68, 334] -> 
             RGBColor[
              0.2690618295669699, 0.40013142075315566`, 0.938634045201308], 
             UndirectedEdge[95, 308] -> 
             RGBColor[
              0.2714334547461428, 0.4026241491861876, 0.9387691057467569], 
             UndirectedEdge[17, 36] -> 
             RGBColor[
              0.5275969503288876, 0.6273659981055699, 0.9559535110626505], 
             UndirectedEdge[41, 361] -> 
             RGBColor[
              0.34822341852427197`, 0.4760353557329764, 0.9434094661998561], 
             UndirectedEdge[117, 371] -> 
             RGBColor[
              0.31078136056287864`, 0.44021172480761495`, 0.9411479331302521],
              UndirectedEdge[89, 304] -> 
             RGBColor[
              0.21884062978169738`, 0.3473457555708567, 0.9357740221691438], 
             UndirectedEdge[267, 272] -> 
             RGBColor[
              0.6091079366672787, 0.6934689353256587, 0.9624191392814057], 
             UndirectedEdge[20, 158] -> 
             RGBColor[
              0.4553874406509526, 0.5675033157176284, 0.9506114604100135], 
             UndirectedEdge[30, 62] -> 
             RGBColor[
              0.17899764558147852`, 0.30546825298532254`, 0.9335050231613544],
              UndirectedEdge[197, 310] -> 
             RGBColor[
              0.5856647922314719, 0.6494240169162264, 0.8848951542933734], 
             UndirectedEdge[142, 268] -> 
             RGBColor[
              0.820162315663362, 0.15598197013746787`, 0.16694076229030108`], 
             UndirectedEdge[78, 213] -> 
             RGBColor[
              0.8648853376422582, 0.4433327628407137, 0.2075424324006481], 
             UndirectedEdge[48, 71] -> 
             RGBColor[
              0.6482814539995922, 0.7214952269023049, 0.9679496107647267], 
             UndirectedEdge[262, 269] -> 
             RGBColor[
              0.965850894705439, 0.9706613010892211, 0.7373156259818411], 
             UndirectedEdge[27, 376] -> 
             RGBColor[
              0.3679050083022842, 0.49203509004620194`, 0.9447019126873052], 
             UndirectedEdge[245, 292] -> 
             RGBColor[
              0.2204587636622521, 0.3490465168749334, 0.935866172499827], 
             UndirectedEdge[142, 217] -> 
             RGBColor[
              0.8219978721653904, 0.17009086175804683`, 0.16869849326960812`],
              UndirectedEdge[142, 363] -> 
             RGBColor[
              0.8352268135570913, 0.26746735996305215`, 0.18119789342745665`],
              UndirectedEdge[121, 130] -> 
             RGBColor[
              0.48180086572832803`, 0.5890215010044231, 0.9526702161686205], 
             UndirectedEdge[217, 300] -> 
             RGBColor[
              0.8452160389815616, 0.31543007828927405`, 0.18963511325602334`],
              UndirectedEdge[25, 109] -> 
             RGBColor[
              0.8971728932220235, 0.5808892824840503, 0.3786862947423749], 
             UndirectedEdge[40, 146] -> 
             RGBColor[
              0.43732168419070216`, 0.5509809435704429, 0.9497020146539848], 
             UndirectedEdge[18, 140] -> 
             RGBColor[
              0.8085657806265083, 0.8511439536813179, 0.9727850165539047], 
             UndirectedEdge[170, 239] -> 
             RGBColor[
              0.38474227729381244`, 0.5076661557079413, 0.9457364155882924], 
             UndirectedEdge[152, 333] -> 
             RGBColor[
              0.18958831081692415`, 0.31659971363473505`, 0.9341081458790279],
              UndirectedEdge[14, 250] -> 
             RGBColor[
              0.99129214736786, 0.9898691754012934, 0.7359749681160213], 
             UndirectedEdge[55, 159] -> 
             RGBColor[
              0.36748362390558187`, 0.49271757758819734`, 0.9446367094556223],
              UndirectedEdge[234, 331] -> 
             RGBColor[
              0.3954159318032815, 0.5169111387705692, 0.9464165314152937], 
             UndirectedEdge[370, 389] -> 
             RGBColor[
              0.505152375234491, 0.5869084718259839, 0.9586367768062234], 
             UndirectedEdge[119, 316] -> 
             RGBColor[
              0.24738893708713797`, 0.3773518366161024, 0.9373998060367528], 
             UndirectedEdge[89, 227] -> 
             RGBColor[
              0.22675241851123462`, 0.35566154716197895`, 0.9362245868328485],
              UndirectedEdge[246, 254] -> 
             RGBColor[
              0.4566571232556863, 0.569515492226385, 0.9504402532261262], 
             UndirectedEdge[197, 345] -> 
             RGBColor[
              0.5953494141792219, 0.6596031686238084, 0.8854466791861835], 
             UndirectedEdge[231, 234] -> 
             RGBColor[
              0.3237117587462526, 0.454798867157554, 0.9418478143825956], 
             UndirectedEdge[89, 209] -> 
             RGBColor[
              0.23530790735490154`, 0.3646539083859959, 0.9367118092657838], 
             UndirectedEdge[233, 317] -> 
             RGBColor[
              0.8751811761701102, 0.42026215689431723`, 0.37790000290961884`],
              UndirectedEdge[48, 342] -> 
             RGBColor[
              0.5144005472567488, 0.6158956891444403, 0.9551237685400916], 
             UndirectedEdge[24, 104] -> 
             RGBColor[
              0.9180135558932775, 0.712060691693382, 0.25285908317008815`], 
             UndirectedEdge[118, 149] -> 
             RGBColor[
              0.21314012851733694`, 0.34135416730935836`, 0.9354493870552745],
              UndirectedEdge[34, 53] -> 
             RGBColor[
              0.30076648553276153`, 0.4331274488318972, 0.9404515726006413], 
             UndirectedEdge[29, 45] -> 
             RGBColor[
              0.26796415172899, 0.39897769174864406`, 0.938571534072304], 
             UndirectedEdge[35, 208] -> 
             RGBColor[
              0.25706388434981153`, 0.3875208196162586, 0.9379507799705602], 
             UndirectedEdge[69, 191] -> 
             RGBColor[
              0.5835359920161374, 0.6722207850854224, 0.9607394608823273], 
             UndirectedEdge[102, 166] -> 
             RGBColor[
              0.8211210582465063, 0.16335128575519392`, 0.16785885527066496`],
              UndirectedEdge[185, 213] -> 
             RGBColor[
              0.8527830270590148, 0.3503091004315924, 0.1959532461185295], 
             UndirectedEdge[172, 364] -> 
             RGBColor[
              0.3254772137216906, 0.45565682861361634`, 0.9419848830531403], 
             UndirectedEdge[36, 55] -> 
             RGBColor[
              0.46160497467818506`, 0.5724389504821938, 0.9511318842995795], 
             UndirectedEdge[192, 203] -> 
             RGBColor[
              0.31794365991620344`, 0.4482045703725628, 0.9415387963349251], 
             UndirectedEdge[105, 394] -> 
             RGBColor[
              0.38810603050507936`, 0.5105796696723884, 0.9459507509684641], 
             UndirectedEdge[256, 261] -> 
             RGBColor[
              0.20237836752934693`, 0.3300428741759244, 0.934836520687607], 
             UndirectedEdge[215, 295] -> 
             RGBColor[
              0.6269879146840343, 0.22354035799766941`, 0.4231074612155832], 
             UndirectedEdge[219, 357] -> 
             RGBColor[
              0.5614389734467367, 0.6541634389484363, 0.9590127623584092], 
             UndirectedEdge[204, 295] -> 
             RGBColor[
              0.21065717499813985`, 0.33874442573233643`, 0.9353079865255567],
              UndirectedEdge[24, 138] -> 
             RGBColor[
              0.8469462590828297, 0.31598278774490174`, 0.19079285220574332`],
              UndirectedEdge[135, 376] -> 
             RGBColor[
              0.47083567399736015`, 0.5808793962784845, 0.9515970246612349], 
             UndirectedEdge[127, 305] -> 
             RGBColor[
              0.20669916269368893`, 0.33458430384788407`, 0.9350825835801727],
              UndirectedEdge[54, 158] -> 
             RGBColor[
              0.4775536933364365, 0.5867026096855403, 0.9520238744302849], 
             UndirectedEdge[180, 350] -> 
             RGBColor[
              0.3995063863984757, 0.5204540849487005, 0.9466771715650524], 
             UndirectedEdge[46, 287] -> 
             RGBColor[
              0.27226485336384204`, 0.4034980018471065, 0.9388164526680909], 
             UndirectedEdge[41, 153] -> 
             RGBColor[
              0.32912553840433756`, 0.45949373186045395`, 0.9421925661662062],
              UndirectedEdge[163, 315] -> 
             RGBColor[
              0.24412373790812583`, 0.3739199052533755, 0.9372138577739373], 
             UndirectedEdge[17, 64] -> 
             RGBColor[
              0.46723843843845614`, 0.5768882992816866, 0.951609674456959], 
             UndirectedEdge[67, 127] -> 
             RGBColor[
              0.21172079285419906`, 0.33986235553632177`, 0.9353685579889777],
              UndirectedEdge[83, 246] -> 
             RGBColor[
              0.39834226268445083`, 0.5194457794981713, 0.946602994631389], 
             UndirectedEdge[44, 383] -> 
             RGBColor[
              0.28909643467092216`, 0.42118906098474024`, 0.9397749863234359],
              UndirectedEdge[5, 275] -> 
             RGBColor[
              0.916771833602923, 0.9337046356973782, 0.882657568389807], 
             UndirectedEdge[99, 123] -> 
             RGBColor[
              0.9762118677425246, 0.9817794304286422, 0.9251512823600752], 
             UndirectedEdge[278, 354] -> 
             RGBColor[
              0.2660945297513849, 0.3970126005093012, 0.9384650618665371], 
             UndirectedEdge[61, 215] -> 
             RGBColor[
              0.8773074325747513, 0.4289007027481585, 0.2831094243686247], 
             UndirectedEdge[115, 208] -> 
             RGBColor[
              0.2358464087925902, 0.36521990753996986`, 0.9367424761260187], 
             UndirectedEdge[167, 203] -> 
             RGBColor[
              0.2874735215718495, 0.4194832764189812, 0.9396825638233285], 
             UndirectedEdge[242, 256] -> 
             RGBColor[
              0.5718276027056971, 0.5340616080097416, 0.5946502523941279], 
             UndirectedEdge[136, 254] -> 
             RGBColor[
              0.5440467518592814, 0.6407206880430576, 0.9572484996967315], 
             UndirectedEdge[65, 170] -> 
             RGBColor[
              0.4801509107444425, 0.5886204880785566, 0.952281016742329], 
             UndirectedEdge[247, 340] -> 
             RGBColor[
              0.9503928339373993, 0.8290616417134029, 0.4041000646481473], 
             UndirectedEdge[8, 17] -> 
             RGBColor[
              0.42291827954092154`, 0.5385004052405986, 0.9487856331227857], 
             UndirectedEdge[269, 300] -> 
             RGBColor[
              0.9415278534612976, 0.7904724805205449, 0.35790419683327634`], 
             UndirectedEdge[233, 242] -> 
             RGBColor[
              0.8510877684244544, 0.3281246222789175, 0.19395360445699056`], 
             UndirectedEdge[242, 382] -> 
             RGBColor[
              0.9085638811026002, 0.6736245465915296, 0.24520540694695725`], 
             UndirectedEdge[144, 242] -> 
             RGBColor[
              0.8983924729381163, 0.6274385577093406, 0.23671813465048305`], 
             UndirectedEdge[81, 227] -> 
             RGBColor[
              0.2273187292651137, 0.35625677567048153`, 0.9362568373925002], 
             UndirectedEdge[224, 230] -> 
             RGBColor[
              0.9722593705527938, 0.9180864844443417, 0.3467333222862512], 
             UndirectedEdge[81, 248] -> 
             RGBColor[
              0.21796166804011632`, 0.3464219110510618, 0.9357239665982682], 
             UndirectedEdge[13, 323] -> 
             RGBColor[
              0.8969951869704291, 0.9199794950758233, 0.9649311806841149], 
             UndirectedEdge[10, 189] -> 
             RGBColor[
              0.3312363099818102, 0.46056389881459425`, 0.9423548195879734], 
             UndirectedEdge[135, 364] -> 
             RGBColor[
              0.42640390772588643`, 0.5423948335396401, 0.9487658718038847], 
             UndirectedEdge[39, 383] -> 
             RGBColor[
              0.27666419535336334`, 0.408121989212486, 0.9390669886861509], 
             UndirectedEdge[108, 196] -> 
             RGBColor[
              0.332746597404592, 0.4616295540574491, 0.9424599321408476], 
             UndirectedEdge[75, 89] -> 
             RGBColor[
              0.23138047401831524`, 0.3605259269355878, 0.9364881477473821], 
             UndirectedEdge[131, 269] -> 
             RGBColor[
              0.9577625542405059, 0.8589366723660075, 0.3711790558606476], 
             UndirectedEdge[36, 165] -> 
             RGBColor[
              0.5262130350709433, 0.6262424733544989, 0.9558445641840965], 
             UndirectedEdge[40, 41] -> 
             RGBColor[
              0.34006622360312927`, 0.4689700034848203, 0.942889696952605], 
             UndirectedEdge[86, 249] -> 
             RGBColor[
              0.2850528182511259, 0.41693896374744543`, 0.939544708350323], 
             UndirectedEdge[287, 395] -> 
             RGBColor[
              0.2666407460996809, 0.397586708523477, 0.938496168079518], 
             UndirectedEdge[177, 225] -> 
             RGBColor[
              0.2895083029136421, 0.42040499749423077`, 0.9398430005920957], 
             UndirectedEdge[74, 216] -> 
             RGBColor[
              0.7418875253371497, 0.7983253437301927, 0.9748980148903788], 
             UndirectedEdge[229, 371] -> 
             RGBColor[
              0.25947088353624953`, 0.3900507283737679, 0.9380878550133916], 
             UndirectedEdge[319, 371] -> 
             RGBColor[
              0.2568146393431022, 0.387258847311161, 0.937936585836153], 
             UndirectedEdge[169, 353] -> 
             RGBColor[
              0.21553905850906607`, 0.343875594831612, 0.9355860025694045], 
             UndirectedEdge[47, 362] -> 
             RGBColor[
              0.4192754724662534, 0.5375770736774529, 0.9479368402481747], 
             UndirectedEdge[83, 313] -> 
             RGBColor[
              0.31784501109874064`, 0.44732499341570175`, 0.9415615875935087],
              UndirectedEdge[87, 210] -> 
             RGBColor[
              0.2950312133683537, 0.42742688968244336`, 0.9401129631905363], 
             UndirectedEdge[91, 150] -> 
             RGBColor[
              0.2666109948635128, 0.3975554380879269, 0.9384944737906311], 
             UndirectedEdge[16, 258] -> 
             RGBColor[
              0.24739688608388788`, 0.37736019151568206`, 0.9374002587203583],
              UndirectedEdge[334, 388] -> 
             RGBColor[
              0.24238207309791887`, 0.372089305109921, 0.9371146725395583], 
             UndirectedEdge[67, 325] -> 
             RGBColor[
              0.21225679273606501`, 0.3404257253965182, 0.9353990823893092], 
             UndirectedEdge[279, 363] -> 
             RGBColor[
              0.8902248757714332, 0.5864641010287953, 0.22970180508085886`], 
             UndirectedEdge[192, 385] -> 
             RGBColor[
              0.45995539470159097`, 0.5694965937320001, 0.9514449793856737], 
             UndirectedEdge[216, 339] -> 
             RGBColor[
              0.5124310381777115, 0.6124197611712089, 0.9555918284959135], 
             UndirectedEdge[74, 323] -> 
             RGBColor[
              0.8274418605794372, 0.8652436955878107, 0.9834033373997775], 
             UndirectedEdge[60, 87] -> 
             RGBColor[
              0.32383352968544554`, 0.4531896894262284, 0.9419183552403817], 
             UndirectedEdge[74, 198] -> 
             RGBColor[
              0.8255815527613636, 0.8637603366303892, 0.9832258995793732], 
             UndirectedEdge[16, 348] -> 
             RGBColor[
              0.252407866634222, 0.38262704978860046`, 0.9376856266496183], 
             UndirectedEdge[88, 283] -> 
             RGBColor[
              0.9496145330722283, 0.8334245259791293, 0.5278793972462171], 
             UndirectedEdge[292, 388] -> 
             RGBColor[
              0.21719189432910094`, 0.3456128300743124, 0.9356801291242041], 
             UndirectedEdge[76, 382] -> 
             RGBColor[
              0.8642232647352734, 0.4523172661853562, 0.20747578704175976`], 
             UndirectedEdge[131, 352] -> 
             RGBColor[
              0.9583101575279735, 0.8601079404267151, 0.43078229428572945`], 
             UndirectedEdge[123, 232] -> 
             RGBColor[
              0.7499263891145284, 0.8030301325071595, 0.9420935049543039], 
             UndirectedEdge[69, 357] -> 
             RGBColor[
              0.5819543622257783, 0.6709852038723623, 0.9605818188059951], 
             UndirectedEdge[241, 339] -> 
             RGBColor[
              0.32836122521249217`, 0.457187465102298, 0.9422040691120204], 
             UndirectedEdge[181, 322] -> 
             RGBColor[
              0.5378642093893072, 0.6357014215455682, 0.9567617873060958], 
             UndirectedEdge[140, 168] -> 
             RGBColor[
              0.6710377427034506, 0.7429390517664531, 0.9678464290545918], 
             UndirectedEdge[88, 357] -> 
             RGBColor[
              0.8330019348815232, 0.8684180093986145, 0.8892498058738514], 
             UndirectedEdge[125, 179] -> 
             RGBColor[
              0.2738145581196516, 0.4051268398024189, 0.9389047060613515], 
             UndirectedEdge[316, 324] -> 
             RGBColor[
              0.2671185805915378, 0.39808894287087526`, 0.9385233800469365], 
             UndirectedEdge[128, 390] -> 
             RGBColor[
              0.29625621364741994`, 0.42709948500765055`, 0.9402418566543815],
              UndirectedEdge[200, 339] -> 
             RGBColor[
              0.3182100783412779, 0.4465179661207665, 0.9416259763149808], 
             UndirectedEdge[85, 110] -> 
             RGBColor[
              0.2484427050223485, 0.37845941352875473`, 0.9374598165617531], 
             UndirectedEdge[178, 209] -> 
             RGBColor[
              0.24801071646784933`, 0.37800536616831976`, 0.9374352154526442],
              UndirectedEdge[380, 383] -> 
             RGBColor[
              0.2728634955258139, 0.4041272127154443, 0.9388505444536035], 
             UndirectedEdge[350, 357] -> 
             RGBColor[
              0.5542164267531839, 0.6479076320182329, 0.9585525480697432], 
             UndirectedEdge[98, 352] -> 
             RGBColor[
              0.9858621188487648, 0.9629527205499828, 0.4862282141252213], 
             UndirectedEdge[68, 151] -> 
             RGBColor[
              0.29628007015479707`, 0.4280840429902235, 0.9402080838641316], 
             UndirectedEdge[307, 385] -> 
             RGBColor[
              0.7803305100204103, 0.8271780586683711, 0.9269968726475282], 
             UndirectedEdge[94, 119] -> 
             RGBColor[
              0.25031116778183593`, 0.38042328635635736`, 0.9375662227517629],
              UndirectedEdge[116, 121] -> 
             RGBColor[
              0.48470874113100904`, 0.5915401565241579, 0.9528555034179461], 
             UndirectedEdge[1, 361] -> 
             RGBColor[
              0.35780477718256065`, 0.4843342470296975, 0.9440199819010995], 
             UndirectedEdge[180, 239] -> 
             RGBColor[
              0.3453924706572131, 0.47358333097810695`, 0.943229080705076], 
             UndirectedEdge[45, 394] -> 
             RGBColor[
              0.32718352263793704`, 0.4565868884354943, 0.9421136673575129], 
             UndirectedEdge[32, 124] -> 
             RGBColor[
              0.21977833860588586`, 0.34833134699925217`, 0.9358274232994656],
              UndirectedEdge[87, 243] -> 
             RGBColor[
              0.2892553344802239, 0.4213560747591461, 0.9397840354325044], 
             UndirectedEdge[188, 195] -> 
             RGBColor[
              0.25639031228130726`, 0.3868128526653249, 0.9379124210377194], 
             UndirectedEdge[122, 262] -> 
             RGBColor[
              0.6923652232093209, 0.7572804525421046, 0.9691955483013721], 
             UndirectedEdge[118, 212] -> 
             RGBColor[
              0.208479398474888, 0.33645544452739207`, 0.9351839653742893], 
             UndirectedEdge[35, 258] -> 
             RGBColor[
              0.2669871560923189, 0.3979508073894016, 0.938515895616131], 
             UndirectedEdge[183, 271] -> 
             RGBColor[
              0.28286075625291396`, 0.4146349676025667, 0.9394198736623899], 
             UndirectedEdge[130, 147] -> 
             RGBColor[
              0.34757171171070933`, 0.4732511609805692, 0.9434492148065551], 
             UndirectedEdge[124, 330] -> 
             RGBColor[
              0.22402160898279397`, 0.3527912932042634, 0.9360690712700745], 
             UndirectedEdge[46, 395] -> 
             RGBColor[
              0.27869220583377896`, 0.41025355681069386`, 0.939182480882838], 
             UndirectedEdge[206, 284] -> 
             RGBColor[
              0.23778007994491618`, 0.3672523185228967, 0.9368525958375336], 
             UndirectedEdge[179, 313] -> 
             RGBColor[
              0.2762257553297003, 0.407661160948913, 0.939042020175417], 
             UndirectedEdge[215, 363] -> 
             RGBColor[
              0.8336962959123371, 0.2557031306683627, 0.17973226800236758`], 
             UndirectedEdge[260, 338] -> 
             RGBColor[
              0.9016212039882432, 0.9204360205910522, 0.8006477894997438], 
             UndirectedEdge[88, 113] -> 
             RGBColor[
              0.8934147061054667, 0.915612925432826, 0.8952711863200087], 
             UndirectedEdge[95, 270] -> 
             RGBColor[
              0.26568283896088996`, 0.3965798873857872, 0.9384416166850604], 
             UndirectedEdge[16, 184] -> 
             RGBColor[
              0.22981171473055614`, 0.35887706145906934`, 0.9363988092267157],
              UndirectedEdge[38, 78] -> 
             RGBColor[
              0.8831597035944547, 0.5138469614548667, 0.23233732835271279`], 
             UndirectedEdge[8, 210] -> 
             RGBColor[
              0.30512183219392025`, 0.43788724700591375`, 0.9406929373091137],
              UndirectedEdge[1, 96] -> 
             RGBColor[
              0.32344726087306624`, 0.45255674347328584`, 0.9419046676618501],
              UndirectedEdge[213, 247] -> 
             RGBColor[
              0.9089878266866289, 0.6768740913610367, 0.24562767290302676`], 
             UndirectedEdge[109, 366] -> 
             RGBColor[
              0.9476884477531541, 0.8182230648175637, 0.4934194788371198], 
             UndirectedEdge[223, 260] -> 
             RGBColor[
              0.6315106131402652, 0.7091757673875206, 0.9658788076150083], 
             UndirectedEdge[393, 399] -> 
             RGBColor[
              0.22884950770057744`, 0.3578657208631124, 0.9363440129598162], 
             UndirectedEdge[25, 358] -> 
             RGBColor[
              0.8886663008126862, 0.5521683274544348, 0.24032832849796115`], 
             UndirectedEdge[207, 358] -> 
             RGBColor[
              0.9542162454207332, 0.8524596356255733, 0.30144575978299126`], 
             UndirectedEdge[31, 33] -> 
             RGBColor[0.1810793999809316, 0.30765630885, 0.9336235759947237], 
             UndirectedEdge[355, 375] -> 
             RGBColor[
              0.24288325350972279`, 0.37261607749940034`, 0.9371432140225805],
              UndirectedEdge[25, 104] -> 
             RGBColor[
              0.8770987724063027, 0.5087936416661875, 0.21806999727134982`], 
             UndirectedEdge[360, 375] -> 
             RGBColor[
              0.2826185317002574, 0.4142282159179257, 0.939411650593985], 
             UndirectedEdge[28, 347] -> 
             RGBColor[
              0.28416959916217255`, 0.4160106444856309, 0.9394944103298126], 
             UndirectedEdge[56, 143] -> 
             RGBColor[
              0.5377896391569529, 0.6355761788857779, 0.956773794547269], 
             UndirectedEdge[73, 115] -> 
             RGBColor[
              0.24086103809529086`, 0.3704906008829697, 0.9370280518463283], 
             UndirectedEdge[157, 218] -> 
             RGBColor[
              0.689653807893005, 0.7555582412254274, 0.971321814931075], 
             UndirectedEdge[267, 321] -> 
             RGBColor[
              0.6944927044467815, 0.7601721648632764, 0.9709294949676452], 
             UndirectedEdge[93, 324] -> 
             RGBColor[
              0.26259788296436154`, 0.3933374030359285, 0.9382659330048415], 
             UndirectedEdge[178, 245] -> 
             RGBColor[
              0.23694364602077422`, 0.3663731734356497, 0.9368049621629467], 
             UndirectedEdge[223, 331] -> 
             RGBColor[
              0.45307983116767014`, 0.5668363678003234, 0.9500964447383967], 
             UndirectedEdge[318, 367] -> 
             RGBColor[
              0.22156608180377718`, 0.3502103784497014, 0.9359292326298564], 
             UndirectedEdge[158, 265] -> 
             RGBColor[
              0.5475052991401734, 0.643528492531465, 0.9575207692077594], 
             UndirectedEdge[124, 199] -> 
             RGBColor[
              0.224537016117427, 0.35333301878146245`, 0.9360984229439153], 
             UndirectedEdge[38, 213] -> 
             RGBColor[
              0.9383796626861343, 0.7904965676280676, 0.28441340229193146`], 
             UndirectedEdge[128, 296] -> 
             RGBColor[
              0.3138673468643941, 0.4456099026290287, 0.9412447846377514], 
             UndirectedEdge[89, 315] -> 
             RGBColor[
              0.23092852589242507`, 0.36005090080011104`, 0.93646240997021], 
             UndirectedEdge[129, 178] -> 
             RGBColor[
              0.24083645723076108`, 0.3704647648358321, 0.9370266520024574], 
             UndirectedEdge[61, 279] -> 
             RGBColor[
              0.9694977718101772, 0.9052009249245101, 0.39612374546494056`], 
             UndirectedEdge[7, 332] -> 
             RGBColor[
              0.45831330080032634`, 0.5693830222721039, 0.9509787412394903], 
             UndirectedEdge[105, 180] -> 
             RGBColor[
              0.39180706588006936`, 0.513785320494758, 0.9461865776698615], 
             UndirectedEdge[75, 163] -> 
             RGBColor[
              0.24457568603401603`, 0.37439493138885227`, 0.9372395955511095],
              UndirectedEdge[15, 273] -> 
             RGBColor[
              0.28964915667663804`, 0.4217700068573468, 0.9398064630239824], 
             UndirectedEdge[149, 287] -> 
             RGBColor[
              0.24021601426247097`, 0.36981263993780294`, 0.9369913186932763],
              UndirectedEdge[123, 275] -> 
             RGBColor[
              0.9831983875687983, 0.9856760529092304, 0.8544852374631398], 
             UndirectedEdge[186, 226] -> 
             RGBColor[
              0.24355084950968384`, 0.37331776322339055`, 0.9371812326271585],
              UndirectedEdge[15, 183] -> 
             RGBColor[
              0.281397272925088, 0.41309675383481925`, 0.9393365304518997], 
             UndirectedEdge[35, 41] -> 
             RGBColor[
              0.3109306833758936, 0.44117275107327436`, 0.9411269955899995], 
             UndirectedEdge[47, 54] -> 
             RGBColor[
              0.44294170199458305`, 0.5580755721956097, 0.9494448314664949], 
             UndirectedEdge[19, 196] -> 
             RGBColor[
              0.2861541125436652, 0.4180964938749955, 0.9396074254310642], 
             UndirectedEdge[211, 328] -> 
             RGBColor[
              0.2860571913279975, 0.41793071873950494`, 0.9396042457787188], 
             UndirectedEdge[3, 86] -> 
             RGBColor[
              0.33530800642617503`, 0.4640896371481913, 0.9426142996527203], 
             UndirectedEdge[55, 58] -> 
             RGBColor[
              0.351171823063294, 0.4776705562573528, 0.9436309688854188], 
             UndirectedEdge[63, 214] -> 
             RGBColor[
              0.9711670732550739, 0.9296487112649943, 0.6029350218130802], 
             UndirectedEdge[26, 106] -> 
             RGBColor[
              0.7018038352541023, 0.7648141211568, 0.9611581586207743], 
             UndirectedEdge[89, 378] -> 
             RGBColor[
              0.2135546306131389, 0.341789835292997, 0.9354729923364294], 
             UndirectedEdge[191, 311] -> 
             RGBColor[
              0.5991137006259042, 0.6848674707026068, 0.961965795167115], 
             UndirectedEdge[147, 364] -> 
             RGBColor[
              0.31713379957570453`, 0.44688737134317436`, 0.9415097379605015],
              UndirectedEdge[137, 285] -> 
             RGBColor[
              0.23013560035880143`, 0.35921748578989005`, 0.9364172540340985],
              UndirectedEdge[104, 205] -> 
             RGBColor[
              0.9645712998383063, 0.8839256222853624, 0.49686413410326324`], 
             UndirectedEdge[191, 339] -> 
             RGBColor[
              0.5223069322379694, 0.6201348846706572, 0.9565761653203628], 
             UndirectedEdge[40, 167] -> 
             RGBColor[
              0.31143079927380024`, 0.4418378465956456, 0.9411503707956721], 
             UndirectedEdge[17, 262] -> 
             RGBColor[
              0.7370797325190604, 0.7937780282574919, 0.9726613937241215], 
             UndirectedEdge[96, 348] -> 
             RGBColor[
              0.27493335548153697`, 0.4063027667656103, 0.9389684199159984], 
             UndirectedEdge[60, 122] -> 
             RGBColor[
              0.4018079642776756, 0.5224475960269956, 0.9468238260723096], 
             UndirectedEdge[99, 187] -> 
             RGBColor[
              0.9110307205751575, 0.9308010667922535, 0.953442401298972], 
             UndirectedEdge[111, 166] -> 
             RGBColor[
              0.8412054532208156, 0.3012945495737131, 0.18644817264097716`], 
             UndirectedEdge[130, 172] -> 
             RGBColor[
              0.3559151258566954, 0.4820206182510111, 0.9439243598991939], 
             UndirectedEdge[205, 230] -> 
             RGBColor[
              0.9820628725503424, 0.9494608486926688, 0.5307965926515668], 
             UndirectedEdge[248, 319] -> 
             RGBColor[
              0.2288957810137855, 0.3579143570491916, 0.9363466481565481], 
             UndirectedEdge[77, 111] -> 
             RGBColor[
              0.8517216279012312, 0.6939386797204187, 0.6001134200588495], 
             UndirectedEdge[41, 188] -> 
             RGBColor[
              0.30395311727072993`, 0.43383888669350434`, 0.9407296335226945],
              UndirectedEdge[57, 278] -> 
             RGBColor[
              0.26281152350528336`, 0.39356195279003, 0.9382780995175941], 
             UndirectedEdge[56, 331] -> 
             RGBColor[
              0.4515137506850261, 0.565500249927577, 0.9499910348290849], 
             UndirectedEdge[40, 87] -> 
             RGBColor[
              0.31472542396778913`, 0.4453007060402985, 0.9413379947980343], 
             UndirectedEdge[142, 214] -> 
             RGBColor[
              0.8756470135656208, 0.4404124969282712, 0.41631879531902366`], 
             UndirectedEdge[341, 368] -> 
             RGBColor[
              0.2171826090564914, 0.3456030706640795, 0.9356796003416652], 
             UndirectedEdge[96, 188] -> 
             RGBColor[
              0.2769987034014417, 0.4084735783800516, 0.9390860384246287], 
             UndirectedEdge[142, 202] -> 
             RGBColor[
              0.8331691909471927, 0.2559585132180833, 0.1793961607512619], 
             UndirectedEdge[37, 351] -> 
             RGBColor[
              0.2477720085286644, 0.3777544689892789, 0.9374216213886444], 
             UndirectedEdge[83, 108] -> 
             RGBColor[
              0.3602253738682746, 0.48643084621613597`, 0.9441742201814636], 
             UndirectedEdge[72, 119] -> 
             RGBColor[
              0.2341124382405141, 0.36339739454965503`, 0.9366437290682574], 
             UndirectedEdge[170, 180] -> 
             RGBColor[
              0.40561982873439206`, 0.5257492414295251, 0.9470667147047922], 
             UndirectedEdge[196, 234] -> 
             RGBColor[
              0.3183317548341577, 0.44914414193399255`, 0.9415414311188043], 
             UndirectedEdge[218, 306] -> 
             RGBColor[
              0.9402199448611399, 0.9214289952270589, 0.6653505611679222], 
             UndirectedEdge[186, 189] -> 
             RGBColor[
              0.2745072076984255, 0.4058548584262301, 0.9389441514301794], 
             UndirectedEdge[20, 135] -> 
             RGBColor[
              0.45546851492086315`, 0.5675691354622958, 0.9506178428735257], 
             UndirectedEdge[79, 254] -> 
             RGBColor[
              0.5301586737259505, 0.6294457205636295, 0.9561551793123693], 
             UndirectedEdge[93, 355] -> 
             RGBColor[
              0.23807963900287032`, 0.36756717408594775`, 0.936869655282726], 
             UndirectedEdge[211, 301] -> 
             RGBColor[
              0.25974755171345176`, 0.39034152416978307`, 0.9381036108567895],
              UndirectedEdge[145, 227] -> 
             RGBColor[
              0.23647303514531387`, 0.36587853156708794`, 0.9367781615697957],
              UndirectedEdge[26, 345] -> 
             RGBColor[
              0.3285301240705917, 0.4490550186158963, 0.9425296374326482], 
             UndirectedEdge[132, 140] -> 
             RGBColor[
              0.7355736784173503, 0.7933550152374292, 0.9742787680039452], 
             UndirectedEdge[153, 258] -> 
             RGBColor[
              0.28518201112076286`, 0.41627178817658117`, 0.9395814661923377],
              UndirectedEdge[56, 344] -> 
             RGBColor[
              0.38578184035649155`, 0.5085665729828752, 0.9458026556273967], 
             UndirectedEdge[44, 390] -> 
             RGBColor[
              0.28212790876587335`, 0.4138646984284726, 0.9393781390821536], 
             UndirectedEdge[223, 346] -> 
             RGBColor[
              0.3995496021231435, 0.5204711739094963, 0.9466855458786024], 
             UndirectedEdge[114, 222] -> 
             RGBColor[
              0.4669023906435984, 0.574712579304436, 0.9521089968254883], 
             UndirectedEdge[85, 203] -> 
             RGBColor[
              0.2663525209612127, 0.3972837656284177, 0.9384797540842731], 
             UndirectedEdge[156, 261] -> 
             RGBColor[
              0.18270395436139325`, 0.3093638185065621, 0.9337160919633781], 
             UndirectedEdge[33, 295] -> 
             RGBColor[
              0.21066436833308994`, 0.3387519863834527, 0.9353083961753406], 
             UndirectedEdge[59, 395] -> 
             RGBColor[
              0.303543145607047, 0.434036883269187, 0.9406832590311243], 
             UndirectedEdge[334, 371] -> 
             RGBColor[
              0.26672232113879757`, 0.3976724490617448, 0.9385008136573162], 
             UndirectedEdge[40, 154] -> 
             RGBColor[
              0.3847350802007028, 0.5076599219476261, 0.9457359569958835], 
             UndirectedEdge[300, 306] -> 
             RGBColor[
              0.9301864468516778, 0.7525583544999579, 0.2846700934867103], 
             UndirectedEdge[61, 297] -> 
             RGBColor[
              0.9699924620425022, 0.9739499675150907, 0.7461656307796394], 
             UndirectedEdge[97, 350] -> 
             RGBColor[
              0.437513599136121, 0.5533740223239922, 0.9490989575522366], 
             UndirectedEdge[178, 229] -> 
             RGBColor[
              0.24544230257567465`, 0.37530580032079786`, 0.9372889480811126],
              UndirectedEdge[130, 265] -> 
             RGBColor[
              0.5011501438603255, 0.6047301166670249, 0.9541934622219126], 
             UndirectedEdge[110, 134] -> 
             RGBColor[
              0.24495240537755758`, 0.37479088730430044`, 0.9372610491604179],
              UndirectedEdge[147, 211] -> 
             RGBColor[
              0.2737075152920192, 0.40501433100367, 0.9388986101306735], 
             UndirectedEdge[78, 185] -> 
             RGBColor[
              0.8357927942928458, 0.27612467820309083`, 0.1819085262779956], 
             UndirectedEdge[130, 135] -> 
             RGBColor[
              0.4568418198608912, 0.568758623177035, 0.9507053486499384], 
             UndirectedEdge[52, 384] -> 
             RGBColor[
              0.5675366621289825, 0.6563557009893235, 0.9607088184571579], 
             UndirectedEdge[77, 166] -> 
             RGBColor[
              0.8263011039573982, 0.41652025488755623`, 0.44209707798488607`],
              UndirectedEdge[24, 76] -> 
             RGBColor[
              0.8653472987842202, 0.4574212422768018, 0.20841370860479677`], 
             UndirectedEdge[100, 220] -> 
             RGBColor[
              0.42602430021250687`, 0.5428220538333498, 0.9485327937322395], 
             UndirectedEdge[41, 369] -> 
             RGBColor[
              0.2991371325274741, 0.4287769813772735, 0.940455370316177], 
             UndirectedEdge[12, 318] -> 
             RGBColor[
              0.2211272263803799, 0.3497491135746699, 0.9359042404627222], 
             UndirectedEdge[118, 199] -> 
             RGBColor[
              0.21593219336709382`, 0.3442888044935889, 0.9356083910179783], 
             UndirectedEdge[11, 205] -> 
             RGBColor[
              0.9593655870867921, 0.8632867059265485, 0.49267549542961175`], 
             UndirectedEdge[120, 136] -> 
             RGBColor[
              0.5924802140391232, 0.6800411545432594, 0.9610613592571464], 
             UndirectedEdge[66, 215] -> 
             RGBColor[
              0.8704530936907242, 0.40612621697725415`, 0.22699149849500438`],
              UndirectedEdge[199, 287] -> 
             RGBColor[
              0.24300807911222783`, 0.3727472771220335, 0.9371503226559803], 
             UndirectedEdge[8, 64] -> 
             RGBColor[
              0.3546401133620532, 0.4815931742890025, 0.9438183323208591], 
             UndirectedEdge[312, 361] -> 
             RGBColor[
              0.40929184788600736`, 0.528668033662285, 0.9473730082456748], 
             UndirectedEdge[5, 193] -> 
             RGBColor[
              0.8318913190108279, 0.8687915729636699, 0.983827730717042], 
             UndirectedEdge[187, 232] -> 
             RGBColor[
              0.6847452419471614, 0.7520517688707707, 0.9703846238932006], 
             UndirectedEdge[115, 325] -> 
             RGBColor[
              0.22508690864981107`, 0.3539109906981984, 0.9361297385101415], 
             UndirectedEdge[137, 252] -> 
             RGBColor[
              0.22294460960746476`, 0.35165929857508804`, 0.9360077377489273],
              UndirectedEdge[296, 390] -> 
             RGBColor[
              0.283910407540538, 0.415738217657595, 0.9394796497504001], 
             UndirectedEdge[101, 171] -> 
             RGBColor[
              0.2670272094470698, 0.3979929060047742, 0.9385181765954305], 
             UndirectedEdge[234, 342] -> 
             RGBColor[
              0.47104879657377785`, 0.578346581625195, 0.9523614333210206], 
             UndirectedEdge[56, 343] -> 
             RGBColor[
              0.5865678018857227, 0.673953417760403, 0.9614500105609494], 
             UndirectedEdge[60, 146] -> 
             RGBColor[
              0.44642978990835863`, 0.5588699269563728, 0.9502823750963323], 
             UndirectedEdge[149, 336] -> 
             RGBColor[
              0.21561259787663173`, 0.3439528893695888, 0.9355901905275956], 
             UndirectedEdge[12, 199] -> 
             RGBColor[
              0.22211987446733733`, 0.350792449651586, 0.9359607703027832], 
             UndirectedEdge[42, 104] -> 
             RGBColor[
              0.9330499750272585, 0.8621677183315113, 0.6295247357296906], 
             UndirectedEdge[216, 323] -> 
             RGBColor[
              0.7446559095096992, 0.8005327781235971, 0.9751620658441222], 
             UndirectedEdge[110, 192] -> 
             RGBColor[
              0.30003384397733923`, 0.42938021827289985`, 0.940518858812405], 
             UndirectedEdge[93, 380] -> 
             RGBColor[
              0.25536438822798396`, 0.38573454143794017`, 0.9378539961806014],
              UndirectedEdge[34, 397] -> 
             RGBColor[
              0.28081927975955956`, 0.41216167083836874`, 0.939315608741104], 
             UndirectedEdge[249, 308] -> 
             RGBColor[
              0.2653288302878062, 0.39620780182492993`, 0.9384214564148372], 
             UndirectedEdge[116, 130] -> 
             RGBColor[
              0.4133134657138138, 0.5324130830876621, 0.947556946449905], 
             UndirectedEdge[81, 315] -> 
             RGBColor[
              0.23149483664630416`, 0.3606461293086136, 0.9364946605298619], 
             UndirectedEdge[99, 193] -> 
             RGBColor[
              0.9002336063428361, 0.9221917409832586, 0.9524125629047955], 
             UndirectedEdge[116, 135] -> 
             RGBColor[
              0.4597496952635722, 0.5712772786967698, 0.9508906358992639], 
             UndirectedEdge[304, 378] -> 
             RGBColor[
              0.21381243485280502`, 0.34206080389461896`, 0.9354876739064912],
              UndirectedEdge[56, 120] -> 
             RGBColor[
              0.5086566729306621, 0.6119247244781029, 0.9544803407283637], 
             UndirectedEdge[255, 393] -> 
             RGBColor[
              0.2416474883761139, 0.3713172099919425, 0.9370728390263723], 
             UndirectedEdge[106, 214] -> 
             RGBColor[
              0.9661339552698273, 0.9742633398075717, 0.9422105594358144], 
             UndirectedEdge[130, 328] -> 
             RGBColor[
              0.3599213877466876, 0.48616754871640405`, 0.9441548504546003], 
             UndirectedEdge[181, 250] -> 
             RGBColor[
              0.7777697545864616, 0.8245041838583995, 0.9019245302265969], 
             UndirectedEdge[102, 230] -> 
             RGBColor[
              0.8691504345300162, 0.40175745622288966`, 0.22191366578822208`],
              UndirectedEdge[45, 141] -> 
             RGBColor[
              0.32778152064738697`, 0.45710484425502595`, 0.9421517712618861],
              UndirectedEdge[225, 288] -> 
             RGBColor[
              0.25106704817739506`, 0.3812177645776751, 0.9376092690220652], 
             UndirectedEdge[208, 278] -> 
             RGBColor[
              0.24275117083398723`, 0.37247725023267697`, 0.9371356921095961],
              UndirectedEdge[342, 346] -> 
             RGBColor[
              0.4741951057473072, 0.5810717564932091, 0.9525619133593859], 
             UndirectedEdge[133, 164] -> 
             RGBColor[
              0.2698983654154672, 0.40101067296936244`, 0.9386816846803361], 
             UndirectedEdge[287, 373] -> 
             RGBColor[
              0.2552675974110747, 0.3856328081524763, 0.9378484840867676], 
             UndirectedEdge[122, 314] -> 
             RGBColor[
              0.6859497834912932, 0.7522408691078613, 0.9712156258567326], 
             UndirectedEdge[85, 351] -> 
             RGBColor[
              0.24352597864269326`, 0.37329162236527946`, 0.9371798162680766],
              UndirectedEdge[5, 338] -> 
             RGBColor[
              0.9178657002272999, 0.9332997898377504, 0.8022208620159], 
             UndirectedEdge[311, 339] -> 
             RGBColor[
              0.4425672704759462, 0.555957682108388, 0.9499165435038557], 
             UndirectedEdge[39, 324] -> 
             RGBColor[
              0.27652485948189337`, 0.40797553837716655`, 0.9390590537143996],
              UndirectedEdge[52, 346] -> 
             RGBColor[
              0.36583874865596927`, 0.4912928693208167, 0.944531899459223], 
             UndirectedEdge[272, 291] -> 
             RGBColor[
              0.6717542540567425, 0.7434987958813325, 0.9679178442101087], 
             UndirectedEdge[191, 323] -> 
             RGBColor[
              0.7545318035699571, 0.8082479016230455, 0.9761464026685716], 
             UndirectedEdge[60, 165] -> 
             RGBColor[
              0.4451385583294708, 0.557821646991312, 0.950180724616505], 
             UndirectedEdge[44, 301] -> 
             RGBColor[
              0.2773872245806669, 0.4088819387730828, 0.9391081641310199], 
             UndirectedEdge[11, 144] -> 
             RGBColor[
              0.9009503839038591, 0.6375798223152109, 0.23877628985540691`], 
             UndirectedEdge[333, 381] -> 
             RGBColor[
              0.5943537422981029, 0.6571554755250186, 0.8488416222676571], 
             UndirectedEdge[9, 363] -> 
             RGBColor[
              0.8379491231855124, 0.28839222469078246`, 0.18380478020204166`],
              UndirectedEdge[153, 312] -> 
             RGBColor[
              0.39019396776607296`, 0.5121264097897626, 0.9461561082120249], 
             UndirectedEdge[55, 80] -> 
             RGBColor[
              0.36897452576073053`, 0.49400892184022105`, 0.9447317084034796],
              UndirectedEdge[7, 40] -> 
             RGBColor[
              0.36435856265805855`, 0.4900108066057379, 0.9444375833163132], 
             UndirectedEdge[51, 377] -> 
             RGBColor[
              0.39390138797963725`, 0.5155993170337143, 0.9463200260221095], 
             UndirectedEdge[112, 170] -> 
             RGBColor[
              0.3869454032271654, 0.5095743926590826, 0.9458767968246178], 
             UndirectedEdge[200, 375] -> 
             RGBColor[
              0.26275249757312547`, 0.3934999127928718, 0.9382747380780788], 
             UndirectedEdge[94, 200] -> 
             RGBColor[
              0.26539181138814727`, 0.3962739989546208, 0.9384250430953294], 
             UndirectedEdge[8, 253] -> 
             RGBColor[
              0.3260178665234107, 0.4568020226733255, 0.9419945480619598], 
             UndirectedEdge[31, 295] -> 
             RGBColor[
              0.21280238164412135`, 0.34099917393122015`, 0.9354301528704966],
              UndirectedEdge[301, 383] -> 
             RGBColor[
              0.2685271160434062, 0.39956940293709464`, 0.9386035940571789], 
             UndirectedEdge[327, 392] -> 
             RGBColor[
              0.28327067295496094`, 0.4141554737113025, 0.9394765499044728], 
             UndirectedEdge[119, 375] -> 
             RGBColor[
              0.24767185396681415`, 0.37764920019460835`, 0.9374159177345123],
              UndirectedEdge[160, 340] -> 
             RGBColor[
              0.8842444306145842, 0.48142224852336285`, 0.30529599505492633`],
              UndirectedEdge[151, 308] -> 
             RGBColor[
              0.28846194842015016`, 0.41986670134956156`, 0.9397628533972181],
              UndirectedEdge[221, 276] -> 
             RGBColor[
              0.8437125304054167, 0.8786573253156666, 0.9848385285958808], 
             UndirectedEdge[94, 316] -> 
             RGBColor[
              0.25720173748705216`, 0.38766571200389227`, 0.9379586305027907],
              UndirectedEdge[195, 206] -> 
             RGBColor[
              0.2386283880050733, 0.3681439440799593, 0.9369009057266002], 
             UndirectedEdge[159, 192] -> 
             RGBColor[
              0.3379621693046799, 0.46714757740434754`, 0.9427556284732501], 
             UndirectedEdge[220, 350] -> 
             RGBColor[
              0.454088632793754, 0.5671299681608568, 0.9503210281880017], 
             UndirectedEdge[229, 319] -> 
             RGBColor[
              0.24423991719027513`, 0.3740420170451063, 0.9372204740121839], 
             UndirectedEdge[69, 97] -> 
             RGBColor[
              0.46525153460871527`, 0.5764515941781216, 0.9511282282884884], 
             UndirectedEdge[90, 317] -> 
             RGBColor[
              0.8482164323597703, 0.8802460937906929, 0.8881545671159801], 
             UndirectedEdge[136, 237] -> 
             RGBColor[
              0.59850057250929, 0.6849287527633994, 0.9615353039292178], 
             UndirectedEdge[69, 141] -> 
             RGBColor[
              0.42414128450553, 0.540843961799992, 0.9485087195042803], 
             UndirectedEdge[48, 143] -> 
             RGBColor[
              0.5250435709581793, 0.6245361752480152, 0.9559616263525487], 
             UndirectedEdge[51, 246] -> 
             RGBColor[
              0.408363122473439, 0.5281253445843351, 0.9472415149560449], 
             UndirectedEdge[97, 132] -> 
             RGBColor[
              0.6207534044996754, 0.7002920708010887, 0.965012812845729], 
             UndirectedEdge[94, 383] -> 
             RGBColor[
              0.2701801471577058, 0.4013068434464496, 0.9386977317336979], 
             UndirectedEdge[246, 344] -> 
             RGBColor[
              0.3822157528613575, 0.505477807231359, 0.9455754276855741], 
             UndirectedEdge[155, 354] -> 
             RGBColor[
              0.29215952785429067`, 0.42440856613178546`, 0.9399494249487885],
              UndirectedEdge[107, 307] -> 
             RGBColor[
              0.8878917780488264, 0.5310213536415637, 0.4215505823700465], 
             UndirectedEdge[310, 363] -> 
             RGBColor[
              0.6358677126442442, 0.4154659765664225, 0.4492292381488407], 
             UndirectedEdge[99, 281] -> 
             RGBColor[
              0.8050608246814849, 0.8476642232367373, 0.943040239252503], 
             UndirectedEdge[123, 187] -> 
             RGBColor[
              0.9091149872090246, 0.929372315984517, 0.9566852381845512], 
             UndirectedEdge[23, 227] -> 
             RGBColor[
              0.22416996966139735`, 0.3529472296840859, 0.936077520191241], 
             UndirectedEdge[28, 211] -> 
             RGBColor[
              0.2754831553698227, 0.4068806413075249, 0.9389997302062802], 
             UndirectedEdge[327, 356] -> 
             RGBColor[
              0.4184852693414719, 0.5351260969165677, 0.9483745901685348], 
             UndirectedEdge[140, 219] -> 
             RGBColor[
              0.5595564197473485, 0.6526927736905361, 0.9588251269991186], 
             UndirectedEdge[104, 144] -> 
             RGBColor[
              0.9061560966553733, 0.6582187386740248, 0.24296492852905843`], 
             UndirectedEdge[49, 328] -> 
             RGBColor[
              0.2825867919008145, 0.4142831089055032, 0.9394066116653366], 
             UndirectedEdge[112, 271] -> 
             RGBColor[
              0.3178545270497625, 0.4495503070285146, 0.9414810160978866], 
             UndirectedEdge[106, 197] -> 
             RGBColor[
              0.9686231253627324, 0.9753622711647122, 0.9040752003743098], 
             UndirectedEdge[106, 204] -> 
             RGBColor[
              0.563710908416439, 0.6332510496213667, 0.9527850098927306], 
             UndirectedEdge[50, 158] -> 
             RGBColor[
              0.47863176654490647`, 0.5876138560533424, 0.9520987924297972], 
             UndirectedEdge[259, 299] -> 
             RGBColor[
              0.21257469635649348`, 0.34075986225784227`, 0.9354171865301963],
              UndirectedEdge[79, 286] -> 
             RGBColor[
              0.658527918518543, 0.7323765551714567, 0.9671395072605043], 
             UndirectedEdge[240, 388] -> 
             RGBColor[
              0.23128580999340365`, 0.36042642904335986`, 0.9364827567712063],
              UndirectedEdge[118, 299] -> 
             RGBColor[
              0.21009516231391617`, 0.33815371476755507`, 0.9352759807346135],
              UndirectedEdge[138, 257] -> 
             RGBColor[
              0.820430974175874, 0.158046997191546, 0.167198029985289], 
             UndirectedEdge[171, 244] -> 
             RGBColor[
              0.266624380952421, 0.39756950771609656`, 0.9384952361085915], 
             UndirectedEdge[161, 337] -> 
             RGBColor[
              0.35808998923330093`, 0.48236207273681253`, 0.9441194115332278],
              UndirectedEdge[119, 355] -> 
             RGBColor[
              0.2357097669248304, 0.3650762882733595, 0.9367346945737933], 
             UndirectedEdge[248, 292] -> 
             RGBColor[
              0.21361328404066288`, 0.34185148376416674`, 0.935476332562357], 
             UndirectedEdge[68, 386] -> 
             RGBColor[
              0.30804388160308127`, 0.43827326520037213`, 0.9409576635272863],
              UndirectedEdge[126, 299] -> 
             RGBColor[
              0.21308522513571704`, 0.34129646037420036`, 0.9354462603889135],
              UndirectedEdge[128, 383] -> 
             RGBColor[
              0.30322473955246876`, 0.43442384756391816`, 0.9406387038956638],
              UndirectedEdge[229, 248] -> 
             RGBColor[
              0.2315520252069328, 0.36070623811179847`, 0.9364979173337866], 
             UndirectedEdge[395, 396] -> 
             RGBColor[
              0.2756838068644868, 0.4070915387504564, 0.9390111570120642], 
             UndirectedEdge[81, 292] -> 
             RGBColor[
              0.21536706305033604`, 0.3436948166993449, 0.9355762076824743], 
             UndirectedEdge[34, 253] -> 
             RGBColor[
              0.3270023945629662, 0.4576547713773704, 0.9420572813180563], 
             UndirectedEdge[130, 322] -> 
             RGBColor[
              0.45941085843753277`, 0.5708442844274215, 0.95090759277739], 
             UndirectedEdge[74, 311] -> 
             RGBColor[
              0.6720237576353845, 0.741863264667372, 0.9692227298983209], 
             UndirectedEdge[232, 235] -> 
             RGBColor[
              0.6328251607154107, 0.7112978291642651, 0.965261084970727], 
             UndirectedEdge[207, 221] -> 
             RGBColor[
              0.9308573670898133, 0.869892342221664, 0.6314368519575342], 
             UndirectedEdge[140, 216] -> 
             RGBColor[
              0.6655132848379224, 0.7386233032944675, 0.96729580272355], 
             UndirectedEdge[31, 173] -> 
             RGBColor[
              0.20479251217739197`, 0.3325802932666311, 0.9349740026539064], 
             UndirectedEdge[37, 243] -> 
             RGBColor[
              0.2690857390615694, 0.4001565511479292, 0.9386354068116546], 
             UndirectedEdge[1, 35] -> 
             RGBColor[
              0.32051204203418227`, 0.44947164236999554`, 0.9417375112912428],
              UndirectedEdge[60, 210] -> 
             RGBColor[
              0.3287260262404138, 0.45833201350769803`, 0.942196975681387], 
             UndirectedEdge[35, 92] -> 
             RGBColor[
              0.28435244626912165`, 0.4162028283882106, 0.9395048232020553], 
             UndirectedEdge[52, 291] -> 
             RGBColor[
              0.5415685327056081, 0.6360692009186899, 0.9581205580022027], 
             UndirectedEdge[77, 400] -> 
             RGBColor[
              0.6094880057982189, 0.6893301781287484, 0.9648167092401694], 
             UndirectedEdge[77, 389] -> 
             RGBColor[
              0.5042266153181847, 0.5861702959978048, 0.9585484769989704], 
             UndirectedEdge[96, 361] -> 
             RGBColor[
              0.32126900465498376`, 0.45067004741952366`, 0.9417658711017902],
              UndirectedEdge[150, 374] -> 
             RGBColor[
              0.2733522518909328, 0.4046409266441276, 0.9388783784055468], 
             UndirectedEdge[80, 154] -> 
             RGBColor[
              0.38228721374237734`, 0.5055397030547701, 0.9455799811097223], 
             UndirectedEdge[200, 383] -> 
             RGBColor[
              0.27544799036410295`, 0.4068436806569232, 0.9389977276112265], 
             UndirectedEdge[144, 391] -> 
             RGBColor[
              0.8397398954791699, 0.2854579690084683, 0.1848657380913032], 
             UndirectedEdge[196, 290] -> 
             RGBColor[
              0.3515289166579535, 0.47789785496789633`, 0.943656724915119], 
             UndirectedEdge[159, 228] -> 
             RGBColor[
              0.3496458859290326, 0.47726742550368945`, 0.9435001045650488], 
             UndirectedEdge[27, 377] -> 
             RGBColor[
              0.3561480526956704, 0.48185180602152367`, 0.9439527698723194], 
             UndirectedEdge[24, 233] -> 
             RGBColor[
              0.8456898299251425, 0.30632532266815005`, 0.18958969422540822`],
              UndirectedEdge[24, 109] -> 
             RGBColor[
              0.9481247371168586, 0.8202041529201762, 0.49378352937662584`], 
             UndirectedEdge[189, 255] -> 
             RGBColor[
              0.28051086067435194`, 0.4121650783575129, 0.9392860505855498], 
             UndirectedEdge[262, 298] -> 
             RGBColor[
              0.8810364966451805, 0.9079026895445534, 0.9858832537094278], 
             UndirectedEdge[249, 397] -> 
             RGBColor[
              0.25945941523748706`, 0.39003867446463636`, 0.938087201910743], 
             UndirectedEdge[128, 324] -> 
             RGBColor[
              0.3030854036809988, 0.43427739672859866`, 0.9406307689239126], 
             UndirectedEdge[7, 228] -> 
             RGBColor[
              0.37863108577837257`, 0.5023729487746839, 0.9453470158688431], 
             UndirectedEdge[115, 258] -> 
             RGBColor[
              0.24576968053509757`, 0.37564989531311277`, 0.9373075917715895],
              UndirectedEdge[375, 383] -> 
             RGBColor[
              0.26754083334268397`, 0.3985327572847006, 0.9385474267164473], 
             UndirectedEdge[257, 338] -> 
             RGBColor[
              0.879834237807443, 0.44658003792775297`, 0.31942228583278787`], 
             UndirectedEdge[5, 321] -> 
             RGBColor[
              0.8296147450427847, 0.8669940565457998, 0.9836058756059307], 
             UndirectedEdge[65, 239] -> 
             RGBColor[
              0.4199235526672635, 0.5364545776271384, 0.9484433827426128], 
             UndirectedEdge[56, 71] -> 
             RGBColor[
              0.6610275221983658, 0.7325352305400676, 0.968761778959447], 
             UndirectedEdge[276, 322] -> 
             RGBColor[
              0.6369911357289768, 0.7142897496435541, 0.9658558315605028], 
             UndirectedEdge[239, 326] -> 
             RGBColor[
              0.3319525774457105, 0.4619423709869775, 0.94237270259407], 
             UndirectedEdge[379, 393] -> 
             RGBColor[
              0.22188867958802838`, 0.35054944917483033`, 0.9359476040964289],
              UndirectedEdge[131, 262] -> 
             RGBColor[
              0.9305545199558635, 0.8420358975584873, 0.6226092420681639], 
             UndirectedEdge[201, 210] -> 
             RGBColor[
              0.2881749983278178, 0.42022057296569904`, 0.9397225118868391], 
             UndirectedEdge[301, 372] -> 
             RGBColor[
              0.25414770566980416`, 0.3844557309271635, 0.9377847079088335], 
             UndirectedEdge[291, 398] -> 
             RGBColor[
              0.8179584912880846, 0.8585839639299231, 0.9789023010866215], 
             UndirectedEdge[28, 49] -> 
             RGBColor[
              0.27201275594263963`, 0.40323303147352313`, 0.938802096092898], 
             UndirectedEdge[6, 160] -> 
             RGBColor[
              0.8841009021841464, 0.48111525572360647`, 0.289673811156557], 
             UndirectedEdge[375, 379] -> 
             RGBColor[
              0.23790135046863936`, 0.36737978153232503`, 0.9368595020144559],
              UndirectedEdge[45, 112] -> 
             RGBColor[
              0.31221013250570034`, 0.4436176904874213, 0.9411595761787357], 
             UndirectedEdge[324, 390] -> 
             RGBColor[
              0.27312846435714266`, 0.404405711757165, 0.9388656340365613], 
             UndirectedEdge[169, 227] -> 
             RGBColor[
              0.22781024002051087`, 0.3567733846379857, 0.936284828202895], 
             UndirectedEdge[44, 380] -> 
             RGBColor[
              0.2817236040630746, 0.41343974855143245`, 0.9393551145274445], 
             UndirectedEdge[288, 360] -> 
             RGBColor[
              0.2777088570611381, 0.4090678365808599, 0.9391320518865], 
             UndirectedEdge[87, 134] -> 
             RGBColor[
              0.26223279186396886`, 0.39295366914130303`, 0.9382451416067781],
              UndirectedEdge[85, 258] -> 
             RGBColor[
              0.24712036386052527`, 0.3770695491264064, 0.9373845111888157], 
             UndirectedEdge[26, 77] -> 
             RGBColor[
              0.6422389788407158, 0.7176486903810251, 0.9669170377654001], 
             UndirectedEdge[90, 333] -> 
             RGBColor[
              0.4506831285542931, 0.5464884699982167, 0.9528800174609131], 
             UndirectedEdge[45, 91] -> 
             RGBColor[
              0.27906015322156846`, 0.41064029284447245`, 0.9392034349422431],
              UndirectedEdge[103, 133] -> 
             RGBColor[
              0.32091218999488846`, 0.4513176188145481, 0.9417081084114585], 
             UndirectedEdge[143, 342] -> 
             RGBColor[
              0.6140012232637606, 0.6975128793422373, 0.9627555719373643], 
             UndirectedEdge[75, 164] -> 
             RGBColor[
              0.2433583151299939, 0.3731153973829517, 0.9371702680790643], 
             UndirectedEdge[44, 211] -> 
             RGBColor[
              0.28031687034096775`, 0.4119611822174286, 0.9392750031230466], 
             UndirectedEdge[82, 171] -> 
             RGBColor[
              0.32621487078886763`, 0.45368735101725755`, 0.9421273921767691],
              UndirectedEdge[17, 122] -> 
             RGBColor[
              0.490802095307585, 0.5972979545178956, 0.9531111298361363], 
             UndirectedEdge[150, 186] -> 
             RGBColor[
              0.2595342246109202, 0.3901173038593028, 0.9380914621938894], 
             UndirectedEdge[180, 394] -> 
             RGBColor[
              0.36256898672280274`, 0.4884607658773212, 0.9443235531201786], 
             UndirectedEdge[156, 202] -> 
             RGBColor[
              0.6328795969511609, 0.39363296767320055`, 0.4456899611555588], 
             UndirectedEdge[86, 178] -> 
             RGBColor[
              0.27226239938534696`, 0.40349542256011695`, 0.9388163129176459],
              UndirectedEdge[102, 250] -> 
             RGBColor[
              0.8756070959215718, 0.4293539198974725, 0.392331116689075], 
             UndirectedEdge[7, 222] -> 
             RGBColor[
              0.4971659473495666, 0.600925351032558, 0.9540373638977802], 
             UndirectedEdge[97, 220] -> 
             RGBColor[
              0.4588594812307164, 0.571262237287139, 0.9506250224317093], 
             UndirectedEdge[230, 289] -> 
             RGBColor[
              0.9333052704870481, 0.7676068761755623, 0.28495592618105414`], 
             UndirectedEdge[14, 289] -> 
             RGBColor[
              0.9460551929840001, 0.8094710811761514, 0.43178805845315205`], 
             UndirectedEdge[77, 370] -> 
             RGBColor[
              0.8302908639224114, 0.8675154135193626, 0.9836750778819656], 
             UndirectedEdge[151, 270] -> 
             RGBColor[
              0.28271133263489734`, 0.4138224395491612, 0.9394353643355215], 
             UndirectedEdge[173, 214] -> 
             RGBColor[
              0.6050703523847987, 0.6713378352539525, 0.9242773858520503], 
             UndirectedEdge[144, 317] -> 
             RGBColor[
              0.9345325845565998, 0.7656448596324403, 0.5126377323294256], 
             UndirectedEdge[31, 175] -> 
             RGBColor[
              0.18107477738655686`, 0.3076514502102228, 0.9336233127448126], 
             UndirectedEdge[163, 240] -> 
             RGBColor[
              0.2420898799764604, 0.3717821916131542, 0.9370980325735522], 
             UndirectedEdge[329, 371] -> 
             RGBColor[
              0.25359221551815353`, 0.38387187555766883`, 0.9377530735664711],
              UndirectedEdge[72, 375] -> 
             RGBColor[
              0.24128592482540645`, 0.37093718377569584`, 0.9370522485170447],
              UndirectedEdge[32, 238] -> 
             RGBColor[
              0.22275425852448527`, 0.3514592275179208, 0.9359968975363508], 
             UndirectedEdge[11, 14] -> 
             RGBColor[
              0.9589098698169762, 0.8623003371232989, 0.4422276945427869], 
             UndirectedEdge[79, 237] -> 
             RGBColor[
              0.5846124943759591, 0.6736537852839712, 0.9604419835448554], 
             UndirectedEdge[69, 74] -> 
             RGBColor[
              0.6564460490256175, 0.7292165790501876, 0.9679963956135333], 
             UndirectedEdge[16, 203] -> 
             RGBColor[
              0.2666290431845753, 0.3975744080176934, 0.9384955016158156], 
             UndirectedEdge[315, 319] -> 
             RGBColor[
              0.24242894961997336`, 0.37213857530674344`, 0.9371173420881417],
              UndirectedEdge[40, 80] -> 
             RGBColor[
              0.3368642646638673, 0.46619662758676733`, 0.9426856709603764], 
             UndirectedEdge[18, 198] -> 
             RGBColor[
              0.8858480974802114, 0.9115700695530261, 0.9804738418540726], 
             UndirectedEdge[300, 307] -> 
             RGBColor[
              0.9376183763421341, 0.7907736248179609, 0.5620991500919681], 
             UndirectedEdge[191, 198] -> 
             RGBColor[
              0.7526714957518834, 0.806764542665624, 0.9759689648481673], 
             UndirectedEdge[289, 391] -> 
             RGBColor[
              0.8461782962255958, 0.3146932430712892, 0.1902380974937647], 
             UndirectedEdge[132, 357] -> 
             RGBColor[
              0.7374562321167385, 0.7948256804953293, 0.9744664033632358], 
             UndirectedEdge[157, 187] -> 
             RGBColor[
              0.656588840938115, 0.7291931341002164, 0.9681680488654731], 
             UndirectedEdge[38, 250] -> 
             RGBColor[
              0.9770092142863354, 0.9428337657309378, 0.5831873792076157], 
             UndirectedEdge[140, 191] -> 
             RGBColor[
              0.6753891788981803, 0.7463384267939157, 0.9682801395479993], 
             UndirectedEdge[204, 261] -> 
             RGBColor[
              0.17918768478614402`, 0.3056679962386074, 0.9335158456129223], 
             UndirectedEdge[337, 354] -> 
             RGBColor[
              0.28225838404285286`, 0.4140018362171884, 0.9393855694561568], 
             UndirectedEdge[300, 314] -> 
             RGBColor[
              0.9079043794586273, 0.7685321222787813, 0.6113544605961532], 
             UndirectedEdge[292, 378] -> 
             RGBColor[
              0.20977255736756456`, 0.3378146365146045, 0.93525760886017], 
             UndirectedEdge[153, 361] -> 
             RGBColor[
              0.3365286408445437, 0.46590592710341294`, 0.9426642853073897], 
             UndirectedEdge[240, 334] -> 
             RGBColor[
              0.2503027734840032, 0.3804144634171059, 0.9375657447089196], 
             UndirectedEdge[52, 260] -> 
             RGBColor[
              0.5977997596730911, 0.6799974627988412, 0.9637251611956289], 
             UndirectedEdge[128, 177] -> 
             RGBColor[
              0.32406082685861914`, 0.45510693327935664`, 0.9418698472250615],
              UndirectedEdge[16, 85] -> 
             RGBColor[
              0.2415839884274967, 0.3712504675198166, 0.9370692227982382], 
             UndirectedEdge[179, 303] -> 
             RGBColor[
              0.27962744891017854`, 0.4112365565818258, 0.9392357415924706], 
             UndirectedEdge[48, 320] -> 
             RGBColor[
              0.5676684575710711, 0.6581064280542859, 0.9600245413086331], 
             UndirectedEdge[136, 320] -> 
             RGBColor[
              0.6642380668783059, 0.7372628617572051, 0.9674177280321361], 
             UndirectedEdge[96, 192] -> 
             RGBColor[
              0.3157006162298024, 0.44584698924097155`, 0.9414110583152703], 
             UndirectedEdge[140, 357] -> 
             RGBColor[
              0.6738075491078213, 0.7451028455808557, 0.9681224974716671], 
             UndirectedEdge[202, 306] -> 
             RGBColor[
              0.8943517891579421, 0.5932823607797533, 0.24752854128231921`], 
             UndirectedEdge[114, 258] -> 
             RGBColor[
              0.29090557114945215`, 0.42122924819894025`, 0.9399461663762204],
              UndirectedEdge[87, 236] -> 
             RGBColor[
              0.2703304585010046, 0.4014648301985463, 0.938706291742333], 
             UndirectedEdge[116, 362] -> 
             RGBColor[
              0.41044018393094006`, 0.5299243908226783, 0.9473738634754435], 
             UndirectedEdge[36, 64] -> 
             RGBColor[
              0.45931878415001925`, 0.5704587671539738, 0.9509862102607236], 
             UndirectedEdge[245, 304] -> 
             RGBColor[
              0.22449864114749254`, 0.35329268425494775`, 0.9360962375461481],
              UndirectedEdge[187, 218] -> 
             RGBColor[
              0.8769988069965478, 0.9047590594733392, 0.9881301231890498], 
             UndirectedEdge[26, 370] -> 
             RGBColor[
              0.6431647387570222, 0.7183868662092043, 0.9670053375726531], 
             UndirectedEdge[91, 141] -> 
             RGBColor[
              0.3113425799408942, 0.43982647528346147`, 0.9412155979078848], 
             UndirectedEdge[55, 385] -> 
             RGBColor[
              0.4894768493024928, 0.5950665939158499, 0.9533260603680459], 
             UndirectedEdge[179, 231] -> 
             RGBColor[
              0.28916364068982703`, 0.4212596987717169, 0.9397788136067902], 
             UndirectedEdge[94, 177] -> 
             RGBColor[
              0.29101623446385616`, 0.4219899291618881, 0.9399288750630955], 
             UndirectedEdge[225, 383] -> 
             RGBColor[
              0.26867221560749177`, 0.39972191177879235`, 0.938611857262698], 
             UndirectedEdge[37, 134] -> 
             RGBColor[
              0.24206319644531432`, 0.3717541455300861, 0.9370965129859282], 
             UndirectedEdge[255, 341] -> 
             RGBColor[
              0.24102934533176992`, 0.3706675024598044, 0.9370376366944575], 
             UndirectedEdge[206, 278] -> 
             RGBColor[
              0.24198884677049953`, 0.37167599930781414`, 0.937092278881938], 
             UndirectedEdge[131, 279] -> 
             RGBColor[
              0.934057909721427, 0.776268616484077, 0.26579965018330676`], 
             UndirectedEdge[7, 203] -> 
             RGBColor[
              0.3404012849561078, 0.4676562364290735, 0.9429697763439697], 
             UndirectedEdge[101, 151] -> 
             RGBColor[
              0.2883386750076016, 0.41973713317698713`, 0.9397558331587401], 
             UndirectedEdge[200, 296] -> 
             RGBColor[
              0.2860905976760283, 0.41802973572203384`, 0.939603808353314], 
             UndirectedEdge[86, 229] -> 
             RGBColor[
              0.27371625819309475`, 0.4050235203470323, 0.9388991080259558], 
             UndirectedEdge[138, 382] -> 
             RGBColor[
              0.8458222250338829, 0.3108788116534561, 0.1898549306427063], 
             UndirectedEdge[195, 278] -> 
             RGBColor[
              0.24905516487064655`, 0.3791031476615132, 0.9374946952440605], 
             UndirectedEdge[65, 113] -> 
             RGBColor[
              0.6559239156864949, 0.7291861264524664, 0.9676704388099608], 
             UndirectedEdge[249, 270] -> 
             RGBColor[
              0.25957821450255336`, 0.3901635400245296, 0.9380939673531408], 
             UndirectedEdge[319, 388] -> 
             RGBColor[
              0.23247439130222355`, 0.3616757033593372, 0.9365504447183952], 
             UndirectedEdge[138, 256] -> 
             RGBColor[
              0.6213313727692809, 0.21783685259893074`, 0.42281816094082003`],
              UndirectedEdge[246, 286] -> 
             RGBColor[
              0.5850263680482788, 0.6724463268342122, 0.9614245811742612], 
             UndirectedEdge[188, 208] -> 
             RGBColor[
              0.25008631824464794`, 0.38018695523648866`, 0.9375534179032552],
              UndirectedEdge[173, 345] -> 
             RGBColor[
              0.21415750276433887`, 0.34242349214821033`, 0.9355073250135709],
              UndirectedEdge[84, 156] -> 
             RGBColor[
              0.18244327672263497`, 0.3090898297803102, 0.9337012467574888], 
             UndirectedEdge[136, 349] -> 
             RGBColor[
              0.5319806271096528, 0.6307093057544687, 0.9563581696523957], 
             UndirectedEdge[117, 346] -> 
             RGBColor[
              0.3472745636844825, 0.4752135053615816, 0.9433490060085041], 
             UndirectedEdge[26, 197] -> 
             RGBColor[
              0.7219321437839568, 0.7790682930787789, 0.8931643392096228], 
             UndirectedEdge[328, 362] -> 
             RGBColor[
              0.35704810596381387`, 0.4836788564514203, 0.9439717674801389], 
             UndirectedEdge[187, 275] -> 
             RGBColor[
              0.9180172404014313, 0.9346976892728417, 0.8827763564020366], 
             UndirectedEdge[20, 121] -> 
             RGBColor[
              0.48042756078829996`, 0.5878320132896839, 0.9525827103922078], 
             UndirectedEdge[198, 302] -> 
             RGBColor[
              0.9068833316004294, 0.9166145009599966, 0.6941933109869335], 
             UndirectedEdge[1, 312] -> 
             RGBColor[
              0.4114701041040899, 0.5305547297160472, 0.9475118048057347], 
             UndirectedEdge[89, 292] -> 
             RGBColor[
              0.21480075229645693`, 0.3430995881908423, 0.9355439571228226], 
             UndirectedEdge[304, 315] -> 
             RGBColor[
              0.23118633013209117`, 0.360321869401733, 0.9364770915402718], 
             UndirectedEdge[21, 64] -> 
             RGBColor[
              0.3559387070583645, 0.4827179508795304, 0.9439010775628867], 
             UndirectedEdge[201, 351] -> 
             RGBColor[
              0.26108538890678307`, 0.3917476758837515, 0.9381797987057969], 
             UndirectedEdge[17, 218] -> 
             RGBColor[
              0.7227901892843811, 0.7824598484159166, 0.9739304322567687], 
             UndirectedEdge[266, 365] -> 
             RGBColor[
              0.25561932448523794`, 0.3860024956082064, 0.9378685144233075], 
             UndirectedEdge[112, 180] -> 
             RGBColor[
              0.34759559659056605`, 0.4754915679292482, 0.9433694619414015], 
             UndirectedEdge[247, 289] -> 
             RGBColor[
              0.9023804239029701, 0.648813195238765, 0.2402147401558417], 
             UndirectedEdge[15, 45] -> 
             RGBColor[
              0.29968000514429743`, 0.4323130645893829, 0.9403777050049051], 
             UndirectedEdge[57, 92] -> 
             RGBColor[
              0.2804356326225079, 0.4120860089052909, 0.9392817664592872], 
             UndirectedEdge[53, 86] -> 
             RGBColor[
              0.2948901577623302, 0.4272786312970708, 0.9401049302824465], 
             UndirectedEdge[114, 154] -> 
             RGBColor[
              0.3795179550306004, 0.5031411103456188, 0.9454035263933673], 
             UndirectedEdge[71, 237] -> 
             RGBColor[
              0.7247695222504801, 0.7843485609125668, 0.9737619050151656], 
             UndirectedEdge[241, 375] -> 
             RGBColor[
              0.2729036444443398, 0.40416941177440335`, 0.9388528308751185], 
             UndirectedEdge[100, 282] -> 
             RGBColor[
              0.5117379294109875, 0.6123392626277626, 0.9553276443786378], 
             UndirectedEdge[55, 146] -> 
             RGBColor[
              0.4694319452875655, 0.5787932378238967, 0.951748052097088], 
             UndirectedEdge[309, 319] -> 
             RGBColor[
              0.25618706106620875`, 0.38659922275138503`, 0.9379008461817029],
              UndirectedEdge[13, 302] -> 
             RGBColor[
              0.9755285816369456, 0.9706262250120263, 0.6756345411379316], 
             UndirectedEdge[110, 348] -> 
             RGBColor[
              0.25926658322907375`, 0.3898359957975386, 0.9380762204131332], 
             UndirectedEdge[217, 363] -> 
             RGBColor[
              0.8360546108977863, 0.2738301730667422, 0.18199059309576965`], 
             UndirectedEdge[39, 380] -> 
             RGBColor[
              0.2692913647455158, 0.4003726767791782, 0.9386471168901593], 
             UndirectedEdge[248, 304] -> 
             RGBColor[
              0.2176531615259033, 0.3460976511441812, 0.9357063976086782], 
             UndirectedEdge[204, 400] -> 
             RGBColor[
              0.2842689537951664, 0.40863855928315673`, 0.939773820202813], 
             UndirectedEdge[69, 168] -> 
             RGBColor[
              0.5791845558214077, 0.6688214100579597, 0.9603057503889199], 
             UndirectedEdge[68, 86] -> 
             RGBColor[
              0.28863048877409425`, 0.42069932230449786`, 0.9397484513939167],
              UndirectedEdge[175, 264] -> 
             RGBColor[
              0.18448157797338877`, 0.31123221363061604`, 0.9338173249983228],
              UndirectedEdge[1, 92] -> 
             RGBColor[
              0.3238234376355826, 0.4529521291016748, 0.9419260903719718], 
             UndirectedEdge[368, 393] -> 
             RGBColor[
              0.21780075210083538`, 0.3462527781962177, 0.93571480267358], 
             UndirectedEdge[332, 361] -> 
             RGBColor[
              0.4414240641856033, 0.5547544143941453, 0.9499025740169657], 
             UndirectedEdge[80, 203] -> 
             RGBColor[
              0.31290698696191654`, 0.4438420574101029, 0.9412178639880329], 
             UndirectedEdge[20, 347] -> 
             RGBColor[
              0.3438545327447645, 0.469598113054395, 0.9432282288718172], 
             UndirectedEdge[18, 311] -> 
             RGBColor[
              0.7322903023542322, 0.7896729975900088, 0.9664706721730203], 
             UndirectedEdge[170, 282] -> 
             RGBColor[
              0.5459157043281511, 0.6419423334360943, 0.9575054219741398], 
             UndirectedEdge[198, 323] -> 
             RGBColor[
              0.828349936933913, 0.8659677710237936, 0.9834899505331167], 
             UndirectedEdge[168, 357] -> 
             RGBColor[
              0.6729202964028389, 0.7444097170243531, 0.9680340644138824], 
             UndirectedEdge[180, 326] -> 
             RGBColor[
              0.3528301288862901, 0.48002545670856134`, 0.9437030017105699], 
             UndirectedEdge[18, 340] -> 
             RGBColor[
              0.9694923470519816, 0.9738780487256253, 0.770900506424754], 
             UndirectedEdge[74, 340] -> 
             RGBColor[
              0.9092258023331339, 0.9260683158029884, 0.7736525641500547], 
             UndirectedEdge[173, 204] -> 
             RGBColor[
              0.20264730553141047`, 0.33032554506774736`, 0.9348518363089665],
              UndirectedEdge[26, 30] -> 
             RGBColor[
              0.31701994287924884`, 0.4369570883961569, 0.9418741496415883], 
             UndirectedEdge[169, 240] -> 
             RGBColor[
              0.22995248947003588`, 0.35902502463589653`, 0.9364068261398715],
              UndirectedEdge[95, 371] -> 
             RGBColor[
              0.27691206805261726`, 0.40838251913543877`, 0.9390811046696785],
              UndirectedEdge[65, 356] -> 
             RGBColor[
              0.5168552955479615, 0.6186454388483807, 0.9551078886503179], 
             UndirectedEdge[264, 310] -> 
             RGBColor[
              0.18630458251799184`, 0.3131483069921579, 0.9339211424102444], 
             UndirectedEdge[96, 114] -> 
             RGBColor[
              0.3078946845637386, 0.4390858835693603, 0.940913671252023], 
             UndirectedEdge[244, 308] -> 
             RGBColor[
              0.2605622771689302, 0.3911978522800683, 0.9381500082662007], 
             UndirectedEdge[187, 298] -> 
             RGBColor[
              0.8336819864556111, 0.8702194025777671, 0.983998526176473], 
             UndirectedEdge[58, 228] -> 
             RGBColor[
              0.3333340850867448, 0.46222040417284493`, 0.9424943639948453], 
             UndirectedEdge[36, 82] -> 
             RGBColor[
              0.4494472254875384, 0.5619085191994977, 0.950357203271827], 
             UndirectedEdge[72, 355] -> 
             RGBColor[
              0.2293238377834227, 0.358364271854447, 0.9363710253563257], 
             UndirectedEdge[22, 350] -> 
             RGBColor[
              0.36253057369193453`, 0.4869086502715662, 0.9443767178010922], 
             UndirectedEdge[58, 192] -> 
             RGBColor[
              0.32165036846239214`, 0.45210055607350297`, 0.9417498879030466],
              UndirectedEdge[3, 174] -> 
             RGBColor[
              0.5493425209245979, 0.6414387311936623, 0.9591931799908751], 
             UndirectedEdge[44, 54] -> 
             RGBColor[
              0.3749740145051137, 0.4982078184475008, 0.9451505160427869], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.416297218948796, 0.5331956497034136, 0.948244914168578], 
             UndirectedEdge[170, 271] -> 
             RGBColor[
              0.37587875919358854`, 0.49980798052879155`, 0.9451782688612774],
              UndirectedEdge[192, 201] -> 
             RGBColor[
              0.3104580154232146, 0.4403366833931581, 0.941112499955068], 
             UndirectedEdge[274, 395] -> 
             RGBColor[
              0.2518980358087536, 0.3820911852658918, 0.9376565925383351], 
             UndirectedEdge[208, 284] -> 
             RGBColor[
              0.23854240400840393`, 0.3680535694477596, 0.9368960090651918], 
             UndirectedEdge[237, 320] -> 
             RGBColor[
              0.644156525821959, 0.7209597620645476, 0.9658368355590718], 
             UndirectedEdge[119, 380] -> 
             RGBColor[
              0.25299451614994406`, 0.383243655625352, 0.9377190354716685], 
             UndirectedEdge[342, 398] -> 
             RGBColor[
              0.7713918010534688, 0.8216082690775031, 0.9746694433091629], 
             UndirectedEdge[90, 264] -> 
             RGBColor[
              0.44791840801160593`, 0.5435825734144455, 0.9527225707160447], 
             UndirectedEdge[212, 367] -> 
             RGBColor[
              0.21510593499852879`, 0.3434203545604207, 0.9355613368262283], 
             UndirectedEdge[92, 284] -> 
             RGBColor[
              0.26583096592771405`, 0.3967355782197115, 0.9384500522966869], 
             UndirectedEdge[267, 342] -> 
             RGBColor[
              0.5872785724074823, 0.6758182275354083, 0.9606518669736626], 
             UndirectedEdge[107, 297] -> 
             RGBColor[
              0.8750247932704328, 0.5215412485823864, 0.4485289332891572], 
             UndirectedEdge[163, 245] -> 
             RGBColor[
              0.2374360489235272, 0.36689072010659024`, 0.9368330037798137], 
             UndirectedEdge[72, 200] -> 
             RGBColor[
              0.24919308184682543`, 0.37924810714791846`, 0.937502549411824], 
             UndirectedEdge[254, 286] -> 
             RGBColor[
              0.5978806349455185, 0.6831403582378857, 0.9623651309393161], 
             UndirectedEdge[269, 307] -> 
             RGBColor[
              0.9891494518709179, 0.9878632201941573, 0.6900803930330166], 
             UndirectedEdge[240, 304] -> 
             RGBColor[
              0.22915247220042573`, 0.35818415576151175`, 0.9363612663398866],
              UndirectedEdge[228, 332] -> 
             RGBColor[
              0.44753939238477464`, 0.5600512043149352, 0.9502922373222444], 
             UndirectedEdge[104, 109] -> 
             RGBColor[
              0.9639852685830836, 0.8836832833010115, 0.5065761886025747], 
             UndirectedEdge[28, 372] -> 
             RGBColor[
              0.2698833093261751, 0.4009948480649053, 0.9386808272583244], 
             UndirectedEdge[28, 362] -> 
             RGBColor[
              0.34647407000563907`, 0.4726287790194402, 0.9433672519077005], 
             UndirectedEdge[209, 227] -> 
             RGBColor[
              0.24347750032410487`, 0.3732406685787401, 0.9371770554995502], 
             UndirectedEdge[245, 371] -> 
             RGBColor[
              0.25097222698134913`, 0.38111810148861974`, 0.9376038690952258],
              UndirectedEdge[308, 397] -> 
             RGBColor[
              0.25521896402580857`, 0.3855816913810268, 0.9378457144874233], 
             UndirectedEdge[58, 87] -> 
             RGBColor[
              0.29447485481202706`, 0.42684212156457424`, 0.9400812793938123],
              UndirectedEdge[154, 332] -> 
             RGBColor[
              0.47868981834297064`, 0.5870321376139921, 0.9522771149190605], 
             UndirectedEdge[97, 180] -> 
             RGBColor[
              0.40427723483543804`, 0.5245863540749827, 0.9469811658087601], 
             UndirectedEdge[202, 300] -> 
             RGBColor[
              0.867558676545166, 0.48716538120934694`, 0.2110304482193309], 
             UndirectedEdge[25, 317] -> 
             RGBColor[
              0.8960164310071204, 0.5804110556384645, 0.39785186647159454`], 
             UndirectedEdge[93, 128] -> 
             RGBColor[
              0.2857256322546389, 0.41603117628641406`, 0.9396421556226617], 
             UndirectedEdge[68, 178] -> 
             RGBColor[
              0.2603565331566741, 0.3909816022782634, 0.9381382914490737], 
             UndirectedEdge[271, 273] -> 
             RGBColor[
              0.2911126400044641, 0.42330822062509427`, 0.9398898062344726], 
             UndirectedEdge[149, 318] -> 
             RGBColor[
              0.22201805165799737`, 0.3506854274230307, 0.9359549716444248], 
             UndirectedEdge[42, 358] -> 
             RGBColor[
              0.9504012676368335, 0.9272297470138823, 0.6629122325696076], 
             UndirectedEdge[155, 170] -> 
             RGBColor[
              0.3747576276064379, 0.498629600146848, 0.9451144220759548], 
             UndirectedEdge[193, 338] -> 
             RGBColor[
              0.9083139927934867, 0.9256835176042191, 0.801309811633953], 
             UndirectedEdge[79, 109] -> 
             RGBColor[
              0.79245120355282, 0.8352543310125031, 0.854215095221335], 
             UndirectedEdge[173, 175] -> 
             RGBColor[
              0.20264987627198583`, 0.3303282470790865, 0.9348519827088393], 
             UndirectedEdge[95, 178] -> 
             RGBColor[
              0.2628834870920424, 0.39363759108246865`, 0.9382821977373995], 
             UndirectedEdge[243, 348] -> 
             RGBColor[
              0.27566358738232355`, 0.40707028679271356`, 0.9390100055424669],
              UndirectedEdge[56, 83] -> 
             RGBColor[
              0.4019083501795848, 0.5225345452496872, 0.9468302225732115], 
             UndirectedEdge[205, 207] -> 
             RGBColor[
              0.967562165289962, 0.8957834071543473, 0.4992706546503005], 
             UndirectedEdge[74, 302] -> 
             RGBColor[
              0.9059752552459537, 0.9158904255240137, 0.6941066978535942], 
             UndirectedEdge[179, 196] -> 
             RGBColor[
              0.2837836367777321, 0.41560497354815545`, 0.9394724303429989], 
             UndirectedEdge[174, 338] -> 
             RGBColor[
              0.8614468790047858, 0.8890515325777966, 0.796643588235805], 
             UndirectedEdge[159, 167] -> 
             RGBColor[
              0.30749203096032607`, 0.43842628345076595`, 0.9408993959616536],
              UndirectedEdge[251, 356] -> 
             RGBColor[
              0.6703471241239707, 0.7405191581131181, 0.9690711033483659], 
             UndirectedEdge[238, 277] -> 
             RGBColor[
              0.24351796868213066`, 0.3732832033888673, 0.9371793601126722], 
             UndirectedEdge[163, 164] -> 
             RGBColor[
              0.24375587866941067`, 0.373533261869863, 0.9371929087344915], 
             UndirectedEdge[213, 230] -> 
             RGBColor[
              0.939912673270707, 0.7956677722978341, 0.2903688589282392], 
             UndirectedEdge[246, 343] -> 
             RGBColor[
              0.5830017143905886, 0.6708646520088869, 0.9612227826191269], 
             UndirectedEdge[53, 95] -> 
             RGBColor[
              0.2855112454690256, 0.4174207998194225, 0.9395708151022], 
             UndirectedEdge[139, 184] -> 
             RGBColor[
              0.21446679583023515`, 0.34274857877078024`, 0.9355249387961155],
              UndirectedEdge[101, 308] -> 
             RGBColor[
              0.26096510566357906`, 0.39162125056874597`, 0.9381729487530396],
              UndirectedEdge[3, 52] -> 
             RGBColor[
              0.3783625716146186, 0.5021403753019544, 0.9453299063837663], 
             UndirectedEdge[136, 286] -> 
             RGBColor[
              0.6724159966518739, 0.7436515226508849, 0.9682328276448666], 
             UndirectedEdge[164, 169] -> 
             RGBColor[
              0.23161848816298614`, 0.3607760948926053, 0.9365017023008109], 
             UndirectedEdge[14, 102] -> 
             RGBColor[
              0.8776503828613175, 0.4296669262232824, 0.3198017539696207], 
             UndirectedEdge[232, 281] -> 
             RGBColor[
              0.5787753460534887, 0.6689149253152545, 0.9599824618467317], 
             UndirectedEdge[56, 349] -> 
             RGBColor[
              0.44815708600119175`, 0.5625928756893122, 0.949777151123613], 
             UndirectedEdge[225, 324] -> 
             RGBColor[
              0.2685328797360218, 0.39957546094347285`, 0.9386039222909468], 
             UndirectedEdge[5, 272] -> 
             RGBColor[
              0.744229977263282, 0.800290827008182, 0.9750955199196911], 
             UndirectedEdge[68, 371] -> 
             RGBColor[
              0.27438511411724903`, 0.40572653033123346`, 0.9389371983813526],
              UndirectedEdge[151, 397] -> 
             RGBColor[
              0.28259253336983103`, 0.413697573989268, 0.9394285988931239], 
             UndirectedEdge[1, 356] -> 
             RGBColor[
              0.43918071918933627`, 0.5530514553912338, 0.949693285932573], 
             UndirectedEdge[96, 115] -> 
             RGBColor[
              0.262758793949384, 0.3935065306835328, 0.9382750966473921], 
             UndirectedEdge[328, 347] -> 
             RGBColor[
              0.29474363512034735`, 0.42706072191761096`, 0.940098925902251], 
             UndirectedEdge[80, 159] -> 
             RGBColor[
              0.3329254963503931, 0.4627850644418876, 0.9424346961263579], 
             UndirectedEdge[50, 121] -> 
             RGBColor[
              0.5036718866822538, 0.607942553625398, 0.9540700424119916], 
             UndirectedEdge[108, 342] -> 
             RGBColor[
              0.48546363914421214`, 0.5908319937486516, 0.9532799343430639], 
             UndirectedEdge[178, 315] -> 
             RGBColor[
              0.24363133500537287`, 0.37340235858243487`, 0.9371858161570703],
              UndirectedEdge[146, 228] -> 
             RGBColor[
              0.45159420731101624`, 0.5633430857393887, 0.9506114472065146], 
             UndirectedEdge[63, 152] -> 
             RGBColor[
              0.5710886094431091, 0.5911007265104762, 0.6136429928057057], 
             UndirectedEdge[43, 137] -> 
             RGBColor[
              0.22449567090087896`, 0.35328956233743236`, 0.9360960683949977],
              UndirectedEdge[97, 141] -> 
             RGBColor[
              0.401174197469898, 0.5218986590721447, 0.9467834430117361], 
             UndirectedEdge[25, 207] -> 
             RGBColor[
              0.8790926827074065, 0.5166988315788441, 0.21967434430270802`], 
             UndirectedEdge[214, 310] -> 
             RGBColor[
              0.5831756221385668, 0.6483250855590861, 0.9230305133548782], 
             UndirectedEdge[37, 87] -> 
             RGBColor[
              0.2699691213947309, 0.4010850419897568, 0.9386857141286811], 
             UndirectedEdge[146, 262] -> 
             RGBColor[
              0.736987048840004, 0.7937027834714817, 0.9726540973253948], 
             UndirectedEdge[322, 364] -> 
             RGBColor[
              0.428972946302528, 0.5444804947900268, 0.9489681159313363], 
             UndirectedEdge[219, 311] -> 
             RGBColor[
              0.48328094147507245`, 0.5912218175992272, 0.9525107826182344], 
             UndirectedEdge[5, 260] -> 
             RGBColor[
              0.8251985302055844, 0.863544075950503, 0.9831657085828327], 
             UndirectedEdge[204, 389] -> 
             RGBColor[
              0.17900756331513207`, 0.305478677152213, 0.9335055879616141], 
             UndirectedEdge[275, 279] -> 
             RGBColor[
              0.9688751403565641, 0.9066136951652177, 0.5278514920501343], 
             UndirectedEdge[78, 289] -> 
             RGBColor[
              0.8604804024531523, 0.4246254987591992, 0.2039338105691914], 
             UndirectedEdge[163, 329] -> 
             RGBColor[
              0.2400560374603316, 0.3696444941756393, 0.936982208251059], 
             UndirectedEdge[47, 181] -> 
             RGBColor[
              0.5006021052009016, 0.6049229030605833, 0.9539741177513421], 
             UndirectedEdge[267, 291] -> 
             RGBColor[
              0.6338452626420983, 0.7127939223878283, 0.964884724751121], 
             UndirectedEdge[28, 301] -> 
             RGBColor[
              0.27255350960952185`, 0.40380139786317903`, 0.9388328912142536],
              UndirectedEdge[174, 193] -> 
             RGBColor[
              0.7754724977883137, 0.8245433157037161, 0.9782504569369469], 
             UndirectedEdge[60, 263] -> 
             RGBColor[
              0.3098059764171655, 0.4384458415430197, 0.9411195068336586], 
             UndirectedEdge[122, 385] -> 
             RGBColor[
              0.510754315643456, 0.6134960658238386, 0.9546818417083673], 
             UndirectedEdge[282, 350] -> 
             RGBColor[
              0.5398022619922347, 0.6366471769552697, 0.9571158788344], 
             UndirectedEdge[142, 306] -> 
             RGBColor[
              0.8711813542536425, 0.41518424475599036`, 0.22534050665069866`],
              UndirectedEdge[6, 289] -> 
             RGBColor[
              0.9455504255792939, 0.808391434737298, 0.3768472415142159], 
             UndirectedEdge[3, 117] -> 
             RGBColor[
              0.35979838664313185`, 0.4860610113427193, 0.9441470129330474], 
             UndirectedEdge[6, 132] -> 
             RGBColor[
              0.896284952197167, 0.9156286210821021, 0.7489609820272407], 
             UndirectedEdge[22, 394] -> 
             RGBColor[
              0.32559317401626164`, 0.45491533120018696`, 0.9420230993562184],
              UndirectedEdge[11, 391] -> 
             RGBColor[
              0.8547480807809132, 0.34991274703605424`, 0.19719785488685457`],
              UndirectedEdge[34, 249] -> 
             RGBColor[
              0.2909291460215572, 0.4227877812822719, 0.9398913506685179], 
             UndirectedEdge[269, 306] -> 
             RGBColor[
              0.9817175223804617, 0.9496479498761543, 0.4126513364277588], 
             UndirectedEdge[69, 394] -> 
             RGBColor[
              0.42354328649608, 0.5403260059804602, 0.948470615599907], 
             UndirectedEdge[361, 369] -> 
             RGBColor[
              0.30654023496768024`, 0.43518917662023243`, 0.9409270894573605],
              UndirectedEdge[85, 184] -> 
             RGBColor[
              0.22953519250719354`, 0.35858641906979366`, 0.9363830616951732],
              UndirectedEdge[73, 96] -> 
             RGBColor[
              0.26501373249139615`, 0.3958766140625488, 0.9384035120614771], 
             UndirectedEdge[71, 382] -> 
             RGBColor[
              0.8849504676641144, 0.7666705508963009, 0.612411028914603], 
             UndirectedEdge[122, 165] -> 
             RGBColor[
              0.48941818004964077`, 0.5961744297668246, 0.9530021829575823], 
             UndirectedEdge[321, 331] -> 
             RGBColor[
              0.634939466831133, 0.7117908877119044, 0.9662504402131629], 
             UndirectedEdge[296, 374] -> 
             RGBColor[
              0.2888126336637139, 0.4208907681321412, 0.9397588242759214], 
             UndirectedEdge[66, 297] -> 
             RGBColor[
              0.9597109537164616, 0.9397882388587341, 0.661988741969209], 
             UndirectedEdge[75, 145] -> 
             RGBColor[
              0.24110109065239455`, 0.37074291134069687`, 0.9370417224843294],
              UndirectedEdge[105, 239] -> 
             RGBColor[
              0.37092951443948974`, 0.4957022347731742, 0.9448562785533615], 
             UndirectedEdge[92, 354] -> 
             RGBColor[
              0.2837186388686095, 0.41553665662456213`, 0.9394687288082302], 
             UndirectedEdge[188, 369] -> 
             RGBColor[
              0.26226993371413826`, 0.39299270758076044`, 0.9382472567801988],
              UndirectedEdge[170, 251] -> 
             RGBColor[
              0.6336427393204518, 0.7104942073432939, 0.966244231440377], 
             UndirectedEdge[53, 68] -> 
             RGBColor[
              0.28298429153365734`, 0.4147648110152172, 0.9394269088138741], 
             UndirectedEdge[274, 318] -> 
             RGBColor[
              0.2272727207343431, 0.3562084177875322, 0.9362542172747363], 
             UndirectedEdge[179, 359] -> 
             RGBColor[
              0.2576056390091489, 0.3880902381124516, 0.9379816320969553], 
             UndirectedEdge[20, 328] -> 
             RGBColor[
              0.3585480828066595, 0.484978061001665, 0.9440673446781876], 
             UndirectedEdge[307, 352] -> 
             RGBColor[
              0.9896970551583855, 0.989034488254865, 0.7496836314580985], 
             UndirectedEdge[6, 216] -> 
             RGBColor[
              0.8262245586177389, 0.8608969091391403, 0.7419780167468455], 
             UndirectedEdge[297, 385] -> 
             RGBColor[
              0.76103003285282, 0.8129579010796052, 0.9674643990261943], 
             UndirectedEdge[40, 348] -> 
             RGBColor[
              0.3011336768698887, 0.43101491807386594`, 0.9405639649079968], 
             UndirectedEdge[229, 329] -> 
             RGBColor[
              0.2410174933653264, 0.37065504529161414`, 0.937036961742502], 
             UndirectedEdge[6, 213] -> 
             RGBColor[
              0.9521578283629528, 0.8364523308595698, 0.38226017426140096`], 
             UndirectedEdge[189, 374] -> 
             RGBColor[
              0.2883252349784382, 0.42037848121105487`, 0.9397310676418367], 
             UndirectedEdge[97, 140] -> 
             RGBColor[
              0.5571047214907582, 0.6505692358866151, 0.9586689069541604], 
             UndirectedEdge[34, 386] -> 
             RGBColor[
              0.32582607560218535`, 0.4566359030170521, 0.9419823273140535], 
             UndirectedEdge[162, 313] -> 
             RGBColor[
              0.26444617460999714`, 0.3952800747439503, 0.938371190479758], 
             UndirectedEdge[258, 392] -> 
             RGBColor[
              0.25044123686096187`, 0.3805599972053746, 0.9375736299933992], 
             UndirectedEdge[45, 273] -> 
             RGBColor[
              0.2854682454604019, 0.41737560408400093`, 0.9395683663153217], 
             UndirectedEdge[226, 393] -> 
             RGBColor[
              0.2307270128999809, 0.3598390978683905, 0.9364509341034022], 
             UndirectedEdge[88, 168] -> 
             RGBColor[
              0.8302321284771527, 0.8662542155842119, 0.8889737374567761], 
             UndirectedEdge[188, 327] -> 
             RGBColor[
              0.2928390260811543, 0.4242124195155595, 0.9400214534598996], 
             UndirectedEdge[59, 349] -> 
             RGBColor[
              0.38969866664907243`, 0.5119591310520951, 0.9460522323352465], 
             UndirectedEdge[260, 398] -> 
             RGBColor[
              0.8741897182555676, 0.9025122258100744, 0.9845069042800476], 
             UndirectedEdge[248, 353] -> 
             RGBColor[
              0.21329376874399575`, 0.34151565292892977`, 0.9354581366388923],
              UndirectedEdge[30, 389] -> 
             RGBColor[
              0.17900757935671766`, 0.3054786940129366, 0.9335055888751587], 
             UndirectedEdge[216, 311] -> 
             RGBColor[
              0.5892378065656463, 0.6771523472031584, 0.9609814583426657], 
             UndirectedEdge[66, 307] -> 
             RGBColor[
              0.9790114308840521, 0.9540083964475, 0.6215212155905427], 
             UndirectedEdge[94, 225] -> 
             RGBColor[
              0.2586160366315361, 0.3891522300764899, 0.9380391727468009], 
             UndirectedEdge[177, 324] -> 
             RGBColor[
              0.3009330775683418, 0.4324131600288711, 0.9404936246072413], 
             UndirectedEdge[79, 320] -> 
             RGBColor[
              0.6503499887449748, 0.725987894277777, 0.9663244076477739], 
             UndirectedEdge[133, 234] -> 
             RGBColor[
              0.31799880832538563`, 0.4487941940432452, 0.9415224703076799], 
             UndirectedEdge[35, 195] -> 
             RGBColor[
              0.2633678783864708, 0.39414671704509485`, 0.9383097831050244], 
             UndirectedEdge[34, 86] -> 
             RGBColor[
              0.30641268277319833`, 0.4390619601211778, 0.940773115180684], 
             UndirectedEdge[98, 131] -> 
             RGBColor[
              0.9500181408117219, 0.8331560489585412, 0.3119185917864623], 
             UndirectedEdge[173, 261] -> 
             RGBColor[
              0.2029079903175545, 0.3305995413063548, 0.9348666819218888], 
             UndirectedEdge[103, 331] -> 
             RGBColor[
              0.39832931347278433`, 0.519434563541872, 0.9466021695190721], 
             UndirectedEdge[135, 322] -> 
             RGBColor[
              0.5058470879872912, 0.6097084800365293, 0.954241282226749], 
             UndirectedEdge[50, 181] -> 
             RGBColor[
              0.5107299622168331, 0.6136726173070488, 0.9546256799726562], 
             UndirectedEdge[35, 153] -> 
             RGBColor[
              0.2992359056961653, 0.4310433224437109, 0.940381814697533], 
             UndirectedEdge[121, 362] -> 
             RGBColor[
              0.4789275839454543, 0.5865328087394392, 0.9524871331941591], 
             UndirectedEdge[84, 152] -> 
             RGBColor[
              0.18127159018880934`, 0.30785831294404253`, 0.9336345209427424],
              UndirectedEdge[295, 345] -> 
             RGBColor[
              0.22216737223106828`, 0.3508423728127994, 0.9359634752301611], 
             UndirectedEdge[22, 266] -> 
             RGBColor[
              0.27365816407618504`, 0.40496245974678047`, 0.9388957996519403],
              UndirectedEdge[271, 335] -> 
             RGBColor[
              0.2936530311811995, 0.4259783328219468, 0.9400344777538158], 
             UndirectedEdge[175, 261] -> 
             RGBColor[
              0.1791902555267194, 0.3056706982499465, 0.9335159920127951], 
             UndirectedEdge[59, 254] -> 
             RGBColor[
              0.401764791398701, 0.521970513340684, 0.9469425623795822], 
             UndirectedEdge[53, 270] -> 
             RGBColor[
              0.26941555401375766`, 0.4005032075741548, 0.9386541892852642], 
             UndirectedEdge[214, 300] -> 
             RGBColor[
              0.9368849358196452, 0.7904007327583793, 0.5711375264891978], 
             UndirectedEdge[3, 386] -> 
             RGBColor[
              0.35472139925516205`, 0.48166358004406556`, 0.9438235117860897],
              UndirectedEdge[299, 336] -> 
             RGBColor[
              0.2125676316732109, 0.34075243682778544`, 0.9354167842069347], 
             UndirectedEdge[110, 351] -> 
             RGBColor[
              0.25066121746090764`, 0.3807912107634932, 0.9375861575631339], 
             UndirectedEdge[172, 328] -> 
             RGBColor[
              0.3054309232922502, 0.438293739399488, 0.9407075511532149], 
             UndirectedEdge[185, 302] -> 
             RGBColor[
              0.8782193338347415, 0.4449822071471867, 0.2485709297509695], 
             UndirectedEdge[370, 391] -> 
             RGBColor[
              0.8239994014416612, 0.39457661369970487`, 0.4393608257670162], 
             UndirectedEdge[50, 364] -> 
             RGBColor[
              0.4018386991300539, 0.5224516905515073, 0.9468320085978967], 
             UndirectedEdge[73, 195] -> 
             RGBColor[
              0.2444053413712617, 0.37421588834782205`, 0.937229894674568], 
             UndirectedEdge[80, 332] -> 
             RGBColor[
              0.4308190028061351, 0.5455688432531333, 0.9492268288835535], 
             UndirectedEdge[5, 267] -> 
             RGBColor[
              0.7063209858486378, 0.7695859535146778, 0.9720624004607035], 
             UndirectedEdge[136, 246] -> 
             RGBColor[
              0.5311924849620417, 0.6300266566393842, 0.9563079499316767], 
             UndirectedEdge[59, 246] -> 
             RGBColor[
              0.38891052450146135`, 0.5112764819370106, 0.9460020126145274], 
             UndirectedEdge[177, 200] -> 
             RGBColor[
              0.2962840776702533, 0.42752676637236176`, 0.9402288709406241], 
             UndirectedEdge[17, 157] -> 
             RGBColor[
              0.5023802232259484, 0.6068939230427937, 0.9539683579331921], 
             UndirectedEdge[151, 386] -> 
             RGBColor[
              0.3275993292124569, 0.45817180616795133`, 0.9420953174660733], 
             UndirectedEdge[4, 188] -> 
             RGBColor[
              0.24964120798061978`, 0.37971911612737436`, 0.9375280695322004],
              UndirectedEdge[241, 255] -> 
             RGBColor[
              0.2757184631493581, 0.40712796470319146`, 0.9390131306362182], 
             UndirectedEdge[62, 345] -> 
             RGBColor[
              0.19050782677282135`, 0.3175661832050619, 0.9341605109524143], 
             UndirectedEdge[57, 114] -> 
             RGBColor[
              0.3010426520782409, 0.43188396298315035`, 0.9405234581386476], 
             UndirectedEdge[32, 137] -> 
             RGBColor[
              0.21892075175740905`, 0.34742996884735633`, 0.9357785849971308],
              UndirectedEdge[152, 175] -> 
             RGBColor[
              0.181274153781999, 0.307861007443026, 0.9336346669355821], 
             UndirectedEdge[99, 235] -> 
             RGBColor[
              0.8591106393434069, 0.8900471270857477, 0.9483188623764983], 
             UndirectedEdge[156, 256] -> 
             RGBColor[
              0.20563395231845213`, 0.3334647002052716, 0.9350219214251405], 
             UndirectedEdge[48, 286] -> 
             RGBColor[
              0.5758463873446392, 0.6644950889479655, 0.9608396409213635], 
             UndirectedEdge[61, 262] -> 
             RGBColor[
              0.9659943820446136, 0.9709682059989204, 0.7529333373497976], 
             UndirectedEdge[146, 385] -> 
             RGBColor[
              0.5553761412741389, 0.6499183967532158, 0.95814039073239], 
             UndirectedEdge[29, 150] -> 
             RGBColor[
              0.2555149933709343, 0.38589283699209853`, 0.937862572920692], 
             UndirectedEdge[141, 220] -> 
             RGBColor[
              0.4177492311275311, 0.5356546049090093, 0.9480055136475012], 
             UndirectedEdge[152, 242] -> 
             RGBColor[
              0.5509815030039178, 0.5121510355041116, 0.5934630978551525], 
             UndirectedEdge[95, 151] -> 
             RGBColor[
              0.2988070240901653, 0.4307400317944288, 0.9403519901524575], 
             UndirectedEdge[252, 293] -> 
             RGBColor[
              0.21778209463220533`, 0.3462331680137357, 0.9357137401583427], 
             UndirectedEdge[93, 390] -> 
             RGBColor[
              0.2557686929307827, 0.3861594913149804, 0.9378770207353105], 
             UndirectedEdge[229, 249] -> 
             RGBColor[
              0.2582327214414536, 0.38874934150812634`, 0.9380173435137897], 
             UndirectedEdge[96, 153] -> 
             RGBColor[
              0.3021711245350493, 0.4341284235470012, 0.9405489710681403], 
             UndirectedEdge[202, 217] -> 
             RGBColor[
              0.8451683070696899, 0.34818897778180974`, 0.19088652790122868`],
              UndirectedEdge[163, 304] -> 
             RGBColor[
              0.23203584179739814`, 0.3612147600241211, 0.9365254699728711], 
             UndirectedEdge[18, 323] -> 
             RGBColor[
              0.8877084052982851, 0.9130534285104475, 0.9806512796744769], 
             UndirectedEdge[152, 264] -> 
             RGBColor[
              0.186823590274237, 0.31369381705096394`, 0.9339506991341594], 
             UndirectedEdge[23, 169] -> 
             RGBColor[
              0.21705819820147026`, 0.34547230696734843`, 0.9356725153275212],
              UndirectedEdge[290, 342] -> 
             RGBColor[
              0.5042459583975736, 0.6071002946590989, 0.9544767271173353], 
             UndirectedEdge[285, 330] -> 
             RGBColor[
              0.23174352854992997`, 0.3609075202673017, 0.9365088231658666], 
             UndirectedEdge[55, 192] -> 
             RGBColor[
              0.3740111987150174, 0.498371434802681, 0.9450526407503718], 
             UndirectedEdge[161, 170] -> 
             RGBColor[
              0.43820314080929235`, 0.5539712686639211, 0.9491428945379133], 
             UndirectedEdge[42, 205] -> 
             RGBColor[
              0.9637471875060623, 0.9705535185426564, 0.8607371274369169], 
             UndirectedEdge[267, 398] -> 
             RGBColor[
              0.7553121738986209, 0.8085541033742493, 0.9734035961579184], 
             UndirectedEdge[32, 199] -> 
             RGBColor[
              0.22104408708317058`, 0.349661728901967, 0.9358995058027398], 
             UndirectedEdge[154, 385] -> 
             RGBColor[
              0.5027895372841396, 0.606597375130399, 0.9541743330742887], 
             UndirectedEdge[91, 190] -> 
             RGBColor[
              0.25186209923856306`, 0.38205341365211143`, 0.9376545460038261],
              UndirectedEdge[94, 380] -> 
             RGBColor[
              0.2628073165498582, 0.39355753101314184`, 0.9382778599377064], 
             UndirectedEdge[119, 288] -> 
             RGBColor[
              0.2427621793276949, 0.37248882085754254`, 0.9371363190270272], 
             UndirectedEdge[65, 251] -> 
             RGBColor[
              0.6688240146939028, 0.7392826292624911, 0.9689511985946974], 
             UndirectedEdge[198, 216] -> 
             RGBColor[
              0.7427956016916255, 0.7990494191661757, 0.974984628023718], 
             UndirectedEdge[101, 182] -> 
             RGBColor[
              0.2744680720566198, 0.40581372438534935`, 0.9389419227132746], 
             UndirectedEdge[11, 230] -> 
             RGBColor[
              0.9461599473200244, 0.8204361321227099, 0.29539556227068897`], 
             UndirectedEdge[53, 101] -> 
             RGBColor[
              0.27504289638646184`, 0.40641790120198085`, 0.9389746581084827],
              UndirectedEdge[202, 264] -> 
             RGBColor[
              0.634236755389537, 0.3950594272407488, 0.44576724932088835`], 
             UndirectedEdge[336, 367] -> 
             RGBColor[
              0.21516062802241154`, 0.34347784039625945`, 0.9355644515130273],
              UndirectedEdge[13, 132] -> 
             RGBColor[
              0.8815012453075697, 0.9077928551611671, 0.9634088234551113], 
             UndirectedEdge[146, 307] -> 
             RGBColor[
              0.760285606005483, 0.8109047025764178, 0.9254188643765703], 
             UndirectedEdge[75, 133] -> 
             RGBColor[
              0.27071817278007254`, 0.4018723424883518, 0.9387283714969541], 
             UndirectedEdge[153, 369] -> 
             RGBColor[
              0.28744235484774583`, 0.41864755274771004`, 0.9397101894237105],
              UndirectedEdge[20, 181] -> 
             RGBColor[
              0.4874856363228792, 0.5935620769713348, 0.9531383479528726], 
             UndirectedEdge[112, 394] -> 
             RGBColor[
              0.34389456121557604`, 0.47228591710687856`, 0.9431336352400042],
              UndirectedEdge[279, 306] -> 
             RGBColor[
              0.9580128778613826, 0.8669798939942239, 0.307271930750418], 
             UndirectedEdge[34, 68] -> 
             RGBColor[
              0.29450681654452554`, 0.42654813983932427`, 0.9400950937121118],
              UndirectedEdge[4, 284] -> 
             RGBColor[
              0.23809729374437577`, 0.3675857303386453, 0.936870660694137], 
             UndirectedEdge[193, 235] -> 
             RGBColor[
              0.7812166445775857, 0.8290306868326278, 0.9788229798067978], 
             UndirectedEdge[296, 316] -> 
             RGBColor[
              0.27790052377493313`, 0.40942144877130526`, 0.9391373957607753],
              UndirectedEdge[117, 223] -> 
             RGBColor[
              0.40179215387534173`, 0.5224135595233219, 0.9468284392932418], 
             UndirectedEdge[37, 110] -> 
             RGBColor[
              0.2526887349083196, 0.3829222601527542, 0.9377016216823209], 
             UndirectedEdge[83, 349] -> 
             RGBColor[
              0.3991304048320619, 0.5201284286132558, 0.946653214352108], 
             UndirectedEdge[192, 348] -> 
             RGBColor[
              0.30372248336585006`, 0.4332572121434699, 0.9407289213687278], 
             UndirectedEdge[97, 394] -> 
             RGBColor[
              0.40057619946044803`, 0.521380703252613, 0.9467453391073628], 
             UndirectedEdge[2, 352] -> 
             RGBColor[
              0.8770188414831279, 0.42518789908164617`, 0.3118987659924733], 
             UndirectedEdge[69, 350] -> 
             RGBColor[
              0.4604806861717529, 0.5723193250518395, 0.9508242340447808], 
             UndirectedEdge[164, 304] -> 
             RGBColor[
              0.230818470893376, 0.3599352260182205, 0.936456142500826], 
             UndirectedEdge[141, 350] -> 
             RGBColor[
              0.3964033490329356, 0.5177663899458625, 0.9464794487680284], 
             UndirectedEdge[114, 356] -> 
             RGBColor[
              0.4236281428800086, 0.5395805954873082, 0.9487022895227458], 
             UndirectedEdge[383, 390] -> 
             RGBColor[
              0.27326780022861263`, 0.40455216259248444`, 0.9388735690083126],
              UndirectedEdge[297, 307] -> 
             RGBColor[
              0.965939497584164, 0.9739442069028073, 0.9347428726703746], 
             UndirectedEdge[40, 58] -> 
             RGBColor[
              0.31906156196643076`, 0.449858262003899, 0.9415849314423156], 
             UndirectedEdge[173, 295] -> 
             RGBColor[
              0.23437748052955032`, 0.36367597080008385`, 0.9366588228345232],
              UndirectedEdge[161, 239] -> 
             RGBColor[
              0.3779757827321134, 0.5018053582125028, 0.9453052605381971], 
             UndirectedEdge[35, 369] -> 
             RGBColor[
              0.26924749981930185`, 0.40032657196053045`, 0.9386446188475038],
              UndirectedEdge[303, 313] -> 
             RGBColor[
              0.2862100467675046, 0.4181552842906852, 0.9396106108023645], 
             UndirectedEdge[237, 349] -> 
             RGBColor[
              0.5118990860533059, 0.6144062060618112, 0.9547772771793315], 
             UndirectedEdge[21, 263] -> 
             RGBColor[
              0.2875003760669833, 0.4191258516317633, 0.9396982137034129], 
             UndirectedEdge[126, 274] -> 
             RGBColor[
              0.22138486041548355`, 0.35001990328050514`, 0.9359189123398861],
              UndirectedEdge[331, 346] -> 
             RGBColor[
              0.3985622409768109, 0.5196363136385831, 0.946617011453659], 
             UndirectedEdge[106, 345] -> 
             RGBColor[
              0.5752211056493675, 0.6453489967018295, 0.953440498597335]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {3}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.23802405881018981`, 0.36750875577945274`, 0.9368664900729765],
              316 -> RGBColor[
              0.25427950679235417`, 0.38459426226363735`, 0.9377922137877805],
              308 -> RGBColor[
              0.2610883790761277, 0.39175081874132034`, 0.9381799689915176], 
             160 -> RGBColor[
              0.8294775817921864, 0.22758318757925894`, 0.17586107165535175`],
              245 -> RGBColor[
              0.22989884827362161`, 0.3589686443374169, 0.9364037713530907], 
             155 -> RGBColor[
              0.30454561984188433`, 0.43742713413433654`, 0.9406547945639009],
              213 -> RGBColor[
              0.9109681137578394, 0.6847252697068382, 0.24722105836383443`], 
             352 -> RGBColor[
              0.9941541355650164, 0.9899046120181566, 0.6050919166244885], 27 -> 
             RGBColor[
              0.2974167180204977, 0.42993420632157753`, 0.9402488141514381], 
             367 -> RGBColor[
              0.21931469518675756`, 0.34784402836905765`, 0.9358010194926452],
              19 -> RGBColor[
              0.2743841090042405, 0.40572547389373365`, 0.9389371411416538], 
             164 -> RGBColor[
              0.24253850776538854`, 0.3722537278639624, 0.9371235812624463], 
             190 -> RGBColor[
              0.2411029859620505, 0.37074490343131483`, 0.9370418304194105], 
             103 -> RGBColor[
              0.34456615692423104`, 0.4728676195543337, 0.943176428724691], 
             138 -> RGBColor[
              0.8193428764107183, 0.14968340096107918`, 0.16615606633654534`],
              291 -> RGBColor[
              0.696491580031562, 0.7628237829435023, 0.9703834296798242], 28 -> 
             RGBColor[
              0.2882891132658928, 0.42034051500092084`, 0.9397290105637445], 
             337 -> RGBColor[
              0.2847433322190086, 0.4166136743051424, 0.9395270835786375], 
             195 -> RGBColor[
              0.24569470610522032`, 0.37557109243365844`, 0.9373033220887227],
              114 -> RGBColor[
              0.3288778807819878, 0.45927922327560866`, 0.9421767856415051], 
             93 -> RGBColor[
              0.2452381115380016, 0.3750911825937439, 0.9372773197035907], 34 -> 
             RGBColor[
              0.3122890105436297, 0.4449107776560043, 0.9411197574988789], 
             161 -> RGBColor[
              0.4314366462475933, 0.5481104711684827, 0.9487117394878181], 22 -> 
             RGBColor[
              0.29231839668471055`, 0.42457554734542235`, 0.9399584722936555],
              124 -> RGBColor[
              0.22327126764014227`, 0.35200263687874755`, 0.936026340440641], 
             84 -> RGBColor[
              0.17892701429477148`, 0.30539401502471114`, 0.9335010008140661],
              46 -> RGBColor[
              0.2843163130979401, 0.41616485013432336`, 0.9395027654714108], 
             241 -> RGBColor[
              0.290961948336973, 0.42314983412815754`, 0.9398812245669373], 
             185 -> RGBColor[
              0.8236904837096025, 0.18310101579396953`, 0.170319339995877], 
             390 -> RGBColor[
              0.26629927432356376`, 0.3972278000362168, 0.9384767217670303], 
             121 -> RGBColor[
              0.5531961411455233, 0.6481485744409189, 0.9579687731366617], 
             322 -> RGBColor[
              0.5084161265639328, 0.611794141286916, 0.9544435263542006], 126 -> 
             RGBColor[
              0.21204174778307774`, 0.3401996995162911, 0.935386835897367], 
             236 -> RGBColor[
              0.2505222001886238, 0.3806450947961188, 0.9375782407351351], 78 -> 
             RGBColor[
              0.8418439495844675, 0.3226365094076515, 0.18770311941905493`], 
             376 -> RGBColor[
              0.43839329858407067`, 0.5541359737708264, 0.9491550112231723], 
             254 -> RGBColor[
              0.46951139015292603`, 0.5802095236300584, 0.951380802991181], 
             290 -> RGBColor[
              0.4051337172328171, 0.5253281960795354, 0.9470357401097634], 
             251 -> RGBColor[
              0.822315843269912, 0.8611563485272284, 0.9829144132927453], 165 -> 
             RGBColor[
              0.532748774101436, 0.6315484807311408, 0.9563590815017777], 100 -> 
             RGBColor[
              0.37661408553666426`, 0.5006259245426959, 0.9452184943970047], 
             235 -> RGBColor[
              0.7400936775781565, 0.7968860729351169, 0.9747292792785006], 70 -> 
             RGBColor[
              0.2778101351361315, 0.409326444580954, 0.9391322482615135], 234 -> 
             RGBColor[
              0.3387393935852255, 0.4678207700117279, 0.942805152517134], 257 -> 
             RGBColor[
              0.8226071697061851, 0.17477418965247965`, 0.16928195728277629`],
              135 -> RGBColor[
              0.5032780494106496, 0.6076228187861427, 0.9540390380992975], 
             265 -> RGBColor[
              0.5918946974095183, 0.6795658057661227, 0.9610152652432459], 
             111 -> RGBColor[
              0.8740781517963572, 0.5211001217496539, 0.21664006204298622`], 
             381 -> RGBColor[
              0.9931470290452047, 0.9914341346439413, 0.7632349938486772], 
             182 -> RGBColor[
              0.2880943118622093, 0.4201357663745271, 0.9397179169119876], 
             188 -> RGBColor[
              0.26708591845739416`, 0.39805461289699134`, 0.9385215199867163],
              154 -> RGBColor[
              0.4301580292792129, 0.547002997415629, 0.9486302671452295], 336 -> 
             RGBColor[
              0.2110065608580655, 0.33911165242346125`, 0.9353278835334095], 
             315 -> RGBColor[
              0.24327422624281886`, 0.37302701463098736`, 0.937165479341338], 
             368 -> RGBColor[
              0.21278150541118618`, 0.3409772316867757, 0.9354289639999145], 
             269 -> RGBColor[
              0.9930589289900814, 0.9875620758967413, 0.48588543977432486`], 
             208 -> RGBColor[
              0.2330867180319017, 0.36231929757598597`, 0.9365853158197941], 
             86 -> RGBColor[
              0.30053635500276704`, 0.4332131425863514, 0.940426472862489], 
             119 -> RGBColor[
              0.24049836738192176`, 0.3701094109685675, 0.9370073982857251], 
             377 -> RGBColor[
              0.41487938737084307`, 0.5337694057214698, 0.9476567255932007], 
             140 -> RGBColor[
              0.6719249954084331, 0.7436321803229556, 0.9679348621123766], 85 -> 
             RGBColor[
              0.2413074662041341, 0.37095982513054093`, 0.9370534752666957], 
             351 -> RGBColor[
              0.24574449108125243`, 0.37562341960001794`, 0.9373061572694574],
              242 -> RGBColor[
              0.9183468399249884, 0.7139794601448493, 0.25315815463888625`], 
             117 -> 
             RGBColor[
              0.3495171154366807, 0.47715589097540734`, 0.9434918994231435], 
             47 -> RGBColor[
              0.43389191818712153`, 0.5502371043169462, 0.948868187244693], 
             81 -> RGBColor[
              0.2197154470497895, 0.34826524398623987`, 0.9358238417183856], 
             275 -> RGBColor[
              0.992100640761205, 0.9910014261975552, 0.7805763556806252], 23 -> 
             RGBColor[
              0.21341792784235675`, 0.34164615201344867`, 0.935465207315867], 
             328 -> RGBColor[
              0.3094371851822424, 0.44244066986488095`, 0.9409380417086214], 
             110 -> RGBColor[
              0.25557794384056287`, 0.3859590019269685, 0.9378661578568105], 
             6 -> RGBColor[
              0.9933475429680663, 0.9881793920123014, 0.5172992901589675], 
             218 -> RGBColor[
              0.9100637739514378, 0.9311241665985504, 0.9912838892546516], 
             108 -> RGBColor[
              0.3675690787260941, 0.49279159425864094`, 0.9446421545612206], 
             297 -> RGBColor[
              0.9466390204165737, 0.9597240493140413, 0.9752103990490407], 
             157 -> RGBColor[
              0.46924384183457235`, 0.5799923158523045, 0.9513597406074984], 
             354 -> RGBColor[
              0.27977343586669706`, 0.4113899981292344, 0.939244055333676], 
             385 -> RGBColor[
              0.5754210452890663, 0.6661917528451691, 0.9597183990033479], 
             270 -> RGBColor[
              0.249587147505622, 0.3796622951405196, 0.9375249908681246], 392 -> 
             RGBColor[
              0.24794921220500737`, 0.3779407212884774, 0.9374317128758627], 
             33 -> RGBColor[
              0.17894138666990014`, 0.3054091213022326, 0.9335018192995677], 
             252 -> RGBColor[
              0.2243331252717409, 0.35311871657522015`, 0.9360868116618829], 
             394 -> RGBColor[
              0.35886795134781274`, 0.48525511505495156`, 0.9440877264187814],
              260 -> RGBColor[
              0.8089540339665278, 0.8506803067038047, 0.9815926360666765], 
             159 -> RGBColor[
              0.3314345944952444, 0.46149372018986384`, 0.9423396971785006], 
             183 -> RGBColor[
              0.2589336294896423, 0.3894860403069097, 0.9380572591902335], 99 -> 
             RGBColor[
              0.9781276011086575, 0.9832081812363787, 0.921908445474496], 329 -> 
             RGBColor[
              0.23513882534723038`, 0.36447619247551505`, 0.9367021802955814],
              309 -> 
             RGBColor[
              0.27079044913528966`, 0.40194830952027055`, 0.9387324875284604],
              17 -> RGBColor[
              0.5355166046173245, 0.6337955302332828, 0.9565769752588857], 
             349 -> RGBColor[
              0.4453791406536688, 0.5601867590528806, 0.9496001429025095], 
             347 -> RGBColor[
              0.2800500850584523, 0.411680773970341, 0.9392598100958807], 340 -> 
             RGBColor[
              0.99377812825938, 0.9891003704115706, 0.5641658418540755], 277 -> 
             RGBColor[
              0.2578128298869203, 0.3883080088616496, 0.9379934313109329], 
             104 -> RGBColor[
              0.9338740873595025, 0.7755398220742175, 0.265651742396037], 79 -> 
             RGBColor[
              0.590805957298975, 0.6786819174972005, 0.9609295556335575], 327 -> 
             RGBColor[
              0.3185921337049145, 0.45037022613412764`, 0.941521386933083], 
             191 -> RGBColor[
              0.6788533623879274, 0.7490446732648759, 0.968625416983622], 50 -> 
             RGBColor[
              0.45414763221898446`, 0.5677365328098771, 0.9501713116873214], 
             225 -> RGBColor[
              0.2571081050813221, 0.3875672984088326, 0.9379532982758011], 61 -> 
             RGBColor[
              0.9933459036684309, 0.98817588571614, 0.5171208625102379], 196 -> 
             RGBColor[
              0.29792411608308994`, 0.43046751385625726`, 0.9402777097204745],
              1 -> RGBColor[
              0.3599830334006432, 0.48622094308345976`, 0.9441587784611594], 
             263 -> RGBColor[
              0.26208361027682536`, 0.3927968698345563, 0.9382366459360847], 
             201 -> RGBColor[
              0.27642628673231373`, 0.407871932167485, 0.9390534401421363], 
             371 -> RGBColor[
              0.27204560568907665`, 0.4032675586398226, 0.9388039668373608], 
             293 -> RGBColor[
              0.21123106399266978`, 0.3393476194522512, 0.9353406686548026], 
             362 -> RGBColor[
              0.40465902674538534`, 0.5249170430379596, 0.9470054932516565], 
             184 -> RGBColor[
              0.21776291881025298`, 0.3462130130090464, 0.9357126481236506], 
             106 -> RGBColor[
              0.948494816832878, 0.9611080992427333, 0.9720690197854612], 206 -> 
             RGBColor[
              0.23156206990492625`, 0.36071679572626025`, 0.9364984893644777],
              358 -> RGBColor[
              0.9685766725786527, 0.9056638794389593, 0.332426736075871], 247 -> 
             RGBColor[
              0.9070075396154186, 0.6690229130152352, 0.24403428744221908`], 
             220 -> RGBColor[
              0.4754345148883495, 0.5850181831240037, 0.9518470930674744], 
             107 -> RGBColor[
              0.8392176796973624, 0.30244984821655896`, 0.1851882004092155], 
             375 -> RGBColor[
              0.25484534055170655`, 0.38518898942064916`, 0.9378244371832996],
              131 -> RGBColor[
              0.9224661794909306, 0.7303112688352736, 0.2564726719469704], 
             127 -> RGBColor[
              0.21049571798261152`, 0.33857472417205015`, 0.9352987917873766],
              210 -> RGBColor[
              0.2999237099233219, 0.432569213763913, 0.9403915836315417], 357 -> 
             RGBColor[
              0.6756901028072094, 0.7465735108387558, 0.9683101328309576], 
             181 -> RGBColor[
              0.5673122922146817, 0.6596087018042204, 0.9590800482579911], 
             194 -> RGBColor[
              0.3880550588481297, 0.5105355205850486, 0.9459475030995558], 
             118 -> RGBColor[
              0.20606162213947596`, 0.33391420830300045`, 0.935046276588767], 
             348 -> RGBColor[
              0.26295522261758464`, 0.39371298966810864`, 0.9382862829694559],
              276 -> RGBColor[
              0.765566144894021, 0.8167853580001923, 0.977268136766805], 305 -> 
             RGBColor[
              0.20290260740476634`, 0.33059388352371805`, 0.9348663753729688],
              343 -> RGBColor[
              0.7222005724227306, 0.7829078431950623, 0.9729458617771823], 
             280 -> RGBColor[
              0.23901320904650822`, 0.3685484153935707, 0.9369228207156182], 
             189 -> RGBColor[
              0.30054674338696064`, 0.4332240614368005, 0.9404270644656005], 
             168 -> RGBColor[
              0.6701504899984683, 0.7422459232099505, 0.9677579959968072], 
             363 -> RGBColor[
              0.8625124936811881, 0.46858316947675277`, 0.2069893934114667], 
             41 -> RGBColor[
              0.34082031608406577`, 0.4696231604900174, 0.9429377470586726], 
             14 -> RGBColor[
              0.9943570777774785, 0.9903386848900081, 0.6271809240368398], 77 -> 
             RGBColor[
              0.8293651040061051, 0.8667772376911834, 0.9835867780747127], 51 -> 
             RGBColor[
              0.3729233885884314, 0.4974292283459589, 0.9449833264510183], 
             179 -> RGBColor[
              0.2696431574723743, 0.40074243324005365`, 0.9386671509655232], 
             223 -> 
             RGBColor[
              0.4540671923140028, 0.5676712280712366, 0.9501649791633402], 
             323 -> RGBColor[
              0.8302102447519867, 0.867451129981215, 0.983667388353521], 292 -> 
             RGBColor[
              0.2110186790508826, 0.3391243894124498, 0.9353285736465631], 
             396 -> RGBColor[
              0.2782995151593558, 0.4098408140138484, 0.9391601177298633], 
             321 -> RGBColor[
              0.8177864636409283, 0.8575802678943982, 0.9824729701128726], 
             143 -> RGBColor[
              0.6246442469651912, 0.7061533654458123, 0.9635934297498213], 
             112 -> RGBColor[
              0.3289211710833394, 0.45931671915880556`, 0.9421795440612271], 
             197 -> RGBColor[
              0.988751433892587, 0.9896164430866911, 0.8360813809631582], 54 -> 
             RGBColor[
              0.4519914858020445, 0.5659140400742732, 0.9500214756882968], 71 -> 
             RGBColor[
              0.871120013048017, 0.9000714687543917, 0.9875693985741776], 177 -> 
             RGBColor[
              0.3219085007459621, 0.453242696579629, 0.9417327029083903], 158 -> 
             RGBColor[
              0.5031159008708285, 0.6074911792968075, 0.9540262731722731], 
             226 -> RGBColor[
              0.23863402700947722`, 0.3681498710311214, 0.9369012268595588], 
             350 -> RGBColor[
              0.4327427506991586, 0.5492417531977101, 0.948794963308529], 203 -> 
             RGBColor[
              0.29139757571829134`, 0.42360770612629445`, 0.9399060329018505],
              115 -> RGBColor[
              0.2386060995532787, 0.36812051750395375`, 0.9368996364322433], 
             173 -> RGBColor[
              0.22636761106282094`, 0.3552570901354948, 0.936202672617933], 
             212 -> RGBColor[
              0.21089717481030001`, 0.33899668075178374`, 0.9353216541598114],
              129 -> RGBColor[
              0.23768447069359533`, 0.36715182713778177`, 0.936847151032112], 
             279 -> RGBColor[
              0.9456496399519233, 0.8222259641328803, 0.2751266284196432], 26 -> 
             RGBColor[
              0.45511285367532656`, 0.5685201430708667, 0.9502472974560874], 
             40 -> RGBColor[
              0.3393121311221928, 0.4683168464796233, 0.9428416468465376], 
             146 -> RGBColor[
              0.5353312372592116, 0.6336450406612625, 0.9565623824614321], 
             386 -> RGBColor[
              0.3393631406607411, 0.4683610283780999, 0.942844897129228], 192 -> 
             RGBColor[
              0.34448974411411554`, 0.4728014346188312, 0.9431715597679996], 
             300 -> RGBColor[
              0.8899967779325137, 0.5933828851443484, 0.2299229538922278], 
             221 -> RGBColor[
              0.9218589159168126, 0.9405292926311409, 0.9924089204249567], 62 -> 
             RGBColor[
              0.1790682590797859, 0.30554247224919795`, 0.9335090444956198], 
             286 -> RGBColor[
              0.726249879738111, 0.7860711928457129, 0.9733494588874512], 152 -> 
             RGBColor[
              0.18361616608284723`, 0.3103226108633739, 0.9337680410714186], 
             64 -> RGBColor[
              0.3989602722595878, 0.5199810683300905, 0.9466423736550322], 
             307 -> RGBColor[
              0.9852399747517544, 0.9881643644915732, 0.8942753462917085], 37 -> 
             RGBColor[
              0.24979952597607638`, 0.3798855183785399, 0.9375370855078312], 
             148 -> RGBColor[
              0.6238880244982119, 0.7055394299796848, 0.9635338971470865], 
             261 -> RGBColor[
              0.17944836957228805`, 0.3059419924772149, 0.9335306912258446], 
             387 -> RGBColor[
              0.2935687509337651, 0.4258897489382169, 0.9400296781184059], 15 -> 
             RGBColor[
              0.3038609163605336, 0.43670746736272875`, 0.940615801713566], 
             136 -> RGBColor[
              0.6185821135656369, 0.7012318524560568, 0.9631161964022821], 
             198 -> RGBColor[
              0.8264896291158393, 0.8644844120663722, 0.9833125127127125], 63 -> 
             RGBColor[
              0.9585610528033711, 0.8718788421575785, 0.2935179445399928], 
             310 -> RGBColor[
              0.18257815057035692`, 0.3092315907457619, 0.9337089276235886], 
             171 -> RGBColor[
              0.2732125866431092, 0.40449412961337683`, 0.9388704246762993], 
             395 -> RGBColor[
              0.27306809856961783`, 0.40434226348706437`, 0.938862196294265], 
             311 -> RGBColor[
              0.519374038863881, 0.6206902681403376, 0.955306173350608], 353 -> 
             RGBColor[
              0.21037964845754836`, 0.3384527277419758, 0.9352921817996338], 
             59 -> RGBColor[
              0.3340181926444761, 0.4637315030513096, 0.9425043217679835], 
             397 -> RGBColor[
              0.2493495489754894, 0.37941256402073326`, 0.9375114599833291], 
             229 -> RGBColor[
              0.24689616138342244`, 0.3768338981077132, 0.9373717431894225], 
             102 -> 
             RGBColor[
              0.819297035403237, 0.14933104688991955`, 0.16611216893601113`], 
             299 -> RGBColor[
              0.21412870248835636`, 0.3423932212321097, 0.9355056848804599], 
             128 -> RGBColor[
              0.3262131529712761, 0.45697116997908427`, 0.9420069915417328], 
             12 -> RGBColor[
              0.218436984339963, 0.3469214986189947, 0.935751035158377], 222 -> 
             RGBColor[
              0.6049269005052089, 0.6901459353332633, 0.9620412080094716], 92 -> 
             RGBColor[
              0.28766384187052196`, 0.4196833151198899, 0.9396934022827843], 
             271 -> RGBColor[
              0.30678788301618565`, 0.43978389489822367`, 0.9407824881345462],
              361 -> RGBColor[
              0.35562652096447817`, 0.48244755097593534`, 0.9438811853410396],
              344 -> RGBColor[
              0.32062864936426844`, 0.45213415364000675`, 0.941651151910077], 
             132 -> RGBColor[
              0.7992223614262676, 0.8430778501519028, 0.9806226738955138], 80 -> 
             RGBColor[
              0.3344163982055418, 0.46407640869391137`, 0.9425296950742152], 
             324 -> RGBColor[
              0.2799576543907215, 0.4115836234781131, 0.9392545463060924], 
             244 -> RGBColor[
              0.2600361752617328, 0.3906448858188163, 0.9381200475408837], 
             150 -> RGBColor[
              0.2706007772119499, 0.40174895230294594`, 0.9387216859930206], 
             125 -> RGBColor[
              0.277985958766929, 0.4095112463647842, 0.9391422611571797], 258 -> 
             RGBColor[
              0.2529332615169164, 0.38317927312227185`, 0.9377155471109357], 
             133 -> RGBColor[
              0.29725822306554583`, 0.42976761807476255`, 0.9402397880982258],
              255 -> RGBColor[
              0.26047497796174324`, 0.3911060952782254, 0.938145036705499], 
             326 -> RGBColor[
              0.3393902356747875, 0.4683844967174319, 0.9428466235995638], 
             176 -> RGBColor[
              0.21582348781243682`, 0.34417454806331416`, 0.935602200397456], 
             230 -> RGBColor[
              0.9688572327835747, 0.9066102748888301, 0.333516659492644], 274 -> 
             RGBColor[
              0.2307279730478894, 0.35984010704471925`, 0.9364509887824051], 
             87 -> RGBColor[
              0.29013871681338543`, 0.4222845656009737, 0.9398343427495309], 
             130 -> RGBColor[
              0.4104055903111328, 0.5298944275679272, 0.9473716592005793], 35 -> 
             RGBColor[
              0.28104105066772134`, 0.4127223416565313, 0.9393162441213263], 
             379 -> RGBColor[
              0.22095736038557218`, 0.3495705736440009, 0.9358945668456122], 
             31 -> RGBColor[
              0.183217413291963, 0.30990349639776743`, 0.9337453326898797], 
             18 -> RGBColor[
              0.9452065658445834, 0.95865572703968, 0.9776351709954327], 24 -> 
             RGBColor[
              0.9021530244270525, 0.6485815613125467, 0.24006642394413927`], 
             151 -> RGBColor[
              0.3158355177641727, 0.44798258395780277`, 0.9413457378029186], 
             137 -> RGBColor[
              0.22155609394318862`, 0.3501998805749559, 0.9359286638359716], 
             330 -> RGBColor[
              0.22477195032544567`, 0.3535799495297792, 0.936111802099508], 
             296 -> RGBColor[
              0.30152154075751214`, 0.43424863527897317`, 0.94048257773377], 
             266 -> RGBColor[
              0.2549979314676595, 0.3853493721481386, 0.937833127010225], 302 -> 
             RGBColor[
              0.9872770340850194, 0.9687445898536212, 0.4050741092611545], 
             283 -> RGBColor[
              0.9089152991886196, 0.6765865439997854, 0.2455693155756892], 
             388 -> RGBColor[
              0.22336510960731928`, 0.352101270736175, 0.9360316846018449], 
             284 -> RGBColor[
              0.24399808998490613`, 0.37378784131953313`, 0.9372067023105894],
              318 -> RGBColor[
              0.2238174684207968, 0.35257672853034516`, 0.9360574457670676], 
             238 -> RGBColor[
              0.22922310747734106`, 0.35825839791608494`, 0.9363652889144115],
              72 -> RGBColor[
              0.22772650909910638`, 0.3566853781307425, 0.9362800598507899], 
             288 -> RGBColor[
              0.245025991273468, 0.37486823074651754`, 0.9372652397683294], 
             382 -> RGBColor[
              0.898780922280212, 0.63326963303821, 0.23725265925502825`], 389 -> 
             RGBColor[
              0.17908812663026416`, 0.30556335430442605`, 0.933510175923228], 
             172 -> RGBColor[
              0.301424661402258, 0.4341468089340951, 0.9404770605978084], 243 -> 
             RGBColor[
              0.2883719521470624, 0.4204275839173185, 0.939733728115478], 88 -> 
             RGBColor[
              0.9903137669558371, 0.9902625079584733, 0.8101894789167451], 
             273 -> RGBColor[
              0.2754373969927425, 0.40683254635196486`, 0.938997124334399], 
             202 -> 
             RGBColor[
              0.8563396258514921, 0.4340566292418462, 0.20158419538288244`], 
             393 -> RGBColor[
              0.22281999879048459`, 0.3515283247056597, 0.9360006413472455], 
             98 -> RGBColor[
              0.9775701021325132, 0.9360008290818089, 0.3673645116259542], 30 -> 
             RGBColor[
              0.17892703208317115`, 0.3053940337214471, 0.9335010018270892], 
             116 -> RGBColor[
              0.4162213411164948, 0.534931738607397, 0.9477422336992305], 373 -> 
             RGBColor[
              0.2503218011924054, 0.380434462745063, 0.9375668283087641], 240 -> 
             RGBColor[
              0.23920651037948798`, 0.3687515873505448, 0.9369338289405676], 
             317 -> RGBColor[
              0.9906270631619555, 0.9903920639910485, 0.8049973499967711], 
             391 -> RGBColor[
              0.8203907902431329, 0.1577381258757864, 0.16715954980591485`], 
             73 -> RGBColor[
              0.24311597663730303`, 0.3728606842619857, 0.9371564672604132], 
             303 -> RGBColor[
              0.28961174034798287`, 0.421730679923598, 0.9398043322194181], 
             29 -> RGBColor[
              0.2404292095299187, 0.3700367216812511, 0.9370034598483634], 
             360 -> RGBColor[
              0.3103917228488082, 0.4432674424152022, 0.9409988640046705], 
             320 -> RGBColor[
              0.7098940201909748, 0.7732938710583535, 0.9717192596619902], 75 -> 
             RGBColor[
              0.24417812249459925`, 0.373977066901941, 0.9372169548956822], 
             200 -> RGBColor[
              0.27065965459454444`, 0.40181083616509444`, 0.9387250389728581],
              301 -> RGBColor[
              0.2568179059531509, 0.3872622807254372, 0.9379367718647629], 
             156 -> RGBColor[
              0.18595953915049845`, 0.3127856445359093, 0.9339014927009116], 
             25 -> RGBColor[
              0.8487111149297029, 0.3754205514621725, 0.19427912470900624`], 
             38 -> RGBColor[
              0.9657912116144293, 0.896267865549297, 0.32160574622002847`], 
             365 -> RGBColor[
              0.25624071750281635`, 0.38665561906827417`, 0.93790390183639], 
             380 -> RGBColor[
              0.26549066491796636`, 0.3963779002821365, 0.9384306726576119], 
             370 -> RGBColor[
              0.8312166238387177, 0.8682535893475418, 0.9837633776892186], 3 -> 
             RGBColor[
              0.370079657849583, 0.49496613171003123`, 0.9448021264429514], 
             57 -> 
             RGBColor[
              0.2732074233744939, 0.404488702690692, 0.9388701306357901], 227 -> 
             RGBColor[
              0.23492201148043795`, 0.36424830735472313`, 0.9366898330666149],
              39 -> RGBColor[
              0.27309206457306523`, 0.40436745327622, 0.9388635611227067], 
             109 -> RGBColor[
              0.9940964498066649, 0.9918267445278057, 0.7475006348091123], 
             256 -> RGBColor[
              0.22530836548640581`, 0.35414375587463387`, 0.9361423501493695],
              339 -> RGBColor[
              0.36576050208801136`, 0.49122509607643855`, 0.9445269136571035],
              287 -> RGBColor[
              0.260213393629744, 0.3908311535598896, 0.9381301398647709], 239 -> 
             RGBColor[
              0.32451491921663345`, 0.4555002452565231, 0.9418987815885761], 
             285 -> RGBColor[
              0.23871510677441427`, 0.3682350910048242, 0.9369058442322252], 
             345 -> RGBColor[
              0.20194739446585683`, 0.3295898941609259, 0.9348119774092088], 
             366 -> RGBColor[
              0.9012804456996433, 0.6446193851073215, 0.2393383228651273], 
             216 -> RGBColor[
              0.6591015742674116, 0.7336144262659793, 0.9666567433347234], 21 -> 
             RGBColor[
              0.31291714185714126`, 0.44545483342897024`, 0.9411597814707411],
              355 -> RGBColor[
              0.23092116646773903`, 0.3600431655781515, 0.9364619908618614], 
             175 -> RGBColor[
              0.17893214148115075`, 0.3053994040226782, 0.9335012927997455], 
             7 -> RGBColor[
              0.38940499419392427`, 0.5117047667318526, 0.9460335197860889], 
             13 -> RGBColor[
              0.9637801291888717, 0.9725078601704316, 0.9461949730147088], 
             294 -> RGBColor[
              0.21275955169572475`, 0.34095415693987974`, 0.9354277137682966],
              193 -> RGBColor[
              0.8223396115770147, 0.8611753007301386, 0.9829166803350949], 60 -> 
             RGBColor[
              0.35752834255750565`, 0.4840948132514831, 0.9440023677312325], 
             65 -> RGBColor[
              0.5153321861178936, 0.6174089099977538, 0.9549879838966494], 69 -> 
             RGBColor[
              0.48821862164434726`, 0.5953968969059689, 0.9528535047810326], 
             217 -> RGBColor[
              0.8228256695060855, 0.17645367486173685`, 0.16949119293792111`],
              214 -> RGBColor[
              0.9837730937067766, 0.9874185803724101, 0.9123520990861677], 
             170 -> 
             RGBColor[
              0.44496963537099143`, 0.5598320661593594, 0.9495740495880086], 
             359 -> RGBColor[
              0.2455681205459235, 0.37543804298484945`, 0.9372961132283874], 
             74 -> RGBColor[
              0.8246734764068878, 0.8630362611944062, 0.983139286446034], 246 -> 
             RGBColor[
              0.4438028563584466, 0.5588214608227114, 0.9494997034610714], 
             264 -> RGBColor[
              0.19003101446562676`, 0.31706502323855396`, 0.9341333571969002],
              278 -> RGBColor[
              0.2524156236360728, 0.382635202889368, 0.9376860683993983], 45 -> 
             RGBColor[
              0.2954990939280613, 0.427918661816037, 0.9401396082962444], 306 -> 
             RGBColor[
              0.9703761157708419, 0.9117338238555674, 0.33941723308119276`], 
             237 -> RGBColor[
              0.5784190314529432, 0.6686256530707418, 0.9599544114561535], 
             228 -> RGBColor[
              0.36785717736282086`, 0.49304113081751505`, 0.9446605119515972],
              180 -> RGBColor[
              0.36627002209779275`, 0.4916664166996908, 0.9445593798215759], 
             383 -> RGBColor[
              0.28023632613366145`, 0.41187652514875206`, 0.939270416249595], 
             53 -> RGBColor[
              0.28924396052189333`, 0.4213441200077901, 0.9397833877024038], 
             304 -> RGBColor[
              0.21909843402136348`, 0.34761672417247863`, 0.9357887037392056],
              48 -> RGBColor[
              0.4254428949511675, 0.5429189850502182, 0.948329822955276], 5 -> 
             RGBColor[
              0.8414430264446411, 0.8764078451972013, 0.9847387810989889], 
             101 -> RGBColor[
              0.2608418322510304, 0.39149168239617155`, 0.9381659285145616], 
             333 -> RGBColor[
              0.19556045555100107`, 0.3228768164060961, 0.9344482506866372], 
             267 -> RGBColor[
              0.5711989452526345, 0.6627640618321545, 0.9593860198224179], 
             120 -> RGBColor[
              0.5663783145126094, 0.6588504566304622, 0.9590065221120109], 
             147 -> RGBColor[
              0.28473783311028583`, 0.41660789439321116`, 0.9395267704125309],
              89 -> RGBColor[
              0.21858282554203126`, 0.3470747869692347, 0.9357593405990821], 
             43 -> RGBColor[
              0.2274352478585693, 0.35637924409990884`, 0.9362634729540237], 
             199 -> RGBColor[
              0.22580276459471169`, 0.35466340068417734`, 0.9361705054471896],
              268 -> RGBColor[0.817319, 0.134127, 0.164218], 169 -> 
             RGBColor[
              0.22069846856058375`, 0.34929846192124825`, 0.9358798233391753],
              20 -> RGBColor[
              0.4076589804310767, 0.5275154521384491, 0.9471966476477539], 4 -> 
             RGBColor[
              0.23219649750384544`, 0.36138361935775737`, 0.9365346190776845],
              167 -> RGBColor[
              0.2835494674254077, 0.415358846711668, 0.9394590947448065], 142 -> 
             RGBColor[
              0.8215839734950429, 0.16690945520620182`, 0.16830214343545163`],
              16 -> RGBColor[
              0.2418605106508593, 0.3715411099090923, 0.9370849703297808], 
             281 -> RGBColor[
              0.6319940482543123, 0.7121202652370958, 0.9641720330305101], 
             289 -> RGBColor[
              0.8977533081905217, 0.6286034774622947, 0.23639519286946437`], 
             398 -> RGBColor[
              0.9394254025446074, 0.954344144916344, 0.9874211724934188], 178 -> 
             RGBColor[
              0.24398844376792686`, 0.3737777025338824, 0.9372061529728027], 
             58 -> RGBColor[
              0.2988109928106687, 0.43139967752817476`, 0.9403282160380936], 
             186 -> RGBColor[
              0.24846767200989045`, 0.3784856554156597, 0.9374612383947583], 
             122 -> RGBColor[
              0.44608758599784554`, 0.5608003788025082, 0.9496452844133868], 
             249 -> RGBColor[
              0.2695692814994847, 0.4006647849085395, 0.938662943838157], 113 -> 
             RGBColor[
              0.7965156452550962, 0.8409633429071789, 0.9803528937232722], 52 -> 
             RGBColor[
              0.38664548537965426`, 0.5093146188938776, 0.9458576863245813], 
             187 -> RGBColor[
              0.8439338400416576, 0.8783939523481282, 0.9849763571234479], 
             259 -> RGBColor[
              0.2110206902246306, 0.3391265032835748, 0.9353286881799328], 42 -> 
             RGBColor[
              0.9322258626950144, 0.9487956145888052, 0.9933977290633442], 
             134 -> RGBColor[
              0.2343268669145523, 0.36362277268163234`, 0.9366559404640252], 
             313 -> RGBColor[
              0.2828083531870263, 0.41457988865777246`, 0.939416889385311], 
             248 -> RGBColor[
              0.21620788903044316`, 0.3445785781158837, 0.9356240914781508], 
             174 -> RGBColor[
              0.7286053839996127, 0.7879113306772935, 0.9735842335387989], 
             215 -> RGBColor[
              0.8192881970279116, 0.1492631112641677, 0.166103705297818], 399 -> 
             RGBColor[
              0.2348790166106703, 0.36420311702056507`, 0.9366873845723869], 
             83 -> RGBColor[
              0.35288166901045503`, 0.480070098173631, 0.9437062858017065], 
             95 -> RGBColor[
              0.2817785304161579, 0.4134974796310549, 0.9393582425019963], 
             166 -> RGBColor[
              0.8247691039330448, 0.19139176348574266`, 0.17135222793997262`],
              384 -> RGBColor[
              0.7484278388783107, 0.8033967830847693, 0.9755599505897345], 
             233 -> RGBColor[
              0.8174582326741875, 0.1351972033459516, 0.16435132936604271`], 
             295 -> RGBColor[
              0.24238734999627973`, 0.3720948514646729, 0.9371149730511135], 
             141 -> RGBColor[
              0.3600639473667127, 0.48629102669401497`, 0.9441639342275279], 
             319 -> RGBColor[
              0.24158367299712782`, 0.37125013598249945`, 0.9370692048349454],
              205 -> RGBColor[
              0.9952685123171101, 0.9923114224965074, 0.7280765258104895], 
             224 -> RGBColor[
              0.9756615083220127, 0.9295626939998534, 0.3599499850798584], 
             231 -> RGBColor[
              0.30868412390727973`, 0.44177696430338015`, 0.9408904762480571],
              332 -> RGBColor[
              0.5272216074067284, 0.6270612778123552, 0.9559239626928917], 68 -> 
             RGBColor[
              0.2767246225454214, 0.4081855020226443, 0.9390704299253445], 10 -> 
             RGBColor[
              0.3619258765766598, 0.48790373619238797`, 0.9442825747103464], 
             250 -> RGBColor[
              0.9882272169582415, 0.9893996659125786, 0.8447690121952027], 
             282 -> RGBColor[
              0.6468617732853108, 0.7240526007128293, 0.965436794360271], 374 -> 
             RGBColor[
              0.2761037265699157, 0.40753290098530925`, 0.9390350708180728], 
             232 -> RGBColor[
              0.5255566438526651, 0.6257095853934133, 0.9557928906629534], 
             253 -> RGBColor[
              0.34171577858230273`, 0.47039876509873646`, 0.9429948051372339],
              55 -> RGBColor[
              0.4035326533159193, 0.5239414349865308, 0.9469337217327439], 
             325 -> RGBColor[
              0.21156771774634342`, 0.33970146389244305`, 0.9353598405880397],
              91 -> RGBColor[
              0.26262121251507564`, 0.39336192387290797`, 0.9382672615882417],
              105 -> 
             RGBColor[
              0.417344109662346, 0.5359042242898253, 0.9478137755181469], 36 -> 
             RGBColor[
              0.5196772960404508, 0.620936465977857, 0.9553300468664151], 123 -> 
             RGBColor[
              0.9742961343763916, 0.9803506796209057, 0.9283941192456544], 94 -> 
             RGBColor[
              0.26012396818175015`, 0.3907371617441472, 0.9381250472178008], 
             312 -> RGBColor[
              0.46295717480753656`, 0.5748885163486347, 0.9508648311503101], 
             96 -> RGBColor[
              0.2869114883454893, 0.4188925438631119, 0.939650556862541], 2 -> 
             RGBColor[
              0.8184511944421836, 0.14282954261339104`, 0.16530219067646573`],
              262 -> RGBColor[
              0.9386428604207964, 0.9537605262817009, 0.9887458121893573], 
             272 -> RGBColor[
              0.6470169280819229, 0.7241738088191627, 0.9654522587403933], 97 -> 
             RGBColor[
              0.44228444757308333`, 0.5575062914502744, 0.9494029517959442], 
             372 -> RGBColor[
              0.2514775053864574, 0.3816491811288898, 0.9376326439529042], 
             356 -> RGBColor[
              0.5183784049780293, 0.6198819676990077, 0.9552277934039866], 
             346 -> RGBColor[
              0.3450320119322843, 0.4732711197477559, 0.9432061125938647], 
             341 -> RGBColor[
              0.2215837127017966, 0.35022890964138337`, 0.935930236683416], 
             209 -> RGBColor[
              0.2520329891677718, 0.3822330298027571, 0.9376642779324855], 
             378 -> RGBColor[
              0.20852643568424656`, 0.3365048836167593, 0.9351866440737768], 
             66 -> RGBColor[
              0.9727828870163496, 0.9198524284034268, 0.3487670848893771], 
             139 -> RGBColor[
              0.2111706728502173, 0.3392841445325141, 0.9353372294685806], 56 -> 
             RGBColor[
              0.45093503134871465`, 0.5649989923257436, 0.9499541593447165], 
             335 -> RGBColor[
              0.28051817934621337`, 0.41217277074566994`, 0.9392864673730853],
              314 -> RGBColor[
              0.9258119809847409, 0.9436813594132142, 0.9927859673000785], 
             144 -> RGBColor[
              0.8784381059512442, 0.540897655273832, 0.22027811466207986`], 
             298 -> RGBColor[
              0.8234301328695646, 0.862044852807406, 0.9830206952294982], 204 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 207 -> 
             RGBColor[
              0.9398558182628138, 0.7992553918121872, 0.27046478349011155`], 
             334 -> 
             RGBColor[
              0.26139903658851843`, 0.39207733948366696`, 0.9381976604772716],
              149 -> RGBColor[
              0.22021863489519794`, 0.34879412631571627`, 0.9358524975217819],
              219 -> RGBColor[
              0.4471878440862639, 0.5617533670581167, 0.9497153918858607], 
             400 -> RGBColor[
              0.38961090759033284`, 0.5118831185663134, 0.9460466404056259], 
             9 -> RGBColor[
              0.8256674379376745, 0.1982967522977973, 0.17221247359732916`], 
             11 -> RGBColor[
              0.9234626618564741, 0.7342619893565898, 0.25727446504873397`], 
             44 -> RGBColor[
              0.29795654320818293`, 0.4305015968207284, 0.940279556397277], 
             153 -> RGBColor[
              0.3174307607246093, 0.4493643032308905, 0.9414473852737397], 32 -> 
             RGBColor[
              0.21628540957162948`, 0.3446600571197567, 0.9356285061582901], 
             162 -> RGBColor[
              0.246083996032968, 0.37598026083012825`, 0.9373254915742051], 
             90 -> RGBColor[
              0.7058058015575851, 0.7701001235903371, 0.9713117842351892], 
             331 -> RGBColor[
              0.45209247002133757`, 0.5660015075294104, 0.9500279103134532], 
             8 -> RGBColor[
              0.3103199544645186, 0.44320528024791445`, 0.9409942909866859], 
             364 -> RGBColor[
              0.34952976604112324`, 0.4771668482931376, 0.9434927055084721], 
             342 -> RGBColor[
              0.6033581995623302, 0.6888723932386622, 0.9619177141249072], 
             163 -> RGBColor[
              0.2449732495734328, 0.3748127958757636, 0.9372622362065367], 49 -> 
             RGBColor[
              0.2557363986193865, 0.3861255479461254, 0.9378751816220516], 
             338 -> RGBColor[
              0.9942883740099587, 0.9901917344782997, 0.6197029429328111], 76 -> 
             RGBColor[
              0.8469444359628041, 0.36184108275892934`, 0.19258735093512552`],
              369 -> RGBColor[
              0.25745394897088236`, 0.38793080226452953`, 0.9379729935736814],
              82 -> RGBColor[
              0.37921715493462604`, 0.5028805724211383, 0.9453843596772389], 
             67 -> RGBColor[
              0.2129458677257866, 0.3411499869005934, 0.9354383241905787], 
             211 -> RGBColor[
              0.2626771974737526, 0.39342076761412886`, 
               0.9382704498488161]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9l3k0VX/Yxa95Hq55dufJNVwqktwdKpWiSIU0EZFIxkiFhGRKk6SkQSmp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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 7}], {
             RGBColor[
             0.37469401379728373`, 0.4989628549076562, 0.945096149123624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 35}], {
             RGBColor[
             0.32051204203418227`, 0.44947164236999554`, 0.9417375112912428]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 41}], {
             RGBColor[
             0.3504016747423545, 0.4779220517867386, 0.943548262759916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 57}], {
             RGBColor[
             0.31659522838756854`, 0.44535482288707584`, 0.9415144545484747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 92}], {
             RGBColor[
             0.3238234376355826, 0.4529521291016748, 0.9419260903719718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 96}], {
             RGBColor[
             0.32344726087306624`, 0.45255674347328584`, 0.9419046676618501]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 114}], {
             RGBColor[
             0.3444304570913155, 0.4727500831795342, 0.9431677820513322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 153}], {
             RGBColor[
             0.33870689706262624`, 0.4677926231571751, 0.9428030818674495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 154}], {
             RGBColor[
             0.39507053133992803`, 0.5166119702495444, 0.9463945228031945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 161}], {
             RGBColor[
             0.3957098398241182, 0.5171657071259712, 0.9464352589744887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 188}], {
             RGBColor[
             0.3135344759290187, 0.4421377779902256, 0.9413401492239378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 203}], {
             RGBColor[
             0.32569030455946724`, 0.45491432460487713`, 0.9420324056815049]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 222}], {
             RGBColor[
             0.48245496695292606`, 0.5881834392083616, 0.9530999932353155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 312}], {
             RGBColor[
             0.4114701041040899, 0.5305547297160472, 0.9475118048057347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 327}], {
             RGBColor[
             0.3392875835527789, 0.4682955846087937, 0.9428400826971212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 337}], {
             RGBColor[
             0.3223631828098259, 0.4514173086943011, 0.9418429310198984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 356}], {
             RGBColor[
             0.43918071918933627`, 0.5530514553912338, 0.949693285932573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 361}], {
             RGBColor[
             0.35780477718256065`, 0.4843342470296975, 0.9440199819010995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[
             0.8698950919669056, 0.4018371712100696, 0.22645715541410283`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 98}], {
             RGBColor[
             0.8714908303389601, 0.407219971436197, 0.23265629765962853`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 106}], {
             RGBColor[
             0.8617990685724151, 0.41558906148983843`, 0.4342244670461309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 107}], {
             RGBColor[
             0.8253733561939098, 0.19603631114778033`, 0.17193086058738233`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 197}], {
             RGBColor[
             0.8752179409256514, 0.4250918427711577, 0.3888952541053632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 215}], {
             RGBColor[
             0.818730195304093, 0.14497406549698325`, 0.16556936221691648`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 283}], {
             RGBColor[
             0.8486058960243289, 0.3207485430755225, 0.1920578989762069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 352}], {
             RGBColor[
             0.8770188414831279, 0.42518789908164617`, 0.3118987659924733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 52}], {
             RGBColor[
             0.3783625716146186, 0.5021403753019544, 0.9453299063837663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 86}], {
             RGBColor[
             0.33530800642617503`, 0.4640896371481913, 0.9426142996527203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 117}], {
             RGBColor[
             0.35979838664313185`, 0.4860610113427193, 0.9441470129330474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 174}], {
             RGBColor[
             0.5493425209245979, 0.6414387311936623, 0.9591931799908751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 232}], {
             RGBColor[
             0.4478181508511241, 0.5603378585517222, 0.9502975085529524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 309}], {
             RGBColor[
             0.32043505349243634`, 0.4484572206151509, 0.9417673069857059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 371}], {
             RGBColor[
             0.3210626317693298, 0.4491168451749269, 0.9418030466401561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 386}], {
             RGBColor[
             0.35472139925516205`, 0.48166358004406556`, 0.9438235117860897]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 16}], {
             RGBColor[
             0.23702850407735238`, 0.36646236463342485`, 0.9368097947037326]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 73}], {
             RGBColor[
             0.23765623707057423`, 0.3671221518098715, 0.9368455431690489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 115}], {
             RGBColor[
             0.23540129852856206`, 0.36475206843085556`, 0.936717127754964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 188}], {
             RGBColor[
             0.24964120798061978`, 0.37971911612737436`, 0.9375280695322004]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 195}], {
             RGBColor[
             0.2389456018045329, 0.3684773558957079, 0.9369189705832036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 206}], {
             RGBColor[
             0.23187928370438585`, 0.3610502075420088, 0.9365165542210812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 208}], {
             RGBColor[
             0.23264160776787357`, 0.36185145846687167`, 0.9365599674487393]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 258}], {
             RGBColor[
             0.24256487951038092`, 0.3722814462400146, 0.9371250830943101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 278}], {
             RGBColor[
             0.24230606056995913`, 0.37200941112356267`, 0.9371103437385414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 284}], {
             RGBColor[
             0.23809729374437577`, 0.3675857303386453, 0.936870660694137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 369}], {
             RGBColor[
             0.2448252232373639, 0.37465721081114345`, 0.937253806325683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 392}], {
             RGBColor[
             0.24007285485442642`, 0.3696621703231174, 0.9369831659767736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 99}], {
             RGBColor[
             0.9097853137766493, 0.92980801321679, 0.9533236132867424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 174}], {
             RGBColor[
             0.7850242052221269, 0.8321595879372474, 0.979161507318894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 193}], {
             RGBColor[
             0.8318913190108279, 0.8687915729636699, 0.983827730717042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 223}], {
             RGBColor[
             0.6477551093793219, 0.7220395366342189, 0.9674518801311646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 235}], {
             RGBColor[
             0.7907683520113988, 0.8366469590661592, 0.9797340301887447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 260}], {
             RGBColor[
             0.8251985302055844, 0.863544075950503, 0.9831657085828327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 267}], {
             RGBColor[
             0.7063209858486378, 0.7695859535146778, 0.9720624004607035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 272}], {
             RGBColor[
             0.744229977263282, 0.800290827008182, 0.9750955199196911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 275}], {
             RGBColor[
             0.916771833602923, 0.9337046356973782, 0.882657568389807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 291}], {
             RGBColor[
             0.7689673032381015, 0.8196158140703518, 0.9775611053894065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 321}], {
             RGBColor[
             0.8296147450427847, 0.8669940565457998, 0.9836058756059307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 338}], {
             RGBColor[
             0.9178657002272999, 0.9332997898377504, 0.8022208620159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 384}], {
             RGBColor[
             0.7949354326614759, 0.8399023141409853, 0.9801493658443617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 398}], {
             RGBColor[
             0.8904342144946242, 0.9153759950567726, 0.9860799767962038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 13}], {
             RGBColor[
             0.978563836078469, 0.9803436260913665, 0.7317471315868381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 18}], {
             RGBColor[
             0.9692770544063248, 0.9734175595259907, 0.7474672305772001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 74}], {
             RGBColor[
             0.909010509687477, 0.9256078266033538, 0.7502192883025007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 102}], {
             RGBColor[
             0.8773138712581801, 0.4289471619307136, 0.2831745426769966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 132}], {
             RGBColor[
             0.896284952197167, 0.9156286210821021, 0.7489609820272407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 160}], {
             RGBColor[
             0.8841009021841464, 0.48111525572360647`, 0.289673811156557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 166}], {
             RGBColor[
             0.8809619169447186, 0.4569876396612623, 0.28666791534630426`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 185}], {
             RGBColor[
             0.8802428367957571, 0.45146047453341354`, 0.28597932338357385`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 198}], {
             RGBColor[
             0.9099185860419527, 0.9263319020393368, 0.75030590143584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 213}], {
             RGBColor[
             0.9521578283629528, 0.8364523308595698, 0.38226017426140096`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 216}], {
             RGBColor[
             0.8262245586177389, 0.8608969091391403, 0.7419780167468455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 224}], {
             RGBColor[
             0.9845045256450395, 0.9588710430060774, 0.43862463761941295`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 247}], {
             RGBColor[
             0.9501775412917424, 0.8286011525137683, 0.3806667888005933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 289}], {
             RGBColor[
             0.9455504255792939, 0.808391434737298, 0.3768472415142159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 302}], {
             RGBColor[
             0.9903122885265428, 0.9784619909329613, 0.461186699710061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 323}], {
             RGBColor[
             0.9117788938600264, 0.9278152609967583, 0.7504833392562442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 340}], {
             RGBColor[
             0.9935628356137232, 0.988639881211936, 0.5407325660065214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 40}], {
             RGBColor[
             0.36435856265805855`, 0.4900108066057379, 0.9444375833163132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 41}], {
             RGBColor[
             0.36511265513899505`, 0.490663963610935, 0.9444856334223808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 80}], {
             RGBColor[
             0.36191069619973304`, 0.48789058771288196`, 0.9442816074301521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 96}], {
             RGBColor[
             0.3381582412697068, 0.46529865529748227`, 0.9428420383243149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 114}], {
             RGBColor[
             0.359141437487956, 0.48549199500373064`, 0.9441051527137969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 153}], {
             RGBColor[
             0.3534178774592668, 0.48053453498137155`, 0.9437404525299142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 154}], {
             RGBColor[
             0.40978151173656857`, 0.5293538820737408, 0.9473318934656592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 192}], {
             RGBColor[
             0.36694736915401993`, 0.4922531006753419, 0.9446025397770442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 203}], {
             RGBColor[
             0.3404012849561078, 0.4676562364290735, 0.9429697763439697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 222}], {
             RGBColor[
             0.4971659473495666, 0.600925351032558, 0.9540373638977802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 228}], {
             RGBColor[
             0.37863108577837257`, 0.5023729487746839, 0.9453470158688431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 312}], {
             RGBColor[
             0.42618108450073044`, 0.5432966415402436, 0.9484491754681994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 332}], {
             RGBColor[
             0.45831330080032634`, 0.5693830222721039, 0.9509787412394903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 356}], {
             RGBColor[
             0.4538916995859768, 0.5657933672154302, 0.9506306565950378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 361}], {
             RGBColor[
             0.3725157575792012, 0.497076158853894, 0.9449573525635642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 385}], {
             RGBColor[
             0.4824130197414953, 0.5889482597885108, 0.9528759593947184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 17}], {
             RGBColor[
             0.42291827954092154`, 0.5385004052405986, 0.9487856331227857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.3116185481608299, 0.44433005683844234`, 0.9410770362287135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 36}], {
             RGBColor[
             0.41499862525248465`, 0.5320708731128857, 0.9481621689265505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 60}], {
             RGBColor[
             0.33392414851101215`, 0.4636500467496988, 0.9424983293589592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 64}], {
             RGBColor[
             0.3546401133620532, 0.4815931742890025, 0.9438183323208591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.34476855469957235`, 0.4730429263345264, 0.9431893253319623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 157}], {
             RGBColor[
             0.38978189814954545`, 0.5115987980501094, 0.9461770157970921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 171}], {
             RGBColor[
             0.2917662705538139, 0.42384970493064567`, 0.9399323578314926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 182}], {
             RGBColor[
             0.29920713316336395`, 0.4316705233112208, 0.9403561039493367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 210}], {
             RGBColor[
             0.30512183219392025`, 0.43788724700591375`, 0.9406929373091137]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 253}], {
             RGBColor[
             0.3260178665234107, 0.4568020226733255, 0.9419945480619598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 61}], {
             RGBColor[
             0.8815602598479266, 0.4615897967705782, 0.2871819365682987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 131}], {
             RGBColor[
             0.8579336851220932, 0.37563492447695607`, 0.2002992063805429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 142}], {
             RGBColor[
             0.824306283123464, 0.18783431993393215`, 0.17090903021003664`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 202}], {
             RGBColor[
             0.8358915005756137, 0.2768833779458136, 0.18200304752584692`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 214}], {
             RGBColor[
             0.8783693231940418, 0.4613373616560016, 0.41892568209360864`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 215}], {
             RGBColor[
             0.8235410243010869, 0.18195220528658743`, 0.17017621749749212`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 217}], {
             RGBColor[
             0.8247201817938115, 0.19101572648577717`, 0.17130538004419316`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 269}], {
             RGBColor[
             0.8814646016218102, 0.4613851934974453, 0.276770128989661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 279}], {
             RGBColor[
             0.8656615052757575, 0.40627315624282495`, 0.20651719187143383`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 300}], {
             RGBColor[
             0.8471105512692876, 0.32999212991331434`, 0.19144930036229538`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 306}], {
             RGBColor[
             0.8739036638820636, 0.43610910948372067`, 0.2279473934252837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 363}], {
             RGBColor[
             0.8379491231855124, 0.28839222469078246`, 0.18380478020204166`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 39}], {
             RGBColor[
             0.3175089705748625, 0.446135594734304, 0.9415730679165266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 177}], {
             RGBColor[
             0.34191718866131093`, 0.47057321638600846`, 0.9430076388093683]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.3312363099818102, 0.46056389881459425`, 0.9423548195879734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 200}], {
             RGBColor[
             0.31629276558560215`, 0.4448572861787412, 0.9415038068416022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 216}], {
             RGBColor[
             0.5105137254220357, 0.6107590812291837, 0.9554696590225349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 219}], {
             RGBColor[
             0.4045568603314619, 0.5248285516252523, 0.9469989832981036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 241}], {
             RGBColor[
             0.32644391245681637`, 0.4555267851602728, 0.9420818996386419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 296}], {
             RGBColor[
             0.331723708667086, 0.46107618573568054`, 0.9423825762220581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 311}], {
             RGBColor[
             0.4406499577202704, 0.5542970021663628, 0.9497943740304772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 339}], {
             RGBColor[
             0.3638431893323356, 0.48956441613441326`, 0.9444047441837249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 360}], {
             RGBColor[
             0.336158799712734, 0.4655855893037951, 0.9426407193575084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 374}], {
             RGBColor[
             0.31901480157328777`, 0.4477183185888486, 0.9416588227642095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 14}], {
             RGBColor[
             0.9589098698169762, 0.8623003371232989, 0.4422276945427869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 25}], {
             RGBColor[
             0.8736282972386266, 0.495034364093645, 0.2152775714889155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 38}], {
             RGBColor[
             0.9446269367354516, 0.8152649274529434, 0.2894401056343812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 78}], {
             RGBColor[
             0.8690501870084697, 0.4598450027239643, 0.2108935679622813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 102}], {
             RGBColor[
             0.8540189108876494, 0.344308027712143, 0.19649960097358543`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 144}], {
             RGBColor[
             0.9009503839038591, 0.6375798223152109, 0.23877628985540691`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 205}], {
             RGBColor[
             0.9593655870867921, 0.8632867059265485, 0.49267549542961175`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 207}], {
             RGBColor[
             0.931659240059644, 0.7667586905843885, 0.26386962426942273`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 213}], {
             RGBColor[
             0.9172153878071567, 0.709493629531714, 0.2522477617062842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 221}], {
             RGBColor[
             0.9226607888866434, 0.8373956409938654, 0.6248416927368453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 230}], {
             RGBColor[
             0.9461599473200244, 0.8204361321227099, 0.29539556227068897`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 250}], {
             RGBColor[
             0.9558449394073578, 0.8618308276345842, 0.5510217386219683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 289}], {
             RGBColor[
             0.9106079850234978, 0.6814327334094423, 0.24683482895909917`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 358}], {
             RGBColor[
             0.9460196672175634, 0.8199629343977746, 0.2948506005623025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 391}], {
             RGBColor[
             0.8547480807809132, 0.34991274703605424`, 0.19719785488685457`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 118}], {
             RGBColor[
             0.21224930323971947`, 0.34041785346099757`, 0.9353986558735721]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 126}], {
             RGBColor[
             0.2152393660615204, 0.3435605990676429, 0.935568935527872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 149}], {
             RGBColor[
             0.21932780961758047`, 0.3478578124673555, 0.9358017663400795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 199}], {
             RGBColor[
             0.22211987446733733`, 0.350792449651586, 0.9359607703027832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 212}], {
             RGBColor[
             0.2146670795751315, 0.34295908968538924`, 0.9355363446590942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 238}], {
             RGBColor[
             0.22383004590865202`, 0.3525899482675398, 0.9360581620363942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 259}], {
             RGBColor[
             0.2147288372822968, 0.3430240009512847, 0.9355398616691548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 274}], {
             RGBColor[
             0.2245824786939262, 0.35338080283185697`, 0.936101011970391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 299}], {
             RGBColor[
             0.21628284341415968`, 0.3446573599255522, 0.9356283600194184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 318}], {
             RGBColor[
             0.2211272263803799, 0.3497491135746699, 0.9359042404627222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 336}], {
             RGBColor[
             0.21472177259901426`, 0.343016575521228, 0.9355394593458932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 367}], {
             RGBColor[
             0.21887583976336028`, 0.3473827634940262, 0.9357760273255111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 18}], {
             RGBColor[
             0.9544933475167275, 0.9655817936050558, 0.9619150720050708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 69}], {
             RGBColor[
             0.7259993754166094, 0.7839523785382002, 0.9495242388978706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 74}], {
             RGBColor[
             0.8942268027978797, 0.9177720606824189, 0.9646671297303714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 88}], {
             RGBColor[
             0.9770469480723544, 0.9813851840644524, 0.8781922259657269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 132}], {
             RGBColor[
             0.8815012453075697, 0.9077928551611671, 0.9634088234551113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[
             0.8178525622986523, 0.8580700202466935, 0.9570649175635426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 191}], {
             RGBColor[
             0.8213167457883995, 0.8607762667176537, 0.9574101949991654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 198}], {
             RGBColor[
             0.8951348791523555, 0.9184961361184019, 0.9647537428637106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 216}], {
             RGBColor[
             0.8114408517281416, 0.8530611432182054, 0.956425858174716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 224}], {
             RGBColor[
             0.9697208187554422, 0.9510352770851425, 0.6530724790472836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 302}], {
             RGBColor[
             0.9755285816369456, 0.9706262250120263, 0.6756345411379316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 323}], {
             RGBColor[
             0.8969951869704291, 0.9199794950758233, 0.9649311806841149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 340}], {
             RGBColor[
             0.9787791287241259, 0.9808041152910011, 0.7551804074343922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 357}], {
             RGBColor[
             0.8197351159980406, 0.8595406855045937, 0.9572525529228332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 38}], {
             RGBColor[
             0.9800741446959539, 0.9433032752196526, 0.4743933351284341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 102}], {
             RGBColor[
             0.8776503828613175, 0.4296669262232824, 0.3198017539696207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 205}], {
             RGBColor[
             0.9948127950472943, 0.9913250536932577, 0.6776287249236647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 207}], {
             RGBColor[
             0.9671064480201461, 0.8947970383510977, 0.44882285376347564`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.9526625957676589, 0.8375319772984231, 0.4372009912003371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 224}], {
             RGBColor[
             0.9850092930497456, 0.9599506894449308, 0.4935654545583491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 230}], {
             RGBColor[
             0.9816071552805266, 0.9484744798894191, 0.4803487917647419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 247}], {
             RGBColor[
             0.9506823086964485, 0.8296807989526216, 0.43560760573952945`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 250}], {
             RGBColor[
             0.99129214736786, 0.9898691754012934, 0.7359749681160213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 289}], {
             RGBColor[
             0.9460551929840001, 0.8094710811761514, 0.43178805845315205`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 340}], {
             RGBColor[
             0.9940676030184292, 0.9897195276507893, 0.5956733829454577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 391}], {
             RGBColor[
             0.8783795527545815, 0.43527164554719366`, 0.32050000788288985`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 45}], {
             RGBColor[
             0.29968000514429743`, 0.4323130645893829, 0.9403777050049051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 100}], {
             RGBColor[
             0.34023750094859895`, 0.4686666959527124, 0.9429171480552854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 105}], {
             RGBColor[
             0.36060251301143975`, 0.486305845826277, 0.9442147886158565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.3163910437219365, 0.4480120932607672, 0.9413976728873965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 155}], {
             RGBColor[
             0.30420326810120896`, 0.4370673007485326, 0.9406352981387334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 170}], {
             RGBColor[
             0.3744152758657625, 0.49826976676104406`, 0.9450949256507872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 180}], {
             RGBColor[
             0.33506546922916314`, 0.4641869420312098, 0.9425875907675709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 183}], {
             RGBColor[
             0.281397272925088, 0.41309675383481925`, 0.9393365304518997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 239}], {
             RGBColor[
             0.3141879177885835, 0.4461038563096259, 0.9412572916510711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 271}], {
             RGBColor[
             0.3053243996883596, 0.43824568113047624`, 0.940699144924056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 273}], {
             RGBColor[
             0.28964915667663804`, 0.4217700068573468, 0.9398064630239824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 326}], {
             RGBColor[
             0.3216255760176605, 0.45254598204008034`, 0.9417312126565649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 335}], {
             RGBColor[
             0.2921895478533735, 0.4244401190541993, 0.9399511345433256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 394}], {
             RGBColor[
             0.33136443385417313`, 0.4609812912088401, 0.9423517640661736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 73}], {
             RGBColor[
             0.24248824364408117`, 0.372200897085539, 0.937120718795097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 85}], {
             RGBColor[
             0.2415839884274967, 0.3712504675198166, 0.9370692227982382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 96}], {
             RGBColor[
             0.2643859994981743, 0.3952168268861021, 0.9383677635961609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 110}], {
             RGBColor[
             0.2487192272457111, 0.3787500559180304, 0.9374755640932957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 115}], {
             RGBColor[
             0.240233305102069, 0.36983081370652304`, 0.936992303381012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 184}], {
             RGBColor[
             0.22981171473055614`, 0.35887706145906934`, 0.9363988092267157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 188}], {
             RGBColor[
             0.25447321455412675`, 0.38479786140304184`, 0.9378032451582485]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 203}], {
             RGBColor[
             0.2666290431845753, 0.3975744080176934, 0.9384955016158156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 206}], {
             RGBColor[
             0.23671129027789278`, 0.36612895281767627`, 0.9367917298471292]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 208}], {
             RGBColor[
             0.2374736143413805, 0.36693020374253915`, 0.9368351430747874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 258}], {
             RGBColor[
             0.24739688608388788`, 0.37736019151568206`, 0.9374002587203583]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 284}], {
             RGBColor[
             0.24292930031788273`, 0.3726644756143127, 0.9371458363201851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 325}], {
             RGBColor[
             0.22671411419860138`, 0.35562128690076766`, 0.9362224054589102]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 348}], {
             RGBColor[
             0.252407866634222, 0.38262704978860046`, 0.9376856266496183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 369}], {
             RGBColor[
             0.24965722981087085`, 0.3797359560868109, 0.9375289819517311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 392}], {
             RGBColor[
             0.24490486142793333`, 0.37474091559878486`, 0.9372583416028217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 36}], {
             RGBColor[
             0.5275969503288876, 0.6273659981055699, 0.9559535110626505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 64}], {
             RGBColor[
             0.46723843843845614`, 0.5768882992816866, 0.951609674456959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 82}], {
             RGBColor[
             0.4573668797759753, 0.5683380513272105, 0.9509806674680623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 122}], {
             RGBColor[
             0.490802095307585, 0.5972979545178956, 0.9531111298361363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 157}], {
             RGBColor[
             0.5023802232259484, 0.6068939230427937, 0.9539683579331921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 187}], {
             RGBColor[
             0.6897252223294911, 0.7560947412907055, 0.9707766661911668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 218}], {
             RGBColor[
             0.7227901892843811, 0.7824598484159166, 0.9739304322567687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 253}], {
             RGBColor[
             0.43861619159981363`, 0.5520971476660097, 0.9497858901980598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 262}], {
             RGBColor[
             0.7370797325190604, 0.7937780282574919, 0.9726613937241215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 298}], {
             RGBColor[
             0.6794733687434446, 0.7479201915203444, 0.969798835244192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 74}], {
             RGBColor[
             0.8849400211257357, 0.9108459941170431, 0.9803872287207334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 132}], {
             RGBColor[
             0.8722144636354254, 0.9008667885957915, 0.9791289224454733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 140}], {
             RGBColor[
             0.8085657806265083, 0.8511439536813179, 0.9727850165539047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 191}], {
             RGBColor[
             0.8120299641162554, 0.853850200152278, 0.9731302939895274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.8858480974802114, 0.9115700695530261, 0.9804738418540726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 216}], {
             RGBColor[
             0.8021540700559975, 0.8461350766528297, 0.9721459571650781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.960434037083298, 0.9441092105197667, 0.6687925780376456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 247}], {
             RGBColor[
             0.926107052730001, 0.8138393200274576, 0.6108347292188259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 302}], {
             RGBColor[
             0.9662417999648014, 0.9637001584466507, 0.6913546401282936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 311}], {
             RGBColor[
             0.7322903023542322, 0.7896729975900088, 0.9664706721730203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 323}], {
             RGBColor[
             0.8877084052982851, 0.9130534285104475, 0.9806512796744769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 340}], {
             RGBColor[
             0.9694923470519816, 0.9738780487256253, 0.770900506424754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 357}], {
             RGBColor[
             0.8104483343258964, 0.8526146189392179, 0.9729726519131952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 83}], {
             RGBColor[
             0.31363288900734776`, 0.44289778603368235`, 0.9413217134716801]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 108}], {
             RGBColor[
             0.3209765938651673, 0.4492585340761873, 0.9417896478514372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 125}], {
             RGBColor[
             0.27618503388558474`, 0.4076183601292589, 0.9390397011494167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 179}], {
             RGBColor[
             0.2720136332383074, 0.4032339535668936, 0.9388021460535885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 196}], {
             RGBColor[
             0.2861541125436652, 0.4180964938749955, 0.9396074254310642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 231}], {
             RGBColor[
             0.2915341164557601, 0.4237512190985569, 0.9399138086948555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 303}], {
             RGBColor[
             0.2819979246761117, 0.4137280769086658, 0.939370736680536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 313}], {
             RGBColor[
             0.27859623109563336`, 0.41015268127575305`, 0.9391770152634824]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 344}], {
             RGBColor[
             0.2975063791842545, 0.4289298137668702, 0.9402941465258654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 50}], {
             RGBColor[
             0.4309033063250306, 0.5476259924741631, 0.9486839796675377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 54}], {
             RGBColor[
             0.4298252331165606, 0.5467147461063611, 0.9486090616680254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 116}], {
             RGBColor[
             0.4119401607737857, 0.531223595372923, 0.9474694406734923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 121}], {
             RGBColor[
             0.48042756078829996`, 0.5878320132896839, 0.9525827103922078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 130}], {
             RGBColor[
             0.4090322853711047, 0.5287049398531881, 0.9472841534241666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 135}], {
             RGBColor[
             0.45546851492086315`, 0.5675691354622958, 0.9506178428735257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 147}], {
             RGBColor[
             0.34619840677068126`, 0.47206167326583015`, 0.9433617090301424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 158}], {
             RGBColor[
             0.4553874406509526, 0.5675033157176284, 0.9506114604100135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 172}], {
             RGBColor[
             0.3545418209166673, 0.4808311305362721, 0.9438368541227812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 181}], {
             RGBColor[
             0.4874856363228792, 0.5935620769713348, 0.9531383479528726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 265}], {
             RGBColor[
             0.49977683892029745`, 0.6035406289522859, 0.9541059564454999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 322}], {
             RGBColor[
             0.45803755349750475`, 0.5696547967126826, 0.9508200870009773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 328}], {
             RGBColor[
             0.3585480828066595, 0.484978061001665, 0.9440673446781876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 347}], {
             RGBColor[
             0.3438545327447645, 0.469598113054395, 0.9432282288718172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 362}], {
             RGBColor[
             0.406159003588231, 0.5262162475882044, 0.9471010704497052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 364}], {
             RGBColor[
             0.37859437323609996`, 0.5023411502157933, 0.945344676578113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 387}], {
             RGBColor[
             0.3506138656824209, 0.476702600538333, 0.94361316288308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.416297218948796, 0.5331956497034136, 0.948244914168578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 60}], {
             RGBColor[
             0.33522274220732345`, 0.4647748233402267, 0.9425810746009868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 64}], {
             RGBColor[
             0.3559387070583645, 0.4827179508795304, 0.9439010775628867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 82}], {
             RGBColor[
             0.34606714839588365`, 0.4741677029250543, 0.94327207057399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 122}], {
             RGBColor[
             0.37950236392749337`, 0.5031276061157393, 0.9454025329420639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 159}], {
             RGBColor[
             0.3221758681761928, 0.45347427680941704`, 0.9417497393246208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 182}], {
             RGBColor[
             0.30050572685967525`, 0.4327952999017487, 0.9404388491913643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 210}], {
             RGBColor[
             0.30642042589023155`, 0.43901202359644165`, 0.9407756825511414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 263}], {
             RGBColor[
             0.2875003760669833, 0.4191258516317633, 0.9396982137034129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 29}], {
             RGBColor[
             0.2663738031073146, 0.39730613451333674`, 0.9384809660710094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 45}], {
             RGBColor[
             0.2939087453063859, 0.4262471045807297, 0.94004904029495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 91}], {
             RGBColor[
             0.2774698045998931, 0.40896873560916513`, 0.9391128669409485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 97}], {
             RGBColor[
             0.36730142212889694`, 0.4910409193978484, 0.9446807120447999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 100}], {
             RGBColor[
             0.3344662411106874, 0.46260073594405915`, 0.9425884833453301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 141}], {
             RGBColor[
             0.32619117202571163`, 0.45543328701971864`, 0.9420612032605917]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 150}], {
             RGBColor[
             0.28145958694833023`, 0.41316224982418415`, 0.9393400791433381]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 189}], {
             RGBColor[
             0.29643257003583556`, 0.4288998043911114, 0.9401927683796281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 190}], {
             RGBColor[
             0.26671069132338054`, 0.3976602253883686, 0.938500151356533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 255}], {
             RGBColor[
             0.27639668732322686`, 0.40784082131182386`, 0.9390517544995772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 266}], {
             RGBColor[
             0.27365816407618504`, 0.40496245974678047`, 0.9388957996519403]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 273}], {
             RGBColor[
             0.28387789683872655`, 0.4157040468486936, 0.9394777983140272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 350}], {
             RGBColor[
             0.36253057369193453`, 0.4869086502715662, 0.9443767178010922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 365}], {
             RGBColor[
             0.27427955709376345`, 0.40561558320684826`, 0.9389311870650228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 394}], {
             RGBColor[
             0.32559317401626164`, 0.45491533120018696`, 0.9420230993562184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[
             0.2165666874460731, 0.34495569799984427`, 0.9356445245171263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 89}], {
             RGBColor[
             0.21600037669219402`, 0.3443604694913417, 0.9356122739574746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 163}], {
             RGBColor[
             0.22919558870789478`, 0.35822947394460614`, 0.9363637217612019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 164}], {
             RGBColor[
             0.22797821780387265`, 0.3569499399387055, 0.9362943942891566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 169}], {
             RGBColor[
             0.21705819820147026`, 0.34547230696734843`, 0.9356725153275212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 227}], {
             RGBColor[
             0.22416996966139735`, 0.3529472296840859, 0.936077520191241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 245}], {
             RGBColor[
             0.22165838805798918`, 0.35030739817543277`, 0.9359344893344789]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 292}], {
             RGBColor[
             0.21221830344661968`, 0.3403852707129492, 0.9353968904812151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 304}], {
             RGBColor[
             0.2162581809318601, 0.34463143809296365`, 0.9356269555275363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 353}], {
             RGBColor[
             0.21189878814995255`, 0.34004943987771225`, 0.9353786945577505]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 378}], {
             RGBColor[
             0.21097218176330165`, 0.339075517815104, 0.9353259256948219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 25}], {
             RGBColor[
             0.8665250847621527, 0.4664742214122973, 0.20954155778738393`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 76}], {
             RGBColor[
             0.8653472987842202, 0.4574212422768018, 0.20841370860479677`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 104}], {
             RGBColor[
             0.9180135558932775, 0.712060691693382, 0.25285908317008815`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 109}], {
             RGBColor[
             0.9481247371168586, 0.8202041529201762, 0.49378352937662584`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 138}], {
             RGBColor[
             0.8469462590828297, 0.31598278774490174`, 0.19079285220574332`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 144}], {
             RGBColor[
             0.8902955651891483, 0.5947396082931894, 0.23017226930310958`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 207}], {
             RGBColor[
             0.9210044213449331, 0.723918476562367, 0.2552656037171254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 233}], {
             RGBColor[
             0.8456898299251425, 0.30632532266815005`, 0.18958969422540822`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 242}], {
             RGBColor[
             0.9102499321760205, 0.681280510728698, 0.24661228929151274`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 317}], {
             RGBColor[
             0.946390043794504, 0.8194868126517976, 0.5225318869704552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 358}], {
             RGBColor[
             0.9353648485028525, 0.777122720375753, 0.28624658001000514`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 366}], {
             RGBColor[
             0.9017167350633479, 0.6466004732099342, 0.2397023734046333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 382}], {
             RGBColor[
             0.9004669733536322, 0.6409255971753784, 0.23865954159958375`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[
             0.8481222219407366, 0.3708940618944248, 0.19371520011771268`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 104}], {
             RGBColor[
             0.8770987724063027, 0.5087936416661875, 0.21806999727134982`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 109}], {
             RGBColor[
             0.8971728932220235, 0.5808892824840503, 0.3786862947423749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 138}], {
             RGBColor[
             0.8389217020900414, 0.3001748346284747, 0.18490477191818594`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 144}], {
             RGBColor[
             0.8586201119368833, 0.430579586066059, 0.2029454546933641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 205}], {
             RGBColor[
             0.8975635807255052, 0.5810508418069508, 0.372211591742834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 207}], {
             RGBColor[
             0.8790926827074065, 0.5166988315788441, 0.21967434430270802`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 233}], {
             RGBColor[
             0.8382934875111977, 0.29534610209009887`, 0.1843031929280184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 317}], {
             RGBColor[
             0.8960164310071204, 0.5804110556384645, 0.39785186647159454`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 358}], {
             RGBColor[
             0.8886663008126862, 0.5521683274544348, 0.24032832849796115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 366}], {
             RGBColor[
             0.8662342251863496, 0.4651534960105555, 0.20929885742771326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 382}], {
             RGBColor[
             0.8654010507132059, 0.4613702453208517, 0.2086036362243469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 391}], {
             RGBColor[
             0.8392710067008462, 0.30285974293337714`, 0.18523926640797578`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 30}], {
             RGBColor[
             0.31701994287924884`, 0.4369570883961569, 0.9418741496415883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 62}], {
             RGBColor[
             0.31709055637755623`, 0.43703130766003234`, 0.9418781709758536]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 77}], {
             RGBColor[
             0.6422389788407158, 0.7176486903810251, 0.9669170377654001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 106}], {
             RGBColor[
             0.7018038352541023, 0.7648141211568, 0.9611581586207743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 111}], {
             RGBColor[
             0.6645955027358419, 0.5448101324102603, 0.5834436797495368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 160}], {
             RGBColor[
             0.7046893390865665, 0.34122883940979487`, 0.4339898135889303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.7015503538471387, 0.3171012233474507, 0.4309839177786776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 173}], {
             RGBColor[
             0.34074023236907375`, 0.46188861660318076`, 0.9432249850370102]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 185}], {
             RGBColor[
             0.7008312736981772, 0.31157405821960193`, 0.4302953258159472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 197}], {
             RGBColor[
             0.7219321437839568, 0.7790682930787789, 0.8931643392096228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 204}], {
             RGBColor[
             0.3170199268376633, 0.4369570715354334, 0.9418741487280438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 345}], {
             RGBColor[
             0.3285301240705917, 0.4490550186158963, 0.9425296374326482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 370}], {
             RGBColor[
             0.6431647387570222, 0.7183868662092043, 0.9670053375726531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 389}], {
             RGBColor[
             0.31710049015279534`, 0.4370417486876464, 0.9418787366896577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 400}], {
             RGBColor[
             0.4223618806328297, 0.5402016308185901, 0.9481469689308566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 51}], {
             RGBColor[
             0.33517005330446453`, 0.4636817173337682, 0.9426160703012283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[
             0.3427358884343137, 0.47023486345331306`, 0.943098158625497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 277}], {
             RGBColor[
             0.277614773953709, 0.4091211075916136, 0.9391211227311855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 287}], {
             RGBColor[
             0.27881505582512084`, 0.4103826799407336, 0.9391894770081045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 376}], {
             RGBColor[
             0.3679050083022842, 0.49203509004620194`, 0.9447019126873052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 377}], {
             RGBColor[
             0.3561480526956704, 0.48185180602152367`, 0.9439527698723194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 395}], {
             RGBColor[
             0.28524240829505776`, 0.41713823490432095`, 0.9395555052228516]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 396}], {
             RGBColor[
             0.28785811658992677`, 0.419887510167713, 0.9397044659406507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 44}], {
             RGBColor[
             0.29312282823703784`, 0.42542105591082463`, 0.9400042834805107]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 47}], {
             RGBColor[
             0.3610905157265072, 0.4852888096589335, 0.9442985989042187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 49}], {
             RGBColor[
             0.27201275594263963`, 0.40323303147352313`, 0.938802096092898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 147}], {
             RGBColor[
             0.2865134731880893, 0.418474204697066, 0.9396278904881377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 211}], {
             RGBColor[
             0.2754831553698227, 0.4068806413075249, 0.9389997302062802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 301}], {
             RGBColor[
             0.27255350960952185`, 0.40380139786317903`, 0.9388328912142536]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 328}], {
             RGBColor[
             0.2988631492240676, 0.4313905924329009, 0.9403335261361829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 347}], {
             RGBColor[
             0.28416959916217255`, 0.4160106444856309, 0.9394944103298126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 362}], {
             RGBColor[
             0.34647407000563907`, 0.4726287790194402, 0.9433672519077005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 372}], {
             RGBColor[
             0.2698833093261751, 0.4009948480649053, 0.9386808272583244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 380}], {
             RGBColor[
             0.2768898890919296, 0.40835920764152867`, 0.9390798416106783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 390}], {
             RGBColor[
             0.2772941937947283, 0.40878415751856884`, 0.9391028661653874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 45}], {
             RGBColor[
             0.26796415172899, 0.39897769174864406`, 0.938571534072304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 91}], {
             RGBColor[
             0.25152521102249714`, 0.3816993227770795, 0.9376353607183026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 150}], {
             RGBColor[
             0.2555149933709343, 0.38589283699209853`, 0.937862572920692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 190}], {
             RGBColor[
             0.2407660977459846, 0.370390812556283, 0.937022645133887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 226}], {
             RGBColor[
             0.23953161826969796`, 0.36909329635618626`, 0.936952343353961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 266}], {
             RGBColor[
             0.2477135704987891, 0.37769304691469485`, 0.9374182934292943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 273}], {
             RGBColor[
             0.25793330326133057`, 0.388434634016608, 0.9380002920913812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 365}], {
             RGBColor[
             0.24833496351636752`, 0.37834617037476265`, 0.9374536808423768]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 62}], {
             RGBColor[
             0.17899764558147852`, 0.30546825298532254`, 0.9335050231613544]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 77}], {
             RGBColor[
             0.5041460680446381, 0.5860856357063153, 0.9585438899509009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 84}], {
             RGBColor[
             0.1789270231889713, 0.3053940243730791, 0.9335010013205776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 204}], {
             RGBColor[
             0.17892701604158556`, 0.30539401686072354`, 0.9335010009135446]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 333}], {
             RGBColor[
             0.1872437438170861, 0.31413542506377157`, 0.9339746262568631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 370}], {
             RGBColor[
             0.5050718279609444, 0.5868238115344944, 0.9586321897581539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 389}], {
             RGBColor[
             0.17900757935671766`, 0.3054786940129366, 0.9335055888751587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 400}], {
             RGBColor[
             0.284268969836752, 0.4086385761438802, 0.9397738211163575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 33}], {
             RGBColor[0.1810793999809316, 0.30765630885, 0.9336235759947237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 106}], {
             RGBColor[
             0.5658561150624204, 0.6355057978202503, 0.9529071762376704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 156}], {
             RGBColor[
             0.18458847622123073`, 0.3113445704668384, 0.9338234126953957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 173}], {
             RGBColor[
             0.20479251217739197`, 0.3325802932666311, 0.9349740026539064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 175}], {
             RGBColor[
             0.18107477738655686`, 0.3076514502102228, 0.9336233127448126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 197}], {
             RGBColor[
             0.5859844235922751, 0.6497599697422292, 0.884913356826519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 204}], {
             RGBColor[
             0.1810722066459815, 0.3076487481988837, 0.9336231663449399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 214}], {
             RGBColor[
             0.5834952534993698, 0.6486610383850888, 0.9230487158880236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 261}], {
             RGBColor[
             0.18133289143212553`, 0.3079227444374911, 0.9336380119578622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 295}], {
             RGBColor[
             0.21280238164412135`, 0.34099917393122015`, 0.9354301528704966]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 310}], {
             RGBColor[
             0.18289778193115996`, 0.30956754357176464`, 0.9337271301567341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 345}], {
             RGBColor[
             0.1925824038789099, 0.3197466952793466, 0.9342786550495443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 43}], {
             RGBColor[
             0.2218603287150994, 0.3505196506098328, 0.9359459895561568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 124}], {
             RGBColor[
             0.21977833860588586`, 0.34833134699925217`, 0.9358274232994656]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 137}], {
             RGBColor[
             0.21892075175740905`, 0.34742996884735633`, 0.9357785849971308]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 199}], {
             RGBColor[
             0.22104408708317058`, 0.349661728901967, 0.9358995058027398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 238}], {
             RGBColor[
             0.22275425852448527`, 0.3514592275179208, 0.9359968975363508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 252}], {
             RGBColor[
             0.2203092674216852, 0.34888938684748844`, 0.9358576589100864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 293}], {
             RGBColor[
             0.2137582367821496, 0.342003838286004, 0.9354845874065463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 330}], {
             RGBColor[
             0.2205286799485376, 0.349120003324768, 0.935870154128899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 63}], {
             RGBColor[
             0.5687512197366357, 0.5886439817299056, 0.6135098819197802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 84}], {
             RGBColor[
             0.17893420048233583`, 0.30540156816347186`, 0.9335014100568169]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 90}], {
             RGBColor[
             0.44237359411374266`, 0.5377546224462848, 0.9524068017673784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 152}], {
             RGBColor[
             0.18127877637637368`, 0.30786586608280325`, 0.9336349301854932]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 156}], {
             RGBColor[
             0.18245046291019928`, 0.30909738291907096`, 0.9337016560002396]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 173}], {
             RGBColor[
             0.20265449886636056`, 0.33033310571886365`, 0.9348522459587503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 175}], {
             RGBColor[
             0.17893676407552545`, 0.30540426266245535`, 0.9335015560496566]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 204}], {
             RGBColor[
             0.1789341933349501, 0.3054015606511163, 0.9335014096497838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 214}], {
             RGBColor[
             0.5813572401883383, 0.6464138508373214, 0.9229269591928677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 256}], {
             RGBColor[
             0.202124876078153, 0.3297764385884332, 0.9348220847244686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 261}], {
             RGBColor[
             0.17919487812109408`, 0.3056755568897237, 0.9335162552627061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 264}], {
             RGBColor[
             0.18448620056776344`, 0.31123707227039327`, 0.9338175882482339]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 295}], {
             RGBColor[
             0.21066436833308994`, 0.3387519863834527, 0.9353083961753406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 310}], {
             RGBColor[
             0.18075976862012855`, 0.3073203560239972, 0.9336053734615781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 333}], {
             RGBColor[
             0.1872509211104506, 0.3141429688541644, 0.9339750349931024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 381}], {
             RGBColor[
             0.5860442078575524, 0.648421627973087, 0.8483684065741224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 53}], {
             RGBColor[
             0.30076648553276153`, 0.4331274488318972, 0.9404515726006413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 68}], {
             RGBColor[
             0.29450681654452554`, 0.42654813983932427`, 0.9400950937121118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 86}], {
             RGBColor[
             0.30641268277319833`, 0.4390619601211778, 0.940773115180684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 95}], {
             RGBColor[
             0.29703377047989377`, 0.4292041286435296, 0.9402390000004376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 151}], {
             RGBColor[
             0.31406226415390115`, 0.44644668080690353`, 0.9412327476508988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 244}], {
             RGBColor[
             0.2861625929026812, 0.4177778317374103, 0.9396199025198813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 249}], {
             RGBColor[
             0.2909291460215572, 0.4227877812822719, 0.9398913506685179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 253}], {
             RGBColor[
             0.3270023945629662, 0.4576547713773704, 0.9420572813180563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 270}], {
             RGBColor[
             0.28093807902462586`, 0.41228653639826196`, 0.9393223741835017]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 308}], {
             RGBColor[
             0.2866886948098787, 0.4183307981986623, 0.9396498632451982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 386}], {
             RGBColor[
             0.32582607560218535`, 0.4566359030170521, 0.9419823273140535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 397}], {
             RGBColor[
             0.28081927975955956`, 0.41216167083836874`, 0.939315608741104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 41}], {
             RGBColor[
             0.3109306833758936, 0.44117275107327436`, 0.9411269955899995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 57}], {
             RGBColor[
             0.2771242370211076, 0.4086055221736117, 0.9390931873785582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 92}], {
             RGBColor[
             0.28435244626912165`, 0.4162028283882106, 0.9395048232020553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 114}], {
             RGBColor[
             0.30495946572485455`, 0.43600078246607, 0.9407465148814157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 153}], {
             RGBColor[
             0.2992359056961653, 0.4310433224437109, 0.940381814697533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 188}], {
             RGBColor[
             0.27406348456255775`, 0.4053884772767613, 0.9389188820540213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 195}], {
             RGBColor[
             0.2633678783864708, 0.39414671704509485`, 0.9383097831050244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 208}], {
             RGBColor[
             0.25706388434981153`, 0.3875208196162586, 0.9379507799705602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 258}], {
             RGBColor[
             0.2669871560923189, 0.3979508073894016, 0.938515895616131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 278}], {
             RGBColor[
             0.26672833715189703`, 0.3976787722729497, 0.9385011562603622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 284}], {
             RGBColor[
             0.26251957032631373`, 0.3932550914880322, 0.9382614732159579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 327}], {
             RGBColor[
             0.29981659218631795`, 0.43154628389532945`, 0.9404188155272046]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 337}], {
             RGBColor[
             0.28289219144336497`, 0.41466800798083686`, 0.9394216638499819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 354}], {
             RGBColor[
             0.2804072432672092, 0.41205616989288285`, 0.9392801497275012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 369}], {
             RGBColor[
             0.26924749981930185`, 0.40032657196053045`, 0.9386446188475038]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 392}], {
             RGBColor[
             0.2644951314363644, 0.3953315314725043, 0.9383739784985945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 55}], {
             RGBColor[
             0.46160497467818506`, 0.5724389504821938, 0.9511318842995795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 60}], {
             RGBColor[
             0.4386028192989782, 0.5525156396146701, 0.9496662072988238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 64}], {
             RGBColor[
             0.45931878415001925`, 0.5704587671539738, 0.9509862102607236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 82}], {
             RGBColor[
             0.4494472254875384, 0.5619085191994977, 0.950357203271827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 122}], {
             RGBColor[
             0.4828824410191481, 0.5908684223901826, 0.952487665639901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 157}], {
             RGBColor[
             0.49446056893751156`, 0.6004643909150807, 0.9533448937369567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 165}], {
             RGBColor[
             0.5262130350709433, 0.6262424733544989, 0.9558445641840965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 218}], {
             RGBColor[
             0.7148705349959443, 0.7760303162882036, 0.9733069680605333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 262}], {
             RGBColor[
             0.7291600782306236, 0.787348496129779, 0.9720379295278863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 298}], {
             RGBColor[
             0.6715537144550077, 0.7414906593926315, 0.9691753710479567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 314}], {
             RGBColor[
             0.7227446385125958, 0.7823089126955356, 0.9740580070832467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 58}], {
             RGBColor[
             0.2743052593933725, 0.40564259795335733`, 0.9389326507729624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 87}], {
             RGBColor[
             0.2699691213947309, 0.4010850419897568, 0.9386857141286811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 110}], {
             RGBColor[
             0.2526887349083196, 0.3829222601527542, 0.9377016216823209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 134}], {
             RGBColor[
             0.24206319644531432`, 0.3717541455300861, 0.9370965129859282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 159}], {
             RGBColor[
             0.29061706023566036`, 0.4206896192842019, 0.9399383913431659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 167}], {
             RGBColor[
             0.26667449670074206`, 0.39762218254510395`, 0.9384980901263189]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 201}], {
             RGBColor[
             0.26311290635419504`, 0.3938787252730125, 0.9382952628249838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 236}], {
             RGBColor[
             0.2501608630823501, 0.3802653065873294, 0.9375576631214831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 243}], {
             RGBColor[
             0.2690857390615694, 0.4001565511479292, 0.9386354068116546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 263}], {
             RGBColor[
             0.25594156812645086`, 0.3863411941065481, 0.9378868657219579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 348}], {
             RGBColor[
             0.2563773742968305, 0.38679925402332427`, 0.9379116842386436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 351}], {
             RGBColor[
             0.2477720085286644, 0.3777544689892789, 0.9374216213886444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 78}], {
             RGBColor[
             0.8831597035944547, 0.5138469614548667, 0.23233732835271279`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 102}], {
             RGBColor[
             0.8681284274736344, 0.39830998644304544`, 0.21794336136401693`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 205}], {
             RGBColor[
             0.9805298619657696, 0.9442896440229023, 0.524841136015259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 207}], {
             RGBColor[
             0.9528235149386215, 0.8477616286807421, 0.29603526485507003`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 213}], {
             RGBColor[
             0.9383796626861343, 0.7904965676280676, 0.28441340229193146`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 221}], {
             RGBColor[
             0.9438250637656209, 0.9183985790902189, 0.6570073333224926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 224}], {
             RGBColor[
             0.970726359968221, 0.9129152797745752, 0.34077786564994345`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 230}], {
             RGBColor[
             0.9673242221990019, 0.9014390702190636, 0.3275612028563362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 247}], {
             RGBColor[
             0.9363993756149239, 0.7826453892822661, 0.2828200168311238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 250}], {
             RGBColor[
             0.9770092142863354, 0.9428337657309378, 0.5831873792076157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 289}], {
             RGBColor[
             0.9317722599024755, 0.7624356715057958, 0.27900046954474644`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 358}], {
             RGBColor[
             0.9671839420965409, 0.9009658724941282, 0.3270162411479497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 391}], {
             RGBColor[
             0.8688575973668984, 0.40391470576695665`, 0.21864161527728607`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 93}], {
             RGBColor[
             0.2591650880555334, 0.38972931793498194`, 0.9380704404131488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 94}], {
             RGBColor[
             0.2666080163774077, 0.39755230751018356`, 0.9384943041702538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 119}], {
             RGBColor[
             0.2567952159774935, 0.3872384321223937, 0.9379354797042159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 128}], {
             RGBColor[
             0.2996526087721707, 0.4306693116276521, 0.9404352763322198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 177}], {
             RGBColor[
             0.29750028265951367`, 0.4288050749279245, 0.9402981320155486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 200}], {
             RGBColor[
             0.27187585958380484`, 0.4030891447206572, 0.9387943000477824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 225}], {
             RGBColor[
             0.26510008482719366`, 0.3959673758425263, 0.9384084296992539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 288}], {
             RGBColor[
             0.2590590279232666, 0.38961784201136873`, 0.9380644004455181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 296}], {
             RGBColor[
             0.2873068026652887, 0.4193080442775966, 0.9396730694282384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 316}], {
             RGBColor[
             0.26368578568270973`, 0.3944808577699287, 0.9383278874552436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 324}], {
             RGBColor[
             0.27652485948189337`, 0.40797553837716655`, 0.9390590537143996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 355}], {
             RGBColor[
             0.25200661552040216`, 0.3822053094271858, 0.9376627759922841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 360}], {
             RGBColor[
             0.29174189371093673`, 0.42381744784571107`, 0.9399312125636886]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 374}], {
             RGBColor[
             0.2745978955714905, 0.40595017713076464`, 0.9389493159703898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 375}], {
             RGBColor[
             0.2639687025623859, 0.39477822134843454`, 0.9383439991530031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 380}], {
             RGBColor[
             0.2692913647455158, 0.4003726767791782, 0.9386471168901593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 383}], {
             RGBColor[
             0.27666419535336334`, 0.408121989212486, 0.9390669886861509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 390}], {
             RGBColor[
             0.26969566944831447`, 0.40079762665621843`, 0.9386701414448686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 41}], {
             RGBColor[
             0.34006622360312927`, 0.4689700034848203, 0.942889696952605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 55}], {
             RGBColor[
             0.37142239221905604`, 0.496129140733077, 0.9448876842896408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 58}], {
             RGBColor[
             0.31906156196643076`, 0.449858262003899, 0.9415849314423156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.3368642646638673, 0.46619662758676733`, 0.9426856709603764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 87}], {
             RGBColor[
             0.31472542396778913`, 0.4453007060402985, 0.9413379947980343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 96}], {
             RGBColor[
             0.313111809733841, 0.4436046951713676, 0.9412461018545393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 110}], {
             RGBColor[
             0.29744503748137785`, 0.4271379242032959, 0.940353902351674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 146}], {
             RGBColor[
             0.43732168419070216`, 0.5509809435704429, 0.9497020146539848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 154}], {
             RGBColor[
             0.3847350802007028, 0.5076599219476261, 0.9457359569958835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 159}], {
             RGBColor[
             0.33537336280871854`, 0.46490528333474357`, 0.9425906720125191]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 167}], {
             RGBColor[
             0.31143079927380024`, 0.4418378465956456, 0.9411503707956721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 192}], {
             RGBColor[
             0.34190093761815415`, 0.4705591405492272, 0.9430066033072686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 203}], {
             RGBColor[
             0.31535485342024205`, 0.44596227630295887`, 0.941373839874194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 228}], {
             RGBColor[
             0.35358465424250685`, 0.48067898864856917`, 0.9437510793990673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 243}], {
             RGBColor[
             0.3138420416346276, 0.4443722151984709, 0.9412876874810078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 332}], {
             RGBColor[
             0.43326686926446056`, 0.5476890621459892, 0.9493828047697146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 348}], {
             RGBColor[
             0.3011336768698887, 0.43101491807386594`, 0.9405639649079968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 361}], {
             RGBColor[
             0.34746932604333547`, 0.4753821987277793, 0.9433614160937887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 385}], {
             RGBColor[
             0.4573665882056296, 0.5672542996623962, 0.9512800229249427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 57}], {
             RGBColor[
             0.3070138697292798, 0.4370559315903547, 0.9409039388472313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.31424207897729384`, 0.44465323780495364`, 0.9413155746707285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 96}], {
             RGBColor[
             0.3138659022147775, 0.44425785217656466`, 0.9412941519606068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 114}], {
             RGBColor[
             0.3348490984330268, 0.46445119188281303`, 0.9425572663500889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 153}], {
             RGBColor[
             0.32912553840433756`, 0.45949373186045395`, 0.9421925661662062]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 154}], {
             RGBColor[
             0.3854891726816393, 0.5083130789528232, 0.945784007101951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 188}], {
             RGBColor[
             0.30395311727072993`, 0.43383888669350434`, 0.9407296335226945]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 203}], {
             RGBColor[
             0.31610894590117855`, 0.4466154333081559, 0.9414218899802616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 222}], {
             RGBColor[
             0.4728736082946373, 0.5798845479116403, 0.9524894775340721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 258}], {
             RGBColor[
             0.29687678880049106`, 0.4264012168061446, 0.9403266470848042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 312}], {
             RGBColor[
             0.40188874544580117`, 0.5222558384193261, 0.9469012891044913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 327}], {
             RGBColor[
             0.32970622489449014`, 0.4599966933120725, 0.9422295669958778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 356}], {
             RGBColor[
             0.4295993605310475, 0.5447525640945126, 0.9490827702313296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 361}], {
             RGBColor[
             0.34822341852427197`, 0.4760353557329764, 0.9434094661998561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 369}], {
             RGBColor[
             0.2991371325274741, 0.4287769813772735, 0.940455370316177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 104}], {
             RGBColor[
             0.9330499750272585, 0.8621677183315113, 0.6295247357296906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 109}], {
             RGBColor[
             0.9631611562508396, 0.9703111795583055, 0.8704491819362283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 136}], {
             RGBColor[
             0.7754039881303256, 0.825013733522431, 0.9782569627328132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 205}], {
             RGBColor[
             0.9637471875060623, 0.9705535185426564, 0.8607371274369169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 207}], {
             RGBColor[
             0.9360408404789141, 0.8740255032004962, 0.6319312562767279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 221}], {
             RGBColor[
             0.9270423893059134, 0.944662453609973, 0.9929033247441504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 276}], {
             RGBColor[
             0.8488960037945177, 0.8827904862944987, 0.9853329329150746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 358}], {
             RGBColor[
             0.9504012676368335, 0.9272297470138823, 0.6629122325696076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 366}], {
             RGBColor[
             0.9167531541973288, 0.7967074998480634, 0.6163680259642358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 376}], {
             RGBColor[
             0.6853095806395425, 0.7514657941798157, 0.9712763701432583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 124}], {
             RGBColor[
             0.22535325774935577`, 0.3541909404893282, 0.9361449066973324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 137}], {
             RGBColor[
             0.22449567090087896`, 0.35328956233743236`, 0.9360960683949977]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 199}], {
             RGBColor[
             0.2266190062266405, 0.3555213223920431, 0.9362169892006067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 238}], {
             RGBColor[
             0.22832917766795519`, 0.3573188210079969, 0.9363143809342176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 252}], {
             RGBColor[
             0.2258841865651551, 0.3547489803375645, 0.9361751423079533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 277}], {
             RGBColor[
             0.2426240388727448, 0.37234362648077923`, 0.9371284521324783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 293}], {
             RGBColor[
             0.21933315592561953`, 0.34786343177608003`, 0.9358020708044131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 299}], {
             RGBColor[
             0.22078197517346282`, 0.34938623266600927`, 0.9358845789172419]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 330}], {
             RGBColor[
             0.2261035990920075, 0.35497959681484403`, 0.9361876375267658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 367}], {
             RGBColor[
             0.22337497152266345`, 0.35211163623448327`, 0.9360322462233344]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 47}], {
             RGBColor[
             0.36592423069765223`, 0.4903693505688373, 0.9445738718209851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 49}], {
             RGBColor[
             0.2768464709137847, 0.4083135723834269, 0.9390773690096643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 54}], {
             RGBColor[
             0.3749740145051137, 0.4982078184475008, 0.9451505160427869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 93}], {
             RGBColor[
             0.2715973273730923, 0.4027963897072362, 0.9387784380504338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[
             0.3120848480897295, 0.44373638339990634`, 0.9411432739695049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 211}], {
             RGBColor[
             0.28031687034096775`, 0.4119611822174286, 0.9392750031230466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 301}], {
             RGBColor[
             0.2773872245806669, 0.4088819387730828, 0.9391081641310199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 316}], {
             RGBColor[
             0.27611802500026855`, 0.4075479295421829, 0.9390358850925288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 324}], {
             RGBColor[
             0.2889570987994522, 0.4210426101494208, 0.9397670513516847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 328}], {
             RGBColor[
             0.3036968641952127, 0.4364711333428047, 0.9406087990529493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 362}], {
             RGBColor[
             0.35130778497678417`, 0.477709319929344, 0.9436425248244668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 372}], {
             RGBColor[
             0.27471702429732014`, 0.4060753889748091, 0.9389561001750906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 380}], {
             RGBColor[
             0.2817236040630746, 0.41343974855143245`, 0.9393551145274445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 383}], {
             RGBColor[
             0.28909643467092216`, 0.42118906098474024`, 0.9397749863234359]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 390}], {
             RGBColor[
             0.28212790876587335`, 0.4138646984284726, 0.9393781390821536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 91}], {
             RGBColor[
             0.27906015322156846`, 0.41064029284447245`, 0.9392034349422431]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 97}], {
             RGBColor[
             0.36889177075057233`, 0.4927124766331557, 0.9447712800460943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 100}], {
             RGBColor[
             0.33605658973236274`, 0.46427229317936647`, 0.9426790513466246]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 112}], {
             RGBColor[
             0.31221013250570034`, 0.4436176904874213, 0.9411595761787357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 141}], {
             RGBColor[
             0.32778152064738697`, 0.45710484425502595`, 0.9421517712618861]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 180}], {
             RGBColor[
             0.33088455801292704`, 0.4597925392578639, 0.9423494940589101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 190}], {
             RGBColor[
             0.2683010399450559, 0.3993317826236759, 0.9385907193578275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 266}], {
             RGBColor[
             0.2752485126978604, 0.4066340169820878, 0.9389863676532347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 271}], {
             RGBColor[
             0.30114348847212347`, 0.43385127835713033`, 0.9404610482153953]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 273}], {
             RGBColor[
             0.2854682454604019, 0.41737560408400093`, 0.9395683663153217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 350}], {
             RGBColor[
             0.36412092231360993`, 0.48858020750687353`, 0.9444672858023867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 365}], {
             RGBColor[
             0.2758699057154388, 0.4072871404421556, 0.9390217550663172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 394}], {
             RGBColor[
             0.32718352263793704`, 0.4565868884354943, 0.9421136673575129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 59}], {
             RGBColor[
             0.30916725287120805`, 0.4399481765928165, 0.9410035436196971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 287}], {
             RGBColor[
             0.27226485336384204`, 0.4034980018471065, 0.9388164526680909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 373}], {
             RGBColor[
             0.26731905714517273`, 0.3982996564396932, 0.9385347968900875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 395}], {
             RGBColor[
             0.27869220583377896`, 0.41025355681069386`, 0.939182480882838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 54}], {
             RGBColor[
             0.44294170199458305`, 0.5580755721956097, 0.9494448314664949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 121}], {
             RGBColor[
             0.4935440296663224, 0.5991928393789325, 0.9534184801906773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 128}], {
             RGBColor[
             0.3800525355791988, 0.5036041371480152, 0.945437589393213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 130}], {
             RGBColor[
             0.4221487542491271, 0.5400657659424366, 0.9481199232226362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.468503909528975, 0.5788641418068768, 0.9514472302084831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 181}], {
             RGBColor[
             0.5006021052009016, 0.6049229030605833, 0.9539741177513421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 265}], {
             RGBColor[
             0.5128933077983199, 0.6149014550415344, 0.9549417262439694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 311}], {
             RGBColor[
             0.47663297852550124`, 0.5854636862286419, 0.9520871802976505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 322}], {
             RGBColor[
             0.47115402237552717`, 0.5810156228019311, 0.9516558567994469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 362}], {
             RGBColor[
             0.4192754724662534, 0.5375770736774529, 0.9479368402481747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 56}], {
             RGBColor[
             0.43818896314994105`, 0.5539589886879809, 0.9491419911499963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 71}], {
             RGBColor[
             0.6482814539995922, 0.7214952269023049, 0.9679496107647267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 83}], {
             RGBColor[
             0.38916228198081126`, 0.5114945416119245, 0.9460180543784913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 103}], {
             RGBColor[
             0.3850045259376993, 0.5078933023022759, 0.9457531258399835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 108}], {
             RGBColor[
             0.3965059868386308, 0.5178552896544295, 0.9464859887582483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 120}], {
             RGBColor[
             0.49591060473188847`, 0.6008847208403402, 0.9536681725336434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 143}], {
             RGBColor[
             0.5250435709581793, 0.6245361752480152, 0.9559616263525487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 196}], {
             RGBColor[
             0.3616835055171287, 0.4866932494532377, 0.9443037663378753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 231}], {
             RGBColor[
             0.3670635094292236, 0.49234797467679914`, 0.9446101496016666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 234}], {
             RGBColor[
             0.38209114426819646`, 0.5053698775309731, 0.945567487736205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 286}], {
             RGBColor[
             0.5758463873446392, 0.6644950889479655, 0.9608396409213635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 290}], {
             RGBColor[
             0.4152883060919923, 0.5341235905648768, 0.9476827815325197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 313}], {
             RGBColor[
             0.35412562406909687`, 0.4787494368539953, 0.9438733561702934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 320}], {
             RGBColor[
             0.5676684575710711, 0.6581064280542859, 0.9600245413086331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 331}], {
             RGBColor[
             0.43876768248625253`, 0.5544602462898143, 0.9491788666343646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 342}], {
             RGBColor[
             0.5144005472567488, 0.6158956891444403, 0.9551237685400916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 343}], {
             RGBColor[
             0.5738217336869491, 0.6629134141226403, 0.9606378423662292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 344}], {
             RGBColor[
             0.373035772157718, 0.49752656934511247`, 0.9449904874326764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 349}], {
             RGBColor[
             0.43541101780241814`, 0.5515528720515495, 0.9489649829288928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 147}], {
             RGBColor[
             0.2702371158648362, 0.4013667211696683, 0.9387009760172913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 211}], {
             RGBColor[
             0.25920679804656954`, 0.3897731577801271, 0.9380728157354339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 301}], {
             RGBColor[
             0.2562771522862687, 0.3866939143357813, 0.9379059767434073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 328}], {
             RGBColor[
             0.2825867919008145, 0.4142831089055032, 0.9394066116653366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 347}], {
             RGBColor[
             0.2678932418389194, 0.3989031609582332, 0.9385674958589661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 372}], {
             RGBColor[
             0.25360695200292194`, 0.3838873645375076, 0.9377539127874779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 380}], {
             RGBColor[
             0.2606135317686764, 0.39125172411413095`, 0.9381529271398318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 54}], {
             RGBColor[
             0.4530695590105145, 0.5668252864420751, 0.9500963936878091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 116}], {
             RGBColor[
             0.4351844866677396, 0.551334135708637, 0.9489567726932759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 121}], {
             RGBColor[
             0.5036718866822538, 0.607942553625398, 0.9540700424119916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.4322766112650586, 0.5488154801889021, 0.9487714854439504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 135}], {
             RGBColor[
             0.478712840814817, 0.5876796757980098, 0.9521051748933094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 158}], {
             RGBColor[
             0.47863176654490647`, 0.5876138560533424, 0.9520987924297972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 172}], {
             RGBColor[
             0.3777861468106212, 0.500941670871986, 0.945324186142565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 181}], {
             RGBColor[
             0.5107299622168331, 0.6136726173070488, 0.9546256799726562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 265}], {
             RGBColor[
             0.5230211648142513, 0.6236511692879999, 0.9555932884652836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 276}], {
             RGBColor[
             0.6098568885565028, 0.6922609454050347, 0.9637197242270632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 322}], {
             RGBColor[
             0.4812818793914586, 0.5897653370483966, 0.952307419020761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 328}], {
             RGBColor[
             0.38179240870061343`, 0.505088601337379, 0.9455546766979714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 362}], {
             RGBColor[
             0.4294033294821849, 0.5463267879239184, 0.948588402469489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 364}], {
             RGBColor[
             0.4018386991300539, 0.5224516905515073, 0.9468320085978967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 59}], {
             RGBColor[
             0.3534707906164537, 0.48058036569863427`, 0.9437438241095009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 136}], {
             RGBColor[
             0.4957527510770341, 0.5993305404010079, 0.9540497614266502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 194}], {
             RGBColor[
             0.38048922371828053`, 0.5039823744655038, 0.945465414775287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 246}], {
             RGBColor[
             0.408363122473439, 0.5281253445843351, 0.9472415149560449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 376}], {
             RGBColor[
             0.405658343586251, 0.5257826010583926, 0.9470691688370954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 377}], {
             RGBColor[
             0.39390138797963725`, 0.5155993170337143, 0.9463200260221095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 395}], {
             RGBColor[
             0.3229957435790246, 0.45088574591651165`, 0.9419227613726417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 396}], {
             RGBColor[
             0.3256114518738936, 0.4536350211799036, 0.9420717220904409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 117}], {
             RGBColor[
             0.36808130040816744`, 0.4932352549346425, 0.9446747928738624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 133}], {
             RGBColor[
             0.34195185422260005`, 0.4695411184843201, 0.9430487372114036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 174}], {
             RGBColor[
             0.5576254346896334, 0.6486129747855855, 0.95972095993169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 223}], {
             RGBColor[
             0.42035633884682855`, 0.5384929234825571, 0.9480113327439608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 260}], {
             RGBColor[
             0.5977997596730911, 0.6799974627988412, 0.9637251611956289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 267}], {
             RGBColor[
             0.4789222153161444, 0.5860393403630161, 0.9526218530734996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 272}], {
             RGBColor[
             0.5168312067307885, 0.6167442138565202, 0.9556549725324873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 291}], {
             RGBColor[
             0.5415685327056081, 0.6360692009186899, 0.9581205580022027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 346}], {
             RGBColor[
             0.36583874865596927`, 0.4912928693208167, 0.944531899459223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 384}], {
             RGBColor[
             0.5675366621289825, 0.6563557009893235, 0.9607088184571579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 68}], {
             RGBColor[
             0.28298429153365734`, 0.4147648110152172, 0.9394269088138741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 86}], {
             RGBColor[
             0.2948901577623302, 0.4272786312970708, 0.9401049302824465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 95}], {
             RGBColor[
             0.2855112454690256, 0.4174207998194225, 0.9395708151022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 101}], {
             RGBColor[
             0.27504289638646184`, 0.40641790120198085`, 0.9389746581084827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 129}], {
             RGBColor[
             0.26346421560774436`, 0.39424797357278596`, 0.9383152693672578]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 151}], {
             RGBColor[
             0.302539739143033, 0.43466335198279643`, 0.9405645627526612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 171}], {
             RGBColor[
             0.28122827358250124`, 0.41291912481058346`, 0.9393269061893516]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 244}], {
             RGBColor[
             0.27464006789181306`, 0.4059945029133032, 0.9389517176216438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 249}], {
             RGBColor[
             0.279406621010689, 0.4110044524581648, 0.9392231657702803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 253}], {
             RGBColor[
             0.31547986955209806`, 0.4458714425532633, 0.9413890964198188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 270}], {
             RGBColor[
             0.26941555401375766`, 0.4005032075741548, 0.9386541892852642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 308}], {
             RGBColor[
             0.27516616979901054`, 0.4065474693745552, 0.9389816783469607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 386}], {
             RGBColor[
             0.3143035505913172, 0.444852574192945, 0.9413141424158159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 397}], {
             RGBColor[
             0.26929675474869136`, 0.4003783420142617, 0.9386474238428664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 121}], {
             RGBColor[
             0.502593813473784, 0.607031307257596, 0.9539951244124792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 128}], {
             RGBColor[
             0.3891023193866603, 0.5114426050266787, 0.9460142336150148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 130}], {
             RGBColor[
             0.43119853805658864`, 0.5479042338211002, 0.9486965674444381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 158}], {
             RGBColor[
             0.4775536933364365, 0.5867026096855403, 0.9520238744302849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 181}], {
             RGBColor[
             0.5096518890083631, 0.6127613709392468, 0.9545507619731439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 265}], {
             RGBColor[
             0.5219430916057815, 0.622739922920198, 0.9555183704657713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 311}], {
             RGBColor[
             0.48568276233296276`, 0.5933021541073054, 0.9526638245194523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 322}], {
             RGBColor[
             0.48020380618298864`, 0.5888540906805946, 0.9522325010212487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 328}], {
             RGBColor[
             0.38071433549214345`, 0.504177354969577, 0.9454797586984591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 362}], {
             RGBColor[
             0.4283252562737149, 0.5454155415561164, 0.9485134844699766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 58}], {
             RGBColor[
             0.351171823063294, 0.4776705562573528, 0.9436309688854188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 60}], {
             RGBColor[
             0.38053049793671245`, 0.5040181241190069, 0.9454680447319882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 80}], {
             RGBColor[
             0.36897452576073053`, 0.49400892184022105`, 0.9447317084034796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 87}], {
             RGBColor[
             0.34683568506465234`, 0.47311300029375225`, 0.9433840322411374]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 122}], {
             RGBColor[
             0.4248101196568824, 0.5423709068945195, 0.9482895030730654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 146}], {
             RGBColor[
             0.4694319452875655, 0.5787932378238967, 0.951748052097088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 159}], {
             RGBColor[
             0.36748362390558187`, 0.49271757758819734`, 0.9446367094556223]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.4681407137086776, 0.5777449578588358, 0.9516464016172608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 192}], {
             RGBColor[
             0.3740111987150174, 0.498371434802681, 0.9450526407503718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 201}], {
             RGBColor[
             0.33997947002411655`, 0.46590668357700793`, 0.9429935809374401]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 210}], {
             RGBColor[
             0.3517281816196206, 0.4782553243752219, 0.9436626526821428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 228}], {
             RGBColor[
             0.38569491533937006`, 0.508491282902023, 0.9457971168421706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 385}], {
             RGBColor[
             0.4894768493024928, 0.5950665939158499, 0.9533260603680459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 71}], {
             RGBColor[
             0.6610275221983658, 0.7325352305400676, 0.968761778959447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 83}], {
             RGBColor[
             0.4019083501795848, 0.5225345452496872, 0.9468302225732115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 108}], {
             RGBColor[
             0.40925205503740436`, 0.5288952932921922, 0.9472981569529686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 120}], {
             RGBColor[
             0.5086566729306621, 0.6119247244781029, 0.9544803407283637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 143}], {
             RGBColor[
             0.5377896391569529, 0.6355761788857779, 0.956773794547269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 196}], {
             RGBColor[
             0.3744295737159023, 0.4977332530910004, 0.9451159345325955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 231}], {
             RGBColor[
             0.37980957762799716`, 0.5033879783145618, 0.9454223177963867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 237}], {
             RGBColor[
             0.5146770314008289, 0.6168123226982427, 0.9549542854004349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 254}], {
             RGBColor[
             0.46022321075082034`, 0.5726042579779009, 0.9506674811679487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 286}], {
             RGBColor[
             0.5885924555434128, 0.6755350925857282, 0.9616518091160838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 290}], {
             RGBColor[
             0.42803437429076585`, 0.5451635942026395, 0.9484949497272399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 320}], {
             RGBColor[
             0.5804145257698448, 0.6691464316920486, 0.9608367095033534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 331}], {
             RGBColor[
             0.4515137506850261, 0.565500249927577, 0.9499910348290849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 342}], {
             RGBColor[
             0.5271466154555224, 0.626935692782203, 0.9559359367348119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 343}], {
             RGBColor[
             0.5865678018857227, 0.673953417760403, 0.9614500105609494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 344}], {
             RGBColor[
             0.38578184035649155`, 0.5085665729828752, 0.9458026556273967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 349}], {
             RGBColor[
             0.44815708600119175`, 0.5625928756893122, 0.949777151123613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 92}], {
             RGBColor[
             0.2804356326225079, 0.4120860089052909, 0.9392817664592872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 114}], {
             RGBColor[
             0.3010426520782409, 0.43188396298315035`, 0.9405234581386476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 153}], {
             RGBColor[
             0.2953190920495516, 0.42692650296079127`, 0.9401587579547649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 188}], {
             RGBColor[
             0.270146670915944, 0.40127165779384166`, 0.9386958253112532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 195}], {
             RGBColor[
             0.25945106473985713`, 0.3900298975621752, 0.9380867263622563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 208}], {
             RGBColor[
             0.2531470707031978, 0.383404000133339, 0.9377277232277921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 258}], {
             RGBColor[
             0.26307034244570515`, 0.39383398790648194`, 0.9382928388733629]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 278}], {
             RGBColor[
             0.26281152350528336`, 0.39356195279003, 0.9382780995175941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 284}], {
             RGBColor[
             0.2586027566797, 0.38913827200511253`, 0.9380384164731898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 327}], {
             RGBColor[
             0.2958997785397042, 0.4274294644124098, 0.9401957587844365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 337}], {
             RGBColor[
             0.27897537779675124`, 0.41055118849791716`, 0.9391986071072138]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 354}], {
             RGBColor[
             0.27649042962059545`, 0.4079393504099632, 0.939057092984733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 392}], {
             RGBColor[
             0.2605783177897506, 0.3912147119895847, 0.9381509217558264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 60}], {
             RGBColor[
             0.3281696676840872, 0.4577472453898289, 0.942165291884663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 80}], {
             RGBColor[
             0.31661369550810525`, 0.44773804311104304`, 0.9414289555561544]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 87}], {
             RGBColor[
             0.29447485481202706`, 0.42684212156457424`, 0.9400812793938123]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 110}], {
             RGBColor[
             0.2771944683256158, 0.40867933972757164`, 0.939097186947452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 159}], {
             RGBColor[
             0.31512279365295653`, 0.44644669885901933`, 0.9413339566082971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 167}], {
             RGBColor[
             0.2911802301180382, 0.4233792621199214, 0.9398936553914501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 192}], {
             RGBColor[
             0.32165036846239214`, 0.45210055607350297`, 0.9417498879030466]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 201}], {
             RGBColor[
             0.2876186397714912, 0.4196358048478299, 0.939690828090115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 210}], {
             RGBColor[
             0.2993673513669953, 0.4319844456460439, 0.9403598998348177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 228}], {
             RGBColor[
             0.3333340850867448, 0.46222040417284493`, 0.9424943639948453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 236}], {
             RGBColor[
             0.27466659649964625`, 0.4060223861621468, 0.9389532283866143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 243}], {
             RGBColor[
             0.2935914724788655, 0.42591363072274663`, 0.9400309720767858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 263}], {
             RGBColor[
             0.28044730154374703`, 0.41209827368136553`, 0.9392824309870891]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 348}], {
             RGBColor[
             0.28088310771412667`, 0.4125563335981417, 0.9393072495037748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 351}], {
             RGBColor[
             0.27227774194596055`, 0.4035115485640963, 0.9388171866537756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 79}], {
             RGBColor[
             0.46241207497172554`, 0.5712067102742551, 0.9517169387007705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[
             0.3610366257463029, 0.4871335118181791, 0.9442259124337696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 237}], {
             RGBColor[
             0.4562186120487096, 0.5661785780610258, 0.9512293666120685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 246}], {
             RGBColor[
             0.38891052450146135`, 0.5112764819370106, 0.9460020126145274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 254}], {
             RGBColor[
             0.401764791398701, 0.521970513340684, 0.9469425623795822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 349}], {
             RGBColor[
             0.38969866664907243`, 0.5119591310520951, 0.9460522323352465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 373}], {
             RGBColor[
             0.2921699969184407, 0.4220829828981863, 0.9400355750383738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 395}], {
             RGBColor[
             0.303543145607047, 0.434036883269187, 0.9406832590311243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 87}], {
             RGBColor[
             0.32383352968544554`, 0.4531896894262284, 0.9419183552403817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 122}], {
             RGBColor[
             0.4018079642776756, 0.5224475960269956, 0.9468238260723096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 146}], {
             RGBColor[
             0.44642978990835863`, 0.5588699269563728, 0.9502823750963323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 159}], {
             RGBColor[
             0.344481468526375, 0.4727942667206735, 0.9431710324548666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 165}], {
             RGBColor[
             0.4451385583294708, 0.557821646991312, 0.950180724616505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 201}], {
             RGBColor[
             0.3169773146449097, 0.44598337270948407`, 0.9415279039366844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 210}], {
             RGBColor[
             0.3287260262404138, 0.45833201350769803`, 0.942196975681387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 263}], {
             RGBColor[
             0.3098059764171655, 0.4384458415430197, 0.9411195068336586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 66}], {
             RGBColor[
             0.9830643953423903, 0.9540141570597834, 0.4329439736998075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 98}], {
             RGBColor[
             0.985458002900472, 0.9620883573989745, 0.44224268706809605`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 107}], {
             RGBColor[
             0.8905937543543853, 0.5310251940497527, 0.2958324211095563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 131}], {
             RGBColor[
             0.9579060415796807, 0.8592435772757068, 0.3867967672286041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 215}], {
             RGBColor[
             0.8773074325747513, 0.4289007027481585, 0.2831094243686247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 262}], {
             RGBColor[
             0.9659943820446136, 0.9709682059989204, 0.7529333373497976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 269}], {
             RGBColor[
             0.9932024163292561, 0.9878689808064407, 0.5015031511422814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 279}], {
             RGBColor[
             0.9694977718101772, 0.9052009249245101, 0.39612374546494056`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 297}], {
             RGBColor[
             0.9699924620425022, 0.9739499675150907, 0.7461656307796394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 298}], {
             RGBColor[
             0.9083880182689977, 0.925110369261773, 0.7500707788698681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 300}], {
             RGBColor[
             0.9416713408004723, 0.7907793854302443, 0.3735219082012329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 306}], {
             RGBColor[
             0.9818610097196364, 0.9499548547858537, 0.42826904779571534`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 307}], {
             RGBColor[
             0.9892929392100926, 0.9881701251038566, 0.7056981044009731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 314}], {
             RGBColor[
             0.9595789423265859, 0.965928622564677, 0.7549534149051582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 352}], {
             RGBColor[
             0.9937500196167237, 0.9890402488671484, 0.5611063895673631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 77}], {
             RGBColor[
             0.5042166815429454, 0.5861598549701907, 0.9585479112851663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 204}], {
             RGBColor[
             0.17899762953989296`, 0.30546823612459895`, 0.9335050222478098]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 345}], {
             RGBColor[
             0.19050782677282135`, 0.3175661832050619, 0.9341605109524143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 370}], {
             RGBColor[
             0.5051424414592518, 0.5868980307983699, 0.9586362110924191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 389}], {
             RGBColor[
             0.17907819285502502`, 0.305552913276812, 0.9335096102094239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 400}], {
             RGBColor[
             0.2843395833350594, 0.4087127954077557, 0.9397778424506229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 90}], {
             RGBColor[
             0.8321834271804781, 0.8209894828739578, 0.632414864387591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 138}], {
             RGBColor[
             0.8657489352082692, 0.3904152146932457, 0.2086100257376945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 142}], {
             RGBColor[
             0.8672429999311523, 0.40189925085666073`, 0.21004074380363202`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 152}], {
             RGBColor[
             0.5710886094431091, 0.5911007265104762, 0.6136429928057057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 156}], {
             RGBColor[
             0.5722602959769347, 0.592332243346744, 0.6137097186204522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 202}], {
             RGBColor[
             0.8904134348354518, 0.5799973668804237, 0.23222877843525258`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 214}], {
             RGBColor[
             0.9711670732550739, 0.9296487112649943, 0.6029350218130802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 217}], {
             RGBColor[
             0.8680707972718473, 0.4082620639603508, 0.21083344347194502`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 242}], {
             RGBColor[
             0.9384539463641798, 0.7929291511512139, 0.2733380495894395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 256}], {
             RGBColor[
             0.5919347091448884, 0.6130112990161062, 0.6148301473446811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 257}], {
             RGBColor[
             0.8679251307385805, 0.4071424071541793, 0.2106939530351818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 261}], {
             RGBColor[
             0.5690047111878296, 0.5889104173173967, 0.6135243178829187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 264}], {
             RGBColor[
             0.5742960336344989, 0.5944719326980662, 0.6138256508684465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 268}], {
             RGBColor[
             0.8643996842677903, 0.38004428071919283`, 0.20731798151333095`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 317}], {
             RGBColor[
             0.9745940579826633, 0.9311354530743134, 0.5492576472683819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 381}], {
             RGBColor[
             0.975854040924288, 0.9316564884007599, 0.528376469194335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 82}], {
             RGBColor[
             0.38908871359710695`, 0.5114308203756144, 0.9460133666661356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 151}], {
             RGBColor[
             0.35739789501188024`, 0.48398182614394664`, 0.9439940557289754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 157}], {
             RGBColor[
             0.43410205704708005`, 0.5499866920911975, 0.9490010571312653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 171}], {
             RGBColor[
             0.3360864294513485, 0.46223759897173367`, 0.9427563991656658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 182}], {
             RGBColor[
             0.34352729206089855`, 0.4700584173523088, 0.9431801452835099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 253}], {
             RGBColor[
             0.3703380254209453, 0.4951899167144135, 0.9448185893961331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 105}], {
             RGBColor[
             0.46633814789011974`, 0.5766565671437895, 0.9514008797073982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 113}], {
             RGBColor[
             0.6559239156864949, 0.7291861264524664, 0.9676704388099608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 148}], {
             RGBColor[
             0.5696101053080527, 0.6614741699887192, 0.9592609405218679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 161}], {
             RGBColor[
             0.4733844161827434, 0.5827596905831183, 0.9518498616922337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 168}], {
             RGBColor[
             0.592741338058181, 0.6798274166038522, 0.9613729899467283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 170}], {
             RGBColor[
             0.4801509107444425, 0.5886204880785566, 0.952281016742329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 180}], {
             RGBColor[
             0.4408011041078431, 0.5545376633487222, 0.9497736818591127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 239}], {
             RGBColor[
             0.4199235526672635, 0.5364545776271384, 0.9484433827426128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 251}], {
             RGBColor[
             0.6688240146939028, 0.7392826292624911, 0.9689511985946974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 282}], {
             RGBColor[
             0.5810969797016021, 0.6707307553552915, 0.9602123891284602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 312}], {
             RGBColor[
             0.4891446804627151, 0.5961487131731942, 0.9529264075234798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 326}], {
             RGBColor[
             0.4273612108963405, 0.5428967033575929, 0.9489173037481067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 356}], {
             RGBColor[
             0.5168552955479615, 0.6186454388483807, 0.9551078886503179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[
             0.9751764945744315, 0.9279266287426179, 0.3580657982576656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 107}], {
             RGBColor[
             0.8837394154703582, 0.5082507082788483, 0.23971449523593602`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 131}], {
             RGBColor[
             0.9476245332536402, 0.8250818486193503, 0.3026198784181737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 215}], {
             RGBColor[
             0.8704530936907242, 0.40612621697725415`, 0.22699149849500438`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 297}], {
             RGBColor[
             0.9597109537164616, 0.9397882388587341, 0.661988741969209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 307}], {
             RGBColor[
             0.9790114308840521, 0.9540083964475, 0.6215212155905427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 314}], {
             RGBColor[
             0.9492974340005453, 0.9317668939083206, 0.6707765260947278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 352}], {
             RGBColor[
             0.983468511290683, 0.9548785202107917, 0.47692950075693274`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 85}], {
             RGBColor[
             0.22712666696496037`, 0.35605490601556716`, 0.9362458997286371]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 127}], {
             RGBColor[
             0.21172079285419906`, 0.33986235553632177`, 0.9353685579889777]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 139}], {
             RGBColor[
             0.21205827028800195`, 0.34021706571655375`, 0.9353877768295796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 184}], {
             RGBColor[
             0.2153543932680198, 0.3436814999548199, 0.9355754861571146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 305}], {
             RGBColor[
             0.20792423756527648`, 0.33587193521215575`, 0.9351523497817738]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 325}], {
             RGBColor[
             0.21225679273606501`, 0.3404257253965182, 0.9353990823893092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 86}], {
             RGBColor[
             0.28863048877409425`, 0.42069932230449786`, 0.9397484513939167]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 95}], {
             RGBColor[
             0.2792515764807897, 0.4108414908268496, 0.9392143362136705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 129}], {
             RGBColor[
             0.25720454661950837`, 0.38766866458021304`, 0.9379587904787283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 151}], {
             RGBColor[
             0.29628007015479707`, 0.4280840429902235, 0.9402080838641316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 178}], {
             RGBColor[
             0.2603565331566741, 0.3909816022782634, 0.9381382914490737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 229}], {
             RGBColor[
             0.2618103919644219, 0.39250970006517877`, 0.9382210865573835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 249}], {
             RGBColor[
             0.2731469520224531, 0.4044251434655919, 0.9388666868817508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 308}], {
             RGBColor[
             0.26890650081077455`, 0.39996816038198235`, 0.938625199458431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 309}], {
             RGBColor[
             0.27375753584035556`, 0.40506690577145743`, 0.9389014587269024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 319}], {
             RGBColor[
             0.2591541477712746, 0.38971781900257185`, 0.9380698173801449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 334}], {
             RGBColor[
             0.2690618295669699, 0.40013142075315566`, 0.938634045201308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 371}], {
             RGBColor[
             0.27438511411724903`, 0.40572653033123346`, 0.9389371983813526]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 386}], {
             RGBColor[
             0.30804388160308127`, 0.43827326520037213`, 0.9409576635272863]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 74}], {
             RGBColor[
             0.6564460490256175, 0.7292165790501876, 0.9679963956135333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 97}], {
             RGBColor[
             0.46525153460871527`, 0.5764515941781216, 0.9511282282884884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 100}], {
             RGBColor[
             0.4324163535905058, 0.5480114107243323, 0.9490359995890186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 132}], {
             RGBColor[
             0.6437204915353074, 0.7192373735289359, 0.9667380893382732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 140}], {
             RGBColor[
             0.5800718085263902, 0.6695145386144623, 0.9603941834467046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 141}], {
             RGBColor[
             0.42414128450553, 0.540843961799992, 0.9485087195042803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 168}], {
             RGBColor[
             0.5791845558214077, 0.6688214100579597, 0.9603057503889199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 191}], {
             RGBColor[
             0.5835359920161374, 0.6722207850854224, 0.9607394608823273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 216}], {
             RGBColor[
             0.5736600979558795, 0.6645056615859741, 0.959755124057878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 219}], {
             RGBColor[
             0.4677032328653056, 0.5785751319820428, 0.9512844483334466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 220}], {
             RGBColor[
             0.4818265682663484, 0.5902075400149862, 0.9523502989242535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 350}], {
             RGBColor[
             0.4604806861717529, 0.5723193250518395, 0.9508242340447808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 357}], {
             RGBColor[
             0.5819543622257783, 0.6709852038723623, 0.9605818188059951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 394}], {
             RGBColor[
             0.42354328649608, 0.5403260059804602, 0.948470615599907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 75}], {
             RGBColor[
             0.2609941288153654, 0.3916517557414475, 0.9381746015785979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 103}], {
             RGBColor[
             0.3111881460301813, 0.44109703206764383`, 0.9411543384931023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 133}], {
             RGBColor[
             0.28753417910083867`, 0.4195470313278583, 0.9396860181798696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.2579170969731607, 0.3884176001802034, 0.937999369167245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 164}], {
             RGBColor[
             0.26017432145076, 0.3907900862224582, 0.9381279147619799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 227}], {
             RGBColor[
             0.25636607330828476`, 0.3867873759678386, 0.9379110406640643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 234}], {
             RGBColor[
             0.30827476436067847`, 0.438573607296341, 0.9409687003893238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 280}], {
             RGBColor[
             0.2584116720913199, 0.38893742998726233`, 0.9380275344885658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 346}], {
             RGBColor[
             0.3114210735342079, 0.4412987821643549, 0.9411691804276892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 79}], {
             RGBColor[
             0.730962985173496, 0.7893766931257962, 0.9742494771038676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 109}], {
             RGBColor[
             0.932608231427341, 0.9459491066410988, 0.8675350166916449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 120}], {
             RGBColor[
             0.7187491637803132, 0.7794609626924269, 0.9732879603430942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 143}], {
             RGBColor[
             0.7478821300066041, 0.8031124171001021, 0.9755814141619994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 237}], {
             RGBColor[
             0.7247695222504801, 0.7843485609125668, 0.9737619050151656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 286}], {
             RGBColor[
             0.798684946393064, 0.8430713308000524, 0.9804594287308144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 320}], {
             RGBColor[
             0.7905070166194959, 0.8366826699063725, 0.9796443291180839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 321}], {
             RGBColor[
             0.8444532383444727, 0.878825868324395, 0.985021184343525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 343}], {
             RGBColor[
             0.7966602927353739, 0.841489655974727, 0.98025763017568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 382}], {
             RGBColor[
             0.8849504676641144, 0.7666705508963009, 0.612411028914603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 119}], {
             RGBColor[
             0.2341124382405141, 0.36339739454965503`, 0.9366437290682574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 200}], {
             RGBColor[
             0.24919308184682543`, 0.37924810714791846`, 0.937502549411824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 288}], {
             RGBColor[
             0.2363762501862872, 0.36577680443863003`, 0.9367726498095597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 341}], {
             RGBColor[
             0.22465511090045148`, 0.353457143886063, 0.936105148267103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 355}], {
             RGBColor[
             0.2293238377834227, 0.358364271854447, 0.9363710253563257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 374}], {
             RGBColor[
             0.25191511783451104`, 0.3821091395580259, 0.9376575653344313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 375}], {
             RGBColor[
             0.24128592482540645`, 0.37093718377569584`, 0.9370522485170447]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 379}], {
             RGBColor[
             0.22434193474233927`, 0.3531279758873717, 0.9360873133482011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 393}], {
             RGBColor[
             0.22527325394479547`, 0.3541068514182011, 0.9361403505990177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 399}], {
             RGBColor[
             0.23130276285488832`, 0.3604442475756538, 0.9364837222115884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 85}], {
             RGBColor[
             0.24221172142071856`, 0.3719102546962633, 0.9371049712635544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 96}], {
             RGBColor[
             0.26501373249139615`, 0.3958766140625488, 0.9384035120614771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 110}], {
             RGBColor[
             0.24934696023893294`, 0.3794098430944771, 0.9375113125586119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 115}], {
             RGBColor[
             0.24086103809529086`, 0.3704906008829697, 0.9370280518463283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 184}], {
             RGBColor[
             0.230439447723778, 0.35953684863551605`, 0.9364345576920319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 188}], {
             RGBColor[
             0.2551009475473486, 0.3854576485794885, 0.9378389936235647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 195}], {
             RGBColor[
             0.2444053413712617, 0.37421588834782205`, 0.937229894674568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 203}], {
             RGBColor[
             0.2672567761777972, 0.39823419519414005`, 0.9385312500811318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 206}], {
             RGBColor[
             0.23733902327111464`, 0.366788739994123, 0.9368274783124455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 208}], {
             RGBColor[
             0.23810134733460236`, 0.3675899909189858, 0.9368708915401036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 258}], {
             RGBColor[
             0.2480246190771097, 0.3780199786921288, 0.9374360071856744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 284}], {
             RGBColor[
             0.24355703331110456`, 0.3733242627907594, 0.9371815847855014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 348}], {
             RGBColor[
             0.2530355996274438, 0.3832868369650472, 0.9377213751149346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 369}], {
             RGBColor[
             0.2502849628040927, 0.38039574326325765`, 0.9375647304170474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 392}], {
             RGBColor[
             0.24553259442115521`, 0.3754007027752315, 0.9372940900681379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 132}], {
             RGBColor[
             0.8119479189165777, 0.8530570556731545, 0.981880980170774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 140}], {
             RGBColor[
             0.7482992359076605, 0.8033342207586809, 0.9755370742792053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 191}], {
             RGBColor[
             0.7517634193974077, 0.8060404672296411, 0.9758823517148281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 198}], {
             RGBColor[
             0.8255815527613636, 0.8637603366303892, 0.9832258995793732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 216}], {
             RGBColor[
             0.7418875253371497, 0.7983253437301927, 0.9748980148903788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 219}], {
             RGBColor[
             0.6359306602465759, 0.7123948141262615, 0.9664273391659474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 220}], {
             RGBColor[
             0.6500539956476187, 0.724027222159205, 0.9674931897567542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 224}], {
             RGBColor[
             0.9001674923644503, 0.8962994775971298, 0.6715446357629462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 302}], {
             RGBColor[
             0.9059752552459537, 0.9158904255240137, 0.6941066978535942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 311}], {
             RGBColor[
             0.6720237576353845, 0.741863264667372, 0.9692227298983209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 323}], {
             RGBColor[
             0.8274418605794372, 0.8652436955878107, 0.9834033373997775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 340}], {
             RGBColor[
             0.9092258023331339, 0.9260683158029884, 0.7736525641500547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 357}], {
             RGBColor[
             0.7501817896070486, 0.8048048860165811, 0.9757247096384958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 89}], {
             RGBColor[
             0.23138047401831524`, 0.3605259269355878, 0.9364881477473821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 133}], {
             RGBColor[
             0.27071817278007254`, 0.4018723424883518, 0.9387283714969541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 145}], {
             RGBColor[
             0.24110109065239455`, 0.37074291134069687`, 0.9370417224843294]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.24457568603401603`, 0.37439493138885227`, 0.9372395955511095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 164}], {
             RGBColor[
             0.2433583151299939, 0.3731153973829517, 0.9371702680790643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 169}], {
             RGBColor[
             0.2324382955275915, 0.3616377644115946, 0.9365483891174288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 209}], {
             RGBColor[
             0.24810555583118551`, 0.37810504835234904`, 0.9374406164140838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 227}], {
             RGBColor[
             0.2395500669875186, 0.36911268712833206`, 0.9369533939811485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 280}], {
             RGBColor[
             0.24159566577055375`, 0.3712627411477558, 0.9370698878056503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 315}], {
             RGBColor[
             0.24372617436870905`, 0.3735020407664642, 0.9371912171185102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[
             0.8759209864283702, 0.49974066253069205`, 0.2169421480887627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 109}], {
             RGBColor[
             0.895995107244091, 0.5718363033485547, 0.3775584455597878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 138}], {
             RGBColor[
             0.8377439161121089, 0.2911218554929793, 0.18377692273559879`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 144}], {
             RGBColor[
             0.8574423259589508, 0.4215266069305636, 0.20181760551077696`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 207}], {
             RGBColor[
             0.877914896729474, 0.5076458524433486, 0.21854649512012086`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 233}], {
             RGBColor[
             0.8371157015332652, 0.2862931229546034, 0.18317534374543126`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 242}], {
             RGBColor[
             0.8707452372835323, 0.4792205418875693, 0.2127776188363791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 257}], {
             RGBColor[
             0.8388320138772645, 0.2994854517234461, 0.18481888638434243`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 317}], {
             RGBColor[
             0.8948386450291879, 0.5713580765029691, 0.3967240172890074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 358}], {
             RGBColor[
             0.8874885148347537, 0.5431153483189393, 0.239200479315374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 366}], {
             RGBColor[
             0.8650564392084171, 0.45610051687506004`, 0.2081710082451261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 382}], {
             RGBColor[
             0.8642232647352734, 0.4523172661853562, 0.20747578704175976`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 78}], {
             RGBColor[
             0.83768433439168, 0.5040167521688288, 0.45299767230427423`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 102}], {
             RGBColor[
             0.8226530582708597, 0.3884797771570075, 0.43860370531557835`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 111}], {
             RGBColor[
             0.8517216279012312, 0.6939386797204187, 0.6001134200588495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 160}], {
             RGBColor[
             0.829440089196826, 0.4406478709499005, 0.44510297379513875`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 166}], {
             RGBColor[
             0.8263011039573982, 0.41652025488755623`, 0.44209707798488607`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 185}], {
             RGBColor[
             0.8255820238084367, 0.4109930897597075, 0.44140848602215565`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 370}], {
             RGBColor[
             0.8302908639224114, 0.8675154135193626, 0.9836750778819656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 389}], {
             RGBColor[
             0.5042266153181847, 0.5861702959978048, 0.9585484769989704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 400}], {
             RGBColor[
             0.6094880057982189, 0.6893301781287484, 0.9648167092401694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 102}], {
             RGBColor[
             0.8343283115240573, 0.26486802190174086`, 0.180506135924707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 144}], {
             RGBColor[
             0.8540420017067264, 0.3953902246963783, 0.1985614511667299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 160}], {
             RGBColor[
             0.8377218269870405, 0.2909520687981873, 0.18375577016448721`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 185}], {
             RGBColor[
             0.8357927942928458, 0.27612467820309083`, 0.1819085262779956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 207}], {
             RGBColor[
             0.8745145724772496, 0.48150947020916335`, 0.2152903407760738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 213}], {
             RGBColor[
             0.8648853376422582, 0.4433327628407137, 0.2075424324006481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 230}], {
             RGBColor[
             0.8841817106508366, 0.517294431234711, 0.23630763277691794`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 247}], {
             RGBColor[
             0.8635651462614512, 0.4380986439435127, 0.20648017542677632`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 289}], {
             RGBColor[
             0.8604804024531523, 0.4246254987591992, 0.2039338105691914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 370}], {
             RGBColor[
             0.8383015076692176, 0.504508869387615, 0.4530565388424428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 391}], {
             RGBColor[
             0.8346928964706893, 0.26767038156369644`, 0.18085526288134157`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 400}], {
             RGBColor[
             0.6910996022530893, 0.3857187124605388, 0.44048429308124526`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 109}], {
             RGBColor[
             0.79245120355282, 0.8352543310125031, 0.854215095221335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 120}], {
             RGBColor[
             0.5785921359057922, 0.6687661870638313, 0.9599680388727843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 136}], {
             RGBColor[
             0.6046940354323059, 0.6899568849766287, 0.9620228760179198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 237}], {
             RGBColor[
             0.5846124943759591, 0.6736537852839712, 0.9604419835448554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 246}], {
             RGBColor[
             0.5173044068287108, 0.618751689159956, 0.9552146295473145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 254}], {
             RGBColor[
             0.5301586737259505, 0.6294457205636295, 0.9561551793123693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 286}], {
             RGBColor[
             0.658527918518543, 0.7323765551714567, 0.9671395072605043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 320}], {
             RGBColor[
             0.6503499887449748, 0.725987894277777, 0.9663244076477739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 343}], {
             RGBColor[
             0.6565032648608529, 0.7307948803461315, 0.9669377087053699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 349}], {
             RGBColor[
             0.518092548976322, 0.6194343382750406, 0.9552648492680336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 87}], {
             RGBColor[
             0.3122775575094636, 0.4431804871474425, 0.9411820189118731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 96}], {
             RGBColor[
             0.31066394327551555`, 0.4414844762785116, 0.9410901259683782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 110}], {
             RGBColor[
             0.29499717102305234`, 0.4250177053104399, 0.9401979264655129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 146}], {
             RGBColor[
             0.4348738177323767, 0.548860724677587, 0.9495460387678236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 154}], {
             RGBColor[
             0.38228721374237734`, 0.5055397030547701, 0.9455799811097223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 159}], {
             RGBColor[
             0.3329254963503931, 0.4627850644418876, 0.9424346961263579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 167}], {
             RGBColor[
             0.30898293281547473`, 0.43971762770278966`, 0.9409943949095109]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 192}], {
             RGBColor[
             0.3394530711598287, 0.46843892165637124`, 0.9428506274211075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 201}], {
             RGBColor[
             0.30542134246892777`, 0.4359741704306982, 0.9407915676081757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 203}], {
             RGBColor[
             0.31290698696191654`, 0.4438420574101029, 0.9412178639880329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 228}], {
             RGBColor[
             0.35113678778418134`, 0.4785587697557132, 0.9435951035129062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 243}], {
             RGBColor[
             0.3113941751763021, 0.44225199630561496`, 0.9411317115948465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 332}], {
             RGBColor[
             0.4308190028061351, 0.5455688432531333, 0.9492268288835535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 348}], {
             RGBColor[
             0.2986858104115632, 0.42889469918101, 0.9404079890218355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 361}], {
             RGBColor[
             0.34502145958500996`, 0.47326197983492335`, 0.9432054402076274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 385}], {
             RGBColor[
             0.4549187217473041, 0.5651340807695402, 0.9511240470387816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 89}], {
             RGBColor[
             0.21914913629591037`, 0.3476700154777373, 0.9357915911587338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 163}], {
             RGBColor[
             0.23234434831161116`, 0.36153901993100174`, 0.9365430389624612]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 169}], {
             RGBColor[
             0.22020695780518662`, 0.3487818529537441, 0.9358518325287805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 209}], {
             RGBColor[
             0.23587421810878062`, 0.36524913689449845`, 0.9367440598254355]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 227}], {
             RGBColor[
             0.2273187292651137, 0.35625677567048153`, 0.9362568373925002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 240}], {
             RGBColor[
             0.22946097871463872`, 0.3585084156683923, 0.9363788353294766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 245}], {
             RGBColor[
             0.22480714766170556`, 0.3536169441618284, 0.9361138065357382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 248}], {
             RGBColor[
             0.21796166804011632`, 0.3464219110510618, 0.9357239665982682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 292}], {
             RGBColor[
             0.21536706305033604`, 0.3436948166993449, 0.9355762076824743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 304}], {
             RGBColor[
             0.21940694053557647`, 0.34794098407935925`, 0.9358062727287957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 315}], {
             RGBColor[
             0.23149483664630416`, 0.3606461293086136, 0.9364946605298619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 329}], {
             RGBColor[
             0.22742713619850993`, 0.35637071823087746`, 0.9362630110069835]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 353}], {
             RGBColor[
             0.2150475477536689, 0.34335898586410785`, 0.9355580117590097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 378}], {
             RGBColor[
             0.21412094136701804`, 0.3423850638014996, 0.9355052428960813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 151}], {
             RGBColor[
             0.34752633634939933`, 0.4754315781894705, 0.9433650487400788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 157}], {
             RGBColor[
             0.4242304983845992, 0.5414364441367214, 0.9483720501423687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 171}], {
             RGBColor[
             0.32621487078886763`, 0.45368735101725755`, 0.9421273921767691]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 182}], {
             RGBColor[
             0.3336557333984177, 0.4615081693978327, 0.9425511382946132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 253}], {
             RGBColor[
             0.3604664667584644, 0.48663966875993736`, 0.9441895824072364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 108}], {
             RGBColor[
             0.3602253738682746, 0.48643084621613597`, 0.9441742201814636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 120}], {
             RGBColor[
             0.45962999176153224`, 0.5694602774020465, 0.9513564039568587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 125}], {
             RGBColor[
             0.315433813888692, 0.4447906722692076, 0.9414242734794431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 179}], {
             RGBColor[
             0.3112624132414147, 0.4404062657068423, 0.9411867183836149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 196}], {
             RGBColor[
             0.32540289254677246`, 0.4552688060149441, 0.9419919977610904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 231}], {
             RGBColor[
             0.3307828964588674, 0.4609235312385056, 0.9422983810248817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 237}], {
             RGBColor[
             0.4656503502316991, 0.5743478756221865, 0.9518303486289299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 246}], {
             RGBColor[
             0.39834226268445083`, 0.5194457794981713, 0.946602994631389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 254}], {
             RGBColor[
             0.4111965295816905, 0.5301398109018447, 0.9475435443964437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 303}], {
             RGBColor[
             0.32124670467921895`, 0.4509003890486145, 0.9417553090105623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 313}], {
             RGBColor[
             0.31784501109874064`, 0.44732499341570175`, 0.9415615875935087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 344}], {
             RGBColor[
             0.33675515918736176`, 0.4661021259068189, 0.9426787188558917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 349}], {
             RGBColor[
             0.3991304048320619, 0.5201284286132558, 0.946653214352108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.44236640792617826`, 0.5377470693075241, 0.9524063925246276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 152}], {
             RGBColor[
             0.18127159018880934`, 0.30785831294404253`, 0.9336345209427424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 156}], {
             RGBColor[
             0.18244327672263497`, 0.3090898297803102, 0.9337012467574888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 175}], {
             RGBColor[
             0.1789295778879611, 0.3053967095236947, 0.9335011468069058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 204}], {
             RGBColor[
             0.17892700714738574`, 0.30539400751235557`, 0.933501000407033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 256}], {
             RGBColor[
             0.20211768989058865`, 0.32976888544967253`, 0.9348216754817178]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 261}], {
             RGBColor[
             0.17918769193352976`, 0.30566800375096304`, 0.9335158460199553]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 264}], {
             RGBColor[
             0.18447901438019912`, 0.31122951913163255`, 0.9338171790054831]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 317}], {
             RGBColor[
             0.5847770387283635, 0.6478930395078799, 0.8692491754054186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 333}], {
             RGBColor[
             0.18724373492288626`, 0.3141354157154036, 0.9339746257503516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 381}], {
             RGBColor[
             0.5860370216699882, 0.6484140748343261, 0.8483679973313716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 389}], {
             RGBColor[
             0.1790075704625178, 0.3054786846645686, 0.933505588368647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 96}], {
             RGBColor[
             0.2641094772748117, 0.3949261844968264, 0.9383520160646184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 110}], {
             RGBColor[
             0.2484427050223485, 0.37845941352875473`, 0.9374598165617531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 115}], {
             RGBColor[
             0.2399567828787064, 0.36954017131724737`, 0.9369765558494695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 139}], {
             RGBColor[
             0.2262390695271757, 0.3551219848315275, 0.9361953523676381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 167}], {
             RGBColor[
             0.2624284668147709, 0.39315933592110447`, 0.9382562850057511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 184}], {
             RGBColor[
             0.22953519250719354`, 0.35858641906979366`, 0.9363830616951732]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 188}], {
             RGBColor[
             0.25419669233076414`, 0.38450721901376617`, 0.937787497626706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 203}], {
             RGBColor[
             0.2663525209612127, 0.3972837656284177, 0.9384797540842731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 258}], {
             RGBColor[
             0.24712036386052527`, 0.3770695491264064, 0.9373845111888157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 284}], {
             RGBColor[
             0.24265277809452013`, 0.37237383322503703`, 0.9371300887886426]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 325}], {
             RGBColor[
             0.22643759197523877`, 0.355330644511492, 0.9362066579273677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 348}], {
             RGBColor[
             0.2521313444108594, 0.3823364073993248, 0.9376698791180758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 351}], {
             RGBColor[
             0.24352597864269326`, 0.37329162236527946`, 0.9371798162680766]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 369}], {
             RGBColor[
             0.24938070758750824`, 0.3794453136975352, 0.9375132344201885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 95}], {
             RGBColor[
             0.2911574427094625, 0.42335531110870317`, 0.9398923576822427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 151}], {
             RGBColor[
             0.30818593638346986`, 0.44059786327207706`, 0.9408861053327038]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[
             0.27226239938534696`, 0.40349542256011695`, 0.9388163129176459]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 229}], {
             RGBColor[
             0.27371625819309475`, 0.4050235203470323, 0.9388991080259558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 249}], {
             RGBColor[
             0.2850528182511259, 0.41693896374744543`, 0.939544708350323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 308}], {
             RGBColor[
             0.28081236703944734`, 0.4124819806638359, 0.9393032209270034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 309}], {
             RGBColor[
             0.28566340206902835`, 0.417580726053311, 0.9395794801954747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 334}], {
             RGBColor[
             0.28096769579564274`, 0.4126452410350092, 0.9393120666698803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 371}], {
             RGBColor[
             0.2862909803459218, 0.418240350613087, 0.9396152198499249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 386}], {
             RGBColor[
             0.31994974783175406`, 0.4507870854822257, 0.9416356849958585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 110}], {
             RGBColor[
             0.27285833032697415`, 0.4041217837639711, 0.9388502503031707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 134}], {
             RGBColor[
             0.26223279186396886`, 0.39295366914130303`, 0.9382451416067781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 159}], {
             RGBColor[
             0.3107866556543149, 0.4418891428954188, 0.9410870199640158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 167}], {
             RGBColor[
             0.28684409211939654`, 0.41882170615632086`, 0.9396467187471687]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 192}], {
             RGBColor[
             0.3173142304637505, 0.44754300010990244`, 0.9415029512587653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 201}], {
             RGBColor[
             0.2832825017728496, 0.4150782488842294, 0.9394438914458336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 210}], {
             RGBColor[
             0.2950312133683537, 0.42742688968244336`, 0.9401129631905363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 228}], {
             RGBColor[
             0.32899794708810315`, 0.4576628482092444, 0.9422474273505641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 236}], {
             RGBColor[
             0.2703304585010046, 0.4014648301985463, 0.938706291742333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 243}], {
             RGBColor[
             0.2892553344802239, 0.4213560747591461, 0.9397840354325044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 263}], {
             RGBColor[
             0.2761111635451054, 0.407540717717765, 0.9390354943428079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 348}], {
             RGBColor[
             0.27654696971548504`, 0.4079987776345412, 0.9390603128594934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 351}], {
             RGBColor[
             0.2679416039473189, 0.3989539926004958, 0.9385702500094941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[
             0.8934147061054667, 0.915612925432826, 0.8952711863200087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 132}], {
             RGBColor[
             0.8947680641910523, 0.9166701790551881, 0.8954060764061295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 140}], {
             RGBColor[
             0.8311193811821351, 0.8669473441407145, 0.8890621705145608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 168}], {
             RGBColor[
             0.8302321284771527, 0.8662542155842119, 0.8889737374567761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 282}], {
             RGBColor[
             0.8185877701205739, 0.8571575543356513, 0.887813136638508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 283}], {
             RGBColor[
             0.9496145330722283, 0.8334245259791293, 0.5278793972462171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 357}], {
             RGBColor[
             0.8330019348815232, 0.8684180093986145, 0.8892498058738514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 163}], {
             RGBColor[
             0.23177803755773202`, 0.36094379142249916`, 0.9365107884028094]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 164}], {
             RGBColor[
             0.2305606666537099, 0.3596642574165986, 0.9364414609307642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 169}], {
             RGBColor[
             0.2196406470513075, 0.3481866244452415, 0.9358195819691286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 209}], {
             RGBColor[
             0.23530790735490154`, 0.3646539083859959, 0.9367118092657838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 227}], {
             RGBColor[
             0.22675241851123462`, 0.35566154716197895`, 0.9362245868328485]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 245}], {
             RGBColor[
             0.22424083690782642`, 0.3530217156533258, 0.9360815559760864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.22879801729426974`, 0.3578116011814027, 0.9363410806573501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 292}], {
             RGBColor[
             0.21480075229645693`, 0.3430995881908423, 0.9355439571228226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 304}], {
             RGBColor[
             0.21884062978169738`, 0.3473457555708567, 0.9357740221691438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 315}], {
             RGBColor[
             0.23092852589242507`, 0.36005090080011104`, 0.93646240997021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 329}], {
             RGBColor[
             0.22686082544463082`, 0.3557754897223749, 0.9362307604473317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 353}], {
             RGBColor[
             0.21448123699978983`, 0.34276375735560527`, 0.9355257611993579]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 378}], {
             RGBColor[
             0.2135546306131389, 0.341789835292997, 0.9354729923364294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 138}], {
             RGBColor[
             0.7814971847930072, 0.3564889751708319, 0.4345413056360933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 142}], {
             RGBColor[
             0.7829912495158903, 0.3679730113342469, 0.4359720237020308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 152}], {
             RGBColor[
             0.4447109838202162, 0.5402113672268555, 0.9525399126533038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 156}], {
             RGBColor[
             0.4458826703540418, 0.5414428840631231, 0.9526066384680504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 175}], {
             RGBColor[
             0.44236897151936794`, 0.5377497638065076, 0.9524065385174674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 202}], {
             RGBColor[
             0.8061616844201898, 0.5460711273580099, 0.45816005833365137`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 242}], {
             RGBColor[
             0.8120763207412868, 0.7420397918675932, 0.6122349694370377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 256}], {
             RGBColor[
             0.46555708352199543`, 0.5621219397324855, 0.9537270671922793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[
             0.7836733803233185, 0.3732161676317655, 0.4366252329335806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 261}], {
             RGBColor[
             0.4426270855649366, 0.538021058033776, 0.9524212377305169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 264}], {
             RGBColor[
             0.44791840801160593`, 0.5435825734144455, 0.9527225707160447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 268}], {
             RGBColor[
             0.7801479338525283, 0.346118041196779, 0.4332492614117297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 317}], {
             RGBColor[
             0.8482164323597703, 0.8802460937906929, 0.8881545671159801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 333}], {
             RGBColor[
             0.4506831285542931, 0.5464884699982167, 0.9528800174609131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 381}], {
             RGBColor[
             0.849476415301395, 0.8807671291171392, 0.8672733890419332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 141}], {
             RGBColor[
             0.3113425799408942, 0.43982647528346147`, 0.9412155979078848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 150}], {
             RGBColor[
             0.2666109948635128, 0.3975554380879269, 0.9384944737906311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 186}], {
             RGBColor[
             0.2555444422624831, 0.38592378964428387`, 0.9378642499915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 189}], {
             RGBColor[
             0.28158397795101814`, 0.4132929926548542, 0.9393471630269211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 190}], {
             RGBColor[
             0.25186209923856306`, 0.38205341365211143`, 0.9376545460038261]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 226}], {
             RGBColor[
             0.25062761976227643`, 0.38075589745201466`, 0.9375842442239002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 241}], {
             RGBColor[
             0.2767915804260243, 0.40825587900053273`, 0.9390742430775896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 255}], {
             RGBColor[
             0.26154809523840944`, 0.39223400957556664`, 0.9382061491468703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 266}], {
             RGBColor[
             0.25880957199136756`, 0.38935564801052325`, 0.9380501942992334]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 273}], {
             RGBColor[
             0.26902930475390907`, 0.40009723511243644`, 0.9386321929613204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 365}], {
             RGBColor[
             0.259430965008946, 0.3900087714705911, 0.9380855817123159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 114}], {
             RGBColor[
             0.3082708613262549, 0.43948126919774927`, 0.9409350939621447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 153}], {
             RGBColor[
             0.30254730129756563`, 0.4345238091753902, 0.940570393778262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 161}], {
             RGBColor[
             0.35955024405905767`, 0.48389689314418627`, 0.9442025708853012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 188}], {
             RGBColor[
             0.27737488016395806`, 0.40886896400844064`, 0.9391074611347503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 195}], {
             RGBColor[
             0.26667927398787117`, 0.3976272037767742, 0.9384983621857534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 258}], {
             RGBColor[
             0.2702985516937192, 0.40143129412108086`, 0.93870447469686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 278}], {
             RGBColor[
             0.2700397327532974, 0.4011592590046289, 0.9386897353410912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 284}], {
             RGBColor[
             0.26583096592771405`, 0.3967355782197115, 0.9384500522966869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 327}], {
             RGBColor[
             0.3031279877877182, 0.4350267706270088, 0.9406073946079336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 337}], {
             RGBColor[
             0.2862035870447653, 0.41814849471251614`, 0.9396102429307109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 354}], {
             RGBColor[
             0.2837186388686095, 0.41553665662456213`, 0.9394687288082302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 392}], {
             RGBColor[
             0.26780652703776464`, 0.39881201820418366`, 0.9385625575793235]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 94}], {
             RGBColor[
             0.2526810398598759, 0.3829141721689455, 0.9377011834606958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 119}], {
             RGBColor[
             0.24286823945996167`, 0.3726002967811557, 0.9371423589946579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 128}], {
             RGBColor[
             0.2857256322546389, 0.41603117628641406`, 0.9396421556226617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 225}], {
             RGBColor[
             0.25117310830966183`, 0.38132924050128825`, 0.9376153089896959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 296}], {
             RGBColor[
             0.27337982614775685`, 0.40466990893635857`, 0.9388799487186803]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 301}], {
             RGBColor[
             0.25102800874557624`, 0.38117673165959054`, 0.9376070457841768]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 316}], {
             RGBColor[
             0.2497588091651779, 0.37984272242869066`, 0.9375347667456857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 324}], {
             RGBColor[
             0.26259788296436154`, 0.3933374030359285, 0.9382659330048415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 355}], {
             RGBColor[
             0.23807963900287032`, 0.36756717408594775`, 0.936869655282726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 380}], {
             RGBColor[
             0.25536438822798396`, 0.38573454143794017`, 0.9378539961806014]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 383}], {
             RGBColor[
             0.2627372188358315, 0.39348385387124796`, 0.9382738679765928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 390}], {
             RGBColor[
             0.2557686929307827, 0.3861594913149804, 0.9378770207353105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 119}], {
             RGBColor[
             0.25031116778183593`, 0.38042328635635736`, 0.9375662227517629]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 128}], {
             RGBColor[
             0.29316856057651314`, 0.42385416586161573`, 0.9400660193797667]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 177}], {
             RGBColor[
             0.29101623446385616`, 0.4219899291618881, 0.9399288750630955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 200}], {
             RGBColor[
             0.26539181138814727`, 0.3962739989546208, 0.9384250430953294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 225}], {
             RGBColor[
             0.2586160366315361, 0.3891522300764899, 0.9380391727468009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 288}], {
             RGBColor[
             0.25257497972760906`, 0.38280269624533236`, 0.9376951434930652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 296}], {
             RGBColor[
             0.2808227544696311, 0.4124928985115602, 0.9393038124757853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 316}], {
             RGBColor[
             0.25720173748705216`, 0.38766571200389227`, 0.9379586305027907]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 324}], {
             RGBColor[
             0.2700408112862358, 0.4011603926111301, 0.9386897967619465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 355}], {
             RGBColor[
             0.2455225673247446, 0.37539016366114936`, 0.937293519039831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 375}], {
             RGBColor[
             0.25748465436672835`, 0.3879630755823982, 0.9379747422005502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 380}], {
             RGBColor[
             0.2628073165498582, 0.39355753101314184`, 0.9382778599377064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 383}], {
             RGBColor[
             0.2701801471577058, 0.4013068434464496, 0.9386977317336979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 390}], {
             RGBColor[
             0.26321162125265696`, 0.393982480890182, 0.9383008844924156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 129}], {
             RGBColor[
             0.2597315005548766, 0.39032465338441835`, 0.9381026967670542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 151}], {
             RGBColor[
             0.2988070240901653, 0.4307400317944288, 0.9403519901524575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 178}], {
             RGBColor[
             0.2628834870920424, 0.39363759108246865`, 0.9382821977373995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 229}], {
             RGBColor[
             0.2643373458997902, 0.3951656888693841, 0.9383649928457094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 249}], {
             RGBColor[
             0.2756739059578213, 0.4070811322697972, 0.9390105931700766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 270}], {
             RGBColor[
             0.26568283896088996`, 0.3965798873857872, 0.9384416166850604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 308}], {
             RGBColor[
             0.2714334547461428, 0.4026241491861876, 0.9387691057467569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 309}], {
             RGBColor[
             0.2762844897757238, 0.4077228945756627, 0.9390453650152284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 334}], {
             RGBColor[
             0.27158878350233817`, 0.4027874095573609, 0.9387779514896339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 371}], {
             RGBColor[
             0.27691206805261726`, 0.40838251913543877`, 0.9390811046696785]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 386}], {
             RGBColor[
             0.3105708355384495, 0.4409292540045774, 0.9411015698156122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 110}], {
             RGBColor[
             0.2712447160930261, 0.4024257728950402, 0.9387583573596757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 114}], {
             RGBColor[
             0.3078946845637386, 0.4390858835693603, 0.940913671252023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 115}], {
             RGBColor[
             0.262758793949384, 0.3935065306835328, 0.9382750966473921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 153}], {
             RGBColor[
             0.3021711245350493, 0.4341284235470012, 0.9405489710681403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 154}], {
             RGBColor[
             0.3585347588123511, 0.48294777063937044`, 0.9441404120038852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 167}], {
             RGBColor[
             0.28523047788544853`, 0.41712569528738996`, 0.9395548258036737]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 188}], {
             RGBColor[
             0.2769987034014417, 0.4084735783800516, 0.9390860384246287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 192}], {
             RGBColor[
             0.3157006162298024, 0.44584698924097155`, 0.9414110583152703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 203}], {
             RGBColor[
             0.28915453203189034`, 0.42125012499470316`, 0.9397782948821958]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 228}], {
             RGBColor[
             0.3273843328541551, 0.4559668373403135, 0.9421555344070691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 243}], {
             RGBColor[
             0.2876417202462759, 0.4196600638902152, 0.9396921424890095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 258}], {
             RGBColor[
             0.26992237493120286`, 0.4010359084926919, 0.9386830519867384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 284}], {
             RGBColor[
             0.2654547891651977, 0.3963401925913225, 0.9384286295865651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 348}], {
             RGBColor[
             0.27493335548153697`, 0.4063027667656103, 0.9389684199159984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 361}], {
             RGBColor[
             0.32126900465498376`, 0.45067004741952366`, 0.9417658711017902]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 369}], {
             RGBColor[
             0.27218271865818583`, 0.40341167306382075`, 0.9388117752181111]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 100}], {
             RGBColor[
             0.4094492665548738, 0.5290661079964851, 0.9473107230964745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 105}], {
             RGBColor[
             0.42981427861771465`, 0.5467052578700499, 0.9486083636570456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 112}], {
             RGBColor[
             0.38560280932821134`, 0.5084115053045399, 0.9457912479285857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 132}], {
             RGBColor[
             0.6207534044996754, 0.7002920708010887, 0.965012812845729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 140}], {
             RGBColor[
             0.5571047214907582, 0.6505692358866151, 0.9586689069541604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 141}], {
             RGBColor[
             0.401174197469898, 0.5218986590721447, 0.9467834430117361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 168}], {
             RGBColor[
             0.5562174687857758, 0.6498761073301125, 0.9585804738963757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 180}], {
             RGBColor[
             0.40427723483543804`, 0.5245863540749827, 0.9469811658087601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 220}], {
             RGBColor[
             0.4588594812307164, 0.571262237287139, 0.9506250224317093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 282}], {
             RGBColor[
             0.5445731104291971, 0.6407794460815519, 0.9574198730781076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 350}], {
             RGBColor[
             0.437513599136121, 0.5533740223239922, 0.9490989575522366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 357}], {
             RGBColor[
             0.5589872751901463, 0.652039901144515, 0.958856542313451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 394}], {
             RGBColor[
             0.40057619946044803`, 0.521380703252613, 0.9467453391073628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 107}], {
             RGBColor[
             0.8853351538424127, 0.5136335085049757, 0.24591363748146172`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 131}], {
             RGBColor[
             0.9500181408117219, 0.8331560489585412, 0.3119185917864623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 215}], {
             RGBColor[
             0.8720488320627787, 0.4115090172033815, 0.2331906407405301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 283}], {
             RGBColor[
             0.9432427006605664, 0.8062936865407971, 0.3064669136008217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 297}], {
             RGBColor[
             0.9621045612745434, 0.9478624391979251, 0.6712874553374975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 307}], {
             RGBColor[
             0.9814050384421338, 0.9620825967866911, 0.6308199289588313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 352}], {
             RGBColor[
             0.9858621188487648, 0.9629527205499828, 0.4862282141252213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 123}], {
             RGBColor[
             0.9762118677425246, 0.9817794304286422, 0.9251512823600752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 174}], {
             RGBColor[
             0.8533664925541351, 0.885559755956836, 0.9477463395066474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 187}], {
             RGBColor[
             0.9110307205751575, 0.9308010667922535, 0.953442401298972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 193}], {
             RGBColor[
             0.9002336063428361, 0.9221917409832586, 0.9524125629047955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[
             0.9440956875300477, 0.9571661739174645, 0.9565961673645738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 232}], {
             RGBColor[
             0.7518421224806613, 0.804458883314896, 0.9388506680687247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 235}], {
             RGBColor[
             0.8591106393434069, 0.8900471270857477, 0.9483188623764983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 275}], {
             RGBColor[
             0.9851141209349312, 0.987104803716967, 0.8512424005775606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 279}], {
             RGBColor[
             0.9618886205302903, 0.9027170726846294, 0.5985175369470697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 281}], {
             RGBColor[
             0.8050608246814849, 0.8476642232367373, 0.943040239252503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 306}], {
             RGBColor[
             0.9742518584397497, 0.947471002545973, 0.6306628392778444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 338}], {
             RGBColor[
             0.9862079875593082, 0.9866999578573392, 0.7708056942036536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 384}], {
             RGBColor[
             0.863277719993484, 0.893302482160574, 0.9487341980321153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 105}], {
             RGBColor[
             0.3969790975995051, 0.5182650744162607, 0.9465161349575758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 112}], {
             RGBColor[
             0.35276762831000186`, 0.47997132185075075`, 0.9436990192291159]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 141}], {
             RGBColor[
             0.3683390164516885, 0.49345847561835543`, 0.9446912143122663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 168}], {
             RGBColor[
             0.5233822877675662, 0.6214359238763232, 0.9564882451969059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 170}], {
             RGBColor[
             0.4107918604538279, 0.5302289953510277, 0.9473962719925066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 180}], {
             RGBColor[
             0.3714420538172285, 0.49614617062119337`, 0.9448889371092903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 220}], {
             RGBColor[
             0.42602430021250687`, 0.5428220538333498, 0.9485327937322395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 271}], {
             RGBColor[
             0.3417009842764249, 0.4702049097204598, 0.9430004912657755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 273}], {
             RGBColor[
             0.3260257412647034, 0.4537292354473304, 0.9421078093657018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 282}], {
             RGBColor[
             0.5117379294109875, 0.6123392626277626, 0.9553276443786378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 350}], {
             RGBColor[
             0.4046784181179114, 0.524933838870203, 0.9470067288527668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 394}], {
             RGBColor[
             0.3677410184422385, 0.49294051979882375`, 0.944653110407893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 151}], {
             RGBColor[
             0.2883386750076016, 0.41973713317698713`, 0.9397558331587401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 171}], {
             RGBColor[
             0.2670272094470698, 0.3979929060047742, 0.9385181765954305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 182}], {
             RGBColor[
             0.2744680720566198, 0.40581372438534935`, 0.9389419227132746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 244}], {
             RGBColor[
             0.2604390037563816, 0.39106828410749395`, 0.9381429880277227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 253}], {
             RGBColor[
             0.3012788054166666, 0.43094522374745403`, 0.9405803668258977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 270}], {
             RGBColor[
             0.2552144898783262, 0.38557698876834556`, 0.937845459691343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 308}], {
             RGBColor[
             0.26096510566357906`, 0.39162125056874597`, 0.9381729487530396]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 397}], {
             RGBColor[
             0.2550956906132599, 0.3854521232084524, 0.9378386942489454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 160}], {
             RGBColor[
             0.8226905508662201, 0.17541509378636602`, 0.16936180317579133`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 166}], {
             RGBColor[
             0.8211210582465063, 0.16335128575519392`, 0.16785885527066496`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[
             0.8207615181720255, 0.16058770319126955`, 0.16751455928929976`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 213}], {
             RGBColor[
             0.8498540615214377, 0.3277957878288924, 0.19314846541195224`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 224}], {
             RGBColor[
             0.8714185263761622, 0.40940826259323077`, 0.23072477431729355`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 230}], {
             RGBColor[
             0.8691504345300162, 0.40175745622288966`, 0.22191366578822208`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 247}], {
             RGBColor[
             0.8485338701406309, 0.3225616689316914, 0.19208620843808044`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 250}], {
             RGBColor[
             0.8756070959215718, 0.4293539198974725, 0.392331116689075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 289}], {
             RGBColor[
             0.8454491263323318, 0.30908852374737794`, 0.18953984358049555`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 302}], {
             RGBColor[
             0.8752903682971644, 0.4224688945444868, 0.24576614904439226`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 340}], {
             RGBColor[
             0.8774573996886179, 0.42925415473046985`, 0.29879672657536593`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 370}], {
             RGBColor[
             0.8232702315483972, 0.3889718943757936, 0.4386625718537469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 391}], {
             RGBColor[
             0.8196616203498689, 0.15213340655187516`, 0.16646129589264572`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 400}], {
             RGBColor[
             0.6760683261322689, 0.2701817374487175, 0.4260903260925494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 108}], {
             RGBColor[
             0.3560676178251626, 0.48282960690648735`, 0.9439092916429558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 133}], {
             RGBColor[
             0.32091218999488846`, 0.4513176188145481, 0.9417081084114585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 143}], {
             RGBColor[
             0.48460520194471113`, 0.589510492500073, 0.9533849292372562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 223}], {
             RGBColor[
             0.3993166746191169, 0.5202694238127852, 0.9466707039440156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 231}], {
             RGBColor[
             0.3266251404157554, 0.4573222919288569, 0.942033452486374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 234}], {
             RGBColor[
             0.34165277525472826`, 0.4703441947830308, 0.9429907906209125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 290}], {
             RGBColor[
             0.3748499370785241, 0.4990979078169345, 0.9451060844172272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 313}], {
             RGBColor[
             0.31368725505562867`, 0.4437237541060531, 0.9412966590550009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 331}], {
             RGBColor[
             0.39832931347278433`, 0.519434563541872, 0.9466021695190721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 342}], {
             RGBColor[
             0.4739621782432806, 0.580870006396498, 0.9525470714247991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 346}], {
             RGBColor[
             0.3447990844282577, 0.4730693696510448, 0.9431912706592778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 109}], {
             RGBColor[
             0.9639852685830836, 0.8836832833010115, 0.5065761886025747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 138}], {
             RGBColor[
             0.8575199467269797, 0.3583022079987919, 0.19932129168970925`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 144}], {
             RGBColor[
             0.9061560966553733, 0.6582187386740248, 0.24296492852905843`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 205}], {
             RGBColor[
             0.9645712998383063, 0.8839256222853624, 0.49686413410326324`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 207}], {
             RGBColor[
             0.9368649528111581, 0.7873976069432023, 0.2680582629430743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 233}], {
             RGBColor[
             0.8562635175692925, 0.3486447429220402, 0.19811813370937414`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 358}], {
             RGBColor[
             0.9512253799690775, 0.8406018507565884, 0.299039239235954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 366}], {
             RGBColor[
             0.9175772665295729, 0.7100796035907695, 0.25249503263058215`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 382}], {
             RGBColor[
             0.9163275048198573, 0.7044047275562138, 0.25145220082553266`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 112}], {
             RGBColor[
             0.37313264037284266`, 0.49761047172431544`, 0.944996659789687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 113}], {
             RGBColor[
             0.6069298774587211, 0.6884337835985022, 0.9640833346207096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 148}], {
             RGBColor[
             0.520616067080279, 0.620721827134755, 0.9556738363326167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 155}], {
             RGBColor[
             0.3609448647521152, 0.4866656792120809, 0.9442342850410239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 168}], {
             RGBColor[
             0.5437472998304071, 0.6390750737498879, 0.957785885757477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 170}], {
             RGBColor[
             0.4311568725166687, 0.5478681452245924, 0.9486939125530778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 180}], {
             RGBColor[
             0.39180706588006936`, 0.513785320494758, 0.9461865776698615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 239}], {
             RGBColor[
             0.37092951443948974`, 0.4957022347731742, 0.9448562785533615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 271}], {
             RGBColor[
             0.36206599633926584`, 0.4878440595940245, 0.9442981318263466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 282}], {
             RGBColor[
             0.5321029414738284, 0.6299784125013272, 0.956625284939209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 326}], {
             RGBColor[
             0.37836717266856673`, 0.5021443605036287, 0.9453301995588554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 350}], {
             RGBColor[
             0.4250434301807523, 0.5425729887437677, 0.948304369413338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 394}], {
             RGBColor[
             0.38810603050507936`, 0.5105796696723884, 0.9459507509684641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.8756433920758676, 0.5220025985586171, 0.4474818068679641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 173}], {
             RGBColor[
             0.5874312139478495, 0.658182594689114, 0.9541358462016971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 197}], {
             RGBColor[
             0.9686231253627324, 0.9753622711647122, 0.9040752003743098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 204}], {
             RGBColor[
             0.563710908416439, 0.6332510496213667, 0.9527850098927306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 214}], {
             RGBColor[
             0.9661339552698273, 0.9742633398075717, 0.9422105594358144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 215}], {
             RGBColor[
             0.8623570702962337, 0.4198781072570229, 0.43475881012703244`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 295}], {
             RGBColor[
             0.5954410834145789, 0.6666014753537031, 0.9545919964182874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 310}], {
             RGBColor[
             0.5655364837016175, 0.6351698449942476, 0.952888973704525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 345}], {
             RGBColor[
             0.5752211056493675, 0.6453489967018295, 0.953440498597335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 363}], {
             RGBColor[
             0.8911732680650847, 0.632758146065413, 0.46201593553613163`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 131}], {
             RGBColor[
             0.8669671796285517, 0.4450703217561305, 0.20894969092180046`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 197}], {
             RGBColor[
             0.889062264429104, 0.5315053798399363, 0.4021525939271964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 215}], {
             RGBColor[
             0.8325745188075454, 0.25138760256576187`, 0.17882670203874967`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 297}], {
             RGBColor[
             0.8750247932704328, 0.5215412485823864, 0.4485289332891572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 307}], {
             RGBColor[
             0.8878917780488264, 0.5310213536415637, 0.4215505823700465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 352}], {
             RGBColor[
             0.8908631649865804, 0.5316014361504249, 0.3251561058143065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 363}], {
             RGBColor[
             0.8469826176919709, 0.3578276219699569, 0.19245526474329921`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 143}], {
             RGBColor[
             0.49610666284564264`, 0.5994724798522266, 0.954117792155521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 179}], {
             RGBColor[
             0.3186061180992342, 0.4467670137493473, 0.9416546527633719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 196}], {
             RGBColor[
             0.332746597404592, 0.4616295540574491, 0.9424599321408476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 231}], {
             RGBColor[
             0.3381266013166869, 0.4672842792810106, 0.9427663154046388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 234}], {
             RGBColor[
             0.3531542361556598, 0.4803061821351844, 0.9437236535391773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 290}], {
             RGBColor[
             0.3863513979794556, 0.5090598951690881, 0.945838947335492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 313}], {
             RGBColor[
             0.3251887159565602, 0.4536857414582067, 0.9420295219732657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 331}], {
             RGBColor[
             0.40983077437371584`, 0.5293965508940257, 0.9473350324373369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 342}], {
             RGBColor[
             0.48546363914421214`, 0.5908319937486516, 0.9532799343430639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 344}], {
             RGBColor[
             0.3440988640451813, 0.47246287394932385`, 0.9431466532356487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 136}], {
             RGBColor[
             0.8063392816861509, 0.8465292984919313, 0.8553084156056971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 205}], {
             RGBColor[
             0.9946824810618875, 0.9920690835121566, 0.737788580309801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 207}], {
             RGBColor[
             0.9669761340347394, 0.8955410681699965, 0.508982709149612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 233}], {
             RGBColor[
             0.8763376383850133, 0.4207403837399031, 0.35873443118039927`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 286}], {
             RGBColor[
             0.8601731647723879, 0.8889489686867593, 0.8604250468482817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 320}], {
             RGBColor[
             0.8519952349988198, 0.8825603077930796, 0.8596099472355513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 343}], {
             RGBColor[
             0.8581485111146978, 0.8873672938614341, 0.8602232482931473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 358}], {
             RGBColor[
             0.9813365611926588, 0.9487453119833825, 0.5399636854424916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 366}], {
             RGBColor[
             0.9476884477531541, 0.8182230648175637, 0.4934194788371198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 382}], {
             RGBColor[
             0.9464386860434384, 0.8125481887830079, 0.4923766470320703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 115}], {
             RGBColor[
             0.2470920216969208, 0.3770397597154611, 0.9373828971445268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 134}], {
             RGBColor[
             0.24495240537755758`, 0.37479088730430044`, 0.9372610491604179]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 167}], {
             RGBColor[
             0.26956370563298526`, 0.40065892431931827`, 0.9386626263008084]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 192}], {
             RGBColor[
             0.30003384397733923`, 0.42938021827289985`, 0.940518858812405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 203}], {
             RGBColor[
             0.2734877597794271, 0.40478335402663146`, 0.9388860953793305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 243}], {
             RGBColor[
             0.2719749479938126, 0.4031932929221435, 0.9387999429861442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 348}], {
             RGBColor[
             0.25926658322907375`, 0.3898359957975386, 0.9380762204131332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 351}], {
             RGBColor[
             0.25066121746090764`, 0.3807912107634932, 0.9375861575631339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 369}], {
             RGBColor[
             0.2565159464057226, 0.38694490209574905`, 0.9379195757152459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 160}], {
             RGBColor[
             0.8443444384602433, 0.3254221656360573, 0.18945406845122992`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 166}], {
             RGBColor[
             0.8412054532208156, 0.3012945495737131, 0.18644817264097716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.840486373071854, 0.29576738444586437`, 0.18575958067824674`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 197}], {
             RGBColor[
             0.931414792844472, 0.7553582824181725, 0.5263607215030722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[
             0.631844529693345, 0.5164916201579837, 0.581343351224306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 155}], {
             RGBColor[
             0.31673339546261187`, 0.44837192664657105`, 0.9414171693125639]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 170}], {
             RGBColor[
             0.3869454032271654, 0.5095743926590826, 0.9458767968246178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 180}], {
             RGBColor[
             0.34759559659056605`, 0.4754915679292482, 0.9433694619414015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 183}], {
             RGBColor[
             0.2939274002864909, 0.42440137973285763`, 0.9401184016257302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 271}], {
             RGBColor[
             0.3178545270497625, 0.4495503070285146, 0.9414810160978866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 273}], {
             RGBColor[
             0.30217928403804095`, 0.4330746327553852, 0.940588334197813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 326}], {
             RGBColor[
             0.3341557033790634, 0.4638506079381187, 0.9425130838303954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 350}], {
             RGBColor[
             0.380831960891249, 0.5042792361782578, 0.945487253684878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 394}], {
             RGBColor[
             0.34389456121557604`, 0.47228591710687856`, 0.9431336352400042]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 148}], {
             RGBColor[
             0.7102018348766541, 0.7732513864434318, 0.9719433954351793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 168}], {
             RGBColor[
             0.7333330676267822, 0.7916046330585647, 0.9740554448600397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 170}], {
             RGBColor[
             0.6207426403130438, 0.7003977045332692, 0.9649634716556403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 251}], {
             RGBColor[
             0.8094157442625041, 0.8510598457172036, 0.9816336535080088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 282}], {
             RGBColor[
             0.7216887092702036, 0.7825079718100041, 0.9728948440417715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 153}], {
             RGBColor[
             0.32315432075329853`, 0.4543217632532496, 0.9418120854576224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 154}], {
             RGBColor[
             0.3795179550306004, 0.5031411103456188, 0.9454035263933673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 188}], {
             RGBColor[
             0.297981899619691, 0.4286669180863, 0.9403491528141107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 203}], {
             RGBColor[
             0.3101377282501396, 0.4414434647009515, 0.9410414092716778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 222}], {
             RGBColor[
             0.4669023906435984, 0.574712579304436, 0.9521089968254883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 258}], {
             RGBColor[
             0.29090557114945215`, 0.42122924819894025`, 0.9399461663762204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 312}], {
             RGBColor[
             0.3959175277947622, 0.5170838698121216, 0.9465208083959076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 327}], {
             RGBColor[
             0.32373500724345117`, 0.4548247247048681, 0.941849086287294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 356}], {
             RGBColor[
             0.4236281428800086, 0.5395805954873082, 0.9487022895227458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 361}], {
             RGBColor[
             0.342252200873233, 0.470863387125772, 0.9430289854912723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 369}], {
             RGBColor[
             0.29316591487643506`, 0.4236050127700691, 0.9400748896075932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 392}], {
             RGBColor[
             0.2884135464934976, 0.418609972282043, 0.9398042492586839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 184}], {
             RGBColor[
             0.22818450918176583`, 0.35716676525650004`, 0.936306142277947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 188}], {
             RGBColor[
             0.25284600900533644`, 0.38308756520047255`, 0.9377105782094798]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 195}], {
             RGBColor[
             0.2421504028292495, 0.3718458049688061, 0.937101479260483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 203}], {
             RGBColor[
             0.265001837635785, 0.3958641118151241, 0.9384028346670469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 206}], {
             RGBColor[
             0.23508408472910247`, 0.364418656615107, 0.9366990628983605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 208}], {
             RGBColor[
             0.2358464087925902, 0.36521990753996986`, 0.9367424761260187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 258}], {
             RGBColor[
             0.24576968053509757`, 0.37564989531311277`, 0.9373075917715895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 284}], {
             RGBColor[
             0.24130209476909242`, 0.37095417941174347`, 0.9370531693714164]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 325}], {
             RGBColor[
             0.22508690864981107`, 0.3539109906981984, 0.9361297385101415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 369}], {
             RGBColor[
             0.24803002426208054`, 0.37802565988424164`, 0.9374363150029623]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 392}], {
             RGBColor[
             0.24327765587914302`, 0.37303061939621557`, 0.937165674654053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 121}], {
             RGBColor[
             0.48470874113100904`, 0.5915401565241579, 0.9528555034179461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 130}], {
             RGBColor[
             0.4133134657138138, 0.5324130830876621, 0.947556946449905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 135}], {
             RGBColor[
             0.4597496952635722, 0.5712772786967698, 0.9508906358992639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 147}], {
             RGBColor[
             0.35047958711339033`, 0.47576981650030403`, 0.9436345020558807]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 172}], {
             RGBColor[
             0.3588230012593764, 0.484539273770746, 0.9441096471485195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 265}], {
             RGBColor[
             0.5040580192630065, 0.6072487721867599, 0.9543787494712381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 276}], {
             RGBColor[
             0.5908937430052579, 0.6758585483037947, 0.9625051852330178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 322}], {
             RGBColor[
             0.46231873384021377`, 0.5733629399471565, 0.9510928800267155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 328}], {
             RGBColor[
             0.3628292631493686, 0.48868620423613895`, 0.944340137703926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 362}], {
             RGBColor[
             0.41044018393094006`, 0.5299243908226783, 0.9473738634754435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 364}], {
             RGBColor[
             0.382875553578809, 0.5060492934502673, 0.9456174696038513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 387}], {
             RGBColor[
             0.35489504602512995`, 0.4804107437728069, 0.9438859559088182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 223}], {
             RGBColor[
             0.40179215387534173`, 0.5224135595233219, 0.9468284392932418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 346}], {
             RGBColor[
             0.3472745636844825, 0.4752135053615816, 0.9433490060085041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 371}], {
             RGBColor[
             0.31078136056287864`, 0.44021172480761495`, 0.9411479331302521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 126}], {
             RGBColor[
             0.20905168496127685`, 0.33705695390964574`, 0.935216556243067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 149}], {
             RGBColor[
             0.21314012851733694`, 0.34135416730935836`, 0.9354493870552745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[
             0.21593219336709382`, 0.3442888044935889, 0.9356083910179783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 212}], {
             RGBColor[
             0.208479398474888, 0.33645544452739207`, 0.9351839653742893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 259}], {
             RGBColor[
             0.20854115618205327`, 0.33652035579328765`, 0.9351874823843499]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 293}], {
             RGBColor[
             0.20864634306607288`, 0.33663091387762584`, 0.9351934726217848]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 299}], {
             RGBColor[
             0.21009516231391617`, 0.33815371476755507`, 0.9352759807346135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 336}], {
             RGBColor[
             0.20853409149877072`, 0.3365129303632308, 0.9351870800610882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 367}], {
             RGBColor[
             0.21268815866311674`, 0.340879118336029, 0.9354236480407061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 200}], {
             RGBColor[
             0.2555790109882331, 0.38596012356683096`, 0.9378662186292916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 225}], {
             RGBColor[
             0.24880323623162193`, 0.37883835468870003`, 0.9374803482807631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 288}], {
             RGBColor[
             0.2427621793276949, 0.37248882085754254`, 0.9371363190270272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 296}], {
             RGBColor[
             0.27100995406971695`, 0.4021790231237703, 0.9387449880097476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 316}], {
             RGBColor[
             0.24738893708713797`, 0.3773518366161024, 0.9373998060367528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 324}], {
             RGBColor[
             0.26022801088632164`, 0.3908465172233403, 0.9381309722959088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 355}], {
             RGBColor[
             0.2357097669248304, 0.3650762882733595, 0.9367346945737933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 375}], {
             RGBColor[
             0.24767185396681415`, 0.37764920019460835`, 0.9374159177345123]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 380}], {
             RGBColor[
             0.25299451614994406`, 0.383243655625352, 0.9377190354716685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 383}], {
             RGBColor[
             0.2603673467577916, 0.3909929680586598, 0.93813890726766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 390}], {
             RGBColor[
             0.2533988208527428, 0.3836686055023921, 0.9377420600263777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 136}], {
             RGBColor[
             0.5924802140391232, 0.6800411545432594, 0.9610613592571464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 237}], {
             RGBColor[
             0.5723986729827764, 0.663738054850602, 0.9594804667840822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 246}], {
             RGBColor[
             0.505090585435528, 0.6088359587265868, 0.9542531127865411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 254}], {
             RGBColor[
             0.5179448523327678, 0.6195299901302602, 0.955193662551596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 286}], {
             RGBColor[
             0.6463140971253603, 0.7224608247380875, 0.966177990499731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 320}], {
             RGBColor[
             0.6381361673517921, 0.7160721638444079, 0.9653628908870006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 343}], {
             RGBColor[
             0.64428944346767, 0.7208791499127623, 0.9659761919445966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 349}], {
             RGBColor[
             0.5058787275831391, 0.6095186078416714, 0.9543033325072602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 130}], {
             RGBColor[
             0.48180086572832803`, 0.5890215010044231, 0.9526702161686205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 158}], {
             RGBColor[
             0.5281560210081759, 0.6278198768688632, 0.9559975231544674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 181}], {
             RGBColor[
             0.5602542166801026, 0.6538786381225696, 0.9585244106973264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 250}], {
             RGBColor[
             0.7707116790518824, 0.8187741201767487, 0.9013688926659322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 265}], {
             RGBColor[
             0.5725454192775208, 0.6638571901035208, 0.9594920191899539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 322}], {
             RGBColor[
             0.5308061338547281, 0.6299713578639174, 0.9562061497454312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 362}], {
             RGBColor[
             0.4789275839454543, 0.5865328087394392, 0.9524871331941591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 146}], {
             RGBColor[
             0.49070941162852855`, 0.5972227097318854, 0.9531038334374095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.3887610902465449, 0.5111470494961861, 0.9459924907959437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 165}], {
             RGBColor[
             0.48941818004964077`, 0.5961744297668246, 0.9530021829575823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 210}], {
             RGBColor[
             0.3730056479605837, 0.4966847962832106, 0.9450184340224643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 228}], {
             RGBColor[
             0.40697238168033323`, 0.5269207548100117, 0.9471528981824919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 262}], {
             RGBColor[
             0.6923652232093209, 0.7572804525421046, 0.9691955483013721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 298}], {
             RGBColor[
             0.634758859433705, 0.711422615804957, 0.9663329898214426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 314}], {
             RGBColor[
             0.6859497834912932, 0.7522408691078613, 0.9712156258567326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 385}], {
             RGBColor[
             0.510754315643456, 0.6134960658238386, 0.9546818417083673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 174}], {
             RGBColor[
             0.8514507591880022, 0.8841310051490996, 0.9509891763922267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 187}], {
             RGBColor[
             0.9091149872090246, 0.929372315984517, 0.9566852381845512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 193}], {
             RGBColor[
             0.8983178729767032, 0.9207629901755221, 0.9556553997903747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 218}], {
             RGBColor[
             0.9421799541639146, 0.955737423109728, 0.959839004250153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 232}], {
             RGBColor[
             0.7499263891145284, 0.8030301325071595, 0.9420935049543039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 235}], {
             RGBColor[
             0.8571949059772741, 0.8886183762780113, 0.9515616992620775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 275}], {
             RGBColor[
             0.9831983875687983, 0.9856760529092304, 0.8544852374631398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 279}], {
             RGBColor[
             0.9599728871641575, 0.901288321876893, 0.6017603738326488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 281}], {
             RGBColor[
             0.8031450913153519, 0.8462354724290008, 0.9462830761380823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 306}], {
             RGBColor[
             0.9723361250736168, 0.9460422517382365, 0.6339056761634236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 338}], {
             RGBColor[
             0.9842922541931751, 0.9852712070496027, 0.7740485310892328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.22241368079166546`, 0.3511012587268517, 0.9359775021383063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 199}], {
             RGBColor[
             0.224537016117427, 0.35333301878146245`, 0.9360984229439153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 238}], {
             RGBColor[
             0.22624718755874168`, 0.35513051739741625`, 0.9361958146775262]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 252}], {
             RGBColor[
             0.22380219645594157`, 0.3525606767269839, 0.936056576051262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 277}], {
             RGBColor[
             0.24054204876353127`, 0.3701553228701986, 0.9370098858757869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 293}], {
             RGBColor[
             0.21725116581640602`, 0.3456751281654994, 0.9356835045477219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 330}], {
             RGBColor[
             0.22402160898279397`, 0.3527912932042634, 0.9360690712700745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 179}], {
             RGBColor[
             0.2738145581196516, 0.4051268398024189, 0.9389047060613515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 196}], {
             RGBColor[
             0.2879550374250095, 0.4199893801105207, 0.9397099854388271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 303}], {
             RGBColor[
             0.28379884955745593`, 0.41562096314419106`, 0.9394732966882988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 313}], {
             RGBColor[
             0.2803971559769777, 0.4120455675112783, 0.9392795752712453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 344}], {
             RGBColor[
             0.2993073040655987, 0.4308227000023955, 0.9403967065336283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 149}], {
             RGBColor[
             0.21613019133913786`, 0.3444969129160037, 0.9356196667095744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 199}], {
             RGBColor[
             0.21892225618889471`, 0.3474315501002342, 0.9357786706722784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 212}], {
             RGBColor[
             0.21146946129668887`, 0.3395981901340374, 0.9353542450285892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 238}], {
             RGBColor[
             0.2206324276302094, 0.349229048716188, 0.9358760624058893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 259}], {
             RGBColor[
             0.2115312190038542, 0.33966310139993294`, 0.93535776203865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 274}], {
             RGBColor[
             0.22138486041548355`, 0.35001990328050514`, 0.9359189123398861]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 299}], {
             RGBColor[
             0.21308522513571704`, 0.34129646037420036`, 0.9354462603889135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 318}], {
             RGBColor[
             0.2179296081019373, 0.3463882140233181, 0.9357221408322174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 336}], {
             RGBColor[
             0.21152415432057162`, 0.33965567596987617`, 0.9353573597153882]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 367}], {
             RGBColor[
             0.21567822148491766`, 0.34402186394267437`, 0.935593927695006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 139}], {
             RGBColor[
             0.2108331954164144, 0.3389294343522821, 0.9353180106279786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 184}], {
             RGBColor[
             0.21412931839643223`, 0.34239386859054827`, 0.9355057199555137]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 305}], {
             RGBColor[
             0.20669916269368893`, 0.33458430384788407`, 0.9350825835801727]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 325}], {
             RGBColor[
             0.21103171786447747`, 0.3391380940322466, 0.9353293161877081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 177}], {
             RGBColor[
             0.32406082685861914`, 0.45510693327935664`, 0.9418698472250615]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 225}], {
             RGBColor[
             0.2916606290262991, 0.42226923419395845`, 0.939980144908767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 296}], {
             RGBColor[
             0.3138673468643941, 0.4456099026290287, 0.9412447846377514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 311}], {
             RGBColor[
             0.4227935959175786, 0.5388307190597109, 0.9486565824461703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 316}], {
             RGBColor[
             0.29024632988181515`, 0.4207827161213608, 0.9398996026647567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 324}], {
             RGBColor[
             0.3030854036809988, 0.43427739672859866`, 0.9406307689239126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 380}], {
             RGBColor[
             0.2958519089446212, 0.4266745351306104, 0.9402188320996724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 383}], {
             RGBColor[
             0.30322473955246876`, 0.43442384756391816`, 0.9406387038956638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 390}], {
             RGBColor[
             0.29625621364741994`, 0.42709948500765055`, 0.9402418566543815]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 178}], {
             RGBColor[
             0.24083645723076108`, 0.3704647648358321, 0.9370266520024574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 229}], {
             RGBColor[
             0.24229031603850887`, 0.3719928626227475, 0.9371094471107673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 249}], {
             RGBColor[
             0.25362687609654, 0.3839083060231606, 0.9377550474351345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 270}], {
             RGBColor[
             0.24363580909960866`, 0.3734070611391507, 0.9371860709501183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 308}], {
             RGBColor[
             0.2493864248848615, 0.3794513229395511, 0.9375135600118147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 309}], {
             RGBColor[
             0.25423745991444247`, 0.38455006832902616`, 0.9377898192802863]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 397}], {
             RGBColor[
             0.24351700983454236`, 0.3732821955792575, 0.9371793055077206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 135}], {
             RGBColor[
             0.4568418198608912, 0.568758623177035, 0.9507053486499384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 147}], {
             RGBColor[
             0.34757171171070933`, 0.4732511609805692, 0.9434492148065551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 158}], {
             RGBColor[
             0.4567607455909806, 0.5686928034323673, 0.9506989661864262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 172}], {
             RGBColor[
             0.3559151258566954, 0.4820206182510111, 0.9439243598991939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 181}], {
             RGBColor[
             0.48885894126290724`, 0.5947515646860737, 0.9532258537292853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 265}], {
             RGBColor[
             0.5011501438603255, 0.6047301166670249, 0.9541934622219126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 322}], {
             RGBColor[
             0.45941085843753277`, 0.5708442844274215, 0.95090759277739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 328}], {
             RGBColor[
             0.3599213877466876, 0.48616754871640405`, 0.9441548504546003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 347}], {
             RGBColor[
             0.34522783768479254`, 0.47078760076913406`, 0.9433157346482299]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 362}], {
             RGBColor[
             0.40753230852825906`, 0.5274057353029433, 0.9471885762261179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 364}], {
             RGBColor[
             0.379967678176128, 0.5035306379305324, 0.9454321823545258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 387}], {
             RGBColor[
             0.35198717062244894`, 0.47789208825307206`, 0.9437006686594926]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 215}], {
             RGBColor[
             0.8536808578489179, 0.34294583045453636`, 0.1962266941808688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 217}], {
             RGBColor[
             0.8560391728343671, 0.3610728728529158, 0.19848501927427087`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 262}], {
             RGBColor[
             0.9305545199558635, 0.8420358975584873, 0.6226092420681639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 269}], {
             RGBColor[
             0.9577625542405059, 0.8589366723660075, 0.3711790558606476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 279}], {
             RGBColor[
             0.934057909721427, 0.776268616484077, 0.26579965018330676`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 297}], {
             RGBColor[
             0.9345525999537521, 0.8450176590746574, 0.6158415354980056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 300}], {
             RGBColor[
             0.9062314787117222, 0.661847076989811, 0.24319781291959908`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 306}], {
             RGBColor[
             0.9464211476308863, 0.8210225463454206, 0.2979449525140816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 307}], {
             RGBColor[
             0.9538530771213425, 0.8592378166634234, 0.5753740091193393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 314}], {
             RGBColor[
             0.9241390802378358, 0.8369963141242439, 0.6246293196235244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 352}], {
             RGBColor[
             0.9583101575279735, 0.8601079404267151, 0.43078229428572945`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 363}], {
             RGBColor[
             0.8824970556177689, 0.5558258692629264, 0.22348381958996794`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 140}], {
             RGBColor[
             0.7355736784173503, 0.7933550152374292, 0.9742787680039452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 191}], {
             RGBColor[
             0.7390378619070974, 0.7960612617083893, 0.9746240454395679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 198}], {
             RGBColor[
             0.8128559952710535, 0.8537811311091374, 0.9819675933041132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 216}], {
             RGBColor[
             0.7291619678468395, 0.7883461382089411, 0.9736397086151186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 219}], {
             RGBColor[
             0.6232051027562657, 0.7024156086050097, 0.9651690328906872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 220}], {
             RGBColor[
             0.6373284381573086, 0.7140480166379533, 0.9662348834814941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 302}], {
             RGBColor[
             0.8932496977556434, 0.905911220002762, 0.6928483915783341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 323}], {
             RGBColor[
             0.8147163030891271, 0.8552644900665589, 0.9821450311245175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 357}], {
             RGBColor[
             0.7374562321167385, 0.7948256804953293, 0.9744664033632358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 145}], {
             RGBColor[
             0.26764114093786784`, 0.3986381869271076, 0.9385531390856012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 164}], {
             RGBColor[
             0.2698983654154672, 0.40101067296936244`, 0.9386816846803361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 223}], {
             RGBColor[
             0.3756627076897743, 0.49871942307299955`, 0.945202383630783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 234}], {
             RGBColor[
             0.31799880832538563`, 0.4487941940432452, 0.9415224703076799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 280}], {
             RGBColor[
             0.26813571605602704`, 0.3991580167341666, 0.938581304406922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 346}], {
             RGBColor[
             0.32114511749891506`, 0.4515193689112592, 0.9417229503460453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 167}], {
             RGBColor[
             0.25893816716997997`, 0.3894908096966502, 0.9380575176044159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 201}], {
             RGBColor[
             0.255376576823433, 0.3857473524245587, 0.9378546903030808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 236}], {
             RGBColor[
             0.24242453355158805`, 0.3721339337388756, 0.9371170905995801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 243}], {
             RGBColor[
             0.2613494095308073, 0.3920251782994754, 0.9381948342897516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 263}], {
             RGBColor[
             0.24820523859568883`, 0.3782098212580943, 0.9374462932000549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 348}], {
             RGBColor[
             0.24864104476606846`, 0.3786678811748705, 0.9374711117167406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 351}], {
             RGBColor[
             0.24003567899790235`, 0.3696230961408251, 0.9369810488667414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 221}], {
             RGBColor[
             0.7125684826637311, 0.7740760557086418, 0.9732239792621271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 276}], {
             RGBColor[
             0.6344220971523353, 0.7122040883931675, 0.9656535874330512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 322}], {
             RGBColor[
             0.5058470879872912, 0.6097084800365293, 0.954241282226749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 364}], {
             RGBColor[
             0.42640390772588643`, 0.5423948335396401, 0.9487658718038847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 376}], {
             RGBColor[
             0.47083567399736015`, 0.5808793962784845, 0.9515970246612349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 377}], {
             RGBColor[
             0.4590787183907463, 0.5706961122538062, 0.9508478818462491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 194}], {
             RGBColor[
             0.5033185862068833, 0.6058836865205527, 0.954531849750919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 237}], {
             RGBColor[
             0.59850057250929, 0.6849287527633994, 0.9615353039292178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 246}], {
             RGBColor[
             0.5311924849620417, 0.6300266566393842, 0.9563079499316767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 254}], {
             RGBColor[
             0.5440467518592814, 0.6407206880430576, 0.9572484996967315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 286}], {
             RGBColor[
             0.6724159966518739, 0.7436515226508849, 0.9682328276448666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 320}], {
             RGBColor[
             0.6642380668783059, 0.7372628617572051, 0.9674177280321361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 343}], {
             RGBColor[
             0.6703913429941837, 0.7420698478255596, 0.9680310290897323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 349}], {
             RGBColor[
             0.5319806271096528, 0.6307093057544687, 0.9563581696523957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 376}], {
             RGBColor[
             0.5284877060748537, 0.6276839131134415, 0.9561356038127271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 199}], {
             RGBColor[
             0.22367942926895015`, 0.3524316406295666, 0.9360495846415806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 238}], {
             RGBColor[
             0.22538960071026484`, 0.3542291392455204, 0.9361469763751915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 252}], {
             RGBColor[
             0.22294460960746476`, 0.35165929857508804`, 0.9360077377489273]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 277}], {
             RGBColor[
             0.23968446191505444`, 0.36925394471830275`, 0.9369610475734522]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 285}], {
             RGBColor[
             0.23013560035880143`, 0.35921748578989005`, 0.9364172540340985]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 293}], {
             RGBColor[
             0.2163935789679292, 0.34477375001360355`, 0.9356346662453872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 330}], {
             RGBColor[
             0.22316402213431713`, 0.35188991505236755`, 0.9360202329677398]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 144}], {
             RGBColor[
             0.8390412862575602, 0.28008815239866347`, 0.1841967491117235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 233}], {
             RGBColor[
             0.8187146618318747, 0.1448546684227033, 0.1655544873463778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 242}], {
             RGBColor[
             0.8523441975821417, 0.33778208735566917`, 0.19515676243732563`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 256}], {
             RGBColor[
             0.6213313727692809, 0.21783685259893074`, 0.42281816094082003`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 257}], {
             RGBColor[
             0.820430974175874, 0.158046997191546, 0.167198029985289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 317}], {
             RGBColor[
             0.8764376053277974, 0.429919621971069, 0.3791031608899539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 366}], {
             RGBColor[
             0.8466553995070266, 0.31466206234315997`, 0.19055015184607266`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 381}], {
             RGBColor[
             0.8772775939555472, 0.4302669788553665, 0.36518237550725596`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 382}], {
             RGBColor[
             0.8458222250338829, 0.3108788116534561, 0.1898549306427063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 184}], {
             RGBColor[
             0.21446679583023515`, 0.34274857877078024`, 0.9355249387961155]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 305}], {
             RGBColor[
             0.20703664012749182`, 0.3349390140281161, 0.9351018024207747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 325}], {
             RGBColor[
             0.21136919529828035`, 0.33949280421247857`, 0.9353485350283102]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 141}], {
             RGBColor[
             0.5159944713875729, 0.6149616035084853, 0.9560493981699523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 168}], {
             RGBColor[
             0.6710377427034506, 0.7429390517664531, 0.9678464290545918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 191}], {
             RGBColor[
             0.6753891788981803, 0.7463384267939157, 0.9682801395479993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 216}], {
             RGBColor[
             0.6655132848379224, 0.7386233032944675, 0.96729580272355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 219}], {
             RGBColor[
             0.5595564197473485, 0.6526927736905361, 0.9588251269991186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 220}], {
             RGBColor[
             0.5736797551483913, 0.6643251817234797, 0.9598909775899255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 350}], {
             RGBColor[
             0.5523338730537959, 0.6464369667603329, 0.9583649127104528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 357}], {
             RGBColor[
             0.6738075491078213, 0.7451028455808557, 0.9681224974716671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 150}], {
             RGBColor[
             0.3153323622893313, 0.4440199894984804, 0.9414428101102743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 189}], {
             RGBColor[
             0.33030534537683665`, 0.4597575440654077, 0.9422954993465642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 219}], {
             RGBColor[
             0.4036258957264883, 0.5240221968760659, 0.9469396630566943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 220}], {
             RGBColor[
             0.4177492311275311, 0.5356546049090093, 0.9480055136475012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 273}], {
             RGBColor[
             0.31775067217972763`, 0.44656178652298995`, 0.9415805292809634]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 339}], {
             RGBColor[
             0.36291222472736206`, 0.48875806138522676`, 0.9443454239423157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 350}], {
             RGBColor[
             0.3964033490329356, 0.5177663899458625, 0.9464794487680284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 357}], {
             RGBColor[
             0.5178770250869611, 0.6164322687663853, 0.9562370335292427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 394}], {
             RGBColor[
             0.3594659493572627, 0.4857730708744833, 0.9441258303231546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 202}], {
             RGBColor[
             0.8331691909471927, 0.2559585132180833, 0.1793961607512619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 214}], {
             RGBColor[
             0.8756470135656208, 0.4404124969282712, 0.41631879531902366`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 217}], {
             RGBColor[
             0.8219978721653904, 0.17009086175804683`, 0.16869849326960812`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 257}], {
             RGBColor[
             0.8219250388987569, 0.16953103335496109`, 0.16862874805122652`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 268}], {
             RGBColor[
             0.820162315663362, 0.15598197013746787`, 0.16694076229030108`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 275}], {
             RGBColor[
             0.8784228625837636, 0.4416067788699862, 0.3723935475171762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 279}], {
             RGBColor[
             0.8629391956473363, 0.38534829151509464`, 0.20391030509684882`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 300}], {
             RGBColor[
             0.8443882416408665, 0.30906726518558403`, 0.18884241358771037`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 306}], {
             RGBColor[
             0.8711813542536425, 0.41518424475599036`, 0.22534050665069866`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 338}], {
             RGBColor[
             0.8791521070000148, 0.44133688163023443`, 0.3187690766012381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 363}], {
             RGBColor[
             0.8352268135570913, 0.26746735996305215`, 0.18119789342745665`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 381}], {
             RGBColor[
             0.8787716586784301, 0.4417510150187816, 0.3666130935731935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 223}], {
             RGBColor[
             0.5393557196395969, 0.6369122967585245, 0.9568792044565808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 234}], {
             RGBColor[
             0.4816918202752083, 0.5869870677287701, 0.9531992911334777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 260}], {
             RGBColor[
             0.7167991404658595, 0.7784168360748085, 0.9725930329082488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 267}], {
             RGBColor[
             0.5979215961089128, 0.6844587136389835, 0.9614897247861196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 272}], {
             RGBColor[
             0.635830587523557, 0.7151635871324875, 0.9645228442451073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 290}], {
             RGBColor[
             0.5148889820990041, 0.6157407807626738, 0.9553145849297924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 291}], {
             RGBColor[
             0.6605679134983766, 0.7344885741946573, 0.9669884297148228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 321}], {
             RGBColor[
             0.7212153553030598, 0.7818668166701053, 0.973033199931347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 331}], {
             RGBColor[
             0.5383683584932644, 0.6360774364876114, 0.9568106700316372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 342}], {
             RGBColor[
             0.6140012232637606, 0.6975128793422373, 0.9627555719373643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 398}], {
             RGBColor[
             0.7820348247548993, 0.8302487551810782, 0.97550730112162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 207}], {
             RGBColor[
             0.9091469621070289, 0.6700765235430096, 0.2453714490760957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 233}], {
             RGBColor[
             0.837784857099873, 0.2704306873219118, 0.18299359113138844`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 242}], {
             RGBColor[
             0.8983924729381163, 0.6274385577093406, 0.23671813465048305`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 317}], {
             RGBColor[
             0.9345325845565998, 0.7656448596324403, 0.5126377323294256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 358}], {
             RGBColor[
             0.9235073892649484, 0.7232807673563957, 0.2763524253689754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 366}], {
             RGBColor[
             0.8898592758254438, 0.5927585201905767, 0.22980821876360358`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 370}], {
             RGBColor[
             0.8548273648949809, 0.7045756223106869, 0.6020207461756493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 391}], {
             RGBColor[
             0.8397398954791699, 0.2854579690084683, 0.1848657380913032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 162}], {
             RGBColor[
             0.2420540274215789, 0.3717445083047905, 0.9370959908235907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 164}], {
             RGBColor[
             0.2402812832877892, 0.36988124182170756`, 0.9369950356677115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 227}], {
             RGBColor[
             0.23647303514531387`, 0.36587853156708794`, 0.9367781615697957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 280}], {
             RGBColor[
             0.23851863392834902`, 0.36802858558651175`, 0.9368946553942974]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 359}], {
             RGBColor[
             0.24179608967805666`, 0.37147339938215107`, 0.9370813016506819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 154}], {
             RGBColor[
             0.48274463326921224`, 0.5903240190384458, 0.9525963248033308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 159}], {
             RGBColor[
             0.433382915877228, 0.5475693804255631, 0.9494510398199664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 165}], {
             RGBColor[
             0.5340400056803238, 0.6325967606962016, 0.956460731981605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 192}], {
             RGBColor[
             0.43991049068666355`, 0.5532232376400468, 0.9498669711147159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 228}], {
             RGBColor[
             0.45159420731101624`, 0.5633430857393887, 0.9506114472065146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 262}], {
             RGBColor[
             0.736987048840004, 0.7937027834714817, 0.9726540973253948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 297}], {
             RGBColor[
             0.7409851288378926, 0.7966845449876518, 0.9658863907552364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 307}], {
             RGBColor[
             0.760285606005483, 0.8109047025764178, 0.9254188643765703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 314}], {
             RGBColor[
             0.7305716091219763, 0.7886632000372383, 0.9746741748807553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 332}], {
             RGBColor[
             0.53127642233297, 0.6303531592368088, 0.9562431725771618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 385}], {
             RGBColor[
             0.5553761412741389, 0.6499183967532158, 0.95814039073239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 172}], {
             RGBColor[
             0.29308124725627194`, 0.4253773516636531, 0.9400019155051696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 211}], {
             RGBColor[
             0.2737075152920192, 0.40501433100367, 0.9388986101306735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 328}], {
             RGBColor[
             0.29708750914626414`, 0.42952428212904603`, 0.9402324060605761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 347}], {
             RGBColor[
             0.28239395908436904`, 0.4141443341817761, 0.9393932902542057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 364}], {
             RGBColor[
             0.31713379957570453`, 0.44688737134317436`, 0.9415097379605015]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 372}], {
             RGBColor[
             0.2681076692483716, 0.3991285377610505, 0.9385797071827175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 387}], {
             RGBColor[
             0.28915329202202544`, 0.42124882166571403`, 0.9397782242654684]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 161}], {
             RGBColor[
             0.5276623353729026, 0.6268249505740837, 0.9561228183174523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 168}], {
             RGBColor[
             0.6470192572483401, 0.7238926765948177, 0.9656459465719469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 170}], {
             RGBColor[
             0.5344288299346016, 0.632685748069522, 0.9565539733675475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 251}], {
             RGBColor[
             0.723101933884062, 0.7833478892534567, 0.9732241552199159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.6353748988917614, 0.714796015346257, 0.9644853457536787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 312}], {
             RGBColor[
             0.5434225996528742, 0.6402139731641597, 0.9571993641486982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 326}], {
             RGBColor[
             0.4816391300864997, 0.5869619633485583, 0.9531902603733251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 356}], {
             RGBColor[
             0.5711332147381206, 0.6627106988393463, 0.9593808452755366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 199}], {
             RGBColor[
             0.2230106997449548, 0.3517287634999468, 0.9360115014844858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 212}], {
             RGBColor[
             0.21555790485274898`, 0.34389540353375003`, 0.9355870758407967]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 238}], {
             RGBColor[
             0.2247208711862695, 0.3535262621159006, 0.9361088932180968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 259}], {
             RGBColor[
             0.21561966255991427`, 0.3439603147996455, 0.9355905928508573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 274}], {
             RGBColor[
             0.22547330397154366`, 0.35431711668021776`, 0.9361517431520935]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 287}], {
             RGBColor[
             0.24021601426247097`, 0.36981263993780294`, 0.9369913186932763]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 299}], {
             RGBColor[
             0.21717366869177715`, 0.345593673773913, 0.9356790912011209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 318}], {
             RGBColor[
             0.22201805165799737`, 0.3506854274230307, 0.9359549716444248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 336}], {
             RGBColor[
             0.21561259787663173`, 0.3439528893695888, 0.9355901905275956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 367}], {
             RGBColor[
             0.21976666504097775`, 0.348319077342387, 0.9358267585072135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 186}], {
             RGBColor[
             0.2595342246109202, 0.3901173038593028, 0.9380914621938894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 189}], {
             RGBColor[
             0.28557376029945525`, 0.4174865068698732, 0.9395743752293106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 226}], {
             RGBColor[
             0.2546174021107136, 0.38494941166703367`, 0.9378114564262897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 241}], {
             RGBColor[
             0.2807813627744614, 0.41244939321555174`, 0.939301455279979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 255}], {
             RGBColor[
             0.26553787758684655`, 0.39642752379058566`, 0.9384333613492598]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 266}], {
             RGBColor[
             0.2627993543398047, 0.39354916222554226`, 0.9382774065016228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 365}], {
             RGBColor[
             0.26342074735738313`, 0.39420228568561005`, 0.9383127939147053]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 374}], {
             RGBColor[
             0.2733522518909328, 0.4046409266441276, 0.9388783784055468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 399}], {
             RGBColor[
             0.2527398969113101, 0.3829760346617555, 0.9377045352827038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 171}], {
             RGBColor[
             0.294524052203641, 0.4262383567855898, 0.940108081239609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 182}], {
             RGBColor[
             0.301964914813191, 0.43405917516616493`, 0.9405318273574531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 244}], {
             RGBColor[
             0.28793584651295273`, 0.41931373488830953`, 0.9397328926719012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 249}], {
             RGBColor[
             0.2927023996318287, 0.42432368443317114`, 0.9400043408205379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 253}], {
             RGBColor[
             0.3287756481732377, 0.4591906745282696, 0.9421702714700763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 270}], {
             RGBColor[
             0.28271133263489734`, 0.4138224395491612, 0.9394353643355215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 308}], {
             RGBColor[
             0.28846194842015016`, 0.41986670134956156`, 0.9397628533972181]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 386}], {
             RGBColor[
             0.3275993292124569, 0.45817180616795133`, 0.9420953174660733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 397}], {
             RGBColor[
             0.28259253336983103`, 0.413697573989268, 0.9394285988931239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 156}], {
             RGBColor[
             0.18478785261667285`, 0.31155412769964164`, 0.9338347668861651]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 175}], {
             RGBColor[
             0.181274153781999, 0.307861007443026, 0.9336346669355821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 242}], {
             RGBColor[
             0.5509815030039178, 0.5121510355041116, 0.5934630978551525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 256}], {
             RGBColor[
             0.2044622657846265, 0.33223318336900387`, 0.9349551956103941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 261}], {
             RGBColor[
             0.18153226782756765`, 0.3081323016702944, 0.9336493661486316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 264}], {
             RGBColor[
             0.186823590274237, 0.31369381705096394`, 0.9339506991341594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 317}], {
             RGBColor[
             0.5871216146224013, 0.6503573374272111, 0.8693826955340949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 333}], {
             RGBColor[
             0.18958831081692415`, 0.31659971363473505`, 0.9341081458790279]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 381}], {
             RGBColor[
             0.588381597564026, 0.6508783727536576, 0.8485015174600479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 154}], {
             RGBColor[
             0.3737943950019111, 0.49818365032325973`, 0.9450388262094847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 188}], {
             RGBColor[
             0.2922583395910017, 0.4237094580639409, 0.939984452630228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 195}], {
             RGBColor[
             0.2815627334149148, 0.41246769783227444`, 0.9393753536812313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 203}], {
             RGBColor[
             0.3044141682214503, 0.43648600467859244`, 0.9406767090877951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 258}], {
             RGBColor[
             0.28518201112076286`, 0.41627178817658117`, 0.9395814661923377]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 278}], {
             RGBColor[
             0.284923192180341, 0.41599975306012926`, 0.939566726836569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 284}], {
             RGBColor[
             0.2807144253547577, 0.4115760722752118, 0.9393270437921646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 312}], {
             RGBColor[
             0.39019396776607296`, 0.5121264097897626, 0.9461561082120249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 327}], {
             RGBColor[
             0.31801144721476193`, 0.44986726468250904`, 0.9414843861034113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 337}], {
             RGBColor[
             0.30108704647180895`, 0.43298898876801645`, 0.9404872344261885]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[
             0.4179045828513193, 0.5346231354649491, 0.9483375893388631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 361}], {
             RGBColor[
             0.3365286408445437, 0.46590592710341294`, 0.9426642853073897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 369}], {
             RGBColor[
             0.28744235484774583`, 0.41864755274771004`, 0.9397101894237105]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 392}], {
             RGBColor[
             0.28268998646480836`, 0.4136525122596839, 0.9394395490748012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 192}], {
             RGBColor[
             0.3873238866966642, 0.5099022160172301, 0.9459009134566145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[
             0.36077780249875213`, 0.4853053517709617, 0.9442681500235399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 222}], {
             RGBColor[
             0.5175424648922109, 0.6185744663744461, 0.9553357375773506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 228}], {
             RGBColor[
             0.39900760332101687`, 0.520022064116572, 0.9466453895484133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 312}], {
             RGBColor[
             0.4465576020433747, 0.5609457568821319, 0.9497475491477698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 332}], {
             RGBColor[
             0.47868981834297064`, 0.5870321376139921, 0.9522771149190605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 356}], {
             RGBColor[
             0.4742682171286211, 0.5834424825573183, 0.951929030274608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 361}], {
             RGBColor[
             0.39289227512184555`, 0.5147252741957822, 0.9462557262431346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 385}], {
             RGBColor[
             0.5027895372841396, 0.606597375130399, 0.9541743330742887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 170}], {
             RGBColor[
             0.3747576276064379, 0.498629600146848, 0.9451144220759548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 180}], {
             RGBColor[
             0.33540782096983857`, 0.46454677541701367`, 0.9426070871927383]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 183}], {
             RGBColor[
             0.2817396246657633, 0.4134565872206231, 0.9393560268770672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 239}], {
             RGBColor[
             0.3145302695292589, 0.4464636896954298, 0.9412767880762385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 271}], {
             RGBColor[
             0.305666751429035, 0.4386055145162801, 0.9407186413492236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 326}], {
             RGBColor[
             0.32196792775833594`, 0.4529058154258842, 0.9417507090817323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 335}], {
             RGBColor[
             0.29253189959404885`, 0.42479995244000324`, 0.9399706309684931]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 337}], {
             RGBColor[
             0.29464447603044647`, 0.42702040421973947`, 0.9400909390712692]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 354}], {
             RGBColor[
             0.29215952785429067`, 0.42440856613178546`, 0.9399494249487885]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 175}], {
             RGBColor[
             0.18244584031582461`, 0.30909252427929373`, 0.9337013927503286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 202}], {
             RGBColor[
             0.6328795969511609, 0.39363296767320055`, 0.4456899611555588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 214}], {
             RGBColor[
             0.5848663164286375, 0.6501021124541597, 0.9231267958935396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 256}], {
             RGBColor[
             0.20563395231845213`, 0.3334647002052716, 0.9350219214251405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 261}], {
             RGBColor[
             0.18270395436139325`, 0.3093638185065621, 0.9337160919633781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 264}], {
             RGBColor[
             0.1879952768080626, 0.31492533388723165`, 0.9340174249489059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 295}], {
             RGBColor[
             0.2141734445733891, 0.3424402480002911, 0.9355082328760125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 310}], {
             RGBColor[
             0.1842688448604277, 0.3110086176408356, 0.93380521016225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 363}], {
             RGBColor[
             0.6369948421709581, 0.41665066116313826`, 0.44929342650794835`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 381}], {
             RGBColor[
             0.5895532840978516, 0.6521098895899253, 0.8485682432747944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 187}], {
             RGBColor[
             0.656588840938115, 0.7291931341002164, 0.9681680488654731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 218}], {
             RGBColor[
             0.689653807893005, 0.7555582412254274, 0.971321814931075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 253}], {
             RGBColor[
             0.40547981020843754`, 0.5251955404755204, 0.9471772728723662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 298}], {
             RGBColor[
             0.6463369873520685, 0.7210185843298552, 0.9671902179184984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.5352140965427551, 0.633549940550514, 0.9565531607151321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 265}], {
             RGBColor[
             0.5475052991401734, 0.643528492531465, 0.9575207692077594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 311}], {
             RGBColor[
             0.5112449698673547, 0.6140907237185725, 0.9546662232614405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 322}], {
             RGBColor[
             0.5057660137173806, 0.6096426602918618, 0.9542348997632368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 362}], {
             RGBColor[
             0.4538874638081069, 0.5662041111673836, 0.9505158832119648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 165}], {
             RGBColor[
             0.43209168429834016`, 0.5465211004605023, 0.9493493893401392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 167}], {
             RGBColor[
             0.30749203096032607`, 0.43842628345076595`, 0.9408993959616536]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 192}], {
             RGBColor[
             0.3379621693046799, 0.46714757740434754`, 0.9427556284732501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 201}], {
             RGBColor[
             0.30393044061377905`, 0.43468282617867443`, 0.9406965686603185]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 210}], {
             RGBColor[
             0.3156791522092831, 0.44703146697688845`, 0.9413656404050212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 228}], {
             RGBColor[
             0.3496458859290326, 0.47726742550368945`, 0.9435001045650488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 236}], {
             RGBColor[
             0.2909783973419341, 0.4210694074929913, 0.9399589689568179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 243}], {
             RGBColor[
             0.3099032733211534, 0.44096065205359114`, 0.9410367126469893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 263}], {
             RGBColor[
             0.29675910238603487`, 0.4271452950122101, 0.9402881715572926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 166}], {
             RGBColor[
             0.8279080891724726, 0.21551937954808684`, 0.17435812375022539`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 185}], {
             RGBColor[
             0.8275485490979918, 0.21275579698416247`, 0.17401382776886018`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 213}], {
             RGBColor[
             0.856641092447404, 0.37996388162178535`, 0.19964773389151264`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 224}], {
             RGBColor[
             0.8782055573021286, 0.46157635638612377`, 0.23722404279685397`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 247}], {
             RGBColor[
             0.8553209010665972, 0.37472976272458436`, 0.19858547691764086`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 289}], {
             RGBColor[
             0.8522361572582982, 0.36125661754027083`, 0.19603911206005595`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 302}], {
             RGBColor[
             0.8820773992231308, 0.47463698833737966`, 0.25226541752395265`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 340}], {
             RGBColor[
             0.8842444306145842, 0.48142224852336285`, 0.30529599505492633`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 370}], {
             RGBColor[
             0.8300572624743635, 0.4411399881686866, 0.44516184033330736`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 400}], {
             RGBColor[
             0.6828553570582352, 0.32234983124161043`, 0.43258959457210977`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 170}], {
             RGBColor[
             0.43820314080929235`, 0.5539712686639211, 0.9491428945379133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 222}], {
             RGBColor[
             0.5181817733764011, 0.6191282032508729, 0.9553764737486448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 239}], {
             RGBColor[
             0.3779757827321134, 0.5018053582125028, 0.9453052605381971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 251}], {
             RGBColor[
             0.6268762447587527, 0.7046334098478555, 0.9658130763902817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 312}], {
             RGBColor[
             0.44719691052756494`, 0.5614994937585587, 0.949788285319064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 326}], {
             RGBColor[
             0.3854134409611904, 0.5082474839429573, 0.9457791815436909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 327}], {
             RGBColor[
             0.3750143899762539, 0.4992403486513052, 0.9451165632104506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 337}], {
             RGBColor[
             0.35808998923330093`, 0.48236207273681253`, 0.9441194115332278]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.47490752561281135`, 0.5839962194337451, 0.9519697664459024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 179}], {
             RGBColor[
             0.25786357675267113`, 0.38836134703509095`, 0.9379963212698641]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 231}], {
             RGBColor[
             0.27738405997012383`, 0.4088786125667542, 0.9391079839111312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 313}], {
             RGBColor[
             0.26444617460999714`, 0.3952800747439503, 0.938371190479758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 359}], {
             RGBColor[
             0.24582605828944576`, 0.3757091519074889, 0.9373108024012962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 164}], {
             RGBColor[
             0.24375587866941067`, 0.373533261869863, 0.9371929087344915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 169}], {
             RGBColor[
             0.23283585906700827`, 0.36205562889850595`, 0.936571029772856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 209}], {
             RGBColor[
             0.2485031193706023, 0.3785229128392603, 0.9374632570695112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 227}], {
             RGBColor[
             0.23994763052693538`, 0.3695305516152434, 0.9369760346365759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 240}], {
             RGBColor[
             0.2420898799764604, 0.3717821916131542, 0.9370980325735522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 245}], {
             RGBColor[
             0.2374360489235272, 0.36689072010659024`, 0.9368330037798137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 280}], {
             RGBColor[
             0.24199322930997053`, 0.37168060563466715`, 0.9370925284610774]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 304}], {
             RGBColor[
             0.23203584179739814`, 0.3612147600241211, 0.9365254699728711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 315}], {
             RGBColor[
             0.24412373790812583`, 0.3739199052533755, 0.9372138577739373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 319}], {
             RGBColor[
             0.2432784612852803, 0.3730314659291315, 0.9371657205207411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 329}], {
             RGBColor[
             0.2400560374603316, 0.3696444941756393, 0.936982208251059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 371}], {
             RGBColor[
             0.25850942763125473`, 0.3890401772577931, 0.9380331015219487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 169}], {
             RGBColor[
             0.23161848816298614`, 0.3607760948926053, 0.9365017023008109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 209}], {
             RGBColor[
             0.24728574846658016`, 0.37724337883335973`, 0.9373939295974659]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 227}], {
             RGBColor[
             0.23873025962291325`, 0.36825101760934276`, 0.9369067071645306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 245}], {
             RGBColor[
             0.23621867801950508`, 0.36561118610068966`, 0.9367636763077685]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 280}], {
             RGBColor[
             0.2407758584059484, 0.37040107162876656`, 0.9370232009890322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 304}], {
             RGBColor[
             0.230818470893376, 0.3599352260182205, 0.936456142500826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 315}], {
             RGBColor[
             0.2429063670041037, 0.37264037124747484`, 0.9371445303018922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 228}], {
             RGBColor[
             0.4503029757321284, 0.5622948057743279, 0.9505097967266875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 262}], {
             RGBColor[
             0.7356958172611161, 0.7926545035064209, 0.9725524468455675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 298}], {
             RGBColor[
             0.6780894534855002, 0.7467966667692734, 0.969689888365638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 307}], {
             RGBColor[
             0.7589943744265952, 0.8098564226113569, 0.9253172138967432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 314}], {
             RGBColor[
             0.7292803775430885, 0.7876149200721775, 0.9745725244009281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 332}], {
             RGBColor[
             0.5299851907540822, 0.6293048792717479, 0.9561415220973347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 385}], {
             RGBColor[
             0.5540849096952511, 0.648870116788155, 0.9580387402525627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 185}], {
             RGBColor[
             0.824409563858564, 0.1886281809218183, 0.17100793195860742`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 213}], {
             RGBColor[
             0.8535021072079764, 0.35583626555944115`, 0.1966418380812599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 224}], {
             RGBColor[
             0.8750665720627008, 0.43744874032377956`, 0.2342181469866012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 247}], {
             RGBColor[
             0.8521819158271694, 0.35060214666224016`, 0.1955795811073881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 289}], {
             RGBColor[
             0.8490971720188705, 0.3371290014779267, 0.1930332162498032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 302}], {
             RGBColor[
             0.878938413983703, 0.4505093722750355, 0.24925952171369992`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 340}], {
             RGBColor[
             0.8811054453751566, 0.4572946324610186, 0.30229009924467354`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 400}], {
             RGBColor[
             0.6797163718188075, 0.2982222151792662, 0.42958369876185704`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 192}], {
             RGBColor[
             0.3140196057697616, 0.4440801406652496, 0.941315327256403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[
             0.27998787707886075`, 0.41161538943957654`, 0.9392562674434715]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.2874735215718495, 0.4194832764189812, 0.9396825638233285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 228}], {
             RGBColor[
             0.32570332239411426`, 0.45419998876459156`, 0.9420598033482018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 243}], {
             RGBColor[
             0.28596070978623506`, 0.41789321531449325`, 0.9395964114301423]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 348}], {
             RGBColor[
             0.2732523450214962, 0.4045359181898883, 0.9388726888571313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 351}], {
             RGBColor[
             0.2646469792533301, 0.39549113315584294`, 0.938382626007132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 170}], {
             RGBColor[
             0.5575600626847299, 0.651038994684655, 0.958666022792408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 180}], {
             RGBColor[
             0.5182102560481305, 0.6169561699548207, 0.9561586879091916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 220}], {
             RGBColor[
             0.5727925024434088, 0.663632053166977, 0.9598025445321408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 251}], {
             RGBColor[
             0.7462331666341901, 0.8017011358685895, 0.9753362046447762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 282}], {
             RGBColor[
             0.6585061316418895, 0.73314926196139, 0.9665973951785392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 350}], {
             RGBColor[
             0.5514466203488134, 0.6457438382038303, 0.9582764796526682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 357}], {
             RGBColor[
             0.6729202964028389, 0.7444097170243531, 0.9680340644138824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 394}], {
             RGBColor[
             0.5145092206731405, 0.613750519132451, 0.9559228612077943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 209}], {
             RGBColor[
             0.23636572886417778`, 0.36576574586200267`, 0.9367720506358304]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 227}], {
             RGBColor[
             0.22781024002051087`, 0.3567733846379857, 0.936284828202895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 240}], {
             RGBColor[
             0.22995248947003588`, 0.35902502463589653`, 0.9364068261398715]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 245}], {
             RGBColor[
             0.22529865841710267`, 0.3541335531293326, 0.936141797346133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 280}], {
             RGBColor[
             0.229855838803546, 0.3589234386574095, 0.9364013220273968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 292}], {
             RGBColor[
             0.21585857380573317`, 0.34421142566684904`, 0.9356041984928691]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 304}], {
             RGBColor[
             0.21989845129097363`, 0.3484575930468634, 0.9358342635391905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 315}], {
             RGBColor[
             0.23198634740170132`, 0.3611627382761178, 0.9365226513402567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 329}], {
             RGBColor[
             0.22791864695390707`, 0.3568873271983817, 0.9362910018173783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 353}], {
             RGBColor[
             0.21553905850906607`, 0.343875594831612, 0.9355860025694045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 378}], {
             RGBColor[
             0.21461245212241514`, 0.34290167276900374`, 0.9355332337064761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 180}], {
             RGBColor[
             0.40561982873439206`, 0.5257492414295251, 0.9470667147047922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 239}], {
             RGBColor[
             0.38474227729381244`, 0.5076661557079413, 0.9457364155882924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 251}], {
             RGBColor[
             0.6336427393204518, 0.7104942073432939, 0.966244231440377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 271}], {
             RGBColor[
             0.37587875919358854`, 0.49980798052879155`, 0.9451782688612774]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 282}], {
             RGBColor[
             0.5459157043281511, 0.6419423334360943, 0.9575054219741398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 326}], {
             RGBColor[
             0.39217993552288943`, 0.5141082814383957, 0.9462103365937862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 182}], {
             RGBColor[
             0.2806534492526592, 0.41231494799395196`, 0.9392941707941435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 244}], {
             RGBColor[
             0.266624380952421, 0.39756950771609656`, 0.9384952361085915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 253}], {
             RGBColor[
             0.30746418261270597`, 0.43744644735605664`, 0.9409326149067666]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 270}], {
             RGBColor[
             0.2613998670743656, 0.3920782123769482, 0.9381977077722119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 308}], {
             RGBColor[
             0.26715048285961845`, 0.3981224741773486, 0.9385251968339084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 397}], {
             RGBColor[
             0.26128106780929927`, 0.39195334681705507`, 0.9381909423298143]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 211}], {
             RGBColor[
             0.2820509294380053, 0.413783788274112, 0.9393737552233123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 328}], {
             RGBColor[
             0.3054309232922502, 0.438293739399488, 0.9407075511532149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 347}], {
             RGBColor[
             0.29073737323035515`, 0.422913791452218, 0.9398684353468445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 364}], {
             RGBColor[
             0.3254772137216906, 0.45565682861361634`, 0.9419848830531403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 387}], {
             RGBColor[
             0.29749670616801155`, 0.43001827893615596`, 0.9402533693581072]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 175}], {
             RGBColor[
             0.20264987627198583`, 0.3303282470790865, 0.9348519827088393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 197}], {
             RGBColor[
             0.607559522477704, 0.6724367666110929, 0.8861420267905455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 204}], {
             RGBColor[
             0.20264730553141047`, 0.33032554506774736`, 0.9348518363089665]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 214}], {
             RGBColor[
             0.6050703523847987, 0.6713378352539525, 0.9242773858520503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 261}], {
             RGBColor[
             0.2029079903175545, 0.3305995413063548, 0.9348666819218888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 295}], {
             RGBColor[
             0.23437748052955032`, 0.36367597080008385`, 0.9366588228345232]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 310}], {
             RGBColor[
             0.20447288081658893`, 0.33224434044062834`, 0.9349558001207607]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 345}], {
             RGBColor[
             0.21415750276433887`, 0.34242349214821033`, 0.9355073250135709]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 193}], {
             RGBColor[
             0.7754724977883137, 0.8245433157037161, 0.9782504569369469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 232}], {
             RGBColor[
             0.6270810139261389, 0.7068104580353534, 0.9646885621008761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 235}], {
             RGBColor[
             0.7343495307888845, 0.7923987018062052, 0.9741567564086497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 260}], {
             RGBColor[
             0.7687797089830702, 0.819295818690549, 0.9775884348027377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 267}], {
             RGBColor[
             0.6499021646261236, 0.725337696254724, 0.9664851266806084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 272}], {
             RGBColor[
             0.6878111560407678, 0.756042569748228, 0.9695182461395961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 275}], {
             RGBColor[
             0.8603530123804088, 0.8894563784374243, 0.877080294609712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 281}], {
             RGBColor[
             0.6802997161269625, 0.7500157979571946, 0.9688781332846546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 291}], {
             RGBColor[
             0.7125484820155874, 0.7753675568103979, 0.9719838316093115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 338}], {
             RGBColor[
             0.8614468790047858, 0.8890515325777966, 0.796643588235805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 384}], {
             RGBColor[
             0.7385166114389616, 0.7956540568810313, 0.9745720920642666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 398}], {
             RGBColor[
             0.83401539327211, 0.8711277377968187, 0.9805027030161089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 204}], {
             RGBColor[
             0.17892957074057536`, 0.30539670201133906`, 0.9335011463998728]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 214}], {
             RGBColor[
             0.5813526175939636, 0.6464089921975442, 0.9229266959429565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 256}], {
             RGBColor[
             0.20212025348377827`, 0.329771579948656, 0.9348218214745575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 261}], {
             RGBColor[
             0.1791902555267194, 0.3056706982499465, 0.9335159920127951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 264}], {
             RGBColor[
             0.18448157797338877`, 0.31123221363061604`, 0.9338173249983228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 295}], {
             RGBColor[
             0.21065974573871524`, 0.33874712774367555`, 0.9353081329254295]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 310}], {
             RGBColor[
             0.18075514602575382`, 0.30731549738422004`, 0.933605110211667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 345}], {
             RGBColor[
             0.1904397679735038, 0.31749464909180203`, 0.9341566351044772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 186}], {
             RGBColor[
             0.23214557991116364`, 0.36133010173948693`, 0.9365317193961071]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 226}], {
             RGBColor[
             0.22722875741095702`, 0.3561622095472178, 0.9362517136285073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 294}], {
             RGBColor[
             0.21429151975408078`, 0.34256435250159695`, 0.9355149570828762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 341}], {
             RGBColor[
             0.21870360025711671`, 0.3472017288523488, 0.9357662185404361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 368}], {
             RGBColor[
             0.2143024966118115, 0.34257588987504495`, 0.9355155821986852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 379}], {
             RGBColor[
             0.2183904240990045, 0.34687256085365753`, 0.9357483836215341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 393}], {
             RGBColor[
             0.2193217433014607, 0.3478514363844869, 0.9358014208723507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 399}], {
             RGBColor[
             0.22535125221155355`, 0.3541888325419396, 0.9361447924849214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 200}], {
             RGBColor[
             0.2962840776702533, 0.42752676637236176`, 0.9402288709406241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 225}], {
             RGBColor[
             0.2895083029136421, 0.42040499749423077`, 0.9398430005920957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 296}], {
             RGBColor[
             0.3117150207517371, 0.4437456659293011, 0.9411076403210801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 311}], {
             RGBColor[
             0.42064126980492156`, 0.5369664823599833, 0.9485194381294991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 324}], {
             RGBColor[
             0.3009330775683418, 0.4324131600288711, 0.9404936246072413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 339}], {
             RGBColor[
             0.34383450141698674`, 0.4722338963280338, 0.9431298082827468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 360}], {
             RGBColor[
             0.31615011179738517`, 0.4482550694974156, 0.9413657834565303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 374}], {
             RGBColor[
             0.29900611365793894`, 0.43038779878246913`, 0.9403838868632315]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 375}], {
             RGBColor[
             0.28837692064883436`, 0.4192158430001391, 0.939778570045845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 383}], {
             RGBColor[
             0.3010724134398118, 0.43255961086419054`, 0.9405015595789926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 390}], {
             RGBColor[
             0.2941038875347629, 0.4252352483079229, 0.9401047123377103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 209}], {
             RGBColor[
             0.24801071646784933`, 0.37800536616831976`, 0.9374352154526442]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 229}], {
             RGBColor[
             0.24544230257567465`, 0.37530580032079786`, 0.9372889480811126]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 240}], {
             RGBColor[
             0.24159747707370743`, 0.3712646449422136, 0.9370699909566852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 245}], {
             RGBColor[
             0.23694364602077422`, 0.3663731734356497, 0.9368049621629467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 248}], {
             RGBColor[
             0.230098166399185, 0.35917814032488304`, 0.9364151222254768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 309}], {
             RGBColor[
             0.2573894464516083, 0.38786300602707646`, 0.9379693202506316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 315}], {
             RGBColor[
             0.24363133500537287`, 0.37340235858243487`, 0.9371858161570703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 319}], {
             RGBColor[
             0.24278605838252734`, 0.37251391925819094`, 0.9371376789038741]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 329}], {
             RGBColor[
             0.23956363455757862`, 0.36912694750469877`, 0.9369541666341921]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 334}], {
             RGBColor[
             0.25269374017822266`, 0.3829275210087747, 0.9377019067250372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 371}], {
             RGBColor[
             0.25801702472850174`, 0.38852263058685255`, 0.9380050599050818]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 388}], {
             RGBColor[
             0.23367677668762307`, 0.36293948663502873`, 0.9366189187873238]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 196}], {
             RGBColor[
             0.2837836367777321, 0.41560497354815545`, 0.9394724303429989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 231}], {
             RGBColor[
             0.28916364068982703`, 0.4212596987717169, 0.9397788136067902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 303}], {
             RGBColor[
             0.27962744891017854`, 0.4112365565818258, 0.9392357415924706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 313}], {
             RGBColor[
             0.2762257553297003, 0.407661160948913, 0.939042020175417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 344}], {
             RGBColor[
             0.29513590341832135`, 0.4264382934400302, 0.9401591514378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 359}], {
             RGBColor[
             0.2576056390091489, 0.3880902381124516, 0.9379816320969553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 239}], {
             RGBColor[
             0.3453924706572131, 0.47358333097810695`, 0.943229080705076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 271}], {
             RGBColor[
             0.3365289525569892, 0.46572515579895724`, 0.942670933978061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 282}], {
             RGBColor[
             0.5065658976915518, 0.60785950870626, 0.9549980870909234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 326}], {
             RGBColor[
             0.3528301288862901, 0.48002545670856134`, 0.9437030017105699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 350}], {
             RGBColor[
             0.3995063863984757, 0.5204540849487005, 0.9466771715650524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 394}], {
             RGBColor[
             0.36256898672280274`, 0.4884607658773212, 0.9443235531201786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 250}], {
             RGBColor[
             0.7777697545864616, 0.8245041838583995, 0.9019245302265969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 265}], {
             RGBColor[
             0.5796034948121, 0.6695872537851715, 0.9600476567506184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 322}], {
             RGBColor[
             0.5378642093893072, 0.6357014215455682, 0.9567617873060958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 362}], {
             RGBColor[
             0.4859856594800335, 0.59226287242109, 0.9530427707548238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 244}], {
             RGBColor[
             0.27406524356197104`, 0.4053903260966717, 0.9389189822264357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 253}], {
             RGBColor[
             0.31490504522225604`, 0.4452672657366318, 0.9413563610246107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 271}], {
             RGBColor[
             0.28286075625291396`, 0.4146349676025667, 0.9394198736623899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 273}], {
             RGBColor[
             0.26718551324119244`, 0.3981592933294373, 0.9385271917623162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 335}], {
             RGBColor[
             0.2697259044179279, 0.4008294055262898, 0.9386718632816594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 305}], {
             RGBColor[
             0.21033276310750965`, 0.33840344826638225`, 0.9352895117483098]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 325}], {
             RGBColor[
             0.2146653182782982, 0.3429572384507447, 0.9355362443558451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 213}], {
             RGBColor[
             0.8527830270590148, 0.3503091004315924, 0.1959532461185295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 224}], {
             RGBColor[
             0.8743474919137393, 0.4319215751959308, 0.2335295550238708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 247}], {
             RGBColor[
             0.8514628356782079, 0.3450749815343914, 0.1948909891446577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 289}], {
             RGBColor[
             0.8483780918699089, 0.3316018363500779, 0.1923446242870728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 302}], {
             RGBColor[
             0.8782193338347415, 0.4449822071471867, 0.2485709297509695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 340}], {
             RGBColor[
             0.880386365226195, 0.45176746733316986`, 0.3016015072819431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 400}], {
             RGBColor[
             0.6789972916698459, 0.2926950500514175, 0.4288951067991266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 189}], {
             RGBColor[
             0.2745072076984255, 0.4058548584262301, 0.9389441514301794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 200}], {
             RGBColor[
             0.2595636633022175, 0.3901482457903771, 0.9380931386838082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 226}], {
             RGBColor[
             0.24355084950968384`, 0.37331776322339055`, 0.9371812326271585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 241}], {
             RGBColor[
             0.2697148101734317, 0.4008177447719086, 0.9386712314808479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 255}], {
             RGBColor[
             0.2544713249858168, 0.38479587534694254`, 0.9378031375501286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 288}], {
             RGBColor[
             0.2467468316416792, 0.3766769430810886, 0.9373632390815438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 341}], {
             RGBColor[
             0.23502569235584353`, 0.3643572825285215, 0.9366957375390872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 374}], {
             RGBColor[
             0.2622856992899031, 0.3930092782004845, 0.9382481546064155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 393}], {
             RGBColor[
             0.23564383540018752`, 0.36500699006065973`, 0.9367309398710019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 399}], {
             RGBColor[
             0.24167334431028037`, 0.3713443862181124, 0.9370743114835726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 193}], {
             RGBColor[
             0.8331367258093362, 0.8697846265391334, 0.9839465187292714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 218}], {
             RGBColor[
             0.8769988069965478, 0.9047590594733392, 0.9881301231890498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 232}], {
             RGBColor[
             0.6847452419471614, 0.7520517688707707, 0.9703846238932006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 235}], {
             RGBColor[
             0.792013758809907, 0.8376400126416226, 0.9798528182009743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 275}], {
             RGBColor[
             0.9180172404014313, 0.9346976892728417, 0.8827763564020366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 279}], {
             RGBColor[
             0.8947917399967904, 0.8503099582405043, 0.6300514927715455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 281}], {
             RGBColor[
             0.7379639441479849, 0.795257108792612, 0.9745741950769791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 298}], {
             RGBColor[
             0.8336819864556111, 0.8702194025777671, 0.983998526176473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 306}], {
             RGBColor[
             0.9071549779062498, 0.8950638881018478, 0.6621967951023203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 195}], {
             RGBColor[
             0.25639031228130726`, 0.3868128526653249, 0.9379124210377194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 203}], {
             RGBColor[
             0.2792417470878428, 0.4108311595116429, 0.9392137764442834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 206}], {
             RGBColor[
             0.2493239941811602, 0.37938570431162577`, 0.937510004675597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 208}], {
             RGBColor[
             0.25008631824464794`, 0.38018695523648866`, 0.9375534179032552]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 258}], {
             RGBColor[
             0.2600095899871553, 0.39061694300963157`, 0.938118533548826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 278}], {
             RGBColor[
             0.2597507710467335, 0.39034490789317966`, 0.9381037941930572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 284}], {
             RGBColor[
             0.25554200422115014`, 0.38592122710826227`, 0.9378641111486529]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 327}], {
             RGBColor[
             0.2928390260811543, 0.4242124195155595, 0.9400214534598996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 361}], {
             RGBColor[
             0.3113562197109362, 0.44025108193646334`, 0.9412013526638779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 369}], {
             RGBColor[
             0.26226993371413826`, 0.39299270758076044`, 0.9382472567801988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 392}], {
             RGBColor[
             0.25751756533120074`, 0.38799766709273437`, 0.9379766164312895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 200}], {
             RGBColor[
             0.28560319899075254`, 0.41751744880094743`, 0.9395760517192293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 219}], {
             RGBColor[
             0.37386729373661226`, 0.4974887142474586, 0.9450712281757306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 241}], {
             RGBColor[
             0.2957543458619668, 0.428186947782479, 0.9401541445162689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 255}], {
             RGBColor[
             0.28051086067435194`, 0.4121650783575129, 0.9392860505855498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 339}], {
             RGBColor[
             0.333153622737486, 0.4622245787566195, 0.942476989061352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 360}], {
             RGBColor[
             0.30546923311788443`, 0.43824575192600135`, 0.9407129642351355]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 374}], {
             RGBColor[
             0.2883252349784382, 0.42037848121105487`, 0.9397310676418367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 266}], {
             RGBColor[
             0.24805045871485498`, 0.3780471377897267, 0.9374374787148178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 273}], {
             RGBColor[
             0.2582701914773965, 0.38878872489163985`, 0.9380194773769047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 365}], {
             RGBColor[
             0.24867185173243342`, 0.3787002612497945, 0.9374728661279003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 198}], {
             RGBColor[
             0.7526714957518834, 0.806764542665624, 0.9759689648481673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 216}], {
             RGBColor[
             0.6689774683276695, 0.7413295497654275, 0.9676410801591727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 219}], {
             RGBColor[
             0.5630206032370957, 0.6553990201614963, 0.9591704044347413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 220}], {
             RGBColor[
             0.5771439386381384, 0.6670314281944398, 0.9602362550255482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 311}], {
             RGBColor[
             0.5991137006259042, 0.6848674707026068, 0.961965795167115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 323}], {
             RGBColor[
             0.7545318035699571, 0.8082479016230455, 0.9761464026685716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 339}], {
             RGBColor[
             0.5223069322379694, 0.6201348846706572, 0.9565761653203628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 357}], {
             RGBColor[
             0.6772717325975683, 0.7478090920518159, 0.9684677749072899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 201}], {
             RGBColor[
             0.3104580154232146, 0.4403366833931581, 0.941112499955068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 203}], {
             RGBColor[
             0.31794365991620344`, 0.4482045703725628, 0.9415387963349251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 228}], {
             RGBColor[
             0.35617346073846823`, 0.48292128271817314`, 0.9439160358597984]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 243}], {
             RGBColor[
             0.31643084813058897`, 0.44661450926807483`, 0.9414526439417388]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 332}], {
             RGBColor[
             0.43585567576042195`, 0.5499313562155932, 0.9495477612304457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 348}], {
             RGBColor[
             0.30372248336585006`, 0.4332572121434699, 0.9407289213687278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 361}], {
             RGBColor[
             0.35005813253929685`, 0.4776244927973833, 0.9435263725545195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 385}], {
             RGBColor[
             0.45995539470159097`, 0.5694965937320001, 0.9514449793856737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 232}], {
             RGBColor[
             0.6739481277148399, 0.7434424430617759, 0.9693547854990241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 235}], {
             RGBColor[
             0.7812166445775857, 0.8290306868326278, 0.9788229798067978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 260}], {
             RGBColor[
             0.8156468227717713, 0.8559278037169716, 0.9822546582008858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 275}], {
             RGBColor[
             0.9072201261691099, 0.9260883634638468, 0.8817465180078601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 281}], {
             RGBColor[
             0.7271668299156635, 0.7866477829836171, 0.9735443566828026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 338}], {
             RGBColor[
             0.9083139927934867, 0.9256835176042191, 0.801309811633953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 384}], {
             RGBColor[
             0.7853837252276628, 0.8322860419074539, 0.9792383154624147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 376}], {
             RGBColor[
             0.4132241787161002, 0.5323357471779375, 0.947551257161364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 377}], {
             RGBColor[
             0.40146722310948635`, 0.5221524631532592, 0.9468021143463783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 396}], {
             RGBColor[
             0.3331772870037427, 0.4601881672994485, 0.9425538104147095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 206}], {
             RGBColor[
             0.2386283880050733, 0.3681439440799593, 0.9369009057266002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 208}], {
             RGBColor[
             0.239390712068561, 0.3689451950048222, 0.9369443189542583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 258}], {
             RGBColor[
             0.24931398381106837`, 0.3793751827779651, 0.9375094345998292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 278}], {
             RGBColor[
             0.24905516487064655`, 0.3791031476615132, 0.9374946952440605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 284}], {
             RGBColor[
             0.24484639804506322`, 0.3746794668765958, 0.9372550121996561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 327}], {
             RGBColor[
             0.2821434199050674, 0.41297065928389304`, 0.9394123545109028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 337}], {
             RGBColor[
             0.26521901916211443`, 0.39609238336940045`, 0.9384152028336801]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 369}], {
             RGBColor[
             0.2515743275380513, 0.381750947349094, 0.9376381578312021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 392}], {
             RGBColor[
             0.24682195915511385`, 0.3767559068610679, 0.9373675174822926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 231}], {
             RGBColor[
             0.3033041199951848, 0.43612223907981873`, 0.9405840929842658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 234}], {
             RGBColor[
             0.3183317548341577, 0.44914414193399255`, 0.9415414311188043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 290}], {
             RGBColor[
             0.3515289166579535, 0.47789785496789633`, 0.943656724915119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 303}], {
             RGBColor[
             0.29376792821553643`, 0.42609909688992764`, 0.9400410209699464]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 313}], {
             RGBColor[
             0.2903662346350581, 0.4225237012570149, 0.9398472995528928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 344}], {
             RGBColor[
             0.3092763827236792, 0.441300833748132, 0.9409644308152758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 204}], {
             RGBColor[
             0.5838392169462935, 0.6475052215433456, 0.8847911904815791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 215}], {
             RGBColor[
             0.87577594264947, 0.4293808885383422, 0.3894295971862648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 295}], {
             RGBColor[
             0.6155693919444334, 0.6808556472756819, 0.8865981770071358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 310}], {
             RGBColor[
             0.5856647922314719, 0.6494240169162264, 0.8848951542933734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 345}], {
             RGBColor[
             0.5953494141792219, 0.6596031686238084, 0.8854466791861835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 216}], {
             RGBColor[
             0.7427956016916255, 0.7990494191661757, 0.974984628023718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 219}], {
             RGBColor[
             0.6368387366010516, 0.7131188895622445, 0.9665139522992866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 224}], {
             RGBColor[
             0.901075568718926, 0.8970235530331128, 0.6716312488962854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 247}], {
             RGBColor[
             0.866748584365629, 0.7667536625408037, 0.6136734000774657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 302}], {
             RGBColor[
             0.9068833316004294, 0.9166145009599966, 0.6941933109869335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 311}], {
             RGBColor[
             0.6729318339898602, 0.7425873401033549, 0.9693093430316602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 323}], {
             RGBColor[
             0.828349936933913, 0.8659677710237936, 0.9834899505331167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 340}], {
             RGBColor[
             0.9101338786876096, 0.9267923912389714, 0.7737391772833939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 212}], {
             RGBColor[
             0.21834996970250586`, 0.3468300407179805, 0.9357460798035004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 238}], {
             RGBColor[
             0.22751293603602638`, 0.35646089930013114`, 0.9362678971808005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 252}], {
             RGBColor[
             0.2250679449332263, 0.3538910586296987, 0.9361286585545363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 277}], {
             RGBColor[
             0.24180779724081597`, 0.3714857047729135, 0.9370819683790612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 287}], {
             RGBColor[
             0.24300807911222783`, 0.3727472771220335, 0.9371503226559803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 293}], {
             RGBColor[
             0.21851691429369074`, 0.3470055100682143, 0.9357555870509962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 299}], {
             RGBColor[
             0.21996573354153404`, 0.3485283109581435, 0.9358380951638248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 336}], {
             RGBColor[
             0.2184046627263886, 0.34688752655381927`, 0.9357491944902996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 367}], {
             RGBColor[
             0.2225587298907346, 0.35125371452661747`, 0.9359857624699174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 225}], {
             RGBColor[
             0.26388387983793327`, 0.3946890672869635, 0.9383391686243296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 241}], {
             RGBColor[
             0.2808108014657587, 0.41248033514662596`, 0.9393031317698977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 255}], {
             RGBColor[
             0.26556731627814384`, 0.3964584657216599, 0.9384350378391786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 288}], {
             RGBColor[
             0.25784282293400623`, 0.38833953345580596`, 0.9379951393705938]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 296}], {
             RGBColor[
             0.2860905976760283, 0.41802973572203384`, 0.939603808353314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 339}], {
             RGBColor[
             0.3182100783412779, 0.4465179661207665, 0.9416259763149808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 355}], {
             RGBColor[
             0.2507904105311417, 0.380927000871623, 0.9375935149173598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 360}], {
             RGBColor[
             0.29052568872167633`, 0.4225391392901483, 0.9398619514887643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 374}], {
             RGBColor[
             0.27338169058223005`, 0.4046718685752019, 0.9388800548954654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 375}], {
             RGBColor[
             0.26275249757312547`, 0.3934999127928718, 0.9382747380780788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 383}], {
             RGBColor[
             0.27544799036410295`, 0.4068436806569232, 0.9389977276112265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 399}], {
             RGBColor[
             0.2527693356026074, 0.3830069765928298, 0.9377062117726225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 210}], {
             RGBColor[
             0.2881749983278178, 0.42022057296569904`, 0.9397225118868391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 228}], {
             RGBColor[
             0.3221417320475673, 0.45045653149250003`, 0.9418569760468667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 236}], {
             RGBColor[
             0.26347424346046877`, 0.3942585134818019, 0.9383158404386357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 243}], {
             RGBColor[
             0.2823991194396881, 0.4141497580424017, 0.9393935841288071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 263}], {
             RGBColor[
             0.26925494850456955`, 0.4003344010010207, 0.9386450430391104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 348}], {
             RGBColor[
             0.2696907546749492, 0.40079246091779686`, 0.9386698615557961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 351}], {
             RGBColor[
             0.26108538890678307`, 0.3917476758837515, 0.9381797987057969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 214}], {
             RGBColor[
             0.8988174484699203, 0.6185106129520341, 0.43850682995064416`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 217}], {
             RGBColor[
             0.8451683070696899, 0.34818897778180974`, 0.19088652790122868`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 257}], {
             RGBColor[
             0.8450954738030565, 0.347629149378724, 0.19081678268284705`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 264}], {
             RGBColor[
             0.634236755389537, 0.3950594272407488, 0.44576724932088835`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 268}], {
             RGBColor[
             0.8433327505676614, 0.3340800861612308, 0.18912879692192164`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 279}], {
             RGBColor[
             0.8861096305516358, 0.5634464075388576, 0.22609833972846935`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 300}], {
             RGBColor[
             0.867558676545166, 0.48716538120934694`, 0.2110304482193309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 306}], {
             RGBColor[
             0.8943517891579421, 0.5932823607797533, 0.24752854128231921`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 363}], {
             RGBColor[
             0.8583972484613908, 0.44556547598681506`, 0.20338592805907718`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 381}], {
             RGBColor[
             0.9019420935827297, 0.6198491310425445, 0.38880112820481405`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 243}], {
             RGBColor[
             0.28988476393267687`, 0.4220176450218065, 0.9398198805086642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 258}], {
             RGBColor[
             0.2721654186176039, 0.4033934896242831, 0.9388107900063931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 284}], {
             RGBColor[
             0.26769783285159876`, 0.3986977737229138, 0.93855636760622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 348}], {
             RGBColor[
             0.277176399167938, 0.4086603478972015, 0.9390961579356532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 361}], {
             RGBColor[
             0.32351204834138475`, 0.4530276285511149, 0.941893609121445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 369}], {
             RGBColor[
             0.2744257623445868, 0.405769254195412, 0.9389395132377659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 392}], {
             RGBColor[
             0.26967339396164935`, 0.4007742137073859, 0.9386688728888566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 261}], {
             RGBColor[
             0.17918768478614402`, 0.3056679962386074, 0.9335158456129223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 295}], {
             RGBColor[
             0.21065717499813985`, 0.33874442573233643`, 0.9353079865255567]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 310}], {
             RGBColor[
             0.18075257528517846`, 0.3073127953728809, 0.9336049638117943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 345}], {
             RGBColor[
             0.1904371972329284, 0.3174919470804629, 0.9341564887046044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 389}], {
             RGBColor[
             0.17900756331513207`, 0.305478677152213, 0.9335055879616141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 400}], {
             RGBColor[
             0.2842689537951664, 0.40863855928315673`, 0.939773820202813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 207}], {
             RGBColor[
             0.967562165289962, 0.8957834071543473, 0.4992706546503005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 221}], {
             RGBColor[
             0.9585637141169614, 0.9664203575638242, 0.8602427231177231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 230}], {
             RGBColor[
             0.9820628725503424, 0.9494608486926688, 0.5307965926515668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 250}], {
             RGBColor[
             0.9917478646376758, 0.990855544204543, 0.7864227690028461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 276}], {
             RGBColor[
             0.8804173286055655, 0.9045483902483498, 0.8526723312886473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 358}], {
             RGBColor[
             0.9819225924478814, 0.9489876509677333, 0.5302516309431803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 391}], {
             RGBColor[
             0.8786833642677919, 0.43592922474936013`, 0.3541318751407731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 208}], {
             RGBColor[
             0.23232439396841398`, 0.3615180466511231, 0.9365419025921359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 258}], {
             RGBColor[
             0.24224766571092132`, 0.37194803442426605`, 0.9371070182377067]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 278}], {
             RGBColor[
             0.24198884677049953`, 0.37167599930781414`, 0.937092278881938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 284}], {
             RGBColor[
             0.23778007994491618`, 0.3672523185228967, 0.9368525958375336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 369}], {
             RGBColor[
             0.2445080094379043, 0.3743237989953949, 0.9372357414690795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 392}], {
             RGBColor[
             0.23975564105496683`, 0.3693287585073688, 0.9369651011201702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 221}], {
             RGBColor[
             0.9308573670898133, 0.869892342221664, 0.6314368519575342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 230}], {
             RGBColor[
             0.9543565255231943, 0.8529328333505086, 0.30199072149137773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 233}], {
             RGBColor[
             0.8582574278703963, 0.3565499328346968, 0.19972248074073234`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 250}], {
             RGBColor[
             0.9640415176105277, 0.8943275288623829, 0.5576168978426572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 358}], {
             RGBColor[
             0.9542162454207332, 0.8524596356255733, 0.30144575978299126`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 366}], {
             RGBColor[
             0.9205681319812286, 0.7219373884597544, 0.2549015531776194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 391}], {
             RGBColor[
             0.8602124662496932, 0.37157721452125336`, 0.2015946277006471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[
             0.24300998977440907`, 0.3727492853491289, 0.9371504314653649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 278}], {
             RGBColor[
             0.24275117083398723`, 0.37247725023267697`, 0.9371356921095961]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 284}], {
             RGBColor[
             0.23854240400840393`, 0.3680535694477596, 0.9368960090651918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 369}], {
             RGBColor[
             0.24527033350139205`, 0.37512504992025775`, 0.9372791546967377]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 392}], {
             RGBColor[
             0.24051796511845452`, 0.3701300094322317, 0.9370085143478284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 227}], {
             RGBColor[
             0.24347750032410487`, 0.3732406685787401, 0.9371770554995502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 229}], {
             RGBColor[
             0.24946457527559712`, 0.37953346395523513`, 0.937518010560954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 240}], {
             RGBColor[
             0.24561974977362988`, 0.37549230857665095`, 0.9372990534365266]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 245}], {
             RGBColor[
             0.2409659187206967, 0.37060083707008695`, 0.9370340246427882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 280}], {
             RGBColor[
             0.24552309910713999`, 0.37539072259816386`, 0.9372935493240518]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 304}], {
             RGBColor[
             0.23556571159456763`, 0.3649248769876179, 0.9367264908358456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 315}], {
             RGBColor[
             0.24765360770529532`, 0.37763002221687225`, 0.9374148786369118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 319}], {
             RGBColor[
             0.24680833108244982`, 0.37674158289262827`, 0.9373667413837155]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 329}], {
             RGBColor[
             0.24358590725750107`, 0.37335461113913604`, 0.9371832291140334]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 334}], {
             RGBColor[
             0.2567160128781451, 0.387155184643212, 0.9379309692048785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 371}], {
             RGBColor[
             0.26203929742842424`, 0.3927502942212898, 0.9382341223849231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 236}], {
             RGBColor[
             0.27522295505597283`, 0.4066071542800159, 0.9389849121833385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 263}], {
             RGBColor[
             0.2810036601000736, 0.41268304179923465`, 0.9393141147838132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 301}], {
             RGBColor[
             0.25974755171345176`, 0.39034152416978307`, 0.9381036108567895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 328}], {
             RGBColor[
             0.2860571913279975, 0.41793071873950494`, 0.9396042457787188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 347}], {
             RGBColor[
             0.27136364126610246`, 0.4025507707922349, 0.9387651299723484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 372}], {
             RGBColor[
             0.257077351430105, 0.3875349743715093, 0.9379515469008601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 387}], {
             RGBColor[
             0.27812297420375887`, 0.4096552582761729, 0.939150063983611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 238}], {
             RGBColor[
             0.22006014114382055`, 0.3486275393339343, 0.9358434715371114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 259}], {
             RGBColor[
             0.2109589325174653, 0.33906159201767927`, 0.935325171169872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 293}], {
             RGBColor[
             0.2110641194014849, 0.3391721501020175, 0.935331161407307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 299}], {
             RGBColor[
             0.2125129386493282, 0.3406949509919467, 0.9354136695201356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 336}], {
             RGBColor[
             0.21095186783418274`, 0.3390541665876225, 0.9353247688466104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 367}], {
             RGBColor[
             0.21510593499852879`, 0.3434203545604207, 0.9355613368262283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 224}], {
             RGBColor[
             0.9433148110399261, 0.8071439818533458, 0.30358552172184644`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 230}], {
             RGBColor[
             0.939912673270707, 0.7956677722978341, 0.2903688589282392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 247}], {
             RGBColor[
             0.9089878266866289, 0.6768740913610367, 0.24562767290302676`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 250}], {
             RGBColor[
             0.9495976653580405, 0.8370624678097084, 0.5459950352795185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 289}], {
             RGBColor[
             0.9043607109741805, 0.6566643735845665, 0.24180812561664938`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 302}], {
             RGBColor[
             0.9491225739214294, 0.8267349297802298, 0.3261475838124945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 340}], {
             RGBColor[
             0.9523731210086097, 0.8369128200592044, 0.40569345010895497`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 391}], {
             RGBColor[
             0.8505832314147017, 0.33340050715280367`, 0.19384671932522138`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 215}], {
             RGBColor[
             0.8741164959208666, 0.4286482676335819, 0.4148531698939346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 217}], {
             RGBColor[
             0.8764748109063158, 0.44677531003196125`, 0.4171114949873367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 261}], {
             RGBColor[
             0.5816107316395323, 0.6466802864248125, 0.9229413951560062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 264}], {
             RGBColor[
             0.5869020540862017, 0.6522418018054821, 0.9232427281415339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 295}], {
             RGBColor[
             0.6130802218515281, 0.6797567159185416, 0.9247335360686406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 300}], {
             RGBColor[
             0.9368849358196452, 0.7904007327583793, 0.5711375264891978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 310}], {
             RGBColor[
             0.5831756221385668, 0.6483250855590861, 0.9230305133548782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 363}], {
             RGBColor[
             0.9029326936897176, 0.6415283064419719, 0.4421102953030337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 217}], {
             RGBColor[
             0.8204673545206362, 0.1583266324633574, 0.16723286784451905`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 269}], {
             RGBColor[
             0.8772117743486348, 0.4286960994750255, 0.27269761678998694`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 295}], {
             RGBColor[
             0.6269879146840343, 0.22354035799766941`, 0.4231074612155832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 300}], {
             RGBColor[
             0.8428577239961123, 0.2973030358908946, 0.18737678816262127`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 352}], {
             RGBColor[
             0.8775768432069465, 0.42947694484883064`, 0.31243310907337485`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 363}], {
             RGBColor[
             0.8336962959123371, 0.2557031306683627, 0.17973226800236758`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 219}], {
             RGBColor[
             0.5531447091768378, 0.647683896662048, 0.958186067610292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 220}], {
             RGBColor[
             0.5672680445778805, 0.6593163046949915, 0.9592519182010989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 311}], {
             RGBColor[
             0.5892378065656463, 0.6771523472031584, 0.9609814583426657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 323}], {
             RGBColor[
             0.7446559095096992, 0.8005327781235971, 0.9751620658441222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 339}], {
             RGBColor[
             0.5124310381777115, 0.6124197611712089, 0.9555918284959135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 357}], {
             RGBColor[
             0.6673958385373104, 0.7400939685523675, 0.9674834380828405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 268}], {
             RGBColor[
             0.820990113004057, 0.1623447832411579, 0.16773346195861408`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 269}], {
             RGBColor[
             0.8795700893340841, 0.446823141873405, 0.274955941883389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 279}], {
             RGBColor[
             0.8637669929880314, 0.39171110461878467`, 0.2047030047651618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 300}], {
             RGBColor[
             0.8452160389815616, 0.31543007828927405`, 0.18963511325602334`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 306}], {
             RGBColor[
             0.8720091515943377, 0.4215470578596804, 0.22613320631901165`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 363}], {
             RGBColor[
             0.8360546108977863, 0.2738301730667422, 0.18199059309576965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 262}], {
             RGBColor[
             0.9243533171861171, 0.9424423464401257, 0.9900148507220045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 269}], {
             RGBColor[
             0.9515613514707596, 0.9593431212476458, 0.7385846645144882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 279}], {
             RGBColor[
             0.9278567069516805, 0.8766750653657154, 0.6332052588371474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 298}], {
             RGBColor[
             0.8667469534105012, 0.8965845097029781, 0.9871522922420749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.9000302759419758, 0.7622535258714493, 0.6106034215734397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 306}], {
             RGBColor[
             0.9402199448611399, 0.9214289952270589, 0.6653505611679222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 314}], {
             RGBColor[
             0.9179378774680893, 0.9374027630058823, 0.9920349282773651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 220}], {
             RGBColor[
             0.4613111794873067, 0.5733857750910603, 0.9507812424766675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 241}], {
             RGBColor[
             0.36907489621161843`, 0.49245160059313714`, 0.9447983082263991]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 311}], {
             RGBColor[
             0.48328094147507245`, 0.5912218175992272, 0.9525107826182344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 323}], {
             RGBColor[
             0.6386990444191253, 0.7146022485196659, 0.9666913901196909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 339}], {
             RGBColor[
             0.4064741730871376, 0.5264892315672777, 0.9471211527714821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 357}], {
             RGBColor[
             0.5614389734467367, 0.6541634389484363, 0.9590127623584092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 360}], {
             RGBColor[
             0.37878978346753606`, 0.5025104047366595, 0.9453571279452656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 350}], {
             RGBColor[
             0.454088632793754, 0.5671299681608568, 0.9503210281880017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 357}], {
             RGBColor[
             0.5755623088477795, 0.6657958469813797, 0.960078612949216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 394}], {
             RGBColor[
             0.4171512331180811, 0.5351366490894776, 0.9479674097431279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 230}], {
             RGBColor[
             0.9453580743501937, 0.9235697837599854, 0.6629627899588003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 250}], {
             RGBColor[
             0.955043066437527, 0.9649644792718597, 0.9185889663100797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 276}], {
             RGBColor[
             0.8437125304054167, 0.8786573253156666, 0.9848385285958808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 358}], {
             RGBColor[
             0.9452177942477327, 0.9230965860350502, 0.6624178282504138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 251}], {
             RGBColor[
             0.7136213718875605, 0.7756511419302459, 0.9724778106511085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 297}], {
             RGBColor[
             0.7757829604608912, 0.8249349923236523, 0.9686258035292561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 312}], {
             RGBColor[
             0.5339420376563727, 0.632517225840949, 0.9564530195798908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 332}], {
             RGBColor[
             0.5660742539559687, 0.6586036065728093, 0.9589825853511816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 356}], {
             RGBColor[
             0.5616526527416191, 0.6550139515161355, 0.9586345007067291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 361}], {
             RGBColor[
             0.48027671073484357`, 0.5862967431545993, 0.9529611966752556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 260}], {
             RGBColor[
             0.6315106131402652, 0.7091757673875206, 0.9658788076150083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 267}], {
             RGBColor[
             0.5126330687833186, 0.6152176449516955, 0.954775499492879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 272}], {
             RGBColor[
             0.5505420601979628, 0.6459225184451997, 0.9578086189518668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 290}], {
             RGBColor[
             0.4296004547734099, 0.5464997120753861, 0.9486003596365518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 291}], {
             RGBColor[
             0.5752793861727824, 0.6652475055073694, 0.9602742044215822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 321}], {
             RGBColor[
             0.6359268279774656, 0.7126257479828174, 0.9663189746381065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 331}], {
             RGBColor[
             0.45307983116767014`, 0.5668363678003234, 0.9500964447383967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 342}], {
             RGBColor[
             0.5287126959381665, 0.6282718106549494, 0.9560413466441238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 346}], {
             RGBColor[
             0.3995496021231435, 0.5204711739094963, 0.9466855458786024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 384}], {
             RGBColor[
             0.6012475155961567, 0.6855340055780029, 0.9628624648765374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 398}], {
             RGBColor[
             0.696746297429305, 0.7610076864937902, 0.9687930758283795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 230}], {
             RGBColor[
             0.9722593705527938, 0.9180864844443417, 0.3467333222862512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 247}], {
             RGBColor[
             0.9413345239687156, 0.7992928035075443, 0.30199213626103877`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 289}], {
             RGBColor[
             0.9367074082562672, 0.779083085731074, 0.29817258897466137`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 302}], {
             RGBColor[
             0.981469271203516, 0.9491536419267372, 0.38251204717050646`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 323}], {
             RGBColor[
             0.9029358765369997, 0.8985069119905342, 0.6718086867166897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 340}], {
             RGBColor[
             0.9847198182906963, 0.959331532205712, 0.46205791346696695`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 288}], {
             RGBColor[
             0.25106704817739506`, 0.3812177645776751, 0.9376092690220652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 296}], {
             RGBColor[
             0.2793148229194171, 0.41090796684390285`, 0.9392179380047856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 316}], {
             RGBColor[
             0.2556938059368381, 0.38608078033623494`, 0.9378727560317908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 324}], {
             RGBColor[
             0.2685328797360218, 0.39957546094347285`, 0.9386039222909468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 355}], {
             RGBColor[
             0.24401463577453056`, 0.373805231993492, 0.9372076445688313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 375}], {
             RGBColor[
             0.2559767228165143, 0.3863781439147409, 0.9378888677295503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 380}], {
             RGBColor[
             0.2612993849996442, 0.39197259934548456`, 0.9381919854667065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 383}], {
             RGBColor[
             0.26867221560749177`, 0.39972191177879235`, 0.938611857262698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 390}], {
             RGBColor[
             0.26170368970244295`, 0.3923975492225247, 0.9382150100214157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 255}], {
             RGBColor[
             0.24955450248561023`, 0.3796279831546734, 0.9375231317825289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 266}], {
             RGBColor[
             0.24681597923856835`, 0.37674962158963, 0.9373671769348919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 294}], {
             RGBColor[
             0.22569678935260098`, 0.35455201398550057`, 0.9361644703139277]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 341}], {
             RGBColor[
             0.23010886985563692`, 0.3591893903362524, 0.9364157317714874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 368}], {
             RGBColor[
             0.2257077662103317, 0.35456355135894857`, 0.9361650954297367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 393}], {
             RGBColor[
             0.2307270128999809, 0.3598390978683905, 0.9364509341034022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 399}], {
             RGBColor[
             0.23675652181007376`, 0.36617649402584324`, 0.9367943057159729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 280}], {
             RGBColor[
             0.23696761026347307`, 0.36639836137414694`, 0.9368063268911165]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 304}], {
             RGBColor[
             0.22701022275090071`, 0.35593251576360085`, 0.9362392684029103]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 315}], {
             RGBColor[
             0.2390981188616284, 0.3686376609928552, 0.9369276562039764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 243}], {
             RGBColor[
             0.3281145647549416, 0.45673435736741674`, 0.9421971200335375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 332}], {
             RGBColor[
             0.44753939238477464`, 0.5600512043149352, 0.9502922373222444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 348}], {
             RGBColor[
             0.31540619999020275`, 0.44337706024281187`, 0.9414733974605265]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 361}], {
             RGBColor[
             0.3617418491636495, 0.4877443408967252, 0.9442708486463184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 385}], {
             RGBColor[
             0.4716391113259436, 0.5796164418313421, 0.9521894554774726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 240}], {
             RGBColor[
             0.24305133588145522`, 0.372792742729129, 0.9371527860649951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 245}], {
             RGBColor[
             0.238397504828522, 0.36790127122256505`, 0.9368877572712566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 248}], {
             RGBColor[
             0.2315520252069328, 0.36070623811179847`, 0.9364979173337866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 249}], {
             RGBColor[
             0.2582327214414536, 0.38874934150812634`, 0.9380173435137897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 309}], {
             RGBColor[
             0.25884330525935606`, 0.3893911038139919, 0.9380521153589414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 315}], {
             RGBColor[
             0.24508519381312066`, 0.3749304563693503, 0.9372686112653803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 319}], {
             RGBColor[
             0.24423991719027513`, 0.3740420170451063, 0.9372204740121839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[
             0.2410174933653264, 0.37065504529161414`, 0.937036961742502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 334}], {
             RGBColor[
             0.25414759898597045`, 0.3844556187956901, 0.9377847018333471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 371}], {
             RGBColor[
             0.25947088353624953`, 0.3900507283737679, 0.9380878550133916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 388}], {
             RGBColor[
             0.23513063549537086`, 0.3644675844219441, 0.9367017138956337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 247}], {
             RGBColor[
             0.9379323861994966, 0.7878165939520326, 0.28877547346743154`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 250}], {
             RGBColor[
             0.9785422248709081, 0.9480049704007043, 0.5891428358439234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 289}], {
             RGBColor[
             0.9333052704870481, 0.7676068761755623, 0.28495592618105414`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 358}], {
             RGBColor[
             0.9687169526811137, 0.9061370771638947, 0.3329716977842575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 391}], {
             RGBColor[
             0.8698796044232802, 0.407362175546801, 0.22261191970149125`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 234}], {
             RGBColor[
             0.3237117587462526, 0.454798867157554, 0.9418478143825956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 290}], {
             RGBColor[
             0.3569089205700484, 0.48355258019145775`, 0.9439631081789103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 313}], {
             RGBColor[
             0.295746238547153, 0.4281784264805763, 0.9401536828166841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 331}], {
             RGBColor[
             0.38038829696430865`, 0.5038892359163952, 0.9454591932807552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 359}], {
             RGBColor[
             0.2771261222266016, 0.4086075036441148, 0.9390932947382222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 235}], {
             RGBColor[
             0.6328251607154107, 0.7112978291642651, 0.965261084970727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 281}], {
             RGBColor[
             0.5787753460534887, 0.6689149253152545, 0.9599824618467317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 384}], {
             RGBColor[
             0.6369922413654878, 0.7145531842390913, 0.965676420626344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 386}], {
             RGBColor[
             0.4324598922567031, 0.5470353068857565, 0.9493188938960907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 242}], {
             RGBColor[
             0.8510877684244544, 0.3281246222789175, 0.19395360445699056`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 317}], {
             RGBColor[
             0.8751811761701102, 0.42026215689431723`, 0.37790000290961884`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 358}], {
             RGBColor[
             0.8678310459756758, 0.39201942871028744`, 0.22037646493598545`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 366}], {
             RGBColor[
             0.8453989703493394, 0.3050045972664083, 0.18934699386573758`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 382}], {
             RGBColor[
             0.8445657958761956, 0.3012213465767044, 0.18865177266237124`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 290}], {
             RGBColor[
             0.37193655540902126`, 0.4965744830456317, 0.9449204463134487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 313}], {
             RGBColor[
             0.3107738733861259, 0.4412003293347502, 0.9411110209512226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 331}], {
             RGBColor[
             0.3954159318032815, 0.5169111387705692, 0.9464165314152937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 342}], {
             RGBColor[
             0.47104879657377785`, 0.578346581625195, 0.9523614333210206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 346}], {
             RGBColor[
             0.34188570275875485`, 0.4705459448797419, 0.9430056325554994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 275}], {
             RGBColor[
             0.8660971591696807, 0.893943749566336, 0.8776528174795629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 281}], {
             RGBColor[
             0.6860438629162344, 0.7545031690861064, 0.9694506561545053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 384}], {
             RGBColor[
             0.7442607582282336, 0.800141428009943, 0.9751446149341176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 263}], {
             RGBColor[
             0.2563029052327246, 0.3867209823153376, 0.9379074433356098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 351}], {
             RGBColor[
             0.2481333456349381, 0.37813425719806837`, 0.9374421990022963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 246}], {
             RGBColor[
             0.5111109439056949, 0.6137235569467266, 0.9547270574586124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 254}], {
             RGBColor[
             0.5239652108029346, 0.6244175883504002, 0.9556676072236672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 286}], {
             RGBColor[
             0.652334455595527, 0.7273484229582274, 0.9666519351718024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 320}], {
             RGBColor[
             0.644156525821959, 0.7209597620645476, 0.9658368355590718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 343}], {
             RGBColor[
             0.6503098019378368, 0.7257667481329021, 0.9664501366166679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 349}], {
             RGBColor[
             0.5118990860533059, 0.6144062060618112, 0.9547772771793315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 252}], {
             RGBColor[
             0.22677811637454098`, 0.3556885572456525, 0.9362260502881472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 277}], {
             RGBColor[
             0.24351796868213066`, 0.3732832033888673, 0.9371793601126722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 287}], {
             RGBColor[
             0.24471825055354252`, 0.3745447757379873, 0.9372477143895912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 293}], {
             RGBColor[
             0.22022708573500543`, 0.3488030086841681, 0.935852978784607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 299}], {
             RGBColor[
             0.22167590498284873`, 0.3503258095740973, 0.9359354868974357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 336}], {
             RGBColor[
             0.22011483416770328`, 0.34868502516977307`, 0.9358465862239105]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 367}], {
             RGBColor[
             0.2242689013320493, 0.35305121314257126`, 0.9360831542035284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 396}], {
             RGBColor[
             0.25376131131834845`, 0.3840496059649667, 0.9377627033221374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 271}], {
             RGBColor[
             0.31565140111640955`, 0.4476420700773734, 0.9413406348615612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 326}], {
             RGBColor[
             0.3319525774457105, 0.4619423709869775, 0.94237270259407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 335}], {
             RGBColor[
             0.3025165492814234, 0.4338365080010965, 0.9405926244808307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 337}], {
             RGBColor[
             0.304629125717821, 0.43605695978083275`, 0.9407129325836068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 354}], {
             RGBColor[
             0.3021441775416652, 0.43344512169287874`, 0.940571418461126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 245}], {
             RGBColor[
             0.2345526793265548, 0.3638601158439808, 0.9366688001468292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 248}], {
             RGBColor[
             0.22770719970496556`, 0.3566650827332143, 0.9362789602093593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 292}], {
             RGBColor[
             0.2251125947151853, 0.3539379883814973, 0.9361312012935654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 304}], {
             RGBColor[
             0.22915247220042573`, 0.35818415576151175`, 0.9363612663398866]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 309}], {
             RGBColor[
             0.2549984797573888, 0.3853499484354077, 0.9378331582345141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 315}], {
             RGBColor[
             0.24124036831115342`, 0.3708893009907661, 0.9370496541409528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 319}], {
             RGBColor[
             0.24039509168830792`, 0.37000086166652213`, 0.9370015168877566]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 329}], {
             RGBColor[
             0.23717266786335917`, 0.3666138899130299, 0.9368180046180745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 334}], {
             RGBColor[
             0.2503027734840032, 0.3804144634171059, 0.9375657447089196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 371}], {
             RGBColor[
             0.2556260580342823, 0.3860095729951837, 0.9378688978889642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 388}], {
             RGBColor[
             0.23128580999340365`, 0.36042642904335986`, 0.9364827567712063]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 255}], {
             RGBColor[
             0.2757184631493581, 0.40712796470319146`, 0.9390131306362182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 288}], {
             RGBColor[
             0.2679939698052205, 0.39900903243733754`, 0.9385732321676334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 339}], {
             RGBColor[
             0.32836122521249217`, 0.457187465102298, 0.9422040691120204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 360}], {
             RGBColor[
             0.3006768355928906, 0.4332086382716799, 0.9404400442858039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 374}], {
             RGBColor[
             0.2835328374534444, 0.4153413675567334, 0.939458147692505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 375}], {
             RGBColor[
             0.2729036444443398, 0.40416941177440335`, 0.9388528308751185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 399}], {
             RGBColor[
             0.2629204824738216, 0.3936764755743613, 0.938284304569662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 256}], {
             RGBColor[
             0.5718276027056971, 0.5340616080097416, 0.5946502523941279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 257}], {
             RGBColor[
             0.8545203931124529, 0.3545092798166029, 0.19724068973481296`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 268}], {
             RGBColor[
             0.8509949466416629, 0.3274111533816164, 0.19386471821296208`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 317}], {
             RGBColor[
             0.954486951543472, 0.8521857620679489, 0.5290777523178287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 333}], {
             RGBColor[
             0.5569536477379948, 0.5184281382754727, 0.5938032026627618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 381}], {
             RGBColor[
             0.9557469344850966, 0.8527067973943953, 0.5081965742437817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 382}], {
             RGBColor[
             0.9085638811026002, 0.6736245465915296, 0.24520540694695725`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 348}], {
             RGBColor[
             0.27566358738232355`, 0.40707028679271356`, 0.9390100055424669]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 351}], {
             RGBColor[
             0.26705822161415743`, 0.39802550175866824`, 0.9385199426924677]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 253}], {
             RGBColor[
             0.30087597692201773`, 0.4305218254587764, 0.9405574263390588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 270}], {
             RGBColor[
             0.2548116613836774, 0.3851535904796679, 0.9378225192045042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 308}], {
             RGBColor[
             0.2605622771689302, 0.3911978522800683, 0.9381500082662007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 397}], {
             RGBColor[
             0.2546928621186111, 0.3850287249197748, 0.9378157537621064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 248}], {
             RGBColor[
             0.2230533686520324, 0.3517736112266503, 0.9360139314156208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 292}], {
             RGBColor[
             0.2204587636622521, 0.3490465168749334, 0.935866172499827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 304}], {
             RGBColor[
             0.22449864114749254`, 0.35329268425494775`, 0.9360962375461481]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 315}], {
             RGBColor[
             0.23658653725822024`, 0.3659978294842021, 0.9367846253472143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 319}], {
             RGBColor[
             0.2357412606353747, 0.36510939015995814`, 0.9367364880940181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 329}], {
             RGBColor[
             0.232518836810426, 0.36172241840646596`, 0.936552975824336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 353}], {
             RGBColor[
             0.220139248365585, 0.34871068603969635`, 0.9358479765763623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 371}], {
             RGBColor[
             0.25097222698134913`, 0.38111810148861974`, 0.9376038690952258]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 378}], {
             RGBColor[
             0.2192126419789341, 0.3477367639770881, 0.9357952077134337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 388}], {
             RGBColor[
             0.22663197894047044`, 0.3555349575367959, 0.9362177279774678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 254}], {
             RGBColor[
             0.4566571232556863, 0.569515492226385, 0.9504402532261262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 286}], {
             RGBColor[
             0.5850263680482788, 0.6724463268342122, 0.9614245811742612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 320}], {
             RGBColor[
             0.5768484382747107, 0.6660576659405324, 0.9606094815615308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 343}], {
             RGBColor[
             0.5830017143905886, 0.6708646520088869, 0.9612227826191269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 344}], {
             RGBColor[
             0.3822157528613575, 0.505477807231359, 0.9455754276855741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 349}], {
             RGBColor[
             0.44459099850605766`, 0.559504109937796, 0.9495499231817904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 289}], {
             RGBColor[
             0.9023804239029701, 0.648813195238765, 0.2402147401558417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 302}], {
             RGBColor[
             0.9471422868502191, 0.8188837514344283, 0.3245541983516868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 340}], {
             RGBColor[
             0.9503928339373993, 0.8290616417134029, 0.4041000646481473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 391}], {
             RGBColor[
             0.8492630400338947, 0.3281663882556027, 0.1927844623513496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 292}], {
             RGBColor[
             0.21361328404066288`, 0.34185148376416674`, 0.935476332562357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 304}], {
             RGBColor[
             0.2176531615259033, 0.3460976511441812, 0.9357063976086782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 315}], {
             RGBColor[
             0.229741057636631, 0.35880279637343554`, 0.9363947854097444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 319}], {
             RGBColor[
             0.2288957810137855, 0.3579143570491916, 0.9363466481565481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 329}], {
             RGBColor[
             0.22567335718883677`, 0.3545273852956994, 0.9361631358868661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 353}], {
             RGBColor[
             0.21329376874399575`, 0.34151565292892977`, 0.9354581366388923]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 388}], {
             RGBColor[
             0.21978649931888122`, 0.34833992442602935`, 0.935827888039998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 270}], {
             RGBColor[
             0.25957821450255336`, 0.3901635400245296, 0.9380939673531408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 308}], {
             RGBColor[
             0.2653288302878062, 0.39620780182492993`, 0.9384214564148372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 309}], {
             RGBColor[
             0.2701798653173872, 0.40130654721440506`, 0.9386977156833087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 334}], {
             RGBColor[
             0.2654841590440016, 0.39637106219610324`, 0.9384303021577143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 386}], {
             RGBColor[
             0.3044662110801129, 0.4345129066433197, 0.9407539204836926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 397}], {
             RGBColor[
             0.25945941523748706`, 0.39003867446463636`, 0.938087201910743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 265}], {
             RGBColor[
             0.7900609571838799, 0.8344827358393506, 0.9028921387192244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 276}], {
             RGBColor[
             0.8768966809261312, 0.9030925119563854, 0.9110185744810039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 289}], {
             RGBColor[
             0.9429902625743816, 0.8090015716874366, 0.5405821025323335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 391}], {
             RGBColor[
             0.8763362658148357, 0.4349586392213838, 0.39302937060234416`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 282}], {
             RGBColor[
             0.7345888082776114, 0.7926044746200289, 0.9741756038265081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 312}], {
             RGBColor[
             0.6426365090387243, 0.7180224324379316, 0.9668896222215277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 356}], {
             RGBColor[
             0.6703471241239707, 0.7405191581131181, 0.9690711033483659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 277}], {
             RGBColor[
             0.2410729775793306, 0.3707133627184349, 0.9370401214864079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 293}], {
             RGBColor[
             0.21778209463220533`, 0.3462331680137357, 0.9357137401583427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 330}], {
             RGBColor[
             0.2245525377985933, 0.3533493330524997, 0.9360993068806954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 386}], {
             RGBColor[
             0.3405394596215219, 0.4693798967384182, 0.942919851133231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 286}], {
             RGBColor[
             0.5978806349455185, 0.6831403582378857, 0.9623651309393161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 320}], {
             RGBColor[
             0.5897027051719504, 0.6767516973442059, 0.9615500313265857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 343}], {
             RGBColor[
             0.5958559812878284, 0.6815586834125604, 0.9621633323841816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 344}], {
             RGBColor[
             0.39507001975859724`, 0.5161718386350326, 0.946515977450629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 349}], {
             RGBColor[
             0.45744526540329744`, 0.5701981413414695, 0.9504904729468453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 288}], {
             RGBColor[
             0.25275048461760563`, 0.38298716301237146`, 0.9377051382369141]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 341}], {
             RGBColor[
             0.24102934533176992`, 0.3706675024598044, 0.9370376366944575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 360}], {
             RGBColor[
             0.28543335040527573`, 0.4171867688467138, 0.9395719503550848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 374}], {
             RGBColor[
             0.2682893522658295, 0.3993194981317673, 0.938590053761786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 393}], {
             RGBColor[
             0.2416474883761139, 0.3713172099919425, 0.9370728390263723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 399}], {
             RGBColor[
             0.24767699728620676`, 0.3776546061493952, 0.937416210638943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 261}], {
             RGBColor[
             0.20237836752934693`, 0.3300428741759244, 0.934836520687607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 264}], {
             RGBColor[
             0.2076696899760163, 0.3356043895565939, 0.9351378536731348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 317}], {
             RGBColor[
             0.6079677143241806, 0.6722679099328412, 0.8705698500730703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 333}], {
             RGBColor[
             0.21043441051870343`, 0.338510286140365, 0.9352953004180034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 381}], {
             RGBColor[
             0.6092276972658053, 0.6727889452592876, 0.8496886719990233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 268}], {
             RGBColor[
             0.82084444647079, 0.16122512643498643`, 0.16759397152185085`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 338}], {
             RGBColor[
             0.879834237807443, 0.44658003792775297`, 0.31942228583278787`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 381}], {
             RGBColor[
             0.8794537894858583, 0.44699417131630015`, 0.36726630280474326`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 382}], {
             RGBColor[
             0.847998420564194, 0.3276060041143898, 0.1919388579401936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 278}], {
             RGBColor[
             0.25267444257649463`, 0.38290723800581994`, 0.937700807755167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 284}], {
             RGBColor[
             0.24846567575091127`, 0.3784835572209025, 0.9374611247107626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 369}], {
             RGBColor[
             0.2551936052438994, 0.3855550376934007, 0.9378442703423086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 392}], {
             RGBColor[
             0.25044123686096187`, 0.3805599972053746, 0.9375736299933992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 274}], {
             RGBColor[
             0.22087433163626, 0.34948330516414705`, 0.9358898384811689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 299}], {
             RGBColor[
             0.21257469635649348`, 0.34075986225784227`, 0.9354171865301963]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 318}], {
             RGBColor[
             0.2174190793227137, 0.34585161590696, 0.9356930669735002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 336}], {
             RGBColor[
             0.21101362554134806`, 0.339119077853518, 0.9353282858566712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 367}], {
             RGBColor[
             0.21516769270569408`, 0.3434852658263162, 0.935564853836289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 267}], {
             RGBColor[
             0.6900764896095811, 0.7567221842679797, 0.9704893279445472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 272}], {
             RGBColor[
             0.7279854810242253, 0.7874270577614837, 0.9735224474035349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 291}], {
             RGBColor[
             0.7527228069990448, 0.8067520448236535, 0.9759880328732503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 321}], {
             RGBColor[
             0.813370248803728, 0.8541302872991015, 0.9820328030897745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 338}], {
             RGBColor[
             0.9016212039882432, 0.9204360205910522, 0.8006477894997438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 342}], {
             RGBColor[
             0.706156116764429, 0.7697763499712335, 0.9717551750957918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 384}], {
             RGBColor[
             0.7786909364224193, 0.827038544894287, 0.9785762933282055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 398}], {
             RGBColor[
             0.8741897182555676, 0.9025122258100744, 0.9845069042800476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 264}], {
             RGBColor[
             0.1847396920189574, 0.3115035078578844, 0.9338320242113725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 295}], {
             RGBColor[
             0.2109178597842839, 0.3390184219709439, 0.935322832138479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 310}], {
             RGBColor[
             0.18101326007132248`, 0.3075867916114884, 0.9336198094247166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 381}], {
             RGBColor[
             0.5862976993087463, 0.6486880635605781, 0.8483828425372609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 269}], {
             RGBColor[
             0.965850894705439, 0.9706613010892211, 0.7373156259818411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 298}], {
             RGBColor[
             0.8810364966451805, 0.9079026895445534, 0.9858832537094278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 300}], {
             RGBColor[
             0.9143198191766551, 0.7735717057130247, 0.6093343830407926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 306}], {
             RGBColor[
             0.9545094880958191, 0.9327471750686342, 0.664081522635275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 307}], {
             RGBColor[
             0.9619414175862754, 0.970962445386637, 0.9415105792405329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 314}], {
             RGBColor[
             0.9322274207027686, 0.9487209428474576, 0.9907658897447179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 310}], {
             RGBColor[
             0.18630458251799184`, 0.3131483069921579, 0.9339211424102444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 333}], {
             RGBColor[
             0.19279573500831393`, 0.31997091982232506`, 0.9342908039417687]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 381}], {
             RGBColor[
             0.5915890217554157, 0.6542495789412477, 0.8486841755227887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 322}], {
             RGBColor[
             0.5501554119867256, 0.6456799735265193, 0.9577293957987232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 362}], {
             RGBColor[
             0.4982768620774518, 0.6022414244020411, 0.9540103792474512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 273}], {
             RGBColor[
             0.265217664230201, 0.3960909592500517, 0.938415125672312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 365}], {
             RGBColor[
             0.25561932448523794`, 0.3860024956082064, 0.9378685144233075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 272}], {
             RGBColor[
             0.6091079366672787, 0.6934689353256587, 0.9624191392814057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 291}], {
             RGBColor[
             0.6338452626420983, 0.7127939223878283, 0.964884724751121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 321}], {
             RGBColor[
             0.6944927044467815, 0.7601721648632764, 0.9709294949676452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 331}], {
             RGBColor[
             0.511645707636986, 0.6143827846807824, 0.9547069650679356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 342}], {
             RGBColor[
             0.5872785724074823, 0.6758182275354083, 0.9606518669736626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 346}], {
             RGBColor[
             0.4581154785924594, 0.5680175907899552, 0.9512960662081413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 384}], {
             RGBColor[
             0.6598133920654725, 0.7330804224584619, 0.9674729852060762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 398}], {
             RGBColor[
             0.7553121738986209, 0.8085541033742493, 0.9734035961579184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 338}], {
             RGBColor[
             0.876308791336653, 0.41948191149276653`, 0.31604631431093705`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 381}], {
             RGBColor[
             0.8759283430150683, 0.4198960448813137, 0.3638903312828924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 279}], {
             RGBColor[
             0.9693542844710024, 0.9048940200148108, 0.380506034096984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 298}], {
             RGBColor[
             0.908244530929823, 0.9248034643520736, 0.7344530675019115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 300}], {
             RGBColor[
             0.9415278534612976, 0.7904724805205449, 0.35790419683327634`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 306}], {
             RGBColor[
             0.9817175223804617, 0.9496479498761543, 0.4126513364277588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 307}], {
             RGBColor[
             0.9891494518709179, 0.9878632201941573, 0.6900803930330166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 314}], {
             RGBColor[
             0.9594354549874111, 0.9656217176549777, 0.7393357035372017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 308}], {
             RGBColor[
             0.2553377632908749, 0.38570655694091993`, 0.9378524799298211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 397}], {
             RGBColor[
             0.2494683482405557, 0.3795374295806264, 0.9375182254257268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 273}], {
             RGBColor[
             0.2911126400044641, 0.42330822062509427`, 0.9398898062344726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 326}], {
             RGBColor[
             0.3230890593454866, 0.4540841958078278, 0.941814555867055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 335}], {
             RGBColor[
             0.2936530311811995, 0.4259783328219468, 0.9400344777538158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 394}], {
             RGBColor[
             0.3328279171819992, 0.4625195049765876, 0.9424351072766638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 291}], {
             RGBColor[
             0.6717542540567425, 0.7434987958813325, 0.9679178442101087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 321}], {
             RGBColor[
             0.7324016958614257, 0.7908770383567805, 0.9739626144266329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 331}], {
             RGBColor[
             0.5495546990516302, 0.6450876581742866, 0.9577400845269233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 338}], {
             RGBColor[
             0.8206526510459409, 0.8571827716487312, 0.7925776008366022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 342}], {
             RGBColor[
             0.6251875638221265, 0.7065231010289125, 0.9636849864326502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 346}], {
             RGBColor[
             0.4960244700071036, 0.5987224642834593, 0.954329185667129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 384}], {
             RGBColor[
             0.6977223834801167, 0.763785295951966, 0.9705061046650639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 398}], {
             RGBColor[
             0.7932211653132651, 0.8392589768677534, 0.976436715616906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 365}], {
             RGBColor[
             0.26583905724777945`, 0.3967440827101195, 0.9384505130853945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 394}], {
             RGBColor[
             0.3171526741702776, 0.4460438307034582, 0.9415424253765902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 287}], {
             RGBColor[
             0.2454706833388167, 0.37533563030230443`, 0.937290564323588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 299}], {
             RGBColor[
             0.22242833776812287`, 0.35111666413841447`, 0.9359783368314325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 318}], {
             RGBColor[
             0.2272727207343431, 0.3562084177875322, 0.9362542172747363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 367}], {
             RGBColor[
             0.22502133411732347`, 0.3538420677068884, 0.9361260041375251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 373}], {
             RGBColor[
             0.24052488712014738`, 0.3701372848948911, 0.9370089085455846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 395}], {
             RGBColor[
             0.2518980358087536, 0.3820911852658918, 0.9376565925383351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 279}], {
             RGBColor[
             0.9688751403565641, 0.9066136951652177, 0.5278514920501343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 281}], {
             RGBColor[
             0.8120473445077586, 0.8515608457173255, 0.8723741943555676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 306}], {
             RGBColor[
             0.9812383782660234, 0.9513676250265612, 0.559996794380909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 338}], {
             RGBColor[
             0.9931945073855819, 0.9905965803379274, 0.7001396493067182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 384}], {
             RGBColor[
             0.8702642398197578, 0.8971991046411623, 0.8780681531351799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 322}], {
             RGBColor[
             0.6369911357289768, 0.7142897496435541, 0.9658558315605028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 358}], {
             RGBColor[
             0.8670714087363368, 0.8612246187195758, 0.654847436421338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 376}], {
             RGBColor[
             0.6019797217390458, 0.6854606658855094, 0.9632115739949887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 377}], {
             RGBColor[
             0.590222766132432, 0.6752773818608311, 0.9624624311800029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 287}], {
             RGBColor[
             0.25901311175833214`, 0.3895695812107696, 0.9380617855878519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 330}], {
             RGBColor[
             0.24129239010618297`, 0.3709439791957144, 0.9370526167052204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 396}], {
             RGBColor[
             0.26805617252313807`, 0.399074411437749, 0.9385767745203981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 284}], {
             RGBColor[
             0.24820685681048946`, 0.3782115221044505, 0.9374463853549939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 327}], {
             RGBColor[
             0.28550387867049365`, 0.4165027145117478, 0.9396037276662406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 337}], {
             RGBColor[
             0.26857947792754067`, 0.39962443859725516`, 0.9386065759890179]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 354}], {
             RGBColor[
             0.2660945297513849, 0.3970126005093012, 0.9384650618665371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 392}], {
             RGBColor[
             0.2501824179205401, 0.3802879620889227, 0.9375588906376304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 300}], {
             RGBColor[
             0.9178232089422185, 0.7078044246386144, 0.2525247911559355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 306}], {
             RGBColor[
             0.9580128778613826, 0.8669798939942239, 0.307271930750418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 363}], {
             RGBColor[
             0.8902248757714332, 0.5864641010287953, 0.22970180508085886`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 384}], {
             RGBColor[
             0.6902109435663115, 0.7577585241609326, 0.9698659918101223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 386}], {
             RGBColor[
             0.4856785944575267, 0.5902406468075978, 0.9535084650798691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 350}], {
             RGBColor[
             0.5398022619922347, 0.6366471769552697, 0.9571158788344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 369}], {
             RGBColor[
             0.25072601947789425`, 0.3808593217920313, 0.9375898479421354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 392}], {
             RGBColor[
             0.24597365109495675`, 0.3758642813040053, 0.9373192075932261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 330}], {
             RGBColor[
             0.23174352854992997`, 0.3609075202673017, 0.9365088231658666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 387}], {
             RGBColor[
             0.2661419288540897, 0.3970624199715206, 0.9384677611753156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 320}], {
             RGBColor[
             0.7180719499645429, 0.7796825319520332, 0.9725343592747207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 343}], {
             RGBColor[
             0.7242252260804207, 0.7844895180203877, 0.9731476603323168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 349}], {
             RGBColor[
             0.5858145101958898, 0.6731289759492968, 0.9614748008949803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 367}], {
             RGBColor[
             0.23976404440825078`, 0.3693375909644736, 0.936965579678708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 373}], {
             RGBColor[
             0.2552675974110747, 0.3856328081524763, 0.9378484840867676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 395}], {
             RGBColor[
             0.2666407460996809, 0.397586708523477, 0.938496168079518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 396}], {
             RGBColor[
             0.2692564543945499, 0.400335983786869, 0.9386451287973171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 341}], {
             RGBColor[
             0.2333048519876323, 0.3625485701939505, 0.9365977382258728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 355}], {
             RGBColor[
             0.2379735788706035, 0.36745569816233453`, 0.9368636153150954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 360}], {
             RGBColor[
             0.2777088570611381, 0.4090678365808599, 0.9391320518865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 374}], {
             RGBColor[
             0.26056485892169184`, 0.3912005658659134, 0.9381501552932011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 375}], {
             RGBColor[
             0.24993566591258726`, 0.38002861008358335`, 0.9375448384758145]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 379}], {
             RGBColor[
             0.23299167582952007`, 0.3622194021952592, 0.9365799033069708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 393}], {
             RGBColor[
             0.23392299503197628`, 0.3631982777260886, 0.9366329405577875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 399}], {
             RGBColor[
             0.23995250394206913`, 0.3695356738835413, 0.9369763121703581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 302}], {
             RGBColor[
             0.9425151711377706, 0.798674033657958, 0.3207346510653094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 340}], {
             RGBColor[
             0.9457657182249508, 0.8088519239369327, 0.40028051736176995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 391}], {
             RGBColor[
             0.8461782962255958, 0.3146932430712892, 0.1902380974937647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 313}], {
             RGBColor[
             0.34397103520992167`, 0.4699540423686539, 0.9432263147475373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 321}], {
             RGBColor[
             0.6114600904368728, 0.6914542319869668, 0.964754355111318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 331}], {
             RGBColor[
             0.42861309362707734`, 0.5456648518044729, 0.9485318252116084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 342}], {
             RGBColor[
             0.5042459583975736, 0.6071002946590989, 0.9544767271173353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 346}], {
             RGBColor[
             0.3750828645825507, 0.4992996579136456, 0.9451209263518141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 321}], {
             RGBColor[
             0.7571390218362452, 0.8102020254189503, 0.9764281998963484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 331}], {
             RGBColor[
             0.5742920250264498, 0.6644126452364563, 0.9602056699966387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 338}], {
             RGBColor[
             0.8453899770207604, 0.8765077587109009, 0.7950431863063177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 342}], {
             RGBColor[
             0.6499248897969461, 0.7258480880910823, 0.9661505719023658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 384}], {
             RGBColor[
             0.7224597094549363, 0.7831102830141358, 0.9729716901347794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 398}], {
             RGBColor[
             0.8179584912880846, 0.8585839639299231, 0.9789023010866215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 304}], {
             RGBColor[
             0.21505855653612305`, 0.3433705567924642, 0.9355586386928844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 329}], {
             RGBColor[
             0.22307875219905648`, 0.35180029094398246`, 0.9360153769710722]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 353}], {
             RGBColor[
             0.2106991637542155, 0.3387885585772128, 0.9353103777230984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 378}], {
             RGBColor[
             0.20977255736756456`, 0.3378146365146045, 0.93525760886017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 388}], {
             RGBColor[
             0.21719189432910094`, 0.3456128300743124, 0.9356801291242041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 299}], {
             RGBColor[
             0.21267988324051307`, 0.34087042034218046`, 0.9354231767676313]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 330}], {
             RGBColor[
             0.21800150715905772`, 0.3464637844910152, 0.9357262353771553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 336}], {
             RGBColor[
             0.21111881242536762`, 0.33922963593785627`, 0.935334276094106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 341}], {
             RGBColor[
             0.21717163219876068`, 0.3455915332906315, 0.9356789752258563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 368}], {
             RGBColor[
             0.21277052855345546`, 0.3409656943133277, 0.9354283388841056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 393}], {
             RGBColor[
             0.21778977524310467`, 0.34624124082276975`, 0.9357141775577711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 310}], {
             RGBColor[
             0.2124827502833183, 0.3406632211052174, 0.935411950337351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 345}], {
             RGBColor[
             0.22216737223106828`, 0.3508423728127994, 0.9359634752301611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 363}], {
             RGBColor[
             0.6558041124528853, 0.4364203968060595, 0.4503645866246823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 316}], {
             RGBColor[
             0.27790052377493313`, 0.40942144877130526`, 0.9391373957607753]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 324}], {
             RGBColor[
             0.2907395975741168, 0.42291612937854317`, 0.9398685620199312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 360}], {
             RGBColor[
             0.3059566318031602, 0.4387580388470877, 0.9407407208692202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 374}], {
             RGBColor[
             0.2888126336637139, 0.4208907681321412, 0.9397588242759214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 375}], {
             RGBColor[
             0.2781834406546093, 0.40971881234981117`, 0.9391535074585348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 380}], {
             RGBColor[
             0.28350610283773925`, 0.41531326778055483`, 0.939456625195691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 383}], {
             RGBColor[
             0.2908789334455868, 0.4230625802138626, 0.9398764969916824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 390}], {
             RGBColor[
             0.283910407540538, 0.415738217657595, 0.9394796497504001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 307}], {
             RGBColor[
             0.965939497584164, 0.9739442069028073, 0.9347428726703746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 314}], {
             RGBColor[
             0.9362255007006572, 0.9517027043636277, 0.9839981831745597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 332}], {
             RGBColor[
             0.736930313911651, 0.7933926635631983, 0.9655671808709663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 352}], {
             RGBColor[
             0.970396577990795, 0.974814330666099, 0.7901511578367646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 385}], {
             RGBColor[
             0.76103003285282, 0.8129579010796052, 0.9674643990261943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 306}], {
             RGBColor[
             0.8969031243202032, 0.8868893383314866, 0.6612189641553454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 307}], {
             RGBColor[
             0.9043350538106595, 0.9251046086494896, 0.9386480207606034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 314}], {
             RGBColor[
             0.8746210569271528, 0.9028631061103101, 0.9879033312647884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 336}], {
             RGBColor[
             0.2125676316732109, 0.34075243682778544`, 0.9354167842069347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 367}], {
             RGBColor[
             0.21672169883755696`, 0.34511862480058364`, 0.9356533521865525]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 306}], {
             RGBColor[
             0.9301864468516778, 0.7525583544999579, 0.2846700934867103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 307}], {
             RGBColor[
             0.9376183763421341, 0.7907736248179609, 0.5620991500919681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 314}], {
             RGBColor[
             0.9079043794586273, 0.7685321222787813, 0.6113544605961532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 363}], {
             RGBColor[
             0.8716739217649633, 0.5101830746992847, 0.2146339135717204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 316}], {
             RGBColor[
             0.2555487063727525, 0.3859282714945373, 0.9378644928262717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 324}], {
             RGBColor[
             0.2683877801719362, 0.39942295210177514`, 0.9385956590854276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 372}], {
             RGBColor[
             0.25414770566980416`, 0.3844557309271635, 0.9377847079088335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 380}], {
             RGBColor[
             0.26115428543555863`, 0.39182009050378686`, 0.9381837222611874]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 383}], {
             RGBColor[
             0.2685271160434062, 0.39956940293709464`, 0.9386035940571789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 390}], {
             RGBColor[
             0.26155859013835736`, 0.392245040380827, 0.9382067468158966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 323}], {
             RGBColor[
             0.9087436394185031, 0.9180978599174181, 0.6943707488073377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 340}], {
             RGBColor[
             0.9905275811721996, 0.978922480132596, 0.484619975557615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 313}], {
             RGBColor[
             0.2862100467675046, 0.4181552842906852, 0.9396106108023645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 344}], {
             RGBColor[
             0.3051201948561256, 0.4369324167818024, 0.9407277420647475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 315}], {
             RGBColor[
             0.23118633013209117`, 0.360321869401733, 0.9364770915402718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 329}], {
             RGBColor[
             0.2271186296842969, 0.35604645832399684`, 0.9362454420173936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 353}], {
             RGBColor[
             0.21473904123945592`, 0.3430347259572272, 0.9355404427694197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 378}], {
             RGBColor[
             0.21381243485280502`, 0.34206080389461896`, 0.9354876739064912]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 325}], {
             RGBColor[
             0.20723516257555488`, 0.3351476737080805, 0.9351131079805042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 314}], {
             RGBColor[
             0.9555259778682477, 0.9659228619523936, 0.9435306567958934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 352}], {
             RGBColor[
             0.9896970551583855, 0.989034488254865, 0.7496836314580985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 385}], {
             RGBColor[
             0.7803305100204103, 0.8271780586683711, 0.9269968726475282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 386}], {
             RGBColor[
             0.30022575986843436`, 0.4300559235597101, 0.9405124330603728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 397}], {
             RGBColor[
             0.25521896402580857`, 0.3855816913810268, 0.9378457144874233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 319}], {
             RGBColor[
             0.25618706106620875`, 0.38659922275138503`, 0.9379008461817029]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 329}], {
             RGBColor[
             0.25296463724126, 0.3832122509978928, 0.9377173339120208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 334}], {
             RGBColor[
             0.26609474286190404`, 0.39701282450196873`, 0.9384650740028659]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 371}], {
             RGBColor[
             0.2714180274121831, 0.4026079340800466, 0.9387682271829105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 386}], {
             RGBColor[
             0.30507679489801537`, 0.4351546689491852, 0.9407886923288442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 345}], {
             RGBColor[
             0.19226277251810686`, 0.3194107424533439, 0.9342604525163987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 363}], {
             RGBColor[
             0.6358677126442442, 0.4154659765664225, 0.4492292381488407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 323}], {
             RGBColor[
             0.6747921418079339, 0.7440706990607763, 0.9694867808520644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 339}], {
             RGBColor[
             0.4425672704759462, 0.555957682108388, 0.9499165435038557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 327}], {
             RGBColor[
             0.39077465425622554`, 0.5126293712413812, 0.9461931090416965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 356}], {
             RGBColor[
             0.4906677898927829, 0.5973852420238213, 0.9530463122771483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 361}], {
             RGBColor[
             0.40929184788600736`, 0.528668033662285, 0.9473730082456748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 344}], {
             RGBColor[
             0.30171850127564737`, 0.43335702114888963`, 0.940534020647694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 359}], {
             RGBColor[
             0.2641882368664749, 0.39500896582131095`, 0.9383565013068491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 385}], {
             RGBColor[
             0.7506165131369036, 0.8049365561291917, 0.9762521831517132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 319}], {
             RGBColor[
             0.24242894961997336`, 0.37213857530674344`, 0.9371173420881417]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 329}], {
             RGBColor[
             0.2392065257950246, 0.3687516035532512, 0.9369338298184597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 334}], {
             RGBColor[
             0.25233663141566864`, 0.38255217705732714`, 0.9376815699093048]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 371}], {
             RGBColor[
             0.25765991596594773`, 0.388147286635405, 0.9379847230893494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 324}], {
             RGBColor[
             0.2671185805915378, 0.39808894287087526`, 0.9385233800469365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 355}], {
             RGBColor[
             0.2426003366300466, 0.37231871392089444`, 0.937127102324821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 380}], {
             RGBColor[
             0.25988508585516024`, 0.3904860812728869, 0.9381114432226962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 383}], {
             RGBColor[
             0.2672579164630078, 0.3982353937061947, 0.9385313150186878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 390}], {
             RGBColor[
             0.26028939055795897`, 0.3909110311499271, 0.9381344677774055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 333}], {
             RGBColor[
             0.5930937593564782, 0.6566344401985723, 0.8697228003417041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 370}], {
             RGBColor[
             0.9109218435003366, 0.9293228266692952, 0.8943803638429948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 381}], {
             RGBColor[
             0.99188704610358, 0.9909130993174948, 0.7841161719227241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 382}], {
             RGBColor[
             0.9447039927210837, 0.8118308485146293, 0.5211250046258997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 367}], {
             RGBColor[
             0.22156608180377718`, 0.3502103784497014, 0.9359292326298564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 373}], {
             RGBColor[
             0.2370696348066011, 0.3665055956377041, 0.9368121370379159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 329}], {
             RGBColor[
             0.2383612491721791, 0.3678631642290072, 0.9368856925652633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 334}], {
             RGBColor[
             0.25149135479282314`, 0.3816637377330832, 0.9376334326561084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 371}], {
             RGBColor[
             0.2568146393431022, 0.387258847311161, 0.937936585836153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 388}], {
             RGBColor[
             0.23247439130222355`, 0.3616757033593372, 0.9365504447183952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 343}], {
             RGBColor[
             0.7160472963068527, 0.7781008571267078, 0.9723325607195863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 349}], {
             RGBColor[
             0.5776365804223218, 0.666740315055617, 0.9606597012822499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 331}], {
             RGBColor[
             0.634939466831133, 0.7117908877119044, 0.9662504402131629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 338}], {
             RGBColor[
             0.9060374188254435, 0.923886001186349, 0.8010879565228419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 342}], {
             RGBColor[
             0.7105723316016292, 0.7732263305665302, 0.9721953421188899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 384}], {
             RGBColor[
             0.7831071512596195, 0.8304885254895837, 0.9790164603513036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 398}], {
             RGBColor[
             0.8786059330927678, 0.9059622064053712, 0.9849470713031456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 328}], {
             RGBColor[
             0.4089266558730876, 0.5271174055758985, 0.947690784031411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 362}], {
             RGBColor[
             0.45653757665465905`, 0.5683555921624378, 0.9507245098029286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 364}], {
             RGBColor[
             0.428972946302528, 0.5444804947900268, 0.9489681159313363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 340}], {
             RGBColor[
             0.9119941865056833, 0.9282757501963927, 0.7739166151037982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 375}], {
             RGBColor[
             0.267401497471214, 0.3983863064493811, 0.938539491744696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 380}], {
             RGBColor[
             0.27272415965434393`, 0.4039807618801248, 0.9388426094818522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 383}], {
             RGBColor[
             0.2800969902621915, 0.41173007431343256`, 0.9392624812778436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 390}], {
             RGBColor[
             0.27312846435714266`, 0.404405711757165, 0.9388656340365613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 335}], {
             RGBColor[
             0.3099542075105004, 0.4402786337315509, 0.9410665454863245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 337}], {
             RGBColor[
             0.312066783946898, 0.44249908551128714`, 0.9411868535891006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 354}], {
             RGBColor[
             0.3095818357707423, 0.4398872474233331, 0.94104533946662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 337}], {
             RGBColor[
             0.3016677329619616, 0.43349195021963505`, 0.9405242352558603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 354}], {
             RGBColor[
             0.2991827847858058, 0.430880112131681, 0.9403827211333795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 356}], {
             RGBColor[
             0.4184852693414719, 0.5351260969165677, 0.9483745901685348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 392}], {
             RGBColor[
             0.28327067295496094`, 0.4141554737113025, 0.9394765499044728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 347}], {
             RGBColor[
             0.29474363512034735`, 0.42706072191761096`, 0.940098925902251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 362}], {
             RGBColor[
             0.35704810596381387`, 0.4836788564514203, 0.9439717674801389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 372}], {
             RGBColor[
             0.2804573452843499, 0.4120449254968854, 0.9392853428307628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 387}], {
             RGBColor[
             0.30150296805800375`, 0.4341652094015489, 0.9404838599135137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 334}], {
             RGBColor[
             0.2482689309678744, 0.37827676597959103`, 0.9374499203864265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 353}], {
             RGBColor[
             0.22275923690238936`, 0.35146446010874544`, 0.9359971810476075]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 371}], {
             RGBColor[
             0.25359221551815353`, 0.38387187555766883`, 0.9377530735664711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 388}], {
             RGBColor[
             0.22925196747727483`, 0.358288731605845, 0.9363669324487132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 342}], {
             RGBColor[
             0.5277253347918338, 0.6274369503840362, 0.9559728122191802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 346}], {
             RGBColor[
             0.3985622409768109, 0.5196363136385831, 0.946617011453659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 361}], {
             RGBColor[
             0.4414240641856033, 0.5547544143941453, 0.9499025740169657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 385}], {
             RGBColor[
             0.5513213263478973, 0.6466265153287621, 0.9578211808481198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 381}], {
             RGBColor[
             0.5943537422981029, 0.6571554755250186, 0.8488416222676571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 371}], {
             RGBColor[
             0.26672232113879757`, 0.3976724490617448, 0.9385008136573162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 388}], {
             RGBColor[
             0.24238207309791887`, 0.372089305109921, 0.9371146725395583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 337}], {
             RGBColor[
             0.282630755782611, 0.41439322252540617`, 0.9394067754758614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 354}], {
             RGBColor[
             0.28014580760645524`, 0.41178138443745216`, 0.9392652613533807]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 367}], {
             RGBColor[
             0.21516062802241154`, 0.34347784039625945`, 0.9355644515130273]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 354}], {
             RGBColor[
             0.28225838404285286`, 0.4140018362171884, 0.9393855694561568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 384}], {
             RGBColor[
             0.8713581064441347, 0.8967942587815345, 0.7976314467612728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 398}], {
             RGBColor[
             0.966856888277283, 0.9722679396973218, 0.803562057713115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 360}], {
             RGBColor[
             0.3380761124684098, 0.46724626924582036`, 0.942762888830887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 374}], {
             RGBColor[
             0.3209321143289635, 0.44937899853087393`, 0.9417809922375882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 368}], {
             RGBColor[
             0.2171826090564914, 0.3456030706640795, 0.9356796003416652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 379}], {
             RGBColor[
             0.2212705365436844, 0.3498997416426921, 0.9359124017645142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 393}], {
             RGBColor[
             0.2222018557461406, 0.35087861717352153`, 0.9359654390153307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 399}], {
             RGBColor[
             0.22823136465623345`, 0.3572160133309742, 0.9363088106279014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 346}], {
             RGBColor[
             0.4741951057473072, 0.5810717564932091, 0.9525619133593859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 398}], {
             RGBColor[
             0.7713918010534688, 0.8216082690775031, 0.9746694433091629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 349}], {
             RGBColor[
             0.5837898565381997, 0.6715473011239714, 0.9612730023398459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 349}], {
             RGBColor[
             0.3830038950089686, 0.5061604563464437, 0.9456256474062932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 362}], {
             RGBColor[
             0.3423545559019188, 0.4682989085041503, 0.9431326516737686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 372}], {
             RGBColor[
             0.26576379522245486`, 0.3966649775496154, 0.9384462270243925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 387}], {
             RGBColor[
             0.2868094179961087, 0.41878526145427897`, 0.9396447441071433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 351}], {
             RGBColor[
             0.2543498568494185, 0.38466820463406326`, 0.9377962201194567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 369}], {
             RGBColor[
             0.2602045857942335, 0.3908218959663191, 0.9381296382715687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 357}], {
             RGBColor[
             0.5542164267531839, 0.6479076320182329, 0.9585525480697432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 394}], {
             RGBColor[
             0.3958053510234857, 0.5172484341263308, 0.9464413448636552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 378}], {
             RGBColor[
             0.20945304207089746`, 0.33747880567936756`, 0.9352394129367053]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 375}], {
             RGBColor[
             0.24288325350972279`, 0.37261607749940034`, 0.9371432140225805]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 379}], {
             RGBColor[
             0.2259392634266556, 0.3548068696110762, 0.9361782788537368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 366}], {
             RGBColor[
             0.934928559139148, 0.7751416322731404, 0.28588252947049914`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 391}], {
             RGBColor[
             0.8697860843549728, 0.40704671039684404`, 0.22224861189590023`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 374}], {
             RGBColor[
             0.293247724709362, 0.42540017170025574`, 0.9400169674113716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 375}], {
             RGBColor[
             0.2826185317002574, 0.4142282159179257, 0.939411650593985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 369}], {
             RGBColor[
             0.30654023496768024`, 0.43518917662023243`, 0.9409270894573605]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 385}], {
             RGBColor[
             0.46552378312677223`, 0.5743196519105522, 0.9517997921721937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 377}], {
             RGBColor[
             0.3822045767059832, 0.5054681270073037, 0.9455747155508364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 387}], {
             RGBColor[
             0.3215492584874442, 0.4515282986156772, 0.941761191813439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 382}], {
             RGBColor[
             0.9000306839899277, 0.6389445090727658, 0.23829549106007777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 393}], {
             RGBColor[
             0.21780075210083538`, 0.3462527781962177, 0.93571480267358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 399}], {
             RGBColor[
             0.22383026101092823`, 0.35259017435367035`, 0.9360581742861507]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 392}], {
             RGBColor[
             0.2527015805879449, 0.38293576177650346`, 0.937702353224772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 389}], {
             RGBColor[
             0.505152375234491, 0.5869084718259839, 0.9586367768062234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 391}], {
             RGBColor[
             0.8239994014416612, 0.39457661369970487`, 0.4393608257670162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 400}], {
             RGBColor[
             0.6104137657145253, 0.6900683539569277, 0.9649050090474223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 395}], {
             RGBColor[
             0.2616949498810116, 0.3923883631160637, 0.9382145123015146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 375}], {
             RGBColor[
             0.26547453356081113`, 0.3963609452029792, 0.9384297540006862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 399}], {
             RGBColor[
             0.255491371590293, 0.38586800900293716`, 0.9378612276952298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 379}], {
             RGBColor[
             0.23790135046863936`, 0.36737978153232503`, 0.9368595020144559]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 383}], {
             RGBColor[
             0.26754083334268397`, 0.3985327572847006, 0.9385474267164473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 399}], {
             RGBColor[
             0.24486217858118842`, 0.3746960532206071, 0.9372559108778432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 377}], {
             RGBColor[
             0.4266363429774569, 0.5439526897461481, 0.9484058684081864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 393}], {
             RGBColor[
             0.22188867958802838`, 0.35054944917483033`, 0.9359476040964289]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 399}], {
             RGBColor[
             0.22791818849812123`, 0.356886845332283, 0.9362909757089996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 383}], {
             RGBColor[
             0.2728634955258139, 0.4041272127154443, 0.9388505444536035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 390}], {
             RGBColor[
             0.2658949696207651, 0.39680285015917666`, 0.9384536972123212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 390}], {
             RGBColor[
             0.27326780022861263`, 0.40455216259248444`, 0.9388735690083126]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 398}], {
             RGBColor[
             0.8439266207114591, 0.8788704640005567, 0.9814905615415767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 400}], {
             RGBColor[
             0.2843495171102985, 0.40872323643536973`, 0.9397784081644269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 399}], {
             RGBColor[
             0.22884950770057744`, 0.3578657208631124, 0.9363440129598162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 396}], {
             RGBColor[
             0.2756838068644868, 0.4070915387504564, 0.9390111570120642]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.09653745999529093], {
             RGBColor[
             0.3599830334006432, 0.48622094308345976`, 0.9441587784611594]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.09653745999529093], {
             RGBColor[
             0.8184511944421836, 0.14282954261339104`, 0.16530219067646573`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.09653745999529093], {
             RGBColor[
             0.370079657849583, 0.49496613171003123`, 0.9448021264429514]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.09653745999529093], {
             RGBColor[
             0.23219649750384544`, 0.36138361935775737`, 0.9365346190776845]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.09653745999529093], {
             RGBColor[
             0.8414430264446411, 0.8764078451972013, 0.9847387810989889]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.09653745999529093], {
             RGBColor[
             0.9933475429680663, 0.9881793920123014, 0.5172992901589675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.09653745999529093], {
             RGBColor[
             0.38940499419392427`, 0.5117047667318526, 0.9460335197860889]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.09653745999529093], {
             RGBColor[
             0.3103199544645186, 0.44320528024791445`, 0.9409942909866859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.09653745999529093], {
             RGBColor[
             0.8256674379376745, 0.1982967522977973, 0.17221247359732916`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.09653745999529093], {
             RGBColor[
             0.3619258765766598, 0.48790373619238797`, 0.9442825747103464]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.09653745999529093], {
             RGBColor[
             0.9234626618564741, 0.7342619893565898, 0.25727446504873397`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.09653745999529093], {
             RGBColor[
             0.218436984339963, 0.3469214986189947, 0.935751035158377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.09653745999529093], {
             RGBColor[
             0.9637801291888717, 0.9725078601704316, 0.9461949730147088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.09653745999529093], {
             RGBColor[
             0.9943570777774785, 0.9903386848900081, 0.6271809240368398]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.09653745999529093], {
             RGBColor[
             0.3038609163605336, 0.43670746736272875`, 0.940615801713566]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.09653745999529093], {
             RGBColor[
             0.2418605106508593, 0.3715411099090923, 0.9370849703297808]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.09653745999529093], {
             RGBColor[
             0.5355166046173245, 0.6337955302332828, 0.9565769752588857]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.09653745999529093], {
             RGBColor[
             0.9452065658445834, 0.95865572703968, 0.9776351709954327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.09653745999529093], {
             RGBColor[
             0.2743841090042405, 0.40572547389373365`, 0.9389371411416538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.09653745999529093], {
             RGBColor[
             0.4076589804310767, 0.5275154521384491, 0.9471966476477539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.09653745999529093], {
             RGBColor[
             0.31291714185714126`, 0.44545483342897024`, 0.9411597814707411]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.09653745999529093], {
             RGBColor[
             0.29231839668471055`, 0.42457554734542235`, 0.9399584722936555]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.09653745999529093], {
             RGBColor[
             0.21341792784235675`, 0.34164615201344867`, 0.935465207315867]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.09653745999529093], {
             RGBColor[
             0.9021530244270525, 0.6485815613125467, 0.24006642394413927`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.09653745999529093], {
             RGBColor[
             0.8487111149297029, 0.3754205514621725, 0.19427912470900624`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.09653745999529093], {
             RGBColor[
             0.45511285367532656`, 0.5685201430708667, 0.9502472974560874]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.09653745999529093], {
             RGBColor[
             0.2974167180204977, 0.42993420632157753`, 0.9402488141514381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.09653745999529093], {
             RGBColor[
             0.2882891132658928, 0.42034051500092084`, 0.9397290105637445]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.09653745999529093], {
             RGBColor[
             0.2404292095299187, 0.3700367216812511, 0.9370034598483634]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.09653745999529093], {
             RGBColor[
             0.17892703208317115`, 0.3053940337214471, 0.9335010018270892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.09653745999529093], {
             RGBColor[
             0.183217413291963, 0.30990349639776743`, 0.9337453326898797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.09653745999529093], {
             RGBColor[
             0.21628540957162948`, 0.3446600571197567, 0.9356285061582901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.09653745999529093], {
             RGBColor[
             0.17894138666990014`, 0.3054091213022326, 0.9335018192995677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.09653745999529093], {
             RGBColor[
             0.3122890105436297, 0.4449107776560043, 0.9411197574988789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.09653745999529093], {
             RGBColor[
             0.28104105066772134`, 0.4127223416565313, 0.9393162441213263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.09653745999529093], {
             RGBColor[
             0.5196772960404508, 0.620936465977857, 0.9553300468664151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.09653745999529093], {
             RGBColor[
             0.24979952597607638`, 0.3798855183785399, 0.9375370855078312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.09653745999529093], {
             RGBColor[
             0.9657912116144293, 0.896267865549297, 0.32160574622002847`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.09653745999529093], {
             RGBColor[
             0.27309206457306523`, 0.40436745327622, 0.9388635611227067]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.09653745999529093], {
             RGBColor[
             0.3393121311221928, 0.4683168464796233, 0.9428416468465376]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.09653745999529093], {
             RGBColor[
             0.34082031608406577`, 0.4696231604900174, 0.9429377470586726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.09653745999529093], {
             RGBColor[
             0.9322258626950144, 0.9487956145888052, 0.9933977290633442]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.09653745999529093], {
             RGBColor[
             0.2274352478585693, 0.35637924409990884`, 0.9362634729540237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.09653745999529093], {
             RGBColor[
             0.29795654320818293`, 0.4305015968207284, 0.940279556397277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.09653745999529093], {
             RGBColor[
             0.2954990939280613, 0.427918661816037, 0.9401396082962444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.09653745999529093], {
             RGBColor[
             0.2843163130979401, 0.41616485013432336`, 0.9395027654714108]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.09653745999529093], {
             RGBColor[
             0.43389191818712153`, 0.5502371043169462, 0.948868187244693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.09653745999529093], {
             RGBColor[
             0.4254428949511675, 0.5429189850502182, 0.948329822955276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.09653745999529093], {
             RGBColor[
             0.2557363986193865, 0.3861255479461254, 0.9378751816220516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.09653745999529093], {
             RGBColor[
             0.45414763221898446`, 0.5677365328098771, 0.9501713116873214]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.09653745999529093], {
             RGBColor[
             0.3729233885884314, 0.4974292283459589, 0.9449833264510183]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.09653745999529093], {
             RGBColor[
             0.38664548537965426`, 0.5093146188938776, 0.9458576863245813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.09653745999529093], {
             RGBColor[
             0.28924396052189333`, 0.4213441200077901, 0.9397833877024038]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.09653745999529093], {
             RGBColor[
             0.4519914858020445, 0.5659140400742732, 0.9500214756882968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.09653745999529093], {
             RGBColor[
             0.4035326533159193, 0.5239414349865308, 0.9469337217327439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.09653745999529093], {
             RGBColor[
             0.45093503134871465`, 0.5649989923257436, 0.9499541593447165]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.09653745999529093], {
             RGBColor[
             0.2732074233744939, 0.404488702690692, 0.9388701306357901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.09653745999529093], {
             RGBColor[
             0.2988109928106687, 0.43139967752817476`, 0.9403282160380936]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.09653745999529093], {
             RGBColor[
             0.3340181926444761, 0.4637315030513096, 0.9425043217679835]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.09653745999529093], {
             RGBColor[
             0.35752834255750565`, 0.4840948132514831, 0.9440023677312325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.09653745999529093], {
             RGBColor[
             0.9933459036684309, 0.98817588571614, 0.5171208625102379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.09653745999529093], {
             RGBColor[
             0.1790682590797859, 0.30554247224919795`, 0.9335090444956198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.09653745999529093], {
             RGBColor[
             0.9585610528033711, 0.8718788421575785, 0.2935179445399928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.09653745999529093], {
             RGBColor[
             0.3989602722595878, 0.5199810683300905, 0.9466423736550322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.09653745999529093], {
             RGBColor[
             0.5153321861178936, 0.6174089099977538, 0.9549879838966494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.09653745999529093], {
             RGBColor[
             0.9727828870163496, 0.9198524284034268, 0.3487670848893771]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.09653745999529093], {
             RGBColor[
             0.2129458677257866, 0.3411499869005934, 0.9354383241905787]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.09653745999529093], {
             RGBColor[
             0.2767246225454214, 0.4081855020226443, 0.9390704299253445]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.09653745999529093], {
             RGBColor[
             0.48821862164434726`, 0.5953968969059689, 0.9528535047810326]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.09653745999529093], {
             RGBColor[
             0.2778101351361315, 0.409326444580954, 0.9391322482615135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.09653745999529093], {
             RGBColor[
             0.871120013048017, 0.9000714687543917, 0.9875693985741776]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.09653745999529093], {
             RGBColor[
             0.22772650909910638`, 0.3566853781307425, 0.9362800598507899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.09653745999529093], {
             RGBColor[
             0.24311597663730303`, 0.3728606842619857, 0.9371564672604132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.09653745999529093], {
             RGBColor[
             0.8246734764068878, 0.8630362611944062, 0.983139286446034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.09653745999529093], {
             RGBColor[
             0.24417812249459925`, 0.373977066901941, 0.9372169548956822]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.09653745999529093], {
             RGBColor[
             0.8469444359628041, 0.36184108275892934`, 0.19258735093512552`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.09653745999529093], {
             RGBColor[
             0.8293651040061051, 0.8667772376911834, 0.9835867780747127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.09653745999529093], {
             RGBColor[
             0.8418439495844675, 0.3226365094076515, 0.18770311941905493`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.09653745999529093], {
             RGBColor[
             0.590805957298975, 0.6786819174972005, 0.9609295556335575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.09653745999529093], {
             RGBColor[
             0.3344163982055418, 0.46407640869391137`, 0.9425296950742152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.09653745999529093], {
             RGBColor[
             0.2197154470497895, 0.34826524398623987`, 0.9358238417183856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.09653745999529093], {
             RGBColor[
             0.37921715493462604`, 0.5028805724211383, 0.9453843596772389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.09653745999529093], {
             RGBColor[
             0.35288166901045503`, 0.480070098173631, 0.9437062858017065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.09653745999529093], {
             RGBColor[
             0.17892701429477148`, 0.30539401502471114`, 0.9335010008140661]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.09653745999529093], {
             RGBColor[
             0.2413074662041341, 0.37095982513054093`, 0.9370534752666957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.09653745999529093], {
             RGBColor[
             0.30053635500276704`, 0.4332131425863514, 0.940426472862489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.09653745999529093], {
             RGBColor[
             0.29013871681338543`, 0.4222845656009737, 0.9398343427495309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.09653745999529093], {
             RGBColor[
             0.9903137669558371, 0.9902625079584733, 0.8101894789167451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.09653745999529093], {
             RGBColor[
             0.21858282554203126`, 0.3470747869692347, 0.9357593405990821]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.09653745999529093], {
             RGBColor[
             0.7058058015575851, 0.7701001235903371, 0.9713117842351892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.09653745999529093], {
             RGBColor[
             0.26262121251507564`, 0.39336192387290797`, 0.9382672615882417]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.09653745999529093], {
             RGBColor[
             0.28766384187052196`, 0.4196833151198899, 0.9396934022827843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.09653745999529093], {
             RGBColor[
             0.2452381115380016, 0.3750911825937439, 0.9372773197035907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.09653745999529093], {
             RGBColor[
             0.26012396818175015`, 0.3907371617441472, 0.9381250472178008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.09653745999529093], {
             RGBColor[
             0.2817785304161579, 0.4134974796310549, 0.9393582425019963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.09653745999529093], {
             RGBColor[
             0.2869114883454893, 0.4188925438631119, 0.939650556862541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.09653745999529093], {
             RGBColor[
             0.44228444757308333`, 0.5575062914502744, 0.9494029517959442]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.09653745999529093], {
             RGBColor[
             0.9775701021325132, 0.9360008290818089, 0.3673645116259542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.09653745999529093], {
             RGBColor[
             0.9781276011086575, 0.9832081812363787, 0.921908445474496]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.09653745999529093], {
             RGBColor[
             0.37661408553666426`, 0.5006259245426959, 0.9452184943970047]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.09653745999529093], {
             RGBColor[
             0.2608418322510304, 0.39149168239617155`, 0.9381659285145616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.09653745999529093], {
             RGBColor[
             0.819297035403237, 0.14933104688991955`, 0.16611216893601113`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.09653745999529093], {
             RGBColor[
             0.34456615692423104`, 0.4728676195543337, 0.943176428724691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.09653745999529093], {
             RGBColor[
             0.9338740873595025, 0.7755398220742175, 0.265651742396037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.09653745999529093], {
             RGBColor[
             0.417344109662346, 0.5359042242898253, 0.9478137755181469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.09653745999529093], {
             RGBColor[
             0.948494816832878, 0.9611080992427333, 0.9720690197854612]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.09653745999529093], {
             RGBColor[
             0.8392176796973624, 0.30244984821655896`, 0.1851882004092155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.09653745999529093], {
             RGBColor[
             0.3675690787260941, 0.49279159425864094`, 0.9446421545612206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.09653745999529093], {
             RGBColor[
             0.9940964498066649, 0.9918267445278057, 0.7475006348091123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.09653745999529093], {
             RGBColor[
             0.25557794384056287`, 0.3859590019269685, 0.9378661578568105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.09653745999529093], {
             RGBColor[
             0.8740781517963572, 0.5211001217496539, 0.21664006204298622`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.09653745999529093], {
             RGBColor[
             0.3289211710833394, 0.45931671915880556`, 0.9421795440612271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.09653745999529093], {
             RGBColor[
             0.7965156452550962, 0.8409633429071789, 0.9803528937232722]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.09653745999529093], {
             RGBColor[
             0.3288778807819878, 0.45927922327560866`, 0.9421767856415051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.09653745999529093], {
             RGBColor[
             0.2386060995532787, 0.36812051750395375`, 0.9368996364322433]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.09653745999529093], {
             RGBColor[
             0.4162213411164948, 0.534931738607397, 0.9477422336992305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.09653745999529093], {
             RGBColor[
             0.3495171154366807, 0.47715589097540734`, 0.9434918994231435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.09653745999529093], {
             RGBColor[
             0.20606162213947596`, 0.33391420830300045`, 0.935046276588767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.09653745999529093], {
             RGBColor[
             0.24049836738192176`, 0.3701094109685675, 0.9370073982857251]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.09653745999529093], {
             RGBColor[
             0.5663783145126094, 0.6588504566304622, 0.9590065221120109]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.09653745999529093], {
             RGBColor[
             0.5531961411455233, 0.6481485744409189, 0.9579687731366617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.09653745999529093], {
             RGBColor[
             0.44608758599784554`, 0.5608003788025082, 0.9496452844133868]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.09653745999529093], {
             RGBColor[
             0.9742961343763916, 0.9803506796209057, 0.9283941192456544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.09653745999529093], {
             RGBColor[
             0.22327126764014227`, 0.35200263687874755`, 0.936026340440641]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.09653745999529093], {
             RGBColor[
             0.277985958766929, 0.4095112463647842, 0.9391422611571797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.09653745999529093], {
             RGBColor[
             0.21204174778307774`, 0.3401996995162911, 0.935386835897367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.09653745999529093], {
             RGBColor[
             0.21049571798261152`, 0.33857472417205015`, 0.9352987917873766]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.09653745999529093], {
             RGBColor[
             0.3262131529712761, 0.45697116997908427`, 0.9420069915417328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.09653745999529093], {
             RGBColor[
             0.23768447069359533`, 0.36715182713778177`, 0.936847151032112]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.09653745999529093], {
             RGBColor[
             0.4104055903111328, 0.5298944275679272, 0.9473716592005793]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.09653745999529093], {
             RGBColor[
             0.9224661794909306, 0.7303112688352736, 0.2564726719469704]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.09653745999529093], {
             RGBColor[
             0.7992223614262676, 0.8430778501519028, 0.9806226738955138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.09653745999529093], {
             RGBColor[
             0.29725822306554583`, 0.42976761807476255`, 0.9402397880982258]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.09653745999529093], {
             RGBColor[
             0.2343268669145523, 0.36362277268163234`, 0.9366559404640252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.09653745999529093], {
             RGBColor[
             0.5032780494106496, 0.6076228187861427, 0.9540390380992975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.09653745999529093], {
             RGBColor[
             0.6185821135656369, 0.7012318524560568, 0.9631161964022821]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.09653745999529093], {
             RGBColor[
             0.22155609394318862`, 0.3501998805749559, 0.9359286638359716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.09653745999529093], {
             RGBColor[
             0.8193428764107183, 0.14968340096107918`, 0.16615606633654534`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.09653745999529093], {
             RGBColor[
             0.2111706728502173, 0.3392841445325141, 0.9353372294685806]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.09653745999529093], {
             RGBColor[
             0.6719249954084331, 0.7436321803229556, 0.9679348621123766]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.09653745999529093], {
             RGBColor[
             0.3600639473667127, 0.48629102669401497`, 0.9441639342275279]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.09653745999529093], {
             RGBColor[
             0.8215839734950429, 0.16690945520620182`, 0.16830214343545163`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.09653745999529093], {
             RGBColor[
             0.6246442469651912, 0.7061533654458123, 0.9635934297498213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.09653745999529093], {
             RGBColor[
             0.8784381059512442, 0.540897655273832, 0.22027811466207986`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.09653745999529093], {
             RGBColor[
             0.23802405881018981`, 0.36750875577945274`, 0.9368664900729765]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.09653745999529093], {
             RGBColor[
             0.5353312372592116, 0.6336450406612625, 0.9565623824614321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.09653745999529093], {
             RGBColor[
             0.28473783311028583`, 0.41660789439321116`, 0.9395267704125309]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.09653745999529093], {
             RGBColor[
             0.6238880244982119, 0.7055394299796848, 0.9635338971470865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.09653745999529093], {
             RGBColor[
             0.22021863489519794`, 0.34879412631571627`, 0.9358524975217819]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.09653745999529093], {
             RGBColor[
             0.2706007772119499, 0.40174895230294594`, 0.9387216859930206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.09653745999529093], {
             RGBColor[
             0.3158355177641727, 0.44798258395780277`, 0.9413457378029186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.09653745999529093], {
             RGBColor[
             0.18361616608284723`, 0.3103226108633739, 0.9337680410714186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.09653745999529093], {
             RGBColor[
             0.3174307607246093, 0.4493643032308905, 0.9414473852737397]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.09653745999529093], {
             RGBColor[
             0.4301580292792129, 0.547002997415629, 0.9486302671452295]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.09653745999529093], {
             RGBColor[
             0.30454561984188433`, 0.43742713413433654`, 0.9406547945639009]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.09653745999529093], {
             RGBColor[
             0.18595953915049845`, 0.3127856445359093, 0.9339014927009116]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.09653745999529093], {
             RGBColor[
             0.46924384183457235`, 0.5799923158523045, 0.9513597406074984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.09653745999529093], {
             RGBColor[
             0.5031159008708285, 0.6074911792968075, 0.9540262731722731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.09653745999529093], {
             RGBColor[
             0.3314345944952444, 0.46149372018986384`, 0.9423396971785006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.09653745999529093], {
             RGBColor[
             0.8294775817921864, 0.22758318757925894`, 0.17586107165535175`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.09653745999529093], {
             RGBColor[
             0.4314366462475933, 0.5481104711684827, 0.9487117394878181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.09653745999529093], {
             RGBColor[
             0.246083996032968, 0.37598026083012825`, 0.9373254915742051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.09653745999529093], {
             RGBColor[
             0.2449732495734328, 0.3748127958757636, 0.9372622362065367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.09653745999529093], {
             RGBColor[
             0.24253850776538854`, 0.3722537278639624, 0.9371235812624463]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.09653745999529093], {
             RGBColor[
             0.532748774101436, 0.6315484807311408, 0.9563590815017777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.09653745999529093], {
             RGBColor[
             0.8247691039330448, 0.19139176348574266`, 0.17135222793997262`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.09653745999529093], {
             RGBColor[
             0.2835494674254077, 0.415358846711668, 0.9394590947448065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.09653745999529093], {
             RGBColor[
             0.6701504899984683, 0.7422459232099505, 0.9677579959968072]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.09653745999529093], {
             RGBColor[
             0.22069846856058375`, 0.34929846192124825`, 0.9358798233391753]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.09653745999529093], {
             RGBColor[
             0.44496963537099143`, 0.5598320661593594, 0.9495740495880086]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.09653745999529093], {
             RGBColor[
             0.2732125866431092, 0.40449412961337683`, 0.9388704246762993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.09653745999529093], {
             RGBColor[
             0.301424661402258, 0.4341468089340951, 0.9404770605978084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.09653745999529093], {
             RGBColor[
             0.22636761106282094`, 0.3552570901354948, 0.936202672617933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.09653745999529093], {
             RGBColor[
             0.7286053839996127, 0.7879113306772935, 0.9735842335387989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.09653745999529093], {
             RGBColor[
             0.17893214148115075`, 0.3053994040226782, 0.9335012927997455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.09653745999529093], {
             RGBColor[
             0.21582348781243682`, 0.34417454806331416`, 0.935602200397456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.09653745999529093], {
             RGBColor[
             0.3219085007459621, 0.453242696579629, 0.9417327029083903]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.09653745999529093], {
             RGBColor[
             0.24398844376792686`, 0.3737777025338824, 0.9372061529728027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.09653745999529093], {
             RGBColor[
             0.2696431574723743, 0.40074243324005365`, 0.9386671509655232]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.09653745999529093], {
             RGBColor[
             0.36627002209779275`, 0.4916664166996908, 0.9445593798215759]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.09653745999529093], {
             RGBColor[
             0.5673122922146817, 0.6596087018042204, 0.9590800482579911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.09653745999529093], {
             RGBColor[
             0.2880943118622093, 0.4201357663745271, 0.9397179169119876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.09653745999529093], {
             RGBColor[
             0.2589336294896423, 0.3894860403069097, 0.9380572591902335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.09653745999529093], {
             RGBColor[
             0.21776291881025298`, 0.3462130130090464, 0.9357126481236506]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.09653745999529093], {
             RGBColor[
             0.8236904837096025, 0.18310101579396953`, 0.170319339995877]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.09653745999529093], {
             RGBColor[
             0.24846767200989045`, 0.3784856554156597, 0.9374612383947583]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.09653745999529093], {
             RGBColor[
             0.8439338400416576, 0.8783939523481282, 0.9849763571234479]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.09653745999529093], {
             RGBColor[
             0.26708591845739416`, 0.39805461289699134`, 0.9385215199867163]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.09653745999529093], {
             RGBColor[
             0.30054674338696064`, 0.4332240614368005, 0.9404270644656005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.09653745999529093], {
             RGBColor[
             0.2411029859620505, 0.37074490343131483`, 0.9370418304194105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.09653745999529093], {
             RGBColor[
             0.6788533623879274, 0.7490446732648759, 0.968625416983622]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.09653745999529093], {
             RGBColor[
             0.34448974411411554`, 0.4728014346188312, 0.9431715597679996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.09653745999529093], {
             RGBColor[
             0.8223396115770147, 0.8611753007301386, 0.9829166803350949]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.09653745999529093], {
             RGBColor[
             0.3880550588481297, 0.5105355205850486, 0.9459475030995558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.09653745999529093], {
             RGBColor[
             0.24569470610522032`, 0.37557109243365844`, 0.9373033220887227]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.09653745999529093], {
             RGBColor[
             0.29792411608308994`, 0.43046751385625726`, 0.9402777097204745]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.09653745999529093], {
             RGBColor[
             0.988751433892587, 0.9896164430866911, 0.8360813809631582]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.09653745999529093], {
             RGBColor[
             0.8264896291158393, 0.8644844120663722, 0.9833125127127125]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.09653745999529093], {
             RGBColor[
             0.22580276459471169`, 0.35466340068417734`, 0.9361705054471896]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.09653745999529093], {
             RGBColor[
             0.27065965459454444`, 0.40181083616509444`, 0.9387250389728581]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.09653745999529093], {
             RGBColor[
             0.27642628673231373`, 0.407871932167485, 0.9390534401421363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.09653745999529093], {
             RGBColor[
             0.8563396258514921, 0.4340566292418462, 0.20158419538288244`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.09653745999529093], {
             RGBColor[
             0.29139757571829134`, 0.42360770612629445`, 0.9399060329018505]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.09653745999529093], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.09653745999529093], {
             RGBColor[
             0.9952685123171101, 0.9923114224965074, 0.7280765258104895]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.09653745999529093], {
             RGBColor[
             0.23156206990492625`, 0.36071679572626025`, 0.9364984893644777]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.09653745999529093], {
             RGBColor[
             0.9398558182628138, 0.7992553918121872, 0.27046478349011155`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.09653745999529093], {
             RGBColor[
             0.2330867180319017, 0.36231929757598597`, 0.9365853158197941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.09653745999529093], {
             RGBColor[
             0.2520329891677718, 0.3822330298027571, 0.9376642779324855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.09653745999529093], {
             RGBColor[
             0.2999237099233219, 0.432569213763913, 0.9403915836315417]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.09653745999529093], {
             RGBColor[
             0.2626771974737526, 0.39342076761412886`, 0.9382704498488161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.09653745999529093], {
             RGBColor[
             0.21089717481030001`, 0.33899668075178374`, 0.9353216541598114]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.09653745999529093], {
             RGBColor[
             0.9109681137578394, 0.6847252697068382, 0.24722105836383443`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.09653745999529093], {
             RGBColor[
             0.9837730937067766, 0.9874185803724101, 0.9123520990861677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.09653745999529093], {
             RGBColor[
             0.8192881970279116, 0.1492631112641677, 0.166103705297818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.09653745999529093], {
             RGBColor[
             0.6591015742674116, 0.7336144262659793, 0.9666567433347234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.09653745999529093], {
             RGBColor[
             0.8228256695060855, 0.17645367486173685`, 0.16949119293792111`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.09653745999529093], {
             RGBColor[
             0.9100637739514378, 0.9311241665985504, 0.9912838892546516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.09653745999529093], {
             RGBColor[
             0.4471878440862639, 0.5617533670581167, 0.9497153918858607]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.09653745999529093], {
             RGBColor[
             0.4754345148883495, 0.5850181831240037, 0.9518470930674744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.09653745999529093], {
             RGBColor[
             0.9218589159168126, 0.9405292926311409, 0.9924089204249567]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.09653745999529093], {
             RGBColor[
             0.6049269005052089, 0.6901459353332633, 0.9620412080094716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.09653745999529093], {
             RGBColor[
             0.4540671923140028, 0.5676712280712366, 0.9501649791633402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.09653745999529093], {
             RGBColor[
             0.9756615083220127, 0.9295626939998534, 0.3599499850798584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.09653745999529093], {
             RGBColor[
             0.2571081050813221, 0.3875672984088326, 0.9379532982758011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.09653745999529093], {
             RGBColor[
             0.23863402700947722`, 0.3681498710311214, 0.9369012268595588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.09653745999529093], {
             RGBColor[
             0.23492201148043795`, 0.36424830735472313`, 0.9366898330666149]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.09653745999529093], {
             RGBColor[
             0.36785717736282086`, 0.49304113081751505`, 0.9446605119515972]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.09653745999529093], {
             RGBColor[
             0.24689616138342244`, 0.3768338981077132, 0.9373717431894225]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.09653745999529093], {
             RGBColor[
             0.9688572327835747, 0.9066102748888301, 0.333516659492644]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.09653745999529093], {
             RGBColor[
             0.30868412390727973`, 0.44177696430338015`, 0.9408904762480571]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.09653745999529093], {
             RGBColor[
             0.5255566438526651, 0.6257095853934133, 0.9557928906629534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.09653745999529093], {
             RGBColor[
             0.8174582326741875, 0.1351972033459516, 0.16435132936604271`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.09653745999529093], {
             RGBColor[
             0.3387393935852255, 0.4678207700117279, 0.942805152517134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.09653745999529093], {
             RGBColor[
             0.7400936775781565, 0.7968860729351169, 0.9747292792785006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.09653745999529093], {
             RGBColor[
             0.2505222001886238, 0.3806450947961188, 0.9375782407351351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.09653745999529093], {
             RGBColor[
             0.5784190314529432, 0.6686256530707418, 0.9599544114561535]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.09653745999529093], {
             RGBColor[
             0.22922310747734106`, 0.35825839791608494`, 0.9363652889144115]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.09653745999529093], {
             RGBColor[
             0.32451491921663345`, 0.4555002452565231, 0.9418987815885761]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.09653745999529093], {
             RGBColor[
             0.23920651037948798`, 0.3687515873505448, 0.9369338289405676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.09653745999529093], {
             RGBColor[
             0.290961948336973, 0.42314983412815754`, 0.9398812245669373]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.09653745999529093], {
             RGBColor[
             0.9183468399249884, 0.7139794601448493, 0.25315815463888625`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.09653745999529093], {
             RGBColor[
             0.2883719521470624, 0.4204275839173185, 0.939733728115478]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.09653745999529093], {
             RGBColor[
             0.2600361752617328, 0.3906448858188163, 0.9381200475408837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.09653745999529093], {
             RGBColor[
             0.22989884827362161`, 0.3589686443374169, 0.9364037713530907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.09653745999529093], {
             RGBColor[
             0.4438028563584466, 0.5588214608227114, 0.9494997034610714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.09653745999529093], {
             RGBColor[
             0.9070075396154186, 0.6690229130152352, 0.24403428744221908`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.09653745999529093], {
             RGBColor[
             0.21620788903044316`, 0.3445785781158837, 0.9356240914781508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.09653745999529093], {
             RGBColor[
             0.2695692814994847, 0.4006647849085395, 0.938662943838157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.09653745999529093], {
             RGBColor[
             0.9882272169582415, 0.9893996659125786, 0.8447690121952027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.09653745999529093], {
             RGBColor[
             0.822315843269912, 0.8611563485272284, 0.9829144132927453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.09653745999529093], {
             RGBColor[
             0.2243331252717409, 0.35311871657522015`, 0.9360868116618829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.09653745999529093], {
             RGBColor[
             0.34171577858230273`, 0.47039876509873646`, 0.9429948051372339]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.09653745999529093], {
             RGBColor[
             0.46951139015292603`, 0.5802095236300584, 0.951380802991181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.09653745999529093], {
             RGBColor[
             0.26047497796174324`, 0.3911060952782254, 0.938145036705499]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.09653745999529093], {
             RGBColor[
             0.22530836548640581`, 0.35414375587463387`, 0.9361423501493695]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.09653745999529093], {
             RGBColor[
             0.8226071697061851, 0.17477418965247965`, 0.16928195728277629`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.09653745999529093], {
             RGBColor[
             0.2529332615169164, 0.38317927312227185`, 0.9377155471109357]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.09653745999529093], {
             RGBColor[
             0.2110206902246306, 0.3391265032835748, 0.9353286881799328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.09653745999529093], {
             RGBColor[
             0.8089540339665278, 0.8506803067038047, 0.9815926360666765]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.09653745999529093], {
             RGBColor[
             0.17944836957228805`, 0.3059419924772149, 0.9335306912258446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.09653745999529093], {
             RGBColor[
             0.9386428604207964, 0.9537605262817009, 0.9887458121893573]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.09653745999529093], {
             RGBColor[
             0.26208361027682536`, 0.3927968698345563, 0.9382366459360847]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.09653745999529093], {
             RGBColor[
             0.19003101446562676`, 0.31706502323855396`, 0.9341333571969002]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.09653745999529093], {
             RGBColor[
             0.5918946974095183, 0.6795658057661227, 0.9610152652432459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.09653745999529093], {
             RGBColor[
             0.2549979314676595, 0.3853493721481386, 0.937833127010225]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.09653745999529093], {
             RGBColor[
             0.5711989452526345, 0.6627640618321545, 0.9593860198224179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.09653745999529093], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.09653745999529093], {
             RGBColor[
             0.9930589289900814, 0.9875620758967413, 0.48588543977432486`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.09653745999529093], {
             RGBColor[
             0.249587147505622, 0.3796622951405196, 0.9375249908681246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.09653745999529093], {
             RGBColor[
             0.30678788301618565`, 0.43978389489822367`, 0.9407824881345462]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.09653745999529093], {
             RGBColor[
             0.6470169280819229, 0.7241738088191627, 0.9654522587403933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.09653745999529093], {
             RGBColor[
             0.2754373969927425, 0.40683254635196486`, 0.938997124334399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.09653745999529093], {
             RGBColor[
             0.2307279730478894, 0.35984010704471925`, 0.9364509887824051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.09653745999529093], {
             RGBColor[
             0.992100640761205, 0.9910014261975552, 0.7805763556806252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.09653745999529093], {
             RGBColor[
             0.765566144894021, 0.8167853580001923, 0.977268136766805]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.09653745999529093], {
             RGBColor[
             0.2578128298869203, 0.3883080088616496, 0.9379934313109329]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.09653745999529093], {
             RGBColor[
             0.2524156236360728, 0.382635202889368, 0.9376860683993983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.09653745999529093], {
             RGBColor[
             0.9456496399519233, 0.8222259641328803, 0.2751266284196432]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.09653745999529093], {
             RGBColor[
             0.23901320904650822`, 0.3685484153935707, 0.9369228207156182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.09653745999529093], {
             RGBColor[
             0.6319940482543123, 0.7121202652370958, 0.9641720330305101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.09653745999529093], {
             RGBColor[
             0.6468617732853108, 0.7240526007128293, 0.965436794360271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.09653745999529093], {
             RGBColor[
             0.9089152991886196, 0.6765865439997854, 0.2455693155756892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.09653745999529093], {
             RGBColor[
             0.24399808998490613`, 0.37378784131953313`, 0.9372067023105894]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.09653745999529093], {
             RGBColor[
             0.23871510677441427`, 0.3682350910048242, 0.9369058442322252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.09653745999529093], {
             RGBColor[
             0.726249879738111, 0.7860711928457129, 0.9733494588874512]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.09653745999529093], {
             RGBColor[
             0.260213393629744, 0.3908311535598896, 0.9381301398647709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.09653745999529093], {
             RGBColor[
             0.245025991273468, 0.37486823074651754`, 0.9372652397683294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.09653745999529093], {
             RGBColor[
             0.8977533081905217, 0.6286034774622947, 0.23639519286946437`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.09653745999529093], {
             RGBColor[
             0.4051337172328171, 0.5253281960795354, 0.9470357401097634]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.09653745999529093], {
             RGBColor[
             0.696491580031562, 0.7628237829435023, 0.9703834296798242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.09653745999529093], {
             RGBColor[
             0.2110186790508826, 0.3391243894124498, 0.9353285736465631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.09653745999529093], {
             RGBColor[
             0.21123106399266978`, 0.3393476194522512, 0.9353406686548026]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.09653745999529093], {
             RGBColor[
             0.21275955169572475`, 0.34095415693987974`, 0.9354277137682966]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.09653745999529093], {
             RGBColor[
             0.24238734999627973`, 0.3720948514646729, 0.9371149730511135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.09653745999529093], {
             RGBColor[
             0.30152154075751214`, 0.43424863527897317`, 0.94048257773377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.09653745999529093], {
             RGBColor[
             0.9466390204165737, 0.9597240493140413, 0.9752103990490407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.09653745999529093], {
             RGBColor[
             0.8234301328695646, 0.862044852807406, 0.9830206952294982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.09653745999529093], {
             RGBColor[
             0.21412870248835636`, 0.3423932212321097, 0.9355056848804599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.09653745999529093], {
             RGBColor[
             0.8899967779325137, 0.5933828851443484, 0.2299229538922278]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.09653745999529093], {
             RGBColor[
             0.2568179059531509, 0.3872622807254372, 0.9379367718647629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.09653745999529093], {
             RGBColor[
             0.9872770340850194, 0.9687445898536212, 0.4050741092611545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.09653745999529093], {
             RGBColor[
             0.28961174034798287`, 0.421730679923598, 0.9398043322194181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.09653745999529093], {
             RGBColor[
             0.21909843402136348`, 0.34761672417247863`, 0.9357887037392056]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.09653745999529093], {
             RGBColor[
             0.20290260740476634`, 0.33059388352371805`, 0.9348663753729688]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.09653745999529093], {
             RGBColor[
             0.9703761157708419, 0.9117338238555674, 0.33941723308119276`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.09653745999529093], {
             RGBColor[
             0.9852399747517544, 0.9881643644915732, 0.8942753462917085]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.09653745999529093], {
             RGBColor[
             0.2610883790761277, 0.39175081874132034`, 0.9381799689915176]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.09653745999529093], {
             RGBColor[
             0.27079044913528966`, 0.40194830952027055`, 0.9387324875284604]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.09653745999529093], {
             RGBColor[
             0.18257815057035692`, 0.3092315907457619, 0.9337089276235886]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.09653745999529093], {
             RGBColor[
             0.519374038863881, 0.6206902681403376, 0.955306173350608]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.09653745999529093], {
             RGBColor[
             0.46295717480753656`, 0.5748885163486347, 0.9508648311503101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.09653745999529093], {
             RGBColor[
             0.2828083531870263, 0.41457988865777246`, 0.939416889385311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.09653745999529093], {
             RGBColor[
             0.9258119809847409, 0.9436813594132142, 0.9927859673000785]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.09653745999529093], {
             RGBColor[
             0.24327422624281886`, 0.37302701463098736`, 0.937165479341338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.09653745999529093], {
             RGBColor[
             0.25427950679235417`, 0.38459426226363735`, 0.9377922137877805]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.09653745999529093], {
             RGBColor[
             0.9906270631619555, 0.9903920639910485, 0.8049973499967711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.09653745999529093], {
             RGBColor[
             0.2238174684207968, 0.35257672853034516`, 0.9360574457670676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.09653745999529093], {
             RGBColor[
             0.24158367299712782`, 0.37125013598249945`, 0.9370692048349454]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.09653745999529093], {
             RGBColor[
             0.7098940201909748, 0.7732938710583535, 0.9717192596619902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.09653745999529093], {
             RGBColor[
             0.8177864636409283, 0.8575802678943982, 0.9824729701128726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.09653745999529093], {
             RGBColor[
             0.5084161265639328, 0.611794141286916, 0.9544435263542006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.09653745999529093], {
             RGBColor[
             0.8302102447519867, 0.867451129981215, 0.983667388353521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.09653745999529093], {
             RGBColor[
             0.2799576543907215, 0.4115836234781131, 0.9392545463060924]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.09653745999529093], {
             RGBColor[
             0.21156771774634342`, 0.33970146389244305`, 0.9353598405880397]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.09653745999529093], {
             RGBColor[
             0.3393902356747875, 0.4683844967174319, 0.9428466235995638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.09653745999529093], {
             RGBColor[
             0.3185921337049145, 0.45037022613412764`, 0.941521386933083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.09653745999529093], {
             RGBColor[
             0.3094371851822424, 0.44244066986488095`, 0.9409380417086214]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.09653745999529093], {
             RGBColor[
             0.23513882534723038`, 0.36447619247551505`, 0.9367021802955814]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.09653745999529093], {
             RGBColor[
             0.22477195032544567`, 0.3535799495297792, 0.936111802099508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.09653745999529093], {
             RGBColor[
             0.45209247002133757`, 0.5660015075294104, 0.9500279103134532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.09653745999529093], {
             RGBColor[
             0.5272216074067284, 0.6270612778123552, 0.9559239626928917]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.09653745999529093], {
             RGBColor[
             0.19556045555100107`, 0.3228768164060961, 0.9344482506866372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.09653745999529093], {
             RGBColor[
             0.26139903658851843`, 0.39207733948366696`, 0.9381976604772716]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.09653745999529093], {
             RGBColor[
             0.28051817934621337`, 0.41217277074566994`, 0.9392864673730853]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.09653745999529093], {
             RGBColor[
             0.2110065608580655, 0.33911165242346125`, 0.9353278835334095]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.09653745999529093], {
             RGBColor[
             0.2847433322190086, 0.4166136743051424, 0.9395270835786375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.09653745999529093], {
             RGBColor[
             0.9942883740099587, 0.9901917344782997, 0.6197029429328111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.09653745999529093], {
             RGBColor[
             0.36576050208801136`, 0.49122509607643855`, 0.9445269136571035]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.09653745999529093], {
             RGBColor[
             0.99377812825938, 0.9891003704115706, 0.5641658418540755]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.09653745999529093], {
             RGBColor[
             0.2215837127017966, 0.35022890964138337`, 0.935930236683416]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.09653745999529093], {
             RGBColor[
             0.6033581995623302, 0.6888723932386622, 0.9619177141249072]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.09653745999529093], {
             RGBColor[
             0.7222005724227306, 0.7829078431950623, 0.9729458617771823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.09653745999529093], {
             RGBColor[
             0.32062864936426844`, 0.45213415364000675`, 0.941651151910077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.09653745999529093], {
             RGBColor[
             0.20194739446585683`, 0.3295898941609259, 0.9348119774092088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.09653745999529093], {
             RGBColor[
             0.3450320119322843, 0.4732711197477559, 0.9432061125938647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.09653745999529093], {
             RGBColor[
             0.2800500850584523, 0.411680773970341, 0.9392598100958807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.09653745999529093], {
             RGBColor[
             0.26295522261758464`, 0.39371298966810864`, 0.9382862829694559]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.09653745999529093], {
             RGBColor[
             0.4453791406536688, 0.5601867590528806, 0.9496001429025095]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.09653745999529093], {
             RGBColor[
             0.4327427506991586, 0.5492417531977101, 0.948794963308529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.09653745999529093], {
             RGBColor[
             0.24574449108125243`, 0.37562341960001794`, 0.9373061572694574]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.09653745999529093], {
             RGBColor[
             0.9941541355650164, 0.9899046120181566, 0.6050919166244885]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.09653745999529093], {
             RGBColor[
             0.21037964845754836`, 0.3384527277419758, 0.9352921817996338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.09653745999529093], {
             RGBColor[
             0.27977343586669706`, 0.4113899981292344, 0.939244055333676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.09653745999529093], {
             RGBColor[
             0.23092116646773903`, 0.3600431655781515, 0.9364619908618614]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.09653745999529093], {
             RGBColor[
             0.5183784049780293, 0.6198819676990077, 0.9552277934039866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.09653745999529093], {
             RGBColor[
             0.6756901028072094, 0.7465735108387558, 0.9683101328309576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.09653745999529093], {
             RGBColor[
             0.9685766725786527, 0.9056638794389593, 0.332426736075871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.09653745999529093], {
             RGBColor[
             0.2455681205459235, 0.37543804298484945`, 0.9372961132283874]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.09653745999529093], {
             RGBColor[
             0.3103917228488082, 0.4432674424152022, 0.9409988640046705]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.09653745999529093], {
             RGBColor[
             0.35562652096447817`, 0.48244755097593534`, 0.9438811853410396]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.09653745999529093], {
             RGBColor[
             0.40465902674538534`, 0.5249170430379596, 0.9470054932516565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.09653745999529093], {
             RGBColor[
             0.8625124936811881, 0.46858316947675277`, 0.2069893934114667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.09653745999529093], {
             RGBColor[
             0.34952976604112324`, 0.4771668482931376, 0.9434927055084721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.09653745999529093], {
             RGBColor[
             0.25624071750281635`, 0.38665561906827417`, 0.93790390183639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.09653745999529093], {
             RGBColor[
             0.9012804456996433, 0.6446193851073215, 0.2393383228651273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.09653745999529093], {
             RGBColor[
             0.21931469518675756`, 0.34784402836905765`, 0.9358010194926452]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.09653745999529093], {
             RGBColor[
             0.21278150541118618`, 0.3409772316867757, 0.9354289639999145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.09653745999529093], {
             RGBColor[
             0.25745394897088236`, 0.38793080226452953`, 0.9379729935736814]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.09653745999529093], {
             RGBColor[
             0.8312166238387177, 0.8682535893475418, 0.9837633776892186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.09653745999529093], {
             RGBColor[
             0.27204560568907665`, 0.4032675586398226, 0.9388039668373608]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.09653745999529093], {
             RGBColor[
             0.2514775053864574, 0.3816491811288898, 0.9376326439529042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.09653745999529093], {
             RGBColor[
             0.2503218011924054, 0.380434462745063, 0.9375668283087641]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.09653745999529093], {
             RGBColor[
             0.2761037265699157, 0.40753290098530925`, 0.9390350708180728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.09653745999529093], {
             RGBColor[
             0.25484534055170655`, 0.38518898942064916`, 0.9378244371832996]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.09653745999529093], {
             RGBColor[
             0.43839329858407067`, 0.5541359737708264, 0.9491550112231723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.09653745999529093], {
             RGBColor[
             0.41487938737084307`, 0.5337694057214698, 0.9476567255932007]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.09653745999529093], {
             RGBColor[
             0.20852643568424656`, 0.3365048836167593, 0.9351866440737768]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.09653745999529093], {
             RGBColor[
             0.22095736038557218`, 0.3495705736440009, 0.9358945668456122]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.09653745999529093], {
             RGBColor[
             0.26549066491796636`, 0.3963779002821365, 0.9384306726576119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.09653745999529093], {
             RGBColor[
             0.9931470290452047, 0.9914341346439413, 0.7632349938486772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.09653745999529093], {
             RGBColor[
             0.898780922280212, 0.63326963303821, 0.23725265925502825`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.09653745999529093], {
             RGBColor[
             0.28023632613366145`, 0.41187652514875206`, 0.939270416249595]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.09653745999529093], {
             RGBColor[
             0.7484278388783107, 0.8033967830847693, 0.9755599505897345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.09653745999529093], {
             RGBColor[
             0.5754210452890663, 0.6661917528451691, 0.9597183990033479]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.09653745999529093], {
             RGBColor[
             0.3393631406607411, 0.4683610283780999, 0.942844897129228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.09653745999529093], {
             RGBColor[
             0.2935687509337651, 0.4258897489382169, 0.9400296781184059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.09653745999529093], {
             RGBColor[
             0.22336510960731928`, 0.352101270736175, 0.9360316846018449]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.09653745999529093], {
             RGBColor[
             0.17908812663026416`, 0.30556335430442605`, 0.933510175923228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.09653745999529093], {
             RGBColor[
             0.26629927432356376`, 0.3972278000362168, 0.9384767217670303]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.09653745999529093], {
             RGBColor[
             0.8203907902431329, 0.1577381258757864, 0.16715954980591485`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.09653745999529093], {
             RGBColor[
             0.24794921220500737`, 0.3779407212884774, 0.9374317128758627]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.09653745999529093], {
             RGBColor[
             0.22281999879048459`, 0.3515283247056597, 0.9360006413472455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.09653745999529093], {
             RGBColor[
             0.35886795134781274`, 0.48525511505495156`, 0.9440877264187814]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.09653745999529093], {
             RGBColor[
             0.27306809856961783`, 0.40434226348706437`, 0.938862196294265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.09653745999529093], {
             RGBColor[
             0.2782995151593558, 0.4098408140138484, 0.9391601177298633]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.09653745999529093], {
             RGBColor[
             0.2493495489754894, 0.37941256402073326`, 0.9375114599833291]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.09653745999529093], {
             RGBColor[
             0.9394254025446074, 0.954344144916344, 0.9874211724934188]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.09653745999529093], {
             RGBColor[
             0.2348790166106703, 0.36420311702056507`, 0.9366873845723869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.09653745999529093], {
             RGBColor[
             0.38961090759033284`, 0.5118831185663134, 0.9460466404056259]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{{3.834946926643799*^9, 3.8349469478612347`*^9}, 
   3.834947050298876*^9, {3.8349471234738255`*^9, 3.8349471300172663`*^9}, {
   3.8349471617829676`*^9, 3.834947218900016*^9}, {3.8349472753220577`*^9, 
   3.834947307624898*^9}, 3.83494993428115*^9, 3.8349573375769677`*^9, {
   3.8349587473655295`*^9, 3.83495875945916*^9}, 3.835018920680505*^9, 
   3.835019004300144*^9, 3.8350204747493663`*^9, 3.8350205388580465`*^9, {
   3.8350445644807453`*^9, 3.8350445774530525`*^9}, 3.8350450259183207`*^9, 
   3.835045692651933*^9, 3.8350457593931894`*^9, 3.835045816585536*^9, 
   3.835052059319915*^9},
 Background->RGBColor[1, 1, 0.85],
 CellLabel->
  "Out[415]=",ExpressionUUID->"1581a78b-c893-439d-a9ca-3ed118777aa6"]
}, Open  ]],

Cell["Estimated with cubic Mean Deviation v Calculated: (r=6)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 
  3.834950339812094*^9}},ExpressionUUID->"1399239a-bf75-4485-85ec-\
e94cf5814652"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphinf4", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsif4", ",", "#"}], "}"}], "]"}], ",", "500", ",", "3"}],
      "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"CMDi6f400", ",", "krif4"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.834950273560528*^9, 3.834950273964845*^9}, {
   3.834957360267254*^9, 3.8349573712318316`*^9}, {3.8349587856645794`*^9, 
   3.83495878977224*^9}, {3.8350188291975336`*^9, 3.8350188308736053`*^9}, {
   3.8350443206807604`*^9, 3.835044327012074*^9}, {3.8350446304641314`*^9, 
   3.835044631224497*^9}, {3.8350448339393716`*^9, 3.8350448366448307`*^9}, {
   3.835045599457345*^9, 3.8350456034768167`*^9}, {3.83505207591029*^9, 
   3.835052078308282*^9}, 3.835130050172763*^9},
 CellLabel->
  "In[570]:=",ExpressionUUID->"ae370df5-92ec-4842-8260-fded7e430289"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN2wucz2W+wPHn16rdrWxoc2ntsSnFoptQYTEuNY3rMEhyNxmZGTMj4zII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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[105, 155] -> 
             RGBColor[
              0.711142283604687, 0.771060717502744, 0.9341470465638629], 
             UndirectedEdge[1, 203] -> 
             RGBColor[
              0.8555215896098189, 0.8831262955778028, 0.6988553192975013], 
             UndirectedEdge[187, 193] -> 
             RGBColor[
              0.7056720910239382, 0.768653473849357, 0.9724782445766642], 
             UndirectedEdge[209, 371] -> 
             RGBColor[
              0.5511211403845515, 0.6464597069581322, 0.9578083534696051], 
             UndirectedEdge[23, 245] -> 
             RGBColor[
              0.7289108550643819, 0.7862603034582553, 0.9482582725750914], 
             UndirectedEdge[201, 236] -> 
             RGBColor[
              0.7670357877328653, 0.8181852783841566, 0.9773477906230137], 
             UndirectedEdge[258, 369] -> 
             RGBColor[
              0.9943753330662957, 0.9903777311068951, 0.6291678995659978], 
             UndirectedEdge[161, 312] -> 
             RGBColor[
              0.700672793536256, 0.7660901787117689, 0.9708001739663104], 
             UndirectedEdge[74, 132] -> 
             RGBColor[
              0.6570864559207084, 0.7242493955113904, 0.9308357438649091], 
             UndirectedEdge[89, 169] -> 
             RGBColor[
              0.8031731539292879, 0.8461642392823975, 0.9810164519699598], 
             UndirectedEdge[124, 137] -> 
             RGBColor[
              0.7502547995166352, 0.8042983238809023, 0.9689829220094728], 
             UndirectedEdge[186, 393] -> 
             RGBColor[
              0.8366327177456784, 0.8729730063207857, 0.9706697124876806], 
             UndirectedEdge[84, 261] -> 
             RGBColor[
              0.6545030297845904, 0.7282546526888585, 0.9674067541252332], 
             UndirectedEdge[58, 243] -> 
             RGBColor[
              0.6961352789319106, 0.762045074282109, 0.9706900181972096], 
             UndirectedEdge[205, 250] -> 
             RGBColor[
              0.7179865649904325, 0.7796158285613084, 0.9725258488984694], 
             UndirectedEdge[327, 337] -> 
             RGBColor[
              0.6445989179455598, 0.7205731872547403, 0.9663815210488298], 
             UndirectedEdge[38, 224] -> 
             RGBColor[
              0.7972258283500251, 0.5682141270335217, 0.5822827446101525], 
             UndirectedEdge[49, 301] -> 
             RGBColor[
              0.6857856695399872, 0.7527487882666255, 0.970636468687094], 
             UndirectedEdge[22, 97] -> 
             RGBColor[
              0.6415610532555065, 0.7122979069138635, 0.951677318008543], 
             UndirectedEdge[163, 169] -> 
             RGBColor[
              0.8911661474946764, 0.9088615351594913, 0.6993259824345514], 
             UndirectedEdge[126, 318] -> 
             RGBColor[
              0.5932058995853354, 0.6806302987614359, 0.961118487881618], 
             UndirectedEdge[126, 149] -> 
             RGBColor[
              0.7359047337660395, 0.6331781191162136, 0.5952336384409035], 
             UndirectedEdge[28, 47] -> 
             RGBColor[
              0.7366112711750741, 0.7938028142924503, 0.9748776109974654], 
             UndirectedEdge[203, 392] -> 
             RGBColor[
              0.7820826121873565, 0.8298948686724927, 0.9788594865025395], 
             UndirectedEdge[116, 387] -> 
             RGBColor[
              0.471435729558509, 0.5785151376737602, 0.9524321165167333], 
             UndirectedEdge[114, 203] -> 
             RGBColor[
              0.7078672178884448, 0.771710517695349, 0.9715172469500184], 
             UndirectedEdge[38, 207] -> 
             RGBColor[
              0.7916929437830262, 0.563891795558302, 0.58173127838426], 
             UndirectedEdge[4, 73] -> 
             RGBColor[
              0.738984657411348, 0.7941608715247575, 0.9416003820604252], 
             UndirectedEdge[143, 223] -> 
             RGBColor[
              0.5487855056220634, 0.6432351496307422, 0.9581931586742967], 
             UndirectedEdge[70, 164] -> 
             RGBColor[
              0.8192482434082398, 0.8565218763451998, 0.8273781143561273], 
             UndirectedEdge[291, 331] -> 
             RGBColor[
              0.7781047525064488, 0.82242685679346, 0.7658233957717437], 
             UndirectedEdge[317, 381] -> 
             RGBColor[
              0.9116756947673721, 0.6139669107031719, 0.47390942263563285`], 
             UndirectedEdge[120, 349] -> 
             RGBColor[
              0.6568515381895488, 0.7284914945582668, 0.9686921263233639], 
             UndirectedEdge[102, 160] -> 
             RGBColor[
              0.649815797915406, 0.676405594904842, 0.6266889185040565], 
             UndirectedEdge[84, 381] -> 
             RGBColor[
              0.7598379484327392, 0.8090576999115855, 0.8633644060737933], 
             UndirectedEdge[110, 203] -> 
             RGBColor[
              0.6445603632371825, 0.7211541701869921, 0.9659598643891187], 
             UndirectedEdge[316, 355] -> 
             RGBColor[
              0.8721282031297055, 0.8987293363497265, 0.8816134637440713], 
             UndirectedEdge[62, 77] -> 
             RGBColor[
              0.8767730370820861, 0.9026675796715551, 0.8961178859998276], 
             UndirectedEdge[188, 361] -> 
             RGBColor[
              0.9789157001902236, 0.9833290534839345, 0.899666077282695], 
             UndirectedEdge[168, 282] -> 
             RGBColor[
              0.5210653037248263, 0.6220633131450668, 0.9554393159157688], 
             UndirectedEdge[271, 394] -> 
             RGBColor[
              0.6662230321345599, 0.737469149979626, 0.968534731944038], 
             UndirectedEdge[160, 224] -> 
             RGBColor[
              0.8572803535442114, 0.846329529866612, 0.6432898592946017], 
             UndirectedEdge[97, 168] -> 
             RGBColor[
              0.7392322654549479, 0.7949885532560741, 0.9584278197443651], 
             UndirectedEdge[88, 132] -> 
             RGBColor[
              0.7401011169221174, 0.7948730385467573, 0.9364788898668277], 
             UndirectedEdge[329, 353] -> 
             RGBColor[
              0.8116121483147033, 0.8533816718157162, 0.9658941814133699], 
             UndirectedEdge[189, 339] -> 
             RGBColor[
              0.7186537691299072, 0.779410381712347, 0.9732495297560085], 
             UndirectedEdge[316, 380] -> 
             RGBColor[
              0.9925234982606006, 0.9895090294096892, 0.6523763669989626], 
             UndirectedEdge[156, 295] -> 
             RGBColor[
              0.8051379768345261, 0.8477660385968283, 0.9811945433120233], 
             UndirectedEdge[154, 228] -> 
             RGBColor[
              0.5518934269794673, 0.6470909723943103, 0.9578662187055107], 
             UndirectedEdge[29, 91] -> 
             RGBColor[
              0.7278950419575092, 0.7860847612642594, 0.9655891474796154], 
             UndirectedEdge[6, 198] -> 
             RGBColor[
              0.8235104315217088, 0.8586186802517353, 0.7290579351990022], 
             UndirectedEdge[56, 254] -> 
             RGBColor[
              0.5881536765522475, 0.6755380127134549, 0.961398080621056], 
             UndirectedEdge[245, 315] -> 
             RGBColor[
              0.6420535480539967, 0.7179984859800873, 0.9665286371512942], 
             UndirectedEdge[174, 281] -> 
             RGBColor[
              0.7542446270667587, 0.8080513743579306, 0.9763428806444634], 
             UndirectedEdge[89, 329] -> 
             RGBColor[
              0.8840288442343256, 0.9099541450553988, 0.9731120008901383], 
             UndirectedEdge[260, 267] -> 
             RGBColor[
              0.8099740286676016, 0.8490224598733243, 0.8275637284203496], 
             UndirectedEdge[202, 363] -> 
             RGBColor[
              0.6869086503425157, 0.749347679163567, 0.9117315443560237], 
             UndirectedEdge[43, 238] -> 
             RGBColor[
              0.4150979684901007, 0.5339587297007643, 0.9476706533888362], 
             UndirectedEdge[276, 377] -> 
             RGBColor[
              0.983498589526175, 0.9862555253093236, 0.8699007744836482], 
             UndirectedEdge[284, 369] -> 
             RGBColor[
              0.9820435470321958, 0.9831433353493114, 0.7420867805656326], 
             UndirectedEdge[53, 249] -> 
             RGBColor[
              0.7550984718514222, 0.8068372812269644, 0.9310189015448824], 
             UndirectedEdge[15, 105] -> 
             RGBColor[
              0.7155445741739468, 0.7735920145486699, 0.8930224215878042], 
             UndirectedEdge[97, 112] -> 
             RGBColor[
              0.7672114954217925, 0.8177033525931046, 0.9606304472186515], 
             UndirectedEdge[120, 246] -> 
             RGBColor[
              0.9380729050764243, 0.9505903708380146, 0.8803833684450665], 
             UndirectedEdge[53, 308] -> 
             RGBColor[
              0.9887885943789794, 0.9877139587173218, 0.6960580002178177], 
             UndirectedEdge[188, 392] -> 
             RGBColor[
              0.9081945323894568, 0.9287277752190489, 0.9596971691721445], 
             UndirectedEdge[91, 273] -> 
             RGBColor[
              0.8366280575514173, 0.873055713474056, 0.9750401560850821], 
             UndirectedEdge[327, 354] -> 
             RGBColor[
              0.5279770442087555, 0.6276745754402808, 0.9559834334452033], 
             UndirectedEdge[51, 376] -> 
             RGBColor[
              0.8268961218732637, 0.8648085383571904, 0.983351284354796], 
             UndirectedEdge[202, 214] -> 
             RGBColor[
              0.9745498371168922, 0.9801980825119565, 0.9126577972469572], 
             UndirectedEdge[69, 132] -> 
             RGBColor[
              0.8901523369507932, 0.9142682038751605, 0.9499482094227112], 
             UndirectedEdge[130, 387] -> 
             RGBColor[
              0.7784667235330378, 0.8270873404570407, 0.9681276101356924], 
             UndirectedEdge[61, 306] -> 
             RGBColor[
              0.2900871807100718, 0.4198574852314677, 0.9399182918010736], 
             UndirectedEdge[312, 356] -> 
             RGBColor[
              0.6997634561843546, 0.7653797974612437, 0.9707095397173136], 
             UndirectedEdge[18, 247] -> 
             RGBColor[
              0.48715411284890675`, 0.5945326807102556, 0.9527697027492312], 
             UndirectedEdge[56, 320] -> 
             RGBColor[
              0.5592997074075189, 0.6509795125753105, 0.9594397932001272], 
             UndirectedEdge[43, 124] -> 
             RGBColor[
              0.47592250352979504`, 0.5838390919901567, 0.9523207589869406], 
             UndirectedEdge[259, 318] -> 
             RGBColor[
              0.7472248319927823, 0.8024463473955814, 0.975682111671851], 
             UndirectedEdge[267, 384] -> 
             RGBColor[
              0.7040673543240509, 0.7619529902395189, 0.8195274434713186], 
             UndirectedEdge[44, 324] -> 
             RGBColor[
              0.6936744857462808, 0.5087834861055992, 0.5759227380198646], 
             UndirectedEdge[62, 204] -> 
             RGBColor[
              0.8507304680281025, 0.884212190700202, 0.9835106102217115], 
             UndirectedEdge[42, 109] -> 
             RGBColor[
              0.5954953480951477, 0.6786204548799974, 0.9633163539498635], 
             UndirectedEdge[8, 21] -> 
             RGBColor[
              0.383445249896844, 0.5065427357671797, 0.9456537701494738], 
             UndirectedEdge[48, 349] -> 
             RGBColor[
              0.6551242705708414, 0.7271142182445401, 0.9685273779959416], 
             UndirectedEdge[222, 332] -> 
             RGBColor[
              0.5847301547636432, 0.6737493072872331, 0.9604512462015782], 
             UndirectedEdge[58, 167] -> 
             RGBColor[
              0.6322162941609142, 0.7121110775767296, 0.9643191711521104], 
             UndirectedEdge[76, 144] -> 
             RGBColor[
              0.9256388732420784, 0.942106266665926, 0.9413127072469918], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.45326696998157434`, 0.5650185209976788, 0.9506554315607919], 
             UndirectedEdge[6, 166] -> 
             RGBColor[
              0.7117817384230254, 0.7747685708884213, 0.9719074097736312], 
             UndirectedEdge[79, 343] -> 
             RGBColor[
              0.8784044349786067, 0.9016116702455477, 0.7432898198661262], 
             UndirectedEdge[142, 257] -> 
             RGBColor[
              0.7268718563088261, 0.7851168856168176, 0.961828506530883], 
             UndirectedEdge[175, 256] -> 
             RGBColor[
              0.43990896116992156`, 0.5482273776156753, 0.950501307924951], 
             UndirectedEdge[8, 171] -> 
             RGBColor[
              0.5144065317592252, 0.61393325851462, 0.9558013286874489], 
             UndirectedEdge[31, 214] -> 
             RGBColor[
              0.9429703143684738, 0.9566627919930173, 0.9701476717994177], 
             UndirectedEdge[41, 114] -> 
             RGBColor[
              0.5676584533569071, 0.6586399000517174, 0.9597944457146933], 
             UndirectedEdge[72, 399] -> 
             RGBColor[
              0.699984322315247, 0.7650282135337625, 0.9710899015534409], 
             UndirectedEdge[278, 392] -> 
             RGBColor[
              0.6732650757766254, 0.7427198860993471, 0.9694944064132882], 
             UndirectedEdge[6, 323] -> 
             RGBColor[
              0.49131413832090776`, 0.5943500268255528, 0.9541528832937565], 
             UndirectedEdge[132, 323] -> 
             RGBColor[
              0.654242066605047, 0.7217857284493284, 0.9306545018929099], 
             UndirectedEdge[200, 355] -> 
             RGBColor[
              0.4657428868315568, 0.5560089503674623, 0.9547363417816517], 
             UndirectedEdge[98, 215] -> 
             RGBColor[
              0.6885970102925741, 0.7533088255046992, 0.9586256521565186], 
             UndirectedEdge[12, 367] -> 
             RGBColor[
              0.9699412136932561, 0.9756298324896222, 0.8698039558314987], 
             UndirectedEdge[88, 140] -> 
             RGBColor[
              0.7477725933760258, 0.7986285169547986, 0.8311895466992393], 
             UndirectedEdge[195, 327] -> 
             RGBColor[
              0.602944895789334, 0.6880327485640031, 0.9622298373992657], 
             UndirectedEdge[142, 381] -> 
             RGBColor[
              0.7482334138530511, 0.7996366159614694, 0.8624508546028693], 
             UndirectedEdge[313, 359] -> 
             RGBColor[
              0.3894605544413865, 0.5102137658057662, 0.9462619637445646], 
             UndirectedEdge[64, 82] -> 
             RGBColor[
              0.5667481212909691, 0.6582130407736252, 0.959583383489361], 
             UndirectedEdge[98, 297] -> 
             RGBColor[
              0.9262490936971268, 0.9436506758783969, 0.9796796786750792], 
             UndirectedEdge[139, 305] -> 
             RGBColor[
              0.49239219000017825`, 0.5974014698652745, 0.953564388734776], 
             UndirectedEdge[288, 375] -> 
             RGBColor[
              0.6379762533337345, 0.7165806286831982, 0.9649138993447625], 
             UndirectedEdge[136, 194] -> 
             RGBColor[
              0.9510960827354811, 0.9630426460936525, 0.9674760027833752], 
             UndirectedEdge[254, 349] -> 
             RGBColor[
              0.4497264037481453, 0.5635187821531573, 0.9499968846843455], 
             UndirectedEdge[348, 351] -> 
             RGBColor[
              0.6682618312876265, 0.7308362627512697, 0.8083757515470045], 
             UndirectedEdge[65, 282] -> 
             RGBColor[
              0.7337093951454567, 0.7907048061588082, 0.9633564507114667], 
             UndirectedEdge[131, 215] -> 
             RGBColor[
              0.6486687385207561, 0.7218503307644815, 0.9679652387762554], 
             UndirectedEdge[230, 250] -> 
             RGBColor[
              0.488711478114727, 0.5829702667013216, 0.955597942177991], 
             UndirectedEdge[26, 111] -> 
             RGBColor[
              0.8601626121254744, 0.8914955463549818, 0.9801426157357356], 
             UndirectedEdge[301, 390] -> 
             RGBColor[
              0.9247164246623112, 0.9413840166097522, 0.9418016213073093], 
             UndirectedEdge[3, 309] -> 
             RGBColor[
              0.6755000553343491, 0.73868536570484, 0.8823075055150535], 
             UndirectedEdge[90, 268] -> 
             RGBColor[
              0.6343265493450492, 0.7087896828578211, 0.9673451493380372], 
             UndirectedEdge[17, 187] -> 
             RGBColor[
              0.7396531511545399, 0.7949813833591695, 0.9491039454736359], 
             UndirectedEdge[4, 206] -> 
             RGBColor[
              0.899075329009061, 0.9213776863204359, 0.9560993596214769], 
             UndirectedEdge[19, 231] -> 
             RGBColor[
              0.6892880803658612, 0.7571138491877325, 0.9697218613194765], 
             UndirectedEdge[76, 138] -> 
             RGBColor[
              0.7796268551281451, 0.8281425408188783, 0.9785706342661626], 
             UndirectedEdge[28, 390] -> 
             RGBColor[
              0.7825836365233578, 0.8290361546045171, 0.9283826453916786], 
             UndirectedEdge[123, 174] -> 
             RGBColor[
              0.7011073406857594, 0.765873918108881, 0.9712234426635008], 
             UndirectedEdge[2, 98] -> 
             RGBColor[
              0.7925195404251717, 0.838398139110335, 0.966607787298019], 
             UndirectedEdge[20, 364] -> 
             RGBColor[
              0.6366293898465288, 0.7155634440007561, 0.9647557300947305], 
             UndirectedEdge[56, 196] -> 
             RGBColor[
              0.6839652523301485, 0.7530381205395416, 0.9691349223997351], 
             UndirectedEdge[360, 374] -> 
             RGBColor[
              0.9728076282299449, 0.9791193929635393, 0.9254879253316448], 
             UndirectedEdge[39, 360] -> 
             RGBColor[
              0.8991830196476797, 0.9218035970495766, 0.967899070935903], 
             UndirectedEdge[261, 264] -> 
             RGBColor[
              0.68557634193563, 0.7534813673298323, 0.969852959083056], 
             UndirectedEdge[101, 253] -> 
             RGBColor[
              0.642653142998193, 0.7198888186408108, 0.9656162216025898], 
             UndirectedEdge[141, 273] -> 
             RGBColor[
              0.7691532294189349, 0.819587615693907, 0.9776256638290377], 
             UndirectedEdge[171, 182] -> 
             RGBColor[
              0.5455769362408116, 0.6409314962064878, 0.9577874792981093], 
             UndirectedEdge[156, 175] -> 
             RGBColor[
              0.6933674500524678, 0.7598065398845022, 0.9704663036537828], 
             UndirectedEdge[121, 250] -> 
             RGBColor[
              0.8600379580376261, 0.8898876003950351, 0.9077625823553512], 
             UndirectedEdge[68, 308] -> 
             RGBColor[
              0.6744299607585521, 0.7350803449268823, 0.7148864986556895], 
             UndirectedEdge[39, 390] -> 
             RGBColor[
              0.9113834519632072, 0.9307526660933896, 0.9405299104687835], 
             UndirectedEdge[54, 181] -> 
             RGBColor[
              0.6592992669961661, 0.732643721622966, 0.9674457143946252], 
             UndirectedEdge[196, 313] -> 
             RGBColor[
              0.5700588620503264, 0.6615544452756434, 0.9594904718605461], 
             UndirectedEdge[200, 241] -> 
             RGBColor[
              0.48577563315917877`, 0.5716586840531117, 0.9567330187189309], 
             UndirectedEdge[186, 255] -> 
             RGBColor[
              0.7873086388324675, 0.8341583366113974, 0.9659465759856196], 
             UndirectedEdge[11, 38] -> 
             RGBColor[
              0.7919829607282556, 0.5641183590001255, 0.581760184562998], 
             UndirectedEdge[173, 310] -> 
             RGBColor[
              0.7343880083625998, 0.7920047453274479, 0.9746946735204904], 
             UndirectedEdge[106, 173] -> 
             RGBColor[
              0.877373163414257, 0.9050575611191864, 0.9881658296383629], 
             UndirectedEdge[51, 396] -> 
             RGBColor[
              0.8761005754674418, 0.9040428340338756, 0.9880444490639428], 
             UndirectedEdge[6, 18] -> 
             RGBColor[
              0.5764917246959957, 0.6668840937952796, 0.9599236239298767], 
             UndirectedEdge[238, 287] -> 
             RGBColor[
              0.4304570133467286, 0.5472619623875349, 0.9486493181456304], 
             UndirectedEdge[93, 225] -> 
             RGBColor[
              0.9190304623304796, 0.938113608979577, 0.9865796515079162], 
             UndirectedEdge[116, 276] -> 
             RGBColor[
              0.6552074364080094, 0.7227858609416875, 0.9331091733354254], 
             UndirectedEdge[135, 276] -> 
             RGBColor[
              0.9183564884029958, 0.936670562869544, 0.9551163433438016], 
             UndirectedEdge[147, 172] -> 
             RGBColor[
              0.6633216761370117, 0.7291431471420393, 0.9185102771399013], 
             UndirectedEdge[185, 224] -> 
             RGBColor[
              0.6486132433698724, 0.7239394234440646, 0.9666242324722331], 
             UndirectedEdge[160, 166] -> 
             RGBColor[
              0.8663215018532178, 0.85339254364088, 0.6441909964637089], 
             UndirectedEdge[63, 156] -> 
             RGBColor[
              0.8084850018451033, 0.8504348654876889, 0.9815137855454565], 
             UndirectedEdge[247, 302] -> 
             RGBColor[
              0.427209186742027, 0.5438538758344703, 0.9486067649130359], 
             UndirectedEdge[81, 240] -> 
             RGBColor[
              0.7409814637134604, 0.7975796182114409, 0.9748177655036346], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.7841184530473887, 0.8295606098551331, 0.8983386826557158], 
             UndirectedEdge[12, 212] -> 
             RGBColor[
              0.9819133522973569, 0.9845586338579826, 0.8495382480085921], 
             UndirectedEdge[18, 74] -> 
             RGBColor[
              0.4167442841232918, 0.5341422083576014, 0.9481188553170852], 
             UndirectedEdge[1, 7] -> 
             RGBColor[
              0.8746052217352627, 0.8980345740351754, 0.7007573974010839], 
             UndirectedEdge[231, 331] -> 
             RGBColor[
              0.6519768312314012, 0.7268228962877592, 0.9667845831120028], 
             UndirectedEdge[58, 351] -> 
             RGBColor[
              0.4757170800303316, 0.5822179422173389, 0.9527064361944069], 
             UndirectedEdge[142, 279] -> 
             RGBColor[
              0.6224862713267973, 0.7028873843065195, 0.9644587029412173], 
             UndirectedEdge[303, 344] -> 
             RGBColor[
              0.5305020568749435, 0.6297244944732165, 0.9561822116917118], 
             UndirectedEdge[302, 323] -> 
             RGBColor[
              0.3539549687007507, 0.48099973641975413`, 0.9437746755088905], 
             UndirectedEdge[144, 366] -> 
             RGBColor[
              0.9832615821594685, 0.9868756021490264, 0.9059859346842648], 
             UndirectedEdge[56, 342] -> 
             RGBColor[
              0.8017397712583756, 0.8456625194555616, 0.9807095744178912], 
             UndirectedEdge[137, 293] -> 
             RGBColor[
              0.8912706894136146, 0.6276185860827289, 0.5821529479459391], 
             UndirectedEdge[39, 374] -> 
             RGBColor[
              0.9112966792812487, 0.9307167833594434, 0.9419679583693381], 
             UndirectedEdge[4, 278] -> 
             RGBColor[
              0.7374252880975216, 0.7928949052670061, 0.9414776227958828], 
             UndirectedEdge[238, 396] -> 
             RGBColor[
              0.6804404720293501, 0.7474629512627047, 0.9708673529569114], 
             UndirectedEdge[118, 293] -> 
             RGBColor[
              0.691365346678223, 0.46915777003415404`, 0.5709146976522236], 
             UndirectedEdge[201, 228] -> 
             RGBColor[
              0.6277180861490167, 0.7080273300218969, 0.9642603478886485], 
             UndirectedEdge[212, 336] -> 
             RGBColor[
              0.8786908047143316, 0.9054735864480719, 0.956865453859546], 
             UndirectedEdge[186, 200] -> 
             RGBColor[
              0.5648076483332153, 0.6340689964555516, 0.9509285152892106], 
             UndirectedEdge[7, 356] -> 
             RGBColor[
              0.7520082531581236, 0.8061938299323155, 0.9759168128242726], 
             UndirectedEdge[215, 269] -> 
             RGBColor[
              0.41449970764994404`, 0.5334405462304848, 0.9476325327371226], 
             UndirectedEdge[36, 122] -> 
             RGBColor[
              0.9619762998874819, 0.9711625672309544, 0.9492483855079321], 
             UndirectedEdge[297, 352] -> 
             RGBColor[
              0.6903370217869751, 0.7561705804460849, 0.9713092167003525], 
             UndirectedEdge[228, 243] -> 
             RGBColor[
              0.677539955787449, 0.7469485532436739, 0.9692261262423645], 
             UndirectedEdge[100, 271] -> 
             RGBColor[
              0.8288088635809812, 0.8664820986040984, 0.9834943447110363], 
             UndirectedEdge[157, 298] -> 
             RGBColor[
              0.8804693673275228, 0.5457996354683601, 0.5722696311437314], 
             UndirectedEdge[272, 384] -> 
             RGBColor[
              0.49635280290084566`, 0.600910931330282, 0.953794933730256], 
             UndirectedEdge[35, 114] -> 
             RGBColor[
              0.6411526637328919, 0.7187166328346928, 0.9654666678522005], 
             UndirectedEdge[15, 155] -> 
             RGBColor[
              0.9843156553444882, 0.9870712979009135, 0.8777609884126902], 
             UndirectedEdge[36, 262] -> 
             RGBColor[
              0.7155256571181996, 0.7754457069346359, 0.9486022069427718], 
             UndirectedEdge[111, 185] -> 
             RGBColor[
              0.7441932044313464, 0.7994179246536963, 0.9695967369148677], 
             UndirectedEdge[26, 400] -> 
             RGBColor[
              0.7593397834422309, 0.811921277111954, 0.9766475512459465], 
             UndirectedEdge[61, 131] -> 
             RGBColor[
              0.6024797349008237, 0.6818437373557193, 0.9650221163089256], 
             UndirectedEdge[168, 350] -> 
             RGBColor[
              0.4185507230289969, 0.5350420835747851, 0.948417638316639], 
             UndirectedEdge[16, 208] -> 
             RGBColor[
              0.695568556208126, 0.7552492622298325, 0.8535046487295386], 
             UndirectedEdge[125, 303] -> 
             RGBColor[
              0.7062267780225244, 0.7693287682484344, 0.9722629700397414], 
             UndirectedEdge[145, 164] -> 
             RGBColor[
              0.994881068464534, 0.9914594479860346, 0.6842140766271507], 
             UndirectedEdge[152, 256] -> 
             RGBColor[
              0.5860852169918815, 0.6636210707457835, 0.9645111967333742], 
             UndirectedEdge[237, 246] -> 
             RGBColor[
              0.7449359449428828, 0.7969738884960987, 0.8627893271279339], 
             UndirectedEdge[16, 284] -> 
             RGBColor[
              0.684133647825325, 0.7482369062165215, 0.9407406883576561], 
             UndirectedEdge[240, 309] -> 
             RGBColor[
              0.5699226775579285, 0.657143257613521, 0.9614022247674127], 
             UndirectedEdge[151, 249] -> 
             RGBColor[
              0.7157013116162205, 0.7767361813229732, 0.9733362253915034], 
             UndirectedEdge[47, 311] -> 
             RGBColor[
              0.8997577661103328, 0.7920574126238888, 0.6165941394496777], 
             UndirectedEdge[29, 190] -> 
             RGBColor[
              0.6521796616908515, 0.7261790815263769, 0.9673533139991746], 
             UndirectedEdge[99, 384] -> 
             RGBColor[
              0.47914145124474755`, 0.5869379806933053, 0.9524399930806294], 
             UndirectedEdge[5, 398] -> 
             RGBColor[
              0.8639073320349291, 0.8945350272471715, 0.986290425533897], 
             UndirectedEdge[36, 157] -> 
             RGBColor[
              0.953754972582693, 0.9650311147882309, 0.9631649481693656], 
             UndirectedEdge[40, 55] -> 
             RGBColor[
              0.9099533167162179, 0.9278819465124375, 0.8652549260242168], 
             UndirectedEdge[163, 319] -> 
             RGBColor[
              0.9074242440780331, 0.9215952595059753, 0.7009377398905936], 
             UndirectedEdge[13, 74] -> 
             RGBColor[
              0.4879397148803726, 0.5919418663638049, 0.9537236204237387], 
             UndirectedEdge[47, 158] -> 
             RGBColor[
              0.7972465645613342, 0.8421257169929441, 0.980268812354574], 
             UndirectedEdge[252, 330] -> 
             RGBColor[
              0.960035918674199, 0.9697154340991707, 0.9525329447695481], 
             UndirectedEdge[102, 185] -> 
             RGBColor[
              0.44114868774106686`, 0.5540154884822945, 0.9500232916816878], 
             UndirectedEdge[41, 356] -> 
             RGBColor[
              0.5927158565011421, 0.6782149338313112, 0.9622919334853649], 
             UndirectedEdge[33, 175] -> 
             RGBColor[
              0.6241405440868957, 0.705725954800225, 0.9635664126293522], 
             UndirectedEdge[12, 126] -> 
             RGBColor[
              0.7872217700794342, 0.8312156710120862, 0.86244970699588], 
             UndirectedEdge[18, 191] -> 
             RGBColor[
              0.7428763174988079, 0.7964852280909342, 0.912099534536141], 
             UndirectedEdge[64, 171] -> 
             RGBColor[
              0.554317638019959, 0.6485022527671401, 0.9583444290863774], 
             UndirectedEdge[73, 184] -> 
             RGBColor[
              0.6302833428778916, 0.7089832838907854, 0.9652325822384511], 
             UndirectedEdge[93, 316] -> 
             RGBColor[
              0.9439206537764886, 0.9554297147378401, 0.888605710855376], 
             UndirectedEdge[20, 362] -> 
             RGBColor[
              0.6387636008927278, 0.7172307058906515, 0.9649684483064794], 
             UndirectedEdge[32, 330] -> 
             RGBColor[
              0.8251295794386782, 0.8635330092314066, 0.9465590926106615], 
             UndirectedEdge[124, 277] -> 
             RGBColor[
              0.7648864495909743, 0.8152105845492161, 0.9442153549791346], 
             UndirectedEdge[267, 331] -> 
             RGBColor[
              0.7786493340288014, 0.8235916616041343, 0.825097733712246], 
             UndirectedEdge[134, 167] -> 
             RGBColor[
              0.8126928645066921, 0.8539176211699159, 0.9503950752393091], 
             UndirectedEdge[143, 398] -> 
             RGBColor[
              0.7332355554169292, 0.7915284557791074, 0.974045725754265], 
             UndirectedEdge[109, 320] -> 
             RGBColor[
              0.6029753493122537, 0.6850992559784621, 0.9637929730131121], 
             UndirectedEdge[28, 147] -> 
             RGBColor[
              0.46073100535896033`, 0.5700420924332775, 0.9515292966457355], 
             UndirectedEdge[54, 311] -> 
             RGBColor[
              0.8280269394714509, 0.7354293713105805, 0.6096016135873152], 
             UndirectedEdge[160, 289] -> 
             RGBColor[
              0.7384118035865116, 0.7514997391178513, 0.6327882160879774], 
             UndirectedEdge[209, 240] -> 
             RGBColor[
              0.6190739562105082, 0.699544963141898, 0.9645812550959683], 
             UndirectedEdge[31, 261] -> 
             RGBColor[
              0.8525548283996686, 0.8855749489387249, 0.9857172049438296], 
             UndirectedEdge[245, 248] -> 
             RGBColor[
              0.7419497149676424, 0.794762912190295, 0.871474349454187], 
             UndirectedEdge[81, 245] -> 
             RGBColor[
              0.5978859357749162, 0.6834944115813835, 0.9621264223291193], 
             UndirectedEdge[308, 386] -> 
             RGBColor[
              0.9153654780345817, 0.9304814850218316, 0.735129897995414], 
             UndirectedEdge[320, 349] -> 
             RGBColor[
              0.4208724346034167, 0.5389602820150128, 0.9480385972634167], 
             UndirectedEdge[222, 356] -> 
             RGBColor[
              0.641820832723049, 0.7184913876055284, 0.9660441457695546], 
             UndirectedEdge[200, 374] -> 
             RGBColor[
              0.5819241439317571, 0.6467132896367032, 0.91652890638254], 
             UndirectedEdge[73, 348] -> 
             RGBColor[
              0.7494369585143464, 0.7997675279500691, 0.8139290563526951], 
             UndirectedEdge[23, 81] -> 
             RGBColor[
              0.8344432709162487, 0.8710009214359749, 0.9572056757840472], 
             UndirectedEdge[25, 233] -> 
             RGBColor[
              0.6267727564056885, 0.7059915217678028, 0.9650531038269586], 
             UndirectedEdge[168, 170] -> 
             RGBColor[
              0.7309376671281567, 0.7086174644188183, 0.6124303091570746], 
             UndirectedEdge[73, 284] -> 
             RGBColor[
              0.7372674167293061, 0.7928801562358141, 0.9445072226070215], 
             UndirectedEdge[143, 234] -> 
             RGBColor[
              0.5029994300681095, 0.6035775522609773, 0.9552757104270356], 
             UndirectedEdge[288, 374] -> 
             RGBColor[
              0.8265739926339477, 0.8643878105437455, 0.9335615315474863], 
             UndirectedEdge[254, 344] -> 
             RGBColor[
              0.4921221354647801, 0.5985659452766898, 0.9531608036880193], 
             UndirectedEdge[6, 102] -> 
             RGBColor[
              0.4952760344852135, 0.5977816221523833, 0.9544053318139789], 
             UndirectedEdge[205, 276] -> 
             RGBColor[
              0.8406751452478181, 0.8756644904506992, 0.9474589279316814], 
             UndirectedEdge[101, 244] -> 
             RGBColor[
              0.7893708942812114, 0.8313786215763979, 0.7507612001280666], 
             UndirectedEdge[58, 80] -> 
             RGBColor[
              0.7050405290100206, 0.7690019233255359, 0.9715776103007021], 
             UndirectedEdge[23, 292] -> 
             RGBColor[
              0.9131608739543846, 0.932826044625336, 0.9649638504642108], 
             UndirectedEdge[101, 397] -> 
             RGBColor[
              0.5591266431519342, 0.652963223135794, 0.9584356439787511], 
             UndirectedEdge[105, 168] -> 
             RGBColor[
              0.48296585134074294`, 0.5908352301199331, 0.9525221133326021], 
             UndirectedEdge[166, 340] -> 
             RGBColor[
              0.8207891651706807, 0.8603457871456579, 0.9826608530437232], 
             UndirectedEdge[138, 317] -> 
             RGBColor[
              0.7619011325663517, 0.4984472761831411, 0.5735224423298031], 
             UndirectedEdge[71, 120] -> 
             RGBColor[
              0.7185213115049724, 0.7791861929373753, 0.9733733684848351], 
             UndirectedEdge[231, 290] -> 
             RGBColor[
              0.5099226699339707, 0.6039229353706272, 0.9570182892836677], 
             UndirectedEdge[13, 224] -> 
             RGBColor[
              0.6965217773578225, 0.7628337295903436, 0.970395767762507], 
             UndirectedEdge[40, 159] -> 
             RGBColor[
              0.830446413476968, 0.8676394445118859, 0.9836899143373399], 
             UndirectedEdge[20, 265] -> 
             RGBColor[
              0.5967522119736537, 0.683509354917825, 0.9613976665833968], 
             UndirectedEdge[43, 299] -> 
             RGBColor[
              0.43102615246962894`, 0.5473902116419476, 0.9487863537707315], 
             UndirectedEdge[219, 220] -> 
             RGBColor[
              0.7028739760855195, 0.767783991242577, 0.9710371849982286], 
             UndirectedEdge[56, 290] -> 
             RGBColor[
              0.49263570224160813`, 0.5904182248235329, 0.955295285899991], 
             UndirectedEdge[64, 157] -> 
             RGBColor[
              0.6942507124202357, 0.7586140816982982, 0.964944854043007], 
             UndirectedEdge[13, 340] -> 
             RGBColor[
              0.7566945822007318, 0.8102609680587195, 0.9762818323066222], 
             UndirectedEdge[16, 188] -> 
             RGBColor[
              0.6843252572780749, 0.7483798082326507, 0.9404163435338995], 
             UndirectedEdge[171, 308] -> 
             RGBColor[
              0.8284062356123358, 0.8624052978362933, 0.7265005521957177], 
             UndirectedEdge[288, 379] -> 
             RGBColor[
              0.817977887051653, 0.8580980102858526, 0.953538342630272], 
             UndirectedEdge[81, 353] -> 
             RGBColor[
              0.6867041887091236, 0.7551777984554844, 0.9694079139811757], 
             UndirectedEdge[153, 188] -> 
             RGBColor[
              0.8995107306489393, 0.9218035474266791, 0.9588689004100127], 
             UndirectedEdge[148, 356] -> 
             RGBColor[
              0.8708304586283255, 0.8964693383724138, 0.804569705485908], 
             UndirectedEdge[198, 247] -> 
             RGBColor[
              0.7341728196746198, 0.7862672671667114, 0.7219040140183567], 
             UndirectedEdge[94, 375] -> 
             RGBColor[
              0.5283616018530573, 0.6278694620894056, 0.9560461215970517], 
             UndirectedEdge[298, 307] -> 
             RGBColor[
              0.620128447494978, 0.3374381399943878, 0.556194103286416], 
             UndirectedEdge[9, 142] -> 
             RGBColor[
              0.6081088220794995, 0.691655611681869, 0.9630256931651489], 
             UndirectedEdge[203, 284] -> 
             RGBColor[
              0.8445255838262109, 0.8787891725512085, 0.9537495434317302], 
             UndirectedEdge[370, 400] -> 
             RGBColor[
              0.6254118478276843, 0.7052641134224096, 0.964687911322928], 
             UndirectedEdge[63, 381] -> 
             RGBColor[
              0.913819920493252, 0.931237912710416, 0.8774714374940166], 
             UndirectedEdge[222, 251] -> 
             RGBColor[
              0.6834543314881165, 0.7511008788185087, 0.9701712047500896], 
             UndirectedEdge[103, 234] -> 
             RGBColor[
              0.6266682616030731, 0.7010154514149125, 0.9673824384493133], 
             UndirectedEdge[150, 399] -> 
             RGBColor[
              0.7785269091235798, 0.82691040552178, 0.9785599446199795], 
             UndirectedEdge[321, 338] -> 
             RGBColor[
              0.8258118984349996, 0.8641509523377493, 0.9831929534958446], 
             UndirectedEdge[154, 203] -> 
             RGBColor[
              0.6249436488468332, 0.7052284377219942, 0.964415564773918], 
             UndirectedEdge[225, 390] -> 
             RGBColor[
              0.9635060414658554, 0.9721534525946504, 0.9399419210969453], 
             UndirectedEdge[54, 121] -> 
             RGBColor[
              0.8690523417275884, 0.8969297054454872, 0.9086610518773617], 
             UndirectedEdge[234, 346] -> 
             RGBColor[
              0.40814024610301397`, 0.5270658186560494, 0.9474667249236275], 
             UndirectedEdge[358, 391] -> 
             RGBColor[
              0.9378137927427994, 0.9506435052580546, 0.8916376162993754], 
             UndirectedEdge[74, 357] -> 
             RGBColor[
              0.4875186623686811, 0.5916000369666142, 0.9536904736276521], 
             UndirectedEdge[130, 364] -> 
             RGBColor[
              0.8053442547193533, 0.8485877307324132, 0.9704622938405851], 
             UndirectedEdge[202, 381] -> 
             RGBColor[
              0.9894692697962358, 0.9899132866803911, 0.824184982339929], 
             UndirectedEdge[98, 307] -> 
             RGBColor[
              0.6866714106356873, 0.7516409678653566, 0.9585029546491227], 
             UndirectedEdge[242, 317] -> 
             RGBColor[
              0.9114517355354332, 0.6138742978052755, 0.4776210066967712], 
             UndirectedEdge[9, 279] -> 
             RGBColor[
              0.7268174094570756, 0.7865145513755538, 0.9734060249459708], 
             UndirectedEdge[200, 399] -> 
             RGBColor[
              0.4853756938875294, 0.571346248454448, 0.9566931565099779], 
             UndirectedEdge[275, 306] -> 
             RGBColor[
              0.6173693247384336, 0.6826761052762479, 0.8848386611115159], 
             UndirectedEdge[121, 181] -> 
             RGBColor[
              0.7786631594706546, 0.8251918455779048, 0.900421169821167], 
             UndirectedEdge[239, 271] -> 
             RGBColor[
              0.6949043031728236, 0.7607538978850243, 0.9707926266631277], 
             UndirectedEdge[35, 354] -> 
             RGBColor[
              0.5552536480080973, 0.6498189512015844, 0.9581307476137795], 
             UndirectedEdge[31, 310] -> 
             RGBColor[
              0.7498332463456457, 0.8043203588453123, 0.9761678541074401], 
             UndirectedEdge[146, 154] -> 
             RGBColor[
              0.41049430607523535`, 0.5260940388763077, 0.948026673617898], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.7669603152655569, 0.8182185109486086, 0.9773158032497379], 
             UndirectedEdge[265, 322] -> 
             RGBColor[
              0.7768592050853045, 0.7919837399046057, 0.6495906510090058], 
             UndirectedEdge[115, 284] -> 
             RGBColor[
              0.7403278010177734, 0.7953647140699329, 0.9447481472687665], 
             UndirectedEdge[38, 391] -> 
             RGBColor[
              0.8636200448414808, 0.6206021502747281, 0.5887622129512258], 
             UndirectedEdge[116, 328] -> 
             RGBColor[
              0.5398528182562399, 0.6324665459893805, 0.9589070751051285], 
             UndirectedEdge[92, 278] -> 
             RGBColor[
              0.6803231673367216, 0.7483478167225761, 0.9701676134871229], 
             UndirectedEdge[215, 217] -> 
             RGBColor[
              0.6995138919494762, 0.7614506179696636, 0.9401462190901284], 
             UndirectedEdge[159, 210] -> 
             RGBColor[
              0.7395913220438391, 0.796615781334981, 0.974646793692767], 
             UndirectedEdge[165, 298] -> 
             RGBColor[
              0.6113347883725855, 0.3298215144447301, 0.5556337791030646], 
             UndirectedEdge[83, 254] -> 
             RGBColor[
              0.4826052869292391, 0.5908397389063968, 0.9524116025099367], 
             UndirectedEdge[103, 231] -> 
             RGBColor[
              0.8319444705542789, 0.8694674785408358, 0.9836646825737088], 
             UndirectedEdge[245, 319] -> 
             RGBColor[
              0.658196301658815, 0.7306421035150981, 0.9681288982971772], 
             UndirectedEdge[58, 263] -> 
             RGBColor[
              0.7729517463655887, 0.8229809517810593, 0.9776419872668267], 
             UndirectedEdge[206, 258] -> 
             RGBColor[
              0.9096898743611189, 0.9273313667890764, 0.8460873191684384], 
             UndirectedEdge[213, 391] -> 
             RGBColor[
              0.7088661827215769, 0.7713416812418388, 0.9726202369806258], 
             UndirectedEdge[78, 370] -> 
             RGBColor[
              0.6254118478276843, 0.7052641134224096, 0.964687911322928], 
             UndirectedEdge[101, 270] -> 
             RGBColor[
              0.7403341402054776, 0.7968082600508768, 0.9751901946099313], 
             UndirectedEdge[135, 377] -> 
             RGBColor[
              0.9248182355412242, 0.9405313930104418, 0.9012623023542263], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.8554654702928179, 0.8876306723587526, 0.9860651854767626], 
             UndirectedEdge[19, 83] -> 
             RGBColor[
              0.5664527230504901, 0.6589108648335802, 0.9590123798246803], 
             UndirectedEdge[100, 112] -> 
             RGBColor[
              0.7177560272032841, 0.7787641495290236, 0.973083790713865], 
             UndirectedEdge[10, 296] -> 
             RGBColor[
              0.4446425901445237, 0.5592842326855031, 0.9496263101935039], 
             UndirectedEdge[85, 369] -> 
             RGBColor[
              0.8753056883221781, 0.8994388081440463, 0.7628366806213454], 
             UndirectedEdge[79, 246] -> 
             RGBColor[
              0.8780750814356211, 0.9032060084727553, 0.8745396414789812], 
             UndirectedEdge[227, 280] -> 
             RGBColor[
              0.7628080963505168, 0.8150491769426914, 0.9769645522529075], 
             UndirectedEdge[112, 326] -> 
             RGBColor[
              0.5930808826891165, 0.6805288044131385, 0.9611086460935957], 
             UndirectedEdge[34, 308] -> 
             RGBColor[
              0.9638525987006723, 0.883081709083462, 0.37607689225526547`], 
             UndirectedEdge[29, 226] -> 
             RGBColor[
              0.5181234588071078, 0.6196749909122594, 0.9552077231075131], 
             UndirectedEdge[204, 345] -> 
             RGBColor[
              0.961951952723805, 0.9587913714331986, 0.6949874447298742], 
             UndirectedEdge[54, 265] -> 
             RGBColor[
              0.6665912922844632, 0.7385637162540011, 0.9680197693368887], 
             UndirectedEdge[22, 100] -> 
             RGBColor[
              0.5921055850369981, 0.6733587038497827, 0.9641306615037565], 
             UndirectedEdge[126, 336] -> 
             RGBColor[
              0.6839992224964089, 0.7521306236021753, 0.9697769128468339], 
             UndirectedEdge[82, 157] -> 
             RGBColor[
              0.8161171435257788, 0.8570712300120472, 0.9749597917338169], 
             UndirectedEdge[344, 349] -> 
             RGBColor[
              0.47257030815634427`, 0.5820644928578993, 0.951795240519338], 
             UndirectedEdge[343, 349] -> 
             RGBColor[
              0.7117252968695706, 0.7675218677869067, 0.7290727420245118], 
             UndirectedEdge[2, 66] -> 
             RGBColor[
              0.45802077672306674`, 0.5636855096656265, 0.9518584894902589], 
             UndirectedEdge[211, 387] -> 
             RGBColor[
              0.7662944385417998, 0.8176842593483813, 0.977463781916199], 
             UndirectedEdge[250, 265] -> 
             RGBColor[
              0.6575769085945009, 0.7315216112035491, 0.9671212998148784], 
             UndirectedEdge[217, 306] -> 
             RGBColor[
              0.6090009819757506, 0.6772297013424327, 0.9345920317709079], 
             UndirectedEdge[374, 375] -> 
             RGBColor[
              0.7963235485633008, 0.8402253974128591, 0.9309091805623562], 
             UndirectedEdge[38, 247] -> 
             RGBColor[
              0.6590535945981901, 0.4577127361596372, 0.5702614447035302], 
             UndirectedEdge[204, 310] -> 
             RGBColor[
              0.7572521128754806, 0.81017847971329, 0.9748825378599872], 
             UndirectedEdge[226, 266] -> 
             RGBColor[
              0.7189965194538093, 0.7793679552710614, 0.9736456167061792], 
             UndirectedEdge[319, 334] -> 
             RGBColor[
              0.7646872759473071, 0.8161315546288233, 0.9771718416528579], 
             UndirectedEdge[73, 206] -> 
             RGBColor[
              0.664179610480764, 0.7354979501856713, 0.9686018518500026], 
             UndirectedEdge[200, 255] -> 
             RGBColor[
              0.40142799049925215`, 0.5054833401558457, 0.9485190606964091], 
             UndirectedEdge[296, 383] -> 
             RGBColor[
              0.5013998290521668, 0.6053623161152026, 0.9540944479489302], 
             UndirectedEdge[235, 281] -> 
             RGBColor[
              0.9201681507366926, 0.939123640447966, 0.990254719372744], 
             UndirectedEdge[174, 272] -> 
             RGBColor[
              0.5927999981197926, 0.6803007696660556, 0.9610865338313844], 
             UndirectedEdge[9, 131] -> 
             RGBColor[
              0.7914941714737801, 0.8374492225062027, 0.9797439455673946], 
             UndirectedEdge[228, 361] -> 
             RGBColor[
              0.7797535581207574, 0.8263586816096945, 0.9122790485446827], 
             UndirectedEdge[149, 199] -> 
             RGBColor[
              0.735098336731268, 0.6325234496756138, 0.5951701559123966], 
             UndirectedEdge[102, 400] -> 
             RGBColor[
              0.53886778876819, 0.6318358319078476, 0.9587501504928011], 
             UndirectedEdge[45, 350] -> 
             RGBColor[
              0.6218472083525233, 0.6965691433403853, 0.9671997960952028], 
             UndirectedEdge[369, 392] -> 
             RGBColor[
              0.9196005753933416, 0.9342490314705957, 0.7671967236364419], 
             UndirectedEdge[82, 151] -> 
             RGBColor[
              0.797169267656944, 0.8421669620579264, 0.9802341386459082], 
             UndirectedEdge[260, 342] -> 
             RGBColor[
              0.7607252073883004, 0.8133557126104545, 0.9768034354652355], 
             UndirectedEdge[296, 380] -> 
             RGBColor[
              0.7097864398383498, 0.7658892032037151, 0.732938526747751], 
             UndirectedEdge[105, 148] -> 
             RGBColor[
              0.7183940753511489, 0.774024087983112, 0.7915529686038908], 
             UndirectedEdge[94, 288] -> 
             RGBColor[
              0.5586120459237043, 0.652031875220292, 0.9586984725821819], 
             UndirectedEdge[195, 258] -> 
             RGBColor[
              0.8351881505276788, 0.8690954094739736, 0.8386708771593867], 
             UndirectedEdge[339, 374] -> 
             RGBColor[
              0.7774107038647045, 0.8248710980725944, 0.9294202921476498], 
             UndirectedEdge[199, 367] -> 
             RGBColor[
              0.7632986487496163, 0.8147935408587319, 0.9674787170770631], 
             UndirectedEdge[36, 298] -> 
             RGBColor[
              0.8906046052551704, 0.5533584793198707, 0.5551133170256342], 
             UndirectedEdge[147, 347] -> 
             RGBColor[
              0.5664562305632517, 0.6535895925661916, 0.9614146410170956], 
             UndirectedEdge[38, 205] -> 
             RGBColor[
              0.7735949463944874, 0.549753502448501, 0.5799274391399718], 
             UndirectedEdge[16, 73] -> 
             RGBColor[
              0.4509551699790699, 0.5636378853707001, 0.9503363400395856], 
             UndirectedEdge[108, 290] -> 
             RGBColor[
              0.36412698260261667`, 0.48698994649387695`, 0.9445260914003291],
              UndirectedEdge[225, 296] -> 
             RGBColor[
              0.6840703827280378, 0.7498988400002913, 0.965791344326168], 
             UndirectedEdge[24, 144] -> 
             RGBColor[
              0.7971063950795585, 0.8408125979414558, 0.9289496086408371], 
             UndirectedEdge[209, 319] -> 
             RGBColor[
              0.6418212100077297, 0.7173480664232748, 0.9668397910984665], 
             UndirectedEdge[80, 192] -> 
             RGBColor[
              0.8942872490600303, 0.9166851972898173, 0.9130711877699828], 
             UndirectedEdge[42, 221] -> 
             RGBColor[
              0.693548183220948, 0.7487575371090414, 0.6820166332160961], 
             UndirectedEdge[22, 365] -> 
             RGBColor[
              0.49055240283458246`, 0.5937335379772959, 0.9540860245879412], 
             UndirectedEdge[80, 201] -> 
             RGBColor[
              0.7416584626724468, 0.7981084949435837, 0.9748852424329515], 
             UndirectedEdge[39, 375] -> 
             RGBColor[
              0.7226989399810355, 0.7829096014988962, 0.9733203261666143], 
             UndirectedEdge[15, 326] -> 
             RGBColor[
              0.797680375555476, 0.8405707895048449, 0.8994063268745114], 
             UndirectedEdge[86, 95] -> 
             RGBColor[
              0.6946312592904007, 0.7606834405606988, 0.9706677471783263], 
             UndirectedEdge[59, 194] -> 
             RGBColor[
              0.9618533818101026, 0.9703962249322101, 0.9192986836339425], 
             UndirectedEdge[296, 324] -> 
             RGBColor[
              0.4820076125698553, 0.589618841165465, 0.9525678216314131], 
             UndirectedEdge[169, 245] -> 
             RGBColor[
              0.6419382050754583, 0.7179083791686139, 0.9665171408411349], 
             UndirectedEdge[258, 284] -> 
             RGBColor[
              0.9827776806096611, 0.9847135728392191, 0.8219926899254573], 
             UndirectedEdge[33, 152] -> 
             RGBColor[
              0.7703167999088556, 0.8211196479303333, 0.9775763014377753], 
             UndirectedEdge[246, 349] -> 
             RGBColor[
              0.7113959433265851, 0.7691162060141143, 0.8603225636373668], 
             UndirectedEdge[27, 395] -> 
             RGBColor[
              0.9206329503508108, 0.9393438743367379, 0.9850851201828291], 
             UndirectedEdge[185, 340] -> 
             RGBColor[
              0.7087860482127817, 0.7713666619124406, 0.9725102970163483], 
             UndirectedEdge[223, 321] -> 
             RGBColor[
              0.6085015982477594, 0.6898858150490494, 0.9641451007086124], 
             UndirectedEdge[274, 373] -> 
             RGBColor[
              0.6028428271853931, 0.6836125765123456, 0.9643757364791037], 
             UndirectedEdge[156, 214] -> 
             RGBColor[
              0.8724347924293885, 0.9007265359189425, 0.9633385010038115], 
             UndirectedEdge[205, 221] -> 
             RGBColor[
              0.8473997621083368, 0.8742518639261626, 0.6943518359688299], 
             UndirectedEdge[97, 105] -> 
             RGBColor[
              0.6986376165483505, 0.7617347572866414, 0.9553141861507399], 
             UndirectedEdge[130, 158] -> 
             RGBColor[
              0.8243915224844673, 0.863467601075117, 0.9723607474845744], 
             UndirectedEdge[108, 143] -> 
             RGBColor[
              0.5624799516879613, 0.6550965905101505, 0.9590657566680925], 
             UndirectedEdge[176, 399] -> 
             RGBColor[
              0.7908976116820619, 0.8365744923812879, 0.9797929406402208], 
             UndirectedEdge[150, 189] -> 
             RGBColor[
              0.8163184244330102, 0.8568167303437877, 0.9822249321009003], 
             UndirectedEdge[253, 386] -> 
             RGBColor[
              0.7689010959648074, 0.8195336132138167, 0.9775625947180214], 
             UndirectedEdge[46, 59] -> 
             RGBColor[
              0.9604261337318531, 0.9692581760562311, 0.9191625514381196], 
             UndirectedEdge[186, 241] -> 
             RGBColor[
              0.871656281492394, 0.9003336805086632, 0.9741605340081414], 
             UndirectedEdge[39, 93] -> 
             RGBColor[
              0.8669078728278314, 0.8967128224783161, 0.9871676408797544], 
             UndirectedEdge[214, 264] -> 
             RGBColor[
              0.7759918279044351, 0.8245692103841247, 0.9542834259386441], 
             UndirectedEdge[234, 290] -> 
             RGBColor[
              0.30464646098276493`, 0.4354709082447039, 0.9407360451592722], 
             UndirectedEdge[148, 170] -> 
             RGBColor[
              0.9663658911385626, 0.8918063222819972, 0.4514611644283634], 
             UndirectedEdge[50, 362] -> 
             RGBColor[
              0.7122616313339546, 0.7751434668777605, 0.9719552410141383], 
             UndirectedEdge[271, 326] -> 
             RGBColor[
              0.7041337190668135, 0.7682467534882131, 0.971519200090767], 
             UndirectedEdge[61, 352] -> 
             RGBColor[
              0.40649593476249, 0.5258221366636251, 0.9473120677144622], 
             UndirectedEdge[256, 333] -> 
             RGBColor[
              0.6339162977972189, 0.6966697346218178, 0.6945453210561114], 
             UndirectedEdge[100, 394] -> 
             RGBColor[
              0.6934072627791177, 0.7589967256701482, 0.9711669667859316], 
             UndirectedEdge[1, 114] -> 
             RGBColor[
              0.8447835344214032, 0.8747376452523703, 0.697785050309151], 
             UndirectedEdge[218, 269] -> 
             RGBColor[
              0.6930992331673433, 0.7402232465187075, 0.6695734307110919], 
             UndirectedEdge[182, 253] -> 
             RGBColor[
              0.5637652039288812, 0.6551403091603623, 0.9596003158422308], 
             UndirectedEdge[57, 354] -> 
             RGBColor[
              0.5616187010153105, 0.6549863879752104, 0.9586318279024648], 
             UndirectedEdge[40, 192] -> 
             RGBColor[
              0.9069923955566828, 0.9266575295207669, 0.9143250522560455], 
             UndirectedEdge[262, 314] -> 
             RGBColor[
              0.5080291124601002, 0.611479945802638, 0.9544130591862676], 
             UndirectedEdge[244, 253] -> 
             RGBColor[
              0.8468478725136497, 0.8771560419177397, 0.7558910639879235], 
             UndirectedEdge[277, 330] -> 
             RGBColor[
              0.9747710989462838, 0.9807049074194482, 0.9275901281194265], 
             UndirectedEdge[304, 329] -> 
             RGBColor[
              0.6474864776337768, 0.7175306906359802, 0.9535213125400164], 
             UndirectedEdge[103, 223] -> 
             RGBColor[
              0.6724543371570268, 0.7406730487846773, 0.9702998866965743], 
             UndirectedEdge[92, 337] -> 
             RGBColor[
              0.8091255065710468, 0.8511350791516404, 0.9815245919532294], 
             UndirectedEdge[226, 341] -> 
             RGBColor[
              0.6830106706023282, 0.7506738162067357, 0.9702132543177784], 
             UndirectedEdge[193, 260] -> 
             RGBColor[
              0.7612530321261373, 0.8137765857289847, 0.976853779859925], 
             UndirectedEdge[9, 214] -> 
             RGBColor[
              0.8376451193039858, 0.873548578862069, 0.9598709915146509], 
             UndirectedEdge[8, 157] -> 
             RGBColor[
              0.6543396061595019, 0.7240450874457781, 0.9624017536440785], 
             UndirectedEdge[103, 342] -> 
             RGBColor[
              0.909368152072378, 0.930569496594341, 0.9912175402188379], 
             UndirectedEdge[165, 314] -> 
             RGBColor[
              0.4771238489696564, 0.5850872326326029, 0.9523399483721946], 
             UndirectedEdge[115, 392] -> 
             RGBColor[
              0.677884829378919, 0.7464704101912172, 0.9698580903395758], 
             UndirectedEdge[104, 233] -> 
             RGBColor[
              0.6470778913009669, 0.7224761450116924, 0.9666515984260748], 
             UndirectedEdge[67, 139] -> 
             RGBColor[
              0.7853816884425546, 0.8306622830572659, 0.901620319071026], 
             UndirectedEdge[116, 364] -> 
             RGBColor[
              0.4983132607448245, 0.6000155279491326, 0.9547668002216263], 
             UndirectedEdge[74, 220] -> 
             RGBColor[
              0.48754398114089986`, 0.5916205918864992, 0.9536924668141469], 
             UndirectedEdge[100, 168] -> 
             RGBColor[
              0.6897767972364396, 0.7560493501919933, 0.9708811632395785], 
             UndirectedEdge[129, 308] -> 
             RGBColor[
              0.9789433939496222, 0.9804256352050792, 0.715151029035024], 
             UndirectedEdge[26, 185] -> 
             RGBColor[
              0.6616206824151077, 0.7341009336864008, 0.9679206924348331], 
             UndirectedEdge[197, 215] -> 
             RGBColor[
              0.6246689467772282, 0.7027135482851845, 0.9656761172148907], 
             UndirectedEdge[178, 240] -> 
             RGBColor[
              0.6387119609158518, 0.7154879800437262, 0.9661272307627544], 
             UndirectedEdge[52, 223] -> 
             RGBColor[
              0.5153835237467852, 0.6166171412977313, 0.955222309244548], 
             UndirectedEdge[192, 243] -> 
             RGBColor[
              0.8853819989819204, 0.9097283482463905, 0.9121835956664902], 
             UndirectedEdge[124, 252] -> 
             RGBColor[
              0.7501512693188895, 0.8042211112289386, 0.9691581716292561], 
             UndirectedEdge[194, 396] -> 
             RGBColor[
              0.9307370347796182, 0.9476084636222255, 0.9932557233276813], 
             UndirectedEdge[269, 279] -> 
             RGBColor[
              0.5717025898502659, 0.6602712105968565, 0.9608442493043303], 
             UndirectedEdge[57, 208] -> 
             RGBColor[
              0.7956109910606721, 0.8379750804774891, 0.86096400499448], 
             UndirectedEdge[169, 304] -> 
             RGBColor[
              0.5666307873287391, 0.6537407848629788, 0.961425763619838], 
             UndirectedEdge[209, 280] -> 
             RGBColor[
              0.6778554297879028, 0.7460807751531457, 0.9702767671492272], 
             UndirectedEdge[226, 399] -> 
             RGBColor[
              0.6590461939324773, 0.7317927966709633, 0.9678671021258438], 
             UndirectedEdge[206, 392] -> 
             RGBColor[
              0.8349151166881648, 0.8712026671527769, 0.9841161432388824], 
             UndirectedEdge[48, 343] -> 
             RGBColor[
              0.9366749910007026, 0.9476187562970801, 0.7489687985047893], 
             UndirectedEdge[159, 263] -> 
             RGBColor[
              0.8856524843358838, 0.91164614073646, 0.9885004268174018], 
             UndirectedEdge[261, 295] -> 
             RGBColor[
              0.8051379768345261, 0.8477660385968283, 0.9811945433120233], 
             UndirectedEdge[33, 204] -> 
             RGBColor[
              0.7907467889639312, 0.8373524847224255, 0.9775319976719461], 
             UndirectedEdge[64, 151] -> 
             RGBColor[
              0.6753028365514008, 0.7437098137441774, 0.9702192009550984], 
             UndirectedEdge[210, 263] -> 
             RGBColor[
              0.7901468548080808, 0.8369142647183556, 0.9790137336977744], 
             UndirectedEdge[19, 303] -> 
             RGBColor[
              0.5915055885879954, 0.6792499096956578, 0.960984633171463], 
             UndirectedEdge[248, 315] -> 
             RGBColor[
              0.8916497430985897, 0.9140076045667185, 0.8848239674853178], 
             UndirectedEdge[236, 351] -> 
             RGBColor[
              0.5964394584697186, 0.6772793695411634, 0.9643299869739269], 
             UndirectedEdge[53, 386] -> 
             RGBColor[0.9110951870433812, 0.930633461140971, 0.945307206196], 
             UndirectedEdge[93, 301] -> 
             RGBColor[
              0.8802408455269354, 0.907344172994679, 0.9884393517182801], 
             UndirectedEdge[37, 159] -> 
             RGBColor[
              0.876449962552587, 0.9043214258117106, 0.9880777739160256], 
             UndirectedEdge[148, 326] -> 
             RGBColor[
              0.8005298767326778, 0.8410028629392868, 0.7979368738905981], 
             UndirectedEdge[13, 357] -> 
             RGBColor[
              0.6410472901851887, 0.7194700948804824, 0.9648847373984266], 
             UndirectedEdge[162, 231] -> 
             RGBColor[
              0.8229305786049677, 0.7280937561013716, 0.6083508718836284], 
             UndirectedEdge[33, 84] -> 
             RGBColor[
              0.5852761238190183, 0.6741740676045813, 0.9605068631008026], 
             UndirectedEdge[199, 293] -> 
             RGBColor[
              0.7091736478878252, 0.48361535121093624`, 0.5723166323574003], 
             UndirectedEdge[96, 167] -> 
             RGBColor[
              0.7242807012370193, 0.7845328556343492, 0.9731531895774816], 
             UndirectedEdge[131, 307] -> 
             RGBColor[
              0.6467431388638691, 0.7201824731251388, 0.9678425412688596], 
             UndirectedEdge[174, 291] -> 
             RGBColor[
              0.7999699680206451, 0.8401780237646181, 0.7675447056319449], 
             UndirectedEdge[207, 250] -> 
             RGBColor[
              0.7360845623789714, 0.7937541216711095, 0.9743296881427574], 
             UndirectedEdge[364, 387] -> 
             RGBColor[
              0.6363709598752612, 0.7153536389079436, 0.9647353855407321], 
             UndirectedEdge[103, 346] -> 
             RGBColor[
              0.7037578681758594, 0.7669201123736579, 0.972533931465293], 
             UndirectedEdge[31, 106] -> 
             RGBColor[
              0.892818401397303, 0.9173731746370509, 0.9896390102253125], 
             UndirectedEdge[128, 316] -> 
             RGBColor[
              0.8789504067914491, 0.9040588937009488, 0.8822934372479561], 
             UndirectedEdge[185, 289] -> 
             RGBColor[
              0.5297446934121726, 0.6291096326953038, 0.9561225892656087], 
             UndirectedEdge[20, 172] -> 
             RGBColor[
              0.797632035003434, 0.8412214663517279, 0.9282439628757768], 
             UndirectedEdge[70, 234] -> 
             RGBColor[
              0.48730806702983326`, 0.5913193401966998, 0.9537117420035048], 
             UndirectedEdge[119, 383] -> 
             RGBColor[
              0.6061967112182766, 0.6911768248744523, 0.9621411721602742], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.6351265556655185, 0.7137598158120535, 0.965036404436017], 
             UndirectedEdge[20, 54] -> 
             RGBColor[
              0.6798493689422905, 0.7493272201543724, 0.9690634936973279], 
             UndirectedEdge[229, 334] -> 
             RGBColor[
              0.6452558166328942, 0.7219220470652916, 0.9658756317871289], 
             UndirectedEdge[63, 142] -> 
             RGBColor[
              0.6693641905894222, 0.7396297413617812, 0.9690989540515427], 
             UndirectedEdge[230, 358] -> 
             RGBColor[
              0.6185136074201005, 0.6831492955718406, 0.8658749357676432], 
             UndirectedEdge[119, 296] -> 
             RGBColor[
              0.5310203979179057, 0.6294096283118301, 0.9564262876337601], 
             UndirectedEdge[218, 262] -> 
             RGBColor[
              0.7255746245322935, 0.7679759255367185, 0.6717465886849188], 
             UndirectedEdge[100, 170] -> 
             RGBColor[
              0.8971539641172561, 0.8405777885214458, 0.6276757254704259], 
             UndirectedEdge[97, 357] -> 
             RGBColor[
              0.7977651341680263, 0.842508172953037, 0.9630357415824216], 
             UndirectedEdge[375, 399] -> 
             RGBColor[
              0.6997750985190732, 0.7648583562306039, 0.9710734306897941], 
             UndirectedEdge[199, 252] -> 
             RGBColor[
              0.7617663194290667, 0.813650732160425, 0.9700725509212598], 
             UndirectedEdge[175, 345] -> 
             RGBColor[
              0.7953457078467694, 0.8271648415109981, 0.6810218596872804], 
             UndirectedEdge[176, 186] -> 
             RGBColor[
              0.8703295661277477, 0.8992972403823913, 0.9740282994194536], 
             UndirectedEdge[309, 371] -> 
             RGBColor[
              0.5019698617319719, 0.6040580014297552, 0.9546293231410496], 
             UndirectedEdge[326, 354] -> 
             RGBColor[
              0.5659869682238219, 0.658532744083275, 0.9589757138986088], 
             UndirectedEdge[38, 289] -> 
             RGBColor[
              0.6783572783923253, 0.4733843362847609, 0.5717811014035281], 
             UndirectedEdge[120, 237] -> 
             RGBColor[
              0.6903915398058467, 0.7563491770402513, 0.971158889813931], 
             UndirectedEdge[275, 384] -> 
             RGBColor[
              0.7010810103706253, 0.761006143218317, 0.8899594804297803], 
             UndirectedEdge[216, 220] -> 
             RGBColor[
              0.7936667636374835, 0.839453287142844, 0.9700180651280711], 
             UndirectedEdge[50, 276] -> 
             RGBColor[
              0.8670215959509405, 0.8962465379804201, 0.9500848959161886], 
             UndirectedEdge[143, 321] -> 
             RGBColor[
              0.7346643132316875, 0.792644612242958, 0.9741881309807392], 
             UndirectedEdge[225, 316] -> 
             RGBColor[
              0.9668074411502885, 0.9735186662062654, 0.8852291845773796], 
             UndirectedEdge[40, 332] -> 
             RGBColor[0.7294292442259906, 0.7884595029816, 0.973751248114672],
              UndirectedEdge[254, 343] -> 
             RGBColor[
              0.7312771241780065, 0.7840233202056973, 0.7304383051931931], 
             UndirectedEdge[37, 167] -> 
             RGBColor[
              0.7862700431121541, 0.8337500349907556, 0.9791218978063168], 
             UndirectedEdge[26, 204] -> 
             RGBColor[
              0.8577590867538296, 0.8897030010682208, 0.9842111572501157], 
             UndirectedEdge[141, 189] -> 
             RGBColor[
              0.8391344642598269, 0.874640794064822, 0.9844990217228227], 
             UndirectedEdge[55, 210] -> 
             RGBColor[
              0.8190982252830891, 0.8568582833355325, 0.8562118053796439], 
             UndirectedEdge[41, 312] -> 
             RGBColor[
              0.5452353436969977, 0.6411227963634507, 0.9575595196996671], 
             UndirectedEdge[102, 247] -> 
             RGBColor[
              0.4059384226381245, 0.5254302090673593, 0.9472514106333334], 
             UndirectedEdge[30, 400] -> 
             RGBColor[
              0.8480460713367549, 0.881812820628155, 0.9679407300363982], 
             UndirectedEdge[57, 195] -> 
             RGBColor[
              0.636586552595889, 0.7153445610989326, 0.9648782318565271], 
             UndirectedEdge[301, 324] -> 
             RGBColor[
              0.7010648627425529, 0.765153125628278, 0.9718393027455288], 
             UndirectedEdge[290, 331] -> 
             RGBColor[
              0.4202964437327328, 0.5326806197092359, 0.9489231522392317], 
             UndirectedEdge[49, 347] -> 
             RGBColor[
              0.6493781066053251, 0.7239484263943043, 0.9671028371428234], 
             UndirectedEdge[92, 258] -> 
             RGBColor[
              0.9273928005309029, 0.9414471995837324, 0.8477758400701012], 
             UndirectedEdge[234, 313] -> 
             RGBColor[
              0.40513349050924863`, 0.5246247990122348, 0.9472300221091776], 
             UndirectedEdge[376, 377] -> 
             RGBColor[
              0.9087693678667337, 0.9277344615617109, 0.8997315470284402], 
             UndirectedEdge[223, 272] -> 
             RGBColor[
              0.5010708754095823, 0.6049974886001303, 0.9540955651384849], 
             UndirectedEdge[213, 302] -> 
             RGBColor[
              0.4562781747052182, 0.5674533898059733, 0.9508951821287097], 
             UndirectedEdge[121, 158] -> 
             RGBColor[
              0.8448796303969408, 0.8780457996345747, 0.9062517419187535], 
             UndirectedEdge[240, 248] -> 
             RGBColor[
              0.8850452429061865, 0.9088481188203524, 0.8841656926287025], 
             UndirectedEdge[18, 132] -> 
             RGBColor[
              0.7394196529801351, 0.7943197954190552, 0.9364252425290303], 
             UndirectedEdge[59, 79] -> 
             RGBColor[
              0.8758764264880853, 0.9022968081490945, 0.9109770438962583], 
             UndirectedEdge[109, 207] -> 
             RGBColor[
              0.7674449243710754, 0.8182530748069199, 0.9774553959468855], 
             UndirectedEdge[190, 365] -> 
             RGBColor[
              0.7236335678390456, 0.7840273101054561, 0.9730886893681772], 
             UndirectedEdge[78, 391] -> 
             RGBColor[
              0.8127265608884511, 0.8541477901108243, 0.9818305596244197], 
             UndirectedEdge[159, 236] -> 
             RGBColor[
              0.843118592040734, 0.8777438957215092, 0.9848985980413394], 
             UndirectedEdge[95, 334] -> 
             RGBColor[
              0.6514222054479455, 0.7269281992980007, 0.9663610725028762], 
             UndirectedEdge[20, 147] -> 
             RGBColor[
              0.4756999297650586, 0.5821945396085079, 0.9527077052079604], 
             UndirectedEdge[229, 388] -> 
             RGBColor[
              0.6583300660483289, 0.732135750076605, 0.967178750783052], 
             UndirectedEdge[15, 271] -> 
             RGBColor[
              0.8951712894250857, 0.9172785589302078, 0.9087492366528871], 
             UndirectedEdge[53, 151] -> 
             RGBColor[
              0.9451211431525772, 0.9577648349324699, 0.9485526322650246], 
             UndirectedEdge[178, 309] -> 
             RGBColor[
              0.4300900626736427, 0.5457070307934685, 0.9489677500609728], 
             UndirectedEdge[309, 386] -> 
             RGBColor[
              0.5994864250073515, 0.6803816479043721, 0.9643109240196136], 
             UndirectedEdge[199, 299] -> 
             RGBColor[
              0.5232614069306796, 0.6238462086609005, 0.9556122012047248], 
             UndirectedEdge[33, 90] -> 
             RGBColor[
              0.5115563406919951, 0.6123219760891934, 0.9552568205593513], 
             UndirectedEdge[191, 216] -> 
             RGBColor[
              0.9666659029359648, 0.9742475234396142, 0.9228356341859442], 
             UndirectedEdge[188, 203] -> 
             RGBColor[
              0.8447171932789608, 0.8789320745673377, 0.9534251986079737], 
             UndirectedEdge[87, 263] -> 
             RGBColor[
              0.8991226269415904, 0.9223868668129698, 0.9897852210440724], 
             UndirectedEdge[25, 76] -> 
             RGBColor[
              0.6769653474432848, 0.7455752044826262, 0.9699568895331828], 
             UndirectedEdge[329, 334] -> 
             RGBColor[
              0.8292848696689881, 0.8671877360553405, 0.9676556331169941], 
             UndirectedEdge[42, 376] -> 
             RGBColor[
              0.6120943447009879, 0.6916490998859651, 0.9649544977237396], 
             UndirectedEdge[54, 130] -> 
             RGBColor[
              0.848564233815115, 0.8823515068860295, 0.9747700574431826], 
             UndirectedEdge[90, 256] -> 
             RGBColor[
              0.327324757775021, 0.4548233989046435, 0.9421917158549502], 
             UndirectedEdge[160, 302] -> 
             RGBColor[
              0.6710865620193084, 0.6948292616719529, 0.628044272783759], 
             UndirectedEdge[299, 367] -> 
             RGBColor[
              0.7067872475792729, 0.7689150395790363, 0.9630299325688504], 
             UndirectedEdge[16, 96] -> 
             RGBColor[
              0.5958228454291754, 0.6789277354544652, 0.9633272251761034], 
             UndirectedEdge[5, 223] -> 
             RGBColor[
              0.6794572822400632, 0.7462417210988064, 0.9704378584539287], 
             UndirectedEdge[40, 228] -> 
             RGBColor[
              0.6991503523622113, 0.7638777345180501, 0.9713675828319197], 
             UndirectedEdge[154, 222] -> 
             RGBColor[
              0.5338398605372023, 0.6324342738525797, 0.9564449758227827], 
             UndirectedEdge[85, 188] -> 
             RGBColor[
              0.8638996453182934, 0.8939175518924996, 0.9553371261570481], 
             UndirectedEdge[281, 384] -> 
             RGBColor[
              0.6577974318478118, 0.728661536022157, 0.9690512805433349], 
             UndirectedEdge[249, 334] -> 
             RGBColor[
              0.6155070544075496, 0.697770661724291, 0.963533700251443], 
             UndirectedEdge[203, 243] -> 
             RGBColor[
              0.7505901776548148, 0.8050860185713578, 0.9757754723107718], 
             UndirectedEdge[49, 147] -> 
             RGBColor[
              0.4243114469407097, 0.5404750542269321, 0.9486622155978126], 
             UndirectedEdge[99, 232] -> 
             RGBColor[
              0.601452210417319, 0.6870883638987777, 0.9619294744295064], 
             UndirectedEdge[84, 389] -> 
             RGBColor[
              0.47927927569541817`, 0.5875490727905104, 0.9523129126790992], 
             UndirectedEdge[76, 242] -> 
             RGBColor[
              0.9291774580972267, 0.9435695624410125, 0.8826691986331308], 
             UndirectedEdge[129, 397] -> 
             RGBColor[
              0.7489525120335889, 0.8025521678920474, 0.9504031481337928], 
             UndirectedEdge[177, 390] -> 
             RGBColor[
              0.7468738315789034, 0.8000453262422289, 0.9255714387371254], 
             UndirectedEdge[138, 144] -> 
             RGBColor[
              0.8391520374687734, 0.8741692441170905, 0.932791450414513], 
             UndirectedEdge[184, 325] -> 
             RGBColor[
              0.8469318928887002, 0.8812543116222036, 0.9836177866862814], 
             UndirectedEdge[69, 140] -> 
             RGBColor[
              0.8978238134047014, 0.918023682283202, 0.8446588662551227], 
             UndirectedEdge[247, 391] -> 
             RGBColor[
              0.6797971947583856, 0.7477421672703359, 0.970331819764952], 
             UndirectedEdge[14, 391] -> 
             RGBColor[
              0.6296228148429417, 0.7048786236138223, 0.966970357237485], 
             UndirectedEdge[229, 240] -> 
             RGBColor[
              0.6818603702829462, 0.7505178025816238, 0.9695240316059636], 
             UndirectedEdge[166, 400] -> 
             RGBColor[
              0.7553734927060018, 0.8088227806438858, 0.9762522284524535], 
             UndirectedEdge[281, 386] -> 
             RGBColor[
              0.8700401443869725, 0.8992104107963288, 0.987466399737277], 
             UndirectedEdge[150, 255] -> 
             RGBColor[
              0.6945792057353026, 0.7610474972231775, 0.9703858488064107], 
             UndirectedEdge[103, 290] -> 
             RGBColor[
              0.6002640830556104, 0.6753252019623124, 0.9658032517009377], 
             UndirectedEdge[212, 299] -> 
             RGBColor[
              0.7187593861833736, 0.7778438409473968, 0.9427642247459438], 
             UndirectedEdge[206, 208] -> 
             RGBColor[
              0.9087929967098201, 0.9271093270448036, 0.8717701605399556], 
             UndirectedEdge[75, 169] -> 
             RGBColor[
              0.8699838561525366, 0.899066888984688, 0.9760044552140997], 
             UndirectedEdge[110, 167] -> 
             RGBColor[
              0.6126262830441405, 0.696207024032189, 0.9627769737164229], 
             UndirectedEdge[33, 214] -> 
             RGBColor[
              0.8032078864638164, 0.8466459508346653, 0.9564386099793808], 
             UndirectedEdge[98, 107] -> 
             RGBColor[0.81088955217834, 0.8528672666889265, 0.96835783225685],
              UndirectedEdge[238, 252] -> 
             RGBColor[
              0.6893267342791951, 0.7543407489395462, 0.9645080660311517], 
             UndirectedEdge[91, 241] -> 
             RGBColor[
              0.8692177163545282, 0.8985150026216269, 0.9782883887068993], 
             UndirectedEdge[74, 219] -> 
             RGBColor[
              0.5497410820084847, 0.6402352078060145, 0.9598740748370458], 
             UndirectedEdge[45, 180] -> 
             RGBColor[
              0.9017598283691168, 0.9245028257958059, 0.9904918515119902], 
             UndirectedEdge[187, 235] -> 
             RGBColor[
              0.7258830977508944, 0.7847117000771238, 0.9724130540808912], 
             UndirectedEdge[114, 188] -> 
             RGBColor[
              0.833979138090545, 0.8705434242419052, 0.9523549296196234], 
             UndirectedEdge[81, 378] -> 
             RGBColor[
              0.8215141721280541, 0.8613584207291956, 0.9790912675834356], 
             UndirectedEdge[19, 313] -> 
             RGBColor[
              0.5580947223936764, 0.65212546337674, 0.9583544073966107], 
             UndirectedEdge[195, 284] -> 
             RGBColor[
              0.822856364493579, 0.8618610137163899, 0.9515897581590214], 
             UndirectedEdge[64, 253] -> 
             RGBColor[
              0.5725059057080286, 0.6627110657210145, 0.9601572656304989], 
             UndirectedEdge[55, 122] -> 
             RGBColor[
              0.9770865736573825, 0.9807839185881779, 0.8498758235753721], 
             UndirectedEdge[99, 275] -> 
             RGBColor[
              0.7670358159947109, 0.8156408860144853, 0.8948506079246978], 
             UndirectedEdge[118, 367] -> 
             RGBColor[
              0.745490347540014, 0.8003359596819497, 0.9660767823718864], 
             UndirectedEdge[7, 96] -> 
             RGBColor[
              0.775298413555505, 0.8243882802465248, 0.9782381583537603], 
             UndirectedEdge[110, 115] -> 
             RGBColor[
              0.540362580428745, 0.6377297117057166, 0.956958468226155], 
             UndirectedEdge[68, 95] -> 
             RGBColor[
              0.4766549892713908, 0.5833612050102346, 0.9526747722341875], 
             UndirectedEdge[289, 302] -> 
             RGBColor[
              0.4465128705361622, 0.559525475959594, 0.9501264216130338], 
             UndirectedEdge[260, 321] -> 
             RGBColor[
              0.7096902000825736, 0.7728687274130065, 0.9718807542494144], 
             UndirectedEdge[191, 220] -> 
             RGBColor[
              0.8136760145164159, 0.8539636116198319, 0.9176731460332027], 
             UndirectedEdge[169, 209] -> 
             RGBColor[
              0.6255631134243729, 0.7046143420767906, 0.9652280336424244], 
             UndirectedEdge[32, 252] -> 
             RGBColor[
              0.8088534915215897, 0.8513943295124902, 0.9741102639706954], 
             UndirectedEdge[75, 280] -> 
             RGBColor[
              0.9222761725160665, 0.9405333220610431, 0.9810531887209026], 
             UndirectedEdge[14, 224] -> 
             RGBColor[
              0.563228598351486, 0.6524906003726157, 0.9604908888964118], 
             UndirectedEdge[128, 311] -> 
             RGBColor[
              0.8362843053382012, 0.7418800882839909, 0.6104246306474417], 
             UndirectedEdge[132, 198] -> 
             RGBColor[
              0.9864383598058482, 0.986054381875511, 0.7055595537981556], 
             UndirectedEdge[245, 388] -> 
             RGBColor[
              0.6119187436269762, 0.6944569477287026, 0.9635250814717673], 
             UndirectedEdge[183, 273] -> 
             RGBColor[
              0.8257875160419306, 0.8646725248607858, 0.9830470592992644], 
             UndirectedEdge[69, 220] -> 
             RGBColor[
              0.7206098621709847, 0.7816394002502691, 0.9728049323719489], 
             UndirectedEdge[37, 263] -> 
             RGBColor[
              0.9270054953168285, 0.9446199091950852, 0.9924447139210331], 
             UndirectedEdge[235, 384] -> 
             RGBColor[
              0.6755573645095427, 0.7427653423229462, 0.9687523044151211], 
             UndirectedEdge[132, 216] -> 
             RGBColor[
              0.963209238417292, 0.9720820907677352, 0.9471613421788334], 
             UndirectedEdge[225, 380] -> 
             RGBColor[
              0.9676333068145917, 0.9721929236514262, 0.7503503076515028], 
             UndirectedEdge[3, 371] -> 
             RGBColor[
              0.8161691377506015, 0.8553810587713319, 0.8926940845904722], 
             UndirectedEdge[269, 314] -> 
             RGBColor[
              0.47555372109515004`, 0.5837272667846272, 0.9522399012124407], 
             UndirectedEdge[16, 206] -> 
             RGBColor[
              0.6110458415767829, 0.6908547001663787, 0.9648353176006372], 
             UndirectedEdge[84, 256] -> 
             RGBColor[
              0.40104454090204417`, 0.5166754904200316, 0.9474417583964014], 
             UndirectedEdge[58, 348] -> 
             RGBColor[
              0.8022402268883468, 0.8426355999762148, 0.8180859230638418], 
             UndirectedEdge[177, 360] -> 
             RGBColor[
              0.7346733992633758, 0.7910962571984159, 0.9529405992042449], 
             UndirectedEdge[2, 106] -> 
             RGBColor[
              0.7485903035123884, 0.8037493833700171, 0.9755657582909067], 
             UndirectedEdge[256, 317] -> 
             RGBColor[
              0.552882287236677, 0.3215847012116179, 0.557986774958241], 
             UndirectedEdge[87, 351] -> 
             RGBColor[
              0.6018879606063332, 0.6816238572492493, 0.9648496699716524], 
             UndirectedEdge[48, 103] -> 
             RGBColor[
              0.901179924188946, 0.9240404259436172, 0.9904365397335988], 
             UndirectedEdge[256, 381] -> 
             RGBColor[
              0.6338957362261859, 0.6988625778185502, 0.8549006903679515], 
             UndirectedEdge[91, 226] -> 
             RGBColor[
              0.7360395832402973, 0.7926968667850304, 0.9662303156038343], 
             UndirectedEdge[105, 113] -> 
             RGBColor[
              0.7161355667961694, 0.7738364051857766, 0.883228144397697], 
             UndirectedEdge[223, 291] -> 
             RGBColor[
              0.7082408453104349, 0.7648747426986928, 0.7605537369390454], 
             UndirectedEdge[203, 348] -> 
             RGBColor[
              0.8566951256112512, 0.8856765442654635, 0.8231713771774041], 
             UndirectedEdge[259, 367] -> 
             RGBColor[
              0.9181239781918347, 0.9372642589334772, 0.9821058233958029], 
             UndirectedEdge[188, 206] -> 
             RGBColor[
              0.897549697779769, 0.9202398730476219, 0.9586818553443166], 
             UndirectedEdge[250, 289] -> 
             RGBColor[
              0.6227488969882704, 0.7032466623975684, 0.9643795111620257], 
             UndirectedEdge[194, 377] -> 
             RGBColor[
              0.9627235499831099, 0.9707560618340507, 0.9048777450841672], 
             UndirectedEdge[83, 231] -> 
             RGBColor[
              0.6187677001172681, 0.6998622275949982, 0.9641702386616426], 
             UndirectedEdge[276, 376] -> 
             RGBColor[
              0.9023076207285052, 0.9238736314208131, 0.9535855880180154], 
             UndirectedEdge[83, 120] -> 
             RGBColor[
              0.6897304213706426, 0.7558124513115064, 0.971106844148955], 
             UndirectedEdge[40, 243] -> 
             RGBColor[
              0.8041854788075316, 0.8470020503963102, 0.9811048852727302], 
             UndirectedEdge[4, 392] -> 
             RGBColor[
              0.9097201636187489, 0.929865588491863, 0.957114673449305], 
             UndirectedEdge[81, 329] -> 
             RGBColor[
              0.8283263112323627, 0.8664389029193349, 0.9675600929702692], 
             UndirectedEdge[131, 363] -> 
             RGBColor[
              0.6290581437936116, 0.704864619268979, 0.9667156690212099], 
             UndirectedEdge[167, 192] -> 
             RGBColor[
              0.821463014210924, 0.8597943515410112, 0.9058127486213912], 
             UndirectedEdge[41, 327] -> 
             RGBColor[
              0.4844053505904281, 0.59189028975519, 0.9526668214366495], 
             UndirectedEdge[24, 382] -> 
             RGBColor[
              0.7615683126734435, 0.8139125570185421, 0.9770167034977777], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.7736237993730068, 0.8230800589196181, 0.978071248462208], 
             UndirectedEdge[90, 261] -> 
             RGBColor[
              0.5807832466575673, 0.6664025611734704, 0.962156711583782], 
             UndirectedEdge[146, 297] -> 
             RGBColor[
              0.59589992432325, 0.6732995331721323, 0.9651666941255368], 
             UndirectedEdge[5, 291] -> 
             RGBColor[
              0.9650753369123628, 0.9706401113606655, 0.7828414669908041], 
             UndirectedEdge[229, 315] -> 
             RGBColor[
              0.6884648704753493, 0.7556772883279899, 0.970182306462579], 
             UndirectedEdge[241, 360] -> 
             RGBColor[
              0.8766591174573668, 0.9040647873799479, 0.9656920376680358], 
             UndirectedEdge[59, 237] -> 
             RGBColor[
              0.742737289995347, 0.7960646881724378, 0.899226729545211], 
             UndirectedEdge[257, 381] -> 
             RGBColor[
              0.971327586212656, 0.9767250569654524, 0.8702009899733569], 
             UndirectedEdge[270, 308] -> 
             RGBColor[
              0.9442755005076902, 0.9535335522002335, 0.7378873617471808], 
             UndirectedEdge[317, 382] -> 
             RGBColor[
              0.8723750682741699, 0.5855109611072752, 0.5843316101675727], 
             UndirectedEdge[23, 89] -> 
             RGBColor[
              0.8901458039182115, 0.9145161635720388, 0.9627575837039164], 
             UndirectedEdge[57, 327] -> 
             RGBColor[
              0.5642646139736262, 0.6571344593117914, 0.9588401238628419], 
             UndirectedEdge[347, 362] -> 
             RGBColor[
              0.7295199016909208, 0.7886257588483353, 0.9736753841156147], 
             UndirectedEdge[43, 293] -> 
             RGBColor[
              0.6169383934267746, 0.4071593541919834, 0.565490784923407], 
             UndirectedEdge[73, 208] -> 
             RGBColor[
              0.7487023251121071, 0.799892512249125, 0.8572711829789039], 
             UndirectedEdge[53, 129] -> 
             RGBColor[
              0.9746731029584217, 0.9805776113242186, 0.92532833723561], 
             UndirectedEdge[324, 383] -> 
             RGBColor[
              0.5571839258702262, 0.6513860377280873, 0.9582827061579271], 
             UndirectedEdge[368, 399] -> 
             RGBColor[
              0.8780808536884628, 0.905110954388512, 0.962568554001999], 
             UndirectedEdge[51, 136] -> 
             RGBColor[
              0.8964596234233047, 0.9194770165053028, 0.9622647285196368], 
             UndirectedEdge[145, 359] -> 
             RGBColor[
              0.6472679560182653, 0.711845878631066, 0.8095796459099154], 
             UndirectedEdge[222, 297] -> 
             RGBColor[
              0.719245478785217, 0.7796397681484044, 0.9735849963304214], 
             UndirectedEdge[81, 209] -> 
             RGBColor[
              0.5815108441238309, 0.6702003744895602, 0.9608373151304086], 
             UndirectedEdge[31, 345] -> 
             RGBColor[
              0.9545330861939701, 0.9529332505652208, 0.696272760977327], 
             UndirectedEdge[155, 180] -> 
             RGBColor[
              0.9266397753095346, 0.9432012534130163, 0.9533346269646872], 
             UndirectedEdge[4, 369] -> 
             RGBColor[
              0.9837607877142377, 0.9844240506382547, 0.7391799400190363], 
             UndirectedEdge[102, 289] -> 
             RGBColor[
              0.4252421064322597, 0.5411018091924831, 0.9487710673333313], 
             UndirectedEdge[70, 103] -> 
             RGBColor[
              0.7829256891026788, 0.8311736339143083, 0.9787789485451703], 
             UndirectedEdge[177, 375] -> 
             RGBColor[
              0.5581893195967316, 0.6522022616477356, 0.9583618544349563], 
             UndirectedEdge[171, 253] -> 
             RGBColor[
              0.6819418535425616, 0.7514574260282784, 0.9689332489183251], 
             UndirectedEdge[150, 241] -> 
             RGBColor[
              0.7789268483952292, 0.8272228411204435, 0.9785998068289326], 
             UndirectedEdge[24, 317] -> 
             RGBColor[
              0.7198554901771368, 0.4650906300075065, 0.5696806005561273], 
             UndirectedEdge[80, 110] -> 
             RGBColor[
              0.6854505178932467, 0.7530978697809951, 0.9700354128650144], 
             UndirectedEdge[176, 341] -> 
             RGBColor[
              0.8148620883519128, 0.8554555119170603, 0.9821390928321554], 
             UndirectedEdge[154, 192] -> 
             RGBColor[
              0.7597354701739387, 0.8098707673970269, 0.9008236881296364], 
             UndirectedEdge[121, 322] -> 
             RGBColor[
              0.9793202545284299, 0.9503497290960918, 0.5902319335494788], 
             UndirectedEdge[268, 381] -> 
             RGBColor[
              0.9408975277962139, 0.9528288617717278, 0.8800541238510384], 
             UndirectedEdge[76, 104] -> 
             RGBColor[
              0.6972704823385631, 0.7620598277265158, 0.971555384132299], 
             UndirectedEdge[91, 186] -> 
             RGBColor[
              0.9482497315285647, 0.9609253150240669, 0.9724838852771789], 
             UndirectedEdge[216, 357] -> 
             RGBColor[
              0.7936414448652647, 0.839432732222959, 0.9700160719415764], 
             UndirectedEdge[210, 236] -> 
             RGBColor[
              0.747612962512931, 0.8030120197034047, 0.9754119049217119], 
             UndirectedEdge[26, 173] -> 
             RGBColor[
              0.8348949822409488, 0.8715292666823786, 0.9840232929106189], 
             UndirectedEdge[10, 374] -> 
             RGBColor[
              0.7239914762003827, 0.781502962545916, 0.9252149348648359], 
             UndirectedEdge[289, 340] -> 
             RGBColor[
              0.6928794669039745, 0.7584529826226292, 0.9712580726679918], 
             UndirectedEdge[65, 168] -> 
             RGBColor[
              0.7362045916679707, 0.7927305191031073, 0.963552881721925], 
             UndirectedEdge[40, 203] -> 
             RGBColor[
              0.7722005742295772, 0.8220151998457339, 0.9779169289003271], 
             UndirectedEdge[167, 201] -> 
             RGBColor[
              0.6688342278233406, 0.7412176491947776, 0.9676268032843598], 
             UndirectedEdge[41, 57] -> 
             RGBColor[
              0.5180470073969832, 0.6192021022901195, 0.9553152158939109], 
             UndirectedEdge[214, 363] -> 
             RGBColor[
              0.6752090916238171, 0.7409639756248454, 0.9468427149684662], 
             UndirectedEdge[22, 189] -> 
             RGBColor[
              0.5978127471211885, 0.6779094399789282, 0.9646750157181903], 
             UndirectedEdge[41, 96] -> 
             RGBColor[
              0.6160060168985236, 0.6964093841455206, 0.9646132790148525], 
             UndirectedEdge[31, 197] -> 
             RGBColor[
              0.8728195747947403, 0.9014266531578541, 0.9877315042907968], 
             UndirectedEdge[275, 281] -> 
             RGBColor[
              0.9456917965977751, 0.9573644413433369, 0.9114618953874034], 
             UndirectedEdge[89, 353] -> 
             RGBColor[
              0.7424067217110866, 0.7986930405915484, 0.9749598219010447], 
             UndirectedEdge[324, 375] -> 
             RGBColor[
              0.572758759325501, 0.6640303891653307, 0.9595088141000212], 
             UndirectedEdge[5, 174] -> 
             RGBColor[
              0.7711864049502735, 0.8215450021647317, 0.9774288271468282], 
             UndirectedEdge[36, 314] -> 
             RGBColor[
              0.7563936658522412, 0.8086241975077435, 0.9518194862947642], 
             UndirectedEdge[220, 357] -> 
             RGBColor[
              0.6406515564457159, 0.7191488204031766, 0.9648535837888349], 
             UndirectedEdge[291, 342] -> 
             RGBColor[
              0.9451546602257859, 0.9547711905083565, 0.781471390461309], 
             UndirectedEdge[21, 159] -> 
             RGBColor[
              0.6184639868506858, 0.6969076124663044, 0.9654793910553238], 
             UndirectedEdge[220, 394] -> 
             RGBColor[
              0.5857491532753156, 0.6745765761843687, 0.9605314654971315], 
             UndirectedEdge[129, 249] -> 
             RGBColor[
              0.7452532714220649, 0.7995489577147218, 0.9501119303620887], 
             UndirectedEdge[37, 58] -> 
             RGBColor[
              0.7637492245822919, 0.81565623685631, 0.9772193343654505], 
             UndirectedEdge[118, 259] -> 
             RGBColor[
              0.7167898363336391, 0.7777378468385592, 0.9732861573265006], 
             UndirectedEdge[201, 243] -> 
             RGBColor[
              0.7327532125943369, 0.7911516459001569, 0.973997650329459], 
             UndirectedEdge[40, 110] -> 
             RGBColor[
              0.6981556643898992, 0.7630702020119446, 0.9712892773510773], 
             UndirectedEdge[35, 278] -> 
             RGBColor[
              0.5430731825105766, 0.6399303005869796, 0.9571718567512995], 
             UndirectedEdge[164, 315] -> 
             RGBColor[
              0.8933422842359924, 0.9144047041754072, 0.8347631158976587], 
             UndirectedEdge[81, 304] -> 
             RGBColor[
              0.5225785180281972, 0.6193268172757483, 0.9570350451078222], 
             UndirectedEdge[12, 299] -> 
             RGBColor[
              0.7299039718743194, 0.7846825002917908, 0.8579374399591604], 
             UndirectedEdge[203, 258] -> 
             RGBColor[
              0.8568573698603107, 0.886023568308792, 0.8408306624320956], 
             UndirectedEdge[250, 276] -> 
             RGBColor[
              0.8543482621305609, 0.886346033279035, 0.9488217364400112], 
             UndirectedEdge[124, 238] -> 
             RGBColor[
              0.4957181728409742, 0.6009851057882307, 0.9535821215308258], 
             UndirectedEdge[96, 154] -> 
             RGBColor[
              0.662553157200034, 0.7346092714903648, 0.968164129085727], 
             UndirectedEdge[126, 238] -> 
             RGBColor[
              0.5081396199859228, 0.611069396160317, 0.9545599833513363], 
             UndirectedEdge[103, 108] -> 
             RGBColor[
              0.6861487832229247, 0.7525344896640855, 0.9711724846903702], 
             UndirectedEdge[122, 210] -> 
             RGBColor[
              0.8020740408903295, 0.8458095405695218, 0.9588241187688678], 
             UndirectedEdge[108, 234] -> 
             RGBColor[
              0.3905311611500793, 0.5126801959464771, 0.9461052781487047], 
             UndirectedEdge[222, 361] -> 
             RGBColor[
              0.7616999916784926, 0.8117019830679639, 0.9108578056619546], 
             UndirectedEdge[12, 274] -> 
             RGBColor[
              0.9106572925983858, 0.9286453387656917, 0.8740962578488158], 
             UndirectedEdge[141, 219] -> 
             RGBColor[
              0.7879662935394192, 0.8342845243694124, 0.9795007742424877], 
             UndirectedEdge[179, 344] -> 
             RGBColor[
              0.6391323807909823, 0.7160628428782099, 0.9660006503685035], 
             UndirectedEdge[14, 230] -> 
             RGBColor[
              0.3103226295202427, 0.4373844139276082, 0.9412076767057528], 
             UndirectedEdge[12, 118] -> 
             RGBColor[
              0.7686070718350606, 0.8161034203947041, 0.8609842897621964], 
             UndirectedEdge[44, 49] -> 
             RGBColor[
              0.6783952925437151, 0.4963791487439466, 0.5747199039614297], 
             UndirectedEdge[224, 247] -> 
             RGBColor[
              0.61340297826693, 0.6953541440291295, 0.9638523514238786], 
             UndirectedEdge[161, 222] -> 
             RGBColor[
              0.6427301700749504, 0.7192017688560536, 0.9661347800185514], 
             UndirectedEdge[148, 168] -> 
             RGBColor[
              0.7589887242577461, 0.8072778839525447, 0.794666602197516], 
             UndirectedEdge[219, 323] -> 
             RGBColor[
              0.5468966926928234, 0.6377715407439525, 0.9596928328650465], 
             UndirectedEdge[309, 334] -> 
             RGBColor[
              0.5333181239078766, 0.6285475020971889, 0.957753824948578], 
             UndirectedEdge[170, 326] -> 
             RGBColor[
              0.7724788196030885, 0.7423424434055605, 0.6157005808501568], 
             UndirectedEdge[239, 354] -> 
             RGBColor[
              0.5567575523298318, 0.6510398884800861, 0.9582491404709695], 
             UndirectedEdge[11, 221] -> 
             RGBColor[
              0.8657877764421049, 0.8886167204777873, 0.696184581391856], 
             UndirectedEdge[47, 322] -> 
             RGBColor[
              0.9316871886928233, 0.9144296464544612, 0.6642490039852993], 
             UndirectedEdge[155, 271] -> 
             RGBColor[
              0.8907689988558258, 0.9147472618842818, 0.9498738616289458], 
             UndirectedEdge[106, 363] -> 
             RGBColor[
              0.6250571786526464, 0.701674358268879, 0.9663340533943608], 
             UndirectedEdge[245, 378] -> 
             RGBColor[
              0.7159817562761872, 0.776617802751476, 0.9701438643744799], 
             UndirectedEdge[155, 326] -> 
             RGBColor[
              0.793278084986216, 0.8380394924589188, 0.9405309518505702], 
             UndirectedEdge[10, 39] -> 
             RGBColor[
              0.6503668676181174, 0.7241871666319533, 0.9676260804690939], 
             UndirectedEdge[25, 382] -> 
             RGBColor[
              0.7009524473777982, 0.7647018668579246, 0.9722448005384736], 
             UndirectedEdge[177, 383] -> 
             RGBColor[
              0.5426144861414568, 0.6395579102104922, 0.9571357464928623], 
             UndirectedEdge[177, 296] -> 
             RGBColor[
              0.46743817284108585`, 0.5777907136478699, 0.9514208619663481], 
             UndirectedEdge[103, 143] -> 
             RGBColor[
              0.798617052140955, 0.8434318459785859, 0.9803429169687011], 
             UndirectedEdge[84, 317] -> 
             RGBColor[
              0.6788244994432304, 0.4317798233046532, 0.5664504906640828], 
             UndirectedEdge[50, 328] -> 
             RGBColor[
              0.7516669777991709, 0.8059272230281129, 0.9758827976858917], 
             UndirectedEdge[332, 385] -> 
             RGBColor[
              0.5877530746818611, 0.676203449857833, 0.9606892215308608], 
             UndirectedEdge[242, 257] -> 
             RGBColor[
              0.9711036269807172, 0.976632444067556, 0.8739125740344953], 
             UndirectedEdge[214, 217] -> 
             RGBColor[
              0.9675444839967082, 0.9753153098225507, 0.9398229022260163], 
             UndirectedEdge[51, 59] -> 
             RGBColor[
              0.9072169224979262, 0.9268305953438603, 0.914087409370204], 
             UndirectedEdge[66, 131] -> 
             RGBColor[
              0.5759778908074955, 0.6563615315570113, 0.9634259915373901], 
             UndirectedEdge[66, 98] -> 
             RGBColor[
              0.6159061625793136, 0.6878200262972292, 0.9540864049176532], 
             UndirectedEdge[70, 346] -> 
             RGBColor[
              0.5643976736026196, 0.6572240011554453, 0.9588632350194846], 
             UndirectedEdge[151, 253] -> 
             RGBColor[
              0.8029270520740035, 0.8466649870053157, 0.9808080207870462], 
             UndirectedEdge[384, 398] -> 
             RGBColor[
              0.6023547679242645, 0.6846831013153505, 0.9637020640739091], 
             UndirectedEdge[123, 218] -> 
             RGBColor[
              0.8900608953257458, 0.899157658746492, 0.6863061085372977], 
             UndirectedEdge[169, 280] -> 
             RGBColor[
              0.843815206591397, 0.8785293978099189, 0.9849039960689092], 
             UndirectedEdge[71, 109] -> 
             RGBColor[
              0.6739472644639701, 0.7438510020769245, 0.9690669394268308], 
             UndirectedEdge[166, 302] -> 
             RGBColor[
              0.5744225688028683, 0.6614182804826227, 0.9615292019887652], 
             UndirectedEdge[89, 163] -> 
             RGBColor[
              0.9028164111960972, 0.9179628097083248, 0.7004871718424047], 
             UndirectedEdge[102, 340] -> 
             RGBColor[
              0.6042834612328689, 0.6833588384096199, 0.9651587750840709], 
             UndirectedEdge[380, 390] -> 
             RGBColor[
              0.9892220985761674, 0.9881438157980742, 0.7070891035185283], 
             UndirectedEdge[172, 387] -> 
             RGBColor[
              0.7973736050321664, 0.8410116612589151, 0.9282236183217785], 
             UndirectedEdge[61, 298] -> 
             RGBColor[
              0.5758650435319326, 0.29909940422496833`, 0.553373678326482], 
             UndirectedEdge[10, 216] -> 
             RGBColor[
              0.7048591582971419, 0.767355272390526, 0.9630268051227021], 
             UndirectedEdge[209, 229] -> 
             RGBColor[
              0.5223897506933167, 0.6231385588597431, 0.9555435812327375], 
             UndirectedEdge[39, 119] -> 
             RGBColor[
              0.7367446753914995, 0.7943125622582803, 0.9744260579093501], 
             UndirectedEdge[33, 261] -> 
             RGBColor[
              0.7127924004950111, 0.7755581077803728, 0.9720081431237927], 
             UndirectedEdge[102, 213] -> 
             RGBColor[
              0.43500741060131576`, 0.5490297230388622, 0.9495398278490073], 
             UndirectedEdge[155, 335] -> 
             RGBColor[
              0.8272459896404933, 0.8651226042925129, 0.9435424817266334], 
             UndirectedEdge[76, 317] -> 
             RGBColor[
              0.8483879683396567, 0.5663842987319767, 0.5820436991622819], 
             UndirectedEdge[19, 179] -> 
             RGBColor[
              0.7001359125040344, 0.7655882581006512, 0.9708030718482545], 
             UndirectedEdge[48, 83] -> 
             RGBColor[
              0.6880031537519352, 0.7544351749977798, 0.9709420958215327], 
             UndirectedEdge[288, 355] -> 
             RGBColor[
              0.7103927355337476, 0.7736834712745045, 0.9717689669465979], 
             UndirectedEdge[7, 192] -> 
             RGBColor[
              0.8724807265294097, 0.899649776153187, 0.9108977173976697], 
             UndirectedEdge[341, 393] -> 
             RGBColor[
              0.7811652399698434, 0.8291312778554546, 0.9787805059003826], 
             UndirectedEdge[244, 270] -> 
             RGBColor[
              0.9445288697209342, 0.9540754833278056, 0.7654650369952651], 
             UndirectedEdge[121, 265] -> 
             RGBColor[
              0.7859551847589515, 0.8311118402089399, 0.9009952247634305], 
             UndirectedEdge[156, 363] -> 
             RGBColor[
              0.584793605655012, 0.669876132570553, 0.9624122481128781], 
             UndirectedEdge[133, 280] -> 
             RGBColor[
              0.8587647907829814, 0.8902197498938264, 0.9863909464449014], 
             UndirectedEdge[44, 362] -> 
             RGBColor[
              0.7585370876293107, 0.5610564811979776, 0.581292450934221], 
             UndirectedEdge[116, 147] -> 
             RGBColor[
              0.33738380066335427`, 0.46664662355688435`, 0.9427187753348562],
              UndirectedEdge[83, 196] -> 
             RGBColor[
              0.57841686270714, 0.6683398467324835, 0.9601484442886157], 
             UndirectedEdge[109, 233] -> 
             RGBColor[
              0.7800544573418204, 0.8281037377996661, 0.978712196350624], 
             UndirectedEdge[19, 125] -> 
             RGBColor[
              0.7516942927336122, 0.8062413449790911, 0.9758423393507925], 
             UndirectedEdge[26, 160] -> 
             RGBColor[
              0.8702877925894468, 0.8564910401089483, 0.6445863192572019], 
             UndirectedEdge[224, 302] -> 
             RGBColor[
              0.565381420493862, 0.6543552667083548, 0.9606280648196581], 
             UndirectedEdge[58, 60] -> 
             RGBColor[
              0.7161643890179119, 0.7777133806332256, 0.9726806502698357], 
             UndirectedEdge[165, 332] -> 
             RGBColor[
              0.5192065949074292, 0.619251901590987, 0.9556528562865938], 
             UndirectedEdge[43, 252] -> 
             RGBColor[
              0.6695310649680162, 0.7371947351414723, 0.9632467034872665], 
             UndirectedEdge[292, 304] -> 
             RGBColor[
              0.601296121066333, 0.6811519404651095, 0.9647932197879858], 
             UndirectedEdge[63, 257] -> 
             RGBColor[
              0.8924583629490271, 0.9167181823657642, 0.9768490894220303], 
             UndirectedEdge[94, 355] -> 
             RGBColor[
              0.6007780840530703, 0.684972304680712, 0.9629011891988872], 
             UndirectedEdge[223, 290] -> 
             RGBColor[
              0.3504325365367188, 0.47512850561446884`, 0.9436534934065333], 
             UndirectedEdge[141, 150] -> 
             RGBColor[
              0.7880454702989175, 0.8343463778556981, 0.9795086658419256], 
             UndirectedEdge[131, 306] -> 
             RGBColor[
              0.5581558285470305, 0.6376294141372504, 0.962411051457035], 
             UndirectedEdge[151, 182] -> 
             RGBColor[
              0.6665621347722533, 0.7361390571835251, 0.9696622511668302], 
             UndirectedEdge[87, 201] -> 
             RGBColor[
              0.7724842898694799, 0.8225297660922424, 0.9778674736207391], 
             UndirectedEdge[72, 379] -> 
             RGBColor[
              0.7879366667771798, 0.8341054544581248, 0.9509024625087887], 
             UndirectedEdge[23, 378] -> 
             RGBColor[
              0.9525390914175197, 0.9641243126060672, 0.965223117829408], 
             UndirectedEdge[116, 322] -> 
             RGBColor[
              0.6518011526414276, 0.6871993277533535, 0.6406454454963408], 
             UndirectedEdge[90, 175] -> 
             RGBColor[
              0.49213139024945174`, 0.5965704081933226, 0.9537149810893415], 
             UndirectedEdge[348, 369] -> 
             RGBColor[
              0.9942130888172361, 0.9900307070635666, 0.6115086143113062], 
             UndirectedEdge[134, 243] -> 
             RGBColor[
              0.8766118492776884, 0.9038516178752951, 0.9567659222844083], 
             UndirectedEdge[211, 372] -> 
             RGBColor[
              0.955906697154201, 0.9655589325055156, 0.9145816127165951], 
             UndirectedEdge[73, 188] -> 
             RGBColor[
              0.7374590261820559, 0.7930230582519433, 0.9441828777832648], 
             UndirectedEdge[55, 228] -> 
             RGBColor[
              0.7833077936961355, 0.8278284493598012, 0.8533761669938511], 
             UndirectedEdge[260, 384] -> 
             RGBColor[
              0.5190933199642127, 0.6193727075309425, 0.955585150534743], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.7564935277352323, 0.8052521710082455, 0.7944701711870576], 
             UndirectedEdge[153, 203] -> 
             RGBColor[
              0.773398810446839, 0.822970640880123, 0.9780312177404077], 
             UndirectedEdge[65, 148] -> 
             RGBColor[
              0.9716328156783764, 0.9759193769662862, 0.8025837369932138], 
             UndirectedEdge[42, 366] -> 
             RGBColor[
              0.6889846995345712, 0.751781933216322, 0.9314654904289298], 
             UndirectedEdge[48, 313] -> 
             RGBColor[
              0.6796451530951215, 0.7476497735409396, 0.9702841233934631], 
             UndirectedEdge[166, 213] -> 
             RGBColor[
              0.6515131145391275, 0.7260166717749004, 0.9670419058086596], 
             UndirectedEdge[11, 78] -> 
             RGBColor[
              0.7410894767752259, 0.7976639988362217, 0.974828531236192], 
             UndirectedEdge[228, 348] -> 
             RGBColor[
              0.7836449037438853, 0.8275390789377797, 0.8166220311089967], 
             UndirectedEdge[199, 336] -> 
             RGBColor[
              0.6831928254616375, 0.7514759541615754, 0.969713430318327], 
             UndirectedEdge[249, 309] -> 
             RGBColor[
              0.44348970981539243`, 0.5565854679903655, 0.9500226193684962], 
             UndirectedEdge[190, 273] -> 
             RGBColor[
              0.7609126772847596, 0.8131500337361734, 0.9768043226046412], 
             UndirectedEdge[298, 314] -> 
             RGBColor[
              0.683108060597071, 0.3893927181878728, 0.56092416926913], 
             UndirectedEdge[7, 385] -> 
             RGBColor[
              0.6496080368108914, 0.7246674251793396, 0.9667569804200985], 
             UndirectedEdge[27, 194] -> 
             RGBColor[
              0.9396232970294633, 0.954486261299067, 0.9868964364019217], 
             UndirectedEdge[39, 128] -> 
             RGBColor[
              0.801937625842792, 0.8453420014414248, 0.9808553672723344], 
             UndirectedEdge[116, 265] -> 
             RGBColor[
              0.4584360828719493, 0.5679614388662015, 0.9514087367102926], 
             UndirectedEdge[231, 313] -> 
             RGBColor[
              0.6104096994604544, 0.6930768261381581, 0.9635122662335731], 
             UndirectedEdge[96, 284] -> 
             RGBColor[
              0.8821350921794117, 0.9081700063195792, 0.9574981077435393], 
             UndirectedEdge[279, 300] -> 
             RGBColor[
              0.8317403711901461, 0.8693080345663626, 0.983644339856509], 
             UndirectedEdge[22, 190] -> 
             RGBColor[
              0.5612992408529204, 0.649001505533105, 0.961137408234819], 
             UndirectedEdge[24, 207] -> 
             RGBColor[
              0.6747790887305888, 0.745351548935674, 0.968568206382524], 
             UndirectedEdge[315, 329] -> 
             RGBColor[
              0.8724939235114432, 0.9009429773180386, 0.9719623077924442], 
             UndirectedEdge[239, 335] -> 
             RGBColor[
              0.6313812939574911, 0.7111292402932553, 0.9644612467608152], 
             UndirectedEdge[142, 300] -> 
             RGBColor[
              0.7130317838125699, 0.7744490948726779, 0.9732640080756871], 
             UndirectedEdge[13, 88] -> 
             RGBColor[
              0.5709543758817817, 0.6625655093991716, 0.9593667664256573], 
             UndirectedEdge[18, 302] -> 
             RGBColor[
              0.4391325550758387, 0.5535338033894809, 0.9495454161450108], 
             UndirectedEdge[148, 251] -> 
             RGBColor[
              0.912463957393393, 0.9290788295853941, 0.808696764466443], 
             UndirectedEdge[90, 257] -> 
             RGBColor[
              0.664756607761491, 0.7326858780515457, 0.9574920154603557], 
             UndirectedEdge[134, 348] -> 
             RGBColor[
              0.9827167972341249, 0.9844421435694011, 0.8041618271510405], 
             UndirectedEdge[158, 322] -> 
             RGBColor[
              0.8357836507232937, 0.8389176993302405, 0.6548471681643288], 
             UndirectedEdge[40, 385] -> 
             RGBColor[
              0.6841197058381644, 0.7516751785469193, 0.9701843152784744], 
             UndirectedEdge[228, 385] -> 
             RGBColor[
              0.5574741828180818, 0.6516216813942831, 0.9583055562481086], 
             UndirectedEdge[175, 214] -> 
             RGBColor[
              0.783782936021273, 0.8308943829387947, 0.9548967705093709], 
             UndirectedEdge[7, 41] -> 
             RGBColor[
              0.5974801406707665, 0.6819368288345224, 0.9627667928066261], 
             UndirectedEdge[176, 379] -> 
             RGBColor[
              0.8788499561439946, 0.9056517333056501, 0.9596055015955687], 
             UndirectedEdge[259, 336] -> 
             RGBColor[
              0.8380181549038559, 0.8739466722363209, 0.9843405366370668], 
             UndirectedEdge[213, 340] -> 
             RGBColor[
              0.7026447710730306, 0.7663808964690084, 0.9720268331836677], 
             UndirectedEdge[55, 165] -> 
             RGBColor[
              0.6997306673976564, 0.7586743451218244, 0.8471565341961387], 
             UndirectedEdge[108, 231] -> 
             RGBColor[
              0.5958073701012851, 0.6811322230724004, 0.9623875222731002], 
             UndirectedEdge[38, 230] -> 
             RGBColor[
              0.5443198595187819, 0.35310794058851414`, 0.5629995324194935], 
             UndirectedEdge[39, 316] -> 
             RGBColor[
              0.9146848516476405, 0.9321178797050046, 0.8858171739492178], 
             UndirectedEdge[85, 167] -> 
             RGBColor[
              0.7058536449231512, 0.7701374991911403, 0.9713165528147472], 
             UndirectedEdge[28, 328] -> 
             RGBColor[
              0.663200022951846, 0.7358620148657736, 0.9677175964160079], 
             UndirectedEdge[79, 120] -> 
             RGBColor[
              0.8235306762985848, 0.8625812970169078, 0.9829092041649783], 
             UndirectedEdge[130, 347] -> 
             RGBColor[
              0.8694814543024985, 0.8986921985075371, 0.9768548904988259], 
             UndirectedEdge[77, 160] -> 
             RGBColor[
              0.9764993582880243, 0.9384708747608359, 0.5629381810297324], 
             UndirectedEdge[108, 179] -> 
             RGBColor[
              0.6066552022394582, 0.6896066319853191, 0.9634687328018783], 
             UndirectedEdge[318, 373] -> 
             RGBColor[
              0.4912276020812111, 0.5957791586983804, 0.9536597227378345], 
             UndirectedEdge[48, 331] -> 
             RGBColor[
              0.7212122848660683, 0.7813958436905408, 0.9735564402718928], 
             UndirectedEdge[222, 312] -> 
             RGBColor[
              0.5943403199189046, 0.681399250137668, 0.9613117319838568], 
             UndirectedEdge[292, 353] -> 
             RGBColor[
              0.7654217917472597, 0.8170029216448456, 0.9771660886613394], 
             UndirectedEdge[175, 204] -> 
             RGBColor[
              0.7713218385213879, 0.8216009168265548, 0.9759901582019364], 
             UndirectedEdge[198, 340] -> 
             RGBColor[
              0.9325178582693641, 0.9441958965089718, 0.7398113784690942], 
             UndirectedEdge[14, 207] -> 
             RGBColor[
              0.557695713784487, 0.648168268897396, 0.9599394226705193], 
             UndirectedEdge[45, 271] -> 
             RGBColor[
              0.8658890519154082, 0.8960488342670714, 0.9870310861762488], 
             UndirectedEdge[112, 183] -> 
             RGBColor[
              0.7518245217763773, 0.8059294423369583, 0.9763332741395507], 
             UndirectedEdge[85, 139] -> 
             RGBColor[
              0.6696989115255975, 0.7409750747662374, 0.9683406776528205], 
             UndirectedEdge[45, 97] -> 
             RGBColor[
              0.9425287507784743, 0.9565156130216745, 0.9772099775229289], 
             UndirectedEdge[130, 181] -> 
             RGBColor[
              0.7581750515581811, 0.8106136470184471, 0.9665301753869879], 
             UndirectedEdge[63, 90] -> 
             RGBColor[
              0.6072489420420872, 0.6871987337965093, 0.9647624629810152], 
             UndirectedEdge[114, 361] -> 
             RGBColor[
              0.8420657247997075, 0.8761074966119459, 0.9177581256247398], 
             UndirectedEdge[75, 209] -> 
             RGBColor[
              0.7040240793490424, 0.7666182663279149, 0.9613772262944176], 
             UndirectedEdge[42, 276] -> 
             RGBColor[
              0.6868235663604292, 0.7501701636335778, 0.9351237251789477], 
             UndirectedEdge[205, 358] -> 
             RGBColor[
              0.8477886942958061, 0.8797948574318275, 0.8828028424881215], 
             UndirectedEdge[76, 358] -> 
             RGBColor[
              0.9286888156926862, 0.9433674962491981, 0.8907672678423724], 
             UndirectedEdge[90, 142] -> 
             RGBColor[
              0.4416624354018862, 0.5555974370475627, 0.949741880089868], 
             UndirectedEdge[152, 381] -> 
             RGBColor[
              0.9448786245225766, 0.9560032802373375, 0.880433844410766], 
             UndirectedEdge[86, 309] -> 
             RGBColor[
              0.5765271777503318, 0.6623027433598869, 0.9620604996240281], 
             UndirectedEdge[104, 358] -> 
             RGBColor[
              0.7598456071297994, 0.8093477606080002, 0.87523076087603], 
             UndirectedEdge[16, 369] -> 
             RGBColor[
              0.6957313002819596, 0.7539010644841975, 0.7479158979981967], 
             UndirectedEdge[278, 337] -> 
             RGBColor[
              0.6297725394897233, 0.7085364653035545, 0.9652143342259726], 
             UndirectedEdge[100, 350] -> 
             RGBColor[
              0.5847670200180962, 0.6670024076774124, 0.9636630546299902], 
             UndirectedEdge[90, 202] -> 
             RGBColor[
              0.682898291345071, 0.7458741077664844, 0.9114760078269277], 
             UndirectedEdge[126, 367] -> 
             RGBColor[
              0.7641050457843876, 0.8154482102993317, 0.96754219960557], 
             UndirectedEdge[278, 327] -> 
             RGBColor[
              0.5157965787112346, 0.6177859248256761, 0.9550245425827233], 
             UndirectedEdge[10, 200] -> 
             RGBColor[
              0.3209943322686257, 0.4401836729092129, 0.9421870284822959], 
             UndirectedEdge[149, 299] -> 
             RGBColor[
              0.6785869355609248, 0.5866449483959182, 0.5907213714041839], 
             UndirectedEdge[57, 284] -> 
             RGBColor[
              0.7841760826778712, 0.8309627244641782, 0.9482000446225975], 
             UndirectedEdge[125, 313] -> 
             RGBColor[
              0.6728159118282054, 0.7422043219295167, 0.9696327442648891], 
             UndirectedEdge[125, 196] -> 
             RGBColor[
              0.7636584323902622, 0.8156703268779943, 0.9769784038147278], 
             UndirectedEdge[21, 210] -> 
             RGBColor[
              0.5229583573228828, 0.6221757364481999, 0.9559926979356963], 
             UndirectedEdge[186, 374] -> 
             RGBColor[
              0.9678047922649724, 0.9753882860922547, 0.9339564216717506], 
             UndirectedEdge[6, 74] -> 
             RGBColor[
              0.49415852763656903`, 0.5968136938876147, 0.9543341252657558], 
             UndirectedEdge[7, 312] -> 
             RGBColor[
              0.7045277403539789, 0.7691016924644551, 0.9711843990385747], 
             UndirectedEdge[238, 299] -> 
             RGBColor[
              0.4508218217808081, 0.5645362254400216, 0.9500477163146167], 
             UndirectedEdge[155, 239] -> 
             RGBColor[
              0.784048669092226, 0.8305466368557299, 0.939804378422931], 
             UndirectedEdge[108, 331] -> 
             RGBColor[
              0.5061811439000471, 0.609889907411009, 0.9542923852286642], 
             UndirectedEdge[55, 87] -> 
             RGBColor[
              0.9280739974165986, 0.9423308854301468, 0.8669832927259418], 
             UndirectedEdge[186, 288] -> 
             RGBColor[
              0.809457497035406, 0.8517435173625939, 0.9679611404541568], 
             UndirectedEdge[178, 371] -> 
             RGBColor[
              0.570759145089895, 0.6624027238599604, 0.9593543291363913], 
             UndirectedEdge[212, 238] -> 
             RGBColor[
              0.7028312022038454, 0.7644123590062135, 0.9416485243640484], 
             UndirectedEdge[292, 329] -> 
             RGBColor[
              0.9070439142704987, 0.9282640261086961, 0.9753182676504328], 
             UndirectedEdge[268, 338] -> 
             RGBColor[
              0.8731746514240813, 0.9017097816237925, 0.987765371816684], 
             UndirectedEdge[68, 309] -> 
             RGBColor[
              0.3585509077313219, 0.4849805078094227, 0.9440675246798892], 
             UndirectedEdge[129, 309] -> 
             RGBColor[
              0.663064340922392, 0.7303257980876197, 0.9443320550592236], 
             UndirectedEdge[137, 330] -> 
             RGBColor[
              0.9601394488719447, 0.9697926467511342, 0.9523576951497648], 
             UndirectedEdge[111, 400] -> 
             RGBColor[
              0.8419123054584694, 0.8772382680792495, 0.978323595725981], 
             UndirectedEdge[62, 370] -> 
             RGBColor[
              0.6366335357689622, 0.7140305813301231, 0.9658063843042785], 
             UndirectedEdge[163, 280] -> 
             RGBColor[
              0.9434584638582062, 0.9503279682358463, 0.7043747159413543], 
             UndirectedEdge[316, 383] -> 
             RGBColor[
              0.7841368874744177, 0.8289821423211767, 0.873532288200142], 
             UndirectedEdge[307, 314] -> 
             RGBColor[
              0.48591750809204887`, 0.5927038581822606, 0.952900272555546], 
             UndirectedEdge[126, 259] -> 
             RGBColor[
              0.7354045345780127, 0.7928500974559411, 0.9747515745601842], 
             UndirectedEdge[44, 372] -> 
             RGBColor[
              0.9191376040091974, 0.685763502189844, 0.5158628798179753], 
             UndirectedEdge[202, 279] -> 
             RGBColor[
              0.8637221272699822, 0.8931640550254412, 0.926192830678277], 
             UndirectedEdge[148, 312] -> 
             RGBColor[
              0.8233499458241811, 0.8593772009045535, 0.7998372917002102], 
             UndirectedEdge[109, 358] -> 
             RGBColor[
              0.892822173170653, 0.9149753533959739, 0.8872913588005791], 
             UndirectedEdge[142, 275] -> 
             RGBColor[
              0.746376529534905, 0.7988687465761658, 0.8932242332171221], 
             UndirectedEdge[296, 375] -> 
             RGBColor[
              0.5169746625074417, 0.618006667552446, 0.9553205558910243], 
             UndirectedEdge[92, 195] -> 
             RGBColor[
              0.7674714844148209, 0.8185946404609032, 0.9773729083036653], 
             UndirectedEdge[178, 248] -> 
             RGBColor[
              0.7452126280219007, 0.7974118920002999, 0.8717312179222625], 
             UndirectedEdge[41, 222] -> 
             RGBColor[
              0.48729272023569203`, 0.5942343865077354, 0.9528941257519081], 
             UndirectedEdge[154, 356] -> 
             RGBColor[
              0.6392629968026525, 0.7164148211761554, 0.9658427835562393], 
             UndirectedEdge[70, 133] -> 
             RGBColor[
              0.7324937765702373, 0.7909605957987372, 0.9739687077067263], 
             UndirectedEdge[7, 80] -> 
             RGBColor[
              0.7785790598583684, 0.8269511460721571, 0.9785651425178469], 
             UndirectedEdge[152, 261] -> 
             RGBColor[
              0.8395437058744278, 0.8752002330146104, 0.984476192462206], 
             UndirectedEdge[95, 229] -> 
             RGBColor[
              0.591342553580806, 0.679117550532178, 0.9609717984584802], 
             UndirectedEdge[30, 204] -> 
             RGBColor[
              0.9464653746483538, 0.9595945445844218, 0.9755043360405673], 
             UndirectedEdge[133, 223] -> 
             RGBColor[
              0.6220224246245856, 0.7004600106691062, 0.9654896458581302], 
             UndirectedEdge[298, 306] -> 
             RGBColor[
              0.5315411371781393, 0.2548850810064994, 0.5507626134745914], 
             UndirectedEdge[40, 96] -> 
             RGBColor[
              0.809810082582778, 0.8513960336141047, 0.981665493212136], 
             UndirectedEdge[122, 146] -> 
             RGBColor[
              0.6248844883991439, 0.695782773075788, 0.9461489352954624], 
             UndirectedEdge[223, 267] -> 
             RGBColor[
              0.7087854268327876, 0.7660395475093672, 0.8198280748795475], 
             UndirectedEdge[54, 322] -> 
             RGBColor[
              0.8599563620539414, 0.857801605141153, 0.657256478122937], 
             UndirectedEdge[41, 154] -> 
             RGBColor[
              0.4847348843152955, 0.5921578200783624, 0.9526927635385929], 
             UndirectedEdge[245, 353] -> 
             RGBColor[
              0.5811717728572569, 0.6704371804777649, 0.9604605107722199], 
             UndirectedEdge[26, 62] -> 
             RGBColor[
              0.7705614713835087, 0.8206877450196675, 0.977766024227297], 
             UndirectedEdge[217, 269] -> 
             RGBColor[
              0.6872245052956905, 0.7508061689326876, 0.9393631502396271], 
             UndirectedEdge[172, 347] -> 
             RGBColor[
              0.8883883358016271, 0.9126165193094116, 0.9369508986849121], 
             UndirectedEdge[63, 261] -> 
             RGBColor[
              0.8084850018451033, 0.8504348654876889, 0.9815137855454565], 
             UndirectedEdge[195, 369] -> 
             RGBColor[
              0.8344540169502137, 0.8675251719840659, 0.758764967799562], 
             UndirectedEdge[65, 180] -> 
             RGBColor[
              0.9111074344662209, 0.931617259043947, 0.9796268285291241], 
             UndirectedEdge[49, 211] -> 
             RGBColor[
              0.7151643856887187, 0.7761745790596182, 0.9734386368600495], 
             UndirectedEdge[285, 387] -> 
             RGBColor[
              0.8015032910957112, 0.8411934324160913, 0.7488628383178133], 
             UndirectedEdge[329, 388] -> 
             RGBColor[
              0.8423591190844226, 0.8774014390666538, 0.9689587521129173], 
             UndirectedEdge[38, 102] -> 
             RGBColor[
              0.5897612727212197, 0.39829019207175154`, 0.5656818038196072], 
             UndirectedEdge[92, 188] -> 
             RGBColor[
              0.9152526239495529, 0.934355705842278, 0.9603703762459792], 
             UndirectedEdge[114, 153] -> 
             RGBColor[
              0.7626607552584233, 0.8145819905546905, 0.9769609487520574], 
             UndirectedEdge[326, 337] -> 
             RGBColor[
              0.6826088419606262, 0.7514313558977346, 0.9693738015022353], 
             UndirectedEdge[38, 221] -> 
             RGBColor[
              0.9166812603951346, 0.6550710806416911, 0.3031162347186621], 
             UndirectedEdge[350, 394] -> 
             RGBColor[
              0.422181188571675, 0.5379894590529399, 0.948703441862992], 
             UndirectedEdge[286, 349] -> 
             RGBColor[
              0.6062519871754142, 0.6884491341984788, 0.9637851313408539], 
             UndirectedEdge[246, 320] -> 
             RGBColor[
              0.7020938014902922, 0.7610591582947606, 0.8597298393851193], 
             UndirectedEdge[322, 362] -> 
             RGBColor[
              0.8188705940043788, 0.8257050908774322, 0.6531614327320885], 
             UndirectedEdge[80, 348] -> 
             RGBColor[
              0.8975852802673154, 0.9176202438594665, 0.8272469256532997], 
             UndirectedEdge[78, 230] -> 
             RGBColor[
              0.4934263755657522, 0.5866535804246102, 0.9560678790926874], 
             UndirectedEdge[248, 329] -> 
             RGBColor[
              0.9723900904250888, 0.9777074035282465, 0.876908020095337], 
             UndirectedEdge[43, 330] -> 
             RGBColor[
              0.6858071528851046, 0.7493334148603887, 0.9356955321272326], 
             UndirectedEdge[63, 217] -> 
             RGBColor[
              0.9035946934124229, 0.9250236393912972, 0.9579981867676614], 
             UndirectedEdge[79, 136] -> 
             RGBColor[
              0.8651191274134638, 0.8949432293105369, 0.959154363045691], 
             UndirectedEdge[159, 243] -> 
             RGBColor[
              0.8088360169022057, 0.8507102632375096, 0.9815484577477847], 
             UndirectedEdge[1, 327] -> 
             RGBColor[
              0.7615304316549243, 0.8079880349558428, 0.6906574260311071], 
             UndirectedEdge[304, 353] -> 
             RGBColor[
              0.5058643551105377, 0.6062695861721298, 0.9553691335509229], 
             UndirectedEdge[240, 329] -> 
             RGBColor[
              0.86588942331904, 0.8957834915716727, 0.9713040329358289], 
             UndirectedEdge[10, 311] -> 
             RGBColor[
              0.6847135471135266, 0.6207252534745192, 0.5971953438442011], 
             UndirectedEdge[353, 378] -> 
             RGBColor[
              0.8048000092103946, 0.8483011896255769, 0.9774253560265362], 
             UndirectedEdge[167, 243] -> 
             RGBColor[
              0.7186560974617728, 0.7801388724165546, 0.9725925816380758], 
             UndirectedEdge[169, 292] -> 
             RGBColor[
              0.826188223965461, 0.8644741203356947, 0.9832227187302544], 
             UndirectedEdge[211, 347] -> 
             RGBColor[
              0.8573091693112604, 0.8892891173988777, 0.9861910622793326], 
             UndirectedEdge[224, 340] -> 
             RGBColor[
              0.8117480168616743, 0.8532827733713899, 0.9817597158746161], 
             UndirectedEdge[144, 233] -> 
             RGBColor[
              0.875446282204482, 0.9025225839511026, 0.9364089215407676], 
             UndirectedEdge[273, 394] -> 
             RGBColor[
              0.6291331900224162, 0.7084942834283787, 0.9648379631065804], 
             UndirectedEdge[93, 94] -> 
             RGBColor[
              0.6725705346998534, 0.7416726830688256, 0.9698934363101919], 
             UndirectedEdge[358, 366] -> 
             RGBColor[
              0.9863115246100764, 0.9881368317322985, 0.8554404952796455], 
             UndirectedEdge[245, 329] -> 
             RGBColor[
              0.7227938953804959, 0.7816982849416153, 0.9586126897613134], 
             UndirectedEdge[44, 93] -> 
             RGBColor[
              0.8728504685306633, 0.6509745334720001, 0.5925227869926158], 
             UndirectedEdge[218, 314] -> 
             RGBColor[
              0.7664426332663352, 0.8011544161098261, 0.6749638680369112], 
             UndirectedEdge[133, 346] -> 
             RGBColor[
              0.6533259556434181, 0.7267070742580868, 0.9677236906268489], 
             UndirectedEdge[143, 272] -> 
             RGBColor[
              0.6272335903935105, 0.7077562857940387, 0.9641385954106118], 
             UndirectedEdge[272, 346] -> 
             RGBColor[
              0.5323744064284148, 0.6312445521891108, 0.9563296099072036], 
             UndirectedEdge[61, 269] -> 
             RGBColor[
              0.36831070403001165`, 0.49343395282172264`, 0.9446894102697927],
              UndirectedEdge[158, 362] -> 
             RGBColor[
              0.6844299698728897, 0.7534011614159151, 0.9691812411013632], 
             UndirectedEdge[294, 393] -> 
             RGBColor[
              0.5768981132684186, 0.6655620263150763, 0.960840635623622], 
             UndirectedEdge[17, 298] -> 
             RGBColor[
              0.8913935951028571, 0.5539469066564233, 0.5537777630150098], 
             UndirectedEdge[83, 179] -> 
             RGBColor[
              0.6296155322554413, 0.7083366365079169, 0.9652514491904208], 
             UndirectedEdge[223, 398] -> 
             RGBColor[
              0.6070728404330011, 0.6887696585851988, 0.9640026954821381], 
             UndirectedEdge[52, 272] -> 
             RGBColor[
              0.5938316085182322, 0.6811382774610277, 0.961167745980863], 
             UndirectedEdge[52, 174] -> 
             RGBColor[
              0.6071126464569955, 0.6919204223636566, 0.9622132779374475], 
             UndirectedEdge[63, 317] -> 
             RGBColor[
              0.8328064715037432, 0.5539600361034837, 0.5805575220843062], 
             UndirectedEdge[145, 280] -> 
             RGBColor[
              0.9454693337984771, 0.9556742484320198, 0.8343664531085604], 
             UndirectedEdge[152, 317] -> 
             RGBColor[
              0.8638651755330677, 0.5787254036304051, 0.5835199290010555], 
             UndirectedEdge[102, 391] -> 
             RGBColor[
              0.6105048728814151, 0.6883196231824502, 0.9657521788810289], 
             UndirectedEdge[168, 251] -> 
             RGBColor[
              0.6770357333829872, 0.7458899717222154, 0.9696659091951543], 
             UndirectedEdge[89, 245] -> 
             RGBColor[
              0.6535884687768792, 0.7270096537174475, 0.9676783302489883], 
             UndirectedEdge[293, 330] -> 
             RGBColor[
              0.9074432471329574, 0.6396800531496818, 0.5547770262056886], 
             UndirectedEdge[166, 247] -> 
             RGBColor[
              0.6224441265759364, 0.7024171578033974, 0.9647534885929857], 
             UndirectedEdge[8, 182] -> 
             RGBColor[
              0.3962298821455448, 0.5176161416467038, 0.9464683956113547], 
             UndirectedEdge[2, 215] -> 
             RGBColor[
              0.5307116244363272, 0.6291743088730966, 0.9563977367291242], 
             UndirectedEdge[61, 107] -> 
             RGBColor[
              0.5028926325695633, 0.603636843042926, 0.9552046592206254], 
             UndirectedEdge[192, 361] -> 
             RGBColor[
              0.9875956013152288, 0.9891384766124112, 0.8552365179688084], 
             UndirectedEdge[71, 321] -> 
             RGBColor[
              0.6739472644639701, 0.7438510020769245, 0.9690669394268308], 
             UndirectedEdge[26, 389] -> 
             RGBColor[
              0.6045809441957373, 0.6872030442278201, 0.9635934612558283], 
             UndirectedEdge[134, 263] -> 
             RGBColor[
              0.9534283167113666, 0.9647874953742455, 0.9637178913540254], 
             UndirectedEdge[105, 282] -> 
             RGBColor[
              0.48047065481822904`, 0.588809517175634, 0.9523256823221437], 
             UndirectedEdge[323, 340] -> 
             RGBColor[
              0.6003215650685629, 0.6799272430827893, 0.9649063265638484], 
             UndirectedEdge[311, 323] -> 
             RGBColor[
              0.6175438690611721, 0.5628108177282126, 0.592842251716388], 
             UndirectedEdge[29, 365] -> 
             RGBColor[
              0.5814328236725137, 0.6709111139705677, 0.9603019303522968], 
             UndirectedEdge[321, 384] -> 
             RGBColor[
              0.6037835257390227, 0.6857992577792011, 0.9638444693003834], 
             UndirectedEdge[115, 195] -> 
             RGBColor[
              0.5927382709357911, 0.6797465507046874, 0.9614263345026961], 
             UndirectedEdge[162, 359] -> 
             RGBColor[
              0.6019814335858997, 0.5452306957689795, 0.5911005693946201], 
             UndirectedEdge[106, 295] -> 
             RGBColor[
              0.8454015498321605, 0.8795642642951543, 0.985116348593506], 
             UndirectedEdge[24, 242] -> 
             RGBColor[
              0.8006449799347068, 0.8422758937165424, 0.8703061000269761], 
             UndirectedEdge[109, 286] -> 
             RGBColor[
              0.7883549018842513, 0.834588108161928, 0.9795395070905492], 
             UndirectedEdge[287, 367] -> 
             RGBColor[
              0.6864224391451934, 0.7516407765265496, 0.961631534399864], 
             UndirectedEdge[74, 140] -> 
             RGBColor[
              0.6647579323746167, 0.7280048739194319, 0.8255464006973207], 
             UndirectedEdge[168, 394] -> 
             RGBColor[
              0.5271909657900185, 0.6270364015675208, 0.9559215504725803], 
             UndirectedEdge[68, 249] -> 
             RGBColor[
              0.4407398382309949, 0.5542036674365249, 0.9498473999827544], 
             UndirectedEdge[389, 400] -> 
             RGBColor[
              0.5863306375287323, 0.6729457659520878, 0.9617744412460737], 
             UndirectedEdge[267, 346] -> 
             RGBColor[
              0.7400889578516201, 0.7922866110983477, 0.8220621196482661], 
             UndirectedEdge[16, 392] -> 
             RGBColor[
              0.6216906761864707, 0.6993426023378058, 0.9658506314284654], 
             UndirectedEdge[13, 191] -> 
             RGBColor[
              0.8140717482558887, 0.8542848860971377, 0.9177042996427944], 
             UndirectedEdge[312, 327] -> 
             RGBColor[
              0.5914529502736405, 0.6790551533851226, 0.9610844276685981], 
             UndirectedEdge[260, 291] -> 
             RGBColor[
              0.809429447145249, 0.8478576550626499, 0.7682893904798473], 
             UndirectedEdge[83, 344] -> 
             RGBColor[
              0.505449191337438, 0.6093854496111388, 0.9542099583449292], 
             UndirectedEdge[200, 288] -> 
             RGBColor[
              0.4235768487021907, 0.5230685209070423, 0.9505336251649463], 
             UndirectedEdge[297, 332] -> 
             RGBColor[
              0.7675779370912612, 0.8188782351536849, 0.9773899044959016], 
             UndirectedEdge[189, 241] -> 
             RGBColor[
              0.8300158423561386, 0.8675172573295675, 0.9835901627098296], 
             UndirectedEdge[276, 358] -> 
             RGBColor[
              0.9841503914359345, 0.9865250621495542, 0.8590987300296633], 
             UndirectedEdge[11, 102] -> 
             RGBColor[
              0.53886778876819, 0.6318358319078476, 0.9587501504928011], 
             UndirectedEdge[96, 243] -> 
             RGBColor[
              0.7881996860080156, 0.8344668523397284, 0.9795240366225808], 
             UndirectedEdge[171, 397] -> 
             RGBColor[
              0.5984153536963027, 0.6845318305232615, 0.9617526712944865], 
             UndirectedEdge[314, 385] -> 
             RGBColor[
              0.5456703287440884, 0.642038780899449, 0.9573763136164617], 
             UndirectedEdge[11, 213] -> 
             RGBColor[
              0.6372290986083516, 0.7148578899672362, 0.965618208592398], 
             UndirectedEdge[68, 129] -> 
             RGBColor[
              0.6603144693379943, 0.727943997533779, 0.9441568356734817], 
             UndirectedEdge[137, 277] -> 
             RGBColor[
              0.958598541226941, 0.9686434403524953, 0.954966049859677], 
             UndirectedEdge[35, 327] -> 
             RGBColor[
              0.5578995609664129, 0.6519670225381654, 0.9583390435741567], 
             UndirectedEdge[155, 183] -> 
             RGBColor[
              0.9520217240734767, 0.9634401303827387, 0.9557555798965252], 
             UndirectedEdge[63, 256] -> 
             RGBColor[
              0.555026512962557, 0.638855703218862, 0.9615487898166247], 
             UndirectedEdge[144, 358] -> 
             RGBColor[
              0.9882139980333146, 0.9893941995474104, 0.8449880839907227], 
             UndirectedEdge[192, 332] -> 
             RGBColor[
              0.8106257644003795, 0.8511858008316804, 0.904829958508432], 
             UndirectedEdge[149, 259] -> 
             RGBColor[
              0.8899236661734864, 0.7549941677503591, 0.6097972622311365], 
             UndirectedEdge[146, 165] -> 
             RGBColor[
              0.3475285821394179, 0.47367319960943444`, 0.943429645916229], 
             UndirectedEdge[164, 280] -> 
             RGBColor[
              0.9455192576209839, 0.955781030440289, 0.8398003530943023], 
             UndirectedEdge[65, 105] -> 
             RGBColor[
              0.6956099427613733, 0.7594767231336745, 0.9604392481282998], 
             UndirectedEdge[73, 369] -> 
             RGBColor[
              0.7488650691859408, 0.7985443145034901, 0.751682432247562], 
             UndirectedEdge[187, 281] -> 
             RGBColor[
              0.7081231650891635, 0.7706078937763345, 0.972712030209105], 
             UndirectedEdge[53, 253] -> 
             RGBColor[
              0.8423242123092052, 0.876766086909307, 0.9384906969404252], 
             UndirectedEdge[132, 191] -> 
             RGBColor[
              0.9832184892962245, 0.9865924152447232, 0.894816423083965], 
             UndirectedEdge[29, 273] -> 
             RGBColor[
              0.6187119331182277, 0.7000338376012851, 0.9640175635887609], 
             UndirectedEdge[138, 366] -> 
             RGBColor[
              0.8372495640455353, 0.8729118763019785, 0.9432438617034358], 
             UndirectedEdge[229, 309] -> 
             RGBColor[
              0.4732384720407371, 0.5807368533313662, 0.9523645509041819], 
             UndirectedEdge[274, 287] -> 
             RGBColor[
              0.6271385180503232, 0.704656282802619, 0.9659238364171812], 
             UndirectedEdge[251, 312] -> 
             RGBColor[
              0.7413969549494221, 0.7979892886742241, 0.9748365986978484], 
             UndirectedEdge[339, 360] -> 
             RGBColor[
              0.7652970442311353, 0.8159579117627274, 0.9553514047142146], 
             UndirectedEdge[150, 365] -> 
             RGBColor[
              0.7090580801464043, 0.7726408283421553, 0.9716359409706513], 
             UndirectedEdge[61, 300] -> 
             RGBColor[
              0.6283484853698917, 0.7024707767912288, 0.9674895008219715], 
             UndirectedEdge[62, 389] -> 
             RGBColor[
              0.5975523254700101, 0.6817122338598012, 0.9628929142274242], 
             UndirectedEdge[374, 399] -> 
             RGBColor[
              0.8883728378192864, 0.9126655380911513, 0.9397210628925179], 
             UndirectedEdge[27, 51] -> 
             RGBColor[
              0.8849868377172869, 0.9109206317107172, 0.9816851621381832], 
             UndirectedEdge[58, 159] -> 
             RGBColor[
              0.7223962136013471, 0.7826824683976847, 0.9732750472618192], 
             UndirectedEdge[57, 153] -> 
             RGBColor[
              0.7130493092984994, 0.7751441927930927, 0.972481718931275], 
             UndirectedEdge[84, 264] -> 
             RGBColor[
              0.558060065259637, 0.6520973271540407, 0.9583516790600659], 
             UndirectedEdge[159, 201] -> 
             RGBColor[
              0.7590141472637735, 0.8117890400157326, 0.9765826793940686], 
             UndirectedEdge[80, 87] -> 
             RGBColor[
              0.8312114095860221, 0.8684078383574463, 0.9837208440779477], 
             UndirectedEdge[39, 288] -> 
             RGBColor[
              0.7529493840516824, 0.8070720146297826, 0.9759726771517443], 
             UndirectedEdge[91, 365] -> 
             RGBColor[
              0.7993489481057032, 0.8439329898433388, 0.971324522848618], 
             UndirectedEdge[5, 384] -> 
             RGBColor[
              0.6747392097313265, 0.7421551638289581, 0.9701372270456998], 
             UndirectedEdge[156, 381] -> 
             RGBColor[
              0.8873542251087321, 0.9104417400873771, 0.8748656860967834], 
             UndirectedEdge[2, 197] -> 
             RGBColor[
              0.7285914769098257, 0.7878028618908204, 0.973658252356391], 
             UndirectedEdge[238, 293] -> 
             RGBColor[
              0.6367340627379536, 0.4243053679900574, 0.5667521474672922], 
             UndirectedEdge[85, 325] -> 
             RGBColor[
              0.8471781080300973, 0.8814466567619672, 0.9836423271105645], 
             UndirectedEdge[146, 332] -> 
             RGBColor[
              0.4613846003016761, 0.567409072310961, 0.9520329439966936], 
             UndirectedEdge[197, 204] -> 
             RGBColor[
              0.8802384413245751, 0.9072847740258319, 0.9864461880433439], 
             UndirectedEdge[20, 130] -> 
             RGBColor[
              0.7787251535043055, 0.8272971455498535, 0.9681479546896907], 
             UndirectedEdge[167, 348] -> 
             RGBColor[
              0.824761045418209, 0.8607293981106605, 0.819988486504708], 
             UndirectedEdge[83, 237] -> 
             RGBColor[
              0.49659346123710113`, 0.6021959689695906, 0.9535128028318224], 
             UndirectedEdge[178, 334] -> 
             RGBColor[
              0.6021074072657998, 0.6868922245273941, 0.9624788309439196], 
             UndirectedEdge[178, 388] -> 
             RGBColor[
              0.6151816566812345, 0.6971059275387074, 0.9637819499398428], 
             UndirectedEdge[115, 184] -> 
             RGBColor[
              0.6333437271663587, 0.7114678417249041, 0.9654735069001963], 
             UndirectedEdge[165, 385] -> 
             RGBColor[
              0.47389705651960295`, 0.5824675771563064, 0.9520859234503962], 
             UndirectedEdge[202, 257] -> 
             RGBColor[
              0.968107712252011, 0.9753935563357392, 0.9235626342679426], 
             UndirectedEdge[35, 57] -> 
             RGBColor[
              0.591541217772968, 0.6792788350730949, 0.9609874380314181], 
             UndirectedEdge[115, 206] -> 
             RGBColor[
              0.6672399947692312, 0.7379825080197902, 0.9688427765117478], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.5268370150302354, 0.623644046521105, 0.9570402830904325], 
             UndirectedEdge[61, 98] -> 
             RGBColor[
              0.6424080066726418, 0.7133022320959372, 0.9556825296891888], 
             UndirectedEdge[33, 173] -> 
             RGBColor[
              0.7678826844510503, 0.8191787503365833, 0.9773441333324493], 
             UndirectedEdge[6, 185] -> 
             RGBColor[
              0.5997786214651264, 0.685789445655204, 0.9617568537462563], 
             UndirectedEdge[300, 363] -> 
             RGBColor[
              0.6549268942626796, 0.7254916587044885, 0.9691830535342557], 
             UndirectedEdge[34, 270] -> 
             RGBColor[
              0.9150692138381826, 0.849053278685513, 0.6280835619852145], 
             UndirectedEdge[162, 179] -> 
             RGBColor[
              0.8337784107431409, 0.7365681650142903, 0.6094320824124067], 
             UndirectedEdge[11, 250] -> 
             RGBColor[
              0.7363745793242007, 0.793980685112933, 0.9743585943214955], 
             UndirectedEdge[66, 314] -> 
             RGBColor[
              0.41515226003567524`, 0.5288829166141331, 0.9484837228240766], 
             UndirectedEdge[153, 327] -> 
             RGBColor[
              0.6794076524919443, 0.7478323802581631, 0.9698333244740136], 
             UndirectedEdge[153, 392] -> 
             RGBColor[
              0.8368761495573351, 0.8727663415318342, 0.9843031883045785], 
             UndirectedEdge[110, 369] -> 
             RGBColor[
              0.7820783264431674, 0.8255083329850951, 0.7542971015230211], 
             UndirectedEdge[321, 398] -> 
             RGBColor[
              0.7929516480426253, 0.8381791211974146, 0.9799976677885807], 
             UndirectedEdge[188, 278] -> 
             RGBColor[
              0.7358996568682297, 0.7917570919941921, 0.9440601185187224], 
             UndirectedEdge[213, 289] -> 
             RGBColor[
              0.5236034162724215, 0.6241238672518716, 0.9556391254329282], 
             UndirectedEdge[236, 263] -> 
             RGBColor[
              0.8936741248049757, 0.9180423791048838, 0.9892655380463469], 
             UndirectedEdge[93, 383] -> 
             RGBColor[
              0.7363599086546087, 0.7935770850944882, 0.9748827551306785], 
             UndirectedEdge[56, 286] -> 
             RGBColor[
              0.7446792599795165, 0.8004683647587765, 0.9751863272775643], 
             UndirectedEdge[25, 144] -> 
             RGBColor[
              0.7364905297839132, 0.7916019077808384, 0.924177705681533], 
             UndirectedEdge[143, 331] -> 
             RGBColor[
              0.6186494128180773, 0.7007872637255093, 0.9634628175069951], 
             UndirectedEdge[76, 257] -> 
             RGBColor[
              0.9080398597849406, 0.9291424449942571, 0.978335266500006], 
             UndirectedEdge[91, 189] -> 
             RGBColor[
              0.9066092923923091, 0.9281088918449709, 0.9819135139788671], 
             UndirectedEdge[133, 145] -> 
             RGBColor[
              0.9081266016265315, 0.9258981674395721, 0.8308046699777497], 
             UndirectedEdge[207, 230] -> 
             RGBColor[
              0.49313635862052285`, 0.5864270169827867, 0.9560389729139493], 
             UndirectedEdge[238, 336] -> 
             RGBColor[
              0.6107532403117659, 0.6921659709406967, 0.9641489454282189], 
             UndirectedEdge[123, 306] -> 
             RGBColor[
              0.5209484598346208, 0.6081540418310382, 0.9588110232441078], 
             UndirectedEdge[272, 338] -> 
             RGBColor[
              0.7183811755968225, 0.77926262588883, 0.9731434179257172], 
             UndirectedEdge[11, 289] -> 
             RGBColor[
              0.6274637944392956, 0.7069299761208571, 0.964849448076722], 
             UndirectedEdge[215, 300] -> 
             RGBColor[
              0.6745374889898241, 0.7424773701999909, 0.9704326232893012], 
             UndirectedEdge[224, 289] -> 
             RGBColor[
              0.6327066620610652, 0.7110257441542531, 0.9653720081238766], 
             UndirectedEdge[65, 161] -> 
             RGBColor[
              0.8489556633904514, 0.8826323547735015, 0.9735466192593139], 
             UndirectedEdge[14, 247] -> 
             RGBColor[
              0.42505636459965096`, 0.5419892094987313, 0.9484695889897895], 
             UndirectedEdge[150, 226] -> 
             RGBColor[
              0.6457487152809983, 0.721404705283847, 0.9665417337258675], 
             UndirectedEdge[15, 180] -> 
             RGBColor[
              0.9310420658787943, 0.9457325504589423, 0.9122100019886284], 
             UndirectedEdge[7, 114] -> 
             RGBColor[
              0.7269508500138884, 0.7866187961527217, 0.973419325053601], 
             UndirectedEdge[108, 313] -> 
             RGBColor[
              0.4646140121291003, 0.5761438372614078, 0.9510200683502344], 
             UndirectedEdge[227, 315] -> 
             RGBColor[
              0.7106311229655254, 0.7736728506778097, 0.971927315056264], 
             UndirectedEdge[174, 384] -> 
             RGBColor[
              0.5096338408396088, 0.6116930762329108, 0.9548404656868403], 
             UndirectedEdge[104, 138] -> 
             RGBColor[
              0.6107836465652583, 0.6941228051776803, 0.9630341272998202], 
             UndirectedEdge[313, 344] -> 
             RGBColor[
              0.49709119068062435`, 0.6026000481542988, 0.9535519859168595], 
             UndirectedEdge[255, 374] -> 
             RGBColor[
              0.8044251344310092, 0.8468026297925488, 0.9315469670789491], 
             UndirectedEdge[87, 167] -> 
             RGBColor[
              0.7583871747369157, 0.8115169926086401, 0.9764624049293561], 
             UndirectedEdge[114, 312] -> 
             RGBColor[
              0.6747060530401195, 0.74580476368165, 0.968212051946642], 
             UndirectedEdge[50, 265] -> 
             RGBColor[
              0.6702502424148804, 0.7414221159049341, 0.9683844592910558], 
             UndirectedEdge[310, 345] -> 
             RGBColor[
              0.7812759822008621, 0.8157424043977333, 0.6799142393453312], 
             UndirectedEdge[315, 334] -> 
             RGBColor[
              0.7485445223424889, 0.8034879370938125, 0.9755715805069749], 
             UndirectedEdge[102, 302] -> 
             RGBColor[
              0.35791686486505647`, 0.48443133174658465`, 0.9440271240291129],
              UndirectedEdge[172, 211] -> 
             RGBColor[
              0.9541746148850205, 0.9648426719747255, 0.9432866984021382], 
             UndirectedEdge[264, 381] -> 
             RGBColor[
              0.7909112605837787, 0.8342844145525594, 0.8658106110316159], 
             UndirectedEdge[270, 397] -> 
             RGBColor[
              0.7142846185916569, 0.7756600848872017, 0.9731394808459496], 
             UndirectedEdge[48, 290] -> 
             RGBColor[
              0.5791581235686378, 0.6584958827734088, 0.9637901464435579], 
             UndirectedEdge[224, 323] -> 
             RGBColor[
              0.5401487602256537, 0.6325000046144134, 0.9590202620197332], 
             UndirectedEdge[10, 339] -> 
             RGBColor[
              0.5164808922015731, 0.6183414813451041, 0.9550784142474056], 
             UndirectedEdge[254, 320] -> 
             RGBColor[
              0.4404242619118525, 0.5554617344338035, 0.949404160432098], 
             UndirectedEdge[92, 392] -> 
             RGBColor[
              0.8526180428579488, 0.8853184999474331, 0.9858046641405451], 
             UndirectedEdge[166, 224] -> 
             RGBColor[
              0.7606163603277714, 0.8129185486772819, 0.976774788499608], 
             UndirectedEdge[108, 344] -> 
             RGBColor[
              0.482488861321455, 0.590655445088541, 0.9524272419563866], 
             UndirectedEdge[180, 271] -> 
             RGBColor[
              0.8374954093901321, 0.8734085144423107, 0.984322875204884], 
             UndirectedEdge[104, 207] -> 
             RGBColor[
              0.6344683583302217, 0.7126254820189463, 0.9653947980223363], 
             UndirectedEdge[45, 266] -> 
             RGBColor[
              0.9209392548560578, 0.9397959798648294, 0.9923212023319907], 
             UndirectedEdge[59, 373] -> 
             RGBColor[
              0.6828245037403531, 0.7453642251711124, 0.895079515538004], 
             UndirectedEdge[107, 352] -> 
             RGBColor[
              0.5749774802681883, 0.6653871712566144, 0.9599873702821236], 
             UndirectedEdge[99, 338] -> 
             RGBColor[
              0.7011698239407244, 0.7652896752518534, 0.9717884772760906], 
             UndirectedEdge[186, 341] -> 
             RGBColor[
              0.8952208188905957, 0.9189022644457722, 0.9764668239911231], 
             UndirectedEdge[90, 156] -> 
             RGBColor[
              0.5807832466575673, 0.6664025611734704, 0.962156711583782], 
             UndirectedEdge[34, 151] -> 
             RGBColor[
              0.9201851474742702, 0.85313258529861, 0.6285715243024724], 
             UndirectedEdge[174, 260] -> 
             RGBColor[
              0.6155405151831597, 0.6987625458667162, 0.9628767506358714], 
             UndirectedEdge[13, 216] -> 
             RGBColor[
              0.7940624973769562, 0.8397745616201496, 0.9700492187376628], 
             UndirectedEdge[9, 217] -> 
             RGBColor[
              0.8423393249025002, 0.8770495097113848, 0.9519249258812676], 
             UndirectedEdge[87, 159] -> 
             RGBColor[
              0.8485670941773487, 0.8820883834295952, 0.9854182810390648], 
             UndirectedEdge[184, 305] -> 
             RGBColor[
              0.5794172404887097, 0.6663041726303789, 0.96161054169419], 
             UndirectedEdge[12, 259] -> 
             RGBColor[
              0.9412407024868812, 0.9530317196462317, 0.877013330786113], 
             UndirectedEdge[27, 287] -> 
             RGBColor[
              0.684890109824644, 0.7504979678282429, 0.9642253682440607], 
             UndirectedEdge[188, 284] -> 
             RGBColor[
              0.9706375040283111, 0.9776220790977647, 0.9345872261013353], 
             UndirectedEdge[118, 126] -> 
             RGBColor[
              0.5627709039261921, 0.6559217982044137, 0.9587225335362677], 
             UndirectedEdge[209, 304] -> 
             RGBColor[
              0.400671010525245, 0.5212921622062056, 0.9467985347001558], 
             UndirectedEdge[48, 108] -> 
             RGBColor[
              0.6650428237359522, 0.7357051704751818, 0.9691593794329902], 
             UndirectedEdge[136, 376] -> 
             RGBColor[
              0.897141900619105, 0.9200210458213128, 0.9623298047276483], 
             UndirectedEdge[48, 344] -> 
             RGBColor[
              0.6975200022874762, 0.7621613813680728, 0.9716912969996154], 
             UndirectedEdge[13, 198] -> 
             RGBColor[
              0.8172916187655124, 0.8537468527279254, 0.7284474303569851], 
             UndirectedEdge[286, 320] -> 
             RGBColor[
              0.5969498453391214, 0.6803920864791249, 0.9631924070886062], 
             UndirectedEdge[176, 368] -> 
             RGBColor[
              0.8771540775954658, 0.9043869498609036, 0.962476181622264], 
             UndirectedEdge[248, 388] -> 
             RGBColor[
              0.8615149386715693, 0.8904660663153336, 0.8818204118057908], 
             UndirectedEdge[57, 188] -> 
             RGBColor[
              0.7843676921306211, 0.8311056264803074, 0.947875699798841], 
             UndirectedEdge[39, 225] -> 
             RGBColor[
              0.8897946602016316, 0.9148017739467416, 0.9837911146017579], 
             UndirectedEdge[355, 379] -> 
             RGBColor[
              0.860143925181019, 0.8910384397462726, 0.9577410592469775], 
             UndirectedEdge[85, 348] -> 
             RGBColor[
              0.8758775776505838, 0.9006620215906255, 0.8250833047264785], 
             UndirectedEdge[118, 336] -> 
             RGBColor[
              0.6653845242520353, 0.7370183729847932, 0.9683114956131503], 
             UndirectedEdge[195, 392] -> 
             RGBColor[
              0.7604133928547248, 0.8129667098376742, 0.9766997012298306], 
             UndirectedEdge[193, 281] -> 
             RGBColor[
              0.8999571440097363, 0.9230654142201993, 0.9903199098685171], 
             UndirectedEdge[154, 312] -> 
             RGBColor[
              0.591782483998508, 0.6793226837082951, 0.9611103697705414], 
             UndirectedEdge[53, 171] -> 
             RGBColor[
              0.8241359446211354, 0.8625572739554326, 0.9366778603963037], 
             UndirectedEdge[115, 188] -> 
             RGBColor[
              0.7405194104705233, 0.7955076160860621, 0.94442380244501], 
             UndirectedEdge[319, 329] -> 
             RGBColor[
              0.8886366771162615, 0.9135865948530494, 0.9735625689383272], 
             UndirectedEdge[231, 359] -> 
             RGBColor[
              0.5206539124135713, 0.6152021516167586, 0.9576294176674304], 
             UndirectedEdge[288, 399] -> 
             RGBColor[
              0.7300255425897202, 0.7890207693614903, 0.9737257816749241], 
             UndirectedEdge[140, 220] -> 
             RGBColor[
              0.8178908264516515, 0.8555536573559943, 0.8367095108585034], 
             UndirectedEdge[9, 215] -> 
             RGBColor[
              0.5696145272567538, 0.659683887009182, 0.9601943083787631], 
             UndirectedEdge[309, 329] -> 
             RGBColor[
              0.657267525076831, 0.7260025423214149, 0.9541445522340473], 
             UndirectedEdge[9, 61] -> 
             RGBColor[
              0.5234255236368214, 0.61967729360042, 0.9572511859114332], 
             UndirectedEdge[21, 82] -> 
             RGBColor[
              0.5452227872631209, 0.6395688783334488, 0.958211808239212], 
             UndirectedEdge[154, 361] -> 
             RGBColor[
              0.759142155758096, 0.809625416638591, 0.9106564434486393], 
             UndirectedEdge[160, 213] -> 
             RGBColor[
              0.7481771077555677, 0.7594276529642305, 0.6335569766036533], 
             UndirectedEdge[331, 342] -> 
             RGBColor[
              0.7294005127495002, 0.7879249143412645, 0.9743374407571319], 
             UndirectedEdge[122, 159] -> 
             RGBColor[
              0.8975796704181326, 0.9205414165876263, 0.9683108118884951], 
             UndirectedEdge[258, 278] -> 
             RGBColor[
              0.7480398334495796, 0.7988485857356464, 0.8314655823428443], 
             UndirectedEdge[37, 201] -> 
             RGBColor[
              0.8003671582447182, 0.8447628084743579, 0.9805269664976999], 
             UndirectedEdge[61, 314] -> 
             RGBColor[
              0.4416541041290034, 0.5543651224128412, 0.950079847595612], 
             UndirectedEdge[297, 314] -> 
             RGBColor[
              0.7254951911534885, 0.7847135661953009, 0.9740769965815025], 
             UndirectedEdge[84, 175] -> 
             RGBColor[
              0.565851173376475, 0.6584224997087107, 0.9589650236307927], 
             UndirectedEdge[72, 374] -> 
             RGBColor[
              0.7965327723594746, 0.8403952547160175, 0.930925651426003], 
             UndirectedEdge[168, 180] -> 
             RGBColor[
              0.6984633430455904, 0.7629757660302056, 0.9717096937334263], 
             UndirectedEdge[36, 60] -> 
             RGBColor[
              0.8932617564575563, 0.9169997202319543, 0.9644766634398478], 
             UndirectedEdge[347, 387] -> 
             RGBColor[
              0.7005081594584064, 0.7654581066830675, 0.9711279821989729], 
             UndirectedEdge[140, 141] -> 
             RGBColor[
              0.9029831439055511, 0.9220541904828298, 0.8451731001027626], 
             UndirectedEdge[233, 382] -> 
             RGBColor[
              0.8399081997983671, 0.8756225430281889, 0.9844760163977081], 
             UndirectedEdge[21, 122] -> 
             RGBColor[
              0.6809467056971763, 0.7461013717008453, 0.9496567161314245], 
             UndirectedEdge[202, 268] -> 
             RGBColor[
              0.9376776538355689, 0.9514973611420148, 0.9334157681456241], 
             UndirectedEdge[196, 344] -> 
             RGBColor[
              0.587933711242681, 0.6760660531027765, 0.9608976454666984], 
             UndirectedEdge[109, 343] -> 
             RGBColor[
              0.8938282115784076, 0.913660841750356, 0.7448271177742072], 
             UndirectedEdge[52, 117] -> 
             RGBColor[
              0.6030790509297288, 0.6886457678032138, 0.9618957385219937], 
             UndirectedEdge[51, 194] -> 
             RGBColor[
              0.8808503039896398, 0.9078301386295302, 0.9884974824105228], 
             UndirectedEdge[223, 342] -> 
             RGBColor[
              0.6595366055534863, 0.7303728002464974, 0.9690677819244335], 
             UndirectedEdge[241, 374] -> 
             RGBColor[
              0.8887727770909358, 0.9129779736898148, 0.9397609251014709], 
             UndirectedEdge[76, 109] -> 
             RGBColor[
              0.8302470483794169, 0.8676874205144895, 0.9836159820568482], 
             UndirectedEdge[90, 381] -> 
             RGBColor[
              0.686118165305716, 0.7472056083961975, 0.858114363532342], 
             UndirectedEdge[75, 227] -> 
             RGBColor[
              0.7889767459116566, 0.8355866681174605, 0.968065011398098], 
             UndirectedEdge[209, 329] -> 
             RGBColor[
              0.7064188037294106, 0.768404247849792, 0.9573235825626027], 
             UndirectedEdge[24, 358] -> 
             RGBColor[
              0.8001563375301665, 0.8420738275247279, 0.8784041692362178], 
             UndirectedEdge[208, 369] -> 
             RGBColor[
              0.9934784554149968, 0.9901556913626224, 0.654850740937515], 
             UndirectedEdge[62, 400] -> 
             RGBColor[
              0.7523111647165037, 0.8064304667439353, 0.9759470042175424], 
             UndirectedEdge[127, 325] -> 
             RGBColor[
              0.7946756628241591, 0.8404313475337257, 0.9784093740356825], 
             UndirectedEdge[43, 277] -> 
             RGBColor[
              0.6842662452401009, 0.7481842084617497, 0.9383038868371447], 
             UndirectedEdge[70, 227] -> 
             RGBColor[
              0.6365370821377729, 0.7157900228476023, 0.9645423135147324], 
             UndirectedEdge[25, 366] -> 
             RGBColor[
              0.734588056360675, 0.7903445399657265, 0.9346301169704558], 
             UndirectedEdge[20, 387] -> 
             RGBColor[
              0.6097518586602133, 0.6940630537253837, 0.9624210463898376], 
             UndirectedEdge[328, 387] -> 
             RGBColor[
              0.6779105173866765, 0.7478046569481913, 0.9688756604242345], 
             UndirectedEdge[249, 386] -> 
             RGBColor[
              0.6816753555070244, 0.7496048075314742, 0.9700907993224788], 
             UndirectedEdge[110, 243] -> 
             RGBColor[
              0.6765452678151368, 0.7461410207375683, 0.9691478207615218], 
             UndirectedEdge[47, 121] -> 
             RGBColor[
              0.9407831683664702, 0.9535577467587955, 0.915653577739724], 
             UndirectedEdge[31, 156] -> 
             RGBColor[
              0.8525548283996686, 0.8855749489387249, 0.9857172049438296], 
             UndirectedEdge[98, 283] -> 
             RGBColor[
              0.7299052674968174, 0.7875650516062465, 0.9616785623694597], 
             UndirectedEdge[38, 358] -> 
             RGBColor[
              0.9170701925826039, 0.660614074147356, 0.4915672412379537], 
             UndirectedEdge[126, 199] -> 
             RGBColor[
              0.5805792051357943, 0.6703793793811959, 0.9601244682414444], 
             UndirectedEdge[39, 200] -> 
             RGBColor[
              0.5082995353494917, 0.5893974937227403, 0.9589400519867981], 
             UndirectedEdge[227, 304] -> 
             RGBColor[
              0.48562367708785903`, 0.5902605639957512, 0.9534863198038361], 
             UndirectedEdge[242, 333] -> 
             RGBColor[
              0.9924857460959753, 0.9889593312154754, 0.6141795527946416], 
             UndirectedEdge[30, 333] -> 
             RGBColor[
              0.9738664663986155, 0.9764103716683639, 0.7055827641291339], 
             UndirectedEdge[85, 96] -> 
             RGBColor[
              0.775397233469394, 0.8244654791143141, 0.9782480077992521], 
             UndirectedEdge[39, 94] -> 
             RGBColor[
              0.6433347325710053, 0.7183608480359901, 0.9671048994040337], 
             UndirectedEdge[63, 138] -> 
             RGBColor[
              0.7640453582922317, 0.8157182781903852, 0.9770844571881868], 
             UndirectedEdge[119, 324] -> 
             RGBColor[
              0.586804494735965, 0.6754333499247149, 0.9606145458427571], 
             UndirectedEdge[18, 224] -> 
             RGBColor[
              0.6253263466007417, 0.7050340715841401, 0.9647910026558535], 
             UndirectedEdge[84, 204] -> 
             RGBColor[
              0.7324574182535105, 0.7900490296309111, 0.9729306086733867], 
             UndirectedEdge[241, 288] -> 
             RGBColor[
              0.7304254818613696, 0.789333204960154, 0.9737656438838771], 
             UndirectedEdge[91, 266] -> 
             RGBColor[
              0.9287681026042107, 0.9457777256230614, 0.9840270410782817], 
             UndirectedEdge[201, 263] -> 
             RGBColor[
              0.809569680028015, 0.8520875233991072, 0.9809496193990761], 
             UndirectedEdge[29, 266] -> 
             RGBColor[
              0.7108519781710211, 0.7727558497502904, 0.9730044485819604], 
             UndirectedEdge[161, 326] -> 
             RGBColor[
              0.6778527244447528, 0.7477158407465023, 0.9688997561566981], 
             UndirectedEdge[174, 235] -> 
             RGBColor[
              0.7720045597284897, 0.8221551806587198, 0.9760439045162494], 
             UndirectedEdge[207, 233] -> 
             RGBColor[
              0.7531189758555124, 0.8070615349453207, 0.9760275192824546], 
             UndirectedEdge[199, 212] -> 
             RGBColor[
              0.775270787353717, 0.8237223422270923, 0.9472130092541565], 
             UndirectedEdge[127, 184] -> 
             RGBColor[
              0.7042215168081908, 0.7688624683031002, 0.9711538775373523], 
             UndirectedEdge[261, 381] -> 
             RGBColor[
              0.8873542251087321, 0.9104417400873771, 0.8748656860967834], 
             UndirectedEdge[221, 230] -> 
             RGBColor[
              0.6181246752326313, 0.6776063020661758, 0.6774239292483515], 
             UndirectedEdge[22, 273] -> 
             RGBColor[
              0.5278315122802966, 0.6228562616080132, 0.9578016578244053], 
             UndirectedEdge[240, 292] -> 
             RGBColor[
              0.8196990667515962, 0.859404741400802, 0.9825759401837983], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.8522231839455323, 0.8852099065369623, 0.9751347473973496], 
             UndirectedEdge[120, 343] -> 
             RGBColor[
              0.9384022586194098, 0.9489960326108069, 0.7491335468322116], 
             UndirectedEdge[175, 310] -> 
             RGBColor[
              0.590645867998445, 0.6785519497910897, 0.9609169528173933], 
             UndirectedEdge[55, 201] -> 
             RGBColor[
              0.8385210505030234, 0.8720315420162843, 0.8581476910809456], 
             UndirectedEdge[264, 333] -> 
             RGBColor[
              0.7909318221548118, 0.832091571355827, 0.7054552417197759], 
             UndirectedEdge[107, 197] -> 
             RGBColor[
              0.746961488662994, 0.8022719894694118, 0.9754082973152222], 
             UndirectedEdge[131, 300] -> 
             RGBColor[
              0.8964171332068505, 0.9202427056970115, 0.9899822604779329], 
             UndirectedEdge[164, 227] -> 
             RGBColor[
              0.8122198310165738, 0.8508343764967063, 0.8268121757714977], 
             UndirectedEdge[75, 315] -> 
             RGBColor[
              0.8700991991310751, 0.8991569957961614, 0.976015951524259], 
             UndirectedEdge[123, 193] -> 
             RGBColor[
              0.846819857628737, 0.8808879579711495, 0.9852004718875544], 
             UndirectedEdge[157, 253] -> 
             RGBColor[
              0.8218749279428383, 0.8615692549594365, 0.9755336738749547], 
             UndirectedEdge[87, 110] -> 
             RGBColor[
              0.7162763450902798, 0.7775191409296538, 0.9730176440528022], 
             UndirectedEdge[112, 273] -> 
             RGBColor[
              0.6534819544465826, 0.7282617072872541, 0.9667547870345137], 
             UndirectedEdge[193, 384] -> 
             RGBColor[
              0.6553463577825864, 0.7267071160951795, 0.9688174949108941], 
             UndirectedEdge[95, 249] -> 
             RGBColor[
              0.5615937913554614, 0.6549661651911773, 0.9586298669227944], 
             UndirectedEdge[61, 66] -> 
             RGBColor[
              0.30790924297053684`, 0.4385896026512286, 0.9409332318814285], 
             UndirectedEdge[113, 251] -> 
             RGBColor[
              0.9102054488384137, 0.9288911467880587, 0.9003719402602492], 
             UndirectedEdge[107, 131] -> 
             RGBColor[
              0.770961280406522, 0.8214087719487086, 0.9776974188765869], 
             UndirectedEdge[71, 343] -> 
             RGBColor[
              0.7733950701849943, 0.8182165661660151, 0.733753984185983], 
             UndirectedEdge[113, 168] -> 
             RGBColor[
              0.7567302157027667, 0.8070902011552092, 0.8863417779913222], 
             UndirectedEdge[58, 201] -> 
             RGBColor[
              0.6463134092934784, 0.723123851060332, 0.9657242398434935], 
             UndirectedEdge[47, 130] -> 
             RGBColor[
              0.9202950604539969, 0.9389795481993377, 0.981762583305545], 
             UndirectedEdge[17, 82] -> 
             RGBColor[
              0.8270413713011133, 0.8652185012001103, 0.9564679236050952], 
             UndirectedEdge[11, 25] -> 
             RGBColor[
              0.6144532403801728, 0.6963674222168801, 0.963825209601958], 
             UndirectedEdge[73, 392] -> 
             RGBColor[
              0.6748244450904519, 0.7439858523570984, 0.9696171656778307], 
             UndirectedEdge[155, 337] -> 
             RGBColor[
              0.8692441217496384, 0.8979318642938032, 0.9477284630404141], 
             UndirectedEdge[159, 165] -> 
             RGBColor[
              0.6202237641584065, 0.6984318431212728, 0.9655915225092617], 
             UndirectedEdge[226, 368] -> 
             RGBColor[
              0.7453026598458813, 0.799605254150579, 0.950550343107887], 
             UndirectedEdge[188, 258] -> 
             RGBColor[
              0.982969290062411, 0.9848564748553483, 0.8216683451017006], 
             UndirectedEdge[140, 350] -> 
             RGBColor[
              0.6543228617480108, 0.7189665402245657, 0.8248814872243639], 
             UndirectedEdge[14, 38] -> 
             RGBColor[
              0.6088792146827461, 0.41484919250312347`, 0.5668999821760634], 
             UndirectedEdge[242, 268] -> 
             RGBColor[
              0.9406735685642753, 0.9527362488738313, 0.8837657079121768], 
             UndirectedEdge[20, 50] -> 
             RGBColor[
              0.6835083190727078, 0.7521856198053053, 0.9694281836514949], 
             UndirectedEdge[149, 212] -> 
             RGBColor[
              0.9305963159839621, 0.7865210819621101, 0.5823221794536156], 
             UndirectedEdge[80, 361] -> 
             RGBColor[
              0.8936939346441876, 0.9164398465313813, 0.9229039430889856], 
             UndirectedEdge[31, 204] -> 
             RGBColor[
              0.9305092168685887, 0.9473693258807776, 0.991241059491983], 
             UndirectedEdge[209, 245] -> 
             RGBColor[
              0.4759784282719641, 0.5854597565118407, 0.9518899119214528], 
             UndirectedEdge[113, 148] -> 
             RGBColor[
              0.9921584397131726, 0.9902790590183881, 0.7253726332626109], 
             UndirectedEdge[48, 231] -> 
             RGBColor[
              0.8108385110673063, 0.8526381593519321, 0.9816515773163288], 
             UndirectedEdge[198, 224] -> 
             RGBColor[
              0.8723450534264547, 0.8967686580405958, 0.733925313924979], 
             UndirectedEdge[1, 188] -> 
             RGBColor[
              0.9816335098119192, 0.9819592021243588, 0.6796930019671064], 
             UndirectedEdge[256, 264] -> 
             RGBColor[
              0.4321178530530837, 0.5419022050610054, 0.9498879633542241], 
             UndirectedEdge[15, 170] -> 
             RGBColor[
              0.9635163899613606, 0.8913742488475551, 0.5529306174122768], 
             UndirectedEdge[20, 322] -> 
             RGBColor[
              0.7901172817431319, 0.802747243804977, 0.650634375369445], 
             UndirectedEdge[92, 153] -> 
             RGBColor[
              0.8439342411174313, 0.8783942721550633, 0.9849763953784132], 
             UndirectedEdge[189, 360] -> 
             RGBColor[
              0.9140506934951478, 0.9336586766032919, 0.9693171629400036], 
             UndirectedEdge[272, 342] -> 
             RGBColor[
              0.7379846903249333, 0.7948939364097939, 0.9750132186607485], 
             UndirectedEdge[69, 219] -> 
             RGBColor[
              0.7828069630385694, 0.8302540161697846, 0.9789865403948478], 
             UndirectedEdge[86, 151] -> 
             RGBColor[
              0.8487387795511598, 0.8824534566924946, 0.9853741056470353], 
             UndirectedEdge[72, 288] -> 
             RGBColor[
              0.6381854771299083, 0.7167504859863567, 0.9649303702084093], 
             UndirectedEdge[266, 273] -> 
             RGBColor[
              0.8195849937649292, 0.859726801960087, 0.982455457187427], 
             UndirectedEdge[131, 297] -> 
             RGBColor[
              0.8863208219253088, 0.912192181138179, 0.989019265294816], 
             UndirectedEdge[219, 360] -> 
             RGBColor[
              0.8628825227747401, 0.8933024069078823, 0.9643189154596685], 
             UndirectedEdge[58, 236] -> 
             RGBColor[
              0.7304178540704389, 0.7890787067661086, 0.9740401584907643], 
             UndirectedEdge[272, 321] -> 
             RGBColor[
              0.6869496830192064, 0.7544069512123459, 0.9700905374449275], 
             UndirectedEdge[250, 391] -> 
             RGBColor[
              0.8080116634374259, 0.8504644763875355, 0.9813606227097234], 
             UndirectedEdge[122, 298] -> 
             RGBColor[
              0.8886906946323114, 0.5519310879110837, 0.5583530684822979], 
             UndirectedEdge[113, 282] -> 
             RGBColor[
              0.7542350191802528, 0.8050644882109101, 0.8861453469808638], 
             UndirectedEdge[237, 343] -> 
             RGBColor[
              0.7452652984858684, 0.7953795502688911, 0.7315395055150788], 
             UndirectedEdge[174, 398] -> 
             RGBColor[
              0.6988019631432114, 0.7640729396511241, 0.9709936641750376], 
             UndirectedEdge[223, 384] -> 
             RGBColor[
              0.4179047181293986, 0.5363897951669855, 0.9478494969939408], 
             UndirectedEdge[143, 260] -> 
             RGBColor[
              0.6499741074568774, 0.7262180619946992, 0.9659288122150987], 
             UndirectedEdge[148, 161] -> 
             RGBColor[
              0.8717397959802269, 0.897179719622939, 0.8046603397349048], 
             UndirectedEdge[137, 199] -> 
             RGBColor[
              0.7618698496268124, 0.8137279448123886, 0.9698973013014764], 
             UndirectedEdge[147, 387] -> 
             RGBColor[
              0.4754414997937909, 0.5819847345156952, 0.9526873606539621], 
             UndirectedEdge[138, 381] -> 
             RGBColor[
              0.8429145815558605, 0.8757251527900735, 0.8704363577395136], 
             UndirectedEdge[42, 207] -> 
             RGBColor[
              0.5685598666088395, 0.6575782520256521, 0.9606316768816939], 
             UndirectedEdge[185, 247] -> 
             RGBColor[
              0.5104410096180373, 0.6134380325701801, 0.9546029325656108], 
             UndirectedEdge[49, 380] -> 
             RGBColor[
              0.7502913434538434, 0.7995085874549474, 0.7359239508983131], 
             UndirectedEdge[63, 242] -> 
             RGBColor[
              0.9135959612613134, 0.9311452998125196, 0.8811830215551548], 
             UndirectedEdge[12, 238] -> 
             RGBColor[
              0.7139757878947912, 0.7712510183506074, 0.856821739577265], 
             UndirectedEdge[109, 382] -> 
             RGBColor[
              0.8542341483139301, 0.886814082889788, 0.985903893062139], 
             UndirectedEdge[4, 115] -> 
             RGBColor[
              0.7420450416998152, 0.7966454293588762, 0.9418413067221703], 
             UndirectedEdge[187, 279] -> 
             RGBColor[
              0.6275164854038695, 0.7069711387028483, 0.9648546998196457], 
             UndirectedEdge[152, 156] -> 
             RGBColor[
              0.8395437058744278, 0.8752002330146104, 0.984476192462206], 
             UndirectedEdge[143, 290] -> 
             RGBColor[
              0.47659525152064686`, 0.5778873028083773, 0.9536965236786601], 
             UndirectedEdge[48, 234] -> 
             RGBColor[
              0.6055623021161005, 0.6841861322260088, 0.9653693331919333], 
             UndirectedEdge[294, 341] -> 
             RGBColor[
              0.6354862144133359, 0.7114912844400629, 0.9666377471270644], 
             UndirectedEdge[243, 351] -> 
             RGBColor[
              0.5621568833311902, 0.6502457370571638, 0.9609798466803722], 
             UndirectedEdge[241, 399] -> 
             RGBColor[
              0.7922243270467082, 0.8376109325075598, 0.9799251752289088], 
             UndirectedEdge[78, 207] -> 
             RGBColor[
              0.7407994598299965, 0.7974374353943982, 0.974799625057454], 
             UndirectedEdge[174, 267] -> 
             RGBColor[
              0.8005145495429977, 0.8413428285752925, 0.826819043572447], 
             UndirectedEdge[124, 293] -> 
             RGBColor[
              0.697558597777648, 0.4741857302794498, 0.5714022530653966], 
             UndirectedEdge[57, 392] -> 
             RGBColor[
              0.7217331110390169, 0.7820684205854624, 0.9733099876934068], 
             UndirectedEdge[272, 331] -> 
             RGBColor[
              0.5709347826055963, 0.6625496026948974, 0.9593652239711834], 
             UndirectedEdge[91, 255] -> 
             RGBColor[
              0.7848700736946015, 0.832339658724361, 0.9700744306843774], 
             UndirectedEdge[35, 337] -> 
             RGBColor[
              0.6718755217449016, 0.7427175630160439, 0.968528835217406], 
             UndirectedEdge[219, 339] -> 
             RGBColor[
              0.6674855984094996, 0.7390541120169374, 0.9682512822756735], 
             UndirectedEdge[166, 185] -> 
             RGBColor[
              0.6576543916788786, 0.7310024372183326, 0.9675253696413402], 
             UndirectedEdge[137, 238] -> 
             RGBColor[
              0.6894302644769409, 0.7544179615915099, 0.9643328164113683], 
             UndirectedEdge[218, 300] -> 
             RGBColor[
              0.9531370145072235, 0.9492600704882137, 0.6923735212632707], 
             UndirectedEdge[96, 110] -> 
             RGBColor[
              0.6821698715903832, 0.7505350039553629, 0.9697084287009278], 
             UndirectedEdge[225, 375] -> 
             RGBColor[
              0.7748215294836835, 0.824310388000157, 0.9727323367947761], 
             UndirectedEdge[24, 25] -> 
             RGBColor[
              0.5484328692807651, 0.6442815357581559, 0.9575937909270282], 
             UndirectedEdge[40, 361] -> 
             RGBColor[
              0.90639908114084, 0.9264121787623307, 0.9241578075750485], 
             UndirectedEdge[141, 394] -> 
             RGBColor[
              0.6708414707292153, 0.7410771093112041, 0.9689950547413907], 
             UndirectedEdge[200, 360] -> 
             RGBColor[
              0.5698104842981879, 0.6378001033268361, 0.9424600189491048], 
             UndirectedEdge[68, 229] -> 
             RGBColor[
              0.47048860045633956`, 0.5783550527775255, 0.9521893315184401], 
             UndirectedEdge[96, 258] -> 
             RGBColor[
              0.8944668782135115, 0.9154044020771628, 0.8445792267439045], 
             UndirectedEdge[106, 310] -> 
             RGBColor[
              0.7195612974041949, 0.7801823284695635, 0.9732804885933166], 
             UndirectedEdge[15, 394] -> 
             RGBColor[
              0.7597696886232224, 0.8097931859962576, 0.8964218587277825], 
             UndirectedEdge[115, 203] -> 
             RGBColor[
              0.614407490268423, 0.6966747095395058, 0.963586119775405], 
             UndirectedEdge[218, 298] -> 
             RGBColor[
              0.9006535726692643, 0.5458886979219533, 0.2782576987677812], 
             UndirectedEdge[165, 262] -> 
             RGBColor[
              0.4362558402356147, 0.5519087420594952, 0.9491226690202021], 
             UndirectedEdge[141, 357] -> 
             RGBColor[
              0.7257438738996156, 0.7856493535300121, 0.9733171730330941], 
             UndirectedEdge[15, 239] -> 
             RGBColor[
              0.7884509596614859, 0.8330779339016559, 0.8986797534468722], 
             UndirectedEdge[80, 228] -> 
             RGBColor[
              0.6864452058655589, 0.7539054022871007, 0.970113718345857], 
             UndirectedEdge[260, 272] -> 
             RGBColor[
              0.6022594772443963, 0.6879804009640873, 0.961831218679287], 
             UndirectedEdge[7, 361] -> 
             RGBColor[
              0.8718874121135669, 0.899404425394751, 0.9207304727166725], 
             UndirectedEdge[22, 255] -> 
             RGBColor[
              0.47607352842348083`, 0.5821402068583181, 0.9528359324237006], 
             UndirectedEdge[28, 380] -> 
             RGBColor[
              0.7867109018720941, 0.8290756256612928, 0.738791031946236], 
             UndirectedEdge[53, 397] -> 
             RGBColor[
              0.7587977124629461, 0.80984049140429, 0.9313101193165865], 
             UndirectedEdge[187, 306] -> 
             RGBColor[
              0.37980069322982196`, 0.49591955770924556`, 0.9460887959332176],
              UndirectedEdge[208, 392] -> 
             RGBColor[
              0.919437831319508, 0.9355972292162307, 0.8727854743677836], 
             UndirectedEdge[33, 381] -> 
             RGBColor[
              0.81812731914316, 0.8563611550031001, 0.8679657950723527], 
             UndirectedEdge[290, 321] -> 
             RGBColor[
              0.536311344146343, 0.6245379682266845, 0.9596484657129758], 
             UndirectedEdge[20, 116] -> 
             RGBColor[
              0.47169415952977667`, 0.5787249427665728, 0.9524524610707317], 
             UndirectedEdge[33, 156] -> 
             RGBColor[
              0.7127924004950111, 0.7755581077803728, 0.9720081431237927], 
             UndirectedEdge[9, 202] -> 
             RGBColor[
              0.8493446780226843, 0.8819322824007907, 0.9247598209022085], 
             UndirectedEdge[76, 233] -> 
             RGBColor[
              0.8159210998638537, 0.8564958806528904, 0.9821881053924173], 
             UndirectedEdge[115, 369] -> 
             RGBColor[
              0.751925453474408, 0.8010288723376089, 0.7519233569093071], 
             UndirectedEdge[183, 335] -> 
             RGBColor[
              0.7993543489387418, 0.8440227338202642, 0.9804124482344094], 
             UndirectedEdge[39, 296] -> 
             RGBColor[
              0.6319477932253896, 0.7084980534990305, 0.9663793336980062], 
             UndirectedEdge[10, 219] -> 
             RGBColor[
              0.6140663707451779, 0.6956859764902591, 0.9640459249928596], 
             UndirectedEdge[71, 143] -> 
             RGBColor[
              0.6142311718382741, 0.6972003366586171, 0.963114997392515], 
             UndirectedEdge[232, 384] -> 
             RGBColor[
              0.5354974047932335, 0.6324536211026095, 0.9570383469345889], 
             UndirectedEdge[1, 57] -> 
             RGBColor[
              0.7951720884614794, 0.8352998474907725, 0.6933058204883686], 
             UndirectedEdge[288, 393] -> 
             RGBColor[
              0.6954019181146538, 0.7619725307722763, 0.9702748223634163], 
             UndirectedEdge[328, 372] -> 
             RGBColor[
              0.8675227759990778, 0.8956793301053255, 0.9059934912246306], 
             UndirectedEdge[16, 115] -> 
             RGBColor[
              0.45401555426753715`, 0.5661224432048189, 0.9505772647013306], 
             UndirectedEdge[34, 244] -> 
             RGBColor[
              0.9641059679139163, 0.883623640211034, 0.4036545675033498], 
             UndirectedEdge[233, 366] -> 
             RGBColor[
              0.8735438087812439, 0.9012652161359906, 0.9468613328296904], 
             UndirectedEdge[100, 105] -> 
             RGBColor[
              0.6491821483298423, 0.7227955542225606, 0.9677675296459534], 
             UndirectedEdge[88, 282] -> 
             RGBColor[
              0.5095052581344979, 0.6126783473607189, 0.9545292667810559], 
             UndirectedEdge[189, 219] -> 
             RGBColor[
              0.8162392476735119, 0.856754876857502, 0.9822170405014625], 
             UndirectedEdge[44, 328] -> 
             RGBColor[
              0.7979424340945271, 0.59184023734833, 0.5852200076059744], 
             UndirectedEdge[153, 154] -> 
             RGBColor[
              0.6797371862168118, 0.7480999105813355, 0.969859266575957], 
             UndirectedEdge[73, 258] -> 
             RGBColor[
              0.749599202763406, 0.8001145519933976, 0.8315883416073867], 
             UndirectedEdge[22, 141] -> 
             RGBColor[
              0.5695397929870957, 0.6554390874908386, 0.9619587494592156], 
             UndirectedEdge[100, 273] -> 
             RGBColor[
              0.7917190214688374, 0.8375072320528512, 0.9797975758735786], 
             UndirectedEdge[230, 391] -> 
             RGBColor[
              0.5650634596789774, 0.6431373716992128, 0.9630699074809153], 
             UndirectedEdge[338, 384] -> 
             RGBColor[
              0.6352150183166387, 0.7106549324556852, 0.9668973497811731], 
             UndirectedEdge[76, 207] -> 
             RGBColor[
              0.8033115668931086, 0.8466452176601442, 0.9809313049886788], 
             UndirectedEdge[144, 370] -> 
             RGBColor[
              0.7474491372314247, 0.8004985989863679, 0.9250404074025029], 
             UndirectedEdge[6, 340] -> 
             RGBColor[
              0.7629133949569283, 0.8151327955825294, 0.9768923371486393], 
             UndirectedEdge[30, 370] -> 
             RGBColor[
              0.7323684423892134, 0.7894129352143429, 0.9578001101231342], 
             UndirectedEdge[164, 245] -> 
             RGBColor[
              0.7436422561050451, 0.7951600117989839, 0.821413497866528], 
             UndirectedEdge[56, 108] -> 
             RGBColor[
              0.5785204024089224, 0.667627512525306, 0.9606645188894234], 
             UndirectedEdge[50, 322] -> 
             RGBColor[
              0.8636153121843586, 0.8606600047920859, 0.657621168077104], 
             UndirectedEdge[379, 399] -> 
             RGBColor[
              0.8797767322369916, 0.9063757378332584, 0.9596978739753037], 
             UndirectedEdge[6, 13] -> 
             RGBColor[
              0.6476871554530765, 0.724683751801483, 0.9655283890365303], 
             UndirectedEdge[55, 60] -> 
             RGBColor[
              0.9083720302274569, 0.9266210715891778, 0.8651041015072878], 
             UndirectedEdge[44, 47] -> 
             RGBColor[
              0.8713536823177553, 0.6497810367750068, 0.5923800221874319], 
             UndirectedEdge[156, 264] -> 
             RGBColor[
              0.68557634193563, 0.7534813673298323, 0.969852959083056], 
             UndirectedEdge[32, 43] -> 
             RGBColor[
              0.5346247257324952, 0.6310123102737082, 0.9572728513283799], 
             UndirectedEdge[144, 207] -> 
             RGBColor[
              0.8628367492337369, 0.8926719209583565, 0.935152121137029], 
             UndirectedEdge[14, 213] -> 
             RGBColor[
              0.45412535256284214`, 0.5655887234702341, 0.9507580062054634], 
             UndirectedEdge[127, 139] -> 
             RGBColor[
              0.6171964663196593, 0.6999597655379959, 0.9631077245779384], 
             UndirectedEdge[321, 342] -> 
             RGBColor[
              0.8454154131631104, 0.8797822628587131, 0.9850627542308761], 
             UndirectedEdge[82, 182] -> 
             RGBColor[
              0.5580074195118216, 0.6506422842129729, 0.9590264337010929], 
             UndirectedEdge[50, 172] -> 
             RGBColor[
              0.8711300654446608, 0.8991342273388367, 0.9352307555834358], 
             UndirectedEdge[80, 96] -> 
             RGBColor[
              0.7971049360861255, 0.8414237013831551, 0.9804116287260733], 
             UndirectedEdge[78, 160] -> 
             RGBColor[
              0.8520374859224418, 0.842233761833216, 0.6427672992474472], 
             UndirectedEdge[32, 293] -> 
             RGBColor[
              0.7562608199803481, 0.5213589485630012, 0.5763543454068359], 
             UndirectedEdge[322, 328] -> 
             RGBColor[
              0.8582759404695951, 0.8564888470277846, 0.6570889894038419], 
             UndirectedEdge[120, 254] -> 
             RGBColor[
              0.6764033654979846, 0.7449929469770575, 0.9700576894920452], 
             UndirectedEdge[291, 321] -> 
             RGBColor[
              0.894119652920059, 0.9142842053109086, 0.7765487092454879], 
             UndirectedEdge[65, 312] -> 
             RGBColor[
              0.8005658132344056, 0.8448298360551161, 0.9687235712246193], 
             UndirectedEdge[209, 334] -> 
             RGBColor[
              0.5824694025604562, 0.6709492076255659, 0.9609328552771335], 
             UndirectedEdge[295, 310] -> 
             RGBColor[
              0.7024163947805033, 0.7665114485034157, 0.9716451924756337], 
             UndirectedEdge[109, 205] -> 
             RGBColor[
              0.7493469269825366, 0.8041147816971188, 0.9756515567025972], 
             UndirectedEdge[194, 376] -> 
             RGBColor[
              0.8815325811854401, 0.9083741679455402, 0.9885625586185344], 
             UndirectedEdge[142, 338] -> 
             RGBColor[
              0.6805105374809184, 0.7485175358135341, 0.9701621025685149], 
             UndirectedEdge[232, 386] -> 
             RGBColor[
              0.7477401173323942, 0.8030024958767812, 0.975453466128531], 
             UndirectedEdge[169, 378] -> 
             RGBColor[
              0.8655664414285961, 0.8957723883164259, 0.9834819860954513], 
             UndirectedEdge[94, 324] -> 
             RGBColor[
              0.4933945519154709, 0.5994816357024246, 0.9532933873374405], 
             UndirectedEdge[196, 231] -> 
             RGBColor[
              0.7012522200225111, 0.7665428310866358, 0.9708579257834118], 
             UndirectedEdge[207, 366] -> 
             RGBColor[
              0.8609342758104988, 0.8914145531432445, 0.9456045324259518], 
             UndirectedEdge[156, 310] -> 
             RGBColor[
              0.6792977244065606, 0.7483841027712375, 0.9693586833118338], 
             UndirectedEdge[206, 369] -> 
             RGBColor[
              0.9089557407836537, 0.9257611292991687, 0.7661814098086137], 
             UndirectedEdge[119, 225] -> 
             RGBColor[
              0.7888672648941475, 0.8357133487595412, 0.9738380685375119], 
             UndirectedEdge[69, 100] -> 
             RGBColor[
              0.8282679716747868, 0.8660595497360487, 0.983440433660749], 
             UndirectedEdge[64, 182] -> 
             RGBColor[
              0.4361409884062786, 0.552185135899224, 0.949011496010283], 
             UndirectedEdge[217, 268] -> 
             RGBColor[
              0.9306723007153849, 0.9466145884526089, 0.9605808731246832], 
             UndirectedEdge[235, 275] -> 
             RGBColor[
              0.9634517292595062, 0.9714682476441261, 0.9111629192591895], 
             UndirectedEdge[5, 99] -> 
             RGBColor[
              0.7406940153554121, 0.7967899066251263, 0.9750283545406173], 
             UndirectedEdge[52, 267] -> 
             RGBColor[
              0.8015461599414375, 0.8421803363702647, 0.8269002557219256], 
             UndirectedEdge[290, 346] -> 
             RGBColor[
              0.38173606755555134`, 0.5013755692034493, 0.9458875381752518], 
             UndirectedEdge[19, 108] -> 
             RGBColor[
              0.543492393034507, 0.6401808603109822, 0.9572296634361378], 
             UndirectedEdge[92, 327] -> 
             RGBColor[
              0.695149545792558, 0.760384538673762, 0.9713348003099802], 
             UndirectedEdge[151, 244] -> 
             RGBColor[
              0.9496448033570217, 0.9581547899409026, 0.765952999312523], 
             UndirectedEdge[114, 327] -> 
             RGBColor[
              0.61387605993355, 0.6965722570733892, 0.9633193536836243], 
             UndirectedEdge[99, 174] -> 
             RGBColor[
              0.5755886464636945, 0.6663278190290789, 0.9597315931817578], 
             UndirectedEdge[180, 282] -> 
             RGBColor[
              0.6959681465230766, 0.7609500530859064, 0.9715132627229679], 
             UndirectedEdge[199, 277] -> 
             RGBColor[
              0.7765014997011515, 0.8246402054807025, 0.9451297342711381], 
             UndirectedEdge[237, 286] -> 
             RGBColor[
              0.6397919887917121, 0.7163068166804631, 0.9662518948314208], 
             UndirectedEdge[290, 313] -> 
             RGBColor[
              0.37872931196178594`, 0.4989345495596348, 0.945650835360802], 
             UndirectedEdge[56, 237] -> 
             RGBColor[
              0.6021418508601095, 0.6868942427766487, 0.9624992809429418], 
             UndirectedEdge[203, 361] -> 
             RGBColor[
              0.8528037799881233, 0.8844961469373783, 0.91882839461309], 
             UndirectedEdge[169, 315] -> 
             RGBColor[
              0.7916382332064056, 0.8371530715450373, 0.9798667588722657], 
             UndirectedEdge[23, 304] -> 
             RGBColor[
              0.6536034373176627, 0.7220927091526201, 0.9431668953537945], 
             UndirectedEdge[129, 270] -> 
             RGBColor[
              0.9301600090871325, 0.9463972048071303, 0.967157698764973], 
             UndirectedEdge[85, 284] -> 
             RGBColor[
              0.8637080358655436, 0.8937746498763703, 0.9556614709808047], 
             UndirectedEdge[203, 369] -> 
             RGBColor[
              0.8561232362828455, 0.8844533308188844, 0.7609247530722709], 
             UndirectedEdge[1, 222] -> 
             RGBColor[
              0.7644178013001882, 0.8103321317083882, 0.6908847303463659], 
             UndirectedEdge[25, 205] -> 
             RGBColor[
              0.5960652260464047, 0.6820025656652555, 0.9619924641789319], 
             UndirectedEdge[301, 380] -> 
             RGBColor[
              0.9288436900110475, 0.9414234876665281, 0.7522100078618668], 
             UndirectedEdge[169, 329] -> 
             RGBColor[
              0.8723785805329047, 0.9008528705065653, 0.9719508114822849], 
             UndirectedEdge[302, 340] -> 
             RGBColor[
              0.6255542253367713, 0.7017825051767308, 0.9665141293637733], 
             UndirectedEdge[205, 391] -> 
             RGBColor[
              0.794338546554683, 0.8397829335591996, 0.9799978142013935], 
             UndirectedEdge[96, 203] -> 
             RGBColor[
              0.7562147814300613, 0.8094800017891521, 0.9763360802501777], 
             UndirectedEdge[4, 195] -> 
             RGBColor[
              0.824573605175621, 0.8631417290053331, 0.9486829176124252], 
             UndirectedEdge[269, 298] -> 
             RGBColor[
              0.6097646604980791, 0.3284615485967543, 0.5555337319433107], 
             UndirectedEdge[168, 220] -> 
             RGBColor[
              0.5821186877326374, 0.6716292007062137, 0.9602456619507784], 
             UndirectedEdge[291, 338] -> 
             RGBColor[
              0.925551145497675, 0.9391398799873927, 0.7796015897262776], 
             UndirectedEdge[10, 360] -> 
             RGBColor[
              0.7118778165668136, 0.7725897762360492, 0.9511460474314006], 
             UndirectedEdge[87, 348] -> 
             RGBColor[
              0.9284111074643485, 0.9420415150081253, 0.8302291568410873], 
             UndirectedEdge[259, 274] -> 
             RGBColor[
              0.8588400570969643, 0.8902797652095467, 0.9863981254131201], 
             UndirectedEdge[293, 336] -> 
             RGBColor[
              0.8125936652484398, 0.5653665954319158, 0.5819690769627898], 
             UndirectedEdge[229, 245] -> 
             RGBColor[
              0.538764842344402, 0.6364325959515664, 0.9568326884314482], 
             UndirectedEdge[173, 197] -> 
             RGBColor[
              0.8573743368116942, 0.8891110396399896, 0.9862583237038471], 
             UndirectedEdge[19, 344] -> 
             RGBColor[
              0.5759695715860311, 0.6666370712038732, 0.9597615810027629], 
             UndirectedEdge[83, 125] -> 
             RGBColor[
              0.6811739124850191, 0.7489897233863567, 0.9702907166929586], 
             UndirectedEdge[240, 315] -> 
             RGBColor[
              0.7851490759925408, 0.8320836926101447, 0.9792199803258097], 
             UndirectedEdge[7, 154] -> 
             RGBColor[
              0.6440272809722769, 0.7201367161793668, 0.9663176428775005], 
             UndirectedEdge[200, 225] -> 
             RGBColor[
              0.5604221248521397, 0.6307982802240011, 0.95835206261496], 
             UndirectedEdge[13, 140] -> 
             RGBColor[
              0.8182865601911242, 0.8558749318333001, 0.8367406644680953], 
             UndirectedEdge[104, 366] -> 
             RGBColor[
              0.7548931912559533, 0.8068291632096162, 0.9362286115695722], 
             UndirectedEdge[116, 172] -> 
             RGBColor[
              0.6593159059017297, 0.7256735503001044, 0.9182550330026726], 
             UndirectedEdge[143, 267] -> 
             RGBColor[
              0.8349481418167156, 0.8687983447032757, 0.8298711051516743], 
             UndirectedEdge[51, 395] -> 
             RGBColor[
              0.8618599573109872, 0.8926877516672009, 0.9866861661914303], 
             UndirectedEdge[213, 224] -> 
             RGBColor[
              0.6424719662301213, 0.7189536580006324, 0.9661407686395524], 
             UndirectedEdge[130, 362] -> 
             RGBColor[
              0.8074784657655523, 0.8502549926223086, 0.9706750120523342], 
             UndirectedEdge[153, 278] -> 
             RGBColor[
              0.6645812740361079, 0.7357956583069774, 0.9686661376511564], 
             UndirectedEdge[83, 303] -> 
             RGBColor[
              0.5209852083394024, 0.6219982881029236, 0.9554330105136293], 
             UndirectedEdge[94, 296] -> 
             RGBColor[
              0.43761045509741153`, 0.5534579140895399, 0.9491051291284436], 
             UndirectedEdge[147, 328] -> 
             RGBColor[
              0.5438585884915218, 0.6359361428313155, 0.9591623192423573], 
             UndirectedEdge[78, 102] -> 
             RGBColor[
              0.53886778876819, 0.6318358319078476, 0.9587501504928011], 
             UndirectedEdge[22, 45] -> 
             RGBColor[
              0.6291857733714252, 0.7029254395127557, 0.967667402968969], 
             UndirectedEdge[199, 238] -> 
             RGBColor[
              0.5073332229511514, 0.6104147267197171, 0.9544965008228294], 
             UndirectedEdge[21, 182] -> 
             RGBColor[
              0.4146156543784303, 0.5335409734590475, 0.947639920760134], 
             UndirectedEdge[126, 212] -> 
             RGBColor[
              0.7760771843884884, 0.8243770116676922, 0.9472764917826634], 
             UndirectedEdge[273, 365] -> 
             RGBColor[
              0.6901658392664218, 0.7578820661803644, 0.9697529389577635], 
             UndirectedEdge[149, 367] -> 
             RGBColor[
              0.9186241773798614, 0.7775922805937496, 0.6025878872765222], 
             UndirectedEdge[81, 89] -> 
             RGBColor[
              0.759120884628746, 0.811750271695167, 0.976625733457944], 
             UndirectedEdge[57, 337] -> 
             RGBColor[
              0.6782405747521149, 0.7478849997896699, 0.9690299155060912], 
             UndirectedEdge[255, 288] -> 
             RGBColor[
              0.6460778392014429, 0.723157861062888, 0.9655516858613553], 
             UndirectedEdge[2, 283] -> 
             RGBColor[
              0.5720198816405705, 0.6634305349746438, 0.9594506469420654], 
             UndirectedEdge[94, 128] -> 
             RGBColor[
              0.6076002877148139, 0.6903018620319343, 0.9635811627027719], 
             UndirectedEdge[176, 393] -> 
             RGBColor[
              0.7562739872069955, 0.8095262537920738, 0.9763419813287131], 
             UndirectedEdge[65, 326] -> 
             RGBColor[
              0.7777457441429024, 0.8264554980898495, 0.9668231534150071], 
             UndirectedEdge[97, 282] -> 
             RGBColor[
              0.736737068932434, 0.792962840311775, 0.9582313887339067], 
             UndirectedEdge[12, 149] -> 
             RGBColor[
              0.9417409016749079, 0.7933597413065041, 0.49749539466683224`], 
             UndirectedEdge[78, 144] -> 
             RGBColor[
              0.8631267661789662, 0.8928984844001799, 0.935181027315767], 
             UndirectedEdge[201, 348] -> 
             RGBColor[
              0.8388581605507732, 0.8717421715942628, 0.8213935551960911], 
             UndirectedEdge[242, 381] -> 
             RGBColor[
              0.9924651845249421, 0.9911521744122078, 0.7745349221064817], 
             UndirectedEdge[43, 367] -> 
             RGBColor[
              0.6710633942885655, 0.738337543839779, 0.9606528696430698], 
             UndirectedEdge[111, 197] -> 
             RGBColor[
              0.8826419666962199, 0.9090773193125928, 0.9823776465289639], 
             UndirectedEdge[69, 216] -> 
             RGBColor[
              0.8735997505905335, 0.9019233120700515, 0.9779674205246903], 
             UndirectedEdge[197, 295] -> 
             RGBColor[
              0.8254027232295977, 0.8636177428159575, 0.9832088426589903], 
             UndirectedEdge[193, 275] -> 
             RGBColor[
              0.9432407225325499, 0.9554100214163592, 0.9112281097549626], 
             UndirectedEdge[149, 238] -> 
             RGBColor[
              0.6626587515813965, 0.5732134664547349, 0.5896056710222886], 
             UndirectedEdge[79, 349] -> 
             RGBColor[
              0.5968537145487456, 0.6811071321930077, 0.9628483993572785], 
             UndirectedEdge[16, 110] -> 
             RGBColor[
              0.4841684272362966, 0.5906019038523052, 0.9529510093150446], 
             UndirectedEdge[49, 372] -> 
             RGBColor[
              0.7479756344482656, 0.8002182415009421, 0.8954933875800859], 
             UndirectedEdge[320, 343] -> 
             RGBColor[
              0.7024231550332778, 0.7594648200675529, 0.7284800177722643], 
             UndirectedEdge[221, 358] -> 
             RGBColor[
              0.9908750082964533, 0.9851124356250176, 0.6059916380668118], 
             UndirectedEdge[240, 245] -> 
             RGBColor[
              0.6354490478615935, 0.7128390002337213, 0.9658703622946789], 
             UndirectedEdge[85, 115] -> 
             RGBColor[
              0.6335899423077558, 0.7116601868646678, 0.9654980473244794], 
             UndirectedEdge[70, 280] -> 
             RGBColor[
              0.7698365087421829, 0.8207366767911849, 0.9775304908375371], 
             UndirectedEdge[151, 171] -> 
             RGBColor[
              0.7847387843859337, 0.8324561740514413, 0.9789951842429246], 
             UndirectedEdge[23, 163] -> 
             RGBColor[
              0.9781387974836, 0.9772134594491326, 0.6810671141685078], 
             UndirectedEdge[255, 360] -> 
             RGBColor[
              0.7923114747974401, 0.837889443482682, 0.9574780796455139], 
             UndirectedEdge[165, 307] -> 
             RGBColor[
              0.41414423586756344`, 0.533132654439118, 0.9476098823894806], 
             UndirectedEdge[81, 169] -> 
             RGBColor[
              0.7474706209273251, 0.8026489971463335, 0.9754645440500906], 
             UndirectedEdge[44, 316] -> 
             RGBColor[
              0.9206274473504722, 0.6863795906986885, 0.49117232006207934`], 
             UndirectedEdge[195, 337] -> 
             RGBColor[
              0.7169208565678227, 0.7787832890418815, 0.972419629042515], 
             UndirectedEdge[316, 390] -> 
             RGBColor[
              0.9883962329118643, 0.9894695583529134, 0.8419679804444051], 
             UndirectedEdge[39, 177] -> 
             RGBColor[
              0.6731624503146796, 0.7426936475943201, 0.9694206322419381], 
             UndirectedEdge[45, 190] -> 
             RGBColor[
              0.8622669383758883, 0.8932192116409159, 0.9866700677492048], 
             UndirectedEdge[287, 396] -> 
             RGBColor[
              0.6760038475747989, 0.7436201701514011, 0.9705846551698203], 
             UndirectedEdge[136, 343] -> 
             RGBColor[
              0.9799907097342888, 0.9813579649044359, 0.7253787057129243], 
             UndirectedEdge[296, 360] -> 
             RGBColor[
              0.6934587421740859, 0.7569006631031263, 0.9498993006603129], 
             UndirectedEdge[167, 228] -> 
             RGBColor[
              0.6136209710164526, 0.6970145565382946, 0.9628552791972653], 
             UndirectedEdge[123, 279] -> 
             RGBColor[
              0.7686642520086684, 0.8192056228246409, 0.977576927130536], 
             UndirectedEdge[33, 333] -> 
             RGBColor[
              0.818147880714193, 0.8541683118063677, 0.7076104257605127], 
             UndirectedEdge[164, 209] -> 
             RGBColor[
              0.7272671644539598, 0.7818659747071606, 0.8201243906678174], 
             UndirectedEdge[22, 29] -> 
             RGBColor[
              0.41909849668638843`, 0.5358853093982165, 0.9483506492189386], 
             UndirectedEdge[24, 366] -> 
             RGBColor[
              0.7952039216563204, 0.8395552301263439, 0.9394020199297599], 
             UndirectedEdge[178, 319] -> 
             RGBColor[
              0.6614592147130733, 0.733291083325103, 0.9683857667652527], 
             UndirectedEdge[294, 368] -> 
             RGBColor[
              0.6977782036568889, 0.7604227223839062, 0.946974835917173], 
             UndirectedEdge[13, 69] -> 
             RGBColor[
              0.7210055959104574, 0.7819606747275749, 0.9728360859815406], 
             UndirectedEdge[214, 295] -> 
             RGBColor[
              0.8955534628033313, 0.9188538816511207, 0.9656250101676114], 
             UndirectedEdge[80, 146] -> 
             RGBColor[
              0.545046084961327, 0.632908468769098, 0.9602741732582444], 
             UndirectedEdge[56, 231] -> 
             RGBColor[
              0.7243160897402765, 0.7845605014020562, 0.9731567167727619], 
             UndirectedEdge[134, 351] -> 
             RGBColor[
              0.6561936503761094, 0.724024485810525, 0.9387823402816056], 
             UndirectedEdge[143, 291] -> 
             RGBColor[
              0.8344035602943629, 0.8676335398926014, 0.7705967672111722], 
             UndirectedEdge[120, 320] -> 
             RGBColor[
              0.647549396353256, 0.720434446838913, 0.9680994020711163], 
             UndirectedEdge[132, 220] -> 
             RGBColor[
              0.8102193499977433, 0.851798178947953, 0.941998854026092], 
             UndirectedEdge[6, 247] -> 
             RGBColor[
              0.564568356362184, 0.657204166240269, 0.9589849726979018], 
             UndirectedEdge[166, 289] -> 
             RGBColor[
              0.6417478103700716, 0.7180887579285211, 0.9662731452929836], 
             UndirectedEdge[114, 392] -> 
             RGBColor[
              0.7713445569989408, 0.8215062183470603, 0.9777892175141893], 
             UndirectedEdge[305, 325] -> 
             RGBColor[
              0.669871386504678, 0.7378730518610046, 0.9688660381925203], 
             UndirectedEdge[44, 128] -> 
             RGBColor[
              0.8078802215456238, 0.5996037124351088, 0.5862105133851959], 
             UndirectedEdge[90, 242] -> 
             RGBColor[
              0.6858942060737774, 0.7471129954983011, 0.8618259475934803], 
             UndirectedEdge[1, 337] -> 
             RGBColor[
              0.875506392433413, 0.8987385754337214, 0.7008472176743565], 
             UndirectedEdge[74, 224] -> 
             RGBColor[
              0.542993149541315, 0.6349636716764753, 0.9592015039917325], 
             UndirectedEdge[160, 370] -> 
             RGBColor[
              0.7363598569749004, 0.7498338764194039, 0.6326266793341833], 
             UndirectedEdge[30, 84] -> 
             RGBColor[
              0.7409947095034408, 0.7964161274665775, 0.9584792014694238], 
             UndirectedEdge[293, 299] -> 
             RGBColor[
              0.6526622467174819, 0.4377368499312407, 0.5678678478491875], 
             UndirectedEdge[186, 399] -> 
             RGBColor[
              0.8712563422207447, 0.9000212449099998, 0.9741206717991884], 
             UndirectedEdge[163, 371] -> 
             RGBColor[
              0.8167241744548549, 0.8507069000408328, 0.6919063022617322], 
             UndirectedEdge[90, 138] -> 
             RGBColor[
              0.5363436031046958, 0.6316859738761668, 0.9577273832265123], 
             UndirectedEdge[71, 286] -> 
             RGBColor[
              0.6679217604908378, 0.7391438325775872, 0.968466373502325], 
             UndirectedEdge[60, 201] -> 
             RGBColor[
              0.7527823226803383, 0.8068199522512736, 0.9759882824020851], 
             UndirectedEdge[128, 380] -> 
             RGBColor[
              0.8797762724557522, 0.9027331511461094, 0.7474145603220792], 
             UndirectedEdge[54, 128] -> 
             RGBColor[
              0.7579458151198504, 0.8108322984639587, 0.9765086135109462], 
             UndirectedEdge[25, 138] -> 
             RGBColor[
              0.59047851166998, 0.6776381819337907, 0.961435632700704], 
             UndirectedEdge[95, 129] -> 
             RGBColor[
              0.7811684224624609, 0.8287064952884314, 0.9529393026135219], 
             UndirectedEdge[132, 302] -> 
             RGBColor[
              0.6794747268732553, 0.7436409905432699, 0.9322623046928348], 
             UndirectedEdge[15, 100] -> 
             RGBColor[
              0.9223555200696435, 0.93880613462073, 0.9113814714947807], 
             UndirectedEdge[33, 63] -> 
             RGBColor[
              0.7392580958795311, 0.7963542804034118, 0.9746138945210259], 
             UndirectedEdge[275, 338] -> 
             RGBColor[
              0.9231093830666022, 0.9393578377768652, 0.9093079646252415], 
             UndirectedEdge[252, 277] -> 
             RGBColor[
              0.9584950110291953, 0.9685662277005316, 0.9551412994794604], 
             UndirectedEdge[146, 192] -> 
             RGBColor[
              0.6389477516323683, 0.705607098850128, 0.8926067481380672], 
             UndirectedEdge[237, 254] -> 
             RGBColor[
              0.48326640536444315`, 0.5913764646351417, 0.9524636481749125], 
             UndirectedEdge[37, 236] -> 
             RGBColor[
              0.8844716030216788, 0.9107176641801344, 0.9888428851449707], 
             UndirectedEdge[265, 362] -> 
             RGBColor[
              0.6255055242349005, 0.7064672019902802, 0.9639247239460402], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.648931939215915, 0.7224521816520901, 0.9678098923410492], 
             UndirectedEdge[341, 379] -> 
             RGBColor[
              0.9037412089068426, 0.9252567573690309, 0.9620440261672383], 
             UndirectedEdge[324, 380] -> 
             RGBColor[
              0.7655705366564092, 0.8119129248165999, 0.7371267849567479], 
             UndirectedEdge[63, 264] -> 
             RGBColor[
              0.7120420373201499, 0.7742775399528712, 0.9724587104802892], 
             UndirectedEdge[153, 337] -> 
             RGBColor[
              0.793383613270433, 0.8385829207360416, 0.9800231161172629], 
             UndirectedEdge[112, 155] -> 
             RGBColor[
              0.7797161624781288, 0.8270293128092071, 0.9394633076317745], 
             UndirectedEdge[10, 177] -> 
             RGBColor[
              0.48585724723381357`, 0.5934798267807927, 0.952667608737436], 
             UndirectedEdge[238, 367] -> 
             RGBColor[
              0.6908590635997447, 0.755483557637853, 0.961914232186955], 
             UndirectedEdge[87, 228] -> 
             RGBColor[
              0.717271033062592, 0.7783266734357595, 0.9730959495336446], 
             UndirectedEdge[66, 352] -> 
             RGBColor[
              0.3799940906691619, 0.5003399308649171, 0.9457159429429267], 
             UndirectedEdge[86, 386] -> 
             RGBColor[
              0.8147128234419637, 0.8553220829009957, 0.9821286795780106], 
             UndirectedEdge[52, 133] -> 
             RGBColor[
              0.7147831577332355, 0.7766007995300037, 0.9725618267005083], 
             UndirectedEdge[105, 112] -> 
             RGBColor[
              0.5109450813075875, 0.6135500294569636, 0.9547247408068884], 
             UndirectedEdge[4, 258] -> 
             RGBColor[
              0.9844949212917029, 0.9859942881281624, 0.819085849378861], 
             UndirectedEdge[141, 339] -> 
             RGBColor[
              0.6903808149958144, 0.7569400292242574, 0.9705332634970338], 
             UndirectedEdge[251, 282] -> 
             RGBColor[
              0.6745405368604733, 0.7438642587779162, 0.9694694781846959], 
             UndirectedEdge[94, 390] -> 
             RGBColor[
              0.7170461138352291, 0.7757125266838989, 0.923255705899221], 
             UndirectedEdge[239, 337] -> 
             RGBColor[
              0.6733794260666361, 0.7439385002945456, 0.9686472280745959], 
             UndirectedEdge[80, 243] -> 
             RGBColor[
              0.7914803323108791, 0.8370297181653608, 0.9798510207866674], 
             UndirectedEdge[366, 382] -> 
             RGBColor[
              0.9477234997533535, 0.9599755612261126, 0.9540530295412053], 
             UndirectedEdge[99, 306] -> 
             RGBColor[
              0.39542976561255583`, 0.5086079427512361, 0.947319173762365], 
             UndirectedEdge[214, 261] -> 
             RGBColor[
              0.8724347924293885, 0.9007265359189425, 0.9633385010038115], 
             UndirectedEdge[21, 60] -> 
             RGBColor[
              0.6122321622672507, 0.6919385247018452, 0.9648849940633403], 
             UndirectedEdge[60, 159] -> 
             RGBColor[
              0.828865126988207, 0.8663785695886262, 0.9835390898204108], 
             UndirectedEdge[9, 300] -> 
             RGBColor[
              0.8173629219428482, 0.8580762619417122, 0.9822113300804405], 
             UndirectedEdge[114, 369] -> 
             RGBColor[
              0.8453851810944297, 0.876064680493452, 0.7598544840839206], 
             UndirectedEdge[112, 350] -> 
             RGBColor[
              0.4465299529958414, 0.5577568829118155, 0.9506202657909254], 
             UndirectedEdge[18, 357] -> 
             RGBColor[
              0.5698518594281078, 0.661670436874279, 0.9592799722917732], 
             UndirectedEdge[71, 320] -> 
             RGBColor[
              0.4825422079188404, 0.5896549803941213, 0.9527198394248879], 
             UndirectedEdge[226, 255] -> 
             RGBColor[0.5750984905442, 0.665929888372361, 0.959693006312275], 
             UndirectedEdge[208, 258] -> 
             RGBColor[
              0.994212588992462, 0.99172592885253, 0.7347566502973397], 
             UndirectedEdge[11, 358] -> 
             RGBColor[
              0.8661767086295742, 0.8941597139834521, 0.8846355879111476], 
             UndirectedEdge[274, 299] -> 
             RGBColor[
              0.6475033264844026, 0.7219305458551057, 0.9673222345861676], 
             UndirectedEdge[147, 372] -> 
             RGBColor[
              0.6650537584061922, 0.7298594076728295, 0.8898051914543581], 
             UndirectedEdge[335, 337] -> 
             RGBColor[
              0.7165767466149034, 0.7785144677313285, 0.9723853313782984], 
             UndirectedEdge[36, 218] -> 
             RGBColor[
              0.9739391779244346, 0.965120177241824, 0.6691530157934155], 
             UndirectedEdge[262, 300] -> 
             RGBColor[
              0.6947234937009885, 0.7595856001810257, 0.971822712412627], 
             UndirectedEdge[109, 136] -> 
             RGBColor[
              0.8805429040132648, 0.9069924008153452, 0.960691660953772], 
             UndirectedEdge[219, 241] -> 
             RGBColor[
              0.7788476716357309, 0.8271609876341579, 0.9785919152294946], 
             UndirectedEdge[37, 348] -> 
             RGBColor[
              0.9562939758395868, 0.9642745573902407, 0.8328886497180481], 
             UndirectedEdge[291, 384] -> 
             RGBColor[
              0.7035227728016982, 0.7607881854288445, 0.7602531055308164], 
             UndirectedEdge[10, 241] -> 
             RGBColor[
              0.6278429654278045, 0.7064483569623246, 0.9654190472012267], 
             UndirectedEdge[131, 314] -> 
             RGBColor[
              0.7097227519659621, 0.7721370513186239, 0.9725726072515736], 
             UndirectedEdge[1, 41] -> 
             RGBColor[
              0.7153128250782813, 0.770055677934171, 0.6871325180621761], 
             UndirectedEdge[78, 400] -> 
             RGBColor[
              0.7410894767752259, 0.7976639988362217, 0.974828531236192], 
             UndirectedEdge[191, 357] -> 
             RGBColor[
              0.8136506957441971, 0.8539430566999471, 0.917671152846708], 
             UndirectedEdge[215, 352] -> 
             RGBColor[
              0.4526849383824224, 0.5658287300723872, 0.950255190181792], 
             UndirectedEdge[96, 369] -> 
             RGBColor[
              0.8937327446360464, 0.9138341645872552, 0.7646733173840798], 
             UndirectedEdge[212, 293] -> 
             RGBColor[
              0.9046716271405193, 0.6376129834974327, 0.5594686558986193], 
             UndirectedEdge[66, 107] -> 
             RGBColor[
              0.4763907884762351, 0.5781546372442179, 0.9536085344490899], 
             UndirectedEdge[146, 159] -> 
             RGBColor[
              0.5624017695526535, 0.646589013841247, 0.9619716102193616], 
             UndirectedEdge[11, 207] -> 
             RGBColor[
              0.7407994598299965, 0.7974374353943982, 0.974799625057454], 
             UndirectedEdge[99, 218] -> 
             RGBColor[
              0.7645422011036809, 0.79961155966669, 0.6748142590555547], 
             UndirectedEdge[131, 217] -> 
             RGBColor[
              0.9213935361665025, 0.9392159534666843, 0.95969585627876], 
             UndirectedEdge[81, 163] -> 
             RGBColor[
              0.8471138781941343, 0.8744475675722608, 0.6949352639225357], 
             UndirectedEdge[50, 54] -> 
             RGBColor[
              0.7533473993835174, 0.8072399811414813, 0.9760502864049869], 
             UndirectedEdge[120, 286] -> 
             RGBColor[
              0.8329289489252536, 0.8699232990223789, 0.9838459361485534], 
             UndirectedEdge[17, 253] -> 
             RGBColor[
              0.8327991557181729, 0.8697165261474996, 0.9570418057462331], 
             UndirectedEdge[45, 365] -> 
             RGBColor[
              0.7915201003575504, 0.8379512440851068, 0.9796186841023271], 
             UndirectedEdge[35, 188] -> 
             RGBColor[
              0.7780026391234078, 0.8259381897066814, 0.9473746195101558], 
             UndirectedEdge[99, 279] -> 
             RGBColor[
              0.6431455577866034, 0.7196595237448389, 0.966085077648793], 
             UndirectedEdge[107, 363] -> 
             RGBColor[
              0.5294710414623511, 0.6266577249561857, 0.9568982119329097], 
             UndirectedEdge[105, 271] -> 
             RGBColor[
              0.6219979176852846, 0.7012679785320384, 0.9651352948040597], 
             UndirectedEdge[191, 219] -> 
             RGBColor[
              0.8758731153840007, 0.9025782275393472, 0.9238547540561016], 
             UndirectedEdge[177, 339] -> 
             RGBColor[
              0.5392764748981353, 0.636847962307471, 0.9568729660202498], 
             UndirectedEdge[80, 167] -> 
             RGBColor[
              0.7275613475398828, 0.7870957214599814, 0.9734801737415684], 
             UndirectedEdge[48, 56] -> 
             RGBColor[
              0.7935515433749436, 0.8391334488048379, 0.9799285739326521], 
             UndirectedEdge[42, 136] -> 
             RGBColor[
              0.681657846251029, 0.7463175780340775, 0.9438679418885805], 
             UndirectedEdge[77, 102] -> 
             RGBColor[
              0.6633296611337723, 0.7280729448354676, 0.8789210322750862], 
             UndirectedEdge[73, 203] -> 
             RGBColor[
              0.6113471059799558, 0.6941901517053871, 0.9633451951136598], 
             UndirectedEdge[35, 284] -> 
             RGBColor[
              0.777811029670658, 0.8257952876905522, 0.9476989643339124], 
             UndirectedEdge[274, 367] -> 
             RGBColor[
              0.8875405683033393, 0.9128778780529372, 0.979188750458506], 
             UndirectedEdge[33, 310] -> 
             RGBColor[
              0.6100708184409883, 0.6943035176869603, 0.9624587922874032], 
             UndirectedEdge[175, 295] -> 
             RGBColor[
              0.7164861204264106, 0.7779338856166805, 0.9727528128175827], 
             UndirectedEdge[70, 75] -> 
             RGBColor[
              0.7960051583033225, 0.841274167965954, 0.9686309499827275], 
             UndirectedEdge[57, 258] -> 
             RGBColor[
              0.7965078687119711, 0.8381971202217617, 0.8352811636229629], 
             UndirectedEdge[70, 145] -> 
             RGBColor[
              0.8191983195857331, 0.8564150943369306, 0.8219442143703855], 
             UndirectedEdge[12, 336] -> 
             RGBColor[
              0.8898353904052774, 0.9123122457924657, 0.8720386690727626], 
             UndirectedEdge[18, 216] -> 
             RGBColor[
              0.7228670666198754, 0.7819749036139462, 0.9644444536310094], 
             UndirectedEdge[158, 311] -> 
             RGBColor[
              0.8038542281408032, 0.716545465499668, 0.607192303628707], 
             UndirectedEdge[8, 36] -> 
             RGBColor[
              0.6644748440871495, 0.7316039312972887, 0.9452454395259814], 
             UndirectedEdge[119, 200] -> 
             RGBColor[
              0.4073721400420077, 0.5103090685355399, 0.948987005922552], 
             UndirectedEdge[181, 362] -> 
             RGBColor[
              0.6182134989466035, 0.7005472073592451, 0.9633506690037767], 
             UndirectedEdge[9, 306] -> 
             RGBColor[
              0.47910161728302814`, 0.575462970381951, 0.9546401210595425], 
             UndirectedEdge[82, 253] -> 
             RGBColor[
              0.6943723368135718, 0.7611682140347634, 0.9701722033213087], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.7481533063404004, 0.8031823161796293, 0.9755325877520081], 
             UndirectedEdge[146, 314] -> 
             RGBColor[
              0.4193018543639033, 0.5332444033525772, 0.9487200360822945], 
             UndirectedEdge[27, 277] -> 
             RGBColor[
              0.9584950110291953, 0.9685662277005316, 0.9551412994794604], 
             UndirectedEdge[6, 302] -> 
             RGBColor[
              0.516546798589116, 0.6162052889194942, 0.9557606860936814], 
             UndirectedEdge[93, 296] -> 
             RGBColor[
              0.6611835953542378, 0.731809888531866, 0.9691678706041644], 
             UndirectedEdge[153, 284] -> 
             RGBColor[
              0.8993191211961894, 0.9216606454105499, 0.9591932452337693], 
             UndirectedEdge[43, 199] -> 
             RGBColor[
              0.4875375536399723, 0.5932687129216432, 0.9532351382789441], 
             UndirectedEdge[213, 250] -> 
             RGBColor[
              0.6325142011573264, 0.7111745762439475, 0.9651482716777016], 
             UndirectedEdge[3, 232] -> 
             RGBColor[
              0.8237537476593919, 0.8613062136772492, 0.893450047623971], 
             UndirectedEdge[5, 235] -> 
             RGBColor[
              0.9371099286202074, 0.9526172682547671, 0.9913406658751089], 
             UndirectedEdge[25, 391] -> 
             RGBColor[
              0.686090324493398, 0.7528512134914827, 0.9708272379901859], 
             UndirectedEdge[288, 341] -> 
             RGBColor[
              0.7539900192595711, 0.8079017888972628, 0.9760719338668588], 
             UndirectedEdge[181, 265] -> 
             RGBColor[
              0.5762021100275292, 0.6668258563864187, 0.9597798872806941], 
             UndirectedEdge[295, 363] -> 
             RGBColor[
              0.6079122760289548, 0.6880034783027313, 0.9646987572766779], 
             UndirectedEdge[278, 284] -> 
             RGBColor[
              0.7357080474154798, 0.7916141899780629, 0.9443844633424789], 
             UndirectedEdge[167, 351] -> 
             RGBColor[
              0.4982378985601938, 0.6003117403517845, 0.9546089996352731], 
             UndirectedEdge[198, 311] -> 
             RGBColor[
              0.9497401622619732, 0.8270794711543952, 0.3677473036216339], 
             UndirectedEdge[54, 328] -> 
             RGBColor[
              0.7480080276687537, 0.80306882337718, 0.9755181077317248], 
             UndirectedEdge[261, 310] -> 
             RGBColor[
              0.6792977244065606, 0.7483841027712375, 0.9693586833118338], 
             UndirectedEdge[68, 319] -> 
             RGBColor[
              0.5899200597707526, 0.6725645603410572, 0.9634855413841691], 
             UndirectedEdge[100, 141] -> 
             RGBColor[
              0.8334273021756364, 0.8700900579356765, 0.9839546675083889], 
             UndirectedEdge[139, 325] -> 
             RGBColor[
              0.7599068424001687, 0.8123516088570992, 0.9755716337268675], 
             UndirectedEdge[123, 338] -> 
             RGBColor[
              0.8266885181627893, 0.8648357743316555, 0.9832803267578336], 
             UndirectedEdge[317, 370] -> 
             RGBColor[
              0.670198232329003, 0.4247766310524186, 0.5657713993177932], 
             UndirectedEdge[160, 400] -> 
             RGBColor[
              0.8520374859224418, 0.842233761833216, 0.6427672992474474], 
             UndirectedEdge[150, 266] -> 
             RGBColor[
              0.8384772346449116, 0.8744855641218781, 0.9843384592003148], 
             UndirectedEdge[134, 201] -> 
             RGBColor[
              0.8267899796392562, 0.8649303946535182, 0.9518001439306922], 
             UndirectedEdge[161, 251] -> 
             RGBColor[
              0.789786805105468, 0.8357918073926096, 0.9796596467325431], 
             UndirectedEdge[86, 371] -> 
             RGBColor[
              0.7171962601665841, 0.7789984364263789, 0.9724470786994466], 
             UndirectedEdge[105, 350] -> 
             RGBColor[
              0.37795607412239957`, 0.5017882876053523, 0.9453040047230138], 
             UndirectedEdge[54, 362] -> 
             RGBColor[
              0.7086026812035373, 0.7722850672268275, 0.9715905510599714], 
             UndirectedEdge[4, 208] -> 
             RGBColor[
              0.983598043640404, 0.9857722483838898, 0.8447686907503782], 
             UndirectedEdge[176, 294] -> 
             RGBColor[
              0.6105949616504879, 0.691886260376682, 0.9641992225553948], 
             UndirectedEdge[113, 170] -> 
             RGBColor[
              0.9641073825835832, 0.8916186394846618, 0.5431363402221696], 
             UndirectedEdge[14, 205] -> 
             RGBColor[
              0.5395977163959482, 0.6340299757875949, 0.9581355834262311], 
             UndirectedEdge[262, 306] -> 
             RGBColor[
              0.3564621890411685, 0.4769723086212646, 0.944251503391729], 
             UndirectedEdge[47, 128] -> 
             RGBColor[
              0.8296766417587322, 0.867460339777267, 0.9835011393733086], 
             UndirectedEdge[257, 382] -> 
             RGBColor[
              0.9320269597194538, 0.9482691073695557, 0.9806231775052969], 
             UndirectedEdge[165, 228] -> 
             RGBColor[
              0.48892770304364985`, 0.5946701331274371, 0.9532691910038416], 
             UndirectedEdge[72, 341] -> 
             RGBColor[
              0.7239487989850979, 0.783909233069535, 0.9734360537453755], 
             UndirectedEdge[50, 116] -> 
             RGBColor[
              0.5451921899710035, 0.6366377037536818, 0.9594392537783907], 
             UndirectedEdge[230, 247] -> 
             RGBColor[
              0.36049700943568674`, 0.48024795758412187`, 0.9445691392332196],
              UndirectedEdge[45, 100] -> 
             RGBColor[
              0.893073282559966, 0.9175764099575936, 0.9896633210181424], 
             UndirectedEdge[95, 386] -> 
             RGBColor[
              0.7175905065474204, 0.7787623451051838, 0.9729181715739119], 
             UndirectedEdge[182, 244] -> 
             RGBColor[
              0.7104829552118996, 0.7666301120959491, 0.7447452943677076], 
             UndirectedEdge[104, 382] -> 
             RGBColor[
              0.7212575822730765, 0.7811864901018144, 0.9738432951375899], 
             UndirectedEdge[58, 210] -> 
             RGBColor[
              0.626890584073544, 0.7079505923795804, 0.9637883541421919], 
             UndirectedEdge[102, 370] -> 
             RGBColor[
              0.42319015982064845`, 0.5394359464940356, 0.9486095305795372], 
             UndirectedEdge[1, 161] -> 
             RGBColor[
              0.8707502749175396, 0.8950230602824891, 0.7003731723288193], 
             UndirectedEdge[153, 356] -> 
             RGBColor[
              0.7877181584026585, 0.8341570243342843, 0.979458436522729], 
             UndirectedEdge[1, 154] -> 
             RGBColor[
              0.7618599653797917, 0.8082555652790153, 0.6906833681330506], 
             UndirectedEdge[341, 399] -> 
             RGBColor[
              0.8157888644449098, 0.8561795164446686, 0.9822314652118904], 
             UndirectedEdge[373, 395] -> 
             RGBColor[
              0.6374675385534141, 0.7112213814944531, 0.9676782723592303], 
             UndirectedEdge[190, 266] -> 
             RGBColor[
              0.853052722337553, 0.8858720458851788, 0.9857912075978408], 
             UndirectedEdge[73, 85] -> 
             RGBColor[
              0.6305295580192884, 0.7091756290305491, 0.9652571226627342], 
             UndirectedEdge[221, 250] -> 
             RGBColor[
              0.8610728789910798, 0.8849334067544985, 0.6957146444771596], 
             UndirectedEdge[23, 353] -> 
             RGBColor[
              0.8177291079985893, 0.8579436903323562, 0.9555397642271479], 
             UndirectedEdge[171, 270] -> 
             RGBColor[
              0.7796228507498462, 0.8283768674383443, 0.9785072219256667], 
             UndirectedEdge[277, 396] -> 
             RGBColor[
              0.9496087487793502, 0.9616884300236901, 0.96150058640522], 
             UndirectedEdge[315, 371] -> 
             RGBColor[
              0.7171962601665841, 0.7789984364263789, 0.9724470786994466], 
             UndirectedEdge[207, 391] -> 
             RGBColor[
              0.8124365439432217, 0.8539212266690007, 0.9818016534456817], 
             UndirectedEdge[160, 247] -> 
             RGBColor[
              0.7191081197923764, 0.7358281389927276, 0.6312685593879794], 
             UndirectedEdge[193, 232] -> 
             RGBColor[
              0.777657116955158, 0.8268574993006517, 0.9783069762597709], 
             UndirectedEdge[22, 91] -> 
             RGBColor[
              0.637014621119578, 0.7089071852709876, 0.95937324171526], 
             UndirectedEdge[78, 247] -> 
             RGBColor[
              0.6081601106451604, 0.6912583759957334, 0.9633297913767241], 
             UndirectedEdge[87, 192] -> 
             RGBColor[
              0.9251130762570634, 0.941106468438476, 0.9160534189577705], 
             UndirectedEdge[226, 294] -> 
             RGBColor[
              0.47874354390090346`, 0.5871045646663575, 0.9522733840410178], 
             UndirectedEdge[177, 311] -> 
             RGBColor[
              0.7075091298100887, 0.6392317344368861, 0.5989898956170454], 
             UndirectedEdge[189, 200] -> 
             RGBColor[
              0.5231672091969598, 0.6012525732764558, 0.9603581439908988], 
             UndirectedEdge[67, 184] -> 
             RGBColor[
              0.8724067389310861, 0.8995649858223702, 0.9096664720304399], 
             UndirectedEdge[33, 256] -> 
             RGBColor[
              0.45933391161246484`, 0.563978945511546, 0.9520431473949609], 
             UndirectedEdge[176, 226] -> 
             RGBColor[
              0.6581194178394802, 0.731068792143355, 0.9677747297461089], 
             UndirectedEdge[145, 162] -> 
             RGBColor[
              0.9495446222096617, 0.824737483115679, 0.4603011001261134], 
             UndirectedEdge[286, 343] -> 
             RGBColor[
              0.8878027076052754, 0.9089536722510188, 0.7442265518497014], 
             UndirectedEdge[13, 18] -> 
             RGBColor[
              0.5702729119397993, 0.6620122662714696, 0.9593131190878597], 
             UndirectedEdge[86, 308] -> 
             RGBColor[
              0.892406230777562, 0.9124025804773466, 0.7328794735998283], 
             UndirectedEdge[364, 377] -> 
             RGBColor[
              0.8266044138629901, 0.8634851923167687, 0.891558401369849], 
             UndirectedEdge[90, 152] -> 
             RGBColor[
              0.6383076460714117, 0.7119641013234308, 0.9677248698977646], 
             UndirectedEdge[1, 153] -> 
             RGBColor[
              0.9103151269797976, 0.9259977684371441, 0.7042990210995403], 
             UndirectedEdge[92, 114] -> 
             RGBColor[
              0.778402648559037, 0.8271341489702893, 0.978462424588024], 
             UndirectedEdge[132, 219] -> 
             RGBColor[
              0.872416450865328, 0.9004127948674683, 0.9481804620489909], 
             UndirectedEdge[107, 215] -> 
             RGBColor[
              0.5490816361894957, 0.6436434364516881, 0.9581477816879553], 
             UndirectedEdge[240, 319] -> 
             RGBColor[
              0.8012918295973591, 0.8447273101451553, 0.9808202414716926], 
             UndirectedEdge[58, 110] -> 
             RGBColor[
              0.5901054645142783, 0.6781132258977434, 0.9608744102755565], 
             UndirectedEdge[67, 85] -> 
             RGBColor[
              0.872652954072483, 0.899757330962134, 0.9096910124547231], 
             UndirectedEdge[125, 344] -> 
             RGBColor[
              0.6906907610205602, 0.7567159297566497, 0.9710399178710413], 
             UndirectedEdge[198, 219] -> 
             RGBColor[
              0.8790929858936245, 0.902040194170135, 0.7345978847702923], 
             UndirectedEdge[16, 325] -> 
             RGBColor[
              0.6676037199898787, 0.7359089131021184, 0.968721544487416], 
             UndirectedEdge[119, 390] -> 
             RGBColor[
              0.8104560566557233, 0.8516642409061892, 0.9305768644045375], 
             UndirectedEdge[7, 153] -> 
             RGBColor[
              0.7924824425722827, 0.8378789193374956, 0.9799332958439902], 
             UndirectedEdge[23, 164] -> 
             RGBColor[
              0.9801995912463775, 0.9826665216535752, 0.816492751321456], 
             UndirectedEdge[46, 373] -> 
             RGBColor[
              0.6550306371538173, 0.7252257195808032, 0.9693534563824999], 
             UndirectedEdge[301, 316] -> 
             RGBColor[
              0.9280178243467443, 0.9427492302213674, 0.8870888847877436], 
             UndirectedEdge[22, 150] -> 
             RGBColor[
              0.546723753160279, 0.6376150237698042, 0.9596846598372932], 
             UndirectedEdge[161, 327] -> 
             RGBColor[
              0.6398428004296864, 0.7168576721035081, 0.9659074757032927], 
             UndirectedEdge[123, 281] -> 
             RGBColor[
              0.8492709316939624, 0.8828423778981271, 0.9854342575199954], 
             UndirectedEdge[111, 160] -> 
             RGBColor[
              0.9528603146056854, 0.9218080310762438, 0.6462623637372363], 
             UndirectedEdge[277, 287] -> 
             RGBColor[
              0.6996252900967288, 0.7614874411485203, 0.9392825515939389], 
             UndirectedEdge[48, 120] -> 
             RGBColor[
              0.8818012323206808, 0.9085883830684403, 0.9885881828036412], 
             UndirectedEdge[6, 224] -> 
             RGBColor[
              0.702740590114019, 0.7677055571141534, 0.9710062726045241], 
             UndirectedEdge[103, 313] -> 
             RGBColor[
              0.7007511125820941, 0.7644790927298433, 0.9722972286508431], 
             UndirectedEdge[8, 60] -> 
             RGBColor[
              0.5938463900343652, 0.6760136928895015, 0.9637134689145608], 
             UndirectedEdge[284, 392] -> 
             RGBColor[
              0.9080029229367069, 0.9285848732029197, 0.9600215139959012], 
             UndirectedEdge[218, 279] -> 
             RGBColor[
              0.8625915020214511, 0.8776983599220554, 0.6835682161288008], 
             UndirectedEdge[135, 221] -> 
             RGBColor[
              0.9250811052635144, 0.9352579363450074, 0.7020092513809499], 
             UndirectedEdge[95, 309] -> 
             RGBColor[
              0.4794048608557884, 0.5857430055640751, 0.9528499916199293], 
             UndirectedEdge[80, 385] -> 
             RGBColor[
              0.671414559341512, 0.7417028463159699, 0.9689304507924116], 
             UndirectedEdge[272, 398] -> 
             RGBColor[
              0.6855209252044482, 0.7532907947484953, 0.9699481322184532], 
             UndirectedEdge[33, 264] -> 
             RGBColor[
              0.6163494359700578, 0.6994007822455552, 0.9629530680586253], 
             UndirectedEdge[76, 366] -> 
             RGBColor[
              0.9237363998188401, 0.9408488988508141, 0.9517651185359146], 
             UndirectedEdge[41, 258] -> 
             RGBColor[
              0.7166486053287731, 0.7729529506651605, 0.8291078611967705], 
             UndirectedEdge[174, 232] -> 
             RGBColor[
              0.6319446000121804, 0.7118434594383831, 0.9643299470357173], 
             UndirectedEdge[61, 307] -> 
             RGBColor[
              0.3786744910269105, 0.5024105442193562, 0.9453497816128981], 
             UndirectedEdge[35, 392] -> 
             RGBColor[
              0.7153680580318037, 0.7769009838118365, 0.9728089074047217], 
             UndirectedEdge[212, 259] -> 
             RGBColor[
              0.9300961167959354, 0.9461930603018378, 0.9618401155728964], 
             UndirectedEdge[73, 110] -> 
             RGBColor[
              0.5373021961402777, 0.6352451538715977, 0.95671754356441], 
             UndirectedEdge[122, 228] -> 
             RGBColor[
              0.7662836093033758, 0.8167797065937905, 0.9559884803830749], 
             UndirectedEdge[41, 203] -> 
             RGBColor[
              0.5783965085453229, 0.6670285503771498, 0.9608647147030436], 
             UndirectedEdge[361, 385] -> 
             RGBColor[
              0.7647229115967105, 0.8141561256385638, 0.9110957809912372], 
             UndirectedEdge[9, 269] -> 
             RGBColor[
              0.557325140602968, 0.649039437972206, 0.9594112395282618], 
             UndirectedEdge[192, 228] -> 
             RGBColor[
              0.7803468725366002, 0.8266040323681305, 0.9024462932256798], 
             UndirectedEdge[47, 265] -> 
             RGBColor[
              0.7383221189233451, 0.7951917575673094, 0.975012295199251], 
             UndirectedEdge[338, 398] -> 
             RGBColor[
              0.8243831406202413, 0.8630347958738986, 0.9830505482693703], 
             UndirectedEdge[71, 79] -> 
             RGBColor[
              0.6585234878641693, 0.7318018305721161, 0.9675296415187498], 
             UndirectedEdge[77, 78] -> 
             RGBColor[
              0.8655513491408082, 0.8939011117638416, 0.8949994130184771], 
             UndirectedEdge[89, 164] -> 
             RGBColor[
              0.9048772049588748, 0.9234158719127674, 0.8359128089953529], 
             UndirectedEdge[123, 235] -> 
             RGBColor[
              0.8670308643556932, 0.8969461841989164, 0.9851352813917815], 
             UndirectedEdge[72, 393] -> 
             RGBColor[
              0.6653606978401807, 0.7379799749445484, 0.9676389422419331], 
             UndirectedEdge[240, 371] -> 
             RGBColor[
              0.7105917599741809, 0.7738389506800128, 0.9717888038428313], 
             UndirectedEdge[196, 303] -> 
             RGBColor[
              0.6034697282446454, 0.6886788915945612, 0.9621206976353984], 
             UndirectedEdge[105, 170] -> 
             RGBColor[
              0.6903430182215594, 0.6753636684493857, 0.6093166755634494], 
             UndirectedEdge[195, 208] -> 
             RGBColor[
              0.83429127287638, 0.8688733697297009, 0.8643537185309038], 
             UndirectedEdge[100, 180] -> 
             RGBColor[
              0.8646796400346899, 0.8949360901328329, 0.9869551100467776], 
             UndirectedEdge[39, 355] -> 
             RGBColor[
              0.7951154221810486, 0.8400124440902026, 0.9801753937684498], 
             UndirectedEdge[244, 397] -> 
             RGBColor[
              0.7633213726673908, 0.8102304464127228, 0.7487104863640849], 
             UndirectedEdge[225, 355] -> 
             RGBColor[
              0.8472380116836966, 0.8814132305914635, 0.9795874043966115], 
             UndirectedEdge[335, 354] -> 
             RGBColor[
              0.5999548728780991, 0.685615855916869, 0.9619872437746719], 
             UndirectedEdge[97, 100] -> 
             RGBColor[
              0.9054485624440473, 0.9269488773587016, 0.9736732360577164], 
             UndirectedEdge[2, 107] -> 
             RGBColor[
              0.6530041663220931, 0.7287327500573237, 0.9661299168294557], 
             UndirectedEdge[128, 225] -> 
             RGBColor[
              0.8540602153454402, 0.8867427879426857, 0.9802673779004962], 
             UndirectedEdge[96, 228] -> 
             RGBColor[
              0.6831645595626954, 0.7513425364614683, 0.9697867341817703], 
             UndirectedEdge[262, 307] -> 
             RGBColor[
              0.4450494993580072, 0.559525367609153, 0.9496829932035535], 
             UndirectedEdge[86, 334] -> 
             RGBColor[
              0.7485445223424889, 0.8034879370938125, 0.9755715805069749], 
             UndirectedEdge[255, 399] -> 
             RGBColor[
              0.7078766843867816, 0.7714355886102939, 0.9717112172063869], 
             UndirectedEdge[138, 242] -> 
             RGBColor[
              0.8426906223239219, 0.875632539892177, 0.8741479418006519], 
             UndirectedEdge[27, 396] -> 
             RGBColor[
              0.9348735685072654, 0.9506989567034125, 0.9864434030553417], 
             UndirectedEdge[163, 209] -> 
             RGBColor[
              0.7252063706911822, 0.7764129125027179, 0.6846987535148692], 
             UndirectedEdge[63, 202] -> 
             RGBColor[
              0.910600046532607, 0.9299064120807029, 0.9308330817886022], 
             UndirectedEdge[347, 372] -> 
             RGBColor[
              0.8901204180708076, 0.9133327798402017, 0.9082458129993689], 
             UndirectedEdge[174, 275] -> 
             RGBColor[
              0.7975282055895723, 0.8403959815540907, 0.8972510805309089], 
             UndirectedEdge[209, 315] -> 
             RGBColor[
              0.6256784564029114, 0.704704448888264, 0.9652395299525836], 
             UndirectedEdge[177, 374] -> 
             RGBColor[
              0.746787058896945, 0.800009443508283, 0.9270094866376801], 
             UndirectedEdge[214, 215] -> 
             RGBColor[
              0.6948196863509617, 0.7579496871203478, 0.9480922847235117], 
             UndirectedEdge[160, 185] -> 
             RGBColor[
              0.7543183848953188, 0.7644134184076627, 0.634040440436334], 
             UndirectedEdge[63, 268] -> 
             RGBColor[
              0.8620283045325852, 0.8928219871720395, 0.9867022232997118], 
             UndirectedEdge[48, 196] -> 
             RGBColor[
              0.7704876736571782, 0.8211157784894174, 0.9776297829433019], 
             UndirectedEdge[34, 95] -> 
             RGBColor[
              0.766077627213511, 0.7313625691668142, 0.6138651658337634], 
             UndirectedEdge[84, 333] -> 
             RGBColor[
              0.7598585100037722, 0.8068648567148532, 0.7030090367619533], 
             UndirectedEdge[102, 224] -> 
             RGBColor[
              0.5441106563899595, 0.6359315999412438, 0.9592727105399557], 
             UndirectedEdge[105, 326] -> 
             RGBColor[
              0.5245070038156747, 0.6245602091066753, 0.9557923850256841], 
             UndirectedEdge[134, 236] -> 
             RGBColor[
              0.9108944244162168, 0.9308852503592948, 0.960116062577963], 
             UndirectedEdge[92, 161] -> 
             RGBColor[
              0.8043693890551733, 0.8474195640004083, 0.9810505466076924], 
             UndirectedEdge[77, 185] -> 
             RGBColor[
              0.7678322481136852, 0.8160807683382885, 0.8862725542073637], 
             UndirectedEdge[178, 329] -> 
             RGBColor[
              0.7260568084347541, 0.7843472647516201, 0.9588695582293889], 
             UndirectedEdge[185, 400] -> 
             RGBColor[
              0.6433703757481027, 0.7198436554106685, 0.9661016724250786], 
             UndirectedEdge[317, 333] -> 
             RGBColor[
              0.9116962563384051, 0.6117740675064396, 0.31355405332379294`], 
             UndirectedEdge[106, 215] -> 
             RGBColor[
              0.644667773379791, 0.7186600697643815, 0.9675836231494064], 
             UndirectedEdge[14, 340] -> 
             RGBColor[
              0.6234014031943953, 0.6999178388409917, 0.966376953440527], 
             UndirectedEdge[233, 358] -> 
             RGBColor[
              0.87849622465509, 0.9037838135343748, 0.8858634821361482], 
             UndirectedEdge[74, 191] -> 
             RGBColor[
              0.6605431204393811, 0.7264148281832694, 0.90651003587202], 
             UndirectedEdge[53, 244] -> 
             RGBColor[
              0.9890419635922234, 0.9882558898448939, 0.7236356754659021], 
             UndirectedEdge[4, 16] -> 
             RGBColor[
              0.6858508885073669, 0.7495176215054649, 0.9378338478110598], 
             UndirectedEdge[149, 274] -> 
             RGBColor[
              0.859340256284991, 0.7306077868698191, 0.6068801892938395], 
             UndirectedEdge[326, 335] -> 
             RGBColor[
              0.640610709851481, 0.7186220958964442, 0.9651878201884545], 
             UndirectedEdge[30, 77] -> 
             RGBColor[
              0.9725079437023374, 0.9780499335557749, 0.8881116118186833], 
             UndirectedEdge[129, 229] -> 
             RGBColor[
              0.7750020336474095, 0.8237003430557224, 0.9524538618977745], 
             UndirectedEdge[216, 219] -> 
             RGBColor[
              0.8558638645050682, 0.8880679030623593, 0.97619967315097], 
             UndirectedEdge[138, 233] -> 
             RGBColor[
              0.7294342640905489, 0.7885588581040548, 0.9736668485599385], 
             UndirectedEdge[28, 44] -> 
             RGBColor[
              0.7148148509619656, 0.525946186950292, 0.5775869850093527], 
             UndirectedEdge[163, 227] -> 
             RGBColor[
              0.8101590372537962, 0.8453813142922637, 0.6913865386185496], 
             UndirectedEdge[15, 335] -> 
             RGBColor[
              0.8316482802097532, 0.8676539013384388, 0.9024178567505745], 
             UndirectedEdge[257, 268] -> 
             RGBColor[
              0.9195359702519891, 0.938309131427076, 0.9794317757790522], 
             UndirectedEdge[217, 279] -> 
             RGBColor[
              0.8567167741497981, 0.8882812823360354, 0.9533579356573361], 
             UndirectedEdge[93, 119] -> 
             RGBColor[
              0.7659804775203475, 0.8176243972911157, 0.9772145948155083], 
             UndirectedEdge[67, 305] -> 
             RGBColor[
              0.6953462325470638, 0.7561837260611712, 0.8949147235366788], 
             UndirectedEdge[153, 195] -> 
             RGBColor[
              0.7517295911142072, 0.8060424820453044, 0.9758714324676988], 
             UndirectedEdge[50, 135] -> 
             RGBColor[
              0.8083412419659897, 0.8505224056815381, 0.9814464237867668], 
             UndirectedEdge[68, 334] -> 
             RGBColor[
              0.530568252323479, 0.6261657015433483, 0.9575786055628361], 
             UndirectedEdge[95, 308] -> 
             RGBColor[
              0.7952839138830186, 0.8358428426815347, 0.7236689655957296], 
             UndirectedEdge[17, 36] -> 
             RGBColor[
              0.9646792003580276, 0.973178385976294, 0.944673080040644], 
             UndirectedEdge[41, 361] -> 
             RGBColor[
              0.7125950154565857, 0.7714255292937466, 0.907105593377765], 
             UndirectedEdge[117, 371] -> 
             RGBColor[
              0.6203263945761233, 0.702643649972023, 0.9632564445867648], 
             UndirectedEdge[89, 304] -> 
             RGBColor[
              0.57828105103016, 0.6628420594118124, 0.9625869530276914], 
             UndirectedEdge[267, 272] -> 
             RGBColor[
              0.7872335116042346, 0.8305606836726637, 0.8257735116158627], 
             UndirectedEdge[20, 158] -> 
             RGBColor[
              0.6556766576116428, 0.7304433143434599, 0.9666541837387197], 
             UndirectedEdge[30, 62] -> 
             RGBColor[
              0.8592677592780328, 0.8905792885358685, 0.9690592030177487], 
             UndirectedEdge[197, 310] -> 
             RGBColor[
              0.6995624708016321, 0.7642358069903665, 0.9713729826588009], 
             UndirectedEdge[142, 268] -> 
             RGBColor[
              0.6964417978923841, 0.761220690423093, 0.9716816404085645], 
             UndirectedEdge[78, 213] -> 
             RGBColor[
              0.6372290986083516, 0.7148578899672362, 0.965618208592398], 
             UndirectedEdge[48, 71] -> 
             RGBColor[
              0.7167940438862651, 0.7778089166236486, 0.9732086201574128], 
             UndirectedEdge[262, 269] -> 
             RGBColor[
              0.43468571236110837`, 0.5505487762115195, 0.9490226218604483], 
             UndirectedEdge[27, 376] -> 
             RGBColor[
              0.8856691149130873, 0.9114646610267273, 0.9817502383461947], 
             UndirectedEdge[245, 292] -> 
             RGBColor[
              0.6766035388130522, 0.7453195347707446, 0.9698845970092829], 
             UndirectedEdge[142, 217] -> 
             RGBColor[
              0.7380081867722219, 0.7934223426423506, 0.9429776038765141], 
             UndirectedEdge[142, 363] -> 
             RGBColor[
              0.44567279439933094`, 0.5590710084446453, 0.949997416618964], 
             UndirectedEdge[121, 130] -> 
             RGBColor[
              0.9679281262896033, 0.9748996308409683, 0.9077455128697244], 
             UndirectedEdge[217, 300] -> 
             RGBColor[
              0.9472622866355707, 0.9598429929021938, 0.9621632407918058], 
             UndirectedEdge[25, 109] -> 
             RGBColor[
              0.6410987049212516, 0.7171830616294019, 0.9664809804913895], 
             UndirectedEdge[40, 146] -> 
             RGBColor[
              0.5577512314579793, 0.6428808010000475, 0.9615280377443072], 
             UndirectedEdge[18, 140] -> 
             RGBColor[
              0.7470911294340433, 0.7980752738270966, 0.8311358993614417], 
             UndirectedEdge[170, 239] -> 
             RGBColor[
              0.7632494037090984, 0.7348495878023716, 0.6149740074225174], 
             UndirectedEdge[152, 333] -> 
             RGBColor[
              0.9448991860936097, 0.9538104370406051, 0.720078475098926], 
             UndirectedEdge[14, 250] -> 
             RGBColor[
              0.5532708332786912, 0.6447115186159309, 0.9594983919345609], 
             UndirectedEdge[55, 159] -> 
             RGBColor[
              0.9146038548108921, 0.931590159353637, 0.8656984984992713], 
             UndirectedEdge[234, 331] -> 
             RGBColor[
              0.4467006222801954, 0.558370869161836, 0.9505023389876073], 
             UndirectedEdge[370, 389] -> 
             RGBColor[
              0.4706530085811908, 0.5805458805382757, 0.9516338213328097], 
             UndirectedEdge[119, 316] -> 
             RGBColor[
              0.8137574563401564, 0.8530294545178042, 0.8758641278849717], 
             UndirectedEdge[89, 227] -> 
             RGBColor[
              0.7221660436884079, 0.78268401841517, 0.9730770081539579], 
             UndirectedEdge[246, 254] -> 
             RGBColor[
              0.7309477706350208, 0.785617658432905, 0.8616881268060481], 
             UndirectedEdge[197, 345] -> 
             RGBColor[
              0.9042623106499565, 0.9128486987102751, 0.6914778895286879], 
             UndirectedEdge[231, 234] -> 
             RGBColor[
              0.5363268484814334, 0.6296131848232273, 0.9585974760320433], 
             UndirectedEdge[89, 209] -> 
             RGBColor[
              0.6372133771257938, 0.7137156166256242, 0.9663892230502777], 
             UndirectedEdge[233, 317] -> 
             RGBColor[
              0.7981953773020602, 0.5268006160171532, 0.5771399134560578], 
             UndirectedEdge[48, 342] -> 
             RGBColor[
              0.8882621925854053, 0.9137401774054373, 0.989204434961458], 
             UndirectedEdge[24, 104] -> 
             RGBColor[
              0.5687380041760434, 0.6607661590020457, 0.9591922855261444], 
             UndirectedEdge[118, 149] -> 
             RGBColor[
              0.7172900355216658, 0.6180658684988316, 0.59376822120722], 
             UndirectedEdge[34, 53] -> 
             RGBColor[
              0.9595823077094718, 0.8832336852026013, 0.5862542004558515], 
             UndirectedEdge[29, 45] -> 
             RGBColor[
              0.7200661942093562, 0.7801030155060276, 0.9738833087333245], 
             UndirectedEdge[35, 208] -> 
             RGBColor[
              0.7892459380534589, 0.8328076437038632, 0.8604629247057949], 
             UndirectedEdge[69, 191] -> 
             RGBColor[
              0.893609001469466, 0.9164336365470396, 0.9256225014298219], 
             UndirectedEdge[102, 166] -> 
             RGBColor[
              0.5531518046989659, 0.6429946137155118, 0.9601738477090627], 
             UndirectedEdge[185, 213] -> 
             RGBColor[
              0.5395099975812285, 0.6370375465416831, 0.9568913497812847], 
             UndirectedEdge[172, 364] -> 
             RGBColor[
              0.8242511362184819, 0.8625120515342877, 0.9305583020266714], 
             UndirectedEdge[36, 55] -> 
             RGBColor[
              0.9790004842802413, 0.982211309996965, 0.8466360721187083], 
             UndirectedEdge[192, 203] -> 
             RGBColor[
              0.853397094403966, 0.8847414976958143, 0.9089956392940871], 
             UndirectedEdge[105, 394] -> 
             RGBColor[
              0.4865963168834211, 0.5937826055980882, 0.9528079168789552], 
             UndirectedEdge[256, 261] -> 
             RGBColor[
              0.5285608175780371, 0.6180595305958231, 0.9589430384193915], 
             UndirectedEdge[215, 295] -> 
             RGBColor[
              0.6275228707560994, 0.7049891897982337, 0.9659483270317235], 
             UndirectedEdge[219, 357] -> 
             RGBColor[
              0.7028486573133007, 0.7677634363226921, 0.9710351918117338], 
             UndirectedEdge[204, 295] -> 
             RGBColor[
              0.8830923653034461, 0.909560415538881, 0.9867183978601766], 
             UndirectedEdge[24, 138] -> 
             RGBColor[
              0.6510943769656253, 0.7268488720944081, 0.9662075356600079], 
             UndirectedEdge[135, 376] -> 
             RGBColor[
              0.8436272667435545, 0.8781494991219312, 0.9849471158885936], 
             UndirectedEdge[127, 305] -> 
             RGBColor[
              0.5271610104241686, 0.6254812085419011, 0.9564021290435911], 
             UndirectedEdge[54, 158] -> 
             RGBColor[
              0.7255157379224524, 0.7854976756796359, 0.9732762864922117], 
             UndirectedEdge[180, 350] -> 
             RGBColor[
              0.5934535658272471, 0.6739288235156247, 0.964491585123838], 
             UndirectedEdge[46, 287] -> 
             RGBColor[
              0.6793263280187474, 0.7462694258710767, 0.9709015563205774], 
             UndirectedEdge[41, 153] -> 
             RGBColor[
              0.6331900459153014, 0.7099000232364913, 0.9663084165050826], 
             UndirectedEdge[163, 315] -> 
             RGBColor[
              0.8912814904732148, 0.9089516419709647, 0.6993374787447106], 
             UndirectedEdge[17, 64] -> 
             RGBColor[
              0.7051749401955701, 0.7667613528863614, 0.9464529859142854], 
             UndirectedEdge[67, 127] -> 
             RGBColor[
              0.8201505088665448, 0.8587420217338925, 0.904458059379841], 
             UndirectedEdge[83, 246] -> 
             RGBColor[
              0.7442748265076788, 0.7964371627673539, 0.8627372814629579], 
             UndirectedEdge[44, 383] -> 
             RGBColor[
              0.7130667022285924, 0.5245269610553367, 0.5774493643373817], 
             UndirectedEdge[5, 275] -> 
             RGBColor[
              0.9626335744812899, 0.970858069150138, 0.9125478418897682], 
             UndirectedEdge[99, 123] -> 
             RGBColor[
              0.6706149510908981, 0.7411188225692755, 0.9688229700572899], 
             UndirectedEdge[278, 354] -> 
             RGBColor[
              0.513150665752919, 0.6156378534890949, 0.9548162466223462], 
             UndirectedEdge[61, 215] -> 
             RGBColor[
              0.3806000906837974, 0.5040784018586988, 0.945472479120294], 
             UndirectedEdge[115, 208] -> 
             RGBColor[
              0.7517627094005743, 0.8023770700832438, 0.857512107640649], 
             UndirectedEdge[167, 203] -> 
             RGBColor[
              0.6866711928838185, 0.7551520218659784, 0.9694046252656727], 
             UndirectedEdge[242, 256] -> 
             RGBColor[
              0.633671776994247, 0.6987699649206538, 0.8586122744290898], 
             UndirectedEdge[136, 254] -> 
             RGBColor[
              0.7179918166128636, 0.7773548792706866, 0.946302848372758], 
             UndirectedEdge[65, 170] -> 
             RGBColor[
              0.9435817585487871, 0.8772589574325598, 0.6203474439527725], 
             UndirectedEdge[247, 340] -> 
             RGBColor[
              0.6735757831098393, 0.7427813824975055, 0.9697384159679938], 
             UndirectedEdge[8, 17] -> 
             RGBColor[
              0.6652638339348365, 0.7321923586338412, 0.9439098855153569], 
             UndirectedEdge[269, 300] -> 
             RGBColor[
              0.6622481023360385, 0.7318329211630148, 0.9696495544388], 
             UndirectedEdge[233, 242] -> 
             RGBColor[
              0.8789848670596304, 0.9039858797261892, 0.8777654129269066], 
             UndirectedEdge[242, 382] -> 
             RGBColor[
              0.95316455803174, 0.9626962248163111, 0.8849571096384214], 
             UndirectedEdge[144, 242] -> 
             RGBColor[
              0.9887026404378549, 0.9895962657392248, 0.836890014781481], 
             UndirectedEdge[81, 227] -> 
             RGBColor[
              0.6664635106864449, 0.7391687762791059, 0.9675251002340889], 
             UndirectedEdge[224, 230] -> 
             RGBColor[
              0.49866924318752176`, 0.5907493484580064, 0.9565904391398419], 
             UndirectedEdge[81, 248] -> 
             RGBColor[
              0.8474821308195093, 0.8795035301680146, 0.8804217526631428], 
             UndirectedEdge[13, 323] -> 
             RGBColor[
              0.48509532556471124`, 0.5894781993017428, 0.9535423784517394], 
             UndirectedEdge[10, 189] -> 
             RGBColor[
              0.6652345414655855, 0.7360422461856687, 0.9690441724731946], 
             UndirectedEdge[135, 364] -> 
             RGBColor[
              0.7614623127398108, 0.8139002298769891, 0.9767739702300025], 
             UndirectedEdge[39, 383] -> 
             RGBColor[
              0.7071241065257605, 0.7702652500616527, 0.9720942182245202], 
             UndirectedEdge[108, 196] -> 
             RGBColor[
              0.555456532691157, 0.6496098422098856, 0.9583657279000732], 
             UndirectedEdge[75, 89] -> 
             RGBColor[
              0.8816341198539575, 0.9081681635335217, 0.9771656446219531], 
             UndirectedEdge[131, 269] -> 
             RGBColor[
              0.6363793518669704, 0.7112058817275053, 0.9671821699257541], 
             UndirectedEdge[36, 165] -> 
             RGBColor[
              0.6846203936277558, 0.7490529937646009, 0.9465290961286988], 
             UndirectedEdge[40, 41] -> 
             RGBColor[
              0.6319918096980395, 0.7089445822021023, 0.966194127665002], 
             UndirectedEdge[86, 249] -> 
             RGBColor[
              0.6587161082500047, 0.7315259029869892, 0.9678403749268931], 
             UndirectedEdge[287, 395] -> 
             RGBColor[
              0.6617632294183442, 0.7322650877847265, 0.9692263722973078], 
             UndirectedEdge[177, 225] -> 
             RGBColor[
              0.7252850398173276, 0.7840944340955809, 0.9688326428701], 
             UndirectedEdge[74, 216] -> 
             RGBColor[
              0.6405338695604487, 0.7119045037062814, 0.9588549549668883], 
             UndirectedEdge[229, 371] -> 
             RGBColor[
              0.6139075544569894, 0.697432546397858, 0.9627511299796006], 
             UndirectedEdge[319, 371] -> 
             RGBColor[
              0.7333390137714024, 0.7916420539613895, 0.9740473398453295], 
             UndirectedEdge[169, 353] -> 
             RGBColor[
              0.7307564580096657, 0.7895917660427149, 0.9737986324931913], 
             UndirectedEdge[47, 362] -> 
             RGBColor[
              0.7803335078424192, 0.8289131085401358, 0.9785830769223338], 
             UndirectedEdge[83, 313] -> 
             RGBColor[
              0.48757434214508333`, 0.5948738417840058, 0.952802784738777], 
             UndirectedEdge[87, 210] -> 
             RGBColor[
              0.7530614646495457, 0.8073565074114908, 0.9759315879194375], 
             UndirectedEdge[91, 150] -> 
             RGBColor[
              0.8555202984313998, 0.887814475635847, 0.97692315809797], 
             UndirectedEdge[16, 258] -> 
             RGBColor[
              0.6964654338594248, 0.7554713019741051, 0.8278218073580214], 
             UndirectedEdge[334, 388] -> 
             RGBColor[
              0.7184097179154684, 0.7799463988424278, 0.972568024827448], 
             UndirectedEdge[67, 325] -> 
             RGBColor[
              0.9628608849470544, 0.9711338650529959, 0.9169219685287702], 
             UndirectedEdge[279, 363] -> 
             RGBColor[
              0.5643813817769071, 0.6539299481383302, 0.960377748399786], 
             UndirectedEdge[192, 385] -> 
             RGBColor[
              0.7653162260125532, 0.8144014763969998, 0.9012630256722344], 
             UndirectedEdge[216, 339] -> 
             RGBColor[
              0.7582783859614636, 0.8107234079172043, 0.967232162405516], 
             UndirectedEdge[74, 323] -> 
             RGBColor[
              0.3315666977482037, 0.46160814138787465`, 0.9423481146809649], 
             UndirectedEdge[60, 87] -> 
             RGBColor[
              0.8423352695939136, 0.877119295665136, 0.9848238840470813], 
             UndirectedEdge[74, 198] -> 
             RGBColor[
              0.6637629909490048, 0.7258767948140572, 0.7172531665862105], 
             UndirectedEdge[16, 348] -> 
             RGBColor[
              0.6963031896103653, 0.7551242779307765, 0.8101625221033297], 
             UndirectedEdge[88, 283] -> 
             RGBColor[
              0.5049230088894497, 0.6089582709956127, 0.9541685353351537], 
             UndirectedEdge[292, 388] -> 
             RGBColor[
              0.796168762516979, 0.8410226888957832, 0.9802306593608867], 
             UndirectedEdge[76, 382] -> 
             RGBColor[
              0.8901007908359633, 0.9152062257430122, 0.9893798021039323], 
             UndirectedEdge[131, 352] -> 
             RGBColor[
              0.6745645825994487, 0.7435940655694078, 0.9698048273704236], 
             UndirectedEdge[123, 232] -> 
             RGBColor[
              0.726970904639384, 0.7866344629785796, 0.9734213239112492], 
             UndirectedEdge[69, 357] -> 
             RGBColor[
              0.7205845433987659, 0.7816188453303843, 0.9728029391854541], 
             UndirectedEdge[241, 339] -> 
             RGBColor[
              0.6812621930921262, 0.749816492489003, 0.9696244044840407], 
             UndirectedEdge[181, 322] -> 
             RGBColor[
              0.7695671797970075, 0.7860637452735706, 0.6490165960667423], 
             UndirectedEdge[140, 168] -> 
             RGBColor[
              0.7593326389663542, 0.8080134827391465, 0.8320995958339522], 
             UndirectedEdge[88, 357] -> 
             RGBColor[
              0.5705333233700902, 0.662223680001981, 0.9593336196295708], 
             UndirectedEdge[125, 179] -> 
             RGBColor[
              0.8148571019385634, 0.8556671166534278, 0.9820814087165329], 
             UndirectedEdge[316, 324] -> 
             RGBColor[
              0.7647446709921061, 0.8132386673714391, 0.8720056618826247], 
             UndirectedEdge[128, 390] -> 
             RGBColor[
              0.8756490071070159, 0.9026936800893337, 0.9370061737675217], 
             UndirectedEdge[200, 339] -> 
             RGBColor[
              0.37441355993294745`, 0.4835518084358912, 0.9463923857651098], 
             UndirectedEdge[85, 110] -> 
             RGBColor[
              0.6637428152765152, 0.736139647512154, 0.9678717919381932], 
             UndirectedEdge[178, 209] -> 
             RGBColor[
              0.4792413413262223, 0.5881087363218456, 0.9521467803895284], 
             UndirectedEdge[380, 383] -> 
             RGBColor[
              0.7849627531387207, 0.8276563997663373, 0.7386534112742651], 
             UndirectedEdge[350, 357] -> 
             RGBColor[
              0.4770835917420753, 0.582561703271748, 0.9530255601546955], 
             UndirectedEdge[98, 352] -> 
             RGBColor[
              0.7144928543712668, 0.7750525603096257, 0.9604652407506868], 
             UndirectedEdge[68, 151] -> 
             RGBColor[
              0.63076250953215, 0.7051312211420304, 0.9673811307028966], 
             UndirectedEdge[307, 385] -> 
             RGBColor[
              0.48269071564199545`, 0.5900842027059641, 0.9526462476337476], 
             UndirectedEdge[94, 119] -> 
             RGBColor[
              0.5424073372635212, 0.6392724228487897, 0.9571518533397876], 
             UndirectedEdge[116, 121] -> 
             RGBColor[
              0.6608971323150745, 0.7263274280576877, 0.8920500192507654], 
             UndirectedEdge[1, 361] -> 
             RGBColor[
              0.9897200965210817, 0.9875232744943996, 0.6450961979722226], 
             UndirectedEdge[180, 239] -> 
             RGBColor[
              0.7307750796265322, 0.7892078894137589, 0.9742533919988692], 
             UndirectedEdge[45, 394] -> 
             RGBColor[
              0.7304874511135449, 0.7885634613331212, 0.9747037082511442], 
             UndirectedEdge[32, 124] -> 
             RGBColor[
              0.6152449300833687, 0.6980386863611746, 0.9631843194703695], 
             UndirectedEdge[87, 243] -> 
             RGBColor[
              0.8223061595079122, 0.8614509893140194, 0.9828332519744551], 
             UndirectedEdge[188, 195] -> 
             RGBColor[
              0.8230479739463289, 0.8620039157325191, 0.9512654133352648], 
             UndirectedEdge[122, 262] -> 
             RGBColor[
              0.7136117464953406, 0.7740183155258489, 0.9518419583994355], 
             UndirectedEdge[118, 212] -> 
             RGBColor[
              0.7574624861441147, 0.8092647610503101, 0.9458110745489798], 
             UndirectedEdge[35, 258] -> 
             RGBColor[
              0.7901428157047579, 0.8330296834481359, 0.8347800833342777], 
             UndirectedEdge[183, 271] -> 
             RGBColor[
              0.8628773581540743, 0.8936473914120331, 0.986743828136722], 
             UndirectedEdge[130, 147] -> 
             RGBColor[
              0.6444147946378831, 0.715218826340165, 0.9584142689538151], 
             UndirectedEdge[124, 330] -> 
             RGBColor[
              0.766427357235978, 0.8163597909478552, 0.9416070002692223], 
             UndirectedEdge[46, 395] -> 
             RGBColor[
              0.9150691685449142, 0.9351153323795718, 0.9917613082593459], 
             UndirectedEdge[206, 284] -> 
             RGBColor[
              0.8973580883270191, 0.9200969710314927, 0.9590062001680731], 
             UndirectedEdge[179, 313] -> 
             RGBColor[
              0.6212575315986276, 0.7015512350510769, 0.9645934767623512], 
             UndirectedEdge[215, 363] -> 
             RGBColor[
              0.40717849957658525`, 0.5270992837719584, 0.9471660318325783], 
             UndirectedEdge[260, 338] -> 
             RGBColor[
              0.7411216926601896, 0.7977244020894906, 0.9749336347302042], 
             UndirectedEdge[88, 113] -> 
             RGBColor[
              0.7451701701124382, 0.7977052353708615, 0.8854317288566093], 
             UndirectedEdge[95, 270] -> 
             RGBColor[
              0.7465005290205289, 0.8018144122835857, 0.9756756353256787], 
             UndirectedEdge[16, 184] -> 
             RGBColor[
              0.5771495739739103, 0.6643400338714928, 0.9614660479890857], 
             UndirectedEdge[38, 78] -> 
             RGBColor[
              0.7919829607282556, 0.5641183590001255, 0.581760184562998], 
             UndirectedEdge[8, 210] -> 
             RGBColor[
              0.5045725850899972, 0.6062509046358562, 0.9548211727869169], 
             UndirectedEdge[1, 96] -> 
             RGBColor[
              0.8931310979630198, 0.9125071293461734, 0.7026038836093103], 
             UndirectedEdge[213, 247] -> 
             RGBColor[
              0.5042997324782862, 0.6084522671267478, 0.9541194687329302], 
             UndirectedEdge[109, 366] -> 
             RGBColor[
              0.887869757296807, 0.9124567559975898, 0.9482892094941213], 
             UndirectedEdge[223, 260] -> 
             RGBColor[
              0.5238113924729493, 0.6234592648007908, 0.9558857819429719], 
             UndirectedEdge[393, 399] -> 
             RGBColor[
              0.7572007632999924, 0.8102502583196822, 0.9764343537084479], 
             UndirectedEdge[25, 358] -> 
             RGBColor[
              0.7395404722345211, 0.7928631373641105, 0.8736322662769138], 
             UndirectedEdge[207, 358] -> 
             RGBColor[
              0.8658866916843448, 0.8939331505416286, 0.8846066817324096], 
             UndirectedEdge[31, 33] -> 
             RGBColor[
              0.7833279224340963, 0.8314943638544479, 0.978817313919399], 
             UndirectedEdge[355, 375] -> 
             RGBColor[
              0.6801422914631006, 0.7495210581436181, 0.9691166159614679], 
             UndirectedEdge[25, 104] -> 
             RGBColor[
              0.508122138880398, 0.6115554688414282, 0.9544203825668405], 
             UndirectedEdge[360, 375] -> 
             RGBColor[
              0.7842098889297318, 0.831312211102992, 0.956840293128921], 
             UndirectedEdge[28, 347] -> 
             RGBColor[
              0.6857976650235758, 0.7535154646006498, 0.9699699181907463], 
             UndirectedEdge[56, 143] -> 
             RGBColor[
              0.6909886713269526, 0.7585248688398063, 0.9698349511677544], 
             UndirectedEdge[73, 115] -> 
             RGBColor[
              0.5071493231715183, 0.6107656932241115, 0.954343798950696], 
             UndirectedEdge[157, 218] -> 
             RGBColor[
              0.963803939996787, 0.9575613333903134, 0.6863093299115126], 
             UndirectedEdge[267, 321] -> 
             RGBColor[
              0.8946642344424116, 0.9154490101215829, 0.83582304718599], 
             UndirectedEdge[93, 324] -> 
             RGBColor[
              0.7169676921722972, 0.7778336101447507, 0.9733561288131614], 
             UndirectedEdge[178, 245] -> 
             RGBColor[
              0.4956164329773077, 0.6014027734136689, 0.9534358875882389], 
             UndirectedEdge[223, 331] -> 
             RGBColor[
              0.4924866978341492, 0.5980284665316009, 0.9534197872348683], 
             UndirectedEdge[318, 367] -> 
             RGBColor[
              0.7759253431991573, 0.8250444602389719, 0.9684727367172368], 
             UndirectedEdge[158, 265] -> 
             RGBColor[
              0.6424185809538154, 0.7196798104430886, 0.9656104593782805], 
             UndirectedEdge[124, 199] -> 
             RGBColor[
              0.5681577579908457, 0.6602950890091095, 0.959146606420934], 
             UndirectedEdge[38, 213] -> 
             RGBColor[
              0.6881225825613814, 0.4813122501311401, 0.5725498619192041], 
             UndirectedEdge[128, 296] -> 
             RGBColor[
              0.5962133483691983, 0.6804390674949747, 0.9628555969967444], 
             UndirectedEdge[89, 315] -> 
             RGBColor[
              0.8032884969078264, 0.8462543460938708, 0.9810279482801191], 
             UndirectedEdge[129, 178] -> 
             RGBColor[
              0.7318536242803151, 0.7886705205178248, 0.9490570610545654], 
             UndirectedEdge[61, 279] -> 
             RGBColor[
              0.5378029728841194, 0.6309090662250705, 0.9586841956875016], 
             UndirectedEdge[7, 332] -> 
             RGBColor[
              0.6949175751987176, 0.7614517496140202, 0.9703239132562961], 
             UndirectedEdge[105, 180] -> 
             RGBColor[
              0.6578686941389932, 0.7297219700607729, 0.9685960601398012], 
             UndirectedEdge[75, 163] -> 
             RGBColor[
              0.9696271134193459, 0.9708654594106154, 0.6954751750865447], 
             UndirectedEdge[15, 273] -> 
             RGBColor[
              0.8580814473129419, 0.8883036923789606, 0.9050524678154295], 
             UndirectedEdge[149, 287] -> 
             RGBColor[
              0.6582221271268454, 0.5693706853434315, 0.5893229732351976], 
             UndirectedEdge[123, 275] -> 
             RGBColor[
              0.8925545102167759, 0.9151869850942872, 0.9063424574064408], 
             UndirectedEdge[186, 226] -> 
             RGBColor[
              0.7384781483781633, 0.7945155446720669, 0.9621024609050766], 
             UndirectedEdge[15, 183] -> 
             RGBColor[
              0.9564240146427366, 0.9659714274286647, 0.9146309549204664], 
             UndirectedEdge[35, 41] -> 
             RGBColor[
              0.5116819543897699, 0.6140346655164935, 0.9548141356052257], 
             UndirectedEdge[47, 54] -> 
             RGBColor[
              0.8214192758919819, 0.8610096228038566, 0.9826781223131822], 
             UndirectedEdge[19, 196] -> 
             RGBColor[
              0.6489372429557332, 0.7255914683252178, 0.9657000669464495], 
             UndirectedEdge[211, 328] -> 
             RGBColor[
              0.8347115272395307, 0.8716356676640016, 0.9839387405045942], 
             UndirectedEdge[3, 86] -> 
             RGBColor[
              0.8907264537689614, 0.9136258007014637, 0.9001252610734506], 
             UndirectedEdge[55, 58] -> 
             RGBColor[
              0.801903116840597, 0.8429249703982363, 0.8548400589486962], 
             UndirectedEdge[63, 214] -> 
             RGBColor[
              0.8989004878139084, 0.9215227085419813, 0.9659442524010446], 
             UndirectedEdge[26, 106] -> 
             RGBColor[
              0.820068271282544, 0.8597068498244942, 0.9826091079834451], 
             UndirectedEdge[89, 378] -> 
             RGBColor[
              0.877216705130017, 0.9048736628652595, 0.9846431755033047], 
             UndirectedEdge[191, 311] -> 
             RGBColor[
              0.9465202917523494, 0.8276175045236074, 0.5570041729074432], 
             UndirectedEdge[147, 364] -> 
             RGBColor[
              0.5023190309801064, 0.6034851247910678, 0.9550220443588548], 
             UndirectedEdge[137, 285] -> 
             RGBColor[
              0.9687400223275393, 0.9731323979418964, 0.7575292958449013], 
             UndirectedEdge[104, 205] -> 
             RGBColor[
              0.616370360941683, 0.6984871889091452, 0.9635909587780481], 
             UndirectedEdge[191, 339] -> 
             RGBColor[
              0.778287636840396, 0.8252337323941923, 0.9148872433106476], 
             UndirectedEdge[40, 167] -> 
             RGBColor[
              0.7402664940365351, 0.7970680536909309, 0.9747340382276312], 
             UndirectedEdge[17, 262] -> 
             RGBColor[
              0.7163146469658863, 0.7760341342711885, 0.9472666529321474], 
             UndirectedEdge[96, 348] -> 
             RGBColor[
              0.894304633964452, 0.9150573780338342, 0.826919941489213], 
             UndirectedEdge[60, 122] -> 
             RGBColor[
              0.8913478458346975, 0.9155723288231672, 0.9677164148965116], 
             UndirectedEdge[99, 187] -> 
             RGBColor[
              0.5294671844860992, 0.6288843384474829, 0.9561007427463996], 
             UndirectedEdge[111, 166] -> 
             RGBColor[
              0.8561963213892454, 0.8883970498869136, 0.9797472929422426], 
             UndirectedEdge[130, 172] -> 
             RGBColor[
              0.9663468998762585, 0.9742457530833849, 0.9339505266216316], 
             UndirectedEdge[205, 230] -> 
             RGBColor[
              0.47503836123198406`, 0.5722887238729856, 0.9542351336696613], 
             UndirectedEdge[248, 319] -> 
             RGBColor[
              0.907792496703408, 0.9266512221017291, 0.8864242286312007], 
             UndirectedEdge[77, 111] -> 
             RGBColor[
              0.9663741778240519, 0.9734753810068695, 0.8984944775082662], 
             UndirectedEdge[41, 188] -> 
             RGBColor[
              0.704508428747423, 0.765861456923706, 0.9417023973726486], 
             UndirectedEdge[57, 278] -> 
             RGBColor[
              0.5494382355177898, 0.6450977373606055, 0.9576729370399847], 
             UndirectedEdge[56, 331] -> 
             RGBColor[
              0.6346898635390386, 0.713318185740665, 0.965061579728326], 
             UndirectedEdge[40, 87] -> 
             RGBColor[
              0.8439165560826745, 0.8783801705883957, 0.9849747085640105], 
             UndirectedEdge[142, 214] -> 
             RGBColor[
              0.7333139811737075, 0.7899214117930348, 0.9509236695098975], 
             UndirectedEdge[341, 368] -> 
             RGBColor[
              0.9020453303583138, 0.9239919739242843, 0.9649147061939336], 
             UndirectedEdge[96, 188] -> 
             RGBColor[
              0.8823267016321615, 0.9083129083357084, 0.9571737629197827], 
             UndirectedEdge[142, 202] -> 
             RGBColor[
              0.745013539892406, 0.7983051153317564, 0.915812498897455], 
             UndirectedEdge[37, 351] -> 
             RGBColor[
              0.6297708289815714, 0.7038568996313648, 0.9675091628486132], 
             UndirectedEdge[83, 108] -> 
             RGBColor[
              0.472972012785914, 0.582929238718248, 0.9516780407783041], 
             UndirectedEdge[72, 119] -> 
             RGBColor[
              0.6219807684697253, 0.7039910336148543, 0.963383750966015], 
             UndirectedEdge[170, 180] -> 
             RGBColor[
              0.905840509926407, 0.8475042043596581, 0.6285042559642737], 
             UndirectedEdge[196, 234] -> 
             RGBColor[
              0.49597601107130534`, 0.5980908039607126, 0.9545756816590163], 
             UndirectedEdge[218, 306] -> 
             RGBColor[
              0.6148757098474036, 0.6666467789284526, 0.6648023122423727], 
             UndirectedEdge[186, 189] -> 
             RGBColor[
              0.909047857530175, 0.9299275697320074, 0.9777856592801093], 
             UndirectedEdge[20, 135] -> 
             RGBColor[
              0.734843211524763, 0.7926096446944292, 0.9744596310791078], 
             UndirectedEdge[79, 254] -> 
             RGBColor[
              0.6164055418571813, 0.6976085846117983, 0.9642139625259598], 
             UndirectedEdge[93, 355] -> 
             RGBColor[
              0.8243512243098966, 0.863324279123038, 0.982963930674608], 
             UndirectedEdge[211, 301] -> 
             RGBColor[
              0.8937167322459225, 0.9180894792711989, 0.9897246938236032], 
             UndirectedEdge[145, 227] -> 
             RGBColor[
              0.8121699071940671, 0.8507275944884372, 0.8213782757857557], 
             UndirectedEdge[26, 345] -> 
             RGBColor[
              0.8817829560792112, 0.8952669257526641, 0.6892428587354597], 
             UndirectedEdge[132, 140] -> 
             RGBColor[
              0.98743330123146, 0.9881824609808857, 0.8138527879092656], 
             UndirectedEdge[153, 258] -> 
             RGBColor[
              0.9116509072302892, 0.9288950411681336, 0.8462743642341346], 
             UndirectedEdge[56, 344] -> 
             RGBColor[
              0.6109975809604464, 0.6940837234181969, 0.9631964364560486], 
             UndirectedEdge[44, 390] -> 
             RGBColor[
              0.917326047666039, 0.6850143770870734, 0.545885056581645], 
             UndirectedEdge[223, 346] -> 
             RGBColor[
              0.4539263216569678, 0.5667234160258143, 0.9503841731708884], 
             UndirectedEdge[114, 222] -> 
             RGBColor[
              0.616763429578814, 0.6989163538259346, 0.963546657998883], 
             UndirectedEdge[85, 203] -> 
             RGBColor[
              0.7377877251161933, 0.7950846453459435, 0.9744994434874431], 
             UndirectedEdge[156, 261] -> 
             RGBColor[
              0.7820193064605834, 0.82963869286465, 0.9789080341482234], 
             UndirectedEdge[33, 295] -> 
             RGBColor[
              0.7359110708689539, 0.7936854535125513, 0.9742946522875926], 
             UndirectedEdge[59, 395] -> 
             RGBColor[
              0.94286303513145, 0.955253837969881, 0.9174873674148499], 
             UndirectedEdge[334, 371] -> 
             RGBColor[
              0.673987206324129, 0.7452431951636806, 0.9681404040239965], 
             UndirectedEdge[40, 154] -> 
             RGBColor[
              0.6785389499995498, 0.7471444695469466, 0.9697449777358764], 
             UndirectedEdge[300, 306] -> 
             RGBColor[
              0.5840245790160985, 0.6582564535727599, 0.9648784359700808], 
             UndirectedEdge[61, 297] -> 
             RGBColor[
              0.6182521740883501, 0.6944202522323963, 0.9665265056388546], 
             UndirectedEdge[97, 350] -> 
             RGBColor[
              0.6342224882366045, 0.7059416107414933, 0.9512097111347768], 
             UndirectedEdge[178, 229] -> 
             RGBColor[
              0.5420277553986603, 0.6390815757615713, 0.9570895568995237], 
             UndirectedEdge[130, 265] -> 
             RGBColor[
              0.7654670768464782, 0.8165336416494822, 0.9671042303292514], 
             UndirectedEdge[110, 134] -> 
             RGBColor[
              0.770582034860056, 0.8199197694909296, 0.9469503143627552], 
             UndirectedEdge[147, 211] -> 
             RGBColor[
              0.6322425096466451, 0.7058157452315056, 0.9677504407343218], 
             UndirectedEdge[78, 185] -> 
             RGBColor[
              0.6433703757481027, 0.7198436554106685, 0.9661016724250786], 
             UndirectedEdge[130, 135] -> 
             RGBColor[
              0.9035580763975875, 0.9256339314260862, 0.9801661948249626], 
             UndirectedEdge[52, 384] -> 
             RGBColor[
              0.5106654512380486, 0.612530584027883, 0.954921677836319], 
             UndirectedEdge[77, 166] -> 
             RGBColor[
              0.8798353650715842, 0.9050598935715057, 0.8964231102347386], 
             UndirectedEdge[24, 76] -> 
             RGBColor[
              0.7375812127389303, 0.7947858946432436, 0.9747287924924868], 
             UndirectedEdge[100, 220] -> 
             RGBColor[
              0.7483349847217369, 0.8035895248088412, 0.9754910782641297], 
             UndirectedEdge[41, 369] -> 
             RGBColor[
              0.7159144717513077, 0.7713827131752528, 0.7492019518369458], 
             UndirectedEdge[12, 318] -> 
             RGBColor[
              0.7990420674942038, 0.8408119209517264, 0.8633802441075468], 
             UndirectedEdge[118, 199] -> 
             RGBColor[
              0.5619645068914207, 0.6552671287638138, 0.9586590510077608], 
             UndirectedEdge[11, 205] -> 
             RGBColor[
              0.7227014624414577, 0.7832991422845971, 0.9729957858131657], 
             UndirectedEdge[120, 136] -> 
             RGBColor[
              0.9251169510542671, 0.942327591675796, 0.9649980900117763], 
             UndirectedEdge[66, 215] -> 
             RGBColor[
              0.35409824659046923`, 0.4785961960599907, 0.9438763543487585], 
             UndirectedEdge[199, 287] -> 
             RGBColor[
              0.5028965984966002, 0.6065719456084138, 0.9542138030357383], 
             UndirectedEdge[8, 64] -> 
             RGBColor[
              0.4049705839246922, 0.5251868982073561, 0.9470253453996227], 
             UndirectedEdge[312, 361] -> 
             RGBColor[
              0.8196426151397981, 0.8585903929236793, 0.9155231996097135], 
             UndirectedEdge[5, 193] -> 
             RGBColor[
              0.9168989218932511, 0.9365590420270002, 0.9914058563708819], 
             UndirectedEdge[187, 232] -> 
             RGBColor[
              0.5858231380345852, 0.6743999788567872, 0.960699096600359], 
             UndirectedEdge[115, 325] -> 
             RGBColor[
              0.723797873182327, 0.7830367209555298, 0.9727290033985264], 
             UndirectedEdge[137, 252] -> 
             RGBColor[
              0.9438633609548562, 0.9576539670322177, 0.9799088665097986], 
             UndirectedEdge[296, 390] -> 
             RGBColor[
              0.7056591744896135, 0.7658497321469393, 0.9225301401931936], 
             UndirectedEdge[101, 171] -> 
             RGBColor[
              0.6244648753101234, 0.7056800056869366, 0.9638033850584682], 
             UndirectedEdge[234, 342] -> 
             RGBColor[
              0.6137505299995325, 0.6907152028767325, 0.9661503336771724], 
             UndirectedEdge[56, 343] -> 
             RGBColor[
              0.8501525696736728, 0.8795410983472043, 0.7404739379612224], 
             UndirectedEdge[60, 146] -> 
             RGBColor[
              0.5561699449692183, 0.6416199260767879, 0.9613772132273781], 
             UndirectedEdge[149, 336] -> 
             RGBColor[
              0.8385183540918826, 0.7142746938965933, 0.6048226005177861], 
             UndirectedEdge[12, 199] -> 
             RGBColor[
              0.7864153730446628, 0.8305610015714863, 0.8623862244673731], 
             UndirectedEdge[42, 104] -> 
             RGBColor[
              0.4625187820542941, 0.5729928620920239, 0.9512557560253143], 
             UndirectedEdge[216, 323] -> 
             RGBColor[
              0.6376894802447873, 0.7094408366442194, 0.958673712994889], 
             UndirectedEdge[110, 192] -> 
             RGBColor[
              0.779352184564288, 0.825796499862025, 0.9023679877448372], 
             UndirectedEdge[93, 380] -> 
             RGBColor[
              0.9447465194407916, 0.9541039721830007, 0.7537268339294991], 
             UndirectedEdge[34, 397] -> 
             RGBColor[
              0.7338617167846391, 0.7052082417704302, 0.6113290113540343], 
             UndirectedEdge[249, 308] -> 
             RGBColor[
              0.7593687628426227, 0.8066853051078251, 0.7208415933442964], 
             UndirectedEdge[116, 130] -> 
             RGBColor[
              0.6404090244026012, 0.7117492294982299, 0.9581590248165864], 
             UndirectedEdge[81, 315] -> 
             RGBColor[
              0.7475859639058635, 0.8027391039578069, 0.97547604036025], 
             UndirectedEdge[99, 193] -> 
             RGBColor[
              0.721301163406672, 0.7813418588913476, 0.9737086224058116], 
             UndirectedEdge[116, 135] -> 
             RGBColor[
              0.5965270824230586, 0.6770617286428057, 0.9644707012060036], 
             UndirectedEdge[304, 378] -> 
             RGBColor[
              0.6406743385294682, 0.7124502084458408, 0.9650524871531829], 
             UndirectedEdge[56, 120] -> 
             RGBColor[
              0.795278810993651, 0.8405107251185645, 0.9800933222600744], 
             UndirectedEdge[255, 393] -> 
             RGBColor[
              0.6732530599117152, 0.7443873500210798, 0.9682602578948791], 
             UndirectedEdge[106, 214] -> 
             RGBColor[
              0.9126983654270229, 0.9325247616172685, 0.9672603062852942], 
             UndirectedEdge[130, 328] -> 
             RGBColor[
              0.8468838122307687, 0.881038748772661, 0.9746025687240876], 
             UndirectedEdge[181, 250] -> 
             RGBColor[
              0.6502848833062038, 0.7256016165725139, 0.9665472448726149], 
             UndirectedEdge[102, 230] -> 
             RGBColor[
              0.2912046875587163, 0.42082541349623626`, 0.9399894983492967], 
             UndirectedEdge[45, 141] -> 
             RGBColor[
              0.8705074905100636, 0.8996567935986495, 0.9874914089736014], 
             UndirectedEdge[225, 288] -> 
             RGBColor[
              0.8050719735543306, 0.8484728011310434, 0.9753846877799062], 
             UndirectedEdge[208, 278] -> 
             RGBColor[
              0.7471429557982807, 0.7986265459913737, 0.8571484237143614], 
             UndirectedEdge[342, 346] -> 
             RGBColor[
              0.6908401365723188, 0.756619863835478, 0.9713018266931521], 
             UndirectedEdge[133, 164] -> 
             RGBColor[
              0.9081765254490383, 0.9260049494478413, 0.8362385699634916], 
             UndirectedEdge[287, 373] -> 
             RGBColor[
              0.4017246980272473, 0.522375474985958, 0.9468185204204618], 
             UndirectedEdge[122, 314] -> 
             RGBColor[
              0.7544797552293824, 0.8071968060989565, 0.955059237751428], 
             UndirectedEdge[85, 351] -> 
             RGBColor[
              0.5493544307925686, 0.6402443638317495, 0.9597038178570435], 
             UndirectedEdge[5, 338] -> 
             RGBColor[
              0.8967675824273034, 0.9205068583875062, 0.989485711241161], 
             UndirectedEdge[311, 339] -> 
             RGBColor[
              0.7381327747778483, 0.6640933890011975, 0.601400701127015], 
             UndirectedEdge[39, 324] -> 
             RGBColor[
              0.687731890043449, 0.7545217751119153, 0.9705675919070031], 
             UndirectedEdge[52, 346] -> 
             RGBColor[
              0.5466870547656177, 0.6428642048867117, 0.9574563540132666], 
             UndirectedEdge[272, 291] -> 
             RGBColor[
              0.7866889300818819, 0.8293958788619893, 0.7664991736753604], 
             UndirectedEdge[191, 323] -> 
             RGBColor[
              0.6576987311237198, 0.7239511611212075, 0.9063287939000206], 
             UndirectedEdge[60, 165] -> 
             RGBColor[
              0.6139919395749714, 0.6934627553568137, 0.9649971255172782], 
             UndirectedEdge[44, 301] -> 
             RGBColor[
              0.856947639100919, 0.6382940489555273, 0.5910059609249834], 
             UndirectedEdge[11, 144] -> 
             RGBColor[
              0.8631267661789662, 0.8928984844001799, 0.935181027315767], 
             UndirectedEdge[333, 381] -> 
             RGBColor[
              0.9927097053279139, 0.9890519441133718, 0.6104679687335033], 
             UndirectedEdge[9, 363] -> 
             RGBColor[
              0.5500039325296092, 0.6426981755136796, 0.9589447386237175], 
             UndirectedEdge[153, 312] -> 
             RGBColor[
              0.7402376455985138, 0.7970648868664238, 0.9747260227370311], 
             UndirectedEdge[55, 80] -> 
             RGBColor[
              0.8972481702195656, 0.917909614281488, 0.8640010615381541], 
             UndirectedEdge[7, 40] -> 
             RGBColor[
              0.7912842063550208, 0.8369234783031065, 0.9798190070039097], 
             UndirectedEdge[51, 377] -> 
             RGBColor[
              0.9080870906709335, 0.9271904322457009, 0.8996664708204287], 
             UndirectedEdge[112, 170] -> 
             RGBColor[
              0.7589168970950013, 0.7313322637558488, 0.614632936631361], 
             UndirectedEdge[200, 375] -> 
             RGBColor[
              0.3933264046315438, 0.49890610777615585`, 0.9478812741798162], 
             UndirectedEdge[94, 200] -> 
             RGBColor[
              0.31396219722151353`, 0.43435735431324973`, 0.9416658474172356],
              UndirectedEdge[8, 253] -> 
             RGBColor[
              0.5325947994472949, 0.6281420714684943, 0.9576141652315705], 
             UndirectedEdge[31, 295] -> 
             RGBColor[
              0.8756734987736113, 0.9037022946709032, 0.9880037141076294], 
             UndirectedEdge[301, 383] -> 
             RGBColor[
              0.7204570792248645, 0.7808966005780156, 0.973365929063046], 
             UndirectedEdge[327, 392] -> 
             RGBColor[
              0.6880914542324619, 0.7547566080505329, 0.9706615932361455], 
             UndirectedEdge[119, 375] -> 
             RGBColor[
              0.6217715446735514, 0.7038211763116958, 0.9633672801023683], 
             UndirectedEdge[160, 340] -> 
             RGBColor[
              0.9174531583871207, 0.8937567683349881, 0.6491759238387169], 
             UndirectedEdge[151, 308] -> 
             RGBColor[
              0.9493914341437777, 0.9576128588133306, 0.7383753240644386], 
             UndirectedEdge[221, 276] -> 
             RGBColor[
              0.9837614592484653, 0.9809820686438893, 0.6706477235103718], 
             UndirectedEdge[94, 316] -> 
             RGBColor[
              0.7203475135196623, 0.777077740295514, 0.8685429693796554], 
             UndirectedEdge[195, 206] -> 
             RGBColor[
              0.7497685582450369, 0.8044788076662471, 0.9756843874020027], 
             UndirectedEdge[159, 192] -> 
             RGBColor[0.911642933651357, 0.9303657423619662, 0.9147686247311],
              UndirectedEdge[220, 350] -> 
             RGBColor[
              0.4771089105142941, 0.5825822581916329, 0.9530275533411903], 
             UndirectedEdge[229, 319] -> 
             RGBColor[
              0.7046076240801677, 0.7683209058630005, 0.9717825676084618], 
             UndirectedEdge[69, 97] -> 
             RGBColor[
              0.8777234398932952, 0.9049987528001295, 0.9709870901655355], 
             UndirectedEdge[90, 317] -> 
             RGBColor[
              0.6051047163162072, 0.3699277317892652, 0.5612004481226316], 
             UndirectedEdge[136, 237] -> 
             RGBColor[
              0.7319799909207256, 0.7887111093338803, 0.9474040486946437], 
             UndirectedEdge[69, 141] -> 
             RGBColor[
              0.8057021796248844, 0.8481399333771046, 0.981268521616208], 
             UndirectedEdge[48, 143] -> 
             RGBColor[
              0.7775110926539824, 0.8266025267896822, 0.9783298117113213], 
             UndirectedEdge[51, 246] -> 
             RGBColor[
              0.909415577445462, 0.9277397956675212, 0.8776500069529269], 
             UndirectedEdge[97, 132] -> 
             RGBColor[
              0.9673329277200536, 0.9751575314978134, 0.9401810118196785], 
             UndirectedEdge[94, 383] -> 
             RGBColor[
              0.5127867683977825, 0.6152251106521622, 0.9548200136549577], 
             UndirectedEdge[246, 344] -> 
             RGBColor[
              0.7537916750432199, 0.8041633691376469, 0.8634864826410407], 
             UndirectedEdge[155, 354] -> 
             RGBColor[
              0.7526222480128341, 0.8050332524793437, 0.9373303754367877], 
             UndirectedEdge[107, 307] -> 
             RGBColor[
              0.5471560365326087, 0.6419755788123455, 0.9580250841805593], 
             UndirectedEdge[310, 363] -> 
             RGBColor[
              0.4820720236009892, 0.5886215424771404, 0.9528628972764885], 
             UndirectedEdge[99, 281] -> 
             RGBColor[
              0.7237522374718974, 0.7832962788183251, 0.9739424080382524], 
             UndirectedEdge[123, 187] -> 
             RGBColor[
              0.6549858787081642, 0.728430437527285, 0.9675925922281425], 
             UndirectedEdge[23, 227] -> 
             RGBColor[
              0.7974884299759106, 0.8419346681559776, 0.9536569504800612], 
             UndirectedEdge[28, 211] -> 
             RGBColor[
              0.7515839441069692, 0.8057416172659637, 0.9763057179079724], 
             UndirectedEdge[327, 356] -> 
             RGBColor[
              0.6389334630777852, 0.716147290852983, 0.9658168414542959], 
             UndirectedEdge[140, 219] -> 
             RGBColor[
              0.8800879273192362, 0.9041682732755097, 0.8428911188814023], 
             UndirectedEdge[104, 144] -> 
             RGBColor[
              0.7567956646791915, 0.808086531024728, 0.9257762002806493], 
             UndirectedEdge[49, 328] -> 
             RGBColor[
              0.6267804645335953, 0.7062949766594282, 0.964850515368085], 
             UndirectedEdge[112, 271] -> 
             RGBColor[
              0.6905717965587264, 0.7572365738385014, 0.9704515558719713], 
             UndirectedEdge[106, 197] -> 
             RGBColor[
              0.8425476258532894, 0.8772886227821052, 0.9848441387766733], 
             UndirectedEdge[106, 204] -> 
             RGBColor[
              0.9002372679271378, 0.9232312955050286, 0.9883536939778597], 
             UndirectedEdge[50, 158] -> 
             RGBColor[
              0.7291746880528696, 0.7883560753305688, 0.9736409764463787], 
             UndirectedEdge[259, 299] -> 
             RGBColor[
              0.678086736372898, 0.7463169267356458, 0.9702393075234645], 
             UndirectedEdge[79, 286] -> 
             RGBColor[
              0.7729311252844503, 0.8225389366571197, 0.9780022091824682], 
             UndirectedEdge[240, 388] -> 
             RGBColor[
              0.7550142715655204, 0.8085421543587599, 0.9762164246462828], 
             UndirectedEdge[118, 299] -> 
             RGBColor[
              0.5054531057210774, 0.6093886274841183, 0.9542102664995481], 
             UndirectedEdge[138, 257] -> 
             RGBColor[
              0.8215530240116357, 0.8612054224454215, 0.9698140096675272], 
             UndirectedEdge[171, 244] -> 
             RGBColor[
              0.82865960482558, 0.8629472289638653, 0.754078227443802], 
             UndirectedEdge[161, 337] -> 
             RGBColor[
              0.7538187612081751, 0.8076082125813866, 0.976097267346542], 
             UndirectedEdge[119, 355] -> 
             RGBColor[
              0.6941880268735645, 0.7609240189030022, 0.9702223477042037], 
             UndirectedEdge[248, 292] -> 
             RGBColor[
              0.9261997338576451, 0.9413286533573758, 0.8881799273433064], 
             UndirectedEdge[68, 386] -> 
             RGBColor[
              0.5967365534229538, 0.6779998473505314, 0.9641357046338718], 
             UndirectedEdge[126, 299] -> 
             RGBColor[
              0.524067803965451, 0.6245008781015002, 0.9556756837332316], 
             UndirectedEdge[128, 383] -> 
             RGBColor[
              0.6713896616695691, 0.7422062640575969, 0.9685704815232585], 
             UndirectedEdge[229, 248] -> 
             RGBColor[
              0.7883610373889951, 0.8324417145381976, 0.8751280187654717], 
             UndirectedEdge[395, 396] -> 
             RGBColor[
              0.9117466881009657, 0.9324660766598962, 0.9914444071085888], 
             UndirectedEdge[81, 292] -> 
             RGBColor[
              0.782135954664919, 0.8300601527484642, 0.9788320002182387], 
             UndirectedEdge[34, 253] -> 
             RGBColor[
              0.8173882166308981, 0.772133837275447, 0.6185095889778729], 
             UndirectedEdge[130, 322] -> 
             RGBColor[
              0.9588321466159564, 0.9357715305366341, 0.6563409391152997], 
             UndirectedEdge[74, 311] -> 
             RGBColor[
              0.6203882583768334, 0.5652744847902746, 0.5930234936883874], 
             UndirectedEdge[232, 235] -> 
             RGBColor[
              0.7978681236821142, 0.8429157255284185, 0.978241785763998], 
             UndirectedEdge[207, 221] -> 
             RGBColor[
              0.8654977594968756, 0.8883901570359637, 0.696155675213118], 
             UndirectedEdge[140, 216] -> 
             RGBColor[
              0.9708807148712002, 0.9758375691757767, 0.8418719990112449], 
             UndirectedEdge[31, 173] -> 
             RGBColor[
              0.9076451123557078, 0.9291955914949354, 0.9910531951524862], 
             UndirectedEdge[37, 243] -> 
             RGBColor[
              0.8501890278831504, 0.8836840316961349, 0.9854927448514159], 
             UndirectedEdge[1, 35] -> 
             RGBColor[
              0.7888070354542661, 0.8301324107171464, 0.6928047401996833], 
             UndirectedEdge[60, 210] -> 
             RGBColor[
              0.7333594974604041, 0.7916466935705218, 0.9740523967007835], 
             UndirectedEdge[35, 92] -> 
             RGBColor[
              0.7224261495918998, 0.7825289144350656, 0.9734821144785564], 
             UndirectedEdge[52, 291] -> 
             RGBColor[
              0.8010015784190848, 0.8410155315595904, 0.7676259177814234], 
             UndirectedEdge[77, 400] -> 
             RGBColor[
              0.8655513491408082, 0.8939011117638416, 0.8949994130184771], 
             UndirectedEdge[77, 389] -> 
             RGBColor[
              0.7107925098943148, 0.7691828788797077, 0.8819453230283587], 
             UndirectedEdge[96, 361] -> 
             RGBColor[
              0.890413288341324, 0.913876980705749, 0.922576958924899], 
             UndirectedEdge[150, 374] -> 
             RGBColor[
              0.8750753591678074, 0.902277446704035, 0.9383956944925416], 
             UndirectedEdge[80, 154] -> 
             RGBColor[
              0.6658338035028974, 0.7371721373159972, 0.9684911132498136], 
             UndirectedEdge[200, 383] -> 
             RGBColor[
              0.3777515711762689, 0.48626175633891244`, 0.9466551662377222], 
             UndirectedEdge[144, 391] -> 
             RGBColor[
              0.9347638502921914, 0.9493822756747825, 0.9421830557039947], 
             UndirectedEdge[196, 290] -> 
             RGBColor[
              0.4695718325238427, 0.5724005545081124, 0.9529964949106409], 
             UndirectedEdge[159, 228] -> 
             RGBColor[
              0.7038008904568855, 0.7675859473592497, 0.9718111553069742], 
             UndirectedEdge[27, 377] -> 
             RGBColor[
              0.966860083710757, 0.9738465549152377, 0.8980654248118275], 
             UndirectedEdge[24, 233] -> 
             RGBColor[
              0.6873886217013339, 0.7552022119284202, 0.9698250067862626], 
             UndirectedEdge[24, 109] -> 
             RGBColor[
              0.701714570216897, 0.7663937517900193, 0.9712528834506935], 
             UndirectedEdge[189, 255] -> 
             RGBColor[
              0.745668199696212, 0.8013419134323015, 0.9753762046873078], 
             UndirectedEdge[262, 298] -> 
             RGBColor[
              0.6422400518630292, 0.3562142276147652, 0.5577068899171376], 
             UndirectedEdge[249, 397] -> 
             RGBColor[
              0.5293778809265894, 0.6288118377947933, 0.9560937124430653], 
             UndirectedEdge[128, 324] -> 
             RGBColor[
              0.6519974451872577, 0.7264627891078594, 0.9670438552057413], 
             UndirectedEdge[7, 228] -> 
             RGBColor[
              0.6646386833349383, 0.7368699811504703, 0.9679402479735439], 
             UndirectedEdge[115, 258] -> 
             RGBColor[
              0.7526595870518732, 0.8025991098275165, 0.8318292662691318], 
             UndirectedEdge[375, 383] -> 
             RGBColor[
              0.5921509758078126, 0.6797738641150683, 0.9610354404175383], 
             UndirectedEdge[257, 338] -> 
             RGBColor[
              0.9036047098405233, 0.9256059768175169, 0.9779122379390025], 
             UndirectedEdge[5, 321] -> 
             RGBColor[
              0.8653360898496874, 0.8956511837110221, 0.9864328307603712], 
             UndirectedEdge[65, 239] -> 
             RGBColor[
              0.7685163282489125, 0.8189626424866605, 0.9660965799873679], 
             UndirectedEdge[56, 71] -> 
             RGBColor[
              0.6302716225592353, 0.7097312586737727, 0.964713759613846], 
             UndirectedEdge[276, 322] -> 
             RGBColor[
              0.9736305586213647, 0.9468081619800917, 0.6312910876341387], 
             UndirectedEdge[239, 326] -> 
             RGBColor[
              0.5974133893032139, 0.6840461284596613, 0.9614497168847521], 
             UndirectedEdge[379, 393] -> 
             RGBColor[
              0.8451531077619252, 0.8793274992440444, 0.9562469146637959], 
             UndirectedEdge[131, 262] -> 
             RGBColor[
              0.6688547432319205, 0.7389585607455162, 0.9693553278995811], 
             UndirectedEdge[201, 210] -> 
             RGBColor[
              0.6635085177359703, 0.7370571639976282, 0.9670959862744413], 
             UndirectedEdge[301, 372] -> 
             RGBColor[
              0.9265279810054696, 0.9421331417125228, 0.9117794445436396], 
             UndirectedEdge[291, 398] -> 
             RGBColor[
              0.8926908951053008, 0.9131680488470579, 0.7764063040190137], 
             UndirectedEdge[28, 49] -> 
             RGBColor[
              0.5436528814010338, 0.6404009262613902, 0.9572174927714632], 
             UndirectedEdge[6, 160] -> 
             RGBColor[
              0.8084457316394654, 0.8081795520777515, 0.6384224805686249], 
             UndirectedEdge[375, 379] -> 
             RGBColor[
              0.7877274429810059, 0.8339355971549662, 0.950885991645142], 
             UndirectedEdge[45, 112] -> 
             RGBColor[
              0.7548362155377112, 0.8083308851919966, 0.9766205321790775], 
             UndirectedEdge[324, 390] -> 
             RGBColor[
              0.7614432713076729, 0.8118734537598241, 0.9267183984021905], 
             UndirectedEdge[169, 227] -> 
             RGBColor[
              0.710515779986987, 0.7735827438663363, 0.9719158187461046], 
             UndirectedEdge[44, 380] -> 
             RGBColor[
              0.9214533130147753, 0.6850538481438493, 0.3562934431362025], 
             UndirectedEdge[288, 360] -> 
             RGBColor[
              0.8144603330003787, 0.8554746242338784, 0.9594926441140511], 
             UndirectedEdge[87, 134] -> 
             RGBColor[
              0.9163429265528316, 0.9352297380673806, 0.9606357455756884], 
             UndirectedEdge[85, 258] -> 
             RGBColor[
              0.8760398218996435, 0.901009045633954, 0.84274258998117], 
             UndirectedEdge[26, 77] -> 
             RGBColor[
              0.8838016558078132, 0.908158390039574, 0.8968184330282316], 
             UndirectedEdge[90, 333] -> 
             RGBColor[
              0.6861387268767491, 0.7450127651994651, 0.697758994220502], 
             UndirectedEdge[45, 91] -> 
             RGBColor[
              0.9379823186425459, 0.9531248913787984, 0.9849059012296458], 
             UndirectedEdge[103, 133] -> 
             RGBColor[
              0.8718539711434772, 0.9006567070169498, 0.9876394041525347], 
             UndirectedEdge[143, 342] -> 
             RGBColor[
              0.7856993205374143, 0.8331315974404059, 0.9791108121965604], 
             UndirectedEdge[75, 164] -> 
             RGBColor[
              0.9716879071821234, 0.976318521615058, 0.8309008122394927], 
             UndirectedEdge[44, 211] -> 
             RGBColor[
              0.8863263552496504, 0.66171983974852, 0.5938081290979389], 
             UndirectedEdge[82, 171] -> 
             RGBColor[
              0.6761840691255021, 0.7469594010808891, 0.9683593667771873], 
             UndirectedEdge[17, 122] -> 
             RGBColor[
              0.9627652897351686, 0.9717509945675069, 0.9479128314973078], 
             UndirectedEdge[150, 186] -> 
             RGBColor[
              0.8579588635692657, 0.8896331535228834, 0.9727953033992122], 
             UndirectedEdge[180, 394] -> 
             RGBColor[
              0.7020938085882686, 0.7659231415083605, 0.9719954972797794], 
             UndirectedEdge[156, 202] -> 
             RGBColor[
              0.884134351148087, 0.909110239457664, 0.9282273303913691], 
             UndirectedEdge[86, 178] -> 
             RGBColor[
              0.6453164611082549, 0.7206474657900921, 0.9667855056193697], 
             UndirectedEdge[102, 250] -> 
             RGBColor[
              0.5341528913171647, 0.628152518184559, 0.9582802135781048], 
             UndirectedEdge[7, 222] -> 
             RGBColor[
              0.6465851168926734, 0.7222132826087397, 0.9665190050908159], 
             UndirectedEdge[97, 220] -> 
             RGBColor[
              0.7977904529402451, 0.842528727872922, 0.9630377347689163], 
             UndirectedEdge[230, 289] -> 
             RGBColor[
              0.37980069322982196`, 0.49591955770924556`, 0.9460887959332176],
              UndirectedEdge[14, 289] -> 
             RGBColor[
              0.4443600483937862, 0.5576608096238549, 0.9499892456897874], 
             UndirectedEdge[77, 370] -> 
             RGBColor[
              0.7498737201932668, 0.8015012263500295, 0.884858793105213], 
             UndirectedEdge[151, 270] -> 
             RGBColor[
              0.900608049281288, 0.9235844284153816, 0.9903819937943877], 
             UndirectedEdge[173, 214] -> 
             RGBColor[
              0.9275250763854277, 0.9443471784751529, 0.9686744912124681], 
             UndirectedEdge[144, 317] -> 
             RGBColor[
              0.9079131506802849, 0.612411002030189, 0.5362645153106322], 
             UndirectedEdge[31, 175] -> 
             RGBColor[
              0.7639029719915531, 0.8157427959585771, 0.9772754744493892], 
             UndirectedEdge[163, 240] -> 
             RGBColor[
              0.8846769902808116, 0.9037921562245986, 0.6986792038880953], 
             UndirectedEdge[329, 371] -> 
             RGBColor[
              0.7979366074930833, 0.8426982353879069, 0.9645311313094658], 
             UndirectedEdge[72, 375] -> 
             RGBColor[
              0.6079350330592613, 0.6925880728554703, 0.9622780192232792], 
             UndirectedEdge[32, 238] -> 
             RGBColor[
              0.5544203950436742, 0.6481583240717822, 0.9585342138722651], 
             UndirectedEdge[11, 14] -> 
             RGBColor[
              0.5579857307297164, 0.6483948323392197, 0.9599683288492573], 
             UndirectedEdge[79, 237] -> 
             RGBColor[
              0.6303937161650434, 0.7089648146749921, 0.9653151628478456], 
             UndirectedEdge[69, 74] -> 
             RGBColor[
              0.5674769680939499, 0.6540906168137067, 0.9616418222107661], 
             UndirectedEdge[16, 203] -> 
             RGBColor[
              0.5582133370759746, 0.6495469016860945, 0.9595786608642944], 
             UndirectedEdge[315, 319] -> 
             RGBColor[
              0.8078963297897623, 0.8498867958915214, 0.981478516328308], 
             UndirectedEdge[40, 80] -> 
             RGBColor[
              0.8130907288856415, 0.8539588994397369, 0.9819924773762227], 
             UndirectedEdge[18, 198] -> 
             RGBColor[
              0.7460961880084316, 0.7959471947217219, 0.7228426652503317], 
             UndirectedEdge[300, 307] -> 
             RGBColor[
              0.6726118893329373, 0.7408095125606483, 0.9703099257819054], 
             UndirectedEdge[191, 198] -> 
             RGBColor[
              0.9898950243245209, 0.9882198145473899, 0.6812338458052665], 
             UndirectedEdge[289, 391] -> 
             RGBColor[
              0.6991008785525208, 0.7634137673954596, 0.9718514764649498], 
             UndirectedEdge[132, 357] -> 
             RGBColor[
              0.8101940312255245, 0.851777624028068, 0.9419968608395972], 
             UndirectedEdge[157, 187] -> 
             RGBColor[
              0.7287289233792054, 0.7868341121711063, 0.9675958136023575], 
             UndirectedEdge[38, 250] -> 
             RGBColor[
              0.7872680632772304, 0.5604350452768369, 0.5812902476483016], 
             UndirectedEdge[140, 191] -> 
             RGBColor[
              0.9908899657501327, 0.9903478936527648, 0.7895270799163765], 
             UndirectedEdge[204, 261] -> 
             RGBColor[
              0.8599736949295034, 0.8914330698067026, 0.9844318886963768], 
             UndirectedEdge[337, 354] -> 
             RGBColor[
              0.6419530049872442, 0.7184251159181594, 0.9661732250884527], 
             UndirectedEdge[300, 314] -> 
             RGBColor[
              0.7355915024350301, 0.7927640907541333, 0.9750399917646194], 
             UndirectedEdge[292, 378] -> 
             RGBColor[
              0.90023177516619, 0.9231835439185567, 0.9868494422635993], 
             UndirectedEdge[153, 361] -> 
             RGBColor[
              0.9075973173581018, 0.9273676197967198, 0.924272096415129], 
             UndirectedEdge[240, 334] -> 
             RGBColor[
              0.7419400221500856, 0.7983284513474465, 0.9749133056503596], 
             UndirectedEdge[52, 260] -> 
             RGBColor[
              0.6165721255815992, 0.6996000536616882, 0.96295796278535], 
             UndirectedEdge[128, 177] -> 
             RGBColor[
              0.6374280054584882, 0.7146346615902643, 0.9658968955406764], 
             UndirectedEdge[16, 85] -> 
             RGBColor[
              0.5773957891153074, 0.6645323790112565, 0.9614905884133689], 
             UndirectedEdge[179, 303] -> 
             RGBColor[
              0.6546683977929466, 0.7286756813699946, 0.9672237025372035], 
             UndirectedEdge[48, 320] -> 
             RGBColor[
              0.6458221287345487, 0.7190571705251863, 0.967934653743694], 
             UndirectedEdge[136, 320] -> 
             RGBColor[
              0.689137847468135, 0.752796379132542, 0.9443445609518291], 
             UndirectedEdge[96, 192] -> 
             RGBColor[
              0.8910066027571668, 0.9141223314641851, 0.9127442036058961], 
             UndirectedEdge[140, 357] -> 
             RGBColor[
              0.8178655076794327, 0.8555331024361095, 0.8367075176720087], 
             UndirectedEdge[202, 306] -> 
             RGBColor[
              0.6160063350959346, 0.6821124740318384, 0.9074269267918488], 
             UndirectedEdge[114, 258] -> 
             RGBColor[
              0.8461193146718949, 0.8776349179833596, 0.8397603934437453], 
             UndirectedEdge[87, 236] -> 
             RGBColor[
              0.8565887346464405, 0.888484621798019, 0.9861833922680099], 
             UndirectedEdge[116, 362] -> 
             RGBColor[
              0.5004474717910234, 0.601682789839028, 0.9549795184333751], 
             UndirectedEdge[36, 64] -> 
             RGBColor[
              0.7043859503478833, 0.7661729255498089, 0.9477885399249097], 
             UndirectedEdge[245, 304] -> 
             RGBColor[
              0.4170461021763303, 0.5345861992980289, 0.9480876418988664], 
             UndirectedEdge[187, 218] -> 
             RGBColor[
              0.748913128720947, 0.7869231746246994, 0.6735838812264073], 
             UndirectedEdge[26, 370] -> 
             RGBColor[
              0.6436621544946893, 0.719521391698142, 0.9665069313326826], 
             UndirectedEdge[91, 141] -> 
             RGBColor[
              0.8783363382582163, 0.9056385393568813, 0.9791972477198924], 
             UndirectedEdge[55, 385] -> 
             RGBColor[
              0.7682771471720885, 0.8156258933886704, 0.8521928994404058], 
             UndirectedEdge[179, 231] -> 
             RGBColor[
              0.7524508895708124, 0.8065396208620693, 0.9759609306852169], 
             UndirectedEdge[94, 177] -> 
             RGBColor[
              0.47882511218670143`, 0.5876535081848295, 0.9521464276723757], 
             UndirectedEdge[225, 383] -> 
             RGBColor[
              0.7592466960284087, 0.8116660365629136, 0.9715062288526821], 
             UndirectedEdge[37, 134] -> 
             RGBColor[
              0.9442257949280697, 0.9574627804494962, 0.9632952384526492], 
             UndirectedEdge[255, 341] -> 
             RGBColor[
              0.7318411610566325, 0.7903166081460663, 0.9740573693983215], 
             UndirectedEdge[206, 278] -> 
             RGBColor[
              0.6626202411669376, 0.7342319839279201, 0.9684790925854603], 
             UndirectedEdge[131, 279] -> 
             RGBColor[
              0.8058716207210781, 0.8486809951308532, 0.9811769553434632], 
             UndirectedEdge[7, 203] -> 
             RGBColor[
              0.7376889052023041, 0.7950074464781541, 0.9744895940419512], 
             UndirectedEdge[101, 151] -> 
             RGBColor[
              0.7454500738415651, 0.8008875666639739, 0.9756781569271893], 
             UndirectedEdge[200, 296] -> 
             RGBColor[
              0.302575257875898, 0.42449455977629014`, 0.940940281711208], 
             UndirectedEdge[86, 229] -> 
             RGBColor[
              0.6884648704753493, 0.7556772883279899, 0.970182306462579], 
             UndirectedEdge[138, 382] -> 
             RGBColor[
              0.8036139550626584, 0.8472692031941768, 0.9808585452714534], 
             UndirectedEdge[195, 278] -> 
             RGBColor[
              0.5881185173334975, 0.6759960266128173, 0.9610626505764085], 
             UndirectedEdge[65, 113] -> 
             RGBColor[
              0.9693743071233971, 0.9757316941689507, 0.89425891278702], 
             UndirectedEdge[249, 270] -> 
             RGBColor[
              0.710585377980133, 0.7726568747098761, 0.9728482630742455], 
             UndirectedEdge[319, 388] -> 
             RGBColor[
              0.7777615253627419, 0.8263452576401367, 0.978474960648781], 
             UndirectedEdge[138, 256] -> 
             RGBColor[
              0.4841211740251655, 0.5833429432985194, 0.9545137100621217], 
             UndirectedEdge[246, 286] -> 
             RGBColor[
              0.8874733540622898, 0.9105480104782264, 0.8754763734625564], 
             UndirectedEdge[188, 208] -> 
             RGBColor[
              0.982072412411112, 0.9846344351110756, 0.8473511864732177], 
             UndirectedEdge[173, 345] -> 
             RGBColor[
              0.9390878482109242, 0.9406176370473563, 0.6947995803903774], 
             UndirectedEdge[84, 156] -> 
             RGBColor[
              0.6545030297845904, 0.7282546526888585, 0.9674067541252332], 
             UndirectedEdge[136, 349] -> 
             RGBColor[
              0.6984399893044277, 0.7608534268518959, 0.9449372852040767], 
             UndirectedEdge[117, 346] -> 
             RGBColor[
              0.5416218488399114, 0.6387520425312968, 0.9570576024483343], 
             UndirectedEdge[26, 197] -> 
             RGBColor[
              0.8000694446799812, 0.8437603283452974, 0.9807016020489294], 
             UndirectedEdge[328, 362] -> 
             RGBColor[
              0.7069222596191911, 0.7709723091134592, 0.9714230623408763], 
             UndirectedEdge[187, 275] -> 
             RGBColor[
              0.7514067436119771, 0.8029525009724947, 0.8936202300955505], 
             UndirectedEdge[20, 121] -> 
             RGBColor[
              0.7992132614167788, 0.8418753441093112, 0.9020389491238696], 
             UndirectedEdge[198, 302] -> 
             RGBColor[
              0.6861512619015517, 0.7452683898459367, 0.7186797274141362], 
             UndirectedEdge[1, 312] -> 
             RGBColor[
              0.8223604247614937, 0.8572205415641037, 0.6955501242941248], 
             UndirectedEdge[89, 292] -> 
             RGBColor[
              0.8378384876668818, 0.8735753948845282, 0.9843839081381077], 
             UndirectedEdge[304, 315] -> 
             RGBColor[
              0.5667461303072776, 0.6538308916744522, 0.9614372599299972], 
             UndirectedEdge[21, 64] -> 
             RGBColor[
              0.4233563561575777, 0.5411117300196998, 0.9481968705484022], 
             UndirectedEdge[201, 351] -> 
             RGBColor[
              0.5123350136927579, 0.6113245138353868, 0.9560140683266563], 
             UndirectedEdge[17, 218] -> 
             RGBColor[
              0.9747281677721213, 0.9657086045783765, 0.667817461782791], 
             UndirectedEdge[266, 365] -> 
             RGBColor[
              0.7823058843192152, 0.8306040783293698, 0.978739823950963], 
             UndirectedEdge[112, 180] -> 
             RGBColor[
              0.7264425730124351, 0.7856905653672359, 0.9739123212077128], 
             UndirectedEdge[247, 289] -> 
             RGBColor[
              0.4945344283092302, 0.6005243532803687, 0.9533507082172543], 
             UndirectedEdge[15, 45] -> 
             RGBColor[
              0.9594357084040706, 0.968372870283703, 0.9149182129599932], 
             UndirectedEdge[57, 92] -> 
             RGBColor[
              0.728791202599113, 0.7876963512086914, 0.9739831947672415], 
             UndirectedEdge[53, 86] -> 
             RGBColor[
              0.8881359397863615, 0.9125545565964859, 0.9430567818004143], 
             UndirectedEdge[114, 154] -> 
             RGBColor[
              0.6142055936584174, 0.6968397873965617, 0.9633452957855677], 
             UndirectedEdge[71, 237] -> 
             RGBColor[
              0.525384351371431, 0.6255697105954595, 0.9557793271677024], 
             UndirectedEdge[241, 375] -> 
             RGBColor[
              0.7001750377907225, 0.7651707918292676, 0.9711132928987471], 
             UndirectedEdge[100, 282] -> 
             RGBColor[
              0.6872816007139257, 0.7540236372476941, 0.9706847322291201], 
             UndirectedEdge[55, 146] -> 
             RGBColor[
              0.6419086727919034, 0.7068315158417986, 0.8435366219062386], 
             UndirectedEdge[309, 319] -> 
             RGBColor[
              0.59266993135515, 0.6749463608948978, 0.9636607607699109], 
             UndirectedEdge[13, 302] -> 
             RGBColor[
              0.5103279858329195, 0.6113334613956843, 0.9551501812516643], 
             UndirectedEdge[110, 348] -> 
             RGBColor[
              0.7826502157715731, 0.8267315464316742, 0.8165437256281541], 
             UndirectedEdge[217, 363] -> 
             RGBColor[
              0.6799032972223317, 0.7444649064741613, 0.9388966493350828], 
             UndirectedEdge[39, 380] -> 
             RGBColor[
              0.9155107173119436, 0.9307921371501653, 0.7509382970233409], 
             UndirectedEdge[248, 304] -> 
             RGBColor[
              0.6666422972209233, 0.7305953178846599, 0.86638297223289], 
             UndirectedEdge[204, 400] -> 
             RGBColor[
              0.8395087800868246, 0.8754457227924886, 0.982392137240361], 
             UndirectedEdge[69, 168] -> 
             RGBColor[
              0.6620516746856875, 0.7340992256334213, 0.9681950173473977], 
             UndirectedEdge[68, 86] -> 
             RGBColor[
              0.5737773061659341, 0.6599209428060464, 0.9618852802382862], 
             UndirectedEdge[175, 264] -> 
             RGBColor[
              0.5969244855275144, 0.6836492143496845, 0.9614112285886155], 
             UndirectedEdge[1, 92] -> 
             RGBColor[
              0.9260570202804113, 0.938549926852743, 0.7058004969355068], 
             UndirectedEdge[368, 393] -> 
             RGBColor[
              0.8434572292133964, 0.878062715799298, 0.9591175946904912], 
             UndirectedEdge[332, 361] -> 
             RGBColor[
              0.8100324499845367, 0.8509404500732444, 0.9146627138274348], 
             UndirectedEdge[80, 203] -> 
             RGBColor[
              0.7594954277329248, 0.8120428676147845, 0.9766630644142643], 
             UndirectedEdge[20, 347] -> 
             RGBColor[
              0.700766589429674, 0.7656679117758801, 0.9711483267529712], 
             UndirectedEdge[18, 311] -> 
             RGBColor[
              0.7027214554362601, 0.6353448846979394, 0.5986129923525084], 
             UndirectedEdge[170, 282] -> 
             RGBColor[
              0.7284424706056428, 0.7065917514745192, 0.6122338781466163], 
             UndirectedEdge[198, 323] -> 
             RGBColor[
              0.6609186016333435, 0.7234131277519952, 0.7170719246142113], 
             UndirectedEdge[168, 357] -> 
             RGBColor[
              0.5820933689604186, 0.6716086457863288, 0.9602436687642837], 
             UndirectedEdge[180, 326] -> 
             RGBColor[
              0.7400044955205223, 0.7967007450169477, 0.9749799654265083], 
             UndirectedEdge[18, 340] -> 
             RGBColor[
              0.685499151443651, 0.752461310052516, 0.9706770671999687], 
             UndirectedEdge[74, 340] -> 
             RGBColor[
              0.6031659543842243, 0.6823909101448513, 0.9650875685358478], 
             UndirectedEdge[173, 204] -> 
             RGBColor[
              0.9150639788855426, 0.935053712362913, 0.9897678789050334], 
             UndirectedEdge[26, 30] -> 
             RGBColor[
              0.8662963780037599, 0.8960700989038873, 0.9697597500461528], 
             UndirectedEdge[169, 240] -> 
             RGBColor[
              0.7850337330140023, 0.8319935857986713, 0.9792084840156503], 
             UndirectedEdge[95, 371] -> 
             RGBColor[
              0.6200739432720408, 0.7024386986305671, 0.9632365706953478], 
             UndirectedEdge[65, 356] -> 
             RGBColor[
              0.8480463260385501, 0.8819219735229764, 0.973455985010317], 
             UndirectedEdge[264, 310] -> 
             RGBColor[
              0.5828547598816072, 0.6722267772364197, 0.9603036082466665], 
             UndirectedEdge[96, 114] -> 
             RGBColor[
              0.7454767262416455, 0.8010913514637197, 0.9752658112618273], 
             UndirectedEdge[244, 308] -> 
             RGBColor[
              0.9933122545834239, 0.9881039137257546, 0.5134583672653161], 
             UndirectedEdge[187, 298] -> 
             RGBColor[
              0.6655785560516827, 0.3751614767027462, 0.559544182458626], 
             UndirectedEdge[58, 228] -> 
             RGBColor[
              0.5911001524865904, 0.678920758403849, 0.9609527157563991], 
             UndirectedEdge[36, 82] -> 
             RGBColor[
              0.8262523814534265, 0.8646300738635578, 0.9578034776157196], 
             UndirectedEdge[72, 355] -> 
             RGBColor[
              0.6803515152592744, 0.7496909154467766, 0.9691330868251147], 
             UndirectedEdge[22, 350] -> 
             RGBColor[
              0.32087951082955535`, 0.4523514372325744, 0.9416671365808169], 
             UndirectedEdge[58, 192] -> 
             RGBColor[
              0.7989421956810618, 0.8417005534065656, 0.9039101851805249], 
             UndirectedEdge[3, 174] -> 
             RGBColor[
              0.7978901837057673, 0.8405456688075506, 0.8912521663762225], 
             UndirectedEdge[44, 54] -> 
             RGBColor[
              0.7996228556788735, 0.5931529954616984, 0.5853874963250695], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.682860616320035, 0.7475287631096325, 0.9464169646747609], 
             UndirectedEdge[170, 271] -> 
             RGBColor[
              0.8699697334726983, 0.8190502128309236, 0.6250434906285323], 
             UndirectedEdge[192, 201] -> 
             RGBColor[
              0.8355601293434881, 0.8708071250246135, 0.9072178173127743], 
             UndirectedEdge[274, 395] -> 
             RGBColor[
              0.86288135857649, 0.8935021893111141, 0.9867835883559497], 
             UndirectedEdge[208, 284] -> 
             RGBColor[
              0.9818808029583621, 0.9844915330949464, 0.8476755312969744], 
             UndirectedEdge[237, 320] -> 
             RGBColor[
              0.45441243621971456`, 0.5668179644969973, 0.9505053607539837], 
             UndirectedEdge[119, 380] -> 
             RGBColor[
              0.8145833220044596, 0.8517037119629649, 0.7409852509590948], 
             UndirectedEdge[342, 398] -> 
             RGBColor[
              0.8439866553483522, 0.8786661063948624, 0.9849203490044018], 
             UndirectedEdge[90, 264] -> 
             RGBColor[
              0.48434028213261393`, 0.5902452356386527, 0.9531016365186147], 
             UndirectedEdge[212, 367] -> 
             RGBColor[
              0.9587966280023102, 0.9687911731452282, 0.9546307406182821], 
             UndirectedEdge[92, 284] -> 
             RGBColor[
              0.915061014496803, 0.9342128038261488, 0.9606947210697359], 
             UndirectedEdge[267, 342] -> 
             RGBColor[
              0.9456992417481385, 0.9559359953190308, 0.8407457284018112], 
             UndirectedEdge[107, 297] -> 
             RGBColor[
              0.7867337195940484, 0.8339852868253856, 0.9792018082065158], 
             UndirectedEdge[163, 245] -> 
             RGBColor[
              0.7415814623422675, 0.7897069495945412, 0.6859878607135799], 
             UndirectedEdge[72, 200] -> 
             RGBColor[
              0.3935356284277176, 0.4990759650793144, 0.947897745043463], 
             UndirectedEdge[254, 286] -> 
             RGBColor[
              0.62580381448385, 0.7049505866172694, 0.9651506945095352], 
             UndirectedEdge[269, 307] -> 
             RGBColor[
              0.4125741079930571, 0.5317726885911421, 0.9475098352297266], 
             UndirectedEdge[240, 304] -> 
             RGBColor[
              0.5601416301148744, 0.6486714059280861, 0.9607789850733819], 
             UndirectedEdge[228, 332] -> 
             RGBColor[
              0.6027837212059081, 0.6884060058289637, 0.9618724890843062], 
             UndirectedEdge[104, 109] -> 
             RGBColor[
              0.66140383981653, 0.7336676848732916, 0.9680794750905057], 
             UndirectedEdge[28, 372] -> 
             RGBColor[
              0.7843951928665163, 0.8297852797072875, 0.8983604686280089], 
             UndirectedEdge[28, 362] -> 
             RGBColor[
              0.6237946764866296, 0.7050782587154212, 0.9637900397442545], 
             UndirectedEdge[209, 227] -> 
             RGBColor[
              0.5445560031834928, 0.6411341212095631, 0.9572885898264225], 
             UndirectedEdge[245, 371] -> 
             RGBColor[
              0.5674962320356368, 0.6597537440499555, 0.9590974606683158], 
             UndirectedEdge[308, 397] -> 
             RGBColor[
              0.7630680034541466, 0.8096885152851507, 0.7211328111160005], 
             UndirectedEdge[58, 87] -> 
             RGBColor[
              0.7358663562070535, 0.7934231944741945, 0.9745598414884897], 
             UndirectedEdge[154, 332] -> 
             RGBColor[
              0.5821723188432466, 0.6716727408578602, 0.9602498839882628], 
             UndirectedEdge[97, 180] -> 
             RGBColor[
              0.9141351082531981, 0.9338752931969139, 0.9745017665515642], 
             UndirectedEdge[202, 300] -> 
             RGBColor[
              0.9542676397557547, 0.9647257655915995, 0.9349981358127467], 
             UndirectedEdge[25, 317] -> 
             RGBColor[
              0.6592396248814915, 0.41587993984688904`, 0.5649086975968234], 
             UndirectedEdge[93, 128] -> 
             RGBColor[
              0.8311734279716401, 0.8686538364742603, 0.9836439041784926], 
             UndirectedEdge[68, 178] -> 
             RGBColor[
              0.42734019108924515`, 0.5433252302396279, 0.948792530675231], 
             UndirectedEdge[271, 273] -> 
             RGBColor[
              0.7645347908242797, 0.8159796563623289, 0.977165341031685], 
             UndirectedEdge[149, 318] -> 
             RGBColor[
              0.7477250311808091, 0.6427743690558538, 0.5961641755525703], 
             UndirectedEdge[42, 358] -> 
             RGBColor[
              0.6939371154084173, 0.7543005306147061, 0.8704676397353877], 
             UndirectedEdge[155, 170] -> 
             RGBColor[
              0.9591140993921008, 0.8888429518016292, 0.5940552423883356], 
             UndirectedEdge[193, 338] -> 
             RGBColor[
              0.8773747304785633, 0.9050588106537275, 0.9881659791063553], 
             UndirectedEdge[79, 109] -> 
             RGBColor[
              0.7789566292575826, 0.8272461061564569, 0.9786027751069739], 
             UndirectedEdge[173, 175] -> 
             RGBColor[
              0.748457734008507, 0.8034271824407127, 0.9758022938624396], 
             UndirectedEdge[95, 178] -> 
             RGBColor[
              0.5481941442137116, 0.6440877279942803, 0.957574997615271], 
             UndirectedEdge[243, 348] -> 
             RGBColor[
              0.8886800301892055, 0.9106633948160398, 0.8263593335498072], 
             UndirectedEdge[56, 83] -> 
             RGBColor[
              0.6014807324249054, 0.6863575170479039, 0.9624472352779658], 
             UndirectedEdge[205, 207] -> 
             RGBColor[
              0.7224114454962284, 0.7830725788427735, 0.9729668796344277], 
             UndirectedEdge[74, 302] -> 
             RGBColor[
              0.356799358016412, 0.48346340348181616`, 0.9439559174808898], 
             UndirectedEdge[179, 196] -> 
             RGBColor[
              0.7121000521606844, 0.7750172399995545, 0.9719391363121901], 
             UndirectedEdge[174, 338] -> 
             RGBColor[
              0.7316622135355857, 0.7900447707914589, 0.9741889498823015], 
             UndirectedEdge[159, 167] -> 
             RGBColor[
              0.7449170321312093, 0.8007762665321303, 0.9751776107026855], 
             UndirectedEdge[251, 356] -> 
             RGBColor[
              0.7888774677535666, 0.8350814261420845, 0.9795690124835463], 
             UndirectedEdge[238, 277] -> 
             RGBColor[
              0.7040619145512799, 0.7653302222598237, 0.93956524938103], 
             UndirectedEdge[163, 164] -> 
             RGBColor[
              0.9928701985242632, 0.9861131677898611, 0.5542223394599444], 
             UndirectedEdge[213, 230] -> 
             RGBColor[
              0.389565997398878, 0.5038474715556248, 0.9468575564488935], 
             UndirectedEdge[246, 343] -> 
             RGBColor[
              0.9929466637564461, 0.9896207440666543, 0.6407639841462145], 
             UndirectedEdge[53, 95] -> 
             RGBColor[
              0.7910136228918181, 0.835994818800674, 0.9338462737963156], 
             UndirectedEdge[139, 184] -> 
             RGBColor[
              0.6694526963842005, 0.7407827296264736, 0.9683161372285374], 
             UndirectedEdge[101, 308] -> 
             RGBColor[
              0.7891175250679673, 0.8308366904488258, 0.7231835248799823], 
             UndirectedEdge[3, 52] -> 
             RGBColor[
              0.7989217941042069, 0.8413831766025227, 0.8913333785257012], 
             UndirectedEdge[136, 286] -> 
             RGBColor[
              0.8745174000401326, 0.902285231316008, 0.9600910950292663], 
             UndirectedEdge[164, 169] -> 
             RGBColor[
              0.8932269412574538, 0.9143145973639338, 0.8347516195874995], 
             UndirectedEdge[14, 102] -> 
             RGBColor[
              0.3557640427226805, 0.4825666654108456, 0.9438899481058665], 
             UndirectedEdge[232, 281] -> 
             RGBColor[
              0.7801081910203833, 0.8288119192276293, 0.9785407618922118], 
             UndirectedEdge[56, 349] -> 
             RGBColor[
              0.5686018492438116, 0.6590365602946644, 0.9600325174523747], 
             UndirectedEdge[225, 324] -> 
             RGBColor[
              0.7398544795460971, 0.7959225616131761, 0.9699796025351649], 
             UndirectedEdge[5, 272] -> 
             RGBColor[
              0.7579053670115102, 0.8107628572621028, 0.9763832951902438], 
             UndirectedEdge[68, 371] -> 
             RGBColor[
              0.4992199901475743, 0.6016762008759146, 0.9544541037553078], 
             UndirectedEdge[151, 397] -> 
             RGBColor[
              0.7194005522277445, 0.7797393915002988, 0.9736274431632075], 
             UndirectedEdge[1, 356] -> 
             RGBColor[
              0.8698409375656384, 0.894312679031964, 0.7002825380798225], 
             UndirectedEdge[96, 115] -> 
             RGBColor[
              0.6520169986216238, 0.7260555433078766, 0.9673346840872139], 
             UndirectedEdge[328, 347] -> 
             RGBColor[
              0.7689252481561373, 0.8194095149986877, 0.9776029407873681], 
             UndirectedEdge[80, 159] -> 
             RGBColor[
              0.8177412669803157, 0.8576671122809365, 0.9824360498512772], 
             UndirectedEdge[50, 121] -> 
             RGBColor[
              0.8727112918580057, 0.8997881050964202, 0.9090257418315286], 
             UndirectedEdge[108, 342] -> 
             RGBColor[
              0.6732310516193841, 0.7422342411259055, 0.9699403799182293], 
             UndirectedEdge[178, 315] -> 
             RGBColor[
              0.6453164611082549, 0.7206474657900921, 0.9667855056193697], 
             UndirectedEdge[146, 228] -> 
             RGBColor[
              0.4311057084378968, 0.5428273038474112, 0.9496492787139414], 
             UndirectedEdge[63, 152] -> 
             RGBColor[
              0.8660094012589478, 0.8959964056376493, 0.9870819438594391], 
             UndirectedEdge[43, 137] -> 
             RGBColor[
              0.6696345951657618, 0.7372719477934357, 0.963071453867483], 
             UndirectedEdge[97, 141] -> 
             RGBColor[
              0.8828827703941449, 0.9090292609997574, 0.9715013240131755], 
             UndirectedEdge[25, 207] -> 
             RGBColor[
              0.6141632234349435, 0.6961408587750566, 0.96379630342322], 
             UndirectedEdge[214, 310] -> 
             RGBColor[
              0.7697132103753657, 0.8194719458255298, 0.9537891501674219], 
             UndirectedEdge[37, 87] -> 
             RGBColor[
              0.8899201051582935, 0.9150621518882204, 0.9893625681426961], 
             UndirectedEdge[146, 262] -> 
             RGBColor[
              0.37843384562986165`, 0.5000659127794695, 0.945502756730302], 
             UndirectedEdge[322, 364] -> 
             RGBColor[
              0.8167363829581797, 0.8240378289875367, 0.6529487145203395], 
             UndirectedEdge[219, 311] -> 
             RGBColor[
              0.835718253321453, 0.7414378841463525, 0.610368211872469], 
             UndirectedEdge[5, 260] -> 
             RGBColor[
              0.7806458840748773, 0.8292246334627633, 0.9781735119947308], 
             UndirectedEdge[204, 389] -> 
             RGBColor[
              0.6847499408403311, 0.7507274899083545, 0.9693380472502429], 
             UndirectedEdge[275, 279] -> 
             RGBColor[
              0.8650851169124811, 0.8937276862698507, 0.9036045649979441], 
             UndirectedEdge[78, 289] -> 
             RGBColor[
              0.6274637944392956, 0.7069299761208571, 0.964849448076722], 
             UndirectedEdge[163, 329] -> 
             RGBColor[
              0.972021837799714, 0.9726514409324927, 0.6914215313547298], 
             UndirectedEdge[47, 181] -> 
             RGBColor[
              0.731030093635048, 0.7892717629362742, 0.9744382402569876], 
             UndirectedEdge[267, 291] -> 
             RGBColor[
              0.9944034815050871, 0.9904379377712262, 0.632231683416423], 
             UndirectedEdge[28, 301] -> 
             RGBColor[
              0.7222052279582378, 0.7823158264729709, 0.9735035497350168], 
             UndirectedEdge[174, 193] -> 
             RGBColor[
              0.7517935530015334, 0.8060969544309531, 0.9761090950120226], 
             UndirectedEdge[60, 263] -> 
             RGBColor[
              0.8794206597524488, 0.9066770529720009, 0.9879060298254183], 
             UndirectedEdge[122, 385] -> 
             RGBColor[
              0.751252962779329, 0.8045771506226598, 0.9548052128296296], 
             UndirectedEdge[282, 350] -> 
             RGBColor[
              0.416055526506483, 0.5330163706304859, 0.9482212073061806], 
             UndirectedEdge[142, 306] -> 
             RGBColor[
              0.37477047915274986`, 0.49183580331291676`, 0.9456927990547892],
              UndirectedEdge[6, 289] -> 
             RGBColor[
              0.5838720401563192, 0.6728757663653926, 0.9605046293978998], 
             UndirectedEdge[3, 117] -> 
             RGBColor[
              0.7938565881785006, 0.8372710142471078, 0.8909346269607687], 
             UndirectedEdge[6, 132] -> 
             RGBColor[
              0.8168338964934123, 0.8569912809490685, 0.9426405124777008], 
             UndirectedEdge[22, 394] -> 
             RGBColor[
              0.4295197535905769, 0.5443457552253103, 0.9491710487367583], 
             UndirectedEdge[11, 391] -> 
             RGBColor[
              0.8127265608884511, 0.8541477901108243, 0.9818305596244197], 
             UndirectedEdge[34, 249] -> 
             RGBColor[
              0.7301624761731151, 0.7022050315931045, 0.6110377935823302], 
             UndirectedEdge[269, 306] -> 
             RGBColor[
              0.3239867976762184, 0.4492196296032537, 0.942078345417902], 
             UndirectedEdge[69, 394] -> 
             RGBColor[
              0.6656821402283657, 0.7370466011115763, 0.9684808208937508], 
             UndirectedEdge[361, 369] -> 
             RGBColor[
              0.9903217431941083, 0.9888503097354813, 0.7071656317469923], 
             UndirectedEdge[85, 184] -> 
             RGBColor[
              0.756723962014129, 0.8098777775313417, 0.9763868306122344], 
             UndirectedEdge[73, 96] -> 
             RGBColor[
              0.6489566143331567, 0.7235709854737578, 0.9670937594254687], 
             UndirectedEdge[71, 382] -> 
             RGBColor[
              0.7338010069205168, 0.7913698073054471, 0.9748307594739148], 
             UndirectedEdge[122, 165] -> 
             RGBColor[
              0.682706483004897, 0.7476256023558138, 0.9497688475853625], 
             UndirectedEdge[321, 331] -> 
             RGBColor[
              0.6783655054437734, 0.7474379291438166, 0.9694147595413108], 
             UndirectedEdge[296, 374] -> 
             RGBColor[
              0.705572401807655, 0.7658138494129934, 0.923968188093748], 
             UndirectedEdge[66, 297] -> 
             RGBColor[
              0.591750329995022, 0.6689380464336883, 0.964930380867319], 
             UndirectedEdge[75, 145] -> 
             RGBColor[
              0.9716379833596167, 0.9762117396067889, 0.8254669122537509], 
             UndirectedEdge[105, 239] -> 
             RGBColor[
              0.5152775879216847, 0.6170673535034864, 0.9550658115980448], 
             UndirectedEdge[92, 354] -> 
             RGBColor[
              0.6925036328342424, 0.7582364673371809, 0.971126504349603], 
             UndirectedEdge[188, 369] -> 
             RGBColor[
              0.9822351564849456, 0.9832862373654406, 0.741762435741876], 
             UndirectedEdge[170, 251] -> 
             RGBColor[
              0.8844129002638037, 0.8304184100516678, 0.6264604714260016], 
             UndirectedEdge[53, 68] -> 
             RGBColor[
              0.6701596697673516, 0.7352323210460217, 0.9250638068562755], 
             UndirectedEdge[274, 318] -> 
             RGBColor[
              0.7166414221042869, 0.7780599665150414, 0.9727650387345539], 
             UndirectedEdge[179, 359] -> 
             RGBColor[
              0.5315017445517445, 0.6236765605296773, 0.9587106281962086], 
             UndirectedEdge[20, 328] -> 
             RGBColor[
              0.6781689473579442, 0.748014462041004, 0.9688960049782328], 
             UndirectedEdge[307, 352] -> 
             RGBColor[
              0.45075933872553553`, 0.5641608724330447, 0.9501324926743961], 
             UndirectedEdge[6, 216] -> 
             RGBColor[
              0.8002813101331527, 0.8446463891439595, 0.9706597235796799], 
             UndirectedEdge[297, 385] -> 
             RGBColor[
              0.7222683987034351, 0.7820939107190042, 0.973822971659704], 
             UndirectedEdge[40, 348] -> 
             RGBColor[
              0.9102904267639678, 0.927592576090416, 0.8285007901393624], 
             UndirectedEdge[229, 329] -> 
             RGBColor[
              0.7692052178018485, 0.8193770872895179, 0.9622663590725982], 
             UndirectedEdge[6, 213] -> 
             RGBColor[
              0.5936373443253753, 0.6808036802117718, 0.9612733899135757], 
             UndirectedEdge[189, 374] -> 
             RGBColor[
              0.9261643531287168, 0.942571862913159, 0.9433860503734388], 
             UndirectedEdge[97, 140] -> 
             RGBColor[
              0.9750044041739618, 0.9789130099058547, 0.8348916686520901], 
             UndirectedEdge[34, 386] -> 
             RGBColor[
              0.8861591913650742, 0.826001211507111, 0.6253260982334476], 
             UndirectedEdge[162, 313] -> 
             RGBColor[
              0.6917372206327829, 0.623105370290379, 0.5969834179607627], 
             UndirectedEdge[258, 392] -> 
             RGBColor[
              0.9203347089708067, 0.9358192689605034, 0.8471026329962665], 
             UndirectedEdge[45, 273] -> 
             RGBColor[
              0.8287992098032644, 0.8670739677158241, 0.9833343173387912], 
             UndirectedEdge[226, 393] -> 
             RGBColor[
              0.624422569457411, 0.7047445580817493, 0.9644161428143361], 
             UndirectedEdge[88, 168] -> 
             RGBColor[
              0.5120004546570118, 0.614704060305018, 0.9547256977915143], 
             UndirectedEdge[188, 327] -> 
             RGBColor[
              0.750726035324066, 0.8037938139453779, 0.9452273053415796], 
             UndirectedEdge[59, 349] -> 
             RGBColor[
              0.7091972883790492, 0.7682070056904535, 0.8967599660546439], 
             UndirectedEdge[260, 398] -> 
             RGBColor[
              0.7082614422678153, 0.7717525709491558, 0.9717383490229402], 
             UndirectedEdge[248, 353] -> 
             RGBColor[
              0.8307679679018498, 0.866446299064396, 0.8787558411062435], 
             UndirectedEdge[30, 389] -> 
             RGBColor[
              0.6932872320902614, 0.757094587744021, 0.9548866400462799], 
             UndirectedEdge[216, 311] -> 
             RGBColor[
              0.926511040873417, 0.8131071800466194, 0.6093490920023116], 
             UndirectedEdge[66, 307] -> 
             RGBColor[
              0.3521726469335823, 0.4769283384206481, 0.9437536568413625], 
             UndirectedEdge[94, 225] -> 
             RGBColor[
              0.6954573220736533, 0.7597616345372509, 0.9665169100321955], 
             UndirectedEdge[177, 324] -> 
             RGBColor[
              0.5232222696591452, 0.6238144352607546, 0.955609120175345], 
             UndirectedEdge[79, 320] -> 
             RGBColor[
              0.5875515727124527, 0.6730500844736538, 0.9622556751050311], 
             UndirectedEdge[133, 234] -> 
             RGBColor[
              0.5762363490706317, 0.6608024132993413, 0.9625721976108692], 
             UndirectedEdge[35, 195] -> 
             RGBColor[
              0.6302214995886758, 0.7101771243253067, 0.9643771515678419], 
             UndirectedEdge[34, 86] -> 
             RGBColor[
              0.8631999441080545, 0.807922306962626, 0.6230756738378621], 
             UndirectedEdge[98, 131] -> 
             RGBColor[
              0.9104766545096005, 0.9310741610017199, 0.9781752893451503], 
             UndirectedEdge[173, 261] -> 
             RGBColor[
              0.8371095904166226, 0.8732593354208604, 0.98424402435688], 
             UndirectedEdge[103, 331] -> 
             RGBColor[
              0.742318244353041, 0.7982251628794444, 0.9755695455292728], 
             UndirectedEdge[135, 322] -> 
             RGBColor[
              0.9149502046364139, 0.9010840296812098, 0.662652615504717], 
             UndirectedEdge[50, 181] -> 
             RGBColor[
              0.6629582171265833, 0.7355021212738989, 0.9678104043487923], 
             UndirectedEdge[35, 153] -> 
             RGBColor[
              0.7066842562912862, 0.7699767560194667, 0.9719806386425898], 
             UndirectedEdge[121, 362] -> 
             RGBColor[
              0.8279665736780257, 0.8648331911817664, 0.9045660064865131], 
             UndirectedEdge[84, 152] -> 
             RGBColor[
              0.712027429198435, 0.7738161928388188, 0.9729749124392159], 
             UndirectedEdge[295, 345] -> 
             RGBColor[
              0.9071162346288277, 0.9151243402233242, 0.6917500993455207], 
             UndirectedEdge[22, 266] -> 
             RGBColor[
              0.61997155733309, 0.6955782737570185, 0.9667885428176048], 
             UndirectedEdge[271, 335] -> 
             RGBColor[
              0.7381016237210909, 0.7953298653218073, 0.9745307299668301], 
             UndirectedEdge[175, 261] -> 
             RGBColor[
              0.6933674500524678, 0.7598065398845022, 0.9704663036537828], 
             UndirectedEdge[59, 254] -> 
             RGBColor[
              0.728749115687485, 0.7847084581092441, 0.8981255292233252], 
             UndirectedEdge[53, 270] -> 
             RGBColor[
              0.9400052095164897, 0.9536855283193729, 0.9480646699477668], 
             UndirectedEdge[214, 300] -> 
             RGBColor[
              0.9425680810370561, 0.956342062052878, 0.9701093064251891], 
             UndirectedEdge[3, 386] -> 
             RGBColor[
              0.9136857010259811, 0.9317047052459486, 0.9023756854690361], 
             UndirectedEdge[299, 336] -> 
             RGBColor[
              0.6266814242912941, 0.7055974528818799, 0.9652646458101143], 
             UndirectedEdge[110, 351] -> 
             RGBColor[
              0.4561270689135578, 0.5663138886727982, 0.9511642387587191], 
             UndirectedEdge[172, 328] -> 
             RGBColor[
              0.8657906937298973, 0.8949630695745354, 0.9346985769101737], 
             UndirectedEdge[185, 302] -> 
             RGBColor[
              0.4624194518449693, 0.5724391552494055, 0.9513786459613903], 
             UndirectedEdge[370, 391] -> 
             RGBColor[
              0.6970489319409096, 0.7617479046970121, 0.9716899397111558], 
             UndirectedEdge[50, 364] -> 
             RGBColor[
              0.7101274202877557, 0.7734762049878652, 0.9717425228023895], 
             UndirectedEdge[73, 195] -> 
             RGBColor[
              0.589677886647324, 0.6772619928705685, 0.9611854098409509], 
             UndirectedEdge[80, 332] -> 
             RGBColor[
              0.7167240977293382, 0.7784871707506505, 0.9724973836286092], 
             UndirectedEdge[5, 267] -> 
             RGBColor[
              0.9656199184347154, 0.9718049161713398, 0.8421158049313064], 
             UndirectedEdge[136, 246] -> 
             RGBColor[
              0.9796613561913032, 0.9829523031316436, 0.8566285273257792], 
             UndirectedEdge[59, 246] -> 
             RGBColor[
              0.9904186552659248, 0.9903058819702011, 0.8084512081763465], 
             UndirectedEdge[177, 200] -> 
             RGBColor[
              0.34378991496518785`, 0.45869015387157974`, 0.9439815802551401],
              UndirectedEdge[17, 157] -> 
             RGBColor[
              0.9545439624303799, 0.9656195421247834, 0.9618293941587412], 
             UndirectedEdge[151, 386] -> 
             RGBColor[
              0.8716980268081795, 0.9005323612369797, 0.987624530042621], 
             UndirectedEdge[4, 188] -> 
             RGBColor[
              0.9723547447103529, 0.9789027943867079, 0.9316803855547391], 
             UndirectedEdge[241, 255] -> 
             RGBColor[
              0.708276623658431, 0.7717480242089574, 0.9717510794153399], 
             UndirectedEdge[62, 345] -> 
             RGBColor[
              0.8747543373534841, 0.8897761153846453, 0.6885423117070556], 
             UndirectedEdge[57, 114] -> 
             RGBColor[
              0.6475177167401052, 0.7238840696083187, 0.9659677481408857], 
             UndirectedEdge[32, 137] -> 
             RGBColor[
              0.8089570217193354, 0.8514715421644536, 0.973935014350912], 
             UndirectedEdge[152, 175] -> 
             RGBColor[
              0.7508918494663124, 0.8053680800344626, 0.9760344619677654], 
             UndirectedEdge[99, 235] -> 
             RGBColor[
              0.7415121701336282, 0.7974000851191143, 0.9736434319100385], 
             UndirectedEdge[156, 256] -> 
             RGBColor[
              0.5285608175780371, 0.6180595305958231, 0.9589430384193915], 
             UndirectedEdge[48, 286] -> 
             RGBColor[
              0.8312016813065461, 0.8685460227086522, 0.9836811878211311], 
             UndirectedEdge[61, 262] -> 
             RGBColor[
              0.40078609539496174`, 0.5211866318397336, 0.9468625682436196], 
             UndirectedEdge[146, 385] -> 
             RGBColor[
              0.4160750619138499, 0.5306247478762804, 0.948466011160496], 
             UndirectedEdge[29, 150] -> 
             RGBColor[
              0.6376041739982101, 0.7147925997630761, 0.9659005656016487], 
             UndirectedEdge[141, 220] -> 
             RGBColor[
              0.7257691926718344, 0.785669908449897, 0.9733191662195888], 
             UndirectedEdge[152, 242] -> 
             RGBColor[
              0.9446546652906378, 0.9559106673394411, 0.8841454284719042], 
             UndirectedEdge[95, 151] -> 
             RGBColor[
              0.7516164626566164, 0.8058937188966828, 0.9761635976429366], 
             UndirectedEdge[252, 293] -> 
             RGBColor[
              0.891167159215869, 0.6275413734307653, 0.5823281975657225], 
             UndirectedEdge[93, 390] -> 
             RGBColor[
              0.9406192540920553, 0.954064501126225, 0.9433184473749417], 
             UndirectedEdge[229, 249] -> 
             RGBColor[
              0.55542740254041, 0.6499600129584684, 0.9581444262070471], 
             UndirectedEdge[96, 153] -> 
             RGBColor[
              0.8110083188000399, 0.8523514746484937, 0.9817797820522167], 
             UndirectedEdge[202, 217] -> 
             RGBColor[
              0.9792440427154068, 0.9836990133612723, 0.9047117316135738], 
             UndirectedEdge[163, 304] -> 
             RGBColor[
              0.6662740445955484, 0.7255393552889061, 0.6808964834922828], 
             UndirectedEdge[18, 323] -> 
             RGBColor[
              0.41389989480763045`, 0.5316785412955394, 0.9479376133450859], 
             UndirectedEdge[152, 264] -> 
             RGBColor[
              0.7431007413494745, 0.7990429074797927, 0.9754211173970386], 
             UndirectedEdge[23, 169] -> 
             RGBColor[
              0.8784955402167907, 0.9054148890232052, 0.961596394296063], 
             UndirectedEdge[290, 342] -> 
             RGBColor[
              0.5873463514520698, 0.6650249534241324, 0.964571146928797], 
             UndirectedEdge[285, 330] -> 
             RGBColor[
              0.9849125800468821, 0.9851938650088494, 0.7301533741046508], 
             UndirectedEdge[55, 192] -> 
             RGBColor[
              0.9911498368906069, 0.9906082443625179, 0.7963336364179769], 
             UndirectedEdge[161, 170] -> 
             RGBColor[
              0.8436887388506376, 0.7985193000892127, 0.6224240466944635], 
             UndirectedEdge[42, 205] -> 
             RGBColor[
              0.5504618692203007, 0.643439958915851, 0.9588278376374058], 
             UndirectedEdge[267, 398] -> 
             RGBColor[
              0.8932354766276533, 0.9143328536577322, 0.8356806419595157], 
             UndirectedEdge[32, 199] -> 
             RGBColor[
              0.6268599801935458, 0.7074683072926611, 0.9640986987623732], 
             UndirectedEdge[154, 385] -> 
             RGBColor[
              0.5368627804554205, 0.6348884164231796, 0.9566829511520653], 
             UndirectedEdge[91, 190] -> 
             RGBColor[
              0.8700957861240411, 0.8992009573991477, 0.9783759064954958], 
             UndirectedEdge[94, 380] -> 
             RGBColor[
              0.7211733791839654, 0.7757519977406747, 0.7336640924537785], 
             UndirectedEdge[119, 288] -> 
             RGBColor[
              0.6520219887441985, 0.7279835894425822, 0.9660196310874982], 
             UndirectedEdge[65, 251] -> 
             RGBColor[
              0.8896798248036175, 0.9145314647359568, 0.977583043990852], 
             UndirectedEdge[198, 216] -> 
             RGBColor[
              0.9698857734455885, 0.973709490070402, 0.7335787649001348], 
             UndirectedEdge[101, 182] -> 
             RGBColor[
              0.5062882256964429, 0.6093628888190203, 0.9544704519823739], 
             UndirectedEdge[11, 230] -> 
             RGBColor[
              0.4934263755657522, 0.5866535804246102, 0.9560678790926874], 
             UndirectedEdge[53, 101] -> 
             RGBColor[
              0.7848472340767668, 0.8309886665679651, 0.9333608330805683], 
             UndirectedEdge[202, 264] -> 
             RGBColor[
              0.7876913866231336, 0.8329529139228463, 0.9191722553262016], 
             UndirectedEdge[336, 367] -> 
             RGBColor[
              0.8667186661102309, 0.8965447850797114, 0.9771311616824526], 
             UndirectedEdge[13, 132] -> 
             RGBColor[
              0.8106150837372159, 0.8521194534252586, 0.9420300076356837], 
             UndirectedEdge[146, 307] -> 
             RGBColor[
              0.3563222412618104, 0.48128982515909213`, 0.9439899700995804], 
             UndirectedEdge[75, 133] -> 
             RGBColor[
              0.8849334403441209, 0.9107572410685955, 0.9774914055900918], 
             UndirectedEdge[153, 369] -> 
             RGBColor[
              0.9109167736528241, 0.9273248036782259, 0.7663684548743099], 
             UndirectedEdge[20, 181] -> 
             RGBColor[
              0.5894601866853566, 0.67758936028679, 0.9608236116411333], 
             UndirectedEdge[112, 394] -> 
             RGBColor[
              0.5551701957568629, 0.6497512009045512, 0.9581241779468668], 
             UndirectedEdge[279, 306] -> 
             RGBColor[
              0.4934790665303261, 0.5866947430066015, 0.9560731308356111], 
             UndirectedEdge[34, 68] -> 
             RGBColor[
              0.6452236740890446, 0.6306000714121618, 0.6050826988937232], 
             UndirectedEdge[4, 284] -> 
             RGBColor[
              0.972163135257603, 0.9787598923705787, 0.9320047303784957], 
             UndirectedEdge[193, 235] -> 
             RGBColor[
              0.9177170766714673, 0.9371692205209885, 0.9900209337403032], 
             UndirectedEdge[296, 316] -> 
             RGBColor[
              0.7089605741740468, 0.7672149457585544, 0.8678174036736278], 
             UndirectedEdge[117, 223] -> 
             RGBColor[
              0.5103183178210788, 0.6125049789423163, 0.9548235576796156], 
             UndirectedEdge[37, 110] -> 
             RGBColor[
              0.744159213465518, 0.7997521833117693, 0.9756771369297629], 
             UndirectedEdge[83, 349] -> 
             RGBColor[
              0.46305345962080324`, 0.5743382864876063, 0.9510460393412554], 
             UndirectedEdge[192, 348] -> 
             RGBColor[
              0.9914869469383567, 0.9903188739404964, 0.7595795005331225], 
             UndirectedEdge[97, 394] -> 
             RGBColor[
              0.7428627309976261, 0.7979359287342291, 0.9587136232907182], 
             UndirectedEdge[2, 352] -> 
             RGBColor[
              0.55660746851502, 0.650918043678023, 0.9582373253232924], 
             UndirectedEdge[69, 350] -> 
             RGBColor[
              0.5570418974673441, 0.6450522831188406, 0.9609769087378095], 
             UndirectedEdge[164, 304] -> 
             RGBColor[
              0.668334838358326, 0.7309924174933488, 0.816322120645231], 
             UndirectedEdge[141, 350] -> 
             RGBColor[
              0.5622012279681938, 0.6490827913184682, 0.9614911425854493], 
             UndirectedEdge[114, 356] -> 
             RGBColor[
              0.7221865658442641, 0.7828969011495104, 0.9729444657323397], 
             UndirectedEdge[383, 390] -> 
             RGBColor[
              0.7808354877899844, 0.8276169287095616, 0.9282450247197076], 
             UndirectedEdge[297, 307] -> 
             RGBColor[
              0.6625155780513956, 0.7327589880018159, 0.9693469305987885], 
             UndirectedEdge[40, 58] -> 
             RGBColor[
              0.7177456755066729, 0.7789742555564853, 0.9728314747867648], 
             UndirectedEdge[173, 295] -> 
             RGBColor[
              0.8602282607905654, 0.8913866811530388, 0.9865305335206798], 
             UndirectedEdge[161, 239] -> 
             RGBColor[
              0.6686233085507628, 0.7402229851433134, 0.968173182729059], 
             UndirectedEdge[35, 369] -> 
             RGBColor[
              0.7894086821272925, 0.8314594459582282, 0.754874173974453], 
             UndirectedEdge[303, 313] -> 
             RGBColor[
              0.5126272076825886, 0.6152128866460834, 0.9547750380855596], 
             UndirectedEdge[237, 349] -> 
             RGBColor[
              0.46371457805600735`, 0.5748750122163511, 0.9510980850062312], 
             UndirectedEdge[21, 263] -> 
             RGBColor[
              0.6690195196149276, 0.737206095849679, 0.9698463310603314], 
             UndirectedEdge[126, 274] -> 
             RGBColor[
              0.7048211246895173, 0.7684637165754011, 0.9718345016228871], 
             UndirectedEdge[331, 346] -> 
             RGBColor[
              0.5237902288529818, 0.6242755301205813, 0.955653832003587], 
             UndirectedEdge[106, 345] -> 
             RGBColor[
              0.9242611372525193, 0.9287952201894719, 0.6933853954632037]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {3}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.9948311446420273, 0.9913526659777654, 0.6787801766414088], 
             316 -> RGBColor[
              0.9916976325962975, 0.9908347719645285, 0.7872552439248395], 
             308 -> RGBColor[
              0.9930588853701798, 0.9875619825981825, 0.4858806920172317], 
             160 -> RGBColor[
              0.9629854950696578, 0.8868035248302102, 0.3107060672587026], 
             245 -> RGBColor[
              0.49235351992304943`, 0.598753793603664, 0.9531790191201635], 
             155 -> RGBColor[
              0.9799133647752283, 0.9845400008549875, 0.9188856133887491], 
             213 -> RGBColor[
              0.5333687204414774, 0.6320517810982508, 0.956407885948604], 352 -> 
             RGBColor[
              0.4785807824611151, 0.5875724648773136, 0.9520947787759603], 27 -> 
             RGBColor[
              0.9437598307571106, 0.9575767543802541, 0.980084116129582], 367 -> 
             RGBColor[
              0.9468244893982095, 0.9598623717768677, 0.9748964484411887], 19 -> 
             RGBColor[
              0.6369731032990832, 0.7161624864263144, 0.9645640024825141], 
             164 -> RGBColor[
              0.9949309922870407, 0.9915662299943038, 0.6896479766128926], 
             190 -> RGBColor[
              0.7943804058573836, 0.8392952776612652, 0.9801400730150549], 
             103 -> RGBColor[
              0.9222858836759186, 0.940869745132521, 0.9924496449909788], 138 -> 
             RGBColor[
              0.6931400193548403, 0.7602055182700427, 0.9700493774336838], 
             291 -> RGBColor[
              0.9938588999827345, 0.989273132960552, 0.5729573454759208], 28 -> 
             RGBColor[
              0.5800724398192845, 0.6699679644677357, 0.9600845738193862], 
             337 -> RGBColor[
              0.7585748787240485, 0.8113237277326188, 0.9765713126920791], 
             195 -> RGBColor[
              0.6752668344115969, 0.7462428503511443, 0.9682679453929509], 
             114 -> RGBColor[
              0.697129162700029, 0.7633218673699166, 0.9704469779616681], 93 -> 
             RGBColor[
              0.8961436749566796, 0.9200246575111516, 0.9899561777859126], 34 -> 
             RGBColor[
              0.9346463120311648, 0.7786014355687414, 0.2662730924932992], 
             161 -> 
             RGBColor[
              0.7490626436923018, 0.8038926974301545, 0.9756232220010049], 22 -> 
             RGBColor[
              0.32821807584845725`, 0.4587077334049447, 0.9421347434545831], 
             124 -> RGBColor[
              0.5565427078806685, 0.6508654680776231, 0.9582322271289303], 84 -> 
             RGBColor[
              0.5269867531085975, 0.6268706125130669, 0.9559054741022431], 46 -> 
             RGBColor[
              0.9326322671453173, 0.9491196704659218, 0.9934364922826157], 
             241 -> RGBColor[
              0.7926242663183576, 0.8379233681062234, 0.9799650374378618], 
             185 -> RGBColor[
              0.5456512747209796, 0.6420233119851153, 0.9573748136139653], 
             390 -> RGBColor[
              0.9850948332274311, 0.9881043447412984, 0.8966807169639709], 
             121 -> RGBColor[
              0.9884162342020768, 0.9894778294004261, 0.8416365073039034], 
             322 -> RGBColor[
              0.9702242748547828, 0.9112216287917576, 0.3388273597950541], 
             126 -> RGBColor[
              0.5813856021705658, 0.6710340488217956, 0.9601879507699512], 
             236 -> RGBColor[
              0.8511402325098258, 0.8841401340899331, 0.9856637092702843], 78 -> 
             RGBColor[
              0.7410894767752259, 0.7976639988362217, 0.974828531236192], 376 -> 
             RGBColor[
              0.8275783990690639, 0.8653525676732005, 0.9834163605628075], 
             254 -> RGBColor[
              0.4692782310565811, 0.580020234571948, 0.9513624478530268], 290 -> 
             RGBColor[
              0.2782422824353023, 0.40978065879210385`, 0.9391568584108967], 
             251 -> RGBColor[
              0.8305109665186341, 0.8676909173550648, 0.9836960714640812], 
             165 -> RGBColor[
              0.40535057674517094`, 0.5255160288894603, 0.9470495582061292], 
             100 -> RGBColor[
              0.8559930942255389, 0.8880096742946206, 0.9861265795529298], 
             235 -> RGBColor[
              0.9379280833984235, 0.9532274467487553, 0.9899557432445302], 70 -> 
             RGBColor[
              0.6435654945294389, 0.7214775226960958, 0.965108252099362], 234 -> 
             RGBColor[
              0.3310506395302276, 0.461161157697304, 0.9423152319076478], 257 -> 
             RGBColor[
              0.949966028668431, 0.9622053266208005, 0.9695786419013707], 135 -> 
             RGBColor[
              0.8596761344180449, 0.890946430570662, 0.9864778712143798], 265 -> 
             RGBColor[
              0.5834941353158263, 0.6727458510174539, 0.9603539422229576], 
             111 -> RGBColor[
              0.9427351341417131, 0.9568125373222773, 0.9818186602157701], 
             381 -> RGBColor[
              0.9926891437568809, 0.9912447873101042, 0.7708233380453433], 
             182 -> RGBColor[
              0.42740028662713114`, 0.5446143793385717, 0.9484545462220149], 
             188 -> RGBColor[
              0.9708291134810609, 0.9777649811138939, 0.9342628812775787], 
             154 -> RGBColor[
              0.5312820246168058, 0.6303577074232067, 0.9562436136094673], 
             336 -> RGBColor[
              0.7866128428222521, 0.833227198382555, 0.9793658749237165], 315 -> 
             RGBColor[
              0.791753576184944, 0.8372431783565106, 0.979878255182425], 368 -> 
             RGBColor[
              0.9643373196018667, 0.9729234118681277, 0.9452517949840422], 
             269 -> RGBColor[
              0.4022103209961583, 0.5227960971935086, 0.9468494638866213], 
             208 -> RGBColor[
              0.9933157113411631, 0.9915038891082574, 0.7604394916688568], 86 -> 
             RGBColor[
              0.791753576184944, 0.8372431783565106, 0.979878255182425], 119 -> 
             RGBColor[
              0.6358172800840154, 0.7152241370710799, 0.964473011845104], 377 -> 
             RGBColor[
              0.9899603366644035, 0.9901163554502214, 0.816046733494073], 140 -> 
             RGBColor[
              0.9951047776853682, 0.9919379393889272, 0.7085634447416772], 85 -> 
             RGBColor[
              0.756970177155526, 0.8100701226711053, 0.9764113710365175], 351 -> 
             RGBColor[
              0.3417386844296112, 0.4704186049923937, 0.9429962646775695], 
             242 -> RGBColor[
              0.9922412252930034, 0.9910595615143114, 0.7782465061676199], 
             117 -> RGBColor[
              0.5980138450040224, 0.6845336054477988, 0.9614969869570614], 47 -> 
             RGBColor[
              0.8931501025308638, 0.917637664117165, 0.9896706481755446], 81 -> 
             RGBColor[
              0.7034183516267831, 0.768235029559103, 0.971073825538075], 275 -> 
             RGBColor[
              0.9889753751205888, 0.9897090485394969, 0.8323700952738489], 23 -> 
             RGBColor[
              0.9654681902057143, 0.9737668133128465, 0.9433375260300195], 
             328 -> RGBColor[
              0.7463276060844074, 0.8017560652638116, 0.9753506190126296], 
             110 -> RGBColor[
              0.5705154533975044, 0.6622091723532028, 0.9593322128398689], 6 -> 
             RGBColor[
              0.653905968209273, 0.7295555793252929, 0.9661388938785473], 218 -> 
             RGBColor[
              0.9839881453385285, 0.9576503958439064, 0.3922973975355625], 
             108 -> RGBColor[
              0.450011682769931, 0.5641992341956501, 0.9498953243897615], 297 -> 
             RGBColor[
              0.9020932611128352, 0.9247686960148561, 0.9905236546247449], 
             157 -> RGBColor[
              0.9436197346550455, 0.9574722709367203, 0.9803212622874629], 
             354 -> RGBColor[
              0.5253311312504398, 0.6255265041036998, 0.9557751374848262], 
             385 -> RGBColor[
              0.542443536294035, 0.6394191254231524, 0.9571222886946632], 270 -> 
             RGBColor[
              0.8954921156452005, 0.9195051218022846, 0.9898940314771298], 
             392 -> RGBColor[
              0.8455599512978527, 0.879690569324204, 0.9851314570667105], 33 -> 
             RGBColor[
              0.6435654945294389, 0.7214775226960958, 0.965108252099362], 252 -> 
             RGBColor[
              0.9437598307571106, 0.9575767543802541, 0.980084116129582], 394 -> 
             RGBColor[
              0.5308214313326965, 0.6299837770456758, 0.9562073540189334], 
             260 -> RGBColor[
              0.6249999943077634, 0.7064421771647478, 0.963621435483774], 159 -> 
             RGBColor[
              0.8350969515716422, 0.8713476573530854, 0.9841334868123943], 
             183 -> RGBColor[
              0.9241300833717252, 0.94234025991049, 0.9926255464043013], 99 -> 
             RGBColor[
              0.5450962568688331, 0.6415727234894735, 0.9573311205755469], 
             329 -> RGBColor[
              0.9532342708379423, 0.9646427762795666, 0.9640463604024634], 
             309 -> RGBColor[
              0.36130077931571947`, 0.48736230836326333`, 0.944242744065631], 
             17 -> RGBColor[
              0.9654681902057143, 0.9737668133128465, 0.9433375260300195], 
             349 -> RGBColor[
              0.43017457643970947`, 0.5470173297343667, 0.9486313215156642], 
             347 -> RGBColor[
              0.791522890227867, 0.8370629647335639, 0.9798552625621064], 340 -> 
             RGBColor[
              0.8719208217045836, 0.900710011839766, 0.9876457804187313], 277 -> 
             RGBColor[
              0.9732301913012801, 0.9795557010208091, 0.9301984828293387], 
             104 -> RGBColor[
              0.5284272737756763, 0.628040092085318, 0.9560188771659567], 79 -> 
             RGBColor[
              0.7635328526577816, 0.8151969346516487, 0.9770654771988929], 
             327 -> 
             RGBColor[
              0.5306229571670711, 0.6298226467768618, 0.9561917294055805], 
             191 -> RGBColor[
              0.9866751538148972, 0.9887578479166023, 0.8704907150910758], 50 -> 
             RGBColor[
              0.7570063495139345, 0.8100983807924143, 0.9764149763591539], 
             225 -> RGBColor[
              0.9419172497042796, 0.9562025604480023, 0.9832031252299198], 61 -> 
             RGBColor[
              0.334411087063865, 0.4640718084499367, 0.9425293566529641], 196 -> 
             RGBColor[
              0.6609013826123831, 0.7350204502241211, 0.9668361314103849], 1 -> 
             RGBColor[
              0.9924379061427775, 0.9861534231348239, 0.4251231226566339], 
             263 -> RGBColor[
              0.9362080171001255, 0.9519446241198346, 0.9928673668224094], 
             201 -> RGBColor[
              0.6829313429559046, 0.7522304226783799, 0.9690318719757429], 
             371 -> RGBColor[
              0.6426389441482242, 0.720753694496247, 0.9650159022164682], 293 -> 
             RGBColor[
              0.8385744876746275, 0.2975059924812765, 0.184572279001863], 362 -> 
             RGBColor[
              0.6675169131539747, 0.7401885529631067, 0.9674955056691229], 
             184 -> RGBColor[
              0.756477746872732, 0.809685432391578, 0.9763622901879513], 106 -> 
             RGBColor[
              0.8625464524558522, 0.893235144261302, 0.986751644711189], 206 -> 
             RGBColor[
              0.824270282078477, 0.8627147649813499, 0.9831008294110544], 358 -> 
             RGBColor[
              0.9912639404839225, 0.9906554291306825, 0.7944426445861034], 
             247 -> RGBColor[
              0.475230744515095, 0.584852753155245, 0.9518310515172563], 220 -> 
             RGBColor[
              0.6406768752179347, 0.7191693753230616, 0.9648555769753296], 
             107 -> RGBColor[
              0.6713741780752616, 0.7432018776359153, 0.9678799617882867], 
             375 -> RGBColor[
              0.6077258092630875, 0.6924182155523118, 0.9622615483596324], 
             131 -> RGBColor[
              0.8705483827377825, 0.899615666261502, 0.9875148759648871], 127 -> 
             RGBColor[
              0.6519652867436496, 0.7280395042146224, 0.9659454648867534], 
             210 -> RGBColor[
              0.6440856925160361, 0.7218839053168765, 0.9651601005731395], 
             357 -> RGBColor[
              0.6406262376734971, 0.7191282654832918, 0.9648515906023402], 
             181 -> RGBColor[
              0.5689100847392322, 0.6609058617553836, 0.9592058323384306], 
             194 -> RGBColor[
              0.9354867633018162, 0.95139576821788, 0.9937087566742613], 118 -> 
             RGBColor[
              0.5441562056818184, 0.6408095475870316, 0.9572571163025841], 
             348 -> RGBColor[
              0.9947849781456418, 0.9912539205101456, 0.6737552384164394], 
             276 -> RGBColor[
              0.9770368423879465, 0.9823946951684258, 0.9237548154732234], 
             305 -> RGBColor[
              0.40235673410468753`, 0.5229229128691799, 0.9468587932004288], 
             343 -> RGBColor[
              0.9932760172994317, 0.9880264058394467, 0.5095141625333595], 
             280 -> RGBColor[
              0.8961075229549269, 0.919995830886274, 0.9899527295757121], 189 -> 
             RGBColor[
              0.8674074183939195, 0.8971111465529116, 0.9872152879817975], 
             168 -> RGBColor[
              0.5235605002473402, 0.6240890260893659, 0.9556357469262272], 
             363 -> RGBColor[
              0.38756790484944065`, 0.510113572276456, 0.9459164620775327], 
             41 -> RGBColor[
              0.43818774401378513`, 0.5539579327335181, 0.9491419134677185], 
             14 -> RGBColor[
              0.3748819846842069, 0.4991256658422175, 0.9451081264623227], 77 -> 
             RGBColor[
              0.9900132215063907, 0.9901382246914615, 0.8151702948007621], 51 -> 
             RGBColor[
              0.8262138446774634, 0.8642645090411804, 0.9832862081467845], 
             179 -> RGBColor[
              0.7632987217089856, 0.815014029774988, 0.9770421412139951], 223 -> 
             RGBColor[
              0.42262279063813524`, 0.5404763524368338, 0.9481501284021698], 
             323 -> RGBColor[
              0.3287223084325424, 0.4591444743258127, 0.9421668727089656], 
             292 -> RGBColor[
              0.8608535577030549, 0.8918852759378254, 0.9865901748984023], 
             396 -> RGBColor[
              0.9259873062574203, 0.9438211590265709, 0.9928026899811013], 
             321 -> RGBColor[
              0.7943804058573836, 0.8392952776612652, 0.9801400730150549], 
             143 -> RGBColor[
              0.6749482206059915, 0.7459939468246507, 0.9682361889464235], 
             112 -> RGBColor[
              0.5795189601810293, 0.6695186247634267, 0.9600410018748], 197 -> 
             RGBColor[
              0.8225487992507267, 0.8613421013029083, 0.9829366328421576], 54 -> 
             RGBColor[
              0.7496884492531001, 0.8043815814905484, 0.9756855964508199], 71 -> 
             RGBColor[
              0.5535141230705568, 0.6484067264925836, 0.9579938058386066], 
             177 -> RGBColor[
              0.5086528299303757, 0.6119863077431595, 0.9544621605102801], 
             158 -> RGBColor[
              0.7013430265918047, 0.7666137698687234, 0.9708669765336034], 
             226 -> RGBColor[
              0.5262680000898958, 0.6262870964330304, 0.9558488912317319], 
             350 -> RGBColor[
              0.3135409458106535, 0.4459951410602042, 0.9411995297070508], 
             203 -> RGBColor[
              0.7186052730768605, 0.7800991680207815, 0.9725875159383687], 
             115 -> RGBColor[
              0.5102097074599855, 0.6132502510582303, 0.9545847236124412], 
             173 -> RGBColor[
              0.8921998743726618, 0.9168799779770709, 0.9895800145655366], 
             212 -> RGBColor[
              0.970768766606411, 0.9777199745135887, 0.9343650327953755], 129 -> 
             RGBColor[
              0.9648279025290644, 0.9732892878119759, 0.9444213660528162], 
             279 -> RGBColor[
              0.7411948587043736, 0.7977463240002043, 0.9748390347220393], 26 -> 
             RGBColor[
              0.7775900901092359, 0.8261785553876864, 0.9784665712557011], 40 -> 
             RGBColor[
              0.8257958753822938, 0.8639312316706864, 0.9832463418622855], 
             146 -> RGBColor[
              0.28970658753366485`, 0.4218303703294086, 0.9398097336263288], 
             386 -> RGBColor[
              0.8376720706989834, 0.8734009874454807, 0.9843791039735962], 
             192 -> RGBColor[
              0.9881889157310716, 0.9893838273708472, 0.8454037626498055], 
             300 -> RGBColor[
              0.9222858836759186, 0.940869745132521, 0.9924496449909788], 221 -> 
             RGBColor[
              0.990486076108984, 0.9795694421193528, 0.41754063154752014`], 
             62 -> RGBColor[
              0.7635328526577816, 0.8151969346516487, 0.9770654771988929], 
             286 -> RGBColor[
              0.782329397911119, 0.8298809386625908, 0.9789389411660434], 152 -> 
             RGBColor[
              0.8970681052882723, 0.9207617731645708, 0.9900443507761886], 64 -> 
             RGBColor[
              0.444881690185426, 0.5597558924598762, 0.9495684457985512], 307 -> 
             RGBColor[
              0.42293789498995593`, 0.5407492799887756, 0.948170206572832], 
             37 -> RGBColor[
              0.9178029735335317, 0.9372951942703358, 0.9920220610196568], 
             148 -> RGBColor[
              0.994416948268152, 0.9904667418157235, 0.6336974574688048], 261 -> 
             RGBColor[
              0.7820193064605834, 0.82963869286465, 0.9789080341482234], 387 -> 
             RGBColor[
              0.6094934286889456, 0.693853248632571, 0.9624007018358393], 15 -> 
             RGBColor[
              0.9887179459137481, 0.9896025949468394, 0.8366363634366315], 
             136 -> RGBColor[
              0.966705402169146, 0.9746895239694252, 0.9412432488924891], 198 -> 
             RGBColor[
              0.9931148948341446, 0.9876817811781777, 0.49197697651945704`], 
             63 -> RGBColor[
              0.8349506972296232, 0.8712310381107278, 0.9841195369426898], 
             310 -> RGBColor[
              0.5765761423525377, 0.6671295126778248, 0.9598093324754443], 
             171 -> RGBColor[
              0.663753585854492, 0.737248613074404, 0.9671204123742037], 395 -> 
             RGBColor[
              0.897506069944511, 0.9211109942932216, 0.9900861242360762], 311 -> 
             RGBColor[
              0.9063654296898017, 0.6664771611306126, 0.24351763072381066`], 
             353 -> RGBColor[
              0.6699900257914643, 0.7421205673518658, 0.9677420024242763], 59 -> 
             RGBColor[
              0.988220000318389, 0.9893966816465403, 0.8448886105936236], 397 -> 
             RGBColor[
              0.5330771215381135, 0.631815047972119, 0.9563849302147693], 229 -> 
             RGBColor[
              0.5851761647657547, 0.674111398299469, 0.9604863577427328], 102 -> 
             RGBColor[
              0.33664610076115403`, 0.46600766497947366`, 0.9426717697494104],
              299 -> RGBColor[
              0.4667500057603363, 0.5779677073812048, 0.951163416696512], 128 -> 
             RGBColor[
              0.7662031809866007, 0.817283015437369, 0.9773316305710726], 12 -> 
             RGBColor[
              0.9930579379883027, 0.9913972932023766, 0.7647114632218087], 
             222 -> RGBColor[
              0.5363976964575989, 0.6345108402819527, 0.9566463380360979], 92 -> 
             RGBColor[
              0.8596761344180449, 0.890946430570662, 0.9864778712143798], 271 -> 
             RGBColor[
              0.8016246329364234, 0.8449545229135762, 0.9808621098691426], 
             361 -> RGBColor[
              0.9870022868993861, 0.9888931258539752, 0.8650692732878114], 
             344 -> RGBColor[
              0.5149660398729791, 0.6171116559814318, 0.9549591595230118], 
             132 -> RGBColor[
              0.9797618247775517, 0.9844269825728442, 0.9191421310768542], 80 -> 
             RGBColor[
              0.800385582388989, 0.8439865672087875, 0.98073861289016], 324 -> 
             RGBColor[
              0.5377917093879147, 0.6356425627783499, 0.95675607984041], 244 -> 
             RGBColor[
              0.993565623796668, 0.9886458448533266, 0.5410360425134004], 150 -> 
             RGBColor[
              0.7652294304721008, 0.8165223141346637, 0.9772345762200032], 
             125 -> RGBColor[
              0.8664154821681412, 0.8963202035318676, 0.9871206762190707], 
             258 -> RGBColor[
              0.9951094666437609, 0.9919479685968027, 0.7090738089258225], 
             133 -> RGBColor[
              0.8214220586110358, 0.8604436689013787, 0.9828291633140906], 
             255 -> RGBColor[
              0.6239289809985044, 0.7055726803116915, 0.9635371213928181], 
             326 -> RGBColor[
              0.6066428051972038, 0.6915389840628502, 0.9621762903123914], 
             176 -> RGBColor[
              0.7899708355890648, 0.8358504878536794, 0.9797005682604859], 
             230 -> RGBColor[
              0.24576327435627854`, 0.3756431620129988, 0.9373072269491829], 
             274 -> RGBColor[
              0.8282566472084689, 0.8658933843290066, 0.9834810524758231], 87 -> 
             RGBColor[
              0.8620372367830552, 0.892829109506105, 0.9867030752657354], 130 -> 
             RGBColor[
              0.94744001837713, 0.9603214322815105, 0.9738545184355454], 35 -> 
             RGBColor[
              0.5851761647657547, 0.674111398299469, 0.9604863577427328], 379 -> 
             RGBColor[
              0.9677290766989244, 0.9754529787576207, 0.9395104349306516], 31 -> 
             RGBColor[
              0.9230903503387538, 0.9415112050127998, 0.9925263757394359], 18 -> 
             RGBColor[
              0.4990774811827185, 0.6042126082652661, 0.9537083539812062], 24 -> 
             RGBColor[
              0.6090487345764104, 0.6934922259187735, 0.9623656938863322], 
             151 -> RGBColor[
              0.9057239829173755, 0.9276637350284787, 0.9908699561116456], 
             137 -> RGBColor[
              0.9439668911526019, 0.9577311796841813, 0.9797336168900153], 
             330 -> RGBColor[
              0.9763120065912875, 0.9818541138180872, 0.9249817734095143], 
             296 -> RGBColor[
              0.42622351575179596`, 0.5435951195525803, 0.9483795634224161], 
             266 -> RGBColor[
              0.9117250388177226, 0.9324488141090924, 0.9914423421806265], 
             302 -> RGBColor[
              0.37918762896895897`, 0.5028549985136956, 0.9453824783088154], 
             283 -> 
             RGBColor[
              0.5094056087122162, 0.6125974474705552, 0.9545214220135061], 
             388 -> RGBColor[
              0.731483967330903, 0.7901601018537411, 0.9738711438233711], 284 -> 
             RGBColor[
              0.9704458945755612, 0.9774791770816355, 0.9349115709250919], 
             318 -> RGBColor[
              0.6050261970001051, 0.6902265487010761, 0.9620490249932848], 
             238 -> RGBColor[
              0.4348936378012798, 0.5511047434988383, 0.9489320159327214], 72 -> 
             RGBColor[
              0.6081442568554352, 0.6927579301586287, 0.962294490086926], 288 -> 
             RGBColor[
              0.6682266974043815, 0.7407430418140846, 0.9675662503298925], 
             382 -> RGBColor[
              0.9140878907704766, 0.9343328881183108, 0.9916677131092231], 
             389 -> RGBColor[
              0.4315717982822388, 0.5482275330679538, 0.9487203512559554], 
             172 -> RGBColor[
              0.9852537813753871, 0.9881700738852593, 0.8940465348077178], 
             243 -> RGBColor[
              0.7825750822327692, 0.8300728691219339, 0.9789634286831749], 88 -> 
             RGBColor[
              0.5004404090666833, 0.6053190945206702, 0.9538156486568014], 
             273 -> RGBColor[
              0.7274449487121358, 0.7870047898110817, 0.9734685721942274], 
             202 -> RGBColor[
              0.9862493958355908, 0.988581786050678, 0.8775466266345147], 393 -> 
             RGBColor[
              0.7225771388249261, 0.7832020197304681, 0.9729833943969401], 98 -> 
             RGBColor[
              0.9504049262814185, 0.9625326557419377, 0.9688357027254134], 30 -> 
             RGBColor[
              0.955002665898284, 0.9659616424200883, 0.9610529288366044], 116 -> 
             RGBColor[
              0.33337803042807235`, 0.4631770267149493, 0.9424635311976275], 
             373 -> RGBColor[
              0.37742900716231714`, 0.5013317686956846, 0.9452704204823843], 
             240 -> RGBColor[
              0.7785445758001376, 0.8269242068637787, 0.9785617054691943], 
             317 -> RGBColor[
              0.8306622457778632, 0.23668903409623956`, 0.17699550722592247`],
              391 -> RGBColor[
              0.8843636450016763, 0.9106315813854269, 0.9888325880126475], 73 -> 
             RGBColor[
              0.5040889388830511, 0.6082811353899927, 0.9541028742889509], 
             303 -> RGBColor[
              0.5460380738769077, 0.6423373329650012, 0.9574052638604119], 29 -> 
             RGBColor[
              0.5099789175243196, 0.6130628853914885, 0.9545665549832942], 
             360 -> RGBColor[
              0.9606939685963759, 0.9702062066536724, 0.9514190378982097], 
             320 -> RGBColor[
              0.4115702927671239, 0.530903234295659, 0.9474458730111691], 75 -> 
             RGBColor[
              0.9484448220772062, 0.9610708132358122, 0.972153647866093], 200 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 301 -> 
             RGBColor[
              0.8643380160971912, 0.8946636884782062, 0.9869225256506476], 
             156 -> RGBColor[
              0.7820193064605834, 0.82963869286465, 0.9789080341482234], 25 -> 
             RGBColor[
              0.4878170039851197, 0.5950708455975385, 0.9528218879677242], 38 -> 
             RGBColor[
              0.8428764446812853, 0.3305727191640294, 0.18869183788980406`], 
             365 -> RGBColor[
              0.6528867298207077, 0.728759342549647, 0.9660373057212994], 380 -> 
             RGBColor[
              0.9933493639249037, 0.9881832868548499, 0.5174974900730858], 
             370 -> RGBColor[
              0.5097342188801428, 0.6128642280085975, 0.954547291409664], 3 -> 
             RGBColor[
              0.9896993313529787, 0.9900084230464167, 0.8203722669644762], 57 -> 
             RGBColor[
              0.5979062707801812, 0.6844462718467209, 0.9614885183201033], 
             227 -> RGBColor[
              0.6295086697461069, 0.7101025229991088, 0.9639763749301028], 39 -> 
             RGBColor[
              0.8376720706989834, 0.8734009874454807, 0.9843791039735962], 
             109 -> RGBColor[
              0.7943804058573836, 0.8392952776612652, 0.9801400730150549], 
             256 -> RGBColor[
              0.2751023286954908, 0.40648036832699624`, 0.9389780426905596], 
             339 -> RGBColor[
              0.5699001198658948, 0.6617096168717824, 0.9592837715302196], 
             287 -> RGBColor[
              0.4260203888921774, 0.5434191812762315, 0.9483666203585392], 
             239 -> RGBColor[
              0.5881839734092238, 0.6765532728564724, 0.9607231434571128], 
             285 -> RGBColor[
              0.9935131535024766, 0.9885336161996117, 0.5353249747997872], 
             345 -> RGBColor[
              0.9859758220491865, 0.9643552961176418, 0.4000191462152182], 
             366 -> RGBColor[
              0.9813591087362303, 0.9856182343339144, 0.9164383459731876], 
             216 -> RGBColor[
              0.9466566520570323, 0.9597371989626262, 0.9751805532808125], 21 -> 
             RGBColor[
              0.4018310221297295, 0.5224675675795234, 0.9468252952982532], 
             355 -> RGBColor[
              0.7525587736631136, 0.8066239007349245, 0.9759716835633033], 
             175 -> RGBColor[
              0.6047155936443523, 0.6899743869043544, 0.9620245731593424], 7 -> 
             RGBColor[
              0.7567725373277479, 0.8099157249355268, 0.9763916721455338], 13 -> 
             RGBColor[
              0.6414683426968801, 0.719811924277673, 0.9649178841945132], 294 -> 
             RGBColor[
              0.43121908771191103`, 0.5479220328996847, 0.9486978768503038], 
             193 -> RGBColor[
              0.897506069944511, 0.9211109942932216, 0.9900861242360762], 60 -> 
             RGBColor[
              0.822633302404772, 0.8614094818241671, 0.9829446928284273], 65 -> 
             RGBColor[
              0.948848683088601, 0.9613720121168488, 0.9714700165176229], 69 -> 
             RGBColor[
              0.8005428491240347, 0.8441094251774768, 0.9807542877685681], 
             217 -> RGBColor[
              0.9722386895952226, 0.9788162406718666, 0.9318768365926329], 
             214 -> RGBColor[
              0.9628502783981937, 0.9718143789732349, 0.9477689678593996], 
             170 -> RGBColor[
              0.9383148340089732, 0.7931459027482709, 0.26922487138792206`], 
             359 -> RGBColor[
              0.29970476739450336`, 0.4323390912843666, 0.940379115178422], 
             74 -> RGBColor[
              0.334411087063865, 0.4640718084499367, 0.9425293566529641], 246 -> 
             RGBColor[
              0.9926173102134606, 0.991215082293862, 0.7720138057590694], 264 -> 
             RGBColor[
              0.5891333774106766, 0.6773240417950146, 0.9607978840178886], 
             278 -> RGBColor[
              0.5009702002553983, 0.6057492028744902, 0.9538573557598661], 45 -> 
             RGBColor[
              0.930153470894393, 0.9471431456205666, 0.9932000624833549], 306 -> 
             RGBColor[
              0.24576327435627854`, 0.3756431620129988, 0.9373072269491829], 
             237 -> RGBColor[
              0.4972545796723052, 0.6027326946983355, 0.9535648484967982], 
             228 -> RGBColor[
              0.5725048293421288, 0.6638242373654138, 0.959488823801554], 180 -> 
             RGBColor[
              0.8733661858438407, 0.9018625059710452, 0.9877836405406254], 
             383 -> RGBColor[
              0.5765761423525377, 0.6671295126778248, 0.9598093324754443], 53 -> 
             RGBColor[
              0.9845183033877789, 0.9878659348364612, 0.9062353084184037], 
             304 -> 
             RGBColor[
              0.3417386844296112, 0.4704186049923937, 0.9429962646775695], 48 -> 
             RGBColor[
              0.8800739647019734, 0.9072111067547136, 0.9884234344762189], 5 -> 
             RGBColor[
              0.9362917738419911, 0.952007089760779, 0.9927255885056876], 101 -> 
             RGBColor[
              0.5851761647657547, 0.674111398299469, 0.9604863577427328], 333 -> 
             RGBColor[
              0.9927302668989471, 0.9868591009166395, 0.4501125994216634], 
             267 -> RGBColor[
              0.9949480630274398, 0.9916027425819006, 0.6915060213569252], 
             120 -> RGBColor[
              0.8835284999393881, 0.909965659382167, 0.9887529311310636], 147 -> 
             RGBColor[
              0.3413895708986362, 0.47011622039881945`, 0.9429740194720848], 
             89 -> RGBColor[
              0.8148234176307089, 0.8552655138312311, 0.9821776413778132], 43 -> 
             RGBColor[
              0.3953022991789216, 0.5168127159026903, 0.9464092908449508], 
             199 -> RGBColor[
              0.5797728081010229, 0.669724709940596, 0.9600609857129375], 268 -> 
             RGBColor[
              0.8891059118355471, 0.9144129362333514, 0.9892849096567337], 
             169 -> RGBColor[
              0.791522890227867, 0.8370629647335639, 0.9798552625621064], 20 -> 
             RGBColor[
              0.610010288631481, 0.6942728588181963, 0.962441390943836], 4 -> 
             RGBColor[
              0.9738803759396449, 0.9800406076595221, 0.9290978898318994], 
             167 -> RGBColor[
              0.6547371126907764, 0.7302048757111753, 0.9662217345929768], 
             142 -> RGBColor[
              0.5037776839492212, 0.6080284446128347, 0.9540783711603954], 16 -> 
             RGBColor[
              0.3978214010750888, 0.5189946353514076, 0.9465698057902202], 
             281 -> RGBColor[
              0.9024082180749616, 0.9250198341471768, 0.990553695500958], 289 -> 
             RGBColor[
              0.5138381121033654, 0.6161959534054924, 0.9548703649172522], 
             398 -> RGBColor[
              0.791522890227867, 0.8370629647335639, 0.9798552625621064], 178 -> 
             RGBColor[
              0.4988793460315659, 0.6040517532236737, 0.9536927560563145], 58 -> 
             RGBColor[
              0.609695475631052, 0.6940172794422841, 0.9624166077112442], 186 -> 
             RGBColor[
              0.9506882966664306, 0.9627439929111032, 0.9683560305784211], 
             122 -> RGBColor[
              0.960062389264623, 0.9697351758221673, 0.9524881369645959], 249 -> R\
GBColor[0.5256786403150654, 0.6258086276174677, 0.9558024946713612], 113 -> 
             RGBColor[
              0.9898999311581932, 0.9900913762210527, 0.8170478090564172], 52 -> 
             RGBColor[
              0.6081442568554352, 0.6927579301586287, 0.962294490086926], 187 -> 
             RGBColor[
              0.5138381121033654, 0.6161959534054924, 0.9548703649172522], 
             259 -> RGBColor[
              0.8894234669854597, 0.9146661460900868, 0.9893151983504171], 42 -> 
             RGBColor[
              0.3966102903329119, 0.5179456320987298, 0.946492634884672], 134 -> 
             RGBColor[
              0.9706486163226078, 0.9776303666286564, 0.9345684158856415], 
             313 -> RGBColor[
              0.47921634148826964`, 0.5880884403271657, 0.9521448123107074], 
             248 -> RGBColor[
              0.9915459100122354, 0.9907720307769262, 0.7897696797882106], 
             174 -> RGBColor[
              0.6060810360585558, 0.6910829145686844, 0.9621320657879688], 
             215 -> RGBColor[
              0.4267890943037298, 0.5440849952674608, 0.9484156015876238], 
             399 -> RGBColor[
              0.7918243877750588, 0.8372984969088962, 0.9798853130199557], 83 -> 
             RGBColor[
              0.495932342801897, 0.6016592432408459, 0.9534607571668465], 95 -> 
             RGBColor[
              0.5975089423958573, 0.684123702764887, 0.9614572391742275], 166 -> 
             RGBColor[
              0.7696575086367777, 0.8199815624515499, 0.9776759256687151], 
             384 -> RGBColor[
              0.413186645620662, 0.5323032378971372, 0.9475488655857119], 233 -> 
             RGBColor[
              0.7657285088262574, 0.8169121979380669, 0.9772843196861931], 
             295 -> RGBColor[
              0.8282566472084689, 0.8658933843290066, 0.9834810524758231], 
             141 -> RGBColor[
              0.810861510125734, 0.8521704415767324, 0.981782755463848], 319 -> 
             RGBColor[
              0.8240390833945807, 0.8625304134265321, 0.9830787774741908], 
             205 -> RGBColor[
              0.7043134481076896, 0.7689342857329724, 0.9711630403901396], 
             224 -> RGBColor[
              0.751575212018765, 0.805855534903014, 0.9758736513305009], 231 -> 
             RGBColor[
              0.7416030574326392, 0.7980652119491506, 0.9748797201564388], 
             332 -> RGBColor[
              0.6330626130696874, 0.7129877742925136, 0.9642561543670584], 68 -> 
             RGBColor[
              0.3558010361469244, 0.4825987072555821, 0.9438923052941474], 10 -> 
             RGBColor[
              0.4630616645372514, 0.5749733458184259, 0.9508730569645917], 
             250 -> RGBColor[
              0.7316596818731754, 0.7902973713896443, 0.9738886574067991], 
             282 -> RGBColor[
              0.5185701072023124, 0.6200376002007676, 0.9552428849053105], 
             374 -> RGBColor[
              0.9849212878635141, 0.9880325792734063, 0.89955681276508], 232 -> 
             RGBColor[
              0.657808163965805, 0.7326040043080818, 0.9665278282834657], 253 -> 
             RGBColor[
              0.7001301212306313, 0.7656662389821527, 0.9707460854624467], 55 -> 
             RGBColor[
              0.994110758050142, 0.9918326613541886, 0.7472635101861482], 325 -> 
             RGBColor[
              0.9373860389046685, 0.9528231908528292, 0.9908732831846117], 91 -> 
             RGBColor[
              0.9458111663906987, 0.9591066371370304, 0.9766117399759368], 
             105 -> RGBColor[
              0.4423712024341456, 0.5575814341505004, 0.9494084797389768], 36 -> 
             RGBColor[
              0.9638902105103407, 0.9725899586397415, 0.9460086340512684], 
             123 -> RGBColor[
              0.796133645312963, 0.8406649216490775, 0.9803148195390328], 94 -> 
             RGBColor[
              0.4489973944430271, 0.5633207086264995, 0.9498306948344711], 
             312 -> RGBColor[
              0.6522829433802101, 0.7282876599933834, 0.9659771259316157], 96 -> 
             RGBColor[
              0.7938242897832621, 0.8388608355575229, 0.9800846445619866], 2 -> 
             RGBColor[
              0.6346341545689248, 0.7142636224787323, 0.9643798718706246], 
             262 -> RGBColor[
              0.46716110372605846`, 0.5783014552295304, 0.9511957798342752], 
             272 -> RGBColor[
              0.5795189601810293, 0.6695186247634267, 0.9600410018748], 97 -> 
             RGBColor[
              0.9549040306625556, 0.9658880804227824, 0.961219892562503], 372 -> 
             RGBColor[
              0.9887179459137481, 0.9896025949468394, 0.8366363634366315], 
             356 -> RGBColor[
              0.7472439689884992, 0.8024719349291042, 0.9754419535030113], 
             346 -> RGBColor[
              0.4852298526758003, 0.5929704796147948, 0.9526182179396071], 
             341 -> RGBColor[
              0.8397533411147607, 0.8750605359804411, 0.984577617403825], 209 -> 
             RGBColor[
              0.45960333662087877`, 0.5721657194200174, 0.9506008047227422], 
             378 -> RGBColor[
              0.9396099926293251, 0.9544818118992879, 0.9871087096287963], 66 -> 
             RGBColor[
              0.28140739887720867`, 0.41310739685252057`, 0.939337107109893], 
             139 -> RGBColor[
              0.582427645895669, 0.6718800268613693, 0.9602699842691234], 56 -> 
             RGBColor[
              0.7070291220479139, 0.771055790854962, 0.9714337133890852], 335 -> 
             RGBColor[
              0.6745786145057584, 0.7457052077300382, 0.9681993500645176], 
             314 -> RGBColor[
              0.5488971211941418, 0.6446584363757456, 0.9576303385382601], 
             144 -> RGBColor[
              0.9851640555827066, 0.9881329699641382, 0.895533523395342], 298 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 204 -> 
             RGBColor[
              0.9379280833984235, 0.9532274467487553, 0.9899557432445302], 
             207 -> RGBColor[
              0.7405094428847672, 0.7972108719525746, 0.9747707188787159], 
             334 -> RGBColor[
              0.7053354685000337, 0.7697326958311144, 0.9712649058315248], 
             149 -> RGBColor[
              0.8904238653615132, 0.5953221894106315, 0.23027932611185578`], 
             219 -> RGBColor[
              0.7650710769531043, 0.8163986071620923, 0.9772187930211275], 
             400 -> RGBColor[
              0.7410894767752259, 0.7976639988362217, 0.974828531236192], 9 -> 
             RGBColor[
              0.7124399602097777, 0.7752827787509032, 0.9719730151699023], 11 -> 
             RGBColor[
              0.7410894767752259, 0.7976639988362217, 0.974828531236192], 44 -> 
             RGBColor[
              0.8495572621046469, 0.3819244094328485, 0.19508939619931917`], 
             153 -> RGBColor[
              0.8281923478168176, 0.8658421137394644, 0.9834749195424467], 32 -> 
             RGBColor[
              0.6739471522860687, 0.7452119046447261, 0.9681364118118089], 
             162 -> RGBColor[
              0.9042580997772961, 0.6581223002535925, 0.24182202361081806`], 
             90 -> RGBColor[
              0.3795471868545512, 0.5031664294822908, 0.9454053890193407], 
             331 -> RGBColor[
              0.5623506050301632, 0.6555805806263679, 0.9586894460675668], 8 -> 
             RGBColor[
              0.36505947766395846`, 0.49061790395483595`, 0.9444822450006943],
              364 -> RGBColor[
              0.6632484910615767, 0.736854029183316, 0.967070069245625], 342 -> 
             RGBColor[
              0.8964504204688373, 0.9202692480561611, 0.9899854354466971], 
             163 -> RGBColor[
              0.9908094047614856, 0.9806601055854186, 0.4187967023069963], 49 -> 
             RGBColor[
              0.5072333229827832, 0.6108338880550448, 0.9543504117235403], 
             338 -> RGBColor[
              0.8572433910126156, 0.8890066270142334, 0.9862458339766343], 76 -> 
             RGBColor[
              0.8661136909014501, 0.8960795633677138, 0.9870918910986415], 
             369 -> RGBColor[
              0.9936411994888305, 0.9888074936169874, 0.5492619902061732], 82 -> 
             RGBColor[
              0.6886145523965123, 0.7566701890873742, 0.9695983211801709], 67 -> 
             RGBColor[
              0.9883357309894402, 0.9894445392531626, 0.8429706538729287], 
             211 -> RGBColor[
              0.923095448394654, 0.9415152700641917, 0.9925268619965587]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9l3k0VX/Yxa95Hq55dufJNVwqktwdKpWiSIU0EZFIxkiFhGRKk6SkQSmp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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 7}], {
             RGBColor[
             0.8746052217352627, 0.8980345740351754, 0.7007573974010839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 35}], {
             RGBColor[
             0.7888070354542661, 0.8301324107171464, 0.6928047401996833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 41}], {
             RGBColor[
             0.7153128250782813, 0.770055677934171, 0.6871325180621761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 57}], {
             RGBColor[
             0.7951720884614794, 0.8352998474907725, 0.6933058204883686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 92}], {
             RGBColor[
             0.9260570202804113, 0.938549926852743, 0.7058004969355068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 96}], {
             RGBColor[
             0.8931310979630198, 0.9125071293461734, 0.7026038836093103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 114}], {
             RGBColor[
             0.8447835344214032, 0.8747376452523703, 0.697785050309151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 153}], {
             RGBColor[
             0.9103151269797976, 0.9259977684371441, 0.7042990210995403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 154}], {
             RGBColor[
             0.7618599653797917, 0.8082555652790153, 0.6906833681330506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 161}], {
             RGBColor[
             0.8707502749175396, 0.8950230602824891, 0.7003731723288193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 188}], {
             RGBColor[
             0.9816335098119192, 0.9819592021243588, 0.6796930019671064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 203}], {
             RGBColor[
             0.8555215896098189, 0.8831262955778028, 0.6988553192975013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 222}], {
             RGBColor[
             0.7644178013001882, 0.8103321317083882, 0.6908847303463659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 312}], {
             RGBColor[
             0.8223604247614937, 0.8572205415641037, 0.6955501242941248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 327}], {
             RGBColor[
             0.7615304316549243, 0.8079880349558428, 0.6906574260311071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 337}], {
             RGBColor[
             0.875506392433413, 0.8987385754337214, 0.7008472176743565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 356}], {
             RGBColor[
             0.8698409375656384, 0.894312679031964, 0.7002825380798225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 361}], {
             RGBColor[
             0.9897200965210817, 0.9875232744943996, 0.6450961979722226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[
             0.45802077672306674`, 0.5636855096656265, 0.9518584894902589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 98}], {
             RGBColor[
             0.7925195404251717, 0.838398139110335, 0.966607787298019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 106}], {
             RGBColor[
             0.7485903035123884, 0.8037493833700171, 0.9755657582909067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 107}], {
             RGBColor[
             0.6530041663220931, 0.7287327500573237, 0.9661299168294557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 197}], {
             RGBColor[
             0.7285914769098257, 0.7878028618908204, 0.973658252356391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 215}], {
             RGBColor[
             0.5307116244363272, 0.6291743088730966, 0.9563977367291242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 283}], {
             RGBColor[
             0.5720198816405705, 0.6634305349746438, 0.9594506469420654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 352}], {
             RGBColor[
             0.55660746851502, 0.650918043678023, 0.9582373253232924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 52}], {
             RGBColor[
             0.7989217941042069, 0.8413831766025227, 0.8913333785257012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 86}], {
             RGBColor[
             0.8907264537689614, 0.9136258007014637, 0.9001252610734506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 117}], {
             RGBColor[
             0.7938565881785006, 0.8372710142471078, 0.8909346269607687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 174}], {
             RGBColor[
             0.7978901837057673, 0.8405456688075506, 0.8912521663762225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 232}], {
             RGBColor[
             0.8237537476593919, 0.8613062136772492, 0.893450047623971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 309}], {
             RGBColor[
             0.6755000553343491, 0.73868536570484, 0.8823075055150535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 371}], {
             RGBColor[
             0.8161691377506015, 0.8553810587713319, 0.8926940845904722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 386}], {
             RGBColor[
             0.9136857010259811, 0.9317047052459486, 0.9023756854690361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 16}], {
             RGBColor[
             0.6858508885073669, 0.7495176215054649, 0.9378338478110598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 73}], {
             RGBColor[
             0.738984657411348, 0.7941608715247575, 0.9416003820604252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 115}], {
             RGBColor[
             0.7420450416998152, 0.7966454293588762, 0.9418413067221703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 188}], {
             RGBColor[
             0.9723547447103529, 0.9789027943867079, 0.9316803855547391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 195}], {
             RGBColor[
             0.824573605175621, 0.8631417290053331, 0.9486829176124252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 206}], {
             RGBColor[
             0.899075329009061, 0.9213776863204359, 0.9560993596214769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 208}], {
             RGBColor[
             0.983598043640404, 0.9857722483838898, 0.8447686907503782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 258}], {
             RGBColor[
             0.9844949212917029, 0.9859942881281624, 0.819085849378861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 278}], {
             RGBColor[
             0.7374252880975216, 0.7928949052670061, 0.9414776227958828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 284}], {
             RGBColor[
             0.972163135257603, 0.9787598923705787, 0.9320047303784957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 369}], {
             RGBColor[
             0.9837607877142377, 0.9844240506382547, 0.7391799400190363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 392}], {
             RGBColor[
             0.9097201636187489, 0.929865588491863, 0.957114673449305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 99}], {
             RGBColor[
             0.7406940153554121, 0.7967899066251263, 0.9750283545406173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 174}], {
             RGBColor[
             0.7711864049502735, 0.8215450021647317, 0.9774288271468282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 193}], {
             RGBColor[
             0.9168989218932511, 0.9365590420270002, 0.9914058563708819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 223}], {
             RGBColor[
             0.6794572822400632, 0.7462417210988064, 0.9704378584539287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 235}], {
             RGBColor[
             0.9371099286202074, 0.9526172682547671, 0.9913406658751089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 260}], {
             RGBColor[
             0.7806458840748773, 0.8292246334627633, 0.9781735119947308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 267}], {
             RGBColor[
             0.9656199184347154, 0.9718049161713398, 0.8421158049313064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 272}], {
             RGBColor[
             0.7579053670115102, 0.8107628572621028, 0.9763832951902438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 275}], {
             RGBColor[
             0.9626335744812899, 0.970858069150138, 0.9125478418897682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 291}], {
             RGBColor[
             0.9650753369123628, 0.9706401113606655, 0.7828414669908041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 321}], {
             RGBColor[
             0.8653360898496874, 0.8956511837110221, 0.9864328307603712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 338}], {
             RGBColor[
             0.8967675824273034, 0.9205068583875062, 0.989485711241161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 384}], {
             RGBColor[
             0.6747392097313265, 0.7421551638289581, 0.9701372270456998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 398}], {
             RGBColor[
             0.8639073320349291, 0.8945350272471715, 0.986290425533897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 13}], {
             RGBColor[
             0.6476871554530765, 0.724683751801483, 0.9655283890365303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 18}], {
             RGBColor[
             0.5764917246959957, 0.6668840937952796, 0.9599236239298767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 74}], {
             RGBColor[
             0.49415852763656903`, 0.5968136938876147, 0.9543341252657558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 102}], {
             RGBColor[
             0.4952760344852135, 0.5977816221523833, 0.9544053318139789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 132}], {
             RGBColor[
             0.8168338964934123, 0.8569912809490685, 0.9426405124777008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 160}], {
             RGBColor[
             0.8084457316394654, 0.8081795520777515, 0.6384224805686249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 166}], {
             RGBColor[
             0.7117817384230254, 0.7747685708884213, 0.9719074097736312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 185}], {
             RGBColor[
             0.5997786214651264, 0.685789445655204, 0.9617568537462563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 198}], {
             RGBColor[
             0.8235104315217088, 0.8586186802517353, 0.7290579351990022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 213}], {
             RGBColor[
             0.5936373443253753, 0.6808036802117718, 0.9612733899135757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 216}], {
             RGBColor[
             0.8002813101331527, 0.8446463891439595, 0.9706597235796799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 224}], {
             RGBColor[
             0.702740590114019, 0.7677055571141534, 0.9710062726045241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 247}], {
             RGBColor[
             0.564568356362184, 0.657204166240269, 0.9589849726979018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 289}], {
             RGBColor[
             0.5838720401563192, 0.6728757663653926, 0.9605046293978998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 302}], {
             RGBColor[
             0.516546798589116, 0.6162052889194942, 0.9557606860936814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 323}], {
             RGBColor[
             0.49131413832090776`, 0.5943500268255528, 0.9541528832937565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 340}], {
             RGBColor[
             0.7629133949569283, 0.8151327955825294, 0.9768923371486393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 40}], {
             RGBColor[
             0.7912842063550208, 0.8369234783031065, 0.9798190070039097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 41}], {
             RGBColor[
             0.5974801406707665, 0.6819368288345224, 0.9627667928066261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 80}], {
             RGBColor[
             0.7785790598583684, 0.8269511460721571, 0.9785651425178469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 96}], {
             RGBColor[
             0.775298413555505, 0.8243882802465248, 0.9782381583537603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 114}], {
             RGBColor[
             0.7269508500138884, 0.7866187961527217, 0.973419325053601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 153}], {
             RGBColor[
             0.7924824425722827, 0.8378789193374956, 0.9799332958439902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 154}], {
             RGBColor[
             0.6440272809722769, 0.7201367161793668, 0.9663176428775005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 192}], {
             RGBColor[
             0.8724807265294097, 0.899649776153187, 0.9108977173976697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 203}], {
             RGBColor[
             0.7376889052023041, 0.7950074464781541, 0.9744895940419512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 222}], {
             RGBColor[
             0.6465851168926734, 0.7222132826087397, 0.9665190050908159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 228}], {
             RGBColor[
             0.6646386833349383, 0.7368699811504703, 0.9679402479735439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 312}], {
             RGBColor[
             0.7045277403539789, 0.7691016924644551, 0.9711843990385747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 332}], {
             RGBColor[
             0.6949175751987176, 0.7614517496140202, 0.9703239132562961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 356}], {
             RGBColor[
             0.7520082531581236, 0.8061938299323155, 0.9759168128242726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 361}], {
             RGBColor[
             0.8718874121135669, 0.899404425394751, 0.9207304727166725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 385}], {
             RGBColor[
             0.6496080368108914, 0.7246674251793396, 0.9667569804200985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 17}], {
             RGBColor[
             0.6652638339348365, 0.7321923586338412, 0.9439098855153569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.383445249896844, 0.5065427357671797, 0.9456537701494738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 36}], {
             RGBColor[
             0.6644748440871495, 0.7316039312972887, 0.9452454395259814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 60}], {
             RGBColor[
             0.5938463900343652, 0.6760136928895015, 0.9637134689145608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 64}], {
             RGBColor[
             0.4049705839246922, 0.5251868982073561, 0.9470253453996227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.5268370150302354, 0.623644046521105, 0.9570402830904325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 157}], {
             RGBColor[
             0.6543396061595019, 0.7240450874457781, 0.9624017536440785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 171}], {
             RGBColor[
             0.5144065317592252, 0.61393325851462, 0.9558013286874489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 182}], {
             RGBColor[
             0.3962298821455448, 0.5176161416467038, 0.9464683956113547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 210}], {
             RGBColor[
             0.5045725850899972, 0.6062509046358562, 0.9548211727869169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 253}], {
             RGBColor[
             0.5325947994472949, 0.6281420714684943, 0.9576141652315705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 61}], {
             RGBColor[
             0.5234255236368214, 0.61967729360042, 0.9572511859114332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 131}], {
             RGBColor[
             0.7914941714737801, 0.8374492225062027, 0.9797439455673946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 142}], {
             RGBColor[
             0.6081088220794995, 0.691655611681869, 0.9630256931651489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 202}], {
             RGBColor[
             0.8493446780226843, 0.8819322824007907, 0.9247598209022085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 214}], {
             RGBColor[
             0.8376451193039858, 0.873548578862069, 0.9598709915146509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 215}], {
             RGBColor[
             0.5696145272567538, 0.659683887009182, 0.9601943083787631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 217}], {
             RGBColor[
             0.8423393249025002, 0.8770495097113848, 0.9519249258812676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 269}], {
             RGBColor[
             0.557325140602968, 0.649039437972206, 0.9594112395282618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 279}], {
             RGBColor[
             0.7268174094570756, 0.7865145513755538, 0.9734060249459708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 300}], {
             RGBColor[
             0.8173629219428482, 0.8580762619417122, 0.9822113300804405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 306}], {
             RGBColor[
             0.47910161728302814`, 0.575462970381951, 0.9546401210595425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 363}], {
             RGBColor[
             0.5500039325296092, 0.6426981755136796, 0.9589447386237175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 39}], {
             RGBColor[
             0.6503668676181174, 0.7241871666319533, 0.9676260804690939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 177}], {
             RGBColor[
             0.48585724723381357`, 0.5934798267807927, 0.952667608737436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.6652345414655855, 0.7360422461856687, 0.9690441724731946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 200}], {
             RGBColor[
             0.3209943322686257, 0.4401836729092129, 0.9421870284822959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 216}], {
             RGBColor[
             0.7048591582971419, 0.767355272390526, 0.9630268051227021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 219}], {
             RGBColor[
             0.6140663707451779, 0.6956859764902591, 0.9640459249928596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 241}], {
             RGBColor[
             0.6278429654278045, 0.7064483569623246, 0.9654190472012267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 296}], {
             RGBColor[
             0.4446425901445237, 0.5592842326855031, 0.9496263101935039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 311}], {
             RGBColor[
             0.6847135471135266, 0.6207252534745192, 0.5971953438442011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 339}], {
             RGBColor[
             0.5164808922015731, 0.6183414813451041, 0.9550784142474056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 360}], {
             RGBColor[
             0.7118778165668136, 0.7725897762360492, 0.9511460474314006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 374}], {
             RGBColor[
             0.7239914762003827, 0.781502962545916, 0.9252149348648359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 14}], {
             RGBColor[
             0.5579857307297164, 0.6483948323392197, 0.9599683288492573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 25}], {
             RGBColor[
             0.6144532403801728, 0.6963674222168801, 0.963825209601958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 38}], {
             RGBColor[
             0.7919829607282556, 0.5641183590001255, 0.581760184562998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 78}], {
             RGBColor[
             0.7410894767752259, 0.7976639988362217, 0.974828531236192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 102}], {
             RGBColor[
             0.53886778876819, 0.6318358319078476, 0.9587501504928011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 144}], {
             RGBColor[
             0.8631267661789662, 0.8928984844001799, 0.935181027315767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 205}], {
             RGBColor[
             0.7227014624414577, 0.7832991422845971, 0.9729957858131657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 207}], {
             RGBColor[
             0.7407994598299965, 0.7974374353943982, 0.974799625057454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 213}], {
             RGBColor[
             0.6372290986083516, 0.7148578899672362, 0.965618208592398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 221}], {
             RGBColor[
             0.8657877764421049, 0.8886167204777873, 0.696184581391856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 230}], {
             RGBColor[
             0.4934263755657522, 0.5866535804246102, 0.9560678790926874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 250}], {
             RGBColor[
             0.7363745793242007, 0.793980685112933, 0.9743585943214955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 289}], {
             RGBColor[
             0.6274637944392956, 0.7069299761208571, 0.964849448076722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 358}], {
             RGBColor[
             0.8661767086295742, 0.8941597139834521, 0.8846355879111476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 391}], {
             RGBColor[
             0.8127265608884511, 0.8541477901108243, 0.9818305596244197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 118}], {
             RGBColor[
             0.7686070718350606, 0.8161034203947041, 0.8609842897621964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 126}], {
             RGBColor[
             0.7872217700794342, 0.8312156710120862, 0.86244970699588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 149}], {
             RGBColor[
             0.9417409016749079, 0.7933597413065041, 0.49749539466683224`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 199}], {
             RGBColor[
             0.7864153730446628, 0.8305610015714863, 0.8623862244673731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 212}], {
             RGBColor[
             0.9819133522973569, 0.9845586338579826, 0.8495382480085921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 238}], {
             RGBColor[
             0.7139757878947912, 0.7712510183506074, 0.856821739577265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 259}], {
             RGBColor[
             0.9412407024868812, 0.9530317196462317, 0.877013330786113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 274}], {
             RGBColor[
             0.9106572925983858, 0.9286453387656917, 0.8740962578488158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 299}], {
             RGBColor[
             0.7299039718743194, 0.7846825002917908, 0.8579374399591604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 318}], {
             RGBColor[
             0.7990420674942038, 0.8408119209517264, 0.8633802441075468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 336}], {
             RGBColor[
             0.8898353904052774, 0.9123122457924657, 0.8720386690727626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 367}], {
             RGBColor[
             0.9699412136932561, 0.9756298324896222, 0.8698039558314987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 18}], {
             RGBColor[
             0.5702729119397993, 0.6620122662714696, 0.9593131190878597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 69}], {
             RGBColor[
             0.7210055959104574, 0.7819606747275749, 0.9728360859815406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 74}], {
             RGBColor[
             0.4879397148803726, 0.5919418663638049, 0.9537236204237387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 88}], {
             RGBColor[
             0.5709543758817817, 0.6625655093991716, 0.9593667664256573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 132}], {
             RGBColor[
             0.8106150837372159, 0.8521194534252586, 0.9420300076356837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[
             0.8182865601911242, 0.8558749318333001, 0.8367406644680953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 191}], {
             RGBColor[
             0.8140717482558887, 0.8542848860971377, 0.9177042996427944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 198}], {
             RGBColor[
             0.8172916187655124, 0.8537468527279254, 0.7284474303569851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 216}], {
             RGBColor[
             0.7940624973769562, 0.8397745616201496, 0.9700492187376628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 224}], {
             RGBColor[
             0.6965217773578225, 0.7628337295903436, 0.970395767762507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 302}], {
             RGBColor[
             0.5103279858329195, 0.6113334613956843, 0.9551501812516643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 323}], {
             RGBColor[
             0.48509532556471124`, 0.5894781993017428, 0.9535423784517394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 340}], {
             RGBColor[
             0.7566945822007318, 0.8102609680587195, 0.9762818323066222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 357}], {
             RGBColor[
             0.6410472901851887, 0.7194700948804824, 0.9648847373984266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 38}], {
             RGBColor[
             0.6088792146827461, 0.41484919250312347`, 0.5668999821760634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 102}], {
             RGBColor[
             0.3557640427226805, 0.4825666654108456, 0.9438899481058665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 205}], {
             RGBColor[
             0.5395977163959482, 0.6340299757875949, 0.9581355834262311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 207}], {
             RGBColor[
             0.557695713784487, 0.648168268897396, 0.9599394226705193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.45412535256284214`, 0.5655887234702341, 0.9507580062054634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 224}], {
             RGBColor[
             0.563228598351486, 0.6524906003726157, 0.9604908888964118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 230}], {
             RGBColor[
             0.3103226295202427, 0.4373844139276082, 0.9412076767057528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 247}], {
             RGBColor[
             0.42505636459965096`, 0.5419892094987313, 0.9484695889897895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 250}], {
             RGBColor[
             0.5532708332786912, 0.6447115186159309, 0.9594983919345609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 289}], {
             RGBColor[
             0.4443600483937862, 0.5576608096238549, 0.9499892456897874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 340}], {
             RGBColor[
             0.6234014031943953, 0.6999178388409917, 0.966376953440527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 391}], {
             RGBColor[
             0.6296228148429417, 0.7048786236138223, 0.966970357237485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 45}], {
             RGBColor[
             0.9594357084040706, 0.968372870283703, 0.9149182129599932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 100}], {
             RGBColor[
             0.9223555200696435, 0.93880613462073, 0.9113814714947807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 105}], {
             RGBColor[
             0.7155445741739468, 0.7735920145486699, 0.8930224215878042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.7841184530473887, 0.8295606098551331, 0.8983386826557158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 155}], {
             RGBColor[
             0.9843156553444882, 0.9870712979009135, 0.8777609884126902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 170}], {
             RGBColor[
             0.9635163899613606, 0.8913742488475551, 0.5529306174122768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 180}], {
             RGBColor[
             0.9310420658787943, 0.9457325504589423, 0.9122100019886284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 183}], {
             RGBColor[
             0.9564240146427366, 0.9659714274286647, 0.9146309549204664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 239}], {
             RGBColor[
             0.7884509596614859, 0.8330779339016559, 0.8986797534468722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 271}], {
             RGBColor[
             0.8951712894250857, 0.9172785589302078, 0.9087492366528871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 273}], {
             RGBColor[
             0.8580814473129419, 0.8883036923789606, 0.9050524678154295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 326}], {
             RGBColor[
             0.797680375555476, 0.8405707895048449, 0.8994063268745114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 335}], {
             RGBColor[
             0.8316482802097532, 0.8676539013384388, 0.9024178567505745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 394}], {
             RGBColor[
             0.7597696886232224, 0.8097931859962576, 0.8964218587277825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 73}], {
             RGBColor[
             0.4509551699790699, 0.5636378853707001, 0.9503363400395856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 85}], {
             RGBColor[
             0.5773957891153074, 0.6645323790112565, 0.9614905884133689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 96}], {
             RGBColor[
             0.5958228454291754, 0.6789277354544652, 0.9633272251761034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 110}], {
             RGBColor[
             0.4841684272362966, 0.5906019038523052, 0.9529510093150446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 115}], {
             RGBColor[
             0.45401555426753715`, 0.5661224432048189, 0.9505772647013306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 184}], {
             RGBColor[
             0.5771495739739103, 0.6643400338714928, 0.9614660479890857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 188}], {
             RGBColor[
             0.6843252572780749, 0.7483798082326507, 0.9404163435338995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 203}], {
             RGBColor[
             0.5582133370759746, 0.6495469016860945, 0.9595786608642944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 206}], {
             RGBColor[
             0.6110458415767829, 0.6908547001663787, 0.9648353176006372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 208}], {
             RGBColor[
             0.695568556208126, 0.7552492622298325, 0.8535046487295386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 258}], {
             RGBColor[
             0.6964654338594248, 0.7554713019741051, 0.8278218073580214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 284}], {
             RGBColor[
             0.684133647825325, 0.7482369062165215, 0.9407406883576561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 325}], {
             RGBColor[
             0.6676037199898787, 0.7359089131021184, 0.968721544487416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 348}], {
             RGBColor[
             0.6963031896103653, 0.7551242779307765, 0.8101625221033297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 369}], {
             RGBColor[
             0.6957313002819596, 0.7539010644841975, 0.7479158979981967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 392}], {
             RGBColor[
             0.6216906761864707, 0.6993426023378058, 0.9658506314284654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 36}], {
             RGBColor[
             0.9646792003580276, 0.973178385976294, 0.944673080040644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 64}], {
             RGBColor[
             0.7051749401955701, 0.7667613528863614, 0.9464529859142854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 82}], {
             RGBColor[
             0.8270413713011133, 0.8652185012001103, 0.9564679236050952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 122}], {
             RGBColor[
             0.9627652897351686, 0.9717509945675069, 0.9479128314973078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 157}], {
             RGBColor[
             0.9545439624303799, 0.9656195421247834, 0.9618293941587412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 187}], {
             RGBColor[
             0.7396531511545399, 0.7949813833591695, 0.9491039454736359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 218}], {
             RGBColor[
             0.9747281677721213, 0.9657086045783765, 0.667817461782791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 253}], {
             RGBColor[
             0.8327991557181729, 0.8697165261474996, 0.9570418057462331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 262}], {
             RGBColor[
             0.7163146469658863, 0.7760341342711885, 0.9472666529321474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 298}], {
             RGBColor[
             0.8913935951028571, 0.5539469066564233, 0.5537777630150098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 74}], {
             RGBColor[
             0.4167442841232918, 0.5341422083576014, 0.9481188553170852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 132}], {
             RGBColor[
             0.7394196529801351, 0.7943197954190552, 0.9364252425290303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 140}], {
             RGBColor[
             0.7470911294340433, 0.7980752738270966, 0.8311358993614417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 191}], {
             RGBColor[
             0.7428763174988079, 0.7964852280909342, 0.912099534536141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.7460961880084316, 0.7959471947217219, 0.7228426652503317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 216}], {
             RGBColor[
             0.7228670666198754, 0.7819749036139462, 0.9644444536310094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.6253263466007417, 0.7050340715841401, 0.9647910026558535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 247}], {
             RGBColor[
             0.48715411284890675`, 0.5945326807102556, 0.9527697027492312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 302}], {
             RGBColor[
             0.4391325550758387, 0.5535338033894809, 0.9495454161450108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 311}], {
             RGBColor[
             0.7027214554362601, 0.6353448846979394, 0.5986129923525084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 323}], {
             RGBColor[
             0.41389989480763045`, 0.5316785412955394, 0.9479376133450859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 340}], {
             RGBColor[
             0.685499151443651, 0.752461310052516, 0.9706770671999687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 357}], {
             RGBColor[
             0.5698518594281078, 0.661670436874279, 0.9592799722917732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 83}], {
             RGBColor[
             0.5664527230504901, 0.6589108648335802, 0.9590123798246803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 108}], {
             RGBColor[
             0.543492393034507, 0.6401808603109822, 0.9572296634361378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 125}], {
             RGBColor[
             0.7516942927336122, 0.8062413449790911, 0.9758423393507925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 179}], {
             RGBColor[
             0.7001359125040344, 0.7655882581006512, 0.9708030718482545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 196}], {
             RGBColor[
             0.6489372429557332, 0.7255914683252178, 0.9657000669464495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 231}], {
             RGBColor[
             0.6892880803658612, 0.7571138491877325, 0.9697218613194765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 303}], {
             RGBColor[
             0.5915055885879954, 0.6792499096956578, 0.960984633171463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 313}], {
             RGBColor[
             0.5580947223936764, 0.65212546337674, 0.9583544073966107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 344}], {
             RGBColor[
             0.5759695715860311, 0.6666370712038732, 0.9597615810027629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 50}], {
             RGBColor[
             0.6835083190727078, 0.7521856198053053, 0.9694281836514949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 54}], {
             RGBColor[
             0.6798493689422905, 0.7493272201543724, 0.9690634936973279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 116}], {
             RGBColor[
             0.47169415952977667`, 0.5787249427665728, 0.9524524610707317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 121}], {
             RGBColor[
             0.7992132614167788, 0.8418753441093112, 0.9020389491238696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 130}], {
             RGBColor[
             0.7787251535043055, 0.8272971455498535, 0.9681479546896907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 135}], {
             RGBColor[
             0.734843211524763, 0.7926096446944292, 0.9744596310791078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 147}], {
             RGBColor[
             0.4756999297650586, 0.5821945396085079, 0.9527077052079604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 158}], {
             RGBColor[
             0.6556766576116428, 0.7304433143434599, 0.9666541837387197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 172}], {
             RGBColor[
             0.797632035003434, 0.8412214663517279, 0.9282439628757768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 181}], {
             RGBColor[
             0.5894601866853566, 0.67758936028679, 0.9608236116411333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 265}], {
             RGBColor[
             0.5967522119736537, 0.683509354917825, 0.9613976665833968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 322}], {
             RGBColor[
             0.7901172817431319, 0.802747243804977, 0.650634375369445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 328}], {
             RGBColor[
             0.6781689473579442, 0.748014462041004, 0.9688960049782328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 347}], {
             RGBColor[
             0.700766589429674, 0.7656679117758801, 0.9711483267529712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 362}], {
             RGBColor[
             0.6387636008927278, 0.7172307058906515, 0.9649684483064794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 364}], {
             RGBColor[
             0.6366293898465288, 0.7155634440007561, 0.9647557300947305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 387}], {
             RGBColor[
             0.6097518586602133, 0.6940630537253837, 0.9624210463898376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.682860616320035, 0.7475287631096325, 0.9464169646747609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 60}], {
             RGBColor[
             0.6122321622672507, 0.6919385247018452, 0.9648849940633403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 64}], {
             RGBColor[
             0.4233563561575777, 0.5411117300196998, 0.9481968705484022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 82}], {
             RGBColor[
             0.5452227872631209, 0.6395688783334488, 0.958211808239212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 122}], {
             RGBColor[
             0.6809467056971763, 0.7461013717008453, 0.9496567161314245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 159}], {
             RGBColor[
             0.6184639868506858, 0.6969076124663044, 0.9654793910553238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 182}], {
             RGBColor[
             0.4146156543784303, 0.5335409734590475, 0.947639920760134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 210}], {
             RGBColor[
             0.5229583573228828, 0.6221757364481999, 0.9559926979356963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 263}], {
             RGBColor[
             0.6690195196149276, 0.737206095849679, 0.9698463310603314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 29}], {
             RGBColor[
             0.41909849668638843`, 0.5358853093982165, 0.9483506492189386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 45}], {
             RGBColor[
             0.6291857733714252, 0.7029254395127557, 0.967667402968969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 91}], {
             RGBColor[
             0.637014621119578, 0.7089071852709876, 0.95937324171526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 97}], {
             RGBColor[
             0.6415610532555065, 0.7122979069138635, 0.951677318008543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 100}], {
             RGBColor[
             0.5921055850369981, 0.6733587038497827, 0.9641306615037565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 141}], {
             RGBColor[
             0.5695397929870957, 0.6554390874908386, 0.9619587494592156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 150}], {
             RGBColor[
             0.546723753160279, 0.6376150237698042, 0.9596846598372932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 189}], {
             RGBColor[
             0.5978127471211885, 0.6779094399789282, 0.9646750157181903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 190}], {
             RGBColor[
             0.5612992408529204, 0.649001505533105, 0.961137408234819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 255}], {
             RGBColor[
             0.47607352842348083`, 0.5821402068583181, 0.9528359324237006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 266}], {
             RGBColor[
             0.61997155733309, 0.6955782737570185, 0.9667885428176048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 273}], {
             RGBColor[
             0.5278315122802966, 0.6228562616080132, 0.9578016578244053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 350}], {
             RGBColor[
             0.32087951082955535`, 0.4523514372325744, 0.9416671365808169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 365}], {
             RGBColor[
             0.49055240283458246`, 0.5937335379772959, 0.9540860245879412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 394}], {
             RGBColor[
             0.4295197535905769, 0.5443457552253103, 0.9491710487367583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[
             0.8344432709162487, 0.8710009214359749, 0.9572056757840472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 89}], {
             RGBColor[
             0.8901458039182115, 0.9145161635720388, 0.9627575837039164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 163}], {
             RGBColor[
             0.9781387974836, 0.9772134594491326, 0.6810671141685078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 164}], {
             RGBColor[
             0.9801995912463775, 0.9826665216535752, 0.816492751321456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 169}], {
             RGBColor[
             0.8784955402167907, 0.9054148890232052, 0.961596394296063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 227}], {
             RGBColor[
             0.7974884299759106, 0.8419346681559776, 0.9536569504800612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 245}], {
             RGBColor[
             0.7289108550643819, 0.7862603034582553, 0.9482582725750914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 292}], {
             RGBColor[
             0.9131608739543846, 0.932826044625336, 0.9649638504642108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 304}], {
             RGBColor[
             0.6536034373176627, 0.7220927091526201, 0.9431668953537945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 353}], {
             RGBColor[
             0.8177291079985893, 0.8579436903323562, 0.9555397642271479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 378}], {
             RGBColor[
             0.9525390914175197, 0.9641243126060672, 0.965223117829408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 25}], {
             RGBColor[
             0.5484328692807651, 0.6442815357581559, 0.9575937909270282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 76}], {
             RGBColor[
             0.7375812127389303, 0.7947858946432436, 0.9747287924924868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 104}], {
             RGBColor[
             0.5687380041760434, 0.6607661590020457, 0.9591922855261444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 109}], {
             RGBColor[
             0.701714570216897, 0.7663937517900193, 0.9712528834506935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 138}], {
             RGBColor[
             0.6510943769656253, 0.7268488720944081, 0.9662075356600079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 144}], {
             RGBColor[
             0.7971063950795585, 0.8408125979414558, 0.9289496086408371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 207}], {
             RGBColor[
             0.6747790887305888, 0.745351548935674, 0.968568206382524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 233}], {
             RGBColor[
             0.6873886217013339, 0.7552022119284202, 0.9698250067862626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 242}], {
             RGBColor[
             0.8006449799347068, 0.8422758937165424, 0.8703061000269761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 317}], {
             RGBColor[
             0.7198554901771368, 0.4650906300075065, 0.5696806005561273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 358}], {
             RGBColor[
             0.8001563375301665, 0.8420738275247279, 0.8784041692362178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 366}], {
             RGBColor[
             0.7952039216563204, 0.8395552301263439, 0.9394020199297599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 382}], {
             RGBColor[
             0.7615683126734435, 0.8139125570185421, 0.9770167034977777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[
             0.6769653474432848, 0.7455752044826262, 0.9699568895331828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 104}], {
             RGBColor[
             0.508122138880398, 0.6115554688414282, 0.9544203825668405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 109}], {
             RGBColor[
             0.6410987049212516, 0.7171830616294019, 0.9664809804913895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 138}], {
             RGBColor[
             0.59047851166998, 0.6776381819337907, 0.961435632700704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 144}], {
             RGBColor[
             0.7364905297839132, 0.7916019077808384, 0.924177705681533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 205}], {
             RGBColor[
             0.5960652260464047, 0.6820025656652555, 0.9619924641789319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 207}], {
             RGBColor[
             0.6141632234349435, 0.6961408587750566, 0.96379630342322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 233}], {
             RGBColor[
             0.6267727564056885, 0.7059915217678028, 0.9650531038269586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 317}], {
             RGBColor[
             0.6592396248814915, 0.41587993984688904`, 0.5649086975968234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 358}], {
             RGBColor[
             0.7395404722345211, 0.7928631373641105, 0.8736322662769138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 366}], {
             RGBColor[
             0.734588056360675, 0.7903445399657265, 0.9346301169704558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 382}], {
             RGBColor[
             0.7009524473777982, 0.7647018668579246, 0.9722448005384736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 391}], {
             RGBColor[
             0.686090324493398, 0.7528512134914827, 0.9708272379901859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 30}], {
             RGBColor[
             0.8662963780037599, 0.8960700989038873, 0.9697597500461528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 62}], {
             RGBColor[
             0.7705614713835087, 0.8206877450196675, 0.977766024227297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 77}], {
             RGBColor[
             0.8838016558078132, 0.908158390039574, 0.8968184330282316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 106}], {
             RGBColor[
             0.820068271282544, 0.8597068498244942, 0.9826091079834451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 111}], {
             RGBColor[
             0.8601626121254744, 0.8914955463549818, 0.9801426157357356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 160}], {
             RGBColor[
             0.8702877925894468, 0.8564910401089483, 0.6445863192572019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.7736237993730068, 0.8230800589196181, 0.978071248462208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 173}], {
             RGBColor[
             0.8348949822409488, 0.8715292666823786, 0.9840232929106189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 185}], {
             RGBColor[
             0.6616206824151077, 0.7341009336864008, 0.9679206924348331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 197}], {
             RGBColor[
             0.8000694446799812, 0.8437603283452974, 0.9807016020489294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 204}], {
             RGBColor[
             0.8577590867538296, 0.8897030010682208, 0.9842111572501157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 345}], {
             RGBColor[
             0.8817829560792112, 0.8952669257526641, 0.6892428587354597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 370}], {
             RGBColor[
             0.6436621544946893, 0.719521391698142, 0.9665069313326826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 389}], {
             RGBColor[
             0.6045809441957373, 0.6872030442278201, 0.9635934612558283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 400}], {
             RGBColor[
             0.7593397834422309, 0.811921277111954, 0.9766475512459465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 51}], {
             RGBColor[
             0.8849868377172869, 0.9109206317107172, 0.9816851621381832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[
             0.9396232970294633, 0.954486261299067, 0.9868964364019217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 277}], {
             RGBColor[
             0.9584950110291953, 0.9685662277005316, 0.9551412994794604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 287}], {
             RGBColor[
             0.684890109824644, 0.7504979678282429, 0.9642253682440607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 376}], {
             RGBColor[
             0.8856691149130873, 0.9114646610267273, 0.9817502383461947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 377}], {
             RGBColor[
             0.966860083710757, 0.9738465549152377, 0.8980654248118275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 395}], {
             RGBColor[
             0.9206329503508108, 0.9393438743367379, 0.9850851201828291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 396}], {
             RGBColor[
             0.9348735685072654, 0.9506989567034125, 0.9864434030553417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 44}], {
             RGBColor[
             0.7148148509619656, 0.525946186950292, 0.5775869850093527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 47}], {
             RGBColor[
             0.7366112711750741, 0.7938028142924503, 0.9748776109974654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 49}], {
             RGBColor[
             0.5436528814010338, 0.6404009262613902, 0.9572174927714632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 147}], {
             RGBColor[
             0.46073100535896033`, 0.5700420924332775, 0.9515292966457355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 211}], {
             RGBColor[
             0.7515839441069692, 0.8057416172659637, 0.9763057179079724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 301}], {
             RGBColor[
             0.7222052279582378, 0.7823158264729709, 0.9735035497350168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 328}], {
             RGBColor[
             0.663200022951846, 0.7358620148657736, 0.9677175964160079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 347}], {
             RGBColor[
             0.6857976650235758, 0.7535154646006498, 0.9699699181907463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 362}], {
             RGBColor[
             0.6237946764866296, 0.7050782587154212, 0.9637900397442545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 372}], {
             RGBColor[
             0.7843951928665163, 0.8297852797072875, 0.8983604686280089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 380}], {
             RGBColor[
             0.7867109018720941, 0.8290756256612928, 0.738791031946236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 390}], {
             RGBColor[
             0.7825836365233578, 0.8290361546045171, 0.9283826453916786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 45}], {
             RGBColor[
             0.7200661942093562, 0.7801030155060276, 0.9738833087333245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 91}], {
             RGBColor[
             0.7278950419575092, 0.7860847612642594, 0.9655891474796154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 150}], {
             RGBColor[
             0.6376041739982101, 0.7147925997630761, 0.9659005656016487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 190}], {
             RGBColor[
             0.6521796616908515, 0.7261790815263769, 0.9673533139991746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 226}], {
             RGBColor[
             0.5181234588071078, 0.6196749909122594, 0.9552077231075131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 266}], {
             RGBColor[
             0.7108519781710211, 0.7727558497502904, 0.9730044485819604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 273}], {
             RGBColor[
             0.6187119331182277, 0.7000338376012851, 0.9640175635887609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 365}], {
             RGBColor[
             0.5814328236725137, 0.6709111139705677, 0.9603019303522968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 62}], {
             RGBColor[
             0.8592677592780328, 0.8905792885358685, 0.9690592030177487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 77}], {
             RGBColor[
             0.9725079437023374, 0.9780499335557749, 0.8881116118186833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 84}], {
             RGBColor[
             0.7409947095034408, 0.7964161274665775, 0.9584792014694238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 204}], {
             RGBColor[
             0.9464653746483538, 0.9595945445844218, 0.9755043360405673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 333}], {
             RGBColor[
             0.9738664663986155, 0.9764103716683639, 0.7055827641291339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 370}], {
             RGBColor[
             0.7323684423892134, 0.7894129352143429, 0.9578001101231342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 389}], {
             RGBColor[
             0.6932872320902614, 0.757094587744021, 0.9548866400462799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 400}], {
             RGBColor[
             0.8480460713367549, 0.881812820628155, 0.9679407300363982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 33}], {
             RGBColor[
             0.7833279224340963, 0.8314943638544479, 0.978817313919399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 106}], {
             RGBColor[
             0.892818401397303, 0.9173731746370509, 0.9896390102253125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 156}], {
             RGBColor[
             0.8525548283996686, 0.8855749489387249, 0.9857172049438296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 173}], {
             RGBColor[
             0.9076451123557078, 0.9291955914949354, 0.9910531951524862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 175}], {
             RGBColor[
             0.7639029719915531, 0.8157427959585771, 0.9772754744493892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 197}], {
             RGBColor[
             0.8728195747947403, 0.9014266531578541, 0.9877315042907968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 204}], {
             RGBColor[
             0.9305092168685887, 0.9473693258807776, 0.991241059491983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 214}], {
             RGBColor[
             0.9429703143684738, 0.9566627919930173, 0.9701476717994177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 261}], {
             RGBColor[
             0.8525548283996686, 0.8855749489387249, 0.9857172049438296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 295}], {
             RGBColor[
             0.8756734987736113, 0.9037022946709032, 0.9880037141076294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 310}], {
             RGBColor[
             0.7498332463456457, 0.8043203588453123, 0.9761678541074401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 345}], {
             RGBColor[
             0.9545330861939701, 0.9529332505652208, 0.696272760977327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 43}], {
             RGBColor[
             0.5346247257324952, 0.6310123102737082, 0.9572728513283799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 124}], {
             RGBColor[
             0.6152449300833687, 0.6980386863611746, 0.9631843194703695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 137}], {
             RGBColor[
             0.8089570217193354, 0.8514715421644536, 0.973935014350912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 199}], {
             RGBColor[
             0.6268599801935458, 0.7074683072926611, 0.9640986987623732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 238}], {
             RGBColor[
             0.5544203950436742, 0.6481583240717822, 0.9585342138722651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 252}], {
             RGBColor[
             0.8088534915215897, 0.8513943295124902, 0.9741102639706954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 293}], {
             RGBColor[
             0.7562608199803481, 0.5213589485630012, 0.5763543454068359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 330}], {
             RGBColor[
             0.8251295794386782, 0.8635330092314066, 0.9465590926106615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 63}], {
             RGBColor[
             0.7392580958795311, 0.7963542804034118, 0.9746138945210259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 84}], {
             RGBColor[
             0.5852761238190183, 0.6741740676045813, 0.9605068631008026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 90}], {
             RGBColor[
             0.5115563406919951, 0.6123219760891934, 0.9552568205593513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 152}], {
             RGBColor[
             0.7703167999088556, 0.8211196479303333, 0.9775763014377753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 156}], {
             RGBColor[
             0.7127924004950111, 0.7755581077803728, 0.9720081431237927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 173}], {
             RGBColor[
             0.7678826844510503, 0.8191787503365833, 0.9773441333324493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 175}], {
             RGBColor[
             0.6241405440868957, 0.705725954800225, 0.9635664126293522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 204}], {
             RGBColor[
             0.7907467889639312, 0.8373524847224255, 0.9775319976719461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 214}], {
             RGBColor[
             0.8032078864638164, 0.8466459508346653, 0.9564386099793808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 256}], {
             RGBColor[
             0.45933391161246484`, 0.563978945511546, 0.9520431473949609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 261}], {
             RGBColor[
             0.7127924004950111, 0.7755581077803728, 0.9720081431237927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 264}], {
             RGBColor[
             0.6163494359700578, 0.6994007822455552, 0.9629530680586253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 295}], {
             RGBColor[
             0.7359110708689539, 0.7936854535125513, 0.9742946522875926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 310}], {
             RGBColor[
             0.6100708184409883, 0.6943035176869603, 0.9624587922874032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 333}], {
             RGBColor[
             0.818147880714193, 0.8541683118063677, 0.7076104257605127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 381}], {
             RGBColor[
             0.81812731914316, 0.8563611550031001, 0.8679657950723527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 53}], {
             RGBColor[
             0.9595823077094718, 0.8832336852026013, 0.5862542004558515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 68}], {
             RGBColor[
             0.6452236740890446, 0.6306000714121618, 0.6050826988937232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 86}], {
             RGBColor[
             0.8631999441080545, 0.807922306962626, 0.6230756738378621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 95}], {
             RGBColor[
             0.766077627213511, 0.7313625691668142, 0.6138651658337634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 151}], {
             RGBColor[
             0.9201851474742702, 0.85313258529861, 0.6285715243024724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 244}], {
             RGBColor[
             0.9641059679139163, 0.883623640211034, 0.4036545675033498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 249}], {
             RGBColor[
             0.7301624761731151, 0.7022050315931045, 0.6110377935823302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 253}], {
             RGBColor[
             0.8173882166308981, 0.772133837275447, 0.6185095889778729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 270}], {
             RGBColor[
             0.9150692138381826, 0.849053278685513, 0.6280835619852145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 308}], {
             RGBColor[
             0.9638525987006723, 0.883081709083462, 0.37607689225526547`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 386}], {
             RGBColor[
             0.8861591913650742, 0.826001211507111, 0.6253260982334476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 397}], {
             RGBColor[
             0.7338617167846391, 0.7052082417704302, 0.6113290113540343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 41}], {
             RGBColor[
             0.5116819543897699, 0.6140346655164935, 0.9548141356052257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 57}], {
             RGBColor[
             0.591541217772968, 0.6792788350730949, 0.9609874380314181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 92}], {
             RGBColor[
             0.7224261495918998, 0.7825289144350656, 0.9734821144785564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 114}], {
             RGBColor[
             0.6411526637328919, 0.7187166328346928, 0.9654666678522005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 153}], {
             RGBColor[
             0.7066842562912862, 0.7699767560194667, 0.9719806386425898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 188}], {
             RGBColor[
             0.7780026391234078, 0.8259381897066814, 0.9473746195101558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 195}], {
             RGBColor[
             0.6302214995886758, 0.7101771243253067, 0.9643771515678419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 208}], {
             RGBColor[
             0.7892459380534589, 0.8328076437038632, 0.8604629247057949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 258}], {
             RGBColor[
             0.7901428157047579, 0.8330296834481359, 0.8347800833342777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 278}], {
             RGBColor[
             0.5430731825105766, 0.6399303005869796, 0.9571718567512995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 284}], {
             RGBColor[
             0.777811029670658, 0.8257952876905522, 0.9476989643339124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 327}], {
             RGBColor[
             0.5578995609664129, 0.6519670225381654, 0.9583390435741567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 337}], {
             RGBColor[
             0.6718755217449016, 0.7427175630160439, 0.968528835217406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 354}], {
             RGBColor[
             0.5552536480080973, 0.6498189512015844, 0.9581307476137795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 369}], {
             RGBColor[
             0.7894086821272925, 0.8314594459582282, 0.754874173974453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 392}], {
             RGBColor[
             0.7153680580318037, 0.7769009838118365, 0.9728089074047217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 55}], {
             RGBColor[
             0.9790004842802413, 0.982211309996965, 0.8466360721187083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 60}], {
             RGBColor[
             0.8932617564575563, 0.9169997202319543, 0.9644766634398478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 64}], {
             RGBColor[
             0.7043859503478833, 0.7661729255498089, 0.9477885399249097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 82}], {
             RGBColor[
             0.8262523814534265, 0.8646300738635578, 0.9578034776157196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 122}], {
             RGBColor[
             0.9619762998874819, 0.9711625672309544, 0.9492483855079321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 157}], {
             RGBColor[
             0.953754972582693, 0.9650311147882309, 0.9631649481693656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 165}], {
             RGBColor[
             0.6846203936277558, 0.7490529937646009, 0.9465290961286988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 218}], {
             RGBColor[
             0.9739391779244346, 0.965120177241824, 0.6691530157934155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 262}], {
             RGBColor[
             0.7155256571181996, 0.7754457069346359, 0.9486022069427718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 298}], {
             RGBColor[
             0.8906046052551704, 0.5533584793198707, 0.5551133170256342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 314}], {
             RGBColor[
             0.7563936658522412, 0.8086241975077435, 0.9518194862947642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 58}], {
             RGBColor[
             0.7637492245822919, 0.81565623685631, 0.9772193343654505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 87}], {
             RGBColor[
             0.8899201051582935, 0.9150621518882204, 0.9893625681426961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 110}], {
             RGBColor[
             0.744159213465518, 0.7997521833117693, 0.9756771369297629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 134}], {
             RGBColor[
             0.9442257949280697, 0.9574627804494962, 0.9632952384526492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 159}], {
             RGBColor[
             0.876449962552587, 0.9043214258117106, 0.9880777739160256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 167}], {
             RGBColor[
             0.7862700431121541, 0.8337500349907556, 0.9791218978063168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 201}], {
             RGBColor[
             0.8003671582447182, 0.8447628084743579, 0.9805269664976999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 236}], {
             RGBColor[
             0.8844716030216788, 0.9107176641801344, 0.9888428851449707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 243}], {
             RGBColor[
             0.8501890278831504, 0.8836840316961349, 0.9854927448514159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 263}], {
             RGBColor[
             0.9270054953168285, 0.9446199091950852, 0.9924447139210331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 348}], {
             RGBColor[
             0.9562939758395868, 0.9642745573902407, 0.8328886497180481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 351}], {
             RGBColor[
             0.6297708289815714, 0.7038568996313648, 0.9675091628486132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 78}], {
             RGBColor[
             0.7919829607282556, 0.5641183590001255, 0.581760184562998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 102}], {
             RGBColor[
             0.5897612727212197, 0.39829019207175154`, 0.5656818038196072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 205}], {
             RGBColor[
             0.7735949463944874, 0.549753502448501, 0.5799274391399718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 207}], {
             RGBColor[
             0.7916929437830262, 0.563891795558302, 0.58173127838426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 213}], {
             RGBColor[
             0.6881225825613814, 0.4813122501311401, 0.5725498619192041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 221}], {
             RGBColor[
             0.9166812603951346, 0.6550710806416911, 0.3031162347186621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 224}], {
             RGBColor[
             0.7972258283500251, 0.5682141270335217, 0.5822827446101525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 230}], {
             RGBColor[
             0.5443198595187819, 0.35310794058851414`, 0.5629995324194935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 247}], {
             RGBColor[
             0.6590535945981901, 0.4577127361596372, 0.5702614447035302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 250}], {
             RGBColor[
             0.7872680632772304, 0.5604350452768369, 0.5812902476483016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 289}], {
             RGBColor[
             0.6783572783923253, 0.4733843362847609, 0.5717811014035281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 358}], {
             RGBColor[
             0.9170701925826039, 0.660614074147356, 0.4915672412379537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 391}], {
             RGBColor[
             0.8636200448414808, 0.6206021502747281, 0.5887622129512258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 93}], {
             RGBColor[
             0.8669078728278314, 0.8967128224783161, 0.9871676408797544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 94}], {
             RGBColor[
             0.6433347325710053, 0.7183608480359901, 0.9671048994040337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 119}], {
             RGBColor[
             0.7367446753914995, 0.7943125622582803, 0.9744260579093501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 128}], {
             RGBColor[
             0.801937625842792, 0.8453420014414248, 0.9808553672723344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 177}], {
             RGBColor[
             0.6731624503146796, 0.7426936475943201, 0.9694206322419381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 200}], {
             RGBColor[
             0.5082995353494917, 0.5893974937227403, 0.9589400519867981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 225}], {
             RGBColor[
             0.8897946602016316, 0.9148017739467416, 0.9837911146017579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 288}], {
             RGBColor[
             0.7529493840516824, 0.8070720146297826, 0.9759726771517443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 296}], {
             RGBColor[
             0.6319477932253896, 0.7084980534990305, 0.9663793336980062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 316}], {
             RGBColor[
             0.9146848516476405, 0.9321178797050046, 0.8858171739492178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 324}], {
             RGBColor[
             0.687731890043449, 0.7545217751119153, 0.9705675919070031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 355}], {
             RGBColor[
             0.7951154221810486, 0.8400124440902026, 0.9801753937684498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 360}], {
             RGBColor[
             0.8991830196476797, 0.9218035970495766, 0.967899070935903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 374}], {
             RGBColor[
             0.9112966792812487, 0.9307167833594434, 0.9419679583693381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 375}], {
             RGBColor[
             0.7226989399810355, 0.7829096014988962, 0.9733203261666143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 380}], {
             RGBColor[
             0.9155107173119436, 0.9307921371501653, 0.7509382970233409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 383}], {
             RGBColor[
             0.7071241065257605, 0.7702652500616527, 0.9720942182245202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 390}], {
             RGBColor[
             0.9113834519632072, 0.9307526660933896, 0.9405299104687835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 41}], {
             RGBColor[
             0.6319918096980395, 0.7089445822021023, 0.966194127665002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 55}], {
             RGBColor[
             0.9099533167162179, 0.9278819465124375, 0.8652549260242168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 58}], {
             RGBColor[
             0.7177456755066729, 0.7789742555564853, 0.9728314747867648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.8130907288856415, 0.8539588994397369, 0.9819924773762227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 87}], {
             RGBColor[
             0.8439165560826745, 0.8783801705883957, 0.9849747085640105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 96}], {
             RGBColor[
             0.809810082582778, 0.8513960336141047, 0.981665493212136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 110}], {
             RGBColor[
             0.6981556643898992, 0.7630702020119446, 0.9712892773510773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 146}], {
             RGBColor[
             0.5577512314579793, 0.6428808010000475, 0.9615280377443072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 154}], {
             RGBColor[
             0.6785389499995498, 0.7471444695469466, 0.9697449777358764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 159}], {
             RGBColor[
             0.830446413476968, 0.8676394445118859, 0.9836899143373399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 167}], {
             RGBColor[
             0.7402664940365351, 0.7970680536909309, 0.9747340382276312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 192}], {
             RGBColor[
             0.9069923955566828, 0.9266575295207669, 0.9143250522560455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 203}], {
             RGBColor[
             0.7722005742295772, 0.8220151998457339, 0.9779169289003271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 228}], {
             RGBColor[
             0.6991503523622113, 0.7638777345180501, 0.9713675828319197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 243}], {
             RGBColor[
             0.8041854788075316, 0.8470020503963102, 0.9811048852727302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 332}], {
             RGBColor[
             0.7294292442259906, 0.7884595029816, 0.973751248114672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 348}], {
             RGBColor[
             0.9102904267639678, 0.927592576090416, 0.8285007901393624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 361}], {
             RGBColor[
             0.90639908114084, 0.9264121787623307, 0.9241578075750485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 385}], {
             RGBColor[
             0.6841197058381644, 0.7516751785469193, 0.9701843152784744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 57}], {
             RGBColor[
             0.5180470073969832, 0.6192021022901195, 0.9553152158939109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.648931939215915, 0.7224521816520901, 0.9678098923410492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 96}], {
             RGBColor[
             0.6160060168985236, 0.6964093841455206, 0.9646132790148525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 114}], {
             RGBColor[
             0.5676584533569071, 0.6586399000517174, 0.9597944457146933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 153}], {
             RGBColor[
             0.6331900459153014, 0.7099000232364913, 0.9663084165050826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 154}], {
             RGBColor[
             0.4847348843152955, 0.5921578200783624, 0.9526927635385929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 188}], {
             RGBColor[
             0.704508428747423, 0.765861456923706, 0.9417023973726486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 203}], {
             RGBColor[
             0.5783965085453229, 0.6670285503771498, 0.9608647147030436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 222}], {
             RGBColor[
             0.48729272023569203`, 0.5942343865077354, 0.9528941257519081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 258}], {
             RGBColor[
             0.7166486053287731, 0.7729529506651605, 0.8291078611967705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 312}], {
             RGBColor[
             0.5452353436969977, 0.6411227963634507, 0.9575595196996671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 327}], {
             RGBColor[
             0.4844053505904281, 0.59189028975519, 0.9526668214366495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 356}], {
             RGBColor[
             0.5927158565011421, 0.6782149338313112, 0.9622919334853649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 361}], {
             RGBColor[
             0.7125950154565857, 0.7714255292937466, 0.907105593377765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 369}], {
             RGBColor[
             0.7159144717513077, 0.7713827131752528, 0.7492019518369458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 104}], {
             RGBColor[
             0.4625187820542941, 0.5729928620920239, 0.9512557560253143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 109}], {
             RGBColor[
             0.5954953480951477, 0.6786204548799974, 0.9633163539498635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 136}], {
             RGBColor[
             0.681657846251029, 0.7463175780340775, 0.9438679418885805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 205}], {
             RGBColor[
             0.5504618692203007, 0.643439958915851, 0.9588278376374058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 207}], {
             RGBColor[
             0.5685598666088395, 0.6575782520256521, 0.9606316768816939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 221}], {
             RGBColor[
             0.693548183220948, 0.7487575371090414, 0.6820166332160961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 276}], {
             RGBColor[
             0.6868235663604292, 0.7501701636335778, 0.9351237251789477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 358}], {
             RGBColor[
             0.6939371154084173, 0.7543005306147061, 0.8704676397353877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 366}], {
             RGBColor[
             0.6889846995345712, 0.751781933216322, 0.9314654904289298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 376}], {
             RGBColor[
             0.6120943447009879, 0.6916490998859651, 0.9649544977237396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 124}], {
             RGBColor[
             0.47592250352979504`, 0.5838390919901567, 0.9523207589869406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 137}], {
             RGBColor[
             0.6696345951657618, 0.7372719477934357, 0.963071453867483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 199}], {
             RGBColor[
             0.4875375536399723, 0.5932687129216432, 0.9532351382789441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 238}], {
             RGBColor[
             0.4150979684901007, 0.5339587297007643, 0.9476706533888362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 252}], {
             RGBColor[
             0.6695310649680162, 0.7371947351414723, 0.9632467034872665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 277}], {
             RGBColor[
             0.6842662452401009, 0.7481842084617497, 0.9383038868371447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 293}], {
             RGBColor[
             0.6169383934267746, 0.4071593541919834, 0.565490784923407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 299}], {
             RGBColor[
             0.43102615246962894`, 0.5473902116419476, 0.9487863537707315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 330}], {
             RGBColor[
             0.6858071528851046, 0.7493334148603887, 0.9356955321272326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 367}], {
             RGBColor[
             0.6710633942885655, 0.738337543839779, 0.9606528696430698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 47}], {
             RGBColor[
             0.8713536823177553, 0.6497810367750068, 0.5923800221874319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 49}], {
             RGBColor[
             0.6783952925437151, 0.4963791487439466, 0.5747199039614297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 54}], {
             RGBColor[
             0.7996228556788735, 0.5931529954616984, 0.5853874963250695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 93}], {
             RGBColor[
             0.8728504685306633, 0.6509745334720001, 0.5925227869926158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[
             0.8078802215456238, 0.5996037124351088, 0.5862105133851959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 211}], {
             RGBColor[
             0.8863263552496504, 0.66171983974852, 0.5938081290979389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 301}], {
             RGBColor[
             0.856947639100919, 0.6382940489555273, 0.5910059609249834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 316}], {
             RGBColor[
             0.9206274473504722, 0.6863795906986885, 0.49117232006207934`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 324}], {
             RGBColor[
             0.6936744857462808, 0.5087834861055992, 0.5759227380198646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 328}], {
             RGBColor[
             0.7979424340945271, 0.59184023734833, 0.5852200076059744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 362}], {
             RGBColor[
             0.7585370876293107, 0.5610564811979776, 0.581292450934221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 372}], {
             RGBColor[
             0.9191376040091974, 0.685763502189844, 0.5158628798179753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 380}], {
             RGBColor[
             0.9214533130147753, 0.6850538481438493, 0.3562934431362025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 383}], {
             RGBColor[
             0.7130667022285924, 0.5245269610553367, 0.5774493643373817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 390}], {
             RGBColor[
             0.917326047666039, 0.6850143770870734, 0.545885056581645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 91}], {
             RGBColor[
             0.9379823186425459, 0.9531248913787984, 0.9849059012296458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 97}], {
             RGBColor[
             0.9425287507784743, 0.9565156130216745, 0.9772099775229289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 100}], {
             RGBColor[
             0.893073282559966, 0.9175764099575936, 0.9896633210181424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 112}], {
             RGBColor[
             0.7548362155377112, 0.8083308851919966, 0.9766205321790775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 141}], {
             RGBColor[
             0.8705074905100636, 0.8996567935986495, 0.9874914089736014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 180}], {
             RGBColor[
             0.9017598283691168, 0.9245028257958059, 0.9904918515119902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 190}], {
             RGBColor[
             0.8622669383758883, 0.8932192116409159, 0.9866700677492048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 266}], {
             RGBColor[
             0.9209392548560578, 0.9397959798648294, 0.9923212023319907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 271}], {
             RGBColor[
             0.8658890519154082, 0.8960488342670714, 0.9870310861762488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 273}], {
             RGBColor[
             0.8287992098032644, 0.8670739677158241, 0.9833343173387912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 350}], {
             RGBColor[
             0.6218472083525233, 0.6965691433403853, 0.9671997960952028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 365}], {
             RGBColor[
             0.7915201003575504, 0.8379512440851068, 0.9796186841023271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 394}], {
             RGBColor[
             0.7304874511135449, 0.7885634613331212, 0.9747037082511442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 59}], {
             RGBColor[
             0.9604261337318531, 0.9692581760562311, 0.9191625514381196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 287}], {
             RGBColor[
             0.6793263280187474, 0.7462694258710767, 0.9709015563205774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 373}], {
             RGBColor[
             0.6550306371538173, 0.7252257195808032, 0.9693534563824999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 395}], {
             RGBColor[
             0.9150691685449142, 0.9351153323795718, 0.9917613082593459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 54}], {
             RGBColor[
             0.8214192758919819, 0.8610096228038566, 0.9826781223131822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 121}], {
             RGBColor[
             0.9407831683664702, 0.9535577467587955, 0.915653577739724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 128}], {
             RGBColor[
             0.8296766417587322, 0.867460339777267, 0.9835011393733086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 130}], {
             RGBColor[
             0.9202950604539969, 0.9389795481993377, 0.981762583305545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.7972465645613342, 0.8421257169929441, 0.980268812354574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 181}], {
             RGBColor[
             0.731030093635048, 0.7892717629362742, 0.9744382402569876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 265}], {
             RGBColor[
             0.7383221189233451, 0.7951917575673094, 0.975012295199251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 311}], {
             RGBColor[
             0.8997577661103328, 0.7920574126238888, 0.6165941394496777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 322}], {
             RGBColor[
             0.9316871886928233, 0.9144296464544612, 0.6642490039852993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 362}], {
             RGBColor[
             0.7803335078424192, 0.8289131085401358, 0.9785830769223338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 56}], {
             RGBColor[
             0.7935515433749436, 0.8391334488048379, 0.9799285739326521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 71}], {
             RGBColor[
             0.7167940438862651, 0.7778089166236486, 0.9732086201574128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 83}], {
             RGBColor[
             0.6880031537519352, 0.7544351749977798, 0.9709420958215327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 103}], {
             RGBColor[
             0.901179924188946, 0.9240404259436172, 0.9904365397335988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 108}], {
             RGBColor[
             0.6650428237359522, 0.7357051704751818, 0.9691593794329902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 120}], {
             RGBColor[
             0.8818012323206808, 0.9085883830684403, 0.9885881828036412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 143}], {
             RGBColor[
             0.7775110926539824, 0.8266025267896822, 0.9783298117113213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 196}], {
             RGBColor[
             0.7704876736571782, 0.8211157784894174, 0.9776297829433019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 231}], {
             RGBColor[
             0.8108385110673063, 0.8526381593519321, 0.9816515773163288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 234}], {
             RGBColor[
             0.6055623021161005, 0.6841861322260088, 0.9653693331919333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 286}], {
             RGBColor[
             0.8312016813065461, 0.8685460227086522, 0.9836811878211311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 290}], {
             RGBColor[
             0.5791581235686378, 0.6584958827734088, 0.9637901464435579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 313}], {
             RGBColor[
             0.6796451530951215, 0.7476497735409396, 0.9702841233934631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 320}], {
             RGBColor[
             0.6458221287345487, 0.7190571705251863, 0.967934653743694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 331}], {
             RGBColor[
             0.7212122848660683, 0.7813958436905408, 0.9735564402718928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 342}], {
             RGBColor[
             0.8882621925854053, 0.9137401774054373, 0.989204434961458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 343}], {
             RGBColor[
             0.9366749910007026, 0.9476187562970801, 0.7489687985047893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 344}], {
             RGBColor[
             0.6975200022874762, 0.7621613813680728, 0.9716912969996154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 349}], {
             RGBColor[
             0.6551242705708414, 0.7271142182445401, 0.9685273779959416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 147}], {
             RGBColor[
             0.4243114469407097, 0.5404750542269321, 0.9486622155978126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 211}], {
             RGBColor[
             0.7151643856887187, 0.7761745790596182, 0.9734386368600495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 301}], {
             RGBColor[
             0.6857856695399872, 0.7527487882666255, 0.970636468687094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 328}], {
             RGBColor[
             0.6267804645335953, 0.7062949766594282, 0.964850515368085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 347}], {
             RGBColor[
             0.6493781066053251, 0.7239484263943043, 0.9671028371428234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 372}], {
             RGBColor[
             0.7479756344482656, 0.8002182415009421, 0.8954933875800859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 380}], {
             RGBColor[
             0.7502913434538434, 0.7995085874549474, 0.7359239508983131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 54}], {
             RGBColor[
             0.7533473993835174, 0.8072399811414813, 0.9760502864049869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 116}], {
             RGBColor[
             0.5451921899710035, 0.6366377037536818, 0.9594392537783907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 121}], {
             RGBColor[
             0.8727112918580057, 0.8997881050964202, 0.9090257418315286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.8522231839455323, 0.8852099065369623, 0.9751347473973496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 135}], {
             RGBColor[
             0.8083412419659897, 0.8505224056815381, 0.9814464237867668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 158}], {
             RGBColor[
             0.7291746880528696, 0.7883560753305688, 0.9736409764463787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 172}], {
             RGBColor[
             0.8711300654446608, 0.8991342273388367, 0.9352307555834358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 181}], {
             RGBColor[
             0.6629582171265833, 0.7355021212738989, 0.9678104043487923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 265}], {
             RGBColor[
             0.6702502424148804, 0.7414221159049341, 0.9683844592910558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 276}], {
             RGBColor[
             0.8670215959509405, 0.8962465379804201, 0.9500848959161886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 322}], {
             RGBColor[
             0.8636153121843586, 0.8606600047920859, 0.657621168077104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 328}], {
             RGBColor[
             0.7516669777991709, 0.8059272230281129, 0.9758827976858917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 362}], {
             RGBColor[
             0.7122616313339546, 0.7751434668777605, 0.9719552410141383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 364}], {
             RGBColor[
             0.7101274202877557, 0.7734762049878652, 0.9717425228023895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 59}], {
             RGBColor[
             0.9072169224979262, 0.9268305953438603, 0.914087409370204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 136}], {
             RGBColor[
             0.8964596234233047, 0.9194770165053028, 0.9622647285196368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 194}], {
             RGBColor[
             0.8808503039896398, 0.9078301386295302, 0.9884974824105228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 246}], {
             RGBColor[
             0.909415577445462, 0.9277397956675212, 0.8776500069529269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 376}], {
             RGBColor[
             0.8268961218732637, 0.8648085383571904, 0.983351284354796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 377}], {
             RGBColor[
             0.9080870906709335, 0.9271904322457009, 0.8996664708204287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 395}], {
             RGBColor[
             0.8618599573109872, 0.8926877516672009, 0.9866861661914303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 396}], {
             RGBColor[
             0.8761005754674418, 0.9040428340338756, 0.9880444490639428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 117}], {
             RGBColor[
             0.6030790509297288, 0.6886457678032138, 0.9618957385219937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 133}], {
             RGBColor[
             0.7147831577332355, 0.7766007995300037, 0.9725618267005083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 174}], {
             RGBColor[
             0.6071126464569955, 0.6919204223636566, 0.9622132779374475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 223}], {
             RGBColor[
             0.5153835237467852, 0.6166171412977313, 0.955222309244548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 260}], {
             RGBColor[
             0.6165721255815992, 0.6996000536616882, 0.96295796278535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 267}], {
             RGBColor[
             0.8015461599414375, 0.8421803363702647, 0.8269002557219256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 272}], {
             RGBColor[
             0.5938316085182322, 0.6811382774610277, 0.961167745980863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 291}], {
             RGBColor[
             0.8010015784190848, 0.8410155315595904, 0.7676259177814234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 346}], {
             RGBColor[
             0.5466870547656177, 0.6428642048867117, 0.9574563540132666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 384}], {
             RGBColor[
             0.5106654512380486, 0.612530584027883, 0.954921677836319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 68}], {
             RGBColor[
             0.6701596697673516, 0.7352323210460217, 0.9250638068562755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 86}], {
             RGBColor[
             0.8881359397863615, 0.9125545565964859, 0.9430567818004143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 95}], {
             RGBColor[
             0.7910136228918181, 0.835994818800674, 0.9338462737963156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 101}], {
             RGBColor[
             0.7848472340767668, 0.8309886665679651, 0.9333608330805683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 129}], {
             RGBColor[
             0.9746731029584217, 0.9805776113242186, 0.92532833723561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 151}], {
             RGBColor[
             0.9451211431525772, 0.9577648349324699, 0.9485526322650246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 171}], {
             RGBColor[
             0.8241359446211354, 0.8625572739554326, 0.9366778603963037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 244}], {
             RGBColor[
             0.9890419635922234, 0.9882558898448939, 0.7236356754659021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 249}], {
             RGBColor[
             0.7550984718514222, 0.8068372812269644, 0.9310189015448824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 253}], {
             RGBColor[
             0.8423242123092052, 0.876766086909307, 0.9384906969404252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 270}], {
             RGBColor[
             0.9400052095164897, 0.9536855283193729, 0.9480646699477668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 308}], {
             RGBColor[
             0.9887885943789794, 0.9877139587173218, 0.6960580002178177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 386}], {
             RGBColor[0.9110951870433812, 0.930633461140971, 0.945307206196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 397}], {
             RGBColor[
             0.7587977124629461, 0.80984049140429, 0.9313101193165865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 121}], {
             RGBColor[
             0.8690523417275884, 0.8969297054454872, 0.9086610518773617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 128}], {
             RGBColor[
             0.7579458151198504, 0.8108322984639587, 0.9765086135109462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 130}], {
             RGBColor[
             0.848564233815115, 0.8823515068860295, 0.9747700574431826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 158}], {
             RGBColor[
             0.7255157379224524, 0.7854976756796359, 0.9732762864922117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 181}], {
             RGBColor[
             0.6592992669961661, 0.732643721622966, 0.9674457143946252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 265}], {
             RGBColor[
             0.6665912922844632, 0.7385637162540011, 0.9680197693368887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 311}], {
             RGBColor[
             0.8280269394714509, 0.7354293713105805, 0.6096016135873152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 322}], {
             RGBColor[
             0.8599563620539414, 0.857801605141153, 0.657256478122937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 328}], {
             RGBColor[
             0.7480080276687537, 0.80306882337718, 0.9755181077317248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 362}], {
             RGBColor[
             0.7086026812035373, 0.7722850672268275, 0.9715905510599714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 58}], {
             RGBColor[
             0.801903116840597, 0.8429249703982363, 0.8548400589486962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 60}], {
             RGBColor[
             0.9083720302274569, 0.9266210715891778, 0.8651041015072878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 80}], {
             RGBColor[
             0.8972481702195656, 0.917909614281488, 0.8640010615381541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 87}], {
             RGBColor[
             0.9280739974165986, 0.9423308854301468, 0.8669832927259418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 122}], {
             RGBColor[
             0.9770865736573825, 0.9807839185881779, 0.8498758235753721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 146}], {
             RGBColor[
             0.6419086727919034, 0.7068315158417986, 0.8435366219062386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 159}], {
             RGBColor[
             0.9146038548108921, 0.931590159353637, 0.8656984984992713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.6997306673976564, 0.7586743451218244, 0.8471565341961387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 192}], {
             RGBColor[
             0.9911498368906069, 0.9906082443625179, 0.7963336364179769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 201}], {
             RGBColor[
             0.8385210505030234, 0.8720315420162843, 0.8581476910809456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 210}], {
             RGBColor[
             0.8190982252830891, 0.8568582833355325, 0.8562118053796439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 228}], {
             RGBColor[
             0.7833077936961355, 0.8278284493598012, 0.8533761669938511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 385}], {
             RGBColor[
             0.7682771471720885, 0.8156258933886704, 0.8521928994404058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 71}], {
             RGBColor[
             0.6302716225592353, 0.7097312586737727, 0.964713759613846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 83}], {
             RGBColor[
             0.6014807324249054, 0.6863575170479039, 0.9624472352779658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 108}], {
             RGBColor[
             0.5785204024089224, 0.667627512525306, 0.9606645188894234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 120}], {
             RGBColor[
             0.795278810993651, 0.8405107251185645, 0.9800933222600744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 143}], {
             RGBColor[
             0.6909886713269526, 0.7585248688398063, 0.9698349511677544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 196}], {
             RGBColor[
             0.6839652523301485, 0.7530381205395416, 0.9691349223997351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 231}], {
             RGBColor[
             0.7243160897402765, 0.7845605014020562, 0.9731567167727619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 237}], {
             RGBColor[
             0.6021418508601095, 0.6868942427766487, 0.9624992809429418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 254}], {
             RGBColor[
             0.5881536765522475, 0.6755380127134549, 0.961398080621056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 286}], {
             RGBColor[
             0.7446792599795165, 0.8004683647587765, 0.9751863272775643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 290}], {
             RGBColor[
             0.49263570224160813`, 0.5904182248235329, 0.955295285899991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 320}], {
             RGBColor[
             0.5592997074075189, 0.6509795125753105, 0.9594397932001272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 331}], {
             RGBColor[
             0.6346898635390386, 0.713318185740665, 0.965061579728326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 342}], {
             RGBColor[
             0.8017397712583756, 0.8456625194555616, 0.9807095744178912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 343}], {
             RGBColor[
             0.8501525696736728, 0.8795410983472043, 0.7404739379612224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 344}], {
             RGBColor[
             0.6109975809604464, 0.6940837234181969, 0.9631964364560486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 349}], {
             RGBColor[
             0.5686018492438116, 0.6590365602946644, 0.9600325174523747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 92}], {
             RGBColor[
             0.728791202599113, 0.7876963512086914, 0.9739831947672415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 114}], {
             RGBColor[
             0.6475177167401052, 0.7238840696083187, 0.9659677481408857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 153}], {
             RGBColor[
             0.7130493092984994, 0.7751441927930927, 0.972481718931275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 188}], {
             RGBColor[
             0.7843676921306211, 0.8311056264803074, 0.947875699798841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 195}], {
             RGBColor[
             0.636586552595889, 0.7153445610989326, 0.9648782318565271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 208}], {
             RGBColor[
             0.7956109910606721, 0.8379750804774891, 0.86096400499448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 258}], {
             RGBColor[
             0.7965078687119711, 0.8381971202217617, 0.8352811636229629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 278}], {
             RGBColor[
             0.5494382355177898, 0.6450977373606055, 0.9576729370399847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 284}], {
             RGBColor[
             0.7841760826778712, 0.8309627244641782, 0.9482000446225975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 327}], {
             RGBColor[
             0.5642646139736262, 0.6571344593117914, 0.9588401238628419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 337}], {
             RGBColor[
             0.6782405747521149, 0.7478849997896699, 0.9690299155060912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 354}], {
             RGBColor[
             0.5616187010153105, 0.6549863879752104, 0.9586318279024648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 392}], {
             RGBColor[
             0.7217331110390169, 0.7820684205854624, 0.9733099876934068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 60}], {
             RGBColor[
             0.7161643890179119, 0.7777133806332256, 0.9726806502698357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 80}], {
             RGBColor[
             0.7050405290100206, 0.7690019233255359, 0.9715776103007021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 87}], {
             RGBColor[
             0.7358663562070535, 0.7934231944741945, 0.9745598414884897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 110}], {
             RGBColor[
             0.5901054645142783, 0.6781132258977434, 0.9608744102755565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 159}], {
             RGBColor[
             0.7223962136013471, 0.7826824683976847, 0.9732750472618192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 167}], {
             RGBColor[
             0.6322162941609142, 0.7121110775767296, 0.9643191711521104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 192}], {
             RGBColor[
             0.7989421956810618, 0.8417005534065656, 0.9039101851805249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 201}], {
             RGBColor[
             0.6463134092934784, 0.723123851060332, 0.9657242398434935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 210}], {
             RGBColor[
             0.626890584073544, 0.7079505923795804, 0.9637883541421919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 228}], {
             RGBColor[
             0.5911001524865904, 0.678920758403849, 0.9609527157563991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 236}], {
             RGBColor[
             0.7304178540704389, 0.7890787067661086, 0.9740401584907643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 243}], {
             RGBColor[
             0.6961352789319106, 0.762045074282109, 0.9706900181972096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 263}], {
             RGBColor[
             0.7729517463655887, 0.8229809517810593, 0.9776419872668267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 348}], {
             RGBColor[
             0.8022402268883468, 0.8426355999762148, 0.8180859230638418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 351}], {
             RGBColor[
             0.4757170800303316, 0.5822179422173389, 0.9527064361944069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 79}], {
             RGBColor[
             0.8758764264880853, 0.9022968081490945, 0.9109770438962583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[
             0.9618533818101026, 0.9703962249322101, 0.9192986836339425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 237}], {
             RGBColor[
             0.742737289995347, 0.7960646881724378, 0.899226729545211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 246}], {
             RGBColor[
             0.9904186552659248, 0.9903058819702011, 0.8084512081763465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 254}], {
             RGBColor[
             0.728749115687485, 0.7847084581092441, 0.8981255292233252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 349}], {
             RGBColor[
             0.7091972883790492, 0.7682070056904535, 0.8967599660546439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 373}], {
             RGBColor[
             0.6828245037403531, 0.7453642251711124, 0.895079515538004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 395}], {
             RGBColor[
             0.94286303513145, 0.955253837969881, 0.9174873674148499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 87}], {
             RGBColor[
             0.8423352695939136, 0.877119295665136, 0.9848238840470813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 122}], {
             RGBColor[
             0.8913478458346975, 0.9155723288231672, 0.9677164148965116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 146}], {
             RGBColor[
             0.5561699449692183, 0.6416199260767879, 0.9613772132273781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 159}], {
             RGBColor[
             0.828865126988207, 0.8663785695886262, 0.9835390898204108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 165}], {
             RGBColor[
             0.6139919395749714, 0.6934627553568137, 0.9649971255172782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 201}], {
             RGBColor[
             0.7527823226803383, 0.8068199522512736, 0.9759882824020851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 210}], {
             RGBColor[
             0.7333594974604041, 0.7916466935705218, 0.9740523967007835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 263}], {
             RGBColor[
             0.8794206597524488, 0.9066770529720009, 0.9879060298254183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 66}], {
             RGBColor[
             0.30790924297053684`, 0.4385896026512286, 0.9409332318814285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 98}], {
             RGBColor[
             0.6424080066726418, 0.7133022320959372, 0.9556825296891888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 107}], {
             RGBColor[
             0.5028926325695633, 0.603636843042926, 0.9552046592206254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 131}], {
             RGBColor[
             0.6024797349008237, 0.6818437373557193, 0.9650221163089256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 215}], {
             RGBColor[
             0.3806000906837974, 0.5040784018586988, 0.945472479120294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 262}], {
             RGBColor[
             0.40078609539496174`, 0.5211866318397336, 0.9468625682436196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 269}], {
             RGBColor[
             0.36831070403001165`, 0.49343395282172264`, 0.9446894102697927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 279}], {
             RGBColor[
             0.5378029728841194, 0.6309090662250705, 0.9586841956875016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 297}], {
             RGBColor[
             0.6182521740883501, 0.6944202522323963, 0.9665265056388546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 298}], {
             RGBColor[
             0.5758650435319326, 0.29909940422496833`, 0.553373678326482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 300}], {
             RGBColor[
             0.6283484853698917, 0.7024707767912288, 0.9674895008219715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 306}], {
             RGBColor[
             0.2900871807100718, 0.4198574852314677, 0.9399182918010736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 307}], {
             RGBColor[
             0.3786744910269105, 0.5024105442193562, 0.9453497816128981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 314}], {
             RGBColor[
             0.4416541041290034, 0.5543651224128412, 0.950079847595612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 352}], {
             RGBColor[
             0.40649593476249, 0.5258221366636251, 0.9473120677144622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 77}], {
             RGBColor[
             0.8767730370820861, 0.9026675796715551, 0.8961178859998276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 204}], {
             RGBColor[
             0.8507304680281025, 0.884212190700202, 0.9835106102217115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 345}], {
             RGBColor[
             0.8747543373534841, 0.8897761153846453, 0.6885423117070556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 370}], {
             RGBColor[
             0.6366335357689622, 0.7140305813301231, 0.9658063843042785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 389}], {
             RGBColor[
             0.5975523254700101, 0.6817122338598012, 0.9628929142274242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 400}], {
             RGBColor[
             0.7523111647165037, 0.8064304667439353, 0.9759470042175424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 90}], {
             RGBColor[
             0.6072489420420872, 0.6871987337965093, 0.9647624629810152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 138}], {
             RGBColor[
             0.7640453582922317, 0.8157182781903852, 0.9770844571881868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 142}], {
             RGBColor[
             0.6693641905894222, 0.7396297413617812, 0.9690989540515427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 152}], {
             RGBColor[
             0.8660094012589478, 0.8959964056376493, 0.9870819438594391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 156}], {
             RGBColor[
             0.8084850018451033, 0.8504348654876889, 0.9815137855454565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 202}], {
             RGBColor[
             0.910600046532607, 0.9299064120807029, 0.9308330817886022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 214}], {
             RGBColor[
             0.8989004878139084, 0.9215227085419813, 0.9659442524010446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 217}], {
             RGBColor[
             0.9035946934124229, 0.9250236393912972, 0.9579981867676614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 242}], {
             RGBColor[
             0.9135959612613134, 0.9311452998125196, 0.8811830215551548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 256}], {
             RGBColor[
             0.555026512962557, 0.638855703218862, 0.9615487898166247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 257}], {
             RGBColor[
             0.8924583629490271, 0.9167181823657642, 0.9768490894220303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 261}], {
             RGBColor[
             0.8084850018451033, 0.8504348654876889, 0.9815137855454565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 264}], {
             RGBColor[
             0.7120420373201499, 0.7742775399528712, 0.9724587104802892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 268}], {
             RGBColor[
             0.8620283045325852, 0.8928219871720395, 0.9867022232997118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 317}], {
             RGBColor[
             0.8328064715037432, 0.5539600361034837, 0.5805575220843062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 381}], {
             RGBColor[
             0.913819920493252, 0.931237912710416, 0.8774714374940166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 82}], {
             RGBColor[
             0.5667481212909691, 0.6582130407736252, 0.959583383489361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 151}], {
             RGBColor[
             0.6753028365514008, 0.7437098137441774, 0.9702192009550984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 157}], {
             RGBColor[
             0.6942507124202357, 0.7586140816982982, 0.964944854043007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 171}], {
             RGBColor[
             0.554317638019959, 0.6485022527671401, 0.9583444290863774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 182}], {
             RGBColor[
             0.4361409884062786, 0.552185135899224, 0.949011496010283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 253}], {
             RGBColor[
             0.5725059057080286, 0.6627110657210145, 0.9601572656304989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 105}], {
             RGBColor[
             0.6956099427613733, 0.7594767231336745, 0.9604392481282998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 113}], {
             RGBColor[
             0.9693743071233971, 0.9757316941689507, 0.89425891278702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 148}], {
             RGBColor[
             0.9716328156783764, 0.9759193769662862, 0.8025837369932138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 161}], {
             RGBColor[
             0.8489556633904514, 0.8826323547735015, 0.9735466192593139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 168}], {
             RGBColor[
             0.7362045916679707, 0.7927305191031073, 0.963552881721925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 170}], {
             RGBColor[
             0.9435817585487871, 0.8772589574325598, 0.6203474439527725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 180}], {
             RGBColor[
             0.9111074344662209, 0.931617259043947, 0.9796268285291241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 239}], {
             RGBColor[
             0.7685163282489125, 0.8189626424866605, 0.9660965799873679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 251}], {
             RGBColor[
             0.8896798248036175, 0.9145314647359568, 0.977583043990852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 282}], {
             RGBColor[
             0.7337093951454567, 0.7907048061588082, 0.9633564507114667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 312}], {
             RGBColor[
             0.8005658132344056, 0.8448298360551161, 0.9687235712246193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 326}], {
             RGBColor[
             0.7777457441429024, 0.8264554980898495, 0.9668231534150071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 356}], {
             RGBColor[
             0.8480463260385501, 0.8819219735229764, 0.973455985010317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[
             0.6159061625793136, 0.6878200262972292, 0.9540864049176532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 107}], {
             RGBColor[
             0.4763907884762351, 0.5781546372442179, 0.9536085344490899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 131}], {
             RGBColor[
             0.5759778908074955, 0.6563615315570113, 0.9634259915373901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 215}], {
             RGBColor[
             0.35409824659046923`, 0.4785961960599907, 0.9438763543487585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 297}], {
             RGBColor[
             0.591750329995022, 0.6689380464336883, 0.964930380867319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 307}], {
             RGBColor[
             0.3521726469335823, 0.4769283384206481, 0.9437536568413625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 314}], {
             RGBColor[
             0.41515226003567524`, 0.5288829166141331, 0.9484837228240766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 352}], {
             RGBColor[
             0.3799940906691619, 0.5003399308649171, 0.9457159429429267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 85}], {
             RGBColor[
             0.872652954072483, 0.899757330962134, 0.9096910124547231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 127}], {
             RGBColor[
             0.8201505088665448, 0.8587420217338925, 0.904458059379841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 139}], {
             RGBColor[
             0.7853816884425546, 0.8306622830572659, 0.901620319071026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 184}], {
             RGBColor[
             0.8724067389310861, 0.8995649858223702, 0.9096664720304399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 305}], {
             RGBColor[
             0.6953462325470638, 0.7561837260611712, 0.8949147235366788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 325}], {
             RGBColor[
             0.9628608849470544, 0.9711338650529959, 0.9169219685287702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 86}], {
             RGBColor[
             0.5737773061659341, 0.6599209428060464, 0.9618852802382862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 95}], {
             RGBColor[
             0.4766549892713908, 0.5833612050102346, 0.9526747722341875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 129}], {
             RGBColor[
             0.6603144693379943, 0.727943997533779, 0.9441568356734817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 151}], {
             RGBColor[
             0.63076250953215, 0.7051312211420304, 0.9673811307028966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 178}], {
             RGBColor[
             0.42734019108924515`, 0.5433252302396279, 0.948792530675231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 229}], {
             RGBColor[
             0.47048860045633956`, 0.5783550527775255, 0.9521893315184401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 249}], {
             RGBColor[
             0.4407398382309949, 0.5542036674365249, 0.9498473999827544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 308}], {
             RGBColor[
             0.6744299607585521, 0.7350803449268823, 0.7148864986556895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 309}], {
             RGBColor[
             0.3585509077313219, 0.4849805078094227, 0.9440675246798892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 319}], {
             RGBColor[
             0.5899200597707526, 0.6725645603410572, 0.9634855413841691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 334}], {
             RGBColor[
             0.530568252323479, 0.6261657015433483, 0.9575786055628361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 371}], {
             RGBColor[
             0.4992199901475743, 0.6016762008759146, 0.9544541037553078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 386}], {
             RGBColor[
             0.5967365534229538, 0.6779998473505314, 0.9641357046338718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 74}], {
             RGBColor[
             0.5674769680939499, 0.6540906168137067, 0.9616418222107661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 97}], {
             RGBColor[
             0.8777234398932952, 0.9049987528001295, 0.9709870901655355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 100}], {
             RGBColor[
             0.8282679716747868, 0.8660595497360487, 0.983440433660749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 132}], {
             RGBColor[
             0.8901523369507932, 0.9142682038751605, 0.9499482094227112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 140}], {
             RGBColor[
             0.8978238134047014, 0.918023682283202, 0.8446588662551227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 141}], {
             RGBColor[
             0.8057021796248844, 0.8481399333771046, 0.981268521616208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 168}], {
             RGBColor[
             0.6620516746856875, 0.7340992256334213, 0.9681950173473977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 191}], {
             RGBColor[
             0.893609001469466, 0.9164336365470396, 0.9256225014298219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 216}], {
             RGBColor[
             0.8735997505905335, 0.9019233120700515, 0.9779674205246903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 219}], {
             RGBColor[
             0.7828069630385694, 0.8302540161697846, 0.9789865403948478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 220}], {
             RGBColor[
             0.7206098621709847, 0.7816394002502691, 0.9728049323719489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 350}], {
             RGBColor[
             0.5570418974673441, 0.6450522831188406, 0.9609769087378095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 357}], {
             RGBColor[
             0.7205845433987659, 0.7816188453303843, 0.9728029391854541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 394}], {
             RGBColor[
             0.6656821402283657, 0.7370466011115763, 0.9684808208937508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 75}], {
             RGBColor[
             0.7960051583033225, 0.841274167965954, 0.9686309499827275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 103}], {
             RGBColor[
             0.7829256891026788, 0.8311736339143083, 0.9787789485451703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 133}], {
             RGBColor[
             0.7324937765702373, 0.7909605957987372, 0.9739687077067263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.8191983195857331, 0.8564150943369306, 0.8219442143703855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 164}], {
             RGBColor[
             0.8192482434082398, 0.8565218763451998, 0.8273781143561273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 227}], {
             RGBColor[
             0.6365370821377729, 0.7157900228476023, 0.9645423135147324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 234}], {
             RGBColor[
             0.48730806702983326`, 0.5913193401966998, 0.9537117420035048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 280}], {
             RGBColor[
             0.7698365087421829, 0.8207366767911849, 0.9775304908375371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 346}], {
             RGBColor[
             0.5643976736026196, 0.6572240011554453, 0.9588632350194846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 79}], {
             RGBColor[
             0.6585234878641693, 0.7318018305721161, 0.9675296415187498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 109}], {
             RGBColor[
             0.6739472644639701, 0.7438510020769245, 0.9690669394268308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 120}], {
             RGBColor[
             0.7185213115049724, 0.7791861929373753, 0.9733733684848351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 143}], {
             RGBColor[
             0.6142311718382741, 0.6972003366586171, 0.963114997392515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 237}], {
             RGBColor[
             0.525384351371431, 0.6255697105954595, 0.9557793271677024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 286}], {
             RGBColor[
             0.6679217604908378, 0.7391438325775872, 0.968466373502325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 320}], {
             RGBColor[
             0.4825422079188404, 0.5896549803941213, 0.9527198394248879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 321}], {
             RGBColor[
             0.6739472644639701, 0.7438510020769245, 0.9690669394268308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 343}], {
             RGBColor[
             0.7733950701849943, 0.8182165661660151, 0.733753984185983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 382}], {
             RGBColor[
             0.7338010069205168, 0.7913698073054471, 0.9748307594739148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 119}], {
             RGBColor[
             0.6219807684697253, 0.7039910336148543, 0.963383750966015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 200}], {
             RGBColor[
             0.3935356284277176, 0.4990759650793144, 0.947897745043463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 288}], {
             RGBColor[
             0.6381854771299083, 0.7167504859863567, 0.9649303702084093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 341}], {
             RGBColor[
             0.7239487989850979, 0.783909233069535, 0.9734360537453755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 355}], {
             RGBColor[
             0.6803515152592744, 0.7496909154467766, 0.9691330868251147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 374}], {
             RGBColor[
             0.7965327723594746, 0.8403952547160175, 0.930925651426003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 375}], {
             RGBColor[
             0.6079350330592613, 0.6925880728554703, 0.9622780192232792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 379}], {
             RGBColor[
             0.7879366667771798, 0.8341054544581248, 0.9509024625087887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 393}], {
             RGBColor[
             0.6653606978401807, 0.7379799749445484, 0.9676389422419331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 399}], {
             RGBColor[
             0.699984322315247, 0.7650282135337625, 0.9710899015534409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 85}], {
             RGBColor[
             0.6305295580192884, 0.7091756290305491, 0.9652571226627342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 96}], {
             RGBColor[
             0.6489566143331567, 0.7235709854737578, 0.9670937594254687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 110}], {
             RGBColor[
             0.5373021961402777, 0.6352451538715977, 0.95671754356441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 115}], {
             RGBColor[
             0.5071493231715183, 0.6107656932241115, 0.954343798950696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 184}], {
             RGBColor[
             0.6302833428778916, 0.7089832838907854, 0.9652325822384511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 188}], {
             RGBColor[
             0.7374590261820559, 0.7930230582519433, 0.9441828777832648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 195}], {
             RGBColor[
             0.589677886647324, 0.6772619928705685, 0.9611854098409509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 203}], {
             RGBColor[
             0.6113471059799558, 0.6941901517053871, 0.9633451951136598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 206}], {
             RGBColor[
             0.664179610480764, 0.7354979501856713, 0.9686018518500026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 208}], {
             RGBColor[
             0.7487023251121071, 0.799892512249125, 0.8572711829789039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 258}], {
             RGBColor[
             0.749599202763406, 0.8001145519933976, 0.8315883416073867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 284}], {
             RGBColor[
             0.7372674167293061, 0.7928801562358141, 0.9445072226070215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 348}], {
             RGBColor[
             0.7494369585143464, 0.7997675279500691, 0.8139290563526951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 369}], {
             RGBColor[
             0.7488650691859408, 0.7985443145034901, 0.751682432247562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 392}], {
             RGBColor[
             0.6748244450904519, 0.7439858523570984, 0.9696171656778307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 132}], {
             RGBColor[
             0.6570864559207084, 0.7242493955113904, 0.9308357438649091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 140}], {
             RGBColor[
             0.6647579323746167, 0.7280048739194319, 0.8255464006973207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 191}], {
             RGBColor[
             0.6605431204393811, 0.7264148281832694, 0.90651003587202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 198}], {
             RGBColor[
             0.6637629909490048, 0.7258767948140572, 0.7172531665862105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 216}], {
             RGBColor[
             0.6405338695604487, 0.7119045037062814, 0.9588549549668883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 219}], {
             RGBColor[
             0.5497410820084847, 0.6402352078060145, 0.9598740748370458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 220}], {
             RGBColor[
             0.48754398114089986`, 0.5916205918864992, 0.9536924668141469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 224}], {
             RGBColor[
             0.542993149541315, 0.6349636716764753, 0.9592015039917325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 302}], {
             RGBColor[
             0.356799358016412, 0.48346340348181616`, 0.9439559174808898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 311}], {
             RGBColor[
             0.6203882583768334, 0.5652744847902746, 0.5930234936883874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 323}], {
             RGBColor[
             0.3315666977482037, 0.46160814138787465`, 0.9423481146809649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 340}], {
             RGBColor[
             0.6031659543842243, 0.6823909101448513, 0.9650875685358478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 357}], {
             RGBColor[
             0.4875186623686811, 0.5916000369666142, 0.9536904736276521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 89}], {
             RGBColor[
             0.8816341198539575, 0.9081681635335217, 0.9771656446219531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 133}], {
             RGBColor[
             0.8849334403441209, 0.9107572410685955, 0.9774914055900918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 145}], {
             RGBColor[
             0.9716379833596167, 0.9762117396067889, 0.8254669122537509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.9696271134193459, 0.9708654594106154, 0.6954751750865447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 164}], {
             RGBColor[
             0.9716879071821234, 0.976318521615058, 0.8309008122394927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 169}], {
             RGBColor[
             0.8699838561525366, 0.899066888984688, 0.9760044552140997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 209}], {
             RGBColor[
             0.7040240793490424, 0.7666182663279149, 0.9613772262944176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 227}], {
             RGBColor[
             0.7889767459116566, 0.8355866681174605, 0.968065011398098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 280}], {
             RGBColor[
             0.9222761725160665, 0.9405333220610431, 0.9810531887209026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 315}], {
             RGBColor[
             0.8700991991310751, 0.8991569957961614, 0.976015951524259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[
             0.6972704823385631, 0.7620598277265158, 0.971555384132299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 109}], {
             RGBColor[
             0.8302470483794169, 0.8676874205144895, 0.9836159820568482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 138}], {
             RGBColor[
             0.7796268551281451, 0.8281425408188783, 0.9785706342661626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 144}], {
             RGBColor[
             0.9256388732420784, 0.942106266665926, 0.9413127072469918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 207}], {
             RGBColor[
             0.8033115668931086, 0.8466452176601442, 0.9809313049886788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 233}], {
             RGBColor[
             0.8159210998638537, 0.8564958806528904, 0.9821881053924173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 242}], {
             RGBColor[
             0.9291774580972267, 0.9435695624410125, 0.8826691986331308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 257}], {
             RGBColor[
             0.9080398597849406, 0.9291424449942571, 0.978335266500006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 317}], {
             RGBColor[
             0.8483879683396567, 0.5663842987319767, 0.5820436991622819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 358}], {
             RGBColor[
             0.9286888156926862, 0.9433674962491981, 0.8907672678423724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 366}], {
             RGBColor[
             0.9237363998188401, 0.9408488988508141, 0.9517651185359146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 382}], {
             RGBColor[
             0.8901007908359633, 0.9152062257430122, 0.9893798021039323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 78}], {
             RGBColor[
             0.8655513491408082, 0.8939011117638416, 0.8949994130184771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 102}], {
             RGBColor[
             0.6633296611337723, 0.7280729448354676, 0.8789210322750862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 111}], {
             RGBColor[
             0.9663741778240519, 0.9734753810068695, 0.8984944775082662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 160}], {
             RGBColor[
             0.9764993582880243, 0.9384708747608359, 0.5629381810297324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 166}], {
             RGBColor[
             0.8798353650715842, 0.9050598935715057, 0.8964231102347386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 185}], {
             RGBColor[
             0.7678322481136852, 0.8160807683382885, 0.8862725542073637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 370}], {
             RGBColor[
             0.7498737201932668, 0.8015012263500295, 0.884858793105213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 389}], {
             RGBColor[
             0.7107925098943148, 0.7691828788797077, 0.8819453230283587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 400}], {
             RGBColor[
             0.8655513491408082, 0.8939011117638416, 0.8949994130184771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 102}], {
             RGBColor[
             0.53886778876819, 0.6318358319078476, 0.9587501504928011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 144}], {
             RGBColor[
             0.8631267661789662, 0.8928984844001799, 0.935181027315767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 160}], {
             RGBColor[
             0.8520374859224418, 0.842233761833216, 0.6427672992474472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 185}], {
             RGBColor[
             0.6433703757481027, 0.7198436554106685, 0.9661016724250786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 207}], {
             RGBColor[
             0.7407994598299965, 0.7974374353943982, 0.974799625057454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 213}], {
             RGBColor[
             0.6372290986083516, 0.7148578899672362, 0.965618208592398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 230}], {
             RGBColor[
             0.4934263755657522, 0.5866535804246102, 0.9560678790926874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 247}], {
             RGBColor[
             0.6081601106451604, 0.6912583759957334, 0.9633297913767241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 289}], {
             RGBColor[
             0.6274637944392956, 0.7069299761208571, 0.964849448076722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 370}], {
             RGBColor[
             0.6254118478276843, 0.7052641134224096, 0.964687911322928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 391}], {
             RGBColor[
             0.8127265608884511, 0.8541477901108243, 0.9818305596244197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 400}], {
             RGBColor[
             0.7410894767752259, 0.7976639988362217, 0.974828531236192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 109}], {
             RGBColor[
             0.7789566292575826, 0.8272461061564569, 0.9786027751069739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 120}], {
             RGBColor[
             0.8235306762985848, 0.8625812970169078, 0.9829092041649783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 136}], {
             RGBColor[
             0.8651191274134638, 0.8949432293105369, 0.959154363045691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 237}], {
             RGBColor[
             0.6303937161650434, 0.7089648146749921, 0.9653151628478456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 246}], {
             RGBColor[
             0.8780750814356211, 0.9032060084727553, 0.8745396414789812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 254}], {
             RGBColor[
             0.6164055418571813, 0.6976085846117983, 0.9642139625259598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 286}], {
             RGBColor[
             0.7729311252844503, 0.8225389366571197, 0.9780022091824682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 320}], {
             RGBColor[
             0.5875515727124527, 0.6730500844736538, 0.9622556751050311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 343}], {
             RGBColor[
             0.8784044349786067, 0.9016116702455477, 0.7432898198661262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 349}], {
             RGBColor[
             0.5968537145487456, 0.6811071321930077, 0.9628483993572785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 87}], {
             RGBColor[
             0.8312114095860221, 0.8684078383574463, 0.9837208440779477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 96}], {
             RGBColor[
             0.7971049360861255, 0.8414237013831551, 0.9804116287260733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 110}], {
             RGBColor[
             0.6854505178932467, 0.7530978697809951, 0.9700354128650144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 146}], {
             RGBColor[
             0.545046084961327, 0.632908468769098, 0.9602741732582444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 154}], {
             RGBColor[
             0.6658338035028974, 0.7371721373159972, 0.9684911132498136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 159}], {
             RGBColor[
             0.8177412669803157, 0.8576671122809365, 0.9824360498512772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 167}], {
             RGBColor[
             0.7275613475398828, 0.7870957214599814, 0.9734801737415684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 192}], {
             RGBColor[
             0.8942872490600303, 0.9166851972898173, 0.9130711877699828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 201}], {
             RGBColor[
             0.7416584626724468, 0.7981084949435837, 0.9748852424329515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 203}], {
             RGBColor[
             0.7594954277329248, 0.8120428676147845, 0.9766630644142643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 228}], {
             RGBColor[
             0.6864452058655589, 0.7539054022871007, 0.970113718345857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 243}], {
             RGBColor[
             0.7914803323108791, 0.8370297181653608, 0.9798510207866674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 332}], {
             RGBColor[
             0.7167240977293382, 0.7784871707506505, 0.9724973836286092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 348}], {
             RGBColor[
             0.8975852802673154, 0.9176202438594665, 0.8272469256532997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 361}], {
             RGBColor[
             0.8936939346441876, 0.9164398465313813, 0.9229039430889856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 385}], {
             RGBColor[
             0.671414559341512, 0.7417028463159699, 0.9689304507924116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 89}], {
             RGBColor[
             0.759120884628746, 0.811750271695167, 0.976625733457944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 163}], {
             RGBColor[
             0.8471138781941343, 0.8744475675722608, 0.6949352639225357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 169}], {
             RGBColor[
             0.7474706209273251, 0.8026489971463335, 0.9754645440500906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 209}], {
             RGBColor[
             0.5815108441238309, 0.6702003744895602, 0.9608373151304086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 227}], {
             RGBColor[
             0.6664635106864449, 0.7391687762791059, 0.9675251002340889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 240}], {
             RGBColor[
             0.7409814637134604, 0.7975796182114409, 0.9748177655036346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 245}], {
             RGBColor[
             0.5978859357749162, 0.6834944115813835, 0.9621264223291193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 248}], {
             RGBColor[
             0.8474821308195093, 0.8795035301680146, 0.8804217526631428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 292}], {
             RGBColor[
             0.782135954664919, 0.8300601527484642, 0.9788320002182387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 304}], {
             RGBColor[
             0.5225785180281972, 0.6193268172757483, 0.9570350451078222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 315}], {
             RGBColor[
             0.7475859639058635, 0.8027391039578069, 0.97547604036025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 329}], {
             RGBColor[
             0.8283263112323627, 0.8664389029193349, 0.9675600929702692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 353}], {
             RGBColor[
             0.6867041887091236, 0.7551777984554844, 0.9694079139811757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 378}], {
             RGBColor[
             0.8215141721280541, 0.8613584207291956, 0.9790912675834356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 151}], {
             RGBColor[
             0.797169267656944, 0.8421669620579264, 0.9802341386459082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 157}], {
             RGBColor[
             0.8161171435257788, 0.8570712300120472, 0.9749597917338169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 171}], {
             RGBColor[
             0.6761840691255021, 0.7469594010808891, 0.9683593667771873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 182}], {
             RGBColor[
             0.5580074195118216, 0.6506422842129729, 0.9590264337010929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 253}], {
             RGBColor[
             0.6943723368135718, 0.7611682140347634, 0.9701722033213087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 108}], {
             RGBColor[
             0.472972012785914, 0.582929238718248, 0.9516780407783041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 120}], {
             RGBColor[
             0.6897304213706426, 0.7558124513115064, 0.971106844148955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 125}], {
             RGBColor[
             0.6811739124850191, 0.7489897233863567, 0.9702907166929586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 179}], {
             RGBColor[
             0.6296155322554413, 0.7083366365079169, 0.9652514491904208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 196}], {
             RGBColor[
             0.57841686270714, 0.6683398467324835, 0.9601484442886157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 231}], {
             RGBColor[
             0.6187677001172681, 0.6998622275949982, 0.9641702386616426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 237}], {
             RGBColor[
             0.49659346123710113`, 0.6021959689695906, 0.9535128028318224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 246}], {
             RGBColor[
             0.7442748265076788, 0.7964371627673539, 0.8627372814629579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 254}], {
             RGBColor[
             0.4826052869292391, 0.5908397389063968, 0.9524116025099367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 303}], {
             RGBColor[
             0.5209852083394024, 0.6219982881029236, 0.9554330105136293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 313}], {
             RGBColor[
             0.48757434214508333`, 0.5948738417840058, 0.952802784738777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 344}], {
             RGBColor[
             0.505449191337438, 0.6093854496111388, 0.9542099583449292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 349}], {
             RGBColor[
             0.46305345962080324`, 0.5743382864876063, 0.9510460393412554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.45326696998157434`, 0.5650185209976788, 0.9506554315607919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 152}], {
             RGBColor[
             0.712027429198435, 0.7738161928388188, 0.9729749124392159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 156}], {
             RGBColor[
             0.6545030297845904, 0.7282546526888585, 0.9674067541252332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 175}], {
             RGBColor[
             0.565851173376475, 0.6584224997087107, 0.9589650236307927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 204}], {
             RGBColor[
             0.7324574182535105, 0.7900490296309111, 0.9729306086733867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 256}], {
             RGBColor[
             0.40104454090204417`, 0.5166754904200316, 0.9474417583964014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 261}], {
             RGBColor[
             0.6545030297845904, 0.7282546526888585, 0.9674067541252332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 264}], {
             RGBColor[
             0.558060065259637, 0.6520973271540407, 0.9583516790600659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 317}], {
             RGBColor[
             0.6788244994432304, 0.4317798233046532, 0.5664504906640828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 333}], {
             RGBColor[
             0.7598585100037722, 0.8068648567148532, 0.7030090367619533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 381}], {
             RGBColor[
             0.7598379484327392, 0.8090576999115855, 0.8633644060737933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 389}], {
             RGBColor[
             0.47927927569541817`, 0.5875490727905104, 0.9523129126790992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 96}], {
             RGBColor[
             0.775397233469394, 0.8244654791143141, 0.9782480077992521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 110}], {
             RGBColor[
             0.6637428152765152, 0.736139647512154, 0.9678717919381932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 115}], {
             RGBColor[
             0.6335899423077558, 0.7116601868646678, 0.9654980473244794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 139}], {
             RGBColor[
             0.6696989115255975, 0.7409750747662374, 0.9683406776528205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 167}], {
             RGBColor[
             0.7058536449231512, 0.7701374991911403, 0.9713165528147472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 184}], {
             RGBColor[
             0.756723962014129, 0.8098777775313417, 0.9763868306122344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 188}], {
             RGBColor[
             0.8638996453182934, 0.8939175518924996, 0.9553371261570481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 203}], {
             RGBColor[
             0.7377877251161933, 0.7950846453459435, 0.9744994434874431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 258}], {
             RGBColor[
             0.8760398218996435, 0.901009045633954, 0.84274258998117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 284}], {
             RGBColor[
             0.8637080358655436, 0.8937746498763703, 0.9556614709808047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 325}], {
             RGBColor[
             0.8471781080300973, 0.8814466567619672, 0.9836423271105645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 348}], {
             RGBColor[
             0.8758775776505838, 0.9006620215906255, 0.8250833047264785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 351}], {
             RGBColor[
             0.5493544307925686, 0.6402443638317495, 0.9597038178570435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 369}], {
             RGBColor[
             0.8753056883221781, 0.8994388081440463, 0.7628366806213454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 95}], {
             RGBColor[
             0.6946312592904007, 0.7606834405606988, 0.9706677471783263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 151}], {
             RGBColor[
             0.8487387795511598, 0.8824534566924946, 0.9853741056470353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[
             0.6453164611082549, 0.7206474657900921, 0.9667855056193697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 229}], {
             RGBColor[
             0.6884648704753493, 0.7556772883279899, 0.970182306462579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 249}], {
             RGBColor[
             0.6587161082500047, 0.7315259029869892, 0.9678403749268931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 308}], {
             RGBColor[
             0.892406230777562, 0.9124025804773466, 0.7328794735998283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 309}], {
             RGBColor[
             0.5765271777503318, 0.6623027433598869, 0.9620604996240281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 334}], {
             RGBColor[
             0.7485445223424889, 0.8034879370938125, 0.9755715805069749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 371}], {
             RGBColor[
             0.7171962601665841, 0.7789984364263789, 0.9724470786994466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 386}], {
             RGBColor[
             0.8147128234419637, 0.8553220829009957, 0.9821286795780106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 110}], {
             RGBColor[
             0.7162763450902798, 0.7775191409296538, 0.9730176440528022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 134}], {
             RGBColor[
             0.9163429265528316, 0.9352297380673806, 0.9606357455756884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 159}], {
             RGBColor[
             0.8485670941773487, 0.8820883834295952, 0.9854182810390648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 167}], {
             RGBColor[
             0.7583871747369157, 0.8115169926086401, 0.9764624049293561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 192}], {
             RGBColor[
             0.9251130762570634, 0.941106468438476, 0.9160534189577705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 201}], {
             RGBColor[
             0.7724842898694799, 0.8225297660922424, 0.9778674736207391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 210}], {
             RGBColor[
             0.7530614646495457, 0.8073565074114908, 0.9759315879194375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 228}], {
             RGBColor[
             0.717271033062592, 0.7783266734357595, 0.9730959495336446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 236}], {
             RGBColor[
             0.8565887346464405, 0.888484621798019, 0.9861833922680099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 243}], {
             RGBColor[
             0.8223061595079122, 0.8614509893140194, 0.9828332519744551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 263}], {
             RGBColor[
             0.8991226269415904, 0.9223868668129698, 0.9897852210440724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 348}], {
             RGBColor[
             0.9284111074643485, 0.9420415150081253, 0.8302291568410873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 351}], {
             RGBColor[
             0.6018879606063332, 0.6816238572492493, 0.9648496699716524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[
             0.7451701701124382, 0.7977052353708615, 0.8854317288566093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 132}], {
             RGBColor[
             0.7401011169221174, 0.7948730385467573, 0.9364788898668277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 140}], {
             RGBColor[
             0.7477725933760258, 0.7986285169547986, 0.8311895466992393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 168}], {
             RGBColor[
             0.5120004546570118, 0.614704060305018, 0.9547256977915143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 282}], {
             RGBColor[
             0.5095052581344979, 0.6126783473607189, 0.9545292667810559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 283}], {
             RGBColor[
             0.5049230088894497, 0.6089582709956127, 0.9541685353351537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 357}], {
             RGBColor[
             0.5705333233700902, 0.662223680001981, 0.9593336196295708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 163}], {
             RGBColor[
             0.9028164111960972, 0.9179628097083248, 0.7004871718424047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 164}], {
             RGBColor[
             0.9048772049588748, 0.9234158719127674, 0.8359128089953529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 169}], {
             RGBColor[
             0.8031731539292879, 0.8461642392823975, 0.9810164519699598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 209}], {
             RGBColor[
             0.6372133771257938, 0.7137156166256242, 0.9663892230502777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 227}], {
             RGBColor[
             0.7221660436884079, 0.78268401841517, 0.9730770081539579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 245}], {
             RGBColor[
             0.6535884687768792, 0.7270096537174475, 0.9676783302489883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.8554654702928179, 0.8876306723587526, 0.9860651854767626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 292}], {
             RGBColor[
             0.8378384876668818, 0.8735753948845282, 0.9843839081381077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 304}], {
             RGBColor[
             0.57828105103016, 0.6628420594118124, 0.9625869530276914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 315}], {
             RGBColor[
             0.8032884969078264, 0.8462543460938708, 0.9810279482801191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 329}], {
             RGBColor[
             0.8840288442343256, 0.9099541450553988, 0.9731120008901383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 353}], {
             RGBColor[
             0.7424067217110866, 0.7986930405915484, 0.9749598219010447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 378}], {
             RGBColor[
             0.877216705130017, 0.9048736628652595, 0.9846431755033047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 138}], {
             RGBColor[
             0.5363436031046958, 0.6316859738761668, 0.9577273832265123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 142}], {
             RGBColor[
             0.4416624354018862, 0.5555974370475627, 0.949741880089868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 152}], {
             RGBColor[
             0.6383076460714117, 0.7119641013234308, 0.9677248698977646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 156}], {
             RGBColor[
             0.5807832466575673, 0.6664025611734704, 0.962156711583782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 175}], {
             RGBColor[
             0.49213139024945174`, 0.5965704081933226, 0.9537149810893415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 202}], {
             RGBColor[
             0.682898291345071, 0.7458741077664844, 0.9114760078269277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 242}], {
             RGBColor[
             0.6858942060737774, 0.7471129954983011, 0.8618259475934803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 256}], {
             RGBColor[
             0.327324757775021, 0.4548233989046435, 0.9421917158549502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[
             0.664756607761491, 0.7326858780515457, 0.9574920154603557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 261}], {
             RGBColor[
             0.5807832466575673, 0.6664025611734704, 0.962156711583782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 264}], {
             RGBColor[
             0.48434028213261393`, 0.5902452356386527, 0.9531016365186147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 268}], {
             RGBColor[
             0.6343265493450492, 0.7087896828578211, 0.9673451493380372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 317}], {
             RGBColor[
             0.6051047163162072, 0.3699277317892652, 0.5612004481226316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 333}], {
             RGBColor[
             0.6861387268767491, 0.7450127651994651, 0.697758994220502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 381}], {
             RGBColor[
             0.686118165305716, 0.7472056083961975, 0.858114363532342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 141}], {
             RGBColor[
             0.8783363382582163, 0.9056385393568813, 0.9791972477198924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 150}], {
             RGBColor[
             0.8555202984313998, 0.887814475635847, 0.97692315809797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 186}], {
             RGBColor[
             0.9482497315285647, 0.9609253150240669, 0.9724838852771789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 189}], {
             RGBColor[
             0.9066092923923091, 0.9281088918449709, 0.9819135139788671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 190}], {
             RGBColor[
             0.8700957861240411, 0.8992009573991477, 0.9783759064954958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 226}], {
             RGBColor[
             0.7360395832402973, 0.7926968667850304, 0.9662303156038343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 241}], {
             RGBColor[
             0.8692177163545282, 0.8985150026216269, 0.9782883887068993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 255}], {
             RGBColor[
             0.7848700736946015, 0.832339658724361, 0.9700744306843774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 266}], {
             RGBColor[
             0.9287681026042107, 0.9457777256230614, 0.9840270410782817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 273}], {
             RGBColor[
             0.8366280575514173, 0.873055713474056, 0.9750401560850821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 365}], {
             RGBColor[
             0.7993489481057032, 0.8439329898433388, 0.971324522848618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 114}], {
             RGBColor[
             0.778402648559037, 0.8271341489702893, 0.978462424588024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 153}], {
             RGBColor[
             0.8439342411174313, 0.8783942721550633, 0.9849763953784132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 161}], {
             RGBColor[
             0.8043693890551733, 0.8474195640004083, 0.9810505466076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 188}], {
             RGBColor[
             0.9152526239495529, 0.934355705842278, 0.9603703762459792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 195}], {
             RGBColor[
             0.7674714844148209, 0.8185946404609032, 0.9773729083036653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 258}], {
             RGBColor[
             0.9273928005309029, 0.9414471995837324, 0.8477758400701012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 278}], {
             RGBColor[
             0.6803231673367216, 0.7483478167225761, 0.9701676134871229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 284}], {
             RGBColor[
             0.915061014496803, 0.9342128038261488, 0.9606947210697359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 327}], {
             RGBColor[
             0.695149545792558, 0.760384538673762, 0.9713348003099802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 337}], {
             RGBColor[
             0.8091255065710468, 0.8511350791516404, 0.9815245919532294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 354}], {
             RGBColor[
             0.6925036328342424, 0.7582364673371809, 0.971126504349603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 392}], {
             RGBColor[
             0.8526180428579488, 0.8853184999474331, 0.9858046641405451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 94}], {
             RGBColor[
             0.6725705346998534, 0.7416726830688256, 0.9698934363101919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 119}], {
             RGBColor[
             0.7659804775203475, 0.8176243972911157, 0.9772145948155083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 128}], {
             RGBColor[
             0.8311734279716401, 0.8686538364742603, 0.9836439041784926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 225}], {
             RGBColor[
             0.9190304623304796, 0.938113608979577, 0.9865796515079162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 296}], {
             RGBColor[
             0.6611835953542378, 0.731809888531866, 0.9691678706041644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 301}], {
             RGBColor[
             0.8802408455269354, 0.907344172994679, 0.9884393517182801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 316}], {
             RGBColor[
             0.9439206537764886, 0.9554297147378401, 0.888605710855376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 324}], {
             RGBColor[
             0.7169676921722972, 0.7778336101447507, 0.9733561288131614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 355}], {
             RGBColor[
             0.8243512243098966, 0.863324279123038, 0.982963930674608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 380}], {
             RGBColor[
             0.9447465194407916, 0.9541039721830007, 0.7537268339294991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 383}], {
             RGBColor[
             0.7363599086546087, 0.7935770850944882, 0.9748827551306785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 390}], {
             RGBColor[
             0.9406192540920553, 0.954064501126225, 0.9433184473749417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 119}], {
             RGBColor[
             0.5424073372635212, 0.6392724228487897, 0.9571518533397876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 128}], {
             RGBColor[
             0.6076002877148139, 0.6903018620319343, 0.9635811627027719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 177}], {
             RGBColor[
             0.47882511218670143`, 0.5876535081848295, 0.9521464276723757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 200}], {
             RGBColor[
             0.31396219722151353`, 0.43435735431324973`, 0.9416658474172356]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 225}], {
             RGBColor[
             0.6954573220736533, 0.7597616345372509, 0.9665169100321955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 288}], {
             RGBColor[
             0.5586120459237043, 0.652031875220292, 0.9586984725821819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 296}], {
             RGBColor[
             0.43761045509741153`, 0.5534579140895399, 0.9491051291284436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 316}], {
             RGBColor[
             0.7203475135196623, 0.777077740295514, 0.8685429693796554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 324}], {
             RGBColor[
             0.4933945519154709, 0.5994816357024246, 0.9532933873374405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 355}], {
             RGBColor[
             0.6007780840530703, 0.684972304680712, 0.9629011891988872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 375}], {
             RGBColor[
             0.5283616018530573, 0.6278694620894056, 0.9560461215970517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 380}], {
             RGBColor[
             0.7211733791839654, 0.7757519977406747, 0.7336640924537785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 383}], {
             RGBColor[
             0.5127867683977825, 0.6152251106521622, 0.9548200136549577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 390}], {
             RGBColor[
             0.7170461138352291, 0.7757125266838989, 0.923255705899221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 129}], {
             RGBColor[
             0.7811684224624609, 0.8287064952884314, 0.9529393026135219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 151}], {
             RGBColor[
             0.7516164626566164, 0.8058937188966828, 0.9761635976429366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 178}], {
             RGBColor[
             0.5481941442137116, 0.6440877279942803, 0.957574997615271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 229}], {
             RGBColor[
             0.591342553580806, 0.679117550532178, 0.9609717984584802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 249}], {
             RGBColor[
             0.5615937913554614, 0.6549661651911773, 0.9586298669227944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 270}], {
             RGBColor[
             0.7465005290205289, 0.8018144122835857, 0.9756756353256787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 308}], {
             RGBColor[
             0.7952839138830186, 0.8358428426815347, 0.7236689655957296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 309}], {
             RGBColor[
             0.4794048608557884, 0.5857430055640751, 0.9528499916199293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 334}], {
             RGBColor[
             0.6514222054479455, 0.7269281992980007, 0.9663610725028762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 371}], {
             RGBColor[
             0.6200739432720408, 0.7024386986305671, 0.9632365706953478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 386}], {
             RGBColor[
             0.7175905065474204, 0.7787623451051838, 0.9729181715739119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 110}], {
             RGBColor[
             0.6821698715903832, 0.7505350039553629, 0.9697084287009278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 114}], {
             RGBColor[
             0.7454767262416455, 0.8010913514637197, 0.9752658112618273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 115}], {
             RGBColor[
             0.6520169986216238, 0.7260555433078766, 0.9673346840872139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 153}], {
             RGBColor[
             0.8110083188000399, 0.8523514746484937, 0.9817797820522167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 154}], {
             RGBColor[
             0.662553157200034, 0.7346092714903648, 0.968164129085727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 167}], {
             RGBColor[
             0.7242807012370193, 0.7845328556343492, 0.9731531895774816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 188}], {
             RGBColor[
             0.8823267016321615, 0.9083129083357084, 0.9571737629197827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 192}], {
             RGBColor[
             0.8910066027571668, 0.9141223314641851, 0.9127442036058961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 203}], {
             RGBColor[
             0.7562147814300613, 0.8094800017891521, 0.9763360802501777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 228}], {
             RGBColor[
             0.6831645595626954, 0.7513425364614683, 0.9697867341817703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 243}], {
             RGBColor[
             0.7881996860080156, 0.8344668523397284, 0.9795240366225808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 258}], {
             RGBColor[
             0.8944668782135115, 0.9154044020771628, 0.8445792267439045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 284}], {
             RGBColor[
             0.8821350921794117, 0.9081700063195792, 0.9574981077435393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 348}], {
             RGBColor[
             0.894304633964452, 0.9150573780338342, 0.826919941489213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 361}], {
             RGBColor[
             0.890413288341324, 0.913876980705749, 0.922576958924899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 369}], {
             RGBColor[
             0.8937327446360464, 0.9138341645872552, 0.7646733173840798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 100}], {
             RGBColor[
             0.9054485624440473, 0.9269488773587016, 0.9736732360577164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 105}], {
             RGBColor[
             0.6986376165483505, 0.7617347572866414, 0.9553141861507399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 112}], {
             RGBColor[
             0.7672114954217925, 0.8177033525931046, 0.9606304472186515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 132}], {
             RGBColor[
             0.9673329277200536, 0.9751575314978134, 0.9401810118196785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 140}], {
             RGBColor[
             0.9750044041739618, 0.9789130099058547, 0.8348916686520901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 141}], {
             RGBColor[
             0.8828827703941449, 0.9090292609997574, 0.9715013240131755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 168}], {
             RGBColor[
             0.7392322654549479, 0.7949885532560741, 0.9584278197443651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 180}], {
             RGBColor[
             0.9141351082531981, 0.9338752931969139, 0.9745017665515642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 220}], {
             RGBColor[
             0.7977904529402451, 0.842528727872922, 0.9630377347689163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 282}], {
             RGBColor[
             0.736737068932434, 0.792962840311775, 0.9582313887339067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 350}], {
             RGBColor[
             0.6342224882366045, 0.7059416107414933, 0.9512097111347768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 357}], {
             RGBColor[
             0.7977651341680263, 0.842508172953037, 0.9630357415824216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 394}], {
             RGBColor[
             0.7428627309976261, 0.7979359287342291, 0.9587136232907182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 107}], {
             RGBColor[
             0.81088955217834, 0.8528672666889265, 0.96835783225685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 131}], {
             RGBColor[
             0.9104766545096005, 0.9310741610017199, 0.9781752893451503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 215}], {
             RGBColor[
             0.6885970102925741, 0.7533088255046992, 0.9586256521565186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 283}], {
             RGBColor[
             0.7299052674968174, 0.7875650516062465, 0.9616785623694597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 297}], {
             RGBColor[
             0.9262490936971268, 0.9436506758783969, 0.9796796786750792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 307}], {
             RGBColor[
             0.6866714106356873, 0.7516409678653566, 0.9585029546491227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 352}], {
             RGBColor[
             0.7144928543712668, 0.7750525603096257, 0.9604652407506868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 123}], {
             RGBColor[
             0.6706149510908981, 0.7411188225692755, 0.9688229700572899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 174}], {
             RGBColor[
             0.5755886464636945, 0.6663278190290789, 0.9597315931817578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 187}], {
             RGBColor[
             0.5294671844860992, 0.6288843384474829, 0.9561007427463996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 193}], {
             RGBColor[
             0.721301163406672, 0.7813418588913476, 0.9737086224058116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[
             0.7645422011036809, 0.79961155966669, 0.6748142590555547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 232}], {
             RGBColor[
             0.601452210417319, 0.6870883638987777, 0.9619294744295064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 235}], {
             RGBColor[
             0.7415121701336282, 0.7974000851191143, 0.9736434319100385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 275}], {
             RGBColor[
             0.7670358159947109, 0.8156408860144853, 0.8948506079246978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 279}], {
             RGBColor[
             0.6431455577866034, 0.7196595237448389, 0.966085077648793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 281}], {
             RGBColor[
             0.7237522374718974, 0.7832962788183251, 0.9739424080382524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 306}], {
             RGBColor[
             0.39542976561255583`, 0.5086079427512361, 0.947319173762365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 338}], {
             RGBColor[
             0.7011698239407244, 0.7652896752518534, 0.9717884772760906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 384}], {
             RGBColor[
             0.47914145124474755`, 0.5869379806933053, 0.9524399930806294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 105}], {
             RGBColor[
             0.6491821483298423, 0.7227955542225606, 0.9677675296459534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 112}], {
             RGBColor[
             0.7177560272032841, 0.7787641495290236, 0.973083790713865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 141}], {
             RGBColor[
             0.8334273021756364, 0.8700900579356765, 0.9839546675083889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 168}], {
             RGBColor[
             0.6897767972364396, 0.7560493501919933, 0.9708811632395785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 170}], {
             RGBColor[
             0.8971539641172561, 0.8405777885214458, 0.6276757254704259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 180}], {
             RGBColor[
             0.8646796400346899, 0.8949360901328329, 0.9869551100467776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 220}], {
             RGBColor[
             0.7483349847217369, 0.8035895248088412, 0.9754910782641297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 271}], {
             RGBColor[
             0.8288088635809812, 0.8664820986040984, 0.9834943447110363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 273}], {
             RGBColor[
             0.7917190214688374, 0.8375072320528512, 0.9797975758735786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 282}], {
             RGBColor[
             0.6872816007139257, 0.7540236372476941, 0.9706847322291201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 350}], {
             RGBColor[
             0.5847670200180962, 0.6670024076774124, 0.9636630546299902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 394}], {
             RGBColor[
             0.6934072627791177, 0.7589967256701482, 0.9711669667859316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 151}], {
             RGBColor[
             0.7454500738415651, 0.8008875666639739, 0.9756781569271893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 171}], {
             RGBColor[
             0.6244648753101234, 0.7056800056869366, 0.9638033850584682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 182}], {
             RGBColor[
             0.5062882256964429, 0.6093628888190203, 0.9544704519823739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 244}], {
             RGBColor[
             0.7893708942812114, 0.8313786215763979, 0.7507612001280666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 253}], {
             RGBColor[
             0.642653142998193, 0.7198888186408108, 0.9656162216025898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 270}], {
             RGBColor[
             0.7403341402054776, 0.7968082600508768, 0.9751901946099313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 308}], {
             RGBColor[
             0.7891175250679673, 0.8308366904488258, 0.7231835248799823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 397}], {
             RGBColor[
             0.5591266431519342, 0.652963223135794, 0.9584356439787511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 160}], {
             RGBColor[
             0.649815797915406, 0.676405594904842, 0.6266889185040565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 166}], {
             RGBColor[
             0.5531518046989659, 0.6429946137155118, 0.9601738477090627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[
             0.44114868774106686`, 0.5540154884822945, 0.9500232916816878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 213}], {
             RGBColor[
             0.43500741060131576`, 0.5490297230388622, 0.9495398278490073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 224}], {
             RGBColor[
             0.5441106563899595, 0.6359315999412438, 0.9592727105399557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 230}], {
             RGBColor[
             0.2912046875587163, 0.42082541349623626`, 0.9399894983492967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 247}], {
             RGBColor[
             0.4059384226381245, 0.5254302090673593, 0.9472514106333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 250}], {
             RGBColor[
             0.5341528913171647, 0.628152518184559, 0.9582802135781048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 289}], {
             RGBColor[
             0.4252421064322597, 0.5411018091924831, 0.9487710673333313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 302}], {
             RGBColor[
             0.35791686486505647`, 0.48443133174658465`, 0.9440271240291129]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 340}], {
             RGBColor[
             0.6042834612328689, 0.6833588384096199, 0.9651587750840709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 370}], {
             RGBColor[
             0.42319015982064845`, 0.5394359464940356, 0.9486095305795372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 391}], {
             RGBColor[
             0.6105048728814151, 0.6883196231824502, 0.9657521788810289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 400}], {
             RGBColor[
             0.53886778876819, 0.6318358319078476, 0.9587501504928011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 108}], {
             RGBColor[
             0.6861487832229247, 0.7525344896640855, 0.9711724846903702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 133}], {
             RGBColor[
             0.8718539711434772, 0.9006567070169498, 0.9876394041525347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 143}], {
             RGBColor[
             0.798617052140955, 0.8434318459785859, 0.9803429169687011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 223}], {
             RGBColor[
             0.6724543371570268, 0.7406730487846773, 0.9702998866965743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 231}], {
             RGBColor[
             0.8319444705542789, 0.8694674785408358, 0.9836646825737088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 234}], {
             RGBColor[
             0.6266682616030731, 0.7010154514149125, 0.9673824384493133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 290}], {
             RGBColor[
             0.6002640830556104, 0.6753252019623124, 0.9658032517009377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 313}], {
             RGBColor[
             0.7007511125820941, 0.7644790927298433, 0.9722972286508431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 331}], {
             RGBColor[
             0.742318244353041, 0.7982251628794444, 0.9755695455292728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 342}], {
             RGBColor[
             0.909368152072378, 0.930569496594341, 0.9912175402188379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 346}], {
             RGBColor[
             0.7037578681758594, 0.7669201123736579, 0.972533931465293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 109}], {
             RGBColor[
             0.66140383981653, 0.7336676848732916, 0.9680794750905057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 138}], {
             RGBColor[
             0.6107836465652583, 0.6941228051776803, 0.9630341272998202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 144}], {
             RGBColor[
             0.7567956646791915, 0.808086531024728, 0.9257762002806493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 205}], {
             RGBColor[
             0.616370360941683, 0.6984871889091452, 0.9635909587780481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 207}], {
             RGBColor[
             0.6344683583302217, 0.7126254820189463, 0.9653947980223363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 233}], {
             RGBColor[
             0.6470778913009669, 0.7224761450116924, 0.9666515984260748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 358}], {
             RGBColor[
             0.7598456071297994, 0.8093477606080002, 0.87523076087603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 366}], {
             RGBColor[
             0.7548931912559533, 0.8068291632096162, 0.9362286115695722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 382}], {
             RGBColor[
             0.7212575822730765, 0.7811864901018144, 0.9738432951375899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 112}], {
             RGBColor[
             0.5109450813075875, 0.6135500294569636, 0.9547247408068884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 113}], {
             RGBColor[
             0.7161355667961694, 0.7738364051857766, 0.883228144397697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 148}], {
             RGBColor[
             0.7183940753511489, 0.774024087983112, 0.7915529686038908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 155}], {
             RGBColor[
             0.711142283604687, 0.771060717502744, 0.9341470465638629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 168}], {
             RGBColor[
             0.48296585134074294`, 0.5908352301199331, 0.9525221133326021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 170}], {
             RGBColor[
             0.6903430182215594, 0.6753636684493857, 0.6093166755634494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 180}], {
             RGBColor[
             0.6578686941389932, 0.7297219700607729, 0.9685960601398012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 239}], {
             RGBColor[
             0.5152775879216847, 0.6170673535034864, 0.9550658115980448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 271}], {
             RGBColor[
             0.6219979176852846, 0.7012679785320384, 0.9651352948040597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 282}], {
             RGBColor[
             0.48047065481822904`, 0.588809517175634, 0.9523256823221437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 326}], {
             RGBColor[
             0.5245070038156747, 0.6245602091066753, 0.9557923850256841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 350}], {
             RGBColor[
             0.37795607412239957`, 0.5017882876053523, 0.9453040047230138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 394}], {
             RGBColor[
             0.4865963168834211, 0.5937826055980882, 0.9528079168789552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.7669603152655569, 0.8182185109486086, 0.9773158032497379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 173}], {
             RGBColor[
             0.877373163414257, 0.9050575611191864, 0.9881658296383629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 197}], {
             RGBColor[
             0.8425476258532894, 0.8772886227821052, 0.9848441387766733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 204}], {
             RGBColor[
             0.9002372679271378, 0.9232312955050286, 0.9883536939778597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 214}], {
             RGBColor[
             0.9126983654270229, 0.9325247616172685, 0.9672603062852942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 215}], {
             RGBColor[
             0.644667773379791, 0.7186600697643815, 0.9675836231494064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 295}], {
             RGBColor[
             0.8454015498321605, 0.8795642642951543, 0.985116348593506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 310}], {
             RGBColor[
             0.7195612974041949, 0.7801823284695635, 0.9732804885933166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 345}], {
             RGBColor[
             0.9242611372525193, 0.9287952201894719, 0.6933853954632037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 363}], {
             RGBColor[
             0.6250571786526464, 0.701674358268879, 0.9663340533943608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 131}], {
             RGBColor[
             0.770961280406522, 0.8214087719487086, 0.9776974188765869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 197}], {
             RGBColor[
             0.746961488662994, 0.8022719894694118, 0.9754082973152222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 215}], {
             RGBColor[
             0.5490816361894957, 0.6436434364516881, 0.9581477816879553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 297}], {
             RGBColor[
             0.7867337195940484, 0.8339852868253856, 0.9792018082065158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 307}], {
             RGBColor[
             0.5471560365326087, 0.6419755788123455, 0.9580250841805593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 352}], {
             RGBColor[
             0.5749774802681883, 0.6653871712566144, 0.9599873702821236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 363}], {
             RGBColor[
             0.5294710414623511, 0.6266577249561857, 0.9568982119329097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 143}], {
             RGBColor[
             0.5624799516879613, 0.6550965905101505, 0.9590657566680925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 179}], {
             RGBColor[
             0.6066552022394582, 0.6896066319853191, 0.9634687328018783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 196}], {
             RGBColor[
             0.555456532691157, 0.6496098422098856, 0.9583657279000732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 231}], {
             RGBColor[
             0.5958073701012851, 0.6811322230724004, 0.9623875222731002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 234}], {
             RGBColor[
             0.3905311611500793, 0.5126801959464771, 0.9461052781487047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 290}], {
             RGBColor[
             0.36412698260261667`, 0.48698994649387695`, 0.9445260914003291]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 313}], {
             RGBColor[
             0.4646140121291003, 0.5761438372614078, 0.9510200683502344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 331}], {
             RGBColor[
             0.5061811439000471, 0.609889907411009, 0.9542923852286642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 342}], {
             RGBColor[
             0.6732310516193841, 0.7422342411259055, 0.9699403799182293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 344}], {
             RGBColor[
             0.482488861321455, 0.590655445088541, 0.9524272419563866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 136}], {
             RGBColor[
             0.8805429040132648, 0.9069924008153452, 0.960691660953772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 205}], {
             RGBColor[
             0.7493469269825366, 0.8041147816971188, 0.9756515567025972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 207}], {
             RGBColor[
             0.7674449243710754, 0.8182530748069199, 0.9774553959468855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 233}], {
             RGBColor[
             0.7800544573418204, 0.8281037377996661, 0.978712196350624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 286}], {
             RGBColor[
             0.7883549018842513, 0.834588108161928, 0.9795395070905492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 320}], {
             RGBColor[
             0.6029753493122537, 0.6850992559784621, 0.9637929730131121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 343}], {
             RGBColor[
             0.8938282115784076, 0.913660841750356, 0.7448271177742072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 358}], {
             RGBColor[
             0.892822173170653, 0.9149753533959739, 0.8872913588005791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 366}], {
             RGBColor[
             0.887869757296807, 0.9124567559975898, 0.9482892094941213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 382}], {
             RGBColor[
             0.8542341483139301, 0.886814082889788, 0.985903893062139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 115}], {
             RGBColor[
             0.540362580428745, 0.6377297117057166, 0.956958468226155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 134}], {
             RGBColor[
             0.770582034860056, 0.8199197694909296, 0.9469503143627552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 167}], {
             RGBColor[
             0.6126262830441405, 0.696207024032189, 0.9627769737164229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 192}], {
             RGBColor[
             0.779352184564288, 0.825796499862025, 0.9023679877448372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 203}], {
             RGBColor[
             0.6445603632371825, 0.7211541701869921, 0.9659598643891187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 243}], {
             RGBColor[
             0.6765452678151368, 0.7461410207375683, 0.9691478207615218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 348}], {
             RGBColor[
             0.7826502157715731, 0.8267315464316742, 0.8165437256281541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 351}], {
             RGBColor[
             0.4561270689135578, 0.5663138886727982, 0.9511642387587191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 369}], {
             RGBColor[
             0.7820783264431674, 0.8255083329850951, 0.7542971015230211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 160}], {
             RGBColor[
             0.9528603146056854, 0.9218080310762438, 0.6462623637372363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 166}], {
             RGBColor[
             0.8561963213892454, 0.8883970498869136, 0.9797472929422426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.7441932044313464, 0.7994179246536963, 0.9695967369148677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 197}], {
             RGBColor[
             0.8826419666962199, 0.9090773193125928, 0.9823776465289639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[
             0.8419123054584694, 0.8772382680792495, 0.978323595725981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 155}], {
             RGBColor[
             0.7797161624781288, 0.8270293128092071, 0.9394633076317745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 170}], {
             RGBColor[
             0.7589168970950013, 0.7313322637558488, 0.614632936631361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 180}], {
             RGBColor[
             0.7264425730124351, 0.7856905653672359, 0.9739123212077128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 183}], {
             RGBColor[
             0.7518245217763773, 0.8059294423369583, 0.9763332741395507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 271}], {
             RGBColor[
             0.6905717965587264, 0.7572365738385014, 0.9704515558719713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 273}], {
             RGBColor[
             0.6534819544465826, 0.7282617072872541, 0.9667547870345137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 326}], {
             RGBColor[
             0.5930808826891165, 0.6805288044131385, 0.9611086460935957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 350}], {
             RGBColor[
             0.4465299529958414, 0.5577568829118155, 0.9506202657909254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 394}], {
             RGBColor[
             0.5551701957568629, 0.6497512009045512, 0.9581241779468668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 148}], {
             RGBColor[
             0.9921584397131726, 0.9902790590183881, 0.7253726332626109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 168}], {
             RGBColor[
             0.7567302157027667, 0.8070902011552092, 0.8863417779913222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 170}], {
             RGBColor[
             0.9641073825835832, 0.8916186394846618, 0.5431363402221696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 251}], {
             RGBColor[
             0.9102054488384137, 0.9288911467880587, 0.9003719402602492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 282}], {
             RGBColor[
             0.7542350191802528, 0.8050644882109101, 0.8861453469808638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 153}], {
             RGBColor[
             0.7626607552584233, 0.8145819905546905, 0.9769609487520574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 154}], {
             RGBColor[
             0.6142055936584174, 0.6968397873965617, 0.9633452957855677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 188}], {
             RGBColor[
             0.833979138090545, 0.8705434242419052, 0.9523549296196234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 203}], {
             RGBColor[
             0.7078672178884448, 0.771710517695349, 0.9715172469500184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 222}], {
             RGBColor[
             0.616763429578814, 0.6989163538259346, 0.963546657998883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 258}], {
             RGBColor[
             0.8461193146718949, 0.8776349179833596, 0.8397603934437453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 312}], {
             RGBColor[
             0.6747060530401195, 0.74580476368165, 0.968212051946642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 327}], {
             RGBColor[
             0.61387605993355, 0.6965722570733892, 0.9633193536836243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 356}], {
             RGBColor[
             0.7221865658442641, 0.7828969011495104, 0.9729444657323397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 361}], {
             RGBColor[
             0.8420657247997075, 0.8761074966119459, 0.9177581256247398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 369}], {
             RGBColor[
             0.8453851810944297, 0.876064680493452, 0.7598544840839206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 392}], {
             RGBColor[
             0.7713445569989408, 0.8215062183470603, 0.9777892175141893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 184}], {
             RGBColor[
             0.6333437271663587, 0.7114678417249041, 0.9654735069001963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 188}], {
             RGBColor[
             0.7405194104705233, 0.7955076160860621, 0.94442380244501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 195}], {
             RGBColor[
             0.5927382709357911, 0.6797465507046874, 0.9614263345026961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 203}], {
             RGBColor[
             0.614407490268423, 0.6966747095395058, 0.963586119775405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 206}], {
             RGBColor[
             0.6672399947692312, 0.7379825080197902, 0.9688427765117478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 208}], {
             RGBColor[
             0.7517627094005743, 0.8023770700832438, 0.857512107640649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 258}], {
             RGBColor[
             0.7526595870518732, 0.8025991098275165, 0.8318292662691318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 284}], {
             RGBColor[
             0.7403278010177734, 0.7953647140699329, 0.9447481472687665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 325}], {
             RGBColor[
             0.723797873182327, 0.7830367209555298, 0.9727290033985264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 369}], {
             RGBColor[
             0.751925453474408, 0.8010288723376089, 0.7519233569093071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 392}], {
             RGBColor[
             0.677884829378919, 0.7464704101912172, 0.9698580903395758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 121}], {
             RGBColor[
             0.6608971323150745, 0.7263274280576877, 0.8920500192507654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 130}], {
             RGBColor[
             0.6404090244026012, 0.7117492294982299, 0.9581590248165864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 135}], {
             RGBColor[
             0.5965270824230586, 0.6770617286428057, 0.9644707012060036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 147}], {
             RGBColor[
             0.33738380066335427`, 0.46664662355688435`, 0.9427187753348562]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 172}], {
             RGBColor[
             0.6593159059017297, 0.7256735503001044, 0.9182550330026726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 265}], {
             RGBColor[
             0.4584360828719493, 0.5679614388662015, 0.9514087367102926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 276}], {
             RGBColor[
             0.6552074364080094, 0.7227858609416875, 0.9331091733354254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 322}], {
             RGBColor[
             0.6518011526414276, 0.6871993277533535, 0.6406454454963408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 328}], {
             RGBColor[
             0.5398528182562399, 0.6324665459893805, 0.9589070751051285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 362}], {
             RGBColor[
             0.5004474717910234, 0.601682789839028, 0.9549795184333751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 364}], {
             RGBColor[
             0.4983132607448245, 0.6000155279491326, 0.9547668002216263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 387}], {
             RGBColor[
             0.471435729558509, 0.5785151376737602, 0.9524321165167333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 223}], {
             RGBColor[
             0.5103183178210788, 0.6125049789423163, 0.9548235576796156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 346}], {
             RGBColor[
             0.5416218488399114, 0.6387520425312968, 0.9570576024483343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 371}], {
             RGBColor[
             0.6203263945761233, 0.702643649972023, 0.9632564445867648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 126}], {
             RGBColor[
             0.5627709039261921, 0.6559217982044137, 0.9587225335362677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 149}], {
             RGBColor[
             0.7172900355216658, 0.6180658684988316, 0.59376822120722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[
             0.5619645068914207, 0.6552671287638138, 0.9586590510077608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 212}], {
             RGBColor[
             0.7574624861441147, 0.8092647610503101, 0.9458110745489798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 259}], {
             RGBColor[
             0.7167898363336391, 0.7777378468385592, 0.9732861573265006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 293}], {
             RGBColor[
             0.691365346678223, 0.46915777003415404`, 0.5709146976522236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 299}], {
             RGBColor[
             0.5054531057210774, 0.6093886274841183, 0.9542102664995481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 336}], {
             RGBColor[
             0.6653845242520353, 0.7370183729847932, 0.9683114956131503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 367}], {
             RGBColor[
             0.745490347540014, 0.8003359596819497, 0.9660767823718864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 200}], {
             RGBColor[
             0.4073721400420077, 0.5103090685355399, 0.948987005922552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 225}], {
             RGBColor[
             0.7888672648941475, 0.8357133487595412, 0.9738380685375119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 288}], {
             RGBColor[
             0.6520219887441985, 0.7279835894425822, 0.9660196310874982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 296}], {
             RGBColor[
             0.5310203979179057, 0.6294096283118301, 0.9564262876337601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 316}], {
             RGBColor[
             0.8137574563401564, 0.8530294545178042, 0.8758641278849717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 324}], {
             RGBColor[
             0.586804494735965, 0.6754333499247149, 0.9606145458427571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 355}], {
             RGBColor[
             0.6941880268735645, 0.7609240189030022, 0.9702223477042037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 375}], {
             RGBColor[
             0.6217715446735514, 0.7038211763116958, 0.9633672801023683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 380}], {
             RGBColor[
             0.8145833220044596, 0.8517037119629649, 0.7409852509590948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 383}], {
             RGBColor[
             0.6061967112182766, 0.6911768248744523, 0.9621411721602742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 390}], {
             RGBColor[
             0.8104560566557233, 0.8516642409061892, 0.9305768644045375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 136}], {
             RGBColor[
             0.9251169510542671, 0.942327591675796, 0.9649980900117763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 237}], {
             RGBColor[
             0.6903915398058467, 0.7563491770402513, 0.971158889813931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 246}], {
             RGBColor[
             0.9380729050764243, 0.9505903708380146, 0.8803833684450665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 254}], {
             RGBColor[
             0.6764033654979846, 0.7449929469770575, 0.9700576894920452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 286}], {
             RGBColor[
             0.8329289489252536, 0.8699232990223789, 0.9838459361485534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 320}], {
             RGBColor[
             0.647549396353256, 0.720434446838913, 0.9680994020711163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 343}], {
             RGBColor[
             0.9384022586194098, 0.9489960326108069, 0.7491335468322116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 349}], {
             RGBColor[
             0.6568515381895488, 0.7284914945582668, 0.9686921263233639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 130}], {
             RGBColor[
             0.9679281262896033, 0.9748996308409683, 0.9077455128697244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 158}], {
             RGBColor[
             0.8448796303969408, 0.8780457996345747, 0.9062517419187535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 181}], {
             RGBColor[
             0.7786631594706546, 0.8251918455779048, 0.900421169821167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 250}], {
             RGBColor[
             0.8600379580376261, 0.8898876003950351, 0.9077625823553512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 265}], {
             RGBColor[
             0.7859551847589515, 0.8311118402089399, 0.9009952247634305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 322}], {
             RGBColor[
             0.9793202545284299, 0.9503497290960918, 0.5902319335494788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 362}], {
             RGBColor[
             0.8279665736780257, 0.8648331911817664, 0.9045660064865131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 146}], {
             RGBColor[
             0.6248844883991439, 0.695782773075788, 0.9461489352954624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.8975796704181326, 0.9205414165876263, 0.9683108118884951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 165}], {
             RGBColor[
             0.682706483004897, 0.7476256023558138, 0.9497688475853625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 210}], {
             RGBColor[
             0.8020740408903295, 0.8458095405695218, 0.9588241187688678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 228}], {
             RGBColor[
             0.7662836093033758, 0.8167797065937905, 0.9559884803830749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 262}], {
             RGBColor[
             0.7136117464953406, 0.7740183155258489, 0.9518419583994355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 298}], {
             RGBColor[
             0.8886906946323114, 0.5519310879110837, 0.5583530684822979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 314}], {
             RGBColor[
             0.7544797552293824, 0.8071968060989565, 0.955059237751428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 385}], {
             RGBColor[
             0.751252962779329, 0.8045771506226598, 0.9548052128296296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 174}], {
             RGBColor[
             0.7011073406857594, 0.765873918108881, 0.9712234426635008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 187}], {
             RGBColor[
             0.6549858787081642, 0.728430437527285, 0.9675925922281425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 193}], {
             RGBColor[
             0.846819857628737, 0.8808879579711495, 0.9852004718875544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 218}], {
             RGBColor[
             0.8900608953257458, 0.899157658746492, 0.6863061085372977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 232}], {
             RGBColor[
             0.726970904639384, 0.7866344629785796, 0.9734213239112492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 235}], {
             RGBColor[
             0.8670308643556932, 0.8969461841989164, 0.9851352813917815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 275}], {
             RGBColor[
             0.8925545102167759, 0.9151869850942872, 0.9063424574064408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 279}], {
             RGBColor[
             0.7686642520086684, 0.8192056228246409, 0.977576927130536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 281}], {
             RGBColor[
             0.8492709316939624, 0.8828423778981271, 0.9854342575199954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 306}], {
             RGBColor[
             0.5209484598346208, 0.6081540418310382, 0.9588110232441078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 338}], {
             RGBColor[
             0.8266885181627893, 0.8648357743316555, 0.9832803267578336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.7502547995166352, 0.8042983238809023, 0.9689829220094728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 199}], {
             RGBColor[
             0.5681577579908457, 0.6602950890091095, 0.959146606420934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 238}], {
             RGBColor[
             0.4957181728409742, 0.6009851057882307, 0.9535821215308258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 252}], {
             RGBColor[
             0.7501512693188895, 0.8042211112289386, 0.9691581716292561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 277}], {
             RGBColor[
             0.7648864495909743, 0.8152105845492161, 0.9442153549791346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 293}], {
             RGBColor[
             0.697558597777648, 0.4741857302794498, 0.5714022530653966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 330}], {
             RGBColor[
             0.766427357235978, 0.8163597909478552, 0.9416070002692223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 179}], {
             RGBColor[
             0.8148571019385634, 0.8556671166534278, 0.9820814087165329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 196}], {
             RGBColor[
             0.7636584323902622, 0.8156703268779943, 0.9769784038147278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 303}], {
             RGBColor[
             0.7062267780225244, 0.7693287682484344, 0.9722629700397414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 313}], {
             RGBColor[
             0.6728159118282054, 0.7422043219295167, 0.9696327442648891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 344}], {
             RGBColor[
             0.6906907610205602, 0.7567159297566497, 0.9710399178710413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 149}], {
             RGBColor[
             0.7359047337660395, 0.6331781191162136, 0.5952336384409035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 199}], {
             RGBColor[
             0.5805792051357943, 0.6703793793811959, 0.9601244682414444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 212}], {
             RGBColor[
             0.7760771843884884, 0.8243770116676922, 0.9472764917826634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 238}], {
             RGBColor[
             0.5081396199859228, 0.611069396160317, 0.9545599833513363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 259}], {
             RGBColor[
             0.7354045345780127, 0.7928500974559411, 0.9747515745601842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 274}], {
             RGBColor[
             0.7048211246895173, 0.7684637165754011, 0.9718345016228871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 299}], {
             RGBColor[
             0.524067803965451, 0.6245008781015002, 0.9556756837332316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 318}], {
             RGBColor[
             0.5932058995853354, 0.6806302987614359, 0.961118487881618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 336}], {
             RGBColor[
             0.6839992224964089, 0.7521306236021753, 0.9697769128468339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 367}], {
             RGBColor[
             0.7641050457843876, 0.8154482102993317, 0.96754219960557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 139}], {
             RGBColor[
             0.6171964663196593, 0.6999597655379959, 0.9631077245779384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 184}], {
             RGBColor[
             0.7042215168081908, 0.7688624683031002, 0.9711538775373523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 305}], {
             RGBColor[
             0.5271610104241686, 0.6254812085419011, 0.9564021290435911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 325}], {
             RGBColor[
             0.7946756628241591, 0.8404313475337257, 0.9784093740356825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 177}], {
             RGBColor[
             0.6374280054584882, 0.7146346615902643, 0.9658968955406764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 225}], {
             RGBColor[
             0.8540602153454402, 0.8867427879426857, 0.9802673779004962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 296}], {
             RGBColor[
             0.5962133483691983, 0.6804390674949747, 0.9628555969967444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 311}], {
             RGBColor[
             0.8362843053382012, 0.7418800882839909, 0.6104246306474417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 316}], {
             RGBColor[
             0.8789504067914491, 0.9040588937009488, 0.8822934372479561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 324}], {
             RGBColor[
             0.6519974451872577, 0.7264627891078594, 0.9670438552057413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 380}], {
             RGBColor[
             0.8797762724557522, 0.9027331511461094, 0.7474145603220792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 383}], {
             RGBColor[
             0.6713896616695691, 0.7422062640575969, 0.9685704815232585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 390}], {
             RGBColor[
             0.8756490071070159, 0.9026936800893337, 0.9370061737675217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 178}], {
             RGBColor[
             0.7318536242803151, 0.7886705205178248, 0.9490570610545654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 229}], {
             RGBColor[
             0.7750020336474095, 0.8237003430557224, 0.9524538618977745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 249}], {
             RGBColor[
             0.7452532714220649, 0.7995489577147218, 0.9501119303620887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 270}], {
             RGBColor[
             0.9301600090871325, 0.9463972048071303, 0.967157698764973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 308}], {
             RGBColor[
             0.9789433939496222, 0.9804256352050792, 0.715151029035024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 309}], {
             RGBColor[
             0.663064340922392, 0.7303257980876197, 0.9443320550592236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 397}], {
             RGBColor[
             0.7489525120335889, 0.8025521678920474, 0.9504031481337928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 135}], {
             RGBColor[
             0.9035580763975875, 0.9256339314260862, 0.9801661948249626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 147}], {
             RGBColor[
             0.6444147946378831, 0.715218826340165, 0.9584142689538151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 158}], {
             RGBColor[
             0.8243915224844673, 0.863467601075117, 0.9723607474845744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 172}], {
             RGBColor[
             0.9663468998762585, 0.9742457530833849, 0.9339505266216316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 181}], {
             RGBColor[
             0.7581750515581811, 0.8106136470184471, 0.9665301753869879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 265}], {
             RGBColor[
             0.7654670768464782, 0.8165336416494822, 0.9671042303292514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 322}], {
             RGBColor[
             0.9588321466159564, 0.9357715305366341, 0.6563409391152997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 328}], {
             RGBColor[
             0.8468838122307687, 0.881038748772661, 0.9746025687240876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 347}], {
             RGBColor[
             0.8694814543024985, 0.8986921985075371, 0.9768548904988259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 362}], {
             RGBColor[
             0.8074784657655523, 0.8502549926223086, 0.9706750120523342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 364}], {
             RGBColor[
             0.8053442547193533, 0.8485877307324132, 0.9704622938405851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 387}], {
             RGBColor[
             0.7784667235330378, 0.8270873404570407, 0.9681276101356924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 215}], {
             RGBColor[
             0.6486687385207561, 0.7218503307644815, 0.9679652387762554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 217}], {
             RGBColor[
             0.9213935361665025, 0.9392159534666843, 0.95969585627876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 262}], {
             RGBColor[
             0.6688547432319205, 0.7389585607455162, 0.9693553278995811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 269}], {
             RGBColor[
             0.6363793518669704, 0.7112058817275053, 0.9671821699257541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 279}], {
             RGBColor[
             0.8058716207210781, 0.8486809951308532, 0.9811769553434632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 297}], {
             RGBColor[
             0.8863208219253088, 0.912192181138179, 0.989019265294816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 300}], {
             RGBColor[
             0.8964171332068505, 0.9202427056970115, 0.9899822604779329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 306}], {
             RGBColor[
             0.5581558285470305, 0.6376294141372504, 0.962411051457035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 307}], {
             RGBColor[
             0.6467431388638691, 0.7201824731251388, 0.9678425412688596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 314}], {
             RGBColor[
             0.7097227519659621, 0.7721370513186239, 0.9725726072515736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 352}], {
             RGBColor[
             0.6745645825994487, 0.7435940655694078, 0.9698048273704236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 363}], {
             RGBColor[
             0.6290581437936116, 0.704864619268979, 0.9667156690212099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 140}], {
             RGBColor[
             0.98743330123146, 0.9881824609808857, 0.8138527879092656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 191}], {
             RGBColor[
             0.9832184892962245, 0.9865924152447232, 0.894816423083965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 198}], {
             RGBColor[
             0.9864383598058482, 0.986054381875511, 0.7055595537981556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 216}], {
             RGBColor[
             0.963209238417292, 0.9720820907677352, 0.9471613421788334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 219}], {
             RGBColor[
             0.872416450865328, 0.9004127948674683, 0.9481804620489909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 220}], {
             RGBColor[
             0.8102193499977433, 0.851798178947953, 0.941998854026092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 302}], {
             RGBColor[
             0.6794747268732553, 0.7436409905432699, 0.9322623046928348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 323}], {
             RGBColor[
             0.654242066605047, 0.7217857284493284, 0.9306545018929099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 357}], {
             RGBColor[
             0.8101940312255245, 0.851777624028068, 0.9419968608395972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 145}], {
             RGBColor[
             0.9081266016265315, 0.9258981674395721, 0.8308046699777497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 164}], {
             RGBColor[
             0.9081765254490383, 0.9260049494478413, 0.8362385699634916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 223}], {
             RGBColor[
             0.6220224246245856, 0.7004600106691062, 0.9654896458581302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 234}], {
             RGBColor[
             0.5762363490706317, 0.6608024132993413, 0.9625721976108692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 280}], {
             RGBColor[
             0.8587647907829814, 0.8902197498938264, 0.9863909464449014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 346}], {
             RGBColor[
             0.6533259556434181, 0.7267070742580868, 0.9677236906268489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 167}], {
             RGBColor[
             0.8126928645066921, 0.8539176211699159, 0.9503950752393091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 201}], {
             RGBColor[
             0.8267899796392562, 0.8649303946535182, 0.9518001439306922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 236}], {
             RGBColor[
             0.9108944244162168, 0.9308852503592948, 0.960116062577963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 243}], {
             RGBColor[
             0.8766118492776884, 0.9038516178752951, 0.9567659222844083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 263}], {
             RGBColor[
             0.9534283167113666, 0.9647874953742455, 0.9637178913540254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 348}], {
             RGBColor[
             0.9827167972341249, 0.9844421435694011, 0.8041618271510405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 351}], {
             RGBColor[
             0.6561936503761094, 0.724024485810525, 0.9387823402816056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 221}], {
             RGBColor[
             0.9250811052635144, 0.9352579363450074, 0.7020092513809499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 276}], {
             RGBColor[
             0.9183564884029958, 0.936670562869544, 0.9551163433438016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 322}], {
             RGBColor[
             0.9149502046364139, 0.9010840296812098, 0.662652615504717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 364}], {
             RGBColor[
             0.7614623127398108, 0.8139002298769891, 0.9767739702300025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 376}], {
             RGBColor[
             0.8436272667435545, 0.8781494991219312, 0.9849471158885936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 377}], {
             RGBColor[
             0.9248182355412242, 0.9405313930104418, 0.9012623023542263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 194}], {
             RGBColor[
             0.9510960827354811, 0.9630426460936525, 0.9674760027833752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 237}], {
             RGBColor[
             0.7319799909207256, 0.7887111093338803, 0.9474040486946437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 246}], {
             RGBColor[
             0.9796613561913032, 0.9829523031316436, 0.8566285273257792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 254}], {
             RGBColor[
             0.7179918166128636, 0.7773548792706866, 0.946302848372758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 286}], {
             RGBColor[
             0.8745174000401326, 0.902285231316008, 0.9600910950292663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 320}], {
             RGBColor[
             0.689137847468135, 0.752796379132542, 0.9443445609518291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 343}], {
             RGBColor[
             0.9799907097342888, 0.9813579649044359, 0.7253787057129243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 349}], {
             RGBColor[
             0.6984399893044277, 0.7608534268518959, 0.9449372852040767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 376}], {
             RGBColor[
             0.897141900619105, 0.9200210458213128, 0.9623298047276483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 199}], {
             RGBColor[
             0.7618698496268124, 0.8137279448123886, 0.9698973013014764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 238}], {
             RGBColor[
             0.6894302644769409, 0.7544179615915099, 0.9643328164113683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 252}], {
             RGBColor[
             0.9438633609548562, 0.9576539670322177, 0.9799088665097986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 277}], {
             RGBColor[
             0.958598541226941, 0.9686434403524953, 0.954966049859677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 285}], {
             RGBColor[
             0.9687400223275393, 0.9731323979418964, 0.7575292958449013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 293}], {
             RGBColor[
             0.8912706894136146, 0.6276185860827289, 0.5821529479459391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 330}], {
             RGBColor[
             0.9601394488719447, 0.9697926467511342, 0.9523576951497648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 144}], {
             RGBColor[
             0.8391520374687734, 0.8741692441170905, 0.932791450414513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 233}], {
             RGBColor[
             0.7294342640905489, 0.7885588581040548, 0.9736668485599385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 242}], {
             RGBColor[
             0.8426906223239219, 0.875632539892177, 0.8741479418006519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 256}], {
             RGBColor[
             0.4841211740251655, 0.5833429432985194, 0.9545137100621217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 257}], {
             RGBColor[
             0.8215530240116357, 0.8612054224454215, 0.9698140096675272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 317}], {
             RGBColor[
             0.7619011325663517, 0.4984472761831411, 0.5735224423298031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 366}], {
             RGBColor[
             0.8372495640455353, 0.8729118763019785, 0.9432438617034358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 381}], {
             RGBColor[
             0.8429145815558605, 0.8757251527900735, 0.8704363577395136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 382}], {
             RGBColor[
             0.8036139550626584, 0.8472692031941768, 0.9808585452714534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 184}], {
             RGBColor[
             0.6694526963842005, 0.7407827296264736, 0.9683161372285374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 305}], {
             RGBColor[
             0.49239219000017825`, 0.5974014698652745, 0.953564388734776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 325}], {
             RGBColor[
             0.7599068424001687, 0.8123516088570992, 0.9755716337268675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 141}], {
             RGBColor[
             0.9029831439055511, 0.9220541904828298, 0.8451731001027626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 168}], {
             RGBColor[
             0.7593326389663542, 0.8080134827391465, 0.8320995958339522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 191}], {
             RGBColor[
             0.9908899657501327, 0.9903478936527648, 0.7895270799163765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 216}], {
             RGBColor[
             0.9708807148712002, 0.9758375691757767, 0.8418719990112449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 219}], {
             RGBColor[
             0.8800879273192362, 0.9041682732755097, 0.8428911188814023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 220}], {
             RGBColor[
             0.8178908264516515, 0.8555536573559943, 0.8367095108585034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 350}], {
             RGBColor[
             0.6543228617480108, 0.7189665402245657, 0.8248814872243639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 357}], {
             RGBColor[
             0.8178655076794327, 0.8555331024361095, 0.8367075176720087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 150}], {
             RGBColor[
             0.7880454702989175, 0.8343463778556981, 0.9795086658419256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 189}], {
             RGBColor[
             0.8391344642598269, 0.874640794064822, 0.9844990217228227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 219}], {
             RGBColor[
             0.7879662935394192, 0.8342845243694124, 0.9795007742424877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 220}], {
             RGBColor[
             0.7257691926718344, 0.785669908449897, 0.9733191662195888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 273}], {
             RGBColor[
             0.7691532294189349, 0.819587615693907, 0.9776256638290377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 339}], {
             RGBColor[
             0.6903808149958144, 0.7569400292242574, 0.9705332634970338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 350}], {
             RGBColor[
             0.5622012279681938, 0.6490827913184682, 0.9614911425854493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 357}], {
             RGBColor[
             0.7257438738996156, 0.7856493535300121, 0.9733171730330941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 394}], {
             RGBColor[
             0.6708414707292153, 0.7410771093112041, 0.9689950547413907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 202}], {
             RGBColor[
             0.745013539892406, 0.7983051153317564, 0.915812498897455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 214}], {
             RGBColor[
             0.7333139811737075, 0.7899214117930348, 0.9509236695098975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 217}], {
             RGBColor[
             0.7380081867722219, 0.7934223426423506, 0.9429776038765141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 257}], {
             RGBColor[
             0.7268718563088261, 0.7851168856168176, 0.961828506530883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 268}], {
             RGBColor[
             0.6964417978923841, 0.761220690423093, 0.9716816404085645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 275}], {
             RGBColor[
             0.746376529534905, 0.7988687465761658, 0.8932242332171221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 279}], {
             RGBColor[
             0.6224862713267973, 0.7028873843065195, 0.9644587029412173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 300}], {
             RGBColor[
             0.7130317838125699, 0.7744490948726779, 0.9732640080756871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 306}], {
             RGBColor[
             0.37477047915274986`, 0.49183580331291676`, 0.9456927990547892]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 338}], {
             RGBColor[
             0.6805105374809184, 0.7485175358135341, 0.9701621025685149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 363}], {
             RGBColor[
             0.44567279439933094`, 0.5590710084446453, 0.949997416618964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 381}], {
             RGBColor[
             0.7482334138530511, 0.7996366159614694, 0.8624508546028693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 223}], {
             RGBColor[
             0.5487855056220634, 0.6432351496307422, 0.9581931586742967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 234}], {
             RGBColor[
             0.5029994300681095, 0.6035775522609773, 0.9552757104270356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 260}], {
             RGBColor[
             0.6499741074568774, 0.7262180619946992, 0.9659288122150987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 267}], {
             RGBColor[
             0.8349481418167156, 0.8687983447032757, 0.8298711051516743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 272}], {
             RGBColor[
             0.6272335903935105, 0.7077562857940387, 0.9641385954106118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 290}], {
             RGBColor[
             0.47659525152064686`, 0.5778873028083773, 0.9536965236786601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 291}], {
             RGBColor[
             0.8344035602943629, 0.8676335398926014, 0.7705967672111722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 321}], {
             RGBColor[
             0.7346643132316875, 0.792644612242958, 0.9741881309807392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 331}], {
             RGBColor[
             0.6186494128180773, 0.7007872637255093, 0.9634628175069951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 342}], {
             RGBColor[
             0.7856993205374143, 0.8331315974404059, 0.9791108121965604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 398}], {
             RGBColor[
             0.7332355554169292, 0.7915284557791074, 0.974045725754265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 207}], {
             RGBColor[
             0.8628367492337369, 0.8926719209583565, 0.935152121137029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 233}], {
             RGBColor[
             0.875446282204482, 0.9025225839511026, 0.9364089215407676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 242}], {
             RGBColor[
             0.9887026404378549, 0.9895962657392248, 0.836890014781481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 317}], {
             RGBColor[
             0.9079131506802849, 0.612411002030189, 0.5362645153106322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 358}], {
             RGBColor[
             0.9882139980333146, 0.9893941995474104, 0.8449880839907227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 366}], {
             RGBColor[
             0.9832615821594685, 0.9868756021490264, 0.9059859346842648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 370}], {
             RGBColor[
             0.7474491372314247, 0.8004985989863679, 0.9250404074025029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 391}], {
             RGBColor[
             0.9347638502921914, 0.9493822756747825, 0.9421830557039947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 162}], {
             RGBColor[
             0.9495446222096617, 0.824737483115679, 0.4603011001261134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 164}], {
             RGBColor[
             0.994881068464534, 0.9914594479860346, 0.6842140766271507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 227}], {
             RGBColor[
             0.8121699071940671, 0.8507275944884372, 0.8213782757857557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 280}], {
             RGBColor[
             0.9454693337984771, 0.9556742484320198, 0.8343664531085604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 359}], {
             RGBColor[
             0.6472679560182653, 0.711845878631066, 0.8095796459099154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 154}], {
             RGBColor[
             0.41049430607523535`, 0.5260940388763077, 0.948026673617898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 159}], {
             RGBColor[
             0.5624017695526535, 0.646589013841247, 0.9619716102193616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 165}], {
             RGBColor[
             0.3475285821394179, 0.47367319960943444`, 0.943429645916229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 192}], {
             RGBColor[
             0.6389477516323683, 0.705607098850128, 0.8926067481380672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 228}], {
             RGBColor[
             0.4311057084378968, 0.5428273038474112, 0.9496492787139414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 262}], {
             RGBColor[
             0.37843384562986165`, 0.5000659127794695, 0.945502756730302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 297}], {
             RGBColor[
             0.59589992432325, 0.6732995331721323, 0.9651666941255368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 307}], {
             RGBColor[
             0.3563222412618104, 0.48128982515909213`, 0.9439899700995804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 314}], {
             RGBColor[
             0.4193018543639033, 0.5332444033525772, 0.9487200360822945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 332}], {
             RGBColor[
             0.4613846003016761, 0.567409072310961, 0.9520329439966936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 385}], {
             RGBColor[
             0.4160750619138499, 0.5306247478762804, 0.948466011160496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 172}], {
             RGBColor[
             0.6633216761370117, 0.7291431471420393, 0.9185102771399013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 211}], {
             RGBColor[
             0.6322425096466451, 0.7058157452315056, 0.9677504407343218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 328}], {
             RGBColor[
             0.5438585884915218, 0.6359361428313155, 0.9591623192423573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 347}], {
             RGBColor[
             0.5664562305632517, 0.6535895925661916, 0.9614146410170956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 364}], {
             RGBColor[
             0.5023190309801064, 0.6034851247910678, 0.9550220443588548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 372}], {
             RGBColor[
             0.6650537584061922, 0.7298594076728295, 0.8898051914543581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 387}], {
             RGBColor[
             0.4754414997937909, 0.5819847345156952, 0.9526873606539621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 161}], {
             RGBColor[
             0.8717397959802269, 0.897179719622939, 0.8046603397349048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 168}], {
             RGBColor[
             0.7589887242577461, 0.8072778839525447, 0.794666602197516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 170}], {
             RGBColor[
             0.9663658911385626, 0.8918063222819972, 0.4514611644283634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 251}], {
             RGBColor[
             0.912463957393393, 0.9290788295853941, 0.808696764466443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.7564935277352323, 0.8052521710082455, 0.7944701711870576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 312}], {
             RGBColor[
             0.8233499458241811, 0.8593772009045535, 0.7998372917002102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 326}], {
             RGBColor[
             0.8005298767326778, 0.8410028629392868, 0.7979368738905981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 356}], {
             RGBColor[
             0.8708304586283255, 0.8964693383724138, 0.804569705485908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 199}], {
             RGBColor[
             0.735098336731268, 0.6325234496756138, 0.5951701559123966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 212}], {
             RGBColor[
             0.9305963159839621, 0.7865210819621101, 0.5823221794536156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 238}], {
             RGBColor[
             0.6626587515813965, 0.5732134664547349, 0.5896056710222886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 259}], {
             RGBColor[
             0.8899236661734864, 0.7549941677503591, 0.6097972622311365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 274}], {
             RGBColor[
             0.859340256284991, 0.7306077868698191, 0.6068801892938395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 287}], {
             RGBColor[
             0.6582221271268454, 0.5693706853434315, 0.5893229732351976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 299}], {
             RGBColor[
             0.6785869355609248, 0.5866449483959182, 0.5907213714041839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 318}], {
             RGBColor[
             0.7477250311808091, 0.6427743690558538, 0.5961641755525703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 336}], {
             RGBColor[
             0.8385183540918826, 0.7142746938965933, 0.6048226005177861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 367}], {
             RGBColor[
             0.9186241773798614, 0.7775922805937496, 0.6025878872765222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 186}], {
             RGBColor[
             0.8579588635692657, 0.8896331535228834, 0.9727953033992122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 189}], {
             RGBColor[
             0.8163184244330102, 0.8568167303437877, 0.9822249321009003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 226}], {
             RGBColor[
             0.6457487152809983, 0.721404705283847, 0.9665417337258675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 241}], {
             RGBColor[
             0.7789268483952292, 0.8272228411204435, 0.9785998068289326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 255}], {
             RGBColor[
             0.6945792057353026, 0.7610474972231775, 0.9703858488064107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 266}], {
             RGBColor[
             0.8384772346449116, 0.8744855641218781, 0.9843384592003148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 365}], {
             RGBColor[
             0.7090580801464043, 0.7726408283421553, 0.9716359409706513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 374}], {
             RGBColor[
             0.8750753591678074, 0.902277446704035, 0.9383956944925416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 399}], {
             RGBColor[
             0.7785269091235798, 0.82691040552178, 0.9785599446199795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 171}], {
             RGBColor[
             0.7847387843859337, 0.8324561740514413, 0.9789951842429246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 182}], {
             RGBColor[
             0.6665621347722533, 0.7361390571835251, 0.9696622511668302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 244}], {
             RGBColor[
             0.9496448033570217, 0.9581547899409026, 0.765952999312523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 249}], {
             RGBColor[
             0.7157013116162205, 0.7767361813229732, 0.9733362253915034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 253}], {
             RGBColor[
             0.8029270520740035, 0.8466649870053157, 0.9808080207870462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 270}], {
             RGBColor[
             0.900608049281288, 0.9235844284153816, 0.9903819937943877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 308}], {
             RGBColor[
             0.9493914341437777, 0.9576128588133306, 0.7383753240644386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 386}], {
             RGBColor[
             0.8716980268081795, 0.9005323612369797, 0.987624530042621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 397}], {
             RGBColor[
             0.7194005522277445, 0.7797393915002988, 0.9736274431632075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 156}], {
             RGBColor[
             0.8395437058744278, 0.8752002330146104, 0.984476192462206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 175}], {
             RGBColor[
             0.7508918494663124, 0.8053680800344626, 0.9760344619677654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 242}], {
             RGBColor[
             0.9446546652906378, 0.9559106673394411, 0.8841454284719042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 256}], {
             RGBColor[
             0.5860852169918815, 0.6636210707457835, 0.9645111967333742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 261}], {
             RGBColor[
             0.8395437058744278, 0.8752002330146104, 0.984476192462206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 264}], {
             RGBColor[
             0.7431007413494745, 0.7990429074797927, 0.9754211173970386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 317}], {
             RGBColor[
             0.8638651755330677, 0.5787254036304051, 0.5835199290010555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 333}], {
             RGBColor[
             0.9448991860936097, 0.9538104370406051, 0.720078475098926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 381}], {
             RGBColor[
             0.9448786245225766, 0.9560032802373375, 0.880433844410766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 154}], {
             RGBColor[
             0.6797371862168118, 0.7480999105813355, 0.969859266575957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 188}], {
             RGBColor[
             0.8995107306489393, 0.9218035474266791, 0.9588689004100127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 195}], {
             RGBColor[
             0.7517295911142072, 0.8060424820453044, 0.9758714324676988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 203}], {
             RGBColor[
             0.773398810446839, 0.822970640880123, 0.9780312177404077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 258}], {
             RGBColor[
             0.9116509072302892, 0.9288950411681336, 0.8462743642341346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 278}], {
             RGBColor[
             0.6645812740361079, 0.7357956583069774, 0.9686661376511564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 284}], {
             RGBColor[
             0.8993191211961894, 0.9216606454105499, 0.9591932452337693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 312}], {
             RGBColor[
             0.7402376455985138, 0.7970648868664238, 0.9747260227370311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 327}], {
             RGBColor[
             0.6794076524919443, 0.7478323802581631, 0.9698333244740136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 337}], {
             RGBColor[
             0.793383613270433, 0.8385829207360416, 0.9800231161172629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[
             0.7877181584026585, 0.8341570243342843, 0.979458436522729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 361}], {
             RGBColor[
             0.9075973173581018, 0.9273676197967198, 0.924272096415129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 369}], {
             RGBColor[
             0.9109167736528241, 0.9273248036782259, 0.7663684548743099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 392}], {
             RGBColor[
             0.8368761495573351, 0.8727663415318342, 0.9843031883045785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 192}], {
             RGBColor[
             0.7597354701739387, 0.8098707673970269, 0.9008236881296364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[
             0.6249436488468332, 0.7052284377219942, 0.964415564773918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 222}], {
             RGBColor[
             0.5338398605372023, 0.6324342738525797, 0.9564449758227827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 228}], {
             RGBColor[
             0.5518934269794673, 0.6470909723943103, 0.9578662187055107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 312}], {
             RGBColor[
             0.591782483998508, 0.6793226837082951, 0.9611103697705414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 332}], {
             RGBColor[
             0.5821723188432466, 0.6716727408578602, 0.9602498839882628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 356}], {
             RGBColor[
             0.6392629968026525, 0.7164148211761554, 0.9658427835562393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 361}], {
             RGBColor[
             0.759142155758096, 0.809625416638591, 0.9106564434486393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 385}], {
             RGBColor[
             0.5368627804554205, 0.6348884164231796, 0.9566829511520653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 170}], {
             RGBColor[
             0.9591140993921008, 0.8888429518016292, 0.5940552423883356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 180}], {
             RGBColor[
             0.9266397753095346, 0.9432012534130163, 0.9533346269646872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 183}], {
             RGBColor[
             0.9520217240734767, 0.9634401303827387, 0.9557555798965252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 239}], {
             RGBColor[
             0.784048669092226, 0.8305466368557299, 0.939804378422931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 271}], {
             RGBColor[
             0.8907689988558258, 0.9147472618842818, 0.9498738616289458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 326}], {
             RGBColor[
             0.793278084986216, 0.8380394924589188, 0.9405309518505702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 335}], {
             RGBColor[
             0.8272459896404933, 0.8651226042925129, 0.9435424817266334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 337}], {
             RGBColor[
             0.8692441217496384, 0.8979318642938032, 0.9477284630404141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 354}], {
             RGBColor[
             0.7526222480128341, 0.8050332524793437, 0.9373303754367877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 175}], {
             RGBColor[
             0.6933674500524678, 0.7598065398845022, 0.9704663036537828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 202}], {
             RGBColor[
             0.884134351148087, 0.909110239457664, 0.9282273303913691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 214}], {
             RGBColor[
             0.8724347924293885, 0.9007265359189425, 0.9633385010038115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 256}], {
             RGBColor[
             0.5285608175780371, 0.6180595305958231, 0.9589430384193915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 261}], {
             RGBColor[
             0.7820193064605834, 0.82963869286465, 0.9789080341482234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 264}], {
             RGBColor[
             0.68557634193563, 0.7534813673298323, 0.969852959083056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 295}], {
             RGBColor[
             0.8051379768345261, 0.8477660385968283, 0.9811945433120233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 310}], {
             RGBColor[
             0.6792977244065606, 0.7483841027712375, 0.9693586833118338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 363}], {
             RGBColor[
             0.584793605655012, 0.669876132570553, 0.9624122481128781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 381}], {
             RGBColor[
             0.8873542251087321, 0.9104417400873771, 0.8748656860967834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 187}], {
             RGBColor[
             0.7287289233792054, 0.7868341121711063, 0.9675958136023575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 218}], {
             RGBColor[
             0.963803939996787, 0.9575613333903134, 0.6863093299115126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 253}], {
             RGBColor[
             0.8218749279428383, 0.8615692549594365, 0.9755336738749547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 298}], {
             RGBColor[
             0.8804693673275228, 0.5457996354683601, 0.5722696311437314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.6351265556655185, 0.7137598158120535, 0.965036404436017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 265}], {
             RGBColor[
             0.6424185809538154, 0.7196798104430886, 0.9656104593782805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 311}], {
             RGBColor[
             0.8038542281408032, 0.716545465499668, 0.607192303628707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 322}], {
             RGBColor[
             0.8357836507232937, 0.8389176993302405, 0.6548471681643288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 362}], {
             RGBColor[
             0.6844299698728897, 0.7534011614159151, 0.9691812411013632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 165}], {
             RGBColor[
             0.6202237641584065, 0.6984318431212728, 0.9655915225092617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 167}], {
             RGBColor[
             0.7449170321312093, 0.8007762665321303, 0.9751776107026855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 192}], {
             RGBColor[
             0.911642933651357, 0.9303657423619662, 0.9147686247311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 201}], {
             RGBColor[
             0.7590141472637735, 0.8117890400157326, 0.9765826793940686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 210}], {
             RGBColor[
             0.7395913220438391, 0.796615781334981, 0.974646793692767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 228}], {
             RGBColor[
             0.7038008904568855, 0.7675859473592497, 0.9718111553069742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 236}], {
             RGBColor[
             0.843118592040734, 0.8777438957215092, 0.9848985980413394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 243}], {
             RGBColor[
             0.8088360169022057, 0.8507102632375096, 0.9815484577477847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 263}], {
             RGBColor[
             0.8856524843358838, 0.91164614073646, 0.9885004268174018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 166}], {
             RGBColor[
             0.8663215018532178, 0.85339254364088, 0.6441909964637089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 185}], {
             RGBColor[
             0.7543183848953188, 0.7644134184076627, 0.634040440436334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 213}], {
             RGBColor[
             0.7481771077555677, 0.7594276529642305, 0.6335569766036533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 224}], {
             RGBColor[
             0.8572803535442114, 0.846329529866612, 0.6432898592946017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 247}], {
             RGBColor[
             0.7191081197923764, 0.7358281389927276, 0.6312685593879794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 289}], {
             RGBColor[
             0.7384118035865116, 0.7514997391178513, 0.6327882160879774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 302}], {
             RGBColor[
             0.6710865620193084, 0.6948292616719529, 0.628044272783759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 340}], {
             RGBColor[
             0.9174531583871207, 0.8937567683349881, 0.6491759238387169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 370}], {
             RGBColor[
             0.7363598569749004, 0.7498338764194039, 0.6326266793341833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 400}], {
             RGBColor[
             0.8520374859224418, 0.842233761833216, 0.6427672992474474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 170}], {
             RGBColor[
             0.8436887388506376, 0.7985193000892127, 0.6224240466944635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 222}], {
             RGBColor[
             0.6427301700749504, 0.7192017688560536, 0.9661347800185514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 239}], {
             RGBColor[
             0.6686233085507628, 0.7402229851433134, 0.968173182729059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 251}], {
             RGBColor[
             0.789786805105468, 0.8357918073926096, 0.9796596467325431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 312}], {
             RGBColor[
             0.700672793536256, 0.7660901787117689, 0.9708001739663104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 326}], {
             RGBColor[
             0.6778527244447528, 0.7477158407465023, 0.9688997561566981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 327}], {
             RGBColor[
             0.6398428004296864, 0.7168576721035081, 0.9659074757032927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 337}], {
             RGBColor[
             0.7538187612081751, 0.8076082125813866, 0.976097267346542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.7481533063404004, 0.8031823161796293, 0.9755325877520081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 179}], {
             RGBColor[
             0.8337784107431409, 0.7365681650142903, 0.6094320824124067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 231}], {
             RGBColor[
             0.8229305786049677, 0.7280937561013716, 0.6083508718836284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 313}], {
             RGBColor[
             0.6917372206327829, 0.623105370290379, 0.5969834179607627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 359}], {
             RGBColor[
             0.6019814335858997, 0.5452306957689795, 0.5911005693946201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 164}], {
             RGBColor[
             0.9928701985242632, 0.9861131677898611, 0.5542223394599444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 169}], {
             RGBColor[
             0.8911661474946764, 0.9088615351594913, 0.6993259824345514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 209}], {
             RGBColor[
             0.7252063706911822, 0.7764129125027179, 0.6846987535148692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 227}], {
             RGBColor[
             0.8101590372537962, 0.8453813142922637, 0.6913865386185496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 240}], {
             RGBColor[
             0.8846769902808116, 0.9037921562245986, 0.6986792038880953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 245}], {
             RGBColor[
             0.7415814623422675, 0.7897069495945412, 0.6859878607135799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 280}], {
             RGBColor[
             0.9434584638582062, 0.9503279682358463, 0.7043747159413543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 304}], {
             RGBColor[
             0.6662740445955484, 0.7255393552889061, 0.6808964834922828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 315}], {
             RGBColor[
             0.8912814904732148, 0.9089516419709647, 0.6993374787447106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 319}], {
             RGBColor[
             0.9074242440780331, 0.9215952595059753, 0.7009377398905936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 329}], {
             RGBColor[
             0.972021837799714, 0.9726514409324927, 0.6914215313547298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 371}], {
             RGBColor[
             0.8167241744548549, 0.8507069000408328, 0.6919063022617322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 169}], {
             RGBColor[
             0.8932269412574538, 0.9143145973639338, 0.8347516195874995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 209}], {
             RGBColor[
             0.7272671644539598, 0.7818659747071606, 0.8201243906678174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 227}], {
             RGBColor[
             0.8122198310165738, 0.8508343764967063, 0.8268121757714977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 245}], {
             RGBColor[
             0.7436422561050451, 0.7951600117989839, 0.821413497866528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 280}], {
             RGBColor[
             0.9455192576209839, 0.955781030440289, 0.8398003530943023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 304}], {
             RGBColor[
             0.668334838358326, 0.7309924174933488, 0.816322120645231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 315}], {
             RGBColor[
             0.8933422842359924, 0.9144047041754072, 0.8347631158976587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 228}], {
             RGBColor[
             0.48892770304364985`, 0.5946701331274371, 0.9532691910038416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 262}], {
             RGBColor[
             0.4362558402356147, 0.5519087420594952, 0.9491226690202021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 298}], {
             RGBColor[
             0.6113347883725855, 0.3298215144447301, 0.5556337791030646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 307}], {
             RGBColor[
             0.41414423586756344`, 0.533132654439118, 0.9476098823894806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 314}], {
             RGBColor[
             0.4771238489696564, 0.5850872326326029, 0.9523399483721946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 332}], {
             RGBColor[
             0.5192065949074292, 0.619251901590987, 0.9556528562865938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 385}], {
             RGBColor[
             0.47389705651960295`, 0.5824675771563064, 0.9520859234503962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 185}], {
             RGBColor[
             0.6576543916788786, 0.7310024372183326, 0.9675253696413402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 213}], {
             RGBColor[
             0.6515131145391275, 0.7260166717749004, 0.9670419058086596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 224}], {
             RGBColor[
             0.7606163603277714, 0.8129185486772819, 0.976774788499608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 247}], {
             RGBColor[
             0.6224441265759364, 0.7024171578033974, 0.9647534885929857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 289}], {
             RGBColor[
             0.6417478103700716, 0.7180887579285211, 0.9662731452929836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 302}], {
             RGBColor[
             0.5744225688028683, 0.6614182804826227, 0.9615292019887652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 340}], {
             RGBColor[
             0.8207891651706807, 0.8603457871456579, 0.9826608530437232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 400}], {
             RGBColor[
             0.7553734927060018, 0.8088227806438858, 0.9762522284524535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 192}], {
             RGBColor[
             0.821463014210924, 0.8597943515410112, 0.9058127486213912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[
             0.6688342278233406, 0.7412176491947776, 0.9676268032843598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.6866711928838185, 0.7551520218659784, 0.9694046252656727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 228}], {
             RGBColor[
             0.6136209710164526, 0.6970145565382946, 0.9628552791972653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 243}], {
             RGBColor[
             0.7186560974617728, 0.7801388724165546, 0.9725925816380758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 348}], {
             RGBColor[
             0.824761045418209, 0.8607293981106605, 0.819988486504708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 351}], {
             RGBColor[
             0.4982378985601938, 0.6003117403517845, 0.9546089996352731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 170}], {
             RGBColor[
             0.7309376671281567, 0.7086174644188183, 0.6124303091570746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 180}], {
             RGBColor[
             0.6984633430455904, 0.7629757660302056, 0.9717096937334263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 220}], {
             RGBColor[
             0.5821186877326374, 0.6716292007062137, 0.9602456619507784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 251}], {
             RGBColor[
             0.6770357333829872, 0.7458899717222154, 0.9696659091951543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 282}], {
             RGBColor[
             0.5210653037248263, 0.6220633131450668, 0.9554393159157688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 350}], {
             RGBColor[
             0.4185507230289969, 0.5350420835747851, 0.948417638316639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 357}], {
             RGBColor[
             0.5820933689604186, 0.6716086457863288, 0.9602436687642837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 394}], {
             RGBColor[
             0.5271909657900185, 0.6270364015675208, 0.9559215504725803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 209}], {
             RGBColor[
             0.6255631134243729, 0.7046143420767906, 0.9652280336424244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 227}], {
             RGBColor[
             0.710515779986987, 0.7735827438663363, 0.9719158187461046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 240}], {
             RGBColor[
             0.7850337330140023, 0.8319935857986713, 0.9792084840156503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 245}], {
             RGBColor[
             0.6419382050754583, 0.7179083791686139, 0.9665171408411349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 280}], {
             RGBColor[
             0.843815206591397, 0.8785293978099189, 0.9849039960689092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 292}], {
             RGBColor[
             0.826188223965461, 0.8644741203356947, 0.9832227187302544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 304}], {
             RGBColor[
             0.5666307873287391, 0.6537407848629788, 0.961425763619838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 315}], {
             RGBColor[
             0.7916382332064056, 0.8371530715450373, 0.9798667588722657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 329}], {
             RGBColor[
             0.8723785805329047, 0.9008528705065653, 0.9719508114822849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 353}], {
             RGBColor[
             0.7307564580096657, 0.7895917660427149, 0.9737986324931913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 378}], {
             RGBColor[
             0.8655664414285961, 0.8957723883164259, 0.9834819860954513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 180}], {
             RGBColor[
             0.905840509926407, 0.8475042043596581, 0.6285042559642737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 239}], {
             RGBColor[
             0.7632494037090984, 0.7348495878023716, 0.6149740074225174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 251}], {
             RGBColor[
             0.8844129002638037, 0.8304184100516678, 0.6264604714260016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 271}], {
             RGBColor[
             0.8699697334726983, 0.8190502128309236, 0.6250434906285323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 282}], {
             RGBColor[
             0.7284424706056428, 0.7065917514745192, 0.6122338781466163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 326}], {
             RGBColor[
             0.7724788196030885, 0.7423424434055605, 0.6157005808501568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 182}], {
             RGBColor[
             0.5455769362408116, 0.6409314962064878, 0.9577874792981093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 244}], {
             RGBColor[
             0.82865960482558, 0.8629472289638653, 0.754078227443802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 253}], {
             RGBColor[
             0.6819418535425616, 0.7514574260282784, 0.9689332489183251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 270}], {
             RGBColor[
             0.7796228507498462, 0.8283768674383443, 0.9785072219256667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 308}], {
             RGBColor[
             0.8284062356123358, 0.8624052978362933, 0.7265005521957177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 397}], {
             RGBColor[
             0.5984153536963027, 0.6845318305232615, 0.9617526712944865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 211}], {
             RGBColor[
             0.9541746148850205, 0.9648426719747255, 0.9432866984021382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 328}], {
             RGBColor[
             0.8657906937298973, 0.8949630695745354, 0.9346985769101737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 347}], {
             RGBColor[
             0.8883883358016271, 0.9126165193094116, 0.9369508986849121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 364}], {
             RGBColor[
             0.8242511362184819, 0.8625120515342877, 0.9305583020266714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 387}], {
             RGBColor[
             0.7973736050321664, 0.8410116612589151, 0.9282236183217785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 175}], {
             RGBColor[
             0.748457734008507, 0.8034271824407127, 0.9758022938624396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 197}], {
             RGBColor[
             0.8573743368116942, 0.8891110396399896, 0.9862583237038471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 204}], {
             RGBColor[
             0.9150639788855426, 0.935053712362913, 0.9897678789050334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 214}], {
             RGBColor[
             0.9275250763854277, 0.9443471784751529, 0.9686744912124681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 261}], {
             RGBColor[
             0.8371095904166226, 0.8732593354208604, 0.98424402435688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 295}], {
             RGBColor[
             0.8602282607905654, 0.8913866811530388, 0.9865305335206798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 310}], {
             RGBColor[
             0.7343880083625998, 0.7920047453274479, 0.9746946735204904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 345}], {
             RGBColor[
             0.9390878482109242, 0.9406176370473563, 0.6947995803903774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 193}], {
             RGBColor[
             0.7517935530015334, 0.8060969544309531, 0.9761090950120226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 232}], {
             RGBColor[
             0.6319446000121804, 0.7118434594383831, 0.9643299470357173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 235}], {
             RGBColor[
             0.7720045597284897, 0.8221551806587198, 0.9760439045162494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 260}], {
             RGBColor[
             0.6155405151831597, 0.6987625458667162, 0.9628767506358714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 267}], {
             RGBColor[
             0.8005145495429977, 0.8413428285752925, 0.826819043572447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 272}], {
             RGBColor[
             0.5927999981197926, 0.6803007696660556, 0.9610865338313844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 275}], {
             RGBColor[
             0.7975282055895723, 0.8403959815540907, 0.8972510805309089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 281}], {
             RGBColor[
             0.7542446270667587, 0.8080513743579306, 0.9763428806444634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 291}], {
             RGBColor[
             0.7999699680206451, 0.8401780237646181, 0.7675447056319449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 338}], {
             RGBColor[
             0.7316622135355857, 0.7900447707914589, 0.9741889498823015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 384}], {
             RGBColor[
             0.5096338408396088, 0.6116930762329108, 0.9548404656868403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 398}], {
             RGBColor[
             0.6988019631432114, 0.7640729396511241, 0.9709936641750376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 204}], {
             RGBColor[
             0.7713218385213879, 0.8216009168265548, 0.9759901582019364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 214}], {
             RGBColor[
             0.783782936021273, 0.8308943829387947, 0.9548967705093709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 256}], {
             RGBColor[
             0.43990896116992156`, 0.5482273776156753, 0.950501307924951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 261}], {
             RGBColor[
             0.6933674500524678, 0.7598065398845022, 0.9704663036537828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 264}], {
             RGBColor[
             0.5969244855275144, 0.6836492143496845, 0.9614112285886155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 295}], {
             RGBColor[
             0.7164861204264106, 0.7779338856166805, 0.9727528128175827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 310}], {
             RGBColor[
             0.590645867998445, 0.6785519497910897, 0.9609169528173933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 345}], {
             RGBColor[
             0.7953457078467694, 0.8271648415109981, 0.6810218596872804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 186}], {
             RGBColor[
             0.8703295661277477, 0.8992972403823913, 0.9740282994194536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 226}], {
             RGBColor[
             0.6581194178394802, 0.731068792143355, 0.9677747297461089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 294}], {
             RGBColor[
             0.6105949616504879, 0.691886260376682, 0.9641992225553948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 341}], {
             RGBColor[
             0.8148620883519128, 0.8554555119170603, 0.9821390928321554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 368}], {
             RGBColor[
             0.8771540775954658, 0.9043869498609036, 0.962476181622264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 379}], {
             RGBColor[
             0.8788499561439946, 0.9056517333056501, 0.9596055015955687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 393}], {
             RGBColor[
             0.7562739872069955, 0.8095262537920738, 0.9763419813287131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 399}], {
             RGBColor[
             0.7908976116820619, 0.8365744923812879, 0.9797929406402208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 200}], {
             RGBColor[
             0.34378991496518785`, 0.45869015387157974`, 0.9439815802551401]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 225}], {
             RGBColor[
             0.7252850398173276, 0.7840944340955809, 0.9688326428701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 296}], {
             RGBColor[
             0.46743817284108585`, 0.5777907136478699, 0.9514208619663481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 311}], {
             RGBColor[
             0.7075091298100887, 0.6392317344368861, 0.5989898956170454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 324}], {
             RGBColor[
             0.5232222696591452, 0.6238144352607546, 0.955609120175345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 339}], {
             RGBColor[
             0.5392764748981353, 0.636847962307471, 0.9568729660202498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 360}], {
             RGBColor[
             0.7346733992633758, 0.7910962571984159, 0.9529405992042449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 374}], {
             RGBColor[
             0.746787058896945, 0.800009443508283, 0.9270094866376801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 375}], {
             RGBColor[
             0.5581893195967316, 0.6522022616477356, 0.9583618544349563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 383}], {
             RGBColor[
             0.5426144861414568, 0.6395579102104922, 0.9571357464928623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 390}], {
             RGBColor[
             0.7468738315789034, 0.8000453262422289, 0.9255714387371254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 209}], {
             RGBColor[
             0.4792413413262223, 0.5881087363218456, 0.9521467803895284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 229}], {
             RGBColor[
             0.5420277553986603, 0.6390815757615713, 0.9570895568995237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 240}], {
             RGBColor[
             0.6387119609158518, 0.7154879800437262, 0.9661272307627544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 245}], {
             RGBColor[
             0.4956164329773077, 0.6014027734136689, 0.9534358875882389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 248}], {
             RGBColor[
             0.7452126280219007, 0.7974118920002999, 0.8717312179222625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 309}], {
             RGBColor[
             0.4300900626736427, 0.5457070307934685, 0.9489677500609728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 315}], {
             RGBColor[
             0.6453164611082549, 0.7206474657900921, 0.9667855056193697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 319}], {
             RGBColor[
             0.6614592147130733, 0.733291083325103, 0.9683857667652527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 329}], {
             RGBColor[
             0.7260568084347541, 0.7843472647516201, 0.9588695582293889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 334}], {
             RGBColor[
             0.6021074072657998, 0.6868922245273941, 0.9624788309439196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 371}], {
             RGBColor[
             0.570759145089895, 0.6624027238599604, 0.9593543291363913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 388}], {
             RGBColor[
             0.6151816566812345, 0.6971059275387074, 0.9637819499398428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 196}], {
             RGBColor[
             0.7121000521606844, 0.7750172399995545, 0.9719391363121901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 231}], {
             RGBColor[
             0.7524508895708124, 0.8065396208620693, 0.9759609306852169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 303}], {
             RGBColor[
             0.6546683977929466, 0.7286756813699946, 0.9672237025372035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 313}], {
             RGBColor[
             0.6212575315986276, 0.7015512350510769, 0.9645934767623512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 344}], {
             RGBColor[
             0.6391323807909823, 0.7160628428782099, 0.9660006503685035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 359}], {
             RGBColor[
             0.5315017445517445, 0.6236765605296773, 0.9587106281962086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 239}], {
             RGBColor[
             0.7307750796265322, 0.7892078894137589, 0.9742533919988692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 271}], {
             RGBColor[
             0.8374954093901321, 0.8734085144423107, 0.984322875204884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 282}], {
             RGBColor[
             0.6959681465230766, 0.7609500530859064, 0.9715132627229679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 326}], {
             RGBColor[
             0.7400044955205223, 0.7967007450169477, 0.9749799654265083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 350}], {
             RGBColor[
             0.5934535658272471, 0.6739288235156247, 0.964491585123838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 394}], {
             RGBColor[
             0.7020938085882686, 0.7659231415083605, 0.9719954972797794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 250}], {
             RGBColor[
             0.6502848833062038, 0.7256016165725139, 0.9665472448726149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 265}], {
             RGBColor[
             0.5762021100275292, 0.6668258563864187, 0.9597798872806941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 322}], {
             RGBColor[
             0.7695671797970075, 0.7860637452735706, 0.6490165960667423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 362}], {
             RGBColor[
             0.6182134989466035, 0.7005472073592451, 0.9633506690037767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 244}], {
             RGBColor[
             0.7104829552118996, 0.7666301120959491, 0.7447452943677076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 253}], {
             RGBColor[
             0.5637652039288812, 0.6551403091603623, 0.9596003158422308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 271}], {
             RGBColor[
             0.8628773581540743, 0.8936473914120331, 0.986743828136722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 273}], {
             RGBColor[
             0.8257875160419306, 0.8646725248607858, 0.9830470592992644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 335}], {
             RGBColor[
             0.7993543489387418, 0.8440227338202642, 0.9804124482344094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 305}], {
             RGBColor[
             0.5794172404887097, 0.6663041726303789, 0.96161054169419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 325}], {
             RGBColor[
             0.8469318928887002, 0.8812543116222036, 0.9836177866862814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 213}], {
             RGBColor[
             0.5395099975812285, 0.6370375465416831, 0.9568913497812847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 224}], {
             RGBColor[
             0.6486132433698724, 0.7239394234440646, 0.9666242324722331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 247}], {
             RGBColor[
             0.5104410096180373, 0.6134380325701801, 0.9546029325656108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 289}], {
             RGBColor[
             0.5297446934121726, 0.6291096326953038, 0.9561225892656087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 302}], {
             RGBColor[
             0.4624194518449693, 0.5724391552494055, 0.9513786459613903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 340}], {
             RGBColor[
             0.7087860482127817, 0.7713666619124406, 0.9725102970163483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 400}], {
             RGBColor[
             0.6433703757481027, 0.7198436554106685, 0.9661016724250786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 189}], {
             RGBColor[
             0.909047857530175, 0.9299275697320074, 0.9777856592801093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 200}], {
             RGBColor[
             0.5648076483332153, 0.6340689964555516, 0.9509285152892106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 226}], {
             RGBColor[
             0.7384781483781633, 0.7945155446720669, 0.9621024609050766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 241}], {
             RGBColor[
             0.871656281492394, 0.9003336805086632, 0.9741605340081414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 255}], {
             RGBColor[
             0.7873086388324675, 0.8341583366113974, 0.9659465759856196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 288}], {
             RGBColor[
             0.809457497035406, 0.8517435173625939, 0.9679611404541568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 341}], {
             RGBColor[
             0.8952208188905957, 0.9189022644457722, 0.9764668239911231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 374}], {
             RGBColor[
             0.9678047922649724, 0.9753882860922547, 0.9339564216717506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 393}], {
             RGBColor[
             0.8366327177456784, 0.8729730063207857, 0.9706697124876806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 399}], {
             RGBColor[
             0.8712563422207447, 0.9000212449099998, 0.9741206717991884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 193}], {
             RGBColor[
             0.7056720910239382, 0.768653473849357, 0.9724782445766642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 218}], {
             RGBColor[
             0.748913128720947, 0.7869231746246994, 0.6735838812264073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 232}], {
             RGBColor[
             0.5858231380345852, 0.6743999788567872, 0.960699096600359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 235}], {
             RGBColor[
             0.7258830977508944, 0.7847117000771238, 0.9724130540808912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 275}], {
             RGBColor[
             0.7514067436119771, 0.8029525009724947, 0.8936202300955505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 279}], {
             RGBColor[
             0.6275164854038695, 0.7069711387028483, 0.9648546998196457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 281}], {
             RGBColor[
             0.7081231650891635, 0.7706078937763345, 0.972712030209105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 298}], {
             RGBColor[
             0.6655785560516827, 0.3751614767027462, 0.559544182458626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 306}], {
             RGBColor[
             0.37980069322982196`, 0.49591955770924556`, 0.9460887959332176]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 195}], {
             RGBColor[
             0.8230479739463289, 0.8620039157325191, 0.9512654133352648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 203}], {
             RGBColor[
             0.8447171932789608, 0.8789320745673377, 0.9534251986079737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 206}], {
             RGBColor[
             0.897549697779769, 0.9202398730476219, 0.9586818553443166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 208}], {
             RGBColor[
             0.982072412411112, 0.9846344351110756, 0.8473511864732177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 258}], {
             RGBColor[
             0.982969290062411, 0.9848564748553483, 0.8216683451017006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 278}], {
             RGBColor[
             0.7358996568682297, 0.7917570919941921, 0.9440601185187224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 284}], {
             RGBColor[
             0.9706375040283111, 0.9776220790977647, 0.9345872261013353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 327}], {
             RGBColor[
             0.750726035324066, 0.8037938139453779, 0.9452273053415796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 361}], {
             RGBColor[
             0.9789157001902236, 0.9833290534839345, 0.899666077282695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 369}], {
             RGBColor[
             0.9822351564849456, 0.9832862373654406, 0.741762435741876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 392}], {
             RGBColor[
             0.9081945323894568, 0.9287277752190489, 0.9596971691721445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 200}], {
             RGBColor[
             0.5231672091969598, 0.6012525732764558, 0.9603581439908988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 219}], {
             RGBColor[
             0.8162392476735119, 0.856754876857502, 0.9822170405014625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 241}], {
             RGBColor[
             0.8300158423561386, 0.8675172573295675, 0.9835901627098296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 255}], {
             RGBColor[
             0.745668199696212, 0.8013419134323015, 0.9753762046873078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 339}], {
             RGBColor[
             0.7186537691299072, 0.779410381712347, 0.9732495297560085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 360}], {
             RGBColor[
             0.9140506934951478, 0.9336586766032919, 0.9693171629400036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 374}], {
             RGBColor[
             0.9261643531287168, 0.942571862913159, 0.9433860503734388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 266}], {
             RGBColor[
             0.853052722337553, 0.8858720458851788, 0.9857912075978408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 273}], {
             RGBColor[
             0.7609126772847596, 0.8131500337361734, 0.9768043226046412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 365}], {
             RGBColor[
             0.7236335678390456, 0.7840273101054561, 0.9730886893681772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 198}], {
             RGBColor[
             0.9898950243245209, 0.9882198145473899, 0.6812338458052665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 216}], {
             RGBColor[
             0.9666659029359648, 0.9742475234396142, 0.9228356341859442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 219}], {
             RGBColor[
             0.8758731153840007, 0.9025782275393472, 0.9238547540561016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 220}], {
             RGBColor[
             0.8136760145164159, 0.8539636116198319, 0.9176731460332027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 311}], {
             RGBColor[
             0.9465202917523494, 0.8276175045236074, 0.5570041729074432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 323}], {
             RGBColor[
             0.6576987311237198, 0.7239511611212075, 0.9063287939000206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 339}], {
             RGBColor[
             0.778287636840396, 0.8252337323941923, 0.9148872433106476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 357}], {
             RGBColor[
             0.8136506957441971, 0.8539430566999471, 0.917671152846708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 201}], {
             RGBColor[
             0.8355601293434881, 0.8708071250246135, 0.9072178173127743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 203}], {
             RGBColor[
             0.853397094403966, 0.8847414976958143, 0.9089956392940871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 228}], {
             RGBColor[
             0.7803468725366002, 0.8266040323681305, 0.9024462932256798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 243}], {
             RGBColor[
             0.8853819989819204, 0.9097283482463905, 0.9121835956664902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 332}], {
             RGBColor[
             0.8106257644003795, 0.8511858008316804, 0.904829958508432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 348}], {
             RGBColor[
             0.9914869469383567, 0.9903188739404964, 0.7595795005331225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 361}], {
             RGBColor[
             0.9875956013152288, 0.9891384766124112, 0.8552365179688084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 385}], {
             RGBColor[
             0.7653162260125532, 0.8144014763969998, 0.9012630256722344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 232}], {
             RGBColor[
             0.777657116955158, 0.8268574993006517, 0.9783069762597709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 235}], {
             RGBColor[
             0.9177170766714673, 0.9371692205209885, 0.9900209337403032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 260}], {
             RGBColor[
             0.7612530321261373, 0.8137765857289847, 0.976853779859925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 275}], {
             RGBColor[
             0.9432407225325499, 0.9554100214163592, 0.9112281097549626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 281}], {
             RGBColor[
             0.8999571440097363, 0.9230654142201993, 0.9903199098685171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 338}], {
             RGBColor[
             0.8773747304785633, 0.9050588106537275, 0.9881659791063553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 384}], {
             RGBColor[
             0.6553463577825864, 0.7267071160951795, 0.9688174949108941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 376}], {
             RGBColor[
             0.8815325811854401, 0.9083741679455402, 0.9885625586185344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 377}], {
             RGBColor[
             0.9627235499831099, 0.9707560618340507, 0.9048777450841672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 396}], {
             RGBColor[
             0.9307370347796182, 0.9476084636222255, 0.9932557233276813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 206}], {
             RGBColor[
             0.7497685582450369, 0.8044788076662471, 0.9756843874020027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 208}], {
             RGBColor[
             0.83429127287638, 0.8688733697297009, 0.8643537185309038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 258}], {
             RGBColor[
             0.8351881505276788, 0.8690954094739736, 0.8386708771593867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 278}], {
             RGBColor[
             0.5881185173334975, 0.6759960266128173, 0.9610626505764085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 284}], {
             RGBColor[
             0.822856364493579, 0.8618610137163899, 0.9515897581590214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 327}], {
             RGBColor[
             0.602944895789334, 0.6880327485640031, 0.9622298373992657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 337}], {
             RGBColor[
             0.7169208565678227, 0.7787832890418815, 0.972419629042515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 369}], {
             RGBColor[
             0.8344540169502137, 0.8675251719840659, 0.758764967799562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 392}], {
             RGBColor[
             0.7604133928547248, 0.8129667098376742, 0.9766997012298306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 231}], {
             RGBColor[
             0.7012522200225111, 0.7665428310866358, 0.9708579257834118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 234}], {
             RGBColor[
             0.49597601107130534`, 0.5980908039607126, 0.9545756816590163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 290}], {
             RGBColor[
             0.4695718325238427, 0.5724005545081124, 0.9529964949106409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 303}], {
             RGBColor[
             0.6034697282446454, 0.6886788915945612, 0.9621206976353984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 313}], {
             RGBColor[
             0.5700588620503264, 0.6615544452756434, 0.9594904718605461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 344}], {
             RGBColor[
             0.587933711242681, 0.6760660531027765, 0.9608976454666984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 204}], {
             RGBColor[
             0.8802384413245751, 0.9072847740258319, 0.9864461880433439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 215}], {
             RGBColor[
             0.6246689467772282, 0.7027135482851845, 0.9656761172148907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 295}], {
             RGBColor[
             0.8254027232295977, 0.8636177428159575, 0.9832088426589903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 310}], {
             RGBColor[
             0.6995624708016321, 0.7642358069903665, 0.9713729826588009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 345}], {
             RGBColor[
             0.9042623106499565, 0.9128486987102751, 0.6914778895286879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 216}], {
             RGBColor[
             0.9698857734455885, 0.973709490070402, 0.7335787649001348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 219}], {
             RGBColor[
             0.8790929858936245, 0.902040194170135, 0.7345978847702923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 224}], {
             RGBColor[
             0.8723450534264547, 0.8967686580405958, 0.733925313924979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 247}], {
             RGBColor[
             0.7341728196746198, 0.7862672671667114, 0.7219040140183567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 302}], {
             RGBColor[
             0.6861512619015517, 0.7452683898459367, 0.7186797274141362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 311}], {
             RGBColor[
             0.9497401622619732, 0.8270794711543952, 0.3677473036216339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 323}], {
             RGBColor[
             0.6609186016333435, 0.7234131277519952, 0.7170719246142113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 340}], {
             RGBColor[
             0.9325178582693641, 0.9441958965089718, 0.7398113784690942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 212}], {
             RGBColor[
             0.775270787353717, 0.8237223422270923, 0.9472130092541565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 238}], {
             RGBColor[
             0.5073332229511514, 0.6104147267197171, 0.9544965008228294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 252}], {
             RGBColor[
             0.7617663194290667, 0.813650732160425, 0.9700725509212598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 277}], {
             RGBColor[
             0.7765014997011515, 0.8246402054807025, 0.9451297342711381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 287}], {
             RGBColor[
             0.5028965984966002, 0.6065719456084138, 0.9542138030357383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 293}], {
             RGBColor[
             0.7091736478878252, 0.48361535121093624`, 0.5723166323574003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 299}], {
             RGBColor[
             0.5232614069306796, 0.6238462086609005, 0.9556122012047248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 336}], {
             RGBColor[
             0.6831928254616375, 0.7514759541615754, 0.969713430318327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 367}], {
             RGBColor[
             0.7632986487496163, 0.8147935408587319, 0.9674787170770631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 225}], {
             RGBColor[
             0.5604221248521397, 0.6307982802240011, 0.95835206261496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 241}], {
             RGBColor[
             0.48577563315917877`, 0.5716586840531117, 0.9567330187189309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 255}], {
             RGBColor[
             0.40142799049925215`, 0.5054833401558457, 0.9485190606964091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 288}], {
             RGBColor[
             0.4235768487021907, 0.5230685209070423, 0.9505336251649463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 296}], {
             RGBColor[
             0.302575257875898, 0.42449455977629014`, 0.940940281711208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 339}], {
             RGBColor[
             0.37441355993294745`, 0.4835518084358912, 0.9463923857651098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 355}], {
             RGBColor[
             0.4657428868315568, 0.5560089503674623, 0.9547363417816517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 360}], {
             RGBColor[
             0.5698104842981879, 0.6378001033268361, 0.9424600189491048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 374}], {
             RGBColor[
             0.5819241439317571, 0.6467132896367032, 0.91652890638254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 375}], {
             RGBColor[
             0.3933264046315438, 0.49890610777615585`, 0.9478812741798162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 383}], {
             RGBColor[
             0.3777515711762689, 0.48626175633891244`, 0.9466551662377222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 399}], {
             RGBColor[
             0.4853756938875294, 0.571346248454448, 0.9566931565099779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 210}], {
             RGBColor[
             0.6635085177359703, 0.7370571639976282, 0.9670959862744413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 228}], {
             RGBColor[
             0.6277180861490167, 0.7080273300218969, 0.9642603478886485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 236}], {
             RGBColor[
             0.7670357877328653, 0.8181852783841566, 0.9773477906230137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 243}], {
             RGBColor[
             0.7327532125943369, 0.7911516459001569, 0.973997650329459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 263}], {
             RGBColor[
             0.809569680028015, 0.8520875233991072, 0.9809496193990761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 348}], {
             RGBColor[
             0.8388581605507732, 0.8717421715942628, 0.8213935551960911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 351}], {
             RGBColor[
             0.5123350136927579, 0.6113245138353868, 0.9560140683266563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 214}], {
             RGBColor[
             0.9745498371168922, 0.9801980825119565, 0.9126577972469572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 217}], {
             RGBColor[
             0.9792440427154068, 0.9836990133612723, 0.9047117316135738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 257}], {
             RGBColor[
             0.968107712252011, 0.9753935563357392, 0.9235626342679426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 264}], {
             RGBColor[
             0.7876913866231336, 0.8329529139228463, 0.9191722553262016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 268}], {
             RGBColor[
             0.9376776538355689, 0.9514973611420148, 0.9334157681456241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 279}], {
             RGBColor[
             0.8637221272699822, 0.8931640550254412, 0.926192830678277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 300}], {
             RGBColor[
             0.9542676397557547, 0.9647257655915995, 0.9349981358127467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 306}], {
             RGBColor[
             0.6160063350959346, 0.6821124740318384, 0.9074269267918488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 363}], {
             RGBColor[
             0.6869086503425157, 0.749347679163567, 0.9117315443560237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 381}], {
             RGBColor[
             0.9894692697962358, 0.9899132866803911, 0.824184982339929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 243}], {
             RGBColor[
             0.7505901776548148, 0.8050860185713578, 0.9757754723107718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 258}], {
             RGBColor[
             0.8568573698603107, 0.886023568308792, 0.8408306624320956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 284}], {
             RGBColor[
             0.8445255838262109, 0.8787891725512085, 0.9537495434317302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 348}], {
             RGBColor[
             0.8566951256112512, 0.8856765442654635, 0.8231713771774041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 361}], {
             RGBColor[
             0.8528037799881233, 0.8844961469373783, 0.91882839461309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 369}], {
             RGBColor[
             0.8561232362828455, 0.8844533308188844, 0.7609247530722709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 392}], {
             RGBColor[
             0.7820826121873565, 0.8298948686724927, 0.9788594865025395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 261}], {
             RGBColor[
             0.8599736949295034, 0.8914330698067026, 0.9844318886963768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 295}], {
             RGBColor[
             0.8830923653034461, 0.909560415538881, 0.9867183978601766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 310}], {
             RGBColor[
             0.7572521128754806, 0.81017847971329, 0.9748825378599872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 345}], {
             RGBColor[
             0.961951952723805, 0.9587913714331986, 0.6949874447298742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 389}], {
             RGBColor[
             0.6847499408403311, 0.7507274899083545, 0.9693380472502429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 400}], {
             RGBColor[
             0.8395087800868246, 0.8754457227924886, 0.982392137240361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 207}], {
             RGBColor[
             0.7224114454962284, 0.7830725788427735, 0.9729668796344277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 221}], {
             RGBColor[
             0.8473997621083368, 0.8742518639261626, 0.6943518359688299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 230}], {
             RGBColor[
             0.47503836123198406`, 0.5722887238729856, 0.9542351336696613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 250}], {
             RGBColor[
             0.7179865649904325, 0.7796158285613084, 0.9725258488984694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 276}], {
             RGBColor[
             0.8406751452478181, 0.8756644904506992, 0.9474589279316814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 358}], {
             RGBColor[
             0.8477886942958061, 0.8797948574318275, 0.8828028424881215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 391}], {
             RGBColor[
             0.794338546554683, 0.8397829335591996, 0.9799978142013935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 208}], {
             RGBColor[
             0.9087929967098201, 0.9271093270448036, 0.8717701605399556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 258}], {
             RGBColor[
             0.9096898743611189, 0.9273313667890764, 0.8460873191684384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 278}], {
             RGBColor[
             0.6626202411669376, 0.7342319839279201, 0.9684790925854603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 284}], {
             RGBColor[
             0.8973580883270191, 0.9200969710314927, 0.9590062001680731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 369}], {
             RGBColor[
             0.9089557407836537, 0.9257611292991687, 0.7661814098086137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 392}], {
             RGBColor[
             0.8349151166881648, 0.8712026671527769, 0.9841161432388824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 221}], {
             RGBColor[
             0.8654977594968756, 0.8883901570359637, 0.696155675213118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 230}], {
             RGBColor[
             0.49313635862052285`, 0.5864270169827867, 0.9560389729139493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 233}], {
             RGBColor[
             0.7531189758555124, 0.8070615349453207, 0.9760275192824546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 250}], {
             RGBColor[
             0.7360845623789714, 0.7937541216711095, 0.9743296881427574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 358}], {
             RGBColor[
             0.8658866916843448, 0.8939331505416286, 0.8846066817324096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 366}], {
             RGBColor[
             0.8609342758104988, 0.8914145531432445, 0.9456045324259518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 391}], {
             RGBColor[
             0.8124365439432217, 0.8539212266690007, 0.9818016534456817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[
             0.994212588992462, 0.99172592885253, 0.7347566502973397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 278}], {
             RGBColor[
             0.7471429557982807, 0.7986265459913737, 0.8571484237143614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 284}], {
             RGBColor[
             0.9818808029583621, 0.9844915330949464, 0.8476755312969744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 369}], {
             RGBColor[
             0.9934784554149968, 0.9901556913626224, 0.654850740937515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 392}], {
             RGBColor[
             0.919437831319508, 0.9355972292162307, 0.8727854743677836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 227}], {
             RGBColor[
             0.5445560031834928, 0.6411341212095631, 0.9572885898264225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 229}], {
             RGBColor[
             0.5223897506933167, 0.6231385588597431, 0.9555435812327375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 240}], {
             RGBColor[
             0.6190739562105082, 0.699544963141898, 0.9645812550959683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 245}], {
             RGBColor[
             0.4759784282719641, 0.5854597565118407, 0.9518899119214528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 280}], {
             RGBColor[
             0.6778554297879028, 0.7460807751531457, 0.9702767671492272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 304}], {
             RGBColor[
             0.400671010525245, 0.5212921622062056, 0.9467985347001558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 315}], {
             RGBColor[
             0.6256784564029114, 0.704704448888264, 0.9652395299525836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 319}], {
             RGBColor[
             0.6418212100077297, 0.7173480664232748, 0.9668397910984665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 329}], {
             RGBColor[
             0.7064188037294106, 0.768404247849792, 0.9573235825626027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 334}], {
             RGBColor[
             0.5824694025604562, 0.6709492076255659, 0.9609328552771335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 371}], {
             RGBColor[
             0.5511211403845515, 0.6464597069581322, 0.9578083534696051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 236}], {
             RGBColor[
             0.747612962512931, 0.8030120197034047, 0.9754119049217119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 263}], {
             RGBColor[
             0.7901468548080808, 0.8369142647183556, 0.9790137336977744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 301}], {
             RGBColor[
             0.8937167322459225, 0.9180894792711989, 0.9897246938236032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 328}], {
             RGBColor[
             0.8347115272395307, 0.8716356676640016, 0.9839387405045942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 347}], {
             RGBColor[
             0.8573091693112604, 0.8892891173988777, 0.9861910622793326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 372}], {
             RGBColor[
             0.955906697154201, 0.9655589325055156, 0.9145816127165951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 387}], {
             RGBColor[
             0.7662944385417998, 0.8176842593483813, 0.977463781916199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 238}], {
             RGBColor[
             0.7028312022038454, 0.7644123590062135, 0.9416485243640484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 259}], {
             RGBColor[
             0.9300961167959354, 0.9461930603018378, 0.9618401155728964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 293}], {
             RGBColor[
             0.9046716271405193, 0.6376129834974327, 0.5594686558986193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 299}], {
             RGBColor[
             0.7187593861833736, 0.7778438409473968, 0.9427642247459438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 336}], {
             RGBColor[
             0.8786908047143316, 0.9054735864480719, 0.956865453859546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 367}], {
             RGBColor[
             0.9587966280023102, 0.9687911731452282, 0.9546307406182821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 224}], {
             RGBColor[
             0.6424719662301213, 0.7189536580006324, 0.9661407686395524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 230}], {
             RGBColor[
             0.389565997398878, 0.5038474715556248, 0.9468575564488935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 247}], {
             RGBColor[
             0.5042997324782862, 0.6084522671267478, 0.9541194687329302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 250}], {
             RGBColor[
             0.6325142011573264, 0.7111745762439475, 0.9651482716777016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 289}], {
             RGBColor[
             0.5236034162724215, 0.6241238672518716, 0.9556391254329282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 302}], {
             RGBColor[
             0.4562781747052182, 0.5674533898059733, 0.9508951821287097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 340}], {
             RGBColor[
             0.7026447710730306, 0.7663808964690084, 0.9720268331836677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 391}], {
             RGBColor[
             0.7088661827215769, 0.7713416812418388, 0.9726202369806258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 215}], {
             RGBColor[
             0.6948196863509617, 0.7579496871203478, 0.9480922847235117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 217}], {
             RGBColor[
             0.9675444839967082, 0.9753153098225507, 0.9398229022260163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 261}], {
             RGBColor[
             0.8724347924293885, 0.9007265359189425, 0.9633385010038115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 264}], {
             RGBColor[
             0.7759918279044351, 0.8245692103841247, 0.9542834259386441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 295}], {
             RGBColor[
             0.8955534628033313, 0.9188538816511207, 0.9656250101676114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 300}], {
             RGBColor[
             0.9425680810370561, 0.956342062052878, 0.9701093064251891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 310}], {
             RGBColor[
             0.7697132103753657, 0.8194719458255298, 0.9537891501674219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 363}], {
             RGBColor[
             0.6752090916238171, 0.7409639756248454, 0.9468427149684662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 217}], {
             RGBColor[
             0.6995138919494762, 0.7614506179696636, 0.9401462190901284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 269}], {
             RGBColor[
             0.41449970764994404`, 0.5334405462304848, 0.9476325327371226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 295}], {
             RGBColor[
             0.6275228707560994, 0.7049891897982337, 0.9659483270317235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 300}], {
             RGBColor[
             0.6745374889898241, 0.7424773701999909, 0.9704326232893012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 352}], {
             RGBColor[
             0.4526849383824224, 0.5658287300723872, 0.950255190181792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 363}], {
             RGBColor[
             0.40717849957658525`, 0.5270992837719584, 0.9471660318325783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 219}], {
             RGBColor[
             0.8558638645050682, 0.8880679030623593, 0.97619967315097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 220}], {
             RGBColor[
             0.7936667636374835, 0.839453287142844, 0.9700180651280711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 311}], {
             RGBColor[
             0.926511040873417, 0.8131071800466194, 0.6093490920023116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 323}], {
             RGBColor[
             0.6376894802447873, 0.7094408366442194, 0.958673712994889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 339}], {
             RGBColor[
             0.7582783859614636, 0.8107234079172043, 0.967232162405516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 357}], {
             RGBColor[
             0.7936414448652647, 0.839432732222959, 0.9700160719415764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 268}], {
             RGBColor[
             0.9306723007153849, 0.9466145884526089, 0.9605808731246832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 269}], {
             RGBColor[
             0.6872245052956905, 0.7508061689326876, 0.9393631502396271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 279}], {
             RGBColor[
             0.8567167741497981, 0.8882812823360354, 0.9533579356573361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 300}], {
             RGBColor[
             0.9472622866355707, 0.9598429929021938, 0.9621632407918058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 306}], {
             RGBColor[
             0.6090009819757506, 0.6772297013424327, 0.9345920317709079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 363}], {
             RGBColor[
             0.6799032972223317, 0.7444649064741613, 0.9388966493350828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 262}], {
             RGBColor[
             0.7255746245322935, 0.7679759255367185, 0.6717465886849188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 269}], {
             RGBColor[
             0.6930992331673433, 0.7402232465187075, 0.6695734307110919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 279}], {
             RGBColor[
             0.8625915020214511, 0.8776983599220554, 0.6835682161288008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 298}], {
             RGBColor[
             0.9006535726692643, 0.5458886979219533, 0.2782576987677812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.9531370145072235, 0.9492600704882137, 0.6923735212632707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 306}], {
             RGBColor[
             0.6148757098474036, 0.6666467789284526, 0.6648023122423727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 314}], {
             RGBColor[
             0.7664426332663352, 0.8011544161098261, 0.6749638680369112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 220}], {
             RGBColor[
             0.7028739760855195, 0.767783991242577, 0.9710371849982286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 241}], {
             RGBColor[
             0.7788476716357309, 0.8271609876341579, 0.9785919152294946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 311}], {
             RGBColor[
             0.835718253321453, 0.7414378841463525, 0.610368211872469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 323}], {
             RGBColor[
             0.5468966926928234, 0.6377715407439525, 0.9596928328650465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 339}], {
             RGBColor[
             0.6674855984094996, 0.7390541120169374, 0.9682512822756735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 357}], {
             RGBColor[
             0.7028486573133007, 0.7677634363226921, 0.9710351918117338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 360}], {
             RGBColor[
             0.8628825227747401, 0.8933024069078823, 0.9643189154596685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 350}], {
             RGBColor[
             0.4771089105142941, 0.5825822581916329, 0.9530275533411903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 357}], {
             RGBColor[
             0.6406515564457159, 0.7191488204031766, 0.9648535837888349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 394}], {
             RGBColor[
             0.5857491532753156, 0.6745765761843687, 0.9605314654971315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 230}], {
             RGBColor[
             0.6181246752326313, 0.6776063020661758, 0.6774239292483515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 250}], {
             RGBColor[
             0.8610728789910798, 0.8849334067544985, 0.6957146444771596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 276}], {
             RGBColor[
             0.9837614592484653, 0.9809820686438893, 0.6706477235103718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 358}], {
             RGBColor[
             0.9908750082964533, 0.9851124356250176, 0.6059916380668118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 251}], {
             RGBColor[
             0.6834543314881165, 0.7511008788185087, 0.9701712047500896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 297}], {
             RGBColor[
             0.719245478785217, 0.7796397681484044, 0.9735849963304214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 312}], {
             RGBColor[
             0.5943403199189046, 0.681399250137668, 0.9613117319838568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 332}], {
             RGBColor[
             0.5847301547636432, 0.6737493072872331, 0.9604512462015782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 356}], {
             RGBColor[
             0.641820832723049, 0.7184913876055284, 0.9660441457695546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 361}], {
             RGBColor[
             0.7616999916784926, 0.8117019830679639, 0.9108578056619546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 260}], {
             RGBColor[
             0.5238113924729493, 0.6234592648007908, 0.9558857819429719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 267}], {
             RGBColor[
             0.7087854268327876, 0.7660395475093672, 0.8198280748795475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 272}], {
             RGBColor[
             0.5010708754095823, 0.6049974886001303, 0.9540955651384849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 290}], {
             RGBColor[
             0.3504325365367188, 0.47512850561446884`, 0.9436534934065333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 291}], {
             RGBColor[
             0.7082408453104349, 0.7648747426986928, 0.7605537369390454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 321}], {
             RGBColor[
             0.6085015982477594, 0.6898858150490494, 0.9641451007086124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 331}], {
             RGBColor[
             0.4924866978341492, 0.5980284665316009, 0.9534197872348683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 342}], {
             RGBColor[
             0.6595366055534863, 0.7303728002464974, 0.9690677819244335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 346}], {
             RGBColor[
             0.4539263216569678, 0.5667234160258143, 0.9503841731708884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 384}], {
             RGBColor[
             0.4179047181293986, 0.5363897951669855, 0.9478494969939408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 398}], {
             RGBColor[
             0.6070728404330011, 0.6887696585851988, 0.9640026954821381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 230}], {
             RGBColor[
             0.49866924318752176`, 0.5907493484580064, 0.9565904391398419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 247}], {
             RGBColor[
             0.61340297826693, 0.6953541440291295, 0.9638523514238786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 289}], {
             RGBColor[
             0.6327066620610652, 0.7110257441542531, 0.9653720081238766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 302}], {
             RGBColor[
             0.565381420493862, 0.6543552667083548, 0.9606280648196581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 323}], {
             RGBColor[
             0.5401487602256537, 0.6325000046144134, 0.9590202620197332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 340}], {
             RGBColor[
             0.8117480168616743, 0.8532827733713899, 0.9817597158746161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 288}], {
             RGBColor[
             0.8050719735543306, 0.8484728011310434, 0.9753846877799062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 296}], {
             RGBColor[
             0.6840703827280378, 0.7498988400002913, 0.965791344326168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 316}], {
             RGBColor[
             0.9668074411502885, 0.9735186662062654, 0.8852291845773796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 324}], {
             RGBColor[
             0.7398544795460971, 0.7959225616131761, 0.9699796025351649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 355}], {
             RGBColor[
             0.8472380116836966, 0.8814132305914635, 0.9795874043966115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 375}], {
             RGBColor[
             0.7748215294836835, 0.824310388000157, 0.9727323367947761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 380}], {
             RGBColor[
             0.9676333068145917, 0.9721929236514262, 0.7503503076515028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 383}], {
             RGBColor[
             0.7592466960284087, 0.8116660365629136, 0.9715062288526821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 390}], {
             RGBColor[
             0.9635060414658554, 0.9721534525946504, 0.9399419210969453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 255}], {
             RGBColor[0.5750984905442, 0.665929888372361, 0.959693006312275]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 266}], {
             RGBColor[
             0.7189965194538093, 0.7793679552710614, 0.9736456167061792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 294}], {
             RGBColor[
             0.47874354390090346`, 0.5871045646663575, 0.9522733840410178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 341}], {
             RGBColor[
             0.6830106706023282, 0.7506738162067357, 0.9702132543177784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 368}], {
             RGBColor[
             0.7453026598458813, 0.799605254150579, 0.950550343107887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 393}], {
             RGBColor[
             0.624422569457411, 0.7047445580817493, 0.9644161428143361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 399}], {
             RGBColor[
             0.6590461939324773, 0.7317927966709633, 0.9678671021258438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 280}], {
             RGBColor[
             0.7628080963505168, 0.8150491769426914, 0.9769645522529075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 304}], {
             RGBColor[
             0.48562367708785903`, 0.5902605639957512, 0.9534863198038361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 315}], {
             RGBColor[
             0.7106311229655254, 0.7736728506778097, 0.971927315056264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 243}], {
             RGBColor[
             0.677539955787449, 0.7469485532436739, 0.9692261262423645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 332}], {
             RGBColor[
             0.6027837212059081, 0.6884060058289637, 0.9618724890843062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 348}], {
             RGBColor[
             0.7836449037438853, 0.8275390789377797, 0.8166220311089967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 361}], {
             RGBColor[
             0.7797535581207574, 0.8263586816096945, 0.9122790485446827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 385}], {
             RGBColor[
             0.5574741828180818, 0.6516216813942831, 0.9583055562481086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 240}], {
             RGBColor[
             0.6818603702829462, 0.7505178025816238, 0.9695240316059636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 245}], {
             RGBColor[
             0.538764842344402, 0.6364325959515664, 0.9568326884314482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 248}], {
             RGBColor[
             0.7883610373889951, 0.8324417145381976, 0.8751280187654717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 249}], {
             RGBColor[
             0.55542740254041, 0.6499600129584684, 0.9581444262070471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 309}], {
             RGBColor[
             0.4732384720407371, 0.5807368533313662, 0.9523645509041819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 315}], {
             RGBColor[
             0.6884648704753493, 0.7556772883279899, 0.970182306462579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 319}], {
             RGBColor[
             0.7046076240801677, 0.7683209058630005, 0.9717825676084618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[
             0.7692052178018485, 0.8193770872895179, 0.9622663590725982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 334}], {
             RGBColor[
             0.6452558166328942, 0.7219220470652916, 0.9658756317871289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 371}], {
             RGBColor[
             0.6139075544569894, 0.697432546397858, 0.9627511299796006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 388}], {
             RGBColor[
             0.6583300660483289, 0.732135750076605, 0.967178750783052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 247}], {
             RGBColor[
             0.36049700943568674`, 0.48024795758412187`, 0.9445691392332196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 250}], {
             RGBColor[
             0.488711478114727, 0.5829702667013216, 0.955597942177991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 289}], {
             RGBColor[
             0.37980069322982196`, 0.49591955770924556`, 0.9460887959332176]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 358}], {
             RGBColor[
             0.6185136074201005, 0.6831492955718406, 0.8658749357676432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 391}], {
             RGBColor[
             0.5650634596789774, 0.6431373716992128, 0.9630699074809153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 234}], {
             RGBColor[
             0.5363268484814334, 0.6296131848232273, 0.9585974760320433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 290}], {
             RGBColor[
             0.5099226699339707, 0.6039229353706272, 0.9570182892836677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 313}], {
             RGBColor[
             0.6104096994604544, 0.6930768261381581, 0.9635122662335731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 331}], {
             RGBColor[
             0.6519768312314012, 0.7268228962877592, 0.9667845831120028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 359}], {
             RGBColor[
             0.5206539124135713, 0.6152021516167586, 0.9576294176674304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 235}], {
             RGBColor[
             0.7978681236821142, 0.8429157255284185, 0.978241785763998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 281}], {
             RGBColor[
             0.7801081910203833, 0.8288119192276293, 0.9785407618922118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 384}], {
             RGBColor[
             0.5354974047932335, 0.6324536211026095, 0.9570383469345889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 386}], {
             RGBColor[
             0.7477401173323942, 0.8030024958767812, 0.975453466128531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 242}], {
             RGBColor[
             0.8789848670596304, 0.9039858797261892, 0.8777654129269066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 317}], {
             RGBColor[
             0.7981953773020602, 0.5268006160171532, 0.5771399134560578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 358}], {
             RGBColor[
             0.87849622465509, 0.9037838135343748, 0.8858634821361482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 366}], {
             RGBColor[
             0.8735438087812439, 0.9012652161359906, 0.9468613328296904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 382}], {
             RGBColor[
             0.8399081997983671, 0.8756225430281889, 0.9844760163977081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 290}], {
             RGBColor[
             0.30464646098276493`, 0.4354709082447039, 0.9407360451592722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 313}], {
             RGBColor[
             0.40513349050924863`, 0.5246247990122348, 0.9472300221091776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 331}], {
             RGBColor[
             0.4467006222801954, 0.558370869161836, 0.9505023389876073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 342}], {
             RGBColor[
             0.6137505299995325, 0.6907152028767325, 0.9661503336771724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 346}], {
             RGBColor[
             0.40814024610301397`, 0.5270658186560494, 0.9474667249236275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 275}], {
             RGBColor[
             0.9634517292595062, 0.9714682476441261, 0.9111629192591895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 281}], {
             RGBColor[
             0.9201681507366926, 0.939123640447966, 0.990254719372744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 384}], {
             RGBColor[
             0.6755573645095427, 0.7427653423229462, 0.9687523044151211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 263}], {
             RGBColor[
             0.8936741248049757, 0.9180423791048838, 0.9892655380463469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 351}], {
             RGBColor[
             0.5964394584697186, 0.6772793695411634, 0.9643299869739269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 246}], {
             RGBColor[
             0.7449359449428828, 0.7969738884960987, 0.8627893271279339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 254}], {
             RGBColor[
             0.48326640536444315`, 0.5913764646351417, 0.9524636481749125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 286}], {
             RGBColor[
             0.6397919887917121, 0.7163068166804631, 0.9662518948314208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 320}], {
             RGBColor[
             0.45441243621971456`, 0.5668179644969973, 0.9505053607539837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 343}], {
             RGBColor[
             0.7452652984858684, 0.7953795502688911, 0.7315395055150788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 349}], {
             RGBColor[
             0.46371457805600735`, 0.5748750122163511, 0.9510980850062312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 252}], {
             RGBColor[
             0.6893267342791951, 0.7543407489395462, 0.9645080660311517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 277}], {
             RGBColor[
             0.7040619145512799, 0.7653302222598237, 0.93956524938103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 287}], {
             RGBColor[
             0.4304570133467286, 0.5472619623875349, 0.9486493181456304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 293}], {
             RGBColor[
             0.6367340627379536, 0.4243053679900574, 0.5667521474672922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 299}], {
             RGBColor[
             0.4508218217808081, 0.5645362254400216, 0.9500477163146167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 336}], {
             RGBColor[
             0.6107532403117659, 0.6921659709406967, 0.9641489454282189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 367}], {
             RGBColor[
             0.6908590635997447, 0.755483557637853, 0.961914232186955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 396}], {
             RGBColor[
             0.6804404720293501, 0.7474629512627047, 0.9708673529569114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 271}], {
             RGBColor[
             0.6949043031728236, 0.7607538978850243, 0.9707926266631277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 326}], {
             RGBColor[
             0.5974133893032139, 0.6840461284596613, 0.9614497168847521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 335}], {
             RGBColor[
             0.6313812939574911, 0.7111292402932553, 0.9644612467608152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 337}], {
             RGBColor[
             0.6733794260666361, 0.7439385002945456, 0.9686472280745959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 354}], {
             RGBColor[
             0.5567575523298318, 0.6510398884800861, 0.9582491404709695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 245}], {
             RGBColor[
             0.6354490478615935, 0.7128390002337213, 0.9658703622946789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 248}], {
             RGBColor[
             0.8850452429061865, 0.9088481188203524, 0.8841656926287025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 292}], {
             RGBColor[
             0.8196990667515962, 0.859404741400802, 0.9825759401837983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 304}], {
             RGBColor[
             0.5601416301148744, 0.6486714059280861, 0.9607789850733819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 309}], {
             RGBColor[
             0.5699226775579285, 0.657143257613521, 0.9614022247674127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 315}], {
             RGBColor[
             0.7851490759925408, 0.8320836926101447, 0.9792199803258097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 319}], {
             RGBColor[
             0.8012918295973591, 0.8447273101451553, 0.9808202414716926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 329}], {
             RGBColor[
             0.86588942331904, 0.8957834915716727, 0.9713040329358289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 334}], {
             RGBColor[
             0.7419400221500856, 0.7983284513474465, 0.9749133056503596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 371}], {
             RGBColor[
             0.7105917599741809, 0.7738389506800128, 0.9717888038428313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 388}], {
             RGBColor[
             0.7550142715655204, 0.8085421543587599, 0.9762164246462828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 255}], {
             RGBColor[
             0.708276623658431, 0.7717480242089574, 0.9717510794153399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 288}], {
             RGBColor[
             0.7304254818613696, 0.789333204960154, 0.9737656438838771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 339}], {
             RGBColor[
             0.6812621930921262, 0.749816492489003, 0.9696244044840407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 360}], {
             RGBColor[
             0.8766591174573668, 0.9040647873799479, 0.9656920376680358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 374}], {
             RGBColor[
             0.8887727770909358, 0.9129779736898148, 0.9397609251014709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 375}], {
             RGBColor[
             0.7001750377907225, 0.7651707918292676, 0.9711132928987471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 399}], {
             RGBColor[
             0.7922243270467082, 0.8376109325075598, 0.9799251752289088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 256}], {
             RGBColor[
             0.633671776994247, 0.6987699649206538, 0.8586122744290898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 257}], {
             RGBColor[
             0.9711036269807172, 0.976632444067556, 0.8739125740344953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 268}], {
             RGBColor[
             0.9406735685642753, 0.9527362488738313, 0.8837657079121768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 317}], {
             RGBColor[
             0.9114517355354332, 0.6138742978052755, 0.4776210066967712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 333}], {
             RGBColor[
             0.9924857460959753, 0.9889593312154754, 0.6141795527946416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 381}], {
             RGBColor[
             0.9924651845249421, 0.9911521744122078, 0.7745349221064817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 382}], {
             RGBColor[
             0.95316455803174, 0.9626962248163111, 0.8849571096384214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 348}], {
             RGBColor[
             0.8886800301892055, 0.9106633948160398, 0.8263593335498072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 351}], {
             RGBColor[
             0.5621568833311902, 0.6502457370571638, 0.9609798466803722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 253}], {
             RGBColor[
             0.8468478725136497, 0.8771560419177397, 0.7558910639879235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 270}], {
             RGBColor[
             0.9445288697209342, 0.9540754833278056, 0.7654650369952651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 308}], {
             RGBColor[
             0.9933122545834239, 0.9881039137257546, 0.5134583672653161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 397}], {
             RGBColor[
             0.7633213726673908, 0.8102304464127228, 0.7487104863640849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 248}], {
             RGBColor[
             0.7419497149676424, 0.794762912190295, 0.871474349454187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 292}], {
             RGBColor[
             0.6766035388130522, 0.7453195347707446, 0.9698845970092829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 304}], {
             RGBColor[
             0.4170461021763303, 0.5345861992980289, 0.9480876418988664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 315}], {
             RGBColor[
             0.6420535480539967, 0.7179984859800873, 0.9665286371512942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 319}], {
             RGBColor[
             0.658196301658815, 0.7306421035150981, 0.9681288982971772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 329}], {
             RGBColor[
             0.7227938953804959, 0.7816982849416153, 0.9586126897613134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 353}], {
             RGBColor[
             0.5811717728572569, 0.6704371804777649, 0.9604605107722199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 371}], {
             RGBColor[
             0.5674962320356368, 0.6597537440499555, 0.9590974606683158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 378}], {
             RGBColor[
             0.7159817562761872, 0.776617802751476, 0.9701438643744799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 388}], {
             RGBColor[
             0.6119187436269762, 0.6944569477287026, 0.9635250814717673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 254}], {
             RGBColor[
             0.7309477706350208, 0.785617658432905, 0.8616881268060481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 286}], {
             RGBColor[
             0.8874733540622898, 0.9105480104782264, 0.8754763734625564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 320}], {
             RGBColor[
             0.7020938014902922, 0.7610591582947606, 0.8597298393851193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 343}], {
             RGBColor[
             0.9929466637564461, 0.9896207440666543, 0.6407639841462145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 344}], {
             RGBColor[
             0.7537916750432199, 0.8041633691376469, 0.8634864826410407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 349}], {
             RGBColor[
             0.7113959433265851, 0.7691162060141143, 0.8603225636373668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 289}], {
             RGBColor[
             0.4945344283092302, 0.6005243532803687, 0.9533507082172543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 302}], {
             RGBColor[
             0.427209186742027, 0.5438538758344703, 0.9486067649130359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 340}], {
             RGBColor[
             0.6735757831098393, 0.7427813824975055, 0.9697384159679938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 391}], {
             RGBColor[
             0.6797971947583856, 0.7477421672703359, 0.970331819764952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 292}], {
             RGBColor[
             0.9261997338576451, 0.9413286533573758, 0.8881799273433064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 304}], {
             RGBColor[
             0.6666422972209233, 0.7305953178846599, 0.86638297223289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 315}], {
             RGBColor[
             0.8916497430985897, 0.9140076045667185, 0.8848239674853178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 319}], {
             RGBColor[
             0.907792496703408, 0.9266512221017291, 0.8864242286312007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 329}], {
             RGBColor[
             0.9723900904250888, 0.9777074035282465, 0.876908020095337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 353}], {
             RGBColor[
             0.8307679679018498, 0.866446299064396, 0.8787558411062435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 388}], {
             RGBColor[
             0.8615149386715693, 0.8904660663153336, 0.8818204118057908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 270}], {
             RGBColor[
             0.710585377980133, 0.7726568747098761, 0.9728482630742455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 308}], {
             RGBColor[
             0.7593687628426227, 0.8066853051078251, 0.7208415933442964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 309}], {
             RGBColor[
             0.44348970981539243`, 0.5565854679903655, 0.9500226193684962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 334}], {
             RGBColor[
             0.6155070544075496, 0.697770661724291, 0.963533700251443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 386}], {
             RGBColor[
             0.6816753555070244, 0.7496048075314742, 0.9700907993224788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 397}], {
             RGBColor[
             0.5293778809265894, 0.6288118377947933, 0.9560937124430653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 265}], {
             RGBColor[
             0.6575769085945009, 0.7315216112035491, 0.9671212998148784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 276}], {
             RGBColor[
             0.8543482621305609, 0.886346033279035, 0.9488217364400112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 289}], {
             RGBColor[
             0.6227488969882704, 0.7032466623975684, 0.9643795111620257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 391}], {
             RGBColor[
             0.8080116634374259, 0.8504644763875355, 0.9813606227097234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 282}], {
             RGBColor[
             0.6745405368604733, 0.7438642587779162, 0.9694694781846959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 312}], {
             RGBColor[
             0.7413969549494221, 0.7979892886742241, 0.9748365986978484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 356}], {
             RGBColor[
             0.7888774677535666, 0.8350814261420845, 0.9795690124835463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 277}], {
             RGBColor[
             0.9584950110291953, 0.9685662277005316, 0.9551412994794604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 293}], {
             RGBColor[
             0.891167159215869, 0.6275413734307653, 0.5823281975657225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 330}], {
             RGBColor[
             0.960035918674199, 0.9697154340991707, 0.9525329447695481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 386}], {
             RGBColor[
             0.7689010959648074, 0.8195336132138167, 0.9775625947180214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 286}], {
             RGBColor[
             0.62580381448385, 0.7049505866172694, 0.9651506945095352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 320}], {
             RGBColor[
             0.4404242619118525, 0.5554617344338035, 0.949404160432098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 343}], {
             RGBColor[
             0.7312771241780065, 0.7840233202056973, 0.7304383051931931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 344}], {
             RGBColor[
             0.4921221354647801, 0.5985659452766898, 0.9531608036880193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 349}], {
             RGBColor[
             0.4497264037481453, 0.5635187821531573, 0.9499968846843455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 288}], {
             RGBColor[
             0.6460778392014429, 0.723157861062888, 0.9655516858613553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 341}], {
             RGBColor[
             0.7318411610566325, 0.7903166081460663, 0.9740573693983215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 360}], {
             RGBColor[
             0.7923114747974401, 0.837889443482682, 0.9574780796455139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 374}], {
             RGBColor[
             0.8044251344310092, 0.8468026297925488, 0.9315469670789491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 393}], {
             RGBColor[
             0.6732530599117152, 0.7443873500210798, 0.9682602578948791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 399}], {
             RGBColor[
             0.7078766843867816, 0.7714355886102939, 0.9717112172063869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 261}], {
             RGBColor[
             0.5285608175780371, 0.6180595305958231, 0.9589430384193915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 264}], {
             RGBColor[
             0.4321178530530837, 0.5419022050610054, 0.9498879633542241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 317}], {
             RGBColor[
             0.552882287236677, 0.3215847012116179, 0.557986774958241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 333}], {
             RGBColor[
             0.6339162977972189, 0.6966697346218178, 0.6945453210561114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 381}], {
             RGBColor[
             0.6338957362261859, 0.6988625778185502, 0.8549006903679515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 268}], {
             RGBColor[
             0.9195359702519891, 0.938309131427076, 0.9794317757790522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 338}], {
             RGBColor[
             0.9036047098405233, 0.9256059768175169, 0.9779122379390025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 381}], {
             RGBColor[
             0.971327586212656, 0.9767250569654524, 0.8702009899733569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 382}], {
             RGBColor[
             0.9320269597194538, 0.9482691073695557, 0.9806231775052969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 278}], {
             RGBColor[
             0.7480398334495796, 0.7988485857356464, 0.8314655823428443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 284}], {
             RGBColor[
             0.9827776806096611, 0.9847135728392191, 0.8219926899254573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 369}], {
             RGBColor[
             0.9943753330662957, 0.9903777311068951, 0.6291678995659978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 392}], {
             RGBColor[
             0.9203347089708067, 0.9358192689605034, 0.8471026329962665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 274}], {
             RGBColor[
             0.8588400570969643, 0.8902797652095467, 0.9863981254131201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 299}], {
             RGBColor[
             0.678086736372898, 0.7463169267356458, 0.9702393075234645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 318}], {
             RGBColor[
             0.7472248319927823, 0.8024463473955814, 0.975682111671851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 336}], {
             RGBColor[
             0.8380181549038559, 0.8739466722363209, 0.9843405366370668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 367}], {
             RGBColor[
             0.9181239781918347, 0.9372642589334772, 0.9821058233958029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 267}], {
             RGBColor[
             0.8099740286676016, 0.8490224598733243, 0.8275637284203496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 272}], {
             RGBColor[
             0.6022594772443963, 0.6879804009640873, 0.961831218679287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 291}], {
             RGBColor[
             0.809429447145249, 0.8478576550626499, 0.7682893904798473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 321}], {
             RGBColor[
             0.7096902000825736, 0.7728687274130065, 0.9718807542494144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 338}], {
             RGBColor[
             0.7411216926601896, 0.7977244020894906, 0.9749336347302042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 342}], {
             RGBColor[
             0.7607252073883004, 0.8133557126104545, 0.9768034354652355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 384}], {
             RGBColor[
             0.5190933199642127, 0.6193727075309425, 0.955585150534743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 398}], {
             RGBColor[
             0.7082614422678153, 0.7717525709491558, 0.9717383490229402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 264}], {
             RGBColor[
             0.68557634193563, 0.7534813673298323, 0.969852959083056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 295}], {
             RGBColor[
             0.8051379768345261, 0.8477660385968283, 0.9811945433120233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 310}], {
             RGBColor[
             0.6792977244065606, 0.7483841027712375, 0.9693586833118338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 381}], {
             RGBColor[
             0.8873542251087321, 0.9104417400873771, 0.8748656860967834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 269}], {
             RGBColor[
             0.43468571236110837`, 0.5505487762115195, 0.9490226218604483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 298}], {
             RGBColor[
             0.6422400518630292, 0.3562142276147652, 0.5577068899171376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 300}], {
             RGBColor[
             0.6947234937009885, 0.7595856001810257, 0.971822712412627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 306}], {
             RGBColor[
             0.3564621890411685, 0.4769723086212646, 0.944251503391729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 307}], {
             RGBColor[
             0.4450494993580072, 0.559525367609153, 0.9496829932035535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 314}], {
             RGBColor[
             0.5080291124601002, 0.611479945802638, 0.9544130591862676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 310}], {
             RGBColor[
             0.5828547598816072, 0.6722267772364197, 0.9603036082466665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 333}], {
             RGBColor[
             0.7909318221548118, 0.832091571355827, 0.7054552417197759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 381}], {
             RGBColor[
             0.7909112605837787, 0.8342844145525594, 0.8658106110316159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 322}], {
             RGBColor[
             0.7768592050853045, 0.7919837399046057, 0.6495906510090058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 362}], {
             RGBColor[
             0.6255055242349005, 0.7064672019902802, 0.9639247239460402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 273}], {
             RGBColor[
             0.8195849937649292, 0.859726801960087, 0.982455457187427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 365}], {
             RGBColor[
             0.7823058843192152, 0.8306040783293698, 0.978739823950963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 272}], {
             RGBColor[
             0.7872335116042346, 0.8305606836726637, 0.8257735116158627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 291}], {
             RGBColor[
             0.9944034815050871, 0.9904379377712262, 0.632231683416423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 321}], {
             RGBColor[
             0.8946642344424116, 0.9154490101215829, 0.83582304718599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 331}], {
             RGBColor[
             0.7786493340288014, 0.8235916616041343, 0.825097733712246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 342}], {
             RGBColor[
             0.9456992417481385, 0.9559359953190308, 0.8407457284018112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 346}], {
             RGBColor[
             0.7400889578516201, 0.7922866110983477, 0.8220621196482661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 384}], {
             RGBColor[
             0.7040673543240509, 0.7619529902395189, 0.8195274434713186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 398}], {
             RGBColor[
             0.8932354766276533, 0.9143328536577322, 0.8356806419595157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 338}], {
             RGBColor[
             0.8731746514240813, 0.9017097816237925, 0.987765371816684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 381}], {
             RGBColor[
             0.9408975277962139, 0.9528288617717278, 0.8800541238510384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 279}], {
             RGBColor[
             0.5717025898502659, 0.6602712105968565, 0.9608442493043303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 298}], {
             RGBColor[
             0.6097646604980791, 0.3284615485967543, 0.5555337319433107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 300}], {
             RGBColor[
             0.6622481023360385, 0.7318329211630148, 0.9696495544388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 306}], {
             RGBColor[
             0.3239867976762184, 0.4492196296032537, 0.942078345417902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 307}], {
             RGBColor[
             0.4125741079930571, 0.5317726885911421, 0.9475098352297266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 314}], {
             RGBColor[
             0.47555372109515004`, 0.5837272667846272, 0.9522399012124407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 308}], {
             RGBColor[
             0.9442755005076902, 0.9535335522002335, 0.7378873617471808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 397}], {
             RGBColor[
             0.7142846185916569, 0.7756600848872017, 0.9731394808459496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 273}], {
             RGBColor[
             0.7645347908242797, 0.8159796563623289, 0.977165341031685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 326}], {
             RGBColor[
             0.7041337190668135, 0.7682467534882131, 0.971519200090767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 335}], {
             RGBColor[
             0.7381016237210909, 0.7953298653218073, 0.9745307299668301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 394}], {
             RGBColor[
             0.6662230321345599, 0.737469149979626, 0.968534731944038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 291}], {
             RGBColor[
             0.7866889300818819, 0.8293958788619893, 0.7664991736753604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 321}], {
             RGBColor[
             0.6869496830192064, 0.7544069512123459, 0.9700905374449275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 331}], {
             RGBColor[
             0.5709347826055963, 0.6625496026948974, 0.9593652239711834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 338}], {
             RGBColor[
             0.7183811755968225, 0.77926262588883, 0.9731434179257172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 342}], {
             RGBColor[
             0.7379846903249333, 0.7948939364097939, 0.9750132186607485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 346}], {
             RGBColor[
             0.5323744064284148, 0.6312445521891108, 0.9563296099072036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 384}], {
             RGBColor[
             0.49635280290084566`, 0.600910931330282, 0.953794933730256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 398}], {
             RGBColor[
             0.6855209252044482, 0.7532907947484953, 0.9699481322184532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 365}], {
             RGBColor[
             0.6901658392664218, 0.7578820661803644, 0.9697529389577635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 394}], {
             RGBColor[
             0.6291331900224162, 0.7084942834283787, 0.9648379631065804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 287}], {
             RGBColor[
             0.6271385180503232, 0.704656282802619, 0.9659238364171812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 299}], {
             RGBColor[
             0.6475033264844026, 0.7219305458551057, 0.9673222345861676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 318}], {
             RGBColor[
             0.7166414221042869, 0.7780599665150414, 0.9727650387345539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 367}], {
             RGBColor[
             0.8875405683033393, 0.9128778780529372, 0.979188750458506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 373}], {
             RGBColor[
             0.6028428271853931, 0.6836125765123456, 0.9643757364791037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 395}], {
             RGBColor[
             0.86288135857649, 0.8935021893111141, 0.9867835883559497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 279}], {
             RGBColor[
             0.8650851169124811, 0.8937276862698507, 0.9036045649979441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 281}], {
             RGBColor[
             0.9456917965977751, 0.9573644413433369, 0.9114618953874034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 306}], {
             RGBColor[
             0.6173693247384336, 0.6826761052762479, 0.8848386611115159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 338}], {
             RGBColor[
             0.9231093830666022, 0.9393578377768652, 0.9093079646252415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 384}], {
             RGBColor[
             0.7010810103706253, 0.761006143218317, 0.8899594804297803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 322}], {
             RGBColor[
             0.9736305586213647, 0.9468081619800917, 0.6312910876341387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 358}], {
             RGBColor[
             0.9841503914359345, 0.9865250621495542, 0.8590987300296633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 376}], {
             RGBColor[
             0.9023076207285052, 0.9238736314208131, 0.9535855880180154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 377}], {
             RGBColor[
             0.983498589526175, 0.9862555253093236, 0.8699007744836482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 287}], {
             RGBColor[
             0.6996252900967288, 0.7614874411485203, 0.9392825515939389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 330}], {
             RGBColor[
             0.9747710989462838, 0.9807049074194482, 0.9275901281194265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 396}], {
             RGBColor[
             0.9496087487793502, 0.9616884300236901, 0.96150058640522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 284}], {
             RGBColor[
             0.7357080474154798, 0.7916141899780629, 0.9443844633424789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 327}], {
             RGBColor[
             0.5157965787112346, 0.6177859248256761, 0.9550245425827233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 337}], {
             RGBColor[
             0.6297725394897233, 0.7085364653035545, 0.9652143342259726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 354}], {
             RGBColor[
             0.513150665752919, 0.6156378534890949, 0.9548162466223462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 392}], {
             RGBColor[
             0.6732650757766254, 0.7427198860993471, 0.9694944064132882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 300}], {
             RGBColor[
             0.8317403711901461, 0.8693080345663626, 0.983644339856509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 306}], {
             RGBColor[
             0.4934790665303261, 0.5866947430066015, 0.9560731308356111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 363}], {
             RGBColor[
             0.5643813817769071, 0.6539299481383302, 0.960377748399786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 384}], {
             RGBColor[
             0.6577974318478118, 0.728661536022157, 0.9690512805433349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 386}], {
             RGBColor[
             0.8700401443869725, 0.8992104107963288, 0.987466399737277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 350}], {
             RGBColor[
             0.416055526506483, 0.5330163706304859, 0.9482212073061806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 369}], {
             RGBColor[
             0.9820435470321958, 0.9831433353493114, 0.7420867805656326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 392}], {
             RGBColor[
             0.9080029229367069, 0.9285848732029197, 0.9600215139959012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 330}], {
             RGBColor[
             0.9849125800468821, 0.9851938650088494, 0.7301533741046508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 387}], {
             RGBColor[
             0.8015032910957112, 0.8411934324160913, 0.7488628383178133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 320}], {
             RGBColor[
             0.5969498453391214, 0.6803920864791249, 0.9631924070886062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 343}], {
             RGBColor[
             0.8878027076052754, 0.9089536722510188, 0.7442265518497014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 349}], {
             RGBColor[
             0.6062519871754142, 0.6884491341984788, 0.9637851313408539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 367}], {
             RGBColor[
             0.6864224391451934, 0.7516407765265496, 0.961631534399864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 373}], {
             RGBColor[
             0.4017246980272473, 0.522375474985958, 0.9468185204204618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 395}], {
             RGBColor[
             0.6617632294183442, 0.7322650877847265, 0.9692263722973078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 396}], {
             RGBColor[
             0.6760038475747989, 0.7436201701514011, 0.9705846551698203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 341}], {
             RGBColor[
             0.7539900192595711, 0.8079017888972628, 0.9760719338668588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 355}], {
             RGBColor[
             0.7103927355337476, 0.7736834712745045, 0.9717689669465979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 360}], {
             RGBColor[
             0.8144603330003787, 0.8554746242338784, 0.9594926441140511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 374}], {
             RGBColor[
             0.8265739926339477, 0.8643878105437455, 0.9335615315474863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 375}], {
             RGBColor[
             0.6379762533337345, 0.7165806286831982, 0.9649138993447625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 379}], {
             RGBColor[
             0.817977887051653, 0.8580980102858526, 0.953538342630272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 393}], {
             RGBColor[
             0.6954019181146538, 0.7619725307722763, 0.9702748223634163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 399}], {
             RGBColor[
             0.7300255425897202, 0.7890207693614903, 0.9737257816749241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 302}], {
             RGBColor[
             0.4465128705361622, 0.559525475959594, 0.9501264216130338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 340}], {
             RGBColor[
             0.6928794669039745, 0.7584529826226292, 0.9712580726679918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 391}], {
             RGBColor[
             0.6991008785525208, 0.7634137673954596, 0.9718514764649498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 313}], {
             RGBColor[
             0.37872931196178594`, 0.4989345495596348, 0.945650835360802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 321}], {
             RGBColor[
             0.536311344146343, 0.6245379682266845, 0.9596484657129758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 331}], {
             RGBColor[
             0.4202964437327328, 0.5326806197092359, 0.9489231522392317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 342}], {
             RGBColor[
             0.5873463514520698, 0.6650249534241324, 0.964571146928797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 346}], {
             RGBColor[
             0.38173606755555134`, 0.5013755692034493, 0.9458875381752518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 321}], {
             RGBColor[
             0.894119652920059, 0.9142842053109086, 0.7765487092454879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 331}], {
             RGBColor[
             0.7781047525064488, 0.82242685679346, 0.7658233957717437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 338}], {
             RGBColor[
             0.925551145497675, 0.9391398799873927, 0.7796015897262776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 342}], {
             RGBColor[
             0.9451546602257859, 0.9547711905083565, 0.781471390461309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 384}], {
             RGBColor[
             0.7035227728016982, 0.7607881854288445, 0.7602531055308164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 398}], {
             RGBColor[
             0.8926908951053008, 0.9131680488470579, 0.7764063040190137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 304}], {
             RGBColor[
             0.601296121066333, 0.6811519404651095, 0.9647932197879858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 329}], {
             RGBColor[
             0.9070439142704987, 0.9282640261086961, 0.9753182676504328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 353}], {
             RGBColor[
             0.7654217917472597, 0.8170029216448456, 0.9771660886613394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 378}], {
             RGBColor[
             0.90023177516619, 0.9231835439185567, 0.9868494422635993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 388}], {
             RGBColor[
             0.796168762516979, 0.8410226888957832, 0.9802306593608867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 299}], {
             RGBColor[
             0.6526622467174819, 0.4377368499312407, 0.5678678478491875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 330}], {
             RGBColor[
             0.9074432471329574, 0.6396800531496818, 0.5547770262056886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 336}], {
             RGBColor[
             0.8125936652484398, 0.5653665954319158, 0.5819690769627898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 341}], {
             RGBColor[
             0.6354862144133359, 0.7114912844400629, 0.9666377471270644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 368}], {
             RGBColor[
             0.6977782036568889, 0.7604227223839062, 0.946974835917173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 393}], {
             RGBColor[
             0.5768981132684186, 0.6655620263150763, 0.960840635623622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 310}], {
             RGBColor[
             0.7024163947805033, 0.7665114485034157, 0.9716451924756337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 345}], {
             RGBColor[
             0.9071162346288277, 0.9151243402233242, 0.6917500993455207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 363}], {
             RGBColor[
             0.6079122760289548, 0.6880034783027313, 0.9646987572766779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 316}], {
             RGBColor[
             0.7089605741740468, 0.7672149457585544, 0.8678174036736278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 324}], {
             RGBColor[
             0.4820076125698553, 0.589618841165465, 0.9525678216314131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 360}], {
             RGBColor[
             0.6934587421740859, 0.7569006631031263, 0.9498993006603129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 374}], {
             RGBColor[
             0.705572401807655, 0.7658138494129934, 0.923968188093748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 375}], {
             RGBColor[
             0.5169746625074417, 0.618006667552446, 0.9553205558910243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 380}], {
             RGBColor[
             0.7097864398383498, 0.7658892032037151, 0.732938526747751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 383}], {
             RGBColor[
             0.5013998290521668, 0.6053623161152026, 0.9540944479489302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 390}], {
             RGBColor[
             0.7056591744896135, 0.7658497321469393, 0.9225301401931936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 307}], {
             RGBColor[
             0.6625155780513956, 0.7327589880018159, 0.9693469305987885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 314}], {
             RGBColor[
             0.7254951911534885, 0.7847135661953009, 0.9740769965815025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 332}], {
             RGBColor[
             0.7675779370912612, 0.8188782351536849, 0.9773899044959016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 352}], {
             RGBColor[
             0.6903370217869751, 0.7561705804460849, 0.9713092167003525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 385}], {
             RGBColor[
             0.7222683987034351, 0.7820939107190042, 0.973822971659704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 306}], {
             RGBColor[
             0.5315411371781393, 0.2548850810064994, 0.5507626134745914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 307}], {
             RGBColor[
             0.620128447494978, 0.3374381399943878, 0.556194103286416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 314}], {
             RGBColor[
             0.683108060597071, 0.3893927181878728, 0.56092416926913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 336}], {
             RGBColor[
             0.6266814242912941, 0.7055974528818799, 0.9652646458101143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 367}], {
             RGBColor[
             0.7067872475792729, 0.7689150395790363, 0.9630299325688504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 306}], {
             RGBColor[
             0.5840245790160985, 0.6582564535727599, 0.9648784359700808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 307}], {
             RGBColor[
             0.6726118893329373, 0.7408095125606483, 0.9703099257819054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 314}], {
             RGBColor[
             0.7355915024350301, 0.7927640907541333, 0.9750399917646194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 363}], {
             RGBColor[
             0.6549268942626796, 0.7254916587044885, 0.9691830535342557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 316}], {
             RGBColor[
             0.9280178243467443, 0.9427492302213674, 0.8870888847877436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 324}], {
             RGBColor[
             0.7010648627425529, 0.765153125628278, 0.9718393027455288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 372}], {
             RGBColor[
             0.9265279810054696, 0.9421331417125228, 0.9117794445436396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 380}], {
             RGBColor[
             0.9288436900110475, 0.9414234876665281, 0.7522100078618668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 383}], {
             RGBColor[
             0.7204570792248645, 0.7808966005780156, 0.973365929063046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 390}], {
             RGBColor[
             0.9247164246623112, 0.9413840166097522, 0.9418016213073093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 323}], {
             RGBColor[
             0.3539549687007507, 0.48099973641975413`, 0.9437746755088905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 340}], {
             RGBColor[
             0.6255542253367713, 0.7017825051767308, 0.9665141293637733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 313}], {
             RGBColor[
             0.5126272076825886, 0.6152128866460834, 0.9547750380855596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 344}], {
             RGBColor[
             0.5305020568749435, 0.6297244944732165, 0.9561822116917118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 315}], {
             RGBColor[
             0.5667461303072776, 0.6538308916744522, 0.9614372599299972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 329}], {
             RGBColor[
             0.6474864776337768, 0.7175306906359802, 0.9535213125400164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 353}], {
             RGBColor[
             0.5058643551105377, 0.6062695861721298, 0.9553691335509229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 378}], {
             RGBColor[
             0.6406743385294682, 0.7124502084458408, 0.9650524871531829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 325}], {
             RGBColor[
             0.669871386504678, 0.7378730518610046, 0.9688660381925203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 314}], {
             RGBColor[
             0.48591750809204887`, 0.5927038581822606, 0.952900272555546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 352}], {
             RGBColor[
             0.45075933872553553`, 0.5641608724330447, 0.9501324926743961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 385}], {
             RGBColor[
             0.48269071564199545`, 0.5900842027059641, 0.9526462476337476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 386}], {
             RGBColor[
             0.9153654780345817, 0.9304814850218316, 0.735129897995414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 397}], {
             RGBColor[
             0.7630680034541466, 0.8096885152851507, 0.7211328111160005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 319}], {
             RGBColor[
             0.59266993135515, 0.6749463608948978, 0.9636607607699109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 329}], {
             RGBColor[
             0.657267525076831, 0.7260025423214149, 0.9541445522340473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 334}], {
             RGBColor[
             0.5333181239078766, 0.6285475020971889, 0.957753824948578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 371}], {
             RGBColor[
             0.5019698617319719, 0.6040580014297552, 0.9546293231410496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 386}], {
             RGBColor[
             0.5994864250073515, 0.6803816479043721, 0.9643109240196136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 345}], {
             RGBColor[
             0.7812759822008621, 0.8157424043977333, 0.6799142393453312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 363}], {
             RGBColor[
             0.4820720236009892, 0.5886215424771404, 0.9528628972764885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 323}], {
             RGBColor[
             0.6175438690611721, 0.5628108177282126, 0.592842251716388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 339}], {
             RGBColor[
             0.7381327747778483, 0.6640933890011975, 0.601400701127015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 327}], {
             RGBColor[
             0.5914529502736405, 0.6790551533851226, 0.9610844276685981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 356}], {
             RGBColor[
             0.6997634561843546, 0.7653797974612437, 0.9707095397173136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 361}], {
             RGBColor[
             0.8196426151397981, 0.8585903929236793, 0.9155231996097135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 344}], {
             RGBColor[
             0.49709119068062435`, 0.6026000481542988, 0.9535519859168595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 359}], {
             RGBColor[
             0.3894605544413865, 0.5102137658057662, 0.9462619637445646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 385}], {
             RGBColor[
             0.5456703287440884, 0.642038780899449, 0.9573763136164617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 319}], {
             RGBColor[
             0.8078963297897623, 0.8498867958915214, 0.981478516328308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 329}], {
             RGBColor[
             0.8724939235114432, 0.9009429773180386, 0.9719623077924442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 334}], {
             RGBColor[
             0.7485445223424889, 0.8034879370938125, 0.9755715805069749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 371}], {
             RGBColor[
             0.7171962601665841, 0.7789984364263789, 0.9724470786994466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 324}], {
             RGBColor[
             0.7647446709921061, 0.8132386673714391, 0.8720056618826247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 355}], {
             RGBColor[
             0.8721282031297055, 0.8987293363497265, 0.8816134637440713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 380}], {
             RGBColor[
             0.9925234982606006, 0.9895090294096892, 0.6523763669989626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 383}], {
             RGBColor[
             0.7841368874744177, 0.8289821423211767, 0.873532288200142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 390}], {
             RGBColor[
             0.9883962329118643, 0.9894695583529134, 0.8419679804444051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 333}], {
             RGBColor[
             0.9116962563384051, 0.6117740675064396, 0.31355405332379294`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 370}], {
             RGBColor[
             0.670198232329003, 0.4247766310524186, 0.5657713993177932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 381}], {
             RGBColor[
             0.9116756947673721, 0.6139669107031719, 0.47390942263563285`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 382}], {
             RGBColor[
             0.8723750682741699, 0.5855109611072752, 0.5843316101675727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 367}], {
             RGBColor[
             0.7759253431991573, 0.8250444602389719, 0.9684727367172368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 373}], {
             RGBColor[
             0.4912276020812111, 0.5957791586983804, 0.9536597227378345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 329}], {
             RGBColor[
             0.8886366771162615, 0.9135865948530494, 0.9735625689383272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 334}], {
             RGBColor[
             0.7646872759473071, 0.8161315546288233, 0.9771718416528579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 371}], {
             RGBColor[
             0.7333390137714024, 0.7916420539613895, 0.9740473398453295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 388}], {
             RGBColor[
             0.7777615253627419, 0.8263452576401367, 0.978474960648781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 343}], {
             RGBColor[
             0.7024231550332778, 0.7594648200675529, 0.7284800177722643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 349}], {
             RGBColor[
             0.4208724346034167, 0.5389602820150128, 0.9480385972634167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 331}], {
             RGBColor[
             0.6783655054437734, 0.7474379291438166, 0.9694147595413108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 338}], {
             RGBColor[
             0.8258118984349996, 0.8641509523377493, 0.9831929534958446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 342}], {
             RGBColor[
             0.8454154131631104, 0.8797822628587131, 0.9850627542308761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 384}], {
             RGBColor[
             0.6037835257390227, 0.6857992577792011, 0.9638444693003834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 398}], {
             RGBColor[
             0.7929516480426253, 0.8381791211974146, 0.9799976677885807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 328}], {
             RGBColor[
             0.8582759404695951, 0.8564888470277846, 0.6570889894038419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 362}], {
             RGBColor[
             0.8188705940043788, 0.8257050908774322, 0.6531614327320885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 364}], {
             RGBColor[
             0.8167363829581797, 0.8240378289875367, 0.6529487145203395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 340}], {
             RGBColor[
             0.6003215650685629, 0.6799272430827893, 0.9649063265638484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 375}], {
             RGBColor[
             0.572758759325501, 0.6640303891653307, 0.9595088141000212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 380}], {
             RGBColor[
             0.7655705366564092, 0.8119129248165999, 0.7371267849567479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 383}], {
             RGBColor[
             0.5571839258702262, 0.6513860377280873, 0.9582827061579271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 390}], {
             RGBColor[
             0.7614432713076729, 0.8118734537598241, 0.9267183984021905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 335}], {
             RGBColor[
             0.640610709851481, 0.7186220958964442, 0.9651878201884545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 337}], {
             RGBColor[
             0.6826088419606262, 0.7514313558977346, 0.9693738015022353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 354}], {
             RGBColor[
             0.5659869682238219, 0.658532744083275, 0.9589757138986088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 337}], {
             RGBColor[
             0.6445989179455598, 0.7205731872547403, 0.9663815210488298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 354}], {
             RGBColor[
             0.5279770442087555, 0.6276745754402808, 0.9559834334452033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 356}], {
             RGBColor[
             0.6389334630777852, 0.716147290852983, 0.9658168414542959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 392}], {
             RGBColor[
             0.6880914542324619, 0.7547566080505329, 0.9706615932361455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 347}], {
             RGBColor[
             0.7689252481561373, 0.8194095149986877, 0.9776029407873681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 362}], {
             RGBColor[
             0.7069222596191911, 0.7709723091134592, 0.9714230623408763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 372}], {
             RGBColor[
             0.8675227759990778, 0.8956793301053255, 0.9059934912246306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 387}], {
             RGBColor[
             0.6779105173866765, 0.7478046569481913, 0.9688756604242345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 334}], {
             RGBColor[
             0.8292848696689881, 0.8671877360553405, 0.9676556331169941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 353}], {
             RGBColor[
             0.8116121483147033, 0.8533816718157162, 0.9658941814133699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 371}], {
             RGBColor[
             0.7979366074930833, 0.8426982353879069, 0.9645311313094658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 388}], {
             RGBColor[
             0.8423591190844226, 0.8774014390666538, 0.9689587521129173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 342}], {
             RGBColor[
             0.7294005127495002, 0.7879249143412645, 0.9743374407571319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 346}], {
             RGBColor[
             0.5237902288529818, 0.6242755301205813, 0.955653832003587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 361}], {
             RGBColor[
             0.8100324499845367, 0.8509404500732444, 0.9146627138274348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 385}], {
             RGBColor[
             0.5877530746818611, 0.676203449857833, 0.9606892215308608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 381}], {
             RGBColor[
             0.9927097053279139, 0.9890519441133718, 0.6104679687335033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 371}], {
             RGBColor[
             0.673987206324129, 0.7452431951636806, 0.9681404040239965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 388}], {
             RGBColor[
             0.7184097179154684, 0.7799463988424278, 0.972568024827448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 337}], {
             RGBColor[
             0.7165767466149034, 0.7785144677313285, 0.9723853313782984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 354}], {
             RGBColor[
             0.5999548728780991, 0.685615855916869, 0.9619872437746719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 367}], {
             RGBColor[
             0.8667186661102309, 0.8965447850797114, 0.9771311616824526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 354}], {
             RGBColor[
             0.6419530049872442, 0.7184251159181594, 0.9661732250884527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 384}], {
             RGBColor[
             0.6352150183166387, 0.7106549324556852, 0.9668973497811731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 398}], {
             RGBColor[
             0.8243831406202413, 0.8630347958738986, 0.9830505482693703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 360}], {
             RGBColor[
             0.7652970442311353, 0.8159579117627274, 0.9553514047142146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 374}], {
             RGBColor[
             0.7774107038647045, 0.8248710980725944, 0.9294202921476498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 368}], {
             RGBColor[
             0.9020453303583138, 0.9239919739242843, 0.9649147061939336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 379}], {
             RGBColor[
             0.9037412089068426, 0.9252567573690309, 0.9620440261672383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 393}], {
             RGBColor[
             0.7811652399698434, 0.8291312778554546, 0.9787805059003826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 399}], {
             RGBColor[
             0.8157888644449098, 0.8561795164446686, 0.9822314652118904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 346}], {
             RGBColor[
             0.6908401365723188, 0.756619863835478, 0.9713018266931521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 398}], {
             RGBColor[
             0.8439866553483522, 0.8786661063948624, 0.9849203490044018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 349}], {
             RGBColor[
             0.7117252968695706, 0.7675218677869067, 0.7290727420245118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 349}], {
             RGBColor[
             0.47257030815634427`, 0.5820644928578993, 0.951795240519338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 362}], {
             RGBColor[
             0.7295199016909208, 0.7886257588483353, 0.9736753841156147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 372}], {
             RGBColor[
             0.8901204180708076, 0.9133327798402017, 0.9082458129993689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 387}], {
             RGBColor[
             0.7005081594584064, 0.7654581066830675, 0.9711279821989729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 351}], {
             RGBColor[
             0.6682618312876265, 0.7308362627512697, 0.8083757515470045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 369}], {
             RGBColor[
             0.9942130888172361, 0.9900307070635666, 0.6115086143113062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 357}], {
             RGBColor[
             0.4770835917420753, 0.582561703271748, 0.9530255601546955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 394}], {
             RGBColor[
             0.422181188571675, 0.5379894590529399, 0.948703441862992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 378}], {
             RGBColor[
             0.8048000092103946, 0.8483011896255769, 0.9774253560265362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 375}], {
             RGBColor[
             0.6801422914631006, 0.7495210581436181, 0.9691166159614679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 379}], {
             RGBColor[
             0.860143925181019, 0.8910384397462726, 0.9577410592469775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 366}], {
             RGBColor[
             0.9863115246100764, 0.9881368317322985, 0.8554404952796455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 391}], {
             RGBColor[
             0.9378137927427994, 0.9506435052580546, 0.8916376162993754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 374}], {
             RGBColor[
             0.9728076282299449, 0.9791193929635393, 0.9254879253316448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 375}], {
             RGBColor[
             0.7842098889297318, 0.831312211102992, 0.956840293128921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 369}], {
             RGBColor[
             0.9903217431941083, 0.9888503097354813, 0.7071656317469923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 385}], {
             RGBColor[
             0.7647229115967105, 0.8141561256385638, 0.9110957809912372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 377}], {
             RGBColor[
             0.8266044138629901, 0.8634851923167687, 0.891558401369849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 387}], {
             RGBColor[
             0.6363709598752612, 0.7153536389079436, 0.9647353855407321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 382}], {
             RGBColor[
             0.9477234997533535, 0.9599755612261126, 0.9540530295412053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 393}], {
             RGBColor[
             0.8434572292133964, 0.878062715799298, 0.9591175946904912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 399}], {
             RGBColor[
             0.8780808536884628, 0.905110954388512, 0.962568554001999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 392}], {
             RGBColor[
             0.9196005753933416, 0.9342490314705957, 0.7671967236364419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 389}], {
             RGBColor[
             0.4706530085811908, 0.5805458805382757, 0.9516338213328097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 391}], {
             RGBColor[
             0.6970489319409096, 0.7617479046970121, 0.9716899397111558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 400}], {
             RGBColor[
             0.6254118478276843, 0.7052641134224096, 0.964687911322928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 395}], {
             RGBColor[
             0.6374675385534141, 0.7112213814944531, 0.9676782723592303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 375}], {
             RGBColor[
             0.7963235485633008, 0.8402253974128591, 0.9309091805623562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 399}], {
             RGBColor[
             0.8883728378192864, 0.9126655380911513, 0.9397210628925179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 379}], {
             RGBColor[
             0.7877274429810059, 0.8339355971549662, 0.950885991645142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 383}], {
             RGBColor[
             0.5921509758078126, 0.6797738641150683, 0.9610354404175383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 399}], {
             RGBColor[
             0.6997750985190732, 0.7648583562306039, 0.9710734306897941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 377}], {
             RGBColor[
             0.9087693678667337, 0.9277344615617109, 0.8997315470284402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 393}], {
             RGBColor[
             0.8451531077619252, 0.8793274992440444, 0.9562469146637959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 399}], {
             RGBColor[
             0.8797767322369916, 0.9063757378332584, 0.9596978739753037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 383}], {
             RGBColor[
             0.7849627531387207, 0.8276563997663373, 0.7386534112742651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 390}], {
             RGBColor[
             0.9892220985761674, 0.9881438157980742, 0.7070891035185283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 390}], {
             RGBColor[
             0.7808354877899844, 0.8276169287095616, 0.9282450247197076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 398}], {
             RGBColor[
             0.6023547679242645, 0.6846831013153505, 0.9637020640739091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 400}], {
             RGBColor[
             0.5863306375287323, 0.6729457659520878, 0.9617744412460737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 399}], {
             RGBColor[
             0.7572007632999924, 0.8102502583196822, 0.9764343537084479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 396}], {
             RGBColor[
             0.9117466881009657, 0.9324660766598962, 0.9914444071085888]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.09653745999529093], {
             RGBColor[
             0.9924379061427775, 0.9861534231348239, 0.4251231226566339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.09653745999529093], {
             RGBColor[
             0.6346341545689248, 0.7142636224787323, 0.9643798718706246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.09653745999529093], {
             RGBColor[
             0.9896993313529787, 0.9900084230464167, 0.8203722669644762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.09653745999529093], {
             RGBColor[
             0.9738803759396449, 0.9800406076595221, 0.9290978898318994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.09653745999529093], {
             RGBColor[
             0.9362917738419911, 0.952007089760779, 0.9927255885056876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.09653745999529093], {
             RGBColor[
             0.653905968209273, 0.7295555793252929, 0.9661388938785473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.09653745999529093], {
             RGBColor[
             0.7567725373277479, 0.8099157249355268, 0.9763916721455338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.09653745999529093], {
             RGBColor[
             0.36505947766395846`, 0.49061790395483595`, 0.9444822450006943]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.09653745999529093], {
             RGBColor[
             0.7124399602097777, 0.7752827787509032, 0.9719730151699023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.09653745999529093], {
             RGBColor[
             0.4630616645372514, 0.5749733458184259, 0.9508730569645917]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.09653745999529093], {
             RGBColor[
             0.7410894767752259, 0.7976639988362217, 0.974828531236192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.09653745999529093], {
             RGBColor[
             0.9930579379883027, 0.9913972932023766, 0.7647114632218087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.09653745999529093], {
             RGBColor[
             0.6414683426968801, 0.719811924277673, 0.9649178841945132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.09653745999529093], {
             RGBColor[
             0.3748819846842069, 0.4991256658422175, 0.9451081264623227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.09653745999529093], {
             RGBColor[
             0.9887179459137481, 0.9896025949468394, 0.8366363634366315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.09653745999529093], {
             RGBColor[
             0.3978214010750888, 0.5189946353514076, 0.9465698057902202]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.09653745999529093], {
             RGBColor[
             0.9654681902057143, 0.9737668133128465, 0.9433375260300195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.09653745999529093], {
             RGBColor[
             0.4990774811827185, 0.6042126082652661, 0.9537083539812062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.09653745999529093], {
             RGBColor[
             0.6369731032990832, 0.7161624864263144, 0.9645640024825141]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.09653745999529093], {
             RGBColor[
             0.610010288631481, 0.6942728588181963, 0.962441390943836]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.09653745999529093], {
             RGBColor[
             0.4018310221297295, 0.5224675675795234, 0.9468252952982532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.09653745999529093], {
             RGBColor[
             0.32821807584845725`, 0.4587077334049447, 0.9421347434545831]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.09653745999529093], {
             RGBColor[
             0.9654681902057143, 0.9737668133128465, 0.9433375260300195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.09653745999529093], {
             RGBColor[
             0.6090487345764104, 0.6934922259187735, 0.9623656938863322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.09653745999529093], {
             RGBColor[
             0.4878170039851197, 0.5950708455975385, 0.9528218879677242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.09653745999529093], {
             RGBColor[
             0.7775900901092359, 0.8261785553876864, 0.9784665712557011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.09653745999529093], {
             RGBColor[
             0.9437598307571106, 0.9575767543802541, 0.980084116129582]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.09653745999529093], {
             RGBColor[
             0.5800724398192845, 0.6699679644677357, 0.9600845738193862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.09653745999529093], {
             RGBColor[
             0.5099789175243196, 0.6130628853914885, 0.9545665549832942]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.09653745999529093], {
             RGBColor[
             0.955002665898284, 0.9659616424200883, 0.9610529288366044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.09653745999529093], {
             RGBColor[
             0.9230903503387538, 0.9415112050127998, 0.9925263757394359]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.09653745999529093], {
             RGBColor[
             0.6739471522860687, 0.7452119046447261, 0.9681364118118089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.09653745999529093], {
             RGBColor[
             0.6435654945294389, 0.7214775226960958, 0.965108252099362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.09653745999529093], {
             RGBColor[
             0.9346463120311648, 0.7786014355687414, 0.2662730924932992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.09653745999529093], {
             RGBColor[
             0.5851761647657547, 0.674111398299469, 0.9604863577427328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.09653745999529093], {
             RGBColor[
             0.9638902105103407, 0.9725899586397415, 0.9460086340512684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.09653745999529093], {
             RGBColor[
             0.9178029735335317, 0.9372951942703358, 0.9920220610196568]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.09653745999529093], {
             RGBColor[
             0.8428764446812853, 0.3305727191640294, 0.18869183788980406`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.09653745999529093], {
             RGBColor[
             0.8376720706989834, 0.8734009874454807, 0.9843791039735962]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.09653745999529093], {
             RGBColor[
             0.8257958753822938, 0.8639312316706864, 0.9832463418622855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.09653745999529093], {
             RGBColor[
             0.43818774401378513`, 0.5539579327335181, 0.9491419134677185]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.09653745999529093], {
             RGBColor[
             0.3966102903329119, 0.5179456320987298, 0.946492634884672]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.09653745999529093], {
             RGBColor[
             0.3953022991789216, 0.5168127159026903, 0.9464092908449508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.09653745999529093], {
             RGBColor[
             0.8495572621046469, 0.3819244094328485, 0.19508939619931917`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.09653745999529093], {
             RGBColor[
             0.930153470894393, 0.9471431456205666, 0.9932000624833549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.09653745999529093], {
             RGBColor[
             0.9326322671453173, 0.9491196704659218, 0.9934364922826157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.09653745999529093], {
             RGBColor[
             0.8931501025308638, 0.917637664117165, 0.9896706481755446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.09653745999529093], {
             RGBColor[
             0.8800739647019734, 0.9072111067547136, 0.9884234344762189]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.09653745999529093], {
             RGBColor[
             0.5072333229827832, 0.6108338880550448, 0.9543504117235403]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.09653745999529093], {
             RGBColor[
             0.7570063495139345, 0.8100983807924143, 0.9764149763591539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.09653745999529093], {
             RGBColor[
             0.8262138446774634, 0.8642645090411804, 0.9832862081467845]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.09653745999529093], {
             RGBColor[
             0.6081442568554352, 0.6927579301586287, 0.962294490086926]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.09653745999529093], {
             RGBColor[
             0.9845183033877789, 0.9878659348364612, 0.9062353084184037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.09653745999529093], {
             RGBColor[
             0.7496884492531001, 0.8043815814905484, 0.9756855964508199]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.09653745999529093], {
             RGBColor[
             0.994110758050142, 0.9918326613541886, 0.7472635101861482]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.09653745999529093], {
             RGBColor[
             0.7070291220479139, 0.771055790854962, 0.9714337133890852]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.09653745999529093], {
             RGBColor[
             0.5979062707801812, 0.6844462718467209, 0.9614885183201033]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.09653745999529093], {
             RGBColor[
             0.609695475631052, 0.6940172794422841, 0.9624166077112442]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.09653745999529093], {
             RGBColor[
             0.988220000318389, 0.9893966816465403, 0.8448886105936236]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.09653745999529093], {
             RGBColor[
             0.822633302404772, 0.8614094818241671, 0.9829446928284273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.09653745999529093], {
             RGBColor[
             0.334411087063865, 0.4640718084499367, 0.9425293566529641]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.09653745999529093], {
             RGBColor[
             0.7635328526577816, 0.8151969346516487, 0.9770654771988929]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.09653745999529093], {
             RGBColor[
             0.8349506972296232, 0.8712310381107278, 0.9841195369426898]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.09653745999529093], {
             RGBColor[
             0.444881690185426, 0.5597558924598762, 0.9495684457985512]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.09653745999529093], {
             RGBColor[
             0.948848683088601, 0.9613720121168488, 0.9714700165176229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.09653745999529093], {
             RGBColor[
             0.28140739887720867`, 0.41310739685252057`, 0.939337107109893]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.09653745999529093], {
             RGBColor[
             0.9883357309894402, 0.9894445392531626, 0.8429706538729287]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.09653745999529093], {
             RGBColor[
             0.3558010361469244, 0.4825987072555821, 0.9438923052941474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.09653745999529093], {
             RGBColor[
             0.8005428491240347, 0.8441094251774768, 0.9807542877685681]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.09653745999529093], {
             RGBColor[
             0.6435654945294389, 0.7214775226960958, 0.965108252099362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.09653745999529093], {
             RGBColor[
             0.5535141230705568, 0.6484067264925836, 0.9579938058386066]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.09653745999529093], {
             RGBColor[
             0.6081442568554352, 0.6927579301586287, 0.962294490086926]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.09653745999529093], {
             RGBColor[
             0.5040889388830511, 0.6082811353899927, 0.9541028742889509]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.09653745999529093], {
             RGBColor[
             0.334411087063865, 0.4640718084499367, 0.9425293566529641]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.09653745999529093], {
             RGBColor[
             0.9484448220772062, 0.9610708132358122, 0.972153647866093]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.09653745999529093], {
             RGBColor[
             0.8661136909014501, 0.8960795633677138, 0.9870918910986415]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.09653745999529093], {
             RGBColor[
             0.9900132215063907, 0.9901382246914615, 0.8151702948007621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.09653745999529093], {
             RGBColor[
             0.7410894767752259, 0.7976639988362217, 0.974828531236192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.09653745999529093], {
             RGBColor[
             0.7635328526577816, 0.8151969346516487, 0.9770654771988929]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.09653745999529093], {
             RGBColor[
             0.800385582388989, 0.8439865672087875, 0.98073861289016]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.09653745999529093], {
             RGBColor[
             0.7034183516267831, 0.768235029559103, 0.971073825538075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.09653745999529093], {
             RGBColor[
             0.6886145523965123, 0.7566701890873742, 0.9695983211801709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.09653745999529093], {
             RGBColor[
             0.495932342801897, 0.6016592432408459, 0.9534607571668465]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.09653745999529093], {
             RGBColor[
             0.5269867531085975, 0.6268706125130669, 0.9559054741022431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.09653745999529093], {
             RGBColor[
             0.756970177155526, 0.8100701226711053, 0.9764113710365175]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.09653745999529093], {
             RGBColor[
             0.791753576184944, 0.8372431783565106, 0.979878255182425]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.09653745999529093], {
             RGBColor[
             0.8620372367830552, 0.892829109506105, 0.9867030752657354]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.09653745999529093], {
             RGBColor[
             0.5004404090666833, 0.6053190945206702, 0.9538156486568014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.09653745999529093], {
             RGBColor[
             0.8148234176307089, 0.8552655138312311, 0.9821776413778132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.09653745999529093], {
             RGBColor[
             0.3795471868545512, 0.5031664294822908, 0.9454053890193407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.09653745999529093], {
             RGBColor[
             0.9458111663906987, 0.9591066371370304, 0.9766117399759368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.09653745999529093], {
             RGBColor[
             0.8596761344180449, 0.890946430570662, 0.9864778712143798]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.09653745999529093], {
             RGBColor[
             0.8961436749566796, 0.9200246575111516, 0.9899561777859126]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.09653745999529093], {
             RGBColor[
             0.4489973944430271, 0.5633207086264995, 0.9498306948344711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.09653745999529093], {
             RGBColor[
             0.5975089423958573, 0.684123702764887, 0.9614572391742275]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.09653745999529093], {
             RGBColor[
             0.7938242897832621, 0.8388608355575229, 0.9800846445619866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.09653745999529093], {
             RGBColor[
             0.9549040306625556, 0.9658880804227824, 0.961219892562503]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.09653745999529093], {
             RGBColor[
             0.9504049262814185, 0.9625326557419377, 0.9688357027254134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.09653745999529093], {
             RGBColor[
             0.5450962568688331, 0.6415727234894735, 0.9573311205755469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.09653745999529093], {
             RGBColor[
             0.8559930942255389, 0.8880096742946206, 0.9861265795529298]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.09653745999529093], {
             RGBColor[
             0.5851761647657547, 0.674111398299469, 0.9604863577427328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.09653745999529093], {
             RGBColor[
             0.33664610076115403`, 0.46600766497947366`, 0.9426717697494104]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.09653745999529093], {
             RGBColor[
             0.9222858836759186, 0.940869745132521, 0.9924496449909788]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.09653745999529093], {
             RGBColor[
             0.5284272737756763, 0.628040092085318, 0.9560188771659567]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.09653745999529093], {
             RGBColor[
             0.4423712024341456, 0.5575814341505004, 0.9494084797389768]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.09653745999529093], {
             RGBColor[
             0.8625464524558522, 0.893235144261302, 0.986751644711189]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.09653745999529093], {
             RGBColor[
             0.6713741780752616, 0.7432018776359153, 0.9678799617882867]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.09653745999529093], {
             RGBColor[
             0.450011682769931, 0.5641992341956501, 0.9498953243897615]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.09653745999529093], {
             RGBColor[
             0.7943804058573836, 0.8392952776612652, 0.9801400730150549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.09653745999529093], {
             RGBColor[
             0.5705154533975044, 0.6622091723532028, 0.9593322128398689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.09653745999529093], {
             RGBColor[
             0.9427351341417131, 0.9568125373222773, 0.9818186602157701]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.09653745999529093], {
             RGBColor[
             0.5795189601810293, 0.6695186247634267, 0.9600410018748]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.09653745999529093], {
             RGBColor[
             0.9898999311581932, 0.9900913762210527, 0.8170478090564172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.09653745999529093], {
             RGBColor[
             0.697129162700029, 0.7633218673699166, 0.9704469779616681]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.09653745999529093], {
             RGBColor[
             0.5102097074599855, 0.6132502510582303, 0.9545847236124412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.09653745999529093], {
             RGBColor[
             0.33337803042807235`, 0.4631770267149493, 0.9424635311976275]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.09653745999529093], {
             RGBColor[
             0.5980138450040224, 0.6845336054477988, 0.9614969869570614]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.09653745999529093], {
             RGBColor[
             0.5441562056818184, 0.6408095475870316, 0.9572571163025841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.09653745999529093], {
             RGBColor[
             0.6358172800840154, 0.7152241370710799, 0.964473011845104]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.09653745999529093], {
             RGBColor[
             0.8835284999393881, 0.909965659382167, 0.9887529311310636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.09653745999529093], {
             RGBColor[
             0.9884162342020768, 0.9894778294004261, 0.8416365073039034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.09653745999529093], {
             RGBColor[
             0.960062389264623, 0.9697351758221673, 0.9524881369645959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.09653745999529093], {
             RGBColor[
             0.796133645312963, 0.8406649216490775, 0.9803148195390328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.09653745999529093], {
             RGBColor[
             0.5565427078806685, 0.6508654680776231, 0.9582322271289303]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.09653745999529093], {
             RGBColor[
             0.8664154821681412, 0.8963202035318676, 0.9871206762190707]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.09653745999529093], {
             RGBColor[
             0.5813856021705658, 0.6710340488217956, 0.9601879507699512]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.09653745999529093], {
             RGBColor[
             0.6519652867436496, 0.7280395042146224, 0.9659454648867534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.09653745999529093], {
             RGBColor[
             0.7662031809866007, 0.817283015437369, 0.9773316305710726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.09653745999529093], {
             RGBColor[
             0.9648279025290644, 0.9732892878119759, 0.9444213660528162]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.09653745999529093], {
             RGBColor[
             0.94744001837713, 0.9603214322815105, 0.9738545184355454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.09653745999529093], {
             RGBColor[
             0.8705483827377825, 0.899615666261502, 0.9875148759648871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.09653745999529093], {
             RGBColor[
             0.9797618247775517, 0.9844269825728442, 0.9191421310768542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.09653745999529093], {
             RGBColor[
             0.8214220586110358, 0.8604436689013787, 0.9828291633140906]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.09653745999529093], {
             RGBColor[
             0.9706486163226078, 0.9776303666286564, 0.9345684158856415]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.09653745999529093], {
             RGBColor[
             0.8596761344180449, 0.890946430570662, 0.9864778712143798]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.09653745999529093], {
             RGBColor[
             0.966705402169146, 0.9746895239694252, 0.9412432488924891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.09653745999529093], {
             RGBColor[
             0.9439668911526019, 0.9577311796841813, 0.9797336168900153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.09653745999529093], {
             RGBColor[
             0.6931400193548403, 0.7602055182700427, 0.9700493774336838]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.09653745999529093], {
             RGBColor[
             0.582427645895669, 0.6718800268613693, 0.9602699842691234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.09653745999529093], {
             RGBColor[
             0.9951047776853682, 0.9919379393889272, 0.7085634447416772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.09653745999529093], {
             RGBColor[
             0.810861510125734, 0.8521704415767324, 0.981782755463848]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.09653745999529093], {
             RGBColor[
             0.5037776839492212, 0.6080284446128347, 0.9540783711603954]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.09653745999529093], {
             RGBColor[
             0.6749482206059915, 0.7459939468246507, 0.9682361889464235]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.09653745999529093], {
             RGBColor[
             0.9851640555827066, 0.9881329699641382, 0.895533523395342]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.09653745999529093], {
             RGBColor[
             0.9948311446420273, 0.9913526659777654, 0.6787801766414088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.09653745999529093], {
             RGBColor[
             0.28970658753366485`, 0.4218303703294086, 0.9398097336263288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.09653745999529093], {
             RGBColor[
             0.3413895708986362, 0.47011622039881945`, 0.9429740194720848]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.09653745999529093], {
             RGBColor[
             0.994416948268152, 0.9904667418157235, 0.6336974574688048]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.09653745999529093], {
             RGBColor[
             0.8904238653615132, 0.5953221894106315, 0.23027932611185578`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.09653745999529093], {
             RGBColor[
             0.7652294304721008, 0.8165223141346637, 0.9772345762200032]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.09653745999529093], {
             RGBColor[
             0.9057239829173755, 0.9276637350284787, 0.9908699561116456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.09653745999529093], {
             RGBColor[
             0.8970681052882723, 0.9207617731645708, 0.9900443507761886]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.09653745999529093], {
             RGBColor[
             0.8281923478168176, 0.8658421137394644, 0.9834749195424467]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.09653745999529093], {
             RGBColor[
             0.5312820246168058, 0.6303577074232067, 0.9562436136094673]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.09653745999529093], {
             RGBColor[
             0.9799133647752283, 0.9845400008549875, 0.9188856133887491]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.09653745999529093], {
             RGBColor[
             0.7820193064605834, 0.82963869286465, 0.9789080341482234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.09653745999529093], {
             RGBColor[
             0.9436197346550455, 0.9574722709367203, 0.9803212622874629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.09653745999529093], {
             RGBColor[
             0.7013430265918047, 0.7666137698687234, 0.9708669765336034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.09653745999529093], {
             RGBColor[
             0.8350969515716422, 0.8713476573530854, 0.9841334868123943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.09653745999529093], {
             RGBColor[
             0.9629854950696578, 0.8868035248302102, 0.3107060672587026]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.09653745999529093], {
             RGBColor[
             0.7490626436923018, 0.8038926974301545, 0.9756232220010049]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.09653745999529093], {
             RGBColor[
             0.9042580997772961, 0.6581223002535925, 0.24182202361081806`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.09653745999529093], {
             RGBColor[
             0.9908094047614856, 0.9806601055854186, 0.4187967023069963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.09653745999529093], {
             RGBColor[
             0.9949309922870407, 0.9915662299943038, 0.6896479766128926]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.09653745999529093], {
             RGBColor[
             0.40535057674517094`, 0.5255160288894603, 0.9470495582061292]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.09653745999529093], {
             RGBColor[
             0.7696575086367777, 0.8199815624515499, 0.9776759256687151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.09653745999529093], {
             RGBColor[
             0.6547371126907764, 0.7302048757111753, 0.9662217345929768]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.09653745999529093], {
             RGBColor[
             0.5235605002473402, 0.6240890260893659, 0.9556357469262272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.09653745999529093], {
             RGBColor[
             0.791522890227867, 0.8370629647335639, 0.9798552625621064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.09653745999529093], {
             RGBColor[
             0.9383148340089732, 0.7931459027482709, 0.26922487138792206`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.09653745999529093], {
             RGBColor[
             0.663753585854492, 0.737248613074404, 0.9671204123742037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.09653745999529093], {
             RGBColor[
             0.9852537813753871, 0.9881700738852593, 0.8940465348077178]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.09653745999529093], {
             RGBColor[
             0.8921998743726618, 0.9168799779770709, 0.9895800145655366]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.09653745999529093], {
             RGBColor[
             0.6060810360585558, 0.6910829145686844, 0.9621320657879688]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.09653745999529093], {
             RGBColor[
             0.6047155936443523, 0.6899743869043544, 0.9620245731593424]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.09653745999529093], {
             RGBColor[
             0.7899708355890648, 0.8358504878536794, 0.9797005682604859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.09653745999529093], {
             RGBColor[
             0.5086528299303757, 0.6119863077431595, 0.9544621605102801]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.09653745999529093], {
             RGBColor[
             0.4988793460315659, 0.6040517532236737, 0.9536927560563145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.09653745999529093], {
             RGBColor[
             0.7632987217089856, 0.815014029774988, 0.9770421412139951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.09653745999529093], {
             RGBColor[
             0.8733661858438407, 0.9018625059710452, 0.9877836405406254]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.09653745999529093], {
             RGBColor[
             0.5689100847392322, 0.6609058617553836, 0.9592058323384306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.09653745999529093], {
             RGBColor[
             0.42740028662713114`, 0.5446143793385717, 0.9484545462220149]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.09653745999529093], {
             RGBColor[
             0.9241300833717252, 0.94234025991049, 0.9926255464043013]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.09653745999529093], {
             RGBColor[
             0.756477746872732, 0.809685432391578, 0.9763622901879513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.09653745999529093], {
             RGBColor[
             0.5456512747209796, 0.6420233119851153, 0.9573748136139653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.09653745999529093], {
             RGBColor[
             0.9506882966664306, 0.9627439929111032, 0.9683560305784211]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.09653745999529093], {
             RGBColor[
             0.5138381121033654, 0.6161959534054924, 0.9548703649172522]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.09653745999529093], {
             RGBColor[
             0.9708291134810609, 0.9777649811138939, 0.9342628812775787]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.09653745999529093], {
             RGBColor[
             0.8674074183939195, 0.8971111465529116, 0.9872152879817975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.09653745999529093], {
             RGBColor[
             0.7943804058573836, 0.8392952776612652, 0.9801400730150549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.09653745999529093], {
             RGBColor[
             0.9866751538148972, 0.9887578479166023, 0.8704907150910758]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.09653745999529093], {
             RGBColor[
             0.9881889157310716, 0.9893838273708472, 0.8454037626498055]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.09653745999529093], {
             RGBColor[
             0.897506069944511, 0.9211109942932216, 0.9900861242360762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.09653745999529093], {
             RGBColor[
             0.9354867633018162, 0.95139576821788, 0.9937087566742613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.09653745999529093], {
             RGBColor[
             0.6752668344115969, 0.7462428503511443, 0.9682679453929509]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.09653745999529093], {
             RGBColor[
             0.6609013826123831, 0.7350204502241211, 0.9668361314103849]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.09653745999529093], {
             RGBColor[
             0.8225487992507267, 0.8613421013029083, 0.9829366328421576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.09653745999529093], {
             RGBColor[
             0.9931148948341446, 0.9876817811781777, 0.49197697651945704`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.09653745999529093], {
             RGBColor[
             0.5797728081010229, 0.669724709940596, 0.9600609857129375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.09653745999529093], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.09653745999529093], {
             RGBColor[
             0.6829313429559046, 0.7522304226783799, 0.9690318719757429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.09653745999529093], {
             RGBColor[
             0.9862493958355908, 0.988581786050678, 0.8775466266345147]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.09653745999529093], {
             RGBColor[
             0.7186052730768605, 0.7800991680207815, 0.9725875159383687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.09653745999529093], {
             RGBColor[
             0.9379280833984235, 0.9532274467487553, 0.9899557432445302]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.09653745999529093], {
             RGBColor[
             0.7043134481076896, 0.7689342857329724, 0.9711630403901396]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.09653745999529093], {
             RGBColor[
             0.824270282078477, 0.8627147649813499, 0.9831008294110544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.09653745999529093], {
             RGBColor[
             0.7405094428847672, 0.7972108719525746, 0.9747707188787159]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.09653745999529093], {
             RGBColor[
             0.9933157113411631, 0.9915038891082574, 0.7604394916688568]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.09653745999529093], {
             RGBColor[
             0.45960333662087877`, 0.5721657194200174, 0.9506008047227422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.09653745999529093], {
             RGBColor[
             0.6440856925160361, 0.7218839053168765, 0.9651601005731395]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.09653745999529093], {
             RGBColor[
             0.923095448394654, 0.9415152700641917, 0.9925268619965587]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.09653745999529093], {
             RGBColor[
             0.970768766606411, 0.9777199745135887, 0.9343650327953755]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.09653745999529093], {
             RGBColor[
             0.5333687204414774, 0.6320517810982508, 0.956407885948604]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.09653745999529093], {
             RGBColor[
             0.9628502783981937, 0.9718143789732349, 0.9477689678593996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.09653745999529093], {
             RGBColor[
             0.4267890943037298, 0.5440849952674608, 0.9484156015876238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.09653745999529093], {
             RGBColor[
             0.9466566520570323, 0.9597371989626262, 0.9751805532808125]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.09653745999529093], {
             RGBColor[
             0.9722386895952226, 0.9788162406718666, 0.9318768365926329]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.09653745999529093], {
             RGBColor[
             0.9839881453385285, 0.9576503958439064, 0.3922973975355625]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.09653745999529093], {
             RGBColor[
             0.7650710769531043, 0.8163986071620923, 0.9772187930211275]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.09653745999529093], {
             RGBColor[
             0.6406768752179347, 0.7191693753230616, 0.9648555769753296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.09653745999529093], {
             RGBColor[
             0.990486076108984, 0.9795694421193528, 0.41754063154752014`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.09653745999529093], {
             RGBColor[
             0.5363976964575989, 0.6345108402819527, 0.9566463380360979]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.09653745999529093], {
             RGBColor[
             0.42262279063813524`, 0.5404763524368338, 0.9481501284021698]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.09653745999529093], {
             RGBColor[
             0.751575212018765, 0.805855534903014, 0.9758736513305009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.09653745999529093], {
             RGBColor[
             0.9419172497042796, 0.9562025604480023, 0.9832031252299198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.09653745999529093], {
             RGBColor[
             0.5262680000898958, 0.6262870964330304, 0.9558488912317319]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.09653745999529093], {
             RGBColor[
             0.6295086697461069, 0.7101025229991088, 0.9639763749301028]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.09653745999529093], {
             RGBColor[
             0.5725048293421288, 0.6638242373654138, 0.959488823801554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.09653745999529093], {
             RGBColor[
             0.5851761647657547, 0.674111398299469, 0.9604863577427328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.09653745999529093], {
             RGBColor[
             0.24576327435627854`, 0.3756431620129988, 0.9373072269491829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.09653745999529093], {
             RGBColor[
             0.7416030574326392, 0.7980652119491506, 0.9748797201564388]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.09653745999529093], {
             RGBColor[
             0.657808163965805, 0.7326040043080818, 0.9665278282834657]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.09653745999529093], {
             RGBColor[
             0.7657285088262574, 0.8169121979380669, 0.9772843196861931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.09653745999529093], {
             RGBColor[
             0.3310506395302276, 0.461161157697304, 0.9423152319076478]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.09653745999529093], {
             RGBColor[
             0.9379280833984235, 0.9532274467487553, 0.9899557432445302]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.09653745999529093], {
             RGBColor[
             0.8511402325098258, 0.8841401340899331, 0.9856637092702843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.09653745999529093], {
             RGBColor[
             0.4972545796723052, 0.6027326946983355, 0.9535648484967982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.09653745999529093], {
             RGBColor[
             0.4348936378012798, 0.5511047434988383, 0.9489320159327214]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.09653745999529093], {
             RGBColor[
             0.5881839734092238, 0.6765532728564724, 0.9607231434571128]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.09653745999529093], {
             RGBColor[
             0.7785445758001376, 0.8269242068637787, 0.9785617054691943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.09653745999529093], {
             RGBColor[
             0.7926242663183576, 0.8379233681062234, 0.9799650374378618]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.09653745999529093], {
             RGBColor[
             0.9922412252930034, 0.9910595615143114, 0.7782465061676199]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.09653745999529093], {
             RGBColor[
             0.7825750822327692, 0.8300728691219339, 0.9789634286831749]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.09653745999529093], {
             RGBColor[
             0.993565623796668, 0.9886458448533266, 0.5410360425134004]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.09653745999529093], {
             RGBColor[
             0.49235351992304943`, 0.598753793603664, 0.9531790191201635]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.09653745999529093], {
             RGBColor[
             0.9926173102134606, 0.991215082293862, 0.7720138057590694]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.09653745999529093], {
             RGBColor[
             0.475230744515095, 0.584852753155245, 0.9518310515172563]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.09653745999529093], {
             RGBColor[
             0.9915459100122354, 0.9907720307769262, 0.7897696797882106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.09653745999529093], {
             RGBColor[
             0.5256786403150654, 0.6258086276174677, 0.9558024946713612]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.09653745999529093], {
             RGBColor[
             0.7316596818731754, 0.7902973713896443, 0.9738886574067991]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.09653745999529093], {
             RGBColor[
             0.8305109665186341, 0.8676909173550648, 0.9836960714640812]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.09653745999529093], {
             RGBColor[
             0.9437598307571106, 0.9575767543802541, 0.980084116129582]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.09653745999529093], {
             RGBColor[
             0.7001301212306313, 0.7656662389821527, 0.9707460854624467]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.09653745999529093], {
             RGBColor[
             0.4692782310565811, 0.580020234571948, 0.9513624478530268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.09653745999529093], {
             RGBColor[
             0.6239289809985044, 0.7055726803116915, 0.9635371213928181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.09653745999529093], {
             RGBColor[
             0.2751023286954908, 0.40648036832699624`, 0.9389780426905596]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.09653745999529093], {
             RGBColor[
             0.949966028668431, 0.9622053266208005, 0.9695786419013707]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.09653745999529093], {
             RGBColor[
             0.9951094666437609, 0.9919479685968027, 0.7090738089258225]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.09653745999529093], {
             RGBColor[
             0.8894234669854597, 0.9146661460900868, 0.9893151983504171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.09653745999529093], {
             RGBColor[
             0.6249999943077634, 0.7064421771647478, 0.963621435483774]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.09653745999529093], {
             RGBColor[
             0.7820193064605834, 0.82963869286465, 0.9789080341482234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.09653745999529093], {
             RGBColor[
             0.46716110372605846`, 0.5783014552295304, 0.9511957798342752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.09653745999529093], {
             RGBColor[
             0.9362080171001255, 0.9519446241198346, 0.9928673668224094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.09653745999529093], {
             RGBColor[
             0.5891333774106766, 0.6773240417950146, 0.9607978840178886]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.09653745999529093], {
             RGBColor[
             0.5834941353158263, 0.6727458510174539, 0.9603539422229576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.09653745999529093], {
             RGBColor[
             0.9117250388177226, 0.9324488141090924, 0.9914423421806265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.09653745999529093], {
             RGBColor[
             0.9949480630274398, 0.9916027425819006, 0.6915060213569252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.09653745999529093], {
             RGBColor[
             0.8891059118355471, 0.9144129362333514, 0.9892849096567337]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.09653745999529093], {
             RGBColor[
             0.4022103209961583, 0.5227960971935086, 0.9468494638866213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.09653745999529093], {
             RGBColor[
             0.8954921156452005, 0.9195051218022846, 0.9898940314771298]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.09653745999529093], {
             RGBColor[
             0.8016246329364234, 0.8449545229135762, 0.9808621098691426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.09653745999529093], {
             RGBColor[
             0.5795189601810293, 0.6695186247634267, 0.9600410018748]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.09653745999529093], {
             RGBColor[
             0.7274449487121358, 0.7870047898110817, 0.9734685721942274]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.09653745999529093], {
             RGBColor[
             0.8282566472084689, 0.8658933843290066, 0.9834810524758231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.09653745999529093], {
             RGBColor[
             0.9889753751205888, 0.9897090485394969, 0.8323700952738489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.09653745999529093], {
             RGBColor[
             0.9770368423879465, 0.9823946951684258, 0.9237548154732234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.09653745999529093], {
             RGBColor[
             0.9732301913012801, 0.9795557010208091, 0.9301984828293387]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.09653745999529093], {
             RGBColor[
             0.5009702002553983, 0.6057492028744902, 0.9538573557598661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.09653745999529093], {
             RGBColor[
             0.7411948587043736, 0.7977463240002043, 0.9748390347220393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.09653745999529093], {
             RGBColor[
             0.8961075229549269, 0.919995830886274, 0.9899527295757121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.09653745999529093], {
             RGBColor[
             0.9024082180749616, 0.9250198341471768, 0.990553695500958]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.09653745999529093], {
             RGBColor[
             0.5185701072023124, 0.6200376002007676, 0.9552428849053105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.09653745999529093], {
             RGBColor[
             0.5094056087122162, 0.6125974474705552, 0.9545214220135061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.09653745999529093], {
             RGBColor[
             0.9704458945755612, 0.9774791770816355, 0.9349115709250919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.09653745999529093], {
             RGBColor[
             0.9935131535024766, 0.9885336161996117, 0.5353249747997872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.09653745999529093], {
             RGBColor[
             0.782329397911119, 0.8298809386625908, 0.9789389411660434]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.09653745999529093], {
             RGBColor[
             0.4260203888921774, 0.5434191812762315, 0.9483666203585392]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.09653745999529093], {
             RGBColor[
             0.6682266974043815, 0.7407430418140846, 0.9675662503298925]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.09653745999529093], {
             RGBColor[
             0.5138381121033654, 0.6161959534054924, 0.9548703649172522]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.09653745999529093], {
             RGBColor[
             0.2782422824353023, 0.40978065879210385`, 0.9391568584108967]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.09653745999529093], {
             RGBColor[
             0.9938588999827345, 0.989273132960552, 0.5729573454759208]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.09653745999529093], {
             RGBColor[
             0.8608535577030549, 0.8918852759378254, 0.9865901748984023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.09653745999529093], {
             RGBColor[
             0.8385744876746275, 0.2975059924812765, 0.184572279001863]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.09653745999529093], {
             RGBColor[
             0.43121908771191103`, 0.5479220328996847, 0.9486978768503038]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.09653745999529093], {
             RGBColor[
             0.8282566472084689, 0.8658933843290066, 0.9834810524758231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.09653745999529093], {
             RGBColor[
             0.42622351575179596`, 0.5435951195525803, 0.9483795634224161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.09653745999529093], {
             RGBColor[
             0.9020932611128352, 0.9247686960148561, 0.9905236546247449]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.09653745999529093], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.09653745999529093], {
             RGBColor[
             0.4667500057603363, 0.5779677073812048, 0.951163416696512]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.09653745999529093], {
             RGBColor[
             0.9222858836759186, 0.940869745132521, 0.9924496449909788]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.09653745999529093], {
             RGBColor[
             0.8643380160971912, 0.8946636884782062, 0.9869225256506476]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.09653745999529093], {
             RGBColor[
             0.37918762896895897`, 0.5028549985136956, 0.9453824783088154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.09653745999529093], {
             RGBColor[
             0.5460380738769077, 0.6423373329650012, 0.9574052638604119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.09653745999529093], {
             RGBColor[
             0.3417386844296112, 0.4704186049923937, 0.9429962646775695]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.09653745999529093], {
             RGBColor[
             0.40235673410468753`, 0.5229229128691799, 0.9468587932004288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.09653745999529093], {
             RGBColor[
             0.24576327435627854`, 0.3756431620129988, 0.9373072269491829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.09653745999529093], {
             RGBColor[
             0.42293789498995593`, 0.5407492799887756, 0.948170206572832]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.09653745999529093], {
             RGBColor[
             0.9930588853701798, 0.9875619825981825, 0.4858806920172317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.09653745999529093], {
             RGBColor[
             0.36130077931571947`, 0.48736230836326333`, 0.944242744065631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.09653745999529093], {
             RGBColor[
             0.5765761423525377, 0.6671295126778248, 0.9598093324754443]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.09653745999529093], {
             RGBColor[
             0.9063654296898017, 0.6664771611306126, 0.24351763072381066`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.09653745999529093], {
             RGBColor[
             0.6522829433802101, 0.7282876599933834, 0.9659771259316157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.09653745999529093], {
             RGBColor[
             0.47921634148826964`, 0.5880884403271657, 0.9521448123107074]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.09653745999529093], {
             RGBColor[
             0.5488971211941418, 0.6446584363757456, 0.9576303385382601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.09653745999529093], {
             RGBColor[
             0.791753576184944, 0.8372431783565106, 0.979878255182425]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.09653745999529093], {
             RGBColor[
             0.9916976325962975, 0.9908347719645285, 0.7872552439248395]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.09653745999529093], {
             RGBColor[
             0.8306622457778632, 0.23668903409623956`, 0.17699550722592247`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.09653745999529093], {
             RGBColor[
             0.6050261970001051, 0.6902265487010761, 0.9620490249932848]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.09653745999529093], {
             RGBColor[
             0.8240390833945807, 0.8625304134265321, 0.9830787774741908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.09653745999529093], {
             RGBColor[
             0.4115702927671239, 0.530903234295659, 0.9474458730111691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.09653745999529093], {
             RGBColor[
             0.7943804058573836, 0.8392952776612652, 0.9801400730150549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.09653745999529093], {
             RGBColor[
             0.9702242748547828, 0.9112216287917576, 0.3388273597950541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.09653745999529093], {
             RGBColor[
             0.3287223084325424, 0.4591444743258127, 0.9421668727089656]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.09653745999529093], {
             RGBColor[
             0.5377917093879147, 0.6356425627783499, 0.95675607984041]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.09653745999529093], {
             RGBColor[
             0.9373860389046685, 0.9528231908528292, 0.9908732831846117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.09653745999529093], {
             RGBColor[
             0.6066428051972038, 0.6915389840628502, 0.9621762903123914]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.09653745999529093], {
             RGBColor[
             0.5306229571670711, 0.6298226467768618, 0.9561917294055805]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.09653745999529093], {
             RGBColor[
             0.7463276060844074, 0.8017560652638116, 0.9753506190126296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.09653745999529093], {
             RGBColor[
             0.9532342708379423, 0.9646427762795666, 0.9640463604024634]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.09653745999529093], {
             RGBColor[
             0.9763120065912875, 0.9818541138180872, 0.9249817734095143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.09653745999529093], {
             RGBColor[
             0.5623506050301632, 0.6555805806263679, 0.9586894460675668]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.09653745999529093], {
             RGBColor[
             0.6330626130696874, 0.7129877742925136, 0.9642561543670584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.09653745999529093], {
             RGBColor[
             0.9927302668989471, 0.9868591009166395, 0.4501125994216634]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.09653745999529093], {
             RGBColor[
             0.7053354685000337, 0.7697326958311144, 0.9712649058315248]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.09653745999529093], {
             RGBColor[
             0.6745786145057584, 0.7457052077300382, 0.9681993500645176]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.09653745999529093], {
             RGBColor[
             0.7866128428222521, 0.833227198382555, 0.9793658749237165]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.09653745999529093], {
             RGBColor[
             0.7585748787240485, 0.8113237277326188, 0.9765713126920791]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.09653745999529093], {
             RGBColor[
             0.8572433910126156, 0.8890066270142334, 0.9862458339766343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.09653745999529093], {
             RGBColor[
             0.5699001198658948, 0.6617096168717824, 0.9592837715302196]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.09653745999529093], {
             RGBColor[
             0.8719208217045836, 0.900710011839766, 0.9876457804187313]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.09653745999529093], {
             RGBColor[
             0.8397533411147607, 0.8750605359804411, 0.984577617403825]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.09653745999529093], {
             RGBColor[
             0.8964504204688373, 0.9202692480561611, 0.9899854354466971]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.09653745999529093], {
             RGBColor[
             0.9932760172994317, 0.9880264058394467, 0.5095141625333595]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.09653745999529093], {
             RGBColor[
             0.5149660398729791, 0.6171116559814318, 0.9549591595230118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.09653745999529093], {
             RGBColor[
             0.9859758220491865, 0.9643552961176418, 0.4000191462152182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.09653745999529093], {
             RGBColor[
             0.4852298526758003, 0.5929704796147948, 0.9526182179396071]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.09653745999529093], {
             RGBColor[
             0.791522890227867, 0.8370629647335639, 0.9798552625621064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.09653745999529093], {
             RGBColor[
             0.9947849781456418, 0.9912539205101456, 0.6737552384164394]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.09653745999529093], {
             RGBColor[
             0.43017457643970947`, 0.5470173297343667, 0.9486313215156642]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.09653745999529093], {
             RGBColor[
             0.3135409458106535, 0.4459951410602042, 0.9411995297070508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.09653745999529093], {
             RGBColor[
             0.3417386844296112, 0.4704186049923937, 0.9429962646775695]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.09653745999529093], {
             RGBColor[
             0.4785807824611151, 0.5875724648773136, 0.9520947787759603]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.09653745999529093], {
             RGBColor[
             0.6699900257914643, 0.7421205673518658, 0.9677420024242763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.09653745999529093], {
             RGBColor[
             0.5253311312504398, 0.6255265041036998, 0.9557751374848262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.09653745999529093], {
             RGBColor[
             0.7525587736631136, 0.8066239007349245, 0.9759716835633033]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.09653745999529093], {
             RGBColor[
             0.7472439689884992, 0.8024719349291042, 0.9754419535030113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.09653745999529093], {
             RGBColor[
             0.6406262376734971, 0.7191282654832918, 0.9648515906023402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.09653745999529093], {
             RGBColor[
             0.9912639404839225, 0.9906554291306825, 0.7944426445861034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.09653745999529093], {
             RGBColor[
             0.29970476739450336`, 0.4323390912843666, 0.940379115178422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.09653745999529093], {
             RGBColor[
             0.9606939685963759, 0.9702062066536724, 0.9514190378982097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.09653745999529093], {
             RGBColor[
             0.9870022868993861, 0.9888931258539752, 0.8650692732878114]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.09653745999529093], {
             RGBColor[
             0.6675169131539747, 0.7401885529631067, 0.9674955056691229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.09653745999529093], {
             RGBColor[
             0.38756790484944065`, 0.510113572276456, 0.9459164620775327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.09653745999529093], {
             RGBColor[
             0.6632484910615767, 0.736854029183316, 0.967070069245625]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.09653745999529093], {
             RGBColor[
             0.6528867298207077, 0.728759342549647, 0.9660373057212994]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.09653745999529093], {
             RGBColor[
             0.9813591087362303, 0.9856182343339144, 0.9164383459731876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.09653745999529093], {
             RGBColor[
             0.9468244893982095, 0.9598623717768677, 0.9748964484411887]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.09653745999529093], {
             RGBColor[
             0.9643373196018667, 0.9729234118681277, 0.9452517949840422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.09653745999529093], {
             RGBColor[
             0.9936411994888305, 0.9888074936169874, 0.5492619902061732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.09653745999529093], {
             RGBColor[
             0.5097342188801428, 0.6128642280085975, 0.954547291409664]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.09653745999529093], {
             RGBColor[
             0.6426389441482242, 0.720753694496247, 0.9650159022164682]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.09653745999529093], {
             RGBColor[
             0.9887179459137481, 0.9896025949468394, 0.8366363634366315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.09653745999529093], {
             RGBColor[
             0.37742900716231714`, 0.5013317686956846, 0.9452704204823843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.09653745999529093], {
             RGBColor[
             0.9849212878635141, 0.9880325792734063, 0.89955681276508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.09653745999529093], {
             RGBColor[
             0.6077258092630875, 0.6924182155523118, 0.9622615483596324]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.09653745999529093], {
             RGBColor[
             0.8275783990690639, 0.8653525676732005, 0.9834163605628075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.09653745999529093], {
             RGBColor[
             0.9899603366644035, 0.9901163554502214, 0.816046733494073]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.09653745999529093], {
             RGBColor[
             0.9396099926293251, 0.9544818118992879, 0.9871087096287963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.09653745999529093], {
             RGBColor[
             0.9677290766989244, 0.9754529787576207, 0.9395104349306516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.09653745999529093], {
             RGBColor[
             0.9933493639249037, 0.9881832868548499, 0.5174974900730858]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.09653745999529093], {
             RGBColor[
             0.9926891437568809, 0.9912447873101042, 0.7708233380453433]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.09653745999529093], {
             RGBColor[
             0.9140878907704766, 0.9343328881183108, 0.9916677131092231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.09653745999529093], {
             RGBColor[
             0.5765761423525377, 0.6671295126778248, 0.9598093324754443]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.09653745999529093], {
             RGBColor[
             0.413186645620662, 0.5323032378971372, 0.9475488655857119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.09653745999529093], {
             RGBColor[
             0.542443536294035, 0.6394191254231524, 0.9571222886946632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.09653745999529093], {
             RGBColor[
             0.8376720706989834, 0.8734009874454807, 0.9843791039735962]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.09653745999529093], {
             RGBColor[
             0.6094934286889456, 0.693853248632571, 0.9624007018358393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.09653745999529093], {
             RGBColor[
             0.731483967330903, 0.7901601018537411, 0.9738711438233711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.09653745999529093], {
             RGBColor[
             0.4315717982822388, 0.5482275330679538, 0.9487203512559554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.09653745999529093], {
             RGBColor[
             0.9850948332274311, 0.9881043447412984, 0.8966807169639709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.09653745999529093], {
             RGBColor[
             0.8843636450016763, 0.9106315813854269, 0.9888325880126475]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.09653745999529093], {
             RGBColor[
             0.8455599512978527, 0.879690569324204, 0.9851314570667105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.09653745999529093], {
             RGBColor[
             0.7225771388249261, 0.7832020197304681, 0.9729833943969401]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.09653745999529093], {
             RGBColor[
             0.5308214313326965, 0.6299837770456758, 0.9562073540189334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.09653745999529093], {
             RGBColor[
             0.897506069944511, 0.9211109942932216, 0.9900861242360762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.09653745999529093], {
             RGBColor[
             0.9259873062574203, 0.9438211590265709, 0.9928026899811013]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.09653745999529093], {
             RGBColor[
             0.5330771215381135, 0.631815047972119, 0.9563849302147693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.09653745999529093], {
             RGBColor[
             0.791522890227867, 0.8370629647335639, 0.9798552625621064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.09653745999529093], {
             RGBColor[
             0.7918243877750588, 0.8372984969088962, 0.9798853130199557]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.09653745999529093], {
             RGBColor[
             0.7410894767752259, 0.7976639988362217, 0.974828531236192]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN2wucz2W+wPHn16rdrWxoc2ntsSnFoptQYTEuNY3rMEhyNxmZGTMj4zII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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[105, 155] -> 
             RGBColor[
              0.3609448647521152, 0.4866656792120809, 0.9442342850410239], 
             UndirectedEdge[1, 203] -> 
             RGBColor[
              0.32569030455946724`, 0.45491432460487713`, 0.9420324056815049],
              UndirectedEdge[187, 193] -> 
             RGBColor[
              0.8331367258093362, 0.8697846265391334, 0.9839465187292714], 
             UndirectedEdge[209, 371] -> 
             RGBColor[
              0.26203929742842424`, 0.3927502942212898, 0.9382341223849231], 
             UndirectedEdge[23, 245] -> 
             RGBColor[
              0.22165838805798918`, 0.35030739817543277`, 0.9359344893344789],
              UndirectedEdge[201, 236] -> 
             RGBColor[
              0.26347424346046877`, 0.3942585134818019, 0.9383158404386357], 
             UndirectedEdge[258, 369] -> 
             RGBColor[
              0.2551936052438994, 0.3855550376934007, 0.9378442703423086], 
             UndirectedEdge[161, 312] -> 
             RGBColor[
              0.44719691052756494`, 0.5614994937585587, 0.949788285319064], 
             UndirectedEdge[74, 132] -> 
             RGBColor[
              0.8119479189165777, 0.8530570556731545, 0.981880980170774], 
             UndirectedEdge[89, 169] -> 
             RGBColor[
              0.2196406470513075, 0.3481866244452415, 0.9358195819691286], 
             UndirectedEdge[124, 137] -> 
             RGBColor[
              0.22241368079166546`, 0.3511012587268517, 0.9359775021383063], 
             UndirectedEdge[186, 393] -> 
             RGBColor[
              0.23564383540018752`, 0.36500699006065973`, 0.9367309398710019],
              UndirectedEdge[84, 261] -> 
             RGBColor[
              0.17918769193352976`, 0.30566800375096304`, 0.9335158460199553],
              UndirectedEdge[58, 243] -> 
             RGBColor[
              0.2935914724788655, 0.42591363072274663`, 0.9400309720767858], 
             UndirectedEdge[205, 250] -> 
             RGBColor[
              0.9917478646376758, 0.990855544204543, 0.7864227690028461], 
             UndirectedEdge[327, 337] -> 
             RGBColor[
              0.3016677329619616, 0.43349195021963505`, 0.9405242352558603], 
             UndirectedEdge[38, 224] -> 
             RGBColor[
              0.970726359968221, 0.9129152797745752, 0.34077786564994345`], 
             UndirectedEdge[49, 301] -> 
             RGBColor[
              0.2562771522862687, 0.3866939143357813, 0.9379059767434073], 
             UndirectedEdge[22, 97] -> 
             RGBColor[
              0.36730142212889694`, 0.4910409193978484, 0.9446807120447999], 
             UndirectedEdge[163, 169] -> 
             RGBColor[
              0.23283585906700827`, 0.36205562889850595`, 0.936571029772856], 
             UndirectedEdge[126, 318] -> 
             RGBColor[
              0.2179296081019373, 0.3463882140233181, 0.9357221408322174], 
             UndirectedEdge[126, 149] -> 
             RGBColor[
              0.21613019133913786`, 0.3444969129160037, 0.9356196667095744], 
             UndirectedEdge[28, 47] -> 
             RGBColor[
              0.3610905157265072, 0.4852888096589335, 0.9442985989042187], 
             UndirectedEdge[203, 392] -> 
             RGBColor[
              0.26967339396164935`, 0.4007742137073859, 0.9386688728888566], 
             UndirectedEdge[116, 387] -> 
             RGBColor[
              0.35489504602512995`, 0.4804107437728069, 0.9438859559088182], 
             UndirectedEdge[114, 203] -> 
             RGBColor[
              0.3101377282501396, 0.4414434647009515, 0.9410414092716778], 
             UndirectedEdge[38, 207] -> 
             RGBColor[
              0.9528235149386215, 0.8477616286807421, 0.29603526485507003`], 
             UndirectedEdge[4, 73] -> 
             RGBColor[
              0.23765623707057423`, 0.3671221518098715, 0.9368455431690489], 
             UndirectedEdge[143, 223] -> 
             RGBColor[
              0.5393557196395969, 0.6369122967585245, 0.9568792044565808], 
             UndirectedEdge[70, 164] -> 
             RGBColor[
              0.26017432145076, 0.3907900862224582, 0.9381279147619799], 
             UndirectedEdge[291, 331] -> 
             RGBColor[
              0.5742920250264498, 0.6644126452364563, 0.9602056699966387], 
             UndirectedEdge[317, 381] -> 
             RGBColor[
              0.99188704610358, 0.9909130993174948, 0.7841161719227241], 
             UndirectedEdge[120, 349] -> 
             RGBColor[
              0.5058787275831391, 0.6095186078416714, 0.9543033325072602], 
             UndirectedEdge[102, 160] -> 
             RGBColor[
              0.8243873085977117, 0.18845711723458924`, 0.17098662029568146`],
              UndirectedEdge[84, 381] -> 
             RGBColor[
              0.5860370216699882, 0.6484140748343261, 0.8483679973313716], 
             UndirectedEdge[110, 203] -> 
             RGBColor[
              0.2734877597794271, 0.40478335402663146`, 0.9388860953793305], 
             UndirectedEdge[316, 355] -> 
             RGBColor[
              0.2426003366300466, 0.37231871392089444`, 0.937127102324821], 
             UndirectedEdge[62, 77] -> 
             RGBColor[
              0.5042166815429454, 0.5861598549701907, 0.9585479112851663], 
             UndirectedEdge[188, 361] -> 
             RGBColor[
              0.3113562197109362, 0.44025108193646334`, 0.9412013526638779], 
             UndirectedEdge[168, 282] -> 
             RGBColor[
              0.6585061316418895, 0.73314926196139, 0.9665973951785392], 
             UndirectedEdge[271, 394] -> 
             RGBColor[
              0.3328279171819992, 0.4625195049765876, 0.9424351072766638], 
             UndirectedEdge[160, 224] -> 
             RGBColor[
              0.9025695450570996, 0.5785729407895561, 0.26790552836760506`], 
             UndirectedEdge[97, 168] -> 
             RGBColor[
              0.5562174687857758, 0.6498761073301125, 0.9585804738963757], 
             UndirectedEdge[88, 132] -> 
             RGBColor[
              0.8947680641910523, 0.9166701790551881, 0.8954060764061295], 
             UndirectedEdge[329, 353] -> 
             RGBColor[
              0.22275923690238936`, 0.35146446010874544`, 0.9359971810476075],
              UndirectedEdge[189, 339] -> 
             RGBColor[
              0.333153622737486, 0.4622245787566195, 0.942476989061352], 
             UndirectedEdge[316, 380] -> 
             RGBColor[
              0.25988508585516024`, 0.3904860812728869, 0.9381114432226962], 
             UndirectedEdge[156, 295] -> 
             RGBColor[
              0.2141734445733891, 0.3424402480002911, 0.9355082328760125], 
             UndirectedEdge[154, 228] -> 
             RGBColor[
              0.39900760332101687`, 0.520022064116572, 0.9466453895484133], 
             UndirectedEdge[29, 91] -> 
             RGBColor[
              0.25152521102249714`, 0.3816993227770795, 0.9376353607183026], 
             UndirectedEdge[6, 198] -> 
             RGBColor[
              0.9099185860419527, 0.9263319020393368, 0.75030590143584], 
             UndirectedEdge[56, 254] -> 
             RGBColor[
              0.46022321075082034`, 0.5726042579779009, 0.9506674811679487], 
             UndirectedEdge[245, 315] -> 
             RGBColor[
              0.23658653725822024`, 0.3659978294842021, 0.9367846253472143], 
             UndirectedEdge[174, 281] -> 
             RGBColor[
              0.6802997161269625, 0.7500157979571946, 0.9688781332846546], 
             UndirectedEdge[89, 329] -> 
             RGBColor[
              0.22686082544463082`, 0.3557754897223749, 0.9362307604473317], 
             UndirectedEdge[260, 267] -> 
             RGBColor[
              0.6900764896095811, 0.7567221842679797, 0.9704893279445472], 
             UndirectedEdge[202, 363] -> 
             RGBColor[
              0.8594260597663401, 0.4513198993592995, 0.20428679439717456`], 
             UndirectedEdge[43, 238] -> 
             RGBColor[
              0.22832917766795519`, 0.3573188210079969, 0.9363143809342176], 
             UndirectedEdge[276, 377] -> 
             RGBColor[
              0.590222766132432, 0.6752773818608311, 0.9624624311800029], 
             UndirectedEdge[284, 369] -> 
             RGBColor[
              0.25072601947789425`, 0.3808593217920313, 0.9375898479421354], 
             UndirectedEdge[53, 249] -> 
             RGBColor[
              0.279406621010689, 0.4110044524581648, 0.9392231657702803], 
             UndirectedEdge[15, 105] -> 
             RGBColor[
              0.36060251301143975`, 0.486305845826277, 0.9442147886158565], 
             UndirectedEdge[97, 112] -> 
             RGBColor[
              0.38560280932821134`, 0.5084115053045399, 0.9457912479285857], 
             UndirectedEdge[120, 246] -> 
             RGBColor[
              0.505090585435528, 0.6088359587265868, 0.9542531127865411], 
             UndirectedEdge[53, 308] -> 
             RGBColor[
              0.27516616979901054`, 0.4065474693745552, 0.9389816783469607], 
             UndirectedEdge[188, 392] -> 
             RGBColor[
              0.25751756533120074`, 0.38799766709273437`, 0.9379766164312895],
              UndirectedEdge[91, 273] -> 
             RGBColor[
              0.26902930475390907`, 0.40009723511243644`, 0.9386321929613204],
              UndirectedEdge[327, 354] -> 
             RGBColor[
              0.2991827847858058, 0.430880112131681, 0.9403827211333795], 
             UndirectedEdge[51, 376] -> 
             RGBColor[
              0.405658343586251, 0.5257826010583926, 0.9470691688370954], 
             UndirectedEdge[202, 214] -> 
             RGBColor[
              0.9200563597791344, 0.7107376048071281, 0.556968147234525], 
             UndirectedEdge[69, 132] -> 
             RGBColor[
              0.6437204915353074, 0.7192373735289359, 0.9667380893382732], 
             UndirectedEdge[130, 387] -> 
             RGBColor[
              0.35198717062244894`, 0.47789208825307206`, 0.9437006686594926],
              UndirectedEdge[61, 306] -> 
             RGBColor[
              0.9818610097196364, 0.9499548547858537, 0.42826904779571534`], 
             UndirectedEdge[312, 356] -> 
             RGBColor[
              0.4906677898927829, 0.5973852420238213, 0.9530463122771483], 
             UndirectedEdge[18, 247] -> 
             RGBColor[
              0.926107052730001, 0.8138393200274576, 0.6108347292188259], 
             UndirectedEdge[56, 320] -> 
             RGBColor[
              0.5804145257698448, 0.6691464316920486, 0.9608367095033534], 
             UndirectedEdge[43, 124] -> 
             RGBColor[
              0.22535325774935577`, 0.3541909404893282, 0.9361449066973324], 
             UndirectedEdge[259, 318] -> 
             RGBColor[
              0.2174190793227137, 0.34585161590696, 0.9356930669735002], 
             UndirectedEdge[267, 384] -> 
             RGBColor[
              0.6598133920654725, 0.7330804224584619, 0.9674729852060762], 
             UndirectedEdge[44, 324] -> 
             RGBColor[
              0.2889570987994522, 0.4210426101494208, 0.9397670513516847], 
             UndirectedEdge[62, 204] -> 
             RGBColor[
              0.17899762953989296`, 0.30546823612459895`, 0.9335050222478098],
              UndirectedEdge[42, 109] -> 
             RGBColor[
              0.9631611562508396, 0.9703111795583055, 0.8704491819362283], 
             UndirectedEdge[8, 21] -> 
             RGBColor[
              0.3116185481608299, 0.44433005683844234`, 0.9410770362287135], 
             UndirectedEdge[48, 349] -> 
             RGBColor[
              0.43541101780241814`, 0.5515528720515495, 0.9489649829288928], 
             UndirectedEdge[222, 332] -> 
             RGBColor[
              0.5660742539559687, 0.6586036065728093, 0.9589825853511816], 
             UndirectedEdge[58, 167] -> 
             RGBColor[
              0.2911802301180382, 0.4233792621199214, 0.9398936553914501], 
             UndirectedEdge[76, 144] -> 
             RGBColor[
              0.8626912709570241, 0.4513693690163807, 0.2064327327986027], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.44236640792617826`, 0.5377470693075241, 0.9524063925246276], 
             UndirectedEdge[6, 166] -> 
             RGBColor[
              0.9090583234505556, 0.5897855777490221, 0.34432575904947005`], 
             UndirectedEdge[79, 343] -> 
             RGBColor[
              0.6565032648608529, 0.7307948803461315, 0.9669377087053699], 
             UndirectedEdge[142, 257] -> 
             RGBColor[
              0.822095571600614, 0.17084182242934073`, 0.16879205035911396`], 
             UndirectedEdge[175, 256] -> 
             RGBColor[
              0.20212025348377827`, 0.329771579948656, 0.9348218214745575], 
             UndirectedEdge[8, 171] -> 
             RGBColor[
              0.2917662705538139, 0.42384970493064567`, 0.9399323578314926], 
             UndirectedEdge[31, 214] -> 
             RGBColor[
              0.5834952534993698, 0.6486610383850888, 0.9230487158880236], 
             UndirectedEdge[41, 114] -> 
             RGBColor[
              0.3348490984330268, 0.46445119188281303`, 0.9425572663500889], 
             UndirectedEdge[72, 399] -> 
             RGBColor[
              0.23130276285488832`, 0.3604442475756538, 0.9364837222115884], 
             UndirectedEdge[278, 392] -> 
             RGBColor[
              0.2501824179205401, 0.3802879620889227, 0.9375588906376304], 
             UndirectedEdge[6, 323] -> 
             RGBColor[
              0.9117788938600264, 0.9278152609967583, 0.7504833392562442], 
             UndirectedEdge[132, 323] -> 
             RGBColor[
              0.8147163030891271, 0.8552644900665589, 0.9821450311245175], 
             UndirectedEdge[200, 355] -> 
             RGBColor[
              0.2507904105311417, 0.380927000871623, 0.9375935149173598], 
             UndirectedEdge[98, 215] -> 
             RGBColor[
              0.8984291495802124, 0.5426319701729883, 0.2667341084618861], 
             UndirectedEdge[12, 367] -> 
             RGBColor[
              0.21887583976336028`, 0.3473827634940262, 0.9357760273255111], 
             UndirectedEdge[88, 140] -> 
             RGBColor[
              0.8311193811821351, 0.8669473441407145, 0.8890621705145608], 
             UndirectedEdge[195, 327] -> 
             RGBColor[
              0.2821434199050674, 0.41297065928389304`, 0.9394123545109028], 
             UndirectedEdge[142, 381] -> 
             RGBColor[
              0.9073655012701238, 0.5791717949250715, 0.46576856864206445`], 
             UndirectedEdge[313, 359] -> 
             RGBColor[
              0.2641882368664749, 0.39500896582131095`, 0.9383565013068491], 
             UndirectedEdge[64, 82] -> 
             RGBColor[
              0.38908871359710695`, 0.5114308203756144, 0.9460133666661356], 
             UndirectedEdge[98, 297] -> 
             RGBColor[
              0.9621045612745434, 0.9478624391979251, 0.6712874553374975], 
             UndirectedEdge[139, 305] -> 
             RGBColor[
              0.20703664012749182`, 0.3349390140281161, 0.9351018024207747], 
             UndirectedEdge[288, 375] -> 
             RGBColor[
              0.24993566591258726`, 0.38002861008358335`, 0.9375448384758145],
              UndirectedEdge[136, 194] -> 
             RGBColor[
              0.5033185862068833, 0.6058836865205527, 0.954531849750919], 
             UndirectedEdge[254, 349] -> 
             RGBColor[
              0.45744526540329744`, 0.5701981413414695, 0.9504904729468453], 
             UndirectedEdge[348, 351] -> 
             RGBColor[
              0.2543498568494185, 0.38466820463406326`, 0.9377962201194567], 
             UndirectedEdge[65, 282] -> 
             RGBColor[
              0.5810969797016021, 0.6707307553552915, 0.9602123891284602], 
             UndirectedEdge[131, 215] -> 
             RGBColor[
              0.8708771882594211, 0.43978719004972067`, 0.21128818862239418`],
              UndirectedEdge[230, 250] -> 
             RGBColor[
              0.9785422248709081, 0.9480049704007043, 0.5891428358439234], 
             UndirectedEdge[26, 111] -> 
             RGBColor[
              0.6645955027358419, 0.5448101324102603, 0.5834436797495368], 
             UndirectedEdge[301, 390] -> 
             RGBColor[
              0.26155859013835736`, 0.392245040380827, 0.9382067468158966], 
             UndirectedEdge[3, 309] -> 
             RGBColor[
              0.32043505349243634`, 0.4484572206151509, 0.9417673069857059], 
             UndirectedEdge[90, 268] -> 
             RGBColor[
              0.7615624007787926, 0.45211356179516854`, 0.5677648921175946], 
             UndirectedEdge[17, 187] -> 
             RGBColor[
              0.6897252223294911, 0.7560947412907055, 0.9707766661911668], 
             UndirectedEdge[4, 206] -> 
             RGBColor[
              0.23187928370438585`, 0.3610502075420088, 0.9365165542210812], 
             UndirectedEdge[19, 231] -> 
             RGBColor[
              0.2915341164557601, 0.4237512190985569, 0.9399138086948555], 
             UndirectedEdge[76, 138] -> 
             RGBColor[
              0.8331436561867612, 0.2557622418600043, 0.17937170863583543`], 
             UndirectedEdge[28, 390] -> 
             RGBColor[
              0.2772941937947283, 0.40878415751856884`, 0.9391028661653874], 
             UndirectedEdge[123, 174] -> 
             RGBColor[
              0.8514507591880022, 0.8841310051490996, 0.9509891763922267], 
             UndirectedEdge[2, 98] -> 
             RGBColor[
              0.8980106482873484, 0.5394151858476, 0.26633335115120993`], 
             UndirectedEdge[20, 364] -> 
             RGBColor[
              0.37859437323609996`, 0.5023411502157933, 0.945344676578113], 
             UndirectedEdge[56, 196] -> 
             RGBColor[
              0.3744295737159023, 0.4977332530910004, 0.9451159345325955], 
             UndirectedEdge[360, 374] -> 
             RGBColor[
              0.293247724709362, 0.42540017170025574`, 0.9400169674113716], 
             UndirectedEdge[39, 360] -> 
             RGBColor[
              0.29174189371093673`, 0.42381744784571107`, 0.9399312125636886],
              UndirectedEdge[261, 264] -> 
             RGBColor[
              0.1847396920189574, 0.3115035078578844, 0.9338320242113725], 
             UndirectedEdge[101, 253] -> 
             RGBColor[
              0.3012788054166666, 0.43094522374745403`, 0.9405803668258977], 
             UndirectedEdge[141, 273] -> 
             RGBColor[
              0.31775067217972763`, 0.44656178652298995`, 0.9415805292809634],
              UndirectedEdge[171, 182] -> 
             RGBColor[
              0.2806534492526592, 0.41231494799395196`, 0.9392941707941435], 
             UndirectedEdge[156, 175] -> 
             RGBColor[
              0.18244584031582461`, 0.30909252427929373`, 0.9337013927503286],
              UndirectedEdge[121, 250] -> 
             RGBColor[
              0.7707116790518824, 0.8187741201767487, 0.9013688926659322], 
             UndirectedEdge[68, 308] -> 
             RGBColor[
              0.26890650081077455`, 0.39996816038198235`, 0.938625199458431], 
             UndirectedEdge[39, 390] -> 
             RGBColor[
              0.26969566944831447`, 0.40079762665621843`, 0.9386701414448686],
              UndirectedEdge[54, 181] -> 
             RGBColor[
              0.5096518890083631, 0.6127613709392468, 0.9545507619731439], 
             UndirectedEdge[196, 313] -> 
             RGBColor[
              0.2903662346350581, 0.4225237012570149, 0.9398472995528928], 
             UndirectedEdge[200, 241] -> 
             RGBColor[
              0.2808108014657587, 0.41248033514662596`, 0.9393031317698977], 
             UndirectedEdge[186, 255] -> 
             RGBColor[
              0.2544713249858168, 0.38479587534694254`, 0.9378031375501286], 
             UndirectedEdge[11, 38] -> 
             RGBColor[
              0.9446269367354516, 0.8152649274529434, 0.2894401056343812], 
             UndirectedEdge[173, 310] -> 
             RGBColor[
              0.20447288081658893`, 0.33224434044062834`, 0.9349558001207607],
              UndirectedEdge[106, 173] -> 
             RGBColor[
              0.5874312139478495, 0.658182594689114, 0.9541358462016971], 
             UndirectedEdge[51, 396] -> 
             RGBColor[
              0.3256114518738936, 0.4536350211799036, 0.9420717220904409], 
             UndirectedEdge[6, 18] -> 
             RGBColor[
              0.9692770544063248, 0.9734175595259907, 0.7474672305772001], 
             UndirectedEdge[238, 287] -> 
             RGBColor[
              0.24471825055354252`, 0.3745447757379873, 0.9372477143895912], 
             UndirectedEdge[93, 225] -> 
             RGBColor[
              0.25117310830966183`, 0.38132924050128825`, 0.9376153089896959],
              UndirectedEdge[116, 276] -> 
             RGBColor[
              0.5908937430052579, 0.6758585483037947, 0.9625051852330178], 
             UndirectedEdge[135, 276] -> 
             RGBColor[
              0.6344220971523353, 0.7122040883931675, 0.9656535874330512], 
             UndirectedEdge[147, 172] -> 
             RGBColor[
              0.29308124725627194`, 0.4253773516636531, 0.9400019155051696], 
             UndirectedEdge[185, 224] -> 
             RGBColor[
              0.8996759960158076, 0.5563318548969114, 0.2651346625378677], 
             UndirectedEdge[160, 166] -> 
             RGBColor[
              0.8271233428626157, 0.2094874755325008, 0.1736066497976622], 
             UndirectedEdge[63, 156] -> 
             RGBColor[
              0.5722602959769347, 0.592332243346744, 0.6137097186204522], 
             UndirectedEdge[247, 302] -> 
             RGBColor[
              0.9471422868502191, 0.8188837514344283, 0.3245541983516868], 
             UndirectedEdge[81, 240] -> 
             RGBColor[
              0.22946097871463872`, 0.3585084156683923, 0.9363788353294766], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.3163910437219365, 0.4480120932607672, 0.9413976728873965], 
             UndirectedEdge[12, 212] -> 
             RGBColor[
              0.2146670795751315, 0.34295908968538924`, 0.9355363446590942], 
             UndirectedEdge[18, 74] -> 
             RGBColor[
              0.8849400211257357, 0.9108459941170431, 0.9803872287207334], 
             UndirectedEdge[1, 7] -> 
             RGBColor[
              0.37469401379728373`, 0.4989628549076562, 0.945096149123624], 
             UndirectedEdge[231, 331] -> 
             RGBColor[
              0.38038829696430865`, 0.5038892359163952, 0.9454591932807552], 
             UndirectedEdge[58, 351] -> 
             RGBColor[
              0.27227774194596055`, 0.4035115485640963, 0.9388171866537756], 
             UndirectedEdge[142, 279] -> 
             RGBColor[
              0.8836168067234831, 0.49456770966954106`, 0.2217143859275474], 
             UndirectedEdge[303, 344] -> 
             RGBColor[
              0.3051201948561256, 0.4369324167818024, 0.9407277420647475], 
             UndirectedEdge[302, 323] -> 
             RGBColor[
              0.9087436394185031, 0.9180978599174181, 0.6943707488073377], 
             UndirectedEdge[144, 366] -> 
             RGBColor[
              0.8898592758254438, 0.5927585201905767, 0.22980821876360358`], 
             UndirectedEdge[56, 342] -> 
             RGBColor[
              0.5271466154555224, 0.626935692782203, 0.9559359367348119], 
             UndirectedEdge[137, 293] -> 
             RGBColor[
              0.2163935789679292, 0.34477375001360355`, 0.9356346662453872], 
             UndirectedEdge[39, 374] -> 
             RGBColor[
              0.2745978955714905, 0.40595017713076464`, 0.9389493159703898], 
             UndirectedEdge[4, 278] -> 
             RGBColor[
              0.24230606056995913`, 0.37200941112356267`, 0.9371103437385414],
              UndirectedEdge[238, 396] -> 
             RGBColor[
              0.25376131131834845`, 0.3840496059649667, 0.9377627033221374], 
             UndirectedEdge[118, 293] -> 
             RGBColor[
              0.20864634306607288`, 0.33663091387762584`, 0.9351934726217848],
              UndirectedEdge[201, 228] -> 
             RGBColor[
              0.3221417320475673, 0.45045653149250003`, 0.9418569760468667], 
             UndirectedEdge[212, 336] -> 
             RGBColor[
              0.21095186783418274`, 0.3390541665876225, 0.9353247688466104], 
             UndirectedEdge[186, 200] -> 
             RGBColor[
              0.2595636633022175, 0.3901482457903771, 0.9380931386838082], 
             UndirectedEdge[7, 356] -> 
             RGBColor[
              0.4538916995859768, 0.5657933672154302, 0.9506306565950378], 
             UndirectedEdge[215, 269] -> 
             RGBColor[
              0.9061735630089964, 0.5684125935804545, 0.32599457253607145`], 
             UndirectedEdge[36, 122] -> 
             RGBColor[
              0.4828824410191481, 0.5908684223901826, 0.952487665639901], 
             UndirectedEdge[297, 352] -> 
             RGBColor[
              0.970396577990795, 0.974814330666099, 0.7901511578367646], 
             UndirectedEdge[228, 243] -> 
             RGBColor[
              0.3281145647549416, 0.45673435736741674`, 0.9421971200335375], 
             UndirectedEdge[100, 271] -> 
             RGBColor[
              0.3417009842764249, 0.4702049097204598, 0.9430004912657755], 
             UndirectedEdge[157, 298] -> 
             RGBColor[
              0.6463369873520685, 0.7210185843298552, 0.9671902179184984], 
             UndirectedEdge[272, 384] -> 
             RGBColor[
              0.6977223834801167, 0.763785295951966, 0.9705061046650639], 
             UndirectedEdge[35, 114] -> 
             RGBColor[
              0.30495946572485455`, 0.43600078246607, 0.9407465148814157], 
             UndirectedEdge[15, 155] -> 
             RGBColor[
              0.30420326810120896`, 0.4370673007485326, 0.9406352981387334], 
             UndirectedEdge[36, 262] -> 
             RGBColor[
              0.7291600782306236, 0.787348496129779, 0.9720379295278863], 
             UndirectedEdge[111, 185] -> 
             RGBColor[
              0.8488843177529799, 0.35210056877181173`, 0.19347970101943163`],
              UndirectedEdge[26, 400] -> 
             RGBColor[
              0.4223618806328297, 0.5402016308185901, 0.9481469689308566], 
             UndirectedEdge[61, 131] -> 
             RGBColor[
              0.9579060415796807, 0.8592435772757068, 0.3867967672286041], 
             UndirectedEdge[168, 350] -> 
             RGBColor[
              0.5514466203488134, 0.6457438382038303, 0.9582764796526682], 
             UndirectedEdge[16, 208] -> 
             RGBColor[
              0.2374736143413805, 0.36693020374253915`, 0.9368351430747874], 
             UndirectedEdge[125, 303] -> 
             RGBColor[
              0.28379884955745593`, 0.41562096314419106`, 0.9394732966882988],
              UndirectedEdge[145, 164] -> 
             RGBColor[
              0.2402812832877892, 0.36988124182170756`, 0.9369950356677115], 
             UndirectedEdge[152, 256] -> 
             RGBColor[
              0.2044622657846265, 0.33223318336900387`, 0.9349551956103941], 
             UndirectedEdge[237, 246] -> 
             RGBColor[
              0.5111109439056949, 0.6137235569467266, 0.9547270574586124], 
             UndirectedEdge[16, 284] -> 
             RGBColor[
              0.24292930031788273`, 0.3726644756143127, 0.9371458363201851], 
             UndirectedEdge[240, 309] -> 
             RGBColor[
              0.2549984797573888, 0.3853499484354077, 0.9378331582345141], 
             UndirectedEdge[151, 249] -> 
             RGBColor[
              0.2927023996318287, 0.42432368443317114`, 0.9400043408205379], 
             UndirectedEdge[47, 311] -> 
             RGBColor[
              0.47663297852550124`, 0.5854636862286419, 0.9520871802976505], 
             UndirectedEdge[29, 190] -> 
             RGBColor[
              0.2407660977459846, 0.370390812556283, 0.937022645133887], 
             UndirectedEdge[99, 384] -> 
             RGBColor[
              0.863277719993484, 0.893302482160574, 0.9487341980321153], 
             UndirectedEdge[5, 398] -> 
             RGBColor[
              0.8904342144946242, 0.9153759950567726, 0.9860799767962038], 
             UndirectedEdge[36, 157] -> 
             RGBColor[
              0.49446056893751156`, 0.6004643909150807, 0.9533448937369567], 
             UndirectedEdge[40, 55] -> 
             RGBColor[
              0.37142239221905604`, 0.496129140733077, 0.9448876842896408], 
             UndirectedEdge[163, 319] -> 
             RGBColor[
              0.2432784612852803, 0.3730314659291315, 0.9371657205207411], 
             UndirectedEdge[13, 74] -> 
             RGBColor[
              0.8942268027978797, 0.9177720606824189, 0.9646671297303714], 
             UndirectedEdge[47, 158] -> 
             RGBColor[
              0.468503909528975, 0.5788641418068768, 0.9514472302084831], 
             UndirectedEdge[252, 330] -> 
             RGBColor[
              0.2245525377985933, 0.3533493330524997, 0.9360993068806954], 
             UndirectedEdge[102, 185] -> 
             RGBColor[
              0.8214937595564198, 0.16621603134194454`, 0.16821575446594406`],
              UndirectedEdge[41, 356] -> 
             RGBColor[
              0.4295993605310475, 0.5447525640945126, 0.9490827702313296], 
             UndirectedEdge[33, 175] -> 
             RGBColor[
              0.17893676407552545`, 0.30540426266245535`, 0.9335015560496566],
              UndirectedEdge[12, 126] -> 
             RGBColor[
              0.2152393660615204, 0.3435605990676429, 0.935568935527872], 
             UndirectedEdge[18, 191] -> 
             RGBColor[
              0.8120299641162554, 0.853850200152278, 0.9731302939895274], 
             UndirectedEdge[64, 171] -> 
             RGBColor[
              0.3360864294513485, 0.46223759897173367`, 0.9427563991656658], 
             UndirectedEdge[73, 184] -> 
             RGBColor[
              0.230439447723778, 0.35953684863551605`, 0.9364345576920319], 
             UndirectedEdge[93, 316] -> 
             RGBColor[
              0.2497588091651779, 0.37984272242869066`, 0.9375347667456857], 
             UndirectedEdge[20, 362] -> 
             RGBColor[
              0.406159003588231, 0.5262162475882044, 0.9471010704497052], 
             UndirectedEdge[32, 330] -> 
             RGBColor[
              0.2205286799485376, 0.349120003324768, 0.935870154128899], 
             UndirectedEdge[124, 277] -> 
             RGBColor[
              0.24054204876353127`, 0.3701553228701986, 0.9370098858757869], 
             UndirectedEdge[267, 331] -> 
             RGBColor[
              0.511645707636986, 0.6143827846807824, 0.9547069650679356], 
             UndirectedEdge[134, 167] -> 
             RGBColor[
              0.25893816716997997`, 0.3894908096966502, 0.9380575176044159], 
             UndirectedEdge[143, 398] -> 
             RGBColor[
              0.7820348247548993, 0.8302487551810782, 0.97550730112162], 
             UndirectedEdge[109, 320] -> 
             RGBColor[
              0.8519952349988198, 0.8825603077930796, 0.8596099472355513], 
             UndirectedEdge[28, 147] -> 
             RGBColor[
              0.2865134731880893, 0.418474204697066, 0.9396278904881377], 
             UndirectedEdge[54, 311] -> 
             RGBColor[
              0.48568276233296276`, 0.5933021541073054, 0.9526638245194523], 
             UndirectedEdge[160, 289] -> 
             RGBColor[
              0.863615444991354, 0.42809333252077686`, 0.20612813226240806`], 
             UndirectedEdge[209, 240] -> 
             RGBColor[
              0.24561974977362988`, 0.37549230857665095`, 0.9372990534365266],
              UndirectedEdge[31, 261] -> 
             RGBColor[
              0.18133289143212553`, 0.3079227444374911, 0.9336380119578622], 
             UndirectedEdge[245, 248] -> 
             RGBColor[
              0.2230533686520324, 0.3517736112266503, 0.9360139314156208], 
             UndirectedEdge[81, 245] -> 
             RGBColor[
              0.22480714766170556`, 0.3536169441618284, 0.9361138065357382], 
             UndirectedEdge[308, 386] -> 
             RGBColor[
              0.30022575986843436`, 0.4300559235597101, 0.9405124330603728], 
             UndirectedEdge[320, 349] -> 
             RGBColor[
              0.5776365804223218, 0.666740315055617, 0.9606597012822499], 
             UndirectedEdge[222, 356] -> 
             RGBColor[
              0.5616526527416191, 0.6550139515161355, 0.9586345007067291], 
             UndirectedEdge[200, 374] -> 
             RGBColor[
              0.27338169058223005`, 0.4046718685752019, 0.9388800548954654], 
             UndirectedEdge[73, 348] -> 
             RGBColor[
              0.2530355996274438, 0.3832868369650472, 0.9377213751149346], 
             UndirectedEdge[23, 81] -> 
             RGBColor[
              0.2165666874460731, 0.34495569799984427`, 0.9356445245171263], 
             UndirectedEdge[25, 233] -> 
             RGBColor[
              0.8330846738019452, 0.25530887740406205`, 0.17931522703752448`],
              UndirectedEdge[168, 170] -> 
             RGBColor[
              0.5575600626847299, 0.651038994684655, 0.958666022792408], 
             UndirectedEdge[73, 284] -> 
             RGBColor[
              0.24355703331110456`, 0.3733242627907594, 0.9371815847855014], 
             UndirectedEdge[143, 234] -> 
             RGBColor[
              0.4816918202752083, 0.5869870677287701, 0.9531992911334777], 
             UndirectedEdge[288, 374] -> 
             RGBColor[
              0.26056485892169184`, 0.3912005658659134, 0.9381501552932011], 
             UndirectedEdge[254, 344] -> 
             RGBColor[
              0.39507001975859724`, 0.5161718386350326, 0.946515977450629], 
             UndirectedEdge[6, 102] -> 
             RGBColor[
              0.9063222891856516, 0.5687552194511105, 0.3417057295474893], 
             UndirectedEdge[205, 276] -> 
             RGBColor[
              0.8804173286055655, 0.9045483902483498, 0.8526723312886473], 
             UndirectedEdge[101, 244] -> 
             RGBColor[
              0.2604390037563816, 0.39106828410749395`, 0.9381429880277227], 
             UndirectedEdge[58, 80] -> 
             RGBColor[
              0.31661369550810525`, 0.44773804311104304`, 0.9414289555561544],
              UndirectedEdge[23, 292] -> 
             RGBColor[
              0.21221830344661968`, 0.3403852707129492, 0.9353968904812151], 
             UndirectedEdge[101, 397] -> 
             RGBColor[
              0.2550956906132599, 0.3854521232084524, 0.9378386942489454], 
             UndirectedEdge[105, 168] -> 
             RGBColor[
              0.5437472998304071, 0.6390750737498879, 0.957785885757477], 
             UndirectedEdge[166, 340] -> 
             RGBColor[
              0.9092736160962124, 0.5902460669486567, 0.36775903489702405`], 
             UndirectedEdge[138, 317] -> 
             RGBColor[
              0.9049849697863369, 0.5700377324760639, 0.4855767081666582], 
             UndirectedEdge[71, 120] -> 
             RGBColor[
              0.7187491637803132, 0.7794609626924269, 0.9732879603430942], 
             UndirectedEdge[231, 290] -> 
             RGBColor[
              0.3569089205700484, 0.48355258019145775`, 0.9439631081789103], 
             UndirectedEdge[13, 224] -> 
             RGBColor[
              0.9697208187554422, 0.9510352770851425, 0.6530724790472836], 
             UndirectedEdge[40, 159] -> 
             RGBColor[
              0.33537336280871854`, 0.46490528333474357`, 0.9425906720125191],
              UndirectedEdge[20, 265] -> 
             RGBColor[
              0.49977683892029745`, 0.6035406289522859, 0.9541059564454999], 
             UndirectedEdge[43, 299] -> 
             RGBColor[
              0.22078197517346282`, 0.34938623266600927`, 0.9358845789172419],
              UndirectedEdge[219, 220] -> 
             RGBColor[
              0.4613111794873067, 0.5733857750910603, 0.9507812424766675], 
             UndirectedEdge[56, 290] -> 
             RGBColor[
              0.42803437429076585`, 0.5451635942026395, 0.9484949497272399], 
             UndirectedEdge[64, 157] -> 
             RGBColor[
              0.43410205704708005`, 0.5499866920911975, 0.9490010571312653], 
             UndirectedEdge[13, 340] -> 
             RGBColor[
              0.9787791287241259, 0.9808041152910011, 0.7551804074343922], 
             UndirectedEdge[16, 188] -> 
             RGBColor[
              0.25447321455412675`, 0.38479786140304184`, 0.9378032451582485],
              UndirectedEdge[171, 308] -> 
             RGBColor[
              0.26715048285961845`, 0.3981224741773486, 0.9385251968339084], 
             UndirectedEdge[288, 379] -> 
             RGBColor[
              0.23299167582952007`, 0.3622194021952592, 0.9365799033069708], 
             UndirectedEdge[81, 353] -> 
             RGBColor[
              0.2150475477536689, 0.34335898586410785`, 0.9355580117590097], 
             UndirectedEdge[153, 188] -> 
             RGBColor[
              0.2922583395910017, 0.4237094580639409, 0.939984452630228], 
             UndirectedEdge[148, 356] -> 
             RGBColor[
              0.5711332147381206, 0.6627106988393463, 0.9593808452755366], 
             UndirectedEdge[198, 247] -> 
             RGBColor[
              0.866748584365629, 0.7667536625408037, 0.6136734000774657], 
             UndirectedEdge[94, 375] -> 
             RGBColor[
              0.25748465436672835`, 0.3879630755823982, 0.9379747422005502], 
             UndirectedEdge[298, 307] -> 
             RGBColor[
              0.9043350538106595, 0.9251046086494896, 0.9386480207606034], 
             UndirectedEdge[9, 142] -> 
             RGBColor[
              0.8236257057163587, 0.18260310375199956`, 0.1702573085163904], 
             UndirectedEdge[203, 284] -> 
             RGBColor[
              0.26769783285159876`, 0.3986977737229138, 0.93855636760622], 
             UndirectedEdge[370, 400] -> 
             RGBColor[
              0.6104137657145253, 0.6900683539569277, 0.9649050090474223], 
             UndirectedEdge[63, 381] -> 
             RGBColor[
              0.975854040924288, 0.9316564884007599, 0.528376469194335], 
             UndirectedEdge[222, 251] -> 
             RGBColor[
              0.7136213718875605, 0.7756511419302459, 0.9724778106511085], 
             UndirectedEdge[103, 234] -> 
             RGBColor[
              0.34165277525472826`, 0.4703441947830308, 0.9429907906209125], 
             UndirectedEdge[150, 399] -> 
             RGBColor[
              0.2527398969113101, 0.3829760346617555, 0.9377045352827038], 
             UndirectedEdge[321, 338] -> 
             RGBColor[
              0.9060374188254435, 0.923886001186349, 0.8010879565228419], 
             UndirectedEdge[154, 203] -> 
             RGBColor[
              0.36077780249875213`, 0.4853053517709617, 0.9442681500235399], 
             UndirectedEdge[225, 390] -> 
             RGBColor[
              0.26170368970244295`, 0.3923975492225247, 0.9382150100214157], 
             UndirectedEdge[54, 121] -> 
             RGBColor[
              0.502593813473784, 0.607031307257596, 0.9539951244124792], 
             UndirectedEdge[234, 346] -> 
             RGBColor[
              0.34188570275875485`, 0.4705459448797419, 0.9430056325554994], 
             UndirectedEdge[358, 391] -> 
             RGBColor[
              0.8944837314108928, 0.5317010026573729, 0.24979314294089291`], 
             UndirectedEdge[74, 357] -> 
             RGBColor[
              0.7501817896070486, 0.8048048860165811, 0.9757247096384958], 
             UndirectedEdge[130, 364] -> 
             RGBColor[
              0.379967678176128, 0.5035306379305324, 0.9454321823545258], 
             UndirectedEdge[202, 381] -> 
             RGBColor[
              0.9247433274483484, 0.7127453819428937, 0.4824095946157798], 
             UndirectedEdge[98, 307] -> 
             RGBColor[
              0.9814050384421338, 0.9620825967866911, 0.6308199289588313], 
             UndirectedEdge[242, 317] -> 
             RGBColor[
              0.954486951543472, 0.8521857620679489, 0.5290777523178287], 
             UndirectedEdge[9, 279] -> 
             RGBColor[
              0.8856585389447988, 0.5102613582153388, 0.22366955100848618`], 
             UndirectedEdge[200, 399] -> 
             RGBColor[
              0.2527693356026074, 0.3830069765928298, 0.9377062117726225], 
             UndirectedEdge[275, 306] -> 
             RGBColor[
              0.9812383782660234, 0.9513676250265612, 0.559996794380909], 
             UndirectedEdge[121, 181] -> 
             RGBColor[
              0.5602542166801026, 0.6538786381225696, 0.9585244106973264], 
             UndirectedEdge[239, 271] -> 
             RGBColor[
              0.31565140111640955`, 0.4476420700773734, 0.9413406348615612], 
             UndirectedEdge[35, 354] -> 
             RGBColor[
              0.2804072432672092, 0.41205616989288285`, 0.9392801497275012], 
             UndirectedEdge[31, 310] -> 
             RGBColor[
              0.18289778193115996`, 0.30956754357176464`, 0.9337271301567341],
              UndirectedEdge[146, 154] -> 
             RGBColor[
              0.48274463326921224`, 0.5903240190384458, 0.9525963248033308], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.8938562482651202, 0.6317789737296462, 0.5786286100973383], 
             UndirectedEdge[265, 322] -> 
             RGBColor[
              0.5501554119867256, 0.6456799735265193, 0.9577293957987232], 
             UndirectedEdge[115, 284] -> 
             RGBColor[
              0.24130209476909242`, 0.37095417941174347`, 0.9370531693714164],
              UndirectedEdge[38, 391] -> 
             RGBColor[
              0.8930910009287811, 0.5270029957125417, 0.24438264801297166`], 
             UndirectedEdge[116, 328] -> 
             RGBColor[
              0.3628292631493686, 0.48868620423613895`, 0.944340137703926], 
             UndirectedEdge[92, 278] -> 
             RGBColor[
              0.2700397327532974, 0.4011592590046289, 0.9386897353410912], 
             UndirectedEdge[215, 217] -> 
             RGBColor[
              0.8210569332669986, 0.16285839306295227`, 0.16779744911786956`],
              UndirectedEdge[159, 210] -> 
             RGBColor[
              0.3156791522092831, 0.44703146697688845`, 0.9413656404050212], 
             UndirectedEdge[165, 298] -> 
             RGBColor[
              0.6780894534855002, 0.7467966667692734, 0.969689888365638], 
             UndirectedEdge[83, 254] -> 
             RGBColor[
              0.4111965295816905, 0.5301398109018447, 0.9475435443964437], 
             UndirectedEdge[103, 231] -> 
             RGBColor[
              0.3266251404157554, 0.4573222919288569, 0.942033452486374], 
             UndirectedEdge[245, 319] -> 
             RGBColor[
              0.2357412606353747, 0.36510939015995814`, 0.9367364880940181], 
             UndirectedEdge[58, 263] -> 
             RGBColor[
              0.28044730154374703`, 0.41209827368136553`, 0.9392824309870891],
              UndirectedEdge[206, 258] -> 
             RGBColor[
              0.24224766571092132`, 0.37194803442426605`, 0.9371070182377067],
              UndirectedEdge[213, 391] -> 
             RGBColor[
              0.8656794520004861, 0.4212316977913123, 0.20719030408487465`], 
             UndirectedEdge[78, 370] -> 
             RGBColor[
              0.8365302867115927, 0.5954450493775967, 0.5857332485541368], 
             UndirectedEdge[101, 270] -> 
             RGBColor[
              0.2552144898783262, 0.38557698876834556`, 0.937845459691343], 
             UndirectedEdge[135, 377] -> 
             RGBColor[
              0.4590787183907463, 0.5706961122538062, 0.9508478818462491], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.22879801729426974`, 0.3578116011814027, 0.9363410806573501], 
             UndirectedEdge[19, 83] -> 
             RGBColor[
              0.31363288900734776`, 0.44289778603368235`, 0.9413217134716801],
              UndirectedEdge[100, 112] -> 
             RGBColor[
              0.35276762831000186`, 0.47997132185075075`, 0.9436990192291159],
              UndirectedEdge[10, 296] -> 
             RGBColor[
              0.331723708667086, 0.46107618573568054`, 0.9423825762220581], 
             UndirectedEdge[85, 369] -> 
             RGBColor[
              0.24938070758750824`, 0.3794453136975352, 0.9375132344201885], 
             UndirectedEdge[79, 246] -> 
             RGBColor[
              0.5173044068287108, 0.618751689159956, 0.9552146295473145], 
             UndirectedEdge[227, 280] -> 
             RGBColor[
              0.23696761026347307`, 0.36639836137414694`, 0.9368063268911165],
              UndirectedEdge[112, 326] -> 
             RGBColor[
              0.3341557033790634, 0.4638506079381187, 0.9425130838303954], 
             UndirectedEdge[34, 308] -> 
             RGBColor[
              0.2866886948098787, 0.4183307981986623, 0.9396498632451982], 
             UndirectedEdge[29, 226] -> 
             RGBColor[
              0.23953161826969796`, 0.36909329635618626`, 0.936952343353961], 
             UndirectedEdge[204, 345] -> 
             RGBColor[
              0.1904371972329284, 0.3174919470804629, 0.9341564887046044], 
             UndirectedEdge[54, 265] -> 
             RGBColor[
              0.5219430916057815, 0.622739922920198, 0.9555183704657713], 
             UndirectedEdge[22, 100] -> 
             RGBColor[
              0.3344662411106874, 0.46260073594405915`, 0.9425884833453301], 
             UndirectedEdge[126, 336] -> 
             RGBColor[
              0.21152415432057162`, 0.33965567596987617`, 0.9353573597153882],
              UndirectedEdge[82, 157] -> 
             RGBColor[
              0.4242304983845992, 0.5414364441367214, 0.9483720501423687], 
             UndirectedEdge[344, 349] -> 
             RGBColor[
              0.3830038950089686, 0.5061604563464437, 0.9456256474062932], 
             UndirectedEdge[343, 349] -> 
             RGBColor[
              0.5837898565381997, 0.6715473011239714, 0.9612730023398459], 
             UndirectedEdge[2, 66] -> 
             RGBColor[
              0.8956170407292666, 0.531340985508409, 0.2570346377829214], 
             UndirectedEdge[211, 387] -> 
             RGBColor[
              0.27812297420375887`, 0.4096552582761729, 0.939150063983611], 
             UndirectedEdge[250, 265] -> 
             RGBColor[
              0.7900609571838799, 0.8344827358393506, 0.9028921387192244], 
             UndirectedEdge[217, 306] -> 
             RGBColor[
              0.8966008926384637, 0.5440937493586522, 0.25445421300955695`], 
             UndirectedEdge[374, 375] -> 
             RGBColor[
              0.26547453356081113`, 0.3963609452029792, 0.9384297540006862], 
             UndirectedEdge[38, 247] -> 
             RGBColor[
              0.9363993756149239, 0.7826453892822661, 0.2828200168311238], 
             UndirectedEdge[204, 310] -> 
             RGBColor[
              0.18075257528517846`, 0.3073127953728809, 0.9336049638117943], 
             UndirectedEdge[226, 266] -> 
             RGBColor[
              0.24681597923856835`, 0.37674962158963, 0.9373671769348919], 
             UndirectedEdge[319, 334] -> 
             RGBColor[
              0.25149135479282314`, 0.3816637377330832, 0.9376334326561084], 
             UndirectedEdge[73, 206] -> 
             RGBColor[
              0.23733902327111464`, 0.366788739994123, 0.9368274783124455], 
             UndirectedEdge[200, 255] -> 
             RGBColor[
              0.26556731627814384`, 0.3964584657216599, 0.9384350378391786], 
             UndirectedEdge[296, 383] -> 
             RGBColor[
              0.2908789334455868, 0.4230625802138626, 0.9398764969916824], 
             UndirectedEdge[235, 281] -> 
             RGBColor[
              0.6860438629162344, 0.7545031690861064, 0.9694506561545053], 
             UndirectedEdge[174, 272] -> 
             RGBColor[
              0.6878111560407678, 0.756042569748228, 0.9695182461395961], 
             UndirectedEdge[9, 131] -> 
             RGBColor[
              0.8740668087143025, 0.4643040105665355, 0.21434257277214977`], 
             UndirectedEdge[228, 361] -> 
             RGBColor[
              0.3617418491636495, 0.4877443408967252, 0.9442708486463184], 
             UndirectedEdge[149, 199] -> 
             RGBColor[
              0.2230106997449548, 0.3517287634999468, 0.9360115014844858], 
             UndirectedEdge[102, 400] -> 
             RGBColor[
              0.6044539714967849, 0.33060708272811645`, 0.5560794046708185], 
             UndirectedEdge[45, 350] -> 
             RGBColor[
              0.36412092231360993`, 0.48858020750687353`, 0.9444672858023867],
              UndirectedEdge[369, 392] -> 
             RGBColor[
              0.2527015805879449, 0.38293576177650346`, 0.937702353224772], 
             UndirectedEdge[82, 151] -> 
             RGBColor[
              0.34752633634939933`, 0.4754315781894705, 0.9433650487400788], 
             UndirectedEdge[260, 342] -> 
             RGBColor[
              0.706156116764429, 0.7697763499712335, 0.9717551750957918], 
             UndirectedEdge[296, 380] -> 
             RGBColor[
              0.28350610283773925`, 0.41531326778055483`, 0.939456625195691], 
             UndirectedEdge[105, 148] -> 
             RGBColor[
              0.520616067080279, 0.620721827134755, 0.9556738363326167], 
             UndirectedEdge[94, 288] -> 
             RGBColor[
              0.25257497972760906`, 0.38280269624533236`, 0.9376951434930652],
              UndirectedEdge[195, 258] -> 
             RGBColor[
              0.24931398381106837`, 0.3793751827779651, 0.9375094345998292], 
             UndirectedEdge[339, 374] -> 
             RGBColor[
              0.3209321143289635, 0.44937899853087393`, 0.9417809922375882], 
             UndirectedEdge[199, 367] -> 
             RGBColor[
              0.2225587298907346, 0.35125371452661747`, 0.9359857624699174], 
             UndirectedEdge[36, 298] -> 
             RGBColor[
              0.6715537144550077, 0.7414906593926315, 0.9691753710479567], 
             UndirectedEdge[147, 347] -> 
             RGBColor[
              0.28239395908436904`, 0.4141443341817761, 0.9393932902542057], 
             UndirectedEdge[38, 205] -> 
             RGBColor[
              0.9805298619657696, 0.9442896440229023, 0.524841136015259], 
             UndirectedEdge[16, 73] -> 
             RGBColor[
              0.24248824364408117`, 0.372200897085539, 0.937120718795097], 
             UndirectedEdge[108, 290] -> 
             RGBColor[
              0.3863513979794556, 0.5090598951690881, 0.945838947335492], 
             UndirectedEdge[225, 296] -> 
             RGBColor[
              0.2793148229194171, 0.41090796684390285`, 0.9392179380047856], 
             UndirectedEdge[24, 144] -> 
             RGBColor[
              0.8902955651891483, 0.5947396082931894, 0.23017226930310958`], 
             UndirectedEdge[209, 319] -> 
             RGBColor[
              0.24680833108244982`, 0.37674158289262827`, 0.9373667413837155],
              UndirectedEdge[80, 192] -> 
             RGBColor[
              0.3394530711598287, 0.46843892165637124`, 0.9428506274211075], 
             UndirectedEdge[42, 221] -> 
             RGBColor[
              0.9270423893059134, 0.944662453609973, 0.9929033247441504], 
             UndirectedEdge[22, 365] -> 
             RGBColor[
              0.27427955709376345`, 0.40561558320684826`, 0.9389311870650228],
              UndirectedEdge[80, 201] -> 
             RGBColor[
              0.30542134246892777`, 0.4359741704306982, 0.9407915676081757], 
             UndirectedEdge[39, 375] -> 
             RGBColor[
              0.2639687025623859, 0.39477822134843454`, 0.9383439991530031], 
             UndirectedEdge[15, 326] -> 
             RGBColor[
              0.3216255760176605, 0.45254598204008034`, 0.9417312126565649], 
             UndirectedEdge[86, 95] -> 
             RGBColor[
              0.2911574427094625, 0.42335531110870317`, 0.9398923576822427], 
             UndirectedEdge[59, 194] -> 
             RGBColor[
              0.3610366257463029, 0.4871335118181791, 0.9442259124337696], 
             UndirectedEdge[296, 324] -> 
             RGBColor[
              0.2907395975741168, 0.42291612937854317`, 0.9398685620199312], 
             UndirectedEdge[169, 245] -> 
             RGBColor[
              0.22529865841710267`, 0.3541335531293326, 0.936141797346133], 
             UndirectedEdge[258, 284] -> 
             RGBColor[
              0.24846567575091127`, 0.3784835572209025, 0.9374611247107626], 
             UndirectedEdge[33, 152] -> 
             RGBColor[
              0.18127877637637368`, 0.30786586608280325`, 0.9336349301854932],
              UndirectedEdge[246, 349] -> 
             RGBColor[
              0.44459099850605766`, 0.559504109937796, 0.9495499231817904], 
             UndirectedEdge[27, 395] -> 
             RGBColor[
              0.28524240829505776`, 0.41713823490432095`, 0.9395555052228516],
              UndirectedEdge[185, 340] -> 
             RGBColor[
              0.9087343059844912, 0.5861006931027701, 0.36724259092497624`], 
             UndirectedEdge[223, 321] -> 
             RGBColor[
              0.6359268279774656, 0.7126257479828174, 0.9663189746381065], 
             UndirectedEdge[274, 373] -> 
             RGBColor[
              0.24052488712014738`, 0.3701372848948911, 0.9370089085455846], 
             UndirectedEdge[156, 214] -> 
             RGBColor[
              0.5848663164286375, 0.6501021124541597, 0.9231267958935396], 
             UndirectedEdge[205, 221] -> 
             RGBColor[
              0.9585637141169614, 0.9664203575638242, 0.8602427231177231], 
             UndirectedEdge[97, 105] -> 
             RGBColor[
              0.42981427861771465`, 0.5467052578700499, 0.9486083636570456], 
             UndirectedEdge[130, 158] -> 
             RGBColor[
              0.4567607455909806, 0.5686928034323673, 0.9506989661864262], 
             UndirectedEdge[108, 143] -> 
             RGBColor[
              0.49610666284564264`, 0.5994724798522266, 0.954117792155521], 
             UndirectedEdge[176, 399] -> 
             RGBColor[
              0.22535125221155355`, 0.3541888325419396, 0.9361447924849214], 
             UndirectedEdge[150, 189] -> 
             RGBColor[
              0.28557376029945525`, 0.4174865068698732, 0.9395743752293106], 
             UndirectedEdge[253, 386] -> 
             RGBColor[
              0.3405394596215219, 0.4693798967384182, 0.942919851133231], 
             UndirectedEdge[46, 59] -> 
             RGBColor[
              0.30916725287120805`, 0.4399481765928165, 0.9410035436196971], 
             UndirectedEdge[186, 241] -> 
             RGBColor[
              0.2697148101734317, 0.4008177447719086, 0.9386712314808479], 
             UndirectedEdge[39, 93] -> 
             RGBColor[
              0.2591650880555334, 0.38972931793498194`, 0.9380704404131488], 
             UndirectedEdge[214, 264] -> 
             RGBColor[
              0.5869020540862017, 0.6522418018054821, 0.9232427281415339], 
             UndirectedEdge[234, 290] -> 
             RGBColor[
              0.37193655540902126`, 0.4965744830456317, 0.9449204463134487], 
             UndirectedEdge[148, 170] -> 
             RGBColor[
              0.5344288299346016, 0.632685748069522, 0.9565539733675475], 
             UndirectedEdge[50, 362] -> 
             RGBColor[
              0.4294033294821849, 0.5463267879239184, 0.948588402469489], 
             UndirectedEdge[271, 326] -> 
             RGBColor[
              0.3230890593454866, 0.4540841958078278, 0.941814555867055], 
             UndirectedEdge[61, 352] -> 
             RGBColor[
              0.9937500196167237, 0.9890402488671484, 0.5611063895673631], 
             UndirectedEdge[256, 333] -> 
             RGBColor[
              0.21043441051870343`, 0.338510286140365, 0.9352953004180034], 
             UndirectedEdge[100, 394] -> 
             RGBColor[
              0.3677410184422385, 0.49294051979882375`, 0.944653110407893], 
             UndirectedEdge[1, 114] -> 
             RGBColor[
              0.3444304570913155, 0.4727500831795342, 0.9431677820513322], 
             UndirectedEdge[218, 269] -> 
             RGBColor[
              0.9515613514707596, 0.9593431212476458, 0.7385846645144882], 
             UndirectedEdge[182, 253] -> 
             RGBColor[
              0.31490504522225604`, 0.4452672657366318, 0.9413563610246107], 
             UndirectedEdge[57, 354] -> 
             RGBColor[
              0.27649042962059545`, 0.4079393504099632, 0.939057092984733], 
             UndirectedEdge[40, 192] -> 
             RGBColor[
              0.34190093761815415`, 0.4705591405492272, 0.9430066033072686], 
             UndirectedEdge[262, 314] -> 
             RGBColor[
              0.9322274207027686, 0.9487209428474576, 0.9907658897447179], 
             UndirectedEdge[244, 253] -> 
             RGBColor[
              0.30087597692201773`, 0.4305218254587764, 0.9405574263390588], 
             UndirectedEdge[277, 330] -> 
             RGBColor[
              0.24129239010618297`, 0.3709439791957144, 0.9370526167052204], 
             UndirectedEdge[304, 329] -> 
             RGBColor[
              0.2271186296842969, 0.35604645832399684`, 0.9362454420173936], 
             UndirectedEdge[103, 223] -> 
             RGBColor[
              0.3993166746191169, 0.5202694238127852, 0.9466707039440156], 
             UndirectedEdge[92, 337] -> 
             RGBColor[
              0.2862035870447653, 0.41814849471251614`, 0.9396102429307109], 
             UndirectedEdge[226, 341] -> 
             RGBColor[
              0.23010886985563692`, 0.3591893903362524, 0.9364157317714874], 
             UndirectedEdge[193, 260] -> 
             RGBColor[
              0.8156468227717713, 0.8559278037169716, 0.9822546582008858], 
             UndirectedEdge[9, 214] -> 
             RGBColor[
              0.9047202658222255, 0.5928576663351037, 0.5422822863417485], 
             UndirectedEdge[8, 157] -> 
             RGBColor[
              0.38978189814954545`, 0.5115987980501094, 0.9461770157970921], 
             UndirectedEdge[103, 342] -> 
             RGBColor[
              0.4739621782432806, 0.580870006396498, 0.9525470714247991], 
             UndirectedEdge[165, 314] -> 
             RGBColor[
              0.7292803775430885, 0.7876149200721775, 0.9745725244009281], 
             UndirectedEdge[115, 392] -> 
             RGBColor[
              0.24327765587914302`, 0.37303061939621557`, 0.937165674654053], 
             UndirectedEdge[104, 233] -> 
             RGBColor[
              0.8756661600168449, 0.4553685127100845, 0.21500153588103987`], 
             UndirectedEdge[67, 139] -> 
             RGBColor[
              0.21205827028800195`, 0.34021706571655375`, 0.9353877768295796],
              UndirectedEdge[116, 364] -> 
             RGBColor[
              0.382875553578809, 0.5060492934502673, 0.9456174696038513], 
             UndirectedEdge[74, 220] -> 
             RGBColor[
              0.6500539956476187, 0.724027222159205, 0.9674931897567542], 
             UndirectedEdge[100, 168] -> 
             RGBColor[
              0.5233822877675662, 0.6214359238763232, 0.9564882451969059], 
             UndirectedEdge[129, 308] -> 
             RGBColor[
              0.2493864248848615, 0.3794513229395511, 0.9375135600118147], 
             UndirectedEdge[26, 185] -> 
             RGBColor[
              0.6394016686924645, 0.37581057943241813`, 0.5602833187259821], 
             UndirectedEdge[197, 215] -> 
             RGBColor[
              0.9040198154602492, 0.5694397771754294, 0.5010925431304881], 
             UndirectedEdge[178, 240] -> 
             RGBColor[
              0.24159747707370743`, 0.3712646449422136, 0.9370699909566852], 
             UndirectedEdge[52, 223] -> 
             RGBColor[
              0.42035633884682855`, 0.5384929234825571, 0.9480113327439608], 
             UndirectedEdge[192, 243] -> 
             RGBColor[
              0.31643084813058897`, 0.44661450926807483`, 0.9414526439417388],
              UndirectedEdge[124, 252] -> 
             RGBColor[
              0.22380219645594157`, 0.3525606767269839, 0.936056576051262], 
             UndirectedEdge[194, 396] -> 
             RGBColor[
              0.3331772870037427, 0.4601881672994485, 0.9425538104147095], 
             UndirectedEdge[269, 279] -> 
             RGBColor[
              0.9693542844710024, 0.9048940200148108, 0.380506034096984], 
             UndirectedEdge[57, 208] -> 
             RGBColor[
              0.2531470707031978, 0.383404000133339, 0.9377277232277921], 
             UndirectedEdge[169, 304] -> 
             RGBColor[
              0.21989845129097363`, 0.3484575930468634, 0.9358342635391905], 
             UndirectedEdge[209, 280] -> 
             RGBColor[
              0.24552309910713999`, 0.37539072259816386`, 0.9372935493240518],
              UndirectedEdge[226, 399] -> 
             RGBColor[
              0.23675652181007376`, 0.36617649402584324`, 0.9367943057159729],
              UndirectedEdge[206, 392] -> 
             RGBColor[
              0.23975564105496683`, 0.3693287585073688, 0.9369651011201702], 
             UndirectedEdge[48, 343] -> 
             RGBColor[
              0.5738217336869491, 0.6629134141226403, 0.9606378423662292], 
             UndirectedEdge[159, 263] -> 
             RGBColor[
              0.29675910238603487`, 0.4271452950122101, 0.9402881715572926], 
             UndirectedEdge[261, 295] -> 
             RGBColor[
              0.2109178597842839, 0.3390184219709439, 0.935322832138479], 
             UndirectedEdge[33, 204] -> 
             RGBColor[
              0.1789341933349501, 0.3054015606511163, 0.9335014096497838], 
             UndirectedEdge[64, 151] -> 
             RGBColor[
              0.35739789501188024`, 0.48398182614394664`, 0.9439940557289754],
              UndirectedEdge[210, 263] -> 
             RGBColor[
              0.2810036601000736, 0.41268304179923465`, 0.9393141147838132], 
             UndirectedEdge[19, 303] -> 
             RGBColor[
              0.2819979246761117, 0.4137280769086658, 0.939370736680536], 
             UndirectedEdge[248, 315] -> 
             RGBColor[
              0.229741057636631, 0.35880279637343554`, 0.9363947854097444], 
             UndirectedEdge[236, 351] -> 
             RGBColor[
              0.2481333456349381, 0.37813425719806837`, 0.9374421990022963], 
             UndirectedEdge[53, 386] -> 
             RGBColor[
              0.3143035505913172, 0.444852574192945, 0.9413141424158159], 
             UndirectedEdge[93, 301] -> 
             RGBColor[
              0.25102800874557624`, 0.38117673165959054`, 0.9376070457841768],
              UndirectedEdge[37, 159] -> 
             RGBColor[
              0.29061706023566036`, 0.4206896192842019, 0.9399383913431659], 
             UndirectedEdge[148, 326] -> 
             RGBColor[
              0.4816391300864997, 0.5869619633485583, 0.9531902603733251], 
             UndirectedEdge[13, 357] -> 
             RGBColor[
              0.8197351159980406, 0.8595406855045937, 0.9572525529228332], 
             UndirectedEdge[162, 231] -> 
             RGBColor[
              0.27738405997012383`, 0.4088786125667542, 0.9391079839111312], 
             UndirectedEdge[33, 84] -> 
             RGBColor[
              0.17893420048233583`, 0.30540156816347186`, 0.9335014100568169],
              UndirectedEdge[199, 293] -> 
             RGBColor[
              0.21851691429369074`, 0.3470055100682143, 0.9357555870509962], 
             UndirectedEdge[96, 167] -> 
             RGBColor[
              0.28523047788544853`, 0.41712569528738996`, 0.9395548258036737],
              UndirectedEdge[131, 307] -> 
             RGBColor[
              0.9538530771213425, 0.8592378166634234, 0.5753740091193393], 
             UndirectedEdge[174, 291] -> 
             RGBColor[
              0.7125484820155874, 0.7753675568103979, 0.9719838316093115], 
             UndirectedEdge[207, 250] -> 
             RGBColor[
              0.9640415176105277, 0.8943275288623829, 0.5576168978426572], 
             UndirectedEdge[364, 387] -> 
             RGBColor[
              0.3215492584874442, 0.4515282986156772, 0.941761191813439], 
             UndirectedEdge[103, 346] -> 
             RGBColor[
              0.3447990844282577, 0.4730693696510448, 0.9431912706592778], 
             UndirectedEdge[31, 106] -> 
             RGBColor[
              0.5658561150624204, 0.6355057978202503, 0.9529071762376704], 
             UndirectedEdge[128, 316] -> 
             RGBColor[
              0.29024632988181515`, 0.4207827161213608, 0.9398996026647567], 
             UndirectedEdge[185, 289] -> 
             RGBColor[
              0.8607218959500621, 0.40585224662813213`, 0.20335726643267069`],
              UndirectedEdge[20, 172] -> 
             RGBColor[
              0.3545418209166673, 0.4808311305362721, 0.9438368541227812], 
             UndirectedEdge[70, 234] -> 
             RGBColor[
              0.30827476436067847`, 0.438573607296341, 0.9409687003893238], 
             UndirectedEdge[119, 383] -> 
             RGBColor[
              0.2603673467577916, 0.3909929680586598, 0.93813890726766], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.5352140965427551, 0.633549940550514, 0.9565531607151321], 
             UndirectedEdge[20, 54] -> 
             RGBColor[
              0.4298252331165606, 0.5467147461063611, 0.9486090616680254], 
             UndirectedEdge[229, 334] -> 
             RGBColor[
              0.25414759898597045`, 0.3844556187956901, 0.9377847018333471], 
             UndirectedEdge[63, 142] -> 
             RGBColor[
              0.890072513149207, 0.5193941486818902, 0.23091004398772222`], 
             UndirectedEdge[230, 358] -> 
             RGBColor[
              0.9687169526811137, 0.9061370771638947, 0.3329716977842575], 
             UndirectedEdge[119, 296] -> 
             RGBColor[
              0.27100995406971695`, 0.4021790231237703, 0.9387449880097476], 
             UndirectedEdge[218, 262] -> 
             RGBColor[
              0.9243533171861171, 0.9424423464401257, 0.9900148507220045], 
             UndirectedEdge[100, 170] -> 
             RGBColor[
              0.4107918604538279, 0.5302289953510277, 0.9473962719925066], 
             UndirectedEdge[97, 357] -> 
             RGBColor[
              0.5589872751901463, 0.652039901144515, 0.958856542313451], 
             UndirectedEdge[375, 399] -> 
             RGBColor[
              0.24486217858118842`, 0.3746960532206071, 0.9372559108778432], 
             UndirectedEdge[199, 252] -> 
             RGBColor[
              0.2250679449332263, 0.3538910586296987, 0.9361286585545363], 
             UndirectedEdge[175, 345] -> 
             RGBColor[
              0.1904397679735038, 0.31749464909180203`, 0.9341566351044772], 
             UndirectedEdge[176, 186] -> 
             RGBColor[
              0.23214557991116364`, 0.36133010173948693`, 0.9365317193961071],
              UndirectedEdge[309, 371] -> 
             RGBColor[
              0.2714180274121831, 0.4026079340800466, 0.9387682271829105], 
             UndirectedEdge[326, 354] -> 
             RGBColor[
              0.3095818357707423, 0.4398872474233331, 0.94104533946662], 
             UndirectedEdge[38, 289] -> 
             RGBColor[
              0.9317722599024755, 0.7624356715057958, 0.27900046954474644`], 
             UndirectedEdge[120, 237] -> 
             RGBColor[
              0.5723986729827764, 0.663738054850602, 0.9594804667840822], 
             UndirectedEdge[275, 384] -> 
             RGBColor[
              0.8702642398197578, 0.8971991046411623, 0.8780681531351799], 
             UndirectedEdge[216, 220] -> 
             RGBColor[
              0.5672680445778805, 0.6593163046949915, 0.9592519182010989], 
             UndirectedEdge[50, 276] -> 
             RGBColor[
              0.6098568885565028, 0.6922609454050347, 0.9637197242270632], 
             UndirectedEdge[143, 321] -> 
             RGBColor[
              0.7212153553030598, 0.7818668166701053, 0.973033199931347], 
             UndirectedEdge[225, 316] -> 
             RGBColor[
              0.2556938059368381, 0.38608078033623494`, 0.9378727560317908], 
             UndirectedEdge[40, 332] -> 
             RGBColor[
              0.43326686926446056`, 0.5476890621459892, 0.9493828047697146], 
             UndirectedEdge[254, 343] -> 
             RGBColor[
              0.5958559812878284, 0.6815586834125604, 0.9621633323841816], 
             UndirectedEdge[37, 167] -> 
             RGBColor[
              0.26667449670074206`, 0.39762218254510395`, 0.9384980901263189],
              UndirectedEdge[26, 204] -> 
             RGBColor[
              0.3170199268376633, 0.4369570715354334, 0.9418741487280438], 
             UndirectedEdge[141, 189] -> 
             RGBColor[
              0.33030534537683665`, 0.4597575440654077, 0.9422954993465642], 
             UndirectedEdge[55, 210] -> 
             RGBColor[
              0.3517281816196206, 0.4782553243752219, 0.9436626526821428], 
             UndirectedEdge[41, 312] -> 
             RGBColor[
              0.40188874544580117`, 0.5222558384193261, 0.9469012891044913], 
             UndirectedEdge[102, 247] -> 
             RGBColor[
              0.8631522875093278, 0.40917697995257735`, 0.2050732281891151], 
             UndirectedEdge[30, 400] -> 
             RGBColor[
              0.284268969836752, 0.4086385761438802, 0.9397738211163575], 
             UndirectedEdge[57, 195] -> 
             RGBColor[
              0.25945106473985713`, 0.3900298975621752, 0.9380867263622563], 
             UndirectedEdge[301, 324] -> 
             RGBColor[
              0.2683877801719362, 0.39942295210177514`, 0.9385956590854276], 
             UndirectedEdge[290, 331] -> 
             RGBColor[
              0.42861309362707734`, 0.5456648518044729, 0.9485318252116084], 
             UndirectedEdge[49, 347] -> 
             RGBColor[
              0.2678932418389194, 0.3989031609582332, 0.9385674958589661], 
             UndirectedEdge[92, 258] -> 
             RGBColor[
              0.2702985516937192, 0.40143129412108086`, 0.93870447469686], 
             UndirectedEdge[234, 313] -> 
             RGBColor[
              0.3107738733861259, 0.4412003293347502, 0.9411110209512226], 
             UndirectedEdge[376, 377] -> 
             RGBColor[
              0.4266363429774569, 0.5439526897461481, 0.9484058684081864], 
             UndirectedEdge[223, 272] -> 
             RGBColor[
              0.5505420601979628, 0.6459225184451997, 0.9578086189518668], 
             UndirectedEdge[213, 302] -> 
             RGBColor[
              0.9491225739214294, 0.8267349297802298, 0.3261475838124945], 
             UndirectedEdge[121, 158] -> 
             RGBColor[
              0.5281560210081759, 0.6278198768688632, 0.9559975231544674], 
             UndirectedEdge[240, 248] -> 
             RGBColor[
              0.22770719970496556`, 0.3566650827332143, 0.9362789602093593], 
             UndirectedEdge[18, 132] -> 
             RGBColor[
              0.8722144636354254, 0.9008667885957915, 0.9791289224454733], 
             UndirectedEdge[59, 79] -> 
             RGBColor[
              0.46241207497172554`, 0.5712067102742551, 0.9517169387007705], 
             UndirectedEdge[109, 207] -> 
             RGBColor[
              0.9669761340347394, 0.8955410681699965, 0.508982709149612], 
             UndirectedEdge[190, 365] -> 
             RGBColor[
              0.24867185173243342`, 0.3787002612497945, 0.9374728661279003], 
             UndirectedEdge[78, 391] -> 
             RGBColor[
              0.8311173699138001, 0.24018731764171894`, 0.1774313346124849], 
             UndirectedEdge[159, 236] -> 
             RGBColor[
              0.2909783973419341, 0.4210694074929913, 0.9399589689568179], 
             UndirectedEdge[95, 334] -> 
             RGBColor[
              0.27158878350233817`, 0.4027874095573609, 0.9387779514896339], 
             UndirectedEdge[20, 147] -> 
             RGBColor[
              0.34619840677068126`, 0.47206167326583015`, 0.9433617090301424],
              UndirectedEdge[229, 388] -> 
             RGBColor[
              0.23513063549537086`, 0.3644675844219441, 0.9367017138956337], 
             UndirectedEdge[15, 271] -> 
             RGBColor[
              0.3053243996883596, 0.43824568113047624`, 0.940699144924056], 
             UndirectedEdge[53, 151] -> 
             RGBColor[
              0.302539739143033, 0.43466335198279643`, 0.9405645627526612], 
             UndirectedEdge[178, 309] -> 
             RGBColor[
              0.2573894464516083, 0.38786300602707646`, 0.9379693202506316], 
             UndirectedEdge[309, 386] -> 
             RGBColor[
              0.30507679489801537`, 0.4351546689491852, 0.9407886923288442], 
             UndirectedEdge[199, 299] -> 
             RGBColor[
              0.21996573354153404`, 0.3485283109581435, 0.9358380951638248], 
             UndirectedEdge[33, 90] -> 
             RGBColor[
              0.44237359411374266`, 0.5377546224462848, 0.9524068017673784], 
             UndirectedEdge[191, 216] -> 
             RGBColor[
              0.6689774683276695, 0.7413295497654275, 0.9676410801591727], 
             UndirectedEdge[188, 203] -> 
             RGBColor[
              0.2792417470878428, 0.4108311595116429, 0.9392137764442834], 
             UndirectedEdge[87, 263] -> 
             RGBColor[
              0.2761111635451054, 0.407540717717765, 0.9390354943428079], 
             UndirectedEdge[25, 76] -> 
             RGBColor[
              0.8478277754462535, 0.3686308171105509, 0.1934332378220659], 
             UndirectedEdge[329, 334] -> 
             RGBColor[
              0.2482689309678744, 0.37827676597959103`, 0.9374499203864265], 
             UndirectedEdge[42, 376] -> 
             RGBColor[
              0.6853095806395425, 0.7514657941798157, 0.9712763701432583], 
             UndirectedEdge[54, 130] -> 
             RGBColor[
              0.43119853805658864`, 0.5479042338211002, 0.9486965674444381], 
             UndirectedEdge[90, 256] -> 
             RGBColor[
              0.46555708352199543`, 0.5621219397324855, 0.9537270671922793], 
             UndirectedEdge[160, 302] -> 
             RGBColor[
              0.9083773079386029, 0.59816388871644, 0.2904675904582531], 
             UndirectedEdge[299, 367] -> 
             RGBColor[
              0.21672169883755696`, 0.34511862480058364`, 0.9356533521865525],
              UndirectedEdge[16, 96] -> 
             RGBColor[
              0.2643859994981743, 0.3952168268861021, 0.9383677635961609], 
             UndirectedEdge[5, 223] -> 
             RGBColor[
              0.6477551093793219, 0.7220395366342189, 0.9674518801311646], 
             UndirectedEdge[40, 228] -> 
             RGBColor[
              0.35358465424250685`, 0.48067898864856917`, 0.9437510793990673],
              UndirectedEdge[154, 222] -> 
             RGBColor[
              0.5175424648922109, 0.6185744663744461, 0.9553357375773506], 
             UndirectedEdge[85, 188] -> 
             RGBColor[
              0.25419669233076414`, 0.38450721901376617`, 0.937787497626706], 
             UndirectedEdge[281, 384] -> 
             RGBColor[
              0.6902109435663115, 0.7577585241609326, 0.9698659918101223], 
             UndirectedEdge[249, 334] -> 
             RGBColor[
              0.2654841590440016, 0.39637106219610324`, 0.9384303021577143], 
             UndirectedEdge[203, 243] -> 
             RGBColor[
              0.28988476393267687`, 0.4220176450218065, 0.9398198805086642], 
             UndirectedEdge[49, 147] -> 
             RGBColor[
              0.2702371158648362, 0.4013667211696683, 0.9387009760172913], 
             UndirectedEdge[99, 232] -> 
             RGBColor[
              0.7518421224806613, 0.804458883314896, 0.9388506680687247], 
             UndirectedEdge[84, 389] -> 
             RGBColor[
              0.1790075704625178, 0.3054786846645686, 0.933505588368647], 
             UndirectedEdge[76, 242] -> 
             RGBColor[
              0.8826456379438963, 0.5379102714518893, 0.22287275278700588`], 
             UndirectedEdge[129, 397] -> 
             RGBColor[
              0.24351700983454236`, 0.3732821955792575, 0.9371793055077206], 
             UndirectedEdge[177, 390] -> 
             RGBColor[
              0.2941038875347629, 0.4252352483079229, 0.9401047123377103], 
             UndirectedEdge[138, 144] -> 
             RGBColor[
              0.8488904911809813, 0.34529052811745564`, 0.1932170904993126], 
             UndirectedEdge[184, 325] -> 
             RGBColor[
              0.2146653182782982, 0.3429572384507447, 0.9355362443558451], 
             UndirectedEdge[69, 140] -> 
             RGBColor[
              0.5800718085263902, 0.6695145386144623, 0.9603941834467046], 
             UndirectedEdge[247, 391] -> 
             RGBColor[
              0.8636991649292758, 0.4133805194455108, 0.20559691862406698`], 
             UndirectedEdge[14, 391] -> 
             RGBColor[
              0.9073739340103057, 0.5740384053828973, 0.3971702369213773], 
             UndirectedEdge[229, 240] -> 
             RGBColor[
              0.24305133588145522`, 0.372792742729129, 0.9371527860649951], 
             UndirectedEdge[166, 400] -> 
             RGBColor[
              0.6071900057616888, 0.351637441026028, 0.5586994341727993], 
             UndirectedEdge[281, 386] -> 
             RGBColor[
              0.4856785944575267, 0.5902406468075978, 0.9535084650798691], 
             UndirectedEdge[150, 255] -> 
             RGBColor[
              0.26553787758684655`, 0.39642752379058566`, 0.9384333613492598],
              UndirectedEdge[103, 290] -> 
             RGBColor[
              0.3748499370785241, 0.4990979078169345, 0.9451060844172272], 
             UndirectedEdge[212, 299] -> 
             RGBColor[
              0.2125129386493282, 0.3406949509919467, 0.9354136695201356], 
             UndirectedEdge[206, 208] -> 
             RGBColor[
              0.23232439396841398`, 0.3615180466511231, 0.9365419025921359], 
             UndirectedEdge[75, 169] -> 
             RGBColor[
              0.2324382955275915, 0.3616377644115946, 0.9365483891174288], 
             UndirectedEdge[110, 167] -> 
             RGBColor[
              0.26956370563298526`, 0.40065892431931827`, 0.9386626263008084],
              UndirectedEdge[33, 214] -> 
             RGBColor[
              0.5813572401883383, 0.6464138508373214, 0.9229269591928677], 
             UndirectedEdge[98, 107] -> 
             RGBColor[
              0.9083938909149378, 0.6192253386491839, 0.2762763560175848], 
             UndirectedEdge[238, 252] -> 
             RGBColor[
              0.22677811637454098`, 0.3556885572456525, 0.9362260502881472], 
             UndirectedEdge[91, 241] -> 
             RGBColor[
              0.2767915804260243, 0.40825587900053273`, 0.9390742430775896], 
             UndirectedEdge[74, 219] -> 
             RGBColor[
              0.6359306602465759, 0.7123948141262615, 0.9664273391659474], 
             UndirectedEdge[45, 180] -> 
             RGBColor[
              0.33088455801292704`, 0.4597925392578639, 0.9423494940589101], 
             UndirectedEdge[187, 235] -> 
             RGBColor[
              0.792013758809907, 0.8376400126416226, 0.9798528182009743], 
             UndirectedEdge[114, 188] -> 
             RGBColor[0.297981899619691, 0.4286669180863, 0.9403491528141107],
              UndirectedEdge[81, 378] -> 
             RGBColor[
              0.21412094136701804`, 0.3423850638014996, 0.9355052428960813], 
             UndirectedEdge[19, 313] -> 
             RGBColor[
              0.27859623109563336`, 0.41015268127575305`, 0.9391770152634824],
              UndirectedEdge[195, 284] -> 
             RGBColor[
              0.24484639804506322`, 0.3746794668765958, 0.9372550121996561], 
             UndirectedEdge[64, 253] -> 
             RGBColor[
              0.3703380254209453, 0.4951899167144135, 0.9448185893961331], 
             UndirectedEdge[55, 122] -> 
             RGBColor[
              0.4248101196568824, 0.5423709068945195, 0.9482895030730654], 
             UndirectedEdge[99, 275] -> 
             RGBColor[
              0.9851141209349312, 0.987104803716967, 0.8512424005775606], 
             UndirectedEdge[118, 367] -> 
             RGBColor[
              0.21268815866311674`, 0.340879118336029, 0.9354236480407061], 
             UndirectedEdge[7, 96] -> 
             RGBColor[
              0.3381582412697068, 0.46529865529748227`, 0.9428420383243149], 
             UndirectedEdge[110, 115] -> 
             RGBColor[
              0.2470920216969208, 0.3770397597154611, 0.9373828971445268], 
             UndirectedEdge[68, 95] -> 
             RGBColor[
              0.2792515764807897, 0.4108414908268496, 0.9392143362136705], 
             UndirectedEdge[289, 302] -> 
             RGBColor[
              0.9425151711377706, 0.798674033657958, 0.3207346510653094], 
             UndirectedEdge[260, 321] -> 
             RGBColor[
              0.813370248803728, 0.8541302872991015, 0.9820328030897745], 
             UndirectedEdge[191, 220] -> 
             RGBColor[
              0.5771439386381384, 0.6670314281944398, 0.9602362550255482], 
             UndirectedEdge[169, 209] -> 
             RGBColor[
              0.23636572886417778`, 0.36576574586200267`, 0.9367720506358304],
              UndirectedEdge[32, 252] -> 
             RGBColor[
              0.2203092674216852, 0.34888938684748844`, 0.9358576589100864], 
             UndirectedEdge[75, 280] -> 
             RGBColor[
              0.24159566577055375`, 0.3712627411477558, 0.9370698878056503], 
             UndirectedEdge[14, 224] -> 
             RGBColor[
              0.9850092930497456, 0.9599506894449308, 0.4935654545583491], 
             UndirectedEdge[128, 311] -> 
             RGBColor[
              0.4227935959175786, 0.5388307190597109, 0.9486565824461703], 
             UndirectedEdge[132, 198] -> 
             RGBColor[
              0.8128559952710535, 0.8537811311091374, 0.9819675933041132], 
             UndirectedEdge[245, 388] -> 
             RGBColor[
              0.22663197894047044`, 0.3555349575367959, 0.9362177279774678], 
             UndirectedEdge[183, 273] -> 
             RGBColor[
              0.26718551324119244`, 0.3981592933294373, 0.9385271917623162], 
             UndirectedEdge[69, 220] -> 
             RGBColor[
              0.4818265682663484, 0.5902075400149862, 0.9523502989242535], 
             UndirectedEdge[37, 263] -> 
             RGBColor[
              0.25594156812645086`, 0.3863411941065481, 0.9378868657219579], 
             UndirectedEdge[235, 384] -> 
             RGBColor[
              0.7442607582282336, 0.800141428009943, 0.9751446149341176], 
             UndirectedEdge[132, 216] -> 
             RGBColor[
              0.7291619678468395, 0.7883461382089411, 0.9736397086151186], 
             UndirectedEdge[225, 380] -> 
             RGBColor[
              0.2612993849996442, 0.39197259934548456`, 0.9381919854667065], 
             UndirectedEdge[3, 371] -> 
             RGBColor[
              0.3210626317693298, 0.4491168451749269, 0.9418030466401561], 
             UndirectedEdge[269, 314] -> 
             RGBColor[
              0.9594354549874111, 0.9656217176549777, 0.7393357035372017], 
             UndirectedEdge[16, 206] -> 
             RGBColor[
              0.23671129027789278`, 0.36612895281767627`, 0.9367917298471292],
              UndirectedEdge[84, 256] -> 
             RGBColor[
              0.20211768989058865`, 0.32976888544967253`, 0.9348216754817178],
              UndirectedEdge[58, 348] -> 
             RGBColor[
              0.28088310771412667`, 0.4125563335981417, 0.9393072495037748], 
             UndirectedEdge[177, 360] -> 
             RGBColor[
              0.31615011179738517`, 0.4482550694974156, 0.9413657834565303], 
             UndirectedEdge[2, 106] -> 
             RGBColor[
              0.8834730056375308, 0.5519688209280622, 0.5686856052309635], 
             UndirectedEdge[256, 317] -> 
             RGBColor[
              0.6079677143241806, 0.6722679099328412, 0.8705698500730703], 
             UndirectedEdge[87, 351] -> 
             RGBColor[
              0.2679416039473189, 0.3989539926004958, 0.9385702500094941], 
             UndirectedEdge[48, 103] -> 
             RGBColor[
              0.3850045259376993, 0.5078933023022759, 0.9457531258399835], 
             UndirectedEdge[256, 381] -> 
             RGBColor[
              0.6092276972658053, 0.6727889452592876, 0.8496886719990233], 
             UndirectedEdge[91, 226] -> 
             RGBColor[
              0.25062761976227643`, 0.38075589745201466`, 0.9375842442239002],
              UndirectedEdge[105, 113] -> 
             RGBColor[
              0.6069298774587211, 0.6884337835985022, 0.9640833346207096], 
             UndirectedEdge[223, 291] -> 
             RGBColor[
              0.5752793861727824, 0.6652475055073694, 0.9602742044215822], 
             UndirectedEdge[203, 348] -> 
             RGBColor[
              0.277176399167938, 0.4086603478972015, 0.9390961579356532], 
             UndirectedEdge[259, 367] -> 
             RGBColor[
              0.21516769270569408`, 0.3434852658263162, 0.935564853836289], 
             UndirectedEdge[188, 206] -> 
             RGBColor[
              0.2493239941811602, 0.37938570431162577`, 0.937510004675597], 
             UndirectedEdge[250, 289] -> 
             RGBColor[
              0.9429902625743816, 0.8090015716874366, 0.5405821025323335], 
             UndirectedEdge[194, 377] -> 
             RGBColor[
              0.40146722310948635`, 0.5221524631532592, 0.9468021143463783], 
             UndirectedEdge[83, 231] -> 
             RGBColor[
              0.3307828964588674, 0.4609235312385056, 0.9422983810248817], 
             UndirectedEdge[276, 376] -> 
             RGBColor[
              0.6019797217390458, 0.6854606658855094, 0.9632115739949887], 
             UndirectedEdge[83, 120] -> 
             RGBColor[
              0.45962999176153224`, 0.5694602774020465, 0.9513564039568587], 
             UndirectedEdge[40, 243] -> 
             RGBColor[
              0.3138420416346276, 0.4443722151984709, 0.9412876874810078], 
             UndirectedEdge[4, 392] -> 
             RGBColor[
              0.24007285485442642`, 0.3696621703231174, 0.9369831659767736], 
             UndirectedEdge[81, 329] -> 
             RGBColor[
              0.22742713619850993`, 0.35637071823087746`, 0.9362630110069835],
              UndirectedEdge[131, 363] -> 
             RGBColor[
              0.8924893365860593, 0.5994472191560132, 0.23173103267921852`], 
             UndirectedEdge[167, 192] -> 
             RGBColor[
              0.3140196057697616, 0.4440801406652496, 0.941315327256403], 
             UndirectedEdge[41, 327] -> 
             RGBColor[
              0.32970622489449014`, 0.4599966933120725, 0.9422295669958778], 
             UndirectedEdge[24, 382] -> 
             RGBColor[
              0.9004669733536322, 0.6409255971753784, 0.23865954159958375`], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.6399409788041857, 0.37995595327830467`, 0.56079976269803], 
             UndirectedEdge[90, 261] -> 
             RGBColor[
              0.4426270855649366, 0.538021058033776, 0.9524212377305169], 
             UndirectedEdge[146, 297] -> 
             RGBColor[
              0.7409851288378926, 0.7966845449876518, 0.9658863907552364], 
             UndirectedEdge[5, 291] -> 
             RGBColor[
              0.7689673032381015, 0.8196158140703518, 0.9775611053894065], 
             UndirectedEdge[229, 315] -> 
             RGBColor[
              0.24508519381312066`, 0.3749304563693503, 0.9372686112653803], 
             UndirectedEdge[241, 360] -> 
             RGBColor[
              0.3006768355928906, 0.4332086382716799, 0.9404400442858039], 
             UndirectedEdge[59, 237] -> 
             RGBColor[
              0.4562186120487096, 0.5661785780610258, 0.9512293666120685], 
             UndirectedEdge[257, 381] -> 
             RGBColor[
              0.9078770993756948, 0.5831041621482105, 0.46625847556572675`], 
             UndirectedEdge[270, 308] -> 
             RGBColor[
              0.2553377632908749, 0.38570655694091993`, 0.9378524799298211], 
             UndirectedEdge[317, 382] -> 
             RGBColor[
              0.9447039927210837, 0.8118308485146293, 0.5211250046258997], 
             UndirectedEdge[23, 89] -> 
             RGBColor[
              0.21600037669219402`, 0.3443604694913417, 0.9356122739574746], 
             UndirectedEdge[57, 327] -> 
             RGBColor[
              0.2958997785397042, 0.4274294644124098, 0.9401957587844365], 
             UndirectedEdge[347, 362] -> 
             RGBColor[
              0.3423545559019188, 0.4682989085041503, 0.9431326516737686], 
             UndirectedEdge[43, 293] -> 
             RGBColor[
              0.21933315592561953`, 0.34786343177608003`, 0.9358020708044131],
              UndirectedEdge[73, 208] -> 
             RGBColor[
              0.23810134733460236`, 0.3675899909189858, 0.9368708915401036], 
             UndirectedEdge[53, 129] -> 
             RGBColor[
              0.26346421560774436`, 0.39424797357278596`, 0.9383152693672578],
              UndirectedEdge[324, 383] -> 
             RGBColor[
              0.2800969902621915, 0.41173007431343256`, 0.9392624812778436], 
             UndirectedEdge[368, 399] -> 
             RGBColor[
              0.22383026101092823`, 0.35259017435367035`, 0.9360581742861507],
              UndirectedEdge[51, 136] -> 
             RGBColor[
              0.4957527510770341, 0.5993305404010079, 0.9540497614266502], 
             UndirectedEdge[145, 359] -> 
             RGBColor[
              0.24179608967805666`, 0.37147339938215107`, 0.9370813016506819],
              UndirectedEdge[222, 297] -> 
             RGBColor[
              0.7757829604608912, 0.8249349923236523, 0.9686258035292561], 
             UndirectedEdge[81, 209] -> 
             RGBColor[
              0.23587421810878062`, 0.36524913689449845`, 0.9367440598254355],
              UndirectedEdge[31, 345] -> 
             RGBColor[
              0.1925824038789099, 0.3197466952793466, 0.9342786550495443], 
             UndirectedEdge[155, 180] -> 
             RGBColor[
              0.33540782096983857`, 0.46454677541701367`, 0.9426070871927383],
              UndirectedEdge[4, 369] -> 
             RGBColor[
              0.2448252232373639, 0.37465721081114345`, 0.937253806325683], 
             UndirectedEdge[102, 289] -> 
             RGBColor[
              0.8585251717968794, 0.3889672621761071, 0.20125368090273776`], 
             UndirectedEdge[70, 103] -> 
             RGBColor[
              0.3111881460301813, 0.44109703206764383`, 0.9411543384931023], 
             UndirectedEdge[177, 375] -> 
             RGBColor[
              0.28837692064883436`, 0.4192158430001391, 0.939778570045845], 
             UndirectedEdge[171, 253] -> 
             RGBColor[
              0.30746418261270597`, 0.43744644735605664`, 0.9409326149067666],
              UndirectedEdge[150, 241] -> 
             RGBColor[
              0.2807813627744614, 0.41244939321555174`, 0.939301455279979], 
             UndirectedEdge[24, 317] -> 
             RGBColor[
              0.946390043794504, 0.8194868126517976, 0.5225318869704552], 
             UndirectedEdge[80, 110] -> 
             RGBColor[
              0.29499717102305234`, 0.4250177053104399, 0.9401979264655129], 
             UndirectedEdge[176, 341] -> 
             RGBColor[
              0.21870360025711671`, 0.3472017288523488, 0.9357662185404361], 
             UndirectedEdge[154, 192] -> 
             RGBColor[
              0.3873238866966642, 0.5099022160172301, 0.9459009134566145], 
             UndirectedEdge[121, 322] -> 
             RGBColor[
              0.5308061338547281, 0.6299713578639174, 0.9562061497454312], 
             UndirectedEdge[268, 381] -> 
             RGBColor[
              0.9052330145226024, 0.5627805673219706, 0.46372649692433865`], 
             UndirectedEdge[76, 104] -> 
             RGBColor[
              0.8904092616611533, 0.5686904524165735, 0.22911954666558126`], 
             UndirectedEdge[91, 186] -> 
             RGBColor[
              0.2555444422624831, 0.38592378964428387`, 0.9378642499915], 
             UndirectedEdge[216, 357] -> 
             RGBColor[
              0.6673958385373104, 0.7400939685523675, 0.9674834380828405], 
             UndirectedEdge[210, 236] -> 
             RGBColor[
              0.27522295505597283`, 0.4066071542800159, 0.9389849121833385], 
             UndirectedEdge[26, 173] -> 
             RGBColor[
              0.34074023236907375`, 0.46188861660318076`, 0.9432249850370102],
              UndirectedEdge[10, 374] -> 
             RGBColor[
              0.31901480157328777`, 0.4477183185888486, 0.9416588227642095], 
             UndirectedEdge[289, 340] -> 
             RGBColor[
              0.9457657182249508, 0.8088519239369327, 0.40028051736176995`], 
             UndirectedEdge[65, 168] -> 
             RGBColor[
              0.592741338058181, 0.6798274166038522, 0.9613729899467283], 
             UndirectedEdge[40, 203] -> 
             RGBColor[
              0.31535485342024205`, 0.44596227630295887`, 0.941373839874194], 
             UndirectedEdge[167, 201] -> 
             RGBColor[
              0.27998787707886075`, 0.41161538943957654`, 0.9392562674434715],
              UndirectedEdge[41, 57] -> 
             RGBColor[
              0.3070138697292798, 0.4370559315903547, 0.9409039388472313], 
             UndirectedEdge[214, 363] -> 
             RGBColor[
              0.9231427936939823, 0.7280008749245814, 0.5596707462488172], 
             UndirectedEdge[22, 189] -> 
             RGBColor[
              0.29643257003583556`, 0.4288998043911114, 0.9401927683796281], 
             UndirectedEdge[41, 96] -> 
             RGBColor[
              0.3138659022147775, 0.44425785217656466`, 0.9412941519606068], 
             UndirectedEdge[31, 197] -> 
             RGBColor[
              0.5859844235922751, 0.6497599697422292, 0.884913356826519], 
             UndirectedEdge[275, 281] -> 
             RGBColor[
              0.8120473445077586, 0.8515608457173255, 0.8723741943555676], 
             UndirectedEdge[89, 353] -> 
             RGBColor[
              0.21448123699978983`, 0.34276375735560527`, 0.9355257611993579],
              UndirectedEdge[324, 375] -> 
             RGBColor[
              0.267401497471214, 0.3983863064493811, 0.938539491744696], 
             UndirectedEdge[5, 174] -> 
             RGBColor[
              0.7850242052221269, 0.8321595879372474, 0.979161507318894], 
             UndirectedEdge[36, 314] -> 
             RGBColor[
              0.7227446385125958, 0.7823089126955356, 0.9740580070832467], 
             UndirectedEdge[220, 357] -> 
             RGBColor[
              0.5755623088477795, 0.6657958469813797, 0.960078612949216], 
             UndirectedEdge[291, 342] -> 
             RGBColor[
              0.6499248897969461, 0.7258480880910823, 0.9661505719023658], 
             UndirectedEdge[21, 159] -> 
             RGBColor[
              0.3221758681761928, 0.45347427680941704`, 0.9417497393246208], 
             UndirectedEdge[220, 394] -> 
             RGBColor[
              0.4171512331180811, 0.5351366490894776, 0.9479674097431279], 
             UndirectedEdge[129, 249] -> 
             RGBColor[
              0.25362687609654, 0.3839083060231606, 0.9377550474351345], 
             UndirectedEdge[37, 58] -> 
             RGBColor[
              0.2743052593933725, 0.40564259795335733`, 0.9389326507729624], 
             UndirectedEdge[118, 259] -> 
             RGBColor[
              0.20854115618205327`, 0.33652035579328765`, 0.9351874823843499],
              UndirectedEdge[201, 243] -> 
             RGBColor[
              0.2823991194396881, 0.4141497580424017, 0.9393935841288071], 
             UndirectedEdge[40, 110] -> 
             RGBColor[
              0.29744503748137785`, 0.4271379242032959, 0.940353902351674], 
             UndirectedEdge[35, 278] -> 
             RGBColor[
              0.26672833715189703`, 0.3976787722729497, 0.9385011562603622], 
             UndirectedEdge[164, 315] -> 
             RGBColor[
              0.2429063670041037, 0.37264037124747484`, 0.9371445303018922], 
             UndirectedEdge[81, 304] -> 
             RGBColor[
              0.21940694053557647`, 0.34794098407935925`, 0.9358062727287957],
              UndirectedEdge[12, 299] -> 
             RGBColor[
              0.21628284341415968`, 0.3446573599255522, 0.9356283600194184], 
             UndirectedEdge[203, 258] -> 
             RGBColor[
              0.2721654186176039, 0.4033934896242831, 0.9388107900063931], 
             UndirectedEdge[250, 276] -> 
             RGBColor[
              0.8768966809261312, 0.9030925119563854, 0.9110185744810039], 
             UndirectedEdge[124, 238] -> 
             RGBColor[
              0.22624718755874168`, 0.35513051739741625`, 0.9361958146775262],
              UndirectedEdge[96, 154] -> 
             RGBColor[
              0.3585347588123511, 0.48294777063937044`, 0.9441404120038852], 
             UndirectedEdge[126, 238] -> 
             RGBColor[
              0.2206324276302094, 0.349229048716188, 0.9358760624058893], 
             UndirectedEdge[103, 108] -> 
             RGBColor[
              0.3560676178251626, 0.48282960690648735`, 0.9439092916429558], 
             UndirectedEdge[122, 210] -> 
             RGBColor[
              0.3730056479605837, 0.4966847962832106, 0.9450184340224643], 
             UndirectedEdge[108, 234] -> 
             RGBColor[
              0.3531542361556598, 0.4803061821351844, 0.9437236535391773], 
             UndirectedEdge[222, 361] -> 
             RGBColor[
              0.48027671073484357`, 0.5862967431545993, 0.9529611966752556], 
             UndirectedEdge[12, 274] -> 
             RGBColor[
              0.2245824786939262, 0.35338080283185697`, 0.936101011970391], 
             UndirectedEdge[141, 219] -> 
             RGBColor[
              0.4036258957264883, 0.5240221968760659, 0.9469396630566943], 
             UndirectedEdge[179, 344] -> 
             RGBColor[
              0.29513590341832135`, 0.4264382934400302, 0.9401591514378], 
             UndirectedEdge[14, 230] -> 
             RGBColor[
              0.9816071552805266, 0.9484744798894191, 0.4803487917647419], 
             UndirectedEdge[12, 118] -> 
             RGBColor[
              0.21224930323971947`, 0.34041785346099757`, 0.9353986558735721],
              UndirectedEdge[44, 49] -> 
             RGBColor[
              0.2768464709137847, 0.4083135723834269, 0.9390773690096643], 
             UndirectedEdge[224, 247] -> 
             RGBColor[
              0.9413345239687156, 0.7992928035075443, 0.30199213626103877`], 
             UndirectedEdge[161, 222] -> 
             RGBColor[
              0.5181817733764011, 0.6191282032508729, 0.9553764737486448], 
             UndirectedEdge[148, 168] -> 
             RGBColor[
              0.6470192572483401, 0.7238926765948177, 0.9656459465719469], 
             UndirectedEdge[219, 323] -> 
             RGBColor[
              0.6386990444191253, 0.7146022485196659, 0.9666913901196909], 
             UndirectedEdge[309, 334] -> 
             RGBColor[
              0.26609474286190404`, 0.39701282450196873`, 0.9384650740028659],
              UndirectedEdge[170, 326] -> 
             RGBColor[
              0.39217993552288943`, 0.5141082814383957, 0.9462103365937862], 
             UndirectedEdge[239, 354] -> 
             RGBColor[
              0.3021441775416652, 0.43344512169287874`, 0.940571418461126], 
             UndirectedEdge[11, 221] -> 
             RGBColor[
              0.9226607888866434, 0.8373956409938654, 0.6248416927368453], 
             UndirectedEdge[47, 322] -> 
             RGBColor[
              0.47115402237552717`, 0.5810156228019311, 0.9516558567994469], 
             UndirectedEdge[155, 271] -> 
             RGBColor[
              0.305666751429035, 0.4386055145162801, 0.9407186413492236], 
             UndirectedEdge[106, 363] -> 
             RGBColor[
              0.905503655257033, 0.714845634359743, 0.589529206598464], 
             UndirectedEdge[245, 378] -> 
             RGBColor[
              0.2192126419789341, 0.3477367639770881, 0.9357952077134337], 
             UndirectedEdge[155, 326] -> 
             RGBColor[
              0.32196792775833594`, 0.4529058154258842, 0.9417507090817323], 
             UndirectedEdge[10, 39] -> 
             RGBColor[
              0.3175089705748625, 0.446135594734304, 0.9415730679165266], 
             UndirectedEdge[25, 382] -> 
             RGBColor[
              0.8737460186049575, 0.5043450922501913, 0.21576589198201723`], 
             UndirectedEdge[177, 383] -> 
             RGBColor[
              0.3010724134398118, 0.43255961086419054`, 0.9405015595789926], 
             UndirectedEdge[177, 296] -> 
             RGBColor[
              0.3117150207517371, 0.4437456659293011, 0.9411076403210801], 
             UndirectedEdge[103, 143] -> 
             RGBColor[
              0.48460520194471113`, 0.589510492500073, 0.9533849292372562], 
             UndirectedEdge[84, 317] -> 
             RGBColor[
              0.5847770387283635, 0.6478930395078799, 0.8692491754054186], 
             UndirectedEdge[50, 328] -> 
             RGBColor[
              0.38179240870061343`, 0.505088601337379, 0.9455546766979714], 
             UndirectedEdge[332, 385] -> 
             RGBColor[
              0.5513213263478973, 0.6466265153287621, 0.9578211808481198], 
             UndirectedEdge[242, 257] -> 
             RGBColor[
              0.8704770048155868, 0.4443768248986645, 0.21122005596083127`], 
             UndirectedEdge[214, 217] -> 
             RGBColor[
              0.903299381606431, 0.5819361276170735, 0.5409216460120444], 
             UndirectedEdge[51, 59] -> 
             RGBColor[
              0.3534707906164537, 0.48058036569863427`, 0.9437438241095009], 
             UndirectedEdge[66, 131] -> 
             RGBColor[
              0.9476245332536402, 0.8250818486193503, 0.3026198784181737], 
             UndirectedEdge[66, 98] -> 
             RGBColor[
              0.9751764945744315, 0.9279266287426179, 0.3580657982576656], 
             UndirectedEdge[70, 346] -> 
             RGBColor[
              0.3114210735342079, 0.4412987821643549, 0.9411691804276892], 
             UndirectedEdge[151, 253] -> 
             RGBColor[
              0.3287756481732377, 0.4591906745282696, 0.9421702714700763], 
             UndirectedEdge[384, 398] -> 
             RGBColor[
              0.8439266207114591, 0.8788704640005567, 0.9814905615415767], 
             UndirectedEdge[123, 218] -> 
             RGBColor[
              0.9421799541639146, 0.955737423109728, 0.959839004250153], 
             UndirectedEdge[169, 280] -> 
             RGBColor[
              0.229855838803546, 0.3589234386574095, 0.9364013220273968], 
             UndirectedEdge[71, 109] -> 
             RGBColor[
              0.932608231427341, 0.9459491066410988, 0.8675350166916449], 
             UndirectedEdge[166, 302] -> 
             RGBColor[
              0.9060230690090321, 0.580068176669682, 0.28821316860056356`], 
             UndirectedEdge[89, 163] -> 
             RGBColor[
              0.23177803755773202`, 0.36094379142249916`, 0.9365107884028094],
              UndirectedEdge[102, 340] -> 
             RGBColor[
              0.9065375818313084, 0.569215708650745, 0.3651390053950433], 
             UndirectedEdge[380, 390] -> 
             RGBColor[
              0.2658949696207651, 0.39680285015917666`, 0.9384536972123212], 
             UndirectedEdge[172, 387] -> 
             RGBColor[
              0.29749670616801155`, 0.43001827893615596`, 0.9402533693581072],
              UndirectedEdge[61, 298] -> 
             RGBColor[
              0.9083880182689977, 0.925110369261773, 0.7500707788698681], 
             UndirectedEdge[10, 216] -> 
             RGBColor[
              0.5105137254220357, 0.6107590812291837, 0.9554696590225349], 
             UndirectedEdge[209, 229] -> 
             RGBColor[
              0.24946457527559712`, 0.37953346395523513`, 0.937518010560954], 
             UndirectedEdge[39, 119] -> 
             RGBColor[
              0.2567952159774935, 0.3872384321223937, 0.9379354797042159], 
             UndirectedEdge[33, 261] -> 
             RGBColor[
              0.17919487812109408`, 0.3056755568897237, 0.9335162552627061], 
             UndirectedEdge[102, 213] -> 
             RGBColor[
              0.8651325745805382, 0.41702815829837886`, 0.20666661364992278`],
              UndirectedEdge[155, 335] -> 
             RGBColor[
              0.29253189959404885`, 0.42479995244000324`, 0.9399706309684931],
              UndirectedEdge[76, 317] -> 
             RGBColor[
              0.9187857495623798, 0.676116573374989, 0.49879235046594833`], 
             UndirectedEdge[19, 179] -> 
             RGBColor[
              0.2720136332383074, 0.4032339535668936, 0.9388021460535885], 
             UndirectedEdge[48, 83] -> 
             RGBColor[
              0.38916228198081126`, 0.5114945416119245, 0.9460180543784913], 
             UndirectedEdge[288, 355] -> 
             RGBColor[
              0.2379735788706035, 0.36745569816233453`, 0.9368636153150954], 
             UndirectedEdge[7, 192] -> 
             RGBColor[
              0.36694736915401993`, 0.4922531006753419, 0.9446025397770442], 
             UndirectedEdge[341, 393] -> 
             RGBColor[
              0.2222018557461406, 0.35087861717352153`, 0.9359654390153307], 
             UndirectedEdge[244, 270] -> 
             RGBColor[
              0.2548116613836774, 0.3851535904796679, 0.9378225192045042], 
             UndirectedEdge[121, 265] -> 
             RGBColor[
              0.5725454192775208, 0.6638571901035208, 0.9594920191899539], 
             UndirectedEdge[156, 363] -> 
             RGBColor[
              0.5242360164158433, 0.390684407006331, 0.5704454430561892], 
             UndirectedEdge[133, 280] -> 
             RGBColor[
              0.26813571605602704`, 0.3991580167341666, 0.938581304406922], 
             UndirectedEdge[44, 362] -> 
             RGBColor[
              0.35130778497678417`, 0.477709319929344, 0.9436425248244668], 
             UndirectedEdge[116, 147] -> 
             RGBColor[
              0.35047958711339033`, 0.47576981650030403`, 0.9436345020558807],
              UndirectedEdge[83, 196] -> 
             RGBColor[
              0.32540289254677246`, 0.4552688060149441, 0.9419919977610904], 
             UndirectedEdge[109, 233] -> 
             RGBColor[
              0.9057773412404262, 0.5635119739368787, 0.4559259820875775], 
             UndirectedEdge[19, 125] -> 
             RGBColor[
              0.27618503388558474`, 0.4076183601292589, 0.9390397011494167], 
             UndirectedEdge[26, 160] -> 
             RGBColor[
              0.6422952177337565, 0.39805166532506286`, 0.5630541845557195], 
             UndirectedEdge[224, 302] -> 
             RGBColor[
              0.981469271203516, 0.9491536419267372, 0.38251204717050646`], 
             UndirectedEdge[58, 60] -> 
             RGBColor[
              0.3281696676840872, 0.4577472453898289, 0.942165291884663], 
             UndirectedEdge[165, 332] -> 
             RGBColor[
              0.5299851907540822, 0.6293048792717479, 0.9561415220973347], 
             UndirectedEdge[43, 252] -> 
             RGBColor[
              0.2258841865651551, 0.3547489803375645, 0.9361751423079533], 
             UndirectedEdge[292, 304] -> 
             RGBColor[
              0.21505855653612305`, 0.3433705567924642, 0.9355586386928844], 
             UndirectedEdge[63, 257] -> 
             RGBColor[
              0.8905841112547781, 0.5233265159050291, 0.23139995091138454`], 
             UndirectedEdge[94, 355] -> 
             RGBColor[
              0.2455225673247446, 0.37539016366114936`, 0.937293519039831], 
             UndirectedEdge[223, 290] -> 
             RGBColor[
              0.4296004547734099, 0.5464997120753861, 0.9486003596365518], 
             UndirectedEdge[141, 150] -> 
             RGBColor[
              0.3153323622893313, 0.4440199894984804, 0.9414428101102743], 
             UndirectedEdge[131, 306] -> 
             RGBColor[
              0.9464211476308863, 0.8210225463454206, 0.2979449525140816], 
             UndirectedEdge[151, 182] -> 
             RGBColor[
              0.301964914813191, 0.43405917516616493`, 0.9405318273574531], 
             UndirectedEdge[87, 201] -> 
             RGBColor[
              0.2832825017728496, 0.4150782488842294, 0.9394438914458336], 
             UndirectedEdge[72, 379] -> 
             RGBColor[
              0.22434193474233927`, 0.3531279758873717, 0.9360873133482011], 
             UndirectedEdge[23, 378] -> 
             RGBColor[
              0.21097218176330165`, 0.339075517815104, 0.9353259256948219], 
             UndirectedEdge[116, 322] -> 
             RGBColor[
              0.46231873384021377`, 0.5733629399471565, 0.9510928800267155], 
             UndirectedEdge[90, 175] -> 
             RGBColor[
              0.44236897151936794`, 0.5377497638065076, 0.9524065385174674], 
             UndirectedEdge[348, 369] -> 
             RGBColor[
              0.2602045857942335, 0.3908218959663191, 0.9381296382715687], 
             UndirectedEdge[134, 243] -> 
             RGBColor[
              0.2613494095308073, 0.3920251782994754, 0.9381948342897516], 
             UndirectedEdge[211, 372] -> 
             RGBColor[
              0.257077351430105, 0.3875349743715093, 0.9379515469008601], 
             UndirectedEdge[73, 188] -> 
             RGBColor[
              0.2551009475473486, 0.3854576485794885, 0.9378389936235647], 
             UndirectedEdge[55, 228] -> 
             RGBColor[
              0.38569491533937006`, 0.508491282902023, 0.9457971168421706], 
             UndirectedEdge[260, 384] -> 
             RGBColor[
              0.7786909364224193, 0.827038544894287, 0.9785762933282055], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.6353748988917614, 0.714796015346257, 0.9644853457536787], 
             UndirectedEdge[153, 203] -> 
             RGBColor[
              0.3044141682214503, 0.43648600467859244`, 0.9406767090877951], 
             UndirectedEdge[65, 148] -> 
             RGBColor[
              0.5696101053080527, 0.6614741699887192, 0.9592609405218679], 
             UndirectedEdge[42, 366] -> 
             RGBColor[
              0.9167531541973288, 0.7967074998480634, 0.6163680259642358], 
             UndirectedEdge[48, 313] -> 
             RGBColor[
              0.35412562406909687`, 0.4787494368539953, 0.9438733561702934], 
             UndirectedEdge[166, 213] -> 
             RGBColor[
              0.8678686088454421, 0.43805851659629047`, 0.20928664315190354`],
              UndirectedEdge[11, 78] -> 
             RGBColor[
              0.8826533057204708, 0.5284492493821207, 0.22248879223389445`], 
             UndirectedEdge[228, 348] -> 
             RGBColor[
              0.31540619999020275`, 0.44337706024281187`, 0.9414733974605265],
              UndirectedEdge[199, 336] -> 
             RGBColor[
              0.2184046627263886, 0.34688752655381927`, 0.9357491944902996], 
             UndirectedEdge[249, 309] -> 
             RGBColor[
              0.2701798653173872, 0.40130654721440506`, 0.9386977156833087], 
             UndirectedEdge[190, 273] -> 
             RGBColor[
              0.2582701914773965, 0.38878872489163985`, 0.9380194773769047], 
             UndirectedEdge[298, 314] -> 
             RGBColor[
              0.8746210569271528, 0.9028631061103101, 0.9879033312647884], 
             UndirectedEdge[7, 385] -> 
             RGBColor[
              0.4824130197414953, 0.5889482597885108, 0.9528759593947184], 
             UndirectedEdge[27, 194] -> 
             RGBColor[
              0.3427358884343137, 0.47023486345331306`, 0.943098158625497], 
             UndirectedEdge[39, 128] -> 
             RGBColor[
              0.2996526087721707, 0.4306693116276521, 0.9404352763322198], 
             UndirectedEdge[116, 265] -> 
             RGBColor[
              0.5040580192630065, 0.6072487721867599, 0.9543787494712381], 
             UndirectedEdge[231, 313] -> 
             RGBColor[
              0.295746238547153, 0.4281784264805763, 0.9401536828166841], 
             UndirectedEdge[96, 284] -> 
             RGBColor[
              0.2654547891651977, 0.3963401925913225, 0.9384286295865651], 
             UndirectedEdge[279, 300] -> 
             RGBColor[
              0.9178232089422185, 0.7078044246386144, 0.2525247911559355], 
             UndirectedEdge[22, 190] -> 
             RGBColor[
              0.26671069132338054`, 0.3976602253883686, 0.938500151356533], 
             UndirectedEdge[24, 207] -> 
             RGBColor[
              0.9210044213449331, 0.723918476562367, 0.2552656037171254], 
             UndirectedEdge[315, 329] -> 
             RGBColor[
              0.2392065257950246, 0.3687516035532512, 0.9369338298184597], 
             UndirectedEdge[239, 335] -> 
             RGBColor[
              0.3025165492814234, 0.4338365080010965, 0.9405926244808307], 
             UndirectedEdge[142, 300] -> 
             RGBColor[
              0.8557903757137784, 0.38014617017527513`, 0.1991125486638397], 
             UndirectedEdge[13, 88] -> 
             RGBColor[
              0.9770469480723544, 0.9813851840644524, 0.8781922259657269], 
             UndirectedEdge[18, 302] -> 
             RGBColor[
              0.9662417999648014, 0.9637001584466507, 0.6913546401282936], 
             UndirectedEdge[148, 251] -> 
             RGBColor[
              0.723101933884062, 0.7833478892534567, 0.9732241552199159], 
             UndirectedEdge[90, 257] -> 
             RGBColor[
              0.7642064856318851, 0.4724371566214084, 0.5702968707589827], 
             UndirectedEdge[134, 348] -> 
             RGBColor[
              0.24864104476606846`, 0.3786678811748705, 0.9374711117167406], 
             UndirectedEdge[158, 322] -> 
             RGBColor[
              0.5057660137173806, 0.6096426602918618, 0.9542348997632368], 
             UndirectedEdge[40, 385] -> 
             RGBColor[
              0.4573665882056296, 0.5672542996623962, 0.9512800229249427], 
             UndirectedEdge[228, 385] -> 
             RGBColor[
              0.4716391113259436, 0.5796164418313421, 0.9521894554774726], 
             UndirectedEdge[175, 214] -> 
             RGBColor[
              0.5813526175939636, 0.6464089921975442, 0.9229266959429565], 
             UndirectedEdge[7, 41] -> 
             RGBColor[
              0.36511265513899505`, 0.490663963610935, 0.9444856334223808], 
             UndirectedEdge[176, 379] -> 
             RGBColor[
              0.2183904240990045, 0.34687256085365753`, 0.9357483836215341], 
             UndirectedEdge[259, 336] -> 
             RGBColor[
              0.21101362554134806`, 0.339119077853518, 0.9353282858566712], 
             UndirectedEdge[213, 340] -> 
             RGBColor[
              0.9523731210086097, 0.8369128200592044, 0.40569345010895497`], 
             UndirectedEdge[55, 165] -> 
             RGBColor[
              0.4681407137086776, 0.5777449578588358, 0.9516464016172608], 
             UndirectedEdge[108, 231] -> 
             RGBColor[
              0.3381266013166869, 0.4672842792810106, 0.9427663154046388], 
             UndirectedEdge[38, 230] -> 
             RGBColor[
              0.9673242221990019, 0.9014390702190636, 0.3275612028563362], 
             UndirectedEdge[39, 316] -> 
             RGBColor[
              0.26368578568270973`, 0.3944808577699287, 0.9383278874552436], 
             UndirectedEdge[85, 167] -> 
             RGBColor[
              0.2624284668147709, 0.39315933592110447`, 0.9382562850057511], 
             UndirectedEdge[28, 328] -> 
             RGBColor[
              0.2988631492240676, 0.4313905924329009, 0.9403335261361829], 
             UndirectedEdge[79, 120] -> 
             RGBColor[
              0.5785921359057922, 0.6687661870638313, 0.9599680388727843], 
             UndirectedEdge[130, 347] -> 
             RGBColor[
              0.34522783768479254`, 0.47078760076913406`, 0.9433157346482299],
              UndirectedEdge[77, 160] -> 
             RGBColor[
              0.8294213428991457, 0.5471802126352212, 0.5797239248650322], 
             UndirectedEdge[108, 179] -> 
             RGBColor[
              0.3186061180992342, 0.4467670137493473, 0.9416546527633719], 
             UndirectedEdge[318, 373] -> 
             RGBColor[
              0.2370696348066011, 0.3665055956377041, 0.9368121370379159], 
             UndirectedEdge[48, 331] -> 
             RGBColor[
              0.43876768248625253`, 0.5544602462898143, 0.9491788666343646], 
             UndirectedEdge[222, 312] -> 
             RGBColor[
              0.5339420376563727, 0.632517225840949, 0.9564530195798908], 
             UndirectedEdge[292, 353] -> 
             RGBColor[
              0.2106991637542155, 0.3387885585772128, 0.9353103777230984], 
             UndirectedEdge[175, 204] -> 
             RGBColor[
              0.17892957074057536`, 0.30539670201133906`, 0.9335011463998728],
              UndirectedEdge[198, 340] -> 
             RGBColor[
              0.9101338786876096, 0.9267923912389714, 0.7737391772833939], 
             UndirectedEdge[14, 207] -> 
             RGBColor[
              0.9671064480201461, 0.8947970383510977, 0.44882285376347564`], 
             UndirectedEdge[45, 271] -> 
             RGBColor[
              0.30114348847212347`, 0.43385127835713033`, 0.9404610482153953],
              UndirectedEdge[112, 183] -> 
             RGBColor[
              0.2939274002864909, 0.42440137973285763`, 0.9401184016257302], 
             UndirectedEdge[85, 139] -> 
             RGBColor[
              0.2262390695271757, 0.3551219848315275, 0.9361953523676381], 
             UndirectedEdge[45, 97] -> 
             RGBColor[
              0.36889177075057233`, 0.4927124766331557, 0.9447712800460943], 
             UndirectedEdge[130, 181] -> 
             RGBColor[
              0.48885894126290724`, 0.5947515646860737, 0.9532258537292853], 
             UndirectedEdge[63, 90] -> 
             RGBColor[
              0.8321834271804781, 0.8209894828739578, 0.632414864387591], 
             UndirectedEdge[114, 361] -> 
             RGBColor[
              0.342252200873233, 0.470863387125772, 0.9430289854912723], 
             UndirectedEdge[75, 209] -> 
             RGBColor[
              0.24810555583118551`, 0.37810504835234904`, 0.9374406164140838],
              UndirectedEdge[42, 276] -> 
             RGBColor[
              0.8488960037945177, 0.8827904862944987, 0.9853329329150746], 
             UndirectedEdge[205, 358] -> 
             RGBColor[
              0.9819225924478814, 0.9489876509677333, 0.5302516309431803], 
             UndirectedEdge[76, 358] -> 
             RGBColor[
              0.9077605542707283, 0.6337524810989443, 0.26250704350549825`], 
             UndirectedEdge[90, 142] -> 
             RGBColor[
              0.763694887526314, 0.46850478939826945`, 0.5698069638353204], 
             UndirectedEdge[152, 381] -> 
             RGBColor[
              0.588381597564026, 0.6508783727536576, 0.8485015174600479], 
             UndirectedEdge[86, 309] -> 
             RGBColor[
              0.28566340206902835`, 0.417580726053311, 0.9395794801954747], 
             UndirectedEdge[104, 358] -> 
             RGBColor[
              0.9512253799690775, 0.8406018507565884, 0.299039239235954], 
             UndirectedEdge[16, 369] -> 
             RGBColor[
              0.24965722981087085`, 0.3797359560868109, 0.9375289819517311], 
             UndirectedEdge[278, 337] -> 
             RGBColor[
              0.26857947792754067`, 0.39962443859725516`, 0.9386065759890179],
              UndirectedEdge[100, 350] -> 
             RGBColor[
              0.4046784181179114, 0.524933838870203, 0.9470067288527668], 
             UndirectedEdge[90, 202] -> 
             RGBColor[
              0.7810727137045386, 0.6020783764160916, 0.5864479898090358], 
             UndirectedEdge[126, 367] -> 
             RGBColor[
              0.21567822148491766`, 0.34402186394267437`, 0.935593927695006], 
             UndirectedEdge[278, 327] -> 
             RGBColor[
              0.28550387867049365`, 0.4165027145117478, 0.9396037276662406], 
             UndirectedEdge[10, 200] -> 
             RGBColor[
              0.31629276558560215`, 0.4448572861787412, 0.9415038068416022], 
             UndirectedEdge[149, 299] -> 
             RGBColor[
              0.21717366869177715`, 0.345593673773913, 0.9356790912011209], 
             UndirectedEdge[57, 284] -> 
             RGBColor[
              0.2586027566797, 0.38913827200511253`, 0.9380384164731898], 
             UndirectedEdge[125, 313] -> 
             RGBColor[
              0.2803971559769777, 0.4120455675112783, 0.9392795752712453], 
             UndirectedEdge[125, 196] -> 
             RGBColor[
              0.2879550374250095, 0.4199893801105207, 0.9397099854388271], 
             UndirectedEdge[21, 210] -> 
             RGBColor[
              0.30642042589023155`, 0.43901202359644165`, 0.9407756825511414],
              UndirectedEdge[186, 374] -> 
             RGBColor[
              0.2622856992899031, 0.3930092782004845, 0.9382481546064155], 
             UndirectedEdge[6, 74] -> 
             RGBColor[
              0.909010509687477, 0.9256078266033538, 0.7502192883025007], 
             UndirectedEdge[7, 312] -> 
             RGBColor[
              0.42618108450073044`, 0.5432966415402436, 0.9484491754681994], 
             UndirectedEdge[238, 299] -> 
             RGBColor[
              0.22167590498284873`, 0.3503258095740973, 0.9359354868974357], 
             UndirectedEdge[155, 239] -> 
             RGBColor[
              0.3145302695292589, 0.4464636896954298, 0.9412767880762385], 
             UndirectedEdge[108, 331] -> 
             RGBColor[
              0.40983077437371584`, 0.5293965508940257, 0.9473350324373369], 
             UndirectedEdge[55, 87] -> 
             RGBColor[
              0.34683568506465234`, 0.47311300029375225`, 0.9433840322411374],
              UndirectedEdge[186, 288] -> 
             RGBColor[
              0.2467468316416792, 0.3766769430810886, 0.9373632390815438], 
             UndirectedEdge[178, 371] -> 
             RGBColor[
              0.25801702472850174`, 0.38852263058685255`, 0.9380050599050818],
              UndirectedEdge[212, 238] -> 
             RGBColor[
              0.22006014114382055`, 0.3486275393339343, 0.9358434715371114], 
             UndirectedEdge[292, 329] -> 
             RGBColor[
              0.22307875219905648`, 0.35180029094398246`, 0.9360153769710722],
              UndirectedEdge[268, 338] -> 
             RGBColor[
              0.9058036870049794, 0.5621593672391498, 0.39196047146640556`], 
             UndirectedEdge[68, 309] -> 
             RGBColor[
              0.27375753584035556`, 0.40506690577145743`, 0.9389014587269024],
              UndirectedEdge[129, 309] -> 
             RGBColor[
              0.25423745991444247`, 0.38455006832902616`, 0.9377898192802863],
              UndirectedEdge[137, 330] -> 
             RGBColor[
              0.22316402213431713`, 0.35188991505236755`, 0.9360202329677398],
              UndirectedEdge[111, 400] -> 
             RGBColor[
              0.631844529693345, 0.5164916201579837, 0.581343351224306], 
             UndirectedEdge[62, 370] -> 
             RGBColor[
              0.5051424414592518, 0.5868980307983699, 0.9586362110924191], 
             UndirectedEdge[163, 280] -> 
             RGBColor[
              0.24199322930997053`, 0.37168060563466715`, 0.9370925284610774],
              UndirectedEdge[316, 383] -> 
             RGBColor[
              0.2672579164630078, 0.3982353937061947, 0.9385313150186878], 
             UndirectedEdge[307, 314] -> 
             RGBColor[
              0.9555259778682477, 0.9659228619523936, 0.9435306567958934], 
             UndirectedEdge[126, 259] -> 
             RGBColor[
              0.2115312190038542, 0.33966310139993294`, 0.93535776203865], 
             UndirectedEdge[44, 372] -> 
             RGBColor[
              0.27471702429732014`, 0.4060753889748091, 0.9389561001750906], 
             UndirectedEdge[202, 279] -> 
             RGBColor[
              0.9009946329017078, 0.6281412966873632, 0.2383554119012628], 
             UndirectedEdge[148, 312] -> 
             RGBColor[
              0.5434225996528742, 0.6402139731641597, 0.9571993641486982], 
             UndirectedEdge[109, 358] -> 
             RGBColor[
              0.9813365611926588, 0.9487453119833825, 0.5399636854424916], 
             UndirectedEdge[142, 275] -> 
             RGBColor[
              0.906842307128124, 0.5789554407018784, 0.47443924955803846`], 
             UndirectedEdge[296, 375] -> 
             RGBColor[
              0.2781834406546093, 0.40971881234981117`, 0.9391535074585348], 
             UndirectedEdge[92, 195] -> 
             RGBColor[
              0.26667927398787117`, 0.3976272037767742, 0.9384983621857534], 
             UndirectedEdge[178, 248] -> 
             RGBColor[
              0.230098166399185, 0.35917814032488304`, 0.9364151222254768], 
             UndirectedEdge[41, 222] -> 
             RGBColor[
              0.4728736082946373, 0.5798845479116403, 0.9524894775340721], 
             UndirectedEdge[154, 356] -> 
             RGBColor[
              0.4742682171286211, 0.5834424825573183, 0.951929030274608], 
             UndirectedEdge[70, 133] -> 
             RGBColor[
              0.28753417910083867`, 0.4195470313278583, 0.9396860181798696], 
             UndirectedEdge[7, 80] -> 
             RGBColor[
              0.36191069619973304`, 0.48789058771288196`, 0.9442816074301521],
              UndirectedEdge[152, 261] -> 
             RGBColor[
              0.18153226782756765`, 0.3081323016702944, 0.9336493661486316], 
             UndirectedEdge[95, 229] -> 
             RGBColor[
              0.2643373458997902, 0.3951656888693841, 0.9383649928457094], 
             UndirectedEdge[30, 204] -> 
             RGBColor[
              0.17892701604158556`, 0.30539401686072354`, 0.9335010009135446],
              UndirectedEdge[133, 223] -> 
             RGBColor[
              0.3756627076897743, 0.49871942307299955`, 0.945202383630783], 
             UndirectedEdge[298, 306] -> 
             RGBColor[
              0.8969031243202032, 0.8868893383314866, 0.6612189641553454], 
             UndirectedEdge[40, 96] -> 
             RGBColor[
              0.313111809733841, 0.4436046951713676, 0.9412461018545393], 
             UndirectedEdge[122, 146] -> 
             RGBColor[
              0.49070941162852855`, 0.5972227097318854, 0.9531038334374095], 
             UndirectedEdge[223, 267] -> 
             RGBColor[
              0.5126330687833186, 0.6152176449516955, 0.954775499492879], 
             UndirectedEdge[54, 322] -> 
             RGBColor[
              0.48020380618298864`, 0.5888540906805946, 0.9522325010212487], 
             UndirectedEdge[41, 154] -> 
             RGBColor[
              0.3854891726816393, 0.5083130789528232, 0.945784007101951], 
             UndirectedEdge[245, 353] -> 
             RGBColor[
              0.220139248365585, 0.34871068603969635`, 0.9358479765763623], 
             UndirectedEdge[26, 62] -> 
             RGBColor[
              0.31709055637755623`, 0.43703130766003234`, 0.9418781709758536],
              UndirectedEdge[217, 269] -> 
             RGBColor[
              0.9079422992480835, 0.582007875379239, 0.32768831635612294`], 
             UndirectedEdge[172, 347] -> 
             RGBColor[
              0.29073737323035515`, 0.422913791452218, 0.9398684353468445], 
             UndirectedEdge[63, 261] -> 
             RGBColor[
              0.5690047111878296, 0.5889104173173967, 0.6135243178829187], 
             UndirectedEdge[195, 369] -> 
             RGBColor[
              0.2515743275380513, 0.381750947349094, 0.9376381578312021], 
             UndirectedEdge[65, 180] -> 
             RGBColor[
              0.4408011041078431, 0.5545376633487222, 0.9497736818591127], 
             UndirectedEdge[49, 211] -> 
             RGBColor[
              0.25920679804656954`, 0.3897731577801271, 0.9380728157354339], 
             UndirectedEdge[285, 387] -> 
             RGBColor[
              0.2661419288540897, 0.3970624199715206, 0.9384677611753156], 
             UndirectedEdge[329, 388] -> 
             RGBColor[
              0.22925196747727483`, 0.358288731605845, 0.9363669324487132], 
             UndirectedEdge[38, 102] -> 
             RGBColor[
              0.8925441235088332, 0.5227994562196083, 0.24385895757801979`], 
             UndirectedEdge[92, 188] -> 
             RGBColor[
              0.27737488016395806`, 0.40886896400844064`, 0.9391074611347503],
              UndirectedEdge[114, 153] -> 
             RGBColor[
              0.32315432075329853`, 0.4543217632532496, 0.9418120854576224], 
             UndirectedEdge[326, 337] -> 
             RGBColor[
              0.312066783946898, 0.44249908551128714`, 0.9411868535891006], 
             UndirectedEdge[38, 221] -> 
             RGBColor[
              0.9438250637656209, 0.9183985790902189, 0.6570073333224926], 
             UndirectedEdge[350, 394] -> 
             RGBColor[
              0.3958053510234857, 0.5172484341263308, 0.9464413448636552], 
             UndirectedEdge[286, 349] -> 
             RGBColor[
              0.5858145101958898, 0.6731289759492968, 0.9614748008949803], 
             UndirectedEdge[246, 320] -> 
             RGBColor[
              0.5768484382747107, 0.6660576659405324, 0.9606094815615308], 
             UndirectedEdge[322, 362] -> 
             RGBColor[
              0.45653757665465905`, 0.5683555921624378, 0.9507245098029286], 
             UndirectedEdge[80, 348] -> 
             RGBColor[
              0.2986858104115632, 0.42889469918101, 0.9404079890218355], 
             UndirectedEdge[78, 230] -> 
             RGBColor[
              0.9053505911840212, 0.6146233921482407, 0.26060988945584945`], 
             UndirectedEdge[248, 329] -> 
             RGBColor[
              0.22567335718883677`, 0.3545273852956994, 0.9361631358868661], 
             UndirectedEdge[43, 330] -> 
             RGBColor[
              0.2261035990920075, 0.35497959681484403`, 0.9361876375267658], 
             UndirectedEdge[63, 217] -> 
             RGBColor[
              0.8906933611547283, 0.5241662585096577, 0.23150456873895697`], 
             UndirectedEdge[79, 136] -> 
             RGBColor[
              0.6046940354323059, 0.6899568849766287, 0.9620228760179198], 
             UndirectedEdge[159, 243] -> 
             RGBColor[
              0.3099032733211534, 0.44096065205359114`, 0.9410367126469893], 
             UndirectedEdge[1, 327] -> 
             RGBColor[
              0.3392875835527789, 0.4682955846087937, 0.9428400826971212], 
             UndirectedEdge[304, 353] -> 
             RGBColor[
              0.21473904123945592`, 0.3430347259572272, 0.9355404427694197], 
             UndirectedEdge[240, 329] -> 
             RGBColor[
              0.23717266786335917`, 0.3666138899130299, 0.9368180046180745], 
             UndirectedEdge[10, 311] -> 
             RGBColor[
              0.4406499577202704, 0.5542970021663628, 0.9497943740304772], 
             UndirectedEdge[353, 378] -> 
             RGBColor[
              0.20945304207089746`, 0.33747880567936756`, 0.9352394129367053],
              UndirectedEdge[167, 243] -> 
             RGBColor[
              0.28596070978623506`, 0.41789321531449325`, 0.9395964114301423],
              UndirectedEdge[169, 292] -> 
             RGBColor[
              0.21585857380573317`, 0.34421142566684904`, 0.9356041984928691],
              UndirectedEdge[211, 347] -> 
             RGBColor[
              0.27136364126610246`, 0.4025507707922349, 0.9387651299723484], 
             UndirectedEdge[224, 340] -> 
             RGBColor[
              0.9847198182906963, 0.959331532205712, 0.46205791346696695`], 
             UndirectedEdge[144, 233] -> 
             RGBColor[
              0.8479481693127158, 0.33804742930989184`, 0.1923147220140613], 
             UndirectedEdge[273, 394] -> 
             RGBColor[
              0.3171526741702776, 0.4460438307034582, 0.9415424253765902], 
             UndirectedEdge[93, 94] -> 
             RGBColor[
              0.2526810398598759, 0.3829141721689455, 0.9377011834606958], 
             UndirectedEdge[358, 366] -> 
             RGBColor[
              0.934928559139148, 0.7751416322731404, 0.28588252947049914`], 
             UndirectedEdge[245, 329] -> 
             RGBColor[
              0.232518836810426, 0.36172241840646596`, 0.936552975824336], 
             UndirectedEdge[44, 93] -> 
             RGBColor[
              0.2715973273730923, 0.4027963897072362, 0.9387784380504338], 
             UndirectedEdge[218, 314] -> 
             RGBColor[
              0.9179378774680893, 0.9374027630058823, 0.9920349282773651], 
             UndirectedEdge[133, 346] -> 
             RGBColor[
              0.32114511749891506`, 0.4515193689112592, 0.9417229503460453], 
             UndirectedEdge[143, 272] -> 
             RGBColor[
              0.635830587523557, 0.7151635871324875, 0.9645228442451073], 
             UndirectedEdge[272, 346] -> 
             RGBColor[
              0.4960244700071036, 0.5987224642834593, 0.954329185667129], 
             UndirectedEdge[61, 269] -> 
             RGBColor[
              0.9932024163292561, 0.9878689808064407, 0.5015031511422814], 
             UndirectedEdge[158, 362] -> 
             RGBColor[
              0.4538874638081069, 0.5662041111673836, 0.9505158832119648], 
             UndirectedEdge[294, 393] -> 
             RGBColor[
              0.21778977524310467`, 0.34624124082276975`, 0.9357141775577711],
              UndirectedEdge[17, 298] -> 
             RGBColor[
              0.6794733687434446, 0.7479201915203444, 0.969798835244192], 
             UndirectedEdge[83, 179] -> 
             RGBColor[
              0.3112624132414147, 0.4404062657068423, 0.9411867183836149], 
             UndirectedEdge[223, 398] -> 
             RGBColor[
              0.696746297429305, 0.7610076864937902, 0.9687930758283795], 
             UndirectedEdge[52, 272] -> 
             RGBColor[
              0.5168312067307885, 0.6167442138565202, 0.9556549725324873], 
             UndirectedEdge[52, 174] -> 
             RGBColor[
              0.5576254346896334, 0.6486129747855855, 0.95972095993169], 
             UndirectedEdge[63, 317] -> 
             RGBColor[
              0.9745940579826633, 0.9311354530743134, 0.5492576472683819], 
             UndirectedEdge[145, 280] -> 
             RGBColor[
              0.23851863392834902`, 0.36802858558651175`, 0.9368946553942974],
              UndirectedEdge[152, 317] -> 
             RGBColor[
              0.5871216146224013, 0.6503573374272111, 0.8693826955340949], 
             UndirectedEdge[102, 391] -> 
             RGBColor[
              0.8198439128231849, 0.15353458638285297`, 0.16663585937096298`],
              UndirectedEdge[168, 251] -> 
             RGBColor[
              0.7462331666341901, 0.8017011358685895, 0.9753362046447762], 
             UndirectedEdge[89, 245] -> 
             RGBColor[
              0.22424083690782642`, 0.3530217156533258, 0.9360815559760864], 
             UndirectedEdge[293, 330] -> 
             RGBColor[
              0.21800150715905772`, 0.3464637844910152, 0.9357262353771553], 
             UndirectedEdge[166, 247] -> 
             RGBColor[
              0.8658883217742317, 0.43020733825048896`, 0.20769325769109587`],
              UndirectedEdge[8, 182] -> 
             RGBColor[
              0.29920713316336395`, 0.4316705233112208, 0.9403561039493367], 
             UndirectedEdge[2, 215] -> 
             RGBColor[
              0.8188696957350476, 0.14604632693877936`, 0.16570294798714186`],
              UndirectedEdge[61, 107] -> 
             RGBColor[
              0.9162817916828967, 0.6453128669663495, 0.3511545314597267], 
             UndirectedEdge[192, 361] -> 
             RGBColor[
              0.35005813253929685`, 0.4776244927973833, 0.9435263725545195], 
             UndirectedEdge[71, 321] -> 
             RGBColor[
              0.8444532383444727, 0.878825868324395, 0.985021184343525], 
             UndirectedEdge[26, 389] -> 
             RGBColor[
              0.31710049015279534`, 0.4370417486876464, 0.9418787366896577], 
             UndirectedEdge[134, 263] -> 
             RGBColor[
              0.24820523859568883`, 0.3782098212580943, 0.9374462932000549], 
             UndirectedEdge[105, 282] -> 
             RGBColor[
              0.5321029414738284, 0.6299784125013272, 0.956625284939209], 
             UndirectedEdge[323, 340] -> 
             RGBColor[
              0.9119941865056833, 0.9282757501963927, 0.7739166151037982], 
             UndirectedEdge[311, 323] -> 
             RGBColor[
              0.6747921418079339, 0.7440706990607763, 0.9694867808520644], 
             UndirectedEdge[29, 365] -> 
             RGBColor[
              0.24833496351636752`, 0.37834617037476265`, 0.9374536808423768],
              UndirectedEdge[321, 384] -> 
             RGBColor[
              0.7831071512596195, 0.8304885254895837, 0.9790164603513036], 
             UndirectedEdge[115, 195] -> 
             RGBColor[
              0.2421504028292495, 0.3718458049688061, 0.937101479260483], 
             UndirectedEdge[162, 359] -> 
             RGBColor[
              0.24582605828944576`, 0.3757091519074889, 0.9373108024012962], 
             UndirectedEdge[106, 295] -> 
             RGBColor[
              0.5954410834145789, 0.6666014753537031, 0.9545919964182874], 
             UndirectedEdge[24, 242] -> 
             RGBColor[
              0.9102499321760205, 0.681280510728698, 0.24661228929151274`], 
             UndirectedEdge[109, 286] -> 
             RGBColor[
              0.8601731647723879, 0.8889489686867593, 0.8604250468482817], 
             UndirectedEdge[287, 367] -> 
             RGBColor[
              0.23976404440825078`, 0.3693375909644736, 0.936965579678708], 
             UndirectedEdge[74, 140] -> 
             RGBColor[
              0.7482992359076605, 0.8033342207586809, 0.9755370742792053], 
             UndirectedEdge[168, 394] -> 
             RGBColor[
              0.5145092206731405, 0.613750519132451, 0.9559228612077943], 
             UndirectedEdge[68, 249] -> 
             RGBColor[
              0.2731469520224531, 0.4044251434655919, 0.9388666868817508], 
             UndirectedEdge[389, 400] -> 
             RGBColor[
              0.2843495171102985, 0.40872323643536973`, 0.9397784081644269], 
             UndirectedEdge[267, 346] -> 
             RGBColor[
              0.4581154785924594, 0.5680175907899552, 0.9512960662081413], 
             UndirectedEdge[16, 392] -> 
             RGBColor[
              0.24490486142793333`, 0.37474091559878486`, 0.9372583416028217],
              UndirectedEdge[13, 191] -> 
             RGBColor[
              0.8213167457883995, 0.8607762667176537, 0.9574101949991654], 
             UndirectedEdge[312, 327] -> 
             RGBColor[
              0.39077465425622554`, 0.5126293712413812, 0.9461931090416965], 
             UndirectedEdge[260, 291] -> 
             RGBColor[
              0.7527228069990448, 0.8067520448236535, 0.9759880328732503], 
             UndirectedEdge[83, 344] -> 
             RGBColor[
              0.33675515918736176`, 0.4661021259068189, 0.9426787188558917], 
             UndirectedEdge[200, 288] -> 
             RGBColor[
              0.25784282293400623`, 0.38833953345580596`, 0.9379951393705938],
              UndirectedEdge[297, 332] -> 
             RGBColor[
              0.736930313911651, 0.7933926635631983, 0.9655671808709663], 
             UndirectedEdge[189, 241] -> 
             RGBColor[
              0.2957543458619668, 0.428186947782479, 0.9401541445162689], 
             UndirectedEdge[276, 358] -> 
             RGBColor[
              0.8670714087363368, 0.8612246187195758, 0.654847436421338], 
             UndirectedEdge[11, 102] -> 
             RGBColor[
              0.8713798486298555, 0.4417965181232547, 0.21169331699237254`], 
             UndirectedEdge[96, 243] -> 
             RGBColor[
              0.2876417202462759, 0.4196600638902152, 0.9396921424890095], 
             UndirectedEdge[171, 397] -> 
             RGBColor[
              0.26128106780929927`, 0.39195334681705507`, 0.9381909423298143],
              UndirectedEdge[314, 385] -> 
             RGBColor[
              0.7506165131369036, 0.8049365561291917, 0.9762521831517132], 
             UndirectedEdge[11, 213] -> 
             RGBColor[
              0.9172153878071567, 0.709493629531714, 0.2522477617062842], 
             UndirectedEdge[68, 129] -> 
             RGBColor[
              0.25720454661950837`, 0.38766866458021304`, 0.9379587904787283],
              UndirectedEdge[137, 277] -> 
             RGBColor[
              0.23968446191505444`, 0.36925394471830275`, 0.9369610475734522],
              UndirectedEdge[35, 327] -> 
             RGBColor[
              0.29981659218631795`, 0.43154628389532945`, 0.9404188155272046],
              UndirectedEdge[155, 183] -> 
             RGBColor[
              0.2817396246657633, 0.4134565872206231, 0.9393560268770672], 
             UndirectedEdge[63, 256] -> 
             RGBColor[
              0.5919347091448884, 0.6130112990161062, 0.6148301473446811], 
             UndirectedEdge[144, 358] -> 
             RGBColor[
              0.9235073892649484, 0.7232807673563957, 0.2763524253689754], 
             UndirectedEdge[192, 332] -> 
             RGBColor[
              0.43585567576042195`, 0.5499313562155932, 0.9495477612304457], 
             UndirectedEdge[149, 259] -> 
             RGBColor[
              0.21561966255991427`, 0.3439603147996455, 0.9355905928508573], 
             UndirectedEdge[146, 165] -> 
             RGBColor[
              0.5340400056803238, 0.6325967606962016, 0.956460731981605], 
             UndirectedEdge[164, 280] -> 
             RGBColor[
              0.2407758584059484, 0.37040107162876656`, 0.9370232009890322], 
             UndirectedEdge[65, 105] -> 
             RGBColor[
              0.46633814789011974`, 0.5766565671437895, 0.9514008797073982], 
             UndirectedEdge[73, 369] -> 
             RGBColor[
              0.2502849628040927, 0.38039574326325765`, 0.9375647304170474], 
             UndirectedEdge[187, 281] -> 
             RGBColor[
              0.7379639441479849, 0.795257108792612, 0.9745741950769791], 
             UndirectedEdge[53, 253] -> 
             RGBColor[
              0.31547986955209806`, 0.4458714425532633, 0.9413890964198188], 
             UndirectedEdge[132, 191] -> 
             RGBColor[
              0.7390378619070974, 0.7960612617083893, 0.9746240454395679], 
             UndirectedEdge[29, 273] -> 
             RGBColor[
              0.25793330326133057`, 0.388434634016608, 0.9380002920913812], 
             UndirectedEdge[138, 366] -> 
             RGBColor[
              0.8603116610551809, 0.39715139303420033`, 0.20274719460083632`],
              UndirectedEdge[229, 309] -> 
             RGBColor[
              0.25884330525935606`, 0.3893911038139919, 0.9380521153589414], 
             UndirectedEdge[274, 287] -> 
             RGBColor[
              0.2454706833388167, 0.37533563030230443`, 0.937290564323588], 
             UndirectedEdge[251, 312] -> 
             RGBColor[
              0.6426365090387243, 0.7180224324379316, 0.9668896222215277], 
             UndirectedEdge[339, 360] -> 
             RGBColor[
              0.3380761124684098, 0.46724626924582036`, 0.942762888830887], 
             UndirectedEdge[150, 365] -> 
             RGBColor[
              0.26342074735738313`, 0.39420228568561005`, 0.9383127939147053],
              UndirectedEdge[61, 300] -> 
             RGBColor[
              0.9416713408004723, 0.7907793854302443, 0.3735219082012329], 
             UndirectedEdge[62, 389] -> 
             RGBColor[
              0.17907819285502502`, 0.305552913276812, 0.9335096102094239], 
             UndirectedEdge[374, 399] -> 
             RGBColor[
              0.255491371590293, 0.38586800900293716`, 0.9378612276952298], 
             UndirectedEdge[27, 51] -> 
             RGBColor[
              0.33517005330446453`, 0.4636817173337682, 0.9426160703012283], 
             UndirectedEdge[58, 159] -> 
             RGBColor[
              0.31512279365295653`, 0.44644669885901933`, 0.9413339566082971],
              UndirectedEdge[57, 153] -> 
             RGBColor[
              0.2953190920495516, 0.42692650296079127`, 0.9401587579547649], 
             UndirectedEdge[84, 264] -> 
             RGBColor[
              0.18447901438019912`, 0.31122951913163255`, 0.9338171790054831],
              UndirectedEdge[159, 201] -> 
             RGBColor[
              0.30393044061377905`, 0.43468282617867443`, 0.9406965686603185],
              UndirectedEdge[80, 87] -> 
             RGBColor[
              0.3122775575094636, 0.4431804871474425, 0.9411820189118731], 
             UndirectedEdge[39, 288] -> 
             RGBColor[
              0.2590590279232666, 0.38961784201136873`, 0.9380644004455181], 
             UndirectedEdge[91, 365] -> 
             RGBColor[
              0.259430965008946, 0.3900087714705911, 0.9380855817123159], 
             UndirectedEdge[5, 384] -> 
             RGBColor[
              0.7949354326614759, 0.8399023141409853, 0.9801493658443617], 
             UndirectedEdge[156, 381] -> 
             RGBColor[
              0.5895532840978516, 0.6521098895899253, 0.8485682432747944], 
             UndirectedEdge[2, 197] -> 
             RGBColor[
              0.9036013141673853, 0.5662229928500411, 0.5006917858198119], 
             UndirectedEdge[238, 293] -> 
             RGBColor[
              0.22022708573500543`, 0.3488030086841681, 0.935852978784607], 
             UndirectedEdge[85, 325] -> 
             RGBColor[
              0.22643759197523877`, 0.355330644511492, 0.9362066579273677], 
             UndirectedEdge[146, 332] -> 
             RGBColor[
              0.53127642233297, 0.6303531592368088, 0.9562431725771618], 
             UndirectedEdge[197, 204] -> 
             RGBColor[
              0.5838392169462935, 0.6475052215433456, 0.8847911904815791], 
             UndirectedEdge[20, 130] -> 
             RGBColor[
              0.4090322853711047, 0.5287049398531881, 0.9472841534241666], 
             UndirectedEdge[167, 348] -> 
             RGBColor[
              0.2732523450214962, 0.4045359181898883, 0.9388726888571313], 
             UndirectedEdge[83, 237] -> 
             RGBColor[
              0.4656503502316991, 0.5743478756221865, 0.9518303486289299], 
             UndirectedEdge[178, 334] -> 
             RGBColor[
              0.25269374017822266`, 0.3829275210087747, 0.9377019067250372], 
             UndirectedEdge[178, 388] -> 
             RGBColor[
              0.23367677668762307`, 0.36293948663502873`, 0.9366189187873238],
              UndirectedEdge[115, 184] -> 
             RGBColor[
              0.22818450918176583`, 0.35716676525650004`, 0.936306142277947], 
             UndirectedEdge[165, 385] -> 
             RGBColor[
              0.5540849096952511, 0.648870116788155, 0.9580387402525627], 
             UndirectedEdge[202, 257] -> 
             RGBColor[
              0.8394733977788387, 0.30441540944716294`, 0.18543307633282935`],
              UndirectedEdge[35, 57] -> 
             RGBColor[
              0.2771242370211076, 0.4086055221736117, 0.9390931873785582], 
             UndirectedEdge[115, 206] -> 
             RGBColor[
              0.23508408472910247`, 0.364418656615107, 0.9366990628983605], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.34476855469957235`, 0.4730429263345264, 0.9431893253319623], 
             UndirectedEdge[61, 98] -> 
             RGBColor[
              0.985458002900472, 0.9620883573989745, 0.44224268706809605`], 
             UndirectedEdge[33, 173] -> 
             RGBColor[
              0.20265449886636056`, 0.33033310571886365`, 0.9348522459587503],
              UndirectedEdge[6, 185] -> 
             RGBColor[
              0.9085190133388343, 0.5856402039031354, 0.34380931507742224`], 
             UndirectedEdge[300, 363] -> 
             RGBColor[
              0.8762546358068509, 0.5309830273105506, 0.21845617365184725`], 
             UndirectedEdge[34, 270] -> 
             RGBColor[
              0.28093807902462586`, 0.41228653639826196`, 0.9393223741835017],
              UndirectedEdge[162, 179] -> 
             RGBColor[
              0.25786357675267113`, 0.38836134703509095`, 0.9379963212698641],
              UndirectedEdge[11, 250] -> 
             RGBColor[
              0.9558449394073578, 0.8618308276345842, 0.5510217386219683], 
             UndirectedEdge[66, 314] -> 
             RGBColor[
              0.9492974340005453, 0.9317668939083206, 0.6707765260947278], 
             UndirectedEdge[153, 327] -> 
             RGBColor[
              0.31801144721476193`, 0.44986726468250904`, 0.9414843861034113],
              UndirectedEdge[153, 392] -> 
             RGBColor[
              0.28268998646480836`, 0.4136525122596839, 0.9394395490748012], 
             UndirectedEdge[110, 369] -> 
             RGBColor[
              0.2565159464057226, 0.38694490209574905`, 0.9379195757152459], 
             UndirectedEdge[321, 398] -> 
             RGBColor[
              0.8786059330927678, 0.9059622064053712, 0.9849470713031456], 
             UndirectedEdge[188, 278] -> 
             RGBColor[
              0.2597507710467335, 0.39034490789317966`, 0.9381037941930572], 
             UndirectedEdge[213, 289] -> 
             RGBColor[
              0.9043607109741805, 0.6566643735845665, 0.24180812561664938`], 
             UndirectedEdge[236, 263] -> 
             RGBColor[
              0.2563029052327246, 0.3867209823153376, 0.9379074433356098], 
             UndirectedEdge[93, 383] -> 
             RGBColor[
              0.2627372188358315, 0.39348385387124796`, 0.9382738679765928], 
             UndirectedEdge[56, 286] -> 
             RGBColor[
              0.5885924555434128, 0.6755350925857282, 0.9616518091160838], 
             UndirectedEdge[25, 144] -> 
             RGBColor[
              0.8635746104404736, 0.45815910336800225`, 0.20727861968554306`],
              UndirectedEdge[143, 331] -> 
             RGBColor[
              0.5383683584932644, 0.6360774364876114, 0.9568106700316372], 
             UndirectedEdge[76, 257] -> 
             RGBColor[
              0.8347758028344946, 0.2683076362057045, 0.1809346541089509], 
             UndirectedEdge[91, 189] -> 
             RGBColor[
              0.28158397795101814`, 0.4132929926548542, 0.9393471630269211], 
             UndirectedEdge[133, 145] -> 
             RGBColor[
              0.26764114093786784`, 0.3986381869271076, 0.9385531390856012], 
             UndirectedEdge[207, 230] -> 
             RGBColor[
              0.9543565255231943, 0.8529328333505086, 0.30199072149137773`], 
             UndirectedEdge[238, 336] -> 
             RGBColor[
              0.22011483416770328`, 0.34868502516977307`, 0.9358465862239105],
              UndirectedEdge[123, 306] -> 
             RGBColor[
              0.9723361250736168, 0.9460422517382365, 0.6339056761634236], 
             UndirectedEdge[272, 338] -> 
             RGBColor[
              0.8206526510459409, 0.8571827716487312, 0.7925776008366022], 
             UndirectedEdge[11, 289] -> 
             RGBColor[
              0.9106079850234978, 0.6814327334094423, 0.24683482895909917`], 
             UndirectedEdge[215, 300] -> 
             RGBColor[
              0.8546424874802127, 0.37132299820425807`, 0.1980133295950229], 
             UndirectedEdge[224, 289] -> 
             RGBColor[
              0.9367074082562672, 0.779083085731074, 0.29817258897466137`], 
             UndirectedEdge[65, 161] -> 
             RGBColor[
              0.4733844161827434, 0.5827596905831183, 0.9518498616922337], 
             UndirectedEdge[14, 247] -> 
             RGBColor[
              0.9506823086964485, 0.8296807989526216, 0.43560760573952945`], 
             UndirectedEdge[150, 226] -> 
             RGBColor[
              0.2546174021107136, 0.38494941166703367`, 0.9378114564262897], 
             UndirectedEdge[15, 180] -> 
             RGBColor[
              0.33506546922916314`, 0.4641869420312098, 0.9425875907675709], 
             UndirectedEdge[7, 114] -> 
             RGBColor[
              0.359141437487956, 0.48549199500373064`, 0.9441051527137969], 
             UndirectedEdge[108, 313] -> 
             RGBColor[
              0.3251887159565602, 0.4536857414582067, 0.9420295219732657], 
             UndirectedEdge[227, 315] -> 
             RGBColor[
              0.2390981188616284, 0.3686376609928552, 0.9369276562039764], 
             UndirectedEdge[174, 384] -> 
             RGBColor[
              0.7385166114389616, 0.7956540568810313, 0.9745720920642666], 
             UndirectedEdge[104, 138] -> 
             RGBColor[
              0.8766084818851104, 0.4626116115176483, 0.21590390436629117`], 
             UndirectedEdge[313, 344] -> 
             RGBColor[
              0.30171850127564737`, 0.43335702114888963`, 0.940534020647694], 
             UndirectedEdge[255, 374] -> 
             RGBColor[
              0.2682893522658295, 0.3993194981317673, 0.938590053761786], 
             UndirectedEdge[87, 167] -> 
             RGBColor[
              0.28684409211939654`, 0.41882170615632086`, 0.9396467187471687],
              UndirectedEdge[114, 312] -> 
             RGBColor[
              0.3959175277947622, 0.5170838698121216, 0.9465208083959076], 
             UndirectedEdge[50, 265] -> 
             RGBColor[
              0.5230211648142513, 0.6236511692879999, 0.9555932884652836], 
             UndirectedEdge[310, 345] -> 
             RGBColor[
              0.19226277251810686`, 0.3194107424533439, 0.9342604525163987], 
             UndirectedEdge[315, 334] -> 
             RGBColor[
              0.25233663141566864`, 0.38255217705732714`, 0.9376815699093048],
              UndirectedEdge[102, 302] -> 
             RGBColor[
              0.9032870347441282, 0.5590378183717704, 0.2855931390985828], 
             UndirectedEdge[172, 211] -> 
             RGBColor[
              0.2820509294380053, 0.413783788274112, 0.9393737552233123], 
             UndirectedEdge[264, 381] -> 
             RGBColor[
              0.5915890217554157, 0.6542495789412477, 0.8486841755227887], 
             UndirectedEdge[270, 397] -> 
             RGBColor[
              0.2494683482405557, 0.3795374295806264, 0.9375182254257268], 
             UndirectedEdge[48, 290] -> 
             RGBColor[
              0.4152883060919923, 0.5341235905648768, 0.9476827815325197], 
             UndirectedEdge[224, 323] -> 
             RGBColor[
              0.9029358765369997, 0.8985069119905342, 0.6718086867166897], 
             UndirectedEdge[10, 339] -> 
             RGBColor[
              0.3638431893323356, 0.48956441613441326`, 0.9444047441837249], 
             UndirectedEdge[254, 320] -> 
             RGBColor[
              0.5897027051719504, 0.6767516973442059, 0.9615500313265857], 
             UndirectedEdge[92, 392] -> 
             RGBColor[
              0.26780652703776464`, 0.39881201820418366`, 0.9385625575793235],
              UndirectedEdge[166, 224] -> 
             RGBColor[
              0.9002153061275288, 0.5604772287427979, 0.2656511065099155], 
             UndirectedEdge[108, 344] -> 
             RGBColor[
              0.3440988640451813, 0.47246287394932385`, 0.9431466532356487], 
             UndirectedEdge[180, 271] -> 
             RGBColor[
              0.3365289525569892, 0.46572515579895724`, 0.942670933978061], 
             UndirectedEdge[104, 207] -> 
             RGBColor[
              0.9368649528111581, 0.7873976069432023, 0.2680582629430743], 
             UndirectedEdge[45, 266] -> 
             RGBColor[
              0.2752485126978604, 0.4066340169820878, 0.9389863676532347], 
             UndirectedEdge[59, 373] -> 
             RGBColor[
              0.2921699969184407, 0.4220829828981863, 0.9400355750383738], 
             UndirectedEdge[107, 352] -> 
             RGBColor[
              0.9166859076311894, 0.6461772301173578, 0.39514005851685197`], 
             UndirectedEdge[99, 338] -> 
             RGBColor[
              0.9862079875593082, 0.9866999578573392, 0.7708056942036536], 
             UndirectedEdge[186, 341] -> 
             RGBColor[
              0.23502569235584353`, 0.3643572825285215, 0.9366957375390872], 
             UndirectedEdge[90, 156] -> 
             RGBColor[
              0.4458826703540418, 0.5414428840631231, 0.9526066384680504], 
             UndirectedEdge[34, 151] -> 
             RGBColor[
              0.31406226415390115`, 0.44644668080690353`, 0.9412327476508988],
              UndirectedEdge[174, 260] -> 
             RGBColor[
              0.7687797089830702, 0.819295818690549, 0.9775884348027377], 
             UndirectedEdge[13, 216] -> 
             RGBColor[
              0.8114408517281416, 0.8530611432182054, 0.956425858174716], 
             UndirectedEdge[9, 217] -> 
             RGBColor[
              0.8242465537218799, 0.18737521357976708`, 0.17085183326762515`],
              UndirectedEdge[87, 159] -> 
             RGBColor[
              0.3107866556543149, 0.4418891428954188, 0.9410870199640158], 
             UndirectedEdge[184, 305] -> 
             RGBColor[
              0.21033276310750965`, 0.33840344826638225`, 0.9352895117483098],
              UndirectedEdge[12, 259] -> 
             RGBColor[
              0.2147288372822968, 0.3430240009512847, 0.9355398616691548], 
             UndirectedEdge[27, 287] -> 
             RGBColor[
              0.27881505582512084`, 0.4103826799407336, 0.9391894770081045], 
             UndirectedEdge[188, 284] -> 
             RGBColor[
              0.25554200422115014`, 0.38592122710826227`, 0.9378641111486529],
              UndirectedEdge[118, 126] -> 
             RGBColor[
              0.20905168496127685`, 0.33705695390964574`, 0.935216556243067], 
             UndirectedEdge[209, 304] -> 
             RGBColor[
              0.23556571159456763`, 0.3649248769876179, 0.9367264908358456], 
             UndirectedEdge[48, 108] -> 
             RGBColor[
              0.3965059868386308, 0.5178552896544295, 0.9464859887582483], 
             UndirectedEdge[136, 376] -> 
             RGBColor[
              0.5284877060748537, 0.6276839131134415, 0.9561356038127271], 
             UndirectedEdge[48, 344] -> 
             RGBColor[
              0.373035772157718, 0.49752656934511247`, 0.9449904874326764], 
             UndirectedEdge[13, 198] -> 
             RGBColor[
              0.8951348791523555, 0.9184961361184019, 0.9647537428637106], 
             UndirectedEdge[286, 320] -> 
             RGBColor[
              0.7180719499645429, 0.7796825319520332, 0.9725343592747207], 
             UndirectedEdge[176, 368] -> 
             RGBColor[
              0.2143024966118115, 0.34257588987504495`, 0.9355155821986852], 
             UndirectedEdge[248, 388] -> 
             RGBColor[
              0.21978649931888122`, 0.34833992442602935`, 0.935827888039998], 
             UndirectedEdge[57, 188] -> 
             RGBColor[
              0.270146670915944, 0.40127165779384166`, 0.9386958253112532], 
             UndirectedEdge[39, 225] -> 
             RGBColor[
              0.26510008482719366`, 0.3959673758425263, 0.9384084296992539], 
             UndirectedEdge[355, 379] -> 
             RGBColor[
              0.2259392634266556, 0.3548068696110762, 0.9361782788537368], 
             UndirectedEdge[85, 348] -> 
             RGBColor[
              0.2521313444108594, 0.3823364073993248, 0.9376698791180758], 
             UndirectedEdge[118, 336] -> 
             RGBColor[
              0.20853409149877072`, 0.3365129303632308, 0.9351870800610882], 
             UndirectedEdge[195, 392] -> 
             RGBColor[
              0.24682195915511385`, 0.3767559068610679, 0.9373675174822926], 
             UndirectedEdge[193, 281] -> 
             RGBColor[
              0.7271668299156635, 0.7866477829836171, 0.9735443566828026], 
             UndirectedEdge[154, 312] -> 
             RGBColor[
              0.4465576020433747, 0.5609457568821319, 0.9497475491477698], 
             UndirectedEdge[53, 171] -> 
             RGBColor[
              0.28122827358250124`, 0.41291912481058346`, 0.9393269061893516],
              UndirectedEdge[115, 188] -> 
             RGBColor[
              0.25284600900533644`, 0.38308756520047255`, 0.9377105782094798],
              UndirectedEdge[319, 329] -> 
             RGBColor[
              0.2383612491721791, 0.3678631642290072, 0.9368856925652633], 
             UndirectedEdge[231, 359] -> 
             RGBColor[
              0.2771261222266016, 0.4086075036441148, 0.9390932947382222], 
             UndirectedEdge[288, 399] -> 
             RGBColor[
              0.23995250394206913`, 0.3695356738835413, 0.9369763121703581], 
             UndirectedEdge[140, 220] -> 
             RGBColor[
              0.5736797551483913, 0.6643251817234797, 0.9598909775899255], 
             UndirectedEdge[9, 215] -> 
             RGBColor[
              0.822477817482793, 0.1737799317809825, 0.1691580894475736], 
             UndirectedEdge[309, 329] -> 
             RGBColor[
              0.25296463724126, 0.3832122509978928, 0.9377173339120208], 
             UndirectedEdge[9, 61] -> 
             RGBColor[
              0.9095066708030527, 0.5932363190069687, 0.34466666805378354`], 
             UndirectedEdge[21, 82] -> 
             RGBColor[
              0.34606714839588365`, 0.4741677029250543, 0.94327207057399], 
             UndirectedEdge[154, 361] -> 
             RGBColor[
              0.39289227512184555`, 0.5147252741957822, 0.9462557262431346], 
             UndirectedEdge[160, 213] -> 
             RGBColor[
              0.8702228477750129, 0.45615422864304855`, 0.21154106500959308`],
              UndirectedEdge[331, 342] -> 
             RGBColor[
              0.5277253347918338, 0.6274369503840362, 0.9559728122191802], 
             UndirectedEdge[122, 159] -> 
             RGBColor[
              0.3887610902465449, 0.5111470494961861, 0.9459924907959437], 
             UndirectedEdge[258, 278] -> 
             RGBColor[
              0.25267444257649463`, 0.38290723800581994`, 0.937700807755167], 
             UndirectedEdge[37, 201] -> 
             RGBColor[
              0.26311290635419504`, 0.3938787252730125, 0.9382952628249838], 
             UndirectedEdge[61, 314] -> 
             RGBColor[
              0.9595789423265859, 0.965928622564677, 0.7549534149051582], 
             UndirectedEdge[297, 314] -> 
             RGBColor[
              0.9362255007006572, 0.9517027043636277, 0.9839981831745597], 
             UndirectedEdge[84, 175] -> 
             RGBColor[
              0.1789295778879611, 0.3053967095236947, 0.9335011468069058], 
             UndirectedEdge[72, 374] -> 
             RGBColor[
              0.25191511783451104`, 0.3821091395580259, 0.9376575653344313], 
             UndirectedEdge[168, 180] -> 
             RGBColor[
              0.5182102560481305, 0.6169561699548207, 0.9561586879091916], 
             UndirectedEdge[36, 60] -> 
             RGBColor[
              0.4386028192989782, 0.5525156396146701, 0.9496662072988238], 
             UndirectedEdge[347, 387] -> 
             RGBColor[
              0.2868094179961087, 0.41878526145427897`, 0.9396447441071433], 
             UndirectedEdge[140, 141] -> 
             RGBColor[
              0.5159944713875729, 0.6149616035084853, 0.9560493981699523], 
             UndirectedEdge[233, 382] -> 
             RGBColor[
              0.8581195774771997, 0.3842334181920808, 0.20080199431053547`], 
             UndirectedEdge[21, 122] -> 
             RGBColor[
              0.37950236392749337`, 0.5031276061157393, 0.9454025329420639], 
             UndirectedEdge[202, 268] -> 
             RGBColor[
              0.836829312925746, 0.2840918146209231, 0.18290109769144122`], 
             UndirectedEdge[196, 344] -> 
             RGBColor[
              0.3092763827236792, 0.441300833748132, 0.9409644308152758], 
             UndirectedEdge[109, 343] -> 
             RGBColor[
              0.8581485111146978, 0.8873672938614341, 0.8602232482931473], 
             UndirectedEdge[52, 117] -> 
             RGBColor[
              0.36808130040816744`, 0.4932352549346425, 0.9446747928738624], 
             UndirectedEdge[51, 194] -> 
             RGBColor[
              0.38048922371828053`, 0.5039823744655038, 0.945465414775287], 
             UndirectedEdge[223, 342] -> 
             RGBColor[
              0.5287126959381665, 0.6282718106549494, 0.9560413466441238], 
             UndirectedEdge[241, 374] -> 
             RGBColor[
              0.2835328374534444, 0.4153413675567334, 0.939458147692505], 
             UndirectedEdge[76, 109] -> 
             RGBColor[
              0.9205204428847344, 0.6768339136433675, 0.4700439928721189], 
             UndirectedEdge[90, 381] -> 
             RGBColor[
              0.849476415301395, 0.8807671291171392, 0.8672733890419332], 
             UndirectedEdge[75, 227] -> 
             RGBColor[
              0.2395500669875186, 0.36911268712833206`, 0.9369533939811485], 
             UndirectedEdge[209, 329] -> 
             RGBColor[
              0.24358590725750107`, 0.37335461113913604`, 0.9371832291140334],
              UndirectedEdge[24, 358] -> 
             RGBColor[
              0.9353648485028525, 0.777122720375753, 0.28624658001000514`], 
             UndirectedEdge[208, 369] -> 
             RGBColor[
              0.24527033350139205`, 0.37512504992025775`, 0.9372791546967377],
              UndirectedEdge[62, 400] -> 
             RGBColor[
              0.2843395833350594, 0.4087127954077557, 0.9397778424506229], 
             UndirectedEdge[127, 325] -> 
             RGBColor[
              0.21103171786447747`, 0.3391380940322466, 0.9353293161877081], 
             UndirectedEdge[43, 277] -> 
             RGBColor[
              0.2426240388727448, 0.37234362648077923`, 0.9371284521324783], 
             UndirectedEdge[70, 227] -> 
             RGBColor[
              0.25636607330828476`, 0.3867873759678386, 0.9379110406640643], 
             UndirectedEdge[25, 366] -> 
             RGBColor[
              0.8749957803146731, 0.510019968284747, 0.21680872378706678`], 
             UndirectedEdge[20, 387] -> 
             RGBColor[
              0.3506138656824209, 0.476702600538333, 0.94361316288308], 
             UndirectedEdge[328, 387] -> 
             RGBColor[
              0.30150296805800375`, 0.4341652094015489, 0.9404838599135137], 
             UndirectedEdge[249, 386] -> 
             RGBColor[
              0.3044662110801129, 0.4345129066433197, 0.9407539204836926], 
             UndirectedEdge[110, 243] -> 
             RGBColor[
              0.2719749479938126, 0.4031932929221435, 0.9387999429861442], 
             UndirectedEdge[47, 121] -> 
             RGBColor[
              0.4935440296663224, 0.5991928393789325, 0.9534184801906773], 
             UndirectedEdge[31, 156] -> 
             RGBColor[
              0.18458847622123073`, 0.3113445704668384, 0.9338234126953957], 
             UndirectedEdge[98, 283] -> 
             RGBColor[
              0.9432427006605664, 0.8062936865407971, 0.3064669136008217], 
             UndirectedEdge[38, 358] -> 
             RGBColor[
              0.9671839420965409, 0.9009658724941282, 0.3270162411479497], 
             UndirectedEdge[126, 199] -> 
             RGBColor[
              0.21892225618889471`, 0.3474315501002342, 0.9357786706722784], 
             UndirectedEdge[39, 200] -> 
             RGBColor[
              0.27187585958380484`, 0.4030891447206572, 0.9387943000477824], 
             UndirectedEdge[227, 304] -> 
             RGBColor[
              0.22701022275090071`, 0.35593251576360085`, 0.9362392684029103],
              UndirectedEdge[242, 333] -> 
             RGBColor[
              0.5569536477379948, 0.5184281382754727, 0.5938032026627618], 
             UndirectedEdge[30, 333] -> 
             RGBColor[
              0.1872437438170861, 0.31413542506377157`, 0.9339746262568631], 
             UndirectedEdge[85, 96] -> 
             RGBColor[
              0.2641094772748117, 0.3949261844968264, 0.9383520160646184], 
             UndirectedEdge[39, 94] -> 
             RGBColor[
              0.2666080163774077, 0.39755230751018356`, 0.9384943041702538], 
             UndirectedEdge[63, 138] -> 
             RGBColor[
              0.8889519646070447, 0.5107811215593289, 0.22983700543826907`], 
             UndirectedEdge[119, 324] -> 
             RGBColor[
              0.26022801088632164`, 0.3908465172233403, 0.9381309722959088], 
             UndirectedEdge[18, 224] -> 
             RGBColor[
              0.960434037083298, 0.9441092105197667, 0.6687925780376456], 
             UndirectedEdge[84, 204] -> 
             RGBColor[
              0.17892700714738574`, 0.30539400751235557`, 0.933501000407033], 
             UndirectedEdge[241, 288] -> 
             RGBColor[
              0.2679939698052205, 0.39900903243733754`, 0.9385732321676334], 
             UndirectedEdge[91, 266] -> 
             RGBColor[
              0.25880957199136756`, 0.38935564801052325`, 0.9380501942992334],
              UndirectedEdge[201, 263] -> 
             RGBColor[
              0.26925494850456955`, 0.4003344010010207, 0.9386450430391104], 
             UndirectedEdge[29, 266] -> 
             RGBColor[
              0.2477135704987891, 0.37769304691469485`, 0.9374182934292943], 
             UndirectedEdge[161, 326] -> 
             RGBColor[
              0.3854134409611904, 0.5082474839429573, 0.9457791815436909], 
             UndirectedEdge[174, 235] -> 
             RGBColor[
              0.7343495307888845, 0.7923987018062052, 0.9741567564086497], 
             UndirectedEdge[207, 233] -> 
             RGBColor[
              0.8786570254685007, 0.4672262975790694, 0.21740805642807715`], 
             UndirectedEdge[199, 212] -> 
             RGBColor[
              0.21834996970250586`, 0.3468300407179805, 0.9357460798035004], 
             UndirectedEdge[127, 184] -> 
             RGBColor[
              0.21412931839643223`, 0.34239386859054827`, 0.9355057199555137],
              UndirectedEdge[261, 381] -> 
             RGBColor[
              0.5862976993087463, 0.6486880635605781, 0.8483828425372609], 
             UndirectedEdge[221, 230] -> 
             RGBColor[
              0.9453580743501937, 0.9235697837599854, 0.6629627899588003], 
             UndirectedEdge[22, 273] -> 
             RGBColor[
              0.28387789683872655`, 0.4157040468486936, 0.9394777983140272], 
             UndirectedEdge[240, 292] -> 
             RGBColor[
              0.2251125947151853, 0.3539379883814973, 0.9361312012935654], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.4322766112650586, 0.5488154801889021, 0.9487714854439504], 
             UndirectedEdge[120, 343] -> 
             RGBColor[
              0.64428944346767, 0.7208791499127623, 0.9659761919445966], 
             UndirectedEdge[175, 310] -> 
             RGBColor[
              0.18075514602575382`, 0.30731549738422004`, 0.933605110211667], 
             UndirectedEdge[55, 201] -> 
             RGBColor[
              0.33997947002411655`, 0.46590668357700793`, 0.9429935809374401],
              UndirectedEdge[264, 333] -> 
             RGBColor[
              0.19279573500831393`, 0.31997091982232506`, 0.9342908039417687],
              UndirectedEdge[107, 197] -> 
             RGBColor[
              0.9139845567949747, 0.6460331456516251, 0.5106347906861869], 
             UndirectedEdge[131, 300] -> 
             RGBColor[
              0.9062314787117222, 0.661847076989811, 0.24319781291959908`], 
             UndirectedEdge[164, 227] -> 
             RGBColor[
              0.23873025962291325`, 0.36825101760934276`, 0.9369067071645306],
              UndirectedEdge[75, 315] -> 
             RGBColor[
              0.24372617436870905`, 0.3735020407664642, 0.9371912171185102], 
             UndirectedEdge[123, 193] -> 
             RGBColor[
              0.8983178729767032, 0.9207629901755221, 0.9556553997903747], 
             UndirectedEdge[157, 253] -> 
             RGBColor[
              0.40547981020843754`, 0.5251955404755204, 0.9471772728723662], 
             UndirectedEdge[87, 110] -> 
             RGBColor[
              0.27285833032697415`, 0.4041217837639711, 0.9388502503031707], 
             UndirectedEdge[112, 273] -> 
             RGBColor[
              0.30217928403804095`, 0.4330746327553852, 0.940588334197813], 
             UndirectedEdge[193, 384] -> 
             RGBColor[
              0.7853837252276628, 0.8322860419074539, 0.9792383154624147], 
             UndirectedEdge[95, 249] -> 
             RGBColor[
              0.2756739059578213, 0.4070811322697972, 0.9390105931700766], 
             UndirectedEdge[61, 66] -> 
             RGBColor[
              0.9830643953423903, 0.9540141570597834, 0.4329439736998075], 
             UndirectedEdge[113, 251] -> 
             RGBColor[
              0.8094157442625041, 0.8510598457172036, 0.9816336535080088], 
             UndirectedEdge[107, 131] -> 
             RGBColor[
              0.8808419295941465, 0.5163805585259162, 0.22083043617809295`], 
             UndirectedEdge[71, 343] -> 
             RGBColor[
              0.7966602927353739, 0.841489655974727, 0.98025763017568], 
             UndirectedEdge[113, 168] -> 
             RGBColor[
              0.7333330676267822, 0.7916046330585647, 0.9740554448600397], 
             UndirectedEdge[58, 201] -> 
             RGBColor[
              0.2876186397714912, 0.4196358048478299, 0.939690828090115], 
             UndirectedEdge[47, 130] -> 
             RGBColor[
              0.4221487542491271, 0.5400657659424366, 0.9481199232226362], 
             UndirectedEdge[17, 82] -> 
             RGBColor[
              0.4573668797759753, 0.5683380513272105, 0.9509806674680623], 
             UndirectedEdge[11, 25] -> 
             RGBColor[
              0.8860868883930885, 0.5548412704093811, 0.2257767948788701], 
             UndirectedEdge[73, 392] -> 
             RGBColor[
              0.24553259442115521`, 0.3754007027752315, 0.9372940900681379], 
             UndirectedEdge[155, 337] -> 
             RGBColor[
              0.29464447603044647`, 0.42702040421973947`, 0.9400909390712692],
              UndirectedEdge[159, 165] -> 
             RGBColor[
              0.43209168429834016`, 0.5465211004605023, 0.9493493893401392], 
             UndirectedEdge[226, 368] -> 
             RGBColor[
              0.2257077662103317, 0.35456355135894857`, 0.9361650954297367], 
             UndirectedEdge[188, 258] -> 
             RGBColor[
              0.2600095899871553, 0.39061694300963157`, 0.938118533548826], 
             UndirectedEdge[140, 350] -> 
             RGBColor[
              0.5523338730537959, 0.6464369667603329, 0.9583649127104528], 
             UndirectedEdge[14, 38] -> 
             RGBColor[
              0.9800741446959539, 0.9433032752196526, 0.4743933351284341], 
             UndirectedEdge[242, 268] -> 
             RGBColor[
              0.8678329199624942, 0.4240532300724246, 0.2086880773194431], 
             UndirectedEdge[20, 50] -> 
             RGBColor[
              0.4309033063250306, 0.5476259924741631, 0.9486839796675377], 
             UndirectedEdge[149, 212] -> 
             RGBColor[
              0.21555790485274898`, 0.34389540353375003`, 0.9355870758407967],
              UndirectedEdge[80, 361] -> 
             RGBColor[
              0.34502145958500996`, 0.47326197983492335`, 0.9432054402076274],
              UndirectedEdge[31, 204] -> 
             RGBColor[
              0.1810722066459815, 0.3076487481988837, 0.9336231663449399], 
             UndirectedEdge[209, 245] -> 
             RGBColor[
              0.2409659187206967, 0.37060083707008695`, 0.9370340246427882], 
             UndirectedEdge[113, 148] -> 
             RGBColor[
              0.7102018348766541, 0.7732513864434318, 0.9719433954351793], 
             UndirectedEdge[48, 231] -> 
             RGBColor[
              0.3670635094292236, 0.49234797467679914`, 0.9446101496016666], 
             UndirectedEdge[198, 224] -> 
             RGBColor[
              0.901075568718926, 0.8970235530331128, 0.6716312488962854], 
             UndirectedEdge[1, 188] -> 
             RGBColor[
              0.3135344759290187, 0.4421377779902256, 0.9413401492239378], 
             UndirectedEdge[256, 264] -> 
             RGBColor[
              0.2076696899760163, 0.3356043895565939, 0.9351378536731348], 
             UndirectedEdge[15, 170] -> 
             RGBColor[
              0.3744152758657625, 0.49826976676104406`, 0.9450949256507872], 
             UndirectedEdge[20, 322] -> 
             RGBColor[
              0.45803755349750475`, 0.5696547967126826, 0.9508200870009773], 
             UndirectedEdge[92, 153] -> 
             RGBColor[
              0.30254730129756563`, 0.4345238091753902, 0.940570393778262], 
             UndirectedEdge[189, 360] -> 
             RGBColor[
              0.30546923311788443`, 0.43824575192600135`, 0.9407129642351355],
              UndirectedEdge[272, 342] -> 
             RGBColor[
              0.6251875638221265, 0.7065231010289125, 0.9636849864326502], 
             UndirectedEdge[69, 219] -> 
             RGBColor[
              0.4677032328653056, 0.5785751319820428, 0.9512844483334466], 
             UndirectedEdge[86, 151] -> 
             RGBColor[
              0.30818593638346986`, 0.44059786327207706`, 0.9408861053327038],
              UndirectedEdge[72, 288] -> 
             RGBColor[
              0.2363762501862872, 0.36577680443863003`, 0.9367726498095597], 
             UndirectedEdge[266, 273] -> 
             RGBColor[
              0.265217664230201, 0.3960909592500517, 0.938415125672312], 
             UndirectedEdge[131, 297] -> 
             RGBColor[
              0.9345525999537521, 0.8450176590746574, 0.6158415354980056], 
             UndirectedEdge[219, 360] -> 
             RGBColor[
              0.37878978346753606`, 0.5025104047366595, 0.9453571279452656], 
             UndirectedEdge[58, 236] -> 
             RGBColor[
              0.27466659649964625`, 0.4060223861621468, 0.9389532283866143], 
             UndirectedEdge[272, 321] -> 
             RGBColor[
              0.7324016958614257, 0.7908770383567805, 0.9739626144266329], 
             UndirectedEdge[250, 391] -> 
             RGBColor[
              0.9043090036006871, 0.5735688958941825, 0.5059642810005588], 
             UndirectedEdge[122, 298] -> 
             RGBColor[
              0.634758859433705, 0.711422615804957, 0.9663329898214426], 
             UndirectedEdge[113, 282] -> 
             RGBColor[
              0.7216887092702036, 0.7825079718100041, 0.9728948440417715], 
             UndirectedEdge[237, 343] -> 
             RGBColor[
              0.6503098019378368, 0.7257667481329021, 0.9664501366166679], 
             UndirectedEdge[174, 398] -> 
             RGBColor[
              0.83401539327211, 0.8711277377968187, 0.9805027030161089], 
             UndirectedEdge[223, 384] -> 
             RGBColor[
              0.6012475155961567, 0.6855340055780029, 0.9628624648765374], 
             UndirectedEdge[143, 260] -> 
             RGBColor[
              0.7167991404658595, 0.7784168360748085, 0.9725930329082488], 
             UndirectedEdge[148, 161] -> 
             RGBColor[
              0.5276623353729026, 0.6268249505740837, 0.9561228183174523], 
             UndirectedEdge[137, 199] -> 
             RGBColor[
              0.22367942926895015`, 0.3524316406295666, 0.9360495846415806], 
             UndirectedEdge[147, 387] -> 
             RGBColor[
              0.28915329202202544`, 0.42124882166571403`, 0.9397782242654684],
              UndirectedEdge[138, 381] -> 
             RGBColor[
              0.9062449527279615, 0.5705587678025101, 0.4646955300926113], 
             UndirectedEdge[42, 207] -> 
             RGBColor[
              0.9360408404789141, 0.8740255032004962, 0.6319312562767279], 
             UndirectedEdge[185, 247] -> 
             RGBColor[
              0.8653490116625105, 0.42606196440460237`, 0.20717681371904806`],
              UndirectedEdge[49, 380] -> 
             RGBColor[
              0.2606135317686764, 0.39125172411413095`, 0.9381529271398318], 
             UndirectedEdge[63, 242] -> 
             RGBColor[
              0.9384539463641798, 0.7929291511512139, 0.2733380495894395], 
             UndirectedEdge[12, 238] -> 
             RGBColor[
              0.22383004590865202`, 0.3525899482675398, 0.9360581620363942], 
             UndirectedEdge[109, 382] -> 
             RGBColor[
              0.9464386860434384, 0.8125481887830079, 0.4923766470320703], 
             UndirectedEdge[4, 115] -> 
             RGBColor[
              0.23540129852856206`, 0.36475206843085556`, 0.936717127754964], 
             UndirectedEdge[187, 279] -> 
             RGBColor[
              0.8947917399967904, 0.8503099582405043, 0.6300514927715455], 
             UndirectedEdge[152, 156] -> 
             RGBColor[
              0.18478785261667285`, 0.31155412769964164`, 0.9338347668861651],
              UndirectedEdge[143, 290] -> 
             RGBColor[
              0.5148889820990041, 0.6157407807626738, 0.9553145849297924], 
             UndirectedEdge[48, 234] -> 
             RGBColor[
              0.38209114426819646`, 0.5053698775309731, 0.945567487736205], 
             UndirectedEdge[294, 341] -> 
             RGBColor[
              0.21717163219876068`, 0.3455915332906315, 0.9356789752258563], 
             UndirectedEdge[243, 351] -> 
             RGBColor[
              0.26705822161415743`, 0.39802550175866824`, 0.9385199426924677],
              UndirectedEdge[241, 399] -> 
             RGBColor[
              0.2629204824738216, 0.3936764755743613, 0.938284304569662], 
             UndirectedEdge[78, 207] -> 
             RGBColor[
              0.8908498839236407, 0.5609459506099194, 0.22908395145458324`], 
             UndirectedEdge[174, 267] -> 
             RGBColor[
              0.6499021646261236, 0.725337696254724, 0.9664851266806084], 
             UndirectedEdge[124, 293] -> 
             RGBColor[
              0.21725116581640602`, 0.3456751281654994, 0.9356835045477219], 
             UndirectedEdge[57, 392] -> 
             RGBColor[
              0.2605783177897506, 0.3912147119895847, 0.9381509217558264], 
             UndirectedEdge[272, 331] -> 
             RGBColor[
              0.5495546990516302, 0.6450876581742866, 0.9577400845269233], 
             UndirectedEdge[91, 255] -> 
             RGBColor[
              0.26154809523840944`, 0.39223400957556664`, 0.9382061491468703],
              UndirectedEdge[35, 337] -> 
             RGBColor[
              0.28289219144336497`, 0.41466800798083686`, 0.9394216638499819],
              UndirectedEdge[219, 339] -> 
             RGBColor[
              0.4064741730871376, 0.5264892315672777, 0.9471211527714821], 
             UndirectedEdge[166, 185] -> 
             RGBColor[
              0.8242297938213237, 0.1872463896398561, 0.17083578396792481`], 
             UndirectedEdge[137, 238] -> 
             RGBColor[
              0.22538960071026484`, 0.3542291392455204, 0.9361469763751915], 
             UndirectedEdge[218, 300] -> 
             RGBColor[
              0.9000302759419758, 0.7622535258714493, 0.6106034215734397], 
             UndirectedEdge[96, 110] -> 
             RGBColor[
              0.2712447160930261, 0.4024257728950402, 0.9387583573596757], 
             UndirectedEdge[225, 375] -> 
             RGBColor[
              0.2559767228165143, 0.3863781439147409, 0.9378888677295503], 
             UndirectedEdge[24, 25] -> 
             RGBColor[
              0.8754320696783777, 0.5120010563873596, 0.21717277432657275`], 
             UndirectedEdge[40, 361] -> 
             RGBColor[
              0.34746932604333547`, 0.4753821987277793, 0.9433614160937887], 
             UndirectedEdge[141, 394] -> 
             RGBColor[
              0.3594659493572627, 0.4857730708744833, 0.9441258303231546], 
             UndirectedEdge[200, 360] -> 
             RGBColor[
              0.29052568872167633`, 0.4225391392901483, 0.9398619514887643], 
             UndirectedEdge[68, 229] -> 
             RGBColor[
              0.2618103919644219, 0.39250970006517877`, 0.9382210865573835], 
             UndirectedEdge[96, 258] -> 
             RGBColor[
              0.26992237493120286`, 0.4010359084926919, 0.9386830519867384], 
             UndirectedEdge[106, 310] -> 
             RGBColor[
              0.5655364837016175, 0.6351698449942476, 0.952888973704525], 
             UndirectedEdge[15, 394] -> 
             RGBColor[
              0.33136443385417313`, 0.4609812912088401, 0.9423517640661736], 
             UndirectedEdge[115, 203] -> 
             RGBColor[
              0.265001837635785, 0.3958641118151241, 0.9384028346670469], 
             UndirectedEdge[218, 298] -> 
             RGBColor[
              0.8667469534105012, 0.8965845097029781, 0.9871522922420749], 
             UndirectedEdge[165, 262] -> 
             RGBColor[
              0.7356958172611161, 0.7926545035064209, 0.9725524468455675], 
             UndirectedEdge[141, 357] -> 
             RGBColor[
              0.5178770250869611, 0.6164322687663853, 0.9562370335292427], 
             UndirectedEdge[15, 239] -> 
             RGBColor[
              0.3141879177885835, 0.4461038563096259, 0.9412572916510711], 
             UndirectedEdge[80, 228] -> 
             RGBColor[
              0.35113678778418134`, 0.4785587697557132, 0.9435951035129062], 
             UndirectedEdge[260, 272] -> 
             RGBColor[
              0.7279854810242253, 0.7874270577614837, 0.9735224474035349], 
             UndirectedEdge[7, 361] -> 
             RGBColor[
              0.3725157575792012, 0.497076158853894, 0.9449573525635642], 
             UndirectedEdge[22, 255] -> 
             RGBColor[
              0.27639668732322686`, 0.40784082131182386`, 0.9390517544995772],
              UndirectedEdge[28, 380] -> 
             RGBColor[
              0.2768898890919296, 0.40835920764152867`, 0.9390798416106783], 
             UndirectedEdge[53, 397] -> 
             RGBColor[
              0.26929675474869136`, 0.4003783420142617, 0.9386474238428664], 
             UndirectedEdge[187, 306] -> 
             RGBColor[
              0.9071549779062498, 0.8950638881018478, 0.6621967951023203], 
             UndirectedEdge[208, 392] -> 
             RGBColor[
              0.24051796511845452`, 0.3701300094322317, 0.9370085143478284], 
             UndirectedEdge[33, 381] -> 
             RGBColor[
              0.5860442078575524, 0.648421627973087, 0.8483684065741224], 
             UndirectedEdge[290, 321] -> 
             RGBColor[
              0.6114600904368728, 0.6914542319869668, 0.964754355111318], 
             UndirectedEdge[20, 116] -> 
             RGBColor[
              0.4119401607737857, 0.531223595372923, 0.9474694406734923], 
             UndirectedEdge[33, 156] -> 
             RGBColor[
              0.18245046291019928`, 0.30909738291907096`, 0.9337016560002396],
              UndirectedEdge[9, 202] -> 
             RGBColor[
              0.8410035318945833, 0.31617669076982174`, 0.1868983344901058], 
             UndirectedEdge[76, 233] -> 
             RGBColor[
              0.8322013343184957, 0.24851914305244047`, 0.17846934015058413`],
              UndirectedEdge[115, 369] -> 
             RGBColor[
              0.24803002426208054`, 0.37802565988424164`, 0.9374363150029623],
              UndirectedEdge[183, 335] -> 
             RGBColor[
              0.2697259044179279, 0.4008294055262898, 0.9386718632816594], 
             UndirectedEdge[39, 296] -> 
             RGBColor[
              0.2873068026652887, 0.4193080442775966, 0.9396730694282384], 
             UndirectedEdge[10, 219] -> 
             RGBColor[
              0.4045568603314619, 0.5248285516252523, 0.9469989832981036], 
             UndirectedEdge[71, 143] -> 
             RGBColor[
              0.7478821300066041, 0.8031124171001021, 0.9755814141619994], 
             UndirectedEdge[232, 384] -> 
             RGBColor[
              0.6369922413654878, 0.7145531842390913, 0.965676420626344], 
             UndirectedEdge[1, 57] -> 
             RGBColor[
              0.31659522838756854`, 0.44535482288707584`, 0.9415144545484747],
              UndirectedEdge[288, 393] -> 
             RGBColor[
              0.23392299503197628`, 0.3631982777260886, 0.9366329405577875], 
             UndirectedEdge[328, 372] -> 
             RGBColor[
              0.2804573452843499, 0.4120449254968854, 0.9392853428307628], 
             UndirectedEdge[16, 115] -> 
             RGBColor[
              0.240233305102069, 0.36983081370652304`, 0.936992303381012], 
             UndirectedEdge[34, 244] -> 
             RGBColor[
              0.2861625929026812, 0.4177778317374103, 0.9396199025198813], 
             UndirectedEdge[233, 366] -> 
             RGBColor[
              0.8593693391869154, 0.3899082942266366, 0.20184482611558502`], 
             UndirectedEdge[100, 105] -> 
             RGBColor[
              0.3969790975995051, 0.5182650744162607, 0.9465161349575758], 
             UndirectedEdge[88, 282] -> 
             RGBColor[
              0.8185877701205739, 0.8571575543356513, 0.887813136638508], 
             UndirectedEdge[189, 219] -> 
             RGBColor[
              0.37386729373661226`, 0.4974887142474586, 0.9450712281757306], 
             UndirectedEdge[44, 328] -> 
             RGBColor[
              0.3036968641952127, 0.4364711333428047, 0.9406087990529493], 
             UndirectedEdge[153, 154] -> 
             RGBColor[
              0.3737943950019111, 0.49818365032325973`, 0.9450388262094847], 
             UndirectedEdge[73, 258] -> 
             RGBColor[
              0.2480246190771097, 0.3780199786921288, 0.9374360071856744], 
             UndirectedEdge[22, 141] -> 
             RGBColor[
              0.32619117202571163`, 0.45543328701971864`, 0.9420612032605917],
              UndirectedEdge[100, 273] -> 
             RGBColor[
              0.3260257412647034, 0.4537292354473304, 0.9421078093657018], 
             UndirectedEdge[230, 391] -> 
             RGBColor[
              0.8946240115133538, 0.5321742003823082, 0.2503381046492794], 
             UndirectedEdge[338, 384] -> 
             RGBColor[
              0.8713581064441347, 0.8967942587815345, 0.7976314467612728], 
             UndirectedEdge[76, 207] -> 
             RGBColor[
              0.8934001271128089, 0.5805482372855583, 0.23152606721261854`], 
             UndirectedEdge[144, 370] -> 
             RGBColor[
              0.8548273648949809, 0.7045756223106869, 0.6020207461756493], 
             UndirectedEdge[6, 340] -> 
             RGBColor[
              0.9935628356137232, 0.988639881211936, 0.5407325660065214], 
             UndirectedEdge[30, 370] -> 
             RGBColor[
              0.5050718279609444, 0.5868238115344944, 0.9586321897581539], 
             UndirectedEdge[164, 245] -> 
             RGBColor[
              0.23621867801950508`, 0.36561118610068966`, 0.9367636763077685],
              UndirectedEdge[56, 108] -> 
             RGBColor[
              0.40925205503740436`, 0.5288952932921922, 0.9472981569529686], 
             UndirectedEdge[50, 322] -> 
             RGBColor[
              0.4812818793914586, 0.5897653370483966, 0.952307419020761], 
             UndirectedEdge[379, 399] -> 
             RGBColor[
              0.22791818849812123`, 0.356886845332283, 0.9362909757089996], 
             UndirectedEdge[6, 13] -> 
             RGBColor[
              0.978563836078469, 0.9803436260913665, 0.7317471315868381], 
             UndirectedEdge[55, 60] -> 
             RGBColor[
              0.38053049793671245`, 0.5040181241190069, 0.9454680447319882], 
             UndirectedEdge[44, 47] -> 
             RGBColor[
              0.36592423069765223`, 0.4903693505688373, 0.9445738718209851], 
             UndirectedEdge[156, 264] -> 
             RGBColor[
              0.1879952768080626, 0.31492533388723165`, 0.9340174249489059], 
             UndirectedEdge[32, 43] -> 
             RGBColor[
              0.2218603287150994, 0.3505196506098328, 0.9359459895561568], 
             UndirectedEdge[144, 207] -> 
             RGBColor[
              0.9091469621070289, 0.6700765235430096, 0.2453714490760957], 
             UndirectedEdge[14, 213] -> 
             RGBColor[
              0.9526625957676589, 0.8375319772984231, 0.4372009912003371], 
             UndirectedEdge[127, 139] -> 
             RGBColor[
              0.2108331954164144, 0.3389294343522821, 0.9353180106279786], 
             UndirectedEdge[321, 342] -> 
             RGBColor[
              0.7105723316016292, 0.7732263305665302, 0.9721953421188899], 
             UndirectedEdge[82, 182] -> 
             RGBColor[
              0.3336557333984177, 0.4615081693978327, 0.9425511382946132], 
             UndirectedEdge[50, 172] -> 
             RGBColor[
              0.3777861468106212, 0.500941670871986, 0.945324186142565], 
             UndirectedEdge[80, 96] -> 
             RGBColor[
              0.31066394327551555`, 0.4414844762785116, 0.9410901259683782], 
             UndirectedEdge[78, 160] -> 
             RGBColor[
              0.835660765688327, 0.2751098484934552, 0.18178209553720334`], 
             UndirectedEdge[32, 293] -> 
             RGBColor[
              0.2137582367821496, 0.342003838286004, 0.9354845874065463], 
             UndirectedEdge[322, 328] -> 
             RGBColor[
              0.4089266558730876, 0.5271174055758985, 0.947690784031411], 
             UndirectedEdge[120, 254] -> 
             RGBColor[
              0.5179448523327678, 0.6195299901302602, 0.955193662551596], 
             UndirectedEdge[291, 321] -> 
             RGBColor[
              0.7571390218362452, 0.8102020254189503, 0.9764281998963484], 
             UndirectedEdge[65, 312] -> 
             RGBColor[
              0.4891446804627151, 0.5961487131731942, 0.9529264075234798], 
             UndirectedEdge[209, 334] -> 
             RGBColor[
              0.2567160128781451, 0.387155184643212, 0.9379309692048785], 
             UndirectedEdge[295, 310] -> 
             RGBColor[
              0.2124827502833183, 0.3406632211052174, 0.935411950337351], 
             UndirectedEdge[109, 205] -> 
             RGBColor[
              0.9946824810618875, 0.9920690835121566, 0.737788580309801], 
             UndirectedEdge[194, 376] -> 
             RGBColor[
              0.4132241787161002, 0.5323357471779375, 0.947551257161364], 
             UndirectedEdge[142, 338] -> 
             RGBColor[
              0.9079361737525008, 0.5785505948422507, 0.3940025431841314], 
             UndirectedEdge[232, 386] -> 
             RGBColor[
              0.4324598922567031, 0.5470353068857565, 0.9493188938960907], 
             UndirectedEdge[169, 378] -> 
             RGBColor[
              0.21461245212241514`, 0.34290167276900374`, 0.9355332337064761],
              UndirectedEdge[94, 324] -> 
             RGBColor[
              0.2700408112862358, 0.4011603926111301, 0.9386897967619465], 
             UndirectedEdge[196, 231] -> 
             RGBColor[
              0.3033041199951848, 0.43612223907981873`, 0.9405840929842658], 
             UndirectedEdge[207, 366] -> 
             RGBColor[
              0.9205681319812286, 0.7219373884597544, 0.2549015531776194], 
             UndirectedEdge[156, 310] -> 
             RGBColor[
              0.1842688448604277, 0.3110086176408356, 0.93380521016225], 
             UndirectedEdge[206, 369] -> 
             RGBColor[
              0.2445080094379043, 0.3743237989953949, 0.9372357414690795], 
             UndirectedEdge[119, 225] -> 
             RGBColor[
              0.24880323623162193`, 0.37883835468870003`, 0.9374803482807631],
              UndirectedEdge[69, 100] -> 
             RGBColor[
              0.4324163535905058, 0.5480114107243323, 0.9490359995890186], 
             UndirectedEdge[64, 182] -> 
             RGBColor[
              0.34352729206089855`, 0.4700584173523088, 0.9431801452835099], 
             UndirectedEdge[217, 268] -> 
             RGBColor[
              0.8200723347530428, 0.15529033743086842`, 0.16685459646896056`],
              UndirectedEdge[235, 275] -> 
             RGBColor[
              0.8660971591696807, 0.893943749566336, 0.8776528174795629], 
             UndirectedEdge[5, 99] -> 
             RGBColor[
              0.9097853137766493, 0.92980801321679, 0.9533236132867424], 
             UndirectedEdge[52, 267] -> 
             RGBColor[
              0.4789222153161444, 0.5860393403630161, 0.9526218530734996], 
             UndirectedEdge[290, 346] -> 
             RGBColor[
              0.3750828645825507, 0.4992996579136456, 0.9451209263518141], 
             UndirectedEdge[19, 108] -> 
             RGBColor[
              0.3209765938651673, 0.4492585340761873, 0.9417896478514372], 
             UndirectedEdge[92, 327] -> 
             RGBColor[
              0.3031279877877182, 0.4350267706270088, 0.9406073946079336], 
             UndirectedEdge[151, 244] -> 
             RGBColor[
              0.28793584651295273`, 0.41931373488830953`, 0.9397328926719012],
              UndirectedEdge[114, 327] -> 
             RGBColor[
              0.32373500724345117`, 0.4548247247048681, 0.941849086287294], 
             UndirectedEdge[99, 174] -> 
             RGBColor[
              0.8533664925541351, 0.885559755956836, 0.9477463395066474], 
             UndirectedEdge[180, 282] -> 
             RGBColor[
              0.5065658976915518, 0.60785950870626, 0.9549980870909234], 
             UndirectedEdge[199, 277] -> 
             RGBColor[
              0.24180779724081597`, 0.3714857047729135, 0.9370819683790612], 
             UndirectedEdge[237, 286] -> 
             RGBColor[
              0.652334455595527, 0.7273484229582274, 0.9666519351718024], 
             UndirectedEdge[290, 313] -> 
             RGBColor[
              0.34397103520992167`, 0.4699540423686539, 0.9432263147475373], 
             UndirectedEdge[56, 237] -> 
             RGBColor[
              0.5146770314008289, 0.6168123226982427, 0.9549542854004349], 
             UndirectedEdge[203, 361] -> 
             RGBColor[
              0.32351204834138475`, 0.4530276285511149, 0.941893609121445], 
             UndirectedEdge[169, 315] -> 
             RGBColor[
              0.23198634740170132`, 0.3611627382761178, 0.9365226513402567], 
             UndirectedEdge[23, 304] -> 
             RGBColor[
              0.2162581809318601, 0.34463143809296365`, 0.9356269555275363], 
             UndirectedEdge[129, 270] -> 
             RGBColor[
              0.24363580909960866`, 0.3734070611391507, 0.9371860709501183], 
             UndirectedEdge[85, 284] -> 
             RGBColor[
              0.24265277809452013`, 0.37237383322503703`, 0.9371300887886426],
              UndirectedEdge[203, 369] -> 
             RGBColor[
              0.2744257623445868, 0.405769254195412, 0.9389395132377659], 
             UndirectedEdge[1, 222] -> 
             RGBColor[
              0.48245496695292606`, 0.5881834392083616, 0.9530999932353155], 
             UndirectedEdge[25, 205] -> 
             RGBColor[
              0.9219898136234065, 0.68386598697934, 0.46117782525974793`], 
             UndirectedEdge[301, 380] -> 
             RGBColor[
              0.26115428543555863`, 0.39182009050378686`, 0.9381837222611874],
              UndirectedEdge[169, 329] -> 
             RGBColor[
              0.22791864695390707`, 0.3568873271983817, 0.9362910018173783], 
             UndirectedEdge[302, 340] -> 
             RGBColor[
              0.9905275811721996, 0.978922480132596, 0.484619975557615], 
             UndirectedEdge[205, 391] -> 
             RGBColor[
              0.9078296512801215, 0.575024774186147, 0.4476180378082022], 
             UndirectedEdge[96, 203] -> 
             RGBColor[
              0.28915453203189034`, 0.42125012499470316`, 0.9397782948821958],
              UndirectedEdge[4, 195] -> 
             RGBColor[
              0.2389456018045329, 0.3684773558957079, 0.9369189705832036], 
             UndirectedEdge[269, 298] -> 
             RGBColor[
              0.908244530929823, 0.9248034643520736, 0.7344530675019115], 
             UndirectedEdge[168, 220] -> 
             RGBColor[
              0.5727925024434088, 0.663632053166977, 0.9598025445321408], 
             UndirectedEdge[291, 338] -> 
             RGBColor[
              0.8453899770207604, 0.8765077587109009, 0.7950431863063177], 
             UndirectedEdge[10, 360] -> 
             RGBColor[
              0.336158799712734, 0.4655855893037951, 0.9426407193575084], 
             UndirectedEdge[87, 348] -> 
             RGBColor[
              0.27654696971548504`, 0.4079987776345412, 0.9390603128594934], 
             UndirectedEdge[259, 274] -> 
             RGBColor[
              0.22087433163626, 0.34948330516414705`, 0.9358898384811689], 
             UndirectedEdge[293, 336] -> 
             RGBColor[
              0.21111881242536762`, 0.33922963593785627`, 0.935334276094106], 
             UndirectedEdge[229, 245] -> 
             RGBColor[
              0.238397504828522, 0.36790127122256505`, 0.9368877572712566], 
             UndirectedEdge[173, 197] -> 
             RGBColor[
              0.607559522477704, 0.6724367666110929, 0.8861420267905455], 
             UndirectedEdge[19, 344] -> 
             RGBColor[
              0.2975063791842545, 0.4289298137668702, 0.9402941465258654], 
             UndirectedEdge[83, 125] -> 
             RGBColor[
              0.315433813888692, 0.4447906722692076, 0.9414242734794431], 
             UndirectedEdge[240, 315] -> 
             RGBColor[
              0.24124036831115342`, 0.3708893009907661, 0.9370496541409528], 
             UndirectedEdge[7, 154] -> 
             RGBColor[
              0.40978151173656857`, 0.5293538820737408, 0.9473318934656592], 
             UndirectedEdge[200, 225] -> 
             RGBColor[
              0.26388387983793327`, 0.3946890672869635, 0.9383391686243296], 
             UndirectedEdge[13, 140] -> 
             RGBColor[
              0.8178525622986523, 0.8580700202466935, 0.9570649175635426], 
             UndirectedEdge[104, 366] -> 
             RGBColor[
              0.9175772665295729, 0.7100796035907695, 0.25249503263058215`], 
             UndirectedEdge[116, 172] -> 
             RGBColor[
              0.3588230012593764, 0.484539273770746, 0.9441096471485195], 
             UndirectedEdge[143, 267] -> 
             RGBColor[
              0.5979215961089128, 0.6844587136389835, 0.9614897247861196], 
             UndirectedEdge[51, 395] -> 
             RGBColor[
              0.3229957435790246, 0.45088574591651165`, 0.9419227613726417], 
             UndirectedEdge[213, 224] -> 
             RGBColor[
              0.9433148110399261, 0.8071439818533458, 0.30358552172184644`], 
             UndirectedEdge[130, 362] -> 
             RGBColor[
              0.40753230852825906`, 0.5274057353029433, 0.9471885762261179], 
             UndirectedEdge[153, 278] -> 
             RGBColor[
              0.284923192180341, 0.41599975306012926`, 0.939566726836569], 
             UndirectedEdge[83, 303] -> 
             RGBColor[
              0.32124670467921895`, 0.4509003890486145, 0.9417553090105623], 
             UndirectedEdge[94, 296] -> 
             RGBColor[
              0.2808227544696311, 0.4124928985115602, 0.9393038124757853], 
             UndirectedEdge[147, 328] -> 
             RGBColor[
              0.29708750914626414`, 0.42952428212904603`, 0.9402324060605761],
              UndirectedEdge[78, 102] -> 
             RGBColor[
              0.8305704924938522, 0.23598377814878552`, 0.17690764417753302`],
              UndirectedEdge[22, 45] -> 
             RGBColor[
              0.2939087453063859, 0.4262471045807297, 0.94004904029495], 
             UndirectedEdge[199, 238] -> 
             RGBColor[
              0.22751293603602638`, 0.35646089930013114`, 0.9362678971808005],
              UndirectedEdge[21, 182] -> 
             RGBColor[
              0.30050572685967525`, 0.4327952999017487, 0.9404388491913643], 
             UndirectedEdge[126, 212] -> 
             RGBColor[
              0.21146946129668887`, 0.3395981901340374, 0.9353542450285892], 
             UndirectedEdge[273, 365] -> 
             RGBColor[
              0.26583905724777945`, 0.3967440827101195, 0.9384505130853945], 
             UndirectedEdge[149, 367] -> 
             RGBColor[
              0.21976666504097775`, 0.348319077342387, 0.9358267585072135], 
             UndirectedEdge[81, 89] -> 
             RGBColor[
              0.21914913629591037`, 0.3476700154777373, 0.9357915911587338], 
             UndirectedEdge[57, 337] -> 
             RGBColor[
              0.27897537779675124`, 0.41055118849791716`, 0.9391986071072138],
              UndirectedEdge[255, 288] -> 
             RGBColor[
              0.25275048461760563`, 0.38298716301237146`, 0.9377051382369141],
              UndirectedEdge[2, 283] -> 
             RGBColor[
              0.8636832468154017, 0.4097080433065882, 0.20543575312607748`], 
             UndirectedEdge[94, 128] -> 
             RGBColor[
              0.29316856057651314`, 0.42385416586161573`, 0.9400660193797667],
              UndirectedEdge[176, 393] -> 
             RGBColor[
              0.2193217433014607, 0.3478514363844869, 0.9358014208723507], 
             UndirectedEdge[65, 326] -> 
             RGBColor[
              0.4273612108963405, 0.5428967033575929, 0.9489173037481067], 
             UndirectedEdge[97, 282] -> 
             RGBColor[
              0.5445731104291971, 0.6407794460815519, 0.9574198730781076], 
             UndirectedEdge[12, 149] -> 
             RGBColor[
              0.21932780961758047`, 0.3478578124673555, 0.9358017663400795], 
             UndirectedEdge[78, 144] -> 
             RGBColor[
              0.8601410277678558, 0.4317670823407418, 0.2039906170405674], 
             UndirectedEdge[201, 348] -> 
             RGBColor[
              0.2696907546749492, 0.40079246091779686`, 0.9386698615557961], 
             UndirectedEdge[242, 381] -> 
             RGBColor[
              0.9557469344850966, 0.8527067973943953, 0.5081965742437817], 
             UndirectedEdge[43, 367] -> 
             RGBColor[
              0.22337497152266345`, 0.35211163623448327`, 0.9360322462233344],
              UndirectedEdge[111, 197] -> 
             RGBColor[
              0.931414792844472, 0.7553582824181725, 0.5263607215030722], 
             UndirectedEdge[69, 216] -> 
             RGBColor[
              0.5736600979558795, 0.6645056615859741, 0.959755124057878], 
             UndirectedEdge[197, 295] -> 
             RGBColor[
              0.6155693919444334, 0.6808556472756819, 0.8865981770071358], 
             UndirectedEdge[193, 275] -> 
             RGBColor[
              0.9072201261691099, 0.9260883634638468, 0.8817465180078601], 
             UndirectedEdge[149, 238] -> 
             RGBColor[
              0.2247208711862695, 0.3535262621159006, 0.9361088932180968], 
             UndirectedEdge[79, 349] -> 
             RGBColor[
              0.518092548976322, 0.6194343382750406, 0.9552648492680336], 
             UndirectedEdge[16, 110] -> 
             RGBColor[
              0.2487192272457111, 0.3787500559180304, 0.9374755640932957], 
             UndirectedEdge[49, 372] -> 
             RGBColor[
              0.25360695200292194`, 0.3838873645375076, 0.9377539127874779], 
             UndirectedEdge[320, 343] -> 
             RGBColor[
              0.7160472963068527, 0.7781008571267078, 0.9723325607195863], 
             UndirectedEdge[221, 358] -> 
             RGBColor[
              0.9452177942477327, 0.9230965860350502, 0.6624178282504138], 
             UndirectedEdge[240, 245] -> 
             RGBColor[
              0.2345526793265548, 0.3638601158439808, 0.9366688001468292], 
             UndirectedEdge[85, 115] -> 
             RGBColor[
              0.2399567828787064, 0.36954017131724737`, 0.9369765558494695], 
             UndirectedEdge[70, 280] -> 
             RGBColor[
              0.2584116720913199, 0.38893742998726233`, 0.9380275344885658], 
             UndirectedEdge[151, 171] -> 
             RGBColor[
              0.294524052203641, 0.4262383567855898, 0.940108081239609], 
             UndirectedEdge[23, 163] -> 
             RGBColor[
              0.22919558870789478`, 0.35822947394460614`, 0.9363637217612019],
              UndirectedEdge[255, 360] -> 
             RGBColor[
              0.28543335040527573`, 0.4171867688467138, 0.9395719503550848], 
             UndirectedEdge[165, 307] -> 
             RGBColor[
              0.7589943744265952, 0.8098564226113569, 0.9253172138967432], 
             UndirectedEdge[81, 169] -> 
             RGBColor[
              0.22020695780518662`, 0.3487818529537441, 0.9358518325287805], 
             UndirectedEdge[44, 316] -> 
             RGBColor[
              0.27611802500026855`, 0.4075479295421829, 0.9390358850925288], 
             UndirectedEdge[195, 337] -> 
             RGBColor[
              0.26521901916211443`, 0.39609238336940045`, 0.9384152028336801],
              UndirectedEdge[316, 390] -> 
             RGBColor[
              0.26028939055795897`, 0.3909110311499271, 0.9381344677774055], 
             UndirectedEdge[39, 177] -> 
             RGBColor[
              0.29750028265951367`, 0.4288050749279245, 0.9402981320155486], 
             UndirectedEdge[45, 190] -> 
             RGBColor[
              0.2683010399450559, 0.3993317826236759, 0.9385907193578275], 
             UndirectedEdge[287, 396] -> 
             RGBColor[
              0.2692564543945499, 0.400335983786869, 0.9386451287973171], 
             UndirectedEdge[136, 343] -> 
             RGBColor[
              0.6703913429941837, 0.7420698478255596, 0.9680310290897323], 
             UndirectedEdge[296, 360] -> 
             RGBColor[
              0.3059566318031602, 0.4387580388470877, 0.9407407208692202], 
             UndirectedEdge[167, 228] -> 
             RGBColor[
              0.32570332239411426`, 0.45419998876459156`, 0.9420598033482018],
              UndirectedEdge[123, 279] -> 
             RGBColor[
              0.9599728871641575, 0.901288321876893, 0.6017603738326488], 
             UndirectedEdge[33, 333] -> 
             RGBColor[
              0.1872509211104506, 0.3141429688541644, 0.9339750349931024], 
             UndirectedEdge[164, 209] -> 
             RGBColor[
              0.24728574846658016`, 0.37724337883335973`, 0.9373939295974659],
              UndirectedEdge[22, 29] -> 
             RGBColor[
              0.2663738031073146, 0.39730613451333674`, 0.9384809660710094], 
             UndirectedEdge[24, 366] -> 
             RGBColor[
              0.9017167350633479, 0.6466004732099342, 0.2397023734046333], 
             UndirectedEdge[178, 319] -> 
             RGBColor[
              0.24278605838252734`, 0.37251391925819094`, 0.9371376789038741],
              UndirectedEdge[294, 368] -> 
             RGBColor[
              0.21277052855345546`, 0.3409656943133277, 0.9354283388841056], 
             UndirectedEdge[13, 69] -> 
             RGBColor[
              0.7259993754166094, 0.7839523785382002, 0.9495242388978706], 
             UndirectedEdge[214, 295] -> 
             RGBColor[
              0.6130802218515281, 0.6797567159185416, 0.9247335360686406], 
             UndirectedEdge[80, 146] -> 
             RGBColor[
              0.4348738177323767, 0.548860724677587, 0.9495460387678236], 
             UndirectedEdge[56, 231] -> 
             RGBColor[
              0.37980957762799716`, 0.5033879783145618, 0.9454223177963867], 
             UndirectedEdge[134, 351] -> 
             RGBColor[
              0.24003567899790235`, 0.3696230961408251, 0.9369810488667414], 
             UndirectedEdge[143, 291] -> 
             RGBColor[
              0.6605679134983766, 0.7344885741946573, 0.9669884297148228], 
             UndirectedEdge[120, 320] -> 
             RGBColor[
              0.6381361673517921, 0.7160721638444079, 0.9653628908870006], 
             UndirectedEdge[132, 220] -> 
             RGBColor[
              0.6373284381573086, 0.7140480166379533, 0.9662348834814941], 
             UndirectedEdge[6, 247] -> 
             RGBColor[
              0.9501775412917424, 0.8286011525137683, 0.3806667888005933], 
             UndirectedEdge[166, 289] -> 
             RGBColor[
              0.8612612060617832, 0.40999762047401866`, 0.2038737104047185], 
             UndirectedEdge[114, 392] -> 
             RGBColor[
              0.2884135464934976, 0.418609972282043, 0.9398042492586839], 
             UndirectedEdge[305, 325] -> 
             RGBColor[
              0.20723516257555488`, 0.3351476737080805, 0.9351131079805042], 
             UndirectedEdge[44, 128] -> 
             RGBColor[
              0.3120848480897295, 0.44373638339990634`, 0.9411432739695049], 
             UndirectedEdge[90, 242] -> 
             RGBColor[
              0.8120763207412868, 0.7420397918675932, 0.6122349694370377], 
             UndirectedEdge[1, 337] -> 
             RGBColor[
              0.3223631828098259, 0.4514173086943011, 0.9418429310198984], 
             UndirectedEdge[74, 224] -> 
             RGBColor[
              0.9001674923644503, 0.8962994775971298, 0.6715446357629462], 
             UndirectedEdge[160, 370] -> 
             RGBColor[
              0.8303471028154521, 0.5479183884634005, 0.5798122246722852], 
             UndirectedEdge[30, 84] -> 
             RGBColor[
              0.1789270231889713, 0.3053940243730791, 0.9335010013205776], 
             UndirectedEdge[293, 299] -> 
             RGBColor[
              0.21267988324051307`, 0.34087042034218046`, 0.9354231767676313],
              UndirectedEdge[186, 399] -> 
             RGBColor[
              0.24167334431028037`, 0.3713443862181124, 0.9370743114835726], 
             UndirectedEdge[163, 371] -> 
             RGBColor[
              0.25850942763125473`, 0.3890401772577931, 0.9380331015219487], 
             UndirectedEdge[90, 138] -> 
             RGBColor[
              0.7625743389841517, 0.45989176227570816`, 0.5687339252858672], 
             UndirectedEdge[71, 286] -> 
             RGBColor[
              0.798684946393064, 0.8430713308000524, 0.9804594287308144], 
             UndirectedEdge[60, 201] -> 
             RGBColor[
              0.3169773146449097, 0.44598337270948407`, 0.9415279039366844], 
             UndirectedEdge[128, 380] -> 
             RGBColor[
              0.2958519089446212, 0.4266745351306104, 0.9402188320996724], 
             UndirectedEdge[54, 128] -> 
             RGBColor[
              0.3891023193866603, 0.5114426050266787, 0.9460142336150148], 
             UndirectedEdge[25, 138] -> 
             RGBColor[
              0.8340269956702107, 0.26255197621162585`, 0.18021759552277578`],
              UndirectedEdge[95, 129] -> 
             RGBColor[
              0.2597315005548766, 0.39032465338441835`, 0.9381026967670542], 
             UndirectedEdge[132, 302] -> 
             RGBColor[
              0.8932496977556434, 0.905911220002762, 0.6928483915783341], 
             UndirectedEdge[15, 100] -> 
             RGBColor[
              0.34023750094859895`, 0.4686666959527124, 0.9429171480552854], 
             UndirectedEdge[33, 63] -> 
             RGBColor[
              0.5687512197366357, 0.5886439817299056, 0.6135098819197802], 
             UndirectedEdge[275, 338] -> 
             RGBColor[
              0.9931945073855819, 0.9905965803379274, 0.7001396493067182], 
             UndirectedEdge[252, 277] -> 
             RGBColor[
              0.2410729775793306, 0.3707133627184349, 0.9370401214864079], 
             UndirectedEdge[146, 192] -> 
             RGBColor[
              0.43991049068666355`, 0.5532232376400468, 0.9498669711147159], 
             UndirectedEdge[237, 254] -> 
             RGBColor[
              0.5239652108029346, 0.6244175883504002, 0.9556676072236672], 
             UndirectedEdge[37, 236] -> 
             RGBColor[
              0.2501608630823501, 0.3802653065873294, 0.9375576631214831], 
             UndirectedEdge[265, 362] -> 
             RGBColor[
              0.4982768620774518, 0.6022414244020411, 0.9540103792474512], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.31424207897729384`, 0.44465323780495364`, 0.9413155746707285],
              UndirectedEdge[341, 379] -> 
             RGBColor[
              0.2212705365436844, 0.3498997416426921, 0.9359124017645142], 
             UndirectedEdge[324, 380] -> 
             RGBColor[
              0.27272415965434393`, 0.4039807618801248, 0.9388426094818522], 
             UndirectedEdge[63, 264] -> 
             RGBColor[
              0.5742960336344989, 0.5944719326980662, 0.6138256508684465], 
             UndirectedEdge[153, 337] -> 
             RGBColor[
              0.30108704647180895`, 0.43298898876801645`, 0.9404872344261885],
              UndirectedEdge[112, 155] -> 
             RGBColor[
              0.31673339546261187`, 0.44837192664657105`, 0.9414171693125639],
              UndirectedEdge[10, 177] -> 
             RGBColor[
              0.34191718866131093`, 0.47057321638600846`, 0.9430076388093683],
              UndirectedEdge[238, 367] -> 
             RGBColor[
              0.2242689013320493, 0.35305121314257126`, 0.9360831542035284], 
             UndirectedEdge[87, 228] -> 
             RGBColor[
              0.32899794708810315`, 0.4576628482092444, 0.9422474273505641], 
             UndirectedEdge[66, 352] -> 
             RGBColor[
              0.983468511290683, 0.9548785202107917, 0.47692950075693274`], 
             UndirectedEdge[86, 386] -> 
             RGBColor[
              0.31994974783175406`, 0.4507870854822257, 0.9416356849958585], 
             UndirectedEdge[52, 133] -> 
             RGBColor[
              0.34195185422260005`, 0.4695411184843201, 0.9430487372114036], 
             UndirectedEdge[105, 112] -> 
             RGBColor[
              0.37313264037284266`, 0.49761047172431544`, 0.944996659789687], 
             UndirectedEdge[4, 258] -> 
             RGBColor[
              0.24256487951038092`, 0.3722814462400146, 0.9371250830943101], 
             UndirectedEdge[141, 339] -> 
             RGBColor[
              0.36291222472736206`, 0.48875806138522676`, 0.9443454239423157],
              UndirectedEdge[251, 282] -> 
             RGBColor[
              0.7345888082776114, 0.7926044746200289, 0.9741756038265081], 
             UndirectedEdge[94, 390] -> 
             RGBColor[
              0.26321162125265696`, 0.393982480890182, 0.9383008844924156], 
             UndirectedEdge[239, 337] -> 
             RGBColor[
              0.304629125717821, 0.43605695978083275`, 0.9407129325836068], 
             UndirectedEdge[80, 243] -> 
             RGBColor[
              0.3113941751763021, 0.44225199630561496`, 0.9411317115948465], 
             UndirectedEdge[366, 382] -> 
             RGBColor[
              0.9000306839899277, 0.6389445090727658, 0.23829549106007777`], 
             UndirectedEdge[99, 306] -> 
             RGBColor[
              0.9742518584397497, 0.947471002545973, 0.6306628392778444], 
             UndirectedEdge[214, 261] -> 
             RGBColor[
              0.5816107316395323, 0.6466802864248125, 0.9229413951560062], 
             UndirectedEdge[21, 60] -> 
             RGBColor[
              0.33522274220732345`, 0.4647748233402267, 0.9425810746009868], 
             UndirectedEdge[60, 159] -> 
             RGBColor[
              0.344481468526375, 0.4727942667206735, 0.9431710324548666], 
             UndirectedEdge[9, 300] -> 
             RGBColor[
              0.8578321079350941, 0.3958398187210729, 0.2010677137447785], 
             UndirectedEdge[114, 369] -> 
             RGBColor[
              0.29316591487643506`, 0.4236050127700691, 0.9400748896075932], 
             UndirectedEdge[112, 350] -> 
             RGBColor[
              0.380831960891249, 0.5042792361782578, 0.945487253684878], 
             UndirectedEdge[18, 357] -> 
             RGBColor[
              0.8104483343258964, 0.8526146189392179, 0.9729726519131952], 
             UndirectedEdge[71, 320] -> 
             RGBColor[
              0.7905070166194959, 0.8366826699063725, 0.9796443291180839], 
             UndirectedEdge[226, 255] -> 
             RGBColor[
              0.24955450248561023`, 0.3796279831546734, 0.9375231317825289], 
             UndirectedEdge[208, 258] -> 
             RGBColor[
              0.24300998977440907`, 0.3727492853491289, 0.9371504314653649], 
             UndirectedEdge[11, 358] -> 
             RGBColor[
              0.9460196672175634, 0.8199629343977746, 0.2948506005623025], 
             UndirectedEdge[274, 299] -> 
             RGBColor[
              0.22242833776812287`, 0.35111666413841447`, 0.9359783368314325],
              UndirectedEdge[147, 372] -> 
             RGBColor[
              0.2681076692483716, 0.3991285377610505, 0.9385797071827175], 
             UndirectedEdge[335, 337] -> 
             RGBColor[
              0.282630755782611, 0.41439322252540617`, 0.9394067754758614], 
             UndirectedEdge[36, 218] -> 
             RGBColor[
              0.7148705349959443, 0.7760303162882036, 0.9733069680605333], 
             UndirectedEdge[262, 300] -> 
             RGBColor[
              0.9143198191766551, 0.7735717057130247, 0.6093343830407926], 
             UndirectedEdge[109, 136] -> 
             RGBColor[
              0.8063392816861509, 0.8465292984919313, 0.8553084156056971], 
             UndirectedEdge[219, 241] -> 
             RGBColor[
              0.36907489621161843`, 0.49245160059313714`, 0.9447983082263991],
              UndirectedEdge[37, 348] -> 
             RGBColor[
              0.2563773742968305, 0.38679925402332427`, 0.9379116842386436], 
             UndirectedEdge[291, 384] -> 
             RGBColor[
              0.7224597094549363, 0.7831102830141358, 0.9729716901347794], 
             UndirectedEdge[10, 241] -> 
             RGBColor[
              0.32644391245681637`, 0.4555267851602728, 0.9420818996386419], 
             UndirectedEdge[131, 314] -> 
             RGBColor[
              0.9241390802378358, 0.8369963141242439, 0.6246293196235244], 
             UndirectedEdge[1, 41] -> 
             RGBColor[
              0.3504016747423545, 0.4779220517867386, 0.943548262759916], 
             UndirectedEdge[78, 400] -> 
             RGBColor[
              0.6157274285874001, 0.4172598139869824, 0.5668748799123404], 
             UndirectedEdge[191, 357] -> 
             RGBColor[
              0.6772717325975683, 0.7478090920518159, 0.9684677749072899], 
             UndirectedEdge[215, 352] -> 
             RGBColor[
              0.906721166296464, 0.5695838616411621, 0.3855978109611532], 
             UndirectedEdge[96, 369] -> 
             RGBColor[
              0.27218271865818583`, 0.40341167306382075`, 0.9388117752181111],
              UndirectedEdge[212, 293] -> 
             RGBColor[
              0.2110641194014849, 0.3391721501020175, 0.935331161407307], 
             UndirectedEdge[66, 107] -> 
             RGBColor[
              0.906000283356856, 0.6111511383099929, 0.2669776426492963], 
             UndirectedEdge[146, 159] -> 
             RGBColor[
              0.433382915877228, 0.5475693804255631, 0.9494510398199664], 
             UndirectedEdge[11, 207] -> 
             RGBColor[
              0.931659240059644, 0.7667586905843885, 0.26386962426942273`], 
             UndirectedEdge[99, 218] -> 
             RGBColor[
              0.9440956875300477, 0.9571661739174645, 0.9565961673645738], 
             UndirectedEdge[131, 217] -> 
             RGBColor[
              0.8726459244985081, 0.4533824718485052, 0.21298193244244573`], 
             UndirectedEdge[81, 163] -> 
             RGBColor[
              0.23234434831161116`, 0.36153901993100174`, 0.9365430389624612],
              UndirectedEdge[50, 54] -> 
             RGBColor[
              0.4530695590105145, 0.5668252864420751, 0.9500963936878091], 
             UndirectedEdge[120, 286] -> 
             RGBColor[
              0.6463140971253603, 0.7224608247380875, 0.966177990499731], 
             UndirectedEdge[17, 253] -> 
             RGBColor[
              0.43861619159981363`, 0.5520971476660097, 0.9497858901980598], 
             UndirectedEdge[45, 365] -> 
             RGBColor[
              0.2758699057154388, 0.4072871404421556, 0.9390217550663172], 
             UndirectedEdge[35, 188] -> 
             RGBColor[
              0.27406348456255775`, 0.4053884772767613, 0.9389188820540213], 
             UndirectedEdge[99, 279] -> 
             RGBColor[
              0.9618886205302903, 0.9027170726846294, 0.5985175369470697], 
             UndirectedEdge[107, 363] -> 
             RGBColor[
              0.8508650866892753, 0.3855165088466559, 0.1960887969103411], 
             UndirectedEdge[105, 271] -> 
             RGBColor[
              0.36206599633926584`, 0.4878440595940245, 0.9442981318263466], 
             UndirectedEdge[191, 219] -> 
             RGBColor[
              0.5630206032370957, 0.6553990201614963, 0.9591704044347413], 
             UndirectedEdge[177, 339] -> 
             RGBColor[
              0.34383450141698674`, 0.4722338963280338, 0.9431298082827468], 
             UndirectedEdge[80, 167] -> 
             RGBColor[
              0.30898293281547473`, 0.43971762770278966`, 0.9409943949095109],
              UndirectedEdge[48, 56] -> 
             RGBColor[
              0.43818896314994105`, 0.5539589886879809, 0.9491419911499963], 
             UndirectedEdge[42, 136] -> 
             RGBColor[
              0.7754039881303256, 0.825013733522431, 0.9782569627328132], 
             UndirectedEdge[77, 102] -> 
             RGBColor[
              0.8243310697046711, 0.5080541422905515, 0.574849473505362], 
             UndirectedEdge[73, 203] -> 
             RGBColor[
              0.2672567761777972, 0.39823419519414005`, 0.9385312500811318], 
             UndirectedEdge[35, 284] -> 
             RGBColor[
              0.26251957032631373`, 0.3932550914880322, 0.9382614732159579], 
             UndirectedEdge[274, 367] -> 
             RGBColor[
              0.22502133411732347`, 0.3538420677068884, 0.9361260041375251], 
             UndirectedEdge[33, 310] -> 
             RGBColor[
              0.18075976862012855`, 0.3073203560239972, 0.9336053734615781], 
             UndirectedEdge[175, 295] -> 
             RGBColor[
              0.21065974573871524`, 0.33874712774367555`, 0.9353081329254295],
              UndirectedEdge[70, 75] -> 
             RGBColor[
              0.2609941288153654, 0.3916517557414475, 0.9381746015785979], 
             UndirectedEdge[57, 258] -> 
             RGBColor[
              0.26307034244570515`, 0.39383398790648194`, 0.9382928388733629],
              UndirectedEdge[70, 145] -> 
             RGBColor[
              0.2579170969731607, 0.3884176001802034, 0.937999369167245], 
             UndirectedEdge[12, 336] -> 
             RGBColor[
              0.21472177259901426`, 0.343016575521228, 0.9355394593458932], 
             UndirectedEdge[18, 216] -> 
             RGBColor[
              0.8021540700559975, 0.8461350766528297, 0.9721459571650781], 
             UndirectedEdge[158, 311] -> 
             RGBColor[
              0.5112449698673547, 0.6140907237185725, 0.9546662232614405], 
             UndirectedEdge[8, 36] -> 
             RGBColor[
              0.41499862525248465`, 0.5320708731128857, 0.9481621689265505], 
             UndirectedEdge[119, 200] -> 
             RGBColor[
              0.2555790109882331, 0.38596012356683096`, 0.9378662186292916], 
             UndirectedEdge[181, 362] -> 
             RGBColor[
              0.4859856594800335, 0.59226287242109, 0.9530427707548238], 
             UndirectedEdge[9, 306] -> 
             RGBColor[
              0.8980217768542582, 0.5550152880766823, 0.25581485333926096`], 
             UndirectedEdge[82, 253] -> 
             RGBColor[
              0.3604664667584644, 0.48663966875993736`, 0.9441895824072364], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.47490752561281135`, 0.5839962194337451, 0.9519697664459024], 
             UndirectedEdge[146, 314] -> 
             RGBColor[
              0.7305716091219763, 0.7886632000372383, 0.9746741748807553], 
             UndirectedEdge[27, 277] -> 
             RGBColor[
              0.277614773953709, 0.4091211075916136, 0.9391211227311855], 
             UndirectedEdge[6, 302] -> 
             RGBColor[
              0.9903122885265428, 0.9784619909329613, 0.461186699710061], 
             UndirectedEdge[93, 296] -> 
             RGBColor[
              0.27337982614775685`, 0.40466990893635857`, 0.9388799487186803],
              UndirectedEdge[153, 284] -> 
             RGBColor[
              0.2807144253547577, 0.4115760722752118, 0.9393270437921646], 
             UndirectedEdge[43, 199] -> 
             RGBColor[
              0.2266190062266405, 0.3555213223920431, 0.9362169892006067], 
             UndirectedEdge[213, 250] -> 
             RGBColor[
              0.9495976653580405, 0.8370624678097084, 0.5459950352795185], 
             UndirectedEdge[3, 232] -> 
             RGBColor[
              0.4478181508511241, 0.5603378585517222, 0.9502975085529524], 
             UndirectedEdge[5, 235] -> 
             RGBColor[
              0.7907683520113988, 0.8366469590661592, 0.9797340301887447], 
             UndirectedEdge[25, 391] -> 
             RGBColor[
              0.8345509525864179, 0.2665793386689794, 0.18071933725746053`], 
             UndirectedEdge[288, 341] -> 
             RGBColor[
              0.2333048519876323, 0.3625485701939505, 0.9365977382258728], 
             UndirectedEdge[181, 265] -> 
             RGBColor[
              0.5796034948121, 0.6695872537851715, 0.9600476567506184], 
             UndirectedEdge[295, 363] -> 
             RGBColor[
              0.5524499218387339, 0.42033901047071287`, 0.5720521832312901], 
             UndirectedEdge[278, 284] -> 
             RGBColor[
              0.24820685681048946`, 0.3782115221044505, 0.9374463853549939], 
             UndirectedEdge[167, 351] -> 
             RGBColor[
              0.2646469792533301, 0.39549113315584294`, 0.938382626007132], 
             UndirectedEdge[198, 311] -> 
             RGBColor[
              0.6729318339898602, 0.7425873401033549, 0.9693093430316602], 
             UndirectedEdge[54, 328] -> 
             RGBColor[
              0.38071433549214345`, 0.504177354969577, 0.9454797586984591], 
             UndirectedEdge[261, 310] -> 
             RGBColor[
              0.18101326007132248`, 0.3075867916114884, 0.9336198094247166], 
             UndirectedEdge[68, 319] -> 
             RGBColor[
              0.2591541477712746, 0.38971781900257185`, 0.9380698173801449], 
             UndirectedEdge[100, 141] -> 
             RGBColor[
              0.3683390164516885, 0.49345847561835543`, 0.9446912143122663], 
             UndirectedEdge[139, 325] -> 
             RGBColor[
              0.21136919529828035`, 0.33949280421247857`, 0.9353485350283102],
              UndirectedEdge[123, 338] -> 
             RGBColor[
              0.9842922541931751, 0.9852712070496027, 0.7740485310892328], 
             UndirectedEdge[317, 370] -> 
             RGBColor[
              0.9109218435003366, 0.9293228266692952, 0.8943803638429948], 
             UndirectedEdge[160, 400] -> 
             RGBColor[
              0.6095442446912597, 0.3697331530727862, 0.5609538560304888], 
             UndirectedEdge[150, 266] -> 
             RGBColor[
              0.2627993543398047, 0.39354916222554226`, 0.9382774065016228], 
             UndirectedEdge[134, 201] -> 
             RGBColor[
              0.255376576823433, 0.3857473524245587, 0.9378546903030808], 
             UndirectedEdge[161, 251] -> 
             RGBColor[
              0.6268762447587527, 0.7046334098478555, 0.9658130763902817], 
             UndirectedEdge[86, 371] -> 
             RGBColor[
              0.2862909803459218, 0.418240350613087, 0.9396152198499249], 
             UndirectedEdge[105, 350] -> 
             RGBColor[
              0.4250434301807523, 0.5425729887437677, 0.948304369413338], 
             UndirectedEdge[54, 362] -> 
             RGBColor[
              0.4283252562737149, 0.5454155415561164, 0.9485134844699766], 
             UndirectedEdge[4, 208] -> 
             RGBColor[
              0.23264160776787357`, 0.36185145846687167`, 0.9365599674487393],
              UndirectedEdge[176, 294] -> 
             RGBColor[
              0.21429151975408078`, 0.34256435250159695`, 0.9355149570828762],
              UndirectedEdge[113, 170] -> 
             RGBColor[
              0.6207426403130438, 0.7003977045332692, 0.9649634716556403], 
             UndirectedEdge[14, 205] -> 
             RGBColor[
              0.9948127950472943, 0.9913250536932577, 0.6776287249236647], 
             UndirectedEdge[262, 306] -> 
             RGBColor[
              0.9545094880958191, 0.9327471750686342, 0.664081522635275], 
             UndirectedEdge[47, 128] -> 
             RGBColor[
              0.3800525355791988, 0.5036041371480152, 0.945437589393213], 
             UndirectedEdge[257, 382] -> 
             RGBColor[
              0.8606940459931985, 0.4040219113453448, 0.20326730826890227`], 
             UndirectedEdge[165, 228] -> 
             RGBColor[
              0.4503029757321284, 0.5622948057743279, 0.9505097967266875], 
             UndirectedEdge[72, 341] -> 
             RGBColor[
              0.22465511090045148`, 0.353457143886063, 0.936105148267103], 
             UndirectedEdge[50, 116] -> 
             RGBColor[
              0.4351844866677396, 0.551334135708637, 0.9489567726932759], 
             UndirectedEdge[230, 247] -> 
             RGBColor[
              0.9379323861994966, 0.7878165939520326, 0.28877547346743154`], 
             UndirectedEdge[45, 100] -> 
             RGBColor[
              0.33605658973236274`, 0.46427229317936647`, 0.9426790513466246],
              UndirectedEdge[95, 386] -> 
             RGBColor[
              0.3105708355384495, 0.4409292540045774, 0.9411015698156122], 
             UndirectedEdge[182, 244] -> 
             RGBColor[
              0.27406524356197104`, 0.4053903260966717, 0.9389189822264357], 
             UndirectedEdge[104, 382] -> 
             RGBColor[
              0.9163275048198573, 0.7044047275562138, 0.25145220082553266`], 
             UndirectedEdge[58, 210] -> 
             RGBColor[
              0.2993673513669953, 0.4319844456460439, 0.9403598998348177], 
             UndirectedEdge[102, 370] -> 
             RGBColor[
              0.8252568296209774, 0.5087923181187306, 0.5749377733126149], 
             UndirectedEdge[1, 161] -> 
             RGBColor[
              0.3957098398241182, 0.5171657071259712, 0.9464352589744887], 
             UndirectedEdge[153, 356] -> 
             RGBColor[
              0.4179045828513193, 0.5346231354649491, 0.9483375893388631], 
             UndirectedEdge[1, 154] -> 
             RGBColor[
              0.39507053133992803`, 0.5166119702495444, 0.9463945228031945], 
             UndirectedEdge[341, 399] -> 
             RGBColor[
              0.22823136465623345`, 0.3572160133309742, 0.9363088106279014], 
             UndirectedEdge[373, 395] -> 
             RGBColor[
              0.2616949498810116, 0.3923883631160637, 0.9382145123015146], 
             UndirectedEdge[190, 266] -> 
             RGBColor[
              0.24805045871485498`, 0.3780471377897267, 0.9374374787148178], 
             UndirectedEdge[73, 85] -> 
             RGBColor[
              0.24221172142071856`, 0.3719102546962633, 0.9371049712635544], 
             UndirectedEdge[221, 250] -> 
             RGBColor[
              0.955043066437527, 0.9649644792718597, 0.9185889663100797], 
             UndirectedEdge[23, 353] -> 
             RGBColor[
              0.21189878814995255`, 0.34004943987771225`, 0.9353786945577505],
              UndirectedEdge[171, 270] -> 
             RGBColor[
              0.2613998670743656, 0.3920782123769482, 0.9381977077722119], 
             UndirectedEdge[277, 396] -> 
             RGBColor[
              0.26805617252313807`, 0.399074411437749, 0.9385767745203981], 
             UndirectedEdge[315, 371] -> 
             RGBColor[
              0.25765991596594773`, 0.388147286635405, 0.9379847230893494], 
             UndirectedEdge[207, 391] -> 
             RGBColor[
              0.8801233042529734, 0.4784967588439868, 0.2188121666480132], 
             UndirectedEdge[160, 247] -> 
             RGBColor[
              0.8682425607038025, 0.44830305029724704`, 0.2099476795487854], 
             UndirectedEdge[193, 232] -> 
             RGBColor[
              0.6739481277148399, 0.7434424430617759, 0.9693547854990241], 
             UndirectedEdge[22, 91] -> 
             RGBColor[
              0.2774698045998931, 0.40896873560916513`, 0.9391128669409485], 
             UndirectedEdge[78, 247] -> 
             RGBColor[
              0.874425744599943, 0.49582971121144337`, 0.21586870343063702`], 
             UndirectedEdge[87, 192] -> 
             RGBColor[
              0.3173142304637505, 0.44754300010990244`, 0.9415029512587653], 
             UndirectedEdge[226, 294] -> 
             RGBColor[
              0.22569678935260098`, 0.35455201398550057`, 0.9361644703139277],
              UndirectedEdge[177, 311] -> 
             RGBColor[
              0.42064126980492156`, 0.5369664823599833, 0.9485194381294991], 
             UndirectedEdge[189, 200] -> 
             RGBColor[
              0.28560319899075254`, 0.41751744880094743`, 0.9395760517192293],
              UndirectedEdge[67, 184] -> 
             RGBColor[
              0.2153543932680198, 0.3436814999548199, 0.9355754861571146], 
             UndirectedEdge[33, 256] -> 
             RGBColor[
              0.202124876078153, 0.3297764385884332, 0.9348220847244686], 
             UndirectedEdge[176, 226] -> 
             RGBColor[
              0.22722875741095702`, 0.3561622095472178, 0.9362517136285073], 
             UndirectedEdge[145, 162] -> 
             RGBColor[
              0.2420540274215789, 0.3717445083047905, 0.9370959908235907], 
             UndirectedEdge[286, 343] -> 
             RGBColor[
              0.7242252260804207, 0.7844895180203877, 0.9731476603323168], 
             UndirectedEdge[13, 18] -> 
             RGBColor[
              0.9544933475167275, 0.9655817936050558, 0.9619150720050708], 
             UndirectedEdge[86, 308] -> 
             RGBColor[
              0.28081236703944734`, 0.4124819806638359, 0.9393032209270034], 
             UndirectedEdge[364, 377] -> 
             RGBColor[
              0.3822045767059832, 0.5054681270073037, 0.9455747155508364], 
             UndirectedEdge[90, 152] -> 
             RGBColor[
              0.4447109838202162, 0.5402113672268555, 0.9525399126533038], 
             UndirectedEdge[1, 153] -> 
             RGBColor[
              0.33870689706262624`, 0.4677926231571751, 0.9428030818674495], 
             UndirectedEdge[92, 114] -> 
             RGBColor[
              0.3082708613262549, 0.43948126919774927`, 0.9409350939621447], 
             UndirectedEdge[132, 219] -> 
             RGBColor[
              0.6232051027562657, 0.7024156086050097, 0.9651690328906872], 
             UndirectedEdge[107, 215] -> 
             RGBColor[
              0.829252938362637, 0.22585647974036333`, 0.17564595285351675`], 
             UndirectedEdge[240, 319] -> 
             RGBColor[
              0.24039509168830792`, 0.37000086166652213`, 0.9370015168877566],
              UndirectedEdge[58, 110] -> 
             RGBColor[
              0.2771944683256158, 0.40867933972757164`, 0.939097186947452], 
             UndirectedEdge[67, 85] -> 
             RGBColor[
              0.22712666696496037`, 0.35605490601556716`, 0.9362458997286371],
              UndirectedEdge[125, 344] -> 
             RGBColor[
              0.2993073040655987, 0.4308227000023955, 0.9403967065336283], 
             UndirectedEdge[198, 219] -> 
             RGBColor[
              0.6368387366010516, 0.7131188895622445, 0.9665139522992866], 
             UndirectedEdge[16, 325] -> 
             RGBColor[
              0.22671411419860138`, 0.35562128690076766`, 0.9362224054589102],
              UndirectedEdge[119, 390] -> 
             RGBColor[
              0.2533988208527428, 0.3836686055023921, 0.9377420600263777], 
             UndirectedEdge[7, 153] -> 
             RGBColor[
              0.3534178774592668, 0.48053453498137155`, 0.9437404525299142], 
             UndirectedEdge[23, 164] -> 
             RGBColor[
              0.22797821780387265`, 0.3569499399387055, 0.9362943942891566], 
             UndirectedEdge[46, 373] -> 
             RGBColor[
              0.26731905714517273`, 0.3982996564396932, 0.9385347968900875], 
             UndirectedEdge[301, 316] -> 
             RGBColor[
              0.2555487063727525, 0.3859282714945373, 0.9378644928262717], 
             UndirectedEdge[22, 150] -> 
             RGBColor[
              0.28145958694833023`, 0.41316224982418415`, 0.9393400791433381],
              UndirectedEdge[161, 327] -> 
             RGBColor[
              0.3750143899762539, 0.4992403486513052, 0.9451165632104506], 
             UndirectedEdge[123, 281] -> 
             RGBColor[
              0.8031450913153519, 0.8462354724290008, 0.9462830761380823], 
             UndirectedEdge[111, 160] -> 
             RGBColor[
              0.8517778667942718, 0.37434165466445646`, 0.19625056684916897`],
              UndirectedEdge[277, 287] -> 
             RGBColor[
              0.25901311175833214`, 0.3895695812107696, 0.9380617855878519], 
             UndirectedEdge[48, 120] -> 
             RGBColor[
              0.49591060473188847`, 0.6008847208403402, 0.9536681725336434], 
             UndirectedEdge[6, 224] -> 
             RGBColor[
              0.9845045256450395, 0.9588710430060774, 0.43862463761941295`], 
             UndirectedEdge[103, 313] -> 
             RGBColor[
              0.31368725505562867`, 0.4437237541060531, 0.9412966590550009], 
             UndirectedEdge[8, 60] -> 
             RGBColor[
              0.33392414851101215`, 0.4636500467496988, 0.9424983293589592], 
             UndirectedEdge[284, 392] -> 
             RGBColor[
              0.24597365109495675`, 0.3758642813040053, 0.9373192075932261], 
             UndirectedEdge[218, 279] -> 
             RGBColor[
              0.9278567069516805, 0.8766750653657154, 0.6332052588371474], 
             UndirectedEdge[135, 221] -> 
             RGBColor[
              0.7125684826637311, 0.7740760557086418, 0.9732239792621271], 
             UndirectedEdge[95, 309] -> 
             RGBColor[
              0.2762844897757238, 0.4077228945756627, 0.9390453650152284], 
             UndirectedEdge[80, 385] -> 
             RGBColor[
              0.4549187217473041, 0.5651340807695402, 0.9511240470387816], 
             UndirectedEdge[272, 398] -> 
             RGBColor[
              0.7932211653132651, 0.8392589768677534, 0.976436715616906], 
             UndirectedEdge[33, 264] -> 
             RGBColor[
              0.18448620056776344`, 0.31123707227039327`, 0.9338175882482339],
              UndirectedEdge[76, 366] -> 
             RGBColor[
              0.8741124408312237, 0.5032302339331254, 0.2159628369001264], 
             UndirectedEdge[41, 258] -> 
             RGBColor[
              0.29687678880049106`, 0.4264012168061446, 0.9403266470848042], 
             UndirectedEdge[174, 232] -> 
             RGBColor[
              0.6270810139261389, 0.7068104580353534, 0.9646885621008761], 
             UndirectedEdge[61, 307] -> 
             RGBColor[
              0.9892929392100926, 0.9881701251038566, 0.7056981044009731], 
             UndirectedEdge[35, 392] -> 
             RGBColor[
              0.2644951314363644, 0.3953315314725043, 0.9383739784985945], 
             UndirectedEdge[212, 259] -> 
             RGBColor[
              0.2109589325174653, 0.33906159201767927`, 0.935325171169872], 
             UndirectedEdge[73, 110] -> 
             RGBColor[
              0.24934696023893294`, 0.3794098430944771, 0.9375113125586119], 
             UndirectedEdge[122, 228] -> 
             RGBColor[
              0.40697238168033323`, 0.5269207548100117, 0.9471528981824919], 
             UndirectedEdge[41, 203] -> 
             RGBColor[
              0.31610894590117855`, 0.4466154333081559, 0.9414218899802616], 
             UndirectedEdge[361, 385] -> 
             RGBColor[
              0.46552378312677223`, 0.5743196519105522, 0.9517997921721937], 
             UndirectedEdge[9, 269] -> 
             RGBColor[
              0.909363183463878, 0.5929294140972693, 0.329048956685827], 
             UndirectedEdge[192, 228] -> 
             RGBColor[
              0.35617346073846823`, 0.48292128271817314`, 0.9439160358597984],
              UndirectedEdge[47, 265] -> 
             RGBColor[
              0.5128933077983199, 0.6149014550415344, 0.9549417262439694], 
             UndirectedEdge[338, 398] -> 
             RGBColor[
              0.966856888277283, 0.9722679396973218, 0.803562057713115], 
             UndirectedEdge[71, 79] -> 
             RGBColor[
              0.730962985173496, 0.7893766931257962, 0.9742494771038676], 
             UndirectedEdge[77, 78] -> 
             RGBColor[
              0.8356045267952863, 0.5947068735494174, 0.5856449487468838], 
             UndirectedEdge[89, 164] -> 
             RGBColor[
              0.2305606666537099, 0.3596642574165986, 0.9364414609307642], 
             UndirectedEdge[123, 235] -> 
             RGBColor[
              0.8571949059772741, 0.8886183762780113, 0.9515616992620775], 
             UndirectedEdge[72, 393] -> 
             RGBColor[
              0.22527325394479547`, 0.3541068514182011, 0.9361403505990177], 
             UndirectedEdge[240, 371] -> 
             RGBColor[
              0.2556260580342823, 0.3860095729951837, 0.9378688978889642], 
             UndirectedEdge[196, 303] -> 
             RGBColor[
              0.29376792821553643`, 0.42609909688992764`, 0.9400410209699464],
              UndirectedEdge[105, 170] -> 
             RGBColor[
              0.4311568725166687, 0.5478681452245924, 0.9486939125530778], 
             UndirectedEdge[195, 208] -> 
             RGBColor[
              0.239390712068561, 0.3689451950048222, 0.9369443189542583], 
             UndirectedEdge[100, 180] -> 
             RGBColor[
              0.3714420538172285, 0.49614617062119337`, 0.9448889371092903], 
             UndirectedEdge[39, 355] -> 
             RGBColor[
              0.25200661552040216`, 0.3822053094271858, 0.9376627759922841], 
             UndirectedEdge[244, 397] -> 
             RGBColor[
              0.2546928621186111, 0.3850287249197748, 0.9378157537621064], 
             UndirectedEdge[225, 355] -> 
             RGBColor[
              0.24401463577453056`, 0.373805231993492, 0.9372076445688313], 
             UndirectedEdge[335, 354] -> 
             RGBColor[
              0.28014580760645524`, 0.41178138443745216`, 0.9392652613533807],
              UndirectedEdge[97, 100] -> 
             RGBColor[
              0.4094492665548738, 0.5290661079964851, 0.9473107230964745], 
             UndirectedEdge[2, 107] -> 
             RGBColor[
              0.828834437069773, 0.222639695414975, 0.17524519554284063`], 
             UndirectedEdge[128, 225] -> 
             RGBColor[
              0.2916606290262991, 0.42226923419395845`, 0.939980144908767], 
             UndirectedEdge[96, 228] -> 
             RGBColor[
              0.3273843328541551, 0.4559668373403135, 0.9421555344070691], 
             UndirectedEdge[262, 307] -> 
             RGBColor[
              0.9619414175862754, 0.970962445386637, 0.9415105792405329], 
             UndirectedEdge[86, 334] -> 
             RGBColor[
              0.28096769579564274`, 0.4126452410350092, 0.9393120666698803], 
             UndirectedEdge[255, 399] -> 
             RGBColor[
              0.24767699728620676`, 0.3776546061493952, 0.937416210638943], 
             UndirectedEdge[138, 242] -> 
             RGBColor[
              0.8688448581678534, 0.4318314305529642, 0.2096571104877158], 
             UndirectedEdge[27, 396] -> 
             RGBColor[
              0.28785811658992677`, 0.419887510167713, 0.9397044659406507], 
             UndirectedEdge[163, 209] -> 
             RGBColor[
              0.2485031193706023, 0.3785229128392603, 0.9374632570695112], 
             UndirectedEdge[63, 202] -> 
             RGBColor[
              0.9074503393274316, 0.6529677356997123, 0.2475510699614376], 
             UndirectedEdge[347, 372] -> 
             RGBColor[
              0.26576379522245486`, 0.3966649775496154, 0.9384462270243925], 
             UndirectedEdge[174, 275] -> 
             RGBColor[
              0.8603530123804088, 0.8894563784374243, 0.877080294609712], 
             UndirectedEdge[209, 315] -> 
             RGBColor[
              0.24765360770529532`, 0.37763002221687225`, 0.9374148786369118],
              UndirectedEdge[177, 374] -> 
             RGBColor[
              0.29900611365793894`, 0.43038779878246913`, 0.9403838868632315],
              UndirectedEdge[214, 215] -> 
             RGBColor[
              0.9015306453673441, 0.5683408458182889, 0.5392279021919928], 
             UndirectedEdge[160, 185] -> 
             RGBColor[
              0.8265840327508944, 0.20534210168661424`, 0.17309020582561438`],
              UndirectedEdge[63, 268] -> 
             RGBColor[
              0.8879400264016856, 0.5030029210787892, 0.2288679722699964], 
             UndirectedEdge[48, 196] -> 
             RGBColor[
              0.3616835055171287, 0.4866932494532377, 0.9443037663378753], 
             UndirectedEdge[34, 95] -> 
             RGBColor[
              0.29703377047989377`, 0.4292041286435296, 0.9402390000004376], 
             UndirectedEdge[84, 333] -> 
             RGBColor[
              0.18724373492288626`, 0.3141354157154036, 0.9339746257503516], 
             UndirectedEdge[102, 224] -> 
             RGBColor[
              0.8974792718626248, 0.5394468704448865, 0.26303107700793477`], 
             UndirectedEdge[105, 326] -> 
             RGBColor[
              0.37836717266856673`, 0.5021443605036287, 0.9453301995588554], 
             UndirectedEdge[134, 236] -> 
             RGBColor[
              0.24242453355158805`, 0.3721339337388756, 0.9371170905995801], 
             UndirectedEdge[92, 161] -> 
             RGBColor[
              0.35955024405905767`, 0.48389689314418627`, 0.9442025708853012],
              UndirectedEdge[77, 185] -> 
             RGBColor[
              0.8265277938578538, 0.5249391267425765, 0.5769530590352949], 
             UndirectedEdge[178, 329] -> 
             RGBColor[
              0.23956363455757862`, 0.36912694750469877`, 0.9369541666341921],
              UndirectedEdge[185, 400] -> 
             RGBColor[
              0.6066506956499677, 0.3474920671801415, 0.5581829902007515], 
             UndirectedEdge[317, 333] -> 
             RGBColor[
              0.5930937593564782, 0.6566344401985723, 0.8697228003417041], 
             UndirectedEdge[106, 215] -> 
             RGBColor[
              0.8838915069303948, 0.5551856052534505, 0.5690863625416396], 
             UndirectedEdge[14, 340] -> 
             RGBColor[
              0.9940676030184292, 0.9897195276507893, 0.5956733829454577], 
             UndirectedEdge[233, 358] -> 
             RGBColor[
              0.8930174526264201, 0.5204305413924555, 0.24838903272095686`], 
             UndirectedEdge[74, 191] -> 
             RGBColor[
              0.7517634193974077, 0.8060404672296411, 0.9758823517148281], 
             UndirectedEdge[53, 244] -> 
             RGBColor[
              0.27464006789181306`, 0.4059945029133032, 0.9389517176216438], 
             UndirectedEdge[4, 16] -> 
             RGBColor[
              0.23702850407735238`, 0.36646236463342485`, 0.9368097947037326],
              UndirectedEdge[149, 274] -> 
             RGBColor[
              0.22547330397154366`, 0.35431711668021776`, 0.9361517431520935],
              UndirectedEdge[326, 335] -> 
             RGBColor[
              0.3099542075105004, 0.4402786337315509, 0.9410665454863245], 
             UndirectedEdge[30, 77] -> 
             RGBColor[
              0.5041460680446381, 0.5860856357063153, 0.9585438899509009], 
             UndirectedEdge[129, 229] -> 
             RGBColor[
              0.24229031603850887`, 0.3719928626227475, 0.9371094471107673], 
             UndirectedEdge[216, 219] -> 
             RGBColor[
              0.5531447091768378, 0.647683896662048, 0.958186067610292], 
             UndirectedEdge[138, 233] -> 
             RGBColor[
              0.8184005545424529, 0.14244030215351539`, 0.165253697851294], 
             UndirectedEdge[28, 44] -> 
             RGBColor[
              0.29312282823703784`, 0.42542105591082463`, 0.9400042834805107],
              UndirectedEdge[163, 227] -> 
             RGBColor[
              0.23994763052693538`, 0.3695305516152434, 0.9369760346365759], 
             UndirectedEdge[15, 335] -> 
             RGBColor[
              0.2921895478533735, 0.4244401190541993, 0.9399511345433256], 
             UndirectedEdge[257, 268] -> 
             RGBColor[
              0.8199630848530925, 0.15445059482623982`, 0.16674997864138813`],
              UndirectedEdge[217, 279] -> 
             RGBColor[
              0.8842376547290044, 0.4993398194973086, 0.22230891067878217`], 
             UndirectedEdge[93, 119] -> 
             RGBColor[
              0.24286823945996167`, 0.3726002967811557, 0.9371423589946579], 
             UndirectedEdge[67, 305] -> 
             RGBColor[
              0.20792423756527648`, 0.33587193521215575`, 0.9351523497817738],
              UndirectedEdge[153, 195] -> 
             RGBColor[
              0.2815627334149148, 0.41246769783227444`, 0.9393753536812313], 
             UndirectedEdge[50, 135] -> 
             RGBColor[
              0.478712840814817, 0.5876796757980098, 0.9521051748933094], 
             UndirectedEdge[68, 334] -> 
             RGBColor[
              0.2690618295669699, 0.40013142075315566`, 0.938634045201308], 
             UndirectedEdge[95, 308] -> 
             RGBColor[
              0.2714334547461428, 0.4026241491861876, 0.9387691057467569], 
             UndirectedEdge[17, 36] -> 
             RGBColor[
              0.5275969503288876, 0.6273659981055699, 0.9559535110626505], 
             UndirectedEdge[41, 361] -> 
             RGBColor[
              0.34822341852427197`, 0.4760353557329764, 0.9434094661998561], 
             UndirectedEdge[117, 371] -> 
             RGBColor[
              0.31078136056287864`, 0.44021172480761495`, 0.9411479331302521],
              UndirectedEdge[89, 304] -> 
             RGBColor[
              0.21884062978169738`, 0.3473457555708567, 0.9357740221691438], 
             UndirectedEdge[267, 272] -> 
             RGBColor[
              0.6091079366672787, 0.6934689353256587, 0.9624191392814057], 
             UndirectedEdge[20, 158] -> 
             RGBColor[
              0.4553874406509526, 0.5675033157176284, 0.9506114604100135], 
             UndirectedEdge[30, 62] -> 
             RGBColor[
              0.17899764558147852`, 0.30546825298532254`, 0.9335050231613544],
              UndirectedEdge[197, 310] -> 
             RGBColor[
              0.5856647922314719, 0.6494240169162264, 0.8848951542933734], 
             UndirectedEdge[142, 268] -> 
             RGBColor[
              0.8194514867475214, 0.1505182276031009, 0.16626007171772583`], 
             UndirectedEdge[78, 213] -> 
             RGBColor[
              0.8764060316711535, 0.5036808895572449, 0.2174620888914447], 
             UndirectedEdge[48, 71] -> 
             RGBColor[
              0.6482814539995922, 0.7214952269023049, 0.9679496107647267], 
             UndirectedEdge[262, 269] -> 
             RGBColor[
              0.965850894705439, 0.9706613010892211, 0.7373156259818411], 
             UndirectedEdge[27, 376] -> 
             RGBColor[
              0.3679050083022842, 0.49203509004620194`, 0.9447019126873052], 
             UndirectedEdge[245, 292] -> 
             RGBColor[
              0.2204587636622521, 0.3490465168749334, 0.935866172499827], 
             UndirectedEdge[142, 217] -> 
             RGBColor[
              0.8222048215005642, 0.17168156503396934`, 0.16889666818668636`],
              UndirectedEdge[142, 363] -> 
             RGBColor[
              0.8420482335881154, 0.3177463123414773, 0.18764576842345915`], 
             UndirectedEdge[121, 130] -> 
             RGBColor[
              0.48180086572832803`, 0.5890215010044231, 0.9526702161686205], 
             UndirectedEdge[217, 300] -> 
             RGBColor[
              0.8564112237192996, 0.3849182800030426, 0.19970707341507446`], 
             UndirectedEdge[25, 109] -> 
             RGBColor[
              0.9214037823681839, 0.6836236479949891, 0.47088987975905927`], 
             UndirectedEdge[40, 146] -> 
             RGBColor[
              0.43732168419070216`, 0.5509809435704429, 0.9497020146539848], 
             UndirectedEdge[18, 140] -> 
             RGBColor[
              0.8085657806265083, 0.8511439536813179, 0.9727850165539047], 
             UndirectedEdge[170, 239] -> 
             RGBColor[
              0.38474227729381244`, 0.5076661557079413, 0.9457364155882924], 
             UndirectedEdge[152, 333] -> 
             RGBColor[
              0.18958831081692415`, 0.31659971363473505`, 0.9341081458790279],
              UndirectedEdge[14, 250] -> 
             RGBColor[
              0.99129214736786, 0.9898691754012934, 0.7359749681160213], 
             UndirectedEdge[55, 159] -> 
             RGBColor[
              0.36748362390558187`, 0.49271757758819734`, 0.9446367094556223],
              UndirectedEdge[234, 331] -> 
             RGBColor[
              0.3954159318032815, 0.5169111387705692, 0.9464165314152937], 
             UndirectedEdge[370, 389] -> 
             RGBColor[
              0.505152375234491, 0.5869084718259839, 0.9586367768062234], 
             UndirectedEdge[119, 316] -> 
             RGBColor[
              0.24738893708713797`, 0.3773518366161024, 0.9373998060367528], 
             UndirectedEdge[89, 227] -> 
             RGBColor[
              0.22675241851123462`, 0.35566154716197895`, 0.9362245868328485],
              UndirectedEdge[246, 254] -> 
             RGBColor[
              0.4566571232556863, 0.569515492226385, 0.9504402532261262], 
             UndirectedEdge[197, 345] -> 
             RGBColor[
              0.5953494141792219, 0.6596031686238084, 0.8854466791861835], 
             UndirectedEdge[231, 234] -> 
             RGBColor[
              0.3237117587462526, 0.454798867157554, 0.9418478143825956], 
             UndirectedEdge[89, 209] -> 
             RGBColor[
              0.23530790735490154`, 0.3646539083859959, 0.9367118092657838], 
             UndirectedEdge[233, 317] -> 
             RGBColor[
              0.9040426479180714, 0.5627946336685001, 0.48467433968140694`], 
             UndirectedEdge[48, 342] -> 
             RGBColor[
              0.5144005472567488, 0.6158956891444403, 0.9551237685400916], 
             UndirectedEdge[24, 104] -> 
             RGBColor[
              0.9180135558932775, 0.712060691693382, 0.25285908317008815`], 
             UndirectedEdge[118, 149] -> 
             RGBColor[
              0.21314012851733694`, 0.34135416730935836`, 0.9354493870552745],
              UndirectedEdge[34, 53] -> 
             RGBColor[
              0.30076648553276153`, 0.4331274488318972, 0.9404515726006413], 
             UndirectedEdge[29, 45] -> 
             RGBColor[
              0.26796415172899, 0.39897769174864406`, 0.938571534072304], 
             UndirectedEdge[35, 208] -> 
             RGBColor[
              0.25706388434981153`, 0.3875208196162586, 0.9379507799705602], 
             UndirectedEdge[69, 191] -> 
             RGBColor[
              0.5835359920161374, 0.6722207850854224, 0.9607394608823273], 
             UndirectedEdge[102, 166] -> 
             RGBColor[
              0.8220330696681408, 0.1703614051878311, 0.16873219843799186`], 
             UndirectedEdge[185, 213] -> 
             RGBColor[
              0.8673292987337209, 0.4339131427504039, 0.20877019917985573`], 
             UndirectedEdge[172, 364] -> 
             RGBColor[
              0.3254772137216906, 0.45565682861361634`, 0.9419848830531403], 
             UndirectedEdge[36, 55] -> 
             RGBColor[
              0.46160497467818506`, 0.5724389504821938, 0.9511318842995795], 
             UndirectedEdge[192, 203] -> 
             RGBColor[
              0.31794365991620344`, 0.4482045703725628, 0.9415387963349251], 
             UndirectedEdge[105, 394] -> 
             RGBColor[
              0.38810603050507936`, 0.5105796696723884, 0.9459507509684641], 
             UndirectedEdge[256, 261] -> 
             RGBColor[
              0.20237836752934693`, 0.3300428741759244, 0.934836520687607], 
             UndirectedEdge[215, 295] -> 
             RGBColor[
              0.5308377735120957, 0.2606789813644203, 0.5516093391744658], 
             UndirectedEdge[219, 357] -> 
             RGBColor[
              0.5614389734467367, 0.6541634389484363, 0.9590127623584092], 
             UndirectedEdge[204, 295] -> 
             RGBColor[
              0.21065717499813985`, 0.33874442573233643`, 0.9353079865255567],
              UndirectedEdge[24, 138] -> 
             RGBColor[
              0.8607479504188854, 0.399132481136813, 0.2031112451403423], 
             UndirectedEdge[135, 376] -> 
             RGBColor[
              0.47083567399736015`, 0.5808793962784845, 0.9515970246612349], 
             UndirectedEdge[127, 305] -> 
             RGBColor[
              0.20669916269368893`, 0.33458430384788407`, 0.9350825835801727],
              UndirectedEdge[54, 158] -> 
             RGBColor[
              0.4775536933364365, 0.5867026096855403, 0.9520238744302849], 
             UndirectedEdge[180, 350] -> 
             RGBColor[
              0.3995063863984757, 0.5204540849487005, 0.9466771715650524], 
             UndirectedEdge[46, 287] -> 
             RGBColor[
              0.27226485336384204`, 0.4034980018471065, 0.9388164526680909], 
             UndirectedEdge[41, 153] -> 
             RGBColor[
              0.32912553840433756`, 0.45949373186045395`, 0.9421925661662062],
              UndirectedEdge[163, 315] -> 
             RGBColor[
              0.24412373790812583`, 0.3739199052533755, 0.9372138577739373], 
             UndirectedEdge[17, 64] -> 
             RGBColor[
              0.46723843843845614`, 0.5768882992816866, 0.951609674456959], 
             UndirectedEdge[67, 127] -> 
             RGBColor[
              0.21172079285419906`, 0.33986235553632177`, 0.9353685579889777],
              UndirectedEdge[83, 246] -> 
             RGBColor[
              0.39834226268445083`, 0.5194457794981713, 0.946602994631389], 
             UndirectedEdge[44, 383] -> 
             RGBColor[
              0.28909643467092216`, 0.42118906098474024`, 0.9397749863234359],
              UndirectedEdge[5, 275] -> 
             RGBColor[
              0.916771833602923, 0.9337046356973782, 0.882657568389807], 
             UndirectedEdge[99, 123] -> 
             RGBColor[
              0.9762118677425246, 0.9817794304286422, 0.9251512823600752], 
             UndirectedEdge[278, 354] -> 
             RGBColor[
              0.2660945297513849, 0.3970126005093012, 0.9384650618665371], 
             UndirectedEdge[61, 215] -> 
             RGBColor[
              0.9063170503481712, 0.5687194984901538, 0.341612283904028], 
             UndirectedEdge[115, 208] -> 
             RGBColor[
              0.2358464087925902, 0.36521990753996986`, 0.9367424761260187], 
             UndirectedEdge[167, 203] -> 
             RGBColor[
              0.2874735215718495, 0.4194832764189812, 0.9396825638233285], 
             UndirectedEdge[242, 256] -> 
             RGBColor[
              0.5718276027056971, 0.5340616080097416, 0.5946502523941279], 
             UndirectedEdge[136, 254] -> 
             RGBColor[
              0.5440467518592814, 0.6407206880430576, 0.9572484996967315], 
             UndirectedEdge[65, 170] -> 
             RGBColor[
              0.4801509107444425, 0.5886204880785566, 0.952281016742329], 
             UndirectedEdge[247, 340] -> 
             RGBColor[
              0.9503928339373993, 0.8290616417134029, 0.4041000646481473], 
             UndirectedEdge[8, 17] -> 
             RGBColor[
              0.42291827954092154`, 0.5385004052405986, 0.9487856331227857], 
             UndirectedEdge[269, 300] -> 
             RGBColor[
              0.9415278534612976, 0.7904724805205449, 0.35790419683327634`], 
             UndirectedEdge[233, 242] -> 
             RGBColor[
              0.867902536299588, 0.4245883317454004, 0.20875474200246447`], 
             UndirectedEdge[242, 382] -> 
             RGBColor[
              0.9085638811026002, 0.6736245465915296, 0.24520540694695725`], 
             UndirectedEdge[144, 242] -> 
             RGBColor[
              0.8983924729381163, 0.6274385577093406, 0.23671813465048305`], 
             UndirectedEdge[81, 227] -> 
             RGBColor[
              0.2273187292651137, 0.35625677567048153`, 0.9362568373925002], 
             UndirectedEdge[224, 230] -> 
             RGBColor[
              0.9722593705527938, 0.9180864844443417, 0.3467333222862512], 
             UndirectedEdge[81, 248] -> 
             RGBColor[
              0.21796166804011632`, 0.3464219110510618, 0.9357239665982682], 
             UndirectedEdge[13, 323] -> 
             RGBColor[
              0.8969951869704291, 0.9199794950758233, 0.9649311806841149], 
             UndirectedEdge[10, 189] -> 
             RGBColor[
              0.3312363099818102, 0.46056389881459425`, 0.9423548195879734], 
             UndirectedEdge[135, 364] -> 
             RGBColor[
              0.42640390772588643`, 0.5423948335396401, 0.9487658718038847], 
             UndirectedEdge[39, 383] -> 
             RGBColor[
              0.27666419535336334`, 0.408121989212486, 0.9390669886861509], 
             UndirectedEdge[108, 196] -> 
             RGBColor[
              0.332746597404592, 0.4616295540574491, 0.9424599321408476], 
             UndirectedEdge[75, 89] -> 
             RGBColor[
              0.23138047401831524`, 0.3605259269355878, 0.9364881477473821], 
             UndirectedEdge[131, 269] -> 
             RGBColor[
              0.9577625542405059, 0.8589366723660075, 0.3711790558606476], 
             UndirectedEdge[36, 165] -> 
             RGBColor[
              0.5262130350709433, 0.6262424733544989, 0.9558445641840965], 
             UndirectedEdge[40, 41] -> 
             RGBColor[
              0.34006622360312927`, 0.4689700034848203, 0.942889696952605], 
             UndirectedEdge[86, 249] -> 
             RGBColor[
              0.2850528182511259, 0.41693896374744543`, 0.939544708350323], 
             UndirectedEdge[287, 395] -> 
             RGBColor[
              0.2666407460996809, 0.397586708523477, 0.938496168079518], 
             UndirectedEdge[177, 225] -> 
             RGBColor[
              0.2895083029136421, 0.42040499749423077`, 0.9398430005920957], 
             UndirectedEdge[74, 216] -> 
             RGBColor[
              0.7418875253371497, 0.7983253437301927, 0.9748980148903788], 
             UndirectedEdge[229, 371] -> 
             RGBColor[
              0.25947088353624953`, 0.3900507283737679, 0.9380878550133916], 
             UndirectedEdge[319, 371] -> 
             RGBColor[
              0.2568146393431022, 0.387258847311161, 0.937936585836153], 
             UndirectedEdge[169, 353] -> 
             RGBColor[
              0.21553905850906607`, 0.343875594831612, 0.9355860025694045], 
             UndirectedEdge[47, 362] -> 
             RGBColor[
              0.4192754724662534, 0.5375770736774529, 0.9479368402481747], 
             UndirectedEdge[83, 313] -> 
             RGBColor[
              0.31784501109874064`, 0.44732499341570175`, 0.9415615875935087],
              UndirectedEdge[87, 210] -> 
             RGBColor[
              0.2950312133683537, 0.42742688968244336`, 0.9401129631905363], 
             UndirectedEdge[91, 150] -> 
             RGBColor[
              0.2666109948635128, 0.3975554380879269, 0.9384944737906311], 
             UndirectedEdge[16, 258] -> 
             RGBColor[
              0.24739688608388788`, 0.37736019151568206`, 0.9374002587203583],
              UndirectedEdge[334, 388] -> 
             RGBColor[
              0.24238207309791887`, 0.372089305109921, 0.9371146725395583], 
             UndirectedEdge[67, 325] -> 
             RGBColor[
              0.21225679273606501`, 0.3404257253965182, 0.9353990823893092], 
             UndirectedEdge[279, 363] -> 
             RGBColor[
              0.9040810668165558, 0.6454045668048165, 0.24105801091555495`], 
             UndirectedEdge[192, 385] -> 
             RGBColor[
              0.45995539470159097`, 0.5694965937320001, 0.9514449793856737], 
             UndirectedEdge[216, 339] -> 
             RGBColor[
              0.5124310381777115, 0.6124197611712089, 0.9555918284959135], 
             UndirectedEdge[74, 323] -> 
             RGBColor[
              0.8274418605794372, 0.8652436955878107, 0.9834033373997775], 
             UndirectedEdge[60, 87] -> 
             RGBColor[
              0.32383352968544554`, 0.4531896894262284, 0.9419183552403817], 
             UndirectedEdge[74, 198] -> 
             RGBColor[
              0.8255815527613636, 0.8637603366303892, 0.9832258995793732], 
             UndirectedEdge[16, 348] -> 
             RGBColor[
              0.252407866634222, 0.38262704978860046`, 0.9376856266496183], 
             UndirectedEdge[88, 283] -> 
             RGBColor[
              0.9496145330722283, 0.8334245259791293, 0.5278793972462171], 
             UndirectedEdge[292, 388] -> 
             RGBColor[
              0.21719189432910094`, 0.3456128300743124, 0.9356801291242041], 
             UndirectedEdge[76, 382] -> 
             RGBColor[
              0.8728626791215081, 0.4975553578985697, 0.2149200050950769], 
             UndirectedEdge[131, 352] -> 
             RGBColor[
              0.9583101575279735, 0.8601079404267151, 0.43078229428572945`], 
             UndirectedEdge[123, 232] -> 
             RGBColor[
              0.7499263891145284, 0.8030301325071595, 0.9420935049543039], 
             UndirectedEdge[69, 357] -> 
             RGBColor[
              0.5819543622257783, 0.6709852038723623, 0.9605818188059951], 
             UndirectedEdge[241, 339] -> 
             RGBColor[
              0.32836122521249217`, 0.457187465102298, 0.9422040691120204], 
             UndirectedEdge[181, 322] -> 
             RGBColor[
              0.5378642093893072, 0.6357014215455682, 0.9567617873060958], 
             UndirectedEdge[140, 168] -> 
             RGBColor[
              0.6710377427034506, 0.7429390517664531, 0.9678464290545918], 
             UndirectedEdge[88, 357] -> 
             RGBColor[
              0.8330019348815232, 0.8684180093986145, 0.8892498058738514], 
             UndirectedEdge[125, 179] -> 
             RGBColor[
              0.2738145581196516, 0.4051268398024189, 0.9389047060613515], 
             UndirectedEdge[316, 324] -> 
             RGBColor[
              0.2671185805915378, 0.39808894287087526`, 0.9385233800469365], 
             UndirectedEdge[128, 390] -> 
             RGBColor[
              0.29625621364741994`, 0.42709948500765055`, 0.9402418566543815],
              UndirectedEdge[200, 339] -> 
             RGBColor[
              0.3182100783412779, 0.4465179661207665, 0.9416259763149808], 
             UndirectedEdge[85, 110] -> 
             RGBColor[
              0.2484427050223485, 0.37845941352875473`, 0.9374598165617531], 
             UndirectedEdge[178, 209] -> 
             RGBColor[
              0.24801071646784933`, 0.37800536616831976`, 0.9374352154526442],
              UndirectedEdge[380, 383] -> 
             RGBColor[
              0.2728634955258139, 0.4041272127154443, 0.9388505444536035], 
             UndirectedEdge[350, 357] -> 
             RGBColor[
              0.5542164267531839, 0.6479076320182329, 0.9585525480697432], 
             UndirectedEdge[98, 352] -> 
             RGBColor[
              0.9858621188487648, 0.9629527205499828, 0.4862282141252213], 
             UndirectedEdge[68, 151] -> 
             RGBColor[
              0.29628007015479707`, 0.4280840429902235, 0.9402080838641316], 
             UndirectedEdge[307, 385] -> 
             RGBColor[
              0.7803305100204103, 0.8271780586683711, 0.9269968726475282], 
             UndirectedEdge[94, 119] -> 
             RGBColor[
              0.25031116778183593`, 0.38042328635635736`, 0.9375662227517629],
              UndirectedEdge[116, 121] -> 
             RGBColor[
              0.48470874113100904`, 0.5915401565241579, 0.9528555034179461], 
             UndirectedEdge[1, 361] -> 
             RGBColor[
              0.35780477718256065`, 0.4843342470296975, 0.9440199819010995], 
             UndirectedEdge[180, 239] -> 
             RGBColor[
              0.3453924706572131, 0.47358333097810695`, 0.943229080705076], 
             UndirectedEdge[45, 394] -> 
             RGBColor[
              0.32718352263793704`, 0.4565868884354943, 0.9421136673575129], 
             UndirectedEdge[32, 124] -> 
             RGBColor[
              0.21977833860588586`, 0.34833134699925217`, 0.9358274232994656],
              UndirectedEdge[87, 243] -> 
             RGBColor[
              0.2892553344802239, 0.4213560747591461, 0.9397840354325044], 
             UndirectedEdge[188, 195] -> 
             RGBColor[
              0.25639031228130726`, 0.3868128526653249, 0.9379124210377194], 
             UndirectedEdge[122, 262] -> 
             RGBColor[
              0.6923652232093209, 0.7572804525421046, 0.9691955483013721], 
             UndirectedEdge[118, 212] -> 
             RGBColor[
              0.208479398474888, 0.33645544452739207`, 0.9351839653742893], 
             UndirectedEdge[35, 258] -> 
             RGBColor[
              0.2669871560923189, 0.3979508073894016, 0.938515895616131], 
             UndirectedEdge[183, 271] -> 
             RGBColor[
              0.28286075625291396`, 0.4146349676025667, 0.9394198736623899], 
             UndirectedEdge[130, 147] -> 
             RGBColor[
              0.34757171171070933`, 0.4732511609805692, 0.9434492148065551], 
             UndirectedEdge[124, 330] -> 
             RGBColor[
              0.22402160898279397`, 0.3527912932042634, 0.9360690712700745], 
             UndirectedEdge[46, 395] -> 
             RGBColor[
              0.27869220583377896`, 0.41025355681069386`, 0.939182480882838], 
             UndirectedEdge[206, 284] -> 
             RGBColor[
              0.23778007994491618`, 0.3672523185228967, 0.9368525958375336], 
             UndirectedEdge[179, 313] -> 
             RGBColor[
              0.2762257553297003, 0.407661160948913, 0.939042020175417], 
             UndirectedEdge[215, 363] -> 
             RGBColor[
              0.8409003453545498, 0.3089231403704602, 0.18654654935464235`], 
             UndirectedEdge[260, 338] -> 
             RGBColor[
              0.9016212039882432, 0.9204360205910522, 0.8006477894997438], 
             UndirectedEdge[88, 113] -> 
             RGBColor[
              0.8934147061054667, 0.915612925432826, 0.8952711863200087], 
             UndirectedEdge[95, 270] -> 
             RGBColor[
              0.26568283896088996`, 0.3965798873857872, 0.9384416166850604], 
             UndirectedEdge[16, 184] -> 
             RGBColor[
              0.22981171473055614`, 0.35887706145906934`, 0.9363988092267157],
              UndirectedEdge[38, 78] -> 
             RGBColor[
              0.9038175805994484, 0.6094521874784743, 0.2546544328195417], 
             UndirectedEdge[8, 210] -> 
             RGBColor[
              0.30512183219392025`, 0.43788724700591375`, 0.9406929373091137],
              UndirectedEdge[1, 96] -> 
             RGBColor[
              0.32344726087306624`, 0.45255674347328584`, 0.9419046676618501],
              UndirectedEdge[213, 247] -> 
             RGBColor[
              0.9089878266866289, 0.6768740913610367, 0.24562767290302676`], 
             UndirectedEdge[109, 366] -> 
             RGBColor[
              0.9476884477531541, 0.8182230648175637, 0.4934194788371198], 
             UndirectedEdge[223, 260] -> 
             RGBColor[
              0.6315106131402652, 0.7091757673875206, 0.9658788076150083], 
             UndirectedEdge[393, 399] -> 
             RGBColor[
              0.22884950770057744`, 0.3578657208631124, 0.9363440129598162], 
             UndirectedEdge[25, 358] -> 
             RGBColor[
              0.9086438937541778, 0.640542215450566, 0.2633529303924386], 
             UndirectedEdge[207, 358] -> 
             RGBColor[
              0.9542162454207332, 0.8524596356255733, 0.30144575978299126`], 
             UndirectedEdge[31, 33] -> 
             RGBColor[0.1810793999809316, 0.30765630885, 0.9336235759947237], 
             UndirectedEdge[355, 375] -> 
             RGBColor[
              0.24288325350972279`, 0.37261607749940034`, 0.9371432140225805],
              UndirectedEdge[25, 104] -> 
             RGBColor[
              0.8912926011446027, 0.575480186768195, 0.22996543355252164`], 
             UndirectedEdge[360, 375] -> 
             RGBColor[
              0.2826185317002574, 0.4142282159179257, 0.939411650593985], 
             UndirectedEdge[28, 347] -> 
             RGBColor[
              0.28416959916217255`, 0.4160106444856309, 0.9394944103298126], 
             UndirectedEdge[56, 143] -> 
             RGBColor[
              0.5377896391569529, 0.6355761788857779, 0.956773794547269], 
             UndirectedEdge[73, 115] -> 
             RGBColor[
              0.24086103809529086`, 0.3704906008829697, 0.9370280518463283], 
             UndirectedEdge[157, 218] -> 
             RGBColor[
              0.689653807893005, 0.7555582412254274, 0.971321814931075], 
             UndirectedEdge[267, 321] -> 
             RGBColor[
              0.6944927044467815, 0.7601721648632764, 0.9709294949676452], 
             UndirectedEdge[93, 324] -> 
             RGBColor[
              0.26259788296436154`, 0.3933374030359285, 0.9382659330048415], 
             UndirectedEdge[178, 245] -> 
             RGBColor[
              0.23694364602077422`, 0.3663731734356497, 0.9368049621629467], 
             UndirectedEdge[223, 331] -> 
             RGBColor[
              0.45307983116767014`, 0.5668363678003234, 0.9500964447383967], 
             UndirectedEdge[318, 367] -> 
             RGBColor[
              0.22156608180377718`, 0.3502103784497014, 0.9359292326298564], 
             UndirectedEdge[158, 265] -> 
             RGBColor[
              0.5475052991401734, 0.643528492531465, 0.9575207692077594], 
             UndirectedEdge[124, 199] -> 
             RGBColor[
              0.224537016117427, 0.35333301878146245`, 0.9360984229439153], 
             UndirectedEdge[38, 213] -> 
             RGBColor[
              0.9383796626861343, 0.7904965676280676, 0.28441340229193146`], 
             UndirectedEdge[128, 296] -> 
             RGBColor[
              0.3138673468643941, 0.4456099026290287, 0.9412447846377514], 
             UndirectedEdge[89, 315] -> 
             RGBColor[
              0.23092852589242507`, 0.36005090080011104`, 0.93646240997021], 
             UndirectedEdge[129, 178] -> 
             RGBColor[
              0.24083645723076108`, 0.3704647648358321, 0.9370266520024574], 
             UndirectedEdge[61, 279] -> 
             RGBColor[
              0.9694977718101772, 0.9052009249245101, 0.39612374546494056`], 
             UndirectedEdge[7, 332] -> 
             RGBColor[
              0.45831330080032634`, 0.5693830222721039, 0.9509787412394903], 
             UndirectedEdge[105, 180] -> 
             RGBColor[
              0.39180706588006936`, 0.513785320494758, 0.9461865776698615], 
             UndirectedEdge[75, 163] -> 
             RGBColor[
              0.24457568603401603`, 0.37439493138885227`, 0.9372395955511095],
              UndirectedEdge[15, 273] -> 
             RGBColor[
              0.28964915667663804`, 0.4217700068573468, 0.9398064630239824], 
             UndirectedEdge[149, 287] -> 
             RGBColor[
              0.24021601426247097`, 0.36981263993780294`, 0.9369913186932763],
              UndirectedEdge[123, 275] -> 
             RGBColor[
              0.9831983875687983, 0.9856760529092304, 0.8544852374631398], 
             UndirectedEdge[186, 226] -> 
             RGBColor[
              0.24355084950968384`, 0.37331776322339055`, 0.9371812326271585],
              UndirectedEdge[15, 183] -> 
             RGBColor[
              0.281397272925088, 0.41309675383481925`, 0.9393365304518997], 
             UndirectedEdge[35, 41] -> 
             RGBColor[
              0.3109306833758936, 0.44117275107327436`, 0.9411269955899995], 
             UndirectedEdge[47, 54] -> 
             RGBColor[
              0.44294170199458305`, 0.5580755721956097, 0.9494448314664949], 
             UndirectedEdge[19, 196] -> 
             RGBColor[
              0.2861541125436652, 0.4180964938749955, 0.9396074254310642], 
             UndirectedEdge[211, 328] -> 
             RGBColor[
              0.2860571913279975, 0.41793071873950494`, 0.9396042457787188], 
             UndirectedEdge[3, 86] -> 
             RGBColor[
              0.33530800642617503`, 0.4640896371481913, 0.9426142996527203], 
             UndirectedEdge[55, 58] -> 
             RGBColor[
              0.351171823063294, 0.4776705562573528, 0.9436309688854188], 
             UndirectedEdge[63, 214] -> 
             RGBColor[
              0.9711670732550739, 0.9296487112649943, 0.6029350218130802], 
             UndirectedEdge[26, 106] -> 
             RGBColor[
              0.7018038352541023, 0.7648141211568, 0.9611581586207743], 
             UndirectedEdge[89, 378] -> 
             RGBColor[
              0.2135546306131389, 0.341789835292997, 0.9354729923364294], 
             UndirectedEdge[191, 311] -> 
             RGBColor[
              0.5991137006259042, 0.6848674707026068, 0.961965795167115], 
             UndirectedEdge[147, 364] -> 
             RGBColor[
              0.31713379957570453`, 0.44688737134317436`, 0.9415097379605015],
              UndirectedEdge[137, 285] -> 
             RGBColor[
              0.23013560035880143`, 0.35921748578989005`, 0.9364172540340985],
              UndirectedEdge[104, 205] -> 
             RGBColor[
              0.9645712998383063, 0.8839256222853624, 0.49686413410326324`], 
             UndirectedEdge[191, 339] -> 
             RGBColor[
              0.5223069322379694, 0.6201348846706572, 0.9565761653203628], 
             UndirectedEdge[40, 167] -> 
             RGBColor[
              0.31143079927380024`, 0.4418378465956456, 0.9411503707956721], 
             UndirectedEdge[17, 262] -> 
             RGBColor[
              0.7370797325190604, 0.7937780282574919, 0.9726613937241215], 
             UndirectedEdge[96, 348] -> 
             RGBColor[
              0.27493335548153697`, 0.4063027667656103, 0.9389684199159984], 
             UndirectedEdge[60, 122] -> 
             RGBColor[
              0.4018079642776756, 0.5224475960269956, 0.9468238260723096], 
             UndirectedEdge[99, 187] -> 
             RGBColor[
              0.9110307205751575, 0.9308010667922535, 0.953442401298972], 
             UndirectedEdge[111, 166] -> 
             RGBColor[
              0.8494236278647009, 0.35624594261769826`, 0.19399614499147944`],
              UndirectedEdge[130, 172] -> 
             RGBColor[
              0.3559151258566954, 0.4820206182510111, 0.9439243598991939], 
             UndirectedEdge[205, 230] -> 
             RGBColor[
              0.9820628725503424, 0.9494608486926688, 0.5307965926515668], 
             UndirectedEdge[248, 319] -> 
             RGBColor[
              0.2288957810137855, 0.3579143570491916, 0.9363466481565481], 
             UndirectedEdge[77, 111] -> 
             RGBColor[
              0.8517216279012312, 0.6939386797204187, 0.6001134200588495], 
             UndirectedEdge[41, 188] -> 
             RGBColor[
              0.30395311727072993`, 0.43383888669350434`, 0.9407296335226945],
              UndirectedEdge[57, 278] -> 
             RGBColor[
              0.26281152350528336`, 0.39356195279003, 0.9382780995175941], 
             UndirectedEdge[56, 331] -> 
             RGBColor[
              0.4515137506850261, 0.565500249927577, 0.9499910348290849], 
             UndirectedEdge[40, 87] -> 
             RGBColor[
              0.31472542396778913`, 0.4453007060402985, 0.9413379947980343], 
             UndirectedEdge[142, 214] -> 
             RGBColor[
              0.9026785336009098, 0.577164017789306, 0.5403271212608096], 
             UndirectedEdge[341, 368] -> 
             RGBColor[
              0.2171826090564914, 0.3456030706640795, 0.9356796003416652], 
             UndirectedEdge[96, 188] -> 
             RGBColor[
              0.2769987034014417, 0.4084735783800516, 0.9390860384246287], 
             UndirectedEdge[142, 202] -> 
             RGBColor[
              0.8389617996732674, 0.300483042224024, 0.18494316940916705`], 
             UndirectedEdge[37, 351] -> 
             RGBColor[
              0.2477720085286644, 0.3777544689892789, 0.9374216213886444], 
             UndirectedEdge[83, 108] -> 
             RGBColor[
              0.3602253738682746, 0.48643084621613597`, 0.9441742201814636], 
             UndirectedEdge[72, 119] -> 
             RGBColor[
              0.2341124382405141, 0.36339739454965503`, 0.9366437290682574], 
             UndirectedEdge[170, 180] -> 
             RGBColor[
              0.40561982873439206`, 0.5257492414295251, 0.9470667147047922], 
             UndirectedEdge[196, 234] -> 
             RGBColor[
              0.3183317548341577, 0.44914414193399255`, 0.9415414311188043], 
             UndirectedEdge[218, 306] -> 
             RGBColor[
              0.9402199448611399, 0.9214289952270589, 0.6653505611679222], 
             UndirectedEdge[186, 189] -> 
             RGBColor[
              0.2745072076984255, 0.4058548584262301, 0.9389441514301794], 
             UndirectedEdge[20, 135] -> 
             RGBColor[
              0.45546851492086315`, 0.5675691354622958, 0.9506178428735257], 
             UndirectedEdge[79, 254] -> 
             RGBColor[
              0.5301586737259505, 0.6294457205636295, 0.9561551793123693], 
             UndirectedEdge[93, 355] -> 
             RGBColor[
              0.23807963900287032`, 0.36756717408594775`, 0.936869655282726], 
             UndirectedEdge[211, 301] -> 
             RGBColor[
              0.25974755171345176`, 0.39034152416978307`, 0.9381036108567895],
              UndirectedEdge[145, 227] -> 
             RGBColor[
              0.23647303514531387`, 0.36587853156708794`, 0.9367781615697957],
              UndirectedEdge[26, 345] -> 
             RGBColor[
              0.3285301240705917, 0.4490550186158963, 0.9425296374326482], 
             UndirectedEdge[132, 140] -> 
             RGBColor[
              0.7355736784173503, 0.7933550152374292, 0.9742787680039452], 
             UndirectedEdge[153, 258] -> 
             RGBColor[
              0.28518201112076286`, 0.41627178817658117`, 0.9395814661923377],
              UndirectedEdge[56, 344] -> 
             RGBColor[
              0.38578184035649155`, 0.5085665729828752, 0.9458026556273967], 
             UndirectedEdge[44, 390] -> 
             RGBColor[
              0.28212790876587335`, 0.4138646984284726, 0.9393781390821536], 
             UndirectedEdge[223, 346] -> 
             RGBColor[
              0.3995496021231435, 0.5204711739094963, 0.9466855458786024], 
             UndirectedEdge[114, 222] -> 
             RGBColor[
              0.4669023906435984, 0.574712579304436, 0.9521089968254883], 
             UndirectedEdge[85, 203] -> 
             RGBColor[
              0.2663525209612127, 0.3972837656284177, 0.9384797540842731], 
             UndirectedEdge[156, 261] -> 
             RGBColor[
              0.18270395436139325`, 0.3093638185065621, 0.9337160919633781], 
             UndirectedEdge[33, 295] -> 
             RGBColor[
              0.21066436833308994`, 0.3387519863834527, 0.9353083961753406], 
             UndirectedEdge[59, 395] -> 
             RGBColor[
              0.303543145607047, 0.434036883269187, 0.9406832590311243], 
             UndirectedEdge[334, 371] -> 
             RGBColor[
              0.26672232113879757`, 0.3976724490617448, 0.9385008136573162], 
             UndirectedEdge[40, 154] -> 
             RGBColor[
              0.3847350802007028, 0.5076599219476261, 0.9457359569958835], 
             UndirectedEdge[300, 306] -> 
             RGBColor[
              0.9301864468516778, 0.7525583544999579, 0.2846700934867103], 
             UndirectedEdge[61, 297] -> 
             RGBColor[
              0.9699924620425022, 0.9739499675150907, 0.7461656307796394], 
             UndirectedEdge[97, 350] -> 
             RGBColor[
              0.437513599136121, 0.5533740223239922, 0.9490989575522366], 
             UndirectedEdge[178, 229] -> 
             RGBColor[
              0.24544230257567465`, 0.37530580032079786`, 0.9372889480811126],
              UndirectedEdge[130, 265] -> 
             RGBColor[
              0.5011501438603255, 0.6047301166670249, 0.9541934622219126], 
             UndirectedEdge[110, 134] -> 
             RGBColor[
              0.24495240537755758`, 0.37479088730430044`, 0.9372610491604179],
              UndirectedEdge[147, 211] -> 
             RGBColor[
              0.2737075152920192, 0.40501433100367, 0.9388986101306735], 
             UndirectedEdge[78, 185] -> 
             RGBColor[
              0.832767216647035, 0.2528687626008105, 0.17901122970746597`], 
             UndirectedEdge[130, 135] -> 
             RGBColor[
              0.4568418198608912, 0.568758623177035, 0.9507053486499384], 
             UndirectedEdge[52, 384] -> 
             RGBColor[
              0.5675366621289825, 0.6563557009893235, 0.9607088184571579], 
             UndirectedEdge[77, 166] -> 
             RGBColor[
              0.827067103969575, 0.529084500588463, 0.5774695030073427], 
             UndirectedEdge[24, 76] -> 
             RGBColor[
              0.8745487301949283, 0.505211322035738, 0.2163268874396324], 
             UndirectedEdge[100, 220] -> 
             RGBColor[
              0.42602430021250687`, 0.5428220538333498, 0.9485327937322395], 
             UndirectedEdge[41, 369] -> 
             RGBColor[
              0.2991371325274741, 0.4287769813772735, 0.940455370316177], 
             UndirectedEdge[12, 318] -> 
             RGBColor[
              0.2211272263803799, 0.3497491135746699, 0.9359042404627222], 
             UndirectedEdge[118, 199] -> 
             RGBColor[
              0.21593219336709382`, 0.3442888044935889, 0.9356083910179783], 
             UndirectedEdge[11, 205] -> 
             RGBColor[
              0.9593655870867921, 0.8632867059265485, 0.49267549542961175`], 
             UndirectedEdge[120, 136] -> 
             RGBColor[
              0.5924802140391232, 0.6800411545432594, 0.9610613592571464], 
             UndirectedEdge[66, 215] -> 
             RGBColor[
              0.8960355420221306, 0.5345577698337973, 0.25743539509359753`], 
             UndirectedEdge[199, 287] -> 
             RGBColor[
              0.24300807911222783`, 0.3727472771220335, 0.9371503226559803], 
             UndirectedEdge[8, 64] -> 
             RGBColor[
              0.3546401133620532, 0.4815931742890025, 0.9438183323208591], 
             UndirectedEdge[312, 361] -> 
             RGBColor[
              0.40929184788600736`, 0.528668033662285, 0.9473730082456748], 
             UndirectedEdge[5, 193] -> 
             RGBColor[
              0.8318913190108279, 0.8687915729636699, 0.983827730717042], 
             UndirectedEdge[187, 232] -> 
             RGBColor[
              0.6847452419471614, 0.7520517688707707, 0.9703846238932006], 
             UndirectedEdge[115, 325] -> 
             RGBColor[
              0.22508690864981107`, 0.3539109906981984, 0.9361297385101415], 
             UndirectedEdge[137, 252] -> 
             RGBColor[
              0.22294460960746476`, 0.35165929857508804`, 0.9360077377489273],
              UndirectedEdge[296, 390] -> 
             RGBColor[
              0.283910407540538, 0.415738217657595, 0.9394796497504001], 
             UndirectedEdge[101, 171] -> 
             RGBColor[
              0.2670272094470698, 0.3979929060047742, 0.9385181765954305], 
             UndirectedEdge[234, 342] -> 
             RGBColor[
              0.47104879657377785`, 0.578346581625195, 0.9523614333210206], 
             UndirectedEdge[56, 343] -> 
             RGBColor[
              0.5865678018857227, 0.673953417760403, 0.9614500105609494], 
             UndirectedEdge[60, 146] -> 
             RGBColor[
              0.44642978990835863`, 0.5588699269563728, 0.9502823750963323], 
             UndirectedEdge[149, 336] -> 
             RGBColor[
              0.21561259787663173`, 0.3439528893695888, 0.9355901905275956], 
             UndirectedEdge[12, 199] -> 
             RGBColor[
              0.22211987446733733`, 0.350792449651586, 0.9359607703027832], 
             UndirectedEdge[42, 104] -> 
             RGBColor[
              0.9330499750272585, 0.8621677183315113, 0.6295247357296906], 
             UndirectedEdge[216, 323] -> 
             RGBColor[
              0.7446559095096992, 0.8005327781235971, 0.9751620658441222], 
             UndirectedEdge[110, 192] -> 
             RGBColor[
              0.30003384397733923`, 0.42938021827289985`, 0.940518858812405], 
             UndirectedEdge[93, 380] -> 
             RGBColor[
              0.25536438822798396`, 0.38573454143794017`, 0.9378539961806014],
              UndirectedEdge[34, 397] -> 
             RGBColor[
              0.28081927975955956`, 0.41216167083836874`, 0.939315608741104], 
             UndirectedEdge[249, 308] -> 
             RGBColor[
              0.2653288302878062, 0.39620780182492993`, 0.9384214564148372], 
             UndirectedEdge[116, 130] -> 
             RGBColor[
              0.4133134657138138, 0.5324130830876621, 0.947556946449905], 
             UndirectedEdge[81, 315] -> 
             RGBColor[
              0.23149483664630416`, 0.3606461293086136, 0.9364946605298619], 
             UndirectedEdge[99, 193] -> 
             RGBColor[
              0.9002336063428361, 0.9221917409832586, 0.9524125629047955], 
             UndirectedEdge[116, 135] -> 
             RGBColor[
              0.4597496952635722, 0.5712772786967698, 0.9508906358992639], 
             UndirectedEdge[304, 378] -> 
             RGBColor[
              0.21381243485280502`, 0.34206080389461896`, 0.9354876739064912],
              UndirectedEdge[56, 120] -> 
             RGBColor[
              0.5086566729306621, 0.6119247244781029, 0.9544803407283637], 
             UndirectedEdge[255, 393] -> 
             RGBColor[
              0.2416474883761139, 0.3713172099919425, 0.9370728390263723], 
             UndirectedEdge[106, 214] -> 
             RGBColor[
              0.9661339552698273, 0.9742633398075717, 0.9422105594358144], 
             UndirectedEdge[130, 328] -> 
             RGBColor[
              0.3599213877466876, 0.48616754871640405`, 0.9441548504546003], 
             UndirectedEdge[181, 250] -> 
             RGBColor[
              0.7777697545864616, 0.8245041838583995, 0.9019245302265969], 
             UndirectedEdge[102, 230] -> 
             RGBColor[
              0.8940771340934058, 0.5279706608893748, 0.24981441421432754`], 
             UndirectedEdge[45, 141] -> 
             RGBColor[
              0.32778152064738697`, 0.45710484425502595`, 0.9421517712618861],
              UndirectedEdge[225, 288] -> 
             RGBColor[
              0.25106704817739506`, 0.3812177645776751, 0.9376092690220652], 
             UndirectedEdge[208, 278] -> 
             RGBColor[
              0.24275117083398723`, 0.37247725023267697`, 0.9371356921095961],
              UndirectedEdge[342, 346] -> 
             RGBColor[
              0.4741951057473072, 0.5810717564932091, 0.9525619133593859], 
             UndirectedEdge[133, 164] -> 
             RGBColor[
              0.2698983654154672, 0.40101067296936244`, 0.9386816846803361], 
             UndirectedEdge[287, 373] -> 
             RGBColor[
              0.2552675974110747, 0.3856328081524763, 0.9378484840867676], 
             UndirectedEdge[122, 314] -> 
             RGBColor[
              0.6859497834912932, 0.7522408691078613, 0.9712156258567326], 
             UndirectedEdge[85, 351] -> 
             RGBColor[
              0.24352597864269326`, 0.37329162236527946`, 0.9371798162680766],
              UndirectedEdge[5, 338] -> 
             RGBColor[
              0.9178657002272999, 0.9332997898377504, 0.8022208620159], 
             UndirectedEdge[311, 339] -> 
             RGBColor[
              0.4425672704759462, 0.555957682108388, 0.9499165435038557], 
             UndirectedEdge[39, 324] -> 
             RGBColor[
              0.27652485948189337`, 0.40797553837716655`, 0.9390590537143996],
              UndirectedEdge[52, 346] -> 
             RGBColor[
              0.36583874865596927`, 0.4912928693208167, 0.944531899459223], 
             UndirectedEdge[272, 291] -> 
             RGBColor[
              0.6717542540567425, 0.7434987958813325, 0.9679178442101087], 
             UndirectedEdge[191, 323] -> 
             RGBColor[
              0.7545318035699571, 0.8082479016230455, 0.9761464026685716], 
             UndirectedEdge[60, 165] -> 
             RGBColor[
              0.4451385583294708, 0.557821646991312, 0.950180724616505], 
             UndirectedEdge[44, 301] -> 
             RGBColor[
              0.2773872245806669, 0.4088819387730828, 0.9391081641310199], 
             UndirectedEdge[11, 144] -> 
             RGBColor[
              0.9009503839038591, 0.6375798223152109, 0.23877628985540691`], 
             UndirectedEdge[333, 381] -> 
             RGBColor[
              0.5943537422981029, 0.6571554755250186, 0.8488416222676571], 
             UndirectedEdge[9, 363] -> 
             RGBColor[
              0.8440899658094313, 0.333439960887275, 0.18960093350439794`], 
             UndirectedEdge[153, 312] -> 
             RGBColor[
              0.39019396776607296`, 0.5121264097897626, 0.9461561082120249], 
             UndirectedEdge[55, 80] -> 
             RGBColor[
              0.36897452576073053`, 0.49400892184022105`, 0.9447317084034796],
              UndirectedEdge[7, 40] -> 
             RGBColor[
              0.36435856265805855`, 0.4900108066057379, 0.9444375833163132], 
             UndirectedEdge[51, 377] -> 
             RGBColor[
              0.39390138797963725`, 0.5155993170337143, 0.9463200260221095], 
             UndirectedEdge[112, 170] -> 
             RGBColor[
              0.3869454032271654, 0.5095743926590826, 0.9458767968246178], 
             UndirectedEdge[200, 375] -> 
             RGBColor[
              0.26275249757312547`, 0.3934999127928718, 0.9382747380780788], 
             UndirectedEdge[94, 200] -> 
             RGBColor[
              0.26539181138814727`, 0.3962739989546208, 0.9384250430953294], 
             UndirectedEdge[8, 253] -> 
             RGBColor[
              0.3260178665234107, 0.4568020226733255, 0.9419945480619598], 
             UndirectedEdge[31, 295] -> 
             RGBColor[
              0.21280238164412135`, 0.34099917393122015`, 0.9354301528704966],
              UndirectedEdge[301, 383] -> 
             RGBColor[
              0.2685271160434062, 0.39956940293709464`, 0.9386035940571789], 
             UndirectedEdge[327, 392] -> 
             RGBColor[
              0.28327067295496094`, 0.4141554737113025, 0.9394765499044728], 
             UndirectedEdge[119, 375] -> 
             RGBColor[
              0.24767185396681415`, 0.37764920019460835`, 0.9374159177345123],
              UndirectedEdge[160, 340] -> 
             RGBColor[
              0.9116278550257833, 0.6083417789954149, 0.37001345675471364`], 
             UndirectedEdge[151, 308] -> 
             RGBColor[
              0.28846194842015016`, 0.41986670134956156`, 0.9397628533972181],
              UndirectedEdge[221, 276] -> 
             RGBColor[
              0.8437125304054167, 0.8786573253156666, 0.9848385285958808], 
             UndirectedEdge[94, 316] -> 
             RGBColor[
              0.25720173748705216`, 0.38766571200389227`, 0.9379586305027907],
              UndirectedEdge[195, 206] -> 
             RGBColor[
              0.2386283880050733, 0.3681439440799593, 0.9369009057266002], 
             UndirectedEdge[159, 192] -> 
             RGBColor[
              0.3379621693046799, 0.46714757740434754`, 0.9427556284732501], 
             UndirectedEdge[220, 350] -> 
             RGBColor[
              0.454088632793754, 0.5671299681608568, 0.9503210281880017], 
             UndirectedEdge[229, 319] -> 
             RGBColor[
              0.24423991719027513`, 0.3740420170451063, 0.9372204740121839], 
             UndirectedEdge[69, 97] -> 
             RGBColor[
              0.46525153460871527`, 0.5764515941781216, 0.9511282282884884], 
             UndirectedEdge[90, 317] -> 
             RGBColor[
              0.8482164323597703, 0.8802460937906929, 0.8881545671159801], 
             UndirectedEdge[136, 237] -> 
             RGBColor[
              0.59850057250929, 0.6849287527633994, 0.9615353039292178], 
             UndirectedEdge[69, 141] -> 
             RGBColor[
              0.42414128450553, 0.540843961799992, 0.9485087195042803], 
             UndirectedEdge[48, 143] -> 
             RGBColor[
              0.5250435709581793, 0.6245361752480152, 0.9559616263525487], 
             UndirectedEdge[51, 246] -> 
             RGBColor[
              0.408363122473439, 0.5281253445843351, 0.9472415149560449], 
             UndirectedEdge[97, 132] -> 
             RGBColor[
              0.6207534044996754, 0.7002920708010887, 0.965012812845729], 
             UndirectedEdge[94, 383] -> 
             RGBColor[
              0.2701801471577058, 0.4013068434464496, 0.9386977317336979], 
             UndirectedEdge[246, 344] -> 
             RGBColor[
              0.3822157528613575, 0.505477807231359, 0.9455754276855741], 
             UndirectedEdge[155, 354] -> 
             RGBColor[
              0.29215952785429067`, 0.42440856613178546`, 0.9399494249487885],
              UndirectedEdge[107, 307] -> 
             RGBColor[
              0.9122288272245584, 0.6453071063540661, 0.539731773350462], 
             UndirectedEdge[310, 363] -> 
             RGBColor[
              0.5225453221257725, 0.38890738011125736`, 0.5703491605175277], 
             UndirectedEdge[99, 281] -> 
             RGBColor[
              0.8050608246814849, 0.8476642232367373, 0.943040239252503], 
             UndirectedEdge[123, 187] -> 
             RGBColor[
              0.9091149872090246, 0.929372315984517, 0.9566852381845512], 
             UndirectedEdge[23, 227] -> 
             RGBColor[
              0.22416996966139735`, 0.3529472296840859, 0.936077520191241], 
             UndirectedEdge[28, 211] -> 
             RGBColor[
              0.2754831553698227, 0.4068806413075249, 0.9389997302062802], 
             UndirectedEdge[327, 356] -> 
             RGBColor[
              0.4184852693414719, 0.5351260969165677, 0.9483745901685348], 
             UndirectedEdge[140, 219] -> 
             RGBColor[
              0.5595564197473485, 0.6526927736905361, 0.9588251269991186], 
             UndirectedEdge[104, 144] -> 
             RGBColor[
              0.9061560966553733, 0.6582187386740248, 0.24296492852905843`], 
             UndirectedEdge[49, 328] -> 
             RGBColor[
              0.2825867919008145, 0.4142831089055032, 0.9394066116653366], 
             UndirectedEdge[112, 271] -> 
             RGBColor[
              0.3178545270497625, 0.4495503070285146, 0.9414810160978866], 
             UndirectedEdge[106, 197] -> 
             RGBColor[
              0.9686231253627324, 0.9753622711647122, 0.9040752003743098], 
             UndirectedEdge[106, 204] -> 
             RGBColor[
              0.563710908416439, 0.6332510496213667, 0.9527850098927306], 
             UndirectedEdge[50, 158] -> 
             RGBColor[
              0.47863176654490647`, 0.5876138560533424, 0.9520987924297972], 
             UndirectedEdge[259, 299] -> 
             RGBColor[
              0.21257469635649348`, 0.34075986225784227`, 0.9354171865301963],
              UndirectedEdge[79, 286] -> 
             RGBColor[
              0.658527918518543, 0.7323765551714567, 0.9671395072605043], 
             UndirectedEdge[240, 388] -> 
             RGBColor[
              0.23128580999340365`, 0.36042642904335986`, 0.9364827567712063],
              UndirectedEdge[118, 299] -> 
             RGBColor[
              0.21009516231391617`, 0.33815371476755507`, 0.9352759807346135],
              UndirectedEdge[138, 257] -> 
             RGBColor[
              0.8209750230584517, 0.16222879530677942`, 0.1677190118096608], 
             UndirectedEdge[171, 244] -> 
             RGBColor[
              0.266624380952421, 0.39756950771609656`, 0.9384952361085915], 
             UndirectedEdge[161, 337] -> 
             RGBColor[
              0.35808998923330093`, 0.48236207273681253`, 0.9441194115332278],
              UndirectedEdge[119, 355] -> 
             RGBColor[
              0.2357097669248304, 0.3650762882733595, 0.9367346945737933], 
             UndirectedEdge[248, 292] -> 
             RGBColor[
              0.21361328404066288`, 0.34185148376416674`, 0.935476332562357], 
             UndirectedEdge[68, 386] -> 
             RGBColor[
              0.30804388160308127`, 0.43827326520037213`, 0.9409576635272863],
              UndirectedEdge[126, 299] -> 
             RGBColor[
              0.21308522513571704`, 0.34129646037420036`, 0.9354462603889135],
              UndirectedEdge[128, 383] -> 
             RGBColor[
              0.30322473955246876`, 0.43442384756391816`, 0.9406387038956638],
              UndirectedEdge[229, 248] -> 
             RGBColor[
              0.2315520252069328, 0.36070623811179847`, 0.9364979173337866], 
             UndirectedEdge[395, 396] -> 
             RGBColor[
              0.2756838068644868, 0.4070915387504564, 0.9390111570120642], 
             UndirectedEdge[81, 292] -> 
             RGBColor[
              0.21536706305033604`, 0.3436948166993449, 0.9355762076824743], 
             UndirectedEdge[34, 253] -> 
             RGBColor[
              0.3270023945629662, 0.4576547713773704, 0.9420572813180563], 
             UndirectedEdge[130, 322] -> 
             RGBColor[
              0.45941085843753277`, 0.5708442844274215, 0.95090759277739], 
             UndirectedEdge[74, 311] -> 
             RGBColor[
              0.6720237576353845, 0.741863264667372, 0.9692227298983209], 
             UndirectedEdge[232, 235] -> 
             RGBColor[
              0.6328251607154107, 0.7112978291642651, 0.965261084970727], 
             UndirectedEdge[207, 221] -> 
             RGBColor[
              0.9308573670898133, 0.869892342221664, 0.6314368519575342], 
             UndirectedEdge[140, 216] -> 
             RGBColor[
              0.6655132848379224, 0.7386233032944675, 0.96729580272355], 
             UndirectedEdge[31, 173] -> 
             RGBColor[
              0.20479251217739197`, 0.3325802932666311, 0.9349740026539064], 
             UndirectedEdge[37, 243] -> 
             RGBColor[
              0.2690857390615694, 0.4001565511479292, 0.9386354068116546], 
             UndirectedEdge[1, 35] -> 
             RGBColor[
              0.32051204203418227`, 0.44947164236999554`, 0.9417375112912428],
              UndirectedEdge[60, 210] -> 
             RGBColor[
              0.3287260262404138, 0.45833201350769803`, 0.942196975681387], 
             UndirectedEdge[35, 92] -> 
             RGBColor[
              0.28435244626912165`, 0.4162028283882106, 0.9395048232020553], 
             UndirectedEdge[52, 291] -> 
             RGBColor[
              0.5415685327056081, 0.6360692009186899, 0.9581205580022027], 
             UndirectedEdge[77, 400] -> 
             RGBColor[
              0.6094880057982189, 0.6893301781287484, 0.9648167092401694], 
             UndirectedEdge[77, 389] -> 
             RGBColor[
              0.5042266153181847, 0.5861702959978048, 0.9585484769989704], 
             UndirectedEdge[96, 361] -> 
             RGBColor[
              0.32126900465498376`, 0.45067004741952366`, 0.9417658711017902],
              UndirectedEdge[150, 374] -> 
             RGBColor[
              0.2733522518909328, 0.4046409266441276, 0.9388783784055468], 
             UndirectedEdge[80, 154] -> 
             RGBColor[
              0.38228721374237734`, 0.5055397030547701, 0.9455799811097223], 
             UndirectedEdge[200, 383] -> 
             RGBColor[
              0.27544799036410295`, 0.4068436806569232, 0.9389977276112265], 
             UndirectedEdge[144, 391] -> 
             RGBColor[
              0.8494144480971886, 0.3493178905748092, 0.19371883223399736`], 
             UndirectedEdge[196, 290] -> 
             RGBColor[
              0.3515289166579535, 0.47789785496789633`, 0.943656724915119], 
             UndirectedEdge[159, 228] -> 
             RGBColor[
              0.3496458859290326, 0.47726742550368945`, 0.9435001045650488], 
             UndirectedEdge[27, 377] -> 
             RGBColor[
              0.3561480526956704, 0.48185180602152367`, 0.9439527698723194], 
             UndirectedEdge[24, 233] -> 
             RGBColor[
              0.8598056285506199, 0.3918893823292492, 0.202208876655091], 
             UndirectedEdge[24, 109] -> 
             RGBColor[
              0.9481247371168586, 0.8202041529201762, 0.49378352937662584`], 
             UndirectedEdge[189, 255] -> 
             RGBColor[
              0.28051086067435194`, 0.4121650783575129, 0.9392860505855498], 
             UndirectedEdge[262, 298] -> 
             RGBColor[
              0.8810364966451805, 0.9079026895445534, 0.9858832537094278], 
             UndirectedEdge[249, 397] -> 
             RGBColor[
              0.25945941523748706`, 0.39003867446463636`, 0.938087201910743], 
             UndirectedEdge[128, 324] -> 
             RGBColor[
              0.3030854036809988, 0.43427739672859866`, 0.9406307689239126], 
             UndirectedEdge[7, 228] -> 
             RGBColor[
              0.37863108577837257`, 0.5023729487746839, 0.9453470158688431], 
             UndirectedEdge[115, 258] -> 
             RGBColor[
              0.24576968053509757`, 0.37564989531311277`, 0.9373075917715895],
              UndirectedEdge[375, 383] -> 
             RGBColor[
              0.26754083334268397`, 0.3985327572847006, 0.9385474267164473], 
             UndirectedEdge[257, 338] -> 
             RGBColor[
              0.9084477718580719, 0.5824829620653897, 0.3944924501077937], 
             UndirectedEdge[5, 321] -> 
             RGBColor[
              0.8296147450427847, 0.8669940565457998, 0.9836058756059307], 
             UndirectedEdge[65, 239] -> 
             RGBColor[
              0.4199235526672635, 0.5364545776271384, 0.9484433827426128], 
             UndirectedEdge[56, 71] -> 
             RGBColor[
              0.6610275221983658, 0.7325352305400676, 0.968761778959447], 
             UndirectedEdge[276, 322] -> 
             RGBColor[
              0.6369911357289768, 0.7142897496435541, 0.9658558315605028], 
             UndirectedEdge[239, 326] -> 
             RGBColor[
              0.3319525774457105, 0.4619423709869775, 0.94237270259407], 
             UndirectedEdge[379, 393] -> 
             RGBColor[
              0.22188867958802838`, 0.35054944917483033`, 0.9359476040964289],
              UndirectedEdge[131, 262] -> 
             RGBColor[
              0.9305545199558635, 0.8420358975584873, 0.6226092420681639], 
             UndirectedEdge[201, 210] -> 
             RGBColor[
              0.2881749983278178, 0.42022057296569904`, 0.9397225118868391], 
             UndirectedEdge[301, 372] -> 
             RGBColor[
              0.25414770566980416`, 0.3844557309271635, 0.9377847079088335], 
             UndirectedEdge[291, 398] -> 
             RGBColor[
              0.8179584912880846, 0.8585839639299231, 0.9789023010866215], 
             UndirectedEdge[28, 49] -> 
             RGBColor[
              0.27201275594263963`, 0.40323303147352313`, 0.938802096092898], 
             UndirectedEdge[6, 160] -> 
             RGBColor[
              0.9114125623801264, 0.6078812897957802, 0.3465801809071596], 
             UndirectedEdge[375, 379] -> 
             RGBColor[
              0.23790135046863936`, 0.36737978153232503`, 0.9368595020144559],
              UndirectedEdge[45, 112] -> 
             RGBColor[
              0.31221013250570034`, 0.4436176904874213, 0.9411595761787357], 
             UndirectedEdge[324, 390] -> 
             RGBColor[
              0.27312846435714266`, 0.404405711757165, 0.9388656340365613], 
             UndirectedEdge[169, 227] -> 
             RGBColor[
              0.22781024002051087`, 0.3567733846379857, 0.936284828202895], 
             UndirectedEdge[44, 380] -> 
             RGBColor[
              0.2817236040630746, 0.41343974855143245`, 0.9393551145274445], 
             UndirectedEdge[288, 360] -> 
             RGBColor[
              0.2777088570611381, 0.4090678365808599, 0.9391320518865], 
             UndirectedEdge[87, 134] -> 
             RGBColor[
              0.26223279186396886`, 0.39295366914130303`, 0.9382451416067781],
              UndirectedEdge[85, 258] -> 
             RGBColor[
              0.24712036386052527`, 0.3770695491264064, 0.9373845111888157], 
             UndirectedEdge[26, 77] -> 
             RGBColor[
              0.6422389788407158, 0.7176486903810251, 0.9669170377654001], 
             UndirectedEdge[90, 333] -> 
             RGBColor[
              0.4506831285542931, 0.5464884699982167, 0.9528800174609131], 
             UndirectedEdge[45, 91] -> 
             RGBColor[
              0.27906015322156846`, 0.41064029284447245`, 0.9392034349422431],
              UndirectedEdge[103, 133] -> 
             RGBColor[
              0.32091218999488846`, 0.4513176188145481, 0.9417081084114585], 
             UndirectedEdge[143, 342] -> 
             RGBColor[
              0.6140012232637606, 0.6975128793422373, 0.9627555719373643], 
             UndirectedEdge[75, 164] -> 
             RGBColor[
              0.2433583151299939, 0.3731153973829517, 0.9371702680790643], 
             UndirectedEdge[44, 211] -> 
             RGBColor[
              0.28031687034096775`, 0.4119611822174286, 0.9392750031230466], 
             UndirectedEdge[82, 171] -> 
             RGBColor[
              0.32621487078886763`, 0.45368735101725755`, 0.9421273921767691],
              UndirectedEdge[17, 122] -> 
             RGBColor[
              0.490802095307585, 0.5972979545178956, 0.9531111298361363], 
             UndirectedEdge[150, 186] -> 
             RGBColor[
              0.2595342246109202, 0.3901173038593028, 0.9380914621938894], 
             UndirectedEdge[180, 394] -> 
             RGBColor[
              0.36256898672280274`, 0.4884607658773212, 0.9443235531201786], 
             UndirectedEdge[156, 202] -> 
             RGBColor[
              0.5211495825009953, 0.37342113688887774`, 0.567742844041897], 
             UndirectedEdge[86, 178] -> 
             RGBColor[
              0.27226239938534696`, 0.40349542256011695`, 0.9388163129176459],
              UndirectedEdge[102, 250] -> 
             RGBColor[
              0.9037621261807391, 0.5693653564012491, 0.505440590565607], 
             UndirectedEdge[7, 222] -> 
             RGBColor[
              0.4971659473495666, 0.600925351032558, 0.9540373638977802], 
             UndirectedEdge[97, 220] -> 
             RGBColor[
              0.4588594812307164, 0.571262237287139, 0.9506250224317093], 
             UndirectedEdge[230, 289] -> 
             RGBColor[
              0.9333052704870481, 0.7676068761755623, 0.28495592618105414`], 
             UndirectedEdge[14, 289] -> 
             RGBColor[
              0.9460551929840001, 0.8094710811761514, 0.43178805845315205`], 
             UndirectedEdge[77, 370] -> 
             RGBColor[
              0.8302908639224114, 0.8675154135193626, 0.9836750778819656], 
             UndirectedEdge[151, 270] -> 
             RGBColor[
              0.28271133263489734`, 0.4138224395491612, 0.9394353643355215], 
             UndirectedEdge[173, 214] -> 
             RGBColor[
              0.6050703523847987, 0.6713378352539525, 0.9242773858520503], 
             UndirectedEdge[144, 317] -> 
             RGBColor[
              0.9345325845565998, 0.7656448596324403, 0.5126377323294256], 
             UndirectedEdge[31, 175] -> 
             RGBColor[
              0.18107477738655686`, 0.3076514502102228, 0.9336233127448126], 
             UndirectedEdge[163, 240] -> 
             RGBColor[
              0.2420898799764604, 0.3717821916131542, 0.9370980325735522], 
             UndirectedEdge[329, 371] -> 
             RGBColor[
              0.25359221551815353`, 0.38387187555766883`, 0.9377530735664711],
              UndirectedEdge[72, 375] -> 
             RGBColor[
              0.24128592482540645`, 0.37093718377569584`, 0.9370522485170447],
              UndirectedEdge[32, 238] -> 
             RGBColor[
              0.22275425852448527`, 0.3514592275179208, 0.9359968975363508], 
             UndirectedEdge[11, 14] -> 
             RGBColor[
              0.9589098698169762, 0.8623003371232989, 0.4422276945427869], 
             UndirectedEdge[79, 237] -> 
             RGBColor[
              0.5846124943759591, 0.6736537852839712, 0.9604419835448554], 
             UndirectedEdge[69, 74] -> 
             RGBColor[
              0.6564460490256175, 0.7292165790501876, 0.9679963956135333], 
             UndirectedEdge[16, 203] -> 
             RGBColor[
              0.2666290431845753, 0.3975744080176934, 0.9384955016158156], 
             UndirectedEdge[315, 319] -> 
             RGBColor[
              0.24242894961997336`, 0.37213857530674344`, 0.9371173420881417],
              UndirectedEdge[40, 80] -> 
             RGBColor[
              0.3368642646638673, 0.46619662758676733`, 0.9426856709603764], 
             UndirectedEdge[18, 198] -> 
             RGBColor[
              0.8858480974802114, 0.9115700695530261, 0.9804738418540726], 
             UndirectedEdge[300, 307] -> 
             RGBColor[
              0.9376183763421341, 0.7907736248179609, 0.5620991500919681], 
             UndirectedEdge[191, 198] -> 
             RGBColor[
              0.7526714957518834, 0.806764542665624, 0.9759689648481673], 
             UndirectedEdge[289, 391] -> 
             RGBColor[
              0.8590720492168273, 0.39317080166904056`, 0.2017773713376896], 
             UndirectedEdge[132, 357] -> 
             RGBColor[
              0.7374562321167385, 0.7948256804953293, 0.9744664033632358], 
             UndirectedEdge[157, 187] -> 
             RGBColor[
              0.656588840938115, 0.7291931341002164, 0.9681680488654731], 
             UndirectedEdge[38, 250] -> 
             RGBColor[
              0.9770092142863354, 0.9428337657309378, 0.5831873792076157], 
             UndirectedEdge[140, 191] -> 
             RGBColor[
              0.6753891788981803, 0.7463384267939157, 0.9682801395479993], 
             UndirectedEdge[204, 261] -> 
             RGBColor[
              0.17918768478614402`, 0.3056679962386074, 0.9335158456129223], 
             UndirectedEdge[337, 354] -> 
             RGBColor[
              0.28225838404285286`, 0.4140018362171884, 0.9393855694561568], 
             UndirectedEdge[300, 314] -> 
             RGBColor[
              0.9079043794586273, 0.7685321222787813, 0.6113544605961532], 
             UndirectedEdge[292, 378] -> 
             RGBColor[
              0.20977255736756456`, 0.3378146365146045, 0.93525760886017], 
             UndirectedEdge[153, 361] -> 
             RGBColor[
              0.3365286408445437, 0.46590592710341294`, 0.9426642853073897], 
             UndirectedEdge[240, 334] -> 
             RGBColor[
              0.2503027734840032, 0.3804144634171059, 0.9375657447089196], 
             UndirectedEdge[52, 260] -> 
             RGBColor[
              0.5977997596730911, 0.6799974627988412, 0.9637251611956289], 
             UndirectedEdge[128, 177] -> 
             RGBColor[
              0.32406082685861914`, 0.45510693327935664`, 0.9418698472250615],
              UndirectedEdge[16, 85] -> 
             RGBColor[
              0.2415839884274967, 0.3712504675198166, 0.9370692227982382], 
             UndirectedEdge[179, 303] -> 
             RGBColor[
              0.27962744891017854`, 0.4112365565818258, 0.9392357415924706], 
             UndirectedEdge[48, 320] -> 
             RGBColor[
              0.5676684575710711, 0.6581064280542859, 0.9600245413086331], 
             UndirectedEdge[136, 320] -> 
             RGBColor[
              0.6642380668783059, 0.7372628617572051, 0.9674177280321361], 
             UndirectedEdge[96, 192] -> 
             RGBColor[
              0.3157006162298024, 0.44584698924097155`, 0.9414110583152703], 
             UndirectedEdge[140, 357] -> 
             RGBColor[
              0.6738075491078213, 0.7451028455808557, 0.9681224974716671], 
             UndirectedEdge[202, 306] -> 
             RGBColor[
              0.913357870811167, 0.6728952265487068, 0.2705007142320376], 
             UndirectedEdge[114, 258] -> 
             RGBColor[
              0.29090557114945215`, 0.42122924819894025`, 0.9399461663762204],
              UndirectedEdge[87, 236] -> 
             RGBColor[
              0.2703304585010046, 0.4014648301985463, 0.938706291742333], 
             UndirectedEdge[116, 362] -> 
             RGBColor[
              0.41044018393094006`, 0.5299243908226783, 0.9473738634754435], 
             UndirectedEdge[36, 64] -> 
             RGBColor[
              0.45931878415001925`, 0.5704587671539738, 0.9509862102607236], 
             UndirectedEdge[245, 304] -> 
             RGBColor[
              0.22449864114749254`, 0.35329268425494775`, 0.9360962375461481],
              UndirectedEdge[187, 218] -> 
             RGBColor[
              0.8769988069965478, 0.9047590594733392, 0.9881301231890498], 
             UndirectedEdge[26, 370] -> 
             RGBColor[
              0.6431647387570222, 0.7183868662092043, 0.9670053375726531], 
             UndirectedEdge[91, 141] -> 
             RGBColor[
              0.3113425799408942, 0.43982647528346147`, 0.9412155979078848], 
             UndirectedEdge[55, 385] -> 
             RGBColor[
              0.4894768493024928, 0.5950665939158499, 0.9533260603680459], 
             UndirectedEdge[179, 231] -> 
             RGBColor[
              0.28916364068982703`, 0.4212596987717169, 0.9397788136067902], 
             UndirectedEdge[94, 177] -> 
             RGBColor[
              0.29101623446385616`, 0.4219899291618881, 0.9399288750630955], 
             UndirectedEdge[225, 383] -> 
             RGBColor[
              0.26867221560749177`, 0.39972191177879235`, 0.938611857262698], 
             UndirectedEdge[37, 134] -> 
             RGBColor[
              0.24206319644531432`, 0.3717541455300861, 0.9370965129859282], 
             UndirectedEdge[255, 341] -> 
             RGBColor[
              0.24102934533176992`, 0.3706675024598044, 0.9370376366944575], 
             UndirectedEdge[206, 278] -> 
             RGBColor[
              0.24198884677049953`, 0.37167599930781414`, 0.937092278881938], 
             UndirectedEdge[131, 279] -> 
             RGBColor[
              0.934057909721427, 0.776268616484077, 0.26579965018330676`], 
             UndirectedEdge[7, 203] -> 
             RGBColor[
              0.3404012849561078, 0.4676562364290735, 0.9429697763439697], 
             UndirectedEdge[101, 151] -> 
             RGBColor[
              0.2883386750076016, 0.41973713317698713`, 0.9397558331587401], 
             UndirectedEdge[200, 296] -> 
             RGBColor[
              0.2860905976760283, 0.41802973572203384`, 0.939603808353314], 
             UndirectedEdge[86, 229] -> 
             RGBColor[
              0.27371625819309475`, 0.4050235203470323, 0.9388991080259558], 
             UndirectedEdge[138, 382] -> 
             RGBColor[
              0.8590618993454652, 0.3914765169996446, 0.2017043627957868], 
             UndirectedEdge[195, 278] -> 
             RGBColor[
              0.24905516487064655`, 0.3791031476615132, 0.9374946952440605], 
             UndirectedEdge[65, 113] -> 
             RGBColor[
              0.6559239156864949, 0.7291861264524664, 0.9676704388099608], 
             UndirectedEdge[249, 270] -> 
             RGBColor[
              0.25957821450255336`, 0.3901635400245296, 0.9380939673531408], 
             UndirectedEdge[319, 388] -> 
             RGBColor[
              0.23247439130222355`, 0.3616757033593372, 0.9365504447183952], 
             UndirectedEdge[138, 256] -> 
             RGBColor[
              0.522325620948562, 0.25191357841785655`, 0.5511492082429574], 
             UndirectedEdge[246, 286] -> 
             RGBColor[
              0.5850263680482788, 0.6724463268342122, 0.9614245811742612], 
             UndirectedEdge[188, 208] -> 
             RGBColor[
              0.25008631824464794`, 0.38018695523648866`, 0.9375534179032552],
              UndirectedEdge[173, 345] -> 
             RGBColor[
              0.21415750276433887`, 0.34242349214821033`, 0.9355073250135709],
              UndirectedEdge[84, 156] -> 
             RGBColor[
              0.18244327672263497`, 0.3090898297803102, 0.9337012467574888], 
             UndirectedEdge[136, 349] -> 
             RGBColor[
              0.5319806271096528, 0.6307093057544687, 0.9563581696523957], 
             UndirectedEdge[117, 346] -> 
             RGBColor[
              0.3472745636844825, 0.4752135053615816, 0.9433490060085041], 
             UndirectedEdge[26, 197] -> 
             RGBColor[
              0.7219321437839568, 0.7790682930787789, 0.8931643392096228], 
             UndirectedEdge[328, 362] -> 
             RGBColor[
              0.35704810596381387`, 0.4836788564514203, 0.9439717674801389], 
             UndirectedEdge[187, 275] -> 
             RGBColor[
              0.9180172404014313, 0.9346976892728417, 0.8827763564020366], 
             UndirectedEdge[20, 121] -> 
             RGBColor[
              0.48042756078829996`, 0.5878320132896839, 0.9525827103922078], 
             UndirectedEdge[198, 302] -> 
             RGBColor[
              0.9068833316004294, 0.9166145009599966, 0.6941933109869335], 
             UndirectedEdge[1, 312] -> 
             RGBColor[
              0.4114701041040899, 0.5305547297160472, 0.9475118048057347], 
             UndirectedEdge[89, 292] -> 
             RGBColor[
              0.21480075229645693`, 0.3430995881908423, 0.9355439571228226], 
             UndirectedEdge[304, 315] -> 
             RGBColor[
              0.23118633013209117`, 0.360321869401733, 0.9364770915402718], 
             UndirectedEdge[21, 64] -> 
             RGBColor[
              0.3559387070583645, 0.4827179508795304, 0.9439010775628867], 
             UndirectedEdge[201, 351] -> 
             RGBColor[
              0.26108538890678307`, 0.3917476758837515, 0.9381797987057969], 
             UndirectedEdge[17, 218] -> 
             RGBColor[
              0.7227901892843811, 0.7824598484159166, 0.9739304322567687], 
             UndirectedEdge[266, 365] -> 
             RGBColor[
              0.25561932448523794`, 0.3860024956082064, 0.9378685144233075], 
             UndirectedEdge[112, 180] -> 
             RGBColor[
              0.34759559659056605`, 0.4754915679292482, 0.9433694619414015], 
             UndirectedEdge[247, 289] -> 
             RGBColor[
              0.9023804239029701, 0.648813195238765, 0.2402147401558417], 
             UndirectedEdge[15, 45] -> 
             RGBColor[
              0.29968000514429743`, 0.4323130645893829, 0.9403777050049051], 
             UndirectedEdge[57, 92] -> 
             RGBColor[
              0.2804356326225079, 0.4120860089052909, 0.9392817664592872], 
             UndirectedEdge[53, 86] -> 
             RGBColor[
              0.2948901577623302, 0.4272786312970708, 0.9401049302824465], 
             UndirectedEdge[114, 154] -> 
             RGBColor[
              0.3795179550306004, 0.5031411103456188, 0.9454035263933673], 
             UndirectedEdge[71, 237] -> 
             RGBColor[
              0.7247695222504801, 0.7843485609125668, 0.9737619050151656], 
             UndirectedEdge[241, 375] -> 
             RGBColor[
              0.2729036444443398, 0.40416941177440335`, 0.9388528308751185], 
             UndirectedEdge[100, 282] -> 
             RGBColor[
              0.5117379294109875, 0.6123392626277626, 0.9553276443786378], 
             UndirectedEdge[55, 146] -> 
             RGBColor[
              0.4694319452875655, 0.5787932378238967, 0.951748052097088], 
             UndirectedEdge[309, 319] -> 
             RGBColor[
              0.25618706106620875`, 0.38659922275138503`, 0.9379008461817029],
              UndirectedEdge[13, 302] -> 
             RGBColor[
              0.9755285816369456, 0.9706262250120263, 0.6756345411379316], 
             UndirectedEdge[110, 348] -> 
             RGBColor[
              0.25926658322907375`, 0.3898359957975386, 0.9380762204131332], 
             UndirectedEdge[217, 363] -> 
             RGBColor[
              0.8426690815936368, 0.3225184221692448, 0.1882402931746939], 
             UndirectedEdge[39, 380] -> 
             RGBColor[
              0.2692913647455158, 0.4003726767791782, 0.9386471168901593], 
             UndirectedEdge[248, 304] -> 
             RGBColor[
              0.2176531615259033, 0.3460976511441812, 0.9357063976086782], 
             UndirectedEdge[204, 400] -> 
             RGBColor[
              0.2842689537951664, 0.40863855928315673`, 0.939773820202813], 
             UndirectedEdge[69, 168] -> 
             RGBColor[
              0.5791845558214077, 0.6688214100579597, 0.9603057503889199], 
             UndirectedEdge[68, 86] -> 
             RGBColor[
              0.28863048877409425`, 0.42069932230449786`, 0.9397484513939167],
              UndirectedEdge[175, 264] -> 
             RGBColor[
              0.18448157797338877`, 0.31123221363061604`, 0.9338173249983228],
              UndirectedEdge[1, 92] -> 
             RGBColor[
              0.3238234376355826, 0.4529521291016748, 0.9419260903719718], 
             UndirectedEdge[368, 393] -> 
             RGBColor[
              0.21780075210083538`, 0.3462527781962177, 0.93571480267358], 
             UndirectedEdge[332, 361] -> 
             RGBColor[
              0.4414240641856033, 0.5547544143941453, 0.9499025740169657], 
             UndirectedEdge[80, 203] -> 
             RGBColor[
              0.31290698696191654`, 0.4438420574101029, 0.9412178639880329], 
             UndirectedEdge[20, 347] -> 
             RGBColor[
              0.3438545327447645, 0.469598113054395, 0.9432282288718172], 
             UndirectedEdge[18, 311] -> 
             RGBColor[
              0.7322903023542322, 0.7896729975900088, 0.9664706721730203], 
             UndirectedEdge[170, 282] -> 
             RGBColor[
              0.5459157043281511, 0.6419423334360943, 0.9575054219741398], 
             UndirectedEdge[198, 323] -> 
             RGBColor[
              0.828349936933913, 0.8659677710237936, 0.9834899505331167], 
             UndirectedEdge[168, 357] -> 
             RGBColor[
              0.6729202964028389, 0.7444097170243531, 0.9680340644138824], 
             UndirectedEdge[180, 326] -> 
             RGBColor[
              0.3528301288862901, 0.48002545670856134`, 0.9437030017105699], 
             UndirectedEdge[18, 340] -> 
             RGBColor[
              0.9694923470519816, 0.9738780487256253, 0.770900506424754], 
             UndirectedEdge[74, 340] -> 
             RGBColor[
              0.9092258023331339, 0.9260683158029884, 0.7736525641500547], 
             UndirectedEdge[173, 204] -> 
             RGBColor[
              0.20264730553141047`, 0.33032554506774736`, 0.9348518363089665],
              UndirectedEdge[26, 30] -> 
             RGBColor[
              0.31701994287924884`, 0.4369570883961569, 0.9418741496415883], 
             UndirectedEdge[169, 240] -> 
             RGBColor[
              0.22995248947003588`, 0.35902502463589653`, 0.9364068261398715],
              UndirectedEdge[95, 371] -> 
             RGBColor[
              0.27691206805261726`, 0.40838251913543877`, 0.9390811046696785],
              UndirectedEdge[65, 356] -> 
             RGBColor[
              0.5168552955479615, 0.6186454388483807, 0.9551078886503179], 
             UndirectedEdge[264, 310] -> 
             RGBColor[
              0.18630458251799184`, 0.3131483069921579, 0.9339211424102444], 
             UndirectedEdge[96, 114] -> 
             RGBColor[
              0.3078946845637386, 0.4390858835693603, 0.940913671252023], 
             UndirectedEdge[244, 308] -> 
             RGBColor[
              0.2605622771689302, 0.3911978522800683, 0.9381500082662007], 
             UndirectedEdge[187, 298] -> 
             RGBColor[
              0.8336819864556111, 0.8702194025777671, 0.983998526176473], 
             UndirectedEdge[58, 228] -> 
             RGBColor[
              0.3333340850867448, 0.46222040417284493`, 0.9424943639948453], 
             UndirectedEdge[36, 82] -> 
             RGBColor[
              0.4494472254875384, 0.5619085191994977, 0.950357203271827], 
             UndirectedEdge[72, 355] -> 
             RGBColor[
              0.2293238377834227, 0.358364271854447, 0.9363710253563257], 
             UndirectedEdge[22, 350] -> 
             RGBColor[
              0.36253057369193453`, 0.4869086502715662, 0.9443767178010922], 
             UndirectedEdge[58, 192] -> 
             RGBColor[
              0.32165036846239214`, 0.45210055607350297`, 0.9417498879030466],
              UndirectedEdge[3, 174] -> 
             RGBColor[
              0.5493425209245979, 0.6414387311936623, 0.9591931799908751], 
             UndirectedEdge[44, 54] -> 
             RGBColor[
              0.3749740145051137, 0.4982078184475008, 0.9451505160427869], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.416297218948796, 0.5331956497034136, 0.948244914168578], 
             UndirectedEdge[170, 271] -> 
             RGBColor[
              0.37587875919358854`, 0.49980798052879155`, 0.9451782688612774],
              UndirectedEdge[192, 201] -> 
             RGBColor[
              0.3104580154232146, 0.4403366833931581, 0.941112499955068], 
             UndirectedEdge[274, 395] -> 
             RGBColor[
              0.2518980358087536, 0.3820911852658918, 0.9376565925383351], 
             UndirectedEdge[208, 284] -> 
             RGBColor[
              0.23854240400840393`, 0.3680535694477596, 0.9368960090651918], 
             UndirectedEdge[237, 320] -> 
             RGBColor[
              0.644156525821959, 0.7209597620645476, 0.9658368355590718], 
             UndirectedEdge[119, 380] -> 
             RGBColor[
              0.25299451614994406`, 0.383243655625352, 0.9377190354716685], 
             UndirectedEdge[342, 398] -> 
             RGBColor[
              0.7713918010534688, 0.8216082690775031, 0.9746694433091629], 
             UndirectedEdge[90, 264] -> 
             RGBColor[
              0.44791840801160593`, 0.5435825734144455, 0.9527225707160447], 
             UndirectedEdge[212, 367] -> 
             RGBColor[
              0.21510593499852879`, 0.3434203545604207, 0.9355613368262283], 
             UndirectedEdge[92, 284] -> 
             RGBColor[
              0.26583096592771405`, 0.3967355782197115, 0.9384500522966869], 
             UndirectedEdge[267, 342] -> 
             RGBColor[
              0.5872785724074823, 0.6758182275354083, 0.9606518669736626], 
             UndirectedEdge[107, 297] -> 
             RGBColor[
              0.892928350056968, 0.6310869487653001, 0.5801992997291281], 
             UndirectedEdge[163, 245] -> 
             RGBColor[
              0.2374360489235272, 0.36689072010659024`, 0.9368330037798137], 
             UndirectedEdge[72, 200] -> 
             RGBColor[
              0.24919308184682543`, 0.37924810714791846`, 0.937502549411824], 
             UndirectedEdge[254, 286] -> 
             RGBColor[
              0.5978806349455185, 0.6831403582378857, 0.9623651309393161], 
             UndirectedEdge[269, 307] -> 
             RGBColor[
              0.9891494518709179, 0.9878632201941573, 0.6900803930330166], 
             UndirectedEdge[240, 304] -> 
             RGBColor[
              0.22915247220042573`, 0.35818415576151175`, 0.9363612663398866],
              UndirectedEdge[228, 332] -> 
             RGBColor[
              0.44753939238477464`, 0.5600512043149352, 0.9502922373222444], 
             UndirectedEdge[104, 109] -> 
             RGBColor[
              0.9639852685830836, 0.8836832833010115, 0.5065761886025747], 
             UndirectedEdge[28, 372] -> 
             RGBColor[
              0.2698833093261751, 0.4009948480649053, 0.9386808272583244], 
             UndirectedEdge[28, 362] -> 
             RGBColor[
              0.34647407000563907`, 0.4726287790194402, 0.9433672519077005], 
             UndirectedEdge[209, 227] -> 
             RGBColor[
              0.24347750032410487`, 0.3732406685787401, 0.9371770554995502], 
             UndirectedEdge[245, 371] -> 
             RGBColor[
              0.25097222698134913`, 0.38111810148861974`, 0.9376038690952258],
              UndirectedEdge[308, 397] -> 
             RGBColor[
              0.25521896402580857`, 0.3855816913810268, 0.9378457144874233], 
             UndirectedEdge[58, 87] -> 
             RGBColor[
              0.29447485481202706`, 0.42684212156457424`, 0.9400812793938123],
              UndirectedEdge[154, 332] -> 
             RGBColor[
              0.47868981834297064`, 0.5870321376139921, 0.9522771149190605], 
             UndirectedEdge[97, 180] -> 
             RGBColor[
              0.40427723483543804`, 0.5245863540749827, 0.9469811658087601], 
             UndirectedEdge[202, 300] -> 
             RGBColor[
              0.873168201892003, 0.5137197571930974, 0.21575357463755512`], 
             UndirectedEdge[25, 317] -> 
             RGBColor[
              0.9196690890458292, 0.6829063077266104, 0.4996382373528887], 
             UndirectedEdge[93, 128] -> 
             RGBColor[
              0.2857256322546389, 0.41603117628641406`, 0.9396421556226617], 
             UndirectedEdge[68, 178] -> 
             RGBColor[
              0.2603565331566741, 0.3909816022782634, 0.9381382914490737], 
             UndirectedEdge[271, 273] -> 
             RGBColor[
              0.2911126400044641, 0.42330822062509427`, 0.9398898062344726], 
             UndirectedEdge[149, 318] -> 
             RGBColor[
              0.22201805165799737`, 0.3506854274230307, 0.9359549716444248], 
             UndirectedEdge[42, 358] -> 
             RGBColor[
              0.9504012676368335, 0.9272297470138823, 0.6629122325696076], 
             UndirectedEdge[155, 170] -> 
             RGBColor[
              0.3747576276064379, 0.498629600146848, 0.9451144220759548], 
             UndirectedEdge[193, 338] -> 
             RGBColor[
              0.9083139927934867, 0.9256835176042191, 0.801309811633953], 
             UndirectedEdge[79, 109] -> 
             RGBColor[
              0.79245120355282, 0.8352543310125031, 0.854215095221335], 
             UndirectedEdge[173, 175] -> 
             RGBColor[
              0.20264987627198583`, 0.3303282470790865, 0.9348519827088393], 
             UndirectedEdge[95, 178] -> 
             RGBColor[
              0.2628834870920424, 0.39363759108246865`, 0.9382821977373995], 
             UndirectedEdge[243, 348] -> 
             RGBColor[
              0.27566358738232355`, 0.40707028679271356`, 0.9390100055424669],
              UndirectedEdge[56, 83] -> 
             RGBColor[
              0.4019083501795848, 0.5225345452496872, 0.9468302225732115], 
             UndirectedEdge[205, 207] -> 
             RGBColor[
              0.967562165289962, 0.8957834071543473, 0.4992706546503005], 
             UndirectedEdge[74, 302] -> 
             RGBColor[
              0.9059752552459537, 0.9158904255240137, 0.6941066978535942], 
             UndirectedEdge[179, 196] -> 
             RGBColor[
              0.2837836367777321, 0.41560497354815545`, 0.9394724303429989], 
             UndirectedEdge[174, 338] -> 
             RGBColor[
              0.8614468790047858, 0.8890515325777966, 0.796643588235805], 
             UndirectedEdge[159, 167] -> 
             RGBColor[
              0.30749203096032607`, 0.43842628345076595`, 0.9408993959616536],
              UndirectedEdge[251, 356] -> 
             RGBColor[
              0.6703471241239707, 0.7405191581131181, 0.9690711033483659], 
             UndirectedEdge[238, 277] -> 
             RGBColor[
              0.24351796868213066`, 0.3732832033888673, 0.9371793601126722], 
             UndirectedEdge[163, 164] -> 
             RGBColor[
              0.24375587866941067`, 0.373533261869863, 0.9371929087344915], 
             UndirectedEdge[213, 230] -> 
             RGBColor[
              0.939912673270707, 0.7956677722978341, 0.2903688589282392], 
             UndirectedEdge[246, 343] -> 
             RGBColor[
              0.5830017143905886, 0.6708646520088869, 0.9612227826191269], 
             UndirectedEdge[53, 95] -> 
             RGBColor[
              0.2855112454690256, 0.4174207998194225, 0.9395708151022], 
             UndirectedEdge[139, 184] -> 
             RGBColor[
              0.21446679583023515`, 0.34274857877078024`, 0.9355249387961155],
              UndirectedEdge[101, 308] -> 
             RGBColor[
              0.26096510566357906`, 0.39162125056874597`, 0.9381729487530396],
              UndirectedEdge[3, 52] -> 
             RGBColor[
              0.3783625716146186, 0.5021403753019544, 0.9453299063837663], 
             UndirectedEdge[136, 286] -> 
             RGBColor[
              0.6724159966518739, 0.7436515226508849, 0.9682328276448666], 
             UndirectedEdge[164, 169] -> 
             RGBColor[
              0.23161848816298614`, 0.3607760948926053, 0.9365017023008109], 
             UndirectedEdge[14, 102] -> 
             RGBColor[
              0.9068270565903578, 0.5698348658899638, 0.39664654648642544`], 
             UndirectedEdge[232, 281] -> 
             RGBColor[
              0.5787753460534887, 0.6689149253152545, 0.9599824618467317], 
             UndirectedEdge[56, 349] -> 
             RGBColor[
              0.44815708600119175`, 0.5625928756893122, 0.949777151123613], 
             UndirectedEdge[225, 324] -> 
             RGBColor[
              0.2685328797360218, 0.39957546094347285`, 0.9386039222909468], 
             UndirectedEdge[5, 272] -> 
             RGBColor[
              0.744229977263282, 0.800290827008182, 0.9750955199196911], 
             UndirectedEdge[68, 371] -> 
             RGBColor[
              0.27438511411724903`, 0.40572653033123346`, 0.9389371983813526],
              UndirectedEdge[151, 397] -> 
             RGBColor[
              0.28259253336983103`, 0.413697573989268, 0.9394285988931239], 
             UndirectedEdge[1, 356] -> 
             RGBColor[
              0.43918071918933627`, 0.5530514553912338, 0.949693285932573], 
             UndirectedEdge[96, 115] -> 
             RGBColor[
              0.262758793949384, 0.3935065306835328, 0.9382750966473921], 
             UndirectedEdge[328, 347] -> 
             RGBColor[
              0.29474363512034735`, 0.42706072191761096`, 0.940098925902251], 
             UndirectedEdge[80, 159] -> 
             RGBColor[
              0.3329254963503931, 0.4627850644418876, 0.9424346961263579], 
             UndirectedEdge[50, 121] -> 
             RGBColor[
              0.5036718866822538, 0.607942553625398, 0.9540700424119916], 
             UndirectedEdge[108, 342] -> 
             RGBColor[
              0.48546363914421214`, 0.5908319937486516, 0.9532799343430639], 
             UndirectedEdge[178, 315] -> 
             RGBColor[
              0.24363133500537287`, 0.37340235858243487`, 0.9371858161570703],
              UndirectedEdge[146, 228] -> 
             RGBColor[
              0.45159420731101624`, 0.5633430857393887, 0.9506114472065146], 
             UndirectedEdge[63, 152] -> 
             RGBColor[
              0.5710886094431091, 0.5911007265104762, 0.6136429928057057], 
             UndirectedEdge[43, 137] -> 
             RGBColor[
              0.22449567090087896`, 0.35328956233743236`, 0.9360960683949977],
              UndirectedEdge[97, 141] -> 
             RGBColor[
              0.401174197469898, 0.5218986590721447, 0.9467834430117361], 
             UndirectedEdge[25, 207] -> 
             RGBColor[
              0.8942834665962583, 0.5873379716371798, 0.2323719540995589], 
             UndirectedEdge[214, 310] -> 
             RGBColor[
              0.5831756221385668, 0.6483250855590861, 0.9230305133548782], 
             UndirectedEdge[37, 87] -> 
             RGBColor[
              0.2699691213947309, 0.4010850419897568, 0.9386857141286811], 
             UndirectedEdge[146, 262] -> 
             RGBColor[
              0.736987048840004, 0.7937027834714817, 0.9726540973253948], 
             UndirectedEdge[322, 364] -> 
             RGBColor[
              0.428972946302528, 0.5444804947900268, 0.9489681159313363], 
             UndirectedEdge[219, 311] -> 
             RGBColor[
              0.48328094147507245`, 0.5912218175992272, 0.9525107826182344], 
             UndirectedEdge[5, 260] -> 
             RGBColor[
              0.8251985302055844, 0.863544075950503, 0.9831657085828327], 
             UndirectedEdge[204, 389] -> 
             RGBColor[
              0.17900756331513207`, 0.305478677152213, 0.9335055879616141], 
             UndirectedEdge[275, 279] -> 
             RGBColor[
              0.9688751403565641, 0.9066136951652177, 0.5278514920501343], 
             UndirectedEdge[78, 289] -> 
             RGBColor[
              0.8697986288874946, 0.4756199934349731, 0.21204915614425965`], 
             UndirectedEdge[163, 329] -> 
             RGBColor[
              0.2400560374603316, 0.3696444941756393, 0.936982208251059], 
             UndirectedEdge[47, 181] -> 
             RGBColor[
              0.5006021052009016, 0.6049229030605833, 0.9539741177513421], 
             UndirectedEdge[267, 291] -> 
             RGBColor[
              0.6338452626420983, 0.7127939223878283, 0.964884724751121], 
             UndirectedEdge[28, 301] -> 
             RGBColor[
              0.27255350960952185`, 0.40380139786317903`, 0.9388328912142536],
              UndirectedEdge[174, 193] -> 
             RGBColor[
              0.7754724977883137, 0.8245433157037161, 0.9782504569369469], 
             UndirectedEdge[60, 263] -> 
             RGBColor[
              0.3098059764171655, 0.4384458415430197, 0.9411195068336586], 
             UndirectedEdge[122, 385] -> 
             RGBColor[
              0.510754315643456, 0.6134960658238386, 0.9546818417083673], 
             UndirectedEdge[282, 350] -> 
             RGBColor[
              0.5398022619922347, 0.6366471769552697, 0.9571158788344], 
             UndirectedEdge[142, 306] -> 
             RGBColor[
              0.8959800446329425, 0.5393216395308846, 0.25385968825832217`], 
             UndirectedEdge[6, 289] -> 
             RGBColor[
              0.9455504255792939, 0.808391434737298, 0.3768472415142159], 
             UndirectedEdge[3, 117] -> 
             RGBColor[
              0.35979838664313185`, 0.4860610113427193, 0.9441470129330474], 
             UndirectedEdge[6, 132] -> 
             RGBColor[
              0.896284952197167, 0.9156286210821021, 0.7489609820272407], 
             UndirectedEdge[22, 394] -> 
             RGBColor[
              0.32559317401626164`, 0.45491533120018696`, 0.9420230993562184],
              UndirectedEdge[11, 391] -> 
             RGBColor[
              0.8719267260498035, 0.4460000576161881, 0.2122170074273244], 
             UndirectedEdge[34, 249] -> 
             RGBColor[
              0.2909291460215572, 0.4227877812822719, 0.9398913506685179], 
             UndirectedEdge[269, 306] -> 
             RGBColor[
              0.9817175223804617, 0.9496479498761543, 0.4126513364277588], 
             UndirectedEdge[69, 394] -> 
             RGBColor[
              0.42354328649608, 0.5403260059804602, 0.948470615599907], 
             UndirectedEdge[361, 369] -> 
             RGBColor[
              0.30654023496768024`, 0.43518917662023243`, 0.9409270894573605],
              UndirectedEdge[85, 184] -> 
             RGBColor[
              0.22953519250719354`, 0.35858641906979366`, 0.9363830616951732],
              UndirectedEdge[73, 96] -> 
             RGBColor[
              0.26501373249139615`, 0.3958766140625488, 0.9384035120614771], 
             UndirectedEdge[71, 382] -> 
             RGBColor[
              0.8849504676641144, 0.7666705508963009, 0.612411028914603], 
             UndirectedEdge[122, 165] -> 
             RGBColor[
              0.48941818004964077`, 0.5961744297668246, 0.9530021829575823], 
             UndirectedEdge[321, 331] -> 
             RGBColor[
              0.634939466831133, 0.7117908877119044, 0.9662504402131629], 
             UndirectedEdge[296, 374] -> 
             RGBColor[
              0.2888126336637139, 0.4208907681321412, 0.9397588242759214], 
             UndirectedEdge[66, 297] -> 
             RGBColor[
              0.9597109537164616, 0.9397882388587341, 0.661988741969209], 
             UndirectedEdge[75, 145] -> 
             RGBColor[
              0.24110109065239455`, 0.37074291134069687`, 0.9370417224843294],
              UndirectedEdge[105, 239] -> 
             RGBColor[
              0.37092951443948974`, 0.4957022347731742, 0.9448562785533615], 
             UndirectedEdge[92, 354] -> 
             RGBColor[
              0.2837186388686095, 0.41553665662456213`, 0.9394687288082302], 
             UndirectedEdge[188, 369] -> 
             RGBColor[
              0.26226993371413826`, 0.39299270758076044`, 0.9382472567801988],
              UndirectedEdge[170, 251] -> 
             RGBColor[
              0.6336427393204518, 0.7104942073432939, 0.966244231440377], 
             UndirectedEdge[53, 68] -> 
             RGBColor[
              0.28298429153365734`, 0.4147648110152172, 0.9394269088138741], 
             UndirectedEdge[274, 318] -> 
             RGBColor[
              0.2272727207343431, 0.3562084177875322, 0.9362542172747363], 
             UndirectedEdge[179, 359] -> 
             RGBColor[
              0.2576056390091489, 0.3880902381124516, 0.9379816320969553], 
             UndirectedEdge[20, 328] -> 
             RGBColor[
              0.3585480828066595, 0.484978061001665, 0.9440673446781876], 
             UndirectedEdge[307, 352] -> 
             RGBColor[
              0.9896970551583855, 0.989034488254865, 0.7496836314580985], 
             UndirectedEdge[6, 216] -> 
             RGBColor[
              0.8262245586177389, 0.8608969091391403, 0.7419780167468455], 
             UndirectedEdge[297, 385] -> 
             RGBColor[
              0.76103003285282, 0.8129579010796052, 0.9674643990261943], 
             UndirectedEdge[40, 348] -> 
             RGBColor[
              0.3011336768698887, 0.43101491807386594`, 0.9405639649079968], 
             UndirectedEdge[229, 329] -> 
             RGBColor[
              0.2410174933653264, 0.37065504529161414`, 0.937036961742502], 
             UndirectedEdge[6, 213] -> 
             RGBColor[
              0.9521578283629528, 0.8364523308595698, 0.38226017426140096`], 
             UndirectedEdge[189, 374] -> 
             RGBColor[
              0.2883252349784382, 0.42037848121105487`, 0.9397310676418367], 
             UndirectedEdge[97, 140] -> 
             RGBColor[
              0.5571047214907582, 0.6505692358866151, 0.9586689069541604], 
             UndirectedEdge[34, 386] -> 
             RGBColor[
              0.32582607560218535`, 0.4566359030170521, 0.9419823273140535], 
             UndirectedEdge[162, 313] -> 
             RGBColor[
              0.26444617460999714`, 0.3952800747439503, 0.938371190479758], 
             UndirectedEdge[258, 392] -> 
             RGBColor[
              0.25044123686096187`, 0.3805599972053746, 0.9375736299933992], 
             UndirectedEdge[45, 273] -> 
             RGBColor[
              0.2854682454604019, 0.41737560408400093`, 0.9395683663153217], 
             UndirectedEdge[226, 393] -> 
             RGBColor[
              0.2307270128999809, 0.3598390978683905, 0.9364509341034022], 
             UndirectedEdge[88, 168] -> 
             RGBColor[
              0.8302321284771527, 0.8662542155842119, 0.8889737374567761], 
             UndirectedEdge[188, 327] -> 
             RGBColor[
              0.2928390260811543, 0.4242124195155595, 0.9400214534598996], 
             UndirectedEdge[59, 349] -> 
             RGBColor[
              0.38969866664907243`, 0.5119591310520951, 0.9460522323352465], 
             UndirectedEdge[260, 398] -> 
             RGBColor[
              0.8741897182555676, 0.9025122258100744, 0.9845069042800476], 
             UndirectedEdge[248, 353] -> 
             RGBColor[
              0.21329376874399575`, 0.34151565292892977`, 0.9354581366388923],
              UndirectedEdge[30, 389] -> 
             RGBColor[
              0.17900757935671766`, 0.3054786940129366, 0.9335055888751587], 
             UndirectedEdge[216, 311] -> 
             RGBColor[
              0.5892378065656463, 0.6771523472031584, 0.9609814583426657], 
             UndirectedEdge[66, 307] -> 
             RGBColor[
              0.9790114308840521, 0.9540083964475, 0.6215212155905427], 
             UndirectedEdge[94, 225] -> 
             RGBColor[
              0.2586160366315361, 0.3891522300764899, 0.9380391727468009], 
             UndirectedEdge[177, 324] -> 
             RGBColor[
              0.3009330775683418, 0.4324131600288711, 0.9404936246072413], 
             UndirectedEdge[79, 320] -> 
             RGBColor[
              0.6503499887449748, 0.725987894277777, 0.9663244076477739], 
             UndirectedEdge[133, 234] -> 
             RGBColor[
              0.31799880832538563`, 0.4487941940432452, 0.9415224703076799], 
             UndirectedEdge[35, 195] -> 
             RGBColor[
              0.2633678783864708, 0.39414671704509485`, 0.9383097831050244], 
             UndirectedEdge[34, 86] -> 
             RGBColor[
              0.30641268277319833`, 0.4390619601211778, 0.940773115180684], 
             UndirectedEdge[98, 131] -> 
             RGBColor[
              0.9500181408117219, 0.8331560489585412, 0.3119185917864623], 
             UndirectedEdge[173, 261] -> 
             RGBColor[
              0.2029079903175545, 0.3305995413063548, 0.9348666819218888], 
             UndirectedEdge[103, 331] -> 
             RGBColor[
              0.39832931347278433`, 0.519434563541872, 0.9466021695190721], 
             UndirectedEdge[135, 322] -> 
             RGBColor[
              0.5058470879872912, 0.6097084800365293, 0.954241282226749], 
             UndirectedEdge[50, 181] -> 
             RGBColor[
              0.5107299622168331, 0.6136726173070488, 0.9546256799726562], 
             UndirectedEdge[35, 153] -> 
             RGBColor[
              0.2992359056961653, 0.4310433224437109, 0.940381814697533], 
             UndirectedEdge[121, 362] -> 
             RGBColor[
              0.4789275839454543, 0.5865328087394392, 0.9524871331941591], 
             UndirectedEdge[84, 152] -> 
             RGBColor[
              0.18127159018880934`, 0.30785831294404253`, 0.9336345209427424],
              UndirectedEdge[295, 345] -> 
             RGBColor[
              0.22216737223106828`, 0.3508423728127994, 0.9359634752301611], 
             UndirectedEdge[22, 266] -> 
             RGBColor[
              0.27365816407618504`, 0.40496245974678047`, 0.9388957996519403],
              UndirectedEdge[271, 335] -> 
             RGBColor[
              0.2936530311811995, 0.4259783328219468, 0.9400344777538158], 
             UndirectedEdge[175, 261] -> 
             RGBColor[
              0.1791902555267194, 0.3056706982499465, 0.9335159920127951], 
             UndirectedEdge[59, 254] -> 
             RGBColor[
              0.401764791398701, 0.521970513340684, 0.9469425623795822], 
             UndirectedEdge[53, 270] -> 
             RGBColor[
              0.26941555401375766`, 0.4005032075741548, 0.9386541892852642], 
             UndirectedEdge[214, 300] -> 
             RGBColor[
              0.9368849358196452, 0.7904007327583793, 0.5711375264891978], 
             UndirectedEdge[3, 386] -> 
             RGBColor[
              0.35472139925516205`, 0.48166358004406556`, 0.9438235117860897],
              UndirectedEdge[299, 336] -> 
             RGBColor[
              0.2125676316732109, 0.34075243682778544`, 0.9354167842069347], 
             UndirectedEdge[110, 351] -> 
             RGBColor[
              0.25066121746090764`, 0.3807912107634932, 0.9375861575631339], 
             UndirectedEdge[172, 328] -> 
             RGBColor[
              0.3054309232922502, 0.438293739399488, 0.9407075511532149], 
             UndirectedEdge[185, 302] -> 
             RGBColor[
              0.905483758897311, 0.5759228028237954, 0.28769672462851575`], 
             UndirectedEdge[370, 391] -> 
             RGBColor[
              0.8258037070409253, 0.5129958576116641, 0.5754614637475668], 
             UndirectedEdge[50, 364] -> 
             RGBColor[
              0.4018386991300539, 0.5224516905515073, 0.9468320085978967], 
             UndirectedEdge[73, 195] -> 
             RGBColor[
              0.2444053413712617, 0.37421588834782205`, 0.937229894674568], 
             UndirectedEdge[80, 332] -> 
             RGBColor[
              0.4308190028061351, 0.5455688432531333, 0.9492268288835535], 
             UndirectedEdge[5, 267] -> 
             RGBColor[
              0.7063209858486378, 0.7695859535146778, 0.9720624004607035], 
             UndirectedEdge[136, 246] -> 
             RGBColor[
              0.5311924849620417, 0.6300266566393842, 0.9563079499316767], 
             UndirectedEdge[59, 246] -> 
             RGBColor[
              0.38891052450146135`, 0.5112764819370106, 0.9460020126145274], 
             UndirectedEdge[177, 200] -> 
             RGBColor[
              0.2962840776702533, 0.42752676637236176`, 0.9402288709406241], 
             UndirectedEdge[17, 157] -> 
             RGBColor[
              0.5023802232259484, 0.6068939230427937, 0.9539683579331921], 
             UndirectedEdge[151, 386] -> 
             RGBColor[
              0.3275993292124569, 0.45817180616795133`, 0.9420953174660733], 
             UndirectedEdge[4, 188] -> 
             RGBColor[
              0.24964120798061978`, 0.37971911612737436`, 0.9375280695322004],
              UndirectedEdge[241, 255] -> 
             RGBColor[
              0.2757184631493581, 0.40712796470319146`, 0.9390131306362182], 
             UndirectedEdge[62, 345] -> 
             RGBColor[
              0.19050782677282135`, 0.3175661832050619, 0.9341605109524143], 
             UndirectedEdge[57, 114] -> 
             RGBColor[
              0.3010426520782409, 0.43188396298315035`, 0.9405234581386476], 
             UndirectedEdge[32, 137] -> 
             RGBColor[
              0.21892075175740905`, 0.34742996884735633`, 0.9357785849971308],
              UndirectedEdge[152, 175] -> 
             RGBColor[
              0.181274153781999, 0.307861007443026, 0.9336346669355821], 
             UndirectedEdge[99, 235] -> 
             RGBColor[
              0.8591106393434069, 0.8900471270857477, 0.9483188623764983], 
             UndirectedEdge[156, 256] -> 
             RGBColor[
              0.20563395231845213`, 0.3334647002052716, 0.9350219214251405], 
             UndirectedEdge[48, 286] -> 
             RGBColor[
              0.5758463873446392, 0.6644950889479655, 0.9608396409213635], 
             UndirectedEdge[61, 262] -> 
             RGBColor[
              0.9659943820446136, 0.9709682059989204, 0.7529333373497976], 
             UndirectedEdge[146, 385] -> 
             RGBColor[
              0.5553761412741389, 0.6499183967532158, 0.95814039073239], 
             UndirectedEdge[29, 150] -> 
             RGBColor[
              0.2555149933709343, 0.38589283699209853`, 0.937862572920692], 
             UndirectedEdge[141, 220] -> 
             RGBColor[
              0.4177492311275311, 0.5356546049090093, 0.9480055136475012], 
             UndirectedEdge[152, 242] -> 
             RGBColor[
              0.5509815030039178, 0.5121510355041116, 0.5934630978551525], 
             UndirectedEdge[95, 151] -> 
             RGBColor[
              0.2988070240901653, 0.4307400317944288, 0.9403519901524575], 
             UndirectedEdge[252, 293] -> 
             RGBColor[
              0.21778209463220533`, 0.3462331680137357, 0.9357137401583427], 
             UndirectedEdge[93, 390] -> 
             RGBColor[
              0.2557686929307827, 0.3861594913149804, 0.9378770207353105], 
             UndirectedEdge[229, 249] -> 
             RGBColor[
              0.2582327214414536, 0.38874934150812634`, 0.9380173435137897], 
             UndirectedEdge[96, 153] -> 
             RGBColor[
              0.3021711245350493, 0.4341284235470012, 0.9405489710681403], 
             UndirectedEdge[202, 217] -> 
             RGBColor[
              0.8395826476787889, 0.30525515205179155`, 0.18553769416040178`],
              UndirectedEdge[163, 304] -> 
             RGBColor[
              0.23203584179739814`, 0.3612147600241211, 0.9365254699728711], 
             UndirectedEdge[18, 323] -> 
             RGBColor[
              0.8877084052982851, 0.9130534285104475, 0.9806512796744769], 
             UndirectedEdge[152, 264] -> 
             RGBColor[
              0.186823590274237, 0.31369381705096394`, 0.9339506991341594], 
             UndirectedEdge[23, 169] -> 
             RGBColor[
              0.21705819820147026`, 0.34547230696734843`, 0.9356725153275212],
              UndirectedEdge[290, 342] -> 
             RGBColor[
              0.5042459583975736, 0.6071002946590989, 0.9544767271173353], 
             UndirectedEdge[285, 330] -> 
             RGBColor[
              0.23174352854992997`, 0.3609075202673017, 0.9365088231658666], 
             UndirectedEdge[55, 192] -> 
             RGBColor[
              0.3740111987150174, 0.498371434802681, 0.9450526407503718], 
             UndirectedEdge[161, 170] -> 
             RGBColor[
              0.43820314080929235`, 0.5539712686639211, 0.9491428945379133], 
             UndirectedEdge[42, 205] -> 
             RGBColor[
              0.9637471875060623, 0.9705535185426564, 0.8607371274369169], 
             UndirectedEdge[267, 398] -> 
             RGBColor[
              0.7553121738986209, 0.8085541033742493, 0.9734035961579184], 
             UndirectedEdge[32, 199] -> 
             RGBColor[
              0.22104408708317058`, 0.349661728901967, 0.9358995058027398], 
             UndirectedEdge[154, 385] -> 
             RGBColor[
              0.5027895372841396, 0.606597375130399, 0.9541743330742887], 
             UndirectedEdge[91, 190] -> 
             RGBColor[
              0.25186209923856306`, 0.38205341365211143`, 0.9376545460038261],
              UndirectedEdge[94, 380] -> 
             RGBColor[
              0.2628073165498582, 0.39355753101314184`, 0.9382778599377064], 
             UndirectedEdge[119, 288] -> 
             RGBColor[
              0.2427621793276949, 0.37248882085754254`, 0.9371363190270272], 
             UndirectedEdge[65, 251] -> 
             RGBColor[
              0.6688240146939028, 0.7392826292624911, 0.9689511985946974], 
             UndirectedEdge[198, 216] -> 
             RGBColor[
              0.7427956016916255, 0.7990494191661757, 0.974984628023718], 
             UndirectedEdge[101, 182] -> 
             RGBColor[
              0.2744680720566198, 0.40581372438534935`, 0.9389419227132746], 
             UndirectedEdge[11, 230] -> 
             RGBColor[
              0.9461599473200244, 0.8204361321227099, 0.29539556227068897`], 
             UndirectedEdge[53, 101] -> 
             RGBColor[
              0.27504289638646184`, 0.40641790120198085`, 0.9389746581084827],
              UndirectedEdge[202, 264] -> 
             RGBColor[
              0.5231853201585595, 0.37556082624020004`, 0.5678587762898913], 
             UndirectedEdge[336, 367] -> 
             RGBColor[
              0.21516062802241154`, 0.34347784039625945`, 0.9355644515130273],
              UndirectedEdge[13, 132] -> 
             RGBColor[
              0.8815012453075697, 0.9077928551611671, 0.9634088234551113], 
             UndirectedEdge[146, 307] -> 
             RGBColor[
              0.760285606005483, 0.8109047025764178, 0.9254188643765703], 
             UndirectedEdge[75, 133] -> 
             RGBColor[
              0.27071817278007254`, 0.4018723424883518, 0.9387283714969541], 
             UndirectedEdge[153, 369] -> 
             RGBColor[
              0.28744235484774583`, 0.41864755274771004`, 0.9397101894237105],
              UndirectedEdge[20, 181] -> 
             RGBColor[
              0.4874856363228792, 0.5935620769713348, 0.9531383479528726], 
             UndirectedEdge[112, 394] -> 
             RGBColor[
              0.34389456121557604`, 0.47228591710687856`, 0.9431336352400042],
              UndirectedEdge[279, 306] -> 
             RGBColor[
              0.9580128778613826, 0.8669798939942239, 0.307271930750418], 
             UndirectedEdge[34, 68] -> 
             RGBColor[
              0.29450681654452554`, 0.42654813983932427`, 0.9400950937121118],
              UndirectedEdge[4, 284] -> 
             RGBColor[
              0.23809729374437577`, 0.3675857303386453, 0.936870660694137], 
             UndirectedEdge[193, 235] -> 
             RGBColor[
              0.7812166445775857, 0.8290306868326278, 0.9788229798067978], 
             UndirectedEdge[296, 316] -> 
             RGBColor[
              0.27790052377493313`, 0.40942144877130526`, 0.9391373957607753],
              UndirectedEdge[117, 223] -> 
             RGBColor[
              0.40179215387534173`, 0.5224135595233219, 0.9468284392932418], 
             UndirectedEdge[37, 110] -> 
             RGBColor[
              0.2526887349083196, 0.3829222601527542, 0.9377016216823209], 
             UndirectedEdge[83, 349] -> 
             RGBColor[
              0.3991304048320619, 0.5201284286132558, 0.946653214352108], 
             UndirectedEdge[192, 348] -> 
             RGBColor[
              0.30372248336585006`, 0.4332572121434699, 0.9407289213687278], 
             UndirectedEdge[97, 394] -> 
             RGBColor[
              0.40057619946044803`, 0.521380703252613, 0.9467453391073628], 
             UndirectedEdge[2, 352] -> 
             RGBColor[
              0.9063026650036, 0.5663670773157738, 0.3851970536504771], 
             UndirectedEdge[69, 350] -> 
             RGBColor[
              0.4604806861717529, 0.5723193250518395, 0.9508242340447808], 
             UndirectedEdge[164, 304] -> 
             RGBColor[
              0.230818470893376, 0.3599352260182205, 0.936456142500826], 
             UndirectedEdge[141, 350] -> 
             RGBColor[
              0.3964033490329356, 0.5177663899458625, 0.9464794487680284], 
             UndirectedEdge[114, 356] -> 
             RGBColor[
              0.4236281428800086, 0.5395805954873082, 0.9487022895227458], 
             UndirectedEdge[383, 390] -> 
             RGBColor[
              0.27326780022861263`, 0.40455216259248444`, 0.9388735690083126],
              UndirectedEdge[297, 307] -> 
             RGBColor[
              0.965939497584164, 0.9739442069028073, 0.9347428726703746], 
             UndirectedEdge[40, 58] -> 
             RGBColor[
              0.31906156196643076`, 0.449858262003899, 0.9415849314423156], 
             UndirectedEdge[173, 295] -> 
             RGBColor[
              0.23437748052955032`, 0.36367597080008385`, 0.9366588228345232],
              UndirectedEdge[161, 239] -> 
             RGBColor[
              0.3779757827321134, 0.5018053582125028, 0.9453052605381971], 
             UndirectedEdge[35, 369] -> 
             RGBColor[
              0.26924749981930185`, 0.40032657196053045`, 0.9386446188475038],
              UndirectedEdge[303, 313] -> 
             RGBColor[
              0.2862100467675046, 0.4181552842906852, 0.9396106108023645], 
             UndirectedEdge[237, 349] -> 
             RGBColor[
              0.5118990860533059, 0.6144062060618112, 0.9547772771793315], 
             UndirectedEdge[21, 263] -> 
             RGBColor[
              0.2875003760669833, 0.4191258516317633, 0.9396982137034129], 
             UndirectedEdge[126, 274] -> 
             RGBColor[
              0.22138486041548355`, 0.35001990328050514`, 0.9359189123398861],
              UndirectedEdge[331, 346] -> 
             RGBColor[
              0.3985622409768109, 0.5196363136385831, 0.946617011453659], 
             UndirectedEdge[106, 345] -> 
             RGBColor[
              0.5752211056493675, 0.6453489967018295, 0.953440498597335]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {3}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.23802405881018981`, 0.36750875577945274`, 0.9368664900729765],
              316 -> RGBColor[
              0.25427950679235417`, 0.38459426226363735`, 0.9377922137877805],
              308 -> RGBColor[
              0.2610883790761277, 0.39175081874132034`, 0.9381799689915176], 
             160 -> RGBColor[
              0.8294775817921864, 0.22758318757925894`, 0.17586107165535175`],
              245 -> RGBColor[
              0.22989884827362161`, 0.3589686443374169, 0.9364037713530907], 
             155 -> RGBColor[
              0.30454561984188433`, 0.43742713413433654`, 0.9406547945639009],
              213 -> RGBColor[
              0.9109681137578394, 0.6847252697068382, 0.24722105836383443`], 
             352 -> RGBColor[
              0.9941541355650164, 0.9899046120181566, 0.6050919166244885], 27 -> 
             RGBColor[
              0.2974167180204977, 0.42993420632157753`, 0.9402488141514381], 
             367 -> RGBColor[
              0.21931469518675756`, 0.34784402836905765`, 0.9358010194926452],
              19 -> RGBColor[
              0.2743841090042405, 0.40572547389373365`, 0.9389371411416538], 
             164 -> RGBColor[
              0.24253850776538854`, 0.3722537278639624, 0.9371235812624463], 
             190 -> RGBColor[
              0.2411029859620505, 0.37074490343131483`, 0.9370418304194105], 
             103 -> RGBColor[
              0.34456615692423104`, 0.4728676195543337, 0.943176428724691], 
             138 -> RGBColor[
              0.8193428764107183, 0.14968340096107918`, 0.16615606633654534`],
              291 -> RGBColor[
              0.696491580031562, 0.7628237829435023, 0.9703834296798242], 28 -> 
             RGBColor[
              0.2882891132658928, 0.42034051500092084`, 0.9397290105637445], 
             337 -> 
             RGBColor[
              0.2847433322190086, 0.4166136743051424, 0.9395270835786375], 
             195 -> RGBColor[
              0.24569470610522032`, 0.37557109243365844`, 0.9373033220887227],
              114 -> RGBColor[
              0.3288778807819878, 0.45927922327560866`, 0.9421767856415051], 
             93 -> RGBColor[
              0.2452381115380016, 0.3750911825937439, 0.9372773197035907], 34 -> 
             RGBColor[
              0.3122890105436297, 0.4449107776560043, 0.9411197574988789], 
             161 -> RGBColor[
              0.4314366462475933, 0.5481104711684827, 0.9487117394878181], 22 -> 
             RGBColor[
              0.29231839668471055`, 0.42457554734542235`, 0.9399584722936555],
              124 -> RGBColor[
              0.22327126764014227`, 0.35200263687874755`, 0.936026340440641], 
             84 -> RGBColor[
              0.17892701429477148`, 0.30539401502471114`, 0.9335010008140661],
              46 -> RGBColor[
              0.2843163130979401, 0.41616485013432336`, 0.9395027654714108], 
             241 -> RGBColor[
              0.290961948336973, 0.42314983412815754`, 0.9398812245669373], 
             185 -> RGBColor[
              0.8236904837096025, 0.18310101579396953`, 0.170319339995877], 
             390 -> RGBColor[
              0.26629927432356376`, 0.3972278000362168, 0.9384767217670303], 
             121 -> RGBColor[
              0.5531961411455233, 0.6481485744409189, 0.9579687731366617], 
             322 -> RGBColor[
              0.5084161265639328, 0.611794141286916, 0.9544435263542006], 126 -> 
             RGBColor[
              0.21204174778307774`, 0.3401996995162911, 0.935386835897367], 
             236 -> RGBColor[
              0.2505222001886238, 0.3806450947961188, 0.9375782407351351], 78 -> 
             RGBColor[
              0.8418439495844675, 0.3226365094076515, 0.18770311941905493`], 
             376 -> RGBColor[
              0.43839329858407067`, 0.5541359737708264, 0.9491550112231723], 
             254 -> RGBColor[
              0.46951139015292603`, 0.5802095236300584, 0.951380802991181], 
             290 -> RGBColor[
              0.4051337172328171, 0.5253281960795354, 0.9470357401097634], 
             251 -> RGBColor[
              0.822315843269912, 0.8611563485272284, 0.9829144132927453], 165 -> 
             RGBColor[
              0.532748774101436, 0.6315484807311408, 0.9563590815017777], 100 -> 
             RGBColor[
              0.37661408553666426`, 0.5006259245426959, 0.9452184943970047], 
             235 -> 
             RGBColor[
              0.7400936775781565, 0.7968860729351169, 0.9747292792785006], 70 -> 
             RGBColor[
              0.2778101351361315, 0.409326444580954, 0.9391322482615135], 234 -> 
             RGBColor[
              0.3387393935852255, 0.4678207700117279, 0.942805152517134], 257 -> 
             RGBColor[
              0.8226071697061851, 0.17477418965247965`, 0.16928195728277629`],
              135 -> RGBColor[
              0.5032780494106496, 0.6076228187861427, 0.9540390380992975], 
             265 -> RGBColor[
              0.5918946974095183, 0.6795658057661227, 0.9610152652432459], 
             111 -> RGBColor[
              0.8740781517963572, 0.5211001217496539, 0.21664006204298622`], 
             381 -> RGBColor[
              0.9931470290452047, 0.9914341346439413, 0.7632349938486772], 
             182 -> RGBColor[
              0.2880943118622093, 0.4201357663745271, 0.9397179169119876], 
             188 -> RGBColor[
              0.26708591845739416`, 0.39805461289699134`, 0.9385215199867163],
              154 -> RGBColor[
              0.4301580292792129, 0.547002997415629, 0.9486302671452295], 336 -> 
             RGBColor[
              0.2110065608580655, 0.33911165242346125`, 0.9353278835334095], 
             315 -> RGBColor[
              0.24327422624281886`, 0.37302701463098736`, 0.937165479341338], 
             368 -> RGBColor[
              0.21278150541118618`, 0.3409772316867757, 0.9354289639999145], 
             269 -> RGBColor[
              0.9930589289900814, 0.9875620758967413, 0.48588543977432486`], 
             208 -> RGBColor[
              0.2330867180319017, 0.36231929757598597`, 0.9365853158197941], 
             86 -> RGBColor[
              0.30053635500276704`, 0.4332131425863514, 0.940426472862489], 
             119 -> RGBColor[
              0.24049836738192176`, 0.3701094109685675, 0.9370073982857251], 
             377 -> RGBColor[
              0.41487938737084307`, 0.5337694057214698, 0.9476567255932007], 
             140 -> RGBColor[
              0.6719249954084331, 0.7436321803229556, 0.9679348621123766], 85 -> 
             RGBColor[
              0.2413074662041341, 0.37095982513054093`, 0.9370534752666957], 
             351 -> RGBColor[
              0.24574449108125243`, 0.37562341960001794`, 0.9373061572694574],
              242 -> RGBColor[
              0.9183468399249884, 0.7139794601448493, 0.25315815463888625`], 
             117 -> RGBColor[
              0.3495171154366807, 0.47715589097540734`, 0.9434918994231435], 
             47 -> 
             RGBColor[
              0.43389191818712153`, 0.5502371043169462, 0.948868187244693], 
             81 -> RGBColor[
              0.2197154470497895, 0.34826524398623987`, 0.9358238417183856], 
             275 -> RGBColor[
              0.992100640761205, 0.9910014261975552, 0.7805763556806252], 23 -> 
             RGBColor[
              0.21341792784235675`, 0.34164615201344867`, 0.935465207315867], 
             328 -> RGBColor[
              0.3094371851822424, 0.44244066986488095`, 0.9409380417086214], 
             110 -> RGBColor[
              0.25557794384056287`, 0.3859590019269685, 0.9378661578568105], 
             6 -> RGBColor[
              0.9933475429680663, 0.9881793920123014, 0.5172992901589675], 
             218 -> RGBColor[
              0.9100637739514378, 0.9311241665985504, 0.9912838892546516], 
             108 -> RGBColor[
              0.3675690787260941, 0.49279159425864094`, 0.9446421545612206], 
             297 -> RGBColor[
              0.9466390204165737, 0.9597240493140413, 0.9752103990490407], 
             157 -> RGBColor[
              0.46924384183457235`, 0.5799923158523045, 0.9513597406074984], 
             354 -> RGBColor[
              0.27977343586669706`, 0.4113899981292344, 0.939244055333676], 
             385 -> RGBColor[
              0.5754210452890663, 0.6661917528451691, 0.9597183990033479], 
             270 -> RGBColor[
              0.249587147505622, 0.3796622951405196, 0.9375249908681246], 392 -> 
             RGBColor[
              0.24794921220500737`, 0.3779407212884774, 0.9374317128758627], 
             33 -> RGBColor[
              0.17894138666990014`, 0.3054091213022326, 0.9335018192995677], 
             252 -> RGBColor[
              0.2243331252717409, 0.35311871657522015`, 0.9360868116618829], 
             394 -> RGBColor[
              0.35886795134781274`, 0.48525511505495156`, 0.9440877264187814],
              260 -> RGBColor[
              0.8089540339665278, 0.8506803067038047, 0.9815926360666765], 
             159 -> RGBColor[
              0.3314345944952444, 0.46149372018986384`, 0.9423396971785006], 
             183 -> RGBColor[
              0.2589336294896423, 0.3894860403069097, 0.9380572591902335], 99 -> 
             RGBColor[
              0.9781276011086575, 0.9832081812363787, 0.921908445474496], 329 -> 
             RGBColor[
              0.23513882534723038`, 0.36447619247551505`, 0.9367021802955814],
              309 -> RGBColor[
              0.27079044913528966`, 0.40194830952027055`, 0.9387324875284604],
              17 -> 
             RGBColor[
              0.5355166046173245, 0.6337955302332828, 0.9565769752588857], 
             349 -> RGBColor[
              0.4453791406536688, 0.5601867590528806, 0.9496001429025095], 
             347 -> RGBColor[
              0.2800500850584523, 0.411680773970341, 0.9392598100958807], 340 -> 
             RGBColor[
              0.99377812825938, 0.9891003704115706, 0.5641658418540755], 277 -> 
             RGBColor[
              0.2578128298869203, 0.3883080088616496, 0.9379934313109329], 
             104 -> RGBColor[
              0.9338740873595025, 0.7755398220742175, 0.265651742396037], 79 -> 
             RGBColor[
              0.590805957298975, 0.6786819174972005, 0.9609295556335575], 327 -> 
             RGBColor[
              0.3185921337049145, 0.45037022613412764`, 0.941521386933083], 
             191 -> RGBColor[
              0.6788533623879274, 0.7490446732648759, 0.968625416983622], 50 -> 
             RGBColor[
              0.45414763221898446`, 0.5677365328098771, 0.9501713116873214], 
             225 -> RGBColor[
              0.2571081050813221, 0.3875672984088326, 0.9379532982758011], 61 -> 
             RGBColor[
              0.9933459036684309, 0.98817588571614, 0.5171208625102379], 196 -> 
             RGBColor[
              0.29792411608308994`, 0.43046751385625726`, 0.9402777097204745],
              1 -> RGBColor[
              0.3599830334006432, 0.48622094308345976`, 0.9441587784611594], 
             263 -> RGBColor[
              0.26208361027682536`, 0.3927968698345563, 0.9382366459360847], 
             201 -> RGBColor[
              0.27642628673231373`, 0.407871932167485, 0.9390534401421363], 
             371 -> RGBColor[
              0.27204560568907665`, 0.4032675586398226, 0.9388039668373608], 
             293 -> RGBColor[
              0.21123106399266978`, 0.3393476194522512, 0.9353406686548026], 
             362 -> RGBColor[
              0.40465902674538534`, 0.5249170430379596, 0.9470054932516565], 
             184 -> RGBColor[
              0.21776291881025298`, 0.3462130130090464, 0.9357126481236506], 
             106 -> RGBColor[
              0.948494816832878, 0.9611080992427333, 0.9720690197854612], 206 -> 
             RGBColor[
              0.23156206990492625`, 0.36071679572626025`, 0.9364984893644777],
              358 -> RGBColor[
              0.9685766725786527, 0.9056638794389593, 0.332426736075871], 247 -> 
             RGBColor[
              0.9070075396154186, 0.6690229130152352, 0.24403428744221908`], 
             220 -> 
             RGBColor[
              0.4754345148883495, 0.5850181831240037, 0.9518470930674744], 
             107 -> RGBColor[
              0.8392176796973624, 0.30244984821655896`, 0.1851882004092155], 
             375 -> RGBColor[
              0.25484534055170655`, 0.38518898942064916`, 0.9378244371832996],
              131 -> RGBColor[
              0.9224661794909306, 0.7303112688352736, 0.2564726719469704], 
             127 -> RGBColor[
              0.21049571798261152`, 0.33857472417205015`, 0.9352987917873766],
              210 -> RGBColor[
              0.2999237099233219, 0.432569213763913, 0.9403915836315417], 357 -> 
             RGBColor[
              0.6756901028072094, 0.7465735108387558, 0.9683101328309576], 
             181 -> RGBColor[
              0.5673122922146817, 0.6596087018042204, 0.9590800482579911], 
             194 -> RGBColor[
              0.3880550588481297, 0.5105355205850486, 0.9459475030995558], 
             118 -> RGBColor[
              0.20606162213947596`, 0.33391420830300045`, 0.935046276588767], 
             348 -> RGBColor[
              0.26295522261758464`, 0.39371298966810864`, 0.9382862829694559],
              276 -> RGBColor[
              0.765566144894021, 0.8167853580001923, 0.977268136766805], 305 -> 
             RGBColor[
              0.20290260740476634`, 0.33059388352371805`, 0.9348663753729688],
              343 -> RGBColor[
              0.7222005724227306, 0.7829078431950623, 0.9729458617771823], 
             280 -> RGBColor[
              0.23901320904650822`, 0.3685484153935707, 0.9369228207156182], 
             189 -> RGBColor[
              0.30054674338696064`, 0.4332240614368005, 0.9404270644656005], 
             168 -> RGBColor[
              0.6701504899984683, 0.7422459232099505, 0.9677579959968072], 
             363 -> RGBColor[
              0.8625124936811881, 0.46858316947675277`, 0.2069893934114667], 
             41 -> RGBColor[
              0.34082031608406577`, 0.4696231604900174, 0.9429377470586726], 
             14 -> RGBColor[
              0.9943570777774785, 0.9903386848900081, 0.6271809240368398], 77 -> 
             RGBColor[
              0.8293651040061051, 0.8667772376911834, 0.9835867780747127], 51 -> 
             RGBColor[
              0.3729233885884314, 0.4974292283459589, 0.9449833264510183], 
             179 -> RGBColor[
              0.2696431574723743, 0.40074243324005365`, 0.9386671509655232], 
             223 -> RGBColor[
              0.4540671923140028, 0.5676712280712366, 0.9501649791633402], 
             323 -> 
             RGBColor[
              0.8302102447519867, 0.867451129981215, 0.983667388353521], 292 -> 
             RGBColor[
              0.2110186790508826, 0.3391243894124498, 0.9353285736465631], 
             396 -> RGBColor[
              0.2782995151593558, 0.4098408140138484, 0.9391601177298633], 
             321 -> RGBColor[
              0.8177864636409283, 0.8575802678943982, 0.9824729701128726], 
             143 -> RGBColor[
              0.6246442469651912, 0.7061533654458123, 0.9635934297498213], 
             112 -> RGBColor[
              0.3289211710833394, 0.45931671915880556`, 0.9421795440612271], 
             197 -> RGBColor[
              0.988751433892587, 0.9896164430866911, 0.8360813809631582], 54 -> 
             RGBColor[
              0.4519914858020445, 0.5659140400742732, 0.9500214756882968], 71 -> 
             RGBColor[
              0.871120013048017, 0.9000714687543917, 0.9875693985741776], 177 -> 
             RGBColor[
              0.3219085007459621, 0.453242696579629, 0.9417327029083903], 158 -> 
             RGBColor[
              0.5031159008708285, 0.6074911792968075, 0.9540262731722731], 
             226 -> RGBColor[
              0.23863402700947722`, 0.3681498710311214, 0.9369012268595588], 
             350 -> RGBColor[
              0.4327427506991586, 0.5492417531977101, 0.948794963308529], 203 -> 
             RGBColor[
              0.29139757571829134`, 0.42360770612629445`, 0.9399060329018505],
              115 -> RGBColor[
              0.2386060995532787, 0.36812051750395375`, 0.9368996364322433], 
             173 -> RGBColor[
              0.22636761106282094`, 0.3552570901354948, 0.936202672617933], 
             212 -> RGBColor[
              0.21089717481030001`, 0.33899668075178374`, 0.9353216541598114],
              129 -> RGBColor[
              0.23768447069359533`, 0.36715182713778177`, 0.936847151032112], 
             279 -> RGBColor[
              0.9456496399519233, 0.8222259641328803, 0.2751266284196432], 26 -> 
             RGBColor[
              0.45511285367532656`, 0.5685201430708667, 0.9502472974560874], 
             40 -> RGBColor[
              0.3393121311221928, 0.4683168464796233, 0.9428416468465376], 
             146 -> RGBColor[
              0.5353312372592116, 0.6336450406612625, 0.9565623824614321], 
             386 -> RGBColor[
              0.3393631406607411, 0.4683610283780999, 0.942844897129228], 192 -> 
             RGBColor[
              0.34448974411411554`, 0.4728014346188312, 0.9431715597679996], 
             300 -> 
             RGBColor[
              0.8899967779325137, 0.5933828851443484, 0.2299229538922278], 
             221 -> RGBColor[
              0.9218589159168126, 0.9405292926311409, 0.9924089204249567], 62 -> 
             RGBColor[
              0.1790682590797859, 0.30554247224919795`, 0.9335090444956198], 
             286 -> RGBColor[
              0.726249879738111, 0.7860711928457129, 0.9733494588874512], 152 -> 
             RGBColor[
              0.18361616608284723`, 0.3103226108633739, 0.9337680410714186], 
             64 -> RGBColor[
              0.3989602722595878, 0.5199810683300905, 0.9466423736550322], 
             307 -> RGBColor[
              0.9852399747517544, 0.9881643644915732, 0.8942753462917085], 37 -> 
             RGBColor[
              0.24979952597607638`, 0.3798855183785399, 0.9375370855078312], 
             148 -> RGBColor[
              0.6238880244982119, 0.7055394299796848, 0.9635338971470865], 
             261 -> RGBColor[
              0.17944836957228805`, 0.3059419924772149, 0.9335306912258446], 
             387 -> RGBColor[
              0.2935687509337651, 0.4258897489382169, 0.9400296781184059], 15 -> 
             RGBColor[
              0.3038609163605336, 0.43670746736272875`, 0.940615801713566], 
             136 -> RGBColor[
              0.6185821135656369, 0.7012318524560568, 0.9631161964022821], 
             198 -> RGBColor[
              0.8264896291158393, 0.8644844120663722, 0.9833125127127125], 63 -> 
             RGBColor[
              0.9585610528033711, 0.8718788421575785, 0.2935179445399928], 
             310 -> RGBColor[
              0.18257815057035692`, 0.3092315907457619, 0.9337089276235886], 
             171 -> RGBColor[
              0.2732125866431092, 0.40449412961337683`, 0.9388704246762993], 
             395 -> RGBColor[
              0.27306809856961783`, 0.40434226348706437`, 0.938862196294265], 
             311 -> RGBColor[
              0.519374038863881, 0.6206902681403376, 0.955306173350608], 353 -> 
             RGBColor[
              0.21037964845754836`, 0.3384527277419758, 0.9352921817996338], 
             59 -> RGBColor[
              0.3340181926444761, 0.4637315030513096, 0.9425043217679835], 
             397 -> RGBColor[
              0.2493495489754894, 0.37941256402073326`, 0.9375114599833291], 
             229 -> RGBColor[
              0.24689616138342244`, 0.3768338981077132, 0.9373717431894225], 
             102 -> RGBColor[
              0.819297035403237, 0.14933104688991955`, 0.16611216893601113`], 
             299 -> 
             RGBColor[
              0.21412870248835636`, 0.3423932212321097, 0.9355056848804599], 
             128 -> RGBColor[
              0.3262131529712761, 0.45697116997908427`, 0.9420069915417328], 
             12 -> RGBColor[
              0.218436984339963, 0.3469214986189947, 0.935751035158377], 222 -> 
             RGBColor[
              0.6049269005052089, 0.6901459353332633, 0.9620412080094716], 92 -> 
             RGBColor[
              0.28766384187052196`, 0.4196833151198899, 0.9396934022827843], 
             271 -> RGBColor[
              0.30678788301618565`, 0.43978389489822367`, 0.9407824881345462],
              361 -> RGBColor[
              0.35562652096447817`, 0.48244755097593534`, 0.9438811853410396],
              344 -> RGBColor[
              0.32062864936426844`, 0.45213415364000675`, 0.941651151910077], 
             132 -> RGBColor[
              0.7992223614262676, 0.8430778501519028, 0.9806226738955138], 80 -> 
             RGBColor[
              0.3344163982055418, 0.46407640869391137`, 0.9425296950742152], 
             324 -> RGBColor[
              0.2799576543907215, 0.4115836234781131, 0.9392545463060924], 
             244 -> RGBColor[
              0.2600361752617328, 0.3906448858188163, 0.9381200475408837], 
             150 -> RGBColor[
              0.2706007772119499, 0.40174895230294594`, 0.9387216859930206], 
             125 -> RGBColor[
              0.277985958766929, 0.4095112463647842, 0.9391422611571797], 258 -> 
             RGBColor[
              0.2529332615169164, 0.38317927312227185`, 0.9377155471109357], 
             133 -> RGBColor[
              0.29725822306554583`, 0.42976761807476255`, 0.9402397880982258],
              255 -> RGBColor[
              0.26047497796174324`, 0.3911060952782254, 0.938145036705499], 
             326 -> RGBColor[
              0.3393902356747875, 0.4683844967174319, 0.9428466235995638], 
             176 -> RGBColor[
              0.21582348781243682`, 0.34417454806331416`, 0.935602200397456], 
             230 -> RGBColor[
              0.9688572327835747, 0.9066102748888301, 0.333516659492644], 274 -> 
             RGBColor[
              0.2307279730478894, 0.35984010704471925`, 0.9364509887824051], 
             87 -> RGBColor[
              0.29013871681338543`, 0.4222845656009737, 0.9398343427495309], 
             130 -> RGBColor[
              0.4104055903111328, 0.5298944275679272, 0.9473716592005793], 35 -> 
             RGBColor[
              0.28104105066772134`, 0.4127223416565313, 0.9393162441213263], 
             379 -> 
             RGBColor[
              0.22095736038557218`, 0.3495705736440009, 0.9358945668456122], 
             31 -> RGBColor[
              0.183217413291963, 0.30990349639776743`, 0.9337453326898797], 
             18 -> RGBColor[
              0.9452065658445834, 0.95865572703968, 0.9776351709954327], 24 -> 
             RGBColor[
              0.9021530244270525, 0.6485815613125467, 0.24006642394413927`], 
             151 -> RGBColor[
              0.3158355177641727, 0.44798258395780277`, 0.9413457378029186], 
             137 -> RGBColor[
              0.22155609394318862`, 0.3501998805749559, 0.9359286638359716], 
             330 -> RGBColor[
              0.22477195032544567`, 0.3535799495297792, 0.936111802099508], 
             296 -> RGBColor[
              0.30152154075751214`, 0.43424863527897317`, 0.94048257773377], 
             266 -> RGBColor[
              0.2549979314676595, 0.3853493721481386, 0.937833127010225], 302 -> 
             RGBColor[
              0.9872770340850194, 0.9687445898536212, 0.4050741092611545], 
             283 -> RGBColor[
              0.9089152991886196, 0.6765865439997854, 0.2455693155756892], 
             388 -> RGBColor[
              0.22336510960731928`, 0.352101270736175, 0.9360316846018449], 
             284 -> RGBColor[
              0.24399808998490613`, 0.37378784131953313`, 0.9372067023105894],
              318 -> RGBColor[
              0.2238174684207968, 0.35257672853034516`, 0.9360574457670676], 
             238 -> RGBColor[
              0.22922310747734106`, 0.35825839791608494`, 0.9363652889144115],
              72 -> RGBColor[
              0.22772650909910638`, 0.3566853781307425, 0.9362800598507899], 
             288 -> RGBColor[
              0.245025991273468, 0.37486823074651754`, 0.9372652397683294], 
             382 -> RGBColor[
              0.898780922280212, 0.63326963303821, 0.23725265925502825`], 389 -> 
             RGBColor[
              0.17908812663026416`, 0.30556335430442605`, 0.933510175923228], 
             172 -> RGBColor[
              0.301424661402258, 0.4341468089340951, 0.9404770605978084], 243 -> 
             RGBColor[
              0.2883719521470624, 0.4204275839173185, 0.939733728115478], 88 -> 
             RGBColor[
              0.9903137669558371, 0.9902625079584733, 0.8101894789167451], 
             273 -> RGBColor[
              0.2754373969927425, 0.40683254635196486`, 0.938997124334399], 
             202 -> RGBColor[
              0.8563396258514921, 0.4340566292418462, 0.20158419538288244`], 
             393 -> 
             RGBColor[
              0.22281999879048459`, 0.3515283247056597, 0.9360006413472455], 
             98 -> RGBColor[
              0.9775701021325132, 0.9360008290818089, 0.3673645116259542], 30 -> 
             RGBColor[
              0.17892703208317115`, 0.3053940337214471, 0.9335010018270892], 
             116 -> RGBColor[
              0.4162213411164948, 0.534931738607397, 0.9477422336992305], 373 -> 
             RGBColor[
              0.2503218011924054, 0.380434462745063, 0.9375668283087641], 240 -> 
             RGBColor[
              0.23920651037948798`, 0.3687515873505448, 0.9369338289405676], 
             317 -> RGBColor[
              0.9906270631619555, 0.9903920639910485, 0.8049973499967711], 
             391 -> RGBColor[
              0.8203907902431329, 0.1577381258757864, 0.16715954980591485`], 
             73 -> RGBColor[
              0.24311597663730303`, 0.3728606842619857, 0.9371564672604132], 
             303 -> RGBColor[
              0.28961174034798287`, 0.421730679923598, 0.9398043322194181], 
             29 -> RGBColor[
              0.2404292095299187, 0.3700367216812511, 0.9370034598483634], 
             360 -> RGBColor[
              0.3103917228488082, 0.4432674424152022, 0.9409988640046705], 
             320 -> RGBColor[
              0.7098940201909748, 0.7732938710583535, 0.9717192596619902], 75 -> 
             RGBColor[
              0.24417812249459925`, 0.373977066901941, 0.9372169548956822], 
             200 -> RGBColor[
              0.27065965459454444`, 0.40181083616509444`, 0.9387250389728581],
              301 -> RGBColor[
              0.2568179059531509, 0.3872622807254372, 0.9379367718647629], 
             156 -> RGBColor[
              0.18595953915049845`, 0.3127856445359093, 0.9339014927009116], 
             25 -> RGBColor[
              0.8487111149297029, 0.3754205514621725, 0.19427912470900624`], 
             38 -> RGBColor[
              0.9657912116144293, 0.896267865549297, 0.32160574622002847`], 
             365 -> RGBColor[
              0.25624071750281635`, 0.38665561906827417`, 0.93790390183639], 
             380 -> RGBColor[
              0.26549066491796636`, 0.3963779002821365, 0.9384306726576119], 
             370 -> RGBColor[
              0.8312166238387177, 0.8682535893475418, 0.9837633776892186], 3 -> 
             RGBColor[
              0.370079657849583, 0.49496613171003123`, 0.9448021264429514], 
             57 -> RGBColor[
              0.2732074233744939, 0.404488702690692, 0.9388701306357901], 227 -> 
             RGBColor[
              0.23492201148043795`, 0.36424830735472313`, 0.9366898330666149],
              39 -> RGBColor[
              0.27309206457306523`, 0.40436745327622, 0.9388635611227067], 
             109 -> RGBColor[
              0.9940964498066649, 0.9918267445278057, 0.7475006348091123], 
             256 -> RGBColor[
              0.22530836548640581`, 0.35414375587463387`, 0.9361423501493695],
              339 -> RGBColor[
              0.36576050208801136`, 0.49122509607643855`, 0.9445269136571035],
              287 -> RGBColor[
              0.260213393629744, 0.3908311535598896, 0.9381301398647709], 239 -> 
             RGBColor[
              0.32451491921663345`, 0.4555002452565231, 0.9418987815885761], 
             285 -> RGBColor[
              0.23871510677441427`, 0.3682350910048242, 0.9369058442322252], 
             345 -> RGBColor[
              0.20194739446585683`, 0.3295898941609259, 0.9348119774092088], 
             366 -> RGBColor[
              0.9012804456996433, 0.6446193851073215, 0.2393383228651273], 
             216 -> RGBColor[
              0.6591015742674116, 0.7336144262659793, 0.9666567433347234], 21 -> 
             RGBColor[
              0.31291714185714126`, 0.44545483342897024`, 0.9411597814707411],
              355 -> RGBColor[
              0.23092116646773903`, 0.3600431655781515, 0.9364619908618614], 
             175 -> RGBColor[
              0.17893214148115075`, 0.3053994040226782, 0.9335012927997455], 
             7 -> RGBColor[
              0.38940499419392427`, 0.5117047667318526, 0.9460335197860889], 
             13 -> RGBColor[
              0.9637801291888717, 0.9725078601704316, 0.9461949730147088], 
             294 -> RGBColor[
              0.21275955169572475`, 0.34095415693987974`, 0.9354277137682966],
              193 -> RGBColor[
              0.8223396115770147, 0.8611753007301386, 0.9829166803350949], 60 -> 
             RGBColor[
              0.35752834255750565`, 0.4840948132514831, 0.9440023677312325], 
             65 -> RGBColor[
              0.5153321861178936, 0.6174089099977538, 0.9549879838966494], 69 -> 
             RGBColor[
              0.48821862164434726`, 0.5953968969059689, 0.9528535047810326], 
             217 -> RGBColor[
              0.8228256695060855, 0.17645367486173685`, 0.16949119293792111`],
              214 -> RGBColor[
              0.9837730937067766, 0.9874185803724101, 0.9123520990861677], 
             170 -> RGBColor[
              0.44496963537099143`, 0.5598320661593594, 0.9495740495880086], 
             359 -> 
             RGBColor[
              0.2455681205459235, 0.37543804298484945`, 0.9372961132283874], 
             74 -> RGBColor[
              0.8246734764068878, 0.8630362611944062, 0.983139286446034], 246 -> 
             RGBColor[
              0.4438028563584466, 0.5588214608227114, 0.9494997034610714], 
             264 -> RGBColor[
              0.19003101446562676`, 0.31706502323855396`, 0.9341333571969002],
              278 -> RGBColor[
              0.2524156236360728, 0.382635202889368, 0.9376860683993983], 45 -> 
             RGBColor[
              0.2954990939280613, 0.427918661816037, 0.9401396082962444], 306 -> 
             RGBColor[
              0.9703761157708419, 0.9117338238555674, 0.33941723308119276`], 
             237 -> RGBColor[
              0.5784190314529432, 0.6686256530707418, 0.9599544114561535], 
             228 -> RGBColor[
              0.36785717736282086`, 0.49304113081751505`, 0.9446605119515972],
              180 -> RGBColor[
              0.36627002209779275`, 0.4916664166996908, 0.9445593798215759], 
             383 -> RGBColor[
              0.28023632613366145`, 0.41187652514875206`, 0.939270416249595], 
             53 -> RGBColor[
              0.28924396052189333`, 0.4213441200077901, 0.9397833877024038], 
             304 -> RGBColor[
              0.21909843402136348`, 0.34761672417247863`, 0.9357887037392056],
              48 -> RGBColor[
              0.4254428949511675, 0.5429189850502182, 0.948329822955276], 5 -> 
             RGBColor[
              0.8414430264446411, 0.8764078451972013, 0.9847387810989889], 
             101 -> RGBColor[
              0.2608418322510304, 0.39149168239617155`, 0.9381659285145616], 
             333 -> RGBColor[
              0.19556045555100107`, 0.3228768164060961, 0.9344482506866372], 
             267 -> RGBColor[
              0.5711989452526345, 0.6627640618321545, 0.9593860198224179], 
             120 -> RGBColor[
              0.5663783145126094, 0.6588504566304622, 0.9590065221120109], 
             147 -> RGBColor[
              0.28473783311028583`, 0.41660789439321116`, 0.9395267704125309],
              89 -> RGBColor[
              0.21858282554203126`, 0.3470747869692347, 0.9357593405990821], 
             43 -> RGBColor[
              0.2274352478585693, 0.35637924409990884`, 0.9362634729540237], 
             199 -> RGBColor[
              0.22580276459471169`, 0.35466340068417734`, 0.9361705054471896],
              268 -> RGBColor[0.817319, 0.134127, 0.164218], 169 -> 
             RGBColor[
              0.22069846856058375`, 0.34929846192124825`, 0.9358798233391753],
              20 -> RGBColor[
              0.4076589804310767, 0.5275154521384491, 0.9471966476477539], 4 -> 
             RGBColor[
              0.23219649750384544`, 0.36138361935775737`, 0.9365346190776845],
              167 -> RGBColor[
              0.2835494674254077, 0.415358846711668, 0.9394590947448065], 142 -> 
             RGBColor[
              0.8215839734950429, 0.16690945520620182`, 0.16830214343545163`],
              16 -> RGBColor[
              0.2418605106508593, 0.3715411099090923, 0.9370849703297808], 
             281 -> RGBColor[
              0.6319940482543123, 0.7121202652370958, 0.9641720330305101], 
             289 -> RGBColor[
              0.8977533081905217, 0.6286034774622947, 0.23639519286946437`], 
             398 -> RGBColor[
              0.9394254025446074, 0.954344144916344, 0.9874211724934188], 178 -> 
             RGBColor[
              0.24398844376792686`, 0.3737777025338824, 0.9372061529728027], 
             58 -> RGBColor[
              0.2988109928106687, 0.43139967752817476`, 0.9403282160380936], 
             186 -> RGBColor[
              0.24846767200989045`, 0.3784856554156597, 0.9374612383947583], 
             122 -> RGBColor[
              0.44608758599784554`, 0.5608003788025082, 0.9496452844133868], 
             249 -> RGBColor[
              0.2695692814994847, 0.4006647849085395, 0.938662943838157], 113 -> 
             RGBColor[
              0.7965156452550962, 0.8409633429071789, 0.9803528937232722], 52 -> 
             RGBColor[
              0.38664548537965426`, 0.5093146188938776, 0.9458576863245813], 
             187 -> RGBColor[
              0.8439338400416576, 0.8783939523481282, 0.9849763571234479], 
             259 -> RGBColor[
              0.2110206902246306, 0.3391265032835748, 0.9353286881799328], 42 -> 
             RGBColor[
              0.9322258626950144, 0.9487956145888052, 0.9933977290633442], 
             134 -> RGBColor[
              0.2343268669145523, 0.36362277268163234`, 0.9366559404640252], 
             313 -> RGBColor[
              0.2828083531870263, 0.41457988865777246`, 0.939416889385311], 
             248 -> RGBColor[
              0.21620788903044316`, 0.3445785781158837, 0.9356240914781508], 
             174 -> RGBColor[
              0.7286053839996127, 0.7879113306772935, 0.9735842335387989], 
             215 -> RGBColor[
              0.8192881970279116, 0.1492631112641677, 0.166103705297818], 399 -> 
             RGBColor[
              0.2348790166106703, 0.36420311702056507`, 0.9366873845723869], 
             83 -> RGBColor[
              0.35288166901045503`, 0.480070098173631, 0.9437062858017065], 
             95 -> RGBColor[
              0.2817785304161579, 0.4134974796310549, 0.9393582425019963], 
             166 -> RGBColor[
              0.8247691039330448, 0.19139176348574266`, 0.17135222793997262`],
              384 -> RGBColor[
              0.7484278388783107, 0.8033967830847693, 0.9755599505897345], 
             233 -> RGBColor[
              0.8174582326741875, 0.1351972033459516, 0.16435132936604271`], 
             295 -> RGBColor[
              0.24238734999627973`, 0.3720948514646729, 0.9371149730511135], 
             141 -> RGBColor[
              0.3600639473667127, 0.48629102669401497`, 0.9441639342275279], 
             319 -> RGBColor[
              0.24158367299712782`, 0.37125013598249945`, 0.9370692048349454],
              205 -> RGBColor[
              0.9952685123171101, 0.9923114224965074, 0.7280765258104895], 
             224 -> RGBColor[
              0.9756615083220127, 0.9295626939998534, 0.3599499850798584], 
             231 -> RGBColor[
              0.30868412390727973`, 0.44177696430338015`, 0.9408904762480571],
              332 -> RGBColor[
              0.5272216074067284, 0.6270612778123552, 0.9559239626928917], 68 -> 
             RGBColor[
              0.2767246225454214, 0.4081855020226443, 0.9390704299253445], 10 -> 
             RGBColor[
              0.3619258765766598, 0.48790373619238797`, 0.9442825747103464], 
             250 -> RGBColor[
              0.9882272169582415, 0.9893996659125786, 0.8447690121952027], 
             282 -> RGBColor[
              0.6468617732853108, 0.7240526007128293, 0.965436794360271], 374 -> 
             RGBColor[
              0.2761037265699157, 0.40753290098530925`, 0.9390350708180728], 
             232 -> RGBColor[
              0.5255566438526651, 0.6257095853934133, 0.9557928906629534], 
             253 -> RGBColor[
              0.34171577858230273`, 0.47039876509873646`, 0.9429948051372339],
              55 -> RGBColor[
              0.4035326533159193, 0.5239414349865308, 0.9469337217327439], 
             325 -> RGBColor[
              0.21156771774634342`, 0.33970146389244305`, 0.9353598405880397],
              91 -> RGBColor[
              0.26262121251507564`, 0.39336192387290797`, 0.9382672615882417],
              105 -> RGBColor[
              0.417344109662346, 0.5359042242898253, 0.9478137755181469], 36 -> 
             RGBColor[
              0.5196772960404508, 0.620936465977857, 0.9553300468664151], 123 -> 
             RGBColor[
              0.9742961343763916, 0.9803506796209057, 0.9283941192456544], 94 -> 
             RGBColor[
              0.26012396818175015`, 0.3907371617441472, 0.9381250472178008], 
             312 -> RGBColor[
              0.46295717480753656`, 0.5748885163486347, 0.9508648311503101], 
             96 -> RGBColor[
              0.2869114883454893, 0.4188925438631119, 0.939650556862541], 2 -> 
             RGBColor[
              0.8184511944421836, 0.14282954261339104`, 0.16530219067646573`],
              262 -> RGBColor[
              0.9386428604207964, 0.9537605262817009, 0.9887458121893573], 
             272 -> RGBColor[
              0.6470169280819229, 0.7241738088191627, 0.9654522587403933], 97 -> 
             RGBColor[
              0.44228444757308333`, 0.5575062914502744, 0.9494029517959442], 
             372 -> RGBColor[
              0.2514775053864574, 0.3816491811288898, 0.9376326439529042], 
             356 -> RGBColor[
              0.5183784049780293, 0.6198819676990077, 0.9552277934039866], 
             346 -> RGBColor[
              0.3450320119322843, 0.4732711197477559, 0.9432061125938647], 
             341 -> RGBColor[
              0.2215837127017966, 0.35022890964138337`, 0.935930236683416], 
             209 -> RGBColor[
              0.2520329891677718, 0.3822330298027571, 0.9376642779324855], 
             378 -> RGBColor[
              0.20852643568424656`, 0.3365048836167593, 0.9351866440737768], 
             66 -> RGBColor[
              0.9727828870163496, 0.9198524284034268, 0.3487670848893771], 
             139 -> RGBColor[
              0.2111706728502173, 0.3392841445325141, 0.9353372294685806], 56 -> 
             RGBColor[
              0.45093503134871465`, 0.5649989923257436, 0.9499541593447165], 
             335 -> RGBColor[
              0.28051817934621337`, 0.41217277074566994`, 0.9392864673730853],
              314 -> RGBColor[
              0.9258119809847409, 0.9436813594132142, 0.9927859673000785], 
             144 -> RGBColor[
              0.8784381059512442, 0.540897655273832, 0.22027811466207986`], 
             298 -> RGBColor[
              0.8234301328695646, 0.862044852807406, 0.9830206952294982], 204 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 207 -> 
             RGBColor[
              0.9398558182628138, 0.7992553918121872, 0.27046478349011155`], 
             334 -> RGBColor[
              0.26139903658851843`, 0.39207733948366696`, 0.9381976604772716],
              149 -> 
             RGBColor[
              0.22021863489519794`, 0.34879412631571627`, 0.9358524975217819],
              219 -> RGBColor[
              0.4471878440862639, 0.5617533670581167, 0.9497153918858607], 
             400 -> RGBColor[
              0.38961090759033284`, 0.5118831185663134, 0.9460466404056259], 
             9 -> RGBColor[
              0.8256674379376745, 0.1982967522977973, 0.17221247359732916`], 
             11 -> RGBColor[
              0.9234626618564741, 0.7342619893565898, 0.25727446504873397`], 
             44 -> RGBColor[
              0.29795654320818293`, 0.4305015968207284, 0.940279556397277], 
             153 -> RGBColor[
              0.3174307607246093, 0.4493643032308905, 0.9414473852737397], 32 -> 
             RGBColor[
              0.21628540957162948`, 0.3446600571197567, 0.9356285061582901], 
             162 -> RGBColor[
              0.246083996032968, 0.37598026083012825`, 0.9373254915742051], 
             90 -> RGBColor[
              0.7058058015575851, 0.7701001235903371, 0.9713117842351892], 
             331 -> RGBColor[
              0.45209247002133757`, 0.5660015075294104, 0.9500279103134532], 
             8 -> RGBColor[
              0.3103199544645186, 0.44320528024791445`, 0.9409942909866859], 
             364 -> RGBColor[
              0.34952976604112324`, 0.4771668482931376, 0.9434927055084721], 
             342 -> RGBColor[
              0.6033581995623302, 0.6888723932386622, 0.9619177141249072], 
             163 -> RGBColor[
              0.2449732495734328, 0.3748127958757636, 0.9372622362065367], 49 -> 
             RGBColor[
              0.2557363986193865, 0.3861255479461254, 0.9378751816220516], 
             338 -> RGBColor[
              0.9942883740099587, 0.9901917344782997, 0.6197029429328111], 76 -> 
             RGBColor[
              0.8469444359628041, 0.36184108275892934`, 0.19258735093512552`],
              369 -> RGBColor[
              0.25745394897088236`, 0.38793080226452953`, 0.9379729935736814],
              82 -> RGBColor[
              0.37921715493462604`, 0.5028805724211383, 0.9453843596772389], 
             67 -> RGBColor[
              0.2129458677257866, 0.3411499869005934, 0.9354383241905787], 
             211 -> RGBColor[
              0.2626771974737526, 0.39342076761412886`, 
               0.9382704498488161]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9l3k0VX/Yxa95Hq55dufJNVwqktwdKpWiSIU0EZFIxkiFhGRKk6SkQSmp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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 7}], {
             RGBColor[
             0.37469401379728373`, 0.4989628549076562, 0.945096149123624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 35}], {
             RGBColor[
             0.32051204203418227`, 0.44947164236999554`, 0.9417375112912428]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 41}], {
             RGBColor[
             0.3504016747423545, 0.4779220517867386, 0.943548262759916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 57}], {
             RGBColor[
             0.31659522838756854`, 0.44535482288707584`, 0.9415144545484747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 92}], {
             RGBColor[
             0.3238234376355826, 0.4529521291016748, 0.9419260903719718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 96}], {
             RGBColor[
             0.32344726087306624`, 0.45255674347328584`, 0.9419046676618501]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 114}], {
             RGBColor[
             0.3444304570913155, 0.4727500831795342, 0.9431677820513322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 153}], {
             RGBColor[
             0.33870689706262624`, 0.4677926231571751, 0.9428030818674495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 154}], {
             RGBColor[
             0.39507053133992803`, 0.5166119702495444, 0.9463945228031945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 161}], {
             RGBColor[
             0.3957098398241182, 0.5171657071259712, 0.9464352589744887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 188}], {
             RGBColor[
             0.3135344759290187, 0.4421377779902256, 0.9413401492239378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 203}], {
             RGBColor[
             0.32569030455946724`, 0.45491432460487713`, 0.9420324056815049]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 222}], {
             RGBColor[
             0.48245496695292606`, 0.5881834392083616, 0.9530999932353155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 312}], {
             RGBColor[
             0.4114701041040899, 0.5305547297160472, 0.9475118048057347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 327}], {
             RGBColor[
             0.3392875835527789, 0.4682955846087937, 0.9428400826971212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 337}], {
             RGBColor[
             0.3223631828098259, 0.4514173086943011, 0.9418429310198984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 356}], {
             RGBColor[
             0.43918071918933627`, 0.5530514553912338, 0.949693285932573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 361}], {
             RGBColor[
             0.35780477718256065`, 0.4843342470296975, 0.9440199819010995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[
             0.8956170407292666, 0.531340985508409, 0.2570346377829214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 98}], {
             RGBColor[
             0.8980106482873484, 0.5394151858476, 0.26633335115120993`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 106}], {
             RGBColor[
             0.8834730056375308, 0.5519688209280622, 0.5686856052309635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 107}], {
             RGBColor[
             0.828834437069773, 0.222639695414975, 0.17524519554284063`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 197}], {
             RGBColor[
             0.9036013141673853, 0.5662229928500411, 0.5006917858198119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 215}], {
             RGBColor[
             0.8188696957350476, 0.14604632693877936`, 0.16570294798714186`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 283}], {
             RGBColor[
             0.8636832468154017, 0.4097080433065882, 0.20543575312607748`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 352}], {
             RGBColor[
             0.9063026650036, 0.5663670773157738, 0.3851970536504771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 52}], {
             RGBColor[
             0.3783625716146186, 0.5021403753019544, 0.9453299063837663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 86}], {
             RGBColor[
             0.33530800642617503`, 0.4640896371481913, 0.9426142996527203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 117}], {
             RGBColor[
             0.35979838664313185`, 0.4860610113427193, 0.9441470129330474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 174}], {
             RGBColor[
             0.5493425209245979, 0.6414387311936623, 0.9591931799908751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 232}], {
             RGBColor[
             0.4478181508511241, 0.5603378585517222, 0.9502975085529524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 309}], {
             RGBColor[
             0.32043505349243634`, 0.4484572206151509, 0.9417673069857059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 371}], {
             RGBColor[
             0.3210626317693298, 0.4491168451749269, 0.9418030466401561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 386}], {
             RGBColor[
             0.35472139925516205`, 0.48166358004406556`, 0.9438235117860897]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 16}], {
             RGBColor[
             0.23702850407735238`, 0.36646236463342485`, 0.9368097947037326]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 73}], {
             RGBColor[
             0.23765623707057423`, 0.3671221518098715, 0.9368455431690489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 115}], {
             RGBColor[
             0.23540129852856206`, 0.36475206843085556`, 0.936717127754964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 188}], {
             RGBColor[
             0.24964120798061978`, 0.37971911612737436`, 0.9375280695322004]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 195}], {
             RGBColor[
             0.2389456018045329, 0.3684773558957079, 0.9369189705832036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 206}], {
             RGBColor[
             0.23187928370438585`, 0.3610502075420088, 0.9365165542210812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 208}], {
             RGBColor[
             0.23264160776787357`, 0.36185145846687167`, 0.9365599674487393]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 258}], {
             RGBColor[
             0.24256487951038092`, 0.3722814462400146, 0.9371250830943101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 278}], {
             RGBColor[
             0.24230606056995913`, 0.37200941112356267`, 0.9371103437385414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 284}], {
             RGBColor[
             0.23809729374437577`, 0.3675857303386453, 0.936870660694137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 369}], {
             RGBColor[
             0.2448252232373639, 0.37465721081114345`, 0.937253806325683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 392}], {
             RGBColor[
             0.24007285485442642`, 0.3696621703231174, 0.9369831659767736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 99}], {
             RGBColor[
             0.9097853137766493, 0.92980801321679, 0.9533236132867424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 174}], {
             RGBColor[
             0.7850242052221269, 0.8321595879372474, 0.979161507318894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 193}], {
             RGBColor[
             0.8318913190108279, 0.8687915729636699, 0.983827730717042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 223}], {
             RGBColor[
             0.6477551093793219, 0.7220395366342189, 0.9674518801311646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 235}], {
             RGBColor[
             0.7907683520113988, 0.8366469590661592, 0.9797340301887447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 260}], {
             RGBColor[
             0.8251985302055844, 0.863544075950503, 0.9831657085828327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 267}], {
             RGBColor[
             0.7063209858486378, 0.7695859535146778, 0.9720624004607035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 272}], {
             RGBColor[
             0.744229977263282, 0.800290827008182, 0.9750955199196911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 275}], {
             RGBColor[
             0.916771833602923, 0.9337046356973782, 0.882657568389807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 291}], {
             RGBColor[
             0.7689673032381015, 0.8196158140703518, 0.9775611053894065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 321}], {
             RGBColor[
             0.8296147450427847, 0.8669940565457998, 0.9836058756059307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 338}], {
             RGBColor[
             0.9178657002272999, 0.9332997898377504, 0.8022208620159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 384}], {
             RGBColor[
             0.7949354326614759, 0.8399023141409853, 0.9801493658443617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 398}], {
             RGBColor[
             0.8904342144946242, 0.9153759950567726, 0.9860799767962038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 13}], {
             RGBColor[
             0.978563836078469, 0.9803436260913665, 0.7317471315868381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 18}], {
             RGBColor[
             0.9692770544063248, 0.9734175595259907, 0.7474672305772001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 74}], {
             RGBColor[
             0.909010509687477, 0.9256078266033538, 0.7502192883025007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 102}], {
             RGBColor[
             0.9063222891856516, 0.5687552194511105, 0.3417057295474893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 132}], {
             RGBColor[
             0.896284952197167, 0.9156286210821021, 0.7489609820272407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 160}], {
             RGBColor[
             0.9114125623801264, 0.6078812897957802, 0.3465801809071596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 166}], {
             RGBColor[
             0.9090583234505556, 0.5897855777490221, 0.34432575904947005`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 185}], {
             RGBColor[
             0.9085190133388343, 0.5856402039031354, 0.34380931507742224`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 198}], {
             RGBColor[
             0.9099185860419527, 0.9263319020393368, 0.75030590143584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 213}], {
             RGBColor[
             0.9521578283629528, 0.8364523308595698, 0.38226017426140096`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 216}], {
             RGBColor[
             0.8262245586177389, 0.8608969091391403, 0.7419780167468455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 224}], {
             RGBColor[
             0.9845045256450395, 0.9588710430060774, 0.43862463761941295`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 247}], {
             RGBColor[
             0.9501775412917424, 0.8286011525137683, 0.3806667888005933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 289}], {
             RGBColor[
             0.9455504255792939, 0.808391434737298, 0.3768472415142159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 302}], {
             RGBColor[
             0.9903122885265428, 0.9784619909329613, 0.461186699710061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 323}], {
             RGBColor[
             0.9117788938600264, 0.9278152609967583, 0.7504833392562442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 340}], {
             RGBColor[
             0.9935628356137232, 0.988639881211936, 0.5407325660065214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 40}], {
             RGBColor[
             0.36435856265805855`, 0.4900108066057379, 0.9444375833163132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 41}], {
             RGBColor[
             0.36511265513899505`, 0.490663963610935, 0.9444856334223808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 80}], {
             RGBColor[
             0.36191069619973304`, 0.48789058771288196`, 0.9442816074301521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 96}], {
             RGBColor[
             0.3381582412697068, 0.46529865529748227`, 0.9428420383243149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 114}], {
             RGBColor[
             0.359141437487956, 0.48549199500373064`, 0.9441051527137969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 153}], {
             RGBColor[
             0.3534178774592668, 0.48053453498137155`, 0.9437404525299142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 154}], {
             RGBColor[
             0.40978151173656857`, 0.5293538820737408, 0.9473318934656592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 192}], {
             RGBColor[
             0.36694736915401993`, 0.4922531006753419, 0.9446025397770442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 203}], {
             RGBColor[
             0.3404012849561078, 0.4676562364290735, 0.9429697763439697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 222}], {
             RGBColor[
             0.4971659473495666, 0.600925351032558, 0.9540373638977802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 228}], {
             RGBColor[
             0.37863108577837257`, 0.5023729487746839, 0.9453470158688431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 312}], {
             RGBColor[
             0.42618108450073044`, 0.5432966415402436, 0.9484491754681994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 332}], {
             RGBColor[
             0.45831330080032634`, 0.5693830222721039, 0.9509787412394903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 356}], {
             RGBColor[
             0.4538916995859768, 0.5657933672154302, 0.9506306565950378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 361}], {
             RGBColor[
             0.3725157575792012, 0.497076158853894, 0.9449573525635642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 385}], {
             RGBColor[
             0.4824130197414953, 0.5889482597885108, 0.9528759593947184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 17}], {
             RGBColor[
             0.42291827954092154`, 0.5385004052405986, 0.9487856331227857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.3116185481608299, 0.44433005683844234`, 0.9410770362287135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 36}], {
             RGBColor[
             0.41499862525248465`, 0.5320708731128857, 0.9481621689265505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 60}], {
             RGBColor[
             0.33392414851101215`, 0.4636500467496988, 0.9424983293589592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 64}], {
             RGBColor[
             0.3546401133620532, 0.4815931742890025, 0.9438183323208591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.34476855469957235`, 0.4730429263345264, 0.9431893253319623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 157}], {
             RGBColor[
             0.38978189814954545`, 0.5115987980501094, 0.9461770157970921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 171}], {
             RGBColor[
             0.2917662705538139, 0.42384970493064567`, 0.9399323578314926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 182}], {
             RGBColor[
             0.29920713316336395`, 0.4316705233112208, 0.9403561039493367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 210}], {
             RGBColor[
             0.30512183219392025`, 0.43788724700591375`, 0.9406929373091137]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 253}], {
             RGBColor[
             0.3260178665234107, 0.4568020226733255, 0.9419945480619598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 61}], {
             RGBColor[
             0.9095066708030527, 0.5932363190069687, 0.34466666805378354`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 131}], {
             RGBColor[
             0.8740668087143025, 0.4643040105665355, 0.21434257277214977`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 142}], {
             RGBColor[
             0.8236257057163587, 0.18260310375199956`, 0.1702573085163904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 202}], {
             RGBColor[
             0.8410035318945833, 0.31617669076982174`, 0.1868983344901058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 214}], {
             RGBColor[
             0.9047202658222255, 0.5928576663351037, 0.5422822863417485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 215}], {
             RGBColor[
             0.822477817482793, 0.1737799317809825, 0.1691580894475736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 217}], {
             RGBColor[
             0.8242465537218799, 0.18737521357976708`, 0.17085183326762515`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 269}], {
             RGBColor[
             0.909363183463878, 0.5929294140972693, 0.329048956685827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 279}], {
             RGBColor[
             0.8856585389447988, 0.5102613582153388, 0.22366955100848618`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 300}], {
             RGBColor[
             0.8578321079350941, 0.3958398187210729, 0.2010677137447785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 306}], {
             RGBColor[
             0.8980217768542582, 0.5550152880766823, 0.25581485333926096`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 363}], {
             RGBColor[
             0.8440899658094313, 0.333439960887275, 0.18960093350439794`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 39}], {
             RGBColor[
             0.3175089705748625, 0.446135594734304, 0.9415730679165266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 177}], {
             RGBColor[
             0.34191718866131093`, 0.47057321638600846`, 0.9430076388093683]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.3312363099818102, 0.46056389881459425`, 0.9423548195879734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 200}], {
             RGBColor[
             0.31629276558560215`, 0.4448572861787412, 0.9415038068416022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 216}], {
             RGBColor[
             0.5105137254220357, 0.6107590812291837, 0.9554696590225349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 219}], {
             RGBColor[
             0.4045568603314619, 0.5248285516252523, 0.9469989832981036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 241}], {
             RGBColor[
             0.32644391245681637`, 0.4555267851602728, 0.9420818996386419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 296}], {
             RGBColor[
             0.331723708667086, 0.46107618573568054`, 0.9423825762220581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 311}], {
             RGBColor[
             0.4406499577202704, 0.5542970021663628, 0.9497943740304772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 339}], {
             RGBColor[
             0.3638431893323356, 0.48956441613441326`, 0.9444047441837249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 360}], {
             RGBColor[
             0.336158799712734, 0.4655855893037951, 0.9426407193575084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 374}], {
             RGBColor[
             0.31901480157328777`, 0.4477183185888486, 0.9416588227642095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 14}], {
             RGBColor[
             0.9589098698169762, 0.8623003371232989, 0.4422276945427869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 25}], {
             RGBColor[
             0.8860868883930885, 0.5548412704093811, 0.2257767948788701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 38}], {
             RGBColor[
             0.9446269367354516, 0.8152649274529434, 0.2894401056343812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 78}], {
             RGBColor[
             0.8826533057204708, 0.5284492493821207, 0.22248879223389445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 102}], {
             RGBColor[
             0.8713798486298555, 0.4417965181232547, 0.21169331699237254`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 144}], {
             RGBColor[
             0.9009503839038591, 0.6375798223152109, 0.23877628985540691`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 205}], {
             RGBColor[
             0.9593655870867921, 0.8632867059265485, 0.49267549542961175`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 207}], {
             RGBColor[
             0.931659240059644, 0.7667586905843885, 0.26386962426942273`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 213}], {
             RGBColor[
             0.9172153878071567, 0.709493629531714, 0.2522477617062842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 221}], {
             RGBColor[
             0.9226607888866434, 0.8373956409938654, 0.6248416927368453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 230}], {
             RGBColor[
             0.9461599473200244, 0.8204361321227099, 0.29539556227068897`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 250}], {
             RGBColor[
             0.9558449394073578, 0.8618308276345842, 0.5510217386219683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 289}], {
             RGBColor[
             0.9106079850234978, 0.6814327334094423, 0.24683482895909917`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 358}], {
             RGBColor[
             0.9460196672175634, 0.8199629343977746, 0.2948506005623025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 391}], {
             RGBColor[
             0.8719267260498035, 0.4460000576161881, 0.2122170074273244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 118}], {
             RGBColor[
             0.21224930323971947`, 0.34041785346099757`, 0.9353986558735721]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 126}], {
             RGBColor[
             0.2152393660615204, 0.3435605990676429, 0.935568935527872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 149}], {
             RGBColor[
             0.21932780961758047`, 0.3478578124673555, 0.9358017663400795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 199}], {
             RGBColor[
             0.22211987446733733`, 0.350792449651586, 0.9359607703027832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 212}], {
             RGBColor[
             0.2146670795751315, 0.34295908968538924`, 0.9355363446590942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 238}], {
             RGBColor[
             0.22383004590865202`, 0.3525899482675398, 0.9360581620363942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 259}], {
             RGBColor[
             0.2147288372822968, 0.3430240009512847, 0.9355398616691548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 274}], {
             RGBColor[
             0.2245824786939262, 0.35338080283185697`, 0.936101011970391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 299}], {
             RGBColor[
             0.21628284341415968`, 0.3446573599255522, 0.9356283600194184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 318}], {
             RGBColor[
             0.2211272263803799, 0.3497491135746699, 0.9359042404627222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 336}], {
             RGBColor[
             0.21472177259901426`, 0.343016575521228, 0.9355394593458932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 367}], {
             RGBColor[
             0.21887583976336028`, 0.3473827634940262, 0.9357760273255111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 18}], {
             RGBColor[
             0.9544933475167275, 0.9655817936050558, 0.9619150720050708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 69}], {
             RGBColor[
             0.7259993754166094, 0.7839523785382002, 0.9495242388978706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 74}], {
             RGBColor[
             0.8942268027978797, 0.9177720606824189, 0.9646671297303714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 88}], {
             RGBColor[
             0.9770469480723544, 0.9813851840644524, 0.8781922259657269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 132}], {
             RGBColor[
             0.8815012453075697, 0.9077928551611671, 0.9634088234551113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[
             0.8178525622986523, 0.8580700202466935, 0.9570649175635426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 191}], {
             RGBColor[
             0.8213167457883995, 0.8607762667176537, 0.9574101949991654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 198}], {
             RGBColor[
             0.8951348791523555, 0.9184961361184019, 0.9647537428637106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 216}], {
             RGBColor[
             0.8114408517281416, 0.8530611432182054, 0.956425858174716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 224}], {
             RGBColor[
             0.9697208187554422, 0.9510352770851425, 0.6530724790472836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 302}], {
             RGBColor[
             0.9755285816369456, 0.9706262250120263, 0.6756345411379316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 323}], {
             RGBColor[
             0.8969951869704291, 0.9199794950758233, 0.9649311806841149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 340}], {
             RGBColor[
             0.9787791287241259, 0.9808041152910011, 0.7551804074343922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 357}], {
             RGBColor[
             0.8197351159980406, 0.8595406855045937, 0.9572525529228332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 38}], {
             RGBColor[
             0.9800741446959539, 0.9433032752196526, 0.4743933351284341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 102}], {
             RGBColor[
             0.9068270565903578, 0.5698348658899638, 0.39664654648642544`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 205}], {
             RGBColor[
             0.9948127950472943, 0.9913250536932577, 0.6776287249236647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 207}], {
             RGBColor[
             0.9671064480201461, 0.8947970383510977, 0.44882285376347564`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.9526625957676589, 0.8375319772984231, 0.4372009912003371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 224}], {
             RGBColor[
             0.9850092930497456, 0.9599506894449308, 0.4935654545583491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 230}], {
             RGBColor[
             0.9816071552805266, 0.9484744798894191, 0.4803487917647419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 247}], {
             RGBColor[
             0.9506823086964485, 0.8296807989526216, 0.43560760573952945`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 250}], {
             RGBColor[
             0.99129214736786, 0.9898691754012934, 0.7359749681160213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 289}], {
             RGBColor[
             0.9460551929840001, 0.8094710811761514, 0.43178805845315205`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 340}], {
             RGBColor[
             0.9940676030184292, 0.9897195276507893, 0.5956733829454577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 391}], {
             RGBColor[
             0.9073739340103057, 0.5740384053828973, 0.3971702369213773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 45}], {
             RGBColor[
             0.29968000514429743`, 0.4323130645893829, 0.9403777050049051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 100}], {
             RGBColor[
             0.34023750094859895`, 0.4686666959527124, 0.9429171480552854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 105}], {
             RGBColor[
             0.36060251301143975`, 0.486305845826277, 0.9442147886158565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.3163910437219365, 0.4480120932607672, 0.9413976728873965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 155}], {
             RGBColor[
             0.30420326810120896`, 0.4370673007485326, 0.9406352981387334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 170}], {
             RGBColor[
             0.3744152758657625, 0.49826976676104406`, 0.9450949256507872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 180}], {
             RGBColor[
             0.33506546922916314`, 0.4641869420312098, 0.9425875907675709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 183}], {
             RGBColor[
             0.281397272925088, 0.41309675383481925`, 0.9393365304518997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 239}], {
             RGBColor[
             0.3141879177885835, 0.4461038563096259, 0.9412572916510711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 271}], {
             RGBColor[
             0.3053243996883596, 0.43824568113047624`, 0.940699144924056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 273}], {
             RGBColor[
             0.28964915667663804`, 0.4217700068573468, 0.9398064630239824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 326}], {
             RGBColor[
             0.3216255760176605, 0.45254598204008034`, 0.9417312126565649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 335}], {
             RGBColor[
             0.2921895478533735, 0.4244401190541993, 0.9399511345433256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 394}], {
             RGBColor[
             0.33136443385417313`, 0.4609812912088401, 0.9423517640661736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 73}], {
             RGBColor[
             0.24248824364408117`, 0.372200897085539, 0.937120718795097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 85}], {
             RGBColor[
             0.2415839884274967, 0.3712504675198166, 0.9370692227982382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 96}], {
             RGBColor[
             0.2643859994981743, 0.3952168268861021, 0.9383677635961609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 110}], {
             RGBColor[
             0.2487192272457111, 0.3787500559180304, 0.9374755640932957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 115}], {
             RGBColor[
             0.240233305102069, 0.36983081370652304`, 0.936992303381012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 184}], {
             RGBColor[
             0.22981171473055614`, 0.35887706145906934`, 0.9363988092267157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 188}], {
             RGBColor[
             0.25447321455412675`, 0.38479786140304184`, 0.9378032451582485]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 203}], {
             RGBColor[
             0.2666290431845753, 0.3975744080176934, 0.9384955016158156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 206}], {
             RGBColor[
             0.23671129027789278`, 0.36612895281767627`, 0.9367917298471292]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 208}], {
             RGBColor[
             0.2374736143413805, 0.36693020374253915`, 0.9368351430747874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 258}], {
             RGBColor[
             0.24739688608388788`, 0.37736019151568206`, 0.9374002587203583]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 284}], {
             RGBColor[
             0.24292930031788273`, 0.3726644756143127, 0.9371458363201851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 325}], {
             RGBColor[
             0.22671411419860138`, 0.35562128690076766`, 0.9362224054589102]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 348}], {
             RGBColor[
             0.252407866634222, 0.38262704978860046`, 0.9376856266496183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 369}], {
             RGBColor[
             0.24965722981087085`, 0.3797359560868109, 0.9375289819517311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 392}], {
             RGBColor[
             0.24490486142793333`, 0.37474091559878486`, 0.9372583416028217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 36}], {
             RGBColor[
             0.5275969503288876, 0.6273659981055699, 0.9559535110626505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 64}], {
             RGBColor[
             0.46723843843845614`, 0.5768882992816866, 0.951609674456959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 82}], {
             RGBColor[
             0.4573668797759753, 0.5683380513272105, 0.9509806674680623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 122}], {
             RGBColor[
             0.490802095307585, 0.5972979545178956, 0.9531111298361363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 157}], {
             RGBColor[
             0.5023802232259484, 0.6068939230427937, 0.9539683579331921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 187}], {
             RGBColor[
             0.6897252223294911, 0.7560947412907055, 0.9707766661911668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 218}], {
             RGBColor[
             0.7227901892843811, 0.7824598484159166, 0.9739304322567687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 253}], {
             RGBColor[
             0.43861619159981363`, 0.5520971476660097, 0.9497858901980598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 262}], {
             RGBColor[
             0.7370797325190604, 0.7937780282574919, 0.9726613937241215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 298}], {
             RGBColor[
             0.6794733687434446, 0.7479201915203444, 0.969798835244192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 74}], {
             RGBColor[
             0.8849400211257357, 0.9108459941170431, 0.9803872287207334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 132}], {
             RGBColor[
             0.8722144636354254, 0.9008667885957915, 0.9791289224454733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 140}], {
             RGBColor[
             0.8085657806265083, 0.8511439536813179, 0.9727850165539047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 191}], {
             RGBColor[
             0.8120299641162554, 0.853850200152278, 0.9731302939895274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.8858480974802114, 0.9115700695530261, 0.9804738418540726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 216}], {
             RGBColor[
             0.8021540700559975, 0.8461350766528297, 0.9721459571650781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.960434037083298, 0.9441092105197667, 0.6687925780376456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 247}], {
             RGBColor[
             0.926107052730001, 0.8138393200274576, 0.6108347292188259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 302}], {
             RGBColor[
             0.9662417999648014, 0.9637001584466507, 0.6913546401282936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 311}], {
             RGBColor[
             0.7322903023542322, 0.7896729975900088, 0.9664706721730203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 323}], {
             RGBColor[
             0.8877084052982851, 0.9130534285104475, 0.9806512796744769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 340}], {
             RGBColor[
             0.9694923470519816, 0.9738780487256253, 0.770900506424754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 357}], {
             RGBColor[
             0.8104483343258964, 0.8526146189392179, 0.9729726519131952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 83}], {
             RGBColor[
             0.31363288900734776`, 0.44289778603368235`, 0.9413217134716801]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 108}], {
             RGBColor[
             0.3209765938651673, 0.4492585340761873, 0.9417896478514372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 125}], {
             RGBColor[
             0.27618503388558474`, 0.4076183601292589, 0.9390397011494167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 179}], {
             RGBColor[
             0.2720136332383074, 0.4032339535668936, 0.9388021460535885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 196}], {
             RGBColor[
             0.2861541125436652, 0.4180964938749955, 0.9396074254310642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 231}], {
             RGBColor[
             0.2915341164557601, 0.4237512190985569, 0.9399138086948555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 303}], {
             RGBColor[
             0.2819979246761117, 0.4137280769086658, 0.939370736680536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 313}], {
             RGBColor[
             0.27859623109563336`, 0.41015268127575305`, 0.9391770152634824]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 344}], {
             RGBColor[
             0.2975063791842545, 0.4289298137668702, 0.9402941465258654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 50}], {
             RGBColor[
             0.4309033063250306, 0.5476259924741631, 0.9486839796675377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 54}], {
             RGBColor[
             0.4298252331165606, 0.5467147461063611, 0.9486090616680254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 116}], {
             RGBColor[
             0.4119401607737857, 0.531223595372923, 0.9474694406734923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 121}], {
             RGBColor[
             0.48042756078829996`, 0.5878320132896839, 0.9525827103922078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 130}], {
             RGBColor[
             0.4090322853711047, 0.5287049398531881, 0.9472841534241666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 135}], {
             RGBColor[
             0.45546851492086315`, 0.5675691354622958, 0.9506178428735257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 147}], {
             RGBColor[
             0.34619840677068126`, 0.47206167326583015`, 0.9433617090301424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 158}], {
             RGBColor[
             0.4553874406509526, 0.5675033157176284, 0.9506114604100135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 172}], {
             RGBColor[
             0.3545418209166673, 0.4808311305362721, 0.9438368541227812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 181}], {
             RGBColor[
             0.4874856363228792, 0.5935620769713348, 0.9531383479528726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 265}], {
             RGBColor[
             0.49977683892029745`, 0.6035406289522859, 0.9541059564454999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 322}], {
             RGBColor[
             0.45803755349750475`, 0.5696547967126826, 0.9508200870009773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 328}], {
             RGBColor[
             0.3585480828066595, 0.484978061001665, 0.9440673446781876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 347}], {
             RGBColor[
             0.3438545327447645, 0.469598113054395, 0.9432282288718172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 362}], {
             RGBColor[
             0.406159003588231, 0.5262162475882044, 0.9471010704497052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 364}], {
             RGBColor[
             0.37859437323609996`, 0.5023411502157933, 0.945344676578113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 387}], {
             RGBColor[
             0.3506138656824209, 0.476702600538333, 0.94361316288308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.416297218948796, 0.5331956497034136, 0.948244914168578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 60}], {
             RGBColor[
             0.33522274220732345`, 0.4647748233402267, 0.9425810746009868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 64}], {
             RGBColor[
             0.3559387070583645, 0.4827179508795304, 0.9439010775628867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 82}], {
             RGBColor[
             0.34606714839588365`, 0.4741677029250543, 0.94327207057399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 122}], {
             RGBColor[
             0.37950236392749337`, 0.5031276061157393, 0.9454025329420639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 159}], {
             RGBColor[
             0.3221758681761928, 0.45347427680941704`, 0.9417497393246208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 182}], {
             RGBColor[
             0.30050572685967525`, 0.4327952999017487, 0.9404388491913643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 210}], {
             RGBColor[
             0.30642042589023155`, 0.43901202359644165`, 0.9407756825511414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 263}], {
             RGBColor[
             0.2875003760669833, 0.4191258516317633, 0.9396982137034129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 29}], {
             RGBColor[
             0.2663738031073146, 0.39730613451333674`, 0.9384809660710094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 45}], {
             RGBColor[
             0.2939087453063859, 0.4262471045807297, 0.94004904029495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 91}], {
             RGBColor[
             0.2774698045998931, 0.40896873560916513`, 0.9391128669409485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 97}], {
             RGBColor[
             0.36730142212889694`, 0.4910409193978484, 0.9446807120447999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 100}], {
             RGBColor[
             0.3344662411106874, 0.46260073594405915`, 0.9425884833453301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 141}], {
             RGBColor[
             0.32619117202571163`, 0.45543328701971864`, 0.9420612032605917]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 150}], {
             RGBColor[
             0.28145958694833023`, 0.41316224982418415`, 0.9393400791433381]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 189}], {
             RGBColor[
             0.29643257003583556`, 0.4288998043911114, 0.9401927683796281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 190}], {
             RGBColor[
             0.26671069132338054`, 0.3976602253883686, 0.938500151356533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 255}], {
             RGBColor[
             0.27639668732322686`, 0.40784082131182386`, 0.9390517544995772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 266}], {
             RGBColor[
             0.27365816407618504`, 0.40496245974678047`, 0.9388957996519403]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 273}], {
             RGBColor[
             0.28387789683872655`, 0.4157040468486936, 0.9394777983140272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 350}], {
             RGBColor[
             0.36253057369193453`, 0.4869086502715662, 0.9443767178010922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 365}], {
             RGBColor[
             0.27427955709376345`, 0.40561558320684826`, 0.9389311870650228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 394}], {
             RGBColor[
             0.32559317401626164`, 0.45491533120018696`, 0.9420230993562184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[
             0.2165666874460731, 0.34495569799984427`, 0.9356445245171263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 89}], {
             RGBColor[
             0.21600037669219402`, 0.3443604694913417, 0.9356122739574746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 163}], {
             RGBColor[
             0.22919558870789478`, 0.35822947394460614`, 0.9363637217612019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 164}], {
             RGBColor[
             0.22797821780387265`, 0.3569499399387055, 0.9362943942891566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 169}], {
             RGBColor[
             0.21705819820147026`, 0.34547230696734843`, 0.9356725153275212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 227}], {
             RGBColor[
             0.22416996966139735`, 0.3529472296840859, 0.936077520191241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 245}], {
             RGBColor[
             0.22165838805798918`, 0.35030739817543277`, 0.9359344893344789]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 292}], {
             RGBColor[
             0.21221830344661968`, 0.3403852707129492, 0.9353968904812151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 304}], {
             RGBColor[
             0.2162581809318601, 0.34463143809296365`, 0.9356269555275363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 353}], {
             RGBColor[
             0.21189878814995255`, 0.34004943987771225`, 0.9353786945577505]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 378}], {
             RGBColor[
             0.21097218176330165`, 0.339075517815104, 0.9353259256948219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 25}], {
             RGBColor[
             0.8754320696783777, 0.5120010563873596, 0.21717277432657275`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 76}], {
             RGBColor[
             0.8745487301949283, 0.505211322035738, 0.2163268874396324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 104}], {
             RGBColor[
             0.9180135558932775, 0.712060691693382, 0.25285908317008815`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 109}], {
             RGBColor[
             0.9481247371168586, 0.8202041529201762, 0.49378352937662584`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 138}], {
             RGBColor[
             0.8607479504188854, 0.399132481136813, 0.2031112451403423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 144}], {
             RGBColor[
             0.8902955651891483, 0.5947396082931894, 0.23017226930310958`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 207}], {
             RGBColor[
             0.9210044213449331, 0.723918476562367, 0.2552656037171254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 233}], {
             RGBColor[
             0.8598056285506199, 0.3918893823292492, 0.202208876655091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 242}], {
             RGBColor[
             0.9102499321760205, 0.681280510728698, 0.24661228929151274`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 317}], {
             RGBColor[
             0.946390043794504, 0.8194868126517976, 0.5225318869704552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 358}], {
             RGBColor[
             0.9353648485028525, 0.777122720375753, 0.28624658001000514`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 366}], {
             RGBColor[
             0.9017167350633479, 0.6466004732099342, 0.2397023734046333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 382}], {
             RGBColor[
             0.9004669733536322, 0.6409255971753784, 0.23865954159958375`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[
             0.8478277754462535, 0.3686308171105509, 0.1934332378220659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 104}], {
             RGBColor[
             0.8912926011446027, 0.575480186768195, 0.22996543355252164`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 109}], {
             RGBColor[
             0.9214037823681839, 0.6836236479949891, 0.47088987975905927`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 138}], {
             RGBColor[
             0.8340269956702107, 0.26255197621162585`, 0.18021759552277578`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 144}], {
             RGBColor[
             0.8635746104404736, 0.45815910336800225`, 0.20727861968554306`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 205}], {
             RGBColor[
             0.9219898136234065, 0.68386598697934, 0.46117782525974793`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 207}], {
             RGBColor[
             0.8942834665962583, 0.5873379716371798, 0.2323719540995589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 233}], {
             RGBColor[
             0.8330846738019452, 0.25530887740406205`, 0.17931522703752448`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 317}], {
             RGBColor[
             0.9196690890458292, 0.6829063077266104, 0.4996382373528887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 358}], {
             RGBColor[
             0.9086438937541778, 0.640542215450566, 0.2633529303924386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 366}], {
             RGBColor[
             0.8749957803146731, 0.510019968284747, 0.21680872378706678`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 382}], {
             RGBColor[
             0.8737460186049575, 0.5043450922501913, 0.21576589198201723`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 391}], {
             RGBColor[
             0.8345509525864179, 0.2665793386689794, 0.18071933725746053`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 30}], {
             RGBColor[
             0.31701994287924884`, 0.4369570883961569, 0.9418741496415883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 62}], {
             RGBColor[
             0.31709055637755623`, 0.43703130766003234`, 0.9418781709758536]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 77}], {
             RGBColor[
             0.6422389788407158, 0.7176486903810251, 0.9669170377654001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 106}], {
             RGBColor[
             0.7018038352541023, 0.7648141211568, 0.9611581586207743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 111}], {
             RGBColor[
             0.6645955027358419, 0.5448101324102603, 0.5834436797495368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 160}], {
             RGBColor[
             0.6422952177337565, 0.39805166532506286`, 0.5630541845557195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.6399409788041857, 0.37995595327830467`, 0.56079976269803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 173}], {
             RGBColor[
             0.34074023236907375`, 0.46188861660318076`, 0.9432249850370102]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 185}], {
             RGBColor[
             0.6394016686924645, 0.37581057943241813`, 0.5602833187259821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 197}], {
             RGBColor[
             0.7219321437839568, 0.7790682930787789, 0.8931643392096228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 204}], {
             RGBColor[
             0.3170199268376633, 0.4369570715354334, 0.9418741487280438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 345}], {
             RGBColor[
             0.3285301240705917, 0.4490550186158963, 0.9425296374326482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 370}], {
             RGBColor[
             0.6431647387570222, 0.7183868662092043, 0.9670053375726531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 389}], {
             RGBColor[
             0.31710049015279534`, 0.4370417486876464, 0.9418787366896577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 400}], {
             RGBColor[
             0.4223618806328297, 0.5402016308185901, 0.9481469689308566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 51}], {
             RGBColor[
             0.33517005330446453`, 0.4636817173337682, 0.9426160703012283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[
             0.3427358884343137, 0.47023486345331306`, 0.943098158625497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 277}], {
             RGBColor[
             0.277614773953709, 0.4091211075916136, 0.9391211227311855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 287}], {
             RGBColor[
             0.27881505582512084`, 0.4103826799407336, 0.9391894770081045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 376}], {
             RGBColor[
             0.3679050083022842, 0.49203509004620194`, 0.9447019126873052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 377}], {
             RGBColor[
             0.3561480526956704, 0.48185180602152367`, 0.9439527698723194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 395}], {
             RGBColor[
             0.28524240829505776`, 0.41713823490432095`, 0.9395555052228516]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 396}], {
             RGBColor[
             0.28785811658992677`, 0.419887510167713, 0.9397044659406507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 44}], {
             RGBColor[
             0.29312282823703784`, 0.42542105591082463`, 0.9400042834805107]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 47}], {
             RGBColor[
             0.3610905157265072, 0.4852888096589335, 0.9442985989042187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 49}], {
             RGBColor[
             0.27201275594263963`, 0.40323303147352313`, 0.938802096092898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 147}], {
             RGBColor[
             0.2865134731880893, 0.418474204697066, 0.9396278904881377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 211}], {
             RGBColor[
             0.2754831553698227, 0.4068806413075249, 0.9389997302062802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 301}], {
             RGBColor[
             0.27255350960952185`, 0.40380139786317903`, 0.9388328912142536]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 328}], {
             RGBColor[
             0.2988631492240676, 0.4313905924329009, 0.9403335261361829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 347}], {
             RGBColor[
             0.28416959916217255`, 0.4160106444856309, 0.9394944103298126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 362}], {
             RGBColor[
             0.34647407000563907`, 0.4726287790194402, 0.9433672519077005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 372}], {
             RGBColor[
             0.2698833093261751, 0.4009948480649053, 0.9386808272583244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 380}], {
             RGBColor[
             0.2768898890919296, 0.40835920764152867`, 0.9390798416106783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 390}], {
             RGBColor[
             0.2772941937947283, 0.40878415751856884`, 0.9391028661653874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 45}], {
             RGBColor[
             0.26796415172899, 0.39897769174864406`, 0.938571534072304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 91}], {
             RGBColor[
             0.25152521102249714`, 0.3816993227770795, 0.9376353607183026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 150}], {
             RGBColor[
             0.2555149933709343, 0.38589283699209853`, 0.937862572920692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 190}], {
             RGBColor[
             0.2407660977459846, 0.370390812556283, 0.937022645133887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 226}], {
             RGBColor[
             0.23953161826969796`, 0.36909329635618626`, 0.936952343353961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 266}], {
             RGBColor[
             0.2477135704987891, 0.37769304691469485`, 0.9374182934292943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 273}], {
             RGBColor[
             0.25793330326133057`, 0.388434634016608, 0.9380002920913812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 365}], {
             RGBColor[
             0.24833496351636752`, 0.37834617037476265`, 0.9374536808423768]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 62}], {
             RGBColor[
             0.17899764558147852`, 0.30546825298532254`, 0.9335050231613544]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 77}], {
             RGBColor[
             0.5041460680446381, 0.5860856357063153, 0.9585438899509009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 84}], {
             RGBColor[
             0.1789270231889713, 0.3053940243730791, 0.9335010013205776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 204}], {
             RGBColor[
             0.17892701604158556`, 0.30539401686072354`, 0.9335010009135446]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 333}], {
             RGBColor[
             0.1872437438170861, 0.31413542506377157`, 0.9339746262568631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 370}], {
             RGBColor[
             0.5050718279609444, 0.5868238115344944, 0.9586321897581539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 389}], {
             RGBColor[
             0.17900757935671766`, 0.3054786940129366, 0.9335055888751587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 400}], {
             RGBColor[
             0.284268969836752, 0.4086385761438802, 0.9397738211163575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 33}], {
             RGBColor[0.1810793999809316, 0.30765630885, 0.9336235759947237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 106}], {
             RGBColor[
             0.5658561150624204, 0.6355057978202503, 0.9529071762376704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 156}], {
             RGBColor[
             0.18458847622123073`, 0.3113445704668384, 0.9338234126953957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 173}], {
             RGBColor[
             0.20479251217739197`, 0.3325802932666311, 0.9349740026539064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 175}], {
             RGBColor[
             0.18107477738655686`, 0.3076514502102228, 0.9336233127448126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 197}], {
             RGBColor[
             0.5859844235922751, 0.6497599697422292, 0.884913356826519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 204}], {
             RGBColor[
             0.1810722066459815, 0.3076487481988837, 0.9336231663449399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 214}], {
             RGBColor[
             0.5834952534993698, 0.6486610383850888, 0.9230487158880236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 261}], {
             RGBColor[
             0.18133289143212553`, 0.3079227444374911, 0.9336380119578622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 295}], {
             RGBColor[
             0.21280238164412135`, 0.34099917393122015`, 0.9354301528704966]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 310}], {
             RGBColor[
             0.18289778193115996`, 0.30956754357176464`, 0.9337271301567341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 345}], {
             RGBColor[
             0.1925824038789099, 0.3197466952793466, 0.9342786550495443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 43}], {
             RGBColor[
             0.2218603287150994, 0.3505196506098328, 0.9359459895561568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 124}], {
             RGBColor[
             0.21977833860588586`, 0.34833134699925217`, 0.9358274232994656]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 137}], {
             RGBColor[
             0.21892075175740905`, 0.34742996884735633`, 0.9357785849971308]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 199}], {
             RGBColor[
             0.22104408708317058`, 0.349661728901967, 0.9358995058027398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 238}], {
             RGBColor[
             0.22275425852448527`, 0.3514592275179208, 0.9359968975363508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 252}], {
             RGBColor[
             0.2203092674216852, 0.34888938684748844`, 0.9358576589100864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 293}], {
             RGBColor[
             0.2137582367821496, 0.342003838286004, 0.9354845874065463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 330}], {
             RGBColor[
             0.2205286799485376, 0.349120003324768, 0.935870154128899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 63}], {
             RGBColor[
             0.5687512197366357, 0.5886439817299056, 0.6135098819197802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 84}], {
             RGBColor[
             0.17893420048233583`, 0.30540156816347186`, 0.9335014100568169]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 90}], {
             RGBColor[
             0.44237359411374266`, 0.5377546224462848, 0.9524068017673784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 152}], {
             RGBColor[
             0.18127877637637368`, 0.30786586608280325`, 0.9336349301854932]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 156}], {
             RGBColor[
             0.18245046291019928`, 0.30909738291907096`, 0.9337016560002396]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 173}], {
             RGBColor[
             0.20265449886636056`, 0.33033310571886365`, 0.9348522459587503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 175}], {
             RGBColor[
             0.17893676407552545`, 0.30540426266245535`, 0.9335015560496566]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 204}], {
             RGBColor[
             0.1789341933349501, 0.3054015606511163, 0.9335014096497838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 214}], {
             RGBColor[
             0.5813572401883383, 0.6464138508373214, 0.9229269591928677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 256}], {
             RGBColor[
             0.202124876078153, 0.3297764385884332, 0.9348220847244686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 261}], {
             RGBColor[
             0.17919487812109408`, 0.3056755568897237, 0.9335162552627061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 264}], {
             RGBColor[
             0.18448620056776344`, 0.31123707227039327`, 0.9338175882482339]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 295}], {
             RGBColor[
             0.21066436833308994`, 0.3387519863834527, 0.9353083961753406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 310}], {
             RGBColor[
             0.18075976862012855`, 0.3073203560239972, 0.9336053734615781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 333}], {
             RGBColor[
             0.1872509211104506, 0.3141429688541644, 0.9339750349931024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 381}], {
             RGBColor[
             0.5860442078575524, 0.648421627973087, 0.8483684065741224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 53}], {
             RGBColor[
             0.30076648553276153`, 0.4331274488318972, 0.9404515726006413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 68}], {
             RGBColor[
             0.29450681654452554`, 0.42654813983932427`, 0.9400950937121118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 86}], {
             RGBColor[
             0.30641268277319833`, 0.4390619601211778, 0.940773115180684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 95}], {
             RGBColor[
             0.29703377047989377`, 0.4292041286435296, 0.9402390000004376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 151}], {
             RGBColor[
             0.31406226415390115`, 0.44644668080690353`, 0.9412327476508988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 244}], {
             RGBColor[
             0.2861625929026812, 0.4177778317374103, 0.9396199025198813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 249}], {
             RGBColor[
             0.2909291460215572, 0.4227877812822719, 0.9398913506685179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 253}], {
             RGBColor[
             0.3270023945629662, 0.4576547713773704, 0.9420572813180563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 270}], {
             RGBColor[
             0.28093807902462586`, 0.41228653639826196`, 0.9393223741835017]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 308}], {
             RGBColor[
             0.2866886948098787, 0.4183307981986623, 0.9396498632451982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 386}], {
             RGBColor[
             0.32582607560218535`, 0.4566359030170521, 0.9419823273140535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 397}], {
             RGBColor[
             0.28081927975955956`, 0.41216167083836874`, 0.939315608741104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 41}], {
             RGBColor[
             0.3109306833758936, 0.44117275107327436`, 0.9411269955899995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 57}], {
             RGBColor[
             0.2771242370211076, 0.4086055221736117, 0.9390931873785582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 92}], {
             RGBColor[
             0.28435244626912165`, 0.4162028283882106, 0.9395048232020553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 114}], {
             RGBColor[
             0.30495946572485455`, 0.43600078246607, 0.9407465148814157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 153}], {
             RGBColor[
             0.2992359056961653, 0.4310433224437109, 0.940381814697533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 188}], {
             RGBColor[
             0.27406348456255775`, 0.4053884772767613, 0.9389188820540213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 195}], {
             RGBColor[
             0.2633678783864708, 0.39414671704509485`, 0.9383097831050244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 208}], {
             RGBColor[
             0.25706388434981153`, 0.3875208196162586, 0.9379507799705602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 258}], {
             RGBColor[
             0.2669871560923189, 0.3979508073894016, 0.938515895616131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 278}], {
             RGBColor[
             0.26672833715189703`, 0.3976787722729497, 0.9385011562603622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 284}], {
             RGBColor[
             0.26251957032631373`, 0.3932550914880322, 0.9382614732159579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 327}], {
             RGBColor[
             0.29981659218631795`, 0.43154628389532945`, 0.9404188155272046]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 337}], {
             RGBColor[
             0.28289219144336497`, 0.41466800798083686`, 0.9394216638499819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 354}], {
             RGBColor[
             0.2804072432672092, 0.41205616989288285`, 0.9392801497275012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 369}], {
             RGBColor[
             0.26924749981930185`, 0.40032657196053045`, 0.9386446188475038]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 392}], {
             RGBColor[
             0.2644951314363644, 0.3953315314725043, 0.9383739784985945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 55}], {
             RGBColor[
             0.46160497467818506`, 0.5724389504821938, 0.9511318842995795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 60}], {
             RGBColor[
             0.4386028192989782, 0.5525156396146701, 0.9496662072988238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 64}], {
             RGBColor[
             0.45931878415001925`, 0.5704587671539738, 0.9509862102607236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 82}], {
             RGBColor[
             0.4494472254875384, 0.5619085191994977, 0.950357203271827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 122}], {
             RGBColor[
             0.4828824410191481, 0.5908684223901826, 0.952487665639901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 157}], {
             RGBColor[
             0.49446056893751156`, 0.6004643909150807, 0.9533448937369567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 165}], {
             RGBColor[
             0.5262130350709433, 0.6262424733544989, 0.9558445641840965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 218}], {
             RGBColor[
             0.7148705349959443, 0.7760303162882036, 0.9733069680605333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 262}], {
             RGBColor[
             0.7291600782306236, 0.787348496129779, 0.9720379295278863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 298}], {
             RGBColor[
             0.6715537144550077, 0.7414906593926315, 0.9691753710479567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 314}], {
             RGBColor[
             0.7227446385125958, 0.7823089126955356, 0.9740580070832467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 58}], {
             RGBColor[
             0.2743052593933725, 0.40564259795335733`, 0.9389326507729624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 87}], {
             RGBColor[
             0.2699691213947309, 0.4010850419897568, 0.9386857141286811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 110}], {
             RGBColor[
             0.2526887349083196, 0.3829222601527542, 0.9377016216823209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 134}], {
             RGBColor[
             0.24206319644531432`, 0.3717541455300861, 0.9370965129859282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 159}], {
             RGBColor[
             0.29061706023566036`, 0.4206896192842019, 0.9399383913431659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 167}], {
             RGBColor[
             0.26667449670074206`, 0.39762218254510395`, 0.9384980901263189]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 201}], {
             RGBColor[
             0.26311290635419504`, 0.3938787252730125, 0.9382952628249838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 236}], {
             RGBColor[
             0.2501608630823501, 0.3802653065873294, 0.9375576631214831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 243}], {
             RGBColor[
             0.2690857390615694, 0.4001565511479292, 0.9386354068116546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 263}], {
             RGBColor[
             0.25594156812645086`, 0.3863411941065481, 0.9378868657219579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 348}], {
             RGBColor[
             0.2563773742968305, 0.38679925402332427`, 0.9379116842386436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 351}], {
             RGBColor[
             0.2477720085286644, 0.3777544689892789, 0.9374216213886444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 78}], {
             RGBColor[
             0.9038175805994484, 0.6094521874784743, 0.2546544328195417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 102}], {
             RGBColor[
             0.8925441235088332, 0.5227994562196083, 0.24385895757801979`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 205}], {
             RGBColor[
             0.9805298619657696, 0.9442896440229023, 0.524841136015259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 207}], {
             RGBColor[
             0.9528235149386215, 0.8477616286807421, 0.29603526485507003`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 213}], {
             RGBColor[
             0.9383796626861343, 0.7904965676280676, 0.28441340229193146`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 221}], {
             RGBColor[
             0.9438250637656209, 0.9183985790902189, 0.6570073333224926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 224}], {
             RGBColor[
             0.970726359968221, 0.9129152797745752, 0.34077786564994345`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 230}], {
             RGBColor[
             0.9673242221990019, 0.9014390702190636, 0.3275612028563362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 247}], {
             RGBColor[
             0.9363993756149239, 0.7826453892822661, 0.2828200168311238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 250}], {
             RGBColor[
             0.9770092142863354, 0.9428337657309378, 0.5831873792076157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 289}], {
             RGBColor[
             0.9317722599024755, 0.7624356715057958, 0.27900046954474644`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 358}], {
             RGBColor[
             0.9671839420965409, 0.9009658724941282, 0.3270162411479497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 391}], {
             RGBColor[
             0.8930910009287811, 0.5270029957125417, 0.24438264801297166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 93}], {
             RGBColor[
             0.2591650880555334, 0.38972931793498194`, 0.9380704404131488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 94}], {
             RGBColor[
             0.2666080163774077, 0.39755230751018356`, 0.9384943041702538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 119}], {
             RGBColor[
             0.2567952159774935, 0.3872384321223937, 0.9379354797042159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 128}], {
             RGBColor[
             0.2996526087721707, 0.4306693116276521, 0.9404352763322198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 177}], {
             RGBColor[
             0.29750028265951367`, 0.4288050749279245, 0.9402981320155486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 200}], {
             RGBColor[
             0.27187585958380484`, 0.4030891447206572, 0.9387943000477824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 225}], {
             RGBColor[
             0.26510008482719366`, 0.3959673758425263, 0.9384084296992539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 288}], {
             RGBColor[
             0.2590590279232666, 0.38961784201136873`, 0.9380644004455181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 296}], {
             RGBColor[
             0.2873068026652887, 0.4193080442775966, 0.9396730694282384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 316}], {
             RGBColor[
             0.26368578568270973`, 0.3944808577699287, 0.9383278874552436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 324}], {
             RGBColor[
             0.27652485948189337`, 0.40797553837716655`, 0.9390590537143996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 355}], {
             RGBColor[
             0.25200661552040216`, 0.3822053094271858, 0.9376627759922841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 360}], {
             RGBColor[
             0.29174189371093673`, 0.42381744784571107`, 0.9399312125636886]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 374}], {
             RGBColor[
             0.2745978955714905, 0.40595017713076464`, 0.9389493159703898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 375}], {
             RGBColor[
             0.2639687025623859, 0.39477822134843454`, 0.9383439991530031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 380}], {
             RGBColor[
             0.2692913647455158, 0.4003726767791782, 0.9386471168901593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 383}], {
             RGBColor[
             0.27666419535336334`, 0.408121989212486, 0.9390669886861509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 390}], {
             RGBColor[
             0.26969566944831447`, 0.40079762665621843`, 0.9386701414448686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 41}], {
             RGBColor[
             0.34006622360312927`, 0.4689700034848203, 0.942889696952605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 55}], {
             RGBColor[
             0.37142239221905604`, 0.496129140733077, 0.9448876842896408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 58}], {
             RGBColor[
             0.31906156196643076`, 0.449858262003899, 0.9415849314423156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.3368642646638673, 0.46619662758676733`, 0.9426856709603764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 87}], {
             RGBColor[
             0.31472542396778913`, 0.4453007060402985, 0.9413379947980343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 96}], {
             RGBColor[
             0.313111809733841, 0.4436046951713676, 0.9412461018545393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 110}], {
             RGBColor[
             0.29744503748137785`, 0.4271379242032959, 0.940353902351674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 146}], {
             RGBColor[
             0.43732168419070216`, 0.5509809435704429, 0.9497020146539848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 154}], {
             RGBColor[
             0.3847350802007028, 0.5076599219476261, 0.9457359569958835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 159}], {
             RGBColor[
             0.33537336280871854`, 0.46490528333474357`, 0.9425906720125191]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 167}], {
             RGBColor[
             0.31143079927380024`, 0.4418378465956456, 0.9411503707956721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 192}], {
             RGBColor[
             0.34190093761815415`, 0.4705591405492272, 0.9430066033072686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 203}], {
             RGBColor[
             0.31535485342024205`, 0.44596227630295887`, 0.941373839874194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 228}], {
             RGBColor[
             0.35358465424250685`, 0.48067898864856917`, 0.9437510793990673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 243}], {
             RGBColor[
             0.3138420416346276, 0.4443722151984709, 0.9412876874810078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 332}], {
             RGBColor[
             0.43326686926446056`, 0.5476890621459892, 0.9493828047697146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 348}], {
             RGBColor[
             0.3011336768698887, 0.43101491807386594`, 0.9405639649079968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 361}], {
             RGBColor[
             0.34746932604333547`, 0.4753821987277793, 0.9433614160937887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 385}], {
             RGBColor[
             0.4573665882056296, 0.5672542996623962, 0.9512800229249427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 57}], {
             RGBColor[
             0.3070138697292798, 0.4370559315903547, 0.9409039388472313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.31424207897729384`, 0.44465323780495364`, 0.9413155746707285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 96}], {
             RGBColor[
             0.3138659022147775, 0.44425785217656466`, 0.9412941519606068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 114}], {
             RGBColor[
             0.3348490984330268, 0.46445119188281303`, 0.9425572663500889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 153}], {
             RGBColor[
             0.32912553840433756`, 0.45949373186045395`, 0.9421925661662062]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 154}], {
             RGBColor[
             0.3854891726816393, 0.5083130789528232, 0.945784007101951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 188}], {
             RGBColor[
             0.30395311727072993`, 0.43383888669350434`, 0.9407296335226945]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 203}], {
             RGBColor[
             0.31610894590117855`, 0.4466154333081559, 0.9414218899802616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 222}], {
             RGBColor[
             0.4728736082946373, 0.5798845479116403, 0.9524894775340721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 258}], {
             RGBColor[
             0.29687678880049106`, 0.4264012168061446, 0.9403266470848042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 312}], {
             RGBColor[
             0.40188874544580117`, 0.5222558384193261, 0.9469012891044913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 327}], {
             RGBColor[
             0.32970622489449014`, 0.4599966933120725, 0.9422295669958778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 356}], {
             RGBColor[
             0.4295993605310475, 0.5447525640945126, 0.9490827702313296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 361}], {
             RGBColor[
             0.34822341852427197`, 0.4760353557329764, 0.9434094661998561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 369}], {
             RGBColor[
             0.2991371325274741, 0.4287769813772735, 0.940455370316177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 104}], {
             RGBColor[
             0.9330499750272585, 0.8621677183315113, 0.6295247357296906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 109}], {
             RGBColor[
             0.9631611562508396, 0.9703111795583055, 0.8704491819362283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 136}], {
             RGBColor[
             0.7754039881303256, 0.825013733522431, 0.9782569627328132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 205}], {
             RGBColor[
             0.9637471875060623, 0.9705535185426564, 0.8607371274369169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 207}], {
             RGBColor[
             0.9360408404789141, 0.8740255032004962, 0.6319312562767279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 221}], {
             RGBColor[
             0.9270423893059134, 0.944662453609973, 0.9929033247441504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 276}], {
             RGBColor[
             0.8488960037945177, 0.8827904862944987, 0.9853329329150746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 358}], {
             RGBColor[
             0.9504012676368335, 0.9272297470138823, 0.6629122325696076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 366}], {
             RGBColor[
             0.9167531541973288, 0.7967074998480634, 0.6163680259642358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 376}], {
             RGBColor[
             0.6853095806395425, 0.7514657941798157, 0.9712763701432583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 124}], {
             RGBColor[
             0.22535325774935577`, 0.3541909404893282, 0.9361449066973324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 137}], {
             RGBColor[
             0.22449567090087896`, 0.35328956233743236`, 0.9360960683949977]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 199}], {
             RGBColor[
             0.2266190062266405, 0.3555213223920431, 0.9362169892006067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 238}], {
             RGBColor[
             0.22832917766795519`, 0.3573188210079969, 0.9363143809342176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 252}], {
             RGBColor[
             0.2258841865651551, 0.3547489803375645, 0.9361751423079533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 277}], {
             RGBColor[
             0.2426240388727448, 0.37234362648077923`, 0.9371284521324783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 293}], {
             RGBColor[
             0.21933315592561953`, 0.34786343177608003`, 0.9358020708044131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 299}], {
             RGBColor[
             0.22078197517346282`, 0.34938623266600927`, 0.9358845789172419]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 330}], {
             RGBColor[
             0.2261035990920075, 0.35497959681484403`, 0.9361876375267658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 367}], {
             RGBColor[
             0.22337497152266345`, 0.35211163623448327`, 0.9360322462233344]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 47}], {
             RGBColor[
             0.36592423069765223`, 0.4903693505688373, 0.9445738718209851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 49}], {
             RGBColor[
             0.2768464709137847, 0.4083135723834269, 0.9390773690096643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 54}], {
             RGBColor[
             0.3749740145051137, 0.4982078184475008, 0.9451505160427869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 93}], {
             RGBColor[
             0.2715973273730923, 0.4027963897072362, 0.9387784380504338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[
             0.3120848480897295, 0.44373638339990634`, 0.9411432739695049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 211}], {
             RGBColor[
             0.28031687034096775`, 0.4119611822174286, 0.9392750031230466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 301}], {
             RGBColor[
             0.2773872245806669, 0.4088819387730828, 0.9391081641310199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 316}], {
             RGBColor[
             0.27611802500026855`, 0.4075479295421829, 0.9390358850925288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 324}], {
             RGBColor[
             0.2889570987994522, 0.4210426101494208, 0.9397670513516847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 328}], {
             RGBColor[
             0.3036968641952127, 0.4364711333428047, 0.9406087990529493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 362}], {
             RGBColor[
             0.35130778497678417`, 0.477709319929344, 0.9436425248244668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 372}], {
             RGBColor[
             0.27471702429732014`, 0.4060753889748091, 0.9389561001750906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 380}], {
             RGBColor[
             0.2817236040630746, 0.41343974855143245`, 0.9393551145274445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 383}], {
             RGBColor[
             0.28909643467092216`, 0.42118906098474024`, 0.9397749863234359]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 390}], {
             RGBColor[
             0.28212790876587335`, 0.4138646984284726, 0.9393781390821536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 91}], {
             RGBColor[
             0.27906015322156846`, 0.41064029284447245`, 0.9392034349422431]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 97}], {
             RGBColor[
             0.36889177075057233`, 0.4927124766331557, 0.9447712800460943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 100}], {
             RGBColor[
             0.33605658973236274`, 0.46427229317936647`, 0.9426790513466246]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 112}], {
             RGBColor[
             0.31221013250570034`, 0.4436176904874213, 0.9411595761787357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 141}], {
             RGBColor[
             0.32778152064738697`, 0.45710484425502595`, 0.9421517712618861]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 180}], {
             RGBColor[
             0.33088455801292704`, 0.4597925392578639, 0.9423494940589101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 190}], {
             RGBColor[
             0.2683010399450559, 0.3993317826236759, 0.9385907193578275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 266}], {
             RGBColor[
             0.2752485126978604, 0.4066340169820878, 0.9389863676532347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 271}], {
             RGBColor[
             0.30114348847212347`, 0.43385127835713033`, 0.9404610482153953]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 273}], {
             RGBColor[
             0.2854682454604019, 0.41737560408400093`, 0.9395683663153217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 350}], {
             RGBColor[
             0.36412092231360993`, 0.48858020750687353`, 0.9444672858023867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 365}], {
             RGBColor[
             0.2758699057154388, 0.4072871404421556, 0.9390217550663172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 394}], {
             RGBColor[
             0.32718352263793704`, 0.4565868884354943, 0.9421136673575129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 59}], {
             RGBColor[
             0.30916725287120805`, 0.4399481765928165, 0.9410035436196971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 287}], {
             RGBColor[
             0.27226485336384204`, 0.4034980018471065, 0.9388164526680909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 373}], {
             RGBColor[
             0.26731905714517273`, 0.3982996564396932, 0.9385347968900875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 395}], {
             RGBColor[
             0.27869220583377896`, 0.41025355681069386`, 0.939182480882838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 54}], {
             RGBColor[
             0.44294170199458305`, 0.5580755721956097, 0.9494448314664949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 121}], {
             RGBColor[
             0.4935440296663224, 0.5991928393789325, 0.9534184801906773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 128}], {
             RGBColor[
             0.3800525355791988, 0.5036041371480152, 0.945437589393213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 130}], {
             RGBColor[
             0.4221487542491271, 0.5400657659424366, 0.9481199232226362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.468503909528975, 0.5788641418068768, 0.9514472302084831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 181}], {
             RGBColor[
             0.5006021052009016, 0.6049229030605833, 0.9539741177513421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 265}], {
             RGBColor[
             0.5128933077983199, 0.6149014550415344, 0.9549417262439694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 311}], {
             RGBColor[
             0.47663297852550124`, 0.5854636862286419, 0.9520871802976505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 322}], {
             RGBColor[
             0.47115402237552717`, 0.5810156228019311, 0.9516558567994469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 362}], {
             RGBColor[
             0.4192754724662534, 0.5375770736774529, 0.9479368402481747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 56}], {
             RGBColor[
             0.43818896314994105`, 0.5539589886879809, 0.9491419911499963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 71}], {
             RGBColor[
             0.6482814539995922, 0.7214952269023049, 0.9679496107647267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 83}], {
             RGBColor[
             0.38916228198081126`, 0.5114945416119245, 0.9460180543784913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 103}], {
             RGBColor[
             0.3850045259376993, 0.5078933023022759, 0.9457531258399835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 108}], {
             RGBColor[
             0.3965059868386308, 0.5178552896544295, 0.9464859887582483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 120}], {
             RGBColor[
             0.49591060473188847`, 0.6008847208403402, 0.9536681725336434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 143}], {
             RGBColor[
             0.5250435709581793, 0.6245361752480152, 0.9559616263525487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 196}], {
             RGBColor[
             0.3616835055171287, 0.4866932494532377, 0.9443037663378753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 231}], {
             RGBColor[
             0.3670635094292236, 0.49234797467679914`, 0.9446101496016666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 234}], {
             RGBColor[
             0.38209114426819646`, 0.5053698775309731, 0.945567487736205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 286}], {
             RGBColor[
             0.5758463873446392, 0.6644950889479655, 0.9608396409213635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 290}], {
             RGBColor[
             0.4152883060919923, 0.5341235905648768, 0.9476827815325197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 313}], {
             RGBColor[
             0.35412562406909687`, 0.4787494368539953, 0.9438733561702934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 320}], {
             RGBColor[
             0.5676684575710711, 0.6581064280542859, 0.9600245413086331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 331}], {
             RGBColor[
             0.43876768248625253`, 0.5544602462898143, 0.9491788666343646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 342}], {
             RGBColor[
             0.5144005472567488, 0.6158956891444403, 0.9551237685400916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 343}], {
             RGBColor[
             0.5738217336869491, 0.6629134141226403, 0.9606378423662292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 344}], {
             RGBColor[
             0.373035772157718, 0.49752656934511247`, 0.9449904874326764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 349}], {
             RGBColor[
             0.43541101780241814`, 0.5515528720515495, 0.9489649829288928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 147}], {
             RGBColor[
             0.2702371158648362, 0.4013667211696683, 0.9387009760172913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 211}], {
             RGBColor[
             0.25920679804656954`, 0.3897731577801271, 0.9380728157354339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 301}], {
             RGBColor[
             0.2562771522862687, 0.3866939143357813, 0.9379059767434073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 328}], {
             RGBColor[
             0.2825867919008145, 0.4142831089055032, 0.9394066116653366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 347}], {
             RGBColor[
             0.2678932418389194, 0.3989031609582332, 0.9385674958589661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 372}], {
             RGBColor[
             0.25360695200292194`, 0.3838873645375076, 0.9377539127874779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 380}], {
             RGBColor[
             0.2606135317686764, 0.39125172411413095`, 0.9381529271398318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 54}], {
             RGBColor[
             0.4530695590105145, 0.5668252864420751, 0.9500963936878091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 116}], {
             RGBColor[
             0.4351844866677396, 0.551334135708637, 0.9489567726932759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 121}], {
             RGBColor[
             0.5036718866822538, 0.607942553625398, 0.9540700424119916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.4322766112650586, 0.5488154801889021, 0.9487714854439504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 135}], {
             RGBColor[
             0.478712840814817, 0.5876796757980098, 0.9521051748933094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 158}], {
             RGBColor[
             0.47863176654490647`, 0.5876138560533424, 0.9520987924297972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 172}], {
             RGBColor[
             0.3777861468106212, 0.500941670871986, 0.945324186142565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 181}], {
             RGBColor[
             0.5107299622168331, 0.6136726173070488, 0.9546256799726562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 265}], {
             RGBColor[
             0.5230211648142513, 0.6236511692879999, 0.9555932884652836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 276}], {
             RGBColor[
             0.6098568885565028, 0.6922609454050347, 0.9637197242270632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 322}], {
             RGBColor[
             0.4812818793914586, 0.5897653370483966, 0.952307419020761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 328}], {
             RGBColor[
             0.38179240870061343`, 0.505088601337379, 0.9455546766979714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 362}], {
             RGBColor[
             0.4294033294821849, 0.5463267879239184, 0.948588402469489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 364}], {
             RGBColor[
             0.4018386991300539, 0.5224516905515073, 0.9468320085978967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 59}], {
             RGBColor[
             0.3534707906164537, 0.48058036569863427`, 0.9437438241095009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 136}], {
             RGBColor[
             0.4957527510770341, 0.5993305404010079, 0.9540497614266502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 194}], {
             RGBColor[
             0.38048922371828053`, 0.5039823744655038, 0.945465414775287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 246}], {
             RGBColor[
             0.408363122473439, 0.5281253445843351, 0.9472415149560449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 376}], {
             RGBColor[
             0.405658343586251, 0.5257826010583926, 0.9470691688370954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 377}], {
             RGBColor[
             0.39390138797963725`, 0.5155993170337143, 0.9463200260221095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 395}], {
             RGBColor[
             0.3229957435790246, 0.45088574591651165`, 0.9419227613726417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 396}], {
             RGBColor[
             0.3256114518738936, 0.4536350211799036, 0.9420717220904409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 117}], {
             RGBColor[
             0.36808130040816744`, 0.4932352549346425, 0.9446747928738624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 133}], {
             RGBColor[
             0.34195185422260005`, 0.4695411184843201, 0.9430487372114036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 174}], {
             RGBColor[
             0.5576254346896334, 0.6486129747855855, 0.95972095993169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 223}], {
             RGBColor[
             0.42035633884682855`, 0.5384929234825571, 0.9480113327439608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 260}], {
             RGBColor[
             0.5977997596730911, 0.6799974627988412, 0.9637251611956289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 267}], {
             RGBColor[
             0.4789222153161444, 0.5860393403630161, 0.9526218530734996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 272}], {
             RGBColor[
             0.5168312067307885, 0.6167442138565202, 0.9556549725324873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 291}], {
             RGBColor[
             0.5415685327056081, 0.6360692009186899, 0.9581205580022027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 346}], {
             RGBColor[
             0.36583874865596927`, 0.4912928693208167, 0.944531899459223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 384}], {
             RGBColor[
             0.5675366621289825, 0.6563557009893235, 0.9607088184571579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 68}], {
             RGBColor[
             0.28298429153365734`, 0.4147648110152172, 0.9394269088138741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 86}], {
             RGBColor[
             0.2948901577623302, 0.4272786312970708, 0.9401049302824465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 95}], {
             RGBColor[
             0.2855112454690256, 0.4174207998194225, 0.9395708151022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 101}], {
             RGBColor[
             0.27504289638646184`, 0.40641790120198085`, 0.9389746581084827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 129}], {
             RGBColor[
             0.26346421560774436`, 0.39424797357278596`, 0.9383152693672578]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 151}], {
             RGBColor[
             0.302539739143033, 0.43466335198279643`, 0.9405645627526612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 171}], {
             RGBColor[
             0.28122827358250124`, 0.41291912481058346`, 0.9393269061893516]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 244}], {
             RGBColor[
             0.27464006789181306`, 0.4059945029133032, 0.9389517176216438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 249}], {
             RGBColor[
             0.279406621010689, 0.4110044524581648, 0.9392231657702803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 253}], {
             RGBColor[
             0.31547986955209806`, 0.4458714425532633, 0.9413890964198188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 270}], {
             RGBColor[
             0.26941555401375766`, 0.4005032075741548, 0.9386541892852642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 308}], {
             RGBColor[
             0.27516616979901054`, 0.4065474693745552, 0.9389816783469607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 386}], {
             RGBColor[
             0.3143035505913172, 0.444852574192945, 0.9413141424158159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 397}], {
             RGBColor[
             0.26929675474869136`, 0.4003783420142617, 0.9386474238428664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 121}], {
             RGBColor[
             0.502593813473784, 0.607031307257596, 0.9539951244124792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 128}], {
             RGBColor[
             0.3891023193866603, 0.5114426050266787, 0.9460142336150148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 130}], {
             RGBColor[
             0.43119853805658864`, 0.5479042338211002, 0.9486965674444381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 158}], {
             RGBColor[
             0.4775536933364365, 0.5867026096855403, 0.9520238744302849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 181}], {
             RGBColor[
             0.5096518890083631, 0.6127613709392468, 0.9545507619731439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 265}], {
             RGBColor[
             0.5219430916057815, 0.622739922920198, 0.9555183704657713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 311}], {
             RGBColor[
             0.48568276233296276`, 0.5933021541073054, 0.9526638245194523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 322}], {
             RGBColor[
             0.48020380618298864`, 0.5888540906805946, 0.9522325010212487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 328}], {
             RGBColor[
             0.38071433549214345`, 0.504177354969577, 0.9454797586984591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 362}], {
             RGBColor[
             0.4283252562737149, 0.5454155415561164, 0.9485134844699766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 58}], {
             RGBColor[
             0.351171823063294, 0.4776705562573528, 0.9436309688854188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 60}], {
             RGBColor[
             0.38053049793671245`, 0.5040181241190069, 0.9454680447319882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 80}], {
             RGBColor[
             0.36897452576073053`, 0.49400892184022105`, 0.9447317084034796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 87}], {
             RGBColor[
             0.34683568506465234`, 0.47311300029375225`, 0.9433840322411374]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 122}], {
             RGBColor[
             0.4248101196568824, 0.5423709068945195, 0.9482895030730654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 146}], {
             RGBColor[
             0.4694319452875655, 0.5787932378238967, 0.951748052097088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 159}], {
             RGBColor[
             0.36748362390558187`, 0.49271757758819734`, 0.9446367094556223]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.4681407137086776, 0.5777449578588358, 0.9516464016172608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 192}], {
             RGBColor[
             0.3740111987150174, 0.498371434802681, 0.9450526407503718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 201}], {
             RGBColor[
             0.33997947002411655`, 0.46590668357700793`, 0.9429935809374401]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 210}], {
             RGBColor[
             0.3517281816196206, 0.4782553243752219, 0.9436626526821428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 228}], {
             RGBColor[
             0.38569491533937006`, 0.508491282902023, 0.9457971168421706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 385}], {
             RGBColor[
             0.4894768493024928, 0.5950665939158499, 0.9533260603680459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 71}], {
             RGBColor[
             0.6610275221983658, 0.7325352305400676, 0.968761778959447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 83}], {
             RGBColor[
             0.4019083501795848, 0.5225345452496872, 0.9468302225732115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 108}], {
             RGBColor[
             0.40925205503740436`, 0.5288952932921922, 0.9472981569529686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 120}], {
             RGBColor[
             0.5086566729306621, 0.6119247244781029, 0.9544803407283637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 143}], {
             RGBColor[
             0.5377896391569529, 0.6355761788857779, 0.956773794547269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 196}], {
             RGBColor[
             0.3744295737159023, 0.4977332530910004, 0.9451159345325955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 231}], {
             RGBColor[
             0.37980957762799716`, 0.5033879783145618, 0.9454223177963867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 237}], {
             RGBColor[
             0.5146770314008289, 0.6168123226982427, 0.9549542854004349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 254}], {
             RGBColor[
             0.46022321075082034`, 0.5726042579779009, 0.9506674811679487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 286}], {
             RGBColor[
             0.5885924555434128, 0.6755350925857282, 0.9616518091160838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 290}], {
             RGBColor[
             0.42803437429076585`, 0.5451635942026395, 0.9484949497272399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 320}], {
             RGBColor[
             0.5804145257698448, 0.6691464316920486, 0.9608367095033534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 331}], {
             RGBColor[
             0.4515137506850261, 0.565500249927577, 0.9499910348290849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 342}], {
             RGBColor[
             0.5271466154555224, 0.626935692782203, 0.9559359367348119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 343}], {
             RGBColor[
             0.5865678018857227, 0.673953417760403, 0.9614500105609494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 344}], {
             RGBColor[
             0.38578184035649155`, 0.5085665729828752, 0.9458026556273967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 349}], {
             RGBColor[
             0.44815708600119175`, 0.5625928756893122, 0.949777151123613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 92}], {
             RGBColor[
             0.2804356326225079, 0.4120860089052909, 0.9392817664592872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 114}], {
             RGBColor[
             0.3010426520782409, 0.43188396298315035`, 0.9405234581386476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 153}], {
             RGBColor[
             0.2953190920495516, 0.42692650296079127`, 0.9401587579547649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 188}], {
             RGBColor[
             0.270146670915944, 0.40127165779384166`, 0.9386958253112532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 195}], {
             RGBColor[
             0.25945106473985713`, 0.3900298975621752, 0.9380867263622563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 208}], {
             RGBColor[
             0.2531470707031978, 0.383404000133339, 0.9377277232277921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 258}], {
             RGBColor[
             0.26307034244570515`, 0.39383398790648194`, 0.9382928388733629]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 278}], {
             RGBColor[
             0.26281152350528336`, 0.39356195279003, 0.9382780995175941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 284}], {
             RGBColor[
             0.2586027566797, 0.38913827200511253`, 0.9380384164731898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 327}], {
             RGBColor[
             0.2958997785397042, 0.4274294644124098, 0.9401957587844365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 337}], {
             RGBColor[
             0.27897537779675124`, 0.41055118849791716`, 0.9391986071072138]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 354}], {
             RGBColor[
             0.27649042962059545`, 0.4079393504099632, 0.939057092984733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 392}], {
             RGBColor[
             0.2605783177897506, 0.3912147119895847, 0.9381509217558264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 60}], {
             RGBColor[
             0.3281696676840872, 0.4577472453898289, 0.942165291884663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 80}], {
             RGBColor[
             0.31661369550810525`, 0.44773804311104304`, 0.9414289555561544]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 87}], {
             RGBColor[
             0.29447485481202706`, 0.42684212156457424`, 0.9400812793938123]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 110}], {
             RGBColor[
             0.2771944683256158, 0.40867933972757164`, 0.939097186947452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 159}], {
             RGBColor[
             0.31512279365295653`, 0.44644669885901933`, 0.9413339566082971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 167}], {
             RGBColor[
             0.2911802301180382, 0.4233792621199214, 0.9398936553914501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 192}], {
             RGBColor[
             0.32165036846239214`, 0.45210055607350297`, 0.9417498879030466]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 201}], {
             RGBColor[
             0.2876186397714912, 0.4196358048478299, 0.939690828090115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 210}], {
             RGBColor[
             0.2993673513669953, 0.4319844456460439, 0.9403598998348177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 228}], {
             RGBColor[
             0.3333340850867448, 0.46222040417284493`, 0.9424943639948453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 236}], {
             RGBColor[
             0.27466659649964625`, 0.4060223861621468, 0.9389532283866143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 243}], {
             RGBColor[
             0.2935914724788655, 0.42591363072274663`, 0.9400309720767858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 263}], {
             RGBColor[
             0.28044730154374703`, 0.41209827368136553`, 0.9392824309870891]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 348}], {
             RGBColor[
             0.28088310771412667`, 0.4125563335981417, 0.9393072495037748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 351}], {
             RGBColor[
             0.27227774194596055`, 0.4035115485640963, 0.9388171866537756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 79}], {
             RGBColor[
             0.46241207497172554`, 0.5712067102742551, 0.9517169387007705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[
             0.3610366257463029, 0.4871335118181791, 0.9442259124337696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 237}], {
             RGBColor[
             0.4562186120487096, 0.5661785780610258, 0.9512293666120685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 246}], {
             RGBColor[
             0.38891052450146135`, 0.5112764819370106, 0.9460020126145274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 254}], {
             RGBColor[
             0.401764791398701, 0.521970513340684, 0.9469425623795822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 349}], {
             RGBColor[
             0.38969866664907243`, 0.5119591310520951, 0.9460522323352465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 373}], {
             RGBColor[
             0.2921699969184407, 0.4220829828981863, 0.9400355750383738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 395}], {
             RGBColor[
             0.303543145607047, 0.434036883269187, 0.9406832590311243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 87}], {
             RGBColor[
             0.32383352968544554`, 0.4531896894262284, 0.9419183552403817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 122}], {
             RGBColor[
             0.4018079642776756, 0.5224475960269956, 0.9468238260723096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 146}], {
             RGBColor[
             0.44642978990835863`, 0.5588699269563728, 0.9502823750963323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 159}], {
             RGBColor[
             0.344481468526375, 0.4727942667206735, 0.9431710324548666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 165}], {
             RGBColor[
             0.4451385583294708, 0.557821646991312, 0.950180724616505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 201}], {
             RGBColor[
             0.3169773146449097, 0.44598337270948407`, 0.9415279039366844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 210}], {
             RGBColor[
             0.3287260262404138, 0.45833201350769803`, 0.942196975681387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 263}], {
             RGBColor[
             0.3098059764171655, 0.4384458415430197, 0.9411195068336586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 66}], {
             RGBColor[
             0.9830643953423903, 0.9540141570597834, 0.4329439736998075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 98}], {
             RGBColor[
             0.985458002900472, 0.9620883573989745, 0.44224268706809605`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 107}], {
             RGBColor[
             0.9162817916828967, 0.6453128669663495, 0.3511545314597267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 131}], {
             RGBColor[
             0.9579060415796807, 0.8592435772757068, 0.3867967672286041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 215}], {
             RGBColor[
             0.9063170503481712, 0.5687194984901538, 0.341612283904028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 262}], {
             RGBColor[
             0.9659943820446136, 0.9709682059989204, 0.7529333373497976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 269}], {
             RGBColor[
             0.9932024163292561, 0.9878689808064407, 0.5015031511422814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 279}], {
             RGBColor[
             0.9694977718101772, 0.9052009249245101, 0.39612374546494056`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 297}], {
             RGBColor[
             0.9699924620425022, 0.9739499675150907, 0.7461656307796394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 298}], {
             RGBColor[
             0.9083880182689977, 0.925110369261773, 0.7500707788698681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 300}], {
             RGBColor[
             0.9416713408004723, 0.7907793854302443, 0.3735219082012329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 306}], {
             RGBColor[
             0.9818610097196364, 0.9499548547858537, 0.42826904779571534`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 307}], {
             RGBColor[
             0.9892929392100926, 0.9881701251038566, 0.7056981044009731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 314}], {
             RGBColor[
             0.9595789423265859, 0.965928622564677, 0.7549534149051582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 352}], {
             RGBColor[
             0.9937500196167237, 0.9890402488671484, 0.5611063895673631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 77}], {
             RGBColor[
             0.5042166815429454, 0.5861598549701907, 0.9585479112851663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 204}], {
             RGBColor[
             0.17899762953989296`, 0.30546823612459895`, 0.9335050222478098]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 345}], {
             RGBColor[
             0.19050782677282135`, 0.3175661832050619, 0.9341605109524143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 370}], {
             RGBColor[
             0.5051424414592518, 0.5868980307983699, 0.9586362110924191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 389}], {
             RGBColor[
             0.17907819285502502`, 0.305552913276812, 0.9335096102094239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 400}], {
             RGBColor[
             0.2843395833350594, 0.4087127954077557, 0.9397778424506229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 90}], {
             RGBColor[
             0.8321834271804781, 0.8209894828739578, 0.632414864387591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 138}], {
             RGBColor[
             0.8889519646070447, 0.5107811215593289, 0.22983700543826907`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 142}], {
             RGBColor[
             0.890072513149207, 0.5193941486818902, 0.23091004398772222`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 152}], {
             RGBColor[
             0.5710886094431091, 0.5911007265104762, 0.6136429928057057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 156}], {
             RGBColor[
             0.5722602959769347, 0.592332243346744, 0.6137097186204522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 202}], {
             RGBColor[
             0.9074503393274316, 0.6529677356997123, 0.2475510699614376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 214}], {
             RGBColor[
             0.9711670732550739, 0.9296487112649943, 0.6029350218130802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 217}], {
             RGBColor[
             0.8906933611547283, 0.5241662585096577, 0.23150456873895697`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 242}], {
             RGBColor[
             0.9384539463641798, 0.7929291511512139, 0.2733380495894395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 256}], {
             RGBColor[
             0.5919347091448884, 0.6130112990161062, 0.6148301473446811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 257}], {
             RGBColor[
             0.8905841112547781, 0.5233265159050291, 0.23139995091138454`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 261}], {
             RGBColor[
             0.5690047111878296, 0.5889104173173967, 0.6135243178829187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 264}], {
             RGBColor[
             0.5742960336344989, 0.5944719326980662, 0.6138256508684465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 268}], {
             RGBColor[
             0.8879400264016856, 0.5030029210787892, 0.2288679722699964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 317}], {
             RGBColor[
             0.9745940579826633, 0.9311354530743134, 0.5492576472683819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 381}], {
             RGBColor[
             0.975854040924288, 0.9316564884007599, 0.528376469194335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 82}], {
             RGBColor[
             0.38908871359710695`, 0.5114308203756144, 0.9460133666661356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 151}], {
             RGBColor[
             0.35739789501188024`, 0.48398182614394664`, 0.9439940557289754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 157}], {
             RGBColor[
             0.43410205704708005`, 0.5499866920911975, 0.9490010571312653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 171}], {
             RGBColor[
             0.3360864294513485, 0.46223759897173367`, 0.9427563991656658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 182}], {
             RGBColor[
             0.34352729206089855`, 0.4700584173523088, 0.9431801452835099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 253}], {
             RGBColor[
             0.3703380254209453, 0.4951899167144135, 0.9448185893961331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 105}], {
             RGBColor[
             0.46633814789011974`, 0.5766565671437895, 0.9514008797073982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 113}], {
             RGBColor[
             0.6559239156864949, 0.7291861264524664, 0.9676704388099608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 148}], {
             RGBColor[
             0.5696101053080527, 0.6614741699887192, 0.9592609405218679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 161}], {
             RGBColor[
             0.4733844161827434, 0.5827596905831183, 0.9518498616922337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 168}], {
             RGBColor[
             0.592741338058181, 0.6798274166038522, 0.9613729899467283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 170}], {
             RGBColor[
             0.4801509107444425, 0.5886204880785566, 0.952281016742329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 180}], {
             RGBColor[
             0.4408011041078431, 0.5545376633487222, 0.9497736818591127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 239}], {
             RGBColor[
             0.4199235526672635, 0.5364545776271384, 0.9484433827426128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 251}], {
             RGBColor[
             0.6688240146939028, 0.7392826292624911, 0.9689511985946974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 282}], {
             RGBColor[
             0.5810969797016021, 0.6707307553552915, 0.9602123891284602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 312}], {
             RGBColor[
             0.4891446804627151, 0.5961487131731942, 0.9529264075234798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 326}], {
             RGBColor[
             0.4273612108963405, 0.5428967033575929, 0.9489173037481067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 356}], {
             RGBColor[
             0.5168552955479615, 0.6186454388483807, 0.9551078886503179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[
             0.9751764945744315, 0.9279266287426179, 0.3580657982576656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 107}], {
             RGBColor[
             0.906000283356856, 0.6111511383099929, 0.2669776426492963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 131}], {
             RGBColor[
             0.9476245332536402, 0.8250818486193503, 0.3026198784181737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 215}], {
             RGBColor[
             0.8960355420221306, 0.5345577698337973, 0.25743539509359753`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 297}], {
             RGBColor[
             0.9597109537164616, 0.9397882388587341, 0.661988741969209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 307}], {
             RGBColor[
             0.9790114308840521, 0.9540083964475, 0.6215212155905427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 314}], {
             RGBColor[
             0.9492974340005453, 0.9317668939083206, 0.6707765260947278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 352}], {
             RGBColor[
             0.983468511290683, 0.9548785202107917, 0.47692950075693274`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 85}], {
             RGBColor[
             0.22712666696496037`, 0.35605490601556716`, 0.9362458997286371]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 127}], {
             RGBColor[
             0.21172079285419906`, 0.33986235553632177`, 0.9353685579889777]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 139}], {
             RGBColor[
             0.21205827028800195`, 0.34021706571655375`, 0.9353877768295796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 184}], {
             RGBColor[
             0.2153543932680198, 0.3436814999548199, 0.9355754861571146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 305}], {
             RGBColor[
             0.20792423756527648`, 0.33587193521215575`, 0.9351523497817738]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 325}], {
             RGBColor[
             0.21225679273606501`, 0.3404257253965182, 0.9353990823893092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 86}], {
             RGBColor[
             0.28863048877409425`, 0.42069932230449786`, 0.9397484513939167]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 95}], {
             RGBColor[
             0.2792515764807897, 0.4108414908268496, 0.9392143362136705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 129}], {
             RGBColor[
             0.25720454661950837`, 0.38766866458021304`, 0.9379587904787283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 151}], {
             RGBColor[
             0.29628007015479707`, 0.4280840429902235, 0.9402080838641316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 178}], {
             RGBColor[
             0.2603565331566741, 0.3909816022782634, 0.9381382914490737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 229}], {
             RGBColor[
             0.2618103919644219, 0.39250970006517877`, 0.9382210865573835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 249}], {
             RGBColor[
             0.2731469520224531, 0.4044251434655919, 0.9388666868817508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 308}], {
             RGBColor[
             0.26890650081077455`, 0.39996816038198235`, 0.938625199458431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 309}], {
             RGBColor[
             0.27375753584035556`, 0.40506690577145743`, 0.9389014587269024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 319}], {
             RGBColor[
             0.2591541477712746, 0.38971781900257185`, 0.9380698173801449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 334}], {
             RGBColor[
             0.2690618295669699, 0.40013142075315566`, 0.938634045201308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 371}], {
             RGBColor[
             0.27438511411724903`, 0.40572653033123346`, 0.9389371983813526]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 386}], {
             RGBColor[
             0.30804388160308127`, 0.43827326520037213`, 0.9409576635272863]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 74}], {
             RGBColor[
             0.6564460490256175, 0.7292165790501876, 0.9679963956135333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 97}], {
             RGBColor[
             0.46525153460871527`, 0.5764515941781216, 0.9511282282884884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 100}], {
             RGBColor[
             0.4324163535905058, 0.5480114107243323, 0.9490359995890186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 132}], {
             RGBColor[
             0.6437204915353074, 0.7192373735289359, 0.9667380893382732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 140}], {
             RGBColor[
             0.5800718085263902, 0.6695145386144623, 0.9603941834467046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 141}], {
             RGBColor[
             0.42414128450553, 0.540843961799992, 0.9485087195042803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 168}], {
             RGBColor[
             0.5791845558214077, 0.6688214100579597, 0.9603057503889199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 191}], {
             RGBColor[
             0.5835359920161374, 0.6722207850854224, 0.9607394608823273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 216}], {
             RGBColor[
             0.5736600979558795, 0.6645056615859741, 0.959755124057878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 219}], {
             RGBColor[
             0.4677032328653056, 0.5785751319820428, 0.9512844483334466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 220}], {
             RGBColor[
             0.4818265682663484, 0.5902075400149862, 0.9523502989242535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 350}], {
             RGBColor[
             0.4604806861717529, 0.5723193250518395, 0.9508242340447808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 357}], {
             RGBColor[
             0.5819543622257783, 0.6709852038723623, 0.9605818188059951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 394}], {
             RGBColor[
             0.42354328649608, 0.5403260059804602, 0.948470615599907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 75}], {
             RGBColor[
             0.2609941288153654, 0.3916517557414475, 0.9381746015785979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 103}], {
             RGBColor[
             0.3111881460301813, 0.44109703206764383`, 0.9411543384931023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 133}], {
             RGBColor[
             0.28753417910083867`, 0.4195470313278583, 0.9396860181798696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.2579170969731607, 0.3884176001802034, 0.937999369167245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 164}], {
             RGBColor[
             0.26017432145076, 0.3907900862224582, 0.9381279147619799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 227}], {
             RGBColor[
             0.25636607330828476`, 0.3867873759678386, 0.9379110406640643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 234}], {
             RGBColor[
             0.30827476436067847`, 0.438573607296341, 0.9409687003893238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 280}], {
             RGBColor[
             0.2584116720913199, 0.38893742998726233`, 0.9380275344885658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 346}], {
             RGBColor[
             0.3114210735342079, 0.4412987821643549, 0.9411691804276892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 79}], {
             RGBColor[
             0.730962985173496, 0.7893766931257962, 0.9742494771038676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 109}], {
             RGBColor[
             0.932608231427341, 0.9459491066410988, 0.8675350166916449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 120}], {
             RGBColor[
             0.7187491637803132, 0.7794609626924269, 0.9732879603430942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 143}], {
             RGBColor[
             0.7478821300066041, 0.8031124171001021, 0.9755814141619994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 237}], {
             RGBColor[
             0.7247695222504801, 0.7843485609125668, 0.9737619050151656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 286}], {
             RGBColor[
             0.798684946393064, 0.8430713308000524, 0.9804594287308144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 320}], {
             RGBColor[
             0.7905070166194959, 0.8366826699063725, 0.9796443291180839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 321}], {
             RGBColor[
             0.8444532383444727, 0.878825868324395, 0.985021184343525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 343}], {
             RGBColor[
             0.7966602927353739, 0.841489655974727, 0.98025763017568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 382}], {
             RGBColor[
             0.8849504676641144, 0.7666705508963009, 0.612411028914603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 119}], {
             RGBColor[
             0.2341124382405141, 0.36339739454965503`, 0.9366437290682574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 200}], {
             RGBColor[
             0.24919308184682543`, 0.37924810714791846`, 0.937502549411824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 288}], {
             RGBColor[
             0.2363762501862872, 0.36577680443863003`, 0.9367726498095597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 341}], {
             RGBColor[
             0.22465511090045148`, 0.353457143886063, 0.936105148267103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 355}], {
             RGBColor[
             0.2293238377834227, 0.358364271854447, 0.9363710253563257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 374}], {
             RGBColor[
             0.25191511783451104`, 0.3821091395580259, 0.9376575653344313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 375}], {
             RGBColor[
             0.24128592482540645`, 0.37093718377569584`, 0.9370522485170447]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 379}], {
             RGBColor[
             0.22434193474233927`, 0.3531279758873717, 0.9360873133482011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 393}], {
             RGBColor[
             0.22527325394479547`, 0.3541068514182011, 0.9361403505990177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 399}], {
             RGBColor[
             0.23130276285488832`, 0.3604442475756538, 0.9364837222115884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 85}], {
             RGBColor[
             0.24221172142071856`, 0.3719102546962633, 0.9371049712635544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 96}], {
             RGBColor[
             0.26501373249139615`, 0.3958766140625488, 0.9384035120614771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 110}], {
             RGBColor[
             0.24934696023893294`, 0.3794098430944771, 0.9375113125586119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 115}], {
             RGBColor[
             0.24086103809529086`, 0.3704906008829697, 0.9370280518463283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 184}], {
             RGBColor[
             0.230439447723778, 0.35953684863551605`, 0.9364345576920319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 188}], {
             RGBColor[
             0.2551009475473486, 0.3854576485794885, 0.9378389936235647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 195}], {
             RGBColor[
             0.2444053413712617, 0.37421588834782205`, 0.937229894674568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 203}], {
             RGBColor[
             0.2672567761777972, 0.39823419519414005`, 0.9385312500811318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 206}], {
             RGBColor[
             0.23733902327111464`, 0.366788739994123, 0.9368274783124455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 208}], {
             RGBColor[
             0.23810134733460236`, 0.3675899909189858, 0.9368708915401036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 258}], {
             RGBColor[
             0.2480246190771097, 0.3780199786921288, 0.9374360071856744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 284}], {
             RGBColor[
             0.24355703331110456`, 0.3733242627907594, 0.9371815847855014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 348}], {
             RGBColor[
             0.2530355996274438, 0.3832868369650472, 0.9377213751149346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 369}], {
             RGBColor[
             0.2502849628040927, 0.38039574326325765`, 0.9375647304170474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 392}], {
             RGBColor[
             0.24553259442115521`, 0.3754007027752315, 0.9372940900681379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 132}], {
             RGBColor[
             0.8119479189165777, 0.8530570556731545, 0.981880980170774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 140}], {
             RGBColor[
             0.7482992359076605, 0.8033342207586809, 0.9755370742792053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 191}], {
             RGBColor[
             0.7517634193974077, 0.8060404672296411, 0.9758823517148281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 198}], {
             RGBColor[
             0.8255815527613636, 0.8637603366303892, 0.9832258995793732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 216}], {
             RGBColor[
             0.7418875253371497, 0.7983253437301927, 0.9748980148903788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 219}], {
             RGBColor[
             0.6359306602465759, 0.7123948141262615, 0.9664273391659474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 220}], {
             RGBColor[
             0.6500539956476187, 0.724027222159205, 0.9674931897567542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 224}], {
             RGBColor[
             0.9001674923644503, 0.8962994775971298, 0.6715446357629462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 302}], {
             RGBColor[
             0.9059752552459537, 0.9158904255240137, 0.6941066978535942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 311}], {
             RGBColor[
             0.6720237576353845, 0.741863264667372, 0.9692227298983209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 323}], {
             RGBColor[
             0.8274418605794372, 0.8652436955878107, 0.9834033373997775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 340}], {
             RGBColor[
             0.9092258023331339, 0.9260683158029884, 0.7736525641500547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 357}], {
             RGBColor[
             0.7501817896070486, 0.8048048860165811, 0.9757247096384958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 89}], {
             RGBColor[
             0.23138047401831524`, 0.3605259269355878, 0.9364881477473821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 133}], {
             RGBColor[
             0.27071817278007254`, 0.4018723424883518, 0.9387283714969541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 145}], {
             RGBColor[
             0.24110109065239455`, 0.37074291134069687`, 0.9370417224843294]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.24457568603401603`, 0.37439493138885227`, 0.9372395955511095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 164}], {
             RGBColor[
             0.2433583151299939, 0.3731153973829517, 0.9371702680790643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 169}], {
             RGBColor[
             0.2324382955275915, 0.3616377644115946, 0.9365483891174288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 209}], {
             RGBColor[
             0.24810555583118551`, 0.37810504835234904`, 0.9374406164140838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 227}], {
             RGBColor[
             0.2395500669875186, 0.36911268712833206`, 0.9369533939811485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 280}], {
             RGBColor[
             0.24159566577055375`, 0.3712627411477558, 0.9370698878056503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 315}], {
             RGBColor[
             0.24372617436870905`, 0.3735020407664642, 0.9371912171185102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[
             0.8904092616611533, 0.5686904524165735, 0.22911954666558126`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 109}], {
             RGBColor[
             0.9205204428847344, 0.6768339136433675, 0.4700439928721189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 138}], {
             RGBColor[
             0.8331436561867612, 0.2557622418600043, 0.17937170863583543`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 144}], {
             RGBColor[
             0.8626912709570241, 0.4513693690163807, 0.2064327327986027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 207}], {
             RGBColor[
             0.8934001271128089, 0.5805482372855583, 0.23152606721261854`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 233}], {
             RGBColor[
             0.8322013343184957, 0.24851914305244047`, 0.17846934015058413`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 242}], {
             RGBColor[
             0.8826456379438963, 0.5379102714518893, 0.22287275278700588`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 257}], {
             RGBColor[
             0.8347758028344946, 0.2683076362057045, 0.1809346541089509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 317}], {
             RGBColor[
             0.9187857495623798, 0.676116573374989, 0.49879235046594833`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 358}], {
             RGBColor[
             0.9077605542707283, 0.6337524810989443, 0.26250704350549825`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 366}], {
             RGBColor[
             0.8741124408312237, 0.5032302339331254, 0.2159628369001264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 382}], {
             RGBColor[
             0.8728626791215081, 0.4975553578985697, 0.2149200050950769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 78}], {
             RGBColor[
             0.8356045267952863, 0.5947068735494174, 0.5856449487468838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 102}], {
             RGBColor[
             0.8243310697046711, 0.5080541422905515, 0.574849473505362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 111}], {
             RGBColor[
             0.8517216279012312, 0.6939386797204187, 0.6001134200588495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 160}], {
             RGBColor[
             0.8294213428991457, 0.5471802126352212, 0.5797239248650322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 166}], {
             RGBColor[
             0.827067103969575, 0.529084500588463, 0.5774695030073427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 185}], {
             RGBColor[
             0.8265277938578538, 0.5249391267425765, 0.5769530590352949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 370}], {
             RGBColor[
             0.8302908639224114, 0.8675154135193626, 0.9836750778819656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 389}], {
             RGBColor[
             0.5042266153181847, 0.5861702959978048, 0.9585484769989704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 400}], {
             RGBColor[
             0.6094880057982189, 0.6893301781287484, 0.9648167092401694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 102}], {
             RGBColor[
             0.8305704924938522, 0.23598377814878552`, 0.17690764417753302`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 144}], {
             RGBColor[
             0.8601410277678558, 0.4317670823407418, 0.2039906170405674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 160}], {
             RGBColor[
             0.835660765688327, 0.2751098484934552, 0.18178209553720334`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 185}], {
             RGBColor[
             0.832767216647035, 0.2528687626008105, 0.17901122970746597`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 207}], {
             RGBColor[
             0.8908498839236407, 0.5609459506099194, 0.22908395145458324`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 213}], {
             RGBColor[
             0.8764060316711535, 0.5036808895572449, 0.2174620888914447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 230}], {
             RGBColor[
             0.9053505911840212, 0.6146233921482407, 0.26060988945584945`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 247}], {
             RGBColor[
             0.874425744599943, 0.49582971121144337`, 0.21586870343063702`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 289}], {
             RGBColor[
             0.8697986288874946, 0.4756199934349731, 0.21204915614425965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 370}], {
             RGBColor[
             0.8365302867115927, 0.5954450493775967, 0.5857332485541368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 391}], {
             RGBColor[
             0.8311173699138001, 0.24018731764171894`, 0.1774313346124849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 400}], {
             RGBColor[
             0.6157274285874001, 0.4172598139869824, 0.5668748799123404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 109}], {
             RGBColor[
             0.79245120355282, 0.8352543310125031, 0.854215095221335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 120}], {
             RGBColor[
             0.5785921359057922, 0.6687661870638313, 0.9599680388727843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 136}], {
             RGBColor[
             0.6046940354323059, 0.6899568849766287, 0.9620228760179198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 237}], {
             RGBColor[
             0.5846124943759591, 0.6736537852839712, 0.9604419835448554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 246}], {
             RGBColor[
             0.5173044068287108, 0.618751689159956, 0.9552146295473145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 254}], {
             RGBColor[
             0.5301586737259505, 0.6294457205636295, 0.9561551793123693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 286}], {
             RGBColor[
             0.658527918518543, 0.7323765551714567, 0.9671395072605043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 320}], {
             RGBColor[
             0.6503499887449748, 0.725987894277777, 0.9663244076477739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 343}], {
             RGBColor[
             0.6565032648608529, 0.7307948803461315, 0.9669377087053699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 349}], {
             RGBColor[
             0.518092548976322, 0.6194343382750406, 0.9552648492680336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 87}], {
             RGBColor[
             0.3122775575094636, 0.4431804871474425, 0.9411820189118731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 96}], {
             RGBColor[
             0.31066394327551555`, 0.4414844762785116, 0.9410901259683782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 110}], {
             RGBColor[
             0.29499717102305234`, 0.4250177053104399, 0.9401979264655129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 146}], {
             RGBColor[
             0.4348738177323767, 0.548860724677587, 0.9495460387678236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 154}], {
             RGBColor[
             0.38228721374237734`, 0.5055397030547701, 0.9455799811097223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 159}], {
             RGBColor[
             0.3329254963503931, 0.4627850644418876, 0.9424346961263579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 167}], {
             RGBColor[
             0.30898293281547473`, 0.43971762770278966`, 0.9409943949095109]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 192}], {
             RGBColor[
             0.3394530711598287, 0.46843892165637124`, 0.9428506274211075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 201}], {
             RGBColor[
             0.30542134246892777`, 0.4359741704306982, 0.9407915676081757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 203}], {
             RGBColor[
             0.31290698696191654`, 0.4438420574101029, 0.9412178639880329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 228}], {
             RGBColor[
             0.35113678778418134`, 0.4785587697557132, 0.9435951035129062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 243}], {
             RGBColor[
             0.3113941751763021, 0.44225199630561496`, 0.9411317115948465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 332}], {
             RGBColor[
             0.4308190028061351, 0.5455688432531333, 0.9492268288835535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 348}], {
             RGBColor[
             0.2986858104115632, 0.42889469918101, 0.9404079890218355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 361}], {
             RGBColor[
             0.34502145958500996`, 0.47326197983492335`, 0.9432054402076274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 385}], {
             RGBColor[
             0.4549187217473041, 0.5651340807695402, 0.9511240470387816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 89}], {
             RGBColor[
             0.21914913629591037`, 0.3476700154777373, 0.9357915911587338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 163}], {
             RGBColor[
             0.23234434831161116`, 0.36153901993100174`, 0.9365430389624612]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 169}], {
             RGBColor[
             0.22020695780518662`, 0.3487818529537441, 0.9358518325287805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 209}], {
             RGBColor[
             0.23587421810878062`, 0.36524913689449845`, 0.9367440598254355]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 227}], {
             RGBColor[
             0.2273187292651137, 0.35625677567048153`, 0.9362568373925002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 240}], {
             RGBColor[
             0.22946097871463872`, 0.3585084156683923, 0.9363788353294766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 245}], {
             RGBColor[
             0.22480714766170556`, 0.3536169441618284, 0.9361138065357382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 248}], {
             RGBColor[
             0.21796166804011632`, 0.3464219110510618, 0.9357239665982682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 292}], {
             RGBColor[
             0.21536706305033604`, 0.3436948166993449, 0.9355762076824743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 304}], {
             RGBColor[
             0.21940694053557647`, 0.34794098407935925`, 0.9358062727287957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 315}], {
             RGBColor[
             0.23149483664630416`, 0.3606461293086136, 0.9364946605298619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 329}], {
             RGBColor[
             0.22742713619850993`, 0.35637071823087746`, 0.9362630110069835]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 353}], {
             RGBColor[
             0.2150475477536689, 0.34335898586410785`, 0.9355580117590097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 378}], {
             RGBColor[
             0.21412094136701804`, 0.3423850638014996, 0.9355052428960813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 151}], {
             RGBColor[
             0.34752633634939933`, 0.4754315781894705, 0.9433650487400788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 157}], {
             RGBColor[
             0.4242304983845992, 0.5414364441367214, 0.9483720501423687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 171}], {
             RGBColor[
             0.32621487078886763`, 0.45368735101725755`, 0.9421273921767691]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 182}], {
             RGBColor[
             0.3336557333984177, 0.4615081693978327, 0.9425511382946132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 253}], {
             RGBColor[
             0.3604664667584644, 0.48663966875993736`, 0.9441895824072364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 108}], {
             RGBColor[
             0.3602253738682746, 0.48643084621613597`, 0.9441742201814636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 120}], {
             RGBColor[
             0.45962999176153224`, 0.5694602774020465, 0.9513564039568587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 125}], {
             RGBColor[
             0.315433813888692, 0.4447906722692076, 0.9414242734794431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 179}], {
             RGBColor[
             0.3112624132414147, 0.4404062657068423, 0.9411867183836149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 196}], {
             RGBColor[
             0.32540289254677246`, 0.4552688060149441, 0.9419919977610904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 231}], {
             RGBColor[
             0.3307828964588674, 0.4609235312385056, 0.9422983810248817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 237}], {
             RGBColor[
             0.4656503502316991, 0.5743478756221865, 0.9518303486289299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 246}], {
             RGBColor[
             0.39834226268445083`, 0.5194457794981713, 0.946602994631389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 254}], {
             RGBColor[
             0.4111965295816905, 0.5301398109018447, 0.9475435443964437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 303}], {
             RGBColor[
             0.32124670467921895`, 0.4509003890486145, 0.9417553090105623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 313}], {
             RGBColor[
             0.31784501109874064`, 0.44732499341570175`, 0.9415615875935087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 344}], {
             RGBColor[
             0.33675515918736176`, 0.4661021259068189, 0.9426787188558917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 349}], {
             RGBColor[
             0.3991304048320619, 0.5201284286132558, 0.946653214352108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.44236640792617826`, 0.5377470693075241, 0.9524063925246276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 152}], {
             RGBColor[
             0.18127159018880934`, 0.30785831294404253`, 0.9336345209427424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 156}], {
             RGBColor[
             0.18244327672263497`, 0.3090898297803102, 0.9337012467574888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 175}], {
             RGBColor[
             0.1789295778879611, 0.3053967095236947, 0.9335011468069058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 204}], {
             RGBColor[
             0.17892700714738574`, 0.30539400751235557`, 0.933501000407033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 256}], {
             RGBColor[
             0.20211768989058865`, 0.32976888544967253`, 0.9348216754817178]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 261}], {
             RGBColor[
             0.17918769193352976`, 0.30566800375096304`, 0.9335158460199553]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 264}], {
             RGBColor[
             0.18447901438019912`, 0.31122951913163255`, 0.9338171790054831]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 317}], {
             RGBColor[
             0.5847770387283635, 0.6478930395078799, 0.8692491754054186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 333}], {
             RGBColor[
             0.18724373492288626`, 0.3141354157154036, 0.9339746257503516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 381}], {
             RGBColor[
             0.5860370216699882, 0.6484140748343261, 0.8483679973313716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 389}], {
             RGBColor[
             0.1790075704625178, 0.3054786846645686, 0.933505588368647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 96}], {
             RGBColor[
             0.2641094772748117, 0.3949261844968264, 0.9383520160646184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 110}], {
             RGBColor[
             0.2484427050223485, 0.37845941352875473`, 0.9374598165617531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 115}], {
             RGBColor[
             0.2399567828787064, 0.36954017131724737`, 0.9369765558494695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 139}], {
             RGBColor[
             0.2262390695271757, 0.3551219848315275, 0.9361953523676381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 167}], {
             RGBColor[
             0.2624284668147709, 0.39315933592110447`, 0.9382562850057511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 184}], {
             RGBColor[
             0.22953519250719354`, 0.35858641906979366`, 0.9363830616951732]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 188}], {
             RGBColor[
             0.25419669233076414`, 0.38450721901376617`, 0.937787497626706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 203}], {
             RGBColor[
             0.2663525209612127, 0.3972837656284177, 0.9384797540842731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 258}], {
             RGBColor[
             0.24712036386052527`, 0.3770695491264064, 0.9373845111888157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 284}], {
             RGBColor[
             0.24265277809452013`, 0.37237383322503703`, 0.9371300887886426]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 325}], {
             RGBColor[
             0.22643759197523877`, 0.355330644511492, 0.9362066579273677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 348}], {
             RGBColor[
             0.2521313444108594, 0.3823364073993248, 0.9376698791180758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 351}], {
             RGBColor[
             0.24352597864269326`, 0.37329162236527946`, 0.9371798162680766]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 369}], {
             RGBColor[
             0.24938070758750824`, 0.3794453136975352, 0.9375132344201885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 95}], {
             RGBColor[
             0.2911574427094625, 0.42335531110870317`, 0.9398923576822427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 151}], {
             RGBColor[
             0.30818593638346986`, 0.44059786327207706`, 0.9408861053327038]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[
             0.27226239938534696`, 0.40349542256011695`, 0.9388163129176459]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 229}], {
             RGBColor[
             0.27371625819309475`, 0.4050235203470323, 0.9388991080259558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 249}], {
             RGBColor[
             0.2850528182511259, 0.41693896374744543`, 0.939544708350323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 308}], {
             RGBColor[
             0.28081236703944734`, 0.4124819806638359, 0.9393032209270034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 309}], {
             RGBColor[
             0.28566340206902835`, 0.417580726053311, 0.9395794801954747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 334}], {
             RGBColor[
             0.28096769579564274`, 0.4126452410350092, 0.9393120666698803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 371}], {
             RGBColor[
             0.2862909803459218, 0.418240350613087, 0.9396152198499249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 386}], {
             RGBColor[
             0.31994974783175406`, 0.4507870854822257, 0.9416356849958585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 110}], {
             RGBColor[
             0.27285833032697415`, 0.4041217837639711, 0.9388502503031707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 134}], {
             RGBColor[
             0.26223279186396886`, 0.39295366914130303`, 0.9382451416067781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 159}], {
             RGBColor[
             0.3107866556543149, 0.4418891428954188, 0.9410870199640158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 167}], {
             RGBColor[
             0.28684409211939654`, 0.41882170615632086`, 0.9396467187471687]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 192}], {
             RGBColor[
             0.3173142304637505, 0.44754300010990244`, 0.9415029512587653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 201}], {
             RGBColor[
             0.2832825017728496, 0.4150782488842294, 0.9394438914458336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 210}], {
             RGBColor[
             0.2950312133683537, 0.42742688968244336`, 0.9401129631905363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 228}], {
             RGBColor[
             0.32899794708810315`, 0.4576628482092444, 0.9422474273505641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 236}], {
             RGBColor[
             0.2703304585010046, 0.4014648301985463, 0.938706291742333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 243}], {
             RGBColor[
             0.2892553344802239, 0.4213560747591461, 0.9397840354325044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 263}], {
             RGBColor[
             0.2761111635451054, 0.407540717717765, 0.9390354943428079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 348}], {
             RGBColor[
             0.27654696971548504`, 0.4079987776345412, 0.9390603128594934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 351}], {
             RGBColor[
             0.2679416039473189, 0.3989539926004958, 0.9385702500094941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[
             0.8934147061054667, 0.915612925432826, 0.8952711863200087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 132}], {
             RGBColor[
             0.8947680641910523, 0.9166701790551881, 0.8954060764061295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 140}], {
             RGBColor[
             0.8311193811821351, 0.8669473441407145, 0.8890621705145608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 168}], {
             RGBColor[
             0.8302321284771527, 0.8662542155842119, 0.8889737374567761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 282}], {
             RGBColor[
             0.8185877701205739, 0.8571575543356513, 0.887813136638508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 283}], {
             RGBColor[
             0.9496145330722283, 0.8334245259791293, 0.5278793972462171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 357}], {
             RGBColor[
             0.8330019348815232, 0.8684180093986145, 0.8892498058738514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 163}], {
             RGBColor[
             0.23177803755773202`, 0.36094379142249916`, 0.9365107884028094]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 164}], {
             RGBColor[
             0.2305606666537099, 0.3596642574165986, 0.9364414609307642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 169}], {
             RGBColor[
             0.2196406470513075, 0.3481866244452415, 0.9358195819691286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 209}], {
             RGBColor[
             0.23530790735490154`, 0.3646539083859959, 0.9367118092657838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 227}], {
             RGBColor[
             0.22675241851123462`, 0.35566154716197895`, 0.9362245868328485]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 245}], {
             RGBColor[
             0.22424083690782642`, 0.3530217156533258, 0.9360815559760864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.22879801729426974`, 0.3578116011814027, 0.9363410806573501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 292}], {
             RGBColor[
             0.21480075229645693`, 0.3430995881908423, 0.9355439571228226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 304}], {
             RGBColor[
             0.21884062978169738`, 0.3473457555708567, 0.9357740221691438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 315}], {
             RGBColor[
             0.23092852589242507`, 0.36005090080011104`, 0.93646240997021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 329}], {
             RGBColor[
             0.22686082544463082`, 0.3557754897223749, 0.9362307604473317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 353}], {
             RGBColor[
             0.21448123699978983`, 0.34276375735560527`, 0.9355257611993579]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 378}], {
             RGBColor[
             0.2135546306131389, 0.341789835292997, 0.9354729923364294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 138}], {
             RGBColor[
             0.7625743389841517, 0.45989176227570816`, 0.5687339252858672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 142}], {
             RGBColor[
             0.763694887526314, 0.46850478939826945`, 0.5698069638353204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 152}], {
             RGBColor[
             0.4447109838202162, 0.5402113672268555, 0.9525399126533038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 156}], {
             RGBColor[
             0.4458826703540418, 0.5414428840631231, 0.9526066384680504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 175}], {
             RGBColor[
             0.44236897151936794`, 0.5377497638065076, 0.9524065385174674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 202}], {
             RGBColor[
             0.7810727137045386, 0.6020783764160916, 0.5864479898090358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 242}], {
             RGBColor[
             0.8120763207412868, 0.7420397918675932, 0.6122349694370377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 256}], {
             RGBColor[
             0.46555708352199543`, 0.5621219397324855, 0.9537270671922793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[
             0.7642064856318851, 0.4724371566214084, 0.5702968707589827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 261}], {
             RGBColor[
             0.4426270855649366, 0.538021058033776, 0.9524212377305169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 264}], {
             RGBColor[
             0.44791840801160593`, 0.5435825734144455, 0.9527225707160447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 268}], {
             RGBColor[
             0.7615624007787926, 0.45211356179516854`, 0.5677648921175946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 317}], {
             RGBColor[
             0.8482164323597703, 0.8802460937906929, 0.8881545671159801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 333}], {
             RGBColor[
             0.4506831285542931, 0.5464884699982167, 0.9528800174609131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 381}], {
             RGBColor[
             0.849476415301395, 0.8807671291171392, 0.8672733890419332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 141}], {
             RGBColor[
             0.3113425799408942, 0.43982647528346147`, 0.9412155979078848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 150}], {
             RGBColor[
             0.2666109948635128, 0.3975554380879269, 0.9384944737906311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 186}], {
             RGBColor[
             0.2555444422624831, 0.38592378964428387`, 0.9378642499915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 189}], {
             RGBColor[
             0.28158397795101814`, 0.4132929926548542, 0.9393471630269211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 190}], {
             RGBColor[
             0.25186209923856306`, 0.38205341365211143`, 0.9376545460038261]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 226}], {
             RGBColor[
             0.25062761976227643`, 0.38075589745201466`, 0.9375842442239002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 241}], {
             RGBColor[
             0.2767915804260243, 0.40825587900053273`, 0.9390742430775896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 255}], {
             RGBColor[
             0.26154809523840944`, 0.39223400957556664`, 0.9382061491468703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 266}], {
             RGBColor[
             0.25880957199136756`, 0.38935564801052325`, 0.9380501942992334]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 273}], {
             RGBColor[
             0.26902930475390907`, 0.40009723511243644`, 0.9386321929613204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 365}], {
             RGBColor[
             0.259430965008946, 0.3900087714705911, 0.9380855817123159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 114}], {
             RGBColor[
             0.3082708613262549, 0.43948126919774927`, 0.9409350939621447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 153}], {
             RGBColor[
             0.30254730129756563`, 0.4345238091753902, 0.940570393778262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 161}], {
             RGBColor[
             0.35955024405905767`, 0.48389689314418627`, 0.9442025708853012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 188}], {
             RGBColor[
             0.27737488016395806`, 0.40886896400844064`, 0.9391074611347503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 195}], {
             RGBColor[
             0.26667927398787117`, 0.3976272037767742, 0.9384983621857534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 258}], {
             RGBColor[
             0.2702985516937192, 0.40143129412108086`, 0.93870447469686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 278}], {
             RGBColor[
             0.2700397327532974, 0.4011592590046289, 0.9386897353410912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 284}], {
             RGBColor[
             0.26583096592771405`, 0.3967355782197115, 0.9384500522966869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 327}], {
             RGBColor[
             0.3031279877877182, 0.4350267706270088, 0.9406073946079336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 337}], {
             RGBColor[
             0.2862035870447653, 0.41814849471251614`, 0.9396102429307109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 354}], {
             RGBColor[
             0.2837186388686095, 0.41553665662456213`, 0.9394687288082302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 392}], {
             RGBColor[
             0.26780652703776464`, 0.39881201820418366`, 0.9385625575793235]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 94}], {
             RGBColor[
             0.2526810398598759, 0.3829141721689455, 0.9377011834606958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 119}], {
             RGBColor[
             0.24286823945996167`, 0.3726002967811557, 0.9371423589946579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 128}], {
             RGBColor[
             0.2857256322546389, 0.41603117628641406`, 0.9396421556226617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 225}], {
             RGBColor[
             0.25117310830966183`, 0.38132924050128825`, 0.9376153089896959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 296}], {
             RGBColor[
             0.27337982614775685`, 0.40466990893635857`, 0.9388799487186803]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 301}], {
             RGBColor[
             0.25102800874557624`, 0.38117673165959054`, 0.9376070457841768]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 316}], {
             RGBColor[
             0.2497588091651779, 0.37984272242869066`, 0.9375347667456857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 324}], {
             RGBColor[
             0.26259788296436154`, 0.3933374030359285, 0.9382659330048415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 355}], {
             RGBColor[
             0.23807963900287032`, 0.36756717408594775`, 0.936869655282726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 380}], {
             RGBColor[
             0.25536438822798396`, 0.38573454143794017`, 0.9378539961806014]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 383}], {
             RGBColor[
             0.2627372188358315, 0.39348385387124796`, 0.9382738679765928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 390}], {
             RGBColor[
             0.2557686929307827, 0.3861594913149804, 0.9378770207353105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 119}], {
             RGBColor[
             0.25031116778183593`, 0.38042328635635736`, 0.9375662227517629]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 128}], {
             RGBColor[
             0.29316856057651314`, 0.42385416586161573`, 0.9400660193797667]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 177}], {
             RGBColor[
             0.29101623446385616`, 0.4219899291618881, 0.9399288750630955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 200}], {
             RGBColor[
             0.26539181138814727`, 0.3962739989546208, 0.9384250430953294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 225}], {
             RGBColor[
             0.2586160366315361, 0.3891522300764899, 0.9380391727468009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 288}], {
             RGBColor[
             0.25257497972760906`, 0.38280269624533236`, 0.9376951434930652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 296}], {
             RGBColor[
             0.2808227544696311, 0.4124928985115602, 0.9393038124757853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 316}], {
             RGBColor[
             0.25720173748705216`, 0.38766571200389227`, 0.9379586305027907]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 324}], {
             RGBColor[
             0.2700408112862358, 0.4011603926111301, 0.9386897967619465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 355}], {
             RGBColor[
             0.2455225673247446, 0.37539016366114936`, 0.937293519039831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 375}], {
             RGBColor[
             0.25748465436672835`, 0.3879630755823982, 0.9379747422005502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 380}], {
             RGBColor[
             0.2628073165498582, 0.39355753101314184`, 0.9382778599377064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 383}], {
             RGBColor[
             0.2701801471577058, 0.4013068434464496, 0.9386977317336979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 390}], {
             RGBColor[
             0.26321162125265696`, 0.393982480890182, 0.9383008844924156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 129}], {
             RGBColor[
             0.2597315005548766, 0.39032465338441835`, 0.9381026967670542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 151}], {
             RGBColor[
             0.2988070240901653, 0.4307400317944288, 0.9403519901524575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 178}], {
             RGBColor[
             0.2628834870920424, 0.39363759108246865`, 0.9382821977373995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 229}], {
             RGBColor[
             0.2643373458997902, 0.3951656888693841, 0.9383649928457094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 249}], {
             RGBColor[
             0.2756739059578213, 0.4070811322697972, 0.9390105931700766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 270}], {
             RGBColor[
             0.26568283896088996`, 0.3965798873857872, 0.9384416166850604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 308}], {
             RGBColor[
             0.2714334547461428, 0.4026241491861876, 0.9387691057467569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 309}], {
             RGBColor[
             0.2762844897757238, 0.4077228945756627, 0.9390453650152284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 334}], {
             RGBColor[
             0.27158878350233817`, 0.4027874095573609, 0.9387779514896339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 371}], {
             RGBColor[
             0.27691206805261726`, 0.40838251913543877`, 0.9390811046696785]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 386}], {
             RGBColor[
             0.3105708355384495, 0.4409292540045774, 0.9411015698156122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 110}], {
             RGBColor[
             0.2712447160930261, 0.4024257728950402, 0.9387583573596757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 114}], {
             RGBColor[
             0.3078946845637386, 0.4390858835693603, 0.940913671252023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 115}], {
             RGBColor[
             0.262758793949384, 0.3935065306835328, 0.9382750966473921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 153}], {
             RGBColor[
             0.3021711245350493, 0.4341284235470012, 0.9405489710681403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 154}], {
             RGBColor[
             0.3585347588123511, 0.48294777063937044`, 0.9441404120038852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 167}], {
             RGBColor[
             0.28523047788544853`, 0.41712569528738996`, 0.9395548258036737]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 188}], {
             RGBColor[
             0.2769987034014417, 0.4084735783800516, 0.9390860384246287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 192}], {
             RGBColor[
             0.3157006162298024, 0.44584698924097155`, 0.9414110583152703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 203}], {
             RGBColor[
             0.28915453203189034`, 0.42125012499470316`, 0.9397782948821958]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 228}], {
             RGBColor[
             0.3273843328541551, 0.4559668373403135, 0.9421555344070691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 243}], {
             RGBColor[
             0.2876417202462759, 0.4196600638902152, 0.9396921424890095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 258}], {
             RGBColor[
             0.26992237493120286`, 0.4010359084926919, 0.9386830519867384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 284}], {
             RGBColor[
             0.2654547891651977, 0.3963401925913225, 0.9384286295865651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 348}], {
             RGBColor[
             0.27493335548153697`, 0.4063027667656103, 0.9389684199159984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 361}], {
             RGBColor[
             0.32126900465498376`, 0.45067004741952366`, 0.9417658711017902]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 369}], {
             RGBColor[
             0.27218271865818583`, 0.40341167306382075`, 0.9388117752181111]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 100}], {
             RGBColor[
             0.4094492665548738, 0.5290661079964851, 0.9473107230964745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 105}], {
             RGBColor[
             0.42981427861771465`, 0.5467052578700499, 0.9486083636570456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 112}], {
             RGBColor[
             0.38560280932821134`, 0.5084115053045399, 0.9457912479285857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 132}], {
             RGBColor[
             0.6207534044996754, 0.7002920708010887, 0.965012812845729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 140}], {
             RGBColor[
             0.5571047214907582, 0.6505692358866151, 0.9586689069541604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 141}], {
             RGBColor[
             0.401174197469898, 0.5218986590721447, 0.9467834430117361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 168}], {
             RGBColor[
             0.5562174687857758, 0.6498761073301125, 0.9585804738963757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 180}], {
             RGBColor[
             0.40427723483543804`, 0.5245863540749827, 0.9469811658087601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 220}], {
             RGBColor[
             0.4588594812307164, 0.571262237287139, 0.9506250224317093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 282}], {
             RGBColor[
             0.5445731104291971, 0.6407794460815519, 0.9574198730781076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 350}], {
             RGBColor[
             0.437513599136121, 0.5533740223239922, 0.9490989575522366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 357}], {
             RGBColor[
             0.5589872751901463, 0.652039901144515, 0.958856542313451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 394}], {
             RGBColor[
             0.40057619946044803`, 0.521380703252613, 0.9467453391073628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 107}], {
             RGBColor[
             0.9083938909149378, 0.6192253386491839, 0.2762763560175848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 131}], {
             RGBColor[
             0.9500181408117219, 0.8331560489585412, 0.3119185917864623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 215}], {
             RGBColor[
             0.8984291495802124, 0.5426319701729883, 0.2667341084618861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 283}], {
             RGBColor[
             0.9432427006605664, 0.8062936865407971, 0.3064669136008217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 297}], {
             RGBColor[
             0.9621045612745434, 0.9478624391979251, 0.6712874553374975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 307}], {
             RGBColor[
             0.9814050384421338, 0.9620825967866911, 0.6308199289588313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 352}], {
             RGBColor[
             0.9858621188487648, 0.9629527205499828, 0.4862282141252213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 123}], {
             RGBColor[
             0.9762118677425246, 0.9817794304286422, 0.9251512823600752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 174}], {
             RGBColor[
             0.8533664925541351, 0.885559755956836, 0.9477463395066474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 187}], {
             RGBColor[
             0.9110307205751575, 0.9308010667922535, 0.953442401298972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 193}], {
             RGBColor[
             0.9002336063428361, 0.9221917409832586, 0.9524125629047955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[
             0.9440956875300477, 0.9571661739174645, 0.9565961673645738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 232}], {
             RGBColor[
             0.7518421224806613, 0.804458883314896, 0.9388506680687247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 235}], {
             RGBColor[
             0.8591106393434069, 0.8900471270857477, 0.9483188623764983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 275}], {
             RGBColor[
             0.9851141209349312, 0.987104803716967, 0.8512424005775606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 279}], {
             RGBColor[
             0.9618886205302903, 0.9027170726846294, 0.5985175369470697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 281}], {
             RGBColor[
             0.8050608246814849, 0.8476642232367373, 0.943040239252503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 306}], {
             RGBColor[
             0.9742518584397497, 0.947471002545973, 0.6306628392778444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 338}], {
             RGBColor[
             0.9862079875593082, 0.9866999578573392, 0.7708056942036536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 384}], {
             RGBColor[
             0.863277719993484, 0.893302482160574, 0.9487341980321153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 105}], {
             RGBColor[
             0.3969790975995051, 0.5182650744162607, 0.9465161349575758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 112}], {
             RGBColor[
             0.35276762831000186`, 0.47997132185075075`, 0.9436990192291159]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 141}], {
             RGBColor[
             0.3683390164516885, 0.49345847561835543`, 0.9446912143122663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 168}], {
             RGBColor[
             0.5233822877675662, 0.6214359238763232, 0.9564882451969059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 170}], {
             RGBColor[
             0.4107918604538279, 0.5302289953510277, 0.9473962719925066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 180}], {
             RGBColor[
             0.3714420538172285, 0.49614617062119337`, 0.9448889371092903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 220}], {
             RGBColor[
             0.42602430021250687`, 0.5428220538333498, 0.9485327937322395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 271}], {
             RGBColor[
             0.3417009842764249, 0.4702049097204598, 0.9430004912657755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 273}], {
             RGBColor[
             0.3260257412647034, 0.4537292354473304, 0.9421078093657018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 282}], {
             RGBColor[
             0.5117379294109875, 0.6123392626277626, 0.9553276443786378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 350}], {
             RGBColor[
             0.4046784181179114, 0.524933838870203, 0.9470067288527668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 394}], {
             RGBColor[
             0.3677410184422385, 0.49294051979882375`, 0.944653110407893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 151}], {
             RGBColor[
             0.2883386750076016, 0.41973713317698713`, 0.9397558331587401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 171}], {
             RGBColor[
             0.2670272094470698, 0.3979929060047742, 0.9385181765954305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 182}], {
             RGBColor[
             0.2744680720566198, 0.40581372438534935`, 0.9389419227132746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 244}], {
             RGBColor[
             0.2604390037563816, 0.39106828410749395`, 0.9381429880277227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 253}], {
             RGBColor[
             0.3012788054166666, 0.43094522374745403`, 0.9405803668258977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 270}], {
             RGBColor[
             0.2552144898783262, 0.38557698876834556`, 0.937845459691343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 308}], {
             RGBColor[
             0.26096510566357906`, 0.39162125056874597`, 0.9381729487530396]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 397}], {
             RGBColor[
             0.2550956906132599, 0.3854521232084524, 0.9378386942489454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 160}], {
             RGBColor[
             0.8243873085977117, 0.18845711723458924`, 0.17098662029568146`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 166}], {
             RGBColor[
             0.8220330696681408, 0.1703614051878311, 0.16873219843799186`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[
             0.8214937595564198, 0.16621603134194454`, 0.16821575446594406`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 213}], {
             RGBColor[
             0.8651325745805382, 0.41702815829837886`, 0.20666661364992278`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 224}], {
             RGBColor[
             0.8974792718626248, 0.5394468704448865, 0.26303107700793477`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 230}], {
             RGBColor[
             0.8940771340934058, 0.5279706608893748, 0.24981441421432754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 247}], {
             RGBColor[
             0.8631522875093278, 0.40917697995257735`, 0.2050732281891151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 250}], {
             RGBColor[
             0.9037621261807391, 0.5693653564012491, 0.505440590565607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 289}], {
             RGBColor[
             0.8585251717968794, 0.3889672621761071, 0.20125368090273776`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 302}], {
             RGBColor[
             0.9032870347441282, 0.5590378183717704, 0.2855931390985828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 340}], {
             RGBColor[
             0.9065375818313084, 0.569215708650745, 0.3651390053950433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 370}], {
             RGBColor[
             0.8252568296209774, 0.5087923181187306, 0.5749377733126149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 391}], {
             RGBColor[
             0.8198439128231849, 0.15353458638285297`, 0.16663585937096298`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 400}], {
             RGBColor[
             0.6044539714967849, 0.33060708272811645`, 0.5560794046708185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 108}], {
             RGBColor[
             0.3560676178251626, 0.48282960690648735`, 0.9439092916429558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 133}], {
             RGBColor[
             0.32091218999488846`, 0.4513176188145481, 0.9417081084114585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 143}], {
             RGBColor[
             0.48460520194471113`, 0.589510492500073, 0.9533849292372562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 223}], {
             RGBColor[
             0.3993166746191169, 0.5202694238127852, 0.9466707039440156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 231}], {
             RGBColor[
             0.3266251404157554, 0.4573222919288569, 0.942033452486374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 234}], {
             RGBColor[
             0.34165277525472826`, 0.4703441947830308, 0.9429907906209125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 290}], {
             RGBColor[
             0.3748499370785241, 0.4990979078169345, 0.9451060844172272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 313}], {
             RGBColor[
             0.31368725505562867`, 0.4437237541060531, 0.9412966590550009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 331}], {
             RGBColor[
             0.39832931347278433`, 0.519434563541872, 0.9466021695190721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 342}], {
             RGBColor[
             0.4739621782432806, 0.580870006396498, 0.9525470714247991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 346}], {
             RGBColor[
             0.3447990844282577, 0.4730693696510448, 0.9431912706592778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 109}], {
             RGBColor[
             0.9639852685830836, 0.8836832833010115, 0.5065761886025747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 138}], {
             RGBColor[
             0.8766084818851104, 0.4626116115176483, 0.21590390436629117`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 144}], {
             RGBColor[
             0.9061560966553733, 0.6582187386740248, 0.24296492852905843`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 205}], {
             RGBColor[
             0.9645712998383063, 0.8839256222853624, 0.49686413410326324`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 207}], {
             RGBColor[
             0.9368649528111581, 0.7873976069432023, 0.2680582629430743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 233}], {
             RGBColor[
             0.8756661600168449, 0.4553685127100845, 0.21500153588103987`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 358}], {
             RGBColor[
             0.9512253799690775, 0.8406018507565884, 0.299039239235954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 366}], {
             RGBColor[
             0.9175772665295729, 0.7100796035907695, 0.25249503263058215`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 382}], {
             RGBColor[
             0.9163275048198573, 0.7044047275562138, 0.25145220082553266`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 112}], {
             RGBColor[
             0.37313264037284266`, 0.49761047172431544`, 0.944996659789687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 113}], {
             RGBColor[
             0.6069298774587211, 0.6884337835985022, 0.9640833346207096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 148}], {
             RGBColor[
             0.520616067080279, 0.620721827134755, 0.9556738363326167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 155}], {
             RGBColor[
             0.3609448647521152, 0.4866656792120809, 0.9442342850410239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 168}], {
             RGBColor[
             0.5437472998304071, 0.6390750737498879, 0.957785885757477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 170}], {
             RGBColor[
             0.4311568725166687, 0.5478681452245924, 0.9486939125530778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 180}], {
             RGBColor[
             0.39180706588006936`, 0.513785320494758, 0.9461865776698615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 239}], {
             RGBColor[
             0.37092951443948974`, 0.4957022347731742, 0.9448562785533615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 271}], {
             RGBColor[
             0.36206599633926584`, 0.4878440595940245, 0.9442981318263466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 282}], {
             RGBColor[
             0.5321029414738284, 0.6299784125013272, 0.956625284939209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 326}], {
             RGBColor[
             0.37836717266856673`, 0.5021443605036287, 0.9453301995588554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 350}], {
             RGBColor[
             0.4250434301807523, 0.5425729887437677, 0.948304369413338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 394}], {
             RGBColor[
             0.38810603050507936`, 0.5105796696723884, 0.9459507509684641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.8938562482651202, 0.6317789737296462, 0.5786286100973383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 173}], {
             RGBColor[
             0.5874312139478495, 0.658182594689114, 0.9541358462016971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 197}], {
             RGBColor[
             0.9686231253627324, 0.9753622711647122, 0.9040752003743098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 204}], {
             RGBColor[
             0.563710908416439, 0.6332510496213667, 0.9527850098927306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 214}], {
             RGBColor[
             0.9661339552698273, 0.9742633398075717, 0.9422105594358144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 215}], {
             RGBColor[
             0.8838915069303948, 0.5551856052534505, 0.5690863625416396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 295}], {
             RGBColor[
             0.5954410834145789, 0.6666014753537031, 0.9545919964182874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 310}], {
             RGBColor[
             0.5655364837016175, 0.6351698449942476, 0.952888973704525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 345}], {
             RGBColor[
             0.5752211056493675, 0.6453489967018295, 0.953440498597335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 363}], {
             RGBColor[
             0.905503655257033, 0.714845634359743, 0.589529206598464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 131}], {
             RGBColor[
             0.8808419295941465, 0.5163805585259162, 0.22083043617809295`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 197}], {
             RGBColor[
             0.9139845567949747, 0.6460331456516251, 0.5106347906861869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 215}], {
             RGBColor[
             0.829252938362637, 0.22585647974036333`, 0.17564595285351675`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 297}], {
             RGBColor[
             0.892928350056968, 0.6310869487653001, 0.5801992997291281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 307}], {
             RGBColor[
             0.9122288272245584, 0.6453071063540661, 0.539731773350462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 352}], {
             RGBColor[
             0.9166859076311894, 0.6461772301173578, 0.39514005851685197`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 363}], {
             RGBColor[
             0.8508650866892753, 0.3855165088466559, 0.1960887969103411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 143}], {
             RGBColor[
             0.49610666284564264`, 0.5994724798522266, 0.954117792155521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 179}], {
             RGBColor[
             0.3186061180992342, 0.4467670137493473, 0.9416546527633719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 196}], {
             RGBColor[
             0.332746597404592, 0.4616295540574491, 0.9424599321408476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 231}], {
             RGBColor[
             0.3381266013166869, 0.4672842792810106, 0.9427663154046388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 234}], {
             RGBColor[
             0.3531542361556598, 0.4803061821351844, 0.9437236535391773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 290}], {
             RGBColor[
             0.3863513979794556, 0.5090598951690881, 0.945838947335492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 313}], {
             RGBColor[
             0.3251887159565602, 0.4536857414582067, 0.9420295219732657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 331}], {
             RGBColor[
             0.40983077437371584`, 0.5293965508940257, 0.9473350324373369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 342}], {
             RGBColor[
             0.48546363914421214`, 0.5908319937486516, 0.9532799343430639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 344}], {
             RGBColor[
             0.3440988640451813, 0.47246287394932385`, 0.9431466532356487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 136}], {
             RGBColor[
             0.8063392816861509, 0.8465292984919313, 0.8553084156056971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 205}], {
             RGBColor[
             0.9946824810618875, 0.9920690835121566, 0.737788580309801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 207}], {
             RGBColor[
             0.9669761340347394, 0.8955410681699965, 0.508982709149612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 233}], {
             RGBColor[
             0.9057773412404262, 0.5635119739368787, 0.4559259820875775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 286}], {
             RGBColor[
             0.8601731647723879, 0.8889489686867593, 0.8604250468482817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 320}], {
             RGBColor[
             0.8519952349988198, 0.8825603077930796, 0.8596099472355513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 343}], {
             RGBColor[
             0.8581485111146978, 0.8873672938614341, 0.8602232482931473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 358}], {
             RGBColor[
             0.9813365611926588, 0.9487453119833825, 0.5399636854424916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 366}], {
             RGBColor[
             0.9476884477531541, 0.8182230648175637, 0.4934194788371198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 382}], {
             RGBColor[
             0.9464386860434384, 0.8125481887830079, 0.4923766470320703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 115}], {
             RGBColor[
             0.2470920216969208, 0.3770397597154611, 0.9373828971445268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 134}], {
             RGBColor[
             0.24495240537755758`, 0.37479088730430044`, 0.9372610491604179]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 167}], {
             RGBColor[
             0.26956370563298526`, 0.40065892431931827`, 0.9386626263008084]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 192}], {
             RGBColor[
             0.30003384397733923`, 0.42938021827289985`, 0.940518858812405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 203}], {
             RGBColor[
             0.2734877597794271, 0.40478335402663146`, 0.9388860953793305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 243}], {
             RGBColor[
             0.2719749479938126, 0.4031932929221435, 0.9387999429861442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 348}], {
             RGBColor[
             0.25926658322907375`, 0.3898359957975386, 0.9380762204131332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 351}], {
             RGBColor[
             0.25066121746090764`, 0.3807912107634932, 0.9375861575631339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 369}], {
             RGBColor[
             0.2565159464057226, 0.38694490209574905`, 0.9379195757152459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 160}], {
             RGBColor[
             0.8517778667942718, 0.37434165466445646`, 0.19625056684916897`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 166}], {
             RGBColor[
             0.8494236278647009, 0.35624594261769826`, 0.19399614499147944`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.8488843177529799, 0.35210056877181173`, 0.19347970101943163`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 197}], {
             RGBColor[
             0.931414792844472, 0.7553582824181725, 0.5263607215030722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[
             0.631844529693345, 0.5164916201579837, 0.581343351224306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 155}], {
             RGBColor[
             0.31673339546261187`, 0.44837192664657105`, 0.9414171693125639]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 170}], {
             RGBColor[
             0.3869454032271654, 0.5095743926590826, 0.9458767968246178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 180}], {
             RGBColor[
             0.34759559659056605`, 0.4754915679292482, 0.9433694619414015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 183}], {
             RGBColor[
             0.2939274002864909, 0.42440137973285763`, 0.9401184016257302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 271}], {
             RGBColor[
             0.3178545270497625, 0.4495503070285146, 0.9414810160978866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 273}], {
             RGBColor[
             0.30217928403804095`, 0.4330746327553852, 0.940588334197813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 326}], {
             RGBColor[
             0.3341557033790634, 0.4638506079381187, 0.9425130838303954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 350}], {
             RGBColor[
             0.380831960891249, 0.5042792361782578, 0.945487253684878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 394}], {
             RGBColor[
             0.34389456121557604`, 0.47228591710687856`, 0.9431336352400042]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 148}], {
             RGBColor[
             0.7102018348766541, 0.7732513864434318, 0.9719433954351793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 168}], {
             RGBColor[
             0.7333330676267822, 0.7916046330585647, 0.9740554448600397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 170}], {
             RGBColor[
             0.6207426403130438, 0.7003977045332692, 0.9649634716556403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 251}], {
             RGBColor[
             0.8094157442625041, 0.8510598457172036, 0.9816336535080088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 282}], {
             RGBColor[
             0.7216887092702036, 0.7825079718100041, 0.9728948440417715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 153}], {
             RGBColor[
             0.32315432075329853`, 0.4543217632532496, 0.9418120854576224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 154}], {
             RGBColor[
             0.3795179550306004, 0.5031411103456188, 0.9454035263933673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 188}], {
             RGBColor[
             0.297981899619691, 0.4286669180863, 0.9403491528141107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 203}], {
             RGBColor[
             0.3101377282501396, 0.4414434647009515, 0.9410414092716778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 222}], {
             RGBColor[
             0.4669023906435984, 0.574712579304436, 0.9521089968254883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 258}], {
             RGBColor[
             0.29090557114945215`, 0.42122924819894025`, 0.9399461663762204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 312}], {
             RGBColor[
             0.3959175277947622, 0.5170838698121216, 0.9465208083959076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 327}], {
             RGBColor[
             0.32373500724345117`, 0.4548247247048681, 0.941849086287294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 356}], {
             RGBColor[
             0.4236281428800086, 0.5395805954873082, 0.9487022895227458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 361}], {
             RGBColor[
             0.342252200873233, 0.470863387125772, 0.9430289854912723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 369}], {
             RGBColor[
             0.29316591487643506`, 0.4236050127700691, 0.9400748896075932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 392}], {
             RGBColor[
             0.2884135464934976, 0.418609972282043, 0.9398042492586839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 184}], {
             RGBColor[
             0.22818450918176583`, 0.35716676525650004`, 0.936306142277947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 188}], {
             RGBColor[
             0.25284600900533644`, 0.38308756520047255`, 0.9377105782094798]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 195}], {
             RGBColor[
             0.2421504028292495, 0.3718458049688061, 0.937101479260483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 203}], {
             RGBColor[
             0.265001837635785, 0.3958641118151241, 0.9384028346670469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 206}], {
             RGBColor[
             0.23508408472910247`, 0.364418656615107, 0.9366990628983605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 208}], {
             RGBColor[
             0.2358464087925902, 0.36521990753996986`, 0.9367424761260187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 258}], {
             RGBColor[
             0.24576968053509757`, 0.37564989531311277`, 0.9373075917715895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 284}], {
             RGBColor[
             0.24130209476909242`, 0.37095417941174347`, 0.9370531693714164]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 325}], {
             RGBColor[
             0.22508690864981107`, 0.3539109906981984, 0.9361297385101415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 369}], {
             RGBColor[
             0.24803002426208054`, 0.37802565988424164`, 0.9374363150029623]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 392}], {
             RGBColor[
             0.24327765587914302`, 0.37303061939621557`, 0.937165674654053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 121}], {
             RGBColor[
             0.48470874113100904`, 0.5915401565241579, 0.9528555034179461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 130}], {
             RGBColor[
             0.4133134657138138, 0.5324130830876621, 0.947556946449905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 135}], {
             RGBColor[
             0.4597496952635722, 0.5712772786967698, 0.9508906358992639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 147}], {
             RGBColor[
             0.35047958711339033`, 0.47576981650030403`, 0.9436345020558807]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 172}], {
             RGBColor[
             0.3588230012593764, 0.484539273770746, 0.9441096471485195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 265}], {
             RGBColor[
             0.5040580192630065, 0.6072487721867599, 0.9543787494712381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 276}], {
             RGBColor[
             0.5908937430052579, 0.6758585483037947, 0.9625051852330178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 322}], {
             RGBColor[
             0.46231873384021377`, 0.5733629399471565, 0.9510928800267155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 328}], {
             RGBColor[
             0.3628292631493686, 0.48868620423613895`, 0.944340137703926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 362}], {
             RGBColor[
             0.41044018393094006`, 0.5299243908226783, 0.9473738634754435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 364}], {
             RGBColor[
             0.382875553578809, 0.5060492934502673, 0.9456174696038513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 387}], {
             RGBColor[
             0.35489504602512995`, 0.4804107437728069, 0.9438859559088182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 223}], {
             RGBColor[
             0.40179215387534173`, 0.5224135595233219, 0.9468284392932418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 346}], {
             RGBColor[
             0.3472745636844825, 0.4752135053615816, 0.9433490060085041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 371}], {
             RGBColor[
             0.31078136056287864`, 0.44021172480761495`, 0.9411479331302521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 126}], {
             RGBColor[
             0.20905168496127685`, 0.33705695390964574`, 0.935216556243067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 149}], {
             RGBColor[
             0.21314012851733694`, 0.34135416730935836`, 0.9354493870552745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[
             0.21593219336709382`, 0.3442888044935889, 0.9356083910179783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 212}], {
             RGBColor[
             0.208479398474888, 0.33645544452739207`, 0.9351839653742893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 259}], {
             RGBColor[
             0.20854115618205327`, 0.33652035579328765`, 0.9351874823843499]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 293}], {
             RGBColor[
             0.20864634306607288`, 0.33663091387762584`, 0.9351934726217848]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 299}], {
             RGBColor[
             0.21009516231391617`, 0.33815371476755507`, 0.9352759807346135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 336}], {
             RGBColor[
             0.20853409149877072`, 0.3365129303632308, 0.9351870800610882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 367}], {
             RGBColor[
             0.21268815866311674`, 0.340879118336029, 0.9354236480407061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 200}], {
             RGBColor[
             0.2555790109882331, 0.38596012356683096`, 0.9378662186292916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 225}], {
             RGBColor[
             0.24880323623162193`, 0.37883835468870003`, 0.9374803482807631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 288}], {
             RGBColor[
             0.2427621793276949, 0.37248882085754254`, 0.9371363190270272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 296}], {
             RGBColor[
             0.27100995406971695`, 0.4021790231237703, 0.9387449880097476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 316}], {
             RGBColor[
             0.24738893708713797`, 0.3773518366161024, 0.9373998060367528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 324}], {
             RGBColor[
             0.26022801088632164`, 0.3908465172233403, 0.9381309722959088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 355}], {
             RGBColor[
             0.2357097669248304, 0.3650762882733595, 0.9367346945737933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 375}], {
             RGBColor[
             0.24767185396681415`, 0.37764920019460835`, 0.9374159177345123]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 380}], {
             RGBColor[
             0.25299451614994406`, 0.383243655625352, 0.9377190354716685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 383}], {
             RGBColor[
             0.2603673467577916, 0.3909929680586598, 0.93813890726766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 390}], {
             RGBColor[
             0.2533988208527428, 0.3836686055023921, 0.9377420600263777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 136}], {
             RGBColor[
             0.5924802140391232, 0.6800411545432594, 0.9610613592571464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 237}], {
             RGBColor[
             0.5723986729827764, 0.663738054850602, 0.9594804667840822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 246}], {
             RGBColor[
             0.505090585435528, 0.6088359587265868, 0.9542531127865411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 254}], {
             RGBColor[
             0.5179448523327678, 0.6195299901302602, 0.955193662551596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 286}], {
             RGBColor[
             0.6463140971253603, 0.7224608247380875, 0.966177990499731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 320}], {
             RGBColor[
             0.6381361673517921, 0.7160721638444079, 0.9653628908870006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 343}], {
             RGBColor[
             0.64428944346767, 0.7208791499127623, 0.9659761919445966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 349}], {
             RGBColor[
             0.5058787275831391, 0.6095186078416714, 0.9543033325072602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 130}], {
             RGBColor[
             0.48180086572832803`, 0.5890215010044231, 0.9526702161686205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 158}], {
             RGBColor[
             0.5281560210081759, 0.6278198768688632, 0.9559975231544674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 181}], {
             RGBColor[
             0.5602542166801026, 0.6538786381225696, 0.9585244106973264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 250}], {
             RGBColor[
             0.7707116790518824, 0.8187741201767487, 0.9013688926659322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 265}], {
             RGBColor[
             0.5725454192775208, 0.6638571901035208, 0.9594920191899539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 322}], {
             RGBColor[
             0.5308061338547281, 0.6299713578639174, 0.9562061497454312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 362}], {
             RGBColor[
             0.4789275839454543, 0.5865328087394392, 0.9524871331941591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 146}], {
             RGBColor[
             0.49070941162852855`, 0.5972227097318854, 0.9531038334374095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.3887610902465449, 0.5111470494961861, 0.9459924907959437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 165}], {
             RGBColor[
             0.48941818004964077`, 0.5961744297668246, 0.9530021829575823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 210}], {
             RGBColor[
             0.3730056479605837, 0.4966847962832106, 0.9450184340224643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 228}], {
             RGBColor[
             0.40697238168033323`, 0.5269207548100117, 0.9471528981824919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 262}], {
             RGBColor[
             0.6923652232093209, 0.7572804525421046, 0.9691955483013721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 298}], {
             RGBColor[
             0.634758859433705, 0.711422615804957, 0.9663329898214426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 314}], {
             RGBColor[
             0.6859497834912932, 0.7522408691078613, 0.9712156258567326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 385}], {
             RGBColor[
             0.510754315643456, 0.6134960658238386, 0.9546818417083673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 174}], {
             RGBColor[
             0.8514507591880022, 0.8841310051490996, 0.9509891763922267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 187}], {
             RGBColor[
             0.9091149872090246, 0.929372315984517, 0.9566852381845512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 193}], {
             RGBColor[
             0.8983178729767032, 0.9207629901755221, 0.9556553997903747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 218}], {
             RGBColor[
             0.9421799541639146, 0.955737423109728, 0.959839004250153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 232}], {
             RGBColor[
             0.7499263891145284, 0.8030301325071595, 0.9420935049543039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 235}], {
             RGBColor[
             0.8571949059772741, 0.8886183762780113, 0.9515616992620775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 275}], {
             RGBColor[
             0.9831983875687983, 0.9856760529092304, 0.8544852374631398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 279}], {
             RGBColor[
             0.9599728871641575, 0.901288321876893, 0.6017603738326488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 281}], {
             RGBColor[
             0.8031450913153519, 0.8462354724290008, 0.9462830761380823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 306}], {
             RGBColor[
             0.9723361250736168, 0.9460422517382365, 0.6339056761634236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 338}], {
             RGBColor[
             0.9842922541931751, 0.9852712070496027, 0.7740485310892328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.22241368079166546`, 0.3511012587268517, 0.9359775021383063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 199}], {
             RGBColor[
             0.224537016117427, 0.35333301878146245`, 0.9360984229439153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 238}], {
             RGBColor[
             0.22624718755874168`, 0.35513051739741625`, 0.9361958146775262]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 252}], {
             RGBColor[
             0.22380219645594157`, 0.3525606767269839, 0.936056576051262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 277}], {
             RGBColor[
             0.24054204876353127`, 0.3701553228701986, 0.9370098858757869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 293}], {
             RGBColor[
             0.21725116581640602`, 0.3456751281654994, 0.9356835045477219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 330}], {
             RGBColor[
             0.22402160898279397`, 0.3527912932042634, 0.9360690712700745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 179}], {
             RGBColor[
             0.2738145581196516, 0.4051268398024189, 0.9389047060613515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 196}], {
             RGBColor[
             0.2879550374250095, 0.4199893801105207, 0.9397099854388271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 303}], {
             RGBColor[
             0.28379884955745593`, 0.41562096314419106`, 0.9394732966882988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 313}], {
             RGBColor[
             0.2803971559769777, 0.4120455675112783, 0.9392795752712453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 344}], {
             RGBColor[
             0.2993073040655987, 0.4308227000023955, 0.9403967065336283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 149}], {
             RGBColor[
             0.21613019133913786`, 0.3444969129160037, 0.9356196667095744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 199}], {
             RGBColor[
             0.21892225618889471`, 0.3474315501002342, 0.9357786706722784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 212}], {
             RGBColor[
             0.21146946129668887`, 0.3395981901340374, 0.9353542450285892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 238}], {
             RGBColor[
             0.2206324276302094, 0.349229048716188, 0.9358760624058893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 259}], {
             RGBColor[
             0.2115312190038542, 0.33966310139993294`, 0.93535776203865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 274}], {
             RGBColor[
             0.22138486041548355`, 0.35001990328050514`, 0.9359189123398861]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 299}], {
             RGBColor[
             0.21308522513571704`, 0.34129646037420036`, 0.9354462603889135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 318}], {
             RGBColor[
             0.2179296081019373, 0.3463882140233181, 0.9357221408322174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 336}], {
             RGBColor[
             0.21152415432057162`, 0.33965567596987617`, 0.9353573597153882]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 367}], {
             RGBColor[
             0.21567822148491766`, 0.34402186394267437`, 0.935593927695006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 139}], {
             RGBColor[
             0.2108331954164144, 0.3389294343522821, 0.9353180106279786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 184}], {
             RGBColor[
             0.21412931839643223`, 0.34239386859054827`, 0.9355057199555137]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 305}], {
             RGBColor[
             0.20669916269368893`, 0.33458430384788407`, 0.9350825835801727]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 325}], {
             RGBColor[
             0.21103171786447747`, 0.3391380940322466, 0.9353293161877081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 177}], {
             RGBColor[
             0.32406082685861914`, 0.45510693327935664`, 0.9418698472250615]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 225}], {
             RGBColor[
             0.2916606290262991, 0.42226923419395845`, 0.939980144908767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 296}], {
             RGBColor[
             0.3138673468643941, 0.4456099026290287, 0.9412447846377514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 311}], {
             RGBColor[
             0.4227935959175786, 0.5388307190597109, 0.9486565824461703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 316}], {
             RGBColor[
             0.29024632988181515`, 0.4207827161213608, 0.9398996026647567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 324}], {
             RGBColor[
             0.3030854036809988, 0.43427739672859866`, 0.9406307689239126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 380}], {
             RGBColor[
             0.2958519089446212, 0.4266745351306104, 0.9402188320996724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 383}], {
             RGBColor[
             0.30322473955246876`, 0.43442384756391816`, 0.9406387038956638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 390}], {
             RGBColor[
             0.29625621364741994`, 0.42709948500765055`, 0.9402418566543815]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 178}], {
             RGBColor[
             0.24083645723076108`, 0.3704647648358321, 0.9370266520024574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 229}], {
             RGBColor[
             0.24229031603850887`, 0.3719928626227475, 0.9371094471107673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 249}], {
             RGBColor[
             0.25362687609654, 0.3839083060231606, 0.9377550474351345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 270}], {
             RGBColor[
             0.24363580909960866`, 0.3734070611391507, 0.9371860709501183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 308}], {
             RGBColor[
             0.2493864248848615, 0.3794513229395511, 0.9375135600118147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 309}], {
             RGBColor[
             0.25423745991444247`, 0.38455006832902616`, 0.9377898192802863]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 397}], {
             RGBColor[
             0.24351700983454236`, 0.3732821955792575, 0.9371793055077206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 135}], {
             RGBColor[
             0.4568418198608912, 0.568758623177035, 0.9507053486499384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 147}], {
             RGBColor[
             0.34757171171070933`, 0.4732511609805692, 0.9434492148065551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 158}], {
             RGBColor[
             0.4567607455909806, 0.5686928034323673, 0.9506989661864262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 172}], {
             RGBColor[
             0.3559151258566954, 0.4820206182510111, 0.9439243598991939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 181}], {
             RGBColor[
             0.48885894126290724`, 0.5947515646860737, 0.9532258537292853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 265}], {
             RGBColor[
             0.5011501438603255, 0.6047301166670249, 0.9541934622219126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 322}], {
             RGBColor[
             0.45941085843753277`, 0.5708442844274215, 0.95090759277739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 328}], {
             RGBColor[
             0.3599213877466876, 0.48616754871640405`, 0.9441548504546003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 347}], {
             RGBColor[
             0.34522783768479254`, 0.47078760076913406`, 0.9433157346482299]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 362}], {
             RGBColor[
             0.40753230852825906`, 0.5274057353029433, 0.9471885762261179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 364}], {
             RGBColor[
             0.379967678176128, 0.5035306379305324, 0.9454321823545258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 387}], {
             RGBColor[
             0.35198717062244894`, 0.47789208825307206`, 0.9437006686594926]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 215}], {
             RGBColor[
             0.8708771882594211, 0.43978719004972067`, 0.21128818862239418`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 217}], {
             RGBColor[
             0.8726459244985081, 0.4533824718485052, 0.21298193244244573`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 262}], {
             RGBColor[
             0.9305545199558635, 0.8420358975584873, 0.6226092420681639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 269}], {
             RGBColor[
             0.9577625542405059, 0.8589366723660075, 0.3711790558606476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 279}], {
             RGBColor[
             0.934057909721427, 0.776268616484077, 0.26579965018330676`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 297}], {
             RGBColor[
             0.9345525999537521, 0.8450176590746574, 0.6158415354980056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 300}], {
             RGBColor[
             0.9062314787117222, 0.661847076989811, 0.24319781291959908`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 306}], {
             RGBColor[
             0.9464211476308863, 0.8210225463454206, 0.2979449525140816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 307}], {
             RGBColor[
             0.9538530771213425, 0.8592378166634234, 0.5753740091193393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 314}], {
             RGBColor[
             0.9241390802378358, 0.8369963141242439, 0.6246293196235244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 352}], {
             RGBColor[
             0.9583101575279735, 0.8601079404267151, 0.43078229428572945`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 363}], {
             RGBColor[
             0.8924893365860593, 0.5994472191560132, 0.23173103267921852`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 140}], {
             RGBColor[
             0.7355736784173503, 0.7933550152374292, 0.9742787680039452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 191}], {
             RGBColor[
             0.7390378619070974, 0.7960612617083893, 0.9746240454395679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 198}], {
             RGBColor[
             0.8128559952710535, 0.8537811311091374, 0.9819675933041132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 216}], {
             RGBColor[
             0.7291619678468395, 0.7883461382089411, 0.9736397086151186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 219}], {
             RGBColor[
             0.6232051027562657, 0.7024156086050097, 0.9651690328906872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 220}], {
             RGBColor[
             0.6373284381573086, 0.7140480166379533, 0.9662348834814941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 302}], {
             RGBColor[
             0.8932496977556434, 0.905911220002762, 0.6928483915783341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 323}], {
             RGBColor[
             0.8147163030891271, 0.8552644900665589, 0.9821450311245175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 357}], {
             RGBColor[
             0.7374562321167385, 0.7948256804953293, 0.9744664033632358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 145}], {
             RGBColor[
             0.26764114093786784`, 0.3986381869271076, 0.9385531390856012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 164}], {
             RGBColor[
             0.2698983654154672, 0.40101067296936244`, 0.9386816846803361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 223}], {
             RGBColor[
             0.3756627076897743, 0.49871942307299955`, 0.945202383630783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 234}], {
             RGBColor[
             0.31799880832538563`, 0.4487941940432452, 0.9415224703076799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 280}], {
             RGBColor[
             0.26813571605602704`, 0.3991580167341666, 0.938581304406922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 346}], {
             RGBColor[
             0.32114511749891506`, 0.4515193689112592, 0.9417229503460453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 167}], {
             RGBColor[
             0.25893816716997997`, 0.3894908096966502, 0.9380575176044159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 201}], {
             RGBColor[
             0.255376576823433, 0.3857473524245587, 0.9378546903030808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 236}], {
             RGBColor[
             0.24242453355158805`, 0.3721339337388756, 0.9371170905995801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 243}], {
             RGBColor[
             0.2613494095308073, 0.3920251782994754, 0.9381948342897516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 263}], {
             RGBColor[
             0.24820523859568883`, 0.3782098212580943, 0.9374462932000549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 348}], {
             RGBColor[
             0.24864104476606846`, 0.3786678811748705, 0.9374711117167406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 351}], {
             RGBColor[
             0.24003567899790235`, 0.3696230961408251, 0.9369810488667414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 221}], {
             RGBColor[
             0.7125684826637311, 0.7740760557086418, 0.9732239792621271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 276}], {
             RGBColor[
             0.6344220971523353, 0.7122040883931675, 0.9656535874330512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 322}], {
             RGBColor[
             0.5058470879872912, 0.6097084800365293, 0.954241282226749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 364}], {
             RGBColor[
             0.42640390772588643`, 0.5423948335396401, 0.9487658718038847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 376}], {
             RGBColor[
             0.47083567399736015`, 0.5808793962784845, 0.9515970246612349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 377}], {
             RGBColor[
             0.4590787183907463, 0.5706961122538062, 0.9508478818462491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 194}], {
             RGBColor[
             0.5033185862068833, 0.6058836865205527, 0.954531849750919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 237}], {
             RGBColor[
             0.59850057250929, 0.6849287527633994, 0.9615353039292178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 246}], {
             RGBColor[
             0.5311924849620417, 0.6300266566393842, 0.9563079499316767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 254}], {
             RGBColor[
             0.5440467518592814, 0.6407206880430576, 0.9572484996967315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 286}], {
             RGBColor[
             0.6724159966518739, 0.7436515226508849, 0.9682328276448666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 320}], {
             RGBColor[
             0.6642380668783059, 0.7372628617572051, 0.9674177280321361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 343}], {
             RGBColor[
             0.6703913429941837, 0.7420698478255596, 0.9680310290897323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 349}], {
             RGBColor[
             0.5319806271096528, 0.6307093057544687, 0.9563581696523957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 376}], {
             RGBColor[
             0.5284877060748537, 0.6276839131134415, 0.9561356038127271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 199}], {
             RGBColor[
             0.22367942926895015`, 0.3524316406295666, 0.9360495846415806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 238}], {
             RGBColor[
             0.22538960071026484`, 0.3542291392455204, 0.9361469763751915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 252}], {
             RGBColor[
             0.22294460960746476`, 0.35165929857508804`, 0.9360077377489273]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 277}], {
             RGBColor[
             0.23968446191505444`, 0.36925394471830275`, 0.9369610475734522]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 285}], {
             RGBColor[
             0.23013560035880143`, 0.35921748578989005`, 0.9364172540340985]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 293}], {
             RGBColor[
             0.2163935789679292, 0.34477375001360355`, 0.9356346662453872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 330}], {
             RGBColor[
             0.22316402213431713`, 0.35188991505236755`, 0.9360202329677398]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 144}], {
             RGBColor[
             0.8488904911809813, 0.34529052811745564`, 0.1932170904993126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 233}], {
             RGBColor[
             0.8184005545424529, 0.14244030215351539`, 0.165253697851294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 242}], {
             RGBColor[
             0.8688448581678534, 0.4318314305529642, 0.2096571104877158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 256}], {
             RGBColor[
             0.522325620948562, 0.25191357841785655`, 0.5511492082429574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 257}], {
             RGBColor[
             0.8209750230584517, 0.16222879530677942`, 0.1677190118096608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 317}], {
             RGBColor[
             0.9049849697863369, 0.5700377324760639, 0.4855767081666582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 366}], {
             RGBColor[
             0.8603116610551809, 0.39715139303420033`, 0.20274719460083632`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 381}], {
             RGBColor[
             0.9062449527279615, 0.5705587678025101, 0.4646955300926113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 382}], {
             RGBColor[
             0.8590618993454652, 0.3914765169996446, 0.2017043627957868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 184}], {
             RGBColor[
             0.21446679583023515`, 0.34274857877078024`, 0.9355249387961155]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 305}], {
             RGBColor[
             0.20703664012749182`, 0.3349390140281161, 0.9351018024207747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 325}], {
             RGBColor[
             0.21136919529828035`, 0.33949280421247857`, 0.9353485350283102]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 141}], {
             RGBColor[
             0.5159944713875729, 0.6149616035084853, 0.9560493981699523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 168}], {
             RGBColor[
             0.6710377427034506, 0.7429390517664531, 0.9678464290545918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 191}], {
             RGBColor[
             0.6753891788981803, 0.7463384267939157, 0.9682801395479993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 216}], {
             RGBColor[
             0.6655132848379224, 0.7386233032944675, 0.96729580272355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 219}], {
             RGBColor[
             0.5595564197473485, 0.6526927736905361, 0.9588251269991186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 220}], {
             RGBColor[
             0.5736797551483913, 0.6643251817234797, 0.9598909775899255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 350}], {
             RGBColor[
             0.5523338730537959, 0.6464369667603329, 0.9583649127104528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 357}], {
             RGBColor[
             0.6738075491078213, 0.7451028455808557, 0.9681224974716671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 150}], {
             RGBColor[
             0.3153323622893313, 0.4440199894984804, 0.9414428101102743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 189}], {
             RGBColor[
             0.33030534537683665`, 0.4597575440654077, 0.9422954993465642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 219}], {
             RGBColor[
             0.4036258957264883, 0.5240221968760659, 0.9469396630566943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 220}], {
             RGBColor[
             0.4177492311275311, 0.5356546049090093, 0.9480055136475012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 273}], {
             RGBColor[
             0.31775067217972763`, 0.44656178652298995`, 0.9415805292809634]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 339}], {
             RGBColor[
             0.36291222472736206`, 0.48875806138522676`, 0.9443454239423157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 350}], {
             RGBColor[
             0.3964033490329356, 0.5177663899458625, 0.9464794487680284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 357}], {
             RGBColor[
             0.5178770250869611, 0.6164322687663853, 0.9562370335292427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 394}], {
             RGBColor[
             0.3594659493572627, 0.4857730708744833, 0.9441258303231546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 202}], {
             RGBColor[
             0.8389617996732674, 0.300483042224024, 0.18494316940916705`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 214}], {
             RGBColor[
             0.9026785336009098, 0.577164017789306, 0.5403271212608096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 217}], {
             RGBColor[
             0.8222048215005642, 0.17168156503396934`, 0.16889666818668636`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 257}], {
             RGBColor[
             0.822095571600614, 0.17084182242934073`, 0.16879205035911396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 268}], {
             RGBColor[
             0.8194514867475214, 0.1505182276031009, 0.16626007171772583`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 275}], {
             RGBColor[
             0.906842307128124, 0.5789554407018784, 0.47443924955803846`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 279}], {
             RGBColor[
             0.8836168067234831, 0.49456770966954106`, 0.2217143859275474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 300}], {
             RGBColor[
             0.8557903757137784, 0.38014617017527513`, 0.1991125486638397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 306}], {
             RGBColor[
             0.8959800446329425, 0.5393216395308846, 0.25385968825832217`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 338}], {
             RGBColor[
             0.9079361737525008, 0.5785505948422507, 0.3940025431841314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 363}], {
             RGBColor[
             0.8420482335881154, 0.3177463123414773, 0.18764576842345915`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 381}], {
             RGBColor[
             0.9073655012701238, 0.5791717949250715, 0.46576856864206445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 223}], {
             RGBColor[
             0.5393557196395969, 0.6369122967585245, 0.9568792044565808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 234}], {
             RGBColor[
             0.4816918202752083, 0.5869870677287701, 0.9531992911334777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 260}], {
             RGBColor[
             0.7167991404658595, 0.7784168360748085, 0.9725930329082488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 267}], {
             RGBColor[
             0.5979215961089128, 0.6844587136389835, 0.9614897247861196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 272}], {
             RGBColor[
             0.635830587523557, 0.7151635871324875, 0.9645228442451073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 290}], {
             RGBColor[
             0.5148889820990041, 0.6157407807626738, 0.9553145849297924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 291}], {
             RGBColor[
             0.6605679134983766, 0.7344885741946573, 0.9669884297148228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 321}], {
             RGBColor[
             0.7212153553030598, 0.7818668166701053, 0.973033199931347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 331}], {
             RGBColor[
             0.5383683584932644, 0.6360774364876114, 0.9568106700316372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 342}], {
             RGBColor[
             0.6140012232637606, 0.6975128793422373, 0.9627555719373643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 398}], {
             RGBColor[
             0.7820348247548993, 0.8302487551810782, 0.97550730112162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 207}], {
             RGBColor[
             0.9091469621070289, 0.6700765235430096, 0.2453714490760957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 233}], {
             RGBColor[
             0.8479481693127158, 0.33804742930989184`, 0.1923147220140613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 242}], {
             RGBColor[
             0.8983924729381163, 0.6274385577093406, 0.23671813465048305`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 317}], {
             RGBColor[
             0.9345325845565998, 0.7656448596324403, 0.5126377323294256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 358}], {
             RGBColor[
             0.9235073892649484, 0.7232807673563957, 0.2763524253689754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 366}], {
             RGBColor[
             0.8898592758254438, 0.5927585201905767, 0.22980821876360358`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 370}], {
             RGBColor[
             0.8548273648949809, 0.7045756223106869, 0.6020207461756493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 391}], {
             RGBColor[
             0.8494144480971886, 0.3493178905748092, 0.19371883223399736`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 162}], {
             RGBColor[
             0.2420540274215789, 0.3717445083047905, 0.9370959908235907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 164}], {
             RGBColor[
             0.2402812832877892, 0.36988124182170756`, 0.9369950356677115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 227}], {
             RGBColor[
             0.23647303514531387`, 0.36587853156708794`, 0.9367781615697957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 280}], {
             RGBColor[
             0.23851863392834902`, 0.36802858558651175`, 0.9368946553942974]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 359}], {
             RGBColor[
             0.24179608967805666`, 0.37147339938215107`, 0.9370813016506819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 154}], {
             RGBColor[
             0.48274463326921224`, 0.5903240190384458, 0.9525963248033308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 159}], {
             RGBColor[
             0.433382915877228, 0.5475693804255631, 0.9494510398199664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 165}], {
             RGBColor[
             0.5340400056803238, 0.6325967606962016, 0.956460731981605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 192}], {
             RGBColor[
             0.43991049068666355`, 0.5532232376400468, 0.9498669711147159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 228}], {
             RGBColor[
             0.45159420731101624`, 0.5633430857393887, 0.9506114472065146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 262}], {
             RGBColor[
             0.736987048840004, 0.7937027834714817, 0.9726540973253948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 297}], {
             RGBColor[
             0.7409851288378926, 0.7966845449876518, 0.9658863907552364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 307}], {
             RGBColor[
             0.760285606005483, 0.8109047025764178, 0.9254188643765703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 314}], {
             RGBColor[
             0.7305716091219763, 0.7886632000372383, 0.9746741748807553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 332}], {
             RGBColor[
             0.53127642233297, 0.6303531592368088, 0.9562431725771618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 385}], {
             RGBColor[
             0.5553761412741389, 0.6499183967532158, 0.95814039073239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 172}], {
             RGBColor[
             0.29308124725627194`, 0.4253773516636531, 0.9400019155051696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 211}], {
             RGBColor[
             0.2737075152920192, 0.40501433100367, 0.9388986101306735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 328}], {
             RGBColor[
             0.29708750914626414`, 0.42952428212904603`, 0.9402324060605761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 347}], {
             RGBColor[
             0.28239395908436904`, 0.4141443341817761, 0.9393932902542057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 364}], {
             RGBColor[
             0.31713379957570453`, 0.44688737134317436`, 0.9415097379605015]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 372}], {
             RGBColor[
             0.2681076692483716, 0.3991285377610505, 0.9385797071827175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 387}], {
             RGBColor[
             0.28915329202202544`, 0.42124882166571403`, 0.9397782242654684]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 161}], {
             RGBColor[
             0.5276623353729026, 0.6268249505740837, 0.9561228183174523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 168}], {
             RGBColor[
             0.6470192572483401, 0.7238926765948177, 0.9656459465719469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 170}], {
             RGBColor[
             0.5344288299346016, 0.632685748069522, 0.9565539733675475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 251}], {
             RGBColor[
             0.723101933884062, 0.7833478892534567, 0.9732241552199159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.6353748988917614, 0.714796015346257, 0.9644853457536787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 312}], {
             RGBColor[
             0.5434225996528742, 0.6402139731641597, 0.9571993641486982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 326}], {
             RGBColor[
             0.4816391300864997, 0.5869619633485583, 0.9531902603733251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 356}], {
             RGBColor[
             0.5711332147381206, 0.6627106988393463, 0.9593808452755366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 199}], {
             RGBColor[
             0.2230106997449548, 0.3517287634999468, 0.9360115014844858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 212}], {
             RGBColor[
             0.21555790485274898`, 0.34389540353375003`, 0.9355870758407967]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 238}], {
             RGBColor[
             0.2247208711862695, 0.3535262621159006, 0.9361088932180968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 259}], {
             RGBColor[
             0.21561966255991427`, 0.3439603147996455, 0.9355905928508573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 274}], {
             RGBColor[
             0.22547330397154366`, 0.35431711668021776`, 0.9361517431520935]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 287}], {
             RGBColor[
             0.24021601426247097`, 0.36981263993780294`, 0.9369913186932763]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 299}], {
             RGBColor[
             0.21717366869177715`, 0.345593673773913, 0.9356790912011209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 318}], {
             RGBColor[
             0.22201805165799737`, 0.3506854274230307, 0.9359549716444248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 336}], {
             RGBColor[
             0.21561259787663173`, 0.3439528893695888, 0.9355901905275956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 367}], {
             RGBColor[
             0.21976666504097775`, 0.348319077342387, 0.9358267585072135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 186}], {
             RGBColor[
             0.2595342246109202, 0.3901173038593028, 0.9380914621938894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 189}], {
             RGBColor[
             0.28557376029945525`, 0.4174865068698732, 0.9395743752293106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 226}], {
             RGBColor[
             0.2546174021107136, 0.38494941166703367`, 0.9378114564262897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 241}], {
             RGBColor[
             0.2807813627744614, 0.41244939321555174`, 0.939301455279979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 255}], {
             RGBColor[
             0.26553787758684655`, 0.39642752379058566`, 0.9384333613492598]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 266}], {
             RGBColor[
             0.2627993543398047, 0.39354916222554226`, 0.9382774065016228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 365}], {
             RGBColor[
             0.26342074735738313`, 0.39420228568561005`, 0.9383127939147053]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 374}], {
             RGBColor[
             0.2733522518909328, 0.4046409266441276, 0.9388783784055468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 399}], {
             RGBColor[
             0.2527398969113101, 0.3829760346617555, 0.9377045352827038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 171}], {
             RGBColor[
             0.294524052203641, 0.4262383567855898, 0.940108081239609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 182}], {
             RGBColor[
             0.301964914813191, 0.43405917516616493`, 0.9405318273574531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 244}], {
             RGBColor[
             0.28793584651295273`, 0.41931373488830953`, 0.9397328926719012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 249}], {
             RGBColor[
             0.2927023996318287, 0.42432368443317114`, 0.9400043408205379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 253}], {
             RGBColor[
             0.3287756481732377, 0.4591906745282696, 0.9421702714700763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 270}], {
             RGBColor[
             0.28271133263489734`, 0.4138224395491612, 0.9394353643355215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 308}], {
             RGBColor[
             0.28846194842015016`, 0.41986670134956156`, 0.9397628533972181]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 386}], {
             RGBColor[
             0.3275993292124569, 0.45817180616795133`, 0.9420953174660733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 397}], {
             RGBColor[
             0.28259253336983103`, 0.413697573989268, 0.9394285988931239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 156}], {
             RGBColor[
             0.18478785261667285`, 0.31155412769964164`, 0.9338347668861651]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 175}], {
             RGBColor[
             0.181274153781999, 0.307861007443026, 0.9336346669355821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 242}], {
             RGBColor[
             0.5509815030039178, 0.5121510355041116, 0.5934630978551525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 256}], {
             RGBColor[
             0.2044622657846265, 0.33223318336900387`, 0.9349551956103941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 261}], {
             RGBColor[
             0.18153226782756765`, 0.3081323016702944, 0.9336493661486316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 264}], {
             RGBColor[
             0.186823590274237, 0.31369381705096394`, 0.9339506991341594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 317}], {
             RGBColor[
             0.5871216146224013, 0.6503573374272111, 0.8693826955340949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 333}], {
             RGBColor[
             0.18958831081692415`, 0.31659971363473505`, 0.9341081458790279]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 381}], {
             RGBColor[
             0.588381597564026, 0.6508783727536576, 0.8485015174600479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 154}], {
             RGBColor[
             0.3737943950019111, 0.49818365032325973`, 0.9450388262094847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 188}], {
             RGBColor[
             0.2922583395910017, 0.4237094580639409, 0.939984452630228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 195}], {
             RGBColor[
             0.2815627334149148, 0.41246769783227444`, 0.9393753536812313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 203}], {
             RGBColor[
             0.3044141682214503, 0.43648600467859244`, 0.9406767090877951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 258}], {
             RGBColor[
             0.28518201112076286`, 0.41627178817658117`, 0.9395814661923377]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 278}], {
             RGBColor[
             0.284923192180341, 0.41599975306012926`, 0.939566726836569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 284}], {
             RGBColor[
             0.2807144253547577, 0.4115760722752118, 0.9393270437921646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 312}], {
             RGBColor[
             0.39019396776607296`, 0.5121264097897626, 0.9461561082120249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 327}], {
             RGBColor[
             0.31801144721476193`, 0.44986726468250904`, 0.9414843861034113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 337}], {
             RGBColor[
             0.30108704647180895`, 0.43298898876801645`, 0.9404872344261885]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[
             0.4179045828513193, 0.5346231354649491, 0.9483375893388631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 361}], {
             RGBColor[
             0.3365286408445437, 0.46590592710341294`, 0.9426642853073897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 369}], {
             RGBColor[
             0.28744235484774583`, 0.41864755274771004`, 0.9397101894237105]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 392}], {
             RGBColor[
             0.28268998646480836`, 0.4136525122596839, 0.9394395490748012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 192}], {
             RGBColor[
             0.3873238866966642, 0.5099022160172301, 0.9459009134566145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[
             0.36077780249875213`, 0.4853053517709617, 0.9442681500235399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 222}], {
             RGBColor[
             0.5175424648922109, 0.6185744663744461, 0.9553357375773506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 228}], {
             RGBColor[
             0.39900760332101687`, 0.520022064116572, 0.9466453895484133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 312}], {
             RGBColor[
             0.4465576020433747, 0.5609457568821319, 0.9497475491477698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 332}], {
             RGBColor[
             0.47868981834297064`, 0.5870321376139921, 0.9522771149190605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 356}], {
             RGBColor[
             0.4742682171286211, 0.5834424825573183, 0.951929030274608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 361}], {
             RGBColor[
             0.39289227512184555`, 0.5147252741957822, 0.9462557262431346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 385}], {
             RGBColor[
             0.5027895372841396, 0.606597375130399, 0.9541743330742887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 170}], {
             RGBColor[
             0.3747576276064379, 0.498629600146848, 0.9451144220759548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 180}], {
             RGBColor[
             0.33540782096983857`, 0.46454677541701367`, 0.9426070871927383]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 183}], {
             RGBColor[
             0.2817396246657633, 0.4134565872206231, 0.9393560268770672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 239}], {
             RGBColor[
             0.3145302695292589, 0.4464636896954298, 0.9412767880762385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 271}], {
             RGBColor[
             0.305666751429035, 0.4386055145162801, 0.9407186413492236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 326}], {
             RGBColor[
             0.32196792775833594`, 0.4529058154258842, 0.9417507090817323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 335}], {
             RGBColor[
             0.29253189959404885`, 0.42479995244000324`, 0.9399706309684931]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 337}], {
             RGBColor[
             0.29464447603044647`, 0.42702040421973947`, 0.9400909390712692]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 354}], {
             RGBColor[
             0.29215952785429067`, 0.42440856613178546`, 0.9399494249487885]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 175}], {
             RGBColor[
             0.18244584031582461`, 0.30909252427929373`, 0.9337013927503286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 202}], {
             RGBColor[
             0.5211495825009953, 0.37342113688887774`, 0.567742844041897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 214}], {
             RGBColor[
             0.5848663164286375, 0.6501021124541597, 0.9231267958935396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 256}], {
             RGBColor[
             0.20563395231845213`, 0.3334647002052716, 0.9350219214251405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 261}], {
             RGBColor[
             0.18270395436139325`, 0.3093638185065621, 0.9337160919633781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 264}], {
             RGBColor[
             0.1879952768080626, 0.31492533388723165`, 0.9340174249489059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 295}], {
             RGBColor[
             0.2141734445733891, 0.3424402480002911, 0.9355082328760125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 310}], {
             RGBColor[
             0.1842688448604277, 0.3110086176408356, 0.93380521016225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 363}], {
             RGBColor[
             0.5242360164158433, 0.390684407006331, 0.5704454430561892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 381}], {
             RGBColor[
             0.5895532840978516, 0.6521098895899253, 0.8485682432747944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 187}], {
             RGBColor[
             0.656588840938115, 0.7291931341002164, 0.9681680488654731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 218}], {
             RGBColor[
             0.689653807893005, 0.7555582412254274, 0.971321814931075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 253}], {
             RGBColor[
             0.40547981020843754`, 0.5251955404755204, 0.9471772728723662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 298}], {
             RGBColor[
             0.6463369873520685, 0.7210185843298552, 0.9671902179184984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.5352140965427551, 0.633549940550514, 0.9565531607151321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 265}], {
             RGBColor[
             0.5475052991401734, 0.643528492531465, 0.9575207692077594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 311}], {
             RGBColor[
             0.5112449698673547, 0.6140907237185725, 0.9546662232614405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 322}], {
             RGBColor[
             0.5057660137173806, 0.6096426602918618, 0.9542348997632368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 362}], {
             RGBColor[
             0.4538874638081069, 0.5662041111673836, 0.9505158832119648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 165}], {
             RGBColor[
             0.43209168429834016`, 0.5465211004605023, 0.9493493893401392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 167}], {
             RGBColor[
             0.30749203096032607`, 0.43842628345076595`, 0.9408993959616536]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 192}], {
             RGBColor[
             0.3379621693046799, 0.46714757740434754`, 0.9427556284732501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 201}], {
             RGBColor[
             0.30393044061377905`, 0.43468282617867443`, 0.9406965686603185]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 210}], {
             RGBColor[
             0.3156791522092831, 0.44703146697688845`, 0.9413656404050212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 228}], {
             RGBColor[
             0.3496458859290326, 0.47726742550368945`, 0.9435001045650488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 236}], {
             RGBColor[
             0.2909783973419341, 0.4210694074929913, 0.9399589689568179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 243}], {
             RGBColor[
             0.3099032733211534, 0.44096065205359114`, 0.9410367126469893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 263}], {
             RGBColor[
             0.29675910238603487`, 0.4271452950122101, 0.9402881715572926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 166}], {
             RGBColor[
             0.8271233428626157, 0.2094874755325008, 0.1736066497976622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 185}], {
             RGBColor[
             0.8265840327508944, 0.20534210168661424`, 0.17309020582561438`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 213}], {
             RGBColor[
             0.8702228477750129, 0.45615422864304855`, 0.21154106500959308`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 224}], {
             RGBColor[
             0.9025695450570996, 0.5785729407895561, 0.26790552836760506`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 247}], {
             RGBColor[
             0.8682425607038025, 0.44830305029724704`, 0.2099476795487854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 289}], {
             RGBColor[
             0.863615444991354, 0.42809333252077686`, 0.20612813226240806`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 302}], {
             RGBColor[
             0.9083773079386029, 0.59816388871644, 0.2904675904582531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 340}], {
             RGBColor[
             0.9116278550257833, 0.6083417789954149, 0.37001345675471364`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 370}], {
             RGBColor[
             0.8303471028154521, 0.5479183884634005, 0.5798122246722852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 400}], {
             RGBColor[
             0.6095442446912597, 0.3697331530727862, 0.5609538560304888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 170}], {
             RGBColor[
             0.43820314080929235`, 0.5539712686639211, 0.9491428945379133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 222}], {
             RGBColor[
             0.5181817733764011, 0.6191282032508729, 0.9553764737486448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 239}], {
             RGBColor[
             0.3779757827321134, 0.5018053582125028, 0.9453052605381971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 251}], {
             RGBColor[
             0.6268762447587527, 0.7046334098478555, 0.9658130763902817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 312}], {
             RGBColor[
             0.44719691052756494`, 0.5614994937585587, 0.949788285319064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 326}], {
             RGBColor[
             0.3854134409611904, 0.5082474839429573, 0.9457791815436909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 327}], {
             RGBColor[
             0.3750143899762539, 0.4992403486513052, 0.9451165632104506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 337}], {
             RGBColor[
             0.35808998923330093`, 0.48236207273681253`, 0.9441194115332278]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.47490752561281135`, 0.5839962194337451, 0.9519697664459024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 179}], {
             RGBColor[
             0.25786357675267113`, 0.38836134703509095`, 0.9379963212698641]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 231}], {
             RGBColor[
             0.27738405997012383`, 0.4088786125667542, 0.9391079839111312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 313}], {
             RGBColor[
             0.26444617460999714`, 0.3952800747439503, 0.938371190479758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 359}], {
             RGBColor[
             0.24582605828944576`, 0.3757091519074889, 0.9373108024012962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 164}], {
             RGBColor[
             0.24375587866941067`, 0.373533261869863, 0.9371929087344915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 169}], {
             RGBColor[
             0.23283585906700827`, 0.36205562889850595`, 0.936571029772856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 209}], {
             RGBColor[
             0.2485031193706023, 0.3785229128392603, 0.9374632570695112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 227}], {
             RGBColor[
             0.23994763052693538`, 0.3695305516152434, 0.9369760346365759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 240}], {
             RGBColor[
             0.2420898799764604, 0.3717821916131542, 0.9370980325735522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 245}], {
             RGBColor[
             0.2374360489235272, 0.36689072010659024`, 0.9368330037798137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 280}], {
             RGBColor[
             0.24199322930997053`, 0.37168060563466715`, 0.9370925284610774]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 304}], {
             RGBColor[
             0.23203584179739814`, 0.3612147600241211, 0.9365254699728711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 315}], {
             RGBColor[
             0.24412373790812583`, 0.3739199052533755, 0.9372138577739373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 319}], {
             RGBColor[
             0.2432784612852803, 0.3730314659291315, 0.9371657205207411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 329}], {
             RGBColor[
             0.2400560374603316, 0.3696444941756393, 0.936982208251059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 371}], {
             RGBColor[
             0.25850942763125473`, 0.3890401772577931, 0.9380331015219487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 169}], {
             RGBColor[
             0.23161848816298614`, 0.3607760948926053, 0.9365017023008109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 209}], {
             RGBColor[
             0.24728574846658016`, 0.37724337883335973`, 0.9373939295974659]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 227}], {
             RGBColor[
             0.23873025962291325`, 0.36825101760934276`, 0.9369067071645306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 245}], {
             RGBColor[
             0.23621867801950508`, 0.36561118610068966`, 0.9367636763077685]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 280}], {
             RGBColor[
             0.2407758584059484, 0.37040107162876656`, 0.9370232009890322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 304}], {
             RGBColor[
             0.230818470893376, 0.3599352260182205, 0.936456142500826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 315}], {
             RGBColor[
             0.2429063670041037, 0.37264037124747484`, 0.9371445303018922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 228}], {
             RGBColor[
             0.4503029757321284, 0.5622948057743279, 0.9505097967266875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 262}], {
             RGBColor[
             0.7356958172611161, 0.7926545035064209, 0.9725524468455675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 298}], {
             RGBColor[
             0.6780894534855002, 0.7467966667692734, 0.969689888365638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 307}], {
             RGBColor[
             0.7589943744265952, 0.8098564226113569, 0.9253172138967432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 314}], {
             RGBColor[
             0.7292803775430885, 0.7876149200721775, 0.9745725244009281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 332}], {
             RGBColor[
             0.5299851907540822, 0.6293048792717479, 0.9561415220973347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 385}], {
             RGBColor[
             0.5540849096952511, 0.648870116788155, 0.9580387402525627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 185}], {
             RGBColor[
             0.8242297938213237, 0.1872463896398561, 0.17083578396792481`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 213}], {
             RGBColor[
             0.8678686088454421, 0.43805851659629047`, 0.20928664315190354`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 224}], {
             RGBColor[
             0.9002153061275288, 0.5604772287427979, 0.2656511065099155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 247}], {
             RGBColor[
             0.8658883217742317, 0.43020733825048896`, 0.20769325769109587`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 289}], {
             RGBColor[
             0.8612612060617832, 0.40999762047401866`, 0.2038737104047185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 302}], {
             RGBColor[
             0.9060230690090321, 0.580068176669682, 0.28821316860056356`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 340}], {
             RGBColor[
             0.9092736160962124, 0.5902460669486567, 0.36775903489702405`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 400}], {
             RGBColor[
             0.6071900057616888, 0.351637441026028, 0.5586994341727993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 192}], {
             RGBColor[
             0.3140196057697616, 0.4440801406652496, 0.941315327256403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[
             0.27998787707886075`, 0.41161538943957654`, 0.9392562674434715]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.2874735215718495, 0.4194832764189812, 0.9396825638233285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 228}], {
             RGBColor[
             0.32570332239411426`, 0.45419998876459156`, 0.9420598033482018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 243}], {
             RGBColor[
             0.28596070978623506`, 0.41789321531449325`, 0.9395964114301423]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 348}], {
             RGBColor[
             0.2732523450214962, 0.4045359181898883, 0.9388726888571313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 351}], {
             RGBColor[
             0.2646469792533301, 0.39549113315584294`, 0.938382626007132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 170}], {
             RGBColor[
             0.5575600626847299, 0.651038994684655, 0.958666022792408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 180}], {
             RGBColor[
             0.5182102560481305, 0.6169561699548207, 0.9561586879091916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 220}], {
             RGBColor[
             0.5727925024434088, 0.663632053166977, 0.9598025445321408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 251}], {
             RGBColor[
             0.7462331666341901, 0.8017011358685895, 0.9753362046447762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 282}], {
             RGBColor[
             0.6585061316418895, 0.73314926196139, 0.9665973951785392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 350}], {
             RGBColor[
             0.5514466203488134, 0.6457438382038303, 0.9582764796526682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 357}], {
             RGBColor[
             0.6729202964028389, 0.7444097170243531, 0.9680340644138824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 394}], {
             RGBColor[
             0.5145092206731405, 0.613750519132451, 0.9559228612077943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 209}], {
             RGBColor[
             0.23636572886417778`, 0.36576574586200267`, 0.9367720506358304]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 227}], {
             RGBColor[
             0.22781024002051087`, 0.3567733846379857, 0.936284828202895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 240}], {
             RGBColor[
             0.22995248947003588`, 0.35902502463589653`, 0.9364068261398715]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 245}], {
             RGBColor[
             0.22529865841710267`, 0.3541335531293326, 0.936141797346133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 280}], {
             RGBColor[
             0.229855838803546, 0.3589234386574095, 0.9364013220273968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 292}], {
             RGBColor[
             0.21585857380573317`, 0.34421142566684904`, 0.9356041984928691]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 304}], {
             RGBColor[
             0.21989845129097363`, 0.3484575930468634, 0.9358342635391905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 315}], {
             RGBColor[
             0.23198634740170132`, 0.3611627382761178, 0.9365226513402567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 329}], {
             RGBColor[
             0.22791864695390707`, 0.3568873271983817, 0.9362910018173783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 353}], {
             RGBColor[
             0.21553905850906607`, 0.343875594831612, 0.9355860025694045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 378}], {
             RGBColor[
             0.21461245212241514`, 0.34290167276900374`, 0.9355332337064761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 180}], {
             RGBColor[
             0.40561982873439206`, 0.5257492414295251, 0.9470667147047922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 239}], {
             RGBColor[
             0.38474227729381244`, 0.5076661557079413, 0.9457364155882924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 251}], {
             RGBColor[
             0.6336427393204518, 0.7104942073432939, 0.966244231440377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 271}], {
             RGBColor[
             0.37587875919358854`, 0.49980798052879155`, 0.9451782688612774]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 282}], {
             RGBColor[
             0.5459157043281511, 0.6419423334360943, 0.9575054219741398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 326}], {
             RGBColor[
             0.39217993552288943`, 0.5141082814383957, 0.9462103365937862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 182}], {
             RGBColor[
             0.2806534492526592, 0.41231494799395196`, 0.9392941707941435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 244}], {
             RGBColor[
             0.266624380952421, 0.39756950771609656`, 0.9384952361085915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 253}], {
             RGBColor[
             0.30746418261270597`, 0.43744644735605664`, 0.9409326149067666]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 270}], {
             RGBColor[
             0.2613998670743656, 0.3920782123769482, 0.9381977077722119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 308}], {
             RGBColor[
             0.26715048285961845`, 0.3981224741773486, 0.9385251968339084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 397}], {
             RGBColor[
             0.26128106780929927`, 0.39195334681705507`, 0.9381909423298143]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 211}], {
             RGBColor[
             0.2820509294380053, 0.413783788274112, 0.9393737552233123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 328}], {
             RGBColor[
             0.3054309232922502, 0.438293739399488, 0.9407075511532149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 347}], {
             RGBColor[
             0.29073737323035515`, 0.422913791452218, 0.9398684353468445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 364}], {
             RGBColor[
             0.3254772137216906, 0.45565682861361634`, 0.9419848830531403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 387}], {
             RGBColor[
             0.29749670616801155`, 0.43001827893615596`, 0.9402533693581072]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 175}], {
             RGBColor[
             0.20264987627198583`, 0.3303282470790865, 0.9348519827088393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 197}], {
             RGBColor[
             0.607559522477704, 0.6724367666110929, 0.8861420267905455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 204}], {
             RGBColor[
             0.20264730553141047`, 0.33032554506774736`, 0.9348518363089665]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 214}], {
             RGBColor[
             0.6050703523847987, 0.6713378352539525, 0.9242773858520503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 261}], {
             RGBColor[
             0.2029079903175545, 0.3305995413063548, 0.9348666819218888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 295}], {
             RGBColor[
             0.23437748052955032`, 0.36367597080008385`, 0.9366588228345232]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 310}], {
             RGBColor[
             0.20447288081658893`, 0.33224434044062834`, 0.9349558001207607]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 345}], {
             RGBColor[
             0.21415750276433887`, 0.34242349214821033`, 0.9355073250135709]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 193}], {
             RGBColor[
             0.7754724977883137, 0.8245433157037161, 0.9782504569369469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 232}], {
             RGBColor[
             0.6270810139261389, 0.7068104580353534, 0.9646885621008761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 235}], {
             RGBColor[
             0.7343495307888845, 0.7923987018062052, 0.9741567564086497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 260}], {
             RGBColor[
             0.7687797089830702, 0.819295818690549, 0.9775884348027377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 267}], {
             RGBColor[
             0.6499021646261236, 0.725337696254724, 0.9664851266806084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 272}], {
             RGBColor[
             0.6878111560407678, 0.756042569748228, 0.9695182461395961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 275}], {
             RGBColor[
             0.8603530123804088, 0.8894563784374243, 0.877080294609712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 281}], {
             RGBColor[
             0.6802997161269625, 0.7500157979571946, 0.9688781332846546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 291}], {
             RGBColor[
             0.7125484820155874, 0.7753675568103979, 0.9719838316093115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 338}], {
             RGBColor[
             0.8614468790047858, 0.8890515325777966, 0.796643588235805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 384}], {
             RGBColor[
             0.7385166114389616, 0.7956540568810313, 0.9745720920642666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 398}], {
             RGBColor[
             0.83401539327211, 0.8711277377968187, 0.9805027030161089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 204}], {
             RGBColor[
             0.17892957074057536`, 0.30539670201133906`, 0.9335011463998728]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 214}], {
             RGBColor[
             0.5813526175939636, 0.6464089921975442, 0.9229266959429565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 256}], {
             RGBColor[
             0.20212025348377827`, 0.329771579948656, 0.9348218214745575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 261}], {
             RGBColor[
             0.1791902555267194, 0.3056706982499465, 0.9335159920127951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 264}], {
             RGBColor[
             0.18448157797338877`, 0.31123221363061604`, 0.9338173249983228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 295}], {
             RGBColor[
             0.21065974573871524`, 0.33874712774367555`, 0.9353081329254295]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 310}], {
             RGBColor[
             0.18075514602575382`, 0.30731549738422004`, 0.933605110211667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 345}], {
             RGBColor[
             0.1904397679735038, 0.31749464909180203`, 0.9341566351044772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 186}], {
             RGBColor[
             0.23214557991116364`, 0.36133010173948693`, 0.9365317193961071]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 226}], {
             RGBColor[
             0.22722875741095702`, 0.3561622095472178, 0.9362517136285073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 294}], {
             RGBColor[
             0.21429151975408078`, 0.34256435250159695`, 0.9355149570828762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 341}], {
             RGBColor[
             0.21870360025711671`, 0.3472017288523488, 0.9357662185404361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 368}], {
             RGBColor[
             0.2143024966118115, 0.34257588987504495`, 0.9355155821986852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 379}], {
             RGBColor[
             0.2183904240990045, 0.34687256085365753`, 0.9357483836215341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 393}], {
             RGBColor[
             0.2193217433014607, 0.3478514363844869, 0.9358014208723507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 399}], {
             RGBColor[
             0.22535125221155355`, 0.3541888325419396, 0.9361447924849214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 200}], {
             RGBColor[
             0.2962840776702533, 0.42752676637236176`, 0.9402288709406241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 225}], {
             RGBColor[
             0.2895083029136421, 0.42040499749423077`, 0.9398430005920957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 296}], {
             RGBColor[
             0.3117150207517371, 0.4437456659293011, 0.9411076403210801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 311}], {
             RGBColor[
             0.42064126980492156`, 0.5369664823599833, 0.9485194381294991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 324}], {
             RGBColor[
             0.3009330775683418, 0.4324131600288711, 0.9404936246072413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 339}], {
             RGBColor[
             0.34383450141698674`, 0.4722338963280338, 0.9431298082827468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 360}], {
             RGBColor[
             0.31615011179738517`, 0.4482550694974156, 0.9413657834565303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 374}], {
             RGBColor[
             0.29900611365793894`, 0.43038779878246913`, 0.9403838868632315]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 375}], {
             RGBColor[
             0.28837692064883436`, 0.4192158430001391, 0.939778570045845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 383}], {
             RGBColor[
             0.3010724134398118, 0.43255961086419054`, 0.9405015595789926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 390}], {
             RGBColor[
             0.2941038875347629, 0.4252352483079229, 0.9401047123377103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 209}], {
             RGBColor[
             0.24801071646784933`, 0.37800536616831976`, 0.9374352154526442]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 229}], {
             RGBColor[
             0.24544230257567465`, 0.37530580032079786`, 0.9372889480811126]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 240}], {
             RGBColor[
             0.24159747707370743`, 0.3712646449422136, 0.9370699909566852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 245}], {
             RGBColor[
             0.23694364602077422`, 0.3663731734356497, 0.9368049621629467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 248}], {
             RGBColor[
             0.230098166399185, 0.35917814032488304`, 0.9364151222254768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 309}], {
             RGBColor[
             0.2573894464516083, 0.38786300602707646`, 0.9379693202506316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 315}], {
             RGBColor[
             0.24363133500537287`, 0.37340235858243487`, 0.9371858161570703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 319}], {
             RGBColor[
             0.24278605838252734`, 0.37251391925819094`, 0.9371376789038741]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 329}], {
             RGBColor[
             0.23956363455757862`, 0.36912694750469877`, 0.9369541666341921]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 334}], {
             RGBColor[
             0.25269374017822266`, 0.3829275210087747, 0.9377019067250372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 371}], {
             RGBColor[
             0.25801702472850174`, 0.38852263058685255`, 0.9380050599050818]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 388}], {
             RGBColor[
             0.23367677668762307`, 0.36293948663502873`, 0.9366189187873238]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 196}], {
             RGBColor[
             0.2837836367777321, 0.41560497354815545`, 0.9394724303429989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 231}], {
             RGBColor[
             0.28916364068982703`, 0.4212596987717169, 0.9397788136067902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 303}], {
             RGBColor[
             0.27962744891017854`, 0.4112365565818258, 0.9392357415924706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 313}], {
             RGBColor[
             0.2762257553297003, 0.407661160948913, 0.939042020175417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 344}], {
             RGBColor[
             0.29513590341832135`, 0.4264382934400302, 0.9401591514378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 359}], {
             RGBColor[
             0.2576056390091489, 0.3880902381124516, 0.9379816320969553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 239}], {
             RGBColor[
             0.3453924706572131, 0.47358333097810695`, 0.943229080705076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 271}], {
             RGBColor[
             0.3365289525569892, 0.46572515579895724`, 0.942670933978061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 282}], {
             RGBColor[
             0.5065658976915518, 0.60785950870626, 0.9549980870909234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 326}], {
             RGBColor[
             0.3528301288862901, 0.48002545670856134`, 0.9437030017105699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 350}], {
             RGBColor[
             0.3995063863984757, 0.5204540849487005, 0.9466771715650524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 394}], {
             RGBColor[
             0.36256898672280274`, 0.4884607658773212, 0.9443235531201786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 250}], {
             RGBColor[
             0.7777697545864616, 0.8245041838583995, 0.9019245302265969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 265}], {
             RGBColor[
             0.5796034948121, 0.6695872537851715, 0.9600476567506184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 322}], {
             RGBColor[
             0.5378642093893072, 0.6357014215455682, 0.9567617873060958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 362}], {
             RGBColor[
             0.4859856594800335, 0.59226287242109, 0.9530427707548238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 244}], {
             RGBColor[
             0.27406524356197104`, 0.4053903260966717, 0.9389189822264357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 253}], {
             RGBColor[
             0.31490504522225604`, 0.4452672657366318, 0.9413563610246107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 271}], {
             RGBColor[
             0.28286075625291396`, 0.4146349676025667, 0.9394198736623899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 273}], {
             RGBColor[
             0.26718551324119244`, 0.3981592933294373, 0.9385271917623162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 335}], {
             RGBColor[
             0.2697259044179279, 0.4008294055262898, 0.9386718632816594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 305}], {
             RGBColor[
             0.21033276310750965`, 0.33840344826638225`, 0.9352895117483098]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 325}], {
             RGBColor[
             0.2146653182782982, 0.3429572384507447, 0.9355362443558451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 213}], {
             RGBColor[
             0.8673292987337209, 0.4339131427504039, 0.20877019917985573`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 224}], {
             RGBColor[
             0.8996759960158076, 0.5563318548969114, 0.2651346625378677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 247}], {
             RGBColor[
             0.8653490116625105, 0.42606196440460237`, 0.20717681371904806`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 289}], {
             RGBColor[
             0.8607218959500621, 0.40585224662813213`, 0.20335726643267069`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 302}], {
             RGBColor[
             0.905483758897311, 0.5759228028237954, 0.28769672462851575`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 340}], {
             RGBColor[
             0.9087343059844912, 0.5861006931027701, 0.36724259092497624`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 400}], {
             RGBColor[
             0.6066506956499677, 0.3474920671801415, 0.5581829902007515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 189}], {
             RGBColor[
             0.2745072076984255, 0.4058548584262301, 0.9389441514301794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 200}], {
             RGBColor[
             0.2595636633022175, 0.3901482457903771, 0.9380931386838082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 226}], {
             RGBColor[
             0.24355084950968384`, 0.37331776322339055`, 0.9371812326271585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 241}], {
             RGBColor[
             0.2697148101734317, 0.4008177447719086, 0.9386712314808479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 255}], {
             RGBColor[
             0.2544713249858168, 0.38479587534694254`, 0.9378031375501286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 288}], {
             RGBColor[
             0.2467468316416792, 0.3766769430810886, 0.9373632390815438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 341}], {
             RGBColor[
             0.23502569235584353`, 0.3643572825285215, 0.9366957375390872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 374}], {
             RGBColor[
             0.2622856992899031, 0.3930092782004845, 0.9382481546064155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 393}], {
             RGBColor[
             0.23564383540018752`, 0.36500699006065973`, 0.9367309398710019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 399}], {
             RGBColor[
             0.24167334431028037`, 0.3713443862181124, 0.9370743114835726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 193}], {
             RGBColor[
             0.8331367258093362, 0.8697846265391334, 0.9839465187292714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 218}], {
             RGBColor[
             0.8769988069965478, 0.9047590594733392, 0.9881301231890498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 232}], {
             RGBColor[
             0.6847452419471614, 0.7520517688707707, 0.9703846238932006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 235}], {
             RGBColor[
             0.792013758809907, 0.8376400126416226, 0.9798528182009743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 275}], {
             RGBColor[
             0.9180172404014313, 0.9346976892728417, 0.8827763564020366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 279}], {
             RGBColor[
             0.8947917399967904, 0.8503099582405043, 0.6300514927715455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 281}], {
             RGBColor[
             0.7379639441479849, 0.795257108792612, 0.9745741950769791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 298}], {
             RGBColor[
             0.8336819864556111, 0.8702194025777671, 0.983998526176473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 306}], {
             RGBColor[
             0.9071549779062498, 0.8950638881018478, 0.6621967951023203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 195}], {
             RGBColor[
             0.25639031228130726`, 0.3868128526653249, 0.9379124210377194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 203}], {
             RGBColor[
             0.2792417470878428, 0.4108311595116429, 0.9392137764442834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 206}], {
             RGBColor[
             0.2493239941811602, 0.37938570431162577`, 0.937510004675597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 208}], {
             RGBColor[
             0.25008631824464794`, 0.38018695523648866`, 0.9375534179032552]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 258}], {
             RGBColor[
             0.2600095899871553, 0.39061694300963157`, 0.938118533548826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 278}], {
             RGBColor[
             0.2597507710467335, 0.39034490789317966`, 0.9381037941930572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 284}], {
             RGBColor[
             0.25554200422115014`, 0.38592122710826227`, 0.9378641111486529]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 327}], {
             RGBColor[
             0.2928390260811543, 0.4242124195155595, 0.9400214534598996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 361}], {
             RGBColor[
             0.3113562197109362, 0.44025108193646334`, 0.9412013526638779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 369}], {
             RGBColor[
             0.26226993371413826`, 0.39299270758076044`, 0.9382472567801988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 392}], {
             RGBColor[
             0.25751756533120074`, 0.38799766709273437`, 0.9379766164312895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 200}], {
             RGBColor[
             0.28560319899075254`, 0.41751744880094743`, 0.9395760517192293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 219}], {
             RGBColor[
             0.37386729373661226`, 0.4974887142474586, 0.9450712281757306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 241}], {
             RGBColor[
             0.2957543458619668, 0.428186947782479, 0.9401541445162689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 255}], {
             RGBColor[
             0.28051086067435194`, 0.4121650783575129, 0.9392860505855498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 339}], {
             RGBColor[
             0.333153622737486, 0.4622245787566195, 0.942476989061352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 360}], {
             RGBColor[
             0.30546923311788443`, 0.43824575192600135`, 0.9407129642351355]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 374}], {
             RGBColor[
             0.2883252349784382, 0.42037848121105487`, 0.9397310676418367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 266}], {
             RGBColor[
             0.24805045871485498`, 0.3780471377897267, 0.9374374787148178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 273}], {
             RGBColor[
             0.2582701914773965, 0.38878872489163985`, 0.9380194773769047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 365}], {
             RGBColor[
             0.24867185173243342`, 0.3787002612497945, 0.9374728661279003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 198}], {
             RGBColor[
             0.7526714957518834, 0.806764542665624, 0.9759689648481673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 216}], {
             RGBColor[
             0.6689774683276695, 0.7413295497654275, 0.9676410801591727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 219}], {
             RGBColor[
             0.5630206032370957, 0.6553990201614963, 0.9591704044347413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 220}], {
             RGBColor[
             0.5771439386381384, 0.6670314281944398, 0.9602362550255482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 311}], {
             RGBColor[
             0.5991137006259042, 0.6848674707026068, 0.961965795167115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 323}], {
             RGBColor[
             0.7545318035699571, 0.8082479016230455, 0.9761464026685716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 339}], {
             RGBColor[
             0.5223069322379694, 0.6201348846706572, 0.9565761653203628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 357}], {
             RGBColor[
             0.6772717325975683, 0.7478090920518159, 0.9684677749072899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 201}], {
             RGBColor[
             0.3104580154232146, 0.4403366833931581, 0.941112499955068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 203}], {
             RGBColor[
             0.31794365991620344`, 0.4482045703725628, 0.9415387963349251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 228}], {
             RGBColor[
             0.35617346073846823`, 0.48292128271817314`, 0.9439160358597984]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 243}], {
             RGBColor[
             0.31643084813058897`, 0.44661450926807483`, 0.9414526439417388]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 332}], {
             RGBColor[
             0.43585567576042195`, 0.5499313562155932, 0.9495477612304457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 348}], {
             RGBColor[
             0.30372248336585006`, 0.4332572121434699, 0.9407289213687278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 361}], {
             RGBColor[
             0.35005813253929685`, 0.4776244927973833, 0.9435263725545195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 385}], {
             RGBColor[
             0.45995539470159097`, 0.5694965937320001, 0.9514449793856737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 232}], {
             RGBColor[
             0.6739481277148399, 0.7434424430617759, 0.9693547854990241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 235}], {
             RGBColor[
             0.7812166445775857, 0.8290306868326278, 0.9788229798067978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 260}], {
             RGBColor[
             0.8156468227717713, 0.8559278037169716, 0.9822546582008858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 275}], {
             RGBColor[
             0.9072201261691099, 0.9260883634638468, 0.8817465180078601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 281}], {
             RGBColor[
             0.7271668299156635, 0.7866477829836171, 0.9735443566828026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 338}], {
             RGBColor[
             0.9083139927934867, 0.9256835176042191, 0.801309811633953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 384}], {
             RGBColor[
             0.7853837252276628, 0.8322860419074539, 0.9792383154624147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 376}], {
             RGBColor[
             0.4132241787161002, 0.5323357471779375, 0.947551257161364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 377}], {
             RGBColor[
             0.40146722310948635`, 0.5221524631532592, 0.9468021143463783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 396}], {
             RGBColor[
             0.3331772870037427, 0.4601881672994485, 0.9425538104147095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 206}], {
             RGBColor[
             0.2386283880050733, 0.3681439440799593, 0.9369009057266002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 208}], {
             RGBColor[
             0.239390712068561, 0.3689451950048222, 0.9369443189542583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 258}], {
             RGBColor[
             0.24931398381106837`, 0.3793751827779651, 0.9375094345998292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 278}], {
             RGBColor[
             0.24905516487064655`, 0.3791031476615132, 0.9374946952440605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 284}], {
             RGBColor[
             0.24484639804506322`, 0.3746794668765958, 0.9372550121996561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 327}], {
             RGBColor[
             0.2821434199050674, 0.41297065928389304`, 0.9394123545109028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 337}], {
             RGBColor[
             0.26521901916211443`, 0.39609238336940045`, 0.9384152028336801]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 369}], {
             RGBColor[
             0.2515743275380513, 0.381750947349094, 0.9376381578312021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 392}], {
             RGBColor[
             0.24682195915511385`, 0.3767559068610679, 0.9373675174822926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 231}], {
             RGBColor[
             0.3033041199951848, 0.43612223907981873`, 0.9405840929842658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 234}], {
             RGBColor[
             0.3183317548341577, 0.44914414193399255`, 0.9415414311188043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 290}], {
             RGBColor[
             0.3515289166579535, 0.47789785496789633`, 0.943656724915119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 303}], {
             RGBColor[
             0.29376792821553643`, 0.42609909688992764`, 0.9400410209699464]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 313}], {
             RGBColor[
             0.2903662346350581, 0.4225237012570149, 0.9398472995528928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 344}], {
             RGBColor[
             0.3092763827236792, 0.441300833748132, 0.9409644308152758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 204}], {
             RGBColor[
             0.5838392169462935, 0.6475052215433456, 0.8847911904815791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 215}], {
             RGBColor[
             0.9040198154602492, 0.5694397771754294, 0.5010925431304881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 295}], {
             RGBColor[
             0.6155693919444334, 0.6808556472756819, 0.8865981770071358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 310}], {
             RGBColor[
             0.5856647922314719, 0.6494240169162264, 0.8848951542933734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 345}], {
             RGBColor[
             0.5953494141792219, 0.6596031686238084, 0.8854466791861835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 216}], {
             RGBColor[
             0.7427956016916255, 0.7990494191661757, 0.974984628023718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 219}], {
             RGBColor[
             0.6368387366010516, 0.7131188895622445, 0.9665139522992866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 224}], {
             RGBColor[
             0.901075568718926, 0.8970235530331128, 0.6716312488962854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 247}], {
             RGBColor[
             0.866748584365629, 0.7667536625408037, 0.6136734000774657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 302}], {
             RGBColor[
             0.9068833316004294, 0.9166145009599966, 0.6941933109869335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 311}], {
             RGBColor[
             0.6729318339898602, 0.7425873401033549, 0.9693093430316602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 323}], {
             RGBColor[
             0.828349936933913, 0.8659677710237936, 0.9834899505331167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 340}], {
             RGBColor[
             0.9101338786876096, 0.9267923912389714, 0.7737391772833939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 212}], {
             RGBColor[
             0.21834996970250586`, 0.3468300407179805, 0.9357460798035004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 238}], {
             RGBColor[
             0.22751293603602638`, 0.35646089930013114`, 0.9362678971808005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 252}], {
             RGBColor[
             0.2250679449332263, 0.3538910586296987, 0.9361286585545363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 277}], {
             RGBColor[
             0.24180779724081597`, 0.3714857047729135, 0.9370819683790612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 287}], {
             RGBColor[
             0.24300807911222783`, 0.3727472771220335, 0.9371503226559803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 293}], {
             RGBColor[
             0.21851691429369074`, 0.3470055100682143, 0.9357555870509962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 299}], {
             RGBColor[
             0.21996573354153404`, 0.3485283109581435, 0.9358380951638248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 336}], {
             RGBColor[
             0.2184046627263886, 0.34688752655381927`, 0.9357491944902996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 367}], {
             RGBColor[
             0.2225587298907346, 0.35125371452661747`, 0.9359857624699174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 225}], {
             RGBColor[
             0.26388387983793327`, 0.3946890672869635, 0.9383391686243296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 241}], {
             RGBColor[
             0.2808108014657587, 0.41248033514662596`, 0.9393031317698977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 255}], {
             RGBColor[
             0.26556731627814384`, 0.3964584657216599, 0.9384350378391786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 288}], {
             RGBColor[
             0.25784282293400623`, 0.38833953345580596`, 0.9379951393705938]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 296}], {
             RGBColor[
             0.2860905976760283, 0.41802973572203384`, 0.939603808353314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 339}], {
             RGBColor[
             0.3182100783412779, 0.4465179661207665, 0.9416259763149808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 355}], {
             RGBColor[
             0.2507904105311417, 0.380927000871623, 0.9375935149173598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 360}], {
             RGBColor[
             0.29052568872167633`, 0.4225391392901483, 0.9398619514887643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 374}], {
             RGBColor[
             0.27338169058223005`, 0.4046718685752019, 0.9388800548954654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 375}], {
             RGBColor[
             0.26275249757312547`, 0.3934999127928718, 0.9382747380780788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 383}], {
             RGBColor[
             0.27544799036410295`, 0.4068436806569232, 0.9389977276112265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 399}], {
             RGBColor[
             0.2527693356026074, 0.3830069765928298, 0.9377062117726225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 210}], {
             RGBColor[
             0.2881749983278178, 0.42022057296569904`, 0.9397225118868391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 228}], {
             RGBColor[
             0.3221417320475673, 0.45045653149250003`, 0.9418569760468667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 236}], {
             RGBColor[
             0.26347424346046877`, 0.3942585134818019, 0.9383158404386357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 243}], {
             RGBColor[
             0.2823991194396881, 0.4141497580424017, 0.9393935841288071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 263}], {
             RGBColor[
             0.26925494850456955`, 0.4003344010010207, 0.9386450430391104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 348}], {
             RGBColor[
             0.2696907546749492, 0.40079246091779686`, 0.9386698615557961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 351}], {
             RGBColor[
             0.26108538890678307`, 0.3917476758837515, 0.9381797987057969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 214}], {
             RGBColor[
             0.9200563597791344, 0.7107376048071281, 0.556968147234525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 217}], {
             RGBColor[
             0.8395826476787889, 0.30525515205179155`, 0.18553769416040178`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 257}], {
             RGBColor[
             0.8394733977788387, 0.30441540944716294`, 0.18543307633282935`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 264}], {
             RGBColor[
             0.5231853201585595, 0.37556082624020004`, 0.5678587762898913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 268}], {
             RGBColor[
             0.836829312925746, 0.2840918146209231, 0.18290109769144122`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 279}], {
             RGBColor[
             0.9009946329017078, 0.6281412966873632, 0.2383554119012628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 300}], {
             RGBColor[
             0.873168201892003, 0.5137197571930974, 0.21575357463755512`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 306}], {
             RGBColor[
             0.913357870811167, 0.6728952265487068, 0.2705007142320376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 363}], {
             RGBColor[
             0.8594260597663401, 0.4513198993592995, 0.20428679439717456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 381}], {
             RGBColor[
             0.9247433274483484, 0.7127453819428937, 0.4824095946157798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 243}], {
             RGBColor[
             0.28988476393267687`, 0.4220176450218065, 0.9398198805086642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 258}], {
             RGBColor[
             0.2721654186176039, 0.4033934896242831, 0.9388107900063931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 284}], {
             RGBColor[
             0.26769783285159876`, 0.3986977737229138, 0.93855636760622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 348}], {
             RGBColor[
             0.277176399167938, 0.4086603478972015, 0.9390961579356532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 361}], {
             RGBColor[
             0.32351204834138475`, 0.4530276285511149, 0.941893609121445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 369}], {
             RGBColor[
             0.2744257623445868, 0.405769254195412, 0.9389395132377659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 392}], {
             RGBColor[
             0.26967339396164935`, 0.4007742137073859, 0.9386688728888566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 261}], {
             RGBColor[
             0.17918768478614402`, 0.3056679962386074, 0.9335158456129223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 295}], {
             RGBColor[
             0.21065717499813985`, 0.33874442573233643`, 0.9353079865255567]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 310}], {
             RGBColor[
             0.18075257528517846`, 0.3073127953728809, 0.9336049638117943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 345}], {
             RGBColor[
             0.1904371972329284, 0.3174919470804629, 0.9341564887046044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 389}], {
             RGBColor[
             0.17900756331513207`, 0.305478677152213, 0.9335055879616141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 400}], {
             RGBColor[
             0.2842689537951664, 0.40863855928315673`, 0.939773820202813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 207}], {
             RGBColor[
             0.967562165289962, 0.8957834071543473, 0.4992706546503005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 221}], {
             RGBColor[
             0.9585637141169614, 0.9664203575638242, 0.8602427231177231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 230}], {
             RGBColor[
             0.9820628725503424, 0.9494608486926688, 0.5307965926515668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 250}], {
             RGBColor[
             0.9917478646376758, 0.990855544204543, 0.7864227690028461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 276}], {
             RGBColor[
             0.8804173286055655, 0.9045483902483498, 0.8526723312886473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 358}], {
             RGBColor[
             0.9819225924478814, 0.9489876509677333, 0.5302516309431803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 391}], {
             RGBColor[
             0.9078296512801215, 0.575024774186147, 0.4476180378082022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 208}], {
             RGBColor[
             0.23232439396841398`, 0.3615180466511231, 0.9365419025921359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 258}], {
             RGBColor[
             0.24224766571092132`, 0.37194803442426605`, 0.9371070182377067]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 278}], {
             RGBColor[
             0.24198884677049953`, 0.37167599930781414`, 0.937092278881938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 284}], {
             RGBColor[
             0.23778007994491618`, 0.3672523185228967, 0.9368525958375336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 369}], {
             RGBColor[
             0.2445080094379043, 0.3743237989953949, 0.9372357414690795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 392}], {
             RGBColor[
             0.23975564105496683`, 0.3693287585073688, 0.9369651011201702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 221}], {
             RGBColor[
             0.9308573670898133, 0.869892342221664, 0.6314368519575342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 230}], {
             RGBColor[
             0.9543565255231943, 0.8529328333505086, 0.30199072149137773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 233}], {
             RGBColor[
             0.8786570254685007, 0.4672262975790694, 0.21740805642807715`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 250}], {
             RGBColor[
             0.9640415176105277, 0.8943275288623829, 0.5576168978426572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 358}], {
             RGBColor[
             0.9542162454207332, 0.8524596356255733, 0.30144575978299126`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 366}], {
             RGBColor[
             0.9205681319812286, 0.7219373884597544, 0.2549015531776194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 391}], {
             RGBColor[
             0.8801233042529734, 0.4784967588439868, 0.2188121666480132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[
             0.24300998977440907`, 0.3727492853491289, 0.9371504314653649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 278}], {
             RGBColor[
             0.24275117083398723`, 0.37247725023267697`, 0.9371356921095961]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 284}], {
             RGBColor[
             0.23854240400840393`, 0.3680535694477596, 0.9368960090651918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 369}], {
             RGBColor[
             0.24527033350139205`, 0.37512504992025775`, 0.9372791546967377]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 392}], {
             RGBColor[
             0.24051796511845452`, 0.3701300094322317, 0.9370085143478284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 227}], {
             RGBColor[
             0.24347750032410487`, 0.3732406685787401, 0.9371770554995502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 229}], {
             RGBColor[
             0.24946457527559712`, 0.37953346395523513`, 0.937518010560954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 240}], {
             RGBColor[
             0.24561974977362988`, 0.37549230857665095`, 0.9372990534365266]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 245}], {
             RGBColor[
             0.2409659187206967, 0.37060083707008695`, 0.9370340246427882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 280}], {
             RGBColor[
             0.24552309910713999`, 0.37539072259816386`, 0.9372935493240518]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 304}], {
             RGBColor[
             0.23556571159456763`, 0.3649248769876179, 0.9367264908358456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 315}], {
             RGBColor[
             0.24765360770529532`, 0.37763002221687225`, 0.9374148786369118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 319}], {
             RGBColor[
             0.24680833108244982`, 0.37674158289262827`, 0.9373667413837155]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 329}], {
             RGBColor[
             0.24358590725750107`, 0.37335461113913604`, 0.9371832291140334]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 334}], {
             RGBColor[
             0.2567160128781451, 0.387155184643212, 0.9379309692048785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 371}], {
             RGBColor[
             0.26203929742842424`, 0.3927502942212898, 0.9382341223849231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 236}], {
             RGBColor[
             0.27522295505597283`, 0.4066071542800159, 0.9389849121833385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 263}], {
             RGBColor[
             0.2810036601000736, 0.41268304179923465`, 0.9393141147838132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 301}], {
             RGBColor[
             0.25974755171345176`, 0.39034152416978307`, 0.9381036108567895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 328}], {
             RGBColor[
             0.2860571913279975, 0.41793071873950494`, 0.9396042457787188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 347}], {
             RGBColor[
             0.27136364126610246`, 0.4025507707922349, 0.9387651299723484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 372}], {
             RGBColor[
             0.257077351430105, 0.3875349743715093, 0.9379515469008601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 387}], {
             RGBColor[
             0.27812297420375887`, 0.4096552582761729, 0.939150063983611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 238}], {
             RGBColor[
             0.22006014114382055`, 0.3486275393339343, 0.9358434715371114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 259}], {
             RGBColor[
             0.2109589325174653, 0.33906159201767927`, 0.935325171169872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 293}], {
             RGBColor[
             0.2110641194014849, 0.3391721501020175, 0.935331161407307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 299}], {
             RGBColor[
             0.2125129386493282, 0.3406949509919467, 0.9354136695201356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 336}], {
             RGBColor[
             0.21095186783418274`, 0.3390541665876225, 0.9353247688466104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 367}], {
             RGBColor[
             0.21510593499852879`, 0.3434203545604207, 0.9355613368262283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 224}], {
             RGBColor[
             0.9433148110399261, 0.8071439818533458, 0.30358552172184644`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 230}], {
             RGBColor[
             0.939912673270707, 0.7956677722978341, 0.2903688589282392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 247}], {
             RGBColor[
             0.9089878266866289, 0.6768740913610367, 0.24562767290302676`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 250}], {
             RGBColor[
             0.9495976653580405, 0.8370624678097084, 0.5459950352795185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 289}], {
             RGBColor[
             0.9043607109741805, 0.6566643735845665, 0.24180812561664938`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 302}], {
             RGBColor[
             0.9491225739214294, 0.8267349297802298, 0.3261475838124945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 340}], {
             RGBColor[
             0.9523731210086097, 0.8369128200592044, 0.40569345010895497`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 391}], {
             RGBColor[
             0.8656794520004861, 0.4212316977913123, 0.20719030408487465`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 215}], {
             RGBColor[
             0.9015306453673441, 0.5683408458182889, 0.5392279021919928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 217}], {
             RGBColor[
             0.903299381606431, 0.5819361276170735, 0.5409216460120444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 261}], {
             RGBColor[
             0.5816107316395323, 0.6466802864248125, 0.9229413951560062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 264}], {
             RGBColor[
             0.5869020540862017, 0.6522418018054821, 0.9232427281415339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 295}], {
             RGBColor[
             0.6130802218515281, 0.6797567159185416, 0.9247335360686406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 300}], {
             RGBColor[
             0.9368849358196452, 0.7904007327583793, 0.5711375264891978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 310}], {
             RGBColor[
             0.5831756221385668, 0.6483250855590861, 0.9230305133548782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 363}], {
             RGBColor[
             0.9231427936939823, 0.7280008749245814, 0.5596707462488172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 217}], {
             RGBColor[
             0.8210569332669986, 0.16285839306295227`, 0.16779744911786956`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 269}], {
             RGBColor[
             0.9061735630089964, 0.5684125935804545, 0.32599457253607145`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 295}], {
             RGBColor[
             0.5308377735120957, 0.2606789813644203, 0.5516093391744658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 300}], {
             RGBColor[
             0.8546424874802127, 0.37132299820425807`, 0.1980133295950229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 352}], {
             RGBColor[
             0.906721166296464, 0.5695838616411621, 0.3855978109611532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 363}], {
             RGBColor[
             0.8409003453545498, 0.3089231403704602, 0.18654654935464235`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 219}], {
             RGBColor[
             0.5531447091768378, 0.647683896662048, 0.958186067610292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 220}], {
             RGBColor[
             0.5672680445778805, 0.6593163046949915, 0.9592519182010989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 311}], {
             RGBColor[
             0.5892378065656463, 0.6771523472031584, 0.9609814583426657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 323}], {
             RGBColor[
             0.7446559095096992, 0.8005327781235971, 0.9751620658441222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 339}], {
             RGBColor[
             0.5124310381777115, 0.6124197611712089, 0.9555918284959135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 357}], {
             RGBColor[
             0.6673958385373104, 0.7400939685523675, 0.9674834380828405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 268}], {
             RGBColor[
             0.8200723347530428, 0.15529033743086842`, 0.16685459646896056`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 269}], {
             RGBColor[
             0.9079422992480835, 0.582007875379239, 0.32768831635612294`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 279}], {
             RGBColor[
             0.8842376547290044, 0.4993398194973086, 0.22230891067878217`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 300}], {
             RGBColor[
             0.8564112237192996, 0.3849182800030426, 0.19970707341507446`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 306}], {
             RGBColor[
             0.8966008926384637, 0.5440937493586522, 0.25445421300955695`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 363}], {
             RGBColor[
             0.8426690815936368, 0.3225184221692448, 0.1882402931746939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 262}], {
             RGBColor[
             0.9243533171861171, 0.9424423464401257, 0.9900148507220045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 269}], {
             RGBColor[
             0.9515613514707596, 0.9593431212476458, 0.7385846645144882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 279}], {
             RGBColor[
             0.9278567069516805, 0.8766750653657154, 0.6332052588371474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 298}], {
             RGBColor[
             0.8667469534105012, 0.8965845097029781, 0.9871522922420749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.9000302759419758, 0.7622535258714493, 0.6106034215734397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 306}], {
             RGBColor[
             0.9402199448611399, 0.9214289952270589, 0.6653505611679222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 314}], {
             RGBColor[
             0.9179378774680893, 0.9374027630058823, 0.9920349282773651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 220}], {
             RGBColor[
             0.4613111794873067, 0.5733857750910603, 0.9507812424766675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 241}], {
             RGBColor[
             0.36907489621161843`, 0.49245160059313714`, 0.9447983082263991]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 311}], {
             RGBColor[
             0.48328094147507245`, 0.5912218175992272, 0.9525107826182344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 323}], {
             RGBColor[
             0.6386990444191253, 0.7146022485196659, 0.9666913901196909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 339}], {
             RGBColor[
             0.4064741730871376, 0.5264892315672777, 0.9471211527714821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 357}], {
             RGBColor[
             0.5614389734467367, 0.6541634389484363, 0.9590127623584092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 360}], {
             RGBColor[
             0.37878978346753606`, 0.5025104047366595, 0.9453571279452656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 350}], {
             RGBColor[
             0.454088632793754, 0.5671299681608568, 0.9503210281880017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 357}], {
             RGBColor[
             0.5755623088477795, 0.6657958469813797, 0.960078612949216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 394}], {
             RGBColor[
             0.4171512331180811, 0.5351366490894776, 0.9479674097431279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 230}], {
             RGBColor[
             0.9453580743501937, 0.9235697837599854, 0.6629627899588003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 250}], {
             RGBColor[
             0.955043066437527, 0.9649644792718597, 0.9185889663100797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 276}], {
             RGBColor[
             0.8437125304054167, 0.8786573253156666, 0.9848385285958808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 358}], {
             RGBColor[
             0.9452177942477327, 0.9230965860350502, 0.6624178282504138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 251}], {
             RGBColor[
             0.7136213718875605, 0.7756511419302459, 0.9724778106511085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 297}], {
             RGBColor[
             0.7757829604608912, 0.8249349923236523, 0.9686258035292561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 312}], {
             RGBColor[
             0.5339420376563727, 0.632517225840949, 0.9564530195798908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 332}], {
             RGBColor[
             0.5660742539559687, 0.6586036065728093, 0.9589825853511816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 356}], {
             RGBColor[
             0.5616526527416191, 0.6550139515161355, 0.9586345007067291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 361}], {
             RGBColor[
             0.48027671073484357`, 0.5862967431545993, 0.9529611966752556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 260}], {
             RGBColor[
             0.6315106131402652, 0.7091757673875206, 0.9658788076150083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 267}], {
             RGBColor[
             0.5126330687833186, 0.6152176449516955, 0.954775499492879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 272}], {
             RGBColor[
             0.5505420601979628, 0.6459225184451997, 0.9578086189518668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 290}], {
             RGBColor[
             0.4296004547734099, 0.5464997120753861, 0.9486003596365518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 291}], {
             RGBColor[
             0.5752793861727824, 0.6652475055073694, 0.9602742044215822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 321}], {
             RGBColor[
             0.6359268279774656, 0.7126257479828174, 0.9663189746381065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 331}], {
             RGBColor[
             0.45307983116767014`, 0.5668363678003234, 0.9500964447383967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 342}], {
             RGBColor[
             0.5287126959381665, 0.6282718106549494, 0.9560413466441238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 346}], {
             RGBColor[
             0.3995496021231435, 0.5204711739094963, 0.9466855458786024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 384}], {
             RGBColor[
             0.6012475155961567, 0.6855340055780029, 0.9628624648765374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 398}], {
             RGBColor[
             0.696746297429305, 0.7610076864937902, 0.9687930758283795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 230}], {
             RGBColor[
             0.9722593705527938, 0.9180864844443417, 0.3467333222862512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 247}], {
             RGBColor[
             0.9413345239687156, 0.7992928035075443, 0.30199213626103877`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 289}], {
             RGBColor[
             0.9367074082562672, 0.779083085731074, 0.29817258897466137`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 302}], {
             RGBColor[
             0.981469271203516, 0.9491536419267372, 0.38251204717050646`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 323}], {
             RGBColor[
             0.9029358765369997, 0.8985069119905342, 0.6718086867166897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 340}], {
             RGBColor[
             0.9847198182906963, 0.959331532205712, 0.46205791346696695`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 288}], {
             RGBColor[
             0.25106704817739506`, 0.3812177645776751, 0.9376092690220652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 296}], {
             RGBColor[
             0.2793148229194171, 0.41090796684390285`, 0.9392179380047856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 316}], {
             RGBColor[
             0.2556938059368381, 0.38608078033623494`, 0.9378727560317908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 324}], {
             RGBColor[
             0.2685328797360218, 0.39957546094347285`, 0.9386039222909468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 355}], {
             RGBColor[
             0.24401463577453056`, 0.373805231993492, 0.9372076445688313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 375}], {
             RGBColor[
             0.2559767228165143, 0.3863781439147409, 0.9378888677295503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 380}], {
             RGBColor[
             0.2612993849996442, 0.39197259934548456`, 0.9381919854667065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 383}], {
             RGBColor[
             0.26867221560749177`, 0.39972191177879235`, 0.938611857262698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 390}], {
             RGBColor[
             0.26170368970244295`, 0.3923975492225247, 0.9382150100214157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 255}], {
             RGBColor[
             0.24955450248561023`, 0.3796279831546734, 0.9375231317825289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 266}], {
             RGBColor[
             0.24681597923856835`, 0.37674962158963, 0.9373671769348919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 294}], {
             RGBColor[
             0.22569678935260098`, 0.35455201398550057`, 0.9361644703139277]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 341}], {
             RGBColor[
             0.23010886985563692`, 0.3591893903362524, 0.9364157317714874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 368}], {
             RGBColor[
             0.2257077662103317, 0.35456355135894857`, 0.9361650954297367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 393}], {
             RGBColor[
             0.2307270128999809, 0.3598390978683905, 0.9364509341034022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 399}], {
             RGBColor[
             0.23675652181007376`, 0.36617649402584324`, 0.9367943057159729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 280}], {
             RGBColor[
             0.23696761026347307`, 0.36639836137414694`, 0.9368063268911165]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 304}], {
             RGBColor[
             0.22701022275090071`, 0.35593251576360085`, 0.9362392684029103]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 315}], {
             RGBColor[
             0.2390981188616284, 0.3686376609928552, 0.9369276562039764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 243}], {
             RGBColor[
             0.3281145647549416, 0.45673435736741674`, 0.9421971200335375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 332}], {
             RGBColor[
             0.44753939238477464`, 0.5600512043149352, 0.9502922373222444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 348}], {
             RGBColor[
             0.31540619999020275`, 0.44337706024281187`, 0.9414733974605265]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 361}], {
             RGBColor[
             0.3617418491636495, 0.4877443408967252, 0.9442708486463184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 385}], {
             RGBColor[
             0.4716391113259436, 0.5796164418313421, 0.9521894554774726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 240}], {
             RGBColor[
             0.24305133588145522`, 0.372792742729129, 0.9371527860649951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 245}], {
             RGBColor[
             0.238397504828522, 0.36790127122256505`, 0.9368877572712566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 248}], {
             RGBColor[
             0.2315520252069328, 0.36070623811179847`, 0.9364979173337866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 249}], {
             RGBColor[
             0.2582327214414536, 0.38874934150812634`, 0.9380173435137897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 309}], {
             RGBColor[
             0.25884330525935606`, 0.3893911038139919, 0.9380521153589414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 315}], {
             RGBColor[
             0.24508519381312066`, 0.3749304563693503, 0.9372686112653803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 319}], {
             RGBColor[
             0.24423991719027513`, 0.3740420170451063, 0.9372204740121839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[
             0.2410174933653264, 0.37065504529161414`, 0.937036961742502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 334}], {
             RGBColor[
             0.25414759898597045`, 0.3844556187956901, 0.9377847018333471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 371}], {
             RGBColor[
             0.25947088353624953`, 0.3900507283737679, 0.9380878550133916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 388}], {
             RGBColor[
             0.23513063549537086`, 0.3644675844219441, 0.9367017138956337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 247}], {
             RGBColor[
             0.9379323861994966, 0.7878165939520326, 0.28877547346743154`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 250}], {
             RGBColor[
             0.9785422248709081, 0.9480049704007043, 0.5891428358439234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 289}], {
             RGBColor[
             0.9333052704870481, 0.7676068761755623, 0.28495592618105414`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 358}], {
             RGBColor[
             0.9687169526811137, 0.9061370771638947, 0.3329716977842575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 391}], {
             RGBColor[
             0.8946240115133538, 0.5321742003823082, 0.2503381046492794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 234}], {
             RGBColor[
             0.3237117587462526, 0.454798867157554, 0.9418478143825956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 290}], {
             RGBColor[
             0.3569089205700484, 0.48355258019145775`, 0.9439631081789103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 313}], {
             RGBColor[
             0.295746238547153, 0.4281784264805763, 0.9401536828166841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 331}], {
             RGBColor[
             0.38038829696430865`, 0.5038892359163952, 0.9454591932807552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 359}], {
             RGBColor[
             0.2771261222266016, 0.4086075036441148, 0.9390932947382222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 235}], {
             RGBColor[
             0.6328251607154107, 0.7112978291642651, 0.965261084970727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 281}], {
             RGBColor[
             0.5787753460534887, 0.6689149253152545, 0.9599824618467317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 384}], {
             RGBColor[
             0.6369922413654878, 0.7145531842390913, 0.965676420626344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 386}], {
             RGBColor[
             0.4324598922567031, 0.5470353068857565, 0.9493188938960907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 242}], {
             RGBColor[
             0.867902536299588, 0.4245883317454004, 0.20875474200246447`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 317}], {
             RGBColor[
             0.9040426479180714, 0.5627946336685001, 0.48467433968140694`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 358}], {
             RGBColor[
             0.8930174526264201, 0.5204305413924555, 0.24838903272095686`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 366}], {
             RGBColor[
             0.8593693391869154, 0.3899082942266366, 0.20184482611558502`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 382}], {
             RGBColor[
             0.8581195774771997, 0.3842334181920808, 0.20080199431053547`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 290}], {
             RGBColor[
             0.37193655540902126`, 0.4965744830456317, 0.9449204463134487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 313}], {
             RGBColor[
             0.3107738733861259, 0.4412003293347502, 0.9411110209512226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 331}], {
             RGBColor[
             0.3954159318032815, 0.5169111387705692, 0.9464165314152937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 342}], {
             RGBColor[
             0.47104879657377785`, 0.578346581625195, 0.9523614333210206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 346}], {
             RGBColor[
             0.34188570275875485`, 0.4705459448797419, 0.9430056325554994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 275}], {
             RGBColor[
             0.8660971591696807, 0.893943749566336, 0.8776528174795629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 281}], {
             RGBColor[
             0.6860438629162344, 0.7545031690861064, 0.9694506561545053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 384}], {
             RGBColor[
             0.7442607582282336, 0.800141428009943, 0.9751446149341176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 263}], {
             RGBColor[
             0.2563029052327246, 0.3867209823153376, 0.9379074433356098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 351}], {
             RGBColor[
             0.2481333456349381, 0.37813425719806837`, 0.9374421990022963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 246}], {
             RGBColor[
             0.5111109439056949, 0.6137235569467266, 0.9547270574586124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 254}], {
             RGBColor[
             0.5239652108029346, 0.6244175883504002, 0.9556676072236672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 286}], {
             RGBColor[
             0.652334455595527, 0.7273484229582274, 0.9666519351718024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 320}], {
             RGBColor[
             0.644156525821959, 0.7209597620645476, 0.9658368355590718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 343}], {
             RGBColor[
             0.6503098019378368, 0.7257667481329021, 0.9664501366166679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 349}], {
             RGBColor[
             0.5118990860533059, 0.6144062060618112, 0.9547772771793315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 252}], {
             RGBColor[
             0.22677811637454098`, 0.3556885572456525, 0.9362260502881472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 277}], {
             RGBColor[
             0.24351796868213066`, 0.3732832033888673, 0.9371793601126722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 287}], {
             RGBColor[
             0.24471825055354252`, 0.3745447757379873, 0.9372477143895912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 293}], {
             RGBColor[
             0.22022708573500543`, 0.3488030086841681, 0.935852978784607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 299}], {
             RGBColor[
             0.22167590498284873`, 0.3503258095740973, 0.9359354868974357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 336}], {
             RGBColor[
             0.22011483416770328`, 0.34868502516977307`, 0.9358465862239105]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 367}], {
             RGBColor[
             0.2242689013320493, 0.35305121314257126`, 0.9360831542035284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 396}], {
             RGBColor[
             0.25376131131834845`, 0.3840496059649667, 0.9377627033221374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 271}], {
             RGBColor[
             0.31565140111640955`, 0.4476420700773734, 0.9413406348615612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 326}], {
             RGBColor[
             0.3319525774457105, 0.4619423709869775, 0.94237270259407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 335}], {
             RGBColor[
             0.3025165492814234, 0.4338365080010965, 0.9405926244808307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 337}], {
             RGBColor[
             0.304629125717821, 0.43605695978083275`, 0.9407129325836068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 354}], {
             RGBColor[
             0.3021441775416652, 0.43344512169287874`, 0.940571418461126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 245}], {
             RGBColor[
             0.2345526793265548, 0.3638601158439808, 0.9366688001468292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 248}], {
             RGBColor[
             0.22770719970496556`, 0.3566650827332143, 0.9362789602093593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 292}], {
             RGBColor[
             0.2251125947151853, 0.3539379883814973, 0.9361312012935654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 304}], {
             RGBColor[
             0.22915247220042573`, 0.35818415576151175`, 0.9363612663398866]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 309}], {
             RGBColor[
             0.2549984797573888, 0.3853499484354077, 0.9378331582345141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 315}], {
             RGBColor[
             0.24124036831115342`, 0.3708893009907661, 0.9370496541409528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 319}], {
             RGBColor[
             0.24039509168830792`, 0.37000086166652213`, 0.9370015168877566]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 329}], {
             RGBColor[
             0.23717266786335917`, 0.3666138899130299, 0.9368180046180745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 334}], {
             RGBColor[
             0.2503027734840032, 0.3804144634171059, 0.9375657447089196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 371}], {
             RGBColor[
             0.2556260580342823, 0.3860095729951837, 0.9378688978889642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 388}], {
             RGBColor[
             0.23128580999340365`, 0.36042642904335986`, 0.9364827567712063]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 255}], {
             RGBColor[
             0.2757184631493581, 0.40712796470319146`, 0.9390131306362182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 288}], {
             RGBColor[
             0.2679939698052205, 0.39900903243733754`, 0.9385732321676334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 339}], {
             RGBColor[
             0.32836122521249217`, 0.457187465102298, 0.9422040691120204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 360}], {
             RGBColor[
             0.3006768355928906, 0.4332086382716799, 0.9404400442858039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 374}], {
             RGBColor[
             0.2835328374534444, 0.4153413675567334, 0.939458147692505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 375}], {
             RGBColor[
             0.2729036444443398, 0.40416941177440335`, 0.9388528308751185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 399}], {
             RGBColor[
             0.2629204824738216, 0.3936764755743613, 0.938284304569662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 256}], {
             RGBColor[
             0.5718276027056971, 0.5340616080097416, 0.5946502523941279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 257}], {
             RGBColor[
             0.8704770048155868, 0.4443768248986645, 0.21122005596083127`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 268}], {
             RGBColor[
             0.8678329199624942, 0.4240532300724246, 0.2086880773194431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 317}], {
             RGBColor[
             0.954486951543472, 0.8521857620679489, 0.5290777523178287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 333}], {
             RGBColor[
             0.5569536477379948, 0.5184281382754727, 0.5938032026627618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 381}], {
             RGBColor[
             0.9557469344850966, 0.8527067973943953, 0.5081965742437817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 382}], {
             RGBColor[
             0.9085638811026002, 0.6736245465915296, 0.24520540694695725`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 348}], {
             RGBColor[
             0.27566358738232355`, 0.40707028679271356`, 0.9390100055424669]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 351}], {
             RGBColor[
             0.26705822161415743`, 0.39802550175866824`, 0.9385199426924677]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 253}], {
             RGBColor[
             0.30087597692201773`, 0.4305218254587764, 0.9405574263390588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 270}], {
             RGBColor[
             0.2548116613836774, 0.3851535904796679, 0.9378225192045042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 308}], {
             RGBColor[
             0.2605622771689302, 0.3911978522800683, 0.9381500082662007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 397}], {
             RGBColor[
             0.2546928621186111, 0.3850287249197748, 0.9378157537621064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 248}], {
             RGBColor[
             0.2230533686520324, 0.3517736112266503, 0.9360139314156208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 292}], {
             RGBColor[
             0.2204587636622521, 0.3490465168749334, 0.935866172499827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 304}], {
             RGBColor[
             0.22449864114749254`, 0.35329268425494775`, 0.9360962375461481]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 315}], {
             RGBColor[
             0.23658653725822024`, 0.3659978294842021, 0.9367846253472143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 319}], {
             RGBColor[
             0.2357412606353747, 0.36510939015995814`, 0.9367364880940181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 329}], {
             RGBColor[
             0.232518836810426, 0.36172241840646596`, 0.936552975824336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 353}], {
             RGBColor[
             0.220139248365585, 0.34871068603969635`, 0.9358479765763623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 371}], {
             RGBColor[
             0.25097222698134913`, 0.38111810148861974`, 0.9376038690952258]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 378}], {
             RGBColor[
             0.2192126419789341, 0.3477367639770881, 0.9357952077134337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 388}], {
             RGBColor[
             0.22663197894047044`, 0.3555349575367959, 0.9362177279774678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 254}], {
             RGBColor[
             0.4566571232556863, 0.569515492226385, 0.9504402532261262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 286}], {
             RGBColor[
             0.5850263680482788, 0.6724463268342122, 0.9614245811742612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 320}], {
             RGBColor[
             0.5768484382747107, 0.6660576659405324, 0.9606094815615308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 343}], {
             RGBColor[
             0.5830017143905886, 0.6708646520088869, 0.9612227826191269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 344}], {
             RGBColor[
             0.3822157528613575, 0.505477807231359, 0.9455754276855741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 349}], {
             RGBColor[
             0.44459099850605766`, 0.559504109937796, 0.9495499231817904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 289}], {
             RGBColor[
             0.9023804239029701, 0.648813195238765, 0.2402147401558417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 302}], {
             RGBColor[
             0.9471422868502191, 0.8188837514344283, 0.3245541983516868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 340}], {
             RGBColor[
             0.9503928339373993, 0.8290616417134029, 0.4041000646481473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 391}], {
             RGBColor[
             0.8636991649292758, 0.4133805194455108, 0.20559691862406698`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 292}], {
             RGBColor[
             0.21361328404066288`, 0.34185148376416674`, 0.935476332562357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 304}], {
             RGBColor[
             0.2176531615259033, 0.3460976511441812, 0.9357063976086782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 315}], {
             RGBColor[
             0.229741057636631, 0.35880279637343554`, 0.9363947854097444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 319}], {
             RGBColor[
             0.2288957810137855, 0.3579143570491916, 0.9363466481565481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 329}], {
             RGBColor[
             0.22567335718883677`, 0.3545273852956994, 0.9361631358868661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 353}], {
             RGBColor[
             0.21329376874399575`, 0.34151565292892977`, 0.9354581366388923]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 388}], {
             RGBColor[
             0.21978649931888122`, 0.34833992442602935`, 0.935827888039998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 270}], {
             RGBColor[
             0.25957821450255336`, 0.3901635400245296, 0.9380939673531408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 308}], {
             RGBColor[
             0.2653288302878062, 0.39620780182492993`, 0.9384214564148372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 309}], {
             RGBColor[
             0.2701798653173872, 0.40130654721440506`, 0.9386977156833087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 334}], {
             RGBColor[
             0.2654841590440016, 0.39637106219610324`, 0.9384303021577143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 386}], {
             RGBColor[
             0.3044662110801129, 0.4345129066433197, 0.9407539204836926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 397}], {
             RGBColor[
             0.25945941523748706`, 0.39003867446463636`, 0.938087201910743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 265}], {
             RGBColor[
             0.7900609571838799, 0.8344827358393506, 0.9028921387192244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 276}], {
             RGBColor[
             0.8768966809261312, 0.9030925119563854, 0.9110185744810039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 289}], {
             RGBColor[
             0.9429902625743816, 0.8090015716874366, 0.5405821025323335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 391}], {
             RGBColor[
             0.9043090036006871, 0.5735688958941825, 0.5059642810005588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 282}], {
             RGBColor[
             0.7345888082776114, 0.7926044746200289, 0.9741756038265081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 312}], {
             RGBColor[
             0.6426365090387243, 0.7180224324379316, 0.9668896222215277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 356}], {
             RGBColor[
             0.6703471241239707, 0.7405191581131181, 0.9690711033483659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 277}], {
             RGBColor[
             0.2410729775793306, 0.3707133627184349, 0.9370401214864079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 293}], {
             RGBColor[
             0.21778209463220533`, 0.3462331680137357, 0.9357137401583427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 330}], {
             RGBColor[
             0.2245525377985933, 0.3533493330524997, 0.9360993068806954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 386}], {
             RGBColor[
             0.3405394596215219, 0.4693798967384182, 0.942919851133231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 286}], {
             RGBColor[
             0.5978806349455185, 0.6831403582378857, 0.9623651309393161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 320}], {
             RGBColor[
             0.5897027051719504, 0.6767516973442059, 0.9615500313265857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 343}], {
             RGBColor[
             0.5958559812878284, 0.6815586834125604, 0.9621633323841816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 344}], {
             RGBColor[
             0.39507001975859724`, 0.5161718386350326, 0.946515977450629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 349}], {
             RGBColor[
             0.45744526540329744`, 0.5701981413414695, 0.9504904729468453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 288}], {
             RGBColor[
             0.25275048461760563`, 0.38298716301237146`, 0.9377051382369141]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 341}], {
             RGBColor[
             0.24102934533176992`, 0.3706675024598044, 0.9370376366944575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 360}], {
             RGBColor[
             0.28543335040527573`, 0.4171867688467138, 0.9395719503550848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 374}], {
             RGBColor[
             0.2682893522658295, 0.3993194981317673, 0.938590053761786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 393}], {
             RGBColor[
             0.2416474883761139, 0.3713172099919425, 0.9370728390263723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 399}], {
             RGBColor[
             0.24767699728620676`, 0.3776546061493952, 0.937416210638943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 261}], {
             RGBColor[
             0.20237836752934693`, 0.3300428741759244, 0.934836520687607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 264}], {
             RGBColor[
             0.2076696899760163, 0.3356043895565939, 0.9351378536731348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 317}], {
             RGBColor[
             0.6079677143241806, 0.6722679099328412, 0.8705698500730703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 333}], {
             RGBColor[
             0.21043441051870343`, 0.338510286140365, 0.9352953004180034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 381}], {
             RGBColor[
             0.6092276972658053, 0.6727889452592876, 0.8496886719990233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 268}], {
             RGBColor[
             0.8199630848530925, 0.15445059482623982`, 0.16674997864138813`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 338}], {
             RGBColor[
             0.9084477718580719, 0.5824829620653897, 0.3944924501077937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 381}], {
             RGBColor[
             0.9078770993756948, 0.5831041621482105, 0.46625847556572675`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 382}], {
             RGBColor[
             0.8606940459931985, 0.4040219113453448, 0.20326730826890227`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 278}], {
             RGBColor[
             0.25267444257649463`, 0.38290723800581994`, 0.937700807755167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 284}], {
             RGBColor[
             0.24846567575091127`, 0.3784835572209025, 0.9374611247107626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 369}], {
             RGBColor[
             0.2551936052438994, 0.3855550376934007, 0.9378442703423086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 392}], {
             RGBColor[
             0.25044123686096187`, 0.3805599972053746, 0.9375736299933992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 274}], {
             RGBColor[
             0.22087433163626, 0.34948330516414705`, 0.9358898384811689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 299}], {
             RGBColor[
             0.21257469635649348`, 0.34075986225784227`, 0.9354171865301963]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 318}], {
             RGBColor[
             0.2174190793227137, 0.34585161590696, 0.9356930669735002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 336}], {
             RGBColor[
             0.21101362554134806`, 0.339119077853518, 0.9353282858566712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 367}], {
             RGBColor[
             0.21516769270569408`, 0.3434852658263162, 0.935564853836289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 267}], {
             RGBColor[
             0.6900764896095811, 0.7567221842679797, 0.9704893279445472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 272}], {
             RGBColor[
             0.7279854810242253, 0.7874270577614837, 0.9735224474035349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 291}], {
             RGBColor[
             0.7527228069990448, 0.8067520448236535, 0.9759880328732503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 321}], {
             RGBColor[
             0.813370248803728, 0.8541302872991015, 0.9820328030897745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 338}], {
             RGBColor[
             0.9016212039882432, 0.9204360205910522, 0.8006477894997438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 342}], {
             RGBColor[
             0.706156116764429, 0.7697763499712335, 0.9717551750957918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 384}], {
             RGBColor[
             0.7786909364224193, 0.827038544894287, 0.9785762933282055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 398}], {
             RGBColor[
             0.8741897182555676, 0.9025122258100744, 0.9845069042800476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 264}], {
             RGBColor[
             0.1847396920189574, 0.3115035078578844, 0.9338320242113725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 295}], {
             RGBColor[
             0.2109178597842839, 0.3390184219709439, 0.935322832138479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 310}], {
             RGBColor[
             0.18101326007132248`, 0.3075867916114884, 0.9336198094247166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 381}], {
             RGBColor[
             0.5862976993087463, 0.6486880635605781, 0.8483828425372609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 269}], {
             RGBColor[
             0.965850894705439, 0.9706613010892211, 0.7373156259818411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 298}], {
             RGBColor[
             0.8810364966451805, 0.9079026895445534, 0.9858832537094278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 300}], {
             RGBColor[
             0.9143198191766551, 0.7735717057130247, 0.6093343830407926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 306}], {
             RGBColor[
             0.9545094880958191, 0.9327471750686342, 0.664081522635275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 307}], {
             RGBColor[
             0.9619414175862754, 0.970962445386637, 0.9415105792405329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 314}], {
             RGBColor[
             0.9322274207027686, 0.9487209428474576, 0.9907658897447179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 310}], {
             RGBColor[
             0.18630458251799184`, 0.3131483069921579, 0.9339211424102444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 333}], {
             RGBColor[
             0.19279573500831393`, 0.31997091982232506`, 0.9342908039417687]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 381}], {
             RGBColor[
             0.5915890217554157, 0.6542495789412477, 0.8486841755227887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 322}], {
             RGBColor[
             0.5501554119867256, 0.6456799735265193, 0.9577293957987232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 362}], {
             RGBColor[
             0.4982768620774518, 0.6022414244020411, 0.9540103792474512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 273}], {
             RGBColor[
             0.265217664230201, 0.3960909592500517, 0.938415125672312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 365}], {
             RGBColor[
             0.25561932448523794`, 0.3860024956082064, 0.9378685144233075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 272}], {
             RGBColor[
             0.6091079366672787, 0.6934689353256587, 0.9624191392814057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 291}], {
             RGBColor[
             0.6338452626420983, 0.7127939223878283, 0.964884724751121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 321}], {
             RGBColor[
             0.6944927044467815, 0.7601721648632764, 0.9709294949676452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 331}], {
             RGBColor[
             0.511645707636986, 0.6143827846807824, 0.9547069650679356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 342}], {
             RGBColor[
             0.5872785724074823, 0.6758182275354083, 0.9606518669736626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 346}], {
             RGBColor[
             0.4581154785924594, 0.5680175907899552, 0.9512960662081413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 384}], {
             RGBColor[
             0.6598133920654725, 0.7330804224584619, 0.9674729852060762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 398}], {
             RGBColor[
             0.7553121738986209, 0.8085541033742493, 0.9734035961579184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 338}], {
             RGBColor[
             0.9058036870049794, 0.5621593672391498, 0.39196047146640556`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 381}], {
             RGBColor[
             0.9052330145226024, 0.5627805673219706, 0.46372649692433865`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 279}], {
             RGBColor[
             0.9693542844710024, 0.9048940200148108, 0.380506034096984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 298}], {
             RGBColor[
             0.908244530929823, 0.9248034643520736, 0.7344530675019115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 300}], {
             RGBColor[
             0.9415278534612976, 0.7904724805205449, 0.35790419683327634`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 306}], {
             RGBColor[
             0.9817175223804617, 0.9496479498761543, 0.4126513364277588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 307}], {
             RGBColor[
             0.9891494518709179, 0.9878632201941573, 0.6900803930330166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 314}], {
             RGBColor[
             0.9594354549874111, 0.9656217176549777, 0.7393357035372017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 308}], {
             RGBColor[
             0.2553377632908749, 0.38570655694091993`, 0.9378524799298211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 397}], {
             RGBColor[
             0.2494683482405557, 0.3795374295806264, 0.9375182254257268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 273}], {
             RGBColor[
             0.2911126400044641, 0.42330822062509427`, 0.9398898062344726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 326}], {
             RGBColor[
             0.3230890593454866, 0.4540841958078278, 0.941814555867055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 335}], {
             RGBColor[
             0.2936530311811995, 0.4259783328219468, 0.9400344777538158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 394}], {
             RGBColor[
             0.3328279171819992, 0.4625195049765876, 0.9424351072766638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 291}], {
             RGBColor[
             0.6717542540567425, 0.7434987958813325, 0.9679178442101087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 321}], {
             RGBColor[
             0.7324016958614257, 0.7908770383567805, 0.9739626144266329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 331}], {
             RGBColor[
             0.5495546990516302, 0.6450876581742866, 0.9577400845269233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 338}], {
             RGBColor[
             0.8206526510459409, 0.8571827716487312, 0.7925776008366022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 342}], {
             RGBColor[
             0.6251875638221265, 0.7065231010289125, 0.9636849864326502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 346}], {
             RGBColor[
             0.4960244700071036, 0.5987224642834593, 0.954329185667129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 384}], {
             RGBColor[
             0.6977223834801167, 0.763785295951966, 0.9705061046650639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 398}], {
             RGBColor[
             0.7932211653132651, 0.8392589768677534, 0.976436715616906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 365}], {
             RGBColor[
             0.26583905724777945`, 0.3967440827101195, 0.9384505130853945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 394}], {
             RGBColor[
             0.3171526741702776, 0.4460438307034582, 0.9415424253765902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 287}], {
             RGBColor[
             0.2454706833388167, 0.37533563030230443`, 0.937290564323588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 299}], {
             RGBColor[
             0.22242833776812287`, 0.35111666413841447`, 0.9359783368314325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 318}], {
             RGBColor[
             0.2272727207343431, 0.3562084177875322, 0.9362542172747363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 367}], {
             RGBColor[
             0.22502133411732347`, 0.3538420677068884, 0.9361260041375251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 373}], {
             RGBColor[
             0.24052488712014738`, 0.3701372848948911, 0.9370089085455846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 395}], {
             RGBColor[
             0.2518980358087536, 0.3820911852658918, 0.9376565925383351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 279}], {
             RGBColor[
             0.9688751403565641, 0.9066136951652177, 0.5278514920501343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 281}], {
             RGBColor[
             0.8120473445077586, 0.8515608457173255, 0.8723741943555676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 306}], {
             RGBColor[
             0.9812383782660234, 0.9513676250265612, 0.559996794380909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 338}], {
             RGBColor[
             0.9931945073855819, 0.9905965803379274, 0.7001396493067182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 384}], {
             RGBColor[
             0.8702642398197578, 0.8971991046411623, 0.8780681531351799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 322}], {
             RGBColor[
             0.6369911357289768, 0.7142897496435541, 0.9658558315605028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 358}], {
             RGBColor[
             0.8670714087363368, 0.8612246187195758, 0.654847436421338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 376}], {
             RGBColor[
             0.6019797217390458, 0.6854606658855094, 0.9632115739949887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 377}], {
             RGBColor[
             0.590222766132432, 0.6752773818608311, 0.9624624311800029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 287}], {
             RGBColor[
             0.25901311175833214`, 0.3895695812107696, 0.9380617855878519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 330}], {
             RGBColor[
             0.24129239010618297`, 0.3709439791957144, 0.9370526167052204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 396}], {
             RGBColor[
             0.26805617252313807`, 0.399074411437749, 0.9385767745203981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 284}], {
             RGBColor[
             0.24820685681048946`, 0.3782115221044505, 0.9374463853549939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 327}], {
             RGBColor[
             0.28550387867049365`, 0.4165027145117478, 0.9396037276662406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 337}], {
             RGBColor[
             0.26857947792754067`, 0.39962443859725516`, 0.9386065759890179]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 354}], {
             RGBColor[
             0.2660945297513849, 0.3970126005093012, 0.9384650618665371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 392}], {
             RGBColor[
             0.2501824179205401, 0.3802879620889227, 0.9375588906376304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 300}], {
             RGBColor[
             0.9178232089422185, 0.7078044246386144, 0.2525247911559355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 306}], {
             RGBColor[
             0.9580128778613826, 0.8669798939942239, 0.307271930750418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 363}], {
             RGBColor[
             0.9040810668165558, 0.6454045668048165, 0.24105801091555495`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 384}], {
             RGBColor[
             0.6902109435663115, 0.7577585241609326, 0.9698659918101223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 386}], {
             RGBColor[
             0.4856785944575267, 0.5902406468075978, 0.9535084650798691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 350}], {
             RGBColor[
             0.5398022619922347, 0.6366471769552697, 0.9571158788344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 369}], {
             RGBColor[
             0.25072601947789425`, 0.3808593217920313, 0.9375898479421354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 392}], {
             RGBColor[
             0.24597365109495675`, 0.3758642813040053, 0.9373192075932261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 330}], {
             RGBColor[
             0.23174352854992997`, 0.3609075202673017, 0.9365088231658666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 387}], {
             RGBColor[
             0.2661419288540897, 0.3970624199715206, 0.9384677611753156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 320}], {
             RGBColor[
             0.7180719499645429, 0.7796825319520332, 0.9725343592747207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 343}], {
             RGBColor[
             0.7242252260804207, 0.7844895180203877, 0.9731476603323168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 349}], {
             RGBColor[
             0.5858145101958898, 0.6731289759492968, 0.9614748008949803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 367}], {
             RGBColor[
             0.23976404440825078`, 0.3693375909644736, 0.936965579678708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 373}], {
             RGBColor[
             0.2552675974110747, 0.3856328081524763, 0.9378484840867676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 395}], {
             RGBColor[
             0.2666407460996809, 0.397586708523477, 0.938496168079518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 396}], {
             RGBColor[
             0.2692564543945499, 0.400335983786869, 0.9386451287973171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 341}], {
             RGBColor[
             0.2333048519876323, 0.3625485701939505, 0.9365977382258728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 355}], {
             RGBColor[
             0.2379735788706035, 0.36745569816233453`, 0.9368636153150954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 360}], {
             RGBColor[
             0.2777088570611381, 0.4090678365808599, 0.9391320518865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 374}], {
             RGBColor[
             0.26056485892169184`, 0.3912005658659134, 0.9381501552932011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 375}], {
             RGBColor[
             0.24993566591258726`, 0.38002861008358335`, 0.9375448384758145]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 379}], {
             RGBColor[
             0.23299167582952007`, 0.3622194021952592, 0.9365799033069708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 393}], {
             RGBColor[
             0.23392299503197628`, 0.3631982777260886, 0.9366329405577875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 399}], {
             RGBColor[
             0.23995250394206913`, 0.3695356738835413, 0.9369763121703581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 302}], {
             RGBColor[
             0.9425151711377706, 0.798674033657958, 0.3207346510653094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 340}], {
             RGBColor[
             0.9457657182249508, 0.8088519239369327, 0.40028051736176995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 391}], {
             RGBColor[
             0.8590720492168273, 0.39317080166904056`, 0.2017773713376896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 313}], {
             RGBColor[
             0.34397103520992167`, 0.4699540423686539, 0.9432263147475373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 321}], {
             RGBColor[
             0.6114600904368728, 0.6914542319869668, 0.964754355111318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 331}], {
             RGBColor[
             0.42861309362707734`, 0.5456648518044729, 0.9485318252116084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 342}], {
             RGBColor[
             0.5042459583975736, 0.6071002946590989, 0.9544767271173353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 346}], {
             RGBColor[
             0.3750828645825507, 0.4992996579136456, 0.9451209263518141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 321}], {
             RGBColor[
             0.7571390218362452, 0.8102020254189503, 0.9764281998963484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 331}], {
             RGBColor[
             0.5742920250264498, 0.6644126452364563, 0.9602056699966387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 338}], {
             RGBColor[
             0.8453899770207604, 0.8765077587109009, 0.7950431863063177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 342}], {
             RGBColor[
             0.6499248897969461, 0.7258480880910823, 0.9661505719023658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 384}], {
             RGBColor[
             0.7224597094549363, 0.7831102830141358, 0.9729716901347794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 398}], {
             RGBColor[
             0.8179584912880846, 0.8585839639299231, 0.9789023010866215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 304}], {
             RGBColor[
             0.21505855653612305`, 0.3433705567924642, 0.9355586386928844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 329}], {
             RGBColor[
             0.22307875219905648`, 0.35180029094398246`, 0.9360153769710722]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 353}], {
             RGBColor[
             0.2106991637542155, 0.3387885585772128, 0.9353103777230984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 378}], {
             RGBColor[
             0.20977255736756456`, 0.3378146365146045, 0.93525760886017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 388}], {
             RGBColor[
             0.21719189432910094`, 0.3456128300743124, 0.9356801291242041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 299}], {
             RGBColor[
             0.21267988324051307`, 0.34087042034218046`, 0.9354231767676313]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 330}], {
             RGBColor[
             0.21800150715905772`, 0.3464637844910152, 0.9357262353771553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 336}], {
             RGBColor[
             0.21111881242536762`, 0.33922963593785627`, 0.935334276094106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 341}], {
             RGBColor[
             0.21717163219876068`, 0.3455915332906315, 0.9356789752258563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 368}], {
             RGBColor[
             0.21277052855345546`, 0.3409656943133277, 0.9354283388841056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 393}], {
             RGBColor[
             0.21778977524310467`, 0.34624124082276975`, 0.9357141775577711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 310}], {
             RGBColor[
             0.2124827502833183, 0.3406632211052174, 0.935411950337351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 345}], {
             RGBColor[
             0.22216737223106828`, 0.3508423728127994, 0.9359634752301611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 363}], {
             RGBColor[
             0.5524499218387339, 0.42033901047071287`, 0.5720521832312901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 316}], {
             RGBColor[
             0.27790052377493313`, 0.40942144877130526`, 0.9391373957607753]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 324}], {
             RGBColor[
             0.2907395975741168, 0.42291612937854317`, 0.9398685620199312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 360}], {
             RGBColor[
             0.3059566318031602, 0.4387580388470877, 0.9407407208692202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 374}], {
             RGBColor[
             0.2888126336637139, 0.4208907681321412, 0.9397588242759214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 375}], {
             RGBColor[
             0.2781834406546093, 0.40971881234981117`, 0.9391535074585348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 380}], {
             RGBColor[
             0.28350610283773925`, 0.41531326778055483`, 0.939456625195691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 383}], {
             RGBColor[
             0.2908789334455868, 0.4230625802138626, 0.9398764969916824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 390}], {
             RGBColor[
             0.283910407540538, 0.415738217657595, 0.9394796497504001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 307}], {
             RGBColor[
             0.965939497584164, 0.9739442069028073, 0.9347428726703746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 314}], {
             RGBColor[
             0.9362255007006572, 0.9517027043636277, 0.9839981831745597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 332}], {
             RGBColor[
             0.736930313911651, 0.7933926635631983, 0.9655671808709663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 352}], {
             RGBColor[
             0.970396577990795, 0.974814330666099, 0.7901511578367646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 385}], {
             RGBColor[
             0.76103003285282, 0.8129579010796052, 0.9674643990261943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 306}], {
             RGBColor[
             0.8969031243202032, 0.8868893383314866, 0.6612189641553454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 307}], {
             RGBColor[
             0.9043350538106595, 0.9251046086494896, 0.9386480207606034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 314}], {
             RGBColor[
             0.8746210569271528, 0.9028631061103101, 0.9879033312647884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 336}], {
             RGBColor[
             0.2125676316732109, 0.34075243682778544`, 0.9354167842069347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 367}], {
             RGBColor[
             0.21672169883755696`, 0.34511862480058364`, 0.9356533521865525]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 306}], {
             RGBColor[
             0.9301864468516778, 0.7525583544999579, 0.2846700934867103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 307}], {
             RGBColor[
             0.9376183763421341, 0.7907736248179609, 0.5620991500919681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 314}], {
             RGBColor[
             0.9079043794586273, 0.7685321222787813, 0.6113544605961532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 363}], {
             RGBColor[
             0.8762546358068509, 0.5309830273105506, 0.21845617365184725`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 316}], {
             RGBColor[
             0.2555487063727525, 0.3859282714945373, 0.9378644928262717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 324}], {
             RGBColor[
             0.2683877801719362, 0.39942295210177514`, 0.9385956590854276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 372}], {
             RGBColor[
             0.25414770566980416`, 0.3844557309271635, 0.9377847079088335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 380}], {
             RGBColor[
             0.26115428543555863`, 0.39182009050378686`, 0.9381837222611874]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 383}], {
             RGBColor[
             0.2685271160434062, 0.39956940293709464`, 0.9386035940571789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 390}], {
             RGBColor[
             0.26155859013835736`, 0.392245040380827, 0.9382067468158966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 323}], {
             RGBColor[
             0.9087436394185031, 0.9180978599174181, 0.6943707488073377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 340}], {
             RGBColor[
             0.9905275811721996, 0.978922480132596, 0.484619975557615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 313}], {
             RGBColor[
             0.2862100467675046, 0.4181552842906852, 0.9396106108023645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 344}], {
             RGBColor[
             0.3051201948561256, 0.4369324167818024, 0.9407277420647475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 315}], {
             RGBColor[
             0.23118633013209117`, 0.360321869401733, 0.9364770915402718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 329}], {
             RGBColor[
             0.2271186296842969, 0.35604645832399684`, 0.9362454420173936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 353}], {
             RGBColor[
             0.21473904123945592`, 0.3430347259572272, 0.9355404427694197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 378}], {
             RGBColor[
             0.21381243485280502`, 0.34206080389461896`, 0.9354876739064912]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 325}], {
             RGBColor[
             0.20723516257555488`, 0.3351476737080805, 0.9351131079805042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 314}], {
             RGBColor[
             0.9555259778682477, 0.9659228619523936, 0.9435306567958934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 352}], {
             RGBColor[
             0.9896970551583855, 0.989034488254865, 0.7496836314580985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 385}], {
             RGBColor[
             0.7803305100204103, 0.8271780586683711, 0.9269968726475282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 386}], {
             RGBColor[
             0.30022575986843436`, 0.4300559235597101, 0.9405124330603728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 397}], {
             RGBColor[
             0.25521896402580857`, 0.3855816913810268, 0.9378457144874233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 319}], {
             RGBColor[
             0.25618706106620875`, 0.38659922275138503`, 0.9379008461817029]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 329}], {
             RGBColor[
             0.25296463724126, 0.3832122509978928, 0.9377173339120208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 334}], {
             RGBColor[
             0.26609474286190404`, 0.39701282450196873`, 0.9384650740028659]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 371}], {
             RGBColor[
             0.2714180274121831, 0.4026079340800466, 0.9387682271829105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 386}], {
             RGBColor[
             0.30507679489801537`, 0.4351546689491852, 0.9407886923288442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 345}], {
             RGBColor[
             0.19226277251810686`, 0.3194107424533439, 0.9342604525163987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 363}], {
             RGBColor[
             0.5225453221257725, 0.38890738011125736`, 0.5703491605175277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 323}], {
             RGBColor[
             0.6747921418079339, 0.7440706990607763, 0.9694867808520644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 339}], {
             RGBColor[
             0.4425672704759462, 0.555957682108388, 0.9499165435038557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 327}], {
             RGBColor[
             0.39077465425622554`, 0.5126293712413812, 0.9461931090416965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 356}], {
             RGBColor[
             0.4906677898927829, 0.5973852420238213, 0.9530463122771483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 361}], {
             RGBColor[
             0.40929184788600736`, 0.528668033662285, 0.9473730082456748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 344}], {
             RGBColor[
             0.30171850127564737`, 0.43335702114888963`, 0.940534020647694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 359}], {
             RGBColor[
             0.2641882368664749, 0.39500896582131095`, 0.9383565013068491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 385}], {
             RGBColor[
             0.7506165131369036, 0.8049365561291917, 0.9762521831517132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 319}], {
             RGBColor[
             0.24242894961997336`, 0.37213857530674344`, 0.9371173420881417]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 329}], {
             RGBColor[
             0.2392065257950246, 0.3687516035532512, 0.9369338298184597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 334}], {
             RGBColor[
             0.25233663141566864`, 0.38255217705732714`, 0.9376815699093048]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 371}], {
             RGBColor[
             0.25765991596594773`, 0.388147286635405, 0.9379847230893494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 324}], {
             RGBColor[
             0.2671185805915378, 0.39808894287087526`, 0.9385233800469365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 355}], {
             RGBColor[
             0.2426003366300466, 0.37231871392089444`, 0.937127102324821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 380}], {
             RGBColor[
             0.25988508585516024`, 0.3904860812728869, 0.9381114432226962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 383}], {
             RGBColor[
             0.2672579164630078, 0.3982353937061947, 0.9385313150186878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 390}], {
             RGBColor[
             0.26028939055795897`, 0.3909110311499271, 0.9381344677774055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 333}], {
             RGBColor[
             0.5930937593564782, 0.6566344401985723, 0.8697228003417041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 370}], {
             RGBColor[
             0.9109218435003366, 0.9293228266692952, 0.8943803638429948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 381}], {
             RGBColor[
             0.99188704610358, 0.9909130993174948, 0.7841161719227241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 382}], {
             RGBColor[
             0.9447039927210837, 0.8118308485146293, 0.5211250046258997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 367}], {
             RGBColor[
             0.22156608180377718`, 0.3502103784497014, 0.9359292326298564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 373}], {
             RGBColor[
             0.2370696348066011, 0.3665055956377041, 0.9368121370379159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 329}], {
             RGBColor[
             0.2383612491721791, 0.3678631642290072, 0.9368856925652633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 334}], {
             RGBColor[
             0.25149135479282314`, 0.3816637377330832, 0.9376334326561084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 371}], {
             RGBColor[
             0.2568146393431022, 0.387258847311161, 0.937936585836153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 388}], {
             RGBColor[
             0.23247439130222355`, 0.3616757033593372, 0.9365504447183952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 343}], {
             RGBColor[
             0.7160472963068527, 0.7781008571267078, 0.9723325607195863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 349}], {
             RGBColor[
             0.5776365804223218, 0.666740315055617, 0.9606597012822499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 331}], {
             RGBColor[
             0.634939466831133, 0.7117908877119044, 0.9662504402131629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 338}], {
             RGBColor[
             0.9060374188254435, 0.923886001186349, 0.8010879565228419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 342}], {
             RGBColor[
             0.7105723316016292, 0.7732263305665302, 0.9721953421188899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 384}], {
             RGBColor[
             0.7831071512596195, 0.8304885254895837, 0.9790164603513036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 398}], {
             RGBColor[
             0.8786059330927678, 0.9059622064053712, 0.9849470713031456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 328}], {
             RGBColor[
             0.4089266558730876, 0.5271174055758985, 0.947690784031411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 362}], {
             RGBColor[
             0.45653757665465905`, 0.5683555921624378, 0.9507245098029286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 364}], {
             RGBColor[
             0.428972946302528, 0.5444804947900268, 0.9489681159313363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 340}], {
             RGBColor[
             0.9119941865056833, 0.9282757501963927, 0.7739166151037982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 375}], {
             RGBColor[
             0.267401497471214, 0.3983863064493811, 0.938539491744696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 380}], {
             RGBColor[
             0.27272415965434393`, 0.4039807618801248, 0.9388426094818522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 383}], {
             RGBColor[
             0.2800969902621915, 0.41173007431343256`, 0.9392624812778436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 390}], {
             RGBColor[
             0.27312846435714266`, 0.404405711757165, 0.9388656340365613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 335}], {
             RGBColor[
             0.3099542075105004, 0.4402786337315509, 0.9410665454863245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 337}], {
             RGBColor[
             0.312066783946898, 0.44249908551128714`, 0.9411868535891006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 354}], {
             RGBColor[
             0.3095818357707423, 0.4398872474233331, 0.94104533946662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 337}], {
             RGBColor[
             0.3016677329619616, 0.43349195021963505`, 0.9405242352558603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 354}], {
             RGBColor[
             0.2991827847858058, 0.430880112131681, 0.9403827211333795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 356}], {
             RGBColor[
             0.4184852693414719, 0.5351260969165677, 0.9483745901685348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 392}], {
             RGBColor[
             0.28327067295496094`, 0.4141554737113025, 0.9394765499044728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 347}], {
             RGBColor[
             0.29474363512034735`, 0.42706072191761096`, 0.940098925902251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 362}], {
             RGBColor[
             0.35704810596381387`, 0.4836788564514203, 0.9439717674801389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 372}], {
             RGBColor[
             0.2804573452843499, 0.4120449254968854, 0.9392853428307628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 387}], {
             RGBColor[
             0.30150296805800375`, 0.4341652094015489, 0.9404838599135137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 334}], {
             RGBColor[
             0.2482689309678744, 0.37827676597959103`, 0.9374499203864265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 353}], {
             RGBColor[
             0.22275923690238936`, 0.35146446010874544`, 0.9359971810476075]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 371}], {
             RGBColor[
             0.25359221551815353`, 0.38387187555766883`, 0.9377530735664711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 388}], {
             RGBColor[
             0.22925196747727483`, 0.358288731605845, 0.9363669324487132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 342}], {
             RGBColor[
             0.5277253347918338, 0.6274369503840362, 0.9559728122191802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 346}], {
             RGBColor[
             0.3985622409768109, 0.5196363136385831, 0.946617011453659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 361}], {
             RGBColor[
             0.4414240641856033, 0.5547544143941453, 0.9499025740169657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 385}], {
             RGBColor[
             0.5513213263478973, 0.6466265153287621, 0.9578211808481198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 381}], {
             RGBColor[
             0.5943537422981029, 0.6571554755250186, 0.8488416222676571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 371}], {
             RGBColor[
             0.26672232113879757`, 0.3976724490617448, 0.9385008136573162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 388}], {
             RGBColor[
             0.24238207309791887`, 0.372089305109921, 0.9371146725395583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 337}], {
             RGBColor[
             0.282630755782611, 0.41439322252540617`, 0.9394067754758614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 354}], {
             RGBColor[
             0.28014580760645524`, 0.41178138443745216`, 0.9392652613533807]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 367}], {
             RGBColor[
             0.21516062802241154`, 0.34347784039625945`, 0.9355644515130273]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 354}], {
             RGBColor[
             0.28225838404285286`, 0.4140018362171884, 0.9393855694561568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 384}], {
             RGBColor[
             0.8713581064441347, 0.8967942587815345, 0.7976314467612728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 398}], {
             RGBColor[
             0.966856888277283, 0.9722679396973218, 0.803562057713115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 360}], {
             RGBColor[
             0.3380761124684098, 0.46724626924582036`, 0.942762888830887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 374}], {
             RGBColor[
             0.3209321143289635, 0.44937899853087393`, 0.9417809922375882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 368}], {
             RGBColor[
             0.2171826090564914, 0.3456030706640795, 0.9356796003416652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 379}], {
             RGBColor[
             0.2212705365436844, 0.3498997416426921, 0.9359124017645142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 393}], {
             RGBColor[
             0.2222018557461406, 0.35087861717352153`, 0.9359654390153307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 399}], {
             RGBColor[
             0.22823136465623345`, 0.3572160133309742, 0.9363088106279014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 346}], {
             RGBColor[
             0.4741951057473072, 0.5810717564932091, 0.9525619133593859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 398}], {
             RGBColor[
             0.7713918010534688, 0.8216082690775031, 0.9746694433091629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 349}], {
             RGBColor[
             0.5837898565381997, 0.6715473011239714, 0.9612730023398459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 349}], {
             RGBColor[
             0.3830038950089686, 0.5061604563464437, 0.9456256474062932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 362}], {
             RGBColor[
             0.3423545559019188, 0.4682989085041503, 0.9431326516737686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 372}], {
             RGBColor[
             0.26576379522245486`, 0.3966649775496154, 0.9384462270243925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 387}], {
             RGBColor[
             0.2868094179961087, 0.41878526145427897`, 0.9396447441071433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 351}], {
             RGBColor[
             0.2543498568494185, 0.38466820463406326`, 0.9377962201194567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 369}], {
             RGBColor[
             0.2602045857942335, 0.3908218959663191, 0.9381296382715687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 357}], {
             RGBColor[
             0.5542164267531839, 0.6479076320182329, 0.9585525480697432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 394}], {
             RGBColor[
             0.3958053510234857, 0.5172484341263308, 0.9464413448636552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 378}], {
             RGBColor[
             0.20945304207089746`, 0.33747880567936756`, 0.9352394129367053]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 375}], {
             RGBColor[
             0.24288325350972279`, 0.37261607749940034`, 0.9371432140225805]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 379}], {
             RGBColor[
             0.2259392634266556, 0.3548068696110762, 0.9361782788537368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 366}], {
             RGBColor[
             0.934928559139148, 0.7751416322731404, 0.28588252947049914`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 391}], {
             RGBColor[
             0.8944837314108928, 0.5317010026573729, 0.24979314294089291`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 374}], {
             RGBColor[
             0.293247724709362, 0.42540017170025574`, 0.9400169674113716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 375}], {
             RGBColor[
             0.2826185317002574, 0.4142282159179257, 0.939411650593985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 369}], {
             RGBColor[
             0.30654023496768024`, 0.43518917662023243`, 0.9409270894573605]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 385}], {
             RGBColor[
             0.46552378312677223`, 0.5743196519105522, 0.9517997921721937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 377}], {
             RGBColor[
             0.3822045767059832, 0.5054681270073037, 0.9455747155508364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 387}], {
             RGBColor[
             0.3215492584874442, 0.4515282986156772, 0.941761191813439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 382}], {
             RGBColor[
             0.9000306839899277, 0.6389445090727658, 0.23829549106007777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 393}], {
             RGBColor[
             0.21780075210083538`, 0.3462527781962177, 0.93571480267358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 399}], {
             RGBColor[
             0.22383026101092823`, 0.35259017435367035`, 0.9360581742861507]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 392}], {
             RGBColor[
             0.2527015805879449, 0.38293576177650346`, 0.937702353224772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 389}], {
             RGBColor[
             0.505152375234491, 0.5869084718259839, 0.9586367768062234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 391}], {
             RGBColor[
             0.8258037070409253, 0.5129958576116641, 0.5754614637475668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 400}], {
             RGBColor[
             0.6104137657145253, 0.6900683539569277, 0.9649050090474223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 395}], {
             RGBColor[
             0.2616949498810116, 0.3923883631160637, 0.9382145123015146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 375}], {
             RGBColor[
             0.26547453356081113`, 0.3963609452029792, 0.9384297540006862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 399}], {
             RGBColor[
             0.255491371590293, 0.38586800900293716`, 0.9378612276952298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 379}], {
             RGBColor[
             0.23790135046863936`, 0.36737978153232503`, 0.9368595020144559]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 383}], {
             RGBColor[
             0.26754083334268397`, 0.3985327572847006, 0.9385474267164473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 399}], {
             RGBColor[
             0.24486217858118842`, 0.3746960532206071, 0.9372559108778432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 377}], {
             RGBColor[
             0.4266363429774569, 0.5439526897461481, 0.9484058684081864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 393}], {
             RGBColor[
             0.22188867958802838`, 0.35054944917483033`, 0.9359476040964289]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 399}], {
             RGBColor[
             0.22791818849812123`, 0.356886845332283, 0.9362909757089996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 383}], {
             RGBColor[
             0.2728634955258139, 0.4041272127154443, 0.9388505444536035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 390}], {
             RGBColor[
             0.2658949696207651, 0.39680285015917666`, 0.9384536972123212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 390}], {
             RGBColor[
             0.27326780022861263`, 0.40455216259248444`, 0.9388735690083126]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 398}], {
             RGBColor[
             0.8439266207114591, 0.8788704640005567, 0.9814905615415767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 400}], {
             RGBColor[
             0.2843495171102985, 0.40872323643536973`, 0.9397784081644269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 399}], {
             RGBColor[
             0.22884950770057744`, 0.3578657208631124, 0.9363440129598162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 396}], {
             RGBColor[
             0.2756838068644868, 0.4070915387504564, 0.9390111570120642]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.09653745999529093], {
             RGBColor[
             0.3599830334006432, 0.48622094308345976`, 0.9441587784611594]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.09653745999529093], {
             RGBColor[
             0.8184511944421836, 0.14282954261339104`, 0.16530219067646573`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.09653745999529093], {
             RGBColor[
             0.370079657849583, 0.49496613171003123`, 0.9448021264429514]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.09653745999529093], {
             RGBColor[
             0.23219649750384544`, 0.36138361935775737`, 0.9365346190776845]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.09653745999529093], {
             RGBColor[
             0.8414430264446411, 0.8764078451972013, 0.9847387810989889]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.09653745999529093], {
             RGBColor[
             0.9933475429680663, 0.9881793920123014, 0.5172992901589675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.09653745999529093], {
             RGBColor[
             0.38940499419392427`, 0.5117047667318526, 0.9460335197860889]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.09653745999529093], {
             RGBColor[
             0.3103199544645186, 0.44320528024791445`, 0.9409942909866859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.09653745999529093], {
             RGBColor[
             0.8256674379376745, 0.1982967522977973, 0.17221247359732916`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.09653745999529093], {
             RGBColor[
             0.3619258765766598, 0.48790373619238797`, 0.9442825747103464]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.09653745999529093], {
             RGBColor[
             0.9234626618564741, 0.7342619893565898, 0.25727446504873397`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.09653745999529093], {
             RGBColor[
             0.218436984339963, 0.3469214986189947, 0.935751035158377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.09653745999529093], {
             RGBColor[
             0.9637801291888717, 0.9725078601704316, 0.9461949730147088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.09653745999529093], {
             RGBColor[
             0.9943570777774785, 0.9903386848900081, 0.6271809240368398]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.09653745999529093], {
             RGBColor[
             0.3038609163605336, 0.43670746736272875`, 0.940615801713566]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.09653745999529093], {
             RGBColor[
             0.2418605106508593, 0.3715411099090923, 0.9370849703297808]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.09653745999529093], {
             RGBColor[
             0.5355166046173245, 0.6337955302332828, 0.9565769752588857]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.09653745999529093], {
             RGBColor[
             0.9452065658445834, 0.95865572703968, 0.9776351709954327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.09653745999529093], {
             RGBColor[
             0.2743841090042405, 0.40572547389373365`, 0.9389371411416538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.09653745999529093], {
             RGBColor[
             0.4076589804310767, 0.5275154521384491, 0.9471966476477539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.09653745999529093], {
             RGBColor[
             0.31291714185714126`, 0.44545483342897024`, 0.9411597814707411]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.09653745999529093], {
             RGBColor[
             0.29231839668471055`, 0.42457554734542235`, 0.9399584722936555]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.09653745999529093], {
             RGBColor[
             0.21341792784235675`, 0.34164615201344867`, 0.935465207315867]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.09653745999529093], {
             RGBColor[
             0.9021530244270525, 0.6485815613125467, 0.24006642394413927`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.09653745999529093], {
             RGBColor[
             0.8487111149297029, 0.3754205514621725, 0.19427912470900624`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.09653745999529093], {
             RGBColor[
             0.45511285367532656`, 0.5685201430708667, 0.9502472974560874]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.09653745999529093], {
             RGBColor[
             0.2974167180204977, 0.42993420632157753`, 0.9402488141514381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.09653745999529093], {
             RGBColor[
             0.2882891132658928, 0.42034051500092084`, 0.9397290105637445]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.09653745999529093], {
             RGBColor[
             0.2404292095299187, 0.3700367216812511, 0.9370034598483634]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.09653745999529093], {
             RGBColor[
             0.17892703208317115`, 0.3053940337214471, 0.9335010018270892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.09653745999529093], {
             RGBColor[
             0.183217413291963, 0.30990349639776743`, 0.9337453326898797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.09653745999529093], {
             RGBColor[
             0.21628540957162948`, 0.3446600571197567, 0.9356285061582901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.09653745999529093], {
             RGBColor[
             0.17894138666990014`, 0.3054091213022326, 0.9335018192995677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.09653745999529093], {
             RGBColor[
             0.3122890105436297, 0.4449107776560043, 0.9411197574988789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.09653745999529093], {
             RGBColor[
             0.28104105066772134`, 0.4127223416565313, 0.9393162441213263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.09653745999529093], {
             RGBColor[
             0.5196772960404508, 0.620936465977857, 0.9553300468664151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.09653745999529093], {
             RGBColor[
             0.24979952597607638`, 0.3798855183785399, 0.9375370855078312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.09653745999529093], {
             RGBColor[
             0.9657912116144293, 0.896267865549297, 0.32160574622002847`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.09653745999529093], {
             RGBColor[
             0.27309206457306523`, 0.40436745327622, 0.9388635611227067]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.09653745999529093], {
             RGBColor[
             0.3393121311221928, 0.4683168464796233, 0.9428416468465376]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.09653745999529093], {
             RGBColor[
             0.34082031608406577`, 0.4696231604900174, 0.9429377470586726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.09653745999529093], {
             RGBColor[
             0.9322258626950144, 0.9487956145888052, 0.9933977290633442]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.09653745999529093], {
             RGBColor[
             0.2274352478585693, 0.35637924409990884`, 0.9362634729540237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.09653745999529093], {
             RGBColor[
             0.29795654320818293`, 0.4305015968207284, 0.940279556397277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.09653745999529093], {
             RGBColor[
             0.2954990939280613, 0.427918661816037, 0.9401396082962444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.09653745999529093], {
             RGBColor[
             0.2843163130979401, 0.41616485013432336`, 0.9395027654714108]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.09653745999529093], {
             RGBColor[
             0.43389191818712153`, 0.5502371043169462, 0.948868187244693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.09653745999529093], {
             RGBColor[
             0.4254428949511675, 0.5429189850502182, 0.948329822955276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.09653745999529093], {
             RGBColor[
             0.2557363986193865, 0.3861255479461254, 0.9378751816220516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.09653745999529093], {
             RGBColor[
             0.45414763221898446`, 0.5677365328098771, 0.9501713116873214]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.09653745999529093], {
             RGBColor[
             0.3729233885884314, 0.4974292283459589, 0.9449833264510183]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.09653745999529093], {
             RGBColor[
             0.38664548537965426`, 0.5093146188938776, 0.9458576863245813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.09653745999529093], {
             RGBColor[
             0.28924396052189333`, 0.4213441200077901, 0.9397833877024038]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.09653745999529093], {
             RGBColor[
             0.4519914858020445, 0.5659140400742732, 0.9500214756882968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.09653745999529093], {
             RGBColor[
             0.4035326533159193, 0.5239414349865308, 0.9469337217327439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.09653745999529093], {
             RGBColor[
             0.45093503134871465`, 0.5649989923257436, 0.9499541593447165]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.09653745999529093], {
             RGBColor[
             0.2732074233744939, 0.404488702690692, 0.9388701306357901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.09653745999529093], {
             RGBColor[
             0.2988109928106687, 0.43139967752817476`, 0.9403282160380936]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.09653745999529093], {
             RGBColor[
             0.3340181926444761, 0.4637315030513096, 0.9425043217679835]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.09653745999529093], {
             RGBColor[
             0.35752834255750565`, 0.4840948132514831, 0.9440023677312325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.09653745999529093], {
             RGBColor[
             0.9933459036684309, 0.98817588571614, 0.5171208625102379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.09653745999529093], {
             RGBColor[
             0.1790682590797859, 0.30554247224919795`, 0.9335090444956198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.09653745999529093], {
             RGBColor[
             0.9585610528033711, 0.8718788421575785, 0.2935179445399928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.09653745999529093], {
             RGBColor[
             0.3989602722595878, 0.5199810683300905, 0.9466423736550322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.09653745999529093], {
             RGBColor[
             0.5153321861178936, 0.6174089099977538, 0.9549879838966494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.09653745999529093], {
             RGBColor[
             0.9727828870163496, 0.9198524284034268, 0.3487670848893771]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.09653745999529093], {
             RGBColor[
             0.2129458677257866, 0.3411499869005934, 0.9354383241905787]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.09653745999529093], {
             RGBColor[
             0.2767246225454214, 0.4081855020226443, 0.9390704299253445]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.09653745999529093], {
             RGBColor[
             0.48821862164434726`, 0.5953968969059689, 0.9528535047810326]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.09653745999529093], {
             RGBColor[
             0.2778101351361315, 0.409326444580954, 0.9391322482615135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.09653745999529093], {
             RGBColor[
             0.871120013048017, 0.9000714687543917, 0.9875693985741776]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.09653745999529093], {
             RGBColor[
             0.22772650909910638`, 0.3566853781307425, 0.9362800598507899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.09653745999529093], {
             RGBColor[
             0.24311597663730303`, 0.3728606842619857, 0.9371564672604132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.09653745999529093], {
             RGBColor[
             0.8246734764068878, 0.8630362611944062, 0.983139286446034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.09653745999529093], {
             RGBColor[
             0.24417812249459925`, 0.373977066901941, 0.9372169548956822]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.09653745999529093], {
             RGBColor[
             0.8469444359628041, 0.36184108275892934`, 0.19258735093512552`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.09653745999529093], {
             RGBColor[
             0.8293651040061051, 0.8667772376911834, 0.9835867780747127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.09653745999529093], {
             RGBColor[
             0.8418439495844675, 0.3226365094076515, 0.18770311941905493`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.09653745999529093], {
             RGBColor[
             0.590805957298975, 0.6786819174972005, 0.9609295556335575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.09653745999529093], {
             RGBColor[
             0.3344163982055418, 0.46407640869391137`, 0.9425296950742152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.09653745999529093], {
             RGBColor[
             0.2197154470497895, 0.34826524398623987`, 0.9358238417183856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.09653745999529093], {
             RGBColor[
             0.37921715493462604`, 0.5028805724211383, 0.9453843596772389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.09653745999529093], {
             RGBColor[
             0.35288166901045503`, 0.480070098173631, 0.9437062858017065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.09653745999529093], {
             RGBColor[
             0.17892701429477148`, 0.30539401502471114`, 0.9335010008140661]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.09653745999529093], {
             RGBColor[
             0.2413074662041341, 0.37095982513054093`, 0.9370534752666957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.09653745999529093], {
             RGBColor[
             0.30053635500276704`, 0.4332131425863514, 0.940426472862489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.09653745999529093], {
             RGBColor[
             0.29013871681338543`, 0.4222845656009737, 0.9398343427495309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.09653745999529093], {
             RGBColor[
             0.9903137669558371, 0.9902625079584733, 0.8101894789167451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.09653745999529093], {
             RGBColor[
             0.21858282554203126`, 0.3470747869692347, 0.9357593405990821]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.09653745999529093], {
             RGBColor[
             0.7058058015575851, 0.7701001235903371, 0.9713117842351892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.09653745999529093], {
             RGBColor[
             0.26262121251507564`, 0.39336192387290797`, 0.9382672615882417]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.09653745999529093], {
             RGBColor[
             0.28766384187052196`, 0.4196833151198899, 0.9396934022827843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.09653745999529093], {
             RGBColor[
             0.2452381115380016, 0.3750911825937439, 0.9372773197035907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.09653745999529093], {
             RGBColor[
             0.26012396818175015`, 0.3907371617441472, 0.9381250472178008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.09653745999529093], {
             RGBColor[
             0.2817785304161579, 0.4134974796310549, 0.9393582425019963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.09653745999529093], {
             RGBColor[
             0.2869114883454893, 0.4188925438631119, 0.939650556862541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.09653745999529093], {
             RGBColor[
             0.44228444757308333`, 0.5575062914502744, 0.9494029517959442]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.09653745999529093], {
             RGBColor[
             0.9775701021325132, 0.9360008290818089, 0.3673645116259542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.09653745999529093], {
             RGBColor[
             0.9781276011086575, 0.9832081812363787, 0.921908445474496]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.09653745999529093], {
             RGBColor[
             0.37661408553666426`, 0.5006259245426959, 0.9452184943970047]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.09653745999529093], {
             RGBColor[
             0.2608418322510304, 0.39149168239617155`, 0.9381659285145616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.09653745999529093], {
             RGBColor[
             0.819297035403237, 0.14933104688991955`, 0.16611216893601113`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.09653745999529093], {
             RGBColor[
             0.34456615692423104`, 0.4728676195543337, 0.943176428724691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.09653745999529093], {
             RGBColor[
             0.9338740873595025, 0.7755398220742175, 0.265651742396037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.09653745999529093], {
             RGBColor[
             0.417344109662346, 0.5359042242898253, 0.9478137755181469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.09653745999529093], {
             RGBColor[
             0.948494816832878, 0.9611080992427333, 0.9720690197854612]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.09653745999529093], {
             RGBColor[
             0.8392176796973624, 0.30244984821655896`, 0.1851882004092155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.09653745999529093], {
             RGBColor[
             0.3675690787260941, 0.49279159425864094`, 0.9446421545612206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.09653745999529093], {
             RGBColor[
             0.9940964498066649, 0.9918267445278057, 0.7475006348091123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.09653745999529093], {
             RGBColor[
             0.25557794384056287`, 0.3859590019269685, 0.9378661578568105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.09653745999529093], {
             RGBColor[
             0.8740781517963572, 0.5211001217496539, 0.21664006204298622`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.09653745999529093], {
             RGBColor[
             0.3289211710833394, 0.45931671915880556`, 0.9421795440612271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.09653745999529093], {
             RGBColor[
             0.7965156452550962, 0.8409633429071789, 0.9803528937232722]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.09653745999529093], {
             RGBColor[
             0.3288778807819878, 0.45927922327560866`, 0.9421767856415051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.09653745999529093], {
             RGBColor[
             0.2386060995532787, 0.36812051750395375`, 0.9368996364322433]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.09653745999529093], {
             RGBColor[
             0.4162213411164948, 0.534931738607397, 0.9477422336992305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.09653745999529093], {
             RGBColor[
             0.3495171154366807, 0.47715589097540734`, 0.9434918994231435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.09653745999529093], {
             RGBColor[
             0.20606162213947596`, 0.33391420830300045`, 0.935046276588767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.09653745999529093], {
             RGBColor[
             0.24049836738192176`, 0.3701094109685675, 0.9370073982857251]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.09653745999529093], {
             RGBColor[
             0.5663783145126094, 0.6588504566304622, 0.9590065221120109]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.09653745999529093], {
             RGBColor[
             0.5531961411455233, 0.6481485744409189, 0.9579687731366617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.09653745999529093], {
             RGBColor[
             0.44608758599784554`, 0.5608003788025082, 0.9496452844133868]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.09653745999529093], {
             RGBColor[
             0.9742961343763916, 0.9803506796209057, 0.9283941192456544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.09653745999529093], {
             RGBColor[
             0.22327126764014227`, 0.35200263687874755`, 0.936026340440641]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.09653745999529093], {
             RGBColor[
             0.277985958766929, 0.4095112463647842, 0.9391422611571797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.09653745999529093], {
             RGBColor[
             0.21204174778307774`, 0.3401996995162911, 0.935386835897367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.09653745999529093], {
             RGBColor[
             0.21049571798261152`, 0.33857472417205015`, 0.9352987917873766]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.09653745999529093], {
             RGBColor[
             0.3262131529712761, 0.45697116997908427`, 0.9420069915417328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.09653745999529093], {
             RGBColor[
             0.23768447069359533`, 0.36715182713778177`, 0.936847151032112]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.09653745999529093], {
             RGBColor[
             0.4104055903111328, 0.5298944275679272, 0.9473716592005793]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.09653745999529093], {
             RGBColor[
             0.9224661794909306, 0.7303112688352736, 0.2564726719469704]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.09653745999529093], {
             RGBColor[
             0.7992223614262676, 0.8430778501519028, 0.9806226738955138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.09653745999529093], {
             RGBColor[
             0.29725822306554583`, 0.42976761807476255`, 0.9402397880982258]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.09653745999529093], {
             RGBColor[
             0.2343268669145523, 0.36362277268163234`, 0.9366559404640252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.09653745999529093], {
             RGBColor[
             0.5032780494106496, 0.6076228187861427, 0.9540390380992975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.09653745999529093], {
             RGBColor[
             0.6185821135656369, 0.7012318524560568, 0.9631161964022821]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.09653745999529093], {
             RGBColor[
             0.22155609394318862`, 0.3501998805749559, 0.9359286638359716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.09653745999529093], {
             RGBColor[
             0.8193428764107183, 0.14968340096107918`, 0.16615606633654534`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.09653745999529093], {
             RGBColor[
             0.2111706728502173, 0.3392841445325141, 0.9353372294685806]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.09653745999529093], {
             RGBColor[
             0.6719249954084331, 0.7436321803229556, 0.9679348621123766]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.09653745999529093], {
             RGBColor[
             0.3600639473667127, 0.48629102669401497`, 0.9441639342275279]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.09653745999529093], {
             RGBColor[
             0.8215839734950429, 0.16690945520620182`, 0.16830214343545163`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.09653745999529093], {
             RGBColor[
             0.6246442469651912, 0.7061533654458123, 0.9635934297498213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.09653745999529093], {
             RGBColor[
             0.8784381059512442, 0.540897655273832, 0.22027811466207986`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.09653745999529093], {
             RGBColor[
             0.23802405881018981`, 0.36750875577945274`, 0.9368664900729765]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.09653745999529093], {
             RGBColor[
             0.5353312372592116, 0.6336450406612625, 0.9565623824614321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.09653745999529093], {
             RGBColor[
             0.28473783311028583`, 0.41660789439321116`, 0.9395267704125309]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.09653745999529093], {
             RGBColor[
             0.6238880244982119, 0.7055394299796848, 0.9635338971470865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.09653745999529093], {
             RGBColor[
             0.22021863489519794`, 0.34879412631571627`, 0.9358524975217819]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.09653745999529093], {
             RGBColor[
             0.2706007772119499, 0.40174895230294594`, 0.9387216859930206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.09653745999529093], {
             RGBColor[
             0.3158355177641727, 0.44798258395780277`, 0.9413457378029186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.09653745999529093], {
             RGBColor[
             0.18361616608284723`, 0.3103226108633739, 0.9337680410714186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.09653745999529093], {
             RGBColor[
             0.3174307607246093, 0.4493643032308905, 0.9414473852737397]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.09653745999529093], {
             RGBColor[
             0.4301580292792129, 0.547002997415629, 0.9486302671452295]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.09653745999529093], {
             RGBColor[
             0.30454561984188433`, 0.43742713413433654`, 0.9406547945639009]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.09653745999529093], {
             RGBColor[
             0.18595953915049845`, 0.3127856445359093, 0.9339014927009116]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.09653745999529093], {
             RGBColor[
             0.46924384183457235`, 0.5799923158523045, 0.9513597406074984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.09653745999529093], {
             RGBColor[
             0.5031159008708285, 0.6074911792968075, 0.9540262731722731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.09653745999529093], {
             RGBColor[
             0.3314345944952444, 0.46149372018986384`, 0.9423396971785006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.09653745999529093], {
             RGBColor[
             0.8294775817921864, 0.22758318757925894`, 0.17586107165535175`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.09653745999529093], {
             RGBColor[
             0.4314366462475933, 0.5481104711684827, 0.9487117394878181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.09653745999529093], {
             RGBColor[
             0.246083996032968, 0.37598026083012825`, 0.9373254915742051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.09653745999529093], {
             RGBColor[
             0.2449732495734328, 0.3748127958757636, 0.9372622362065367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.09653745999529093], {
             RGBColor[
             0.24253850776538854`, 0.3722537278639624, 0.9371235812624463]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.09653745999529093], {
             RGBColor[
             0.532748774101436, 0.6315484807311408, 0.9563590815017777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.09653745999529093], {
             RGBColor[
             0.8247691039330448, 0.19139176348574266`, 0.17135222793997262`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.09653745999529093], {
             RGBColor[
             0.2835494674254077, 0.415358846711668, 0.9394590947448065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.09653745999529093], {
             RGBColor[
             0.6701504899984683, 0.7422459232099505, 0.9677579959968072]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.09653745999529093], {
             RGBColor[
             0.22069846856058375`, 0.34929846192124825`, 0.9358798233391753]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.09653745999529093], {
             RGBColor[
             0.44496963537099143`, 0.5598320661593594, 0.9495740495880086]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.09653745999529093], {
             RGBColor[
             0.2732125866431092, 0.40449412961337683`, 0.9388704246762993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.09653745999529093], {
             RGBColor[
             0.301424661402258, 0.4341468089340951, 0.9404770605978084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.09653745999529093], {
             RGBColor[
             0.22636761106282094`, 0.3552570901354948, 0.936202672617933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.09653745999529093], {
             RGBColor[
             0.7286053839996127, 0.7879113306772935, 0.9735842335387989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.09653745999529093], {
             RGBColor[
             0.17893214148115075`, 0.3053994040226782, 0.9335012927997455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.09653745999529093], {
             RGBColor[
             0.21582348781243682`, 0.34417454806331416`, 0.935602200397456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.09653745999529093], {
             RGBColor[
             0.3219085007459621, 0.453242696579629, 0.9417327029083903]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.09653745999529093], {
             RGBColor[
             0.24398844376792686`, 0.3737777025338824, 0.9372061529728027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.09653745999529093], {
             RGBColor[
             0.2696431574723743, 0.40074243324005365`, 0.9386671509655232]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.09653745999529093], {
             RGBColor[
             0.36627002209779275`, 0.4916664166996908, 0.9445593798215759]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.09653745999529093], {
             RGBColor[
             0.5673122922146817, 0.6596087018042204, 0.9590800482579911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.09653745999529093], {
             RGBColor[
             0.2880943118622093, 0.4201357663745271, 0.9397179169119876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.09653745999529093], {
             RGBColor[
             0.2589336294896423, 0.3894860403069097, 0.9380572591902335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.09653745999529093], {
             RGBColor[
             0.21776291881025298`, 0.3462130130090464, 0.9357126481236506]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.09653745999529093], {
             RGBColor[
             0.8236904837096025, 0.18310101579396953`, 0.170319339995877]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.09653745999529093], {
             RGBColor[
             0.24846767200989045`, 0.3784856554156597, 0.9374612383947583]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.09653745999529093], {
             RGBColor[
             0.8439338400416576, 0.8783939523481282, 0.9849763571234479]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.09653745999529093], {
             RGBColor[
             0.26708591845739416`, 0.39805461289699134`, 0.9385215199867163]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.09653745999529093], {
             RGBColor[
             0.30054674338696064`, 0.4332240614368005, 0.9404270644656005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.09653745999529093], {
             RGBColor[
             0.2411029859620505, 0.37074490343131483`, 0.9370418304194105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.09653745999529093], {
             RGBColor[
             0.6788533623879274, 0.7490446732648759, 0.968625416983622]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.09653745999529093], {
             RGBColor[
             0.34448974411411554`, 0.4728014346188312, 0.9431715597679996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.09653745999529093], {
             RGBColor[
             0.8223396115770147, 0.8611753007301386, 0.9829166803350949]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.09653745999529093], {
             RGBColor[
             0.3880550588481297, 0.5105355205850486, 0.9459475030995558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.09653745999529093], {
             RGBColor[
             0.24569470610522032`, 0.37557109243365844`, 0.9373033220887227]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.09653745999529093], {
             RGBColor[
             0.29792411608308994`, 0.43046751385625726`, 0.9402777097204745]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.09653745999529093], {
             RGBColor[
             0.988751433892587, 0.9896164430866911, 0.8360813809631582]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.09653745999529093], {
             RGBColor[
             0.8264896291158393, 0.8644844120663722, 0.9833125127127125]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.09653745999529093], {
             RGBColor[
             0.22580276459471169`, 0.35466340068417734`, 0.9361705054471896]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.09653745999529093], {
             RGBColor[
             0.27065965459454444`, 0.40181083616509444`, 0.9387250389728581]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.09653745999529093], {
             RGBColor[
             0.27642628673231373`, 0.407871932167485, 0.9390534401421363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.09653745999529093], {
             RGBColor[
             0.8563396258514921, 0.4340566292418462, 0.20158419538288244`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.09653745999529093], {
             RGBColor[
             0.29139757571829134`, 0.42360770612629445`, 0.9399060329018505]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.09653745999529093], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.09653745999529093], {
             RGBColor[
             0.9952685123171101, 0.9923114224965074, 0.7280765258104895]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.09653745999529093], {
             RGBColor[
             0.23156206990492625`, 0.36071679572626025`, 0.9364984893644777]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.09653745999529093], {
             RGBColor[
             0.9398558182628138, 0.7992553918121872, 0.27046478349011155`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.09653745999529093], {
             RGBColor[
             0.2330867180319017, 0.36231929757598597`, 0.9365853158197941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.09653745999529093], {
             RGBColor[
             0.2520329891677718, 0.3822330298027571, 0.9376642779324855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.09653745999529093], {
             RGBColor[
             0.2999237099233219, 0.432569213763913, 0.9403915836315417]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.09653745999529093], {
             RGBColor[
             0.2626771974737526, 0.39342076761412886`, 0.9382704498488161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.09653745999529093], {
             RGBColor[
             0.21089717481030001`, 0.33899668075178374`, 0.9353216541598114]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.09653745999529093], {
             RGBColor[
             0.9109681137578394, 0.6847252697068382, 0.24722105836383443`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.09653745999529093], {
             RGBColor[
             0.9837730937067766, 0.9874185803724101, 0.9123520990861677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.09653745999529093], {
             RGBColor[
             0.8192881970279116, 0.1492631112641677, 0.166103705297818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.09653745999529093], {
             RGBColor[
             0.6591015742674116, 0.7336144262659793, 0.9666567433347234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.09653745999529093], {
             RGBColor[
             0.8228256695060855, 0.17645367486173685`, 0.16949119293792111`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.09653745999529093], {
             RGBColor[
             0.9100637739514378, 0.9311241665985504, 0.9912838892546516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.09653745999529093], {
             RGBColor[
             0.4471878440862639, 0.5617533670581167, 0.9497153918858607]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.09653745999529093], {
             RGBColor[
             0.4754345148883495, 0.5850181831240037, 0.9518470930674744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.09653745999529093], {
             RGBColor[
             0.9218589159168126, 0.9405292926311409, 0.9924089204249567]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.09653745999529093], {
             RGBColor[
             0.6049269005052089, 0.6901459353332633, 0.9620412080094716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.09653745999529093], {
             RGBColor[
             0.4540671923140028, 0.5676712280712366, 0.9501649791633402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.09653745999529093], {
             RGBColor[
             0.9756615083220127, 0.9295626939998534, 0.3599499850798584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.09653745999529093], {
             RGBColor[
             0.2571081050813221, 0.3875672984088326, 0.9379532982758011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.09653745999529093], {
             RGBColor[
             0.23863402700947722`, 0.3681498710311214, 0.9369012268595588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.09653745999529093], {
             RGBColor[
             0.23492201148043795`, 0.36424830735472313`, 0.9366898330666149]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.09653745999529093], {
             RGBColor[
             0.36785717736282086`, 0.49304113081751505`, 0.9446605119515972]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.09653745999529093], {
             RGBColor[
             0.24689616138342244`, 0.3768338981077132, 0.9373717431894225]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.09653745999529093], {
             RGBColor[
             0.9688572327835747, 0.9066102748888301, 0.333516659492644]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.09653745999529093], {
             RGBColor[
             0.30868412390727973`, 0.44177696430338015`, 0.9408904762480571]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.09653745999529093], {
             RGBColor[
             0.5255566438526651, 0.6257095853934133, 0.9557928906629534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.09653745999529093], {
             RGBColor[
             0.8174582326741875, 0.1351972033459516, 0.16435132936604271`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.09653745999529093], {
             RGBColor[
             0.3387393935852255, 0.4678207700117279, 0.942805152517134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.09653745999529093], {
             RGBColor[
             0.7400936775781565, 0.7968860729351169, 0.9747292792785006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.09653745999529093], {
             RGBColor[
             0.2505222001886238, 0.3806450947961188, 0.9375782407351351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.09653745999529093], {
             RGBColor[
             0.5784190314529432, 0.6686256530707418, 0.9599544114561535]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.09653745999529093], {
             RGBColor[
             0.22922310747734106`, 0.35825839791608494`, 0.9363652889144115]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.09653745999529093], {
             RGBColor[
             0.32451491921663345`, 0.4555002452565231, 0.9418987815885761]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.09653745999529093], {
             RGBColor[
             0.23920651037948798`, 0.3687515873505448, 0.9369338289405676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.09653745999529093], {
             RGBColor[
             0.290961948336973, 0.42314983412815754`, 0.9398812245669373]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.09653745999529093], {
             RGBColor[
             0.9183468399249884, 0.7139794601448493, 0.25315815463888625`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.09653745999529093], {
             RGBColor[
             0.2883719521470624, 0.4204275839173185, 0.939733728115478]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.09653745999529093], {
             RGBColor[
             0.2600361752617328, 0.3906448858188163, 0.9381200475408837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.09653745999529093], {
             RGBColor[
             0.22989884827362161`, 0.3589686443374169, 0.9364037713530907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.09653745999529093], {
             RGBColor[
             0.4438028563584466, 0.5588214608227114, 0.9494997034610714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.09653745999529093], {
             RGBColor[
             0.9070075396154186, 0.6690229130152352, 0.24403428744221908`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.09653745999529093], {
             RGBColor[
             0.21620788903044316`, 0.3445785781158837, 0.9356240914781508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.09653745999529093], {
             RGBColor[
             0.2695692814994847, 0.4006647849085395, 0.938662943838157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.09653745999529093], {
             RGBColor[
             0.9882272169582415, 0.9893996659125786, 0.8447690121952027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.09653745999529093], {
             RGBColor[
             0.822315843269912, 0.8611563485272284, 0.9829144132927453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.09653745999529093], {
             RGBColor[
             0.2243331252717409, 0.35311871657522015`, 0.9360868116618829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.09653745999529093], {
             RGBColor[
             0.34171577858230273`, 0.47039876509873646`, 0.9429948051372339]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.09653745999529093], {
             RGBColor[
             0.46951139015292603`, 0.5802095236300584, 0.951380802991181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.09653745999529093], {
             RGBColor[
             0.26047497796174324`, 0.3911060952782254, 0.938145036705499]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.09653745999529093], {
             RGBColor[
             0.22530836548640581`, 0.35414375587463387`, 0.9361423501493695]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.09653745999529093], {
             RGBColor[
             0.8226071697061851, 0.17477418965247965`, 0.16928195728277629`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.09653745999529093], {
             RGBColor[
             0.2529332615169164, 0.38317927312227185`, 0.9377155471109357]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.09653745999529093], {
             RGBColor[
             0.2110206902246306, 0.3391265032835748, 0.9353286881799328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.09653745999529093], {
             RGBColor[
             0.8089540339665278, 0.8506803067038047, 0.9815926360666765]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.09653745999529093], {
             RGBColor[
             0.17944836957228805`, 0.3059419924772149, 0.9335306912258446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.09653745999529093], {
             RGBColor[
             0.9386428604207964, 0.9537605262817009, 0.9887458121893573]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.09653745999529093], {
             RGBColor[
             0.26208361027682536`, 0.3927968698345563, 0.9382366459360847]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.09653745999529093], {
             RGBColor[
             0.19003101446562676`, 0.31706502323855396`, 0.9341333571969002]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.09653745999529093], {
             RGBColor[
             0.5918946974095183, 0.6795658057661227, 0.9610152652432459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.09653745999529093], {
             RGBColor[
             0.2549979314676595, 0.3853493721481386, 0.937833127010225]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.09653745999529093], {
             RGBColor[
             0.5711989452526345, 0.6627640618321545, 0.9593860198224179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.09653745999529093], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.09653745999529093], {
             RGBColor[
             0.9930589289900814, 0.9875620758967413, 0.48588543977432486`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.09653745999529093], {
             RGBColor[
             0.249587147505622, 0.3796622951405196, 0.9375249908681246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.09653745999529093], {
             RGBColor[
             0.30678788301618565`, 0.43978389489822367`, 0.9407824881345462]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.09653745999529093], {
             RGBColor[
             0.6470169280819229, 0.7241738088191627, 0.9654522587403933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.09653745999529093], {
             RGBColor[
             0.2754373969927425, 0.40683254635196486`, 0.938997124334399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.09653745999529093], {
             RGBColor[
             0.2307279730478894, 0.35984010704471925`, 0.9364509887824051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.09653745999529093], {
             RGBColor[
             0.992100640761205, 0.9910014261975552, 0.7805763556806252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.09653745999529093], {
             RGBColor[
             0.765566144894021, 0.8167853580001923, 0.977268136766805]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.09653745999529093], {
             RGBColor[
             0.2578128298869203, 0.3883080088616496, 0.9379934313109329]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.09653745999529093], {
             RGBColor[
             0.2524156236360728, 0.382635202889368, 0.9376860683993983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.09653745999529093], {
             RGBColor[
             0.9456496399519233, 0.8222259641328803, 0.2751266284196432]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.09653745999529093], {
             RGBColor[
             0.23901320904650822`, 0.3685484153935707, 0.9369228207156182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.09653745999529093], {
             RGBColor[
             0.6319940482543123, 0.7121202652370958, 0.9641720330305101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.09653745999529093], {
             RGBColor[
             0.6468617732853108, 0.7240526007128293, 0.965436794360271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.09653745999529093], {
             RGBColor[
             0.9089152991886196, 0.6765865439997854, 0.2455693155756892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.09653745999529093], {
             RGBColor[
             0.24399808998490613`, 0.37378784131953313`, 0.9372067023105894]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.09653745999529093], {
             RGBColor[
             0.23871510677441427`, 0.3682350910048242, 0.9369058442322252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.09653745999529093], {
             RGBColor[
             0.726249879738111, 0.7860711928457129, 0.9733494588874512]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.09653745999529093], {
             RGBColor[
             0.260213393629744, 0.3908311535598896, 0.9381301398647709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.09653745999529093], {
             RGBColor[
             0.245025991273468, 0.37486823074651754`, 0.9372652397683294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.09653745999529093], {
             RGBColor[
             0.8977533081905217, 0.6286034774622947, 0.23639519286946437`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.09653745999529093], {
             RGBColor[
             0.4051337172328171, 0.5253281960795354, 0.9470357401097634]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.09653745999529093], {
             RGBColor[
             0.696491580031562, 0.7628237829435023, 0.9703834296798242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.09653745999529093], {
             RGBColor[
             0.2110186790508826, 0.3391243894124498, 0.9353285736465631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.09653745999529093], {
             RGBColor[
             0.21123106399266978`, 0.3393476194522512, 0.9353406686548026]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.09653745999529093], {
             RGBColor[
             0.21275955169572475`, 0.34095415693987974`, 0.9354277137682966]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.09653745999529093], {
             RGBColor[
             0.24238734999627973`, 0.3720948514646729, 0.9371149730511135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.09653745999529093], {
             RGBColor[
             0.30152154075751214`, 0.43424863527897317`, 0.94048257773377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.09653745999529093], {
             RGBColor[
             0.9466390204165737, 0.9597240493140413, 0.9752103990490407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.09653745999529093], {
             RGBColor[
             0.8234301328695646, 0.862044852807406, 0.9830206952294982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.09653745999529093], {
             RGBColor[
             0.21412870248835636`, 0.3423932212321097, 0.9355056848804599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.09653745999529093], {
             RGBColor[
             0.8899967779325137, 0.5933828851443484, 0.2299229538922278]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.09653745999529093], {
             RGBColor[
             0.2568179059531509, 0.3872622807254372, 0.9379367718647629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.09653745999529093], {
             RGBColor[
             0.9872770340850194, 0.9687445898536212, 0.4050741092611545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.09653745999529093], {
             RGBColor[
             0.28961174034798287`, 0.421730679923598, 0.9398043322194181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.09653745999529093], {
             RGBColor[
             0.21909843402136348`, 0.34761672417247863`, 0.9357887037392056]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.09653745999529093], {
             RGBColor[
             0.20290260740476634`, 0.33059388352371805`, 0.9348663753729688]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.09653745999529093], {
             RGBColor[
             0.9703761157708419, 0.9117338238555674, 0.33941723308119276`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.09653745999529093], {
             RGBColor[
             0.9852399747517544, 0.9881643644915732, 0.8942753462917085]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.09653745999529093], {
             RGBColor[
             0.2610883790761277, 0.39175081874132034`, 0.9381799689915176]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.09653745999529093], {
             RGBColor[
             0.27079044913528966`, 0.40194830952027055`, 0.9387324875284604]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.09653745999529093], {
             RGBColor[
             0.18257815057035692`, 0.3092315907457619, 0.9337089276235886]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.09653745999529093], {
             RGBColor[
             0.519374038863881, 0.6206902681403376, 0.955306173350608]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.09653745999529093], {
             RGBColor[
             0.46295717480753656`, 0.5748885163486347, 0.9508648311503101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.09653745999529093], {
             RGBColor[
             0.2828083531870263, 0.41457988865777246`, 0.939416889385311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.09653745999529093], {
             RGBColor[
             0.9258119809847409, 0.9436813594132142, 0.9927859673000785]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.09653745999529093], {
             RGBColor[
             0.24327422624281886`, 0.37302701463098736`, 0.937165479341338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.09653745999529093], {
             RGBColor[
             0.25427950679235417`, 0.38459426226363735`, 0.9377922137877805]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.09653745999529093], {
             RGBColor[
             0.9906270631619555, 0.9903920639910485, 0.8049973499967711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.09653745999529093], {
             RGBColor[
             0.2238174684207968, 0.35257672853034516`, 0.9360574457670676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.09653745999529093], {
             RGBColor[
             0.24158367299712782`, 0.37125013598249945`, 0.9370692048349454]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.09653745999529093], {
             RGBColor[
             0.7098940201909748, 0.7732938710583535, 0.9717192596619902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.09653745999529093], {
             RGBColor[
             0.8177864636409283, 0.8575802678943982, 0.9824729701128726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.09653745999529093], {
             RGBColor[
             0.5084161265639328, 0.611794141286916, 0.9544435263542006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.09653745999529093], {
             RGBColor[
             0.8302102447519867, 0.867451129981215, 0.983667388353521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.09653745999529093], {
             RGBColor[
             0.2799576543907215, 0.4115836234781131, 0.9392545463060924]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.09653745999529093], {
             RGBColor[
             0.21156771774634342`, 0.33970146389244305`, 0.9353598405880397]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.09653745999529093], {
             RGBColor[
             0.3393902356747875, 0.4683844967174319, 0.9428466235995638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.09653745999529093], {
             RGBColor[
             0.3185921337049145, 0.45037022613412764`, 0.941521386933083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.09653745999529093], {
             RGBColor[
             0.3094371851822424, 0.44244066986488095`, 0.9409380417086214]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.09653745999529093], {
             RGBColor[
             0.23513882534723038`, 0.36447619247551505`, 0.9367021802955814]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.09653745999529093], {
             RGBColor[
             0.22477195032544567`, 0.3535799495297792, 0.936111802099508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.09653745999529093], {
             RGBColor[
             0.45209247002133757`, 0.5660015075294104, 0.9500279103134532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.09653745999529093], {
             RGBColor[
             0.5272216074067284, 0.6270612778123552, 0.9559239626928917]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.09653745999529093], {
             RGBColor[
             0.19556045555100107`, 0.3228768164060961, 0.9344482506866372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.09653745999529093], {
             RGBColor[
             0.26139903658851843`, 0.39207733948366696`, 0.9381976604772716]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.09653745999529093], {
             RGBColor[
             0.28051817934621337`, 0.41217277074566994`, 0.9392864673730853]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.09653745999529093], {
             RGBColor[
             0.2110065608580655, 0.33911165242346125`, 0.9353278835334095]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.09653745999529093], {
             RGBColor[
             0.2847433322190086, 0.4166136743051424, 0.9395270835786375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.09653745999529093], {
             RGBColor[
             0.9942883740099587, 0.9901917344782997, 0.6197029429328111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.09653745999529093], {
             RGBColor[
             0.36576050208801136`, 0.49122509607643855`, 0.9445269136571035]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.09653745999529093], {
             RGBColor[
             0.99377812825938, 0.9891003704115706, 0.5641658418540755]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.09653745999529093], {
             RGBColor[
             0.2215837127017966, 0.35022890964138337`, 0.935930236683416]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.09653745999529093], {
             RGBColor[
             0.6033581995623302, 0.6888723932386622, 0.9619177141249072]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.09653745999529093], {
             RGBColor[
             0.7222005724227306, 0.7829078431950623, 0.9729458617771823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.09653745999529093], {
             RGBColor[
             0.32062864936426844`, 0.45213415364000675`, 0.941651151910077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.09653745999529093], {
             RGBColor[
             0.20194739446585683`, 0.3295898941609259, 0.9348119774092088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.09653745999529093], {
             RGBColor[
             0.3450320119322843, 0.4732711197477559, 0.9432061125938647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.09653745999529093], {
             RGBColor[
             0.2800500850584523, 0.411680773970341, 0.9392598100958807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.09653745999529093], {
             RGBColor[
             0.26295522261758464`, 0.39371298966810864`, 0.9382862829694559]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.09653745999529093], {
             RGBColor[
             0.4453791406536688, 0.5601867590528806, 0.9496001429025095]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.09653745999529093], {
             RGBColor[
             0.4327427506991586, 0.5492417531977101, 0.948794963308529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.09653745999529093], {
             RGBColor[
             0.24574449108125243`, 0.37562341960001794`, 0.9373061572694574]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.09653745999529093], {
             RGBColor[
             0.9941541355650164, 0.9899046120181566, 0.6050919166244885]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.09653745999529093], {
             RGBColor[
             0.21037964845754836`, 0.3384527277419758, 0.9352921817996338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.09653745999529093], {
             RGBColor[
             0.27977343586669706`, 0.4113899981292344, 0.939244055333676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.09653745999529093], {
             RGBColor[
             0.23092116646773903`, 0.3600431655781515, 0.9364619908618614]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.09653745999529093], {
             RGBColor[
             0.5183784049780293, 0.6198819676990077, 0.9552277934039866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.09653745999529093], {
             RGBColor[
             0.6756901028072094, 0.7465735108387558, 0.9683101328309576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.09653745999529093], {
             RGBColor[
             0.9685766725786527, 0.9056638794389593, 0.332426736075871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.09653745999529093], {
             RGBColor[
             0.2455681205459235, 0.37543804298484945`, 0.9372961132283874]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.09653745999529093], {
             RGBColor[
             0.3103917228488082, 0.4432674424152022, 0.9409988640046705]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.09653745999529093], {
             RGBColor[
             0.35562652096447817`, 0.48244755097593534`, 0.9438811853410396]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.09653745999529093], {
             RGBColor[
             0.40465902674538534`, 0.5249170430379596, 0.9470054932516565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.09653745999529093], {
             RGBColor[
             0.8625124936811881, 0.46858316947675277`, 0.2069893934114667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.09653745999529093], {
             RGBColor[
             0.34952976604112324`, 0.4771668482931376, 0.9434927055084721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.09653745999529093], {
             RGBColor[
             0.25624071750281635`, 0.38665561906827417`, 0.93790390183639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.09653745999529093], {
             RGBColor[
             0.9012804456996433, 0.6446193851073215, 0.2393383228651273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.09653745999529093], {
             RGBColor[
             0.21931469518675756`, 0.34784402836905765`, 0.9358010194926452]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.09653745999529093], {
             RGBColor[
             0.21278150541118618`, 0.3409772316867757, 0.9354289639999145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.09653745999529093], {
             RGBColor[
             0.25745394897088236`, 0.38793080226452953`, 0.9379729935736814]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.09653745999529093], {
             RGBColor[
             0.8312166238387177, 0.8682535893475418, 0.9837633776892186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.09653745999529093], {
             RGBColor[
             0.27204560568907665`, 0.4032675586398226, 0.9388039668373608]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.09653745999529093], {
             RGBColor[
             0.2514775053864574, 0.3816491811288898, 0.9376326439529042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.09653745999529093], {
             RGBColor[
             0.2503218011924054, 0.380434462745063, 0.9375668283087641]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.09653745999529093], {
             RGBColor[
             0.2761037265699157, 0.40753290098530925`, 0.9390350708180728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.09653745999529093], {
             RGBColor[
             0.25484534055170655`, 0.38518898942064916`, 0.9378244371832996]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.09653745999529093], {
             RGBColor[
             0.43839329858407067`, 0.5541359737708264, 0.9491550112231723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.09653745999529093], {
             RGBColor[
             0.41487938737084307`, 0.5337694057214698, 0.9476567255932007]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.09653745999529093], {
             RGBColor[
             0.20852643568424656`, 0.3365048836167593, 0.9351866440737768]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.09653745999529093], {
             RGBColor[
             0.22095736038557218`, 0.3495705736440009, 0.9358945668456122]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.09653745999529093], {
             RGBColor[
             0.26549066491796636`, 0.3963779002821365, 0.9384306726576119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.09653745999529093], {
             RGBColor[
             0.9931470290452047, 0.9914341346439413, 0.7632349938486772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.09653745999529093], {
             RGBColor[
             0.898780922280212, 0.63326963303821, 0.23725265925502825`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.09653745999529093], {
             RGBColor[
             0.28023632613366145`, 0.41187652514875206`, 0.939270416249595]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.09653745999529093], {
             RGBColor[
             0.7484278388783107, 0.8033967830847693, 0.9755599505897345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.09653745999529093], {
             RGBColor[
             0.5754210452890663, 0.6661917528451691, 0.9597183990033479]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.09653745999529093], {
             RGBColor[
             0.3393631406607411, 0.4683610283780999, 0.942844897129228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.09653745999529093], {
             RGBColor[
             0.2935687509337651, 0.4258897489382169, 0.9400296781184059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.09653745999529093], {
             RGBColor[
             0.22336510960731928`, 0.352101270736175, 0.9360316846018449]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.09653745999529093], {
             RGBColor[
             0.17908812663026416`, 0.30556335430442605`, 0.933510175923228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.09653745999529093], {
             RGBColor[
             0.26629927432356376`, 0.3972278000362168, 0.9384767217670303]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.09653745999529093], {
             RGBColor[
             0.8203907902431329, 0.1577381258757864, 0.16715954980591485`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.09653745999529093], {
             RGBColor[
             0.24794921220500737`, 0.3779407212884774, 0.9374317128758627]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.09653745999529093], {
             RGBColor[
             0.22281999879048459`, 0.3515283247056597, 0.9360006413472455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.09653745999529093], {
             RGBColor[
             0.35886795134781274`, 0.48525511505495156`, 0.9440877264187814]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.09653745999529093], {
             RGBColor[
             0.27306809856961783`, 0.40434226348706437`, 0.938862196294265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.09653745999529093], {
             RGBColor[
             0.2782995151593558, 0.4098408140138484, 0.9391601177298633]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.09653745999529093], {
             RGBColor[
             0.2493495489754894, 0.37941256402073326`, 0.9375114599833291]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.09653745999529093], {
             RGBColor[
             0.9394254025446074, 0.954344144916344, 0.9874211724934188]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.09653745999529093], {
             RGBColor[
             0.2348790166106703, 0.36420311702056507`, 0.9366873845723869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.09653745999529093], {
             RGBColor[
             0.38961090759033284`, 0.5118831185663134, 0.9460466404056259]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{
  3.834950276960332*^9, {3.8349573666066523`*^9, 3.83495737580899*^9}, 
   3.8349587938370156`*^9, 3.8350189212906833`*^9, 3.835019008666805*^9, 
   3.8350204886401753`*^9, 3.83502054312705*^9, {3.8350446267813253`*^9, 
   3.8350446323653708`*^9}, 3.835045028161322*^9, 3.8350456979409313`*^9, 
   3.8350520818267603`*^9, 3.835130056011287*^9},
 CellLabel->
  "Out[570]=",ExpressionUUID->"e0bb0494-d322-4d44-b08b-bbe30d06a05d"]
}, Open  ]],

Cell["Estimated with absolute Mean Deviation v Calculated: (r=3)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 
  3.8349503756793146`*^9}},ExpressionUUID->"1f247f63-64c4-418c-bfb8-\
f4fff5c40ce3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphinf4", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsif4", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}],
      "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"AMDi3f400", ",", "krif4"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502409842243`*^9}, {3.834957391671958*^9, 3.8349574025038147`*^9}, {
   3.8350188314314775`*^9, 3.835018832832349*^9}, {3.8350443332621727`*^9, 
   3.835044338598092*^9}, {3.835044923956807*^9, 3.8350449330660315`*^9}, {
   3.835045604518895*^9, 3.8350456066714773`*^9}},
 CellLabel->
  "In[330]:=",ExpressionUUID->"1d734512-e52f-42bf-9bfc-b77483f7a9f1"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN2wucz2W+wPHn16rdrWxoc2ntsSnFoptQYTEuNY3rMEhyNxmZGTMj4zII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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[105, 155] -> 
             RGBColor[
              0.9816199908186837, 0.9496620545793462, 0.38309756441442155`], 
             UndirectedEdge[1, 203] -> 
             RGBColor[
              0.9831837630048716, 0.9632248510101955, 0.6041529958256905], 
             UndirectedEdge[187, 193] -> 
             RGBColor[
              0.8169103880146069, 0.8548910421967215, 0.8469288399294149], 
             UndirectedEdge[209, 371] -> 
             RGBColor[
              0.911450937988189, 0.9296245826030358, 0.8892143852331706], 
             UndirectedEdge[23, 245] -> 
             RGBColor[
              0.5962821473339583, 0.6765077837770551, 0.9646124408964014], 
             UndirectedEdge[201, 236] -> 
             RGBColor[
              0.9658226483256684, 0.9719456142079854, 0.8409396977090068], 
             UndirectedEdge[258, 369] -> 
             RGBColor[
              0.8281781767965818, 0.8628482853528994, 0.776228676955638], 
             UndirectedEdge[161, 312] -> 
             RGBColor[
              0.9068566357486195, 0.9253756566406217, 0.86313754004813], 
             UndirectedEdge[74, 132] -> 
             RGBColor[
              0.8053257850583762, 0.8457984988210137, 0.859074696940077], 
             UndirectedEdge[89, 169] -> 
             RGBColor[
              0.9896348277623432, 0.9899817491540223, 0.8214412583912459], 
             UndirectedEdge[124, 137] -> 
             RGBColor[
              0.9712097680693306, 0.974332331454345, 0.702408800254371], 
             UndirectedEdge[186, 393] -> 
             RGBColor[
              0.9333857556827445, 0.9275715042483104, 0.681751921858771], 
             UndirectedEdge[84, 261] -> 
             RGBColor[
              0.8010092354066698, 0.8437534087762472, 0.9197384873077894], 
             UndirectedEdge[58, 243] -> 
             RGBColor[
              0.6222598426181201, 0.6979276411517097, 0.9667652298835697], 
             UndirectedEdge[205, 250] -> 
             RGBColor[
              0.9079385078932184, 0.9278106831322126, 0.93173036529657], 
             UndirectedEdge[327, 337] -> 
             RGBColor[
              0.6905154441667198, 0.7541836509809816, 0.947264632584879], 
             UndirectedEdge[38, 224] -> 
             RGBColor[
              0.905648503746573, 0.9261507375567326, 0.9387220409193249], 
             UndirectedEdge[49, 301] -> 
             RGBColor[
              0.6883221741452422, 0.7550280865108057, 0.9705828786394801], 
             UndirectedEdge[22, 97] -> 
             RGBColor[
              0.9313214478576108, 0.9475702250179683, 0.9758293652433268], 
             UndirectedEdge[163, 169] -> 
             RGBColor[
              0.9783737063791937, 0.9508503235378132, 0.6120842702677112], 
             UndirectedEdge[126, 318] -> 
             RGBColor[
              0.7275263831310179, 0.78335125855074, 0.8827904793177039], 
             UndirectedEdge[126, 149] -> 
             RGBColor[
              0.9809116513328295, 0.9532996428404313, 0.5796994155035606], 
             UndirectedEdge[28, 47] -> 
             RGBColor[
              0.9012877937028172, 0.9204156359536027, 0.8198435844474459], 
             UndirectedEdge[203, 392] -> 
             RGBColor[
              0.9910596867623731, 0.9891171464934794, 0.6921504015530981], 
             UndirectedEdge[116, 387] -> 
             RGBColor[
              0.5318616885214638, 0.6081853150844612, 0.9611874311905233], 
             UndirectedEdge[114, 203] -> 
             RGBColor[
              0.9915221538556642, 0.9901063168434335, 0.7424870906417769], 
             UndirectedEdge[38, 207] -> 
             RGBColor[
              0.9131335054173004, 0.9321190747140129, 0.9394359670606188], 
             UndirectedEdge[4, 73] -> 
             RGBColor[
              0.8660658759602974, 0.893345662940328, 0.8516380659503673], 
             UndirectedEdge[143, 223] -> 
             RGBColor[
              0.6573479589598268, 0.7227951153834044, 0.874982722816966], 
             UndirectedEdge[70, 164] -> 
             RGBColor[
              0.889808389965302, 0.9130942593011875, 0.9084522346619377], 
             UndirectedEdge[291, 331] -> 
             RGBColor[
              0.8282919362204539, 0.8662130271671451, 0.9574822193135628], 
             UndirectedEdge[317, 381] -> 
             RGBColor[
              0.9821408097713927, 0.9509697038086862, 0.42331718148275294`], 
             UndirectedEdge[120, 349] -> 
             RGBColor[
              0.9605995545746774, 0.9692859793034316, 0.9143817638585018], 
             UndirectedEdge[102, 160] -> 
             RGBColor[
              0.8024564351106218, 0.8460390058243679, 0.9559547088674527], 
             UndirectedEdge[84, 381] -> 
             RGBColor[
              0.7933809720615888, 0.8064553635431952, 0.6524641923687085], 
             UndirectedEdge[110, 203] -> 
             RGBColor[
              0.8996106860814155, 0.9207825627296116, 0.9108201798491318], 
             UndirectedEdge[316, 355] -> 
             RGBColor[
              0.876371323740492, 0.9041025037229788, 0.978953235851004], 
             UndirectedEdge[62, 77] -> 
             RGBColor[
              0.8130430083009809, 0.8541058253659337, 0.9461105433104741], 
             UndirectedEdge[188, 361] -> 
             RGBColor[
              0.8050697164825438, 0.8445089007672129, 0.7835735767343744], 
             UndirectedEdge[168, 282] -> 
             RGBColor[
              0.5866762190356201, 0.6753292099324204, 0.9606044475097365], 
             UndirectedEdge[271, 394] -> 
             RGBColor[
              0.9890479433145689, 0.9897390573526252, 0.8311674524991322], 
             UndirectedEdge[160, 224] -> 
             RGBColor[
              0.8946832173927719, 0.9181479734447497, 0.9651260224011287], 
             UndirectedEdge[97, 168] -> 
             RGBColor[
              0.7622655964558351, 0.8136765377888702, 0.9599323413850018], 
             UndirectedEdge[88, 132] -> 
             RGBColor[
              0.993730722640332, 0.9904202541067363, 0.6623180501518566], 
             UndirectedEdge[329, 353] -> 
             RGBColor[
              0.38235427392283927`, 0.5055977872125437, 0.9455842541251225], 
             UndirectedEdge[189, 339] -> 
             RGBColor[
              0.8918108273548357, 0.9149409587113536, 0.9214561317210276], 
             UndirectedEdge[316, 380] -> 
             RGBColor[
              0.9672168169031918, 0.974343801974235, 0.9078149990708604], 
             UndirectedEdge[156, 295] -> 
             RGBColor[
              0.9833695330446601, 0.9867661751589996, 0.8972974537236862], 
             UndirectedEdge[154, 228] -> 
             RGBColor[
              0.6362327427977706, 0.7135435934760328, 0.9658853233623841], 
             UndirectedEdge[29, 91] -> 
             RGBColor[
              0.7782929742023161, 0.8272579568232536, 0.9764734538758053], 
             UndirectedEdge[6, 198] -> 
             RGBColor[
              0.9148631796312665, 0.9323454114663938, 0.8895398478872312], 
             UndirectedEdge[56, 254] -> 
             RGBColor[
              0.8819885994218379, 0.9086708585580866, 0.9862856893152349], 
             UndirectedEdge[245, 315] -> 
             RGBColor[
              0.7189176321812345, 0.7796086207605513, 0.9732886910991283], 
             UndirectedEdge[174, 281] -> 
             RGBColor[
              0.8160067910261677, 0.8564652615341496, 0.9822225361636767], 
             UndirectedEdge[89, 329] -> 
             RGBColor[
              0.6903597012727948, 0.7507300144862481, 0.8528934271777111], 
             UndirectedEdge[260, 267] -> 
             RGBColor[
              0.9736159499638588, 0.9782432646853063, 0.8578882012128681], 
             UndirectedEdge[202, 363] -> 
             RGBColor[
              0.8795822970581881, 0.9066591723079039, 0.981714762741304], 
             UndirectedEdge[43, 238] -> 
             RGBColor[
              0.8429420432621555, 0.786814259027725, 0.6198868034684986], 
             UndirectedEdge[276, 377] -> 
             RGBColor[
              0.9615653197215835, 0.8805777992939494, 0.31266319092059935`], 
             UndirectedEdge[284, 369] -> 
             RGBColor[
              0.9689080090629127, 0.9022894309767332, 0.42957293110138123`], 
             UndirectedEdge[53, 249] -> 
             RGBColor[
              0.7527376988170905, 0.8060148829881624, 0.9611542241049087], 
             UndirectedEdge[15, 105] -> 
             RGBColor[
              0.9332520903543422, 0.9354818521797692, 0.6935331252551145], 
             UndirectedEdge[97, 112] -> 
             RGBColor[
              0.8474547045017868, 0.8813464152194381, 0.967657788118545], 
             UndirectedEdge[120, 246] -> 
             RGBColor[
              0.9807490434451137, 0.9843984176431119, 0.8832203327572457], 
             UndirectedEdge[53, 308] -> 
             RGBColor[
              0.9392973685131238, 0.8535492556644337, 0.6116836703972477], 
             UndirectedEdge[188, 392] -> 
             RGBColor[
              0.9938715192381834, 0.9893001242719546, 0.5743308735545101], 
             UndirectedEdge[91, 273] -> 
             RGBColor[
              0.7889677128320851, 0.8352191594150551, 0.9584039057933353], 
             UndirectedEdge[327, 354] -> 
             RGBColor[
              0.7009749730556767, 0.7619498845133358, 0.9280159211363971], 
             UndirectedEdge[51, 376] -> 
             RGBColor[
              0.9913396705955804, 0.9896362247415293, 0.7168258329698987], 
             UndirectedEdge[202, 214] -> 
             RGBColor[
              0.9363163894739748, 0.9518653899332753, 0.9871346049721448], 
             UndirectedEdge[69, 132] -> 
             RGBColor[
              0.8527278644189942, 0.883217569471805, 0.8635338746609058], 
             UndirectedEdge[130, 387] -> 
             RGBColor[
              0.8923871708960643, 0.9170293231408033, 0.9895978790751403], 
             UndirectedEdge[61, 306] -> 
             RGBColor[
              0.7942132002086624, 0.8390794929024461, 0.9481368614468951], 
             UndirectedEdge[312, 356] -> 
             RGBColor[
              0.891962046527117, 0.9159514584576698, 0.9637704129440028], 
             UndirectedEdge[18, 247] -> 
             RGBColor[
              0.8746476819843287, 0.902513991427804, 0.9665319322478263], 
             UndirectedEdge[56, 320] -> 
             RGBColor[
              0.712537919209115, 0.7747471819835292, 0.9724205600962088], 
             UndirectedEdge[43, 124] -> 
             RGBColor[
              0.8735739562283797, 0.8973733616463498, 0.7055881081899523], 
             UndirectedEdge[259, 318] -> 
             RGBColor[
              0.6734812136162638, 0.7426319622365802, 0.9698145835817595], 
             UndirectedEdge[267, 384] -> 
             RGBColor[
              0.6983267636306614, 0.7615555099810501, 0.9566078453698843], 
             UndirectedEdge[44, 324] -> 
             RGBColor[
              0.9415089220236506, 0.805088846899253, 0.5512130567699306], 
             UndirectedEdge[62, 204] -> 
             RGBColor[
              0.6322811262636561, 0.7122268152093676, 0.9642811304157772], 
             UndirectedEdge[42, 109] -> 
             RGBColor[
              0.9209662538997199, 0.9387735003790169, 0.9561273720528487], 
             UndirectedEdge[8, 21] -> 
             RGBColor[
              0.9038665062827225, 0.5622154810471205, 0.48637307486910997`], 
             UndirectedEdge[48, 349] -> 
             RGBColor[
              0.9269547478813611, 0.944592570716998, 0.9928949654268382], 
             UndirectedEdge[222, 332] -> 
             RGBColor[
              0.8148642840062729, 0.8328803666223497, 0.6678105772514669], 
             UndirectedEdge[58, 167] -> 
             RGBColor[
              0.6661102236694036, 0.7307688264630914, 0.8896652706135045], 
             UndirectedEdge[76, 144] -> 
             RGBColor[
              0.953738755938121, 0.9085150957286193, 0.6215272783304258], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.7600355593569093, 0.8127385910698761, 0.9768150193608847], 
             UndirectedEdge[6, 166] -> 
             RGBColor[
              0.6876009018491005, 0.7544096347030491, 0.9705639537639692], 
             UndirectedEdge[79, 343] -> 
             RGBColor[
              0.7863283109341739, 0.8338297917770259, 0.979118619812944], 
             UndirectedEdge[142, 257] -> 
             RGBColor[
              0.9362300066641219, 0.9508844140397086, 0.955503404500867], 
             UndirectedEdge[175, 256] -> 
             RGBColor[
              0.9226632014429466, 0.9383990589946369, 0.8830808194546828], 
             UndirectedEdge[8, 171] -> 
             RGBColor[
              0.8526617749818883, 0.883757996657162, 0.8903736546413832], 
             UndirectedEdge[31, 214] -> 
             RGBColor[
              0.8137604605415192, 0.8553202371094693, 0.981836813858134], 
             UndirectedEdge[41, 114] -> 
             RGBColor[
              0.9935446184128958, 0.9909426579128171, 0.7089696189579573], 
             UndirectedEdge[72, 399] -> 
             RGBColor[
              0.9641449580593584, 0.9000478139026937, 0.5836850403599485], 
             UndirectedEdge[278, 392] -> 
             RGBColor[
              0.9942573473825694, 0.990125371659587, 0.6163258860156322], 
             UndirectedEdge[6, 323] -> 
             RGBColor[
              0.9032170901075384, 0.8888131742147041, 0.657244876613847], 
             UndirectedEdge[132, 323] -> 
             RGBColor[
              0.9807976523058931, 0.9476110700549507, 0.5425953117864818], 
             UndirectedEdge[200, 355] -> 
             RGBColor[
              0.770605325820368, 0.820722004439048, 0.9777703952277201], 
             UndirectedEdge[98, 215] -> 
             RGBColor[
              0.7439054718379885, 0.7996234619278708, 0.9755682164738911], 
             UndirectedEdge[12, 367] -> 
             RGBColor[
              0.9890086766015117, 0.9738577289197868, 0.47371339064792906`], 
             UndirectedEdge[88, 140] -> 
             RGBColor[
              0.9347735619758017, 0.9464721531307935, 0.7787439316428247], 
             UndirectedEdge[195, 327] -> 
             RGBColor[
              0.6990666903462672, 0.7605611563803076, 0.9327896033251029], 
             UndirectedEdge[142, 381] -> 
             RGBColor[
              0.9325000420724899, 0.9161422833017264, 0.6658925383133808], 
             UndirectedEdge[313, 359] -> 
             RGBColor[
              0.37021839352508557`, 0.48441755343036186`, 0.9456733020215791],
              UndirectedEdge[64, 82] -> 
             RGBColor[
              0.8821881879146889, 0.9066335606450086, 0.884669686640844], 
             UndirectedEdge[98, 297] -> 
             RGBColor[
              0.9354218124733338, 0.9090306014679601, 0.6522816508092024], 
             UndirectedEdge[139, 305] -> 
             RGBColor[
              0.38334835901089337`, 0.5064588137516468, 0.9456475963478983], 
             UndirectedEdge[288, 375] -> 
             RGBColor[
              0.9938173460225311, 0.9905403929628596, 0.667011494958572], 
             UndirectedEdge[136, 194] -> 
             RGBColor[
              0.994838962807073, 0.9913693882422605, 0.6796311356585165], 
             UndirectedEdge[254, 349] -> 
             RGBColor[
              0.9353488931948539, 0.9512189083861007, 0.9913752417706017], 
             UndirectedEdge[348, 351] -> 
             RGBColor[
              0.7362590239605372, 0.7902638078713622, 0.8760785707014946], 
             UndirectedEdge[65, 282] -> 
             RGBColor[
              0.7968089091633455, 0.8396987842490665, 0.8924605760044368], 
             UndirectedEdge[131, 215] -> 
             RGBColor[
              0.7274712991793381, 0.786519298743596, 0.9740007104147499], 
             UndirectedEdge[230, 250] -> 
             RGBColor[
              0.9787602979106026, 0.9833611850948509, 0.9065582355150622], 
             UndirectedEdge[26, 111] -> 
             RGBColor[
              0.9277498772902478, 0.9419097354254686, 0.8598871470349362], 
             UndirectedEdge[301, 390] -> 
             RGBColor[
              0.8437307546096049, 0.8782320175372166, 0.9849569866536423], 
             UndirectedEdge[3, 309] -> 
             RGBColor[
              0.6956494609127561, 0.7606335808642815, 0.9715546425335893], 
             UndirectedEdge[90, 268] -> 
             RGBColor[
              0.9443418120642099, 0.9571807735010832, 0.9501004265105691], 
             UndirectedEdge[17, 187] -> 
             RGBColor[
              0.4807834155298763, 0.5858208359111795, 0.9532462425126776], 
             UndirectedEdge[4, 206] -> 
             RGBColor[
              0.8654881650143667, 0.8920573650134378, 0.7849319581885952], 
             UndirectedEdge[19, 231] -> 
             RGBColor[
              0.6205673158813142, 0.616208249722858, 0.6053599651225812], 
             UndirectedEdge[76, 138] -> 
             RGBColor[
              0.9695577568967553, 0.9767379332951258, 0.932882899888641], 
             UndirectedEdge[28, 390] -> 
             RGBColor[
              0.8307335134666909, 0.8679657694941201, 0.983691451426171], 
             UndirectedEdge[123, 174] -> 
             RGBColor[
              0.901141546009415, 0.859475248613222, 0.631575719967193], 
             UndirectedEdge[2, 98] -> 
             RGBColor[
              0.9410490871482007, 0.9280127202932132, 0.6741425502994058], 
             UndirectedEdge[20, 364] -> 
             RGBColor[
              0.9027694837700745, 0.9250132768383158, 0.9803734663747543], 
             UndirectedEdge[56, 196] -> 
             RGBColor[
              0.8730737203368089, 0.9016293019145027, 0.9877557449194776], 
             UndirectedEdge[360, 374] -> 
             RGBColor[
              0.9567155038108053, 0.9390984081921956, 0.670337240044702], 
             UndirectedEdge[39, 360] -> 
             RGBColor[
              0.9298592019681252, 0.9468111902243734, 0.9897980801908526], 
             UndirectedEdge[261, 264] -> 
             RGBColor[
              0.9649141563858831, 0.9730021854647893, 0.9285375924738641], 
             UndirectedEdge[101, 253] -> 
             RGBColor[
              0.9415458239629964, 0.9543507494991403, 0.9237545295978378], 
             UndirectedEdge[141, 273] -> 
             RGBColor[
              0.913732691374548, 0.7316113668201891, 0.5826773980414838], 
             UndirectedEdge[171, 182] -> 
             RGBColor[
              0.6275566749188934, 0.707406423959839, 0.9645825644864991], 
             UndirectedEdge[156, 175] -> 
             RGBColor[
              0.9892122965711652, 0.9898070216479138, 0.828443693704737], 
             UndirectedEdge[121, 250] -> 
             RGBColor[
              0.9895449247834203, 0.9899445719618365, 0.8229311834134514], 
             UndirectedEdge[68, 308] -> 
             RGBColor[
              0.8236387358629503, 0.7625673439324068, 0.6159328623067628], 
             UndirectedEdge[39, 390] -> 
             RGBColor[
              0.8868895866764606, 0.9126456987120397, 0.9890735145845231], 
             UndirectedEdge[54, 181] -> 
             RGBColor[
              0.9629724051643558, 0.9719054609154743, 0.9475622391000491], 
             UndirectedEdge[196, 313] -> 
             RGBColor[
              0.7231308061701761, 0.782661115497437, 0.974043870955072], 
             UndirectedEdge[200, 241] -> 
             RGBColor[
              0.8644486521299446, 0.891583918710315, 0.8119508127786134], 
             UndirectedEdge[186, 255] -> 
             RGBColor[
              0.8023272245851198, 0.8243810654688937, 0.6690127194007475], 
             UndirectedEdge[11, 38] -> 
             RGBColor[
              0.7910253557465886, 0.8358593913018351, 0.9277876034357504], 
             UndirectedEdge[173, 310] -> 
             RGBColor[
              0.7885772390747057, 0.835402874291792, 0.9793915460891054], 
             UndirectedEdge[106, 173] -> 
             RGBColor[
              0.7271460065380906, 0.7867712539126729, 0.973438776432092], 
             UndirectedEdge[51, 396] -> 
             RGBColor[
              0.9813015846079534, 0.9848404998417157, 0.8836283921275407], 
             UndirectedEdge[6, 18] -> 
             RGBColor[
              0.8141178175813553, 0.8548637364182361, 0.9820676562592554], 
             UndirectedEdge[238, 287] -> 
             RGBColor[
              0.9605725261461822, 0.8777506370891912, 0.5410091218135213], 
             UndirectedEdge[93, 225] -> 
             RGBColor[
              0.9669017144706018, 0.974835933362419, 0.9409109433725729], 
             UndirectedEdge[116, 276] -> 
             RGBColor[
              0.5754738720803751, 0.6113377707959187, 0.6396536519069874], 
             UndirectedEdge[135, 276] -> 
             RGBColor[
              0.9832961251229514, 0.9540394334749664, 0.49816321292150856`], 
             UndirectedEdge[147, 172] -> 
             RGBColor[
              0.816214434394058, 0.8570935074350796, 0.9821195611991294], 
             UndirectedEdge[185, 224] -> 
             RGBColor[
              0.8998697226925529, 0.9220160606052035, 0.9563466217858266], 
             UndirectedEdge[160, 166] -> 
             RGBColor[
              0.7500219922483168, 0.8034703629640165, 0.9518268774516392], 
             UndirectedEdge[63, 156] -> 
             RGBColor[
              0.8818111746454611, 0.9072847087818354, 0.9275129734148441], 
             UndirectedEdge[247, 302] -> 
             RGBColor[
              0.9690848061270949, 0.9764640795453472, 0.9372155386396239], 
             UndirectedEdge[81, 240] -> 
             RGBColor[
              0.6335174944571975, 0.6815949889055339, 0.6582063219375527], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.810279899268405, 0.8522084683387241, 0.9815941219344898], 
             UndirectedEdge[12, 212] -> 
             RGBColor[
              0.8622802512772632, 0.8892914373422305, 0.763797072319004], 
             UndirectedEdge[18, 74] -> 
             RGBColor[
              0.7033896687319408, 0.767824416278524, 0.9713363852473945], 
             UndirectedEdge[1, 7] -> 
             RGBColor[
              0.9658558807665444, 0.9510212140735472, 0.6657038842634595], 
             UndirectedEdge[231, 331] -> 
             RGBColor[
              0.4968364396224658, 0.5968466920028429, 0.9552157884830671], 
             UndirectedEdge[58, 351] -> 
             RGBColor[
              0.6672083364222208, 0.7312229243065917, 0.8714667004746194], 
             UndirectedEdge[142, 279] -> 
             RGBColor[
              0.9434885201158736, 0.9548298636661052, 0.8774793797447011], 
             UndirectedEdge[303, 344] -> 
             RGBColor[
              0.918804792323981, 0.9368603123583054, 0.9493442878178612], 
             UndirectedEdge[302, 323] -> 
             RGBColor[
              0.9732986601222238, 0.9435870756300042, 0.625540606485597], 
             UndirectedEdge[144, 366] -> 
             RGBColor[
              0.9456154712396072, 0.9024567633011257, 0.6352778804330428], 
             UndirectedEdge[56, 342] -> 
             RGBColor[
              0.8964405605349985, 0.9194491074933673, 0.9618222888257848], 
             UndirectedEdge[137, 293] -> 
             RGBColor[
              0.9693608740957496, 0.9758888503584903, 0.9017680679425981], 
             UndirectedEdge[39, 374] -> 
             RGBColor[
              0.9471020053969623, 0.9315301788505643, 0.6727942106435362], 
             UndirectedEdge[4, 278] -> 
             RGBColor[
              0.8659143394407984, 0.8929689090187314, 0.8313184144620083], 
             UndirectedEdge[238, 396] -> 
             RGBColor[
              0.9526578702869926, 0.8727824843806528, 0.5962591807991522], 
             UndirectedEdge[118, 293] -> 
             RGBColor[
              0.9439670357622645, 0.8120615394594821, 0.535596562103439], 
             UndirectedEdge[201, 228] -> 
             RGBColor[
              0.7175476801969591, 0.7779847816864705, 0.9728337130852505], 
             UndirectedEdge[212, 336] -> 
             RGBColor[
              0.8574576454107758, 0.8886511626542769, 0.9428576016479235], 
             UndirectedEdge[186, 200] -> 
             RGBColor[
              0.8568547153243182, 0.8672400159564295, 0.6742686115145979], 
             UndirectedEdge[7, 356] -> 
             RGBColor[
              0.9592034409181383, 0.9690945735517578, 0.9539421124655869], 
             UndirectedEdge[215, 269] -> 
             RGBColor[
              0.6573114776327622, 0.7312712591488967, 0.9671242403064885], 
             UndirectedEdge[36, 122] -> 
             RGBColor[
              0.8380523160686439, 0.8739799500110146, 0.9843421925035638], 
             UndirectedEdge[297, 352] -> 
             RGBColor[
              0.9740738105488989, 0.9385549519086458, 0.6106498028657066], 
             UndirectedEdge[228, 243] -> 
             RGBColor[
              0.6997125768439786, 0.7637896847253167, 0.9720385400033995], 
             UndirectedEdge[100, 271] -> 
             RGBColor[
              0.9633381097027147, 0.9705850700316176, 0.8762323728236365], 
             UndirectedEdge[157, 298] -> 
             RGBColor[
              0.9763808054158831, 0.9803180886266252, 0.8537811996834883], 
             UndirectedEdge[272, 384] -> 
             RGBColor[
              0.5576708364310532, 0.6510522883428598, 0.9587080638616265], 
             UndirectedEdge[35, 114] -> 
             RGBColor[
              0.94508021784107, 0.9551564220452582, 0.8175041861802261], 
             UndirectedEdge[15, 155] -> 
             RGBColor[
              0.9292708987345968, 0.9220523580181218, 0.6780669475973559], 
             UndirectedEdge[36, 262] -> 
             RGBColor[
              0.8623468287449532, 0.8932710486831473, 0.9838619808673064], 
             UndirectedEdge[111, 185] -> 
             RGBColor[
              0.9171148990866536, 0.9357668961540164, 0.9579914821052467], 
             UndirectedEdge[26, 400] -> 
             RGBColor[
              0.7958815528961628, 0.8378675536217582, 0.8473078492319416], 
             UndirectedEdge[61, 131] -> 
             RGBColor[
              0.7456361285030844, 0.8012663255048489, 0.9754307123190775], 
             UndirectedEdge[168, 350] -> 
             RGBColor[
              0.37521881485478603`, 0.4844725237874147, 0.9464314768275215], 
             UndirectedEdge[16, 208] -> 
             RGBColor[
              0.614404621433587, 0.6786609334029035, 0.8612181998107782], 
             UndirectedEdge[125, 303] -> 
             RGBColor[
              0.930963142025431, 0.9465550503806308, 0.9505039620662723], 
             UndirectedEdge[145, 164] -> 
             RGBColor[
              0.866606009209663, 0.8949683831102573, 0.9061396381867916], 
             UndirectedEdge[152, 256] -> 
             RGBColor[
              0.9197489024863452, 0.9371939214820153, 0.9313782951295047], 
             UndirectedEdge[237, 246] -> 
             RGBColor[
              0.7973177874313873, 0.8415572333356791, 0.9472359038707681], 
             UndirectedEdge[16, 284] -> 
             RGBColor[
              0.5904277572426657, 0.5907531244479496, 0.6052405968327925], 
             UndirectedEdge[240, 309] -> 
             RGBColor[
              0.7449696136971735, 0.7785976092310005, 0.6656593819376092], 
             UndirectedEdge[151, 249] -> 
             RGBColor[
              0.7729083146709348, 0.8195337139895976, 0.8587457247703142], 
             UndirectedEdge[47, 311] -> 
             RGBColor[
              0.9664681711449291, 0.9722243744573071, 0.823766029069791], 
             UndirectedEdge[29, 190] -> 
             RGBColor[
              0.9570932309721072, 0.9675207824291595, 0.9575141474733178], 
             UndirectedEdge[99, 384] -> 
             RGBColor[
              0.4802595917102056, 0.5886618945096127, 0.9523025105790247], 
             UndirectedEdge[5, 398] -> 
             RGBColor[
              0.848858633199941, 0.8816130698575255, 0.9274542212013794], 
             UndirectedEdge[36, 157] -> 
             RGBColor[
              0.8724404663994574, 0.9007988671190619, 0.9667760851605521], 
             UndirectedEdge[40, 55] -> 
             RGBColor[
              0.7505705177800825, 0.8033317128320379, 0.936207239359071], 
             UndirectedEdge[163, 319] -> 
             RGBColor[
              0.9804992721254259, 0.9517292995984281, 0.5768581450648259], 
             UndirectedEdge[13, 74] -> 
             RGBColor[
              0.5587435030554042, 0.6526521727451664, 0.9584054817868638], 
             UndirectedEdge[47, 158] -> 
             RGBColor[
              0.9690566091254971, 0.9741548272650364, 0.8193844787414364], 
             UndirectedEdge[252, 330] -> 
             RGBColor[
              0.9882831894132424, 0.9884726080693673, 0.7851431726684627], 
             UndirectedEdge[102, 185] -> 
             RGBColor[
              0.8076429404104031, 0.8499070929848217, 0.9471753082521508], 
             UndirectedEdge[41, 356] -> 
             RGBColor[
              0.9785537877136968, 0.9821345515577895, 0.8588737523439981], 
             UndirectedEdge[33, 175] -> 
             RGBColor[
              0.8915223036331333, 0.9138030066484079, 0.880048249719581], 
             UndirectedEdge[12, 126] -> 
             RGBColor[
              0.9918665408403615, 0.9895249597287525, 0.6841692697864784], 
             UndirectedEdge[18, 191] -> 
             RGBColor[
              0.8855568004349165, 0.8922216866435762, 0.6808668382086552], 
             UndirectedEdge[64, 171] -> 
             RGBColor[
              0.7439173112478563, 0.7998731246185787, 0.9751103833488082], 
             UndirectedEdge[73, 184] -> 
             RGBColor[
              0.9098746125990291, 0.9276061103237421, 0.855994764559111], 
             UndirectedEdge[93, 316] -> 
             RGBColor[
              0.9510516698766079, 0.9630149960562846, 0.9677409345165024], 
             UndirectedEdge[20, 362] -> 
             RGBColor[
              0.9132454621944098, 0.9333665376710218, 0.9813726745488838], 
             UndirectedEdge[32, 330] -> 
             RGBColor[
              0.9937426619632637, 0.9890245115903702, 0.5603055543944178], 
             UndirectedEdge[124, 277] -> 
             RGBColor[
              0.9445520375160416, 0.953440530425368, 0.7124983952633934], 
             UndirectedEdge[267, 331] -> 
             RGBColor[
              0.8227584074225618, 0.8620861304499989, 0.9668490401929427], 
             UndirectedEdge[134, 167] -> 
             RGBColor[
              0.9847172243848373, 0.9873666483251767, 0.8768958790371326], 
             UndirectedEdge[143, 398] -> 
             RGBColor[
              0.9881806123153312, 0.9893803936950505, 0.8455413717371743], 
             UndirectedEdge[109, 320] -> 
             RGBColor[
              0.7877886912973273, 0.833706097228517, 0.9434016404431109], 
             UndirectedEdge[28, 147] -> 
             RGBColor[
              0.7643303189353898, 0.8158199213686843, 0.977144961184699], 
             UndirectedEdge[54, 311] -> 
             RGBColor[
              0.9591037339348785, 0.9690202122468978, 0.9541108903804996], 
             UndirectedEdge[160, 289] -> 
             RGBColor[
              0.8009667233710602, 0.8448295907234427, 0.9558374333023205], 
             UndirectedEdge[209, 240] -> 
             RGBColor[
              0.9058180238982543, 0.9063761980502649, 0.6802794650271753], 
             UndirectedEdge[31, 261] -> 
             RGBColor[
              0.8421680527594331, 0.8763152006655848, 0.9235617175112818], 
             UndirectedEdge[245, 248] -> 
             RGBColor[
              0.9269489392976543, 0.9433200650969107, 0.9487843600409056], 
             UndirectedEdge[81, 245] -> 
             RGBColor[
              0.5783315936917917, 0.6589537723202619, 0.9635421022546911], 
             UndirectedEdge[308, 386] -> 
             RGBColor[
              0.922907094081693, 0.8409269178648379, 0.6256119551275998], 
             UndirectedEdge[320, 349] -> 
             RGBColor[
              0.765898212982131, 0.8172952318115433, 0.9775101125515757], 
             UndirectedEdge[222, 356] -> 
             RGBColor[
              0.8080465055159489, 0.850396000038012, 0.9554064960513259], 
             UndirectedEdge[200, 374] -> 
             RGBColor[
              0.85414560640354, 0.8581015554376203, 0.6637442349296665], 
             UndirectedEdge[73, 348] -> 
             RGBColor[
              0.7383999762175406, 0.7911491466495963, 0.8405974511961164], 
             UndirectedEdge[23, 81] -> 
             RGBColor[
              0.3049983831833343, 0.4365898585610943, 0.9407286599336466], 
             UndirectedEdge[25, 233] -> 
             RGBColor[
              0.9946113463565481, 0.9908825396701411, 0.654856489704792], 
             UndirectedEdge[168, 170] -> 
             RGBColor[
              0.7739388654368232, 0.8223824426816673, 0.9401725418763431], 
             UndirectedEdge[73, 284] -> 
             RGBColor[
              0.9695315576002871, 0.9036757708768298, 0.5012681778149635], 
             UndirectedEdge[143, 234] -> 
             RGBColor[
              0.6114684763015705, 0.676006788575355, 0.8723174513756002], 
             UndirectedEdge[288, 374] -> 
             RGBColor[
              0.9839414975543992, 0.9566156217079091, 0.4667256607072565], 
             UndirectedEdge[254, 344] -> 
             RGBColor[
              0.8961816117263877, 0.9199879813106786, 0.9876394314990945], 
             UndirectedEdge[6, 102] -> 
             RGBColor[
              0.7400353447114056, 0.7969782775634005, 0.9746917851797828], 
             UndirectedEdge[205, 276] -> 
             RGBColor[
              0.9008932452663497, 0.8921891203151988, 0.6647156477575997], 
             UndirectedEdge[101, 244] -> 
             RGBColor[
              0.9451834660134726, 0.9553772594460359, 0.8287421125723953], 
             UndirectedEdge[58, 80] -> 
             RGBColor[
              0.5456236827762666, 0.6374037281990881, 0.9593007136400991], 
             UndirectedEdge[23, 292] -> 
             RGBColor[
              0.639625248008294, 0.7105371124645028, 0.9503266199364363], 
             UndirectedEdge[101, 397] -> 
             RGBColor[
              0.9044207133579241, 0.9266245432580819, 0.9907456490976226], 
             UndirectedEdge[105, 168] -> 
             RGBColor[
              0.7774398833065403, 0.8121482874693805, 0.6788992920180124], 
             UndirectedEdge[166, 340] -> 
             RGBColor[
              0.7656932496983008, 0.8128809087801216, 0.8083070812786297], 
             UndirectedEdge[138, 317] -> 
             RGBColor[
              0.9889487884460753, 0.9879285402501738, 0.7041857162390149], 
             UndirectedEdge[71, 120] -> 
             RGBColor[
              0.9563227645612596, 0.9658757830371046, 0.9139738398090865], 
             UndirectedEdge[231, 290] -> 
             RGBColor[
              0.6414142166139516, 0.7099205218877057, 0.9285422473763528], 
             UndirectedEdge[13, 224] -> 
             RGBColor[
              0.6632604071889383, 0.7347388149481817, 0.9685443187328804], 
             UndirectedEdge[40, 159] -> 
             RGBColor[
              0.7346907812772598, 0.7914886313489149, 0.9630874911597578], 
             UndirectedEdge[20, 265] -> 
             RGBColor[
              0.9704932513976222, 0.9746832527793091, 0.7738663084638457], 
             UndirectedEdge[43, 299] -> 
             RGBColor[
              0.5080345635768928, 0.6001906428282127, 0.9571874625421208], 
             UndirectedEdge[219, 220] -> 
             RGBColor[
              0.9356004309566446, 0.950239186489859, 0.9504777940674669], 
             UndirectedEdge[56, 290] -> 
             RGBColor[
              0.9034734050909708, 0.9246941914479854, 0.9499175174521527], 
             UndirectedEdge[64, 157] -> 
             RGBColor[
              0.865970141125056, 0.8957441998384059, 0.9661311836058273], 
             UndirectedEdge[13, 340] -> 
             RGBColor[
              0.7475639997540191, 0.7981627669619509, 0.8068798803133852], 
             UndirectedEdge[16, 188] -> 
             RGBColor[
              0.6155798248393329, 0.6781671230014585, 0.7705218509634195], 
             UndirectedEdge[171, 308] -> 
             RGBColor[
              0.8202390110037177, 0.7599114530335084, 0.6155940095050296], 
             UndirectedEdge[288, 379] -> 
             RGBColor[
              0.9762336725568103, 0.9306153181076678, 0.43678221609223883`], 
             UndirectedEdge[81, 353] -> 
             RGBColor[
              0.3321931327501654, 0.46014458378802725`, 0.9424614853286722], 
             UndirectedEdge[153, 188] -> 
             RGBColor[
              0.960765977474764, 0.9674119819537312, 0.7985854187440877], 
             UndirectedEdge[148, 356] -> 
             RGBColor[
              0.9783326592587437, 0.9820431092589244, 0.8625384231046689], 
             UndirectedEdge[198, 247] -> 
             RGBColor[
              0.9753930440342399, 0.9799956664759617, 0.8740041238758021], 
             UndirectedEdge[94, 375] -> 
             RGBColor[
              0.7115920721445093, 0.7690387931607544, 0.8512458646661608], 
             UndirectedEdge[298, 307] -> 
             RGBColor[
              0.7755301272361348, 0.8215867520543493, 0.8557972864224761], 
             UndirectedEdge[9, 142] -> 
             RGBColor[
              0.9437188083660775, 0.9549250937757027, 0.8736629074719353], 
             UndirectedEdge[203, 284] -> 
             RGBColor[
              0.9661823604605918, 0.9022907917891254, 0.5567730418640703], 
             UndirectedEdge[370, 400] -> 
             RGBColor[
              0.6292934289500365, 0.7096302410755078, 0.9641628599374947], 
             UndirectedEdge[63, 381] -> 
             RGBColor[
              0.8741829113003801, 0.8699866635487836, 0.6602386784757631], 
             UndirectedEdge[222, 251] -> 
             RGBColor[
              0.8176722318214689, 0.8575748509559886, 0.939112652207577], 
             UndirectedEdge[103, 234] -> 
             RGBColor[
              0.6108224759518366, 0.6757396508292883, 0.8830233489660064], 
             UndirectedEdge[150, 399] -> 
             RGBColor[
              0.9489576219986801, 0.9606860946731055, 0.942932881326912], 
             UndirectedEdge[321, 338] -> 
             RGBColor[
              0.8752489715017522, 0.9026889179097619, 0.9516688590889867], 
             UndirectedEdge[154, 203] -> 
             RGBColor[
              0.8813025126138321, 0.9064800784694634, 0.9089953922174916], 
             UndirectedEdge[225, 390] -> 
             RGBColor[
              0.9155492301971561, 0.934418511889161, 0.9543763883500078], 
             UndirectedEdge[54, 121] -> 
             RGBColor[
              0.9864458680015717, 0.9879521608686459, 0.8424562974891568], 
             UndirectedEdge[234, 346] -> 
             RGBColor[
              0.5526933806061631, 0.6315909271489252, 0.9621449829243166], 
             UndirectedEdge[358, 391] -> 
             RGBColor[
              0.9522346564329792, 0.9636878431119351, 0.9584776414293724], 
             UndirectedEdge[74, 357] -> 
             RGBColor[
              0.8027665674174977, 0.8447401965576171, 0.901487556292381], 
             UndirectedEdge[130, 364] -> 
             RGBColor[
              0.8791964375225941, 0.9065113904017172, 0.988339735150472], 
             UndirectedEdge[202, 381] -> 
             RGBColor[
              0.9570957183468078, 0.935562308256339, 0.6615852136862116], 
             UndirectedEdge[98, 307] -> 
             RGBColor[
              0.7322186845530484, 0.7901356015261891, 0.9746481897687083], 
             UndirectedEdge[242, 317] -> 
             RGBColor[
              0.9868039752927715, 0.9666996560756292, 0.44143269896839143`], 
             UndirectedEdge[9, 279] -> 
             RGBColor[
              0.993258030584872, 0.9914800366332033, 0.7613954110736121], 
             UndirectedEdge[200, 399] -> 
             RGBColor[
              0.8597847170835675, 0.890274326737995, 0.9342437786557966], 
             UndirectedEdge[275, 306] -> 
             RGBColor[
              0.9827515122895981, 0.9839865227552564, 0.7658972057806527], 
             UndirectedEdge[121, 181] -> 
             RGBColor[
              0.9695051173151372, 0.9753177767446366, 0.8711325695458796], 
             UndirectedEdge[239, 271] -> 
             RGBColor[
              0.9830168140136829, 0.9853240095632583, 0.8450916354118461], 
             UndirectedEdge[35, 354] -> 
             RGBColor[
              0.9400190898009597, 0.95371940568786, 0.9490564657241397], 
             UndirectedEdge[31, 310] -> 
             RGBColor[
              0.7986639587193411, 0.8432826963400901, 0.9803968960375284], 
             UndirectedEdge[146, 154] -> 
             RGBColor[
              0.881588528090521, 0.8991570501762955, 0.6951260365734102], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.8828923993242874, 0.907570341389341, 0.9022720217327374], 
             UndirectedEdge[265, 322] -> 
             RGBColor[
              0.9652049169756796, 0.8877096432244302, 0.42057300093688854`], 
             UndirectedEdge[115, 284] -> 
             RGBColor[
              0.9550576023938764, 0.8947134347029815, 0.6078236591131951], 
             UndirectedEdge[38, 391] -> 
             RGBColor[
              0.9810687995457467, 0.9852265937183158, 0.9090871518183832], 
             UndirectedEdge[116, 328] -> 
             RGBColor[
              0.5776363860535187, 0.6186324382097599, 0.6480546103361536], 
             UndirectedEdge[92, 278] -> 
             RGBColor[
              0.9947447114534971, 0.991167794127235, 0.6693724574736979], 
             UndirectedEdge[215, 217] -> 
             RGBColor[
              0.7876968126267028, 0.8307763362475964, 0.8126573934349043], 
             UndirectedEdge[159, 210] -> 
             RGBColor[
              0.9551078315601075, 0.9660400747984832, 0.9608749108027348], 
             UndirectedEdge[165, 298] -> 
             RGBColor[
              0.9698322637169126, 0.9074861844455833, 0.5143221440258557], 
             UndirectedEdge[83, 254] -> 
             RGBColor[
              0.7333031129684715, 0.7907235086051234, 0.9726728046665271], 
             UndirectedEdge[103, 231] -> 
             RGBColor[
              0.6453566844681263, 0.7120372935751937, 0.8849900210522259], 
             UndirectedEdge[245, 319] -> 
             RGBColor[
              0.9298934271002464, 0.9445376864731674, 0.8999865770617907], 
             UndirectedEdge[58, 263] -> 
             RGBColor[
              0.6650110209783705, 0.7303142779021286, 0.9078819038493017], 
             UndirectedEdge[206, 258] -> 
             RGBColor[
              0.8282240143880253, 0.8629463273261058, 0.7812178159074482], 
             UndirectedEdge[213, 391] -> 
             RGBColor[
              0.7731777837504463, 0.8218209553484062, 0.94162516619652], 
             UndirectedEdge[78, 370] -> 
             RGBColor[
              0.6292934289500365, 0.7096302410755078, 0.9641628599374947], 
             UndirectedEdge[101, 270] -> 
             RGBColor[
              0.8944545509511294, 0.9186777958791756, 0.9897950676303644], 
             UndirectedEdge[135, 377] -> 
             RGBColor[
              0.9728407006837848, 0.9173356911770784, 0.4650201000281331], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.9930328799880763, 0.9891736821516675, 0.604246906627333], 
             UndirectedEdge[19, 83] -> 
             RGBColor[
              0.733941017904967, 0.7130345693301745, 0.6131223505496732], 
             UndirectedEdge[100, 112] -> 
             RGBColor[
              0.8364642366784913, 0.8730871482346221, 0.9840916074116978], 
             UndirectedEdge[10, 296] -> 
             RGBColor[
              0.4753580570210896, 0.5849561111829744, 0.9518410740240892], 
             UndirectedEdge[85, 369] -> 
             RGBColor[
              0.9940758694512318, 0.9897372087146894, 0.5965731331415073], 
             UndirectedEdge[79, 246] -> 
             RGBColor[
              0.8116600805455827, 0.8530744401102941, 0.9484514792750385], 
             UndirectedEdge[227, 280] -> 
             RGBColor[
              0.9887031395997324, 0.9873832232318347, 0.6760019098711303], 
             UndirectedEdge[112, 326] -> 
             RGBColor[
              0.8256337144690296, 0.8644511838114909, 0.9830585825348379], 
             UndirectedEdge[34, 308] -> 
             RGBColor[
              0.9370311230557884, 0.8518590935129893, 0.615519832825038], 
             UndirectedEdge[29, 226] -> 
             RGBColor[
              0.9615153992401665, 0.9706798107935406, 0.9438030828813952], 
             UndirectedEdge[204, 345] -> 
             RGBColor[
              0.7663461575908841, 0.7065179424819672, 0.6081159318027679], 
             UndirectedEdge[54, 265] -> 
             RGBColor[
              0.9868878007009363, 0.9869102808061101, 0.7461146128766096], 
             UndirectedEdge[22, 100] -> 
             RGBColor[
              0.9203309800343153, 0.9393109580331522, 0.9922631845364795], 
             UndirectedEdge[126, 336] -> 
             RGBColor[
              0.987043934973874, 0.9888846850407991, 0.8632297991153981], 
             UndirectedEdge[82, 157] -> 
             RGBColor[
              0.9752332439423635, 0.9798435424663403, 0.8727992630936015], 
             UndirectedEdge[344, 349] -> 
             RGBColor[
              0.893236192902275, 0.9177063102424673, 0.9896788595520236], 
             UndirectedEdge[343, 349] -> 
             RGBColor[
              0.9272211936297688, 0.9448050273243012, 0.9929203792601802], 
             UndirectedEdge[2, 66] -> 
             RGBColor[
              0.7882576351276829, 0.807321274893116, 0.6595281412689984], 
             UndirectedEdge[211, 387] -> 
             RGBColor[
              0.9181445972855405, 0.9371603167107082, 0.9779340244966084], 
             UndirectedEdge[250, 265] -> 
             RGBColor[
              0.989986857482785, 0.9889026918993007, 0.7265894988009041], 
             UndirectedEdge[217, 306] -> 
             RGBColor[
              0.9830577681485047, 0.9846415730702404, 0.7992312660305456], 
             UndirectedEdge[374, 375] -> 
             RGBColor[
              0.9838341557077743, 0.9577421680733369, 0.5536192047487012], 
             UndirectedEdge[38, 247] -> 
             RGBColor[
              0.9723896128654269, 0.9787536705029972, 0.9237787509737401], 
             UndirectedEdge[204, 310] -> 
             RGBColor[
              0.7566218342028199, 0.8100037959026793, 0.9765041286584442], 
             UndirectedEdge[226, 266] -> 
             RGBColor[
              0.9820702114742057, 0.986009556102271, 0.9090091473227923], 
             UndirectedEdge[319, 334] -> 
             RGBColor[
              0.961685768794283, 0.9698880367598663, 0.9030189589939265], 
             UndirectedEdge[73, 206] -> 
             RGBColor[
              0.9946432789149084, 0.9910034728126778, 0.6621579881332995], 
             UndirectedEdge[200, 255] -> 
             RGBColor[
              0.6798054148282391, 0.7495267635693186, 0.968899207248097], 
             UndirectedEdge[296, 383] -> 
             RGBColor[
              0.6829425537037717, 0.7501876367797911, 0.9707038258014618], 
             UndirectedEdge[235, 281] -> 
             RGBColor[
              0.6959574888839817, 0.7619712736466461, 0.9706277951523303], 
             UndirectedEdge[174, 272] -> 
             RGBColor[
              0.7630698694518898, 0.8151105360648185, 0.9769462785448111], 
             UndirectedEdge[9, 131] -> 
             RGBColor[
              0.9338717509153189, 0.9470733174557218, 0.87272368634171], 
             UndirectedEdge[228, 361] -> 
             RGBColor[
              0.5571881141906719, 0.6513894379953069, 0.9582830358778549], 
             UndirectedEdge[149, 199] -> 
             RGBColor[
              0.7455981431792571, 0.7685879959905315, 0.6500768832207029], 
             UndirectedEdge[102, 400] -> 
             RGBColor[
              0.6192009519955407, 0.7017342533718063, 0.9631649136303639], 
             UndirectedEdge[45, 350] -> 
             RGBColor[
              0.5858647175475526, 0.6490543246886666, 0.8697823449679447], 
             UndirectedEdge[369, 392] -> 
             RGBColor[
              0.993785335364694, 0.9891157856810872, 0.564950290790409], 
             UndirectedEdge[82, 151] -> 
             RGBColor[
              0.9924093874284143, 0.9911291008788736, 0.7754596243942058], 
             UndirectedEdge[260, 342] -> 
             RGBColor[
              0.9805108443510713, 0.983385465629936, 0.8462169434917801], 
             UndirectedEdge[296, 380] -> 
             RGBColor[
              0.7275773574741813, 0.7836877186366868, 0.8951298608608684], 
             UndirectedEdge[105, 148] -> 
             RGBColor[
              0.9888632251122172, 0.9770515794230947, 0.5893659821095838], 
             UndirectedEdge[94, 288] -> 
             RGBColor[
              0.7116994139911341, 0.7679122467953268, 0.7643523206247161], 
             UndirectedEdge[195, 258] -> 
             RGBColor[
              0.8214826757189568, 0.8606084059541396, 0.9423680160994381], 
             UndirectedEdge[339, 374] -> 
             RGBColor[
              0.8852132556338489, 0.8823718391392171, 0.6668407678612549], 
             UndirectedEdge[199, 367] -> 
             RGBColor[
              0.7518789692593082, 0.7897746971666382, 0.6744767065072198], 
             UndirectedEdge[36, 298] -> 
             RGBColor[
              0.8898060746626099, 0.9121627740859494, 0.8662965247854558], 
             UndirectedEdge[147, 347] -> 
             RGBColor[
              0.8533237228008247, 0.8851012317896737, 0.9278992596041609], 
             UndirectedEdge[38, 205] -> 
             RGBColor[
              0.9075059357937101, 0.92763180345247, 0.9388992044461301], 
             UndirectedEdge[16, 73] -> 
             RGBColor[
              0.616117189503218, 0.6793691243106877, 0.8328365149129007], 
             UndirectedEdge[108, 290] -> 
             RGBColor[
              0.9873225675864263, 0.9868993257534431, 0.7187817032133448], 
             UndirectedEdge[225, 296] -> 
             RGBColor[
              0.7220754865726686, 0.7803115665933024, 0.9370056512545936], 
             UndirectedEdge[24, 144] -> 
             RGBColor[
              0.9723826815136867, 0.9211662691799375, 0.5338365631498219], 
             UndirectedEdge[209, 319] -> 
             RGBColor[
              0.9109101923906789, 0.9294009704019375, 0.8981759391886586], 
             UndirectedEdge[80, 192] -> 
             RGBColor[
              0.8674744386443575, 0.8959244716331067, 0.9188166982839308], 
             UndirectedEdge[42, 221] -> 
             RGBColor[
              0.9144952966326787, 0.9339474710444775, 0.9670810148099961], 
             UndirectedEdge[22, 365] -> 
             RGBColor[
              0.8931740870539344, 0.9176567887248188, 0.9896729358407663], 
             UndirectedEdge[80, 201] -> 
             RGBColor[
              0.8422410412497583, 0.8776017108818678, 0.9837540505621092], 
             UndirectedEdge[39, 375] -> 
             RGBColor[
              0.9569778538650942, 0.9654549501055147, 0.8730800448948517], 
             UndirectedEdge[15, 326] -> 
             RGBColor[
              0.8962568134708797, 0.9201148710913116, 0.989966969038397], 
             UndirectedEdge[86, 95] -> 
             RGBColor[
              0.7286438702734985, 0.7873640590036227, 0.9742163883710836], 
             UndirectedEdge[59, 194] -> 
             RGBColor[
              0.9926943927994892, 0.9910705425400351, 0.7579128117379541], 
             UndirectedEdge[296, 324] -> 
             RGBColor[
              0.6813700427771141, 0.5995882030831703, 0.5931056405253631], 
             UndirectedEdge[169, 245] -> 
             RGBColor[
              0.9277678613540141, 0.9436587104125523, 0.9352127022646761], 
             UndirectedEdge[258, 284] -> 
             RGBColor[
              0.8031122930734039, 0.7756186253902578, 0.6203280055891123], 
             UndirectedEdge[33, 152] -> 
             RGBColor[
              0.8886080046765319, 0.9125978691357862, 0.9283457253944027], 
             UndirectedEdge[246, 349] -> 
             RGBColor[
              0.9525529632411776, 0.9640496756575695, 0.9622532387222746], 
             UndirectedEdge[27, 395] -> 
             RGBColor[
              0.988578955987587, 0.9891734770800378, 0.8222968999092816], 
             UndirectedEdge[185, 340] -> 
             RGBColor[
              0.9841733152576337, 0.9854400126189727, 0.7946821833663315], 
             UndirectedEdge[223, 321] -> 
             RGBColor[
              0.6502197445778688, 0.7185170674087131, 0.9335399745390456], 
             UndirectedEdge[274, 373] -> 
             RGBColor[
              0.7688354190192821, 0.8181787161800428, 0.9381475827816395], 
             UndirectedEdge[156, 214] -> 
             RGBColor[
              0.9578997207201487, 0.9676107727048362, 0.9348618867087513], 
             UndirectedEdge[205, 221] -> 
             RGBColor[
              0.8965041314195004, 0.9196018042606592, 0.9653650014110604], 
             UndirectedEdge[97, 105] -> 
             RGBColor[
              0.970426895587724, 0.9646197990604832, 0.6795967914391696], 
             UndirectedEdge[130, 158] -> 
             RGBColor[
              0.921724576364652, 0.9402217505912277, 0.9854473044150986], 
             UndirectedEdge[108, 143] -> 
             RGBColor[
              0.991911035790335, 0.989283235186998, 0.6645235792988118], 
             UndirectedEdge[176, 399] -> 
             RGBColor[
              0.905104701946709, 0.925718966579468, 0.9387501506643912], 
             UndirectedEdge[150, 189] -> 
             RGBColor[
              0.9499160830396394, 0.9610824429448674, 0.9270487014605546], 
             UndirectedEdge[253, 386] -> 
             RGBColor[
              0.9538493139640073, 0.9641612184566073, 0.9249280474575894], 
             UndirectedEdge[46, 59] -> 
             RGBColor[
              0.962863932555764, 0.8859583939372855, 0.5385617751348979], 
             UndirectedEdge[186, 241] -> 
             RGBColor[
              0.9869704618868252, 0.96643822060989, 0.5120643249312639], 
             UndirectedEdge[39, 93] -> 
             RGBColor[
              0.9382420709499063, 0.9530631201852976, 0.9756080696070882], 
             UndirectedEdge[214, 264] -> 
             RGBColor[
              0.9365065641679692, 0.9520072219086737, 0.9868126888207163], 
             UndirectedEdge[234, 290] -> 
             RGBColor[
              0.6068800080976617, 0.6736228791418002, 0.9265755752901332], 
             UndirectedEdge[148, 170] -> 
             RGBColor[
              0.9853622072425001, 0.9872857346353814, 0.8506392319679146], 
             UndirectedEdge[50, 362] -> 
             RGBColor[
              0.9209232294453066, 0.9390926039155505, 0.9683762172755225], 
             UndirectedEdge[271, 326] -> 
             RGBColor[
              0.9525075874932529, 0.9619491056084865, 0.8751993479467768], 
             UndirectedEdge[61, 352] -> 
             RGBColor[
              0.8007222992372999, 0.8438948391298093, 0.9353663704347228], 
             UndirectedEdge[256, 333] -> 
             RGBColor[
              0.9232157793856818, 0.9368508060021008, 0.7447716101924535], 
             UndirectedEdge[100, 394] -> 
             RGBColor[
              0.9589815067022819, 0.9687835027313484, 0.9484325590679603], 
             UndirectedEdge[1, 114] -> 
             RGBColor[
              0.9861833212790871, 0.96380935528947, 0.5067662624741822], 
             UndirectedEdge[218, 269] -> 
             RGBColor[
              0.8230192292650063, 0.8624127070957303, 0.9827969391801405], 
             UndirectedEdge[182, 253] -> 
             RGBColor[
              0.763828368406594, 0.8133401463650336, 0.9072735067769719], 
             UndirectedEdge[57, 354] -> 
             RGBColor[
              0.9766778656831079, 0.9820925049426045, 0.9228190120768787], 
             UndirectedEdge[40, 192] -> 
             RGBColor[
              0.753660547560861, 0.8051399862733262, 0.9087528325358674], 
             UndirectedEdge[262, 314] -> 
             RGBColor[
              0.8697356774913891, 0.8990432734811935, 0.9845984322576338], 
             UndirectedEdge[244, 253] -> 
             RGBColor[
              0.9910905664242088, 0.990105985977368, 0.7625886271000495], 
             UndirectedEdge[277, 330] -> 
             RGBColor[
              0.9455619767916624, 0.9556006884153969, 0.8224240527919909], 
             UndirectedEdge[304, 329] -> 
             RGBColor[
              0.689154598616674, 0.7502316735682166, 0.8728650968953323], 
             UndirectedEdge[103, 223] -> 
             RGBColor[
              0.6567019586100928, 0.7225279776373376, 0.8856886204073722], 
             UndirectedEdge[92, 337] -> 
             RGBColor[
              0.9790259521784492, 0.9815408233506493, 0.798611230652051], 
             UndirectedEdge[226, 341] -> 
             RGBColor[
              0.9891042568369175, 0.9879487582186095, 0.6984056184983723], 
             UndirectedEdge[193, 260] -> 
             RGBColor[
              0.9945131681259083, 0.9919990682619851, 0.7405945338268096], 
             UndirectedEdge[9, 214] -> 
             RGBColor[
              0.9614902236686553, 0.9690955379457606, 0.8753579609282249], 
             UndirectedEdge[8, 157] -> 
             RGBColor[
              0.9747146048590878, 0.9796290718769893, 0.8813944548984023], 
             UndirectedEdge[103, 342] -> 
             RGBColor[
              0.9781735466554349, 0.9824189329669795, 0.8849520150410135], 
             UndirectedEdge[165, 314] -> 
             RGBColor[
              0.8732807734469228, 0.833739187736066, 0.628053480893247], 
             UndirectedEdge[115, 392] -> 
             RGBColor[
              0.9799349286956577, 0.9815397894073354, 0.7432010188022229], 
             UndirectedEdge[104, 233] -> 
             RGBColor[
              0.8445389040702196, 0.8759601804737844, 0.8043524043090663], 
             UndirectedEdge[67, 139] -> 
             RGBColor[
              0.6744927580921232, 0.7418647502009771, 0.9689984886711568], 
             UndirectedEdge[116, 364] -> 
             RGBColor[
              0.5186709551479936, 0.5976673823453749, 0.9599292872658549], 
             UndirectedEdge[74, 220] -> 
             RGBColor[
              0.7520766373368661, 0.8064018124259513, 0.9760450138011537], 
             UndirectedEdge[100, 168] -> 
             RGBColor[
              0.7512751286325396, 0.8054172708040541, 0.9763661606781546], 
             UndirectedEdge[129, 308] -> 
             RGBColor[
              0.9595167999637878, 0.8655208711141822, 0.39453258719683715`], 
             UndirectedEdge[26, 185] -> 
             RGBColor[
              0.9843235413110252, 0.9860403932347737, 0.8313182438537284], 
             UndirectedEdge[197, 215] -> 
             RGBColor[
              0.6547740991042161, 0.7292890397576055, 0.9668713381279135], 
             UndirectedEdge[178, 240] -> 
             RGBColor[
              0.9169648751453285, 0.9152643946614654, 0.6813426616500328], 
             UndirectedEdge[52, 223] -> 
             RGBColor[
              0.6336542228368114, 0.6336039275259208, 0.6074599231208706], 
             UndirectedEdge[192, 243] -> 
             RGBColor[
              0.944110598486211, 0.9564483845857285, 0.9262812145274015], 
             UndirectedEdge[124, 252] -> 
             RGBColor[
              0.9872732501376216, 0.9863124500793385, 0.6752175151398652], 
             UndirectedEdge[194, 396] -> 
             RGBColor[
              0.9845328005380384, 0.9860002752831856, 0.8172552459599776], 
             UndirectedEdge[269, 279] -> 
             RGBColor[
              0.8634816411185392, 0.891730047751425, 0.8696636885062143], 
             UndirectedEdge[57, 208] -> 
             RGBColor[
              0.9803760645190669, 0.9836218052006485, 0.8615302867332439], 
             UndirectedEdge[169, 304] -> 
             RGBColor[
              0.9884297251062226, 0.9894834082359907, 0.8414129281088671], 
             UndirectedEdge[209, 280] -> 
             RGBColor[
              0.9121826788701798, 0.9277139273389676, 0.7162077126276309], 
             UndirectedEdge[226, 399] -> 
             RGBColor[
              0.985132648068475, 0.9881199821498672, 0.896054027186201], 
             UndirectedEdge[206, 392] -> 
             RGBColor[
              0.9938311729561375, 0.9892138276542936, 0.5699394297422192], 
             UndirectedEdge[48, 343] -> 
             RGBColor[
              0.9217724671403886, 0.9404603607234099, 0.9924006748634876], 
             UndirectedEdge[159, 263] -> 
             RGBColor[
              0.9678920105628603, 0.9751836664117359, 0.9217325471170239], 
             UndirectedEdge[261, 295] -> 
             RGBColor[
              0.9833695330446601, 0.9867661751589996, 0.8972974537236862], 
             UndirectedEdge[33, 204] -> 
             RGBColor[
              0.7024359353048799, 0.7670322852286682, 0.9712735061470416], 
             UndirectedEdge[64, 151] -> 
             RGBColor[
              0.8831462846111067, 0.9070297582509392, 0.8687915449064316], 
             UndirectedEdge[210, 263] -> 
             RGBColor[
              0.9737602754563793, 0.9795602087609205, 0.9117991053409036], 
             UndirectedEdge[19, 303] -> 
             RGBColor[
              0.9615553975530555, 0.8926839712269897, 0.5914902159195854], 
             UndirectedEdge[248, 315] -> 
             RGBColor[
              0.7762512136364731, 0.8240569883212391, 0.9346471679225881], 
             UndirectedEdge[236, 351] -> 
             RGBColor[
              0.9929360387767886, 0.9910458004017135, 0.7448459952182054], 
             UndirectedEdge[53, 386] -> 
             RGBColor[
              0.936635977985713, 0.951865298682338, 0.9783267660593346], 
             UndirectedEdge[93, 301] -> 
             RGBColor[
              0.8950832388830505, 0.9186494390104745, 0.9714915416762073], 
             UndirectedEdge[37, 159] -> 
             RGBColor[
              0.9716736191363881, 0.9767474587397971, 0.8590615065643952], 
             UndirectedEdge[148, 326] -> 
             RGBColor[
              0.9518679482287548, 0.9616845983346372, 0.8857998258928662], 
             UndirectedEdge[13, 357] -> 
             RGBColor[
              0.744492996462295, 0.7974310864617284, 0.8969000473236635], 
             UndirectedEdge[162, 231] -> 
             RGBColor[
              0.6472733728362391, 0.7128298934720527, 0.8532255345621054], 
             UndirectedEdge[33, 84] -> 
             RGBColor[
              0.7033192424686379, 0.7677493937767412, 0.9713430433226333], 
             UndirectedEdge[199, 293] -> 
             RGBColor[
              0.7541585037462273, 0.8052027737607839, 0.8945170063046821], 
             UndirectedEdge[96, 167] -> 
             RGBColor[
              0.9257067628637938, 0.9414735430876137, 0.9114934837413393], 
             UndirectedEdge[131, 307] -> 
             RGBColor[
              0.715784511894398, 0.7770314383419143, 0.973080683709567], 
             UndirectedEdge[174, 291] -> 
             RGBColor[
              0.9092593254493901, 0.929740654420155, 0.9654792391736888], 
             UndirectedEdge[207, 250] -> 
             RGBColor[
              0.9135660775168087, 0.9322979543937554, 0.9322671279110588], 
             UndirectedEdge[364, 387] -> 
             RGBColor[
              0.8716056436694573, 0.9004586974298361, 0.9876157184563782], 
             UndirectedEdge[103, 346] -> 
             RGBColor[
              0.9310197637199085, 0.9456320649287224, 0.9086166513015648], 
             UndirectedEdge[31, 106] -> 
             RGBColor[
              0.7372327261827263, 0.7946510759609708, 0.974444126380515], 
             UndirectedEdge[128, 316] -> 
             RGBColor[
              0.9435649251747888, 0.8819944190072431, 0.6240596918597807], 
             UndirectedEdge[185, 289] -> 
             RGBColor[
              0.8061532286708413, 0.8486976778838964, 0.9470580326870186], 
             UndirectedEdge[20, 172] -> 
             RGBColor[
              0.9294129226481207, 0.9462580317827878, 0.9829147413598209], 
             UndirectedEdge[70, 234] -> 
             RGBColor[
              0.511711709950045, 0.5991481096557154, 0.9581737914901727], 
             UndirectedEdge[119, 383] -> 
             RGBColor[
              0.9436908127167734, 0.9559402747896526, 0.9187122422914181], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.944751421229012, 0.9583162809306178, 0.9784056121088676], 
             UndirectedEdge[20, 54] -> 
             RGBColor[
              0.9635186065474761, 0.9723128170126827, 0.9466376626305626], 
             UndirectedEdge[229, 334] -> 
             RGBColor[
              0.9144193823913747, 0.9345972105387146, 0.9916993310759503], 
             UndirectedEdge[63, 142] -> 
             RGBColor[
              0.8356321671249693, 0.8721193010556619, 0.9840930163054067], 
             UndirectedEdge[230, 358] -> 
             RGBColor[
              0.9494935826983268, 0.9616435548087277, 0.9631175642756116], 
             UndirectedEdge[119, 296] -> 
             RGBColor[
              0.7273342415626659, 0.7835871839594812, 0.8991589206784876], 
             UndirectedEdge[218, 262] -> 
             RGBColor[
              0.9254654202356623, 0.9433243350000625, 0.9899554680831617], 
             UndirectedEdge[100, 170] -> 
             RGBColor[
              0.9559354098947113, 0.9665946872879541, 0.9573038605906532], 
             UndirectedEdge[97, 357] -> 
             RGBColor[
              0.9718843347807037, 0.9778335798270761, 0.9003059813176698], 
             UndirectedEdge[375, 399] -> 
             RGBColor[
              0.9894732663878019, 0.9899149393737114, 0.8241187484748311], 
             UndirectedEdge[199, 252] -> 
             RGBColor[
              0.7506891777623987, 0.803396476348404, 0.9353698298863214], 
             UndirectedEdge[175, 345] -> 
             RGBColor[
              0.9554325259191376, 0.8532886639017068, 0.5168906753753073], 
             UndirectedEdge[176, 186] -> 
             RGBColor[
              0.9021747001874596, 0.9026846557979025, 0.6787749835231925], 
             UndirectedEdge[309, 371] -> 
             RGBColor[
              0.7506025277871082, 0.8018459937837714, 0.8745943021436047], 
             UndirectedEdge[326, 354] -> 
             RGBColor[
              0.9480050423605818, 0.9600871874859951, 0.9498181730084205], 
             UndirectedEdge[38, 289] -> 
             RGBColor[
              0.8119320097248613, 0.8528323548354255, 0.929433451820517], 
             UndirectedEdge[120, 237] -> 
             RGBColor[
              0.8053643787648871, 0.8467935369815411, 0.8993644290069952], 
             UndirectedEdge[275, 384] -> 
             RGBColor[
              0.7186693899814691, 0.7740568435365811, 0.7739889209909582], 
             UndirectedEdge[216, 220] -> 
             RGBColor[
              0.8814345403279407, 0.9082959928270183, 0.988553207394024], 
             UndirectedEdge[50, 276] -> 
             RGBColor[
              0.9672501679533527, 0.9444097315333883, 0.6471013737425255], 
             UndirectedEdge[143, 321] -> 
             RGBColor[
              0.9833126453830918, 0.9860370161265278, 0.8666404738845217], 
             UndirectedEdge[225, 316] -> 
             RGBColor[
              0.9617149460016792, 0.9709676499308506, 0.9496907894645856], 
             UndirectedEdge[40, 332] -> 
             RGBColor[
              0.7491588018000307, 0.7796785359149296, 0.6625417081016463], 
             UndirectedEdge[254, 343] -> 
             RGBColor[
              0.9301666124538815, 0.9470866983925126, 0.9908809512072512], 
             UndirectedEdge[37, 167] -> 
             RGBColor[
              0.991425265723693, 0.9907221412631972, 0.7917690678667669], 
             UndirectedEdge[26, 204] -> 
             RGBColor[
              0.8044515315311901, 0.8448250483508112, 0.847982509342957], 
             UndirectedEdge[141, 189] -> 
             RGBColor[
              0.9276336626140468, 0.7414866838564762, 0.5371137105624021], 
             UndirectedEdge[55, 210] -> 
             RGBColor[
              0.9709875680629301, 0.9778831562816062, 0.933994659002048], 
             UndirectedEdge[41, 312] -> 
             RGBColor[
              0.9059757835093317, 0.9250114016028063, 0.8777355412256505], 
             UndirectedEdge[102, 247] -> 
             RGBColor[
              0.800565209114379, 0.8446285325729683, 0.9591560611683537], 
             UndirectedEdge[30, 400] -> 
             RGBColor[
              0.7379085406817055, 0.7949582972164084, 0.9748619901185497], 
             UndirectedEdge[57, 195] -> 
             RGBColor[
              0.9747695829736984, 0.9807037768095763, 0.9275926942655843], 
             UndirectedEdge[301, 324] -> 
             RGBColor[
              0.8650410712125672, 0.7458787293749085, 0.60954138589506], 
             UndirectedEdge[290, 331] -> 
             RGBColor[
              0.8366861463657467, 0.8724734153492466, 0.9432730110982226], 
             UndirectedEdge[49, 347] -> 
             RGBColor[
              0.7643183368677633, 0.8140431488886986, 0.9200716418314707], 
             UndirectedEdge[92, 258] -> 
             RGBColor[
              0.8284769834461128, 0.8634874025622596, 0.8087519367362057], 
             UndirectedEdge[234, 313] -> 
             RGBColor[
              0.3791465756647675, 0.4938016389386104, 0.9461817487863721], 
             UndirectedEdge[376, 377] -> 
             RGBColor[
              0.9725870818345366, 0.9167932261033356, 0.4374152534415765], 
             UndirectedEdge[223, 272] -> 
             RGBColor[
              0.49817582461312515`, 0.5995206994124115, 0.9549170943179615], 
             UndirectedEdge[213, 302] -> 
             RGBColor[
              0.7740503026818386, 0.8224716785388199, 0.9401482192350562], 
             UndirectedEdge[121, 158] -> 
             RGBColor[
              0.968224884066228, 0.9743629808837895, 0.8732996704979752], 
             UndirectedEdge[240, 248] -> 
             RGBColor[
              0.9821348400630602, 0.9659612816821828, 0.6434485797237672], 
             UndirectedEdge[18, 132] -> 
             RGBColor[
              0.89169837977971, 0.9136616322584827, 0.8674180914318902], 
             UndirectedEdge[59, 79] -> 
             RGBColor[
              0.8204644949569277, 0.85862412307401, 0.8880209148281122], 
             UndirectedEdge[109, 207] -> 
             RGBColor[
              0.9086026583101319, 0.9289151048567413, 0.9549481212684017], 
             UndirectedEdge[190, 365] -> 
             RGBColor[
              0.9275711590653998, 0.9440400724727553, 0.9567573538038197], 
             UndirectedEdge[78, 391] -> 
             RGBColor[
              0.7868480300768643, 0.8329190771537713, 0.942701338063098], 
             UndirectedEdge[159, 236] -> 
             RGBColor[
              0.9720862794366665, 0.9766170200348131, 0.8303370040547189], 
             UndirectedEdge[95, 334] -> 
             RGBColor[
              0.9111339376287164, 0.9319774860659933, 0.9913859624215369], 
             UndirectedEdge[20, 147] -> 
             RGBColor[
              0.8339255689900993, 0.8709212646381737, 0.9735941780571071], 
             UndirectedEdge[229, 388] -> 
             RGBColor[
              0.6723032539711552, 0.7414585424273319, 0.9698684115891312], 
             UndirectedEdge[15, 271] -> 
             RGBColor[
              0.9371537722926285, 0.9497063901357197, 0.8737348873464286], 
             UndirectedEdge[53, 151] -> 
             RGBColor[
              0.973196868270988, 0.9780064674833691, 0.8619899819943878], 
             UndirectedEdge[178, 309] -> 
             RGBColor[
              0.6819473294692746, 0.7497078731856991, 0.9702477210044729], 
             UndirectedEdge[309, 386] -> 
             RGBColor[
              0.7150988857877008, 0.7761420243189883, 0.973409746040868], 
             UndirectedEdge[199, 299] -> 
             RGBColor[
              0.3904680050683214, 0.5064635360385014, 0.9467570929686235], 
             UndirectedEdge[33, 90] -> 
             RGBColor[
              0.8476436439502704, 0.8815869035550747, 0.9852678784298383], 
             UndirectedEdge[191, 216] -> 
             RGBColor[
              0.9285421087046571, 0.926252733607174, 0.6850316373097123], 
             UndirectedEdge[188, 203] -> 
             RGBColor[
              0.991334428057259, 0.9897047903426344, 0.7220542959946972], 
             UndirectedEdge[87, 263] -> 
             RGBColor[
              0.9898271916305312, 0.9881874798557937, 0.6820465981074597], 
             UndirectedEdge[25, 76] -> 
             RGBColor[
              0.9746051577860926, 0.9783761740487994, 0.816597627912869], 
             UndirectedEdge[329, 334] -> 
             RGBColor[
              0.6602850765585024, 0.7297573260314772, 0.9696972529832768], 
             UndirectedEdge[42, 376] -> 
             RGBColor[
              0.9299061725924811, 0.9427502139084035, 0.7911837236775126], 
             UndirectedEdge[54, 130] -> 
             RGBColor[
              0.9399455602999958, 0.9538109305760841, 0.9546039314062802], 
             UndirectedEdge[90, 256] -> 
             RGBColor[
              0.8787845417600835, 0.9061829559013039, 0.98830044816494], 
             UndirectedEdge[160, 302] -> 
             RGBColor[
              0.9709760321233378, 0.9778745527967467, 0.9340141863387229], 
             UndirectedEdge[299, 367] -> 
             RGBColor[
              0.6229236489830441, 0.6755079520794354, 0.6659237461129319], 
             UndirectedEdge[16, 96] -> 
             RGBColor[
              0.5498420275159928, 0.629890333280468, 0.9617862131149051], 
             UndirectedEdge[5, 223] -> 
             RGBColor[
              0.5180259798444364, 0.6150277915458793, 0.9568955722811712], 
             UndirectedEdge[40, 228] -> 
             RGBColor[
              0.5092625259186285, 0.6124812864129144, 0.9545101580118653], 
             UndirectedEdge[154, 222] -> 
             RGBColor[
              0.7128176949733156, 0.7755778680190695, 0.9720106642409997], 
             UndirectedEdge[85, 188] -> 
             RGBColor[
              0.9941620533247212, 0.9899215473055569, 0.6059537159056083], 
             UndirectedEdge[281, 384] -> 
             RGBColor[
              0.6106077580053311, 0.6924070138121909, 0.9639843214804922], 
             UndirectedEdge[249, 334] -> 
             RGBColor[
              0.7428245932237633, 0.7985572638020059, 0.9757003069812762], 
             UndirectedEdge[203, 243] -> 
             RGBColor[
              0.94478234666004, 0.9567261697187474, 0.915148608858507], 
             UndirectedEdge[49, 147] -> 
             RGBColor[
              0.6317216948029754, 0.7106986573894905, 0.9649713801237254], 
             UndirectedEdge[99, 232] -> 
             RGBColor[
              0.7552344628666774, 0.8034190931478865, 0.7279088214056244], 
             UndirectedEdge[84, 389] -> 
             RGBColor[
              0.42598846380839467`, 0.5322808818889248, 0.9498282711826753], 
             UndirectedEdge[76, 242] -> 
             RGBColor[
              0.9674129437434515, 0.9555090491205813, 0.6701298826180175], 
             UndirectedEdge[129, 397] -> 
             RGBColor[
              0.9533339092410298, 0.961028965464893, 0.7608397990266116], 
             UndirectedEdge[177, 390] -> 
             RGBColor[
              0.909800988055161, 0.9301314823115439, 0.9641066629147452], 
             UndirectedEdge[138, 144] -> 
             RGBColor[
              0.9688477426386315, 0.9197044811113169, 0.592419648438046], 
             UndirectedEdge[184, 325] -> 
             RGBColor[
              0.9031107025530143, 0.9243939132064767, 0.9494991505026267], 
             UndirectedEdge[69, 140] -> 
             RGBColor[
              0.7937707037544639, 0.8392694684958621, 0.9799597561518739], 
             UndirectedEdge[247, 391] -> 
             RGBColor[
              0.9682122871957026, 0.9758133563549334, 0.9386924856010878], 
             UndirectedEdge[14, 391] -> 
             RGBColor[
              0.9839120097967788, 0.9864023342242882, 0.8619677999665156], 
             UndirectedEdge[229, 240] -> 
             RGBColor[
              0.9378129414627439, 0.9318880768372877, 0.6833311688266763], 
             UndirectedEdge[166, 400] -> 
             RGBColor[
              0.5667665091332357, 0.659165610511455, 0.9590370822145503], 
             UndirectedEdge[281, 386] -> 
             RGBColor[
              0.8491080688872423, 0.8828593219903189, 0.9853797655959255], 
             UndirectedEdge[150, 255] -> 
             RGBColor[
              0.7689783197433517, 0.8199385315044291, 0.9775883099192124], 
             UndirectedEdge[103, 290] -> 
             RGBColor[
              0.9852063912114072, 0.9876640169215976, 0.8730472436673814], 
             UndirectedEdge[212, 299] -> 
             RGBColor[
              0.4961952236587956, 0.5909416605018791, 0.9560074277840068], 
             UndirectedEdge[206, 208] -> 
             RGBColor[
              0.9929307108452776, 0.9902952819048936, 0.690539673031177], 
             UndirectedEdge[75, 169] -> 
             RGBColor[
              0.9903591702302388, 0.989863722014336, 0.779084725932665], 
             UndirectedEdge[110, 167] -> 
             RGBColor[
              0.8997208182112904, 0.9208281051955814, 0.9089950054442884], 
             UndirectedEdge[33, 214] -> 
             RGBColor[
              0.8602097277821168, 0.8916067577053304, 0.9864664427235952], 
             UndirectedEdge[98, 107] -> 
             RGBColor[
              0.9482358335883943, 0.9593214452320753, 0.9085979406829827], 
             UndirectedEdge[238, 252] -> 
             RGBColor[
              0.9566413371713973, 0.8757533474607135, 0.5895162104184115], 
             UndirectedEdge[91, 241] -> 
             RGBColor[
              0.8065741580770016, 0.8460077201519003, 0.8064314323034278], 
             UndirectedEdge[74, 219] -> 
             RGBColor[
              0.8005408676303853, 0.8437986569049626, 0.9374257710218945], 
             UndirectedEdge[45, 180] -> 
             RGBColor[
              0.9896967707583215, 0.9900073641747217, 0.820414702644551], 
             UndirectedEdge[187, 235] -> 
             RGBColor[
              0.6262812188910063, 0.707482332999934, 0.9637222981762472], 
             UndirectedEdge[114, 188] -> 
             RGBColor[
              0.9943339863314746, 0.9902892946219088, 0.624667562643189], 
             UndirectedEdge[81, 378] -> 
             RGBColor[
              0.6404920140341788, 0.7042371569176804, 0.7605145681502393], 
             UndirectedEdge[19, 313] -> 
             RGBColor[
              0.7326835901917006, 0.712013732866072, 0.6130233612339755], 
             UndirectedEdge[195, 284] -> 
             RGBColor[
              0.9622125079852877, 0.9000495515779734, 0.5957122702451814], 
             UndirectedEdge[64, 253] -> 
             RGBColor[
              0.8801890047355568, 0.9058068470237732, 0.917801325639281], 
             UndirectedEdge[55, 122] -> 
             RGBColor[
              0.9356189680816687, 0.950333021429594, 0.9532204118610448], 
             UndirectedEdge[99, 275] -> 
             RGBColor[
              0.755683899901215, 0.8043803935197076, 0.776827269011163], 
             UndirectedEdge[118, 367] -> 
             RGBColor[
              0.9416875012753454, 0.7966334628653364, 0.31555626230597666`], 
             UndirectedEdge[7, 96] -> 
             RGBColor[
              0.9082687484955917, 0.9292243636849954, 0.9748695465839519], 
             UndirectedEdge[110, 115] -> 
             RGBColor[
              0.8884859280146999, 0.9132052056434676, 0.9618707970982566], 
             UndirectedEdge[68, 95] -> 
             RGBColor[
              0.8053884105718703, 0.8484531935201229, 0.9810890714546847], 
             UndirectedEdge[289, 302] -> 
             RGBColor[
              0.8086272029865293, 0.8505427638777754, 0.9428702394864006], 
             UndirectedEdge[260, 321] -> 
             RGBColor[
              0.9850039427289943, 0.9867364110434176, 0.8386112999256945], 
             UndirectedEdge[191, 220] -> 
             RGBColor[
              0.9342437690398419, 0.9307990827910034, 0.6855754667624145], 
             UndirectedEdge[169, 209] -> 
             RGBColor[
              0.9087846266444468, 0.9285219943413225, 0.9334020643915438], 
             UndirectedEdge[32, 252] -> 
             RGBColor[
              0.9874145027302332, 0.9866145750921069, 0.6905919881356868], 
             UndirectedEdge[75, 280] -> 
             RGBColor[
              0.9937572224559718, 0.9890556550119813, 0.561890374168752], 
             UndirectedEdge[14, 224] -> 
             RGBColor[
              0.9084917139976052, 0.9273264780627051, 0.8916026890674575], 
             UndirectedEdge[128, 311] -> 
             RGBColor[
              0.9397796304804293, 0.879171352422041, 0.6304672084143594], 
             UndirectedEdge[132, 198] -> 
             RGBColor[
              0.9924437418296213, 0.9911433073066405, 0.7748902830598661], 
             UndirectedEdge[245, 388] -> 
             RGBColor[
              0.659291571116233, 0.7310833797115391, 0.9686273456627623], 
             UndirectedEdge[183, 273] -> 
             RGBColor[
              0.9679931606900298, 0.9756499321657894, 0.9390634096178458], 
             UndirectedEdge[69, 220] -> 
             RGBColor[
              0.7994787166974842, 0.8438208830767426, 0.9805041915219825], 
             UndirectedEdge[37, 263] -> 
             RGBColor[
              0.9903260630326599, 0.9902675927022343, 0.8099857011025641], 
             UndirectedEdge[235, 384] -> 
             RGBColor[
              0.5285948126691103, 0.6279026043609414, 0.956107636230658], 
             UndirectedEdge[132, 216] -> 
             RGBColor[
              0.9346836880494507, 0.9476926792220806, 0.8715828905329472], 
             UndirectedEdge[225, 380] -> 
             RGBColor[
              0.9830668614971856, 0.9861647392803694, 0.8809850079269308], 
             UndirectedEdge[3, 371] -> 
             RGBColor[
              0.9362999206787448, 0.9494384868928185, 0.8915845033851446], 
             UndirectedEdge[269, 314] -> 
             RGBColor[
              0.7672894865207331, 0.8181316455768612, 0.9774399033546126], 
             UndirectedEdge[16, 206] -> 
             RGBColor[
              0.6155394785572872, 0.6780808263837975, 0.7661304071511286], 
             UndirectedEdge[84, 256] -> 
             RGBColor[
              0.7344601402784511, 0.7923454461229704, 0.9743756130577351], 
             UndirectedEdge[58, 348] -> 
             RGBColor[
              0.4125282750359253, 0.5309656389948543, 0.947718936270286], 
             UndirectedEdge[177, 360] -> 
             RGBColor[
              0.9527706033468255, 0.9642969738238776, 0.9648312285210745], 
             UndirectedEdge[2, 106] -> 
             RGBColor[
              0.8757056528840939, 0.876261616450479, 0.6678166313491606], 
             UndirectedEdge[256, 317] -> 
             RGBColor[
              0.9232199779882551, 0.9368597863884612, 0.7452286021717796], 
             UndirectedEdge[87, 351] -> 
             RGBColor[
              0.9920245070743815, 0.9890961262602569, 0.6456313947327774], 
             UndirectedEdge[48, 103] -> 
             RGBColor[
              0.9553274402287815, 0.9650143463625962, 0.9109351391867], 
             UndirectedEdge[256, 381] -> 
             RGBColor[
              0.912129954464763, 0.8998997283746232, 0.6639496211727639], 
             UndirectedEdge[91, 226] -> 
             RGBColor[
              0.8018063424994021, 0.8446551709103118, 0.9304459674171663], 
             UndirectedEdge[105, 113] -> 
             RGBColor[
              0.9642676993183577, 0.9600262805675481, 0.6900227041475442], 
             UndirectedEdge[223, 291] -> 
             RGBColor[
              0.6443652806106255, 0.714150817767748, 0.9434500549468392], 
             UndirectedEdge[203, 348] -> 
             RGBColor[
              0.7350507790778453, 0.7897641675618919, 0.8961023152452232], 
             UndirectedEdge[259, 367] -> 
             RGBColor[
              0.9331473078981263, 0.9337670477023782, 0.6911233430541333], 
             UndirectedEdge[188, 206] -> 
             RGBColor[
              0.9941059142510236, 0.9898014715034487, 0.5998433241838184], 
             UndirectedEdge[250, 289] -> 
             RGBColor[
              0.8123645818243697, 0.8530112345151681, 0.9222646126709568], 
             UndirectedEdge[194, 377] -> 
             RGBColor[
              0.9730936999735458, 0.917876831075725, 0.49255751138798287`], 
             UndirectedEdge[83, 231] -> 
             RGBColor[
              0.41493821189432367`, 0.5311201181486185, 0.9482474101882894], 
             UndirectedEdge[276, 376] -> 
             RGBColor[
              0.9830425062737032, 0.9534969684012237, 0.47055836633495196`], 
             UndirectedEdge[83, 120] -> 
             RGBColor[
              0.7585537743482951, 0.8087905795224545, 0.8956793267544272], 
             UndirectedEdge[40, 243] -> 
             RGBColor[
              0.7105920468132814, 0.7726221285609334, 0.9728950117321946], 
             UndirectedEdge[4, 392] -> 
             RGBColor[
              0.8652537700015265, 0.8915560177819439, 0.7594195075592871], 
             UndirectedEdge[81, 329] -> 
             RGBColor[
              0.33720897071384165`, 0.4644890505288174, 0.9427810900883864], 
             UndirectedEdge[131, 363] -> 
             RGBColor[
              0.8451395633331118, 0.8793873710333104, 0.9850828662382478], 
             UndirectedEdge[167, 192] -> 
             RGBColor[
              0.9879609795374946, 0.98928956989711, 0.8491812552573363], 
             UndirectedEdge[41, 327] -> 
             RGBColor[
              0.7050590073788028, 0.7636387376608431, 0.8603329032601721], 
             UndirectedEdge[24, 382] -> 
             RGBColor[
              0.9768835209105461, 0.981026912545309, 0.8678829364460803], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.7658434757516921, 0.8134812893959226, 0.8449431417660267], 
             UndirectedEdge[90, 261] -> 
             RGBColor[
              0.9453336368883022, 0.9575909185545808, 0.9336633224149944], 
             UndirectedEdge[146, 297] -> 
             RGBColor[
              0.9764073615843157, 0.9320786321882755, 0.36284748416133555`], 
             UndirectedEdge[5, 291] -> 
             RGBColor[
              0.8381362023004583, 0.8739034426480377, 0.9584634037565206], 
             UndirectedEdge[229, 315] -> 
             RGBColor[
              0.7319293150361568, 0.789983783476344, 0.9745297570254972], 
             UndirectedEdge[241, 360] -> 
             RGBColor[
              0.9670185495372099, 0.9725807714648902, 0.8185438178936488], 
             UndirectedEdge[59, 237] -> 
             RGBColor[
              0.8061222018427323, 0.8471069162993949, 0.8868053394238419], 
             UndirectedEdge[257, 381] -> 
             RGBColor[
              0.9747807508395328, 0.9487517765328303, 0.6316490666712234], 
             UndirectedEdge[270, 308] -> 
             RGBColor[
              0.9094194314795512, 0.8301722218187382, 0.624325489828029], 
             UndirectedEdge[317, 382] -> 
             RGBColor[
              0.9776306268843004, 0.9795663460490389, 0.7268764679770581], 
             UndirectedEdge[23, 89] -> 
             RGBColor[
              0.6581491137422875, 0.7228308225185252, 0.8508409970229713], 
             UndirectedEdge[57, 327] -> 
             RGBColor[
              0.6932533826891252, 0.7562256010480287, 0.9426300168351798], 
             UndirectedEdge[347, 362] -> 
             RGBColor[
              0.9326436160051352, 0.9475465048225219, 0.9356777560959375], 
             UndirectedEdge[43, 293] -> 
             RGBColor[
              0.8717250622547987, 0.8989298805504952, 0.9049473758781794], 
             UndirectedEdge[73, 208] -> 
             RGBColor[
              0.9935084217912085, 0.9915835798317838, 0.757245780792949], 
             UndirectedEdge[53, 129] -> 
             RGBColor[
              0.9732456838678076, 0.9764592519316824, 0.7472473981285719], 
             UndirectedEdge[324, 383] -> 
             RGBColor[
              0.8977266139312214, 0.7719412939133417, 0.6126589621382936], 
             UndirectedEdge[368, 399] -> 
             RGBColor[
              0.8477528679440562, 0.8808749547447685, 0.933044556377593], 
             UndirectedEdge[51, 136] -> 
             RGBColor[
              0.9916077468769879, 0.9902096128007906, 0.7460042818260797], 
             UndirectedEdge[145, 359] -> 
             RGBColor[
              0.47958114705472416`, 0.5716381479565367, 0.9553527482502334], 
             UndirectedEdge[222, 297] -> 
             RGBColor[
              0.8076365284671103, 0.8084994500310494, 0.6397321118289251], 
             UndirectedEdge[81, 209] -> 
             RGBColor[
              0.5593483589822243, 0.6438170562490321, 0.9617314643815588], 
             UndirectedEdge[31, 345] -> 
             RGBColor[
              0.8083882821074054, 0.7397968429193779, 0.6120086991818522], 
             UndirectedEdge[155, 180] -> 
             RGBColor[
              0.9832309755776982, 0.9629393303834355, 0.6012621069005368], 
             UndirectedEdge[4, 369] -> 
             RGBColor[
              0.865442327422923, 0.8919593230402314, 0.779942819236785], 
             UndirectedEdge[102, 289] -> 
             RGBColor[
              0.6401076059738134, 0.7187072169053967, 0.9648107620151305], 
             UndirectedEdge[70, 103] -> 
             RGBColor[
              0.8900380930637903, 0.9131892474355128, 0.9046454598674207], 
             UndirectedEdge[177, 375] -> 
             RGBColor[
              0.9798892552437946, 0.9829407337050189, 0.8481131932250738], 
             UndirectedEdge[171, 253] -> 
             RGBColor[
              0.851181230886032, 0.8831457536252778, 0.9149101018350192], 
             UndirectedEdge[150, 241] -> 
             RGBColor[
              0.953621557045057, 0.9619956866454256, 0.8206399154497288], 
             UndirectedEdge[24, 317] -> 
             RGBColor[
              0.9924837273211304, 0.9893903283187945, 0.6456026309507908], 
             UndirectedEdge[80, 110] -> 
             RGBColor[
              0.7792342773181532, 0.8274630069315781, 0.978630448470883], 
             UndirectedEdge[176, 341] -> 
             RGBColor[
              0.9090763107151516, 0.9255477426482103, 0.7411017419765625], 
             UndirectedEdge[154, 192] -> 
             RGBColor[
              0.8806307644400031, 0.9062022933364445, 0.9201279978863861], 
             UndirectedEdge[121, 322] -> 
             RGBColor[
              0.9647629842763149, 0.888751523286966, 0.5169146855494358], 
             UndirectedEdge[268, 381] -> 
             RGBColor[
              0.9776872247688894, 0.9508975459744025, 0.625749599518393], 
             UndirectedEdge[76, 104] -> 
             RGBColor[
              0.8245327154997639, 0.8634538148524427, 0.9660935425171433], 
             UndirectedEdge[91, 186] -> 
             RGBColor[
              0.7989802212713752, 0.8216638173980149, 0.6687492310394124], 
             UndirectedEdge[216, 357] -> 
             RGBColor[
              0.9321244704085723, 0.946634376958684, 0.9139957498852511], 
             UndirectedEdge[210, 236] -> 
             RGBColor[
              0.9779545443301856, 0.9809935623839976, 0.8204035622785986], 
             UndirectedEdge[26, 173] -> 
             RGBColor[
              0.8364069364030757, 0.8702241267399239, 0.8508699267736183], 
             UndirectedEdge[10, 374] -> 
             RGBColor[
              0.7290442193660787, 0.7579475366173577, 0.6529325071785165], 
             UndirectedEdge[289, 340] -> 
             RGBColor[
              0.8166379808210442, 0.8542401365395478, 0.8123176371293112], 
             UndirectedEdge[65, 168] -> 
             RGBColor[
              0.7794112743023769, 0.8255746005144133, 0.891090970458545], 
             UndirectedEdge[40, 203] -> 
             RGBColor[
              0.7543322957346901, 0.8054177714063451, 0.8976202268669728], 
             UndirectedEdge[167, 201] -> 
             RGBColor[
              0.9627275821428956, 0.9709668091458711, 0.9141186075355147], 
             UndirectedEdge[41, 57] -> 
             RGBColor[
              0.980761900006234, 0.9837813580901118, 0.8551359942006536], 
             UndirectedEdge[214, 363] -> 
             RGBColor[
              0.8727580360864482, 0.9014095915233493, 0.9877171408247627], 
             UndirectedEdge[22, 189] -> 
             RGBColor[
              0.9472718688299095, 0.9589740183093115, 0.9267964939487128], 
             UndirectedEdge[41, 96] -> 
             RGBColor[
              0.9276190952911503, 0.9422643416910272, 0.8798011864623632], 
             UndirectedEdge[31, 197] -> 
             RGBColor[
              0.7134447877130607, 0.7760677576334398, 0.9720731669847826], 
             UndirectedEdge[275, 281] -> 
             RGBColor[
              0.8860320661963405, 0.9081255128222858, 0.7885090799126304], 
             UndirectedEdge[89, 353] -> 
             RGBColor[
              0.6853438633091185, 0.7463855477454581, 0.852573822417997], 
             UndirectedEdge[324, 375] -> 
             RGBColor[
              0.944932053590235, 0.8065043997725041, 0.4944829079311059], 
             UndirectedEdge[5, 174] -> 
             RGBColor[
              0.7829200246832011, 0.8306176281982862, 0.9789247565080208], 
             UndirectedEdge[36, 314] -> 
             RGBColor[
              0.7932545843926202, 0.838415777376432, 0.980027861652847], 
             UndirectedEdge[220, 357] -> 
             RGBColor[
              0.937826130743757, 0.9511807261425135, 0.9145395793379534], 
             UndirectedEdge[291, 342] -> 
             RGBColor[
              0.9658368686559675, 0.9740417730973898, 0.9427134495804805], 
             UndirectedEdge[21, 159] -> 
             RGBColor[
              0.8832792833332943, 0.5478952662246493, 0.5675131762894275], 
             UndirectedEdge[220, 394] -> 
             RGBColor[
              0.9359137704886307, 0.9503899160316018, 0.946232337795091], 
             UndirectedEdge[129, 249] -> 
             RGBColor[
              0.7729571302677545, 0.8179864984379108, 0.7440031409044983], 
             UndirectedEdge[37, 58] -> 
             RGBColor[
              0.6687926295518982, 0.7318780702301896, 0.845210863296673], 
             UndirectedEdge[118, 259] -> 
             RGBColor[
              0.890500195999441, 0.7715813973601424, 0.6130362457085816], 
             UndirectedEdge[201, 243] -> 
             RGBColor[
              0.9188772010916119, 0.9381256238344895, 0.9912185668055798], 
             UndirectedEdge[40, 110] -> 
             RGBColor[
              0.6654203862346567, 0.7366785215717976, 0.9685665827228194], 
             UndirectedEdge[35, 278] -> 
             RGBColor[
              0.9452783201870507, 0.9555801429320915, 0.8390664039942685], 
             UndirectedEdge[164, 315] -> 
             RGBColor[
              0.7784546796943291, 0.8249681781626572, 0.8981300329565496], 
             UndirectedEdge[81, 304] -> 
             RGBColor[
              0.6389934574440002, 0.7047784701437003, 0.8697423280988821], 
             UndirectedEdge[12, 299] -> 
             RGBColor[
              0.627597712410525, 0.69054656779165, 0.7459937771093328], 
             UndirectedEdge[203, 258] -> 
             RGBColor[
              0.8254525281942608, 0.8628496461652915, 0.9034287877183271], 
             UndirectedEdge[250, 276] -> 
             RGBColor[
              0.9790660067876188, 0.9529031044088511, 0.6128210213529451], 
             UndirectedEdge[124, 238] -> 
             RGBColor[
              0.9619595571288069, 0.876003125968948, 0.349304119148545], 
             UndirectedEdge[96, 154] -> 
             RGBColor[
              0.8183765477663023, 0.8583862665269482, 0.9824402263703891], 
             UndirectedEdge[126, 238] -> 
             RGBColor[
              0.9606889929071565, 0.8777987990879134, 0.5390789661778591], 
             UndirectedEdge[103, 108] -> 
             RGBColor[
              0.9912650354406011, 0.9890160974409312, 0.6752294768892179], 
             UndirectedEdge[122, 210] -> 
             RGBColor[
              0.9256074964723651, 0.9428664822956555, 0.9701672218856112], 
             UndirectedEdge[108, 234] -> 
             RGBColor[
              0.6129386523268557, 0.6749749596611339, 0.7287578085119697], 
             UndirectedEdge[222, 361] -> 
             RGBColor[
              0.6337730663662169, 0.7134237125383436, 0.9644083767564706], 
             UndirectedEdge[12, 274] -> 
             RGBColor[
              0.9870572465901252, 0.9869114793445244, 0.7358957693649015], 
             UndirectedEdge[141, 219] -> 
             RGBColor[
              0.9260892678983206, 0.7408268813595815, 0.5617609370980404], 
             UndirectedEdge[179, 344] -> 
             RGBColor[
              0.6651145837361796, 0.7360413778255243, 0.968923637674906], 
             UndirectedEdge[14, 230] -> 
             RGBColor[
              0.9811709360621266, 0.9843580459210808, 0.8666077228127548], 
             UndirectedEdge[12, 118] -> 
             RGBColor[
              0.9463615647028263, 0.8116720785775511, 0.3956262933023774], 
             UndirectedEdge[44, 49] -> 
             RGBColor[
              0.7647900249563255, 0.8142382040351501, 0.9122545495143507], 
             UndirectedEdge[224, 247] -> 
             RGBColor[
              0.892791991396529, 0.9167375001933502, 0.9683273747020296], 
             UndirectedEdge[161, 222] -> 
             RGBColor[
              0.8229410947374514, 0.8598201982209641, 0.8547736231554532], 
             UndirectedEdge[148, 168] -> 
             RGBColor[
              0.7807019259803285, 0.8261083181514814, 0.869701532055416], 
             UndirectedEdge[219, 323] -> 
             RGBColor[
              0.9760127348779022, 0.9456112281388995, 0.6209463858682993], 
             UndirectedEdge[309, 334] -> 
             RGBColor[
              0.7215760546258043, 0.7813067429324275, 0.9740275441868833], 
             UndirectedEdge[170, 326] -> 
             RGBColor[
              0.9451048876852495, 0.9579587228648229, 0.9562708357137935], 
             UndirectedEdge[239, 354] -> 
             RGBColor[
              0.9785142688810118, 0.9834620914407668, 0.9197104604734898], 
             UndirectedEdge[11, 221] -> 
             RGBColor[
              0.7800235513723788, 0.8278293921100244, 0.9542534004006806], 
             UndirectedEdge[47, 322] -> 
             RGBColor[
              0.9655947093355841, 0.888543369668213, 0.4629994937928969], 
             UndirectedEdge[155, 271] -> 
             RGBColor[
              0.98552167275697, 0.9638865925352966, 0.5632993265057357], 
             UndirectedEdge[106, 363] -> 
             RGBColor[
              0.7962303017276553, 0.8407404303748509, 0.9803244533471438], 
             UndirectedEdge[245, 378] -> 
             RGBColor[
              0.9317757781848026, 0.9441550821336413, 0.7843983491129942], 
             UndirectedEdge[155, 326] -> 
             RGBColor[
              0.9446247139352212, 0.9342950734908886, 0.679531408197704], 
             UndirectedEdge[10, 39] -> 
             RGBColor[
              0.7021879175233985, 0.7656603186495357, 0.9723933473246671], 
             UndirectedEdge[25, 382] -> 
             RGBColor[
              0.9783959829248281, 0.981203365230362, 0.8101807497585323], 
             UndirectedEdge[177, 383] -> 
             RGBColor[
              0.932683815584781, 0.9483776278458564, 0.9662892474322615], 
             UndirectedEdge[177, 296] -> 
             RGBColor[
              0.7163272444306735, 0.7760245370156851, 0.946735925819331], 
             UndirectedEdge[103, 143] -> 
             RGBColor[
              0.9897948594153159, 0.9900479263551523, 0.8187891197528483], 
             UndirectedEdge[84, 317] -> 
             RGBColor[
              0.8044709955850808, 0.8434154215570333, 0.7337431733677242], 
             UndirectedEdge[50, 328] -> 
             RGBColor[
              0.9694126819264965, 0.9517043989472294, 0.6555023321716917], 
             UndirectedEdge[332, 385] -> 
             RGBColor[
              0.9241431048664206, 0.9186549666911392, 0.6785949532559568], 
             UndirectedEdge[242, 257] -> 
             RGBColor[
              0.9794439163609114, 0.9644817287997733, 0.649764584156862], 
             UndirectedEdge[214, 217] -> 
             RGBColor[
              0.9620991691962631, 0.9688506261626821, 0.829159391489243], 
             UndirectedEdge[51, 59] -> 
             RGBColor[
              0.9894631768694042, 0.9899107670985652, 0.8242859579055173], 
             UndirectedEdge[66, 131] -> 
             RGBColor[
              0.7378979036336946, 0.7949840859528206, 0.9748215309113075], 
             UndirectedEdge[66, 98] -> 
             RGBColor[
              0.7543320762923449, 0.8080882491370953, 0.9763890369704487], 
             UndirectedEdge[70, 346] -> 
             RGBColor[
              0.8319089977181169, 0.8690405237551497, 0.983767093825731], 
             UndirectedEdge[151, 253] -> 
             RGBColor[
              0.9904102042492823, 0.9903023872576383, 0.8085912633926426], 
             UndirectedEdge[384, 398] -> 
             RGBColor[
              0.7145827233280362, 0.7733920339076841, 0.9162318419353631], 
             UndirectedEdge[123, 218] -> 
             RGBColor[
              0.9301714314071496, 0.8826228912341284, 0.6343446163517137], 
             UndirectedEdge[169, 280] -> 
             RGBColor[
              0.9893184170913456, 0.9876376562865271, 0.6658051695479934], 
             UndirectedEdge[71, 109] -> 
             RGBColor[
              0.9500171626725198, 0.9619379064685359, 0.9588982736656508], 
             UndirectedEdge[166, 302] -> 
             RGBColor[
              0.757682471863786, 0.8091835361183494, 0.9388596836357193], 
             UndirectedEdge[89, 163] -> 
             RGBColor[
              0.9820881692759245, 0.9523863494029534, 0.5505260073470508], 
             UndirectedEdge[102, 340] -> 
             RGBColor[
              0.8181276925606058, 0.855449551640473, 0.8124349126944433], 
             UndirectedEdge[380, 390] -> 
             RGBColor[
              0.9210511010986686, 0.9377946639325455, 0.9125005979562826], 
             UndirectedEdge[172, 387] -> 
             RGBColor[
              0.8982490825475034, 0.921703452374308, 0.9901569934414449], 
             UndirectedEdge[61, 298] -> 
             RGBColor[
              0.8053817438448212, 0.8458216392172839, 0.8581473150319867], 
             UndirectedEdge[10, 216] -> 
             RGBColor[
              0.6799315057426354, 0.7479136600297589, 0.9702705109004846], 
             UndirectedEdge[209, 229] -> 
             RGBColor[
              0.8636438059877706, 0.8941101441807857, 0.9868563112706825], 
             UndirectedEdge[39, 119] -> 
             RGBColor[
              0.9541641020649749, 0.9642913914260425, 0.9197111939790654], 
             UndirectedEdge[33, 261] -> 
             RGBColor[
              0.8886173200000307, 0.9126017212614459, 0.928191346376743], 
             UndirectedEdge[102, 213] -> 
             RGBColor[
              0.6055307056691227, 0.6906361315664411, 0.962088741763786], 
             UndirectedEdge[155, 335] -> 
             RGBColor[
              0.9494620208263472, 0.938152210700675, 0.6799927948472944], 
             UndirectedEdge[76, 317] -> 
             RGBColor[
              0.9738398017455647, 0.9767391548674763, 0.7332933461313947], 
             UndirectedEdge[19, 179] -> 
             RGBColor[
              0.7078651889652541, 0.6918650366942086, 0.6110695657766303], 
             UndirectedEdge[48, 83] -> 
             RGBColor[
              0.7249089676549787, 0.7840971709360208, 0.9741925283227635], 
             UndirectedEdge[288, 355] -> 
             RGBColor[
              0.9004012169712272, 0.9192360707093368, 0.7807518210053102], 
             UndirectedEdge[7, 192] -> 
             RGBColor[
              0.9705229651692925, 0.9770403904944918, 0.9125573180999488], 
             UndirectedEdge[341, 393] -> 
             RGBColor[
              0.9402873662104365, 0.9504345910986182, 0.744078680312141], 
             UndirectedEdge[244, 270] -> 
             RGBColor[
              0.9439992934123418, 0.9544330323574033, 0.8286291651325761], 
             UndirectedEdge[121, 265] -> 
             RGBColor[
              0.9934205128517178, 0.9903225966352723, 0.6696849433224401], 
             UndirectedEdge[156, 363] -> 
             RGBColor[
              0.9011656283043621, 0.9224045550794648, 0.9294420444779106], 
             UndirectedEdge[133, 280] -> 
             RGBColor[
              0.9895800831926056, 0.9877458619439101, 0.6614686850799532], 
             UndirectedEdge[44, 362] -> 
             RGBColor[
              0.9331153040936975, 0.9477415599689734, 0.9278606637788174], 
             UndirectedEdge[116, 147] -> 
             RGBColor[
              0.4498270403680184, 0.5435753701452327, 0.9531499989482077], 
             UndirectedEdge[83, 196] -> 
             RGBColor[
              0.7243882338834424, 0.7836819519615396, 0.9741428602707698], 
             UndirectedEdge[109, 233] -> 
             RGBColor[
              0.985322789169145, 0.9861601236534743, 0.7818529894857341], 
             UndirectedEdge[19, 125] -> 
             RGBColor[
              0.908977866364333, 0.851993780058055, 0.6292486516306519], 
             UndirectedEdge[26, 160] -> 
             RGBColor[
              0.9791370360112439, 0.9821723060743199, 0.8400976444690305], 
             UndirectedEdge[224, 302] -> 
             RGBColor[
              0.902343697008241, 0.9238611465990825, 0.9521588285852087], 
             UndirectedEdge[58, 60] -> 
             RGBColor[
              0.665900410562786, 0.7306820633515541, 0.8931424167690731], 
             UndirectedEdge[165, 332] -> 
             RGBColor[
              0.9620468607334598, 0.8806668574394909, 0.3225297176029759], 
             UndirectedEdge[43, 252] -> 
             RGBColor[
              0.8682557362709702, 0.8971235831381155, 0.9458001994598187], 
             UndirectedEdge[292, 304] -> 
             RGBColor[
              0.9736203222689599, 0.9787257240471089, 0.8793402881016719], 
             UndirectedEdge[63, 257] -> 
             RGBColor[
              0.8779128758920121, 0.9047287942867658, 0.9498495446632493], 
             UndirectedEdge[94, 355] -> 
             RGBColor[
              0.6181759430932054, 0.6977344709072315, 0.9649861907128989], 
             UndirectedEdge[223, 290] -> 
             RGBColor[
              0.652759490755918, 0.7204112059498495, 0.929240846731499], 
             UndirectedEdge[141, 150] -> 
             RGBColor[
              0.8903962949720701, 0.7136134908386842, 0.6015983138060258], 
             UndirectedEdge[131, 306] -> 
             RGBColor[
              0.9228322547011398, 0.94038453556624, 0.9605745830103913], 
             UndirectedEdge[151, 182] -> 
             RGBColor[
              0.7667856482821438, 0.8145630575921996, 0.8582637260441226], 
             UndirectedEdge[87, 201] -> 
             RGBColor[
              0.9649111166232613, 0.9699959400665288, 0.7417250972235787], 
             UndirectedEdge[72, 379] -> 
             RGBColor[
              0.9507980223817418, 0.8418747390020779, 0.28324205201880087`], 
             UndirectedEdge[23, 378] -> 
             RGBColor[
              0.6584425676763452, 0.7217911683744738, 0.7615849067919498], 
             UndirectedEdge[116, 322] -> 
             RGBColor[
              0.5577371942001383, 0.545766284938062, 0.6006518715819422], 
             UndirectedEdge[90, 175] -> 
             RGBColor[
              0.9482386205214048, 0.9587922039415426, 0.8855202257578323], 
             UndirectedEdge[348, 369] -> 
             RGBColor[
              0.7377764276801662, 0.7897628067494997, 0.7689022044825342], 
             UndirectedEdge[134, 243] -> 
             RGBColor[
              0.9408668433335536, 0.9545254630137952, 0.9539958383071978], 
             UndirectedEdge[211, 372] -> 
             RGBColor[
              0.9161979078992044, 0.9356080794355195, 0.9777483475251095], 
             UndirectedEdge[73, 188] -> 
             RGBColor[
              0.9946836251969543, 0.9910897694303389, 0.6665494319455904], 
             UndirectedEdge[55, 228] -> 
             RGBColor[
              0.7396910478107798, 0.7944992689964212, 0.9353507676302759], 
             UndirectedEdge[260, 384] -> 
             RGBColor[
              0.7185342681236573, 0.7750260992307425, 0.8507445184018039], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.798099560841297, 0.8402325018861346, 0.8710711376013078], 
             UndirectedEdge[153, 203] -> 
             RGBColor[
              0.9579541449989537, 0.9672290041752559, 0.9164049467426757], 
             UndirectedEdge[65, 148] -> 
             RGBColor[
              0.9908346161080538, 0.9904778924681276, 0.8015576605501165], 
             UndirectedEdge[42, 366] -> 
             RGBColor[
              0.9019751387987616, 0.9246099578318191, 0.9882743762426753], 
             UndirectedEdge[48, 313] -> 
             RGBColor[
              0.7236515399417123, 0.7830763344719183, 0.9740935390070657], 
             UndirectedEdge[166, 213] -> 
             RGBColor[
              0.5530962628068177, 0.6480674887060898, 0.9579609103479725], 
             UndirectedEdge[11, 78] -> 
             RGBColor[
              0.5968045862777063, 0.6835518747372906, 0.9614017896804652], 
             UndirectedEdge[228, 348] -> 
             RGBColor[
              0.4899810092617838, 0.5968276825684613, 0.9529922463901157], 
             UndirectedEdge[199, 336] -> 
             RGBColor[
              0.7517304268203016, 0.8041730381908991, 0.9336072668325401], 
             UndirectedEdge[249, 309] -> 
             RGBColor[
              0.5312006066190784, 0.6302916086248126, 0.9562372040864422], 
             UndirectedEdge[190, 273] -> 
             RGBColor[
              0.9677679696018762, 0.975481985020961, 0.9394445993908478], 
             UndirectedEdge[298, 314] -> 
             RGBColor[
              0.8971949234090458, 0.9179349988839955, 0.8670329761757831], 
             UndirectedEdge[7, 385] -> 
             RGBColor[
              0.9119887165627527, 0.9321905652459064, 0.9752243604590524], 
             UndirectedEdge[27, 194] -> 
             RGBColor[
              0.9885162674224433, 0.9889711383632465, 0.8105122755792368], 
             UndirectedEdge[39, 128] -> 
             RGBColor[
              0.9307553262480872, 0.8720425431362562, 0.6319268269503665], 
             UndirectedEdge[116, 265] -> 
             RGBColor[
              0.5863947227755413, 0.6473373582863682, 0.7534221293549463], 
             UndirectedEdge[231, 313] -> 
             RGBColor[
              0.41368078418105725`, 0.5300992816845159, 0.9481484208725917], 
             UndirectedEdge[96, 284] -> 
             RGBColor[
              0.9032563956130619, 0.85419697984661, 0.6302178760169679], 
             UndirectedEdge[279, 300] -> 
             RGBColor[
              0.991088300700125, 0.9905827975663457, 0.7973534503448162], 
             UndirectedEdge[22, 190] -> 
             RGBColor[
              0.9417873589896684, 0.9553756844039001, 0.958113307643548], 
             UndirectedEdge[24, 207] -> 
             RGBColor[
              0.916378753483253, 0.9334610681883554, 0.8856538081750076], 
             UndirectedEdge[315, 329] -> 
             RGBColor[
              0.47779500920328444`, 0.5851438989691067, 0.9525276789328236], 
             UndirectedEdge[239, 335] -> 
             RGBColor[
              0.9469571620830601, 0.9595896277286367, 0.9617851037534049], 
             UndirectedEdge[142, 300] -> 
             RGBColor[
              0.9415490784813305, 0.9540278547088452, 0.9096209467431394], 
             UndirectedEdge[13, 88] -> 
             RGBColor[
              0.7471484406373601, 0.7972739280308889, 0.7616488349986434], 
             UndirectedEdge[18, 302] -> 
             RGBColor[
              0.8841993875960408, 0.9096376378335362, 0.9503633861310053], 
             UndirectedEdge[148, 251] -> 
             RGBColor[
              0.9879583855642637, 0.9892219601769009, 0.8462445792609199], 
             UndirectedEdge[90, 257] -> 
             RGBColor[
              0.9414353381348533, 0.955035004059511, 0.9559998936633995], 
             UndirectedEdge[134, 348] -> 
             RGBColor[
              0.731135275751359, 0.7875634608569397, 0.9349495446939141], 
             UndirectedEdge[158, 322] -> 
             RGBColor[
              0.9400092881901896, 0.8717500274729474, 0.6241877281124237], 
             UndirectedEdge[40, 385] -> 
             RGBColor[
              0.6951262989543212, 0.7602901610247408, 0.971419874894971], 
             UndirectedEdge[228, 385] -> 
             RGBColor[
              0.6842468289850185, 0.751457717189124, 0.9705634031661757], 
             UndirectedEdge[175, 214] -> 
             RGBColor[
              0.9608047043532513, 0.9688120580917983, 0.8867187900515892], 
             UndirectedEdge[7, 41] -> 
             RGBColor[
              0.9732171779003529, 0.9781545166968942, 0.8679072407472346], 
             UndirectedEdge[176, 379] -> 
             RGBColor[
              0.8917577662690925, 0.8675458916788521, 0.6383071623232435], 
             UndirectedEdge[259, 336] -> 
             RGBColor[
              0.9329987654591199, 0.9481653887266392, 0.9502539033794537], 
             UndirectedEdge[213, 340] -> 
             RGBColor[
              0.7820610805163535, 0.8261690512005921, 0.8095956168779668], 
             UndirectedEdge[55, 165] -> 
             RGBColor[
              0.9634585767135115, 0.9043200343565991, 0.5961952488604007], 
             UndirectedEdge[108, 231] -> 
             RGBColor[
              0.6474728608431455, 0.7112726024070395, 0.7307244805981893], 
             UndirectedEdge[38, 230] -> 
             RGBColor[
              0.9783277258110943, 0.9831823054151083, 0.9137270746646222], 
             UndirectedEdge[39, 316] -> 
             RGBColor[
              0.9330553024809838, 0.9491948367537291, 0.984387915699101], 
             UndirectedEdge[85, 167] -> 
             RGBColor[
              0.9914603529787858, 0.9897841119930515, 0.721948069499353], 
             UndirectedEdge[28, 328] -> 
             RGBColor[
              0.8921396646208902, 0.8908769894332114, 0.6720495725726447], 
             UndirectedEdge[79, 120] -> 
             RGBColor[
              0.8197066718790824, 0.8583107437561563, 0.9005800044112655], 
             UndirectedEdge[130, 347] -> 
             RGBColor[
              0.9429491648074069, 0.9557638697007833, 0.9366607085405703], 
             UndirectedEdge[77, 160] -> 
             RGBColor[
              0.9693919300651395, 0.9766931320754715, 0.9366956579232664], 
             UndirectedEdge[108, 179] -> 
             RGBColor[
              0.7347707339270855, 0.78692938937839, 0.7364340812522384], 
             UndirectedEdge[318, 373] -> 
             RGBColor[
              0.5111207547488059, 0.6139898802895073, 0.9546564445922934], 
             UndirectedEdge[48, 331] -> 
             RGBColor[
              0.8068071953831208, 0.8498237447902453, 0.9811609066175412], 
             UndirectedEdge[222, 312] -> 
             RGBColor[
              0.7354685013115838, 0.7932728500830287, 0.9742682849329782], 
             UndirectedEdge[292, 353] -> 
             RGBColor[
              0.666819997575125, 0.7340918376914358, 0.9520594453314619], 
             UndirectedEdge[175, 204] -> 
             RGBColor[
              0.8030309118760144, 0.8442375856151361, 0.8715258534750355], 
             UndirectedEdge[198, 340] -> 
             RGBColor[
              0.9929555274804667, 0.9908166855434664, 0.7272829754018917], 
             UndirectedEdge[14, 207] -> 
             RGBColor[
              0.9159767156683327, 0.9332948152199853, 0.8923166152087514], 
             UndirectedEdge[45, 271] -> 
             RGBColor[
              0.9919874679375933, 0.9909546263265828, 0.7824519222497497], 
             UndirectedEdge[112, 183] -> 
             RGBColor[
              0.858145806721998, 0.8893198217501983, 0.9495605407457641], 
             UndirectedEdge[85, 139] -> 
             RGBColor[
              0.7027964196932557, 0.760362024083477, 0.7775543206398274], 
             UndirectedEdge[45, 97] -> 
             RGBColor[
              0.9729114991486019, 0.978258338690122, 0.883283209525425], 
             UndirectedEdge[130, 181] -> 
             RGBColor[
              0.9230048096135612, 0.9411765464520747, 0.983280203463003], 
             UndirectedEdge[63, 90] -> 
             RGBColor[
              0.8408374985957006, 0.8762698910754644, 0.9845895054679392], 
             UndirectedEdge[114, 361] -> 
             RGBColor[
              0.805257442280949, 0.8449104272680121, 0.8040063713814543], 
             UndirectedEdge[75, 209] -> 
             RGBColor[
              0.913223432009073, 0.9299399930667767, 0.8294872690123025], 
             UndirectedEdge[42, 276] -> 
             RGBColor[
              0.9188844104795281, 0.9065347870990172, 0.6664316611565355], 
             UndirectedEdge[205, 358] -> 
             RGBColor[
              0.8786717926809426, 0.9060930528460893, 0.9882896940571193], 
             UndirectedEdge[76, 358] -> 
             RGBColor[
              0.9410133045930904, 0.9553189772830233, 0.9774724630970175], 
             UndirectedEdge[90, 142] -> 
             RGBColor[
              0.8991546293678104, 0.9224255108284072, 0.9902433653055569], 
             UndirectedEdge[152, 381] -> 
             RGBColor[
              0.9786697342694829, 0.9513038389022404, 0.6094668744404779], 
             UndirectedEdge[86, 309] -> 
             RGBColor[
              0.5390859872705864, 0.636693315870057, 0.9568579701364299], 
             UndirectedEdge[104, 358] -> 
             RGBColor[
              0.8110972498966096, 0.8532242442230376, 0.9815754758331399], 
             UndirectedEdge[16, 369] -> 
             RGBColor[
              0.6154936409658436, 0.6779827844105911, 0.7611412681993184], 
             UndirectedEdge[278, 337] -> 
             RGBColor[
              0.9791991575467935, 0.981911292119789, 0.8174635660967066], 
             UndirectedEdge[100, 350] -> 
             RGBColor[
              0.5572153593126741, 0.6286847683937015, 0.9635627955418316], 
             UndirectedEdge[90, 202] -> 
             RGBColor[
              0.9237503056421283, 0.9418455357830198, 0.9859360406783877], 
             UndirectedEdge[126, 367] -> 
             RGBColor[
              0.9871924774128806, 0.9744863440165379, 0.6040992387900777], 
             UndirectedEdge[278, 327] -> 
             RGBColor[
              0.7062342034417677, 0.7638106217575673, 0.8180258594065258], 
             UndirectedEdge[10, 200] -> 
             RGBColor[
              0.6092315185299761, 0.6922316952365917, 0.9633433716107974], 
             UndirectedEdge[149, 299] -> 
             RGBColor[
              0.616642822902993, 0.6543212509033288, 0.641523922826415], 
             UndirectedEdge[57, 284] -> 
             RGBColor[
              0.9563992003281456, 0.8957139962456946, 0.6055526837552584], 
             UndirectedEdge[125, 313] -> 
             RGBColor[
              0.702091334664076, 0.765884812019713, 0.9720371073806623], 
             UndirectedEdge[125, 196] -> 
             RGBColor[
              0.8994250823428085, 0.9226411626894202, 0.9902691613517485], 
             UndirectedEdge[21, 210] -> 
             RGBColor[
              0.8891475482268132, 0.5522718085738338, 0.5575797345133072], 
             UndirectedEdge[186, 374] -> 
             RGBColor[
              0.9766674161604206, 0.9329558573371954, 0.363857747082317], 
             UndirectedEdge[6, 74] -> 
             RGBColor[
              0.7277452228600214, 0.787000602980767, 0.9737242617674422], 
             UndirectedEdge[7, 312] -> 
             RGBColor[
              0.8866254367137731, 0.9119714235967744, 0.9728039013472393], 
             UndirectedEdge[238, 299] -> 
             RGBColor[
              0.59642016447732, 0.5788204071508108, 0.6009034735007135], 
             UndirectedEdge[155, 239] -> 
             RGBColor[
              0.9751339404556512, 0.9576699774456605, 0.6494236956627732], 
             UndirectedEdge[108, 331] -> 
             RGBColor[
              0.8427447905949406, 0.8738254958685803, 0.745455244320059], 
             UndirectedEdge[55, 87] -> 
             RGBColor[
              0.9870544842370821, 0.9865104273764794, 0.7042421517686042], 
             UndirectedEdge[186, 288] -> 
             RGBColor[
              0.9866506064751774, 0.9657540822267183, 0.4772500372921879], 
             UndirectedEdge[178, 371] -> 
             RGBColor[
              0.9225977892352633, 0.9385127792142363, 0.8902775818560282], 
             UndirectedEdge[212, 238] -> 
             RGBColor[
              0.8311027033440583, 0.7775652767013912, 0.6187067687103847], 
             UndirectedEdge[292, 329] -> 
             RGBColor[
              0.6718358355388013, 0.738436304432226, 0.9523790500911761], 
             UndirectedEdge[268, 338] -> 
             RGBColor[
              0.8793185876461243, 0.9057021569108219, 0.9438004955622104], 
             UndirectedEdge[68, 309] -> 
             RGBColor[
              0.6158305275689582, 0.6977824503865572, 0.963730653220031], 
             UndirectedEdge[129, 309] -> 
             RGBColor[
              0.7517085916697956, 0.8007359775683325, 0.7423303781101054], 
             UndirectedEdge[137, 330] -> 
             RGBColor[
              0.9722197073449514, 0.9764924894443738, 0.8123344577829685], 
             UndirectedEdge[111, 400] -> 
             RGBColor[
              0.7286729106717913, 0.7875940565410009, 0.9739810874834598], 
             UndirectedEdge[62, 370] -> 
             RGBColor[
              0.6561999903009591, 0.7313476868185317, 0.9663675405617913], 
             UndirectedEdge[163, 280] -> 
             RGBColor[
              0.9817717586049267, 0.9500422565354583, 0.39488991850379823`], 
             UndirectedEdge[316, 383] -> 
             RGBColor[
              0.9225820131327822, 0.9408437201173392, 0.9833889640114537], 
             UndirectedEdge[307, 314] -> 
             RGBColor[
              0.6789786369661451, 0.7478397553448319, 0.9695286232898673], 
             UndirectedEdge[126, 259] -> 
             RGBColor[
              0.9360051721369761, 0.9494342785113439, 0.9015792221926826], 
             UndirectedEdge[44, 372] -> 
             RGBColor[
              0.9338833696564963, 0.9483539946001649, 0.9279339225578574], 
             UndirectedEdge[202, 279] -> 
             RGBColor[
              0.9680841963901915, 0.9742498886207178, 0.8731720551175319], 
             UndirectedEdge[148, 312] -> 
             RGBColor[
              0.9057546550543786, 0.924919959303941, 0.8814002119863212], 
             UndirectedEdge[109, 358] -> 
             RGBColor[
              0.951881134995535, 0.9634241874027274, 0.9590760610098077], 
             UndirectedEdge[142, 275] -> 
             RGBColor[
              0.9440214980347787, 0.9540251316776402, 0.7941302777830603], 
             UndirectedEdge[296, 375] -> 
             RGBColor[
              0.7301479933627852, 0.7847507426389535, 0.8525277715942738], 
             UndirectedEdge[92, 195] -> 
             RGBColor[
              0.9875771983579966, 0.9879183287499753, 0.7841362013922748], 
             UndirectedEdge[178, 248] -> 
             RGBColor[
              0.9191125558351614, 0.9370715456368812, 0.9480369187906309], 
             UndirectedEdge[41, 222] -> 
             RGBColor[
              0.8220602424981636, 0.8594559431831486, 0.8693716243329737], 
             UndirectedEdge[154, 356] -> 
             RGBColor[
              0.8693112401888488, 0.8982564763937104, 0.9615127922520241], 
             UndirectedEdge[70, 133] -> 
             RGBColor[
              0.8886855120650656, 0.912629920432794, 0.9270612273837064], 
             UndirectedEdge[7, 80] -> 
             RGBColor[
              0.8508183045798593, 0.8839986198294774, 0.9692349810528054], 
             UndirectedEdge[152, 261] -> 
             RGBColor[
              0.9862979976145638, 0.9886018841352922, 0.8767411693795588], 
             UndirectedEdge[95, 229] -> 
             RGBColor[
              0.892353278789602, 0.9170022984950871, 0.9895946464157701], 
             UndirectedEdge[30, 204] -> 
             RGBColor[
              0.7464785193167328, 0.8019157919454614, 0.9755366502295651], 
             UndirectedEdge[133, 223] -> 
             RGBColor[
              0.6553493776113681, 0.7219686506346188, 0.9081043879236579], 
             UndirectedEdge[298, 306] -> 
             RGBColor[
              0.9825778700428767, 0.984939849278675, 0.8432911857233005], 
             UndirectedEdge[40, 96] -> 
             RGBColor[
              0.6914063308871602, 0.7573239594638298, 0.9710650610198703], 
             UndirectedEdge[122, 146] -> 
             RGBColor[
              0.9396667615129652, 0.9450960517107332, 0.7007640437248652], 
             UndirectedEdge[223, 267] -> 
             RGBColor[
              0.6388317518127333, 0.7100239210506019, 0.9528168758262192], 
             UndirectedEdge[54, 322] -> 
             RGBColor[
              0.9582302721255334, 0.8853392074578038, 0.5933443551036053], 
             UndirectedEdge[41, 154] -> 
             RGBColor[
              0.8833249771710635, 0.907316419538847, 0.8754779205336719], 
             UndirectedEdge[245, 353] -> 
             RGBColor[
              0.6234768969007893, 0.7000625090039881, 0.9663452662914271], 
             UndirectedEdge[26, 62] -> 
             RGBColor[
              0.8227881142470854, 0.8595849993647822, 0.849512529856238], 
             UndirectedEdge[217, 269] -> 
             RGBColor[
              0.8643208748963509, 0.8915803660779439, 0.8196486467944666], 
             UndirectedEdge[172, 347] -> 
             RGBColor[
              0.948811076458846, 0.9604379989342878, 0.9372198229068748], 
             UndirectedEdge[63, 261] -> 
             RGBColor[
              0.8818111746454611, 0.9072847087818354, 0.9275129734148441], 
             UndirectedEdge[195, 369] -> 
             RGBColor[
              0.9872783917084655, 0.9872792115406149, 0.7516129416117072], 
             UndirectedEdge[65, 180] -> 
             RGBColor[
              0.9891835581932803, 0.9897951375901157, 0.8289199629988281], 
             UndirectedEdge[49, 211] -> 
             RGBColor[
              0.7471045631990337, 0.8014922888705047, 0.9620689744816028], 
             UndirectedEdge[285, 387] -> 
             RGBColor[
              0.9177795151893247, 0.9368880390811174, 0.9785520132568415], 
             UndirectedEdge[329, 388] -> 
             RGBColor[
              0.41816894813828287`, 0.5366186579200947, 0.9478663334964577], 
             UndirectedEdge[38, 102] -> 
             RGBColor[
              0.813421721464423, 0.8540417699363507, 0.9295507273856491], 
             UndirectedEdge[92, 188] -> 
             RGBColor[
              0.994358883309111, 0.9903425467396025, 0.6273774450125758], 
             UndirectedEdge[114, 153] -> 
             RGBColor[
              0.9609537032731692, 0.9678135084545304, 0.8190182133911674], 
             UndirectedEdge[326, 337] -> 
             RGBColor[
              0.9375455134716251, 0.9523209539536409, 0.9690668844569024], 
             UndirectedEdge[38, 221] -> 
             RGBColor[
              0.9742443208412612, 0.9801369086745688, 0.9206392141559658], 
             UndirectedEdge[350, 394] -> 
             RGBColor[
              0.5829251929245283, 0.647838755714709, 0.9184978752173271], 
             UndirectedEdge[286, 349] -> 
             RGBColor[
              0.9604976766274077, 0.9692438501540919, 0.9160701450964364], 
             UndirectedEdge[246, 320] -> 
             RGBColor[
              0.7860477018525673, 0.8324076701512235, 0.9463486814503197], 
             UndirectedEdge[322, 362] -> 
             RGBColor[
              0.9079571277724672, 0.8463929281161429, 0.6280793670219265], 
             UndirectedEdge[80, 348] -> 
             RGBColor[
              0.614674370314583, 0.6964446117638585, 0.9639125838669744], 
             UndirectedEdge[78, 230] -> 
             RGBColor[
              0.7841069563422121, 0.8308747888505639, 0.947341260909337], 
             UndirectedEdge[248, 329] -> 
             RGBColor[
              0.6858263163197043, 0.7488553433054661, 0.928023347874601], 
             UndirectedEdge[43, 330] -> 
             RGBColor[
              0.8745838955040006, 0.8995335196363787, 0.8155137657185498], 
             UndirectedEdge[63, 217] -> 
             RGBColor[
              0.8860106231215754, 0.9085245622396814, 0.8218104781953357], 
             UndirectedEdge[79, 136] -> 
             RGBColor[
              0.8226090649645115, 0.8589229687762354, 0.8097392387486746], 
             UndirectedEdge[159, 243] -> 
             RGBColor[
              0.9251408322026099, 0.9427970296613172, 0.980615873151292], 
             UndirectedEdge[1, 327] -> 
             RGBColor[
              0.6976977102449942, 0.736505435037496, 0.658129546776397], 
             UndirectedEdge[304, 353] -> 
             RGBColor[
              0.6841387606529978, 0.7458872068274265, 0.8725454921356182], 
             UndirectedEdge[240, 329] -> 
             RGBColor[
              0.6836786356298715, 0.7270481923300502, 0.6613290907340028], 
             UndirectedEdge[10, 311] -> 
             RGBColor[
              0.7112122217557408, 0.7727891279353205, 0.97093372878866], 
             UndirectedEdge[353, 378] -> 
             RGBColor[
              0.6856373172431762, 0.7453458936014067, 0.7633177321869754], 
             UndirectedEdge[167, 243] -> 
             RGBColor[
              0.9448924787899149, 0.9567717121847172, 0.9133234344536636], 
             UndirectedEdge[169, 292] -> 
             RGBColor[0.9711109620283498, 0.9776880391, 0.9209268813047109], 
             UndirectedEdge[211, 347] -> 
             RGBColor[
              0.9687065911968831, 0.9758948632706881, 0.9249968539620383], 
             UndirectedEdge[224, 340] -> 
             RGBColor[
              0.9103544748427559, 0.9275585192608549, 0.8216062262281192], 
             UndirectedEdge[144, 233] -> 
             RGBColor[
              0.9737449445085766, 0.921021461349961, 0.45978614012234886`], 
             UndirectedEdge[273, 394] -> 
             RGBColor[
              0.9720214242583773, 0.9785712459712206, 0.928529555959275], 
             UndirectedEdge[93, 94] -> 
             RGBColor[
              0.6928562892293213, 0.7566469632405373, 0.9537738893783974], 
             UndirectedEdge[358, 366] -> 
             RGBColor[
              0.9328900198945766, 0.9492606448555296, 0.9912230651996343], 
             UndirectedEdge[245, 329] -> 
             RGBColor[
              0.6284927348644657, 0.7044069757447782, 0.9666648710511412], 
             UndirectedEdge[44, 93] -> 
             RGBColor[
              0.9715510896941338, 0.9778595565348189, 0.9131632125510779], 
             UndirectedEdge[218, 314] -> 
             RGBColor[
              0.8563731758833293, 0.8884690636933472, 0.9861213488687023], 
             UndirectedEdge[133, 346] -> 
             RGBColor[
              0.9296671827211838, 0.9450727379260038, 0.9310324188178505], 
             UndirectedEdge[143, 272] -> 
             RGBColor[
              0.8312687254183482, 0.8670406481302262, 0.8880175936634376], 
             UndirectedEdge[272, 346] -> 
             RGBColor[
              0.7724936297229408, 0.8226247867037964, 0.977845125212154], 
             UndirectedEdge[61, 269] -> 
             RGBColor[
              0.6754763069565086, 0.7460182859101496, 0.968554242210816], 
             UndirectedEdge[158, 362] -> 
             RGBColor[
              0.9114190275623801, 0.9320043857129663, 0.9844643519704659], 
             UndirectedEdge[294, 393] -> 
             RGBColor[
              0.7899717387091705, 0.8363960512843986, 0.9795560697395373], 
             UndirectedEdge[17, 298] -> 
             RGBColor[
              0.6583476752522681, 0.7229129328057002, 0.8475503189418745], 
             UndirectedEdge[83, 179] -> 
             RGBColor[
              0.5022360849782636, 0.6067769051199691, 0.9539570108423385], 
             UndirectedEdge[223, 398] -> 
             RGBColor[
              0.6550877115101081, 0.7218604449772357, 0.912440872391698], 
             UndirectedEdge[52, 272] -> 
             RGBColor[
              0.8075749892953329, 0.7778494602727427, 0.6204947939673422], 
             UndirectedEdge[52, 174] -> 
             RGBColor[
              0.898548267675576, 0.8491937641783278, 0.6294891073477202], 
             UndirectedEdge[63, 317] -> 
             RGBColor[
              0.8852729348238721, 0.9069467215626217, 0.7415176594747788], 
             UndirectedEdge[145, 280] -> 
             RGBColor[
              0.8686195174338998, 0.8935877715821259, 0.7118907636126875], 
             UndirectedEdge[152, 317] -> 
             RGBColor[
              0.9897597577929749, 0.9882638969160784, 0.6907458554394936], 
             UndirectedEdge[102, 391] -> 
             RGBColor[
              0.8092443957946988, 0.851101455788287, 0.9444644620129967], 
             UndirectedEdge[168, 251] -> 
             RGBColor[
              0.776535043758587, 0.8243186682231867, 0.9357778891693487], 
             UndirectedEdge[89, 245] -> 
             RGBColor[
              0.9314823242507448, 0.9451947362776927, 0.8736544393440158], 
             UndirectedEdge[293, 330] -> 
             RGBColor[
              0.991752515397071, 0.9902789054817471, 0.7442903490868233], 
             UndirectedEdge[166, 247] -> 
             RGBColor[
              0.748130766252074, 0.802059889712617, 0.9550282297525401], 
             UndirectedEdge[8, 182] -> 
             RGBColor[
              0.7653089125024503, 0.8139523893969178, 0.8827370595833359], 
             UndirectedEdge[2, 215] -> 
             RGBColor[
              0.7778310306733265, 0.7988564876838916, 0.658707320772441], 
             UndirectedEdge[61, 107] -> 
             RGBColor[
              0.8031826064372664, 0.8449122393840065, 0.8945927130603453], 
             UndirectedEdge[192, 361] -> 
             RGBColor[
              0.8015861358329044, 0.8440481378557187, 0.9125257104018569], 
             UndirectedEdge[71, 321] -> 
             RGBColor[
              0.9500171626725198, 0.9619379064685359, 0.9588982736656508], 
             UndirectedEdge[26, 389] -> 
             RGBColor[
              0.6156121446280659, 0.6789219574962665, 0.8349901334475445], 
             UndirectedEdge[134, 263] -> 
             RGBColor[
              0.9836180216938042, 0.9869120997642138, 0.8951125122729298], 
             UndirectedEdge[105, 282] -> 
             RGBColor[
              0.7948375181675089, 0.8262724712040337, 0.6802688975639042], 
             UndirectedEdge[323, 340] -> 
             RGBColor[
              0.9813094379567386, 0.9472844482917765, 0.49498800412850746`], 
             UndirectedEdge[311, 323] -> 
             RGBColor[
              0.9531275602623037, 0.9285435023816204, 0.6596850170830317], 
             UndirectedEdge[29, 365] -> 
             RGBColor[
              0.9084799590363731, 0.9298018867500782, 0.9890737756705361], 
             UndirectedEdge[321, 384] -> 
             RGBColor[
              0.7097147563957968, 0.7700486563391614, 0.9373309440827107], 
             UndirectedEdge[115, 195] -> 
             RGBColor[
              0.9734279850394292, 0.9797032152668632, 0.9298636696235211], 
             UndirectedEdge[162, 359] -> 
             RGBColor[
              0.6038109821802673, 0.6671481652178985, 0.8507504157110928], 
             UndirectedEdge[106, 295] -> 
             RGBColor[
              0.8784342064679533, 0.9051020504543855, 0.9481798625929193], 
             UndirectedEdge[24, 242] -> 
             RGBColor[
              0.9860568693190173, 0.9681602225718995, 0.5824391674374136], 
             UndirectedEdge[109, 286] -> 
             RGBColor[
              0.982388154942604, 0.9856547155710655, 0.8819616729879716], 
             UndirectedEdge[287, 367] -> 
             RGBColor[
              0.9870760106519061, 0.9744381820178157, 0.6060293944257399], 
             UndirectedEdge[74, 140] -> 
             RGBColor[
              0.7463686243938459, 0.8018503978450708, 0.9755005784310451], 
             UndirectedEdge[168, 394] -> 
             RGBColor[
              0.7769849622443938, 0.8245712581250617, 0.9313012403536503], 
             UndirectedEdge[68, 249] -> 
             RGBColor[
              0.637079066166917, 0.7150329712561355, 0.9654034160144239], 
             UndirectedEdge[389, 400] -> 
             RGBColor[
              0.4165351780096094, 0.5246062786117989, 0.949084073896068], 
             UndirectedEdge[267, 346] -> 
             RGBColor[
              0.913149556922549, 0.9331280083419867, 0.9757449067204118], 
             UndirectedEdge[16, 392] -> 
             RGBColor[
              0.6153050835444471, 0.6775794791523035, 0.7406179565218204], 
             UndirectedEdge[13, 191] -> 
             RGBColor[
              0.7409106347583799, 0.7770494431102184, 0.6679359347481245], 
             UndirectedEdge[312, 327] -> 
             RGBColor[
              0.6184672661922229, 0.6974556445607232, 0.9652295638601767], 
             UndirectedEdge[260, 291] -> 
             RGBColor[
              0.979149478761751, 0.9823701614024525, 0.8485213803334881], 
             UndirectedEdge[83, 344] -> 
             RGBColor[
              0.6911904126758925, 0.7572109104614901, 0.9709764224479489], 
             UndirectedEdge[200, 288] -> 
             RGBColor[
              0.8641287967182967, 0.8908997803271432, 0.7771365251395375], 
             UndirectedEdge[297, 332] -> 
             RGBColor[
              0.9709478521729675, 0.913662424990028, 0.3416383210400904], 
             UndirectedEdge[189, 241] -> 
             RGBColor[
              0.9908589246870338, 0.9898688796632175, 0.7561553122061051], 
             UndirectedEdge[276, 358] -> 
             RGBColor[
              0.949799291575343, 0.9311854741227278, 0.6693803501134945], 
             UndirectedEdge[11, 102] -> 
             RGBColor[
              0.6192009519955407, 0.7017342533718063, 0.9631649136303639], 
             UndirectedEdge[96, 243] -> 
             RGBColor[
              0.8818563818125102, 0.9086323577762321, 0.9885934430114045], 
             UndirectedEdge[171, 397] -> 
             RGBColor[
              0.8140561202809597, 0.8554195473842192, 0.9819012213348041], 
             UndirectedEdge[314, 385] -> 
             RGBColor[
              0.8353770175798837, 0.8717272969877143, 0.9841187165462278], 
             UndirectedEdge[11, 213] -> 
             RGBColor[
              0.5831343399512883, 0.6724537529319254, 0.9603256178138873], 
             UndirectedEdge[68, 129] -> 
             RGBColor[
              0.8575870512176342, 0.8854773401996554, 0.751496590038087], 
             UndirectedEdge[137, 277] -> 
             RGBColor[
              0.923170335490341, 0.94121063329214, 0.9799017716477657], 
             UndirectedEdge[35, 327] -> 
             RGBColor[
              0.656594606806977, 0.7278525017932842, 0.9688674704824409], 
             UndirectedEdge[155, 183] -> 
             RGBColor[
              0.9771368061881897, 0.9591637114295961, 0.6460333664086302], 
             UndirectedEdge[63, 256] -> 
             RGBColor[
              0.8152620795172424, 0.8558767461285587, 0.9821500991647898], 
             UndirectedEdge[144, 358] -> 
             RGBColor[
              0.9403032903349666, 0.8982855250992142, 0.6370092116464223], 
             UndirectedEdge[192, 332] -> 
             RGBColor[
              0.9826773534729604, 0.9635047919397247, 0.6159279108968532], 
             UndirectedEdge[149, 259] -> 
             RGBColor[
              0.9268664818180752, 0.9125803465262716, 0.6667235197676162], 
             UndirectedEdge[146, 165] -> 
             RGBColor[
              0.9675063701448081, 0.8990830646377386, 0.343738880724221], 
             UndirectedEdge[164, 280] -> 
             RGBColor[
              0.9907029610928417, 0.9882102008123036, 0.6428596923581844], 
             UndirectedEdge[65, 105] -> 
             RGBColor[
              0.9875725734342657, 0.9765178617860266, 0.6107554205127128], 
             UndirectedEdge[73, 369] -> 
             RGBColor[
              0.994597441323465, 0.9909054308394714, 0.6571688491814893], 
             UndirectedEdge[187, 281] -> 
             RGBColor[
              0.7082941642272271, 0.7719867424511835, 0.9715989834260814], 
             UndirectedEdge[53, 253] -> 
             RGBColor[
              0.970239588395438, 0.9767835562562031, 0.9109997627272373], 
             UndirectedEdge[132, 191] -> 
             RGBColor[
              0.987492916761352, 0.9701957691860656, 0.5686051499013377], 
             UndirectedEdge[29, 273] -> 
             RGBColor[
              0.9486767695728495, 0.9612437992982839, 0.9717610212575643], 
             UndirectedEdge[138, 366] -> 
             RGBColor[
              0.9614344721982415, 0.9706796008676322, 0.946633501991258], 
             UndirectedEdge[229, 309] -> 
             RGBColor[
              0.7027953957866898, 0.7663315553615213, 0.9722362281811164], 
             UndirectedEdge[274, 287] -> 
             RGBColor[
              0.9851245806405196, 0.9874919324425533, 0.8682117731427124], 
             UndirectedEdge[251, 312] -> 
             RGBColor[
              0.901587772832637, 0.9231303093756462, 0.9474765691002538], 
             UndirectedEdge[339, 360] -> 
             RGBColor[
              0.8679704522050118, 0.8976528505130263, 0.9838446374085712], 
             UndirectedEdge[150, 365] -> 
             RGBColor[
              0.8958183012636641, 0.9197652133603748, 0.9899251433526082], 
             UndirectedEdge[61, 300] -> 
             RGBColor[
              0.8030829665380944, 0.8448710357250703, 0.896244004049418], 
             UndirectedEdge[62, 389] -> 
             RGBColor[
              0.44344173936053194`, 0.5463237243548228, 0.9512887545203645], 
             UndirectedEdge[374, 399] -> 
             RGBColor[
              0.97959741791967, 0.955990168118761, 0.6238329142235157], 
             UndirectedEdge[27, 51] -> 
             RGBColor[
              0.9852850514923583, 0.9878113629217764, 0.8768854217468], 
             UndirectedEdge[58, 159] -> 
             RGBColor[
              0.6463585770820987, 0.7167941439396912, 0.9569577093111328], 
             UndirectedEdge[57, 153] -> 
             RGBColor[
              0.9481709848665075, 0.9606522086318251, 0.9651845886338638], 
             UndirectedEdge[84, 264] -> 
             RGBColor[
              0.7796160788544901, 0.8281498579800847, 0.9716892894197544], 
             UndirectedEdge[159, 201] -> 
             RGBColor[
              0.9429759355555904, 0.956992126622471, 0.9814110462331429], 
             UndirectedEdge[80, 87] -> 
             RGBColor[
              0.8704398534284273, 0.8952769301527532, 0.7334654078982571], 
             UndirectedEdge[39, 288] -> 
             RGBColor[
              0.957085195711719, 0.964328403740087, 0.786186500853407], 
             UndirectedEdge[91, 365] -> 
             RGBColor[
              0.7487709022956087, 0.8037772468668496, 0.9757166602063072], 
             UndirectedEdge[5, 384] -> 
             RGBColor[
              0.5775209916623646, 0.6665593804763277, 0.9606865418248363], 
             UndirectedEdge[156, 381] -> 
             RGBColor[
              0.9786790495929817, 0.9513076910278999, 0.6093124954228182], 
             UndirectedEdge[2, 197] -> 
             RGBColor[
              0.8519177144144284, 0.8576782981229478, 0.6654456719534283], 
             UndirectedEdge[238, 293] -> 
             RGBColor[
              0.9601106631552259, 0.8775596448730933, 0.5486633868367721], 
             UndirectedEdge[85, 325] -> 
             RGBColor[
              0.9879355079425913, 0.9879113514975206, 0.7617727657986051], 
             UndirectedEdge[146, 332] -> 
             RGBColor[
              0.9836351171234783, 0.9564595487795757, 0.3909259495838773], 
             UndirectedEdge[197, 204] -> 
             RGBColor[
              0.6714026631965395, 0.742788857196029, 0.9681803996056985], 
             UndirectedEdge[20, 130] -> 
             RGBColor[
              0.9235510109966816, 0.9415839025492831, 0.9823556269935164], 
             UndirectedEdge[167, 348] -> 
             RGBColor[
              0.7351609112077202, 0.7898097100278618, 0.8942771408403798], 
             UndirectedEdge[83, 237] -> 
             RGBColor[
              0.5751225183345685, 0.6659493952150217, 0.9596948978679496], 
             UndirectedEdge[178, 334] -> 
             RGBColor[
              0.8935713160739595, 0.9179735283628924, 0.9897108238993069], 
             UndirectedEdge[178, 388] -> 
             RGBColor[
              0.65145518765374, 0.7248348602515098, 0.9678799044124875], 
             UndirectedEdge[115, 184] -> 
             RGBColor[
              0.8954006573926184, 0.9186437741498937, 0.9625502458573427], 
             UndirectedEdge[165, 385] -> 
             RGBColor[
              0.9080143578877504, 0.8612784825493021, 0.6314078843963005], 
             UndirectedEdge[202, 257] -> 
             RGBColor[
              0.9608256829384398, 0.9703044389943212, 0.9511960798736978], 
             UndirectedEdge[35, 57] -> 
             RGBColor[
              0.9322974994344082, 0.9479951222225529, 0.9636705614229224], 
             UndirectedEdge[115, 206] -> 
             RGBColor[
              0.9801693237084979, 0.9820411366388294, 0.7687134694315312], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.9909326516487207, 0.9905184326835919, 0.7999329579334191], 
             UndirectedEdge[61, 98] -> 
             RGBColor[
              0.7620703011617348, 0.8143704886891237, 0.9769982183782187], 
             UndirectedEdge[33, 173] -> 
             RGBColor[
              0.7343913401767656, 0.7924313636177809, 0.9741609235777028], 
             UndirectedEdge[6, 185] -> 
             RGBColor[
              0.9060809674084335, 0.9269687385419003, 0.9569390558516709], 
             UndirectedEdge[300, 363] -> 
             RGBColor[
              0.9025864013681217, 0.9229920812535317, 0.9058961579685882], 
             UndirectedEdge[34, 270] -> 
             RGBColor[
              0.9208820699262357, 0.939420440484794, 0.9808764631875541], 
             UndirectedEdge[162, 179] -> 
             RGBColor[
              0.734571245920179, 0.7884866804434032, 0.8589351352161545], 
             UndirectedEdge[11, 250] -> 
             RGBColor[
              0.7914579278460969, 0.8360382709815777, 0.9206187642861903], 
             UndirectedEdge[66, 314] -> 
             RGBColor[
              0.7010920287054416, 0.7657924029557381, 0.9712694704916078], 
             UndirectedEdge[153, 327] -> 
             RGBColor[
              0.6724680922390763, 0.7405095882025564, 0.9703814976933822], 
             UndirectedEdge[153, 392] -> 
             RGBColor[
              0.9604912361798781, 0.9668243381045762, 0.7686815243024887], 
             UndirectedEdge[110, 369] -> 
             RGBColor[
              0.9023363346837363, 0.9207812019172193, 0.7836200690864428], 
             UndirectedEdge[321, 398] -> 
             RGBColor[
              0.9810523979333732, 0.9851023457203593, 0.9040986234592538], 
             UndirectedEdge[188, 278] -> 
             RGBColor[
              0.9945320886774554, 0.9907130155087421, 0.6462297804572312], 
             UndirectedEdge[213, 289] -> 
             RGBColor[
              0.604040993929561, 0.6894267164655159, 0.9619714661986538], 
             UndirectedEdge[236, 263] -> 
             RGBColor[
              0.9907387233329383, 0.9901371539972503, 0.7812611985928877], 
             UndirectedEdge[93, 383] -> 
             RGBColor[
              0.9277687816017047, 0.9447120035489076, 0.9746091179194409], 
             UndirectedEdge[56, 286] -> 
             RGBColor[
              0.9071373828543917, 0.9266958003260778, 0.9109805926410695], 
             UndirectedEdge[25, 144] -> 
             RGBColor[
              0.9738951435279687, 0.9213427218649903, 0.47613437646227397`], 
             UndirectedEdge[143, 331] -> 
             RGBColor[
              0.8412746145696552, 0.8748573247828014, 0.8890148871836896], 
             UndirectedEdge[76, 257] -> 
             RGBColor[
              0.9664797428137049, 0.9745212275916204, 0.9416252313198652], 
             UndirectedEdge[91, 189] -> 
             RGBColor[
              0.802868684071584, 0.8450944764513422, 0.9128402183142537], 
             UndirectedEdge[133, 145] -> 
             RGBColor[
              0.8654831313094267, 0.8945040442418638, 0.9247486309085604], 
             UndirectedEdge[207, 230] -> 
             RGBColor[
              0.9062151060129239, 0.9271344722627416, 0.9589896245342056], 
             UndirectedEdge[238, 336] -> 
             RGBColor[
              0.9576825862293002, 0.8765299093032086, 0.5877536473646301], 
             UndirectedEdge[123, 306] -> 
             RGBColor[
              0.9598246352967073, 0.9053466801099388, 0.6052457900737029], 
             UndirectedEdge[272, 338] -> 
             RGBColor[
              0.7232050515370085, 0.7836925499134603, 0.9730459788679026], 
             UndirectedEdge[11, 289] -> 
             RGBColor[
              0.617711240255979, 0.7005248382708811, 0.9630476380652317], 
             UndirectedEdge[215, 300] -> 
             RGBColor[
              0.7849181372143481, 0.8301240089638173, 0.8948140021450903], 
             UndirectedEdge[224, 289] -> 
             RGBColor[
              0.7323343882559634, 0.7908161845257785, 0.9739820755488063], 
             UndirectedEdge[65, 161] -> 
             RGBColor[
              0.9919365968022947, 0.9909335898048083, 0.7832949886119253], 
             UndirectedEdge[14, 247] -> 
             RGBColor[
              0.9752328231164591, 0.9799294110089696, 0.8766593991218727], 
             UndirectedEdge[150, 226] -> 
             RGBColor[
              0.9488537414674575, 0.9606431374038371, 0.9446544505634673], 
             UndirectedEdge[15, 180] -> 
             RGBColor[
              0.9348630751133569, 0.9487591279838585, 0.9116976677412297], 
             UndirectedEdge[7, 114] -> 
             RGBColor[
              0.9741942716173371, 0.9779026799067851, 0.804037979079546], 
             UndirectedEdge[108, 313] -> 
             RGBColor[
              0.759589135153532, 0.8070780855502533, 0.7383878767095835], 
             UndirectedEdge[227, 315] -> 
             RGBColor[
              0.7764548582012198, 0.8241412005821884, 0.9312722504694955], 
             UndirectedEdge[174, 384] -> 
             RGBColor[
              0.6486441148112965, 0.7223965922484449, 0.9677023772420045], 
             UndirectedEdge[104, 138] -> 
             RGBColor[
              0.8396417022002745, 0.8746432002351401, 0.9369859126247635], 
             UndirectedEdge[313, 344] -> 
             RGBColor[
              0.6899329849626261, 0.7561900739973876, 0.9708774331322512], 
             UndirectedEdge[255, 374] -> 
             RGBColor[
              0.7996181156643416, 0.8152426049500845, 0.658488342815816], 
             UndirectedEdge[87, 167] -> 
             RGBColor[
              0.9909263943215645, 0.9886420284167565, 0.6638299648716626], 
             UndirectedEdge[114, 312] -> 
             RGBColor[
              0.9069528772263158, 0.9247595648126972, 0.8138662795579619], 
             UndirectedEdge[50, 265] -> 
             RGBColor[
              0.978171018648519, 0.9804093190238379, 0.7608698511904846], 
             UndirectedEdge[310, 345] -> 
             RGBColor[
              0.9090234482459432, 0.81905487418925, 0.621868950558716], 
             UndirectedEdge[315, 334] -> 
             RGBColor[
              0.7507099738752712, 0.8049589710472502, 0.9763210730312639], 
             UndirectedEdge[102, 302] -> 
             RGBColor[
              0.810116914726091, 0.8517521789787007, 0.9429875150515328], 
             UndirectedEdge[172, 211] -> 
             RGBColor[
              0.9315973027901165, 0.947887138916094, 0.9792171555570068], 
             UndirectedEdge[264, 381] -> 
             RGBColor[
              0.9572858930408021, 0.9357041402317374, 0.6612632975347832], 
             UndirectedEdge[270, 397] -> 
             RGBColor[
              0.9032365407567933, 0.9256803161694491, 0.9906327016578034], 
             UndirectedEdge[48, 290] -> 
             RGBColor[
              0.9513849723746066, 0.9628975746751081, 0.9544873655108269], 
             UndirectedEdge[224, 323] -> 
             RGBColor[
              0.8970058453916578, 0.8838604962780072, 0.6566524425480027], 
             UndirectedEdge[10, 339] -> 
             RGBColor[
              0.6402991677602852, 0.7165019789381885, 0.9664399045423858], 
             UndirectedEdge[254, 320] -> 
             RGBColor[
              0.7688436318062437, 0.8195769028797546, 0.9754706844986467], 
             UndirectedEdge[92, 392] -> 
             RGBColor[
              0.994084142014225, 0.9897549028904475, 0.5974735505709767], 
             UndirectedEdge[166, 224] -> 
             RGBColor[
              0.6813896571332201, 0.7494569567663525, 0.9699715196981249], 
             UndirectedEdge[108, 344] -> 
             RGBColor[
              0.9237250616247143, 0.9373633947199111, 0.7534534928578488], 
             UndirectedEdge[180, 271] -> 
             RGBColor[
              0.9911138491357301, 0.9905933625010332, 0.7969300466496095], 
             UndirectedEdge[104, 207] -> 
             RGBColor[
              0.7678187732112065, 0.8187151616770515, 0.9774475360917338], 
             UndirectedEdge[45, 266] -> 
             RGBColor[
              0.9848410224856718, 0.9871553576621073, 0.8630896382337596], 
             UndirectedEdge[59, 373] -> 
             RGBColor[
              0.7737751829108052, 0.8208461491138599, 0.884258863602486], 
             UndirectedEdge[107, 352] -> 
             RGBColor[
              0.9868878316639593, 0.9888457956727609, 0.8669660927394869], 
             UndirectedEdge[99, 338] -> 
             RGBColor[
              0.6457938068161609, 0.7213021560802131, 0.9666404255853007], 
             UndirectedEdge[186, 341] -> 
             RGBColor[
              0.9862781356088908, 0.9649574047063124, 0.4367088821206184], 
             UndirectedEdge[90, 156] -> 
             RGBColor[
              0.9453336368883022, 0.9575909185545808, 0.9336633224149944], 
             UndirectedEdge[34, 151] -> 
             RGBColor[
              0.9709306228136525, 0.9763163053319247, 0.8658261444221782], 
             UndirectedEdge[174, 260] -> 
             RGBColor[
              0.9239333011444938, 0.939084346952701, 0.8689827330849884], 
             UndirectedEdge[13, 216] -> 
             RGBColor[
              0.6881014060464787, 0.7545463531462333, 0.970913675379734], 
             UndirectedEdge[9, 217] -> 
             RGBColor[
              0.9940972643626838, 0.9913303549597221, 0.7113803693618643], 
             UndirectedEdge[87, 159] -> 
             RGBColor[
              0.9711747477342594, 0.9746673458933565, 0.7311224035692908], 
             UndirectedEdge[184, 305] -> 
             RGBColor[0.5899049800444337, 0.67253467786713, 0.9634923242272], 
             UndirectedEdge[12, 259] -> 
             RGBColor[
              0.9378213713256072, 0.9488056634145928, 0.771193374050534], 
             UndirectedEdge[27, 287] -> 
             RGBColor[
              0.9858862191549967, 0.9880599611995817, 0.8669225178048415], 
             UndirectedEdge[188, 284] -> 
             RGBColor[
              0.9689941929364021, 0.9024737695676006, 0.4389535138654823], 
             UndirectedEdge[118, 126] -> 
             RGBColor[
              0.9445453655141952, 0.8123006936743022, 0.526012141444526], 
             UndirectedEdge[209, 304] -> 
             RGBColor[
              0.9112939868850568, 0.9295596792884313, 0.8918154711885047], 
             UndirectedEdge[48, 108] -> 
             RGBColor[
              0.9574436166038005, 0.9642496551944417, 0.7566695987326634], 
             UndirectedEdge[136, 376] -> 
             RGBColor[
              0.9943323446680639, 0.990285783269871, 0.62448887771211], 
             UndirectedEdge[48, 344] -> 
             RGBColor[
              0.8877874664128947, 0.913361643641576, 0.9891591551553309], 
             UndirectedEdge[13, 198] -> 
             RGBColor[
              0.7458614598266492, 0.7979969812307932, 0.8742210679066529], 
             UndirectedEdge[286, 320] -> 
             RGBColor[
              0.7939924152387974, 0.8376018446477458, 0.9001655878244813], 
             UndirectedEdge[176, 368] -> 
             RGBColor[
              0.7676210412910678, 0.8184309819051008, 0.9774622490923385], 
             UndirectedEdge[248, 388] -> 
             RGBColor[
              0.7166251525714715, 0.775531747272227, 0.9299858224862221], 
             UndirectedEdge[57, 188] -> 
             RGBColor[
              0.9815512679248128, 0.9831279947992035, 0.7708339378858853], 
             UndirectedEdge[39, 225] -> 
             RGBColor[
              0.9489053470749775, 0.9610157740598636, 0.9575579245551714], 
             UndirectedEdge[355, 379] -> 
             RGBColor[
              0.8827102016588815, 0.8604375422195727, 0.6374160861804217], 
             UndirectedEdge[85, 348] -> 
             RGBColor[
              0.7378784043453075, 0.7899809245248145, 0.7800017351561344], 
             UndirectedEdge[118, 336] -> 
             RGBColor[
              0.941538958836339, 0.8110318038895976, 0.5746868226312971], 
             UndirectedEdge[195, 392] -> 
             RGBColor[
              0.9870898342870691, 0.9868759062823274, 0.7310896299342091], 
             UndirectedEdge[193, 281] -> 
             RGBColor[
              0.8865866580075822, 0.9093799828434337, 0.8538343369054979], 
             UndirectedEdge[154, 312] -> 
             RGBColor[
              0.7967332359844836, 0.8411333264387271, 0.9803745811336766], 
             UndirectedEdge[53, 171] -> 
             RGBColor[
              0.8339678949077376, 0.8708498338510086, 0.9683088204367644], 
             UndirectedEdge[115, 188] -> 
             RGBColor[
              0.9802096699905436, 0.9821274332564904, 0.773104913243822], 
             UndirectedEdge[319, 329] -> 
             RGBColor[
              0.6887708041222962, 0.7500729646817228, 0.8792255648954861], 
             UndirectedEdge[231, 359] -> 
             RGBColor[
              0.25810211921469906`, 0.38861207028714795`, 0.9380099059101847],
              UndirectedEdge[288, 399] -> 
             RGBColor[
              0.9895806082344267, 0.9887883930082837, 0.7372252044333865], 
             UndirectedEdge[140, 220] -> 
             RGBColor[
              0.8814281877201051, 0.9082909274299673, 0.9885526014766175], 
             UndirectedEdge[9, 215] -> 
             RGBColor[
              0.7870878670990951, 0.8310212480306749, 0.8588559628738862], 
             UndirectedEdge[309, 329] -> 
             RGBColor[
              0.4486610899538175, 0.561491670854284, 0.9502341500884429], 
             UndirectedEdge[9, 61] -> 
             RGBColor[
              0.8052526964228415, 0.8457682747919277, 0.8602859647782137], 
             UndirectedEdge[21, 82] -> 
             RGBColor[
              0.9043851453659982, 0.5624299516364715, 0.47777788306430913`], 
             UndirectedEdge[154, 361] -> 
             RGBColor[
              0.6950378010391167, 0.761284188894042, 0.9705146729571688], 
             UndirectedEdge[160, 213] -> 
             RGBColor[
              0.7663898230663695, 0.816758505384487, 0.9531154130509761], 
             UndirectedEdge[331, 342] -> 
             RGBColor[
              0.8296533018097744, 0.8672283313946285, 0.9551777824718546], 
             UndirectedEdge[122, 159] -> 
             RGBColor[
              0.9197392315788462, 0.938489939946471, 0.9801006636617315], 
             UndirectedEdge[258, 278] -> 
             RGBColor[
              0.8286501888144572, 0.8638578713313994, 0.8276042721808612], 
             UndirectedEdge[37, 201] -> 
             RGBColor[
              0.96540998802539, 0.9720760529129693, 0.8696642002186832], 
             UndirectedEdge[61, 314] -> 
             RGBColor[
              0.7088302535748315, 0.7720746425077666, 0.9718786518993778], 
             UndirectedEdge[297, 314] -> 
             RGBColor[
              0.8821817648864305, 0.8667347552866029, 0.6471620843303616], 
             UndirectedEdge[84, 175] -> 
             RGBColor[
              0.8039142190397723, 0.8449546941632091, 0.8715953906506273], 
             UndirectedEdge[72, 374] -> 
             RGBColor[
              0.9585058473793308, 0.8678750426023192, 0.31318549663381856`], 
             UndirectedEdge[168, 180] -> 
             RGBColor[
              0.779050868065555, 0.8254255632734697, 0.8970638345041277], 
             UndirectedEdge[36, 60] -> 
             RGBColor[
              0.8870944846370737, 0.9110414619257052, 0.9112345888786276], 
             UndirectedEdge[347, 387] -> 
             RGBColor[
              0.9353583709542701, 0.949711176728902, 0.9359366918464764], 
             UndirectedEdge[140, 141] -> 
             RGBColor[
              0.8719170246617811, 0.6988786222996899, 0.5998357445071911], 
             UndirectedEdge[233, 382] -> 
             RGBColor[
              0.978245783905436, 0.9808821047153327, 0.7938325134186072], 
             UndirectedEdge[21, 122] -> 
             RGBColor[
              0.8537789482455519, 0.5247216737218217, 0.576805487372304], 
             UndirectedEdge[202, 268] -> 
             RGBColor[
              0.9637321568677963, 0.9724502084358934, 0.9452966127208673], 
             UndirectedEdge[196, 344] -> 
             RGBColor[
              0.8872667326413586, 0.9129464246670947, 0.9891094871033372], 
             UndirectedEdge[109, 343] -> 
             RGBColor[
              0.9491116719449652, 0.9612158927412748, 0.9588119071517155], 
             UndirectedEdge[52, 117] -> 
             RGBColor[
              0.9648744900387319, 0.9003494941242814, 0.5715948074934865], 
             UndirectedEdge[51, 194] -> 
             RGBColor[
              0.9918462887345896, 0.9907198297139188, 0.7719680909163051], 
             UndirectedEdge[223, 342] -> 
             RGBColor[
              0.6457266461999458, 0.7151661219952314, 0.9411456181051311], 
             UndirectedEdge[241, 374] -> 
             RGBColor[
              0.984261352966047, 0.957299760091081, 0.5015399483463324], 
             UndirectedEdge[76, 109] -> 
             RGBColor[
              0.9653166005986893, 0.9736537580321325, 0.9435941276938111], 
             UndirectedEdge[90, 381] -> 
             RGBColor[
              0.9377053735432213, 0.9202928733215289, 0.6663890274759134], 
             UndirectedEdge[75, 227] -> 
             RGBColor[
              0.9897438927386256, 0.9896092889596437, 0.7892814662558019], 
             UndirectedEdge[209, 329] -> 
             RGBColor[
              0.6095095001548982, 0.6892702596735484, 0.964854233178009], 
             UndirectedEdge[24, 358] -> 
             RGBColor[
              0.9596572301686561, 0.9679701507343415, 0.8897817479164136], 
             UndirectedEdge[208, 369] -> 
             RGBColor[
              0.992884873253834, 0.9901972399316872, 0.6855505340793668], 
             UndirectedEdge[62, 400] -> 
             RGBColor[
              0.6237111476286288, 0.7052693204803147, 0.9636064703047618], 
             UndirectedEdge[127, 325] -> 
             RGBColor[
              0.9883009767691511, 0.9886930523629657, 0.8015517921574917], 
             UndirectedEdge[43, 277] -> 
             RGBColor[
              0.8255345236493902, 0.864251663484145, 0.983081079583347], 
             UndirectedEdge[70, 227] -> 
             RGBColor[
              0.8878085684721926, 0.9122672817207186, 0.9415944521748836], 
             UndirectedEdge[25, 366] -> 
             RGBColor[
              0.9664818730875787, 0.9723178416213057, 0.8303482300154859], 
             UndirectedEdge[20, 387] -> 
             RGBColor[
              0.9159602171435447, 0.935531209577402, 0.9816316102994226], 
             UndirectedEdge[328, 387] -> 
             RGBColor[
              0.9305710745749826, 0.9214237532942209, 0.6757410415266769], 
             UndirectedEdge[249, 386] -> 
             RGBColor[
              0.7363474243856598, 0.7933925451885666, 0.9750825088352609], 
             UndirectedEdge[110, 243] -> 
             RGBColor[
              0.8558704371600068, 0.8879869198841999, 0.9860949647143535], 
             UndirectedEdge[47, 121] -> 
             RGBColor[
              0.9938103052116224, 0.9911563230790552, 0.7121114361784484], 
             UndirectedEdge[31, 156] -> 
             RGBColor[
              0.8421680527594331, 0.8763152006655848, 0.9235617175112818], 
             UndirectedEdge[98, 283] -> 
             RGBColor[
              0.6830623749742647, 0.7502282949436219, 0.9707784250131712], 
             UndirectedEdge[38, 358] -> 
             RGBColor[
              0.9564119821027035, 0.9666281572599988, 0.9435639068020247], 
             UndirectedEdge[126, 199] -> 
             RGBColor[
              0.7547368334981579, 0.8054419279756039, 0.8849325856457692], 
             UndirectedEdge[39, 200] -> 
             RGBColor[
              0.8272893045608598, 0.8658143374697983, 0.9832050750758171], 
             UndirectedEdge[227, 304] -> 
             RGBColor[
              0.9878144476146095, 0.9892289751812984, 0.8516096684320041], 
             UndirectedEdge[242, 333] -> 
             RGBColor[
              0.9867997766901982, 0.9666906756892688, 0.4409757069890654], 
             UndirectedEdge[30, 333] -> 
             RGBColor[
              0.9361174655877216, 0.9471382603726648, 0.7460021845398754], 
             UndirectedEdge[85, 96] -> 
             RGBColor[
              0.9284242560013811, 0.9416447575845663, 0.7972180780570939], 
             UndirectedEdge[39, 94] -> 
             RGBColor[
              0.6748599218336973, 0.7428268039379818, 0.9704208705609958], 
             UndirectedEdge[63, 138] -> 
             RGBColor[
              0.8809908899750626, 0.9069454999902713, 0.9411072132320251], 
             UndirectedEdge[119, 324] -> 
             RGBColor[
              0.9421183017901158, 0.8053408410930318, 0.5411140570153194], 
             UndirectedEdge[18, 224] -> 
             RGBColor[
              0.8079065728654748, 0.8499110584815394, 0.9814752221934111], 
             UndirectedEdge[84, 204] -> 
             RGBColor[
              0.6148278507115188, 0.6981839727434695, 0.9628206470780879], 
             UndirectedEdge[241, 288] -> 
             RGBColor[
              0.9942445432808038, 0.9900979849806038, 0.6149322385562033], 
             UndirectedEdge[91, 266] -> 
             RGBColor[
              0.7988477864363552, 0.8425877021319841, 0.9416795183172023], 
             UndirectedEdge[201, 263] -> 
             RGBColor[
              0.9616283794518623, 0.9705122605849081, 0.9323352407713118], 
             UndirectedEdge[29, 266] -> 
             RGBColor[
              0.9585568431771196, 0.9686123420152128, 0.9550366337814312], 
             UndirectedEdge[161, 326] -> 
             RGBColor[
              0.9529699289229957, 0.9621402956713179, 0.867537153954675], 
             UndirectedEdge[174, 235] -> 
             RGBColor[
              0.7339938456899469, 0.7919608520829, 0.9743458509138425], 
             UndirectedEdge[207, 233] -> 
             RGBColor[
              0.917741016478143, 0.9333162603583789, 0.8116033851475346], 
             UndirectedEdge[199, 212] -> 
             RGBColor[
              0.6251505439350596, 0.7052084055890817, 0.9645603881782947], 
             UndirectedEdge[127, 184] -> 
             RGBColor[
              0.9097185095533559, 0.9272195890644053, 0.8351780748780158], 
             UndirectedEdge[261, 381] -> 
             RGBColor[
              0.9786790495929817, 0.9513076910278999, 0.6093124954228182], 
             UndirectedEdge[221, 230] -> 
             RGBColor[
              0.9673259214368846, 0.9751523062232976, 0.9401928716295525], 
             UndirectedEdge[22, 273] -> 
             RGBColor[
              0.9333708975904107, 0.9490987012730245, 0.9723601814277945], 
             UndirectedEdge[240, 292] -> 
             RGBColor[
              0.9681443592821573, 0.9555422428089426, 0.6678042819403424], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.9312287782475783, 0.9473099687938118, 0.9693591697201551], 
             UndirectedEdge[120, 343] -> 
             RGBColor[
              0.955417273833705, 0.9651537693098435, 0.9138874732951512], 
             UndirectedEdge[175, 310] -> 
             RGBColor[
              0.9457082025310735, 0.956774517322419, 0.8852788722309837], 
             UndirectedEdge[55, 201] -> 
             RGBColor[
              0.958855672058413, 0.968835208105594, 0.9545307944324564], 
             UndirectedEdge[264, 333] -> 
             RGBColor[
              0.9683717179617208, 0.9726552178592152, 0.7420852865544728], 
             UndirectedEdge[107, 197] -> 
             RGBColor[
              0.859104460854622, 0.8889870230618099, 0.8999010623370051], 
             UndirectedEdge[131, 300] -> 
             RGBColor[
              0.931702021030572, 0.9461760783888642, 0.908681725612914], 
             UndirectedEdge[164, 227] -> 
             RGBColor[
              0.9866896313754956, 0.9887638347599661, 0.8702507844452343], 
             UndirectedEdge[75, 315] -> 
             RGBColor[
              0.7815089410574592, 0.825813632362335, 0.8171607147671172], 
             UndirectedEdge[123, 193] -> 
             RGBColor[
              0.9717214129908294, 0.912389969922506, 0.5031875207090143], 
             UndirectedEdge[157, 253] -> 
             RGBColor[
              0.9732340607632315, 0.979016828845105, 0.9059309020920383], 
             UndirectedEdge[87, 110] -> 
             RGBColor[
              0.9019043526916563, 0.9198572361162392, 0.7366014951323525], 
             UndirectedEdge[112, 273] -> 
             RGBColor[
              0.8495041542345867, 0.8828748914744943, 0.9641886043030126], 
             UndirectedEdge[193, 384] -> 
             RGBColor[
              0.7192239817927109, 0.775311313557729, 0.8393141779838258], 
             UndirectedEdge[95, 249] -> 
             RGBColor[
              0.7207584896219905, 0.7809623517583784, 0.9735956223210958], 
             UndirectedEdge[61, 66] -> 
             RGBColor[
              0.609278849141217, 0.6936790432890265, 0.9623838093478112], 
             UndirectedEdge[113, 251] -> 
             RGBColor[
              0.963362859770404, 0.9721966613213543, 0.9469013012988804], 
             UndirectedEdge[107, 131] -> 
             RGBColor[
              0.9318016609297439, 0.9462172820478005, 0.9070304346238416], 
             UndirectedEdge[71, 343] -> 
             RGBColor[
              0.9229444036163511, 0.9413948310579743, 0.9925124552107649], 
             UndirectedEdge[113, 168] -> 
             RGBColor[
              0.7561064001864688, 0.8090830192959348, 0.9703582540933764], 
             UndirectedEdge[58, 201] -> 
             RGBColor[
              0.6400949459711006, 0.7121227381128635, 0.9675604029654208], 
             UndirectedEdge[47, 130] -> 
             RGBColor[
              0.9473099975100464, 0.9570150927864933, 0.8242590700955719], 
             UndirectedEdge[17, 82] -> 
             RGBColor[
              0.6572001137787487, 0.7224383866454152, 0.8665683823519876], 
             UndirectedEdge[11, 25] -> 
             RGBColor[
              0.7957830658268232, 0.8373778374612305, 0.8163032578625912], 
             UndirectedEdge[73, 392] -> 
             RGBColor[
              0.9944088839020684, 0.9905021255811838, 0.6366455375039912], 
             UndirectedEdge[155, 337] -> 
             RGBColor[
              0.9705595987353419, 0.9542584408804511, 0.6571668630158614], 
             UndirectedEdge[159, 165] -> 
             RGBColor[
              0.947578840210689, 0.8924769528734762, 0.6230755006610873], 
             UndirectedEdge[226, 368] -> 
             RGBColor[
              0.8476489874128337, 0.8808319974755001, 0.9347661256141483], 
             UndirectedEdge[188, 258] -> 
             RGBColor[
              0.8282643606700711, 0.8630326239437669, 0.785609259719739], 
             UndirectedEdge[140, 350] -> 
             RGBColor[
              0.5284396101560027, 0.6057397671130744, 0.9608181388988537], 
             UndirectedEdge[14, 38] -> 
             RGBColor[
              0.9880893354665032, 0.989342648372352, 0.847054065339168], 
             UndirectedEdge[242, 268] -> 
             RGBColor[
              0.9823503902902682, 0.9666274982413455, 0.6438651170040315], 
             UndirectedEdge[20, 50] -> 
             RGBColor[
              0.9548018244950587, 0.9658118552304105, 0.9613929009444375], 
             UndirectedEdge[149, 212] -> 
             RGBColor[
              0.8513253617697312, 0.8530661204539092, 0.6593272180360862], 
             UndirectedEdge[80, 361] -> 
             RGBColor[
              0.6818814752434712, 0.7510063671907042, 0.9692033733547136], 
             UndirectedEdge[31, 204] -> 
             RGBColor[
              0.6559866680642821, 0.7307457646328072, 0.9666438772815804], 
             UndirectedEdge[209, 245] -> 
             RGBColor[
              0.8506321231328484, 0.8837349814649929, 0.9856152453443137], 
             UndirectedEdge[113, 148] -> 
             RGBColor[
              0.9675297419921456, 0.9739863112496491, 0.8808249441849478], 
             UndirectedEdge[48, 231] -> 
             RGBColor[
              0.6115352656313259, 0.6872708513287044, 0.9664301428956714], 
             UndirectedEdge[198, 224] -> 
             RGBColor[
              0.908651934915386, 0.9273927335296971, 0.8889474138213869], 
             UndirectedEdge[1, 188] -> 
             RGBColor[
              0.9859955954806818, 0.9634078287886708, 0.4863334678271025], 
             UndirectedEdge[256, 264] -> 
             RGBColor[
              0.8983650612576644, 0.9215942228115126, 0.9831747182238098], 
             UndirectedEdge[15, 170] -> 
             RGBColor[
              0.9297510724846251, 0.9457160073920561, 0.9548063751134452], 
             UndirectedEdge[20, 322] -> 
             RGBColor[
              0.9418357228222193, 0.8731121794310028, 0.6210960506908415], 
             UndirectedEdge[92, 153] -> 
             RGBColor[
              0.9609786002508056, 0.9678667605722241, 0.8217280957605543], 
             UndirectedEdge[189, 360] -> 
             RGBColor[
              0.9633130755317922, 0.9716675277643321, 0.9249526039044746], 
             UndirectedEdge[272, 342] -> 
             RGBColor[
              0.8196474126584673, 0.8594116547420534, 0.9541804889516028], 
             UndirectedEdge[69, 219] -> 
             RGBColor[
              0.8479429469910033, 0.8812177275557538, 0.9418849487427232], 
             UndirectedEdge[86, 151] -> 
             RGBColor[
              0.7807936953224427, 0.825935421234842, 0.859366490820302], 
             UndirectedEdge[72, 288] -> 
             RGBColor[
              0.9684890376940876, 0.900673267491842, 0.4265777868436894], 
             UndirectedEdge[266, 273] -> 
             RGBColor[
              0.9692315818068886, 0.9765735446070143, 0.9369670856989613], 
             UndirectedEdge[131, 297] -> 
             RGBColor[
              0.9189876398146835, 0.8959264382836853, 0.6507141447500612], 
             UndirectedEdge[219, 360] -> 
             RGBColor[
              0.9617686808160659, 0.9710077252674374, 0.949599830440113], 
             UndirectedEdge[58, 236] -> 
             RGBColor[
              0.6692052898521768, 0.7317476315252056, 0.8164863607869967], 
             UndirectedEdge[272, 321] -> 
             RGBColor[
              0.8241405110363902, 0.8627626001555351, 0.9465748453855172], 
             UndirectedEdge[250, 391] -> 
             RGBColor[
              0.981501371645255, 0.9854054733980584, 0.901918312668823], 
             UndirectedEdge[122, 298] -> 
             RGBColor[0.9419926550850697, 0.953499171518578, 0.8713473070265],
              UndirectedEdge[113, 282] -> 
             RGBColor[
              0.7735040350474374, 0.823207203030588, 0.9717278596392682], 
             UndirectedEdge[237, 343] -> 
             RGBColor[
              0.7719860178199786, 0.8223125850024108, 0.9779030444086736], 
             UndirectedEdge[174, 398] -> 
             RGBColor[
              0.9199817563488728, 0.9374502816296427, 0.9344700566185477], 
             UndirectedEdge[223, 384] -> 
             RGBColor[
              0.38375006997253175`, 0.5068067555960379, 0.9456731930151548], 
             UndirectedEdge[143, 260] -> 
             RGBColor[
              0.9921321571109523, 0.9910144590181089, 0.7800540482036149], 
             UndirectedEdge[148, 161] -> 
             RGBColor[
              0.9932272484802462, 0.9914673074418764, 0.7619055502087961], 
             UndirectedEdge[137, 199] -> 
             RGBColor[
              0.7346256956941077, 0.7914163577234106, 0.9625611150008273], 
             UndirectedEdge[147, 387] -> 
             RGBColor[
              0.8027617288894822, 0.8463666852296938, 0.9808364301387309], 
             UndirectedEdge[138, 381] -> 
             RGBColor[
              0.9778587649225832, 0.9509684822363358, 0.6229067352399993], 
             UndirectedEdge[42, 207] -> 
             RGBColor[
              0.853384481208718, 0.8859296370839216, 0.9858777677146491], 
             UndirectedEdge[185, 247] -> 
             RGBColor[
              0.9666108318114068, 0.9746189935514682, 0.9414033318402418], 
             UndirectedEdge[49, 380] -> 
             RGBColor[
              0.765642520634306, 0.8145907329061346, 0.8981264899421204], 
             UndirectedEdge[63, 242] -> 
             RGBColor[
              0.8788460768217589, 0.8857166158157267, 0.6783541959614017], 
             UndirectedEdge[12, 238] -> 
             RGBColor[
              0.9625051920957877, 0.8771701839911623, 0.4086931180357105], 
             UndirectedEdge[109, 382] -> 
             RGBColor[
              0.9691074257374249, 0.976480949213695, 0.9371772495394743], 
             UndirectedEdge[4, 115] -> 
             RGBColor[
              0.8515919207538867, 0.8843833267664798, 0.958193547248599], 
             UndirectedEdge[187, 279] -> 
             RGBColor[
              0.81582281828446, 0.8544413041640386, 0.8649526848981881], 
             UndirectedEdge[152, 156] -> 
             RGBColor[
              0.9862979976145638, 0.9886018841352922, 0.8767411693795588], 
             UndirectedEdge[143, 290] -> 
             RGBColor[
              0.9858523915611411, 0.9879311546676642, 0.8623413460769753], 
             UndirectedEdge[48, 234] -> 
             RGBColor[
              0.577001057115036, 0.6509732085827988, 0.9644634708094519], 
             UndirectedEdge[294, 341] -> 
             RGBColor[
              0.8428641186353167, 0.8737819517424006, 0.7345130300013848], 
             UndirectedEdge[243, 351] -> 
             RGBColor[
              0.945990591542732, 0.9572258100282176, 0.8951248643147784], 
             UndirectedEdge[241, 399] -> 
             RGBColor[
              0.9899004636460746, 0.9894725313914556, 0.7720394920724625], 
             UndirectedEdge[78, 207] -> 
             RGBColor[
              0.7189127359484182, 0.7798115581494683, 0.9730501533053337], 
             UndirectedEdge[174, 267] -> 
             RGBColor[
              0.903725796651498, 0.9256137577030088, 0.9748460600530688], 
             UndirectedEdge[124, 293] -> 
             RGBColor[
              0.9907425761214501, 0.9881187474917182, 0.6343646915582258], 
             UndirectedEdge[57, 392] -> 
             RGBColor[
              0.9812765266299269, 0.9825403509500485, 0.7409300434442863], 
             UndirectedEdge[272, 331] -> 
             RGBColor[
              0.6821024802229537, 0.7515829088118087, 0.968949258684685], 
             UndirectedEdge[91, 255] -> 
             RGBColor[
              0.6219309207752963, 0.7039505650109039, 0.9633798267729115], 
             UndirectedEdge[35, 337] -> 
             RGBColor[
              0.929559560912003, 0.9459531721555059, 0.9683051771726217], 
             UndirectedEdge[219, 339] -> 
             RGBColor[
              0.8902664326391095, 0.914281156214459, 0.946103358256666], 
             UndirectedEdge[166, 185] -> 
             RGBColor[
              0.7552084975480979, 0.8073384501244704, 0.9430474768363372], 
             UndirectedEdge[137, 238] -> 
             RGBColor[
              0.9405778551031063, 0.86377322883572, 0.6167074955329173], 
             UndirectedEdge[218, 300] -> 
             RGBColor[
              0.9506258888465922, 0.9612654569106509, 0.9104867010187423], 
             UndirectedEdge[96, 110] -> 
             RGBColor[
              0.8366847212338856, 0.8726887507870962, 0.9842650140020294], 
             UndirectedEdge[225, 375] -> 
             RGBColor[
              0.9856374973857897, 0.9872277632826362, 0.8383829186603364], 
             UndirectedEdge[24, 25] -> 
             RGBColor[
              0.9932490833616582, 0.9910273475001176, 0.7289069127322652], 
             UndirectedEdge[40, 361] -> 
             RGBColor[
              0.5680675841599747, 0.6602218818309237, 0.95913950760665], 
             UndirectedEdge[141, 394] -> 
             RGBColor[
              0.9264026074303068, 0.7409776109013244, 0.5575154808256645], 
             UndirectedEdge[200, 360] -> 
             RGBColor[
              0.8369028029747029, 0.8733825668114296, 0.9807481044769828], 
             UndirectedEdge[68, 229] -> 
             RGBColor[
              0.8086738553345285, 0.8510729179928442, 0.9814024401090982], 
             UndirectedEdge[96, 258] -> 
             RGBColor[
              0.7625265633467311, 0.8147558342227762, 0.9768736218712246], 
             UndirectedEdge[106, 310] -> 
             RGBColor[
              0.837867892321264, 0.8739091072308431, 0.9843043777573789], 
             UndirectedEdge[15, 394] -> 
             RGBColor[
              0.9327971692921957, 0.9479048228354504, 0.9459350735907524], 
             UndirectedEdge[115, 203] -> 
             RGBColor[
              0.9773978375147333, 0.9819444554780152, 0.89092444124241], 
             UndirectedEdge[218, 298] -> 
             RGBColor[
              0.9529246661533188, 0.9622160604028646, 0.872390012001311], 
             UndirectedEdge[165, 262] -> 
             RGBColor[
              0.9423730177992559, 0.8885944590427812, 0.6318876001077063], 
             UndirectedEdge[141, 357] -> 
             RGBColor[
              0.928314967685433, 0.7417684210122361, 0.5258227223685269], 
             UndirectedEdge[15, 239] -> 
             RGBColor[
              0.9267660399913097, 0.9434897750460836, 0.9598592565034663], 
             UndirectedEdge[80, 228] -> 
             RGBColor[
              0.623076417002125, 0.703265771772695, 0.9645740237599287], 
             UndirectedEdge[260, 272] -> 
             RGBColor[
              0.8329600227642506, 0.867740043047116, 0.8599884197046104], 
             UndirectedEdge[7, 361] -> 
             RGBColor[
              0.7849300017684062, 0.8321222860520893, 0.9629439931707315], 
             UndirectedEdge[22, 255] -> 
             RGBColor[
              0.7663341055336219, 0.8178301068688731, 0.9773361024073706], 
             UndirectedEdge[28, 380] -> 
             RGBColor[
              0.8982511447667205, 0.9197119968853285, 0.910300071003094], 
             UndirectedEdge[53, 397] -> 
             RGBColor[
              0.9331144777903658, 0.9490573500151447, 0.977990882227022], 
             UndirectedEdge[187, 306] -> 
             RGBColor[
              0.8050136103204848, 0.8478477523841543, 0.9489871092941036], 
             UndirectedEdge[208, 392] -> 
             RGBColor[
              0.9926963158324376, 0.9897939346733995, 0.6650272224018687], 
             UndirectedEdge[33, 381] -> 
             RGBColor[
              0.8809890566549499, 0.8753036760283941, 0.6609170514376621], 
             UndirectedEdge[290, 321] -> 
             RGBColor[
              0.9787241771791831, 0.983653106692973, 0.9208985977990548], 
             UndirectedEdge[20, 116] -> 
             RGBColor[
              0.563025528622081, 0.6327398944929409, 0.9539451791088993], 
             UndirectedEdge[33, 156] -> 
             RGBColor[
              0.8886173200000307, 0.9126017212614459, 0.928191346376743], 
             UndirectedEdge[9, 202] -> 
             RGBColor[
              0.9683144846403954, 0.9743451187303153, 0.8693555828447661], 
             UndirectedEdge[76, 233] -> 
             RGBColor[
              0.9744549587667004, 0.9780549135337702, 0.8002493915729438], 
             UndirectedEdge[115, 369] -> 
             RGBColor[
              0.9801234861170542, 0.981943094665623, 0.763724330479721], 
             UndirectedEdge[183, 335] -> 
             RGBColor[
              0.9489600278155987, 0.9610833617125722, 0.9583947744992618], 
             UndirectedEdge[39, 296] -> 
             RGBColor[
              0.6934158430519732, 0.7585387534161809, 0.9717027774891089], 
             UndirectedEdge[10, 219] -> 
             RGBColor[
              0.7340973963713393, 0.7898568536925996, 0.9321950975739275], 
             UndirectedEdge[71, 143] -> 
             RGBColor[
              0.9571453770544778, 0.9662159544432272, 0.9003410219435712], 
             UndirectedEdge[232, 384] -> 
             RGBColor[
              0.7182199529469318, 0.77309554316476, 0.7250704733854196], 
             UndirectedEdge[1, 57] -> 
             RGBColor[
              0.9734006028724254, 0.9566480554667647, 0.6529326377168785], 
             UndirectedEdge[288, 393] -> 
             RGBColor[
              0.9406598370767232, 0.9512312686190241, 0.7846198354837104], 
             UndirectedEdge[328, 372] -> 
             RGBColor[
              0.9286243851886464, 0.9198715160190323, 0.675555364555178], 
             UndirectedEdge[16, 115] -> 
             RGBColor[
              0.6016432342968072, 0.6704067881368394, 0.9393919962111323], 
             UndirectedEdge[34, 244] -> 
             RGBColor[
              0.971610984988579, 0.9761199040516544, 0.819823508129585], 
             UndirectedEdge[233, 366] -> 
             RGBColor[
              0.9663316740681867, 0.9719965811062765, 0.8139999936755609], 
             UndirectedEdge[100, 105] -> 
             RGBColor[
              0.9594364277644285, 0.9563605320756672, 0.6960306107323224], 
             UndirectedEdge[88, 282] -> 
             RGBColor[
              0.7989504015355535, 0.8393290935397869, 0.7657268751173845], 
             UndirectedEdge[189, 219] -> 
             RGBColor[
              0.9856090559658899, 0.9882958334657648, 0.8872113247525693], 
             UndirectedEdge[44, 328] -> 
             RGBColor[
              0.9816047565748874, 0.9603533550006522, 0.6149867786749867], 
             UndirectedEdge[153, 154] -> 
             RGBColor[
              0.8507340620313371, 0.8841872700805603, 0.9855265149668822], 
             UndirectedEdge[73, 258] -> 
             RGBColor[
              0.8288017253339561, 0.864234625252996, 0.8479239236692202], 
             UndirectedEdge[22, 141] -> 
             RGBColor[
              0.8877520807623402, 0.7115050662031284, 0.6013461062941838], 
             UndirectedEdge[100, 273] -> 
             RGBColor[
              0.9463115906465231, 0.959417258650213, 0.9735944762837795], 
             UndirectedEdge[230, 391] -> 
             RGBColor[
              0.9741504001413701, 0.9802419912670446, 0.9286408092919698], 
             UndirectedEdge[338, 384] -> 
             RGBColor[
              0.6087792968964152, 0.6909786060970866, 0.963802077565096], 
             UndirectedEdge[76, 207] -> 
             RGBColor[
              0.8977348279076874, 0.9208098947370372, 0.9733445233556115], 
             UndirectedEdge[144, 370] -> 
             RGBColor[
              0.807405506651182, 0.7935951254792675, 0.6239939785371775], 
             UndirectedEdge[6, 340] -> 
             RGBColor[
              0.9165657195586363, 0.9325111971975515, 0.8221986602939635], 
             UndirectedEdge[30, 370] -> 
             RGBColor[
              0.7703973833540358, 0.8210366635546256, 0.9776230603755792], 
             UndirectedEdge[164, 245] -> 
             RGBColor[
              0.9291524053555104, 0.9442312549383288, 0.9122672250748671], 
             UndirectedEdge[56, 108] -> 
             RGBColor[
              0.9095320493201647, 0.926046271967319, 0.7520997506739892], 
             UndirectedEdge[50, 322] -> 
             RGBColor[
              0.949513490073116, 0.8788382456755315, 0.6080995934174802], 
             UndirectedEdge[379, 399] -> 
             RGBColor[
              0.971889592922081, 0.9299898645185196, 0.593889469608498], 
             UndirectedEdge[6, 13] -> 
             RGBColor[
              0.6694716519048187, 0.7396914928848783, 0.9691367527987247], 
             UndirectedEdge[55, 60] -> 
             RGBColor[
              0.9846611366500985, 0.9873945333442845, 0.8801128082361087], 
             UndirectedEdge[44, 47] -> 
             RGBColor[
              0.9907528856568144, 0.9898920015210435, 0.7627807905497879], 
             UndirectedEdge[156, 264] -> 
             RGBColor[
              0.9649141563858831, 0.9730021854647893, 0.9285375924738641], 
             UndirectedEdge[32, 43] -> 
             RGBColor[
              0.8737152088209914, 0.8976754866591183, 0.7209625811857738], 
             UndirectedEdge[144, 207] -> 
             RGBColor[
              0.8970248136495635, 0.8637764425532282, 0.6328812719050165], 
             UndirectedEdge[14, 213] -> 
             RGBColor[
              0.7801983196712028, 0.8259370100024424, 0.879592079717305], 
             UndirectedEdge[127, 139] -> 
             RGBColor[
              0.7031618885198155, 0.7611437249489221, 0.817333346998714], 
             UndirectedEdge[321, 342] -> 
             RGBColor[
              0.9716913326232108, 0.9784080227383549, 0.9328033691726869], 
             UndirectedEdge[82, 182] -> 
             RGBColor[
              0.765827551585726, 0.8141668599862688, 0.8741418677785351], 
             UndirectedEdge[50, 172] -> 
             RGBColor[
              0.9370906898990174, 0.9519840980273164, 0.9699182840864597], 
             UndirectedEdge[80, 96] -> 
             RGBColor[
              0.8052202219706567, 0.8481084448236104, 0.981128926767934], 
             UndirectedEdge[78, 160] -> 
             RGBColor[
              0.7800600693927875, 0.8278566271898522, 0.954191584917554], 
             UndirectedEdge[32, 293] -> 
             RGBColor[
              0.9908838287140618, 0.9884208725044867, 0.6497391645540473], 
             UndirectedEdge[322, 328] -> 
             RGBColor[
              0.9564465802536571, 0.8590047231478218, 0.3152054819180958], 
             UndirectedEdge[120, 254] -> 
             RGBColor[
              0.9635449733987901, 0.971567650371643, 0.9123423358055727], 
             UndirectedEdge[291, 321] -> 
             RGBColor[
              0.9703299670338905, 0.9773927185108715, 0.9351078060143949], 
             UndirectedEdge[65, 312] -> 
             RGBColor[
              0.9044640033764271, 0.9243862416668729, 0.9027896503894504], 
             UndirectedEdge[209, 334] -> 
             RGBColor[
              0.8824244648268851, 0.9090853317516919, 0.9886476272764493], 
             UndirectedEdge[295, 310] -> 
             RGBColor[
              0.9398654390045684, 0.9537336708335047, 0.9541326322499327], 
             UndirectedEdge[109, 205] -> 
             RGBColor[
              0.9029750886865415, 0.9244278335951985, 0.9544113586539129], 
             UndirectedEdge[194, 376] -> 
             RGBColor[
              0.9945708865256654, 0.9907960001829994, 0.6504526868023355], 
             UndirectedEdge[142, 338] -> 
             RGBColor[
              0.8341314049497248, 0.870946894238146, 0.9839434343571982], 
             UndirectedEdge[232, 386] -> 
             RGBColor[
              0.9567202638288428, 0.963547851342888, 0.7464659175008531], 
             UndirectedEdge[169, 378] -> 
             RGBColor[
              0.9899282816964011, 0.9889420950099709, 0.7321851681602244], 
             UndirectedEdge[94, 324] -> 
             RGBColor[
              0.6628141215588381, 0.5838762536049713, 0.5918237335972499], 
             UndirectedEdge[196, 231] -> 
             RGBColor[
              0.6110145318597896, 0.6868556323542231, 0.9663804748436777], 
             UndirectedEdge[207, 366] -> 
             RGBColor[
              0.8896115432091736, 0.9147515623095436, 0.9870951254582284], 
             UndirectedEdge[156, 310] -> 
             RGBColor[
              0.9428032188979708, 0.9555732319354571, 0.9334219688881458], 
             UndirectedEdge[206, 369] -> 
             RGBColor[
              0.9940197303775342, 0.9896171329125811, 0.5904627414197172], 
             UndirectedEdge[119, 225] -> 
             RGBColor[
              0.9828237455856703, 0.9860642046031639, 0.8850140677445499], 
             UndirectedEdge[69, 100] -> 
             RGBColor[
              0.8225464529111353, 0.8622144697764891, 0.9827044127948518], 
             UndirectedEdge[64, 182] -> 
             RGBColor[
              0.6565644487684184, 0.7300675173583345, 0.9674737882907609], 
             UndirectedEdge[217, 268] -> 
             RGBColor[
              0.9895149365900847, 0.9894354446653002, 0.7873213992379655], 
             UndirectedEdge[235, 275] -> 
             RGBColor[
              0.8040191208601197, 0.8436211033710361, 0.7806323946627962], 
             UndirectedEdge[5, 99] -> 
             RGBColor[
              0.6145355015821103, 0.6968829304594542, 0.963524889845041], 
             UndirectedEdge[52, 267] -> 
             RGBColor[0.948230916494941, 0.8883526819109331, 0.6183945754756],
              UndirectedEdge[290, 346] -> 
             RGBColor[
              0.9270772958657336, 0.9435152932412344, 0.9521688776256916], 
             UndirectedEdge[19, 108] -> 
             RGBColor[
              0.9664756668537888, 0.8931870535885955, 0.3955994209595731], 
             UndirectedEdge[92, 327] -> 
             RGBColor[
              0.7060609980734234, 0.7634401529884277, 0.7991735239618702], 
             UndirectedEdge[151, 244] -> 
             RGBColor[
              0.9940478462997586, 0.991328897204534, 0.7135788463672001], 
             UndirectedEdge[114, 327] -> 
             RGBColor[
              0.706036101095787, 0.763386900870734, 0.7964636415924835], 
             UndirectedEdge[99, 174] -> 
             RGBColor[
              0.6856586247310421, 0.7527201422315714, 0.9705407252622092], 
             UndirectedEdge[180, 282] -> 
             RGBColor[
              0.7964485029265235, 0.8395497470081228, 0.8984334400500196], 
             UndirectedEdge[199, 277] -> 
             RGBColor[
              0.7079679651408187, 0.7705245566944336, 0.9726507100098497], 
             UndirectedEdge[237, 286] -> 
             RGBColor[
              0.8052625008176174, 0.8467514078322014, 0.9010528102449298], 
             UndirectedEdge[290, 313] -> 
             RGBColor[
              0.7535304909243381, 0.8057260050309196, 0.936205643487747], 
             UndirectedEdge[56, 237] -> 
             RGBColor[
              0.7238080047879349, 0.7838967451679848, 0.9733077825166574], 
             UndirectedEdge[203, 361] -> 
             RGBColor[
              0.8022578840067334, 0.8443259229887377, 0.9013931047329624], 
             UndirectedEdge[169, 315] -> 
             RGBColor[
              0.7770701356928329, 0.8243956336368807, 0.9210755101463585], 
             UndirectedEdge[23, 304] -> 
             RGBColor[
              0.6569440110861667, 0.7223324816004935, 0.8708126667405925], 
             UndirectedEdge[129, 270] -> 
             RGBColor[
              0.9433677468342352, 0.9530822180859868, 0.7598892175593532], 
             UndirectedEdge[85, 284] -> 
             RGBColor[
              0.969009985728054, 0.902507548752048, 0.4406724617749815], 
             UndirectedEdge[203, 369] -> 
             RGBColor[
              0.9912482441837697, 0.9895204517517668, 0.712673713230596], 
             UndirectedEdge[1, 222] -> 
             RGBColor[
              0.814698945364355, 0.8323226405598014, 0.6671682678491986], 
             UndirectedEdge[25, 205] -> 
             RGBColor[
              0.9122636458739448, 0.9291502496118653, 0.8274148588729708], 
             UndirectedEdge[301, 380] -> 
             RGBColor[
              0.9112483859096344, 0.929978244928425, 0.9115656062305653], 
             UndirectedEdge[169, 329] -> 
             RGBColor[
              0.6866452383760641, 0.7491939886211079, 0.9144516900983715], 
             UndirectedEdge[302, 340] -> 
             RGBColor[
              0.9866472895733218, 0.9872850986128517, 0.7904943901657135], 
             UndirectedEdge[205, 391] -> 
             RGBColor[
              0.9033286101239859, 0.9246914893044061, 0.9538129390734778], 
             UndirectedEdge[96, 203] -> 
             RGBColor[
              0.925596630733919, 0.9414280006216438, 0.9133186581461827], 
             UndirectedEdge[4, 195] -> 
             RGBColor[
              0.858746826345298, 0.8897194436414717, 0.9460821583805852], 
             UndirectedEdge[269, 298] -> 
             RGBColor[
              0.8638409767907229, 0.8918786422863785, 0.8637085664872214], 
             UndirectedEdge[168, 220] -> 
             RGBColor[
              0.7282073924188885, 0.7870236841043076, 0.9741659394052854], 
             UndirectedEdge[291, 338] -> 
             RGBColor[
              0.8693945075345089, 0.8983226682687967, 0.9615789394967804], 
             UndirectedEdge[10, 360] -> 
             RGBColor[
              0.7118014159372417, 0.7732285479911669, 0.9699363767258329], 
             UndirectedEdge[87, 348] -> 
             RGBColor[
              0.7373444456880861, 0.7888388409485195, 0.721883630528444], 
             UndirectedEdge[259, 274] -> 
             RGBColor[
              0.9311958778867397, 0.9468207981271157, 0.9533057217711056], 
             UndirectedEdge[293, 336] -> 
             RGBColor[
              0.9864656052219434, 0.988645530825979, 0.872814219774311], 
             UndirectedEdge[229, 245] -> 
             RGBColor[
              0.882627040697338, 0.9092468602520156, 0.9886669491438147], 
             UndirectedEdge[173, 197] -> 
             RGBColor[
              0.7033580680684253, 0.7681879355851418, 0.9710678170363597], 
             UndirectedEdge[19, 344] -> 
             RGBColor[
              0.8968195166628831, 0.8422990420357297, 0.6280889773822407], 
             UndirectedEdge[83, 125] -> 
             RGBColor[
              0.7033487623773425, 0.7669056484838155, 0.9721360966963601], 
             UndirectedEdge[240, 315] -> 
             RGBColor[
              0.7741035329466404, 0.8022498373458233, 0.6679529107819899], 
             UndirectedEdge[7, 154] -> 
             RGBColor[
              0.8639746303755049, 0.894276441532815, 0.9705462806552607], 
             UndirectedEdge[200, 225] -> 
             RGBColor[
              0.8559489480815552, 0.8875871506469197, 0.9485079488413017], 
             UndirectedEdge[13, 140] -> 
             RGBColor[
              0.6880950534386432, 0.7545412877491822, 0.9709130694623276], 
             UndirectedEdge[104, 366] -> 
             RGBColor[
              0.8164094308012502, 0.857395482424949, 0.9798441446197601], 
             UndirectedEdge[116, 172] -> 
             RGBColor[
              0.5453143940260397, 0.618912137289847, 0.9624705622509216], 
             UndirectedEdge[143, 267] -> 
             RGBColor[
              0.9719246526179564, 0.9775438697684166, 0.8859173751716953], 
             UndirectedEdge[51, 395] -> 
             RGBColor[
              0.9919089772997333, 0.9909221684307102, 0.7837527152463499], 
             UndirectedEdge[213, 224] -> 
             RGBColor[
              0.6977574879512727, 0.762745099186823, 0.971260055297462], 
             UndirectedEdge[130, 362] -> 
             RGBColor[
              0.8896724159469295, 0.9148646512344232, 0.9893389433246014], 
             UndirectedEdge[153, 278] -> 
             RGBColor[
              0.96115180561915, 0.9682372293413637, 0.8405804312052099], 
             UndirectedEdge[83, 303] -> 
             RGBColor[
              0.7559262935660649, 0.8075958396527502, 0.9343776609852937], 
             UndirectedEdge[94, 296] -> 
             RGBColor[
              0.44803006133138823`, 0.5621225964714206, 0.949868597260418], 
             UndirectedEdge[147, 328] -> 
             RGBColor[
              0.8485364264215371, 0.8568138083549925, 0.6677036092843613], 
             UndirectedEdge[78, 102] -> 
             RGBColor[
              0.6192009519955407, 0.7017342533718063, 0.9631649136303639], 
             UndirectedEdge[22, 45] -> 
             RGBColor[
              0.9489803382691939, 0.9596805143281175, 0.8984827339625928], 
             UndirectedEdge[199, 238] -> 
             RGBColor[
              0.725375484753584, 0.6930871522380135, 0.6094564338950013], 
             UndirectedEdge[21, 182] -> 
             RGBColor[
              0.6787614062197278, 0.3858639083497974, 0.5605819847142259], 
             UndirectedEdge[126, 212] -> 
             RGBColor[
              0.8604640520886321, 0.8899200524389816, 0.8941829204611524], 
             UndirectedEdge[273, 365] -> 
             RGBColor[
              0.9191546976661421, 0.9377630893418797, 0.9710042275880661], 
             UndirectedEdge[149, 367] -> 
             RGBColor[
              0.9780537870939797, 0.9376324120314656, 0.36924353636501134`], 
             UndirectedEdge[81, 89] -> 
             RGBColor[
              0.6401985601001208, 0.7052768110617318, 0.8497706583812609], 
             UndirectedEdge[57, 337] -> 
             RGBColor[
              0.966218336794151, 0.9743262714102503, 0.9420677235253605], 
             UndirectedEdge[255, 288] -> 
             RGBColor[
              0.8096013059790984, 0.8480408298396074, 0.7718806330256869], 
             UndirectedEdge[2, 283] -> 
             RGBColor[
              0.7169879338096027, 0.7494613206996427, 0.6539175293117211], 
             UndirectedEdge[94, 128] -> 
             RGBColor[
              0.6853695445275022, 0.6756263861914957, 0.6100926467216755], 
             UndirectedEdge[176, 393] -> 
             RGBColor[
              0.8561839307890053, 0.8881618421902082, 0.9861447817147151], 
             UndirectedEdge[65, 326] -> 
             RGBColor[
              0.9505772965508033, 0.961150880697569, 0.9071892642959953], 
             UndirectedEdge[97, 282] -> 
             RGBColor[
              0.7796632313168037, 0.8278007215235232, 0.9613019469308937], 
             UndirectedEdge[12, 149] -> 
             RGBColor[
              0.9827278505214606, 0.9526710277436803, 0.4493135673614121], 
             UndirectedEdge[78, 144] -> 
             RGBColor[
              0.7749166639788517, 0.7675167591410504, 0.621232908280148], 
             UndirectedEdge[201, 348] -> 
             RGBColor[
              0.7091456335094171, 0.7711636216776341, 0.9721722731922962], 
             UndirectedEdge[242, 381] -> 
             RGBColor[
              0.9757139517692794, 0.9297395980617912, 0.36015371796937573`], 
             UndirectedEdge[43, 367] -> 
             RGBColor[
              0.8694455277678796, 0.8835018039563495, 0.6849070760807171], 
             UndirectedEdge[111, 197] -> 
             RGBColor[
              0.7947010089555973, 0.8398735442706865, 0.9800850372976776], 
             UndirectedEdge[69, 216] -> 
             RGBColor[
              0.7937770563622994, 0.8392745338929132, 0.9799603620692803], 
             UndirectedEdge[197, 295] -> 
             RGBColor[
              0.854646267998288, 0.8865187321268544, 0.945808903197187], 
             UndirectedEdge[193, 275] -> 
             RGBColor[
              0.9946482899837202, 0.9910298125678237, 0.663838936415964], 
             UndirectedEdge[149, 238] -> 
             RGBColor[
              0.9515503025882557, 0.840944867102841, 0.30422326375279285`], 
             UndirectedEdge[79, 349] -> 
             RGBColor[
              0.7915105916751464, 0.837962001770614, 0.9796129103762945], 
             UndirectedEdge[16, 110] -> 
             RGBColor[
              0.5238560828634893, 0.6092448953884357, 0.9592877348178541], 
             UndirectedEdge[49, 372] -> 
             RGBColor[
              0.7118096535700846, 0.7737563650535301, 0.972823135394542], 
             UndirectedEdge[320, 343] -> 
             RGBColor[
              0.7607159322411585, 0.8131630218179553, 0.9770158219882252], 
             UndirectedEdge[221, 358] -> 
             RGBColor[
              0.9454101777284938, 0.9585981580681882, 0.9700297037669551], 
             UndirectedEdge[240, 245] -> 
             RGBColor[
              0.9248012586078216, 0.9215129141214948, 0.6820901029003075], 
             UndirectedEdge[85, 115] -> 
             RGBColor[
              0.9802254627821955, 0.9821612124409378, 0.7748238611533211], 
             UndirectedEdge[70, 280] -> 
             RGBColor[
              0.8918218981895387, 0.9117136477730561, 0.7142033600878337], 
             UndirectedEdge[151, 171] -> 
             RGBColor[
              0.8541385107615818, 0.8843686648524438, 0.8659003211021699], 
             UndirectedEdge[23, 163] -> 
             RGBColor[
              0.6468879923591379, 0.683699396902316, 0.6414840088994365], 
             UndirectedEdge[255, 360] -> 
             RGBColor[
              0.7823753122355046, 0.8305236163238937, 0.9754922123631324], 
             UndirectedEdge[165, 307] -> 
             RGBColor[
              0.7516159772740119, 0.7373909409064198, 0.61681779113994], 
             UndirectedEdge[81, 169] -> 
             RGBColor[
              0.6364840972033903, 0.7037407851965916, 0.9113289213019212], 
             UndirectedEdge[44, 316] -> 
             RGBColor[
              0.9663643212252113, 0.9739912731032505, 0.9219430586430907], 
             UndirectedEdge[195, 337] -> 
             RGBColor[
              0.9720316444512932, 0.9786618267425292, 0.9322273100152836], 
             UndirectedEdge[316, 390] -> 
             RGBColor[
              0.8996991856031622, 0.9225975745830266, 0.9812063794939374], 
             UndirectedEdge[39, 177] -> 
             RGBColor[
              0.9431571049329825, 0.9567287444822463, 0.9672881991199088], 
             UndirectedEdge[45, 190] -> 
             RGBColor[
              0.9833774102806594, 0.9860637980760539, 0.8655671519256463], 
             UndirectedEdge[287, 396] -> 
             RGBColor[
              0.9819027522705919, 0.9850890981195208, 0.8736654881855823], 
             UndirectedEdge[136, 343] -> 
             RGBColor[
              0.958319666919134, 0.9657659943299227, 0.8230467076325603], 
             UndirectedEdge[296, 360] -> 
             RGBColor[
              0.7030293414658162, 0.7661069827578122, 0.9692458068902747], 
             UndirectedEdge[167, 228] -> 
             RGBColor[
              0.7435629578952622, 0.7966308700366983, 0.8949385807333343], 
             UndirectedEdge[123, 279] -> 
             RGBColor[
              0.9706338432606825, 0.9119402318898231, 0.5212113656777875], 
             UndirectedEdge[33, 333] -> 
             RGBColor[
              0.8920748815758686, 0.9122547536558717, 0.7417390404573518], 
             UndirectedEdge[164, 209] -> 
             RGBColor[
              0.9101691706459429, 0.929094538867099, 0.910456587201735], 
             UndirectedEdge[22, 29] -> 
             RGBColor[
              0.9226961589606417, 0.9411374986812231, 0.9904297295102644], 
             UndirectedEdge[24, 366] -> 
             RGBColor[
              0.9649694110732967, 0.9721413889362529, 0.8880504167030339], 
             UndirectedEdge[178, 319] -> 
             RGBColor[
              0.9220570436377533, 0.9382891670131379, 0.8992391358115162], 
             UndirectedEdge[294, 368] -> 
             RGBColor[
              0.7014088492112329, 0.7666651909992912, 0.9708735371171606], 
             UndirectedEdge[13, 69] -> 
             RGBColor[
              0.6061455824160222, 0.6900712433959576, 0.9628646595076926], 
             UndirectedEdge[214, 295] -> 
             RGBColor[
              0.9549619408267462, 0.9657712116028839, 0.9555725500705383], 
             UndirectedEdge[80, 146] -> 
             RGBColor[
              0.8684322022948754, 0.8888792284729579, 0.693814736970955], 
             UndirectedEdge[56, 231] -> 
             RGBColor[
              0.56362369834769, 0.6490674681015816, 0.9618602948369972], 
             UndirectedEdge[134, 351] -> 
             RGBColor[
              0.9858153371376543, 0.987820746168677, 0.8586973088982475], 
             UndirectedEdge[143, 291] -> 
             RGBColor[
              0.9774581814158485, 0.9816707664855626, 0.8765505542923154], 
             UndirectedEdge[120, 320] -> 
             RGBColor[
              0.7940942931860671, 0.8376439737970857, 0.8984772065865467], 
             UndirectedEdge[132, 220] -> 
             RGBColor[
              0.9403853483846354, 0.9522390284059101, 0.8721267199856494], 
             UndirectedEdge[6, 247] -> 
             RGBColor[
              0.8990032361124094, 0.9216901781300469, 0.9689198087678739], 
             UndirectedEdge[166, 289] -> 
             RGBColor[
              0.5876731631115084, 0.6761385740450454, 0.9606829305993169], 
             UndirectedEdge[114, 392] -> 
             RGBColor[
              0.9940592450365886, 0.9897016507727538, 0.5947636682015899], 
             UndirectedEdge[305, 325] -> 
             RGBColor[
              0.6684874472602289, 0.7340081411656905, 0.929866041506676], 
             UndirectedEdge[44, 128] -> 
             RGBColor[
              0.9640643449923147, 0.8968389794857774, 0.5694819698943562], 
             UndirectedEdge[90, 242] -> 
             RGBColor[
              0.9423685390645999, 0.9360228255884719, 0.6845045449615519], 
             UndirectedEdge[1, 337] -> 
             RGBColor[
              0.9706626643500201, 0.9546061053997177, 0.6575672534665777], 
             UndirectedEdge[74, 224] -> 
             RGBColor[
              0.721533978144141, 0.7820479250440703, 0.9731318277015979], 
             UndirectedEdge[160, 370] -> 
             RGBColor[
              0.8125489120651177, 0.8539349935280693, 0.9569526551745835], 
             UndirectedEdge[30, 84] -> 
             RGBColor[
              0.7473618264804909, 0.8026329004935344, 0.9756061874051569], 
             UndirectedEdge[293, 299] -> 
             RGBColor[
              0.6252031834699632, 0.6909360286735811, 0.8859640459103943], 
             UndirectedEdge[186, 399] -> 
             RGBColor[
              0.9823065268404483, 0.9651286286375701, 0.634357290808447], 
             UndirectedEdge[163, 371] -> 
             RGBColor[
              0.9810400177229359, 0.9519529117995265, 0.5678965911093381], 
             UndirectedEdge[90, 138] -> 
             RGBColor[
              0.9445133522179037, 0.9572517097630164, 0.9472575622321754], 
             UndirectedEdge[71, 286] -> 
             RGBColor[
              0.95622088661399, 0.9658336538877648, 0.9156622210470211], 
             UndirectedEdge[60, 201] -> 
             RGBColor[
              0.9625177690362778, 0.9708800460343339, 0.9175957536910833], 
             UndirectedEdge[128, 380] -> 
             RGBColor[
              0.9649168406702953, 0.897191508356762, 0.5553539103221259], 
             UndirectedEdge[54, 128] -> 
             RGBColor[
              0.9605890523963412, 0.8946909852146269, 0.5952422850771862], 
             UndirectedEdge[25, 138] -> 
             RGBColor[
              0.9897141444866029, 0.9895655594314969, 0.7874899980204892], 
             UndirectedEdge[95, 129] -> 
             RGBColor[
              0.9412664746727077, 0.9514067207018982, 0.7596887963447589], 
             UndirectedEdge[132, 302] -> 
             RGBColor[
              0.9861355039224762, 0.987611720376026, 0.8381016978236878], 
             UndirectedEdge[15, 100] -> 
             RGBColor[
              0.9070873356803415, 0.9287508355144428, 0.9909999939152567], 
             UndirectedEdge[33, 63] -> 
             RGBColor[
              0.7841211817074292, 0.8312806937823296, 0.979117529429688], 
             UndirectedEdge[275, 338] -> 
             RGBColor[
              0.8842036050874245, 0.9066971051071815, 0.7883268359972342], 
             UndirectedEdge[252, 277] -> 
             RGBColor[
              0.939233817558632, 0.9531907519171336, 0.9527104865332598], 
             UndirectedEdge[146, 192] -> 
             RGBColor[
              0.9881368628843086, 0.9819209991379723, 0.6371370740180983], 
             UndirectedEdge[237, 254] -> 
             RGBColor[
              0.7801137173850636, 0.8287264660642102, 0.9763579069190951], 
             UndirectedEdge[37, 236] -> 
             RGBColor[
              0.9945203319064662, 0.9917009463253115, 0.718590158040259], 
             UndirectedEdge[265, 362] -> 
             RGBColor[
              0.9366146563478701, 0.9479640014644493, 0.7808496247949308], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.9935695153905322, 0.9909959100305108, 0.711679501327344], 
             UndirectedEdge[341, 379] -> 
             RGBColor[
              0.9758612016905236, 0.9298186405872619, 0.39624106092066935`], 
             UndirectedEdge[324, 380] -> 
             RGBColor[
              0.9423614177016311, 0.8054413757702374, 0.5370849971977003], 
             UndirectedEdge[63, 264] -> 
             RGBColor[
              0.8604180180932814, 0.8916811579856729, 0.979463775526809], 
             UndirectedEdge[153, 337] -> 
             RGBColor[
              0.9454330463441023, 0.958610258564778, 0.969819204383563], 
             UndirectedEdge[112, 155] -> 
             RGBColor[
              0.8586477997327465, 0.8663886707383011, 0.6711585610937969], 
             UndirectedEdge[10, 177] -> 
             RGBColor[
              0.7250993189020989, 0.7831461022490398, 0.9474264956548891], 
             UndirectedEdge[238, 367] -> 
             RGBColor[
              0.9578311286683068, 0.8621315682789477, 0.32862308703930976`], 
             UndirectedEdge[87, 228] -> 
             RGBColor[
              0.7457464923756281, 0.795660000957356, 0.7225450704213984], 
             UndirectedEdge[66, 352] -> 
             RGBColor[
              0.79298407436791, 0.8376125995777809, 0.9347571890269528], 
             UndirectedEdge[86, 386] -> 
             RGBColor[
              0.7442328050371677, 0.7997942524338109, 0.9757032748852488], 
             UndirectedEdge[52, 133] -> 
             RGBColor[
              0.9647485422935758, 0.90029741149495, 0.5736820875730387], 
             UndirectedEdge[105, 112] -> 
             RGBColor[
              0.862628991352492, 0.8798181648999485, 0.6866247387515556], 
             UndirectedEdge[4, 258] -> 
             RGBColor[
              0.6996466114334142, 0.765288517453756, 0.9706978937245161], 
             UndirectedEdge[141, 339] -> 
             RGBColor[
              0.8322910392872664, 0.6674720066051705, 0.5960057440664988], 
             UndirectedEdge[251, 282] -> 
             RGBColor[
              0.7939326786195554, 0.8384428519578399, 0.9371474947152405], 
             UndirectedEdge[94, 390] -> 
             RGBColor[
              0.6415038049558757, 0.7162295417672793, 0.9672393343558322], 
             UndirectedEdge[239, 337] -> 
             RGBColor[
              0.9680547399920549, 0.9756958579084127, 0.9389591719219718], 
             UndirectedEdge[80, 243] -> 
             RGBColor[
              0.8244059378967779, 0.8634066139207139, 0.9829588774802581], 
             UndirectedEdge[366, 382] -> 
             RGBColor[
              0.9501163106364666, 0.9623174066664972, 0.969324253729301], 
             UndirectedEdge[99, 306] -> 
             RGBColor[
              0.7443417140183346, 0.7985915737282882, 0.9442107953687192], 
             UndirectedEdge[214, 261] -> 
             RGBColor[
              0.9578997207201487, 0.9676107727048362, 0.9348618867087513], 
             UndirectedEdge[21, 60] -> 
             RGBColor[
              0.9028211168139817, 0.5617831856365122, 0.5036978837473678], 
             UndirectedEdge[60, 159] -> 
             RGBColor[
              0.9687814001472759, 0.9755514518611615, 0.9069930600367953], 
             UndirectedEdge[9, 300] -> 
             RGBColor[
              0.9913185889503289, 0.990678027675943, 0.7935369780720504], 
             UndirectedEdge[114, 369] -> 
             RGBColor[
              0.9942478024579853, 0.9901049560310413, 0.6152869798790879], 
             UndirectedEdge[112, 350] -> 
             RGBColor[
              0.4604079229007377, 0.5521424012179826, 0.9541569235610645], 
             UndirectedEdge[18, 357] -> 
             RGBColor[
              0.8891391621388316, 0.9126033299950862, 0.9098309507841942], 
             UndirectedEdge[71, 320] -> 
             RGBColor[
              0.7616214229687133, 0.8138850355452163, 0.9771021885021605], 
             UndirectedEdge[226, 255] -> 
             RGBColor[
              0.8051533458131466, 0.8473724189811908, 0.9307094557785014], 
             UndirectedEdge[208, 258] -> 
             RGBColor[
              0.8270891572643253, 0.8635264343452118, 0.8763056085670977], 
             UndirectedEdge[11, 358] -> 
             RGBColor[
              0.7621912126338212, 0.8143206406954544, 0.9771780930467396], 
             UndirectedEdge[274, 299] -> 
             RGBColor[
              0.6209722189716576, 0.6885617025041729, 0.9281061248299044], 
             UndirectedEdge[147, 372] -> 
             RGBColor[
              0.800815039503146, 0.8448144479545052, 0.9806507531672322], 
             UndirectedEdge[335, 337] -> 
             RGBColor[
              0.9423828203627511, 0.9561780911634272, 0.9695282711064929], 
             UndirectedEdge[36, 218] -> 
             RGBColor[
              0.8489843271368933, 0.8826968388953012, 0.985384897478375], 
             UndirectedEdge[262, 300] -> 
             RGBColor[
              0.963988390454652, 0.9718396666984972, 0.9089637844076739], 
             UndirectedEdge[109, 136] -> 
             RGBColor[
              0.9853924259753026, 0.9863090697404844, 0.7894325260874462], 
             UndirectedEdge[219, 241] -> 
             RGBColor[
              0.9893145299713076, 0.9892090771663229, 0.7808025387417434], 
             UndirectedEdge[37, 348] -> 
             RGBColor[
              0.7378433170902148, 0.7909189537949601, 0.8498227335235484], 
             UndirectedEdge[291, 384] -> 
             RGBColor[
              0.7038602924285535, 0.7656824066981962, 0.9472410244905043], 
             UndirectedEdge[10, 241] -> 
             RGBColor[
              0.7393472650924833, 0.7914298998900523, 0.8011390850274633], 
             UndirectedEdge[131, 314] -> 
             RGBColor[
              0.8374493080673091, 0.8733796851715605, 0.984316373462874], 
             UndirectedEdge[1, 41] -> 
             RGBColor[
              0.985206227562103, 0.964061192079579, 0.5706355241418708], 
             UndirectedEdge[78, 400] -> 
             RGBColor[
              0.5968045862777063, 0.6835518747372906, 0.9614017896804652], 
             UndirectedEdge[191, 357] -> 
             RGBColor[
              0.9849336991204735, 0.9691374669226691, 0.6110180092536417], 
             UndirectedEdge[215, 352] -> 
             RGBColor[
              0.7825574699135536, 0.8291478123685565, 0.9339363685303953], 
             UndirectedEdge[96, 369] -> 
             RGBColor[
              0.9283222793362398, 0.9414266398092516, 0.7861185473834937], 
             UndirectedEdge[212, 293] -> 
             RGBColor[
              0.8598857223367014, 0.8896808982241615, 0.9037673411200655], 
             UndirectedEdge[66, 107] -> 
             RGBColor[
              0.7954443815678764, 0.8386299998319781, 0.8939835316525753], 
             UndirectedEdge[146, 159] -> 
             RGBColor[
              0.9691670966007075, 0.968269644213561, 0.6914717326419888], 
             UndirectedEdge[11, 207] -> 
             RGBColor[
              0.7189127359484182, 0.7798115581494683, 0.9730501533053337], 
             UndirectedEdge[99, 218] -> 
             RGBColor[
              0.7146885101287768, 0.7758677848524778, 0.9733096216467299], 
             UndirectedEdge[131, 217] -> 
             RGBColor[
              0.9344806964429266, 0.9468284056726433, 0.8265251169027281], 
             UndirectedEdge[81, 163] -> 
             RGBColor[
              0.6289374387169713, 0.6661453854455227, 0.6404136702577261], 
             UndirectedEdge[50, 54] -> 
             RGBColor[
              0.9711963737983729, 0.9780388832572113, 0.9336412053572013], 
             UndirectedEdge[120, 286] -> 
             RGBColor[
              0.9886937568313439, 0.9895925921396342, 0.8370372391314074], 
             UndirectedEdge[17, 253] -> 
             RGBColor[
              0.6552009305996167, 0.72161167302418, 0.8997000213504245], 
             UndirectedEdge[45, 365] -> 
             RGBColor[
              0.9347641383449252, 0.9483449023969727, 0.8971267801228646], 
             UndirectedEdge[35, 188] -> 
             RGBColor[
              0.9448924920426647, 0.954754895544459, 0.7970713915331464], 
             UndirectedEdge[99, 279] -> 
             RGBColor[
              0.7551509219823098, 0.8051851255081726, 0.8601763709728036], 
             UndirectedEdge[107, 363] -> 
             RGBColor[
              0.9026860412672937, 0.923033284912468, 0.9042448669795157], 
             UndirectedEdge[105, 271] -> 
             RGBColor[
              0.9895028643767154, 0.977316086696944, 0.5787655041634943], 
             UndirectedEdge[191, 219] -> 
             RGBColor[
              0.982707999333361, 0.9681959272700147, 0.6469562239831552], 
             UndirectedEdge[177, 339] -> 
             RGBColor[
              0.8812683551698691, 0.9075704047708992, 0.9613347563376275], 
             UndirectedEdge[80, 167] -> 
             RGBColor[
              0.8682563189480614, 0.8962477992320956, 0.9058589182101929], 
             UndirectedEdge[48, 56] -> 
             RGBColor[
              0.8735944541083451, 0.902044520888984, 0.9878054129714713], 
             UndirectedEdge[42, 136] -> 
             RGBColor[
              0.9301742488738887, 0.9433236019676647, 0.8203621725336936], 
             UndirectedEdge[77, 102] -> 
             RGBColor[
              0.8085328126678928, 0.8505707582574255, 0.9456689866360763], 
             UndirectedEdge[73, 203] -> 
             RGBColor[
              0.991871792721144, 0.9909067916518635, 0.7843689599441783], 
             UndirectedEdge[35, 284] -> 
             RGBColor[
              0.9197404244459975, 0.86734089699095, 0.6317901374025194], 
             UndirectedEdge[274, 367] -> 
             RGBColor[
              0.9823831831626443, 0.9718728636323097, 0.6558257383685007], 
             UndirectedEdge[33, 310] -> 
             RGBColor[
              0.845113225959939, 0.8795692169359511, 0.9850265249029897], 
             UndirectedEdge[175, 295] -> 
             RGBColor[
              0.9862745166777628, 0.9879674605459614, 0.8491543570665241], 
             UndirectedEdge[70, 75] -> 
             RGBColor[
              0.8928626513284319, 0.9139397135008651, 0.8274829164725053], 
             UndirectedEdge[57, 258] -> 
             RGBColor[
              0.8156693680618147, 0.8562728506218606, 0.9522084296095152], 
             UndirectedEdge[70, 145] -> 
             RGBColor[
              0.7677249463063599, 0.8184718300710098, 0.9774833059164408], 
             UndirectedEdge[12, 336] -> 
             RGBColor[
              0.9888601341625052, 0.9882560699440479, 0.7328439509732494], 
             UndirectedEdge[18, 216] -> 
             RGBColor[
              0.8327475717230153, 0.8697185966795911, 0.9838445788402648], 
             UndirectedEdge[158, 311] -> 
             RGBColor[
              0.9408827499995347, 0.9554310322620414, 0.9849542633893179], 
             UndirectedEdge[8, 36] -> 
             RGBColor[
              0.8881398741058146, 0.9114737573363134, 0.8939097800003698], 
             UndirectedEdge[119, 200] -> 
             RGBColor[
              0.8612077030715526, 0.8908627680130986, 0.9106612182651956], 
             UndirectedEdge[181, 362] -> 
             RGBColor[
              0.9126992608112896, 0.9329591815738134, 0.9822972510183703], 
             UndirectedEdge[9, 306] -> 
             RGBColor[
              0.9824488226208968, 0.9848864848533189, 0.8454298354695275], 
             UndirectedEdge[82, 253] -> 
             RGBColor[
              0.9894521075528644, 0.9899061896517076, 0.8244694051270551], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.9794346399529846, 0.9824988065956051, 0.8442757511664777], 
             UndirectedEdge[146, 314] -> 
             RGBColor[
              0.8948690298369414, 0.9095318790761507, 0.6964497128741485], 
             UndirectedEdge[27, 277] -> 
             RGBColor[
              0.939233817558632, 0.9531907519171336, 0.9527104865332598], 
             UndirectedEdge[6, 302] -> 
             RGBColor[
              0.9085549417241214, 0.9288138245357793, 0.952751262651053], 
             UndirectedEdge[93, 296] -> 
             RGBColor[
              0.7114122104475973, 0.7723589127187364, 0.9550557963065104], 
             UndirectedEdge[153, 284] -> 
             RGBColor[
              0.9356139098780968, 0.8799979834002223, 0.6333041646134608], 
             UndirectedEdge[43, 199] -> 
             RGBColor[
              0.6369898838531569, 0.7144573879154155, 0.9657404229364086], 
             UndirectedEdge[213, 250] -> 
             RGBColor[
              0.7777876815196789, 0.8249401491762125, 0.9195425924196124], 
             UndirectedEdge[3, 232] -> 
             RGBColor[
              0.9372708389538982, 0.9480394078881812, 0.7446108139935743], 
             UndirectedEdge[5, 235] -> 
             RGBColor[
              0.6628707225410151, 0.7361236403107827, 0.9673300154966744], 
             UndirectedEdge[25, 391] -> 
             RGBColor[
              0.9858265096259813, 0.9867450398777111, 0.797602806245224], 
             UndirectedEdge[288, 341] -> 
             RGBColor[
              0.9935522170028693, 0.988617169077026, 0.539576795745558], 
             UndirectedEdge[181, 265] -> 
             RGBColor[
              0.969947050014502, 0.9742758966821008, 0.7747908849333323], 
             UndirectedEdge[295, 363] -> 
             RGBColor[
              0.8982278484109596, 0.9205649939775126, 0.9501527078396976], 
             UndirectedEdge[278, 284] -> 
             RGBColor[
              0.9693800210807881, 0.9032990169552331, 0.4809485263266044], 
             UndirectedEdge[167, 351] -> 
             RGBColor[
              0.9898409725940156, 0.9900669953395993, 0.8180249050447133], 
             UndirectedEdge[198, 311] -> 
             RGBColor[
              0.9647736497860318, 0.9720757396333103, 0.8919799883564161], 
             UndirectedEdge[54, 328] -> 
             RGBColor[
              0.978129463978914, 0.9582053607295017, 0.6407470938578168], 
             UndirectedEdge[261, 310] -> 
             RGBColor[
              0.9428032188979708, 0.9555732319354571, 0.9334219688881458], 
             UndirectedEdge[68, 319] -> 
             RGBColor[
              0.8559402417374369, 0.886363744213996, 0.8927220680270742], 
             UndirectedEdge[100, 141] -> 
             RGBColor[
              0.9006927738184526, 0.7218236235803168, 0.602580401150169], 
             UndirectedEdge[139, 325] -> 
             RGBColor[
              0.696554081519474, 0.7583180490909935, 0.931654422623325], 
             UndirectedEdge[123, 338] -> 
             RGBColor[
              0.8612767280945337, 0.8280572624618638, 0.6276754202902846], 
             UndirectedEdge[317, 370] -> 
             RGBColor[
              0.8275065524586258, 0.8618191846181245, 0.7357600463381464], 
             UndirectedEdge[160, 400] -> 
             RGBColor[
              0.7800600693927875, 0.8278566271898522, 0.954191584917554], 
             UndirectedEdge[150, 266] -> 
             RGBColor[
              0.9458951854044106, 0.9585756686255094, 0.9558880014635033], 
             UndirectedEdge[134, 201] -> 
             RGBColor[
              0.9587019466865343, 0.9687205599749489, 0.954791011389049], 
             UndirectedEdge[161, 251] -> 
             RGBColor[
              0.9890603662585047, 0.9896776575135816, 0.8279819073227288], 
             UndirectedEdge[86, 371] -> 
             RGBColor[
              0.7797364470365751, 0.8254982218985941, 0.8768878309879853], 
             UndirectedEdge[105, 350] -> 
             RGBColor[
              0.5833801139866748, 0.6354157850590278, 0.6660959268816893], 
             UndirectedEdge[54, 362] -> 
             RGBColor[
              0.9296400114977239, 0.9455935656978227, 0.9536209789616475], 
             UndirectedEdge[4, 208] -> 
             RGBColor[
              0.8643533078906664, 0.8926374720325438, 0.8800197508482448], 
             UndirectedEdge[176, 294] -> 
             RGBColor[
              0.7587606832138856, 0.8115092028339908, 0.9765791314039589], 
             UndirectedEdge[113, 170] -> 
             RGBColor[
              0.9607666814486404, 0.9702604357798348, 0.951295954005875], 
             UndirectedEdge[14, 205] -> 
             RGBColor[
              0.9103491460447424, 0.9288075439584424, 0.8917798525942626], 
             UndirectedEdge[262, 306] -> 
             RGBColor[
              0.95511862412522, 0.9660481238758729, 0.9608566418051511], 
             UndirectedEdge[47, 128] -> 
             RGBColor[
              0.9679534896063919, 0.8978951474250361, 0.4648974237664778], 
             UndirectedEdge[257, 382] -> 
             RGBColor[
              0.9702705679524404, 0.9773484187731829, 0.9352083531655285], 
             UndirectedEdge[165, 228] -> 
             RGBColor[
              0.7221505848520576, 0.7134696079374757, 0.6144981675131949], 
             UndirectedEdge[72, 341] -> 
             RGBColor[
              0.9681165668278009, 0.899876589971436, 0.38603663167212], 
             UndirectedEdge[50, 116] -> 
             RGBColor[
              0.5707032958729777, 0.6384659607374695, 0.9409487218355381], 
             UndirectedEdge[230, 247] -> 
             RGBColor[
              0.9654712134610504, 0.9737690680517259, 0.9433324084473269], 
             UndirectedEdge[45, 100] -> 
             RGBColor[
              0.9619210313253063, 0.969999071705306, 0.8997170288185778], 
             UndirectedEdge[95, 386] -> 
             RGBColor[
              0.904656768790613, 0.9268127674525539, 0.9907681642755217], 
             UndirectedEdge[182, 244] -> 
             RGBColor[
              0.7674660104570703, 0.8143666563119292, 0.8122610897515294], 
             UndirectedEdge[104, 382] -> 
             RGBColor[
              0.8283235406384996, 0.8662810060340052, 0.9596766643628065], 
             UndirectedEdge[58, 210] -> 
             RGBColor[
              0.6522268419756176, 0.7211706862888758, 0.9470242675350126], 
             UndirectedEdge[102, 370] -> 
             RGBColor[
              0.651689794667871, 0.7278126197100234, 0.9659259838873935], 
             UndirectedEdge[1, 161] -> 
             RGBColor[
              0.9860870798013908, 0.9644254471173945, 0.5560375229643504], 
             UndirectedEdge[153, 356] -> 
             RGBColor[
              0.9459628725739704, 0.9590054020995029, 0.9689223467772083], 
             UndirectedEdge[1, 154] -> 
             RGBColor[
              0.875963680037255, 0.8801831169154999, 0.6732745640498969], 
             UndirectedEdge[341, 399] -> 
             RGBColor[
              0.9892081373681401, 0.9879917154878779, 0.696684049261817], 
             UndirectedEdge[373, 395] -> 
             RGBColor[
              0.7762209833411342, 0.8218575504460051, 0.8437256209433186], 
             UndirectedEdge[190, 266] -> 
             RGBColor[
              0.9776480432061463, 0.9828505277378898, 0.9227202119147148], 
             UndirectedEdge[73, 85] -> 
             RGBColor[
              0.9946994179886062, 0.991123548614786, 0.6682683798550895], 
             UndirectedEdge[221, 250] -> 
             RGBColor[
              0.9746768929407694, 0.9803157883543114, 0.9134703750064057], 
             UndirectedEdge[23, 353] -> 
             RGBColor[
              0.3501436863923319, 0.4776985952448205, 0.9435318239703827], 
             UndirectedEdge[171, 270] -> 
             RGBColor[
              0.804089957874165, 0.8474728000053131, 0.9809506398675458], 
             UndirectedEdge[277, 396] -> 
             RGBColor[
              0.9352503506742271, 0.9502198888370728, 0.9594534569140005], 
             UndirectedEdge[315, 371] -> 
             RGBColor[
              0.7797364470365751, 0.8254982218985941, 0.8768878309879853], 
             UndirectedEdge[207, 391] -> 
             RGBColor[
              0.9089561797475763, 0.929178760565949, 0.9543497016879665], 
             UndirectedEdge[160, 247] -> 
             RGBColor[
              0.9614243265116258, 0.9707509063910144, 0.9501827324555439], 
             UndirectedEdge[193, 232] -> 
             RGBColor[
              0.9941988529491828, 0.9900685121960027, 0.6149204888104255], 
             UndirectedEdge[22, 91] -> 
             RGBColor[
              0.7629871022198773, 0.8151128587979943, 0.9770726140460355], 
             UndirectedEdge[78, 247] -> 
             RGBColor[
              0.7781688433965446, 0.8264461539384527, 0.957392937218455], 
             UndirectedEdge[87, 192] -> 
             RGBColor[
              0.9901445140178605, 0.9883187008177677, 0.6767877449454004], 
             UndirectedEdge[226, 294] -> 
             RGBColor[
              0.8387886293356517, 0.8739102184043899, 0.9338830079257687], 
             UndirectedEdge[177, 311] -> 
             RGBColor[
              0.9521814091653247, 0.9638575537680312, 0.9658285805839018], 
             UndirectedEdge[189, 200] -> 
             RGBColor[
              0.8607431781245267, 0.8906706750097568, 0.9183595987894392], 
             UndirectedEdge[67, 184] -> 
             RGBColor[
              0.8810493791256635, 0.9079406143164602, 0.9868432165504586], 
             UndirectedEdge[33, 256] -> 
             RGBColor[
              0.8220682248718121, 0.861193758608169, 0.9828284721266888], 
             UndirectedEdge[176, 226] -> 
             RGBColor[
              0.9050008214154864, 0.9256760093101996, 0.9404717199009465], 
             UndirectedEdge[145, 162] -> 
             RGBColor[
              0.8687524006762641, 0.8958559711414414, 0.8705683769021542], 
             UndirectedEdge[286, 343] -> 
             RGBColor[
              0.9553153958864353, 0.9651116401605038, 0.9155758545330859], 
             UndirectedEdge[13, 18] -> 
             RGBColor[
              0.6451160977767381, 0.7205153061826355, 0.966748876278677], 
             UndirectedEdge[86, 308] -> 
             RGBColor[
              0.7468941955645786, 0.7014782094159067, 0.6090601792231618], 
             UndirectedEdge[364, 377] -> 
             RGBColor[
              0.9047624027892021, 0.8669074108434056, 0.6329388262794668], 
             UndirectedEdge[90, 152] -> 
             RGBColor[
              0.9453243215648034, 0.957587066428921, 0.9338177014326541], 
             UndirectedEdge[1, 153] -> 
             RGBColor[
              0.9526153124223766, 0.9409320426212924, 0.6806841185750809], 
             UndirectedEdge[92, 114] -> 
             RGBColor[
              0.9945466091075162, 0.9907440732404017, 0.6478102396596555], 
             UndirectedEdge[132, 219] -> 
             RGBColor[
              0.9888495786781546, 0.9896358728849213, 0.8335074772063902], 
             UndirectedEdge[107, 215] -> 
             RGBColor[
              0.78501777711352, 0.8301652126227537, 0.8931627111560178], 
             UndirectedEdge[240, 319] -> 
             RGBColor[
              0.9850793278656522, 0.9671789030584395, 0.5946507967446524], 
             UndirectedEdge[58, 110] -> 
             RGBColor[
              0.5770881820394955, 0.6619840341625739, 0.9624368008741946], 
             UndirectedEdge[67, 85] -> 
             RGBColor[
              0.9658741845152405, 0.9714580526075043, 0.799116831846437], 
             UndirectedEdge[125, 344] -> 
             RGBColor[
              0.8662272611352585, 0.8961701211893707, 0.9871027235289276], 
             UndirectedEdge[198, 219] -> 
             RGBColor[
              0.9876588244016302, 0.9891434653905894, 0.8532413571416836], 
             UndirectedEdge[16, 325] -> 
             RGBColor[
              0.609353279457203, 0.6761569271934222, 0.9263409008564162], 
             UndirectedEdge[119, 390] -> 
             RGBColor[
              0.9208079851871533, 0.93769412925534, 0.9165296577739017], 
             UndirectedEdge[7, 153] -> 
             RGBColor[
              0.9406262627606266, 0.9550253672386075, 0.9779558351804448], 
             UndirectedEdge[23, 164] -> 
             RGBColor[
              0.6558191948470529, 0.7218673411791612, 0.8894537827538227], 
             UndirectedEdge[46, 373] -> 
             RGBColor[
              0.7463278345322653, 0.716543063126464, 0.6125899600102176], 
             UndirectedEdge[301, 316] -> 
             RGBColor[
              0.889896470414128, 0.914781155578906, 0.9802713877682201], 
             UndirectedEdge[22, 150] -> 
             RGBColor[
              0.9100345011879327, 0.9311008252915196, 0.9912810971923365], 
             UndirectedEdge[161, 327] -> 
             RGBColor[
              0.7059398596180906, 0.7640029926986586, 0.8457349020826517], 
             UndirectedEdge[123, 281] -> 
             RGBColor[
              0.8631051892034496, 0.8294856701769681, 0.6278576642056808], 
             UndirectedEdge[111, 160] -> 
             RGBColor[
              0.9119283937868725, 0.9318988089935626, 0.9667708827205486], 
             UndirectedEdge[277, 287] -> 
             RGBColor[
              0.9431650065334167, 0.9551880415456112, 0.9042033979283698], 
             UndirectedEdge[48, 120] -> 
             RGBColor[
              0.9551508280852972, 0.9649413127025404, 0.9138620594618092], 
             UndirectedEdge[6, 224] -> 
             RGBColor[
              0.8322621269935555, 0.8690872451837823, 0.9838630987134587], 
             UndirectedEdge[103, 313] -> 
             RGBColor[
              0.7574729587785128, 0.8078427767184078, 0.8926534171636202], 
             UndirectedEdge[8, 60] -> 
             RGBColor[
              0.9893686230967041, 0.9898716666836327, 0.8258529586164778], 
             UndirectedEdge[284, 392] -> 
             RGBColor[
              0.9687194516415162, 0.9018861257184456, 0.40904961942388324`], 
             UndirectedEdge[218, 279] -> 
             RGBColor[
              0.9525653304811352, 0.9620674658679111, 0.8783451340203041], 
             UndirectedEdge[135, 221] -> 
             RGBColor[
              0.978907011276102, 0.9814521174204267, 0.7988125665749692], 
             UndirectedEdge[95, 309] -> 
             RGBColor[
              0.6995099510240317, 0.7637118308888, 0.9719228595267029], 
             UndirectedEdge[80, 385] -> 
             RGBColor[
              0.8089401900378177, 0.8510746463845213, 0.9814837406430343], 
             UndirectedEdge[272, 398] -> 
             RGBColor[
              0.8290084779686296, 0.8661059777240576, 0.9254757432381697], 
             UndirectedEdge[33, 264] -> 
             RGBColor[
              0.8672241634478512, 0.8969981704652834, 0.9801421484887081], 
             UndirectedEdge[76, 366] -> 
             RGBColor[
              0.946325485497731, 0.9594902154849347, 0.9757411318836378], 
             UndirectedEdge[41, 258] -> 
             RGBColor[
              0.8274749927514923, 0.863685987234675, 0.8699113160345074], 
             UndirectedEdge[174, 232] -> 
             RGBColor[
              0.9236189859677683, 0.9371537908867187, 0.7433086880686042], 
             UndirectedEdge[61, 307] -> 
             RGBColor[
              0.5871654574019205, 0.6757263956781203, 0.9606429621460708], 
             UndirectedEdge[35, 392] -> 
             RGBColor[
              0.9446177507477789, 0.9541672516953039, 0.7671674970915473], 
             UndirectedEdge[212, 259] -> 
             RGBColor[
              0.8064188825738778, 0.8492007561248218, 0.981207024725208], 
             UndirectedEdge[73, 110] -> 
             RGBColor[
              0.9029598832211108, 0.922167541817316, 0.855315315800025], 
             UndirectedEdge[122, 228] -> 
             RGBColor[
              0.6943109762202148, 0.7594825950104704, 0.9715233305138391], 
             UndirectedEdge[41, 203] -> 
             RGBColor[
              0.9905450601386802, 0.9903581536335426, 0.8063563523094655], 
             UndirectedEdge[361, 385] -> 
             RGBColor[
              0.7430518872263647, 0.7991983126071333, 0.9751927527609605], 
             UndirectedEdge[9, 269] -> 
             RGBColor[
              0.8637119293687431, 0.8918252778610224, 0.8658472162334485], 
             UndirectedEdge[192, 228] -> 
             RGBColor[
              0.7427810775915582, 0.7963075424377095, 0.9078963608070721], 
             UndirectedEdge[47, 265] -> 
             RGBColor[
              0.994252237910987, 0.9901144430165194, 0.6157697515659011], 
             UndirectedEdge[338, 398] -> 
             RGBColor[
              0.8801169384339915, 0.9060322954782845, 0.9305697569416391], 
             UndirectedEdge[71, 79] -> 
             RGBColor[
              0.7872338016617286, 0.8345518055042869, 0.9792049863268792], 
             UndirectedEdge[77, 78] -> 
             RGBColor[
              0.7861364469500582, 0.8323883796229098, 0.9439058626861776], 
             UndirectedEdge[89, 164] -> 
             RGBColor[
              0.9910193717638395, 0.9905542936797987, 0.798495781201437], 
             UndirectedEdge[123, 235] -> 
             RGBColor[
              0.7810922438672289, 0.7649812607257185, 0.6199809789558466], 
             UndirectedEdge[72, 393] -> 
             RGBColor[
              0.9152241869016546, 0.8624906895134341, 0.6310796714102724], 
             UndirectedEdge[240, 371] -> 
             RGBColor[
              0.9856200734631622, 0.9674025152595378, 0.5856892427891646], 
             UndirectedEdge[196, 303] -> 
             RGBColor[
              0.9520026135315309, 0.9633313538583548, 0.9525107256406822], 
             UndirectedEdge[105, 170] -> 
             RGBColor[
              0.982100164568712, 0.9733257039532804, 0.6598369919305109], 
             UndirectedEdge[195, 208] -> 
             RGBColor[
              0.9861893721762091, 0.9879573605329273, 0.8516898732231669], 
             UndirectedEdge[100, 180] -> 
             RGBColor[
              0.961047412523443, 0.9696378078797565, 0.9141951532184377], 
             UndirectedEdge[39, 355] -> 
             RGBColor[
              0.8635617248137903, 0.894150627851992, 0.9868203709415899], 
             UndirectedEdge[244, 397] -> 
             RGBColor[
              0.9539654558191366, 0.9623797797363094, 0.8295797465998344], 
             UndirectedEdge[225, 355] -> 
             RGBColor[
              0.8922213683344857, 0.9159234410291133, 0.9521232447070744], 
             UndirectedEdge[335, 354] -> 
             RGBColor[
              0.9528423492517079, 0.9639443246957813, 0.9502795596580109], 
             UndirectedEdge[97, 100] -> 
             RGBColor[
              0.9442621409137233, 0.9578887823951568, 0.9770636600993119], 
             UndirectedEdge[2, 107] -> 
             RGBColor[
              0.9821613924237322, 0.958554470988096, 0.5917370449815325], 
             UndirectedEdge[128, 225] -> 
             RGBColor[
              0.9594149697687826, 0.8938153563133775, 0.5972297007158511], 
             UndirectedEdge[96, 228] -> 
             RGBColor[
              0.6805268609178574, 0.748491515628213, 0.9702085892910752], 
             UndirectedEdge[262, 307] -> 
             RGBColor[
              0.7480708813184782, 0.8026950266515472, 0.9733627425043268], 
             UndirectedEdge[86, 334] -> 
             RGBColor[
              0.7507099738752712, 0.8049589710472502, 0.9763210730312639], 
             UndirectedEdge[255, 399] -> 
             RGBColor[
              0.8052572263443691, 0.8474153762504592, 0.9289878865419461], 
             UndirectedEdge[138, 242] -> 
             RGBColor[
              0.982521930443962, 0.9666984345032787, 0.6410222527256377], 
             UndirectedEdge[27, 396] -> 
             RGBColor[
              0.9779715632958071, 0.9830918084910433, 0.9221725767904723], 
             UndirectedEdge[163, 209] -> 
             RGBColor[
              0.9012379681580279, 0.8909265945902537, 0.6624868133473487], 
             UndirectedEdge[63, 202] -> 
             RGBColor[
              0.8602278433992872, 0.8915393260102745, 0.9797856916782375], 
             UndirectedEdge[347, 372] -> 
             RGBColor[
              0.933411681567934, 0.9481589394537133, 0.9357510148749775], 
             UndirectedEdge[174, 275] -> 
             RGBColor[
              0.9240684230023057, 0.9381150912585396, 0.7922271356741427], 
             UndirectedEdge[209, 315] -> 
             RGBColor[
              0.6999343974716672, 0.7644719046893214, 0.971478053225996], 
             UndirectedEdge[177, 374] -> 
             RGBColor[
              0.9700134067756626, 0.9490159624500685, 0.6478273589737582], 
             UndirectedEdge[214, 215] -> 
             RGBColor[
              0.7550897719326746, 0.8085415192336349, 0.9766349850012648], 
             UndirectedEdge[160, 185] -> 
             RGBColor[
              0.9685020578076498, 0.9760294668028677, 0.9382019795393408], 
             UndirectedEdge[63, 268] -> 
             RGBColor[
              0.8808193498213688, 0.906874563728338, 0.9439500775104188], 
             UndirectedEdge[48, 196] -> 
             RGBColor[
              0.9209852876204447, 0.9398326851416254, 0.9923255929781518], 
             UndirectedEdge[34, 95] -> 
             RGBColor[
              0.9187807977647082, 0.9377449431007054, 0.9806760419729598], 
             UndirectedEdge[84, 333] -> 
             RGBColor[
              0.8044667969825076, 0.843406441170673, 0.7332861813883982], 
             UndirectedEdge[102, 224] -> 
             RGBColor[
              0.7338240999955251, 0.7920255996267038, 0.9740993511139385], 
             UndirectedEdge[105, 326] -> 
             RGBColor[
              0.9486059055549667, 0.9477245676525361, 0.6949975858554627], 
             UndirectedEdge[134, 236] -> 
             RGBColor[
              0.9878122905676103, 0.9883454533872911, 0.8037169692106247], 
             UndirectedEdge[92, 161] -> 
             RGBColor[
              0.99445036762982, 0.9913601650683262, 0.6970815001498236], 
             UndirectedEdge[77, 185] -> 
             RGBColor[
              0.9745784353649206, 0.9805612192359252, 0.9279162573079645], 
             UndirectedEdge[178, 329] -> 
             RGBColor[
              0.6206563514019726, 0.6981584562847488, 0.9659174298008665], 
             UndirectedEdge[185, 400] -> 
             RGBColor[
              0.7852465746925685, 0.831724714350306, 0.945412184302252], 
             UndirectedEdge[317, 333] -> 
             RGBColor[
              0.9932266346923115, 0.9879207814361639, 0.5041391705024426], 
             UndirectedEdge[106, 215] -> 
             RGBColor[
              0.6785620375738817, 0.7478723580851365, 0.9692422975236459], 
             UndirectedEdge[14, 340] -> 
             RGBColor[
              0.992795306562686, 0.9907504300764742, 0.7299382506479624], 
             UndirectedEdge[233, 358] -> 
             RGBColor[
              0.9610194931635461, 0.9678253429043651, 0.8157313248889405], 
             UndirectedEdge[74, 191] -> 
             RGBColor[
              0.7991842057135826, 0.8243585532061071, 0.672523443716842], 
             UndirectedEdge[53, 244] -> 
             RGBColor[
              0.9738772304459145, 0.9778100662030987, 0.8159873457017947], 
             UndirectedEdge[4, 16] -> 
             RGBColor[
              0.486962075602676, 0.5804230165114479, 0.9556104849681963], 
             UndirectedEdge[149, 274] -> 
             RGBColor[
              0.9761023570825932, 0.9506861624562031, 0.6314259150819838], 
             UndirectedEdge[326, 335] -> 
             RGBColor[
              0.9164479355626303, 0.9362147237738648, 0.9918928162883356], 
             UndirectedEdge[30, 77] -> 
             RGBColor[
              0.9272404013540576, 0.9437948021020276, 0.957366063124262], 
             UndirectedEdge[129, 229] -> 
             RGBColor[
              0.944551919435366, 0.9540264451746195, 0.7600021649991724], 
             UndirectedEdge[216, 219] -> 
             RGBColor[
              0.9298987706214599, 0.9456928373060296, 0.9499339646147646], 
             UndirectedEdge[138, 233] -> 
             RGBColor[
              0.9895639454672109, 0.9892442989164676, 0.771141761680564], 
             UndirectedEdge[28, 44] -> 
             RGBColor[
              0.89739864908874, 0.919359468014344, 0.9244281305753242], 
             UndirectedEdge[163, 227] -> 
             RGBColor[
              0.9777584288875806, 0.9505958904831208, 0.6222810105908481], 
             UndirectedEdge[15, 335] -> 
             RGBColor[
              0.9010941203620058, 0.923972008301098, 0.9904283556879874], 
             UndirectedEdge[257, 268] -> 
             RGBColor[
              0.9814171893605214, 0.9856396767123846, 0.9153604657058791], 
             UndirectedEdge[217, 279] -> 
             RGBColor[
              0.9938669761124799, 0.9912351248501248, 0.7151968416346302], 
             UndirectedEdge[93, 119] -> 
             RGBColor[
              0.972160469460599, 0.9781115507285979, 0.9030642127964668], 
             UndirectedEdge[67, 305] -> 
             RGBColor[
              0.6464261238328782, 0.717554842275674, 0.9672101075545079], 
             UndirectedEdge[153, 195] -> 
             RGBColor[
              0.9539842925236497, 0.964987763964104, 0.9553441751237868], 
             UndirectedEdge[50, 135] -> 
             RGBColor[
              0.978525548915554, 0.9811676234165172, 0.7994582828500593], 
             UndirectedEdge[68, 334] -> 
             RGBColor[
              0.8274545141736429, 0.8660481055637504, 0.9831937561148649], 
             UndirectedEdge[95, 308] -> 
             RGBColor[
              0.9073181593180238, 0.8284967244346497, 0.6241250686134348], 
             UndirectedEdge[17, 36] -> 
             RGBColor[
              0.5544073362358426, 0.6433937112981367, 0.9605452044189383], 
             UndirectedEdge[41, 361] -> 
             RGBColor[
              0.8042803485639649, 0.8451622640581211, 0.8678756330491428], 
             UndirectedEdge[117, 371] -> 
             RGBColor[
              0.9889742900557708, 0.9897085998373097, 0.8323880776059407], 
             UndirectedEdge[89, 304] -> 
             RGBColor[
              0.9921441880029533, 0.9910194341011311, 0.7798546651882068], 
             UndirectedEdge[267, 272] -> 
             RGBColor[
              0.8127525182712547, 0.8542694537974238, 0.9658517466726908], 
             UndirectedEdge[20, 158] -> 
             RGBColor[
              0.9452976226121323, 0.9587236370278263, 0.9774810356393809], 
             UndirectedEdge[30, 62] -> 
             RGBColor[
              0.7648151020326281, 0.8166757429594325, 0.9770666707428461], 
             UndirectedEdge[197, 310] -> 
             RGBColor[
              0.8140799538515986, 0.855325788903312, 0.9819334183616466], 
             UndirectedEdge[142, 268] -> 
             RGBColor[
              0.9391364805934785, 0.9530301834812808, 0.9496039373480365], 
             UndirectedEdge[78, 213] -> 
             RGBColor[
              0.5831343399512883, 0.6724537529319254, 0.9603256178138873], 
             UndirectedEdge[48, 71] -> 
             RGBColor[
              0.9226779578679434, 0.941182374450671, 0.9924870413774229], 
             UndirectedEdge[262, 269] -> 
             RGBColor[
              0.8363817308730662, 0.8729869168835764, 0.9812740225690719], 
             UndirectedEdge[27, 376] -> 
             RGBColor[
              0.9880096492834342, 0.987887533390857, 0.7553700176328304], 
             UndirectedEdge[245, 292] -> 
             RGBColor[
              0.9129584585167514, 0.9329010262236705, 0.9731400622574807], 
             UndirectedEdge[142, 217] -> 
             RGBColor[
              0.9443277538936853, 0.9546801819926242, 0.8274643380329534], 
             UndirectedEdge[142, 363] -> 
             RGBColor[
              0.8549866207838703, 0.8872391473532913, 0.9860220873684732], 
             UndirectedEdge[121, 130] -> 
             RGBColor[
              0.9464782724507772, 0.9572232464052464, 0.8781742618521107], 
             UndirectedEdge[217, 300] -> 
             RGBColor[
              0.9919275344779367, 0.9904331158928645, 0.7473384086330684], 
             UndirectedEdge[25, 109] -> 
             RGBColor[
              0.985472988188537, 0.9864813841685035, 0.7982012258256592], 
             UndirectedEdge[40, 146] -> 
             RGBColor[
              0.7546183112113789, 0.7980947431131773, 0.6837508712228915], 
             UndirectedEdge[18, 140] -> 
             RGBColor[
              0.8327412191151797, 0.8697135312825399, 0.9838439729228583], 
             UndirectedEdge[170, 239] -> 
             RGBColor[
              0.9756141142056795, 0.9813336268195947, 0.9261631231788627], 
             UndirectedEdge[152, 333] -> 
             RGBColor[
              0.9897555591904017, 0.988254916529718, 0.6902888634601676], 
             UndirectedEdge[14, 250] -> 
             RGBColor[
              0.9885219075660114, 0.9895215280520946, 0.839885226189608], 
             UndirectedEdge[55, 159] -> 
             RGBColor[
              0.9651193031694111, 0.9735066139324217, 0.9439281007781684], 
             UndirectedEdge[234, 331] -> 
             RGBColor[
              0.46230223110617596`, 0.5605490492569374, 0.9532491163968475], 
             UndirectedEdge[370, 389] -> 
             RGBColor[
              0.44902402068193964`, 0.5506846449500159, 0.9518451441530975], 
             UndirectedEdge[119, 316] -> 
             RGBColor[
              0.9669737009916766, 0.9742432672970294, 0.9118440588884795], 
             UndirectedEdge[89, 227] -> 
             RGBColor[
              0.9890195502707302, 0.9897273160993298, 0.8316379987143829], 
             UndirectedEdge[246, 254] -> 
             RGBColor[
              0.9554983820652903, 0.9663313467257808, 0.9602138106693456], 
             UndirectedEdge[197, 345] -> 
             RGBColor[
              0.8238042772396628, 0.7518399354825998, 0.6135452215059702], 
             UndirectedEdge[231, 234] -> 
             RGBColor[
              0.267030301354381, 0.3979961557953965, 0.9385183526749779], 
             UndirectedEdge[89, 209] -> 
             RGBColor[
              0.9124990895411775, 0.9300580202064628, 0.8718438014708835], 
             UndirectedEdge[233, 317] -> 
             RGBColor[
              0.9938459903160204, 0.989245520488818, 0.5715522079233177], 
             UndirectedEdge[48, 342] -> 
             RGBColor[
              0.9443521278186344, 0.95765249072049, 0.966392136884459], 
             UndirectedEdge[24, 104] -> 
             RGBColor[
              0.8431766410753296, 0.8761049883037608, 0.8784028273365394], 
             UndirectedEdge[118, 149] -> 
             RGBColor[
              0.9354066751952943, 0.7754467616892299, 0.2911564390194597], 
             UndirectedEdge[34, 53] -> 
             RGBColor[
              0.9507600069598082, 0.9627974743304895, 0.9682346437567726], 
             UndirectedEdge[29, 45] -> 
             RGBColor[
              0.9642862102516327, 0.9718256123533768, 0.8978835737923627], 
             UndirectedEdge[35, 208] -> 
             RGBColor[
              0.9437172886369188, 0.9552487059459039, 0.8877677403805051], 
             UndirectedEdge[69, 191] -> 
             RGBColor[
              0.8465862850742005, 0.8617776238568983, 0.6769826214376709], 
             UndirectedEdge[102, 166] -> 
             RGBColor[
              0.58916287485107, 0.6773479891459706, 0.960800206164449], 
             UndirectedEdge[185, 213] -> 
             RGBColor[
              0.7715763283661505, 0.8206265925449409, 0.9443360124356741], 
             UndirectedEdge[172, 364] -> 
             RGBColor[
              0.8850583491740331, 0.9111855196352219, 0.9888988495167765], 
             UndirectedEdge[36, 55] -> 
             RGBColor[
              0.883432387659209, 0.9089966239969653, 0.9481696296200006], 
             UndirectedEdge[192, 203] -> 
             RGBColor[
              0.9878508474076197, 0.9892440274311401, 0.8510064296621797], 
             UndirectedEdge[105, 394] -> 
             RGBColor[
              0.9851462613762827, 0.9755145193966748, 0.650965690407818], 
             UndirectedEdge[256, 261] -> 
             RGBColor[
              0.919758217809844, 0.9371977736076751, 0.9312239161118449], 
             UndirectedEdge[215, 295] -> 
             RGBColor[
              0.780559584257186, 0.8276969216877982, 0.9390705520161997], 
             UndirectedEdge[219, 357] -> 
             RGBColor[
              0.9862903610372762, 0.9885775706215247, 0.8759203365586941], 
             UndirectedEdge[204, 295] -> 
             RGBColor[
              0.7971881483495094, 0.8411967391262218, 0.9403796134939846], 
             UndirectedEdge[24, 138] -> 
             RGBColor[
              0.988201682472321, 0.989389106746444, 0.8451921847080371], 
             UndirectedEdge[135, 376] -> 
             RGBColor[
              0.9943178872359044, 0.9902548602843526, 0.6229152754424857], 
             UndirectedEdge[127, 305] -> 
             RGBColor[
              0.6750952542605706, 0.736833817023619, 0.815544965882065], 
             UndirectedEdge[54, 158] -> 
             RGBColor[
              0.9616921719154464, 0.9709506650546272, 0.9497293400521447], 
             UndirectedEdge[180, 350] -> 
             RGBColor[
              0.5849910987456894, 0.6486930608631171, 0.8842604693678044], 
             UndirectedEdge[46, 287] -> 
             RGBColor[
              0.9626169961535027, 0.8858562793889744, 0.5426541503712905], 
             UndirectedEdge[41, 153] -> 
             RGBColor[
              0.9599766095561851, 0.9680653452446395, 0.882887475058856], 
             UndirectedEdge[163, 315] -> 
             RGBColor[
              0.7695234772064141, 0.786800233885812, 0.6501602591021634], 
             UndirectedEdge[17, 64] -> 
             RGBColor[
              0.547937010961441, 0.6383390440174809, 0.9599003028642135], 
             UndirectedEdge[67, 127] -> 
             RGBColor[
              0.9662396533418004, 0.9722397534729492, 0.8388958582053235], 
             UndirectedEdge[83, 246] -> 
             RGBColor[
              0.7505071830147951, 0.8035542758765923, 0.9435508016182], 
             UndirectedEdge[44, 383] -> 
             RGBColor[
              0.9430814329503081, 0.9556882805958735, 0.9288112420460293], 
             UndirectedEdge[5, 275] -> 
             RGBColor[
              0.852945299853374, 0.8822778794864224, 0.7852113002569745], 
             UndirectedEdge[99, 123] -> 
             RGBColor[
              0.7327570229083241, 0.7257405508743898, 0.6161758533042132], 
             UndirectedEdge[278, 354] -> 
             RGBColor[
              0.9896586864357504, 0.9896775256521431, 0.7982148546482246], 
             UndirectedEdge[61, 215] -> 
             RGBColor[
              0.5988522446868605, 0.685214256079802, 0.9615629888512538], 
             UndirectedEdge[115, 208] -> 
             RGBColor[
              0.9790344665847976, 0.9826212436579354, 0.8638012620911807], 
             UndirectedEdge[167, 203] -> 
             RGBColor[
              0.9886327277113236, 0.9895673550301289, 0.8380486495884418], 
             UndirectedEdge[242, 256] -> 
             RGBColor[
              0.9167931199861418, 0.9156296806415662, 0.6820651386584025], 
             UndirectedEdge[136, 254] -> 
             RGBColor[
              0.966447366484219, 0.9721798753917221, 0.8215015701429818], 
             UndirectedEdge[65, 170] -> 
             RGBColor[
              0.9840715555645485, 0.9867520169983133, 0.8720286703710436], 
             UndirectedEdge[247, 340] -> 
             RGBColor[
              0.9770955839616098, 0.9801614522071194, 0.8066629362825344], 
             UndirectedEdge[8, 17] -> 
             RGBColor[
              0.656681474695473, 0.7222239160560642, 0.8751635741567885], 
             UndirectedEdge[269, 300] -> 
             RGBColor[
              0.861542199483996, 0.8909280387941649, 0.9018052555046526], 
             UndirectedEdge[233, 242] -> 
             RGBColor[
              0.9874191323139072, 0.9680154147419231, 0.5083887444099406], 
             UndirectedEdge[242, 382] -> 
             RGBColor[
              0.9712037688821871, 0.9583362403021438, 0.6637130044636808], 
             UndirectedEdge[144, 242] -> 
             RGBColor[
              0.9667029294853278, 0.8984755969367723, 0.32966663116742245`], 
             UndirectedEdge[81, 227] -> 
             RGBColor[
              0.635868819711777, 0.703486352141899, 0.9215256616250582], 
             UndirectedEdge[224, 230] -> 
             RGBColor[
              0.8987301043421965, 0.9211661351054614, 0.9582756983929117], 
             UndirectedEdge[81, 248] -> 
             RGBColor[
              0.6356651751470304, 0.7034021398809498, 0.9249005790781508], 
             UndirectedEdge[13, 323] -> 
             RGBColor[
              0.734215370302921, 0.7544647439791033, 0.6419260966332686], 
             UndirectedEdge[10, 189] -> 
             RGBColor[
              0.7356417910870655, 0.7905166561894942, 0.9075478710382892], 
             UndirectedEdge[135, 364] -> 
             RGBColor[
              0.9264932081905699, 0.9403690450244226, 0.8184388482803762], 
             UndirectedEdge[39, 383] -> 
             RGBColor[
              0.9097724142060806, 0.9308918442463523, 0.9912560991020396], 
             UndirectedEdge[108, 196] -> 
             RGBColor[
              0.9569228828322643, 0.9638344362199605, 0.7566199306806698], 
             UndirectedEdge[75, 89] -> 
             RGBColor[
              0.9940736331269695, 0.9913997478794765, 0.7175264630120046], 
             UndirectedEdge[131, 269] -> 
             RGBColor[
              0.8040953614489861, 0.8473233285739435, 0.9809919637743123], 
             UndirectedEdge[36, 165] -> 
             RGBColor[
              0.8658919247004868, 0.8279669629380199, 0.6273170295029196], 
             UndirectedEdge[40, 41] -> 
             RGBColor[
              0.7563547602919214, 0.8062541124757286, 0.8641027551831532], 
             UndirectedEdge[86, 249] -> 
             RGBColor[
              0.5603345258685453, 0.6539438367396353, 0.9585307329308228], 
             UndirectedEdge[287, 395] -> 
             RGBColor[
              0.9925101449623717, 0.9911707667085154, 0.7737898113043915], 
             UndirectedEdge[177, 225] -> 
             RGBColor[
              0.9718167484536779, 0.9785015576593677, 0.9325910728853934], 
             UndirectedEdge[74, 216] -> 
             RGBColor[
              0.7463749770016814, 0.801855463242122, 0.9755011843484516], 
             UndirectedEdge[229, 371] -> 
             RGBColor[
              0.9434458555526786, 0.9551364613900585, 0.8922660890326718], 
             UndirectedEdge[319, 371] -> 
             RGBColor[
              0.9907122419555869, 0.9904272876112102, 0.803585716950648], 
             UndirectedEdge[169, 353] -> 
             RGBColor[
              0.6816294004123877, 0.7448495218803177, 0.9141320853386573], 
             UndirectedEdge[47, 362] -> 
             RGBColor[
              0.9370044487077747, 0.948797727908232, 0.8232761176509391], 
             UndirectedEdge[83, 313] -> 
             RGBColor[
              0.5270544862047102, 0.6269256012918324, 0.9559108062996837], 
             UndirectedEdge[87, 210] -> 
             RGBColor[
              0.9770430126277785, 0.979043888242541, 0.7211889617931706], 
             UndirectedEdge[91, 150] -> 
             RGBColor[
              0.7656313164296071, 0.8172212834335502, 0.9773248215578774], 
             UndirectedEdge[16, 258] -> 
             RGBColor[
              0.44969792497633476`, 0.5513119788241158, 0.9518963426870494], 
             UndirectedEdge[334, 388] -> 
             RGBColor[
              0.6910839128102697, 0.7564337299982382, 0.9716597275948979], 
             UndirectedEdge[67, 325] -> 
             RGBColor[
              0.9596318463414588, 0.9694140776150206, 0.9532169338299346], 
             UndirectedEdge[279, 363] -> 
             RGBColor[
              0.9045258430026648, 0.923794090210792, 0.87375459097015], 
             UndirectedEdge[192, 385] -> 
             RGBColor[
              0.9286448506272509, 0.9441164170495357, 0.9248060776901778], 
             UndirectedEdge[216, 339] -> 
             RGBColor[
              0.8361005420104057, 0.8723379625516183, 0.984178771583223], 
             UndirectedEdge[74, 323] -> 
             RGBColor[
              0.7924889412581237, 0.8017738540749919, 0.6465136056019861], 
             UndirectedEdge[60, 87] -> 
             RGBColor[
              0.9907165812149468, 0.9885552653052193, 0.6673071110272312], 
             UndirectedEdge[74, 198] -> 
             RGBColor[
              0.8041350307818519, 0.8453060913266818, 0.8788085768753704], 
             UndirectedEdge[16, 348] -> 
             RGBColor[
              0.35929617585991924`, 0.47822650022071617`, 0.9445698702139456],
              UndirectedEdge[88, 283] -> 
             RGBColor[
              0.7264140854050927, 0.7804408443812758, 0.7600165506023135], 
             UndirectedEdge[292, 388] -> 
             RGBColor[
              0.7026346717905687, 0.7651127083989868, 0.9543415247027971], 
             UndirectedEdge[76, 382] -> 
             RGBColor[
              0.9582395953349805, 0.9683757390939909, 0.9555736516266842], 
             UndirectedEdge[131, 352] -> 
             RGBColor[
              0.9293413537297774, 0.9451998817936034, 0.9478040919982191], 
             UndirectedEdge[123, 232] -> 
             RGBColor[
              0.9707173841450503, 0.9101741995295372, 0.38894381611060824`], 
             UndirectedEdge[69, 357] -> 
             RGBColor[
              0.8501686467781158, 0.8821592672084083, 0.9059467340132097], 
             UndirectedEdge[241, 339] -> 
             RGBColor[
              0.8955163013602535, 0.9158542024119117, 0.8150473457102018], 
             UndirectedEdge[181, 322] -> 
             RGBColor[
              0.941289521439099, 0.8727048233337944, 0.6220206271603281], 
             UndirectedEdge[140, 168] -> 
             RGBColor[
              0.7224993794758683, 0.782472269523427, 0.9736215040351768], 
             UndirectedEdge[88, 357] -> 
             RGBColor[
              0.9911715049994536, 0.9893619518433396, 0.7047309095041605], 
             UndirectedEdge[125, 179] -> 
             RGBColor[
              0.6772729334376295, 0.7457361158478497, 0.9700833119233172], 
             UndirectedEdge[316, 324] -> 
             RGBColor[
              0.9210095022061247, 0.7902442864207185, 0.6057907787353551], 
             UndirectedEdge[128, 390] -> 
             RGBColor[
              0.8973992093702656, 0.8454452809655536, 0.6287452907452029], 
             UndirectedEdge[200, 339] -> 
             RGBColor[
              0.7654005547977465, 0.8166559977584511, 0.9772516322935358], 
             UndirectedEdge[85, 110] -> 
             RGBColor[
              0.9024383113488776, 0.9209993196925341, 0.7947195997600429], 
             UndirectedEdge[178, 209] -> 
             RGBColor[
              0.8427957396703554, 0.8774864620049635, 0.9848678040940388], 
             UndirectedEdge[380, 383] -> 
             RGBColor[
              0.9439339286282886, 0.9560408094668581, 0.914683182473799], 
             UndirectedEdge[350, 357] -> 
             RGBColor[
              0.5848375531796545, 0.6486295658256207, 0.8868051167601894], 
             UndirectedEdge[98, 352] -> 
             RGBColor[
              0.9457755263884278, 0.9583040449778781, 0.9493715980573603], 
             UndirectedEdge[68, 151] -> 
             RGBColor[
              0.8575382356208144, 0.8870245557513422, 0.866239173903903], 
             UndirectedEdge[307, 385] -> 
             RGBColor[
              0.7137122214069727, 0.7753790501580681, 0.9728830267929208], 
             UndirectedEdge[94, 119] -> 
             RGBColor[
              0.7087783203443899, 0.7678752344812821, 0.8978770137503744], 
             UndirectedEdge[116, 121] -> 
             RGBColor[
              0.5859527900761765, 0.648379238348904, 0.8497638139674937], 
             UndirectedEdge[1, 361] -> 
             RGBColor[
              0.7969190514301563, 0.818028961434774, 0.6656722765653678], 
             UndirectedEdge[180, 239] -> 
             RGBColor[
              0.9807261168344112, 0.9843767474113971, 0.8830544158066472], 
             UndirectedEdge[45, 394] -> 
             RGBColor[
              0.9876308649371605, 0.9891530590263136, 0.8546521084940735], 
             UndirectedEdge[32, 124] -> 
             RGBColor[
              0.9927327226876428, 0.9868643536003414, 0.4503798968658203], 
             UndirectedEdge[87, 243] -> 
             RGBColor[
              0.9470760132702809, 0.9558008431053749, 0.7409299241417278], 
             UndirectedEdge[188, 195] -> 
             RGBColor[
              0.9873645755819549, 0.9874635501314823, 0.7609935243758083], 
             UndirectedEdge[122, 262] -> 
             RGBColor[
              0.914533409167413, 0.934607446115776, 0.9889127631083505], 
             UndirectedEdge[118, 212] -> 
             RGBColor[
              0.814959075951097, 0.7120671712877802, 0.6056399439770516], 
             UndirectedEdge[35, 258] -> 
             RGBColor[
              0.7790105921796666, 0.8278997513671162, 0.9784458832567763], 
             UndirectedEdge[183, 271] -> 
             RGBColor[
              0.9850196797462214, 0.9868177435471939, 0.841701306157703], 
             UndirectedEdge[130, 147] -> 
             RGBColor[
              0.8103525227426189, 0.852419378201575, 0.9815604468328247], 
             UndirectedEdge[124, 330] -> 
             RGBColor[
              0.993601409370652, 0.9887223865776018, 0.5449310813985963], 
             UndirectedEdge[46, 395] -> 
             RGBColor[
              0.965309732986093, 0.8869697952694306, 0.49802853247573053`], 
             UndirectedEdge[206, 284] -> 
             RGBColor[
              0.9689538466543564, 0.9023874729499396, 0.4345620700531914], 
             UndirectedEdge[179, 313] -> 
             RGBColor[
              0.5009786572649972, 0.6057560686558665, 0.9538580215266408], 
             UndirectedEdge[215, 363] -> 
             RGBColor[
              0.6983556795168879, 0.7633353016082636, 0.9712151427704241], 
             UndirectedEdge[260, 338] -> 
             RGBColor[
              0.8840684832296126, 0.9076663608013429, 0.8650824334080799], 
             UndirectedEdge[88, 113] -> 
             RGBColor[
              0.9683805826864023, 0.9730829029033013, 0.7754806817010244], 
             UndirectedEdge[95, 270] -> 
             RGBColor[
              0.8911691061884712, 0.9160580714064543, 0.9894816989759508], 
             UndirectedEdge[16, 184] -> 
             RGBColor[
              0.5307708122414079, 0.6146834638948618, 0.9599671835769402], 
             UndirectedEdge[38, 78] -> 
             RGBColor[
              0.7910253557465886, 0.8358593913018351, 0.9277876034357504], 
             UndirectedEdge[8, 210] -> 
             RGBColor[
              0.9756950545095358, 0.9803602896209543, 0.8797348093824172], 
             UndirectedEdge[1, 96] -> 
             RGBColor[
              0.9202577981573418, 0.9151310390676801, 0.6775978299785881], 
             UndirectedEdge[213, 247] -> 
             RGBColor[
              0.7644985970701266, 0.8153480321330875, 0.9563167653518772], 
             UndirectedEdge[109, 366] -> 
             RGBColor[
              0.9571933159001755, 0.9675954256046388, 0.9573447297964279], 
             UndirectedEdge[223, 260] -> 
             RGBColor[
              0.6590392563057291, 0.7234945103002941, 0.8469535488581388], 
             UndirectedEdge[393, 399] -> 
             RGBColor[
              0.9363157574419939, 0.9506058150298758, 0.9417270889999696], 
             UndirectedEdge[25, 358] -> 
             RGBColor[
              0.9611696921829381, 0.9681466034193943, 0.8320795612288656], 
             UndirectedEdge[207, 358] -> 
             RGBColor[
              0.884299362304533, 0.9105803241076321, 0.9888264566716081], 
             UndirectedEdge[31, 33] -> 
             RGBColor[
              0.7444780598214011, 0.800311185666079, 0.9751662735261257], 
             UndirectedEdge[355, 375] -> 
             RGBColor[
              0.9002938751246023, 0.9203626170747645, 0.8676453650467548], 
             UndirectedEdge[25, 104] -> 
             RGBColor[
              0.8446891030896116, 0.8762814409888137, 0.8207006406489914], 
             UndirectedEdge[360, 375] -> 
             RGBColor[
              0.9665913522789373, 0.973023179447146, 0.8706230742960175], 
             UndirectedEdge[28, 347] -> 
             RGBColor[
              0.8969269610001778, 0.9191644128678925, 0.9322452228924443], 
             UndirectedEdge[56, 143] -> 
             RGBColor[
              0.9080618732948795, 0.9270781008815401, 0.8956593935376196], 
             UndirectedEdge[73, 115] -> 
             RGBColor[
              0.9807470346544286, 0.9833294345657196, 0.8354195771933032], 
             UndirectedEdge[157, 218] -> 
             RGBColor[
              0.9355590578901665, 0.9508521534359771, 0.9728695723764074], 
             UndirectedEdge[267, 321] -> 
             RGBColor[
              0.9647964382359984, 0.9732658217937253, 0.9444746268937749], 
             UndirectedEdge[93, 324] -> 
             RGBColor[
              0.9261962706750472, 0.7941125698522871, 0.5970109326433424], 
             UndirectedEdge[178, 245] -> 
             RGBColor[
              0.8617789743799227, 0.8926231780761933, 0.9866784419671711], 
             UndirectedEdge[223, 331] -> 
             RGBColor[
              0.5081817137644322, 0.6073373760649867, 0.9559143878382133], 
             UndirectedEdge[318, 367] -> 
             RGBColor[
              0.7246685188921682, 0.7676840277417742, 0.6723346001791546], 
             UndirectedEdge[158, 265] -> 
             RGBColor[
              0.9686668167655925, 0.9733211008212537, 0.776957985885428], 
             UndirectedEdge[124, 199] -> 
             RGBColor[
              0.7560073977198083, 0.8036462548566385, 0.695157738616455], 
             UndirectedEdge[38, 213] -> 
             RGBColor[
              0.7773551094201706, 0.8247612694964699, 0.9267114315691725], 
             UndirectedEdge[128, 296] -> 
             RGBColor[
              0.7039254657457782, 0.6913383356696949, 0.6113745536497885], 
             UndirectedEdge[89, 315] -> 
             RGBColor[
              0.7807845985895636, 0.8259316595020212, 0.8595172472256981], 
             UndirectedEdge[129, 178] -> 
             RGBColor[
              0.9237038531179507, 0.9374027629987973, 0.7580136578225289], 
             UndirectedEdge[61, 279] -> 
             RGBColor[
              0.8050224081726376, 0.8456730446823304, 0.8641024370509796], 
             UndirectedEdge[7, 332] -> 
             RGBColor[
              0.9660212194084622, 0.9515789401360952, 0.6663461936657278], 
             UndirectedEdge[105, 180] -> 
             RGBColor[
              0.9872121671974438, 0.9763688245450829, 0.6167282845582954], 
             UndirectedEdge[75, 163] -> 
             RGBColor[
              0.9828125117438199, 0.9522683222632673, 0.5081694748884699], 
             UndirectedEdge[15, 273] -> 
             RGBColor[
              0.9201272532364368, 0.938538578754315, 0.9710969908065715], 
             UndirectedEdge[149, 287] -> 
             RGBColor[
              0.980795184571855, 0.9532514808417092, 0.581629571139223], 
             UndirectedEdge[123, 275] -> 
             RGBColor[
              0.9711668211795876, 0.9111354999013581, 0.43786226371614667`], 
             UndirectedEdge[186, 226] -> 
             RGBColor[
              0.9822026463092257, 0.9650856713683017, 0.6360788600450024], 
             UndirectedEdge[15, 183] -> 
             RGBColor[
              0.9287689057238482, 0.9449835090300192, 0.9564689272493232], 
             UndirectedEdge[35, 41] -> 
             RGBColor[
              0.9441031241240858, 0.9554082588353672, 0.8813734478479147], 
             UndirectedEdge[47, 54] -> 
             RGBColor[
              0.9872775930608408, 0.9877440072498929, 0.7885411057326179], 
             UndirectedEdge[19, 196] -> 
             RGBColor[
              0.9300173378704331, 0.8687700835357791, 0.6312554152050616], 
             UndirectedEdge[211, 328] -> 
             RGBColor[
              0.9639192948175956, 0.947607439836007, 0.6648012036422388], 
             UndirectedEdge[3, 86] -> 
             RGBColor[0.724783380162223, 0.784285808979104, 0.97384817137797],
              UndirectedEdge[55, 58] -> 
             RGBColor[
              0.6622383135849212, 0.7286372254228142, 0.9300774575104462], 
             UndirectedEdge[63, 214] -> 
             RGBColor[
              0.8534035824275472, 0.8862897452257199, 0.9857880697616963], 
             UndirectedEdge[26, 106] -> 
             RGBColor[
              0.8856975896496342, 0.9087303596789749, 0.8557827584418918], 
             UndirectedEdge[89, 378] -> 
             RGBColor[
              0.9936427445931317, 0.9904781208751112, 0.670626905239564], 
             UndirectedEdge[191, 311] -> 
             RGBColor[
              0.9598228247177625, 0.9511282015127356, 0.6856948551978876], 
             UndirectedEdge[147, 364] -> 
             RGBColor[
              0.789570995516012, 0.8358487524906077, 0.9795782862140627], 
             UndirectedEdge[137, 285] -> 
             RGBColor[
              0.9502953596896759, 0.9624509411572149, 0.9690211703856899], 
             UndirectedEdge[104, 205] -> 
             RGBColor[
              0.7621912035876162, 0.8142278904155087, 0.9769107734772451], 
             UndirectedEdge[191, 339] -> 
             RGBColor[
              0.8889097707223068, 0.8948410525156034, 0.6812010309516134], 
             UndirectedEdge[40, 167] -> 
             RGBColor[
              0.754442427864565, 0.8054633138723151, 0.8957950524621294], 
             UndirectedEdge[17, 262] -> 
             RGBColor[
              0.6308884293346115, 0.7040212074028981, 0.9651157750237251], 
             UndirectedEdge[96, 348] -> 
             RGBColor[
              0.6721248142303154, 0.7416703556193767, 0.9695471493981208], 
             UndirectedEdge[60, 122] -> 
             RGBColor[
              0.9392810650595336, 0.9523778593583339, 0.9162853711196718], 
             UndirectedEdge[99, 187] -> 
             RGBColor[
              0.5779459979321016, 0.6682416231486052, 0.9599171725246138], 
             UndirectedEdge[111, 166] -> 
             RGBColor[
              0.6986348335273207, 0.7632077923151652, 0.9716163800175449], 
             UndirectedEdge[130, 172] -> 
             RGBColor[
              0.9058398764006403, 0.9277561453461891, 0.9908810101355388], 
             UndirectedEdge[205, 230] -> 
             RGBColor[
              0.9005875363893335, 0.9226472010011988, 0.9584528619197168], 
             UndirectedEdge[248, 319] -> 
             RGBColor[
              0.9872270085554848, 0.9889860540338552, 0.8613450538852505], 
             UndirectedEdge[77, 111] -> 
             RGBColor[
              0.9180047713441433, 0.9364305614266202, 0.9564851604891722], 
             UndirectedEdge[41, 188] -> 
             RGBColor[
              0.9933568926144904, 0.9905411314120178, 0.6885368243108776], 
             UndirectedEdge[57, 278] -> 
             RGBColor[
              0.9819370960691989, 0.983953242186836, 0.8128289503470074], 
             UndirectedEdge[56, 331] -> 
             RGBColor[
              0.758895628099485, 0.8116203615631226, 0.976591058558867], 
             UndirectedEdge[40, 87] -> 
             RGBColor[
              0.7566259623449308, 0.8044924447929727, 0.7234015421501936], 
             UndirectedEdge[142, 214] -> 
             RGBColor[
              0.911720713199657, 0.9324453649786627, 0.991441929599314], 
             UndirectedEdge[341, 368] -> 
             RGBColor[
              0.8517244767124988, 0.8807037308135108, 0.7353961476897644], 
             UndirectedEdge[96, 188] -> 
             RGBColor[
              0.9284084632097291, 0.941610978400119, 0.7954991301475948], 
             UndirectedEdge[142, 202] -> 
             RGBColor[
              0.9185449741713969, 0.9376949457632173, 0.9854395515158552], 
             UndirectedEdge[37, 351] -> 
             RGBColor[
              0.9925233784765102, 0.9911762391066975, 0.7735704977278818], 
             UndirectedEdge[83, 108] -> 
             RGBColor[
              0.7608465628667984, 0.808098922014356, 0.7384868660252814], 
             UndirectedEdge[72, 119] -> 
             RGBColor[
              0.9655679440473434, 0.9006362551777973, 0.5601024799693477], 
             UndirectedEdge[170, 180] -> 
             RGBColor[
              0.9837111493277266, 0.9866029797573697, 0.8780015344166262], 
             UndirectedEdge[196, 234] -> 
             RGBColor[
              0.5764803233434999, 0.6505579896083176, 0.9644138027574582], 
             UndirectedEdge[218, 306] -> 
             RGBColor[
              0.94175612251716, 0.9554739140880267, 0.9623795584162196], 
             UndirectedEdge[186, 189] -> 
             RGBColor[
              0.9832649878814075, 0.9655249769093319, 0.6184731109420897], 
             UndirectedEdge[20, 135] -> 
             RGBColor[
              0.9708477816646572, 0.9754415571719885, 0.8124547401234206], 
             UndirectedEdge[79, 254] -> 
             RGBColor[
              0.7944560104992591, 0.8402436728388253, 0.9775734823233655], 
             UndirectedEdge[93, 355] -> 
             RGBColor[
              0.8815580922094145, 0.9079707871545473, 0.9701733897589913], 
             UndirectedEdge[211, 301] -> 
             RGBColor[
              0.8927104284743621, 0.9168798008927952, 0.9755080907700476], 
             UndirectedEdge[145, 227] -> 
             RGBColor[
              0.8646061877165536, 0.8941414055297884, 0.9392818556997374], 
             UndirectedEdge[26, 345] -> 
             RGBColor[
              0.9568531455743134, 0.8538761266373819, 0.4933473312432288], 
             UndirectedEdge[132, 140] -> 
             RGBColor[
              0.9346773354416151, 0.9476876138250295, 0.8715822846155408], 
             UndirectedEdge[153, 258] -> 
             RGBColor[
              0.7948840776117658, 0.8405568377763883, 0.9799599104677177], 
             UndirectedEdge[56, 344] -> 
             RGBColor[
              0.839875899129259, 0.8751582604144532, 0.9845893070966567], 
             UndirectedEdge[44, 390] -> 
             RGBColor[
              0.9201986054206881, 0.9374421350615609, 0.9266286575285128], 
             UndirectedEdge[223, 346] -> 
             RGBColor[
              0.5985728632644193, 0.6783792539569745, 0.9648102543656824], 
             UndirectedEdge[114, 222] -> 
             RGBColor[
              0.8230373362151477, 0.8592041063930396, 0.8055023626652851], 
             UndirectedEdge[85, 203] -> 
             RGBColor[
              0.9913502208489109, 0.9897385695270816, 0.7237732439041964], 
             UndirectedEdge[156, 261] -> 
             RGBColor[
              0.9863073129380626, 0.9886057362609518, 0.8765867903618991], 
             UndirectedEdge[33, 295] -> 
             RGBColor[
              0.8856795401066283, 0.9107621601594935, 0.9489020097385301], 
             UndirectedEdge[59, 395] -> 
             RGBColor[
              0.9927570813646329, 0.9912728812568266, 0.7696974360679989], 
             UndirectedEdge[334, 371] -> 
             RGBColor[
              0.962226514391793, 0.9701116489609647, 0.8940574050384387], 
             UndirectedEdge[40, 154] -> 
             RGBColor[
              0.6471122127670734, 0.7223760373116495, 0.9667417950911792], 
             UndirectedEdge[300, 306] -> 
             RGBColor[
              0.9802790927361498, 0.9839892457864614, 0.8813878747407318], 
             UndirectedEdge[61, 297] -> 
             RGBColor[
              0.7903685853222059, 0.7946213956198913, 0.638276423186565], 
             UndirectedEdge[97, 350] -> 
             RGBColor[
              0.5682058271359696, 0.6369440353785175, 0.9471289762486788], 
             UndirectedEdge[178, 229] -> 
             RGBColor[
              0.874790657234845, 0.9029983407919862, 0.98791950789354], 
             UndirectedEdge[130, 265] -> 
             RGBColor[
              0.9469202051501419, 0.9561813663427106, 0.7818325772395635], 
             UndirectedEdge[110, 134] -> 
             RGBColor[
              0.8956951827549291, 0.9185818560246592, 0.9496674092978227], 
             UndirectedEdge[147, 211] -> 
             RGBColor[
              0.8361099491320951, 0.8725503717714799, 0.9698965922542928], 
             UndirectedEdge[78, 185] -> 
             RGBColor[
              0.7852465746925685, 0.831724714350306, 0.945412184302252], 
             UndirectedEdge[130, 135] -> 
             RGBColor[
              0.9472747354171769, 0.95693967073539, 0.8204210088991382], 
             UndirectedEdge[52, 384] -> 
             RGBColor[
              0.6931492346547394, 0.685135516456369, 0.6112508926645357], 
             UndirectedEdge[77, 166] -> 
             RGBColor[
              0.7560983698055876, 0.8080021153970741, 0.9415411552202626], 
             UndirectedEdge[24, 76] -> 
             RGBColor[
              0.9730926957718105, 0.9781997213637466, 0.874299814600417], 
             UndirectedEdge[100, 220] -> 
             RGBColor[
              0.9102039368767765, 0.9312359287105942, 0.9912972581195953], 
             UndirectedEdge[41, 369] -> 
             RGBColor[
              0.9932707087410011, 0.9903567928211504, 0.6791562415467765], 
             UndirectedEdge[12, 318] -> 
             RGBColor[
              0.7293425823196491, 0.7827226434539889, 0.7524046311755553], 
             UndirectedEdge[118, 199] -> 
             RGBColor[
              0.7092318573606228, 0.6275890468244024, 0.5963896091616682], 
             UndirectedEdge[11, 205] -> 
             RGBColor[
              0.7132851663248279, 0.7753242868879255, 0.972513390690845], 
             UndirectedEdge[120, 136] -> 
             RGBColor[
              0.9916980278640425, 0.9902469463090531, 0.7445080922308819], 
             UndirectedEdge[66, 215] -> 
             RGBColor[
              0.5911140198174707, 0.6789320165277737, 0.9609538074434837], 
             UndirectedEdge[199, 287] -> 
             RGBColor[
              0.7546203667371835, 0.8053937659768817, 0.8868627412814314], 
             UndirectedEdge[8, 64] -> 
             RGBColor[
              0.8816695488314131, 0.9064190900556576, 0.893264878445645], 
             UndirectedEdge[312, 361] -> 
             RGBColor[
              0.7176886073773849, 0.7789791709580013, 0.9727722936491474], 
             UndirectedEdge[5, 193] -> 
             RGBColor[
              0.8534998916646157, 0.8835323495075703, 0.850536557249842], 
             UndirectedEdge[187, 232] -> 
             RGBColor[
              0.8159063591688276, 0.8526752718037527, 0.7326851353310089], 
             UndirectedEdge[115, 325] -> 
             RGBColor[
              0.9739831246084136, 0.9801172374484541, 0.9289239631368187], 
             UndirectedEdge[137, 252] -> 
             RGBColor[
              0.965891548111921, 0.9740825529461106, 0.9426208915242374], 
             UndirectedEdge[296, 390] -> 
             RGBColor[
              0.6600597261741517, 0.7319414912454785, 0.9685212412839452], 
             UndirectedEdge[101, 171] -> 
             RGBColor[
              0.8052741304752958, 0.8484170270939457, 0.981063587307365], 
             UndirectedEdge[234, 342] -> 
             RGBColor[
              0.5998471635416895, 0.6683777951871821, 0.9384803466637653], 
             UndirectedEdge[56, 343] -> 
             RGBColor[
              0.8738608998567529, 0.9022569774962872, 0.9878308268048134], 
             UndirectedEdge[60, 146] -> 
             RGBColor[
              0.9887089300813949, 0.9821575636254238, 0.627656440099929], 
             UndirectedEdge[149, 336] -> 
             RGBColor[
              0.9779052446549732, 0.9520307530557266, 0.6283740966903317], 
             UndirectedEdge[12, 199] -> 
             RGBColor[
              0.7565530326867891, 0.8048133128788528, 0.7545467375036206], 
             UndirectedEdge[42, 104] -> 
             RGBColor[
              0.7801823688007945, 0.828573557199327, 0.9786267868761809], 
             UndirectedEdge[216, 323] -> 
             RGBColor[
              0.9218468442491983, 0.9036680344760589, 0.6590217991948564], 
             UndirectedEdge[110, 192] -> 
             RGBColor[
              0.8989389379075864, 0.9205047775965927, 0.9219527855180263], 
             UndirectedEdge[93, 380] -> 
             RGBColor[
              0.9724035853721144, 0.9782120854058034, 0.8990351529788476], 
             UndirectedEdge[34, 397] -> 
             RGBColor[
              0.9308482323330304, 0.9473671878637002, 0.9818270446548123], 
             UndirectedEdge[249, 308] -> 
             RGBColor[
              0.7390088149130707, 0.6950765021706622, 0.6084394131731741], 
             UndirectedEdge[116, 130] -> 
             RGBColor[
              0.5394524823746005, 0.6142380080563423, 0.9619114478846171], 
             UndirectedEdge[81, 315] -> 
             RGBColor[
              0.42763386803061054`, 0.5396906955445904, 0.9494049101363734], 
             UndirectedEdge[99, 193] -> 
             RGBColor[
              0.7562384917124567, 0.8056348635408555, 0.8421525260040306], 
             UndirectedEdge[116, 135] -> 
             RGBColor[
              0.5867492530425764, 0.6480956626790477, 0.7920105610145212], 
             UndirectedEdge[304, 378] -> 
             RGBColor[
              0.9924376419370111, 0.9899797799570798, 0.6905985749571852], 
             UndirectedEdge[56, 120] -> 
             RGBColor[
              0.9072392608016614, 0.9267379294754177, 0.909292211403135], 
             UndirectedEdge[255, 393] -> 
             RGBColor[
              0.7563364551866656, 0.8098582518611994, 0.97638251759227], 
             UndirectedEdge[106, 214] -> 
             RGBColor[
              0.8529643941434419, 0.8859466480002223, 0.9857442955779845], 
             UndirectedEdge[130, 328] -> 
             RGBColor[
              0.9381618684281194, 0.9274764462661022, 0.6764650582207707], 
             UndirectedEdge[181, 250] -> 
             RGBColor[
              0.9660714619462044, 0.9738978720086648, 0.9280371250243437], 
             UndirectedEdge[102, 230] -> 
             RGBColor[
              0.8065033220600464, 0.8490571674850795, 0.9491043848592358], 
             UndirectedEdge[45, 141] -> 
             RGBColor[
              0.9293421320533312, 0.7421931798752821, 0.5087999505762821], 
             UndirectedEdge[225, 288] -> 
             RGBColor[
              0.9857448392324145, 0.9861012169172085, 0.7514893746188918], 
             UndirectedEdge[208, 278] -> 
             RGBColor[
              0.9933568852717094, 0.991206825910187, 0.7369261293045899], 
             UndirectedEdge[342, 346] -> 
             RGBColor[
              0.9200444513097614, 0.9382702092866164, 0.9640736489993237], 
             UndirectedEdge[133, 164] -> 
             RGBColor[
              0.9875665749683687, 0.9891264734720415, 0.8557175596540572], 
             UndirectedEdge[287, 373] -> 
             RGBColor[
              0.7735282465085439, 0.8207440345655488, 0.8883512388388786], 
             UndirectedEdge[122, 314] -> 
             RGBColor[
              0.8454411648150799, 0.8797521748090606, 0.9850786438938912], 
             UndirectedEdge[85, 351] -> 
             RGBColor[
              0.9925584657316029, 0.9902382098365519, 0.7037494993604678], 
             UndirectedEdge[5, 338] -> 
             RGBColor[
              0.7430552067683199, 0.7991996420469281, 0.9750244568311124], 
             UndirectedEdge[311, 339] -> 
             RGBColor[
              0.867381258023511, 0.8972134304571799, 0.9848419894713984], 
             UndirectedEdge[39, 324] -> 
             RGBColor[
              0.908199903279423, 0.7802924105497315, 0.6136579138259409], 
             UndirectedEdge[52, 346] -> 
             RGBColor[
              0.907972027946627, 0.8567080148173056, 0.6303879540150632], 
             UndirectedEdge[272, 291] -> 
             RGBColor[
              0.8182860470691469, 0.8583963505145699, 0.9564849257933108], 
             UndirectedEdge[191, 323] -> 
             RGBColor[
              0.9746560729610996, 0.926171124440044, 0.35604405856324683`], 
             UndirectedEdge[60, 165] -> 
             RGBColor[
              0.9671206736913764, 0.906364872285339, 0.5592602081190275], 
             UndirectedEdge[44, 301] -> 
             RGBColor[
              0.9103958902316539, 0.9296257160574404, 0.9256936658027956], 
             UndirectedEdge[11, 144] -> 
             RGBColor[
              0.7749166639788517, 0.7675167591410504, 0.621232908280148], 
             UndirectedEdge[333, 381] -> 
             RGBColor[
              0.9821366111688195, 0.9509607234223258, 0.4228601895034269], 
             UndirectedEdge[9, 363] -> 
             RGBColor[
              0.9047561312528687, 0.9238893203203893, 0.8699381186973841], 
             UndirectedEdge[153, 312] -> 
             RGBColor[
              0.8733848683696053, 0.9018822521445196, 0.9877841356588607], 
             UndirectedEdge[55, 80] -> 
             RGBColor[
              0.864384408863579, 0.8941161981918184, 0.9462711051071346], 
             UndirectedEdge[7, 40] -> 
             RGBColor[
              0.7370044134963628, 0.7932141344696968, 0.959171115304742], 
             UndirectedEdge[51, 377] -> 
             RGBColor[
              0.9698624840434608, 0.9167170556342551, 0.558930657555546], 
             UndirectedEdge[112, 170] -> 
             RGBColor[
              0.8591279734827748, 0.8900523201122352, 0.9478979886098863], 
             UndirectedEdge[200, 375] -> 
             RGBColor[
              0.8640214548716718, 0.8920263266925709, 0.8640300691809821], 
             UndirectedEdge[94, 200] -> 
             RGBColor[
              0.5819035228402749, 0.669398180525038, 0.9613708948471262], 
             UndirectedEdge[8, 253] -> 
             RGBColor[
              0.9889334684695887, 0.9896917190623566, 0.833064596931856], 
             UndirectedEdge[31, 295] -> 
             RGBColor[
              0.8392302728660306, 0.8744756395636325, 0.9442723808730689], 
             UndirectedEdge[301, 383] -> 
             RGBColor[
              0.8666135821392248, 0.8964781630715292, 0.9871395711711586], 
             UndirectedEdge[327, 392] -> 
             RGBColor[
              0.7055736340024957, 0.7623977305207799, 0.7461269525038047], 
             UndirectedEdge[119, 375] -> 
             RGBColor[
              0.9908962523757869, 0.990503380648815, 0.8005361880842303], 
             UndirectedEdge[160, 340] -> 
             RGBColor[
              0.9789868099578526, 0.9815719254585189, 0.8034615839816335], 
             UndirectedEdge[151, 308] -> 
             RGBColor[
              0.959467984366968, 0.8670680866658689, 0.5092751710626531], 
             UndirectedEdge[221, 276] -> 
             RGBColor[
              0.9676316303139008, 0.9446942255372976, 0.6464556574674355], 
             UndirectedEdge[94, 316] -> 
             RGBColor[
              0.6876695207603989, 0.7527786798089688, 0.9625537354704101], 
             UndirectedEdge[195, 206] -> 
             RGBColor[
              0.9873242292999092, 0.9873772535138213, 0.7566020805635174], 
             UndirectedEdge[159, 192] -> 
             RGBColor[
              0.9682093329501895, 0.97531488737371, 0.9164736939549646], 
             UndirectedEdge[220, 350] -> 
             RGBColor[
              0.534147623099023, 0.6102911816939549, 0.9613625742689622], 
             UndirectedEdge[229, 319] -> 
             RGBColor[
              0.9429051099551685, 0.9549128491889601, 0.9012276429881596], 
             UndirectedEdge[69, 97] -> 
             RGBColor[
              0.8335369207344308, 0.8704737367613051, 0.966270593501699], 
             UndirectedEdge[90, 317] -> 
             RGBColor[
              0.9487953970667132, 0.9572529313353669, 0.7476680084749291], 
             UndirectedEdge[136, 237] -> 
             RGBColor[
              0.808266771850316, 0.8474057620016203, 0.8085236633444043], 
             UndirectedEdge[69, 141] -> 
             RGBColor[
              0.7899675536391602, 0.6344085779464652, 0.5917873345525559], 
             UndirectedEdge[48, 143] -> 
             RGBColor[
              0.9559734405785154, 0.9652814841086629, 0.9002292415962938], 
             UndirectedEdge[51, 246] -> 
             RGBColor[
              0.9806587624580592, 0.9843610841348494, 0.8847165223524435], 
             UndirectedEdge[97, 132] -> 
             RGBColor[
              0.9744435524215822, 0.9788918820904726, 0.8578931219653658], 
             UndirectedEdge[94, 383] -> 
             RGBColor[
              0.6643866324854957, 0.7344756873015919, 0.9694219188733486], 
             UndirectedEdge[246, 344] -> 
             RGBColor[
              0.9133856817727113, 0.9328187485821475, 0.9585174284507675], 
             UndirectedEdge[155, 354] -> 
             RGBColor[
              0.9810191276242988, 0.9620246744128051, 0.6379181515673793], 
             UndirectedEdge[107, 307] -> 
             RGBColor[
              0.77333098982858, 0.820677352221072, 0.8922426844508349], 
             UndirectedEdge[310, 363] -> 
             RGBColor[
              0.8576615342642703, 0.8893720507539702, 0.9862772230041572], 
             UndirectedEdge[99, 281] -> 
             RGBColor[
              0.6476222679250769, 0.7227305637953174, 0.966822669500697], 
             UndirectedEdge[123, 187] -> 
             RGBColor[
              0.7934289192104743, 0.774996729530256, 0.6209521672295977], 
             UndirectedEdge[23, 227] -> 
             RGBColor[
              0.6538193733539436, 0.7210403635986924, 0.9225960002667686], 
             UndirectedEdge[28, 211] -> 
             RGBColor[
              0.8797131873314482, 0.9066135528496987, 0.9742425555425763], 
             UndirectedEdge[327, 356] -> 
             RGBColor[
              0.691045270396588, 0.7545787945157065, 0.9463677749785243], 
             UndirectedEdge[140, 219] -> 
             RGBColor[
              0.9298924180136243, 0.9456877719089785, 0.9499333586973584], 
             UndirectedEdge[104, 144] -> 
             RGBColor[
              0.8238227012416401, 0.8064203626686336, 0.6256302910665482], 
             UndirectedEdge[49, 328] -> 
             RGBColor[
              0.7595310404884758, 0.7857557254540175, 0.6598759915116712], 
             UndirectedEdge[112, 271] -> 
             RGBColor[
              0.8665306732907783, 0.8940427028558988, 0.8668265008428696], 
             UndirectedEdge[106, 197] -> 
             RGBColor[
              0.7526487213149836, 0.8066941685241928, 0.9759806487046332], 
             UndirectedEdge[106, 204] -> 
             RGBColor[
              0.6951906016662049, 0.7613721755235602, 0.9705513590014307], 
             UndirectedEdge[50, 158] -> 
             RGBColor[
              0.9529753898630291, 0.9644497032723549, 0.9644845783660196], 
             UndirectedEdge[259, 299] -> 
             RGBColor[
              0.5717363437071397, 0.6504558865742414, 0.9634037295155369], 
             UndirectedEdge[79, 286] -> 
             RGBColor[
              0.8196047939318127, 0.8582686146068165, 0.9022683856492001], 
             UndirectedEdge[240, 388] -> 
             RGBColor[
              0.7144774718816389, 0.7537245962968112, 0.663291565345624], 
             UndirectedEdge[118, 299] -> 
             RGBColor[
              0.5802765370843588, 0.5133223017371997, 0.5878366487673804], 
             UndirectedEdge[138, 257] -> 
             RGBColor[
              0.9815887295142152, 0.9857106129743178, 0.9125176014274854], 
             UndirectedEdge[171, 244] -> 
             RGBColor[
              0.8548188729365083, 0.8841722635721734, 0.8198976848095767], 
             UndirectedEdge[161, 337] -> 
             RGBColor[
              0.9789048137231164, 0.9821036630608801, 0.8451726087728324], 
             UndirectedEdge[119, 355] -> 
             RGBColor[
              0.8974801233244831, 0.9191990583952923, 0.9142765141309684], 
             UndirectedEdge[248, 292] -> 
             RGBColor[
              0.97029203997199, 0.9773493937843584, 0.9344985390809405], 
             UndirectedEdge[68, 386] -> 
             RGBColor[
              0.8209773453355395, 0.8608833869503112, 0.9825759579688498], 
             UndirectedEdge[126, 299] -> 
             RGBColor[
              0.6257815132218938, 0.6911751828884012, 0.8763796252514813], 
             UndirectedEdge[128, 383] -> 
             RGBColor[
              0.9202820368998856, 0.8636914264998662, 0.6309278752627192], 
             UndirectedEdge[229, 248] -> 
             RGBColor[
              0.9399606221525765, 0.9536952278127034, 0.9500254259672745], 
             UndirectedEdge[395, 396] -> 
             RGBColor[
              0.9845954891031821, 0.9862026139999771, 0.8290398702900224], 
             UndirectedEdge[81, 292] -> 
             RGBColor[
              0.6216746943661273, 0.6929831010077097, 0.9492562812947258], 
             UndirectedEdge[34, 253] -> 
             RGBColor[
              0.9679733429381026, 0.9750933941047587, 0.9148359251550275], 
             UndirectedEdge[130, 322] -> 
             RGBColor[
              0.9182626765747389, 0.8546102929944043, 0.6290623194665592], 
             UndirectedEdge[74, 311] -> 
             RGBColor[
              0.7776556930147868, 0.8267309311476835, 0.9761644022366269], 
             UndirectedEdge[232, 235] -> 
             RGBColor[
              0.8035696838255821, 0.8426598029992152, 0.7317139470572578], 
             UndirectedEdge[207, 221] -> 
             RGBColor[
              0.9021317010430907, 0.924089075522202, 0.9659017640255492], 
             UndirectedEdge[140, 216] -> 
             RGBColor[
              0.8757265273849204, 0.9037445782461377, 0.9880087720239153], 
             UndirectedEdge[31, 173] -> 
             RGBColor[
              0.6879420729361678, 0.7561448430219199, 0.9695312947122416], 
             UndirectedEdge[37, 243] -> 
             RGBColor[
              0.9475748846724095, 0.9578809559518155, 0.8688690271368321], 
             UndirectedEdge[1, 35] -> 
             RGBColor[
              0.9367418269902773, 0.9282749562120202, 0.6791700913641396], 
             UndirectedEdge[60, 210] -> 
             RGBColor[
              0.9746496650407949, 0.979927994210346, 0.897059618260675], 
             UndirectedEdge[35, 92] -> 
             RGBColor[
              0.9451051148187064, 0.9552096741629519, 0.8202140685496129], 
             UndirectedEdge[52, 291] -> 
             RGBColor[
              0.9537644452928331, 0.8924795786280791, 0.60902775459622], 
             UndirectedEdge[77, 400] -> 
             RGBColor[
              0.7861364469500582, 0.8323883796229098, 0.9439058626861776], 
             UndirectedEdge[77, 389] -> 
             RGBColor[
              0.6058670386819613, 0.673442783497418, 0.9315881469017804], 
             UndirectedEdge[96, 361] -> 
             RGBColor[
              0.7393319191592036, 0.7962321110462223, 0.97483793888586], 
             UndirectedEdge[150, 374] -> 
             RGBColor[
              0.9433185113186524, 0.928513323372731, 0.6724333376007819], 
             UndirectedEdge[80, 154] -> 
             RGBColor[
              0.7609261038505699, 0.81316052267143, 0.9768056608392427], 
             UndirectedEdge[200, 383] -> 
             RGBColor[
              0.8168160152126582, 0.8574632208334083, 0.9822061233881698], 
             UndirectedEdge[144, 391] -> 
             RGBColor[
              0.9649601077780098, 0.916883961557531, 0.6025324566627808], 
             UndirectedEdge[196, 290] -> 
             RGBColor[
              0.9508642386030705, 0.9624823557006268, 0.9544376974588333], 
             UndirectedEdge[159, 228] -> 
             RGBColor[
              0.7238113113079572, 0.7826561875132982, 0.9622310194309626], 
             UndirectedEdge[27, 377] -> 
             RGBColor[
              0.9665324627313145, 0.9149683642835826, 0.5974748422184777], 
             UndirectedEdge[24, 233] -> 
             RGBColor[
              0.9930988843422661, 0.9907060869850883, 0.7125586763923399], 
             UndirectedEdge[24, 109] -> 
             RGBColor[
              0.983960526174255, 0.9863049314834507, 0.8559034125132072], 
             UndirectedEdge[189, 255] -> 
             RGBColor[
              0.8062156873853284, 0.847811724522221, 0.9131037066755887], 
             UndirectedEdge[262, 298] -> 
             RGBColor[
              0.9662871677613789, 0.9727902701907107, 0.8708670953902427], 
             UndirectedEdge[249, 397] -> 
             RGBColor[
              0.7328259241903127, 0.7905845965213731, 0.9747466250029484], 
             UndirectedEdge[128, 324] -> 
             RGBColor[
              0.9187095259732281, 0.7130919928032455, 0.2533296899866206], 
             UndirectedEdge[7, 228] -> 
             RGBColor[0.72612494352706, 0.78438169063408, 0.9583146435759468],
              UndirectedEdge[115, 258] -> 
             RGBColor[
              0.8143277701275454, 0.8552722890791477, 0.9544794049674519], 
             UndirectedEdge[375, 383] -> 
             RGBColor[
              0.9465045645168926, 0.9571038334691249, 0.8720810932072045], 
             UndirectedEdge[257, 338] -> 
             RGBColor[
              0.8764121137167676, 0.9035563874692498, 0.9496999627150409], 
             UndirectedEdge[5, 321] -> 
             RGBColor[
              0.8439906662677016, 0.8782696922890028, 0.9485533233487269], 
             UndirectedEdge[65, 239] -> 
             RGBColor[
              0.9810865230712331, 0.9845257846523408, 0.8770815517610646], 
             UndirectedEdge[56, 71] -> 
             RGBColor[
              0.8747663905843075, 0.9029789912235482, 0.9879171933187487], 
             UndirectedEdge[276, 322] -> 
             RGBColor[
              0.9542840662805134, 0.8517100557339807, 0.3068045234889296], 
             UndirectedEdge[239, 326] -> 
             RGBColor[
              0.9421198551919341, 0.9557324905188503, 0.9613237171038145], 
             UndirectedEdge[379, 393] -> 
             RGBColor[
              0.9229688217643774, 0.89243274012926, 0.6412841006588219], 
             UndirectedEdge[131, 262] -> 
             RGBColor[
              0.9065415524196421, 0.9282349564782758, 0.9881504926773335], 
             UndirectedEdge[201, 210] -> 
             RGBColor[
              0.9488442004491094, 0.9613686689716555, 0.9714776044570227], 
             UndirectedEdge[301, 372] -> 
             RGBColor[
              0.8574155188454129, 0.8891438770758204, 0.9862622516829869], 
             UndirectedEdge[291, 398] -> 
             RGBColor[
              0.9751979339661299, 0.980736096079394, 0.9140087038670475], 
             UndirectedEdge[28, 49] -> 
             RGBColor[
              0.6753249330023283, 0.7447618384677093, 0.9693173434120088], 
             UndirectedEdge[6, 160] -> 
             RGBColor[
              0.9008944621086523, 0.9231006513814465, 0.965718456466973], 
             UndirectedEdge[375, 379] -> 
             RGBColor[
              0.9761263307101854, 0.9317418644730955, 0.5236757601336834], 
             UndirectedEdge[45, 112] -> 
             RGBColor[
              0.8651135949133699, 0.8934567045295873, 0.890311156837811], 
             UndirectedEdge[324, 390] -> 
             RGBColor[
              0.8748437864016014, 0.7536951483790291, 0.6104763776207773], 
             UndirectedEdge[169, 227] -> 
             RGBColor[
              0.9853050873739995, 0.9881912902341896, 0.8931962616350433], 
             UndirectedEdge[44, 380] -> 
             RGBColor[
              0.9877162367207177, 0.9891883624527693, 0.853237277105436], 
             UndirectedEdge[288, 360] -> 
             RGBColor[
              0.9666986941255622, 0.9718966330817183, 0.7837295302545728], 
             UndirectedEdge[87, 134] -> 
             RGBColor[
              0.9869007588652032, 0.9863957792458344, 0.7045023687251968], 
             UndirectedEdge[85, 258] -> 
             RGBColor[
              0.828280153461723, 0.863066403128214, 0.7873282076292383], 
             UndirectedEdge[26, 77] -> 
             RGBColor[
              0.9852134135685149, 0.9867040585073774, 0.8298119222376539], 
             UndirectedEdge[90, 333] -> 
             RGBColor[
              0.94879119846414, 0.9572439509490065, 0.7472110164956031], 
             UndirectedEdge[45, 91] -> 
             RGBColor[
              0.8045771535108683, 0.8458009724701481, 0.8845264583281338], 
             UndirectedEdge[103, 133] -> 
             RGBColor[
              0.9877962780668572, 0.9892214616063668, 0.8519107848595402], 
             UndirectedEdge[143, 342] -> 
             RGBColor[
              0.9788195470051688, 0.9826860707130463, 0.8742461174506073], 
             UndirectedEdge[75, 164] -> 
             RGBColor[
              0.9917437142317349, 0.9904362665401125, 0.756139248742856], 
             UndirectedEdge[44, 211] -> 
             RGBColor[
              0.9691782792854454, 0.9760899184171395, 0.9171797616449182], 
             UndirectedEdge[82, 171] -> 
             RGBColor[
              0.853180414065164, 0.883972467246513, 0.8817784628365823], 
             UndirectedEdge[17, 122] -> 
             RGBColor[
              0.6065939166583023, 0.6847301087307653, 0.9655959866599825], 
             UndirectedEdge[150, 186] -> 
             RGBColor[
              0.9460276202394307, 0.93765178389154, 0.6829577141857134], 
             UndirectedEdge[180, 394] -> 
             RGBColor[
              0.9867572461352971, 0.9887917952007641, 0.8691302328939332], 
             UndirectedEdge[156, 202] -> 
             RGBColor[
              0.9647239816918887, 0.9728603534893909, 0.9288595086252925], 
             UndirectedEdge[86, 178] -> 
             RGBColor[
              0.7110812487187415, 0.7733601013005218, 0.9725412498488535], 
             UndirectedEdge[102, 250] -> 
             RGBColor[
              0.8138542935639312, 0.8542206496160933, 0.922381888236089], 
             UndirectedEdge[7, 222] -> 
             RGBColor[
              0.802709895702605, 0.8464159651771167, 0.9644399844545624], 
             UndirectedEdge[97, 220] -> 
             RGBColor[
              0.9211944047000721, 0.9394951956954103, 0.9748634388264426], 
             UndirectedEdge[230, 289] -> 
             RGBColor[
              0.8050136103204848, 0.8478477523841543, 0.9489871092941036], 
             UndirectedEdge[14, 289] -> 
             RGBColor[
              0.8147752199758935, 0.854008095341398, 0.8823140999686494], 
             UndirectedEdge[77, 370] -> 
             RGBColor[
              0.8186252896223886, 0.8584667459611268, 0.9466669329432071], 
             UndirectedEdge[151, 270] -> 
             RGBColor[
              0.9433189312374153, 0.9546294336376736, 0.8746318014251693], 
             UndirectedEdge[173, 214] -> 
             RGBColor[
              0.8036737408968835, 0.8474404150611713, 0.9808314639097111], 
             UndirectedEdge[144, 317] -> 
             RGBColor[
              0.973129787487441, 0.9197057026836672, 0.39283009468079966`], 
             UndirectedEdge[31, 175] -> 
             RGBColor[
              0.8450730363925356, 0.8775164860525468, 0.8754186208541197], 
             UndirectedEdge[163, 240] -> 
             RGBColor[
              0.9754071036330012, 0.9287045272467556, 0.3589616709033426], 
             UndirectedEdge[329, 371] -> 
             RGBColor[
              0.6893115497198061, 0.7502965768828211, 0.8702640109399983], 
             UndirectedEdge[72, 375] -> 
             RGBColor[
              0.9683816958474627, 0.9017998138572696, 0.5134713308851341], 
             UndirectedEdge[32, 238] -> 
             RGBColor[
              0.9621008097214185, 0.8763052509817164, 0.3646785921443666], 
             UndirectedEdge[11, 14] -> 
             RGBColor[
              0.7938685659976208, 0.8370351318078075, 0.8806682515838828], 
             UndirectedEdge[79, 237] -> 
             RGBColor[
              0.6362754158653561, 0.7154695594487235, 0.9645955755247879], 
             UndirectedEdge[69, 74] -> 
             RGBColor[
              0.6644191533712249, 0.7373803534918462, 0.9674521684764101], 
             UndirectedEdge[16, 203] -> 
             RGBColor[
              0.6127679923635228, 0.6779841452229833, 0.8883413789620074], 
             UndirectedEdge[315, 319] -> 
             RGBColor[
              0.7791957014390651, 0.8252746096974958, 0.8858493849434732], 
             UndirectedEdge[40, 80] -> 
             RGBColor[
              0.6339558869714278, 0.7120982156083118, 0.965430495488724], 
             UndirectedEdge[18, 198] -> 
             RGBColor[
              0.8905076255031857, 0.9131692247641509, 0.8871519713671836], 
             UndirectedEdge[300, 307] -> 
             RGBColor[
              0.773231349929408, 0.8206361485621356, 0.8938939754399073], 
             UndirectedEdge[191, 198] -> 
             RGBColor[
              0.9863021624848276, 0.9697033616917339, 0.5883390298366311], 
             UndirectedEdge[289, 391] -> 
             RGBColor[
              0.8077546840551371, 0.8498920406873617, 0.9443471864478645], 
             UndirectedEdge[132, 357] -> 
             RGBColor[
              0.991075278465267, 0.9905774125375757, 0.7975692624768767], 
             UndirectedEdge[157, 187] -> 
             RGBColor[
              0.7988165456934913, 0.8432259917321046, 0.9594771232542915], 
             UndirectedEdge[38, 250] -> 
             RGBColor[
              0.9856786973149791, 0.9883457875461221, 0.8870045780414755], 
             UndirectedEdge[140, 191] -> 
             RGBColor[
              0.9285357560968216, 0.9262476682101228, 0.6850310313923059], 
             UndirectedEdge[204, 261] -> 
             RGBColor[
              0.8001259282429117, 0.8430363002281742, 0.9196689501321976], 
             UndirectedEdge[337, 354] -> 
             RGBColor[
              0.9739399271607025, 0.9800505548755574, 0.9274536278265778], 
             UndirectedEdge[300, 314] -> 
             RGBColor[
              0.894896146102319, 0.9169843953917819, 0.9051296651932144], 
             UndirectedEdge[292, 378] -> 
             RGBColor[
              0.9751188788591383, 0.9781844108210891, 0.770112528153029], 
             UndirectedEdge[153, 361] -> 
             RGBColor[
              0.7716894334242383, 0.8220331145998345, 0.977924227482353], 
             UndirectedEdge[240, 334] -> 
             RGBColor[
              0.9565936003018582, 0.9468632644081938, 0.6851224848324431], 
             UndirectedEdge[52, 260] -> 
             RGBColor[
              0.9684384209879369, 0.9018232711606253, 0.5125312485075195], 
             UndirectedEdge[128, 177] -> 
             RGBColor[
              0.9536667276267875, 0.8895283267357603, 0.6069599752805885], 
             UndirectedEdge[16, 85] -> 
             RGBColor[
              0.6155956176309849, 0.6782009021859059, 0.7722407988729186], 
             UndirectedEdge[179, 303] -> 
             RGBColor[
              0.729850464626352, 0.7864263070167843, 0.9323248762122508], 
             UndirectedEdge[48, 320] -> 
             RGBColor[
              0.7604494864927508, 0.812950565210652, 0.976990408154883], 
             UndirectedEdge[136, 320] -> 
             RGBColor[
              0.7969966862714961, 0.8382561988171648, 0.8076364409239558], 
             UndirectedEdge[96, 192] -> 
             RGBColor[
              0.9249248825600899, 0.9411502154886249, 0.9244512638150773], 
             UndirectedEdge[140, 357] -> 
             RGBColor[
              0.9321181178007367, 0.9466293115616329, 0.9139951439678448], 
             UndirectedEdge[202, 306] -> 
             RGBColor[
              0.9572749884262163, 0.9676563368408335, 0.9572064795134474], 
             UndirectedEdge[114, 258] -> 
             RGBColor[
              0.8284520864684763, 0.863434150444566, 0.8060420543668189], 
             UndirectedEdge[87, 236] -> 
             RGBColor[
              0.9940214605043375, 0.9896208334788709, 0.5906510550451547], 
             UndirectedEdge[116, 362] -> 
             RGBColor[
              0.5291469335723289, 0.606020643178081, 0.9609284954399844], 
             UndirectedEdge[36, 64] -> 
             RGBColor[
              0.7793954103717827, 0.8275888852977301, 0.9786465087077947], 
             UndirectedEdge[245, 304] -> 
             RGBColor[
              0.9302772215946242, 0.9446963953596612, 0.893626109061637], 
             UndirectedEdge[187, 218] -> 
             RGBColor[
              0.775360406430927, 0.8251239635083438, 0.9780859355721143], 
             UndirectedEdge[26, 370] -> 
             RGBColor[
              0.8283703955684931, 0.8639459199599753, 0.8500689194889711], 
             UndirectedEdge[91, 141] -> 
             RGBColor[
              0.7433488960040147, 0.5976255243451589, 0.5873898306597247], 
             UndirectedEdge[55, 385] -> 
             RGBColor[
              0.9255548208464724, 0.9423081436082474, 0.9522604845133815], 
             UndirectedEdge[179, 231] -> 
             RGBColor[
              0.38886238295461073`, 0.5099505855126526, 0.9461946254152465], 
             UndirectedEdge[94, 177] -> 
             RGBColor[
              0.6977713232123975, 0.760312587537486, 0.9454540188912179], 
             UndirectedEdge[225, 383] -> 
             RGBColor[
              0.938432057726776, 0.9526646574234736, 0.9565589728675241], 
             UndirectedEdge[37, 134] -> 
             RGBColor[
              0.9873996302673318, 0.9884758920922749, 0.8324414717203013], 
             UndirectedEdge[255, 341] -> 
             RGBColor[
              0.8092288351128117, 0.8472441523192015, 0.7313394778541175], 
             UndirectedEdge[206, 278] -> 
             RGBColor[
              0.9944917423954096, 0.9906267188910811, 0.6418383366449404], 
             UndirectedEdge[131, 279] -> 
             RGBColor[
              0.933641462665115, 0.9469780873461244, 0.8765401586144759], 
             UndirectedEdge[7, 203] -> 
             RGBColor[
              0.9711947133431216, 0.9773181756275107, 0.9014247124310543], 
             UndirectedEdge[101, 151] -> 
             RGBColor[
              0.9445031038385461, 0.9555736607263063, 0.8747447488649884], 
             UndirectedEdge[200, 296] -> 
             RGBColor[
              0.6004594440585509, 0.6851101300032371, 0.9626528017752393], 
             UndirectedEdge[86, 229] -> 
             RGBColor[
              0.7319293150361568, 0.789983783476344, 0.9745297570254972], 
             UndirectedEdge[138, 382] -> 
             RGBColor[
              0.9733485820354908, 0.9795651244766884, 0.9264660217343044], 
             UndirectedEdge[195, 278] -> 
             RGBColor[
              0.9877504037263409, 0.9882887975191148, 0.8029885368369303], 
             UndirectedEdge[65, 113] -> 
             RGBColor[
              0.9662390903141942, 0.973452593612581, 0.9022143825880768], 
             UndirectedEdge[249, 270] -> 
             RGBColor[
              0.722859761783518, 0.7826378491424669, 0.97379604353569], 
             UndirectedEdge[319, 388] -> 
             RGBColor[
              0.7195696403740636, 0.7767493686484837, 0.8811880395071072], 
             UndirectedEdge[138, 256] -> 
             RGBColor[
              0.9189379331394455, 0.9368585648161107, 0.9448181559290258], 
             UndirectedEdge[246, 286] -> 
             RGBColor[
              0.980647165497844, 0.984356288493772, 0.8849087139951803], 
             UndirectedEdge[188, 208] -> 
             RGBColor[
              0.9929710571273234, 0.9903815785225546, 0.6949311168434679], 
             UndirectedEdge[173, 345] -> 
             RGBColor[
              0.7983015624627698, 0.7319170208710799, 0.6110033492334291], 
             UndirectedEdge[84, 156] -> 
             RGBColor[
              0.8010092354066698, 0.8437534087762472, 0.9197384873077894], 
             UndirectedEdge[136, 349] -> 
             RGBColor[
              0.9635019476601063, 0.9698982043235107, 0.8235409981959109], 
             UndirectedEdge[117, 346] -> 
             RGBColor[
              0.9297931304663398, 0.9451248205553351, 0.9289451387382982], 
             UndirectedEdge[26, 197] -> 
             RGBColor[
              0.8619096511799688, 0.8901470413514438, 0.8534117990461594], 
             UndirectedEdge[328, 362] -> 
             RGBColor[
              0.9278563196258477, 0.9192590813878407, 0.675482105776138], 
             UndirectedEdge[187, 275] -> 
             RGBColor[
              0.8163557962033652, 0.8536365721755736, 0.7816035829365473], 
             UndirectedEdge[20, 121] -> 
             RGBColor[
              0.9700513186982576, 0.9757251328418449, 0.8702079930763931], 
             UndirectedEdge[198, 302] -> 
             RGBColor[
              0.9849447496459519, 0.987119312881694, 0.8578355777589812], 
             UndirectedEdge[1, 312] -> 
             RGBColor[
              0.8986144863755232, 0.8978780989794592, 0.6755321847418754], 
             UndirectedEdge[89, 292] -> 
             RGBColor[
              0.9748254249250805, 0.9792240649651405, 0.8593686183840505], 
             UndirectedEdge[304, 315] -> 
             RGBColor[
              0.779579495933443, 0.8254333185839896, 0.8794889169433193], 
             UndirectedEdge[21, 64] -> 
             RGBColor[
              0.7951220425486907, 0.47833060900853713`, 0.571109803576535], 
             UndirectedEdge[201, 351] -> 
             RGBColor[
              0.9638256948957125, 0.9714209069893713, 0.8959200373966295], 
             UndirectedEdge[17, 218] -> 
             RGBColor[
              0.6175259277265516, 0.6934469976150519, 0.9666386916347935], 
             UndirectedEdge[266, 365] -> 
             RGBColor[
              0.9290347712704123, 0.9451316320588086, 0.9542798401119331], 
             UndirectedEdge[112, 180] -> 
             RGBColor[
              0.8642399761115066, 0.8930954407040377, 0.9047892812376708], 
             UndirectedEdge[247, 289] -> 
             RGBColor[
              0.7990754973748173, 0.8434191174720431, 0.9590387856032215], 
             UndirectedEdge[15, 45] -> 
             RGBColor[
              0.9357366939152201, 0.949120391809408, 0.8972195433413699], 
             UndirectedEdge[57, 92] -> 
             RGBColor[
              0.9817638907008546, 0.9835827734176964, 0.7939766149023518], 
             UndirectedEdge[53, 86] -> 
             RGBColor[
              0.7606230794685984, 0.8124165902334068, 0.9617749901548964], 
             UndirectedEdge[114, 154] -> 
             RGBColor[
              0.8843020708880476, 0.9070645827487379, 0.8116086588659833], 
             UndirectedEdge[71, 237] -> 
             RGBColor[
              0.7728915085475332, 0.8230345987296719, 0.9779894109226089], 
             UndirectedEdge[241, 375] -> 
             RGBColor[
              0.9941372014341789, 0.9912245313460315, 0.7018257825976479], 
             UndirectedEdge[100, 282] -> 
             RGBColor[
              0.7686727634935082, 0.8195414545387072, 0.9777357662240465], 
             UndirectedEdge[55, 146] -> 
             RGBColor[
              0.9850468331035301, 0.980112725696684, 0.664591480841302], 
             UndirectedEdge[309, 319] -> 
             RGBColor[
              0.7500617821895982, 0.8016223815826731, 0.8835558560990926], 
             UndirectedEdge[13, 302] -> 
             RGBColor[
              0.7395532219195042, 0.7944653943001786, 0.9374324826704746], 
             UndirectedEdge[110, 348] -> 
             RGBColor[
              0.646138869577812, 0.7210249177273444, 0.9670486711010698], 
             UndirectedEdge[217, 363] -> 
             RGBColor[
              0.9053650767804765, 0.9236444085373108, 0.8237395492584022], 
             UndirectedEdge[39, 380] -> 
             RGBColor[
              0.9544072179764902, 0.9643919261032481, 0.9156821341614463], 
             UndirectedEdge[248, 304] -> 
             RGBColor[
              0.9876108030498627, 0.989144762920349, 0.8549845858850967], 
             UndirectedEdge[204, 400] -> 
             RGBColor[
              0.6053745649127336, 0.6905093694663436, 0.9620764497914807], 
             UndirectedEdge[69, 168] -> 
             RGBColor[
              0.6405499084532472, 0.7180022251702024, 0.9655730940805418], 
             UndirectedEdge[68, 86] -> 
             RGBColor[
              0.644964446818425, 0.7214346785013799, 0.9660241820644118], 
             UndirectedEdge[175, 264] -> 
             RGBColor[
              0.9678191400189857, 0.9742034708517513, 0.880394495816702], 
             UndirectedEdge[1, 92] -> 
             RGBColor[
              0.9862082182567236, 0.9638626074071637, 0.5094761448435691], 
             UndirectedEdge[368, 393] -> 
             RGBColor[
              0.7988320967863527, 0.8433178303555087, 0.9804391874279169], 
             UndirectedEdge[332, 361] -> 
             RGBColor[
              0.7970843900720741, 0.8185866874973222, 0.6663145859676359], 
             UndirectedEdge[80, 203] -> 
             RGBColor[
              0.8681461868181866, 0.8962022567661256, 0.9076840926150362], 
             UndirectedEdge[20, 347] -> 
             RGBColor[
              0.9665222110548872, 0.9742657561373818, 0.9286944397648524], 
             UndirectedEdge[18, 311] -> 
             RGBColor[
              0.8640282877361206, 0.8945940645851526, 0.9845077967284401], 
             UndirectedEdge[170, 282] -> 
             RGBColor[
              0.7913365002977917, 0.8365066264163203, 0.941542147422235], 
             UndirectedEdge[198, 323] -> 
             RGBColor[
              0.9796068980293688, 0.9471186625606187, 0.5623291917217752], 
             UndirectedEdge[168, 357] -> 
             RGBColor[
              0.7788973224995202, 0.8253620682359732, 0.8996084818965127], 
             UndirectedEdge[180, 326] -> 
             RGBColor[
              0.9502168903139813, 0.9610018434566253, 0.9131621283415778], 
             UndirectedEdge[18, 340] -> 
             RGBColor[
              0.8922101654305556, 0.9133350104953086, 0.8198107837739159], 
             UndirectedEdge[74, 340] -> 
             RGBColor[
              0.8058375707092218, 0.8454718770578395, 0.8114673892821027], 
             UndirectedEdge[173, 204] -> 
             RGBColor[
              0.6458999484196466, 0.7228659425845092, 0.9656385273331574], 
             UndirectedEdge[26, 30] -> 
             RGBColor[
              0.9369855073001621, 0.949273976100876, 0.8607680496700261], 
             UndirectedEdge[169, 240] -> 
             RGBColor[
              0.98295376211942, 0.9662999269978244, 0.6298769219475377], 
             UndirectedEdge[95, 371] -> 
             RGBColor[
              0.9401604107900203, 0.9525167369173372, 0.8919527203782582], 
             UndirectedEdge[65, 356] -> 
             RGBColor[
              0.9770420075807922, 0.9815093916218562, 0.8839278615077979], 
             UndirectedEdge[264, 310] -> 
             RGBColor[
              0.9214100623457913, 0.9399696811392946, 0.9853727710001107], 
             UndirectedEdge[96, 114] -> 
             RGBColor[
              0.9285961890081345, 0.9420125049009183, 0.8159319247946746], 
             UndirectedEdge[244, 308] -> 
             RGBColor[
              0.9601483465418945, 0.8668716853855986, 0.46327253477006], 
             UndirectedEdge[187, 298] -> 
             RGBColor[
              0.8161821539566436, 0.8545898986989922, 0.8589975628791952], 
             UndirectedEdge[58, 228] -> 
             RGBColor[
              0.42093032172346734`, 0.5377867990036908, 0.9483803761632403], 
             UndirectedEdge[36, 82] -> 
             RGBColor[
              0.8886585131890903, 0.9116882279256644, 0.8853145881955689], 
             UndirectedEdge[72, 355] -> 
             RGBColor[
              0.8749655667961589, 0.8304954916037468, 0.6272116569318722], 
             UndirectedEdge[22, 350] -> 
             RGBColor[
              0.5442746662565617, 0.6183662110165129, 0.9623285006858464], 
             UndirectedEdge[58, 192] -> 
             RGBColor[
              0.6653283433656998, 0.7304454988641025, 0.9026230506872424], 
             UndirectedEdge[3, 174] -> 
             RGBColor[
              0.8676950008182629, 0.897340456971866, 0.9872427178501592], 
             UndirectedEdge[44, 54] -> 
             RGBColor[
              0.9833884484467637, 0.9866878393106342, 0.8931256518604962], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.8015923678230921, 0.483385276289193, 0.5717547051312598], 
             UndirectedEdge[170, 271] -> 
             RGBColor[
              0.9860018465069983, 0.9875502419092308, 0.840038754021825], 
             UndirectedEdge[192, 201] -> 
             RGBColor[
              0.9619457018391915, 0.9706434815468823, 0.9270763876092525], 
             UndirectedEdge[274, 395] -> 
             RGBColor[
              0.9878173174731099, 0.9886054483230093, 0.8235861552471524], 
             UndirectedEdge[208, 284] -> 
             RGBColor[
              0.9678189895306561, 0.9029675799690455, 0.529649862712841], 
             UndirectedEdge[237, 320] -> 
             RGBColor[
              0.6106630371723407, 0.6948027894896529, 0.9624927777000691], 
             UndirectedEdge[119, 380] -> 
             RGBColor[
              0.988325616487183, 0.9894403566465484, 0.8431382773508248], 
             UndirectedEdge[342, 398] -> 
             RGBColor[
              0.9765592995554503, 0.9817514003068777, 0.9117042670253394], 
             UndirectedEdge[90, 264] -> 
             RGBColor[
              0.9239404803361226, 0.9419873677584183, 0.9856141245269593], 
             UndirectedEdge[212, 367] -> 
             RGBColor[
              0.8576061878497823, 0.8742528216300158, 0.6837270413226031], 
             UndirectedEdge[92, 284] -> 
             RGBColor[
              0.9692068157124438, 0.9029285481860936, 0.46209619088194887`], 
             UndirectedEdge[267, 342] -> 
             RGBColor[
              0.9603033398580754, 0.9699148763802437, 0.9520802704598605], 
             UndirectedEdge[107, 297] -> 
             RGBColor[
              0.9765341177488653, 0.939572352162843, 0.569876145491329], 
             UndirectedEdge[163, 245] -> 
             RGBColor[
              0.9202212028675953, 0.9060633106614835, 0.6642974512204809], 
             UndirectedEdge[72, 200] -> 
             RGBColor[
              0.8386931465432284, 0.8021592012215533, 0.6235963610660995], 
             UndirectedEdge[254, 286] -> 
             RGBColor[
              0.9634430954515204, 0.9715255212223032, 0.9140307170435074], 
             UndirectedEdge[269, 307] -> 
             RGBColor[
              0.6456246903478222, 0.721783398747215, 0.9662042136013056], 
             UndirectedEdge[240, 304] -> 
             RGBColor[
              0.9854631223600301, 0.9673376119449333, 0.5882903287444986], 
             UndirectedEdge[228, 332] -> 
             RGBColor[
              0.7382793318307279, 0.770846092079313, 0.6616852363728511], 
             UndirectedEdge[104, 109] -> 
             RGBColor[
              0.8354005459022085, 0.8715590249721468, 0.9476971404299335], 
             UndirectedEdge[28, 372] -> 
             RGBColor[
              0.8444182777024991, 0.878877629032724, 0.9849967164555156], 
             UndirectedEdge[28, 362] -> 
             RGBColor[
              0.8436502121397003, 0.8782651944015325, 0.9849234576764756], 
             UndirectedEdge[209, 227] -> 
             RGBColor[
              0.9081693491528336, 0.9282675612866301, 0.9435988047146808], 
             UndirectedEdge[245, 371] -> 
             RGBColor[
              0.9304341726977563, 0.9447612986742657, 0.8910250231063029], 
             UndirectedEdge[308, 397] -> 
             RGBColor[
              0.919385593886346, 0.8381189691976445, 0.6252760712952874], 
             UndirectedEdge[58, 87] -> 
             RGBColor[
              0.6682937581497697, 0.729797957383749, 0.7172717603015687], 
             UndirectedEdge[154, 332] -> 
             RGBColor[
              0.8761290186791728, 0.880740842978048, 0.673916873452165], 
             UndirectedEdge[97, 180] -> 
             RGBColor[
              0.9720378803467385, 0.9778970748645726, 0.8977613339252849], 
             UndirectedEdge[202, 300] -> 
             RGBColor[
              0.9661447547556483, 0.9734478796634578, 0.9053136221159702], 
             UndirectedEdge[25, 317] -> 
             RGBColor[
              0.9939961893354125, 0.9895667810038473, 0.587900444263243], 
             UndirectedEdge[93, 128] -> 
             RGBColor[
              0.9487516936437113, 0.8858627024388115, 0.615279845767768], 
             UndirectedEdge[68, 178] -> 
             RGBColor[
              0.7878257890171132, 0.834449235817022, 0.9794139329324546], 
             UndirectedEdge[271, 273] -> 
             RGBColor[
              0.9763780272588101, 0.9803728132714898, 0.8563293697149513], 
             UndirectedEdge[149, 318] -> 
             RGBColor[
              0.7183876928121171, 0.7464973265656676, 0.6479347768926376], 
             UndirectedEdge[42, 358] -> 
             RGBColor[
              0.896662957894121, 0.9204387196299076, 0.9900057074560551], 
             UndirectedEdge[155, 170] -> 
             RGBColor[
              0.9781189729489665, 0.959896209791633, 0.6443708142727522], 
             UndirectedEdge[193, 338] -> 
             RGBColor[
              0.8847581968986662, 0.9079515751283294, 0.8536520929901018], 
             UndirectedEdge[79, 109] -> 
             RGBColor[
              0.8134010699903427, 0.8543728671875876, 0.9455044382678297], 
             UndirectedEdge[173, 175] -> 
             RGBColor[
              0.8349863167479, 0.8696366640042488, 0.8744132709056968], 
             UndirectedEdge[95, 178] -> 
             RGBColor[
              0.8715052124721867, 0.9003786163192649, 0.9876061392391264], 
             UndirectedEdge[243, 348] -> 
             RGBColor[
              0.6913105301564366, 0.7569685247164802, 0.971377100110445], 
             UndirectedEdge[56, 83] -> 
             RGBColor[
              0.6769974003713428, 0.745893787708898, 0.9696226802640893], 
             UndirectedEdge[205, 207] -> 
             RGBColor[
              0.8353933159955397, 0.8715839703001032, 0.9841617543157134], 
             UndirectedEdge[74, 302] -> 
             RGBColor[
              0.7978267928747069, 0.8417745043960672, 0.9420199916391921], 
             UndirectedEdge[179, 196] -> 
             RGBColor[
              0.6983124049437295, 0.7625124193255737, 0.9720900754977269], 
             UndirectedEdge[174, 338] -> 
             RGBColor[
              0.8141783299172518, 0.8550368538190454, 0.9820402922482805], 
             UndirectedEdge[159, 167] -> 
             RGBColor[
              0.9689912132538936, 0.9756382149726988, 0.9035159138812268], 
             UndirectedEdge[251, 356] -> 
             RGBColor[
              0.9741657770370021, 0.9802534593306296, 0.9286147802186014], 
             UndirectedEdge[238, 277] -> 
             RGBColor[
              0.9139201245498174, 0.8428814278067431, 0.6267970905419398], 
             UndirectedEdge[163, 164] -> 
             RGBColor[
              0.9797582503806899, 0.9514228680635897, 0.5891387930779022], 
             UndirectedEdge[213, 230] -> 
             RGBColor[
              0.7704367100157941, 0.8197766670451987, 0.9462650890427592], 
             UndirectedEdge[246, 343] -> 
             RGBColor[
              0.9473706825002052, 0.9599174656639815, 0.9617589481589242], 
             UndirectedEdge[53, 95] -> 
             RGBColor[
              0.9210470432220437, 0.9394351052521499, 0.9768398795451694], 
             UndirectedEdge[139, 184] -> 
             RGBColor[
              0.6179716143036786, 0.696844585792433, 0.965280705343849], 
             UndirectedEdge[101, 308] -> 
             RGBColor[
              0.910603604080682, 0.831116448907371, 0.6244384372678482], 
             UndirectedEdge[3, 52] -> 
             RGBColor[
              0.912200120661706, 0.8600793811797902, 0.6307912332726904], 
             UndirectedEdge[136, 286] -> 
             RGBColor[
              0.9915961499167728, 0.9902048171597133, 0.7461964734688165], 
             UndirectedEdge[164, 169] -> 
             RGBColor[
              0.9873049088671089, 0.9890182678146584, 0.8600540441220974], 
             UndirectedEdge[14, 102] -> 
             RGBColor[
              0.8162649317154553, 0.8552175104423232, 0.8824313755337816], 
             UndirectedEdge[232, 281] -> 
             RGBColor[
              0.885582629161803, 0.9071642124504647, 0.739590632307092], 
             UndirectedEdge[56, 349] -> 
             RGBColor[
              0.8790431805977252, 0.9063891874898753, 0.988325117368164], 
             UndirectedEdge[225, 324] -> 
             RGBColor[
              0.9368595468001184, 0.8020652237268531, 0.5789607875914256], 
             UndirectedEdge[5, 272] -> 
             RGBColor[
              0.691946746302958, 0.7592733242927012, 0.9699304431276428], 
             UndirectedEdge[68, 371] -> 
             RGBColor[
              0.8564809873349468, 0.8865873564150943, 0.8837605140715864], 
             UndirectedEdge[151, 397] -> 
             RGBColor[
              0.9532850936442101, 0.9625761810165798, 0.8755823828924275], 
             UndirectedEdge[1, 356] -> 
             RGBColor[
              0.9711924905798883, 0.9550012489344425, 0.6566703958602231], 
             UndirectedEdge[96, 115] -> 
             RGBColor[
              0.9144718726672034, 0.9338506435354998, 0.9643692753953076], 
             UndirectedEdge[328, 347] -> 
             RGBColor[
              0.9811330684863251, 0.9601582998542009, 0.6228038709921068], 
             UndirectedEdge[80, 159] -> 
             RGBColor[
              0.8485046723607563, 0.8822731167086955, 0.9731513569078212], 
             UndirectedEdge[50, 121] -> 
             RGBColor[
              0.9777290859491543, 0.9814511990863737, 0.8572115358030318], 
             UndirectedEdge[108, 342] -> 
             RGBColor[
              0.9802897230304541, 0.9816542417988251, 0.7306864745869768], 
             UndirectedEdge[178, 315] -> 
             RGBColor[
              0.7110812487187415, 0.7733601013005218, 0.9725412498488535], 
             UndirectedEdge[146, 228] -> 
             RGBColor[
              0.7437388412420762, 0.7892622992775604, 0.6828943994940964], 
             UndirectedEdge[63, 152] -> 
             RGBColor[
              0.8818018593219623, 0.9072808566561759, 0.9276673524325039], 
             UndirectedEdge[43, 137] -> 
             RGBColor[
              0.8521922542026792, 0.8851434645131219, 0.9729914845743246], 
             UndirectedEdge[97, 141] -> 
             RGBColor[
              0.9116832416417482, 0.7300828905651329, 0.5861465818570162], 
             UndirectedEdge[25, 207] -> 
             RGBColor[
              0.9178912154975352, 0.9336375208734082, 0.8279516214874596], 
             UndirectedEdge[214, 310] -> 
             RGBColor[
              0.9143956266800569, 0.9345782683793415, 0.9916970652349979], 
             UndirectedEdge[37, 87] -> 
             RGBColor[
              0.9936088002040591, 0.9897512721838548, 0.6193755575548311], 
             UndirectedEdge[146, 262] -> 
             RGBColor[
              0.9639612741892745, 0.964387150382866, 0.7002838320886078], 
             UndirectedEdge[322, 364] -> 
             RGBColor[
              0.8974811493481318, 0.8380396672834369, 0.6270801588477971], 
             UndirectedEdge[219, 311] -> 
             RGBColor[
              0.9611794866345651, 0.9705683052115911, 0.9505971825029402], 
             UndirectedEdge[5, 260] -> 
             RGBColor[
              0.8528101779955619, 0.8832471351805838, 0.8619668976678201], 
             UndirectedEdge[204, 389] -> 
             RGBColor[
              0.42510515664463666`, 0.5315637733408518, 0.9497587340070834], 
             UndirectedEdge[275, 279] -> 
             RGBColor[
              0.9935607202535733, 0.9905800745351409, 0.6818627813847371], 
             UndirectedEdge[78, 289] -> 
             RGBColor[
              0.617711240255979, 0.7005248382708811, 0.9630476380652317], 
             UndirectedEdge[163, 329] -> 
             RGBColor[
              0.6790985798896452, 0.711598588870039, 0.6435364390541762], 
             UndirectedEdge[47, 181] -> 
             RGBColor[
              0.9703368423744065, 0.9751096231258836, 0.8172173777893407], 
             UndirectedEdge[267, 291] -> 
             RGBColor[
              0.958941974268755, 0.9688995721527602, 0.9543847073015685], 
             UndirectedEdge[28, 301] -> 
             RGBColor[
              0.8209307982776567, 0.8601493504899995, 0.9827564597004537], 
             UndirectedEdge[174, 193] -> 
             RGBColor[
              0.9246230148135475, 0.9393695612796875, 0.8575523926670103], 
             UndirectedEdge[60, 263] -> 
             RGBColor[
              0.9874338440435477, 0.9890715858235988, 0.8579172545749641], 
             UndirectedEdge[122, 385] -> 
             RGBColor[
              0.8801747492559076, 0.9072914696222968, 0.9884330473969447], 
             UndirectedEdge[282, 350] -> 
             RGBColor[
              0.39261644971575455`, 0.49859670752206786`, 0.9478010823734133],
              UndirectedEdge[142, 306] -> 
             RGBColor[
              0.9326793121518984, 0.9482363118862209, 0.9615138041406166], 
             UndirectedEdge[6, 289] -> 
             RGBColor[
              0.7385456329718438, 0.7957688624624752, 0.9745745096146506], 
             UndirectedEdge[3, 117] -> 
             RGBColor[
              0.9340212231814188, 0.9484961869178197, 0.9293484179959254], 
             UndirectedEdge[6, 132] -> 
             RGBColor[
              0.9160539339077908, 0.9328378189607257, 0.8698059679519379], 
             UndirectedEdge[22, 394] -> 
             RGBColor[
              0.9460408136461695, 0.9584649453541598, 0.9471982642119752], 
             UndirectedEdge[11, 391] -> 
             RGBColor[
              0.7868480300768643, 0.8329190771537713, 0.942701338063098], 
             UndirectedEdge[34, 249] -> 
             RGBColor[
              0.7504714533597551, 0.804324720836718, 0.964990386532699], 
             UndirectedEdge[269, 306] -> 
             RGBColor[
              0.852672433154564, 0.8851364959715406, 0.9536981129021298], 
             UndirectedEdge[69, 394] -> 
             RGBColor[
              0.8482562865229895, 0.8813684570974967, 0.9376394924703473], 
             UndirectedEdge[361, 369] -> 
             RGBColor[
              0.8049835326090544, 0.8443245621763454, 0.7741929939702734], 
             UndirectedEdge[85, 184] -> 
             RGBColor[
              0.909353040726796, 0.9264378881989601, 0.7953990485191291], 
             UndirectedEdge[73, 96] -> 
             RGBColor[
              0.9289458278736142, 0.9428129797093482, 0.8578137940970759], 
             UndirectedEdge[71, 382] -> 
             RGBColor[
              0.9429401574088109, 0.9566598875303944, 0.9708777975985239], 
             UndirectedEdge[122, 165] -> 
             RGBColor[
              0.9180785051229466, 0.8693033603706485, 0.6323678117439637], 
             UndirectedEdge[321, 331] -> 
             RGBColor[
              0.8341464001876973, 0.8705792768081102, 0.9475721389057691], 
             UndirectedEdge[296, 374] -> 
             RGBColor[
              0.7202721448946533, 0.7508259713840031, 0.6522419373429583], 
             UndirectedEdge[66, 297] -> 
             RGBColor[
              0.782630360452816, 0.788339156067863, 0.637667241778795], 
             UndirectedEdge[75, 145] -> 
             RGBColor[
              0.8696602705727929, 0.8958138373099349, 0.8251703199973592], 
             UndirectedEdge[105, 239] -> 
             RGBColor[
              0.9791151320753966, 0.9710994716073079, 0.664889873320532], 
             UndirectedEdge[92, 354] -> 
             RGBColor[
              0.9894854810674061, 0.9893070568830035, 0.7793625192035691], 
             UndirectedEdge[188, 369] -> 
             RGBColor[
              0.99406007665958, 0.9897034295302423, 0.5948541852320082], 
             UndirectedEdge[170, 251] -> 
             RGBColor[
              0.9811953250207586, 0.9854960847070866, 0.9167155890818471], 
             UndirectedEdge[53, 68] -> 
             RGBColor[
              0.8373676197669702, 0.873505724749907, 0.9686476732384975], 
             UndirectedEdge[274, 318] -> 
             RGBColor[
              0.7227170888807817, 0.7807377781665117, 0.934516978896127], 
             UndirectedEdge[179, 359] -> 
             RGBColor[
              0.345399992298639, 0.46426885725849854`, 0.9437195065642339], 
             UndirectedEdge[20, 328] -> 
             RGBColor[
              0.9617349146755998, 0.9459783327027007, 0.6684987894450529], 
             UndirectedEdge[307, 352] -> 
             RGBColor[
              0.7708706826286135, 0.8196599519668748, 0.9330163418252124], 
             UndirectedEdge[6, 216] -> 
             RGBColor[
              0.8571031258510959, 0.8888947833818339, 0.9862324553603123], 
             UndirectedEdge[297, 385] -> 
             RGBColor[
              0.916915349327258, 0.8942740500998391, 0.6505164878334151], 
             UndirectedEdge[40, 348] -> 
             RGBColor[
              0.5008604792310866, 0.605660126404078, 0.9538487181189108], 
             UndirectedEdge[229, 329] -> 
             RGBColor[
              0.6415044177193878, 0.714782138460571, 0.96790593697751], 
             UndirectedEdge[6, 213] -> 
             RGBColor[
              0.7039687326671531, 0.7676977771235196, 0.9718524893633063], 
             UndirectedEdge[189, 374] -> 
             RGBColor[
              0.9805558789606292, 0.9563865163905229, 0.6079487343571582], 
             UndirectedEdge[97, 140] -> 
             RGBColor[
              0.9154863917570518, 0.9349437811145298, 0.974319003456334], 
             UndirectedEdge[34, 386] -> 
             RGBColor[
              0.9343697325283775, 0.9501751365308937, 0.9821629284871249], 
             UndirectedEdge[162, 313] -> 
             RGBColor[
              0.7593896471466255, 0.8086353766152665, 0.8608889306734997], 
             UndirectedEdge[258, 392] -> 
             RGBColor[
              0.8279896193751852, 0.8624449800946118, 0.75570536527814], 
             UndirectedEdge[45, 273] -> 
             RGBColor[
              0.9749609488814017, 0.9797868149451783, 0.8798140257098928], 
             UndirectedEdge[226, 393] -> 
             RGBColor[
              0.9362118769107713, 0.9505628577606074, 0.9434486582365249], 
             UndirectedEdge[88, 168] -> 
             RGBColor[
              0.7815527666745851, 0.8252049098051337, 0.7643572695714926], 
             UndirectedEdge[188, 327] -> 
             RGBColor[
              0.7058483752973816, 0.7629853743699349, 0.7760308469454038], 
             UndirectedEdge[59, 349] -> 
             RGBColor[
              0.9613573776525226, 0.9695993586212854, 0.9018226742753485], 
             UndirectedEdge[260, 398] -> 
             RGBColor[
              0.9898719096612336, 0.9900797886119403, 0.817512197778347], 
             UndirectedEdge[248, 353] -> 
             RGBColor[
              0.6808104783560279, 0.744510876564676, 0.9277037431148869], 
             UndirectedEdge[30, 389] -> 
             RGBColor[
              0.5576391324136086, 0.6360127010909167, 0.9625442743341526], 
             UndirectedEdge[216, 311] -> 
             RGBColor[
              0.9070135960058613, 0.9286251115487505, 0.9886725958294972], 
             UndirectedEdge[66, 307] -> 
             RGBColor[
              0.5794272325325306, 0.669444156126092, 0.9600337807383008], 
             UndirectedEdge[94, 225] -> 
             RGBColor[
              0.7035195653543926, 0.7645996171151033, 0.9357237443264805], 
             UndirectedEdge[177, 324] -> 
             RGBColor[
              0.9311113046581234, 0.7977781941492357, 0.588691062156163], 
             UndirectedEdge[79, 320] -> 
             RGBColor[
              0.625005330286536, 0.7063199962642679, 0.9637083531043394], 
             UndirectedEdge[133, 234] -> 
             RGBColor[
              0.6094698949531119, 0.6751803238265695, 0.9054391164822921], 
             UndirectedEdge[35, 195] -> 
             RGBColor[
              0.9381108070915504, 0.9523306775548317, 0.9538301479128455], 
             UndirectedEdge[34, 86] -> 
             RGBColor[
              0.758356834011263, 0.8107264280819624, 0.9656111525826868], 
             UndirectedEdge[98, 131] -> 
             RGBColor[
              0.8906893556542124, 0.9156755313529177, 0.989435939941715], 
             UndirectedEdge[173, 261] -> 
             RGBColor[
              0.8320813331147974, 0.8684353786172869, 0.9225563675628589], 
             UndirectedEdge[103, 331] -> 
             RGBColor[
              0.8406286142199213, 0.8745901870367347, 0.8997207847740957], 
             UndirectedEdge[135, 322] -> 
             RGBColor[
              0.9655594472427147, 0.8884679476171097, 0.4591614325964633], 
             UndirectedEdge[50, 181] -> 
             RGBColor[
              0.9542556231119383, 0.965404499133202, 0.962317477413924], 
             UndirectedEdge[35, 153] -> 
             RGBColor[
              0.9115122089843595, 0.9322791093770806, 0.9914220422811248], 
             UndirectedEdge[121, 362] -> 
             RGBColor[
              0.9361727236485055, 0.9490058815269851, 0.877191309407478], 
             UndirectedEdge[84, 152] -> 
             RGBColor[
              0.800999920083171, 0.8437495566505875, 0.9198928663254491], 
             UndirectedEdge[295, 345] -> 
             RGBColor[
              0.9495897623926326, 0.8502478174127925, 0.5857444353942565], 
             UndirectedEdge[22, 266] -> 
             RGBColor[
              0.9432509711946809, 0.9564672439899534, 0.9556357939516613], 
             UndirectedEdge[271, 335] -> 
             RGBColor[
              0.957344894384379, 0.9658062428182728, 0.8756607345963672], 
             UndirectedEdge[175, 261] -> 
             RGBColor[
              0.9892122965711652, 0.9898070216479138, 0.828443693704737], 
             UndirectedEdge[59, 254] -> 
             RGBColor[
              0.9643027964766353, 0.9718810296894967, 0.8997832462224193], 
             UndirectedEdge[53, 270] -> 
             RGBColor[
              0.9231483153835711, 0.9411106026362384, 0.9770403007597637], 
             UndirectedEdge[214, 300] -> 
             RGBColor[
              0.9593204937839084, 0.9681982988789031, 0.9113160001994289], 
             UndirectedEdge[3, 386] -> 
             RGBColor[
              0.9007962786793375, 0.9237345174280354, 0.9903999472824081], 
             UndirectedEdge[299, 336] -> 
             RGBColor[
              0.6227751065440376, 0.6899062931036966, 0.9250543064382524], 
             UndirectedEdge[110, 351] -> 
             RGBColor[
              0.9008189309641074, 0.9212822030390817, 0.8907964353054032], 
             UndirectedEdge[172, 328] -> 
             RGBColor[
              0.9440237800795586, 0.9321505754996067, 0.6770241725870753], 
             UndirectedEdge[185, 302] -> 
             RGBColor[
              0.9761625374231189, 0.9817426399572005, 0.9252347857234209], 
             UndirectedEdge[370, 391] -> 
             RGBColor[
              0.8193368727491945, 0.8589974434919884, 0.9454624083201275], 
             UndirectedEdge[50, 364] -> 
             RGBColor[
              0.9104472510209712, 0.9307393430828446, 0.9673770091013931], 
             UndirectedEdge[73, 195] -> 
             RGBColor[
              0.98790194024584, 0.9886655514407116, 0.8233081883252894], 
             UndirectedEdge[80, 332] -> 
             RGBColor[
              0.8629726928835272, 0.8704630212747102, 0.6726055738497099], 
             UndirectedEdge[5, 267] -> 
             RGBColor[
              0.8326026735025661, 0.8697765459308915, 0.9678302246359005], 
             UndirectedEdge[136, 246] -> 
             RGBColor[
              0.9836514365305427, 0.985010642663191, 0.7923795670946547], 
             UndirectedEdge[59, 246] -> 
             RGBColor[
              0.9815068665229589, 0.9847117969609656, 0.8706612431740923], 
             UndirectedEdge[177, 200] -> 
             RGBColor[
              0.8502007059395602, 0.8833001210693024, 0.9582382234060391], 
             UndirectedEdge[17, 157] -> 
             RGBColor[
              0.6409820669891158, 0.7115490258388126, 0.9480298793169708], 
             UndirectedEdge[151, 386] -> 
             RGBColor[
              0.9568065938395571, 0.9653841296837733, 0.87591826672474], 
             UndirectedEdge[4, 188] -> 
             RGBColor[
              0.8655285112964124, 0.8921436616310989, 0.7893234020008861], 
             UndirectedEdge[241, 255] -> 
             RGBColor[
              0.8099211613907462, 0.8487249682227791, 0.8066949206647629], 
             UndirectedEdge[62, 345] -> 
             RGBColor[
              0.7846827403067794, 0.7212778934959383, 0.609645952316049], 
             UndirectedEdge[57, 114] -> 
             RGBColor[
              0.9817389937232182, 0.9835295213000027, 0.791266732532965], 
             UndirectedEdge[32, 137] -> 
             RGBColor[
              0.9713510206619422, 0.9746344564671134, 0.7177832732501925], 
             UndirectedEdge[152, 175] -> 
             RGBColor[
              0.9892029812476664, 0.9898031695222541, 0.8285980727223967], 
             UndirectedEdge[99, 235] -> 
             RGBColor[
              0.5656093225888561, 0.6582261543440678, 0.9589459842508627], 
             UndirectedEdge[156, 256] -> 
             RGBColor[
              0.919758217809844, 0.9371977736076751, 0.9312239161118449], 
             UndirectedEdge[48, 286] -> 
             RGBColor[
              0.9550489501380275, 0.9648991835532006, 0.9155504406997437], 
             UndirectedEdge[61, 262] -> 
             RGBColor[
              0.7779224979271646, 0.8269299138144819, 0.9757127711138373], 
             UndirectedEdge[146, 385] -> 
             RGBColor[
              0.9296026142777689, 0.9370711738893869, 0.699804116377202], 
             UndirectedEdge[29, 150] -> 
             RGBColor[
              0.9253403731703715, 0.9432459233167789, 0.9906819370221063], 
             UndirectedEdge[141, 220] -> 
             RGBColor[
              0.8776250376048014, 0.7034300368805704, 0.6003801798772996], 
             UndirectedEdge[152, 242] -> 
             RGBColor[
              0.9833328997908617, 0.9670337911691833, 0.6275823919261164], 
             UndirectedEdge[95, 151] -> 
             RGBColor[
              0.941217659075888, 0.952953936253585, 0.874431380210575], 
             UndirectedEdge[252, 293] -> 
             RGBColor[
              0.9854243561640406, 0.9878689689834839, 0.8745767828280923], 
             UndirectedEdge[93, 390] -> 
             RGBColor[
              0.9048859540720848, 0.926465858014595, 0.9724265334019246], 
             UndirectedEdge[229, 249] -> 
             RGBColor[
              0.7240439343846488, 0.7835820762310997, 0.9739089909755093], 
             UndirectedEdge[96, 153] -> 
             RGBColor[
              0.8950281801514239, 0.9191351922327406, 0.9898497808955733], 
             UndirectedEdge[202, 217] -> 
             RGBColor[
              0.9689234301680032, 0.9741002069472368, 0.8231570134057842], 
             UndirectedEdge[163, 304] -> 
             RGBColor[
              0.9808830666198037, 0.9518880084849219, 0.5704976770646721], 
             UndirectedEdge[18, 323] -> 
             RGBColor[
              0.8788615359794576, 0.869636987512461, 0.6548570000937993], 
             UndirectedEdge[152, 264] -> 
             RGBColor[
              0.9649048410623843, 0.9729983333391297, 0.9286919714915238], 
             UndirectedEdge[23, 169] -> 
             RGBColor[
              0.6544346508455567, 0.7212947966533847, 0.9123992599436317], 
             UndirectedEdge[290, 342] -> 
             RGBColor[
              0.9742310788012603, 0.9803021612794913, 0.9285042413651403], 
             UndirectedEdge[285, 330] -> 
             RGBColor[
              0.9726870009909974, 0.9768409962804717, 0.8115434515299151], 
             UndirectedEdge[55, 192] -> 
             RGBColor[
              0.9840890694530122, 0.9871579688568329, 0.8895934421542779], 
             UndirectedEdge[161, 170] -> 
             RGBColor[
              0.9864641879367411, 0.9877414319720621, 0.8323765600297234], 
             UndirectedEdge[42, 205] -> 
             RGBColor[
              0.8477569115851277, 0.8814423658223787, 0.9853410051001603], 
             UndirectedEdge[267, 398] -> 
             RGBColor[
              0.9696644051682377, 0.976609199362248, 0.9233755247464275], 
             UndirectedEdge[32, 199] -> 
             RGBColor[
              0.75614865031242, 0.8039483798694069, 0.7105322116122765], 
             UndirectedEdge[154, 385] -> 
             RGBColor[
              0.8220965158334633, 0.861352468087859, 0.9827950402454897], 
             UndirectedEdge[91, 190] -> 
             RGBColor[
              0.7973841742313428, 0.8414961425459309, 0.9441570320090888], 
             UndirectedEdge[94, 380] -> 
             RGBColor[
              0.7090214362559053, 0.7679757691584876, 0.8938479539327553], 
             UndirectedEdge[119, 288] -> 
             RGBColor[
              0.9910035942224118, 0.9893768342833873, 0.7136426440427857], 
             UndirectedEdge[65, 251] -> 
             RGBColor[
              0.9866677338863122, 0.9886882425398328, 0.867634017664049], 
             UndirectedEdge[198, 216] -> 
             RGBColor[
              0.9334929337729264, 0.9472002717277488, 0.8913167704682405], 
             UndirectedEdge[101, 182] -> 
             RGBColor[
              0.7179212679958578, 0.7786114198337015, 0.9734269922493177], 
             UndirectedEdge[11, 230] -> 
             RGBColor[
              0.7841069563422121, 0.8308747888505639, 0.947341260909337], 
             UndirectedEdge[53, 101] -> 
             RGBColor[
              0.9243324879847019, 0.9420548297248712, 0.9771532481995829], 
             UndirectedEdge[202, 264] -> 
             RGBColor[
              0.9433308251397092, 0.9572568026932284, 0.9808103107372574], 
             UndirectedEdge[336, 367] -> 
             RGBColor[
              0.9841860707350243, 0.9732174542318333, 0.6527739199768487], 
             UndirectedEdge[13, 132] -> 
             RGBColor[
              0.7470522141031735, 0.798489388725125, 0.8544871879713595], 
             UndirectedEdge[146, 307] -> 
             RGBColor[
              0.7732042336640303, 0.8131836322465045, 0.6852140231208415], 
             UndirectedEdge[75, 133] -> 
             RGBColor[
              0.9906208363314988, 0.9899719276717192, 0.7747482414646248], 
             UndirectedEdge[153, 369] -> 
             RGBColor[
              0.9606797936012746, 0.9672276433628637, 0.7892048359799866], 
             UndirectedEdge[20, 181] -> 
             RGBColor[
              0.9465778558610416, 0.9596784328886734, 0.9753139346872852], 
             UndirectedEdge[112, 394] -> 
             RGBColor[
              0.8621740702903455, 0.8922411355556297, 0.9390266870871933], 
             UndirectedEdge[279, 306] -> 
             RGBColor[
              0.982218534370693, 0.9847912547437214, 0.8492463077422934], 
             UndirectedEdge[34, 68] -> 
             RGBColor[
              0.8351013743096347, 0.8718155625984626, 0.9724838356662879], 
             UndirectedEdge[4, 284] -> 
             RGBColor[
              0.8403764436997452, 0.80472966307759, 0.6240421478702592], 
             UndirectedEdge[193, 235] -> 
             RGBColor[
              0.8045737126713615, 0.844875573392184, 0.8459576516556638], 
             UndirectedEdge[296, 316] -> 
             RGBColor[
              0.7062254419786749, 0.7684906292871678, 0.9638356423985232], 
             UndirectedEdge[117, 223] -> 
             RGBColor[
              0.6554753253565242, 0.7220207332639502, 0.9060171078441056], 
             UndirectedEdge[37, 110] -> 
             RGBColor[
              0.9024032240937849, 0.9219373489626796, 0.864540598127457], 
             UndirectedEdge[83, 349] -> 
             RGBColor[
              0.7303576941443588, 0.7884418375369121, 0.9747122327194562], 
             UndirectedEdge[192, 348] -> 
             RGBColor[
              0.7343790309040162, 0.789486382428873, 0.9072349209141177], 
             UndirectedEdge[97, 394] -> 
             RGBColor[
              0.9699719745255775, 0.9770427697161644, 0.9319987397748075], 
             UndirectedEdge[2, 352] -> 
             RGBColor[
              0.9797010852237658, 0.9575370707338988, 0.63251070235591], 
             UndirectedEdge[69, 350] -> 
             RGBColor[
              0.44649013913338165`, 0.5412697227598497, 0.9527697289442185], 
             UndirectedEdge[164, 304] -> 
             RGBColor[
              0.9898142691077187, 0.9900559527617672, 0.8184674509190583], 
             UndirectedEdge[141, 350] -> 
             RGBColor[
              0.524636460040699, 0.4008788765636775, 0.5726457172995357], 
             UndirectedEdge[114, 356] -> 
             RGBColor[
              0.9795308814306809, 0.9818827147676805, 0.7950044906763095], 
             UndirectedEdge[383, 390] -> 
             RGBColor[
              0.876416297328259, 0.9042945820756497, 0.9880745628968759], 
             UndirectedEdge[297, 307] -> 
             RGBColor[
              0.7605169687135195, 0.7703865084569568, 0.6359263945770546], 
             UndirectedEdge[40, 58] -> 
             RGBColor[
              0.43180979169277006`, 0.5466192428393075, 0.9492368478920356], 
             UndirectedEdge[173, 295] -> 
             RGBColor[
              0.829143553221395, 0.8665958175153345, 0.9432670309246458], 
             UndirectedEdge[161, 239] -> 
             RGBColor[
              0.9834791554434257, 0.9855151996260896, 0.8374294414197444], 
             UndirectedEdge[35, 369] -> 
             RGBColor[
              0.9448063081691753, 0.9545705569535916, 0.7876908087690453], 
             UndirectedEdge[303, 313] -> 
             RGBColor[
              0.7546688658527986, 0.8065750031886476, 0.9342786716695959], 
             UndirectedEdge[237, 349] -> 
             RGBColor[
              0.7771682985609509, 0.8264447949959988, 0.9783973349720242], 
             UndirectedEdge[21, 263] -> 
             RGBColor[
              0.9019317272295662, 0.5614154001870866, 0.5184373708275963], 
             UndirectedEdge[126, 274] -> 
             RGBColor[
              0.9852410474014941, 0.9875400944412754, 0.86628161750705], 
             UndirectedEdge[331, 346] -> 
             RGBColor[
              0.7824995188742478, 0.8304414633563716, 0.9788424187324059], 
             UndirectedEdge[106, 345] -> 
             RGBColor[
              0.8475922157093283, 0.7704232538101309, 0.6159161809017026]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.7445225655507209, 0.8003459538800796, 0.9751707094412947], 
             316 -> RGBColor[
              0.9458649014076854, 0.9591467126247161, 0.9765207806085152], 
             308 -> RGBColor[
              0.9255684846091039, 0.7426108748469336, 0.25896885946551296`], 
             160 -> RGBColor[
              0.9633155525078686, 0.9721613796424139, 0.9469813801546428], 
             245 -> RGBColor[
              0.8696153578424157, 0.8988716975362228, 0.9874258832174458], 
             155 -> RGBColor[
              0.9776387991989381, 0.9362325604176988, 0.3676313867566629], 
             213 -> RGBColor[
              0.5694640936248703, 0.6613556311265603, 0.9592494459473094], 
             352 -> 
             RGBColor[
              0.9844275244639928, 0.9878283954185637, 0.9077397501138644], 27 -> 
             RGBColor[
              0.981955030180212, 0.986062671571104, 0.9154296064097316], 367 -> 
             RGBColor[
              0.9843346131740308, 0.9588191132075722, 0.3936433596515283], 19 -> 
             RGBColor[
              0.9395701218919575, 0.7981227009044141, 0.27023490548396495`], 
             164 -> RGBColor[
              0.988689452868605, 0.9895908123404349, 0.8371085669322884], 190 -> 
             RGBColor[
              0.9761844310011338, 0.9817589681518366, 0.9251977256066013], 
             103 -> RGBColor[
              0.9891488590655819, 0.9897807886090856, 0.8294950173432545], 
             138 -> RGBColor[
              0.9846667435972657, 0.9879273186778234, 0.9037752699962612], 
             291 -> RGBColor[
              0.9644755030666472, 0.9730264688699063, 0.9450178864221886], 28 -> 
             RGBColor[
              0.8079335571347428, 0.8498831024469031, 0.9814909244729824], 
             337 -> RGBColor[
              0.9634803982717458, 0.9722843213432033, 0.9467023392750598], 
             195 -> RGBColor[
              0.9805828906308406, 0.9850393321418551, 0.9177522807555073], 
             114 -> RGBColor[
              0.9945217121298798, 0.990690821122708, 0.6451003572902687], 93 -> 
             RGBColor[
              0.9562384383455305, 0.966883279487853, 0.9589610884244897], 34 -> 
             RGBColor[
              0.9484937615024728, 0.9611073121790451, 0.972070806184563], 161 -> 
             RGBColor[
              0.9943292291744872, 0.9919230047785571, 0.743642878270605], 22 -> 
             RGBColor[
              0.907390286978203, 0.9289924006559637, 0.9910288896804945], 124 -> 
             RGBColor[
              0.9925914700950311, 0.9865622285875729, 0.43500542386999874`], 
             84 -> RGBColor[
              0.6157111578752769, 0.6989010812915425, 0.9628901842536797], 46 -> 
             RGBColor[
              0.9354165841772241, 0.7816553079498896, 0.26689287154262953`], 
             241 -> RGBColor[
              0.9945643986924516, 0.9907821233637756, 0.6497465261952793], 
             185 -> RGBColor[
              0.9736885631074309, 0.9798975539633215, 0.9294225789240389], 
             390 -> RGBColor[
              0.8535334697986391, 0.8860484365413371, 0.9858919783793595], 
             121 -> RGBColor[
              0.9929785801523532, 0.9913644766978081, 0.7660266279349873], 
             322 -> RGBColor[
              0.9365473884002766, 0.786138569876124, 0.2678027431638843], 126 -> 
             RGBColor[
              0.9900503416517303, 0.9901535748255037, 0.814555117928627], 236 -> 
             RGBColor[
              0.9949329922067446, 0.9915705076203275, 0.6898656555305827], 78 -> 
             RGBColor[
              0.5968045862777063, 0.6835518747372906, 0.9614017896804652], 
             376 -> RGBColor[
              0.9940642683866563, 0.9897123952106099, 0.5953104288559291], 
             254 -> RGBColor[
              0.9382943120189666, 0.953500579454312, 0.9893358137176727], 290 -> 
             RGBColor[
              0.9812639233572324, 0.9855472452341094, 0.9165994699915083], 
             251 -> RGBColor[
              0.9837915033425222, 0.9874323102486061, 0.9123209363748526], 
             165 -> RGBColor[
              0.9459181137547895, 0.8232903732976538, 0.27534264874331954`], 
             100 -> RGBColor[
              0.9332716730904277, 0.9496295154103408, 0.9934974793924647], 
             235 -> RGBColor[
              0.6139445435477608, 0.6974668641953965, 0.9627511099024961], 70 -> 
             RGBColor[
              0.7909273270619989, 0.83659770626194, 0.979795902391587], 234 -> 
             RGBColor[
              0.2324960928380912, 0.36169851304949097`, 0.9365516805887583], 
             257 -> RGBColor[
              0.9785107154311647, 0.9834939072708124, 0.9212599328587097], 
             135 -> RGBColor[
              0.9945715060851527, 0.9907973253580954, 0.6505201220290423], 
             265 -> RGBColor[
              0.9938624455510825, 0.9892807165727365, 0.5733432587098928], 
             111 -> RGBColor[
              0.8605412350658763, 0.8916362383447113, 0.9865603852864544], 
             381 -> RGBColor[
              0.9710507862479008, 0.9140096457948481, 0.34203820048373723`], 
             182 -> RGBColor[
              0.5402038124394555, 0.6376008166995948, 0.9569459694284519], 
             188 -> RGBColor[
              0.9941462605330693, 0.9898877681211097, 0.6042347679961092], 
             154 -> RGBColor[
              0.7740824296462154, 0.8234383443747678, 0.9781169604416979], 
             336 -> RGBColor[
              0.9840375282960178, 0.9876157952560943, 0.9119044803021691], 
             315 -> RGBColor[
              0.5682199065200533, 0.6603455439848797, 0.9591514989808106], 
             368 -> RGBColor[
              0.710269207288415, 0.7735869700704013, 0.9717566548055403], 269 -> 
             RGBColor[
              0.7339355399024102, 0.7920752889792442, 0.9741154936660508], 
             208 -> 
             RGBColor[
              0.9917958537215775, 0.9908753889239995, 0.7856274656908265], 86 -> 
             RGBColor[
              0.5682199065200533, 0.6603455439848797, 0.9591514989808106], 
             119 -> RGBColor[
              0.9880825005756676, 0.9893398219693428, 0.847167337168444], 377 -> 
             RGBColor[
              0.951109895282417, 0.8438740569960613, 0.27952007802722384`], 
             140 -> RGBColor[
              0.8757201747770849, 0.9037395128490867, 0.988008166106509], 85 -> 
             RGBColor[
              0.994177846116373, 0.9899553264900042, 0.6076726638151075], 351 -> 
             RGBColor[
              0.9909390853468326, 0.9905210931830996, 0.7998263349058281], 
             242 -> RGBColor[
              0.9803771172906582, 0.9454695503287343, 0.37826923545501423`], 
             117 -> RGBColor[
              0.9866955925584447, 0.9887662998623109, 0.8701519922167215], 47 -> 
             RGBColor[
              0.9946420302708916, 0.9909481694603022, 0.6581962444219095], 81 -> 
             RGBColor[
              0.28704782954116775`, 0.41903584710430103`, 0.9396583212919362],
              275 -> RGBColor[
              0.9940936981724785, 0.9897753425466759, 0.5985136794230964], 23 -> 
             RGBColor[
              0.32294893682550085`, 0.45414387001788753`, 0.941798998575357], 
             328 -> RGBColor[
              0.9763457721070377, 0.9318708764195197, 0.36260822067230725`], 
             110 -> RGBColor[
              0.8106987765813821, 0.852043312895064, 0.9817665357049784], 6 -> 
             RGBColor[
              0.838473371709436, 0.8740399231204791, 0.984455532779303], 218 -> 
             RGBColor[
              0.9121029186276023, 0.9327501252122163, 0.9914783846942302], 
             108 -> RGBColor[
              0.9933812118156202, 0.9882514062727769, 0.5209639364351812], 
             297 -> RGBColor[
              0.9637200966338049, 0.8892815083987278, 0.3135598556175487], 
             157 -> RGBColor[
              0.9590151971527306, 0.9689541816597377, 0.9542607600585846], 
             354 -> RGBColor[
              0.9843994560496594, 0.9878167884079115, 0.9082049163780959], 
             385 -> RGBColor[
              0.8701106020207112, 0.8992665918009504, 0.9874731200492813], 
             270 -> RGBColor[
              0.8932703783499986, 0.9177335687905429, 0.9896821201905451], 
             392 -> RGBColor[
              0.9935967779432975, 0.9887124804227996, 0.544426979112911], 33 -> 
             RGBColor[
              0.7909273270619989, 0.83659770626194, 0.979795902391587], 252 -> 
             RGBColor[
              0.981955030180212, 0.986062671571104, 0.9154296064097316], 394 -> 
             RGBColor[
              0.9846913403141361, 0.987937490052356, 0.9033676387434558], 260 -> 
             RGBColor[
              0.9938234544568546, 0.9917138539349987, 0.7520248742447877], 
             159 -> RGBColor[
              0.9492395666665885, 0.9616635324492987, 0.970808352578855], 183 -> 
             RGBColor[
              0.9766348131774412, 0.9820948624414935, 0.9244353460605975], 99 -> 
             RGBColor[
              0.5172741016299514, 0.6189854444927392, 0.9551408585992295], 
             329 -> RGBColor[
              0.38737011188651554`, 0.5099422539533337, 0.9459038588848365], 
             309 -> RGBColor[
              0.5099520680211195, 0.6130410877552342, 0.9545644412920493], 17 -> 
             RGBColor[
              0.32294893682550085`, 0.45414387001788753`, 0.941798998575357], 
             349 -> RGBColor[
              0.9324034743707412, 0.9489372373178893, 0.9934146698235308], 
             347 -> RGBColor[
              0.9859203648656126, 0.9884457232888819, 0.8829995213119063], 
             340 -> RGBColor[
              0.9946580674078366, 0.990982471274624, 0.659941787808624], 277 -> 
             RGBColor[
              0.896512604937052, 0.9203188322631631, 0.9899913666567881], 104 -> 
             RGBColor[
              0.6946166608032831, 0.7613590817924569, 0.9701965552532656], 79 -> 
             RGBColor[
              0.6506177089795514, 0.7269867662233386, 0.9658111509290582], 
             327 -> RGBColor[
              0.417550490061694, 0.53608298061876, 0.9478269258946983], 191 -> 
             RGBColor[
              0.9813513374165583, 0.9487558235711591, 0.3820538966781028], 50 -> 
             RGBColor[
              0.9624795917459554, 0.9715379214749391, 0.9483964436710762], 
             225 -> RGBColor[
              0.977564990595673, 0.982788587236985, 0.922860798320656], 61 -> 
             RGBColor[
              0.6170170740106069, 0.699961282841055, 0.9629929907555813], 196 -> 
             RGBColor[
              0.9204645538489085, 0.9394174661671442, 0.9922759249261582], 1 -> 
             RGBColor[
              0.9778449304282945, 0.936927889456232, 0.3684321676580958], 263 -> 
             RGBColor[
              0.9865444544591322, 0.9887038003741732, 0.8726567416551927], 
             201 -> RGBColor[
              0.9367123044445924, 0.9523207207956432, 0.9920137398874309], 
             371 -> 
             RGBColor[
              0.9912529875530969, 0.9906508998123086, 0.79462416299516], 293 -> 
             RGBColor[
              0.988893682147869, 0.9896752663958636, 0.8337239592464529], 362 -> 
             RGBColor[
              0.8793668671446577, 0.9066472863561619, 0.9883559908799687], 
             184 -> RGBColor[
              0.824528235337219, 0.8629204499079162, 0.9831254332231507], 106 -> 
             RGBColor[
              0.776436659784649, 0.8252774868517239, 0.9783516081003655], 206 -> 
             RGBColor[
              0.9940655679689777, 0.9897151748857875, 0.5954518803715274], 
             358 -> RGBColor[
              0.9275778389899361, 0.9450894066536182, 0.9929543964130141], 
             247 -> RGBColor[
              0.9595331005153829, 0.9693404331396148, 0.9533840847564448], 
             220 -> RGBColor[
              0.8871362006631254, 0.9128423420108478, 0.9890970368467261], 
             107 -> RGBColor[
              0.9893481388639258, 0.989863195926958, 0.8261924353651093], 375 -> 
             RGBColor[
              0.9937100041759063, 0.9916669393282873, 0.7539050390000167], 
             131 -> RGBColor[
              0.8742551829955619, 0.9025713681686429, 0.9878684338825737], 
             127 -> RGBColor[
              0.9949087837694928, 0.9915187282208943, 0.6872307165328807], 
             210 -> RGBColor[
              0.9609760964536265, 0.9704166171476678, 0.9509414690266145], 
             357 -> RGBColor[
              0.9885160608243886, 0.9895191102741792, 0.8399821218291805], 
             181 -> RGBColor[
              0.9460316544779214, 0.959271076791465, 0.9762385111567718], 194 -> 
             RGBColor[
              0.9950775046646745, 0.9918796051553888, 0.705594944748742], 118 -> 
             RGBColor[
              0.8990403893766601, 0.6344478125231008, 0.23746916496042506`], 
             348 -> RGBColor[
              0.4815789625742418, 0.5900065225596248, 0.9523308064971613], 
             276 -> RGBColor[
              0.9720207441607501, 0.9172815415918374, 0.34580630381397487`], 
             305 -> RGBColor[
              0.35528172475164843`, 0.48214890582634373`, 0.9438592152312494],
              343 -> RGBColor[
              0.9220389128887965, 0.9406728173307132, 0.9924260886968297], 
             280 -> RGBColor[
              0.9927164693170786, 0.9868295892841723, 0.4486108177840804], 
             189 -> RGBColor[
              0.9871534506816161, 0.9889556359626593, 0.8625640982169309], 
             168 -> 
             RGBColor[
              0.5692785841746516, 0.6612050261977673, 0.9592348419638447], 
             363 -> RGBColor[
              0.8160239436706616, 0.856203373897978, 0.982297298593922], 41 -> 
             RGBColor[
              0.9925675246959116, 0.9911944947029261, 0.7728388806256459], 14 -> 
             RGBColor[
              0.9909325457175354, 0.9905183888783244, 0.7999347134873006], 77 -> 
             RGBColor[
              0.9754683076224103, 0.981224884508529, 0.9264099356918899], 51 -> 
             RGBColor[
              0.9886150728045046, 0.9895600542724489, 0.8383412370838683], 
             179 -> RGBColor[
              0.4761602560385506, 0.5856073724840032, 0.9519042260692956], 
             223 -> RGBColor[
              0.32425505815460365`, 0.4552751666655896, 0.9418822234714898], 
             323 -> RGBColor[
              0.9679608085056407, 0.903586425308929, 0.3300342204483909], 292 -> 
             RGBColor[
              0.9563015591910871, 0.9669303549111182, 0.9588542412975156], 
             396 -> RGBColor[
              0.9739880964114023, 0.9801209454109825, 0.928915547171213], 321 -> 
             RGBColor[
              0.9761844310011338, 0.9817589681518366, 0.9251977256066013], 
             143 -> RGBColor[
              0.9904408597650498, 0.9903150641012191, 0.8080832221624422], 
             112 -> RGBColor[
              0.7396568002665549, 0.7965447810589033, 0.9746857354309308], 
             197 -> RGBColor[
              0.7288607828453182, 0.7881108501966617, 0.9736096893089008], 54 -> 
             RGBColor[
              0.9799131558507902, 0.9845398450394837, 0.9188859670433264], 71 -> 
             RGBColor[
              0.9238498943439057, 0.9421168447852353, 0.9925988217247003], 
             177 -> RGBColor[
              0.9660685063116828, 0.9742145280817505, 0.9423213474501309], 
             158 -> RGBColor[
              0.9434711879801027, 0.9573614850697708, 0.9805727130609632], 
             226 -> RGBColor[
              0.9850287675372524, 0.9880770248805988, 0.8977755964227563], 
             350 -> RGBColor[
              0.18115904553492043`, 0.3077400213770621, 0.9336281116911983], 
             203 -> RGBColor[
              0.9885225955814487, 0.989521812564159, 0.8398738239932851], 115 -> 
             RGBColor[
              0.9662730794480179, 0.9743670983918713, 0.9419750584915348], 
             173 -> RGBColor[
              0.6778553532915322, 0.7482650209736219, 0.9685259447638186], 
             212 -> RGBColor[
              0.7308777625255338, 0.7896865300524595, 0.973810722993678], 129 -> 
             RGBColor[
              0.9934651153184717, 0.9884308673814307, 0.5300963149281613], 
             279 -> RGBColor[
              0.9930277423346682, 0.9913848065236058, 0.7652118833463779], 26 -> 
             RGBColor[
              0.9949585195146193, 0.9921832325062259, 0.733213908783418], 40 -> 
             RGBColor[
              0.5201419958879313, 0.6213137302485312, 0.9553666297406604], 
             146 -> RGBColor[
              0.9890946265348266, 0.9748757559778233, 0.41213511270512243`], 
             386 -> RGBColor[
              0.9202457035542821, 0.9392429608827422, 0.9922550507896868], 
             192 -> RGBColor[
              0.9871790992337907, 0.9889662422981212, 0.8621390353310742], 
             300 -> RGBColor[
              0.9891488590655819, 0.9897807886090856, 0.8294950173432545], 
             221 -> RGBColor[
              0.9632425164670514, 0.972106909482758, 0.9471050111208961], 62 -> 
             RGBColor[
              0.6506177089795514, 0.7269867662233386, 0.9658111509290582], 
             286 -> RGBColor[
              0.9885918788840742, 0.9895504629902944, 0.838725620369342], 152 -> 
             RGBColor[
              0.986288682291065, 0.9885980320096325, 0.8768955483972186], 64 -> 
             RGBColor[
              0.7729250850973812, 0.8225342180170743, 0.9780016071530698], 
             307 -> RGBColor[
              0.5573138407932341, 0.6514915085151858, 0.9582929335365603], 37 -> 
             RGBColor[
              0.9941076716061876, 0.9918313850302954, 0.7473146605499355], 
             148 -> RGBColor[
              0.9921252677860053, 0.9910116101051957, 0.7801682221469873], 
             261 -> RGBColor[
              0.9863073129380626, 0.9886057362609518, 0.8765867903618991], 
             387 -> RGBColor[
              0.8847963770429275, 0.9109766301689222, 0.9888738623810465], 15 -> 
             RGBColor[
              0.8809029982702553, 0.9078721556185448, 0.9885025084380488], 
             136 -> RGBColor[
              0.9946004209494714, 0.9908591713291323, 0.653667326568291], 198 -> 
             RGBColor[
              0.9912529875530969, 0.9906508998123086, 0.7946241629951595], 63 -> 
             RGBColor[
              0.7773150363528595, 0.8259636813027191, 0.978439156467789], 310 -> 
             RGBColor[
              0.899299124857879, 0.9225407276099623, 0.9902571474143923], 171 -> 
             RGBColor[
              0.7149095373983315, 0.7772120312200832, 0.9722191595445464], 
             395 -> 
             RGBColor[
              0.995202881794962, 0.9922842825889716, 0.7291641934088315], 311 -> 
             RGBColor[
              0.9382943120189666, 0.953500579454312, 0.9893358137176727], 353 -> 
             RGBColor[
              0.37733843595916294`, 0.5012533204717535, 0.9452646493654083], 
             59 -> RGBColor[
              0.990311280934304, 0.9902614799246815, 0.8102306787271661], 397 -> 
             RGBColor[
              0.913202703163588, 0.9336270635483553, 0.9915832831250617], 229 -> 
             RGBColor[
              0.8956387235522602, 0.9196220229678084, 0.9899080150701836], 
             102 -> RGBColor[
              0.6415973177133751, 0.7199166320063219, 0.9649280375802627], 
             299 -> RGBColor[
              0.26151268479205736`, 0.39219679095129867`, 0.9382041325743357],
              128 -> RGBColor[
              0.9412649489418922, 0.8048421253897701, 0.27159860311104617`], 
             12 -> RGBColor[
              0.9936827400289926, 0.9888963446320015, 0.5537834216443298], 
             222 -> RGBColor[
              0.6515529603004157, 0.727717391663371, 0.9659043680403014], 92 -> 
             RGBColor[
              0.9945715060851527, 0.9907973253580954, 0.6505201220290423], 
             271 -> RGBColor[
              0.9934045463150017, 0.9915406246528944, 0.7589672662548084], 
             361 -> RGBColor[
              0.6159931724320181, 0.6991300334133161, 0.9629123854726397], 
             344 -> RGBColor[
              0.8540689114338086, 0.8864753831670453, 0.9859430492805163], 
             132 -> RGBColor[
              0.9936344961061455, 0.9916357148009723, 0.7551564031245727], 80 -> 
             RGBColor[
              0.7477697780549243, 0.8028827009680923, 0.9754943612367875], 
             324 -> RGBColor[
              0.8961541030045639, 0.621341860216721, 0.235060776862195], 244 -> 
             RGBColor[
              0.9947282084746851, 0.9911324959242636, 0.667576210074607], 150 -> 
             RGBColor[
              0.9126787153976625, 0.9332092499270754, 0.9915333047041783], 
             125 -> RGBColor[
              0.8783856108367084, 0.9058648592116961, 0.9882623977773387], 
             258 -> RGBColor[
              0.662382460807073, 0.736177479766424, 0.966983751443369], 133 -> 
             RGBColor[
              0.9864436970681325, 0.988662134603648, 0.874326552375826], 255 -> 
             RGBColor[
              0.6252779240890408, 0.7066678130817827, 0.9636433151342465], 
             326 -> RGBColor[
              0.9116106286715042, 0.9323575865640785, 0.9914314296387451], 
             176 -> RGBColor[
              0.8249728752937204, 0.8632749937398003, 0.9831678433791367], 
             230 -> RGBColor[
              0.9714093264067177, 0.9781977029638371, 0.933280732138209], 274 -> 
             RGBColor[
              0.9804317531512577, 0.9849266140570472, 0.9180081170854731], 87 -> 
             RGBColor[
              0.9931099288019304, 0.9876711593374142, 0.4914364545597267], 
             130 -> RGBColor[
              0.8999779647492012, 0.9230820161126846, 0.9903218957692341], 35 -> 
             RGBColor[
              0.8956387235522602, 0.9196220229678084, 0.9899080150701836], 
             379 -> RGBColor[
              0.9585426572444645, 0.8718167896179038, 0.2934464812673503], 31 -> 
             RGBColor[
              0.6980287925808034, 0.7640246650702178, 0.9705366446606646], 18 -> 
             RGBColor[
              0.7897622634532746, 0.8356875497159931, 0.9796797797392077], 24 -> 
             RGBColor[
              0.9917366213473762, 0.9908508948150647, 0.786609099419813], 151 -> 
             RGBColor[
              0.9933674841248321, 0.9915252984848043, 0.7595814826597933], 
             137 -> RGBColor[
              0.94982806604363, 0.962102434321117, 0.9698121766387433], 330 -> 
             RGBColor[
              0.9946113486462729, 0.9908825445676307, 0.6548567389271938], 
             296 -> RGBColor[
              0.4665859825496642, 0.5778345459496197, 0.9511505041885311], 
             266 -> RGBColor[
              0.9791116554111589, 0.9839420873239432, 0.9202426982228282], 
             302 -> RGBColor[
              0.978636511738807, 0.9835877259510795, 0.921046992522803], 283 -> 
             RGBColor[
              0.45900122163566676`, 0.5716768953500513, 0.9505534040254865], 
             388 -> RGBColor[
              0.44896778439005025`, 0.5632950618868555, 0.9498288081080787], 
             284 -> RGBColor[
              0.9438421253397349, 0.8150597710140917, 0.2736722597348554], 
             318 -> RGBColor[
              0.4650024246103056, 0.5765489422759762, 0.9510258407067809], 
             238 -> RGBColor[
              0.9313276441625827, 0.765444023350323, 0.26360281442709127`], 
             72 -> RGBColor[
              0.9430533875190191, 0.811932688386252, 0.27303762277025145`], 
             288 -> RGBColor[
              0.993924687869156, 0.9894138465974319, 0.5801179509171274], 382 -> 
             RGBColor[
              0.962030420473716, 0.9712029302755535, 0.9491567734723474], 389 -> 
             RGBColor[
              0.23626576974151248`, 0.36566068248630706`, 0.9367663581116709],
              172 -> RGBColor[
              0.9117017880520794, 0.9324302745796937, 0.9914401245018433], 
             243 -> RGBColor[
              0.9010420977386313, 0.9239305268733357, 0.9904233937237288], 88 -> 
             RGBColor[
              0.9938269491745185, 0.9892047934125002, 0.5694796971791405], 
             273 -> RGBColor[
              0.9593515082026185, 0.9692050018900853, 0.9536914731750943], 
             202 -> RGBColor[
              0.9431406504457148, 0.9571149707178299, 0.981132226888686], 393 -> 
             RGBColor[
              0.8873949862842903, 0.9130486906406161, 0.9891217200502935], 98 -> 
             RGBColor[
              0.9071235283128627, 0.9287796945371924, 0.9910034460008561], 30 -> 
             RGBColor[
              0.8790124950857048, 0.9063647196955262, 0.9883221905566342], 
             116 -> RGBColor[0.178927, 0.305394, 0.933501], 373 -> 
             RGBColor[
              0.5572390848873063, 0.6514308183030384, 0.9582870484778058], 
             240 -> RGBColor[
              0.9799871593732274, 0.9441541307067669, 0.3767543225831691], 
             317 -> RGBColor[
              0.9932308332948847, 0.9879297618225242, 0.5045961624817686], 
             391 -> RGBColor[
              0.9768914738760224, 0.9822862795702519, 0.9240008864457308], 73 -> 
             RGBColor[
              0.9952209898608393, 0.992291770739568, 0.7288640958950715], 303 -> 
             RGBColor[
              0.9835406732141534, 0.9872452415495654, 0.912745526355206], 29 -> 
             RGBColor[
              0.9380020309430805, 0.9532825967064824, 0.9898305693400342], 
             360 -> RGBColor[
              0.9394727003819683, 0.9543794195660047, 0.9873411095920183], 
             320 -> RGBColor[
              0.5993929515935207, 0.6856532263051973, 0.9616055552796207], 75 -> 
             RGBColor[
              0.9947979755948649, 0.9912817207397903, 0.6751699305534237], 
             200 -> RGBColor[
              0.7343329055674375, 0.7923857140568544, 0.9741550993619474], 
             301 -> RGBColor[
              0.8339280394205706, 0.870415598533096, 0.984021994927925], 156 -> 
             RGBColor[
              0.9863073129380626, 0.9886057362609518, 0.8765867903618991], 25 -> 
             RGBColor[
              0.9947615453759402, 0.9912038001851704, 0.6712047260447171], 38 -> 
             RGBColor[
              0.985246125215471, 0.9881669078663796, 0.8941734171910355], 365 -> 
             RGBColor[
              0.8789578871296657, 0.9063211767936741, 0.988316982001038], 380 -> 
             RGBColor[
              0.9885687323986982, 0.9895408913237539, 0.8391092175332057], 
             370 -> RGBColor[
              0.6617822716223668, 0.7357086074137248, 0.9669239301945243], 3 -> 
             RGBColor[
              0.8813468538043928, 0.9082260739733286, 0.9885448437751293], 57 -> 
             RGBColor[
              0.9689562753165564, 0.9763682214772974, 0.9374331077756614], 
             227 -> RGBColor[
              0.9846898098823863, 0.9879368571794972, 0.9033930019581802], 39 -> 
             RGBColor[
              0.9202457035542821, 0.9392429608827422, 0.9922550507896868], 
             109 -> RGBColor[
              0.9761844310011338, 0.9817589681518366, 0.9251977256066013], 
             256 -> RGBColor[
              0.8532091226816253, 0.8857898109543982, 0.9858610418617906], 
             339 -> RGBColor[
              0.7964682040280554, 0.8409262814600479, 0.9803481652251242], 
             287 -> RGBColor[
              0.9898174081297815, 0.9900572508280593, 0.8184154291999515], 
             239 -> RGBColor[
              0.9726290817123641, 0.9791073944736222, 0.9312160045688838], 
             285 -> RGBColor[
              0.9507626533357217, 0.9627994479933127, 0.9682301641326365], 
             345 -> RGBColor[
              0.9187477716340074, 0.7155690207685379, 0.25348075370303974`], 
             366 -> RGBColor[
              0.9382022007992172, 0.9534318830574411, 0.9894917339862547], 
             216 -> RGBColor[
              0.875732879992756, 0.9037496436431889, 0.9880093779413217], 21 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 355 -> 
             RGBColor[
              0.8068777460732985, 0.8490582948212416, 0.9813856910934929], 
             175 -> RGBColor[
              0.9921172802042678, 0.9910083070348757, 0.7803005970475749], 7 -> 
             RGBColor[
              0.9538668311047943, 0.9651145386908624, 0.9629756008688234], 13 -> 
             RGBColor[
              0.5004699321002015, 0.6053430626492777, 0.9538179728181463], 
             294 -> RGBColor[
              0.6925484911340508, 0.7597434119281811, 0.9699904194287811], 
             193 -> RGBColor[
              0.995202881794962, 0.9922842825889716, 0.7291641934088315], 60 -> 
             RGBColor[
              0.9883232336279633, 0.9894393712730244, 0.8431777674947356], 65 -> 
             RGBColor[
              0.9895439644301023, 0.9899441748310595, 0.8229470989532455], 69 -> 
             RGBColor[
              0.7118212327318428, 0.7747994241426375, 0.9719113461972388], 
             217 -> RGBColor[
              0.9947062098902915, 0.9910854431766436, 0.6651817999228824], 
             214 -> RGBColor[
              0.9294921285022348, 0.9466158091487207, 0.9931369830556035], 
             170 -> RGBColor[
              0.9785991466989948, 0.9835598591655672, 0.9211102417888417], 
             359 -> RGBColor[
              0.21463972855872734`, 0.3429303420329939, 0.9355347870591721], 
             74 -> RGBColor[
              0.6170170740106069, 0.699961282841055, 0.9629929907555813], 246 -> 
             RGBColor[
              0.9727024521116139, 0.9791621139972497, 0.9310918076210186], 
             264 -> RGBColor[
              0.9435209998337035, 0.9573986346686268, 0.980488394585829], 278 -> 
             RGBColor[
              0.9949179168218414, 0.9915382628963746, 0.6882247929183534], 45 -> 
             RGBColor[
              0.9905703895601848, 0.9903686280002713, 0.8059365782446911], 
             306 -> RGBColor[
              0.9714093264067177, 0.9781977029638371, 0.933280732138209], 237 -> 
             RGBColor[
              0.6219331227511606, 0.7039523526741084, 0.9633800001205176], 
             228 -> RGBColor[
              0.4983830559493258, 0.6036488425772977, 0.9536536862830701], 
             180 -> RGBColor[
              0.9888231519564583, 0.9896461003491721, 0.8348928270444107], 
             383 -> RGBColor[
              0.899299124857879, 0.9225407276099623, 0.9902571474143923], 53 -> 
             RGBColor[
              0.9530262524171437, 0.9644876364819339, 0.9643984813289823], 
             304 -> RGBColor[
              0.9909390853468326, 0.9905210931830996, 0.7998263349058281], 48 -> 
             RGBColor[
              0.9215060213919809, 0.9402479041161067, 0.9923752610301455], 5 -> 
             RGBColor[
              0.7117969015342693, 0.774780416426169, 0.9719089210908526], 101 -> 
             RGBColor[
              0.8956387235522602, 0.9196220229678084, 0.9899080150701836], 
             333 -> RGBColor[
              0.9932224360897383, 0.9879118010498035, 0.5036821785231166], 
             267 -> RGBColor[
              0.9534084454708629, 0.9647726754356141, 0.9637515281809486], 
             120 -> RGBColor[
              0.9887956347786135, 0.989634721288974, 0.8353488578934728], 147 -> 
             RGBColor[
              0.7207270807360368, 0.7817567402904655, 0.9727989978964154], 89 -> 
             RGBColor[
              0.993349290659074, 0.9915177750191626, 0.7598829954705856], 43 -> 
             RGBColor[
              0.7545564423617284, 0.8081844947051268, 0.9761707925099059], 
             199 -> RGBColor[
              0.5194233253445855, 0.620730281125704, 0.9553100533629113], 268 -> 
             RGBColor[
              0.984323663289878, 0.9877854461539568, 0.9094609985530487], 169 -> 
             RGBColor[
              0.9859203648656126, 0.9884457232888819, 0.8829995213119063], 20 -> 
             RGBColor[
              0.9471240572441619, 0.9600857889858817, 0.9743893582177987], 4 -> 
             RGBColor[
              0.7369107620597555, 0.7943995551410882, 0.9744120360056631], 
             167 -> RGBColor[
              0.9887428598411986, 0.9896128974960989, 0.8362234751835984], 
             142 -> RGBColor[
              0.8939492978970791, 0.9182749208086047, 0.9897468761430244], 16 -> 
             RGBColor[
              0.2370133891455966, 0.3664464778818075, 0.9368089339307297], 
             281 -> RGBColor[
              0.7779704342202024, 0.8264756830978957, 0.9785044804021644], 
             289 -> RGBColor[
              0.6386178942342517, 0.7174978018044714, 0.9646934864499983], 
             398 -> RGBColor[
              0.9859203648656126, 0.9884457232888819, 0.8829995213119063], 
             178 -> RGBColor[
              0.8539425909174297, 0.8863746586161639, 0.9859310007168964], 58 -> 
             RGBColor[
              0.3434775874976088, 0.4719247554300838, 0.9431070660434107], 
             186 -> RGBColor[
              0.9793765250811989, 0.9420943178560046, 0.37438212366724843`], 
             122 -> RGBColor[
              0.8902388964911038, 0.9153163474436432, 0.989392974744608], 249 -> 
             RGBColor[
              0.5524491452170374, 0.6475421294943909, 0.9579099668808351], 
             113 -> RGBColor[
              0.942934216198286, 0.9569610123941025, 0.9814816662229082], 52 -> 
             RGBColor[
              0.9430533875190191, 0.811932688386252, 0.27303762277025145`], 
             187 -> RGBColor[
              0.6386178942342517, 0.7174978018044714, 0.9646934864499983], 
             259 -> RGBColor[
              0.8819600026222219, 0.9087149821971842, 0.9886033264567382], 42 -> 
             RGBColor[
              0.865748076798306, 0.8957880326061971, 0.9870570184990961], 134 -> 
             RGBColor[
              0.9806915889284761, 0.9851203991542545, 0.9175682828906669], 
             313 -> RGBColor[
              0.5257970584914438, 0.6259047648277298, 0.9558118169839859], 
             248 -> RGBColor[
              0.9842825207528929, 0.9877684326575985, 0.9101428368643654], 
             174 -> 
             RGBColor[
              0.854043147832133, 0.8864548399704035, 0.985940591925189], 215 -> 
             RGBColor[
              0.5806874153631142, 0.6704672293185492, 0.9601329869469262], 
             399 -> RGBColor[
              0.9852365285996976, 0.9881629394191356, 0.8943324579496457], 83 -> 
             RGBColor[
              0.5283119139179765, 0.627946437755935, 0.9560097956153815], 95 -> 
             RGBColor[
              0.8890678340269438, 0.9143825740223658, 0.9892812777613565], 
             166 -> RGBColor[
              0.536728431988765, 0.6347793462856193, 0.9566723747486354], 384 -> 
             RGBColor[
              0.44324508179045985`, 0.5583383445264862, 0.9494641625588199], 
             233 -> RGBColor[
              0.9944611473371561, 0.9905612791551118, 0.6385082533648669], 
             295 -> RGBColor[
              0.9804317531512577, 0.9849266140570472, 0.9180081170854731], 
             141 -> RGBColor[
              0.8681138745464775, 0.49401773175029295`, 0.21166332290787318`],
              319 -> RGBColor[
              0.9901714963580769, 0.9902036754101119, 0.8125472709061358], 
             205 -> RGBColor[
              0.8297657463719493, 0.8670966990385603, 0.9836249917012246], 
             224 -> RGBColor[
              0.8260508822776751, 0.8641345672470856, 0.9832706646476144], 
             231 -> RGBColor[
              0.3015645098706708, 0.434293798541302, 0.9404850247611973], 332 -> 
             RGBColor[
              0.9781756077121301, 0.9380433415813282, 0.3697167864626322], 68 -> 
             RGBColor[
              0.7217089871167968, 0.7825238130178801, 0.9728968651480128], 10 -> 
             RGBColor[
              0.48413013149251494`, 0.592077676416329, 0.9525316438596474], 
             250 -> RGBColor[
              0.9861112694144875, 0.9885246672258647, 0.8798357388919155], 
             282 -> RGBColor[
              0.6040738538965886, 0.6894533936670736, 0.9619740530556283], 
             374 -> RGBColor[
              0.9739583072396424, 0.9238173968183864, 0.3533333704973856], 
             232 -> RGBColor[
              0.9931948241034035, 0.9878527418030338, 0.5006767842120194], 
             253 -> RGBColor[
              0.9874529243737324, 0.9890794760304723, 0.8576010441254921], 55 -> 
             RGBColor[
              0.9809990396722337, 0.9853496954155446, 0.9170478489774817], 
             325 -> RGBColor[
              0.9816931697688095, 0.9858673765050371, 0.9158728677821026], 91 -> 
             RGBColor[
              0.6185839174615517, 0.701233316940025, 0.9631163384115764], 105 -> 
             RGBColor[
              0.9856011824384292, 0.9630915487409937, 0.3985637420721802], 36 -> 
             RGBColor[
              0.7858657356461842, 0.832643552578386, 0.9792914102625196], 123 -> 
             RGBColor[
              0.9482399441866969, 0.8324956572560405, 0.277210848009197], 94 -> 
             RGBColor[
              0.42947414011311225`, 0.5464106469932215, 0.9485866903323049], 
             312 -> RGBColor[
              0.8193840423227519, 0.8588283085026864, 0.9826322018256551], 96 -> 
             RGBColor[
              0.8626706658863891, 0.8933341886791284, 0.9867634922990803], 2 -> 
             RGBColor[
              0.9749746459835387, 0.927245746049234, 0.3572816545979557], 262 -> 
             RGBColor[
              0.9388279218437222, 0.9538985447879087, 0.9884325514720932], 
             272 -> RGBColor[
              0.6720965910716467, 0.7437662321592334, 0.967951965164433], 97 -> 
             RGBColor[
              0.9552526087370188, 0.9661480493799729, 0.9606298408061591], 
             372 -> RGBColor[
              0.8809029982702553, 0.9078721556185448, 0.9885025084380488], 
             356 -> RGBColor[
              0.9645400507314821, 0.973074608412653, 0.9449086240623503], 346 -> 
             RGBColor[
              0.8728906683742349, 0.9014833412483594, 0.987738285259875], 341 -> 
             RGBColor[
              0.9931797461365827, 0.9878204915566202, 0.49903564057398847`], 
             209 -> RGBColor[
              0.831648888423281, 0.8685982653937631, 0.9838046074711814], 378 -> 
             RGBColor[
              0.9939361985271896, 0.9894384667310598, 0.5813708150085425], 66 -> 
             RGBColor[
              0.6015406242718271, 0.6873968037369981, 0.9617746279400412], 
             139 -> RGBColor[
              0.41141499327013836`, 0.5307687216769499, 0.9474359774645472], 
             56 -> RGBColor[
              0.8256828868247093, 0.8638411376618612, 0.9832355649127971], 
             335 -> RGBColor[
              0.9212852424537563, 0.9400718609836511, 0.992354202937926], 314 -> 
             RGBColor[
              0.8006434331390562, 0.8441880021744782, 0.9807643130431744], 
             144 -> RGBColor[
              0.9530287416799972, 0.8514816435448103, 0.28106402687983073`], 
             298 -> RGBColor[
              0.9937464136790355, 0.9916819955935128, 0.753301639308392], 204 -> 
             RGBColor[
              0.6139445435477608, 0.6974668641953965, 0.9627511099024961], 
             207 -> 
             RGBColor[
              0.84102088561913, 0.8760712415616461, 0.9846985169302022], 334 -> 
             RGBColor[
              0.9332000412304892, 0.9495723981096208, 0.9934906470817172], 
             149 -> RGBColor[
              0.9717729610139286, 0.916445710855359, 0.3448437130784944], 219 -> 
             RGBColor[
              0.9840646612501637, 0.9876360309688702, 0.9118585512882077], 
             400 -> RGBColor[
              0.5968045862777063, 0.6835518747372906, 0.9614017896804652], 9 -> 
             RGBColor[
              0.9934883188350759, 0.9915752667428006, 0.7575789388008463], 11 -> 
             RGBColor[
              0.5968045862777063, 0.6835518747372906, 0.9614017896804652], 44 -> 
             RGBColor[
              0.9868637410427372, 0.9888358335817848, 0.8673653366776661], 
             153 -> RGBColor[
              0.9273856944164587, 0.9449361957863528, 0.9929360694920663], 32 -> 
             RGBColor[
              0.9928739752802545, 0.9871664786131098, 0.46575436986164187`], 
             162 -> RGBColor[
              0.9929822358018073, 0.9913659884028033, 0.7659660443630135], 90 -> 
             RGBColor[
              0.9043599608385418, 0.9265761008482096, 0.9907398544680895], 
             331 -> RGBColor[
              0.6921083693742608, 0.7593995854643838, 0.9699465522049369], 8 -> 
             RGBColor[
              0.990414012565445, 0.9903039620942409, 0.80852814973822], 364 -> 
             RGBColor[
              0.858414910295987, 0.8899407646907499, 0.9863575745317099], 342 -> 
             RGBColor[
              0.967198234245288, 0.9750570773248733, 0.9404090127387724], 163 -> 
             RGBColor[
              0.9708270478927749, 0.9132549237867443, 0.34116901922351606`], 
             49 -> RGBColor[
              0.5427163088699138, 0.6396405744885153, 0.9571437623510353], 
             338 -> RGBColor[
              0.7743135120023705, 0.8236188676676871, 0.9781399925713721], 76 -> 
             RGBColor[
              0.9544487701962449, 0.9655485479124284, 0.9619905297810208], 
             369 -> RGBColor[
              0.9939738927860906, 0.9895190909393747, 0.585473602467907], 82 -> 
             RGBColor[
              0.9914512907319964, 0.9907329032729428, 0.7913377661286182], 67 -> 
             RGBColor[
              0.937570522914108, 0.9529607787250043, 0.9905609998777664], 211 -> 
             RGBColor[
              0.9514928175281536, 0.9633440032524943, 
               0.9669941866121703]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9l3k0VX/Yxa95Hq55dufJNVwqktwdKpWiSIU0EZFIxkiFhGRKk6SkQSmp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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 7}], {
             RGBColor[
             0.9658558807665444, 0.9510212140735472, 0.6657038842634595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 35}], {
             RGBColor[
             0.9367418269902773, 0.9282749562120202, 0.6791700913641396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 41}], {
             RGBColor[
             0.985206227562103, 0.964061192079579, 0.5706355241418708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 57}], {
             RGBColor[
             0.9734006028724254, 0.9566480554667647, 0.6529326377168785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 92}], {
             RGBColor[
             0.9862082182567236, 0.9638626074071637, 0.5094761448435691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 96}], {
             RGBColor[
             0.9202577981573418, 0.9151310390676801, 0.6775978299785881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 114}], {
             RGBColor[
             0.9861833212790871, 0.96380935528947, 0.5067662624741822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 153}], {
             RGBColor[
             0.9526153124223766, 0.9409320426212924, 0.6806841185750809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 154}], {
             RGBColor[
             0.875963680037255, 0.8801831169154999, 0.6732745640498969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 161}], {
             RGBColor[
             0.9860870798013908, 0.9644254471173945, 0.5560375229643504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 188}], {
             RGBColor[
             0.9859955954806818, 0.9634078287886708, 0.4863334678271025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 203}], {
             RGBColor[
             0.9831837630048716, 0.9632248510101955, 0.6041529958256905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 222}], {
             RGBColor[
             0.814698945364355, 0.8323226405598014, 0.6671682678491986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 312}], {
             RGBColor[
             0.8986144863755232, 0.8978780989794592, 0.6755321847418754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 327}], {
             RGBColor[
             0.6976977102449942, 0.736505435037496, 0.658129546776397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 337}], {
             RGBColor[
             0.9706626643500201, 0.9546061053997177, 0.6575672534665777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 356}], {
             RGBColor[
             0.9711924905798883, 0.9550012489344425, 0.6566703958602231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 361}], {
             RGBColor[
             0.7969190514301563, 0.818028961434774, 0.6656722765653678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[
             0.7882576351276829, 0.807321274893116, 0.6595281412689984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 98}], {
             RGBColor[
             0.9410490871482007, 0.9280127202932132, 0.6741425502994058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 106}], {
             RGBColor[
             0.8757056528840939, 0.876261616450479, 0.6678166313491606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 107}], {
             RGBColor[
             0.9821613924237322, 0.958554470988096, 0.5917370449815325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 197}], {
             RGBColor[
             0.8519177144144284, 0.8576782981229478, 0.6654456719534283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 215}], {
             RGBColor[
             0.7778310306733265, 0.7988564876838916, 0.658707320772441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 283}], {
             RGBColor[
             0.7169879338096027, 0.7494613206996427, 0.6539175293117211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 352}], {
             RGBColor[
             0.9797010852237658, 0.9575370707338988, 0.63251070235591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 52}], {
             RGBColor[
             0.912200120661706, 0.8600793811797902, 0.6307912332726904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 86}], {
             RGBColor[
             0.724783380162223, 0.784285808979104, 0.97384817137797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 117}], {
             RGBColor[
             0.9340212231814188, 0.9484961869178197, 0.9293484179959254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 174}], {
             RGBColor[
             0.8676950008182629, 0.897340456971866, 0.9872427178501592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 232}], {
             RGBColor[
             0.9372708389538982, 0.9480394078881812, 0.7446108139935743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 309}], {
             RGBColor[
             0.6956494609127561, 0.7606335808642815, 0.9715546425335893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 371}], {
             RGBColor[
             0.9362999206787448, 0.9494384868928185, 0.8915845033851446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 386}], {
             RGBColor[
             0.9007962786793375, 0.9237345174280354, 0.9903999472824081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 16}], {
             RGBColor[
             0.486962075602676, 0.5804230165114479, 0.9556104849681963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 73}], {
             RGBColor[
             0.8660658759602974, 0.893345662940328, 0.8516380659503673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 115}], {
             RGBColor[
             0.8515919207538867, 0.8843833267664798, 0.958193547248599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 188}], {
             RGBColor[
             0.8655285112964124, 0.8921436616310989, 0.7893234020008861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 195}], {
             RGBColor[
             0.858746826345298, 0.8897194436414717, 0.9460821583805852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 206}], {
             RGBColor[
             0.8654881650143667, 0.8920573650134378, 0.7849319581885952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 208}], {
             RGBColor[
             0.8643533078906664, 0.8926374720325438, 0.8800197508482448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 258}], {
             RGBColor[
             0.6996466114334142, 0.765288517453756, 0.9706978937245161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 278}], {
             RGBColor[
             0.8659143394407984, 0.8929689090187314, 0.8313184144620083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 284}], {
             RGBColor[
             0.8403764436997452, 0.80472966307759, 0.6240421478702592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 369}], {
             RGBColor[
             0.865442327422923, 0.8919593230402314, 0.779942819236785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 392}], {
             RGBColor[
             0.8652537700015265, 0.8915560177819439, 0.7594195075592871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 99}], {
             RGBColor[
             0.6145355015821103, 0.6968829304594542, 0.963524889845041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 174}], {
             RGBColor[
             0.7829200246832011, 0.8306176281982862, 0.9789247565080208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 193}], {
             RGBColor[
             0.8534998916646157, 0.8835323495075703, 0.850536557249842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 223}], {
             RGBColor[
             0.5180259798444364, 0.6150277915458793, 0.9568955722811712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 235}], {
             RGBColor[
             0.6628707225410151, 0.7361236403107827, 0.9673300154966744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 260}], {
             RGBColor[
             0.8528101779955619, 0.8832471351805838, 0.8619668976678201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 267}], {
             RGBColor[
             0.8326026735025661, 0.8697765459308915, 0.9678302246359005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 272}], {
             RGBColor[
             0.691946746302958, 0.7592733242927012, 0.9699304431276428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 275}], {
             RGBColor[
             0.852945299853374, 0.8822778794864224, 0.7852113002569745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 291}], {
             RGBColor[
             0.8381362023004583, 0.8739034426480377, 0.9584634037565206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 321}], {
             RGBColor[
             0.8439906662677016, 0.8782696922890028, 0.9485533233487269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 338}], {
             RGBColor[
             0.7430552067683199, 0.7991996420469281, 0.9750244568311124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 384}], {
             RGBColor[
             0.5775209916623646, 0.6665593804763277, 0.9606865418248363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 398}], {
             RGBColor[
             0.848858633199941, 0.8816130698575255, 0.9274542212013794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 13}], {
             RGBColor[
             0.6694716519048187, 0.7396914928848783, 0.9691367527987247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 18}], {
             RGBColor[
             0.8141178175813553, 0.8548637364182361, 0.9820676562592554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 74}], {
             RGBColor[
             0.7277452228600214, 0.787000602980767, 0.9737242617674422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 102}], {
             RGBColor[
             0.7400353447114056, 0.7969782775634005, 0.9746917851797828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 132}], {
             RGBColor[
             0.9160539339077908, 0.9328378189607257, 0.8698059679519379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 160}], {
             RGBColor[
             0.9008944621086523, 0.9231006513814465, 0.965718456466973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 166}], {
             RGBColor[
             0.6876009018491005, 0.7544096347030491, 0.9705639537639692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 185}], {
             RGBColor[
             0.9060809674084335, 0.9269687385419003, 0.9569390558516709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 198}], {
             RGBColor[
             0.9148631796312665, 0.9323454114663938, 0.8895398478872312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 213}], {
             RGBColor[
             0.7039687326671531, 0.7676977771235196, 0.9718524893633063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 216}], {
             RGBColor[
             0.8571031258510959, 0.8888947833818339, 0.9862324553603123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 224}], {
             RGBColor[
             0.8322621269935555, 0.8690872451837823, 0.9838630987134587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 247}], {
             RGBColor[
             0.8990032361124094, 0.9216901781300469, 0.9689198087678739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 289}], {
             RGBColor[
             0.7385456329718438, 0.7957688624624752, 0.9745745096146506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 302}], {
             RGBColor[
             0.9085549417241214, 0.9288138245357793, 0.952751262651053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 323}], {
             RGBColor[
             0.9032170901075384, 0.8888131742147041, 0.657244876613847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 340}], {
             RGBColor[
             0.9165657195586363, 0.9325111971975515, 0.8221986602939635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 40}], {
             RGBColor[
             0.7370044134963628, 0.7932141344696968, 0.959171115304742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 41}], {
             RGBColor[
             0.9732171779003529, 0.9781545166968942, 0.8679072407472346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 80}], {
             RGBColor[
             0.8508183045798593, 0.8839986198294774, 0.9692349810528054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 96}], {
             RGBColor[
             0.9082687484955917, 0.9292243636849954, 0.9748695465839519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 114}], {
             RGBColor[
             0.9741942716173371, 0.9779026799067851, 0.804037979079546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 153}], {
             RGBColor[
             0.9406262627606266, 0.9550253672386075, 0.9779558351804448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 154}], {
             RGBColor[
             0.8639746303755049, 0.894276441532815, 0.9705462806552607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 192}], {
             RGBColor[
             0.9705229651692925, 0.9770403904944918, 0.9125573180999488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 203}], {
             RGBColor[
             0.9711947133431216, 0.9773181756275107, 0.9014247124310543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 222}], {
             RGBColor[
             0.802709895702605, 0.8464159651771167, 0.9644399844545624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 228}], {
             RGBColor[
             0.72612494352706, 0.78438169063408, 0.9583146435759468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 312}], {
             RGBColor[
             0.8866254367137731, 0.9119714235967744, 0.9728039013472393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 332}], {
             RGBColor[
             0.9660212194084622, 0.9515789401360952, 0.6663461936657278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 356}], {
             RGBColor[
             0.9592034409181383, 0.9690945735517578, 0.9539421124655869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 361}], {
             RGBColor[
             0.7849300017684062, 0.8321222860520893, 0.9629439931707315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 385}], {
             RGBColor[
             0.9119887165627527, 0.9321905652459064, 0.9752243604590524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 17}], {
             RGBColor[
             0.656681474695473, 0.7222239160560642, 0.8751635741567885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.9038665062827225, 0.5622154810471205, 0.48637307486910997`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 36}], {
             RGBColor[
             0.8881398741058146, 0.9114737573363134, 0.8939097800003698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 60}], {
             RGBColor[
             0.9893686230967041, 0.9898716666836327, 0.8258529586164778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 64}], {
             RGBColor[
             0.8816695488314131, 0.9064190900556576, 0.893264878445645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.9909326516487207, 0.9905184326835919, 0.7999329579334191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 157}], {
             RGBColor[
             0.9747146048590878, 0.9796290718769893, 0.8813944548984023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 171}], {
             RGBColor[
             0.8526617749818883, 0.883757996657162, 0.8903736546413832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 182}], {
             RGBColor[
             0.7653089125024503, 0.8139523893969178, 0.8827370595833359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 210}], {
             RGBColor[
             0.9756950545095358, 0.9803602896209543, 0.8797348093824172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 253}], {
             RGBColor[
             0.9889334684695887, 0.9896917190623566, 0.833064596931856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 61}], {
             RGBColor[
             0.8052526964228415, 0.8457682747919277, 0.8602859647782137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 131}], {
             RGBColor[
             0.9338717509153189, 0.9470733174557218, 0.87272368634171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 142}], {
             RGBColor[
             0.9437188083660775, 0.9549250937757027, 0.8736629074719353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 202}], {
             RGBColor[
             0.9683144846403954, 0.9743451187303153, 0.8693555828447661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 214}], {
             RGBColor[
             0.9614902236686553, 0.9690955379457606, 0.8753579609282249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 215}], {
             RGBColor[
             0.7870878670990951, 0.8310212480306749, 0.8588559628738862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 217}], {
             RGBColor[
             0.9940972643626838, 0.9913303549597221, 0.7113803693618643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 269}], {
             RGBColor[
             0.8637119293687431, 0.8918252778610224, 0.8658472162334485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 279}], {
             RGBColor[
             0.993258030584872, 0.9914800366332033, 0.7613954110736121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 300}], {
             RGBColor[
             0.9913185889503289, 0.990678027675943, 0.7935369780720504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 306}], {
             RGBColor[
             0.9824488226208968, 0.9848864848533189, 0.8454298354695275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 363}], {
             RGBColor[
             0.9047561312528687, 0.9238893203203893, 0.8699381186973841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 39}], {
             RGBColor[
             0.7021879175233985, 0.7656603186495357, 0.9723933473246671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 177}], {
             RGBColor[
             0.7250993189020989, 0.7831461022490398, 0.9474264956548891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.7356417910870655, 0.7905166561894942, 0.9075478710382892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 200}], {
             RGBColor[
             0.6092315185299761, 0.6922316952365917, 0.9633433716107974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 216}], {
             RGBColor[
             0.6799315057426354, 0.7479136600297589, 0.9702705109004846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 219}], {
             RGBColor[
             0.7340973963713393, 0.7898568536925996, 0.9321950975739275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 241}], {
             RGBColor[
             0.7393472650924833, 0.7914298998900523, 0.8011390850274633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 296}], {
             RGBColor[
             0.4753580570210896, 0.5849561111829744, 0.9518410740240892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 311}], {
             RGBColor[
             0.7112122217557408, 0.7727891279353205, 0.97093372878866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 339}], {
             RGBColor[
             0.6402991677602852, 0.7165019789381885, 0.9664399045423858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 360}], {
             RGBColor[
             0.7118014159372417, 0.7732285479911669, 0.9699363767258329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 374}], {
             RGBColor[
             0.7290442193660787, 0.7579475366173577, 0.6529325071785165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 14}], {
             RGBColor[
             0.7938685659976208, 0.8370351318078075, 0.8806682515838828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 25}], {
             RGBColor[
             0.7957830658268232, 0.8373778374612305, 0.8163032578625912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 38}], {
             RGBColor[
             0.7910253557465886, 0.8358593913018351, 0.9277876034357504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 78}], {
             RGBColor[
             0.5968045862777063, 0.6835518747372906, 0.9614017896804652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 102}], {
             RGBColor[
             0.6192009519955407, 0.7017342533718063, 0.9631649136303639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 144}], {
             RGBColor[
             0.7749166639788517, 0.7675167591410504, 0.621232908280148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 205}], {
             RGBColor[
             0.7132851663248279, 0.7753242868879255, 0.972513390690845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 207}], {
             RGBColor[
             0.7189127359484182, 0.7798115581494683, 0.9730501533053337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 213}], {
             RGBColor[
             0.5831343399512883, 0.6724537529319254, 0.9603256178138873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 221}], {
             RGBColor[
             0.7800235513723788, 0.8278293921100244, 0.9542534004006806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 230}], {
             RGBColor[
             0.7841069563422121, 0.8308747888505639, 0.947341260909337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 250}], {
             RGBColor[
             0.7914579278460969, 0.8360382709815777, 0.9206187642861903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 289}], {
             RGBColor[
             0.617711240255979, 0.7005248382708811, 0.9630476380652317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 358}], {
             RGBColor[
             0.7621912126338212, 0.8143206406954544, 0.9771780930467396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 391}], {
             RGBColor[
             0.7868480300768643, 0.8329190771537713, 0.942701338063098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 118}], {
             RGBColor[
             0.9463615647028263, 0.8116720785775511, 0.3956262933023774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 126}], {
             RGBColor[
             0.9918665408403615, 0.9895249597287525, 0.6841692697864784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 149}], {
             RGBColor[
             0.9827278505214606, 0.9526710277436803, 0.4493135673614121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 199}], {
             RGBColor[
             0.7565530326867891, 0.8048133128788528, 0.7545467375036206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 212}], {
             RGBColor[
             0.8622802512772632, 0.8892914373422305, 0.763797072319004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 238}], {
             RGBColor[
             0.9625051920957877, 0.8771701839911623, 0.4086931180357105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 259}], {
             RGBColor[
             0.9378213713256072, 0.9488056634145928, 0.771193374050534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 274}], {
             RGBColor[
             0.9870572465901252, 0.9869114793445244, 0.7358957693649015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 299}], {
             RGBColor[
             0.627597712410525, 0.69054656779165, 0.7459937771093328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 318}], {
             RGBColor[
             0.7293425823196491, 0.7827226434539889, 0.7524046311755553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 336}], {
             RGBColor[
             0.9888601341625052, 0.9882560699440479, 0.7328439509732494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 367}], {
             RGBColor[
             0.9890086766015117, 0.9738577289197868, 0.47371339064792906`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 18}], {
             RGBColor[
             0.6451160977767381, 0.7205153061826355, 0.966748876278677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 69}], {
             RGBColor[
             0.6061455824160222, 0.6900712433959576, 0.9628646595076926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 74}], {
             RGBColor[
             0.5587435030554042, 0.6526521727451664, 0.9584054817868638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 88}], {
             RGBColor[
             0.7471484406373601, 0.7972739280308889, 0.7616488349986434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 132}], {
             RGBColor[
             0.7470522141031735, 0.798489388725125, 0.8544871879713595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[
             0.6880950534386432, 0.7545412877491822, 0.9709130694623276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 191}], {
             RGBColor[
             0.7409106347583799, 0.7770494431102184, 0.6679359347481245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 198}], {
             RGBColor[
             0.7458614598266492, 0.7979969812307932, 0.8742210679066529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 216}], {
             RGBColor[
             0.6881014060464787, 0.7545463531462333, 0.970913675379734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 224}], {
             RGBColor[
             0.6632604071889383, 0.7347388149481817, 0.9685443187328804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 302}], {
             RGBColor[
             0.7395532219195042, 0.7944653943001786, 0.9374324826704746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 323}], {
             RGBColor[
             0.734215370302921, 0.7544647439791033, 0.6419260966332686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 340}], {
             RGBColor[
             0.7475639997540191, 0.7981627669619509, 0.8068798803133852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 357}], {
             RGBColor[
             0.744492996462295, 0.7974310864617284, 0.8969000473236635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 38}], {
             RGBColor[
             0.9880893354665032, 0.989342648372352, 0.847054065339168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 102}], {
             RGBColor[
             0.8162649317154553, 0.8552175104423232, 0.8824313755337816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 205}], {
             RGBColor[
             0.9103491460447424, 0.9288075439584424, 0.8917798525942626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 207}], {
             RGBColor[
             0.9159767156683327, 0.9332948152199853, 0.8923166152087514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.7801983196712028, 0.8259370100024424, 0.879592079717305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 224}], {
             RGBColor[
             0.9084917139976052, 0.9273264780627051, 0.8916026890674575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 230}], {
             RGBColor[
             0.9811709360621266, 0.9843580459210808, 0.8666077228127548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 247}], {
             RGBColor[
             0.9752328231164591, 0.9799294110089696, 0.8766593991218727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 250}], {
             RGBColor[
             0.9885219075660114, 0.9895215280520946, 0.839885226189608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 289}], {
             RGBColor[
             0.8147752199758935, 0.854008095341398, 0.8823140999686494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 340}], {
             RGBColor[
             0.992795306562686, 0.9907504300764742, 0.7299382506479624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 391}], {
             RGBColor[
             0.9839120097967788, 0.9864023342242882, 0.8619677999665156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 45}], {
             RGBColor[
             0.9357366939152201, 0.949120391809408, 0.8972195433413699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 100}], {
             RGBColor[
             0.9070873356803415, 0.9287508355144428, 0.9909999939152567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 105}], {
             RGBColor[
             0.9332520903543422, 0.9354818521797692, 0.6935331252551145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.810279899268405, 0.8522084683387241, 0.9815941219344898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 155}], {
             RGBColor[
             0.9292708987345968, 0.9220523580181218, 0.6780669475973559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 170}], {
             RGBColor[
             0.9297510724846251, 0.9457160073920561, 0.9548063751134452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 180}], {
             RGBColor[
             0.9348630751133569, 0.9487591279838585, 0.9116976677412297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 183}], {
             RGBColor[
             0.9287689057238482, 0.9449835090300192, 0.9564689272493232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 239}], {
             RGBColor[
             0.9267660399913097, 0.9434897750460836, 0.9598592565034663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 271}], {
             RGBColor[
             0.9371537722926285, 0.9497063901357197, 0.8737348873464286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 273}], {
             RGBColor[
             0.9201272532364368, 0.938538578754315, 0.9710969908065715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 326}], {
             RGBColor[
             0.8962568134708797, 0.9201148710913116, 0.989966969038397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 335}], {
             RGBColor[
             0.9010941203620058, 0.923972008301098, 0.9904283556879874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 394}], {
             RGBColor[
             0.9327971692921957, 0.9479048228354504, 0.9459350735907524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 73}], {
             RGBColor[
             0.616117189503218, 0.6793691243106877, 0.8328365149129007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 85}], {
             RGBColor[
             0.6155956176309849, 0.6782009021859059, 0.7722407988729186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 96}], {
             RGBColor[
             0.5498420275159928, 0.629890333280468, 0.9617862131149051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 110}], {
             RGBColor[
             0.5238560828634893, 0.6092448953884357, 0.9592877348178541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 115}], {
             RGBColor[
             0.6016432342968072, 0.6704067881368394, 0.9393919962111323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 184}], {
             RGBColor[
             0.5307708122414079, 0.6146834638948618, 0.9599671835769402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 188}], {
             RGBColor[
             0.6155798248393329, 0.6781671230014585, 0.7705218509634195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 203}], {
             RGBColor[
             0.6127679923635228, 0.6779841452229833, 0.8883413789620074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 206}], {
             RGBColor[
             0.6155394785572872, 0.6780808263837975, 0.7661304071511286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 208}], {
             RGBColor[
             0.614404621433587, 0.6786609334029035, 0.8612181998107782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 258}], {
             RGBColor[
             0.44969792497633476`, 0.5513119788241158, 0.9518963426870494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 284}], {
             RGBColor[
             0.5904277572426657, 0.5907531244479496, 0.6052405968327925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 325}], {
             RGBColor[
             0.609353279457203, 0.6761569271934222, 0.9263409008564162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 348}], {
             RGBColor[
             0.35929617585991924`, 0.47822650022071617`, 0.9445698702139456]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 369}], {
             RGBColor[
             0.6154936409658436, 0.6779827844105911, 0.7611412681993184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 392}], {
             RGBColor[
             0.6153050835444471, 0.6775794791523035, 0.7406179565218204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 36}], {
             RGBColor[
             0.5544073362358426, 0.6433937112981367, 0.9605452044189383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 64}], {
             RGBColor[
             0.547937010961441, 0.6383390440174809, 0.9599003028642135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 82}], {
             RGBColor[
             0.6572001137787487, 0.7224383866454152, 0.8665683823519876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 122}], {
             RGBColor[
             0.6065939166583023, 0.6847301087307653, 0.9655959866599825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 157}], {
             RGBColor[
             0.6409820669891158, 0.7115490258388126, 0.9480298793169708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 187}], {
             RGBColor[
             0.4807834155298763, 0.5858208359111795, 0.9532462425126776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 218}], {
             RGBColor[
             0.6175259277265516, 0.6934469976150519, 0.9666386916347935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 253}], {
             RGBColor[
             0.6552009305996167, 0.72161167302418, 0.8997000213504245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 262}], {
             RGBColor[
             0.6308884293346115, 0.7040212074028981, 0.9651157750237251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 298}], {
             RGBColor[
             0.6583476752522681, 0.7229129328057002, 0.8475503189418745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 74}], {
             RGBColor[
             0.7033896687319408, 0.767824416278524, 0.9713363852473945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 132}], {
             RGBColor[
             0.89169837977971, 0.9136616322584827, 0.8674180914318902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 140}], {
             RGBColor[
             0.8327412191151797, 0.8697135312825399, 0.9838439729228583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 191}], {
             RGBColor[
             0.8855568004349165, 0.8922216866435762, 0.6808668382086552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.8905076255031857, 0.9131692247641509, 0.8871519713671836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 216}], {
             RGBColor[
             0.8327475717230153, 0.8697185966795911, 0.9838445788402648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.8079065728654748, 0.8499110584815394, 0.9814752221934111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 247}], {
             RGBColor[
             0.8746476819843287, 0.902513991427804, 0.9665319322478263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 302}], {
             RGBColor[
             0.8841993875960408, 0.9096376378335362, 0.9503633861310053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 311}], {
             RGBColor[
             0.8640282877361206, 0.8945940645851526, 0.9845077967284401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 323}], {
             RGBColor[
             0.8788615359794576, 0.869636987512461, 0.6548570000937993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 340}], {
             RGBColor[
             0.8922101654305556, 0.9133350104953086, 0.8198107837739159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 357}], {
             RGBColor[
             0.8891391621388316, 0.9126033299950862, 0.9098309507841942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 83}], {
             RGBColor[
             0.733941017904967, 0.7130345693301745, 0.6131223505496732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 108}], {
             RGBColor[
             0.9664756668537888, 0.8931870535885955, 0.3955994209595731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 125}], {
             RGBColor[
             0.908977866364333, 0.851993780058055, 0.6292486516306519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 179}], {
             RGBColor[
             0.7078651889652541, 0.6918650366942086, 0.6110695657766303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 196}], {
             RGBColor[
             0.9300173378704331, 0.8687700835357791, 0.6312554152050616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 231}], {
             RGBColor[
             0.6205673158813142, 0.616208249722858, 0.6053599651225812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 303}], {
             RGBColor[
             0.9615553975530555, 0.8926839712269897, 0.5914902159195854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 313}], {
             RGBColor[
             0.7326835901917006, 0.712013732866072, 0.6130233612339755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 344}], {
             RGBColor[
             0.8968195166628831, 0.8422990420357297, 0.6280889773822407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 50}], {
             RGBColor[
             0.9548018244950587, 0.9658118552304105, 0.9613929009444375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 54}], {
             RGBColor[
             0.9635186065474761, 0.9723128170126827, 0.9466376626305626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 116}], {
             RGBColor[
             0.563025528622081, 0.6327398944929409, 0.9539451791088993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 121}], {
             RGBColor[
             0.9700513186982576, 0.9757251328418449, 0.8702079930763931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 130}], {
             RGBColor[
             0.9235510109966816, 0.9415839025492831, 0.9823556269935164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 135}], {
             RGBColor[
             0.9708477816646572, 0.9754415571719885, 0.8124547401234206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 147}], {
             RGBColor[
             0.8339255689900993, 0.8709212646381737, 0.9735941780571071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 158}], {
             RGBColor[
             0.9452976226121323, 0.9587236370278263, 0.9774810356393809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 172}], {
             RGBColor[
             0.9294129226481207, 0.9462580317827878, 0.9829147413598209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 181}], {
             RGBColor[
             0.9465778558610416, 0.9596784328886734, 0.9753139346872852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 265}], {
             RGBColor[
             0.9704932513976222, 0.9746832527793091, 0.7738663084638457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 322}], {
             RGBColor[
             0.9418357228222193, 0.8731121794310028, 0.6210960506908415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 328}], {
             RGBColor[
             0.9617349146755998, 0.9459783327027007, 0.6684987894450529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 347}], {
             RGBColor[
             0.9665222110548872, 0.9742657561373818, 0.9286944397648524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 362}], {
             RGBColor[
             0.9132454621944098, 0.9333665376710218, 0.9813726745488838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 364}], {
             RGBColor[
             0.9027694837700745, 0.9250132768383158, 0.9803734663747543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 387}], {
             RGBColor[
             0.9159602171435447, 0.935531209577402, 0.9816316102994226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.8015923678230921, 0.483385276289193, 0.5717547051312598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 60}], {
             RGBColor[
             0.9028211168139817, 0.5617831856365122, 0.5036978837473678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 64}], {
             RGBColor[
             0.7951220425486907, 0.47833060900853713`, 0.571109803576535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 82}], {
             RGBColor[
             0.9043851453659982, 0.5624299516364715, 0.47777788306430913`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 122}], {
             RGBColor[
             0.8537789482455519, 0.5247216737218217, 0.576805487372304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 159}], {
             RGBColor[
             0.8832792833332943, 0.5478952662246493, 0.5675131762894275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 182}], {
             RGBColor[
             0.6787614062197278, 0.3858639083497974, 0.5605819847142259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 210}], {
             RGBColor[
             0.8891475482268132, 0.5522718085738338, 0.5575797345133072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 263}], {
             RGBColor[
             0.9019317272295662, 0.5614154001870866, 0.5184373708275963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 29}], {
             RGBColor[
             0.9226961589606417, 0.9411374986812231, 0.9904297295102644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 45}], {
             RGBColor[
             0.9489803382691939, 0.9596805143281175, 0.8984827339625928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 91}], {
             RGBColor[
             0.7629871022198773, 0.8151128587979943, 0.9770726140460355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 97}], {
             RGBColor[
             0.9313214478576108, 0.9475702250179683, 0.9758293652433268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 100}], {
             RGBColor[
             0.9203309800343153, 0.9393109580331522, 0.9922631845364795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 141}], {
             RGBColor[
             0.8877520807623402, 0.7115050662031284, 0.6013461062941838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 150}], {
             RGBColor[
             0.9100345011879327, 0.9311008252915196, 0.9912810971923365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 189}], {
             RGBColor[
             0.9472718688299095, 0.9589740183093115, 0.9267964939487128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 190}], {
             RGBColor[
             0.9417873589896684, 0.9553756844039001, 0.958113307643548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 255}], {
             RGBColor[
             0.7663341055336219, 0.8178301068688731, 0.9773361024073706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 266}], {
             RGBColor[
             0.9432509711946809, 0.9564672439899534, 0.9556357939516613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 273}], {
             RGBColor[
             0.9333708975904107, 0.9490987012730245, 0.9723601814277945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 350}], {
             RGBColor[
             0.5442746662565617, 0.6183662110165129, 0.9623285006858464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 365}], {
             RGBColor[
             0.8931740870539344, 0.9176567887248188, 0.9896729358407663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 394}], {
             RGBColor[
             0.9460408136461695, 0.9584649453541598, 0.9471982642119752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[
             0.3049983831833343, 0.4365898585610943, 0.9407286599336466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 89}], {
             RGBColor[
             0.6581491137422875, 0.7228308225185252, 0.8508409970229713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 163}], {
             RGBColor[
             0.6468879923591379, 0.683699396902316, 0.6414840088994365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 164}], {
             RGBColor[
             0.6558191948470529, 0.7218673411791612, 0.8894537827538227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 169}], {
             RGBColor[
             0.6544346508455567, 0.7212947966533847, 0.9123992599436317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 227}], {
             RGBColor[
             0.6538193733539436, 0.7210403635986924, 0.9225960002667686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 245}], {
             RGBColor[
             0.5962821473339583, 0.6765077837770551, 0.9646124408964014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 292}], {
             RGBColor[
             0.639625248008294, 0.7105371124645028, 0.9503266199364363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 304}], {
             RGBColor[
             0.6569440110861667, 0.7223324816004935, 0.8708126667405925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 353}], {
             RGBColor[
             0.3501436863923319, 0.4776985952448205, 0.9435318239703827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 378}], {
             RGBColor[
             0.6584425676763452, 0.7217911683744738, 0.7615849067919498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 25}], {
             RGBColor[
             0.9932490833616582, 0.9910273475001176, 0.7289069127322652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 76}], {
             RGBColor[
             0.9730926957718105, 0.9781997213637466, 0.874299814600417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 104}], {
             RGBColor[
             0.8431766410753296, 0.8761049883037608, 0.8784028273365394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 109}], {
             RGBColor[
             0.983960526174255, 0.9863049314834507, 0.8559034125132072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 138}], {
             RGBColor[
             0.988201682472321, 0.989389106746444, 0.8451921847080371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 144}], {
             RGBColor[
             0.9723826815136867, 0.9211662691799375, 0.5338365631498219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 207}], {
             RGBColor[
             0.916378753483253, 0.9334610681883554, 0.8856538081750076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 233}], {
             RGBColor[
             0.9930988843422661, 0.9907060869850883, 0.7125586763923399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 242}], {
             RGBColor[
             0.9860568693190173, 0.9681602225718995, 0.5824391674374136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 317}], {
             RGBColor[
             0.9924837273211304, 0.9893903283187945, 0.6456026309507908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 358}], {
             RGBColor[
             0.9596572301686561, 0.9679701507343415, 0.8897817479164136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 366}], {
             RGBColor[
             0.9649694110732967, 0.9721413889362529, 0.8880504167030339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 382}], {
             RGBColor[
             0.9768835209105461, 0.981026912545309, 0.8678829364460803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[
             0.9746051577860926, 0.9783761740487994, 0.816597627912869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 104}], {
             RGBColor[
             0.8446891030896116, 0.8762814409888137, 0.8207006406489914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 109}], {
             RGBColor[
             0.985472988188537, 0.9864813841685035, 0.7982012258256592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 138}], {
             RGBColor[
             0.9897141444866029, 0.9895655594314969, 0.7874899980204892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 144}], {
             RGBColor[
             0.9738951435279687, 0.9213427218649903, 0.47613437646227397`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 205}], {
             RGBColor[
             0.9122636458739448, 0.9291502496118653, 0.8274148588729708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 207}], {
             RGBColor[
             0.9178912154975352, 0.9336375208734082, 0.8279516214874596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 233}], {
             RGBColor[
             0.9946113463565481, 0.9908825396701411, 0.654856489704792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 317}], {
             RGBColor[
             0.9939961893354125, 0.9895667810038473, 0.587900444263243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 358}], {
             RGBColor[
             0.9611696921829381, 0.9681466034193943, 0.8320795612288656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 366}], {
             RGBColor[
             0.9664818730875787, 0.9723178416213057, 0.8303482300154859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 382}], {
             RGBColor[
             0.9783959829248281, 0.981203365230362, 0.8101807497585323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 391}], {
             RGBColor[
             0.9858265096259813, 0.9867450398777111, 0.797602806245224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 30}], {
             RGBColor[
             0.9369855073001621, 0.949273976100876, 0.8607680496700261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 62}], {
             RGBColor[
             0.8227881142470854, 0.8595849993647822, 0.849512529856238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 77}], {
             RGBColor[
             0.9852134135685149, 0.9867040585073774, 0.8298119222376539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 106}], {
             RGBColor[
             0.8856975896496342, 0.9087303596789749, 0.8557827584418918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 111}], {
             RGBColor[
             0.9277498772902478, 0.9419097354254686, 0.8598871470349362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 160}], {
             RGBColor[
             0.9791370360112439, 0.9821723060743199, 0.8400976444690305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.7658434757516921, 0.8134812893959226, 0.8449431417660267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 173}], {
             RGBColor[
             0.8364069364030757, 0.8702241267399239, 0.8508699267736183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 185}], {
             RGBColor[
             0.9843235413110252, 0.9860403932347737, 0.8313182438537284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 197}], {
             RGBColor[
             0.8619096511799688, 0.8901470413514438, 0.8534117990461594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 204}], {
             RGBColor[
             0.8044515315311901, 0.8448250483508112, 0.847982509342957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 345}], {
             RGBColor[
             0.9568531455743134, 0.8538761266373819, 0.4933473312432288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 370}], {
             RGBColor[
             0.8283703955684931, 0.8639459199599753, 0.8500689194889711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 389}], {
             RGBColor[
             0.6156121446280659, 0.6789219574962665, 0.8349901334475445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 400}], {
             RGBColor[
             0.7958815528961628, 0.8378675536217582, 0.8473078492319416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 51}], {
             RGBColor[
             0.9852850514923583, 0.9878113629217764, 0.8768854217468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[
             0.9885162674224433, 0.9889711383632465, 0.8105122755792368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 277}], {
             RGBColor[
             0.939233817558632, 0.9531907519171336, 0.9527104865332598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 287}], {
             RGBColor[
             0.9858862191549967, 0.9880599611995817, 0.8669225178048415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 376}], {
             RGBColor[
             0.9880096492834342, 0.987887533390857, 0.7553700176328304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 377}], {
             RGBColor[
             0.9665324627313145, 0.9149683642835826, 0.5974748422184777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 395}], {
             RGBColor[
             0.988578955987587, 0.9891734770800378, 0.8222968999092816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 396}], {
             RGBColor[
             0.9779715632958071, 0.9830918084910433, 0.9221725767904723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 44}], {
             RGBColor[
             0.89739864908874, 0.919359468014344, 0.9244281305753242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 47}], {
             RGBColor[
             0.9012877937028172, 0.9204156359536027, 0.8198435844474459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 49}], {
             RGBColor[
             0.6753249330023283, 0.7447618384677093, 0.9693173434120088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 147}], {
             RGBColor[
             0.7643303189353898, 0.8158199213686843, 0.977144961184699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 211}], {
             RGBColor[
             0.8797131873314482, 0.9066135528496987, 0.9742425555425763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 301}], {
             RGBColor[
             0.8209307982776567, 0.8601493504899995, 0.9827564597004537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 328}], {
             RGBColor[
             0.8921396646208902, 0.8908769894332114, 0.6720495725726447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 347}], {
             RGBColor[
             0.8969269610001778, 0.9191644128678925, 0.9322452228924443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 362}], {
             RGBColor[
             0.8436502121397003, 0.8782651944015325, 0.9849234576764756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 372}], {
             RGBColor[
             0.8444182777024991, 0.878877629032724, 0.9849967164555156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 380}], {
             RGBColor[
             0.8982511447667205, 0.9197119968853285, 0.910300071003094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 390}], {
             RGBColor[
             0.8307335134666909, 0.8679657694941201, 0.983691451426171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 45}], {
             RGBColor[
             0.9642862102516327, 0.9718256123533768, 0.8978835737923627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 91}], {
             RGBColor[
             0.7782929742023161, 0.8272579568232536, 0.9764734538758053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 150}], {
             RGBColor[
             0.9253403731703715, 0.9432459233167789, 0.9906819370221063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 190}], {
             RGBColor[
             0.9570932309721072, 0.9675207824291595, 0.9575141474733178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 226}], {
             RGBColor[
             0.9615153992401665, 0.9706798107935406, 0.9438030828813952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 266}], {
             RGBColor[
             0.9585568431771196, 0.9686123420152128, 0.9550366337814312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 273}], {
             RGBColor[
             0.9486767695728495, 0.9612437992982839, 0.9717610212575643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 365}], {
             RGBColor[
             0.9084799590363731, 0.9298018867500782, 0.9890737756705361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 62}], {
             RGBColor[
             0.7648151020326281, 0.8166757429594325, 0.9770666707428461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 77}], {
             RGBColor[
             0.9272404013540576, 0.9437948021020276, 0.957366063124262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 84}], {
             RGBColor[
             0.7473618264804909, 0.8026329004935344, 0.9756061874051569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 204}], {
             RGBColor[
             0.7464785193167328, 0.8019157919454614, 0.9755366502295651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 333}], {
             RGBColor[
             0.9361174655877216, 0.9471382603726648, 0.7460021845398754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 370}], {
             RGBColor[
             0.7703973833540358, 0.8210366635546256, 0.9776230603755792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 389}], {
             RGBColor[
             0.5576391324136086, 0.6360127010909167, 0.9625442743341526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 400}], {
             RGBColor[
             0.7379085406817055, 0.7949582972164084, 0.9748619901185497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 33}], {
             RGBColor[
             0.7444780598214011, 0.800311185666079, 0.9751662735261257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 106}], {
             RGBColor[
             0.7372327261827263, 0.7946510759609708, 0.974444126380515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 156}], {
             RGBColor[
             0.8421680527594331, 0.8763152006655848, 0.9235617175112818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 173}], {
             RGBColor[
             0.6879420729361678, 0.7561448430219199, 0.9695312947122416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 175}], {
             RGBColor[
             0.8450730363925356, 0.8775164860525468, 0.8754186208541197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 197}], {
             RGBColor[
             0.7134447877130607, 0.7760677576334398, 0.9720731669847826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 204}], {
             RGBColor[
             0.6559866680642821, 0.7307457646328072, 0.9666438772815804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 214}], {
             RGBColor[
             0.8137604605415192, 0.8553202371094693, 0.981836813858134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 261}], {
             RGBColor[
             0.8421680527594331, 0.8763152006655848, 0.9235617175112818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 295}], {
             RGBColor[
             0.8392302728660306, 0.8744756395636325, 0.9442723808730689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 310}], {
             RGBColor[
             0.7986639587193411, 0.8432826963400901, 0.9803968960375284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 345}], {
             RGBColor[
             0.8083882821074054, 0.7397968429193779, 0.6120086991818522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 43}], {
             RGBColor[
             0.8737152088209914, 0.8976754866591183, 0.7209625811857738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 124}], {
             RGBColor[
             0.9927327226876428, 0.9868643536003414, 0.4503798968658203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 137}], {
             RGBColor[
             0.9713510206619422, 0.9746344564671134, 0.7177832732501925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 199}], {
             RGBColor[
             0.75614865031242, 0.8039483798694069, 0.7105322116122765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 238}], {
             RGBColor[
             0.9621008097214185, 0.8763052509817164, 0.3646785921443666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 252}], {
             RGBColor[
             0.9874145027302332, 0.9866145750921069, 0.6905919881356868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 293}], {
             RGBColor[
             0.9908838287140618, 0.9884208725044867, 0.6497391645540473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 330}], {
             RGBColor[
             0.9937426619632637, 0.9890245115903702, 0.5603055543944178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 63}], {
             RGBColor[
             0.7841211817074292, 0.8312806937823296, 0.979117529429688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 84}], {
             RGBColor[
             0.7033192424686379, 0.7677493937767412, 0.9713430433226333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 90}], {
             RGBColor[
             0.8476436439502704, 0.8815869035550747, 0.9852678784298383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 152}], {
             RGBColor[
             0.8886080046765319, 0.9125978691357862, 0.9283457253944027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 156}], {
             RGBColor[
             0.8886173200000307, 0.9126017212614459, 0.928191346376743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 173}], {
             RGBColor[
             0.7343913401767656, 0.7924313636177809, 0.9741609235777028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 175}], {
             RGBColor[
             0.8915223036331333, 0.9138030066484079, 0.880048249719581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 204}], {
             RGBColor[
             0.7024359353048799, 0.7670322852286682, 0.9712735061470416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 214}], {
             RGBColor[
             0.8602097277821168, 0.8916067577053304, 0.9864664427235952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 256}], {
             RGBColor[
             0.8220682248718121, 0.861193758608169, 0.9828284721266888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 261}], {
             RGBColor[
             0.8886173200000307, 0.9126017212614459, 0.928191346376743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 264}], {
             RGBColor[
             0.8672241634478512, 0.8969981704652834, 0.9801421484887081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 295}], {
             RGBColor[
             0.8856795401066283, 0.9107621601594935, 0.9489020097385301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 310}], {
             RGBColor[
             0.845113225959939, 0.8795692169359511, 0.9850265249029897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 333}], {
             RGBColor[
             0.8920748815758686, 0.9122547536558717, 0.7417390404573518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 381}], {
             RGBColor[
             0.8809890566549499, 0.8753036760283941, 0.6609170514376621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 53}], {
             RGBColor[
             0.9507600069598082, 0.9627974743304895, 0.9682346437567726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 68}], {
             RGBColor[
             0.8351013743096347, 0.8718155625984626, 0.9724838356662879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 86}], {
             RGBColor[
             0.758356834011263, 0.8107264280819624, 0.9656111525826868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 95}], {
             RGBColor[
             0.9187807977647082, 0.9377449431007054, 0.9806760419729598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 151}], {
             RGBColor[
             0.9709306228136525, 0.9763163053319247, 0.8658261444221782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 244}], {
             RGBColor[
             0.971610984988579, 0.9761199040516544, 0.819823508129585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 249}], {
             RGBColor[
             0.7504714533597551, 0.804324720836718, 0.964990386532699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 253}], {
             RGBColor[
             0.9679733429381026, 0.9750933941047587, 0.9148359251550275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 270}], {
             RGBColor[
             0.9208820699262357, 0.939420440484794, 0.9808764631875541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 308}], {
             RGBColor[
             0.9370311230557884, 0.8518590935129893, 0.615519832825038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 386}], {
             RGBColor[
             0.9343697325283775, 0.9501751365308937, 0.9821629284871249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 397}], {
             RGBColor[
             0.9308482323330304, 0.9473671878637002, 0.9818270446548123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 41}], {
             RGBColor[
             0.9441031241240858, 0.9554082588353672, 0.8813734478479147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 57}], {
             RGBColor[
             0.9322974994344082, 0.9479951222225529, 0.9636705614229224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 92}], {
             RGBColor[
             0.9451051148187064, 0.9552096741629519, 0.8202140685496129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 114}], {
             RGBColor[
             0.94508021784107, 0.9551564220452582, 0.8175041861802261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 153}], {
             RGBColor[
             0.9115122089843595, 0.9322791093770806, 0.9914220422811248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 188}], {
             RGBColor[
             0.9448924920426647, 0.954754895544459, 0.7970713915331464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 195}], {
             RGBColor[
             0.9381108070915504, 0.9523306775548317, 0.9538301479128455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 208}], {
             RGBColor[
             0.9437172886369188, 0.9552487059459039, 0.8877677403805051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 258}], {
             RGBColor[
             0.7790105921796666, 0.8278997513671162, 0.9784458832567763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 278}], {
             RGBColor[
             0.9452783201870507, 0.9555801429320915, 0.8390664039942685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 284}], {
             RGBColor[
             0.9197404244459975, 0.86734089699095, 0.6317901374025194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 327}], {
             RGBColor[
             0.656594606806977, 0.7278525017932842, 0.9688674704824409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 337}], {
             RGBColor[
             0.929559560912003, 0.9459531721555059, 0.9683051771726217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 354}], {
             RGBColor[
             0.9400190898009597, 0.95371940568786, 0.9490564657241397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 369}], {
             RGBColor[
             0.9448063081691753, 0.9545705569535916, 0.7876908087690453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 392}], {
             RGBColor[
             0.9446177507477789, 0.9541672516953039, 0.7671674970915473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 55}], {
             RGBColor[
             0.883432387659209, 0.9089966239969653, 0.9481696296200006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 60}], {
             RGBColor[
             0.8870944846370737, 0.9110414619257052, 0.9112345888786276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 64}], {
             RGBColor[
             0.7793954103717827, 0.8275888852977301, 0.9786465087077947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 82}], {
             RGBColor[
             0.8886585131890903, 0.9116882279256644, 0.8853145881955689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 122}], {
             RGBColor[
             0.8380523160686439, 0.8739799500110146, 0.9843421925035638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 157}], {
             RGBColor[
             0.8724404663994574, 0.9007988671190619, 0.9667760851605521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 165}], {
             RGBColor[
             0.8658919247004868, 0.8279669629380199, 0.6273170295029196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 218}], {
             RGBColor[
             0.8489843271368933, 0.8826968388953012, 0.985384897478375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 262}], {
             RGBColor[
             0.8623468287449532, 0.8932710486831473, 0.9838619808673064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 298}], {
             RGBColor[
             0.8898060746626099, 0.9121627740859494, 0.8662965247854558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 314}], {
             RGBColor[
             0.7932545843926202, 0.838415777376432, 0.980027861652847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 58}], {
             RGBColor[
             0.6687926295518982, 0.7318780702301896, 0.845210863296673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 87}], {
             RGBColor[
             0.9936088002040591, 0.9897512721838548, 0.6193755575548311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 110}], {
             RGBColor[
             0.9024032240937849, 0.9219373489626796, 0.864540598127457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 134}], {
             RGBColor[
             0.9873996302673318, 0.9884758920922749, 0.8324414717203013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 159}], {
             RGBColor[
             0.9716736191363881, 0.9767474587397971, 0.8590615065643952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 167}], {
             RGBColor[
             0.991425265723693, 0.9907221412631972, 0.7917690678667669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 201}], {
             RGBColor[
             0.96540998802539, 0.9720760529129693, 0.8696642002186832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 236}], {
             RGBColor[
             0.9945203319064662, 0.9917009463253115, 0.718590158040259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 243}], {
             RGBColor[
             0.9475748846724095, 0.9578809559518155, 0.8688690271368321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 263}], {
             RGBColor[
             0.9903260630326599, 0.9902675927022343, 0.8099857011025641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 348}], {
             RGBColor[
             0.7378433170902148, 0.7909189537949601, 0.8498227335235484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 351}], {
             RGBColor[
             0.9925233784765102, 0.9911762391066975, 0.7735704977278818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 78}], {
             RGBColor[
             0.7910253557465886, 0.8358593913018351, 0.9277876034357504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 102}], {
             RGBColor[
             0.813421721464423, 0.8540417699363507, 0.9295507273856491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 205}], {
             RGBColor[
             0.9075059357937101, 0.92763180345247, 0.9388992044461301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 207}], {
             RGBColor[
             0.9131335054173004, 0.9321190747140129, 0.9394359670606188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 213}], {
             RGBColor[
             0.7773551094201706, 0.8247612694964699, 0.9267114315691725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 221}], {
             RGBColor[
             0.9742443208412612, 0.9801369086745688, 0.9206392141559658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 224}], {
             RGBColor[
             0.905648503746573, 0.9261507375567326, 0.9387220409193249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 230}], {
             RGBColor[
             0.9783277258110943, 0.9831823054151083, 0.9137270746646222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 247}], {
             RGBColor[
             0.9723896128654269, 0.9787536705029972, 0.9237787509737401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 250}], {
             RGBColor[
             0.9856786973149791, 0.9883457875461221, 0.8870045780414755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 289}], {
             RGBColor[
             0.8119320097248613, 0.8528323548354255, 0.929433451820517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 358}], {
             RGBColor[
             0.9564119821027035, 0.9666281572599988, 0.9435639068020247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 391}], {
             RGBColor[
             0.9810687995457467, 0.9852265937183158, 0.9090871518183832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 93}], {
             RGBColor[
             0.9382420709499063, 0.9530631201852976, 0.9756080696070882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 94}], {
             RGBColor[
             0.6748599218336973, 0.7428268039379818, 0.9704208705609958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 119}], {
             RGBColor[
             0.9541641020649749, 0.9642913914260425, 0.9197111939790654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 128}], {
             RGBColor[
             0.9307553262480872, 0.8720425431362562, 0.6319268269503665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 177}], {
             RGBColor[
             0.9431571049329825, 0.9567287444822463, 0.9672881991199088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 200}], {
             RGBColor[
             0.8272893045608598, 0.8658143374697983, 0.9832050750758171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 225}], {
             RGBColor[
             0.9489053470749775, 0.9610157740598636, 0.9575579245551714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 288}], {
             RGBColor[
             0.957085195711719, 0.964328403740087, 0.786186500853407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 296}], {
             RGBColor[
             0.6934158430519732, 0.7585387534161809, 0.9717027774891089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 316}], {
             RGBColor[
             0.9330553024809838, 0.9491948367537291, 0.984387915699101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 324}], {
             RGBColor[
             0.908199903279423, 0.7802924105497315, 0.6136579138259409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 355}], {
             RGBColor[
             0.8635617248137903, 0.894150627851992, 0.9868203709415899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 360}], {
             RGBColor[
             0.9298592019681252, 0.9468111902243734, 0.9897980801908526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 374}], {
             RGBColor[
             0.9471020053969623, 0.9315301788505643, 0.6727942106435362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 375}], {
             RGBColor[
             0.9569778538650942, 0.9654549501055147, 0.8730800448948517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 380}], {
             RGBColor[
             0.9544072179764902, 0.9643919261032481, 0.9156821341614463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 383}], {
             RGBColor[
             0.9097724142060806, 0.9308918442463523, 0.9912560991020396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 390}], {
             RGBColor[
             0.8868895866764606, 0.9126456987120397, 0.9890735145845231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 41}], {
             RGBColor[
             0.7563547602919214, 0.8062541124757286, 0.8641027551831532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 55}], {
             RGBColor[
             0.7505705177800825, 0.8033317128320379, 0.936207239359071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 58}], {
             RGBColor[
             0.43180979169277006`, 0.5466192428393075, 0.9492368478920356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.6339558869714278, 0.7120982156083118, 0.965430495488724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 87}], {
             RGBColor[
             0.7566259623449308, 0.8044924447929727, 0.7234015421501936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 96}], {
             RGBColor[
             0.6914063308871602, 0.7573239594638298, 0.9710650610198703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 110}], {
             RGBColor[
             0.6654203862346567, 0.7366785215717976, 0.9685665827228194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 146}], {
             RGBColor[
             0.7546183112113789, 0.7980947431131773, 0.6837508712228915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 154}], {
             RGBColor[
             0.6471122127670734, 0.7223760373116495, 0.9667417950911792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 159}], {
             RGBColor[
             0.7346907812772598, 0.7914886313489149, 0.9630874911597578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 167}], {
             RGBColor[
             0.754442427864565, 0.8054633138723151, 0.8957950524621294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 192}], {
             RGBColor[
             0.753660547560861, 0.8051399862733262, 0.9087528325358674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 203}], {
             RGBColor[
             0.7543322957346901, 0.8054177714063451, 0.8976202268669728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 228}], {
             RGBColor[
             0.5092625259186285, 0.6124812864129144, 0.9545101580118653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 243}], {
             RGBColor[
             0.7105920468132814, 0.7726221285609334, 0.9728950117321946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 332}], {
             RGBColor[
             0.7491588018000307, 0.7796785359149296, 0.6625417081016463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 348}], {
             RGBColor[
             0.5008604792310866, 0.605660126404078, 0.9538487181189108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 361}], {
             RGBColor[
             0.5680675841599747, 0.6602218818309237, 0.95913950760665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 385}], {
             RGBColor[
             0.6951262989543212, 0.7602901610247408, 0.971419874894971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 57}], {
             RGBColor[
             0.980761900006234, 0.9837813580901118, 0.8551359942006536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.9935695153905322, 0.9909959100305108, 0.711679501327344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 96}], {
             RGBColor[
             0.9276190952911503, 0.9422643416910272, 0.8798011864623632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 114}], {
             RGBColor[
             0.9935446184128958, 0.9909426579128171, 0.7089696189579573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 153}], {
             RGBColor[
             0.9599766095561851, 0.9680653452446395, 0.882887475058856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 154}], {
             RGBColor[
             0.8833249771710635, 0.907316419538847, 0.8754779205336719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 188}], {
             RGBColor[
             0.9933568926144904, 0.9905411314120178, 0.6885368243108776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 203}], {
             RGBColor[
             0.9905450601386802, 0.9903581536335426, 0.8063563523094655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 222}], {
             RGBColor[
             0.8220602424981636, 0.8594559431831486, 0.8693716243329737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 258}], {
             RGBColor[
             0.8274749927514923, 0.863685987234675, 0.8699113160345074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 312}], {
             RGBColor[
             0.9059757835093317, 0.9250114016028063, 0.8777355412256505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 327}], {
             RGBColor[
             0.7050590073788028, 0.7636387376608431, 0.8603329032601721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 356}], {
             RGBColor[
             0.9785537877136968, 0.9821345515577895, 0.8588737523439981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 361}], {
             RGBColor[
             0.8042803485639649, 0.8451622640581211, 0.8678756330491428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 369}], {
             RGBColor[
             0.9932707087410011, 0.9903567928211504, 0.6791562415467765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 104}], {
             RGBColor[
             0.7801823688007945, 0.828573557199327, 0.9786267868761809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 109}], {
             RGBColor[
             0.9209662538997199, 0.9387735003790169, 0.9561273720528487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 136}], {
             RGBColor[
             0.9301742488738887, 0.9433236019676647, 0.8203621725336936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 205}], {
             RGBColor[
             0.8477569115851277, 0.8814423658223787, 0.9853410051001603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 207}], {
             RGBColor[
             0.853384481208718, 0.8859296370839216, 0.9858777677146491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 221}], {
             RGBColor[
             0.9144952966326787, 0.9339474710444775, 0.9670810148099961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 276}], {
             RGBColor[
             0.9188844104795281, 0.9065347870990172, 0.6664316611565355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 358}], {
             RGBColor[
             0.896662957894121, 0.9204387196299076, 0.9900057074560551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 366}], {
             RGBColor[
             0.9019751387987616, 0.9246099578318191, 0.9882743762426753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 376}], {
             RGBColor[
             0.9299061725924811, 0.9427502139084035, 0.7911837236775126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 124}], {
             RGBColor[
             0.8735739562283797, 0.8973733616463498, 0.7055881081899523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 137}], {
             RGBColor[
             0.8521922542026792, 0.8851434645131219, 0.9729914845743246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 199}], {
             RGBColor[
             0.6369898838531569, 0.7144573879154155, 0.9657404229364086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 238}], {
             RGBColor[
             0.8429420432621555, 0.786814259027725, 0.6198868034684986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 252}], {
             RGBColor[
             0.8682557362709702, 0.8971235831381155, 0.9458001994598187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 277}], {
             RGBColor[
             0.8255345236493902, 0.864251663484145, 0.983081079583347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 293}], {
             RGBColor[
             0.8717250622547987, 0.8989298805504952, 0.9049473758781794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 299}], {
             RGBColor[
             0.5080345635768928, 0.6001906428282127, 0.9571874625421208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 330}], {
             RGBColor[
             0.8745838955040006, 0.8995335196363787, 0.8155137657185498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 367}], {
             RGBColor[
             0.8694455277678796, 0.8835018039563495, 0.6849070760807171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 47}], {
             RGBColor[
             0.9907528856568144, 0.9898920015210435, 0.7627807905497879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 49}], {
             RGBColor[
             0.7647900249563255, 0.8142382040351501, 0.9122545495143507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 54}], {
             RGBColor[
             0.9833884484467637, 0.9866878393106342, 0.8931256518604962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 93}], {
             RGBColor[
             0.9715510896941338, 0.9778595565348189, 0.9131632125510779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[
             0.9640643449923147, 0.8968389794857774, 0.5694819698943562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 211}], {
             RGBColor[
             0.9691782792854454, 0.9760899184171395, 0.9171797616449182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 301}], {
             RGBColor[
             0.9103958902316539, 0.9296257160574404, 0.9256936658027956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 316}], {
             RGBColor[
             0.9663643212252113, 0.9739912731032505, 0.9219430586430907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 324}], {
             RGBColor[
             0.9415089220236506, 0.805088846899253, 0.5512130567699306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 328}], {
             RGBColor[
             0.9816047565748874, 0.9603533550006522, 0.6149867786749867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 362}], {
             RGBColor[
             0.9331153040936975, 0.9477415599689734, 0.9278606637788174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 372}], {
             RGBColor[
             0.9338833696564963, 0.9483539946001649, 0.9279339225578574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 380}], {
             RGBColor[
             0.9877162367207177, 0.9891883624527693, 0.853237277105436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 383}], {
             RGBColor[
             0.9430814329503081, 0.9556882805958735, 0.9288112420460293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 390}], {
             RGBColor[
             0.9201986054206881, 0.9374421350615609, 0.9266286575285128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 91}], {
             RGBColor[
             0.8045771535108683, 0.8458009724701481, 0.8845264583281338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 97}], {
             RGBColor[
             0.9729114991486019, 0.978258338690122, 0.883283209525425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 100}], {
             RGBColor[
             0.9619210313253063, 0.969999071705306, 0.8997170288185778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 112}], {
             RGBColor[
             0.8651135949133699, 0.8934567045295873, 0.890311156837811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 141}], {
             RGBColor[
             0.9293421320533312, 0.7421931798752821, 0.5087999505762821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 180}], {
             RGBColor[
             0.9896967707583215, 0.9900073641747217, 0.820414702644551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 190}], {
             RGBColor[
             0.9833774102806594, 0.9860637980760539, 0.8655671519256463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 266}], {
             RGBColor[
             0.9848410224856718, 0.9871553576621073, 0.8630896382337596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 271}], {
             RGBColor[
             0.9919874679375933, 0.9909546263265828, 0.7824519222497497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 273}], {
             RGBColor[
             0.9749609488814017, 0.9797868149451783, 0.8798140257098928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 350}], {
             RGBColor[
             0.5858647175475526, 0.6490543246886666, 0.8697823449679447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 365}], {
             RGBColor[
             0.9347641383449252, 0.9483449023969727, 0.8971267801228646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 394}], {
             RGBColor[
             0.9876308649371605, 0.9891530590263136, 0.8546521084940735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 59}], {
             RGBColor[
             0.962863932555764, 0.8859583939372855, 0.5385617751348979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 287}], {
             RGBColor[
             0.9626169961535027, 0.8858562793889744, 0.5426541503712905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 373}], {
             RGBColor[
             0.7463278345322653, 0.716543063126464, 0.6125899600102176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 395}], {
             RGBColor[
             0.965309732986093, 0.8869697952694306, 0.49802853247573053`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 54}], {
             RGBColor[
             0.9872775930608408, 0.9877440072498929, 0.7885411057326179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 121}], {
             RGBColor[
             0.9938103052116224, 0.9911563230790552, 0.7121114361784484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 128}], {
             RGBColor[
             0.9679534896063919, 0.8978951474250361, 0.4648974237664778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 130}], {
             RGBColor[
             0.9473099975100464, 0.9570150927864933, 0.8242590700955719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.9690566091254971, 0.9741548272650364, 0.8193844787414364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 181}], {
             RGBColor[
             0.9703368423744065, 0.9751096231258836, 0.8172173777893407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 265}], {
             RGBColor[
             0.994252237910987, 0.9901144430165194, 0.6157697515659011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 311}], {
             RGBColor[
             0.9664681711449291, 0.9722243744573071, 0.823766029069791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 322}], {
             RGBColor[
             0.9655947093355841, 0.888543369668213, 0.4629994937928969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 362}], {
             RGBColor[
             0.9370044487077747, 0.948797727908232, 0.8232761176509391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 56}], {
             RGBColor[
             0.8735944541083451, 0.902044520888984, 0.9878054129714713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 71}], {
             RGBColor[
             0.9226779578679434, 0.941182374450671, 0.9924870413774229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 83}], {
             RGBColor[
             0.7249089676549787, 0.7840971709360208, 0.9741925283227635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 103}], {
             RGBColor[
             0.9553274402287815, 0.9650143463625962, 0.9109351391867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 108}], {
             RGBColor[
             0.9574436166038005, 0.9642496551944417, 0.7566695987326634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 120}], {
             RGBColor[
             0.9551508280852972, 0.9649413127025404, 0.9138620594618092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 143}], {
             RGBColor[
             0.9559734405785154, 0.9652814841086629, 0.9002292415962938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 196}], {
             RGBColor[
             0.9209852876204447, 0.9398326851416254, 0.9923255929781518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 231}], {
             RGBColor[
             0.6115352656313259, 0.6872708513287044, 0.9664301428956714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 234}], {
             RGBColor[
             0.577001057115036, 0.6509732085827988, 0.9644634708094519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 286}], {
             RGBColor[
             0.9550489501380275, 0.9648991835532006, 0.9155504406997437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 290}], {
             RGBColor[
             0.9513849723746066, 0.9628975746751081, 0.9544873655108269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 313}], {
             RGBColor[
             0.7236515399417123, 0.7830763344719183, 0.9740935390070657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 320}], {
             RGBColor[
             0.7604494864927508, 0.812950565210652, 0.976990408154883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 331}], {
             RGBColor[
             0.8068071953831208, 0.8498237447902453, 0.9811609066175412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 342}], {
             RGBColor[
             0.9443521278186344, 0.95765249072049, 0.966392136884459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 343}], {
             RGBColor[
             0.9217724671403886, 0.9404603607234099, 0.9924006748634876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 344}], {
             RGBColor[
             0.8877874664128947, 0.913361643641576, 0.9891591551553309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 349}], {
             RGBColor[
             0.9269547478813611, 0.944592570716998, 0.9928949654268382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 147}], {
             RGBColor[
             0.6317216948029754, 0.7106986573894905, 0.9649713801237254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 211}], {
             RGBColor[
             0.7471045631990337, 0.8014922888705047, 0.9620689744816028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 301}], {
             RGBColor[
             0.6883221741452422, 0.7550280865108057, 0.9705828786394801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 328}], {
             RGBColor[
             0.7595310404884758, 0.7857557254540175, 0.6598759915116712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 347}], {
             RGBColor[
             0.7643183368677633, 0.8140431488886986, 0.9200716418314707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 372}], {
             RGBColor[
             0.7118096535700846, 0.7737563650535301, 0.972823135394542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 380}], {
             RGBColor[
             0.765642520634306, 0.8145907329061346, 0.8981264899421204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 54}], {
             RGBColor[
             0.9711963737983729, 0.9780388832572113, 0.9336412053572013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 116}], {
             RGBColor[
             0.5707032958729777, 0.6384659607374695, 0.9409487218355381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 121}], {
             RGBColor[
             0.9777290859491543, 0.9814511990863737, 0.8572115358030318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.9312287782475783, 0.9473099687938118, 0.9693591697201551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 135}], {
             RGBColor[
             0.978525548915554, 0.9811676234165172, 0.7994582828500593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 158}], {
             RGBColor[
             0.9529753898630291, 0.9644497032723549, 0.9644845783660196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 172}], {
             RGBColor[
             0.9370906898990174, 0.9519840980273164, 0.9699182840864597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 181}], {
             RGBColor[
             0.9542556231119383, 0.965404499133202, 0.962317477413924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 265}], {
             RGBColor[
             0.978171018648519, 0.9804093190238379, 0.7608698511904846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 276}], {
             RGBColor[
             0.9672501679533527, 0.9444097315333883, 0.6471013737425255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 322}], {
             RGBColor[
             0.949513490073116, 0.8788382456755315, 0.6080995934174802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 328}], {
             RGBColor[
             0.9694126819264965, 0.9517043989472294, 0.6555023321716917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 362}], {
             RGBColor[
             0.9209232294453066, 0.9390926039155505, 0.9683762172755225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 364}], {
             RGBColor[
             0.9104472510209712, 0.9307393430828446, 0.9673770091013931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 59}], {
             RGBColor[
             0.9894631768694042, 0.9899107670985652, 0.8242859579055173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 136}], {
             RGBColor[
             0.9916077468769879, 0.9902096128007906, 0.7460042818260797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 194}], {
             RGBColor[
             0.9918462887345896, 0.9907198297139188, 0.7719680909163051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 246}], {
             RGBColor[
             0.9806587624580592, 0.9843610841348494, 0.8847165223524435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 376}], {
             RGBColor[
             0.9913396705955804, 0.9896362247415293, 0.7168258329698987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 377}], {
             RGBColor[
             0.9698624840434608, 0.9167170556342551, 0.558930657555546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 395}], {
             RGBColor[
             0.9919089772997333, 0.9909221684307102, 0.7837527152463499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 396}], {
             RGBColor[
             0.9813015846079534, 0.9848404998417157, 0.8836283921275407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 117}], {
             RGBColor[
             0.9648744900387319, 0.9003494941242814, 0.5715948074934865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 133}], {
             RGBColor[
             0.9647485422935758, 0.90029741149495, 0.5736820875730387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 174}], {
             RGBColor[
             0.898548267675576, 0.8491937641783278, 0.6294891073477202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 223}], {
             RGBColor[
             0.6336542228368114, 0.6336039275259208, 0.6074599231208706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 260}], {
             RGBColor[
             0.9684384209879369, 0.9018232711606253, 0.5125312485075195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 267}], {
             RGBColor[
             0.948230916494941, 0.8883526819109331, 0.6183945754756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 272}], {
             RGBColor[
             0.8075749892953329, 0.7778494602727427, 0.6204947939673422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 291}], {
             RGBColor[
             0.9537644452928331, 0.8924795786280791, 0.60902775459622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 346}], {
             RGBColor[
             0.907972027946627, 0.8567080148173056, 0.6303879540150632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 384}], {
             RGBColor[
             0.6931492346547394, 0.685135516456369, 0.6112508926645357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 68}], {
             RGBColor[
             0.8373676197669702, 0.873505724749907, 0.9686476732384975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 86}], {
             RGBColor[
             0.7606230794685984, 0.8124165902334068, 0.9617749901548964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 95}], {
             RGBColor[
             0.9210470432220437, 0.9394351052521499, 0.9768398795451694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 101}], {
             RGBColor[
             0.9243324879847019, 0.9420548297248712, 0.9771532481995829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 129}], {
             RGBColor[
             0.9732456838678076, 0.9764592519316824, 0.7472473981285719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 151}], {
             RGBColor[
             0.973196868270988, 0.9780064674833691, 0.8619899819943878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 171}], {
             RGBColor[
             0.8339678949077376, 0.8708498338510086, 0.9683088204367644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 244}], {
             RGBColor[
             0.9738772304459145, 0.9778100662030987, 0.8159873457017947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 249}], {
             RGBColor[
             0.7527376988170905, 0.8060148829881624, 0.9611542241049087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 253}], {
             RGBColor[
             0.970239588395438, 0.9767835562562031, 0.9109997627272373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 270}], {
             RGBColor[
             0.9231483153835711, 0.9411106026362384, 0.9770403007597637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 308}], {
             RGBColor[
             0.9392973685131238, 0.8535492556644337, 0.6116836703972477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 386}], {
             RGBColor[
             0.936635977985713, 0.951865298682338, 0.9783267660593346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 397}], {
             RGBColor[
             0.9331144777903658, 0.9490573500151447, 0.977990882227022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 121}], {
             RGBColor[
             0.9864458680015717, 0.9879521608686459, 0.8424562974891568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 128}], {
             RGBColor[
             0.9605890523963412, 0.8946909852146269, 0.5952422850771862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 130}], {
             RGBColor[
             0.9399455602999958, 0.9538109305760841, 0.9546039314062802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 158}], {
             RGBColor[
             0.9616921719154464, 0.9709506650546272, 0.9497293400521447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 181}], {
             RGBColor[
             0.9629724051643558, 0.9719054609154743, 0.9475622391000491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 265}], {
             RGBColor[
             0.9868878007009363, 0.9869102808061101, 0.7461146128766096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 311}], {
             RGBColor[
             0.9591037339348785, 0.9690202122468978, 0.9541108903804996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 322}], {
             RGBColor[
             0.9582302721255334, 0.8853392074578038, 0.5933443551036053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 328}], {
             RGBColor[
             0.978129463978914, 0.9582053607295017, 0.6407470938578168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 362}], {
             RGBColor[
             0.9296400114977239, 0.9455935656978227, 0.9536209789616475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 58}], {
             RGBColor[
             0.6622383135849212, 0.7286372254228142, 0.9300774575104462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 60}], {
             RGBColor[
             0.9846611366500985, 0.9873945333442845, 0.8801128082361087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 80}], {
             RGBColor[
             0.864384408863579, 0.8941161981918184, 0.9462711051071346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 87}], {
             RGBColor[
             0.9870544842370821, 0.9865104273764794, 0.7042421517686042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 122}], {
             RGBColor[
             0.9356189680816687, 0.950333021429594, 0.9532204118610448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 146}], {
             RGBColor[
             0.9850468331035301, 0.980112725696684, 0.664591480841302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 159}], {
             RGBColor[
             0.9651193031694111, 0.9735066139324217, 0.9439281007781684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.9634585767135115, 0.9043200343565991, 0.5961952488604007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 192}], {
             RGBColor[
             0.9840890694530122, 0.9871579688568329, 0.8895934421542779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 201}], {
             RGBColor[
             0.958855672058413, 0.968835208105594, 0.9545307944324564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 210}], {
             RGBColor[
             0.9709875680629301, 0.9778831562816062, 0.933994659002048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 228}], {
             RGBColor[
             0.7396910478107798, 0.7944992689964212, 0.9353507676302759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 385}], {
             RGBColor[
             0.9255548208464724, 0.9423081436082474, 0.9522604845133815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 71}], {
             RGBColor[
             0.8747663905843075, 0.9029789912235482, 0.9879171933187487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 83}], {
             RGBColor[
             0.6769974003713428, 0.745893787708898, 0.9696226802640893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 108}], {
             RGBColor[
             0.9095320493201647, 0.926046271967319, 0.7520997506739892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 120}], {
             RGBColor[
             0.9072392608016614, 0.9267379294754177, 0.909292211403135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 143}], {
             RGBColor[
             0.9080618732948795, 0.9270781008815401, 0.8956593935376196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 196}], {
             RGBColor[
             0.8730737203368089, 0.9016293019145027, 0.9877557449194776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 231}], {
             RGBColor[
             0.56362369834769, 0.6490674681015816, 0.9618602948369972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 237}], {
             RGBColor[
             0.7238080047879349, 0.7838967451679848, 0.9733077825166574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 254}], {
             RGBColor[
             0.8819885994218379, 0.9086708585580866, 0.9862856893152349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 286}], {
             RGBColor[
             0.9071373828543917, 0.9266958003260778, 0.9109805926410695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 290}], {
             RGBColor[
             0.9034734050909708, 0.9246941914479854, 0.9499175174521527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 320}], {
             RGBColor[
             0.712537919209115, 0.7747471819835292, 0.9724205600962088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 331}], {
             RGBColor[
             0.758895628099485, 0.8116203615631226, 0.976591058558867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 342}], {
             RGBColor[
             0.8964405605349985, 0.9194491074933673, 0.9618222888257848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 343}], {
             RGBColor[
             0.8738608998567529, 0.9022569774962872, 0.9878308268048134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 344}], {
             RGBColor[
             0.839875899129259, 0.8751582604144532, 0.9845893070966567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 349}], {
             RGBColor[
             0.8790431805977252, 0.9063891874898753, 0.988325117368164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 92}], {
             RGBColor[
             0.9817638907008546, 0.9835827734176964, 0.7939766149023518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 114}], {
             RGBColor[
             0.9817389937232182, 0.9835295213000027, 0.791266732532965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 153}], {
             RGBColor[
             0.9481709848665075, 0.9606522086318251, 0.9651845886338638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 188}], {
             RGBColor[
             0.9815512679248128, 0.9831279947992035, 0.7708339378858853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 195}], {
             RGBColor[
             0.9747695829736984, 0.9807037768095763, 0.9275926942655843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 208}], {
             RGBColor[
             0.9803760645190669, 0.9836218052006485, 0.8615302867332439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 258}], {
             RGBColor[
             0.8156693680618147, 0.8562728506218606, 0.9522084296095152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 278}], {
             RGBColor[
             0.9819370960691989, 0.983953242186836, 0.8128289503470074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 284}], {
             RGBColor[
             0.9563992003281456, 0.8957139962456946, 0.6055526837552584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 327}], {
             RGBColor[
             0.6932533826891252, 0.7562256010480287, 0.9426300168351798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 337}], {
             RGBColor[
             0.966218336794151, 0.9743262714102503, 0.9420677235253605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 354}], {
             RGBColor[
             0.9766778656831079, 0.9820925049426045, 0.9228190120768787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 392}], {
             RGBColor[
             0.9812765266299269, 0.9825403509500485, 0.7409300434442863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 60}], {
             RGBColor[
             0.665900410562786, 0.7306820633515541, 0.8931424167690731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 80}], {
             RGBColor[
             0.5456236827762666, 0.6374037281990881, 0.9593007136400991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 87}], {
             RGBColor[
             0.6682937581497697, 0.729797957383749, 0.7172717603015687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 110}], {
             RGBColor[
             0.5770881820394955, 0.6619840341625739, 0.9624368008741946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 159}], {
             RGBColor[
             0.6463585770820987, 0.7167941439396912, 0.9569577093111328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 167}], {
             RGBColor[
             0.6661102236694036, 0.7307688264630914, 0.8896652706135045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 192}], {
             RGBColor[
             0.6653283433656998, 0.7304454988641025, 0.9026230506872424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 201}], {
             RGBColor[
             0.6400949459711006, 0.7121227381128635, 0.9675604029654208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 210}], {
             RGBColor[
             0.6522268419756176, 0.7211706862888758, 0.9470242675350126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 228}], {
             RGBColor[
             0.42093032172346734`, 0.5377867990036908, 0.9483803761632403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 236}], {
             RGBColor[
             0.6692052898521768, 0.7317476315252056, 0.8164863607869967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 243}], {
             RGBColor[
             0.6222598426181201, 0.6979276411517097, 0.9667652298835697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 263}], {
             RGBColor[
             0.6650110209783705, 0.7303142779021286, 0.9078819038493017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 348}], {
             RGBColor[
             0.4125282750359253, 0.5309656389948543, 0.947718936270286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 351}], {
             RGBColor[
             0.6672083364222208, 0.7312229243065917, 0.8714667004746194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 79}], {
             RGBColor[
             0.8204644949569277, 0.85862412307401, 0.8880209148281122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[
             0.9926943927994892, 0.9910705425400351, 0.7579128117379541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 237}], {
             RGBColor[
             0.8061222018427323, 0.8471069162993949, 0.8868053394238419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 246}], {
             RGBColor[
             0.9815068665229589, 0.9847117969609656, 0.8706612431740923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 254}], {
             RGBColor[
             0.9643027964766353, 0.9718810296894967, 0.8997832462224193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 349}], {
             RGBColor[
             0.9613573776525226, 0.9695993586212854, 0.9018226742753485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 373}], {
             RGBColor[
             0.7737751829108052, 0.8208461491138599, 0.884258863602486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 395}], {
             RGBColor[
             0.9927570813646329, 0.9912728812568266, 0.7696974360679989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 87}], {
             RGBColor[
             0.9907165812149468, 0.9885552653052193, 0.6673071110272312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 122}], {
             RGBColor[
             0.9392810650595336, 0.9523778593583339, 0.9162853711196718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 146}], {
             RGBColor[
             0.9887089300813949, 0.9821575636254238, 0.627656440099929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 159}], {
             RGBColor[
             0.9687814001472759, 0.9755514518611615, 0.9069930600367953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 165}], {
             RGBColor[
             0.9671206736913764, 0.906364872285339, 0.5592602081190275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 201}], {
             RGBColor[
             0.9625177690362778, 0.9708800460343339, 0.9175957536910833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 210}], {
             RGBColor[
             0.9746496650407949, 0.979927994210346, 0.897059618260675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 263}], {
             RGBColor[
             0.9874338440435477, 0.9890715858235988, 0.8579172545749641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 66}], {
             RGBColor[
             0.609278849141217, 0.6936790432890265, 0.9623838093478112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 98}], {
             RGBColor[
             0.7620703011617348, 0.8143704886891237, 0.9769982183782187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 107}], {
             RGBColor[
             0.8031826064372664, 0.8449122393840065, 0.8945927130603453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 131}], {
             RGBColor[
             0.7456361285030844, 0.8012663255048489, 0.9754307123190775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 215}], {
             RGBColor[
             0.5988522446868605, 0.685214256079802, 0.9615629888512538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 262}], {
             RGBColor[
             0.7779224979271646, 0.8269299138144819, 0.9757127711138373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 269}], {
             RGBColor[
             0.6754763069565086, 0.7460182859101496, 0.968554242210816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 279}], {
             RGBColor[
             0.8050224081726376, 0.8456730446823304, 0.8641024370509796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 297}], {
             RGBColor[
             0.7903685853222059, 0.7946213956198913, 0.638276423186565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 298}], {
             RGBColor[
             0.8053817438448212, 0.8458216392172839, 0.8581473150319867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 300}], {
             RGBColor[
             0.8030829665380944, 0.8448710357250703, 0.896244004049418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 306}], {
             RGBColor[
             0.7942132002086624, 0.8390794929024461, 0.9481368614468951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 307}], {
             RGBColor[
             0.5871654574019205, 0.6757263956781203, 0.9606429621460708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 314}], {
             RGBColor[
             0.7088302535748315, 0.7720746425077666, 0.9718786518993778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 352}], {
             RGBColor[
             0.8007222992372999, 0.8438948391298093, 0.9353663704347228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 77}], {
             RGBColor[
             0.8130430083009809, 0.8541058253659337, 0.9461105433104741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 204}], {
             RGBColor[
             0.6322811262636561, 0.7122268152093676, 0.9642811304157772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 345}], {
             RGBColor[
             0.7846827403067794, 0.7212778934959383, 0.609645952316049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 370}], {
             RGBColor[
             0.6561999903009591, 0.7313476868185317, 0.9663675405617913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 389}], {
             RGBColor[
             0.44344173936053194`, 0.5463237243548228, 0.9512887545203645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 400}], {
             RGBColor[
             0.6237111476286288, 0.7052693204803147, 0.9636064703047618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 90}], {
             RGBColor[
             0.8408374985957006, 0.8762698910754644, 0.9845895054679392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 138}], {
             RGBColor[
             0.8809908899750626, 0.9069454999902713, 0.9411072132320251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 142}], {
             RGBColor[
             0.8356321671249693, 0.8721193010556619, 0.9840930163054067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 152}], {
             RGBColor[
             0.8818018593219623, 0.9072808566561759, 0.9276673524325039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 156}], {
             RGBColor[
             0.8818111746454611, 0.9072847087818354, 0.9275129734148441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 202}], {
             RGBColor[
             0.8602278433992872, 0.8915393260102745, 0.9797856916782375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 214}], {
             RGBColor[
             0.8534035824275472, 0.8862897452257199, 0.9857880697616963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 217}], {
             RGBColor[
             0.8860106231215754, 0.9085245622396814, 0.8218104781953357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 242}], {
             RGBColor[
             0.8788460768217589, 0.8857166158157267, 0.6783541959614017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 256}], {
             RGBColor[
             0.8152620795172424, 0.8558767461285587, 0.9821500991647898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 257}], {
             RGBColor[
             0.8779128758920121, 0.9047287942867658, 0.9498495446632493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 261}], {
             RGBColor[
             0.8818111746454611, 0.9072847087818354, 0.9275129734148441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 264}], {
             RGBColor[
             0.8604180180932814, 0.8916811579856729, 0.979463775526809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 268}], {
             RGBColor[
             0.8808193498213688, 0.906874563728338, 0.9439500775104188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 317}], {
             RGBColor[
             0.8852729348238721, 0.9069467215626217, 0.7415176594747788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 381}], {
             RGBColor[
             0.8741829113003801, 0.8699866635487836, 0.6602386784757631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 82}], {
             RGBColor[
             0.8821881879146889, 0.9066335606450086, 0.884669686640844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 151}], {
             RGBColor[
             0.8831462846111067, 0.9070297582509392, 0.8687915449064316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 157}], {
             RGBColor[
             0.865970141125056, 0.8957441998384059, 0.9661311836058273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 171}], {
             RGBColor[
             0.7439173112478563, 0.7998731246185787, 0.9751103833488082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 182}], {
             RGBColor[
             0.6565644487684184, 0.7300675173583345, 0.9674737882907609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 253}], {
             RGBColor[
             0.8801890047355568, 0.9058068470237732, 0.917801325639281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 105}], {
             RGBColor[
             0.9875725734342657, 0.9765178617860266, 0.6107554205127128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 113}], {
             RGBColor[
             0.9662390903141942, 0.973452593612581, 0.9022143825880768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 148}], {
             RGBColor[
             0.9908346161080538, 0.9904778924681276, 0.8015576605501165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 161}], {
             RGBColor[
             0.9919365968022947, 0.9909335898048083, 0.7832949886119253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 168}], {
             RGBColor[
             0.7794112743023769, 0.8255746005144133, 0.891090970458545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 170}], {
             RGBColor[
             0.9840715555645485, 0.9867520169983133, 0.8720286703710436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 180}], {
             RGBColor[
             0.9891835581932803, 0.9897951375901157, 0.8289199629988281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 239}], {
             RGBColor[
             0.9810865230712331, 0.9845257846523408, 0.8770815517610646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 251}], {
             RGBColor[
             0.9866677338863122, 0.9886882425398328, 0.867634017664049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 282}], {
             RGBColor[
             0.7968089091633455, 0.8396987842490665, 0.8924605760044368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 312}], {
             RGBColor[
             0.9044640033764271, 0.9243862416668729, 0.9027896503894504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 326}], {
             RGBColor[
             0.9505772965508033, 0.961150880697569, 0.9071892642959953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 356}], {
             RGBColor[
             0.9770420075807922, 0.9815093916218562, 0.8839278615077979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[
             0.7543320762923449, 0.8080882491370953, 0.9763890369704487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 107}], {
             RGBColor[
             0.7954443815678764, 0.8386299998319781, 0.8939835316525753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 131}], {
             RGBColor[
             0.7378979036336946, 0.7949840859528206, 0.9748215309113075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 215}], {
             RGBColor[
             0.5911140198174707, 0.6789320165277737, 0.9609538074434837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 297}], {
             RGBColor[
             0.782630360452816, 0.788339156067863, 0.637667241778795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 307}], {
             RGBColor[
             0.5794272325325306, 0.669444156126092, 0.9600337807383008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 314}], {
             RGBColor[
             0.7010920287054416, 0.7657924029557381, 0.9712694704916078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 352}], {
             RGBColor[
             0.79298407436791, 0.8376125995777809, 0.9347571890269528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 85}], {
             RGBColor[
             0.9658741845152405, 0.9714580526075043, 0.799116831846437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 127}], {
             RGBColor[
             0.9662396533418004, 0.9722397534729492, 0.8388958582053235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 139}], {
             RGBColor[
             0.6744927580921232, 0.7418647502009771, 0.9689984886711568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 184}], {
             RGBColor[
             0.8810493791256635, 0.9079406143164602, 0.9868432165504586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 305}], {
             RGBColor[
             0.6464261238328782, 0.717554842275674, 0.9672101075545079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 325}], {
             RGBColor[
             0.9596318463414588, 0.9694140776150206, 0.9532169338299346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 86}], {
             RGBColor[
             0.644964446818425, 0.7214346785013799, 0.9660241820644118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 95}], {
             RGBColor[
             0.8053884105718703, 0.8484531935201229, 0.9810890714546847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 129}], {
             RGBColor[
             0.8575870512176342, 0.8854773401996554, 0.751496590038087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 151}], {
             RGBColor[
             0.8575382356208144, 0.8870245557513422, 0.866239173903903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 178}], {
             RGBColor[
             0.7878257890171132, 0.834449235817022, 0.9794139329324546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 229}], {
             RGBColor[
             0.8086738553345285, 0.8510729179928442, 0.9814024401090982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 249}], {
             RGBColor[
             0.637079066166917, 0.7150329712561355, 0.9654034160144239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 308}], {
             RGBColor[
             0.8236387358629503, 0.7625673439324068, 0.6159328623067628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 309}], {
             RGBColor[
             0.6158305275689582, 0.6977824503865572, 0.963730653220031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 319}], {
             RGBColor[
             0.8559402417374369, 0.886363744213996, 0.8927220680270742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 334}], {
             RGBColor[
             0.8274545141736429, 0.8660481055637504, 0.9831937561148649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 371}], {
             RGBColor[
             0.8564809873349468, 0.8865873564150943, 0.8837605140715864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 386}], {
             RGBColor[
             0.8209773453355395, 0.8608833869503112, 0.9825759579688498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 74}], {
             RGBColor[
             0.6644191533712249, 0.7373803534918462, 0.9674521684764101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 97}], {
             RGBColor[
             0.8335369207344308, 0.8704737367613051, 0.966270593501699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 100}], {
             RGBColor[
             0.8225464529111353, 0.8622144697764891, 0.9827044127948518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 132}], {
             RGBColor[
             0.8527278644189942, 0.883217569471805, 0.8635338746609058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 140}], {
             RGBColor[
             0.7937707037544639, 0.8392694684958621, 0.9799597561518739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 141}], {
             RGBColor[
             0.7899675536391602, 0.6344085779464652, 0.5917873345525559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 168}], {
             RGBColor[
             0.6405499084532472, 0.7180022251702024, 0.9655730940805418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 191}], {
             RGBColor[
             0.8465862850742005, 0.8617776238568983, 0.6769826214376709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 216}], {
             RGBColor[
             0.7937770563622994, 0.8392745338929132, 0.9799603620692803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 219}], {
             RGBColor[
             0.8479429469910033, 0.8812177275557538, 0.9418849487427232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 220}], {
             RGBColor[
             0.7994787166974842, 0.8438208830767426, 0.9805041915219825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 350}], {
             RGBColor[
             0.44649013913338165`, 0.5412697227598497, 0.9527697289442185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 357}], {
             RGBColor[
             0.8501686467781158, 0.8821592672084083, 0.9059467340132097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 394}], {
             RGBColor[
             0.8482562865229895, 0.8813684570974967, 0.9376394924703473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 75}], {
             RGBColor[
             0.8928626513284319, 0.9139397135008651, 0.8274829164725053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 103}], {
             RGBColor[
             0.8900380930637903, 0.9131892474355128, 0.9046454598674207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 133}], {
             RGBColor[
             0.8886855120650656, 0.912629920432794, 0.9270612273837064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.7677249463063599, 0.8184718300710098, 0.9774833059164408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 164}], {
             RGBColor[
             0.889808389965302, 0.9130942593011875, 0.9084522346619377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 227}], {
             RGBColor[
             0.8878085684721926, 0.9122672817207186, 0.9415944521748836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 234}], {
             RGBColor[
             0.511711709950045, 0.5991481096557154, 0.9581737914901727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 280}], {
             RGBColor[
             0.8918218981895387, 0.9117136477730561, 0.7142033600878337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 346}], {
             RGBColor[
             0.8319089977181169, 0.8690405237551497, 0.983767093825731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 79}], {
             RGBColor[
             0.7872338016617286, 0.8345518055042869, 0.9792049863268792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 109}], {
             RGBColor[
             0.9500171626725198, 0.9619379064685359, 0.9588982736656508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 120}], {
             RGBColor[
             0.9563227645612596, 0.9658757830371046, 0.9139738398090865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 143}], {
             RGBColor[
             0.9571453770544778, 0.9662159544432272, 0.9003410219435712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 237}], {
             RGBColor[
             0.7728915085475332, 0.8230345987296719, 0.9779894109226089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 286}], {
             RGBColor[
             0.95622088661399, 0.9658336538877648, 0.9156622210470211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 320}], {
             RGBColor[
             0.7616214229687133, 0.8138850355452163, 0.9771021885021605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 321}], {
             RGBColor[
             0.9500171626725198, 0.9619379064685359, 0.9588982736656508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 343}], {
             RGBColor[
             0.9229444036163511, 0.9413948310579743, 0.9925124552107649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 382}], {
             RGBColor[
             0.9429401574088109, 0.9566598875303944, 0.9708777975985239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 119}], {
             RGBColor[
             0.9655679440473434, 0.9006362551777973, 0.5601024799693477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 200}], {
             RGBColor[
             0.8386931465432284, 0.8021592012215533, 0.6235963610660995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 288}], {
             RGBColor[
             0.9684890376940876, 0.900673267491842, 0.4265777868436894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 341}], {
             RGBColor[
             0.9681165668278009, 0.899876589971436, 0.38603663167212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 355}], {
             RGBColor[
             0.8749655667961589, 0.8304954916037468, 0.6272116569318722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 374}], {
             RGBColor[
             0.9585058473793308, 0.8678750426023192, 0.31318549663381856`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 375}], {
             RGBColor[
             0.9683816958474627, 0.9017998138572696, 0.5134713308851341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 379}], {
             RGBColor[
             0.9507980223817418, 0.8418747390020779, 0.28324205201880087`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 393}], {
             RGBColor[
             0.9152241869016546, 0.8624906895134341, 0.6310796714102724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 399}], {
             RGBColor[
             0.9641449580593584, 0.9000478139026937, 0.5836850403599485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 85}], {
             RGBColor[
             0.9946994179886062, 0.991123548614786, 0.6682683798550895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 96}], {
             RGBColor[
             0.9289458278736142, 0.9428129797093482, 0.8578137940970759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 110}], {
             RGBColor[
             0.9029598832211108, 0.922167541817316, 0.855315315800025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 115}], {
             RGBColor[
             0.9807470346544286, 0.9833294345657196, 0.8354195771933032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 184}], {
             RGBColor[
             0.9098746125990291, 0.9276061103237421, 0.855994764559111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 188}], {
             RGBColor[
             0.9946836251969543, 0.9910897694303389, 0.6665494319455904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 195}], {
             RGBColor[
             0.98790194024584, 0.9886655514407116, 0.8233081883252894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 203}], {
             RGBColor[
             0.991871792721144, 0.9909067916518635, 0.7843689599441783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 206}], {
             RGBColor[
             0.9946432789149084, 0.9910034728126778, 0.6621579881332995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 208}], {
             RGBColor[
             0.9935084217912085, 0.9915835798317838, 0.757245780792949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 258}], {
             RGBColor[
             0.8288017253339561, 0.864234625252996, 0.8479239236692202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 284}], {
             RGBColor[
             0.9695315576002871, 0.9036757708768298, 0.5012681778149635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 348}], {
             RGBColor[
             0.7383999762175406, 0.7911491466495963, 0.8405974511961164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 369}], {
             RGBColor[
             0.994597441323465, 0.9909054308394714, 0.6571688491814893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 392}], {
             RGBColor[
             0.9944088839020684, 0.9905021255811838, 0.6366455375039912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 132}], {
             RGBColor[
             0.8053257850583762, 0.8457984988210137, 0.859074696940077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 140}], {
             RGBColor[
             0.7463686243938459, 0.8018503978450708, 0.9755005784310451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 191}], {
             RGBColor[
             0.7991842057135826, 0.8243585532061071, 0.672523443716842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 198}], {
             RGBColor[
             0.8041350307818519, 0.8453060913266818, 0.8788085768753704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 216}], {
             RGBColor[
             0.7463749770016814, 0.801855463242122, 0.9755011843484516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 219}], {
             RGBColor[
             0.8005408676303853, 0.8437986569049626, 0.9374257710218945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 220}], {
             RGBColor[
             0.7520766373368661, 0.8064018124259513, 0.9760450138011537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 224}], {
             RGBColor[
             0.721533978144141, 0.7820479250440703, 0.9731318277015979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 302}], {
             RGBColor[
             0.7978267928747069, 0.8417745043960672, 0.9420199916391921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 311}], {
             RGBColor[
             0.7776556930147868, 0.8267309311476835, 0.9761644022366269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 323}], {
             RGBColor[
             0.7924889412581237, 0.8017738540749919, 0.6465136056019861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 340}], {
             RGBColor[
             0.8058375707092218, 0.8454718770578395, 0.8114673892821027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 357}], {
             RGBColor[
             0.8027665674174977, 0.8447401965576171, 0.901487556292381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 89}], {
             RGBColor[
             0.9940736331269695, 0.9913997478794765, 0.7175264630120046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 133}], {
             RGBColor[
             0.9906208363314988, 0.9899719276717192, 0.7747482414646248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 145}], {
             RGBColor[
             0.8696602705727929, 0.8958138373099349, 0.8251703199973592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.9828125117438199, 0.9522683222632673, 0.5081694748884699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 164}], {
             RGBColor[
             0.9917437142317349, 0.9904362665401125, 0.756139248742856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 169}], {
             RGBColor[
             0.9903591702302388, 0.989863722014336, 0.779084725932665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 209}], {
             RGBColor[
             0.913223432009073, 0.9299399930667767, 0.8294872690123025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 227}], {
             RGBColor[
             0.9897438927386256, 0.9896092889596437, 0.7892814662558019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 280}], {
             RGBColor[
             0.9937572224559718, 0.9890556550119813, 0.561890374168752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 315}], {
             RGBColor[
             0.7815089410574592, 0.825813632362335, 0.8171607147671172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[
             0.8245327154997639, 0.8634538148524427, 0.9660935425171433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 109}], {
             RGBColor[
             0.9653166005986893, 0.9736537580321325, 0.9435941276938111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 138}], {
             RGBColor[
             0.9695577568967553, 0.9767379332951258, 0.932882899888641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 144}], {
             RGBColor[
             0.953738755938121, 0.9085150957286193, 0.6215272783304258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 207}], {
             RGBColor[
             0.8977348279076874, 0.9208098947370372, 0.9733445233556115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 233}], {
             RGBColor[
             0.9744549587667004, 0.9780549135337702, 0.8002493915729438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 242}], {
             RGBColor[
             0.9674129437434515, 0.9555090491205813, 0.6701298826180175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 257}], {
             RGBColor[
             0.9664797428137049, 0.9745212275916204, 0.9416252313198652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 317}], {
             RGBColor[
             0.9738398017455647, 0.9767391548674763, 0.7332933461313947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 358}], {
             RGBColor[
             0.9410133045930904, 0.9553189772830233, 0.9774724630970175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 366}], {
             RGBColor[
             0.946325485497731, 0.9594902154849347, 0.9757411318836378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 382}], {
             RGBColor[
             0.9582395953349805, 0.9683757390939909, 0.9555736516266842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 78}], {
             RGBColor[
             0.7861364469500582, 0.8323883796229098, 0.9439058626861776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 102}], {
             RGBColor[
             0.8085328126678928, 0.8505707582574255, 0.9456689866360763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 111}], {
             RGBColor[
             0.9180047713441433, 0.9364305614266202, 0.9564851604891722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 160}], {
             RGBColor[
             0.9693919300651395, 0.9766931320754715, 0.9366956579232664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 166}], {
             RGBColor[
             0.7560983698055876, 0.8080021153970741, 0.9415411552202626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 185}], {
             RGBColor[
             0.9745784353649206, 0.9805612192359252, 0.9279162573079645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 370}], {
             RGBColor[
             0.8186252896223886, 0.8584667459611268, 0.9466669329432071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 389}], {
             RGBColor[
             0.6058670386819613, 0.673442783497418, 0.9315881469017804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 400}], {
             RGBColor[
             0.7861364469500582, 0.8323883796229098, 0.9439058626861776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 102}], {
             RGBColor[
             0.6192009519955407, 0.7017342533718063, 0.9631649136303639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 144}], {
             RGBColor[
             0.7749166639788517, 0.7675167591410504, 0.621232908280148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 160}], {
             RGBColor[
             0.7800600693927875, 0.8278566271898522, 0.954191584917554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 185}], {
             RGBColor[
             0.7852465746925685, 0.831724714350306, 0.945412184302252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 207}], {
             RGBColor[
             0.7189127359484182, 0.7798115581494683, 0.9730501533053337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 213}], {
             RGBColor[
             0.5831343399512883, 0.6724537529319254, 0.9603256178138873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 230}], {
             RGBColor[
             0.7841069563422121, 0.8308747888505639, 0.947341260909337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 247}], {
             RGBColor[
             0.7781688433965446, 0.8264461539384527, 0.957392937218455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 289}], {
             RGBColor[
             0.617711240255979, 0.7005248382708811, 0.9630476380652317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 370}], {
             RGBColor[
             0.6292934289500365, 0.7096302410755078, 0.9641628599374947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 391}], {
             RGBColor[
             0.7868480300768643, 0.8329190771537713, 0.942701338063098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 400}], {
             RGBColor[
             0.5968045862777063, 0.6835518747372906, 0.9614017896804652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 109}], {
             RGBColor[
             0.8134010699903427, 0.8543728671875876, 0.9455044382678297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 120}], {
             RGBColor[
             0.8197066718790824, 0.8583107437561563, 0.9005800044112655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 136}], {
             RGBColor[
             0.8226090649645115, 0.8589229687762354, 0.8097392387486746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 237}], {
             RGBColor[
             0.6362754158653561, 0.7154695594487235, 0.9645955755247879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 246}], {
             RGBColor[
             0.8116600805455827, 0.8530744401102941, 0.9484514792750385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 254}], {
             RGBColor[
             0.7944560104992591, 0.8402436728388253, 0.9775734823233655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 286}], {
             RGBColor[
             0.8196047939318127, 0.8582686146068165, 0.9022683856492001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 320}], {
             RGBColor[
             0.625005330286536, 0.7063199962642679, 0.9637083531043394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 343}], {
             RGBColor[
             0.7863283109341739, 0.8338297917770259, 0.979118619812944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 349}], {
             RGBColor[
             0.7915105916751464, 0.837962001770614, 0.9796129103762945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 87}], {
             RGBColor[
             0.8704398534284273, 0.8952769301527532, 0.7334654078982571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 96}], {
             RGBColor[
             0.8052202219706567, 0.8481084448236104, 0.981128926767934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 110}], {
             RGBColor[
             0.7792342773181532, 0.8274630069315781, 0.978630448470883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 146}], {
             RGBColor[
             0.8684322022948754, 0.8888792284729579, 0.693814736970955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 154}], {
             RGBColor[
             0.7609261038505699, 0.81316052267143, 0.9768056608392427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 159}], {
             RGBColor[
             0.8485046723607563, 0.8822731167086955, 0.9731513569078212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 167}], {
             RGBColor[
             0.8682563189480614, 0.8962477992320956, 0.9058589182101929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 192}], {
             RGBColor[
             0.8674744386443575, 0.8959244716331067, 0.9188166982839308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 201}], {
             RGBColor[
             0.8422410412497583, 0.8776017108818678, 0.9837540505621092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 203}], {
             RGBColor[
             0.8681461868181866, 0.8962022567661256, 0.9076840926150362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 228}], {
             RGBColor[
             0.623076417002125, 0.703265771772695, 0.9645740237599287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 243}], {
             RGBColor[
             0.8244059378967779, 0.8634066139207139, 0.9829588774802581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 332}], {
             RGBColor[
             0.8629726928835272, 0.8704630212747102, 0.6726055738497099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 348}], {
             RGBColor[
             0.614674370314583, 0.6964446117638585, 0.9639125838669744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 361}], {
             RGBColor[
             0.6818814752434712, 0.7510063671907042, 0.9692033733547136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 385}], {
             RGBColor[
             0.8089401900378177, 0.8510746463845213, 0.9814837406430343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 89}], {
             RGBColor[
             0.6401985601001208, 0.7052768110617318, 0.8497706583812609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 163}], {
             RGBColor[
             0.6289374387169713, 0.6661453854455227, 0.6404136702577261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 169}], {
             RGBColor[
             0.6364840972033903, 0.7037407851965916, 0.9113289213019212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 209}], {
             RGBColor[
             0.5593483589822243, 0.6438170562490321, 0.9617314643815588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 227}], {
             RGBColor[
             0.635868819711777, 0.703486352141899, 0.9215256616250582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 240}], {
             RGBColor[
             0.6335174944571975, 0.6815949889055339, 0.6582063219375527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 245}], {
             RGBColor[
             0.5783315936917917, 0.6589537723202619, 0.9635421022546911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 248}], {
             RGBColor[
             0.6356651751470304, 0.7034021398809498, 0.9249005790781508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 292}], {
             RGBColor[
             0.6216746943661273, 0.6929831010077097, 0.9492562812947258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 304}], {
             RGBColor[
             0.6389934574440002, 0.7047784701437003, 0.8697423280988821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 315}], {
             RGBColor[
             0.42763386803061054`, 0.5396906955445904, 0.9494049101363734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 329}], {
             RGBColor[
             0.33720897071384165`, 0.4644890505288174, 0.9427810900883864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 353}], {
             RGBColor[
             0.3321931327501654, 0.46014458378802725`, 0.9424614853286722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 378}], {
             RGBColor[
             0.6404920140341788, 0.7042371569176804, 0.7605145681502393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 151}], {
             RGBColor[
             0.9924093874284143, 0.9911291008788736, 0.7754596243942058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 157}], {
             RGBColor[
             0.9752332439423635, 0.9798435424663403, 0.8727992630936015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 171}], {
             RGBColor[
             0.853180414065164, 0.883972467246513, 0.8817784628365823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 182}], {
             RGBColor[
             0.765827551585726, 0.8141668599862688, 0.8741418677785351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 253}], {
             RGBColor[
             0.9894521075528644, 0.9899061896517076, 0.8244694051270551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 108}], {
             RGBColor[
             0.7608465628667984, 0.808098922014356, 0.7384868660252814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 120}], {
             RGBColor[
             0.7585537743482951, 0.8087905795224545, 0.8956793267544272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 125}], {
             RGBColor[
             0.7033487623773425, 0.7669056484838155, 0.9721360966963601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 179}], {
             RGBColor[
             0.5022360849782636, 0.6067769051199691, 0.9539570108423385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 196}], {
             RGBColor[
             0.7243882338834424, 0.7836819519615396, 0.9741428602707698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 231}], {
             RGBColor[
             0.41493821189432367`, 0.5311201181486185, 0.9482474101882894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 237}], {
             RGBColor[
             0.5751225183345685, 0.6659493952150217, 0.9596948978679496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 246}], {
             RGBColor[
             0.7505071830147951, 0.8035542758765923, 0.9435508016182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 254}], {
             RGBColor[
             0.7333031129684715, 0.7907235086051234, 0.9726728046665271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 303}], {
             RGBColor[
             0.7559262935660649, 0.8075958396527502, 0.9343776609852937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 313}], {
             RGBColor[
             0.5270544862047102, 0.6269256012918324, 0.9559108062996837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 344}], {
             RGBColor[
             0.6911904126758925, 0.7572109104614901, 0.9709764224479489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 349}], {
             RGBColor[
             0.7303576941443588, 0.7884418375369121, 0.9747122327194562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.7600355593569093, 0.8127385910698761, 0.9768150193608847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 152}], {
             RGBColor[
             0.800999920083171, 0.8437495566505875, 0.9198928663254491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 156}], {
             RGBColor[
             0.8010092354066698, 0.8437534087762472, 0.9197384873077894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 175}], {
             RGBColor[
             0.8039142190397723, 0.8449546941632091, 0.8715953906506273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 204}], {
             RGBColor[
             0.6148278507115188, 0.6981839727434695, 0.9628206470780879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 256}], {
             RGBColor[
             0.7344601402784511, 0.7923454461229704, 0.9743756130577351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 261}], {
             RGBColor[
             0.8010092354066698, 0.8437534087762472, 0.9197384873077894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 264}], {
             RGBColor[
             0.7796160788544901, 0.8281498579800847, 0.9716892894197544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 317}], {
             RGBColor[
             0.8044709955850808, 0.8434154215570333, 0.7337431733677242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 333}], {
             RGBColor[
             0.8044667969825076, 0.843406441170673, 0.7332861813883982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 381}], {
             RGBColor[
             0.7933809720615888, 0.8064553635431952, 0.6524641923687085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 389}], {
             RGBColor[
             0.42598846380839467`, 0.5322808818889248, 0.9498282711826753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 96}], {
             RGBColor[
             0.9284242560013811, 0.9416447575845663, 0.7972180780570939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 110}], {
             RGBColor[
             0.9024383113488776, 0.9209993196925341, 0.7947195997600429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 115}], {
             RGBColor[
             0.9802254627821955, 0.9821612124409378, 0.7748238611533211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 139}], {
             RGBColor[
             0.7027964196932557, 0.760362024083477, 0.7775543206398274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 167}], {
             RGBColor[
             0.9914603529787858, 0.9897841119930515, 0.721948069499353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 184}], {
             RGBColor[
             0.909353040726796, 0.9264378881989601, 0.7953990485191291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 188}], {
             RGBColor[
             0.9941620533247212, 0.9899215473055569, 0.6059537159056083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 203}], {
             RGBColor[
             0.9913502208489109, 0.9897385695270816, 0.7237732439041964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 258}], {
             RGBColor[
             0.828280153461723, 0.863066403128214, 0.7873282076292383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 284}], {
             RGBColor[
             0.969009985728054, 0.902507548752048, 0.4406724617749815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 325}], {
             RGBColor[
             0.9879355079425913, 0.9879113514975206, 0.7617727657986051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 348}], {
             RGBColor[
             0.7378784043453075, 0.7899809245248145, 0.7800017351561344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 351}], {
             RGBColor[
             0.9925584657316029, 0.9902382098365519, 0.7037494993604678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 369}], {
             RGBColor[
             0.9940758694512318, 0.9897372087146894, 0.5965731331415073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 95}], {
             RGBColor[
             0.7286438702734985, 0.7873640590036227, 0.9742163883710836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 151}], {
             RGBColor[
             0.7807936953224427, 0.825935421234842, 0.859366490820302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[
             0.7110812487187415, 0.7733601013005218, 0.9725412498488535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 229}], {
             RGBColor[
             0.7319293150361568, 0.789983783476344, 0.9745297570254972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 249}], {
             RGBColor[
             0.5603345258685453, 0.6539438367396353, 0.9585307329308228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 308}], {
             RGBColor[
             0.7468941955645786, 0.7014782094159067, 0.6090601792231618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 309}], {
             RGBColor[
             0.5390859872705864, 0.636693315870057, 0.9568579701364299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 334}], {
             RGBColor[
             0.7507099738752712, 0.8049589710472502, 0.9763210730312639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 371}], {
             RGBColor[
             0.7797364470365751, 0.8254982218985941, 0.8768878309879853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 386}], {
             RGBColor[
             0.7442328050371677, 0.7997942524338109, 0.9757032748852488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 110}], {
             RGBColor[
             0.9019043526916563, 0.9198572361162392, 0.7366014951323525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 134}], {
             RGBColor[
             0.9869007588652032, 0.9863957792458344, 0.7045023687251968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 159}], {
             RGBColor[
             0.9711747477342594, 0.9746673458933565, 0.7311224035692908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 167}], {
             RGBColor[
             0.9909263943215645, 0.9886420284167565, 0.6638299648716626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 192}], {
             RGBColor[
             0.9901445140178605, 0.9883187008177677, 0.6767877449454004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 201}], {
             RGBColor[
             0.9649111166232613, 0.9699959400665288, 0.7417250972235787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 210}], {
             RGBColor[
             0.9770430126277785, 0.979043888242541, 0.7211889617931706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 228}], {
             RGBColor[
             0.7457464923756281, 0.795660000957356, 0.7225450704213984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 236}], {
             RGBColor[
             0.9940214605043375, 0.9896208334788709, 0.5906510550451547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 243}], {
             RGBColor[
             0.9470760132702809, 0.9558008431053749, 0.7409299241417278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 263}], {
             RGBColor[
             0.9898271916305312, 0.9881874798557937, 0.6820465981074597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 348}], {
             RGBColor[
             0.7373444456880861, 0.7888388409485195, 0.721883630528444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 351}], {
             RGBColor[
             0.9920245070743815, 0.9890961262602569, 0.6456313947327774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[
             0.9683805826864023, 0.9730829029033013, 0.7754806817010244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 132}], {
             RGBColor[
             0.993730722640332, 0.9904202541067363, 0.6623180501518566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 140}], {
             RGBColor[
             0.9347735619758017, 0.9464721531307935, 0.7787439316428247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 168}], {
             RGBColor[
             0.7815527666745851, 0.8252049098051337, 0.7643572695714926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 282}], {
             RGBColor[
             0.7989504015355535, 0.8393290935397869, 0.7657268751173845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 283}], {
             RGBColor[
             0.7264140854050927, 0.7804408443812758, 0.7600165506023135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 357}], {
             RGBColor[
             0.9911715049994536, 0.9893619518433396, 0.7047309095041605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 163}], {
             RGBColor[
             0.9820881692759245, 0.9523863494029534, 0.5505260073470508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 164}], {
             RGBColor[
             0.9910193717638395, 0.9905542936797987, 0.798495781201437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 169}], {
             RGBColor[
             0.9896348277623432, 0.9899817491540223, 0.8214412583912459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 209}], {
             RGBColor[
             0.9124990895411775, 0.9300580202064628, 0.8718438014708835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 227}], {
             RGBColor[
             0.9890195502707302, 0.9897273160993298, 0.8316379987143829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 245}], {
             RGBColor[
             0.9314823242507448, 0.9451947362776927, 0.8736544393440158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.9930328799880763, 0.9891736821516675, 0.604246906627333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 292}], {
             RGBColor[
             0.9748254249250805, 0.9792240649651405, 0.8593686183840505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 304}], {
             RGBColor[
             0.9921441880029533, 0.9910194341011311, 0.7798546651882068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 315}], {
             RGBColor[
             0.7807845985895636, 0.8259316595020212, 0.8595172472256981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 329}], {
             RGBColor[
             0.6903597012727948, 0.7507300144862481, 0.8528934271777111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 353}], {
             RGBColor[
             0.6853438633091185, 0.7463855477454581, 0.852573822417997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 378}], {
             RGBColor[
             0.9936427445931317, 0.9904781208751112, 0.670626905239564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 138}], {
             RGBColor[
             0.9445133522179037, 0.9572517097630164, 0.9472575622321754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 142}], {
             RGBColor[
             0.8991546293678104, 0.9224255108284072, 0.9902433653055569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 152}], {
             RGBColor[
             0.9453243215648034, 0.957587066428921, 0.9338177014326541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 156}], {
             RGBColor[
             0.9453336368883022, 0.9575909185545808, 0.9336633224149944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 175}], {
             RGBColor[
             0.9482386205214048, 0.9587922039415426, 0.8855202257578323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 202}], {
             RGBColor[
             0.9237503056421283, 0.9418455357830198, 0.9859360406783877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 242}], {
             RGBColor[
             0.9423685390645999, 0.9360228255884719, 0.6845045449615519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 256}], {
             RGBColor[
             0.8787845417600835, 0.9061829559013039, 0.98830044816494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[
             0.9414353381348533, 0.955035004059511, 0.9559998936633995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 261}], {
             RGBColor[
             0.9453336368883022, 0.9575909185545808, 0.9336633224149944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 264}], {
             RGBColor[
             0.9239404803361226, 0.9419873677584183, 0.9856141245269593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 268}], {
             RGBColor[
             0.9443418120642099, 0.9571807735010832, 0.9501004265105691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 317}], {
             RGBColor[
             0.9487953970667132, 0.9572529313353669, 0.7476680084749291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 333}], {
             RGBColor[
             0.94879119846414, 0.9572439509490065, 0.7472110164956031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 381}], {
             RGBColor[
             0.9377053735432213, 0.9202928733215289, 0.6663890274759134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 141}], {
             RGBColor[
             0.7433488960040147, 0.5976255243451589, 0.5873898306597247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 150}], {
             RGBColor[
             0.7656313164296071, 0.8172212834335502, 0.9773248215578774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 186}], {
             RGBColor[
             0.7989802212713752, 0.8216638173980149, 0.6687492310394124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 189}], {
             RGBColor[
             0.802868684071584, 0.8450944764513422, 0.9128402183142537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 190}], {
             RGBColor[
             0.7973841742313428, 0.8414961425459309, 0.9441570320090888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 226}], {
             RGBColor[
             0.8018063424994021, 0.8446551709103118, 0.9304459674171663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 241}], {
             RGBColor[
             0.8065741580770016, 0.8460077201519003, 0.8064314323034278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 255}], {
             RGBColor[
             0.6219309207752963, 0.7039505650109039, 0.9633798267729115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 266}], {
             RGBColor[
             0.7988477864363552, 0.8425877021319841, 0.9416795183172023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 273}], {
             RGBColor[
             0.7889677128320851, 0.8352191594150551, 0.9584039057933353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 365}], {
             RGBColor[
             0.7487709022956087, 0.8037772468668496, 0.9757166602063072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 114}], {
             RGBColor[
             0.9945466091075162, 0.9907440732404017, 0.6478102396596555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 153}], {
             RGBColor[
             0.9609786002508056, 0.9678667605722241, 0.8217280957605543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 161}], {
             RGBColor[
             0.99445036762982, 0.9913601650683262, 0.6970815001498236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 188}], {
             RGBColor[
             0.994358883309111, 0.9903425467396025, 0.6273774450125758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 195}], {
             RGBColor[
             0.9875771983579966, 0.9879183287499753, 0.7841362013922748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 258}], {
             RGBColor[
             0.8284769834461128, 0.8634874025622596, 0.8087519367362057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 278}], {
             RGBColor[
             0.9947447114534971, 0.991167794127235, 0.6693724574736979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 284}], {
             RGBColor[
             0.9692068157124438, 0.9029285481860936, 0.46209619088194887`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 327}], {
             RGBColor[
             0.7060609980734234, 0.7634401529884277, 0.7991735239618702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 337}], {
             RGBColor[
             0.9790259521784492, 0.9815408233506493, 0.798611230652051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 354}], {
             RGBColor[
             0.9894854810674061, 0.9893070568830035, 0.7793625192035691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 392}], {
             RGBColor[
             0.994084142014225, 0.9897549028904475, 0.5974735505709767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 94}], {
             RGBColor[
             0.6928562892293213, 0.7566469632405373, 0.9537738893783974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 119}], {
             RGBColor[
             0.972160469460599, 0.9781115507285979, 0.9030642127964668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 128}], {
             RGBColor[
             0.9487516936437113, 0.8858627024388115, 0.615279845767768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 225}], {
             RGBColor[
             0.9669017144706018, 0.974835933362419, 0.9409109433725729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 296}], {
             RGBColor[
             0.7114122104475973, 0.7723589127187364, 0.9550557963065104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 301}], {
             RGBColor[
             0.8950832388830505, 0.9186494390104745, 0.9714915416762073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 316}], {
             RGBColor[
             0.9510516698766079, 0.9630149960562846, 0.9677409345165024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 324}], {
             RGBColor[
             0.9261962706750472, 0.7941125698522871, 0.5970109326433424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 355}], {
             RGBColor[
             0.8815580922094145, 0.9079707871545473, 0.9701733897589913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 380}], {
             RGBColor[
             0.9724035853721144, 0.9782120854058034, 0.8990351529788476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 383}], {
             RGBColor[
             0.9277687816017047, 0.9447120035489076, 0.9746091179194409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 390}], {
             RGBColor[
             0.9048859540720848, 0.926465858014595, 0.9724265334019246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 119}], {
             RGBColor[
             0.7087783203443899, 0.7678752344812821, 0.8978770137503744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 128}], {
             RGBColor[
             0.6853695445275022, 0.6756263861914957, 0.6100926467216755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 177}], {
             RGBColor[
             0.6977713232123975, 0.760312587537486, 0.9454540188912179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 200}], {
             RGBColor[
             0.5819035228402749, 0.669398180525038, 0.9613708948471262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 225}], {
             RGBColor[
             0.7035195653543926, 0.7645996171151033, 0.9357237443264805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 288}], {
             RGBColor[
             0.7116994139911341, 0.7679122467953268, 0.7643523206247161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 296}], {
             RGBColor[
             0.44803006133138823`, 0.5621225964714206, 0.949868597260418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 316}], {
             RGBColor[
             0.6876695207603989, 0.7527786798089688, 0.9625537354704101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 324}], {
             RGBColor[
             0.6628141215588381, 0.5838762536049713, 0.5918237335972499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 355}], {
             RGBColor[
             0.6181759430932054, 0.6977344709072315, 0.9649861907128989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 375}], {
             RGBColor[
             0.7115920721445093, 0.7690387931607544, 0.8512458646661608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 380}], {
             RGBColor[
             0.7090214362559053, 0.7679757691584876, 0.8938479539327553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 383}], {
             RGBColor[
             0.6643866324854957, 0.7344756873015919, 0.9694219188733486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 390}], {
             RGBColor[
             0.6415038049558757, 0.7162295417672793, 0.9672393343558322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 129}], {
             RGBColor[
             0.9412664746727077, 0.9514067207018982, 0.7596887963447589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 151}], {
             RGBColor[
             0.941217659075888, 0.952953936253585, 0.874431380210575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 178}], {
             RGBColor[
             0.8715052124721867, 0.9003786163192649, 0.9876061392391264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 229}], {
             RGBColor[
             0.892353278789602, 0.9170022984950871, 0.9895946464157701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 249}], {
             RGBColor[
             0.7207584896219905, 0.7809623517583784, 0.9735956223210958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 270}], {
             RGBColor[
             0.8911691061884712, 0.9160580714064543, 0.9894816989759508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 308}], {
             RGBColor[
             0.9073181593180238, 0.8284967244346497, 0.6241250686134348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 309}], {
             RGBColor[
             0.6995099510240317, 0.7637118308888, 0.9719228595267029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 334}], {
             RGBColor[
             0.9111339376287164, 0.9319774860659933, 0.9913859624215369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 371}], {
             RGBColor[
             0.9401604107900203, 0.9525167369173372, 0.8919527203782582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 386}], {
             RGBColor[
             0.904656768790613, 0.9268127674525539, 0.9907681642755217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 110}], {
             RGBColor[
             0.8366847212338856, 0.8726887507870962, 0.9842650140020294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 114}], {
             RGBColor[
             0.9285961890081345, 0.9420125049009183, 0.8159319247946746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 115}], {
             RGBColor[
             0.9144718726672034, 0.9338506435354998, 0.9643692753953076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 153}], {
             RGBColor[
             0.8950281801514239, 0.9191351922327406, 0.9898497808955733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 154}], {
             RGBColor[
             0.8183765477663023, 0.8583862665269482, 0.9824402263703891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 167}], {
             RGBColor[
             0.9257067628637938, 0.9414735430876137, 0.9114934837413393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 188}], {
             RGBColor[
             0.9284084632097291, 0.941610978400119, 0.7954991301475948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 192}], {
             RGBColor[
             0.9249248825600899, 0.9411502154886249, 0.9244512638150773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 203}], {
             RGBColor[
             0.925596630733919, 0.9414280006216438, 0.9133186581461827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 228}], {
             RGBColor[
             0.6805268609178574, 0.748491515628213, 0.9702085892910752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 243}], {
             RGBColor[
             0.8818563818125102, 0.9086323577762321, 0.9885934430114045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 258}], {
             RGBColor[
             0.7625265633467311, 0.8147558342227762, 0.9768736218712246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 284}], {
             RGBColor[
             0.9032563956130619, 0.85419697984661, 0.6302178760169679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 348}], {
             RGBColor[
             0.6721248142303154, 0.7416703556193767, 0.9695471493981208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 361}], {
             RGBColor[
             0.7393319191592036, 0.7962321110462223, 0.97483793888586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 369}], {
             RGBColor[
             0.9283222793362398, 0.9414266398092516, 0.7861185473834937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 100}], {
             RGBColor[
             0.9442621409137233, 0.9578887823951568, 0.9770636600993119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 105}], {
             RGBColor[
             0.970426895587724, 0.9646197990604832, 0.6795967914391696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 112}], {
             RGBColor[
             0.8474547045017868, 0.8813464152194381, 0.967657788118545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 132}], {
             RGBColor[
             0.9744435524215822, 0.9788918820904726, 0.8578931219653658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 140}], {
             RGBColor[
             0.9154863917570518, 0.9349437811145298, 0.974319003456334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 141}], {
             RGBColor[
             0.9116832416417482, 0.7300828905651329, 0.5861465818570162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 168}], {
             RGBColor[
             0.7622655964558351, 0.8136765377888702, 0.9599323413850018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 180}], {
             RGBColor[
             0.9720378803467385, 0.9778970748645726, 0.8977613339252849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 220}], {
             RGBColor[
             0.9211944047000721, 0.9394951956954103, 0.9748634388264426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 282}], {
             RGBColor[
             0.7796632313168037, 0.8278007215235232, 0.9613019469308937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 350}], {
             RGBColor[
             0.5682058271359696, 0.6369440353785175, 0.9471289762486788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 357}], {
             RGBColor[
             0.9718843347807037, 0.9778335798270761, 0.9003059813176698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 394}], {
             RGBColor[
             0.9699719745255775, 0.9770427697161644, 0.9319987397748075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 107}], {
             RGBColor[
             0.9482358335883943, 0.9593214452320753, 0.9085979406829827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 131}], {
             RGBColor[
             0.8906893556542124, 0.9156755313529177, 0.989435939941715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 215}], {
             RGBColor[
             0.7439054718379885, 0.7996234619278708, 0.9755682164738911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 283}], {
             RGBColor[
             0.6830623749742647, 0.7502282949436219, 0.9707784250131712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 297}], {
             RGBColor[
             0.9354218124733338, 0.9090306014679601, 0.6522816508092024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 307}], {
             RGBColor[
             0.7322186845530484, 0.7901356015261891, 0.9746481897687083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 352}], {
             RGBColor[
             0.9457755263884278, 0.9583040449778781, 0.9493715980573603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 123}], {
             RGBColor[
             0.7327570229083241, 0.7257405508743898, 0.6161758533042132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 174}], {
             RGBColor[
             0.6856586247310421, 0.7527201422315714, 0.9705407252622092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 187}], {
             RGBColor[
             0.5779459979321016, 0.6682416231486052, 0.9599171725246138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 193}], {
             RGBColor[
             0.7562384917124567, 0.8056348635408555, 0.8421525260040306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[
             0.7146885101287768, 0.7758677848524778, 0.9733096216467299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 232}], {
             RGBColor[
             0.7552344628666774, 0.8034190931478865, 0.7279088214056244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 235}], {
             RGBColor[
             0.5656093225888561, 0.6582261543440678, 0.9589459842508627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 275}], {
             RGBColor[
             0.755683899901215, 0.8043803935197076, 0.776827269011163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 279}], {
             RGBColor[
             0.7551509219823098, 0.8051851255081726, 0.8601763709728036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 281}], {
             RGBColor[
             0.6476222679250769, 0.7227305637953174, 0.966822669500697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 306}], {
             RGBColor[
             0.7443417140183346, 0.7985915737282882, 0.9442107953687192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 338}], {
             RGBColor[
             0.6457938068161609, 0.7213021560802131, 0.9666404255853007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 384}], {
             RGBColor[
             0.4802595917102056, 0.5886618945096127, 0.9523025105790247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 105}], {
             RGBColor[
             0.9594364277644285, 0.9563605320756672, 0.6960306107323224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 112}], {
             RGBColor[
             0.8364642366784913, 0.8730871482346221, 0.9840916074116978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 141}], {
             RGBColor[
             0.9006927738184526, 0.7218236235803168, 0.602580401150169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 168}], {
             RGBColor[
             0.7512751286325396, 0.8054172708040541, 0.9763661606781546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 170}], {
             RGBColor[
             0.9559354098947113, 0.9665946872879541, 0.9573038605906532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 180}], {
             RGBColor[
             0.961047412523443, 0.9696378078797565, 0.9141951532184377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 220}], {
             RGBColor[
             0.9102039368767765, 0.9312359287105942, 0.9912972581195953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 271}], {
             RGBColor[
             0.9633381097027147, 0.9705850700316176, 0.8762323728236365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 273}], {
             RGBColor[
             0.9463115906465231, 0.959417258650213, 0.9735944762837795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 282}], {
             RGBColor[
             0.7686727634935082, 0.8195414545387072, 0.9777357662240465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 350}], {
             RGBColor[
             0.5572153593126741, 0.6286847683937015, 0.9635627955418316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 394}], {
             RGBColor[
             0.9589815067022819, 0.9687835027313484, 0.9484325590679603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 151}], {
             RGBColor[
             0.9445031038385461, 0.9555736607263063, 0.8747447488649884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 171}], {
             RGBColor[
             0.8052741304752958, 0.8484170270939457, 0.981063587307365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 182}], {
             RGBColor[
             0.7179212679958578, 0.7786114198337015, 0.9734269922493177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 244}], {
             RGBColor[
             0.9451834660134726, 0.9553772594460359, 0.8287421125723953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 253}], {
             RGBColor[
             0.9415458239629964, 0.9543507494991403, 0.9237545295978378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 270}], {
             RGBColor[
             0.8944545509511294, 0.9186777958791756, 0.9897950676303644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 308}], {
             RGBColor[
             0.910603604080682, 0.831116448907371, 0.6244384372678482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 397}], {
             RGBColor[
             0.9044207133579241, 0.9266245432580819, 0.9907456490976226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 160}], {
             RGBColor[
             0.8024564351106218, 0.8460390058243679, 0.9559547088674527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 166}], {
             RGBColor[
             0.58916287485107, 0.6773479891459706, 0.960800206164449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[
             0.8076429404104031, 0.8499070929848217, 0.9471753082521508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 213}], {
             RGBColor[
             0.6055307056691227, 0.6906361315664411, 0.962088741763786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 224}], {
             RGBColor[
             0.7338240999955251, 0.7920255996267038, 0.9740993511139385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 230}], {
             RGBColor[
             0.8065033220600464, 0.8490571674850795, 0.9491043848592358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 247}], {
             RGBColor[
             0.800565209114379, 0.8446285325729683, 0.9591560611683537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 250}], {
             RGBColor[
             0.8138542935639312, 0.8542206496160933, 0.922381888236089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 289}], {
             RGBColor[
             0.6401076059738134, 0.7187072169053967, 0.9648107620151305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 302}], {
             RGBColor[
             0.810116914726091, 0.8517521789787007, 0.9429875150515328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 340}], {
             RGBColor[
             0.8181276925606058, 0.855449551640473, 0.8124349126944433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 370}], {
             RGBColor[
             0.651689794667871, 0.7278126197100234, 0.9659259838873935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 391}], {
             RGBColor[
             0.8092443957946988, 0.851101455788287, 0.9444644620129967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 400}], {
             RGBColor[
             0.6192009519955407, 0.7017342533718063, 0.9631649136303639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 108}], {
             RGBColor[
             0.9912650354406011, 0.9890160974409312, 0.6752294768892179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 133}], {
             RGBColor[
             0.9877962780668572, 0.9892214616063668, 0.8519107848595402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 143}], {
             RGBColor[
             0.9897948594153159, 0.9900479263551523, 0.8187891197528483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 223}], {
             RGBColor[
             0.6567019586100928, 0.7225279776373376, 0.8856886204073722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 231}], {
             RGBColor[
             0.6453566844681263, 0.7120372935751937, 0.8849900210522259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 234}], {
             RGBColor[
             0.6108224759518366, 0.6757396508292883, 0.8830233489660064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 290}], {
             RGBColor[
             0.9852063912114072, 0.9876640169215976, 0.8730472436673814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 313}], {
             RGBColor[
             0.7574729587785128, 0.8078427767184078, 0.8926534171636202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 331}], {
             RGBColor[
             0.8406286142199213, 0.8745901870367347, 0.8997207847740957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 342}], {
             RGBColor[
             0.9781735466554349, 0.9824189329669795, 0.8849520150410135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 346}], {
             RGBColor[
             0.9310197637199085, 0.9456320649287224, 0.9086166513015648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 109}], {
             RGBColor[
             0.8354005459022085, 0.8715590249721468, 0.9476971404299335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 138}], {
             RGBColor[
             0.8396417022002745, 0.8746432002351401, 0.9369859126247635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 144}], {
             RGBColor[
             0.8238227012416401, 0.8064203626686336, 0.6256302910665482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 205}], {
             RGBColor[
             0.7621912035876162, 0.8142278904155087, 0.9769107734772451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 207}], {
             RGBColor[
             0.7678187732112065, 0.8187151616770515, 0.9774475360917338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 233}], {
             RGBColor[
             0.8445389040702196, 0.8759601804737844, 0.8043524043090663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 358}], {
             RGBColor[
             0.8110972498966096, 0.8532242442230376, 0.9815754758331399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 366}], {
             RGBColor[
             0.8164094308012502, 0.857395482424949, 0.9798441446197601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 382}], {
             RGBColor[
             0.8283235406384996, 0.8662810060340052, 0.9596766643628065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 112}], {
             RGBColor[
             0.862628991352492, 0.8798181648999485, 0.6866247387515556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 113}], {
             RGBColor[
             0.9642676993183577, 0.9600262805675481, 0.6900227041475442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 148}], {
             RGBColor[
             0.9888632251122172, 0.9770515794230947, 0.5893659821095838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 155}], {
             RGBColor[
             0.9816199908186837, 0.9496620545793462, 0.38309756441442155`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 168}], {
             RGBColor[
             0.7774398833065403, 0.8121482874693805, 0.6788992920180124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 170}], {
             RGBColor[
             0.982100164568712, 0.9733257039532804, 0.6598369919305109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 180}], {
             RGBColor[
             0.9872121671974438, 0.9763688245450829, 0.6167282845582954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 239}], {
             RGBColor[
             0.9791151320753966, 0.9710994716073079, 0.664889873320532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 271}], {
             RGBColor[
             0.9895028643767154, 0.977316086696944, 0.5787655041634943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 282}], {
             RGBColor[
             0.7948375181675089, 0.8262724712040337, 0.6802688975639042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 326}], {
             RGBColor[
             0.9486059055549667, 0.9477245676525361, 0.6949975858554627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 350}], {
             RGBColor[
             0.5833801139866748, 0.6354157850590278, 0.6660959268816893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 394}], {
             RGBColor[
             0.9851462613762827, 0.9755145193966748, 0.650965690407818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.8828923993242874, 0.907570341389341, 0.9022720217327374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 173}], {
             RGBColor[
             0.7271460065380906, 0.7867712539126729, 0.973438776432092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 197}], {
             RGBColor[
             0.7526487213149836, 0.8066941685241928, 0.9759806487046332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 204}], {
             RGBColor[
             0.6951906016662049, 0.7613721755235602, 0.9705513590014307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 214}], {
             RGBColor[
             0.8529643941434419, 0.8859466480002223, 0.9857442955779845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 215}], {
             RGBColor[
             0.6785620375738817, 0.7478723580851365, 0.9692422975236459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 295}], {
             RGBColor[
             0.8784342064679533, 0.9051020504543855, 0.9481798625929193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 310}], {
             RGBColor[
             0.837867892321264, 0.8739091072308431, 0.9843043777573789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 345}], {
             RGBColor[
             0.8475922157093283, 0.7704232538101309, 0.6159161809017026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 363}], {
             RGBColor[
             0.7962303017276553, 0.8407404303748509, 0.9803244533471438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 131}], {
             RGBColor[
             0.9318016609297439, 0.9462172820478005, 0.9070304346238416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 197}], {
             RGBColor[
             0.859104460854622, 0.8889870230618099, 0.8999010623370051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 215}], {
             RGBColor[
             0.78501777711352, 0.8301652126227537, 0.8931627111560178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 297}], {
             RGBColor[
             0.9765341177488653, 0.939572352162843, 0.569876145491329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 307}], {
             RGBColor[
             0.77333098982858, 0.820677352221072, 0.8922426844508349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 352}], {
             RGBColor[
             0.9868878316639593, 0.9888457956727609, 0.8669660927394869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 363}], {
             RGBColor[
             0.9026860412672937, 0.923033284912468, 0.9042448669795157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 143}], {
             RGBColor[
             0.991911035790335, 0.989283235186998, 0.6645235792988118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 179}], {
             RGBColor[
             0.7347707339270855, 0.78692938937839, 0.7364340812522384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 196}], {
             RGBColor[
             0.9569228828322643, 0.9638344362199605, 0.7566199306806698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 231}], {
             RGBColor[
             0.6474728608431455, 0.7112726024070395, 0.7307244805981893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 234}], {
             RGBColor[
             0.6129386523268557, 0.6749749596611339, 0.7287578085119697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 290}], {
             RGBColor[
             0.9873225675864263, 0.9868993257534431, 0.7187817032133448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 313}], {
             RGBColor[
             0.759589135153532, 0.8070780855502533, 0.7383878767095835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 331}], {
             RGBColor[
             0.8427447905949406, 0.8738254958685803, 0.745455244320059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 342}], {
             RGBColor[
             0.9802897230304541, 0.9816542417988251, 0.7306864745869768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 344}], {
             RGBColor[
             0.9237250616247143, 0.9373633947199111, 0.7534534928578488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 136}], {
             RGBColor[
             0.9853924259753026, 0.9863090697404844, 0.7894325260874462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 205}], {
             RGBColor[
             0.9029750886865415, 0.9244278335951985, 0.9544113586539129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 207}], {
             RGBColor[
             0.9086026583101319, 0.9289151048567413, 0.9549481212684017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 233}], {
             RGBColor[
             0.985322789169145, 0.9861601236534743, 0.7818529894857341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 286}], {
             RGBColor[
             0.982388154942604, 0.9856547155710655, 0.8819616729879716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 320}], {
             RGBColor[
             0.7877886912973273, 0.833706097228517, 0.9434016404431109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 343}], {
             RGBColor[
             0.9491116719449652, 0.9612158927412748, 0.9588119071517155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 358}], {
             RGBColor[
             0.951881134995535, 0.9634241874027274, 0.9590760610098077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 366}], {
             RGBColor[
             0.9571933159001755, 0.9675954256046388, 0.9573447297964279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 382}], {
             RGBColor[
             0.9691074257374249, 0.976480949213695, 0.9371772495394743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 115}], {
             RGBColor[
             0.8884859280146999, 0.9132052056434676, 0.9618707970982566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 134}], {
             RGBColor[
             0.8956951827549291, 0.9185818560246592, 0.9496674092978227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 167}], {
             RGBColor[
             0.8997208182112904, 0.9208281051955814, 0.9089950054442884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 192}], {
             RGBColor[
             0.8989389379075864, 0.9205047775965927, 0.9219527855180263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 203}], {
             RGBColor[
             0.8996106860814155, 0.9207825627296116, 0.9108201798491318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 243}], {
             RGBColor[
             0.8558704371600068, 0.8879869198841999, 0.9860949647143535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 348}], {
             RGBColor[
             0.646138869577812, 0.7210249177273444, 0.9670486711010698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 351}], {
             RGBColor[
             0.9008189309641074, 0.9212822030390817, 0.8907964353054032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 369}], {
             RGBColor[
             0.9023363346837363, 0.9207812019172193, 0.7836200690864428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 160}], {
             RGBColor[
             0.9119283937868725, 0.9318988089935626, 0.9667708827205486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 166}], {
             RGBColor[
             0.6986348335273207, 0.7632077923151652, 0.9716163800175449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.9171148990866536, 0.9357668961540164, 0.9579914821052467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 197}], {
             RGBColor[
             0.7947010089555973, 0.8398735442706865, 0.9800850372976776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[
             0.7286729106717913, 0.7875940565410009, 0.9739810874834598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 155}], {
             RGBColor[
             0.8586477997327465, 0.8663886707383011, 0.6711585610937969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 170}], {
             RGBColor[
             0.8591279734827748, 0.8900523201122352, 0.9478979886098863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 180}], {
             RGBColor[
             0.8642399761115066, 0.8930954407040377, 0.9047892812376708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 183}], {
             RGBColor[
             0.858145806721998, 0.8893198217501983, 0.9495605407457641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 271}], {
             RGBColor[
             0.8665306732907783, 0.8940427028558988, 0.8668265008428696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 273}], {
             RGBColor[
             0.8495041542345867, 0.8828748914744943, 0.9641886043030126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 326}], {
             RGBColor[
             0.8256337144690296, 0.8644511838114909, 0.9830585825348379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 350}], {
             RGBColor[
             0.4604079229007377, 0.5521424012179826, 0.9541569235610645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 394}], {
             RGBColor[
             0.8621740702903455, 0.8922411355556297, 0.9390266870871933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 148}], {
             RGBColor[
             0.9675297419921456, 0.9739863112496491, 0.8808249441849478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 168}], {
             RGBColor[
             0.7561064001864688, 0.8090830192959348, 0.9703582540933764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 170}], {
             RGBColor[
             0.9607666814486404, 0.9702604357798348, 0.951295954005875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 251}], {
             RGBColor[
             0.963362859770404, 0.9721966613213543, 0.9469013012988804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 282}], {
             RGBColor[
             0.7735040350474374, 0.823207203030588, 0.9717278596392682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 153}], {
             RGBColor[
             0.9609537032731692, 0.9678135084545304, 0.8190182133911674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 154}], {
             RGBColor[
             0.8843020708880476, 0.9070645827487379, 0.8116086588659833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 188}], {
             RGBColor[
             0.9943339863314746, 0.9902892946219088, 0.624667562643189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 203}], {
             RGBColor[
             0.9915221538556642, 0.9901063168434335, 0.7424870906417769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 222}], {
             RGBColor[
             0.8230373362151477, 0.8592041063930396, 0.8055023626652851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 258}], {
             RGBColor[
             0.8284520864684763, 0.863434150444566, 0.8060420543668189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 312}], {
             RGBColor[
             0.9069528772263158, 0.9247595648126972, 0.8138662795579619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 327}], {
             RGBColor[
             0.706036101095787, 0.763386900870734, 0.7964636415924835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 356}], {
             RGBColor[
             0.9795308814306809, 0.9818827147676805, 0.7950044906763095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 361}], {
             RGBColor[
             0.805257442280949, 0.8449104272680121, 0.8040063713814543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 369}], {
             RGBColor[
             0.9942478024579853, 0.9901049560310413, 0.6152869798790879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 392}], {
             RGBColor[
             0.9940592450365886, 0.9897016507727538, 0.5947636682015899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 184}], {
             RGBColor[
             0.8954006573926184, 0.9186437741498937, 0.9625502458573427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 188}], {
             RGBColor[
             0.9802096699905436, 0.9821274332564904, 0.773104913243822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 195}], {
             RGBColor[
             0.9734279850394292, 0.9797032152668632, 0.9298636696235211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 203}], {
             RGBColor[
             0.9773978375147333, 0.9819444554780152, 0.89092444124241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 206}], {
             RGBColor[
             0.9801693237084979, 0.9820411366388294, 0.7687134694315312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 208}], {
             RGBColor[
             0.9790344665847976, 0.9826212436579354, 0.8638012620911807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 258}], {
             RGBColor[
             0.8143277701275454, 0.8552722890791477, 0.9544794049674519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 284}], {
             RGBColor[
             0.9550576023938764, 0.8947134347029815, 0.6078236591131951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 325}], {
             RGBColor[
             0.9739831246084136, 0.9801172374484541, 0.9289239631368187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 369}], {
             RGBColor[
             0.9801234861170542, 0.981943094665623, 0.763724330479721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 392}], {
             RGBColor[
             0.9799349286956577, 0.9815397894073354, 0.7432010188022229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 121}], {
             RGBColor[
             0.5859527900761765, 0.648379238348904, 0.8497638139674937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 130}], {
             RGBColor[
             0.5394524823746005, 0.6142380080563423, 0.9619114478846171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 135}], {
             RGBColor[
             0.5867492530425764, 0.6480956626790477, 0.7920105610145212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 147}], {
             RGBColor[
             0.4498270403680184, 0.5435753701452327, 0.9531499989482077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 172}], {
             RGBColor[
             0.5453143940260397, 0.618912137289847, 0.9624705622509216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 265}], {
             RGBColor[
             0.5863947227755413, 0.6473373582863682, 0.7534221293549463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 276}], {
             RGBColor[
             0.5754738720803751, 0.6113377707959187, 0.6396536519069874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 322}], {
             RGBColor[
             0.5577371942001383, 0.545766284938062, 0.6006518715819422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 328}], {
             RGBColor[
             0.5776363860535187, 0.6186324382097599, 0.6480546103361536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 362}], {
             RGBColor[
             0.5291469335723289, 0.606020643178081, 0.9609284954399844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 364}], {
             RGBColor[
             0.5186709551479936, 0.5976673823453749, 0.9599292872658549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 387}], {
             RGBColor[
             0.5318616885214638, 0.6081853150844612, 0.9611874311905233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 223}], {
             RGBColor[
             0.6554753253565242, 0.7220207332639502, 0.9060171078441056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 346}], {
             RGBColor[
             0.9297931304663398, 0.9451248205553351, 0.9289451387382982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 371}], {
             RGBColor[
             0.9889742900557708, 0.9897085998373097, 0.8323880776059407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 126}], {
             RGBColor[
             0.9445453655141952, 0.8123006936743022, 0.526012141444526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 149}], {
             RGBColor[
             0.9354066751952943, 0.7754467616892299, 0.2911564390194597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[
             0.7092318573606228, 0.6275890468244024, 0.5963896091616682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 212}], {
             RGBColor[
             0.814959075951097, 0.7120671712877802, 0.6056399439770516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 259}], {
             RGBColor[
             0.890500195999441, 0.7715813973601424, 0.6130362457085816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 293}], {
             RGBColor[
             0.9439670357622645, 0.8120615394594821, 0.535596562103439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 299}], {
             RGBColor[
             0.5802765370843588, 0.5133223017371997, 0.5878366487673804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 336}], {
             RGBColor[
             0.941538958836339, 0.8110318038895976, 0.5746868226312971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 367}], {
             RGBColor[
             0.9416875012753454, 0.7966334628653364, 0.31555626230597666`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 200}], {
             RGBColor[
             0.8612077030715526, 0.8908627680130986, 0.9106612182651956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 225}], {
             RGBColor[
             0.9828237455856703, 0.9860642046031639, 0.8850140677445499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 288}], {
             RGBColor[
             0.9910035942224118, 0.9893768342833873, 0.7136426440427857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 296}], {
             RGBColor[
             0.7273342415626659, 0.7835871839594812, 0.8991589206784876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 316}], {
             RGBColor[
             0.9669737009916766, 0.9742432672970294, 0.9118440588884795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 324}], {
             RGBColor[
             0.9421183017901158, 0.8053408410930318, 0.5411140570153194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 355}], {
             RGBColor[
             0.8974801233244831, 0.9191990583952923, 0.9142765141309684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 375}], {
             RGBColor[
             0.9908962523757869, 0.990503380648815, 0.8005361880842303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 380}], {
             RGBColor[
             0.988325616487183, 0.9894403566465484, 0.8431382773508248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 383}], {
             RGBColor[
             0.9436908127167734, 0.9559402747896526, 0.9187122422914181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 390}], {
             RGBColor[
             0.9208079851871533, 0.93769412925534, 0.9165296577739017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 136}], {
             RGBColor[
             0.9916980278640425, 0.9902469463090531, 0.7445080922308819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 237}], {
             RGBColor[
             0.8053643787648871, 0.8467935369815411, 0.8993644290069952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 246}], {
             RGBColor[
             0.9807490434451137, 0.9843984176431119, 0.8832203327572457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 254}], {
             RGBColor[
             0.9635449733987901, 0.971567650371643, 0.9123423358055727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 286}], {
             RGBColor[
             0.9886937568313439, 0.9895925921396342, 0.8370372391314074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 320}], {
             RGBColor[
             0.7940942931860671, 0.8376439737970857, 0.8984772065865467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 343}], {
             RGBColor[
             0.955417273833705, 0.9651537693098435, 0.9138874732951512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 349}], {
             RGBColor[
             0.9605995545746774, 0.9692859793034316, 0.9143817638585018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 130}], {
             RGBColor[
             0.9464782724507772, 0.9572232464052464, 0.8781742618521107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 158}], {
             RGBColor[
             0.968224884066228, 0.9743629808837895, 0.8732996704979752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 181}], {
             RGBColor[
             0.9695051173151372, 0.9753177767446366, 0.8711325695458796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 250}], {
             RGBColor[
             0.9895449247834203, 0.9899445719618365, 0.8229311834134514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 265}], {
             RGBColor[
             0.9934205128517178, 0.9903225966352723, 0.6696849433224401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 322}], {
             RGBColor[
             0.9647629842763149, 0.888751523286966, 0.5169146855494358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 362}], {
             RGBColor[
             0.9361727236485055, 0.9490058815269851, 0.877191309407478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 146}], {
             RGBColor[
             0.9396667615129652, 0.9450960517107332, 0.7007640437248652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.9197392315788462, 0.938489939946471, 0.9801006636617315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 165}], {
             RGBColor[
             0.9180785051229466, 0.8693033603706485, 0.6323678117439637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 210}], {
             RGBColor[
             0.9256074964723651, 0.9428664822956555, 0.9701672218856112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 228}], {
             RGBColor[
             0.6943109762202148, 0.7594825950104704, 0.9715233305138391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 262}], {
             RGBColor[
             0.914533409167413, 0.934607446115776, 0.9889127631083505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 298}], {
             RGBColor[
             0.9419926550850697, 0.953499171518578, 0.8713473070265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 314}], {
             RGBColor[
             0.8454411648150799, 0.8797521748090606, 0.9850786438938912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 385}], {
             RGBColor[
             0.8801747492559076, 0.9072914696222968, 0.9884330473969447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 174}], {
             RGBColor[
             0.901141546009415, 0.859475248613222, 0.631575719967193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 187}], {
             RGBColor[
             0.7934289192104743, 0.774996729530256, 0.6209521672295977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 193}], {
             RGBColor[
             0.9717214129908294, 0.912389969922506, 0.5031875207090143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 218}], {
             RGBColor[
             0.9301714314071496, 0.8826228912341284, 0.6343446163517137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 232}], {
             RGBColor[
             0.9707173841450503, 0.9101741995295372, 0.38894381611060824`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 235}], {
             RGBColor[
             0.7810922438672289, 0.7649812607257185, 0.6199809789558466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 275}], {
             RGBColor[
             0.9711668211795876, 0.9111354999013581, 0.43786226371614667`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 279}], {
             RGBColor[
             0.9706338432606825, 0.9119402318898231, 0.5212113656777875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 281}], {
             RGBColor[
             0.8631051892034496, 0.8294856701769681, 0.6278576642056808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 306}], {
             RGBColor[
             0.9598246352967073, 0.9053466801099388, 0.6052457900737029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 338}], {
             RGBColor[
             0.8612767280945337, 0.8280572624618638, 0.6276754202902846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.9712097680693306, 0.974332331454345, 0.702408800254371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 199}], {
             RGBColor[
             0.7560073977198083, 0.8036462548566385, 0.695157738616455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 238}], {
             RGBColor[
             0.9619595571288069, 0.876003125968948, 0.349304119148545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 252}], {
             RGBColor[
             0.9872732501376216, 0.9863124500793385, 0.6752175151398652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 277}], {
             RGBColor[
             0.9445520375160416, 0.953440530425368, 0.7124983952633934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 293}], {
             RGBColor[
             0.9907425761214501, 0.9881187474917182, 0.6343646915582258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 330}], {
             RGBColor[
             0.993601409370652, 0.9887223865776018, 0.5449310813985963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 179}], {
             RGBColor[
             0.6772729334376295, 0.7457361158478497, 0.9700833119233172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 196}], {
             RGBColor[
             0.8994250823428085, 0.9226411626894202, 0.9902691613517485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 303}], {
             RGBColor[
             0.930963142025431, 0.9465550503806308, 0.9505039620662723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 313}], {
             RGBColor[
             0.702091334664076, 0.765884812019713, 0.9720371073806623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 344}], {
             RGBColor[
             0.8662272611352585, 0.8961701211893707, 0.9871027235289276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 149}], {
             RGBColor[
             0.9809116513328295, 0.9532996428404313, 0.5796994155035606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 199}], {
             RGBColor[
             0.7547368334981579, 0.8054419279756039, 0.8849325856457692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 212}], {
             RGBColor[
             0.8604640520886321, 0.8899200524389816, 0.8941829204611524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 238}], {
             RGBColor[
             0.9606889929071565, 0.8777987990879134, 0.5390789661778591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 259}], {
             RGBColor[
             0.9360051721369761, 0.9494342785113439, 0.9015792221926826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 274}], {
             RGBColor[
             0.9852410474014941, 0.9875400944412754, 0.86628161750705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 299}], {
             RGBColor[
             0.6257815132218938, 0.6911751828884012, 0.8763796252514813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 318}], {
             RGBColor[
             0.7275263831310179, 0.78335125855074, 0.8827904793177039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 336}], {
             RGBColor[
             0.987043934973874, 0.9888846850407991, 0.8632297991153981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 367}], {
             RGBColor[
             0.9871924774128806, 0.9744863440165379, 0.6040992387900777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 139}], {
             RGBColor[
             0.7031618885198155, 0.7611437249489221, 0.817333346998714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 184}], {
             RGBColor[
             0.9097185095533559, 0.9272195890644053, 0.8351780748780158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 305}], {
             RGBColor[
             0.6750952542605706, 0.736833817023619, 0.815544965882065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 325}], {
             RGBColor[
             0.9883009767691511, 0.9886930523629657, 0.8015517921574917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 177}], {
             RGBColor[
             0.9536667276267875, 0.8895283267357603, 0.6069599752805885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 225}], {
             RGBColor[
             0.9594149697687826, 0.8938153563133775, 0.5972297007158511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 296}], {
             RGBColor[
             0.7039254657457782, 0.6913383356696949, 0.6113745536497885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 311}], {
             RGBColor[
             0.9397796304804293, 0.879171352422041, 0.6304672084143594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 316}], {
             RGBColor[
             0.9435649251747888, 0.8819944190072431, 0.6240596918597807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 324}], {
             RGBColor[
             0.9187095259732281, 0.7130919928032455, 0.2533296899866206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 380}], {
             RGBColor[
             0.9649168406702953, 0.897191508356762, 0.5553539103221259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 383}], {
             RGBColor[
             0.9202820368998856, 0.8636914264998662, 0.6309278752627192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 390}], {
             RGBColor[
             0.8973992093702656, 0.8454452809655536, 0.6287452907452029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 178}], {
             RGBColor[
             0.9237038531179507, 0.9374027629987973, 0.7580136578225289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 229}], {
             RGBColor[
             0.944551919435366, 0.9540264451746195, 0.7600021649991724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 249}], {
             RGBColor[
             0.7729571302677545, 0.8179864984379108, 0.7440031409044983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 270}], {
             RGBColor[
             0.9433677468342352, 0.9530822180859868, 0.7598892175593532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 308}], {
             RGBColor[
             0.9595167999637878, 0.8655208711141822, 0.39453258719683715`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 309}], {
             RGBColor[
             0.7517085916697956, 0.8007359775683325, 0.7423303781101054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 397}], {
             RGBColor[
             0.9533339092410298, 0.961028965464893, 0.7608397990266116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 135}], {
             RGBColor[
             0.9472747354171769, 0.95693967073539, 0.8204210088991382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 147}], {
             RGBColor[
             0.8103525227426189, 0.852419378201575, 0.9815604468328247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 158}], {
             RGBColor[
             0.921724576364652, 0.9402217505912277, 0.9854473044150986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 172}], {
             RGBColor[
             0.9058398764006403, 0.9277561453461891, 0.9908810101355388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 181}], {
             RGBColor[
             0.9230048096135612, 0.9411765464520747, 0.983280203463003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 265}], {
             RGBColor[
             0.9469202051501419, 0.9561813663427106, 0.7818325772395635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 322}], {
             RGBColor[
             0.9182626765747389, 0.8546102929944043, 0.6290623194665592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 328}], {
             RGBColor[
             0.9381618684281194, 0.9274764462661022, 0.6764650582207707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 347}], {
             RGBColor[
             0.9429491648074069, 0.9557638697007833, 0.9366607085405703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 362}], {
             RGBColor[
             0.8896724159469295, 0.9148646512344232, 0.9893389433246014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 364}], {
             RGBColor[
             0.8791964375225941, 0.9065113904017172, 0.988339735150472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 387}], {
             RGBColor[
             0.8923871708960643, 0.9170293231408033, 0.9895978790751403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 215}], {
             RGBColor[
             0.7274712991793381, 0.786519298743596, 0.9740007104147499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 217}], {
             RGBColor[
             0.9344806964429266, 0.9468284056726433, 0.8265251169027281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 262}], {
             RGBColor[
             0.9065415524196421, 0.9282349564782758, 0.9881504926773335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 269}], {
             RGBColor[
             0.8040953614489861, 0.8473233285739435, 0.9809919637743123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 279}], {
             RGBColor[
             0.933641462665115, 0.9469780873461244, 0.8765401586144759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 297}], {
             RGBColor[
             0.9189876398146835, 0.8959264382836853, 0.6507141447500612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 300}], {
             RGBColor[
             0.931702021030572, 0.9461760783888642, 0.908681725612914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 306}], {
             RGBColor[
             0.9228322547011398, 0.94038453556624, 0.9605745830103913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 307}], {
             RGBColor[
             0.715784511894398, 0.7770314383419143, 0.973080683709567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 314}], {
             RGBColor[
             0.8374493080673091, 0.8733796851715605, 0.984316373462874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 352}], {
             RGBColor[
             0.9293413537297774, 0.9451998817936034, 0.9478040919982191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 363}], {
             RGBColor[
             0.8451395633331118, 0.8793873710333104, 0.9850828662382478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 140}], {
             RGBColor[
             0.9346773354416151, 0.9476876138250295, 0.8715822846155408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 191}], {
             RGBColor[
             0.987492916761352, 0.9701957691860656, 0.5686051499013377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 198}], {
             RGBColor[
             0.9924437418296213, 0.9911433073066405, 0.7748902830598661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 216}], {
             RGBColor[
             0.9346836880494507, 0.9476926792220806, 0.8715828905329472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 219}], {
             RGBColor[
             0.9888495786781546, 0.9896358728849213, 0.8335074772063902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 220}], {
             RGBColor[
             0.9403853483846354, 0.9522390284059101, 0.8721267199856494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 302}], {
             RGBColor[
             0.9861355039224762, 0.987611720376026, 0.8381016978236878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 323}], {
             RGBColor[
             0.9807976523058931, 0.9476110700549507, 0.5425953117864818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 357}], {
             RGBColor[
             0.991075278465267, 0.9905774125375757, 0.7975692624768767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 145}], {
             RGBColor[
             0.8654831313094267, 0.8945040442418638, 0.9247486309085604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 164}], {
             RGBColor[
             0.9875665749683687, 0.9891264734720415, 0.8557175596540572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 223}], {
             RGBColor[
             0.6553493776113681, 0.7219686506346188, 0.9081043879236579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 234}], {
             RGBColor[
             0.6094698949531119, 0.6751803238265695, 0.9054391164822921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 280}], {
             RGBColor[
             0.9895800831926056, 0.9877458619439101, 0.6614686850799532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 346}], {
             RGBColor[
             0.9296671827211838, 0.9450727379260038, 0.9310324188178505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 167}], {
             RGBColor[
             0.9847172243848373, 0.9873666483251767, 0.8768958790371326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 201}], {
             RGBColor[
             0.9587019466865343, 0.9687205599749489, 0.954791011389049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 236}], {
             RGBColor[
             0.9878122905676103, 0.9883454533872911, 0.8037169692106247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 243}], {
             RGBColor[
             0.9408668433335536, 0.9545254630137952, 0.9539958383071978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 263}], {
             RGBColor[
             0.9836180216938042, 0.9869120997642138, 0.8951125122729298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 348}], {
             RGBColor[
             0.731135275751359, 0.7875634608569397, 0.9349495446939141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 351}], {
             RGBColor[
             0.9858153371376543, 0.987820746168677, 0.8586973088982475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 221}], {
             RGBColor[
             0.978907011276102, 0.9814521174204267, 0.7988125665749692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 276}], {
             RGBColor[
             0.9832961251229514, 0.9540394334749664, 0.49816321292150856`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 322}], {
             RGBColor[
             0.9655594472427147, 0.8884679476171097, 0.4591614325964633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 364}], {
             RGBColor[
             0.9264932081905699, 0.9403690450244226, 0.8184388482803762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 376}], {
             RGBColor[
             0.9943178872359044, 0.9902548602843526, 0.6229152754424857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 377}], {
             RGBColor[
             0.9728407006837848, 0.9173356911770784, 0.4650201000281331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 194}], {
             RGBColor[
             0.994838962807073, 0.9913693882422605, 0.6796311356585165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 237}], {
             RGBColor[
             0.808266771850316, 0.8474057620016203, 0.8085236633444043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 246}], {
             RGBColor[
             0.9836514365305427, 0.985010642663191, 0.7923795670946547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 254}], {
             RGBColor[
             0.966447366484219, 0.9721798753917221, 0.8215015701429818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 286}], {
             RGBColor[
             0.9915961499167728, 0.9902048171597133, 0.7461964734688165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 320}], {
             RGBColor[
             0.7969966862714961, 0.8382561988171648, 0.8076364409239558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 343}], {
             RGBColor[
             0.958319666919134, 0.9657659943299227, 0.8230467076325603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 349}], {
             RGBColor[
             0.9635019476601063, 0.9698982043235107, 0.8235409981959109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 376}], {
             RGBColor[
             0.9943323446680639, 0.990285783269871, 0.62448887771211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 199}], {
             RGBColor[
             0.7346256956941077, 0.7914163577234106, 0.9625611150008273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 238}], {
             RGBColor[
             0.9405778551031063, 0.86377322883572, 0.6167074955329173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 252}], {
             RGBColor[
             0.965891548111921, 0.9740825529461106, 0.9426208915242374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 277}], {
             RGBColor[
             0.923170335490341, 0.94121063329214, 0.9799017716477657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 285}], {
             RGBColor[
             0.9502953596896759, 0.9624509411572149, 0.9690211703856899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 293}], {
             RGBColor[
             0.9693608740957496, 0.9758888503584903, 0.9017680679425981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 330}], {
             RGBColor[
             0.9722197073449514, 0.9764924894443738, 0.8123344577829685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 144}], {
             RGBColor[
             0.9688477426386315, 0.9197044811113169, 0.592419648438046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 233}], {
             RGBColor[
             0.9895639454672109, 0.9892442989164676, 0.771141761680564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 242}], {
             RGBColor[
             0.982521930443962, 0.9666984345032787, 0.6410222527256377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 256}], {
             RGBColor[
             0.9189379331394455, 0.9368585648161107, 0.9448181559290258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 257}], {
             RGBColor[
             0.9815887295142152, 0.9857106129743178, 0.9125176014274854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 317}], {
             RGBColor[
             0.9889487884460753, 0.9879285402501738, 0.7041857162390149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 366}], {
             RGBColor[
             0.9614344721982415, 0.9706796008676322, 0.946633501991258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 381}], {
             RGBColor[
             0.9778587649225832, 0.9509684822363358, 0.6229067352399993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 382}], {
             RGBColor[
             0.9733485820354908, 0.9795651244766884, 0.9264660217343044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 184}], {
             RGBColor[
             0.6179716143036786, 0.696844585792433, 0.965280705343849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 305}], {
             RGBColor[
             0.38334835901089337`, 0.5064588137516468, 0.9456475963478983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 325}], {
             RGBColor[
             0.696554081519474, 0.7583180490909935, 0.931654422623325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 141}], {
             RGBColor[
             0.8719170246617811, 0.6988786222996899, 0.5998357445071911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 168}], {
             RGBColor[
             0.7224993794758683, 0.782472269523427, 0.9736215040351768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 191}], {
             RGBColor[
             0.9285357560968216, 0.9262476682101228, 0.6850310313923059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 216}], {
             RGBColor[
             0.8757265273849204, 0.9037445782461377, 0.9880087720239153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 219}], {
             RGBColor[
             0.9298924180136243, 0.9456877719089785, 0.9499333586973584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 220}], {
             RGBColor[
             0.8814281877201051, 0.9082909274299673, 0.9885526014766175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 350}], {
             RGBColor[
             0.5284396101560027, 0.6057397671130744, 0.9608181388988537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 357}], {
             RGBColor[
             0.9321181178007367, 0.9466293115616329, 0.9139951439678448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 150}], {
             RGBColor[
             0.8903962949720701, 0.7136134908386842, 0.6015983138060258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 189}], {
             RGBColor[
             0.9276336626140468, 0.7414866838564762, 0.5371137105624021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 219}], {
             RGBColor[
             0.9260892678983206, 0.7408268813595815, 0.5617609370980404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 220}], {
             RGBColor[
             0.8776250376048014, 0.7034300368805704, 0.6003801798772996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 273}], {
             RGBColor[
             0.913732691374548, 0.7316113668201891, 0.5826773980414838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 339}], {
             RGBColor[
             0.8322910392872664, 0.6674720066051705, 0.5960057440664988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 350}], {
             RGBColor[
             0.524636460040699, 0.4008788765636775, 0.5726457172995357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 357}], {
             RGBColor[
             0.928314967685433, 0.7417684210122361, 0.5258227223685269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 394}], {
             RGBColor[
             0.9264026074303068, 0.7409776109013244, 0.5575154808256645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 202}], {
             RGBColor[
             0.9185449741713969, 0.9376949457632173, 0.9854395515158552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 214}], {
             RGBColor[
             0.911720713199657, 0.9324453649786627, 0.991441929599314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 217}], {
             RGBColor[
             0.9443277538936853, 0.9546801819926242, 0.8274643380329534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 257}], {
             RGBColor[
             0.9362300066641219, 0.9508844140397086, 0.955503404500867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 268}], {
             RGBColor[
             0.9391364805934785, 0.9530301834812808, 0.9496039373480365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 275}], {
             RGBColor[
             0.9440214980347787, 0.9540251316776402, 0.7941302777830603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 279}], {
             RGBColor[
             0.9434885201158736, 0.9548298636661052, 0.8774793797447011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 300}], {
             RGBColor[
             0.9415490784813305, 0.9540278547088452, 0.9096209467431394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 306}], {
             RGBColor[
             0.9326793121518984, 0.9482363118862209, 0.9615138041406166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 338}], {
             RGBColor[
             0.8341314049497248, 0.870946894238146, 0.9839434343571982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 363}], {
             RGBColor[
             0.8549866207838703, 0.8872391473532913, 0.9860220873684732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 381}], {
             RGBColor[
             0.9325000420724899, 0.9161422833017264, 0.6658925383133808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 223}], {
             RGBColor[
             0.6573479589598268, 0.7227951153834044, 0.874982722816966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 234}], {
             RGBColor[
             0.6114684763015705, 0.676006788575355, 0.8723174513756002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 260}], {
             RGBColor[
             0.9921321571109523, 0.9910144590181089, 0.7800540482036149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 267}], {
             RGBColor[
             0.9719246526179564, 0.9775438697684166, 0.8859173751716953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 272}], {
             RGBColor[
             0.8312687254183482, 0.8670406481302262, 0.8880175936634376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 290}], {
             RGBColor[
             0.9858523915611411, 0.9879311546676642, 0.8623413460769753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 291}], {
             RGBColor[
             0.9774581814158485, 0.9816707664855626, 0.8765505542923154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 321}], {
             RGBColor[
             0.9833126453830918, 0.9860370161265278, 0.8666404738845217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 331}], {
             RGBColor[
             0.8412746145696552, 0.8748573247828014, 0.8890148871836896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 342}], {
             RGBColor[
             0.9788195470051688, 0.9826860707130463, 0.8742461174506073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 398}], {
             RGBColor[
             0.9881806123153312, 0.9893803936950505, 0.8455413717371743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 207}], {
             RGBColor[
             0.8970248136495635, 0.8637764425532282, 0.6328812719050165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 233}], {
             RGBColor[
             0.9737449445085766, 0.921021461349961, 0.45978614012234886`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 242}], {
             RGBColor[
             0.9667029294853278, 0.8984755969367723, 0.32966663116742245`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 317}], {
             RGBColor[
             0.973129787487441, 0.9197057026836672, 0.39283009468079966`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 358}], {
             RGBColor[
             0.9403032903349666, 0.8982855250992142, 0.6370092116464223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 366}], {
             RGBColor[
             0.9456154712396072, 0.9024567633011257, 0.6352778804330428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 370}], {
             RGBColor[
             0.807405506651182, 0.7935951254792675, 0.6239939785371775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 391}], {
             RGBColor[
             0.9649601077780098, 0.916883961557531, 0.6025324566627808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 162}], {
             RGBColor[
             0.8687524006762641, 0.8958559711414414, 0.8705683769021542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 164}], {
             RGBColor[
             0.866606009209663, 0.8949683831102573, 0.9061396381867916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 227}], {
             RGBColor[
             0.8646061877165536, 0.8941414055297884, 0.9392818556997374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 280}], {
             RGBColor[
             0.8686195174338998, 0.8935877715821259, 0.7118907636126875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 359}], {
             RGBColor[
             0.47958114705472416`, 0.5716381479565367, 0.9553527482502334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 154}], {
             RGBColor[
             0.881588528090521, 0.8991570501762955, 0.6951260365734102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 159}], {
             RGBColor[
             0.9691670966007075, 0.968269644213561, 0.6914717326419888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 165}], {
             RGBColor[
             0.9675063701448081, 0.8990830646377386, 0.343738880724221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 192}], {
             RGBColor[
             0.9881368628843086, 0.9819209991379723, 0.6371370740180983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 228}], {
             RGBColor[
             0.7437388412420762, 0.7892622992775604, 0.6828943994940964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 262}], {
             RGBColor[
             0.9639612741892745, 0.964387150382866, 0.7002838320886078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 297}], {
             RGBColor[
             0.9764073615843157, 0.9320786321882755, 0.36284748416133555`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 307}], {
             RGBColor[
             0.7732042336640303, 0.8131836322465045, 0.6852140231208415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 314}], {
             RGBColor[
             0.8948690298369414, 0.9095318790761507, 0.6964497128741485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 332}], {
             RGBColor[
             0.9836351171234783, 0.9564595487795757, 0.3909259495838773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 385}], {
             RGBColor[
             0.9296026142777689, 0.9370711738893869, 0.699804116377202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 172}], {
             RGBColor[
             0.816214434394058, 0.8570935074350796, 0.9821195611991294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 211}], {
             RGBColor[
             0.8361099491320951, 0.8725503717714799, 0.9698965922542928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 328}], {
             RGBColor[
             0.8485364264215371, 0.8568138083549925, 0.6677036092843613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 347}], {
             RGBColor[
             0.8533237228008247, 0.8851012317896737, 0.9278992596041609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 364}], {
             RGBColor[
             0.789570995516012, 0.8358487524906077, 0.9795782862140627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 372}], {
             RGBColor[
             0.800815039503146, 0.8448144479545052, 0.9806507531672322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 387}], {
             RGBColor[
             0.8027617288894822, 0.8463666852296938, 0.9808364301387309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 161}], {
             RGBColor[
             0.9932272484802462, 0.9914673074418764, 0.7619055502087961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 168}], {
             RGBColor[
             0.7807019259803285, 0.8261083181514814, 0.869701532055416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 170}], {
             RGBColor[
             0.9853622072425001, 0.9872857346353814, 0.8506392319679146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 251}], {
             RGBColor[
             0.9879583855642637, 0.9892219601769009, 0.8462445792609199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.798099560841297, 0.8402325018861346, 0.8710711376013078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 312}], {
             RGBColor[
             0.9057546550543786, 0.924919959303941, 0.8814002119863212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 326}], {
             RGBColor[
             0.9518679482287548, 0.9616845983346372, 0.8857998258928662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 356}], {
             RGBColor[
             0.9783326592587437, 0.9820431092589244, 0.8625384231046689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 199}], {
             RGBColor[
             0.7455981431792571, 0.7685879959905315, 0.6500768832207029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 212}], {
             RGBColor[
             0.8513253617697312, 0.8530661204539092, 0.6593272180360862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 238}], {
             RGBColor[
             0.9515503025882557, 0.840944867102841, 0.30422326375279285`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 259}], {
             RGBColor[
             0.9268664818180752, 0.9125803465262716, 0.6667235197676162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 274}], {
             RGBColor[
             0.9761023570825932, 0.9506861624562031, 0.6314259150819838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 287}], {
             RGBColor[
             0.980795184571855, 0.9532514808417092, 0.581629571139223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 299}], {
             RGBColor[
             0.616642822902993, 0.6543212509033288, 0.641523922826415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 318}], {
             RGBColor[
             0.7183876928121171, 0.7464973265656676, 0.6479347768926376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 336}], {
             RGBColor[
             0.9779052446549732, 0.9520307530557266, 0.6283740966903317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 367}], {
             RGBColor[
             0.9780537870939797, 0.9376324120314656, 0.36924353636501134`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 186}], {
             RGBColor[
             0.9460276202394307, 0.93765178389154, 0.6829577141857134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 189}], {
             RGBColor[
             0.9499160830396394, 0.9610824429448674, 0.9270487014605546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 226}], {
             RGBColor[
             0.9488537414674575, 0.9606431374038371, 0.9446544505634673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 241}], {
             RGBColor[
             0.953621557045057, 0.9619956866454256, 0.8206399154497288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 255}], {
             RGBColor[
             0.7689783197433517, 0.8199385315044291, 0.9775883099192124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 266}], {
             RGBColor[
             0.9458951854044106, 0.9585756686255094, 0.9558880014635033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 365}], {
             RGBColor[
             0.8958183012636641, 0.9197652133603748, 0.9899251433526082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 374}], {
             RGBColor[
             0.9433185113186524, 0.928513323372731, 0.6724333376007819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 399}], {
             RGBColor[
             0.9489576219986801, 0.9606860946731055, 0.942932881326912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 171}], {
             RGBColor[
             0.8541385107615818, 0.8843686648524438, 0.8659003211021699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 182}], {
             RGBColor[
             0.7667856482821438, 0.8145630575921996, 0.8582637260441226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 244}], {
             RGBColor[
             0.9940478462997586, 0.991328897204534, 0.7135788463672001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 249}], {
             RGBColor[
             0.7729083146709348, 0.8195337139895976, 0.8587457247703142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 253}], {
             RGBColor[
             0.9904102042492823, 0.9903023872576383, 0.8085912633926426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 270}], {
             RGBColor[
             0.9433189312374153, 0.9546294336376736, 0.8746318014251693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 308}], {
             RGBColor[
             0.959467984366968, 0.8670680866658689, 0.5092751710626531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 386}], {
             RGBColor[
             0.9568065938395571, 0.9653841296837733, 0.87591826672474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 397}], {
             RGBColor[
             0.9532850936442101, 0.9625761810165798, 0.8755823828924275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 156}], {
             RGBColor[
             0.9862979976145638, 0.9886018841352922, 0.8767411693795588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 175}], {
             RGBColor[
             0.9892029812476664, 0.9898031695222541, 0.8285980727223967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 242}], {
             RGBColor[
             0.9833328997908617, 0.9670337911691833, 0.6275823919261164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 256}], {
             RGBColor[
             0.9197489024863452, 0.9371939214820153, 0.9313782951295047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 261}], {
             RGBColor[
             0.9862979976145638, 0.9886018841352922, 0.8767411693795588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 264}], {
             RGBColor[
             0.9649048410623843, 0.9729983333391297, 0.9286919714915238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 317}], {
             RGBColor[
             0.9897597577929749, 0.9882638969160784, 0.6907458554394936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 333}], {
             RGBColor[
             0.9897555591904017, 0.988254916529718, 0.6902888634601676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 381}], {
             RGBColor[
             0.9786697342694829, 0.9513038389022404, 0.6094668744404779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 154}], {
             RGBColor[
             0.8507340620313371, 0.8841872700805603, 0.9855265149668822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 188}], {
             RGBColor[
             0.960765977474764, 0.9674119819537312, 0.7985854187440877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 195}], {
             RGBColor[
             0.9539842925236497, 0.964987763964104, 0.9553441751237868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 203}], {
             RGBColor[
             0.9579541449989537, 0.9672290041752559, 0.9164049467426757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 258}], {
             RGBColor[
             0.7948840776117658, 0.8405568377763883, 0.9799599104677177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 278}], {
             RGBColor[
             0.96115180561915, 0.9682372293413637, 0.8405804312052099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 284}], {
             RGBColor[
             0.9356139098780968, 0.8799979834002223, 0.6333041646134608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 312}], {
             RGBColor[
             0.8733848683696053, 0.9018822521445196, 0.9877841356588607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 327}], {
             RGBColor[
             0.6724680922390763, 0.7405095882025564, 0.9703814976933822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 337}], {
             RGBColor[
             0.9454330463441023, 0.958610258564778, 0.969819204383563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[
             0.9459628725739704, 0.9590054020995029, 0.9689223467772083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 361}], {
             RGBColor[
             0.7716894334242383, 0.8220331145998345, 0.977924227482353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 369}], {
             RGBColor[
             0.9606797936012746, 0.9672276433628637, 0.7892048359799866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 392}], {
             RGBColor[
             0.9604912361798781, 0.9668243381045762, 0.7686815243024887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 192}], {
             RGBColor[
             0.8806307644400031, 0.9062022933364445, 0.9201279978863861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[
             0.8813025126138321, 0.9064800784694634, 0.9089953922174916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 222}], {
             RGBColor[
             0.7128176949733156, 0.7755778680190695, 0.9720106642409997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 228}], {
             RGBColor[
             0.6362327427977706, 0.7135435934760328, 0.9658853233623841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 312}], {
             RGBColor[
             0.7967332359844836, 0.8411333264387271, 0.9803745811336766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 332}], {
             RGBColor[
             0.8761290186791728, 0.880740842978048, 0.673916873452165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 356}], {
             RGBColor[
             0.8693112401888488, 0.8982564763937104, 0.9615127922520241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 361}], {
             RGBColor[
             0.6950378010391167, 0.761284188894042, 0.9705146729571688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 385}], {
             RGBColor[
             0.8220965158334633, 0.861352468087859, 0.9827950402454897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 170}], {
             RGBColor[
             0.9781189729489665, 0.959896209791633, 0.6443708142727522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 180}], {
             RGBColor[
             0.9832309755776982, 0.9629393303834355, 0.6012621069005368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 183}], {
             RGBColor[
             0.9771368061881897, 0.9591637114295961, 0.6460333664086302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 239}], {
             RGBColor[
             0.9751339404556512, 0.9576699774456605, 0.6494236956627732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 271}], {
             RGBColor[
             0.98552167275697, 0.9638865925352966, 0.5632993265057357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 326}], {
             RGBColor[
             0.9446247139352212, 0.9342950734908886, 0.679531408197704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 335}], {
             RGBColor[
             0.9494620208263472, 0.938152210700675, 0.6799927948472944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 337}], {
             RGBColor[
             0.9705595987353419, 0.9542584408804511, 0.6571668630158614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 354}], {
             RGBColor[
             0.9810191276242988, 0.9620246744128051, 0.6379181515673793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 175}], {
             RGBColor[
             0.9892122965711652, 0.9898070216479138, 0.828443693704737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 202}], {
             RGBColor[
             0.9647239816918887, 0.9728603534893909, 0.9288595086252925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 214}], {
             RGBColor[
             0.9578997207201487, 0.9676107727048362, 0.9348618867087513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 256}], {
             RGBColor[
             0.919758217809844, 0.9371977736076751, 0.9312239161118449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 261}], {
             RGBColor[
             0.9863073129380626, 0.9886057362609518, 0.8765867903618991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 264}], {
             RGBColor[
             0.9649141563858831, 0.9730021854647893, 0.9285375924738641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 295}], {
             RGBColor[
             0.9833695330446601, 0.9867661751589996, 0.8972974537236862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 310}], {
             RGBColor[
             0.9428032188979708, 0.9555732319354571, 0.9334219688881458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 363}], {
             RGBColor[
             0.9011656283043621, 0.9224045550794648, 0.9294420444779106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 381}], {
             RGBColor[
             0.9786790495929817, 0.9513076910278999, 0.6093124954228182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 187}], {
             RGBColor[
             0.7988165456934913, 0.8432259917321046, 0.9594771232542915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 218}], {
             RGBColor[
             0.9355590578901665, 0.9508521534359771, 0.9728695723764074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 253}], {
             RGBColor[
             0.9732340607632315, 0.979016828845105, 0.9059309020920383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 298}], {
             RGBColor[
             0.9763808054158831, 0.9803180886266252, 0.8537811996834883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.944751421229012, 0.9583162809306178, 0.9784056121088676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 265}], {
             RGBColor[
             0.9686668167655925, 0.9733211008212537, 0.776957985885428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 311}], {
             RGBColor[
             0.9408827499995347, 0.9554310322620414, 0.9849542633893179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 322}], {
             RGBColor[
             0.9400092881901896, 0.8717500274729474, 0.6241877281124237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 362}], {
             RGBColor[
             0.9114190275623801, 0.9320043857129663, 0.9844643519704659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 165}], {
             RGBColor[
             0.947578840210689, 0.8924769528734762, 0.6230755006610873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 167}], {
             RGBColor[
             0.9689912132538936, 0.9756382149726988, 0.9035159138812268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 192}], {
             RGBColor[
             0.9682093329501895, 0.97531488737371, 0.9164736939549646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 201}], {
             RGBColor[
             0.9429759355555904, 0.956992126622471, 0.9814110462331429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 210}], {
             RGBColor[
             0.9551078315601075, 0.9660400747984832, 0.9608749108027348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 228}], {
             RGBColor[
             0.7238113113079572, 0.7826561875132982, 0.9622310194309626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 236}], {
             RGBColor[
             0.9720862794366665, 0.9766170200348131, 0.8303370040547189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 243}], {
             RGBColor[
             0.9251408322026099, 0.9427970296613172, 0.980615873151292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 263}], {
             RGBColor[
             0.9678920105628603, 0.9751836664117359, 0.9217325471170239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 166}], {
             RGBColor[
             0.7500219922483168, 0.8034703629640165, 0.9518268774516392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 185}], {
             RGBColor[
             0.9685020578076498, 0.9760294668028677, 0.9382019795393408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 213}], {
             RGBColor[
             0.7663898230663695, 0.816758505384487, 0.9531154130509761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 224}], {
             RGBColor[
             0.8946832173927719, 0.9181479734447497, 0.9651260224011287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 247}], {
             RGBColor[
             0.9614243265116258, 0.9707509063910144, 0.9501827324555439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 289}], {
             RGBColor[
             0.8009667233710602, 0.8448295907234427, 0.9558374333023205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 302}], {
             RGBColor[
             0.9709760321233378, 0.9778745527967467, 0.9340141863387229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 340}], {
             RGBColor[
             0.9789868099578526, 0.9815719254585189, 0.8034615839816335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 370}], {
             RGBColor[
             0.8125489120651177, 0.8539349935280693, 0.9569526551745835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 400}], {
             RGBColor[
             0.7800600693927875, 0.8278566271898522, 0.954191584917554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 170}], {
             RGBColor[
             0.9864641879367411, 0.9877414319720621, 0.8323765600297234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 222}], {
             RGBColor[
             0.8229410947374514, 0.8598201982209641, 0.8547736231554532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 239}], {
             RGBColor[
             0.9834791554434257, 0.9855151996260896, 0.8374294414197444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 251}], {
             RGBColor[
             0.9890603662585047, 0.9896776575135816, 0.8279819073227288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 312}], {
             RGBColor[
             0.9068566357486195, 0.9253756566406217, 0.86313754004813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 326}], {
             RGBColor[
             0.9529699289229957, 0.9621402956713179, 0.867537153954675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 327}], {
             RGBColor[
             0.7059398596180906, 0.7640029926986586, 0.8457349020826517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 337}], {
             RGBColor[
             0.9789048137231164, 0.9821036630608801, 0.8451726087728324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.9794346399529846, 0.9824988065956051, 0.8442757511664777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 179}], {
             RGBColor[
             0.734571245920179, 0.7884866804434032, 0.8589351352161545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 231}], {
             RGBColor[
             0.6472733728362391, 0.7128298934720527, 0.8532255345621054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 313}], {
             RGBColor[
             0.7593896471466255, 0.8086353766152665, 0.8608889306734997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 359}], {
             RGBColor[
             0.6038109821802673, 0.6671481652178985, 0.8507504157110928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 164}], {
             RGBColor[
             0.9797582503806899, 0.9514228680635897, 0.5891387930779022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 169}], {
             RGBColor[
             0.9783737063791937, 0.9508503235378132, 0.6120842702677112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 209}], {
             RGBColor[
             0.9012379681580279, 0.8909265945902537, 0.6624868133473487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 227}], {
             RGBColor[
             0.9777584288875806, 0.9505958904831208, 0.6222810105908481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 240}], {
             RGBColor[
             0.9754071036330012, 0.9287045272467556, 0.3589616709033426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 245}], {
             RGBColor[
             0.9202212028675953, 0.9060633106614835, 0.6642974512204809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 280}], {
             RGBColor[
             0.9817717586049267, 0.9500422565354583, 0.39488991850379823`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 304}], {
             RGBColor[
             0.9808830666198037, 0.9518880084849219, 0.5704976770646721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 315}], {
             RGBColor[
             0.7695234772064141, 0.786800233885812, 0.6501602591021634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 319}], {
             RGBColor[
             0.9804992721254259, 0.9517292995984281, 0.5768581450648259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 329}], {
             RGBColor[
             0.6790985798896452, 0.711598588870039, 0.6435364390541762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 371}], {
             RGBColor[
             0.9810400177229359, 0.9519529117995265, 0.5678965911093381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 169}], {
             RGBColor[
             0.9873049088671089, 0.9890182678146584, 0.8600540441220974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 209}], {
             RGBColor[
             0.9101691706459429, 0.929094538867099, 0.910456587201735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 227}], {
             RGBColor[
             0.9866896313754956, 0.9887638347599661, 0.8702507844452343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 245}], {
             RGBColor[
             0.9291524053555104, 0.9442312549383288, 0.9122672250748671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 280}], {
             RGBColor[
             0.9907029610928417, 0.9882102008123036, 0.6428596923581844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 304}], {
             RGBColor[
             0.9898142691077187, 0.9900559527617672, 0.8184674509190583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 315}], {
             RGBColor[
             0.7784546796943291, 0.8249681781626572, 0.8981300329565496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 228}], {
             RGBColor[
             0.7221505848520576, 0.7134696079374757, 0.6144981675131949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 262}], {
             RGBColor[
             0.9423730177992559, 0.8885944590427812, 0.6318876001077063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 298}], {
             RGBColor[
             0.9698322637169126, 0.9074861844455833, 0.5143221440258557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 307}], {
             RGBColor[
             0.7516159772740119, 0.7373909409064198, 0.61681779113994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 314}], {
             RGBColor[
             0.8732807734469228, 0.833739187736066, 0.628053480893247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 332}], {
             RGBColor[
             0.9620468607334598, 0.8806668574394909, 0.3225297176029759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 385}], {
             RGBColor[
             0.9080143578877504, 0.8612784825493021, 0.6314078843963005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 185}], {
             RGBColor[
             0.7552084975480979, 0.8073384501244704, 0.9430474768363372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 213}], {
             RGBColor[
             0.5530962628068177, 0.6480674887060898, 0.9579609103479725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 224}], {
             RGBColor[
             0.6813896571332201, 0.7494569567663525, 0.9699715196981249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 247}], {
             RGBColor[
             0.748130766252074, 0.802059889712617, 0.9550282297525401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 289}], {
             RGBColor[
             0.5876731631115084, 0.6761385740450454, 0.9606829305993169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 302}], {
             RGBColor[
             0.757682471863786, 0.8091835361183494, 0.9388596836357193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 340}], {
             RGBColor[
             0.7656932496983008, 0.8128809087801216, 0.8083070812786297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 400}], {
             RGBColor[
             0.5667665091332357, 0.659165610511455, 0.9590370822145503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 192}], {
             RGBColor[
             0.9879609795374946, 0.98928956989711, 0.8491812552573363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[
             0.9627275821428956, 0.9709668091458711, 0.9141186075355147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.9886327277113236, 0.9895673550301289, 0.8380486495884418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 228}], {
             RGBColor[
             0.7435629578952622, 0.7966308700366983, 0.8949385807333343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 243}], {
             RGBColor[
             0.9448924787899149, 0.9567717121847172, 0.9133234344536636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 348}], {
             RGBColor[
             0.7351609112077202, 0.7898097100278618, 0.8942771408403798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 351}], {
             RGBColor[
             0.9898409725940156, 0.9900669953395993, 0.8180249050447133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 170}], {
             RGBColor[
             0.7739388654368232, 0.8223824426816673, 0.9401725418763431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 180}], {
             RGBColor[
             0.779050868065555, 0.8254255632734697, 0.8970638345041277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 220}], {
             RGBColor[
             0.7282073924188885, 0.7870236841043076, 0.9741659394052854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 251}], {
             RGBColor[
             0.776535043758587, 0.8243186682231867, 0.9357778891693487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 282}], {
             RGBColor[
             0.5866762190356201, 0.6753292099324204, 0.9606044475097365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 350}], {
             RGBColor[
             0.37521881485478603`, 0.4844725237874147, 0.9464314768275215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 357}], {
             RGBColor[
             0.7788973224995202, 0.8253620682359732, 0.8996084818965127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 394}], {
             RGBColor[
             0.7769849622443938, 0.8245712581250617, 0.9313012403536503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 209}], {
             RGBColor[
             0.9087846266444468, 0.9285219943413225, 0.9334020643915438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 227}], {
             RGBColor[
             0.9853050873739995, 0.9881912902341896, 0.8931962616350433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 240}], {
             RGBColor[
             0.98295376211942, 0.9662999269978244, 0.6298769219475377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 245}], {
             RGBColor[
             0.9277678613540141, 0.9436587104125523, 0.9352127022646761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 280}], {
             RGBColor[
             0.9893184170913456, 0.9876376562865271, 0.6658051695479934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 292}], {
             RGBColor[0.9711109620283498, 0.9776880391, 0.9209268813047109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 304}], {
             RGBColor[
             0.9884297251062226, 0.9894834082359907, 0.8414129281088671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 315}], {
             RGBColor[
             0.7770701356928329, 0.8243956336368807, 0.9210755101463585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 329}], {
             RGBColor[
             0.6866452383760641, 0.7491939886211079, 0.9144516900983715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 353}], {
             RGBColor[
             0.6816294004123877, 0.7448495218803177, 0.9141320853386573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 378}], {
             RGBColor[
             0.9899282816964011, 0.9889420950099709, 0.7321851681602244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 180}], {
             RGBColor[
             0.9837111493277266, 0.9866029797573697, 0.8780015344166262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 239}], {
             RGBColor[
             0.9756141142056795, 0.9813336268195947, 0.9261631231788627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 251}], {
             RGBColor[
             0.9811953250207586, 0.9854960847070866, 0.9167155890818471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 271}], {
             RGBColor[
             0.9860018465069983, 0.9875502419092308, 0.840038754021825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 282}], {
             RGBColor[
             0.7913365002977917, 0.8365066264163203, 0.941542147422235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 326}], {
             RGBColor[
             0.9451048876852495, 0.9579587228648229, 0.9562708357137935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 182}], {
             RGBColor[
             0.6275566749188934, 0.707406423959839, 0.9645825644864991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 244}], {
             RGBColor[
             0.8548188729365083, 0.8841722635721734, 0.8198976848095767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 253}], {
             RGBColor[
             0.851181230886032, 0.8831457536252778, 0.9149101018350192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 270}], {
             RGBColor[
             0.804089957874165, 0.8474728000053131, 0.9809506398675458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 308}], {
             RGBColor[
             0.8202390110037177, 0.7599114530335084, 0.6155940095050296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 397}], {
             RGBColor[
             0.8140561202809597, 0.8554195473842192, 0.9819012213348041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 211}], {
             RGBColor[
             0.9315973027901165, 0.947887138916094, 0.9792171555570068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 328}], {
             RGBColor[
             0.9440237800795586, 0.9321505754996067, 0.6770241725870753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 347}], {
             RGBColor[
             0.948811076458846, 0.9604379989342878, 0.9372198229068748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 364}], {
             RGBColor[
             0.8850583491740331, 0.9111855196352219, 0.9888988495167765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 387}], {
             RGBColor[
             0.8982490825475034, 0.921703452374308, 0.9901569934414449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 175}], {
             RGBColor[
             0.8349863167479, 0.8696366640042488, 0.8744132709056968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 197}], {
             RGBColor[
             0.7033580680684253, 0.7681879355851418, 0.9710678170363597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 204}], {
             RGBColor[
             0.6458999484196466, 0.7228659425845092, 0.9656385273331574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 214}], {
             RGBColor[
             0.8036737408968835, 0.8474404150611713, 0.9808314639097111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 261}], {
             RGBColor[
             0.8320813331147974, 0.8684353786172869, 0.9225563675628589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 295}], {
             RGBColor[
             0.829143553221395, 0.8665958175153345, 0.9432670309246458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 310}], {
             RGBColor[
             0.7885772390747057, 0.835402874291792, 0.9793915460891054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 345}], {
             RGBColor[
             0.7983015624627698, 0.7319170208710799, 0.6110033492334291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 193}], {
             RGBColor[
             0.9246230148135475, 0.9393695612796875, 0.8575523926670103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 232}], {
             RGBColor[
             0.9236189859677683, 0.9371537908867187, 0.7433086880686042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 235}], {
             RGBColor[
             0.7339938456899469, 0.7919608520829, 0.9743458509138425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 260}], {
             RGBColor[
             0.9239333011444938, 0.939084346952701, 0.8689827330849884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 267}], {
             RGBColor[
             0.903725796651498, 0.9256137577030088, 0.9748460600530688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 272}], {
             RGBColor[
             0.7630698694518898, 0.8151105360648185, 0.9769462785448111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 275}], {
             RGBColor[
             0.9240684230023057, 0.9381150912585396, 0.7922271356741427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 281}], {
             RGBColor[
             0.8160067910261677, 0.8564652615341496, 0.9822225361636767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 291}], {
             RGBColor[
             0.9092593254493901, 0.929740654420155, 0.9654792391736888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 338}], {
             RGBColor[
             0.8141783299172518, 0.8550368538190454, 0.9820402922482805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 384}], {
             RGBColor[
             0.6486441148112965, 0.7223965922484449, 0.9677023772420045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 398}], {
             RGBColor[
             0.9199817563488728, 0.9374502816296427, 0.9344700566185477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 204}], {
             RGBColor[
             0.8030309118760144, 0.8442375856151361, 0.8715258534750355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 214}], {
             RGBColor[
             0.9608047043532513, 0.9688120580917983, 0.8867187900515892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 256}], {
             RGBColor[
             0.9226632014429466, 0.9383990589946369, 0.8830808194546828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 261}], {
             RGBColor[
             0.9892122965711652, 0.9898070216479138, 0.828443693704737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 264}], {
             RGBColor[
             0.9678191400189857, 0.9742034708517513, 0.880394495816702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 295}], {
             RGBColor[
             0.9862745166777628, 0.9879674605459614, 0.8491543570665241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 310}], {
             RGBColor[
             0.9457082025310735, 0.956774517322419, 0.8852788722309837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 345}], {
             RGBColor[
             0.9554325259191376, 0.8532886639017068, 0.5168906753753073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 186}], {
             RGBColor[
             0.9021747001874596, 0.9026846557979025, 0.6787749835231925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 226}], {
             RGBColor[
             0.9050008214154864, 0.9256760093101996, 0.9404717199009465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 294}], {
             RGBColor[
             0.7587606832138856, 0.8115092028339908, 0.9765791314039589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 341}], {
             RGBColor[
             0.9090763107151516, 0.9255477426482103, 0.7411017419765625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 368}], {
             RGBColor[
             0.7676210412910678, 0.8184309819051008, 0.9774622490923385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 379}], {
             RGBColor[
             0.8917577662690925, 0.8675458916788521, 0.6383071623232435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 393}], {
             RGBColor[
             0.8561839307890053, 0.8881618421902082, 0.9861447817147151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 399}], {
             RGBColor[
             0.905104701946709, 0.925718966579468, 0.9387501506643912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 200}], {
             RGBColor[
             0.8502007059395602, 0.8833001210693024, 0.9582382234060391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 225}], {
             RGBColor[
             0.9718167484536779, 0.9785015576593677, 0.9325910728853934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 296}], {
             RGBColor[
             0.7163272444306735, 0.7760245370156851, 0.946735925819331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 311}], {
             RGBColor[
             0.9521814091653247, 0.9638575537680312, 0.9658285805839018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 324}], {
             RGBColor[
             0.9311113046581234, 0.7977781941492357, 0.588691062156163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 339}], {
             RGBColor[
             0.8812683551698691, 0.9075704047708992, 0.9613347563376275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 360}], {
             RGBColor[
             0.9527706033468255, 0.9642969738238776, 0.9648312285210745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 374}], {
             RGBColor[
             0.9700134067756626, 0.9490159624500685, 0.6478273589737582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 375}], {
             RGBColor[
             0.9798892552437946, 0.9829407337050189, 0.8481131932250738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 383}], {
             RGBColor[
             0.932683815584781, 0.9483776278458564, 0.9662892474322615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 390}], {
             RGBColor[
             0.909800988055161, 0.9301314823115439, 0.9641066629147452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 209}], {
             RGBColor[
             0.8427957396703554, 0.8774864620049635, 0.9848678040940388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 229}], {
             RGBColor[
             0.874790657234845, 0.9029983407919862, 0.98791950789354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 240}], {
             RGBColor[
             0.9169648751453285, 0.9152643946614654, 0.6813426616500328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 245}], {
             RGBColor[
             0.8617789743799227, 0.8926231780761933, 0.9866784419671711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 248}], {
             RGBColor[
             0.9191125558351614, 0.9370715456368812, 0.9480369187906309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 309}], {
             RGBColor[
             0.6819473294692746, 0.7497078731856991, 0.9702477210044729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 315}], {
             RGBColor[
             0.7110812487187415, 0.7733601013005218, 0.9725412498488535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 319}], {
             RGBColor[
             0.9220570436377533, 0.9382891670131379, 0.8992391358115162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 329}], {
             RGBColor[
             0.6206563514019726, 0.6981584562847488, 0.9659174298008665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 334}], {
             RGBColor[
             0.8935713160739595, 0.9179735283628924, 0.9897108238993069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 371}], {
             RGBColor[
             0.9225977892352633, 0.9385127792142363, 0.8902775818560282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 388}], {
             RGBColor[
             0.65145518765374, 0.7248348602515098, 0.9678799044124875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 196}], {
             RGBColor[
             0.6983124049437295, 0.7625124193255737, 0.9720900754977269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 231}], {
             RGBColor[
             0.38886238295461073`, 0.5099505855126526, 0.9461946254152465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 303}], {
             RGBColor[
             0.729850464626352, 0.7864263070167843, 0.9323248762122508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 313}], {
             RGBColor[
             0.5009786572649972, 0.6057560686558665, 0.9538580215266408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 344}], {
             RGBColor[
             0.6651145837361796, 0.7360413778255243, 0.968923637674906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 359}], {
             RGBColor[
             0.345399992298639, 0.46426885725849854`, 0.9437195065642339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 239}], {
             RGBColor[
             0.9807261168344112, 0.9843767474113971, 0.8830544158066472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 271}], {
             RGBColor[
             0.9911138491357301, 0.9905933625010332, 0.7969300466496095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 282}], {
             RGBColor[
             0.7964485029265235, 0.8395497470081228, 0.8984334400500196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 326}], {
             RGBColor[
             0.9502168903139813, 0.9610018434566253, 0.9131621283415778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 350}], {
             RGBColor[
             0.5849910987456894, 0.6486930608631171, 0.8842604693678044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 394}], {
             RGBColor[
             0.9867572461352971, 0.9887917952007641, 0.8691302328939332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 250}], {
             RGBColor[
             0.9660714619462044, 0.9738978720086648, 0.9280371250243437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 265}], {
             RGBColor[
             0.969947050014502, 0.9742758966821008, 0.7747908849333323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 322}], {
             RGBColor[
             0.941289521439099, 0.8727048233337944, 0.6220206271603281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 362}], {
             RGBColor[
             0.9126992608112896, 0.9329591815738134, 0.9822972510183703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 244}], {
             RGBColor[
             0.7674660104570703, 0.8143666563119292, 0.8122610897515294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 253}], {
             RGBColor[
             0.763828368406594, 0.8133401463650336, 0.9072735067769719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 271}], {
             RGBColor[
             0.9850196797462214, 0.9868177435471939, 0.841701306157703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 273}], {
             RGBColor[
             0.9679931606900298, 0.9756499321657894, 0.9390634096178458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 335}], {
             RGBColor[
             0.9489600278155987, 0.9610833617125722, 0.9583947744992618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 305}], {
             RGBColor[0.5899049800444337, 0.67253467786713, 0.9634923242272]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 325}], {
             RGBColor[
             0.9031107025530143, 0.9243939132064767, 0.9494991505026267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 213}], {
             RGBColor[
             0.7715763283661505, 0.8206265925449409, 0.9443360124356741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 224}], {
             RGBColor[
             0.8998697226925529, 0.9220160606052035, 0.9563466217858266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 247}], {
             RGBColor[
             0.9666108318114068, 0.9746189935514682, 0.9414033318402418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 289}], {
             RGBColor[
             0.8061532286708413, 0.8486976778838964, 0.9470580326870186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 302}], {
             RGBColor[
             0.9761625374231189, 0.9817426399572005, 0.9252347857234209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 340}], {
             RGBColor[
             0.9841733152576337, 0.9854400126189727, 0.7946821833663315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 400}], {
             RGBColor[
             0.7852465746925685, 0.831724714350306, 0.945412184302252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 189}], {
             RGBColor[
             0.9832649878814075, 0.9655249769093319, 0.6184731109420897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 200}], {
             RGBColor[
             0.8568547153243182, 0.8672400159564295, 0.6742686115145979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 226}], {
             RGBColor[
             0.9822026463092257, 0.9650856713683017, 0.6360788600450024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 241}], {
             RGBColor[
             0.9869704618868252, 0.96643822060989, 0.5120643249312639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 255}], {
             RGBColor[
             0.8023272245851198, 0.8243810654688937, 0.6690127194007475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 288}], {
             RGBColor[
             0.9866506064751774, 0.9657540822267183, 0.4772500372921879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 341}], {
             RGBColor[
             0.9862781356088908, 0.9649574047063124, 0.4367088821206184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 374}], {
             RGBColor[
             0.9766674161604206, 0.9329558573371954, 0.363857747082317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 393}], {
             RGBColor[
             0.9333857556827445, 0.9275715042483104, 0.681751921858771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 399}], {
             RGBColor[
             0.9823065268404483, 0.9651286286375701, 0.634357290808447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 193}], {
             RGBColor[
             0.8169103880146069, 0.8548910421967215, 0.8469288399294149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 218}], {
             RGBColor[
             0.775360406430927, 0.8251239635083438, 0.9780859355721143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 232}], {
             RGBColor[
             0.8159063591688276, 0.8526752718037527, 0.7326851353310089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 235}], {
             RGBColor[
             0.6262812188910063, 0.707482332999934, 0.9637222981762472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 275}], {
             RGBColor[
             0.8163557962033652, 0.8536365721755736, 0.7816035829365473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 279}], {
             RGBColor[
             0.81582281828446, 0.8544413041640386, 0.8649526848981881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 281}], {
             RGBColor[
             0.7082941642272271, 0.7719867424511835, 0.9715989834260814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 298}], {
             RGBColor[
             0.8161821539566436, 0.8545898986989922, 0.8589975628791952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 306}], {
             RGBColor[
             0.8050136103204848, 0.8478477523841543, 0.9489871092941036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 195}], {
             RGBColor[
             0.9873645755819549, 0.9874635501314823, 0.7609935243758083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 203}], {
             RGBColor[
             0.991334428057259, 0.9897047903426344, 0.7220542959946972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 206}], {
             RGBColor[
             0.9941059142510236, 0.9898014715034487, 0.5998433241838184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 208}], {
             RGBColor[
             0.9929710571273234, 0.9903815785225546, 0.6949311168434679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 258}], {
             RGBColor[
             0.8282643606700711, 0.8630326239437669, 0.785609259719739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 278}], {
             RGBColor[
             0.9945320886774554, 0.9907130155087421, 0.6462297804572312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 284}], {
             RGBColor[
             0.9689941929364021, 0.9024737695676006, 0.4389535138654823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 327}], {
             RGBColor[
             0.7058483752973816, 0.7629853743699349, 0.7760308469454038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 361}], {
             RGBColor[
             0.8050697164825438, 0.8445089007672129, 0.7835735767343744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 369}], {
             RGBColor[
             0.99406007665958, 0.9897034295302423, 0.5948541852320082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 392}], {
             RGBColor[
             0.9938715192381834, 0.9893001242719546, 0.5743308735545101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 200}], {
             RGBColor[
             0.8607431781245267, 0.8906706750097568, 0.9183595987894392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 219}], {
             RGBColor[
             0.9856090559658899, 0.9882958334657648, 0.8872113247525693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 241}], {
             RGBColor[
             0.9908589246870338, 0.9898688796632175, 0.7561553122061051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 255}], {
             RGBColor[
             0.8062156873853284, 0.847811724522221, 0.9131037066755887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 339}], {
             RGBColor[
             0.8918108273548357, 0.9149409587113536, 0.9214561317210276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 360}], {
             RGBColor[
             0.9633130755317922, 0.9716675277643321, 0.9249526039044746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 374}], {
             RGBColor[
             0.9805558789606292, 0.9563865163905229, 0.6079487343571582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 266}], {
             RGBColor[
             0.9776480432061463, 0.9828505277378898, 0.9227202119147148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 273}], {
             RGBColor[
             0.9677679696018762, 0.975481985020961, 0.9394445993908478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 365}], {
             RGBColor[
             0.9275711590653998, 0.9440400724727553, 0.9567573538038197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 198}], {
             RGBColor[
             0.9863021624848276, 0.9697033616917339, 0.5883390298366311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 216}], {
             RGBColor[
             0.9285421087046571, 0.926252733607174, 0.6850316373097123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 219}], {
             RGBColor[
             0.982707999333361, 0.9681959272700147, 0.6469562239831552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 220}], {
             RGBColor[
             0.9342437690398419, 0.9307990827910034, 0.6855754667624145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 311}], {
             RGBColor[
             0.9598228247177625, 0.9511282015127356, 0.6856948551978876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 323}], {
             RGBColor[
             0.9746560729610996, 0.926171124440044, 0.35604405856324683`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 339}], {
             RGBColor[
             0.8889097707223068, 0.8948410525156034, 0.6812010309516134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 357}], {
             RGBColor[
             0.9849336991204735, 0.9691374669226691, 0.6110180092536417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 201}], {
             RGBColor[
             0.9619457018391915, 0.9706434815468823, 0.9270763876092525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 203}], {
             RGBColor[
             0.9878508474076197, 0.9892440274311401, 0.8510064296621797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 228}], {
             RGBColor[
             0.7427810775915582, 0.7963075424377095, 0.9078963608070721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 243}], {
             RGBColor[
             0.944110598486211, 0.9564483845857285, 0.9262812145274015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 332}], {
             RGBColor[
             0.9826773534729604, 0.9635047919397247, 0.6159279108968532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 348}], {
             RGBColor[
             0.7343790309040162, 0.789486382428873, 0.9072349209141177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 361}], {
             RGBColor[
             0.8015861358329044, 0.8440481378557187, 0.9125257104018569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 385}], {
             RGBColor[
             0.9286448506272509, 0.9441164170495357, 0.9248060776901778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 232}], {
             RGBColor[
             0.9941988529491828, 0.9900685121960027, 0.6149204888104255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 235}], {
             RGBColor[
             0.8045737126713615, 0.844875573392184, 0.8459576516556638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 260}], {
             RGBColor[
             0.9945131681259083, 0.9919990682619851, 0.7405945338268096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 275}], {
             RGBColor[
             0.9946482899837202, 0.9910298125678237, 0.663838936415964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 281}], {
             RGBColor[
             0.8865866580075822, 0.9093799828434337, 0.8538343369054979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 338}], {
             RGBColor[
             0.8847581968986662, 0.9079515751283294, 0.8536520929901018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 384}], {
             RGBColor[
             0.7192239817927109, 0.775311313557729, 0.8393141779838258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 376}], {
             RGBColor[
             0.9945708865256654, 0.9907960001829994, 0.6504526868023355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 377}], {
             RGBColor[
             0.9730936999735458, 0.917876831075725, 0.49255751138798287`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 396}], {
             RGBColor[
             0.9845328005380384, 0.9860002752831856, 0.8172552459599776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 206}], {
             RGBColor[
             0.9873242292999092, 0.9873772535138213, 0.7566020805635174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 208}], {
             RGBColor[
             0.9861893721762091, 0.9879573605329273, 0.8516898732231669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 258}], {
             RGBColor[
             0.8214826757189568, 0.8606084059541396, 0.9423680160994381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 278}], {
             RGBColor[
             0.9877504037263409, 0.9882887975191148, 0.8029885368369303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 284}], {
             RGBColor[
             0.9622125079852877, 0.9000495515779734, 0.5957122702451814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 327}], {
             RGBColor[
             0.6990666903462672, 0.7605611563803076, 0.9327896033251029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 337}], {
             RGBColor[
             0.9720316444512932, 0.9786618267425292, 0.9322273100152836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 369}], {
             RGBColor[
             0.9872783917084655, 0.9872792115406149, 0.7516129416117072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 392}], {
             RGBColor[
             0.9870898342870691, 0.9868759062823274, 0.7310896299342091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 231}], {
             RGBColor[
             0.6110145318597896, 0.6868556323542231, 0.9663804748436777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 234}], {
             RGBColor[
             0.5764803233434999, 0.6505579896083176, 0.9644138027574582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 290}], {
             RGBColor[
             0.9508642386030705, 0.9624823557006268, 0.9544376974588333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 303}], {
             RGBColor[
             0.9520026135315309, 0.9633313538583548, 0.9525107256406822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 313}], {
             RGBColor[
             0.7231308061701761, 0.782661115497437, 0.974043870955072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 344}], {
             RGBColor[
             0.8872667326413586, 0.9129464246670947, 0.9891094871033372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 204}], {
             RGBColor[
             0.6714026631965395, 0.742788857196029, 0.9681803996056985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 215}], {
             RGBColor[
             0.6547740991042161, 0.7292890397576055, 0.9668713381279135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 295}], {
             RGBColor[
             0.854646267998288, 0.8865187321268544, 0.945808903197187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 310}], {
             RGBColor[
             0.8140799538515986, 0.855325788903312, 0.9819334183616466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 345}], {
             RGBColor[
             0.8238042772396628, 0.7518399354825998, 0.6135452215059702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 216}], {
             RGBColor[
             0.9334929337729264, 0.9472002717277488, 0.8913167704682405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 219}], {
             RGBColor[
             0.9876588244016302, 0.9891434653905894, 0.8532413571416836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 224}], {
             RGBColor[
             0.908651934915386, 0.9273927335296971, 0.8889474138213869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 247}], {
             RGBColor[
             0.9753930440342399, 0.9799956664759617, 0.8740041238758021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 302}], {
             RGBColor[
             0.9849447496459519, 0.987119312881694, 0.8578355777589812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 311}], {
             RGBColor[
             0.9647736497860318, 0.9720757396333103, 0.8919799883564161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 323}], {
             RGBColor[
             0.9796068980293688, 0.9471186625606187, 0.5623291917217752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 340}], {
             RGBColor[
             0.9929555274804667, 0.9908166855434664, 0.7272829754018917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 212}], {
             RGBColor[
             0.6251505439350596, 0.7052084055890817, 0.9645603881782947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 238}], {
             RGBColor[
             0.725375484753584, 0.6930871522380135, 0.6094564338950013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 252}], {
             RGBColor[
             0.7506891777623987, 0.803396476348404, 0.9353698298863214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 277}], {
             RGBColor[
             0.7079679651408187, 0.7705245566944336, 0.9726507100098497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 287}], {
             RGBColor[
             0.7546203667371835, 0.8053937659768817, 0.8868627412814314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 293}], {
             RGBColor[
             0.7541585037462273, 0.8052027737607839, 0.8945170063046821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 299}], {
             RGBColor[
             0.3904680050683214, 0.5064635360385014, 0.9467570929686235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 336}], {
             RGBColor[
             0.7517304268203016, 0.8041730381908991, 0.9336072668325401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 367}], {
             RGBColor[
             0.7518789692593082, 0.7897746971666382, 0.6744767065072198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 225}], {
             RGBColor[
             0.8559489480815552, 0.8875871506469197, 0.9485079488413017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 241}], {
             RGBColor[
             0.8644486521299446, 0.891583918710315, 0.8119508127786134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 255}], {
             RGBColor[
             0.6798054148282391, 0.7495267635693186, 0.968899207248097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 288}], {
             RGBColor[
             0.8641287967182967, 0.8908997803271432, 0.7771365251395375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 296}], {
             RGBColor[
             0.6004594440585509, 0.6851101300032371, 0.9626528017752393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 339}], {
             RGBColor[
             0.7654005547977465, 0.8166559977584511, 0.9772516322935358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 355}], {
             RGBColor[
             0.770605325820368, 0.820722004439048, 0.9777703952277201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 360}], {
             RGBColor[
             0.8369028029747029, 0.8733825668114296, 0.9807481044769828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 374}], {
             RGBColor[
             0.85414560640354, 0.8581015554376203, 0.6637442349296665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 375}], {
             RGBColor[
             0.8640214548716718, 0.8920263266925709, 0.8640300691809821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 383}], {
             RGBColor[
             0.8168160152126582, 0.8574632208334083, 0.9822061233881698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 399}], {
             RGBColor[
             0.8597847170835675, 0.890274326737995, 0.9342437786557966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 210}], {
             RGBColor[
             0.9488442004491094, 0.9613686689716555, 0.9714776044570227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 228}], {
             RGBColor[
             0.7175476801969591, 0.7779847816864705, 0.9728337130852505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 236}], {
             RGBColor[
             0.9658226483256684, 0.9719456142079854, 0.8409396977090068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 243}], {
             RGBColor[
             0.9188772010916119, 0.9381256238344895, 0.9912185668055798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 263}], {
             RGBColor[
             0.9616283794518623, 0.9705122605849081, 0.9323352407713118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 348}], {
             RGBColor[
             0.7091456335094171, 0.7711636216776341, 0.9721722731922962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 351}], {
             RGBColor[
             0.9638256948957125, 0.9714209069893713, 0.8959200373966295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 214}], {
             RGBColor[
             0.9363163894739748, 0.9518653899332753, 0.9871346049721448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 217}], {
             RGBColor[
             0.9689234301680032, 0.9741002069472368, 0.8231570134057842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 257}], {
             RGBColor[
             0.9608256829384398, 0.9703044389943212, 0.9511960798736978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 264}], {
             RGBColor[
             0.9433308251397092, 0.9572568026932284, 0.9808103107372574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 268}], {
             RGBColor[
             0.9637321568677963, 0.9724502084358934, 0.9452966127208673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 279}], {
             RGBColor[
             0.9680841963901915, 0.9742498886207178, 0.8731720551175319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 300}], {
             RGBColor[
             0.9661447547556483, 0.9734478796634578, 0.9053136221159702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 306}], {
             RGBColor[
             0.9572749884262163, 0.9676563368408335, 0.9572064795134474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 363}], {
             RGBColor[
             0.8795822970581881, 0.9066591723079039, 0.981714762741304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 381}], {
             RGBColor[
             0.9570957183468078, 0.935562308256339, 0.6615852136862116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 243}], {
             RGBColor[
             0.94478234666004, 0.9567261697187474, 0.915148608858507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 258}], {
             RGBColor[
             0.8254525281942608, 0.8628496461652915, 0.9034287877183271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 284}], {
             RGBColor[
             0.9661823604605918, 0.9022907917891254, 0.5567730418640703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 348}], {
             RGBColor[
             0.7350507790778453, 0.7897641675618919, 0.8961023152452232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 361}], {
             RGBColor[
             0.8022578840067334, 0.8443259229887377, 0.9013931047329624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 369}], {
             RGBColor[
             0.9912482441837697, 0.9895204517517668, 0.712673713230596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 392}], {
             RGBColor[
             0.9910596867623731, 0.9891171464934794, 0.6921504015530981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 261}], {
             RGBColor[
             0.8001259282429117, 0.8430363002281742, 0.9196689501321976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 295}], {
             RGBColor[
             0.7971881483495094, 0.8411967391262218, 0.9403796134939846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 310}], {
             RGBColor[
             0.7566218342028199, 0.8100037959026793, 0.9765041286584442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 345}], {
             RGBColor[
             0.7663461575908841, 0.7065179424819672, 0.6081159318027679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 389}], {
             RGBColor[
             0.42510515664463666`, 0.5315637733408518, 0.9497587340070834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 400}], {
             RGBColor[
             0.6053745649127336, 0.6905093694663436, 0.9620764497914807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 207}], {
             RGBColor[
             0.8353933159955397, 0.8715839703001032, 0.9841617543157134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 221}], {
             RGBColor[
             0.8965041314195004, 0.9196018042606592, 0.9653650014110604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 230}], {
             RGBColor[
             0.9005875363893335, 0.9226472010011988, 0.9584528619197168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 250}], {
             RGBColor[
             0.9079385078932184, 0.9278106831322126, 0.93173036529657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 276}], {
             RGBColor[
             0.9008932452663497, 0.8921891203151988, 0.6647156477575997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 358}], {
             RGBColor[
             0.8786717926809426, 0.9060930528460893, 0.9882896940571193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 391}], {
             RGBColor[
             0.9033286101239859, 0.9246914893044061, 0.9538129390734778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 208}], {
             RGBColor[
             0.9929307108452776, 0.9902952819048936, 0.690539673031177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 258}], {
             RGBColor[
             0.8282240143880253, 0.8629463273261058, 0.7812178159074482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 278}], {
             RGBColor[
             0.9944917423954096, 0.9906267188910811, 0.6418383366449404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 284}], {
             RGBColor[
             0.9689538466543564, 0.9023874729499396, 0.4345620700531914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 369}], {
             RGBColor[
             0.9940197303775342, 0.9896171329125811, 0.5904627414197172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 392}], {
             RGBColor[
             0.9938311729561375, 0.9892138276542936, 0.5699394297422192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 221}], {
             RGBColor[
             0.9021317010430907, 0.924089075522202, 0.9659017640255492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 230}], {
             RGBColor[
             0.9062151060129239, 0.9271344722627416, 0.9589896245342056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 233}], {
             RGBColor[
             0.917741016478143, 0.9333162603583789, 0.8116033851475346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 250}], {
             RGBColor[
             0.9135660775168087, 0.9322979543937554, 0.9322671279110588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 358}], {
             RGBColor[
             0.884299362304533, 0.9105803241076321, 0.9888264566716081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 366}], {
             RGBColor[
             0.8896115432091736, 0.9147515623095436, 0.9870951254582284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 391}], {
             RGBColor[
             0.9089561797475763, 0.929178760565949, 0.9543497016879665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[
             0.8270891572643253, 0.8635264343452118, 0.8763056085670977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 278}], {
             RGBColor[
             0.9933568852717094, 0.991206825910187, 0.7369261293045899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 284}], {
             RGBColor[
             0.9678189895306561, 0.9029675799690455, 0.529649862712841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 369}], {
             RGBColor[
             0.992884873253834, 0.9901972399316872, 0.6855505340793668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 392}], {
             RGBColor[
             0.9926963158324376, 0.9897939346733995, 0.6650272224018687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 227}], {
             RGBColor[
             0.9081693491528336, 0.9282675612866301, 0.9435988047146808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 229}], {
             RGBColor[
             0.8636438059877706, 0.8941101441807857, 0.9868563112706825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 240}], {
             RGBColor[
             0.9058180238982543, 0.9063761980502649, 0.6802794650271753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 245}], {
             RGBColor[
             0.8506321231328484, 0.8837349814649929, 0.9856152453443137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 280}], {
             RGBColor[
             0.9121826788701798, 0.9277139273389676, 0.7162077126276309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 304}], {
             RGBColor[
             0.9112939868850568, 0.9295596792884313, 0.8918154711885047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 315}], {
             RGBColor[
             0.6999343974716672, 0.7644719046893214, 0.971478053225996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 319}], {
             RGBColor[
             0.9109101923906789, 0.9294009704019375, 0.8981759391886586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 329}], {
             RGBColor[
             0.6095095001548982, 0.6892702596735484, 0.964854233178009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 334}], {
             RGBColor[
             0.8824244648268851, 0.9090853317516919, 0.9886476272764493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 371}], {
             RGBColor[
             0.911450937988189, 0.9296245826030358, 0.8892143852331706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 236}], {
             RGBColor[
             0.9779545443301856, 0.9809935623839976, 0.8204035622785986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 263}], {
             RGBColor[
             0.9737602754563793, 0.9795602087609205, 0.9117991053409036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 301}], {
             RGBColor[
             0.8927104284743621, 0.9168798008927952, 0.9755080907700476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 328}], {
             RGBColor[
             0.9639192948175956, 0.947607439836007, 0.6648012036422388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 347}], {
             RGBColor[
             0.9687065911968831, 0.9758948632706881, 0.9249968539620383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 372}], {
             RGBColor[
             0.9161979078992044, 0.9356080794355195, 0.9777483475251095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 387}], {
             RGBColor[
             0.9181445972855405, 0.9371603167107082, 0.9779340244966084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 238}], {
             RGBColor[
             0.8311027033440583, 0.7775652767013912, 0.6187067687103847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 259}], {
             RGBColor[
             0.8064188825738778, 0.8492007561248218, 0.981207024725208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 293}], {
             RGBColor[
             0.8598857223367014, 0.8896808982241615, 0.9037673411200655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 299}], {
             RGBColor[
             0.4961952236587956, 0.5909416605018791, 0.9560074277840068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 336}], {
             RGBColor[
             0.8574576454107758, 0.8886511626542769, 0.9428576016479235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 367}], {
             RGBColor[
             0.8576061878497823, 0.8742528216300158, 0.6837270413226031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 224}], {
             RGBColor[
             0.6977574879512727, 0.762745099186823, 0.971260055297462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 230}], {
             RGBColor[
             0.7704367100157941, 0.8197766670451987, 0.9462650890427592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 247}], {
             RGBColor[
             0.7644985970701266, 0.8153480321330875, 0.9563167653518772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 250}], {
             RGBColor[
             0.7777876815196789, 0.8249401491762125, 0.9195425924196124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 289}], {
             RGBColor[
             0.604040993929561, 0.6894267164655159, 0.9619714661986538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 302}], {
             RGBColor[
             0.7740503026818386, 0.8224716785388199, 0.9401482192350562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 340}], {
             RGBColor[
             0.7820610805163535, 0.8261690512005921, 0.8095956168779668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 391}], {
             RGBColor[
             0.7731777837504463, 0.8218209553484062, 0.94162516619652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 215}], {
             RGBColor[
             0.7550897719326746, 0.8085415192336349, 0.9766349850012648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 217}], {
             RGBColor[
             0.9620991691962631, 0.9688506261626821, 0.829159391489243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 261}], {
             RGBColor[
             0.9578997207201487, 0.9676107727048362, 0.9348618867087513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 264}], {
             RGBColor[
             0.9365065641679692, 0.9520072219086737, 0.9868126888207163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 295}], {
             RGBColor[
             0.9549619408267462, 0.9657712116028839, 0.9555725500705383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 300}], {
             RGBColor[
             0.9593204937839084, 0.9681982988789031, 0.9113160001994289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 310}], {
             RGBColor[
             0.9143956266800569, 0.9345782683793415, 0.9916970652349979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 363}], {
             RGBColor[
             0.8727580360864482, 0.9014095915233493, 0.9877171408247627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 217}], {
             RGBColor[
             0.7876968126267028, 0.8307763362475964, 0.8126573934349043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 269}], {
             RGBColor[
             0.6573114776327622, 0.7312712591488967, 0.9671242403064885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 295}], {
             RGBColor[
             0.780559584257186, 0.8276969216877982, 0.9390705520161997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 300}], {
             RGBColor[
             0.7849181372143481, 0.8301240089638173, 0.8948140021450903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 352}], {
             RGBColor[
             0.7825574699135536, 0.8291478123685565, 0.9339363685303953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 363}], {
             RGBColor[
             0.6983556795168879, 0.7633353016082636, 0.9712151427704241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 219}], {
             RGBColor[
             0.9298987706214599, 0.9456928373060296, 0.9499339646147646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 220}], {
             RGBColor[
             0.8814345403279407, 0.9082959928270183, 0.988553207394024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 311}], {
             RGBColor[
             0.9070135960058613, 0.9286251115487505, 0.9886725958294972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 323}], {
             RGBColor[
             0.9218468442491983, 0.9036680344760589, 0.6590217991948564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 339}], {
             RGBColor[
             0.8361005420104057, 0.8723379625516183, 0.984178771583223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 357}], {
             RGBColor[
             0.9321244704085723, 0.946634376958684, 0.9139957498852511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 268}], {
             RGBColor[
             0.9895149365900847, 0.9894354446653002, 0.7873213992379655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 269}], {
             RGBColor[
             0.8643208748963509, 0.8915803660779439, 0.8196486467944666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 279}], {
             RGBColor[
             0.9938669761124799, 0.9912351248501248, 0.7151968416346302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 300}], {
             RGBColor[
             0.9919275344779367, 0.9904331158928645, 0.7473384086330684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 306}], {
             RGBColor[
             0.9830577681485047, 0.9846415730702404, 0.7992312660305456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 363}], {
             RGBColor[
             0.9053650767804765, 0.9236444085373108, 0.8237395492584022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 262}], {
             RGBColor[
             0.9254654202356623, 0.9433243350000625, 0.9899554680831617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 269}], {
             RGBColor[
             0.8230192292650063, 0.8624127070957303, 0.9827969391801405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 279}], {
             RGBColor[
             0.9525653304811352, 0.9620674658679111, 0.8783451340203041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 298}], {
             RGBColor[
             0.9529246661533188, 0.9622160604028646, 0.872390012001311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.9506258888465922, 0.9612654569106509, 0.9104867010187423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 306}], {
             RGBColor[
             0.94175612251716, 0.9554739140880267, 0.9623795584162196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 314}], {
             RGBColor[
             0.8563731758833293, 0.8884690636933472, 0.9861213488687023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 220}], {
             RGBColor[
             0.9356004309566446, 0.950239186489859, 0.9504777940674669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 241}], {
             RGBColor[
             0.9893145299713076, 0.9892090771663229, 0.7808025387417434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 311}], {
             RGBColor[
             0.9611794866345651, 0.9705683052115911, 0.9505971825029402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 323}], {
             RGBColor[
             0.9760127348779022, 0.9456112281388995, 0.6209463858682993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 339}], {
             RGBColor[
             0.8902664326391095, 0.914281156214459, 0.946103358256666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 357}], {
             RGBColor[
             0.9862903610372762, 0.9885775706215247, 0.8759203365586941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 360}], {
             RGBColor[
             0.9617686808160659, 0.9710077252674374, 0.949599830440113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 350}], {
             RGBColor[
             0.534147623099023, 0.6102911816939549, 0.9613625742689622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 357}], {
             RGBColor[
             0.937826130743757, 0.9511807261425135, 0.9145395793379534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 394}], {
             RGBColor[
             0.9359137704886307, 0.9503899160316018, 0.946232337795091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 230}], {
             RGBColor[
             0.9673259214368846, 0.9751523062232976, 0.9401928716295525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 250}], {
             RGBColor[
             0.9746768929407694, 0.9803157883543114, 0.9134703750064057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 276}], {
             RGBColor[
             0.9676316303139008, 0.9446942255372976, 0.6464556574674355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 358}], {
             RGBColor[
             0.9454101777284938, 0.9585981580681882, 0.9700297037669551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 251}], {
             RGBColor[
             0.8176722318214689, 0.8575748509559886, 0.939112652207577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 297}], {
             RGBColor[
             0.8076365284671103, 0.8084994500310494, 0.6397321118289251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 312}], {
             RGBColor[
             0.7354685013115838, 0.7932728500830287, 0.9742682849329782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 332}], {
             RGBColor[
             0.8148642840062729, 0.8328803666223497, 0.6678105772514669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 356}], {
             RGBColor[
             0.8080465055159489, 0.850396000038012, 0.9554064960513259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 361}], {
             RGBColor[
             0.6337730663662169, 0.7134237125383436, 0.9644083767564706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 260}], {
             RGBColor[
             0.6590392563057291, 0.7234945103002941, 0.8469535488581388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 267}], {
             RGBColor[
             0.6388317518127333, 0.7100239210506019, 0.9528168758262192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 272}], {
             RGBColor[
             0.49817582461312515`, 0.5995206994124115, 0.9549170943179615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 290}], {
             RGBColor[
             0.652759490755918, 0.7204112059498495, 0.929240846731499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 291}], {
             RGBColor[
             0.6443652806106255, 0.714150817767748, 0.9434500549468392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 321}], {
             RGBColor[
             0.6502197445778688, 0.7185170674087131, 0.9335399745390456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 331}], {
             RGBColor[
             0.5081817137644322, 0.6073373760649867, 0.9559143878382133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 342}], {
             RGBColor[
             0.6457266461999458, 0.7151661219952314, 0.9411456181051311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 346}], {
             RGBColor[
             0.5985728632644193, 0.6783792539569745, 0.9648102543656824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 384}], {
             RGBColor[
             0.38375006997253175`, 0.5068067555960379, 0.9456731930151548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 398}], {
             RGBColor[
             0.6550877115101081, 0.7218604449772357, 0.912440872391698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 230}], {
             RGBColor[
             0.8987301043421965, 0.9211661351054614, 0.9582756983929117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 247}], {
             RGBColor[
             0.892791991396529, 0.9167375001933502, 0.9683273747020296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 289}], {
             RGBColor[
             0.7323343882559634, 0.7908161845257785, 0.9739820755488063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 302}], {
             RGBColor[
             0.902343697008241, 0.9238611465990825, 0.9521588285852087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 323}], {
             RGBColor[
             0.8970058453916578, 0.8838604962780072, 0.6566524425480027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 340}], {
             RGBColor[
             0.9103544748427559, 0.9275585192608549, 0.8216062262281192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 288}], {
             RGBColor[
             0.9857448392324145, 0.9861012169172085, 0.7514893746188918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 296}], {
             RGBColor[
             0.7220754865726686, 0.7803115665933024, 0.9370056512545936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 316}], {
             RGBColor[
             0.9617149460016792, 0.9709676499308506, 0.9496907894645856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 324}], {
             RGBColor[
             0.9368595468001184, 0.8020652237268531, 0.5789607875914256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 355}], {
             RGBColor[
             0.8922213683344857, 0.9159234410291133, 0.9521232447070744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 375}], {
             RGBColor[
             0.9856374973857897, 0.9872277632826362, 0.8383829186603364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 380}], {
             RGBColor[
             0.9830668614971856, 0.9861647392803694, 0.8809850079269308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 383}], {
             RGBColor[
             0.938432057726776, 0.9526646574234736, 0.9565589728675241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 390}], {
             RGBColor[
             0.9155492301971561, 0.934418511889161, 0.9543763883500078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 255}], {
             RGBColor[
             0.8051533458131466, 0.8473724189811908, 0.9307094557785014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 266}], {
             RGBColor[
             0.9820702114742057, 0.986009556102271, 0.9090091473227923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 294}], {
             RGBColor[
             0.8387886293356517, 0.8739102184043899, 0.9338830079257687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 341}], {
             RGBColor[
             0.9891042568369175, 0.9879487582186095, 0.6984056184983723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 368}], {
             RGBColor[
             0.8476489874128337, 0.8808319974755001, 0.9347661256141483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 393}], {
             RGBColor[
             0.9362118769107713, 0.9505628577606074, 0.9434486582365249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 399}], {
             RGBColor[
             0.985132648068475, 0.9881199821498672, 0.896054027186201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 280}], {
             RGBColor[
             0.9887031395997324, 0.9873832232318347, 0.6760019098711303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 304}], {
             RGBColor[
             0.9878144476146095, 0.9892289751812984, 0.8516096684320041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 315}], {
             RGBColor[
             0.7764548582012198, 0.8241412005821884, 0.9312722504694955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 243}], {
             RGBColor[
             0.6997125768439786, 0.7637896847253167, 0.9720385400033995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 332}], {
             RGBColor[
             0.7382793318307279, 0.770846092079313, 0.6616852363728511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 348}], {
             RGBColor[
             0.4899810092617838, 0.5968276825684613, 0.9529922463901157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 361}], {
             RGBColor[
             0.5571881141906719, 0.6513894379953069, 0.9582830358778549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 385}], {
             RGBColor[
             0.6842468289850185, 0.751457717189124, 0.9705634031661757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 240}], {
             RGBColor[
             0.9378129414627439, 0.9318880768372877, 0.6833311688266763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 245}], {
             RGBColor[
             0.882627040697338, 0.9092468602520156, 0.9886669491438147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 248}], {
             RGBColor[
             0.9399606221525765, 0.9536952278127034, 0.9500254259672745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 249}], {
             RGBColor[
             0.7240439343846488, 0.7835820762310997, 0.9739089909755093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 309}], {
             RGBColor[
             0.7027953957866898, 0.7663315553615213, 0.9722362281811164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 315}], {
             RGBColor[
             0.7319293150361568, 0.789983783476344, 0.9745297570254972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 319}], {
             RGBColor[
             0.9429051099551685, 0.9549128491889601, 0.9012276429881596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[
             0.6415044177193878, 0.714782138460571, 0.96790593697751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 334}], {
             RGBColor[
             0.9144193823913747, 0.9345972105387146, 0.9916993310759503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 371}], {
             RGBColor[
             0.9434458555526786, 0.9551364613900585, 0.8922660890326718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 388}], {
             RGBColor[
             0.6723032539711552, 0.7414585424273319, 0.9698684115891312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 247}], {
             RGBColor[
             0.9654712134610504, 0.9737690680517259, 0.9433324084473269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 250}], {
             RGBColor[
             0.9787602979106026, 0.9833611850948509, 0.9065582355150622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 289}], {
             RGBColor[
             0.8050136103204848, 0.8478477523841543, 0.9489871092941036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 358}], {
             RGBColor[
             0.9494935826983268, 0.9616435548087277, 0.9631175642756116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 391}], {
             RGBColor[
             0.9741504001413701, 0.9802419912670446, 0.9286408092919698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 234}], {
             RGBColor[
             0.267030301354381, 0.3979961557953965, 0.9385183526749779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 290}], {
             RGBColor[
             0.6414142166139516, 0.7099205218877057, 0.9285422473763528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 313}], {
             RGBColor[
             0.41368078418105725`, 0.5300992816845159, 0.9481484208725917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 331}], {
             RGBColor[
             0.4968364396224658, 0.5968466920028429, 0.9552157884830671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 359}], {
             RGBColor[
             0.25810211921469906`, 0.38861207028714795`, 0.9380099059101847]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 235}], {
             RGBColor[
             0.8035696838255821, 0.8426598029992152, 0.7317139470572578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 281}], {
             RGBColor[
             0.885582629161803, 0.9071642124504647, 0.739590632307092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 384}], {
             RGBColor[
             0.7182199529469318, 0.77309554316476, 0.7250704733854196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 386}], {
             RGBColor[
             0.9567202638288428, 0.963547851342888, 0.7464659175008531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 242}], {
             RGBColor[
             0.9874191323139072, 0.9680154147419231, 0.5083887444099406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 317}], {
             RGBColor[
             0.9938459903160204, 0.989245520488818, 0.5715522079233177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 358}], {
             RGBColor[
             0.9610194931635461, 0.9678253429043651, 0.8157313248889405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 366}], {
             RGBColor[
             0.9663316740681867, 0.9719965811062765, 0.8139999936755609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 382}], {
             RGBColor[
             0.978245783905436, 0.9808821047153327, 0.7938325134186072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 290}], {
             RGBColor[
             0.6068800080976617, 0.6736228791418002, 0.9265755752901332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 313}], {
             RGBColor[
             0.3791465756647675, 0.4938016389386104, 0.9461817487863721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 331}], {
             RGBColor[
             0.46230223110617596`, 0.5605490492569374, 0.9532491163968475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 342}], {
             RGBColor[
             0.5998471635416895, 0.6683777951871821, 0.9384803466637653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 346}], {
             RGBColor[
             0.5526933806061631, 0.6315909271489252, 0.9621449829243166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 275}], {
             RGBColor[
             0.8040191208601197, 0.8436211033710361, 0.7806323946627962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 281}], {
             RGBColor[
             0.6959574888839817, 0.7619712736466461, 0.9706277951523303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 384}], {
             RGBColor[
             0.5285948126691103, 0.6279026043609414, 0.956107636230658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 263}], {
             RGBColor[
             0.9907387233329383, 0.9901371539972503, 0.7812611985928877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 351}], {
             RGBColor[
             0.9929360387767886, 0.9910458004017135, 0.7448459952182054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 246}], {
             RGBColor[
             0.7973177874313873, 0.8415572333356791, 0.9472359038707681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 254}], {
             RGBColor[
             0.7801137173850636, 0.8287264660642102, 0.9763579069190951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 286}], {
             RGBColor[
             0.8052625008176174, 0.8467514078322014, 0.9010528102449298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 320}], {
             RGBColor[
             0.6106630371723407, 0.6948027894896529, 0.9624927777000691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 343}], {
             RGBColor[
             0.7719860178199786, 0.8223125850024108, 0.9779030444086736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 349}], {
             RGBColor[
             0.7771682985609509, 0.8264447949959988, 0.9783973349720242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 252}], {
             RGBColor[
             0.9566413371713973, 0.8757533474607135, 0.5895162104184115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 277}], {
             RGBColor[
             0.9139201245498174, 0.8428814278067431, 0.6267970905419398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 287}], {
             RGBColor[
             0.9605725261461822, 0.8777506370891912, 0.5410091218135213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 293}], {
             RGBColor[
             0.9601106631552259, 0.8775596448730933, 0.5486633868367721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 299}], {
             RGBColor[
             0.59642016447732, 0.5788204071508108, 0.6009034735007135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 336}], {
             RGBColor[
             0.9576825862293002, 0.8765299093032086, 0.5877536473646301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 367}], {
             RGBColor[
             0.9578311286683068, 0.8621315682789477, 0.32862308703930976`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 396}], {
             RGBColor[
             0.9526578702869926, 0.8727824843806528, 0.5962591807991522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 271}], {
             RGBColor[
             0.9830168140136829, 0.9853240095632583, 0.8450916354118461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 326}], {
             RGBColor[
             0.9421198551919341, 0.9557324905188503, 0.9613237171038145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 335}], {
             RGBColor[
             0.9469571620830601, 0.9595896277286367, 0.9617851037534049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 337}], {
             RGBColor[
             0.9680547399920549, 0.9756958579084127, 0.9389591719219718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 354}], {
             RGBColor[
             0.9785142688810118, 0.9834620914407668, 0.9197104604734898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 245}], {
             RGBColor[
             0.9248012586078216, 0.9215129141214948, 0.6820901029003075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 248}], {
             RGBColor[
             0.9821348400630602, 0.9659612816821828, 0.6434485797237672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 292}], {
             RGBColor[
             0.9681443592821573, 0.9555422428089426, 0.6678042819403424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 304}], {
             RGBColor[
             0.9854631223600301, 0.9673376119449333, 0.5882903287444986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 309}], {
             RGBColor[
             0.7449696136971735, 0.7785976092310005, 0.6656593819376092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 315}], {
             RGBColor[
             0.7741035329466404, 0.8022498373458233, 0.6679529107819899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 319}], {
             RGBColor[
             0.9850793278656522, 0.9671789030584395, 0.5946507967446524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 329}], {
             RGBColor[
             0.6836786356298715, 0.7270481923300502, 0.6613290907340028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 334}], {
             RGBColor[
             0.9565936003018582, 0.9468632644081938, 0.6851224848324431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 371}], {
             RGBColor[
             0.9856200734631622, 0.9674025152595378, 0.5856892427891646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 388}], {
             RGBColor[
             0.7144774718816389, 0.7537245962968112, 0.663291565345624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 255}], {
             RGBColor[
             0.8099211613907462, 0.8487249682227791, 0.8066949206647629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 288}], {
             RGBColor[
             0.9942445432808038, 0.9900979849806038, 0.6149322385562033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 339}], {
             RGBColor[
             0.8955163013602535, 0.9158542024119117, 0.8150473457102018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 360}], {
             RGBColor[
             0.9670185495372099, 0.9725807714648902, 0.8185438178936488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 374}], {
             RGBColor[
             0.984261352966047, 0.957299760091081, 0.5015399483463324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 375}], {
             RGBColor[
             0.9941372014341789, 0.9912245313460315, 0.7018257825976479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 399}], {
             RGBColor[
             0.9899004636460746, 0.9894725313914556, 0.7720394920724625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 256}], {
             RGBColor[
             0.9167931199861418, 0.9156296806415662, 0.6820651386584025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 257}], {
             RGBColor[
             0.9794439163609114, 0.9644817287997733, 0.649764584156862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 268}], {
             RGBColor[
             0.9823503902902682, 0.9666274982413455, 0.6438651170040315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 317}], {
             RGBColor[
             0.9868039752927715, 0.9666996560756292, 0.44143269896839143`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 333}], {
             RGBColor[
             0.9867997766901982, 0.9666906756892688, 0.4409757069890654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 381}], {
             RGBColor[
             0.9757139517692794, 0.9297395980617912, 0.36015371796937573`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 382}], {
             RGBColor[
             0.9712037688821871, 0.9583362403021438, 0.6637130044636808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 348}], {
             RGBColor[
             0.6913105301564366, 0.7569685247164802, 0.971377100110445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 351}], {
             RGBColor[
             0.945990591542732, 0.9572258100282176, 0.8951248643147784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 253}], {
             RGBColor[
             0.9910905664242088, 0.990105985977368, 0.7625886271000495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 270}], {
             RGBColor[
             0.9439992934123418, 0.9544330323574033, 0.8286291651325761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 308}], {
             RGBColor[
             0.9601483465418945, 0.8668716853855986, 0.46327253477006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 397}], {
             RGBColor[
             0.9539654558191366, 0.9623797797363094, 0.8295797465998344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 248}], {
             RGBColor[
             0.9269489392976543, 0.9433200650969107, 0.9487843600409056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 292}], {
             RGBColor[
             0.9129584585167514, 0.9329010262236705, 0.9731400622574807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 304}], {
             RGBColor[
             0.9302772215946242, 0.9446963953596612, 0.893626109061637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 315}], {
             RGBColor[
             0.7189176321812345, 0.7796086207605513, 0.9732886910991283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 319}], {
             RGBColor[
             0.9298934271002464, 0.9445376864731674, 0.8999865770617907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 329}], {
             RGBColor[
             0.6284927348644657, 0.7044069757447782, 0.9666648710511412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 353}], {
             RGBColor[
             0.6234768969007893, 0.7000625090039881, 0.9663452662914271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 371}], {
             RGBColor[
             0.9304341726977563, 0.9447612986742657, 0.8910250231063029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 378}], {
             RGBColor[
             0.9317757781848026, 0.9441550821336413, 0.7843983491129942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 388}], {
             RGBColor[
             0.659291571116233, 0.7310833797115391, 0.9686273456627623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 254}], {
             RGBColor[
             0.9554983820652903, 0.9663313467257808, 0.9602138106693456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 286}], {
             RGBColor[
             0.980647165497844, 0.984356288493772, 0.8849087139951803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 320}], {
             RGBColor[
             0.7860477018525673, 0.8324076701512235, 0.9463486814503197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 343}], {
             RGBColor[
             0.9473706825002052, 0.9599174656639815, 0.9617589481589242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 344}], {
             RGBColor[
             0.9133856817727113, 0.9328187485821475, 0.9585174284507675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 349}], {
             RGBColor[
             0.9525529632411776, 0.9640496756575695, 0.9622532387222746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 289}], {
             RGBColor[
             0.7990754973748173, 0.8434191174720431, 0.9590387856032215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 302}], {
             RGBColor[
             0.9690848061270949, 0.9764640795453472, 0.9372155386396239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 340}], {
             RGBColor[
             0.9770955839616098, 0.9801614522071194, 0.8066629362825344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 391}], {
             RGBColor[
             0.9682122871957026, 0.9758133563549334, 0.9386924856010878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 292}], {
             RGBColor[
             0.97029203997199, 0.9773493937843584, 0.9344985390809405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 304}], {
             RGBColor[
             0.9876108030498627, 0.989144762920349, 0.8549845858850967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 315}], {
             RGBColor[
             0.7762512136364731, 0.8240569883212391, 0.9346471679225881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 319}], {
             RGBColor[
             0.9872270085554848, 0.9889860540338552, 0.8613450538852505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 329}], {
             RGBColor[
             0.6858263163197043, 0.7488553433054661, 0.928023347874601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 353}], {
             RGBColor[
             0.6808104783560279, 0.744510876564676, 0.9277037431148869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 388}], {
             RGBColor[
             0.7166251525714715, 0.775531747272227, 0.9299858224862221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 270}], {
             RGBColor[
             0.722859761783518, 0.7826378491424669, 0.97379604353569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 308}], {
             RGBColor[
             0.7390088149130707, 0.6950765021706622, 0.6084394131731741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 309}], {
             RGBColor[
             0.5312006066190784, 0.6302916086248126, 0.9562372040864422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 334}], {
             RGBColor[
             0.7428245932237633, 0.7985572638020059, 0.9757003069812762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 386}], {
             RGBColor[
             0.7363474243856598, 0.7933925451885666, 0.9750825088352609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 397}], {
             RGBColor[
             0.7328259241903127, 0.7905845965213731, 0.9747466250029484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 265}], {
             RGBColor[
             0.989986857482785, 0.9889026918993007, 0.7265894988009041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 276}], {
             RGBColor[
             0.9790660067876188, 0.9529031044088511, 0.6128210213529451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 289}], {
             RGBColor[
             0.8123645818243697, 0.8530112345151681, 0.9222646126709568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 391}], {
             RGBColor[
             0.981501371645255, 0.9854054733980584, 0.901918312668823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 282}], {
             RGBColor[
             0.7939326786195554, 0.8384428519578399, 0.9371474947152405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 312}], {
             RGBColor[
             0.901587772832637, 0.9231303093756462, 0.9474765691002538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 356}], {
             RGBColor[
             0.9741657770370021, 0.9802534593306296, 0.9286147802186014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 277}], {
             RGBColor[
             0.939233817558632, 0.9531907519171336, 0.9527104865332598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 293}], {
             RGBColor[
             0.9854243561640406, 0.9878689689834839, 0.8745767828280923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 330}], {
             RGBColor[
             0.9882831894132424, 0.9884726080693673, 0.7851431726684627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 386}], {
             RGBColor[
             0.9538493139640073, 0.9641612184566073, 0.9249280474575894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 286}], {
             RGBColor[
             0.9634430954515204, 0.9715255212223032, 0.9140307170435074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 320}], {
             RGBColor[
             0.7688436318062437, 0.8195769028797546, 0.9754706844986467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 343}], {
             RGBColor[
             0.9301666124538815, 0.9470866983925126, 0.9908809512072512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 344}], {
             RGBColor[
             0.8961816117263877, 0.9199879813106786, 0.9876394314990945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 349}], {
             RGBColor[
             0.9353488931948539, 0.9512189083861007, 0.9913752417706017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 288}], {
             RGBColor[
             0.8096013059790984, 0.8480408298396074, 0.7718806330256869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 341}], {
             RGBColor[
             0.8092288351128117, 0.8472441523192015, 0.7313394778541175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 360}], {
             RGBColor[
             0.7823753122355046, 0.8305236163238937, 0.9754922123631324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 374}], {
             RGBColor[
             0.7996181156643416, 0.8152426049500845, 0.658488342815816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 393}], {
             RGBColor[
             0.7563364551866656, 0.8098582518611994, 0.97638251759227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 399}], {
             RGBColor[
             0.8052572263443691, 0.8474153762504592, 0.9289878865419461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 261}], {
             RGBColor[
             0.919758217809844, 0.9371977736076751, 0.9312239161118449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 264}], {
             RGBColor[
             0.8983650612576644, 0.9215942228115126, 0.9831747182238098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 317}], {
             RGBColor[
             0.9232199779882551, 0.9368597863884612, 0.7452286021717796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 333}], {
             RGBColor[
             0.9232157793856818, 0.9368508060021008, 0.7447716101924535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 381}], {
             RGBColor[
             0.912129954464763, 0.8998997283746232, 0.6639496211727639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 268}], {
             RGBColor[
             0.9814171893605214, 0.9856396767123846, 0.9153604657058791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 338}], {
             RGBColor[
             0.8764121137167676, 0.9035563874692498, 0.9496999627150409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 381}], {
             RGBColor[
             0.9747807508395328, 0.9487517765328303, 0.6316490666712234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 382}], {
             RGBColor[
             0.9702705679524404, 0.9773484187731829, 0.9352083531655285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 278}], {
             RGBColor[
             0.8286501888144572, 0.8638578713313994, 0.8276042721808612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 284}], {
             RGBColor[
             0.8031122930734039, 0.7756186253902578, 0.6203280055891123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 369}], {
             RGBColor[
             0.8281781767965818, 0.8628482853528994, 0.776228676955638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 392}], {
             RGBColor[
             0.8279896193751852, 0.8624449800946118, 0.75570536527814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 274}], {
             RGBColor[
             0.9311958778867397, 0.9468207981271157, 0.9533057217711056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 299}], {
             RGBColor[
             0.5717363437071397, 0.6504558865742414, 0.9634037295155369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 318}], {
             RGBColor[
             0.6734812136162638, 0.7426319622365802, 0.9698145835817595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 336}], {
             RGBColor[
             0.9329987654591199, 0.9481653887266392, 0.9502539033794537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 367}], {
             RGBColor[
             0.9331473078981263, 0.9337670477023782, 0.6911233430541333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 267}], {
             RGBColor[
             0.9736159499638588, 0.9782432646853063, 0.8578882012128681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 272}], {
             RGBColor[
             0.8329600227642506, 0.867740043047116, 0.8599884197046104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 291}], {
             RGBColor[
             0.979149478761751, 0.9823701614024525, 0.8485213803334881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 321}], {
             RGBColor[
             0.9850039427289943, 0.9867364110434176, 0.8386112999256945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 338}], {
             RGBColor[
             0.8840684832296126, 0.9076663608013429, 0.8650824334080799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 342}], {
             RGBColor[
             0.9805108443510713, 0.983385465629936, 0.8462169434917801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 384}], {
             RGBColor[
             0.7185342681236573, 0.7750260992307425, 0.8507445184018039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 398}], {
             RGBColor[
             0.9898719096612336, 0.9900797886119403, 0.817512197778347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 264}], {
             RGBColor[
             0.9649141563858831, 0.9730021854647893, 0.9285375924738641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 295}], {
             RGBColor[
             0.9833695330446601, 0.9867661751589996, 0.8972974537236862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 310}], {
             RGBColor[
             0.9428032188979708, 0.9555732319354571, 0.9334219688881458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 381}], {
             RGBColor[
             0.9786790495929817, 0.9513076910278999, 0.6093124954228182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 269}], {
             RGBColor[
             0.8363817308730662, 0.8729869168835764, 0.9812740225690719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 298}], {
             RGBColor[
             0.9662871677613789, 0.9727902701907107, 0.8708670953902427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 300}], {
             RGBColor[
             0.963988390454652, 0.9718396666984972, 0.9089637844076739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 306}], {
             RGBColor[
             0.95511862412522, 0.9660481238758729, 0.9608566418051511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 307}], {
             RGBColor[
             0.7480708813184782, 0.8026950266515472, 0.9733627425043268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 314}], {
             RGBColor[
             0.8697356774913891, 0.8990432734811935, 0.9845984322576338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 310}], {
             RGBColor[
             0.9214100623457913, 0.9399696811392946, 0.9853727710001107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 333}], {
             RGBColor[
             0.9683717179617208, 0.9726552178592152, 0.7420852865544728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 381}], {
             RGBColor[
             0.9572858930408021, 0.9357041402317374, 0.6612632975347832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 322}], {
             RGBColor[
             0.9652049169756796, 0.8877096432244302, 0.42057300093688854`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 362}], {
             RGBColor[
             0.9366146563478701, 0.9479640014644493, 0.7808496247949308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 273}], {
             RGBColor[
             0.9692315818068886, 0.9765735446070143, 0.9369670856989613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 365}], {
             RGBColor[
             0.9290347712704123, 0.9451316320588086, 0.9542798401119331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 272}], {
             RGBColor[
             0.8127525182712547, 0.8542694537974238, 0.9658517466726908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 291}], {
             RGBColor[
             0.958941974268755, 0.9688995721527602, 0.9543847073015685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 321}], {
             RGBColor[
             0.9647964382359984, 0.9732658217937253, 0.9444746268937749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 331}], {
             RGBColor[
             0.8227584074225618, 0.8620861304499989, 0.9668490401929427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 342}], {
             RGBColor[
             0.9603033398580754, 0.9699148763802437, 0.9520802704598605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 346}], {
             RGBColor[
             0.913149556922549, 0.9331280083419867, 0.9757449067204118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 384}], {
             RGBColor[
             0.6983267636306614, 0.7615555099810501, 0.9566078453698843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 398}], {
             RGBColor[
             0.9696644051682377, 0.976609199362248, 0.9233755247464275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 338}], {
             RGBColor[
             0.8793185876461243, 0.9057021569108219, 0.9438004955622104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 381}], {
             RGBColor[
             0.9776872247688894, 0.9508975459744025, 0.625749599518393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 279}], {
             RGBColor[
             0.8634816411185392, 0.891730047751425, 0.8696636885062143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 298}], {
             RGBColor[
             0.8638409767907229, 0.8918786422863785, 0.8637085664872214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 300}], {
             RGBColor[
             0.861542199483996, 0.8909280387941649, 0.9018052555046526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 306}], {
             RGBColor[
             0.852672433154564, 0.8851364959715406, 0.9536981129021298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 307}], {
             RGBColor[
             0.6456246903478222, 0.721783398747215, 0.9662042136013056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 314}], {
             RGBColor[
             0.7672894865207331, 0.8181316455768612, 0.9774399033546126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 308}], {
             RGBColor[
             0.9094194314795512, 0.8301722218187382, 0.624325489828029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 397}], {
             RGBColor[
             0.9032365407567933, 0.9256803161694491, 0.9906327016578034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 273}], {
             RGBColor[
             0.9763780272588101, 0.9803728132714898, 0.8563293697149513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 326}], {
             RGBColor[
             0.9525075874932529, 0.9619491056084865, 0.8751993479467768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 335}], {
             RGBColor[
             0.957344894384379, 0.9658062428182728, 0.8756607345963672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 394}], {
             RGBColor[
             0.9890479433145689, 0.9897390573526252, 0.8311674524991322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 291}], {
             RGBColor[
             0.8182860470691469, 0.8583963505145699, 0.9564849257933108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 321}], {
             RGBColor[
             0.8241405110363902, 0.8627626001555351, 0.9465748453855172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 331}], {
             RGBColor[
             0.6821024802229537, 0.7515829088118087, 0.968949258684685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 338}], {
             RGBColor[
             0.7232050515370085, 0.7836925499134603, 0.9730459788679026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 342}], {
             RGBColor[
             0.8196474126584673, 0.8594116547420534, 0.9541804889516028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 346}], {
             RGBColor[
             0.7724936297229408, 0.8226247867037964, 0.977845125212154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 384}], {
             RGBColor[
             0.5576708364310532, 0.6510522883428598, 0.9587080638616265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 398}], {
             RGBColor[
             0.8290084779686296, 0.8661059777240576, 0.9254757432381697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 365}], {
             RGBColor[
             0.9191546976661421, 0.9377630893418797, 0.9710042275880661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 394}], {
             RGBColor[
             0.9720214242583773, 0.9785712459712206, 0.928529555959275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 287}], {
             RGBColor[
             0.9851245806405196, 0.9874919324425533, 0.8682117731427124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 299}], {
             RGBColor[
             0.6209722189716576, 0.6885617025041729, 0.9281061248299044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 318}], {
             RGBColor[
             0.7227170888807817, 0.7807377781665117, 0.934516978896127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 367}], {
             RGBColor[
             0.9823831831626443, 0.9718728636323097, 0.6558257383685007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 373}], {
             RGBColor[
             0.7688354190192821, 0.8181787161800428, 0.9381475827816395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 395}], {
             RGBColor[
             0.9878173174731099, 0.9886054483230093, 0.8235861552471524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 279}], {
             RGBColor[
             0.9935607202535733, 0.9905800745351409, 0.6818627813847371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 281}], {
             RGBColor[
             0.8860320661963405, 0.9081255128222858, 0.7885090799126304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 306}], {
             RGBColor[
             0.9827515122895981, 0.9839865227552564, 0.7658972057806527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 338}], {
             RGBColor[
             0.8842036050874245, 0.9066971051071815, 0.7883268359972342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 384}], {
             RGBColor[
             0.7186693899814691, 0.7740568435365811, 0.7739889209909582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 322}], {
             RGBColor[
             0.9542840662805134, 0.8517100557339807, 0.3068045234889296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 358}], {
             RGBColor[
             0.949799291575343, 0.9311854741227278, 0.6693803501134945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 376}], {
             RGBColor[
             0.9830425062737032, 0.9534969684012237, 0.47055836633495196`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 377}], {
             RGBColor[
             0.9615653197215835, 0.8805777992939494, 0.31266319092059935`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 287}], {
             RGBColor[
             0.9431650065334167, 0.9551880415456112, 0.9042033979283698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 330}], {
             RGBColor[
             0.9455619767916624, 0.9556006884153969, 0.8224240527919909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 396}], {
             RGBColor[
             0.9352503506742271, 0.9502198888370728, 0.9594534569140005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 284}], {
             RGBColor[
             0.9693800210807881, 0.9032990169552331, 0.4809485263266044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 327}], {
             RGBColor[
             0.7062342034417677, 0.7638106217575673, 0.8180258594065258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 337}], {
             RGBColor[
             0.9791991575467935, 0.981911292119789, 0.8174635660967066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 354}], {
             RGBColor[
             0.9896586864357504, 0.9896775256521431, 0.7982148546482246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 392}], {
             RGBColor[
             0.9942573473825694, 0.990125371659587, 0.6163258860156322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 300}], {
             RGBColor[
             0.991088300700125, 0.9905827975663457, 0.7973534503448162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 306}], {
             RGBColor[
             0.982218534370693, 0.9847912547437214, 0.8492463077422934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 363}], {
             RGBColor[
             0.9045258430026648, 0.923794090210792, 0.87375459097015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 384}], {
             RGBColor[
             0.6106077580053311, 0.6924070138121909, 0.9639843214804922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 386}], {
             RGBColor[
             0.8491080688872423, 0.8828593219903189, 0.9853797655959255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 350}], {
             RGBColor[
             0.39261644971575455`, 0.49859670752206786`, 0.9478010823734133]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 369}], {
             RGBColor[
             0.9689080090629127, 0.9022894309767332, 0.42957293110138123`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 392}], {
             RGBColor[
             0.9687194516415162, 0.9018861257184456, 0.40904961942388324`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 330}], {
             RGBColor[
             0.9726870009909974, 0.9768409962804717, 0.8115434515299151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 387}], {
             RGBColor[
             0.9177795151893247, 0.9368880390811174, 0.9785520132568415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 320}], {
             RGBColor[
             0.7939924152387974, 0.8376018446477458, 0.9001655878244813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 343}], {
             RGBColor[
             0.9553153958864353, 0.9651116401605038, 0.9155758545330859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 349}], {
             RGBColor[
             0.9604976766274077, 0.9692438501540919, 0.9160701450964364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 367}], {
             RGBColor[
             0.9870760106519061, 0.9744381820178157, 0.6060293944257399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 373}], {
             RGBColor[
             0.7735282465085439, 0.8207440345655488, 0.8883512388388786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 395}], {
             RGBColor[
             0.9925101449623717, 0.9911707667085154, 0.7737898113043915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 396}], {
             RGBColor[
             0.9819027522705919, 0.9850890981195208, 0.8736654881855823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 341}], {
             RGBColor[
             0.9935522170028693, 0.988617169077026, 0.539576795745558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 355}], {
             RGBColor[
             0.9004012169712272, 0.9192360707093368, 0.7807518210053102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 360}], {
             RGBColor[
             0.9666986941255622, 0.9718966330817183, 0.7837295302545728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 374}], {
             RGBColor[
             0.9839414975543992, 0.9566156217079091, 0.4667256607072565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 375}], {
             RGBColor[
             0.9938173460225311, 0.9905403929628596, 0.667011494958572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 379}], {
             RGBColor[
             0.9762336725568103, 0.9306153181076678, 0.43678221609223883`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 393}], {
             RGBColor[
             0.9406598370767232, 0.9512312686190241, 0.7846198354837104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 399}], {
             RGBColor[
             0.9895806082344267, 0.9887883930082837, 0.7372252044333865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 302}], {
             RGBColor[
             0.8086272029865293, 0.8505427638777754, 0.9428702394864006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 340}], {
             RGBColor[
             0.8166379808210442, 0.8542401365395478, 0.8123176371293112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 391}], {
             RGBColor[
             0.8077546840551371, 0.8498920406873617, 0.9443471864478645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 313}], {
             RGBColor[
             0.7535304909243381, 0.8057260050309196, 0.936205643487747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 321}], {
             RGBColor[
             0.9787241771791831, 0.983653106692973, 0.9208985977990548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 331}], {
             RGBColor[
             0.8366861463657467, 0.8724734153492466, 0.9432730110982226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 342}], {
             RGBColor[
             0.9742310788012603, 0.9803021612794913, 0.9285042413651403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 346}], {
             RGBColor[
             0.9270772958657336, 0.9435152932412344, 0.9521688776256916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 321}], {
             RGBColor[
             0.9703299670338905, 0.9773927185108715, 0.9351078060143949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 331}], {
             RGBColor[
             0.8282919362204539, 0.8662130271671451, 0.9574822193135628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 338}], {
             RGBColor[
             0.8693945075345089, 0.8983226682687967, 0.9615789394967804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 342}], {
             RGBColor[
             0.9658368686559675, 0.9740417730973898, 0.9427134495804805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 384}], {
             RGBColor[
             0.7038602924285535, 0.7656824066981962, 0.9472410244905043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 398}], {
             RGBColor[
             0.9751979339661299, 0.980736096079394, 0.9140087038670475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 304}], {
             RGBColor[
             0.9736203222689599, 0.9787257240471089, 0.8793402881016719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 329}], {
             RGBColor[
             0.6718358355388013, 0.738436304432226, 0.9523790500911761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 353}], {
             RGBColor[
             0.666819997575125, 0.7340918376914358, 0.9520594453314619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 378}], {
             RGBColor[
             0.9751188788591383, 0.9781844108210891, 0.770112528153029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 388}], {
             RGBColor[
             0.7026346717905687, 0.7651127083989868, 0.9543415247027971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 299}], {
             RGBColor[
             0.6252031834699632, 0.6909360286735811, 0.8859640459103943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 330}], {
             RGBColor[
             0.991752515397071, 0.9902789054817471, 0.7442903490868233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 336}], {
             RGBColor[
             0.9864656052219434, 0.988645530825979, 0.872814219774311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 341}], {
             RGBColor[
             0.8428641186353167, 0.8737819517424006, 0.7345130300013848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 368}], {
             RGBColor[
             0.7014088492112329, 0.7666651909992912, 0.9708735371171606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 393}], {
             RGBColor[
             0.7899717387091705, 0.8363960512843986, 0.9795560697395373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 310}], {
             RGBColor[
             0.9398654390045684, 0.9537336708335047, 0.9541326322499327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 345}], {
             RGBColor[
             0.9495897623926326, 0.8502478174127925, 0.5857444353942565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 363}], {
             RGBColor[
             0.8982278484109596, 0.9205649939775126, 0.9501527078396976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 316}], {
             RGBColor[
             0.7062254419786749, 0.7684906292871678, 0.9638356423985232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 324}], {
             RGBColor[
             0.6813700427771141, 0.5995882030831703, 0.5931056405253631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 360}], {
             RGBColor[
             0.7030293414658162, 0.7661069827578122, 0.9692458068902747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 374}], {
             RGBColor[
             0.7202721448946533, 0.7508259713840031, 0.6522419373429583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 375}], {
             RGBColor[
             0.7301479933627852, 0.7847507426389535, 0.8525277715942738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 380}], {
             RGBColor[
             0.7275773574741813, 0.7836877186366868, 0.8951298608608684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 383}], {
             RGBColor[
             0.6829425537037717, 0.7501876367797911, 0.9707038258014618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 390}], {
             RGBColor[
             0.6600597261741517, 0.7319414912454785, 0.9685212412839452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 307}], {
             RGBColor[
             0.7605169687135195, 0.7703865084569568, 0.6359263945770546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 314}], {
             RGBColor[
             0.8821817648864305, 0.8667347552866029, 0.6471620843303616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 332}], {
             RGBColor[
             0.9709478521729675, 0.913662424990028, 0.3416383210400904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 352}], {
             RGBColor[
             0.9740738105488989, 0.9385549519086458, 0.6106498028657066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 385}], {
             RGBColor[
             0.916915349327258, 0.8942740500998391, 0.6505164878334151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 306}], {
             RGBColor[
             0.9825778700428767, 0.984939849278675, 0.8432911857233005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 307}], {
             RGBColor[
             0.7755301272361348, 0.8215867520543493, 0.8557972864224761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 314}], {
             RGBColor[
             0.8971949234090458, 0.9179349988839955, 0.8670329761757831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 336}], {
             RGBColor[
             0.6227751065440376, 0.6899062931036966, 0.9250543064382524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 367}], {
             RGBColor[
             0.6229236489830441, 0.6755079520794354, 0.6659237461129319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 306}], {
             RGBColor[
             0.9802790927361498, 0.9839892457864614, 0.8813878747407318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 307}], {
             RGBColor[
             0.773231349929408, 0.8206361485621356, 0.8938939754399073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 314}], {
             RGBColor[
             0.894896146102319, 0.9169843953917819, 0.9051296651932144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 363}], {
             RGBColor[
             0.9025864013681217, 0.9229920812535317, 0.9058961579685882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 316}], {
             RGBColor[
             0.889896470414128, 0.914781155578906, 0.9802713877682201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 324}], {
             RGBColor[
             0.8650410712125672, 0.7458787293749085, 0.60954138589506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 372}], {
             RGBColor[
             0.8574155188454129, 0.8891438770758204, 0.9862622516829869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 380}], {
             RGBColor[
             0.9112483859096344, 0.929978244928425, 0.9115656062305653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 383}], {
             RGBColor[
             0.8666135821392248, 0.8964781630715292, 0.9871395711711586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 390}], {
             RGBColor[
             0.8437307546096049, 0.8782320175372166, 0.9849569866536423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 323}], {
             RGBColor[
             0.9732986601222238, 0.9435870756300042, 0.625540606485597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 340}], {
             RGBColor[
             0.9866472895733218, 0.9872850986128517, 0.7904943901657135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 313}], {
             RGBColor[
             0.7546688658527986, 0.8065750031886476, 0.9342786716695959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 344}], {
             RGBColor[
             0.918804792323981, 0.9368603123583054, 0.9493442878178612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 315}], {
             RGBColor[
             0.779579495933443, 0.8254333185839896, 0.8794889169433193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 329}], {
             RGBColor[
             0.689154598616674, 0.7502316735682166, 0.8728650968953323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 353}], {
             RGBColor[
             0.6841387606529978, 0.7458872068274265, 0.8725454921356182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 378}], {
             RGBColor[
             0.9924376419370111, 0.9899797799570798, 0.6905985749571852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 325}], {
             RGBColor[
             0.6684874472602289, 0.7340081411656905, 0.929866041506676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 314}], {
             RGBColor[
             0.6789786369661451, 0.7478397553448319, 0.9695286232898673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 352}], {
             RGBColor[
             0.7708706826286135, 0.8196599519668748, 0.9330163418252124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 385}], {
             RGBColor[
             0.7137122214069727, 0.7753790501580681, 0.9728830267929208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 386}], {
             RGBColor[
             0.922907094081693, 0.8409269178648379, 0.6256119551275998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 397}], {
             RGBColor[
             0.919385593886346, 0.8381189691976445, 0.6252760712952874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 319}], {
             RGBColor[
             0.7500617821895982, 0.8016223815826731, 0.8835558560990926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 329}], {
             RGBColor[
             0.4486610899538175, 0.561491670854284, 0.9502341500884429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 334}], {
             RGBColor[
             0.7215760546258043, 0.7813067429324275, 0.9740275441868833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 371}], {
             RGBColor[
             0.7506025277871082, 0.8018459937837714, 0.8745943021436047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 386}], {
             RGBColor[
             0.7150988857877008, 0.7761420243189883, 0.973409746040868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 345}], {
             RGBColor[
             0.9090234482459432, 0.81905487418925, 0.621868950558716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 363}], {
             RGBColor[
             0.8576615342642703, 0.8893720507539702, 0.9862772230041572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 323}], {
             RGBColor[
             0.9531275602623037, 0.9285435023816204, 0.6596850170830317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 339}], {
             RGBColor[
             0.867381258023511, 0.8972134304571799, 0.9848419894713984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 327}], {
             RGBColor[
             0.6184672661922229, 0.6974556445607232, 0.9652295638601767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 356}], {
             RGBColor[
             0.891962046527117, 0.9159514584576698, 0.9637704129440028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 361}], {
             RGBColor[
             0.7176886073773849, 0.7789791709580013, 0.9727722936491474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 344}], {
             RGBColor[
             0.6899329849626261, 0.7561900739973876, 0.9708774331322512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 359}], {
             RGBColor[
             0.37021839352508557`, 0.48441755343036186`, 0.9456733020215791]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 385}], {
             RGBColor[
             0.8353770175798837, 0.8717272969877143, 0.9841187165462278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 319}], {
             RGBColor[
             0.7791957014390651, 0.8252746096974958, 0.8858493849434732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 329}], {
             RGBColor[
             0.47779500920328444`, 0.5851438989691067, 0.9525276789328236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 334}], {
             RGBColor[
             0.7507099738752712, 0.8049589710472502, 0.9763210730312639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 371}], {
             RGBColor[
             0.7797364470365751, 0.8254982218985941, 0.8768878309879853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 324}], {
             RGBColor[
             0.9210095022061247, 0.7902442864207185, 0.6057907787353551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 355}], {
             RGBColor[
             0.876371323740492, 0.9041025037229788, 0.978953235851004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 380}], {
             RGBColor[
             0.9672168169031918, 0.974343801974235, 0.9078149990708604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 383}], {
             RGBColor[
             0.9225820131327822, 0.9408437201173392, 0.9833889640114537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 390}], {
             RGBColor[
             0.8996991856031622, 0.9225975745830266, 0.9812063794939374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 333}], {
             RGBColor[
             0.9932266346923115, 0.9879207814361639, 0.5041391705024426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 370}], {
             RGBColor[
             0.8275065524586258, 0.8618191846181245, 0.7357600463381464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 381}], {
             RGBColor[
             0.9821408097713927, 0.9509697038086862, 0.42331718148275294`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 382}], {
             RGBColor[
             0.9776306268843004, 0.9795663460490389, 0.7268764679770581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 367}], {
             RGBColor[
             0.7246685188921682, 0.7676840277417742, 0.6723346001791546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 373}], {
             RGBColor[
             0.5111207547488059, 0.6139898802895073, 0.9546564445922934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 329}], {
             RGBColor[
             0.6887708041222962, 0.7500729646817228, 0.8792255648954861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 334}], {
             RGBColor[
             0.961685768794283, 0.9698880367598663, 0.9030189589939265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 371}], {
             RGBColor[
             0.9907122419555869, 0.9904272876112102, 0.803585716950648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 388}], {
             RGBColor[
             0.7195696403740636, 0.7767493686484837, 0.8811880395071072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 343}], {
             RGBColor[
             0.7607159322411585, 0.8131630218179553, 0.9770158219882252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 349}], {
             RGBColor[
             0.765898212982131, 0.8172952318115433, 0.9775101125515757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 331}], {
             RGBColor[
             0.8341464001876973, 0.8705792768081102, 0.9475721389057691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 338}], {
             RGBColor[
             0.8752489715017522, 0.9026889179097619, 0.9516688590889867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 342}], {
             RGBColor[
             0.9716913326232108, 0.9784080227383549, 0.9328033691726869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 384}], {
             RGBColor[
             0.7097147563957968, 0.7700486563391614, 0.9373309440827107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 398}], {
             RGBColor[
             0.9810523979333732, 0.9851023457203593, 0.9040986234592538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 328}], {
             RGBColor[
             0.9564465802536571, 0.8590047231478218, 0.3152054819180958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 362}], {
             RGBColor[
             0.9079571277724672, 0.8463929281161429, 0.6280793670219265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 364}], {
             RGBColor[
             0.8974811493481318, 0.8380396672834369, 0.6270801588477971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 340}], {
             RGBColor[
             0.9813094379567386, 0.9472844482917765, 0.49498800412850746`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 375}], {
             RGBColor[
             0.944932053590235, 0.8065043997725041, 0.4944829079311059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 380}], {
             RGBColor[
             0.9423614177016311, 0.8054413757702374, 0.5370849971977003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 383}], {
             RGBColor[
             0.8977266139312214, 0.7719412939133417, 0.6126589621382936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 390}], {
             RGBColor[
             0.8748437864016014, 0.7536951483790291, 0.6104763776207773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 335}], {
             RGBColor[
             0.9164479355626303, 0.9362147237738648, 0.9918928162883356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 337}], {
             RGBColor[
             0.9375455134716251, 0.9523209539536409, 0.9690668844569024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 354}], {
             RGBColor[
             0.9480050423605818, 0.9600871874859951, 0.9498181730084205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 337}], {
             RGBColor[
             0.6905154441667198, 0.7541836509809816, 0.947264632584879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 354}], {
             RGBColor[
             0.7009749730556767, 0.7619498845133358, 0.9280159211363971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 356}], {
             RGBColor[
             0.691045270396588, 0.7545787945157065, 0.9463677749785243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 392}], {
             RGBColor[
             0.7055736340024957, 0.7623977305207799, 0.7461269525038047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 347}], {
             RGBColor[
             0.9811330684863251, 0.9601582998542009, 0.6228038709921068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 362}], {
             RGBColor[
             0.9278563196258477, 0.9192590813878407, 0.675482105776138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 372}], {
             RGBColor[
             0.9286243851886464, 0.9198715160190323, 0.675555364555178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 387}], {
             RGBColor[
             0.9305710745749826, 0.9214237532942209, 0.6757410415266769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 334}], {
             RGBColor[
             0.6602850765585024, 0.7297573260314772, 0.9696972529832768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 353}], {
             RGBColor[
             0.38235427392283927`, 0.5055977872125437, 0.9455842541251225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 371}], {
             RGBColor[
             0.6893115497198061, 0.7502965768828211, 0.8702640109399983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 388}], {
             RGBColor[
             0.41816894813828287`, 0.5366186579200947, 0.9478663334964577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 342}], {
             RGBColor[
             0.8296533018097744, 0.8672283313946285, 0.9551777824718546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 346}], {
             RGBColor[
             0.7824995188742478, 0.8304414633563716, 0.9788424187324059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 361}], {
             RGBColor[
             0.7970843900720741, 0.8185866874973222, 0.6663145859676359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 385}], {
             RGBColor[
             0.9241431048664206, 0.9186549666911392, 0.6785949532559568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 381}], {
             RGBColor[
             0.9821366111688195, 0.9509607234223258, 0.4228601895034269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 371}], {
             RGBColor[
             0.962226514391793, 0.9701116489609647, 0.8940574050384387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 388}], {
             RGBColor[
             0.6910839128102697, 0.7564337299982382, 0.9716597275948979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 337}], {
             RGBColor[
             0.9423828203627511, 0.9561780911634272, 0.9695282711064929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 354}], {
             RGBColor[
             0.9528423492517079, 0.9639443246957813, 0.9502795596580109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 367}], {
             RGBColor[
             0.9841860707350243, 0.9732174542318333, 0.6527739199768487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 354}], {
             RGBColor[
             0.9739399271607025, 0.9800505548755574, 0.9274536278265778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 384}], {
             RGBColor[
             0.6087792968964152, 0.6909786060970866, 0.963802077565096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 398}], {
             RGBColor[
             0.8801169384339915, 0.9060322954782845, 0.9305697569416391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 360}], {
             RGBColor[
             0.8679704522050118, 0.8976528505130263, 0.9838446374085712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 374}], {
             RGBColor[
             0.8852132556338489, 0.8823718391392171, 0.6668407678612549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 368}], {
             RGBColor[
             0.8517244767124988, 0.8807037308135108, 0.7353961476897644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 379}], {
             RGBColor[
             0.9758612016905236, 0.9298186405872619, 0.39624106092066935`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 393}], {
             RGBColor[
             0.9402873662104365, 0.9504345910986182, 0.744078680312141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 399}], {
             RGBColor[
             0.9892081373681401, 0.9879917154878779, 0.696684049261817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 346}], {
             RGBColor[
             0.9200444513097614, 0.9382702092866164, 0.9640736489993237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 398}], {
             RGBColor[
             0.9765592995554503, 0.9817514003068777, 0.9117042670253394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 349}], {
             RGBColor[
             0.9272211936297688, 0.9448050273243012, 0.9929203792601802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 349}], {
             RGBColor[
             0.893236192902275, 0.9177063102424673, 0.9896788595520236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 362}], {
             RGBColor[
             0.9326436160051352, 0.9475465048225219, 0.9356777560959375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 372}], {
             RGBColor[
             0.933411681567934, 0.9481589394537133, 0.9357510148749775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 387}], {
             RGBColor[
             0.9353583709542701, 0.949711176728902, 0.9359366918464764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 351}], {
             RGBColor[
             0.7362590239605372, 0.7902638078713622, 0.8760785707014946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 369}], {
             RGBColor[
             0.7377764276801662, 0.7897628067494997, 0.7689022044825342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 357}], {
             RGBColor[
             0.5848375531796545, 0.6486295658256207, 0.8868051167601894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 394}], {
             RGBColor[
             0.5829251929245283, 0.647838755714709, 0.9184978752173271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 378}], {
             RGBColor[
             0.6856373172431762, 0.7453458936014067, 0.7633177321869754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 375}], {
             RGBColor[
             0.9002938751246023, 0.9203626170747645, 0.8676453650467548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 379}], {
             RGBColor[
             0.8827102016588815, 0.8604375422195727, 0.6374160861804217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 366}], {
             RGBColor[
             0.9328900198945766, 0.9492606448555296, 0.9912230651996343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 391}], {
             RGBColor[
             0.9522346564329792, 0.9636878431119351, 0.9584776414293724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 374}], {
             RGBColor[
             0.9567155038108053, 0.9390984081921956, 0.670337240044702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 375}], {
             RGBColor[
             0.9665913522789373, 0.973023179447146, 0.8706230742960175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 369}], {
             RGBColor[
             0.8049835326090544, 0.8443245621763454, 0.7741929939702734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 385}], {
             RGBColor[
             0.7430518872263647, 0.7991983126071333, 0.9751927527609605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 377}], {
             RGBColor[
             0.9047624027892021, 0.8669074108434056, 0.6329388262794668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 387}], {
             RGBColor[
             0.8716056436694573, 0.9004586974298361, 0.9876157184563782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 382}], {
             RGBColor[
             0.9501163106364666, 0.9623174066664972, 0.969324253729301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 393}], {
             RGBColor[
             0.7988320967863527, 0.8433178303555087, 0.9804391874279169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 399}], {
             RGBColor[
             0.8477528679440562, 0.8808749547447685, 0.933044556377593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 392}], {
             RGBColor[
             0.993785335364694, 0.9891157856810872, 0.564950290790409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 389}], {
             RGBColor[
             0.44902402068193964`, 0.5506846449500159, 0.9518451441530975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 391}], {
             RGBColor[
             0.8193368727491945, 0.8589974434919884, 0.9454624083201275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 400}], {
             RGBColor[
             0.6292934289500365, 0.7096302410755078, 0.9641628599374947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 395}], {
             RGBColor[
             0.7762209833411342, 0.8218575504460051, 0.8437256209433186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 375}], {
             RGBColor[
             0.9838341557077743, 0.9577421680733369, 0.5536192047487012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 399}], {
             RGBColor[
             0.97959741791967, 0.955990168118761, 0.6238329142235157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 379}], {
             RGBColor[
             0.9761263307101854, 0.9317418644730955, 0.5236757601336834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 383}], {
             RGBColor[
             0.9465045645168926, 0.9571038334691249, 0.8720810932072045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 399}], {
             RGBColor[
             0.9894732663878019, 0.9899149393737114, 0.8241187484748311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 377}], {
             RGBColor[
             0.9725870818345366, 0.9167932261033356, 0.4374152534415765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 393}], {
             RGBColor[
             0.9229688217643774, 0.89243274012926, 0.6412841006588219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 399}], {
             RGBColor[
             0.971889592922081, 0.9299898645185196, 0.593889469608498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 383}], {
             RGBColor[
             0.9439339286282886, 0.9560408094668581, 0.914683182473799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 390}], {
             RGBColor[
             0.9210511010986686, 0.9377946639325455, 0.9125005979562826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 390}], {
             RGBColor[
             0.876416297328259, 0.9042945820756497, 0.9880745628968759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 398}], {
             RGBColor[
             0.7145827233280362, 0.7733920339076841, 0.9162318419353631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 400}], {
             RGBColor[
             0.4165351780096094, 0.5246062786117989, 0.949084073896068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 399}], {
             RGBColor[
             0.9363157574419939, 0.9506058150298758, 0.9417270889999696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 396}], {
             RGBColor[
             0.9845954891031821, 0.9862026139999771, 0.8290398702900224]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.03217915333176364], {
             RGBColor[
             0.9778449304282945, 0.936927889456232, 0.3684321676580958]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.03217915333176364], {
             RGBColor[
             0.9749746459835387, 0.927245746049234, 0.3572816545979557]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.03217915333176364], {
             RGBColor[
             0.8813468538043928, 0.9082260739733286, 0.9885448437751293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.03217915333176364], {
             RGBColor[
             0.7369107620597555, 0.7943995551410882, 0.9744120360056631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.03217915333176364], {
             RGBColor[
             0.7117969015342693, 0.774780416426169, 0.9719089210908526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.03217915333176364], {
             RGBColor[
             0.838473371709436, 0.8740399231204791, 0.984455532779303]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.03217915333176364], {
             RGBColor[
             0.9538668311047943, 0.9651145386908624, 0.9629756008688234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.03217915333176364], {
             RGBColor[
             0.990414012565445, 0.9903039620942409, 0.80852814973822]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.03217915333176364], {
             RGBColor[
             0.9934883188350759, 0.9915752667428006, 0.7575789388008463]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.03217915333176364], {
             RGBColor[
             0.48413013149251494`, 0.592077676416329, 0.9525316438596474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.03217915333176364], {
             RGBColor[
             0.5968045862777063, 0.6835518747372906, 0.9614017896804652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.03217915333176364], {
             RGBColor[
             0.9936827400289926, 0.9888963446320015, 0.5537834216443298]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.03217915333176364], {
             RGBColor[
             0.5004699321002015, 0.6053430626492777, 0.9538179728181463]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.03217915333176364], {
             RGBColor[
             0.9909325457175354, 0.9905183888783244, 0.7999347134873006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.03217915333176364], {
             RGBColor[
             0.8809029982702553, 0.9078721556185448, 0.9885025084380488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.03217915333176364], {
             RGBColor[
             0.2370133891455966, 0.3664464778818075, 0.9368089339307297]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.03217915333176364], {
             RGBColor[
             0.32294893682550085`, 0.45414387001788753`, 0.941798998575357]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.03217915333176364], {
             RGBColor[
             0.7897622634532746, 0.8356875497159931, 0.9796797797392077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.03217915333176364], {
             RGBColor[
             0.9395701218919575, 0.7981227009044141, 0.27023490548396495`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.03217915333176364], {
             RGBColor[
             0.9471240572441619, 0.9600857889858817, 0.9743893582177987]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.03217915333176364], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.03217915333176364], {
             RGBColor[
             0.907390286978203, 0.9289924006559637, 0.9910288896804945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.03217915333176364], {
             RGBColor[
             0.32294893682550085`, 0.45414387001788753`, 0.941798998575357]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.03217915333176364], {
             RGBColor[
             0.9917366213473762, 0.9908508948150647, 0.786609099419813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.03217915333176364], {
             RGBColor[
             0.9947615453759402, 0.9912038001851704, 0.6712047260447171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.03217915333176364], {
             RGBColor[
             0.9949585195146193, 0.9921832325062259, 0.733213908783418]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.03217915333176364], {
             RGBColor[
             0.981955030180212, 0.986062671571104, 0.9154296064097316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.03217915333176364], {
             RGBColor[
             0.8079335571347428, 0.8498831024469031, 0.9814909244729824]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.03217915333176364], {
             RGBColor[
             0.9380020309430805, 0.9532825967064824, 0.9898305693400342]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.03217915333176364], {
             RGBColor[
             0.8790124950857048, 0.9063647196955262, 0.9883221905566342]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.03217915333176364], {
             RGBColor[
             0.6980287925808034, 0.7640246650702178, 0.9705366446606646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.03217915333176364], {
             RGBColor[
             0.9928739752802545, 0.9871664786131098, 0.46575436986164187`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.03217915333176364], {
             RGBColor[
             0.7909273270619989, 0.83659770626194, 0.979795902391587]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.03217915333176364], {
             RGBColor[
             0.9484937615024728, 0.9611073121790451, 0.972070806184563]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.03217915333176364], {
             RGBColor[
             0.8956387235522602, 0.9196220229678084, 0.9899080150701836]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.03217915333176364], {
             RGBColor[
             0.7858657356461842, 0.832643552578386, 0.9792914102625196]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.03217915333176364], {
             RGBColor[
             0.9941076716061876, 0.9918313850302954, 0.7473146605499355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.03217915333176364], {
             RGBColor[
             0.985246125215471, 0.9881669078663796, 0.8941734171910355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.03217915333176364], {
             RGBColor[
             0.9202457035542821, 0.9392429608827422, 0.9922550507896868]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.03217915333176364], {
             RGBColor[
             0.5201419958879313, 0.6213137302485312, 0.9553666297406604]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.03217915333176364], {
             RGBColor[
             0.9925675246959116, 0.9911944947029261, 0.7728388806256459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.03217915333176364], {
             RGBColor[
             0.865748076798306, 0.8957880326061971, 0.9870570184990961]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.03217915333176364], {
             RGBColor[
             0.7545564423617284, 0.8081844947051268, 0.9761707925099059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.03217915333176364], {
             RGBColor[
             0.9868637410427372, 0.9888358335817848, 0.8673653366776661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.03217915333176364], {
             RGBColor[
             0.9905703895601848, 0.9903686280002713, 0.8059365782446911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.03217915333176364], {
             RGBColor[
             0.9354165841772241, 0.7816553079498896, 0.26689287154262953`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.03217915333176364], {
             RGBColor[
             0.9946420302708916, 0.9909481694603022, 0.6581962444219095]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.03217915333176364], {
             RGBColor[
             0.9215060213919809, 0.9402479041161067, 0.9923752610301455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.03217915333176364], {
             RGBColor[
             0.5427163088699138, 0.6396405744885153, 0.9571437623510353]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.03217915333176364], {
             RGBColor[
             0.9624795917459554, 0.9715379214749391, 0.9483964436710762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.03217915333176364], {
             RGBColor[
             0.9886150728045046, 0.9895600542724489, 0.8383412370838683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.03217915333176364], {
             RGBColor[
             0.9430533875190191, 0.811932688386252, 0.27303762277025145`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.03217915333176364], {
             RGBColor[
             0.9530262524171437, 0.9644876364819339, 0.9643984813289823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.03217915333176364], {
             RGBColor[
             0.9799131558507902, 0.9845398450394837, 0.9188859670433264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.03217915333176364], {
             RGBColor[
             0.9809990396722337, 0.9853496954155446, 0.9170478489774817]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.03217915333176364], {
             RGBColor[
             0.8256828868247093, 0.8638411376618612, 0.9832355649127971]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.03217915333176364], {
             RGBColor[
             0.9689562753165564, 0.9763682214772974, 0.9374331077756614]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.03217915333176364], {
             RGBColor[
             0.3434775874976088, 0.4719247554300838, 0.9431070660434107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.03217915333176364], {
             RGBColor[
             0.990311280934304, 0.9902614799246815, 0.8102306787271661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.03217915333176364], {
             RGBColor[
             0.9883232336279633, 0.9894393712730244, 0.8431777674947356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.03217915333176364], {
             RGBColor[
             0.6170170740106069, 0.699961282841055, 0.9629929907555813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.03217915333176364], {
             RGBColor[
             0.6506177089795514, 0.7269867662233386, 0.9658111509290582]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.03217915333176364], {
             RGBColor[
             0.7773150363528595, 0.8259636813027191, 0.978439156467789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.03217915333176364], {
             RGBColor[
             0.7729250850973812, 0.8225342180170743, 0.9780016071530698]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.03217915333176364], {
             RGBColor[
             0.9895439644301023, 0.9899441748310595, 0.8229470989532455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.03217915333176364], {
             RGBColor[
             0.6015406242718271, 0.6873968037369981, 0.9617746279400412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.03217915333176364], {
             RGBColor[
             0.937570522914108, 0.9529607787250043, 0.9905609998777664]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.03217915333176364], {
             RGBColor[
             0.7217089871167968, 0.7825238130178801, 0.9728968651480128]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.03217915333176364], {
             RGBColor[
             0.7118212327318428, 0.7747994241426375, 0.9719113461972388]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.03217915333176364], {
             RGBColor[
             0.7909273270619989, 0.83659770626194, 0.979795902391587]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.03217915333176364], {
             RGBColor[
             0.9238498943439057, 0.9421168447852353, 0.9925988217247003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.03217915333176364], {
             RGBColor[
             0.9430533875190191, 0.811932688386252, 0.27303762277025145`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.03217915333176364], {
             RGBColor[
             0.9952209898608393, 0.992291770739568, 0.7288640958950715]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.03217915333176364], {
             RGBColor[
             0.6170170740106069, 0.699961282841055, 0.9629929907555813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.03217915333176364], {
             RGBColor[
             0.9947979755948649, 0.9912817207397903, 0.6751699305534237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.03217915333176364], {
             RGBColor[
             0.9544487701962449, 0.9655485479124284, 0.9619905297810208]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.03217915333176364], {
             RGBColor[
             0.9754683076224103, 0.981224884508529, 0.9264099356918899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.03217915333176364], {
             RGBColor[
             0.5968045862777063, 0.6835518747372906, 0.9614017896804652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.03217915333176364], {
             RGBColor[
             0.6506177089795514, 0.7269867662233386, 0.9658111509290582]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.03217915333176364], {
             RGBColor[
             0.7477697780549243, 0.8028827009680923, 0.9754943612367875]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.03217915333176364], {
             RGBColor[
             0.28704782954116775`, 0.41903584710430103`, 0.9396583212919362]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.03217915333176364], {
             RGBColor[
             0.9914512907319964, 0.9907329032729428, 0.7913377661286182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.03217915333176364], {
             RGBColor[
             0.5283119139179765, 0.627946437755935, 0.9560097956153815]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.03217915333176364], {
             RGBColor[
             0.6157111578752769, 0.6989010812915425, 0.9628901842536797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.03217915333176364], {
             RGBColor[
             0.994177846116373, 0.9899553264900042, 0.6076726638151075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.03217915333176364], {
             RGBColor[
             0.5682199065200533, 0.6603455439848797, 0.9591514989808106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.03217915333176364], {
             RGBColor[
             0.9931099288019304, 0.9876711593374142, 0.4914364545597267]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.03217915333176364], {
             RGBColor[
             0.9938269491745185, 0.9892047934125002, 0.5694796971791405]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.03217915333176364], {
             RGBColor[
             0.993349290659074, 0.9915177750191626, 0.7598829954705856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.03217915333176364], {
             RGBColor[
             0.9043599608385418, 0.9265761008482096, 0.9907398544680895]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.03217915333176364], {
             RGBColor[
             0.6185839174615517, 0.701233316940025, 0.9631163384115764]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.03217915333176364], {
             RGBColor[
             0.9945715060851527, 0.9907973253580954, 0.6505201220290423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.03217915333176364], {
             RGBColor[
             0.9562384383455305, 0.966883279487853, 0.9589610884244897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.03217915333176364], {
             RGBColor[
             0.42947414011311225`, 0.5464106469932215, 0.9485866903323049]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.03217915333176364], {
             RGBColor[
             0.8890678340269438, 0.9143825740223658, 0.9892812777613565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.03217915333176364], {
             RGBColor[
             0.8626706658863891, 0.8933341886791284, 0.9867634922990803]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.03217915333176364], {
             RGBColor[
             0.9552526087370188, 0.9661480493799729, 0.9606298408061591]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.03217915333176364], {
             RGBColor[
             0.9071235283128627, 0.9287796945371924, 0.9910034460008561]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.03217915333176364], {
             RGBColor[
             0.5172741016299514, 0.6189854444927392, 0.9551408585992295]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.03217915333176364], {
             RGBColor[
             0.9332716730904277, 0.9496295154103408, 0.9934974793924647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.03217915333176364], {
             RGBColor[
             0.8956387235522602, 0.9196220229678084, 0.9899080150701836]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.03217915333176364], {
             RGBColor[
             0.6415973177133751, 0.7199166320063219, 0.9649280375802627]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.03217915333176364], {
             RGBColor[
             0.9891488590655819, 0.9897807886090856, 0.8294950173432545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.03217915333176364], {
             RGBColor[
             0.6946166608032831, 0.7613590817924569, 0.9701965552532656]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.03217915333176364], {
             RGBColor[
             0.9856011824384292, 0.9630915487409937, 0.3985637420721802]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.03217915333176364], {
             RGBColor[
             0.776436659784649, 0.8252774868517239, 0.9783516081003655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.03217915333176364], {
             RGBColor[
             0.9893481388639258, 0.989863195926958, 0.8261924353651093]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.03217915333176364], {
             RGBColor[
             0.9933812118156202, 0.9882514062727769, 0.5209639364351812]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.03217915333176364], {
             RGBColor[
             0.9761844310011338, 0.9817589681518366, 0.9251977256066013]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.03217915333176364], {
             RGBColor[
             0.8106987765813821, 0.852043312895064, 0.9817665357049784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.03217915333176364], {
             RGBColor[
             0.8605412350658763, 0.8916362383447113, 0.9865603852864544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.03217915333176364], {
             RGBColor[
             0.7396568002665549, 0.7965447810589033, 0.9746857354309308]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.03217915333176364], {
             RGBColor[
             0.942934216198286, 0.9569610123941025, 0.9814816662229082]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.03217915333176364], {
             RGBColor[
             0.9945217121298798, 0.990690821122708, 0.6451003572902687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.03217915333176364], {
             RGBColor[
             0.9662730794480179, 0.9743670983918713, 0.9419750584915348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.03217915333176364], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.03217915333176364], {
             RGBColor[
             0.9866955925584447, 0.9887662998623109, 0.8701519922167215]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.03217915333176364], {
             RGBColor[
             0.8990403893766601, 0.6344478125231008, 0.23746916496042506`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.03217915333176364], {
             RGBColor[
             0.9880825005756676, 0.9893398219693428, 0.847167337168444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.03217915333176364], {
             RGBColor[
             0.9887956347786135, 0.989634721288974, 0.8353488578934728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.03217915333176364], {
             RGBColor[
             0.9929785801523532, 0.9913644766978081, 0.7660266279349873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.03217915333176364], {
             RGBColor[
             0.8902388964911038, 0.9153163474436432, 0.989392974744608]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.03217915333176364], {
             RGBColor[
             0.9482399441866969, 0.8324956572560405, 0.277210848009197]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.03217915333176364], {
             RGBColor[
             0.9925914700950311, 0.9865622285875729, 0.43500542386999874`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.03217915333176364], {
             RGBColor[
             0.8783856108367084, 0.9058648592116961, 0.9882623977773387]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.03217915333176364], {
             RGBColor[
             0.9900503416517303, 0.9901535748255037, 0.814555117928627]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.03217915333176364], {
             RGBColor[
             0.9949087837694928, 0.9915187282208943, 0.6872307165328807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.03217915333176364], {
             RGBColor[
             0.9412649489418922, 0.8048421253897701, 0.27159860311104617`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.03217915333176364], {
             RGBColor[
             0.9934651153184717, 0.9884308673814307, 0.5300963149281613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.03217915333176364], {
             RGBColor[
             0.8999779647492012, 0.9230820161126846, 0.9903218957692341]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.03217915333176364], {
             RGBColor[
             0.8742551829955619, 0.9025713681686429, 0.9878684338825737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.03217915333176364], {
             RGBColor[
             0.9936344961061455, 0.9916357148009723, 0.7551564031245727]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.03217915333176364], {
             RGBColor[
             0.9864436970681325, 0.988662134603648, 0.874326552375826]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.03217915333176364], {
             RGBColor[
             0.9806915889284761, 0.9851203991542545, 0.9175682828906669]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.03217915333176364], {
             RGBColor[
             0.9945715060851527, 0.9907973253580954, 0.6505201220290423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.03217915333176364], {
             RGBColor[
             0.9946004209494714, 0.9908591713291323, 0.653667326568291]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.03217915333176364], {
             RGBColor[
             0.94982806604363, 0.962102434321117, 0.9698121766387433]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.03217915333176364], {
             RGBColor[
             0.9846667435972657, 0.9879273186778234, 0.9037752699962612]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.03217915333176364], {
             RGBColor[
             0.41141499327013836`, 0.5307687216769499, 0.9474359774645472]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.03217915333176364], {
             RGBColor[
             0.8757201747770849, 0.9037395128490867, 0.988008166106509]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.03217915333176364], {
             RGBColor[
             0.8681138745464775, 0.49401773175029295`, 0.21166332290787318`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.03217915333176364], {
             RGBColor[
             0.8939492978970791, 0.9182749208086047, 0.9897468761430244]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.03217915333176364], {
             RGBColor[
             0.9904408597650498, 0.9903150641012191, 0.8080832221624422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.03217915333176364], {
             RGBColor[
             0.9530287416799972, 0.8514816435448103, 0.28106402687983073`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.03217915333176364], {
             RGBColor[
             0.7445225655507209, 0.8003459538800796, 0.9751707094412947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.03217915333176364], {
             RGBColor[
             0.9890946265348266, 0.9748757559778233, 0.41213511270512243`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.03217915333176364], {
             RGBColor[
             0.7207270807360368, 0.7817567402904655, 0.9727989978964154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.03217915333176364], {
             RGBColor[
             0.9921252677860053, 0.9910116101051957, 0.7801682221469873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.03217915333176364], {
             RGBColor[
             0.9717729610139286, 0.916445710855359, 0.3448437130784944]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.03217915333176364], {
             RGBColor[
             0.9126787153976625, 0.9332092499270754, 0.9915333047041783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.03217915333176364], {
             RGBColor[
             0.9933674841248321, 0.9915252984848043, 0.7595814826597933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.03217915333176364], {
             RGBColor[
             0.986288682291065, 0.9885980320096325, 0.8768955483972186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.03217915333176364], {
             RGBColor[
             0.9273856944164587, 0.9449361957863528, 0.9929360694920663]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.03217915333176364], {
             RGBColor[
             0.7740824296462154, 0.8234383443747678, 0.9781169604416979]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.03217915333176364], {
             RGBColor[
             0.9776387991989381, 0.9362325604176988, 0.3676313867566629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.03217915333176364], {
             RGBColor[
             0.9863073129380626, 0.9886057362609518, 0.8765867903618991]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.03217915333176364], {
             RGBColor[
             0.9590151971527306, 0.9689541816597377, 0.9542607600585846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.03217915333176364], {
             RGBColor[
             0.9434711879801027, 0.9573614850697708, 0.9805727130609632]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.03217915333176364], {
             RGBColor[
             0.9492395666665885, 0.9616635324492987, 0.970808352578855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.03217915333176364], {
             RGBColor[
             0.9633155525078686, 0.9721613796424139, 0.9469813801546428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.03217915333176364], {
             RGBColor[
             0.9943292291744872, 0.9919230047785571, 0.743642878270605]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.03217915333176364], {
             RGBColor[
             0.9929822358018073, 0.9913659884028033, 0.7659660443630135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.03217915333176364], {
             RGBColor[
             0.9708270478927749, 0.9132549237867443, 0.34116901922351606`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.03217915333176364], {
             RGBColor[
             0.988689452868605, 0.9895908123404349, 0.8371085669322884]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.03217915333176364], {
             RGBColor[
             0.9459181137547895, 0.8232903732976538, 0.27534264874331954`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.03217915333176364], {
             RGBColor[
             0.536728431988765, 0.6347793462856193, 0.9566723747486354]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.03217915333176364], {
             RGBColor[
             0.9887428598411986, 0.9896128974960989, 0.8362234751835984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.03217915333176364], {
             RGBColor[
             0.5692785841746516, 0.6612050261977673, 0.9592348419638447]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.03217915333176364], {
             RGBColor[
             0.9859203648656126, 0.9884457232888819, 0.8829995213119063]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.03217915333176364], {
             RGBColor[
             0.9785991466989948, 0.9835598591655672, 0.9211102417888417]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.03217915333176364], {
             RGBColor[
             0.7149095373983315, 0.7772120312200832, 0.9722191595445464]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.03217915333176364], {
             RGBColor[
             0.9117017880520794, 0.9324302745796937, 0.9914401245018433]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.03217915333176364], {
             RGBColor[
             0.6778553532915322, 0.7482650209736219, 0.9685259447638186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.03217915333176364], {
             RGBColor[
             0.854043147832133, 0.8864548399704035, 0.985940591925189]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.03217915333176364], {
             RGBColor[
             0.9921172802042678, 0.9910083070348757, 0.7803005970475749]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.03217915333176364], {
             RGBColor[
             0.8249728752937204, 0.8632749937398003, 0.9831678433791367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.03217915333176364], {
             RGBColor[
             0.9660685063116828, 0.9742145280817505, 0.9423213474501309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.03217915333176364], {
             RGBColor[
             0.8539425909174297, 0.8863746586161639, 0.9859310007168964]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.03217915333176364], {
             RGBColor[
             0.4761602560385506, 0.5856073724840032, 0.9519042260692956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.03217915333176364], {
             RGBColor[
             0.9888231519564583, 0.9896461003491721, 0.8348928270444107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.03217915333176364], {
             RGBColor[
             0.9460316544779214, 0.959271076791465, 0.9762385111567718]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.03217915333176364], {
             RGBColor[
             0.5402038124394555, 0.6376008166995948, 0.9569459694284519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.03217915333176364], {
             RGBColor[
             0.9766348131774412, 0.9820948624414935, 0.9244353460605975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.03217915333176364], {
             RGBColor[
             0.824528235337219, 0.8629204499079162, 0.9831254332231507]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.03217915333176364], {
             RGBColor[
             0.9736885631074309, 0.9798975539633215, 0.9294225789240389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.03217915333176364], {
             RGBColor[
             0.9793765250811989, 0.9420943178560046, 0.37438212366724843`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.03217915333176364], {
             RGBColor[
             0.6386178942342517, 0.7174978018044714, 0.9646934864499983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.03217915333176364], {
             RGBColor[
             0.9941462605330693, 0.9898877681211097, 0.6042347679961092]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.03217915333176364], {
             RGBColor[
             0.9871534506816161, 0.9889556359626593, 0.8625640982169309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.03217915333176364], {
             RGBColor[
             0.9761844310011338, 0.9817589681518366, 0.9251977256066013]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.03217915333176364], {
             RGBColor[
             0.9813513374165583, 0.9487558235711591, 0.3820538966781028]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.03217915333176364], {
             RGBColor[
             0.9871790992337907, 0.9889662422981212, 0.8621390353310742]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.03217915333176364], {
             RGBColor[
             0.995202881794962, 0.9922842825889716, 0.7291641934088315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.03217915333176364], {
             RGBColor[
             0.9950775046646745, 0.9918796051553888, 0.705594944748742]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.03217915333176364], {
             RGBColor[
             0.9805828906308406, 0.9850393321418551, 0.9177522807555073]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.03217915333176364], {
             RGBColor[
             0.9204645538489085, 0.9394174661671442, 0.9922759249261582]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.03217915333176364], {
             RGBColor[
             0.7288607828453182, 0.7881108501966617, 0.9736096893089008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.03217915333176364], {
             RGBColor[
             0.9912529875530969, 0.9906508998123086, 0.7946241629951595]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.03217915333176364], {
             RGBColor[
             0.5194233253445855, 0.620730281125704, 0.9553100533629113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.03217915333176364], {
             RGBColor[
             0.7343329055674375, 0.7923857140568544, 0.9741550993619474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.03217915333176364], {
             RGBColor[
             0.9367123044445924, 0.9523207207956432, 0.9920137398874309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.03217915333176364], {
             RGBColor[
             0.9431406504457148, 0.9571149707178299, 0.981132226888686]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.03217915333176364], {
             RGBColor[
             0.9885225955814487, 0.989521812564159, 0.8398738239932851]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.03217915333176364], {
             RGBColor[
             0.6139445435477608, 0.6974668641953965, 0.9627511099024961]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.03217915333176364], {
             RGBColor[
             0.8297657463719493, 0.8670966990385603, 0.9836249917012246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.03217915333176364], {
             RGBColor[
             0.9940655679689777, 0.9897151748857875, 0.5954518803715274]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.03217915333176364], {
             RGBColor[
             0.84102088561913, 0.8760712415616461, 0.9846985169302022]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.03217915333176364], {
             RGBColor[
             0.9917958537215775, 0.9908753889239995, 0.7856274656908265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.03217915333176364], {
             RGBColor[
             0.831648888423281, 0.8685982653937631, 0.9838046074711814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.03217915333176364], {
             RGBColor[
             0.9609760964536265, 0.9704166171476678, 0.9509414690266145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.03217915333176364], {
             RGBColor[
             0.9514928175281536, 0.9633440032524943, 0.9669941866121703]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.03217915333176364], {
             RGBColor[
             0.7308777625255338, 0.7896865300524595, 0.973810722993678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.03217915333176364], {
             RGBColor[
             0.5694640936248703, 0.6613556311265603, 0.9592494459473094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.03217915333176364], {
             RGBColor[
             0.9294921285022348, 0.9466158091487207, 0.9931369830556035]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.03217915333176364], {
             RGBColor[
             0.5806874153631142, 0.6704672293185492, 0.9601329869469262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.03217915333176364], {
             RGBColor[
             0.875732879992756, 0.9037496436431889, 0.9880093779413217]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.03217915333176364], {
             RGBColor[
             0.9947062098902915, 0.9910854431766436, 0.6651817999228824]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.03217915333176364], {
             RGBColor[
             0.9121029186276023, 0.9327501252122163, 0.9914783846942302]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.03217915333176364], {
             RGBColor[
             0.9840646612501637, 0.9876360309688702, 0.9118585512882077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.03217915333176364], {
             RGBColor[
             0.8871362006631254, 0.9128423420108478, 0.9890970368467261]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.03217915333176364], {
             RGBColor[
             0.9632425164670514, 0.972106909482758, 0.9471050111208961]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.03217915333176364], {
             RGBColor[
             0.6515529603004157, 0.727717391663371, 0.9659043680403014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.03217915333176364], {
             RGBColor[
             0.32425505815460365`, 0.4552751666655896, 0.9418822234714898]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.03217915333176364], {
             RGBColor[
             0.8260508822776751, 0.8641345672470856, 0.9832706646476144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.03217915333176364], {
             RGBColor[
             0.977564990595673, 0.982788587236985, 0.922860798320656]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.03217915333176364], {
             RGBColor[
             0.9850287675372524, 0.9880770248805988, 0.8977755964227563]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.03217915333176364], {
             RGBColor[
             0.9846898098823863, 0.9879368571794972, 0.9033930019581802]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.03217915333176364], {
             RGBColor[
             0.4983830559493258, 0.6036488425772977, 0.9536536862830701]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.03217915333176364], {
             RGBColor[
             0.8956387235522602, 0.9196220229678084, 0.9899080150701836]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.03217915333176364], {
             RGBColor[
             0.9714093264067177, 0.9781977029638371, 0.933280732138209]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.03217915333176364], {
             RGBColor[
             0.3015645098706708, 0.434293798541302, 0.9404850247611973]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.03217915333176364], {
             RGBColor[
             0.9931948241034035, 0.9878527418030338, 0.5006767842120194]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.03217915333176364], {
             RGBColor[
             0.9944611473371561, 0.9905612791551118, 0.6385082533648669]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.03217915333176364], {
             RGBColor[
             0.2324960928380912, 0.36169851304949097`, 0.9365516805887583]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.03217915333176364], {
             RGBColor[
             0.6139445435477608, 0.6974668641953965, 0.9627511099024961]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.03217915333176364], {
             RGBColor[
             0.9949329922067446, 0.9915705076203275, 0.6898656555305827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.03217915333176364], {
             RGBColor[
             0.6219331227511606, 0.7039523526741084, 0.9633800001205176]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.03217915333176364], {
             RGBColor[
             0.9313276441625827, 0.765444023350323, 0.26360281442709127`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.03217915333176364], {
             RGBColor[
             0.9726290817123641, 0.9791073944736222, 0.9312160045688838]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.03217915333176364], {
             RGBColor[
             0.9799871593732274, 0.9441541307067669, 0.3767543225831691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.03217915333176364], {
             RGBColor[
             0.9945643986924516, 0.9907821233637756, 0.6497465261952793]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.03217915333176364], {
             RGBColor[
             0.9803771172906582, 0.9454695503287343, 0.37826923545501423`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.03217915333176364], {
             RGBColor[
             0.9010420977386313, 0.9239305268733357, 0.9904233937237288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.03217915333176364], {
             RGBColor[
             0.9947282084746851, 0.9911324959242636, 0.667576210074607]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.03217915333176364], {
             RGBColor[
             0.8696153578424157, 0.8988716975362228, 0.9874258832174458]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.03217915333176364], {
             RGBColor[
             0.9727024521116139, 0.9791621139972497, 0.9310918076210186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.03217915333176364], {
             RGBColor[
             0.9595331005153829, 0.9693404331396148, 0.9533840847564448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.03217915333176364], {
             RGBColor[
             0.9842825207528929, 0.9877684326575985, 0.9101428368643654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.03217915333176364], {
             RGBColor[
             0.5524491452170374, 0.6475421294943909, 0.9579099668808351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.03217915333176364], {
             RGBColor[
             0.9861112694144875, 0.9885246672258647, 0.8798357388919155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.03217915333176364], {
             RGBColor[
             0.9837915033425222, 0.9874323102486061, 0.9123209363748526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.03217915333176364], {
             RGBColor[
             0.981955030180212, 0.986062671571104, 0.9154296064097316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.03217915333176364], {
             RGBColor[
             0.9874529243737324, 0.9890794760304723, 0.8576010441254921]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.03217915333176364], {
             RGBColor[
             0.9382943120189666, 0.953500579454312, 0.9893358137176727]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.03217915333176364], {
             RGBColor[
             0.6252779240890408, 0.7066678130817827, 0.9636433151342465]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.03217915333176364], {
             RGBColor[
             0.8532091226816253, 0.8857898109543982, 0.9858610418617906]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.03217915333176364], {
             RGBColor[
             0.9785107154311647, 0.9834939072708124, 0.9212599328587097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.03217915333176364], {
             RGBColor[
             0.662382460807073, 0.736177479766424, 0.966983751443369]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.03217915333176364], {
             RGBColor[
             0.8819600026222219, 0.9087149821971842, 0.9886033264567382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.03217915333176364], {
             RGBColor[
             0.9938234544568546, 0.9917138539349987, 0.7520248742447877]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.03217915333176364], {
             RGBColor[
             0.9863073129380626, 0.9886057362609518, 0.8765867903618991]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.03217915333176364], {
             RGBColor[
             0.9388279218437222, 0.9538985447879087, 0.9884325514720932]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.03217915333176364], {
             RGBColor[
             0.9865444544591322, 0.9887038003741732, 0.8726567416551927]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.03217915333176364], {
             RGBColor[
             0.9435209998337035, 0.9573986346686268, 0.980488394585829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.03217915333176364], {
             RGBColor[
             0.9938624455510825, 0.9892807165727365, 0.5733432587098928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.03217915333176364], {
             RGBColor[
             0.9791116554111589, 0.9839420873239432, 0.9202426982228282]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.03217915333176364], {
             RGBColor[
             0.9534084454708629, 0.9647726754356141, 0.9637515281809486]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.03217915333176364], {
             RGBColor[
             0.984323663289878, 0.9877854461539568, 0.9094609985530487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.03217915333176364], {
             RGBColor[
             0.7339355399024102, 0.7920752889792442, 0.9741154936660508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.03217915333176364], {
             RGBColor[
             0.8932703783499986, 0.9177335687905429, 0.9896821201905451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.03217915333176364], {
             RGBColor[
             0.9934045463150017, 0.9915406246528944, 0.7589672662548084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.03217915333176364], {
             RGBColor[
             0.6720965910716467, 0.7437662321592334, 0.967951965164433]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.03217915333176364], {
             RGBColor[
             0.9593515082026185, 0.9692050018900853, 0.9536914731750943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.03217915333176364], {
             RGBColor[
             0.9804317531512577, 0.9849266140570472, 0.9180081170854731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.03217915333176364], {
             RGBColor[
             0.9940936981724785, 0.9897753425466759, 0.5985136794230964]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.03217915333176364], {
             RGBColor[
             0.9720207441607501, 0.9172815415918374, 0.34580630381397487`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.03217915333176364], {
             RGBColor[
             0.896512604937052, 0.9203188322631631, 0.9899913666567881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.03217915333176364], {
             RGBColor[
             0.9949179168218414, 0.9915382628963746, 0.6882247929183534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.03217915333176364], {
             RGBColor[
             0.9930277423346682, 0.9913848065236058, 0.7652118833463779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.03217915333176364], {
             RGBColor[
             0.9927164693170786, 0.9868295892841723, 0.4486108177840804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.03217915333176364], {
             RGBColor[
             0.7779704342202024, 0.8264756830978957, 0.9785044804021644]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.03217915333176364], {
             RGBColor[
             0.6040738538965886, 0.6894533936670736, 0.9619740530556283]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.03217915333176364], {
             RGBColor[
             0.45900122163566676`, 0.5716768953500513, 0.9505534040254865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.03217915333176364], {
             RGBColor[
             0.9438421253397349, 0.8150597710140917, 0.2736722597348554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.03217915333176364], {
             RGBColor[
             0.9507626533357217, 0.9627994479933127, 0.9682301641326365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.03217915333176364], {
             RGBColor[
             0.9885918788840742, 0.9895504629902944, 0.838725620369342]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.03217915333176364], {
             RGBColor[
             0.9898174081297815, 0.9900572508280593, 0.8184154291999515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.03217915333176364], {
             RGBColor[
             0.993924687869156, 0.9894138465974319, 0.5801179509171274]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.03217915333176364], {
             RGBColor[
             0.6386178942342517, 0.7174978018044714, 0.9646934864499983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.03217915333176364], {
             RGBColor[
             0.9812639233572324, 0.9855472452341094, 0.9165994699915083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.03217915333176364], {
             RGBColor[
             0.9644755030666472, 0.9730264688699063, 0.9450178864221886]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.03217915333176364], {
             RGBColor[
             0.9563015591910871, 0.9669303549111182, 0.9588542412975156]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.03217915333176364], {
             RGBColor[
             0.988893682147869, 0.9896752663958636, 0.8337239592464529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.03217915333176364], {
             RGBColor[
             0.6925484911340508, 0.7597434119281811, 0.9699904194287811]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.03217915333176364], {
             RGBColor[
             0.9804317531512577, 0.9849266140570472, 0.9180081170854731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.03217915333176364], {
             RGBColor[
             0.4665859825496642, 0.5778345459496197, 0.9511505041885311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.03217915333176364], {
             RGBColor[
             0.9637200966338049, 0.8892815083987278, 0.3135598556175487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.03217915333176364], {
             RGBColor[
             0.9937464136790355, 0.9916819955935128, 0.753301639308392]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.03217915333176364], {
             RGBColor[
             0.26151268479205736`, 0.39219679095129867`, 0.9382041325743357]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.03217915333176364], {
             RGBColor[
             0.9891488590655819, 0.9897807886090856, 0.8294950173432545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.03217915333176364], {
             RGBColor[
             0.8339280394205706, 0.870415598533096, 0.984021994927925]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.03217915333176364], {
             RGBColor[
             0.978636511738807, 0.9835877259510795, 0.921046992522803]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.03217915333176364], {
             RGBColor[
             0.9835406732141534, 0.9872452415495654, 0.912745526355206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.03217915333176364], {
             RGBColor[
             0.9909390853468326, 0.9905210931830996, 0.7998263349058281]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.03217915333176364], {
             RGBColor[
             0.35528172475164843`, 0.48214890582634373`, 0.9438592152312494]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.03217915333176364], {
             RGBColor[
             0.9714093264067177, 0.9781977029638371, 0.933280732138209]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.03217915333176364], {
             RGBColor[
             0.5573138407932341, 0.6514915085151858, 0.9582929335365603]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.03217915333176364], {
             RGBColor[
             0.9255684846091039, 0.7426108748469336, 0.25896885946551296`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.03217915333176364], {
             RGBColor[
             0.5099520680211195, 0.6130410877552342, 0.9545644412920493]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.03217915333176364], {
             RGBColor[
             0.899299124857879, 0.9225407276099623, 0.9902571474143923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.03217915333176364], {
             RGBColor[
             0.9382943120189666, 0.953500579454312, 0.9893358137176727]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.03217915333176364], {
             RGBColor[
             0.8193840423227519, 0.8588283085026864, 0.9826322018256551]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.03217915333176364], {
             RGBColor[
             0.5257970584914438, 0.6259047648277298, 0.9558118169839859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.03217915333176364], {
             RGBColor[
             0.8006434331390562, 0.8441880021744782, 0.9807643130431744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.03217915333176364], {
             RGBColor[
             0.5682199065200533, 0.6603455439848797, 0.9591514989808106]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.03217915333176364], {
             RGBColor[
             0.9458649014076854, 0.9591467126247161, 0.9765207806085152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.03217915333176364], {
             RGBColor[
             0.9932308332948847, 0.9879297618225242, 0.5045961624817686]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.03217915333176364], {
             RGBColor[
             0.4650024246103056, 0.5765489422759762, 0.9510258407067809]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.03217915333176364], {
             RGBColor[
             0.9901714963580769, 0.9902036754101119, 0.8125472709061358]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.03217915333176364], {
             RGBColor[
             0.5993929515935207, 0.6856532263051973, 0.9616055552796207]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.03217915333176364], {
             RGBColor[
             0.9761844310011338, 0.9817589681518366, 0.9251977256066013]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.03217915333176364], {
             RGBColor[
             0.9365473884002766, 0.786138569876124, 0.2678027431638843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.03217915333176364], {
             RGBColor[
             0.9679608085056407, 0.903586425308929, 0.3300342204483909]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.03217915333176364], {
             RGBColor[
             0.8961541030045639, 0.621341860216721, 0.235060776862195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.03217915333176364], {
             RGBColor[
             0.9816931697688095, 0.9858673765050371, 0.9158728677821026]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.03217915333176364], {
             RGBColor[
             0.9116106286715042, 0.9323575865640785, 0.9914314296387451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.03217915333176364], {
             RGBColor[
             0.417550490061694, 0.53608298061876, 0.9478269258946983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.03217915333176364], {
             RGBColor[
             0.9763457721070377, 0.9318708764195197, 0.36260822067230725`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.03217915333176364], {
             RGBColor[
             0.38737011188651554`, 0.5099422539533337, 0.9459038588848365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.03217915333176364], {
             RGBColor[
             0.9946113486462729, 0.9908825445676307, 0.6548567389271938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.03217915333176364], {
             RGBColor[
             0.6921083693742608, 0.7593995854643838, 0.9699465522049369]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.03217915333176364], {
             RGBColor[
             0.9781756077121301, 0.9380433415813282, 0.3697167864626322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.03217915333176364], {
             RGBColor[
             0.9932224360897383, 0.9879118010498035, 0.5036821785231166]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.03217915333176364], {
             RGBColor[
             0.9332000412304892, 0.9495723981096208, 0.9934906470817172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.03217915333176364], {
             RGBColor[
             0.9212852424537563, 0.9400718609836511, 0.992354202937926]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.03217915333176364], {
             RGBColor[
             0.9840375282960178, 0.9876157952560943, 0.9119044803021691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.03217915333176364], {
             RGBColor[
             0.9634803982717458, 0.9722843213432033, 0.9467023392750598]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.03217915333176364], {
             RGBColor[
             0.7743135120023705, 0.8236188676676871, 0.9781399925713721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.03217915333176364], {
             RGBColor[
             0.7964682040280554, 0.8409262814600479, 0.9803481652251242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.03217915333176364], {
             RGBColor[
             0.9946580674078366, 0.990982471274624, 0.659941787808624]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.03217915333176364], {
             RGBColor[
             0.9931797461365827, 0.9878204915566202, 0.49903564057398847`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.03217915333176364], {
             RGBColor[
             0.967198234245288, 0.9750570773248733, 0.9404090127387724]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.03217915333176364], {
             RGBColor[
             0.9220389128887965, 0.9406728173307132, 0.9924260886968297]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.03217915333176364], {
             RGBColor[
             0.8540689114338086, 0.8864753831670453, 0.9859430492805163]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.03217915333176364], {
             RGBColor[
             0.9187477716340074, 0.7155690207685379, 0.25348075370303974`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.03217915333176364], {
             RGBColor[
             0.8728906683742349, 0.9014833412483594, 0.987738285259875]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.03217915333176364], {
             RGBColor[
             0.9859203648656126, 0.9884457232888819, 0.8829995213119063]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.03217915333176364], {
             RGBColor[
             0.4815789625742418, 0.5900065225596248, 0.9523308064971613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.03217915333176364], {
             RGBColor[
             0.9324034743707412, 0.9489372373178893, 0.9934146698235308]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.03217915333176364], {
             RGBColor[
             0.18115904553492043`, 0.3077400213770621, 0.9336281116911983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.03217915333176364], {
             RGBColor[
             0.9909390853468326, 0.9905210931830996, 0.7998263349058281]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.03217915333176364], {
             RGBColor[
             0.9844275244639928, 0.9878283954185637, 0.9077397501138644]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.03217915333176364], {
             RGBColor[
             0.37733843595916294`, 0.5012533204717535, 0.9452646493654083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.03217915333176364], {
             RGBColor[
             0.9843994560496594, 0.9878167884079115, 0.9082049163780959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.03217915333176364], {
             RGBColor[
             0.8068777460732985, 0.8490582948212416, 0.9813856910934929]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.03217915333176364], {
             RGBColor[
             0.9645400507314821, 0.973074608412653, 0.9449086240623503]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.03217915333176364], {
             RGBColor[
             0.9885160608243886, 0.9895191102741792, 0.8399821218291805]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.03217915333176364], {
             RGBColor[
             0.9275778389899361, 0.9450894066536182, 0.9929543964130141]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.03217915333176364], {
             RGBColor[
             0.21463972855872734`, 0.3429303420329939, 0.9355347870591721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.03217915333176364], {
             RGBColor[
             0.9394727003819683, 0.9543794195660047, 0.9873411095920183]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.03217915333176364], {
             RGBColor[
             0.6159931724320181, 0.6991300334133161, 0.9629123854726397]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.03217915333176364], {
             RGBColor[
             0.8793668671446577, 0.9066472863561619, 0.9883559908799687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.03217915333176364], {
             RGBColor[
             0.8160239436706616, 0.856203373897978, 0.982297298593922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.03217915333176364], {
             RGBColor[
             0.858414910295987, 0.8899407646907499, 0.9863575745317099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.03217915333176364], {
             RGBColor[
             0.8789578871296657, 0.9063211767936741, 0.988316982001038]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.03217915333176364], {
             RGBColor[
             0.9382022007992172, 0.9534318830574411, 0.9894917339862547]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.03217915333176364], {
             RGBColor[
             0.9843346131740308, 0.9588191132075722, 0.3936433596515283]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.03217915333176364], {
             RGBColor[
             0.710269207288415, 0.7735869700704013, 0.9717566548055403]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.03217915333176364], {
             RGBColor[
             0.9939738927860906, 0.9895190909393747, 0.585473602467907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.03217915333176364], {
             RGBColor[
             0.6617822716223668, 0.7357086074137248, 0.9669239301945243]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.03217915333176364], {
             RGBColor[
             0.9912529875530969, 0.9906508998123086, 0.79462416299516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.03217915333176364], {
             RGBColor[
             0.8809029982702553, 0.9078721556185448, 0.9885025084380488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.03217915333176364], {
             RGBColor[
             0.5572390848873063, 0.6514308183030384, 0.9582870484778058]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.03217915333176364], {
             RGBColor[
             0.9739583072396424, 0.9238173968183864, 0.3533333704973856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.03217915333176364], {
             RGBColor[
             0.9937100041759063, 0.9916669393282873, 0.7539050390000167]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.03217915333176364], {
             RGBColor[
             0.9940642683866563, 0.9897123952106099, 0.5953104288559291]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.03217915333176364], {
             RGBColor[
             0.951109895282417, 0.8438740569960613, 0.27952007802722384`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.03217915333176364], {
             RGBColor[
             0.9939361985271896, 0.9894384667310598, 0.5813708150085425]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.03217915333176364], {
             RGBColor[
             0.9585426572444645, 0.8718167896179038, 0.2934464812673503]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.03217915333176364], {
             RGBColor[
             0.9885687323986982, 0.9895408913237539, 0.8391092175332057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.03217915333176364], {
             RGBColor[
             0.9710507862479008, 0.9140096457948481, 0.34203820048373723`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.03217915333176364], {
             RGBColor[
             0.962030420473716, 0.9712029302755535, 0.9491567734723474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.03217915333176364], {
             RGBColor[
             0.899299124857879, 0.9225407276099623, 0.9902571474143923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.03217915333176364], {
             RGBColor[
             0.44324508179045985`, 0.5583383445264862, 0.9494641625588199]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.03217915333176364], {
             RGBColor[
             0.8701106020207112, 0.8992665918009504, 0.9874731200492813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.03217915333176364], {
             RGBColor[
             0.9202457035542821, 0.9392429608827422, 0.9922550507896868]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.03217915333176364], {
             RGBColor[
             0.8847963770429275, 0.9109766301689222, 0.9888738623810465]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.03217915333176364], {
             RGBColor[
             0.44896778439005025`, 0.5632950618868555, 0.9498288081080787]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.03217915333176364], {
             RGBColor[
             0.23626576974151248`, 0.36566068248630706`, 0.9367663581116709]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.03217915333176364], {
             RGBColor[
             0.8535334697986391, 0.8860484365413371, 0.9858919783793595]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.03217915333176364], {
             RGBColor[
             0.9768914738760224, 0.9822862795702519, 0.9240008864457308]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.03217915333176364], {
             RGBColor[
             0.9935967779432975, 0.9887124804227996, 0.544426979112911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.03217915333176364], {
             RGBColor[
             0.8873949862842903, 0.9130486906406161, 0.9891217200502935]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.03217915333176364], {
             RGBColor[
             0.9846913403141361, 0.987937490052356, 0.9033676387434558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.03217915333176364], {
             RGBColor[
             0.995202881794962, 0.9922842825889716, 0.7291641934088315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.03217915333176364], {
             RGBColor[
             0.9739880964114023, 0.9801209454109825, 0.928915547171213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.03217915333176364], {
             RGBColor[
             0.913202703163588, 0.9336270635483553, 0.9915832831250617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.03217915333176364], {
             RGBColor[
             0.9859203648656126, 0.9884457232888819, 0.8829995213119063]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.03217915333176364], {
             RGBColor[
             0.9852365285996976, 0.9881629394191356, 0.8943324579496457]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.03217915333176364], {
             RGBColor[
             0.5968045862777063, 0.6835518747372906, 0.9614017896804652]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN2wucz2W+wPHn16rdrWxoc2ntsSnFoptQYTEuNY3rMEhyNxmZGTMj4zII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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[105, 155] -> 
             RGBColor[
              0.3609448647521152, 0.4866656792120809, 0.9442342850410239], 
             UndirectedEdge[1, 203] -> 
             RGBColor[
              0.32569030455946724`, 0.45491432460487713`, 0.9420324056815049],
              UndirectedEdge[187, 193] -> 
             RGBColor[
              0.8331367258093362, 0.8697846265391334, 0.9839465187292714], 
             UndirectedEdge[209, 371] -> 
             RGBColor[
              0.26203929742842424`, 0.3927502942212898, 0.9382341223849231], 
             UndirectedEdge[23, 245] -> 
             RGBColor[
              0.22165838805798918`, 0.35030739817543277`, 0.9359344893344789],
              UndirectedEdge[201, 236] -> 
             RGBColor[
              0.26347424346046877`, 0.3942585134818019, 0.9383158404386357], 
             UndirectedEdge[258, 369] -> 
             RGBColor[
              0.2551936052438994, 0.3855550376934007, 0.9378442703423086], 
             UndirectedEdge[161, 312] -> 
             RGBColor[
              0.44719691052756494`, 0.5614994937585587, 0.949788285319064], 
             UndirectedEdge[74, 132] -> 
             RGBColor[
              0.8119479189165777, 0.8530570556731545, 0.981880980170774], 
             UndirectedEdge[89, 169] -> 
             RGBColor[
              0.2196406470513075, 0.3481866244452415, 0.9358195819691286], 
             UndirectedEdge[124, 137] -> 
             RGBColor[
              0.22241368079166546`, 0.3511012587268517, 0.9359775021383063], 
             UndirectedEdge[186, 393] -> 
             RGBColor[
              0.23564383540018752`, 0.36500699006065973`, 0.9367309398710019],
              UndirectedEdge[84, 261] -> 
             RGBColor[
              0.17918769193352976`, 0.30566800375096304`, 0.9335158460199553],
              UndirectedEdge[58, 243] -> 
             RGBColor[
              0.2935914724788655, 0.42591363072274663`, 0.9400309720767858], 
             UndirectedEdge[205, 250] -> 
             RGBColor[
              0.9917478646376758, 0.990855544204543, 0.7864227690028461], 
             UndirectedEdge[327, 337] -> 
             RGBColor[
              0.3016677329619616, 0.43349195021963505`, 0.9405242352558603], 
             UndirectedEdge[38, 224] -> 
             RGBColor[
              0.970726359968221, 0.9129152797745752, 0.34077786564994345`], 
             UndirectedEdge[49, 301] -> 
             RGBColor[
              0.2562771522862687, 0.3866939143357813, 0.9379059767434073], 
             UndirectedEdge[22, 97] -> 
             RGBColor[
              0.36730142212889694`, 0.4910409193978484, 0.9446807120447999], 
             UndirectedEdge[163, 169] -> 
             RGBColor[
              0.23283585906700827`, 0.36205562889850595`, 0.936571029772856], 
             UndirectedEdge[126, 318] -> 
             RGBColor[
              0.2179296081019373, 0.3463882140233181, 0.9357221408322174], 
             UndirectedEdge[126, 149] -> 
             RGBColor[
              0.21613019133913786`, 0.3444969129160037, 0.9356196667095744], 
             UndirectedEdge[28, 47] -> 
             RGBColor[
              0.3610905157265072, 0.4852888096589335, 0.9442985989042187], 
             UndirectedEdge[203, 392] -> 
             RGBColor[
              0.26967339396164935`, 0.4007742137073859, 0.9386688728888566], 
             UndirectedEdge[116, 387] -> 
             RGBColor[
              0.35489504602512995`, 0.4804107437728069, 0.9438859559088182], 
             UndirectedEdge[114, 203] -> 
             RGBColor[
              0.3101377282501396, 0.4414434647009515, 0.9410414092716778], 
             UndirectedEdge[38, 207] -> 
             RGBColor[
              0.9528235149386215, 0.8477616286807421, 0.29603526485507003`], 
             UndirectedEdge[4, 73] -> 
             RGBColor[
              0.23765623707057423`, 0.3671221518098715, 0.9368455431690489], 
             UndirectedEdge[143, 223] -> 
             RGBColor[
              0.5393557196395969, 0.6369122967585245, 0.9568792044565808], 
             UndirectedEdge[70, 164] -> 
             RGBColor[
              0.26017432145076, 0.3907900862224582, 0.9381279147619799], 
             UndirectedEdge[291, 331] -> 
             RGBColor[
              0.5742920250264498, 0.6644126452364563, 0.9602056699966387], 
             UndirectedEdge[317, 381] -> 
             RGBColor[
              0.99188704610358, 0.9909130993174948, 0.7841161719227241], 
             UndirectedEdge[120, 349] -> 
             RGBColor[
              0.5058787275831391, 0.6095186078416714, 0.9543033325072602], 
             UndirectedEdge[102, 160] -> 
             RGBColor[
              0.8243873085977117, 0.18845711723458924`, 0.17098662029568146`],
              UndirectedEdge[84, 381] -> 
             RGBColor[
              0.5860370216699882, 0.6484140748343261, 0.8483679973313716], 
             UndirectedEdge[110, 203] -> 
             RGBColor[
              0.2734877597794271, 0.40478335402663146`, 0.9388860953793305], 
             UndirectedEdge[316, 355] -> 
             RGBColor[
              0.2426003366300466, 0.37231871392089444`, 0.937127102324821], 
             UndirectedEdge[62, 77] -> 
             RGBColor[
              0.5042166815429454, 0.5861598549701907, 0.9585479112851663], 
             UndirectedEdge[188, 361] -> 
             RGBColor[
              0.3113562197109362, 0.44025108193646334`, 0.9412013526638779], 
             UndirectedEdge[168, 282] -> 
             RGBColor[
              0.6585061316418895, 0.73314926196139, 0.9665973951785392], 
             UndirectedEdge[271, 394] -> 
             RGBColor[
              0.3328279171819992, 0.4625195049765876, 0.9424351072766638], 
             UndirectedEdge[160, 224] -> 
             RGBColor[
              0.9025695450570996, 0.5785729407895561, 0.26790552836760506`], 
             UndirectedEdge[97, 168] -> 
             RGBColor[
              0.5562174687857758, 0.6498761073301125, 0.9585804738963757], 
             UndirectedEdge[88, 132] -> 
             RGBColor[
              0.8947680641910523, 0.9166701790551881, 0.8954060764061295], 
             UndirectedEdge[329, 353] -> 
             RGBColor[
              0.22275923690238936`, 0.35146446010874544`, 0.9359971810476075],
              UndirectedEdge[189, 339] -> 
             RGBColor[
              0.333153622737486, 0.4622245787566195, 0.942476989061352], 
             UndirectedEdge[316, 380] -> 
             RGBColor[
              0.25988508585516024`, 0.3904860812728869, 0.9381114432226962], 
             UndirectedEdge[156, 295] -> 
             RGBColor[
              0.2141734445733891, 0.3424402480002911, 0.9355082328760125], 
             UndirectedEdge[154, 228] -> 
             RGBColor[
              0.39900760332101687`, 0.520022064116572, 0.9466453895484133], 
             UndirectedEdge[29, 91] -> 
             RGBColor[
              0.25152521102249714`, 0.3816993227770795, 0.9376353607183026], 
             UndirectedEdge[6, 198] -> 
             RGBColor[
              0.9099185860419527, 0.9263319020393368, 0.75030590143584], 
             UndirectedEdge[56, 254] -> 
             RGBColor[
              0.46022321075082034`, 0.5726042579779009, 0.9506674811679487], 
             UndirectedEdge[245, 315] -> 
             RGBColor[
              0.23658653725822024`, 0.3659978294842021, 0.9367846253472143], 
             UndirectedEdge[174, 281] -> 
             RGBColor[
              0.6802997161269625, 0.7500157979571946, 0.9688781332846546], 
             UndirectedEdge[89, 329] -> 
             RGBColor[
              0.22686082544463082`, 0.3557754897223749, 0.9362307604473317], 
             UndirectedEdge[260, 267] -> 
             RGBColor[
              0.6900764896095811, 0.7567221842679797, 0.9704893279445472], 
             UndirectedEdge[202, 363] -> 
             RGBColor[
              0.8594260597663401, 0.4513198993592995, 0.20428679439717456`], 
             UndirectedEdge[43, 238] -> 
             RGBColor[
              0.22832917766795519`, 0.3573188210079969, 0.9363143809342176], 
             UndirectedEdge[276, 377] -> 
             RGBColor[
              0.590222766132432, 0.6752773818608311, 0.9624624311800029], 
             UndirectedEdge[284, 369] -> 
             RGBColor[
              0.25072601947789425`, 0.3808593217920313, 0.9375898479421354], 
             UndirectedEdge[53, 249] -> 
             RGBColor[
              0.279406621010689, 0.4110044524581648, 0.9392231657702803], 
             UndirectedEdge[15, 105] -> 
             RGBColor[
              0.36060251301143975`, 0.486305845826277, 0.9442147886158565], 
             UndirectedEdge[97, 112] -> 
             RGBColor[
              0.38560280932821134`, 0.5084115053045399, 0.9457912479285857], 
             UndirectedEdge[120, 246] -> 
             RGBColor[
              0.505090585435528, 0.6088359587265868, 0.9542531127865411], 
             UndirectedEdge[53, 308] -> 
             RGBColor[
              0.27516616979901054`, 0.4065474693745552, 0.9389816783469607], 
             UndirectedEdge[188, 392] -> 
             RGBColor[
              0.25751756533120074`, 0.38799766709273437`, 0.9379766164312895],
              UndirectedEdge[91, 273] -> 
             RGBColor[
              0.26902930475390907`, 0.40009723511243644`, 0.9386321929613204],
              UndirectedEdge[327, 354] -> 
             RGBColor[
              0.2991827847858058, 0.430880112131681, 0.9403827211333795], 
             UndirectedEdge[51, 376] -> 
             RGBColor[
              0.405658343586251, 0.5257826010583926, 0.9470691688370954], 
             UndirectedEdge[202, 214] -> 
             RGBColor[
              0.9200563597791344, 0.7107376048071281, 0.556968147234525], 
             UndirectedEdge[69, 132] -> 
             RGBColor[
              0.6437204915353074, 0.7192373735289359, 0.9667380893382732], 
             UndirectedEdge[130, 387] -> 
             RGBColor[
              0.35198717062244894`, 0.47789208825307206`, 0.9437006686594926],
              UndirectedEdge[61, 306] -> 
             RGBColor[
              0.9818610097196364, 0.9499548547858537, 0.42826904779571534`], 
             UndirectedEdge[312, 356] -> 
             RGBColor[
              0.4906677898927829, 0.5973852420238213, 0.9530463122771483], 
             UndirectedEdge[18, 247] -> 
             RGBColor[
              0.926107052730001, 0.8138393200274576, 0.6108347292188259], 
             UndirectedEdge[56, 320] -> 
             RGBColor[
              0.5804145257698448, 0.6691464316920486, 0.9608367095033534], 
             UndirectedEdge[43, 124] -> 
             RGBColor[
              0.22535325774935577`, 0.3541909404893282, 0.9361449066973324], 
             UndirectedEdge[259, 318] -> 
             RGBColor[
              0.2174190793227137, 0.34585161590696, 0.9356930669735002], 
             UndirectedEdge[267, 384] -> 
             RGBColor[
              0.6598133920654725, 0.7330804224584619, 0.9674729852060762], 
             UndirectedEdge[44, 324] -> 
             RGBColor[
              0.2889570987994522, 0.4210426101494208, 0.9397670513516847], 
             UndirectedEdge[62, 204] -> 
             RGBColor[
              0.17899762953989296`, 0.30546823612459895`, 0.9335050222478098],
              UndirectedEdge[42, 109] -> 
             RGBColor[
              0.9631611562508396, 0.9703111795583055, 0.8704491819362283], 
             UndirectedEdge[8, 21] -> 
             RGBColor[
              0.3116185481608299, 0.44433005683844234`, 0.9410770362287135], 
             UndirectedEdge[48, 349] -> 
             RGBColor[
              0.43541101780241814`, 0.5515528720515495, 0.9489649829288928], 
             UndirectedEdge[222, 332] -> 
             RGBColor[
              0.5660742539559687, 0.6586036065728093, 0.9589825853511816], 
             UndirectedEdge[58, 167] -> 
             RGBColor[
              0.2911802301180382, 0.4233792621199214, 0.9398936553914501], 
             UndirectedEdge[76, 144] -> 
             RGBColor[
              0.8626912709570241, 0.4513693690163807, 0.2064327327986027], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.44236640792617826`, 0.5377470693075241, 0.9524063925246276], 
             UndirectedEdge[6, 166] -> 
             RGBColor[
              0.9090583234505556, 0.5897855777490221, 0.34432575904947005`], 
             UndirectedEdge[79, 343] -> 
             RGBColor[
              0.6565032648608529, 0.7307948803461315, 0.9669377087053699], 
             UndirectedEdge[142, 257] -> 
             RGBColor[
              0.822095571600614, 0.17084182242934073`, 0.16879205035911396`], 
             UndirectedEdge[175, 256] -> 
             RGBColor[
              0.20212025348377827`, 0.329771579948656, 0.9348218214745575], 
             UndirectedEdge[8, 171] -> 
             RGBColor[
              0.2917662705538139, 0.42384970493064567`, 0.9399323578314926], 
             UndirectedEdge[31, 214] -> 
             RGBColor[
              0.5834952534993698, 0.6486610383850888, 0.9230487158880236], 
             UndirectedEdge[41, 114] -> 
             RGBColor[
              0.3348490984330268, 0.46445119188281303`, 0.9425572663500889], 
             UndirectedEdge[72, 399] -> 
             RGBColor[
              0.23130276285488832`, 0.3604442475756538, 0.9364837222115884], 
             UndirectedEdge[278, 392] -> 
             RGBColor[
              0.2501824179205401, 0.3802879620889227, 0.9375588906376304], 
             UndirectedEdge[6, 323] -> 
             RGBColor[
              0.9117788938600264, 0.9278152609967583, 0.7504833392562442], 
             UndirectedEdge[132, 323] -> 
             RGBColor[
              0.8147163030891271, 0.8552644900665589, 0.9821450311245175], 
             UndirectedEdge[200, 355] -> 
             RGBColor[
              0.2507904105311417, 0.380927000871623, 0.9375935149173598], 
             UndirectedEdge[98, 215] -> 
             RGBColor[
              0.8984291495802124, 0.5426319701729883, 0.2667341084618861], 
             UndirectedEdge[12, 367] -> 
             RGBColor[
              0.21887583976336028`, 0.3473827634940262, 0.9357760273255111], 
             UndirectedEdge[88, 140] -> 
             RGBColor[
              0.8311193811821351, 0.8669473441407145, 0.8890621705145608], 
             UndirectedEdge[195, 327] -> 
             RGBColor[
              0.2821434199050674, 0.41297065928389304`, 0.9394123545109028], 
             UndirectedEdge[142, 381] -> 
             RGBColor[
              0.9073655012701238, 0.5791717949250715, 0.46576856864206445`], 
             UndirectedEdge[313, 359] -> 
             RGBColor[
              0.2641882368664749, 0.39500896582131095`, 0.9383565013068491], 
             UndirectedEdge[64, 82] -> 
             RGBColor[
              0.38908871359710695`, 0.5114308203756144, 0.9460133666661356], 
             UndirectedEdge[98, 297] -> 
             RGBColor[
              0.9621045612745434, 0.9478624391979251, 0.6712874553374975], 
             UndirectedEdge[139, 305] -> 
             RGBColor[
              0.20703664012749182`, 0.3349390140281161, 0.9351018024207747], 
             UndirectedEdge[288, 375] -> 
             RGBColor[
              0.24993566591258726`, 0.38002861008358335`, 0.9375448384758145],
              UndirectedEdge[136, 194] -> 
             RGBColor[
              0.5033185862068833, 0.6058836865205527, 0.954531849750919], 
             UndirectedEdge[254, 349] -> 
             RGBColor[
              0.45744526540329744`, 0.5701981413414695, 0.9504904729468453], 
             UndirectedEdge[348, 351] -> 
             RGBColor[
              0.2543498568494185, 0.38466820463406326`, 0.9377962201194567], 
             UndirectedEdge[65, 282] -> 
             RGBColor[
              0.5810969797016021, 0.6707307553552915, 0.9602123891284602], 
             UndirectedEdge[131, 215] -> 
             RGBColor[
              0.8708771882594211, 0.43978719004972067`, 0.21128818862239418`],
              UndirectedEdge[230, 250] -> 
             RGBColor[
              0.9785422248709081, 0.9480049704007043, 0.5891428358439234], 
             UndirectedEdge[26, 111] -> 
             RGBColor[
              0.6645955027358419, 0.5448101324102603, 0.5834436797495368], 
             UndirectedEdge[301, 390] -> 
             RGBColor[
              0.26155859013835736`, 0.392245040380827, 0.9382067468158966], 
             UndirectedEdge[3, 309] -> 
             RGBColor[
              0.32043505349243634`, 0.4484572206151509, 0.9417673069857059], 
             UndirectedEdge[90, 268] -> 
             RGBColor[
              0.7615624007787926, 0.45211356179516854`, 0.5677648921175946], 
             UndirectedEdge[17, 187] -> 
             RGBColor[
              0.6897252223294911, 0.7560947412907055, 0.9707766661911668], 
             UndirectedEdge[4, 206] -> 
             RGBColor[
              0.23187928370438585`, 0.3610502075420088, 0.9365165542210812], 
             UndirectedEdge[19, 231] -> 
             RGBColor[
              0.2915341164557601, 0.4237512190985569, 0.9399138086948555], 
             UndirectedEdge[76, 138] -> 
             RGBColor[
              0.8331436561867612, 0.2557622418600043, 0.17937170863583543`], 
             UndirectedEdge[28, 390] -> 
             RGBColor[
              0.2772941937947283, 0.40878415751856884`, 0.9391028661653874], 
             UndirectedEdge[123, 174] -> 
             RGBColor[
              0.8514507591880022, 0.8841310051490996, 0.9509891763922267], 
             UndirectedEdge[2, 98] -> 
             RGBColor[
              0.8980106482873484, 0.5394151858476, 0.26633335115120993`], 
             UndirectedEdge[20, 364] -> 
             RGBColor[
              0.37859437323609996`, 0.5023411502157933, 0.945344676578113], 
             UndirectedEdge[56, 196] -> 
             RGBColor[
              0.3744295737159023, 0.4977332530910004, 0.9451159345325955], 
             UndirectedEdge[360, 374] -> 
             RGBColor[
              0.293247724709362, 0.42540017170025574`, 0.9400169674113716], 
             UndirectedEdge[39, 360] -> 
             RGBColor[
              0.29174189371093673`, 0.42381744784571107`, 0.9399312125636886],
              UndirectedEdge[261, 264] -> 
             RGBColor[
              0.1847396920189574, 0.3115035078578844, 0.9338320242113725], 
             UndirectedEdge[101, 253] -> 
             RGBColor[
              0.3012788054166666, 0.43094522374745403`, 0.9405803668258977], 
             UndirectedEdge[141, 273] -> 
             RGBColor[
              0.31775067217972763`, 0.44656178652298995`, 0.9415805292809634],
              UndirectedEdge[171, 182] -> 
             RGBColor[
              0.2806534492526592, 0.41231494799395196`, 0.9392941707941435], 
             UndirectedEdge[156, 175] -> 
             RGBColor[
              0.18244584031582461`, 0.30909252427929373`, 0.9337013927503286],
              UndirectedEdge[121, 250] -> 
             RGBColor[
              0.7707116790518824, 0.8187741201767487, 0.9013688926659322], 
             UndirectedEdge[68, 308] -> 
             RGBColor[
              0.26890650081077455`, 0.39996816038198235`, 0.938625199458431], 
             UndirectedEdge[39, 390] -> 
             RGBColor[
              0.26969566944831447`, 0.40079762665621843`, 0.9386701414448686],
              UndirectedEdge[54, 181] -> 
             RGBColor[
              0.5096518890083631, 0.6127613709392468, 0.9545507619731439], 
             UndirectedEdge[196, 313] -> 
             RGBColor[
              0.2903662346350581, 0.4225237012570149, 0.9398472995528928], 
             UndirectedEdge[200, 241] -> 
             RGBColor[
              0.2808108014657587, 0.41248033514662596`, 0.9393031317698977], 
             UndirectedEdge[186, 255] -> 
             RGBColor[
              0.2544713249858168, 0.38479587534694254`, 0.9378031375501286], 
             UndirectedEdge[11, 38] -> 
             RGBColor[
              0.9446269367354516, 0.8152649274529434, 0.2894401056343812], 
             UndirectedEdge[173, 310] -> 
             RGBColor[
              0.20447288081658893`, 0.33224434044062834`, 0.9349558001207607],
              UndirectedEdge[106, 173] -> 
             RGBColor[
              0.5874312139478495, 0.658182594689114, 0.9541358462016971], 
             UndirectedEdge[51, 396] -> 
             RGBColor[
              0.3256114518738936, 0.4536350211799036, 0.9420717220904409], 
             UndirectedEdge[6, 18] -> 
             RGBColor[
              0.9692770544063248, 0.9734175595259907, 0.7474672305772001], 
             UndirectedEdge[238, 287] -> 
             RGBColor[
              0.24471825055354252`, 0.3745447757379873, 0.9372477143895912], 
             UndirectedEdge[93, 225] -> 
             RGBColor[
              0.25117310830966183`, 0.38132924050128825`, 0.9376153089896959],
              UndirectedEdge[116, 276] -> 
             RGBColor[
              0.5908937430052579, 0.6758585483037947, 0.9625051852330178], 
             UndirectedEdge[135, 276] -> 
             RGBColor[
              0.6344220971523353, 0.7122040883931675, 0.9656535874330512], 
             UndirectedEdge[147, 172] -> 
             RGBColor[
              0.29308124725627194`, 0.4253773516636531, 0.9400019155051696], 
             UndirectedEdge[185, 224] -> 
             RGBColor[
              0.8996759960158076, 0.5563318548969114, 0.2651346625378677], 
             UndirectedEdge[160, 166] -> 
             RGBColor[
              0.8271233428626157, 0.2094874755325008, 0.1736066497976622], 
             UndirectedEdge[63, 156] -> 
             RGBColor[
              0.5722602959769347, 0.592332243346744, 0.6137097186204522], 
             UndirectedEdge[247, 302] -> 
             RGBColor[
              0.9471422868502191, 0.8188837514344283, 0.3245541983516868], 
             UndirectedEdge[81, 240] -> 
             RGBColor[
              0.22946097871463872`, 0.3585084156683923, 0.9363788353294766], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.3163910437219365, 0.4480120932607672, 0.9413976728873965], 
             UndirectedEdge[12, 212] -> 
             RGBColor[
              0.2146670795751315, 0.34295908968538924`, 0.9355363446590942], 
             UndirectedEdge[18, 74] -> 
             RGBColor[
              0.8849400211257357, 0.9108459941170431, 0.9803872287207334], 
             UndirectedEdge[1, 7] -> 
             RGBColor[
              0.37469401379728373`, 0.4989628549076562, 0.945096149123624], 
             UndirectedEdge[231, 331] -> 
             RGBColor[
              0.38038829696430865`, 0.5038892359163952, 0.9454591932807552], 
             UndirectedEdge[58, 351] -> 
             RGBColor[
              0.27227774194596055`, 0.4035115485640963, 0.9388171866537756], 
             UndirectedEdge[142, 279] -> 
             RGBColor[
              0.8836168067234831, 0.49456770966954106`, 0.2217143859275474], 
             UndirectedEdge[303, 344] -> 
             RGBColor[
              0.3051201948561256, 0.4369324167818024, 0.9407277420647475], 
             UndirectedEdge[302, 323] -> 
             RGBColor[
              0.9087436394185031, 0.9180978599174181, 0.6943707488073377], 
             UndirectedEdge[144, 366] -> 
             RGBColor[
              0.8898592758254438, 0.5927585201905767, 0.22980821876360358`], 
             UndirectedEdge[56, 342] -> 
             RGBColor[
              0.5271466154555224, 0.626935692782203, 0.9559359367348119], 
             UndirectedEdge[137, 293] -> 
             RGBColor[
              0.2163935789679292, 0.34477375001360355`, 0.9356346662453872], 
             UndirectedEdge[39, 374] -> 
             RGBColor[
              0.2745978955714905, 0.40595017713076464`, 0.9389493159703898], 
             UndirectedEdge[4, 278] -> 
             RGBColor[
              0.24230606056995913`, 0.37200941112356267`, 0.9371103437385414],
              UndirectedEdge[238, 396] -> 
             RGBColor[
              0.25376131131834845`, 0.3840496059649667, 0.9377627033221374], 
             UndirectedEdge[118, 293] -> 
             RGBColor[
              0.20864634306607288`, 0.33663091387762584`, 0.9351934726217848],
              UndirectedEdge[201, 228] -> 
             RGBColor[
              0.3221417320475673, 0.45045653149250003`, 0.9418569760468667], 
             UndirectedEdge[212, 336] -> 
             RGBColor[
              0.21095186783418274`, 0.3390541665876225, 0.9353247688466104], 
             UndirectedEdge[186, 200] -> 
             RGBColor[
              0.2595636633022175, 0.3901482457903771, 0.9380931386838082], 
             UndirectedEdge[7, 356] -> 
             RGBColor[
              0.4538916995859768, 0.5657933672154302, 0.9506306565950378], 
             UndirectedEdge[215, 269] -> 
             RGBColor[
              0.9061735630089964, 0.5684125935804545, 0.32599457253607145`], 
             UndirectedEdge[36, 122] -> 
             RGBColor[
              0.4828824410191481, 0.5908684223901826, 0.952487665639901], 
             UndirectedEdge[297, 352] -> 
             RGBColor[
              0.970396577990795, 0.974814330666099, 0.7901511578367646], 
             UndirectedEdge[228, 243] -> 
             RGBColor[
              0.3281145647549416, 0.45673435736741674`, 0.9421971200335375], 
             UndirectedEdge[100, 271] -> 
             RGBColor[
              0.3417009842764249, 0.4702049097204598, 0.9430004912657755], 
             UndirectedEdge[157, 298] -> 
             RGBColor[
              0.6463369873520685, 0.7210185843298552, 0.9671902179184984], 
             UndirectedEdge[272, 384] -> 
             RGBColor[
              0.6977223834801167, 0.763785295951966, 0.9705061046650639], 
             UndirectedEdge[35, 114] -> 
             RGBColor[
              0.30495946572485455`, 0.43600078246607, 0.9407465148814157], 
             UndirectedEdge[15, 155] -> 
             RGBColor[
              0.30420326810120896`, 0.4370673007485326, 0.9406352981387334], 
             UndirectedEdge[36, 262] -> 
             RGBColor[
              0.7291600782306236, 0.787348496129779, 0.9720379295278863], 
             UndirectedEdge[111, 185] -> 
             RGBColor[
              0.8488843177529799, 0.35210056877181173`, 0.19347970101943163`],
              UndirectedEdge[26, 400] -> 
             RGBColor[
              0.4223618806328297, 0.5402016308185901, 0.9481469689308566], 
             UndirectedEdge[61, 131] -> 
             RGBColor[
              0.9579060415796807, 0.8592435772757068, 0.3867967672286041], 
             UndirectedEdge[168, 350] -> 
             RGBColor[
              0.5514466203488134, 0.6457438382038303, 0.9582764796526682], 
             UndirectedEdge[16, 208] -> 
             RGBColor[
              0.2374736143413805, 0.36693020374253915`, 0.9368351430747874], 
             UndirectedEdge[125, 303] -> 
             RGBColor[
              0.28379884955745593`, 0.41562096314419106`, 0.9394732966882988],
              UndirectedEdge[145, 164] -> 
             RGBColor[
              0.2402812832877892, 0.36988124182170756`, 0.9369950356677115], 
             UndirectedEdge[152, 256] -> 
             RGBColor[
              0.2044622657846265, 0.33223318336900387`, 0.9349551956103941], 
             UndirectedEdge[237, 246] -> 
             RGBColor[
              0.5111109439056949, 0.6137235569467266, 0.9547270574586124], 
             UndirectedEdge[16, 284] -> 
             RGBColor[
              0.24292930031788273`, 0.3726644756143127, 0.9371458363201851], 
             UndirectedEdge[240, 309] -> 
             RGBColor[
              0.2549984797573888, 0.3853499484354077, 0.9378331582345141], 
             UndirectedEdge[151, 249] -> 
             RGBColor[
              0.2927023996318287, 0.42432368443317114`, 0.9400043408205379], 
             UndirectedEdge[47, 311] -> 
             RGBColor[
              0.47663297852550124`, 0.5854636862286419, 0.9520871802976505], 
             UndirectedEdge[29, 190] -> 
             RGBColor[
              0.2407660977459846, 0.370390812556283, 0.937022645133887], 
             UndirectedEdge[99, 384] -> 
             RGBColor[
              0.863277719993484, 0.893302482160574, 0.9487341980321153], 
             UndirectedEdge[5, 398] -> 
             RGBColor[
              0.8904342144946242, 0.9153759950567726, 0.9860799767962038], 
             UndirectedEdge[36, 157] -> 
             RGBColor[
              0.49446056893751156`, 0.6004643909150807, 0.9533448937369567], 
             UndirectedEdge[40, 55] -> 
             RGBColor[
              0.37142239221905604`, 0.496129140733077, 0.9448876842896408], 
             UndirectedEdge[163, 319] -> 
             RGBColor[
              0.2432784612852803, 0.3730314659291315, 0.9371657205207411], 
             UndirectedEdge[13, 74] -> 
             RGBColor[
              0.8942268027978797, 0.9177720606824189, 0.9646671297303714], 
             UndirectedEdge[47, 158] -> 
             RGBColor[
              0.468503909528975, 0.5788641418068768, 0.9514472302084831], 
             UndirectedEdge[252, 330] -> 
             RGBColor[
              0.2245525377985933, 0.3533493330524997, 0.9360993068806954], 
             UndirectedEdge[102, 185] -> 
             RGBColor[
              0.8214937595564198, 0.16621603134194454`, 0.16821575446594406`],
              UndirectedEdge[41, 356] -> 
             RGBColor[
              0.4295993605310475, 0.5447525640945126, 0.9490827702313296], 
             UndirectedEdge[33, 175] -> 
             RGBColor[
              0.17893676407552545`, 0.30540426266245535`, 0.9335015560496566],
              UndirectedEdge[12, 126] -> 
             RGBColor[
              0.2152393660615204, 0.3435605990676429, 0.935568935527872], 
             UndirectedEdge[18, 191] -> 
             RGBColor[
              0.8120299641162554, 0.853850200152278, 0.9731302939895274], 
             UndirectedEdge[64, 171] -> 
             RGBColor[
              0.3360864294513485, 0.46223759897173367`, 0.9427563991656658], 
             UndirectedEdge[73, 184] -> 
             RGBColor[
              0.230439447723778, 0.35953684863551605`, 0.9364345576920319], 
             UndirectedEdge[93, 316] -> 
             RGBColor[
              0.2497588091651779, 0.37984272242869066`, 0.9375347667456857], 
             UndirectedEdge[20, 362] -> 
             RGBColor[
              0.406159003588231, 0.5262162475882044, 0.9471010704497052], 
             UndirectedEdge[32, 330] -> 
             RGBColor[
              0.2205286799485376, 0.349120003324768, 0.935870154128899], 
             UndirectedEdge[124, 277] -> 
             RGBColor[
              0.24054204876353127`, 0.3701553228701986, 0.9370098858757869], 
             UndirectedEdge[267, 331] -> 
             RGBColor[
              0.511645707636986, 0.6143827846807824, 0.9547069650679356], 
             UndirectedEdge[134, 167] -> 
             RGBColor[
              0.25893816716997997`, 0.3894908096966502, 0.9380575176044159], 
             UndirectedEdge[143, 398] -> 
             RGBColor[
              0.7820348247548993, 0.8302487551810782, 0.97550730112162], 
             UndirectedEdge[109, 320] -> 
             RGBColor[
              0.8519952349988198, 0.8825603077930796, 0.8596099472355513], 
             UndirectedEdge[28, 147] -> 
             RGBColor[
              0.2865134731880893, 0.418474204697066, 0.9396278904881377], 
             UndirectedEdge[54, 311] -> 
             RGBColor[
              0.48568276233296276`, 0.5933021541073054, 0.9526638245194523], 
             UndirectedEdge[160, 289] -> 
             RGBColor[
              0.863615444991354, 0.42809333252077686`, 0.20612813226240806`], 
             UndirectedEdge[209, 240] -> 
             RGBColor[
              0.24561974977362988`, 0.37549230857665095`, 0.9372990534365266],
              UndirectedEdge[31, 261] -> 
             RGBColor[
              0.18133289143212553`, 0.3079227444374911, 0.9336380119578622], 
             UndirectedEdge[245, 248] -> 
             RGBColor[
              0.2230533686520324, 0.3517736112266503, 0.9360139314156208], 
             UndirectedEdge[81, 245] -> 
             RGBColor[
              0.22480714766170556`, 0.3536169441618284, 0.9361138065357382], 
             UndirectedEdge[308, 386] -> 
             RGBColor[
              0.30022575986843436`, 0.4300559235597101, 0.9405124330603728], 
             UndirectedEdge[320, 349] -> 
             RGBColor[
              0.5776365804223218, 0.666740315055617, 0.9606597012822499], 
             UndirectedEdge[222, 356] -> 
             RGBColor[
              0.5616526527416191, 0.6550139515161355, 0.9586345007067291], 
             UndirectedEdge[200, 374] -> 
             RGBColor[
              0.27338169058223005`, 0.4046718685752019, 0.9388800548954654], 
             UndirectedEdge[73, 348] -> 
             RGBColor[
              0.2530355996274438, 0.3832868369650472, 0.9377213751149346], 
             UndirectedEdge[23, 81] -> 
             RGBColor[
              0.2165666874460731, 0.34495569799984427`, 0.9356445245171263], 
             UndirectedEdge[25, 233] -> 
             RGBColor[
              0.8330846738019452, 0.25530887740406205`, 0.17931522703752448`],
              UndirectedEdge[168, 170] -> 
             RGBColor[
              0.5575600626847299, 0.651038994684655, 0.958666022792408], 
             UndirectedEdge[73, 284] -> 
             RGBColor[
              0.24355703331110456`, 0.3733242627907594, 0.9371815847855014], 
             UndirectedEdge[143, 234] -> 
             RGBColor[
              0.4816918202752083, 0.5869870677287701, 0.9531992911334777], 
             UndirectedEdge[288, 374] -> 
             RGBColor[
              0.26056485892169184`, 0.3912005658659134, 0.9381501552932011], 
             UndirectedEdge[254, 344] -> 
             RGBColor[
              0.39507001975859724`, 0.5161718386350326, 0.946515977450629], 
             UndirectedEdge[6, 102] -> 
             RGBColor[
              0.9063222891856516, 0.5687552194511105, 0.3417057295474893], 
             UndirectedEdge[205, 276] -> 
             RGBColor[
              0.8804173286055655, 0.9045483902483498, 0.8526723312886473], 
             UndirectedEdge[101, 244] -> 
             RGBColor[
              0.2604390037563816, 0.39106828410749395`, 0.9381429880277227], 
             UndirectedEdge[58, 80] -> 
             RGBColor[
              0.31661369550810525`, 0.44773804311104304`, 0.9414289555561544],
              UndirectedEdge[23, 292] -> 
             RGBColor[
              0.21221830344661968`, 0.3403852707129492, 0.9353968904812151], 
             UndirectedEdge[101, 397] -> 
             RGBColor[
              0.2550956906132599, 0.3854521232084524, 0.9378386942489454], 
             UndirectedEdge[105, 168] -> 
             RGBColor[
              0.5437472998304071, 0.6390750737498879, 0.957785885757477], 
             UndirectedEdge[166, 340] -> 
             RGBColor[
              0.9092736160962124, 0.5902460669486567, 0.36775903489702405`], 
             UndirectedEdge[138, 317] -> 
             RGBColor[
              0.9049849697863369, 0.5700377324760639, 0.4855767081666582], 
             UndirectedEdge[71, 120] -> 
             RGBColor[
              0.7187491637803132, 0.7794609626924269, 0.9732879603430942], 
             UndirectedEdge[231, 290] -> 
             RGBColor[
              0.3569089205700484, 0.48355258019145775`, 0.9439631081789103], 
             UndirectedEdge[13, 224] -> 
             RGBColor[
              0.9697208187554422, 0.9510352770851425, 0.6530724790472836], 
             UndirectedEdge[40, 159] -> 
             RGBColor[
              0.33537336280871854`, 0.46490528333474357`, 0.9425906720125191],
              UndirectedEdge[20, 265] -> 
             RGBColor[
              0.49977683892029745`, 0.6035406289522859, 0.9541059564454999], 
             UndirectedEdge[43, 299] -> 
             RGBColor[
              0.22078197517346282`, 0.34938623266600927`, 0.9358845789172419],
              UndirectedEdge[219, 220] -> 
             RGBColor[
              0.4613111794873067, 0.5733857750910603, 0.9507812424766675], 
             UndirectedEdge[56, 290] -> 
             RGBColor[
              0.42803437429076585`, 0.5451635942026395, 0.9484949497272399], 
             UndirectedEdge[64, 157] -> 
             RGBColor[
              0.43410205704708005`, 0.5499866920911975, 0.9490010571312653], 
             UndirectedEdge[13, 340] -> 
             RGBColor[
              0.9787791287241259, 0.9808041152910011, 0.7551804074343922], 
             UndirectedEdge[16, 188] -> 
             RGBColor[
              0.25447321455412675`, 0.38479786140304184`, 0.9378032451582485],
              UndirectedEdge[171, 308] -> 
             RGBColor[
              0.26715048285961845`, 0.3981224741773486, 0.9385251968339084], 
             UndirectedEdge[288, 379] -> 
             RGBColor[
              0.23299167582952007`, 0.3622194021952592, 0.9365799033069708], 
             UndirectedEdge[81, 353] -> 
             RGBColor[
              0.2150475477536689, 0.34335898586410785`, 0.9355580117590097], 
             UndirectedEdge[153, 188] -> 
             RGBColor[
              0.2922583395910017, 0.4237094580639409, 0.939984452630228], 
             UndirectedEdge[148, 356] -> 
             RGBColor[
              0.5711332147381206, 0.6627106988393463, 0.9593808452755366], 
             UndirectedEdge[198, 247] -> 
             RGBColor[
              0.866748584365629, 0.7667536625408037, 0.6136734000774657], 
             UndirectedEdge[94, 375] -> 
             RGBColor[
              0.25748465436672835`, 0.3879630755823982, 0.9379747422005502], 
             UndirectedEdge[298, 307] -> 
             RGBColor[
              0.9043350538106595, 0.9251046086494896, 0.9386480207606034], 
             UndirectedEdge[9, 142] -> 
             RGBColor[
              0.8236257057163587, 0.18260310375199956`, 0.1702573085163904], 
             UndirectedEdge[203, 284] -> 
             RGBColor[
              0.26769783285159876`, 0.3986977737229138, 0.93855636760622], 
             UndirectedEdge[370, 400] -> 
             RGBColor[
              0.6104137657145253, 0.6900683539569277, 0.9649050090474223], 
             UndirectedEdge[63, 381] -> 
             RGBColor[
              0.975854040924288, 0.9316564884007599, 0.528376469194335], 
             UndirectedEdge[222, 251] -> 
             RGBColor[
              0.7136213718875605, 0.7756511419302459, 0.9724778106511085], 
             UndirectedEdge[103, 234] -> 
             RGBColor[
              0.34165277525472826`, 0.4703441947830308, 0.9429907906209125], 
             UndirectedEdge[150, 399] -> 
             RGBColor[
              0.2527398969113101, 0.3829760346617555, 0.9377045352827038], 
             UndirectedEdge[321, 338] -> 
             RGBColor[
              0.9060374188254435, 0.923886001186349, 0.8010879565228419], 
             UndirectedEdge[154, 203] -> 
             RGBColor[
              0.36077780249875213`, 0.4853053517709617, 0.9442681500235399], 
             UndirectedEdge[225, 390] -> 
             RGBColor[
              0.26170368970244295`, 0.3923975492225247, 0.9382150100214157], 
             UndirectedEdge[54, 121] -> 
             RGBColor[
              0.502593813473784, 0.607031307257596, 0.9539951244124792], 
             UndirectedEdge[234, 346] -> 
             RGBColor[
              0.34188570275875485`, 0.4705459448797419, 0.9430056325554994], 
             UndirectedEdge[358, 391] -> 
             RGBColor[
              0.8944837314108928, 0.5317010026573729, 0.24979314294089291`], 
             UndirectedEdge[74, 357] -> 
             RGBColor[
              0.7501817896070486, 0.8048048860165811, 0.9757247096384958], 
             UndirectedEdge[130, 364] -> 
             RGBColor[
              0.379967678176128, 0.5035306379305324, 0.9454321823545258], 
             UndirectedEdge[202, 381] -> 
             RGBColor[
              0.9247433274483484, 0.7127453819428937, 0.4824095946157798], 
             UndirectedEdge[98, 307] -> 
             RGBColor[
              0.9814050384421338, 0.9620825967866911, 0.6308199289588313], 
             UndirectedEdge[242, 317] -> 
             RGBColor[
              0.954486951543472, 0.8521857620679489, 0.5290777523178287], 
             UndirectedEdge[9, 279] -> 
             RGBColor[
              0.8856585389447988, 0.5102613582153388, 0.22366955100848618`], 
             UndirectedEdge[200, 399] -> 
             RGBColor[
              0.2527693356026074, 0.3830069765928298, 0.9377062117726225], 
             UndirectedEdge[275, 306] -> 
             RGBColor[
              0.9812383782660234, 0.9513676250265612, 0.559996794380909], 
             UndirectedEdge[121, 181] -> 
             RGBColor[
              0.5602542166801026, 0.6538786381225696, 0.9585244106973264], 
             UndirectedEdge[239, 271] -> 
             RGBColor[
              0.31565140111640955`, 0.4476420700773734, 0.9413406348615612], 
             UndirectedEdge[35, 354] -> 
             RGBColor[
              0.2804072432672092, 0.41205616989288285`, 0.9392801497275012], 
             UndirectedEdge[31, 310] -> 
             RGBColor[
              0.18289778193115996`, 0.30956754357176464`, 0.9337271301567341],
              UndirectedEdge[146, 154] -> 
             RGBColor[
              0.48274463326921224`, 0.5903240190384458, 0.9525963248033308], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.8938562482651202, 0.6317789737296462, 0.5786286100973383], 
             UndirectedEdge[265, 322] -> 
             RGBColor[
              0.5501554119867256, 0.6456799735265193, 0.9577293957987232], 
             UndirectedEdge[115, 284] -> 
             RGBColor[
              0.24130209476909242`, 0.37095417941174347`, 0.9370531693714164],
              UndirectedEdge[38, 391] -> 
             RGBColor[
              0.8930910009287811, 0.5270029957125417, 0.24438264801297166`], 
             UndirectedEdge[116, 328] -> 
             RGBColor[
              0.3628292631493686, 0.48868620423613895`, 0.944340137703926], 
             UndirectedEdge[92, 278] -> 
             RGBColor[
              0.2700397327532974, 0.4011592590046289, 0.9386897353410912], 
             UndirectedEdge[215, 217] -> 
             RGBColor[
              0.8210569332669986, 0.16285839306295227`, 0.16779744911786956`],
              UndirectedEdge[159, 210] -> 
             RGBColor[
              0.3156791522092831, 0.44703146697688845`, 0.9413656404050212], 
             UndirectedEdge[165, 298] -> 
             RGBColor[
              0.6780894534855002, 0.7467966667692734, 0.969689888365638], 
             UndirectedEdge[83, 254] -> 
             RGBColor[
              0.4111965295816905, 0.5301398109018447, 0.9475435443964437], 
             UndirectedEdge[103, 231] -> 
             RGBColor[
              0.3266251404157554, 0.4573222919288569, 0.942033452486374], 
             UndirectedEdge[245, 319] -> 
             RGBColor[
              0.2357412606353747, 0.36510939015995814`, 0.9367364880940181], 
             UndirectedEdge[58, 263] -> 
             RGBColor[
              0.28044730154374703`, 0.41209827368136553`, 0.9392824309870891],
              UndirectedEdge[206, 258] -> 
             RGBColor[
              0.24224766571092132`, 0.37194803442426605`, 0.9371070182377067],
              UndirectedEdge[213, 391] -> 
             RGBColor[
              0.8656794520004861, 0.4212316977913123, 0.20719030408487465`], 
             UndirectedEdge[78, 370] -> 
             RGBColor[
              0.8365302867115927, 0.5954450493775967, 0.5857332485541368], 
             UndirectedEdge[101, 270] -> 
             RGBColor[
              0.2552144898783262, 0.38557698876834556`, 0.937845459691343], 
             UndirectedEdge[135, 377] -> 
             RGBColor[
              0.4590787183907463, 0.5706961122538062, 0.9508478818462491], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.22879801729426974`, 0.3578116011814027, 0.9363410806573501], 
             UndirectedEdge[19, 83] -> 
             RGBColor[
              0.31363288900734776`, 0.44289778603368235`, 0.9413217134716801],
              UndirectedEdge[100, 112] -> 
             RGBColor[
              0.35276762831000186`, 0.47997132185075075`, 0.9436990192291159],
              UndirectedEdge[10, 296] -> 
             RGBColor[
              0.331723708667086, 0.46107618573568054`, 0.9423825762220581], 
             UndirectedEdge[85, 369] -> 
             RGBColor[
              0.24938070758750824`, 0.3794453136975352, 0.9375132344201885], 
             UndirectedEdge[79, 246] -> 
             RGBColor[
              0.5173044068287108, 0.618751689159956, 0.9552146295473145], 
             UndirectedEdge[227, 280] -> 
             RGBColor[
              0.23696761026347307`, 0.36639836137414694`, 0.9368063268911165],
              UndirectedEdge[112, 326] -> 
             RGBColor[
              0.3341557033790634, 0.4638506079381187, 0.9425130838303954], 
             UndirectedEdge[34, 308] -> 
             RGBColor[
              0.2866886948098787, 0.4183307981986623, 0.9396498632451982], 
             UndirectedEdge[29, 226] -> 
             RGBColor[
              0.23953161826969796`, 0.36909329635618626`, 0.936952343353961], 
             UndirectedEdge[204, 345] -> 
             RGBColor[
              0.1904371972329284, 0.3174919470804629, 0.9341564887046044], 
             UndirectedEdge[54, 265] -> 
             RGBColor[
              0.5219430916057815, 0.622739922920198, 0.9555183704657713], 
             UndirectedEdge[22, 100] -> 
             RGBColor[
              0.3344662411106874, 0.46260073594405915`, 0.9425884833453301], 
             UndirectedEdge[126, 336] -> 
             RGBColor[
              0.21152415432057162`, 0.33965567596987617`, 0.9353573597153882],
              UndirectedEdge[82, 157] -> 
             RGBColor[
              0.4242304983845992, 0.5414364441367214, 0.9483720501423687], 
             UndirectedEdge[344, 349] -> 
             RGBColor[
              0.3830038950089686, 0.5061604563464437, 0.9456256474062932], 
             UndirectedEdge[343, 349] -> 
             RGBColor[
              0.5837898565381997, 0.6715473011239714, 0.9612730023398459], 
             UndirectedEdge[2, 66] -> 
             RGBColor[
              0.8956170407292666, 0.531340985508409, 0.2570346377829214], 
             UndirectedEdge[211, 387] -> 
             RGBColor[
              0.27812297420375887`, 0.4096552582761729, 0.939150063983611], 
             UndirectedEdge[250, 265] -> 
             RGBColor[
              0.7900609571838799, 0.8344827358393506, 0.9028921387192244], 
             UndirectedEdge[217, 306] -> 
             RGBColor[
              0.8966008926384637, 0.5440937493586522, 0.25445421300955695`], 
             UndirectedEdge[374, 375] -> 
             RGBColor[
              0.26547453356081113`, 0.3963609452029792, 0.9384297540006862], 
             UndirectedEdge[38, 247] -> 
             RGBColor[
              0.9363993756149239, 0.7826453892822661, 0.2828200168311238], 
             UndirectedEdge[204, 310] -> 
             RGBColor[
              0.18075257528517846`, 0.3073127953728809, 0.9336049638117943], 
             UndirectedEdge[226, 266] -> 
             RGBColor[
              0.24681597923856835`, 0.37674962158963, 0.9373671769348919], 
             UndirectedEdge[319, 334] -> 
             RGBColor[
              0.25149135479282314`, 0.3816637377330832, 0.9376334326561084], 
             UndirectedEdge[73, 206] -> 
             RGBColor[
              0.23733902327111464`, 0.366788739994123, 0.9368274783124455], 
             UndirectedEdge[200, 255] -> 
             RGBColor[
              0.26556731627814384`, 0.3964584657216599, 0.9384350378391786], 
             UndirectedEdge[296, 383] -> 
             RGBColor[
              0.2908789334455868, 0.4230625802138626, 0.9398764969916824], 
             UndirectedEdge[235, 281] -> 
             RGBColor[
              0.6860438629162344, 0.7545031690861064, 0.9694506561545053], 
             UndirectedEdge[174, 272] -> 
             RGBColor[
              0.6878111560407678, 0.756042569748228, 0.9695182461395961], 
             UndirectedEdge[9, 131] -> 
             RGBColor[
              0.8740668087143025, 0.4643040105665355, 0.21434257277214977`], 
             UndirectedEdge[228, 361] -> 
             RGBColor[
              0.3617418491636495, 0.4877443408967252, 0.9442708486463184], 
             UndirectedEdge[149, 199] -> 
             RGBColor[
              0.2230106997449548, 0.3517287634999468, 0.9360115014844858], 
             UndirectedEdge[102, 400] -> 
             RGBColor[
              0.6044539714967849, 0.33060708272811645`, 0.5560794046708185], 
             UndirectedEdge[45, 350] -> 
             RGBColor[
              0.36412092231360993`, 0.48858020750687353`, 0.9444672858023867],
              UndirectedEdge[369, 392] -> 
             RGBColor[
              0.2527015805879449, 0.38293576177650346`, 0.937702353224772], 
             UndirectedEdge[82, 151] -> 
             RGBColor[
              0.34752633634939933`, 0.4754315781894705, 0.9433650487400788], 
             UndirectedEdge[260, 342] -> 
             RGBColor[
              0.706156116764429, 0.7697763499712335, 0.9717551750957918], 
             UndirectedEdge[296, 380] -> 
             RGBColor[
              0.28350610283773925`, 0.41531326778055483`, 0.939456625195691], 
             UndirectedEdge[105, 148] -> 
             RGBColor[
              0.520616067080279, 0.620721827134755, 0.9556738363326167], 
             UndirectedEdge[94, 288] -> 
             RGBColor[
              0.25257497972760906`, 0.38280269624533236`, 0.9376951434930652],
              UndirectedEdge[195, 258] -> 
             RGBColor[
              0.24931398381106837`, 0.3793751827779651, 0.9375094345998292], 
             UndirectedEdge[339, 374] -> 
             RGBColor[
              0.3209321143289635, 0.44937899853087393`, 0.9417809922375882], 
             UndirectedEdge[199, 367] -> 
             RGBColor[
              0.2225587298907346, 0.35125371452661747`, 0.9359857624699174], 
             UndirectedEdge[36, 298] -> 
             RGBColor[
              0.6715537144550077, 0.7414906593926315, 0.9691753710479567], 
             UndirectedEdge[147, 347] -> 
             RGBColor[
              0.28239395908436904`, 0.4141443341817761, 0.9393932902542057], 
             UndirectedEdge[38, 205] -> 
             RGBColor[
              0.9805298619657696, 0.9442896440229023, 0.524841136015259], 
             UndirectedEdge[16, 73] -> 
             RGBColor[
              0.24248824364408117`, 0.372200897085539, 0.937120718795097], 
             UndirectedEdge[108, 290] -> 
             RGBColor[
              0.3863513979794556, 0.5090598951690881, 0.945838947335492], 
             UndirectedEdge[225, 296] -> 
             RGBColor[
              0.2793148229194171, 0.41090796684390285`, 0.9392179380047856], 
             UndirectedEdge[24, 144] -> 
             RGBColor[
              0.8902955651891483, 0.5947396082931894, 0.23017226930310958`], 
             UndirectedEdge[209, 319] -> 
             RGBColor[
              0.24680833108244982`, 0.37674158289262827`, 0.9373667413837155],
              UndirectedEdge[80, 192] -> 
             RGBColor[
              0.3394530711598287, 0.46843892165637124`, 0.9428506274211075], 
             UndirectedEdge[42, 221] -> 
             RGBColor[
              0.9270423893059134, 0.944662453609973, 0.9929033247441504], 
             UndirectedEdge[22, 365] -> 
             RGBColor[
              0.27427955709376345`, 0.40561558320684826`, 0.9389311870650228],
              UndirectedEdge[80, 201] -> 
             RGBColor[
              0.30542134246892777`, 0.4359741704306982, 0.9407915676081757], 
             UndirectedEdge[39, 375] -> 
             RGBColor[
              0.2639687025623859, 0.39477822134843454`, 0.9383439991530031], 
             UndirectedEdge[15, 326] -> 
             RGBColor[
              0.3216255760176605, 0.45254598204008034`, 0.9417312126565649], 
             UndirectedEdge[86, 95] -> 
             RGBColor[
              0.2911574427094625, 0.42335531110870317`, 0.9398923576822427], 
             UndirectedEdge[59, 194] -> 
             RGBColor[
              0.3610366257463029, 0.4871335118181791, 0.9442259124337696], 
             UndirectedEdge[296, 324] -> 
             RGBColor[
              0.2907395975741168, 0.42291612937854317`, 0.9398685620199312], 
             UndirectedEdge[169, 245] -> 
             RGBColor[
              0.22529865841710267`, 0.3541335531293326, 0.936141797346133], 
             UndirectedEdge[258, 284] -> 
             RGBColor[
              0.24846567575091127`, 0.3784835572209025, 0.9374611247107626], 
             UndirectedEdge[33, 152] -> 
             RGBColor[
              0.18127877637637368`, 0.30786586608280325`, 0.9336349301854932],
              UndirectedEdge[246, 349] -> 
             RGBColor[
              0.44459099850605766`, 0.559504109937796, 0.9495499231817904], 
             UndirectedEdge[27, 395] -> 
             RGBColor[
              0.28524240829505776`, 0.41713823490432095`, 0.9395555052228516],
              UndirectedEdge[185, 340] -> 
             RGBColor[
              0.9087343059844912, 0.5861006931027701, 0.36724259092497624`], 
             UndirectedEdge[223, 321] -> 
             RGBColor[
              0.6359268279774656, 0.7126257479828174, 0.9663189746381065], 
             UndirectedEdge[274, 373] -> 
             RGBColor[
              0.24052488712014738`, 0.3701372848948911, 0.9370089085455846], 
             UndirectedEdge[156, 214] -> 
             RGBColor[
              0.5848663164286375, 0.6501021124541597, 0.9231267958935396], 
             UndirectedEdge[205, 221] -> 
             RGBColor[
              0.9585637141169614, 0.9664203575638242, 0.8602427231177231], 
             UndirectedEdge[97, 105] -> 
             RGBColor[
              0.42981427861771465`, 0.5467052578700499, 0.9486083636570456], 
             UndirectedEdge[130, 158] -> 
             RGBColor[
              0.4567607455909806, 0.5686928034323673, 0.9506989661864262], 
             UndirectedEdge[108, 143] -> 
             RGBColor[
              0.49610666284564264`, 0.5994724798522266, 0.954117792155521], 
             UndirectedEdge[176, 399] -> 
             RGBColor[
              0.22535125221155355`, 0.3541888325419396, 0.9361447924849214], 
             UndirectedEdge[150, 189] -> 
             RGBColor[
              0.28557376029945525`, 0.4174865068698732, 0.9395743752293106], 
             UndirectedEdge[253, 386] -> 
             RGBColor[
              0.3405394596215219, 0.4693798967384182, 0.942919851133231], 
             UndirectedEdge[46, 59] -> 
             RGBColor[
              0.30916725287120805`, 0.4399481765928165, 0.9410035436196971], 
             UndirectedEdge[186, 241] -> 
             RGBColor[
              0.2697148101734317, 0.4008177447719086, 0.9386712314808479], 
             UndirectedEdge[39, 93] -> 
             RGBColor[
              0.2591650880555334, 0.38972931793498194`, 0.9380704404131488], 
             UndirectedEdge[214, 264] -> 
             RGBColor[
              0.5869020540862017, 0.6522418018054821, 0.9232427281415339], 
             UndirectedEdge[234, 290] -> 
             RGBColor[
              0.37193655540902126`, 0.4965744830456317, 0.9449204463134487], 
             UndirectedEdge[148, 170] -> 
             RGBColor[
              0.5344288299346016, 0.632685748069522, 0.9565539733675475], 
             UndirectedEdge[50, 362] -> 
             RGBColor[
              0.4294033294821849, 0.5463267879239184, 0.948588402469489], 
             UndirectedEdge[271, 326] -> 
             RGBColor[
              0.3230890593454866, 0.4540841958078278, 0.941814555867055], 
             UndirectedEdge[61, 352] -> 
             RGBColor[
              0.9937500196167237, 0.9890402488671484, 0.5611063895673631], 
             UndirectedEdge[256, 333] -> 
             RGBColor[
              0.21043441051870343`, 0.338510286140365, 0.9352953004180034], 
             UndirectedEdge[100, 394] -> 
             RGBColor[
              0.3677410184422385, 0.49294051979882375`, 0.944653110407893], 
             UndirectedEdge[1, 114] -> 
             RGBColor[
              0.3444304570913155, 0.4727500831795342, 0.9431677820513322], 
             UndirectedEdge[218, 269] -> 
             RGBColor[
              0.9515613514707596, 0.9593431212476458, 0.7385846645144882], 
             UndirectedEdge[182, 253] -> 
             RGBColor[
              0.31490504522225604`, 0.4452672657366318, 0.9413563610246107], 
             UndirectedEdge[57, 354] -> 
             RGBColor[
              0.27649042962059545`, 0.4079393504099632, 0.939057092984733], 
             UndirectedEdge[40, 192] -> 
             RGBColor[
              0.34190093761815415`, 0.4705591405492272, 0.9430066033072686], 
             UndirectedEdge[262, 314] -> 
             RGBColor[
              0.9322274207027686, 0.9487209428474576, 0.9907658897447179], 
             UndirectedEdge[244, 253] -> 
             RGBColor[
              0.30087597692201773`, 0.4305218254587764, 0.9405574263390588], 
             UndirectedEdge[277, 330] -> 
             RGBColor[
              0.24129239010618297`, 0.3709439791957144, 0.9370526167052204], 
             UndirectedEdge[304, 329] -> 
             RGBColor[
              0.2271186296842969, 0.35604645832399684`, 0.9362454420173936], 
             UndirectedEdge[103, 223] -> 
             RGBColor[
              0.3993166746191169, 0.5202694238127852, 0.9466707039440156], 
             UndirectedEdge[92, 337] -> 
             RGBColor[
              0.2862035870447653, 0.41814849471251614`, 0.9396102429307109], 
             UndirectedEdge[226, 341] -> 
             RGBColor[
              0.23010886985563692`, 0.3591893903362524, 0.9364157317714874], 
             UndirectedEdge[193, 260] -> 
             RGBColor[
              0.8156468227717713, 0.8559278037169716, 0.9822546582008858], 
             UndirectedEdge[9, 214] -> 
             RGBColor[
              0.9047202658222255, 0.5928576663351037, 0.5422822863417485], 
             UndirectedEdge[8, 157] -> 
             RGBColor[
              0.38978189814954545`, 0.5115987980501094, 0.9461770157970921], 
             UndirectedEdge[103, 342] -> 
             RGBColor[
              0.4739621782432806, 0.580870006396498, 0.9525470714247991], 
             UndirectedEdge[165, 314] -> 
             RGBColor[
              0.7292803775430885, 0.7876149200721775, 0.9745725244009281], 
             UndirectedEdge[115, 392] -> 
             RGBColor[
              0.24327765587914302`, 0.37303061939621557`, 0.937165674654053], 
             UndirectedEdge[104, 233] -> 
             RGBColor[
              0.8756661600168449, 0.4553685127100845, 0.21500153588103987`], 
             UndirectedEdge[67, 139] -> 
             RGBColor[
              0.21205827028800195`, 0.34021706571655375`, 0.9353877768295796],
              UndirectedEdge[116, 364] -> 
             RGBColor[
              0.382875553578809, 0.5060492934502673, 0.9456174696038513], 
             UndirectedEdge[74, 220] -> 
             RGBColor[
              0.6500539956476187, 0.724027222159205, 0.9674931897567542], 
             UndirectedEdge[100, 168] -> 
             RGBColor[
              0.5233822877675662, 0.6214359238763232, 0.9564882451969059], 
             UndirectedEdge[129, 308] -> 
             RGBColor[
              0.2493864248848615, 0.3794513229395511, 0.9375135600118147], 
             UndirectedEdge[26, 185] -> 
             RGBColor[
              0.6394016686924645, 0.37581057943241813`, 0.5602833187259821], 
             UndirectedEdge[197, 215] -> 
             RGBColor[
              0.9040198154602492, 0.5694397771754294, 0.5010925431304881], 
             UndirectedEdge[178, 240] -> 
             RGBColor[
              0.24159747707370743`, 0.3712646449422136, 0.9370699909566852], 
             UndirectedEdge[52, 223] -> 
             RGBColor[
              0.42035633884682855`, 0.5384929234825571, 0.9480113327439608], 
             UndirectedEdge[192, 243] -> 
             RGBColor[
              0.31643084813058897`, 0.44661450926807483`, 0.9414526439417388],
              UndirectedEdge[124, 252] -> 
             RGBColor[
              0.22380219645594157`, 0.3525606767269839, 0.936056576051262], 
             UndirectedEdge[194, 396] -> 
             RGBColor[
              0.3331772870037427, 0.4601881672994485, 0.9425538104147095], 
             UndirectedEdge[269, 279] -> 
             RGBColor[
              0.9693542844710024, 0.9048940200148108, 0.380506034096984], 
             UndirectedEdge[57, 208] -> 
             RGBColor[
              0.2531470707031978, 0.383404000133339, 0.9377277232277921], 
             UndirectedEdge[169, 304] -> 
             RGBColor[
              0.21989845129097363`, 0.3484575930468634, 0.9358342635391905], 
             UndirectedEdge[209, 280] -> 
             RGBColor[
              0.24552309910713999`, 0.37539072259816386`, 0.9372935493240518],
              UndirectedEdge[226, 399] -> 
             RGBColor[
              0.23675652181007376`, 0.36617649402584324`, 0.9367943057159729],
              UndirectedEdge[206, 392] -> 
             RGBColor[
              0.23975564105496683`, 0.3693287585073688, 0.9369651011201702], 
             UndirectedEdge[48, 343] -> 
             RGBColor[
              0.5738217336869491, 0.6629134141226403, 0.9606378423662292], 
             UndirectedEdge[159, 263] -> 
             RGBColor[
              0.29675910238603487`, 0.4271452950122101, 0.9402881715572926], 
             UndirectedEdge[261, 295] -> 
             RGBColor[
              0.2109178597842839, 0.3390184219709439, 0.935322832138479], 
             UndirectedEdge[33, 204] -> 
             RGBColor[
              0.1789341933349501, 0.3054015606511163, 0.9335014096497838], 
             UndirectedEdge[64, 151] -> 
             RGBColor[
              0.35739789501188024`, 0.48398182614394664`, 0.9439940557289754],
              UndirectedEdge[210, 263] -> 
             RGBColor[
              0.2810036601000736, 0.41268304179923465`, 0.9393141147838132], 
             UndirectedEdge[19, 303] -> 
             RGBColor[
              0.2819979246761117, 0.4137280769086658, 0.939370736680536], 
             UndirectedEdge[248, 315] -> 
             RGBColor[
              0.229741057636631, 0.35880279637343554`, 0.9363947854097444], 
             UndirectedEdge[236, 351] -> 
             RGBColor[
              0.2481333456349381, 0.37813425719806837`, 0.9374421990022963], 
             UndirectedEdge[53, 386] -> 
             RGBColor[
              0.3143035505913172, 0.444852574192945, 0.9413141424158159], 
             UndirectedEdge[93, 301] -> 
             RGBColor[
              0.25102800874557624`, 0.38117673165959054`, 0.9376070457841768],
              UndirectedEdge[37, 159] -> 
             RGBColor[
              0.29061706023566036`, 0.4206896192842019, 0.9399383913431659], 
             UndirectedEdge[148, 326] -> 
             RGBColor[
              0.4816391300864997, 0.5869619633485583, 0.9531902603733251], 
             UndirectedEdge[13, 357] -> 
             RGBColor[
              0.8197351159980406, 0.8595406855045937, 0.9572525529228332], 
             UndirectedEdge[162, 231] -> 
             RGBColor[
              0.27738405997012383`, 0.4088786125667542, 0.9391079839111312], 
             UndirectedEdge[33, 84] -> 
             RGBColor[
              0.17893420048233583`, 0.30540156816347186`, 0.9335014100568169],
              UndirectedEdge[199, 293] -> 
             RGBColor[
              0.21851691429369074`, 0.3470055100682143, 0.9357555870509962], 
             UndirectedEdge[96, 167] -> 
             RGBColor[
              0.28523047788544853`, 0.41712569528738996`, 0.9395548258036737],
              UndirectedEdge[131, 307] -> 
             RGBColor[
              0.9538530771213425, 0.8592378166634234, 0.5753740091193393], 
             UndirectedEdge[174, 291] -> 
             RGBColor[
              0.7125484820155874, 0.7753675568103979, 0.9719838316093115], 
             UndirectedEdge[207, 250] -> 
             RGBColor[
              0.9640415176105277, 0.8943275288623829, 0.5576168978426572], 
             UndirectedEdge[364, 387] -> 
             RGBColor[
              0.3215492584874442, 0.4515282986156772, 0.941761191813439], 
             UndirectedEdge[103, 346] -> 
             RGBColor[
              0.3447990844282577, 0.4730693696510448, 0.9431912706592778], 
             UndirectedEdge[31, 106] -> 
             RGBColor[
              0.5658561150624204, 0.6355057978202503, 0.9529071762376704], 
             UndirectedEdge[128, 316] -> 
             RGBColor[
              0.29024632988181515`, 0.4207827161213608, 0.9398996026647567], 
             UndirectedEdge[185, 289] -> 
             RGBColor[
              0.8607218959500621, 0.40585224662813213`, 0.20335726643267069`],
              UndirectedEdge[20, 172] -> 
             RGBColor[
              0.3545418209166673, 0.4808311305362721, 0.9438368541227812], 
             UndirectedEdge[70, 234] -> 
             RGBColor[
              0.30827476436067847`, 0.438573607296341, 0.9409687003893238], 
             UndirectedEdge[119, 383] -> 
             RGBColor[
              0.2603673467577916, 0.3909929680586598, 0.93813890726766], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.5352140965427551, 0.633549940550514, 0.9565531607151321], 
             UndirectedEdge[20, 54] -> 
             RGBColor[
              0.4298252331165606, 0.5467147461063611, 0.9486090616680254], 
             UndirectedEdge[229, 334] -> 
             RGBColor[
              0.25414759898597045`, 0.3844556187956901, 0.9377847018333471], 
             UndirectedEdge[63, 142] -> 
             RGBColor[
              0.890072513149207, 0.5193941486818902, 0.23091004398772222`], 
             UndirectedEdge[230, 358] -> 
             RGBColor[
              0.9687169526811137, 0.9061370771638947, 0.3329716977842575], 
             UndirectedEdge[119, 296] -> 
             RGBColor[
              0.27100995406971695`, 0.4021790231237703, 0.9387449880097476], 
             UndirectedEdge[218, 262] -> 
             RGBColor[
              0.9243533171861171, 0.9424423464401257, 0.9900148507220045], 
             UndirectedEdge[100, 170] -> 
             RGBColor[
              0.4107918604538279, 0.5302289953510277, 0.9473962719925066], 
             UndirectedEdge[97, 357] -> 
             RGBColor[
              0.5589872751901463, 0.652039901144515, 0.958856542313451], 
             UndirectedEdge[375, 399] -> 
             RGBColor[
              0.24486217858118842`, 0.3746960532206071, 0.9372559108778432], 
             UndirectedEdge[199, 252] -> 
             RGBColor[
              0.2250679449332263, 0.3538910586296987, 0.9361286585545363], 
             UndirectedEdge[175, 345] -> 
             RGBColor[
              0.1904397679735038, 0.31749464909180203`, 0.9341566351044772], 
             UndirectedEdge[176, 186] -> 
             RGBColor[
              0.23214557991116364`, 0.36133010173948693`, 0.9365317193961071],
              UndirectedEdge[309, 371] -> 
             RGBColor[
              0.2714180274121831, 0.4026079340800466, 0.9387682271829105], 
             UndirectedEdge[326, 354] -> 
             RGBColor[
              0.3095818357707423, 0.4398872474233331, 0.94104533946662], 
             UndirectedEdge[38, 289] -> 
             RGBColor[
              0.9317722599024755, 0.7624356715057958, 0.27900046954474644`], 
             UndirectedEdge[120, 237] -> 
             RGBColor[
              0.5723986729827764, 0.663738054850602, 0.9594804667840822], 
             UndirectedEdge[275, 384] -> 
             RGBColor[
              0.8702642398197578, 0.8971991046411623, 0.8780681531351799], 
             UndirectedEdge[216, 220] -> 
             RGBColor[
              0.5672680445778805, 0.6593163046949915, 0.9592519182010989], 
             UndirectedEdge[50, 276] -> 
             RGBColor[
              0.6098568885565028, 0.6922609454050347, 0.9637197242270632], 
             UndirectedEdge[143, 321] -> 
             RGBColor[
              0.7212153553030598, 0.7818668166701053, 0.973033199931347], 
             UndirectedEdge[225, 316] -> 
             RGBColor[
              0.2556938059368381, 0.38608078033623494`, 0.9378727560317908], 
             UndirectedEdge[40, 332] -> 
             RGBColor[
              0.43326686926446056`, 0.5476890621459892, 0.9493828047697146], 
             UndirectedEdge[254, 343] -> 
             RGBColor[
              0.5958559812878284, 0.6815586834125604, 0.9621633323841816], 
             UndirectedEdge[37, 167] -> 
             RGBColor[
              0.26667449670074206`, 0.39762218254510395`, 0.9384980901263189],
              UndirectedEdge[26, 204] -> 
             RGBColor[
              0.3170199268376633, 0.4369570715354334, 0.9418741487280438], 
             UndirectedEdge[141, 189] -> 
             RGBColor[
              0.33030534537683665`, 0.4597575440654077, 0.9422954993465642], 
             UndirectedEdge[55, 210] -> 
             RGBColor[
              0.3517281816196206, 0.4782553243752219, 0.9436626526821428], 
             UndirectedEdge[41, 312] -> 
             RGBColor[
              0.40188874544580117`, 0.5222558384193261, 0.9469012891044913], 
             UndirectedEdge[102, 247] -> 
             RGBColor[
              0.8631522875093278, 0.40917697995257735`, 0.2050732281891151], 
             UndirectedEdge[30, 400] -> 
             RGBColor[
              0.284268969836752, 0.4086385761438802, 0.9397738211163575], 
             UndirectedEdge[57, 195] -> 
             RGBColor[
              0.25945106473985713`, 0.3900298975621752, 0.9380867263622563], 
             UndirectedEdge[301, 324] -> 
             RGBColor[
              0.2683877801719362, 0.39942295210177514`, 0.9385956590854276], 
             UndirectedEdge[290, 331] -> 
             RGBColor[
              0.42861309362707734`, 0.5456648518044729, 0.9485318252116084], 
             UndirectedEdge[49, 347] -> 
             RGBColor[
              0.2678932418389194, 0.3989031609582332, 0.9385674958589661], 
             UndirectedEdge[92, 258] -> 
             RGBColor[
              0.2702985516937192, 0.40143129412108086`, 0.93870447469686], 
             UndirectedEdge[234, 313] -> 
             RGBColor[
              0.3107738733861259, 0.4412003293347502, 0.9411110209512226], 
             UndirectedEdge[376, 377] -> 
             RGBColor[
              0.4266363429774569, 0.5439526897461481, 0.9484058684081864], 
             UndirectedEdge[223, 272] -> 
             RGBColor[
              0.5505420601979628, 0.6459225184451997, 0.9578086189518668], 
             UndirectedEdge[213, 302] -> 
             RGBColor[
              0.9491225739214294, 0.8267349297802298, 0.3261475838124945], 
             UndirectedEdge[121, 158] -> 
             RGBColor[
              0.5281560210081759, 0.6278198768688632, 0.9559975231544674], 
             UndirectedEdge[240, 248] -> 
             RGBColor[
              0.22770719970496556`, 0.3566650827332143, 0.9362789602093593], 
             UndirectedEdge[18, 132] -> 
             RGBColor[
              0.8722144636354254, 0.9008667885957915, 0.9791289224454733], 
             UndirectedEdge[59, 79] -> 
             RGBColor[
              0.46241207497172554`, 0.5712067102742551, 0.9517169387007705], 
             UndirectedEdge[109, 207] -> 
             RGBColor[
              0.9669761340347394, 0.8955410681699965, 0.508982709149612], 
             UndirectedEdge[190, 365] -> 
             RGBColor[
              0.24867185173243342`, 0.3787002612497945, 0.9374728661279003], 
             UndirectedEdge[78, 391] -> 
             RGBColor[
              0.8311173699138001, 0.24018731764171894`, 0.1774313346124849], 
             UndirectedEdge[159, 236] -> 
             RGBColor[
              0.2909783973419341, 0.4210694074929913, 0.9399589689568179], 
             UndirectedEdge[95, 334] -> 
             RGBColor[
              0.27158878350233817`, 0.4027874095573609, 0.9387779514896339], 
             UndirectedEdge[20, 147] -> 
             RGBColor[
              0.34619840677068126`, 0.47206167326583015`, 0.9433617090301424],
              UndirectedEdge[229, 388] -> 
             RGBColor[
              0.23513063549537086`, 0.3644675844219441, 0.9367017138956337], 
             UndirectedEdge[15, 271] -> 
             RGBColor[
              0.3053243996883596, 0.43824568113047624`, 0.940699144924056], 
             UndirectedEdge[53, 151] -> 
             RGBColor[
              0.302539739143033, 0.43466335198279643`, 0.9405645627526612], 
             UndirectedEdge[178, 309] -> 
             RGBColor[
              0.2573894464516083, 0.38786300602707646`, 0.9379693202506316], 
             UndirectedEdge[309, 386] -> 
             RGBColor[
              0.30507679489801537`, 0.4351546689491852, 0.9407886923288442], 
             UndirectedEdge[199, 299] -> 
             RGBColor[
              0.21996573354153404`, 0.3485283109581435, 0.9358380951638248], 
             UndirectedEdge[33, 90] -> 
             RGBColor[
              0.44237359411374266`, 0.5377546224462848, 0.9524068017673784], 
             UndirectedEdge[191, 216] -> 
             RGBColor[
              0.6689774683276695, 0.7413295497654275, 0.9676410801591727], 
             UndirectedEdge[188, 203] -> 
             RGBColor[
              0.2792417470878428, 0.4108311595116429, 0.9392137764442834], 
             UndirectedEdge[87, 263] -> 
             RGBColor[
              0.2761111635451054, 0.407540717717765, 0.9390354943428079], 
             UndirectedEdge[25, 76] -> 
             RGBColor[
              0.8478277754462535, 0.3686308171105509, 0.1934332378220659], 
             UndirectedEdge[329, 334] -> 
             RGBColor[
              0.2482689309678744, 0.37827676597959103`, 0.9374499203864265], 
             UndirectedEdge[42, 376] -> 
             RGBColor[
              0.6853095806395425, 0.7514657941798157, 0.9712763701432583], 
             UndirectedEdge[54, 130] -> 
             RGBColor[
              0.43119853805658864`, 0.5479042338211002, 0.9486965674444381], 
             UndirectedEdge[90, 256] -> 
             RGBColor[
              0.46555708352199543`, 0.5621219397324855, 0.9537270671922793], 
             UndirectedEdge[160, 302] -> 
             RGBColor[
              0.9083773079386029, 0.59816388871644, 0.2904675904582531], 
             UndirectedEdge[299, 367] -> 
             RGBColor[
              0.21672169883755696`, 0.34511862480058364`, 0.9356533521865525],
              UndirectedEdge[16, 96] -> 
             RGBColor[
              0.2643859994981743, 0.3952168268861021, 0.9383677635961609], 
             UndirectedEdge[5, 223] -> 
             RGBColor[
              0.6477551093793219, 0.7220395366342189, 0.9674518801311646], 
             UndirectedEdge[40, 228] -> 
             RGBColor[
              0.35358465424250685`, 0.48067898864856917`, 0.9437510793990673],
              UndirectedEdge[154, 222] -> 
             RGBColor[
              0.5175424648922109, 0.6185744663744461, 0.9553357375773506], 
             UndirectedEdge[85, 188] -> 
             RGBColor[
              0.25419669233076414`, 0.38450721901376617`, 0.937787497626706], 
             UndirectedEdge[281, 384] -> 
             RGBColor[
              0.6902109435663115, 0.7577585241609326, 0.9698659918101223], 
             UndirectedEdge[249, 334] -> 
             RGBColor[
              0.2654841590440016, 0.39637106219610324`, 0.9384303021577143], 
             UndirectedEdge[203, 243] -> 
             RGBColor[
              0.28988476393267687`, 0.4220176450218065, 0.9398198805086642], 
             UndirectedEdge[49, 147] -> 
             RGBColor[
              0.2702371158648362, 0.4013667211696683, 0.9387009760172913], 
             UndirectedEdge[99, 232] -> 
             RGBColor[
              0.7518421224806613, 0.804458883314896, 0.9388506680687247], 
             UndirectedEdge[84, 389] -> 
             RGBColor[
              0.1790075704625178, 0.3054786846645686, 0.933505588368647], 
             UndirectedEdge[76, 242] -> 
             RGBColor[
              0.8826456379438963, 0.5379102714518893, 0.22287275278700588`], 
             UndirectedEdge[129, 397] -> 
             RGBColor[
              0.24351700983454236`, 0.3732821955792575, 0.9371793055077206], 
             UndirectedEdge[177, 390] -> 
             RGBColor[
              0.2941038875347629, 0.4252352483079229, 0.9401047123377103], 
             UndirectedEdge[138, 144] -> 
             RGBColor[
              0.8488904911809813, 0.34529052811745564`, 0.1932170904993126], 
             UndirectedEdge[184, 325] -> 
             RGBColor[
              0.2146653182782982, 0.3429572384507447, 0.9355362443558451], 
             UndirectedEdge[69, 140] -> 
             RGBColor[
              0.5800718085263902, 0.6695145386144623, 0.9603941834467046], 
             UndirectedEdge[247, 391] -> 
             RGBColor[
              0.8636991649292758, 0.4133805194455108, 0.20559691862406698`], 
             UndirectedEdge[14, 391] -> 
             RGBColor[
              0.9073739340103057, 0.5740384053828973, 0.3971702369213773], 
             UndirectedEdge[229, 240] -> 
             RGBColor[
              0.24305133588145522`, 0.372792742729129, 0.9371527860649951], 
             UndirectedEdge[166, 400] -> 
             RGBColor[
              0.6071900057616888, 0.351637441026028, 0.5586994341727993], 
             UndirectedEdge[281, 386] -> 
             RGBColor[
              0.4856785944575267, 0.5902406468075978, 0.9535084650798691], 
             UndirectedEdge[150, 255] -> 
             RGBColor[
              0.26553787758684655`, 0.39642752379058566`, 0.9384333613492598],
              UndirectedEdge[103, 290] -> 
             RGBColor[
              0.3748499370785241, 0.4990979078169345, 0.9451060844172272], 
             UndirectedEdge[212, 299] -> 
             RGBColor[
              0.2125129386493282, 0.3406949509919467, 0.9354136695201356], 
             UndirectedEdge[206, 208] -> 
             RGBColor[
              0.23232439396841398`, 0.3615180466511231, 0.9365419025921359], 
             UndirectedEdge[75, 169] -> 
             RGBColor[
              0.2324382955275915, 0.3616377644115946, 0.9365483891174288], 
             UndirectedEdge[110, 167] -> 
             RGBColor[
              0.26956370563298526`, 0.40065892431931827`, 0.9386626263008084],
              UndirectedEdge[33, 214] -> 
             RGBColor[
              0.5813572401883383, 0.6464138508373214, 0.9229269591928677], 
             UndirectedEdge[98, 107] -> 
             RGBColor[
              0.9083938909149378, 0.6192253386491839, 0.2762763560175848], 
             UndirectedEdge[238, 252] -> 
             RGBColor[
              0.22677811637454098`, 0.3556885572456525, 0.9362260502881472], 
             UndirectedEdge[91, 241] -> 
             RGBColor[
              0.2767915804260243, 0.40825587900053273`, 0.9390742430775896], 
             UndirectedEdge[74, 219] -> 
             RGBColor[
              0.6359306602465759, 0.7123948141262615, 0.9664273391659474], 
             UndirectedEdge[45, 180] -> 
             RGBColor[
              0.33088455801292704`, 0.4597925392578639, 0.9423494940589101], 
             UndirectedEdge[187, 235] -> 
             RGBColor[
              0.792013758809907, 0.8376400126416226, 0.9798528182009743], 
             UndirectedEdge[114, 188] -> 
             RGBColor[0.297981899619691, 0.4286669180863, 0.9403491528141107],
              UndirectedEdge[81, 378] -> 
             RGBColor[
              0.21412094136701804`, 0.3423850638014996, 0.9355052428960813], 
             UndirectedEdge[19, 313] -> 
             RGBColor[
              0.27859623109563336`, 0.41015268127575305`, 0.9391770152634824],
              UndirectedEdge[195, 284] -> 
             RGBColor[
              0.24484639804506322`, 0.3746794668765958, 0.9372550121996561], 
             UndirectedEdge[64, 253] -> 
             RGBColor[
              0.3703380254209453, 0.4951899167144135, 0.9448185893961331], 
             UndirectedEdge[55, 122] -> 
             RGBColor[
              0.4248101196568824, 0.5423709068945195, 0.9482895030730654], 
             UndirectedEdge[99, 275] -> 
             RGBColor[
              0.9851141209349312, 0.987104803716967, 0.8512424005775606], 
             UndirectedEdge[118, 367] -> 
             RGBColor[
              0.21268815866311674`, 0.340879118336029, 0.9354236480407061], 
             UndirectedEdge[7, 96] -> 
             RGBColor[
              0.3381582412697068, 0.46529865529748227`, 0.9428420383243149], 
             UndirectedEdge[110, 115] -> 
             RGBColor[
              0.2470920216969208, 0.3770397597154611, 0.9373828971445268], 
             UndirectedEdge[68, 95] -> 
             RGBColor[
              0.2792515764807897, 0.4108414908268496, 0.9392143362136705], 
             UndirectedEdge[289, 302] -> 
             RGBColor[
              0.9425151711377706, 0.798674033657958, 0.3207346510653094], 
             UndirectedEdge[260, 321] -> 
             RGBColor[
              0.813370248803728, 0.8541302872991015, 0.9820328030897745], 
             UndirectedEdge[191, 220] -> 
             RGBColor[
              0.5771439386381384, 0.6670314281944398, 0.9602362550255482], 
             UndirectedEdge[169, 209] -> 
             RGBColor[
              0.23636572886417778`, 0.36576574586200267`, 0.9367720506358304],
              UndirectedEdge[32, 252] -> 
             RGBColor[
              0.2203092674216852, 0.34888938684748844`, 0.9358576589100864], 
             UndirectedEdge[75, 280] -> 
             RGBColor[
              0.24159566577055375`, 0.3712627411477558, 0.9370698878056503], 
             UndirectedEdge[14, 224] -> 
             RGBColor[
              0.9850092930497456, 0.9599506894449308, 0.4935654545583491], 
             UndirectedEdge[128, 311] -> 
             RGBColor[
              0.4227935959175786, 0.5388307190597109, 0.9486565824461703], 
             UndirectedEdge[132, 198] -> 
             RGBColor[
              0.8128559952710535, 0.8537811311091374, 0.9819675933041132], 
             UndirectedEdge[245, 388] -> 
             RGBColor[
              0.22663197894047044`, 0.3555349575367959, 0.9362177279774678], 
             UndirectedEdge[183, 273] -> 
             RGBColor[
              0.26718551324119244`, 0.3981592933294373, 0.9385271917623162], 
             UndirectedEdge[69, 220] -> 
             RGBColor[
              0.4818265682663484, 0.5902075400149862, 0.9523502989242535], 
             UndirectedEdge[37, 263] -> 
             RGBColor[
              0.25594156812645086`, 0.3863411941065481, 0.9378868657219579], 
             UndirectedEdge[235, 384] -> 
             RGBColor[
              0.7442607582282336, 0.800141428009943, 0.9751446149341176], 
             UndirectedEdge[132, 216] -> 
             RGBColor[
              0.7291619678468395, 0.7883461382089411, 0.9736397086151186], 
             UndirectedEdge[225, 380] -> 
             RGBColor[
              0.2612993849996442, 0.39197259934548456`, 0.9381919854667065], 
             UndirectedEdge[3, 371] -> 
             RGBColor[
              0.3210626317693298, 0.4491168451749269, 0.9418030466401561], 
             UndirectedEdge[269, 314] -> 
             RGBColor[
              0.9594354549874111, 0.9656217176549777, 0.7393357035372017], 
             UndirectedEdge[16, 206] -> 
             RGBColor[
              0.23671129027789278`, 0.36612895281767627`, 0.9367917298471292],
              UndirectedEdge[84, 256] -> 
             RGBColor[
              0.20211768989058865`, 0.32976888544967253`, 0.9348216754817178],
              UndirectedEdge[58, 348] -> 
             RGBColor[
              0.28088310771412667`, 0.4125563335981417, 0.9393072495037748], 
             UndirectedEdge[177, 360] -> 
             RGBColor[
              0.31615011179738517`, 0.4482550694974156, 0.9413657834565303], 
             UndirectedEdge[2, 106] -> 
             RGBColor[
              0.8834730056375308, 0.5519688209280622, 0.5686856052309635], 
             UndirectedEdge[256, 317] -> 
             RGBColor[
              0.6079677143241806, 0.6722679099328412, 0.8705698500730703], 
             UndirectedEdge[87, 351] -> 
             RGBColor[
              0.2679416039473189, 0.3989539926004958, 0.9385702500094941], 
             UndirectedEdge[48, 103] -> 
             RGBColor[
              0.3850045259376993, 0.5078933023022759, 0.9457531258399835], 
             UndirectedEdge[256, 381] -> 
             RGBColor[
              0.6092276972658053, 0.6727889452592876, 0.8496886719990233], 
             UndirectedEdge[91, 226] -> 
             RGBColor[
              0.25062761976227643`, 0.38075589745201466`, 0.9375842442239002],
              UndirectedEdge[105, 113] -> 
             RGBColor[
              0.6069298774587211, 0.6884337835985022, 0.9640833346207096], 
             UndirectedEdge[223, 291] -> 
             RGBColor[
              0.5752793861727824, 0.6652475055073694, 0.9602742044215822], 
             UndirectedEdge[203, 348] -> 
             RGBColor[
              0.277176399167938, 0.4086603478972015, 0.9390961579356532], 
             UndirectedEdge[259, 367] -> 
             RGBColor[
              0.21516769270569408`, 0.3434852658263162, 0.935564853836289], 
             UndirectedEdge[188, 206] -> 
             RGBColor[
              0.2493239941811602, 0.37938570431162577`, 0.937510004675597], 
             UndirectedEdge[250, 289] -> 
             RGBColor[
              0.9429902625743816, 0.8090015716874366, 0.5405821025323335], 
             UndirectedEdge[194, 377] -> 
             RGBColor[
              0.40146722310948635`, 0.5221524631532592, 0.9468021143463783], 
             UndirectedEdge[83, 231] -> 
             RGBColor[
              0.3307828964588674, 0.4609235312385056, 0.9422983810248817], 
             UndirectedEdge[276, 376] -> 
             RGBColor[
              0.6019797217390458, 0.6854606658855094, 0.9632115739949887], 
             UndirectedEdge[83, 120] -> 
             RGBColor[
              0.45962999176153224`, 0.5694602774020465, 0.9513564039568587], 
             UndirectedEdge[40, 243] -> 
             RGBColor[
              0.3138420416346276, 0.4443722151984709, 0.9412876874810078], 
             UndirectedEdge[4, 392] -> 
             RGBColor[
              0.24007285485442642`, 0.3696621703231174, 0.9369831659767736], 
             UndirectedEdge[81, 329] -> 
             RGBColor[
              0.22742713619850993`, 0.35637071823087746`, 0.9362630110069835],
              UndirectedEdge[131, 363] -> 
             RGBColor[
              0.8924893365860593, 0.5994472191560132, 0.23173103267921852`], 
             UndirectedEdge[167, 192] -> 
             RGBColor[
              0.3140196057697616, 0.4440801406652496, 0.941315327256403], 
             UndirectedEdge[41, 327] -> 
             RGBColor[
              0.32970622489449014`, 0.4599966933120725, 0.9422295669958778], 
             UndirectedEdge[24, 382] -> 
             RGBColor[
              0.9004669733536322, 0.6409255971753784, 0.23865954159958375`], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.6399409788041857, 0.37995595327830467`, 0.56079976269803], 
             UndirectedEdge[90, 261] -> 
             RGBColor[
              0.4426270855649366, 0.538021058033776, 0.9524212377305169], 
             UndirectedEdge[146, 297] -> 
             RGBColor[
              0.7409851288378926, 0.7966845449876518, 0.9658863907552364], 
             UndirectedEdge[5, 291] -> 
             RGBColor[
              0.7689673032381015, 0.8196158140703518, 0.9775611053894065], 
             UndirectedEdge[229, 315] -> 
             RGBColor[
              0.24508519381312066`, 0.3749304563693503, 0.9372686112653803], 
             UndirectedEdge[241, 360] -> 
             RGBColor[
              0.3006768355928906, 0.4332086382716799, 0.9404400442858039], 
             UndirectedEdge[59, 237] -> 
             RGBColor[
              0.4562186120487096, 0.5661785780610258, 0.9512293666120685], 
             UndirectedEdge[257, 381] -> 
             RGBColor[
              0.9078770993756948, 0.5831041621482105, 0.46625847556572675`], 
             UndirectedEdge[270, 308] -> 
             RGBColor[
              0.2553377632908749, 0.38570655694091993`, 0.9378524799298211], 
             UndirectedEdge[317, 382] -> 
             RGBColor[
              0.9447039927210837, 0.8118308485146293, 0.5211250046258997], 
             UndirectedEdge[23, 89] -> 
             RGBColor[
              0.21600037669219402`, 0.3443604694913417, 0.9356122739574746], 
             UndirectedEdge[57, 327] -> 
             RGBColor[
              0.2958997785397042, 0.4274294644124098, 0.9401957587844365], 
             UndirectedEdge[347, 362] -> 
             RGBColor[
              0.3423545559019188, 0.4682989085041503, 0.9431326516737686], 
             UndirectedEdge[43, 293] -> 
             RGBColor[
              0.21933315592561953`, 0.34786343177608003`, 0.9358020708044131],
              UndirectedEdge[73, 208] -> 
             RGBColor[
              0.23810134733460236`, 0.3675899909189858, 0.9368708915401036], 
             UndirectedEdge[53, 129] -> 
             RGBColor[
              0.26346421560774436`, 0.39424797357278596`, 0.9383152693672578],
              UndirectedEdge[324, 383] -> 
             RGBColor[
              0.2800969902621915, 0.41173007431343256`, 0.9392624812778436], 
             UndirectedEdge[368, 399] -> 
             RGBColor[
              0.22383026101092823`, 0.35259017435367035`, 0.9360581742861507],
              UndirectedEdge[51, 136] -> 
             RGBColor[
              0.4957527510770341, 0.5993305404010079, 0.9540497614266502], 
             UndirectedEdge[145, 359] -> 
             RGBColor[
              0.24179608967805666`, 0.37147339938215107`, 0.9370813016506819],
              UndirectedEdge[222, 297] -> 
             RGBColor[
              0.7757829604608912, 0.8249349923236523, 0.9686258035292561], 
             UndirectedEdge[81, 209] -> 
             RGBColor[
              0.23587421810878062`, 0.36524913689449845`, 0.9367440598254355],
              UndirectedEdge[31, 345] -> 
             RGBColor[
              0.1925824038789099, 0.3197466952793466, 0.9342786550495443], 
             UndirectedEdge[155, 180] -> 
             RGBColor[
              0.33540782096983857`, 0.46454677541701367`, 0.9426070871927383],
              UndirectedEdge[4, 369] -> 
             RGBColor[
              0.2448252232373639, 0.37465721081114345`, 0.937253806325683], 
             UndirectedEdge[102, 289] -> 
             RGBColor[
              0.8585251717968794, 0.3889672621761071, 0.20125368090273776`], 
             UndirectedEdge[70, 103] -> 
             RGBColor[
              0.3111881460301813, 0.44109703206764383`, 0.9411543384931023], 
             UndirectedEdge[177, 375] -> 
             RGBColor[
              0.28837692064883436`, 0.4192158430001391, 0.939778570045845], 
             UndirectedEdge[171, 253] -> 
             RGBColor[
              0.30746418261270597`, 0.43744644735605664`, 0.9409326149067666],
              UndirectedEdge[150, 241] -> 
             RGBColor[
              0.2807813627744614, 0.41244939321555174`, 0.939301455279979], 
             UndirectedEdge[24, 317] -> 
             RGBColor[
              0.946390043794504, 0.8194868126517976, 0.5225318869704552], 
             UndirectedEdge[80, 110] -> 
             RGBColor[
              0.29499717102305234`, 0.4250177053104399, 0.9401979264655129], 
             UndirectedEdge[176, 341] -> 
             RGBColor[
              0.21870360025711671`, 0.3472017288523488, 0.9357662185404361], 
             UndirectedEdge[154, 192] -> 
             RGBColor[
              0.3873238866966642, 0.5099022160172301, 0.9459009134566145], 
             UndirectedEdge[121, 322] -> 
             RGBColor[
              0.5308061338547281, 0.6299713578639174, 0.9562061497454312], 
             UndirectedEdge[268, 381] -> 
             RGBColor[
              0.9052330145226024, 0.5627805673219706, 0.46372649692433865`], 
             UndirectedEdge[76, 104] -> 
             RGBColor[
              0.8904092616611533, 0.5686904524165735, 0.22911954666558126`], 
             UndirectedEdge[91, 186] -> 
             RGBColor[
              0.2555444422624831, 0.38592378964428387`, 0.9378642499915], 
             UndirectedEdge[216, 357] -> 
             RGBColor[
              0.6673958385373104, 0.7400939685523675, 0.9674834380828405], 
             UndirectedEdge[210, 236] -> 
             RGBColor[
              0.27522295505597283`, 0.4066071542800159, 0.9389849121833385], 
             UndirectedEdge[26, 173] -> 
             RGBColor[
              0.34074023236907375`, 0.46188861660318076`, 0.9432249850370102],
              UndirectedEdge[10, 374] -> 
             RGBColor[
              0.31901480157328777`, 0.4477183185888486, 0.9416588227642095], 
             UndirectedEdge[289, 340] -> 
             RGBColor[
              0.9457657182249508, 0.8088519239369327, 0.40028051736176995`], 
             UndirectedEdge[65, 168] -> 
             RGBColor[
              0.592741338058181, 0.6798274166038522, 0.9613729899467283], 
             UndirectedEdge[40, 203] -> 
             RGBColor[
              0.31535485342024205`, 0.44596227630295887`, 0.941373839874194], 
             UndirectedEdge[167, 201] -> 
             RGBColor[
              0.27998787707886075`, 0.41161538943957654`, 0.9392562674434715],
              UndirectedEdge[41, 57] -> 
             RGBColor[
              0.3070138697292798, 0.4370559315903547, 0.9409039388472313], 
             UndirectedEdge[214, 363] -> 
             RGBColor[
              0.9231427936939823, 0.7280008749245814, 0.5596707462488172], 
             UndirectedEdge[22, 189] -> 
             RGBColor[
              0.29643257003583556`, 0.4288998043911114, 0.9401927683796281], 
             UndirectedEdge[41, 96] -> 
             RGBColor[
              0.3138659022147775, 0.44425785217656466`, 0.9412941519606068], 
             UndirectedEdge[31, 197] -> 
             RGBColor[
              0.5859844235922751, 0.6497599697422292, 0.884913356826519], 
             UndirectedEdge[275, 281] -> 
             RGBColor[
              0.8120473445077586, 0.8515608457173255, 0.8723741943555676], 
             UndirectedEdge[89, 353] -> 
             RGBColor[
              0.21448123699978983`, 0.34276375735560527`, 0.9355257611993579],
              UndirectedEdge[324, 375] -> 
             RGBColor[
              0.267401497471214, 0.3983863064493811, 0.938539491744696], 
             UndirectedEdge[5, 174] -> 
             RGBColor[
              0.7850242052221269, 0.8321595879372474, 0.979161507318894], 
             UndirectedEdge[36, 314] -> 
             RGBColor[
              0.7227446385125958, 0.7823089126955356, 0.9740580070832467], 
             UndirectedEdge[220, 357] -> 
             RGBColor[
              0.5755623088477795, 0.6657958469813797, 0.960078612949216], 
             UndirectedEdge[291, 342] -> 
             RGBColor[
              0.6499248897969461, 0.7258480880910823, 0.9661505719023658], 
             UndirectedEdge[21, 159] -> 
             RGBColor[
              0.3221758681761928, 0.45347427680941704`, 0.9417497393246208], 
             UndirectedEdge[220, 394] -> 
             RGBColor[
              0.4171512331180811, 0.5351366490894776, 0.9479674097431279], 
             UndirectedEdge[129, 249] -> 
             RGBColor[
              0.25362687609654, 0.3839083060231606, 0.9377550474351345], 
             UndirectedEdge[37, 58] -> 
             RGBColor[
              0.2743052593933725, 0.40564259795335733`, 0.9389326507729624], 
             UndirectedEdge[118, 259] -> 
             RGBColor[
              0.20854115618205327`, 0.33652035579328765`, 0.9351874823843499],
              UndirectedEdge[201, 243] -> 
             RGBColor[
              0.2823991194396881, 0.4141497580424017, 0.9393935841288071], 
             UndirectedEdge[40, 110] -> 
             RGBColor[
              0.29744503748137785`, 0.4271379242032959, 0.940353902351674], 
             UndirectedEdge[35, 278] -> 
             RGBColor[
              0.26672833715189703`, 0.3976787722729497, 0.9385011562603622], 
             UndirectedEdge[164, 315] -> 
             RGBColor[
              0.2429063670041037, 0.37264037124747484`, 0.9371445303018922], 
             UndirectedEdge[81, 304] -> 
             RGBColor[
              0.21940694053557647`, 0.34794098407935925`, 0.9358062727287957],
              UndirectedEdge[12, 299] -> 
             RGBColor[
              0.21628284341415968`, 0.3446573599255522, 0.9356283600194184], 
             UndirectedEdge[203, 258] -> 
             RGBColor[
              0.2721654186176039, 0.4033934896242831, 0.9388107900063931], 
             UndirectedEdge[250, 276] -> 
             RGBColor[
              0.8768966809261312, 0.9030925119563854, 0.9110185744810039], 
             UndirectedEdge[124, 238] -> 
             RGBColor[
              0.22624718755874168`, 0.35513051739741625`, 0.9361958146775262],
              UndirectedEdge[96, 154] -> 
             RGBColor[
              0.3585347588123511, 0.48294777063937044`, 0.9441404120038852], 
             UndirectedEdge[126, 238] -> 
             RGBColor[
              0.2206324276302094, 0.349229048716188, 0.9358760624058893], 
             UndirectedEdge[103, 108] -> 
             RGBColor[
              0.3560676178251626, 0.48282960690648735`, 0.9439092916429558], 
             UndirectedEdge[122, 210] -> 
             RGBColor[
              0.3730056479605837, 0.4966847962832106, 0.9450184340224643], 
             UndirectedEdge[108, 234] -> 
             RGBColor[
              0.3531542361556598, 0.4803061821351844, 0.9437236535391773], 
             UndirectedEdge[222, 361] -> 
             RGBColor[
              0.48027671073484357`, 0.5862967431545993, 0.9529611966752556], 
             UndirectedEdge[12, 274] -> 
             RGBColor[
              0.2245824786939262, 0.35338080283185697`, 0.936101011970391], 
             UndirectedEdge[141, 219] -> 
             RGBColor[
              0.4036258957264883, 0.5240221968760659, 0.9469396630566943], 
             UndirectedEdge[179, 344] -> 
             RGBColor[
              0.29513590341832135`, 0.4264382934400302, 0.9401591514378], 
             UndirectedEdge[14, 230] -> 
             RGBColor[
              0.9816071552805266, 0.9484744798894191, 0.4803487917647419], 
             UndirectedEdge[12, 118] -> 
             RGBColor[
              0.21224930323971947`, 0.34041785346099757`, 0.9353986558735721],
              UndirectedEdge[44, 49] -> 
             RGBColor[
              0.2768464709137847, 0.4083135723834269, 0.9390773690096643], 
             UndirectedEdge[224, 247] -> 
             RGBColor[
              0.9413345239687156, 0.7992928035075443, 0.30199213626103877`], 
             UndirectedEdge[161, 222] -> 
             RGBColor[
              0.5181817733764011, 0.6191282032508729, 0.9553764737486448], 
             UndirectedEdge[148, 168] -> 
             RGBColor[
              0.6470192572483401, 0.7238926765948177, 0.9656459465719469], 
             UndirectedEdge[219, 323] -> 
             RGBColor[
              0.6386990444191253, 0.7146022485196659, 0.9666913901196909], 
             UndirectedEdge[309, 334] -> 
             RGBColor[
              0.26609474286190404`, 0.39701282450196873`, 0.9384650740028659],
              UndirectedEdge[170, 326] -> 
             RGBColor[
              0.39217993552288943`, 0.5141082814383957, 0.9462103365937862], 
             UndirectedEdge[239, 354] -> 
             RGBColor[
              0.3021441775416652, 0.43344512169287874`, 0.940571418461126], 
             UndirectedEdge[11, 221] -> 
             RGBColor[
              0.9226607888866434, 0.8373956409938654, 0.6248416927368453], 
             UndirectedEdge[47, 322] -> 
             RGBColor[
              0.47115402237552717`, 0.5810156228019311, 0.9516558567994469], 
             UndirectedEdge[155, 271] -> 
             RGBColor[
              0.305666751429035, 0.4386055145162801, 0.9407186413492236], 
             UndirectedEdge[106, 363] -> 
             RGBColor[
              0.905503655257033, 0.714845634359743, 0.589529206598464], 
             UndirectedEdge[245, 378] -> 
             RGBColor[
              0.2192126419789341, 0.3477367639770881, 0.9357952077134337], 
             UndirectedEdge[155, 326] -> 
             RGBColor[
              0.32196792775833594`, 0.4529058154258842, 0.9417507090817323], 
             UndirectedEdge[10, 39] -> 
             RGBColor[
              0.3175089705748625, 0.446135594734304, 0.9415730679165266], 
             UndirectedEdge[25, 382] -> 
             RGBColor[
              0.8737460186049575, 0.5043450922501913, 0.21576589198201723`], 
             UndirectedEdge[177, 383] -> 
             RGBColor[
              0.3010724134398118, 0.43255961086419054`, 0.9405015595789926], 
             UndirectedEdge[177, 296] -> 
             RGBColor[
              0.3117150207517371, 0.4437456659293011, 0.9411076403210801], 
             UndirectedEdge[103, 143] -> 
             RGBColor[
              0.48460520194471113`, 0.589510492500073, 0.9533849292372562], 
             UndirectedEdge[84, 317] -> 
             RGBColor[
              0.5847770387283635, 0.6478930395078799, 0.8692491754054186], 
             UndirectedEdge[50, 328] -> 
             RGBColor[
              0.38179240870061343`, 0.505088601337379, 0.9455546766979714], 
             UndirectedEdge[332, 385] -> 
             RGBColor[
              0.5513213263478973, 0.6466265153287621, 0.9578211808481198], 
             UndirectedEdge[242, 257] -> 
             RGBColor[
              0.8704770048155868, 0.4443768248986645, 0.21122005596083127`], 
             UndirectedEdge[214, 217] -> 
             RGBColor[
              0.903299381606431, 0.5819361276170735, 0.5409216460120444], 
             UndirectedEdge[51, 59] -> 
             RGBColor[
              0.3534707906164537, 0.48058036569863427`, 0.9437438241095009], 
             UndirectedEdge[66, 131] -> 
             RGBColor[
              0.9476245332536402, 0.8250818486193503, 0.3026198784181737], 
             UndirectedEdge[66, 98] -> 
             RGBColor[
              0.9751764945744315, 0.9279266287426179, 0.3580657982576656], 
             UndirectedEdge[70, 346] -> 
             RGBColor[
              0.3114210735342079, 0.4412987821643549, 0.9411691804276892], 
             UndirectedEdge[151, 253] -> 
             RGBColor[
              0.3287756481732377, 0.4591906745282696, 0.9421702714700763], 
             UndirectedEdge[384, 398] -> 
             RGBColor[
              0.8439266207114591, 0.8788704640005567, 0.9814905615415767], 
             UndirectedEdge[123, 218] -> 
             RGBColor[
              0.9421799541639146, 0.955737423109728, 0.959839004250153], 
             UndirectedEdge[169, 280] -> 
             RGBColor[
              0.229855838803546, 0.3589234386574095, 0.9364013220273968], 
             UndirectedEdge[71, 109] -> 
             RGBColor[
              0.932608231427341, 0.9459491066410988, 0.8675350166916449], 
             UndirectedEdge[166, 302] -> 
             RGBColor[
              0.9060230690090321, 0.580068176669682, 0.28821316860056356`], 
             UndirectedEdge[89, 163] -> 
             RGBColor[
              0.23177803755773202`, 0.36094379142249916`, 0.9365107884028094],
              UndirectedEdge[102, 340] -> 
             RGBColor[
              0.9065375818313084, 0.569215708650745, 0.3651390053950433], 
             UndirectedEdge[380, 390] -> 
             RGBColor[
              0.2658949696207651, 0.39680285015917666`, 0.9384536972123212], 
             UndirectedEdge[172, 387] -> 
             RGBColor[
              0.29749670616801155`, 0.43001827893615596`, 0.9402533693581072],
              UndirectedEdge[61, 298] -> 
             RGBColor[
              0.9083880182689977, 0.925110369261773, 0.7500707788698681], 
             UndirectedEdge[10, 216] -> 
             RGBColor[
              0.5105137254220357, 0.6107590812291837, 0.9554696590225349], 
             UndirectedEdge[209, 229] -> 
             RGBColor[
              0.24946457527559712`, 0.37953346395523513`, 0.937518010560954], 
             UndirectedEdge[39, 119] -> 
             RGBColor[
              0.2567952159774935, 0.3872384321223937, 0.9379354797042159], 
             UndirectedEdge[33, 261] -> 
             RGBColor[
              0.17919487812109408`, 0.3056755568897237, 0.9335162552627061], 
             UndirectedEdge[102, 213] -> 
             RGBColor[
              0.8651325745805382, 0.41702815829837886`, 0.20666661364992278`],
              UndirectedEdge[155, 335] -> 
             RGBColor[
              0.29253189959404885`, 0.42479995244000324`, 0.9399706309684931],
              UndirectedEdge[76, 317] -> 
             RGBColor[
              0.9187857495623798, 0.676116573374989, 0.49879235046594833`], 
             UndirectedEdge[19, 179] -> 
             RGBColor[
              0.2720136332383074, 0.4032339535668936, 0.9388021460535885], 
             UndirectedEdge[48, 83] -> 
             RGBColor[
              0.38916228198081126`, 0.5114945416119245, 0.9460180543784913], 
             UndirectedEdge[288, 355] -> 
             RGBColor[
              0.2379735788706035, 0.36745569816233453`, 0.9368636153150954], 
             UndirectedEdge[7, 192] -> 
             RGBColor[
              0.36694736915401993`, 0.4922531006753419, 0.9446025397770442], 
             UndirectedEdge[341, 393] -> 
             RGBColor[
              0.2222018557461406, 0.35087861717352153`, 0.9359654390153307], 
             UndirectedEdge[244, 270] -> 
             RGBColor[
              0.2548116613836774, 0.3851535904796679, 0.9378225192045042], 
             UndirectedEdge[121, 265] -> 
             RGBColor[
              0.5725454192775208, 0.6638571901035208, 0.9594920191899539], 
             UndirectedEdge[156, 363] -> 
             RGBColor[
              0.5242360164158433, 0.390684407006331, 0.5704454430561892], 
             UndirectedEdge[133, 280] -> 
             RGBColor[
              0.26813571605602704`, 0.3991580167341666, 0.938581304406922], 
             UndirectedEdge[44, 362] -> 
             RGBColor[
              0.35130778497678417`, 0.477709319929344, 0.9436425248244668], 
             UndirectedEdge[116, 147] -> 
             RGBColor[
              0.35047958711339033`, 0.47576981650030403`, 0.9436345020558807],
              UndirectedEdge[83, 196] -> 
             RGBColor[
              0.32540289254677246`, 0.4552688060149441, 0.9419919977610904], 
             UndirectedEdge[109, 233] -> 
             RGBColor[
              0.9057773412404262, 0.5635119739368787, 0.4559259820875775], 
             UndirectedEdge[19, 125] -> 
             RGBColor[
              0.27618503388558474`, 0.4076183601292589, 0.9390397011494167], 
             UndirectedEdge[26, 160] -> 
             RGBColor[
              0.6422952177337565, 0.39805166532506286`, 0.5630541845557195], 
             UndirectedEdge[224, 302] -> 
             RGBColor[
              0.981469271203516, 0.9491536419267372, 0.38251204717050646`], 
             UndirectedEdge[58, 60] -> 
             RGBColor[
              0.3281696676840872, 0.4577472453898289, 0.942165291884663], 
             UndirectedEdge[165, 332] -> 
             RGBColor[
              0.5299851907540822, 0.6293048792717479, 0.9561415220973347], 
             UndirectedEdge[43, 252] -> 
             RGBColor[
              0.2258841865651551, 0.3547489803375645, 0.9361751423079533], 
             UndirectedEdge[292, 304] -> 
             RGBColor[
              0.21505855653612305`, 0.3433705567924642, 0.9355586386928844], 
             UndirectedEdge[63, 257] -> 
             RGBColor[
              0.8905841112547781, 0.5233265159050291, 0.23139995091138454`], 
             UndirectedEdge[94, 355] -> 
             RGBColor[
              0.2455225673247446, 0.37539016366114936`, 0.937293519039831], 
             UndirectedEdge[223, 290] -> 
             RGBColor[
              0.4296004547734099, 0.5464997120753861, 0.9486003596365518], 
             UndirectedEdge[141, 150] -> 
             RGBColor[
              0.3153323622893313, 0.4440199894984804, 0.9414428101102743], 
             UndirectedEdge[131, 306] -> 
             RGBColor[
              0.9464211476308863, 0.8210225463454206, 0.2979449525140816], 
             UndirectedEdge[151, 182] -> 
             RGBColor[
              0.301964914813191, 0.43405917516616493`, 0.9405318273574531], 
             UndirectedEdge[87, 201] -> 
             RGBColor[
              0.2832825017728496, 0.4150782488842294, 0.9394438914458336], 
             UndirectedEdge[72, 379] -> 
             RGBColor[
              0.22434193474233927`, 0.3531279758873717, 0.9360873133482011], 
             UndirectedEdge[23, 378] -> 
             RGBColor[
              0.21097218176330165`, 0.339075517815104, 0.9353259256948219], 
             UndirectedEdge[116, 322] -> 
             RGBColor[
              0.46231873384021377`, 0.5733629399471565, 0.9510928800267155], 
             UndirectedEdge[90, 175] -> 
             RGBColor[
              0.44236897151936794`, 0.5377497638065076, 0.9524065385174674], 
             UndirectedEdge[348, 369] -> 
             RGBColor[
              0.2602045857942335, 0.3908218959663191, 0.9381296382715687], 
             UndirectedEdge[134, 243] -> 
             RGBColor[
              0.2613494095308073, 0.3920251782994754, 0.9381948342897516], 
             UndirectedEdge[211, 372] -> 
             RGBColor[
              0.257077351430105, 0.3875349743715093, 0.9379515469008601], 
             UndirectedEdge[73, 188] -> 
             RGBColor[
              0.2551009475473486, 0.3854576485794885, 0.9378389936235647], 
             UndirectedEdge[55, 228] -> 
             RGBColor[
              0.38569491533937006`, 0.508491282902023, 0.9457971168421706], 
             UndirectedEdge[260, 384] -> 
             RGBColor[
              0.7786909364224193, 0.827038544894287, 0.9785762933282055], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.6353748988917614, 0.714796015346257, 0.9644853457536787], 
             UndirectedEdge[153, 203] -> 
             RGBColor[
              0.3044141682214503, 0.43648600467859244`, 0.9406767090877951], 
             UndirectedEdge[65, 148] -> 
             RGBColor[
              0.5696101053080527, 0.6614741699887192, 0.9592609405218679], 
             UndirectedEdge[42, 366] -> 
             RGBColor[
              0.9167531541973288, 0.7967074998480634, 0.6163680259642358], 
             UndirectedEdge[48, 313] -> 
             RGBColor[
              0.35412562406909687`, 0.4787494368539953, 0.9438733561702934], 
             UndirectedEdge[166, 213] -> 
             RGBColor[
              0.8678686088454421, 0.43805851659629047`, 0.20928664315190354`],
              UndirectedEdge[11, 78] -> 
             RGBColor[
              0.8826533057204708, 0.5284492493821207, 0.22248879223389445`], 
             UndirectedEdge[228, 348] -> 
             RGBColor[
              0.31540619999020275`, 0.44337706024281187`, 0.9414733974605265],
              UndirectedEdge[199, 336] -> 
             RGBColor[
              0.2184046627263886, 0.34688752655381927`, 0.9357491944902996], 
             UndirectedEdge[249, 309] -> 
             RGBColor[
              0.2701798653173872, 0.40130654721440506`, 0.9386977156833087], 
             UndirectedEdge[190, 273] -> 
             RGBColor[
              0.2582701914773965, 0.38878872489163985`, 0.9380194773769047], 
             UndirectedEdge[298, 314] -> 
             RGBColor[
              0.8746210569271528, 0.9028631061103101, 0.9879033312647884], 
             UndirectedEdge[7, 385] -> 
             RGBColor[
              0.4824130197414953, 0.5889482597885108, 0.9528759593947184], 
             UndirectedEdge[27, 194] -> 
             RGBColor[
              0.3427358884343137, 0.47023486345331306`, 0.943098158625497], 
             UndirectedEdge[39, 128] -> 
             RGBColor[
              0.2996526087721707, 0.4306693116276521, 0.9404352763322198], 
             UndirectedEdge[116, 265] -> 
             RGBColor[
              0.5040580192630065, 0.6072487721867599, 0.9543787494712381], 
             UndirectedEdge[231, 313] -> 
             RGBColor[
              0.295746238547153, 0.4281784264805763, 0.9401536828166841], 
             UndirectedEdge[96, 284] -> 
             RGBColor[
              0.2654547891651977, 0.3963401925913225, 0.9384286295865651], 
             UndirectedEdge[279, 300] -> 
             RGBColor[
              0.9178232089422185, 0.7078044246386144, 0.2525247911559355], 
             UndirectedEdge[22, 190] -> 
             RGBColor[
              0.26671069132338054`, 0.3976602253883686, 0.938500151356533], 
             UndirectedEdge[24, 207] -> 
             RGBColor[
              0.9210044213449331, 0.723918476562367, 0.2552656037171254], 
             UndirectedEdge[315, 329] -> 
             RGBColor[
              0.2392065257950246, 0.3687516035532512, 0.9369338298184597], 
             UndirectedEdge[239, 335] -> 
             RGBColor[
              0.3025165492814234, 0.4338365080010965, 0.9405926244808307], 
             UndirectedEdge[142, 300] -> 
             RGBColor[
              0.8557903757137784, 0.38014617017527513`, 0.1991125486638397], 
             UndirectedEdge[13, 88] -> 
             RGBColor[
              0.9770469480723544, 0.9813851840644524, 0.8781922259657269], 
             UndirectedEdge[18, 302] -> 
             RGBColor[
              0.9662417999648014, 0.9637001584466507, 0.6913546401282936], 
             UndirectedEdge[148, 251] -> 
             RGBColor[
              0.723101933884062, 0.7833478892534567, 0.9732241552199159], 
             UndirectedEdge[90, 257] -> 
             RGBColor[
              0.7642064856318851, 0.4724371566214084, 0.5702968707589827], 
             UndirectedEdge[134, 348] -> 
             RGBColor[
              0.24864104476606846`, 0.3786678811748705, 0.9374711117167406], 
             UndirectedEdge[158, 322] -> 
             RGBColor[
              0.5057660137173806, 0.6096426602918618, 0.9542348997632368], 
             UndirectedEdge[40, 385] -> 
             RGBColor[
              0.4573665882056296, 0.5672542996623962, 0.9512800229249427], 
             UndirectedEdge[228, 385] -> 
             RGBColor[
              0.4716391113259436, 0.5796164418313421, 0.9521894554774726], 
             UndirectedEdge[175, 214] -> 
             RGBColor[
              0.5813526175939636, 0.6464089921975442, 0.9229266959429565], 
             UndirectedEdge[7, 41] -> 
             RGBColor[
              0.36511265513899505`, 0.490663963610935, 0.9444856334223808], 
             UndirectedEdge[176, 379] -> 
             RGBColor[
              0.2183904240990045, 0.34687256085365753`, 0.9357483836215341], 
             UndirectedEdge[259, 336] -> 
             RGBColor[
              0.21101362554134806`, 0.339119077853518, 0.9353282858566712], 
             UndirectedEdge[213, 340] -> 
             RGBColor[
              0.9523731210086097, 0.8369128200592044, 0.40569345010895497`], 
             UndirectedEdge[55, 165] -> 
             RGBColor[
              0.4681407137086776, 0.5777449578588358, 0.9516464016172608], 
             UndirectedEdge[108, 231] -> 
             RGBColor[
              0.3381266013166869, 0.4672842792810106, 0.9427663154046388], 
             UndirectedEdge[38, 230] -> 
             RGBColor[
              0.9673242221990019, 0.9014390702190636, 0.3275612028563362], 
             UndirectedEdge[39, 316] -> 
             RGBColor[
              0.26368578568270973`, 0.3944808577699287, 0.9383278874552436], 
             UndirectedEdge[85, 167] -> 
             RGBColor[
              0.2624284668147709, 0.39315933592110447`, 0.9382562850057511], 
             UndirectedEdge[28, 328] -> 
             RGBColor[
              0.2988631492240676, 0.4313905924329009, 0.9403335261361829], 
             UndirectedEdge[79, 120] -> 
             RGBColor[
              0.5785921359057922, 0.6687661870638313, 0.9599680388727843], 
             UndirectedEdge[130, 347] -> 
             RGBColor[
              0.34522783768479254`, 0.47078760076913406`, 0.9433157346482299],
              UndirectedEdge[77, 160] -> 
             RGBColor[
              0.8294213428991457, 0.5471802126352212, 0.5797239248650322], 
             UndirectedEdge[108, 179] -> 
             RGBColor[
              0.3186061180992342, 0.4467670137493473, 0.9416546527633719], 
             UndirectedEdge[318, 373] -> 
             RGBColor[
              0.2370696348066011, 0.3665055956377041, 0.9368121370379159], 
             UndirectedEdge[48, 331] -> 
             RGBColor[
              0.43876768248625253`, 0.5544602462898143, 0.9491788666343646], 
             UndirectedEdge[222, 312] -> 
             RGBColor[
              0.5339420376563727, 0.632517225840949, 0.9564530195798908], 
             UndirectedEdge[292, 353] -> 
             RGBColor[
              0.2106991637542155, 0.3387885585772128, 0.9353103777230984], 
             UndirectedEdge[175, 204] -> 
             RGBColor[
              0.17892957074057536`, 0.30539670201133906`, 0.9335011463998728],
              UndirectedEdge[198, 340] -> 
             RGBColor[
              0.9101338786876096, 0.9267923912389714, 0.7737391772833939], 
             UndirectedEdge[14, 207] -> 
             RGBColor[
              0.9671064480201461, 0.8947970383510977, 0.44882285376347564`], 
             UndirectedEdge[45, 271] -> 
             RGBColor[
              0.30114348847212347`, 0.43385127835713033`, 0.9404610482153953],
              UndirectedEdge[112, 183] -> 
             RGBColor[
              0.2939274002864909, 0.42440137973285763`, 0.9401184016257302], 
             UndirectedEdge[85, 139] -> 
             RGBColor[
              0.2262390695271757, 0.3551219848315275, 0.9361953523676381], 
             UndirectedEdge[45, 97] -> 
             RGBColor[
              0.36889177075057233`, 0.4927124766331557, 0.9447712800460943], 
             UndirectedEdge[130, 181] -> 
             RGBColor[
              0.48885894126290724`, 0.5947515646860737, 0.9532258537292853], 
             UndirectedEdge[63, 90] -> 
             RGBColor[
              0.8321834271804781, 0.8209894828739578, 0.632414864387591], 
             UndirectedEdge[114, 361] -> 
             RGBColor[
              0.342252200873233, 0.470863387125772, 0.9430289854912723], 
             UndirectedEdge[75, 209] -> 
             RGBColor[
              0.24810555583118551`, 0.37810504835234904`, 0.9374406164140838],
              UndirectedEdge[42, 276] -> 
             RGBColor[
              0.8488960037945177, 0.8827904862944987, 0.9853329329150746], 
             UndirectedEdge[205, 358] -> 
             RGBColor[
              0.9819225924478814, 0.9489876509677333, 0.5302516309431803], 
             UndirectedEdge[76, 358] -> 
             RGBColor[
              0.9077605542707283, 0.6337524810989443, 0.26250704350549825`], 
             UndirectedEdge[90, 142] -> 
             RGBColor[
              0.763694887526314, 0.46850478939826945`, 0.5698069638353204], 
             UndirectedEdge[152, 381] -> 
             RGBColor[
              0.588381597564026, 0.6508783727536576, 0.8485015174600479], 
             UndirectedEdge[86, 309] -> 
             RGBColor[
              0.28566340206902835`, 0.417580726053311, 0.9395794801954747], 
             UndirectedEdge[104, 358] -> 
             RGBColor[
              0.9512253799690775, 0.8406018507565884, 0.299039239235954], 
             UndirectedEdge[16, 369] -> 
             RGBColor[
              0.24965722981087085`, 0.3797359560868109, 0.9375289819517311], 
             UndirectedEdge[278, 337] -> 
             RGBColor[
              0.26857947792754067`, 0.39962443859725516`, 0.9386065759890179],
              UndirectedEdge[100, 350] -> 
             RGBColor[
              0.4046784181179114, 0.524933838870203, 0.9470067288527668], 
             UndirectedEdge[90, 202] -> 
             RGBColor[
              0.7810727137045386, 0.6020783764160916, 0.5864479898090358], 
             UndirectedEdge[126, 367] -> 
             RGBColor[
              0.21567822148491766`, 0.34402186394267437`, 0.935593927695006], 
             UndirectedEdge[278, 327] -> 
             RGBColor[
              0.28550387867049365`, 0.4165027145117478, 0.9396037276662406], 
             UndirectedEdge[10, 200] -> 
             RGBColor[
              0.31629276558560215`, 0.4448572861787412, 0.9415038068416022], 
             UndirectedEdge[149, 299] -> 
             RGBColor[
              0.21717366869177715`, 0.345593673773913, 0.9356790912011209], 
             UndirectedEdge[57, 284] -> 
             RGBColor[
              0.2586027566797, 0.38913827200511253`, 0.9380384164731898], 
             UndirectedEdge[125, 313] -> 
             RGBColor[
              0.2803971559769777, 0.4120455675112783, 0.9392795752712453], 
             UndirectedEdge[125, 196] -> 
             RGBColor[
              0.2879550374250095, 0.4199893801105207, 0.9397099854388271], 
             UndirectedEdge[21, 210] -> 
             RGBColor[
              0.30642042589023155`, 0.43901202359644165`, 0.9407756825511414],
              UndirectedEdge[186, 374] -> 
             RGBColor[
              0.2622856992899031, 0.3930092782004845, 0.9382481546064155], 
             UndirectedEdge[6, 74] -> 
             RGBColor[
              0.909010509687477, 0.9256078266033538, 0.7502192883025007], 
             UndirectedEdge[7, 312] -> 
             RGBColor[
              0.42618108450073044`, 0.5432966415402436, 0.9484491754681994], 
             UndirectedEdge[238, 299] -> 
             RGBColor[
              0.22167590498284873`, 0.3503258095740973, 0.9359354868974357], 
             UndirectedEdge[155, 239] -> 
             RGBColor[
              0.3145302695292589, 0.4464636896954298, 0.9412767880762385], 
             UndirectedEdge[108, 331] -> 
             RGBColor[
              0.40983077437371584`, 0.5293965508940257, 0.9473350324373369], 
             UndirectedEdge[55, 87] -> 
             RGBColor[
              0.34683568506465234`, 0.47311300029375225`, 0.9433840322411374],
              UndirectedEdge[186, 288] -> 
             RGBColor[
              0.2467468316416792, 0.3766769430810886, 0.9373632390815438], 
             UndirectedEdge[178, 371] -> 
             RGBColor[
              0.25801702472850174`, 0.38852263058685255`, 0.9380050599050818],
              UndirectedEdge[212, 238] -> 
             RGBColor[
              0.22006014114382055`, 0.3486275393339343, 0.9358434715371114], 
             UndirectedEdge[292, 329] -> 
             RGBColor[
              0.22307875219905648`, 0.35180029094398246`, 0.9360153769710722],
              UndirectedEdge[268, 338] -> 
             RGBColor[
              0.9058036870049794, 0.5621593672391498, 0.39196047146640556`], 
             UndirectedEdge[68, 309] -> 
             RGBColor[
              0.27375753584035556`, 0.40506690577145743`, 0.9389014587269024],
              UndirectedEdge[129, 309] -> 
             RGBColor[
              0.25423745991444247`, 0.38455006832902616`, 0.9377898192802863],
              UndirectedEdge[137, 330] -> 
             RGBColor[
              0.22316402213431713`, 0.35188991505236755`, 0.9360202329677398],
              UndirectedEdge[111, 400] -> 
             RGBColor[
              0.631844529693345, 0.5164916201579837, 0.581343351224306], 
             UndirectedEdge[62, 370] -> 
             RGBColor[
              0.5051424414592518, 0.5868980307983699, 0.9586362110924191], 
             UndirectedEdge[163, 280] -> 
             RGBColor[
              0.24199322930997053`, 0.37168060563466715`, 0.9370925284610774],
              UndirectedEdge[316, 383] -> 
             RGBColor[
              0.2672579164630078, 0.3982353937061947, 0.9385313150186878], 
             UndirectedEdge[307, 314] -> 
             RGBColor[
              0.9555259778682477, 0.9659228619523936, 0.9435306567958934], 
             UndirectedEdge[126, 259] -> 
             RGBColor[
              0.2115312190038542, 0.33966310139993294`, 0.93535776203865], 
             UndirectedEdge[44, 372] -> 
             RGBColor[
              0.27471702429732014`, 0.4060753889748091, 0.9389561001750906], 
             UndirectedEdge[202, 279] -> 
             RGBColor[
              0.9009946329017078, 0.6281412966873632, 0.2383554119012628], 
             UndirectedEdge[148, 312] -> 
             RGBColor[
              0.5434225996528742, 0.6402139731641597, 0.9571993641486982], 
             UndirectedEdge[109, 358] -> 
             RGBColor[
              0.9813365611926588, 0.9487453119833825, 0.5399636854424916], 
             UndirectedEdge[142, 275] -> 
             RGBColor[
              0.906842307128124, 0.5789554407018784, 0.47443924955803846`], 
             UndirectedEdge[296, 375] -> 
             RGBColor[
              0.2781834406546093, 0.40971881234981117`, 0.9391535074585348], 
             UndirectedEdge[92, 195] -> 
             RGBColor[
              0.26667927398787117`, 0.3976272037767742, 0.9384983621857534], 
             UndirectedEdge[178, 248] -> 
             RGBColor[
              0.230098166399185, 0.35917814032488304`, 0.9364151222254768], 
             UndirectedEdge[41, 222] -> 
             RGBColor[
              0.4728736082946373, 0.5798845479116403, 0.9524894775340721], 
             UndirectedEdge[154, 356] -> 
             RGBColor[
              0.4742682171286211, 0.5834424825573183, 0.951929030274608], 
             UndirectedEdge[70, 133] -> 
             RGBColor[
              0.28753417910083867`, 0.4195470313278583, 0.9396860181798696], 
             UndirectedEdge[7, 80] -> 
             RGBColor[
              0.36191069619973304`, 0.48789058771288196`, 0.9442816074301521],
              UndirectedEdge[152, 261] -> 
             RGBColor[
              0.18153226782756765`, 0.3081323016702944, 0.9336493661486316], 
             UndirectedEdge[95, 229] -> 
             RGBColor[
              0.2643373458997902, 0.3951656888693841, 0.9383649928457094], 
             UndirectedEdge[30, 204] -> 
             RGBColor[
              0.17892701604158556`, 0.30539401686072354`, 0.9335010009135446],
              UndirectedEdge[133, 223] -> 
             RGBColor[
              0.3756627076897743, 0.49871942307299955`, 0.945202383630783], 
             UndirectedEdge[298, 306] -> 
             RGBColor[
              0.8969031243202032, 0.8868893383314866, 0.6612189641553454], 
             UndirectedEdge[40, 96] -> 
             RGBColor[
              0.313111809733841, 0.4436046951713676, 0.9412461018545393], 
             UndirectedEdge[122, 146] -> 
             RGBColor[
              0.49070941162852855`, 0.5972227097318854, 0.9531038334374095], 
             UndirectedEdge[223, 267] -> 
             RGBColor[
              0.5126330687833186, 0.6152176449516955, 0.954775499492879], 
             UndirectedEdge[54, 322] -> 
             RGBColor[
              0.48020380618298864`, 0.5888540906805946, 0.9522325010212487], 
             UndirectedEdge[41, 154] -> 
             RGBColor[
              0.3854891726816393, 0.5083130789528232, 0.945784007101951], 
             UndirectedEdge[245, 353] -> 
             RGBColor[
              0.220139248365585, 0.34871068603969635`, 0.9358479765763623], 
             UndirectedEdge[26, 62] -> 
             RGBColor[
              0.31709055637755623`, 0.43703130766003234`, 0.9418781709758536],
              UndirectedEdge[217, 269] -> 
             RGBColor[
              0.9079422992480835, 0.582007875379239, 0.32768831635612294`], 
             UndirectedEdge[172, 347] -> 
             RGBColor[
              0.29073737323035515`, 0.422913791452218, 0.9398684353468445], 
             UndirectedEdge[63, 261] -> 
             RGBColor[
              0.5690047111878296, 0.5889104173173967, 0.6135243178829187], 
             UndirectedEdge[195, 369] -> 
             RGBColor[
              0.2515743275380513, 0.381750947349094, 0.9376381578312021], 
             UndirectedEdge[65, 180] -> 
             RGBColor[
              0.4408011041078431, 0.5545376633487222, 0.9497736818591127], 
             UndirectedEdge[49, 211] -> 
             RGBColor[
              0.25920679804656954`, 0.3897731577801271, 0.9380728157354339], 
             UndirectedEdge[285, 387] -> 
             RGBColor[
              0.2661419288540897, 0.3970624199715206, 0.9384677611753156], 
             UndirectedEdge[329, 388] -> 
             RGBColor[
              0.22925196747727483`, 0.358288731605845, 0.9363669324487132], 
             UndirectedEdge[38, 102] -> 
             RGBColor[
              0.8925441235088332, 0.5227994562196083, 0.24385895757801979`], 
             UndirectedEdge[92, 188] -> 
             RGBColor[
              0.27737488016395806`, 0.40886896400844064`, 0.9391074611347503],
              UndirectedEdge[114, 153] -> 
             RGBColor[
              0.32315432075329853`, 0.4543217632532496, 0.9418120854576224], 
             UndirectedEdge[326, 337] -> 
             RGBColor[
              0.312066783946898, 0.44249908551128714`, 0.9411868535891006], 
             UndirectedEdge[38, 221] -> 
             RGBColor[
              0.9438250637656209, 0.9183985790902189, 0.6570073333224926], 
             UndirectedEdge[350, 394] -> 
             RGBColor[
              0.3958053510234857, 0.5172484341263308, 0.9464413448636552], 
             UndirectedEdge[286, 349] -> 
             RGBColor[
              0.5858145101958898, 0.6731289759492968, 0.9614748008949803], 
             UndirectedEdge[246, 320] -> 
             RGBColor[
              0.5768484382747107, 0.6660576659405324, 0.9606094815615308], 
             UndirectedEdge[322, 362] -> 
             RGBColor[
              0.45653757665465905`, 0.5683555921624378, 0.9507245098029286], 
             UndirectedEdge[80, 348] -> 
             RGBColor[
              0.2986858104115632, 0.42889469918101, 0.9404079890218355], 
             UndirectedEdge[78, 230] -> 
             RGBColor[
              0.9053505911840212, 0.6146233921482407, 0.26060988945584945`], 
             UndirectedEdge[248, 329] -> 
             RGBColor[
              0.22567335718883677`, 0.3545273852956994, 0.9361631358868661], 
             UndirectedEdge[43, 330] -> 
             RGBColor[
              0.2261035990920075, 0.35497959681484403`, 0.9361876375267658], 
             UndirectedEdge[63, 217] -> 
             RGBColor[
              0.8906933611547283, 0.5241662585096577, 0.23150456873895697`], 
             UndirectedEdge[79, 136] -> 
             RGBColor[
              0.6046940354323059, 0.6899568849766287, 0.9620228760179198], 
             UndirectedEdge[159, 243] -> 
             RGBColor[
              0.3099032733211534, 0.44096065205359114`, 0.9410367126469893], 
             UndirectedEdge[1, 327] -> 
             RGBColor[
              0.3392875835527789, 0.4682955846087937, 0.9428400826971212], 
             UndirectedEdge[304, 353] -> 
             RGBColor[
              0.21473904123945592`, 0.3430347259572272, 0.9355404427694197], 
             UndirectedEdge[240, 329] -> 
             RGBColor[
              0.23717266786335917`, 0.3666138899130299, 0.9368180046180745], 
             UndirectedEdge[10, 311] -> 
             RGBColor[
              0.4406499577202704, 0.5542970021663628, 0.9497943740304772], 
             UndirectedEdge[353, 378] -> 
             RGBColor[
              0.20945304207089746`, 0.33747880567936756`, 0.9352394129367053],
              UndirectedEdge[167, 243] -> 
             RGBColor[
              0.28596070978623506`, 0.41789321531449325`, 0.9395964114301423],
              UndirectedEdge[169, 292] -> 
             RGBColor[
              0.21585857380573317`, 0.34421142566684904`, 0.9356041984928691],
              UndirectedEdge[211, 347] -> 
             RGBColor[
              0.27136364126610246`, 0.4025507707922349, 0.9387651299723484], 
             UndirectedEdge[224, 340] -> 
             RGBColor[
              0.9847198182906963, 0.959331532205712, 0.46205791346696695`], 
             UndirectedEdge[144, 233] -> 
             RGBColor[
              0.8479481693127158, 0.33804742930989184`, 0.1923147220140613], 
             UndirectedEdge[273, 394] -> 
             RGBColor[
              0.3171526741702776, 0.4460438307034582, 0.9415424253765902], 
             UndirectedEdge[93, 94] -> 
             RGBColor[
              0.2526810398598759, 0.3829141721689455, 0.9377011834606958], 
             UndirectedEdge[358, 366] -> 
             RGBColor[
              0.934928559139148, 0.7751416322731404, 0.28588252947049914`], 
             UndirectedEdge[245, 329] -> 
             RGBColor[
              0.232518836810426, 0.36172241840646596`, 0.936552975824336], 
             UndirectedEdge[44, 93] -> 
             RGBColor[
              0.2715973273730923, 0.4027963897072362, 0.9387784380504338], 
             UndirectedEdge[218, 314] -> 
             RGBColor[
              0.9179378774680893, 0.9374027630058823, 0.9920349282773651], 
             UndirectedEdge[133, 346] -> 
             RGBColor[
              0.32114511749891506`, 0.4515193689112592, 0.9417229503460453], 
             UndirectedEdge[143, 272] -> 
             RGBColor[
              0.635830587523557, 0.7151635871324875, 0.9645228442451073], 
             UndirectedEdge[272, 346] -> 
             RGBColor[
              0.4960244700071036, 0.5987224642834593, 0.954329185667129], 
             UndirectedEdge[61, 269] -> 
             RGBColor[
              0.9932024163292561, 0.9878689808064407, 0.5015031511422814], 
             UndirectedEdge[158, 362] -> 
             RGBColor[
              0.4538874638081069, 0.5662041111673836, 0.9505158832119648], 
             UndirectedEdge[294, 393] -> 
             RGBColor[
              0.21778977524310467`, 0.34624124082276975`, 0.9357141775577711],
              UndirectedEdge[17, 298] -> 
             RGBColor[
              0.6794733687434446, 0.7479201915203444, 0.969798835244192], 
             UndirectedEdge[83, 179] -> 
             RGBColor[
              0.3112624132414147, 0.4404062657068423, 0.9411867183836149], 
             UndirectedEdge[223, 398] -> 
             RGBColor[
              0.696746297429305, 0.7610076864937902, 0.9687930758283795], 
             UndirectedEdge[52, 272] -> 
             RGBColor[
              0.5168312067307885, 0.6167442138565202, 0.9556549725324873], 
             UndirectedEdge[52, 174] -> 
             RGBColor[
              0.5576254346896334, 0.6486129747855855, 0.95972095993169], 
             UndirectedEdge[63, 317] -> 
             RGBColor[
              0.9745940579826633, 0.9311354530743134, 0.5492576472683819], 
             UndirectedEdge[145, 280] -> 
             RGBColor[
              0.23851863392834902`, 0.36802858558651175`, 0.9368946553942974],
              UndirectedEdge[152, 317] -> 
             RGBColor[
              0.5871216146224013, 0.6503573374272111, 0.8693826955340949], 
             UndirectedEdge[102, 391] -> 
             RGBColor[
              0.8198439128231849, 0.15353458638285297`, 0.16663585937096298`],
              UndirectedEdge[168, 251] -> 
             RGBColor[
              0.7462331666341901, 0.8017011358685895, 0.9753362046447762], 
             UndirectedEdge[89, 245] -> 
             RGBColor[
              0.22424083690782642`, 0.3530217156533258, 0.9360815559760864], 
             UndirectedEdge[293, 330] -> 
             RGBColor[
              0.21800150715905772`, 0.3464637844910152, 0.9357262353771553], 
             UndirectedEdge[166, 247] -> 
             RGBColor[
              0.8658883217742317, 0.43020733825048896`, 0.20769325769109587`],
              UndirectedEdge[8, 182] -> 
             RGBColor[
              0.29920713316336395`, 0.4316705233112208, 0.9403561039493367], 
             UndirectedEdge[2, 215] -> 
             RGBColor[
              0.8188696957350476, 0.14604632693877936`, 0.16570294798714186`],
              UndirectedEdge[61, 107] -> 
             RGBColor[
              0.9162817916828967, 0.6453128669663495, 0.3511545314597267], 
             UndirectedEdge[192, 361] -> 
             RGBColor[
              0.35005813253929685`, 0.4776244927973833, 0.9435263725545195], 
             UndirectedEdge[71, 321] -> 
             RGBColor[
              0.8444532383444727, 0.878825868324395, 0.985021184343525], 
             UndirectedEdge[26, 389] -> 
             RGBColor[
              0.31710049015279534`, 0.4370417486876464, 0.9418787366896577], 
             UndirectedEdge[134, 263] -> 
             RGBColor[
              0.24820523859568883`, 0.3782098212580943, 0.9374462932000549], 
             UndirectedEdge[105, 282] -> 
             RGBColor[
              0.5321029414738284, 0.6299784125013272, 0.956625284939209], 
             UndirectedEdge[323, 340] -> 
             RGBColor[
              0.9119941865056833, 0.9282757501963927, 0.7739166151037982], 
             UndirectedEdge[311, 323] -> 
             RGBColor[
              0.6747921418079339, 0.7440706990607763, 0.9694867808520644], 
             UndirectedEdge[29, 365] -> 
             RGBColor[
              0.24833496351636752`, 0.37834617037476265`, 0.9374536808423768],
              UndirectedEdge[321, 384] -> 
             RGBColor[
              0.7831071512596195, 0.8304885254895837, 0.9790164603513036], 
             UndirectedEdge[115, 195] -> 
             RGBColor[
              0.2421504028292495, 0.3718458049688061, 0.937101479260483], 
             UndirectedEdge[162, 359] -> 
             RGBColor[
              0.24582605828944576`, 0.3757091519074889, 0.9373108024012962], 
             UndirectedEdge[106, 295] -> 
             RGBColor[
              0.5954410834145789, 0.6666014753537031, 0.9545919964182874], 
             UndirectedEdge[24, 242] -> 
             RGBColor[
              0.9102499321760205, 0.681280510728698, 0.24661228929151274`], 
             UndirectedEdge[109, 286] -> 
             RGBColor[
              0.8601731647723879, 0.8889489686867593, 0.8604250468482817], 
             UndirectedEdge[287, 367] -> 
             RGBColor[
              0.23976404440825078`, 0.3693375909644736, 0.936965579678708], 
             UndirectedEdge[74, 140] -> 
             RGBColor[
              0.7482992359076605, 0.8033342207586809, 0.9755370742792053], 
             UndirectedEdge[168, 394] -> 
             RGBColor[
              0.5145092206731405, 0.613750519132451, 0.9559228612077943], 
             UndirectedEdge[68, 249] -> 
             RGBColor[
              0.2731469520224531, 0.4044251434655919, 0.9388666868817508], 
             UndirectedEdge[389, 400] -> 
             RGBColor[
              0.2843495171102985, 0.40872323643536973`, 0.9397784081644269], 
             UndirectedEdge[267, 346] -> 
             RGBColor[
              0.4581154785924594, 0.5680175907899552, 0.9512960662081413], 
             UndirectedEdge[16, 392] -> 
             RGBColor[
              0.24490486142793333`, 0.37474091559878486`, 0.9372583416028217],
              UndirectedEdge[13, 191] -> 
             RGBColor[
              0.8213167457883995, 0.8607762667176537, 0.9574101949991654], 
             UndirectedEdge[312, 327] -> 
             RGBColor[
              0.39077465425622554`, 0.5126293712413812, 0.9461931090416965], 
             UndirectedEdge[260, 291] -> 
             RGBColor[
              0.7527228069990448, 0.8067520448236535, 0.9759880328732503], 
             UndirectedEdge[83, 344] -> 
             RGBColor[
              0.33675515918736176`, 0.4661021259068189, 0.9426787188558917], 
             UndirectedEdge[200, 288] -> 
             RGBColor[
              0.25784282293400623`, 0.38833953345580596`, 0.9379951393705938],
              UndirectedEdge[297, 332] -> 
             RGBColor[
              0.736930313911651, 0.7933926635631983, 0.9655671808709663], 
             UndirectedEdge[189, 241] -> 
             RGBColor[
              0.2957543458619668, 0.428186947782479, 0.9401541445162689], 
             UndirectedEdge[276, 358] -> 
             RGBColor[
              0.8670714087363368, 0.8612246187195758, 0.654847436421338], 
             UndirectedEdge[11, 102] -> 
             RGBColor[
              0.8713798486298555, 0.4417965181232547, 0.21169331699237254`], 
             UndirectedEdge[96, 243] -> 
             RGBColor[
              0.2876417202462759, 0.4196600638902152, 0.9396921424890095], 
             UndirectedEdge[171, 397] -> 
             RGBColor[
              0.26128106780929927`, 0.39195334681705507`, 0.9381909423298143],
              UndirectedEdge[314, 385] -> 
             RGBColor[
              0.7506165131369036, 0.8049365561291917, 0.9762521831517132], 
             UndirectedEdge[11, 213] -> 
             RGBColor[
              0.9172153878071567, 0.709493629531714, 0.2522477617062842], 
             UndirectedEdge[68, 129] -> 
             RGBColor[
              0.25720454661950837`, 0.38766866458021304`, 0.9379587904787283],
              UndirectedEdge[137, 277] -> 
             RGBColor[
              0.23968446191505444`, 0.36925394471830275`, 0.9369610475734522],
              UndirectedEdge[35, 327] -> 
             RGBColor[
              0.29981659218631795`, 0.43154628389532945`, 0.9404188155272046],
              UndirectedEdge[155, 183] -> 
             RGBColor[
              0.2817396246657633, 0.4134565872206231, 0.9393560268770672], 
             UndirectedEdge[63, 256] -> 
             RGBColor[
              0.5919347091448884, 0.6130112990161062, 0.6148301473446811], 
             UndirectedEdge[144, 358] -> 
             RGBColor[
              0.9235073892649484, 0.7232807673563957, 0.2763524253689754], 
             UndirectedEdge[192, 332] -> 
             RGBColor[
              0.43585567576042195`, 0.5499313562155932, 0.9495477612304457], 
             UndirectedEdge[149, 259] -> 
             RGBColor[
              0.21561966255991427`, 0.3439603147996455, 0.9355905928508573], 
             UndirectedEdge[146, 165] -> 
             RGBColor[
              0.5340400056803238, 0.6325967606962016, 0.956460731981605], 
             UndirectedEdge[164, 280] -> 
             RGBColor[
              0.2407758584059484, 0.37040107162876656`, 0.9370232009890322], 
             UndirectedEdge[65, 105] -> 
             RGBColor[
              0.46633814789011974`, 0.5766565671437895, 0.9514008797073982], 
             UndirectedEdge[73, 369] -> 
             RGBColor[
              0.2502849628040927, 0.38039574326325765`, 0.9375647304170474], 
             UndirectedEdge[187, 281] -> 
             RGBColor[
              0.7379639441479849, 0.795257108792612, 0.9745741950769791], 
             UndirectedEdge[53, 253] -> 
             RGBColor[
              0.31547986955209806`, 0.4458714425532633, 0.9413890964198188], 
             UndirectedEdge[132, 191] -> 
             RGBColor[
              0.7390378619070974, 0.7960612617083893, 0.9746240454395679], 
             UndirectedEdge[29, 273] -> 
             RGBColor[
              0.25793330326133057`, 0.388434634016608, 0.9380002920913812], 
             UndirectedEdge[138, 366] -> 
             RGBColor[
              0.8603116610551809, 0.39715139303420033`, 0.20274719460083632`],
              UndirectedEdge[229, 309] -> 
             RGBColor[
              0.25884330525935606`, 0.3893911038139919, 0.9380521153589414], 
             UndirectedEdge[274, 287] -> 
             RGBColor[
              0.2454706833388167, 0.37533563030230443`, 0.937290564323588], 
             UndirectedEdge[251, 312] -> 
             RGBColor[
              0.6426365090387243, 0.7180224324379316, 0.9668896222215277], 
             UndirectedEdge[339, 360] -> 
             RGBColor[
              0.3380761124684098, 0.46724626924582036`, 0.942762888830887], 
             UndirectedEdge[150, 365] -> 
             RGBColor[
              0.26342074735738313`, 0.39420228568561005`, 0.9383127939147053],
              UndirectedEdge[61, 300] -> 
             RGBColor[
              0.9416713408004723, 0.7907793854302443, 0.3735219082012329], 
             UndirectedEdge[62, 389] -> 
             RGBColor[
              0.17907819285502502`, 0.305552913276812, 0.9335096102094239], 
             UndirectedEdge[374, 399] -> 
             RGBColor[
              0.255491371590293, 0.38586800900293716`, 0.9378612276952298], 
             UndirectedEdge[27, 51] -> 
             RGBColor[
              0.33517005330446453`, 0.4636817173337682, 0.9426160703012283], 
             UndirectedEdge[58, 159] -> 
             RGBColor[
              0.31512279365295653`, 0.44644669885901933`, 0.9413339566082971],
              UndirectedEdge[57, 153] -> 
             RGBColor[
              0.2953190920495516, 0.42692650296079127`, 0.9401587579547649], 
             UndirectedEdge[84, 264] -> 
             RGBColor[
              0.18447901438019912`, 0.31122951913163255`, 0.9338171790054831],
              UndirectedEdge[159, 201] -> 
             RGBColor[
              0.30393044061377905`, 0.43468282617867443`, 0.9406965686603185],
              UndirectedEdge[80, 87] -> 
             RGBColor[
              0.3122775575094636, 0.4431804871474425, 0.9411820189118731], 
             UndirectedEdge[39, 288] -> 
             RGBColor[
              0.2590590279232666, 0.38961784201136873`, 0.9380644004455181], 
             UndirectedEdge[91, 365] -> 
             RGBColor[
              0.259430965008946, 0.3900087714705911, 0.9380855817123159], 
             UndirectedEdge[5, 384] -> 
             RGBColor[
              0.7949354326614759, 0.8399023141409853, 0.9801493658443617], 
             UndirectedEdge[156, 381] -> 
             RGBColor[
              0.5895532840978516, 0.6521098895899253, 0.8485682432747944], 
             UndirectedEdge[2, 197] -> 
             RGBColor[
              0.9036013141673853, 0.5662229928500411, 0.5006917858198119], 
             UndirectedEdge[238, 293] -> 
             RGBColor[
              0.22022708573500543`, 0.3488030086841681, 0.935852978784607], 
             UndirectedEdge[85, 325] -> 
             RGBColor[
              0.22643759197523877`, 0.355330644511492, 0.9362066579273677], 
             UndirectedEdge[146, 332] -> 
             RGBColor[
              0.53127642233297, 0.6303531592368088, 0.9562431725771618], 
             UndirectedEdge[197, 204] -> 
             RGBColor[
              0.5838392169462935, 0.6475052215433456, 0.8847911904815791], 
             UndirectedEdge[20, 130] -> 
             RGBColor[
              0.4090322853711047, 0.5287049398531881, 0.9472841534241666], 
             UndirectedEdge[167, 348] -> 
             RGBColor[
              0.2732523450214962, 0.4045359181898883, 0.9388726888571313], 
             UndirectedEdge[83, 237] -> 
             RGBColor[
              0.4656503502316991, 0.5743478756221865, 0.9518303486289299], 
             UndirectedEdge[178, 334] -> 
             RGBColor[
              0.25269374017822266`, 0.3829275210087747, 0.9377019067250372], 
             UndirectedEdge[178, 388] -> 
             RGBColor[
              0.23367677668762307`, 0.36293948663502873`, 0.9366189187873238],
              UndirectedEdge[115, 184] -> 
             RGBColor[
              0.22818450918176583`, 0.35716676525650004`, 0.936306142277947], 
             UndirectedEdge[165, 385] -> 
             RGBColor[
              0.5540849096952511, 0.648870116788155, 0.9580387402525627], 
             UndirectedEdge[202, 257] -> 
             RGBColor[
              0.8394733977788387, 0.30441540944716294`, 0.18543307633282935`],
              UndirectedEdge[35, 57] -> 
             RGBColor[
              0.2771242370211076, 0.4086055221736117, 0.9390931873785582], 
             UndirectedEdge[115, 206] -> 
             RGBColor[
              0.23508408472910247`, 0.364418656615107, 0.9366990628983605], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.34476855469957235`, 0.4730429263345264, 0.9431893253319623], 
             UndirectedEdge[61, 98] -> 
             RGBColor[
              0.985458002900472, 0.9620883573989745, 0.44224268706809605`], 
             UndirectedEdge[33, 173] -> 
             RGBColor[
              0.20265449886636056`, 0.33033310571886365`, 0.9348522459587503],
              UndirectedEdge[6, 185] -> 
             RGBColor[
              0.9085190133388343, 0.5856402039031354, 0.34380931507742224`], 
             UndirectedEdge[300, 363] -> 
             RGBColor[
              0.8762546358068509, 0.5309830273105506, 0.21845617365184725`], 
             UndirectedEdge[34, 270] -> 
             RGBColor[
              0.28093807902462586`, 0.41228653639826196`, 0.9393223741835017],
              UndirectedEdge[162, 179] -> 
             RGBColor[
              0.25786357675267113`, 0.38836134703509095`, 0.9379963212698641],
              UndirectedEdge[11, 250] -> 
             RGBColor[
              0.9558449394073578, 0.8618308276345842, 0.5510217386219683], 
             UndirectedEdge[66, 314] -> 
             RGBColor[
              0.9492974340005453, 0.9317668939083206, 0.6707765260947278], 
             UndirectedEdge[153, 327] -> 
             RGBColor[
              0.31801144721476193`, 0.44986726468250904`, 0.9414843861034113],
              UndirectedEdge[153, 392] -> 
             RGBColor[
              0.28268998646480836`, 0.4136525122596839, 0.9394395490748012], 
             UndirectedEdge[110, 369] -> 
             RGBColor[
              0.2565159464057226, 0.38694490209574905`, 0.9379195757152459], 
             UndirectedEdge[321, 398] -> 
             RGBColor[
              0.8786059330927678, 0.9059622064053712, 0.9849470713031456], 
             UndirectedEdge[188, 278] -> 
             RGBColor[
              0.2597507710467335, 0.39034490789317966`, 0.9381037941930572], 
             UndirectedEdge[213, 289] -> 
             RGBColor[
              0.9043607109741805, 0.6566643735845665, 0.24180812561664938`], 
             UndirectedEdge[236, 263] -> 
             RGBColor[
              0.2563029052327246, 0.3867209823153376, 0.9379074433356098], 
             UndirectedEdge[93, 383] -> 
             RGBColor[
              0.2627372188358315, 0.39348385387124796`, 0.9382738679765928], 
             UndirectedEdge[56, 286] -> 
             RGBColor[
              0.5885924555434128, 0.6755350925857282, 0.9616518091160838], 
             UndirectedEdge[25, 144] -> 
             RGBColor[
              0.8635746104404736, 0.45815910336800225`, 0.20727861968554306`],
              UndirectedEdge[143, 331] -> 
             RGBColor[
              0.5383683584932644, 0.6360774364876114, 0.9568106700316372], 
             UndirectedEdge[76, 257] -> 
             RGBColor[
              0.8347758028344946, 0.2683076362057045, 0.1809346541089509], 
             UndirectedEdge[91, 189] -> 
             RGBColor[
              0.28158397795101814`, 0.4132929926548542, 0.9393471630269211], 
             UndirectedEdge[133, 145] -> 
             RGBColor[
              0.26764114093786784`, 0.3986381869271076, 0.9385531390856012], 
             UndirectedEdge[207, 230] -> 
             RGBColor[
              0.9543565255231943, 0.8529328333505086, 0.30199072149137773`], 
             UndirectedEdge[238, 336] -> 
             RGBColor[
              0.22011483416770328`, 0.34868502516977307`, 0.9358465862239105],
              UndirectedEdge[123, 306] -> 
             RGBColor[
              0.9723361250736168, 0.9460422517382365, 0.6339056761634236], 
             UndirectedEdge[272, 338] -> 
             RGBColor[
              0.8206526510459409, 0.8571827716487312, 0.7925776008366022], 
             UndirectedEdge[11, 289] -> 
             RGBColor[
              0.9106079850234978, 0.6814327334094423, 0.24683482895909917`], 
             UndirectedEdge[215, 300] -> 
             RGBColor[
              0.8546424874802127, 0.37132299820425807`, 0.1980133295950229], 
             UndirectedEdge[224, 289] -> 
             RGBColor[
              0.9367074082562672, 0.779083085731074, 0.29817258897466137`], 
             UndirectedEdge[65, 161] -> 
             RGBColor[
              0.4733844161827434, 0.5827596905831183, 0.9518498616922337], 
             UndirectedEdge[14, 247] -> 
             RGBColor[
              0.9506823086964485, 0.8296807989526216, 0.43560760573952945`], 
             UndirectedEdge[150, 226] -> 
             RGBColor[
              0.2546174021107136, 0.38494941166703367`, 0.9378114564262897], 
             UndirectedEdge[15, 180] -> 
             RGBColor[
              0.33506546922916314`, 0.4641869420312098, 0.9425875907675709], 
             UndirectedEdge[7, 114] -> 
             RGBColor[
              0.359141437487956, 0.48549199500373064`, 0.9441051527137969], 
             UndirectedEdge[108, 313] -> 
             RGBColor[
              0.3251887159565602, 0.4536857414582067, 0.9420295219732657], 
             UndirectedEdge[227, 315] -> 
             RGBColor[
              0.2390981188616284, 0.3686376609928552, 0.9369276562039764], 
             UndirectedEdge[174, 384] -> 
             RGBColor[
              0.7385166114389616, 0.7956540568810313, 0.9745720920642666], 
             UndirectedEdge[104, 138] -> 
             RGBColor[
              0.8766084818851104, 0.4626116115176483, 0.21590390436629117`], 
             UndirectedEdge[313, 344] -> 
             RGBColor[
              0.30171850127564737`, 0.43335702114888963`, 0.940534020647694], 
             UndirectedEdge[255, 374] -> 
             RGBColor[
              0.2682893522658295, 0.3993194981317673, 0.938590053761786], 
             UndirectedEdge[87, 167] -> 
             RGBColor[
              0.28684409211939654`, 0.41882170615632086`, 0.9396467187471687],
              UndirectedEdge[114, 312] -> 
             RGBColor[
              0.3959175277947622, 0.5170838698121216, 0.9465208083959076], 
             UndirectedEdge[50, 265] -> 
             RGBColor[
              0.5230211648142513, 0.6236511692879999, 0.9555932884652836], 
             UndirectedEdge[310, 345] -> 
             RGBColor[
              0.19226277251810686`, 0.3194107424533439, 0.9342604525163987], 
             UndirectedEdge[315, 334] -> 
             RGBColor[
              0.25233663141566864`, 0.38255217705732714`, 0.9376815699093048],
              UndirectedEdge[102, 302] -> 
             RGBColor[
              0.9032870347441282, 0.5590378183717704, 0.2855931390985828], 
             UndirectedEdge[172, 211] -> 
             RGBColor[
              0.2820509294380053, 0.413783788274112, 0.9393737552233123], 
             UndirectedEdge[264, 381] -> 
             RGBColor[
              0.5915890217554157, 0.6542495789412477, 0.8486841755227887], 
             UndirectedEdge[270, 397] -> 
             RGBColor[
              0.2494683482405557, 0.3795374295806264, 0.9375182254257268], 
             UndirectedEdge[48, 290] -> 
             RGBColor[
              0.4152883060919923, 0.5341235905648768, 0.9476827815325197], 
             UndirectedEdge[224, 323] -> 
             RGBColor[
              0.9029358765369997, 0.8985069119905342, 0.6718086867166897], 
             UndirectedEdge[10, 339] -> 
             RGBColor[
              0.3638431893323356, 0.48956441613441326`, 0.9444047441837249], 
             UndirectedEdge[254, 320] -> 
             RGBColor[
              0.5897027051719504, 0.6767516973442059, 0.9615500313265857], 
             UndirectedEdge[92, 392] -> 
             RGBColor[
              0.26780652703776464`, 0.39881201820418366`, 0.9385625575793235],
              UndirectedEdge[166, 224] -> 
             RGBColor[
              0.9002153061275288, 0.5604772287427979, 0.2656511065099155], 
             UndirectedEdge[108, 344] -> 
             RGBColor[
              0.3440988640451813, 0.47246287394932385`, 0.9431466532356487], 
             UndirectedEdge[180, 271] -> 
             RGBColor[
              0.3365289525569892, 0.46572515579895724`, 0.942670933978061], 
             UndirectedEdge[104, 207] -> 
             RGBColor[
              0.9368649528111581, 0.7873976069432023, 0.2680582629430743], 
             UndirectedEdge[45, 266] -> 
             RGBColor[
              0.2752485126978604, 0.4066340169820878, 0.9389863676532347], 
             UndirectedEdge[59, 373] -> 
             RGBColor[
              0.2921699969184407, 0.4220829828981863, 0.9400355750383738], 
             UndirectedEdge[107, 352] -> 
             RGBColor[
              0.9166859076311894, 0.6461772301173578, 0.39514005851685197`], 
             UndirectedEdge[99, 338] -> 
             RGBColor[
              0.9862079875593082, 0.9866999578573392, 0.7708056942036536], 
             UndirectedEdge[186, 341] -> 
             RGBColor[
              0.23502569235584353`, 0.3643572825285215, 0.9366957375390872], 
             UndirectedEdge[90, 156] -> 
             RGBColor[
              0.4458826703540418, 0.5414428840631231, 0.9526066384680504], 
             UndirectedEdge[34, 151] -> 
             RGBColor[
              0.31406226415390115`, 0.44644668080690353`, 0.9412327476508988],
              UndirectedEdge[174, 260] -> 
             RGBColor[
              0.7687797089830702, 0.819295818690549, 0.9775884348027377], 
             UndirectedEdge[13, 216] -> 
             RGBColor[
              0.8114408517281416, 0.8530611432182054, 0.956425858174716], 
             UndirectedEdge[9, 217] -> 
             RGBColor[
              0.8242465537218799, 0.18737521357976708`, 0.17085183326762515`],
              UndirectedEdge[87, 159] -> 
             RGBColor[
              0.3107866556543149, 0.4418891428954188, 0.9410870199640158], 
             UndirectedEdge[184, 305] -> 
             RGBColor[
              0.21033276310750965`, 0.33840344826638225`, 0.9352895117483098],
              UndirectedEdge[12, 259] -> 
             RGBColor[
              0.2147288372822968, 0.3430240009512847, 0.9355398616691548], 
             UndirectedEdge[27, 287] -> 
             RGBColor[
              0.27881505582512084`, 0.4103826799407336, 0.9391894770081045], 
             UndirectedEdge[188, 284] -> 
             RGBColor[
              0.25554200422115014`, 0.38592122710826227`, 0.9378641111486529],
              UndirectedEdge[118, 126] -> 
             RGBColor[
              0.20905168496127685`, 0.33705695390964574`, 0.935216556243067], 
             UndirectedEdge[209, 304] -> 
             RGBColor[
              0.23556571159456763`, 0.3649248769876179, 0.9367264908358456], 
             UndirectedEdge[48, 108] -> 
             RGBColor[
              0.3965059868386308, 0.5178552896544295, 0.9464859887582483], 
             UndirectedEdge[136, 376] -> 
             RGBColor[
              0.5284877060748537, 0.6276839131134415, 0.9561356038127271], 
             UndirectedEdge[48, 344] -> 
             RGBColor[
              0.373035772157718, 0.49752656934511247`, 0.9449904874326764], 
             UndirectedEdge[13, 198] -> 
             RGBColor[
              0.8951348791523555, 0.9184961361184019, 0.9647537428637106], 
             UndirectedEdge[286, 320] -> 
             RGBColor[
              0.7180719499645429, 0.7796825319520332, 0.9725343592747207], 
             UndirectedEdge[176, 368] -> 
             RGBColor[
              0.2143024966118115, 0.34257588987504495`, 0.9355155821986852], 
             UndirectedEdge[248, 388] -> 
             RGBColor[
              0.21978649931888122`, 0.34833992442602935`, 0.935827888039998], 
             UndirectedEdge[57, 188] -> 
             RGBColor[
              0.270146670915944, 0.40127165779384166`, 0.9386958253112532], 
             UndirectedEdge[39, 225] -> 
             RGBColor[
              0.26510008482719366`, 0.3959673758425263, 0.9384084296992539], 
             UndirectedEdge[355, 379] -> 
             RGBColor[
              0.2259392634266556, 0.3548068696110762, 0.9361782788537368], 
             UndirectedEdge[85, 348] -> 
             RGBColor[
              0.2521313444108594, 0.3823364073993248, 0.9376698791180758], 
             UndirectedEdge[118, 336] -> 
             RGBColor[
              0.20853409149877072`, 0.3365129303632308, 0.9351870800610882], 
             UndirectedEdge[195, 392] -> 
             RGBColor[
              0.24682195915511385`, 0.3767559068610679, 0.9373675174822926], 
             UndirectedEdge[193, 281] -> 
             RGBColor[
              0.7271668299156635, 0.7866477829836171, 0.9735443566828026], 
             UndirectedEdge[154, 312] -> 
             RGBColor[
              0.4465576020433747, 0.5609457568821319, 0.9497475491477698], 
             UndirectedEdge[53, 171] -> 
             RGBColor[
              0.28122827358250124`, 0.41291912481058346`, 0.9393269061893516],
              UndirectedEdge[115, 188] -> 
             RGBColor[
              0.25284600900533644`, 0.38308756520047255`, 0.9377105782094798],
              UndirectedEdge[319, 329] -> 
             RGBColor[
              0.2383612491721791, 0.3678631642290072, 0.9368856925652633], 
             UndirectedEdge[231, 359] -> 
             RGBColor[
              0.2771261222266016, 0.4086075036441148, 0.9390932947382222], 
             UndirectedEdge[288, 399] -> 
             RGBColor[
              0.23995250394206913`, 0.3695356738835413, 0.9369763121703581], 
             UndirectedEdge[140, 220] -> 
             RGBColor[
              0.5736797551483913, 0.6643251817234797, 0.9598909775899255], 
             UndirectedEdge[9, 215] -> 
             RGBColor[
              0.822477817482793, 0.1737799317809825, 0.1691580894475736], 
             UndirectedEdge[309, 329] -> 
             RGBColor[
              0.25296463724126, 0.3832122509978928, 0.9377173339120208], 
             UndirectedEdge[9, 61] -> 
             RGBColor[
              0.9095066708030527, 0.5932363190069687, 0.34466666805378354`], 
             UndirectedEdge[21, 82] -> 
             RGBColor[
              0.34606714839588365`, 0.4741677029250543, 0.94327207057399], 
             UndirectedEdge[154, 361] -> 
             RGBColor[
              0.39289227512184555`, 0.5147252741957822, 0.9462557262431346], 
             UndirectedEdge[160, 213] -> 
             RGBColor[
              0.8702228477750129, 0.45615422864304855`, 0.21154106500959308`],
              UndirectedEdge[331, 342] -> 
             RGBColor[
              0.5277253347918338, 0.6274369503840362, 0.9559728122191802], 
             UndirectedEdge[122, 159] -> 
             RGBColor[
              0.3887610902465449, 0.5111470494961861, 0.9459924907959437], 
             UndirectedEdge[258, 278] -> 
             RGBColor[
              0.25267444257649463`, 0.38290723800581994`, 0.937700807755167], 
             UndirectedEdge[37, 201] -> 
             RGBColor[
              0.26311290635419504`, 0.3938787252730125, 0.9382952628249838], 
             UndirectedEdge[61, 314] -> 
             RGBColor[
              0.9595789423265859, 0.965928622564677, 0.7549534149051582], 
             UndirectedEdge[297, 314] -> 
             RGBColor[
              0.9362255007006572, 0.9517027043636277, 0.9839981831745597], 
             UndirectedEdge[84, 175] -> 
             RGBColor[
              0.1789295778879611, 0.3053967095236947, 0.9335011468069058], 
             UndirectedEdge[72, 374] -> 
             RGBColor[
              0.25191511783451104`, 0.3821091395580259, 0.9376575653344313], 
             UndirectedEdge[168, 180] -> 
             RGBColor[
              0.5182102560481305, 0.6169561699548207, 0.9561586879091916], 
             UndirectedEdge[36, 60] -> 
             RGBColor[
              0.4386028192989782, 0.5525156396146701, 0.9496662072988238], 
             UndirectedEdge[347, 387] -> 
             RGBColor[
              0.2868094179961087, 0.41878526145427897`, 0.9396447441071433], 
             UndirectedEdge[140, 141] -> 
             RGBColor[
              0.5159944713875729, 0.6149616035084853, 0.9560493981699523], 
             UndirectedEdge[233, 382] -> 
             RGBColor[
              0.8581195774771997, 0.3842334181920808, 0.20080199431053547`], 
             UndirectedEdge[21, 122] -> 
             RGBColor[
              0.37950236392749337`, 0.5031276061157393, 0.9454025329420639], 
             UndirectedEdge[202, 268] -> 
             RGBColor[
              0.836829312925746, 0.2840918146209231, 0.18290109769144122`], 
             UndirectedEdge[196, 344] -> 
             RGBColor[
              0.3092763827236792, 0.441300833748132, 0.9409644308152758], 
             UndirectedEdge[109, 343] -> 
             RGBColor[
              0.8581485111146978, 0.8873672938614341, 0.8602232482931473], 
             UndirectedEdge[52, 117] -> 
             RGBColor[
              0.36808130040816744`, 0.4932352549346425, 0.9446747928738624], 
             UndirectedEdge[51, 194] -> 
             RGBColor[
              0.38048922371828053`, 0.5039823744655038, 0.945465414775287], 
             UndirectedEdge[223, 342] -> 
             RGBColor[
              0.5287126959381665, 0.6282718106549494, 0.9560413466441238], 
             UndirectedEdge[241, 374] -> 
             RGBColor[
              0.2835328374534444, 0.4153413675567334, 0.939458147692505], 
             UndirectedEdge[76, 109] -> 
             RGBColor[
              0.9205204428847344, 0.6768339136433675, 0.4700439928721189], 
             UndirectedEdge[90, 381] -> 
             RGBColor[
              0.849476415301395, 0.8807671291171392, 0.8672733890419332], 
             UndirectedEdge[75, 227] -> 
             RGBColor[
              0.2395500669875186, 0.36911268712833206`, 0.9369533939811485], 
             UndirectedEdge[209, 329] -> 
             RGBColor[
              0.24358590725750107`, 0.37335461113913604`, 0.9371832291140334],
              UndirectedEdge[24, 358] -> 
             RGBColor[
              0.9353648485028525, 0.777122720375753, 0.28624658001000514`], 
             UndirectedEdge[208, 369] -> 
             RGBColor[
              0.24527033350139205`, 0.37512504992025775`, 0.9372791546967377],
              UndirectedEdge[62, 400] -> 
             RGBColor[
              0.2843395833350594, 0.4087127954077557, 0.9397778424506229], 
             UndirectedEdge[127, 325] -> 
             RGBColor[
              0.21103171786447747`, 0.3391380940322466, 0.9353293161877081], 
             UndirectedEdge[43, 277] -> 
             RGBColor[
              0.2426240388727448, 0.37234362648077923`, 0.9371284521324783], 
             UndirectedEdge[70, 227] -> 
             RGBColor[
              0.25636607330828476`, 0.3867873759678386, 0.9379110406640643], 
             UndirectedEdge[25, 366] -> 
             RGBColor[
              0.8749957803146731, 0.510019968284747, 0.21680872378706678`], 
             UndirectedEdge[20, 387] -> 
             RGBColor[
              0.3506138656824209, 0.476702600538333, 0.94361316288308], 
             UndirectedEdge[328, 387] -> 
             RGBColor[
              0.30150296805800375`, 0.4341652094015489, 0.9404838599135137], 
             UndirectedEdge[249, 386] -> 
             RGBColor[
              0.3044662110801129, 0.4345129066433197, 0.9407539204836926], 
             UndirectedEdge[110, 243] -> 
             RGBColor[
              0.2719749479938126, 0.4031932929221435, 0.9387999429861442], 
             UndirectedEdge[47, 121] -> 
             RGBColor[
              0.4935440296663224, 0.5991928393789325, 0.9534184801906773], 
             UndirectedEdge[31, 156] -> 
             RGBColor[
              0.18458847622123073`, 0.3113445704668384, 0.9338234126953957], 
             UndirectedEdge[98, 283] -> 
             RGBColor[
              0.9432427006605664, 0.8062936865407971, 0.3064669136008217], 
             UndirectedEdge[38, 358] -> 
             RGBColor[
              0.9671839420965409, 0.9009658724941282, 0.3270162411479497], 
             UndirectedEdge[126, 199] -> 
             RGBColor[
              0.21892225618889471`, 0.3474315501002342, 0.9357786706722784], 
             UndirectedEdge[39, 200] -> 
             RGBColor[
              0.27187585958380484`, 0.4030891447206572, 0.9387943000477824], 
             UndirectedEdge[227, 304] -> 
             RGBColor[
              0.22701022275090071`, 0.35593251576360085`, 0.9362392684029103],
              UndirectedEdge[242, 333] -> 
             RGBColor[
              0.5569536477379948, 0.5184281382754727, 0.5938032026627618], 
             UndirectedEdge[30, 333] -> 
             RGBColor[
              0.1872437438170861, 0.31413542506377157`, 0.9339746262568631], 
             UndirectedEdge[85, 96] -> 
             RGBColor[
              0.2641094772748117, 0.3949261844968264, 0.9383520160646184], 
             UndirectedEdge[39, 94] -> 
             RGBColor[
              0.2666080163774077, 0.39755230751018356`, 0.9384943041702538], 
             UndirectedEdge[63, 138] -> 
             RGBColor[
              0.8889519646070447, 0.5107811215593289, 0.22983700543826907`], 
             UndirectedEdge[119, 324] -> 
             RGBColor[
              0.26022801088632164`, 0.3908465172233403, 0.9381309722959088], 
             UndirectedEdge[18, 224] -> 
             RGBColor[
              0.960434037083298, 0.9441092105197667, 0.6687925780376456], 
             UndirectedEdge[84, 204] -> 
             RGBColor[
              0.17892700714738574`, 0.30539400751235557`, 0.933501000407033], 
             UndirectedEdge[241, 288] -> 
             RGBColor[
              0.2679939698052205, 0.39900903243733754`, 0.9385732321676334], 
             UndirectedEdge[91, 266] -> 
             RGBColor[
              0.25880957199136756`, 0.38935564801052325`, 0.9380501942992334],
              UndirectedEdge[201, 263] -> 
             RGBColor[
              0.26925494850456955`, 0.4003344010010207, 0.9386450430391104], 
             UndirectedEdge[29, 266] -> 
             RGBColor[
              0.2477135704987891, 0.37769304691469485`, 0.9374182934292943], 
             UndirectedEdge[161, 326] -> 
             RGBColor[
              0.3854134409611904, 0.5082474839429573, 0.9457791815436909], 
             UndirectedEdge[174, 235] -> 
             RGBColor[
              0.7343495307888845, 0.7923987018062052, 0.9741567564086497], 
             UndirectedEdge[207, 233] -> 
             RGBColor[
              0.8786570254685007, 0.4672262975790694, 0.21740805642807715`], 
             UndirectedEdge[199, 212] -> 
             RGBColor[
              0.21834996970250586`, 0.3468300407179805, 0.9357460798035004], 
             UndirectedEdge[127, 184] -> 
             RGBColor[
              0.21412931839643223`, 0.34239386859054827`, 0.9355057199555137],
              UndirectedEdge[261, 381] -> 
             RGBColor[
              0.5862976993087463, 0.6486880635605781, 0.8483828425372609], 
             UndirectedEdge[221, 230] -> 
             RGBColor[
              0.9453580743501937, 0.9235697837599854, 0.6629627899588003], 
             UndirectedEdge[22, 273] -> 
             RGBColor[
              0.28387789683872655`, 0.4157040468486936, 0.9394777983140272], 
             UndirectedEdge[240, 292] -> 
             RGBColor[
              0.2251125947151853, 0.3539379883814973, 0.9361312012935654], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.4322766112650586, 0.5488154801889021, 0.9487714854439504], 
             UndirectedEdge[120, 343] -> 
             RGBColor[
              0.64428944346767, 0.7208791499127623, 0.9659761919445966], 
             UndirectedEdge[175, 310] -> 
             RGBColor[
              0.18075514602575382`, 0.30731549738422004`, 0.933605110211667], 
             UndirectedEdge[55, 201] -> 
             RGBColor[
              0.33997947002411655`, 0.46590668357700793`, 0.9429935809374401],
              UndirectedEdge[264, 333] -> 
             RGBColor[
              0.19279573500831393`, 0.31997091982232506`, 0.9342908039417687],
              UndirectedEdge[107, 197] -> 
             RGBColor[
              0.9139845567949747, 0.6460331456516251, 0.5106347906861869], 
             UndirectedEdge[131, 300] -> 
             RGBColor[
              0.9062314787117222, 0.661847076989811, 0.24319781291959908`], 
             UndirectedEdge[164, 227] -> 
             RGBColor[
              0.23873025962291325`, 0.36825101760934276`, 0.9369067071645306],
              UndirectedEdge[75, 315] -> 
             RGBColor[
              0.24372617436870905`, 0.3735020407664642, 0.9371912171185102], 
             UndirectedEdge[123, 193] -> 
             RGBColor[
              0.8983178729767032, 0.9207629901755221, 0.9556553997903747], 
             UndirectedEdge[157, 253] -> 
             RGBColor[
              0.40547981020843754`, 0.5251955404755204, 0.9471772728723662], 
             UndirectedEdge[87, 110] -> 
             RGBColor[
              0.27285833032697415`, 0.4041217837639711, 0.9388502503031707], 
             UndirectedEdge[112, 273] -> 
             RGBColor[
              0.30217928403804095`, 0.4330746327553852, 0.940588334197813], 
             UndirectedEdge[193, 384] -> 
             RGBColor[
              0.7853837252276628, 0.8322860419074539, 0.9792383154624147], 
             UndirectedEdge[95, 249] -> 
             RGBColor[
              0.2756739059578213, 0.4070811322697972, 0.9390105931700766], 
             UndirectedEdge[61, 66] -> 
             RGBColor[
              0.9830643953423903, 0.9540141570597834, 0.4329439736998075], 
             UndirectedEdge[113, 251] -> 
             RGBColor[
              0.8094157442625041, 0.8510598457172036, 0.9816336535080088], 
             UndirectedEdge[107, 131] -> 
             RGBColor[
              0.8808419295941465, 0.5163805585259162, 0.22083043617809295`], 
             UndirectedEdge[71, 343] -> 
             RGBColor[
              0.7966602927353739, 0.841489655974727, 0.98025763017568], 
             UndirectedEdge[113, 168] -> 
             RGBColor[
              0.7333330676267822, 0.7916046330585647, 0.9740554448600397], 
             UndirectedEdge[58, 201] -> 
             RGBColor[
              0.2876186397714912, 0.4196358048478299, 0.939690828090115], 
             UndirectedEdge[47, 130] -> 
             RGBColor[
              0.4221487542491271, 0.5400657659424366, 0.9481199232226362], 
             UndirectedEdge[17, 82] -> 
             RGBColor[
              0.4573668797759753, 0.5683380513272105, 0.9509806674680623], 
             UndirectedEdge[11, 25] -> 
             RGBColor[
              0.8860868883930885, 0.5548412704093811, 0.2257767948788701], 
             UndirectedEdge[73, 392] -> 
             RGBColor[
              0.24553259442115521`, 0.3754007027752315, 0.9372940900681379], 
             UndirectedEdge[155, 337] -> 
             RGBColor[
              0.29464447603044647`, 0.42702040421973947`, 0.9400909390712692],
              UndirectedEdge[159, 165] -> 
             RGBColor[
              0.43209168429834016`, 0.5465211004605023, 0.9493493893401392], 
             UndirectedEdge[226, 368] -> 
             RGBColor[
              0.2257077662103317, 0.35456355135894857`, 0.9361650954297367], 
             UndirectedEdge[188, 258] -> 
             RGBColor[
              0.2600095899871553, 0.39061694300963157`, 0.938118533548826], 
             UndirectedEdge[140, 350] -> 
             RGBColor[
              0.5523338730537959, 0.6464369667603329, 0.9583649127104528], 
             UndirectedEdge[14, 38] -> 
             RGBColor[
              0.9800741446959539, 0.9433032752196526, 0.4743933351284341], 
             UndirectedEdge[242, 268] -> 
             RGBColor[
              0.8678329199624942, 0.4240532300724246, 0.2086880773194431], 
             UndirectedEdge[20, 50] -> 
             RGBColor[
              0.4309033063250306, 0.5476259924741631, 0.9486839796675377], 
             UndirectedEdge[149, 212] -> 
             RGBColor[
              0.21555790485274898`, 0.34389540353375003`, 0.9355870758407967],
              UndirectedEdge[80, 361] -> 
             RGBColor[
              0.34502145958500996`, 0.47326197983492335`, 0.9432054402076274],
              UndirectedEdge[31, 204] -> 
             RGBColor[
              0.1810722066459815, 0.3076487481988837, 0.9336231663449399], 
             UndirectedEdge[209, 245] -> 
             RGBColor[
              0.2409659187206967, 0.37060083707008695`, 0.9370340246427882], 
             UndirectedEdge[113, 148] -> 
             RGBColor[
              0.7102018348766541, 0.7732513864434318, 0.9719433954351793], 
             UndirectedEdge[48, 231] -> 
             RGBColor[
              0.3670635094292236, 0.49234797467679914`, 0.9446101496016666], 
             UndirectedEdge[198, 224] -> 
             RGBColor[
              0.901075568718926, 0.8970235530331128, 0.6716312488962854], 
             UndirectedEdge[1, 188] -> 
             RGBColor[
              0.3135344759290187, 0.4421377779902256, 0.9413401492239378], 
             UndirectedEdge[256, 264] -> 
             RGBColor[
              0.2076696899760163, 0.3356043895565939, 0.9351378536731348], 
             UndirectedEdge[15, 170] -> 
             RGBColor[
              0.3744152758657625, 0.49826976676104406`, 0.9450949256507872], 
             UndirectedEdge[20, 322] -> 
             RGBColor[
              0.45803755349750475`, 0.5696547967126826, 0.9508200870009773], 
             UndirectedEdge[92, 153] -> 
             RGBColor[
              0.30254730129756563`, 0.4345238091753902, 0.940570393778262], 
             UndirectedEdge[189, 360] -> 
             RGBColor[
              0.30546923311788443`, 0.43824575192600135`, 0.9407129642351355],
              UndirectedEdge[272, 342] -> 
             RGBColor[
              0.6251875638221265, 0.7065231010289125, 0.9636849864326502], 
             UndirectedEdge[69, 219] -> 
             RGBColor[
              0.4677032328653056, 0.5785751319820428, 0.9512844483334466], 
             UndirectedEdge[86, 151] -> 
             RGBColor[
              0.30818593638346986`, 0.44059786327207706`, 0.9408861053327038],
              UndirectedEdge[72, 288] -> 
             RGBColor[
              0.2363762501862872, 0.36577680443863003`, 0.9367726498095597], 
             UndirectedEdge[266, 273] -> 
             RGBColor[
              0.265217664230201, 0.3960909592500517, 0.938415125672312], 
             UndirectedEdge[131, 297] -> 
             RGBColor[
              0.9345525999537521, 0.8450176590746574, 0.6158415354980056], 
             UndirectedEdge[219, 360] -> 
             RGBColor[
              0.37878978346753606`, 0.5025104047366595, 0.9453571279452656], 
             UndirectedEdge[58, 236] -> 
             RGBColor[
              0.27466659649964625`, 0.4060223861621468, 0.9389532283866143], 
             UndirectedEdge[272, 321] -> 
             RGBColor[
              0.7324016958614257, 0.7908770383567805, 0.9739626144266329], 
             UndirectedEdge[250, 391] -> 
             RGBColor[
              0.9043090036006871, 0.5735688958941825, 0.5059642810005588], 
             UndirectedEdge[122, 298] -> 
             RGBColor[
              0.634758859433705, 0.711422615804957, 0.9663329898214426], 
             UndirectedEdge[113, 282] -> 
             RGBColor[
              0.7216887092702036, 0.7825079718100041, 0.9728948440417715], 
             UndirectedEdge[237, 343] -> 
             RGBColor[
              0.6503098019378368, 0.7257667481329021, 0.9664501366166679], 
             UndirectedEdge[174, 398] -> 
             RGBColor[
              0.83401539327211, 0.8711277377968187, 0.9805027030161089], 
             UndirectedEdge[223, 384] -> 
             RGBColor[
              0.6012475155961567, 0.6855340055780029, 0.9628624648765374], 
             UndirectedEdge[143, 260] -> 
             RGBColor[
              0.7167991404658595, 0.7784168360748085, 0.9725930329082488], 
             UndirectedEdge[148, 161] -> 
             RGBColor[
              0.5276623353729026, 0.6268249505740837, 0.9561228183174523], 
             UndirectedEdge[137, 199] -> 
             RGBColor[
              0.22367942926895015`, 0.3524316406295666, 0.9360495846415806], 
             UndirectedEdge[147, 387] -> 
             RGBColor[
              0.28915329202202544`, 0.42124882166571403`, 0.9397782242654684],
              UndirectedEdge[138, 381] -> 
             RGBColor[
              0.9062449527279615, 0.5705587678025101, 0.4646955300926113], 
             UndirectedEdge[42, 207] -> 
             RGBColor[
              0.9360408404789141, 0.8740255032004962, 0.6319312562767279], 
             UndirectedEdge[185, 247] -> 
             RGBColor[
              0.8653490116625105, 0.42606196440460237`, 0.20717681371904806`],
              UndirectedEdge[49, 380] -> 
             RGBColor[
              0.2606135317686764, 0.39125172411413095`, 0.9381529271398318], 
             UndirectedEdge[63, 242] -> 
             RGBColor[
              0.9384539463641798, 0.7929291511512139, 0.2733380495894395], 
             UndirectedEdge[12, 238] -> 
             RGBColor[
              0.22383004590865202`, 0.3525899482675398, 0.9360581620363942], 
             UndirectedEdge[109, 382] -> 
             RGBColor[
              0.9464386860434384, 0.8125481887830079, 0.4923766470320703], 
             UndirectedEdge[4, 115] -> 
             RGBColor[
              0.23540129852856206`, 0.36475206843085556`, 0.936717127754964], 
             UndirectedEdge[187, 279] -> 
             RGBColor[
              0.8947917399967904, 0.8503099582405043, 0.6300514927715455], 
             UndirectedEdge[152, 156] -> 
             RGBColor[
              0.18478785261667285`, 0.31155412769964164`, 0.9338347668861651],
              UndirectedEdge[143, 290] -> 
             RGBColor[
              0.5148889820990041, 0.6157407807626738, 0.9553145849297924], 
             UndirectedEdge[48, 234] -> 
             RGBColor[
              0.38209114426819646`, 0.5053698775309731, 0.945567487736205], 
             UndirectedEdge[294, 341] -> 
             RGBColor[
              0.21717163219876068`, 0.3455915332906315, 0.9356789752258563], 
             UndirectedEdge[243, 351] -> 
             RGBColor[
              0.26705822161415743`, 0.39802550175866824`, 0.9385199426924677],
              UndirectedEdge[241, 399] -> 
             RGBColor[
              0.2629204824738216, 0.3936764755743613, 0.938284304569662], 
             UndirectedEdge[78, 207] -> 
             RGBColor[
              0.8908498839236407, 0.5609459506099194, 0.22908395145458324`], 
             UndirectedEdge[174, 267] -> 
             RGBColor[
              0.6499021646261236, 0.725337696254724, 0.9664851266806084], 
             UndirectedEdge[124, 293] -> 
             RGBColor[
              0.21725116581640602`, 0.3456751281654994, 0.9356835045477219], 
             UndirectedEdge[57, 392] -> 
             RGBColor[
              0.2605783177897506, 0.3912147119895847, 0.9381509217558264], 
             UndirectedEdge[272, 331] -> 
             RGBColor[
              0.5495546990516302, 0.6450876581742866, 0.9577400845269233], 
             UndirectedEdge[91, 255] -> 
             RGBColor[
              0.26154809523840944`, 0.39223400957556664`, 0.9382061491468703],
              UndirectedEdge[35, 337] -> 
             RGBColor[
              0.28289219144336497`, 0.41466800798083686`, 0.9394216638499819],
              UndirectedEdge[219, 339] -> 
             RGBColor[
              0.4064741730871376, 0.5264892315672777, 0.9471211527714821], 
             UndirectedEdge[166, 185] -> 
             RGBColor[
              0.8242297938213237, 0.1872463896398561, 0.17083578396792481`], 
             UndirectedEdge[137, 238] -> 
             RGBColor[
              0.22538960071026484`, 0.3542291392455204, 0.9361469763751915], 
             UndirectedEdge[218, 300] -> 
             RGBColor[
              0.9000302759419758, 0.7622535258714493, 0.6106034215734397], 
             UndirectedEdge[96, 110] -> 
             RGBColor[
              0.2712447160930261, 0.4024257728950402, 0.9387583573596757], 
             UndirectedEdge[225, 375] -> 
             RGBColor[
              0.2559767228165143, 0.3863781439147409, 0.9378888677295503], 
             UndirectedEdge[24, 25] -> 
             RGBColor[
              0.8754320696783777, 0.5120010563873596, 0.21717277432657275`], 
             UndirectedEdge[40, 361] -> 
             RGBColor[
              0.34746932604333547`, 0.4753821987277793, 0.9433614160937887], 
             UndirectedEdge[141, 394] -> 
             RGBColor[
              0.3594659493572627, 0.4857730708744833, 0.9441258303231546], 
             UndirectedEdge[200, 360] -> 
             RGBColor[
              0.29052568872167633`, 0.4225391392901483, 0.9398619514887643], 
             UndirectedEdge[68, 229] -> 
             RGBColor[
              0.2618103919644219, 0.39250970006517877`, 0.9382210865573835], 
             UndirectedEdge[96, 258] -> 
             RGBColor[
              0.26992237493120286`, 0.4010359084926919, 0.9386830519867384], 
             UndirectedEdge[106, 310] -> 
             RGBColor[
              0.5655364837016175, 0.6351698449942476, 0.952888973704525], 
             UndirectedEdge[15, 394] -> 
             RGBColor[
              0.33136443385417313`, 0.4609812912088401, 0.9423517640661736], 
             UndirectedEdge[115, 203] -> 
             RGBColor[
              0.265001837635785, 0.3958641118151241, 0.9384028346670469], 
             UndirectedEdge[218, 298] -> 
             RGBColor[
              0.8667469534105012, 0.8965845097029781, 0.9871522922420749], 
             UndirectedEdge[165, 262] -> 
             RGBColor[
              0.7356958172611161, 0.7926545035064209, 0.9725524468455675], 
             UndirectedEdge[141, 357] -> 
             RGBColor[
              0.5178770250869611, 0.6164322687663853, 0.9562370335292427], 
             UndirectedEdge[15, 239] -> 
             RGBColor[
              0.3141879177885835, 0.4461038563096259, 0.9412572916510711], 
             UndirectedEdge[80, 228] -> 
             RGBColor[
              0.35113678778418134`, 0.4785587697557132, 0.9435951035129062], 
             UndirectedEdge[260, 272] -> 
             RGBColor[
              0.7279854810242253, 0.7874270577614837, 0.9735224474035349], 
             UndirectedEdge[7, 361] -> 
             RGBColor[
              0.3725157575792012, 0.497076158853894, 0.9449573525635642], 
             UndirectedEdge[22, 255] -> 
             RGBColor[
              0.27639668732322686`, 0.40784082131182386`, 0.9390517544995772],
              UndirectedEdge[28, 380] -> 
             RGBColor[
              0.2768898890919296, 0.40835920764152867`, 0.9390798416106783], 
             UndirectedEdge[53, 397] -> 
             RGBColor[
              0.26929675474869136`, 0.4003783420142617, 0.9386474238428664], 
             UndirectedEdge[187, 306] -> 
             RGBColor[
              0.9071549779062498, 0.8950638881018478, 0.6621967951023203], 
             UndirectedEdge[208, 392] -> 
             RGBColor[
              0.24051796511845452`, 0.3701300094322317, 0.9370085143478284], 
             UndirectedEdge[33, 381] -> 
             RGBColor[
              0.5860442078575524, 0.648421627973087, 0.8483684065741224], 
             UndirectedEdge[290, 321] -> 
             RGBColor[
              0.6114600904368728, 0.6914542319869668, 0.964754355111318], 
             UndirectedEdge[20, 116] -> 
             RGBColor[
              0.4119401607737857, 0.531223595372923, 0.9474694406734923], 
             UndirectedEdge[33, 156] -> 
             RGBColor[
              0.18245046291019928`, 0.30909738291907096`, 0.9337016560002396],
              UndirectedEdge[9, 202] -> 
             RGBColor[
              0.8410035318945833, 0.31617669076982174`, 0.1868983344901058], 
             UndirectedEdge[76, 233] -> 
             RGBColor[
              0.8322013343184957, 0.24851914305244047`, 0.17846934015058413`],
              UndirectedEdge[115, 369] -> 
             RGBColor[
              0.24803002426208054`, 0.37802565988424164`, 0.9374363150029623],
              UndirectedEdge[183, 335] -> 
             RGBColor[
              0.2697259044179279, 0.4008294055262898, 0.9386718632816594], 
             UndirectedEdge[39, 296] -> 
             RGBColor[
              0.2873068026652887, 0.4193080442775966, 0.9396730694282384], 
             UndirectedEdge[10, 219] -> 
             RGBColor[
              0.4045568603314619, 0.5248285516252523, 0.9469989832981036], 
             UndirectedEdge[71, 143] -> 
             RGBColor[
              0.7478821300066041, 0.8031124171001021, 0.9755814141619994], 
             UndirectedEdge[232, 384] -> 
             RGBColor[
              0.6369922413654878, 0.7145531842390913, 0.965676420626344], 
             UndirectedEdge[1, 57] -> 
             RGBColor[
              0.31659522838756854`, 0.44535482288707584`, 0.9415144545484747],
              UndirectedEdge[288, 393] -> 
             RGBColor[
              0.23392299503197628`, 0.3631982777260886, 0.9366329405577875], 
             UndirectedEdge[328, 372] -> 
             RGBColor[
              0.2804573452843499, 0.4120449254968854, 0.9392853428307628], 
             UndirectedEdge[16, 115] -> 
             RGBColor[
              0.240233305102069, 0.36983081370652304`, 0.936992303381012], 
             UndirectedEdge[34, 244] -> 
             RGBColor[
              0.2861625929026812, 0.4177778317374103, 0.9396199025198813], 
             UndirectedEdge[233, 366] -> 
             RGBColor[
              0.8593693391869154, 0.3899082942266366, 0.20184482611558502`], 
             UndirectedEdge[100, 105] -> 
             RGBColor[
              0.3969790975995051, 0.5182650744162607, 0.9465161349575758], 
             UndirectedEdge[88, 282] -> 
             RGBColor[
              0.8185877701205739, 0.8571575543356513, 0.887813136638508], 
             UndirectedEdge[189, 219] -> 
             RGBColor[
              0.37386729373661226`, 0.4974887142474586, 0.9450712281757306], 
             UndirectedEdge[44, 328] -> 
             RGBColor[
              0.3036968641952127, 0.4364711333428047, 0.9406087990529493], 
             UndirectedEdge[153, 154] -> 
             RGBColor[
              0.3737943950019111, 0.49818365032325973`, 0.9450388262094847], 
             UndirectedEdge[73, 258] -> 
             RGBColor[
              0.2480246190771097, 0.3780199786921288, 0.9374360071856744], 
             UndirectedEdge[22, 141] -> 
             RGBColor[
              0.32619117202571163`, 0.45543328701971864`, 0.9420612032605917],
              UndirectedEdge[100, 273] -> 
             RGBColor[
              0.3260257412647034, 0.4537292354473304, 0.9421078093657018], 
             UndirectedEdge[230, 391] -> 
             RGBColor[
              0.8946240115133538, 0.5321742003823082, 0.2503381046492794], 
             UndirectedEdge[338, 384] -> 
             RGBColor[
              0.8713581064441347, 0.8967942587815345, 0.7976314467612728], 
             UndirectedEdge[76, 207] -> 
             RGBColor[
              0.8934001271128089, 0.5805482372855583, 0.23152606721261854`], 
             UndirectedEdge[144, 370] -> 
             RGBColor[
              0.8548273648949809, 0.7045756223106869, 0.6020207461756493], 
             UndirectedEdge[6, 340] -> 
             RGBColor[
              0.9935628356137232, 0.988639881211936, 0.5407325660065214], 
             UndirectedEdge[30, 370] -> 
             RGBColor[
              0.5050718279609444, 0.5868238115344944, 0.9586321897581539], 
             UndirectedEdge[164, 245] -> 
             RGBColor[
              0.23621867801950508`, 0.36561118610068966`, 0.9367636763077685],
              UndirectedEdge[56, 108] -> 
             RGBColor[
              0.40925205503740436`, 0.5288952932921922, 0.9472981569529686], 
             UndirectedEdge[50, 322] -> 
             RGBColor[
              0.4812818793914586, 0.5897653370483966, 0.952307419020761], 
             UndirectedEdge[379, 399] -> 
             RGBColor[
              0.22791818849812123`, 0.356886845332283, 0.9362909757089996], 
             UndirectedEdge[6, 13] -> 
             RGBColor[
              0.978563836078469, 0.9803436260913665, 0.7317471315868381], 
             UndirectedEdge[55, 60] -> 
             RGBColor[
              0.38053049793671245`, 0.5040181241190069, 0.9454680447319882], 
             UndirectedEdge[44, 47] -> 
             RGBColor[
              0.36592423069765223`, 0.4903693505688373, 0.9445738718209851], 
             UndirectedEdge[156, 264] -> 
             RGBColor[
              0.1879952768080626, 0.31492533388723165`, 0.9340174249489059], 
             UndirectedEdge[32, 43] -> 
             RGBColor[
              0.2218603287150994, 0.3505196506098328, 0.9359459895561568], 
             UndirectedEdge[144, 207] -> 
             RGBColor[
              0.9091469621070289, 0.6700765235430096, 0.2453714490760957], 
             UndirectedEdge[14, 213] -> 
             RGBColor[
              0.9526625957676589, 0.8375319772984231, 0.4372009912003371], 
             UndirectedEdge[127, 139] -> 
             RGBColor[
              0.2108331954164144, 0.3389294343522821, 0.9353180106279786], 
             UndirectedEdge[321, 342] -> 
             RGBColor[
              0.7105723316016292, 0.7732263305665302, 0.9721953421188899], 
             UndirectedEdge[82, 182] -> 
             RGBColor[
              0.3336557333984177, 0.4615081693978327, 0.9425511382946132], 
             UndirectedEdge[50, 172] -> 
             RGBColor[
              0.3777861468106212, 0.500941670871986, 0.945324186142565], 
             UndirectedEdge[80, 96] -> 
             RGBColor[
              0.31066394327551555`, 0.4414844762785116, 0.9410901259683782], 
             UndirectedEdge[78, 160] -> 
             RGBColor[
              0.835660765688327, 0.2751098484934552, 0.18178209553720334`], 
             UndirectedEdge[32, 293] -> 
             RGBColor[
              0.2137582367821496, 0.342003838286004, 0.9354845874065463], 
             UndirectedEdge[322, 328] -> 
             RGBColor[
              0.4089266558730876, 0.5271174055758985, 0.947690784031411], 
             UndirectedEdge[120, 254] -> 
             RGBColor[
              0.5179448523327678, 0.6195299901302602, 0.955193662551596], 
             UndirectedEdge[291, 321] -> 
             RGBColor[
              0.7571390218362452, 0.8102020254189503, 0.9764281998963484], 
             UndirectedEdge[65, 312] -> 
             RGBColor[
              0.4891446804627151, 0.5961487131731942, 0.9529264075234798], 
             UndirectedEdge[209, 334] -> 
             RGBColor[
              0.2567160128781451, 0.387155184643212, 0.9379309692048785], 
             UndirectedEdge[295, 310] -> 
             RGBColor[
              0.2124827502833183, 0.3406632211052174, 0.935411950337351], 
             UndirectedEdge[109, 205] -> 
             RGBColor[
              0.9946824810618875, 0.9920690835121566, 0.737788580309801], 
             UndirectedEdge[194, 376] -> 
             RGBColor[
              0.4132241787161002, 0.5323357471779375, 0.947551257161364], 
             UndirectedEdge[142, 338] -> 
             RGBColor[
              0.9079361737525008, 0.5785505948422507, 0.3940025431841314], 
             UndirectedEdge[232, 386] -> 
             RGBColor[
              0.4324598922567031, 0.5470353068857565, 0.9493188938960907], 
             UndirectedEdge[169, 378] -> 
             RGBColor[
              0.21461245212241514`, 0.34290167276900374`, 0.9355332337064761],
              UndirectedEdge[94, 324] -> 
             RGBColor[
              0.2700408112862358, 0.4011603926111301, 0.9386897967619465], 
             UndirectedEdge[196, 231] -> 
             RGBColor[
              0.3033041199951848, 0.43612223907981873`, 0.9405840929842658], 
             UndirectedEdge[207, 366] -> 
             RGBColor[
              0.9205681319812286, 0.7219373884597544, 0.2549015531776194], 
             UndirectedEdge[156, 310] -> 
             RGBColor[
              0.1842688448604277, 0.3110086176408356, 0.93380521016225], 
             UndirectedEdge[206, 369] -> 
             RGBColor[
              0.2445080094379043, 0.3743237989953949, 0.9372357414690795], 
             UndirectedEdge[119, 225] -> 
             RGBColor[
              0.24880323623162193`, 0.37883835468870003`, 0.9374803482807631],
              UndirectedEdge[69, 100] -> 
             RGBColor[
              0.4324163535905058, 0.5480114107243323, 0.9490359995890186], 
             UndirectedEdge[64, 182] -> 
             RGBColor[
              0.34352729206089855`, 0.4700584173523088, 0.9431801452835099], 
             UndirectedEdge[217, 268] -> 
             RGBColor[
              0.8200723347530428, 0.15529033743086842`, 0.16685459646896056`],
              UndirectedEdge[235, 275] -> 
             RGBColor[
              0.8660971591696807, 0.893943749566336, 0.8776528174795629], 
             UndirectedEdge[5, 99] -> 
             RGBColor[
              0.9097853137766493, 0.92980801321679, 0.9533236132867424], 
             UndirectedEdge[52, 267] -> 
             RGBColor[
              0.4789222153161444, 0.5860393403630161, 0.9526218530734996], 
             UndirectedEdge[290, 346] -> 
             RGBColor[
              0.3750828645825507, 0.4992996579136456, 0.9451209263518141], 
             UndirectedEdge[19, 108] -> 
             RGBColor[
              0.3209765938651673, 0.4492585340761873, 0.9417896478514372], 
             UndirectedEdge[92, 327] -> 
             RGBColor[
              0.3031279877877182, 0.4350267706270088, 0.9406073946079336], 
             UndirectedEdge[151, 244] -> 
             RGBColor[
              0.28793584651295273`, 0.41931373488830953`, 0.9397328926719012],
              UndirectedEdge[114, 327] -> 
             RGBColor[
              0.32373500724345117`, 0.4548247247048681, 0.941849086287294], 
             UndirectedEdge[99, 174] -> 
             RGBColor[
              0.8533664925541351, 0.885559755956836, 0.9477463395066474], 
             UndirectedEdge[180, 282] -> 
             RGBColor[
              0.5065658976915518, 0.60785950870626, 0.9549980870909234], 
             UndirectedEdge[199, 277] -> 
             RGBColor[
              0.24180779724081597`, 0.3714857047729135, 0.9370819683790612], 
             UndirectedEdge[237, 286] -> 
             RGBColor[
              0.652334455595527, 0.7273484229582274, 0.9666519351718024], 
             UndirectedEdge[290, 313] -> 
             RGBColor[
              0.34397103520992167`, 0.4699540423686539, 0.9432263147475373], 
             UndirectedEdge[56, 237] -> 
             RGBColor[
              0.5146770314008289, 0.6168123226982427, 0.9549542854004349], 
             UndirectedEdge[203, 361] -> 
             RGBColor[
              0.32351204834138475`, 0.4530276285511149, 0.941893609121445], 
             UndirectedEdge[169, 315] -> 
             RGBColor[
              0.23198634740170132`, 0.3611627382761178, 0.9365226513402567], 
             UndirectedEdge[23, 304] -> 
             RGBColor[
              0.2162581809318601, 0.34463143809296365`, 0.9356269555275363], 
             UndirectedEdge[129, 270] -> 
             RGBColor[
              0.24363580909960866`, 0.3734070611391507, 0.9371860709501183], 
             UndirectedEdge[85, 284] -> 
             RGBColor[
              0.24265277809452013`, 0.37237383322503703`, 0.9371300887886426],
              UndirectedEdge[203, 369] -> 
             RGBColor[
              0.2744257623445868, 0.405769254195412, 0.9389395132377659], 
             UndirectedEdge[1, 222] -> 
             RGBColor[
              0.48245496695292606`, 0.5881834392083616, 0.9530999932353155], 
             UndirectedEdge[25, 205] -> 
             RGBColor[
              0.9219898136234065, 0.68386598697934, 0.46117782525974793`], 
             UndirectedEdge[301, 380] -> 
             RGBColor[
              0.26115428543555863`, 0.39182009050378686`, 0.9381837222611874],
              UndirectedEdge[169, 329] -> 
             RGBColor[
              0.22791864695390707`, 0.3568873271983817, 0.9362910018173783], 
             UndirectedEdge[302, 340] -> 
             RGBColor[
              0.9905275811721996, 0.978922480132596, 0.484619975557615], 
             UndirectedEdge[205, 391] -> 
             RGBColor[
              0.9078296512801215, 0.575024774186147, 0.4476180378082022], 
             UndirectedEdge[96, 203] -> 
             RGBColor[
              0.28915453203189034`, 0.42125012499470316`, 0.9397782948821958],
              UndirectedEdge[4, 195] -> 
             RGBColor[
              0.2389456018045329, 0.3684773558957079, 0.9369189705832036], 
             UndirectedEdge[269, 298] -> 
             RGBColor[
              0.908244530929823, 0.9248034643520736, 0.7344530675019115], 
             UndirectedEdge[168, 220] -> 
             RGBColor[
              0.5727925024434088, 0.663632053166977, 0.9598025445321408], 
             UndirectedEdge[291, 338] -> 
             RGBColor[
              0.8453899770207604, 0.8765077587109009, 0.7950431863063177], 
             UndirectedEdge[10, 360] -> 
             RGBColor[
              0.336158799712734, 0.4655855893037951, 0.9426407193575084], 
             UndirectedEdge[87, 348] -> 
             RGBColor[
              0.27654696971548504`, 0.4079987776345412, 0.9390603128594934], 
             UndirectedEdge[259, 274] -> 
             RGBColor[
              0.22087433163626, 0.34948330516414705`, 0.9358898384811689], 
             UndirectedEdge[293, 336] -> 
             RGBColor[
              0.21111881242536762`, 0.33922963593785627`, 0.935334276094106], 
             UndirectedEdge[229, 245] -> 
             RGBColor[
              0.238397504828522, 0.36790127122256505`, 0.9368877572712566], 
             UndirectedEdge[173, 197] -> 
             RGBColor[
              0.607559522477704, 0.6724367666110929, 0.8861420267905455], 
             UndirectedEdge[19, 344] -> 
             RGBColor[
              0.2975063791842545, 0.4289298137668702, 0.9402941465258654], 
             UndirectedEdge[83, 125] -> 
             RGBColor[
              0.315433813888692, 0.4447906722692076, 0.9414242734794431], 
             UndirectedEdge[240, 315] -> 
             RGBColor[
              0.24124036831115342`, 0.3708893009907661, 0.9370496541409528], 
             UndirectedEdge[7, 154] -> 
             RGBColor[
              0.40978151173656857`, 0.5293538820737408, 0.9473318934656592], 
             UndirectedEdge[200, 225] -> 
             RGBColor[
              0.26388387983793327`, 0.3946890672869635, 0.9383391686243296], 
             UndirectedEdge[13, 140] -> 
             RGBColor[
              0.8178525622986523, 0.8580700202466935, 0.9570649175635426], 
             UndirectedEdge[104, 366] -> 
             RGBColor[
              0.9175772665295729, 0.7100796035907695, 0.25249503263058215`], 
             UndirectedEdge[116, 172] -> 
             RGBColor[
              0.3588230012593764, 0.484539273770746, 0.9441096471485195], 
             UndirectedEdge[143, 267] -> 
             RGBColor[
              0.5979215961089128, 0.6844587136389835, 0.9614897247861196], 
             UndirectedEdge[51, 395] -> 
             RGBColor[
              0.3229957435790246, 0.45088574591651165`, 0.9419227613726417], 
             UndirectedEdge[213, 224] -> 
             RGBColor[
              0.9433148110399261, 0.8071439818533458, 0.30358552172184644`], 
             UndirectedEdge[130, 362] -> 
             RGBColor[
              0.40753230852825906`, 0.5274057353029433, 0.9471885762261179], 
             UndirectedEdge[153, 278] -> 
             RGBColor[
              0.284923192180341, 0.41599975306012926`, 0.939566726836569], 
             UndirectedEdge[83, 303] -> 
             RGBColor[
              0.32124670467921895`, 0.4509003890486145, 0.9417553090105623], 
             UndirectedEdge[94, 296] -> 
             RGBColor[
              0.2808227544696311, 0.4124928985115602, 0.9393038124757853], 
             UndirectedEdge[147, 328] -> 
             RGBColor[
              0.29708750914626414`, 0.42952428212904603`, 0.9402324060605761],
              UndirectedEdge[78, 102] -> 
             RGBColor[
              0.8305704924938522, 0.23598377814878552`, 0.17690764417753302`],
              UndirectedEdge[22, 45] -> 
             RGBColor[
              0.2939087453063859, 0.4262471045807297, 0.94004904029495], 
             UndirectedEdge[199, 238] -> 
             RGBColor[
              0.22751293603602638`, 0.35646089930013114`, 0.9362678971808005],
              UndirectedEdge[21, 182] -> 
             RGBColor[
              0.30050572685967525`, 0.4327952999017487, 0.9404388491913643], 
             UndirectedEdge[126, 212] -> 
             RGBColor[
              0.21146946129668887`, 0.3395981901340374, 0.9353542450285892], 
             UndirectedEdge[273, 365] -> 
             RGBColor[
              0.26583905724777945`, 0.3967440827101195, 0.9384505130853945], 
             UndirectedEdge[149, 367] -> 
             RGBColor[
              0.21976666504097775`, 0.348319077342387, 0.9358267585072135], 
             UndirectedEdge[81, 89] -> 
             RGBColor[
              0.21914913629591037`, 0.3476700154777373, 0.9357915911587338], 
             UndirectedEdge[57, 337] -> 
             RGBColor[
              0.27897537779675124`, 0.41055118849791716`, 0.9391986071072138],
              UndirectedEdge[255, 288] -> 
             RGBColor[
              0.25275048461760563`, 0.38298716301237146`, 0.9377051382369141],
              UndirectedEdge[2, 283] -> 
             RGBColor[
              0.8636832468154017, 0.4097080433065882, 0.20543575312607748`], 
             UndirectedEdge[94, 128] -> 
             RGBColor[
              0.29316856057651314`, 0.42385416586161573`, 0.9400660193797667],
              UndirectedEdge[176, 393] -> 
             RGBColor[
              0.2193217433014607, 0.3478514363844869, 0.9358014208723507], 
             UndirectedEdge[65, 326] -> 
             RGBColor[
              0.4273612108963405, 0.5428967033575929, 0.9489173037481067], 
             UndirectedEdge[97, 282] -> 
             RGBColor[
              0.5445731104291971, 0.6407794460815519, 0.9574198730781076], 
             UndirectedEdge[12, 149] -> 
             RGBColor[
              0.21932780961758047`, 0.3478578124673555, 0.9358017663400795], 
             UndirectedEdge[78, 144] -> 
             RGBColor[
              0.8601410277678558, 0.4317670823407418, 0.2039906170405674], 
             UndirectedEdge[201, 348] -> 
             RGBColor[
              0.2696907546749492, 0.40079246091779686`, 0.9386698615557961], 
             UndirectedEdge[242, 381] -> 
             RGBColor[
              0.9557469344850966, 0.8527067973943953, 0.5081965742437817], 
             UndirectedEdge[43, 367] -> 
             RGBColor[
              0.22337497152266345`, 0.35211163623448327`, 0.9360322462233344],
              UndirectedEdge[111, 197] -> 
             RGBColor[
              0.931414792844472, 0.7553582824181725, 0.5263607215030722], 
             UndirectedEdge[69, 216] -> 
             RGBColor[
              0.5736600979558795, 0.6645056615859741, 0.959755124057878], 
             UndirectedEdge[197, 295] -> 
             RGBColor[
              0.6155693919444334, 0.6808556472756819, 0.8865981770071358], 
             UndirectedEdge[193, 275] -> 
             RGBColor[
              0.9072201261691099, 0.9260883634638468, 0.8817465180078601], 
             UndirectedEdge[149, 238] -> 
             RGBColor[
              0.2247208711862695, 0.3535262621159006, 0.9361088932180968], 
             UndirectedEdge[79, 349] -> 
             RGBColor[
              0.518092548976322, 0.6194343382750406, 0.9552648492680336], 
             UndirectedEdge[16, 110] -> 
             RGBColor[
              0.2487192272457111, 0.3787500559180304, 0.9374755640932957], 
             UndirectedEdge[49, 372] -> 
             RGBColor[
              0.25360695200292194`, 0.3838873645375076, 0.9377539127874779], 
             UndirectedEdge[320, 343] -> 
             RGBColor[
              0.7160472963068527, 0.7781008571267078, 0.9723325607195863], 
             UndirectedEdge[221, 358] -> 
             RGBColor[
              0.9452177942477327, 0.9230965860350502, 0.6624178282504138], 
             UndirectedEdge[240, 245] -> 
             RGBColor[
              0.2345526793265548, 0.3638601158439808, 0.9366688001468292], 
             UndirectedEdge[85, 115] -> 
             RGBColor[
              0.2399567828787064, 0.36954017131724737`, 0.9369765558494695], 
             UndirectedEdge[70, 280] -> 
             RGBColor[
              0.2584116720913199, 0.38893742998726233`, 0.9380275344885658], 
             UndirectedEdge[151, 171] -> 
             RGBColor[
              0.294524052203641, 0.4262383567855898, 0.940108081239609], 
             UndirectedEdge[23, 163] -> 
             RGBColor[
              0.22919558870789478`, 0.35822947394460614`, 0.9363637217612019],
              UndirectedEdge[255, 360] -> 
             RGBColor[
              0.28543335040527573`, 0.4171867688467138, 0.9395719503550848], 
             UndirectedEdge[165, 307] -> 
             RGBColor[
              0.7589943744265952, 0.8098564226113569, 0.9253172138967432], 
             UndirectedEdge[81, 169] -> 
             RGBColor[
              0.22020695780518662`, 0.3487818529537441, 0.9358518325287805], 
             UndirectedEdge[44, 316] -> 
             RGBColor[
              0.27611802500026855`, 0.4075479295421829, 0.9390358850925288], 
             UndirectedEdge[195, 337] -> 
             RGBColor[
              0.26521901916211443`, 0.39609238336940045`, 0.9384152028336801],
              UndirectedEdge[316, 390] -> 
             RGBColor[
              0.26028939055795897`, 0.3909110311499271, 0.9381344677774055], 
             UndirectedEdge[39, 177] -> 
             RGBColor[
              0.29750028265951367`, 0.4288050749279245, 0.9402981320155486], 
             UndirectedEdge[45, 190] -> 
             RGBColor[
              0.2683010399450559, 0.3993317826236759, 0.9385907193578275], 
             UndirectedEdge[287, 396] -> 
             RGBColor[
              0.2692564543945499, 0.400335983786869, 0.9386451287973171], 
             UndirectedEdge[136, 343] -> 
             RGBColor[
              0.6703913429941837, 0.7420698478255596, 0.9680310290897323], 
             UndirectedEdge[296, 360] -> 
             RGBColor[
              0.3059566318031602, 0.4387580388470877, 0.9407407208692202], 
             UndirectedEdge[167, 228] -> 
             RGBColor[
              0.32570332239411426`, 0.45419998876459156`, 0.9420598033482018],
              UndirectedEdge[123, 279] -> 
             RGBColor[
              0.9599728871641575, 0.901288321876893, 0.6017603738326488], 
             UndirectedEdge[33, 333] -> 
             RGBColor[
              0.1872509211104506, 0.3141429688541644, 0.9339750349931024], 
             UndirectedEdge[164, 209] -> 
             RGBColor[
              0.24728574846658016`, 0.37724337883335973`, 0.9373939295974659],
              UndirectedEdge[22, 29] -> 
             RGBColor[
              0.2663738031073146, 0.39730613451333674`, 0.9384809660710094], 
             UndirectedEdge[24, 366] -> 
             RGBColor[
              0.9017167350633479, 0.6466004732099342, 0.2397023734046333], 
             UndirectedEdge[178, 319] -> 
             RGBColor[
              0.24278605838252734`, 0.37251391925819094`, 0.9371376789038741],
              UndirectedEdge[294, 368] -> 
             RGBColor[
              0.21277052855345546`, 0.3409656943133277, 0.9354283388841056], 
             UndirectedEdge[13, 69] -> 
             RGBColor[
              0.7259993754166094, 0.7839523785382002, 0.9495242388978706], 
             UndirectedEdge[214, 295] -> 
             RGBColor[
              0.6130802218515281, 0.6797567159185416, 0.9247335360686406], 
             UndirectedEdge[80, 146] -> 
             RGBColor[
              0.4348738177323767, 0.548860724677587, 0.9495460387678236], 
             UndirectedEdge[56, 231] -> 
             RGBColor[
              0.37980957762799716`, 0.5033879783145618, 0.9454223177963867], 
             UndirectedEdge[134, 351] -> 
             RGBColor[
              0.24003567899790235`, 0.3696230961408251, 0.9369810488667414], 
             UndirectedEdge[143, 291] -> 
             RGBColor[
              0.6605679134983766, 0.7344885741946573, 0.9669884297148228], 
             UndirectedEdge[120, 320] -> 
             RGBColor[
              0.6381361673517921, 0.7160721638444079, 0.9653628908870006], 
             UndirectedEdge[132, 220] -> 
             RGBColor[
              0.6373284381573086, 0.7140480166379533, 0.9662348834814941], 
             UndirectedEdge[6, 247] -> 
             RGBColor[
              0.9501775412917424, 0.8286011525137683, 0.3806667888005933], 
             UndirectedEdge[166, 289] -> 
             RGBColor[
              0.8612612060617832, 0.40999762047401866`, 0.2038737104047185], 
             UndirectedEdge[114, 392] -> 
             RGBColor[
              0.2884135464934976, 0.418609972282043, 0.9398042492586839], 
             UndirectedEdge[305, 325] -> 
             RGBColor[
              0.20723516257555488`, 0.3351476737080805, 0.9351131079805042], 
             UndirectedEdge[44, 128] -> 
             RGBColor[
              0.3120848480897295, 0.44373638339990634`, 0.9411432739695049], 
             UndirectedEdge[90, 242] -> 
             RGBColor[
              0.8120763207412868, 0.7420397918675932, 0.6122349694370377], 
             UndirectedEdge[1, 337] -> 
             RGBColor[
              0.3223631828098259, 0.4514173086943011, 0.9418429310198984], 
             UndirectedEdge[74, 224] -> 
             RGBColor[
              0.9001674923644503, 0.8962994775971298, 0.6715446357629462], 
             UndirectedEdge[160, 370] -> 
             RGBColor[
              0.8303471028154521, 0.5479183884634005, 0.5798122246722852], 
             UndirectedEdge[30, 84] -> 
             RGBColor[
              0.1789270231889713, 0.3053940243730791, 0.9335010013205776], 
             UndirectedEdge[293, 299] -> 
             RGBColor[
              0.21267988324051307`, 0.34087042034218046`, 0.9354231767676313],
              UndirectedEdge[186, 399] -> 
             RGBColor[
              0.24167334431028037`, 0.3713443862181124, 0.9370743114835726], 
             UndirectedEdge[163, 371] -> 
             RGBColor[
              0.25850942763125473`, 0.3890401772577931, 0.9380331015219487], 
             UndirectedEdge[90, 138] -> 
             RGBColor[
              0.7625743389841517, 0.45989176227570816`, 0.5687339252858672], 
             UndirectedEdge[71, 286] -> 
             RGBColor[
              0.798684946393064, 0.8430713308000524, 0.9804594287308144], 
             UndirectedEdge[60, 201] -> 
             RGBColor[
              0.3169773146449097, 0.44598337270948407`, 0.9415279039366844], 
             UndirectedEdge[128, 380] -> 
             RGBColor[
              0.2958519089446212, 0.4266745351306104, 0.9402188320996724], 
             UndirectedEdge[54, 128] -> 
             RGBColor[
              0.3891023193866603, 0.5114426050266787, 0.9460142336150148], 
             UndirectedEdge[25, 138] -> 
             RGBColor[
              0.8340269956702107, 0.26255197621162585`, 0.18021759552277578`],
              UndirectedEdge[95, 129] -> 
             RGBColor[
              0.2597315005548766, 0.39032465338441835`, 0.9381026967670542], 
             UndirectedEdge[132, 302] -> 
             RGBColor[
              0.8932496977556434, 0.905911220002762, 0.6928483915783341], 
             UndirectedEdge[15, 100] -> 
             RGBColor[
              0.34023750094859895`, 0.4686666959527124, 0.9429171480552854], 
             UndirectedEdge[33, 63] -> 
             RGBColor[
              0.5687512197366357, 0.5886439817299056, 0.6135098819197802], 
             UndirectedEdge[275, 338] -> 
             RGBColor[
              0.9931945073855819, 0.9905965803379274, 0.7001396493067182], 
             UndirectedEdge[252, 277] -> 
             RGBColor[
              0.2410729775793306, 0.3707133627184349, 0.9370401214864079], 
             UndirectedEdge[146, 192] -> 
             RGBColor[
              0.43991049068666355`, 0.5532232376400468, 0.9498669711147159], 
             UndirectedEdge[237, 254] -> 
             RGBColor[
              0.5239652108029346, 0.6244175883504002, 0.9556676072236672], 
             UndirectedEdge[37, 236] -> 
             RGBColor[
              0.2501608630823501, 0.3802653065873294, 0.9375576631214831], 
             UndirectedEdge[265, 362] -> 
             RGBColor[
              0.4982768620774518, 0.6022414244020411, 0.9540103792474512], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.31424207897729384`, 0.44465323780495364`, 0.9413155746707285],
              UndirectedEdge[341, 379] -> 
             RGBColor[
              0.2212705365436844, 0.3498997416426921, 0.9359124017645142], 
             UndirectedEdge[324, 380] -> 
             RGBColor[
              0.27272415965434393`, 0.4039807618801248, 0.9388426094818522], 
             UndirectedEdge[63, 264] -> 
             RGBColor[
              0.5742960336344989, 0.5944719326980662, 0.6138256508684465], 
             UndirectedEdge[153, 337] -> 
             RGBColor[
              0.30108704647180895`, 0.43298898876801645`, 0.9404872344261885],
              UndirectedEdge[112, 155] -> 
             RGBColor[
              0.31673339546261187`, 0.44837192664657105`, 0.9414171693125639],
              UndirectedEdge[10, 177] -> 
             RGBColor[
              0.34191718866131093`, 0.47057321638600846`, 0.9430076388093683],
              UndirectedEdge[238, 367] -> 
             RGBColor[
              0.2242689013320493, 0.35305121314257126`, 0.9360831542035284], 
             UndirectedEdge[87, 228] -> 
             RGBColor[
              0.32899794708810315`, 0.4576628482092444, 0.9422474273505641], 
             UndirectedEdge[66, 352] -> 
             RGBColor[
              0.983468511290683, 0.9548785202107917, 0.47692950075693274`], 
             UndirectedEdge[86, 386] -> 
             RGBColor[
              0.31994974783175406`, 0.4507870854822257, 0.9416356849958585], 
             UndirectedEdge[52, 133] -> 
             RGBColor[
              0.34195185422260005`, 0.4695411184843201, 0.9430487372114036], 
             UndirectedEdge[105, 112] -> 
             RGBColor[
              0.37313264037284266`, 0.49761047172431544`, 0.944996659789687], 
             UndirectedEdge[4, 258] -> 
             RGBColor[
              0.24256487951038092`, 0.3722814462400146, 0.9371250830943101], 
             UndirectedEdge[141, 339] -> 
             RGBColor[
              0.36291222472736206`, 0.48875806138522676`, 0.9443454239423157],
              UndirectedEdge[251, 282] -> 
             RGBColor[
              0.7345888082776114, 0.7926044746200289, 0.9741756038265081], 
             UndirectedEdge[94, 390] -> 
             RGBColor[
              0.26321162125265696`, 0.393982480890182, 0.9383008844924156], 
             UndirectedEdge[239, 337] -> 
             RGBColor[
              0.304629125717821, 0.43605695978083275`, 0.9407129325836068], 
             UndirectedEdge[80, 243] -> 
             RGBColor[
              0.3113941751763021, 0.44225199630561496`, 0.9411317115948465], 
             UndirectedEdge[366, 382] -> 
             RGBColor[
              0.9000306839899277, 0.6389445090727658, 0.23829549106007777`], 
             UndirectedEdge[99, 306] -> 
             RGBColor[
              0.9742518584397497, 0.947471002545973, 0.6306628392778444], 
             UndirectedEdge[214, 261] -> 
             RGBColor[
              0.5816107316395323, 0.6466802864248125, 0.9229413951560062], 
             UndirectedEdge[21, 60] -> 
             RGBColor[
              0.33522274220732345`, 0.4647748233402267, 0.9425810746009868], 
             UndirectedEdge[60, 159] -> 
             RGBColor[
              0.344481468526375, 0.4727942667206735, 0.9431710324548666], 
             UndirectedEdge[9, 300] -> 
             RGBColor[
              0.8578321079350941, 0.3958398187210729, 0.2010677137447785], 
             UndirectedEdge[114, 369] -> 
             RGBColor[
              0.29316591487643506`, 0.4236050127700691, 0.9400748896075932], 
             UndirectedEdge[112, 350] -> 
             RGBColor[
              0.380831960891249, 0.5042792361782578, 0.945487253684878], 
             UndirectedEdge[18, 357] -> 
             RGBColor[
              0.8104483343258964, 0.8526146189392179, 0.9729726519131952], 
             UndirectedEdge[71, 320] -> 
             RGBColor[
              0.7905070166194959, 0.8366826699063725, 0.9796443291180839], 
             UndirectedEdge[226, 255] -> 
             RGBColor[
              0.24955450248561023`, 0.3796279831546734, 0.9375231317825289], 
             UndirectedEdge[208, 258] -> 
             RGBColor[
              0.24300998977440907`, 0.3727492853491289, 0.9371504314653649], 
             UndirectedEdge[11, 358] -> 
             RGBColor[
              0.9460196672175634, 0.8199629343977746, 0.2948506005623025], 
             UndirectedEdge[274, 299] -> 
             RGBColor[
              0.22242833776812287`, 0.35111666413841447`, 0.9359783368314325],
              UndirectedEdge[147, 372] -> 
             RGBColor[
              0.2681076692483716, 0.3991285377610505, 0.9385797071827175], 
             UndirectedEdge[335, 337] -> 
             RGBColor[
              0.282630755782611, 0.41439322252540617`, 0.9394067754758614], 
             UndirectedEdge[36, 218] -> 
             RGBColor[
              0.7148705349959443, 0.7760303162882036, 0.9733069680605333], 
             UndirectedEdge[262, 300] -> 
             RGBColor[
              0.9143198191766551, 0.7735717057130247, 0.6093343830407926], 
             UndirectedEdge[109, 136] -> 
             RGBColor[
              0.8063392816861509, 0.8465292984919313, 0.8553084156056971], 
             UndirectedEdge[219, 241] -> 
             RGBColor[
              0.36907489621161843`, 0.49245160059313714`, 0.9447983082263991],
              UndirectedEdge[37, 348] -> 
             RGBColor[
              0.2563773742968305, 0.38679925402332427`, 0.9379116842386436], 
             UndirectedEdge[291, 384] -> 
             RGBColor[
              0.7224597094549363, 0.7831102830141358, 0.9729716901347794], 
             UndirectedEdge[10, 241] -> 
             RGBColor[
              0.32644391245681637`, 0.4555267851602728, 0.9420818996386419], 
             UndirectedEdge[131, 314] -> 
             RGBColor[
              0.9241390802378358, 0.8369963141242439, 0.6246293196235244], 
             UndirectedEdge[1, 41] -> 
             RGBColor[
              0.3504016747423545, 0.4779220517867386, 0.943548262759916], 
             UndirectedEdge[78, 400] -> 
             RGBColor[
              0.6157274285874001, 0.4172598139869824, 0.5668748799123404], 
             UndirectedEdge[191, 357] -> 
             RGBColor[
              0.6772717325975683, 0.7478090920518159, 0.9684677749072899], 
             UndirectedEdge[215, 352] -> 
             RGBColor[
              0.906721166296464, 0.5695838616411621, 0.3855978109611532], 
             UndirectedEdge[96, 369] -> 
             RGBColor[
              0.27218271865818583`, 0.40341167306382075`, 0.9388117752181111],
              UndirectedEdge[212, 293] -> 
             RGBColor[
              0.2110641194014849, 0.3391721501020175, 0.935331161407307], 
             UndirectedEdge[66, 107] -> 
             RGBColor[
              0.906000283356856, 0.6111511383099929, 0.2669776426492963], 
             UndirectedEdge[146, 159] -> 
             RGBColor[
              0.433382915877228, 0.5475693804255631, 0.9494510398199664], 
             UndirectedEdge[11, 207] -> 
             RGBColor[
              0.931659240059644, 0.7667586905843885, 0.26386962426942273`], 
             UndirectedEdge[99, 218] -> 
             RGBColor[
              0.9440956875300477, 0.9571661739174645, 0.9565961673645738], 
             UndirectedEdge[131, 217] -> 
             RGBColor[
              0.8726459244985081, 0.4533824718485052, 0.21298193244244573`], 
             UndirectedEdge[81, 163] -> 
             RGBColor[
              0.23234434831161116`, 0.36153901993100174`, 0.9365430389624612],
              UndirectedEdge[50, 54] -> 
             RGBColor[
              0.4530695590105145, 0.5668252864420751, 0.9500963936878091], 
             UndirectedEdge[120, 286] -> 
             RGBColor[
              0.6463140971253603, 0.7224608247380875, 0.966177990499731], 
             UndirectedEdge[17, 253] -> 
             RGBColor[
              0.43861619159981363`, 0.5520971476660097, 0.9497858901980598], 
             UndirectedEdge[45, 365] -> 
             RGBColor[
              0.2758699057154388, 0.4072871404421556, 0.9390217550663172], 
             UndirectedEdge[35, 188] -> 
             RGBColor[
              0.27406348456255775`, 0.4053884772767613, 0.9389188820540213], 
             UndirectedEdge[99, 279] -> 
             RGBColor[
              0.9618886205302903, 0.9027170726846294, 0.5985175369470697], 
             UndirectedEdge[107, 363] -> 
             RGBColor[
              0.8508650866892753, 0.3855165088466559, 0.1960887969103411], 
             UndirectedEdge[105, 271] -> 
             RGBColor[
              0.36206599633926584`, 0.4878440595940245, 0.9442981318263466], 
             UndirectedEdge[191, 219] -> 
             RGBColor[
              0.5630206032370957, 0.6553990201614963, 0.9591704044347413], 
             UndirectedEdge[177, 339] -> 
             RGBColor[
              0.34383450141698674`, 0.4722338963280338, 0.9431298082827468], 
             UndirectedEdge[80, 167] -> 
             RGBColor[
              0.30898293281547473`, 0.43971762770278966`, 0.9409943949095109],
              UndirectedEdge[48, 56] -> 
             RGBColor[
              0.43818896314994105`, 0.5539589886879809, 0.9491419911499963], 
             UndirectedEdge[42, 136] -> 
             RGBColor[
              0.7754039881303256, 0.825013733522431, 0.9782569627328132], 
             UndirectedEdge[77, 102] -> 
             RGBColor[
              0.8243310697046711, 0.5080541422905515, 0.574849473505362], 
             UndirectedEdge[73, 203] -> 
             RGBColor[
              0.2672567761777972, 0.39823419519414005`, 0.9385312500811318], 
             UndirectedEdge[35, 284] -> 
             RGBColor[
              0.26251957032631373`, 0.3932550914880322, 0.9382614732159579], 
             UndirectedEdge[274, 367] -> 
             RGBColor[
              0.22502133411732347`, 0.3538420677068884, 0.9361260041375251], 
             UndirectedEdge[33, 310] -> 
             RGBColor[
              0.18075976862012855`, 0.3073203560239972, 0.9336053734615781], 
             UndirectedEdge[175, 295] -> 
             RGBColor[
              0.21065974573871524`, 0.33874712774367555`, 0.9353081329254295],
              UndirectedEdge[70, 75] -> 
             RGBColor[
              0.2609941288153654, 0.3916517557414475, 0.9381746015785979], 
             UndirectedEdge[57, 258] -> 
             RGBColor[
              0.26307034244570515`, 0.39383398790648194`, 0.9382928388733629],
              UndirectedEdge[70, 145] -> 
             RGBColor[
              0.2579170969731607, 0.3884176001802034, 0.937999369167245], 
             UndirectedEdge[12, 336] -> 
             RGBColor[
              0.21472177259901426`, 0.343016575521228, 0.9355394593458932], 
             UndirectedEdge[18, 216] -> 
             RGBColor[
              0.8021540700559975, 0.8461350766528297, 0.9721459571650781], 
             UndirectedEdge[158, 311] -> 
             RGBColor[
              0.5112449698673547, 0.6140907237185725, 0.9546662232614405], 
             UndirectedEdge[8, 36] -> 
             RGBColor[
              0.41499862525248465`, 0.5320708731128857, 0.9481621689265505], 
             UndirectedEdge[119, 200] -> 
             RGBColor[
              0.2555790109882331, 0.38596012356683096`, 0.9378662186292916], 
             UndirectedEdge[181, 362] -> 
             RGBColor[
              0.4859856594800335, 0.59226287242109, 0.9530427707548238], 
             UndirectedEdge[9, 306] -> 
             RGBColor[
              0.8980217768542582, 0.5550152880766823, 0.25581485333926096`], 
             UndirectedEdge[82, 253] -> 
             RGBColor[
              0.3604664667584644, 0.48663966875993736`, 0.9441895824072364], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.47490752561281135`, 0.5839962194337451, 0.9519697664459024], 
             UndirectedEdge[146, 314] -> 
             RGBColor[
              0.7305716091219763, 0.7886632000372383, 0.9746741748807553], 
             UndirectedEdge[27, 277] -> 
             RGBColor[
              0.277614773953709, 0.4091211075916136, 0.9391211227311855], 
             UndirectedEdge[6, 302] -> 
             RGBColor[
              0.9903122885265428, 0.9784619909329613, 0.461186699710061], 
             UndirectedEdge[93, 296] -> 
             RGBColor[
              0.27337982614775685`, 0.40466990893635857`, 0.9388799487186803],
              UndirectedEdge[153, 284] -> 
             RGBColor[
              0.2807144253547577, 0.4115760722752118, 0.9393270437921646], 
             UndirectedEdge[43, 199] -> 
             RGBColor[
              0.2266190062266405, 0.3555213223920431, 0.9362169892006067], 
             UndirectedEdge[213, 250] -> 
             RGBColor[
              0.9495976653580405, 0.8370624678097084, 0.5459950352795185], 
             UndirectedEdge[3, 232] -> 
             RGBColor[
              0.4478181508511241, 0.5603378585517222, 0.9502975085529524], 
             UndirectedEdge[5, 235] -> 
             RGBColor[
              0.7907683520113988, 0.8366469590661592, 0.9797340301887447], 
             UndirectedEdge[25, 391] -> 
             RGBColor[
              0.8345509525864179, 0.2665793386689794, 0.18071933725746053`], 
             UndirectedEdge[288, 341] -> 
             RGBColor[
              0.2333048519876323, 0.3625485701939505, 0.9365977382258728], 
             UndirectedEdge[181, 265] -> 
             RGBColor[
              0.5796034948121, 0.6695872537851715, 0.9600476567506184], 
             UndirectedEdge[295, 363] -> 
             RGBColor[
              0.5524499218387339, 0.42033901047071287`, 0.5720521832312901], 
             UndirectedEdge[278, 284] -> 
             RGBColor[
              0.24820685681048946`, 0.3782115221044505, 0.9374463853549939], 
             UndirectedEdge[167, 351] -> 
             RGBColor[
              0.2646469792533301, 0.39549113315584294`, 0.938382626007132], 
             UndirectedEdge[198, 311] -> 
             RGBColor[
              0.6729318339898602, 0.7425873401033549, 0.9693093430316602], 
             UndirectedEdge[54, 328] -> 
             RGBColor[
              0.38071433549214345`, 0.504177354969577, 0.9454797586984591], 
             UndirectedEdge[261, 310] -> 
             RGBColor[
              0.18101326007132248`, 0.3075867916114884, 0.9336198094247166], 
             UndirectedEdge[68, 319] -> 
             RGBColor[
              0.2591541477712746, 0.38971781900257185`, 0.9380698173801449], 
             UndirectedEdge[100, 141] -> 
             RGBColor[
              0.3683390164516885, 0.49345847561835543`, 0.9446912143122663], 
             UndirectedEdge[139, 325] -> 
             RGBColor[
              0.21136919529828035`, 0.33949280421247857`, 0.9353485350283102],
              UndirectedEdge[123, 338] -> 
             RGBColor[
              0.9842922541931751, 0.9852712070496027, 0.7740485310892328], 
             UndirectedEdge[317, 370] -> 
             RGBColor[
              0.9109218435003366, 0.9293228266692952, 0.8943803638429948], 
             UndirectedEdge[160, 400] -> 
             RGBColor[
              0.6095442446912597, 0.3697331530727862, 0.5609538560304888], 
             UndirectedEdge[150, 266] -> 
             RGBColor[
              0.2627993543398047, 0.39354916222554226`, 0.9382774065016228], 
             UndirectedEdge[134, 201] -> 
             RGBColor[
              0.255376576823433, 0.3857473524245587, 0.9378546903030808], 
             UndirectedEdge[161, 251] -> 
             RGBColor[
              0.6268762447587527, 0.7046334098478555, 0.9658130763902817], 
             UndirectedEdge[86, 371] -> 
             RGBColor[
              0.2862909803459218, 0.418240350613087, 0.9396152198499249], 
             UndirectedEdge[105, 350] -> 
             RGBColor[
              0.4250434301807523, 0.5425729887437677, 0.948304369413338], 
             UndirectedEdge[54, 362] -> 
             RGBColor[
              0.4283252562737149, 0.5454155415561164, 0.9485134844699766], 
             UndirectedEdge[4, 208] -> 
             RGBColor[
              0.23264160776787357`, 0.36185145846687167`, 0.9365599674487393],
              UndirectedEdge[176, 294] -> 
             RGBColor[
              0.21429151975408078`, 0.34256435250159695`, 0.9355149570828762],
              UndirectedEdge[113, 170] -> 
             RGBColor[
              0.6207426403130438, 0.7003977045332692, 0.9649634716556403], 
             UndirectedEdge[14, 205] -> 
             RGBColor[
              0.9948127950472943, 0.9913250536932577, 0.6776287249236647], 
             UndirectedEdge[262, 306] -> 
             RGBColor[
              0.9545094880958191, 0.9327471750686342, 0.664081522635275], 
             UndirectedEdge[47, 128] -> 
             RGBColor[
              0.3800525355791988, 0.5036041371480152, 0.945437589393213], 
             UndirectedEdge[257, 382] -> 
             RGBColor[
              0.8606940459931985, 0.4040219113453448, 0.20326730826890227`], 
             UndirectedEdge[165, 228] -> 
             RGBColor[
              0.4503029757321284, 0.5622948057743279, 0.9505097967266875], 
             UndirectedEdge[72, 341] -> 
             RGBColor[
              0.22465511090045148`, 0.353457143886063, 0.936105148267103], 
             UndirectedEdge[50, 116] -> 
             RGBColor[
              0.4351844866677396, 0.551334135708637, 0.9489567726932759], 
             UndirectedEdge[230, 247] -> 
             RGBColor[
              0.9379323861994966, 0.7878165939520326, 0.28877547346743154`], 
             UndirectedEdge[45, 100] -> 
             RGBColor[
              0.33605658973236274`, 0.46427229317936647`, 0.9426790513466246],
              UndirectedEdge[95, 386] -> 
             RGBColor[
              0.3105708355384495, 0.4409292540045774, 0.9411015698156122], 
             UndirectedEdge[182, 244] -> 
             RGBColor[
              0.27406524356197104`, 0.4053903260966717, 0.9389189822264357], 
             UndirectedEdge[104, 382] -> 
             RGBColor[
              0.9163275048198573, 0.7044047275562138, 0.25145220082553266`], 
             UndirectedEdge[58, 210] -> 
             RGBColor[
              0.2993673513669953, 0.4319844456460439, 0.9403598998348177], 
             UndirectedEdge[102, 370] -> 
             RGBColor[
              0.8252568296209774, 0.5087923181187306, 0.5749377733126149], 
             UndirectedEdge[1, 161] -> 
             RGBColor[
              0.3957098398241182, 0.5171657071259712, 0.9464352589744887], 
             UndirectedEdge[153, 356] -> 
             RGBColor[
              0.4179045828513193, 0.5346231354649491, 0.9483375893388631], 
             UndirectedEdge[1, 154] -> 
             RGBColor[
              0.39507053133992803`, 0.5166119702495444, 0.9463945228031945], 
             UndirectedEdge[341, 399] -> 
             RGBColor[
              0.22823136465623345`, 0.3572160133309742, 0.9363088106279014], 
             UndirectedEdge[373, 395] -> 
             RGBColor[
              0.2616949498810116, 0.3923883631160637, 0.9382145123015146], 
             UndirectedEdge[190, 266] -> 
             RGBColor[
              0.24805045871485498`, 0.3780471377897267, 0.9374374787148178], 
             UndirectedEdge[73, 85] -> 
             RGBColor[
              0.24221172142071856`, 0.3719102546962633, 0.9371049712635544], 
             UndirectedEdge[221, 250] -> 
             RGBColor[
              0.955043066437527, 0.9649644792718597, 0.9185889663100797], 
             UndirectedEdge[23, 353] -> 
             RGBColor[
              0.21189878814995255`, 0.34004943987771225`, 0.9353786945577505],
              UndirectedEdge[171, 270] -> 
             RGBColor[
              0.2613998670743656, 0.3920782123769482, 0.9381977077722119], 
             UndirectedEdge[277, 396] -> 
             RGBColor[
              0.26805617252313807`, 0.399074411437749, 0.9385767745203981], 
             UndirectedEdge[315, 371] -> 
             RGBColor[
              0.25765991596594773`, 0.388147286635405, 0.9379847230893494], 
             UndirectedEdge[207, 391] -> 
             RGBColor[
              0.8801233042529734, 0.4784967588439868, 0.2188121666480132], 
             UndirectedEdge[160, 247] -> 
             RGBColor[
              0.8682425607038025, 0.44830305029724704`, 0.2099476795487854], 
             UndirectedEdge[193, 232] -> 
             RGBColor[
              0.6739481277148399, 0.7434424430617759, 0.9693547854990241], 
             UndirectedEdge[22, 91] -> 
             RGBColor[
              0.2774698045998931, 0.40896873560916513`, 0.9391128669409485], 
             UndirectedEdge[78, 247] -> 
             RGBColor[
              0.874425744599943, 0.49582971121144337`, 0.21586870343063702`], 
             UndirectedEdge[87, 192] -> 
             RGBColor[
              0.3173142304637505, 0.44754300010990244`, 0.9415029512587653], 
             UndirectedEdge[226, 294] -> 
             RGBColor[
              0.22569678935260098`, 0.35455201398550057`, 0.9361644703139277],
              UndirectedEdge[177, 311] -> 
             RGBColor[
              0.42064126980492156`, 0.5369664823599833, 0.9485194381294991], 
             UndirectedEdge[189, 200] -> 
             RGBColor[
              0.28560319899075254`, 0.41751744880094743`, 0.9395760517192293],
              UndirectedEdge[67, 184] -> 
             RGBColor[
              0.2153543932680198, 0.3436814999548199, 0.9355754861571146], 
             UndirectedEdge[33, 256] -> 
             RGBColor[
              0.202124876078153, 0.3297764385884332, 0.9348220847244686], 
             UndirectedEdge[176, 226] -> 
             RGBColor[
              0.22722875741095702`, 0.3561622095472178, 0.9362517136285073], 
             UndirectedEdge[145, 162] -> 
             RGBColor[
              0.2420540274215789, 0.3717445083047905, 0.9370959908235907], 
             UndirectedEdge[286, 343] -> 
             RGBColor[
              0.7242252260804207, 0.7844895180203877, 0.9731476603323168], 
             UndirectedEdge[13, 18] -> 
             RGBColor[
              0.9544933475167275, 0.9655817936050558, 0.9619150720050708], 
             UndirectedEdge[86, 308] -> 
             RGBColor[
              0.28081236703944734`, 0.4124819806638359, 0.9393032209270034], 
             UndirectedEdge[364, 377] -> 
             RGBColor[
              0.3822045767059832, 0.5054681270073037, 0.9455747155508364], 
             UndirectedEdge[90, 152] -> 
             RGBColor[
              0.4447109838202162, 0.5402113672268555, 0.9525399126533038], 
             UndirectedEdge[1, 153] -> 
             RGBColor[
              0.33870689706262624`, 0.4677926231571751, 0.9428030818674495], 
             UndirectedEdge[92, 114] -> 
             RGBColor[
              0.3082708613262549, 0.43948126919774927`, 0.9409350939621447], 
             UndirectedEdge[132, 219] -> 
             RGBColor[
              0.6232051027562657, 0.7024156086050097, 0.9651690328906872], 
             UndirectedEdge[107, 215] -> 
             RGBColor[
              0.829252938362637, 0.22585647974036333`, 0.17564595285351675`], 
             UndirectedEdge[240, 319] -> 
             RGBColor[
              0.24039509168830792`, 0.37000086166652213`, 0.9370015168877566],
              UndirectedEdge[58, 110] -> 
             RGBColor[
              0.2771944683256158, 0.40867933972757164`, 0.939097186947452], 
             UndirectedEdge[67, 85] -> 
             RGBColor[
              0.22712666696496037`, 0.35605490601556716`, 0.9362458997286371],
              UndirectedEdge[125, 344] -> 
             RGBColor[
              0.2993073040655987, 0.4308227000023955, 0.9403967065336283], 
             UndirectedEdge[198, 219] -> 
             RGBColor[
              0.6368387366010516, 0.7131188895622445, 0.9665139522992866], 
             UndirectedEdge[16, 325] -> 
             RGBColor[
              0.22671411419860138`, 0.35562128690076766`, 0.9362224054589102],
              UndirectedEdge[119, 390] -> 
             RGBColor[
              0.2533988208527428, 0.3836686055023921, 0.9377420600263777], 
             UndirectedEdge[7, 153] -> 
             RGBColor[
              0.3534178774592668, 0.48053453498137155`, 0.9437404525299142], 
             UndirectedEdge[23, 164] -> 
             RGBColor[
              0.22797821780387265`, 0.3569499399387055, 0.9362943942891566], 
             UndirectedEdge[46, 373] -> 
             RGBColor[
              0.26731905714517273`, 0.3982996564396932, 0.9385347968900875], 
             UndirectedEdge[301, 316] -> 
             RGBColor[
              0.2555487063727525, 0.3859282714945373, 0.9378644928262717], 
             UndirectedEdge[22, 150] -> 
             RGBColor[
              0.28145958694833023`, 0.41316224982418415`, 0.9393400791433381],
              UndirectedEdge[161, 327] -> 
             RGBColor[
              0.3750143899762539, 0.4992403486513052, 0.9451165632104506], 
             UndirectedEdge[123, 281] -> 
             RGBColor[
              0.8031450913153519, 0.8462354724290008, 0.9462830761380823], 
             UndirectedEdge[111, 160] -> 
             RGBColor[
              0.8517778667942718, 0.37434165466445646`, 0.19625056684916897`],
              UndirectedEdge[277, 287] -> 
             RGBColor[
              0.25901311175833214`, 0.3895695812107696, 0.9380617855878519], 
             UndirectedEdge[48, 120] -> 
             RGBColor[
              0.49591060473188847`, 0.6008847208403402, 0.9536681725336434], 
             UndirectedEdge[6, 224] -> 
             RGBColor[
              0.9845045256450395, 0.9588710430060774, 0.43862463761941295`], 
             UndirectedEdge[103, 313] -> 
             RGBColor[
              0.31368725505562867`, 0.4437237541060531, 0.9412966590550009], 
             UndirectedEdge[8, 60] -> 
             RGBColor[
              0.33392414851101215`, 0.4636500467496988, 0.9424983293589592], 
             UndirectedEdge[284, 392] -> 
             RGBColor[
              0.24597365109495675`, 0.3758642813040053, 0.9373192075932261], 
             UndirectedEdge[218, 279] -> 
             RGBColor[
              0.9278567069516805, 0.8766750653657154, 0.6332052588371474], 
             UndirectedEdge[135, 221] -> 
             RGBColor[
              0.7125684826637311, 0.7740760557086418, 0.9732239792621271], 
             UndirectedEdge[95, 309] -> 
             RGBColor[
              0.2762844897757238, 0.4077228945756627, 0.9390453650152284], 
             UndirectedEdge[80, 385] -> 
             RGBColor[
              0.4549187217473041, 0.5651340807695402, 0.9511240470387816], 
             UndirectedEdge[272, 398] -> 
             RGBColor[
              0.7932211653132651, 0.8392589768677534, 0.976436715616906], 
             UndirectedEdge[33, 264] -> 
             RGBColor[
              0.18448620056776344`, 0.31123707227039327`, 0.9338175882482339],
              UndirectedEdge[76, 366] -> 
             RGBColor[
              0.8741124408312237, 0.5032302339331254, 0.2159628369001264], 
             UndirectedEdge[41, 258] -> 
             RGBColor[
              0.29687678880049106`, 0.4264012168061446, 0.9403266470848042], 
             UndirectedEdge[174, 232] -> 
             RGBColor[
              0.6270810139261389, 0.7068104580353534, 0.9646885621008761], 
             UndirectedEdge[61, 307] -> 
             RGBColor[
              0.9892929392100926, 0.9881701251038566, 0.7056981044009731], 
             UndirectedEdge[35, 392] -> 
             RGBColor[
              0.2644951314363644, 0.3953315314725043, 0.9383739784985945], 
             UndirectedEdge[212, 259] -> 
             RGBColor[
              0.2109589325174653, 0.33906159201767927`, 0.935325171169872], 
             UndirectedEdge[73, 110] -> 
             RGBColor[
              0.24934696023893294`, 0.3794098430944771, 0.9375113125586119], 
             UndirectedEdge[122, 228] -> 
             RGBColor[
              0.40697238168033323`, 0.5269207548100117, 0.9471528981824919], 
             UndirectedEdge[41, 203] -> 
             RGBColor[
              0.31610894590117855`, 0.4466154333081559, 0.9414218899802616], 
             UndirectedEdge[361, 385] -> 
             RGBColor[
              0.46552378312677223`, 0.5743196519105522, 0.9517997921721937], 
             UndirectedEdge[9, 269] -> 
             RGBColor[
              0.909363183463878, 0.5929294140972693, 0.329048956685827], 
             UndirectedEdge[192, 228] -> 
             RGBColor[
              0.35617346073846823`, 0.48292128271817314`, 0.9439160358597984],
              UndirectedEdge[47, 265] -> 
             RGBColor[
              0.5128933077983199, 0.6149014550415344, 0.9549417262439694], 
             UndirectedEdge[338, 398] -> 
             RGBColor[
              0.966856888277283, 0.9722679396973218, 0.803562057713115], 
             UndirectedEdge[71, 79] -> 
             RGBColor[
              0.730962985173496, 0.7893766931257962, 0.9742494771038676], 
             UndirectedEdge[77, 78] -> 
             RGBColor[
              0.8356045267952863, 0.5947068735494174, 0.5856449487468838], 
             UndirectedEdge[89, 164] -> 
             RGBColor[
              0.2305606666537099, 0.3596642574165986, 0.9364414609307642], 
             UndirectedEdge[123, 235] -> 
             RGBColor[
              0.8571949059772741, 0.8886183762780113, 0.9515616992620775], 
             UndirectedEdge[72, 393] -> 
             RGBColor[
              0.22527325394479547`, 0.3541068514182011, 0.9361403505990177], 
             UndirectedEdge[240, 371] -> 
             RGBColor[
              0.2556260580342823, 0.3860095729951837, 0.9378688978889642], 
             UndirectedEdge[196, 303] -> 
             RGBColor[
              0.29376792821553643`, 0.42609909688992764`, 0.9400410209699464],
              UndirectedEdge[105, 170] -> 
             RGBColor[
              0.4311568725166687, 0.5478681452245924, 0.9486939125530778], 
             UndirectedEdge[195, 208] -> 
             RGBColor[
              0.239390712068561, 0.3689451950048222, 0.9369443189542583], 
             UndirectedEdge[100, 180] -> 
             RGBColor[
              0.3714420538172285, 0.49614617062119337`, 0.9448889371092903], 
             UndirectedEdge[39, 355] -> 
             RGBColor[
              0.25200661552040216`, 0.3822053094271858, 0.9376627759922841], 
             UndirectedEdge[244, 397] -> 
             RGBColor[
              0.2546928621186111, 0.3850287249197748, 0.9378157537621064], 
             UndirectedEdge[225, 355] -> 
             RGBColor[
              0.24401463577453056`, 0.373805231993492, 0.9372076445688313], 
             UndirectedEdge[335, 354] -> 
             RGBColor[
              0.28014580760645524`, 0.41178138443745216`, 0.9392652613533807],
              UndirectedEdge[97, 100] -> 
             RGBColor[
              0.4094492665548738, 0.5290661079964851, 0.9473107230964745], 
             UndirectedEdge[2, 107] -> 
             RGBColor[
              0.828834437069773, 0.222639695414975, 0.17524519554284063`], 
             UndirectedEdge[128, 225] -> 
             RGBColor[
              0.2916606290262991, 0.42226923419395845`, 0.939980144908767], 
             UndirectedEdge[96, 228] -> 
             RGBColor[
              0.3273843328541551, 0.4559668373403135, 0.9421555344070691], 
             UndirectedEdge[262, 307] -> 
             RGBColor[
              0.9619414175862754, 0.970962445386637, 0.9415105792405329], 
             UndirectedEdge[86, 334] -> 
             RGBColor[
              0.28096769579564274`, 0.4126452410350092, 0.9393120666698803], 
             UndirectedEdge[255, 399] -> 
             RGBColor[
              0.24767699728620676`, 0.3776546061493952, 0.937416210638943], 
             UndirectedEdge[138, 242] -> 
             RGBColor[
              0.8688448581678534, 0.4318314305529642, 0.2096571104877158], 
             UndirectedEdge[27, 396] -> 
             RGBColor[
              0.28785811658992677`, 0.419887510167713, 0.9397044659406507], 
             UndirectedEdge[163, 209] -> 
             RGBColor[
              0.2485031193706023, 0.3785229128392603, 0.9374632570695112], 
             UndirectedEdge[63, 202] -> 
             RGBColor[
              0.9074503393274316, 0.6529677356997123, 0.2475510699614376], 
             UndirectedEdge[347, 372] -> 
             RGBColor[
              0.26576379522245486`, 0.3966649775496154, 0.9384462270243925], 
             UndirectedEdge[174, 275] -> 
             RGBColor[
              0.8603530123804088, 0.8894563784374243, 0.877080294609712], 
             UndirectedEdge[209, 315] -> 
             RGBColor[
              0.24765360770529532`, 0.37763002221687225`, 0.9374148786369118],
              UndirectedEdge[177, 374] -> 
             RGBColor[
              0.29900611365793894`, 0.43038779878246913`, 0.9403838868632315],
              UndirectedEdge[214, 215] -> 
             RGBColor[
              0.9015306453673441, 0.5683408458182889, 0.5392279021919928], 
             UndirectedEdge[160, 185] -> 
             RGBColor[
              0.8265840327508944, 0.20534210168661424`, 0.17309020582561438`],
              UndirectedEdge[63, 268] -> 
             RGBColor[
              0.8879400264016856, 0.5030029210787892, 0.2288679722699964], 
             UndirectedEdge[48, 196] -> 
             RGBColor[
              0.3616835055171287, 0.4866932494532377, 0.9443037663378753], 
             UndirectedEdge[34, 95] -> 
             RGBColor[
              0.29703377047989377`, 0.4292041286435296, 0.9402390000004376], 
             UndirectedEdge[84, 333] -> 
             RGBColor[
              0.18724373492288626`, 0.3141354157154036, 0.9339746257503516], 
             UndirectedEdge[102, 224] -> 
             RGBColor[
              0.8974792718626248, 0.5394468704448865, 0.26303107700793477`], 
             UndirectedEdge[105, 326] -> 
             RGBColor[
              0.37836717266856673`, 0.5021443605036287, 0.9453301995588554], 
             UndirectedEdge[134, 236] -> 
             RGBColor[
              0.24242453355158805`, 0.3721339337388756, 0.9371170905995801], 
             UndirectedEdge[92, 161] -> 
             RGBColor[
              0.35955024405905767`, 0.48389689314418627`, 0.9442025708853012],
              UndirectedEdge[77, 185] -> 
             RGBColor[
              0.8265277938578538, 0.5249391267425765, 0.5769530590352949], 
             UndirectedEdge[178, 329] -> 
             RGBColor[
              0.23956363455757862`, 0.36912694750469877`, 0.9369541666341921],
              UndirectedEdge[185, 400] -> 
             RGBColor[
              0.6066506956499677, 0.3474920671801415, 0.5581829902007515], 
             UndirectedEdge[317, 333] -> 
             RGBColor[
              0.5930937593564782, 0.6566344401985723, 0.8697228003417041], 
             UndirectedEdge[106, 215] -> 
             RGBColor[
              0.8838915069303948, 0.5551856052534505, 0.5690863625416396], 
             UndirectedEdge[14, 340] -> 
             RGBColor[
              0.9940676030184292, 0.9897195276507893, 0.5956733829454577], 
             UndirectedEdge[233, 358] -> 
             RGBColor[
              0.8930174526264201, 0.5204305413924555, 0.24838903272095686`], 
             UndirectedEdge[74, 191] -> 
             RGBColor[
              0.7517634193974077, 0.8060404672296411, 0.9758823517148281], 
             UndirectedEdge[53, 244] -> 
             RGBColor[
              0.27464006789181306`, 0.4059945029133032, 0.9389517176216438], 
             UndirectedEdge[4, 16] -> 
             RGBColor[
              0.23702850407735238`, 0.36646236463342485`, 0.9368097947037326],
              UndirectedEdge[149, 274] -> 
             RGBColor[
              0.22547330397154366`, 0.35431711668021776`, 0.9361517431520935],
              UndirectedEdge[326, 335] -> 
             RGBColor[
              0.3099542075105004, 0.4402786337315509, 0.9410665454863245], 
             UndirectedEdge[30, 77] -> 
             RGBColor[
              0.5041460680446381, 0.5860856357063153, 0.9585438899509009], 
             UndirectedEdge[129, 229] -> 
             RGBColor[
              0.24229031603850887`, 0.3719928626227475, 0.9371094471107673], 
             UndirectedEdge[216, 219] -> 
             RGBColor[
              0.5531447091768378, 0.647683896662048, 0.958186067610292], 
             UndirectedEdge[138, 233] -> 
             RGBColor[
              0.8184005545424529, 0.14244030215351539`, 0.165253697851294], 
             UndirectedEdge[28, 44] -> 
             RGBColor[
              0.29312282823703784`, 0.42542105591082463`, 0.9400042834805107],
              UndirectedEdge[163, 227] -> 
             RGBColor[
              0.23994763052693538`, 0.3695305516152434, 0.9369760346365759], 
             UndirectedEdge[15, 335] -> 
             RGBColor[
              0.2921895478533735, 0.4244401190541993, 0.9399511345433256], 
             UndirectedEdge[257, 268] -> 
             RGBColor[
              0.8199630848530925, 0.15445059482623982`, 0.16674997864138813`],
              UndirectedEdge[217, 279] -> 
             RGBColor[
              0.8842376547290044, 0.4993398194973086, 0.22230891067878217`], 
             UndirectedEdge[93, 119] -> 
             RGBColor[
              0.24286823945996167`, 0.3726002967811557, 0.9371423589946579], 
             UndirectedEdge[67, 305] -> 
             RGBColor[
              0.20792423756527648`, 0.33587193521215575`, 0.9351523497817738],
              UndirectedEdge[153, 195] -> 
             RGBColor[
              0.2815627334149148, 0.41246769783227444`, 0.9393753536812313], 
             UndirectedEdge[50, 135] -> 
             RGBColor[
              0.478712840814817, 0.5876796757980098, 0.9521051748933094], 
             UndirectedEdge[68, 334] -> 
             RGBColor[
              0.2690618295669699, 0.40013142075315566`, 0.938634045201308], 
             UndirectedEdge[95, 308] -> 
             RGBColor[
              0.2714334547461428, 0.4026241491861876, 0.9387691057467569], 
             UndirectedEdge[17, 36] -> 
             RGBColor[
              0.5275969503288876, 0.6273659981055699, 0.9559535110626505], 
             UndirectedEdge[41, 361] -> 
             RGBColor[
              0.34822341852427197`, 0.4760353557329764, 0.9434094661998561], 
             UndirectedEdge[117, 371] -> 
             RGBColor[
              0.31078136056287864`, 0.44021172480761495`, 0.9411479331302521],
              UndirectedEdge[89, 304] -> 
             RGBColor[
              0.21884062978169738`, 0.3473457555708567, 0.9357740221691438], 
             UndirectedEdge[267, 272] -> 
             RGBColor[
              0.6091079366672787, 0.6934689353256587, 0.9624191392814057], 
             UndirectedEdge[20, 158] -> 
             RGBColor[
              0.4553874406509526, 0.5675033157176284, 0.9506114604100135], 
             UndirectedEdge[30, 62] -> 
             RGBColor[
              0.17899764558147852`, 0.30546825298532254`, 0.9335050231613544],
              UndirectedEdge[197, 310] -> 
             RGBColor[
              0.5856647922314719, 0.6494240169162264, 0.8848951542933734], 
             UndirectedEdge[142, 268] -> 
             RGBColor[
              0.8194514867475214, 0.1505182276031009, 0.16626007171772583`], 
             UndirectedEdge[78, 213] -> 
             RGBColor[
              0.8764060316711535, 0.5036808895572449, 0.2174620888914447], 
             UndirectedEdge[48, 71] -> 
             RGBColor[
              0.6482814539995922, 0.7214952269023049, 0.9679496107647267], 
             UndirectedEdge[262, 269] -> 
             RGBColor[
              0.965850894705439, 0.9706613010892211, 0.7373156259818411], 
             UndirectedEdge[27, 376] -> 
             RGBColor[
              0.3679050083022842, 0.49203509004620194`, 0.9447019126873052], 
             UndirectedEdge[245, 292] -> 
             RGBColor[
              0.2204587636622521, 0.3490465168749334, 0.935866172499827], 
             UndirectedEdge[142, 217] -> 
             RGBColor[
              0.8222048215005642, 0.17168156503396934`, 0.16889666818668636`],
              UndirectedEdge[142, 363] -> 
             RGBColor[
              0.8420482335881154, 0.3177463123414773, 0.18764576842345915`], 
             UndirectedEdge[121, 130] -> 
             RGBColor[
              0.48180086572832803`, 0.5890215010044231, 0.9526702161686205], 
             UndirectedEdge[217, 300] -> 
             RGBColor[
              0.8564112237192996, 0.3849182800030426, 0.19970707341507446`], 
             UndirectedEdge[25, 109] -> 
             RGBColor[
              0.9214037823681839, 0.6836236479949891, 0.47088987975905927`], 
             UndirectedEdge[40, 146] -> 
             RGBColor[
              0.43732168419070216`, 0.5509809435704429, 0.9497020146539848], 
             UndirectedEdge[18, 140] -> 
             RGBColor[
              0.8085657806265083, 0.8511439536813179, 0.9727850165539047], 
             UndirectedEdge[170, 239] -> 
             RGBColor[
              0.38474227729381244`, 0.5076661557079413, 0.9457364155882924], 
             UndirectedEdge[152, 333] -> 
             RGBColor[
              0.18958831081692415`, 0.31659971363473505`, 0.9341081458790279],
              UndirectedEdge[14, 250] -> 
             RGBColor[
              0.99129214736786, 0.9898691754012934, 0.7359749681160213], 
             UndirectedEdge[55, 159] -> 
             RGBColor[
              0.36748362390558187`, 0.49271757758819734`, 0.9446367094556223],
              UndirectedEdge[234, 331] -> 
             RGBColor[
              0.3954159318032815, 0.5169111387705692, 0.9464165314152937], 
             UndirectedEdge[370, 389] -> 
             RGBColor[
              0.505152375234491, 0.5869084718259839, 0.9586367768062234], 
             UndirectedEdge[119, 316] -> 
             RGBColor[
              0.24738893708713797`, 0.3773518366161024, 0.9373998060367528], 
             UndirectedEdge[89, 227] -> 
             RGBColor[
              0.22675241851123462`, 0.35566154716197895`, 0.9362245868328485],
              UndirectedEdge[246, 254] -> 
             RGBColor[
              0.4566571232556863, 0.569515492226385, 0.9504402532261262], 
             UndirectedEdge[197, 345] -> 
             RGBColor[
              0.5953494141792219, 0.6596031686238084, 0.8854466791861835], 
             UndirectedEdge[231, 234] -> 
             RGBColor[
              0.3237117587462526, 0.454798867157554, 0.9418478143825956], 
             UndirectedEdge[89, 209] -> 
             RGBColor[
              0.23530790735490154`, 0.3646539083859959, 0.9367118092657838], 
             UndirectedEdge[233, 317] -> 
             RGBColor[
              0.9040426479180714, 0.5627946336685001, 0.48467433968140694`], 
             UndirectedEdge[48, 342] -> 
             RGBColor[
              0.5144005472567488, 0.6158956891444403, 0.9551237685400916], 
             UndirectedEdge[24, 104] -> 
             RGBColor[
              0.9180135558932775, 0.712060691693382, 0.25285908317008815`], 
             UndirectedEdge[118, 149] -> 
             RGBColor[
              0.21314012851733694`, 0.34135416730935836`, 0.9354493870552745],
              UndirectedEdge[34, 53] -> 
             RGBColor[
              0.30076648553276153`, 0.4331274488318972, 0.9404515726006413], 
             UndirectedEdge[29, 45] -> 
             RGBColor[
              0.26796415172899, 0.39897769174864406`, 0.938571534072304], 
             UndirectedEdge[35, 208] -> 
             RGBColor[
              0.25706388434981153`, 0.3875208196162586, 0.9379507799705602], 
             UndirectedEdge[69, 191] -> 
             RGBColor[
              0.5835359920161374, 0.6722207850854224, 0.9607394608823273], 
             UndirectedEdge[102, 166] -> 
             RGBColor[
              0.8220330696681408, 0.1703614051878311, 0.16873219843799186`], 
             UndirectedEdge[185, 213] -> 
             RGBColor[
              0.8673292987337209, 0.4339131427504039, 0.20877019917985573`], 
             UndirectedEdge[172, 364] -> 
             RGBColor[
              0.3254772137216906, 0.45565682861361634`, 0.9419848830531403], 
             UndirectedEdge[36, 55] -> 
             RGBColor[
              0.46160497467818506`, 0.5724389504821938, 0.9511318842995795], 
             UndirectedEdge[192, 203] -> 
             RGBColor[
              0.31794365991620344`, 0.4482045703725628, 0.9415387963349251], 
             UndirectedEdge[105, 394] -> 
             RGBColor[
              0.38810603050507936`, 0.5105796696723884, 0.9459507509684641], 
             UndirectedEdge[256, 261] -> 
             RGBColor[
              0.20237836752934693`, 0.3300428741759244, 0.934836520687607], 
             UndirectedEdge[215, 295] -> 
             RGBColor[
              0.5308377735120957, 0.2606789813644203, 0.5516093391744658], 
             UndirectedEdge[219, 357] -> 
             RGBColor[
              0.5614389734467367, 0.6541634389484363, 0.9590127623584092], 
             UndirectedEdge[204, 295] -> 
             RGBColor[
              0.21065717499813985`, 0.33874442573233643`, 0.9353079865255567],
              UndirectedEdge[24, 138] -> 
             RGBColor[
              0.8607479504188854, 0.399132481136813, 0.2031112451403423], 
             UndirectedEdge[135, 376] -> 
             RGBColor[
              0.47083567399736015`, 0.5808793962784845, 0.9515970246612349], 
             UndirectedEdge[127, 305] -> 
             RGBColor[
              0.20669916269368893`, 0.33458430384788407`, 0.9350825835801727],
              UndirectedEdge[54, 158] -> 
             RGBColor[
              0.4775536933364365, 0.5867026096855403, 0.9520238744302849], 
             UndirectedEdge[180, 350] -> 
             RGBColor[
              0.3995063863984757, 0.5204540849487005, 0.9466771715650524], 
             UndirectedEdge[46, 287] -> 
             RGBColor[
              0.27226485336384204`, 0.4034980018471065, 0.9388164526680909], 
             UndirectedEdge[41, 153] -> 
             RGBColor[
              0.32912553840433756`, 0.45949373186045395`, 0.9421925661662062],
              UndirectedEdge[163, 315] -> 
             RGBColor[
              0.24412373790812583`, 0.3739199052533755, 0.9372138577739373], 
             UndirectedEdge[17, 64] -> 
             RGBColor[
              0.46723843843845614`, 0.5768882992816866, 0.951609674456959], 
             UndirectedEdge[67, 127] -> 
             RGBColor[
              0.21172079285419906`, 0.33986235553632177`, 0.9353685579889777],
              UndirectedEdge[83, 246] -> 
             RGBColor[
              0.39834226268445083`, 0.5194457794981713, 0.946602994631389], 
             UndirectedEdge[44, 383] -> 
             RGBColor[
              0.28909643467092216`, 0.42118906098474024`, 0.9397749863234359],
              UndirectedEdge[5, 275] -> 
             RGBColor[
              0.916771833602923, 0.9337046356973782, 0.882657568389807], 
             UndirectedEdge[99, 123] -> 
             RGBColor[
              0.9762118677425246, 0.9817794304286422, 0.9251512823600752], 
             UndirectedEdge[278, 354] -> 
             RGBColor[
              0.2660945297513849, 0.3970126005093012, 0.9384650618665371], 
             UndirectedEdge[61, 215] -> 
             RGBColor[
              0.9063170503481712, 0.5687194984901538, 0.341612283904028], 
             UndirectedEdge[115, 208] -> 
             RGBColor[
              0.2358464087925902, 0.36521990753996986`, 0.9367424761260187], 
             UndirectedEdge[167, 203] -> 
             RGBColor[
              0.2874735215718495, 0.4194832764189812, 0.9396825638233285], 
             UndirectedEdge[242, 256] -> 
             RGBColor[
              0.5718276027056971, 0.5340616080097416, 0.5946502523941279], 
             UndirectedEdge[136, 254] -> 
             RGBColor[
              0.5440467518592814, 0.6407206880430576, 0.9572484996967315], 
             UndirectedEdge[65, 170] -> 
             RGBColor[
              0.4801509107444425, 0.5886204880785566, 0.952281016742329], 
             UndirectedEdge[247, 340] -> 
             RGBColor[
              0.9503928339373993, 0.8290616417134029, 0.4041000646481473], 
             UndirectedEdge[8, 17] -> 
             RGBColor[
              0.42291827954092154`, 0.5385004052405986, 0.9487856331227857], 
             UndirectedEdge[269, 300] -> 
             RGBColor[
              0.9415278534612976, 0.7904724805205449, 0.35790419683327634`], 
             UndirectedEdge[233, 242] -> 
             RGBColor[
              0.867902536299588, 0.4245883317454004, 0.20875474200246447`], 
             UndirectedEdge[242, 382] -> 
             RGBColor[
              0.9085638811026002, 0.6736245465915296, 0.24520540694695725`], 
             UndirectedEdge[144, 242] -> 
             RGBColor[
              0.8983924729381163, 0.6274385577093406, 0.23671813465048305`], 
             UndirectedEdge[81, 227] -> 
             RGBColor[
              0.2273187292651137, 0.35625677567048153`, 0.9362568373925002], 
             UndirectedEdge[224, 230] -> 
             RGBColor[
              0.9722593705527938, 0.9180864844443417, 0.3467333222862512], 
             UndirectedEdge[81, 248] -> 
             RGBColor[
              0.21796166804011632`, 0.3464219110510618, 0.9357239665982682], 
             UndirectedEdge[13, 323] -> 
             RGBColor[
              0.8969951869704291, 0.9199794950758233, 0.9649311806841149], 
             UndirectedEdge[10, 189] -> 
             RGBColor[
              0.3312363099818102, 0.46056389881459425`, 0.9423548195879734], 
             UndirectedEdge[135, 364] -> 
             RGBColor[
              0.42640390772588643`, 0.5423948335396401, 0.9487658718038847], 
             UndirectedEdge[39, 383] -> 
             RGBColor[
              0.27666419535336334`, 0.408121989212486, 0.9390669886861509], 
             UndirectedEdge[108, 196] -> 
             RGBColor[
              0.332746597404592, 0.4616295540574491, 0.9424599321408476], 
             UndirectedEdge[75, 89] -> 
             RGBColor[
              0.23138047401831524`, 0.3605259269355878, 0.9364881477473821], 
             UndirectedEdge[131, 269] -> 
             RGBColor[
              0.9577625542405059, 0.8589366723660075, 0.3711790558606476], 
             UndirectedEdge[36, 165] -> 
             RGBColor[
              0.5262130350709433, 0.6262424733544989, 0.9558445641840965], 
             UndirectedEdge[40, 41] -> 
             RGBColor[
              0.34006622360312927`, 0.4689700034848203, 0.942889696952605], 
             UndirectedEdge[86, 249] -> 
             RGBColor[
              0.2850528182511259, 0.41693896374744543`, 0.939544708350323], 
             UndirectedEdge[287, 395] -> 
             RGBColor[
              0.2666407460996809, 0.397586708523477, 0.938496168079518], 
             UndirectedEdge[177, 225] -> 
             RGBColor[
              0.2895083029136421, 0.42040499749423077`, 0.9398430005920957], 
             UndirectedEdge[74, 216] -> 
             RGBColor[
              0.7418875253371497, 0.7983253437301927, 0.9748980148903788], 
             UndirectedEdge[229, 371] -> 
             RGBColor[
              0.25947088353624953`, 0.3900507283737679, 0.9380878550133916], 
             UndirectedEdge[319, 371] -> 
             RGBColor[
              0.2568146393431022, 0.387258847311161, 0.937936585836153], 
             UndirectedEdge[169, 353] -> 
             RGBColor[
              0.21553905850906607`, 0.343875594831612, 0.9355860025694045], 
             UndirectedEdge[47, 362] -> 
             RGBColor[
              0.4192754724662534, 0.5375770736774529, 0.9479368402481747], 
             UndirectedEdge[83, 313] -> 
             RGBColor[
              0.31784501109874064`, 0.44732499341570175`, 0.9415615875935087],
              UndirectedEdge[87, 210] -> 
             RGBColor[
              0.2950312133683537, 0.42742688968244336`, 0.9401129631905363], 
             UndirectedEdge[91, 150] -> 
             RGBColor[
              0.2666109948635128, 0.3975554380879269, 0.9384944737906311], 
             UndirectedEdge[16, 258] -> 
             RGBColor[
              0.24739688608388788`, 0.37736019151568206`, 0.9374002587203583],
              UndirectedEdge[334, 388] -> 
             RGBColor[
              0.24238207309791887`, 0.372089305109921, 0.9371146725395583], 
             UndirectedEdge[67, 325] -> 
             RGBColor[
              0.21225679273606501`, 0.3404257253965182, 0.9353990823893092], 
             UndirectedEdge[279, 363] -> 
             RGBColor[
              0.9040810668165558, 0.6454045668048165, 0.24105801091555495`], 
             UndirectedEdge[192, 385] -> 
             RGBColor[
              0.45995539470159097`, 0.5694965937320001, 0.9514449793856737], 
             UndirectedEdge[216, 339] -> 
             RGBColor[
              0.5124310381777115, 0.6124197611712089, 0.9555918284959135], 
             UndirectedEdge[74, 323] -> 
             RGBColor[
              0.8274418605794372, 0.8652436955878107, 0.9834033373997775], 
             UndirectedEdge[60, 87] -> 
             RGBColor[
              0.32383352968544554`, 0.4531896894262284, 0.9419183552403817], 
             UndirectedEdge[74, 198] -> 
             RGBColor[
              0.8255815527613636, 0.8637603366303892, 0.9832258995793732], 
             UndirectedEdge[16, 348] -> 
             RGBColor[
              0.252407866634222, 0.38262704978860046`, 0.9376856266496183], 
             UndirectedEdge[88, 283] -> 
             RGBColor[
              0.9496145330722283, 0.8334245259791293, 0.5278793972462171], 
             UndirectedEdge[292, 388] -> 
             RGBColor[
              0.21719189432910094`, 0.3456128300743124, 0.9356801291242041], 
             UndirectedEdge[76, 382] -> 
             RGBColor[
              0.8728626791215081, 0.4975553578985697, 0.2149200050950769], 
             UndirectedEdge[131, 352] -> 
             RGBColor[
              0.9583101575279735, 0.8601079404267151, 0.43078229428572945`], 
             UndirectedEdge[123, 232] -> 
             RGBColor[
              0.7499263891145284, 0.8030301325071595, 0.9420935049543039], 
             UndirectedEdge[69, 357] -> 
             RGBColor[
              0.5819543622257783, 0.6709852038723623, 0.9605818188059951], 
             UndirectedEdge[241, 339] -> 
             RGBColor[
              0.32836122521249217`, 0.457187465102298, 0.9422040691120204], 
             UndirectedEdge[181, 322] -> 
             RGBColor[
              0.5378642093893072, 0.6357014215455682, 0.9567617873060958], 
             UndirectedEdge[140, 168] -> 
             RGBColor[
              0.6710377427034506, 0.7429390517664531, 0.9678464290545918], 
             UndirectedEdge[88, 357] -> 
             RGBColor[
              0.8330019348815232, 0.8684180093986145, 0.8892498058738514], 
             UndirectedEdge[125, 179] -> 
             RGBColor[
              0.2738145581196516, 0.4051268398024189, 0.9389047060613515], 
             UndirectedEdge[316, 324] -> 
             RGBColor[
              0.2671185805915378, 0.39808894287087526`, 0.9385233800469365], 
             UndirectedEdge[128, 390] -> 
             RGBColor[
              0.29625621364741994`, 0.42709948500765055`, 0.9402418566543815],
              UndirectedEdge[200, 339] -> 
             RGBColor[
              0.3182100783412779, 0.4465179661207665, 0.9416259763149808], 
             UndirectedEdge[85, 110] -> 
             RGBColor[
              0.2484427050223485, 0.37845941352875473`, 0.9374598165617531], 
             UndirectedEdge[178, 209] -> 
             RGBColor[
              0.24801071646784933`, 0.37800536616831976`, 0.9374352154526442],
              UndirectedEdge[380, 383] -> 
             RGBColor[
              0.2728634955258139, 0.4041272127154443, 0.9388505444536035], 
             UndirectedEdge[350, 357] -> 
             RGBColor[
              0.5542164267531839, 0.6479076320182329, 0.9585525480697432], 
             UndirectedEdge[98, 352] -> 
             RGBColor[
              0.9858621188487648, 0.9629527205499828, 0.4862282141252213], 
             UndirectedEdge[68, 151] -> 
             RGBColor[
              0.29628007015479707`, 0.4280840429902235, 0.9402080838641316], 
             UndirectedEdge[307, 385] -> 
             RGBColor[
              0.7803305100204103, 0.8271780586683711, 0.9269968726475282], 
             UndirectedEdge[94, 119] -> 
             RGBColor[
              0.25031116778183593`, 0.38042328635635736`, 0.9375662227517629],
              UndirectedEdge[116, 121] -> 
             RGBColor[
              0.48470874113100904`, 0.5915401565241579, 0.9528555034179461], 
             UndirectedEdge[1, 361] -> 
             RGBColor[
              0.35780477718256065`, 0.4843342470296975, 0.9440199819010995], 
             UndirectedEdge[180, 239] -> 
             RGBColor[
              0.3453924706572131, 0.47358333097810695`, 0.943229080705076], 
             UndirectedEdge[45, 394] -> 
             RGBColor[
              0.32718352263793704`, 0.4565868884354943, 0.9421136673575129], 
             UndirectedEdge[32, 124] -> 
             RGBColor[
              0.21977833860588586`, 0.34833134699925217`, 0.9358274232994656],
              UndirectedEdge[87, 243] -> 
             RGBColor[
              0.2892553344802239, 0.4213560747591461, 0.9397840354325044], 
             UndirectedEdge[188, 195] -> 
             RGBColor[
              0.25639031228130726`, 0.3868128526653249, 0.9379124210377194], 
             UndirectedEdge[122, 262] -> 
             RGBColor[
              0.6923652232093209, 0.7572804525421046, 0.9691955483013721], 
             UndirectedEdge[118, 212] -> 
             RGBColor[
              0.208479398474888, 0.33645544452739207`, 0.9351839653742893], 
             UndirectedEdge[35, 258] -> 
             RGBColor[
              0.2669871560923189, 0.3979508073894016, 0.938515895616131], 
             UndirectedEdge[183, 271] -> 
             RGBColor[
              0.28286075625291396`, 0.4146349676025667, 0.9394198736623899], 
             UndirectedEdge[130, 147] -> 
             RGBColor[
              0.34757171171070933`, 0.4732511609805692, 0.9434492148065551], 
             UndirectedEdge[124, 330] -> 
             RGBColor[
              0.22402160898279397`, 0.3527912932042634, 0.9360690712700745], 
             UndirectedEdge[46, 395] -> 
             RGBColor[
              0.27869220583377896`, 0.41025355681069386`, 0.939182480882838], 
             UndirectedEdge[206, 284] -> 
             RGBColor[
              0.23778007994491618`, 0.3672523185228967, 0.9368525958375336], 
             UndirectedEdge[179, 313] -> 
             RGBColor[
              0.2762257553297003, 0.407661160948913, 0.939042020175417], 
             UndirectedEdge[215, 363] -> 
             RGBColor[
              0.8409003453545498, 0.3089231403704602, 0.18654654935464235`], 
             UndirectedEdge[260, 338] -> 
             RGBColor[
              0.9016212039882432, 0.9204360205910522, 0.8006477894997438], 
             UndirectedEdge[88, 113] -> 
             RGBColor[
              0.8934147061054667, 0.915612925432826, 0.8952711863200087], 
             UndirectedEdge[95, 270] -> 
             RGBColor[
              0.26568283896088996`, 0.3965798873857872, 0.9384416166850604], 
             UndirectedEdge[16, 184] -> 
             RGBColor[
              0.22981171473055614`, 0.35887706145906934`, 0.9363988092267157],
              UndirectedEdge[38, 78] -> 
             RGBColor[
              0.9038175805994484, 0.6094521874784743, 0.2546544328195417], 
             UndirectedEdge[8, 210] -> 
             RGBColor[
              0.30512183219392025`, 0.43788724700591375`, 0.9406929373091137],
              UndirectedEdge[1, 96] -> 
             RGBColor[
              0.32344726087306624`, 0.45255674347328584`, 0.9419046676618501],
              UndirectedEdge[213, 247] -> 
             RGBColor[
              0.9089878266866289, 0.6768740913610367, 0.24562767290302676`], 
             UndirectedEdge[109, 366] -> 
             RGBColor[
              0.9476884477531541, 0.8182230648175637, 0.4934194788371198], 
             UndirectedEdge[223, 260] -> 
             RGBColor[
              0.6315106131402652, 0.7091757673875206, 0.9658788076150083], 
             UndirectedEdge[393, 399] -> 
             RGBColor[
              0.22884950770057744`, 0.3578657208631124, 0.9363440129598162], 
             UndirectedEdge[25, 358] -> 
             RGBColor[
              0.9086438937541778, 0.640542215450566, 0.2633529303924386], 
             UndirectedEdge[207, 358] -> 
             RGBColor[
              0.9542162454207332, 0.8524596356255733, 0.30144575978299126`], 
             UndirectedEdge[31, 33] -> 
             RGBColor[0.1810793999809316, 0.30765630885, 0.9336235759947237], 
             UndirectedEdge[355, 375] -> 
             RGBColor[
              0.24288325350972279`, 0.37261607749940034`, 0.9371432140225805],
              UndirectedEdge[25, 104] -> 
             RGBColor[
              0.8912926011446027, 0.575480186768195, 0.22996543355252164`], 
             UndirectedEdge[360, 375] -> 
             RGBColor[
              0.2826185317002574, 0.4142282159179257, 0.939411650593985], 
             UndirectedEdge[28, 347] -> 
             RGBColor[
              0.28416959916217255`, 0.4160106444856309, 0.9394944103298126], 
             UndirectedEdge[56, 143] -> 
             RGBColor[
              0.5377896391569529, 0.6355761788857779, 0.956773794547269], 
             UndirectedEdge[73, 115] -> 
             RGBColor[
              0.24086103809529086`, 0.3704906008829697, 0.9370280518463283], 
             UndirectedEdge[157, 218] -> 
             RGBColor[
              0.689653807893005, 0.7555582412254274, 0.971321814931075], 
             UndirectedEdge[267, 321] -> 
             RGBColor[
              0.6944927044467815, 0.7601721648632764, 0.9709294949676452], 
             UndirectedEdge[93, 324] -> 
             RGBColor[
              0.26259788296436154`, 0.3933374030359285, 0.9382659330048415], 
             UndirectedEdge[178, 245] -> 
             RGBColor[
              0.23694364602077422`, 0.3663731734356497, 0.9368049621629467], 
             UndirectedEdge[223, 331] -> 
             RGBColor[
              0.45307983116767014`, 0.5668363678003234, 0.9500964447383967], 
             UndirectedEdge[318, 367] -> 
             RGBColor[
              0.22156608180377718`, 0.3502103784497014, 0.9359292326298564], 
             UndirectedEdge[158, 265] -> 
             RGBColor[
              0.5475052991401734, 0.643528492531465, 0.9575207692077594], 
             UndirectedEdge[124, 199] -> 
             RGBColor[
              0.224537016117427, 0.35333301878146245`, 0.9360984229439153], 
             UndirectedEdge[38, 213] -> 
             RGBColor[
              0.9383796626861343, 0.7904965676280676, 0.28441340229193146`], 
             UndirectedEdge[128, 296] -> 
             RGBColor[
              0.3138673468643941, 0.4456099026290287, 0.9412447846377514], 
             UndirectedEdge[89, 315] -> 
             RGBColor[
              0.23092852589242507`, 0.36005090080011104`, 0.93646240997021], 
             UndirectedEdge[129, 178] -> 
             RGBColor[
              0.24083645723076108`, 0.3704647648358321, 0.9370266520024574], 
             UndirectedEdge[61, 279] -> 
             RGBColor[
              0.9694977718101772, 0.9052009249245101, 0.39612374546494056`], 
             UndirectedEdge[7, 332] -> 
             RGBColor[
              0.45831330080032634`, 0.5693830222721039, 0.9509787412394903], 
             UndirectedEdge[105, 180] -> 
             RGBColor[
              0.39180706588006936`, 0.513785320494758, 0.9461865776698615], 
             UndirectedEdge[75, 163] -> 
             RGBColor[
              0.24457568603401603`, 0.37439493138885227`, 0.9372395955511095],
              UndirectedEdge[15, 273] -> 
             RGBColor[
              0.28964915667663804`, 0.4217700068573468, 0.9398064630239824], 
             UndirectedEdge[149, 287] -> 
             RGBColor[
              0.24021601426247097`, 0.36981263993780294`, 0.9369913186932763],
              UndirectedEdge[123, 275] -> 
             RGBColor[
              0.9831983875687983, 0.9856760529092304, 0.8544852374631398], 
             UndirectedEdge[186, 226] -> 
             RGBColor[
              0.24355084950968384`, 0.37331776322339055`, 0.9371812326271585],
              UndirectedEdge[15, 183] -> 
             RGBColor[
              0.281397272925088, 0.41309675383481925`, 0.9393365304518997], 
             UndirectedEdge[35, 41] -> 
             RGBColor[
              0.3109306833758936, 0.44117275107327436`, 0.9411269955899995], 
             UndirectedEdge[47, 54] -> 
             RGBColor[
              0.44294170199458305`, 0.5580755721956097, 0.9494448314664949], 
             UndirectedEdge[19, 196] -> 
             RGBColor[
              0.2861541125436652, 0.4180964938749955, 0.9396074254310642], 
             UndirectedEdge[211, 328] -> 
             RGBColor[
              0.2860571913279975, 0.41793071873950494`, 0.9396042457787188], 
             UndirectedEdge[3, 86] -> 
             RGBColor[
              0.33530800642617503`, 0.4640896371481913, 0.9426142996527203], 
             UndirectedEdge[55, 58] -> 
             RGBColor[
              0.351171823063294, 0.4776705562573528, 0.9436309688854188], 
             UndirectedEdge[63, 214] -> 
             RGBColor[
              0.9711670732550739, 0.9296487112649943, 0.6029350218130802], 
             UndirectedEdge[26, 106] -> 
             RGBColor[
              0.7018038352541023, 0.7648141211568, 0.9611581586207743], 
             UndirectedEdge[89, 378] -> 
             RGBColor[
              0.2135546306131389, 0.341789835292997, 0.9354729923364294], 
             UndirectedEdge[191, 311] -> 
             RGBColor[
              0.5991137006259042, 0.6848674707026068, 0.961965795167115], 
             UndirectedEdge[147, 364] -> 
             RGBColor[
              0.31713379957570453`, 0.44688737134317436`, 0.9415097379605015],
              UndirectedEdge[137, 285] -> 
             RGBColor[
              0.23013560035880143`, 0.35921748578989005`, 0.9364172540340985],
              UndirectedEdge[104, 205] -> 
             RGBColor[
              0.9645712998383063, 0.8839256222853624, 0.49686413410326324`], 
             UndirectedEdge[191, 339] -> 
             RGBColor[
              0.5223069322379694, 0.6201348846706572, 0.9565761653203628], 
             UndirectedEdge[40, 167] -> 
             RGBColor[
              0.31143079927380024`, 0.4418378465956456, 0.9411503707956721], 
             UndirectedEdge[17, 262] -> 
             RGBColor[
              0.7370797325190604, 0.7937780282574919, 0.9726613937241215], 
             UndirectedEdge[96, 348] -> 
             RGBColor[
              0.27493335548153697`, 0.4063027667656103, 0.9389684199159984], 
             UndirectedEdge[60, 122] -> 
             RGBColor[
              0.4018079642776756, 0.5224475960269956, 0.9468238260723096], 
             UndirectedEdge[99, 187] -> 
             RGBColor[
              0.9110307205751575, 0.9308010667922535, 0.953442401298972], 
             UndirectedEdge[111, 166] -> 
             RGBColor[
              0.8494236278647009, 0.35624594261769826`, 0.19399614499147944`],
              UndirectedEdge[130, 172] -> 
             RGBColor[
              0.3559151258566954, 0.4820206182510111, 0.9439243598991939], 
             UndirectedEdge[205, 230] -> 
             RGBColor[
              0.9820628725503424, 0.9494608486926688, 0.5307965926515668], 
             UndirectedEdge[248, 319] -> 
             RGBColor[
              0.2288957810137855, 0.3579143570491916, 0.9363466481565481], 
             UndirectedEdge[77, 111] -> 
             RGBColor[
              0.8517216279012312, 0.6939386797204187, 0.6001134200588495], 
             UndirectedEdge[41, 188] -> 
             RGBColor[
              0.30395311727072993`, 0.43383888669350434`, 0.9407296335226945],
              UndirectedEdge[57, 278] -> 
             RGBColor[
              0.26281152350528336`, 0.39356195279003, 0.9382780995175941], 
             UndirectedEdge[56, 331] -> 
             RGBColor[
              0.4515137506850261, 0.565500249927577, 0.9499910348290849], 
             UndirectedEdge[40, 87] -> 
             RGBColor[
              0.31472542396778913`, 0.4453007060402985, 0.9413379947980343], 
             UndirectedEdge[142, 214] -> 
             RGBColor[
              0.9026785336009098, 0.577164017789306, 0.5403271212608096], 
             UndirectedEdge[341, 368] -> 
             RGBColor[
              0.2171826090564914, 0.3456030706640795, 0.9356796003416652], 
             UndirectedEdge[96, 188] -> 
             RGBColor[
              0.2769987034014417, 0.4084735783800516, 0.9390860384246287], 
             UndirectedEdge[142, 202] -> 
             RGBColor[
              0.8389617996732674, 0.300483042224024, 0.18494316940916705`], 
             UndirectedEdge[37, 351] -> 
             RGBColor[
              0.2477720085286644, 0.3777544689892789, 0.9374216213886444], 
             UndirectedEdge[83, 108] -> 
             RGBColor[
              0.3602253738682746, 0.48643084621613597`, 0.9441742201814636], 
             UndirectedEdge[72, 119] -> 
             RGBColor[
              0.2341124382405141, 0.36339739454965503`, 0.9366437290682574], 
             UndirectedEdge[170, 180] -> 
             RGBColor[
              0.40561982873439206`, 0.5257492414295251, 0.9470667147047922], 
             UndirectedEdge[196, 234] -> 
             RGBColor[
              0.3183317548341577, 0.44914414193399255`, 0.9415414311188043], 
             UndirectedEdge[218, 306] -> 
             RGBColor[
              0.9402199448611399, 0.9214289952270589, 0.6653505611679222], 
             UndirectedEdge[186, 189] -> 
             RGBColor[
              0.2745072076984255, 0.4058548584262301, 0.9389441514301794], 
             UndirectedEdge[20, 135] -> 
             RGBColor[
              0.45546851492086315`, 0.5675691354622958, 0.9506178428735257], 
             UndirectedEdge[79, 254] -> 
             RGBColor[
              0.5301586737259505, 0.6294457205636295, 0.9561551793123693], 
             UndirectedEdge[93, 355] -> 
             RGBColor[
              0.23807963900287032`, 0.36756717408594775`, 0.936869655282726], 
             UndirectedEdge[211, 301] -> 
             RGBColor[
              0.25974755171345176`, 0.39034152416978307`, 0.9381036108567895],
              UndirectedEdge[145, 227] -> 
             RGBColor[
              0.23647303514531387`, 0.36587853156708794`, 0.9367781615697957],
              UndirectedEdge[26, 345] -> 
             RGBColor[
              0.3285301240705917, 0.4490550186158963, 0.9425296374326482], 
             UndirectedEdge[132, 140] -> 
             RGBColor[
              0.7355736784173503, 0.7933550152374292, 0.9742787680039452], 
             UndirectedEdge[153, 258] -> 
             RGBColor[
              0.28518201112076286`, 0.41627178817658117`, 0.9395814661923377],
              UndirectedEdge[56, 344] -> 
             RGBColor[
              0.38578184035649155`, 0.5085665729828752, 0.9458026556273967], 
             UndirectedEdge[44, 390] -> 
             RGBColor[
              0.28212790876587335`, 0.4138646984284726, 0.9393781390821536], 
             UndirectedEdge[223, 346] -> 
             RGBColor[
              0.3995496021231435, 0.5204711739094963, 0.9466855458786024], 
             UndirectedEdge[114, 222] -> 
             RGBColor[
              0.4669023906435984, 0.574712579304436, 0.9521089968254883], 
             UndirectedEdge[85, 203] -> 
             RGBColor[
              0.2663525209612127, 0.3972837656284177, 0.9384797540842731], 
             UndirectedEdge[156, 261] -> 
             RGBColor[
              0.18270395436139325`, 0.3093638185065621, 0.9337160919633781], 
             UndirectedEdge[33, 295] -> 
             RGBColor[
              0.21066436833308994`, 0.3387519863834527, 0.9353083961753406], 
             UndirectedEdge[59, 395] -> 
             RGBColor[
              0.303543145607047, 0.434036883269187, 0.9406832590311243], 
             UndirectedEdge[334, 371] -> 
             RGBColor[
              0.26672232113879757`, 0.3976724490617448, 0.9385008136573162], 
             UndirectedEdge[40, 154] -> 
             RGBColor[
              0.3847350802007028, 0.5076599219476261, 0.9457359569958835], 
             UndirectedEdge[300, 306] -> 
             RGBColor[
              0.9301864468516778, 0.7525583544999579, 0.2846700934867103], 
             UndirectedEdge[61, 297] -> 
             RGBColor[
              0.9699924620425022, 0.9739499675150907, 0.7461656307796394], 
             UndirectedEdge[97, 350] -> 
             RGBColor[
              0.437513599136121, 0.5533740223239922, 0.9490989575522366], 
             UndirectedEdge[178, 229] -> 
             RGBColor[
              0.24544230257567465`, 0.37530580032079786`, 0.9372889480811126],
              UndirectedEdge[130, 265] -> 
             RGBColor[
              0.5011501438603255, 0.6047301166670249, 0.9541934622219126], 
             UndirectedEdge[110, 134] -> 
             RGBColor[
              0.24495240537755758`, 0.37479088730430044`, 0.9372610491604179],
              UndirectedEdge[147, 211] -> 
             RGBColor[
              0.2737075152920192, 0.40501433100367, 0.9388986101306735], 
             UndirectedEdge[78, 185] -> 
             RGBColor[
              0.832767216647035, 0.2528687626008105, 0.17901122970746597`], 
             UndirectedEdge[130, 135] -> 
             RGBColor[
              0.4568418198608912, 0.568758623177035, 0.9507053486499384], 
             UndirectedEdge[52, 384] -> 
             RGBColor[
              0.5675366621289825, 0.6563557009893235, 0.9607088184571579], 
             UndirectedEdge[77, 166] -> 
             RGBColor[
              0.827067103969575, 0.529084500588463, 0.5774695030073427], 
             UndirectedEdge[24, 76] -> 
             RGBColor[
              0.8745487301949283, 0.505211322035738, 0.2163268874396324], 
             UndirectedEdge[100, 220] -> 
             RGBColor[
              0.42602430021250687`, 0.5428220538333498, 0.9485327937322395], 
             UndirectedEdge[41, 369] -> 
             RGBColor[
              0.2991371325274741, 0.4287769813772735, 0.940455370316177], 
             UndirectedEdge[12, 318] -> 
             RGBColor[
              0.2211272263803799, 0.3497491135746699, 0.9359042404627222], 
             UndirectedEdge[118, 199] -> 
             RGBColor[
              0.21593219336709382`, 0.3442888044935889, 0.9356083910179783], 
             UndirectedEdge[11, 205] -> 
             RGBColor[
              0.9593655870867921, 0.8632867059265485, 0.49267549542961175`], 
             UndirectedEdge[120, 136] -> 
             RGBColor[
              0.5924802140391232, 0.6800411545432594, 0.9610613592571464], 
             UndirectedEdge[66, 215] -> 
             RGBColor[
              0.8960355420221306, 0.5345577698337973, 0.25743539509359753`], 
             UndirectedEdge[199, 287] -> 
             RGBColor[
              0.24300807911222783`, 0.3727472771220335, 0.9371503226559803], 
             UndirectedEdge[8, 64] -> 
             RGBColor[
              0.3546401133620532, 0.4815931742890025, 0.9438183323208591], 
             UndirectedEdge[312, 361] -> 
             RGBColor[
              0.40929184788600736`, 0.528668033662285, 0.9473730082456748], 
             UndirectedEdge[5, 193] -> 
             RGBColor[
              0.8318913190108279, 0.8687915729636699, 0.983827730717042], 
             UndirectedEdge[187, 232] -> 
             RGBColor[
              0.6847452419471614, 0.7520517688707707, 0.9703846238932006], 
             UndirectedEdge[115, 325] -> 
             RGBColor[
              0.22508690864981107`, 0.3539109906981984, 0.9361297385101415], 
             UndirectedEdge[137, 252] -> 
             RGBColor[
              0.22294460960746476`, 0.35165929857508804`, 0.9360077377489273],
              UndirectedEdge[296, 390] -> 
             RGBColor[
              0.283910407540538, 0.415738217657595, 0.9394796497504001], 
             UndirectedEdge[101, 171] -> 
             RGBColor[
              0.2670272094470698, 0.3979929060047742, 0.9385181765954305], 
             UndirectedEdge[234, 342] -> 
             RGBColor[
              0.47104879657377785`, 0.578346581625195, 0.9523614333210206], 
             UndirectedEdge[56, 343] -> 
             RGBColor[
              0.5865678018857227, 0.673953417760403, 0.9614500105609494], 
             UndirectedEdge[60, 146] -> 
             RGBColor[
              0.44642978990835863`, 0.5588699269563728, 0.9502823750963323], 
             UndirectedEdge[149, 336] -> 
             RGBColor[
              0.21561259787663173`, 0.3439528893695888, 0.9355901905275956], 
             UndirectedEdge[12, 199] -> 
             RGBColor[
              0.22211987446733733`, 0.350792449651586, 0.9359607703027832], 
             UndirectedEdge[42, 104] -> 
             RGBColor[
              0.9330499750272585, 0.8621677183315113, 0.6295247357296906], 
             UndirectedEdge[216, 323] -> 
             RGBColor[
              0.7446559095096992, 0.8005327781235971, 0.9751620658441222], 
             UndirectedEdge[110, 192] -> 
             RGBColor[
              0.30003384397733923`, 0.42938021827289985`, 0.940518858812405], 
             UndirectedEdge[93, 380] -> 
             RGBColor[
              0.25536438822798396`, 0.38573454143794017`, 0.9378539961806014],
              UndirectedEdge[34, 397] -> 
             RGBColor[
              0.28081927975955956`, 0.41216167083836874`, 0.939315608741104], 
             UndirectedEdge[249, 308] -> 
             RGBColor[
              0.2653288302878062, 0.39620780182492993`, 0.9384214564148372], 
             UndirectedEdge[116, 130] -> 
             RGBColor[
              0.4133134657138138, 0.5324130830876621, 0.947556946449905], 
             UndirectedEdge[81, 315] -> 
             RGBColor[
              0.23149483664630416`, 0.3606461293086136, 0.9364946605298619], 
             UndirectedEdge[99, 193] -> 
             RGBColor[
              0.9002336063428361, 0.9221917409832586, 0.9524125629047955], 
             UndirectedEdge[116, 135] -> 
             RGBColor[
              0.4597496952635722, 0.5712772786967698, 0.9508906358992639], 
             UndirectedEdge[304, 378] -> 
             RGBColor[
              0.21381243485280502`, 0.34206080389461896`, 0.9354876739064912],
              UndirectedEdge[56, 120] -> 
             RGBColor[
              0.5086566729306621, 0.6119247244781029, 0.9544803407283637], 
             UndirectedEdge[255, 393] -> 
             RGBColor[
              0.2416474883761139, 0.3713172099919425, 0.9370728390263723], 
             UndirectedEdge[106, 214] -> 
             RGBColor[
              0.9661339552698273, 0.9742633398075717, 0.9422105594358144], 
             UndirectedEdge[130, 328] -> 
             RGBColor[
              0.3599213877466876, 0.48616754871640405`, 0.9441548504546003], 
             UndirectedEdge[181, 250] -> 
             RGBColor[
              0.7777697545864616, 0.8245041838583995, 0.9019245302265969], 
             UndirectedEdge[102, 230] -> 
             RGBColor[
              0.8940771340934058, 0.5279706608893748, 0.24981441421432754`], 
             UndirectedEdge[45, 141] -> 
             RGBColor[
              0.32778152064738697`, 0.45710484425502595`, 0.9421517712618861],
              UndirectedEdge[225, 288] -> 
             RGBColor[
              0.25106704817739506`, 0.3812177645776751, 0.9376092690220652], 
             UndirectedEdge[208, 278] -> 
             RGBColor[
              0.24275117083398723`, 0.37247725023267697`, 0.9371356921095961],
              UndirectedEdge[342, 346] -> 
             RGBColor[
              0.4741951057473072, 0.5810717564932091, 0.9525619133593859], 
             UndirectedEdge[133, 164] -> 
             RGBColor[
              0.2698983654154672, 0.40101067296936244`, 0.9386816846803361], 
             UndirectedEdge[287, 373] -> 
             RGBColor[
              0.2552675974110747, 0.3856328081524763, 0.9378484840867676], 
             UndirectedEdge[122, 314] -> 
             RGBColor[
              0.6859497834912932, 0.7522408691078613, 0.9712156258567326], 
             UndirectedEdge[85, 351] -> 
             RGBColor[
              0.24352597864269326`, 0.37329162236527946`, 0.9371798162680766],
              UndirectedEdge[5, 338] -> 
             RGBColor[
              0.9178657002272999, 0.9332997898377504, 0.8022208620159], 
             UndirectedEdge[311, 339] -> 
             RGBColor[
              0.4425672704759462, 0.555957682108388, 0.9499165435038557], 
             UndirectedEdge[39, 324] -> 
             RGBColor[
              0.27652485948189337`, 0.40797553837716655`, 0.9390590537143996],
              UndirectedEdge[52, 346] -> 
             RGBColor[
              0.36583874865596927`, 0.4912928693208167, 0.944531899459223], 
             UndirectedEdge[272, 291] -> 
             RGBColor[
              0.6717542540567425, 0.7434987958813325, 0.9679178442101087], 
             UndirectedEdge[191, 323] -> 
             RGBColor[
              0.7545318035699571, 0.8082479016230455, 0.9761464026685716], 
             UndirectedEdge[60, 165] -> 
             RGBColor[
              0.4451385583294708, 0.557821646991312, 0.950180724616505], 
             UndirectedEdge[44, 301] -> 
             RGBColor[
              0.2773872245806669, 0.4088819387730828, 0.9391081641310199], 
             UndirectedEdge[11, 144] -> 
             RGBColor[
              0.9009503839038591, 0.6375798223152109, 0.23877628985540691`], 
             UndirectedEdge[333, 381] -> 
             RGBColor[
              0.5943537422981029, 0.6571554755250186, 0.8488416222676571], 
             UndirectedEdge[9, 363] -> 
             RGBColor[
              0.8440899658094313, 0.333439960887275, 0.18960093350439794`], 
             UndirectedEdge[153, 312] -> 
             RGBColor[
              0.39019396776607296`, 0.5121264097897626, 0.9461561082120249], 
             UndirectedEdge[55, 80] -> 
             RGBColor[
              0.36897452576073053`, 0.49400892184022105`, 0.9447317084034796],
              UndirectedEdge[7, 40] -> 
             RGBColor[
              0.36435856265805855`, 0.4900108066057379, 0.9444375833163132], 
             UndirectedEdge[51, 377] -> 
             RGBColor[
              0.39390138797963725`, 0.5155993170337143, 0.9463200260221095], 
             UndirectedEdge[112, 170] -> 
             RGBColor[
              0.3869454032271654, 0.5095743926590826, 0.9458767968246178], 
             UndirectedEdge[200, 375] -> 
             RGBColor[
              0.26275249757312547`, 0.3934999127928718, 0.9382747380780788], 
             UndirectedEdge[94, 200] -> 
             RGBColor[
              0.26539181138814727`, 0.3962739989546208, 0.9384250430953294], 
             UndirectedEdge[8, 253] -> 
             RGBColor[
              0.3260178665234107, 0.4568020226733255, 0.9419945480619598], 
             UndirectedEdge[31, 295] -> 
             RGBColor[
              0.21280238164412135`, 0.34099917393122015`, 0.9354301528704966],
              UndirectedEdge[301, 383] -> 
             RGBColor[
              0.2685271160434062, 0.39956940293709464`, 0.9386035940571789], 
             UndirectedEdge[327, 392] -> 
             RGBColor[
              0.28327067295496094`, 0.4141554737113025, 0.9394765499044728], 
             UndirectedEdge[119, 375] -> 
             RGBColor[
              0.24767185396681415`, 0.37764920019460835`, 0.9374159177345123],
              UndirectedEdge[160, 340] -> 
             RGBColor[
              0.9116278550257833, 0.6083417789954149, 0.37001345675471364`], 
             UndirectedEdge[151, 308] -> 
             RGBColor[
              0.28846194842015016`, 0.41986670134956156`, 0.9397628533972181],
              UndirectedEdge[221, 276] -> 
             RGBColor[
              0.8437125304054167, 0.8786573253156666, 0.9848385285958808], 
             UndirectedEdge[94, 316] -> 
             RGBColor[
              0.25720173748705216`, 0.38766571200389227`, 0.9379586305027907],
              UndirectedEdge[195, 206] -> 
             RGBColor[
              0.2386283880050733, 0.3681439440799593, 0.9369009057266002], 
             UndirectedEdge[159, 192] -> 
             RGBColor[
              0.3379621693046799, 0.46714757740434754`, 0.9427556284732501], 
             UndirectedEdge[220, 350] -> 
             RGBColor[
              0.454088632793754, 0.5671299681608568, 0.9503210281880017], 
             UndirectedEdge[229, 319] -> 
             RGBColor[
              0.24423991719027513`, 0.3740420170451063, 0.9372204740121839], 
             UndirectedEdge[69, 97] -> 
             RGBColor[
              0.46525153460871527`, 0.5764515941781216, 0.9511282282884884], 
             UndirectedEdge[90, 317] -> 
             RGBColor[
              0.8482164323597703, 0.8802460937906929, 0.8881545671159801], 
             UndirectedEdge[136, 237] -> 
             RGBColor[
              0.59850057250929, 0.6849287527633994, 0.9615353039292178], 
             UndirectedEdge[69, 141] -> 
             RGBColor[
              0.42414128450553, 0.540843961799992, 0.9485087195042803], 
             UndirectedEdge[48, 143] -> 
             RGBColor[
              0.5250435709581793, 0.6245361752480152, 0.9559616263525487], 
             UndirectedEdge[51, 246] -> 
             RGBColor[
              0.408363122473439, 0.5281253445843351, 0.9472415149560449], 
             UndirectedEdge[97, 132] -> 
             RGBColor[
              0.6207534044996754, 0.7002920708010887, 0.965012812845729], 
             UndirectedEdge[94, 383] -> 
             RGBColor[
              0.2701801471577058, 0.4013068434464496, 0.9386977317336979], 
             UndirectedEdge[246, 344] -> 
             RGBColor[
              0.3822157528613575, 0.505477807231359, 0.9455754276855741], 
             UndirectedEdge[155, 354] -> 
             RGBColor[
              0.29215952785429067`, 0.42440856613178546`, 0.9399494249487885],
              UndirectedEdge[107, 307] -> 
             RGBColor[
              0.9122288272245584, 0.6453071063540661, 0.539731773350462], 
             UndirectedEdge[310, 363] -> 
             RGBColor[
              0.5225453221257725, 0.38890738011125736`, 0.5703491605175277], 
             UndirectedEdge[99, 281] -> 
             RGBColor[
              0.8050608246814849, 0.8476642232367373, 0.943040239252503], 
             UndirectedEdge[123, 187] -> 
             RGBColor[
              0.9091149872090246, 0.929372315984517, 0.9566852381845512], 
             UndirectedEdge[23, 227] -> 
             RGBColor[
              0.22416996966139735`, 0.3529472296840859, 0.936077520191241], 
             UndirectedEdge[28, 211] -> 
             RGBColor[
              0.2754831553698227, 0.4068806413075249, 0.9389997302062802], 
             UndirectedEdge[327, 356] -> 
             RGBColor[
              0.4184852693414719, 0.5351260969165677, 0.9483745901685348], 
             UndirectedEdge[140, 219] -> 
             RGBColor[
              0.5595564197473485, 0.6526927736905361, 0.9588251269991186], 
             UndirectedEdge[104, 144] -> 
             RGBColor[
              0.9061560966553733, 0.6582187386740248, 0.24296492852905843`], 
             UndirectedEdge[49, 328] -> 
             RGBColor[
              0.2825867919008145, 0.4142831089055032, 0.9394066116653366], 
             UndirectedEdge[112, 271] -> 
             RGBColor[
              0.3178545270497625, 0.4495503070285146, 0.9414810160978866], 
             UndirectedEdge[106, 197] -> 
             RGBColor[
              0.9686231253627324, 0.9753622711647122, 0.9040752003743098], 
             UndirectedEdge[106, 204] -> 
             RGBColor[
              0.563710908416439, 0.6332510496213667, 0.9527850098927306], 
             UndirectedEdge[50, 158] -> 
             RGBColor[
              0.47863176654490647`, 0.5876138560533424, 0.9520987924297972], 
             UndirectedEdge[259, 299] -> 
             RGBColor[
              0.21257469635649348`, 0.34075986225784227`, 0.9354171865301963],
              UndirectedEdge[79, 286] -> 
             RGBColor[
              0.658527918518543, 0.7323765551714567, 0.9671395072605043], 
             UndirectedEdge[240, 388] -> 
             RGBColor[
              0.23128580999340365`, 0.36042642904335986`, 0.9364827567712063],
              UndirectedEdge[118, 299] -> 
             RGBColor[
              0.21009516231391617`, 0.33815371476755507`, 0.9352759807346135],
              UndirectedEdge[138, 257] -> 
             RGBColor[
              0.8209750230584517, 0.16222879530677942`, 0.1677190118096608], 
             UndirectedEdge[171, 244] -> 
             RGBColor[
              0.266624380952421, 0.39756950771609656`, 0.9384952361085915], 
             UndirectedEdge[161, 337] -> 
             RGBColor[
              0.35808998923330093`, 0.48236207273681253`, 0.9441194115332278],
              UndirectedEdge[119, 355] -> 
             RGBColor[
              0.2357097669248304, 0.3650762882733595, 0.9367346945737933], 
             UndirectedEdge[248, 292] -> 
             RGBColor[
              0.21361328404066288`, 0.34185148376416674`, 0.935476332562357], 
             UndirectedEdge[68, 386] -> 
             RGBColor[
              0.30804388160308127`, 0.43827326520037213`, 0.9409576635272863],
              UndirectedEdge[126, 299] -> 
             RGBColor[
              0.21308522513571704`, 0.34129646037420036`, 0.9354462603889135],
              UndirectedEdge[128, 383] -> 
             RGBColor[
              0.30322473955246876`, 0.43442384756391816`, 0.9406387038956638],
              UndirectedEdge[229, 248] -> 
             RGBColor[
              0.2315520252069328, 0.36070623811179847`, 0.9364979173337866], 
             UndirectedEdge[395, 396] -> 
             RGBColor[
              0.2756838068644868, 0.4070915387504564, 0.9390111570120642], 
             UndirectedEdge[81, 292] -> 
             RGBColor[
              0.21536706305033604`, 0.3436948166993449, 0.9355762076824743], 
             UndirectedEdge[34, 253] -> 
             RGBColor[
              0.3270023945629662, 0.4576547713773704, 0.9420572813180563], 
             UndirectedEdge[130, 322] -> 
             RGBColor[
              0.45941085843753277`, 0.5708442844274215, 0.95090759277739], 
             UndirectedEdge[74, 311] -> 
             RGBColor[
              0.6720237576353845, 0.741863264667372, 0.9692227298983209], 
             UndirectedEdge[232, 235] -> 
             RGBColor[
              0.6328251607154107, 0.7112978291642651, 0.965261084970727], 
             UndirectedEdge[207, 221] -> 
             RGBColor[
              0.9308573670898133, 0.869892342221664, 0.6314368519575342], 
             UndirectedEdge[140, 216] -> 
             RGBColor[
              0.6655132848379224, 0.7386233032944675, 0.96729580272355], 
             UndirectedEdge[31, 173] -> 
             RGBColor[
              0.20479251217739197`, 0.3325802932666311, 0.9349740026539064], 
             UndirectedEdge[37, 243] -> 
             RGBColor[
              0.2690857390615694, 0.4001565511479292, 0.9386354068116546], 
             UndirectedEdge[1, 35] -> 
             RGBColor[
              0.32051204203418227`, 0.44947164236999554`, 0.9417375112912428],
              UndirectedEdge[60, 210] -> 
             RGBColor[
              0.3287260262404138, 0.45833201350769803`, 0.942196975681387], 
             UndirectedEdge[35, 92] -> 
             RGBColor[
              0.28435244626912165`, 0.4162028283882106, 0.9395048232020553], 
             UndirectedEdge[52, 291] -> 
             RGBColor[
              0.5415685327056081, 0.6360692009186899, 0.9581205580022027], 
             UndirectedEdge[77, 400] -> 
             RGBColor[
              0.6094880057982189, 0.6893301781287484, 0.9648167092401694], 
             UndirectedEdge[77, 389] -> 
             RGBColor[
              0.5042266153181847, 0.5861702959978048, 0.9585484769989704], 
             UndirectedEdge[96, 361] -> 
             RGBColor[
              0.32126900465498376`, 0.45067004741952366`, 0.9417658711017902],
              UndirectedEdge[150, 374] -> 
             RGBColor[
              0.2733522518909328, 0.4046409266441276, 0.9388783784055468], 
             UndirectedEdge[80, 154] -> 
             RGBColor[
              0.38228721374237734`, 0.5055397030547701, 0.9455799811097223], 
             UndirectedEdge[200, 383] -> 
             RGBColor[
              0.27544799036410295`, 0.4068436806569232, 0.9389977276112265], 
             UndirectedEdge[144, 391] -> 
             RGBColor[
              0.8494144480971886, 0.3493178905748092, 0.19371883223399736`], 
             UndirectedEdge[196, 290] -> 
             RGBColor[
              0.3515289166579535, 0.47789785496789633`, 0.943656724915119], 
             UndirectedEdge[159, 228] -> 
             RGBColor[
              0.3496458859290326, 0.47726742550368945`, 0.9435001045650488], 
             UndirectedEdge[27, 377] -> 
             RGBColor[
              0.3561480526956704, 0.48185180602152367`, 0.9439527698723194], 
             UndirectedEdge[24, 233] -> 
             RGBColor[
              0.8598056285506199, 0.3918893823292492, 0.202208876655091], 
             UndirectedEdge[24, 109] -> 
             RGBColor[
              0.9481247371168586, 0.8202041529201762, 0.49378352937662584`], 
             UndirectedEdge[189, 255] -> 
             RGBColor[
              0.28051086067435194`, 0.4121650783575129, 0.9392860505855498], 
             UndirectedEdge[262, 298] -> 
             RGBColor[
              0.8810364966451805, 0.9079026895445534, 0.9858832537094278], 
             UndirectedEdge[249, 397] -> 
             RGBColor[
              0.25945941523748706`, 0.39003867446463636`, 0.938087201910743], 
             UndirectedEdge[128, 324] -> 
             RGBColor[
              0.3030854036809988, 0.43427739672859866`, 0.9406307689239126], 
             UndirectedEdge[7, 228] -> 
             RGBColor[
              0.37863108577837257`, 0.5023729487746839, 0.9453470158688431], 
             UndirectedEdge[115, 258] -> 
             RGBColor[
              0.24576968053509757`, 0.37564989531311277`, 0.9373075917715895],
              UndirectedEdge[375, 383] -> 
             RGBColor[
              0.26754083334268397`, 0.3985327572847006, 0.9385474267164473], 
             UndirectedEdge[257, 338] -> 
             RGBColor[
              0.9084477718580719, 0.5824829620653897, 0.3944924501077937], 
             UndirectedEdge[5, 321] -> 
             RGBColor[
              0.8296147450427847, 0.8669940565457998, 0.9836058756059307], 
             UndirectedEdge[65, 239] -> 
             RGBColor[
              0.4199235526672635, 0.5364545776271384, 0.9484433827426128], 
             UndirectedEdge[56, 71] -> 
             RGBColor[
              0.6610275221983658, 0.7325352305400676, 0.968761778959447], 
             UndirectedEdge[276, 322] -> 
             RGBColor[
              0.6369911357289768, 0.7142897496435541, 0.9658558315605028], 
             UndirectedEdge[239, 326] -> 
             RGBColor[
              0.3319525774457105, 0.4619423709869775, 0.94237270259407], 
             UndirectedEdge[379, 393] -> 
             RGBColor[
              0.22188867958802838`, 0.35054944917483033`, 0.9359476040964289],
              UndirectedEdge[131, 262] -> 
             RGBColor[
              0.9305545199558635, 0.8420358975584873, 0.6226092420681639], 
             UndirectedEdge[201, 210] -> 
             RGBColor[
              0.2881749983278178, 0.42022057296569904`, 0.9397225118868391], 
             UndirectedEdge[301, 372] -> 
             RGBColor[
              0.25414770566980416`, 0.3844557309271635, 0.9377847079088335], 
             UndirectedEdge[291, 398] -> 
             RGBColor[
              0.8179584912880846, 0.8585839639299231, 0.9789023010866215], 
             UndirectedEdge[28, 49] -> 
             RGBColor[
              0.27201275594263963`, 0.40323303147352313`, 0.938802096092898], 
             UndirectedEdge[6, 160] -> 
             RGBColor[
              0.9114125623801264, 0.6078812897957802, 0.3465801809071596], 
             UndirectedEdge[375, 379] -> 
             RGBColor[
              0.23790135046863936`, 0.36737978153232503`, 0.9368595020144559],
              UndirectedEdge[45, 112] -> 
             RGBColor[
              0.31221013250570034`, 0.4436176904874213, 0.9411595761787357], 
             UndirectedEdge[324, 390] -> 
             RGBColor[
              0.27312846435714266`, 0.404405711757165, 0.9388656340365613], 
             UndirectedEdge[169, 227] -> 
             RGBColor[
              0.22781024002051087`, 0.3567733846379857, 0.936284828202895], 
             UndirectedEdge[44, 380] -> 
             RGBColor[
              0.2817236040630746, 0.41343974855143245`, 0.9393551145274445], 
             UndirectedEdge[288, 360] -> 
             RGBColor[
              0.2777088570611381, 0.4090678365808599, 0.9391320518865], 
             UndirectedEdge[87, 134] -> 
             RGBColor[
              0.26223279186396886`, 0.39295366914130303`, 0.9382451416067781],
              UndirectedEdge[85, 258] -> 
             RGBColor[
              0.24712036386052527`, 0.3770695491264064, 0.9373845111888157], 
             UndirectedEdge[26, 77] -> 
             RGBColor[
              0.6422389788407158, 0.7176486903810251, 0.9669170377654001], 
             UndirectedEdge[90, 333] -> 
             RGBColor[
              0.4506831285542931, 0.5464884699982167, 0.9528800174609131], 
             UndirectedEdge[45, 91] -> 
             RGBColor[
              0.27906015322156846`, 0.41064029284447245`, 0.9392034349422431],
              UndirectedEdge[103, 133] -> 
             RGBColor[
              0.32091218999488846`, 0.4513176188145481, 0.9417081084114585], 
             UndirectedEdge[143, 342] -> 
             RGBColor[
              0.6140012232637606, 0.6975128793422373, 0.9627555719373643], 
             UndirectedEdge[75, 164] -> 
             RGBColor[
              0.2433583151299939, 0.3731153973829517, 0.9371702680790643], 
             UndirectedEdge[44, 211] -> 
             RGBColor[
              0.28031687034096775`, 0.4119611822174286, 0.9392750031230466], 
             UndirectedEdge[82, 171] -> 
             RGBColor[
              0.32621487078886763`, 0.45368735101725755`, 0.9421273921767691],
              UndirectedEdge[17, 122] -> 
             RGBColor[
              0.490802095307585, 0.5972979545178956, 0.9531111298361363], 
             UndirectedEdge[150, 186] -> 
             RGBColor[
              0.2595342246109202, 0.3901173038593028, 0.9380914621938894], 
             UndirectedEdge[180, 394] -> 
             RGBColor[
              0.36256898672280274`, 0.4884607658773212, 0.9443235531201786], 
             UndirectedEdge[156, 202] -> 
             RGBColor[
              0.5211495825009953, 0.37342113688887774`, 0.567742844041897], 
             UndirectedEdge[86, 178] -> 
             RGBColor[
              0.27226239938534696`, 0.40349542256011695`, 0.9388163129176459],
              UndirectedEdge[102, 250] -> 
             RGBColor[
              0.9037621261807391, 0.5693653564012491, 0.505440590565607], 
             UndirectedEdge[7, 222] -> 
             RGBColor[
              0.4971659473495666, 0.600925351032558, 0.9540373638977802], 
             UndirectedEdge[97, 220] -> 
             RGBColor[
              0.4588594812307164, 0.571262237287139, 0.9506250224317093], 
             UndirectedEdge[230, 289] -> 
             RGBColor[
              0.9333052704870481, 0.7676068761755623, 0.28495592618105414`], 
             UndirectedEdge[14, 289] -> 
             RGBColor[
              0.9460551929840001, 0.8094710811761514, 0.43178805845315205`], 
             UndirectedEdge[77, 370] -> 
             RGBColor[
              0.8302908639224114, 0.8675154135193626, 0.9836750778819656], 
             UndirectedEdge[151, 270] -> 
             RGBColor[
              0.28271133263489734`, 0.4138224395491612, 0.9394353643355215], 
             UndirectedEdge[173, 214] -> 
             RGBColor[
              0.6050703523847987, 0.6713378352539525, 0.9242773858520503], 
             UndirectedEdge[144, 317] -> 
             RGBColor[
              0.9345325845565998, 0.7656448596324403, 0.5126377323294256], 
             UndirectedEdge[31, 175] -> 
             RGBColor[
              0.18107477738655686`, 0.3076514502102228, 0.9336233127448126], 
             UndirectedEdge[163, 240] -> 
             RGBColor[
              0.2420898799764604, 0.3717821916131542, 0.9370980325735522], 
             UndirectedEdge[329, 371] -> 
             RGBColor[
              0.25359221551815353`, 0.38387187555766883`, 0.9377530735664711],
              UndirectedEdge[72, 375] -> 
             RGBColor[
              0.24128592482540645`, 0.37093718377569584`, 0.9370522485170447],
              UndirectedEdge[32, 238] -> 
             RGBColor[
              0.22275425852448527`, 0.3514592275179208, 0.9359968975363508], 
             UndirectedEdge[11, 14] -> 
             RGBColor[
              0.9589098698169762, 0.8623003371232989, 0.4422276945427869], 
             UndirectedEdge[79, 237] -> 
             RGBColor[
              0.5846124943759591, 0.6736537852839712, 0.9604419835448554], 
             UndirectedEdge[69, 74] -> 
             RGBColor[
              0.6564460490256175, 0.7292165790501876, 0.9679963956135333], 
             UndirectedEdge[16, 203] -> 
             RGBColor[
              0.2666290431845753, 0.3975744080176934, 0.9384955016158156], 
             UndirectedEdge[315, 319] -> 
             RGBColor[
              0.24242894961997336`, 0.37213857530674344`, 0.9371173420881417],
              UndirectedEdge[40, 80] -> 
             RGBColor[
              0.3368642646638673, 0.46619662758676733`, 0.9426856709603764], 
             UndirectedEdge[18, 198] -> 
             RGBColor[
              0.8858480974802114, 0.9115700695530261, 0.9804738418540726], 
             UndirectedEdge[300, 307] -> 
             RGBColor[
              0.9376183763421341, 0.7907736248179609, 0.5620991500919681], 
             UndirectedEdge[191, 198] -> 
             RGBColor[
              0.7526714957518834, 0.806764542665624, 0.9759689648481673], 
             UndirectedEdge[289, 391] -> 
             RGBColor[
              0.8590720492168273, 0.39317080166904056`, 0.2017773713376896], 
             UndirectedEdge[132, 357] -> 
             RGBColor[
              0.7374562321167385, 0.7948256804953293, 0.9744664033632358], 
             UndirectedEdge[157, 187] -> 
             RGBColor[
              0.656588840938115, 0.7291931341002164, 0.9681680488654731], 
             UndirectedEdge[38, 250] -> 
             RGBColor[
              0.9770092142863354, 0.9428337657309378, 0.5831873792076157], 
             UndirectedEdge[140, 191] -> 
             RGBColor[
              0.6753891788981803, 0.7463384267939157, 0.9682801395479993], 
             UndirectedEdge[204, 261] -> 
             RGBColor[
              0.17918768478614402`, 0.3056679962386074, 0.9335158456129223], 
             UndirectedEdge[337, 354] -> 
             RGBColor[
              0.28225838404285286`, 0.4140018362171884, 0.9393855694561568], 
             UndirectedEdge[300, 314] -> 
             RGBColor[
              0.9079043794586273, 0.7685321222787813, 0.6113544605961532], 
             UndirectedEdge[292, 378] -> 
             RGBColor[
              0.20977255736756456`, 0.3378146365146045, 0.93525760886017], 
             UndirectedEdge[153, 361] -> 
             RGBColor[
              0.3365286408445437, 0.46590592710341294`, 0.9426642853073897], 
             UndirectedEdge[240, 334] -> 
             RGBColor[
              0.2503027734840032, 0.3804144634171059, 0.9375657447089196], 
             UndirectedEdge[52, 260] -> 
             RGBColor[
              0.5977997596730911, 0.6799974627988412, 0.9637251611956289], 
             UndirectedEdge[128, 177] -> 
             RGBColor[
              0.32406082685861914`, 0.45510693327935664`, 0.9418698472250615],
              UndirectedEdge[16, 85] -> 
             RGBColor[
              0.2415839884274967, 0.3712504675198166, 0.9370692227982382], 
             UndirectedEdge[179, 303] -> 
             RGBColor[
              0.27962744891017854`, 0.4112365565818258, 0.9392357415924706], 
             UndirectedEdge[48, 320] -> 
             RGBColor[
              0.5676684575710711, 0.6581064280542859, 0.9600245413086331], 
             UndirectedEdge[136, 320] -> 
             RGBColor[
              0.6642380668783059, 0.7372628617572051, 0.9674177280321361], 
             UndirectedEdge[96, 192] -> 
             RGBColor[
              0.3157006162298024, 0.44584698924097155`, 0.9414110583152703], 
             UndirectedEdge[140, 357] -> 
             RGBColor[
              0.6738075491078213, 0.7451028455808557, 0.9681224974716671], 
             UndirectedEdge[202, 306] -> 
             RGBColor[
              0.913357870811167, 0.6728952265487068, 0.2705007142320376], 
             UndirectedEdge[114, 258] -> 
             RGBColor[
              0.29090557114945215`, 0.42122924819894025`, 0.9399461663762204],
              UndirectedEdge[87, 236] -> 
             RGBColor[
              0.2703304585010046, 0.4014648301985463, 0.938706291742333], 
             UndirectedEdge[116, 362] -> 
             RGBColor[
              0.41044018393094006`, 0.5299243908226783, 0.9473738634754435], 
             UndirectedEdge[36, 64] -> 
             RGBColor[
              0.45931878415001925`, 0.5704587671539738, 0.9509862102607236], 
             UndirectedEdge[245, 304] -> 
             RGBColor[
              0.22449864114749254`, 0.35329268425494775`, 0.9360962375461481],
              UndirectedEdge[187, 218] -> 
             RGBColor[
              0.8769988069965478, 0.9047590594733392, 0.9881301231890498], 
             UndirectedEdge[26, 370] -> 
             RGBColor[
              0.6431647387570222, 0.7183868662092043, 0.9670053375726531], 
             UndirectedEdge[91, 141] -> 
             RGBColor[
              0.3113425799408942, 0.43982647528346147`, 0.9412155979078848], 
             UndirectedEdge[55, 385] -> 
             RGBColor[
              0.4894768493024928, 0.5950665939158499, 0.9533260603680459], 
             UndirectedEdge[179, 231] -> 
             RGBColor[
              0.28916364068982703`, 0.4212596987717169, 0.9397788136067902], 
             UndirectedEdge[94, 177] -> 
             RGBColor[
              0.29101623446385616`, 0.4219899291618881, 0.9399288750630955], 
             UndirectedEdge[225, 383] -> 
             RGBColor[
              0.26867221560749177`, 0.39972191177879235`, 0.938611857262698], 
             UndirectedEdge[37, 134] -> 
             RGBColor[
              0.24206319644531432`, 0.3717541455300861, 0.9370965129859282], 
             UndirectedEdge[255, 341] -> 
             RGBColor[
              0.24102934533176992`, 0.3706675024598044, 0.9370376366944575], 
             UndirectedEdge[206, 278] -> 
             RGBColor[
              0.24198884677049953`, 0.37167599930781414`, 0.937092278881938], 
             UndirectedEdge[131, 279] -> 
             RGBColor[
              0.934057909721427, 0.776268616484077, 0.26579965018330676`], 
             UndirectedEdge[7, 203] -> 
             RGBColor[
              0.3404012849561078, 0.4676562364290735, 0.9429697763439697], 
             UndirectedEdge[101, 151] -> 
             RGBColor[
              0.2883386750076016, 0.41973713317698713`, 0.9397558331587401], 
             UndirectedEdge[200, 296] -> 
             RGBColor[
              0.2860905976760283, 0.41802973572203384`, 0.939603808353314], 
             UndirectedEdge[86, 229] -> 
             RGBColor[
              0.27371625819309475`, 0.4050235203470323, 0.9388991080259558], 
             UndirectedEdge[138, 382] -> 
             RGBColor[
              0.8590618993454652, 0.3914765169996446, 0.2017043627957868], 
             UndirectedEdge[195, 278] -> 
             RGBColor[
              0.24905516487064655`, 0.3791031476615132, 0.9374946952440605], 
             UndirectedEdge[65, 113] -> 
             RGBColor[
              0.6559239156864949, 0.7291861264524664, 0.9676704388099608], 
             UndirectedEdge[249, 270] -> 
             RGBColor[
              0.25957821450255336`, 0.3901635400245296, 0.9380939673531408], 
             UndirectedEdge[319, 388] -> 
             RGBColor[
              0.23247439130222355`, 0.3616757033593372, 0.9365504447183952], 
             UndirectedEdge[138, 256] -> 
             RGBColor[
              0.522325620948562, 0.25191357841785655`, 0.5511492082429574], 
             UndirectedEdge[246, 286] -> 
             RGBColor[
              0.5850263680482788, 0.6724463268342122, 0.9614245811742612], 
             UndirectedEdge[188, 208] -> 
             RGBColor[
              0.25008631824464794`, 0.38018695523648866`, 0.9375534179032552],
              UndirectedEdge[173, 345] -> 
             RGBColor[
              0.21415750276433887`, 0.34242349214821033`, 0.9355073250135709],
              UndirectedEdge[84, 156] -> 
             RGBColor[
              0.18244327672263497`, 0.3090898297803102, 0.9337012467574888], 
             UndirectedEdge[136, 349] -> 
             RGBColor[
              0.5319806271096528, 0.6307093057544687, 0.9563581696523957], 
             UndirectedEdge[117, 346] -> 
             RGBColor[
              0.3472745636844825, 0.4752135053615816, 0.9433490060085041], 
             UndirectedEdge[26, 197] -> 
             RGBColor[
              0.7219321437839568, 0.7790682930787789, 0.8931643392096228], 
             UndirectedEdge[328, 362] -> 
             RGBColor[
              0.35704810596381387`, 0.4836788564514203, 0.9439717674801389], 
             UndirectedEdge[187, 275] -> 
             RGBColor[
              0.9180172404014313, 0.9346976892728417, 0.8827763564020366], 
             UndirectedEdge[20, 121] -> 
             RGBColor[
              0.48042756078829996`, 0.5878320132896839, 0.9525827103922078], 
             UndirectedEdge[198, 302] -> 
             RGBColor[
              0.9068833316004294, 0.9166145009599966, 0.6941933109869335], 
             UndirectedEdge[1, 312] -> 
             RGBColor[
              0.4114701041040899, 0.5305547297160472, 0.9475118048057347], 
             UndirectedEdge[89, 292] -> 
             RGBColor[
              0.21480075229645693`, 0.3430995881908423, 0.9355439571228226], 
             UndirectedEdge[304, 315] -> 
             RGBColor[
              0.23118633013209117`, 0.360321869401733, 0.9364770915402718], 
             UndirectedEdge[21, 64] -> 
             RGBColor[
              0.3559387070583645, 0.4827179508795304, 0.9439010775628867], 
             UndirectedEdge[201, 351] -> 
             RGBColor[
              0.26108538890678307`, 0.3917476758837515, 0.9381797987057969], 
             UndirectedEdge[17, 218] -> 
             RGBColor[
              0.7227901892843811, 0.7824598484159166, 0.9739304322567687], 
             UndirectedEdge[266, 365] -> 
             RGBColor[
              0.25561932448523794`, 0.3860024956082064, 0.9378685144233075], 
             UndirectedEdge[112, 180] -> 
             RGBColor[
              0.34759559659056605`, 0.4754915679292482, 0.9433694619414015], 
             UndirectedEdge[247, 289] -> 
             RGBColor[
              0.9023804239029701, 0.648813195238765, 0.2402147401558417], 
             UndirectedEdge[15, 45] -> 
             RGBColor[
              0.29968000514429743`, 0.4323130645893829, 0.9403777050049051], 
             UndirectedEdge[57, 92] -> 
             RGBColor[
              0.2804356326225079, 0.4120860089052909, 0.9392817664592872], 
             UndirectedEdge[53, 86] -> 
             RGBColor[
              0.2948901577623302, 0.4272786312970708, 0.9401049302824465], 
             UndirectedEdge[114, 154] -> 
             RGBColor[
              0.3795179550306004, 0.5031411103456188, 0.9454035263933673], 
             UndirectedEdge[71, 237] -> 
             RGBColor[
              0.7247695222504801, 0.7843485609125668, 0.9737619050151656], 
             UndirectedEdge[241, 375] -> 
             RGBColor[
              0.2729036444443398, 0.40416941177440335`, 0.9388528308751185], 
             UndirectedEdge[100, 282] -> 
             RGBColor[
              0.5117379294109875, 0.6123392626277626, 0.9553276443786378], 
             UndirectedEdge[55, 146] -> 
             RGBColor[
              0.4694319452875655, 0.5787932378238967, 0.951748052097088], 
             UndirectedEdge[309, 319] -> 
             RGBColor[
              0.25618706106620875`, 0.38659922275138503`, 0.9379008461817029],
              UndirectedEdge[13, 302] -> 
             RGBColor[
              0.9755285816369456, 0.9706262250120263, 0.6756345411379316], 
             UndirectedEdge[110, 348] -> 
             RGBColor[
              0.25926658322907375`, 0.3898359957975386, 0.9380762204131332], 
             UndirectedEdge[217, 363] -> 
             RGBColor[
              0.8426690815936368, 0.3225184221692448, 0.1882402931746939], 
             UndirectedEdge[39, 380] -> 
             RGBColor[
              0.2692913647455158, 0.4003726767791782, 0.9386471168901593], 
             UndirectedEdge[248, 304] -> 
             RGBColor[
              0.2176531615259033, 0.3460976511441812, 0.9357063976086782], 
             UndirectedEdge[204, 400] -> 
             RGBColor[
              0.2842689537951664, 0.40863855928315673`, 0.939773820202813], 
             UndirectedEdge[69, 168] -> 
             RGBColor[
              0.5791845558214077, 0.6688214100579597, 0.9603057503889199], 
             UndirectedEdge[68, 86] -> 
             RGBColor[
              0.28863048877409425`, 0.42069932230449786`, 0.9397484513939167],
              UndirectedEdge[175, 264] -> 
             RGBColor[
              0.18448157797338877`, 0.31123221363061604`, 0.9338173249983228],
              UndirectedEdge[1, 92] -> 
             RGBColor[
              0.3238234376355826, 0.4529521291016748, 0.9419260903719718], 
             UndirectedEdge[368, 393] -> 
             RGBColor[
              0.21780075210083538`, 0.3462527781962177, 0.93571480267358], 
             UndirectedEdge[332, 361] -> 
             RGBColor[
              0.4414240641856033, 0.5547544143941453, 0.9499025740169657], 
             UndirectedEdge[80, 203] -> 
             RGBColor[
              0.31290698696191654`, 0.4438420574101029, 0.9412178639880329], 
             UndirectedEdge[20, 347] -> 
             RGBColor[
              0.3438545327447645, 0.469598113054395, 0.9432282288718172], 
             UndirectedEdge[18, 311] -> 
             RGBColor[
              0.7322903023542322, 0.7896729975900088, 0.9664706721730203], 
             UndirectedEdge[170, 282] -> 
             RGBColor[
              0.5459157043281511, 0.6419423334360943, 0.9575054219741398], 
             UndirectedEdge[198, 323] -> 
             RGBColor[
              0.828349936933913, 0.8659677710237936, 0.9834899505331167], 
             UndirectedEdge[168, 357] -> 
             RGBColor[
              0.6729202964028389, 0.7444097170243531, 0.9680340644138824], 
             UndirectedEdge[180, 326] -> 
             RGBColor[
              0.3528301288862901, 0.48002545670856134`, 0.9437030017105699], 
             UndirectedEdge[18, 340] -> 
             RGBColor[
              0.9694923470519816, 0.9738780487256253, 0.770900506424754], 
             UndirectedEdge[74, 340] -> 
             RGBColor[
              0.9092258023331339, 0.9260683158029884, 0.7736525641500547], 
             UndirectedEdge[173, 204] -> 
             RGBColor[
              0.20264730553141047`, 0.33032554506774736`, 0.9348518363089665],
              UndirectedEdge[26, 30] -> 
             RGBColor[
              0.31701994287924884`, 0.4369570883961569, 0.9418741496415883], 
             UndirectedEdge[169, 240] -> 
             RGBColor[
              0.22995248947003588`, 0.35902502463589653`, 0.9364068261398715],
              UndirectedEdge[95, 371] -> 
             RGBColor[
              0.27691206805261726`, 0.40838251913543877`, 0.9390811046696785],
              UndirectedEdge[65, 356] -> 
             RGBColor[
              0.5168552955479615, 0.6186454388483807, 0.9551078886503179], 
             UndirectedEdge[264, 310] -> 
             RGBColor[
              0.18630458251799184`, 0.3131483069921579, 0.9339211424102444], 
             UndirectedEdge[96, 114] -> 
             RGBColor[
              0.3078946845637386, 0.4390858835693603, 0.940913671252023], 
             UndirectedEdge[244, 308] -> 
             RGBColor[
              0.2605622771689302, 0.3911978522800683, 0.9381500082662007], 
             UndirectedEdge[187, 298] -> 
             RGBColor[
              0.8336819864556111, 0.8702194025777671, 0.983998526176473], 
             UndirectedEdge[58, 228] -> 
             RGBColor[
              0.3333340850867448, 0.46222040417284493`, 0.9424943639948453], 
             UndirectedEdge[36, 82] -> 
             RGBColor[
              0.4494472254875384, 0.5619085191994977, 0.950357203271827], 
             UndirectedEdge[72, 355] -> 
             RGBColor[
              0.2293238377834227, 0.358364271854447, 0.9363710253563257], 
             UndirectedEdge[22, 350] -> 
             RGBColor[
              0.36253057369193453`, 0.4869086502715662, 0.9443767178010922], 
             UndirectedEdge[58, 192] -> 
             RGBColor[
              0.32165036846239214`, 0.45210055607350297`, 0.9417498879030466],
              UndirectedEdge[3, 174] -> 
             RGBColor[
              0.5493425209245979, 0.6414387311936623, 0.9591931799908751], 
             UndirectedEdge[44, 54] -> 
             RGBColor[
              0.3749740145051137, 0.4982078184475008, 0.9451505160427869], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.416297218948796, 0.5331956497034136, 0.948244914168578], 
             UndirectedEdge[170, 271] -> 
             RGBColor[
              0.37587875919358854`, 0.49980798052879155`, 0.9451782688612774],
              UndirectedEdge[192, 201] -> 
             RGBColor[
              0.3104580154232146, 0.4403366833931581, 0.941112499955068], 
             UndirectedEdge[274, 395] -> 
             RGBColor[
              0.2518980358087536, 0.3820911852658918, 0.9376565925383351], 
             UndirectedEdge[208, 284] -> 
             RGBColor[
              0.23854240400840393`, 0.3680535694477596, 0.9368960090651918], 
             UndirectedEdge[237, 320] -> 
             RGBColor[
              0.644156525821959, 0.7209597620645476, 0.9658368355590718], 
             UndirectedEdge[119, 380] -> 
             RGBColor[
              0.25299451614994406`, 0.383243655625352, 0.9377190354716685], 
             UndirectedEdge[342, 398] -> 
             RGBColor[
              0.7713918010534688, 0.8216082690775031, 0.9746694433091629], 
             UndirectedEdge[90, 264] -> 
             RGBColor[
              0.44791840801160593`, 0.5435825734144455, 0.9527225707160447], 
             UndirectedEdge[212, 367] -> 
             RGBColor[
              0.21510593499852879`, 0.3434203545604207, 0.9355613368262283], 
             UndirectedEdge[92, 284] -> 
             RGBColor[
              0.26583096592771405`, 0.3967355782197115, 0.9384500522966869], 
             UndirectedEdge[267, 342] -> 
             RGBColor[
              0.5872785724074823, 0.6758182275354083, 0.9606518669736626], 
             UndirectedEdge[107, 297] -> 
             RGBColor[
              0.892928350056968, 0.6310869487653001, 0.5801992997291281], 
             UndirectedEdge[163, 245] -> 
             RGBColor[
              0.2374360489235272, 0.36689072010659024`, 0.9368330037798137], 
             UndirectedEdge[72, 200] -> 
             RGBColor[
              0.24919308184682543`, 0.37924810714791846`, 0.937502549411824], 
             UndirectedEdge[254, 286] -> 
             RGBColor[
              0.5978806349455185, 0.6831403582378857, 0.9623651309393161], 
             UndirectedEdge[269, 307] -> 
             RGBColor[
              0.9891494518709179, 0.9878632201941573, 0.6900803930330166], 
             UndirectedEdge[240, 304] -> 
             RGBColor[
              0.22915247220042573`, 0.35818415576151175`, 0.9363612663398866],
              UndirectedEdge[228, 332] -> 
             RGBColor[
              0.44753939238477464`, 0.5600512043149352, 0.9502922373222444], 
             UndirectedEdge[104, 109] -> 
             RGBColor[
              0.9639852685830836, 0.8836832833010115, 0.5065761886025747], 
             UndirectedEdge[28, 372] -> 
             RGBColor[
              0.2698833093261751, 0.4009948480649053, 0.9386808272583244], 
             UndirectedEdge[28, 362] -> 
             RGBColor[
              0.34647407000563907`, 0.4726287790194402, 0.9433672519077005], 
             UndirectedEdge[209, 227] -> 
             RGBColor[
              0.24347750032410487`, 0.3732406685787401, 0.9371770554995502], 
             UndirectedEdge[245, 371] -> 
             RGBColor[
              0.25097222698134913`, 0.38111810148861974`, 0.9376038690952258],
              UndirectedEdge[308, 397] -> 
             RGBColor[
              0.25521896402580857`, 0.3855816913810268, 0.9378457144874233], 
             UndirectedEdge[58, 87] -> 
             RGBColor[
              0.29447485481202706`, 0.42684212156457424`, 0.9400812793938123],
              UndirectedEdge[154, 332] -> 
             RGBColor[
              0.47868981834297064`, 0.5870321376139921, 0.9522771149190605], 
             UndirectedEdge[97, 180] -> 
             RGBColor[
              0.40427723483543804`, 0.5245863540749827, 0.9469811658087601], 
             UndirectedEdge[202, 300] -> 
             RGBColor[
              0.873168201892003, 0.5137197571930974, 0.21575357463755512`], 
             UndirectedEdge[25, 317] -> 
             RGBColor[
              0.9196690890458292, 0.6829063077266104, 0.4996382373528887], 
             UndirectedEdge[93, 128] -> 
             RGBColor[
              0.2857256322546389, 0.41603117628641406`, 0.9396421556226617], 
             UndirectedEdge[68, 178] -> 
             RGBColor[
              0.2603565331566741, 0.3909816022782634, 0.9381382914490737], 
             UndirectedEdge[271, 273] -> 
             RGBColor[
              0.2911126400044641, 0.42330822062509427`, 0.9398898062344726], 
             UndirectedEdge[149, 318] -> 
             RGBColor[
              0.22201805165799737`, 0.3506854274230307, 0.9359549716444248], 
             UndirectedEdge[42, 358] -> 
             RGBColor[
              0.9504012676368335, 0.9272297470138823, 0.6629122325696076], 
             UndirectedEdge[155, 170] -> 
             RGBColor[
              0.3747576276064379, 0.498629600146848, 0.9451144220759548], 
             UndirectedEdge[193, 338] -> 
             RGBColor[
              0.9083139927934867, 0.9256835176042191, 0.801309811633953], 
             UndirectedEdge[79, 109] -> 
             RGBColor[
              0.79245120355282, 0.8352543310125031, 0.854215095221335], 
             UndirectedEdge[173, 175] -> 
             RGBColor[
              0.20264987627198583`, 0.3303282470790865, 0.9348519827088393], 
             UndirectedEdge[95, 178] -> 
             RGBColor[
              0.2628834870920424, 0.39363759108246865`, 0.9382821977373995], 
             UndirectedEdge[243, 348] -> 
             RGBColor[
              0.27566358738232355`, 0.40707028679271356`, 0.9390100055424669],
              UndirectedEdge[56, 83] -> 
             RGBColor[
              0.4019083501795848, 0.5225345452496872, 0.9468302225732115], 
             UndirectedEdge[205, 207] -> 
             RGBColor[
              0.967562165289962, 0.8957834071543473, 0.4992706546503005], 
             UndirectedEdge[74, 302] -> 
             RGBColor[
              0.9059752552459537, 0.9158904255240137, 0.6941066978535942], 
             UndirectedEdge[179, 196] -> 
             RGBColor[
              0.2837836367777321, 0.41560497354815545`, 0.9394724303429989], 
             UndirectedEdge[174, 338] -> 
             RGBColor[
              0.8614468790047858, 0.8890515325777966, 0.796643588235805], 
             UndirectedEdge[159, 167] -> 
             RGBColor[
              0.30749203096032607`, 0.43842628345076595`, 0.9408993959616536],
              UndirectedEdge[251, 356] -> 
             RGBColor[
              0.6703471241239707, 0.7405191581131181, 0.9690711033483659], 
             UndirectedEdge[238, 277] -> 
             RGBColor[
              0.24351796868213066`, 0.3732832033888673, 0.9371793601126722], 
             UndirectedEdge[163, 164] -> 
             RGBColor[
              0.24375587866941067`, 0.373533261869863, 0.9371929087344915], 
             UndirectedEdge[213, 230] -> 
             RGBColor[
              0.939912673270707, 0.7956677722978341, 0.2903688589282392], 
             UndirectedEdge[246, 343] -> 
             RGBColor[
              0.5830017143905886, 0.6708646520088869, 0.9612227826191269], 
             UndirectedEdge[53, 95] -> 
             RGBColor[
              0.2855112454690256, 0.4174207998194225, 0.9395708151022], 
             UndirectedEdge[139, 184] -> 
             RGBColor[
              0.21446679583023515`, 0.34274857877078024`, 0.9355249387961155],
              UndirectedEdge[101, 308] -> 
             RGBColor[
              0.26096510566357906`, 0.39162125056874597`, 0.9381729487530396],
              UndirectedEdge[3, 52] -> 
             RGBColor[
              0.3783625716146186, 0.5021403753019544, 0.9453299063837663], 
             UndirectedEdge[136, 286] -> 
             RGBColor[
              0.6724159966518739, 0.7436515226508849, 0.9682328276448666], 
             UndirectedEdge[164, 169] -> 
             RGBColor[
              0.23161848816298614`, 0.3607760948926053, 0.9365017023008109], 
             UndirectedEdge[14, 102] -> 
             RGBColor[
              0.9068270565903578, 0.5698348658899638, 0.39664654648642544`], 
             UndirectedEdge[232, 281] -> 
             RGBColor[
              0.5787753460534887, 0.6689149253152545, 0.9599824618467317], 
             UndirectedEdge[56, 349] -> 
             RGBColor[
              0.44815708600119175`, 0.5625928756893122, 0.949777151123613], 
             UndirectedEdge[225, 324] -> 
             RGBColor[
              0.2685328797360218, 0.39957546094347285`, 0.9386039222909468], 
             UndirectedEdge[5, 272] -> 
             RGBColor[
              0.744229977263282, 0.800290827008182, 0.9750955199196911], 
             UndirectedEdge[68, 371] -> 
             RGBColor[
              0.27438511411724903`, 0.40572653033123346`, 0.9389371983813526],
              UndirectedEdge[151, 397] -> 
             RGBColor[
              0.28259253336983103`, 0.413697573989268, 0.9394285988931239], 
             UndirectedEdge[1, 356] -> 
             RGBColor[
              0.43918071918933627`, 0.5530514553912338, 0.949693285932573], 
             UndirectedEdge[96, 115] -> 
             RGBColor[
              0.262758793949384, 0.3935065306835328, 0.9382750966473921], 
             UndirectedEdge[328, 347] -> 
             RGBColor[
              0.29474363512034735`, 0.42706072191761096`, 0.940098925902251], 
             UndirectedEdge[80, 159] -> 
             RGBColor[
              0.3329254963503931, 0.4627850644418876, 0.9424346961263579], 
             UndirectedEdge[50, 121] -> 
             RGBColor[
              0.5036718866822538, 0.607942553625398, 0.9540700424119916], 
             UndirectedEdge[108, 342] -> 
             RGBColor[
              0.48546363914421214`, 0.5908319937486516, 0.9532799343430639], 
             UndirectedEdge[178, 315] -> 
             RGBColor[
              0.24363133500537287`, 0.37340235858243487`, 0.9371858161570703],
              UndirectedEdge[146, 228] -> 
             RGBColor[
              0.45159420731101624`, 0.5633430857393887, 0.9506114472065146], 
             UndirectedEdge[63, 152] -> 
             RGBColor[
              0.5710886094431091, 0.5911007265104762, 0.6136429928057057], 
             UndirectedEdge[43, 137] -> 
             RGBColor[
              0.22449567090087896`, 0.35328956233743236`, 0.9360960683949977],
              UndirectedEdge[97, 141] -> 
             RGBColor[
              0.401174197469898, 0.5218986590721447, 0.9467834430117361], 
             UndirectedEdge[25, 207] -> 
             RGBColor[
              0.8942834665962583, 0.5873379716371798, 0.2323719540995589], 
             UndirectedEdge[214, 310] -> 
             RGBColor[
              0.5831756221385668, 0.6483250855590861, 0.9230305133548782], 
             UndirectedEdge[37, 87] -> 
             RGBColor[
              0.2699691213947309, 0.4010850419897568, 0.9386857141286811], 
             UndirectedEdge[146, 262] -> 
             RGBColor[
              0.736987048840004, 0.7937027834714817, 0.9726540973253948], 
             UndirectedEdge[322, 364] -> 
             RGBColor[
              0.428972946302528, 0.5444804947900268, 0.9489681159313363], 
             UndirectedEdge[219, 311] -> 
             RGBColor[
              0.48328094147507245`, 0.5912218175992272, 0.9525107826182344], 
             UndirectedEdge[5, 260] -> 
             RGBColor[
              0.8251985302055844, 0.863544075950503, 0.9831657085828327], 
             UndirectedEdge[204, 389] -> 
             RGBColor[
              0.17900756331513207`, 0.305478677152213, 0.9335055879616141], 
             UndirectedEdge[275, 279] -> 
             RGBColor[
              0.9688751403565641, 0.9066136951652177, 0.5278514920501343], 
             UndirectedEdge[78, 289] -> 
             RGBColor[
              0.8697986288874946, 0.4756199934349731, 0.21204915614425965`], 
             UndirectedEdge[163, 329] -> 
             RGBColor[
              0.2400560374603316, 0.3696444941756393, 0.936982208251059], 
             UndirectedEdge[47, 181] -> 
             RGBColor[
              0.5006021052009016, 0.6049229030605833, 0.9539741177513421], 
             UndirectedEdge[267, 291] -> 
             RGBColor[
              0.6338452626420983, 0.7127939223878283, 0.964884724751121], 
             UndirectedEdge[28, 301] -> 
             RGBColor[
              0.27255350960952185`, 0.40380139786317903`, 0.9388328912142536],
              UndirectedEdge[174, 193] -> 
             RGBColor[
              0.7754724977883137, 0.8245433157037161, 0.9782504569369469], 
             UndirectedEdge[60, 263] -> 
             RGBColor[
              0.3098059764171655, 0.4384458415430197, 0.9411195068336586], 
             UndirectedEdge[122, 385] -> 
             RGBColor[
              0.510754315643456, 0.6134960658238386, 0.9546818417083673], 
             UndirectedEdge[282, 350] -> 
             RGBColor[
              0.5398022619922347, 0.6366471769552697, 0.9571158788344], 
             UndirectedEdge[142, 306] -> 
             RGBColor[
              0.8959800446329425, 0.5393216395308846, 0.25385968825832217`], 
             UndirectedEdge[6, 289] -> 
             RGBColor[
              0.9455504255792939, 0.808391434737298, 0.3768472415142159], 
             UndirectedEdge[3, 117] -> 
             RGBColor[
              0.35979838664313185`, 0.4860610113427193, 0.9441470129330474], 
             UndirectedEdge[6, 132] -> 
             RGBColor[
              0.896284952197167, 0.9156286210821021, 0.7489609820272407], 
             UndirectedEdge[22, 394] -> 
             RGBColor[
              0.32559317401626164`, 0.45491533120018696`, 0.9420230993562184],
              UndirectedEdge[11, 391] -> 
             RGBColor[
              0.8719267260498035, 0.4460000576161881, 0.2122170074273244], 
             UndirectedEdge[34, 249] -> 
             RGBColor[
              0.2909291460215572, 0.4227877812822719, 0.9398913506685179], 
             UndirectedEdge[269, 306] -> 
             RGBColor[
              0.9817175223804617, 0.9496479498761543, 0.4126513364277588], 
             UndirectedEdge[69, 394] -> 
             RGBColor[
              0.42354328649608, 0.5403260059804602, 0.948470615599907], 
             UndirectedEdge[361, 369] -> 
             RGBColor[
              0.30654023496768024`, 0.43518917662023243`, 0.9409270894573605],
              UndirectedEdge[85, 184] -> 
             RGBColor[
              0.22953519250719354`, 0.35858641906979366`, 0.9363830616951732],
              UndirectedEdge[73, 96] -> 
             RGBColor[
              0.26501373249139615`, 0.3958766140625488, 0.9384035120614771], 
             UndirectedEdge[71, 382] -> 
             RGBColor[
              0.8849504676641144, 0.7666705508963009, 0.612411028914603], 
             UndirectedEdge[122, 165] -> 
             RGBColor[
              0.48941818004964077`, 0.5961744297668246, 0.9530021829575823], 
             UndirectedEdge[321, 331] -> 
             RGBColor[
              0.634939466831133, 0.7117908877119044, 0.9662504402131629], 
             UndirectedEdge[296, 374] -> 
             RGBColor[
              0.2888126336637139, 0.4208907681321412, 0.9397588242759214], 
             UndirectedEdge[66, 297] -> 
             RGBColor[
              0.9597109537164616, 0.9397882388587341, 0.661988741969209], 
             UndirectedEdge[75, 145] -> 
             RGBColor[
              0.24110109065239455`, 0.37074291134069687`, 0.9370417224843294],
              UndirectedEdge[105, 239] -> 
             RGBColor[
              0.37092951443948974`, 0.4957022347731742, 0.9448562785533615], 
             UndirectedEdge[92, 354] -> 
             RGBColor[
              0.2837186388686095, 0.41553665662456213`, 0.9394687288082302], 
             UndirectedEdge[188, 369] -> 
             RGBColor[
              0.26226993371413826`, 0.39299270758076044`, 0.9382472567801988],
              UndirectedEdge[170, 251] -> 
             RGBColor[
              0.6336427393204518, 0.7104942073432939, 0.966244231440377], 
             UndirectedEdge[53, 68] -> 
             RGBColor[
              0.28298429153365734`, 0.4147648110152172, 0.9394269088138741], 
             UndirectedEdge[274, 318] -> 
             RGBColor[
              0.2272727207343431, 0.3562084177875322, 0.9362542172747363], 
             UndirectedEdge[179, 359] -> 
             RGBColor[
              0.2576056390091489, 0.3880902381124516, 0.9379816320969553], 
             UndirectedEdge[20, 328] -> 
             RGBColor[
              0.3585480828066595, 0.484978061001665, 0.9440673446781876], 
             UndirectedEdge[307, 352] -> 
             RGBColor[
              0.9896970551583855, 0.989034488254865, 0.7496836314580985], 
             UndirectedEdge[6, 216] -> 
             RGBColor[
              0.8262245586177389, 0.8608969091391403, 0.7419780167468455], 
             UndirectedEdge[297, 385] -> 
             RGBColor[
              0.76103003285282, 0.8129579010796052, 0.9674643990261943], 
             UndirectedEdge[40, 348] -> 
             RGBColor[
              0.3011336768698887, 0.43101491807386594`, 0.9405639649079968], 
             UndirectedEdge[229, 329] -> 
             RGBColor[
              0.2410174933653264, 0.37065504529161414`, 0.937036961742502], 
             UndirectedEdge[6, 213] -> 
             RGBColor[
              0.9521578283629528, 0.8364523308595698, 0.38226017426140096`], 
             UndirectedEdge[189, 374] -> 
             RGBColor[
              0.2883252349784382, 0.42037848121105487`, 0.9397310676418367], 
             UndirectedEdge[97, 140] -> 
             RGBColor[
              0.5571047214907582, 0.6505692358866151, 0.9586689069541604], 
             UndirectedEdge[34, 386] -> 
             RGBColor[
              0.32582607560218535`, 0.4566359030170521, 0.9419823273140535], 
             UndirectedEdge[162, 313] -> 
             RGBColor[
              0.26444617460999714`, 0.3952800747439503, 0.938371190479758], 
             UndirectedEdge[258, 392] -> 
             RGBColor[
              0.25044123686096187`, 0.3805599972053746, 0.9375736299933992], 
             UndirectedEdge[45, 273] -> 
             RGBColor[
              0.2854682454604019, 0.41737560408400093`, 0.9395683663153217], 
             UndirectedEdge[226, 393] -> 
             RGBColor[
              0.2307270128999809, 0.3598390978683905, 0.9364509341034022], 
             UndirectedEdge[88, 168] -> 
             RGBColor[
              0.8302321284771527, 0.8662542155842119, 0.8889737374567761], 
             UndirectedEdge[188, 327] -> 
             RGBColor[
              0.2928390260811543, 0.4242124195155595, 0.9400214534598996], 
             UndirectedEdge[59, 349] -> 
             RGBColor[
              0.38969866664907243`, 0.5119591310520951, 0.9460522323352465], 
             UndirectedEdge[260, 398] -> 
             RGBColor[
              0.8741897182555676, 0.9025122258100744, 0.9845069042800476], 
             UndirectedEdge[248, 353] -> 
             RGBColor[
              0.21329376874399575`, 0.34151565292892977`, 0.9354581366388923],
              UndirectedEdge[30, 389] -> 
             RGBColor[
              0.17900757935671766`, 0.3054786940129366, 0.9335055888751587], 
             UndirectedEdge[216, 311] -> 
             RGBColor[
              0.5892378065656463, 0.6771523472031584, 0.9609814583426657], 
             UndirectedEdge[66, 307] -> 
             RGBColor[
              0.9790114308840521, 0.9540083964475, 0.6215212155905427], 
             UndirectedEdge[94, 225] -> 
             RGBColor[
              0.2586160366315361, 0.3891522300764899, 0.9380391727468009], 
             UndirectedEdge[177, 324] -> 
             RGBColor[
              0.3009330775683418, 0.4324131600288711, 0.9404936246072413], 
             UndirectedEdge[79, 320] -> 
             RGBColor[
              0.6503499887449748, 0.725987894277777, 0.9663244076477739], 
             UndirectedEdge[133, 234] -> 
             RGBColor[
              0.31799880832538563`, 0.4487941940432452, 0.9415224703076799], 
             UndirectedEdge[35, 195] -> 
             RGBColor[
              0.2633678783864708, 0.39414671704509485`, 0.9383097831050244], 
             UndirectedEdge[34, 86] -> 
             RGBColor[
              0.30641268277319833`, 0.4390619601211778, 0.940773115180684], 
             UndirectedEdge[98, 131] -> 
             RGBColor[
              0.9500181408117219, 0.8331560489585412, 0.3119185917864623], 
             UndirectedEdge[173, 261] -> 
             RGBColor[
              0.2029079903175545, 0.3305995413063548, 0.9348666819218888], 
             UndirectedEdge[103, 331] -> 
             RGBColor[
              0.39832931347278433`, 0.519434563541872, 0.9466021695190721], 
             UndirectedEdge[135, 322] -> 
             RGBColor[
              0.5058470879872912, 0.6097084800365293, 0.954241282226749], 
             UndirectedEdge[50, 181] -> 
             RGBColor[
              0.5107299622168331, 0.6136726173070488, 0.9546256799726562], 
             UndirectedEdge[35, 153] -> 
             RGBColor[
              0.2992359056961653, 0.4310433224437109, 0.940381814697533], 
             UndirectedEdge[121, 362] -> 
             RGBColor[
              0.4789275839454543, 0.5865328087394392, 0.9524871331941591], 
             UndirectedEdge[84, 152] -> 
             RGBColor[
              0.18127159018880934`, 0.30785831294404253`, 0.9336345209427424],
              UndirectedEdge[295, 345] -> 
             RGBColor[
              0.22216737223106828`, 0.3508423728127994, 0.9359634752301611], 
             UndirectedEdge[22, 266] -> 
             RGBColor[
              0.27365816407618504`, 0.40496245974678047`, 0.9388957996519403],
              UndirectedEdge[271, 335] -> 
             RGBColor[
              0.2936530311811995, 0.4259783328219468, 0.9400344777538158], 
             UndirectedEdge[175, 261] -> 
             RGBColor[
              0.1791902555267194, 0.3056706982499465, 0.9335159920127951], 
             UndirectedEdge[59, 254] -> 
             RGBColor[
              0.401764791398701, 0.521970513340684, 0.9469425623795822], 
             UndirectedEdge[53, 270] -> 
             RGBColor[
              0.26941555401375766`, 0.4005032075741548, 0.9386541892852642], 
             UndirectedEdge[214, 300] -> 
             RGBColor[
              0.9368849358196452, 0.7904007327583793, 0.5711375264891978], 
             UndirectedEdge[3, 386] -> 
             RGBColor[
              0.35472139925516205`, 0.48166358004406556`, 0.9438235117860897],
              UndirectedEdge[299, 336] -> 
             RGBColor[
              0.2125676316732109, 0.34075243682778544`, 0.9354167842069347], 
             UndirectedEdge[110, 351] -> 
             RGBColor[
              0.25066121746090764`, 0.3807912107634932, 0.9375861575631339], 
             UndirectedEdge[172, 328] -> 
             RGBColor[
              0.3054309232922502, 0.438293739399488, 0.9407075511532149], 
             UndirectedEdge[185, 302] -> 
             RGBColor[
              0.905483758897311, 0.5759228028237954, 0.28769672462851575`], 
             UndirectedEdge[370, 391] -> 
             RGBColor[
              0.8258037070409253, 0.5129958576116641, 0.5754614637475668], 
             UndirectedEdge[50, 364] -> 
             RGBColor[
              0.4018386991300539, 0.5224516905515073, 0.9468320085978967], 
             UndirectedEdge[73, 195] -> 
             RGBColor[
              0.2444053413712617, 0.37421588834782205`, 0.937229894674568], 
             UndirectedEdge[80, 332] -> 
             RGBColor[
              0.4308190028061351, 0.5455688432531333, 0.9492268288835535], 
             UndirectedEdge[5, 267] -> 
             RGBColor[
              0.7063209858486378, 0.7695859535146778, 0.9720624004607035], 
             UndirectedEdge[136, 246] -> 
             RGBColor[
              0.5311924849620417, 0.6300266566393842, 0.9563079499316767], 
             UndirectedEdge[59, 246] -> 
             RGBColor[
              0.38891052450146135`, 0.5112764819370106, 0.9460020126145274], 
             UndirectedEdge[177, 200] -> 
             RGBColor[
              0.2962840776702533, 0.42752676637236176`, 0.9402288709406241], 
             UndirectedEdge[17, 157] -> 
             RGBColor[
              0.5023802232259484, 0.6068939230427937, 0.9539683579331921], 
             UndirectedEdge[151, 386] -> 
             RGBColor[
              0.3275993292124569, 0.45817180616795133`, 0.9420953174660733], 
             UndirectedEdge[4, 188] -> 
             RGBColor[
              0.24964120798061978`, 0.37971911612737436`, 0.9375280695322004],
              UndirectedEdge[241, 255] -> 
             RGBColor[
              0.2757184631493581, 0.40712796470319146`, 0.9390131306362182], 
             UndirectedEdge[62, 345] -> 
             RGBColor[
              0.19050782677282135`, 0.3175661832050619, 0.9341605109524143], 
             UndirectedEdge[57, 114] -> 
             RGBColor[
              0.3010426520782409, 0.43188396298315035`, 0.9405234581386476], 
             UndirectedEdge[32, 137] -> 
             RGBColor[
              0.21892075175740905`, 0.34742996884735633`, 0.9357785849971308],
              UndirectedEdge[152, 175] -> 
             RGBColor[
              0.181274153781999, 0.307861007443026, 0.9336346669355821], 
             UndirectedEdge[99, 235] -> 
             RGBColor[
              0.8591106393434069, 0.8900471270857477, 0.9483188623764983], 
             UndirectedEdge[156, 256] -> 
             RGBColor[
              0.20563395231845213`, 0.3334647002052716, 0.9350219214251405], 
             UndirectedEdge[48, 286] -> 
             RGBColor[
              0.5758463873446392, 0.6644950889479655, 0.9608396409213635], 
             UndirectedEdge[61, 262] -> 
             RGBColor[
              0.9659943820446136, 0.9709682059989204, 0.7529333373497976], 
             UndirectedEdge[146, 385] -> 
             RGBColor[
              0.5553761412741389, 0.6499183967532158, 0.95814039073239], 
             UndirectedEdge[29, 150] -> 
             RGBColor[
              0.2555149933709343, 0.38589283699209853`, 0.937862572920692], 
             UndirectedEdge[141, 220] -> 
             RGBColor[
              0.4177492311275311, 0.5356546049090093, 0.9480055136475012], 
             UndirectedEdge[152, 242] -> 
             RGBColor[
              0.5509815030039178, 0.5121510355041116, 0.5934630978551525], 
             UndirectedEdge[95, 151] -> 
             RGBColor[
              0.2988070240901653, 0.4307400317944288, 0.9403519901524575], 
             UndirectedEdge[252, 293] -> 
             RGBColor[
              0.21778209463220533`, 0.3462331680137357, 0.9357137401583427], 
             UndirectedEdge[93, 390] -> 
             RGBColor[
              0.2557686929307827, 0.3861594913149804, 0.9378770207353105], 
             UndirectedEdge[229, 249] -> 
             RGBColor[
              0.2582327214414536, 0.38874934150812634`, 0.9380173435137897], 
             UndirectedEdge[96, 153] -> 
             RGBColor[
              0.3021711245350493, 0.4341284235470012, 0.9405489710681403], 
             UndirectedEdge[202, 217] -> 
             RGBColor[
              0.8395826476787889, 0.30525515205179155`, 0.18553769416040178`],
              UndirectedEdge[163, 304] -> 
             RGBColor[
              0.23203584179739814`, 0.3612147600241211, 0.9365254699728711], 
             UndirectedEdge[18, 323] -> 
             RGBColor[
              0.8877084052982851, 0.9130534285104475, 0.9806512796744769], 
             UndirectedEdge[152, 264] -> 
             RGBColor[
              0.186823590274237, 0.31369381705096394`, 0.9339506991341594], 
             UndirectedEdge[23, 169] -> 
             RGBColor[
              0.21705819820147026`, 0.34547230696734843`, 0.9356725153275212],
              UndirectedEdge[290, 342] -> 
             RGBColor[
              0.5042459583975736, 0.6071002946590989, 0.9544767271173353], 
             UndirectedEdge[285, 330] -> 
             RGBColor[
              0.23174352854992997`, 0.3609075202673017, 0.9365088231658666], 
             UndirectedEdge[55, 192] -> 
             RGBColor[
              0.3740111987150174, 0.498371434802681, 0.9450526407503718], 
             UndirectedEdge[161, 170] -> 
             RGBColor[
              0.43820314080929235`, 0.5539712686639211, 0.9491428945379133], 
             UndirectedEdge[42, 205] -> 
             RGBColor[
              0.9637471875060623, 0.9705535185426564, 0.8607371274369169], 
             UndirectedEdge[267, 398] -> 
             RGBColor[
              0.7553121738986209, 0.8085541033742493, 0.9734035961579184], 
             UndirectedEdge[32, 199] -> 
             RGBColor[
              0.22104408708317058`, 0.349661728901967, 0.9358995058027398], 
             UndirectedEdge[154, 385] -> 
             RGBColor[
              0.5027895372841396, 0.606597375130399, 0.9541743330742887], 
             UndirectedEdge[91, 190] -> 
             RGBColor[
              0.25186209923856306`, 0.38205341365211143`, 0.9376545460038261],
              UndirectedEdge[94, 380] -> 
             RGBColor[
              0.2628073165498582, 0.39355753101314184`, 0.9382778599377064], 
             UndirectedEdge[119, 288] -> 
             RGBColor[
              0.2427621793276949, 0.37248882085754254`, 0.9371363190270272], 
             UndirectedEdge[65, 251] -> 
             RGBColor[
              0.6688240146939028, 0.7392826292624911, 0.9689511985946974], 
             UndirectedEdge[198, 216] -> 
             RGBColor[
              0.7427956016916255, 0.7990494191661757, 0.974984628023718], 
             UndirectedEdge[101, 182] -> 
             RGBColor[
              0.2744680720566198, 0.40581372438534935`, 0.9389419227132746], 
             UndirectedEdge[11, 230] -> 
             RGBColor[
              0.9461599473200244, 0.8204361321227099, 0.29539556227068897`], 
             UndirectedEdge[53, 101] -> 
             RGBColor[
              0.27504289638646184`, 0.40641790120198085`, 0.9389746581084827],
              UndirectedEdge[202, 264] -> 
             RGBColor[
              0.5231853201585595, 0.37556082624020004`, 0.5678587762898913], 
             UndirectedEdge[336, 367] -> 
             RGBColor[
              0.21516062802241154`, 0.34347784039625945`, 0.9355644515130273],
              UndirectedEdge[13, 132] -> 
             RGBColor[
              0.8815012453075697, 0.9077928551611671, 0.9634088234551113], 
             UndirectedEdge[146, 307] -> 
             RGBColor[
              0.760285606005483, 0.8109047025764178, 0.9254188643765703], 
             UndirectedEdge[75, 133] -> 
             RGBColor[
              0.27071817278007254`, 0.4018723424883518, 0.9387283714969541], 
             UndirectedEdge[153, 369] -> 
             RGBColor[
              0.28744235484774583`, 0.41864755274771004`, 0.9397101894237105],
              UndirectedEdge[20, 181] -> 
             RGBColor[
              0.4874856363228792, 0.5935620769713348, 0.9531383479528726], 
             UndirectedEdge[112, 394] -> 
             RGBColor[
              0.34389456121557604`, 0.47228591710687856`, 0.9431336352400042],
              UndirectedEdge[279, 306] -> 
             RGBColor[
              0.9580128778613826, 0.8669798939942239, 0.307271930750418], 
             UndirectedEdge[34, 68] -> 
             RGBColor[
              0.29450681654452554`, 0.42654813983932427`, 0.9400950937121118],
              UndirectedEdge[4, 284] -> 
             RGBColor[
              0.23809729374437577`, 0.3675857303386453, 0.936870660694137], 
             UndirectedEdge[193, 235] -> 
             RGBColor[
              0.7812166445775857, 0.8290306868326278, 0.9788229798067978], 
             UndirectedEdge[296, 316] -> 
             RGBColor[
              0.27790052377493313`, 0.40942144877130526`, 0.9391373957607753],
              UndirectedEdge[117, 223] -> 
             RGBColor[
              0.40179215387534173`, 0.5224135595233219, 0.9468284392932418], 
             UndirectedEdge[37, 110] -> 
             RGBColor[
              0.2526887349083196, 0.3829222601527542, 0.9377016216823209], 
             UndirectedEdge[83, 349] -> 
             RGBColor[
              0.3991304048320619, 0.5201284286132558, 0.946653214352108], 
             UndirectedEdge[192, 348] -> 
             RGBColor[
              0.30372248336585006`, 0.4332572121434699, 0.9407289213687278], 
             UndirectedEdge[97, 394] -> 
             RGBColor[
              0.40057619946044803`, 0.521380703252613, 0.9467453391073628], 
             UndirectedEdge[2, 352] -> 
             RGBColor[
              0.9063026650036, 0.5663670773157738, 0.3851970536504771], 
             UndirectedEdge[69, 350] -> 
             RGBColor[
              0.4604806861717529, 0.5723193250518395, 0.9508242340447808], 
             UndirectedEdge[164, 304] -> 
             RGBColor[
              0.230818470893376, 0.3599352260182205, 0.936456142500826], 
             UndirectedEdge[141, 350] -> 
             RGBColor[
              0.3964033490329356, 0.5177663899458625, 0.9464794487680284], 
             UndirectedEdge[114, 356] -> 
             RGBColor[
              0.4236281428800086, 0.5395805954873082, 0.9487022895227458], 
             UndirectedEdge[383, 390] -> 
             RGBColor[
              0.27326780022861263`, 0.40455216259248444`, 0.9388735690083126],
              UndirectedEdge[297, 307] -> 
             RGBColor[
              0.965939497584164, 0.9739442069028073, 0.9347428726703746], 
             UndirectedEdge[40, 58] -> 
             RGBColor[
              0.31906156196643076`, 0.449858262003899, 0.9415849314423156], 
             UndirectedEdge[173, 295] -> 
             RGBColor[
              0.23437748052955032`, 0.36367597080008385`, 0.9366588228345232],
              UndirectedEdge[161, 239] -> 
             RGBColor[
              0.3779757827321134, 0.5018053582125028, 0.9453052605381971], 
             UndirectedEdge[35, 369] -> 
             RGBColor[
              0.26924749981930185`, 0.40032657196053045`, 0.9386446188475038],
              UndirectedEdge[303, 313] -> 
             RGBColor[
              0.2862100467675046, 0.4181552842906852, 0.9396106108023645], 
             UndirectedEdge[237, 349] -> 
             RGBColor[
              0.5118990860533059, 0.6144062060618112, 0.9547772771793315], 
             UndirectedEdge[21, 263] -> 
             RGBColor[
              0.2875003760669833, 0.4191258516317633, 0.9396982137034129], 
             UndirectedEdge[126, 274] -> 
             RGBColor[
              0.22138486041548355`, 0.35001990328050514`, 0.9359189123398861],
              UndirectedEdge[331, 346] -> 
             RGBColor[
              0.3985622409768109, 0.5196363136385831, 0.946617011453659], 
             UndirectedEdge[106, 345] -> 
             RGBColor[
              0.5752211056493675, 0.6453489967018295, 0.953440498597335]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.23802405881018981`, 0.36750875577945274`, 0.9368664900729765],
              316 -> RGBColor[
              0.25427950679235417`, 0.38459426226363735`, 0.9377922137877805],
              308 -> RGBColor[
              0.2610883790761277, 0.39175081874132034`, 0.9381799689915176], 
             160 -> RGBColor[
              0.8294775817921864, 0.22758318757925894`, 0.17586107165535175`],
              245 -> RGBColor[
              0.22989884827362161`, 0.3589686443374169, 0.9364037713530907], 
             155 -> 
             RGBColor[
              0.30454561984188433`, 0.43742713413433654`, 0.9406547945639009],
              213 -> RGBColor[
              0.9109681137578394, 0.6847252697068382, 0.24722105836383443`], 
             352 -> RGBColor[
              0.9941541355650164, 0.9899046120181566, 0.6050919166244885], 27 -> 
             RGBColor[
              0.2974167180204977, 0.42993420632157753`, 0.9402488141514381], 
             367 -> RGBColor[
              0.21931469518675756`, 0.34784402836905765`, 0.9358010194926452],
              19 -> RGBColor[
              0.2743841090042405, 0.40572547389373365`, 0.9389371411416538], 
             164 -> RGBColor[
              0.24253850776538854`, 0.3722537278639624, 0.9371235812624463], 
             190 -> RGBColor[
              0.2411029859620505, 0.37074490343131483`, 0.9370418304194105], 
             103 -> RGBColor[
              0.34456615692423104`, 0.4728676195543337, 0.943176428724691], 
             138 -> RGBColor[
              0.8193428764107183, 0.14968340096107918`, 0.16615606633654534`],
              291 -> RGBColor[
              0.696491580031562, 0.7628237829435023, 0.9703834296798242], 28 -> 
             RGBColor[
              0.2882891132658928, 0.42034051500092084`, 0.9397290105637445], 
             337 -> RGBColor[
              0.2847433322190086, 0.4166136743051424, 0.9395270835786375], 
             195 -> RGBColor[
              0.24569470610522032`, 0.37557109243365844`, 0.9373033220887227],
              114 -> RGBColor[
              0.3288778807819878, 0.45927922327560866`, 0.9421767856415051], 
             93 -> RGBColor[
              0.2452381115380016, 0.3750911825937439, 0.9372773197035907], 34 -> 
             RGBColor[
              0.3122890105436297, 0.4449107776560043, 0.9411197574988789], 
             161 -> RGBColor[
              0.4314366462475933, 0.5481104711684827, 0.9487117394878181], 22 -> 
             RGBColor[
              0.29231839668471055`, 0.42457554734542235`, 0.9399584722936555],
              124 -> RGBColor[
              0.22327126764014227`, 0.35200263687874755`, 0.936026340440641], 
             84 -> RGBColor[
              0.17892701429477148`, 0.30539401502471114`, 0.9335010008140661],
              46 -> RGBColor[
              0.2843163130979401, 0.41616485013432336`, 0.9395027654714108], 
             241 -> RGBColor[
              0.290961948336973, 0.42314983412815754`, 0.9398812245669373], 
             185 -> RGBColor[
              0.8236904837096025, 0.18310101579396953`, 0.170319339995877], 
             390 -> 
             RGBColor[
              0.26629927432356376`, 0.3972278000362168, 0.9384767217670303], 
             121 -> RGBColor[
              0.5531961411455233, 0.6481485744409189, 0.9579687731366617], 
             322 -> RGBColor[
              0.5084161265639328, 0.611794141286916, 0.9544435263542006], 126 -> 
             RGBColor[
              0.21204174778307774`, 0.3401996995162911, 0.935386835897367], 
             236 -> RGBColor[
              0.2505222001886238, 0.3806450947961188, 0.9375782407351351], 78 -> 
             RGBColor[
              0.8418439495844675, 0.3226365094076515, 0.18770311941905493`], 
             376 -> RGBColor[
              0.43839329858407067`, 0.5541359737708264, 0.9491550112231723], 
             254 -> RGBColor[
              0.46951139015292603`, 0.5802095236300584, 0.951380802991181], 
             290 -> RGBColor[
              0.4051337172328171, 0.5253281960795354, 0.9470357401097634], 
             251 -> RGBColor[
              0.822315843269912, 0.8611563485272284, 0.9829144132927453], 165 -> 
             RGBColor[
              0.532748774101436, 0.6315484807311408, 0.9563590815017777], 100 -> 
             RGBColor[
              0.37661408553666426`, 0.5006259245426959, 0.9452184943970047], 
             235 -> RGBColor[
              0.7400936775781565, 0.7968860729351169, 0.9747292792785006], 70 -> 
             RGBColor[
              0.2778101351361315, 0.409326444580954, 0.9391322482615135], 234 -> 
             RGBColor[
              0.3387393935852255, 0.4678207700117279, 0.942805152517134], 257 -> 
             RGBColor[
              0.8226071697061851, 0.17477418965247965`, 0.16928195728277629`],
              135 -> RGBColor[
              0.5032780494106496, 0.6076228187861427, 0.9540390380992975], 
             265 -> RGBColor[
              0.5918946974095183, 0.6795658057661227, 0.9610152652432459], 
             111 -> RGBColor[
              0.8740781517963572, 0.5211001217496539, 0.21664006204298622`], 
             381 -> RGBColor[
              0.9931470290452047, 0.9914341346439413, 0.7632349938486772], 
             182 -> RGBColor[
              0.2880943118622093, 0.4201357663745271, 0.9397179169119876], 
             188 -> RGBColor[
              0.26708591845739416`, 0.39805461289699134`, 0.9385215199867163],
              154 -> RGBColor[
              0.4301580292792129, 0.547002997415629, 0.9486302671452295], 336 -> 
             RGBColor[
              0.2110065608580655, 0.33911165242346125`, 0.9353278835334095], 
             315 -> 
             RGBColor[
              0.24327422624281886`, 0.37302701463098736`, 0.937165479341338], 
             368 -> RGBColor[
              0.21278150541118618`, 0.3409772316867757, 0.9354289639999145], 
             269 -> RGBColor[
              0.9930589289900814, 0.9875620758967413, 0.48588543977432486`], 
             208 -> RGBColor[
              0.2330867180319017, 0.36231929757598597`, 0.9365853158197941], 
             86 -> RGBColor[
              0.30053635500276704`, 0.4332131425863514, 0.940426472862489], 
             119 -> RGBColor[
              0.24049836738192176`, 0.3701094109685675, 0.9370073982857251], 
             377 -> RGBColor[
              0.41487938737084307`, 0.5337694057214698, 0.9476567255932007], 
             140 -> RGBColor[
              0.6719249954084331, 0.7436321803229556, 0.9679348621123766], 85 -> 
             RGBColor[
              0.2413074662041341, 0.37095982513054093`, 0.9370534752666957], 
             351 -> RGBColor[
              0.24574449108125243`, 0.37562341960001794`, 0.9373061572694574],
              242 -> RGBColor[
              0.9183468399249884, 0.7139794601448493, 0.25315815463888625`], 
             117 -> RGBColor[
              0.3495171154366807, 0.47715589097540734`, 0.9434918994231435], 
             47 -> RGBColor[
              0.43389191818712153`, 0.5502371043169462, 0.948868187244693], 
             81 -> RGBColor[
              0.2197154470497895, 0.34826524398623987`, 0.9358238417183856], 
             275 -> RGBColor[
              0.992100640761205, 0.9910014261975552, 0.7805763556806252], 23 -> 
             RGBColor[
              0.21341792784235675`, 0.34164615201344867`, 0.935465207315867], 
             328 -> RGBColor[
              0.3094371851822424, 0.44244066986488095`, 0.9409380417086214], 
             110 -> RGBColor[
              0.25557794384056287`, 0.3859590019269685, 0.9378661578568105], 
             6 -> RGBColor[
              0.9933475429680663, 0.9881793920123014, 0.5172992901589675], 
             218 -> RGBColor[
              0.9100637739514378, 0.9311241665985504, 0.9912838892546516], 
             108 -> RGBColor[
              0.3675690787260941, 0.49279159425864094`, 0.9446421545612206], 
             297 -> RGBColor[
              0.9466390204165737, 0.9597240493140413, 0.9752103990490407], 
             157 -> RGBColor[
              0.46924384183457235`, 0.5799923158523045, 0.9513597406074984], 
             354 -> RGBColor[
              0.27977343586669706`, 0.4113899981292344, 0.939244055333676], 
             385 -> 
             RGBColor[
              0.5754210452890663, 0.6661917528451691, 0.9597183990033479], 
             270 -> RGBColor[
              0.249587147505622, 0.3796622951405196, 0.9375249908681246], 392 -> 
             RGBColor[
              0.24794921220500737`, 0.3779407212884774, 0.9374317128758627], 
             33 -> RGBColor[
              0.17894138666990014`, 0.3054091213022326, 0.9335018192995677], 
             252 -> RGBColor[
              0.2243331252717409, 0.35311871657522015`, 0.9360868116618829], 
             394 -> RGBColor[
              0.35886795134781274`, 0.48525511505495156`, 0.9440877264187814],
              260 -> RGBColor[
              0.8089540339665278, 0.8506803067038047, 0.9815926360666765], 
             159 -> RGBColor[
              0.3314345944952444, 0.46149372018986384`, 0.9423396971785006], 
             183 -> RGBColor[
              0.2589336294896423, 0.3894860403069097, 0.9380572591902335], 99 -> 
             RGBColor[
              0.9781276011086575, 0.9832081812363787, 0.921908445474496], 329 -> 
             RGBColor[
              0.23513882534723038`, 0.36447619247551505`, 0.9367021802955814],
              309 -> RGBColor[
              0.27079044913528966`, 0.40194830952027055`, 0.9387324875284604],
              17 -> RGBColor[
              0.5355166046173245, 0.6337955302332828, 0.9565769752588857], 
             349 -> RGBColor[
              0.4453791406536688, 0.5601867590528806, 0.9496001429025095], 
             347 -> RGBColor[
              0.2800500850584523, 0.411680773970341, 0.9392598100958807], 340 -> 
             RGBColor[
              0.99377812825938, 0.9891003704115706, 0.5641658418540755], 277 -> 
             RGBColor[
              0.2578128298869203, 0.3883080088616496, 0.9379934313109329], 
             104 -> RGBColor[
              0.9338740873595025, 0.7755398220742175, 0.265651742396037], 79 -> 
             RGBColor[
              0.590805957298975, 0.6786819174972005, 0.9609295556335575], 327 -> 
             RGBColor[
              0.3185921337049145, 0.45037022613412764`, 0.941521386933083], 
             191 -> RGBColor[
              0.6788533623879274, 0.7490446732648759, 0.968625416983622], 50 -> 
             RGBColor[
              0.45414763221898446`, 0.5677365328098771, 0.9501713116873214], 
             225 -> RGBColor[
              0.2571081050813221, 0.3875672984088326, 0.9379532982758011], 61 -> 
             RGBColor[
              0.9933459036684309, 0.98817588571614, 0.5171208625102379], 196 -> 
             RGBColor[
              0.29792411608308994`, 0.43046751385625726`, 0.9402777097204745],
              1 -> RGBColor[
              0.3599830334006432, 0.48622094308345976`, 0.9441587784611594], 
             263 -> RGBColor[
              0.26208361027682536`, 0.3927968698345563, 0.9382366459360847], 
             201 -> RGBColor[
              0.27642628673231373`, 0.407871932167485, 0.9390534401421363], 
             371 -> RGBColor[
              0.27204560568907665`, 0.4032675586398226, 0.9388039668373608], 
             293 -> RGBColor[
              0.21123106399266978`, 0.3393476194522512, 0.9353406686548026], 
             362 -> RGBColor[
              0.40465902674538534`, 0.5249170430379596, 0.9470054932516565], 
             184 -> RGBColor[
              0.21776291881025298`, 0.3462130130090464, 0.9357126481236506], 
             106 -> RGBColor[
              0.948494816832878, 0.9611080992427333, 0.9720690197854612], 206 -> 
             RGBColor[
              0.23156206990492625`, 0.36071679572626025`, 0.9364984893644777],
              358 -> RGBColor[
              0.9685766725786527, 0.9056638794389593, 0.332426736075871], 247 -> 
             RGBColor[
              0.9070075396154186, 0.6690229130152352, 0.24403428744221908`], 
             220 -> RGBColor[
              0.4754345148883495, 0.5850181831240037, 0.9518470930674744], 
             107 -> RGBColor[
              0.8392176796973624, 0.30244984821655896`, 0.1851882004092155], 
             375 -> RGBColor[
              0.25484534055170655`, 0.38518898942064916`, 0.9378244371832996],
              131 -> RGBColor[
              0.9224661794909306, 0.7303112688352736, 0.2564726719469704], 
             127 -> RGBColor[
              0.21049571798261152`, 0.33857472417205015`, 0.9352987917873766],
              210 -> RGBColor[
              0.2999237099233219, 0.432569213763913, 0.9403915836315417], 357 -> 
             RGBColor[
              0.6756901028072094, 0.7465735108387558, 0.9683101328309576], 
             181 -> RGBColor[
              0.5673122922146817, 0.6596087018042204, 0.9590800482579911], 
             194 -> RGBColor[
              0.3880550588481297, 0.5105355205850486, 0.9459475030995558], 
             118 -> RGBColor[
              0.20606162213947596`, 0.33391420830300045`, 0.935046276588767], 
             348 -> RGBColor[
              0.26295522261758464`, 0.39371298966810864`, 0.9382862829694559],
              276 -> RGBColor[
              0.765566144894021, 0.8167853580001923, 0.977268136766805], 305 -> 
             RGBColor[
              0.20290260740476634`, 0.33059388352371805`, 0.9348663753729688],
              343 -> RGBColor[
              0.7222005724227306, 0.7829078431950623, 0.9729458617771823], 
             280 -> RGBColor[
              0.23901320904650822`, 0.3685484153935707, 0.9369228207156182], 
             189 -> RGBColor[
              0.30054674338696064`, 0.4332240614368005, 0.9404270644656005], 
             168 -> RGBColor[
              0.6701504899984683, 0.7422459232099505, 0.9677579959968072], 
             363 -> RGBColor[
              0.8625124936811881, 0.46858316947675277`, 0.2069893934114667], 
             41 -> RGBColor[
              0.34082031608406577`, 0.4696231604900174, 0.9429377470586726], 
             14 -> RGBColor[
              0.9943570777774785, 0.9903386848900081, 0.6271809240368398], 77 -> 
             RGBColor[
              0.8293651040061051, 0.8667772376911834, 0.9835867780747127], 51 -> 
             RGBColor[
              0.3729233885884314, 0.4974292283459589, 0.9449833264510183], 
             179 -> RGBColor[
              0.2696431574723743, 0.40074243324005365`, 0.9386671509655232], 
             223 -> RGBColor[
              0.4540671923140028, 0.5676712280712366, 0.9501649791633402], 
             323 -> RGBColor[
              0.8302102447519867, 0.867451129981215, 0.983667388353521], 292 -> 
             RGBColor[
              0.2110186790508826, 0.3391243894124498, 0.9353285736465631], 
             396 -> RGBColor[
              0.2782995151593558, 0.4098408140138484, 0.9391601177298633], 
             321 -> RGBColor[
              0.8177864636409283, 0.8575802678943982, 0.9824729701128726], 
             143 -> RGBColor[
              0.6246442469651912, 0.7061533654458123, 0.9635934297498213], 
             112 -> RGBColor[
              0.3289211710833394, 0.45931671915880556`, 0.9421795440612271], 
             197 -> RGBColor[
              0.988751433892587, 0.9896164430866911, 0.8360813809631582], 54 -> 
             RGBColor[
              0.4519914858020445, 0.5659140400742732, 0.9500214756882968], 71 -> 
             RGBColor[
              0.871120013048017, 0.9000714687543917, 0.9875693985741776], 177 -> 
             RGBColor[
              0.3219085007459621, 0.453242696579629, 0.9417327029083903], 158 -> 
             RGBColor[
              0.5031159008708285, 0.6074911792968075, 0.9540262731722731], 
             226 -> RGBColor[
              0.23863402700947722`, 0.3681498710311214, 0.9369012268595588], 
             350 -> 
             RGBColor[
              0.4327427506991586, 0.5492417531977101, 0.948794963308529], 203 -> 
             RGBColor[
              0.29139757571829134`, 0.42360770612629445`, 0.9399060329018505],
              115 -> RGBColor[
              0.2386060995532787, 0.36812051750395375`, 0.9368996364322433], 
             173 -> RGBColor[
              0.22636761106282094`, 0.3552570901354948, 0.936202672617933], 
             212 -> RGBColor[
              0.21089717481030001`, 0.33899668075178374`, 0.9353216541598114],
              129 -> RGBColor[
              0.23768447069359533`, 0.36715182713778177`, 0.936847151032112], 
             279 -> RGBColor[
              0.9456496399519233, 0.8222259641328803, 0.2751266284196432], 26 -> 
             RGBColor[
              0.45511285367532656`, 0.5685201430708667, 0.9502472974560874], 
             40 -> RGBColor[
              0.3393121311221928, 0.4683168464796233, 0.9428416468465376], 
             146 -> RGBColor[
              0.5353312372592116, 0.6336450406612625, 0.9565623824614321], 
             386 -> RGBColor[
              0.3393631406607411, 0.4683610283780999, 0.942844897129228], 192 -> 
             RGBColor[
              0.34448974411411554`, 0.4728014346188312, 0.9431715597679996], 
             300 -> RGBColor[
              0.8899967779325137, 0.5933828851443484, 0.2299229538922278], 
             221 -> RGBColor[
              0.9218589159168126, 0.9405292926311409, 0.9924089204249567], 62 -> 
             RGBColor[
              0.1790682590797859, 0.30554247224919795`, 0.9335090444956198], 
             286 -> RGBColor[
              0.726249879738111, 0.7860711928457129, 0.9733494588874512], 152 -> 
             RGBColor[
              0.18361616608284723`, 0.3103226108633739, 0.9337680410714186], 
             64 -> RGBColor[
              0.3989602722595878, 0.5199810683300905, 0.9466423736550322], 
             307 -> RGBColor[
              0.9852399747517544, 0.9881643644915732, 0.8942753462917085], 37 -> 
             RGBColor[
              0.24979952597607638`, 0.3798855183785399, 0.9375370855078312], 
             148 -> RGBColor[
              0.6238880244982119, 0.7055394299796848, 0.9635338971470865], 
             261 -> RGBColor[
              0.17944836957228805`, 0.3059419924772149, 0.9335306912258446], 
             387 -> RGBColor[
              0.2935687509337651, 0.4258897489382169, 0.9400296781184059], 15 -> 
             RGBColor[
              0.3038609163605336, 0.43670746736272875`, 0.940615801713566], 
             136 -> 
             RGBColor[
              0.6185821135656369, 0.7012318524560568, 0.9631161964022821], 
             198 -> RGBColor[
              0.8264896291158393, 0.8644844120663722, 0.9833125127127125], 63 -> 
             RGBColor[
              0.9585610528033711, 0.8718788421575785, 0.2935179445399928], 
             310 -> RGBColor[
              0.18257815057035692`, 0.3092315907457619, 0.9337089276235886], 
             171 -> RGBColor[
              0.2732125866431092, 0.40449412961337683`, 0.9388704246762993], 
             395 -> RGBColor[
              0.27306809856961783`, 0.40434226348706437`, 0.938862196294265], 
             311 -> RGBColor[
              0.519374038863881, 0.6206902681403376, 0.955306173350608], 353 -> 
             RGBColor[
              0.21037964845754836`, 0.3384527277419758, 0.9352921817996338], 
             59 -> RGBColor[
              0.3340181926444761, 0.4637315030513096, 0.9425043217679835], 
             397 -> RGBColor[
              0.2493495489754894, 0.37941256402073326`, 0.9375114599833291], 
             229 -> RGBColor[
              0.24689616138342244`, 0.3768338981077132, 0.9373717431894225], 
             102 -> RGBColor[
              0.819297035403237, 0.14933104688991955`, 0.16611216893601113`], 
             299 -> RGBColor[
              0.21412870248835636`, 0.3423932212321097, 0.9355056848804599], 
             128 -> RGBColor[
              0.3262131529712761, 0.45697116997908427`, 0.9420069915417328], 
             12 -> RGBColor[
              0.218436984339963, 0.3469214986189947, 0.935751035158377], 222 -> 
             RGBColor[
              0.6049269005052089, 0.6901459353332633, 0.9620412080094716], 92 -> 
             RGBColor[
              0.28766384187052196`, 0.4196833151198899, 0.9396934022827843], 
             271 -> RGBColor[
              0.30678788301618565`, 0.43978389489822367`, 0.9407824881345462],
              361 -> RGBColor[
              0.35562652096447817`, 0.48244755097593534`, 0.9438811853410396],
              344 -> RGBColor[
              0.32062864936426844`, 0.45213415364000675`, 0.941651151910077], 
             132 -> RGBColor[
              0.7992223614262676, 0.8430778501519028, 0.9806226738955138], 80 -> 
             RGBColor[
              0.3344163982055418, 0.46407640869391137`, 0.9425296950742152], 
             324 -> RGBColor[
              0.2799576543907215, 0.4115836234781131, 0.9392545463060924], 
             244 -> RGBColor[
              0.2600361752617328, 0.3906448858188163, 0.9381200475408837], 
             150 -> 
             RGBColor[
              0.2706007772119499, 0.40174895230294594`, 0.9387216859930206], 
             125 -> RGBColor[
              0.277985958766929, 0.4095112463647842, 0.9391422611571797], 258 -> 
             RGBColor[
              0.2529332615169164, 0.38317927312227185`, 0.9377155471109357], 
             133 -> RGBColor[
              0.29725822306554583`, 0.42976761807476255`, 0.9402397880982258],
              255 -> RGBColor[
              0.26047497796174324`, 0.3911060952782254, 0.938145036705499], 
             326 -> RGBColor[
              0.3393902356747875, 0.4683844967174319, 0.9428466235995638], 
             176 -> RGBColor[
              0.21582348781243682`, 0.34417454806331416`, 0.935602200397456], 
             230 -> RGBColor[
              0.9688572327835747, 0.9066102748888301, 0.333516659492644], 274 -> 
             RGBColor[
              0.2307279730478894, 0.35984010704471925`, 0.9364509887824051], 
             87 -> RGBColor[
              0.29013871681338543`, 0.4222845656009737, 0.9398343427495309], 
             130 -> RGBColor[
              0.4104055903111328, 0.5298944275679272, 0.9473716592005793], 35 -> 
             RGBColor[
              0.28104105066772134`, 0.4127223416565313, 0.9393162441213263], 
             379 -> RGBColor[
              0.22095736038557218`, 0.3495705736440009, 0.9358945668456122], 
             31 -> RGBColor[
              0.183217413291963, 0.30990349639776743`, 0.9337453326898797], 
             18 -> RGBColor[
              0.9452065658445834, 0.95865572703968, 0.9776351709954327], 24 -> 
             RGBColor[
              0.9021530244270525, 0.6485815613125467, 0.24006642394413927`], 
             151 -> RGBColor[
              0.3158355177641727, 0.44798258395780277`, 0.9413457378029186], 
             137 -> RGBColor[
              0.22155609394318862`, 0.3501998805749559, 0.9359286638359716], 
             330 -> RGBColor[
              0.22477195032544567`, 0.3535799495297792, 0.936111802099508], 
             296 -> RGBColor[
              0.30152154075751214`, 0.43424863527897317`, 0.94048257773377], 
             266 -> RGBColor[
              0.2549979314676595, 0.3853493721481386, 0.937833127010225], 302 -> 
             RGBColor[
              0.9872770340850194, 0.9687445898536212, 0.4050741092611545], 
             283 -> RGBColor[
              0.9089152991886196, 0.6765865439997854, 0.2455693155756892], 
             388 -> RGBColor[
              0.22336510960731928`, 0.352101270736175, 0.9360316846018449], 
             284 -> 
             RGBColor[
              0.24399808998490613`, 0.37378784131953313`, 0.9372067023105894],
              318 -> RGBColor[
              0.2238174684207968, 0.35257672853034516`, 0.9360574457670676], 
             238 -> RGBColor[
              0.22922310747734106`, 0.35825839791608494`, 0.9363652889144115],
              72 -> RGBColor[
              0.22772650909910638`, 0.3566853781307425, 0.9362800598507899], 
             288 -> RGBColor[
              0.245025991273468, 0.37486823074651754`, 0.9372652397683294], 
             382 -> RGBColor[
              0.898780922280212, 0.63326963303821, 0.23725265925502825`], 389 -> 
             RGBColor[
              0.17908812663026416`, 0.30556335430442605`, 0.933510175923228], 
             172 -> RGBColor[
              0.301424661402258, 0.4341468089340951, 0.9404770605978084], 243 -> 
             RGBColor[
              0.2883719521470624, 0.4204275839173185, 0.939733728115478], 88 -> 
             RGBColor[
              0.9903137669558371, 0.9902625079584733, 0.8101894789167451], 
             273 -> RGBColor[
              0.2754373969927425, 0.40683254635196486`, 0.938997124334399], 
             202 -> RGBColor[
              0.8563396258514921, 0.4340566292418462, 0.20158419538288244`], 
             393 -> RGBColor[
              0.22281999879048459`, 0.3515283247056597, 0.9360006413472455], 
             98 -> RGBColor[
              0.9775701021325132, 0.9360008290818089, 0.3673645116259542], 30 -> 
             RGBColor[
              0.17892703208317115`, 0.3053940337214471, 0.9335010018270892], 
             116 -> RGBColor[
              0.4162213411164948, 0.534931738607397, 0.9477422336992305], 373 -> 
             RGBColor[
              0.2503218011924054, 0.380434462745063, 0.9375668283087641], 240 -> 
             RGBColor[
              0.23920651037948798`, 0.3687515873505448, 0.9369338289405676], 
             317 -> RGBColor[
              0.9906270631619555, 0.9903920639910485, 0.8049973499967711], 
             391 -> RGBColor[
              0.8203907902431329, 0.1577381258757864, 0.16715954980591485`], 
             73 -> RGBColor[
              0.24311597663730303`, 0.3728606842619857, 0.9371564672604132], 
             303 -> RGBColor[
              0.28961174034798287`, 0.421730679923598, 0.9398043322194181], 
             29 -> RGBColor[
              0.2404292095299187, 0.3700367216812511, 0.9370034598483634], 
             360 -> RGBColor[
              0.3103917228488082, 0.4432674424152022, 0.9409988640046705], 
             320 -> 
             RGBColor[
              0.7098940201909748, 0.7732938710583535, 0.9717192596619902], 75 -> 
             RGBColor[
              0.24417812249459925`, 0.373977066901941, 0.9372169548956822], 
             200 -> RGBColor[
              0.27065965459454444`, 0.40181083616509444`, 0.9387250389728581],
              301 -> RGBColor[
              0.2568179059531509, 0.3872622807254372, 0.9379367718647629], 
             156 -> RGBColor[
              0.18595953915049845`, 0.3127856445359093, 0.9339014927009116], 
             25 -> RGBColor[
              0.8487111149297029, 0.3754205514621725, 0.19427912470900624`], 
             38 -> RGBColor[
              0.9657912116144293, 0.896267865549297, 0.32160574622002847`], 
             365 -> RGBColor[
              0.25624071750281635`, 0.38665561906827417`, 0.93790390183639], 
             380 -> RGBColor[
              0.26549066491796636`, 0.3963779002821365, 0.9384306726576119], 
             370 -> RGBColor[
              0.8312166238387177, 0.8682535893475418, 0.9837633776892186], 3 -> 
             RGBColor[
              0.370079657849583, 0.49496613171003123`, 0.9448021264429514], 
             57 -> RGBColor[
              0.2732074233744939, 0.404488702690692, 0.9388701306357901], 227 -> 
             RGBColor[
              0.23492201148043795`, 0.36424830735472313`, 0.9366898330666149],
              39 -> RGBColor[
              0.27309206457306523`, 0.40436745327622, 0.9388635611227067], 
             109 -> RGBColor[
              0.9940964498066649, 0.9918267445278057, 0.7475006348091123], 
             256 -> RGBColor[
              0.22530836548640581`, 0.35414375587463387`, 0.9361423501493695],
              339 -> RGBColor[
              0.36576050208801136`, 0.49122509607643855`, 0.9445269136571035],
              287 -> RGBColor[
              0.260213393629744, 0.3908311535598896, 0.9381301398647709], 239 -> 
             RGBColor[
              0.32451491921663345`, 0.4555002452565231, 0.9418987815885761], 
             285 -> RGBColor[
              0.23871510677441427`, 0.3682350910048242, 0.9369058442322252], 
             345 -> RGBColor[
              0.20194739446585683`, 0.3295898941609259, 0.9348119774092088], 
             366 -> RGBColor[
              0.9012804456996433, 0.6446193851073215, 0.2393383228651273], 
             216 -> RGBColor[
              0.6591015742674116, 0.7336144262659793, 0.9666567433347234], 21 -> 
             RGBColor[
              0.31291714185714126`, 0.44545483342897024`, 0.9411597814707411],
              355 -> 
             RGBColor[
              0.23092116646773903`, 0.3600431655781515, 0.9364619908618614], 
             175 -> RGBColor[
              0.17893214148115075`, 0.3053994040226782, 0.9335012927997455], 
             7 -> RGBColor[
              0.38940499419392427`, 0.5117047667318526, 0.9460335197860889], 
             13 -> RGBColor[
              0.9637801291888717, 0.9725078601704316, 0.9461949730147088], 
             294 -> RGBColor[
              0.21275955169572475`, 0.34095415693987974`, 0.9354277137682966],
              193 -> RGBColor[
              0.8223396115770147, 0.8611753007301386, 0.9829166803350949], 60 -> 
             RGBColor[
              0.35752834255750565`, 0.4840948132514831, 0.9440023677312325], 
             65 -> RGBColor[
              0.5153321861178936, 0.6174089099977538, 0.9549879838966494], 69 -> 
             RGBColor[
              0.48821862164434726`, 0.5953968969059689, 0.9528535047810326], 
             217 -> RGBColor[
              0.8228256695060855, 0.17645367486173685`, 0.16949119293792111`],
              214 -> RGBColor[
              0.9837730937067766, 0.9874185803724101, 0.9123520990861677], 
             170 -> RGBColor[
              0.44496963537099143`, 0.5598320661593594, 0.9495740495880086], 
             359 -> RGBColor[
              0.2455681205459235, 0.37543804298484945`, 0.9372961132283874], 
             74 -> RGBColor[
              0.8246734764068878, 0.8630362611944062, 0.983139286446034], 246 -> 
             RGBColor[
              0.4438028563584466, 0.5588214608227114, 0.9494997034610714], 
             264 -> RGBColor[
              0.19003101446562676`, 0.31706502323855396`, 0.9341333571969002],
              278 -> RGBColor[
              0.2524156236360728, 0.382635202889368, 0.9376860683993983], 45 -> 
             RGBColor[
              0.2954990939280613, 0.427918661816037, 0.9401396082962444], 306 -> 
             RGBColor[
              0.9703761157708419, 0.9117338238555674, 0.33941723308119276`], 
             237 -> RGBColor[
              0.5784190314529432, 0.6686256530707418, 0.9599544114561535], 
             228 -> RGBColor[
              0.36785717736282086`, 0.49304113081751505`, 0.9446605119515972],
              180 -> RGBColor[
              0.36627002209779275`, 0.4916664166996908, 0.9445593798215759], 
             383 -> RGBColor[
              0.28023632613366145`, 0.41187652514875206`, 0.939270416249595], 
             53 -> RGBColor[
              0.28924396052189333`, 0.4213441200077901, 0.9397833877024038], 
             304 -> 
             RGBColor[
              0.21909843402136348`, 0.34761672417247863`, 0.9357887037392056],
              48 -> RGBColor[
              0.4254428949511675, 0.5429189850502182, 0.948329822955276], 5 -> 
             RGBColor[
              0.8414430264446411, 0.8764078451972013, 0.9847387810989889], 
             101 -> RGBColor[
              0.2608418322510304, 0.39149168239617155`, 0.9381659285145616], 
             333 -> RGBColor[
              0.19556045555100107`, 0.3228768164060961, 0.9344482506866372], 
             267 -> RGBColor[
              0.5711989452526345, 0.6627640618321545, 0.9593860198224179], 
             120 -> RGBColor[
              0.5663783145126094, 0.6588504566304622, 0.9590065221120109], 
             147 -> RGBColor[
              0.28473783311028583`, 0.41660789439321116`, 0.9395267704125309],
              89 -> RGBColor[
              0.21858282554203126`, 0.3470747869692347, 0.9357593405990821], 
             43 -> RGBColor[
              0.2274352478585693, 0.35637924409990884`, 0.9362634729540237], 
             199 -> RGBColor[
              0.22580276459471169`, 0.35466340068417734`, 0.9361705054471896],
              268 -> RGBColor[0.817319, 0.134127, 0.164218], 169 -> 
             RGBColor[
              0.22069846856058375`, 0.34929846192124825`, 0.9358798233391753],
              20 -> RGBColor[
              0.4076589804310767, 0.5275154521384491, 0.9471966476477539], 4 -> 
             RGBColor[
              0.23219649750384544`, 0.36138361935775737`, 0.9365346190776845],
              167 -> RGBColor[
              0.2835494674254077, 0.415358846711668, 0.9394590947448065], 142 -> 
             RGBColor[
              0.8215839734950429, 0.16690945520620182`, 0.16830214343545163`],
              16 -> RGBColor[
              0.2418605106508593, 0.3715411099090923, 0.9370849703297808], 
             281 -> RGBColor[
              0.6319940482543123, 0.7121202652370958, 0.9641720330305101], 
             289 -> RGBColor[
              0.8977533081905217, 0.6286034774622947, 0.23639519286946437`], 
             398 -> RGBColor[
              0.9394254025446074, 0.954344144916344, 0.9874211724934188], 178 -> 
             RGBColor[
              0.24398844376792686`, 0.3737777025338824, 0.9372061529728027], 
             58 -> RGBColor[
              0.2988109928106687, 0.43139967752817476`, 0.9403282160380936], 
             186 -> RGBColor[
              0.24846767200989045`, 0.3784856554156597, 0.9374612383947583], 
             122 -> RGBColor[
              0.44608758599784554`, 0.5608003788025082, 0.9496452844133868], 
             249 -> RGBColor[
              0.2695692814994847, 0.4006647849085395, 0.938662943838157], 113 -> 
             RGBColor[
              0.7965156452550962, 0.8409633429071789, 0.9803528937232722], 52 -> 
             RGBColor[
              0.38664548537965426`, 0.5093146188938776, 0.9458576863245813], 
             187 -> RGBColor[
              0.8439338400416576, 0.8783939523481282, 0.9849763571234479], 
             259 -> RGBColor[
              0.2110206902246306, 0.3391265032835748, 0.9353286881799328], 42 -> 
             RGBColor[
              0.9322258626950144, 0.9487956145888052, 0.9933977290633442], 
             134 -> RGBColor[
              0.2343268669145523, 0.36362277268163234`, 0.9366559404640252], 
             313 -> RGBColor[
              0.2828083531870263, 0.41457988865777246`, 0.939416889385311], 
             248 -> RGBColor[
              0.21620788903044316`, 0.3445785781158837, 0.9356240914781508], 
             174 -> RGBColor[
              0.7286053839996127, 0.7879113306772935, 0.9735842335387989], 
             215 -> RGBColor[
              0.8192881970279116, 0.1492631112641677, 0.166103705297818], 399 -> 
             RGBColor[
              0.2348790166106703, 0.36420311702056507`, 0.9366873845723869], 
             83 -> RGBColor[
              0.35288166901045503`, 0.480070098173631, 0.9437062858017065], 
             95 -> RGBColor[
              0.2817785304161579, 0.4134974796310549, 0.9393582425019963], 
             166 -> RGBColor[
              0.8247691039330448, 0.19139176348574266`, 0.17135222793997262`],
              384 -> RGBColor[
              0.7484278388783107, 0.8033967830847693, 0.9755599505897345], 
             233 -> RGBColor[
              0.8174582326741875, 0.1351972033459516, 0.16435132936604271`], 
             295 -> RGBColor[
              0.24238734999627973`, 0.3720948514646729, 0.9371149730511135], 
             141 -> RGBColor[
              0.3600639473667127, 0.48629102669401497`, 0.9441639342275279], 
             319 -> RGBColor[
              0.24158367299712782`, 0.37125013598249945`, 0.9370692048349454],
              205 -> RGBColor[
              0.9952685123171101, 0.9923114224965074, 0.7280765258104895], 
             224 -> RGBColor[
              0.9756615083220127, 0.9295626939998534, 0.3599499850798584], 
             231 -> RGBColor[
              0.30868412390727973`, 0.44177696430338015`, 0.9408904762480571],
              332 -> 
             RGBColor[
              0.5272216074067284, 0.6270612778123552, 0.9559239626928917], 68 -> 
             RGBColor[
              0.2767246225454214, 0.4081855020226443, 0.9390704299253445], 10 -> 
             RGBColor[
              0.3619258765766598, 0.48790373619238797`, 0.9442825747103464], 
             250 -> RGBColor[
              0.9882272169582415, 0.9893996659125786, 0.8447690121952027], 
             282 -> RGBColor[
              0.6468617732853108, 0.7240526007128293, 0.965436794360271], 374 -> 
             RGBColor[
              0.2761037265699157, 0.40753290098530925`, 0.9390350708180728], 
             232 -> RGBColor[
              0.5255566438526651, 0.6257095853934133, 0.9557928906629534], 
             253 -> RGBColor[
              0.34171577858230273`, 0.47039876509873646`, 0.9429948051372339],
              55 -> RGBColor[
              0.4035326533159193, 0.5239414349865308, 0.9469337217327439], 
             325 -> RGBColor[
              0.21156771774634342`, 0.33970146389244305`, 0.9353598405880397],
              91 -> RGBColor[
              0.26262121251507564`, 0.39336192387290797`, 0.9382672615882417],
              105 -> RGBColor[
              0.417344109662346, 0.5359042242898253, 0.9478137755181469], 36 -> 
             RGBColor[
              0.5196772960404508, 0.620936465977857, 0.9553300468664151], 123 -> 
             RGBColor[
              0.9742961343763916, 0.9803506796209057, 0.9283941192456544], 94 -> 
             RGBColor[
              0.26012396818175015`, 0.3907371617441472, 0.9381250472178008], 
             312 -> RGBColor[
              0.46295717480753656`, 0.5748885163486347, 0.9508648311503101], 
             96 -> RGBColor[
              0.2869114883454893, 0.4188925438631119, 0.939650556862541], 2 -> 
             RGBColor[
              0.8184511944421836, 0.14282954261339104`, 0.16530219067646573`],
              262 -> RGBColor[
              0.9386428604207964, 0.9537605262817009, 0.9887458121893573], 
             272 -> RGBColor[
              0.6470169280819229, 0.7241738088191627, 0.9654522587403933], 97 -> 
             RGBColor[
              0.44228444757308333`, 0.5575062914502744, 0.9494029517959442], 
             372 -> RGBColor[
              0.2514775053864574, 0.3816491811288898, 0.9376326439529042], 
             356 -> RGBColor[
              0.5183784049780293, 0.6198819676990077, 0.9552277934039866], 
             346 -> RGBColor[
              0.3450320119322843, 0.4732711197477559, 0.9432061125938647], 
             341 -> 
             RGBColor[
              0.2215837127017966, 0.35022890964138337`, 0.935930236683416], 
             209 -> RGBColor[
              0.2520329891677718, 0.3822330298027571, 0.9376642779324855], 
             378 -> RGBColor[
              0.20852643568424656`, 0.3365048836167593, 0.9351866440737768], 
             66 -> RGBColor[
              0.9727828870163496, 0.9198524284034268, 0.3487670848893771], 
             139 -> RGBColor[
              0.2111706728502173, 0.3392841445325141, 0.9353372294685806], 56 -> 
             RGBColor[
              0.45093503134871465`, 0.5649989923257436, 0.9499541593447165], 
             335 -> RGBColor[
              0.28051817934621337`, 0.41217277074566994`, 0.9392864673730853],
              314 -> RGBColor[
              0.9258119809847409, 0.9436813594132142, 0.9927859673000785], 
             144 -> RGBColor[
              0.8784381059512442, 0.540897655273832, 0.22027811466207986`], 
             298 -> RGBColor[
              0.8234301328695646, 0.862044852807406, 0.9830206952294982], 204 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 207 -> 
             RGBColor[
              0.9398558182628138, 0.7992553918121872, 0.27046478349011155`], 
             334 -> RGBColor[
              0.26139903658851843`, 0.39207733948366696`, 0.9381976604772716],
              149 -> RGBColor[
              0.22021863489519794`, 0.34879412631571627`, 0.9358524975217819],
              219 -> RGBColor[
              0.4471878440862639, 0.5617533670581167, 0.9497153918858607], 
             400 -> RGBColor[
              0.38961090759033284`, 0.5118831185663134, 0.9460466404056259], 
             9 -> RGBColor[
              0.8256674379376745, 0.1982967522977973, 0.17221247359732916`], 
             11 -> RGBColor[
              0.9234626618564741, 0.7342619893565898, 0.25727446504873397`], 
             44 -> RGBColor[
              0.29795654320818293`, 0.4305015968207284, 0.940279556397277], 
             153 -> RGBColor[
              0.3174307607246093, 0.4493643032308905, 0.9414473852737397], 32 -> 
             RGBColor[
              0.21628540957162948`, 0.3446600571197567, 0.9356285061582901], 
             162 -> RGBColor[
              0.246083996032968, 0.37598026083012825`, 0.9373254915742051], 
             90 -> RGBColor[
              0.7058058015575851, 0.7701001235903371, 0.9713117842351892], 
             331 -> RGBColor[
              0.45209247002133757`, 0.5660015075294104, 0.9500279103134532], 
             8 -> RGBColor[
              0.3103199544645186, 0.44320528024791445`, 0.9409942909866859], 
             364 -> RGBColor[
              0.34952976604112324`, 0.4771668482931376, 0.9434927055084721], 
             342 -> RGBColor[
              0.6033581995623302, 0.6888723932386622, 0.9619177141249072], 
             163 -> RGBColor[
              0.2449732495734328, 0.3748127958757636, 0.9372622362065367], 49 -> 
             RGBColor[
              0.2557363986193865, 0.3861255479461254, 0.9378751816220516], 
             338 -> RGBColor[
              0.9942883740099587, 0.9901917344782997, 0.6197029429328111], 76 -> 
             RGBColor[
              0.8469444359628041, 0.36184108275892934`, 0.19258735093512552`],
              369 -> RGBColor[
              0.25745394897088236`, 0.38793080226452953`, 0.9379729935736814],
              82 -> RGBColor[
              0.37921715493462604`, 0.5028805724211383, 0.9453843596772389], 
             67 -> RGBColor[
              0.2129458677257866, 0.3411499869005934, 0.9354383241905787], 
             211 -> RGBColor[
              0.2626771974737526, 0.39342076761412886`, 
               0.9382704498488161]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9l3k0VX/Yxa95Hq55dufJNVwqktwdKpWiSIU0EZFIxkiFhGRKk6SkQSmp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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 7}], {
             RGBColor[
             0.37469401379728373`, 0.4989628549076562, 0.945096149123624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 35}], {
             RGBColor[
             0.32051204203418227`, 0.44947164236999554`, 0.9417375112912428]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 41}], {
             RGBColor[
             0.3504016747423545, 0.4779220517867386, 0.943548262759916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 57}], {
             RGBColor[
             0.31659522838756854`, 0.44535482288707584`, 0.9415144545484747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 92}], {
             RGBColor[
             0.3238234376355826, 0.4529521291016748, 0.9419260903719718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 96}], {
             RGBColor[
             0.32344726087306624`, 0.45255674347328584`, 0.9419046676618501]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 114}], {
             RGBColor[
             0.3444304570913155, 0.4727500831795342, 0.9431677820513322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 153}], {
             RGBColor[
             0.33870689706262624`, 0.4677926231571751, 0.9428030818674495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 154}], {
             RGBColor[
             0.39507053133992803`, 0.5166119702495444, 0.9463945228031945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 161}], {
             RGBColor[
             0.3957098398241182, 0.5171657071259712, 0.9464352589744887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 188}], {
             RGBColor[
             0.3135344759290187, 0.4421377779902256, 0.9413401492239378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 203}], {
             RGBColor[
             0.32569030455946724`, 0.45491432460487713`, 0.9420324056815049]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 222}], {
             RGBColor[
             0.48245496695292606`, 0.5881834392083616, 0.9530999932353155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 312}], {
             RGBColor[
             0.4114701041040899, 0.5305547297160472, 0.9475118048057347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 327}], {
             RGBColor[
             0.3392875835527789, 0.4682955846087937, 0.9428400826971212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 337}], {
             RGBColor[
             0.3223631828098259, 0.4514173086943011, 0.9418429310198984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 356}], {
             RGBColor[
             0.43918071918933627`, 0.5530514553912338, 0.949693285932573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 361}], {
             RGBColor[
             0.35780477718256065`, 0.4843342470296975, 0.9440199819010995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[
             0.8956170407292666, 0.531340985508409, 0.2570346377829214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 98}], {
             RGBColor[
             0.8980106482873484, 0.5394151858476, 0.26633335115120993`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 106}], {
             RGBColor[
             0.8834730056375308, 0.5519688209280622, 0.5686856052309635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 107}], {
             RGBColor[
             0.828834437069773, 0.222639695414975, 0.17524519554284063`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 197}], {
             RGBColor[
             0.9036013141673853, 0.5662229928500411, 0.5006917858198119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 215}], {
             RGBColor[
             0.8188696957350476, 0.14604632693877936`, 0.16570294798714186`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 283}], {
             RGBColor[
             0.8636832468154017, 0.4097080433065882, 0.20543575312607748`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 352}], {
             RGBColor[
             0.9063026650036, 0.5663670773157738, 0.3851970536504771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 52}], {
             RGBColor[
             0.3783625716146186, 0.5021403753019544, 0.9453299063837663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 86}], {
             RGBColor[
             0.33530800642617503`, 0.4640896371481913, 0.9426142996527203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 117}], {
             RGBColor[
             0.35979838664313185`, 0.4860610113427193, 0.9441470129330474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 174}], {
             RGBColor[
             0.5493425209245979, 0.6414387311936623, 0.9591931799908751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 232}], {
             RGBColor[
             0.4478181508511241, 0.5603378585517222, 0.9502975085529524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 309}], {
             RGBColor[
             0.32043505349243634`, 0.4484572206151509, 0.9417673069857059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 371}], {
             RGBColor[
             0.3210626317693298, 0.4491168451749269, 0.9418030466401561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 386}], {
             RGBColor[
             0.35472139925516205`, 0.48166358004406556`, 0.9438235117860897]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 16}], {
             RGBColor[
             0.23702850407735238`, 0.36646236463342485`, 0.9368097947037326]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 73}], {
             RGBColor[
             0.23765623707057423`, 0.3671221518098715, 0.9368455431690489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 115}], {
             RGBColor[
             0.23540129852856206`, 0.36475206843085556`, 0.936717127754964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 188}], {
             RGBColor[
             0.24964120798061978`, 0.37971911612737436`, 0.9375280695322004]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 195}], {
             RGBColor[
             0.2389456018045329, 0.3684773558957079, 0.9369189705832036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 206}], {
             RGBColor[
             0.23187928370438585`, 0.3610502075420088, 0.9365165542210812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 208}], {
             RGBColor[
             0.23264160776787357`, 0.36185145846687167`, 0.9365599674487393]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 258}], {
             RGBColor[
             0.24256487951038092`, 0.3722814462400146, 0.9371250830943101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 278}], {
             RGBColor[
             0.24230606056995913`, 0.37200941112356267`, 0.9371103437385414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 284}], {
             RGBColor[
             0.23809729374437577`, 0.3675857303386453, 0.936870660694137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 369}], {
             RGBColor[
             0.2448252232373639, 0.37465721081114345`, 0.937253806325683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 392}], {
             RGBColor[
             0.24007285485442642`, 0.3696621703231174, 0.9369831659767736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 99}], {
             RGBColor[
             0.9097853137766493, 0.92980801321679, 0.9533236132867424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 174}], {
             RGBColor[
             0.7850242052221269, 0.8321595879372474, 0.979161507318894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 193}], {
             RGBColor[
             0.8318913190108279, 0.8687915729636699, 0.983827730717042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 223}], {
             RGBColor[
             0.6477551093793219, 0.7220395366342189, 0.9674518801311646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 235}], {
             RGBColor[
             0.7907683520113988, 0.8366469590661592, 0.9797340301887447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 260}], {
             RGBColor[
             0.8251985302055844, 0.863544075950503, 0.9831657085828327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 267}], {
             RGBColor[
             0.7063209858486378, 0.7695859535146778, 0.9720624004607035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 272}], {
             RGBColor[
             0.744229977263282, 0.800290827008182, 0.9750955199196911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 275}], {
             RGBColor[
             0.916771833602923, 0.9337046356973782, 0.882657568389807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 291}], {
             RGBColor[
             0.7689673032381015, 0.8196158140703518, 0.9775611053894065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 321}], {
             RGBColor[
             0.8296147450427847, 0.8669940565457998, 0.9836058756059307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 338}], {
             RGBColor[
             0.9178657002272999, 0.9332997898377504, 0.8022208620159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 384}], {
             RGBColor[
             0.7949354326614759, 0.8399023141409853, 0.9801493658443617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 398}], {
             RGBColor[
             0.8904342144946242, 0.9153759950567726, 0.9860799767962038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 13}], {
             RGBColor[
             0.978563836078469, 0.9803436260913665, 0.7317471315868381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 18}], {
             RGBColor[
             0.9692770544063248, 0.9734175595259907, 0.7474672305772001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 74}], {
             RGBColor[
             0.909010509687477, 0.9256078266033538, 0.7502192883025007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 102}], {
             RGBColor[
             0.9063222891856516, 0.5687552194511105, 0.3417057295474893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 132}], {
             RGBColor[
             0.896284952197167, 0.9156286210821021, 0.7489609820272407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 160}], {
             RGBColor[
             0.9114125623801264, 0.6078812897957802, 0.3465801809071596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 166}], {
             RGBColor[
             0.9090583234505556, 0.5897855777490221, 0.34432575904947005`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 185}], {
             RGBColor[
             0.9085190133388343, 0.5856402039031354, 0.34380931507742224`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 198}], {
             RGBColor[
             0.9099185860419527, 0.9263319020393368, 0.75030590143584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 213}], {
             RGBColor[
             0.9521578283629528, 0.8364523308595698, 0.38226017426140096`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 216}], {
             RGBColor[
             0.8262245586177389, 0.8608969091391403, 0.7419780167468455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 224}], {
             RGBColor[
             0.9845045256450395, 0.9588710430060774, 0.43862463761941295`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 247}], {
             RGBColor[
             0.9501775412917424, 0.8286011525137683, 0.3806667888005933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 289}], {
             RGBColor[
             0.9455504255792939, 0.808391434737298, 0.3768472415142159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 302}], {
             RGBColor[
             0.9903122885265428, 0.9784619909329613, 0.461186699710061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 323}], {
             RGBColor[
             0.9117788938600264, 0.9278152609967583, 0.7504833392562442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 340}], {
             RGBColor[
             0.9935628356137232, 0.988639881211936, 0.5407325660065214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 40}], {
             RGBColor[
             0.36435856265805855`, 0.4900108066057379, 0.9444375833163132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 41}], {
             RGBColor[
             0.36511265513899505`, 0.490663963610935, 0.9444856334223808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 80}], {
             RGBColor[
             0.36191069619973304`, 0.48789058771288196`, 0.9442816074301521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 96}], {
             RGBColor[
             0.3381582412697068, 0.46529865529748227`, 0.9428420383243149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 114}], {
             RGBColor[
             0.359141437487956, 0.48549199500373064`, 0.9441051527137969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 153}], {
             RGBColor[
             0.3534178774592668, 0.48053453498137155`, 0.9437404525299142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 154}], {
             RGBColor[
             0.40978151173656857`, 0.5293538820737408, 0.9473318934656592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 192}], {
             RGBColor[
             0.36694736915401993`, 0.4922531006753419, 0.9446025397770442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 203}], {
             RGBColor[
             0.3404012849561078, 0.4676562364290735, 0.9429697763439697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 222}], {
             RGBColor[
             0.4971659473495666, 0.600925351032558, 0.9540373638977802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 228}], {
             RGBColor[
             0.37863108577837257`, 0.5023729487746839, 0.9453470158688431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 312}], {
             RGBColor[
             0.42618108450073044`, 0.5432966415402436, 0.9484491754681994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 332}], {
             RGBColor[
             0.45831330080032634`, 0.5693830222721039, 0.9509787412394903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 356}], {
             RGBColor[
             0.4538916995859768, 0.5657933672154302, 0.9506306565950378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 361}], {
             RGBColor[
             0.3725157575792012, 0.497076158853894, 0.9449573525635642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 385}], {
             RGBColor[
             0.4824130197414953, 0.5889482597885108, 0.9528759593947184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 17}], {
             RGBColor[
             0.42291827954092154`, 0.5385004052405986, 0.9487856331227857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.3116185481608299, 0.44433005683844234`, 0.9410770362287135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 36}], {
             RGBColor[
             0.41499862525248465`, 0.5320708731128857, 0.9481621689265505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 60}], {
             RGBColor[
             0.33392414851101215`, 0.4636500467496988, 0.9424983293589592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 64}], {
             RGBColor[
             0.3546401133620532, 0.4815931742890025, 0.9438183323208591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.34476855469957235`, 0.4730429263345264, 0.9431893253319623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 157}], {
             RGBColor[
             0.38978189814954545`, 0.5115987980501094, 0.9461770157970921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 171}], {
             RGBColor[
             0.2917662705538139, 0.42384970493064567`, 0.9399323578314926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 182}], {
             RGBColor[
             0.29920713316336395`, 0.4316705233112208, 0.9403561039493367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 210}], {
             RGBColor[
             0.30512183219392025`, 0.43788724700591375`, 0.9406929373091137]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 253}], {
             RGBColor[
             0.3260178665234107, 0.4568020226733255, 0.9419945480619598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 61}], {
             RGBColor[
             0.9095066708030527, 0.5932363190069687, 0.34466666805378354`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 131}], {
             RGBColor[
             0.8740668087143025, 0.4643040105665355, 0.21434257277214977`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 142}], {
             RGBColor[
             0.8236257057163587, 0.18260310375199956`, 0.1702573085163904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 202}], {
             RGBColor[
             0.8410035318945833, 0.31617669076982174`, 0.1868983344901058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 214}], {
             RGBColor[
             0.9047202658222255, 0.5928576663351037, 0.5422822863417485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 215}], {
             RGBColor[
             0.822477817482793, 0.1737799317809825, 0.1691580894475736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 217}], {
             RGBColor[
             0.8242465537218799, 0.18737521357976708`, 0.17085183326762515`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 269}], {
             RGBColor[
             0.909363183463878, 0.5929294140972693, 0.329048956685827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 279}], {
             RGBColor[
             0.8856585389447988, 0.5102613582153388, 0.22366955100848618`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 300}], {
             RGBColor[
             0.8578321079350941, 0.3958398187210729, 0.2010677137447785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 306}], {
             RGBColor[
             0.8980217768542582, 0.5550152880766823, 0.25581485333926096`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 363}], {
             RGBColor[
             0.8440899658094313, 0.333439960887275, 0.18960093350439794`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 39}], {
             RGBColor[
             0.3175089705748625, 0.446135594734304, 0.9415730679165266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 177}], {
             RGBColor[
             0.34191718866131093`, 0.47057321638600846`, 0.9430076388093683]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.3312363099818102, 0.46056389881459425`, 0.9423548195879734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 200}], {
             RGBColor[
             0.31629276558560215`, 0.4448572861787412, 0.9415038068416022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 216}], {
             RGBColor[
             0.5105137254220357, 0.6107590812291837, 0.9554696590225349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 219}], {
             RGBColor[
             0.4045568603314619, 0.5248285516252523, 0.9469989832981036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 241}], {
             RGBColor[
             0.32644391245681637`, 0.4555267851602728, 0.9420818996386419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 296}], {
             RGBColor[
             0.331723708667086, 0.46107618573568054`, 0.9423825762220581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 311}], {
             RGBColor[
             0.4406499577202704, 0.5542970021663628, 0.9497943740304772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 339}], {
             RGBColor[
             0.3638431893323356, 0.48956441613441326`, 0.9444047441837249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 360}], {
             RGBColor[
             0.336158799712734, 0.4655855893037951, 0.9426407193575084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 374}], {
             RGBColor[
             0.31901480157328777`, 0.4477183185888486, 0.9416588227642095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 14}], {
             RGBColor[
             0.9589098698169762, 0.8623003371232989, 0.4422276945427869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 25}], {
             RGBColor[
             0.8860868883930885, 0.5548412704093811, 0.2257767948788701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 38}], {
             RGBColor[
             0.9446269367354516, 0.8152649274529434, 0.2894401056343812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 78}], {
             RGBColor[
             0.8826533057204708, 0.5284492493821207, 0.22248879223389445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 102}], {
             RGBColor[
             0.8713798486298555, 0.4417965181232547, 0.21169331699237254`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 144}], {
             RGBColor[
             0.9009503839038591, 0.6375798223152109, 0.23877628985540691`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 205}], {
             RGBColor[
             0.9593655870867921, 0.8632867059265485, 0.49267549542961175`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 207}], {
             RGBColor[
             0.931659240059644, 0.7667586905843885, 0.26386962426942273`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 213}], {
             RGBColor[
             0.9172153878071567, 0.709493629531714, 0.2522477617062842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 221}], {
             RGBColor[
             0.9226607888866434, 0.8373956409938654, 0.6248416927368453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 230}], {
             RGBColor[
             0.9461599473200244, 0.8204361321227099, 0.29539556227068897`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 250}], {
             RGBColor[
             0.9558449394073578, 0.8618308276345842, 0.5510217386219683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 289}], {
             RGBColor[
             0.9106079850234978, 0.6814327334094423, 0.24683482895909917`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 358}], {
             RGBColor[
             0.9460196672175634, 0.8199629343977746, 0.2948506005623025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 391}], {
             RGBColor[
             0.8719267260498035, 0.4460000576161881, 0.2122170074273244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 118}], {
             RGBColor[
             0.21224930323971947`, 0.34041785346099757`, 0.9353986558735721]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 126}], {
             RGBColor[
             0.2152393660615204, 0.3435605990676429, 0.935568935527872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 149}], {
             RGBColor[
             0.21932780961758047`, 0.3478578124673555, 0.9358017663400795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 199}], {
             RGBColor[
             0.22211987446733733`, 0.350792449651586, 0.9359607703027832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 212}], {
             RGBColor[
             0.2146670795751315, 0.34295908968538924`, 0.9355363446590942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 238}], {
             RGBColor[
             0.22383004590865202`, 0.3525899482675398, 0.9360581620363942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 259}], {
             RGBColor[
             0.2147288372822968, 0.3430240009512847, 0.9355398616691548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 274}], {
             RGBColor[
             0.2245824786939262, 0.35338080283185697`, 0.936101011970391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 299}], {
             RGBColor[
             0.21628284341415968`, 0.3446573599255522, 0.9356283600194184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 318}], {
             RGBColor[
             0.2211272263803799, 0.3497491135746699, 0.9359042404627222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 336}], {
             RGBColor[
             0.21472177259901426`, 0.343016575521228, 0.9355394593458932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 367}], {
             RGBColor[
             0.21887583976336028`, 0.3473827634940262, 0.9357760273255111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 18}], {
             RGBColor[
             0.9544933475167275, 0.9655817936050558, 0.9619150720050708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 69}], {
             RGBColor[
             0.7259993754166094, 0.7839523785382002, 0.9495242388978706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 74}], {
             RGBColor[
             0.8942268027978797, 0.9177720606824189, 0.9646671297303714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 88}], {
             RGBColor[
             0.9770469480723544, 0.9813851840644524, 0.8781922259657269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 132}], {
             RGBColor[
             0.8815012453075697, 0.9077928551611671, 0.9634088234551113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[
             0.8178525622986523, 0.8580700202466935, 0.9570649175635426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 191}], {
             RGBColor[
             0.8213167457883995, 0.8607762667176537, 0.9574101949991654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 198}], {
             RGBColor[
             0.8951348791523555, 0.9184961361184019, 0.9647537428637106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 216}], {
             RGBColor[
             0.8114408517281416, 0.8530611432182054, 0.956425858174716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 224}], {
             RGBColor[
             0.9697208187554422, 0.9510352770851425, 0.6530724790472836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 302}], {
             RGBColor[
             0.9755285816369456, 0.9706262250120263, 0.6756345411379316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 323}], {
             RGBColor[
             0.8969951869704291, 0.9199794950758233, 0.9649311806841149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 340}], {
             RGBColor[
             0.9787791287241259, 0.9808041152910011, 0.7551804074343922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 357}], {
             RGBColor[
             0.8197351159980406, 0.8595406855045937, 0.9572525529228332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 38}], {
             RGBColor[
             0.9800741446959539, 0.9433032752196526, 0.4743933351284341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 102}], {
             RGBColor[
             0.9068270565903578, 0.5698348658899638, 0.39664654648642544`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 205}], {
             RGBColor[
             0.9948127950472943, 0.9913250536932577, 0.6776287249236647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 207}], {
             RGBColor[
             0.9671064480201461, 0.8947970383510977, 0.44882285376347564`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.9526625957676589, 0.8375319772984231, 0.4372009912003371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 224}], {
             RGBColor[
             0.9850092930497456, 0.9599506894449308, 0.4935654545583491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 230}], {
             RGBColor[
             0.9816071552805266, 0.9484744798894191, 0.4803487917647419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 247}], {
             RGBColor[
             0.9506823086964485, 0.8296807989526216, 0.43560760573952945`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 250}], {
             RGBColor[
             0.99129214736786, 0.9898691754012934, 0.7359749681160213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 289}], {
             RGBColor[
             0.9460551929840001, 0.8094710811761514, 0.43178805845315205`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 340}], {
             RGBColor[
             0.9940676030184292, 0.9897195276507893, 0.5956733829454577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 391}], {
             RGBColor[
             0.9073739340103057, 0.5740384053828973, 0.3971702369213773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 45}], {
             RGBColor[
             0.29968000514429743`, 0.4323130645893829, 0.9403777050049051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 100}], {
             RGBColor[
             0.34023750094859895`, 0.4686666959527124, 0.9429171480552854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 105}], {
             RGBColor[
             0.36060251301143975`, 0.486305845826277, 0.9442147886158565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.3163910437219365, 0.4480120932607672, 0.9413976728873965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 155}], {
             RGBColor[
             0.30420326810120896`, 0.4370673007485326, 0.9406352981387334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 170}], {
             RGBColor[
             0.3744152758657625, 0.49826976676104406`, 0.9450949256507872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 180}], {
             RGBColor[
             0.33506546922916314`, 0.4641869420312098, 0.9425875907675709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 183}], {
             RGBColor[
             0.281397272925088, 0.41309675383481925`, 0.9393365304518997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 239}], {
             RGBColor[
             0.3141879177885835, 0.4461038563096259, 0.9412572916510711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 271}], {
             RGBColor[
             0.3053243996883596, 0.43824568113047624`, 0.940699144924056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 273}], {
             RGBColor[
             0.28964915667663804`, 0.4217700068573468, 0.9398064630239824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 326}], {
             RGBColor[
             0.3216255760176605, 0.45254598204008034`, 0.9417312126565649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 335}], {
             RGBColor[
             0.2921895478533735, 0.4244401190541993, 0.9399511345433256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 394}], {
             RGBColor[
             0.33136443385417313`, 0.4609812912088401, 0.9423517640661736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 73}], {
             RGBColor[
             0.24248824364408117`, 0.372200897085539, 0.937120718795097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 85}], {
             RGBColor[
             0.2415839884274967, 0.3712504675198166, 0.9370692227982382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 96}], {
             RGBColor[
             0.2643859994981743, 0.3952168268861021, 0.9383677635961609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 110}], {
             RGBColor[
             0.2487192272457111, 0.3787500559180304, 0.9374755640932957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 115}], {
             RGBColor[
             0.240233305102069, 0.36983081370652304`, 0.936992303381012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 184}], {
             RGBColor[
             0.22981171473055614`, 0.35887706145906934`, 0.9363988092267157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 188}], {
             RGBColor[
             0.25447321455412675`, 0.38479786140304184`, 0.9378032451582485]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 203}], {
             RGBColor[
             0.2666290431845753, 0.3975744080176934, 0.9384955016158156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 206}], {
             RGBColor[
             0.23671129027789278`, 0.36612895281767627`, 0.9367917298471292]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 208}], {
             RGBColor[
             0.2374736143413805, 0.36693020374253915`, 0.9368351430747874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 258}], {
             RGBColor[
             0.24739688608388788`, 0.37736019151568206`, 0.9374002587203583]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 284}], {
             RGBColor[
             0.24292930031788273`, 0.3726644756143127, 0.9371458363201851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 325}], {
             RGBColor[
             0.22671411419860138`, 0.35562128690076766`, 0.9362224054589102]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 348}], {
             RGBColor[
             0.252407866634222, 0.38262704978860046`, 0.9376856266496183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 369}], {
             RGBColor[
             0.24965722981087085`, 0.3797359560868109, 0.9375289819517311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 392}], {
             RGBColor[
             0.24490486142793333`, 0.37474091559878486`, 0.9372583416028217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 36}], {
             RGBColor[
             0.5275969503288876, 0.6273659981055699, 0.9559535110626505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 64}], {
             RGBColor[
             0.46723843843845614`, 0.5768882992816866, 0.951609674456959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 82}], {
             RGBColor[
             0.4573668797759753, 0.5683380513272105, 0.9509806674680623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 122}], {
             RGBColor[
             0.490802095307585, 0.5972979545178956, 0.9531111298361363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 157}], {
             RGBColor[
             0.5023802232259484, 0.6068939230427937, 0.9539683579331921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 187}], {
             RGBColor[
             0.6897252223294911, 0.7560947412907055, 0.9707766661911668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 218}], {
             RGBColor[
             0.7227901892843811, 0.7824598484159166, 0.9739304322567687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 253}], {
             RGBColor[
             0.43861619159981363`, 0.5520971476660097, 0.9497858901980598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 262}], {
             RGBColor[
             0.7370797325190604, 0.7937780282574919, 0.9726613937241215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 298}], {
             RGBColor[
             0.6794733687434446, 0.7479201915203444, 0.969798835244192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 74}], {
             RGBColor[
             0.8849400211257357, 0.9108459941170431, 0.9803872287207334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 132}], {
             RGBColor[
             0.8722144636354254, 0.9008667885957915, 0.9791289224454733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 140}], {
             RGBColor[
             0.8085657806265083, 0.8511439536813179, 0.9727850165539047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 191}], {
             RGBColor[
             0.8120299641162554, 0.853850200152278, 0.9731302939895274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.8858480974802114, 0.9115700695530261, 0.9804738418540726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 216}], {
             RGBColor[
             0.8021540700559975, 0.8461350766528297, 0.9721459571650781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.960434037083298, 0.9441092105197667, 0.6687925780376456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 247}], {
             RGBColor[
             0.926107052730001, 0.8138393200274576, 0.6108347292188259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 302}], {
             RGBColor[
             0.9662417999648014, 0.9637001584466507, 0.6913546401282936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 311}], {
             RGBColor[
             0.7322903023542322, 0.7896729975900088, 0.9664706721730203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 323}], {
             RGBColor[
             0.8877084052982851, 0.9130534285104475, 0.9806512796744769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 340}], {
             RGBColor[
             0.9694923470519816, 0.9738780487256253, 0.770900506424754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 357}], {
             RGBColor[
             0.8104483343258964, 0.8526146189392179, 0.9729726519131952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 83}], {
             RGBColor[
             0.31363288900734776`, 0.44289778603368235`, 0.9413217134716801]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 108}], {
             RGBColor[
             0.3209765938651673, 0.4492585340761873, 0.9417896478514372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 125}], {
             RGBColor[
             0.27618503388558474`, 0.4076183601292589, 0.9390397011494167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 179}], {
             RGBColor[
             0.2720136332383074, 0.4032339535668936, 0.9388021460535885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 196}], {
             RGBColor[
             0.2861541125436652, 0.4180964938749955, 0.9396074254310642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 231}], {
             RGBColor[
             0.2915341164557601, 0.4237512190985569, 0.9399138086948555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 303}], {
             RGBColor[
             0.2819979246761117, 0.4137280769086658, 0.939370736680536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 313}], {
             RGBColor[
             0.27859623109563336`, 0.41015268127575305`, 0.9391770152634824]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 344}], {
             RGBColor[
             0.2975063791842545, 0.4289298137668702, 0.9402941465258654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 50}], {
             RGBColor[
             0.4309033063250306, 0.5476259924741631, 0.9486839796675377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 54}], {
             RGBColor[
             0.4298252331165606, 0.5467147461063611, 0.9486090616680254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 116}], {
             RGBColor[
             0.4119401607737857, 0.531223595372923, 0.9474694406734923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 121}], {
             RGBColor[
             0.48042756078829996`, 0.5878320132896839, 0.9525827103922078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 130}], {
             RGBColor[
             0.4090322853711047, 0.5287049398531881, 0.9472841534241666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 135}], {
             RGBColor[
             0.45546851492086315`, 0.5675691354622958, 0.9506178428735257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 147}], {
             RGBColor[
             0.34619840677068126`, 0.47206167326583015`, 0.9433617090301424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 158}], {
             RGBColor[
             0.4553874406509526, 0.5675033157176284, 0.9506114604100135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 172}], {
             RGBColor[
             0.3545418209166673, 0.4808311305362721, 0.9438368541227812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 181}], {
             RGBColor[
             0.4874856363228792, 0.5935620769713348, 0.9531383479528726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 265}], {
             RGBColor[
             0.49977683892029745`, 0.6035406289522859, 0.9541059564454999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 322}], {
             RGBColor[
             0.45803755349750475`, 0.5696547967126826, 0.9508200870009773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 328}], {
             RGBColor[
             0.3585480828066595, 0.484978061001665, 0.9440673446781876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 347}], {
             RGBColor[
             0.3438545327447645, 0.469598113054395, 0.9432282288718172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 362}], {
             RGBColor[
             0.406159003588231, 0.5262162475882044, 0.9471010704497052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 364}], {
             RGBColor[
             0.37859437323609996`, 0.5023411502157933, 0.945344676578113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 387}], {
             RGBColor[
             0.3506138656824209, 0.476702600538333, 0.94361316288308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.416297218948796, 0.5331956497034136, 0.948244914168578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 60}], {
             RGBColor[
             0.33522274220732345`, 0.4647748233402267, 0.9425810746009868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 64}], {
             RGBColor[
             0.3559387070583645, 0.4827179508795304, 0.9439010775628867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 82}], {
             RGBColor[
             0.34606714839588365`, 0.4741677029250543, 0.94327207057399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 122}], {
             RGBColor[
             0.37950236392749337`, 0.5031276061157393, 0.9454025329420639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 159}], {
             RGBColor[
             0.3221758681761928, 0.45347427680941704`, 0.9417497393246208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 182}], {
             RGBColor[
             0.30050572685967525`, 0.4327952999017487, 0.9404388491913643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 210}], {
             RGBColor[
             0.30642042589023155`, 0.43901202359644165`, 0.9407756825511414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 263}], {
             RGBColor[
             0.2875003760669833, 0.4191258516317633, 0.9396982137034129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 29}], {
             RGBColor[
             0.2663738031073146, 0.39730613451333674`, 0.9384809660710094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 45}], {
             RGBColor[
             0.2939087453063859, 0.4262471045807297, 0.94004904029495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 91}], {
             RGBColor[
             0.2774698045998931, 0.40896873560916513`, 0.9391128669409485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 97}], {
             RGBColor[
             0.36730142212889694`, 0.4910409193978484, 0.9446807120447999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 100}], {
             RGBColor[
             0.3344662411106874, 0.46260073594405915`, 0.9425884833453301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 141}], {
             RGBColor[
             0.32619117202571163`, 0.45543328701971864`, 0.9420612032605917]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 150}], {
             RGBColor[
             0.28145958694833023`, 0.41316224982418415`, 0.9393400791433381]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 189}], {
             RGBColor[
             0.29643257003583556`, 0.4288998043911114, 0.9401927683796281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 190}], {
             RGBColor[
             0.26671069132338054`, 0.3976602253883686, 0.938500151356533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 255}], {
             RGBColor[
             0.27639668732322686`, 0.40784082131182386`, 0.9390517544995772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 266}], {
             RGBColor[
             0.27365816407618504`, 0.40496245974678047`, 0.9388957996519403]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 273}], {
             RGBColor[
             0.28387789683872655`, 0.4157040468486936, 0.9394777983140272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 350}], {
             RGBColor[
             0.36253057369193453`, 0.4869086502715662, 0.9443767178010922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 365}], {
             RGBColor[
             0.27427955709376345`, 0.40561558320684826`, 0.9389311870650228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 394}], {
             RGBColor[
             0.32559317401626164`, 0.45491533120018696`, 0.9420230993562184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[
             0.2165666874460731, 0.34495569799984427`, 0.9356445245171263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 89}], {
             RGBColor[
             0.21600037669219402`, 0.3443604694913417, 0.9356122739574746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 163}], {
             RGBColor[
             0.22919558870789478`, 0.35822947394460614`, 0.9363637217612019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 164}], {
             RGBColor[
             0.22797821780387265`, 0.3569499399387055, 0.9362943942891566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 169}], {
             RGBColor[
             0.21705819820147026`, 0.34547230696734843`, 0.9356725153275212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 227}], {
             RGBColor[
             0.22416996966139735`, 0.3529472296840859, 0.936077520191241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 245}], {
             RGBColor[
             0.22165838805798918`, 0.35030739817543277`, 0.9359344893344789]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 292}], {
             RGBColor[
             0.21221830344661968`, 0.3403852707129492, 0.9353968904812151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 304}], {
             RGBColor[
             0.2162581809318601, 0.34463143809296365`, 0.9356269555275363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 353}], {
             RGBColor[
             0.21189878814995255`, 0.34004943987771225`, 0.9353786945577505]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 378}], {
             RGBColor[
             0.21097218176330165`, 0.339075517815104, 0.9353259256948219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 25}], {
             RGBColor[
             0.8754320696783777, 0.5120010563873596, 0.21717277432657275`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 76}], {
             RGBColor[
             0.8745487301949283, 0.505211322035738, 0.2163268874396324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 104}], {
             RGBColor[
             0.9180135558932775, 0.712060691693382, 0.25285908317008815`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 109}], {
             RGBColor[
             0.9481247371168586, 0.8202041529201762, 0.49378352937662584`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 138}], {
             RGBColor[
             0.8607479504188854, 0.399132481136813, 0.2031112451403423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 144}], {
             RGBColor[
             0.8902955651891483, 0.5947396082931894, 0.23017226930310958`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 207}], {
             RGBColor[
             0.9210044213449331, 0.723918476562367, 0.2552656037171254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 233}], {
             RGBColor[
             0.8598056285506199, 0.3918893823292492, 0.202208876655091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 242}], {
             RGBColor[
             0.9102499321760205, 0.681280510728698, 0.24661228929151274`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 317}], {
             RGBColor[
             0.946390043794504, 0.8194868126517976, 0.5225318869704552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 358}], {
             RGBColor[
             0.9353648485028525, 0.777122720375753, 0.28624658001000514`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 366}], {
             RGBColor[
             0.9017167350633479, 0.6466004732099342, 0.2397023734046333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 382}], {
             RGBColor[
             0.9004669733536322, 0.6409255971753784, 0.23865954159958375`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[
             0.8478277754462535, 0.3686308171105509, 0.1934332378220659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 104}], {
             RGBColor[
             0.8912926011446027, 0.575480186768195, 0.22996543355252164`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 109}], {
             RGBColor[
             0.9214037823681839, 0.6836236479949891, 0.47088987975905927`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 138}], {
             RGBColor[
             0.8340269956702107, 0.26255197621162585`, 0.18021759552277578`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 144}], {
             RGBColor[
             0.8635746104404736, 0.45815910336800225`, 0.20727861968554306`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 205}], {
             RGBColor[
             0.9219898136234065, 0.68386598697934, 0.46117782525974793`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 207}], {
             RGBColor[
             0.8942834665962583, 0.5873379716371798, 0.2323719540995589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 233}], {
             RGBColor[
             0.8330846738019452, 0.25530887740406205`, 0.17931522703752448`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 317}], {
             RGBColor[
             0.9196690890458292, 0.6829063077266104, 0.4996382373528887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 358}], {
             RGBColor[
             0.9086438937541778, 0.640542215450566, 0.2633529303924386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 366}], {
             RGBColor[
             0.8749957803146731, 0.510019968284747, 0.21680872378706678`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 382}], {
             RGBColor[
             0.8737460186049575, 0.5043450922501913, 0.21576589198201723`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 391}], {
             RGBColor[
             0.8345509525864179, 0.2665793386689794, 0.18071933725746053`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 30}], {
             RGBColor[
             0.31701994287924884`, 0.4369570883961569, 0.9418741496415883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 62}], {
             RGBColor[
             0.31709055637755623`, 0.43703130766003234`, 0.9418781709758536]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 77}], {
             RGBColor[
             0.6422389788407158, 0.7176486903810251, 0.9669170377654001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 106}], {
             RGBColor[
             0.7018038352541023, 0.7648141211568, 0.9611581586207743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 111}], {
             RGBColor[
             0.6645955027358419, 0.5448101324102603, 0.5834436797495368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 160}], {
             RGBColor[
             0.6422952177337565, 0.39805166532506286`, 0.5630541845557195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.6399409788041857, 0.37995595327830467`, 0.56079976269803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 173}], {
             RGBColor[
             0.34074023236907375`, 0.46188861660318076`, 0.9432249850370102]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 185}], {
             RGBColor[
             0.6394016686924645, 0.37581057943241813`, 0.5602833187259821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 197}], {
             RGBColor[
             0.7219321437839568, 0.7790682930787789, 0.8931643392096228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 204}], {
             RGBColor[
             0.3170199268376633, 0.4369570715354334, 0.9418741487280438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 345}], {
             RGBColor[
             0.3285301240705917, 0.4490550186158963, 0.9425296374326482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 370}], {
             RGBColor[
             0.6431647387570222, 0.7183868662092043, 0.9670053375726531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 389}], {
             RGBColor[
             0.31710049015279534`, 0.4370417486876464, 0.9418787366896577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 400}], {
             RGBColor[
             0.4223618806328297, 0.5402016308185901, 0.9481469689308566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 51}], {
             RGBColor[
             0.33517005330446453`, 0.4636817173337682, 0.9426160703012283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[
             0.3427358884343137, 0.47023486345331306`, 0.943098158625497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 277}], {
             RGBColor[
             0.277614773953709, 0.4091211075916136, 0.9391211227311855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 287}], {
             RGBColor[
             0.27881505582512084`, 0.4103826799407336, 0.9391894770081045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 376}], {
             RGBColor[
             0.3679050083022842, 0.49203509004620194`, 0.9447019126873052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 377}], {
             RGBColor[
             0.3561480526956704, 0.48185180602152367`, 0.9439527698723194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 395}], {
             RGBColor[
             0.28524240829505776`, 0.41713823490432095`, 0.9395555052228516]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 396}], {
             RGBColor[
             0.28785811658992677`, 0.419887510167713, 0.9397044659406507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 44}], {
             RGBColor[
             0.29312282823703784`, 0.42542105591082463`, 0.9400042834805107]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 47}], {
             RGBColor[
             0.3610905157265072, 0.4852888096589335, 0.9442985989042187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 49}], {
             RGBColor[
             0.27201275594263963`, 0.40323303147352313`, 0.938802096092898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 147}], {
             RGBColor[
             0.2865134731880893, 0.418474204697066, 0.9396278904881377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 211}], {
             RGBColor[
             0.2754831553698227, 0.4068806413075249, 0.9389997302062802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 301}], {
             RGBColor[
             0.27255350960952185`, 0.40380139786317903`, 0.9388328912142536]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 328}], {
             RGBColor[
             0.2988631492240676, 0.4313905924329009, 0.9403335261361829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 347}], {
             RGBColor[
             0.28416959916217255`, 0.4160106444856309, 0.9394944103298126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 362}], {
             RGBColor[
             0.34647407000563907`, 0.4726287790194402, 0.9433672519077005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 372}], {
             RGBColor[
             0.2698833093261751, 0.4009948480649053, 0.9386808272583244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 380}], {
             RGBColor[
             0.2768898890919296, 0.40835920764152867`, 0.9390798416106783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 390}], {
             RGBColor[
             0.2772941937947283, 0.40878415751856884`, 0.9391028661653874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 45}], {
             RGBColor[
             0.26796415172899, 0.39897769174864406`, 0.938571534072304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 91}], {
             RGBColor[
             0.25152521102249714`, 0.3816993227770795, 0.9376353607183026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 150}], {
             RGBColor[
             0.2555149933709343, 0.38589283699209853`, 0.937862572920692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 190}], {
             RGBColor[
             0.2407660977459846, 0.370390812556283, 0.937022645133887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 226}], {
             RGBColor[
             0.23953161826969796`, 0.36909329635618626`, 0.936952343353961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 266}], {
             RGBColor[
             0.2477135704987891, 0.37769304691469485`, 0.9374182934292943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 273}], {
             RGBColor[
             0.25793330326133057`, 0.388434634016608, 0.9380002920913812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 365}], {
             RGBColor[
             0.24833496351636752`, 0.37834617037476265`, 0.9374536808423768]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 62}], {
             RGBColor[
             0.17899764558147852`, 0.30546825298532254`, 0.9335050231613544]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 77}], {
             RGBColor[
             0.5041460680446381, 0.5860856357063153, 0.9585438899509009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 84}], {
             RGBColor[
             0.1789270231889713, 0.3053940243730791, 0.9335010013205776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 204}], {
             RGBColor[
             0.17892701604158556`, 0.30539401686072354`, 0.9335010009135446]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 333}], {
             RGBColor[
             0.1872437438170861, 0.31413542506377157`, 0.9339746262568631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 370}], {
             RGBColor[
             0.5050718279609444, 0.5868238115344944, 0.9586321897581539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 389}], {
             RGBColor[
             0.17900757935671766`, 0.3054786940129366, 0.9335055888751587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 400}], {
             RGBColor[
             0.284268969836752, 0.4086385761438802, 0.9397738211163575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 33}], {
             RGBColor[0.1810793999809316, 0.30765630885, 0.9336235759947237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 106}], {
             RGBColor[
             0.5658561150624204, 0.6355057978202503, 0.9529071762376704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 156}], {
             RGBColor[
             0.18458847622123073`, 0.3113445704668384, 0.9338234126953957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 173}], {
             RGBColor[
             0.20479251217739197`, 0.3325802932666311, 0.9349740026539064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 175}], {
             RGBColor[
             0.18107477738655686`, 0.3076514502102228, 0.9336233127448126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 197}], {
             RGBColor[
             0.5859844235922751, 0.6497599697422292, 0.884913356826519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 204}], {
             RGBColor[
             0.1810722066459815, 0.3076487481988837, 0.9336231663449399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 214}], {
             RGBColor[
             0.5834952534993698, 0.6486610383850888, 0.9230487158880236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 261}], {
             RGBColor[
             0.18133289143212553`, 0.3079227444374911, 0.9336380119578622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 295}], {
             RGBColor[
             0.21280238164412135`, 0.34099917393122015`, 0.9354301528704966]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 310}], {
             RGBColor[
             0.18289778193115996`, 0.30956754357176464`, 0.9337271301567341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 345}], {
             RGBColor[
             0.1925824038789099, 0.3197466952793466, 0.9342786550495443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 43}], {
             RGBColor[
             0.2218603287150994, 0.3505196506098328, 0.9359459895561568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 124}], {
             RGBColor[
             0.21977833860588586`, 0.34833134699925217`, 0.9358274232994656]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 137}], {
             RGBColor[
             0.21892075175740905`, 0.34742996884735633`, 0.9357785849971308]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 199}], {
             RGBColor[
             0.22104408708317058`, 0.349661728901967, 0.9358995058027398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 238}], {
             RGBColor[
             0.22275425852448527`, 0.3514592275179208, 0.9359968975363508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 252}], {
             RGBColor[
             0.2203092674216852, 0.34888938684748844`, 0.9358576589100864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 293}], {
             RGBColor[
             0.2137582367821496, 0.342003838286004, 0.9354845874065463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 330}], {
             RGBColor[
             0.2205286799485376, 0.349120003324768, 0.935870154128899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 63}], {
             RGBColor[
             0.5687512197366357, 0.5886439817299056, 0.6135098819197802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 84}], {
             RGBColor[
             0.17893420048233583`, 0.30540156816347186`, 0.9335014100568169]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 90}], {
             RGBColor[
             0.44237359411374266`, 0.5377546224462848, 0.9524068017673784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 152}], {
             RGBColor[
             0.18127877637637368`, 0.30786586608280325`, 0.9336349301854932]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 156}], {
             RGBColor[
             0.18245046291019928`, 0.30909738291907096`, 0.9337016560002396]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 173}], {
             RGBColor[
             0.20265449886636056`, 0.33033310571886365`, 0.9348522459587503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 175}], {
             RGBColor[
             0.17893676407552545`, 0.30540426266245535`, 0.9335015560496566]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 204}], {
             RGBColor[
             0.1789341933349501, 0.3054015606511163, 0.9335014096497838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 214}], {
             RGBColor[
             0.5813572401883383, 0.6464138508373214, 0.9229269591928677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 256}], {
             RGBColor[
             0.202124876078153, 0.3297764385884332, 0.9348220847244686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 261}], {
             RGBColor[
             0.17919487812109408`, 0.3056755568897237, 0.9335162552627061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 264}], {
             RGBColor[
             0.18448620056776344`, 0.31123707227039327`, 0.9338175882482339]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 295}], {
             RGBColor[
             0.21066436833308994`, 0.3387519863834527, 0.9353083961753406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 310}], {
             RGBColor[
             0.18075976862012855`, 0.3073203560239972, 0.9336053734615781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 333}], {
             RGBColor[
             0.1872509211104506, 0.3141429688541644, 0.9339750349931024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 381}], {
             RGBColor[
             0.5860442078575524, 0.648421627973087, 0.8483684065741224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 53}], {
             RGBColor[
             0.30076648553276153`, 0.4331274488318972, 0.9404515726006413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 68}], {
             RGBColor[
             0.29450681654452554`, 0.42654813983932427`, 0.9400950937121118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 86}], {
             RGBColor[
             0.30641268277319833`, 0.4390619601211778, 0.940773115180684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 95}], {
             RGBColor[
             0.29703377047989377`, 0.4292041286435296, 0.9402390000004376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 151}], {
             RGBColor[
             0.31406226415390115`, 0.44644668080690353`, 0.9412327476508988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 244}], {
             RGBColor[
             0.2861625929026812, 0.4177778317374103, 0.9396199025198813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 249}], {
             RGBColor[
             0.2909291460215572, 0.4227877812822719, 0.9398913506685179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 253}], {
             RGBColor[
             0.3270023945629662, 0.4576547713773704, 0.9420572813180563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 270}], {
             RGBColor[
             0.28093807902462586`, 0.41228653639826196`, 0.9393223741835017]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 308}], {
             RGBColor[
             0.2866886948098787, 0.4183307981986623, 0.9396498632451982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 386}], {
             RGBColor[
             0.32582607560218535`, 0.4566359030170521, 0.9419823273140535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 397}], {
             RGBColor[
             0.28081927975955956`, 0.41216167083836874`, 0.939315608741104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 41}], {
             RGBColor[
             0.3109306833758936, 0.44117275107327436`, 0.9411269955899995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 57}], {
             RGBColor[
             0.2771242370211076, 0.4086055221736117, 0.9390931873785582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 92}], {
             RGBColor[
             0.28435244626912165`, 0.4162028283882106, 0.9395048232020553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 114}], {
             RGBColor[
             0.30495946572485455`, 0.43600078246607, 0.9407465148814157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 153}], {
             RGBColor[
             0.2992359056961653, 0.4310433224437109, 0.940381814697533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 188}], {
             RGBColor[
             0.27406348456255775`, 0.4053884772767613, 0.9389188820540213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 195}], {
             RGBColor[
             0.2633678783864708, 0.39414671704509485`, 0.9383097831050244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 208}], {
             RGBColor[
             0.25706388434981153`, 0.3875208196162586, 0.9379507799705602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 258}], {
             RGBColor[
             0.2669871560923189, 0.3979508073894016, 0.938515895616131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 278}], {
             RGBColor[
             0.26672833715189703`, 0.3976787722729497, 0.9385011562603622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 284}], {
             RGBColor[
             0.26251957032631373`, 0.3932550914880322, 0.9382614732159579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 327}], {
             RGBColor[
             0.29981659218631795`, 0.43154628389532945`, 0.9404188155272046]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 337}], {
             RGBColor[
             0.28289219144336497`, 0.41466800798083686`, 0.9394216638499819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 354}], {
             RGBColor[
             0.2804072432672092, 0.41205616989288285`, 0.9392801497275012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 369}], {
             RGBColor[
             0.26924749981930185`, 0.40032657196053045`, 0.9386446188475038]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 392}], {
             RGBColor[
             0.2644951314363644, 0.3953315314725043, 0.9383739784985945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 55}], {
             RGBColor[
             0.46160497467818506`, 0.5724389504821938, 0.9511318842995795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 60}], {
             RGBColor[
             0.4386028192989782, 0.5525156396146701, 0.9496662072988238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 64}], {
             RGBColor[
             0.45931878415001925`, 0.5704587671539738, 0.9509862102607236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 82}], {
             RGBColor[
             0.4494472254875384, 0.5619085191994977, 0.950357203271827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 122}], {
             RGBColor[
             0.4828824410191481, 0.5908684223901826, 0.952487665639901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 157}], {
             RGBColor[
             0.49446056893751156`, 0.6004643909150807, 0.9533448937369567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 165}], {
             RGBColor[
             0.5262130350709433, 0.6262424733544989, 0.9558445641840965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 218}], {
             RGBColor[
             0.7148705349959443, 0.7760303162882036, 0.9733069680605333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 262}], {
             RGBColor[
             0.7291600782306236, 0.787348496129779, 0.9720379295278863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 298}], {
             RGBColor[
             0.6715537144550077, 0.7414906593926315, 0.9691753710479567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 314}], {
             RGBColor[
             0.7227446385125958, 0.7823089126955356, 0.9740580070832467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 58}], {
             RGBColor[
             0.2743052593933725, 0.40564259795335733`, 0.9389326507729624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 87}], {
             RGBColor[
             0.2699691213947309, 0.4010850419897568, 0.9386857141286811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 110}], {
             RGBColor[
             0.2526887349083196, 0.3829222601527542, 0.9377016216823209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 134}], {
             RGBColor[
             0.24206319644531432`, 0.3717541455300861, 0.9370965129859282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 159}], {
             RGBColor[
             0.29061706023566036`, 0.4206896192842019, 0.9399383913431659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 167}], {
             RGBColor[
             0.26667449670074206`, 0.39762218254510395`, 0.9384980901263189]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 201}], {
             RGBColor[
             0.26311290635419504`, 0.3938787252730125, 0.9382952628249838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 236}], {
             RGBColor[
             0.2501608630823501, 0.3802653065873294, 0.9375576631214831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 243}], {
             RGBColor[
             0.2690857390615694, 0.4001565511479292, 0.9386354068116546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 263}], {
             RGBColor[
             0.25594156812645086`, 0.3863411941065481, 0.9378868657219579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 348}], {
             RGBColor[
             0.2563773742968305, 0.38679925402332427`, 0.9379116842386436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 351}], {
             RGBColor[
             0.2477720085286644, 0.3777544689892789, 0.9374216213886444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 78}], {
             RGBColor[
             0.9038175805994484, 0.6094521874784743, 0.2546544328195417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 102}], {
             RGBColor[
             0.8925441235088332, 0.5227994562196083, 0.24385895757801979`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 205}], {
             RGBColor[
             0.9805298619657696, 0.9442896440229023, 0.524841136015259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 207}], {
             RGBColor[
             0.9528235149386215, 0.8477616286807421, 0.29603526485507003`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 213}], {
             RGBColor[
             0.9383796626861343, 0.7904965676280676, 0.28441340229193146`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 221}], {
             RGBColor[
             0.9438250637656209, 0.9183985790902189, 0.6570073333224926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 224}], {
             RGBColor[
             0.970726359968221, 0.9129152797745752, 0.34077786564994345`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 230}], {
             RGBColor[
             0.9673242221990019, 0.9014390702190636, 0.3275612028563362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 247}], {
             RGBColor[
             0.9363993756149239, 0.7826453892822661, 0.2828200168311238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 250}], {
             RGBColor[
             0.9770092142863354, 0.9428337657309378, 0.5831873792076157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 289}], {
             RGBColor[
             0.9317722599024755, 0.7624356715057958, 0.27900046954474644`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 358}], {
             RGBColor[
             0.9671839420965409, 0.9009658724941282, 0.3270162411479497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 391}], {
             RGBColor[
             0.8930910009287811, 0.5270029957125417, 0.24438264801297166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 93}], {
             RGBColor[
             0.2591650880555334, 0.38972931793498194`, 0.9380704404131488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 94}], {
             RGBColor[
             0.2666080163774077, 0.39755230751018356`, 0.9384943041702538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 119}], {
             RGBColor[
             0.2567952159774935, 0.3872384321223937, 0.9379354797042159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 128}], {
             RGBColor[
             0.2996526087721707, 0.4306693116276521, 0.9404352763322198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 177}], {
             RGBColor[
             0.29750028265951367`, 0.4288050749279245, 0.9402981320155486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 200}], {
             RGBColor[
             0.27187585958380484`, 0.4030891447206572, 0.9387943000477824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 225}], {
             RGBColor[
             0.26510008482719366`, 0.3959673758425263, 0.9384084296992539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 288}], {
             RGBColor[
             0.2590590279232666, 0.38961784201136873`, 0.9380644004455181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 296}], {
             RGBColor[
             0.2873068026652887, 0.4193080442775966, 0.9396730694282384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 316}], {
             RGBColor[
             0.26368578568270973`, 0.3944808577699287, 0.9383278874552436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 324}], {
             RGBColor[
             0.27652485948189337`, 0.40797553837716655`, 0.9390590537143996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 355}], {
             RGBColor[
             0.25200661552040216`, 0.3822053094271858, 0.9376627759922841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 360}], {
             RGBColor[
             0.29174189371093673`, 0.42381744784571107`, 0.9399312125636886]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 374}], {
             RGBColor[
             0.2745978955714905, 0.40595017713076464`, 0.9389493159703898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 375}], {
             RGBColor[
             0.2639687025623859, 0.39477822134843454`, 0.9383439991530031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 380}], {
             RGBColor[
             0.2692913647455158, 0.4003726767791782, 0.9386471168901593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 383}], {
             RGBColor[
             0.27666419535336334`, 0.408121989212486, 0.9390669886861509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 390}], {
             RGBColor[
             0.26969566944831447`, 0.40079762665621843`, 0.9386701414448686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 41}], {
             RGBColor[
             0.34006622360312927`, 0.4689700034848203, 0.942889696952605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 55}], {
             RGBColor[
             0.37142239221905604`, 0.496129140733077, 0.9448876842896408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 58}], {
             RGBColor[
             0.31906156196643076`, 0.449858262003899, 0.9415849314423156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.3368642646638673, 0.46619662758676733`, 0.9426856709603764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 87}], {
             RGBColor[
             0.31472542396778913`, 0.4453007060402985, 0.9413379947980343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 96}], {
             RGBColor[
             0.313111809733841, 0.4436046951713676, 0.9412461018545393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 110}], {
             RGBColor[
             0.29744503748137785`, 0.4271379242032959, 0.940353902351674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 146}], {
             RGBColor[
             0.43732168419070216`, 0.5509809435704429, 0.9497020146539848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 154}], {
             RGBColor[
             0.3847350802007028, 0.5076599219476261, 0.9457359569958835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 159}], {
             RGBColor[
             0.33537336280871854`, 0.46490528333474357`, 0.9425906720125191]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 167}], {
             RGBColor[
             0.31143079927380024`, 0.4418378465956456, 0.9411503707956721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 192}], {
             RGBColor[
             0.34190093761815415`, 0.4705591405492272, 0.9430066033072686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 203}], {
             RGBColor[
             0.31535485342024205`, 0.44596227630295887`, 0.941373839874194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 228}], {
             RGBColor[
             0.35358465424250685`, 0.48067898864856917`, 0.9437510793990673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 243}], {
             RGBColor[
             0.3138420416346276, 0.4443722151984709, 0.9412876874810078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 332}], {
             RGBColor[
             0.43326686926446056`, 0.5476890621459892, 0.9493828047697146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 348}], {
             RGBColor[
             0.3011336768698887, 0.43101491807386594`, 0.9405639649079968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 361}], {
             RGBColor[
             0.34746932604333547`, 0.4753821987277793, 0.9433614160937887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 385}], {
             RGBColor[
             0.4573665882056296, 0.5672542996623962, 0.9512800229249427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 57}], {
             RGBColor[
             0.3070138697292798, 0.4370559315903547, 0.9409039388472313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.31424207897729384`, 0.44465323780495364`, 0.9413155746707285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 96}], {
             RGBColor[
             0.3138659022147775, 0.44425785217656466`, 0.9412941519606068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 114}], {
             RGBColor[
             0.3348490984330268, 0.46445119188281303`, 0.9425572663500889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 153}], {
             RGBColor[
             0.32912553840433756`, 0.45949373186045395`, 0.9421925661662062]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 154}], {
             RGBColor[
             0.3854891726816393, 0.5083130789528232, 0.945784007101951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 188}], {
             RGBColor[
             0.30395311727072993`, 0.43383888669350434`, 0.9407296335226945]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 203}], {
             RGBColor[
             0.31610894590117855`, 0.4466154333081559, 0.9414218899802616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 222}], {
             RGBColor[
             0.4728736082946373, 0.5798845479116403, 0.9524894775340721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 258}], {
             RGBColor[
             0.29687678880049106`, 0.4264012168061446, 0.9403266470848042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 312}], {
             RGBColor[
             0.40188874544580117`, 0.5222558384193261, 0.9469012891044913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 327}], {
             RGBColor[
             0.32970622489449014`, 0.4599966933120725, 0.9422295669958778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 356}], {
             RGBColor[
             0.4295993605310475, 0.5447525640945126, 0.9490827702313296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 361}], {
             RGBColor[
             0.34822341852427197`, 0.4760353557329764, 0.9434094661998561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 369}], {
             RGBColor[
             0.2991371325274741, 0.4287769813772735, 0.940455370316177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 104}], {
             RGBColor[
             0.9330499750272585, 0.8621677183315113, 0.6295247357296906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 109}], {
             RGBColor[
             0.9631611562508396, 0.9703111795583055, 0.8704491819362283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 136}], {
             RGBColor[
             0.7754039881303256, 0.825013733522431, 0.9782569627328132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 205}], {
             RGBColor[
             0.9637471875060623, 0.9705535185426564, 0.8607371274369169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 207}], {
             RGBColor[
             0.9360408404789141, 0.8740255032004962, 0.6319312562767279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 221}], {
             RGBColor[
             0.9270423893059134, 0.944662453609973, 0.9929033247441504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 276}], {
             RGBColor[
             0.8488960037945177, 0.8827904862944987, 0.9853329329150746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 358}], {
             RGBColor[
             0.9504012676368335, 0.9272297470138823, 0.6629122325696076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 366}], {
             RGBColor[
             0.9167531541973288, 0.7967074998480634, 0.6163680259642358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 376}], {
             RGBColor[
             0.6853095806395425, 0.7514657941798157, 0.9712763701432583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 124}], {
             RGBColor[
             0.22535325774935577`, 0.3541909404893282, 0.9361449066973324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 137}], {
             RGBColor[
             0.22449567090087896`, 0.35328956233743236`, 0.9360960683949977]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 199}], {
             RGBColor[
             0.2266190062266405, 0.3555213223920431, 0.9362169892006067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 238}], {
             RGBColor[
             0.22832917766795519`, 0.3573188210079969, 0.9363143809342176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 252}], {
             RGBColor[
             0.2258841865651551, 0.3547489803375645, 0.9361751423079533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 277}], {
             RGBColor[
             0.2426240388727448, 0.37234362648077923`, 0.9371284521324783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 293}], {
             RGBColor[
             0.21933315592561953`, 0.34786343177608003`, 0.9358020708044131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 299}], {
             RGBColor[
             0.22078197517346282`, 0.34938623266600927`, 0.9358845789172419]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 330}], {
             RGBColor[
             0.2261035990920075, 0.35497959681484403`, 0.9361876375267658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 367}], {
             RGBColor[
             0.22337497152266345`, 0.35211163623448327`, 0.9360322462233344]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 47}], {
             RGBColor[
             0.36592423069765223`, 0.4903693505688373, 0.9445738718209851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 49}], {
             RGBColor[
             0.2768464709137847, 0.4083135723834269, 0.9390773690096643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 54}], {
             RGBColor[
             0.3749740145051137, 0.4982078184475008, 0.9451505160427869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 93}], {
             RGBColor[
             0.2715973273730923, 0.4027963897072362, 0.9387784380504338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[
             0.3120848480897295, 0.44373638339990634`, 0.9411432739695049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 211}], {
             RGBColor[
             0.28031687034096775`, 0.4119611822174286, 0.9392750031230466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 301}], {
             RGBColor[
             0.2773872245806669, 0.4088819387730828, 0.9391081641310199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 316}], {
             RGBColor[
             0.27611802500026855`, 0.4075479295421829, 0.9390358850925288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 324}], {
             RGBColor[
             0.2889570987994522, 0.4210426101494208, 0.9397670513516847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 328}], {
             RGBColor[
             0.3036968641952127, 0.4364711333428047, 0.9406087990529493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 362}], {
             RGBColor[
             0.35130778497678417`, 0.477709319929344, 0.9436425248244668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 372}], {
             RGBColor[
             0.27471702429732014`, 0.4060753889748091, 0.9389561001750906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 380}], {
             RGBColor[
             0.2817236040630746, 0.41343974855143245`, 0.9393551145274445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 383}], {
             RGBColor[
             0.28909643467092216`, 0.42118906098474024`, 0.9397749863234359]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 390}], {
             RGBColor[
             0.28212790876587335`, 0.4138646984284726, 0.9393781390821536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 91}], {
             RGBColor[
             0.27906015322156846`, 0.41064029284447245`, 0.9392034349422431]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 97}], {
             RGBColor[
             0.36889177075057233`, 0.4927124766331557, 0.9447712800460943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 100}], {
             RGBColor[
             0.33605658973236274`, 0.46427229317936647`, 0.9426790513466246]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 112}], {
             RGBColor[
             0.31221013250570034`, 0.4436176904874213, 0.9411595761787357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 141}], {
             RGBColor[
             0.32778152064738697`, 0.45710484425502595`, 0.9421517712618861]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 180}], {
             RGBColor[
             0.33088455801292704`, 0.4597925392578639, 0.9423494940589101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 190}], {
             RGBColor[
             0.2683010399450559, 0.3993317826236759, 0.9385907193578275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 266}], {
             RGBColor[
             0.2752485126978604, 0.4066340169820878, 0.9389863676532347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 271}], {
             RGBColor[
             0.30114348847212347`, 0.43385127835713033`, 0.9404610482153953]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 273}], {
             RGBColor[
             0.2854682454604019, 0.41737560408400093`, 0.9395683663153217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 350}], {
             RGBColor[
             0.36412092231360993`, 0.48858020750687353`, 0.9444672858023867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 365}], {
             RGBColor[
             0.2758699057154388, 0.4072871404421556, 0.9390217550663172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 394}], {
             RGBColor[
             0.32718352263793704`, 0.4565868884354943, 0.9421136673575129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 59}], {
             RGBColor[
             0.30916725287120805`, 0.4399481765928165, 0.9410035436196971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 287}], {
             RGBColor[
             0.27226485336384204`, 0.4034980018471065, 0.9388164526680909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 373}], {
             RGBColor[
             0.26731905714517273`, 0.3982996564396932, 0.9385347968900875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 395}], {
             RGBColor[
             0.27869220583377896`, 0.41025355681069386`, 0.939182480882838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 54}], {
             RGBColor[
             0.44294170199458305`, 0.5580755721956097, 0.9494448314664949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 121}], {
             RGBColor[
             0.4935440296663224, 0.5991928393789325, 0.9534184801906773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 128}], {
             RGBColor[
             0.3800525355791988, 0.5036041371480152, 0.945437589393213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 130}], {
             RGBColor[
             0.4221487542491271, 0.5400657659424366, 0.9481199232226362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.468503909528975, 0.5788641418068768, 0.9514472302084831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 181}], {
             RGBColor[
             0.5006021052009016, 0.6049229030605833, 0.9539741177513421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 265}], {
             RGBColor[
             0.5128933077983199, 0.6149014550415344, 0.9549417262439694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 311}], {
             RGBColor[
             0.47663297852550124`, 0.5854636862286419, 0.9520871802976505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 322}], {
             RGBColor[
             0.47115402237552717`, 0.5810156228019311, 0.9516558567994469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 362}], {
             RGBColor[
             0.4192754724662534, 0.5375770736774529, 0.9479368402481747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 56}], {
             RGBColor[
             0.43818896314994105`, 0.5539589886879809, 0.9491419911499963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 71}], {
             RGBColor[
             0.6482814539995922, 0.7214952269023049, 0.9679496107647267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 83}], {
             RGBColor[
             0.38916228198081126`, 0.5114945416119245, 0.9460180543784913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 103}], {
             RGBColor[
             0.3850045259376993, 0.5078933023022759, 0.9457531258399835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 108}], {
             RGBColor[
             0.3965059868386308, 0.5178552896544295, 0.9464859887582483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 120}], {
             RGBColor[
             0.49591060473188847`, 0.6008847208403402, 0.9536681725336434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 143}], {
             RGBColor[
             0.5250435709581793, 0.6245361752480152, 0.9559616263525487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 196}], {
             RGBColor[
             0.3616835055171287, 0.4866932494532377, 0.9443037663378753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 231}], {
             RGBColor[
             0.3670635094292236, 0.49234797467679914`, 0.9446101496016666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 234}], {
             RGBColor[
             0.38209114426819646`, 0.5053698775309731, 0.945567487736205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 286}], {
             RGBColor[
             0.5758463873446392, 0.6644950889479655, 0.9608396409213635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 290}], {
             RGBColor[
             0.4152883060919923, 0.5341235905648768, 0.9476827815325197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 313}], {
             RGBColor[
             0.35412562406909687`, 0.4787494368539953, 0.9438733561702934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 320}], {
             RGBColor[
             0.5676684575710711, 0.6581064280542859, 0.9600245413086331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 331}], {
             RGBColor[
             0.43876768248625253`, 0.5544602462898143, 0.9491788666343646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 342}], {
             RGBColor[
             0.5144005472567488, 0.6158956891444403, 0.9551237685400916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 343}], {
             RGBColor[
             0.5738217336869491, 0.6629134141226403, 0.9606378423662292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 344}], {
             RGBColor[
             0.373035772157718, 0.49752656934511247`, 0.9449904874326764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 349}], {
             RGBColor[
             0.43541101780241814`, 0.5515528720515495, 0.9489649829288928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 147}], {
             RGBColor[
             0.2702371158648362, 0.4013667211696683, 0.9387009760172913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 211}], {
             RGBColor[
             0.25920679804656954`, 0.3897731577801271, 0.9380728157354339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 301}], {
             RGBColor[
             0.2562771522862687, 0.3866939143357813, 0.9379059767434073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 328}], {
             RGBColor[
             0.2825867919008145, 0.4142831089055032, 0.9394066116653366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 347}], {
             RGBColor[
             0.2678932418389194, 0.3989031609582332, 0.9385674958589661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 372}], {
             RGBColor[
             0.25360695200292194`, 0.3838873645375076, 0.9377539127874779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 380}], {
             RGBColor[
             0.2606135317686764, 0.39125172411413095`, 0.9381529271398318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 54}], {
             RGBColor[
             0.4530695590105145, 0.5668252864420751, 0.9500963936878091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 116}], {
             RGBColor[
             0.4351844866677396, 0.551334135708637, 0.9489567726932759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 121}], {
             RGBColor[
             0.5036718866822538, 0.607942553625398, 0.9540700424119916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.4322766112650586, 0.5488154801889021, 0.9487714854439504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 135}], {
             RGBColor[
             0.478712840814817, 0.5876796757980098, 0.9521051748933094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 158}], {
             RGBColor[
             0.47863176654490647`, 0.5876138560533424, 0.9520987924297972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 172}], {
             RGBColor[
             0.3777861468106212, 0.500941670871986, 0.945324186142565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 181}], {
             RGBColor[
             0.5107299622168331, 0.6136726173070488, 0.9546256799726562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 265}], {
             RGBColor[
             0.5230211648142513, 0.6236511692879999, 0.9555932884652836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 276}], {
             RGBColor[
             0.6098568885565028, 0.6922609454050347, 0.9637197242270632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 322}], {
             RGBColor[
             0.4812818793914586, 0.5897653370483966, 0.952307419020761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 328}], {
             RGBColor[
             0.38179240870061343`, 0.505088601337379, 0.9455546766979714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 362}], {
             RGBColor[
             0.4294033294821849, 0.5463267879239184, 0.948588402469489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 364}], {
             RGBColor[
             0.4018386991300539, 0.5224516905515073, 0.9468320085978967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 59}], {
             RGBColor[
             0.3534707906164537, 0.48058036569863427`, 0.9437438241095009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 136}], {
             RGBColor[
             0.4957527510770341, 0.5993305404010079, 0.9540497614266502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 194}], {
             RGBColor[
             0.38048922371828053`, 0.5039823744655038, 0.945465414775287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 246}], {
             RGBColor[
             0.408363122473439, 0.5281253445843351, 0.9472415149560449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 376}], {
             RGBColor[
             0.405658343586251, 0.5257826010583926, 0.9470691688370954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 377}], {
             RGBColor[
             0.39390138797963725`, 0.5155993170337143, 0.9463200260221095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 395}], {
             RGBColor[
             0.3229957435790246, 0.45088574591651165`, 0.9419227613726417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 396}], {
             RGBColor[
             0.3256114518738936, 0.4536350211799036, 0.9420717220904409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 117}], {
             RGBColor[
             0.36808130040816744`, 0.4932352549346425, 0.9446747928738624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 133}], {
             RGBColor[
             0.34195185422260005`, 0.4695411184843201, 0.9430487372114036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 174}], {
             RGBColor[
             0.5576254346896334, 0.6486129747855855, 0.95972095993169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 223}], {
             RGBColor[
             0.42035633884682855`, 0.5384929234825571, 0.9480113327439608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 260}], {
             RGBColor[
             0.5977997596730911, 0.6799974627988412, 0.9637251611956289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 267}], {
             RGBColor[
             0.4789222153161444, 0.5860393403630161, 0.9526218530734996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 272}], {
             RGBColor[
             0.5168312067307885, 0.6167442138565202, 0.9556549725324873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 291}], {
             RGBColor[
             0.5415685327056081, 0.6360692009186899, 0.9581205580022027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 346}], {
             RGBColor[
             0.36583874865596927`, 0.4912928693208167, 0.944531899459223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 384}], {
             RGBColor[
             0.5675366621289825, 0.6563557009893235, 0.9607088184571579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 68}], {
             RGBColor[
             0.28298429153365734`, 0.4147648110152172, 0.9394269088138741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 86}], {
             RGBColor[
             0.2948901577623302, 0.4272786312970708, 0.9401049302824465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 95}], {
             RGBColor[
             0.2855112454690256, 0.4174207998194225, 0.9395708151022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 101}], {
             RGBColor[
             0.27504289638646184`, 0.40641790120198085`, 0.9389746581084827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 129}], {
             RGBColor[
             0.26346421560774436`, 0.39424797357278596`, 0.9383152693672578]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 151}], {
             RGBColor[
             0.302539739143033, 0.43466335198279643`, 0.9405645627526612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 171}], {
             RGBColor[
             0.28122827358250124`, 0.41291912481058346`, 0.9393269061893516]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 244}], {
             RGBColor[
             0.27464006789181306`, 0.4059945029133032, 0.9389517176216438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 249}], {
             RGBColor[
             0.279406621010689, 0.4110044524581648, 0.9392231657702803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 253}], {
             RGBColor[
             0.31547986955209806`, 0.4458714425532633, 0.9413890964198188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 270}], {
             RGBColor[
             0.26941555401375766`, 0.4005032075741548, 0.9386541892852642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 308}], {
             RGBColor[
             0.27516616979901054`, 0.4065474693745552, 0.9389816783469607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 386}], {
             RGBColor[
             0.3143035505913172, 0.444852574192945, 0.9413141424158159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 397}], {
             RGBColor[
             0.26929675474869136`, 0.4003783420142617, 0.9386474238428664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 121}], {
             RGBColor[
             0.502593813473784, 0.607031307257596, 0.9539951244124792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 128}], {
             RGBColor[
             0.3891023193866603, 0.5114426050266787, 0.9460142336150148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 130}], {
             RGBColor[
             0.43119853805658864`, 0.5479042338211002, 0.9486965674444381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 158}], {
             RGBColor[
             0.4775536933364365, 0.5867026096855403, 0.9520238744302849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 181}], {
             RGBColor[
             0.5096518890083631, 0.6127613709392468, 0.9545507619731439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 265}], {
             RGBColor[
             0.5219430916057815, 0.622739922920198, 0.9555183704657713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 311}], {
             RGBColor[
             0.48568276233296276`, 0.5933021541073054, 0.9526638245194523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 322}], {
             RGBColor[
             0.48020380618298864`, 0.5888540906805946, 0.9522325010212487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 328}], {
             RGBColor[
             0.38071433549214345`, 0.504177354969577, 0.9454797586984591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 362}], {
             RGBColor[
             0.4283252562737149, 0.5454155415561164, 0.9485134844699766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 58}], {
             RGBColor[
             0.351171823063294, 0.4776705562573528, 0.9436309688854188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 60}], {
             RGBColor[
             0.38053049793671245`, 0.5040181241190069, 0.9454680447319882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 80}], {
             RGBColor[
             0.36897452576073053`, 0.49400892184022105`, 0.9447317084034796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 87}], {
             RGBColor[
             0.34683568506465234`, 0.47311300029375225`, 0.9433840322411374]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 122}], {
             RGBColor[
             0.4248101196568824, 0.5423709068945195, 0.9482895030730654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 146}], {
             RGBColor[
             0.4694319452875655, 0.5787932378238967, 0.951748052097088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 159}], {
             RGBColor[
             0.36748362390558187`, 0.49271757758819734`, 0.9446367094556223]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.4681407137086776, 0.5777449578588358, 0.9516464016172608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 192}], {
             RGBColor[
             0.3740111987150174, 0.498371434802681, 0.9450526407503718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 201}], {
             RGBColor[
             0.33997947002411655`, 0.46590668357700793`, 0.9429935809374401]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 210}], {
             RGBColor[
             0.3517281816196206, 0.4782553243752219, 0.9436626526821428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 228}], {
             RGBColor[
             0.38569491533937006`, 0.508491282902023, 0.9457971168421706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 385}], {
             RGBColor[
             0.4894768493024928, 0.5950665939158499, 0.9533260603680459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 71}], {
             RGBColor[
             0.6610275221983658, 0.7325352305400676, 0.968761778959447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 83}], {
             RGBColor[
             0.4019083501795848, 0.5225345452496872, 0.9468302225732115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 108}], {
             RGBColor[
             0.40925205503740436`, 0.5288952932921922, 0.9472981569529686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 120}], {
             RGBColor[
             0.5086566729306621, 0.6119247244781029, 0.9544803407283637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 143}], {
             RGBColor[
             0.5377896391569529, 0.6355761788857779, 0.956773794547269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 196}], {
             RGBColor[
             0.3744295737159023, 0.4977332530910004, 0.9451159345325955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 231}], {
             RGBColor[
             0.37980957762799716`, 0.5033879783145618, 0.9454223177963867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 237}], {
             RGBColor[
             0.5146770314008289, 0.6168123226982427, 0.9549542854004349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 254}], {
             RGBColor[
             0.46022321075082034`, 0.5726042579779009, 0.9506674811679487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 286}], {
             RGBColor[
             0.5885924555434128, 0.6755350925857282, 0.9616518091160838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 290}], {
             RGBColor[
             0.42803437429076585`, 0.5451635942026395, 0.9484949497272399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 320}], {
             RGBColor[
             0.5804145257698448, 0.6691464316920486, 0.9608367095033534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 331}], {
             RGBColor[
             0.4515137506850261, 0.565500249927577, 0.9499910348290849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 342}], {
             RGBColor[
             0.5271466154555224, 0.626935692782203, 0.9559359367348119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 343}], {
             RGBColor[
             0.5865678018857227, 0.673953417760403, 0.9614500105609494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 344}], {
             RGBColor[
             0.38578184035649155`, 0.5085665729828752, 0.9458026556273967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 349}], {
             RGBColor[
             0.44815708600119175`, 0.5625928756893122, 0.949777151123613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 92}], {
             RGBColor[
             0.2804356326225079, 0.4120860089052909, 0.9392817664592872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 114}], {
             RGBColor[
             0.3010426520782409, 0.43188396298315035`, 0.9405234581386476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 153}], {
             RGBColor[
             0.2953190920495516, 0.42692650296079127`, 0.9401587579547649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 188}], {
             RGBColor[
             0.270146670915944, 0.40127165779384166`, 0.9386958253112532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 195}], {
             RGBColor[
             0.25945106473985713`, 0.3900298975621752, 0.9380867263622563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 208}], {
             RGBColor[
             0.2531470707031978, 0.383404000133339, 0.9377277232277921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 258}], {
             RGBColor[
             0.26307034244570515`, 0.39383398790648194`, 0.9382928388733629]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 278}], {
             RGBColor[
             0.26281152350528336`, 0.39356195279003, 0.9382780995175941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 284}], {
             RGBColor[
             0.2586027566797, 0.38913827200511253`, 0.9380384164731898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 327}], {
             RGBColor[
             0.2958997785397042, 0.4274294644124098, 0.9401957587844365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 337}], {
             RGBColor[
             0.27897537779675124`, 0.41055118849791716`, 0.9391986071072138]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 354}], {
             RGBColor[
             0.27649042962059545`, 0.4079393504099632, 0.939057092984733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 392}], {
             RGBColor[
             0.2605783177897506, 0.3912147119895847, 0.9381509217558264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 60}], {
             RGBColor[
             0.3281696676840872, 0.4577472453898289, 0.942165291884663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 80}], {
             RGBColor[
             0.31661369550810525`, 0.44773804311104304`, 0.9414289555561544]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 87}], {
             RGBColor[
             0.29447485481202706`, 0.42684212156457424`, 0.9400812793938123]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 110}], {
             RGBColor[
             0.2771944683256158, 0.40867933972757164`, 0.939097186947452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 159}], {
             RGBColor[
             0.31512279365295653`, 0.44644669885901933`, 0.9413339566082971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 167}], {
             RGBColor[
             0.2911802301180382, 0.4233792621199214, 0.9398936553914501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 192}], {
             RGBColor[
             0.32165036846239214`, 0.45210055607350297`, 0.9417498879030466]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 201}], {
             RGBColor[
             0.2876186397714912, 0.4196358048478299, 0.939690828090115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 210}], {
             RGBColor[
             0.2993673513669953, 0.4319844456460439, 0.9403598998348177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 228}], {
             RGBColor[
             0.3333340850867448, 0.46222040417284493`, 0.9424943639948453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 236}], {
             RGBColor[
             0.27466659649964625`, 0.4060223861621468, 0.9389532283866143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 243}], {
             RGBColor[
             0.2935914724788655, 0.42591363072274663`, 0.9400309720767858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 263}], {
             RGBColor[
             0.28044730154374703`, 0.41209827368136553`, 0.9392824309870891]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 348}], {
             RGBColor[
             0.28088310771412667`, 0.4125563335981417, 0.9393072495037748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 351}], {
             RGBColor[
             0.27227774194596055`, 0.4035115485640963, 0.9388171866537756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 79}], {
             RGBColor[
             0.46241207497172554`, 0.5712067102742551, 0.9517169387007705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[
             0.3610366257463029, 0.4871335118181791, 0.9442259124337696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 237}], {
             RGBColor[
             0.4562186120487096, 0.5661785780610258, 0.9512293666120685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 246}], {
             RGBColor[
             0.38891052450146135`, 0.5112764819370106, 0.9460020126145274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 254}], {
             RGBColor[
             0.401764791398701, 0.521970513340684, 0.9469425623795822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 349}], {
             RGBColor[
             0.38969866664907243`, 0.5119591310520951, 0.9460522323352465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 373}], {
             RGBColor[
             0.2921699969184407, 0.4220829828981863, 0.9400355750383738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 395}], {
             RGBColor[
             0.303543145607047, 0.434036883269187, 0.9406832590311243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 87}], {
             RGBColor[
             0.32383352968544554`, 0.4531896894262284, 0.9419183552403817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 122}], {
             RGBColor[
             0.4018079642776756, 0.5224475960269956, 0.9468238260723096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 146}], {
             RGBColor[
             0.44642978990835863`, 0.5588699269563728, 0.9502823750963323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 159}], {
             RGBColor[
             0.344481468526375, 0.4727942667206735, 0.9431710324548666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 165}], {
             RGBColor[
             0.4451385583294708, 0.557821646991312, 0.950180724616505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 201}], {
             RGBColor[
             0.3169773146449097, 0.44598337270948407`, 0.9415279039366844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 210}], {
             RGBColor[
             0.3287260262404138, 0.45833201350769803`, 0.942196975681387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 263}], {
             RGBColor[
             0.3098059764171655, 0.4384458415430197, 0.9411195068336586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 66}], {
             RGBColor[
             0.9830643953423903, 0.9540141570597834, 0.4329439736998075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 98}], {
             RGBColor[
             0.985458002900472, 0.9620883573989745, 0.44224268706809605`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 107}], {
             RGBColor[
             0.9162817916828967, 0.6453128669663495, 0.3511545314597267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 131}], {
             RGBColor[
             0.9579060415796807, 0.8592435772757068, 0.3867967672286041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 215}], {
             RGBColor[
             0.9063170503481712, 0.5687194984901538, 0.341612283904028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 262}], {
             RGBColor[
             0.9659943820446136, 0.9709682059989204, 0.7529333373497976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 269}], {
             RGBColor[
             0.9932024163292561, 0.9878689808064407, 0.5015031511422814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 279}], {
             RGBColor[
             0.9694977718101772, 0.9052009249245101, 0.39612374546494056`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 297}], {
             RGBColor[
             0.9699924620425022, 0.9739499675150907, 0.7461656307796394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 298}], {
             RGBColor[
             0.9083880182689977, 0.925110369261773, 0.7500707788698681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 300}], {
             RGBColor[
             0.9416713408004723, 0.7907793854302443, 0.3735219082012329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 306}], {
             RGBColor[
             0.9818610097196364, 0.9499548547858537, 0.42826904779571534`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 307}], {
             RGBColor[
             0.9892929392100926, 0.9881701251038566, 0.7056981044009731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 314}], {
             RGBColor[
             0.9595789423265859, 0.965928622564677, 0.7549534149051582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 352}], {
             RGBColor[
             0.9937500196167237, 0.9890402488671484, 0.5611063895673631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 77}], {
             RGBColor[
             0.5042166815429454, 0.5861598549701907, 0.9585479112851663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 204}], {
             RGBColor[
             0.17899762953989296`, 0.30546823612459895`, 0.9335050222478098]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 345}], {
             RGBColor[
             0.19050782677282135`, 0.3175661832050619, 0.9341605109524143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 370}], {
             RGBColor[
             0.5051424414592518, 0.5868980307983699, 0.9586362110924191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 389}], {
             RGBColor[
             0.17907819285502502`, 0.305552913276812, 0.9335096102094239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 400}], {
             RGBColor[
             0.2843395833350594, 0.4087127954077557, 0.9397778424506229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 90}], {
             RGBColor[
             0.8321834271804781, 0.8209894828739578, 0.632414864387591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 138}], {
             RGBColor[
             0.8889519646070447, 0.5107811215593289, 0.22983700543826907`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 142}], {
             RGBColor[
             0.890072513149207, 0.5193941486818902, 0.23091004398772222`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 152}], {
             RGBColor[
             0.5710886094431091, 0.5911007265104762, 0.6136429928057057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 156}], {
             RGBColor[
             0.5722602959769347, 0.592332243346744, 0.6137097186204522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 202}], {
             RGBColor[
             0.9074503393274316, 0.6529677356997123, 0.2475510699614376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 214}], {
             RGBColor[
             0.9711670732550739, 0.9296487112649943, 0.6029350218130802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 217}], {
             RGBColor[
             0.8906933611547283, 0.5241662585096577, 0.23150456873895697`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 242}], {
             RGBColor[
             0.9384539463641798, 0.7929291511512139, 0.2733380495894395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 256}], {
             RGBColor[
             0.5919347091448884, 0.6130112990161062, 0.6148301473446811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 257}], {
             RGBColor[
             0.8905841112547781, 0.5233265159050291, 0.23139995091138454`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 261}], {
             RGBColor[
             0.5690047111878296, 0.5889104173173967, 0.6135243178829187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 264}], {
             RGBColor[
             0.5742960336344989, 0.5944719326980662, 0.6138256508684465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 268}], {
             RGBColor[
             0.8879400264016856, 0.5030029210787892, 0.2288679722699964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 317}], {
             RGBColor[
             0.9745940579826633, 0.9311354530743134, 0.5492576472683819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 381}], {
             RGBColor[
             0.975854040924288, 0.9316564884007599, 0.528376469194335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 82}], {
             RGBColor[
             0.38908871359710695`, 0.5114308203756144, 0.9460133666661356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 151}], {
             RGBColor[
             0.35739789501188024`, 0.48398182614394664`, 0.9439940557289754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 157}], {
             RGBColor[
             0.43410205704708005`, 0.5499866920911975, 0.9490010571312653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 171}], {
             RGBColor[
             0.3360864294513485, 0.46223759897173367`, 0.9427563991656658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 182}], {
             RGBColor[
             0.34352729206089855`, 0.4700584173523088, 0.9431801452835099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 253}], {
             RGBColor[
             0.3703380254209453, 0.4951899167144135, 0.9448185893961331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 105}], {
             RGBColor[
             0.46633814789011974`, 0.5766565671437895, 0.9514008797073982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 113}], {
             RGBColor[
             0.6559239156864949, 0.7291861264524664, 0.9676704388099608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 148}], {
             RGBColor[
             0.5696101053080527, 0.6614741699887192, 0.9592609405218679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 161}], {
             RGBColor[
             0.4733844161827434, 0.5827596905831183, 0.9518498616922337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 168}], {
             RGBColor[
             0.592741338058181, 0.6798274166038522, 0.9613729899467283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 170}], {
             RGBColor[
             0.4801509107444425, 0.5886204880785566, 0.952281016742329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 180}], {
             RGBColor[
             0.4408011041078431, 0.5545376633487222, 0.9497736818591127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 239}], {
             RGBColor[
             0.4199235526672635, 0.5364545776271384, 0.9484433827426128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 251}], {
             RGBColor[
             0.6688240146939028, 0.7392826292624911, 0.9689511985946974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 282}], {
             RGBColor[
             0.5810969797016021, 0.6707307553552915, 0.9602123891284602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 312}], {
             RGBColor[
             0.4891446804627151, 0.5961487131731942, 0.9529264075234798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 326}], {
             RGBColor[
             0.4273612108963405, 0.5428967033575929, 0.9489173037481067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 356}], {
             RGBColor[
             0.5168552955479615, 0.6186454388483807, 0.9551078886503179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[
             0.9751764945744315, 0.9279266287426179, 0.3580657982576656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 107}], {
             RGBColor[
             0.906000283356856, 0.6111511383099929, 0.2669776426492963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 131}], {
             RGBColor[
             0.9476245332536402, 0.8250818486193503, 0.3026198784181737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 215}], {
             RGBColor[
             0.8960355420221306, 0.5345577698337973, 0.25743539509359753`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 297}], {
             RGBColor[
             0.9597109537164616, 0.9397882388587341, 0.661988741969209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 307}], {
             RGBColor[
             0.9790114308840521, 0.9540083964475, 0.6215212155905427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 314}], {
             RGBColor[
             0.9492974340005453, 0.9317668939083206, 0.6707765260947278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 352}], {
             RGBColor[
             0.983468511290683, 0.9548785202107917, 0.47692950075693274`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 85}], {
             RGBColor[
             0.22712666696496037`, 0.35605490601556716`, 0.9362458997286371]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 127}], {
             RGBColor[
             0.21172079285419906`, 0.33986235553632177`, 0.9353685579889777]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 139}], {
             RGBColor[
             0.21205827028800195`, 0.34021706571655375`, 0.9353877768295796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 184}], {
             RGBColor[
             0.2153543932680198, 0.3436814999548199, 0.9355754861571146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 305}], {
             RGBColor[
             0.20792423756527648`, 0.33587193521215575`, 0.9351523497817738]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 325}], {
             RGBColor[
             0.21225679273606501`, 0.3404257253965182, 0.9353990823893092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 86}], {
             RGBColor[
             0.28863048877409425`, 0.42069932230449786`, 0.9397484513939167]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 95}], {
             RGBColor[
             0.2792515764807897, 0.4108414908268496, 0.9392143362136705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 129}], {
             RGBColor[
             0.25720454661950837`, 0.38766866458021304`, 0.9379587904787283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 151}], {
             RGBColor[
             0.29628007015479707`, 0.4280840429902235, 0.9402080838641316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 178}], {
             RGBColor[
             0.2603565331566741, 0.3909816022782634, 0.9381382914490737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 229}], {
             RGBColor[
             0.2618103919644219, 0.39250970006517877`, 0.9382210865573835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 249}], {
             RGBColor[
             0.2731469520224531, 0.4044251434655919, 0.9388666868817508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 308}], {
             RGBColor[
             0.26890650081077455`, 0.39996816038198235`, 0.938625199458431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 309}], {
             RGBColor[
             0.27375753584035556`, 0.40506690577145743`, 0.9389014587269024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 319}], {
             RGBColor[
             0.2591541477712746, 0.38971781900257185`, 0.9380698173801449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 334}], {
             RGBColor[
             0.2690618295669699, 0.40013142075315566`, 0.938634045201308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 371}], {
             RGBColor[
             0.27438511411724903`, 0.40572653033123346`, 0.9389371983813526]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 386}], {
             RGBColor[
             0.30804388160308127`, 0.43827326520037213`, 0.9409576635272863]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 74}], {
             RGBColor[
             0.6564460490256175, 0.7292165790501876, 0.9679963956135333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 97}], {
             RGBColor[
             0.46525153460871527`, 0.5764515941781216, 0.9511282282884884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 100}], {
             RGBColor[
             0.4324163535905058, 0.5480114107243323, 0.9490359995890186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 132}], {
             RGBColor[
             0.6437204915353074, 0.7192373735289359, 0.9667380893382732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 140}], {
             RGBColor[
             0.5800718085263902, 0.6695145386144623, 0.9603941834467046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 141}], {
             RGBColor[
             0.42414128450553, 0.540843961799992, 0.9485087195042803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 168}], {
             RGBColor[
             0.5791845558214077, 0.6688214100579597, 0.9603057503889199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 191}], {
             RGBColor[
             0.5835359920161374, 0.6722207850854224, 0.9607394608823273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 216}], {
             RGBColor[
             0.5736600979558795, 0.6645056615859741, 0.959755124057878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 219}], {
             RGBColor[
             0.4677032328653056, 0.5785751319820428, 0.9512844483334466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 220}], {
             RGBColor[
             0.4818265682663484, 0.5902075400149862, 0.9523502989242535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 350}], {
             RGBColor[
             0.4604806861717529, 0.5723193250518395, 0.9508242340447808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 357}], {
             RGBColor[
             0.5819543622257783, 0.6709852038723623, 0.9605818188059951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 394}], {
             RGBColor[
             0.42354328649608, 0.5403260059804602, 0.948470615599907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 75}], {
             RGBColor[
             0.2609941288153654, 0.3916517557414475, 0.9381746015785979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 103}], {
             RGBColor[
             0.3111881460301813, 0.44109703206764383`, 0.9411543384931023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 133}], {
             RGBColor[
             0.28753417910083867`, 0.4195470313278583, 0.9396860181798696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.2579170969731607, 0.3884176001802034, 0.937999369167245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 164}], {
             RGBColor[
             0.26017432145076, 0.3907900862224582, 0.9381279147619799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 227}], {
             RGBColor[
             0.25636607330828476`, 0.3867873759678386, 0.9379110406640643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 234}], {
             RGBColor[
             0.30827476436067847`, 0.438573607296341, 0.9409687003893238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 280}], {
             RGBColor[
             0.2584116720913199, 0.38893742998726233`, 0.9380275344885658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 346}], {
             RGBColor[
             0.3114210735342079, 0.4412987821643549, 0.9411691804276892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 79}], {
             RGBColor[
             0.730962985173496, 0.7893766931257962, 0.9742494771038676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 109}], {
             RGBColor[
             0.932608231427341, 0.9459491066410988, 0.8675350166916449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 120}], {
             RGBColor[
             0.7187491637803132, 0.7794609626924269, 0.9732879603430942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 143}], {
             RGBColor[
             0.7478821300066041, 0.8031124171001021, 0.9755814141619994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 237}], {
             RGBColor[
             0.7247695222504801, 0.7843485609125668, 0.9737619050151656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 286}], {
             RGBColor[
             0.798684946393064, 0.8430713308000524, 0.9804594287308144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 320}], {
             RGBColor[
             0.7905070166194959, 0.8366826699063725, 0.9796443291180839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 321}], {
             RGBColor[
             0.8444532383444727, 0.878825868324395, 0.985021184343525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 343}], {
             RGBColor[
             0.7966602927353739, 0.841489655974727, 0.98025763017568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 382}], {
             RGBColor[
             0.8849504676641144, 0.7666705508963009, 0.612411028914603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 119}], {
             RGBColor[
             0.2341124382405141, 0.36339739454965503`, 0.9366437290682574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 200}], {
             RGBColor[
             0.24919308184682543`, 0.37924810714791846`, 0.937502549411824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 288}], {
             RGBColor[
             0.2363762501862872, 0.36577680443863003`, 0.9367726498095597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 341}], {
             RGBColor[
             0.22465511090045148`, 0.353457143886063, 0.936105148267103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 355}], {
             RGBColor[
             0.2293238377834227, 0.358364271854447, 0.9363710253563257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 374}], {
             RGBColor[
             0.25191511783451104`, 0.3821091395580259, 0.9376575653344313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 375}], {
             RGBColor[
             0.24128592482540645`, 0.37093718377569584`, 0.9370522485170447]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 379}], {
             RGBColor[
             0.22434193474233927`, 0.3531279758873717, 0.9360873133482011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 393}], {
             RGBColor[
             0.22527325394479547`, 0.3541068514182011, 0.9361403505990177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 399}], {
             RGBColor[
             0.23130276285488832`, 0.3604442475756538, 0.9364837222115884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 85}], {
             RGBColor[
             0.24221172142071856`, 0.3719102546962633, 0.9371049712635544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 96}], {
             RGBColor[
             0.26501373249139615`, 0.3958766140625488, 0.9384035120614771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 110}], {
             RGBColor[
             0.24934696023893294`, 0.3794098430944771, 0.9375113125586119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 115}], {
             RGBColor[
             0.24086103809529086`, 0.3704906008829697, 0.9370280518463283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 184}], {
             RGBColor[
             0.230439447723778, 0.35953684863551605`, 0.9364345576920319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 188}], {
             RGBColor[
             0.2551009475473486, 0.3854576485794885, 0.9378389936235647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 195}], {
             RGBColor[
             0.2444053413712617, 0.37421588834782205`, 0.937229894674568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 203}], {
             RGBColor[
             0.2672567761777972, 0.39823419519414005`, 0.9385312500811318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 206}], {
             RGBColor[
             0.23733902327111464`, 0.366788739994123, 0.9368274783124455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 208}], {
             RGBColor[
             0.23810134733460236`, 0.3675899909189858, 0.9368708915401036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 258}], {
             RGBColor[
             0.2480246190771097, 0.3780199786921288, 0.9374360071856744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 284}], {
             RGBColor[
             0.24355703331110456`, 0.3733242627907594, 0.9371815847855014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 348}], {
             RGBColor[
             0.2530355996274438, 0.3832868369650472, 0.9377213751149346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 369}], {
             RGBColor[
             0.2502849628040927, 0.38039574326325765`, 0.9375647304170474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 392}], {
             RGBColor[
             0.24553259442115521`, 0.3754007027752315, 0.9372940900681379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 132}], {
             RGBColor[
             0.8119479189165777, 0.8530570556731545, 0.981880980170774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 140}], {
             RGBColor[
             0.7482992359076605, 0.8033342207586809, 0.9755370742792053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 191}], {
             RGBColor[
             0.7517634193974077, 0.8060404672296411, 0.9758823517148281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 198}], {
             RGBColor[
             0.8255815527613636, 0.8637603366303892, 0.9832258995793732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 216}], {
             RGBColor[
             0.7418875253371497, 0.7983253437301927, 0.9748980148903788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 219}], {
             RGBColor[
             0.6359306602465759, 0.7123948141262615, 0.9664273391659474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 220}], {
             RGBColor[
             0.6500539956476187, 0.724027222159205, 0.9674931897567542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 224}], {
             RGBColor[
             0.9001674923644503, 0.8962994775971298, 0.6715446357629462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 302}], {
             RGBColor[
             0.9059752552459537, 0.9158904255240137, 0.6941066978535942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 311}], {
             RGBColor[
             0.6720237576353845, 0.741863264667372, 0.9692227298983209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 323}], {
             RGBColor[
             0.8274418605794372, 0.8652436955878107, 0.9834033373997775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 340}], {
             RGBColor[
             0.9092258023331339, 0.9260683158029884, 0.7736525641500547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 357}], {
             RGBColor[
             0.7501817896070486, 0.8048048860165811, 0.9757247096384958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 89}], {
             RGBColor[
             0.23138047401831524`, 0.3605259269355878, 0.9364881477473821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 133}], {
             RGBColor[
             0.27071817278007254`, 0.4018723424883518, 0.9387283714969541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 145}], {
             RGBColor[
             0.24110109065239455`, 0.37074291134069687`, 0.9370417224843294]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.24457568603401603`, 0.37439493138885227`, 0.9372395955511095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 164}], {
             RGBColor[
             0.2433583151299939, 0.3731153973829517, 0.9371702680790643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 169}], {
             RGBColor[
             0.2324382955275915, 0.3616377644115946, 0.9365483891174288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 209}], {
             RGBColor[
             0.24810555583118551`, 0.37810504835234904`, 0.9374406164140838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 227}], {
             RGBColor[
             0.2395500669875186, 0.36911268712833206`, 0.9369533939811485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 280}], {
             RGBColor[
             0.24159566577055375`, 0.3712627411477558, 0.9370698878056503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 315}], {
             RGBColor[
             0.24372617436870905`, 0.3735020407664642, 0.9371912171185102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[
             0.8904092616611533, 0.5686904524165735, 0.22911954666558126`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 109}], {
             RGBColor[
             0.9205204428847344, 0.6768339136433675, 0.4700439928721189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 138}], {
             RGBColor[
             0.8331436561867612, 0.2557622418600043, 0.17937170863583543`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 144}], {
             RGBColor[
             0.8626912709570241, 0.4513693690163807, 0.2064327327986027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 207}], {
             RGBColor[
             0.8934001271128089, 0.5805482372855583, 0.23152606721261854`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 233}], {
             RGBColor[
             0.8322013343184957, 0.24851914305244047`, 0.17846934015058413`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 242}], {
             RGBColor[
             0.8826456379438963, 0.5379102714518893, 0.22287275278700588`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 257}], {
             RGBColor[
             0.8347758028344946, 0.2683076362057045, 0.1809346541089509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 317}], {
             RGBColor[
             0.9187857495623798, 0.676116573374989, 0.49879235046594833`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 358}], {
             RGBColor[
             0.9077605542707283, 0.6337524810989443, 0.26250704350549825`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 366}], {
             RGBColor[
             0.8741124408312237, 0.5032302339331254, 0.2159628369001264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 382}], {
             RGBColor[
             0.8728626791215081, 0.4975553578985697, 0.2149200050950769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 78}], {
             RGBColor[
             0.8356045267952863, 0.5947068735494174, 0.5856449487468838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 102}], {
             RGBColor[
             0.8243310697046711, 0.5080541422905515, 0.574849473505362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 111}], {
             RGBColor[
             0.8517216279012312, 0.6939386797204187, 0.6001134200588495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 160}], {
             RGBColor[
             0.8294213428991457, 0.5471802126352212, 0.5797239248650322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 166}], {
             RGBColor[
             0.827067103969575, 0.529084500588463, 0.5774695030073427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 185}], {
             RGBColor[
             0.8265277938578538, 0.5249391267425765, 0.5769530590352949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 370}], {
             RGBColor[
             0.8302908639224114, 0.8675154135193626, 0.9836750778819656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 389}], {
             RGBColor[
             0.5042266153181847, 0.5861702959978048, 0.9585484769989704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 400}], {
             RGBColor[
             0.6094880057982189, 0.6893301781287484, 0.9648167092401694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 102}], {
             RGBColor[
             0.8305704924938522, 0.23598377814878552`, 0.17690764417753302`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 144}], {
             RGBColor[
             0.8601410277678558, 0.4317670823407418, 0.2039906170405674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 160}], {
             RGBColor[
             0.835660765688327, 0.2751098484934552, 0.18178209553720334`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 185}], {
             RGBColor[
             0.832767216647035, 0.2528687626008105, 0.17901122970746597`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 207}], {
             RGBColor[
             0.8908498839236407, 0.5609459506099194, 0.22908395145458324`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 213}], {
             RGBColor[
             0.8764060316711535, 0.5036808895572449, 0.2174620888914447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 230}], {
             RGBColor[
             0.9053505911840212, 0.6146233921482407, 0.26060988945584945`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 247}], {
             RGBColor[
             0.874425744599943, 0.49582971121144337`, 0.21586870343063702`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 289}], {
             RGBColor[
             0.8697986288874946, 0.4756199934349731, 0.21204915614425965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 370}], {
             RGBColor[
             0.8365302867115927, 0.5954450493775967, 0.5857332485541368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 391}], {
             RGBColor[
             0.8311173699138001, 0.24018731764171894`, 0.1774313346124849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 400}], {
             RGBColor[
             0.6157274285874001, 0.4172598139869824, 0.5668748799123404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 109}], {
             RGBColor[
             0.79245120355282, 0.8352543310125031, 0.854215095221335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 120}], {
             RGBColor[
             0.5785921359057922, 0.6687661870638313, 0.9599680388727843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 136}], {
             RGBColor[
             0.6046940354323059, 0.6899568849766287, 0.9620228760179198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 237}], {
             RGBColor[
             0.5846124943759591, 0.6736537852839712, 0.9604419835448554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 246}], {
             RGBColor[
             0.5173044068287108, 0.618751689159956, 0.9552146295473145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 254}], {
             RGBColor[
             0.5301586737259505, 0.6294457205636295, 0.9561551793123693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 286}], {
             RGBColor[
             0.658527918518543, 0.7323765551714567, 0.9671395072605043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 320}], {
             RGBColor[
             0.6503499887449748, 0.725987894277777, 0.9663244076477739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 343}], {
             RGBColor[
             0.6565032648608529, 0.7307948803461315, 0.9669377087053699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 349}], {
             RGBColor[
             0.518092548976322, 0.6194343382750406, 0.9552648492680336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 87}], {
             RGBColor[
             0.3122775575094636, 0.4431804871474425, 0.9411820189118731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 96}], {
             RGBColor[
             0.31066394327551555`, 0.4414844762785116, 0.9410901259683782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 110}], {
             RGBColor[
             0.29499717102305234`, 0.4250177053104399, 0.9401979264655129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 146}], {
             RGBColor[
             0.4348738177323767, 0.548860724677587, 0.9495460387678236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 154}], {
             RGBColor[
             0.38228721374237734`, 0.5055397030547701, 0.9455799811097223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 159}], {
             RGBColor[
             0.3329254963503931, 0.4627850644418876, 0.9424346961263579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 167}], {
             RGBColor[
             0.30898293281547473`, 0.43971762770278966`, 0.9409943949095109]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 192}], {
             RGBColor[
             0.3394530711598287, 0.46843892165637124`, 0.9428506274211075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 201}], {
             RGBColor[
             0.30542134246892777`, 0.4359741704306982, 0.9407915676081757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 203}], {
             RGBColor[
             0.31290698696191654`, 0.4438420574101029, 0.9412178639880329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 228}], {
             RGBColor[
             0.35113678778418134`, 0.4785587697557132, 0.9435951035129062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 243}], {
             RGBColor[
             0.3113941751763021, 0.44225199630561496`, 0.9411317115948465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 332}], {
             RGBColor[
             0.4308190028061351, 0.5455688432531333, 0.9492268288835535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 348}], {
             RGBColor[
             0.2986858104115632, 0.42889469918101, 0.9404079890218355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 361}], {
             RGBColor[
             0.34502145958500996`, 0.47326197983492335`, 0.9432054402076274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 385}], {
             RGBColor[
             0.4549187217473041, 0.5651340807695402, 0.9511240470387816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 89}], {
             RGBColor[
             0.21914913629591037`, 0.3476700154777373, 0.9357915911587338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 163}], {
             RGBColor[
             0.23234434831161116`, 0.36153901993100174`, 0.9365430389624612]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 169}], {
             RGBColor[
             0.22020695780518662`, 0.3487818529537441, 0.9358518325287805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 209}], {
             RGBColor[
             0.23587421810878062`, 0.36524913689449845`, 0.9367440598254355]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 227}], {
             RGBColor[
             0.2273187292651137, 0.35625677567048153`, 0.9362568373925002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 240}], {
             RGBColor[
             0.22946097871463872`, 0.3585084156683923, 0.9363788353294766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 245}], {
             RGBColor[
             0.22480714766170556`, 0.3536169441618284, 0.9361138065357382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 248}], {
             RGBColor[
             0.21796166804011632`, 0.3464219110510618, 0.9357239665982682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 292}], {
             RGBColor[
             0.21536706305033604`, 0.3436948166993449, 0.9355762076824743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 304}], {
             RGBColor[
             0.21940694053557647`, 0.34794098407935925`, 0.9358062727287957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 315}], {
             RGBColor[
             0.23149483664630416`, 0.3606461293086136, 0.9364946605298619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 329}], {
             RGBColor[
             0.22742713619850993`, 0.35637071823087746`, 0.9362630110069835]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 353}], {
             RGBColor[
             0.2150475477536689, 0.34335898586410785`, 0.9355580117590097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 378}], {
             RGBColor[
             0.21412094136701804`, 0.3423850638014996, 0.9355052428960813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 151}], {
             RGBColor[
             0.34752633634939933`, 0.4754315781894705, 0.9433650487400788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 157}], {
             RGBColor[
             0.4242304983845992, 0.5414364441367214, 0.9483720501423687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 171}], {
             RGBColor[
             0.32621487078886763`, 0.45368735101725755`, 0.9421273921767691]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 182}], {
             RGBColor[
             0.3336557333984177, 0.4615081693978327, 0.9425511382946132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 253}], {
             RGBColor[
             0.3604664667584644, 0.48663966875993736`, 0.9441895824072364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 108}], {
             RGBColor[
             0.3602253738682746, 0.48643084621613597`, 0.9441742201814636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 120}], {
             RGBColor[
             0.45962999176153224`, 0.5694602774020465, 0.9513564039568587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 125}], {
             RGBColor[
             0.315433813888692, 0.4447906722692076, 0.9414242734794431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 179}], {
             RGBColor[
             0.3112624132414147, 0.4404062657068423, 0.9411867183836149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 196}], {
             RGBColor[
             0.32540289254677246`, 0.4552688060149441, 0.9419919977610904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 231}], {
             RGBColor[
             0.3307828964588674, 0.4609235312385056, 0.9422983810248817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 237}], {
             RGBColor[
             0.4656503502316991, 0.5743478756221865, 0.9518303486289299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 246}], {
             RGBColor[
             0.39834226268445083`, 0.5194457794981713, 0.946602994631389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 254}], {
             RGBColor[
             0.4111965295816905, 0.5301398109018447, 0.9475435443964437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 303}], {
             RGBColor[
             0.32124670467921895`, 0.4509003890486145, 0.9417553090105623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 313}], {
             RGBColor[
             0.31784501109874064`, 0.44732499341570175`, 0.9415615875935087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 344}], {
             RGBColor[
             0.33675515918736176`, 0.4661021259068189, 0.9426787188558917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 349}], {
             RGBColor[
             0.3991304048320619, 0.5201284286132558, 0.946653214352108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.44236640792617826`, 0.5377470693075241, 0.9524063925246276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 152}], {
             RGBColor[
             0.18127159018880934`, 0.30785831294404253`, 0.9336345209427424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 156}], {
             RGBColor[
             0.18244327672263497`, 0.3090898297803102, 0.9337012467574888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 175}], {
             RGBColor[
             0.1789295778879611, 0.3053967095236947, 0.9335011468069058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 204}], {
             RGBColor[
             0.17892700714738574`, 0.30539400751235557`, 0.933501000407033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 256}], {
             RGBColor[
             0.20211768989058865`, 0.32976888544967253`, 0.9348216754817178]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 261}], {
             RGBColor[
             0.17918769193352976`, 0.30566800375096304`, 0.9335158460199553]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 264}], {
             RGBColor[
             0.18447901438019912`, 0.31122951913163255`, 0.9338171790054831]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 317}], {
             RGBColor[
             0.5847770387283635, 0.6478930395078799, 0.8692491754054186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 333}], {
             RGBColor[
             0.18724373492288626`, 0.3141354157154036, 0.9339746257503516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 381}], {
             RGBColor[
             0.5860370216699882, 0.6484140748343261, 0.8483679973313716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 389}], {
             RGBColor[
             0.1790075704625178, 0.3054786846645686, 0.933505588368647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 96}], {
             RGBColor[
             0.2641094772748117, 0.3949261844968264, 0.9383520160646184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 110}], {
             RGBColor[
             0.2484427050223485, 0.37845941352875473`, 0.9374598165617531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 115}], {
             RGBColor[
             0.2399567828787064, 0.36954017131724737`, 0.9369765558494695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 139}], {
             RGBColor[
             0.2262390695271757, 0.3551219848315275, 0.9361953523676381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 167}], {
             RGBColor[
             0.2624284668147709, 0.39315933592110447`, 0.9382562850057511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 184}], {
             RGBColor[
             0.22953519250719354`, 0.35858641906979366`, 0.9363830616951732]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 188}], {
             RGBColor[
             0.25419669233076414`, 0.38450721901376617`, 0.937787497626706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 203}], {
             RGBColor[
             0.2663525209612127, 0.3972837656284177, 0.9384797540842731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 258}], {
             RGBColor[
             0.24712036386052527`, 0.3770695491264064, 0.9373845111888157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 284}], {
             RGBColor[
             0.24265277809452013`, 0.37237383322503703`, 0.9371300887886426]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 325}], {
             RGBColor[
             0.22643759197523877`, 0.355330644511492, 0.9362066579273677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 348}], {
             RGBColor[
             0.2521313444108594, 0.3823364073993248, 0.9376698791180758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 351}], {
             RGBColor[
             0.24352597864269326`, 0.37329162236527946`, 0.9371798162680766]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 369}], {
             RGBColor[
             0.24938070758750824`, 0.3794453136975352, 0.9375132344201885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 95}], {
             RGBColor[
             0.2911574427094625, 0.42335531110870317`, 0.9398923576822427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 151}], {
             RGBColor[
             0.30818593638346986`, 0.44059786327207706`, 0.9408861053327038]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[
             0.27226239938534696`, 0.40349542256011695`, 0.9388163129176459]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 229}], {
             RGBColor[
             0.27371625819309475`, 0.4050235203470323, 0.9388991080259558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 249}], {
             RGBColor[
             0.2850528182511259, 0.41693896374744543`, 0.939544708350323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 308}], {
             RGBColor[
             0.28081236703944734`, 0.4124819806638359, 0.9393032209270034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 309}], {
             RGBColor[
             0.28566340206902835`, 0.417580726053311, 0.9395794801954747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 334}], {
             RGBColor[
             0.28096769579564274`, 0.4126452410350092, 0.9393120666698803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 371}], {
             RGBColor[
             0.2862909803459218, 0.418240350613087, 0.9396152198499249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 386}], {
             RGBColor[
             0.31994974783175406`, 0.4507870854822257, 0.9416356849958585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 110}], {
             RGBColor[
             0.27285833032697415`, 0.4041217837639711, 0.9388502503031707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 134}], {
             RGBColor[
             0.26223279186396886`, 0.39295366914130303`, 0.9382451416067781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 159}], {
             RGBColor[
             0.3107866556543149, 0.4418891428954188, 0.9410870199640158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 167}], {
             RGBColor[
             0.28684409211939654`, 0.41882170615632086`, 0.9396467187471687]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 192}], {
             RGBColor[
             0.3173142304637505, 0.44754300010990244`, 0.9415029512587653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 201}], {
             RGBColor[
             0.2832825017728496, 0.4150782488842294, 0.9394438914458336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 210}], {
             RGBColor[
             0.2950312133683537, 0.42742688968244336`, 0.9401129631905363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 228}], {
             RGBColor[
             0.32899794708810315`, 0.4576628482092444, 0.9422474273505641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 236}], {
             RGBColor[
             0.2703304585010046, 0.4014648301985463, 0.938706291742333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 243}], {
             RGBColor[
             0.2892553344802239, 0.4213560747591461, 0.9397840354325044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 263}], {
             RGBColor[
             0.2761111635451054, 0.407540717717765, 0.9390354943428079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 348}], {
             RGBColor[
             0.27654696971548504`, 0.4079987776345412, 0.9390603128594934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 351}], {
             RGBColor[
             0.2679416039473189, 0.3989539926004958, 0.9385702500094941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[
             0.8934147061054667, 0.915612925432826, 0.8952711863200087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 132}], {
             RGBColor[
             0.8947680641910523, 0.9166701790551881, 0.8954060764061295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 140}], {
             RGBColor[
             0.8311193811821351, 0.8669473441407145, 0.8890621705145608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 168}], {
             RGBColor[
             0.8302321284771527, 0.8662542155842119, 0.8889737374567761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 282}], {
             RGBColor[
             0.8185877701205739, 0.8571575543356513, 0.887813136638508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 283}], {
             RGBColor[
             0.9496145330722283, 0.8334245259791293, 0.5278793972462171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 357}], {
             RGBColor[
             0.8330019348815232, 0.8684180093986145, 0.8892498058738514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 163}], {
             RGBColor[
             0.23177803755773202`, 0.36094379142249916`, 0.9365107884028094]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 164}], {
             RGBColor[
             0.2305606666537099, 0.3596642574165986, 0.9364414609307642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 169}], {
             RGBColor[
             0.2196406470513075, 0.3481866244452415, 0.9358195819691286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 209}], {
             RGBColor[
             0.23530790735490154`, 0.3646539083859959, 0.9367118092657838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 227}], {
             RGBColor[
             0.22675241851123462`, 0.35566154716197895`, 0.9362245868328485]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 245}], {
             RGBColor[
             0.22424083690782642`, 0.3530217156533258, 0.9360815559760864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.22879801729426974`, 0.3578116011814027, 0.9363410806573501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 292}], {
             RGBColor[
             0.21480075229645693`, 0.3430995881908423, 0.9355439571228226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 304}], {
             RGBColor[
             0.21884062978169738`, 0.3473457555708567, 0.9357740221691438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 315}], {
             RGBColor[
             0.23092852589242507`, 0.36005090080011104`, 0.93646240997021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 329}], {
             RGBColor[
             0.22686082544463082`, 0.3557754897223749, 0.9362307604473317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 353}], {
             RGBColor[
             0.21448123699978983`, 0.34276375735560527`, 0.9355257611993579]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 378}], {
             RGBColor[
             0.2135546306131389, 0.341789835292997, 0.9354729923364294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 138}], {
             RGBColor[
             0.7625743389841517, 0.45989176227570816`, 0.5687339252858672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 142}], {
             RGBColor[
             0.763694887526314, 0.46850478939826945`, 0.5698069638353204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 152}], {
             RGBColor[
             0.4447109838202162, 0.5402113672268555, 0.9525399126533038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 156}], {
             RGBColor[
             0.4458826703540418, 0.5414428840631231, 0.9526066384680504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 175}], {
             RGBColor[
             0.44236897151936794`, 0.5377497638065076, 0.9524065385174674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 202}], {
             RGBColor[
             0.7810727137045386, 0.6020783764160916, 0.5864479898090358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 242}], {
             RGBColor[
             0.8120763207412868, 0.7420397918675932, 0.6122349694370377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 256}], {
             RGBColor[
             0.46555708352199543`, 0.5621219397324855, 0.9537270671922793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[
             0.7642064856318851, 0.4724371566214084, 0.5702968707589827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 261}], {
             RGBColor[
             0.4426270855649366, 0.538021058033776, 0.9524212377305169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 264}], {
             RGBColor[
             0.44791840801160593`, 0.5435825734144455, 0.9527225707160447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 268}], {
             RGBColor[
             0.7615624007787926, 0.45211356179516854`, 0.5677648921175946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 317}], {
             RGBColor[
             0.8482164323597703, 0.8802460937906929, 0.8881545671159801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 333}], {
             RGBColor[
             0.4506831285542931, 0.5464884699982167, 0.9528800174609131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 381}], {
             RGBColor[
             0.849476415301395, 0.8807671291171392, 0.8672733890419332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 141}], {
             RGBColor[
             0.3113425799408942, 0.43982647528346147`, 0.9412155979078848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 150}], {
             RGBColor[
             0.2666109948635128, 0.3975554380879269, 0.9384944737906311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 186}], {
             RGBColor[
             0.2555444422624831, 0.38592378964428387`, 0.9378642499915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 189}], {
             RGBColor[
             0.28158397795101814`, 0.4132929926548542, 0.9393471630269211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 190}], {
             RGBColor[
             0.25186209923856306`, 0.38205341365211143`, 0.9376545460038261]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 226}], {
             RGBColor[
             0.25062761976227643`, 0.38075589745201466`, 0.9375842442239002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 241}], {
             RGBColor[
             0.2767915804260243, 0.40825587900053273`, 0.9390742430775896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 255}], {
             RGBColor[
             0.26154809523840944`, 0.39223400957556664`, 0.9382061491468703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 266}], {
             RGBColor[
             0.25880957199136756`, 0.38935564801052325`, 0.9380501942992334]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 273}], {
             RGBColor[
             0.26902930475390907`, 0.40009723511243644`, 0.9386321929613204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 365}], {
             RGBColor[
             0.259430965008946, 0.3900087714705911, 0.9380855817123159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 114}], {
             RGBColor[
             0.3082708613262549, 0.43948126919774927`, 0.9409350939621447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 153}], {
             RGBColor[
             0.30254730129756563`, 0.4345238091753902, 0.940570393778262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 161}], {
             RGBColor[
             0.35955024405905767`, 0.48389689314418627`, 0.9442025708853012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 188}], {
             RGBColor[
             0.27737488016395806`, 0.40886896400844064`, 0.9391074611347503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 195}], {
             RGBColor[
             0.26667927398787117`, 0.3976272037767742, 0.9384983621857534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 258}], {
             RGBColor[
             0.2702985516937192, 0.40143129412108086`, 0.93870447469686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 278}], {
             RGBColor[
             0.2700397327532974, 0.4011592590046289, 0.9386897353410912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 284}], {
             RGBColor[
             0.26583096592771405`, 0.3967355782197115, 0.9384500522966869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 327}], {
             RGBColor[
             0.3031279877877182, 0.4350267706270088, 0.9406073946079336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 337}], {
             RGBColor[
             0.2862035870447653, 0.41814849471251614`, 0.9396102429307109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 354}], {
             RGBColor[
             0.2837186388686095, 0.41553665662456213`, 0.9394687288082302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 392}], {
             RGBColor[
             0.26780652703776464`, 0.39881201820418366`, 0.9385625575793235]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 94}], {
             RGBColor[
             0.2526810398598759, 0.3829141721689455, 0.9377011834606958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 119}], {
             RGBColor[
             0.24286823945996167`, 0.3726002967811557, 0.9371423589946579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 128}], {
             RGBColor[
             0.2857256322546389, 0.41603117628641406`, 0.9396421556226617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 225}], {
             RGBColor[
             0.25117310830966183`, 0.38132924050128825`, 0.9376153089896959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 296}], {
             RGBColor[
             0.27337982614775685`, 0.40466990893635857`, 0.9388799487186803]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 301}], {
             RGBColor[
             0.25102800874557624`, 0.38117673165959054`, 0.9376070457841768]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 316}], {
             RGBColor[
             0.2497588091651779, 0.37984272242869066`, 0.9375347667456857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 324}], {
             RGBColor[
             0.26259788296436154`, 0.3933374030359285, 0.9382659330048415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 355}], {
             RGBColor[
             0.23807963900287032`, 0.36756717408594775`, 0.936869655282726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 380}], {
             RGBColor[
             0.25536438822798396`, 0.38573454143794017`, 0.9378539961806014]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 383}], {
             RGBColor[
             0.2627372188358315, 0.39348385387124796`, 0.9382738679765928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 390}], {
             RGBColor[
             0.2557686929307827, 0.3861594913149804, 0.9378770207353105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 119}], {
             RGBColor[
             0.25031116778183593`, 0.38042328635635736`, 0.9375662227517629]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 128}], {
             RGBColor[
             0.29316856057651314`, 0.42385416586161573`, 0.9400660193797667]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 177}], {
             RGBColor[
             0.29101623446385616`, 0.4219899291618881, 0.9399288750630955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 200}], {
             RGBColor[
             0.26539181138814727`, 0.3962739989546208, 0.9384250430953294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 225}], {
             RGBColor[
             0.2586160366315361, 0.3891522300764899, 0.9380391727468009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 288}], {
             RGBColor[
             0.25257497972760906`, 0.38280269624533236`, 0.9376951434930652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 296}], {
             RGBColor[
             0.2808227544696311, 0.4124928985115602, 0.9393038124757853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 316}], {
             RGBColor[
             0.25720173748705216`, 0.38766571200389227`, 0.9379586305027907]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 324}], {
             RGBColor[
             0.2700408112862358, 0.4011603926111301, 0.9386897967619465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 355}], {
             RGBColor[
             0.2455225673247446, 0.37539016366114936`, 0.937293519039831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 375}], {
             RGBColor[
             0.25748465436672835`, 0.3879630755823982, 0.9379747422005502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 380}], {
             RGBColor[
             0.2628073165498582, 0.39355753101314184`, 0.9382778599377064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 383}], {
             RGBColor[
             0.2701801471577058, 0.4013068434464496, 0.9386977317336979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 390}], {
             RGBColor[
             0.26321162125265696`, 0.393982480890182, 0.9383008844924156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 129}], {
             RGBColor[
             0.2597315005548766, 0.39032465338441835`, 0.9381026967670542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 151}], {
             RGBColor[
             0.2988070240901653, 0.4307400317944288, 0.9403519901524575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 178}], {
             RGBColor[
             0.2628834870920424, 0.39363759108246865`, 0.9382821977373995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 229}], {
             RGBColor[
             0.2643373458997902, 0.3951656888693841, 0.9383649928457094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 249}], {
             RGBColor[
             0.2756739059578213, 0.4070811322697972, 0.9390105931700766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 270}], {
             RGBColor[
             0.26568283896088996`, 0.3965798873857872, 0.9384416166850604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 308}], {
             RGBColor[
             0.2714334547461428, 0.4026241491861876, 0.9387691057467569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 309}], {
             RGBColor[
             0.2762844897757238, 0.4077228945756627, 0.9390453650152284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 334}], {
             RGBColor[
             0.27158878350233817`, 0.4027874095573609, 0.9387779514896339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 371}], {
             RGBColor[
             0.27691206805261726`, 0.40838251913543877`, 0.9390811046696785]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 386}], {
             RGBColor[
             0.3105708355384495, 0.4409292540045774, 0.9411015698156122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 110}], {
             RGBColor[
             0.2712447160930261, 0.4024257728950402, 0.9387583573596757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 114}], {
             RGBColor[
             0.3078946845637386, 0.4390858835693603, 0.940913671252023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 115}], {
             RGBColor[
             0.262758793949384, 0.3935065306835328, 0.9382750966473921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 153}], {
             RGBColor[
             0.3021711245350493, 0.4341284235470012, 0.9405489710681403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 154}], {
             RGBColor[
             0.3585347588123511, 0.48294777063937044`, 0.9441404120038852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 167}], {
             RGBColor[
             0.28523047788544853`, 0.41712569528738996`, 0.9395548258036737]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 188}], {
             RGBColor[
             0.2769987034014417, 0.4084735783800516, 0.9390860384246287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 192}], {
             RGBColor[
             0.3157006162298024, 0.44584698924097155`, 0.9414110583152703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 203}], {
             RGBColor[
             0.28915453203189034`, 0.42125012499470316`, 0.9397782948821958]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 228}], {
             RGBColor[
             0.3273843328541551, 0.4559668373403135, 0.9421555344070691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 243}], {
             RGBColor[
             0.2876417202462759, 0.4196600638902152, 0.9396921424890095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 258}], {
             RGBColor[
             0.26992237493120286`, 0.4010359084926919, 0.9386830519867384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 284}], {
             RGBColor[
             0.2654547891651977, 0.3963401925913225, 0.9384286295865651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 348}], {
             RGBColor[
             0.27493335548153697`, 0.4063027667656103, 0.9389684199159984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 361}], {
             RGBColor[
             0.32126900465498376`, 0.45067004741952366`, 0.9417658711017902]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 369}], {
             RGBColor[
             0.27218271865818583`, 0.40341167306382075`, 0.9388117752181111]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 100}], {
             RGBColor[
             0.4094492665548738, 0.5290661079964851, 0.9473107230964745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 105}], {
             RGBColor[
             0.42981427861771465`, 0.5467052578700499, 0.9486083636570456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 112}], {
             RGBColor[
             0.38560280932821134`, 0.5084115053045399, 0.9457912479285857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 132}], {
             RGBColor[
             0.6207534044996754, 0.7002920708010887, 0.965012812845729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 140}], {
             RGBColor[
             0.5571047214907582, 0.6505692358866151, 0.9586689069541604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 141}], {
             RGBColor[
             0.401174197469898, 0.5218986590721447, 0.9467834430117361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 168}], {
             RGBColor[
             0.5562174687857758, 0.6498761073301125, 0.9585804738963757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 180}], {
             RGBColor[
             0.40427723483543804`, 0.5245863540749827, 0.9469811658087601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 220}], {
             RGBColor[
             0.4588594812307164, 0.571262237287139, 0.9506250224317093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 282}], {
             RGBColor[
             0.5445731104291971, 0.6407794460815519, 0.9574198730781076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 350}], {
             RGBColor[
             0.437513599136121, 0.5533740223239922, 0.9490989575522366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 357}], {
             RGBColor[
             0.5589872751901463, 0.652039901144515, 0.958856542313451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 394}], {
             RGBColor[
             0.40057619946044803`, 0.521380703252613, 0.9467453391073628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 107}], {
             RGBColor[
             0.9083938909149378, 0.6192253386491839, 0.2762763560175848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 131}], {
             RGBColor[
             0.9500181408117219, 0.8331560489585412, 0.3119185917864623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 215}], {
             RGBColor[
             0.8984291495802124, 0.5426319701729883, 0.2667341084618861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 283}], {
             RGBColor[
             0.9432427006605664, 0.8062936865407971, 0.3064669136008217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 297}], {
             RGBColor[
             0.9621045612745434, 0.9478624391979251, 0.6712874553374975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 307}], {
             RGBColor[
             0.9814050384421338, 0.9620825967866911, 0.6308199289588313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 352}], {
             RGBColor[
             0.9858621188487648, 0.9629527205499828, 0.4862282141252213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 123}], {
             RGBColor[
             0.9762118677425246, 0.9817794304286422, 0.9251512823600752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 174}], {
             RGBColor[
             0.8533664925541351, 0.885559755956836, 0.9477463395066474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 187}], {
             RGBColor[
             0.9110307205751575, 0.9308010667922535, 0.953442401298972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 193}], {
             RGBColor[
             0.9002336063428361, 0.9221917409832586, 0.9524125629047955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[
             0.9440956875300477, 0.9571661739174645, 0.9565961673645738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 232}], {
             RGBColor[
             0.7518421224806613, 0.804458883314896, 0.9388506680687247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 235}], {
             RGBColor[
             0.8591106393434069, 0.8900471270857477, 0.9483188623764983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 275}], {
             RGBColor[
             0.9851141209349312, 0.987104803716967, 0.8512424005775606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 279}], {
             RGBColor[
             0.9618886205302903, 0.9027170726846294, 0.5985175369470697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 281}], {
             RGBColor[
             0.8050608246814849, 0.8476642232367373, 0.943040239252503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 306}], {
             RGBColor[
             0.9742518584397497, 0.947471002545973, 0.6306628392778444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 338}], {
             RGBColor[
             0.9862079875593082, 0.9866999578573392, 0.7708056942036536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 384}], {
             RGBColor[
             0.863277719993484, 0.893302482160574, 0.9487341980321153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 105}], {
             RGBColor[
             0.3969790975995051, 0.5182650744162607, 0.9465161349575758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 112}], {
             RGBColor[
             0.35276762831000186`, 0.47997132185075075`, 0.9436990192291159]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 141}], {
             RGBColor[
             0.3683390164516885, 0.49345847561835543`, 0.9446912143122663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 168}], {
             RGBColor[
             0.5233822877675662, 0.6214359238763232, 0.9564882451969059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 170}], {
             RGBColor[
             0.4107918604538279, 0.5302289953510277, 0.9473962719925066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 180}], {
             RGBColor[
             0.3714420538172285, 0.49614617062119337`, 0.9448889371092903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 220}], {
             RGBColor[
             0.42602430021250687`, 0.5428220538333498, 0.9485327937322395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 271}], {
             RGBColor[
             0.3417009842764249, 0.4702049097204598, 0.9430004912657755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 273}], {
             RGBColor[
             0.3260257412647034, 0.4537292354473304, 0.9421078093657018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 282}], {
             RGBColor[
             0.5117379294109875, 0.6123392626277626, 0.9553276443786378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 350}], {
             RGBColor[
             0.4046784181179114, 0.524933838870203, 0.9470067288527668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 394}], {
             RGBColor[
             0.3677410184422385, 0.49294051979882375`, 0.944653110407893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 151}], {
             RGBColor[
             0.2883386750076016, 0.41973713317698713`, 0.9397558331587401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 171}], {
             RGBColor[
             0.2670272094470698, 0.3979929060047742, 0.9385181765954305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 182}], {
             RGBColor[
             0.2744680720566198, 0.40581372438534935`, 0.9389419227132746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 244}], {
             RGBColor[
             0.2604390037563816, 0.39106828410749395`, 0.9381429880277227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 253}], {
             RGBColor[
             0.3012788054166666, 0.43094522374745403`, 0.9405803668258977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 270}], {
             RGBColor[
             0.2552144898783262, 0.38557698876834556`, 0.937845459691343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 308}], {
             RGBColor[
             0.26096510566357906`, 0.39162125056874597`, 0.9381729487530396]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 397}], {
             RGBColor[
             0.2550956906132599, 0.3854521232084524, 0.9378386942489454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 160}], {
             RGBColor[
             0.8243873085977117, 0.18845711723458924`, 0.17098662029568146`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 166}], {
             RGBColor[
             0.8220330696681408, 0.1703614051878311, 0.16873219843799186`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[
             0.8214937595564198, 0.16621603134194454`, 0.16821575446594406`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 213}], {
             RGBColor[
             0.8651325745805382, 0.41702815829837886`, 0.20666661364992278`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 224}], {
             RGBColor[
             0.8974792718626248, 0.5394468704448865, 0.26303107700793477`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 230}], {
             RGBColor[
             0.8940771340934058, 0.5279706608893748, 0.24981441421432754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 247}], {
             RGBColor[
             0.8631522875093278, 0.40917697995257735`, 0.2050732281891151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 250}], {
             RGBColor[
             0.9037621261807391, 0.5693653564012491, 0.505440590565607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 289}], {
             RGBColor[
             0.8585251717968794, 0.3889672621761071, 0.20125368090273776`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 302}], {
             RGBColor[
             0.9032870347441282, 0.5590378183717704, 0.2855931390985828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 340}], {
             RGBColor[
             0.9065375818313084, 0.569215708650745, 0.3651390053950433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 370}], {
             RGBColor[
             0.8252568296209774, 0.5087923181187306, 0.5749377733126149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 391}], {
             RGBColor[
             0.8198439128231849, 0.15353458638285297`, 0.16663585937096298`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 400}], {
             RGBColor[
             0.6044539714967849, 0.33060708272811645`, 0.5560794046708185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 108}], {
             RGBColor[
             0.3560676178251626, 0.48282960690648735`, 0.9439092916429558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 133}], {
             RGBColor[
             0.32091218999488846`, 0.4513176188145481, 0.9417081084114585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 143}], {
             RGBColor[
             0.48460520194471113`, 0.589510492500073, 0.9533849292372562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 223}], {
             RGBColor[
             0.3993166746191169, 0.5202694238127852, 0.9466707039440156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 231}], {
             RGBColor[
             0.3266251404157554, 0.4573222919288569, 0.942033452486374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 234}], {
             RGBColor[
             0.34165277525472826`, 0.4703441947830308, 0.9429907906209125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 290}], {
             RGBColor[
             0.3748499370785241, 0.4990979078169345, 0.9451060844172272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 313}], {
             RGBColor[
             0.31368725505562867`, 0.4437237541060531, 0.9412966590550009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 331}], {
             RGBColor[
             0.39832931347278433`, 0.519434563541872, 0.9466021695190721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 342}], {
             RGBColor[
             0.4739621782432806, 0.580870006396498, 0.9525470714247991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 346}], {
             RGBColor[
             0.3447990844282577, 0.4730693696510448, 0.9431912706592778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 109}], {
             RGBColor[
             0.9639852685830836, 0.8836832833010115, 0.5065761886025747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 138}], {
             RGBColor[
             0.8766084818851104, 0.4626116115176483, 0.21590390436629117`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 144}], {
             RGBColor[
             0.9061560966553733, 0.6582187386740248, 0.24296492852905843`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 205}], {
             RGBColor[
             0.9645712998383063, 0.8839256222853624, 0.49686413410326324`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 207}], {
             RGBColor[
             0.9368649528111581, 0.7873976069432023, 0.2680582629430743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 233}], {
             RGBColor[
             0.8756661600168449, 0.4553685127100845, 0.21500153588103987`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 358}], {
             RGBColor[
             0.9512253799690775, 0.8406018507565884, 0.299039239235954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 366}], {
             RGBColor[
             0.9175772665295729, 0.7100796035907695, 0.25249503263058215`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 382}], {
             RGBColor[
             0.9163275048198573, 0.7044047275562138, 0.25145220082553266`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 112}], {
             RGBColor[
             0.37313264037284266`, 0.49761047172431544`, 0.944996659789687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 113}], {
             RGBColor[
             0.6069298774587211, 0.6884337835985022, 0.9640833346207096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 148}], {
             RGBColor[
             0.520616067080279, 0.620721827134755, 0.9556738363326167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 155}], {
             RGBColor[
             0.3609448647521152, 0.4866656792120809, 0.9442342850410239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 168}], {
             RGBColor[
             0.5437472998304071, 0.6390750737498879, 0.957785885757477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 170}], {
             RGBColor[
             0.4311568725166687, 0.5478681452245924, 0.9486939125530778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 180}], {
             RGBColor[
             0.39180706588006936`, 0.513785320494758, 0.9461865776698615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 239}], {
             RGBColor[
             0.37092951443948974`, 0.4957022347731742, 0.9448562785533615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 271}], {
             RGBColor[
             0.36206599633926584`, 0.4878440595940245, 0.9442981318263466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 282}], {
             RGBColor[
             0.5321029414738284, 0.6299784125013272, 0.956625284939209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 326}], {
             RGBColor[
             0.37836717266856673`, 0.5021443605036287, 0.9453301995588554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 350}], {
             RGBColor[
             0.4250434301807523, 0.5425729887437677, 0.948304369413338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 394}], {
             RGBColor[
             0.38810603050507936`, 0.5105796696723884, 0.9459507509684641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.8938562482651202, 0.6317789737296462, 0.5786286100973383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 173}], {
             RGBColor[
             0.5874312139478495, 0.658182594689114, 0.9541358462016971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 197}], {
             RGBColor[
             0.9686231253627324, 0.9753622711647122, 0.9040752003743098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 204}], {
             RGBColor[
             0.563710908416439, 0.6332510496213667, 0.9527850098927306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 214}], {
             RGBColor[
             0.9661339552698273, 0.9742633398075717, 0.9422105594358144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 215}], {
             RGBColor[
             0.8838915069303948, 0.5551856052534505, 0.5690863625416396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 295}], {
             RGBColor[
             0.5954410834145789, 0.6666014753537031, 0.9545919964182874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 310}], {
             RGBColor[
             0.5655364837016175, 0.6351698449942476, 0.952888973704525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 345}], {
             RGBColor[
             0.5752211056493675, 0.6453489967018295, 0.953440498597335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 363}], {
             RGBColor[
             0.905503655257033, 0.714845634359743, 0.589529206598464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 131}], {
             RGBColor[
             0.8808419295941465, 0.5163805585259162, 0.22083043617809295`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 197}], {
             RGBColor[
             0.9139845567949747, 0.6460331456516251, 0.5106347906861869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 215}], {
             RGBColor[
             0.829252938362637, 0.22585647974036333`, 0.17564595285351675`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 297}], {
             RGBColor[
             0.892928350056968, 0.6310869487653001, 0.5801992997291281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 307}], {
             RGBColor[
             0.9122288272245584, 0.6453071063540661, 0.539731773350462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 352}], {
             RGBColor[
             0.9166859076311894, 0.6461772301173578, 0.39514005851685197`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 363}], {
             RGBColor[
             0.8508650866892753, 0.3855165088466559, 0.1960887969103411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 143}], {
             RGBColor[
             0.49610666284564264`, 0.5994724798522266, 0.954117792155521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 179}], {
             RGBColor[
             0.3186061180992342, 0.4467670137493473, 0.9416546527633719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 196}], {
             RGBColor[
             0.332746597404592, 0.4616295540574491, 0.9424599321408476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 231}], {
             RGBColor[
             0.3381266013166869, 0.4672842792810106, 0.9427663154046388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 234}], {
             RGBColor[
             0.3531542361556598, 0.4803061821351844, 0.9437236535391773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 290}], {
             RGBColor[
             0.3863513979794556, 0.5090598951690881, 0.945838947335492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 313}], {
             RGBColor[
             0.3251887159565602, 0.4536857414582067, 0.9420295219732657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 331}], {
             RGBColor[
             0.40983077437371584`, 0.5293965508940257, 0.9473350324373369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 342}], {
             RGBColor[
             0.48546363914421214`, 0.5908319937486516, 0.9532799343430639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 344}], {
             RGBColor[
             0.3440988640451813, 0.47246287394932385`, 0.9431466532356487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 136}], {
             RGBColor[
             0.8063392816861509, 0.8465292984919313, 0.8553084156056971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 205}], {
             RGBColor[
             0.9946824810618875, 0.9920690835121566, 0.737788580309801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 207}], {
             RGBColor[
             0.9669761340347394, 0.8955410681699965, 0.508982709149612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 233}], {
             RGBColor[
             0.9057773412404262, 0.5635119739368787, 0.4559259820875775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 286}], {
             RGBColor[
             0.8601731647723879, 0.8889489686867593, 0.8604250468482817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 320}], {
             RGBColor[
             0.8519952349988198, 0.8825603077930796, 0.8596099472355513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 343}], {
             RGBColor[
             0.8581485111146978, 0.8873672938614341, 0.8602232482931473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 358}], {
             RGBColor[
             0.9813365611926588, 0.9487453119833825, 0.5399636854424916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 366}], {
             RGBColor[
             0.9476884477531541, 0.8182230648175637, 0.4934194788371198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 382}], {
             RGBColor[
             0.9464386860434384, 0.8125481887830079, 0.4923766470320703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 115}], {
             RGBColor[
             0.2470920216969208, 0.3770397597154611, 0.9373828971445268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 134}], {
             RGBColor[
             0.24495240537755758`, 0.37479088730430044`, 0.9372610491604179]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 167}], {
             RGBColor[
             0.26956370563298526`, 0.40065892431931827`, 0.9386626263008084]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 192}], {
             RGBColor[
             0.30003384397733923`, 0.42938021827289985`, 0.940518858812405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 203}], {
             RGBColor[
             0.2734877597794271, 0.40478335402663146`, 0.9388860953793305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 243}], {
             RGBColor[
             0.2719749479938126, 0.4031932929221435, 0.9387999429861442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 348}], {
             RGBColor[
             0.25926658322907375`, 0.3898359957975386, 0.9380762204131332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 351}], {
             RGBColor[
             0.25066121746090764`, 0.3807912107634932, 0.9375861575631339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 369}], {
             RGBColor[
             0.2565159464057226, 0.38694490209574905`, 0.9379195757152459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 160}], {
             RGBColor[
             0.8517778667942718, 0.37434165466445646`, 0.19625056684916897`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 166}], {
             RGBColor[
             0.8494236278647009, 0.35624594261769826`, 0.19399614499147944`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.8488843177529799, 0.35210056877181173`, 0.19347970101943163`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 197}], {
             RGBColor[
             0.931414792844472, 0.7553582824181725, 0.5263607215030722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[
             0.631844529693345, 0.5164916201579837, 0.581343351224306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 155}], {
             RGBColor[
             0.31673339546261187`, 0.44837192664657105`, 0.9414171693125639]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 170}], {
             RGBColor[
             0.3869454032271654, 0.5095743926590826, 0.9458767968246178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 180}], {
             RGBColor[
             0.34759559659056605`, 0.4754915679292482, 0.9433694619414015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 183}], {
             RGBColor[
             0.2939274002864909, 0.42440137973285763`, 0.9401184016257302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 271}], {
             RGBColor[
             0.3178545270497625, 0.4495503070285146, 0.9414810160978866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 273}], {
             RGBColor[
             0.30217928403804095`, 0.4330746327553852, 0.940588334197813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 326}], {
             RGBColor[
             0.3341557033790634, 0.4638506079381187, 0.9425130838303954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 350}], {
             RGBColor[
             0.380831960891249, 0.5042792361782578, 0.945487253684878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 394}], {
             RGBColor[
             0.34389456121557604`, 0.47228591710687856`, 0.9431336352400042]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 148}], {
             RGBColor[
             0.7102018348766541, 0.7732513864434318, 0.9719433954351793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 168}], {
             RGBColor[
             0.7333330676267822, 0.7916046330585647, 0.9740554448600397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 170}], {
             RGBColor[
             0.6207426403130438, 0.7003977045332692, 0.9649634716556403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 251}], {
             RGBColor[
             0.8094157442625041, 0.8510598457172036, 0.9816336535080088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 282}], {
             RGBColor[
             0.7216887092702036, 0.7825079718100041, 0.9728948440417715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 153}], {
             RGBColor[
             0.32315432075329853`, 0.4543217632532496, 0.9418120854576224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 154}], {
             RGBColor[
             0.3795179550306004, 0.5031411103456188, 0.9454035263933673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 188}], {
             RGBColor[
             0.297981899619691, 0.4286669180863, 0.9403491528141107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 203}], {
             RGBColor[
             0.3101377282501396, 0.4414434647009515, 0.9410414092716778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 222}], {
             RGBColor[
             0.4669023906435984, 0.574712579304436, 0.9521089968254883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 258}], {
             RGBColor[
             0.29090557114945215`, 0.42122924819894025`, 0.9399461663762204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 312}], {
             RGBColor[
             0.3959175277947622, 0.5170838698121216, 0.9465208083959076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 327}], {
             RGBColor[
             0.32373500724345117`, 0.4548247247048681, 0.941849086287294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 356}], {
             RGBColor[
             0.4236281428800086, 0.5395805954873082, 0.9487022895227458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 361}], {
             RGBColor[
             0.342252200873233, 0.470863387125772, 0.9430289854912723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 369}], {
             RGBColor[
             0.29316591487643506`, 0.4236050127700691, 0.9400748896075932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 392}], {
             RGBColor[
             0.2884135464934976, 0.418609972282043, 0.9398042492586839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 184}], {
             RGBColor[
             0.22818450918176583`, 0.35716676525650004`, 0.936306142277947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 188}], {
             RGBColor[
             0.25284600900533644`, 0.38308756520047255`, 0.9377105782094798]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 195}], {
             RGBColor[
             0.2421504028292495, 0.3718458049688061, 0.937101479260483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 203}], {
             RGBColor[
             0.265001837635785, 0.3958641118151241, 0.9384028346670469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 206}], {
             RGBColor[
             0.23508408472910247`, 0.364418656615107, 0.9366990628983605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 208}], {
             RGBColor[
             0.2358464087925902, 0.36521990753996986`, 0.9367424761260187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 258}], {
             RGBColor[
             0.24576968053509757`, 0.37564989531311277`, 0.9373075917715895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 284}], {
             RGBColor[
             0.24130209476909242`, 0.37095417941174347`, 0.9370531693714164]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 325}], {
             RGBColor[
             0.22508690864981107`, 0.3539109906981984, 0.9361297385101415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 369}], {
             RGBColor[
             0.24803002426208054`, 0.37802565988424164`, 0.9374363150029623]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 392}], {
             RGBColor[
             0.24327765587914302`, 0.37303061939621557`, 0.937165674654053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 121}], {
             RGBColor[
             0.48470874113100904`, 0.5915401565241579, 0.9528555034179461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 130}], {
             RGBColor[
             0.4133134657138138, 0.5324130830876621, 0.947556946449905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 135}], {
             RGBColor[
             0.4597496952635722, 0.5712772786967698, 0.9508906358992639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 147}], {
             RGBColor[
             0.35047958711339033`, 0.47576981650030403`, 0.9436345020558807]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 172}], {
             RGBColor[
             0.3588230012593764, 0.484539273770746, 0.9441096471485195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 265}], {
             RGBColor[
             0.5040580192630065, 0.6072487721867599, 0.9543787494712381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 276}], {
             RGBColor[
             0.5908937430052579, 0.6758585483037947, 0.9625051852330178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 322}], {
             RGBColor[
             0.46231873384021377`, 0.5733629399471565, 0.9510928800267155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 328}], {
             RGBColor[
             0.3628292631493686, 0.48868620423613895`, 0.944340137703926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 362}], {
             RGBColor[
             0.41044018393094006`, 0.5299243908226783, 0.9473738634754435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 364}], {
             RGBColor[
             0.382875553578809, 0.5060492934502673, 0.9456174696038513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 387}], {
             RGBColor[
             0.35489504602512995`, 0.4804107437728069, 0.9438859559088182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 223}], {
             RGBColor[
             0.40179215387534173`, 0.5224135595233219, 0.9468284392932418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 346}], {
             RGBColor[
             0.3472745636844825, 0.4752135053615816, 0.9433490060085041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 371}], {
             RGBColor[
             0.31078136056287864`, 0.44021172480761495`, 0.9411479331302521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 126}], {
             RGBColor[
             0.20905168496127685`, 0.33705695390964574`, 0.935216556243067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 149}], {
             RGBColor[
             0.21314012851733694`, 0.34135416730935836`, 0.9354493870552745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[
             0.21593219336709382`, 0.3442888044935889, 0.9356083910179783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 212}], {
             RGBColor[
             0.208479398474888, 0.33645544452739207`, 0.9351839653742893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 259}], {
             RGBColor[
             0.20854115618205327`, 0.33652035579328765`, 0.9351874823843499]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 293}], {
             RGBColor[
             0.20864634306607288`, 0.33663091387762584`, 0.9351934726217848]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 299}], {
             RGBColor[
             0.21009516231391617`, 0.33815371476755507`, 0.9352759807346135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 336}], {
             RGBColor[
             0.20853409149877072`, 0.3365129303632308, 0.9351870800610882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 367}], {
             RGBColor[
             0.21268815866311674`, 0.340879118336029, 0.9354236480407061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 200}], {
             RGBColor[
             0.2555790109882331, 0.38596012356683096`, 0.9378662186292916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 225}], {
             RGBColor[
             0.24880323623162193`, 0.37883835468870003`, 0.9374803482807631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 288}], {
             RGBColor[
             0.2427621793276949, 0.37248882085754254`, 0.9371363190270272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 296}], {
             RGBColor[
             0.27100995406971695`, 0.4021790231237703, 0.9387449880097476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 316}], {
             RGBColor[
             0.24738893708713797`, 0.3773518366161024, 0.9373998060367528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 324}], {
             RGBColor[
             0.26022801088632164`, 0.3908465172233403, 0.9381309722959088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 355}], {
             RGBColor[
             0.2357097669248304, 0.3650762882733595, 0.9367346945737933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 375}], {
             RGBColor[
             0.24767185396681415`, 0.37764920019460835`, 0.9374159177345123]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 380}], {
             RGBColor[
             0.25299451614994406`, 0.383243655625352, 0.9377190354716685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 383}], {
             RGBColor[
             0.2603673467577916, 0.3909929680586598, 0.93813890726766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 390}], {
             RGBColor[
             0.2533988208527428, 0.3836686055023921, 0.9377420600263777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 136}], {
             RGBColor[
             0.5924802140391232, 0.6800411545432594, 0.9610613592571464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 237}], {
             RGBColor[
             0.5723986729827764, 0.663738054850602, 0.9594804667840822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 246}], {
             RGBColor[
             0.505090585435528, 0.6088359587265868, 0.9542531127865411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 254}], {
             RGBColor[
             0.5179448523327678, 0.6195299901302602, 0.955193662551596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 286}], {
             RGBColor[
             0.6463140971253603, 0.7224608247380875, 0.966177990499731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 320}], {
             RGBColor[
             0.6381361673517921, 0.7160721638444079, 0.9653628908870006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 343}], {
             RGBColor[
             0.64428944346767, 0.7208791499127623, 0.9659761919445966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 349}], {
             RGBColor[
             0.5058787275831391, 0.6095186078416714, 0.9543033325072602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 130}], {
             RGBColor[
             0.48180086572832803`, 0.5890215010044231, 0.9526702161686205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 158}], {
             RGBColor[
             0.5281560210081759, 0.6278198768688632, 0.9559975231544674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 181}], {
             RGBColor[
             0.5602542166801026, 0.6538786381225696, 0.9585244106973264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 250}], {
             RGBColor[
             0.7707116790518824, 0.8187741201767487, 0.9013688926659322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 265}], {
             RGBColor[
             0.5725454192775208, 0.6638571901035208, 0.9594920191899539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 322}], {
             RGBColor[
             0.5308061338547281, 0.6299713578639174, 0.9562061497454312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 362}], {
             RGBColor[
             0.4789275839454543, 0.5865328087394392, 0.9524871331941591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 146}], {
             RGBColor[
             0.49070941162852855`, 0.5972227097318854, 0.9531038334374095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.3887610902465449, 0.5111470494961861, 0.9459924907959437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 165}], {
             RGBColor[
             0.48941818004964077`, 0.5961744297668246, 0.9530021829575823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 210}], {
             RGBColor[
             0.3730056479605837, 0.4966847962832106, 0.9450184340224643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 228}], {
             RGBColor[
             0.40697238168033323`, 0.5269207548100117, 0.9471528981824919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 262}], {
             RGBColor[
             0.6923652232093209, 0.7572804525421046, 0.9691955483013721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 298}], {
             RGBColor[
             0.634758859433705, 0.711422615804957, 0.9663329898214426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 314}], {
             RGBColor[
             0.6859497834912932, 0.7522408691078613, 0.9712156258567326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 385}], {
             RGBColor[
             0.510754315643456, 0.6134960658238386, 0.9546818417083673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 174}], {
             RGBColor[
             0.8514507591880022, 0.8841310051490996, 0.9509891763922267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 187}], {
             RGBColor[
             0.9091149872090246, 0.929372315984517, 0.9566852381845512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 193}], {
             RGBColor[
             0.8983178729767032, 0.9207629901755221, 0.9556553997903747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 218}], {
             RGBColor[
             0.9421799541639146, 0.955737423109728, 0.959839004250153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 232}], {
             RGBColor[
             0.7499263891145284, 0.8030301325071595, 0.9420935049543039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 235}], {
             RGBColor[
             0.8571949059772741, 0.8886183762780113, 0.9515616992620775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 275}], {
             RGBColor[
             0.9831983875687983, 0.9856760529092304, 0.8544852374631398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 279}], {
             RGBColor[
             0.9599728871641575, 0.901288321876893, 0.6017603738326488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 281}], {
             RGBColor[
             0.8031450913153519, 0.8462354724290008, 0.9462830761380823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 306}], {
             RGBColor[
             0.9723361250736168, 0.9460422517382365, 0.6339056761634236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 338}], {
             RGBColor[
             0.9842922541931751, 0.9852712070496027, 0.7740485310892328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.22241368079166546`, 0.3511012587268517, 0.9359775021383063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 199}], {
             RGBColor[
             0.224537016117427, 0.35333301878146245`, 0.9360984229439153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 238}], {
             RGBColor[
             0.22624718755874168`, 0.35513051739741625`, 0.9361958146775262]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 252}], {
             RGBColor[
             0.22380219645594157`, 0.3525606767269839, 0.936056576051262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 277}], {
             RGBColor[
             0.24054204876353127`, 0.3701553228701986, 0.9370098858757869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 293}], {
             RGBColor[
             0.21725116581640602`, 0.3456751281654994, 0.9356835045477219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 330}], {
             RGBColor[
             0.22402160898279397`, 0.3527912932042634, 0.9360690712700745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 179}], {
             RGBColor[
             0.2738145581196516, 0.4051268398024189, 0.9389047060613515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 196}], {
             RGBColor[
             0.2879550374250095, 0.4199893801105207, 0.9397099854388271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 303}], {
             RGBColor[
             0.28379884955745593`, 0.41562096314419106`, 0.9394732966882988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 313}], {
             RGBColor[
             0.2803971559769777, 0.4120455675112783, 0.9392795752712453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 344}], {
             RGBColor[
             0.2993073040655987, 0.4308227000023955, 0.9403967065336283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 149}], {
             RGBColor[
             0.21613019133913786`, 0.3444969129160037, 0.9356196667095744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 199}], {
             RGBColor[
             0.21892225618889471`, 0.3474315501002342, 0.9357786706722784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 212}], {
             RGBColor[
             0.21146946129668887`, 0.3395981901340374, 0.9353542450285892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 238}], {
             RGBColor[
             0.2206324276302094, 0.349229048716188, 0.9358760624058893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 259}], {
             RGBColor[
             0.2115312190038542, 0.33966310139993294`, 0.93535776203865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 274}], {
             RGBColor[
             0.22138486041548355`, 0.35001990328050514`, 0.9359189123398861]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 299}], {
             RGBColor[
             0.21308522513571704`, 0.34129646037420036`, 0.9354462603889135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 318}], {
             RGBColor[
             0.2179296081019373, 0.3463882140233181, 0.9357221408322174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 336}], {
             RGBColor[
             0.21152415432057162`, 0.33965567596987617`, 0.9353573597153882]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 367}], {
             RGBColor[
             0.21567822148491766`, 0.34402186394267437`, 0.935593927695006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 139}], {
             RGBColor[
             0.2108331954164144, 0.3389294343522821, 0.9353180106279786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 184}], {
             RGBColor[
             0.21412931839643223`, 0.34239386859054827`, 0.9355057199555137]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 305}], {
             RGBColor[
             0.20669916269368893`, 0.33458430384788407`, 0.9350825835801727]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 325}], {
             RGBColor[
             0.21103171786447747`, 0.3391380940322466, 0.9353293161877081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 177}], {
             RGBColor[
             0.32406082685861914`, 0.45510693327935664`, 0.9418698472250615]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 225}], {
             RGBColor[
             0.2916606290262991, 0.42226923419395845`, 0.939980144908767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 296}], {
             RGBColor[
             0.3138673468643941, 0.4456099026290287, 0.9412447846377514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 311}], {
             RGBColor[
             0.4227935959175786, 0.5388307190597109, 0.9486565824461703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 316}], {
             RGBColor[
             0.29024632988181515`, 0.4207827161213608, 0.9398996026647567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 324}], {
             RGBColor[
             0.3030854036809988, 0.43427739672859866`, 0.9406307689239126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 380}], {
             RGBColor[
             0.2958519089446212, 0.4266745351306104, 0.9402188320996724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 383}], {
             RGBColor[
             0.30322473955246876`, 0.43442384756391816`, 0.9406387038956638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 390}], {
             RGBColor[
             0.29625621364741994`, 0.42709948500765055`, 0.9402418566543815]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 178}], {
             RGBColor[
             0.24083645723076108`, 0.3704647648358321, 0.9370266520024574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 229}], {
             RGBColor[
             0.24229031603850887`, 0.3719928626227475, 0.9371094471107673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 249}], {
             RGBColor[
             0.25362687609654, 0.3839083060231606, 0.9377550474351345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 270}], {
             RGBColor[
             0.24363580909960866`, 0.3734070611391507, 0.9371860709501183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 308}], {
             RGBColor[
             0.2493864248848615, 0.3794513229395511, 0.9375135600118147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 309}], {
             RGBColor[
             0.25423745991444247`, 0.38455006832902616`, 0.9377898192802863]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 397}], {
             RGBColor[
             0.24351700983454236`, 0.3732821955792575, 0.9371793055077206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 135}], {
             RGBColor[
             0.4568418198608912, 0.568758623177035, 0.9507053486499384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 147}], {
             RGBColor[
             0.34757171171070933`, 0.4732511609805692, 0.9434492148065551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 158}], {
             RGBColor[
             0.4567607455909806, 0.5686928034323673, 0.9506989661864262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 172}], {
             RGBColor[
             0.3559151258566954, 0.4820206182510111, 0.9439243598991939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 181}], {
             RGBColor[
             0.48885894126290724`, 0.5947515646860737, 0.9532258537292853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 265}], {
             RGBColor[
             0.5011501438603255, 0.6047301166670249, 0.9541934622219126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 322}], {
             RGBColor[
             0.45941085843753277`, 0.5708442844274215, 0.95090759277739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 328}], {
             RGBColor[
             0.3599213877466876, 0.48616754871640405`, 0.9441548504546003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 347}], {
             RGBColor[
             0.34522783768479254`, 0.47078760076913406`, 0.9433157346482299]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 362}], {
             RGBColor[
             0.40753230852825906`, 0.5274057353029433, 0.9471885762261179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 364}], {
             RGBColor[
             0.379967678176128, 0.5035306379305324, 0.9454321823545258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 387}], {
             RGBColor[
             0.35198717062244894`, 0.47789208825307206`, 0.9437006686594926]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 215}], {
             RGBColor[
             0.8708771882594211, 0.43978719004972067`, 0.21128818862239418`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 217}], {
             RGBColor[
             0.8726459244985081, 0.4533824718485052, 0.21298193244244573`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 262}], {
             RGBColor[
             0.9305545199558635, 0.8420358975584873, 0.6226092420681639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 269}], {
             RGBColor[
             0.9577625542405059, 0.8589366723660075, 0.3711790558606476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 279}], {
             RGBColor[
             0.934057909721427, 0.776268616484077, 0.26579965018330676`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 297}], {
             RGBColor[
             0.9345525999537521, 0.8450176590746574, 0.6158415354980056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 300}], {
             RGBColor[
             0.9062314787117222, 0.661847076989811, 0.24319781291959908`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 306}], {
             RGBColor[
             0.9464211476308863, 0.8210225463454206, 0.2979449525140816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 307}], {
             RGBColor[
             0.9538530771213425, 0.8592378166634234, 0.5753740091193393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 314}], {
             RGBColor[
             0.9241390802378358, 0.8369963141242439, 0.6246293196235244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 352}], {
             RGBColor[
             0.9583101575279735, 0.8601079404267151, 0.43078229428572945`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 363}], {
             RGBColor[
             0.8924893365860593, 0.5994472191560132, 0.23173103267921852`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 140}], {
             RGBColor[
             0.7355736784173503, 0.7933550152374292, 0.9742787680039452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 191}], {
             RGBColor[
             0.7390378619070974, 0.7960612617083893, 0.9746240454395679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 198}], {
             RGBColor[
             0.8128559952710535, 0.8537811311091374, 0.9819675933041132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 216}], {
             RGBColor[
             0.7291619678468395, 0.7883461382089411, 0.9736397086151186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 219}], {
             RGBColor[
             0.6232051027562657, 0.7024156086050097, 0.9651690328906872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 220}], {
             RGBColor[
             0.6373284381573086, 0.7140480166379533, 0.9662348834814941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 302}], {
             RGBColor[
             0.8932496977556434, 0.905911220002762, 0.6928483915783341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 323}], {
             RGBColor[
             0.8147163030891271, 0.8552644900665589, 0.9821450311245175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 357}], {
             RGBColor[
             0.7374562321167385, 0.7948256804953293, 0.9744664033632358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 145}], {
             RGBColor[
             0.26764114093786784`, 0.3986381869271076, 0.9385531390856012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 164}], {
             RGBColor[
             0.2698983654154672, 0.40101067296936244`, 0.9386816846803361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 223}], {
             RGBColor[
             0.3756627076897743, 0.49871942307299955`, 0.945202383630783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 234}], {
             RGBColor[
             0.31799880832538563`, 0.4487941940432452, 0.9415224703076799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 280}], {
             RGBColor[
             0.26813571605602704`, 0.3991580167341666, 0.938581304406922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 346}], {
             RGBColor[
             0.32114511749891506`, 0.4515193689112592, 0.9417229503460453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 167}], {
             RGBColor[
             0.25893816716997997`, 0.3894908096966502, 0.9380575176044159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 201}], {
             RGBColor[
             0.255376576823433, 0.3857473524245587, 0.9378546903030808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 236}], {
             RGBColor[
             0.24242453355158805`, 0.3721339337388756, 0.9371170905995801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 243}], {
             RGBColor[
             0.2613494095308073, 0.3920251782994754, 0.9381948342897516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 263}], {
             RGBColor[
             0.24820523859568883`, 0.3782098212580943, 0.9374462932000549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 348}], {
             RGBColor[
             0.24864104476606846`, 0.3786678811748705, 0.9374711117167406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 351}], {
             RGBColor[
             0.24003567899790235`, 0.3696230961408251, 0.9369810488667414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 221}], {
             RGBColor[
             0.7125684826637311, 0.7740760557086418, 0.9732239792621271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 276}], {
             RGBColor[
             0.6344220971523353, 0.7122040883931675, 0.9656535874330512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 322}], {
             RGBColor[
             0.5058470879872912, 0.6097084800365293, 0.954241282226749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 364}], {
             RGBColor[
             0.42640390772588643`, 0.5423948335396401, 0.9487658718038847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 376}], {
             RGBColor[
             0.47083567399736015`, 0.5808793962784845, 0.9515970246612349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 377}], {
             RGBColor[
             0.4590787183907463, 0.5706961122538062, 0.9508478818462491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 194}], {
             RGBColor[
             0.5033185862068833, 0.6058836865205527, 0.954531849750919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 237}], {
             RGBColor[
             0.59850057250929, 0.6849287527633994, 0.9615353039292178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 246}], {
             RGBColor[
             0.5311924849620417, 0.6300266566393842, 0.9563079499316767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 254}], {
             RGBColor[
             0.5440467518592814, 0.6407206880430576, 0.9572484996967315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 286}], {
             RGBColor[
             0.6724159966518739, 0.7436515226508849, 0.9682328276448666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 320}], {
             RGBColor[
             0.6642380668783059, 0.7372628617572051, 0.9674177280321361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 343}], {
             RGBColor[
             0.6703913429941837, 0.7420698478255596, 0.9680310290897323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 349}], {
             RGBColor[
             0.5319806271096528, 0.6307093057544687, 0.9563581696523957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 376}], {
             RGBColor[
             0.5284877060748537, 0.6276839131134415, 0.9561356038127271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 199}], {
             RGBColor[
             0.22367942926895015`, 0.3524316406295666, 0.9360495846415806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 238}], {
             RGBColor[
             0.22538960071026484`, 0.3542291392455204, 0.9361469763751915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 252}], {
             RGBColor[
             0.22294460960746476`, 0.35165929857508804`, 0.9360077377489273]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 277}], {
             RGBColor[
             0.23968446191505444`, 0.36925394471830275`, 0.9369610475734522]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 285}], {
             RGBColor[
             0.23013560035880143`, 0.35921748578989005`, 0.9364172540340985]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 293}], {
             RGBColor[
             0.2163935789679292, 0.34477375001360355`, 0.9356346662453872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 330}], {
             RGBColor[
             0.22316402213431713`, 0.35188991505236755`, 0.9360202329677398]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 144}], {
             RGBColor[
             0.8488904911809813, 0.34529052811745564`, 0.1932170904993126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 233}], {
             RGBColor[
             0.8184005545424529, 0.14244030215351539`, 0.165253697851294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 242}], {
             RGBColor[
             0.8688448581678534, 0.4318314305529642, 0.2096571104877158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 256}], {
             RGBColor[
             0.522325620948562, 0.25191357841785655`, 0.5511492082429574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 257}], {
             RGBColor[
             0.8209750230584517, 0.16222879530677942`, 0.1677190118096608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 317}], {
             RGBColor[
             0.9049849697863369, 0.5700377324760639, 0.4855767081666582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 366}], {
             RGBColor[
             0.8603116610551809, 0.39715139303420033`, 0.20274719460083632`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 381}], {
             RGBColor[
             0.9062449527279615, 0.5705587678025101, 0.4646955300926113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 382}], {
             RGBColor[
             0.8590618993454652, 0.3914765169996446, 0.2017043627957868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 184}], {
             RGBColor[
             0.21446679583023515`, 0.34274857877078024`, 0.9355249387961155]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 305}], {
             RGBColor[
             0.20703664012749182`, 0.3349390140281161, 0.9351018024207747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 325}], {
             RGBColor[
             0.21136919529828035`, 0.33949280421247857`, 0.9353485350283102]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 141}], {
             RGBColor[
             0.5159944713875729, 0.6149616035084853, 0.9560493981699523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 168}], {
             RGBColor[
             0.6710377427034506, 0.7429390517664531, 0.9678464290545918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 191}], {
             RGBColor[
             0.6753891788981803, 0.7463384267939157, 0.9682801395479993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 216}], {
             RGBColor[
             0.6655132848379224, 0.7386233032944675, 0.96729580272355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 219}], {
             RGBColor[
             0.5595564197473485, 0.6526927736905361, 0.9588251269991186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 220}], {
             RGBColor[
             0.5736797551483913, 0.6643251817234797, 0.9598909775899255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 350}], {
             RGBColor[
             0.5523338730537959, 0.6464369667603329, 0.9583649127104528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 357}], {
             RGBColor[
             0.6738075491078213, 0.7451028455808557, 0.9681224974716671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 150}], {
             RGBColor[
             0.3153323622893313, 0.4440199894984804, 0.9414428101102743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 189}], {
             RGBColor[
             0.33030534537683665`, 0.4597575440654077, 0.9422954993465642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 219}], {
             RGBColor[
             0.4036258957264883, 0.5240221968760659, 0.9469396630566943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 220}], {
             RGBColor[
             0.4177492311275311, 0.5356546049090093, 0.9480055136475012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 273}], {
             RGBColor[
             0.31775067217972763`, 0.44656178652298995`, 0.9415805292809634]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 339}], {
             RGBColor[
             0.36291222472736206`, 0.48875806138522676`, 0.9443454239423157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 350}], {
             RGBColor[
             0.3964033490329356, 0.5177663899458625, 0.9464794487680284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 357}], {
             RGBColor[
             0.5178770250869611, 0.6164322687663853, 0.9562370335292427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 394}], {
             RGBColor[
             0.3594659493572627, 0.4857730708744833, 0.9441258303231546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 202}], {
             RGBColor[
             0.8389617996732674, 0.300483042224024, 0.18494316940916705`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 214}], {
             RGBColor[
             0.9026785336009098, 0.577164017789306, 0.5403271212608096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 217}], {
             RGBColor[
             0.8222048215005642, 0.17168156503396934`, 0.16889666818668636`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 257}], {
             RGBColor[
             0.822095571600614, 0.17084182242934073`, 0.16879205035911396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 268}], {
             RGBColor[
             0.8194514867475214, 0.1505182276031009, 0.16626007171772583`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 275}], {
             RGBColor[
             0.906842307128124, 0.5789554407018784, 0.47443924955803846`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 279}], {
             RGBColor[
             0.8836168067234831, 0.49456770966954106`, 0.2217143859275474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 300}], {
             RGBColor[
             0.8557903757137784, 0.38014617017527513`, 0.1991125486638397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 306}], {
             RGBColor[
             0.8959800446329425, 0.5393216395308846, 0.25385968825832217`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 338}], {
             RGBColor[
             0.9079361737525008, 0.5785505948422507, 0.3940025431841314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 363}], {
             RGBColor[
             0.8420482335881154, 0.3177463123414773, 0.18764576842345915`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 381}], {
             RGBColor[
             0.9073655012701238, 0.5791717949250715, 0.46576856864206445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 223}], {
             RGBColor[
             0.5393557196395969, 0.6369122967585245, 0.9568792044565808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 234}], {
             RGBColor[
             0.4816918202752083, 0.5869870677287701, 0.9531992911334777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 260}], {
             RGBColor[
             0.7167991404658595, 0.7784168360748085, 0.9725930329082488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 267}], {
             RGBColor[
             0.5979215961089128, 0.6844587136389835, 0.9614897247861196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 272}], {
             RGBColor[
             0.635830587523557, 0.7151635871324875, 0.9645228442451073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 290}], {
             RGBColor[
             0.5148889820990041, 0.6157407807626738, 0.9553145849297924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 291}], {
             RGBColor[
             0.6605679134983766, 0.7344885741946573, 0.9669884297148228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 321}], {
             RGBColor[
             0.7212153553030598, 0.7818668166701053, 0.973033199931347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 331}], {
             RGBColor[
             0.5383683584932644, 0.6360774364876114, 0.9568106700316372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 342}], {
             RGBColor[
             0.6140012232637606, 0.6975128793422373, 0.9627555719373643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 398}], {
             RGBColor[
             0.7820348247548993, 0.8302487551810782, 0.97550730112162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 207}], {
             RGBColor[
             0.9091469621070289, 0.6700765235430096, 0.2453714490760957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 233}], {
             RGBColor[
             0.8479481693127158, 0.33804742930989184`, 0.1923147220140613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 242}], {
             RGBColor[
             0.8983924729381163, 0.6274385577093406, 0.23671813465048305`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 317}], {
             RGBColor[
             0.9345325845565998, 0.7656448596324403, 0.5126377323294256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 358}], {
             RGBColor[
             0.9235073892649484, 0.7232807673563957, 0.2763524253689754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 366}], {
             RGBColor[
             0.8898592758254438, 0.5927585201905767, 0.22980821876360358`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 370}], {
             RGBColor[
             0.8548273648949809, 0.7045756223106869, 0.6020207461756493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 391}], {
             RGBColor[
             0.8494144480971886, 0.3493178905748092, 0.19371883223399736`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 162}], {
             RGBColor[
             0.2420540274215789, 0.3717445083047905, 0.9370959908235907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 164}], {
             RGBColor[
             0.2402812832877892, 0.36988124182170756`, 0.9369950356677115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 227}], {
             RGBColor[
             0.23647303514531387`, 0.36587853156708794`, 0.9367781615697957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 280}], {
             RGBColor[
             0.23851863392834902`, 0.36802858558651175`, 0.9368946553942974]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 359}], {
             RGBColor[
             0.24179608967805666`, 0.37147339938215107`, 0.9370813016506819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 154}], {
             RGBColor[
             0.48274463326921224`, 0.5903240190384458, 0.9525963248033308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 159}], {
             RGBColor[
             0.433382915877228, 0.5475693804255631, 0.9494510398199664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 165}], {
             RGBColor[
             0.5340400056803238, 0.6325967606962016, 0.956460731981605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 192}], {
             RGBColor[
             0.43991049068666355`, 0.5532232376400468, 0.9498669711147159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 228}], {
             RGBColor[
             0.45159420731101624`, 0.5633430857393887, 0.9506114472065146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 262}], {
             RGBColor[
             0.736987048840004, 0.7937027834714817, 0.9726540973253948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 297}], {
             RGBColor[
             0.7409851288378926, 0.7966845449876518, 0.9658863907552364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 307}], {
             RGBColor[
             0.760285606005483, 0.8109047025764178, 0.9254188643765703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 314}], {
             RGBColor[
             0.7305716091219763, 0.7886632000372383, 0.9746741748807553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 332}], {
             RGBColor[
             0.53127642233297, 0.6303531592368088, 0.9562431725771618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 385}], {
             RGBColor[
             0.5553761412741389, 0.6499183967532158, 0.95814039073239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 172}], {
             RGBColor[
             0.29308124725627194`, 0.4253773516636531, 0.9400019155051696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 211}], {
             RGBColor[
             0.2737075152920192, 0.40501433100367, 0.9388986101306735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 328}], {
             RGBColor[
             0.29708750914626414`, 0.42952428212904603`, 0.9402324060605761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 347}], {
             RGBColor[
             0.28239395908436904`, 0.4141443341817761, 0.9393932902542057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 364}], {
             RGBColor[
             0.31713379957570453`, 0.44688737134317436`, 0.9415097379605015]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 372}], {
             RGBColor[
             0.2681076692483716, 0.3991285377610505, 0.9385797071827175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 387}], {
             RGBColor[
             0.28915329202202544`, 0.42124882166571403`, 0.9397782242654684]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 161}], {
             RGBColor[
             0.5276623353729026, 0.6268249505740837, 0.9561228183174523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 168}], {
             RGBColor[
             0.6470192572483401, 0.7238926765948177, 0.9656459465719469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 170}], {
             RGBColor[
             0.5344288299346016, 0.632685748069522, 0.9565539733675475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 251}], {
             RGBColor[
             0.723101933884062, 0.7833478892534567, 0.9732241552199159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.6353748988917614, 0.714796015346257, 0.9644853457536787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 312}], {
             RGBColor[
             0.5434225996528742, 0.6402139731641597, 0.9571993641486982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 326}], {
             RGBColor[
             0.4816391300864997, 0.5869619633485583, 0.9531902603733251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 356}], {
             RGBColor[
             0.5711332147381206, 0.6627106988393463, 0.9593808452755366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 199}], {
             RGBColor[
             0.2230106997449548, 0.3517287634999468, 0.9360115014844858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 212}], {
             RGBColor[
             0.21555790485274898`, 0.34389540353375003`, 0.9355870758407967]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 238}], {
             RGBColor[
             0.2247208711862695, 0.3535262621159006, 0.9361088932180968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 259}], {
             RGBColor[
             0.21561966255991427`, 0.3439603147996455, 0.9355905928508573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 274}], {
             RGBColor[
             0.22547330397154366`, 0.35431711668021776`, 0.9361517431520935]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 287}], {
             RGBColor[
             0.24021601426247097`, 0.36981263993780294`, 0.9369913186932763]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 299}], {
             RGBColor[
             0.21717366869177715`, 0.345593673773913, 0.9356790912011209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 318}], {
             RGBColor[
             0.22201805165799737`, 0.3506854274230307, 0.9359549716444248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 336}], {
             RGBColor[
             0.21561259787663173`, 0.3439528893695888, 0.9355901905275956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 367}], {
             RGBColor[
             0.21976666504097775`, 0.348319077342387, 0.9358267585072135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 186}], {
             RGBColor[
             0.2595342246109202, 0.3901173038593028, 0.9380914621938894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 189}], {
             RGBColor[
             0.28557376029945525`, 0.4174865068698732, 0.9395743752293106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 226}], {
             RGBColor[
             0.2546174021107136, 0.38494941166703367`, 0.9378114564262897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 241}], {
             RGBColor[
             0.2807813627744614, 0.41244939321555174`, 0.939301455279979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 255}], {
             RGBColor[
             0.26553787758684655`, 0.39642752379058566`, 0.9384333613492598]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 266}], {
             RGBColor[
             0.2627993543398047, 0.39354916222554226`, 0.9382774065016228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 365}], {
             RGBColor[
             0.26342074735738313`, 0.39420228568561005`, 0.9383127939147053]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 374}], {
             RGBColor[
             0.2733522518909328, 0.4046409266441276, 0.9388783784055468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 399}], {
             RGBColor[
             0.2527398969113101, 0.3829760346617555, 0.9377045352827038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 171}], {
             RGBColor[
             0.294524052203641, 0.4262383567855898, 0.940108081239609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 182}], {
             RGBColor[
             0.301964914813191, 0.43405917516616493`, 0.9405318273574531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 244}], {
             RGBColor[
             0.28793584651295273`, 0.41931373488830953`, 0.9397328926719012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 249}], {
             RGBColor[
             0.2927023996318287, 0.42432368443317114`, 0.9400043408205379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 253}], {
             RGBColor[
             0.3287756481732377, 0.4591906745282696, 0.9421702714700763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 270}], {
             RGBColor[
             0.28271133263489734`, 0.4138224395491612, 0.9394353643355215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 308}], {
             RGBColor[
             0.28846194842015016`, 0.41986670134956156`, 0.9397628533972181]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 386}], {
             RGBColor[
             0.3275993292124569, 0.45817180616795133`, 0.9420953174660733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 397}], {
             RGBColor[
             0.28259253336983103`, 0.413697573989268, 0.9394285988931239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 156}], {
             RGBColor[
             0.18478785261667285`, 0.31155412769964164`, 0.9338347668861651]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 175}], {
             RGBColor[
             0.181274153781999, 0.307861007443026, 0.9336346669355821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 242}], {
             RGBColor[
             0.5509815030039178, 0.5121510355041116, 0.5934630978551525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 256}], {
             RGBColor[
             0.2044622657846265, 0.33223318336900387`, 0.9349551956103941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 261}], {
             RGBColor[
             0.18153226782756765`, 0.3081323016702944, 0.9336493661486316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 264}], {
             RGBColor[
             0.186823590274237, 0.31369381705096394`, 0.9339506991341594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 317}], {
             RGBColor[
             0.5871216146224013, 0.6503573374272111, 0.8693826955340949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 333}], {
             RGBColor[
             0.18958831081692415`, 0.31659971363473505`, 0.9341081458790279]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 381}], {
             RGBColor[
             0.588381597564026, 0.6508783727536576, 0.8485015174600479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 154}], {
             RGBColor[
             0.3737943950019111, 0.49818365032325973`, 0.9450388262094847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 188}], {
             RGBColor[
             0.2922583395910017, 0.4237094580639409, 0.939984452630228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 195}], {
             RGBColor[
             0.2815627334149148, 0.41246769783227444`, 0.9393753536812313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 203}], {
             RGBColor[
             0.3044141682214503, 0.43648600467859244`, 0.9406767090877951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 258}], {
             RGBColor[
             0.28518201112076286`, 0.41627178817658117`, 0.9395814661923377]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 278}], {
             RGBColor[
             0.284923192180341, 0.41599975306012926`, 0.939566726836569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 284}], {
             RGBColor[
             0.2807144253547577, 0.4115760722752118, 0.9393270437921646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 312}], {
             RGBColor[
             0.39019396776607296`, 0.5121264097897626, 0.9461561082120249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 327}], {
             RGBColor[
             0.31801144721476193`, 0.44986726468250904`, 0.9414843861034113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 337}], {
             RGBColor[
             0.30108704647180895`, 0.43298898876801645`, 0.9404872344261885]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[
             0.4179045828513193, 0.5346231354649491, 0.9483375893388631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 361}], {
             RGBColor[
             0.3365286408445437, 0.46590592710341294`, 0.9426642853073897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 369}], {
             RGBColor[
             0.28744235484774583`, 0.41864755274771004`, 0.9397101894237105]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 392}], {
             RGBColor[
             0.28268998646480836`, 0.4136525122596839, 0.9394395490748012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 192}], {
             RGBColor[
             0.3873238866966642, 0.5099022160172301, 0.9459009134566145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[
             0.36077780249875213`, 0.4853053517709617, 0.9442681500235399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 222}], {
             RGBColor[
             0.5175424648922109, 0.6185744663744461, 0.9553357375773506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 228}], {
             RGBColor[
             0.39900760332101687`, 0.520022064116572, 0.9466453895484133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 312}], {
             RGBColor[
             0.4465576020433747, 0.5609457568821319, 0.9497475491477698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 332}], {
             RGBColor[
             0.47868981834297064`, 0.5870321376139921, 0.9522771149190605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 356}], {
             RGBColor[
             0.4742682171286211, 0.5834424825573183, 0.951929030274608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 361}], {
             RGBColor[
             0.39289227512184555`, 0.5147252741957822, 0.9462557262431346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 385}], {
             RGBColor[
             0.5027895372841396, 0.606597375130399, 0.9541743330742887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 170}], {
             RGBColor[
             0.3747576276064379, 0.498629600146848, 0.9451144220759548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 180}], {
             RGBColor[
             0.33540782096983857`, 0.46454677541701367`, 0.9426070871927383]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 183}], {
             RGBColor[
             0.2817396246657633, 0.4134565872206231, 0.9393560268770672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 239}], {
             RGBColor[
             0.3145302695292589, 0.4464636896954298, 0.9412767880762385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 271}], {
             RGBColor[
             0.305666751429035, 0.4386055145162801, 0.9407186413492236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 326}], {
             RGBColor[
             0.32196792775833594`, 0.4529058154258842, 0.9417507090817323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 335}], {
             RGBColor[
             0.29253189959404885`, 0.42479995244000324`, 0.9399706309684931]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 337}], {
             RGBColor[
             0.29464447603044647`, 0.42702040421973947`, 0.9400909390712692]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 354}], {
             RGBColor[
             0.29215952785429067`, 0.42440856613178546`, 0.9399494249487885]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 175}], {
             RGBColor[
             0.18244584031582461`, 0.30909252427929373`, 0.9337013927503286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 202}], {
             RGBColor[
             0.5211495825009953, 0.37342113688887774`, 0.567742844041897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 214}], {
             RGBColor[
             0.5848663164286375, 0.6501021124541597, 0.9231267958935396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 256}], {
             RGBColor[
             0.20563395231845213`, 0.3334647002052716, 0.9350219214251405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 261}], {
             RGBColor[
             0.18270395436139325`, 0.3093638185065621, 0.9337160919633781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 264}], {
             RGBColor[
             0.1879952768080626, 0.31492533388723165`, 0.9340174249489059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 295}], {
             RGBColor[
             0.2141734445733891, 0.3424402480002911, 0.9355082328760125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 310}], {
             RGBColor[
             0.1842688448604277, 0.3110086176408356, 0.93380521016225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 363}], {
             RGBColor[
             0.5242360164158433, 0.390684407006331, 0.5704454430561892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 381}], {
             RGBColor[
             0.5895532840978516, 0.6521098895899253, 0.8485682432747944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 187}], {
             RGBColor[
             0.656588840938115, 0.7291931341002164, 0.9681680488654731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 218}], {
             RGBColor[
             0.689653807893005, 0.7555582412254274, 0.971321814931075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 253}], {
             RGBColor[
             0.40547981020843754`, 0.5251955404755204, 0.9471772728723662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 298}], {
             RGBColor[
             0.6463369873520685, 0.7210185843298552, 0.9671902179184984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.5352140965427551, 0.633549940550514, 0.9565531607151321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 265}], {
             RGBColor[
             0.5475052991401734, 0.643528492531465, 0.9575207692077594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 311}], {
             RGBColor[
             0.5112449698673547, 0.6140907237185725, 0.9546662232614405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 322}], {
             RGBColor[
             0.5057660137173806, 0.6096426602918618, 0.9542348997632368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 362}], {
             RGBColor[
             0.4538874638081069, 0.5662041111673836, 0.9505158832119648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 165}], {
             RGBColor[
             0.43209168429834016`, 0.5465211004605023, 0.9493493893401392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 167}], {
             RGBColor[
             0.30749203096032607`, 0.43842628345076595`, 0.9408993959616536]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 192}], {
             RGBColor[
             0.3379621693046799, 0.46714757740434754`, 0.9427556284732501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 201}], {
             RGBColor[
             0.30393044061377905`, 0.43468282617867443`, 0.9406965686603185]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 210}], {
             RGBColor[
             0.3156791522092831, 0.44703146697688845`, 0.9413656404050212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 228}], {
             RGBColor[
             0.3496458859290326, 0.47726742550368945`, 0.9435001045650488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 236}], {
             RGBColor[
             0.2909783973419341, 0.4210694074929913, 0.9399589689568179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 243}], {
             RGBColor[
             0.3099032733211534, 0.44096065205359114`, 0.9410367126469893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 263}], {
             RGBColor[
             0.29675910238603487`, 0.4271452950122101, 0.9402881715572926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 166}], {
             RGBColor[
             0.8271233428626157, 0.2094874755325008, 0.1736066497976622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 185}], {
             RGBColor[
             0.8265840327508944, 0.20534210168661424`, 0.17309020582561438`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 213}], {
             RGBColor[
             0.8702228477750129, 0.45615422864304855`, 0.21154106500959308`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 224}], {
             RGBColor[
             0.9025695450570996, 0.5785729407895561, 0.26790552836760506`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 247}], {
             RGBColor[
             0.8682425607038025, 0.44830305029724704`, 0.2099476795487854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 289}], {
             RGBColor[
             0.863615444991354, 0.42809333252077686`, 0.20612813226240806`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 302}], {
             RGBColor[
             0.9083773079386029, 0.59816388871644, 0.2904675904582531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 340}], {
             RGBColor[
             0.9116278550257833, 0.6083417789954149, 0.37001345675471364`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 370}], {
             RGBColor[
             0.8303471028154521, 0.5479183884634005, 0.5798122246722852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 400}], {
             RGBColor[
             0.6095442446912597, 0.3697331530727862, 0.5609538560304888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 170}], {
             RGBColor[
             0.43820314080929235`, 0.5539712686639211, 0.9491428945379133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 222}], {
             RGBColor[
             0.5181817733764011, 0.6191282032508729, 0.9553764737486448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 239}], {
             RGBColor[
             0.3779757827321134, 0.5018053582125028, 0.9453052605381971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 251}], {
             RGBColor[
             0.6268762447587527, 0.7046334098478555, 0.9658130763902817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 312}], {
             RGBColor[
             0.44719691052756494`, 0.5614994937585587, 0.949788285319064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 326}], {
             RGBColor[
             0.3854134409611904, 0.5082474839429573, 0.9457791815436909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 327}], {
             RGBColor[
             0.3750143899762539, 0.4992403486513052, 0.9451165632104506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 337}], {
             RGBColor[
             0.35808998923330093`, 0.48236207273681253`, 0.9441194115332278]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.47490752561281135`, 0.5839962194337451, 0.9519697664459024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 179}], {
             RGBColor[
             0.25786357675267113`, 0.38836134703509095`, 0.9379963212698641]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 231}], {
             RGBColor[
             0.27738405997012383`, 0.4088786125667542, 0.9391079839111312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 313}], {
             RGBColor[
             0.26444617460999714`, 0.3952800747439503, 0.938371190479758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 359}], {
             RGBColor[
             0.24582605828944576`, 0.3757091519074889, 0.9373108024012962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 164}], {
             RGBColor[
             0.24375587866941067`, 0.373533261869863, 0.9371929087344915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 169}], {
             RGBColor[
             0.23283585906700827`, 0.36205562889850595`, 0.936571029772856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 209}], {
             RGBColor[
             0.2485031193706023, 0.3785229128392603, 0.9374632570695112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 227}], {
             RGBColor[
             0.23994763052693538`, 0.3695305516152434, 0.9369760346365759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 240}], {
             RGBColor[
             0.2420898799764604, 0.3717821916131542, 0.9370980325735522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 245}], {
             RGBColor[
             0.2374360489235272, 0.36689072010659024`, 0.9368330037798137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 280}], {
             RGBColor[
             0.24199322930997053`, 0.37168060563466715`, 0.9370925284610774]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 304}], {
             RGBColor[
             0.23203584179739814`, 0.3612147600241211, 0.9365254699728711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 315}], {
             RGBColor[
             0.24412373790812583`, 0.3739199052533755, 0.9372138577739373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 319}], {
             RGBColor[
             0.2432784612852803, 0.3730314659291315, 0.9371657205207411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 329}], {
             RGBColor[
             0.2400560374603316, 0.3696444941756393, 0.936982208251059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 371}], {
             RGBColor[
             0.25850942763125473`, 0.3890401772577931, 0.9380331015219487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 169}], {
             RGBColor[
             0.23161848816298614`, 0.3607760948926053, 0.9365017023008109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 209}], {
             RGBColor[
             0.24728574846658016`, 0.37724337883335973`, 0.9373939295974659]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 227}], {
             RGBColor[
             0.23873025962291325`, 0.36825101760934276`, 0.9369067071645306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 245}], {
             RGBColor[
             0.23621867801950508`, 0.36561118610068966`, 0.9367636763077685]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 280}], {
             RGBColor[
             0.2407758584059484, 0.37040107162876656`, 0.9370232009890322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 304}], {
             RGBColor[
             0.230818470893376, 0.3599352260182205, 0.936456142500826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 315}], {
             RGBColor[
             0.2429063670041037, 0.37264037124747484`, 0.9371445303018922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 228}], {
             RGBColor[
             0.4503029757321284, 0.5622948057743279, 0.9505097967266875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 262}], {
             RGBColor[
             0.7356958172611161, 0.7926545035064209, 0.9725524468455675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 298}], {
             RGBColor[
             0.6780894534855002, 0.7467966667692734, 0.969689888365638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 307}], {
             RGBColor[
             0.7589943744265952, 0.8098564226113569, 0.9253172138967432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 314}], {
             RGBColor[
             0.7292803775430885, 0.7876149200721775, 0.9745725244009281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 332}], {
             RGBColor[
             0.5299851907540822, 0.6293048792717479, 0.9561415220973347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 385}], {
             RGBColor[
             0.5540849096952511, 0.648870116788155, 0.9580387402525627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 185}], {
             RGBColor[
             0.8242297938213237, 0.1872463896398561, 0.17083578396792481`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 213}], {
             RGBColor[
             0.8678686088454421, 0.43805851659629047`, 0.20928664315190354`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 224}], {
             RGBColor[
             0.9002153061275288, 0.5604772287427979, 0.2656511065099155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 247}], {
             RGBColor[
             0.8658883217742317, 0.43020733825048896`, 0.20769325769109587`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 289}], {
             RGBColor[
             0.8612612060617832, 0.40999762047401866`, 0.2038737104047185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 302}], {
             RGBColor[
             0.9060230690090321, 0.580068176669682, 0.28821316860056356`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 340}], {
             RGBColor[
             0.9092736160962124, 0.5902460669486567, 0.36775903489702405`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 400}], {
             RGBColor[
             0.6071900057616888, 0.351637441026028, 0.5586994341727993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 192}], {
             RGBColor[
             0.3140196057697616, 0.4440801406652496, 0.941315327256403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[
             0.27998787707886075`, 0.41161538943957654`, 0.9392562674434715]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.2874735215718495, 0.4194832764189812, 0.9396825638233285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 228}], {
             RGBColor[
             0.32570332239411426`, 0.45419998876459156`, 0.9420598033482018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 243}], {
             RGBColor[
             0.28596070978623506`, 0.41789321531449325`, 0.9395964114301423]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 348}], {
             RGBColor[
             0.2732523450214962, 0.4045359181898883, 0.9388726888571313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 351}], {
             RGBColor[
             0.2646469792533301, 0.39549113315584294`, 0.938382626007132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 170}], {
             RGBColor[
             0.5575600626847299, 0.651038994684655, 0.958666022792408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 180}], {
             RGBColor[
             0.5182102560481305, 0.6169561699548207, 0.9561586879091916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 220}], {
             RGBColor[
             0.5727925024434088, 0.663632053166977, 0.9598025445321408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 251}], {
             RGBColor[
             0.7462331666341901, 0.8017011358685895, 0.9753362046447762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 282}], {
             RGBColor[
             0.6585061316418895, 0.73314926196139, 0.9665973951785392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 350}], {
             RGBColor[
             0.5514466203488134, 0.6457438382038303, 0.9582764796526682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 357}], {
             RGBColor[
             0.6729202964028389, 0.7444097170243531, 0.9680340644138824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 394}], {
             RGBColor[
             0.5145092206731405, 0.613750519132451, 0.9559228612077943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 209}], {
             RGBColor[
             0.23636572886417778`, 0.36576574586200267`, 0.9367720506358304]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 227}], {
             RGBColor[
             0.22781024002051087`, 0.3567733846379857, 0.936284828202895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 240}], {
             RGBColor[
             0.22995248947003588`, 0.35902502463589653`, 0.9364068261398715]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 245}], {
             RGBColor[
             0.22529865841710267`, 0.3541335531293326, 0.936141797346133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 280}], {
             RGBColor[
             0.229855838803546, 0.3589234386574095, 0.9364013220273968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 292}], {
             RGBColor[
             0.21585857380573317`, 0.34421142566684904`, 0.9356041984928691]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 304}], {
             RGBColor[
             0.21989845129097363`, 0.3484575930468634, 0.9358342635391905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 315}], {
             RGBColor[
             0.23198634740170132`, 0.3611627382761178, 0.9365226513402567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 329}], {
             RGBColor[
             0.22791864695390707`, 0.3568873271983817, 0.9362910018173783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 353}], {
             RGBColor[
             0.21553905850906607`, 0.343875594831612, 0.9355860025694045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 378}], {
             RGBColor[
             0.21461245212241514`, 0.34290167276900374`, 0.9355332337064761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 180}], {
             RGBColor[
             0.40561982873439206`, 0.5257492414295251, 0.9470667147047922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 239}], {
             RGBColor[
             0.38474227729381244`, 0.5076661557079413, 0.9457364155882924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 251}], {
             RGBColor[
             0.6336427393204518, 0.7104942073432939, 0.966244231440377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 271}], {
             RGBColor[
             0.37587875919358854`, 0.49980798052879155`, 0.9451782688612774]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 282}], {
             RGBColor[
             0.5459157043281511, 0.6419423334360943, 0.9575054219741398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 326}], {
             RGBColor[
             0.39217993552288943`, 0.5141082814383957, 0.9462103365937862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 182}], {
             RGBColor[
             0.2806534492526592, 0.41231494799395196`, 0.9392941707941435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 244}], {
             RGBColor[
             0.266624380952421, 0.39756950771609656`, 0.9384952361085915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 253}], {
             RGBColor[
             0.30746418261270597`, 0.43744644735605664`, 0.9409326149067666]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 270}], {
             RGBColor[
             0.2613998670743656, 0.3920782123769482, 0.9381977077722119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 308}], {
             RGBColor[
             0.26715048285961845`, 0.3981224741773486, 0.9385251968339084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 397}], {
             RGBColor[
             0.26128106780929927`, 0.39195334681705507`, 0.9381909423298143]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 211}], {
             RGBColor[
             0.2820509294380053, 0.413783788274112, 0.9393737552233123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 328}], {
             RGBColor[
             0.3054309232922502, 0.438293739399488, 0.9407075511532149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 347}], {
             RGBColor[
             0.29073737323035515`, 0.422913791452218, 0.9398684353468445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 364}], {
             RGBColor[
             0.3254772137216906, 0.45565682861361634`, 0.9419848830531403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 387}], {
             RGBColor[
             0.29749670616801155`, 0.43001827893615596`, 0.9402533693581072]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 175}], {
             RGBColor[
             0.20264987627198583`, 0.3303282470790865, 0.9348519827088393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 197}], {
             RGBColor[
             0.607559522477704, 0.6724367666110929, 0.8861420267905455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 204}], {
             RGBColor[
             0.20264730553141047`, 0.33032554506774736`, 0.9348518363089665]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 214}], {
             RGBColor[
             0.6050703523847987, 0.6713378352539525, 0.9242773858520503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 261}], {
             RGBColor[
             0.2029079903175545, 0.3305995413063548, 0.9348666819218888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 295}], {
             RGBColor[
             0.23437748052955032`, 0.36367597080008385`, 0.9366588228345232]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 310}], {
             RGBColor[
             0.20447288081658893`, 0.33224434044062834`, 0.9349558001207607]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 345}], {
             RGBColor[
             0.21415750276433887`, 0.34242349214821033`, 0.9355073250135709]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 193}], {
             RGBColor[
             0.7754724977883137, 0.8245433157037161, 0.9782504569369469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 232}], {
             RGBColor[
             0.6270810139261389, 0.7068104580353534, 0.9646885621008761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 235}], {
             RGBColor[
             0.7343495307888845, 0.7923987018062052, 0.9741567564086497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 260}], {
             RGBColor[
             0.7687797089830702, 0.819295818690549, 0.9775884348027377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 267}], {
             RGBColor[
             0.6499021646261236, 0.725337696254724, 0.9664851266806084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 272}], {
             RGBColor[
             0.6878111560407678, 0.756042569748228, 0.9695182461395961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 275}], {
             RGBColor[
             0.8603530123804088, 0.8894563784374243, 0.877080294609712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 281}], {
             RGBColor[
             0.6802997161269625, 0.7500157979571946, 0.9688781332846546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 291}], {
             RGBColor[
             0.7125484820155874, 0.7753675568103979, 0.9719838316093115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 338}], {
             RGBColor[
             0.8614468790047858, 0.8890515325777966, 0.796643588235805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 384}], {
             RGBColor[
             0.7385166114389616, 0.7956540568810313, 0.9745720920642666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 398}], {
             RGBColor[
             0.83401539327211, 0.8711277377968187, 0.9805027030161089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 204}], {
             RGBColor[
             0.17892957074057536`, 0.30539670201133906`, 0.9335011463998728]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 214}], {
             RGBColor[
             0.5813526175939636, 0.6464089921975442, 0.9229266959429565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 256}], {
             RGBColor[
             0.20212025348377827`, 0.329771579948656, 0.9348218214745575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 261}], {
             RGBColor[
             0.1791902555267194, 0.3056706982499465, 0.9335159920127951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 264}], {
             RGBColor[
             0.18448157797338877`, 0.31123221363061604`, 0.9338173249983228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 295}], {
             RGBColor[
             0.21065974573871524`, 0.33874712774367555`, 0.9353081329254295]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 310}], {
             RGBColor[
             0.18075514602575382`, 0.30731549738422004`, 0.933605110211667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 345}], {
             RGBColor[
             0.1904397679735038, 0.31749464909180203`, 0.9341566351044772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 186}], {
             RGBColor[
             0.23214557991116364`, 0.36133010173948693`, 0.9365317193961071]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 226}], {
             RGBColor[
             0.22722875741095702`, 0.3561622095472178, 0.9362517136285073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 294}], {
             RGBColor[
             0.21429151975408078`, 0.34256435250159695`, 0.9355149570828762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 341}], {
             RGBColor[
             0.21870360025711671`, 0.3472017288523488, 0.9357662185404361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 368}], {
             RGBColor[
             0.2143024966118115, 0.34257588987504495`, 0.9355155821986852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 379}], {
             RGBColor[
             0.2183904240990045, 0.34687256085365753`, 0.9357483836215341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 393}], {
             RGBColor[
             0.2193217433014607, 0.3478514363844869, 0.9358014208723507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 399}], {
             RGBColor[
             0.22535125221155355`, 0.3541888325419396, 0.9361447924849214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 200}], {
             RGBColor[
             0.2962840776702533, 0.42752676637236176`, 0.9402288709406241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 225}], {
             RGBColor[
             0.2895083029136421, 0.42040499749423077`, 0.9398430005920957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 296}], {
             RGBColor[
             0.3117150207517371, 0.4437456659293011, 0.9411076403210801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 311}], {
             RGBColor[
             0.42064126980492156`, 0.5369664823599833, 0.9485194381294991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 324}], {
             RGBColor[
             0.3009330775683418, 0.4324131600288711, 0.9404936246072413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 339}], {
             RGBColor[
             0.34383450141698674`, 0.4722338963280338, 0.9431298082827468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 360}], {
             RGBColor[
             0.31615011179738517`, 0.4482550694974156, 0.9413657834565303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 374}], {
             RGBColor[
             0.29900611365793894`, 0.43038779878246913`, 0.9403838868632315]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 375}], {
             RGBColor[
             0.28837692064883436`, 0.4192158430001391, 0.939778570045845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 383}], {
             RGBColor[
             0.3010724134398118, 0.43255961086419054`, 0.9405015595789926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 390}], {
             RGBColor[
             0.2941038875347629, 0.4252352483079229, 0.9401047123377103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 209}], {
             RGBColor[
             0.24801071646784933`, 0.37800536616831976`, 0.9374352154526442]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 229}], {
             RGBColor[
             0.24544230257567465`, 0.37530580032079786`, 0.9372889480811126]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 240}], {
             RGBColor[
             0.24159747707370743`, 0.3712646449422136, 0.9370699909566852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 245}], {
             RGBColor[
             0.23694364602077422`, 0.3663731734356497, 0.9368049621629467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 248}], {
             RGBColor[
             0.230098166399185, 0.35917814032488304`, 0.9364151222254768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 309}], {
             RGBColor[
             0.2573894464516083, 0.38786300602707646`, 0.9379693202506316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 315}], {
             RGBColor[
             0.24363133500537287`, 0.37340235858243487`, 0.9371858161570703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 319}], {
             RGBColor[
             0.24278605838252734`, 0.37251391925819094`, 0.9371376789038741]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 329}], {
             RGBColor[
             0.23956363455757862`, 0.36912694750469877`, 0.9369541666341921]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 334}], {
             RGBColor[
             0.25269374017822266`, 0.3829275210087747, 0.9377019067250372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 371}], {
             RGBColor[
             0.25801702472850174`, 0.38852263058685255`, 0.9380050599050818]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 388}], {
             RGBColor[
             0.23367677668762307`, 0.36293948663502873`, 0.9366189187873238]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 196}], {
             RGBColor[
             0.2837836367777321, 0.41560497354815545`, 0.9394724303429989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 231}], {
             RGBColor[
             0.28916364068982703`, 0.4212596987717169, 0.9397788136067902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 303}], {
             RGBColor[
             0.27962744891017854`, 0.4112365565818258, 0.9392357415924706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 313}], {
             RGBColor[
             0.2762257553297003, 0.407661160948913, 0.939042020175417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 344}], {
             RGBColor[
             0.29513590341832135`, 0.4264382934400302, 0.9401591514378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 359}], {
             RGBColor[
             0.2576056390091489, 0.3880902381124516, 0.9379816320969553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 239}], {
             RGBColor[
             0.3453924706572131, 0.47358333097810695`, 0.943229080705076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 271}], {
             RGBColor[
             0.3365289525569892, 0.46572515579895724`, 0.942670933978061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 282}], {
             RGBColor[
             0.5065658976915518, 0.60785950870626, 0.9549980870909234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 326}], {
             RGBColor[
             0.3528301288862901, 0.48002545670856134`, 0.9437030017105699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 350}], {
             RGBColor[
             0.3995063863984757, 0.5204540849487005, 0.9466771715650524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 394}], {
             RGBColor[
             0.36256898672280274`, 0.4884607658773212, 0.9443235531201786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 250}], {
             RGBColor[
             0.7777697545864616, 0.8245041838583995, 0.9019245302265969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 265}], {
             RGBColor[
             0.5796034948121, 0.6695872537851715, 0.9600476567506184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 322}], {
             RGBColor[
             0.5378642093893072, 0.6357014215455682, 0.9567617873060958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 362}], {
             RGBColor[
             0.4859856594800335, 0.59226287242109, 0.9530427707548238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 244}], {
             RGBColor[
             0.27406524356197104`, 0.4053903260966717, 0.9389189822264357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 253}], {
             RGBColor[
             0.31490504522225604`, 0.4452672657366318, 0.9413563610246107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 271}], {
             RGBColor[
             0.28286075625291396`, 0.4146349676025667, 0.9394198736623899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 273}], {
             RGBColor[
             0.26718551324119244`, 0.3981592933294373, 0.9385271917623162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 335}], {
             RGBColor[
             0.2697259044179279, 0.4008294055262898, 0.9386718632816594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 305}], {
             RGBColor[
             0.21033276310750965`, 0.33840344826638225`, 0.9352895117483098]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 325}], {
             RGBColor[
             0.2146653182782982, 0.3429572384507447, 0.9355362443558451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 213}], {
             RGBColor[
             0.8673292987337209, 0.4339131427504039, 0.20877019917985573`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 224}], {
             RGBColor[
             0.8996759960158076, 0.5563318548969114, 0.2651346625378677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 247}], {
             RGBColor[
             0.8653490116625105, 0.42606196440460237`, 0.20717681371904806`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 289}], {
             RGBColor[
             0.8607218959500621, 0.40585224662813213`, 0.20335726643267069`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 302}], {
             RGBColor[
             0.905483758897311, 0.5759228028237954, 0.28769672462851575`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 340}], {
             RGBColor[
             0.9087343059844912, 0.5861006931027701, 0.36724259092497624`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 400}], {
             RGBColor[
             0.6066506956499677, 0.3474920671801415, 0.5581829902007515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 189}], {
             RGBColor[
             0.2745072076984255, 0.4058548584262301, 0.9389441514301794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 200}], {
             RGBColor[
             0.2595636633022175, 0.3901482457903771, 0.9380931386838082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 226}], {
             RGBColor[
             0.24355084950968384`, 0.37331776322339055`, 0.9371812326271585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 241}], {
             RGBColor[
             0.2697148101734317, 0.4008177447719086, 0.9386712314808479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 255}], {
             RGBColor[
             0.2544713249858168, 0.38479587534694254`, 0.9378031375501286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 288}], {
             RGBColor[
             0.2467468316416792, 0.3766769430810886, 0.9373632390815438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 341}], {
             RGBColor[
             0.23502569235584353`, 0.3643572825285215, 0.9366957375390872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 374}], {
             RGBColor[
             0.2622856992899031, 0.3930092782004845, 0.9382481546064155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 393}], {
             RGBColor[
             0.23564383540018752`, 0.36500699006065973`, 0.9367309398710019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 399}], {
             RGBColor[
             0.24167334431028037`, 0.3713443862181124, 0.9370743114835726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 193}], {
             RGBColor[
             0.8331367258093362, 0.8697846265391334, 0.9839465187292714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 218}], {
             RGBColor[
             0.8769988069965478, 0.9047590594733392, 0.9881301231890498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 232}], {
             RGBColor[
             0.6847452419471614, 0.7520517688707707, 0.9703846238932006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 235}], {
             RGBColor[
             0.792013758809907, 0.8376400126416226, 0.9798528182009743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 275}], {
             RGBColor[
             0.9180172404014313, 0.9346976892728417, 0.8827763564020366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 279}], {
             RGBColor[
             0.8947917399967904, 0.8503099582405043, 0.6300514927715455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 281}], {
             RGBColor[
             0.7379639441479849, 0.795257108792612, 0.9745741950769791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 298}], {
             RGBColor[
             0.8336819864556111, 0.8702194025777671, 0.983998526176473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 306}], {
             RGBColor[
             0.9071549779062498, 0.8950638881018478, 0.6621967951023203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 195}], {
             RGBColor[
             0.25639031228130726`, 0.3868128526653249, 0.9379124210377194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 203}], {
             RGBColor[
             0.2792417470878428, 0.4108311595116429, 0.9392137764442834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 206}], {
             RGBColor[
             0.2493239941811602, 0.37938570431162577`, 0.937510004675597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 208}], {
             RGBColor[
             0.25008631824464794`, 0.38018695523648866`, 0.9375534179032552]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 258}], {
             RGBColor[
             0.2600095899871553, 0.39061694300963157`, 0.938118533548826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 278}], {
             RGBColor[
             0.2597507710467335, 0.39034490789317966`, 0.9381037941930572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 284}], {
             RGBColor[
             0.25554200422115014`, 0.38592122710826227`, 0.9378641111486529]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 327}], {
             RGBColor[
             0.2928390260811543, 0.4242124195155595, 0.9400214534598996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 361}], {
             RGBColor[
             0.3113562197109362, 0.44025108193646334`, 0.9412013526638779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 369}], {
             RGBColor[
             0.26226993371413826`, 0.39299270758076044`, 0.9382472567801988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 392}], {
             RGBColor[
             0.25751756533120074`, 0.38799766709273437`, 0.9379766164312895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 200}], {
             RGBColor[
             0.28560319899075254`, 0.41751744880094743`, 0.9395760517192293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 219}], {
             RGBColor[
             0.37386729373661226`, 0.4974887142474586, 0.9450712281757306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 241}], {
             RGBColor[
             0.2957543458619668, 0.428186947782479, 0.9401541445162689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 255}], {
             RGBColor[
             0.28051086067435194`, 0.4121650783575129, 0.9392860505855498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 339}], {
             RGBColor[
             0.333153622737486, 0.4622245787566195, 0.942476989061352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 360}], {
             RGBColor[
             0.30546923311788443`, 0.43824575192600135`, 0.9407129642351355]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 374}], {
             RGBColor[
             0.2883252349784382, 0.42037848121105487`, 0.9397310676418367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 266}], {
             RGBColor[
             0.24805045871485498`, 0.3780471377897267, 0.9374374787148178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 273}], {
             RGBColor[
             0.2582701914773965, 0.38878872489163985`, 0.9380194773769047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 365}], {
             RGBColor[
             0.24867185173243342`, 0.3787002612497945, 0.9374728661279003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 198}], {
             RGBColor[
             0.7526714957518834, 0.806764542665624, 0.9759689648481673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 216}], {
             RGBColor[
             0.6689774683276695, 0.7413295497654275, 0.9676410801591727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 219}], {
             RGBColor[
             0.5630206032370957, 0.6553990201614963, 0.9591704044347413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 220}], {
             RGBColor[
             0.5771439386381384, 0.6670314281944398, 0.9602362550255482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 311}], {
             RGBColor[
             0.5991137006259042, 0.6848674707026068, 0.961965795167115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 323}], {
             RGBColor[
             0.7545318035699571, 0.8082479016230455, 0.9761464026685716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 339}], {
             RGBColor[
             0.5223069322379694, 0.6201348846706572, 0.9565761653203628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 357}], {
             RGBColor[
             0.6772717325975683, 0.7478090920518159, 0.9684677749072899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 201}], {
             RGBColor[
             0.3104580154232146, 0.4403366833931581, 0.941112499955068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 203}], {
             RGBColor[
             0.31794365991620344`, 0.4482045703725628, 0.9415387963349251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 228}], {
             RGBColor[
             0.35617346073846823`, 0.48292128271817314`, 0.9439160358597984]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 243}], {
             RGBColor[
             0.31643084813058897`, 0.44661450926807483`, 0.9414526439417388]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 332}], {
             RGBColor[
             0.43585567576042195`, 0.5499313562155932, 0.9495477612304457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 348}], {
             RGBColor[
             0.30372248336585006`, 0.4332572121434699, 0.9407289213687278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 361}], {
             RGBColor[
             0.35005813253929685`, 0.4776244927973833, 0.9435263725545195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 385}], {
             RGBColor[
             0.45995539470159097`, 0.5694965937320001, 0.9514449793856737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 232}], {
             RGBColor[
             0.6739481277148399, 0.7434424430617759, 0.9693547854990241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 235}], {
             RGBColor[
             0.7812166445775857, 0.8290306868326278, 0.9788229798067978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 260}], {
             RGBColor[
             0.8156468227717713, 0.8559278037169716, 0.9822546582008858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 275}], {
             RGBColor[
             0.9072201261691099, 0.9260883634638468, 0.8817465180078601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 281}], {
             RGBColor[
             0.7271668299156635, 0.7866477829836171, 0.9735443566828026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 338}], {
             RGBColor[
             0.9083139927934867, 0.9256835176042191, 0.801309811633953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 384}], {
             RGBColor[
             0.7853837252276628, 0.8322860419074539, 0.9792383154624147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 376}], {
             RGBColor[
             0.4132241787161002, 0.5323357471779375, 0.947551257161364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 377}], {
             RGBColor[
             0.40146722310948635`, 0.5221524631532592, 0.9468021143463783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 396}], {
             RGBColor[
             0.3331772870037427, 0.4601881672994485, 0.9425538104147095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 206}], {
             RGBColor[
             0.2386283880050733, 0.3681439440799593, 0.9369009057266002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 208}], {
             RGBColor[
             0.239390712068561, 0.3689451950048222, 0.9369443189542583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 258}], {
             RGBColor[
             0.24931398381106837`, 0.3793751827779651, 0.9375094345998292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 278}], {
             RGBColor[
             0.24905516487064655`, 0.3791031476615132, 0.9374946952440605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 284}], {
             RGBColor[
             0.24484639804506322`, 0.3746794668765958, 0.9372550121996561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 327}], {
             RGBColor[
             0.2821434199050674, 0.41297065928389304`, 0.9394123545109028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 337}], {
             RGBColor[
             0.26521901916211443`, 0.39609238336940045`, 0.9384152028336801]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 369}], {
             RGBColor[
             0.2515743275380513, 0.381750947349094, 0.9376381578312021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 392}], {
             RGBColor[
             0.24682195915511385`, 0.3767559068610679, 0.9373675174822926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 231}], {
             RGBColor[
             0.3033041199951848, 0.43612223907981873`, 0.9405840929842658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 234}], {
             RGBColor[
             0.3183317548341577, 0.44914414193399255`, 0.9415414311188043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 290}], {
             RGBColor[
             0.3515289166579535, 0.47789785496789633`, 0.943656724915119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 303}], {
             RGBColor[
             0.29376792821553643`, 0.42609909688992764`, 0.9400410209699464]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 313}], {
             RGBColor[
             0.2903662346350581, 0.4225237012570149, 0.9398472995528928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 344}], {
             RGBColor[
             0.3092763827236792, 0.441300833748132, 0.9409644308152758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 204}], {
             RGBColor[
             0.5838392169462935, 0.6475052215433456, 0.8847911904815791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 215}], {
             RGBColor[
             0.9040198154602492, 0.5694397771754294, 0.5010925431304881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 295}], {
             RGBColor[
             0.6155693919444334, 0.6808556472756819, 0.8865981770071358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 310}], {
             RGBColor[
             0.5856647922314719, 0.6494240169162264, 0.8848951542933734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 345}], {
             RGBColor[
             0.5953494141792219, 0.6596031686238084, 0.8854466791861835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 216}], {
             RGBColor[
             0.7427956016916255, 0.7990494191661757, 0.974984628023718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 219}], {
             RGBColor[
             0.6368387366010516, 0.7131188895622445, 0.9665139522992866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 224}], {
             RGBColor[
             0.901075568718926, 0.8970235530331128, 0.6716312488962854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 247}], {
             RGBColor[
             0.866748584365629, 0.7667536625408037, 0.6136734000774657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 302}], {
             RGBColor[
             0.9068833316004294, 0.9166145009599966, 0.6941933109869335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 311}], {
             RGBColor[
             0.6729318339898602, 0.7425873401033549, 0.9693093430316602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 323}], {
             RGBColor[
             0.828349936933913, 0.8659677710237936, 0.9834899505331167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 340}], {
             RGBColor[
             0.9101338786876096, 0.9267923912389714, 0.7737391772833939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 212}], {
             RGBColor[
             0.21834996970250586`, 0.3468300407179805, 0.9357460798035004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 238}], {
             RGBColor[
             0.22751293603602638`, 0.35646089930013114`, 0.9362678971808005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 252}], {
             RGBColor[
             0.2250679449332263, 0.3538910586296987, 0.9361286585545363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 277}], {
             RGBColor[
             0.24180779724081597`, 0.3714857047729135, 0.9370819683790612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 287}], {
             RGBColor[
             0.24300807911222783`, 0.3727472771220335, 0.9371503226559803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 293}], {
             RGBColor[
             0.21851691429369074`, 0.3470055100682143, 0.9357555870509962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 299}], {
             RGBColor[
             0.21996573354153404`, 0.3485283109581435, 0.9358380951638248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 336}], {
             RGBColor[
             0.2184046627263886, 0.34688752655381927`, 0.9357491944902996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 367}], {
             RGBColor[
             0.2225587298907346, 0.35125371452661747`, 0.9359857624699174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 225}], {
             RGBColor[
             0.26388387983793327`, 0.3946890672869635, 0.9383391686243296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 241}], {
             RGBColor[
             0.2808108014657587, 0.41248033514662596`, 0.9393031317698977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 255}], {
             RGBColor[
             0.26556731627814384`, 0.3964584657216599, 0.9384350378391786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 288}], {
             RGBColor[
             0.25784282293400623`, 0.38833953345580596`, 0.9379951393705938]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 296}], {
             RGBColor[
             0.2860905976760283, 0.41802973572203384`, 0.939603808353314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 339}], {
             RGBColor[
             0.3182100783412779, 0.4465179661207665, 0.9416259763149808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 355}], {
             RGBColor[
             0.2507904105311417, 0.380927000871623, 0.9375935149173598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 360}], {
             RGBColor[
             0.29052568872167633`, 0.4225391392901483, 0.9398619514887643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 374}], {
             RGBColor[
             0.27338169058223005`, 0.4046718685752019, 0.9388800548954654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 375}], {
             RGBColor[
             0.26275249757312547`, 0.3934999127928718, 0.9382747380780788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 383}], {
             RGBColor[
             0.27544799036410295`, 0.4068436806569232, 0.9389977276112265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 399}], {
             RGBColor[
             0.2527693356026074, 0.3830069765928298, 0.9377062117726225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 210}], {
             RGBColor[
             0.2881749983278178, 0.42022057296569904`, 0.9397225118868391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 228}], {
             RGBColor[
             0.3221417320475673, 0.45045653149250003`, 0.9418569760468667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 236}], {
             RGBColor[
             0.26347424346046877`, 0.3942585134818019, 0.9383158404386357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 243}], {
             RGBColor[
             0.2823991194396881, 0.4141497580424017, 0.9393935841288071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 263}], {
             RGBColor[
             0.26925494850456955`, 0.4003344010010207, 0.9386450430391104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 348}], {
             RGBColor[
             0.2696907546749492, 0.40079246091779686`, 0.9386698615557961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 351}], {
             RGBColor[
             0.26108538890678307`, 0.3917476758837515, 0.9381797987057969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 214}], {
             RGBColor[
             0.9200563597791344, 0.7107376048071281, 0.556968147234525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 217}], {
             RGBColor[
             0.8395826476787889, 0.30525515205179155`, 0.18553769416040178`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 257}], {
             RGBColor[
             0.8394733977788387, 0.30441540944716294`, 0.18543307633282935`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 264}], {
             RGBColor[
             0.5231853201585595, 0.37556082624020004`, 0.5678587762898913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 268}], {
             RGBColor[
             0.836829312925746, 0.2840918146209231, 0.18290109769144122`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 279}], {
             RGBColor[
             0.9009946329017078, 0.6281412966873632, 0.2383554119012628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 300}], {
             RGBColor[
             0.873168201892003, 0.5137197571930974, 0.21575357463755512`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 306}], {
             RGBColor[
             0.913357870811167, 0.6728952265487068, 0.2705007142320376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 363}], {
             RGBColor[
             0.8594260597663401, 0.4513198993592995, 0.20428679439717456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 381}], {
             RGBColor[
             0.9247433274483484, 0.7127453819428937, 0.4824095946157798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 243}], {
             RGBColor[
             0.28988476393267687`, 0.4220176450218065, 0.9398198805086642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 258}], {
             RGBColor[
             0.2721654186176039, 0.4033934896242831, 0.9388107900063931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 284}], {
             RGBColor[
             0.26769783285159876`, 0.3986977737229138, 0.93855636760622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 348}], {
             RGBColor[
             0.277176399167938, 0.4086603478972015, 0.9390961579356532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 361}], {
             RGBColor[
             0.32351204834138475`, 0.4530276285511149, 0.941893609121445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 369}], {
             RGBColor[
             0.2744257623445868, 0.405769254195412, 0.9389395132377659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 392}], {
             RGBColor[
             0.26967339396164935`, 0.4007742137073859, 0.9386688728888566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 261}], {
             RGBColor[
             0.17918768478614402`, 0.3056679962386074, 0.9335158456129223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 295}], {
             RGBColor[
             0.21065717499813985`, 0.33874442573233643`, 0.9353079865255567]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 310}], {
             RGBColor[
             0.18075257528517846`, 0.3073127953728809, 0.9336049638117943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 345}], {
             RGBColor[
             0.1904371972329284, 0.3174919470804629, 0.9341564887046044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 389}], {
             RGBColor[
             0.17900756331513207`, 0.305478677152213, 0.9335055879616141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 400}], {
             RGBColor[
             0.2842689537951664, 0.40863855928315673`, 0.939773820202813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 207}], {
             RGBColor[
             0.967562165289962, 0.8957834071543473, 0.4992706546503005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 221}], {
             RGBColor[
             0.9585637141169614, 0.9664203575638242, 0.8602427231177231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 230}], {
             RGBColor[
             0.9820628725503424, 0.9494608486926688, 0.5307965926515668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 250}], {
             RGBColor[
             0.9917478646376758, 0.990855544204543, 0.7864227690028461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 276}], {
             RGBColor[
             0.8804173286055655, 0.9045483902483498, 0.8526723312886473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 358}], {
             RGBColor[
             0.9819225924478814, 0.9489876509677333, 0.5302516309431803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 391}], {
             RGBColor[
             0.9078296512801215, 0.575024774186147, 0.4476180378082022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 208}], {
             RGBColor[
             0.23232439396841398`, 0.3615180466511231, 0.9365419025921359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 258}], {
             RGBColor[
             0.24224766571092132`, 0.37194803442426605`, 0.9371070182377067]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 278}], {
             RGBColor[
             0.24198884677049953`, 0.37167599930781414`, 0.937092278881938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 284}], {
             RGBColor[
             0.23778007994491618`, 0.3672523185228967, 0.9368525958375336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 369}], {
             RGBColor[
             0.2445080094379043, 0.3743237989953949, 0.9372357414690795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 392}], {
             RGBColor[
             0.23975564105496683`, 0.3693287585073688, 0.9369651011201702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 221}], {
             RGBColor[
             0.9308573670898133, 0.869892342221664, 0.6314368519575342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 230}], {
             RGBColor[
             0.9543565255231943, 0.8529328333505086, 0.30199072149137773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 233}], {
             RGBColor[
             0.8786570254685007, 0.4672262975790694, 0.21740805642807715`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 250}], {
             RGBColor[
             0.9640415176105277, 0.8943275288623829, 0.5576168978426572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 358}], {
             RGBColor[
             0.9542162454207332, 0.8524596356255733, 0.30144575978299126`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 366}], {
             RGBColor[
             0.9205681319812286, 0.7219373884597544, 0.2549015531776194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 391}], {
             RGBColor[
             0.8801233042529734, 0.4784967588439868, 0.2188121666480132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[
             0.24300998977440907`, 0.3727492853491289, 0.9371504314653649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 278}], {
             RGBColor[
             0.24275117083398723`, 0.37247725023267697`, 0.9371356921095961]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 284}], {
             RGBColor[
             0.23854240400840393`, 0.3680535694477596, 0.9368960090651918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 369}], {
             RGBColor[
             0.24527033350139205`, 0.37512504992025775`, 0.9372791546967377]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 392}], {
             RGBColor[
             0.24051796511845452`, 0.3701300094322317, 0.9370085143478284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 227}], {
             RGBColor[
             0.24347750032410487`, 0.3732406685787401, 0.9371770554995502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 229}], {
             RGBColor[
             0.24946457527559712`, 0.37953346395523513`, 0.937518010560954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 240}], {
             RGBColor[
             0.24561974977362988`, 0.37549230857665095`, 0.9372990534365266]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 245}], {
             RGBColor[
             0.2409659187206967, 0.37060083707008695`, 0.9370340246427882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 280}], {
             RGBColor[
             0.24552309910713999`, 0.37539072259816386`, 0.9372935493240518]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 304}], {
             RGBColor[
             0.23556571159456763`, 0.3649248769876179, 0.9367264908358456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 315}], {
             RGBColor[
             0.24765360770529532`, 0.37763002221687225`, 0.9374148786369118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 319}], {
             RGBColor[
             0.24680833108244982`, 0.37674158289262827`, 0.9373667413837155]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 329}], {
             RGBColor[
             0.24358590725750107`, 0.37335461113913604`, 0.9371832291140334]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 334}], {
             RGBColor[
             0.2567160128781451, 0.387155184643212, 0.9379309692048785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 371}], {
             RGBColor[
             0.26203929742842424`, 0.3927502942212898, 0.9382341223849231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 236}], {
             RGBColor[
             0.27522295505597283`, 0.4066071542800159, 0.9389849121833385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 263}], {
             RGBColor[
             0.2810036601000736, 0.41268304179923465`, 0.9393141147838132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 301}], {
             RGBColor[
             0.25974755171345176`, 0.39034152416978307`, 0.9381036108567895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 328}], {
             RGBColor[
             0.2860571913279975, 0.41793071873950494`, 0.9396042457787188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 347}], {
             RGBColor[
             0.27136364126610246`, 0.4025507707922349, 0.9387651299723484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 372}], {
             RGBColor[
             0.257077351430105, 0.3875349743715093, 0.9379515469008601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 387}], {
             RGBColor[
             0.27812297420375887`, 0.4096552582761729, 0.939150063983611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 238}], {
             RGBColor[
             0.22006014114382055`, 0.3486275393339343, 0.9358434715371114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 259}], {
             RGBColor[
             0.2109589325174653, 0.33906159201767927`, 0.935325171169872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 293}], {
             RGBColor[
             0.2110641194014849, 0.3391721501020175, 0.935331161407307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 299}], {
             RGBColor[
             0.2125129386493282, 0.3406949509919467, 0.9354136695201356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 336}], {
             RGBColor[
             0.21095186783418274`, 0.3390541665876225, 0.9353247688466104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 367}], {
             RGBColor[
             0.21510593499852879`, 0.3434203545604207, 0.9355613368262283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 224}], {
             RGBColor[
             0.9433148110399261, 0.8071439818533458, 0.30358552172184644`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 230}], {
             RGBColor[
             0.939912673270707, 0.7956677722978341, 0.2903688589282392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 247}], {
             RGBColor[
             0.9089878266866289, 0.6768740913610367, 0.24562767290302676`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 250}], {
             RGBColor[
             0.9495976653580405, 0.8370624678097084, 0.5459950352795185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 289}], {
             RGBColor[
             0.9043607109741805, 0.6566643735845665, 0.24180812561664938`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 302}], {
             RGBColor[
             0.9491225739214294, 0.8267349297802298, 0.3261475838124945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 340}], {
             RGBColor[
             0.9523731210086097, 0.8369128200592044, 0.40569345010895497`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 391}], {
             RGBColor[
             0.8656794520004861, 0.4212316977913123, 0.20719030408487465`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 215}], {
             RGBColor[
             0.9015306453673441, 0.5683408458182889, 0.5392279021919928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 217}], {
             RGBColor[
             0.903299381606431, 0.5819361276170735, 0.5409216460120444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 261}], {
             RGBColor[
             0.5816107316395323, 0.6466802864248125, 0.9229413951560062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 264}], {
             RGBColor[
             0.5869020540862017, 0.6522418018054821, 0.9232427281415339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 295}], {
             RGBColor[
             0.6130802218515281, 0.6797567159185416, 0.9247335360686406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 300}], {
             RGBColor[
             0.9368849358196452, 0.7904007327583793, 0.5711375264891978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 310}], {
             RGBColor[
             0.5831756221385668, 0.6483250855590861, 0.9230305133548782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 363}], {
             RGBColor[
             0.9231427936939823, 0.7280008749245814, 0.5596707462488172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 217}], {
             RGBColor[
             0.8210569332669986, 0.16285839306295227`, 0.16779744911786956`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 269}], {
             RGBColor[
             0.9061735630089964, 0.5684125935804545, 0.32599457253607145`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 295}], {
             RGBColor[
             0.5308377735120957, 0.2606789813644203, 0.5516093391744658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 300}], {
             RGBColor[
             0.8546424874802127, 0.37132299820425807`, 0.1980133295950229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 352}], {
             RGBColor[
             0.906721166296464, 0.5695838616411621, 0.3855978109611532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 363}], {
             RGBColor[
             0.8409003453545498, 0.3089231403704602, 0.18654654935464235`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 219}], {
             RGBColor[
             0.5531447091768378, 0.647683896662048, 0.958186067610292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 220}], {
             RGBColor[
             0.5672680445778805, 0.6593163046949915, 0.9592519182010989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 311}], {
             RGBColor[
             0.5892378065656463, 0.6771523472031584, 0.9609814583426657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 323}], {
             RGBColor[
             0.7446559095096992, 0.8005327781235971, 0.9751620658441222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 339}], {
             RGBColor[
             0.5124310381777115, 0.6124197611712089, 0.9555918284959135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 357}], {
             RGBColor[
             0.6673958385373104, 0.7400939685523675, 0.9674834380828405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 268}], {
             RGBColor[
             0.8200723347530428, 0.15529033743086842`, 0.16685459646896056`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 269}], {
             RGBColor[
             0.9079422992480835, 0.582007875379239, 0.32768831635612294`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 279}], {
             RGBColor[
             0.8842376547290044, 0.4993398194973086, 0.22230891067878217`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 300}], {
             RGBColor[
             0.8564112237192996, 0.3849182800030426, 0.19970707341507446`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 306}], {
             RGBColor[
             0.8966008926384637, 0.5440937493586522, 0.25445421300955695`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 363}], {
             RGBColor[
             0.8426690815936368, 0.3225184221692448, 0.1882402931746939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 262}], {
             RGBColor[
             0.9243533171861171, 0.9424423464401257, 0.9900148507220045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 269}], {
             RGBColor[
             0.9515613514707596, 0.9593431212476458, 0.7385846645144882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 279}], {
             RGBColor[
             0.9278567069516805, 0.8766750653657154, 0.6332052588371474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 298}], {
             RGBColor[
             0.8667469534105012, 0.8965845097029781, 0.9871522922420749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.9000302759419758, 0.7622535258714493, 0.6106034215734397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 306}], {
             RGBColor[
             0.9402199448611399, 0.9214289952270589, 0.6653505611679222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 314}], {
             RGBColor[
             0.9179378774680893, 0.9374027630058823, 0.9920349282773651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 220}], {
             RGBColor[
             0.4613111794873067, 0.5733857750910603, 0.9507812424766675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 241}], {
             RGBColor[
             0.36907489621161843`, 0.49245160059313714`, 0.9447983082263991]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 311}], {
             RGBColor[
             0.48328094147507245`, 0.5912218175992272, 0.9525107826182344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 323}], {
             RGBColor[
             0.6386990444191253, 0.7146022485196659, 0.9666913901196909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 339}], {
             RGBColor[
             0.4064741730871376, 0.5264892315672777, 0.9471211527714821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 357}], {
             RGBColor[
             0.5614389734467367, 0.6541634389484363, 0.9590127623584092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 360}], {
             RGBColor[
             0.37878978346753606`, 0.5025104047366595, 0.9453571279452656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 350}], {
             RGBColor[
             0.454088632793754, 0.5671299681608568, 0.9503210281880017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 357}], {
             RGBColor[
             0.5755623088477795, 0.6657958469813797, 0.960078612949216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 394}], {
             RGBColor[
             0.4171512331180811, 0.5351366490894776, 0.9479674097431279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 230}], {
             RGBColor[
             0.9453580743501937, 0.9235697837599854, 0.6629627899588003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 250}], {
             RGBColor[
             0.955043066437527, 0.9649644792718597, 0.9185889663100797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 276}], {
             RGBColor[
             0.8437125304054167, 0.8786573253156666, 0.9848385285958808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 358}], {
             RGBColor[
             0.9452177942477327, 0.9230965860350502, 0.6624178282504138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 251}], {
             RGBColor[
             0.7136213718875605, 0.7756511419302459, 0.9724778106511085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 297}], {
             RGBColor[
             0.7757829604608912, 0.8249349923236523, 0.9686258035292561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 312}], {
             RGBColor[
             0.5339420376563727, 0.632517225840949, 0.9564530195798908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 332}], {
             RGBColor[
             0.5660742539559687, 0.6586036065728093, 0.9589825853511816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 356}], {
             RGBColor[
             0.5616526527416191, 0.6550139515161355, 0.9586345007067291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 361}], {
             RGBColor[
             0.48027671073484357`, 0.5862967431545993, 0.9529611966752556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 260}], {
             RGBColor[
             0.6315106131402652, 0.7091757673875206, 0.9658788076150083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 267}], {
             RGBColor[
             0.5126330687833186, 0.6152176449516955, 0.954775499492879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 272}], {
             RGBColor[
             0.5505420601979628, 0.6459225184451997, 0.9578086189518668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 290}], {
             RGBColor[
             0.4296004547734099, 0.5464997120753861, 0.9486003596365518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 291}], {
             RGBColor[
             0.5752793861727824, 0.6652475055073694, 0.9602742044215822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 321}], {
             RGBColor[
             0.6359268279774656, 0.7126257479828174, 0.9663189746381065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 331}], {
             RGBColor[
             0.45307983116767014`, 0.5668363678003234, 0.9500964447383967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 342}], {
             RGBColor[
             0.5287126959381665, 0.6282718106549494, 0.9560413466441238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 346}], {
             RGBColor[
             0.3995496021231435, 0.5204711739094963, 0.9466855458786024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 384}], {
             RGBColor[
             0.6012475155961567, 0.6855340055780029, 0.9628624648765374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 398}], {
             RGBColor[
             0.696746297429305, 0.7610076864937902, 0.9687930758283795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 230}], {
             RGBColor[
             0.9722593705527938, 0.9180864844443417, 0.3467333222862512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 247}], {
             RGBColor[
             0.9413345239687156, 0.7992928035075443, 0.30199213626103877`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 289}], {
             RGBColor[
             0.9367074082562672, 0.779083085731074, 0.29817258897466137`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 302}], {
             RGBColor[
             0.981469271203516, 0.9491536419267372, 0.38251204717050646`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 323}], {
             RGBColor[
             0.9029358765369997, 0.8985069119905342, 0.6718086867166897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 340}], {
             RGBColor[
             0.9847198182906963, 0.959331532205712, 0.46205791346696695`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 288}], {
             RGBColor[
             0.25106704817739506`, 0.3812177645776751, 0.9376092690220652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 296}], {
             RGBColor[
             0.2793148229194171, 0.41090796684390285`, 0.9392179380047856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 316}], {
             RGBColor[
             0.2556938059368381, 0.38608078033623494`, 0.9378727560317908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 324}], {
             RGBColor[
             0.2685328797360218, 0.39957546094347285`, 0.9386039222909468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 355}], {
             RGBColor[
             0.24401463577453056`, 0.373805231993492, 0.9372076445688313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 375}], {
             RGBColor[
             0.2559767228165143, 0.3863781439147409, 0.9378888677295503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 380}], {
             RGBColor[
             0.2612993849996442, 0.39197259934548456`, 0.9381919854667065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 383}], {
             RGBColor[
             0.26867221560749177`, 0.39972191177879235`, 0.938611857262698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 390}], {
             RGBColor[
             0.26170368970244295`, 0.3923975492225247, 0.9382150100214157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 255}], {
             RGBColor[
             0.24955450248561023`, 0.3796279831546734, 0.9375231317825289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 266}], {
             RGBColor[
             0.24681597923856835`, 0.37674962158963, 0.9373671769348919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 294}], {
             RGBColor[
             0.22569678935260098`, 0.35455201398550057`, 0.9361644703139277]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 341}], {
             RGBColor[
             0.23010886985563692`, 0.3591893903362524, 0.9364157317714874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 368}], {
             RGBColor[
             0.2257077662103317, 0.35456355135894857`, 0.9361650954297367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 393}], {
             RGBColor[
             0.2307270128999809, 0.3598390978683905, 0.9364509341034022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 399}], {
             RGBColor[
             0.23675652181007376`, 0.36617649402584324`, 0.9367943057159729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 280}], {
             RGBColor[
             0.23696761026347307`, 0.36639836137414694`, 0.9368063268911165]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 304}], {
             RGBColor[
             0.22701022275090071`, 0.35593251576360085`, 0.9362392684029103]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 315}], {
             RGBColor[
             0.2390981188616284, 0.3686376609928552, 0.9369276562039764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 243}], {
             RGBColor[
             0.3281145647549416, 0.45673435736741674`, 0.9421971200335375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 332}], {
             RGBColor[
             0.44753939238477464`, 0.5600512043149352, 0.9502922373222444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 348}], {
             RGBColor[
             0.31540619999020275`, 0.44337706024281187`, 0.9414733974605265]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 361}], {
             RGBColor[
             0.3617418491636495, 0.4877443408967252, 0.9442708486463184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 385}], {
             RGBColor[
             0.4716391113259436, 0.5796164418313421, 0.9521894554774726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 240}], {
             RGBColor[
             0.24305133588145522`, 0.372792742729129, 0.9371527860649951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 245}], {
             RGBColor[
             0.238397504828522, 0.36790127122256505`, 0.9368877572712566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 248}], {
             RGBColor[
             0.2315520252069328, 0.36070623811179847`, 0.9364979173337866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 249}], {
             RGBColor[
             0.2582327214414536, 0.38874934150812634`, 0.9380173435137897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 309}], {
             RGBColor[
             0.25884330525935606`, 0.3893911038139919, 0.9380521153589414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 315}], {
             RGBColor[
             0.24508519381312066`, 0.3749304563693503, 0.9372686112653803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 319}], {
             RGBColor[
             0.24423991719027513`, 0.3740420170451063, 0.9372204740121839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[
             0.2410174933653264, 0.37065504529161414`, 0.937036961742502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 334}], {
             RGBColor[
             0.25414759898597045`, 0.3844556187956901, 0.9377847018333471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 371}], {
             RGBColor[
             0.25947088353624953`, 0.3900507283737679, 0.9380878550133916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 388}], {
             RGBColor[
             0.23513063549537086`, 0.3644675844219441, 0.9367017138956337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 247}], {
             RGBColor[
             0.9379323861994966, 0.7878165939520326, 0.28877547346743154`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 250}], {
             RGBColor[
             0.9785422248709081, 0.9480049704007043, 0.5891428358439234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 289}], {
             RGBColor[
             0.9333052704870481, 0.7676068761755623, 0.28495592618105414`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 358}], {
             RGBColor[
             0.9687169526811137, 0.9061370771638947, 0.3329716977842575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 391}], {
             RGBColor[
             0.8946240115133538, 0.5321742003823082, 0.2503381046492794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 234}], {
             RGBColor[
             0.3237117587462526, 0.454798867157554, 0.9418478143825956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 290}], {
             RGBColor[
             0.3569089205700484, 0.48355258019145775`, 0.9439631081789103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 313}], {
             RGBColor[
             0.295746238547153, 0.4281784264805763, 0.9401536828166841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 331}], {
             RGBColor[
             0.38038829696430865`, 0.5038892359163952, 0.9454591932807552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 359}], {
             RGBColor[
             0.2771261222266016, 0.4086075036441148, 0.9390932947382222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 235}], {
             RGBColor[
             0.6328251607154107, 0.7112978291642651, 0.965261084970727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 281}], {
             RGBColor[
             0.5787753460534887, 0.6689149253152545, 0.9599824618467317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 384}], {
             RGBColor[
             0.6369922413654878, 0.7145531842390913, 0.965676420626344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 386}], {
             RGBColor[
             0.4324598922567031, 0.5470353068857565, 0.9493188938960907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 242}], {
             RGBColor[
             0.867902536299588, 0.4245883317454004, 0.20875474200246447`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 317}], {
             RGBColor[
             0.9040426479180714, 0.5627946336685001, 0.48467433968140694`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 358}], {
             RGBColor[
             0.8930174526264201, 0.5204305413924555, 0.24838903272095686`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 366}], {
             RGBColor[
             0.8593693391869154, 0.3899082942266366, 0.20184482611558502`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 382}], {
             RGBColor[
             0.8581195774771997, 0.3842334181920808, 0.20080199431053547`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 290}], {
             RGBColor[
             0.37193655540902126`, 0.4965744830456317, 0.9449204463134487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 313}], {
             RGBColor[
             0.3107738733861259, 0.4412003293347502, 0.9411110209512226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 331}], {
             RGBColor[
             0.3954159318032815, 0.5169111387705692, 0.9464165314152937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 342}], {
             RGBColor[
             0.47104879657377785`, 0.578346581625195, 0.9523614333210206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 346}], {
             RGBColor[
             0.34188570275875485`, 0.4705459448797419, 0.9430056325554994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 275}], {
             RGBColor[
             0.8660971591696807, 0.893943749566336, 0.8776528174795629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 281}], {
             RGBColor[
             0.6860438629162344, 0.7545031690861064, 0.9694506561545053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 384}], {
             RGBColor[
             0.7442607582282336, 0.800141428009943, 0.9751446149341176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 263}], {
             RGBColor[
             0.2563029052327246, 0.3867209823153376, 0.9379074433356098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 351}], {
             RGBColor[
             0.2481333456349381, 0.37813425719806837`, 0.9374421990022963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 246}], {
             RGBColor[
             0.5111109439056949, 0.6137235569467266, 0.9547270574586124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 254}], {
             RGBColor[
             0.5239652108029346, 0.6244175883504002, 0.9556676072236672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 286}], {
             RGBColor[
             0.652334455595527, 0.7273484229582274, 0.9666519351718024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 320}], {
             RGBColor[
             0.644156525821959, 0.7209597620645476, 0.9658368355590718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 343}], {
             RGBColor[
             0.6503098019378368, 0.7257667481329021, 0.9664501366166679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 349}], {
             RGBColor[
             0.5118990860533059, 0.6144062060618112, 0.9547772771793315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 252}], {
             RGBColor[
             0.22677811637454098`, 0.3556885572456525, 0.9362260502881472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 277}], {
             RGBColor[
             0.24351796868213066`, 0.3732832033888673, 0.9371793601126722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 287}], {
             RGBColor[
             0.24471825055354252`, 0.3745447757379873, 0.9372477143895912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 293}], {
             RGBColor[
             0.22022708573500543`, 0.3488030086841681, 0.935852978784607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 299}], {
             RGBColor[
             0.22167590498284873`, 0.3503258095740973, 0.9359354868974357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 336}], {
             RGBColor[
             0.22011483416770328`, 0.34868502516977307`, 0.9358465862239105]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 367}], {
             RGBColor[
             0.2242689013320493, 0.35305121314257126`, 0.9360831542035284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 396}], {
             RGBColor[
             0.25376131131834845`, 0.3840496059649667, 0.9377627033221374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 271}], {
             RGBColor[
             0.31565140111640955`, 0.4476420700773734, 0.9413406348615612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 326}], {
             RGBColor[
             0.3319525774457105, 0.4619423709869775, 0.94237270259407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 335}], {
             RGBColor[
             0.3025165492814234, 0.4338365080010965, 0.9405926244808307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 337}], {
             RGBColor[
             0.304629125717821, 0.43605695978083275`, 0.9407129325836068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 354}], {
             RGBColor[
             0.3021441775416652, 0.43344512169287874`, 0.940571418461126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 245}], {
             RGBColor[
             0.2345526793265548, 0.3638601158439808, 0.9366688001468292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 248}], {
             RGBColor[
             0.22770719970496556`, 0.3566650827332143, 0.9362789602093593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 292}], {
             RGBColor[
             0.2251125947151853, 0.3539379883814973, 0.9361312012935654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 304}], {
             RGBColor[
             0.22915247220042573`, 0.35818415576151175`, 0.9363612663398866]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 309}], {
             RGBColor[
             0.2549984797573888, 0.3853499484354077, 0.9378331582345141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 315}], {
             RGBColor[
             0.24124036831115342`, 0.3708893009907661, 0.9370496541409528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 319}], {
             RGBColor[
             0.24039509168830792`, 0.37000086166652213`, 0.9370015168877566]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 329}], {
             RGBColor[
             0.23717266786335917`, 0.3666138899130299, 0.9368180046180745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 334}], {
             RGBColor[
             0.2503027734840032, 0.3804144634171059, 0.9375657447089196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 371}], {
             RGBColor[
             0.2556260580342823, 0.3860095729951837, 0.9378688978889642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 388}], {
             RGBColor[
             0.23128580999340365`, 0.36042642904335986`, 0.9364827567712063]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 255}], {
             RGBColor[
             0.2757184631493581, 0.40712796470319146`, 0.9390131306362182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 288}], {
             RGBColor[
             0.2679939698052205, 0.39900903243733754`, 0.9385732321676334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 339}], {
             RGBColor[
             0.32836122521249217`, 0.457187465102298, 0.9422040691120204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 360}], {
             RGBColor[
             0.3006768355928906, 0.4332086382716799, 0.9404400442858039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 374}], {
             RGBColor[
             0.2835328374534444, 0.4153413675567334, 0.939458147692505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 375}], {
             RGBColor[
             0.2729036444443398, 0.40416941177440335`, 0.9388528308751185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 399}], {
             RGBColor[
             0.2629204824738216, 0.3936764755743613, 0.938284304569662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 256}], {
             RGBColor[
             0.5718276027056971, 0.5340616080097416, 0.5946502523941279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 257}], {
             RGBColor[
             0.8704770048155868, 0.4443768248986645, 0.21122005596083127`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 268}], {
             RGBColor[
             0.8678329199624942, 0.4240532300724246, 0.2086880773194431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 317}], {
             RGBColor[
             0.954486951543472, 0.8521857620679489, 0.5290777523178287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 333}], {
             RGBColor[
             0.5569536477379948, 0.5184281382754727, 0.5938032026627618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 381}], {
             RGBColor[
             0.9557469344850966, 0.8527067973943953, 0.5081965742437817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 382}], {
             RGBColor[
             0.9085638811026002, 0.6736245465915296, 0.24520540694695725`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 348}], {
             RGBColor[
             0.27566358738232355`, 0.40707028679271356`, 0.9390100055424669]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 351}], {
             RGBColor[
             0.26705822161415743`, 0.39802550175866824`, 0.9385199426924677]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 253}], {
             RGBColor[
             0.30087597692201773`, 0.4305218254587764, 0.9405574263390588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 270}], {
             RGBColor[
             0.2548116613836774, 0.3851535904796679, 0.9378225192045042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 308}], {
             RGBColor[
             0.2605622771689302, 0.3911978522800683, 0.9381500082662007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 397}], {
             RGBColor[
             0.2546928621186111, 0.3850287249197748, 0.9378157537621064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 248}], {
             RGBColor[
             0.2230533686520324, 0.3517736112266503, 0.9360139314156208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 292}], {
             RGBColor[
             0.2204587636622521, 0.3490465168749334, 0.935866172499827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 304}], {
             RGBColor[
             0.22449864114749254`, 0.35329268425494775`, 0.9360962375461481]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 315}], {
             RGBColor[
             0.23658653725822024`, 0.3659978294842021, 0.9367846253472143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 319}], {
             RGBColor[
             0.2357412606353747, 0.36510939015995814`, 0.9367364880940181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 329}], {
             RGBColor[
             0.232518836810426, 0.36172241840646596`, 0.936552975824336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 353}], {
             RGBColor[
             0.220139248365585, 0.34871068603969635`, 0.9358479765763623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 371}], {
             RGBColor[
             0.25097222698134913`, 0.38111810148861974`, 0.9376038690952258]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 378}], {
             RGBColor[
             0.2192126419789341, 0.3477367639770881, 0.9357952077134337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 388}], {
             RGBColor[
             0.22663197894047044`, 0.3555349575367959, 0.9362177279774678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 254}], {
             RGBColor[
             0.4566571232556863, 0.569515492226385, 0.9504402532261262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 286}], {
             RGBColor[
             0.5850263680482788, 0.6724463268342122, 0.9614245811742612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 320}], {
             RGBColor[
             0.5768484382747107, 0.6660576659405324, 0.9606094815615308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 343}], {
             RGBColor[
             0.5830017143905886, 0.6708646520088869, 0.9612227826191269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 344}], {
             RGBColor[
             0.3822157528613575, 0.505477807231359, 0.9455754276855741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 349}], {
             RGBColor[
             0.44459099850605766`, 0.559504109937796, 0.9495499231817904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 289}], {
             RGBColor[
             0.9023804239029701, 0.648813195238765, 0.2402147401558417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 302}], {
             RGBColor[
             0.9471422868502191, 0.8188837514344283, 0.3245541983516868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 340}], {
             RGBColor[
             0.9503928339373993, 0.8290616417134029, 0.4041000646481473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 391}], {
             RGBColor[
             0.8636991649292758, 0.4133805194455108, 0.20559691862406698`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 292}], {
             RGBColor[
             0.21361328404066288`, 0.34185148376416674`, 0.935476332562357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 304}], {
             RGBColor[
             0.2176531615259033, 0.3460976511441812, 0.9357063976086782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 315}], {
             RGBColor[
             0.229741057636631, 0.35880279637343554`, 0.9363947854097444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 319}], {
             RGBColor[
             0.2288957810137855, 0.3579143570491916, 0.9363466481565481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 329}], {
             RGBColor[
             0.22567335718883677`, 0.3545273852956994, 0.9361631358868661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 353}], {
             RGBColor[
             0.21329376874399575`, 0.34151565292892977`, 0.9354581366388923]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 388}], {
             RGBColor[
             0.21978649931888122`, 0.34833992442602935`, 0.935827888039998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 270}], {
             RGBColor[
             0.25957821450255336`, 0.3901635400245296, 0.9380939673531408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 308}], {
             RGBColor[
             0.2653288302878062, 0.39620780182492993`, 0.9384214564148372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 309}], {
             RGBColor[
             0.2701798653173872, 0.40130654721440506`, 0.9386977156833087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 334}], {
             RGBColor[
             0.2654841590440016, 0.39637106219610324`, 0.9384303021577143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 386}], {
             RGBColor[
             0.3044662110801129, 0.4345129066433197, 0.9407539204836926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 397}], {
             RGBColor[
             0.25945941523748706`, 0.39003867446463636`, 0.938087201910743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 265}], {
             RGBColor[
             0.7900609571838799, 0.8344827358393506, 0.9028921387192244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 276}], {
             RGBColor[
             0.8768966809261312, 0.9030925119563854, 0.9110185744810039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 289}], {
             RGBColor[
             0.9429902625743816, 0.8090015716874366, 0.5405821025323335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 391}], {
             RGBColor[
             0.9043090036006871, 0.5735688958941825, 0.5059642810005588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 282}], {
             RGBColor[
             0.7345888082776114, 0.7926044746200289, 0.9741756038265081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 312}], {
             RGBColor[
             0.6426365090387243, 0.7180224324379316, 0.9668896222215277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 356}], {
             RGBColor[
             0.6703471241239707, 0.7405191581131181, 0.9690711033483659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 277}], {
             RGBColor[
             0.2410729775793306, 0.3707133627184349, 0.9370401214864079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 293}], {
             RGBColor[
             0.21778209463220533`, 0.3462331680137357, 0.9357137401583427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 330}], {
             RGBColor[
             0.2245525377985933, 0.3533493330524997, 0.9360993068806954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 386}], {
             RGBColor[
             0.3405394596215219, 0.4693798967384182, 0.942919851133231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 286}], {
             RGBColor[
             0.5978806349455185, 0.6831403582378857, 0.9623651309393161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 320}], {
             RGBColor[
             0.5897027051719504, 0.6767516973442059, 0.9615500313265857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 343}], {
             RGBColor[
             0.5958559812878284, 0.6815586834125604, 0.9621633323841816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 344}], {
             RGBColor[
             0.39507001975859724`, 0.5161718386350326, 0.946515977450629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 349}], {
             RGBColor[
             0.45744526540329744`, 0.5701981413414695, 0.9504904729468453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 288}], {
             RGBColor[
             0.25275048461760563`, 0.38298716301237146`, 0.9377051382369141]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 341}], {
             RGBColor[
             0.24102934533176992`, 0.3706675024598044, 0.9370376366944575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 360}], {
             RGBColor[
             0.28543335040527573`, 0.4171867688467138, 0.9395719503550848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 374}], {
             RGBColor[
             0.2682893522658295, 0.3993194981317673, 0.938590053761786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 393}], {
             RGBColor[
             0.2416474883761139, 0.3713172099919425, 0.9370728390263723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 399}], {
             RGBColor[
             0.24767699728620676`, 0.3776546061493952, 0.937416210638943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 261}], {
             RGBColor[
             0.20237836752934693`, 0.3300428741759244, 0.934836520687607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 264}], {
             RGBColor[
             0.2076696899760163, 0.3356043895565939, 0.9351378536731348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 317}], {
             RGBColor[
             0.6079677143241806, 0.6722679099328412, 0.8705698500730703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 333}], {
             RGBColor[
             0.21043441051870343`, 0.338510286140365, 0.9352953004180034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 381}], {
             RGBColor[
             0.6092276972658053, 0.6727889452592876, 0.8496886719990233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 268}], {
             RGBColor[
             0.8199630848530925, 0.15445059482623982`, 0.16674997864138813`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 338}], {
             RGBColor[
             0.9084477718580719, 0.5824829620653897, 0.3944924501077937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 381}], {
             RGBColor[
             0.9078770993756948, 0.5831041621482105, 0.46625847556572675`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 382}], {
             RGBColor[
             0.8606940459931985, 0.4040219113453448, 0.20326730826890227`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 278}], {
             RGBColor[
             0.25267444257649463`, 0.38290723800581994`, 0.937700807755167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 284}], {
             RGBColor[
             0.24846567575091127`, 0.3784835572209025, 0.9374611247107626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 369}], {
             RGBColor[
             0.2551936052438994, 0.3855550376934007, 0.9378442703423086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 392}], {
             RGBColor[
             0.25044123686096187`, 0.3805599972053746, 0.9375736299933992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 274}], {
             RGBColor[
             0.22087433163626, 0.34948330516414705`, 0.9358898384811689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 299}], {
             RGBColor[
             0.21257469635649348`, 0.34075986225784227`, 0.9354171865301963]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 318}], {
             RGBColor[
             0.2174190793227137, 0.34585161590696, 0.9356930669735002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 336}], {
             RGBColor[
             0.21101362554134806`, 0.339119077853518, 0.9353282858566712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 367}], {
             RGBColor[
             0.21516769270569408`, 0.3434852658263162, 0.935564853836289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 267}], {
             RGBColor[
             0.6900764896095811, 0.7567221842679797, 0.9704893279445472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 272}], {
             RGBColor[
             0.7279854810242253, 0.7874270577614837, 0.9735224474035349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 291}], {
             RGBColor[
             0.7527228069990448, 0.8067520448236535, 0.9759880328732503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 321}], {
             RGBColor[
             0.813370248803728, 0.8541302872991015, 0.9820328030897745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 338}], {
             RGBColor[
             0.9016212039882432, 0.9204360205910522, 0.8006477894997438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 342}], {
             RGBColor[
             0.706156116764429, 0.7697763499712335, 0.9717551750957918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 384}], {
             RGBColor[
             0.7786909364224193, 0.827038544894287, 0.9785762933282055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 398}], {
             RGBColor[
             0.8741897182555676, 0.9025122258100744, 0.9845069042800476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 264}], {
             RGBColor[
             0.1847396920189574, 0.3115035078578844, 0.9338320242113725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 295}], {
             RGBColor[
             0.2109178597842839, 0.3390184219709439, 0.935322832138479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 310}], {
             RGBColor[
             0.18101326007132248`, 0.3075867916114884, 0.9336198094247166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 381}], {
             RGBColor[
             0.5862976993087463, 0.6486880635605781, 0.8483828425372609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 269}], {
             RGBColor[
             0.965850894705439, 0.9706613010892211, 0.7373156259818411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 298}], {
             RGBColor[
             0.8810364966451805, 0.9079026895445534, 0.9858832537094278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 300}], {
             RGBColor[
             0.9143198191766551, 0.7735717057130247, 0.6093343830407926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 306}], {
             RGBColor[
             0.9545094880958191, 0.9327471750686342, 0.664081522635275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 307}], {
             RGBColor[
             0.9619414175862754, 0.970962445386637, 0.9415105792405329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 314}], {
             RGBColor[
             0.9322274207027686, 0.9487209428474576, 0.9907658897447179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 310}], {
             RGBColor[
             0.18630458251799184`, 0.3131483069921579, 0.9339211424102444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 333}], {
             RGBColor[
             0.19279573500831393`, 0.31997091982232506`, 0.9342908039417687]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 381}], {
             RGBColor[
             0.5915890217554157, 0.6542495789412477, 0.8486841755227887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 322}], {
             RGBColor[
             0.5501554119867256, 0.6456799735265193, 0.9577293957987232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 362}], {
             RGBColor[
             0.4982768620774518, 0.6022414244020411, 0.9540103792474512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 273}], {
             RGBColor[
             0.265217664230201, 0.3960909592500517, 0.938415125672312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 365}], {
             RGBColor[
             0.25561932448523794`, 0.3860024956082064, 0.9378685144233075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 272}], {
             RGBColor[
             0.6091079366672787, 0.6934689353256587, 0.9624191392814057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 291}], {
             RGBColor[
             0.6338452626420983, 0.7127939223878283, 0.964884724751121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 321}], {
             RGBColor[
             0.6944927044467815, 0.7601721648632764, 0.9709294949676452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 331}], {
             RGBColor[
             0.511645707636986, 0.6143827846807824, 0.9547069650679356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 342}], {
             RGBColor[
             0.5872785724074823, 0.6758182275354083, 0.9606518669736626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 346}], {
             RGBColor[
             0.4581154785924594, 0.5680175907899552, 0.9512960662081413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 384}], {
             RGBColor[
             0.6598133920654725, 0.7330804224584619, 0.9674729852060762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 398}], {
             RGBColor[
             0.7553121738986209, 0.8085541033742493, 0.9734035961579184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 338}], {
             RGBColor[
             0.9058036870049794, 0.5621593672391498, 0.39196047146640556`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 381}], {
             RGBColor[
             0.9052330145226024, 0.5627805673219706, 0.46372649692433865`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 279}], {
             RGBColor[
             0.9693542844710024, 0.9048940200148108, 0.380506034096984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 298}], {
             RGBColor[
             0.908244530929823, 0.9248034643520736, 0.7344530675019115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 300}], {
             RGBColor[
             0.9415278534612976, 0.7904724805205449, 0.35790419683327634`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 306}], {
             RGBColor[
             0.9817175223804617, 0.9496479498761543, 0.4126513364277588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 307}], {
             RGBColor[
             0.9891494518709179, 0.9878632201941573, 0.6900803930330166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 314}], {
             RGBColor[
             0.9594354549874111, 0.9656217176549777, 0.7393357035372017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 308}], {
             RGBColor[
             0.2553377632908749, 0.38570655694091993`, 0.9378524799298211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 397}], {
             RGBColor[
             0.2494683482405557, 0.3795374295806264, 0.9375182254257268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 273}], {
             RGBColor[
             0.2911126400044641, 0.42330822062509427`, 0.9398898062344726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 326}], {
             RGBColor[
             0.3230890593454866, 0.4540841958078278, 0.941814555867055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 335}], {
             RGBColor[
             0.2936530311811995, 0.4259783328219468, 0.9400344777538158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 394}], {
             RGBColor[
             0.3328279171819992, 0.4625195049765876, 0.9424351072766638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 291}], {
             RGBColor[
             0.6717542540567425, 0.7434987958813325, 0.9679178442101087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 321}], {
             RGBColor[
             0.7324016958614257, 0.7908770383567805, 0.9739626144266329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 331}], {
             RGBColor[
             0.5495546990516302, 0.6450876581742866, 0.9577400845269233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 338}], {
             RGBColor[
             0.8206526510459409, 0.8571827716487312, 0.7925776008366022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 342}], {
             RGBColor[
             0.6251875638221265, 0.7065231010289125, 0.9636849864326502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 346}], {
             RGBColor[
             0.4960244700071036, 0.5987224642834593, 0.954329185667129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 384}], {
             RGBColor[
             0.6977223834801167, 0.763785295951966, 0.9705061046650639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 398}], {
             RGBColor[
             0.7932211653132651, 0.8392589768677534, 0.976436715616906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 365}], {
             RGBColor[
             0.26583905724777945`, 0.3967440827101195, 0.9384505130853945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 394}], {
             RGBColor[
             0.3171526741702776, 0.4460438307034582, 0.9415424253765902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 287}], {
             RGBColor[
             0.2454706833388167, 0.37533563030230443`, 0.937290564323588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 299}], {
             RGBColor[
             0.22242833776812287`, 0.35111666413841447`, 0.9359783368314325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 318}], {
             RGBColor[
             0.2272727207343431, 0.3562084177875322, 0.9362542172747363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 367}], {
             RGBColor[
             0.22502133411732347`, 0.3538420677068884, 0.9361260041375251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 373}], {
             RGBColor[
             0.24052488712014738`, 0.3701372848948911, 0.9370089085455846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 395}], {
             RGBColor[
             0.2518980358087536, 0.3820911852658918, 0.9376565925383351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 279}], {
             RGBColor[
             0.9688751403565641, 0.9066136951652177, 0.5278514920501343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 281}], {
             RGBColor[
             0.8120473445077586, 0.8515608457173255, 0.8723741943555676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 306}], {
             RGBColor[
             0.9812383782660234, 0.9513676250265612, 0.559996794380909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 338}], {
             RGBColor[
             0.9931945073855819, 0.9905965803379274, 0.7001396493067182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 384}], {
             RGBColor[
             0.8702642398197578, 0.8971991046411623, 0.8780681531351799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 322}], {
             RGBColor[
             0.6369911357289768, 0.7142897496435541, 0.9658558315605028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 358}], {
             RGBColor[
             0.8670714087363368, 0.8612246187195758, 0.654847436421338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 376}], {
             RGBColor[
             0.6019797217390458, 0.6854606658855094, 0.9632115739949887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 377}], {
             RGBColor[
             0.590222766132432, 0.6752773818608311, 0.9624624311800029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 287}], {
             RGBColor[
             0.25901311175833214`, 0.3895695812107696, 0.9380617855878519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 330}], {
             RGBColor[
             0.24129239010618297`, 0.3709439791957144, 0.9370526167052204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 396}], {
             RGBColor[
             0.26805617252313807`, 0.399074411437749, 0.9385767745203981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 284}], {
             RGBColor[
             0.24820685681048946`, 0.3782115221044505, 0.9374463853549939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 327}], {
             RGBColor[
             0.28550387867049365`, 0.4165027145117478, 0.9396037276662406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 337}], {
             RGBColor[
             0.26857947792754067`, 0.39962443859725516`, 0.9386065759890179]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 354}], {
             RGBColor[
             0.2660945297513849, 0.3970126005093012, 0.9384650618665371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 392}], {
             RGBColor[
             0.2501824179205401, 0.3802879620889227, 0.9375588906376304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 300}], {
             RGBColor[
             0.9178232089422185, 0.7078044246386144, 0.2525247911559355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 306}], {
             RGBColor[
             0.9580128778613826, 0.8669798939942239, 0.307271930750418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 363}], {
             RGBColor[
             0.9040810668165558, 0.6454045668048165, 0.24105801091555495`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 384}], {
             RGBColor[
             0.6902109435663115, 0.7577585241609326, 0.9698659918101223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 386}], {
             RGBColor[
             0.4856785944575267, 0.5902406468075978, 0.9535084650798691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 350}], {
             RGBColor[
             0.5398022619922347, 0.6366471769552697, 0.9571158788344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 369}], {
             RGBColor[
             0.25072601947789425`, 0.3808593217920313, 0.9375898479421354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 392}], {
             RGBColor[
             0.24597365109495675`, 0.3758642813040053, 0.9373192075932261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 330}], {
             RGBColor[
             0.23174352854992997`, 0.3609075202673017, 0.9365088231658666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 387}], {
             RGBColor[
             0.2661419288540897, 0.3970624199715206, 0.9384677611753156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 320}], {
             RGBColor[
             0.7180719499645429, 0.7796825319520332, 0.9725343592747207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 343}], {
             RGBColor[
             0.7242252260804207, 0.7844895180203877, 0.9731476603323168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 349}], {
             RGBColor[
             0.5858145101958898, 0.6731289759492968, 0.9614748008949803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 367}], {
             RGBColor[
             0.23976404440825078`, 0.3693375909644736, 0.936965579678708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 373}], {
             RGBColor[
             0.2552675974110747, 0.3856328081524763, 0.9378484840867676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 395}], {
             RGBColor[
             0.2666407460996809, 0.397586708523477, 0.938496168079518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 396}], {
             RGBColor[
             0.2692564543945499, 0.400335983786869, 0.9386451287973171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 341}], {
             RGBColor[
             0.2333048519876323, 0.3625485701939505, 0.9365977382258728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 355}], {
             RGBColor[
             0.2379735788706035, 0.36745569816233453`, 0.9368636153150954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 360}], {
             RGBColor[
             0.2777088570611381, 0.4090678365808599, 0.9391320518865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 374}], {
             RGBColor[
             0.26056485892169184`, 0.3912005658659134, 0.9381501552932011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 375}], {
             RGBColor[
             0.24993566591258726`, 0.38002861008358335`, 0.9375448384758145]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 379}], {
             RGBColor[
             0.23299167582952007`, 0.3622194021952592, 0.9365799033069708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 393}], {
             RGBColor[
             0.23392299503197628`, 0.3631982777260886, 0.9366329405577875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 399}], {
             RGBColor[
             0.23995250394206913`, 0.3695356738835413, 0.9369763121703581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 302}], {
             RGBColor[
             0.9425151711377706, 0.798674033657958, 0.3207346510653094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 340}], {
             RGBColor[
             0.9457657182249508, 0.8088519239369327, 0.40028051736176995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 391}], {
             RGBColor[
             0.8590720492168273, 0.39317080166904056`, 0.2017773713376896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 313}], {
             RGBColor[
             0.34397103520992167`, 0.4699540423686539, 0.9432263147475373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 321}], {
             RGBColor[
             0.6114600904368728, 0.6914542319869668, 0.964754355111318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 331}], {
             RGBColor[
             0.42861309362707734`, 0.5456648518044729, 0.9485318252116084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 342}], {
             RGBColor[
             0.5042459583975736, 0.6071002946590989, 0.9544767271173353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 346}], {
             RGBColor[
             0.3750828645825507, 0.4992996579136456, 0.9451209263518141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 321}], {
             RGBColor[
             0.7571390218362452, 0.8102020254189503, 0.9764281998963484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 331}], {
             RGBColor[
             0.5742920250264498, 0.6644126452364563, 0.9602056699966387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 338}], {
             RGBColor[
             0.8453899770207604, 0.8765077587109009, 0.7950431863063177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 342}], {
             RGBColor[
             0.6499248897969461, 0.7258480880910823, 0.9661505719023658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 384}], {
             RGBColor[
             0.7224597094549363, 0.7831102830141358, 0.9729716901347794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 398}], {
             RGBColor[
             0.8179584912880846, 0.8585839639299231, 0.9789023010866215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 304}], {
             RGBColor[
             0.21505855653612305`, 0.3433705567924642, 0.9355586386928844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 329}], {
             RGBColor[
             0.22307875219905648`, 0.35180029094398246`, 0.9360153769710722]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 353}], {
             RGBColor[
             0.2106991637542155, 0.3387885585772128, 0.9353103777230984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 378}], {
             RGBColor[
             0.20977255736756456`, 0.3378146365146045, 0.93525760886017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 388}], {
             RGBColor[
             0.21719189432910094`, 0.3456128300743124, 0.9356801291242041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 299}], {
             RGBColor[
             0.21267988324051307`, 0.34087042034218046`, 0.9354231767676313]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 330}], {
             RGBColor[
             0.21800150715905772`, 0.3464637844910152, 0.9357262353771553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 336}], {
             RGBColor[
             0.21111881242536762`, 0.33922963593785627`, 0.935334276094106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 341}], {
             RGBColor[
             0.21717163219876068`, 0.3455915332906315, 0.9356789752258563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 368}], {
             RGBColor[
             0.21277052855345546`, 0.3409656943133277, 0.9354283388841056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 393}], {
             RGBColor[
             0.21778977524310467`, 0.34624124082276975`, 0.9357141775577711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 310}], {
             RGBColor[
             0.2124827502833183, 0.3406632211052174, 0.935411950337351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 345}], {
             RGBColor[
             0.22216737223106828`, 0.3508423728127994, 0.9359634752301611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 363}], {
             RGBColor[
             0.5524499218387339, 0.42033901047071287`, 0.5720521832312901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 316}], {
             RGBColor[
             0.27790052377493313`, 0.40942144877130526`, 0.9391373957607753]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 324}], {
             RGBColor[
             0.2907395975741168, 0.42291612937854317`, 0.9398685620199312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 360}], {
             RGBColor[
             0.3059566318031602, 0.4387580388470877, 0.9407407208692202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 374}], {
             RGBColor[
             0.2888126336637139, 0.4208907681321412, 0.9397588242759214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 375}], {
             RGBColor[
             0.2781834406546093, 0.40971881234981117`, 0.9391535074585348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 380}], {
             RGBColor[
             0.28350610283773925`, 0.41531326778055483`, 0.939456625195691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 383}], {
             RGBColor[
             0.2908789334455868, 0.4230625802138626, 0.9398764969916824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 390}], {
             RGBColor[
             0.283910407540538, 0.415738217657595, 0.9394796497504001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 307}], {
             RGBColor[
             0.965939497584164, 0.9739442069028073, 0.9347428726703746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 314}], {
             RGBColor[
             0.9362255007006572, 0.9517027043636277, 0.9839981831745597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 332}], {
             RGBColor[
             0.736930313911651, 0.7933926635631983, 0.9655671808709663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 352}], {
             RGBColor[
             0.970396577990795, 0.974814330666099, 0.7901511578367646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 385}], {
             RGBColor[
             0.76103003285282, 0.8129579010796052, 0.9674643990261943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 306}], {
             RGBColor[
             0.8969031243202032, 0.8868893383314866, 0.6612189641553454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 307}], {
             RGBColor[
             0.9043350538106595, 0.9251046086494896, 0.9386480207606034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 314}], {
             RGBColor[
             0.8746210569271528, 0.9028631061103101, 0.9879033312647884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 336}], {
             RGBColor[
             0.2125676316732109, 0.34075243682778544`, 0.9354167842069347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 367}], {
             RGBColor[
             0.21672169883755696`, 0.34511862480058364`, 0.9356533521865525]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 306}], {
             RGBColor[
             0.9301864468516778, 0.7525583544999579, 0.2846700934867103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 307}], {
             RGBColor[
             0.9376183763421341, 0.7907736248179609, 0.5620991500919681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 314}], {
             RGBColor[
             0.9079043794586273, 0.7685321222787813, 0.6113544605961532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 363}], {
             RGBColor[
             0.8762546358068509, 0.5309830273105506, 0.21845617365184725`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 316}], {
             RGBColor[
             0.2555487063727525, 0.3859282714945373, 0.9378644928262717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 324}], {
             RGBColor[
             0.2683877801719362, 0.39942295210177514`, 0.9385956590854276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 372}], {
             RGBColor[
             0.25414770566980416`, 0.3844557309271635, 0.9377847079088335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 380}], {
             RGBColor[
             0.26115428543555863`, 0.39182009050378686`, 0.9381837222611874]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 383}], {
             RGBColor[
             0.2685271160434062, 0.39956940293709464`, 0.9386035940571789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 390}], {
             RGBColor[
             0.26155859013835736`, 0.392245040380827, 0.9382067468158966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 323}], {
             RGBColor[
             0.9087436394185031, 0.9180978599174181, 0.6943707488073377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 340}], {
             RGBColor[
             0.9905275811721996, 0.978922480132596, 0.484619975557615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 313}], {
             RGBColor[
             0.2862100467675046, 0.4181552842906852, 0.9396106108023645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 344}], {
             RGBColor[
             0.3051201948561256, 0.4369324167818024, 0.9407277420647475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 315}], {
             RGBColor[
             0.23118633013209117`, 0.360321869401733, 0.9364770915402718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 329}], {
             RGBColor[
             0.2271186296842969, 0.35604645832399684`, 0.9362454420173936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 353}], {
             RGBColor[
             0.21473904123945592`, 0.3430347259572272, 0.9355404427694197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 378}], {
             RGBColor[
             0.21381243485280502`, 0.34206080389461896`, 0.9354876739064912]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 325}], {
             RGBColor[
             0.20723516257555488`, 0.3351476737080805, 0.9351131079805042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 314}], {
             RGBColor[
             0.9555259778682477, 0.9659228619523936, 0.9435306567958934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 352}], {
             RGBColor[
             0.9896970551583855, 0.989034488254865, 0.7496836314580985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 385}], {
             RGBColor[
             0.7803305100204103, 0.8271780586683711, 0.9269968726475282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 386}], {
             RGBColor[
             0.30022575986843436`, 0.4300559235597101, 0.9405124330603728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 397}], {
             RGBColor[
             0.25521896402580857`, 0.3855816913810268, 0.9378457144874233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 319}], {
             RGBColor[
             0.25618706106620875`, 0.38659922275138503`, 0.9379008461817029]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 329}], {
             RGBColor[
             0.25296463724126, 0.3832122509978928, 0.9377173339120208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 334}], {
             RGBColor[
             0.26609474286190404`, 0.39701282450196873`, 0.9384650740028659]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 371}], {
             RGBColor[
             0.2714180274121831, 0.4026079340800466, 0.9387682271829105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 386}], {
             RGBColor[
             0.30507679489801537`, 0.4351546689491852, 0.9407886923288442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 345}], {
             RGBColor[
             0.19226277251810686`, 0.3194107424533439, 0.9342604525163987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 363}], {
             RGBColor[
             0.5225453221257725, 0.38890738011125736`, 0.5703491605175277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 323}], {
             RGBColor[
             0.6747921418079339, 0.7440706990607763, 0.9694867808520644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 339}], {
             RGBColor[
             0.4425672704759462, 0.555957682108388, 0.9499165435038557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 327}], {
             RGBColor[
             0.39077465425622554`, 0.5126293712413812, 0.9461931090416965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 356}], {
             RGBColor[
             0.4906677898927829, 0.5973852420238213, 0.9530463122771483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 361}], {
             RGBColor[
             0.40929184788600736`, 0.528668033662285, 0.9473730082456748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 344}], {
             RGBColor[
             0.30171850127564737`, 0.43335702114888963`, 0.940534020647694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 359}], {
             RGBColor[
             0.2641882368664749, 0.39500896582131095`, 0.9383565013068491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 385}], {
             RGBColor[
             0.7506165131369036, 0.8049365561291917, 0.9762521831517132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 319}], {
             RGBColor[
             0.24242894961997336`, 0.37213857530674344`, 0.9371173420881417]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 329}], {
             RGBColor[
             0.2392065257950246, 0.3687516035532512, 0.9369338298184597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 334}], {
             RGBColor[
             0.25233663141566864`, 0.38255217705732714`, 0.9376815699093048]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 371}], {
             RGBColor[
             0.25765991596594773`, 0.388147286635405, 0.9379847230893494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 324}], {
             RGBColor[
             0.2671185805915378, 0.39808894287087526`, 0.9385233800469365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 355}], {
             RGBColor[
             0.2426003366300466, 0.37231871392089444`, 0.937127102324821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 380}], {
             RGBColor[
             0.25988508585516024`, 0.3904860812728869, 0.9381114432226962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 383}], {
             RGBColor[
             0.2672579164630078, 0.3982353937061947, 0.9385313150186878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 390}], {
             RGBColor[
             0.26028939055795897`, 0.3909110311499271, 0.9381344677774055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 333}], {
             RGBColor[
             0.5930937593564782, 0.6566344401985723, 0.8697228003417041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 370}], {
             RGBColor[
             0.9109218435003366, 0.9293228266692952, 0.8943803638429948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 381}], {
             RGBColor[
             0.99188704610358, 0.9909130993174948, 0.7841161719227241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 382}], {
             RGBColor[
             0.9447039927210837, 0.8118308485146293, 0.5211250046258997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 367}], {
             RGBColor[
             0.22156608180377718`, 0.3502103784497014, 0.9359292326298564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 373}], {
             RGBColor[
             0.2370696348066011, 0.3665055956377041, 0.9368121370379159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 329}], {
             RGBColor[
             0.2383612491721791, 0.3678631642290072, 0.9368856925652633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 334}], {
             RGBColor[
             0.25149135479282314`, 0.3816637377330832, 0.9376334326561084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 371}], {
             RGBColor[
             0.2568146393431022, 0.387258847311161, 0.937936585836153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 388}], {
             RGBColor[
             0.23247439130222355`, 0.3616757033593372, 0.9365504447183952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 343}], {
             RGBColor[
             0.7160472963068527, 0.7781008571267078, 0.9723325607195863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 349}], {
             RGBColor[
             0.5776365804223218, 0.666740315055617, 0.9606597012822499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 331}], {
             RGBColor[
             0.634939466831133, 0.7117908877119044, 0.9662504402131629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 338}], {
             RGBColor[
             0.9060374188254435, 0.923886001186349, 0.8010879565228419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 342}], {
             RGBColor[
             0.7105723316016292, 0.7732263305665302, 0.9721953421188899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 384}], {
             RGBColor[
             0.7831071512596195, 0.8304885254895837, 0.9790164603513036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 398}], {
             RGBColor[
             0.8786059330927678, 0.9059622064053712, 0.9849470713031456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 328}], {
             RGBColor[
             0.4089266558730876, 0.5271174055758985, 0.947690784031411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 362}], {
             RGBColor[
             0.45653757665465905`, 0.5683555921624378, 0.9507245098029286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 364}], {
             RGBColor[
             0.428972946302528, 0.5444804947900268, 0.9489681159313363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 340}], {
             RGBColor[
             0.9119941865056833, 0.9282757501963927, 0.7739166151037982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 375}], {
             RGBColor[
             0.267401497471214, 0.3983863064493811, 0.938539491744696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 380}], {
             RGBColor[
             0.27272415965434393`, 0.4039807618801248, 0.9388426094818522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 383}], {
             RGBColor[
             0.2800969902621915, 0.41173007431343256`, 0.9392624812778436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 390}], {
             RGBColor[
             0.27312846435714266`, 0.404405711757165, 0.9388656340365613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 335}], {
             RGBColor[
             0.3099542075105004, 0.4402786337315509, 0.9410665454863245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 337}], {
             RGBColor[
             0.312066783946898, 0.44249908551128714`, 0.9411868535891006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 354}], {
             RGBColor[
             0.3095818357707423, 0.4398872474233331, 0.94104533946662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 337}], {
             RGBColor[
             0.3016677329619616, 0.43349195021963505`, 0.9405242352558603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 354}], {
             RGBColor[
             0.2991827847858058, 0.430880112131681, 0.9403827211333795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 356}], {
             RGBColor[
             0.4184852693414719, 0.5351260969165677, 0.9483745901685348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 392}], {
             RGBColor[
             0.28327067295496094`, 0.4141554737113025, 0.9394765499044728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 347}], {
             RGBColor[
             0.29474363512034735`, 0.42706072191761096`, 0.940098925902251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 362}], {
             RGBColor[
             0.35704810596381387`, 0.4836788564514203, 0.9439717674801389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 372}], {
             RGBColor[
             0.2804573452843499, 0.4120449254968854, 0.9392853428307628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 387}], {
             RGBColor[
             0.30150296805800375`, 0.4341652094015489, 0.9404838599135137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 334}], {
             RGBColor[
             0.2482689309678744, 0.37827676597959103`, 0.9374499203864265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 353}], {
             RGBColor[
             0.22275923690238936`, 0.35146446010874544`, 0.9359971810476075]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 371}], {
             RGBColor[
             0.25359221551815353`, 0.38387187555766883`, 0.9377530735664711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 388}], {
             RGBColor[
             0.22925196747727483`, 0.358288731605845, 0.9363669324487132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 342}], {
             RGBColor[
             0.5277253347918338, 0.6274369503840362, 0.9559728122191802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 346}], {
             RGBColor[
             0.3985622409768109, 0.5196363136385831, 0.946617011453659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 361}], {
             RGBColor[
             0.4414240641856033, 0.5547544143941453, 0.9499025740169657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 385}], {
             RGBColor[
             0.5513213263478973, 0.6466265153287621, 0.9578211808481198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 381}], {
             RGBColor[
             0.5943537422981029, 0.6571554755250186, 0.8488416222676571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 371}], {
             RGBColor[
             0.26672232113879757`, 0.3976724490617448, 0.9385008136573162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 388}], {
             RGBColor[
             0.24238207309791887`, 0.372089305109921, 0.9371146725395583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 337}], {
             RGBColor[
             0.282630755782611, 0.41439322252540617`, 0.9394067754758614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 354}], {
             RGBColor[
             0.28014580760645524`, 0.41178138443745216`, 0.9392652613533807]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 367}], {
             RGBColor[
             0.21516062802241154`, 0.34347784039625945`, 0.9355644515130273]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 354}], {
             RGBColor[
             0.28225838404285286`, 0.4140018362171884, 0.9393855694561568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 384}], {
             RGBColor[
             0.8713581064441347, 0.8967942587815345, 0.7976314467612728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 398}], {
             RGBColor[
             0.966856888277283, 0.9722679396973218, 0.803562057713115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 360}], {
             RGBColor[
             0.3380761124684098, 0.46724626924582036`, 0.942762888830887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 374}], {
             RGBColor[
             0.3209321143289635, 0.44937899853087393`, 0.9417809922375882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 368}], {
             RGBColor[
             0.2171826090564914, 0.3456030706640795, 0.9356796003416652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 379}], {
             RGBColor[
             0.2212705365436844, 0.3498997416426921, 0.9359124017645142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 393}], {
             RGBColor[
             0.2222018557461406, 0.35087861717352153`, 0.9359654390153307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 399}], {
             RGBColor[
             0.22823136465623345`, 0.3572160133309742, 0.9363088106279014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 346}], {
             RGBColor[
             0.4741951057473072, 0.5810717564932091, 0.9525619133593859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 398}], {
             RGBColor[
             0.7713918010534688, 0.8216082690775031, 0.9746694433091629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 349}], {
             RGBColor[
             0.5837898565381997, 0.6715473011239714, 0.9612730023398459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 349}], {
             RGBColor[
             0.3830038950089686, 0.5061604563464437, 0.9456256474062932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 362}], {
             RGBColor[
             0.3423545559019188, 0.4682989085041503, 0.9431326516737686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 372}], {
             RGBColor[
             0.26576379522245486`, 0.3966649775496154, 0.9384462270243925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 387}], {
             RGBColor[
             0.2868094179961087, 0.41878526145427897`, 0.9396447441071433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 351}], {
             RGBColor[
             0.2543498568494185, 0.38466820463406326`, 0.9377962201194567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 369}], {
             RGBColor[
             0.2602045857942335, 0.3908218959663191, 0.9381296382715687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 357}], {
             RGBColor[
             0.5542164267531839, 0.6479076320182329, 0.9585525480697432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 394}], {
             RGBColor[
             0.3958053510234857, 0.5172484341263308, 0.9464413448636552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 378}], {
             RGBColor[
             0.20945304207089746`, 0.33747880567936756`, 0.9352394129367053]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 375}], {
             RGBColor[
             0.24288325350972279`, 0.37261607749940034`, 0.9371432140225805]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 379}], {
             RGBColor[
             0.2259392634266556, 0.3548068696110762, 0.9361782788537368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 366}], {
             RGBColor[
             0.934928559139148, 0.7751416322731404, 0.28588252947049914`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 391}], {
             RGBColor[
             0.8944837314108928, 0.5317010026573729, 0.24979314294089291`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 374}], {
             RGBColor[
             0.293247724709362, 0.42540017170025574`, 0.9400169674113716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 375}], {
             RGBColor[
             0.2826185317002574, 0.4142282159179257, 0.939411650593985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 369}], {
             RGBColor[
             0.30654023496768024`, 0.43518917662023243`, 0.9409270894573605]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 385}], {
             RGBColor[
             0.46552378312677223`, 0.5743196519105522, 0.9517997921721937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 377}], {
             RGBColor[
             0.3822045767059832, 0.5054681270073037, 0.9455747155508364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 387}], {
             RGBColor[
             0.3215492584874442, 0.4515282986156772, 0.941761191813439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 382}], {
             RGBColor[
             0.9000306839899277, 0.6389445090727658, 0.23829549106007777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 393}], {
             RGBColor[
             0.21780075210083538`, 0.3462527781962177, 0.93571480267358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 399}], {
             RGBColor[
             0.22383026101092823`, 0.35259017435367035`, 0.9360581742861507]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 392}], {
             RGBColor[
             0.2527015805879449, 0.38293576177650346`, 0.937702353224772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 389}], {
             RGBColor[
             0.505152375234491, 0.5869084718259839, 0.9586367768062234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 391}], {
             RGBColor[
             0.8258037070409253, 0.5129958576116641, 0.5754614637475668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 400}], {
             RGBColor[
             0.6104137657145253, 0.6900683539569277, 0.9649050090474223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 395}], {
             RGBColor[
             0.2616949498810116, 0.3923883631160637, 0.9382145123015146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 375}], {
             RGBColor[
             0.26547453356081113`, 0.3963609452029792, 0.9384297540006862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 399}], {
             RGBColor[
             0.255491371590293, 0.38586800900293716`, 0.9378612276952298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 379}], {
             RGBColor[
             0.23790135046863936`, 0.36737978153232503`, 0.9368595020144559]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 383}], {
             RGBColor[
             0.26754083334268397`, 0.3985327572847006, 0.9385474267164473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 399}], {
             RGBColor[
             0.24486217858118842`, 0.3746960532206071, 0.9372559108778432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 377}], {
             RGBColor[
             0.4266363429774569, 0.5439526897461481, 0.9484058684081864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 393}], {
             RGBColor[
             0.22188867958802838`, 0.35054944917483033`, 0.9359476040964289]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 399}], {
             RGBColor[
             0.22791818849812123`, 0.356886845332283, 0.9362909757089996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 383}], {
             RGBColor[
             0.2728634955258139, 0.4041272127154443, 0.9388505444536035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 390}], {
             RGBColor[
             0.2658949696207651, 0.39680285015917666`, 0.9384536972123212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 390}], {
             RGBColor[
             0.27326780022861263`, 0.40455216259248444`, 0.9388735690083126]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 398}], {
             RGBColor[
             0.8439266207114591, 0.8788704640005567, 0.9814905615415767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 400}], {
             RGBColor[
             0.2843495171102985, 0.40872323643536973`, 0.9397784081644269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 399}], {
             RGBColor[
             0.22884950770057744`, 0.3578657208631124, 0.9363440129598162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 396}], {
             RGBColor[
             0.2756838068644868, 0.4070915387504564, 0.9390111570120642]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.03217915333176364], {
             RGBColor[
             0.3599830334006432, 0.48622094308345976`, 0.9441587784611594]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.03217915333176364], {
             RGBColor[
             0.8184511944421836, 0.14282954261339104`, 0.16530219067646573`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.03217915333176364], {
             RGBColor[
             0.370079657849583, 0.49496613171003123`, 0.9448021264429514]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.03217915333176364], {
             RGBColor[
             0.23219649750384544`, 0.36138361935775737`, 0.9365346190776845]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.03217915333176364], {
             RGBColor[
             0.8414430264446411, 0.8764078451972013, 0.9847387810989889]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.03217915333176364], {
             RGBColor[
             0.9933475429680663, 0.9881793920123014, 0.5172992901589675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.03217915333176364], {
             RGBColor[
             0.38940499419392427`, 0.5117047667318526, 0.9460335197860889]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.03217915333176364], {
             RGBColor[
             0.3103199544645186, 0.44320528024791445`, 0.9409942909866859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.03217915333176364], {
             RGBColor[
             0.8256674379376745, 0.1982967522977973, 0.17221247359732916`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.03217915333176364], {
             RGBColor[
             0.3619258765766598, 0.48790373619238797`, 0.9442825747103464]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.03217915333176364], {
             RGBColor[
             0.9234626618564741, 0.7342619893565898, 0.25727446504873397`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.03217915333176364], {
             RGBColor[
             0.218436984339963, 0.3469214986189947, 0.935751035158377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.03217915333176364], {
             RGBColor[
             0.9637801291888717, 0.9725078601704316, 0.9461949730147088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.03217915333176364], {
             RGBColor[
             0.9943570777774785, 0.9903386848900081, 0.6271809240368398]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.03217915333176364], {
             RGBColor[
             0.3038609163605336, 0.43670746736272875`, 0.940615801713566]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.03217915333176364], {
             RGBColor[
             0.2418605106508593, 0.3715411099090923, 0.9370849703297808]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.03217915333176364], {
             RGBColor[
             0.5355166046173245, 0.6337955302332828, 0.9565769752588857]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.03217915333176364], {
             RGBColor[
             0.9452065658445834, 0.95865572703968, 0.9776351709954327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.03217915333176364], {
             RGBColor[
             0.2743841090042405, 0.40572547389373365`, 0.9389371411416538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.03217915333176364], {
             RGBColor[
             0.4076589804310767, 0.5275154521384491, 0.9471966476477539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.03217915333176364], {
             RGBColor[
             0.31291714185714126`, 0.44545483342897024`, 0.9411597814707411]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.03217915333176364], {
             RGBColor[
             0.29231839668471055`, 0.42457554734542235`, 0.9399584722936555]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.03217915333176364], {
             RGBColor[
             0.21341792784235675`, 0.34164615201344867`, 0.935465207315867]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.03217915333176364], {
             RGBColor[
             0.9021530244270525, 0.6485815613125467, 0.24006642394413927`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.03217915333176364], {
             RGBColor[
             0.8487111149297029, 0.3754205514621725, 0.19427912470900624`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.03217915333176364], {
             RGBColor[
             0.45511285367532656`, 0.5685201430708667, 0.9502472974560874]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.03217915333176364], {
             RGBColor[
             0.2974167180204977, 0.42993420632157753`, 0.9402488141514381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.03217915333176364], {
             RGBColor[
             0.2882891132658928, 0.42034051500092084`, 0.9397290105637445]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.03217915333176364], {
             RGBColor[
             0.2404292095299187, 0.3700367216812511, 0.9370034598483634]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.03217915333176364], {
             RGBColor[
             0.17892703208317115`, 0.3053940337214471, 0.9335010018270892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.03217915333176364], {
             RGBColor[
             0.183217413291963, 0.30990349639776743`, 0.9337453326898797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.03217915333176364], {
             RGBColor[
             0.21628540957162948`, 0.3446600571197567, 0.9356285061582901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.03217915333176364], {
             RGBColor[
             0.17894138666990014`, 0.3054091213022326, 0.9335018192995677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.03217915333176364], {
             RGBColor[
             0.3122890105436297, 0.4449107776560043, 0.9411197574988789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.03217915333176364], {
             RGBColor[
             0.28104105066772134`, 0.4127223416565313, 0.9393162441213263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.03217915333176364], {
             RGBColor[
             0.5196772960404508, 0.620936465977857, 0.9553300468664151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.03217915333176364], {
             RGBColor[
             0.24979952597607638`, 0.3798855183785399, 0.9375370855078312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.03217915333176364], {
             RGBColor[
             0.9657912116144293, 0.896267865549297, 0.32160574622002847`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.03217915333176364], {
             RGBColor[
             0.27309206457306523`, 0.40436745327622, 0.9388635611227067]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.03217915333176364], {
             RGBColor[
             0.3393121311221928, 0.4683168464796233, 0.9428416468465376]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.03217915333176364], {
             RGBColor[
             0.34082031608406577`, 0.4696231604900174, 0.9429377470586726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.03217915333176364], {
             RGBColor[
             0.9322258626950144, 0.9487956145888052, 0.9933977290633442]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.03217915333176364], {
             RGBColor[
             0.2274352478585693, 0.35637924409990884`, 0.9362634729540237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.03217915333176364], {
             RGBColor[
             0.29795654320818293`, 0.4305015968207284, 0.940279556397277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.03217915333176364], {
             RGBColor[
             0.2954990939280613, 0.427918661816037, 0.9401396082962444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.03217915333176364], {
             RGBColor[
             0.2843163130979401, 0.41616485013432336`, 0.9395027654714108]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.03217915333176364], {
             RGBColor[
             0.43389191818712153`, 0.5502371043169462, 0.948868187244693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.03217915333176364], {
             RGBColor[
             0.4254428949511675, 0.5429189850502182, 0.948329822955276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.03217915333176364], {
             RGBColor[
             0.2557363986193865, 0.3861255479461254, 0.9378751816220516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.03217915333176364], {
             RGBColor[
             0.45414763221898446`, 0.5677365328098771, 0.9501713116873214]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.03217915333176364], {
             RGBColor[
             0.3729233885884314, 0.4974292283459589, 0.9449833264510183]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.03217915333176364], {
             RGBColor[
             0.38664548537965426`, 0.5093146188938776, 0.9458576863245813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.03217915333176364], {
             RGBColor[
             0.28924396052189333`, 0.4213441200077901, 0.9397833877024038]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.03217915333176364], {
             RGBColor[
             0.4519914858020445, 0.5659140400742732, 0.9500214756882968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.03217915333176364], {
             RGBColor[
             0.4035326533159193, 0.5239414349865308, 0.9469337217327439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.03217915333176364], {
             RGBColor[
             0.45093503134871465`, 0.5649989923257436, 0.9499541593447165]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.03217915333176364], {
             RGBColor[
             0.2732074233744939, 0.404488702690692, 0.9388701306357901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.03217915333176364], {
             RGBColor[
             0.2988109928106687, 0.43139967752817476`, 0.9403282160380936]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.03217915333176364], {
             RGBColor[
             0.3340181926444761, 0.4637315030513096, 0.9425043217679835]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.03217915333176364], {
             RGBColor[
             0.35752834255750565`, 0.4840948132514831, 0.9440023677312325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.03217915333176364], {
             RGBColor[
             0.9933459036684309, 0.98817588571614, 0.5171208625102379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.03217915333176364], {
             RGBColor[
             0.1790682590797859, 0.30554247224919795`, 0.9335090444956198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.03217915333176364], {
             RGBColor[
             0.9585610528033711, 0.8718788421575785, 0.2935179445399928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.03217915333176364], {
             RGBColor[
             0.3989602722595878, 0.5199810683300905, 0.9466423736550322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.03217915333176364], {
             RGBColor[
             0.5153321861178936, 0.6174089099977538, 0.9549879838966494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.03217915333176364], {
             RGBColor[
             0.9727828870163496, 0.9198524284034268, 0.3487670848893771]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.03217915333176364], {
             RGBColor[
             0.2129458677257866, 0.3411499869005934, 0.9354383241905787]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.03217915333176364], {
             RGBColor[
             0.2767246225454214, 0.4081855020226443, 0.9390704299253445]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.03217915333176364], {
             RGBColor[
             0.48821862164434726`, 0.5953968969059689, 0.9528535047810326]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.03217915333176364], {
             RGBColor[
             0.2778101351361315, 0.409326444580954, 0.9391322482615135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.03217915333176364], {
             RGBColor[
             0.871120013048017, 0.9000714687543917, 0.9875693985741776]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.03217915333176364], {
             RGBColor[
             0.22772650909910638`, 0.3566853781307425, 0.9362800598507899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.03217915333176364], {
             RGBColor[
             0.24311597663730303`, 0.3728606842619857, 0.9371564672604132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.03217915333176364], {
             RGBColor[
             0.8246734764068878, 0.8630362611944062, 0.983139286446034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.03217915333176364], {
             RGBColor[
             0.24417812249459925`, 0.373977066901941, 0.9372169548956822]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.03217915333176364], {
             RGBColor[
             0.8469444359628041, 0.36184108275892934`, 0.19258735093512552`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.03217915333176364], {
             RGBColor[
             0.8293651040061051, 0.8667772376911834, 0.9835867780747127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.03217915333176364], {
             RGBColor[
             0.8418439495844675, 0.3226365094076515, 0.18770311941905493`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.03217915333176364], {
             RGBColor[
             0.590805957298975, 0.6786819174972005, 0.9609295556335575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.03217915333176364], {
             RGBColor[
             0.3344163982055418, 0.46407640869391137`, 0.9425296950742152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.03217915333176364], {
             RGBColor[
             0.2197154470497895, 0.34826524398623987`, 0.9358238417183856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.03217915333176364], {
             RGBColor[
             0.37921715493462604`, 0.5028805724211383, 0.9453843596772389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.03217915333176364], {
             RGBColor[
             0.35288166901045503`, 0.480070098173631, 0.9437062858017065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.03217915333176364], {
             RGBColor[
             0.17892701429477148`, 0.30539401502471114`, 0.9335010008140661]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.03217915333176364], {
             RGBColor[
             0.2413074662041341, 0.37095982513054093`, 0.9370534752666957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.03217915333176364], {
             RGBColor[
             0.30053635500276704`, 0.4332131425863514, 0.940426472862489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.03217915333176364], {
             RGBColor[
             0.29013871681338543`, 0.4222845656009737, 0.9398343427495309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.03217915333176364], {
             RGBColor[
             0.9903137669558371, 0.9902625079584733, 0.8101894789167451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.03217915333176364], {
             RGBColor[
             0.21858282554203126`, 0.3470747869692347, 0.9357593405990821]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.03217915333176364], {
             RGBColor[
             0.7058058015575851, 0.7701001235903371, 0.9713117842351892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.03217915333176364], {
             RGBColor[
             0.26262121251507564`, 0.39336192387290797`, 0.9382672615882417]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.03217915333176364], {
             RGBColor[
             0.28766384187052196`, 0.4196833151198899, 0.9396934022827843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.03217915333176364], {
             RGBColor[
             0.2452381115380016, 0.3750911825937439, 0.9372773197035907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.03217915333176364], {
             RGBColor[
             0.26012396818175015`, 0.3907371617441472, 0.9381250472178008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.03217915333176364], {
             RGBColor[
             0.2817785304161579, 0.4134974796310549, 0.9393582425019963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.03217915333176364], {
             RGBColor[
             0.2869114883454893, 0.4188925438631119, 0.939650556862541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.03217915333176364], {
             RGBColor[
             0.44228444757308333`, 0.5575062914502744, 0.9494029517959442]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.03217915333176364], {
             RGBColor[
             0.9775701021325132, 0.9360008290818089, 0.3673645116259542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.03217915333176364], {
             RGBColor[
             0.9781276011086575, 0.9832081812363787, 0.921908445474496]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.03217915333176364], {
             RGBColor[
             0.37661408553666426`, 0.5006259245426959, 0.9452184943970047]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.03217915333176364], {
             RGBColor[
             0.2608418322510304, 0.39149168239617155`, 0.9381659285145616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.03217915333176364], {
             RGBColor[
             0.819297035403237, 0.14933104688991955`, 0.16611216893601113`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.03217915333176364], {
             RGBColor[
             0.34456615692423104`, 0.4728676195543337, 0.943176428724691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.03217915333176364], {
             RGBColor[
             0.9338740873595025, 0.7755398220742175, 0.265651742396037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.03217915333176364], {
             RGBColor[
             0.417344109662346, 0.5359042242898253, 0.9478137755181469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.03217915333176364], {
             RGBColor[
             0.948494816832878, 0.9611080992427333, 0.9720690197854612]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.03217915333176364], {
             RGBColor[
             0.8392176796973624, 0.30244984821655896`, 0.1851882004092155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.03217915333176364], {
             RGBColor[
             0.3675690787260941, 0.49279159425864094`, 0.9446421545612206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.03217915333176364], {
             RGBColor[
             0.9940964498066649, 0.9918267445278057, 0.7475006348091123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.03217915333176364], {
             RGBColor[
             0.25557794384056287`, 0.3859590019269685, 0.9378661578568105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.03217915333176364], {
             RGBColor[
             0.8740781517963572, 0.5211001217496539, 0.21664006204298622`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.03217915333176364], {
             RGBColor[
             0.3289211710833394, 0.45931671915880556`, 0.9421795440612271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.03217915333176364], {
             RGBColor[
             0.7965156452550962, 0.8409633429071789, 0.9803528937232722]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.03217915333176364], {
             RGBColor[
             0.3288778807819878, 0.45927922327560866`, 0.9421767856415051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.03217915333176364], {
             RGBColor[
             0.2386060995532787, 0.36812051750395375`, 0.9368996364322433]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.03217915333176364], {
             RGBColor[
             0.4162213411164948, 0.534931738607397, 0.9477422336992305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.03217915333176364], {
             RGBColor[
             0.3495171154366807, 0.47715589097540734`, 0.9434918994231435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.03217915333176364], {
             RGBColor[
             0.20606162213947596`, 0.33391420830300045`, 0.935046276588767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.03217915333176364], {
             RGBColor[
             0.24049836738192176`, 0.3701094109685675, 0.9370073982857251]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.03217915333176364], {
             RGBColor[
             0.5663783145126094, 0.6588504566304622, 0.9590065221120109]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.03217915333176364], {
             RGBColor[
             0.5531961411455233, 0.6481485744409189, 0.9579687731366617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.03217915333176364], {
             RGBColor[
             0.44608758599784554`, 0.5608003788025082, 0.9496452844133868]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.03217915333176364], {
             RGBColor[
             0.9742961343763916, 0.9803506796209057, 0.9283941192456544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.03217915333176364], {
             RGBColor[
             0.22327126764014227`, 0.35200263687874755`, 0.936026340440641]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.03217915333176364], {
             RGBColor[
             0.277985958766929, 0.4095112463647842, 0.9391422611571797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.03217915333176364], {
             RGBColor[
             0.21204174778307774`, 0.3401996995162911, 0.935386835897367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.03217915333176364], {
             RGBColor[
             0.21049571798261152`, 0.33857472417205015`, 0.9352987917873766]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.03217915333176364], {
             RGBColor[
             0.3262131529712761, 0.45697116997908427`, 0.9420069915417328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.03217915333176364], {
             RGBColor[
             0.23768447069359533`, 0.36715182713778177`, 0.936847151032112]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.03217915333176364], {
             RGBColor[
             0.4104055903111328, 0.5298944275679272, 0.9473716592005793]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.03217915333176364], {
             RGBColor[
             0.9224661794909306, 0.7303112688352736, 0.2564726719469704]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.03217915333176364], {
             RGBColor[
             0.7992223614262676, 0.8430778501519028, 0.9806226738955138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.03217915333176364], {
             RGBColor[
             0.29725822306554583`, 0.42976761807476255`, 0.9402397880982258]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.03217915333176364], {
             RGBColor[
             0.2343268669145523, 0.36362277268163234`, 0.9366559404640252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.03217915333176364], {
             RGBColor[
             0.5032780494106496, 0.6076228187861427, 0.9540390380992975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.03217915333176364], {
             RGBColor[
             0.6185821135656369, 0.7012318524560568, 0.9631161964022821]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.03217915333176364], {
             RGBColor[
             0.22155609394318862`, 0.3501998805749559, 0.9359286638359716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.03217915333176364], {
             RGBColor[
             0.8193428764107183, 0.14968340096107918`, 0.16615606633654534`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.03217915333176364], {
             RGBColor[
             0.2111706728502173, 0.3392841445325141, 0.9353372294685806]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.03217915333176364], {
             RGBColor[
             0.6719249954084331, 0.7436321803229556, 0.9679348621123766]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.03217915333176364], {
             RGBColor[
             0.3600639473667127, 0.48629102669401497`, 0.9441639342275279]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.03217915333176364], {
             RGBColor[
             0.8215839734950429, 0.16690945520620182`, 0.16830214343545163`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.03217915333176364], {
             RGBColor[
             0.6246442469651912, 0.7061533654458123, 0.9635934297498213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.03217915333176364], {
             RGBColor[
             0.8784381059512442, 0.540897655273832, 0.22027811466207986`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.03217915333176364], {
             RGBColor[
             0.23802405881018981`, 0.36750875577945274`, 0.9368664900729765]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.03217915333176364], {
             RGBColor[
             0.5353312372592116, 0.6336450406612625, 0.9565623824614321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.03217915333176364], {
             RGBColor[
             0.28473783311028583`, 0.41660789439321116`, 0.9395267704125309]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.03217915333176364], {
             RGBColor[
             0.6238880244982119, 0.7055394299796848, 0.9635338971470865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.03217915333176364], {
             RGBColor[
             0.22021863489519794`, 0.34879412631571627`, 0.9358524975217819]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.03217915333176364], {
             RGBColor[
             0.2706007772119499, 0.40174895230294594`, 0.9387216859930206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.03217915333176364], {
             RGBColor[
             0.3158355177641727, 0.44798258395780277`, 0.9413457378029186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.03217915333176364], {
             RGBColor[
             0.18361616608284723`, 0.3103226108633739, 0.9337680410714186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.03217915333176364], {
             RGBColor[
             0.3174307607246093, 0.4493643032308905, 0.9414473852737397]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.03217915333176364], {
             RGBColor[
             0.4301580292792129, 0.547002997415629, 0.9486302671452295]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.03217915333176364], {
             RGBColor[
             0.30454561984188433`, 0.43742713413433654`, 0.9406547945639009]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.03217915333176364], {
             RGBColor[
             0.18595953915049845`, 0.3127856445359093, 0.9339014927009116]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.03217915333176364], {
             RGBColor[
             0.46924384183457235`, 0.5799923158523045, 0.9513597406074984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.03217915333176364], {
             RGBColor[
             0.5031159008708285, 0.6074911792968075, 0.9540262731722731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.03217915333176364], {
             RGBColor[
             0.3314345944952444, 0.46149372018986384`, 0.9423396971785006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.03217915333176364], {
             RGBColor[
             0.8294775817921864, 0.22758318757925894`, 0.17586107165535175`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.03217915333176364], {
             RGBColor[
             0.4314366462475933, 0.5481104711684827, 0.9487117394878181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.03217915333176364], {
             RGBColor[
             0.246083996032968, 0.37598026083012825`, 0.9373254915742051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.03217915333176364], {
             RGBColor[
             0.2449732495734328, 0.3748127958757636, 0.9372622362065367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.03217915333176364], {
             RGBColor[
             0.24253850776538854`, 0.3722537278639624, 0.9371235812624463]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.03217915333176364], {
             RGBColor[
             0.532748774101436, 0.6315484807311408, 0.9563590815017777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.03217915333176364], {
             RGBColor[
             0.8247691039330448, 0.19139176348574266`, 0.17135222793997262`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.03217915333176364], {
             RGBColor[
             0.2835494674254077, 0.415358846711668, 0.9394590947448065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.03217915333176364], {
             RGBColor[
             0.6701504899984683, 0.7422459232099505, 0.9677579959968072]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.03217915333176364], {
             RGBColor[
             0.22069846856058375`, 0.34929846192124825`, 0.9358798233391753]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.03217915333176364], {
             RGBColor[
             0.44496963537099143`, 0.5598320661593594, 0.9495740495880086]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.03217915333176364], {
             RGBColor[
             0.2732125866431092, 0.40449412961337683`, 0.9388704246762993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.03217915333176364], {
             RGBColor[
             0.301424661402258, 0.4341468089340951, 0.9404770605978084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.03217915333176364], {
             RGBColor[
             0.22636761106282094`, 0.3552570901354948, 0.936202672617933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.03217915333176364], {
             RGBColor[
             0.7286053839996127, 0.7879113306772935, 0.9735842335387989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.03217915333176364], {
             RGBColor[
             0.17893214148115075`, 0.3053994040226782, 0.9335012927997455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.03217915333176364], {
             RGBColor[
             0.21582348781243682`, 0.34417454806331416`, 0.935602200397456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.03217915333176364], {
             RGBColor[
             0.3219085007459621, 0.453242696579629, 0.9417327029083903]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.03217915333176364], {
             RGBColor[
             0.24398844376792686`, 0.3737777025338824, 0.9372061529728027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.03217915333176364], {
             RGBColor[
             0.2696431574723743, 0.40074243324005365`, 0.9386671509655232]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.03217915333176364], {
             RGBColor[
             0.36627002209779275`, 0.4916664166996908, 0.9445593798215759]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.03217915333176364], {
             RGBColor[
             0.5673122922146817, 0.6596087018042204, 0.9590800482579911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.03217915333176364], {
             RGBColor[
             0.2880943118622093, 0.4201357663745271, 0.9397179169119876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.03217915333176364], {
             RGBColor[
             0.2589336294896423, 0.3894860403069097, 0.9380572591902335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.03217915333176364], {
             RGBColor[
             0.21776291881025298`, 0.3462130130090464, 0.9357126481236506]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.03217915333176364], {
             RGBColor[
             0.8236904837096025, 0.18310101579396953`, 0.170319339995877]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.03217915333176364], {
             RGBColor[
             0.24846767200989045`, 0.3784856554156597, 0.9374612383947583]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.03217915333176364], {
             RGBColor[
             0.8439338400416576, 0.8783939523481282, 0.9849763571234479]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.03217915333176364], {
             RGBColor[
             0.26708591845739416`, 0.39805461289699134`, 0.9385215199867163]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.03217915333176364], {
             RGBColor[
             0.30054674338696064`, 0.4332240614368005, 0.9404270644656005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.03217915333176364], {
             RGBColor[
             0.2411029859620505, 0.37074490343131483`, 0.9370418304194105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.03217915333176364], {
             RGBColor[
             0.6788533623879274, 0.7490446732648759, 0.968625416983622]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.03217915333176364], {
             RGBColor[
             0.34448974411411554`, 0.4728014346188312, 0.9431715597679996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.03217915333176364], {
             RGBColor[
             0.8223396115770147, 0.8611753007301386, 0.9829166803350949]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.03217915333176364], {
             RGBColor[
             0.3880550588481297, 0.5105355205850486, 0.9459475030995558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.03217915333176364], {
             RGBColor[
             0.24569470610522032`, 0.37557109243365844`, 0.9373033220887227]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.03217915333176364], {
             RGBColor[
             0.29792411608308994`, 0.43046751385625726`, 0.9402777097204745]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.03217915333176364], {
             RGBColor[
             0.988751433892587, 0.9896164430866911, 0.8360813809631582]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.03217915333176364], {
             RGBColor[
             0.8264896291158393, 0.8644844120663722, 0.9833125127127125]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.03217915333176364], {
             RGBColor[
             0.22580276459471169`, 0.35466340068417734`, 0.9361705054471896]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.03217915333176364], {
             RGBColor[
             0.27065965459454444`, 0.40181083616509444`, 0.9387250389728581]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.03217915333176364], {
             RGBColor[
             0.27642628673231373`, 0.407871932167485, 0.9390534401421363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.03217915333176364], {
             RGBColor[
             0.8563396258514921, 0.4340566292418462, 0.20158419538288244`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.03217915333176364], {
             RGBColor[
             0.29139757571829134`, 0.42360770612629445`, 0.9399060329018505]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.03217915333176364], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.03217915333176364], {
             RGBColor[
             0.9952685123171101, 0.9923114224965074, 0.7280765258104895]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.03217915333176364], {
             RGBColor[
             0.23156206990492625`, 0.36071679572626025`, 0.9364984893644777]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.03217915333176364], {
             RGBColor[
             0.9398558182628138, 0.7992553918121872, 0.27046478349011155`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.03217915333176364], {
             RGBColor[
             0.2330867180319017, 0.36231929757598597`, 0.9365853158197941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.03217915333176364], {
             RGBColor[
             0.2520329891677718, 0.3822330298027571, 0.9376642779324855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.03217915333176364], {
             RGBColor[
             0.2999237099233219, 0.432569213763913, 0.9403915836315417]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.03217915333176364], {
             RGBColor[
             0.2626771974737526, 0.39342076761412886`, 0.9382704498488161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.03217915333176364], {
             RGBColor[
             0.21089717481030001`, 0.33899668075178374`, 0.9353216541598114]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.03217915333176364], {
             RGBColor[
             0.9109681137578394, 0.6847252697068382, 0.24722105836383443`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.03217915333176364], {
             RGBColor[
             0.9837730937067766, 0.9874185803724101, 0.9123520990861677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.03217915333176364], {
             RGBColor[
             0.8192881970279116, 0.1492631112641677, 0.166103705297818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.03217915333176364], {
             RGBColor[
             0.6591015742674116, 0.7336144262659793, 0.9666567433347234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.03217915333176364], {
             RGBColor[
             0.8228256695060855, 0.17645367486173685`, 0.16949119293792111`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.03217915333176364], {
             RGBColor[
             0.9100637739514378, 0.9311241665985504, 0.9912838892546516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.03217915333176364], {
             RGBColor[
             0.4471878440862639, 0.5617533670581167, 0.9497153918858607]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.03217915333176364], {
             RGBColor[
             0.4754345148883495, 0.5850181831240037, 0.9518470930674744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.03217915333176364], {
             RGBColor[
             0.9218589159168126, 0.9405292926311409, 0.9924089204249567]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.03217915333176364], {
             RGBColor[
             0.6049269005052089, 0.6901459353332633, 0.9620412080094716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.03217915333176364], {
             RGBColor[
             0.4540671923140028, 0.5676712280712366, 0.9501649791633402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.03217915333176364], {
             RGBColor[
             0.9756615083220127, 0.9295626939998534, 0.3599499850798584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.03217915333176364], {
             RGBColor[
             0.2571081050813221, 0.3875672984088326, 0.9379532982758011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.03217915333176364], {
             RGBColor[
             0.23863402700947722`, 0.3681498710311214, 0.9369012268595588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.03217915333176364], {
             RGBColor[
             0.23492201148043795`, 0.36424830735472313`, 0.9366898330666149]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.03217915333176364], {
             RGBColor[
             0.36785717736282086`, 0.49304113081751505`, 0.9446605119515972]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.03217915333176364], {
             RGBColor[
             0.24689616138342244`, 0.3768338981077132, 0.9373717431894225]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.03217915333176364], {
             RGBColor[
             0.9688572327835747, 0.9066102748888301, 0.333516659492644]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.03217915333176364], {
             RGBColor[
             0.30868412390727973`, 0.44177696430338015`, 0.9408904762480571]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.03217915333176364], {
             RGBColor[
             0.5255566438526651, 0.6257095853934133, 0.9557928906629534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.03217915333176364], {
             RGBColor[
             0.8174582326741875, 0.1351972033459516, 0.16435132936604271`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.03217915333176364], {
             RGBColor[
             0.3387393935852255, 0.4678207700117279, 0.942805152517134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.03217915333176364], {
             RGBColor[
             0.7400936775781565, 0.7968860729351169, 0.9747292792785006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.03217915333176364], {
             RGBColor[
             0.2505222001886238, 0.3806450947961188, 0.9375782407351351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.03217915333176364], {
             RGBColor[
             0.5784190314529432, 0.6686256530707418, 0.9599544114561535]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.03217915333176364], {
             RGBColor[
             0.22922310747734106`, 0.35825839791608494`, 0.9363652889144115]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.03217915333176364], {
             RGBColor[
             0.32451491921663345`, 0.4555002452565231, 0.9418987815885761]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.03217915333176364], {
             RGBColor[
             0.23920651037948798`, 0.3687515873505448, 0.9369338289405676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.03217915333176364], {
             RGBColor[
             0.290961948336973, 0.42314983412815754`, 0.9398812245669373]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.03217915333176364], {
             RGBColor[
             0.9183468399249884, 0.7139794601448493, 0.25315815463888625`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.03217915333176364], {
             RGBColor[
             0.2883719521470624, 0.4204275839173185, 0.939733728115478]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.03217915333176364], {
             RGBColor[
             0.2600361752617328, 0.3906448858188163, 0.9381200475408837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.03217915333176364], {
             RGBColor[
             0.22989884827362161`, 0.3589686443374169, 0.9364037713530907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.03217915333176364], {
             RGBColor[
             0.4438028563584466, 0.5588214608227114, 0.9494997034610714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.03217915333176364], {
             RGBColor[
             0.9070075396154186, 0.6690229130152352, 0.24403428744221908`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.03217915333176364], {
             RGBColor[
             0.21620788903044316`, 0.3445785781158837, 0.9356240914781508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.03217915333176364], {
             RGBColor[
             0.2695692814994847, 0.4006647849085395, 0.938662943838157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.03217915333176364], {
             RGBColor[
             0.9882272169582415, 0.9893996659125786, 0.8447690121952027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.03217915333176364], {
             RGBColor[
             0.822315843269912, 0.8611563485272284, 0.9829144132927453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.03217915333176364], {
             RGBColor[
             0.2243331252717409, 0.35311871657522015`, 0.9360868116618829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.03217915333176364], {
             RGBColor[
             0.34171577858230273`, 0.47039876509873646`, 0.9429948051372339]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.03217915333176364], {
             RGBColor[
             0.46951139015292603`, 0.5802095236300584, 0.951380802991181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.03217915333176364], {
             RGBColor[
             0.26047497796174324`, 0.3911060952782254, 0.938145036705499]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.03217915333176364], {
             RGBColor[
             0.22530836548640581`, 0.35414375587463387`, 0.9361423501493695]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.03217915333176364], {
             RGBColor[
             0.8226071697061851, 0.17477418965247965`, 0.16928195728277629`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.03217915333176364], {
             RGBColor[
             0.2529332615169164, 0.38317927312227185`, 0.9377155471109357]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.03217915333176364], {
             RGBColor[
             0.2110206902246306, 0.3391265032835748, 0.9353286881799328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.03217915333176364], {
             RGBColor[
             0.8089540339665278, 0.8506803067038047, 0.9815926360666765]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.03217915333176364], {
             RGBColor[
             0.17944836957228805`, 0.3059419924772149, 0.9335306912258446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.03217915333176364], {
             RGBColor[
             0.9386428604207964, 0.9537605262817009, 0.9887458121893573]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.03217915333176364], {
             RGBColor[
             0.26208361027682536`, 0.3927968698345563, 0.9382366459360847]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.03217915333176364], {
             RGBColor[
             0.19003101446562676`, 0.31706502323855396`, 0.9341333571969002]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.03217915333176364], {
             RGBColor[
             0.5918946974095183, 0.6795658057661227, 0.9610152652432459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.03217915333176364], {
             RGBColor[
             0.2549979314676595, 0.3853493721481386, 0.937833127010225]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.03217915333176364], {
             RGBColor[
             0.5711989452526345, 0.6627640618321545, 0.9593860198224179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.03217915333176364], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.03217915333176364], {
             RGBColor[
             0.9930589289900814, 0.9875620758967413, 0.48588543977432486`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.03217915333176364], {
             RGBColor[
             0.249587147505622, 0.3796622951405196, 0.9375249908681246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.03217915333176364], {
             RGBColor[
             0.30678788301618565`, 0.43978389489822367`, 0.9407824881345462]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.03217915333176364], {
             RGBColor[
             0.6470169280819229, 0.7241738088191627, 0.9654522587403933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.03217915333176364], {
             RGBColor[
             0.2754373969927425, 0.40683254635196486`, 0.938997124334399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.03217915333176364], {
             RGBColor[
             0.2307279730478894, 0.35984010704471925`, 0.9364509887824051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.03217915333176364], {
             RGBColor[
             0.992100640761205, 0.9910014261975552, 0.7805763556806252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.03217915333176364], {
             RGBColor[
             0.765566144894021, 0.8167853580001923, 0.977268136766805]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.03217915333176364], {
             RGBColor[
             0.2578128298869203, 0.3883080088616496, 0.9379934313109329]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.03217915333176364], {
             RGBColor[
             0.2524156236360728, 0.382635202889368, 0.9376860683993983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.03217915333176364], {
             RGBColor[
             0.9456496399519233, 0.8222259641328803, 0.2751266284196432]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.03217915333176364], {
             RGBColor[
             0.23901320904650822`, 0.3685484153935707, 0.9369228207156182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.03217915333176364], {
             RGBColor[
             0.6319940482543123, 0.7121202652370958, 0.9641720330305101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.03217915333176364], {
             RGBColor[
             0.6468617732853108, 0.7240526007128293, 0.965436794360271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.03217915333176364], {
             RGBColor[
             0.9089152991886196, 0.6765865439997854, 0.2455693155756892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.03217915333176364], {
             RGBColor[
             0.24399808998490613`, 0.37378784131953313`, 0.9372067023105894]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.03217915333176364], {
             RGBColor[
             0.23871510677441427`, 0.3682350910048242, 0.9369058442322252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.03217915333176364], {
             RGBColor[
             0.726249879738111, 0.7860711928457129, 0.9733494588874512]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.03217915333176364], {
             RGBColor[
             0.260213393629744, 0.3908311535598896, 0.9381301398647709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.03217915333176364], {
             RGBColor[
             0.245025991273468, 0.37486823074651754`, 0.9372652397683294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.03217915333176364], {
             RGBColor[
             0.8977533081905217, 0.6286034774622947, 0.23639519286946437`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.03217915333176364], {
             RGBColor[
             0.4051337172328171, 0.5253281960795354, 0.9470357401097634]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.03217915333176364], {
             RGBColor[
             0.696491580031562, 0.7628237829435023, 0.9703834296798242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.03217915333176364], {
             RGBColor[
             0.2110186790508826, 0.3391243894124498, 0.9353285736465631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.03217915333176364], {
             RGBColor[
             0.21123106399266978`, 0.3393476194522512, 0.9353406686548026]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.03217915333176364], {
             RGBColor[
             0.21275955169572475`, 0.34095415693987974`, 0.9354277137682966]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.03217915333176364], {
             RGBColor[
             0.24238734999627973`, 0.3720948514646729, 0.9371149730511135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.03217915333176364], {
             RGBColor[
             0.30152154075751214`, 0.43424863527897317`, 0.94048257773377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.03217915333176364], {
             RGBColor[
             0.9466390204165737, 0.9597240493140413, 0.9752103990490407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.03217915333176364], {
             RGBColor[
             0.8234301328695646, 0.862044852807406, 0.9830206952294982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.03217915333176364], {
             RGBColor[
             0.21412870248835636`, 0.3423932212321097, 0.9355056848804599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.03217915333176364], {
             RGBColor[
             0.8899967779325137, 0.5933828851443484, 0.2299229538922278]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.03217915333176364], {
             RGBColor[
             0.2568179059531509, 0.3872622807254372, 0.9379367718647629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.03217915333176364], {
             RGBColor[
             0.9872770340850194, 0.9687445898536212, 0.4050741092611545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.03217915333176364], {
             RGBColor[
             0.28961174034798287`, 0.421730679923598, 0.9398043322194181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.03217915333176364], {
             RGBColor[
             0.21909843402136348`, 0.34761672417247863`, 0.9357887037392056]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.03217915333176364], {
             RGBColor[
             0.20290260740476634`, 0.33059388352371805`, 0.9348663753729688]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.03217915333176364], {
             RGBColor[
             0.9703761157708419, 0.9117338238555674, 0.33941723308119276`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.03217915333176364], {
             RGBColor[
             0.9852399747517544, 0.9881643644915732, 0.8942753462917085]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.03217915333176364], {
             RGBColor[
             0.2610883790761277, 0.39175081874132034`, 0.9381799689915176]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.03217915333176364], {
             RGBColor[
             0.27079044913528966`, 0.40194830952027055`, 0.9387324875284604]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.03217915333176364], {
             RGBColor[
             0.18257815057035692`, 0.3092315907457619, 0.9337089276235886]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.03217915333176364], {
             RGBColor[
             0.519374038863881, 0.6206902681403376, 0.955306173350608]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.03217915333176364], {
             RGBColor[
             0.46295717480753656`, 0.5748885163486347, 0.9508648311503101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.03217915333176364], {
             RGBColor[
             0.2828083531870263, 0.41457988865777246`, 0.939416889385311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.03217915333176364], {
             RGBColor[
             0.9258119809847409, 0.9436813594132142, 0.9927859673000785]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.03217915333176364], {
             RGBColor[
             0.24327422624281886`, 0.37302701463098736`, 0.937165479341338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.03217915333176364], {
             RGBColor[
             0.25427950679235417`, 0.38459426226363735`, 0.9377922137877805]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.03217915333176364], {
             RGBColor[
             0.9906270631619555, 0.9903920639910485, 0.8049973499967711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.03217915333176364], {
             RGBColor[
             0.2238174684207968, 0.35257672853034516`, 0.9360574457670676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.03217915333176364], {
             RGBColor[
             0.24158367299712782`, 0.37125013598249945`, 0.9370692048349454]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.03217915333176364], {
             RGBColor[
             0.7098940201909748, 0.7732938710583535, 0.9717192596619902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.03217915333176364], {
             RGBColor[
             0.8177864636409283, 0.8575802678943982, 0.9824729701128726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.03217915333176364], {
             RGBColor[
             0.5084161265639328, 0.611794141286916, 0.9544435263542006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.03217915333176364], {
             RGBColor[
             0.8302102447519867, 0.867451129981215, 0.983667388353521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.03217915333176364], {
             RGBColor[
             0.2799576543907215, 0.4115836234781131, 0.9392545463060924]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.03217915333176364], {
             RGBColor[
             0.21156771774634342`, 0.33970146389244305`, 0.9353598405880397]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.03217915333176364], {
             RGBColor[
             0.3393902356747875, 0.4683844967174319, 0.9428466235995638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.03217915333176364], {
             RGBColor[
             0.3185921337049145, 0.45037022613412764`, 0.941521386933083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.03217915333176364], {
             RGBColor[
             0.3094371851822424, 0.44244066986488095`, 0.9409380417086214]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.03217915333176364], {
             RGBColor[
             0.23513882534723038`, 0.36447619247551505`, 0.9367021802955814]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.03217915333176364], {
             RGBColor[
             0.22477195032544567`, 0.3535799495297792, 0.936111802099508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.03217915333176364], {
             RGBColor[
             0.45209247002133757`, 0.5660015075294104, 0.9500279103134532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.03217915333176364], {
             RGBColor[
             0.5272216074067284, 0.6270612778123552, 0.9559239626928917]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.03217915333176364], {
             RGBColor[
             0.19556045555100107`, 0.3228768164060961, 0.9344482506866372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.03217915333176364], {
             RGBColor[
             0.26139903658851843`, 0.39207733948366696`, 0.9381976604772716]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.03217915333176364], {
             RGBColor[
             0.28051817934621337`, 0.41217277074566994`, 0.9392864673730853]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.03217915333176364], {
             RGBColor[
             0.2110065608580655, 0.33911165242346125`, 0.9353278835334095]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.03217915333176364], {
             RGBColor[
             0.2847433322190086, 0.4166136743051424, 0.9395270835786375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.03217915333176364], {
             RGBColor[
             0.9942883740099587, 0.9901917344782997, 0.6197029429328111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.03217915333176364], {
             RGBColor[
             0.36576050208801136`, 0.49122509607643855`, 0.9445269136571035]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.03217915333176364], {
             RGBColor[
             0.99377812825938, 0.9891003704115706, 0.5641658418540755]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.03217915333176364], {
             RGBColor[
             0.2215837127017966, 0.35022890964138337`, 0.935930236683416]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.03217915333176364], {
             RGBColor[
             0.6033581995623302, 0.6888723932386622, 0.9619177141249072]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.03217915333176364], {
             RGBColor[
             0.7222005724227306, 0.7829078431950623, 0.9729458617771823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.03217915333176364], {
             RGBColor[
             0.32062864936426844`, 0.45213415364000675`, 0.941651151910077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.03217915333176364], {
             RGBColor[
             0.20194739446585683`, 0.3295898941609259, 0.9348119774092088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.03217915333176364], {
             RGBColor[
             0.3450320119322843, 0.4732711197477559, 0.9432061125938647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.03217915333176364], {
             RGBColor[
             0.2800500850584523, 0.411680773970341, 0.9392598100958807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.03217915333176364], {
             RGBColor[
             0.26295522261758464`, 0.39371298966810864`, 0.9382862829694559]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.03217915333176364], {
             RGBColor[
             0.4453791406536688, 0.5601867590528806, 0.9496001429025095]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.03217915333176364], {
             RGBColor[
             0.4327427506991586, 0.5492417531977101, 0.948794963308529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.03217915333176364], {
             RGBColor[
             0.24574449108125243`, 0.37562341960001794`, 0.9373061572694574]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.03217915333176364], {
             RGBColor[
             0.9941541355650164, 0.9899046120181566, 0.6050919166244885]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.03217915333176364], {
             RGBColor[
             0.21037964845754836`, 0.3384527277419758, 0.9352921817996338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.03217915333176364], {
             RGBColor[
             0.27977343586669706`, 0.4113899981292344, 0.939244055333676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.03217915333176364], {
             RGBColor[
             0.23092116646773903`, 0.3600431655781515, 0.9364619908618614]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.03217915333176364], {
             RGBColor[
             0.5183784049780293, 0.6198819676990077, 0.9552277934039866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.03217915333176364], {
             RGBColor[
             0.6756901028072094, 0.7465735108387558, 0.9683101328309576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.03217915333176364], {
             RGBColor[
             0.9685766725786527, 0.9056638794389593, 0.332426736075871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.03217915333176364], {
             RGBColor[
             0.2455681205459235, 0.37543804298484945`, 0.9372961132283874]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.03217915333176364], {
             RGBColor[
             0.3103917228488082, 0.4432674424152022, 0.9409988640046705]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.03217915333176364], {
             RGBColor[
             0.35562652096447817`, 0.48244755097593534`, 0.9438811853410396]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.03217915333176364], {
             RGBColor[
             0.40465902674538534`, 0.5249170430379596, 0.9470054932516565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.03217915333176364], {
             RGBColor[
             0.8625124936811881, 0.46858316947675277`, 0.2069893934114667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.03217915333176364], {
             RGBColor[
             0.34952976604112324`, 0.4771668482931376, 0.9434927055084721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.03217915333176364], {
             RGBColor[
             0.25624071750281635`, 0.38665561906827417`, 0.93790390183639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.03217915333176364], {
             RGBColor[
             0.9012804456996433, 0.6446193851073215, 0.2393383228651273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.03217915333176364], {
             RGBColor[
             0.21931469518675756`, 0.34784402836905765`, 0.9358010194926452]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.03217915333176364], {
             RGBColor[
             0.21278150541118618`, 0.3409772316867757, 0.9354289639999145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.03217915333176364], {
             RGBColor[
             0.25745394897088236`, 0.38793080226452953`, 0.9379729935736814]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.03217915333176364], {
             RGBColor[
             0.8312166238387177, 0.8682535893475418, 0.9837633776892186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.03217915333176364], {
             RGBColor[
             0.27204560568907665`, 0.4032675586398226, 0.9388039668373608]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.03217915333176364], {
             RGBColor[
             0.2514775053864574, 0.3816491811288898, 0.9376326439529042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.03217915333176364], {
             RGBColor[
             0.2503218011924054, 0.380434462745063, 0.9375668283087641]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.03217915333176364], {
             RGBColor[
             0.2761037265699157, 0.40753290098530925`, 0.9390350708180728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.03217915333176364], {
             RGBColor[
             0.25484534055170655`, 0.38518898942064916`, 0.9378244371832996]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.03217915333176364], {
             RGBColor[
             0.43839329858407067`, 0.5541359737708264, 0.9491550112231723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.03217915333176364], {
             RGBColor[
             0.41487938737084307`, 0.5337694057214698, 0.9476567255932007]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.03217915333176364], {
             RGBColor[
             0.20852643568424656`, 0.3365048836167593, 0.9351866440737768]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.03217915333176364], {
             RGBColor[
             0.22095736038557218`, 0.3495705736440009, 0.9358945668456122]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.03217915333176364], {
             RGBColor[
             0.26549066491796636`, 0.3963779002821365, 0.9384306726576119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.03217915333176364], {
             RGBColor[
             0.9931470290452047, 0.9914341346439413, 0.7632349938486772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.03217915333176364], {
             RGBColor[
             0.898780922280212, 0.63326963303821, 0.23725265925502825`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.03217915333176364], {
             RGBColor[
             0.28023632613366145`, 0.41187652514875206`, 0.939270416249595]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.03217915333176364], {
             RGBColor[
             0.7484278388783107, 0.8033967830847693, 0.9755599505897345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.03217915333176364], {
             RGBColor[
             0.5754210452890663, 0.6661917528451691, 0.9597183990033479]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.03217915333176364], {
             RGBColor[
             0.3393631406607411, 0.4683610283780999, 0.942844897129228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.03217915333176364], {
             RGBColor[
             0.2935687509337651, 0.4258897489382169, 0.9400296781184059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.03217915333176364], {
             RGBColor[
             0.22336510960731928`, 0.352101270736175, 0.9360316846018449]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.03217915333176364], {
             RGBColor[
             0.17908812663026416`, 0.30556335430442605`, 0.933510175923228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.03217915333176364], {
             RGBColor[
             0.26629927432356376`, 0.3972278000362168, 0.9384767217670303]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.03217915333176364], {
             RGBColor[
             0.8203907902431329, 0.1577381258757864, 0.16715954980591485`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.03217915333176364], {
             RGBColor[
             0.24794921220500737`, 0.3779407212884774, 0.9374317128758627]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.03217915333176364], {
             RGBColor[
             0.22281999879048459`, 0.3515283247056597, 0.9360006413472455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.03217915333176364], {
             RGBColor[
             0.35886795134781274`, 0.48525511505495156`, 0.9440877264187814]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.03217915333176364], {
             RGBColor[
             0.27306809856961783`, 0.40434226348706437`, 0.938862196294265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.03217915333176364], {
             RGBColor[
             0.2782995151593558, 0.4098408140138484, 0.9391601177298633]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.03217915333176364], {
             RGBColor[
             0.2493495489754894, 0.37941256402073326`, 0.9375114599833291]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.03217915333176364], {
             RGBColor[
             0.9394254025446074, 0.954344144916344, 0.9874211724934188]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.03217915333176364], {
             RGBColor[
             0.2348790166106703, 0.36420311702056507`, 0.9366873845723869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.03217915333176364], {
             RGBColor[
             0.38961090759033284`, 0.5118831185663134, 0.9460466404056259]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{3.8349502435193233`*^9, 3.834957407142641*^9, 
  3.835018921852682*^9, 3.8350190129675236`*^9, 3.8350205474078445`*^9, 
  3.8350446401426015`*^9, 3.835045030495333*^9, 3.8350457030519285`*^9},
 CellLabel->
  "Out[330]=",ExpressionUUID->"5e56f9e7-410a-4287-9d19-4f3b995d3f71"]
}, Open  ]],

Cell["Estimated with absolute Mean Deviation v Calculated: (r=6)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 
  3.8349503922098827`*^9}},ExpressionUUID->"5a510703-e1ea-4994-93f2-\
5538f07d3c6c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphinf4", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsif4", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}],
      "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"AMDi6f400", ",", "krif4"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502409842243`*^9}, {3.8349504019691753`*^9, 3.834950402221115*^9}, {
   3.8349577477528667`*^9, 3.8349577551942053`*^9}, {3.835018833417392*^9, 
   3.8350188346728773`*^9}, {3.8350443403897114`*^9, 
   3.8350443452390656`*^9}, {3.8350449339623103`*^9, 3.835044937670579*^9}, {
   3.835045607563691*^9, 3.835045609169958*^9}},
 CellLabel->
  "In[331]:=",ExpressionUUID->"78b19c96-b418-452a-b4f3-add8e9d71595"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN2wucz2W+wPHn16rdrWxoc2ntsSnFoptQYTEuNY3rMEhyNxmZGTMj4zII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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[105, 155] -> 
             RGBColor[
              0.8440834282508313, 0.7170547940222387, 0.6050709526960195], 
             UndirectedEdge[1, 203] -> 
             RGBColor[
              0.8734409750659864, 0.8506570844549727, 0.63278412085636], 
             UndirectedEdge[187, 193] -> 
             RGBColor[
              0.8653015894680507, 0.7915261926714298, 0.619290782566415], 
             UndirectedEdge[209, 371] -> 
             RGBColor[
              0.9630426084703875, 0.9719578184261652, 0.9474434032148922], 
             UndirectedEdge[23, 245] -> 
             RGBColor[
              0.9402857049848907, 0.95173928263665, 0.8499484241635995], 
             UndirectedEdge[201, 236] -> 
             RGBColor[
              0.9651183969929951, 0.9541041672578445, 0.6746643541047007], 
             UndirectedEdge[258, 369] -> 
             RGBColor[
              0.9609578964936023, 0.9704030436472816, 0.9509722768116254], 
             UndirectedEdge[161, 312] -> 
             RGBColor[
              0.9803975811127136, 0.9836422685706929, 0.8616916370211619], 
             UndirectedEdge[74, 132] -> 
             RGBColor[
              0.591610823086262, 0.652903379579729, 0.7620763492221462], 
             UndirectedEdge[89, 169] -> 
             RGBColor[
              0.9928529928087821, 0.9880615093274205, 0.5879415812260196], 
             UndirectedEdge[124, 137] -> 
             RGBColor[
              0.8602749694282454, 0.8405445030838187, 0.6317241998657477], 
             UndirectedEdge[186, 393] -> 
             RGBColor[
              0.9915889411417658, 0.9907898252548366, 0.7890565426109001], 
             UndirectedEdge[84, 261] -> 
             RGBColor[
              0.7965475623498134, 0.8412390832661416, 0.955413543489642], 
             UndirectedEdge[58, 243] -> 
             RGBColor[
              0.7381423141806184, 0.7939773170124783, 0.9549527401090343], 
             UndirectedEdge[205, 250] -> 
             RGBColor[
              0.9856198219701171, 0.9628520260177914, 0.4243499167288963], 
             UndirectedEdge[327, 337] -> 
             RGBColor[
              0.8604820527771891, 0.8915890479941726, 0.9865547404269268], 
             UndirectedEdge[38, 224] -> 
             RGBColor[
              0.9701911164673973, 0.956118645827357, 0.6623228474200413], 
             UndirectedEdge[49, 301] -> 
             RGBColor[
              0.8528145142376162, 0.882316352993627, 0.7964631509248364], 
             UndirectedEdge[22, 97] -> 
             RGBColor[
              0.9923257407691903, 0.9906168679320209, 0.7421262691681765], 
             UndirectedEdge[163, 169] -> 
             RGBColor[
              0.9933993071446194, 0.9882874243449273, 0.5788877388650158], 
             UndirectedEdge[126, 318] -> 
             RGBColor[
              0.8693874020121308, 0.8986899317448497, 0.9874041405868547], 
             UndirectedEdge[126, 149] -> 
             RGBColor[
              0.9102024058212057, 0.8495457046027862, 0.6285986135772457], 
             UndirectedEdge[28, 47] -> 
             RGBColor[
              0.7449910927983112, 0.795573390595032, 0.7656503238072657], 
             UndirectedEdge[203, 392] -> 
             RGBColor[
              0.8924170412389247, 0.9134134182942037, 0.8131670940198871], 
             UndirectedEdge[116, 387] -> 
             RGBColor[
              0.687846213081402, 0.7510068973225372, 0.9344733011076831], 
             UndirectedEdge[114, 203] -> 
             RGBColor[
              0.8860581711504301, 0.9110334109097897, 0.9476976032247644], 
             UndirectedEdge[38, 207] -> 
             RGBColor[
              0.9779216012201937, 0.9618840286984853, 0.6492371531668906], 
             UndirectedEdge[4, 73] -> 
             RGBColor[
              0.9745186261499277, 0.9798776447383672, 0.8994031666399925], 
             UndirectedEdge[143, 223] -> 
             RGBColor[
              0.771143377638015, 0.8181961873040693, 0.8625918964294131], 
             UndirectedEdge[70, 164] -> 
             RGBColor[
              0.8468407375342362, 0.8792166541636703, 0.8900698957183766], 
             UndirectedEdge[291, 331] -> 
             RGBColor[
              0.9811580236030992, 0.9467440979576056, 0.4969162621804708], 
             UndirectedEdge[317, 381] -> 
             RGBColor[
              0.963636784073634, 0.8968757942290806, 0.5776131030100247], 
             UndirectedEdge[120, 349] -> 
             RGBColor[
              0.9887907090743395, 0.9849990640513826, 0.6457077488103882], 
             UndirectedEdge[102, 160] -> 
             RGBColor[
              0.5860421408862369, 0.6484161872050751, 0.8482830398123113], 
             UndirectedEdge[84, 381] -> 
             RGBColor[
              0.8077910389202225, 0.8493426314005714, 0.9237608719553743], 
             UndirectedEdge[110, 203] -> 
             RGBColor[
              0.8749229065705617, 0.9027287488184463, 0.9665467016163483], 
             UndirectedEdge[316, 355] -> 
             RGBColor[
              0.9085884061184455, 0.9245833183153691, 0.7040789960141849], 
             UndirectedEdge[62, 77] -> 
             RGBColor[
              0.9886916688516076, 0.9882620212903759, 0.743570420781793], 
             UndirectedEdge[188, 361] -> 
             RGBColor[
              0.9607863993626748, 0.8746946423031299, 0.5220776507438705], 
             UndirectedEdge[168, 282] -> 
             RGBColor[
              0.7417428737060887, 0.7982032979372573, 0.9748859970591646], 
             UndirectedEdge[271, 394] -> 
             RGBColor[
              0.977596789356305, 0.9808771401892215, 0.8329420211304406], 
             UndirectedEdge[160, 224] -> 
             RGBColor[
              0.9771377716228389, 0.9809805089983225, 0.8568829501778339], 
             UndirectedEdge[97, 168] -> 
             RGBColor[
              0.8249271105378482, 0.8621817065268026, 0.8917012110262141], 
             UndirectedEdge[88, 132] -> 
             RGBColor[
              0.966683602488854, 0.9719490429243454, 0.7888066346434897], 
             UndirectedEdge[329, 353] -> 
             RGBColor[
              0.9589969653802404, 0.9658508011408669, 0.7862070579493174], 
             UndirectedEdge[189, 339] -> 
             RGBColor[
              0.8687664770940061, 0.8951608455469291, 0.8287052489124651], 
             UndirectedEdge[316, 380] -> 
             RGBColor[
              0.9925862865340602, 0.9864929452761193, 0.43938980991243515`], 
             UndirectedEdge[156, 295] -> 
             RGBColor[
              0.9783790493399278, 0.9818731138876445, 0.8532978034494325], 
             UndirectedEdge[154, 228] -> 
             RGBColor[
              0.7210616033740045, 0.7820180719177121, 0.9728323399866763], 
             UndirectedEdge[29, 91] -> 
             RGBColor[
              0.913500617621761, 0.9324937498507231, 0.9430295271004372], 
             UndirectedEdge[6, 198] -> 
             RGBColor[
              0.9244086570723944, 0.9422513458848054, 0.9818681256769681], 
             UndirectedEdge[56, 254] -> 
             RGBColor[
              0.8013184529232578, 0.8456394075970961, 0.9805863716578405], 
             UndirectedEdge[245, 315] -> 
             RGBColor[
              0.9162715807602179, 0.9357801400246786, 0.98168410614792], 
             UndirectedEdge[174, 281] -> 
             RGBColor[
              0.8881325041983689, 0.910197620556935, 0.8232577272259065], 
             UndirectedEdge[89, 329] -> 
             RGBColor[
              0.9938507650970774, 0.990551645705708, 0.6662710676347077], 
             UndirectedEdge[260, 267] -> 
             RGBColor[
              0.9592053709563944, 0.8873029859332622, 0.5926531468795662], 
             UndirectedEdge[202, 363] -> 
             RGBColor[
              0.863535862534794, 0.8895880967154913, 0.7091185861564813], 
             UndirectedEdge[43, 238] -> 
             RGBColor[
              0.9863351596545418, 0.9864837623028331, 0.7459107079911279], 
             UndirectedEdge[276, 377] -> 
             RGBColor[
              0.9387560200890224, 0.7878692337638684, 0.30123045691993594`], 
             UndirectedEdge[284, 369] -> 
             RGBColor[
              0.942889349269938, 0.8289165621759718, 0.5844136588973734], 
             UndirectedEdge[53, 249] -> 
             RGBColor[
              0.7495400856119085, 0.7995864031010981, 0.7922302722222827], 
             UndirectedEdge[15, 105] -> 
             RGBColor[
              0.895789564881013, 0.9150072737714868, 0.7301416071903687], 
             UndirectedEdge[97, 112] -> 
             RGBColor[
              0.9302433414753382, 0.9448643620981978, 0.9020896616181853], 
             UndirectedEdge[120, 246] -> 
             RGBColor[
              0.9786819893779936, 0.9832233275474489, 0.9031326264960123], 
             UndirectedEdge[53, 308] -> 
             RGBColor[
              0.9431112347838904, 0.7960687296392407, 0.43088409654570187`], 
             UndirectedEdge[188, 392] -> 
             RGBColor[
              0.9620460992436524, 0.874571564013132, 0.45438941191744053`], 
             UndirectedEdge[91, 273] -> 
             RGBColor[
              0.9893876954080058, 0.9898795535744919, 0.8255368810606512], 
             UndirectedEdge[327, 354] -> 
             RGBColor[
              0.7856490662484306, 0.8324945971187883, 0.9792644254779584], 
             UndirectedEdge[51, 376] -> 
             RGBColor[
              0.9913220211383894, 0.9906794469739093, 0.7934800978336709], 
             UndirectedEdge[202, 214] -> 
             RGBColor[
              0.9919538680768347, 0.9886915379928101, 0.6195161040380368], 
             UndirectedEdge[69, 132] -> 
             RGBColor[
              0.9904008620594813, 0.989206439177136, 0.7293630480612997], 
             UndirectedEdge[130, 387] -> 
             RGBColor[
              0.9800669719139756, 0.9846545608075566, 0.9186255965700079], 
             UndirectedEdge[61, 306] -> 
             RGBColor[
              0.5437344204135495, 0.6189560956774971, 0.962122348281609], 
             UndirectedEdge[312, 356] -> 
             RGBColor[
              0.9552112843383582, 0.9661172297111142, 0.9606997922339622], 
             UndirectedEdge[18, 247] -> 
             RGBColor[
              0.9693496748440793, 0.9741082029432946, 0.7978465237781602], 
             UndirectedEdge[56, 320] -> 
             RGBColor[
              0.7917359951509264, 0.8381535187559745, 0.9796312818202536], 
             UndirectedEdge[43, 124] -> 
             RGBColor[
              0.8713308639574202, 0.8995812504742562, 0.9489087207840818], 
             UndirectedEdge[259, 318] -> 
             RGBColor[
              0.9252417313751878, 0.9394612012109687, 0.8256192122733161], 
             UndirectedEdge[267, 384] -> 
             RGBColor[
              0.9407172925160926, 0.873514607303935, 0.6239486412158748], 
             UndirectedEdge[44, 324] -> 
             RGBColor[
              0.8902169556459049, 0.5420840388563168, 0.22790253574395586`], 
             UndirectedEdge[62, 204] -> 
             RGBColor[
              0.9796908672109688, 0.9843740625358692, 0.9192622437283815], 
             UndirectedEdge[42, 109] -> 
             RGBColor[
              0.987474974529824, 0.9744081755170069, 0.5980697785012831], 
             UndirectedEdge[8, 21] -> 
             RGBColor[
              0.9165687344103421, 0.9332710868690568, 0.8708442546603792], 
             UndirectedEdge[48, 349] -> 
             RGBColor[
              0.9903039501785502, 0.9856248281364961, 0.6206294275711761], 
             UndirectedEdge[222, 332] -> 
             RGBColor[
              0.7416072411115653, 0.7974127373339692, 0.9719201145963401], 
             UndirectedEdge[58, 167] -> 
             RGBColor[
              0.7518977936375513, 0.8038956319926331, 0.9164200570751794], 
             UndirectedEdge[76, 144] -> 
             RGBColor[
              0.9393619183523532, 0.7788955623574828, 0.4344288305562278], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.7787956964816487, 0.827798594722271, 0.978487922192984], 
             UndirectedEdge[6, 166] -> 
             RGBColor[
              0.886085719796952, 0.9120047170827048, 0.9889968410439351], 
             UndirectedEdge[79, 343] -> 
             RGBColor[
              0.9885273483948486, 0.9879105564487147, 0.725685153131878], 
             UndirectedEdge[142, 257] -> 
             RGBColor[
              0.8495014601898427, 0.879344054246822, 0.7653672215638101], 
             UndirectedEdge[175, 256] -> 
             RGBColor[
              0.9378292779205464, 0.951128514122229, 0.9121636833356108], 
             UndirectedEdge[8, 171] -> 
             RGBColor[
              0.9781766838302692, 0.9816957645816601, 0.8524569702683331], 
             UndirectedEdge[31, 214] -> 
             RGBColor[
              0.9885566244849262, 0.98953588439025, 0.8393098769986842], 
             UndirectedEdge[41, 114] -> 
             RGBColor[
              0.9472862523394334, 0.838884483013941, 0.5821602979801157], 
             UndirectedEdge[72, 399] -> 
             RGBColor[
              0.8923792436931494, 0.9134077374030551, 0.8150733370724632], 
             UndirectedEdge[278, 392] -> 
             RGBColor[
              0.9574811125456428, 0.9650538064680211, 0.8194366349063934], 
             UndirectedEdge[6, 323] -> 
             RGBColor[
              0.9306936574348519, 0.9008953458920645, 0.6454089633010505], 
             UndirectedEdge[132, 323] -> 
             RGBColor[
              0.9771734547658208, 0.9337290146046322, 0.44522975477732785`], 
             UndirectedEdge[200, 355] -> 
             RGBColor[
              0.8745443747602506, 0.9028019618319042, 0.9878960172512543], 
             UndirectedEdge[98, 215] -> 
             RGBColor[
              0.8597693366846955, 0.8889837352777263, 0.8762661730990607], 
             UndirectedEdge[12, 367] -> 
             RGBColor[
              0.9710750217249731, 0.9127103589675796, 0.5167757009725693], 
             UndirectedEdge[88, 140] -> 
             RGBColor[
              0.9649090151287051, 0.972307290291045, 0.8975991792791858], 
             UndirectedEdge[195, 327] -> 
             RGBColor[
              0.8876262501302693, 0.9127932433754473, 0.9738938755949069], 
             UndirectedEdge[142, 381] -> 
             RGBColor[
              0.8455780923832413, 0.8790561799211349, 0.9273944830779127], 
             UndirectedEdge[313, 359] -> 
             RGBColor[
              0.7178191677918485, 0.7785035575345274, 0.9734476977290833], 
             UndirectedEdge[64, 82] -> 
             RGBColor[
              0.9430507805989041, 0.9539012670453433, 0.8467416938543219], 
             UndirectedEdge[98, 297] -> 
             RGBColor[
              0.9884936466349914, 0.975707151031968, 0.5872545716133635], 
             UndirectedEdge[139, 305] -> 
             RGBColor[
              0.689067366113344, 0.7556716700926119, 0.9705971113384562], 
             UndirectedEdge[288, 375] -> 
             RGBColor[
              0.9583177937973857, 0.9684340593792146, 0.9554412820272574], 
             UndirectedEdge[136, 194] -> 
             RGBColor[
              0.9883652256025581, 0.9872225488253168, 0.6809628863355724], 
             UndirectedEdge[254, 349] -> 
             RGBColor[
              0.829658142614808, 0.8610475252644392, 0.6935408166292127], 
             UndirectedEdge[348, 351] -> 
             RGBColor[
              0.8614391003395823, 0.8885966431580974, 0.7606952037782833], 
             UndirectedEdge[65, 282] -> 
             RGBColor[
              0.8933881529442209, 0.8748721103231147, 0.6473279885175468], 
             UndirectedEdge[131, 215] -> 
             RGBColor[
              0.8590204919901563, 0.8886740687521035, 0.8886764676355223], 
             UndirectedEdge[230, 250] -> 
             RGBColor[
              0.9382549749591101, 0.9299989079497364, 0.680075592609419], 
             UndirectedEdge[26, 111] -> 
             RGBColor[
              0.9903106532581486, 0.9880026553002117, 0.6460672433994351], 
             UndirectedEdge[301, 390] -> 
             RGBColor[
              0.9822610464110633, 0.9507148919147186, 0.47993978374478663`], 
             UndirectedEdge[3, 309] -> 
             RGBColor[
              0.8585126070396709, 0.528496164752507, 0.5772569879738741], 
             UndirectedEdge[90, 268] -> 
             RGBColor[
              0.9561995919752604, 0.9666017024760588, 0.9497488314893145], 
             UndirectedEdge[17, 187] -> 
             RGBColor[
              0.9012079799883567, 0.9206823731803331, 0.8461939269345207], 
             UndirectedEdge[4, 206] -> 
             RGBColor[
              0.9727729228423001, 0.9791557515581346, 0.9283339881827236], 
             UndirectedEdge[19, 231] -> 
             RGBColor[
              0.9601048331440736, 0.9674984330254969, 0.8482651635752572], 
             UndirectedEdge[76, 138] -> 
             RGBColor[
              0.9946778337705605, 0.9914006450965116, 0.6894168742422906], 
             UndirectedEdge[28, 390] -> 
             RGBColor[
              0.7331498731436399, 0.7564946141057465, 0.6461438658229306], 
             UndirectedEdge[123, 174] -> 
             RGBColor[
              0.8873101754829793, 0.9103346859078185, 0.871567386361036], 
             UndirectedEdge[2, 98] -> 
             RGBColor[
              0.9627154860522527, 0.9703214528252828, 0.8862839633072246], 
             UndirectedEdge[20, 364] -> 
             RGBColor[
              0.9369728857054351, 0.9518393502187579, 0.9681452965389019], 
             UndirectedEdge[56, 196] -> 
             RGBColor[
              0.9609629654292966, 0.9698026492306835, 0.9242690329744914], 
             UndirectedEdge[360, 374] -> 
             RGBColor[
              0.9336994830682547, 0.7536958199443724, 0.40667745013907997`], 
             UndirectedEdge[39, 360] -> 
             RGBColor[
              0.9942309327795318, 0.9900688734946155, 0.6134508194870163], 
             UndirectedEdge[261, 264] -> 
             RGBColor[
              0.9622246692782123, 0.9713478007158936, 0.9488279609145374], 
             UndirectedEdge[101, 253] -> 
             RGBColor[
              0.9601804019356145, 0.9691978806804559, 0.9250292653249201], 
             UndirectedEdge[141, 273] -> 
             RGBColor[
              0.9813613929790395, 0.9490365395257243, 0.5414941363440139], 
             UndirectedEdge[171, 182] -> 
             RGBColor[
              0.7763987223433999, 0.8248999654777891, 0.9543267193200837], 
             UndirectedEdge[156, 175] -> 
             RGBColor[
              0.9761012681537746, 0.9809311928308638, 0.8910465324127399], 
             UndirectedEdge[121, 250] -> 
             RGBColor[
              0.9862120674525241, 0.9641187792194565, 0.4888121825734595], 
             UndirectedEdge[68, 308] -> 
             RGBColor[
              0.7100926095334013, 0.6148567429429848, 0.593735432244974], 
             UndirectedEdge[39, 390] -> 
             RGBColor[
              0.9823000320872682, 0.9507982783340645, 0.48418313400798885`], 
             UndirectedEdge[54, 181] -> 
             RGBColor[
              0.8856703204889247, 0.9107832355387339, 0.9503325091625539], 
             UndirectedEdge[196, 313] -> 
             RGBColor[
              0.943351636917068, 0.95575985392181, 0.9225892487391765], 
             UndirectedEdge[200, 241] -> 
             RGBColor[
              0.9584227873358102, 0.9644560591628282, 0.7102034940295578], 
             UndirectedEdge[186, 255] -> 
             RGBColor[
              0.7425959288867237, 0.7949595568095097, 0.85781433122697], 
             UndirectedEdge[11, 38] -> 
             RGBColor[
              0.9623196962945562, 0.9502481535507197, 0.6756471085774833], 
             UndirectedEdge[173, 310] -> 
             RGBColor[
              0.9854941660175793, 0.9882694791124094, 0.8900627391910798], 
             UndirectedEdge[106, 173] -> 
             RGBColor[
              0.9900941535941172, 0.9899331999568529, 0.7964931729931677], 
             UndirectedEdge[51, 396] -> 
             RGBColor[
              0.9883132162566424, 0.9740319346302218, 0.5791814560828581], 
             UndirectedEdge[6, 18] -> 
             RGBColor[
              0.9476589008972304, 0.9570379244030911, 0.8035908663038613], 
             UndirectedEdge[238, 287] -> 
             RGBColor[
              0.9656776799121338, 0.9710774477344639, 0.7808784328614244], 
             UndirectedEdge[93, 225] -> 
             RGBColor[
              0.9868362194290916, 0.9880920896930678, 0.8350247298537992], 
             UndirectedEdge[116, 276] -> 
             RGBColor[
              0.6494035942174397, 0.5811024215834972, 0.5928236623257395], 
             UndirectedEdge[135, 276] -> 
             RGBColor[
              0.9362726524631526, 0.8107587955334414, 0.5860349909345601], 
             UndirectedEdge[147, 172] -> 
             RGBColor[
              0.8875534757387185, 0.8961009708880305, 0.6844529676541411], 
             UndirectedEdge[185, 224] -> 
             RGBColor[
              0.9760362885435905, 0.9805250174382294, 0.8751373753478107], 
             UndirectedEdge[160, 166] -> 
             RGBColor[
              0.9321361137445533, 0.9457529013060226, 0.8753169974361046], 
             UndirectedEdge[63, 156] -> 
             RGBColor[
              0.9745727863841667, 0.9802991263389411, 0.9163774309191648], 
             UndirectedEdge[247, 302] -> 
             RGBColor[
              0.8854144804067225, 0.9112441331886034, 0.9811195897233386], 
             UndirectedEdge[81, 240] -> 
             RGBColor[
              0.9492454866063034, 0.961667947530645, 0.9707983316650852], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.9317829306769336, 0.9435343802209992, 0.7336206024440354], 
             UndirectedEdge[12, 212] -> 
             RGBColor[
              0.9825418389678018, 0.9535765793188604, 0.549937638930418], 
             UndirectedEdge[18, 74] -> 
             RGBColor[
              0.5917334327752523, 0.6531656293067382, 0.7754216572094464], 
             UndirectedEdge[1, 7] -> 
             RGBColor[
              0.9755981397699358, 0.928046766241533, 0.47043101171690505`], 
             UndirectedEdge[231, 331] -> 
             RGBColor[
              0.9599273007251814, 0.9671187091327671, 0.8289418553819201], 
             UndirectedEdge[58, 351] -> 
             RGBColor[
              0.6234025194402644, 0.7038142009794264, 0.964405739057651], 
             UndirectedEdge[142, 279] -> 
             RGBColor[
              0.7884350450882194, 0.8350679274393971, 0.9794367800985615], 
             UndirectedEdge[303, 344] -> 
             RGBColor[
              0.9336199535705147, 0.9493049507017954, 0.9726494772375431], 
             UndirectedEdge[302, 323] -> 
             RGBColor[
              0.8933608700174542, 0.8711271945769502, 0.6418481287098063], 
             UndirectedEdge[144, 366] -> 
             RGBColor[
              0.8530703014365593, 0.3683331520074642, 0.19686392672425448`], 
             UndirectedEdge[56, 342] -> 
             RGBColor[
              0.9566052192956841, 0.9454696666224361, 0.6830597986697581], 
             UndirectedEdge[137, 293] -> 
             RGBColor[
              0.967332733761027, 0.901467781716384, 0.32759426866753005`], 
             UndirectedEdge[39, 374] -> 
             RGBColor[
              0.9338474012632938, 0.7540122020067375, 0.4227774328238073], 
             UndirectedEdge[4, 278] -> 
             RGBColor[
              0.9407129635548059, 0.9549105759218703, 0.9715873381181925], 
             UndirectedEdge[238, 396] -> 
             RGBColor[
              0.9887781020600221, 0.9729817615706257, 0.48116661952247175`], 
             UndirectedEdge[118, 293] -> 
             RGBColor[
              0.9847393584488184, 0.964021793238427, 0.579434870196008], 
             UndirectedEdge[201, 228] -> 
             RGBColor[
              0.8260517622710326, 0.8647258829844017, 0.9705667292749269], 
             UndirectedEdge[212, 336] -> 
             RGBColor[
              0.9453578290666678, 0.9269791685306521, 0.6679787057838589], 
             UndirectedEdge[186, 200] -> 
             RGBColor[
              0.9587566879149945, 0.9669726204145217, 0.8775606323676313], 
             UndirectedEdge[7, 356] -> 
             RGBColor[
              0.9680047953394961, 0.9733501046720731, 0.8195556674238266], 
             UndirectedEdge[215, 269] -> 
             RGBColor[
              0.6029085162442567, 0.6872054069427376, 0.9627724385176192], 
             UndirectedEdge[36, 122] -> 
             RGBColor[
              0.9805696895789584, 0.9459337835245045, 0.39477887863266864`], 
             UndirectedEdge[297, 352] -> 
             RGBColor[
              0.9661648074546807, 0.9603833176580013, 0.6845658367782592], 
             UndirectedEdge[228, 243] -> 
             RGBColor[
              0.8306038132386195, 0.8681207951427287, 0.9628612943518382], 
             UndirectedEdge[100, 271] -> 
             RGBColor[
              0.9631229908941827, 0.9720177675062178, 0.9473073367385005], 
             UndirectedEdge[157, 298] -> 
             RGBColor[
              0.9883050194499907, 0.9726445618813578, 0.5697512583669284], 
             UndirectedEdge[272, 384] -> 
             RGBColor[
              0.9073412073097762, 0.9287361402799006, 0.9834963282338307], 
             UndirectedEdge[35, 114] -> 
             RGBColor[
              0.9573326626066605, 0.9676258195334642, 0.9545594995292388], 
             UndirectedEdge[15, 155] -> 
             RGBColor[
              0.9412961924046754, 0.7894885345664018, 0.35465422944825287`], 
             UndirectedEdge[36, 262] -> 
             RGBColor[
              0.993931066754556, 0.9894274903882982, 0.5808122532269959], 
             UndirectedEdge[111, 185] -> 
             RGBColor[
              0.9894558409509708, 0.9899077335077685, 0.8244075330587067], 
             UndirectedEdge[26, 400] -> 
             RGBColor[
              0.9690196806779272, 0.9727494469540352, 0.710121346845981], 
             UndirectedEdge[61, 131] -> 
             RGBColor[
              0.5899495960603041, 0.6533085043578444, 0.868990219753158], 
             UndirectedEdge[168, 350] -> 
             RGBColor[
              0.5898068329668837, 0.6776016016465417, 0.9610349419100009], 
             UndirectedEdge[16, 208] -> 
             RGBColor[
              0.8101588129809172, 0.8206845227175644, 0.6548999679711349], 
             UndirectedEdge[125, 303] -> 
             RGBColor[
              0.9244842112696039, 0.9424915290521811, 0.9881139059697842], 
             UndirectedEdge[145, 164] -> 
             RGBColor[
              0.9917394776691896, 0.9889680572895508, 0.6496134928710877], 
             UndirectedEdge[152, 256] -> 
             RGBColor[
              0.8767718778586013, 0.9045781123385683, 0.9881084784852905], 
             UndirectedEdge[237, 246] -> 
             RGBColor[
              0.9127904719425985, 0.9323938621181878, 0.9601844006070754], 
             UndirectedEdge[16, 284] -> 
             RGBColor[
              0.7786573720642356, 0.7004164155599261, 0.6054681277116873], 
             UndirectedEdge[240, 309] -> 
             RGBColor[
              0.9185846735448626, 0.9378730085078277, 0.9905193794603737], 
             UndirectedEdge[151, 249] -> 
             RGBColor[
              0.7492171760089823, 0.7988957321116077, 0.7570835547108314], 
             UndirectedEdge[47, 311] -> 
             RGBColor[
              0.9795911638376545, 0.9419539069245928, 0.44872151035758734`], 
             UndirectedEdge[29, 190] -> 
             RGBColor[
              0.9131924766881008, 0.9176859068361214, 0.6889703823405644], 
             UndirectedEdge[99, 384] -> 
             RGBColor[
              0.8881767441611926, 0.9134549175707141, 0.9816684046304006], 
             UndirectedEdge[5, 398] -> 
             RGBColor[
              0.9842130456994609, 0.9832107358004059, 0.6738993974264276], 
             UndirectedEdge[36, 157] -> 
             RGBColor[
              0.9933171087389028, 0.9893661575965977, 0.6049838150025428], 
             UndirectedEdge[40, 55] -> 
             RGBColor[
              0.9586445139130166, 0.9432012685251486, 0.6727275379612929], 
             UndirectedEdge[163, 319] -> 
             RGBColor[
              0.9947421579300866, 0.9920937614307824, 0.736799580164959], 
             UndirectedEdge[13, 74] -> 
             RGBColor[
              0.5397718643891435, 0.6157964610643536, 0.9617443961505856], 
             UndirectedEdge[47, 158] -> 
             RGBColor[
              0.9923377574339549, 0.9899103981348751, 0.690213017196472], 
             UndirectedEdge[252, 330] -> 
             RGBColor[
              0.9846261952919884, 0.9857012892925884, 0.7878471738944954], 
             UndirectedEdge[102, 185] -> 
             RGBColor[
              0.5849406578069885, 0.6479606956449819, 0.8665374649822881], 
             UndirectedEdge[41, 356] -> 
             RGBColor[
              0.9270757118245501, 0.8238114949896638, 0.616371471318633], 
             UndirectedEdge[33, 175] -> 
             RGBColor[
              0.8460509023951052, 0.8788900370358026, 0.9031595080015947], 
             UndirectedEdge[12, 126] -> 
             RGBColor[
              0.9382881053854024, 0.9505773729810312, 0.8723882402706128], 
             UndirectedEdge[18, 191] -> 
             RGBColor[
              0.9946372779569874, 0.9909380047413936, 0.6576789843813112], 
             UndirectedEdge[64, 171] -> 
             RGBColor[
              0.9789502727378707, 0.9818267187595914, 0.825902313856607], 
             UndirectedEdge[73, 184] -> 
             RGBColor[
              0.9878180281467424, 0.9892304558233509, 0.8515503297484406], 
             UndirectedEdge[93, 316] -> 
             RGBColor[
              0.9860962497646105, 0.9852491434649808, 0.6720573103129864], 
             UndirectedEdge[20, 362] -> 
             RGBColor[
              0.9503684147686423, 0.9606585928434404, 0.8930249680446621], 
             UndirectedEdge[32, 330] -> 
             RGBColor[
              0.9684804096678936, 0.9325000373162621, 0.6177891636910854], 
             UndirectedEdge[124, 277] -> 
             RGBColor[
              0.8782722765731267, 0.9011250810373301, 0.7125725804748091], 
             UndirectedEdge[267, 331] -> 
             RGBColor[
              0.9660108608488811, 0.8901348574917809, 0.4667909829572594], 
             UndirectedEdge[134, 167] -> 
             RGBColor[
              0.9849780000552124, 0.9726528998472654, 0.6344557452608875], 
             UndirectedEdge[143, 398] -> 
             RGBColor[
              0.9924074986391038, 0.9878772860395807, 0.5953245725195426], 
             UndirectedEdge[109, 320] -> 
             RGBColor[
              0.8166811625748994, 0.8421111157430481, 0.6793986487838299], 
             UndirectedEdge[28, 147] -> 
             RGBColor[
              0.6440222271341787, 0.719593495490845, 0.9666858427743934], 
             UndirectedEdge[54, 311] -> 
             RGBColor[
              0.9720566142295204, 0.939137192388715, 0.6201631993656332], 
             UndirectedEdge[160, 289] -> 
             RGBColor[
              0.9002232175682128, 0.9204090318668307, 0.8722458879760141], 
             UndirectedEdge[209, 240] -> 
             RGBColor[
              0.9563843817861821, 0.9669921238669306, 0.9587140442476121], 
             UndirectedEdge[31, 261] -> 
             RGBColor[
              0.9746408349987339, 0.9803272661898343, 0.9152496892716165], 
             UndirectedEdge[245, 248] -> 
             RGBColor[
              0.9376739555456868, 0.9445485678936738, 0.7021061886221085], 
             UndirectedEdge[81, 245] -> 
             RGBColor[
              0.9232362217796216, 0.9409743578933969, 0.9698947855713672], 
             UndirectedEdge[308, 386] -> 
             RGBColor[
              0.9431077471805862, 0.796061270008424, 0.43050449244904576`], 
             UndirectedEdge[320, 349] -> 
             RGBColor[
              0.8200756848424767, 0.8535616364233176, 0.6925857267916259], 
             UndirectedEdge[222, 356] -> 
             RGBColor[
              0.7423644916602439, 0.7979774935532897, 0.9706382869400012], 
             UndirectedEdge[200, 374] -> 
             RGBColor[
              0.8988182966378473, 0.7300656772121312, 0.6043238927529475], 
             UndirectedEdge[73, 348] -> 
             RGBColor[
              0.990832642252353, 0.989049530956084, 0.6978229011079157], 
             UndirectedEdge[23, 81] -> 
             RGBColor[
              0.9780773234074922, 0.9812201322939018, 0.8309075189494036], 
             UndirectedEdge[25, 233] -> 
             RGBColor[
              0.9908922587358318, 0.990135709337411, 0.7739965946654358], 
             UndirectedEdge[168, 170] -> 
             RGBColor[
              0.8120843201521567, 0.853555726828869, 0.9560800325195853], 
             UndirectedEdge[73, 284] -> 
             RGBColor[
              0.9483184269689061, 0.8323265905516186, 0.5466093144150487], 
             UndirectedEdge[143, 234] -> 
             RGBColor[
              0.7197129657914253, 0.7762585447779553, 0.8585939781648149], 
             UndirectedEdge[288, 374] -> 
             RGBColor[
              0.9199425395193639, 0.7461135194954442, 0.5787389949297967], 
             UndirectedEdge[254, 344] -> 
             RGBColor[
              0.8136894460826821, 0.8549014276312124, 0.9608851065710764], 
             UndirectedEdge[6, 102] -> 
             RGBColor[
              0.5399917469386356, 0.6146680029817572, 0.9619628834201419], 
             UndirectedEdge[205, 276] -> 
             RGBColor[
              0.9469796938501457, 0.8153072181302052, 0.35889164016730885`], 
             UndirectedEdge[101, 244] -> 
             RGBColor[
              0.963648535914221, 0.9699138611511013, 0.8153490560650529], 
             UndirectedEdge[58, 80] -> 
             RGBColor[
              0.7541919424563661, 0.8048443214861485, 0.8784000740805928], 
             UndirectedEdge[23, 292] -> 
             RGBColor[
              0.977569837474108, 0.9808416501157158, 0.8317665602610935], 
             UndirectedEdge[101, 397] -> 
             RGBColor[
              0.8498898724314203, 0.8835719290283433, 0.9854306589718059], 
             UndirectedEdge[105, 168] -> 
             RGBColor[
              0.7292539355855996, 0.7884179841054411, 0.9736488750998309], 
             UndirectedEdge[166, 340] -> 
             RGBColor[
              0.9279943348937192, 0.9440401693123412, 0.9439569915745007], 
             UndirectedEdge[138, 317] -> 
             RGBColor[
              0.9681157670512344, 0.8987279687949304, 0.5033847638348068], 
             UndirectedEdge[71, 120] -> 
             RGBColor[
              0.9904913698442472, 0.9895692105163162, 0.7515121773506761], 
             UndirectedEdge[231, 290] -> 
             RGBColor[
              0.9492266233693112, 0.961381813141841, 0.9613975556521388], 
             UndirectedEdge[13, 224] -> 
             RGBColor[
              0.925728216309088, 0.9429590749721969, 0.9700516321903813], 
             UndirectedEdge[40, 159] -> 
             RGBColor[
              0.9678700971271819, 0.9731274378167157, 0.8100869030862876], 
             UndirectedEdge[20, 265] -> 
             RGBColor[
              0.9515096131858028, 0.9596135194238767, 0.7638433222217333], 
             UndirectedEdge[43, 299] -> 
             RGBColor[
              0.8582490881768532, 0.8893616678092989, 0.9476048516304201], 
             UndirectedEdge[219, 220] -> 
             RGBColor[
              0.9818380559181878, 0.9842584465648396, 0.8387374814976193], 
             UndirectedEdge[56, 290] -> 
             RGBColor[
              0.9538085903844297, 0.9650353492655153, 0.961834587756411], 
             UndirectedEdge[64, 157] -> 
             RGBColor[
              0.9944469307809077, 0.9917827327019153, 0.7279579718213722], 
             UndirectedEdge[13, 340] -> 
             RGBColor[
              0.9376059476078886, 0.9517042083903432, 0.9448737557755662], 
             UndirectedEdge[16, 188] -> 
             RGBColor[
              0.7891363206644683, 0.7419619548572305, 0.6138997357279717], 
             UndirectedEdge[171, 308] -> 
             RGBColor[
              0.9273371039084604, 0.7867710906883393, 0.5896243360085126], 
             UndirectedEdge[288, 379] -> 
             RGBColor[
              0.9628908504726494, 0.9243322324231721, 0.6187614528199405], 
             UndirectedEdge[81, 353] -> 
             RGBColor[
              0.9425500292848057, 0.9563746637386921, 0.9717369537728512], 
             UndirectedEdge[153, 188] -> 
             RGBColor[
              0.9607349766435903, 0.8714032327712073, 0.3426314087898562], 
             UndirectedEdge[148, 356] -> 
             RGBColor[
              0.9314078978146452, 0.947996464179088, 0.9882256450550548], 
             UndirectedEdge[198, 247] -> 
             RGBColor[
              0.9460994310192432, 0.9593216244250089, 0.976123783151267], 
             UndirectedEdge[94, 375] -> 
             RGBColor[
              0.9629339852237684, 0.971876807386691, 0.9476272740379384], 
             UndirectedEdge[298, 307] -> 
             RGBColor[
              0.9007567003031267, 0.9059464393435459, 0.6850840736690273], 
             UndirectedEdge[9, 142] -> 
             RGBColor[
              0.8497129141409641, 0.8807660349780255, 0.8588697859767548], 
             UndirectedEdge[203, 284] -> 
             RGBColor[
              0.8494486930670664, 0.7557191335613043, 0.6125239450067422], 
             UndirectedEdge[370, 400] -> 
             RGBColor[
              0.8257362431678008, 0.8645546600005047, 0.9743450788598931], 
             UndirectedEdge[63, 381] -> 
             RGBColor[
              0.9858162629545757, 0.988402674473371, 0.8847247593848971], 
             UndirectedEdge[222, 251] -> 
             RGBColor[
              0.7654003351612413, 0.8146132647202067, 0.9072687076614175], 
             UndirectedEdge[103, 234] -> 
             RGBColor[
              0.7195992304642472, 0.7739507202757809, 0.6961431530429958], 
             UndirectedEdge[150, 399] -> 
             RGBColor[
              0.8424243363986202, 0.8774311462242343, 0.9847684701475905], 
             UndirectedEdge[321, 338] -> 
             RGBColor[
              0.9892048151572155, 0.9751235090713096, 0.5694018426213654], 
             UndirectedEdge[154, 203] -> 
             RGBColor[
              0.7649723605273793, 0.8163214891400434, 0.9772089538903685], 
             UndirectedEdge[225, 390] -> 
             RGBColor[
              0.9820549284844977, 0.9514760562510102, 0.5448799922408725], 
             UndirectedEdge[54, 121] -> 
             RGBColor[
              0.986506010736826, 0.9868449715707948, 0.7641716438344206], 
             UndirectedEdge[234, 346] -> 
             RGBColor[
              0.712535403042265, 0.7723503895778374, 0.935447473226651], 
             UndirectedEdge[358, 391] -> 
             RGBColor[
              0.9647048771228564, 0.9068503250320834, 0.5953275712652681], 
             UndirectedEdge[74, 357] -> 
             RGBColor[
              0.43969860522091747`, 0.537049823843225, 0.9519209302309262], 
             UndirectedEdge[130, 364] -> 
             RGBColor[
              0.9733661970352284, 0.9796571338744988, 0.9299682605977406], 
             UndirectedEdge[202, 381] -> 
             RGBColor[
              0.9892815551610517, 0.9875864679268243, 0.6638032447767015], 
             UndirectedEdge[98, 307] -> 
             RGBColor[
              0.9054627830495182, 0.9246798028609806, 0.8808204688031724], 
             UndirectedEdge[242, 317] -> 
             RGBColor[
              0.9121876528974052, 0.6834430345800908, 0.24788588651737703`], 
             UndirectedEdge[9, 279] -> 
             RGBColor[
              0.9328800818208558, 0.9461540692608605, 0.8670483970921381], 
             UndirectedEdge[200, 399] -> 
             RGBColor[
              0.857254250890172, 0.8892561174924926, 0.9861829606306157], 
             UndirectedEdge[275, 306] -> 
             RGBColor[
              0.94004527321824, 0.9360380043598029, 0.6870305632766807], 
             UndirectedEdge[121, 181] -> 
             RGBColor[
              0.8933417779327104, 0.9138927820915652, 0.7937923931679784], 
             UndirectedEdge[239, 271] -> 
             RGBColor[
              0.881108368608267, 0.9075520716308205, 0.966717394542305], 
             UndirectedEdge[35, 354] -> 
             RGBColor[
              0.8408245550870812, 0.8764900342199818, 0.9845271128591293], 
             UndirectedEdge[31, 310] -> 
             RGBColor[
              0.9858429438505658, 0.9884137077095307, 0.8842825878903959], 
             UndirectedEdge[146, 154] -> 
             RGBColor[
              0.8492609408983309, 0.8826933145844138, 0.9645907449207722], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.9793791722566176, 0.9821065856706876, 0.8220020218103139], 
             UndirectedEdge[265, 322] -> 
             RGBColor[
              0.9590039826325054, 0.8634343740813322, 0.39727676512273624`], 
             UndirectedEdge[115, 284] -> 
             RGBColor[
              0.9257365355623003, 0.8161240217979704, 0.6134488983340992], 
             UndirectedEdge[38, 391] -> 
             RGBColor[
              0.980880487767382, 0.9640907614406464, 0.6442285300437077], 
             UndirectedEdge[116, 328] -> 
             RGBColor[
              0.686705379615538, 0.7501560655916392, 0.9364044345883695], 
             UndirectedEdge[92, 278] -> 
             RGBColor[
              0.9460028103589095, 0.9588557350070417, 0.9626330072918536], 
             UndirectedEdge[215, 217] -> 
             RGBColor[
              0.8611065010036691, 0.8891775096933212, 0.82799749499931], 
             UndirectedEdge[159, 210] -> 
             RGBColor[
              0.9667023169840316, 0.9722565092980189, 0.8120636502628003], 
             UndirectedEdge[165, 298] -> 
             RGBColor[
              0.8930543099004273, 0.8999292734206219, 0.6843163713766169], 
             UndirectedEdge[83, 254] -> 
             RGBColor[
              0.5644108697793881, 0.6568554397152822, 0.9591235860484668], 
             UndirectedEdge[103, 231] -> 
             RGBColor[
              0.9589049706457966, 0.9649320484663897, 0.7176675353307991], 
             UndirectedEdge[245, 319] -> 
             RGBColor[
              0.9400282363722282, 0.9517666960031395, 0.8639472446390886], 
             UndirectedEdge[58, 263] -> 
             RGBColor[
              0.7391206706551016, 0.7491319043466423, 0.6284703979761892], 
             UndirectedEdge[206, 258] -> 
             RGBColor[
              0.9646412708849429, 0.9730911788426957, 0.9420987538720317], 
             UndirectedEdge[213, 391] -> 
             RGBColor[
              0.8702014987663524, 0.8986340321466678, 0.945508415219189], 
             UndirectedEdge[78, 370] -> 
             RGBColor[
              0.8257362431678008, 0.8645546600005047, 0.9743450788598931], 
             UndirectedEdge[101, 270] -> 
             RGBColor[
              0.9639476074475558, 0.9705535449201341, 0.8479011468129922], 
             UndirectedEdge[135, 377] -> 
             RGBColor[
              0.9740622620676813, 0.9554346047571951, 0.6481891636705972], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.9377927645583376, 0.7739424868828161, 0.48791808684249083`], 
             UndirectedEdge[19, 83] -> 
             RGBColor[
              0.7277792170153224, 0.7823680012673571, 0.8272394100701558], 
             UndirectedEdge[100, 112] -> 
             RGBColor[
              0.9183824178762983, 0.9369706570420897, 0.9648064387536266], 
             UndirectedEdge[10, 296] -> 
             RGBColor[
              0.6340937981838695, 0.7123149280308461, 0.9653697342944152], 
             UndirectedEdge[85, 369] -> 
             RGBColor[
              0.9644486519392659, 0.97300644334307, 0.9450633383769498], 
             UndirectedEdge[79, 246] -> 
             RGBColor[
              0.9771430669287163, 0.9824739172570054, 0.9235750050334973], 
             UndirectedEdge[227, 280] -> 
             RGBColor[
              0.9356820743206945, 0.7730696622272858, 0.5228976863714736], 
             UndirectedEdge[112, 326] -> 
             RGBColor[
              0.9303010543051895, 0.9448882278364934, 0.9011332106715313], 
             UndirectedEdge[34, 308] -> 
             RGBColor[
              0.8874437720929554, 0.5817902818965771, 0.22779266323980077`], 
             UndirectedEdge[29, 226] -> 
             RGBColor[
              0.8781979854131121, 0.7872953854544836, 0.6173209719274949], 
             UndirectedEdge[204, 345] -> 
             RGBColor[
              0.984195550686651, 0.9839680517648928, 0.6765349448975227], 
             UndirectedEdge[54, 265] -> 
             RGBColor[
              0.9861790533543497, 0.9861456427901403, 0.7285843504989553], 
             UndirectedEdge[22, 100] -> 
             RGBColor[
              0.9804648171701505, 0.9827231628759128, 0.8048430463036178], 
             UndirectedEdge[126, 336] -> 
             RGBColor[
              0.9011040954842684, 0.9239799621928229, 0.9904293071240537], 
             UndirectedEdge[82, 157] -> 
             RGBColor[
              0.9424347303343896, 0.9538354591448869, 0.8706855272531575], 
             UndirectedEdge[344, 349] -> 
             RGBColor[
              0.975023199365455, 0.9751295934051978, 0.686849935852031], 
             UndirectedEdge[343, 349] -> 
             RGBColor[
              0.9922674576673671, 0.9849365937262005, 0.4790406716941721], 
             UndirectedEdge[2, 66] -> 
             RGBColor[
              0.863431734910945, 0.8941541039693528, 0.9867795442994243], 
             UndirectedEdge[211, 387] -> 
             RGBColor[
              0.98162731646359, 0.9856170746593182, 0.9069747055481037], 
             UndirectedEdge[250, 265] -> 
             RGBColor[
              0.985885110070048, 0.9634194504388022, 0.4532248892379942], 
             UndirectedEdge[217, 306] -> 
             RGBColor[
              0.9465644678540512, 0.9565706252057508, 0.8363472467471008], 
             UndirectedEdge[374, 375] -> 
             RGBColor[
              0.9116912058300386, 0.7399596883402646, 0.5927063505733317], 
             UndirectedEdge[38, 247] -> 
             RGBColor[
              0.9618510066162798, 0.9498986055560701, 0.6764404779489595], 
             UndirectedEdge[204, 310] -> 
             RGBColor[
              0.9808378144951974, 0.9849613810222628, 0.9053159080749626], 
             UndirectedEdge[226, 266] -> 
             RGBColor[
              0.9546248873787646, 0.8449044203492861, 0.4908820422147281], 
             UndirectedEdge[319, 334] -> 
             RGBColor[
              0.9924011442561773, 0.9911256921153138, 0.7755962350908175], 
             UndirectedEdge[73, 206] -> 
             RGBColor[
              0.9862923481586232, 0.9885995479400764, 0.876834795484817], 
             UndirectedEdge[200, 255] -> 
             RGBColor[
              0.708159882695407, 0.7704791423627562, 0.9728974208893628], 
             UndirectedEdge[296, 383] -> 
             RGBColor[
              0.863368660345345, 0.89296951698788, 0.9298573739306968], 
             UndirectedEdge[235, 281] -> 
             RGBColor[
              0.9852994973983922, 0.9863292821551733, 0.7966927317011745], 
             UndirectedEdge[174, 272] -> 
             RGBColor[
              0.8260498014941786, 0.8644444657590784, 0.9831880953330584], 
             UndirectedEdge[9, 131] -> 
             RGBColor[
              0.9924257926804467, 0.9911358848721847, 0.7751877469125967], 
             UndirectedEdge[228, 361] -> 
             RGBColor[
              0.8472465842045722, 0.8792330793618703, 0.8764787189426246], 
             UndirectedEdge[149, 199] -> 
             RGBColor[
              0.881705030785213, 0.8268226712897242, 0.6258805085064056], 
             UndirectedEdge[102, 400] -> 
             RGBColor[
              0.5621512105637609, 0.6320878295166101, 0.9554251715229646], 
             UndirectedEdge[45, 350] -> 
             RGBColor[
              0.7574605398088944, 0.8066198866890838, 0.8419523173360646], 
             UndirectedEdge[369, 392] -> 
             RGBColor[
              0.9858576974417963, 0.9866108469088712, 0.7850568079105182], 
             UndirectedEdge[82, 151] -> 
             RGBColor[
              0.9423892935638563, 0.9524864131639741, 0.7747429123141303], 
             UndirectedEdge[260, 342] -> 
             RGBColor[
              0.9799964806290168, 0.9629505846166202, 0.6447040941108344], 
             UndirectedEdge[296, 380] -> 
             RGBColor[
              0.8668478086988709, 0.8922358760685299, 0.7142913753258187], 
             UndirectedEdge[105, 148] -> 
             RGBColor[
              0.8599979593739686, 0.8913760714770774, 0.9864626512735775], 
             UndirectedEdge[94, 288] -> 
             RGBColor[
              0.9711853189130935, 0.9780306385418708, 0.9336599183944034], 
             UndirectedEdge[195, 258] -> 
             RGBColor[
              0.9487459041408489, 0.9612953597459003, 0.9716439944671245], 
             UndirectedEdge[339, 374] -> 
             RGBColor[
              0.8079921390166291, 0.6582682783413787, 0.5954949798477847], 
             UndirectedEdge[199, 367] -> 
             RGBColor[
              0.8872866385046134, 0.8489518859366342, 0.6303716010946072], 
             UndirectedEdge[36, 298] -> 
             RGBColor[
              0.9877912476725004, 0.9702937946764967, 0.4228332681492635], 
             UndirectedEdge[147, 347] -> 
             RGBColor[
              0.8919460444987726, 0.9109181367398842, 0.7015172678199435], 
             UndirectedEdge[38, 205] -> 
             RGBColor[
              0.9861284743386941, 0.9645678298942573, 0.4263259351298781], 
             UndirectedEdge[16, 73] -> 
             RGBColor[
              0.8183769965615804, 0.8574112661286165, 0.9067627872387247], 
             UndirectedEdge[108, 290] -> 
             RGBColor[
              0.8654302323164287, 0.8950694294055346, 0.9532710800159103], 
             UndirectedEdge[225, 296] -> 
             RGBColor[
              0.8674101962693594, 0.8946407959551956, 0.8628786645100814], 
             UndirectedEdge[24, 144] -> 
             RGBColor[
              0.9361051552184476, 0.7782153237478693, 0.5368505476294628], 
             UndirectedEdge[209, 319] -> 
             RGBColor[
              0.9849587499747084, 0.9865717219966768, 0.8328220520074194], 
             UndirectedEdge[80, 192] -> 
             RGBColor[
              0.9749019256693667, 0.9796996957597862, 0.8779838408312575], 
             UndirectedEdge[42, 221] -> 
             RGBColor[
              0.9861682883096965, 0.9700004160720022, 0.5929935492830751], 
             UndirectedEdge[22, 365] -> 
             RGBColor[
              0.9686243726822767, 0.973892578763805, 0.8248858303390787], 
             UndirectedEdge[80, 201] -> 
             RGBColor[
              0.9702281344295782, 0.9762139899057827, 0.8858953502802354], 
             UndirectedEdge[39, 375] -> 
             RGBColor[
              0.9722226555413157, 0.9763327418905077, 0.799479719921268], 
             UndirectedEdge[15, 326] -> 
             RGBColor[
              0.991520452663113, 0.9887948619311441, 0.6472374921700979], 
             UndirectedEdge[86, 95] -> 
             RGBColor[
              0.9711827487376974, 0.9761757792622021, 0.8503231292814951], 
             UndirectedEdge[59, 194] -> 
             RGBColor[
              0.9895074253798117, 0.9896655986547502, 0.8052842832496943], 
             UndirectedEdge[296, 324] -> 
             RGBColor[
              0.7869940914363273, 0.5263162976112541, 0.5770504975262707], 
             UndirectedEdge[169, 245] -> 
             RGBColor[
              0.9386853855867611, 0.9479603589172844, 0.7060354033391454], 
             UndirectedEdge[258, 284] -> 
             RGBColor[
              0.9266673496952258, 0.8168182214542379, 0.6118732728022633], 
             UndirectedEdge[33, 152] -> 
             RGBColor[
              0.7849935023331602, 0.8323396352521419, 0.9791043031512744], 
             UndirectedEdge[246, 349] -> 
             RGBColor[
              0.9808831762012349, 0.9794999545344909, 0.6769305235957914], 
             UndirectedEdge[27, 395] -> 
             RGBColor[
              0.9589311469954598, 0.8622101591793698, 0.45257285712748374`], 
             UndirectedEdge[185, 340] -> 
             RGBColor[
              0.9879140198423912, 0.9892701508563757, 0.8499594989329957], 
             UndirectedEdge[223, 321] -> 
             RGBColor[
              0.7668003885883753, 0.8017198309026432, 0.675400626803522], 
             UndirectedEdge[274, 373] -> 
             RGBColor[
              0.7348663569297644, 0.7886516778323089, 0.8558403372363701], 
             UndirectedEdge[156, 214] -> 
             RGBColor[
              0.9773171437035293, 0.9814339886172636, 0.8708963279682503], 
             UndirectedEdge[205, 221] -> 
             RGBColor[
              0.9872912280689845, 0.968490071254086, 0.43084301380443907`], 
             UndirectedEdge[97, 105] -> 
             RGBColor[
              0.8942499756794173, 0.9163372556486853, 0.8986106663645186], 
             UndirectedEdge[130, 158] -> 
             RGBColor[
              0.986527078987067, 0.9883793438884747, 0.8587366419861344], 
             UndirectedEdge[108, 143] -> 
             RGBColor[
              0.875222314920092, 0.9009274892322574, 0.8719918848163895], 
             UndirectedEdge[176, 399] -> 
             RGBColor[
              0.8386665909168742, 0.8744348219783737, 0.9844100530289626], 
             UndirectedEdge[150, 189] -> 
             RGBColor[
              0.9447627202236726, 0.9551332731494233, 0.8361196713346029], 
             UndirectedEdge[253, 386] -> 
             RGBColor[
              0.9909460441353839, 0.9897448362654316, 0.7430761525435811], 
             UndirectedEdge[46, 59] -> 
             RGBColor[
              0.9947920800956059, 0.9912691108630016, 0.6745282418418839], 
             UndirectedEdge[186, 241] -> 
             RGBColor[
              0.9928588335271269, 0.9889364736095817, 0.5951204043671651], 
             UndirectedEdge[39, 93] -> 
             RGBColor[
              0.9870813230318621, 0.9874143117761222, 0.7743278716209157], 
             UndirectedEdge[214, 264] -> 
             RGBColor[
              0.9761404587644045, 0.9805564189163092, 0.872888148641605], 
             UndirectedEdge[234, 290] -> 
             RGBColor[
              0.7099208831877619, 0.7704004849512324, 0.9398731733643356], 
             UndirectedEdge[148, 170] -> 
             RGBColor[
              0.9428283439405257, 0.9565138142005054, 0.9688938086933319], 
             UndirectedEdge[50, 362] -> 
             RGBColor[
              0.9924822388482909, 0.9898145754367795, 0.6765103276300335], 
             UndirectedEdge[271, 326] -> 
             RGBColor[
              0.975041627323074, 0.9799353383006215, 0.8836341086564052], 
             UndirectedEdge[61, 352] -> 
             RGBColor[
              0.5683696015745325, 0.6382943375095005, 0.9538911903815922], 
             UndirectedEdge[256, 333] -> 
             RGBColor[
              0.8831497213124613, 0.7290382147121695, 0.6050931440105851], 
             UndirectedEdge[100, 394] -> 
             RGBColor[
              0.9806751018957087, 0.9831729406408345, 0.8277312409537245], 
             UndirectedEdge[1, 114] -> 
             RGBColor[
              0.9692005625538451, 0.9255839682250822, 0.6007484889556514], 
             UndirectedEdge[218, 269] -> 
             RGBColor[
              0.7368126574283842, 0.7898735064266362, 0.841016639853998], 
             UndirectedEdge[182, 253] -> 
             RGBColor[
              0.7887365587763386, 0.8335497255063249, 0.9087322261324542], 
             UndirectedEdge[57, 354] -> 
             RGBColor[
              0.7558709977702975, 0.8092114353812923, 0.9763018151078133], 
             UndirectedEdge[40, 192] -> 
             RGBColor[
              0.950138383998386, 0.9623338689436749, 0.9692868892852263], 
             UndirectedEdge[262, 314] -> 
             RGBColor[
              0.9871329095853175, 0.9879264012095983, 0.8118199740390784], 
             UndirectedEdge[244, 253] -> 
             RGBColor[
              0.9909813712748032, 0.9898203974445281, 0.7469212936555512], 
             UndirectedEdge[277, 330] -> 
             RGBColor[
              0.9837077183157092, 0.9837367599125946, 0.6878766232093706], 
             UndirectedEdge[304, 329] -> 
             RGBColor[
              0.8615863400169008, 0.888911573939667, 0.7767213339964626], 
             UndirectedEdge[103, 223] -> 
             RGBColor[
              0.7710296423108369, 0.8158883628018949, 0.7001410713075942], 
             UndirectedEdge[92, 337] -> 
             RGBColor[
              0.9350232055492296, 0.9501008961652357, 0.9615857627834974], 
             UndirectedEdge[226, 341] -> 
             RGBColor[
              0.8972630890482667, 0.802497381584704, 0.619139418531835], 
             UndirectedEdge[193, 260] -> 
             RGBColor[
              0.9522045323766477, 0.8595469938557274, 0.5870201078274999], 
             UndirectedEdge[9, 214] -> 
             RGBColor[
              0.9926954420316609, 0.991247391808584, 0.7707189593328247], 
             UndirectedEdge[8, 157] -> 
             RGBColor[
              0.9936733418733061, 0.991651778523984, 0.7545126282330983], 
             UndirectedEdge[103, 342] -> 
             RGBColor[
              0.9857796404421186, 0.9635957955087615, 0.4075676101374066], 
             UndirectedEdge[165, 314] -> 
             RGBColor[
              0.891268242020101, 0.915149779957162, 0.9505566488243138], 
             UndirectedEdge[115, 392] -> 
             RGBColor[
              0.9687048837341586, 0.9738183065308699, 0.814092047347244], 
             UndirectedEdge[104, 233] -> 
             RGBColor[
              0.9063326963399733, 0.9245031729213842, 0.8320739644383064], 
             UndirectedEdge[67, 139] -> 
             RGBColor[
              0.7720749337986487, 0.8180288711897779, 0.8061067442875323], 
             UndirectedEdge[116, 364] -> 
             RGBColor[
              0.6811454382026549, 0.7460094703894795, 0.9458159651354159], 
             UndirectedEdge[74, 220] -> 
             RGBColor[
              0.579177434644142, 0.646354801716613, 0.9355963481290617], 
             UndirectedEdge[100, 168] -> 
             RGBColor[
              0.8130661869388084, 0.8542880014706946, 0.9544179881616555], 
             UndirectedEdge[129, 308] -> 
             RGBColor[
              0.9430528521626207, 0.7959438551157336, 0.4245295085162821], 
             UndirectedEdge[26, 185] -> 
             RGBColor[
              0.9918091279211547, 0.988622313082407, 0.6212336403053047], 
             UndirectedEdge[197, 215] -> 
             RGBColor[
              0.8325492319362718, 0.8700120040517734, 0.9818570750243986], 
             UndirectedEdge[178, 240] -> 
             RGBColor[
              0.9041155257760267, 0.9263357028315113, 0.9891392992294215], 
             UndirectedEdge[52, 223] -> 
             RGBColor[
              0.7719842765719783, 0.8179302289581472, 0.8040471193130938], 
             UndirectedEdge[192, 243] -> 
             RGBColor[
              0.9588522973936191, 0.968832691286116, 0.9545365068596989], 
             UndirectedEdge[124, 252] -> 
             RGBColor[
              0.8791907535494057, 0.9030896104173238, 0.8125431311599339], 
             UndirectedEdge[194, 396] -> 
             RGBColor[
              0.983857978133285, 0.9721579438604511, 0.6515995876958918], 
             UndirectedEdge[269, 279] -> 
             RGBColor[
              0.6750359478818025, 0.7439691155241903, 0.9698507119165004], 
             UndirectedEdge[57, 208] -> 
             RGBColor[
              0.8672710681231948, 0.8653010505039274, 0.6605923838193482], 
             UndirectedEdge[169, 304] -> 
             RGBColor[
              0.8605885677286057, 0.8864214375613796, 0.6983918475877744], 
             UndirectedEdge[209, 280] -> 
             RGBColor[
              0.9285556709387968, 0.7686463624662171, 0.5748867163239475], 
             UndirectedEdge[226, 399] -> 
             RGBColor[
              0.8522008644345576, 0.7668068179659135, 0.6147774341498219], 
             UndirectedEdge[206, 392] -> 
             RGBColor[
              0.9895410718331368, 0.9892989821042854, 0.7761832849709245], 
             UndirectedEdge[48, 343] -> 
             RGBColor[
              0.9915795119483364, 0.989285730824272, 0.6801644533551808], 
             UndirectedEdge[159, 263] -> 
             RGBColor[
              0.977562366996898, 0.9347808474933209, 0.4688541785279151], 
             UndirectedEdge[261, 295] -> 
             RGBColor[
              0.9783790493399278, 0.9818731138876445, 0.8532978034494325], 
             UndirectedEdge[33, 204] -> 
             RGBColor[
              0.839585339884696, 0.8748337837075053, 0.9483959850450382], 
             UndirectedEdge[64, 151] -> 
             RGBColor[
              0.9944014940103745, 0.9904336867210024, 0.632015356882345], 
             UndirectedEdge[210, 263] -> 
             RGBColor[
              0.9498272200575175, 0.9165267340634655, 0.6449873688547827], 
             UndirectedEdge[19, 303] -> 
             RGBColor[
              0.9516232440558019, 0.9607354441131117, 0.8474561820364138], 
             UndirectedEdge[248, 315] -> 
             RGBColor[
              0.9685009329488845, 0.9688351996822073, 0.6948546039844654], 
             UndirectedEdge[236, 351] -> 
             RGBColor[
              0.854930653220228, 0.8673359633831196, 0.6764119181302286], 
             UndirectedEdge[53, 386] -> 
             RGBColor[
              0.994382338577875, 0.9903927151877974, 0.6299304062683997], 
             UndirectedEdge[93, 301] -> 
             RGBColor[
              0.9870423373556572, 0.9873309253567764, 0.7700845213577134], 
             UndirectedEdge[37, 159] -> 
             RGBColor[
              0.9852896973108887, 0.9861189471117467, 0.7806000637346338], 
             UndirectedEdge[148, 326] -> 
             RGBColor[
              0.9557288471560685, 0.9651636596367347, 0.9035585362533067], 
             UndirectedEdge[13, 357] -> 
             RGBColor[
              0.790264911976746, 0.8366488691367702, 0.9795789777300579], 
             UndirectedEdge[162, 231] -> 
             RGBColor[
              0.8961001169274616, 0.7161734039269558, 0.6017498348056967], 
             UndirectedEdge[33, 84] -> 
             RGBColor[
              0.6664971965911439, 0.7391979274710803, 0.9675265190784968], 
             UndirectedEdge[199, 293] -> 
             RGBColor[
              0.9019755572373274, 0.9006870111987053, 0.6760507948978501], 
             UndirectedEdge[96, 167] -> 
             RGBColor[
              0.98999236796893, 0.988802116258447, 0.7190217489816659], 
             UndirectedEdge[131, 307] -> 
             RGBColor[
              0.904713938354979, 0.9243701363353578, 0.8932307633396339], 
             UndirectedEdge[174, 291] -> 
             RGBColor[
              0.8745730494547133, 0.8658321732489377, 0.6537656875383139], 
             UndirectedEdge[207, 250] -> 
             RGBColor[
              0.9774129488516166, 0.9601682248220195, 0.6472611347659087], 
             UndirectedEdge[364, 387] -> 
             RGBColor[
              0.9711508733336713, 0.9780049490851372, 0.9337182257755192], 
             UndirectedEdge[103, 346] -> 
             RGBColor[
              0.9855975313853673, 0.9851113827784457, 0.681916699086375], 
             UndirectedEdge[31, 106] -> 
             RGBColor[
              0.9904429314271037, 0.9900774285539743, 0.7907130216924838], 
             UndirectedEdge[128, 316] -> 
             RGBColor[
              0.9931455029224383, 0.9888965537974866, 0.5880296537910253], 
             UndirectedEdge[185, 289] -> 
             RGBColor[
              0.8991217344889646, 0.9199535403067376, 0.890500313145991], 
             UndirectedEdge[20, 172] -> 
             RGBColor[
              0.9463183516261702, 0.9427320280900762, 0.6901181094178372], 
             UndirectedEdge[70, 234] -> 
             RGBColor[
              0.5749188624105714, 0.6646663929509491, 0.9603680093010821], 
             UndirectedEdge[119, 383] -> 
             RGBColor[
              0.9901702793318852, 0.9895587338168252, 0.7657235772303159], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.8916389750217053, 0.9141414941197679, 0.8912754555380757], 
             UndirectedEdge[20, 54] -> 
             RGBColor[
              0.9441651131244932, 0.9572033016516998, 0.955970731551774], 
             UndirectedEdge[229, 334] -> 
             RGBColor[
              0.9615189928499752, 0.9697514224237614, 0.9028453497117215], 
             UndirectedEdge[63, 142] -> 
             RGBColor[
              0.8455060479796619, 0.8790263877087983, 0.9285884452901626], 
             UndirectedEdge[230, 358] -> 
             RGBColor[
              0.9225880166831615, 0.8744742754176393, 0.6331506522319612], 
             UndirectedEdge[119, 296] -> 
             RGBColor[
              0.8677333677562292, 0.8941299973484644, 0.8106790136822712], 
             UndirectedEdge[218, 262] -> 
             RGBColor[
              0.995107214204487, 0.9920521669559919, 0.7167529643790271], 
             UndirectedEdge[100, 170] -> 
             RGBColor[
              0.9652194366469348, 0.9735812933160053, 0.9437586009197143], 
             UndirectedEdge[97, 357] -> 
             RGBColor[
              0.840057401720093, 0.8740016049928443, 0.8932092570506501], 
             UndirectedEdge[375, 399] -> 
             RGBColor[0.8701271600823635, 0.8991501286206258, 0.974565418451],
              UndirectedEdge[199, 252] -> 
             RGBColor[
              0.9102753077739101, 0.9274217444882076, 0.8156284403856768], 
             UndirectedEdge[175, 345] -> 
             RGBColor[
              0.9906611131970602, 0.9880243050931901, 0.6312984678540793], 
             UndirectedEdge[176, 186] -> 
             RGBColor[
              0.9401690279416965, 0.952151324900403, 0.8757877247659781], 
             UndirectedEdge[309, 371] -> 
             RGBColor[
              0.9252429002290681, 0.9428387030670626, 0.9792487384276539], 
             UndirectedEdge[326, 354] -> 
             RGBColor[
              0.8694200599452495, 0.8969187167997864, 0.8951736491907152], 
             UndirectedEdge[38, 289] -> 
             RGBColor[
              0.8932765624127712, 0.8955471686958651, 0.6776857852182214], 
             UndirectedEdge[120, 237] -> 
             RGBColor[
              0.9206980048157032, 0.9378929716350795, 0.9289616258216722], 
             UndirectedEdge[275, 384] -> 
             RGBColor[
              0.9629730727716193, 0.9541028837844362, 0.681689557081895], 
             UndirectedEdge[216, 220] -> 
             RGBColor[
              0.9791998431870401, 0.9831674778015353, 0.8824594939284269], 
             UndirectedEdge[50, 276] -> 
             RGBColor[
              0.9473448657998685, 0.8160882840061148, 0.39863835331459685`], 
             UndirectedEdge[143, 321] -> 
             RGBColor[
              0.988545840412066, 0.9748510060793119, 0.5803227595204665], 
             UndirectedEdge[225, 316] -> 
             RGBColor[
              0.9931486741045488, 0.9888978651627851, 0.587977099096698], 
             UndirectedEdge[40, 332] -> 
             RGBColor[
              0.940592453421058, 0.9552145295491306, 0.9854456597752053], 
             UndirectedEdge[254, 343] -> 
             RGBColor[
              0.8309337043845942, 0.864708427952215, 0.7530758424132175], 
             UndirectedEdge[37, 167] -> 
             RGBColor[
              0.9811917233668241, 0.9851528995231843, 0.9014734414256065], 
             UndirectedEdge[26, 204] -> 
             RGBColor[
              0.9842669986488632, 0.9841208717315675, 0.6843116146586086], 
             UndirectedEdge[141, 189] -> 
             RGBColor[
              0.9818155780392926, 0.9488642952385744, 0.5077944457931391], 
             UndirectedEdge[55, 210] -> 
             RGBColor[
              0.9574767337698664, 0.9423303400064518, 0.6747042851378056], 
             UndirectedEdge[41, 312] -> 
             RGBColor[
              0.9408903185543862, 0.8341144060694332, 0.5929869455515049], 
             UndirectedEdge[102, 247] -> 
             RGBColor[
              0.5616825208854845, 0.6317382815219605, 0.9562185408944408], 
             UndirectedEdge[30, 400] -> 
             RGBColor[
              0.955640961437652, 0.9277192126368639, 0.6497014848316596], 
             UndirectedEdge[57, 195] -> 
             RGBColor[
              0.8578481816521364, 0.8895100816379513, 0.9709312652247619], 
             UndirectedEdge[301, 324] -> 
             RGBColor[
              0.9136786568625632, 0.6226551487106391, 0.4001761431576143], 
             UndirectedEdge[290, 331] -> 
             RGBColor[
              0.984005341610249, 0.985348138818218, 0.7976167192751806], 
             UndirectedEdge[49, 347] -> 
             RGBColor[
              0.8516271583347867, 0.8794207164336942, 0.6974986580485306], 
             UndirectedEdge[92, 258] -> 
             RGBColor[
              0.9581573956803509, 0.9683144347261579, 0.9557127942008683], 
             UndirectedEdge[234, 313] -> 
             RGBColor[
              0.6728134808055841, 0.7417817960805819, 0.9699555573400325], 
             UndirectedEdge[376, 377] -> 
             RGBColor[
              0.9831388067514023, 0.9612834843319191, 0.5916078804590624], 
             UndirectedEdge[223, 272] -> 
             RGBColor[
              0.7099807290666672, 0.7723463791268748, 0.9725930423289686], 
             UndirectedEdge[213, 302] -> 
             RGBColor[
              0.7921484562510037, 0.8376034464067738, 0.9799038710588979], 
             UndirectedEdge[121, 158] -> 
             RGBColor[
              0.9924746652696066, 0.9902032301518287, 0.7051145902099424], 
             UndirectedEdge[240, 248] -> 
             RGBColor[
              0.9636832203723685, 0.965242157530922, 0.7030097347158264], 
             UndirectedEdge[18, 132] -> 
             RGBColor[
              0.9941386982281992, 0.9898715931156589, 0.6034116577801387], 
             UndirectedEdge[59, 79] -> 
             RGBColor[
              0.9892624729456784, 0.9894829135304464, 0.8056989238268553], 
             UndirectedEdge[109, 207] -> 
             RGBColor[
              0.9803910411706116, 0.9702140295033188, 0.6588304610596594], 
             UndirectedEdge[190, 365] -> 
             RGBColor[
              0.9633616329101327, 0.9575135247057505, 0.6876568072636409], 
             UndirectedEdge[78, 391] -> 
             RGBColor[
              0.9639362126003477, 0.9726242669231471, 0.9459307645121535], 
             UndirectedEdge[159, 236] -> 
             RGBColor[
              0.9875239013615794, 0.9683834419848889, 0.5075528584567843], 
             UndirectedEdge[95, 334] -> 
             RGBColor[
              0.9927286792184487, 0.9912481435858431, 0.7692237043708672], 
             UndirectedEdge[20, 147] -> 
             RGBColor[
              0.8507307970684946, 0.8840401210833906, 0.9855645615108557], 
             UndirectedEdge[229, 388] -> 
             RGBColor[
              0.9403141879200723, 0.9549334689774014, 0.983367338044556], 
             UndirectedEdge[15, 271] -> 
             RGBColor[
              0.9765235036948181, 0.9785814906851273, 0.7161215004289093], 
             UndirectedEdge[53, 151] -> 
             RGBColor[
              0.9940629165782527, 0.9897095038291237, 0.5951632928536046], 
             UndirectedEdge[178, 309] -> 
             RGBColor[
              0.8852370663105058, 0.9113280238286977, 0.9889158957167961], 
             UndirectedEdge[309, 386] -> 
             RGBColor[
              0.9470425325269564, 0.9566252925309975, 0.8099233890597459], 
             UndirectedEdge[199, 299] -> 
             RGBColor[
              0.7818360171239789, 0.8295441499011827, 0.978876856942406], 
             UndirectedEdge[33, 90] -> 
             RGBColor[
              0.8155991225905028, 0.8567437260779163, 0.9820234945333794], 
             UndirectedEdge[191, 216] -> 
             RGBColor[
              0.9921318113579483, 0.9907824672903862, 0.7632068216226839], 
             UndirectedEdge[188, 203] -> 
             RGBColor[
              0.8599276416672991, 0.7972646728586086, 0.6209555530230266], 
             UndirectedEdge[87, 263] -> 
             RGBColor[
              0.971964656978374, 0.9330367982723142, 0.607514462516024], 
             UndirectedEdge[25, 76] -> 
             RGBColor[
              0.9907180953692641, 0.9897631915069405, 0.7550399870262636], 
             UndirectedEdge[329, 334] -> 
             RGBColor[
              0.9920560657590054, 0.9898094914077461, 0.6960138801995626], 
             UndirectedEdge[42, 376] -> 
             RGBColor[
              0.9902395407532376, 0.9902318135161721, 0.8114195991850714], 
             UndirectedEdge[54, 130] -> 
             RGBColor[
              0.9805584244542864, 0.9850210853074408, 0.9177936956106126], 
             UndirectedEdge[90, 256] -> 
             RGBColor[
              0.9073774981159439, 0.9289822031643428, 0.9910276698673955], 
             UndirectedEdge[160, 302] -> 
             RGBColor[
              0.9097741004074749, 0.927922038871718, 0.8731840886412091], 
             UndirectedEdge[299, 367] -> 
             RGBColor[
              0.8431203084995422, 0.8144001692007933, 0.6259824227152027], 
             UndirectedEdge[16, 96] -> 
             RGBColor[
              0.8212295807797432, 0.8572633980515344, 0.7629939415904086], 
             UndirectedEdge[5, 223] -> 
             RGBColor[
              0.762948924698372, 0.8135296370648943, 0.9411667213362982], 
             UndirectedEdge[40, 228] -> 
             RGBColor[
              0.8218898998433866, 0.8616219728002875, 0.9776116767773655], 
             UndirectedEdge[154, 222] -> 
             RGBColor[
              0.6414892215520767, 0.7183385598078205, 0.9659384642670882], 
             UndirectedEdge[85, 188] -> 
             RGBColor[
              0.9406370537411219, 0.8609671604473307, 0.614395942383872], 
             UndirectedEdge[281, 384] -> 
             RGBColor[
              0.9694239100139663, 0.9744892950777571, 0.8235659601266789], 
             UndirectedEdge[249, 334] -> 
             RGBColor[
              0.7474423820837782, 0.7994920659220379, 0.8831921028842653], 
             UndirectedEdge[203, 243] -> 
             RGBColor[
              0.8745145703919944, 0.90242421236506, 0.9672379082555306], 
             UndirectedEdge[49, 147] -> 
             RGBColor[
              0.7516470350170572, 0.805911643575155, 0.9758808099757466], 
             UndirectedEdge[99, 232] -> 
             RGBColor[
              0.9087923089280819, 0.9156547960118246, 0.690724232721708], 
             UndirectedEdge[84, 389] -> 
             RGBColor[
              0.6474511902445041, 0.7243190425580759, 0.9656281911609126], 
             UndirectedEdge[76, 242] -> 
             RGBColor[
              0.9387497196167314, 0.7761157108816721, 0.4339179969248608], 
             UndirectedEdge[129, 397] -> 
             RGBColor[
              0.8806006196132242, 0.9040014697206286, 0.7975025622577031], 
             UndirectedEdge[177, 390] -> 
             RGBColor[
              0.9554880220150475, 0.9332734657330478, 0.6619931315103461], 
             UndirectedEdge[138, 144] -> 
             RGBColor[
              0.9395303578951484, 0.7796317330783786, 0.4800860751361488], 
             UndirectedEdge[184, 325] -> 
             RGBColor[
              0.9837510968677396, 0.966506861186192, 0.6158143417745836], 
             UndirectedEdge[69, 140] -> 
             RGBColor[
              0.9886262746993324, 0.9895646865438358, 0.8381555926969959], 
             UndirectedEdge[247, 391] -> 
             RGBColor[
              0.9634675229220713, 0.9722747189284975, 0.9467241338836299], 
             UndirectedEdge[14, 391] -> 
             RGBColor[
              0.9202664891619037, 0.9380527430936022, 0.9504168086259009], 
             UndirectedEdge[229, 240] -> 
             RGBColor[
              0.9351553497927079, 0.9510860159488352, 0.9920999053537105], 
             UndirectedEdge[166, 400] -> 
             RGBColor[
              0.9082451834220774, 0.9294245436175577, 0.9824591291467578], 
             UndirectedEdge[281, 386] -> 
             RGBColor[
              0.9945538943509807, 0.9907596556395212, 0.6486031934514543], 
             UndirectedEdge[150, 255] -> 
             RGBColor[
              0.6933299682038552, 0.758654171094498, 0.9714829304063377], 
             UndirectedEdge[103, 290] -> 
             RGBColor[
              0.9829830115308642, 0.9831614781518405, 0.6863423992240596], 
             UndirectedEdge[212, 299] -> 
             RGBColor[
              0.8545871257423708, 0.855266389552074, 0.6591443606730514], 
             UndirectedEdge[206, 208] -> 
             RGBColor[
              0.9780741645779601, 0.9518728045290243, 0.6249719762172272], 
             UndirectedEdge[75, 169] -> 
             RGBColor[
              0.9924356192685457, 0.9858728770847793, 0.44831389284232837`], 
             UndirectedEdge[110, 167] -> 
             RGBColor[
              0.9728943727569177, 0.9789647490239808, 0.9155186917125506], 
             UndirectedEdge[33, 214] -> 
             RGBColor[
              0.8472667779448597, 0.8793928328222024, 0.8830093035571052], 
             UndirectedEdge[98, 107] -> 
             RGBColor[
              0.9779720606577651, 0.9817632010961868, 0.8626573701598248], 
             UndirectedEdge[238, 252] -> 
             RGBColor[
              0.9941950492465272, 0.9899921222459008, 0.60954511836698], 
             UndirectedEdge[91, 241] -> 
             RGBColor[
              0.9886720330888448, 0.9872051240324887, 0.6645065227217064], 
             UndirectedEdge[74, 219] -> 
             RGBColor[
              0.5918661789073609, 0.654101060619035, 0.8372274820200116], 
             UndirectedEdge[45, 180] -> 
             RGBColor[
              0.9731480311918788, 0.9776592037921921, 0.8481525518927477], 
             UndirectedEdge[187, 235] -> 
             RGBColor[
              0.8915796052166729, 0.9154520989558981, 0.9535782874992949], 
             UndirectedEdge[114, 188] -> 
             RGBColor[
              0.9556872291551577, 0.8721915566287181, 0.588919921122318], 
             UndirectedEdge[81, 378] -> 
             RGBColor[
              0.9733860293766097, 0.9794140449058415, 0.9183863009771591], 
             UndirectedEdge[19, 313] -> 
             RGBColor[
              0.9470754716469635, 0.9571091738402974, 0.8470224114442144], 
             UndirectedEdge[195, 284] -> 
             RGBColor[
              0.9306773569171845, 0.8198088782745905, 0.6050853765528725], 
             UndirectedEdge[64, 253] -> 
             RGBColor[
              0.9912881091708096, 0.9904764787881271, 0.7803078206689775], 
             UndirectedEdge[55, 122] -> 
             RGBColor[
              0.972161169845793, 0.9177552304010062, 0.3463518310832012], 
             UndirectedEdge[99, 275] -> 
             RGBColor[
              0.9070309346322696, 0.9097132669216978, 0.6838816261901028], 
             UndirectedEdge[118, 367] -> 
             RGBColor[
              0.9700504397161045, 0.9122866679763559, 0.5337556763927651], 
             UndirectedEdge[7, 96] -> 
             RGBColor[
              0.9941780664865234, 0.9899557978394731, 0.6076966497460083], 
             UndirectedEdge[110, 115] -> 
             RGBColor[
              0.9512107490657956, 0.9631336370551125, 0.9674716549437052], 
             UndirectedEdge[68, 95] -> 
             RGBColor[
              0.76180775749609, 0.8101304940686473, 0.8411132094081567], 
             UndirectedEdge[289, 302] -> 
             RGBColor[
              0.816840036203214, 0.8568926963283985, 0.9823648969926005], 
             UndirectedEdge[260, 321] -> 
             RGBColor[
              0.9826489452717861, 0.9718979706849962, 0.6550084183720754], 
             UndirectedEdge[191, 220] -> 
             RGBColor[
              0.9820812798258771, 0.9841271771512683, 0.8178536753009265], 
             UndirectedEdge[169, 209] -> 
             RGBColor[
              0.9836158991892413, 0.9827653849108215, 0.6749102107074763], 
             UndirectedEdge[32, 252] -> 
             RGBColor[
              0.9784024827946753, 0.9375463703630651, 0.477932835246133], 
             UndirectedEdge[75, 280] -> 
             RGBColor[
              0.9373753910181013, 0.7717538546401748, 0.3482903984587997], 
             UndirectedEdge[14, 224] -> 
             RGBColor[
              0.909577117861919, 0.9300806274803126, 0.9685111260022345], 
             UndirectedEdge[128, 311] -> 
             RGBColor[
              0.9795804882854049, 0.943138574209871, 0.5353321334642179], 
             UndirectedEdge[132, 198] -> 
             RGBColor[
              0.9708884544033632, 0.9750850145973732, 0.7816889171532455], 
             UndirectedEdge[245, 388] -> 
             RGBColor[
              0.9166127063110663, 0.9360345509019594, 0.9811066695701265], 
             UndirectedEdge[183, 273] -> 
             RGBColor[
              0.9943192522261246, 0.9919188790540133, 0.7438082221244856], 
             UndirectedEdge[69, 220] -> 
             RGBColor[
              0.9779674736173614, 0.9826578613140198, 0.9028830469682152], 
             UndirectedEdge[37, 263] -> 
             RGBColor[
              0.9684146003843744, 0.9303891718771935, 0.6135237823266162], 
             UndirectedEdge[235, 384] -> 
             RGBColor[
              0.959994469684968, 0.9696845215108687, 0.9526031070966884], 
             UndirectedEdge[132, 216] -> 
             RGBColor[
              0.9916332316291601, 0.9897160556646516, 0.7089394950215115], 
             UndirectedEdge[225, 380] -> 
             RGBColor[
              0.9933262561985413, 0.9893358915042064, 0.602357229453248], 
             UndirectedEdge[3, 371] -> 
             RGBColor[
              0.8840492931893972, 0.5484695383145555, 0.5662097504537797], 
             UndirectedEdge[269, 314] -> 
             RGBColor[
              0.7288383528092148, 0.7857477406802427, 0.9360836495140492], 
             UndirectedEdge[16, 206] -> 
             RGBColor[
              0.8166312932539527, 0.8566893729483838, 0.9356936087814558], 
             UndirectedEdge[84, 256] -> 
             RGBColor[
              0.758275572116585, 0.8114364045575069, 0.976530694412513], 
             UndirectedEdge[58, 348] -> 
             RGBColor[
              0.7555906521391371, 0.803995178613188, 0.7514523635531131], 
             UndirectedEdge[177, 360] -> 
             RGBColor[
              0.967418922707311, 0.9725440608935989, 0.7912608169893736], 
             UndirectedEdge[2, 106] -> 
             RGBColor[
              0.9641225976511052, 0.9706648373997837, 0.8456286149577137], 
             UndirectedEdge[256, 317] -> 
             RGBColor[
              0.9141213172699965, 0.8589695673860159, 0.6303829254671632], 
             UndirectedEdge[87, 351] -> 
             RGBColor[
              0.8562465057635368, 0.8877190949050981, 0.9434498035974859], 
             UndirectedEdge[48, 103] -> 
             RGBColor[
              0.9911386816334344, 0.9883428393554785, 0.6321827940674523], 
             UndirectedEdge[256, 381] -> 
             RGBColor[
              0.9363728405545177, 0.9505262398426432, 0.9363006196297858], 
             UndirectedEdge[91, 226] -> 
             RGBColor[
              0.949516501021098, 0.8427919713108498, 0.5755412242413787], 
             UndirectedEdge[105, 113] -> 
             RGBColor[
              0.8961536912267762, 0.9157861032062535, 0.7697745127993771], 
             UndirectedEdge[223, 291] -> 
             RGBColor[
              0.7585039770272017, 0.7737340866167339, 0.6431706345342241], 
             UndirectedEdge[203, 348] -> 
             RGBColor[
              0.8919629083505132, 0.9124420739657697, 0.7637375316996093], 
             UndirectedEdge[259, 367] -> 
             RGBColor[
              0.9716383429036632, 0.9124461887158152, 0.4713047778519087], 
             UndirectedEdge[188, 206] -> 
             RGBColor[
              0.9570516722615112, 0.8731502366686903, 0.5839717439740642], 
             UndirectedEdge[250, 289] -> 
             RGBColor[
              0.8927679100441943, 0.8938313648193992, 0.6757097668172396], 
             UndirectedEdge[194, 377] -> 
             RGBColor[
              0.9802736059571807, 0.9600670148598415, 0.637674978643615], 
             UndirectedEdge[83, 231] -> 
             RGBColor[
              0.6928229663554923, 0.7580219516982503, 0.9716969382537769], 
             UndirectedEdge[276, 376] -> 
             RGBColor[
              0.9453491971468737, 0.8166076751081655, 0.5294537077230254], 
             UndirectedEdge[83, 120] -> 
             RGBColor[
              0.7235434362389197, 0.7808069785022256, 0.9112905182296422], 
             UndirectedEdge[40, 243] -> 
             RGBColor[
              0.9500166437261846, 0.9622430752479985, 0.9694929638111154], 
             UndirectedEdge[4, 392] -> 
             RGBColor[
              0.9777673498244412, 0.9805770789025763, 0.7987516561261001], 
             UndirectedEdge[81, 329] -> 
             RGBColor[
              0.9774747762976577, 0.9799313449528235, 0.7653239845336377], 
             UndirectedEdge[131, 363] -> 
             RGBColor[
              0.8625452782964664, 0.8914276586039612, 0.8890277853935344], 
             UndirectedEdge[167, 192] -> 
             RGBColor[
              0.9726077768505519, 0.978751006266271, 0.916003823825844], 
             UndirectedEdge[41, 327] -> 
             RGBColor[
              0.8676256674691545, 0.7765545707663123, 0.6157951388041281], 
             UndirectedEdge[24, 382] -> 
             RGBColor[
              0.9905243997615392, 0.9903496100366473, 0.8066987482260344], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.9318894429724827, 0.9433923315383725, 0.7152311329468097], 
             UndirectedEdge[90, 261] -> 
             RGBColor[
              0.9456494883491723, 0.9587848818729776, 0.9699105189445246], 
             UndirectedEdge[146, 297] -> 
             RGBColor[
              0.9718358568990431, 0.9646127770481155, 0.6749662293155342], 
             UndirectedEdge[5, 291] -> 
             RGBColor[
              0.9720549759112496, 0.9421987115542276, 0.6266675921580537], 
             UndirectedEdge[229, 315] -> 
             RGBColor[
              0.939973062369224, 0.9546790581001205, 0.9839447746223495], 
             UndirectedEdge[241, 360] -> 
             RGBColor[
              0.9933039737662176, 0.9880862018950693, 0.5125570514156903], 
             UndirectedEdge[59, 237] -> 
             RGBColor[
              0.9249098779595606, 0.939402858391629, 0.8423083194004335], 
             UndirectedEdge[257, 381] -> 
             RGBColor[
              0.9898116751647565, 0.9887203410113949, 0.7215035356585446], 
             UndirectedEdge[270, 308] -> 
             RGBColor[
              0.9434421458533405, 0.7967765149565533, 0.4669017243089552], 
             UndirectedEdge[317, 382] -> 
             RGBColor[
              0.9672190961761185, 0.8983571723446797, 0.5182449207453156], 
             UndirectedEdge[23, 89] -> 
             RGBColor[
              0.9944533122069118, 0.9918404330467863, 0.7318546020504737], 
             UndirectedEdge[57, 327] -> 
             RGBColor[
              0.7927185204195979, 0.8380173084471458, 0.9799690426019351], 
             UndirectedEdge[347, 362] -> 
             RGBColor[
              0.9915836621989202, 0.987536608499934, 0.6089776743537499], 
             UndirectedEdge[43, 293] -> 
             RGBColor[
              0.9783886282902018, 0.9605045291068215, 0.6447787895858642], 
             UndirectedEdge[73, 208] -> 
             RGBColor[
              0.9798198678855878, 0.952594697709257, 0.5960411546744961], 
             UndirectedEdge[53, 129] -> 
             RGBColor[
              0.9943274435599094, 0.9902753002951068, 0.6239554223356361], 
             UndirectedEdge[324, 383] -> 
             RGBColor[
              0.9094310030119832, 0.6217450340796149, 0.5320950610743154], 
             UndirectedEdge[368, 399] -> 
             RGBColor[
              0.8885957609767691, 0.9124568617339941, 0.92238434262615], 
             UndirectedEdge[51, 136] -> 
             RGBColor[
              0.9928204637259155, 0.9890965395950875, 0.6085447547225389], 
             UndirectedEdge[145, 359] -> 
             RGBColor[
              0.7648232895317892, 0.8111395575307749, 0.723403746842844], 
             UndirectedEdge[222, 297] -> 
             RGBColor[
              0.7640641375527888, 0.8002580222715223, 0.6763139486618501], 
             UndirectedEdge[81, 209] -> 
             RGBColor[
              0.9681667353821019, 0.9757793838869342, 0.9387695929396982], 
             UndirectedEdge[31, 345] -> 
             RGBColor[
              0.9892006800420194, 0.9874203784521606, 0.6555016247129559], 
             UndirectedEdge[155, 180] -> 
             RGBColor[
              0.9203238170150998, 0.7772777286664476, 0.5986572540628727], 
             UndirectedEdge[4, 369] -> 
             RGBColor[
              0.9690895484509595, 0.9764676163627204, 0.9372075111223174], 
             UndirectedEdge[102, 289] -> 
             RGBColor[
              0.49310807668197604`, 0.5773868446617556, 0.9574638481637028], 
             UndirectedEdge[70, 103] -> 
             RGBColor[
              0.8479809907536737, 0.8774273861515574, 0.7068372351608061], 
             UndirectedEdge[177, 375] -> 
             RGBColor[
              0.9454106454690949, 0.9588079292894911, 0.9772897174236252], 
             UndirectedEdge[171, 253] -> 
             RGBColor[
              0.975175400863258, 0.980454656945347, 0.9021959961030479], 
             UndirectedEdge[150, 241] -> 
             RGBColor[
              0.9435928728442584, 0.95263108789457, 0.7087890035465327], 
             UndirectedEdge[24, 317] -> 
             RGBColor[
              0.9646905643745334, 0.897311559464421, 0.5601492363281207], 
             UndirectedEdge[80, 110] -> 
             RGBColor[
              0.9751885215757324, 0.979913438517496, 0.8774987087179642], 
             UndirectedEdge[176, 341] -> 
             RGBColor[
              0.8837288155305832, 0.9101253855971642, 0.9887720374109756], 
             UndirectedEdge[154, 192] -> 
             RGBColor[
              0.8493100875290039, 0.8827299680610995, 0.964507552494537], 
             UndirectedEdge[121, 322] -> 
             RGBColor[
              0.9593309400149816, 0.8641337028619867, 0.43286405845820153`], 
             UndirectedEdge[268, 381] -> 
             RGBColor[
              0.9851949344138342, 0.9881457391543592, 0.895021781251705], 
             UndirectedEdge[76, 104] -> 
             RGBColor[
              0.9061585329734057, 0.9241306550909136, 0.8131173567991341], 
             UndirectedEdge[91, 186] -> 
             RGBColor[
              0.989005933668029, 0.9897216852841823, 0.8318636610597796], 
             UndirectedEdge[216, 357] -> 
             RGBColor[
              0.8397210137638156, 0.8738624999281475, 0.8987840760302914], 
             UndirectedEdge[210, 236] -> 
             RGBColor[
              0.9597887544221988, 0.9501293285550335, 0.6836860487836519], 
             UndirectedEdge[26, 173] -> 
             RGBColor[
              0.9889233501712452, 0.987428969821714, 0.6690584457747257], 
             UndirectedEdge[10, 374] -> 
             RGBColor[
              0.7002858995750334, 0.5723641119993337, 0.5859653608410247], 
             UndirectedEdge[289, 340] -> 
             RGBColor[
              0.8960814387173787, 0.9186962998731494, 0.9408858821144104], 
             UndirectedEdge[65, 168] -> 
             RGBColor[
              0.8115763496821624, 0.8109312473694157, 0.6391814112199086], 
             UndirectedEdge[40, 203] -> 
             RGBColor[
              0.8658006569967613, 0.8959253900226188, 0.981988290681058], 
             UndirectedEdge[167, 201] -> 
             RGBColor[
              0.9679339856107634, 0.9752653004122674, 0.9239153332748218], 
             UndirectedEdge[41, 57] -> 
             RGBColor[
              0.8378475989910216, 0.7532714090288163, 0.6128325284339828], 
             UndirectedEdge[214, 363] -> 
             RGBColor[
              0.8628149276476808, 0.8915391655403606, 0.8845589978137625], 
             UndirectedEdge[22, 189] -> 
             RGBColor[
              0.9947964793067428, 0.9912785203307948, 0.6750070688253416], 
             UndirectedEdge[41, 96] -> 
             RGBColor[
              0.9532489829715775, 0.8404171881570638, 0.4045124536408148], 
             UndirectedEdge[31, 197] -> 
             RGBColor[
              0.9618157150798274, 0.9707623127535203, 0.9369592719673325], 
             UndirectedEdge[275, 281] -> 
             RGBColor[
              0.9882781004850434, 0.9707476444287408, 0.5257791816863812], 
             UndirectedEdge[89, 353] -> 
             RGBColor[
              0.9589260180842253, 0.9669949644915765, 0.8726840368739213], 
             UndirectedEdge[324, 375] -> 
             RGBColor[
              0.891561447105513, 0.6086860214635119, 0.574348411170341], 
             UndirectedEdge[5, 174] -> 
             RGBColor[
              0.8790179971258836, 0.9056277236970982, 0.9517617743403879], 
             UndirectedEdge[36, 314] -> 
             RGBColor[
              0.9860051797921741, 0.9855143012130367, 0.6890735455969602], 
             UndirectedEdge[220, 357] -> 
             RGBColor[
              0.8296704822317444, 0.8672072097890295, 0.9534309297085339], 
             UndirectedEdge[291, 342] -> 
             RGBColor[
              0.9732539751584836, 0.9214415193236005, 0.3505971733640365], 
             UndirectedEdge[21, 159] -> 
             RGBColor[
              0.9170295647569386, 0.9327330821097394, 0.8102477590053512], 
             UndirectedEdge[220, 394] -> 
             RGBColor[
              0.9821491060063998, 0.9842722504931278, 0.8252361364761669], 
             UndirectedEdge[129, 249] -> 
             RGBColor[
              0.749481702990639, 0.799461528577591, 0.7858756841928629], 
             UndirectedEdge[37, 58] -> 
             RGBColor[
              0.7468480009690921, 0.8004700039650682, 0.9402162831829077], 
             UndirectedEdge[118, 259] -> 
             RGBColor[
              0.9931178527395907, 0.9909249514559264, 0.7275832873772701], 
             UndirectedEdge[201, 243] -> 
             RGBColor[
              0.9541785061538306, 0.9653469854321126, 0.9624480163086768], 
             UndirectedEdge[40, 110] -> 
             RGBColor[
              0.9504249799047517, 0.9625476117013847, 0.968801757171933], 
             UndirectedEdge[35, 278] -> 
             RGBColor[
              0.9266371464255199, 0.9443393239371721, 0.9928646723164538], 
             UndirectedEdge[164, 315] -> 
             RGBColor[
              0.968739705265945, 0.9751785106569136, 0.891755110764069], 
             UndirectedEdge[81, 304] -> 
             RGBColor[
              0.8451394039214662, 0.8794354365374921, 0.9622512298199963], 
             UndirectedEdge[12, 299] -> 
             RGBColor[
              0.8656244003443385, 0.8933026229321281, 0.8652809568203681], 
             UndirectedEdge[203, 258] -> 
             RGBColor[
              0.8675172402907307, 0.897205615032614, 0.9790825629209943], 
             UndirectedEdge[250, 276] -> 
             RGBColor[
              0.9396065386044651, 0.790738232427701, 0.30453456074548635`], 
             UndirectedEdge[124, 238] -> 
             RGBColor[
              0.878837534377163, 0.9023341103238334, 0.7740974040773709], 
             UndirectedEdge[96, 154] -> 
             RGBColor[
              0.866694678647382, 0.8927810780532757, 0.7675254776503588], 
             UndirectedEdge[126, 238] -> 
             RGBColor[
              0.9384194636376599, 0.949389277707779, 0.779900818373954], 
             UndirectedEdge[103, 108] -> 
             RGBColor[
              0.8751085795929139, 0.8986196647300831, 0.7095410596945706], 
             UndirectedEdge[122, 210] -> 
             RGBColor[
              0.9536516061205778, 0.929427286262718, 0.6598443865350636], 
             UndirectedEdge[108, 234] -> 
             RGBColor[
              0.6020464512498116, 0.685858671529475, 0.9630718338348466], 
             UndirectedEdge[222, 361] -> 
             RGBColor[
              0.7676742023826444, 0.8155535672519788, 0.8695848432230366], 
             UndirectedEdge[12, 274] -> 
             RGBColor[
              0.993467929016144, 0.9915668350286777, 0.7579168508677087], 
             UndirectedEdge[141, 219] -> 
             RGBColor[
              0.9816466642766106, 0.9491545065384079, 0.5367664526848078], 
             UndirectedEdge[179, 344] -> 
             RGBColor[
              0.9033458011446388, 0.9251651633273779, 0.9697619015531082], 
             UndirectedEdge[14, 230] -> 
             RGBColor[
              0.8781496287222089, 0.905676693479158, 0.988239889592594], 
             UndirectedEdge[12, 118] -> 
             RGBColor[
              0.9925545315609008, 0.9911891217076908, 0.7730542104979307], 
             UndirectedEdge[44, 49] -> 
             RGBColor[
              0.8293528130209578, 0.8017452431393047, 0.624189543511178], 
             UndirectedEdge[224, 247] -> 
             RGBColor[
              0.9527781516220866, 0.964302603315208, 0.9648184512599633], 
             UndirectedEdge[161, 222] -> 
             RGBColor[
              0.7675507884345993, 0.8155025324128684, 0.871630131727201], 
             UndirectedEdge[148, 168] -> 
             RGBColor[
              0.7906750942323993, 0.8372205223551947, 0.979553195935273], 
             UndirectedEdge[219, 323] -> 
             RGBColor[
              0.9774288105869198, 0.9349266956439382, 0.5203808875751932], 
             UndirectedEdge[309, 334] -> 
             RGBColor[
              0.9449483166021301, 0.956538414982754, 0.9012648238183847], 
             UndirectedEdge[170, 326] -> 
             RGBColor[
              0.9771380730758259, 0.981498864110409, 0.880085372837619], 
             UndirectedEdge[239, 354] -> 
             RGBColor[
              0.7754868012304426, 0.8245354501299854, 0.978256935076615], 
             UndirectedEdge[11, 221] -> 
             RGBColor[
              0.9634824500248467, 0.9541703949105482, 0.6801641872520443], 
             UndirectedEdge[47, 322] -> 
             RGBColor[
              0.9591940321793299, 0.863840870845033, 0.417962485444731], 
             UndirectedEdge[155, 271] -> 
             RGBColor[
              0.9248173670646365, 0.7806290109358791, 0.59105084593456], 
             UndirectedEdge[106, 363] -> 
             RGBColor[
              0.8647012345898583, 0.8920807097040849, 0.8359621425075621], 
             UndirectedEdge[245, 378] -> 
             RGBColor[
              0.9355944109540082, 0.9499331952485897, 0.9374272061913551], 
             UndirectedEdge[155, 326] -> 
             RGBColor[
              0.9398143160329313, 0.790842382181896, 0.5221668376757487], 
             UndirectedEdge[10, 39] -> 
             RGBColor[
              0.7608173492863104, 0.8087371655495768, 0.792738730188961], 
             UndirectedEdge[25, 382] -> 
             RGBColor[
              0.9899898640369436, 0.9901285657775856, 0.8155573885166933], 
             UndirectedEdge[177, 383] -> 
             RGBColor[
              0.9632802013755651, 0.9718669419055941, 0.9350363673275998], 
             UndirectedEdge[177, 296] -> 
             RGBColor[
              0.8408432897999092, 0.8764382054372333, 0.9799918037795552], 
             UndirectedEdge[103, 143] -> 
             RGBColor[
              0.9927750941345276, 0.9890195379785636, 0.6050632040245387], 
             UndirectedEdge[84, 317] -> 
             RGBColor[
              0.7855395156357012, 0.7577859589439442, 0.6178431777927517], 
             UndirectedEdge[50, 328] -> 
             RGBColor[
              0.9846466511979668, 0.9851419280142568, 0.7422191255772269], 
             UndirectedEdge[332, 385] -> 
             RGBColor[
              0.8277792277258036, 0.8662479108664678, 0.9794717772448124], 
             UndirectedEdge[242, 257] -> 
             RGBColor[
              0.9383625439885277, 0.7752875813624052, 0.39177631916589706`], 
             UndirectedEdge[214, 217] -> 
             RGBColor[
              0.9930492928520201, 0.9910345408224975, 0.7387463306388777], 
             UndirectedEdge[51, 59] -> 
             RGBColor[
              0.9939626635031691, 0.9915395894245209, 0.7328661516366608], 
             UndirectedEdge[66, 131] -> 
             RGBColor[
              0.8921587280405245, 0.9145619106145734, 0.8919793773106002], 
             UndirectedEdge[66, 98] -> 
             RGBColor[
              0.8929075727350637, 0.9148715771401962, 0.8795690827741387], 
             UndirectedEdge[70, 346] -> 
             RGBColor[
              0.8409171633316914, 0.8758270554536138, 0.9461415553444612], 
             UndirectedEdge[151, 253] -> 
             RGBColor[
              0.9906266221357616, 0.989061624906758, 0.7083090391287858], 
             UndirectedEdge[384, 398] -> 
             RGBColor[
              0.9680225250585222, 0.971135872015938, 0.7013057257074602], 
             UndirectedEdge[123, 218] -> 
             RGBColor[
              0.994119956078943, 0.9918364649754763, 0.7471110750451819], 
             UndirectedEdge[169, 280] -> 
             RGBColor[
              0.9368659395660575, 0.7703081871538191, 0.32311162150919887`], 
             UndirectedEdge[71, 109] -> 
             RGBColor[
              0.9892980343999113, 0.9743953168230888, 0.5121229964426591], 
             UndirectedEdge[166, 302] -> 
             RGBColor[
              0.8487529323795544, 0.8822365657675905, 0.985436006452691], 
             UndirectedEdge[89, 163] -> 
             RGBColor[
              0.9943261321368995, 0.9919217240739244, 0.7436942041983078], 
             UndirectedEdge[102, 340] -> 
             RGBColor[
              0.5819003620354026, 0.6467034552113937, 0.9169230339507075], 
             UndirectedEdge[380, 390] -> 
             RGBColor[
              0.9814925409140092, 0.9490711363643445, 0.3962927030566096], 
             UndirectedEdge[172, 387] -> 
             RGBColor[
              0.9804963392544063, 0.9688976269564555, 0.6556910386544545], 
             UndirectedEdge[61, 298] -> 
             RGBColor[
              0.5859923580084516, 0.6348848073660325, 0.6608435300825515], 
             UndirectedEdge[10, 216] -> 
             RGBColor[
              0.7582531111585806, 0.8084559217414131, 0.8918696492281815], 
             UndirectedEdge[209, 229] -> 
             RGBColor[
              0.9540765985685065, 0.9651974523051243, 0.9600711666283235], 
             UndirectedEdge[39, 119] -> 
             RGBColor[
              0.9944569188586702, 0.9905522348671951, 0.6380480095768171], 
             UndirectedEdge[33, 261] -> 
             RGBColor[
              0.8333509884586674, 0.8701842146217869, 0.9589491158300375], 
             UndirectedEdge[102, 213] -> 
             RGBColor[
              0.46841649672976565`, 0.5580975947401308, 0.9550028222300001], 
             UndirectedEdge[155, 335] -> 
             RGBColor[
              0.9401881301505719, 0.790996963926125, 0.5159717703465174], 
             UndirectedEdge[76, 317] -> 
             RGBColor[
              0.9679473275084389, 0.8979917980740346, 0.45772751925488575`], 
             UndirectedEdge[19, 179] -> 
             RGBColor[
              0.9213490916299261, 0.9365956567386942, 0.8445686063519788], 
             UndirectedEdge[48, 83] -> 
             RGBColor[
              0.7250566773431303, 0.7814327425873391, 0.8862121969904302], 
             UndirectedEdge[288, 355] -> 
             RGBColor[
              0.8956686176417671, 0.9188498041152172, 0.9623111194281034], 
             UndirectedEdge[7, 192] -> 
             RGBColor[
              0.9767934753681453, 0.9799046878472969, 0.8046787245901865], 
             UndirectedEdge[341, 393] -> 
             RGBColor[
              0.9351487287306524, 0.9487638859515977, 0.9020408552558976], 
             UndirectedEdge[244, 270] -> 
             RGBColor[
              0.9947485767867446, 0.9911760616842065, 0.6697931751436232], 
             UndirectedEdge[121, 265] -> 
             RGBColor[
              0.9938505107981357, 0.9892551893429717, 0.5720442345043799], 
             UndirectedEdge[156, 363] -> 
             RGBColor[
              0.8488991381614885, 0.882330547339945, 0.9604988100866948], 
             UndirectedEdge[133, 280] -> 
             RGBColor[
              0.9369848840760095, 0.773608407541792, 0.5013067571623349], 
             UndirectedEdge[44, 362] -> 
             RGBColor[
              0.9693093168850913, 0.9098611352055445, 0.5356685598163973], 
             UndirectedEdge[116, 147] -> 
             RGBColor[
              0.5949033495657143, 0.6782102412541122, 0.9632352301073697], 
             UndirectedEdge[83, 196] -> 
             RGBColor[
              0.724055382285427, 0.7810186813488695, 0.9028062473651178], 
             UndirectedEdge[109, 233] -> 
             RGBColor[
              0.9895302861616633, 0.9748920798572214, 0.5374021674176446], 
             UndirectedEdge[19, 125] -> 
             RGBColor[
              0.9679220510177056, 0.973600567533673, 0.8444653593250064], 
             UndirectedEdge[26, 160] -> 
             RGBColor[
              0.9929106110004031, 0.9890778046425001, 0.6029792151353278], 
             UndirectedEdge[224, 302] -> 
             RGBColor[
              0.89375459025784, 0.9174641734598903, 0.9670019591944203], 
             UndirectedEdge[58, 60] -> 
             RGBColor[
              0.6585825464573929, 0.7312971054633154, 0.9679121553746741], 
             UndirectedEdge[165, 332] -> 
             RGBColor[
              0.8716058189642155, 0.9004855770363454, 0.9838400022766763], 
             UndirectedEdge[43, 252] -> 
             RGBColor[
              0.9866883788267844, 0.9872392623963238, 0.7843564350736909], 
             UndirectedEdge[292, 304] -> 
             RGBColor[
              0.8446319179880821, 0.8790569543593061, 0.9631102711316861], 
             UndirectedEdge[63, 257] -> 
             RGBColor[
              0.9897396307611771, 0.9886905487990582, 0.7226974978707945], 
             UndirectedEdge[94, 355] -> 
             RGBColor[
              0.9002848090681497, 0.9222925521226937, 0.9544971114387845], 
             UndirectedEdge[223, 290] -> 
             RGBColor[
              0.7613512950343515, 0.8123381274773464, 0.9438710916289339], 
             UndirectedEdge[141, 150] -> 
             RGBColor[
              0.9317136705561944, 0.912573285520403, 0.66148951552251], 
             UndirectedEdge[131, 306] -> 
             RGBColor[
              0.9444784588405384, 0.9560671842645332, 0.8970262193833132], 
             UndirectedEdge[151, 182] -> 
             RGBColor[
              0.7918499436159034, 0.8335069334392002, 0.7604397623458217], 
             UndirectedEdge[87, 201] -> 
             RGBColor[
              0.9664342495363039, 0.9744872987798232, 0.941702239571958], 
             UndirectedEdge[72, 379] -> 
             RGBColor[
              0.9768916003941103, 0.9324360100504216, 0.4732367270849388], 
             UndirectedEdge[23, 378] -> 
             RGBColor[
              0.9904355125818789, 0.9901789696490946, 0.7984399395693915], 
             UndirectedEdge[116, 322] -> 
             RGBColor[
              0.6611625948998685, 0.6286621531136133, 0.6023338147720689], 
             UndirectedEdge[90, 175] -> 
             RGBColor[
              0.95834940228561, 0.9674907042869934, 0.9141209111160818], 
             UndirectedEdge[348, 369] -> 
             RGBColor[
              0.9854035645533847, 0.9856395025804372, 0.7356272455902405], 
             UndirectedEdge[134, 243] -> 
             RGBColor[
              0.9712225205982795, 0.9627345848671107, 0.6729884282947425], 
             UndirectedEdge[211, 372] -> 
             RGBColor[
              0.9892026568748093, 0.9878363938080457, 0.6856493666455115], 
             UndirectedEdge[73, 188] -> 
             RGBColor[
              0.9587973755691388, 0.8738721298489229, 0.5550409224313331], 
             UndirectedEdge[55, 228] -> 
             RGBColor[
              0.8392316834254517, 0.8490789884198788, 0.6660958685020157], 
             UndirectedEdge[260, 384] -> 
             RGBColor[
              0.9626069607408441, 0.9716329130627794, 0.9481808411858841], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.8724868974944577, 0.9011613853088937, 0.9876997732329112], 
             UndirectedEdge[153, 203] -> 
             RGBColor[
              0.8911059186388626, 0.910245087052279, 0.7014090908923027], 
             UndirectedEdge[65, 148] -> 
             RGBColor[
              0.9423203734705314, 0.9138893347410522, 0.6519951873936553], 
             UndirectedEdge[42, 366] -> 
             RGBColor[
              0.9063366290466996, 0.5799906775158532, 0.48581894455320696`], 
             UndirectedEdge[48, 313] -> 
             RGBColor[
              0.9443529319747713, 0.9561739151602795, 0.9059951983644889], 
             UndirectedEdge[166, 213] -> 
             RGBColor[
              0.8145104695880822, 0.8554343088410784, 0.9820367798537933], 
             UndirectedEdge[11, 78] -> 
             RGBColor[
              0.9453754211275218, 0.9587816590332203, 0.9773493430459291], 
             UndirectedEdge[228, 348] -> 
             RGBColor[
              0.8480521511971384, 0.8781386567434384, 0.7593609177959169], 
             UndirectedEdge[199, 336] -> 
             RGBColor[
              0.8726067204482758, 0.9012569288797607, 0.9877112020532137], 
             UndirectedEdge[249, 309] -> 
             RGBColor[
              0.70220027956099, 0.7658189804442982, 0.9722232550136289], 
             UndirectedEdge[190, 273] -> 
             RGBColor[
              0.9890795544743455, 0.9750717105598901, 0.5714777363007784], 
             UndirectedEdge[298, 314] -> 
             RGBColor[
              0.980993090503262, 0.9687927054977967, 0.6538409889613457], 
             UndirectedEdge[7, 385] -> 
             RGBColor[
              0.8551445960054564, 0.8843484531265167, 0.81366129901121], 
             UndirectedEdge[27, 194] -> 
             RGBColor[
              0.9892749253197902, 0.9891683045357262, 0.7799780865404], 
             UndirectedEdge[39, 128] -> 
             RGBColor[
              0.9941305761896899, 0.991061722108628, 0.6903002150989546], 
             UndirectedEdge[116, 265] -> 
             RGBColor[
              0.6956821656830225, 0.7537836395945984, 0.7415139908182473], 
             UndirectedEdge[231, 313] -> 
             RGBColor[
              0.9121192209871334, 0.9327631242711907, 0.9914799396278355], 
             UndirectedEdge[96, 284] -> 
             RGBColor[
              0.951171011187069, 0.8321787224745365, 0.4028404687667325], 
             UndirectedEdge[279, 300] -> 
             RGBColor[
              0.9321317857877304, 0.9435838375993106, 0.7151138850583323], 
             UndirectedEdge[22, 190] -> 
             RGBColor[
              0.9894655911345704, 0.9747537037359403, 0.5303605129700131], 
             UndirectedEdge[24, 207] -> 
             RGBColor[
              0.9822875494693755, 0.9856787032425702, 0.8865662480167916], 
             UndirectedEdge[315, 329] -> 
             RGBColor[
              0.9705101352782539, 0.9747371270841052, 0.7771133051101905], 
             UndirectedEdge[239, 335] -> 
             RGBColor[
              0.8964791316942025, 0.9179200246210663, 0.8916383189542623], 
             UndirectedEdge[142, 300] -> 
             RGBColor[
              0.8489646181078385, 0.8781958033164756, 0.706935273942949], 
             UndirectedEdge[13, 88] -> 
             RGBColor[
              0.9148446437917355, 0.9348421244089699, 0.9884746815719291], 
             UndirectedEdge[18, 302] -> 
             RGBColor[
              0.9103261134798327, 0.9272697730879769, 0.8000300317126172], 
             UndirectedEdge[148, 251] -> 
             RGBColor[
              0.9544437413156426, 0.9646322353460048, 0.9248560657764713], 
             UndirectedEdge[90, 257] -> 
             RGBColor[
              0.9608163327261827, 0.9671763043330945, 0.7762305858961542], 
             UndirectedEdge[134, 348] -> 
             RGBColor[
              0.9886708585567983, 0.9727524464678203, 0.46948805173882124`], 
             UndirectedEdge[158, 322] -> 
             RGBColor[
              0.9576281371039763, 0.8643824148901891, 0.5303471208282988], 
             UndirectedEdge[40, 385] -> 
             RGBColor[
              0.828489504635697, 0.8667776342228947, 0.9782694637062499], 
             UndirectedEdge[228, 385] -> 
             RGBColor[
              0.7090766741481322, 0.7726553541176249, 0.9716377942469727], 
             UndirectedEdge[175, 214] -> 
             RGBColor[
              0.990017057639967, 0.9901398110312793, 0.8151067201398076], 
             UndirectedEdge[7, 41] -> 
             RGBColor[
              0.9536838295555241, 0.8413472810303919, 0.4518428207413694], 
             UndirectedEdge[176, 379] -> 
             RGBColor[
              0.9231789476178351, 0.8934630946257403, 0.6425734430414383], 
             UndirectedEdge[259, 336] -> 
             RGBColor[
              0.9569584248473255, 0.9647512316589417, 0.8286443788105151], 
             UndirectedEdge[213, 340] -> 
             RGBColor[
              0.8713898587651683, 0.8994070499515245, 0.9384248561807076], 
             UndirectedEdge[55, 165] -> 
             RGBColor[
              0.889657879456174, 0.8884723160123635, 0.671121880462764], 
             UndirectedEdge[108, 231] -> 
             RGBColor[
              0.841352191431361, 0.8768399997200836, 0.9845962161226498], 
             UndirectedEdge[38, 230] -> 
             RGBColor[
              0.9387636273276871, 0.9317147118262024, 0.6820516110104008], 
             UndirectedEdge[39, 316] -> 
             RGBColor[
              0.9933937777073193, 0.9882200872458393, 0.5272802408638144], 
             UndirectedEdge[85, 167] -> 
             RGBColor[
              0.9689794619227502, 0.9760450149339368, 0.9221456145825209], 
             UndirectedEdge[28, 328] -> 
             RGBColor[
              0.7358242571840022, 0.7915393198283718, 0.9398550472553932], 
             UndirectedEdge[79, 120] -> 
             RGBColor[
              0.985050599801821, 0.987973026773897, 0.8923522302480941], 
             UndirectedEdge[130, 347] -> 
             RGBColor[
              0.9871042317160174, 0.985366977597671, 0.6690053736424784], 
             UndirectedEdge[77, 160] -> 
             RGBColor[
              0.9935144710615726, 0.9903694002537242, 0.668705656201315], 
             UndirectedEdge[108, 179] -> 
             RGBColor[
              0.8025964499172134, 0.8459372234332809, 0.9808996588993715], 
             UndirectedEdge[318, 373] -> 
             RGBColor[
              0.6660768381101183, 0.7368102142663642, 0.9690136217626382], 
             UndirectedEdge[48, 331] -> 
             RGBColor[
              0.9921610117128192, 0.9905295000218559, 0.7434571141185734], 
             UndirectedEdge[222, 312] -> 
             RGBColor[
              0.7561790983900801, 0.8082804046330592, 0.9472537611728733], 
             UndirectedEdge[292, 353] -> 
             RGBColor[
              0.9420425433514215, 0.955996181560506, 0.9725959950845411], 
             UndirectedEdge[175, 204] -> 
             RGBColor[
              0.9823356195798032, 0.9855807619165823, 0.8804934016277406], 
             UndirectedEdge[198, 340] -> 
             RGBColor[
              0.9663172721691614, 0.9742867981144421, 0.9368282762075338], 
             UndirectedEdge[14, 207] -> 
             RGBColor[
              0.9173076026147153, 0.9358460103514412, 0.9554254317490838], 
             UndirectedEdge[45, 271] -> 
             RGBColor[
              0.9776415812414153, 0.9810104860616236, 0.8405461437644351], 
             UndirectedEdge[112, 183] -> 
             RGBColor[
              0.9326228895924975, 0.9458483663962405, 0.8626543912437292], 
             UndirectedEdge[85, 139] -> 
             RGBColor[
              0.7506294532062003, 0.8043465366507949, 0.9621475400677086], 
             UndirectedEdge[45, 97] -> 
             RGBColor[
              0.9925808173798587, 0.9911999915693447, 0.7726185864522778], 
             UndirectedEdge[130, 181] -> 
             RGBColor[
              0.8873941916501709, 0.9120688958282114, 0.9474144449441706], 
             UndirectedEdge[63, 90] -> 
             RGBColor[
              0.956820920516002, 0.9668586377950706, 0.9394518096225069], 
             UndirectedEdge[114, 361] -> 
             RGBColor[
              0.9869169288458057, 0.988463380354311, 0.8488197009456082], 
             UndirectedEdge[75, 209] -> 
             RGBColor[
              0.984125350641285, 0.9842110523971774, 0.700088987657077], 
             UndirectedEdge[42, 276] -> 
             RGBColor[
              0.9458567540908577, 0.8168175629481214, 0.5210421756459449], 
             UndirectedEdge[205, 358] -> 
             RGBColor[
              0.9699528636941684, 0.9073273934856944, 0.3774249763514385], 
             UndirectedEdge[76, 358] -> 
             RGBColor[
              0.9707110722001522, 0.9089491248133543, 0.4599512931072639], 
             UndirectedEdge[90, 142] -> 
             RGBColor[
              0.8165827499446676, 0.8575121432428345, 0.9821215333155224], 
             UndirectedEdge[152, 381] -> 
             RGBColor[
              0.9262873446622388, 0.9424843391816331, 0.9353386560281518], 
             UndirectedEdge[86, 309] -> 
             RGBColor[
              0.9234023861213787, 0.941466050659113, 0.9823642487290127], 
             UndirectedEdge[104, 358] -> 
             RGBColor[
              0.8823602109457926, 0.8424153055286522, 0.6293090202440285], 
             UndirectedEdge[16, 369] -> 
             RGBColor[
              0.8129479188626121, 0.8540012377529698, 0.9445671317210496], 
             UndirectedEdge[278, 337] -> 
             RGBColor[
              0.9094471214663274, 0.9306324646455093, 0.9912250723901297], 
             UndirectedEdge[100, 350] -> 
             RGBColor[
              0.7429419494616618, 0.797627168133678, 0.9487135103101301], 
             UndirectedEdge[90, 202] -> 
             RGBColor[
              0.9602862127224778, 0.9660424312485238, 0.7185302950143111], 
             UndirectedEdge[126, 367] -> 
             RGBColor[
              0.9157840135406061, 0.8716749192496962, 0.6330897061654472], 
             UndirectedEdge[278, 327] -> 
             RGBColor[
              0.8714616575868692, 0.9003438868359785, 0.9876019849352831], 
             UndirectedEdge[10, 200] -> 
             RGBColor[
              0.7257882446608639, 0.7847906407549706, 0.9742851901181012], 
             UndirectedEdge[149, 299] -> 
             RGBColor[
              0.8375387007801418, 0.7922709545538833, 0.621491330127001], 
             UndirectedEdge[57, 284] -> 
             RGBColor[
              0.8357696272065132, 0.745032943346289, 0.6111605435599007], 
             UndirectedEdge[125, 313] -> 
             RGBColor[
              0.9199364388607654, 0.9388652587793669, 0.9876801353775848], 
             UndirectedEdge[125, 196] -> 
             RGBColor[
              0.9641982162878102, 0.9722512476151856, 0.9200321966199685], 
             UndirectedEdge[21, 210] -> 
             RGBColor[
              0.8892944178175581, 0.914478968679884, 0.9863809493322188], 
             UndirectedEdge[186, 374] -> 
             RGBColor[
              0.933254342829164, 0.7545460916588848, 0.48924080309055473`], 
             UndirectedEdge[6, 74] -> 
             RGBColor[
              0.5451310257552932, 0.6200697108671613, 0.9622555577458689], 
             UndirectedEdge[7, 312] -> 
             RGBColor[
              0.9818194020693323, 0.9836530157518424, 0.7961711416566986], 
             UndirectedEdge[238, 299] -> 
             RGBColor[
              0.865755758596596, 0.892114527658876, 0.7727935349237093], 
             UndirectedEdge[155, 239] -> 
             RGBColor[
              0.8458810573181244, 0.718459115512095, 0.6052501235616485], 
             UndirectedEdge[108, 331] -> 
             RGBColor[
              0.8761309096722987, 0.9008063253964607, 0.8208153797456916], 
             UndirectedEdge[55, 87] -> 
             RGBColor[
              0.979614170690723, 0.9588404042153004, 0.6372313787990467], 
             UndirectedEdge[186, 288] -> 
             RGBColor[
              0.979880930796511, 0.9830204626978347, 0.8519757345444804], 
             UndirectedEdge[178, 371] -> 
             RGBColor[
              0.9107737524602322, 0.931301397390746, 0.9778686581967017], 
             UndirectedEdge[212, 238] -> 
             RGBColor[
              0.9826731972200593, 0.9523884840456083, 0.45745021703375915`], 
             UndirectedEdge[292, 329] -> 
             RGBColor[
              0.9769672903642735, 0.9795528627746375, 0.7661830258453275], 
             UndirectedEdge[268, 338] -> 
             RGBColor[
              0.9893541702107589, 0.989865690043872, 0.8260924803394591], 
             UndirectedEdge[68, 309] -> 
             RGBColor[
              0.7140273948797713, 0.7754207654655583, 0.9731543288556743], 
             UndirectedEdge[129, 309] -> 
             RGBColor[
              0.9469876375089908, 0.9565078776383069, 0.8039484051269823], 
             UndirectedEdge[137, 330] -> 
             RGBColor[
              0.965710411170828, 0.9231561819590832, 0.6070282426003091], 
             UndirectedEdge[111, 400] -> 
             RGBColor[
              0.9666663937077433, 0.9740348673793968, 0.9132952395993832], 
             UndirectedEdge[62, 370] -> 
             RGBColor[
              0.8448043712803117, 0.8787756387256213, 0.942067711729718], 
             UndirectedEdge[163, 280] -> 
             RGBColor[
              0.9383390788941748, 0.7741684019003228, 0.4788642444814871], 
             UndirectedEdge[316, 383] -> 
             RGBColor[
              0.9891071381805343, 0.9872265861954694, 0.6549558085173133], 
             UndirectedEdge[307, 314] -> 
             RGBColor[
              0.8989706324228004, 0.921166945880086, 0.9513243511167242], 
             UndirectedEdge[126, 259] -> 
             RGBColor[
              0.9388514265640924, 0.9503132027292667, 0.8269173171499522], 
             UndirectedEdge[44, 372] -> 
             RGBColor[
              0.9701899031118507, 0.9082586386626472, 0.3781208853803122], 
             UndirectedEdge[202, 279] -> 
             RGBColor[
              0.9321385078660296, 0.9435982154450864, 0.7158455417973504], 
             UndirectedEdge[148, 312] -> 
             RGBColor[
              0.9452225045444813, 0.9582993752588573, 0.9648411192879269], 
             UndirectedEdge[109, 358] -> 
             RGBColor[
              0.9655578007674828, 0.8928042124644894, 0.33463722322336675`], 
             UndirectedEdge[142, 275] -> 
             RGBColor[
              0.8435475703255119, 0.8600205631459911, 0.6775804738123877], 
             UndirectedEdge[296, 375] -> 
             RGBColor[
              0.8454991044388748, 0.879910504371777, 0.9721107240267223], 
             UndirectedEdge[92, 195] -> 
             RGBColor[
              0.9621674029023097, 0.9713050915465105, 0.9489248979514775], 
             UndirectedEdge[178, 248] -> 
             RGBColor[
              0.9303356131380117, 0.9386971728517919, 0.7014062509722487], 
             UndirectedEdge[41, 222] -> 
             RGBColor[
              0.7280435258762721, 0.6659746699116087, 0.6029254402575441], 
             UndirectedEdge[154, 356] -> 
             RGBColor[
              0.8405214075003546, 0.8761753848858757, 0.9793844953281771], 
             UndirectedEdge[70, 133] -> 
             RGBColor[
              0.8477323397682021, 0.8795853546005475, 0.8752937393089459], 
             UndirectedEdge[7, 80] -> 
             RGBColor[
              0.9927213633716916, 0.9906808986252905, 0.728332133087634], 
             UndirectedEdge[152, 261] -> 
             RGBColor[
              0.9150438680918298, 0.9343807910472032, 0.9669913275624196], 
             UndirectedEdge[95, 229] -> 
             RGBColor[
              0.9640572529435056, 0.9707880655491108, 0.8598353823935676], 
             UndirectedEdge[30, 204] -> 
             RGBColor[
              0.970888279408588, 0.9390906374143962, 0.6238917526442871], 
             UndirectedEdge[133, 223] -> 
             RGBColor[
              0.7707809913253652, 0.8180463312508852, 0.868597575455734], 
             UndirectedEdge[298, 306] -> 
             RGBColor[
              0.940521220788686, 0.9376434872727213, 0.6888795297127066], 
             UndirectedEdge[40, 96] -> 
             RGBColor[
              0.9675229751167641, 0.9723849789358511, 0.7723048144410483], 
             UndirectedEdge[122, 146] -> 
             RGBColor[
              0.9636058933004894, 0.9368511773428467, 0.64299437483337], 
             UndirectedEdge[223, 267] -> 
             RGBColor[
              0.7433568142729836, 0.7171248461509092, 0.6130453553110127], 
             UndirectedEdge[54, 322] -> 
             RGBColor[
              0.9516594825711957, 0.8610241563091552, 0.5894041744527769], 
             UndirectedEdge[41, 154] -> 
             RGBColor[
              0.8262004417163827, 0.7441725612441945, 0.6116716486457199], 
             UndirectedEdge[245, 353] -> 
             RGBColor[
              0.9047584108622042, 0.9268938140814402, 0.9907778589870471], 
             UndirectedEdge[26, 62] -> 
             RGBColor[
              0.9880878087904381, 0.9869704256791517, 0.677843979715806], 
             UndirectedEdge[217, 269] -> 
             RGBColor[
              0.7366676677549063, 0.7894543720767322, 0.8173110891007467], 
             UndirectedEdge[172, 347] -> 
             RGBColor[
              0.987533599056448, 0.9696100437465699, 0.4060708157269251], 
             UndirectedEdge[63, 261] -> 
             RGBColor[
              0.9745727863841667, 0.9802991263389411, 0.9163774309191648], 
             UndirectedEdge[195, 369] -> 
             RGBColor[
              0.9649679037155612, 0.9733937004676342, 0.9441843805622347], 
             UndirectedEdge[65, 180] -> 
             RGBColor[
              0.9571396035880002, 0.9253097311355074, 0.6396771679250662], 
             UndirectedEdge[49, 211] -> 
             RGBColor[
              0.8483655667839164, 0.8813229982847033, 0.9317180247763772], 
             UndirectedEdge[285, 387] -> 
             RGBColor[
              0.9821054350299738, 0.9858147889736046, 0.8990510435719372], 
             UndirectedEdge[329, 388] -> 
             RGBColor[
              0.9708512608291023, 0.974991537961386, 0.776535868532397], 
             UndirectedEdge[38, 102] -> 
             RGBColor[
              0.5790954857307953, 0.6235543240341095, 0.6537229370545188], 
             UndirectedEdge[92, 188] -> 
             RGBColor[
              0.9505677970569193, 0.8683734925521525, 0.5975857843029007], 
             UndirectedEdge[114, 153] -> 
             RGBColor[
              0.9868655061267213, 0.9851719708223885, 0.6693734589915941], 
             UndirectedEdge[326, 337] -> 
             RGBColor[
              0.9442530464740081, 0.9560131676751709, 0.9024639641396837], 
             UndirectedEdge[38, 221] -> 
             RGBColor[
              0.980426725191881, 0.9456368894280476, 0.3784619527835984], 
             UndirectedEdge[350, 394] -> 
             RGBColor[
              0.7574157479237841, 0.8064865408166817, 0.8343481947020701], 
             UndirectedEdge[286, 349] -> 
             RGBColor[
              0.9920169499091473, 0.9844007829615878, 0.4517744481666278], 
             UndirectedEdge[246, 320] -> 
             RGBColor[
              0.8099669651461308, 0.8517858999193839, 0.95001060447725], 
             UndirectedEdge[322, 362] -> 
             RGBColor[
              0.9578627842153449, 0.8644794475008957, 0.5264584109456651], 
             UndirectedEdge[80, 348] -> 
             RGBColor[
              0.992228523355684, 0.9896267636648195, 0.6746895388012253], 
             UndirectedEdge[78, 230] -> 
             RGBColor[
              0.9218193521606528, 0.940248217308703, 0.9837538454788466], 
             UndirectedEdge[248, 329] -> 
             RGBColor[
              0.9919125100637229, 0.9835055549531004, 0.4975353875843789], 
             UndirectedEdge[43, 330] -> 
             RGBColor[
              0.9767663057000028, 0.9821929293495206, 0.9242127635186432], 
             UndirectedEdge[63, 217] -> 
             RGBColor[
              0.9903049355326576, 0.989899678544175, 0.7842274335897923], 
             UndirectedEdge[79, 136] -> 
             RGBColor[
              0.9881202731684248, 0.987039863701013, 0.6813775269127335], 
             UndirectedEdge[159, 243] -> 
             RGBColor[
              0.9765840105224148, 0.9796262601591569, 0.7953365206607603], 
             UndirectedEdge[1, 327] -> 
             RGBColor[
              0.8895399776835662, 0.8632540559774534, 0.6343833297796636], 
             UndirectedEdge[304, 353] -> 
             RGBColor[
              0.8266615930040488, 0.8653548927255355, 0.9831343032356761], 
             UndirectedEdge[240, 329] -> 
             RGBColor[
              0.9656924227017379, 0.9711440849328199, 0.7852684358415516], 
             UndirectedEdge[10, 311] -> 
             RGBColor[
              0.7462672613820254, 0.7608140176508198, 0.6377706485542244], 
             UndirectedEdge[353, 378] -> 
             RGBColor[
              0.9549082184591924, 0.9653335010938848, 0.9392693743928391], 
             UndirectedEdge[167, 243] -> 
             RGBColor[
              0.9724860365783504, 0.9786602125705944, 0.916209898351733], 
             UndirectedEdge[169, 292] -> 
             RGBColor[
              0.9759695180759784, 0.9770627263963501, 0.6878535394366393], 
             UndirectedEdge[211, 347] -> 
             RGBColor[
              0.9886645762656316, 0.9863294914494325, 0.6573544826205742], 
             UndirectedEdge[224, 340] -> 
             RGBColor[
              0.9729959927720047, 0.9792677770046412, 0.9255229443162301], 
             UndirectedEdge[144, 233] -> 
             RGBColor[
              0.9395360817189207, 0.7792680801879533, 0.4533854381954], 
             UndirectedEdge[273, 394] -> 
             RGBColor[
              0.9945525789720477, 0.9919005423828664, 0.7315949540263229], 
             UndirectedEdge[93, 94] -> 
             RGBColor[
              0.9777926527143148, 0.9829583772723054, 0.922475425737586], 
             UndirectedEdge[358, 366] -> 
             RGBColor[
              0.8844194552843583, 0.49838671446333577`, 0.2223863892752906], 
             UndirectedEdge[245, 329] -> 
             RGBColor[
              0.9396831578750562, 0.9504504952955718, 0.7843648897478335], 
             UndirectedEdge[44, 93] -> 
             RGBColor[
              0.9635806361389988, 0.9067598155024541, 0.5978109139440551], 
             UndirectedEdge[218, 314] -> 
             RGBColor[
              0.9871813272421051, 0.9881389777807303, 0.8250142567489913], 
             UndirectedEdge[133, 346] -> 
             RGBColor[
              0.9853488803998955, 0.9872693512274358, 0.8503732032345148], 
             UndirectedEdge[143, 272] -> 
             RGBColor[
              0.9317261808903579, 0.9454775543035432, 0.8775151750459131], 
             UndirectedEdge[272, 346] -> 
             RGBColor[
              0.9245486181411976, 0.9415693991034253, 0.9543686701077494], 
             UndirectedEdge[61, 269] -> 
             RGBColor[
              0.33383762031440445`, 0.4518398425484784, 0.9430861906352549], 
             UndirectedEdge[158, 362] -> 
             RGBColor[
              0.9910065094699698, 0.9905489747907378, 0.798708942697406], 
             UndirectedEdge[294, 393] -> 
             RGBColor[
              0.8167840776604678, 0.8558089096659336, 0.8903727700548251], 
             UndirectedEdge[17, 298] -> 
             RGBColor[
              0.9889529824981749, 0.9727786279992059, 0.5492809345276425], 
             UndirectedEdge[83, 179] -> 
             RGBColor[
              0.6540672248413448, 0.7271191754114477, 0.9680003810304986], 
             UndirectedEdge[223, 398] -> 
             RGBColor[
              0.7706620468154131, 0.8147461108629122, 0.6904024398025981], 
             UndirectedEdge[52, 272] -> 
             RGBColor[
              0.9325670798243213, 0.945211595957621, 0.8189703979295939], 
             UndirectedEdge[52, 174] -> 
             RGBColor[
              0.8880533489994897, 0.9100283155903509, 0.8146421723171835], 
             UndirectedEdge[63, 317] -> 
             RGBColor[
              0.9635647396700546, 0.8968460020167438, 0.5788070652222744], 
             UndirectedEdge[145, 280] -> 
             RGBColor[
              0.9374519071427588, 0.7719175148938504, 0.3566187064249923], 
             UndirectedEdge[152, 317] -> 
             RGBColor[
              0.9040358213777177, 0.8509276667250059, 0.6294209618655292], 
             UndirectedEdge[102, 391] -> 
             RGBColor[
              0.5807120020365868, 0.6459304374065369, 0.924006592989189], 
             UndirectedEdge[168, 251] -> 
             RGBColor[
              0.8236997175272736, 0.8616741479743684, 0.9120422896027245], 
             UndirectedEdge[89, 245] -> 
             RGBColor[
              0.9396122105790412, 0.9515946586462813, 0.8708418686724373], 
             UndirectedEdge[293, 330] -> 
             RGBColor[
              0.9763264447554056, 0.9589665560030862, 0.6482695284066686], 
             UndirectedEdge[166, 247] -> 
             RGBColor[
              0.907776493743801, 0.9290749956229081, 0.983252498518234], 
             UndirectedEdge[8, 182] -> 
             RGBColor[
              0.7917378417433498, 0.8347908331426381, 0.8589932002977394], 
             UndirectedEdge[2, 215] -> 
             RGBColor[
              0.8302934988605768, 0.8682662621068831, 0.9834766346243463], 
             UndirectedEdge[61, 107] -> 
             RGBColor[
              0.5764791775362369, 0.6443424459835279, 0.9401637935945824], 
             UndirectedEdge[192, 361] -> 
             RGBColor[
              0.9754950683595717, 0.9799449755052578, 0.8681539314504854], 
             UndirectedEdge[71, 321] -> 
             RGBColor[
              0.9892980343999113, 0.9743953168230888, 0.5121229964426591], 
             UndirectedEdge[26, 389] -> 
             RGBColor[
              0.8289362751175255, 0.8625512619377833, 0.7050793931148784], 
             UndirectedEdge[134, 263] -> 
             RGBColor[
              0.9722008770727627, 0.9178891722012748, 0.3465060861618974], 
             UndirectedEdge[105, 282] -> 
             RGBColor[0.811065738847658, 0.85235884705914, 0.981795452397469],
              UndirectedEdge[323, 340] -> 
             RGBColor[
              0.972602272531619, 0.932930798121701, 0.6003691138316161], 
             UndirectedEdge[311, 323] -> 
             RGBColor[
              0.9628047480792167, 0.8861938227900406, 0.3100038993320438], 
             UndirectedEdge[29, 365] -> 
             RGBColor[
              0.8923512582358071, 0.9168247818639861, 0.98349569970963], 
             UndirectedEdge[321, 384] -> 
             RGBColor[
              0.9641608668314843, 0.958109592055669, 0.686303912708384], 
             UndirectedEdge[115, 195] -> 
             RGBColor[
              0.9478150900079234, 0.9606011600896327, 0.9732196199989605], 
             UndirectedEdge[162, 359] -> 
             RGBColor[
              0.7018000637321767, 0.5619138371902924, 0.5837175929069444], 
             UndirectedEdge[106, 295] -> 
             RGBColor[
              0.9941811457682976, 0.9916232762517845, 0.7287611358702998], 
             UndirectedEdge[24, 242] -> 
             RGBColor[
              0.9354929564828258, 0.7754354722720584, 0.5363397139980959], 
             UndirectedEdge[109, 286] -> 
             RGBColor[
              0.98862242764157, 0.9729502622813184, 0.43858737015883176`], 
             UndirectedEdge[287, 367] -> 
             RGBColor[
              0.94304222981508, 0.8933630892763812, 0.6340673206529178], 
             UndirectedEdge[74, 140] -> 
             RGBColor[
              0.5898362357261131, 0.6532616269464289, 0.8708688938578424], 
             UndirectedEdge[168, 394] -> 
             RGBColor[
              0.8275399854009307, 0.8631473741536982, 0.8400526725535955], 
             UndirectedEdge[68, 249] -> 
             RGBColor[
              0.5165214603614194, 0.6183744164048421, 0.9550816079215548], 
             UndirectedEdge[389, 400] -> 
             RGBColor[
              0.8052920155671202, 0.8485834740169684, 0.9723073893148264], 
             UndirectedEdge[267, 346] -> 
             RGBColor[
              0.957924703347514, 0.88634786612746, 0.5948209830897935], 
             UndirectedEdge[16, 392] -> 
             RGBColor[
              0.8216257202360939, 0.8581107002928254, 0.8061112767248322], 
             UndirectedEdge[13, 191] -> 
             RGBColor[
              0.9426757095708787, 0.9535688364990091, 0.8440017233224504], 
             UndirectedEdge[312, 327] -> 
             RGBColor[
              0.8957612399829626, 0.9188603054877628, 0.9601234597194572], 
             UndirectedEdge[260, 291] -> 
             RGBColor[
              0.9743525337106126, 0.9439122263990869, 0.6227784261027776], 
             UndirectedEdge[83, 344] -> 
             RGBColor[
              0.7097759265300352, 0.7709375078560408, 0.9524327052712851], 
             UndirectedEdge[200, 288] -> 
             RGBColor[
              0.9454448846051944, 0.9585400482510813, 0.9670588242068732], 
             UndirectedEdge[297, 332] -> 
             RGBColor[
              0.9623390729523881, 0.9575300911302568, 0.6910418073792779], 
             UndirectedEdge[189, 241] -> 
             RGBColor[
              0.9936947803273568, 0.9889220976127415, 0.5550939338171619], 
             UndirectedEdge[276, 358] -> 
             RGBColor[
              0.9239395803285164, 0.735213599895604, 0.2576096203680286], 
             UndirectedEdge[11, 102] -> 
             RGBColor[
              0.5621512105637609, 0.6320878295166101, 0.9554251715229646], 
             UndirectedEdge[96, 243] -> 
             RGBColor[
              0.9762368885119972, 0.9788838012782922, 0.7575544320155209], 
             UndirectedEdge[171, 397] -> 
             RGBColor[
              0.8648848713590639, 0.8948287052932342, 0.9625973897499336], 
             UndirectedEdge[314, 385] -> 
             RGBColor[
              0.8474416507816892, 0.8809121137872844, 0.9461884237924498], 
             UndirectedEdge[11, 213] -> 
             RGBColor[
              0.8516407072935266, 0.884791424256741, 0.9769269937529647], 
             UndirectedEdge[68, 129] -> 
             RGBColor[
              0.7613088183094203, 0.809063313598851, 0.7868067580349083], 
             UndirectedEdge[137, 277] -> 
             RGBColor[
              0.9747140073213306, 0.9262379856258924, 0.3672013634702319], 
             UndirectedEdge[35, 327] -> 
             RGBColor[
              0.8776720777363816, 0.9052959072858355, 0.988194340353251], 
             UndirectedEdge[155, 183] -> 
             RGBColor[
              0.9421361513202393, 0.7918025207416428, 0.48368801824794677`], 
             UndirectedEdge[63, 256] -> 
             RGBColor[
              0.9363007961509383, 0.9504964476303064, 0.9374945818420357], 
             UndirectedEdge[144, 358] -> 
             RGBColor[
              0.9155635963247402, 0.6971802127952214, 0.25062049400112213`], 
             UndirectedEdge[192, 332] -> 
             RGBColor[
              0.9494281070884926, 0.9618041455872481, 0.9704892028237888], 
             UndirectedEdge[149, 259] -> 
             RGBColor[
              0.9660567351842628, 0.8903169740689052, 0.4668136852637071], 
             UndirectedEdge[146, 165] -> 
             RGBColor[
              0.8811026029108704, 0.9075682629542041, 0.9677644242129326], 
             UndirectedEdge[164, 280] -> 
             RGBColor[
              0.9360932818420437, 0.7732397071049149, 0.5160829135717655], 
             UndirectedEdge[65, 105] -> 
             RGBColor[
              0.8808992148237317, 0.8650867964912985, 0.646090866558213], 
             UndirectedEdge[73, 369] -> 
             RGBColor[
              0.9826089737672827, 0.9859114127446622, 0.8857083184244108], 
             UndirectedEdge[187, 281] -> 
             RGBColor[
              0.9010090455456713, 0.9202568725227864, 0.8245411405292853], 
             UndirectedEdge[53, 253] -> 
             RGBColor[
              0.9909495317386878, 0.9897522958962484, 0.7434557566402371], 
             UndirectedEdge[132, 191] -> 
             RGBColor[
              0.9945146682679971, 0.9906757550143845, 0.644333676394011], 
             UndirectedEdge[29, 273] -> 
             RGBColor[
              0.9180691798000199, 0.9343829677181257, 0.8673166287467674], 
             UndirectedEdge[138, 366] -> 
             RGBColor[
              0.9083862168547667, 0.5808382347464931, 0.4518519704103173], 
             UndirectedEdge[229, 309] -> 
             RGBColor[
              0.916276890327187, 0.9360783369460217, 0.9918765018410851], 
             UndirectedEdge[274, 287] -> 
             RGBColor[
              0.9654351371062508, 0.9722195653374793, 0.8752084705480572], 
             UndirectedEdge[251, 312] -> 
             RGBColor[
              0.9782471278393556, 0.9827530008780312, 0.8973302129553784], 
             UndirectedEdge[339, 360] -> 
             RGBColor[
              0.8683756705328669, 0.8943249498292568, 0.7861683665109935], 
             UndirectedEdge[150, 365] -> 
             RGBColor[
              0.9185906135992066, 0.9377473315824334, 0.9859984328483401], 
             UndirectedEdge[61, 300] -> 
             RGBColor[
              0.5909334582203323, 0.6514545646235987, 0.6883493637770868], 
             UndirectedEdge[62, 389] -> 
             RGBColor[
              0.8243601436796311, 0.862804452742085, 0.9400300221846514], 
             UndirectedEdge[374, 399] -> 
             RGBColor[
              0.8317519058043416, 0.6768295887368556, 0.5978631313535392], 
             UndirectedEdge[27, 51] -> 
             RGBColor[
              0.9937301634431476, 0.9910422953054969, 0.7075599549273665], 
             UndirectedEdge[58, 159] -> 
             RGBColor[
              0.7559957675816158, 0.8048616795811956, 0.7955466793842068], 
             UndirectedEdge[57, 153] -> 
             RGBColor[
              0.8774268527783093, 0.8995588968372638, 0.7000456894454612], 
             UndirectedEdge[84, 264] -> 
             RGBColor[
              0.7953708774106887, 0.8403615135651872, 0.9574053641629967], 
             UndirectedEdge[159, 201] -> 
             RGBColor[
              0.9720319595548279, 0.9762313480008299, 0.803041955583849], 
             UndirectedEdge[80, 87] -> 
             RGBColor[
              0.9870359287796385, 0.9887492154118203, 0.8574441386204277], 
             UndirectedEdge[39, 288] -> 
             RGBColor[
              0.9804739892306409, 0.9824865730456875, 0.7855123642777331], 
             UndirectedEdge[91, 365] -> 
             RGBColor[
              0.9636697738437929, 0.9723213677203522, 0.9417159520235137], 
             UndirectedEdge[5, 384] -> 
             RGBColor[
              0.960309402941481, 0.9699193982179202, 0.9520700072411602], 
             UndirectedEdge[156, 381] -> 
             RGBColor[
              0.974644830787746, 0.980328918551278, 0.9151834687069149], 
             UndirectedEdge[2, 197] -> 
             RGBColor[
              0.935495381303829, 0.9513497215993298, 0.9918748652325624], 
             UndirectedEdge[238, 293] -> 
             RGBColor[
              0.9858952987099446, 0.9632573889563987, 0.4699674728791534], 
             UndirectedEdge[85, 325] -> 
             RGBColor[
              0.9658107983592312, 0.9536928770815578, 0.6715230059207679], 
             UndirectedEdge[146, 332] -> 
             RGBColor[
              0.9493789604578196, 0.9617674921105624, 0.970572395250024], 
             UndirectedEdge[197, 204] -> 
             RGBColor[
              0.956810585724459, 0.9673099860662526, 0.9579925921518994], 
             UndirectedEdge[20, 130] -> 
             RGBColor[
              0.9458889842857394, 0.9584889619411773, 0.9530526673333906], 
             UndirectedEdge[167, 348] -> 
             RGBColor[
              0.9899343745368692, 0.9886780741713042, 0.7127095217958117], 
             UndirectedEdge[83, 237] -> 
             RGBColor[
              0.6576519188035247, 0.7299775130729644, 0.9683422923407055], 
             UndirectedEdge[178, 334] -> 
             RGBColor[
              0.9304791688332941, 0.9450011093064374, 0.8998847435874324], 
             UndirectedEdge[178, 388] -> 
             RGBColor[
              0.9092743639033911, 0.9301831558600775, 0.980406731920267], 
             UndirectedEdge[115, 184] -> 
             RGBColor[
              0.9652361367401365, 0.9730278870697027, 0.9183899136674912], 
             UndirectedEdge[165, 385] -> 
             RGBColor[
              0.7595028701788545, 0.8120486817101096, 0.976663806207721], 
             UndirectedEdge[202, 257] -> 
             RGBColor[
              0.993204922967653, 0.9878743422525114, 0.5017759832625988], 
             UndirectedEdge[35, 57] -> 
             RGBColor[
              0.8478940092582485, 0.8820127455483395, 0.9852317299831059], 
             UndirectedEdge[115, 206] -> 
             RGBColor[
              0.9637104567520174, 0.9723969791864282, 0.9436743794038676], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.9422771916913026, 0.953770312867412, 0.873296350266048], 
             UndirectedEdge[61, 98] -> 
             RGBColor[
              0.5906984407548432, 0.6536181708834672, 0.8565799252166965], 
             UndirectedEdge[33, 173] -> 
             RGBColor[
              0.8442416914070779, 0.8781418817976516, 0.9331428161611554], 
             UndirectedEdge[6, 185] -> 
             RGBColor[
              0.9460054047456241, 0.957234698626739, 0.8949993484024301], 
             UndirectedEdge[300, 363] -> 
             RGBColor[
              0.8635291404564948, 0.8895737188697155, 0.7083869294174634], 
             UndirectedEdge[34, 270] -> 
             RGBColor[
              0.9390492745596943, 0.776829512393263, 0.4632362048224081], 
             UndirectedEdge[162, 179] -> 
             RGBColor[
              0.8573443754133141, 0.685270627640153, 0.5980532775824183], 
             UndirectedEdge[11, 250] -> 
             RGBColor[
              0.9618110439259792, 0.9485323496742537, 0.6736710901765015], 
             UndirectedEdge[66, 314] -> 
             RGBColor[
              0.8864154221083459, 0.9113587201593014, 0.9500729650876905], 
             UndirectedEdge[153, 327] -> 
             RGBColor[
              0.9072049212564424, 0.9228420585747598, 0.7030082998156062], 
             UndirectedEdge[153, 392] -> 
             RGBColor[
              0.993224376215216, 0.9875519782068023, 0.5348429497867166], 
             UndirectedEdge[110, 369] -> 
             RGBColor[
              0.9683635627734333, 0.9759261774331138, 0.9384364155069795], 
             UndirectedEdge[321, 398] -> 
             RGBColor[
              0.9880645095894642, 0.9714009296381547, 0.4081333028936514], 
             UndirectedEdge[188, 278] -> 
             RGBColor[
              0.9249917129740172, 0.848905061032426, 0.627225093909533], 
             UndirectedEdge[213, 289] -> 
             RGBColor[
              0.7825975734117416, 0.8300904394018864, 0.9789656703937029], 
             UndirectedEdge[236, 263] -> 
             RGBColor[
              0.9706488044350652, 0.9126536667503355, 0.34047657704876677`], 
             UndirectedEdge[93, 383] -> 
             RGBColor[
              0.9827946835050771, 0.9864208107257522, 0.9020034392744145], 
             UndirectedEdge[56, 286] -> 
             RGBColor[
              0.9636772602175971, 0.9689926652942448, 0.7388200031952554], 
             UndirectedEdge[25, 144] -> 
             RGBColor[
              0.935570619493852, 0.7779942794888075, 0.5457091879201218], 
             UndirectedEdge[143, 331] -> 
             RGBColor[
              0.9937974242139124, 0.991206198644941, 0.7163375240756598], 
             UndirectedEdge[76, 257] -> 
             RGBColor[
              0.9941222185995615, 0.989836344856349, 0.6016179519034057], 
             UndirectedEdge[91, 189] -> 
             RGBColor[
              0.9898418804682589, 0.9897073092873421, 0.7918371905097765], 
             UndirectedEdge[133, 145] -> 
             RGBColor[
              0.9926310799031555, 0.989336757726428, 0.6348373364616571], 
             UndirectedEdge[207, 230] -> 
             RGBColor[
              0.9374212570862903, 0.9518840924564688, 0.9573438900682538], 
             UndirectedEdge[238, 336] -> 
             RGBColor[
              0.9565264619208931, 0.9638273066374541, 0.7816278800345169], 
             UndirectedEdge[123, 306] -> 
             RGBColor[
              0.9456737817451977, 0.9565614810040072, 0.8772166254565941], 
             UndirectedEdge[272, 338] -> 
             RGBColor[
              0.9323851556355074, 0.9457500572955411, 0.8665942581468121], 
             UndirectedEdge[11, 289] -> 
             RGBColor[
              0.8763322872457369, 0.9040806741783658, 0.9793880196866673], 
             UndirectedEdge[215, 300] -> 
             RGBColor[
              0.8600043541501845, 0.8868201290178579, 0.7080356116594511], 
             UndirectedEdge[224, 289] -> 
             RGBColor[
              0.884203707418578, 0.9099511664550031, 0.9660637585292253], 
             UndirectedEdge[65, 161] -> 
             RGBColor[
              0.9774954500387637, 0.9392322280528878, 0.5488457051268902], 
             UndirectedEdge[14, 247] -> 
             RGBColor[
              0.9012370080108015, 0.9238605872090258, 0.9826287565311527], 
             UndirectedEdge[150, 226] -> 
             RGBColor[
              0.9044373407765116, 0.8082179351729311, 0.619823705066205], 
             UndirectedEdge[15, 180] -> 
             RGBColor[
              0.9720299536452816, 0.9752302084156959, 0.7237279085572219], 
             UndirectedEdge[7, 114] -> 
             RGBColor[
              0.9882153358543795, 0.9884230926963502, 0.7853444940853094], 
             UndirectedEdge[108, 313] -> 
             RGBColor[
              0.8283228299342509, 0.8664507405348841, 0.9833534639916071], 
             UndirectedEdge[227, 315] -> 
             RGBColor[
              0.9683284977445958, 0.9750084657792846, 0.898569883563777], 
             UndirectedEdge[174, 384] -> 
             RGBColor[
              0.8628274764849446, 0.8935528599126303, 0.9791681026214204], 
             UndirectedEdge[104, 138] -> 
             RGBColor[
              0.9063269725162011, 0.9248668258118095, 0.8587746013790551], 
             UndirectedEdge[313, 344] -> 
             RGBColor[
              0.9290721811616762, 0.9456786804289811, 0.9722157066453438], 
             UndirectedEdge[255, 374] -> 
             RGBColor[
              0.6826575376095765, 0.5580526136071192, 0.5845775916122864], 
             UndirectedEdge[87, 167] -> 
             RGBColor[
              0.9847417799608238, 0.987800525918305, 0.8954641216150142], 
             UndirectedEdge[114, 312] -> 
             RGBColor[
              0.9754218248532416, 0.9811902177353915, 0.9264886188954449], 
             UndirectedEdge[50, 265] -> 
             RGBColor[
              0.9936234372654514, 0.988769502017216, 0.5473286818071047], 
             UndirectedEdge[310, 345] -> 
             RGBColor[
              0.9891633081124545, 0.9874049241988707, 0.6561209743013015], 
             UndirectedEdge[315, 334] -> 
             RGBColor[
              0.968644488644167, 0.9751391361368529, 0.8933330965996491], 
             UndirectedEdge[102, 302] -> 
             RGBColor[
              0.5026589595212381, 0.5848998516666428, 0.9584020488288978], 
             UndirectedEdge[172, 211] -> 
             RGBColor[
              0.9842720075055778, 0.9715123255975788, 0.6402901824547718], 
             UndirectedEdge[264, 381] -> 
             RGBColor[
              0.9734681458486214, 0.9794513488503235, 0.9171752893802696], 
             UndirectedEdge[270, 397] -> 
             RGBColor[
              0.880989913303944, 0.9048341295614484, 0.8398747780503762], 
             UndirectedEdge[48, 290] -> 
             RGBColor[
              0.9814603343569491, 0.9847926040309298, 0.8759128143887921], 
             UndirectedEdge[224, 323] -> 
             RGBColor[
              0.9607245412328183, 0.9241856647035547, 0.6255469902464311], 
             UndirectedEdge[10, 339] -> 
             RGBColor[
              0.6349620870396457, 0.7129932418842181, 0.9654562772129383], 
             UndirectedEdge[254, 320] -> 
             RGBColor[
              0.6587419315597038, 0.7333334706493322, 0.9666208975106714], 
             UndirectedEdge[92, 392] -> 
             RGBColor[
              0.9830571966285448, 0.9845222379877476, 0.7897973252997612], 
             UndirectedEdge[166, 224] -> 
             RGBColor[
              0.9161166035949184, 0.9352950358941949, 0.9691348679893158], 
             UndirectedEdge[108, 344] -> 
             RGBColor[
              0.8583051516059037, 0.889755555877874, 0.965331983140158], 
             UndirectedEdge[180, 271] -> 
             RGBColor[
              0.9555511283052425, 0.9663706847851732, 0.9601245250435291], 
             UndirectedEdge[104, 207] -> 
             RGBColor[
              0.8971934513489215, 0.9198251225674816, 0.9535022580803212], 
             UndirectedEdge[45, 266] -> 
             RGBColor[
              0.9951371950365658, 0.9922571194263021, 0.7302527929873367], 
             UndirectedEdge[59, 373] -> 
             RGBColor[
              0.7356946189679117, 0.7887623544418081, 0.8252622233415946], 
             UndirectedEdge[107, 352] -> 
             RGBColor[
              0.9556432214774544, 0.96643936772222, 0.9599686353247205], 
             UndirectedEdge[99, 338] -> 
             RGBColor[
              0.913220692486924, 0.9304688345863545, 0.864766334543382], 
             UndirectedEdge[186, 341] -> 
             RGBColor[
              0.9367525216951977, 0.9494270955580364, 0.8754618553502359], 
             UndirectedEdge[90, 156] -> 
             RGBColor[
              0.9456494883491723, 0.9587848818729776, 0.9699105189445246], 
             UndirectedEdge[34, 151] -> 
             RGBColor[
              0.9383954538873178, 0.7754310560864601, 0.3920718595477035], 
             UndirectedEdge[174, 260] -> 
             RGBColor[
              0.8813155549252465, 0.9073412385419575, 0.9478726082851118], 
             UndirectedEdge[13, 216] -> 
             RGBColor[
              0.9397942729320417, 0.9526091371492761, 0.908607541949951], 
             UndirectedEdge[9, 217] -> 
             RGBColor[
              0.9945118016939596, 0.9916393258134024, 0.7145087742763845], 
             UndirectedEdge[87, 159] -> 
             RGBColor[
              0.9888397539048882, 0.9887665735068675, 0.7745907439240416], 
             UndirectedEdge[184, 305] -> 
             RGBColor[
              0.9080956192258692, 0.9276506198635757, 0.9193549209717271], 
             UndirectedEdge[12, 259] -> 
             RGBColor[
              0.9941424347484594, 0.99134864244715, 0.7106033119570743], 
             UndirectedEdge[27, 287] -> 
             RGBColor[
              0.9660308990843766, 0.9718329478279546, 0.8193241599439874], 
             UndirectedEdge[188, 284] -> 
             RGBColor[
              0.919077751071794, 0.7168772792802325, 0.2537462629042957], 
             UndirectedEdge[118, 126] -> 
             RGBColor[
              0.9372635233765337, 0.9501536819898073, 0.8893682156908086], 
             UndirectedEdge[209, 304] -> 
             RGBColor[
              0.852278299101345, 0.8847596128737776, 0.9501669424025231], 
             UndirectedEdge[48, 108] -> 
             RGBColor[
              0.8735859024189989, 0.9002507906091723, 0.8991114748593031], 
             UndirectedEdge[136, 376] -> 
             RGBColor[
              0.9912304263967797, 0.9884390182973944, 0.6348957881510199], 
             UndirectedEdge[48, 344] -> 
             RGBColor[
              0.9743352536464243, 0.9794787305032693, 0.8879737175130398], 
             UndirectedEdge[13, 198] -> 
             RGBColor[
              0.9190494957062447, 0.9379780960819977, 0.981356964081685], 
             UndirectedEdge[286, 320] -> 
             RGBColor[
              0.8211007388540432, 0.8566867283464807, 0.7248545290480863], 
             UndirectedEdge[176, 368] -> 
             RGBColor[
              0.9370744918369769, 0.950871654695151, 0.9270721964239053], 
             UndirectedEdge[248, 388] -> 
             RGBColor[
              0.9688420584997329, 0.9690896105594882, 0.6942771674066719], 
             UndirectedEdge[57, 188] -> 
             RGBColor[
              0.846248575806746, 0.7865784826435933, 0.6195921515761851], 
             UndirectedEdge[39, 225] -> 
             RGBColor[
              0.9941337473718004, 0.9910630334739263, 0.6902476604046273], 
             UndirectedEdge[355, 379] -> 
             RGBColor[
              0.8919903406277057, 0.868594146003995, 0.6395986458643215], 
             UndirectedEdge[85, 348] -> 
             RGBColor[
              0.972672320424336, 0.9761445615544917, 0.7571779210604546], 
             UndirectedEdge[118, 336] -> 
             RGBColor[
              0.9553705216597668, 0.9645917109194825, 0.8910952773513716], 
             UndirectedEdge[195, 392] -> 
             RGBColor[
              0.9736457050890428, 0.97750316300749, 0.8057285255660174], 
             UndirectedEdge[193, 281] -> 
             RGBColor[
              0.95902148164977, 0.862403375870705, 0.46240522676829476`], 
             UndirectedEdge[154, 312] -> 
             RGBColor[
              0.8543360142301908, 0.886478295965645, 0.955999969561049], 
             UndirectedEdge[53, 171] -> 
             RGBColor[
              0.9786116953057491, 0.9811025358677126, 0.7890502498278666], 
             UndirectedEdge[115, 188] -> 
             RGBColor[
              0.936215484162533, 0.8576695610952747, 0.6218805063503836], 
             UndirectedEdge[319, 329] -> 
             RGBColor[
              0.9942667908902643, 0.9907236830625661, 0.6593764436013589], 
             UndirectedEdge[231, 359] -> 
             RGBColor[
              0.7308485292889586, 0.7888928167197269, 0.974690449860126], 
             UndirectedEdge[288, 399] -> 
             RGBColor[
              0.8783784937716885, 0.9053039597758056, 0.9605980628074648], 
             UndirectedEdge[140, 220] -> 
             RGBColor[
              0.97980811273694, 0.9834190128922333, 0.8723788933354502], 
             UndirectedEdge[9, 215] -> 
             RGBColor[
              0.86075265018331, 0.8893903606794078, 0.8599701236932569], 
             UndirectedEdge[309, 329] -> 
             RGBColor[
              0.9468139632362171, 0.9561364059300064, 0.7850450323289262], 
             UndirectedEdge[9, 61] -> 
             RGBColor[
              0.5916817542534578, 0.6540247962851486, 0.8402838758108926], 
             UndirectedEdge[21, 82] -> 
             RGBColor[
              0.8653301228714256, 0.8954547674899598, 0.9870171536804384], 
             UndirectedEdge[154, 361] -> 
             RGBColor[
              0.865831118222755, 0.8937514585845647, 0.8783310516112124], 
             UndirectedEdge[160, 213] -> 
             RGBColor[
              0.8755316376160025, 0.9011197819452059, 0.8697848620423114], 
             UndirectedEdge[331, 342] -> 
             RGBColor[
              0.9868019705215034, 0.9657824561751389, 0.5188419301885276], 
             UndirectedEdge[122, 159] -> 
             RGBColor[
              0.9813867530599583, 0.9476813996925733, 0.483711196208196], 
             UndirectedEdge[258, 278] -> 
             RGBColor[
              0.9325813115974488, 0.9488460032064314, 0.9853521038075006], 
             UndirectedEdge[37, 201] -> 
             RGBColor[
              0.9628841929423042, 0.9718396723847025, 0.9477115593825503], 
             UndirectedEdge[61, 314] -> 
             RGBColor[
              0.5842062901281253, 0.6501053139025725, 0.9270838075302482], 
             UndirectedEdge[297, 314] -> 
             RGBColor[
              0.9820014960082737, 0.9721942940510733, 0.6577584539269152], 
             UndirectedEdge[84, 175] -> 
             RGBColor[
              0.8092474762862512, 0.8499449056801573, 0.8996239356611992], 
             UndirectedEdge[72, 374] -> 
             RGBColor[
              0.9339432894408246, 0.7542172971226939, 0.433214269194795], 
             UndirectedEdge[168, 180] -> 
             RGBColor[
              0.8054943243498681, 0.84864091874965, 0.967235176466684], 
             UndirectedEdge[36, 60] -> 
             RGBColor[
              0.8962071793181896, 0.9151984324419252, 0.7193636183508727], 
             UndirectedEdge[347, 387] -> 
             RGBColor[
              0.9848889080144603, 0.9837147928083092, 0.672755338820257], 
             UndirectedEdge[140, 141] -> 
             RGBColor[
              0.9796167210953628, 0.9483150728658016, 0.5704078645226386], 
             UndirectedEdge[233, 382] -> 
             RGBColor[
              0.9939553262620122, 0.9914023664767314, 0.7232336387919716], 
             UndirectedEdge[21, 122] -> 
             RGBColor[
              0.9039788538934848, 0.8899038590744385, 0.6580284952776145], 
             UndirectedEdge[202, 268] -> 
             RGBColor[
              0.9885881822167306, 0.9872997403954757, 0.6752942288557592], 
             UndirectedEdge[196, 344] -> 
             RGBColor[
              0.973333958588721, 0.9790646692647997, 0.9045677678877274], 
             UndirectedEdge[109, 343] -> 
             RGBColor[
              0.9888729353997898, 0.9734860730459309, 0.465853593686376], 
             UndirectedEdge[52, 117] -> 
             RGBColor[
              0.993918941259563, 0.989401555180584, 0.5794924679269023], 
             UndirectedEdge[51, 194] -> 
             RGBColor[
              0.9884568203441678, 0.9894629775018317, 0.8395471960182235], 
             UndirectedEdge[223, 342] -> 
             RGBColor[
              0.7641479239456059, 0.7927724448342672, 0.665096302542281], 
             UndirectedEdge[241, 374] -> 
             RGBColor[
              0.9329204422499797, 0.7520295304071912, 0.3218836647524814], 
             UndirectedEdge[76, 109] -> 
             RGBColor[
              0.9893561227950958, 0.9745195620267508, 0.5184455597784724], 
             UndirectedEdge[90, 381] -> 
             RGBColor[
              0.9568929649195814, 0.9668884300074074, 0.938257847410257], 
             UndirectedEdge[75, 227] -> 
             RGBColor[
              0.9912517540231829, 0.9886343521582461, 0.648099957704603], 
             UndirectedEdge[209, 329] -> 
             RGBColor[
              0.9846136714775364, 0.985255521289109, 0.7532396971161645], 
             UndirectedEdge[24, 358] -> 
             RGBColor[
              0.9674543090662466, 0.9082688862037408, 0.5623730101804989], 
             UndirectedEdge[208, 369] -> 
             RGBColor[
              0.9743907901866196, 0.9491846693336101, 0.633845499156821], 
             UndirectedEdge[62, 400] -> 
             RGBColor[
              0.9644435492400327, 0.9730026377583368, 0.9450719759157541], 
             UndirectedEdge[127, 325] -> 
             RGBColor[
              0.9830034695085634, 0.9661976980600258, 0.6282044619137169], 
             UndirectedEdge[43, 277] -> 
             RGBColor[
              0.9857699018505054, 0.9852747330163298, 0.6843858843885661], 
             UndirectedEdge[70, 227] -> 
             RGBColor[
              0.846429530012887, 0.8790466092860413, 0.8968846685180847], 
             UndirectedEdge[25, 366] -> 
             RGBColor[
              0.9044264784534704, 0.5792007811569218, 0.5174750831942903], 
             UndirectedEdge[20, 387] -> 
             RGBColor[
              0.9436736605841824, 0.9568367771518156, 0.9568026325111691], 
             UndirectedEdge[328, 387] -> 
             RGBColor[
              0.9767108147465544, 0.9821515442872969, 0.9243066952284728], 
             UndirectedEdge[249, 386] -> 
             RGBColor[
              0.7495365980086045, 0.7995789434702814, 0.7918506681256265], 
             UndirectedEdge[110, 243] -> 
             RGBColor[
              0.9591388932999847, 0.9690464340438258, 0.9540513747464057], 
             UndirectedEdge[47, 121] -> 
             RGBColor[
              0.99404056034496, 0.9896616861066725, 0.5927299548263747], 
             UndirectedEdge[31, 156] -> 
             RGBColor[
              0.9746408349987339, 0.9803272661898343, 0.9152496892716165], 
             UndirectedEdge[98, 283] -> 
             RGBColor[
              0.8677355244124301, 0.8952069816759018, 0.8770601682435044], 
             UndirectedEdge[38, 358] -> 
             RGBColor[
              0.9630883608170648, 0.884474211659656, 0.32504391533059784`], 
             UndirectedEdge[126, 199] -> 
             RGBColor[
              0.8544997221650428, 0.8868188999500857, 0.9859841403926507], 
             UndirectedEdge[39, 200] -> 
             RGBColor[
              0.9593497463491243, 0.9664387307623745, 0.8110972621008838], 
             UndirectedEdge[227, 304] -> 
             RGBColor[
              0.8594047024832427, 0.8891829126348463, 0.8981779124500491], 
             UndirectedEdge[242, 333] -> 
             RGBColor[
              0.8812160569398699, 0.5535116819062443, 0.22259610506079894`], 
             UndirectedEdge[30, 333] -> 
             RGBColor[
              0.9226742853109122, 0.7210565913326339, 0.2715847362758179], 
             UndirectedEdge[85, 96] -> 
             RGBColor[
              0.972730313856397, 0.9762686036416346, 0.7634901482463088], 
             UndirectedEdge[39, 94] -> 
             RGBColor[
              0.9850901806570236, 0.9859293210531639, 0.7776983562884141], 
             UndirectedEdge[63, 138] -> 
             RGBColor[
              0.9902952459321761, 0.9902548490392209, 0.8104964202096794], 
             UndirectedEdge[119, 324] -> 
             RGBColor[
              0.9137957104228674, 0.6229055144401994, 0.41291670082588994`], 
             UndirectedEdge[18, 224] -> 
             RGBColor[
              0.9776897846951967, 0.9803282432145815, 0.7837288932492421], 
             UndirectedEdge[84, 204] -> 
             RGBColor[
              0.8027819137758418, 0.8458886523518601, 0.9448604127046427], 
             UndirectedEdge[241, 288] -> 
             RGBColor[
              0.9795470302173268, 0.9805039014461412, 0.6846185962064071], 
             UndirectedEdge[91, 266] -> 
             RGBColor[
              0.9899275195874135, 0.9901027847455256, 0.8165905973876704], 
             UndirectedEdge[201, 263] -> 
             RGBColor[
              0.9551568626283138, 0.9205015727662766, 0.6359656741758315], 
             UndirectedEdge[29, 266] -> 
             RGBColor[
              0.9186090039794277, 0.9346061988891594, 0.8583703450737865], 
             UndirectedEdge[161, 326] -> 
             RGBColor[
              0.9909039237243008, 0.9905065529485703, 0.8004090539865417], 
             UndirectedEdge[174, 235] -> 
             RGBColor[
              0.8787030638693705, 0.9053928469900466, 0.9522948741959161], 
             UndirectedEdge[207, 233] -> 
             RGBColor[
              0.9857184759698485, 0.9867314596826544, 0.8031011385827288], 
             UndirectedEdge[199, 212] -> 
             RGBColor[
              0.8987534557474421, 0.8898181062879149, 0.6635335390524559], 
             UndirectedEdge[127, 184] -> 
             RGBColor[
              0.9868503774680577, 0.9888303074002266, 0.8675868056939287], 
             UndirectedEdge[261, 381] -> 
             RGBColor[
              0.974644830787746, 0.980328918551278, 0.9151834687069149], 
             UndirectedEdge[221, 230] -> 
             RGBColor[
              0.9399263810579777, 0.9356369531860309, 0.6865686896849618], 
             UndirectedEdge[22, 273] -> 
             RGBColor[
              0.9943422942464897, 0.9914507646179447, 0.7087067593762162], 
             UndirectedEdge[240, 292] -> 
             RGBColor[
              0.9487380006729191, 0.9612894653524591, 0.971657372976775], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.988002808365388, 0.9876449445345166, 0.736538026918762], 
             UndirectedEdge[120, 343] -> 
             RGBColor[
              0.9900662708441258, 0.9886599667391585, 0.705242774594393], 
             UndirectedEdge[175, 310] -> 
             RGBColor[
              0.9873033770056066, 0.9890176343505601, 0.8600794310315192], 
             UndirectedEdge[55, 201] -> 
             RGBColor[
              0.9628063763406627, 0.9463051787092628, 0.6656825904588544], 
             UndirectedEdge[264, 333] -> 
             RGBColor[
              0.9202450266065649, 0.7579633237198498, 0.5859678137610689], 
             UndirectedEdge[107, 197] -> 
             RGBColor[
              0.9507519559093414, 0.9627914698702338, 0.9682482720851626], 
             UndirectedEdge[131, 300] -> 
             RGBColor[
              0.9916774966473212, 0.9885656532106348, 0.6232532348787909], 
             UndirectedEdge[164, 227] -> 
             RGBColor[
              0.9899696448471252, 0.9901202046229862, 0.8158924728175689], 
             UndirectedEdge[75, 315] -> 
             RGBColor[
              0.9700218144420025, 0.9736926581921735, 0.7239625956511031], 
             UndirectedEdge[123, 193] -> 
             RGBColor[
              0.9581991529343805, 0.8625404412215885, 0.5107148859034242], 
             UndirectedEdge[157, 253] -> 
             RGBColor[
              0.990672058906295, 0.9904106708876708, 0.8042516540678131], 
             UndirectedEdge[87, 110] -> 
             RGBColor[
              0.9713946366824581, 0.9781867473915364, 0.9333055980096869], 
             UndirectedEdge[112, 273] -> 
             RGBColor[
              0.9322598949526374, 0.9456982587841216, 0.868670151826225], 
             UndirectedEdge[193, 384] -> 
             RGBColor[
              0.9337164539363458, 0.8457586152264003, 0.6183156021638085], 
             UndirectedEdge[95, 249] -> 
             RGBColor[
              0.7499806421773085, 0.8005287090473873, 0.8401821355661113], 
             UndirectedEdge[61, 66] -> 
             RGBColor[
              0.49141468961353557`, 0.5774508220275372, 0.9570755062088961], 
             UndirectedEdge[113, 251] -> 
             RGBColor[
              0.9905994731684502, 0.9890422670751811, 0.7081679273022708], 
             UndirectedEdge[107, 131] -> 
             RGBColor[
              0.9772232159632259, 0.981453534570564, 0.8750676646962864], 
             UndirectedEdge[71, 343] -> 
             RGBColor[
              0.9939681184372748, 0.9895067401911339, 0.5848451002344599], 
             UndirectedEdge[113, 168] -> 
             RGBColor[
              0.8268308260852071, 0.8616305540843708, 0.7628650574610727], 
             UndirectedEdge[58, 201] -> 
             RGBColor[
              0.7335902632130313, 0.7905824048541513, 0.9626581750321231], 
             UndirectedEdge[47, 130] -> 
             RGBColor[
              0.9880929740624205, 0.9878377998433187, 0.7463520066025667], 
             UndirectedEdge[17, 82] -> 
             RGBColor[
              0.9430826933825737, 0.9539695252627349, 0.8502152034138715], 
             UndirectedEdge[11, 25] -> 
             RGBColor[
              0.9661511088191425, 0.9738217838357427, 0.9218348437180434], 
             UndirectedEdge[73, 392] -> 
             RGBColor[
              0.9912867751407645, 0.9900208752845181, 0.7472524634281934], 
             UndirectedEdge[155, 337] -> 
             RGBColor[
              0.8940287862155706, 0.7567068403104285, 0.6098807014178385], 
             UndirectedEdge[159, 165] -> 
             RGBColor[
              0.8988834626703393, 0.9183984853039306, 0.8084812455877588], 
             UndirectedEdge[226, 368] -> 
             RGBColor[
              0.9506087653546604, 0.8432436506826908, 0.5574395775447645], 
             UndirectedEdge[188, 258] -> 
             RGBColor[
              0.9371462982954585, 0.8583637607515423, 0.6203048808185476], 
             UndirectedEdge[140, 350] -> 
             RGBColor[
              0.7550747546543242, 0.8056333032157872, 0.8814909515613532], 
             UndirectedEdge[14, 38] -> 
             RGBColor[
              0.9186499728561123, 0.9156766297211747, 0.6801331526912306], 
             UndirectedEdge[242, 268] -> 
             RGBColor[
              0.9337458032376054, 0.7747129795053695, 0.5652945647590574], 
             UndirectedEdge[20, 50] -> 
             RGBColor[
              0.9516094970355948, 0.9598271608787754, 0.7747150628599233], 
             UndirectedEdge[149, 212] -> 
             RGBColor[
              0.9544561394036051, 0.8525449109406156, 0.30614801223705085`], 
             UndirectedEdge[80, 361] -> 
             RGBColor[
              0.9914229563631178, 0.9907211862832515, 0.791807339947933], 
             UndirectedEdge[31, 204] -> 
             RGBColor[
              0.9808751864247625, 0.9849768352755528, 0.9046965584866172], 
             UndirectedEdge[209, 245] -> 
             RGBColor[
              0.9303751169595004, 0.9462985342296824, 0.957810498153894], 
             UndirectedEdge[113, 148] -> 
             RGBColor[
              0.9575748498735761, 0.9645886414560072, 0.7756788336348193], 
             UndirectedEdge[48, 231] -> 
             RGBColor[
              0.9573822934718814, 0.966563174345479, 0.9072379504955316], 
             UndirectedEdge[198, 224] -> 
             RGBColor[
              0.9544395408703608, 0.9655416646962958, 0.9620061526223489], 
             UndirectedEdge[1, 188] -> 
             RGBColor[
              0.9430700330707141, 0.811815230173901, 0.27400643875391356`], 
             UndirectedEdge[256, 264] -> 
             RGBColor[
              0.9239526790449839, 0.9415451220072588, 0.9699451118374083], 
             UndirectedEdge[15, 170] -> 
             RGBColor[
              0.9786199494475701, 0.9801450164949148, 0.7125727646101231], 
             UndirectedEdge[20, 322] -> 
             RGBColor[
              0.9169900424026488, 0.8344920329428916, 0.624663146175555], 
             UndirectedEdge[92, 153] -> 
             RGBColor[
              0.9817460740284827, 0.9813539067458229, 0.6780393221721769], 
             UndirectedEdge[189, 360] -> 
             RGBColor[
              0.9944738211456317, 0.9905883871499226, 0.6398877192037604], 
             UndirectedEdge[272, 342] -> 
             RGBColor[
              0.924730727197949, 0.9200538118337412, 0.680019581158781], 
             UndirectedEdge[69, 219] -> 
             RGBColor[
              0.9906562178805802, 0.990404120216442, 0.8045141808591652], 
             UndirectedEdge[86, 151] -> 
             RGBColor[
              0.970419282569371, 0.9745428023264227, 0.7672245484262152], 
             UndirectedEdge[72, 288] -> 
             RGBColor[
              0.9805698774081717, 0.982691668161644, 0.7959492006487208], 
             UndirectedEdge[266, 273] -> 
             RGBColor[
              0.9944960817656724, 0.9919920026129282, 0.7408776990340005], 
             UndirectedEdge[131, 297] -> 
             RGBColor[
              0.9877448019404522, 0.9753974845063452, 0.599664866149825], 
             UndirectedEdge[219, 360] -> 
             RGBColor[
              0.9943049073829497, 0.9908785984497561, 0.6688597260954291], 
             UndirectedEdge[58, 236] -> 
             RGBColor[
              0.749082205019783, 0.7827344988382103, 0.6671690779050583], 
             UndirectedEdge[272, 321] -> 
             RGBColor[
              0.9273831918407183, 0.9290011979021172, 0.690323905420022], 
             UndirectedEdge[250, 391] -> 
             RGBColor[
              0.9803718353988049, 0.9623749575641805, 0.642252511642726], 
             UndirectedEdge[122, 298] -> 
             RGBColor[
              0.9755576002900463, 0.9292121878092645, 0.35954632199705416`], 
             UndirectedEdge[113, 282] -> 
             RGBColor[
              0.9086426293472655, 0.9255714170380698, 0.7710116347587108], 
             UndirectedEdge[237, 343] -> 
             RGBColor[
              0.9241747534087308, 0.9378305013098973, 0.762294548705456], 
             UndirectedEdge[174, 398] -> 
             RGBColor[
              0.8867311192429246, 0.9068441974951159, 0.7009974928066878], 
             UndirectedEdge[223, 384] -> 
             RGBColor[
              0.7467584040574332, 0.8014547732804266, 0.9685730496173306], 
             UndirectedEdge[143, 260] -> 
             RGBColor[
              0.9869919343214257, 0.9883743270864223, 0.8421996879979665], 
             UndirectedEdge[148, 161] -> 
             RGBColor[
              0.9565941945890006, 0.9655215030386667, 0.8892174898422547], 
             UndirectedEdge[137, 199] -> 
             RGBColor[
              0.8913595236527497, 0.8648766371547023, 0.6348095090914906], 
             UndirectedEdge[147, 387] -> 
             RGBColor[
              0.8849087846967307, 0.91020571994977, 0.951137490747473], 
             UndirectedEdge[138, 381] -> 
             RGBColor[
              0.9903672903357554, 0.9902846412515577, 0.8093024579974295], 
             UndirectedEdge[42, 207] -> 
             RGBColor[
              0.9836631643380092, 0.9862475553424399, 0.8637687496663673], 
             UndirectedEdge[185, 247] -> 
             RGBColor[
              0.967696178692473, 0.9743049771669425, 0.889255005876729], 
             UndirectedEdge[49, 380] -> 
             RGBColor[
              0.8520460087405621, 0.8806725974432528, 0.7128160702366594], 
             UndirectedEdge[63, 242] -> 
             RGBColor[
              0.9343671317783471, 0.7749699148243814, 0.5549975428922496], 
             UndirectedEdge[12, 238] -> 
             RGBColor[
              0.993710471822027, 0.9904247174256624, 0.663586813181076], 
             UndirectedEdge[109, 382] -> 
             RGBColor[
              0.9886278914627753, 0.9748849362973959, 0.5789629612689022], 
             UndirectedEdge[4, 115] -> 
             RGBColor[
              0.9519367347433219, 0.963675075984719, 0.9662427505590432], 
             UndirectedEdge[187, 279] -> 
             RGBColor[
              0.8394456830660316, 0.8749178255228717, 0.9845210437706753], 
             UndirectedEdge[152, 156] -> 
             RGBColor[
              0.9150438680918298, 0.9343807910472032, 0.9669913275624196], 
             UndirectedEdge[143, 290] -> 
             RGBColor[
              0.9830967468580423, 0.9854693026540149, 0.8487932243458784], 
             UndirectedEdge[48, 234] -> 
             RGBColor[
              0.7180765532903322, 0.7755818461548702, 0.8857135682077284], 
             UndirectedEdge[294, 341] -> 
             RGBColor[
              0.7619476582138999, 0.8144461799691334, 0.9767780827941609], 
             UndirectedEdge[243, 351] -> 
             RGBColor[
              0.8439907623810634, 0.8785787815573876, 0.9641955803342046], 
             UndirectedEdge[241, 399] -> 
             RGBColor[
              0.8913563965023045, 0.9112199706875526, 0.7037427326301495], 
             UndirectedEdge[78, 207] -> 
             RGBColor[
              0.9609773260531593, 0.9704175341809861, 0.9509393876353364], 
             UndirectedEdge[174, 267] -> 
             RGBColor[
              0.8594258867004951, 0.8092229327831131, 0.6236404083151025], 
             UndirectedEdge[124, 293] -> 
             RGBColor[
              0.8708910030128231, 0.8763548771278217, 0.6729654856721072], 
             UndirectedEdge[57, 392] -> 
             RGBColor[
              0.8787379753783715, 0.9027272280791885, 0.8118036925730454], 
             UndirectedEdge[272, 331] -> 
             RGBColor[
              0.9326347756425646, 0.9453563904677464, 0.8263386699752153], 
             UndirectedEdge[91, 255] -> 
             RGBColor[
              0.7384091284484415, 0.7932282072324167, 0.9272004495815114], 
             UndirectedEdge[35, 337] -> 
             RGBColor[
              0.9156575416158398, 0.9355844850953663, 0.9918174278080977], 
             UndirectedEdge[219, 339] -> 
             RGBColor[
              0.8685975633313241, 0.8954510568467624, 0.8576772558041337], 
             UndirectedEdge[166, 185] -> 
             RGBColor[
              0.931034630665305, 0.9452974097459295, 0.8935714226060814], 
             UndirectedEdge[137, 238] -> 
             RGBColor[
              0.975279265125367, 0.9274470149123957, 0.4287261870727938], 
             UndirectedEdge[218, 300] -> 
             RGBColor[
              0.993908495334312, 0.9894882285017566, 0.58627981299583], 
             UndirectedEdge[96, 110] -> 
             RGBColor[
              0.9766452246905644, 0.9791883377316786, 0.7568632253763385], 
             UndirectedEdge[225, 375] -> 
             RGBColor[
              0.9719775519385452, 0.9770105198074535, 0.8601765781541517], 
             UndirectedEdge[24, 25] -> 
             RGBColor[
              0.9874613322353586, 0.9890829528973268, 0.8574617040994986], 
             UndirectedEdge[40, 361] -> 
             RGBColor[
              0.9666594146921371, 0.9733553594671401, 0.8831103884019018], 
             UndirectedEdge[141, 394] -> 
             RGBColor[
              0.9819577143648226, 0.9491683104666961, 0.5232651076633554], 
             UndirectedEdge[200, 360] -> 
             RGBColor[
              0.9592018281540852, 0.9661223487000093, 0.7949972794161565], 
             UndirectedEdge[68, 229] -> 
             RGBColor[
              0.7305980711276165, 0.7886337729065657, 0.9747348547490111], 
             UndirectedEdge[96, 258] -> 
             RGBColor[
              0.9692395584107334, 0.9736652039458462, 0.7693990866809846], 
             UndirectedEdge[106, 310] -> 
             RGBColor[
              0.9904055594975387, 0.9900619743006844, 0.7913323712808292], 
             UndirectedEdge[15, 394] -> 
             RGBColor[
              0.9940756146963441, 0.989736663819744, 0.5965454046441333], 
             UndirectedEdge[115, 203] -> 
             RGBColor[
              0.8665864261578053, 0.8965114153763465, 0.9806581884528301], 
             UndirectedEdge[218, 298] -> 
             RGBColor[
              0.9889673951224314, 0.9729184712441904, 0.5587739793012946], 
             UndirectedEdge[165, 262] -> 
             RGBColor[
              0.8991941289824829, 0.9190629691324234, 0.8422953564543495], 
             UndirectedEdge[141, 357] -> 
             RGBColor[
              0.8294790905901672, 0.8321032697625979, 0.6514599008957225], 
             UndirectedEdge[15, 239] -> 
             RGBColor[
              0.897587193948306, 0.9164115952613431, 0.7303207780559977], 
             UndirectedEdge[80, 228] -> 
             RGBColor[
              0.8466534415143673, 0.8789877996163988, 0.8863086283233967], 
             UndirectedEdge[260, 272] -> 
             RGBColor[
              0.9258292857500781, 0.9425245189092276, 0.9522008338975221], 
             UndirectedEdge[7, 361] -> 
             RGBColor[
              0.9933145060618964, 0.9909261783707621, 0.7185022237068619], 
             UndirectedEdge[22, 255] -> 
             RGBColor[
              0.7433637272869253, 0.7947994182758695, 0.8103703278970764], 
             UndirectedEdge[28, 380] -> 
             RGBColor[
              0.7444212008576835, 0.7943544493589427, 0.7036211030353061], 
             UndirectedEdge[53, 397] -> 
             RGBColor[
              0.8806590022344938, 0.9041263442441356, 0.8038571502871229], 
             UndirectedEdge[187, 306] -> 
             RGBColor[
              0.8527762182788678, 0.8855472324538485, 0.9857925221195849], 
             UndirectedEdge[208, 392] -> 
             RGBColor[
              0.9830685915601014, 0.953294131873466, 0.4953896441606037], 
             UndirectedEdge[33, 381] -> 
             RGBColor[
              0.8445944650290765, 0.8782877627562167, 0.9272964442957699], 
             UndirectedEdge[290, 321] -> 
             RGBColor[
              0.9787537578084027, 0.9689929462525888, 0.6616019547199873], 
             UndirectedEdge[20, 116] -> 
             RGBColor[
              0.6536682254531659, 0.7248412984561579, 0.9689003718710659], 
             UndirectedEdge[33, 156] -> 
             RGBColor[
              0.8333509884586674, 0.8701842146217869, 0.9589491158300375], 
             UndirectedEdge[9, 202] -> 
             RGBColor[
              0.9934163769187743, 0.9892963229837148, 0.5952785476755436], 
             UndirectedEdge[76, 233] -> 
             RGBColor[
              0.9946835575943327, 0.9910369922060863, 0.6627162373015418], 
             UndirectedEdge[115, 369] -> 
             RGBColor[
              0.9600270823606769, 0.969708843991014, 0.9525479023434613], 
             UndirectedEdge[183, 335] -> 
             RGBColor[
              0.9927342256963174, 0.9912634298506142, 0.7700762136405606], 
             UndirectedEdge[39, 296] -> 
             RGBColor[
              0.86765529987213, 0.8939630180382498, 0.8021818062771979], 
             UndirectedEdge[10, 219] -> 
             RGBColor[
              0.7608913238897284, 0.8095468905047174, 0.8481476367973738], 
             UndirectedEdge[71, 143] -> 
             RGBColor[
              0.993641023449551, 0.9908716732245149, 0.6993142660685503], 
             UndirectedEdge[232, 384] -> 
             RGBColor[
              0.9647344470674315, 0.9600444128745629, 0.6885321636135], 
             UndirectedEdge[1, 57] -> 
             RGBColor[
              0.8597619092054332, 0.8399708942399574, 0.6314207194095185], 
             UndirectedEdge[288, 393] -> 
             RGBColor[
              0.9782771378319657, 0.9823572530913961, 0.8785547344501421], 
             UndirectedEdge[328, 372] -> 
             RGBColor[
              0.9842861551577737, 0.9843708634360244, 0.7029813563258805], 
             UndirectedEdge[16, 115] -> 
             RGBColor[
              0.7957951051549745, 0.8412086973749683, 0.9736023711577753], 
             UndirectedEdge[34, 244] -> 
             RGBColor[
              0.9387502030263595, 0.7761898286242301, 0.4306841140744687], 
             UndirectedEdge[233, 366] -> 
             RGBColor[
              0.9083919406785389, 0.5804745818560677, 0.42515133346956846`], 
             UndirectedEdge[100, 105] -> 
             RGBColor[
              0.8823890520803777, 0.9084435505925773, 0.9613274434999599], 
             UndirectedEdge[88, 282] -> 
             RGBColor[
              0.881452896703323, 0.9082164516754985, 0.9852897469254718], 
             UndirectedEdge[189, 219] -> 
             RGBColor[
              0.9946957139440888, 0.9917144941674283, 0.7113966084969006], 
             UndirectedEdge[44, 328] -> 
             RGBColor[
              0.9614737292347673, 0.9051884877830216, 0.6013773577635908], 
             UndirectedEdge[153, 154] -> 
             RGBColor[
              0.8657796955036705, 0.890460049052642, 0.6988848096571982], 
             UndirectedEdge[73, 258] -> 
             RGBColor[
              0.9663869741925706, 0.9738130720229283, 0.9131679323293006], 
             UndirectedEdge[22, 141] -> 
             RGBColor[
              0.9817474296392645, 0.9487185327017744, 0.5003769130132487], 
             UndirectedEdge[100, 273] -> 
             RGBColor[
              0.9800787805099256, 0.9830411696998627, 0.8459602696343829], 
             UndirectedEdge[230, 391] -> 
             RGBColor[
              0.9403801436334787, 0.9540908251986298, 0.9523352669450711], 
             UndirectedEdge[338, 384] -> 
             RGBColor[
              0.9691628306262734, 0.974858451449093, 0.8625742654351741], 
             UndirectedEdge[76, 207] -> 
             RGBColor[
              0.985544312603281, 0.9863589418521839, 0.7841445309435566], 
             UndirectedEdge[144, 370] -> 
             RGBColor[
              0.7951557538425104, 0.6687271556535694, 0.5982194230619715], 
             UndirectedEdge[6, 340] -> 
             RGBColor[
              0.9429651089740383, 0.9559774581931509, 0.9453849173708495], 
             UndirectedEdge[30, 370] -> 
             RGBColor[
              0.836001783477931, 0.8334922136041483, 0.6466972206456235], 
             UndirectedEdge[164, 245] -> 
             RGBColor[
              0.9379127278627473, 0.9508918788683802, 0.899006695401712], 
             UndirectedEdge[56, 108] -> 
             RGBColor[
              0.8459341584464795, 0.8804935358437578, 0.985033248226922], 
             UndirectedEdge[50, 322] -> 
             RGBColor[
              0.9591038664822974, 0.8636480155362309, 0.4081485057609263], 
             UndirectedEdge[379, 399] -> 
             RGBColor[
              0.8747002167576272, 0.8550483016645833, 0.637885589243683], 
             UndirectedEdge[6, 13] -> 
             RGBColor[
              0.8956973325111216, 0.9196687561607066, 0.9899136052450006], 
             UndirectedEdge[55, 60] -> 
             RGBColor[
              0.8877986595850242, 0.8870198793184269, 0.6709365708014053], 
             UndirectedEdge[44, 47] -> 
             RGBColor[
              0.9706405648490763, 0.9092225585496818, 0.42717263431546326`], 
             UndirectedEdge[156, 264] -> 
             RGBColor[
              0.9622246692782123, 0.9713478007158936, 0.9488279609145374], 
             UndirectedEdge[32, 43] -> 
             RGBColor[
              0.9705425932026899, 0.9340380104199975, 0.6142984248702809], 
             UndirectedEdge[144, 207] -> 
             RGBColor[
              0.9303968367278689, 0.7745900298340509, 0.5748137318374148], 
             UndirectedEdge[14, 213] -> 
             RGBColor[
              0.8079709838550827, 0.8502199004271961, 0.9814130378667121], 
             UndirectedEdge[127, 139] -> 
             RGBColor[
              0.7678221243555325, 0.8168513576292629, 0.9188289960606577], 
             UndirectedEdge[321, 342] -> 
             RGBColor[
              0.9815503867196571, 0.9494272636095098, 0.3828271656333343], 
             UndirectedEdge[82, 182] -> 
             RGBColor[
              0.7404992302044333, 0.796974513763541, 0.9751660993177986], 
             UndirectedEdge[50, 172] -> 
             RGBColor[
              0.9884321757058188, 0.9718880106834155, 0.4736034690032087], 
             UndirectedEdge[80, 96] -> 
             RGBColor[
              0.9922865167877448, 0.9897508057519624, 0.6810017659870794], 
             UndirectedEdge[78, 160] -> 
             RGBColor[
              0.9692663514499977, 0.9751100167216852, 0.8702072113352759], 
             UndirectedEdge[32, 293] -> 
             RGBColor[
              0.9701027322580926, 0.9108116370735628, 0.33835518975830636`], 
             UndirectedEdge[322, 328] -> 
             RGBColor[
              0.9500271965650209, 0.859806800078373, 0.5921672088928585], 
             UndirectedEdge[120, 254] -> 
             RGBColor[
              0.8274569557915666, 0.8647708982773972, 0.9197429195294335], 
             UndirectedEdge[291, 321] -> 
             RGBColor[
              0.9759064398012529, 0.9303889053919765, 0.36090149762527746`], 
             UndirectedEdge[65, 312] -> 
             RGBColor[
              0.9661237599942445, 0.9320101002730784, 0.6244693345725625], 
             UndirectedEdge[209, 334] -> 
             RGBColor[
              0.9827480248434495, 0.9856575303418567, 0.869459488605623], 
             UndirectedEdge[295, 310] -> 
             RGBColor[
              0.9895811581917597, 0.9899595554073408, 0.8223307020682119], 
             UndirectedEdge[109, 205] -> 
             RGBColor[
              0.988597914289112, 0.9728978306990907, 0.435919243022647], 
             UndirectedEdge[194, 376] -> 
             RGBColor[
              0.9868667830150321, 0.9888054562041386, 0.8658982294467045], 
             UndirectedEdge[142, 338] -> 
             RGBColor[
              0.8497373281801661, 0.8807761308106479, 0.8584651821656668], 
             UndirectedEdge[232, 386] -> 
             RGBColor[
              0.9898644314044458, 0.9763147734363271, 0.5135693969382755], 
             UndirectedEdge[169, 378] -> 
             RGBColor[
              0.9888351931837491, 0.9864000459297289, 0.6545269187449373], 
             UndirectedEdge[94, 324] -> 
             RGBColor[
              0.9044289722212209, 0.6182826006261681, 0.5525670475374869], 
             UndirectedEdge[196, 231] -> 
             RGBColor[
              0.9563809984141782, 0.9661491131070095, 0.9238320008702192], 
             UndirectedEdge[207, 366] -> 
             RGBColor[
              0.8992526956874871, 0.5757965315021651, 0.5465796271115833], 
             UndirectedEdge[156, 310] -> 
             RGBColor[
              0.9746034630691689, 0.9803118119365444, 0.915869038859962], 
             UndirectedEdge[206, 369] -> 
             RGBColor[
              0.9808632704596552, 0.9851895195644296, 0.9146391399671419], 
             UndirectedEdge[119, 225] -> 
             RGBColor[
              0.9942118152558996, 0.9912300127841409, 0.6987448678097007], 
             UndirectedEdge[69, 100] -> 
             RGBColor[
              0.97649346950667, 0.9815585514617265, 0.9053781514457727], 
             UndirectedEdge[64, 182] -> 
             RGBColor[
              0.7925114306509514, 0.8349217873205694, 0.8324385438860133], 
             UndirectedEdge[217, 268] -> 
             RGBColor[
              0.9896836069919159, 0.9896427432251632, 0.7945244554566], 
             UndirectedEdge[235, 275] -> 
             RGBColor[
              0.9788486601560451, 0.9659428708618525, 0.6548163286563906], 
             UndirectedEdge[5, 99] -> 
             RGBColor[
              0.9043672648021315, 0.9255297813551819, 0.9542620763493681], 
             UndirectedEdge[52, 267] -> 
             RGBColor[
              0.9659431650306377, 0.8899900629816557, 0.45942271091163794`], 
             UndirectedEdge[290, 346] -> 
             RGBColor[
              0.9759191841088819, 0.981561147453897, 0.9256467194077147], 
             UndirectedEdge[19, 108] -> 
             RGBColor[
              0.8763084420911911, 0.9011860492891903, 0.8401386879390287], 
             UndirectedEdge[92, 327] -> 
             RGBColor[
              0.8970377416697712, 0.919812318355705, 0.9579626753286508], 
             UndirectedEdge[151, 244] -> 
             RGBColor[
              0.994094756114368, 0.9897776053774034, 0.5986288298689186], 
             UndirectedEdge[114, 327] -> 
             RGBColor[
              0.9021571737680099, 0.9236303824322705, 0.9492968121480679], 
             UndirectedEdge[99, 174] -> 
             RGBColor[
              0.8068853383455952, 0.849163243049892, 0.9813601717296283], 
             UndirectedEdge[180, 282] -> 
             RGBColor[
              0.8873061276119265, 0.912581781703349, 0.9753817537643222], 
             UndirectedEdge[199, 277] -> 
             RGBColor[
              0.909356830797631, 0.9254572151082137, 0.715657889700552], 
             UndirectedEdge[237, 286] -> 
             RGBColor[
              0.923924245650511, 0.9372946905452847, 0.7350283251779117], 
             UndirectedEdge[290, 313] -> 
             RGBColor[
              0.9361972618722011, 0.9509925539566415, 0.9601548035210961], 
             UndirectedEdge[56, 237] -> 
             RGBColor[
              0.8945595019473943, 0.9187614809547784, 0.989805077950079], 
             UndirectedEdge[203, 361] -> 
             RGBColor[
              0.891157341357947, 0.9135364965842017, 0.880855332846317], 
             UndirectedEdge[169, 315] -> 
             RGBColor[
              0.9695123629899588, 0.9722469907058178, 0.6987838187015023], 
             UndirectedEdge[23, 304] -> 
             RGBColor[
              0.8621888871267354, 0.8902003612807452, 0.8423048684122285], 
             UndirectedEdge[129, 270] -> 
             RGBColor[
              0.9946583546293597, 0.9909830856124195, 0.6599730500988894], 
             UndirectedEdge[85, 284] -> 
             RGBColor[
              0.9301581051408891, 0.8194216211500263, 0.6059643343675876], 
             UndirectedEdge[203, 369] -> 
             RGBColor[
              0.8837392398654429, 0.9093039557543479, 0.9516229490161043], 
             UndirectedEdge[1, 222] -> 
             RGBColor[
              0.7499578360906837, 0.7526741551227498, 0.6215136312330797], 
             UndirectedEdge[25, 205] -> 
             RGBColor[
              0.9899598868632804, 0.9881414601792804, 0.6725136702704382], 
             UndirectedEdge[301, 380] -> 
             RGBColor[
              0.993532374125107, 0.9885747271679148, 0.5374170209571622], 
             UndirectedEdge[169, 329] -> 
             RGBColor[
              0.9929239401047971, 0.986917345976711, 0.5014646023014158], 
             UndirectedEdge[302, 340] -> 
             RGBColor[
              0.9056323215566406, 0.9262093068780366, 0.9418240827796054], 
             UndirectedEdge[205, 391] -> 
             RGBColor[
              0.9877449906444855, 0.9869439432666849, 0.6966095910645485], 
             UndirectedEdge[96, 203] -> 
             RGBColor[
              0.892020901782574, 0.9125661160529126, 0.7700497588854635], 
             UndirectedEdge[4, 195] -> 
             RGBColor[
              0.9568775560982061, 0.9673599324613391, 0.9578792287778164], 
             UndirectedEdge[269, 298] -> 
             RGBColor[
              0.7306244206895411, 0.7705272341437026, 0.6698433720663525], 
             UndirectedEdge[168, 220] -> 
             RGBColor[
              0.8145401910494996, 0.8553873113229878, 0.9519228836840978], 
             UndirectedEdge[291, 338] -> 
             RGBColor[
              0.980908403596042, 0.9471377647854002, 0.5371718503520676], 
             UndirectedEdge[10, 360] -> 
             RGBColor[
              0.7606694310912713, 0.8084207834872117, 0.7766387475042337], 
             UndirectedEdge[87, 348] -> 
             RGBColor[
              0.9884346384624096, 0.9879000725388599, 0.7304964280929479], 
             UndirectedEdge[259, 274] -> 
             RGBColor[
              0.9940312501948341, 0.9913026647769133, 0.7124459277470481], 
             UndirectedEdge[293, 336] -> 
             RGBColor[
              0.9485799305565531, 0.9378480734414425, 0.6804959616292532], 
             UndirectedEdge[229, 245] -> 
             RGBColor[
              0.9091460849660262, 0.9303924263115871, 0.9911963592599925], 
             UndirectedEdge[173, 197] -> 
             RGBColor[
              0.961466937246841, 0.9706180841563989, 0.9427394232680165], 
             UndirectedEdge[19, 344] -> 
             RGBColor[
              0.9770577933186164, 0.9804139891832873, 0.8290009305927654], 
             UndirectedEdge[83, 125] -> 
             RGBColor[
              0.7006401842291243, 0.7641240862064265, 0.9678971340035262], 
             UndirectedEdge[240, 315] -> 
             RGBColor[
              0.9422808455868996, 0.9564737296619267, 0.9825876522416381], 
             UndirectedEdge[7, 154] -> 
             RGBColor[
              0.8671295252313287, 0.8937111709266038, 0.8148558447509135], 
             UndirectedEdge[200, 225] -> 
             RGBColor[
              0.9591046427463539, 0.9671165086793202, 0.8717941203337675], 
             UndirectedEdge[13, 140] -> 
             RGBColor[
              0.9404025424819416, 0.9528606722399742, 0.8985269413569741], 
             UndirectedEdge[104, 366] -> 
             RGBColor[
              0.8198669160576119, 0.5135682447408949, 0.5755524529671608], 
             UndirectedEdge[116, 172] -> 
             RGBColor[
              0.6904909041233898, 0.7369021482607978, 0.6677887780143512], 
             UndirectedEdge[143, 267] -> 
             RGBColor[
              0.9651022660966744, 0.8902560213275779, 0.5179674880279572], 
             UndirectedEdge[51, 395] -> 
             RGBColor[
              0.9581130420198374, 0.8625048321454754, 0.5121419666053072], 
             UndirectedEdge[213, 224] -> 
             RGBColor[
              0.8595121274663677, 0.8906619165333782, 0.9636027325955226], 
             UndirectedEdge[130, 362] -> 
             RGBColor[
              0.9867617260984356, 0.9884763764991813, 0.8548479321035007], 
             UndirectedEdge[153, 278] -> 
             RGBColor[
              0.9561699899455807, 0.9618854752260964, 0.7076786317788091], 
             UndirectedEdge[83, 303] -> 
             RGBColor[
              0.6843413772672207, 0.7512589627858651, 0.9708879567149336], 
             UndirectedEdge[94, 296] -> 
             RGBColor[
              0.8583666295545826, 0.8895070835344332, 0.9503293603938683], 
             UndirectedEdge[147, 328] -> 
             RGBColor[
              0.8837679512308667, 0.9093548882188719, 0.9530686242281592], 
             UndirectedEdge[78, 102] -> 
             RGBColor[
              0.5621512105637609, 0.6320878295166101, 0.9554251715229646], 
             UndirectedEdge[22, 45] -> 
             RGBColor[
              0.9949834075173831, 0.9917158814313186, 0.6980818533295523], 
             UndirectedEdge[199, 238] -> 
             RGBColor[
              0.9099220886016673, 0.9266662443947169, 0.777182713303114], 
             UndirectedEdge[21, 182] -> 
             RGBColor[
              0.7147907729234728, 0.7764752877651859, 0.9727140037121298], 
             UndirectedEdge[126, 212] -> 
             RGBColor[
              0.9272508307834347, 0.912541139600977, 0.666251644123296], 
             UndirectedEdge[273, 365] -> 
             RGBColor[
              0.9682383360220517, 0.9742105855877548, 0.866003053669844], 
             UndirectedEdge[149, 367] -> 
             RGBColor[
              0.9429893221607765, 0.8116786905893347, 0.27298607427920213`], 
             UndirectedEdge[81, 89] -> 
             RGBColor[
              0.9774038290016427, 0.9810755083035332, 0.8518009634582414], 
             UndirectedEdge[57, 337] -> 
             RGBColor[
              0.8307039842990562, 0.8683058862566766, 0.9835921300567817], 
             UndirectedEdge[255, 288] -> 
             RGBColor[
              0.7292841255769236, 0.7865269846460692, 0.947312523066212], 
             UndirectedEdge[2, 283] -> 
             RGBColor[
              0.8382596865883114, 0.8744895085050585, 0.98427062976879], 
             UndirectedEdge[94, 128] -> 
             RGBColor[
              0.9848419058721425, 0.9866057876048113, 0.8384477692156249], 
             UndirectedEdge[176, 393] -> 
             RGBColor[
              0.9385652349771512, 0.9514881152939643, 0.9023667246716398], 
             UndirectedEdge[65, 326] -> 
             RGBColor[
              0.9766301026058317, 0.9388743846509557, 0.5631867515379423], 
             UndirectedEdge[97, 282] -> 
             RGBColor[
              0.9067389137999067, 0.9261225694805015, 0.8998477883238523], 
             UndirectedEdge[12, 149] -> 
             RGBColor[
              0.9654934140055726, 0.8905811443206697, 0.5122846083843677], 
             UndirectedEdge[78, 144] -> 
             RGBColor[
              0.9147949318022315, 0.762954154686285, 0.6012236872480076], 
             UndirectedEdge[201, 348] -> 
             RGBColor[
              0.9716268441123492, 0.9753648470328223, 0.7589476397527555], 
             UndirectedEdge[242, 381] -> 
             RGBColor[
              0.9344391761819264, 0.774999707036718, 0.5538035806799997], 
             UndirectedEdge[43, 367] -> 
             RGBColor[
              0.963699709557488, 0.9087694038447504, 0.5990995957826213], 
             UndirectedEdge[111, 197] -> 
             RGBColor[
              0.9628542403337443, 0.9711917696348966, 0.9197482208927259], 
             UndirectedEdge[69, 216] -> 
             RGBColor[
              0.9880180051494325, 0.9893131514531377, 0.8482361932899727], 
             UndirectedEdge[197, 295] -> 
             RGBColor[
              0.9655539294210214, 0.9723081604513306, 0.8750073861451486], 
             UndirectedEdge[193, 275] -> 
             RGBColor[
              0.9525706444074229, 0.8420169645773841, 0.3205288237235108], 
             UndirectedEdge[149, 238] -> 
             RGBColor[
              0.9656247722578304, 0.8893930490474176, 0.4197971864877088], 
             UndirectedEdge[79, 349] -> 
             RGBColor[
              0.9872517866250623, 0.984249653760939, 0.6661501273478732], 
             UndirectedEdge[16, 110] -> 
             RGBColor[
              0.8041315855677309, 0.847426030817068, 0.9594908843212934], 
             UndirectedEdge[49, 372] -> 
             RGBColor[
              0.8521652389439642, 0.8809276187923074, 0.7257935420734678], 
             UndirectedEdge[320, 343] -> 
             RGBColor[
              0.821351246612263, 0.8572225391110934, 0.7521207525756306], 
             UndirectedEdge[221, 358] -> 
             RGBColor[
              0.9642511145473553, 0.8883964530194846, 0.3295609940051588], 
             UndirectedEdge[240, 245] -> 
             RGBColor[
              0.9114538681837019, 0.9321870978733933, 0.9898392368792811], 
             UndirectedEdge[85, 115] -> 
             RGBColor[
              0.9472958382316281, 0.9602139029650685, 0.9740985778136755], 
             UndirectedEdge[70, 280] -> 
             RGBColor[
              0.7925531670078054, 0.66216611176797, 0.5970751092722812], 
             UndirectedEdge[151, 171] -> 
             RGBColor[
              0.9782887857028228, 0.9804118648782223, 0.7539035323164154], 
             UndirectedEdge[23, 163] -> 
             RGBColor[
              0.994999626542749, 0.9920663480642931, 0.72280075968947], 
             UndirectedEdge[255, 360] -> 
             RGBColor[
              0.7430410691258144, 0.7941092850949973, 0.7752509782754953], 
             UndirectedEdge[165, 307] -> 
             RGBColor[
              0.8110318518199657, 0.852303513802911, 0.9817997335319953], 
             UndirectedEdge[81, 169] -> 
             RGBColor[
              0.9764770040093625, 0.9774412085745361, 0.6869944981249494], 
             UndirectedEdge[44, 316] -> 
             RGBColor[
              0.969893090814456, 0.9075655909721713, 0.3507632831869538], 
             UndirectedEdge[195, 337] -> 
             RGBColor[
              0.9256117140097275, 0.9430818211849782, 0.9775169630497536], 
             UndirectedEdge[316, 390] -> 
             RGBColor[
              0.9813149588200166, 0.948633110022923, 0.3819125727000596], 
             UndirectedEdge[39, 177] -> 
             RGBColor[
              0.9675668409023501, 0.972860442955964, 0.8073607996741009], 
             UndirectedEdge[45, 190] -> 
             RGBColor[
              0.9897206677452389, 0.9753368273732641, 0.5608528302541145], 
             UndirectedEdge[287, 396] -> 
             RGBColor[
              0.9606139518978714, 0.9548225871526794, 0.6909456610994791], 
             UndirectedEdge[136, 343] -> 
             RGBColor[
              0.9931359442107296, 0.9877268036662745, 0.49426807125903227`], 
             UndirectedEdge[296, 360] -> 
             RGBColor[
              0.8675073816770908, 0.8936466359758848, 0.7860818235924705], 
             UndirectedEdge[167, 228] -> 
             RGBColor[
              0.8443592926955525, 0.8780391101228835, 0.9243286113179832], 
             UndirectedEdge[123, 279] -> 
             RGBColor[
              0.9323432465323613, 0.9459320740730304, 0.8759451471076845], 
             UndirectedEdge[33, 333] -> 
             RGBColor[
              0.7913713457870202, 0.6567997376257428, 0.596088968676569], 
             UndirectedEdge[164, 209] -> 
             RGBColor[
              0.9828432414652275, 0.9856969048619175, 0.867881502770043], 
             UndirectedEdge[22, 29] -> 
             RGBColor[
              0.9184552164602449, 0.9340649608941758, 0.8261994054160022], 
             UndirectedEdge[24, 366] -> 
             RGBColor[
              0.9049610141780657, 0.5794218254159835, 0.5086164429036313], 
             UndirectedEdge[178, 319] -> 
             RGBColor[
              0.9326898939645532, 0.9459153009612575, 0.8632473069892288], 
             UndirectedEdge[294, 368] -> 
             RGBColor[
              0.8152933345202935, 0.8551924490671203, 0.9150782418070904], 
             UndirectedEdge[13, 69] -> 
             RGBColor[
              0.9385619033623629, 0.9520995206617606, 0.9290310949897391], 
             UndirectedEdge[214, 295] -> 
             RGBColor[
              0.9922948388261201, 0.99108173208806, 0.7773579911765003], 
             UndirectedEdge[80, 146] -> 
             RGBColor[
              0.9748527790386937, 0.9796630422831005, 0.8780670332574927], 
             UndirectedEdge[56, 231] -> 
             RGBColor[
              0.929730549499362, 0.9468059195800643, 0.9931597238631504], 
             UndirectedEdge[134, 351] -> 
             RGBColor[
              0.8564827258579255, 0.8725714688340587, 0.6824414272433592], 
             UndirectedEdge[143, 291] -> 
             RGBColor[
              0.9802494288508925, 0.9468652617934025, 0.5480927672511686], 
             UndirectedEdge[120, 320] -> 
             RGBColor[
              0.8178744980192354, 0.8572850094362756, 0.9187878296918468], 
             UndirectedEdge[132, 220] -> 
             RGBColor[
              0.9815827000970889, 0.9830607655255337, 0.7635863486997538], 
             UndirectedEdge[6, 247] -> 
             RGBColor[
              0.9227472678241202, 0.9410122845037178, 0.9846804243145827], 
             UndirectedEdge[166, 289] -> 
             RGBColor[
              0.8392020495402925, 0.8747235587627031, 0.984497805787496], 
             UndirectedEdge[114, 392] -> 
             RGBColor[
              0.9881766287267834, 0.9883403020643131, 0.7811314621191783], 
             UndirectedEdge[305, 325] -> 
             RGBColor[
              0.9042487112663751, 0.9050180105233749, 0.6799725771915154], 
             UndirectedEdge[44, 128] -> 
             RGBColor[
              0.9706298892968266, 0.9104072258349599, 0.5137832574220939], 
             UndirectedEdge[90, 242] -> 
             RGBColor[
              0.9054438337433526, 0.7534556703584177, 0.6085306309176093], 
             UndirectedEdge[1, 337] -> 
             RGBColor[
              0.9275254415630244, 0.8935426337869843, 0.6380064172345102], 
             UndirectedEdge[74, 224] -> 
             RGBColor[
              0.5751619095532595, 0.6433600296786517, 0.9423935846912495], 
             UndirectedEdge[160, 370] -> 
             RGBColor[
              0.8496271734902767, 0.8808830176889696, 0.8672029471492397], 
             UndirectedEdge[30, 84] -> 
             RGBColor[
              0.797800136115036, 0.8034547811779713, 0.6430222866777457], 
             UndirectedEdge[293, 299] -> 
             RGBColor[
              0.8578092272322562, 0.8661352944628644, 0.6716616165184455], 
             UndirectedEdge[186, 399] -> 
             RGBColor[
              0.8916902970814886, 0.9137365319392461, 0.871099870968223], 
             UndirectedEdge[163, 371] -> 
             RGBColor[
              0.9728260164257656, 0.977479857860271, 0.8514209313724318], 
             UndirectedEdge[90, 138] -> 
             RGBColor[
              0.9613719478971817, 0.9687406045732573, 0.8640295082350391], 
             UndirectedEdge[71, 286] -> 
             RGBColor[
              0.9937176106790551, 0.9889709294265214, 0.5575788767069156], 
             UndirectedEdge[60, 201] -> 
             RGBColor[
              0.874618738430605, 0.9026667738829497, 0.9754074315743166], 
             UndirectedEdge[128, 380] -> 
             RGBColor[
              0.9933230850164309, 0.989334580138908, 0.6024097841475753], 
             UndirectedEdge[54, 128] -> 
             RGBColor[
              0.9863584273489245, 0.9877368068391192, 0.8358806939275807], 
             UndirectedEdge[25, 138] -> 
             RGBColor[
              0.9908865349120595, 0.9904993622278363, 0.8006972316061847], 
             UndirectedEdge[95, 129] -> 
             RGBColor[
              0.9947680001253094, 0.991217606241396, 0.6719072856794648], 
             UndirectedEdge[132, 302] -> 
             RGBColor[
              0.9102035037908425, 0.9270075233609678, 0.786684723725317], 
             UndirectedEdge[15, 100] -> 
             RGBColor[
              0.9796018162342218, 0.9808772911367404, 0.7109107202521933], 
             UndirectedEdge[33, 63] -> 
             RGBColor[
              0.8445224206254971, 0.8782579705438799, 0.9284904065080197], 
             UndirectedEdge[275, 338] -> 
             RGBColor[
              0.9880170210973505, 0.9711168008000768, 0.5647874869948764], 
             UndirectedEdge[252, 277] -> 
             RGBColor[
              0.993629791442491, 0.9887830929593976, 0.5480202947644182], 
             UndirectedEdge[146, 192] -> 
             RGBColor[
              0.9589248910351476, 0.9688868315051069, 0.9544136247600452], 
             UndirectedEdge[237, 254] -> 
             RGBColor[
              0.7615654383561716, 0.813941432848136, 0.9767946936404968], 
             UndirectedEdge[37, 236] -> 
             RGBColor[
              0.9783761347490558, 0.9639917663687614, 0.6522224622554854], 
             UndirectedEdge[265, 362] -> 
             RGBColor[
              0.9923823549984989, 0.9896009339818808, 0.6656385869918435], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.9421668202411949, 0.8350664189373754, 0.5908261611606986], 
             UndirectedEdge[341, 379] -> 
             RGBColor[
              0.9197624413713363, 0.8907388652833736, 0.6422475736256961], 
             UndirectedEdge[324, 380] -> 
             RGBColor[
              0.9129101513655091, 0.621011393160265, 0.31652906246943724`], 
             UndirectedEdge[63, 264] -> 
             RGBColor[
              0.973396101445042, 0.9794215566379867, 0.9183692515925195], 
             UndirectedEdge[153, 337] -> 
             RGBColor[
              0.9451903851359006, 0.9531306363842906, 0.7066313872704528], 
             UndirectedEdge[112, 155] -> 
             RGBColor[
              0.880076794046752, 0.7455819004717511, 0.6085499479496862], 
             UndirectedEdge[10, 177] -> 
             RGBColor[
              0.7340053392140897, 0.7912123529485602, 0.9705487276913183], 
             UndirectedEdge[238, 367] -> 
             RGBColor[
              0.9712063799772308, 0.9115222636943274, 0.42428827907591044`], 
             UndirectedEdge[87, 228] -> 
             RGBColor[
              0.8428595566210929, 0.8772611084904393, 0.9421155176151195], 
             UndirectedEdge[66, 352] -> 
             RGBColor[
              0.870578733554753, 0.8995477437662295, 0.9768803479390344], 
             UndirectedEdge[86, 386] -> 
             RGBColor[
              0.9707387045689932, 0.9752260136850963, 0.8019916618410103], 
             UndirectedEdge[52, 133] -> 
             RGBColor[
              0.9933673420830194, 0.9909115480816315, 0.7149749310563593], 
             UndirectedEdge[105, 112] -> 
             RGBColor[
              0.8345701665230895, 0.8711006396768362, 0.984037325691802], 
             UndirectedEdge[4, 258] -> 
             RGBColor[
              0.9528675488762473, 0.9643692756409865, 0.9646671250272072], 
             UndirectedEdge[141, 339] -> 
             RGBColor[
              0.8557174274265279, 0.8526008579179086, 0.6540750931003723], 
             UndirectedEdge[251, 282] -> 
             RGBColor[
              0.9055115207893321, 0.9256150109280674, 0.9201888669003628], 
             UndirectedEdge[94, 390] -> 
             RGBColor[
              0.9730113617697209, 0.9463423438302477, 0.6323306881246593], 
             UndirectedEdge[239, 337] -> 
             RGBColor[
              0.850319787759201, 0.8836299010053699, 0.9855472500255834], 
             UndirectedEdge[80, 243] -> 
             RGBColor[
              0.9747801853971652, 0.9796089020641097, 0.8781899153571465], 
             UndirectedEdge[366, 382] -> 
             RGBColor[
              0.9074895459796508, 0.5804674382962423, 0.46671212732082606`], 
             UndirectedEdge[99, 306] -> 
             RGBColor[
              0.8652489446078134, 0.8953900381460806, 0.9870094108251863], 
             UndirectedEdge[214, 261] -> 
             RGBColor[
              0.9773171437035293, 0.9814339886172636, 0.8708963279682503], 
             UndirectedEdge[21, 60] -> 
             RGBColor[
              0.8196163436327158, 0.8591685079918592, 0.9826132349958185], 
             UndirectedEdge[60, 159] -> 
             RGBColor[
              0.8970242427991895, 0.916946048609994, 0.8082959359264001], 
             UndirectedEdge[9, 300] -> 
             RGBColor[
              0.9934096548404749, 0.9892819451379391, 0.5945468909365256], 
             UndirectedEdge[114, 369] -> 
             RGBColor[
              0.9794988273533016, 0.9842308395244573, 0.9195873171153957], 
             UndirectedEdge[112, 350] -> 
             RGBColor[
              0.6951230639043737, 0.7602842572179369, 0.9714233925019722], 
             UndirectedEdge[18, 357] -> 
             RGBColor[
              0.8422264803628547, 0.8740180373791547, 0.7932562387889187], 
             UndirectedEdge[71, 320] -> 
             RGBColor[
              0.8217763456123843, 0.8581317828882511, 0.7983901553319137], 
             UndirectedEdge[226, 255] -> 
             RGBColor[
              0.7031064962397926, 0.6480298428361773, 0.6014918944085691], 
             UndirectedEdge[208, 258] -> 
             RGBColor[
              0.9581687906119074, 0.9370863286118762, 0.6613051130617109], 
             UndirectedEdge[11, 358] -> 
             RGBColor[
              0.9461440856500305, 0.8930077171421567, 0.6267461497990436], 
             UndirectedEdge[274, 299] -> 
             RGBColor[
              0.865513215790713, 0.8932566452618914, 0.8671235726103419], 
             UndirectedEdge[147, 372] -> 
             RGBColor[
              0.89248412510795, 0.9124250390984974, 0.7298121518448808], 
             UndirectedEdge[335, 337] -> 
             RGBColor[
              0.9446268605916488, 0.9561677494193999, 0.8962688968104523], 
             UndirectedEdge[36, 218] -> 
             RGBColor[
              0.9939794844113435, 0.9896400669594303, 0.594006535936909], 
             UndirectedEdge[262, 300] -> 
             RGBColor[
              0.9938600776775244, 0.9892756519306245, 0.5730855302859169], 
             UndirectedEdge[109, 136] -> 
             RGBColor[
              0.988465860173366, 0.9726153802982292, 0.4215459674672315], 
             UndirectedEdge[219, 241] -> 
             RGBColor[
              0.9935258665646747, 0.989212308912575, 0.5840659407088304], 
             UndirectedEdge[37, 348] -> 
             RGBColor[
              0.98488458186841, 0.9852524461437392, 0.7365057479035402], 
             UndirectedEdge[291, 384] -> 
             RGBColor[
              0.9558644552703108, 0.9301238477697598, 0.6540739204390862], 
             UndirectedEdge[10, 241] -> 
             RGBColor[
              0.7598903902729963, 0.8067544939500306, 0.691844962117635], 
             UndirectedEdge[131, 314] -> 
             RGBColor[
              0.9849503285551143, 0.9872164024896086, 0.8619876786319522], 
             UndirectedEdge[1, 41] -> 
             RGBColor[
              0.9346690562549897, 0.7785081565591239, 0.2672468156117114], 
             UndirectedEdge[78, 400] -> 
             RGBColor[
              0.9453754211275218, 0.9587816590332203, 0.9773493430459291], 
             UndirectedEdge[191, 357] -> 
             RGBColor[
              0.8426024504026526, 0.8748221992778804, 0.834178257402791], 
             UndirectedEdge[215, 352] -> 
             RGBColor[
              0.8374404975043848, 0.8736599019037596, 0.9735774382639565], 
             UndirectedEdge[96, 369] -> 
             RGBColor[
              0.9854615579854457, 0.9857635446675801, 0.7419394727760946], 
             UndirectedEdge[212, 293] -> 
             RGBColor[
              0.9747266658557194, 0.9264092508495967, 0.3563182986284954], 
             UndirectedEdge[66, 107] -> 
             RGBColor[
              0.8786883095164575, 0.9055958522402567, 0.9631529511520245], 
             UndirectedEdge[146, 159] -> 
             RGBColor[
              0.9766566041639434, 0.9796804003781476, 0.7952136385611066], 
             UndirectedEdge[11, 207] -> 
             RGBColor[
              0.9609773260531593, 0.9704175341809861, 0.9509393876353364], 
             UndirectedEdge[99, 218] -> 
             RGBColor[
              0.9136951189415587, 0.9306650221175499, 0.8569038604137743], 
             UndirectedEdge[131, 217] -> 
             RGBColor[
              0.9927796435008058, 0.9909230338860981, 0.7432151182186497], 
             UndirectedEdge[81, 163] -> 
             RGBColor[
              0.97795014333748, 0.9813014233210399, 0.8427471210972377], 
             UndirectedEdge[50, 54] -> 
             RGBColor[
              0.9862789372041418, 0.986359284245039, 0.7394560911371454], 
             UndirectedEdge[120, 286] -> 
             RGBColor[
              0.989815763085906, 0.9881241559745458, 0.6779765510668487], 
             UndirectedEdge[17, 253] -> 
             RGBColor[
              0.9913200219544791, 0.9905447370055187, 0.7837813302285273], 
             UndirectedEdge[45, 365] -> 
             RGBColor[
              0.9688794492929451, 0.9744757024011288, 0.8553781476231801], 
             UndirectedEdge[35, 188] -> 
             RGBColor[
              0.9312021331235295, 0.853857081482283, 0.627817449327501], 
             UndirectedEdge[99, 279] -> 
             RGBColor[
              0.8519184093949772, 0.884760631215104, 0.9857379324762767], 
             UndirectedEdge[107, 363] -> 
             RGBColor[
              0.8490748597723994, 0.8824616002296446, 0.9602013592349588], 
             UndirectedEdge[105, 271] -> 
             RGBColor[
              0.8793107395409739, 0.9061477501409643, 0.966538223676676], 
             UndirectedEdge[191, 219] -> 
             RGBColor[
              0.994770024089096, 0.9918734360536905, 0.7194848091918764], 
             UndirectedEdge[177, 339] -> 
             RGBColor[
              0.8417115786556855, 0.8771165192906053, 0.9800783466980783], 
             UndirectedEdge[80, 167] -> 
             RGBColor[
              0.9885356648540982, 0.9895272170442646, 0.8396572323232916], 
             UndirectedEdge[48, 56] -> 
             RGBColor[
              0.9619642604869999, 0.970216710469153, 0.9076749825998038], 
             UndirectedEdge[42, 136] -> 
             RGBColor[
              0.9917379833407638, 0.9886489061373503, 0.6264842560739393], 
             UndirectedEdge[77, 102] -> 
             RGBColor[
              0.5863993301753357, 0.6473472130486492, 0.7539236163890035], 
             UndirectedEdge[73, 203] -> 
             RGBColor[
              0.8891683175644112, 0.9127139841299947, 0.9138186045337795], 
             UndirectedEdge[35, 284] -> 
             RGBColor[
              0.9207231845232968, 0.8123115421849787, 0.6193858413112167], 
             UndirectedEdge[274, 367] -> 
             RGBColor[
              0.9709638371713478, 0.9126643812973428, 0.5186183167625431], 
             UndirectedEdge[33, 310] -> 
             RGBColor[
              0.8445530973104993, 0.8782706561414831, 0.9279820144488169], 
             UndirectedEdge[175, 295] -> 
             RGBColor[
              0.9910789632763655, 0.9905789363016603, 0.7975081956209897], 
             UndirectedEdge[70, 75] -> 
             RGBColor[
              0.8481228467102937, 0.8777308016989303, 0.7222773806054108], 
             UndirectedEdge[57, 258] -> 
             RGBColor[
              0.8538381744301775, 0.8865194248175987, 0.9777191614741526], 
             UndirectedEdge[70, 145] -> 
             RGBColor[
              0.8481993628349513, 0.8778944619526059, 0.7306056885716035], 
             UndirectedEdge[12, 336] -> 
             RGBColor[
              0.9563951036686354, 0.9650154019107062, 0.8741153019311758], 
             UndirectedEdge[18, 216] -> 
             RGBColor[
              0.9917558413181504, 0.9899783053916607, 0.7222848030088118], 
             UndirectedEdge[158, 311] -> 
             RGBColor[
              0.978025268762301, 0.942495450969749, 0.561106145741155], 
             UndirectedEdge[8, 36] -> 
             RGBColor[
              0.9931595700958158, 0.9893010113191228, 0.6075946380154333], 
             UndirectedEdge[119, 200] -> 
             RGBColor[
              0.9594278142332235, 0.966605710072589, 0.8195944695059573], 
             UndirectedEdge[181, 362] -> 
             RGBColor[
              0.8918736221330738, 0.9142385267304745, 0.8873867456554421], 
             UndirectedEdge[9, 306] -> 
             RGBColor[
              0.9462106170336921, 0.9567834761918372, 0.8683198754410477], 
             UndirectedEdge[82, 253] -> 
             RGBColor[
              0.9392759087242915, 0.9525292052310987, 0.9230353761007628], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.9665829743828773, 0.9733393574909236, 0.8850761627882899], 
             UndirectedEdge[146, 314] -> 
             RGBColor[
              0.9690413835137051, 0.9764316950313789, 0.9372890417976615], 
             UndirectedEdge[27, 277] -> 
             RGBColor[
              0.993629791442491, 0.9887830929593976, 0.5480202947644182], 
             UndirectedEdge[6, 302] -> 
             RGBColor[
              0.8637237064598736, 0.8941738546484002, 0.9868639322490397], 
             UndirectedEdge[93, 296] -> 
             RGBColor[
              0.8603577719294212, 0.8909920742573914, 0.9469588757263698], 
             UndirectedEdge[153, 284] -> 
             RGBColor[
              0.9502560280433576, 0.8298576934739029, 0.33419980077357186`], 
             UndirectedEdge[43, 199] -> 
             RGBColor[
              0.9024154181819245, 0.9239133845451398, 0.9519940300098246], 
             UndirectedEdge[213, 250] -> 
             RGBColor[
              0.8680763300919839, 0.8745421148977743, 0.673248740883537], 
             UndirectedEdge[3, 232] -> 
             RGBColor[
              0.9013345059171605, 0.5481856456578367, 0.2809029958524037], 
             UndirectedEdge[5, 235] -> 
             RGBColor[
              0.9761849903259069, 0.9817593852953366, 0.9251967788156559], 
             UndirectedEdge[25, 391] -> 
             RGBColor[
              0.9847119002919682, 0.9876643917256696, 0.8904162651842678], 
             UndirectedEdge[288, 341] -> 
             RGBColor[
              0.9234407183853977, 0.940994523394596, 0.9649600471894779], 
             UndirectedEdge[181, 265] -> 
             RGBColor[
              0.8930148205502343, 0.9131934533109108, 0.7582050998325132], 
             UndirectedEdge[295, 363] -> 
             RGBColor[
              0.8638768332840794, 0.8919782908107414, 0.8669604732949447], 
             UndirectedEdge[278, 284] -> 
             RGBColor[
              0.9145127643737845, 0.8073595217351217, 0.6187934858932486], 
             UndirectedEdge[167, 351] -> 
             RGBColor[
              0.8577462418379964, 0.8884970965375425, 0.9256628973003496], 
             UndirectedEdge[198, 311] -> 
             RGBColor[
              0.9565197477167591, 0.9275498227827816, 0.6464630617079615], 
             UndirectedEdge[54, 328] -> 
             RGBColor[
              0.9772022672868652, 0.9825180687871811, 0.9234747942690775], 
             UndirectedEdge[261, 310] -> 
             RGBColor[
              0.9746034630691689, 0.9803118119365444, 0.915869038859962], 
             UndirectedEdge[68, 319] -> 
             RGBColor[
              0.7614802225338186, 0.810008042598118, 0.8474857401281071], 
             UndirectedEdge[100, 141] -> 
             RGBColor[
              0.9674839159027004, 0.9403089377836924, 0.6376304232714154], 
             UndirectedEdge[139, 325] -> 
             RGBColor[
              0.7647228437552145, 0.7945279114152282, 0.6670565321413126], 
             UndirectedEdge[123, 338] -> 
             RGBColor[
              0.9936455296243081, 0.9916402774442811, 0.7549735491747898], 
             UndirectedEdge[317, 370] -> 
             RGBColor[
              0.8237411629985962, 0.7878233913701213, 0.6215181117606294], 
             UndirectedEdge[160, 400] -> 
             RGBColor[
              0.9692663514499977, 0.9751100167216852, 0.8702072113352759], 
             UndirectedEdge[150, 266] -> 
             RGBColor[
              0.9448483593428272, 0.9555287486076068, 0.8608730782124967], 
             UndirectedEdge[134, 201] -> 
             RGBColor[
              0.9666704696306925, 0.9593396727087837, 0.6806938632178314], 
             UndirectedEdge[161, 251] -> 
             RGBColor[
              0.9896188178838747, 0.9899751286578404, 0.8217065835097062], 
             UndirectedEdge[86, 371] -> 
             RGBColor[
              0.948939072271105, 0.9614394242211615, 0.9713170112089182], 
             UndirectedEdge[105, 350] -> 
             RGBColor[
              0.659129698108453, 0.7317571507684244, 0.9679443972483055], 
             UndirectedEdge[54, 362] -> 
             RGBColor[
              0.9850378549371892, 0.9871907162097038, 0.8577659963218842], 
             UndirectedEdge[4, 208] -> 
             RGBColor[
              0.9663004425692645, 0.9431509013273152, 0.6475403473724028], 
             UndirectedEdge[176, 294] -> 
             RGBColor[
              0.7653641644603987, 0.8171704093115, 0.9771039522099031], 
             UndirectedEdge[113, 170] -> 
             RGBColor[
              0.9789840757933335, 0.9809238459296816, 0.7522056702191315], 
             UndirectedEdge[14, 205] -> 
             RGBColor[
              0.9255144757332159, 0.9385298115472132, 0.7325142137120713], 
             UndirectedEdge[262, 306] -> 
             RGBColor[
              0.9466610398707416, 0.9567771829845226, 0.846858514790439], 
             UndirectedEdge[47, 128] -> 
             RGBColor[
              0.9938929769570586, 0.9905535213749972, 0.6644390049195348], 
             UndirectedEdge[257, 382] -> 
             RGBColor[
              0.993393987267241, 0.9902017191269941, 0.6621353533938356], 
             UndirectedEdge[165, 228] -> 
             RGBColor[
              0.752903265386544, 0.8068930202875024, 0.9760060192788367], 
             UndirectedEdge[72, 341] -> 
             RGBColor[
              0.9374414683068584, 0.9490983010218456, 0.8194353214544763], 
             UndirectedEdge[50, 116] -> 
             RGBColor[
              0.6957820495328145, 0.753997281049497, 0.7523857314564373], 
             UndirectedEdge[230, 247] -> 
             RGBColor[
              0.9213506624823764, 0.9398986693140534, 0.9845472148503229], 
             UndirectedEdge[45, 100] -> 
             RGBColor[
              0.980719893780819, 0.9833062865132367, 0.8353353635877191], 
             UndirectedEdge[95, 386] -> 
             RGBColor[
              0.9948228951432749, 0.9913350211340866, 0.6778822696122284], 
             UndirectedEdge[182, 244] -> 
             RGBColor[
              0.7922046927549451, 0.8342657059769704, 0.799052016872587], 
             UndirectedEdge[104, 382] -> 
             RGBColor[
              0.9054303016410852, 0.9244960293615587, 0.8736347582895639], 
             UndirectedEdge[58, 210] -> 
             RGBColor[
              0.7282606206422352, 0.7866075661513403, 0.9716798697110743], 
             UndirectedEdge[102, 370] -> 
             RGBColor[
              0.4425120326040399, 0.5378608304838945, 0.9524209073369285], 
             UndirectedEdge[1, 161] -> 
             RGBColor[
              0.9741763188133171, 0.9280360190603836, 0.5359515070813683], 
             UndirectedEdge[153, 356] -> 
             RGBColor[
              0.966654965611838, 0.9700989827981112, 0.7035846323301111], 
             UndirectedEdge[1, 154] -> 
             RGBColor[
              0.8481147519307943, 0.8308720464553356, 0.6302598396212555], 
             UndirectedEdge[341, 399] -> 
             RGBColor[
              0.8352500846703754, 0.8717105926360071, 0.9840841836132204], 
             UndirectedEdge[373, 395] -> 
             RGBColor[
              0.69984499748458, 0.6597275971627625, 0.604538038310241], 
             UndirectedEdge[190, 266] -> 
             RGBColor[
              0.9896193786537533, 0.9752949417309238, 0.5625314526277975], 
             UndirectedEdge[73, 85] -> 
             RGBColor[
              0.9698777296382339, 0.9764164717187167, 0.9072589938946249], 
             UndirectedEdge[221, 250] -> 
             RGBColor[
              0.9799180728233039, 0.9439210855515816, 0.37648593438261657`], 
             UndirectedEdge[23, 353] -> 
             RGBColor[
              0.9595995124900748, 0.9671395884819451, 0.8517905923650835], 
             UndirectedEdge[171, 270] -> 
             RGBColor[
              0.9789426063751994, 0.9818103211850252, 0.82506787759112], 
             UndirectedEdge[277, 396] -> 
             RGBColor[
              0.9882128442559858, 0.9717727322841224, 0.4196417959199099], 
             UndirectedEdge[315, 371] -> 
             RGBColor[
              0.948939072271105, 0.9614394242211615, 0.9713170112089182], 
             UndirectedEdge[207, 391] -> 
             RGBColor[
              0.9795381175259851, 0.984260142070913, 0.9195208091015608], 
             UndirectedEdge[160, 247] -> 
             RGBColor[
              0.9687976617717213, 0.9747604687270356, 0.8710005807067521], 
             UndirectedEdge[193, 232] -> 
             RGBColor[
              0.9543320187032351, 0.8479584936675109, 0.32737143025511595`], 
             UndirectedEdge[22, 91] -> 
             RGBColor[
              0.9897737320682307, 0.9895615467505421, 0.784419657729886], 
             UndirectedEdge[78, 247] -> 
             RGBColor[
              0.9449067314492454, 0.9584321110385707, 0.9781427124174054], 
             UndirectedEdge[87, 192] -> 
             RGBColor[
              0.9711080407760924, 0.9779730046338266, 0.9337907301229802], 
             UndirectedEdge[226, 294] -> 
             RGBColor[
              0.7788984379780821, 0.7095424052990398, 0.6074713333307624], 
             UndirectedEdge[177, 311] -> 
             RGBColor[
              0.9530167529980651, 0.924937295057207, 0.6523927180393643], 
             UndirectedEdge[189, 200] -> 
             RGBColor[
              0.9595926347152244, 0.9669582444176816, 0.837534161817628], 
             UndirectedEdge[67, 184] -> 
             RGBColor[
              0.9911031869111739, 0.9900078209607417, 0.7548645539208032], 
             UndirectedEdge[33, 256] -> 
             RGBColor[
              0.7950789982254391, 0.840381535913152, 0.9800662667529084], 
             UndirectedEdge[176, 226] -> 
             RGBColor[
              0.9006795952947655, 0.8052216109270706, 0.619465287947577], 
             UndirectedEdge[145, 162] -> 
             RGBColor[
              0.9300748771702922, 0.7384201447380039, 0.3504631317884147], 
             UndirectedEdge[286, 343] -> 
             RGBColor[
              0.9932925116789336, 0.9880616856493636, 0.5113094739506325], 
             UndirectedEdge[13, 18] -> 
             RGBColor[
              0.9422997395310807, 0.9527646746002834, 0.8030797047085783], 
             UndirectedEdge[86, 308] -> 
             RGBColor[
              0.9194676007750087, 0.7809020281365397, 0.6029453521183125], 
             UndirectedEdge[364, 377] -> 
             RGBColor[
              0.9704978640742375, 0.9527762825698507, 0.6542227597296124], 
             UndirectedEdge[90, 152] -> 
             RGBColor[
              0.897292002223665, 0.9209403025033327, 0.9900657062657615], 
             UndirectedEdge[1, 153] -> 
             RGBColor[
              0.9742483100422776, 0.9247956443675713, 0.35445997662318973`], 
             UndirectedEdge[92, 114] -> 
             RGBColor[
              0.9766983265400502, 0.9821422306033336, 0.9243278345046385], 
             UndirectedEdge[132, 219] -> 
             RGBColor[
              0.9942714443603079, 0.9908070244279558, 0.6652174825907038], 
             UndirectedEdge[107, 215] -> 
             RGBColor[
              0.8455500734660892, 0.879708010377787, 0.9598500414769466], 
             UndirectedEdge[240, 319] -> 
             RGBColor[
              0.96603750119891, 0.9724602856403876, 0.8648507907328065], 
             UndirectedEdge[58, 110] -> 
             RGBColor[
              0.7385506503591857, 0.7942818534658647, 0.9542615334698521], 
             UndirectedEdge[67, 85] -> 
             RGBColor[
              0.9731628884026655, 0.9771938368561075, 0.8105732180669876], 
             UndirectedEdge[125, 344] -> 
             RGBColor[
              0.9499187605324184, 0.9621700741223567, 0.9696586545261358], 
             UndirectedEdge[198, 219] -> 
             RGBColor[
              0.9711438102244622, 0.9762826956366791, 0.8568400499511108], 
             UndirectedEdge[16, 325] -> 
             RGBColor[
              0.8143100652825777, 0.8346876714914575, 0.6710267992648676], 
             UndirectedEdge[119, 390] -> 
             RGBColor[
              0.9823780999713675, 0.950965257644279, 0.4926803414130623], 
             UndirectedEdge[7, 153] -> 
             RGBColor[
              0.993263083342812, 0.9876347688388394, 0.5390559817528477], 
             UndirectedEdge[23, 164] -> 
             RGBColor[
              0.9927538294906179, 0.9911376532688851, 0.7600194287797484], 
             UndirectedEdge[46, 373] -> 
             RGBColor[
              0.7354734305247046, 0.7882892547273703, 0.8011872263153469], 
             UndirectedEdge[301, 316] -> 
             RGBColor[
              0.9933547920311143, 0.9881367008264935, 0.5230368906006122], 
             UndirectedEdge[22, 150] -> 
             RGBColor[
              0.9446945718236444, 0.9549875106126233, 0.8287021385547124], 
             UndirectedEdge[161, 327] -> 
             RGBColor[
              0.9071329300274819, 0.9260824332675721, 0.884499830273785], 
             UndirectedEdge[123, 281] -> 
             RGBColor[
              0.993906609012001, 0.9912711210729452, 0.7159652438662945], 
             UndirectedEdge[111, 160] -> 
             RGBColor[
              0.9905573240302192, 0.9903632250678616, 0.8061531078887298], 
             UndirectedEdge[277, 287] -> 
             RGBColor[
              0.9651124221080976, 0.9698684184479607, 0.7193536092588626], 
             UndirectedEdge[48, 120] -> 
             RGBColor[
              0.9881027633553088, 0.9893482011494541, 0.8468315304713969], 
             UndirectedEdge[6, 224] -> 
             RGBColor[
              0.9310873776752376, 0.9472323247750046, 0.9705627937856645], 
             UndirectedEdge[103, 313] -> 
             RGBColor[
              0.9458756091486864, 0.9545427892811902, 0.7164247831997563], 
             UndirectedEdge[8, 60] -> 
             RGBColor[
              0.8965634124525929, 0.9174840533693114, 0.8688924315814281], 
             UndirectedEdge[284, 392] -> 
             RGBColor[
              0.9515671506434197, 0.8330260247158277, 0.44595780390115614`], 
             UndirectedEdge[218, 279] -> 
             RGBColor[
              0.9333789223146929, 0.946360352624678, 0.8587813191514425], 
             UndirectedEdge[135, 221] -> 
             RGBColor[
              0.9765841866819915, 0.9639416486573222, 0.6579863645716904], 
             UndirectedEdge[95, 309] -> 
             RGBColor[
              0.9474865766956604, 0.9575750581081033, 0.8582548565002308], 
             UndirectedEdge[80, 385] -> 
             RGBColor[
              0.8532530463066779, 0.884143461039006, 0.886966415252281], 
             UndirectedEdge[272, 398] -> 
             RGBColor[
              0.9312448500677561, 0.942027477862386, 0.7053257184190982], 
             UndirectedEdge[33, 264] -> 
             RGBColor[
              0.8321743035195428, 0.8693066449208323, 0.9609409365033922], 
             UndirectedEdge[76, 366] -> 
             RGBColor[
              0.9082177773119713, 0.5801020640255972, 0.4061947258303963], 
             UndirectedEdge[41, 258] -> 
             RGBColor[
              0.9287453214797341, 0.8250566871367653, 0.6135452576763456], 
             UndirectedEdge[174, 232] -> 
             RGBColor[
              0.8834430412518339, 0.8957527383537409, 0.6882239307127278], 
             UndirectedEdge[61, 307] -> 
             RGBColor[
              0.50396989992799, 0.5872590477483217, 0.9583268922379298], 
             UndirectedEdge[35, 392] -> 
             RGBColor[
              0.9636915326951552, 0.9700058269178781, 0.8200289903243614], 
             UndirectedEdge[212, 259] -> 
             RGBColor[
              0.9831051601464917, 0.9533124090670959, 0.5044667158097574], 
             UndirectedEdge[73, 110] -> 
             RGBColor[
              0.9737926404724014, 0.9793362058087607, 0.9006320710246547], 
             UndirectedEdge[122, 228] -> 
             RGBColor[
              0.835406555776163, 0.836175934676145, 0.6512359698992739], 
             UndirectedEdge[41, 203] -> 
             RGBColor[
              0.8515266648515747, 0.7639575992438316, 0.6141959298808244], 
             UndirectedEdge[361, 385] -> 
             RGBColor[
              0.8538461889968827, 0.8843887407844775, 0.8771365058715089], 
             UndirectedEdge[9, 269] -> 
             RGBColor[
              0.7363138169345471, 0.7896672230628187, 0.8492837177946937], 
             UndirectedEdge[192, 228] -> 
             RGBColor[
              0.8307255535108211, 0.8682115888384052, 0.9626552198259493], 
             UndirectedEdge[47, 265] -> 
             RGBColor[
              0.9937136029624839, 0.9889623573260181, 0.5571426614909094], 
             UndirectedEdge[338, 398] -> 
             RGBColor[
              0.9930664733842534, 0.9881497890315785, 0.5844036556204415], 
             UndirectedEdge[71, 79] -> 
             RGBColor[
              0.98895244739497, 0.9888198002258726, 0.7719545558881611], 
             UndirectedEdge[77, 78] -> 
             RGBColor[
              0.9696235407390967, 0.9740410425652593, 0.7758477879119681], 
             UndirectedEdge[89, 164] -> 
             RGBColor[
              0.9920803350847683, 0.9909930292785165, 0.7809128732885862], 
             UndirectedEdge[123, 235] -> 
             RGBColor[
              0.9844771686830027, 0.9864663475060569, 0.845002390836304], 
             UndirectedEdge[72, 393] -> 
             RGBColor[
              0.9922778877534264, 0.9904610307186457, 0.7330300087151405], 
             UndirectedEdge[240, 371] -> 
             RGBColor[
              0.944121359694589, 0.9578463820698762, 0.9794721419402793], 
             UndirectedEdge[196, 303] -> 
             RGBColor[
              0.9478994093259066, 0.9593861241946242, 0.9230230193313759], 
             UndirectedEdge[105, 170] -> 
             RGBColor[
              0.881407185293726, 0.9077112759507517, 0.9629894878578897], 
             UndirectedEdge[195, 208] -> 
             RGBColor[
              0.9621787978338662, 0.9400769854322288, 0.6545172168123201], 
             UndirectedEdge[100, 180] -> 
             RGBColor[
              0.9586294408446462, 0.9686664852367863, 0.954913744866813], 
             UndirectedEdge[39, 355] -> 
             RGBColor[
              0.9095734793856971, 0.9267484866265103, 0.806349557322114], 
             UndirectedEdge[244, 397] -> 
             RGBColor[
              0.8806908417706092, 0.9041944457924155, 0.8073226873024368], 
             UndirectedEdge[225, 355] -> 
             RGBColor[
              0.9093283757829266, 0.9274262645434561, 0.8670464155549977], 
             UndirectedEdge[335, 354] -> 
             RGBColor[
              0.8697938740628901, 0.8970732985440154, 0.8889785818614839], 
             UndirectedEdge[97, 100] -> 
             RGBColor[
              0.9780622270326262, 0.9822072730139388, 0.8793797794263432], 
             UndirectedEdge[2, 107] -> 
             RGBColor[
              0.9484962228336464, 0.9610457279253435, 0.9698678316851104], 
             UndirectedEdge[128, 225] -> 
             RGBColor[
              0.9938854725869194, 0.9917395000255738, 0.7509970733318381], 
             UndirectedEdge[96, 228] -> 
             RGBColor[
              0.8481101446291992, 0.8782626988305813, 0.7656731449817711], 
             UndirectedEdge[262, 307] -> 
             RGBColor[
              0.9068965193851822, 0.9250801350553474, 0.8430630587467599], 
             UndirectedEdge[86, 334] -> 
             RGBColor[
              0.968644488644167, 0.9751391361368529, 0.8933330965996491], 
             UndirectedEdge[255, 399] -> 
             RGBColor[
              0.6410934918619012, 0.7172430538874806, 0.9664366594899545], 
             UndirectedEdge[138, 242] -> 
             RGBColor[
              0.9389181591595268, 0.776851881602568, 0.47957524150478187`], 
             UndirectedEdge[27, 396] -> 
             RGBColor[
              0.9891313212322648, 0.9737372616641162, 0.5196123466050346], 
             UndirectedEdge[163, 209] -> 
             RGBColor[
              0.9850890385173587, 0.9866255996573254, 0.8306628336797646], 
             UndirectedEdge[63, 202] -> 
             RGBColor[
              0.9892095107574722, 0.9875566757144876, 0.6649972069889514], 
             UndirectedEdge[347, 372] -> 
             RGBColor[
              0.9924642484256796, 0.9859341119570367, 0.4514299999176648], 
             UndirectedEdge[174, 275] -> 
             RGBColor[
              0.8816816669560217, 0.8898112092636141, 0.6813813241811226], 
             UndirectedEdge[209, 315] -> 
             RGBColor[
              0.9612020943626981, 0.9705851660182159, 0.950558913516251], 
             UndirectedEdge[177, 374] -> 
             RGBColor[
              0.9070353911910731, 0.7364873894057209, 0.6005874303261646], 
             UndirectedEdge[214, 215] -> 
             RGBColor[
              0.8592901413413705, 0.8887855756885029, 0.8842076800557502], 
             UndirectedEdge[160, 185] -> 
             RGBColor[
              0.9920557986932254, 0.9909828828500569, 0.7813195047945996], 
             UndirectedEdge[63, 268] -> 
             RGBColor[
              0.9851228900102548, 0.9881159469420224, 0.8962157434639548], 
             UndirectedEdge[48, 196] -> 
             RGBColor[
              0.9886147094018161, 0.9895599039960982, 0.8383472596068725], 
             UndirectedEdge[34, 95] -> 
             RGBColor[
              0.9391589200556442, 0.7770640330222396, 0.4751704404029834], 
             UndirectedEdge[84, 333] -> 
             RGBColor[
              0.754567919678166, 0.6278546062700977, 0.5925533963361735], 
             UndirectedEdge[102, 224] -> 
             RGBColor[
              0.5700226307366021, 0.6379583217932474, 0.9421009103655226], 
             UndirectedEdge[105, 326] -> 
             RGBColor[
              0.8943076885092688, 0.916361121386981, 0.8976542154178646], 
             UndirectedEdge[134, 236] -> 
             RGBColor[
              0.9821624114374441, 0.9514917666928426, 0.38520476609076654`], 
             UndirectedEdge[92, 161] -> 
             RGBColor[
              0.9816740827995223, 0.9845942814386353, 0.8595308526303556], 
             UndirectedEdge[77, 185] -> 
             RGBColor[
              0.9924129879823242, 0.989913908693631, 0.6869600813712917], 
             UndirectedEdge[178, 329] -> 
             RGBColor[
              0.9323448154673811, 0.9445991002536898, 0.7836649520979739], 
             UndirectedEdge[185, 400] -> 
             RGBColor[
              0.9681648683707494, 0.9746545251615921, 0.8884616365052527], 
             UndirectedEdge[317, 333] -> 
             RGBColor[
              0.9104136648315775, 0.6753877690986068, 0.24640562739082383`], 
             UndirectedEdge[106, 215] -> 
             RGBColor[
              0.861176448283548, 0.8893271198522272, 0.8356108247495497], 
             UndirectedEdge[14, 340] -> 
             RGBColor[
              0.9214548491607197, 0.9388257608984589, 0.9433332495874195], 
             UndirectedEdge[233, 358] -> 
             RGBColor[
              0.9708852355667197, 0.9093216426438249, 0.47890790074643613`], 
             UndirectedEdge[74, 191] -> 
             RGBColor[
              0.5921094028150502, 0.6539697912054638, 0.8163436758233187], 
             UndirectedEdge[53, 244] -> 
             RGBColor[
              0.9944176657172943, 0.9904682763668937, 0.6337755473803699], 
             UndirectedEdge[4, 16] -> 
             RGBColor[
              0.804857571245257, 0.8479674697466747, 0.9582619799366312], 
             UndirectedEdge[149, 274] -> 
             RGBColor[
              0.9653822294519474, 0.8905351666504329, 0.5141272241743415], 
             UndirectedEdge[326, 335] -> 
             RGBColor[
              0.9904123904090094, 0.9903032912908672, 0.8085550330683624], 
             UndirectedEdge[30, 77] -> 
             RGBColor[
              0.9798890810492269, 0.9429785961689029, 0.4481999296976986], 
             UndirectedEdge[129, 229] -> 
             RGBColor[
              0.963558313756836, 0.9697208850793144, 0.8055289310203191], 
             UndirectedEdge[216, 219] -> 
             RGBColor[
              0.991888587450259, 0.9909137367039575, 0.7840906278193769], 
             UndirectedEdge[138, 233] -> 
             RGBColor[
              0.9948519971371281, 0.9917731629269821, 0.7083734818814629], 
             UndirectedEdge[28, 44] -> 
             RGBColor[
              0.7217280051380792, 0.7154270950549947, 0.6149945763098248], 
             UndirectedEdge[163, 227] -> 
             RGBColor[
              0.9922154418992564, 0.9910488994183941, 0.7786738037272904], 
             UndirectedEdge[15, 335] -> 
             RGBColor[
              0.9918942667807537, 0.9889494436753731, 0.6410424248408666], 
             UndirectedEdge[257, 268] -> 
             RGBColor[
              0.9891183022204355, 0.9884336134800463, 0.7329945197376022], 
             UndirectedEdge[217, 279] -> 
             RGBColor[
              0.933233932641215, 0.945941218274774, 0.8350757683981912], 
             UndirectedEdge[93, 119] -> 
             RGBColor[
              0.9871593909159614, 0.9875812910863366, 0.782825079025989], 
             UndirectedEdge[67, 305] -> 
             RGBColor[
              0.9116008013098091, 0.9285189702979246, 0.8190227893377351], 
             UndirectedEdge[153, 195] -> 
             RGBColor[
              0.9723345824889807, 0.9743348317655653, 0.6939705224384332], 
             UndirectedEdge[50, 135] -> 
             RGBColor[
              0.9826511077785276, 0.9836536549994415, 0.745597060065258], 
             UndirectedEdge[68, 334] -> 
             RGBColor[
              0.7592694974025596, 0.809093850943298, 0.8841231767263107], 
             UndirectedEdge[95, 308] -> 
             RGBColor[
              0.9435517913492903, 0.7970110355855299, 0.47883595988953054`], 
             UndirectedEdge[17, 36] -> 
             RGBColor[
              0.9939650717870869, 0.9895002237144458, 0.5845134911632569], 
             UndirectedEdge[41, 361] -> 
             RGBColor[
              0.9523854225469505, 0.8413875686883528, 0.5153180276016682], 
             UndirectedEdge[117, 371] -> 
             RGBColor[
              0.972023420784144, 0.9754098706006927, 0.7383809809238226], 
             UndirectedEdge[89, 304] -> 
             RGBColor[
              0.8615153927208858, 0.8900557372903766, 0.8631983129210663], 
             UndirectedEdge[267, 272] -> 
             RGBColor[
              0.9039396175253266, 0.8444062131503832, 0.6279686339275128], 
             UndirectedEdge[20, 158] -> 
             RGBColor[
              0.9501337676572739, 0.9605615602327338, 0.8969136779272958], 
             UndirectedEdge[30, 62] -> 
             RGBColor[
              0.974709089550163, 0.9419401913619805, 0.6174241177014845], 
             UndirectedEdge[197, 310] -> 
             RGBColor[
              0.9617783431502624, 0.9707468585002305, 0.9375786215556781], 
             UndirectedEdge[142, 268] -> 
             RGBColor[
              0.8448847194389204, 0.8787694523897864, 0.9388854671569704], 
             UndirectedEdge[78, 213] -> 
             RGBColor[
              0.8516407072935266, 0.884791424256741, 0.9769269937529647], 
             UndirectedEdge[48, 71] -> 
             RGBColor[
              0.9920046109484577, 0.9901949746014298, 0.7264338561114639], 
             UndirectedEdge[262, 269] -> 
             RGBColor[
              0.7367642397715966, 0.7896609298555041, 0.827822357144085], 
             UndirectedEdge[27, 376] -> 
             RGBColor[
              0.9921401261140118, 0.9903847740078038, 0.7339109883558474], 
             UndirectedEdge[245, 292] -> 
             RGBColor[
              0.9227287358462375, 0.9405958757152109, 0.9707538268830571], 
             UndirectedEdge[142, 217] -> 
             RGBColor[
              0.8500667649613232, 0.8805531839919389, 0.8268971572828079], 
             UndirectedEdge[142, 363] -> 
             RGBColor[
              0.7198323997569838, 0.781057808709802, 0.9727098244576926], 
             UndirectedEdge[121, 130] -> 
             RGBColor[
              0.9882298818980723, 0.9881306318602723, 0.7612535796160371], 
             UndirectedEdge[217, 300] -> 
             RGBColor[
              0.9937635056608342, 0.9890690941518525, 0.5625742622425787], 
             UndirectedEdge[25, 109] -> 
             RGBColor[
              0.9855648239365947, 0.9736182791580754, 0.6297259171423664], 
             UndirectedEdge[40, 146] -> 
             RGBColor[
              0.950089237367713, 0.9622972154669893, 0.9693700817114616], 
             UndirectedEdge[18, 140] -> 
             RGBColor[
              0.9923641108680503, 0.9902298404823586, 0.7122042024158349], 
             UndirectedEdge[170, 239] -> 
             RGBColor[
              0.8832048143610189, 0.909115597440608, 0.9631686587235188], 
             UndirectedEdge[152, 333] -> 
             RGBColor[
              0.8730642254201824, 0.7209963140511593, 0.6041311804089511], 
             UndirectedEdge[14, 250] -> 
             RGBColor[
              0.9181413204875353, 0.9139608258447087, 0.6781571342902488], 
             UndirectedEdge[55, 159] -> 
             RGBColor[
              0.985211880709247, 0.960584453436307, 0.49857109481093786`], 
             UndirectedEdge[234, 331] -> 
             RGBColor[
              0.7206215605436319, 0.7761373809421585, 0.8074174730941169], 
             UndirectedEdge[370, 389] -> 
             RGBColor[
              0.6856528376073991, 0.7543564749842528, 0.9693031251287904], 
             UndirectedEdge[119, 316] -> 
             RGBColor[
              0.9934718455914185, 0.9883870665560539, 0.5357774482688878], 
             UndirectedEdge[89, 227] -> 
             RGBColor[
              0.9916691275634192, 0.9908229844008873, 0.7877276460882943], 
             UndirectedEdge[246, 254] -> 
             RGBColor[
              0.819549422918462, 0.8592717887605055, 0.9509656943148368], 
             UndirectedEdge[197, 345] -> 
             RGBColor[
              0.9651360793417161, 0.9697535292428603, 0.708797658378238], 
             UndirectedEdge[231, 234] -> 
             RGBColor[
              0.6858428423026942, 0.7521710552657814, 0.9711983094710751], 
             UndirectedEdge[89, 209] -> 
             RGBColor[
              0.9845427241815214, 0.9863996846398186, 0.8397166760407682], 
             UndirectedEdge[233, 317] -> 
             RGBColor[
              0.9681214908750065, 0.8983643159045052, 0.4766841268940579], 
             UndirectedEdge[48, 342] -> 
             RGBColor[
              0.9842569632682036, 0.9652269213878508, 0.5971380253021391], 
             UndirectedEdge[24, 104] -> 
             RGBColor[
              0.9029017698395001, 0.9234504164813, 0.9155390738723692], 
             UndirectedEdge[118, 149] -> 
             RGBColor[
              0.9644688319967041, 0.8901574533294458, 0.5292645838045635], 
             UndirectedEdge[34, 53] -> 
             RGBColor[
              0.9387183634902441, 0.7761217270759504, 0.4272185770591548], 
             UndirectedEdge[29, 45] -> 
             RGBColor[
              0.9187102930709133, 0.9346480845314997, 0.8566917227001036], 
             UndirectedEdge[35, 208] -> 
             RGBColor[
              0.9522246254399784, 0.9325796493426171, 0.6688176815706641], 
             UndirectedEdge[69, 191] -> 
             RGBColor[
              0.9908994417882695, 0.9902728508028708, 0.7836303746624722], 
             UndirectedEdge[102, 166] -> 
             RGBColor[
              0.5250209728583164, 0.6027307141009475, 0.9605349576237933], 
             UndirectedEdge[185, 213] -> 
             RGBColor[
              0.8744301545367542, 0.9006642903851128, 0.8880392872122882], 
             UndirectedEdge[172, 364] -> 
             RGBColor[
              0.9737955643756591, 0.9639002000233978, 0.6670337026821873], 
             UndirectedEdge[36, 55] -> 
             RGBColor[
              0.9843948172282472, 0.9588368372682383, 0.4096387772354105], 
             UndirectedEdge[192, 203] -> 
             RGBColor[
              0.8746363106641959, 0.9025150060607365, 0.9670318337296415], 
             UndirectedEdge[105, 394] -> 
             RGBColor[
              0.8968628505424998, 0.9173029232755809, 0.8469621278919], 
             UndirectedEdge[256, 261] -> 
             RGBColor[
              0.9251293639841086, 0.9424226917082132, 0.9679532911640536], 
             UndirectedEdge[215, 295] -> 
             RGBColor[
              0.8603520469777691, 0.8892247009588838, 0.8666091555369324], 
             UndirectedEdge[219, 357] -> 
             RGBColor[
              0.8423592264949633, 0.8749534686914516, 0.8550620635994839], 
             UndirectedEdge[204, 295] -> 
             RGBColor[
              0.9846134007659563, 0.986522682973363, 0.8427446726644332], 
             UndirectedEdge[24, 138] -> 
             RGBColor[
              0.991421070636655, 0.9907204064868981, 0.7918385913155257], 
             UndirectedEdge[135, 376] -> 
             RGBColor[
              0.9806554391255327, 0.9841730461014921, 0.8764124144736867], 
             UndirectedEdge[127, 305] -> 
             RGBColor[
              0.907347991866693, 0.9273414567374095, 0.9317450411108604], 
             UndirectedEdge[54, 158] -> 
             RGBColor[
              0.9848032078258208, 0.9870936835989972, 0.8616547062045179], 
             UndirectedEdge[180, 350] -> 
             RGBColor[
              0.7353700868727215, 0.7919800854126334, 0.9615306986151586], 
             UndirectedEdge[46, 287] -> 
             RGBColor[
              0.966042210701191, 0.9718571422325408, 0.8205553596270341], 
             UndirectedEdge[41, 153] -> 
             RGBColor[
              0.9523339998278659, 0.8380961591564302, 0.3358717856476541], 
             UndirectedEdge[163, 315] -> 
             RGBColor[
              0.9709855023180762, 0.9761072054523215, 0.8545364416737906], 
             UndirectedEdge[17, 64] -> 
             RGBColor[
              0.9950948938290918, 0.9919167988197632, 0.7074876479820862], 
             UndirectedEdge[67, 127] -> 
             RGBColor[
              0.9903555595519977, 0.9896986578345754, 0.7672546740599366], 
             UndirectedEdge[83, 246] -> 
             RGBColor[
              0.7156359033658151, 0.7753078689853339, 0.9425132930150455], 
             UndirectedEdge[44, 383] -> 
             RGBColor[
              0.9665915245549226, 0.9087372582329427, 0.5807094121483818], 
             UndirectedEdge[5, 275] -> 
             RGBColor[
              0.979163593412558, 0.966177747568904, 0.6542832288008624], 
             UndirectedEdge[99, 123] -> 
             RGBColor[
              0.9126594431592272, 0.9302367435659022, 0.8740676883700162], 
             UndirectedEdge[278, 354] -> 
             RGBColor[
              0.8346141349375689, 0.8715380137701249, 0.9839347574411612], 
             UndirectedEdge[61, 215] -> 
             RGBColor[
              0.4582764535631673, 0.5515629801650674, 0.9537725965338182], 
             UndirectedEdge[115, 208] -> 
             RGBColor[
              0.957237976478982, 0.9363921289556087, 0.6628807385935468], 
             UndirectedEdge[167, 203] -> 
             RGBColor[
              0.8882700498489273, 0.9123425273452148, 0.9287052252216756], 
             UndirectedEdge[242, 256] -> 
             RGBColor[
              0.8849237093782889, 0.7370934801936535, 0.6065734031371384], 
             UndirectedEdge[136, 254] -> 
             RGBColor[
              0.8305266291581704, 0.8638377352045132, 0.7087682161940729], 
             UndirectedEdge[65, 170] -> 
             RGBColor[
              0.9637295993902888, 0.9302245392147265, 0.6285220239779674], 
             UndirectedEdge[247, 340] -> 
             RGBColor[
              0.9646558829208871, 0.9730477367333543, 0.9396405748451484], 
             UndirectedEdge[8, 17] -> 
             RGBColor[
              0.9943213049214903, 0.991785844641832, 0.7340423043938124], 
             UndirectedEdge[269, 300] -> 
             RGBColor[
              0.7355655209014216, 0.7870969914012689, 0.6973492057608879], 
             UndirectedEdge[233, 242] -> 
             RGBColor[
              0.938923882983299, 0.7764882287121426, 0.45287460456403306`], 
             UndirectedEdge[242, 382] -> 
             RGBColor[
              0.9380214882844109, 0.7764810851523172, 0.4944353984152907], 
             UndirectedEdge[144, 242] -> 
             RGBColor[
              0.8836022437413193, 0.5643467988635391, 0.22458719781871905`], 
             UndirectedEdge[81, 227] -> 
             RGBColor[
              0.9752931387639996, 0.9802026836480029, 0.8867805629872241], 
             UndirectedEdge[224, 230] -> 
             RGBColor[
              0.929690772333494, 0.9461187095853403, 0.9704295843214046], 
             UndirectedEdge[81, 248] -> 
             RGBColor[
              0.9754655739682883, 0.9740294175509256, 0.6830652834079125], 
             UndirectedEdge[13, 323] -> 
             RGBColor[
              0.9253344960687022, 0.8966220960892568, 0.6448978017057673], 
             UndirectedEdge[10, 189] -> 
             RGBColor[
              0.7610602376524105, 0.8092566792048839, 0.8191756299057051], 
             UndirectedEdge[135, 364] -> 
             RGBColor[
              0.9680144964483679, 0.9756658443394237, 0.9390272937442365], 
             UndirectedEdge[39, 383] -> 
             RGBColor[
              0.9900922114477859, 0.9893917545066107, 0.7572263698252425], 
             UndirectedEdge[108, 196] -> 
             RGBColor[
              0.8725846073612955, 0.8998367293707028, 0.9157055252339907], 
             UndirectedEdge[75, 89] -> 
             RGBColor[
              0.993362444260826, 0.9895071768137764, 0.6131203581756204], 
             UndirectedEdge[131, 269] -> 
             RGBColor[
              0.7345816587413934, 0.7889509311355145, 0.8779900617369589], 
             UndirectedEdge[36, 165] -> 
             RGBColor[
              0.8980663991893394, 0.9166508691358619, 0.7195489280122314], 
             UndirectedEdge[40, 41] -> 
             RGBColor[
              0.9270287381857648, 0.82377646212677, 0.6164509854364092], 
             UndirectedEdge[86, 249] -> 
             RGBColor[
              0.7258964516030268, 0.7844197015983971, 0.9642915277948932], 
             UndirectedEdge[287, 395] -> 
             RGBColor[
              0.9304137776610664, 0.843295484667933, 0.6239061716219282], 
             UndirectedEdge[177, 225] -> 
             RGBColor[
              0.9673217372995797, 0.9735382208729098, 0.8680576579069845], 
             UndirectedEdge[74, 216] -> 
             RGBColor[
              0.5892279661762132, 0.6530100918557309, 0.8809494944508192], 
             UndirectedEdge[229, 371] -> 
             RGBColor[
              0.9418135764769133, 0.95605171050807, 0.9808292643209907], 
             UndirectedEdge[319, 371] -> 
             RGBColor[
              0.9726957278831153, 0.9774259801996223, 0.8535801497000868], 
             UndirectedEdge[169, 353] -> 
             RGBColor[
              0.9579991930919451, 0.9633606647625794, 0.7078775715406294], 
             UndirectedEdge[47, 362] -> 
             RGBColor[
              0.9925724045453234, 0.9900074307455817, 0.6863243073138383], 
             UndirectedEdge[83, 313] -> 
             RGBColor[
              0.6797936048583822, 0.7476326925130508, 0.9704541861227343], 
             UndirectedEdge[87, 210] -> 
             RGBColor[
              0.9611046069655076, 0.9705124600770121, 0.9507239342509092], 
             UndirectedEdge[91, 150] -> 
             RGBColor[
              0.9397399729851605, 0.9534162995691705, 0.9455322602391474], 
             UndirectedEdge[16, 258] -> 
             RGBColor[
              0.7967259192878999, 0.8419028970312359, 0.9720267456259393], 
             UndirectedEdge[334, 388] -> 
             RGBColor[
              0.9689856141950153, 0.9753935470141337, 0.8927556600218556], 
             UndirectedEdge[67, 325] -> 
             RGBColor[
              0.9872562789516797, 0.9673752116205409, 0.5154822101405915], 
             UndirectedEdge[279, 363] -> 
             RGBColor[
              0.8029995674368756, 0.8464458429926369, 0.9808884355730759], 
             UndirectedEdge[192, 385] -> 
             RGBColor[
              0.8373251583031316, 0.8733672502610124, 0.9633130067548334], 
             UndirectedEdge[216, 339] -> 
             RGBColor[
              0.8659593506001764, 0.8943600880834582, 0.9013992682349414], 
             UndirectedEdge[74, 323] -> 
             RGBColor[
              0.5747681893128738, 0.5970230507957115, 0.6172397542066356], 
             UndirectedEdge[60, 87] -> 
             RGBColor[
              0.8914265327806654, 0.9152019993889873, 0.946956219914509], 
             UndirectedEdge[74, 198] -> 
             RGBColor[
              0.5684831889504163, 0.6383790507884524, 0.9536989165825532], 
             UndirectedEdge[16, 348] -> 
             RGBColor[
              0.8211715873476824, 0.8571393559643915, 0.7566817144045543], 
             UndirectedEdge[88, 283] -> 
             RGBColor[
              0.8413154206934939, 0.8768318899078591, 0.9812968770996053], 
             UndirectedEdge[292, 388] -> 
             RGBColor[
              0.9538968388002835, 0.9651369183810252, 0.9629248056676205], 
             UndirectedEdge[76, 382] -> 
             RGBColor[
              0.9937811628954447, 0.9910298486462609, 0.7042770311527994], 
             UndirectedEdge[131, 352] -> 
             RGBColor[
              0.9691136400015214, 0.9754054260965367, 0.8887950614832962], 
             UndirectedEdge[123, 232] -> 
             RGBColor[
              0.9892171460654662, 0.9768262388697511, 0.5809314473531156], 
             UndirectedEdge[69, 357] -> 
             RGBColor[
              0.8384886441941368, 0.8733528834406319, 0.9192076290700797], 
             UndirectedEdge[241, 339] -> 
             RGBColor[
              0.8675966297145921, 0.8926586602920756, 0.701374581124395], 
             UndirectedEdge[181, 322] -> 
             RGBColor[
              0.8584952497670802, 0.7880719668299258, 0.6190249237863349], 
             UndirectedEdge[140, 168] -> 
             RGBColor[
              0.8251989921314707, 0.8622941365528038, 0.8871954294128785], 
             UndirectedEdge[88, 357] -> 
             RGBColor[
              0.8147713846235094, 0.8560954871878412, 0.9786512156522695], 
             UndirectedEdge[125, 179] -> 
             RGBColor[
              0.8942100588437281, 0.9183517416777636, 0.9852263302853492], 
             UndirectedEdge[316, 324] -> 
             RGBColor[
              0.9127325692715166, 0.6205733668188436, 0.3021489321128873], 
             UndirectedEdge[128, 390] -> 
             RGBColor[
              0.9820517573023873, 0.9514747448857117, 0.5449325469351998], 
             UndirectedEdge[200, 339] -> 
             RGBColor[
              0.8334944841024596, 0.8706948070970157, 0.9838148091248611], 
             UndirectedEdge[85, 110] -> 
             RGBColor[
              0.9556323186443845, 0.9664312364071683, 0.9599870909771936], 
             UndirectedEdge[178, 209] -> 
             RGBColor[
              0.9230367745518253, 0.9404471391878004, 0.9571105605040344], 
             UndirectedEdge[380, 383] -> 
             RGBColor[
              0.9892847202745267, 0.9876646125368908, 0.6693359388738632], 
             UndirectedEdge[350, 357] -> 
             RGBColor[
              0.6049371241491286, 0.6894215001125834, 0.9625429879344369], 
             UndirectedEdge[98, 352] -> 
             RGBColor[
              0.9698624846960606, 0.9757150926221595, 0.8763847669468348], 
             UndirectedEdge[68, 151] -> 
             RGBColor[
              0.7610442913277637, 0.8084975171328678, 0.7580146285528768], 
             UndirectedEdge[307, 385] -> 
             RGBColor[
              0.7672052605815539, 0.8180658476330336, 0.9774315085001314], 
             UndirectedEdge[94, 119] -> 
             RGBColor[
              0.9851682485411228, 0.9860963003633785, 0.7861955636934874], 
             UndirectedEdge[116, 121] -> 
             RGBColor[
              0.6960091230654988, 0.7544829683752527, 0.7771012841537125], 
             UndirectedEdge[1, 361] -> 
             RGBColor[
              0.9742997327613621, 0.928087053899494, 0.5339062185772039], 
             UndirectedEdge[180, 239] -> 
             RGBColor[
              0.8766148185587304, 0.904200789361389, 0.9743238026706176], 
             UndirectedEdge[45, 394] -> 
             RGBColor[
              0.9951936922429412, 0.9921656591962403, 0.7209700479796591], 
             UndirectedEdge[32, 124] -> 
             RGBColor[
              0.8630449679253112, 0.8498883584409975, 0.6424851209565239], 
             UndirectedEdge[87, 243] -> 
             RGBColor[
              0.9709863005038908, 0.9778822109381502, 0.9339968046488691], 
             UndirectedEdge[188, 195] -> 
             RGBColor[
              0.9411563055174172, 0.8613544175718949, 0.6135169845691569], 
             UndirectedEdge[122, 262] -> 
             RGBColor[
              0.9816974193721019, 0.9483458835210661, 0.5175253070747867], 
             UndirectedEdge[118, 212] -> 
             RGBColor[
              0.9815172569589331, 0.9531528883276367, 0.5669176143506138], 
             UndirectedEdge[35, 258] -> 
             RGBColor[
              0.9387917317469612, 0.9537980236562884, 0.9859444592254686], 
             UndirectedEdge[183, 271] -> 
             RGBColor[
              0.977363462610382, 0.9808954768603684, 0.8451552892286032], 
             UndirectedEdge[130, 147] -> 
             RGBColor[
              0.8871241083982879, 0.9118579047391316, 0.9473875255696944], 
             UndirectedEdge[124, 330] -> 
             RGBColor[
              0.8692686804226241, 0.8980432773705209, 0.9523994596048864], 
             UndirectedEdge[46, 395] -> 
             RGBColor[
              0.9589424586122741, 0.8622343535839561, 0.45380405681053027`], 
             UndirectedEdge[206, 284] -> 
             RGBColor[
              0.9465727236612784, 0.831604697371386, 0.5755401359577798], 
             UndirectedEdge[179, 313] -> 
             RGBColor[
              0.8733634794729859, 0.901860347984388, 0.9877833824045572], 
             UndirectedEdge[215, 363] -> 
             RGBColor[
              0.7308721357993297, 0.7896821344111842, 0.9738101621741947], 
             UndirectedEdge[260, 338] -> 
             RGBColor[
              0.9876509090665753, 0.98864683007842, 0.8312787710988655], 
             UndirectedEdge[88, 113] -> 
             RGBColor[
              0.9665408490824414, 0.9716437078226121, 0.7732688073273799], 
             UndirectedEdge[95, 270] -> 
             RGBColor[
              0.9951572938160292, 0.9920502660822158, 0.7142795014721379], 
             UndirectedEdge[16, 184] -> 
             RGBColor[
              0.8181569732420718, 0.8573202808316583, 0.9104091430450794], 
             UndirectedEdge[38, 78] -> 
             RGBColor[
              0.9623196962945562, 0.9502481535507197, 0.6756471085774833], 
             UndirectedEdge[8, 210] -> 
             RGBColor[
              0.9662414866374351, 0.9727945140573362, 0.8726601459178284], 
             UndirectedEdge[1, 96] -> 
             RGBColor[
              0.975163293185989, 0.9271166733682049, 0.4231006446163504], 
             UndirectedEdge[213, 247] -> 
             RGBColor[
              0.8511720176152502, 0.8844418762620914, 0.9777203631244409], 
             UndirectedEdge[109, 366] -> 
             RGBColor[
              0.9030645058793019, 0.5639571516767321, 0.28088065594649914`], 
             UndirectedEdge[223, 260] -> 
             RGBColor[
              0.765246482497735, 0.8152431519097536, 0.937277555281022], 
             UndirectedEdge[393, 399] -> 
             RGBColor[
              0.8900865041169433, 0.9130733223328074, 0.8976788708738845], 
             UndirectedEdge[25, 358] -> 
             RGBColor[
              0.9669197733416511, 0.908047841944679, 0.5712316504711579], 
             UndirectedEdge[207, 358] -> 
             RGBColor[
              0.961745990575668, 0.9046435922899224, 0.6003361943884509], 
             UndirectedEdge[31, 33] -> 
             RGBColor[
              0.8445904692400644, 0.878286110394773, 0.9273626648604714], 
             UndirectedEdge[355, 375] -> 
             RGBColor[
              0.8874172839524419, 0.9126959729600375, 0.9762784750716385], 
             UndirectedEdge[25, 104] -> 
             RGBColor[
              0.9023672341149047, 0.9232293722222382, 0.9243977141630282], 
             UndirectedEdge[360, 375] -> 
             RGBColor[
              0.9720747373462766, 0.9760163598281426, 0.7833797372365408], 
             UndirectedEdge[28, 347] -> 
             RGBColor[
              0.7440023504519081, 0.7931025683493842, 0.6883036908471774], 
             UndirectedEdge[56, 143] -> 
             RGBColor[
              0.963600672988093, 0.9708934090922381, 0.8805553925568902], 
             UndirectedEdge[73, 115] -> 
             RGBColor[
              0.9654561600596451, 0.9731188723666608, 0.9147435578611365], 
             UndirectedEdge[157, 218] -> 
             RGBColor[
              0.9944932561888338, 0.9919908341642915, 0.7409245261545739], 
             UndirectedEdge[267, 321] -> 
             RGBColor[
              0.9607592770470347, 0.8737796649261518, 0.33077621840206606`], 
             UndirectedEdge[93, 324] -> 
             RGBColor[
              0.9064201145960594, 0.6197675913491264, 0.5491965628699884], 
             UndirectedEdge[178, 245] -> 
             RGBColor[
              0.8781062609493451, 0.9056421131942631, 0.9882357531357034], 
             UndirectedEdge[223, 331] -> 
             RGBColor[
              0.7720519723902217, 0.8180750234682724, 0.8114153913587152], 
             UndirectedEdge[318, 367] -> 
             RGBColor[
              0.9021743183517015, 0.8608229177313982, 0.6317916012888112], 
             UndirectedEdge[158, 265] -> 
             RGBColor[
              0.9921477078871304, 0.9895039013711742, 0.6695272968744772], 
             UndirectedEdge[124, 199] -> 
             RGBColor[
              0.7949177929045458, 0.83976373256614, 0.9801807260960678], 
             UndirectedEdge[38, 213] -> 
             RGBColor[
              0.8685849824605609, 0.8762579187742403, 0.6752247592845189], 
             UndirectedEdge[128, 296] -> 
             RGBColor[
              0.867407025087249, 0.8946394845898973, 0.8629312192044087], 
             UndirectedEdge[89, 315] -> 
             RGBColor[
              0.9704391879822389, 0.9758812904348149, 0.8635902840347942], 
             UndirectedEdge[129, 178] -> 
             RGBColor[
              0.9325184897401548, 0.9449705719619905, 0.80256832489603], 
             UndirectedEdge[61, 279] -> 
             RGBColor[
              0.5304038852007131, 0.6083266887465202, 0.9608508699326994], 
             UndirectedEdge[7, 332] -> 
             RGBColor[
              0.9672475447908173, 0.9727853484527524, 0.8208374950801653], 
             UndirectedEdge[105, 180] -> 
             RGBColor[
              0.8748171894914374, 0.9027964678715328, 0.9741446318049884], 
             UndirectedEdge[75, 163] -> 
             RGBColor[
              0.9939087585966632, 0.9897330918312831, 0.6040665158146167], 
             UndirectedEdge[15, 273] -> 
             RGBColor[
              0.993479293310561, 0.9896048928787722, 0.6147744333247918], 
             UndirectedEdge[149, 287] -> 
             RGBColor[
              0.9374606220956796, 0.8712338746294712, 0.6295762280647161], 
             UndirectedEdge[123, 275] -> 
             RGBColor[
              0.9874557717696538, 0.9708847097796243, 0.5740888408215106], 
             UndirectedEdge[186, 226] -> 
             RGBColor[
              0.95370330145938, 0.8445233208879428, 0.5061551058868374], 
             UndirectedEdge[15, 183] -> 
             RGBColor[
              0.993842287950421, 0.989755000490891, 0.608758672742296], 
             UndirectedEdge[35, 41] -> 
             RGBColor[
              0.9228011563078051, 0.8205500078675059, 0.6210578261852988], 
             UndirectedEdge[47, 54] -> 
             RGBColor[
              0.9863691029011743, 0.9865521395538411, 0.7492700708209501], 
             UndirectedEdge[19, 196] -> 
             RGBColor[
              0.9913372490740082, 0.990495162676116, 0.7793744726865981], 
             UndirectedEdge[211, 328] -> 
             RGBColor[
              0.9804864829977258, 0.9847662429284202, 0.9089058390287899], 
             UndirectedEdge[3, 86] -> 
             RGBColor[
              0.8822087790817078, 0.547096885906606, 0.5693252607551386], 
             UndirectedEdge[55, 58] -> 
             RGBColor[
              0.7467701843674506, 0.7749355102896285, 0.6581873142592118], 
             UndirectedEdge[63, 214] -> 
             RGBColor[
              0.988488575870359, 0.9895077445393567, 0.8404376186462326], 
             UndirectedEdge[26, 106] -> 
             RGBColor[
              0.9938347436512045, 0.9892214650099891, 0.570328077864475], 
             UndirectedEdge[89, 378] -> 
             RGBColor[
              0.9897620181760294, 0.990034345658726, 0.8193333840782293], 
             UndirectedEdge[191, 311] -> 
             RGBColor[
              0.980145961581393, 0.9431405631997929, 0.509107820948727], 
             UndirectedEdge[147, 364] -> 
             RGBColor[
              0.8782080098179836, 0.9052082930167122, 0.9624801547752057], 
             UndirectedEdge[137, 285] -> 
             RGBColor[
              0.9715379610119892, 0.9271423048006977, 0.5810397541286293], 
             UndirectedEdge[104, 205] -> 
             RGBColor[
              0.905400324467422, 0.9225089237632536, 0.7305910400433087], 
             UndirectedEdge[191, 339] -> 
             RGBColor[
              0.8688407872390134, 0.8953197874331913, 0.8367934496074408], 
             UndirectedEdge[40, 167] -> 
             RGBColor[
              0.9637721231831173, 0.9721613902281533, 0.9309602807772603], 
             UndirectedEdge[17, 262] -> 
             RGBColor[
              0.9950928015802303, 0.9919123237110072, 0.707259919605375], 
             UndirectedEdge[96, 348] -> 
             RGBColor[
              0.9936852264705158, 0.9889016628790019, 0.5540540554595996], 
             UndirectedEdge[60, 122] -> 
             RGBColor[
              0.8839735319357355, 0.8741168255746931, 0.6560766721986635], 
             UndirectedEdge[99, 187] -> 
             RGBColor[
              0.8197618796928976, 0.8592224950157434, 0.9826435850330071], 
             UndirectedEdge[111, 166] -> 
             RGBColor[
              0.9295361560022988, 0.9446777519637342, 0.9184050257002119], 
             UndirectedEdge[130, 172] -> 
             RGBColor[
              0.9827116629559633, 0.9705498117458173, 0.651941073476676], 
             UndirectedEdge[205, 230] -> 
             RGBColor[
              0.9456281302047908, 0.9545678936522407, 0.7344326720312415], 
             UndirectedEdge[248, 319] -> 
             RGBColor[
              0.9922575885608949, 0.9848217556606682, 0.5771177424756339], 
             UndirectedEdge[77, 111] -> 
             RGBColor[
              0.9909145133193181, 0.9892942509114357, 0.7117936844654221], 
             UndirectedEdge[41, 188] -> 
             RGBColor[
              0.9211557228563025, 0.7251157449627599, 0.25541824777837796`], 
             UndirectedEdge[57, 278] -> 
             RGBColor[
              0.8416835891087362, 0.8770607250984825, 0.9846393745651378], 
             UndirectedEdge[56, 331] -> 
             RGBColor[
              0.9645092677402998, 0.9707722452564413, 0.8293788874861923], 
             UndirectedEdge[40, 87] -> 
             RGBColor[
              0.9622723871086578, 0.971383388595709, 0.9487471870743965], 
             UndirectedEdge[142, 214] -> 
             RGBColor[
              0.8482504052990245, 0.8801612499871208, 0.8831073423392481], 
             UndirectedEdge[341, 368] -> 
             RGBColor[
              0.9336579855904781, 0.9481474253527844, 0.9267463270081631], 
             UndirectedEdge[96, 188] -> 
             RGBColor[
              0.9616499597873018, 0.8737242617718408, 0.4112720767830169], 
             UndirectedEdge[142, 202] -> 
             RGBColor[
              0.8489713401861378, 0.8782101811622515, 0.707666930681967], 
             UndirectedEdge[37, 351] -> 
             RGBColor[
              0.8526964491695372, 0.8850714685099774, 0.949459123408078], 
             UndirectedEdge[83, 108] -> 
             RGBColor[
              0.6090265753026098, 0.6917095679619438, 0.9635704626175484], 
             UndirectedEdge[72, 119] -> 
             RGBColor[
              0.9945528070362009, 0.9907573299831516, 0.6484848459478048], 
             UndirectedEdge[170, 180] -> 
             RGBColor[
              0.9576475740579945, 0.9679342105949608, 0.9565757892247428], 
             UndirectedEdge[196, 234] -> 
             RGBColor[
              0.7170752582326289, 0.7751677849164007, 0.902307618582416], 
             UndirectedEdge[218, 306] -> 
             RGBColor[
              0.9467094575275292, 0.9569897595556549, 0.8600527975003521], 
             UndirectedEdge[186, 189] -> 
             RGBColor[
              0.994028680906541, 0.991438658864435, 0.7224510721552352], 
             UndirectedEdge[20, 135] -> 
             RGBColor[
              0.940537283698879, 0.9544976724061022, 0.9621117004798867], 
             UndirectedEdge[79, 254] -> 
             RGBColor[
              0.8259180333422894, 0.8640214879869536, 0.9401852980669185], 
             UndirectedEdge[93, 355] -> 
             RGBColor[
              0.9022759514429883, 0.9237775428456518, 0.951126626771286], 
             UndirectedEdge[211, 301] -> 
             RGBColor[
              0.9898519321684612, 0.9892251280093654, 0.75631897549688], 
             UndirectedEdge[145, 227] -> 
             RGBColor[
              0.9913282701478404, 0.9887980124119218, 0.6564282656707957], 
             UndirectedEdge[26, 345] -> 
             RGBColor[
              0.9925924922661202, 0.9865644149081754, 0.43511668088494726`], 
             UndirectedEdge[132, 140] -> 
             RGBColor[
              0.9922415011790601, 0.9899675907553496, 0.6988588944285347], 
             UndirectedEdge[153, 258] -> 
             RGBColor[
              0.968324575267022, 0.9713441749452127, 0.7007584186878237], 
             UndirectedEdge[56, 344] -> 
             RGBColor[
              0.9466835096739048, 0.9597214757378547, 0.9738954908806587], 
             UndirectedEdge[44, 390] -> 
             RGBColor[
              0.9587993451944049, 0.8701437820603963, 0.30766617633112825`], 
             UndirectedEdge[223, 346] -> 
             RGBColor[
              0.7639658148888546, 0.8142880321039514, 0.9394453914912493], 
             UndirectedEdge[114, 222] -> 
             RGBColor[
              0.7625750321751272, 0.813050481577567, 0.936427113601484], 
             UndirectedEdge[85, 203] -> 
             RGBColor[
              0.8710079957363942, 0.8998090147284024, 0.9731736244863185], 
             UndirectedEdge[156, 261] -> 
             RGBColor[
              0.963401354217337, 0.9722253704168481, 0.9468361402411827], 
             UndirectedEdge[33, 295] -> 
             RGBColor[
              0.8483286835812582, 0.8798319580925833, 0.8654107790382874], 
             UndirectedEdge[59, 395] -> 
             RGBColor[
              0.9591636470554812, 0.8627074532983938, 0.477879053836778], 
             UndirectedEdge[334, 371] -> 
             RGBColor[
              0.9704850027518563, 0.9765117885448024, 0.8902175862982904], 
             UndirectedEdge[40, 154] -> 
             RGBColor[
              0.8404744338615694, 0.8761403520229818, 0.9794640094459534], 
             UndirectedEdge[300, 306] -> 
             RGBColor[
              0.9454623210005666, 0.9542132445302874, 0.7163853634072419], 
             UndirectedEdge[61, 297] -> 
             RGBColor[
              0.5870007635134633, 0.638286395919309, 0.6647609950481209], 
             UndirectedEdge[97, 350] -> 
             RGBColor[
              0.7548028730607017, 0.805520873189786, 0.8859967331746887], 
             UndirectedEdge[178, 229] -> 
             RGBColor[
              0.901807742558351, 0.9245410312697051, 0.9904964216101328], 
             UndirectedEdge[130, 265] -> 
             RGBColor[
              0.9879029245155961, 0.9874313030796178, 0.725666286280572], 
             UndirectedEdge[110, 134] -> 
             RGBColor[
              0.9716308567768468, 0.963039121320497, 0.6722972216555603], 
             UndirectedEdge[147, 211] -> 
             RGBColor[
              0.8886844529479022, 0.9128204185908932, 0.9357366345477901], 
             UndirectedEdge[78, 185] -> 
             RGBColor[
              0.9681648683707494, 0.9746545251615921, 0.8884616365052527], 
             UndirectedEdge[130, 135] -> 
             RGBColor[
              0.9769305950286722, 0.9823154560618432, 0.9239346645387253], 
             UndirectedEdge[52, 384] -> 
             RGBColor[
              0.9693447548150873, 0.974319990111173, 0.8149504052179559], 
             UndirectedEdge[77, 166] -> 
             RGBColor[
              0.9324933030336522, 0.9446839271495967, 0.7809575740127968], 
             UndirectedEdge[24, 76] -> 
             RGBColor[
              0.9912526310938596, 0.9899842357660023, 0.7461813467356047], 
             UndirectedEdge[100, 220] -> 
             RGBColor[
              0.9676753075442777, 0.9754128778101241, 0.9396014520842269], 
             UndirectedEdge[41, 369] -> 
             RGBColor[
              0.9449673210544464, 0.8371550278584992, 0.5860856437714557], 
             UndirectedEdge[12, 318] -> 
             RGBColor[
              0.9246784101964978, 0.9397253714627332, 0.8710901353939767], 
             UndirectedEdge[118, 199] -> 
             RGBColor[
              0.9087661483405411, 0.9274306486767454, 0.8866501106199686], 
             UndirectedEdge[11, 205] -> 
             RGBColor[
              0.9691841991716598, 0.973101335376758, 0.728028169598324], 
             UndirectedEdge[120, 136] -> 
             RGBColor[
              0.989659195617702, 0.9877892739914567, 0.6609351483752485], 
             UndirectedEdge[66, 215] -> 
             RGBColor[
              0.7604855855433879, 0.8128163864217963, 0.9767617540912604], 
             UndirectedEdge[199, 287] -> 
             RGBColor[
              0.8817579384395167, 0.9085070699767707, 0.9869617548801213], 
             UndirectedEdge[8, 64] -> 
             RGBColor[
              0.9942893921378207, 0.9917175864244403, 0.7305687948342627], 
             UndirectedEdge[312, 361] -> 
             RGBColor[
              0.9805209950607585, 0.9836933034098033, 0.8596463485169975], 
             UndirectedEdge[5, 193] -> 
             RGBColor[
              0.9499069745772847, 0.8578334790108681, 0.590909273882776], 
             UndirectedEdge[187, 232] -> 
             RGBColor[
              0.8963195825991364, 0.9058119903195924, 0.6895073440161065], 
             UndirectedEdge[115, 325] -> 
             RGBColor[
              0.9613892287806424, 0.9503952777295019, 0.6790075698872795], 
             UndirectedEdge[137, 252] -> 
             RGBColor[
              0.9756324842976096, 0.9282025150058861, 0.46717191415535675`], 
             UndirectedEdge[296, 390] -> 
             RGBColor[
              0.8555764809848273, 0.8543760408153337, 0.6568141381134431], 
             UndirectedEdge[101, 171] -> 
             RGBColor[
              0.9478425655026756, 0.9605481206519202, 0.9706237585125497], 
             UndirectedEdge[234, 342] -> 
             RGBColor[
              0.7127175120990163, 0.7508348023081532, 0.6610983842776826], 
             UndirectedEdge[56, 343] -> 
             RGBColor[
              0.9639277679758169, 0.9695284760588574, 0.7660862267227997], 
             UndirectedEdge[60, 146] -> 
             RGBColor[
              0.8792433830397206, 0.9061158262602675, 0.967579114551574], 
             UndirectedEdge[149, 336] -> 
             RGBColor[
              0.9283094041044389, 0.8639837335324614, 0.6303256752378086], 
             UndirectedEdge[12, 199] -> 
             RGBColor[
              0.9097907303494097, 0.927854339667969, 0.8696701351997728], 
             UndirectedEdge[42, 104] -> 
             RGBColor[
              0.904277384708134, 0.9240192685811697, 0.8927415755219448], 
             UndirectedEdge[216, 323] -> 
             RGBColor[
              0.9747905978557719, 0.9338357268806339, 0.5641029000060008], 
             UndirectedEdge[110, 192] -> 
             RGBColor[
              0.9592606335721863, 0.9691372277395024, 0.9538453002205167], 
             UndirectedEdge[93, 380] -> 
             RGBColor[
              0.9862738318586031, 0.9856871698064023, 0.6864374406695364], 
             UndirectedEdge[34, 397] -> 
             RGBColor[
              0.824991539543559, 0.689847896501472, 0.6007657169812218], 
             UndirectedEdge[249, 308] -> 
             RGBColor[
              0.6982654942146198, 0.6052549579217248, 0.5928043584029287], 
             UndirectedEdge[116, 130] -> 
             RGBColor[
              0.6900615367829592, 0.7526590821118989, 0.9307233359299045], 
             UndirectedEdge[81, 315] -> 
             RGBColor[
              0.9540631991828193, 0.9652609896819303, 0.9626432009337242], 
             UndirectedEdge[99, 193] -> 
             RGBColor[
              0.8777743157969963, 0.801368998363662, 0.6205076712720164], 
             UndirectedEdge[116, 135] -> 
             RGBColor[
              0.6847098361960986, 0.7486677925768238, 0.9397823690764007], 
             UndirectedEdge[304, 378] -> 
             RGBColor[
              0.8574975930958528, 0.8883942738926849, 0.9297836504399841], 
             UndirectedEdge[56, 120] -> 
             RGBColor[
              0.9604510193827893, 0.9695909463840395, 0.9327533038390159], 
             UndirectedEdge[255, 393] -> 
             RGBColor[
              0.7409921359221783, 0.7942963472030711, 0.8843933311326317], 
             UndirectedEdge[106, 214] -> 
             RGBColor[
              0.993119240131899, 0.9911841509814037, 0.7463596603891176], 
             UndirectedEdge[130, 328] -> 
             RGBColor[
              0.9789261384481115, 0.9838037290766586, 0.9205567300506942], 
             UndirectedEdge[181, 250] -> 
             RGBColor[
              0.8853763772046228, 0.8880570431873958, 0.6749730479015928], 
             UndirectedEdge[102, 230] -> 
             RGBColor[
              0.5385951415968919, 0.6135543877920928, 0.961829673955882], 
             UndirectedEdge[45, 141] -> 
             RGBColor[
              0.9820025062499329, 0.9493016563390982, 0.53086923029735], 
             UndirectedEdge[225, 288] -> 
             RGBColor[
              0.9802288856278704, 0.9831643509626332, 0.8462092225106166], 
             UndirectedEdge[208, 278] -> 
             RGBColor[
              0.9460142052904661, 0.9276276288927601, 0.6682253261526961], 
             UndirectedEdge[342, 346] -> 
             RGBColor[
              0.9787158130201363, 0.961995464810818, 0.6468719303210617], 
             UndirectedEdge[133, 164] -> 
             RGBColor[
              0.9912724546024403, 0.9906589499374925, 0.7943015436084302], 
             UndirectedEdge[287, 373] -> 
             RGBColor[
              0.7069447495734967, 0.7693503858113473, 0.9712893411267447], 
             UndirectedEdge[122, 314] -> 
             RGBColor[
              0.97377153240972, 0.9444326943458046, 0.6257865994447509], 
             UndirectedEdge[85, 351] -> 
             RGBColor[
              0.8404841877254632, 0.87596358392073, 0.9701312965649925], 
             UndirectedEdge[5, 338] -> 
             RGBColor[
              0.9853533512672124, 0.9869333152335608, 0.8351679371541416], 
             UndirectedEdge[311, 339] -> 
             RGBColor[
              0.8539735008236211, 0.8467181839928649, 0.6473002675609842], 
             UndirectedEdge[39, 324] -> 
             RGBColor[
              0.9137176425387682, 0.6227385351299849, 0.4044194934208165], 
             UndirectedEdge[52, 346] -> 
             RGBColor[
              0.9865521656465087, 0.9871532489346978, 0.7858227470918746], 
             UndirectedEdge[272, 291] -> 
             RGBColor[
              0.9190867802795448, 0.9010154536162078, 0.6580939131507242], 
             UndirectedEdge[191, 323] -> 
             RGBColor[
              0.9776720344946089, 0.9347954262303669, 0.49949708137850035`], 
             UndirectedEdge[60, 165] -> 
             RGBColor[
              0.8014702415461165, 0.8448339111860503, 0.9808467215782263], 
             UndirectedEdge[44, 301] -> 
             RGBColor[
              0.9708391784055026, 0.9096473728639668, 0.4487904942316808], 
             UndirectedEdge[11, 144] -> 
             RGBColor[
              0.9147949318022315, 0.762954154686285, 0.6012236872480076], 
             UndirectedEdge[333, 381] -> 
             RGBColor[
              0.9326651881160988, 0.766944441555234, 0.5523233215534465], 
             UndirectedEdge[9, 363] -> 
             RGBColor[
              0.8642774364896202, 0.8921439505312654, 0.8603214414512692], 
             UndirectedEdge[153, 312] -> 
             RGBColor[
              0.9804695723416741, 0.9804018938778807, 0.6802001065629832], 
             UndirectedEdge[55, 80] -> 
             RGBColor[
              0.9834080555839974, 0.96056709534126, 0.5814244895073241], 
             UndirectedEdge[7, 40] -> 
             RGBColor[
              0.9679578217007108, 0.9733150718091792, 0.8196351815416029], 
             UndirectedEdge[51, 377] -> 
             RGBColor[
              0.9847288440805381, 0.9619410056296122, 0.5652568470305814], 
             UndirectedEdge[112, 170] -> 
             RGBColor[
              0.9174005510896466, 0.9362383824002642, 0.9664684831115564], 
             UndirectedEdge[200, 375] -> 
             RGBColor[
              0.9371935509158691, 0.9523862170959015, 0.9810261798504083], 
             UndirectedEdge[94, 200] -> 
             RGBColor[
              0.950061076031577, 0.9619827962585578, 0.9592448162175542], 
             UndirectedEdge[8, 253] -> 
             RGBColor[
              0.990514520263208, 0.9903455246101958, 0.8068624770807036], 
             UndirectedEdge[31, 295] -> 
             RGBColor[
              0.9896185301213247, 0.9899750096606308, 0.8217113524798665], 
             UndirectedEdge[301, 383] -> 
             RGBColor[
              0.990053225771581, 0.989308368087265, 0.7529830195620403], 
             UndirectedEdge[327, 392] -> 
             RGBColor[
              0.9085160438565045, 0.9260103898166845, 0.8147663029431906], 
             UndirectedEdge[119, 375] -> 
             RGBColor[
              0.972300723425415, 0.9764997212007223, 0.8079769273263415], 
             UndirectedEdge[160, 340] -> 
             RGBColor[
              0.9890155029216394, 0.9897256424164688, 0.8317050737630189], 
             UndirectedEdge[151, 308] -> 
             RGBColor[
              0.9427883251809641, 0.7953780586497503, 0.3957373790342506], 
             UndirectedEdge[221, 276] -> 
             RGBColor[
              0.9412779447033326, 0.7963762776639955, 0.31102765782102915`], 
             UndirectedEdge[94, 316] -> 
             RGBColor[
              0.984105107389772, 0.9837641527420227, 0.6754277949804849], 
             UndirectedEdge[195, 206] -> 
             RGBColor[
              0.9686512781069017, 0.9760818356630483, 0.935310857622641], 
             UndirectedEdge[159, 192] -> 
             RGBColor[
              0.9767057507946164, 0.9797170538548334, 0.7951304461348714], 
             UndirectedEdge[220, 350] -> 
             RGBColor[
              0.7444159535723531, 0.7987264779859713, 0.9462184058325724], 
             UndirectedEdge[229, 319] -> 
             RGBColor[
              0.9637297179812343, 0.9706656140785814, 0.8662079131135179], 
             UndirectedEdge[69, 97] -> 
             RGBColor[
              0.9883543931057099, 0.9894522565178345, 0.8426613743103314], 
             UndirectedEdge[90, 317] -> 
             RGBColor[
              0.9346414416350601, 0.8753317575507802, 0.6323401532476343], 
             UndirectedEdge[136, 237] -> 
             RGBColor[
              0.923767678182307, 0.9369598085621955, 0.7179869224863116], 
             UndirectedEdge[69, 141] -> 
             RGBColor[
              0.9777760819757841, 0.9475539212875881, 0.6009120181554036], 
             UndirectedEdge[48, 143] -> 
             RGBColor[
              0.9912524169606125, 0.9906506638576528, 0.7946336191892713], 
             UndirectedEdge[51, 246] -> 
             RGBColor[
              0.981843257486207, 0.9845305931510798, 0.8507422328433027], 
             UndirectedEdge[97, 132] -> 
             RGBColor[
              0.9919696195854375, 0.9898551607293484, 0.7033646760418701], 
             UndirectedEdge[94, 383] -> 
             RGBColor[
              0.9808035411302385, 0.984935820002794, 0.905373923941913], 
             UndirectedEdge[246, 344] -> 
             RGBColor[
              0.964914479669109, 0.9733538569012641, 0.9442748135376551], 
             UndirectedEdge[155, 354] -> 
             RGBColor[
              0.819195799686812, 0.6976123894350441, 0.6025903864688702], 
             UndirectedEdge[107, 307] -> 
             RGBColor[
              0.8912435198309119, 0.9154040779610412, 0.9644043371810582], 
             UndirectedEdge[310, 363] -> 
             RGBColor[
              0.8601012470133205, 0.8904169888596414, 0.9295317087054742], 
             UndirectedEdge[99, 281] -> 
             RGBColor[
              0.9134817718746169, 0.9300996782150187, 0.8257580292348867], 
             UndirectedEdge[123, 187] -> 
             RGBColor[
              0.9001867168302817, 0.92039393787367, 0.8728507996644147], 
             UndirectedEdge[23, 227] -> 
             RGBColor[
              0.9923426219692687, 0.990967608391256, 0.7668342015794565], 
             UndirectedEdge[28, 211] -> 
             RGBColor[
              0.7407407589010377, 0.7950048502003932, 0.9225230575750241], 
             UndirectedEdge[327, 356] -> 
             RGBColor[
              0.8819466332531265, 0.9085573944079934, 0.9835079854865851], 
             UndirectedEdge[140, 219] -> 
             RGBColor[
              0.992496857000159, 0.9911652717946555, 0.7740100272264001], 
             UndirectedEdge[104, 144] -> 
             RGBColor[
              0.8510110570979936, 0.7123617430727807, 0.6037865576929924], 
             UndirectedEdge[49, 328] -> 
             RGBColor[
              0.8434490650668809, 0.8778574679126818, 0.9490500144567464], 
             UndirectedEdge[112, 271] -> 
             RGBColor[
              0.9153041053368947, 0.9346748565904767, 0.9700172189303427], 
             UndirectedEdge[106, 197] -> 
             RGBColor[
              0.9663783307268003, 0.972410579344674, 0.8440090553577659], 
             UndirectedEdge[106, 204] -> 
             RGBColor[
              0.9854378020717351, 0.9866251018667065, 0.8117463418770505], 
             UndirectedEdge[50, 158] -> 
             RGBColor[
              0.9922475917369225, 0.9897175428260729, 0.6803990375126672], 
             UndirectedEdge[259, 299] -> 
             RGBColor[
              0.8661877215230285, 0.8930384526803637, 0.8198100336997076], 
             UndirectedEdge[79, 286] -> 
             RGBColor[
              0.9882768406366288, 0.9873747456841022, 0.6984189296043337], 
             UndirectedEdge[240, 388] -> 
             RGBColor[
              0.9426219711377479, 0.9567281405392076, 0.9820102156638446], 
             UndirectedEdge[118, 299] -> 
             RGBColor[
              0.8645998183354698, 0.8928789319409045, 0.8822609322405639], 
             UndirectedEdge[138, 257] -> 
             RGBColor[
              0.9942906581423568, 0.9905725155772448, 0.6472751964833268], 
             UndirectedEdge[171, 244] -> 
             RGBColor[
              0.9786435348418645, 0.9811706374159923, 0.7925157868431806], 
             UndirectedEdge[161, 337] -> 
             RGBColor[
              0.9451183939069401, 0.9563710110771029, 0.8881229177286316], 
             UndirectedEdge[119, 355] -> 
             RGBColor[
              0.9096515472697964, 0.9269154659367249, 0.8148467647271875], 
             UndirectedEdge[248, 292] -> 
             RGBColor[
              0.9749580880349041, 0.9736509353727396, 0.6839243247196024], 
             UndirectedEdge[68, 386] -> 
             RGBColor[
              0.7613637133273858, 0.8091807284915414, 0.7927817419676719], 
             UndirectedEdge[126, 299] -> 
             RGBColor[
              0.8103333921599715, 0.8522671832142448, 0.981594962013246], 
             UndirectedEdge[128, 383] -> 
             RGBColor[
              0.9898439366629048, 0.9900682210582581, 0.8179757827524534], 
             UndirectedEdge[229, 248] -> 
             RGBColor[
              0.9613754371546929, 0.9634474859691158, 0.7043668570965378], 
             UndirectedEdge[395, 396] -> 
             RGBColor[
              0.9535141998089546, 0.8451997985040947, 0.3241943582829754], 
             UndirectedEdge[81, 292] -> 
             RGBColor[
              0.960520354268839, 0.9700767253724627, 0.9517129216688611], 
             UndirectedEdge[34, 253] -> 
             RGBColor[
              0.935282069047753, 0.7754738481535848, 0.540364323334336], 
             UndirectedEdge[130, 322] -> 
             RGBColor[
              0.9533833537324421, 0.8623098165986327, 0.5864861102343936], 
             UndirectedEdge[74, 311] -> 
             RGBColor[
              0.577242116399658, 0.6053681877651376, 0.6268504937768622], 
             UndirectedEdge[232, 235] -> 
             RGBColor[
              0.9806100344518573, 0.9718843999519793, 0.6616589351879958], 
             UndirectedEdge[207, 221] -> 
             RGBColor[
              0.9790843549504841, 0.9658062700583141, 0.6537542318414515], 
             UndirectedEdge[140, 216] -> 
             RGBColor[
              0.9898586442690112, 0.9900743030313512, 0.8177320396572076], 
             UndirectedEdge[31, 173] -> 
             RGBColor[
              0.9855315379471444, 0.9882849333656992, 0.8894433896027344], 
             UndirectedEdge[37, 243] -> 
             RGBColor[
              0.9674362439098912, 0.9752345845430295, 0.9400061244594614], 
             UndirectedEdge[1, 35] -> 
             RGBColor[
              0.9447154665222168, 0.907249493078647, 0.6396460171608345], 
             UndirectedEdge[60, 210] -> 
             RGBColor[
              0.8692890958598088, 0.8986919351801386, 0.9844291262532678], 
             UndirectedEdge[35, 92] -> 
             RGBColor[
              0.9522132305084219, 0.9638077554568987, 0.9632253627098216], 
             UndirectedEdge[52, 291] -> 
             RGBColor[
              0.9810903277848559, 0.9465993034474803, 0.4895479901348493], 
             UndirectedEdge[77, 400] -> 
             RGBColor[
              0.9696235407390967, 0.9740410425652593, 0.7758477879119681], 
             UndirectedEdge[77, 389] -> 
             RGBColor[
              0.8295401351786951, 0.8638428575490074, 0.7708058341808655], 
             UndirectedEdge[96, 361] -> 
             RGBColor[
              0.9928796594779498, 0.9899960854974339, 0.6711718566063073], 
             UndirectedEdge[150, 374] -> 
             RGBColor[
              0.8839883821462955, 0.718240705943873, 0.6029094022699224], 
             UndirectedEdge[80, 154] -> 
             RGBColor[
              0.8652379755325501, 0.8935061788390931, 0.8881609609919845], 
             UndirectedEdge[200, 383] -> 
             RGBColor[
              0.9550631068223393, 0.9654452297120045, 0.9387728297543827], 
             UndirectedEdge[144, 391] -> 
             RGBColor[
              0.9333557232750572, 0.7767967625762119, 0.569805108714232], 
             UndirectedEdge[196, 290] -> 
             RGBColor[
              0.9804590392992458, 0.9843785427924603, 0.8925068647634797], 
             UndirectedEdge[159, 228] -> 
             RGBColor[
              0.848457266639617, 0.8790051577114459, 0.8034552336270105], 
             UndirectedEdge[27, 377] -> 
             RGBColor[
              0.9855469490561605, 0.9616463326635067, 0.505687737552758], 
             UndirectedEdge[24, 233] -> 
             RGBColor[
              0.9914267944604271, 0.9903567535964728, 0.7651379543747768], 
             UndirectedEdge[24, 109] -> 
             RGBColor[
              0.9860993596611902, 0.9738393234171372, 0.6208672768517074], 
             UndirectedEdge[189, 255] -> 
             RGBColor[
              0.7434318756869536, 0.7949451808126695, 0.8177878606769668], 
             UndirectedEdge[262, 298] -> 
             RGBColor[
              0.9889189774656438, 0.9727058946730582, 0.5455796965913815], 
             UndirectedEdge[249, 397] -> 
             RGBColor[
              0.6358132616652233, 0.7133125725266198, 0.9657774121443496], 
             UndirectedEdge[128, 324] -> 
             RGBColor[
              0.9134693677538872, 0.6234150016816322, 0.4651689063480273], 
             UndirectedEdge[7, 228] -> 
             RGBColor[
              0.848544991213146, 0.8791927917039095, 0.8130035120823258], 
             UndirectedEdge[115, 258] -> 
             RGBColor[
              0.9438050827859648, 0.9576105032692801, 0.9800075162483513], 
             UndirectedEdge[375, 383] -> 
             RGBColor[
              0.9679360160145307, 0.9753392408401378, 0.9271552875747668], 
             UndirectedEdge[257, 338] -> 
             RGBColor[
              0.9939709109616812, 0.9904402919009078, 0.6525742347462987], 
             UndirectedEdge[5, 321] -> 
             RGBColor[
              0.9803513874724231, 0.9701844558401369, 0.6588975844273515], 
             UndirectedEdge[65, 239] -> 
             RGBColor[
              0.8826968438910248, 0.8664911179811547, 0.6462700374238421], 
             UndirectedEdge[56, 71] -> 
             RGBColor[
              0.9643528669759382, 0.9704377198360151, 0.8123556294790828], 
             UndirectedEdge[276, 322] -> 
             RGBColor[
              0.9127254111669225, 0.6907531560702309, 0.2485864366302284], 
             UndirectedEdge[239, 326] -> 
             RGBColor[
              0.8961053175765619, 0.9177654428768373, 0.8978333862834935], 
             UndirectedEdge[379, 393] -> 
             RGBColor[
              0.9745988608179043, 0.9321015949801739, 0.5558422608863602], 
             UndirectedEdge[131, 262] -> 
             RGBColor[
              0.9928762155174962, 0.9911295916648701, 0.7537263862619881], 
             UndirectedEdge[201, 210] -> 
             RGBColor[
              0.9442968126154474, 0.9579772345709745, 0.9791751459107167], 
             UndirectedEdge[301, 372] -> 
             RGBColor[
              0.9936516043285091, 0.9888297485169695, 0.5503944927939706], 
             UndirectedEdge[291, 398] -> 
             RGBColor[
              0.9797680980282907, 0.9434151853522453, 0.37590331062435356`], 
             UndirectedEdge[28, 49] -> 
             RGBColor[
              0.6037033409701928, 0.6880960751846549, 0.9626672330029804], 
             UndirectedEdge[6, 160] -> 
             RGBColor[
              0.9471068878248725, 0.9576901901868322, 0.8767449232324532], 
             UndirectedEdge[375, 379] -> 
             RGBColor[
              0.9546395167833244, 0.9181784012679923, 0.6327288084634755], 
             UndirectedEdge[45, 112] -> 
             RGBColor[
              0.9329010082235308, 0.9459633755974955, 0.8580452457795612], 
             UndirectedEdge[324, 390] -> 
             RGBColor[
              0.9016388236514655, 0.5831515579070687, 0.2590518252570617], 
             UndirectedEdge[169, 227] -> 
             RGBColor[
              0.990742302571139, 0.9871886846718902, 0.6229211807550022], 
             UndirectedEdge[44, 380] -> 
             RGBColor[
              0.9700706729084485, 0.9080036173135926, 0.36514341354350377`], 
             UndirectedEdge[288, 360] -> 
             RGBColor[
              0.9803260710356017, 0.9821701909833224, 0.7694123815930056], 
             UndirectedEdge[87, 134] -> 
             RGBColor[
              0.9834782639807529, 0.9718748982148213, 0.6522426515580237], 
             UndirectedEdge[85, 258] -> 
             RGBColor[
              0.9482266523645536, 0.9609081026213361, 0.9725229522818395], 
             UndirectedEdge[26, 77] -> 
             RGBColor[
              0.993267800289502, 0.9880088304860741, 0.5086197917120201], 
             UndirectedEdge[90, 333] -> 
             RGBColor[
              0.903669845677525, 0.7454004048769336, 0.6070503717910561], 
             UndirectedEdge[45, 91] -> 
             RGBColor[
              0.9900288086788992, 0.9901446703878658, 0.8149119750139873], 
             UndirectedEdge[103, 133] -> 
             RGBColor[
              0.9924127078218778, 0.9888696819253794, 0.6110688830508597], 
             UndirectedEdge[143, 342] -> 
             RGBColor[
              0.9858933757692967, 0.9659036200109359, 0.5700184352592256], 
             UndirectedEdge[75, 164] -> 
             RGBColor[
              0.991662961544532, 0.9888043970358752, 0.6412851849048951], 
             UndirectedEdge[44, 211] -> 
             RGBColor[
              0.9663902309518029, 0.9086540181550431, 0.5840453680832216], 
             UndirectedEdge[82, 171] -> 
             RGBColor[
              0.9269380722913526, 0.943879445202563, 0.9686298692883922], 
             UndirectedEdge[17, 122] -> 
             RGBColor[
              0.9817314244046329, 0.9484186168472136, 0.5212265450110476], 
             UndirectedEdge[150, 186] -> 
             RGBColor[
              0.9439267734234427, 0.9551476491462635, 0.876146141884606], 
             UndirectedEdge[180, 394] -> 
             RGBColor[
              0.9731032393067685, 0.97752585791979, 0.8405484292587531], 
             UndirectedEdge[156, 202] -> 
             RGBColor[
              0.9780380785906425, 0.9794829197923944, 0.6954559163109693], 
             UndirectedEdge[86, 178] -> 
             RGBColor[
              0.9089332383525428, 0.9299287449827967, 0.9809841684980605], 
             UndirectedEdge[102, 250] -> 
             RGBColor[
              0.5785868333622182, 0.6218385201576435, 0.651746918653537], 
             UndirectedEdge[7, 222] -> 
             RGBColor[
              0.768972609391218, 0.8155132795940179, 0.8061096363627377], 
             UndirectedEdge[97, 220] -> 
             RGBColor[
              0.9795362311433174, 0.9833065828662322, 0.8768846749487855], 
             UndirectedEdge[230, 289] -> 
             RGBColor[
              0.8527762182788678, 0.8855472324538485, 0.9857925221195849], 
             UndirectedEdge[14, 289] -> 
             RGBColor[
              0.8326625638072931, 0.8695091503488208, 0.9838740638004146], 
             UndirectedEdge[77, 370] -> 
             RGBColor[
              0.8499843627793756, 0.8798140435325437, 0.772843523725932], 
             UndirectedEdge[151, 270] -> 
             RGBColor[
              0.9943938276477029, 0.9904172891464362, 0.6311809206168579], 
             UndirectedEdge[173, 214] -> 
             RGBColor[
              0.9882078466519397, 0.9893916557931286, 0.8450900282993682], 
             UndirectedEdge[144, 317] -> 
             RGBColor[
              0.9127998516330269, 0.6862228860559016, 0.24839672014874395`], 
             UndirectedEdge[31, 175] -> 
             RGBColor[
              0.9873407489351717, 0.9890330886038501, 0.8594600814431738], 
             UndirectedEdge[163, 240] -> 
             RGBColor[
              0.9661677897415601, 0.9725141633010362, 0.8626915724051516], 
             UndirectedEdge[329, 371] -> 
             RGBColor[
              0.9723506493859433, 0.9761097794920547, 0.7739977948088317], 
             UndirectedEdge[72, 375] -> 
             RGBColor[
              0.9723185437188464, 0.9765378370064641, 0.8099165562922557], 
             UndirectedEdge[32, 238] -> 
             RGBColor[
              0.9780492636224327, 0.9367908702695745, 0.43948710816357006`], 
             UndirectedEdge[11, 14] -> 
             RGBColor[
              0.9017056976890779, 0.9242101352036753, 0.9818353871596766], 
             UndirectedEdge[79, 237] -> 
             RGBColor[
              0.919159082366426, 0.9371435613446358, 0.9494040043591572], 
             UndirectedEdge[69, 74] -> 
             RGBColor[
              0.5879955966065344, 0.6525004753682153, 0.9013730474906074], 
             UndirectedEdge[16, 203] -> 
             RGBColor[
              0.7195072626597405, 0.7808038091383022, 0.9726774178304183], 
             UndirectedEdge[315, 319] -> 
             RGBColor[
              0.9708552137754259, 0.9760533277916729, 0.8566956600014455], 
             UndirectedEdge[40, 80] -> 
             RGBColor[
              0.9660662720019322, 0.9731100797216685, 0.8929402977826739], 
             UndirectedEdge[18, 198] -> 
             RGBColor[
              0.9710110640923535, 0.9753472643243822, 0.7950342251405458], 
             UndirectedEdge[300, 307] -> 
             RGBColor[
              0.9056978005150074, 0.9225161966011122, 0.7125899073635628], 
             UndirectedEdge[191, 198] -> 
             RGBColor[
              0.9713870341321513, 0.9761514262231079, 0.835956243754418], 
             UndirectedEdge[289, 391] -> 
             RGBColor[
              0.8948930787185627, 0.9179232820682925, 0.9479694411528918], 
             UndirectedEdge[132, 357] -> 
             RGBColor[
              0.8421038706738644, 0.8737557876521457, 0.7799109308016184], 
             UndirectedEdge[157, 187] -> 
             RGBColor[
              0.9005600169401726, 0.9205483070624851, 0.8666642507738067], 
             UndirectedEdge[38, 250] -> 
             RGBColor[
              0.9787553190930135, 0.9399988441917531, 0.3719688557080556], 
             UndirectedEdge[140, 191] -> 
             RGBColor[
              0.9927400809078482, 0.9910340023810843, 0.7531262210297072], 
             UndirectedEdge[204, 261] -> 
             RGBColor[
              0.9696357056433654, 0.9768749395025665, 0.9362830094561834], 
             UndirectedEdge[337, 354] -> 
             RGBColor[
              0.8236345301278888, 0.862783174928319, 0.9828875129328051], 
             UndirectedEdge[300, 314] -> 
             RGBColor[
              0.9859341907151427, 0.985362462755363, 0.6813468226558812], 
             UndirectedEdge[292, 378] -> 
             RGBColor[
              0.9728785434432256, 0.9790355627276555, 0.919245342288849], 
             UndirectedEdge[153, 361] -> 
             RGBColor[
              0.9919646763342382, 0.9876750564968003, 0.6025311886131466], 
             UndirectedEdge[240, 334] -> 
             RGBColor[
              0.9638267760676509, 0.9715460939855676, 0.9014882273310101], 
             UndirectedEdge[52, 260] -> 
             RGBColor[
              0.9878328332553892, 0.9881083687405001, 0.7836549108816473], 
             UndirectedEdge[128, 177] -> 
             RGBColor[
              0.9673185661174692, 0.9735369095076114, 0.8681102126013118], 
             UndirectedEdge[16, 85] -> 
             RGBColor[
              0.8002166747335634, 0.8445062967270243, 0.9661178071912636], 
             UndirectedEdge[179, 303] -> 
             RGBColor[
              0.8779112518818244, 0.9054866182572023, 0.9882171529967566], 
             UndirectedEdge[48, 320] -> 
             RGBColor[
              0.8193877391234459, 0.8579107735213891, 0.8937095084526347], 
             UndirectedEdge[136, 320] -> 
             RGBColor[
              0.8209441713858392, 0.8563518463633917, 0.7078131263564862], 
             UndirectedEdge[96, 192] -> 
             RGBColor[
              0.9763586287841987, 0.9789745949739688, 0.7573483574896318], 
             UndirectedEdge[140, 357] -> 
             RGBColor[
              0.8403292833137155, 0.8741140350188454, 0.8887034754373146], 
             UndirectedEdge[202, 306] -> 
             RGBColor[
              0.9454690430788659, 0.9542276223760633, 0.71711702014626], 
             UndirectedEdge[114, 258] -> 
             RGBColor[
              0.9632768277785895, 0.9721324988027235, 0.9470469310202855], 
             UndirectedEdge[87, 236] -> 
             RGBColor[
              0.9819261913430554, 0.9666393927638821, 0.6462131424448931], 
             UndirectedEdge[116, 362] -> 
             RGBColor[
              0.694540967265862, 0.754828713014162, 0.8706956366411761], 
             UndirectedEdge[36, 64] -> 
             RGBColor[
              0.9939331590034175, 0.9894319654970541, 0.5810399816037073], 
             UndirectedEdge[245, 304] -> 
             RGBColor[
              0.8073477854988648, 0.8499545868802404, 0.9812921350341921], 
             UndirectedEdge[187, 218] -> 
             RGBColor[
              0.9012223926126133, 0.9208222164253177, 0.8556869717081728], 
             UndirectedEdge[26, 370] -> 
             RGBColor[
              0.8493805027182061, 0.8785224479213196, 0.7071170826599449], 
             UndirectedEdge[91, 141] -> 
             RGBColor[
              0.9767928308007807, 0.9471473216583217, 0.6172070346976837], 
             UndirectedEdge[55, 385] -> 
             RGBColor[0.8458312882177623, 0.854234649842486, 0.6667536554309],
              UndirectedEdge[179, 231] -> 
             RGBColor[
              0.8863928409700961, 0.9122496071695875, 0.9890261345356], 
             UndirectedEdge[94, 177] -> 
             RGBColor[
              0.9582781705848028, 0.9684045084521473, 0.9555083537907714], 
             UndirectedEdge[225, 383] -> 
             RGBColor[
              0.9898471078450153, 0.9900695324235564, 0.8179232280581261], 
             UndirectedEdge[37, 134] -> 
             RGBColor[
              0.9799282073867532, 0.9692272718197006, 0.658251971368616], 
             UndirectedEdge[255, 341] -> 
             RGBColor[
              0.6861557164756102, 0.7529336175062709, 0.9707986438719676], 
             UndirectedEdge[206, 278] -> 
             RGBColor[
              0.9524866855635016, 0.9636324791235794, 0.9490189669630169], 
             UndirectedEdge[131, 279] -> 
             RGBColor[
              0.931147923627702, 0.9454377773335563, 0.8957547410344036], 
             UndirectedEdge[7, 203] -> 
             RGBColor[
              0.8924557483665208, 0.9134962089262408, 0.8173801259860181], 
             UndirectedEdge[101, 151] -> 
             RGBColor[
              0.9632937867751794, 0.9691550886133312, 0.7767368015382876], 
             UndirectedEdge[200, 296] -> 
             RGBColor[
              0.8326261952466834, 0.8700164932436437, 0.983728266206338], 
             UndirectedEdge[86, 229] -> 
             RGBColor[
              0.939973062369224, 0.9546790581001205, 0.9839447746223495], 
             UndirectedEdge[138, 382] -> 
             RGBColor[
              0.9939496024382399, 0.9917660193671567, 0.7499342757327204], 
             UndirectedEdge[195, 278] -> 
             RGBColor[
              0.9365913188194076, 0.951836660026784, 0.9785642075581098], 
             UndirectedEdge[65, 113] -> 
             RGBColor[
              0.9784761053233392, 0.9382993664702283, 0.4353070489194549], 
             UndirectedEdge[249, 270] -> 
             RGBColor[
              0.7498709966813588, 0.8002941884184107, 0.828247899985536], 
             UndirectedEdge[319, 388] -> 
             RGBColor[
              0.9711963393262744, 0.9763077386689538, 0.856118223423652], 
             UndirectedEdge[138, 256] -> 
             RGBColor[
              0.940851823532118, 0.952378414408493, 0.8620722804545681], 
             UndirectedEdge[246, 286] -> 
             RGBColor[
              0.9819082302128014, 0.9826250464576542, 0.709199325852252], 
             UndirectedEdge[188, 208] -> 
             RGBColor[
              0.9505791919884757, 0.8371453864378708, 0.3031781031637433], 
             UndirectedEdge[173, 345] -> 
             RGBColor[
              0.988851902209033, 0.9872761498550392, 0.6612817760136399], 
             UndirectedEdge[84, 156] -> 
             RGBColor[
              0.7965475623498134, 0.8412390832661416, 0.955413543489642], 
             UndirectedEdge[136, 349] -> 
             RGBColor[
              0.9918603824409433, 0.9840659009784987, 0.43473304547502756`], 
             UndirectedEdge[117, 346] -> 
             RGBColor[
              0.9859004795764394, 0.9857593583263883, 0.7148907401050579], 
             UndirectedEdge[26, 197] -> 
             RGBColor[
              0.9652075273039282, 0.9699063492095351, 0.7165743281393238], 
             UndirectedEdge[328, 362] -> 
             RGBColor[
              0.9834055689310144, 0.9859733599789215, 0.8605290307619657], 
             UndirectedEdge[187, 275] -> 
             RGBColor[
              0.8945582083033241, 0.8998704612294657, 0.6826647374845014], 
             UndirectedEdge[20, 121] -> 
             RGBColor[
              0.951836570568279, 0.9603128482045311, 0.7994306155571985], 
             UndirectedEdge[198, 302] -> 
             RGBColor[
              0.8870758696549967, 0.9124831945696912, 0.978307291085724], 
             UndirectedEdge[1, 312] -> 
             RGBColor[
              0.9628046287687979, 0.9208138912805743, 0.6115751365270405], 
             UndirectedEdge[89, 292] -> 
             RGBColor[
              0.9768963430682585, 0.9806970261253471, 0.8526600047699313], 
             UndirectedEdge[304, 315] -> 
             RGBColor[
              0.8381747629020625, 0.8742412186687738, 0.9740405503965491], 
             UndirectedEdge[21, 64] -> 
             RGBColor[
              0.9173423233179437, 0.9334020410469881, 0.8442895982486531], 
             UndirectedEdge[201, 351] -> 
             RGBColor[
              0.8394387114134765, 0.8751838693990606, 0.9719010152572933], 
             UndirectedEdge[17, 218] -> 
             RGBColor[
              0.9951412192370179, 0.9921249002821395, 0.720454202315288], 
             UndirectedEdge[266, 365] -> 
             RGBColor[
              0.9687781602014596, 0.9744338167587885, 0.8570567699968631], 
             UndirectedEdge[112, 180] -> 
             RGBColor[
              0.910810555287358, 0.9313235743210452, 0.9776236270586551], 
             UndirectedEdge[247, 289] -> 
             RGBColor[
              0.8758635975674605, 0.9037311261837162, 0.9801813890581436], 
             UndirectedEdge[15, 45] -> 
             RGBColor[
              0.9941204065814544, 0.9898700096921462, 0.6041495272781279], 
             UndirectedEdge[57, 92] -> 
             RGBColor[
              0.8672596731916383, 0.896529156618209, 0.9550000649585056], 
             UndirectedEdge[53, 86] -> 
             RGBColor[
              0.9707421921722973, 0.9752334733159129, 0.8023712659376665], 
             UndirectedEdge[114, 154] -> 
             RGBColor[
              0.860731948015238, 0.8912483729101528, 0.9451733219896599], 
             UndirectedEdge[71, 237] -> 
             RGBColor[
              0.9245998524088521, 0.938739745087055, 0.8085639514617391], 
             UndirectedEdge[241, 375] -> 
             RGBColor[
              0.9712956965280015, 0.9743500702909615, 0.6985859518499421], 
             UndirectedEdge[100, 282] -> 
             RGBColor[
              0.8948779902008668, 0.9182288644243936, 0.9625645654592936], 
             UndirectedEdge[55, 146] -> 
             RGBColor[
              0.9674310209497782, 0.9497542310865805, 0.6578542734361117], 
             UndirectedEdge[309, 319] -> 
             RGBColor[
              0.947159041733389, 0.9574526066375739, 0.8646273872201811], 
             UndirectedEdge[13, 302] -> 
             RGBColor[
              0.858364545093724, 0.8899006048455924, 0.9863527706537565], 
             UndirectedEdge[110, 348] -> 
             RGBColor[
              0.9765872312585036, 0.9790642956445357, 0.7505509981904843], 
             UndirectedEdge[217, 363] -> 
             RGBColor[
              0.8646312873099794, 0.8919310995451788, 0.8283488127573222], 
             UndirectedEdge[39, 380] -> 
             RGBColor[
              0.9935713598013118, 0.9886581135872607, 0.5416603712203644], 
             UndirectedEdge[248, 304] -> 
             RGBColor[
              0.8595771376875314, 0.883009646537769, 0.6944626328707375], 
             UndirectedEdge[204, 400] -> 
             RGBColor[
              0.9606227390984579, 0.9701530838107526, 0.9515396108585565], 
             UndirectedEdge[69, 168] -> 
             RGBColor[
              0.823358353011892, 0.8615329849745903, 0.9176995830456436], 
             UndirectedEdge[68, 86] -> 
             RGBColor[
              0.7377235669218083, 0.7940214866196571, 0.9652226016369386], 
             UndirectedEdge[175, 264] -> 
             RGBColor[
              0.97492458321465, 0.9800536231299093, 0.8930383530860946], 
             UndirectedEdge[1, 92] -> 
             RGBColor[
              0.9640811304556065, 0.9217659041485166, 0.6094143521362342], 
             UndirectedEdge[368, 393] -> 
             RGBColor[
              0.9884944050370461, 0.9895101550495846, 0.8403410142688272], 
             UndirectedEdge[332, 361] -> 
             RGBColor[
              0.9659491377822437, 0.9728256361107133, 0.8843127019404643], 
             UndirectedEdge[80, 203] -> 
             RGBColor[
              0.8905641986677422, 0.9132912168387302, 0.8906852422270891], 
             UndirectedEdge[20, 347] -> 
             RGBColor[
              0.9507109203862241, 0.9575491939419298, 0.7071824095836398], 
             UndirectedEdge[18, 311] -> 
             RGBColor[
              0.9797699915415952, 0.9423364013010673, 0.46818580233485474`], 
             UndirectedEdge[170, 282] -> 
             RGBColor[
              0.8938961234142151, 0.917496589782568, 0.9642266098172234], 
             UndirectedEdge[198, 323] -> 
             RGBColor[
              0.9540458206299751, 0.9192046858133556, 0.6368523221377349], 
             UndirectedEdge[168, 357] -> 
             RGBColor[
              0.6750613616262751, 0.7460823334495998, 0.9682474657859623], 
             UndirectedEdge[180, 326] -> 
             RGBColor[
              0.9705480772735373, 0.97658405603119, 0.8912405167847177], 
             UndirectedEdge[18, 340] -> 
             RGBColor[
              0.9895675159939974, 0.9890733766327278, 0.758551016834427], 
             UndirectedEdge[74, 340] -> 
             RGBColor[
              0.5870396408520602, 0.652105163096798, 0.9172157082764345], 
             UndirectedEdge[173, 204] -> 
             RGBColor[
              0.980526408591776, 0.9848326066784314, 0.9104767097873012], 
             UndirectedEdge[26, 30] -> 
             RGBColor[
              0.9792852209880574, 0.9416870005576787, 0.3824734886317116], 
             UndirectedEdge[169, 240] -> 
             RGBColor[
              0.9646946504134428, 0.9686539485545325, 0.7069389494328633], 
             UndirectedEdge[95, 371] -> 
             RGBColor[
              0.9730232628453868, 0.9775484316701517, 0.8472076189801363], 
             UndirectedEdge[65, 356] -> 
             RGBColor[
              0.9523091532644083, 0.9217071891933091, 0.6478538603396904], 
             UndirectedEdge[264, 310] -> 
             RGBColor[
              0.9734267781300442, 0.97943424223559, 0.9178608595333166], 
             UndirectedEdge[96, 114] -> 
             RGBColor[
              0.9877804892704327, 0.987492999823022, 0.7380141269847547], 
             UndirectedEdge[244, 308] -> 
             RGBColor[
              0.9431430743200057, 0.7961368311875205, 0.43434963356101586`], 
             UndirectedEdge[187, 298] -> 
             RGBColor[
              0.8950341558737702, 0.9014759441423841, 0.6845137039205272], 
             UndirectedEdge[58, 228] -> 
             RGBColor[
              0.6100155702978205, 0.6933562145647674, 0.9630714530752846], 
             UndirectedEdge[36, 82] -> 
             RGBColor[
              0.9419209585568993, 0.9514846919400257, 0.7237675370354926], 
             UndirectedEdge[72, 355] -> 
             RGBColor[
              0.9096693675632279, 0.9269535817424668, 0.8167863936931017], 
             UndirectedEdge[22, 350] -> 
             RGBColor[
              0.7572054631982259, 0.80603676305176, 0.8114600000519633], 
             UndirectedEdge[58, 192] -> 
             RGBColor[
              0.7382640544528198, 0.7940681107081549, 0.9547466655831454], 
             UndirectedEdge[3, 174] -> 
             RGBColor[
              0.7994275353346736, 0.48169409269590413`, 0.571538934860324], 
             UndirectedEdge[44, 54] -> 
             RGBColor[
              0.9631060152409422, 0.9064058440138039, 0.5986143233235093], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.9162125012759388, 0.9309854659416706, 0.7213154414298237], 
             UndirectedEdge[170, 271] -> 
             RGBColor[
              0.962141124107531, 0.9712854928643923, 0.9489693810964304], 
             UndirectedEdge[192, 201] -> 
             RGBColor[
              0.9543002464260321, 0.965437779127789, 0.9622419417827878], 
             UndirectedEdge[274, 395] -> 
             RGBColor[
              0.9583353850173341, 0.8625967766888947, 0.5084571677315535], 
             UndirectedEdge[208, 284] -> 
             RGBColor[
              0.940100243388243, 0.7955998471405665, 0.2947464951474589], 
             UndirectedEdge[237, 320] -> 
             RGBColor[
              0.7519829805838403, 0.8064555440070145, 0.9758396038029099], 
             UndirectedEdge[119, 380] -> 
             RGBColor[
              0.9936494276854111, 0.9888250928974752, 0.5501575786254378], 
             UndirectedEdge[342, 398] -> 
             RGBColor[
              0.9854120449466949, 0.9624535435697787, 0.3978289786324105], 
             UndirectedEdge[90, 264] -> 
             RGBColor[
              0.9444728034100476, 0.9579073121720231, 0.9719023396178793], 
             UndirectedEdge[212, 367] -> 
             RGBColor[
              0.9600377471230055, 0.8746741255875254, 0.3106391048252525], 
             UndirectedEdge[92, 284] -> 
             RGBColor[
              0.9400888484566865, 0.8268279532548481, 0.5891541762866164], 
             UndirectedEdge[267, 342] -> 
             RGBColor[
              0.9581068124042653, 0.8648322788577758, 0.3204718941408251], 
             UndirectedEdge[107, 297] -> 
             RGBColor[
              0.9742743834163852, 0.9664314261320286, 0.6708384399912493], 
             UndirectedEdge[163, 245] -> 
             RGBColor[
              0.9401585249148785, 0.9518205736637881, 0.8617880263114336], 
             UndirectedEdge[72, 200] -> 
             RGBColor[
              0.9594456345266551, 0.966643825878331, 0.8215340984718715], 
             UndirectedEdge[254, 286] -> 
             RGBColor[
              0.8306831966263745, 0.8641726171876024, 0.7258096188856732], 
             UndirectedEdge[269, 307] -> 
             RGBColor[
              0.6486019626090794, 0.7229014745259917, 0.9673267342217309], 
             UndirectedEdge[240, 304] -> 
             RGBColor[
              0.8333570503255465, 0.8706481765174885, 0.9821956811279102], 
             UndirectedEdge[228, 332] -> 
             RGBColor[
              0.8211796229334931, 0.8610922494438606, 0.9788139903159281], 
             UndirectedEdge[104, 109] -> 
             RGBColor[
              0.9010052615407362, 0.9079857427420486, 0.687803286915237], 
             UndirectedEdge[28, 372] -> 
             RGBColor[
              0.7445404310610857, 0.7946094707079974, 0.7165985748721146], 
             UndirectedEdge[28, 362] -> 
             RGBColor[
              0.7436598448343263, 0.7962119672508946, 0.8741462493081997], 
             UndirectedEdge[209, 227] -> 
             RGBColor[
              0.9824320339438783, 0.9855268599842884, 0.8746962755697509], 
             UndirectedEdge[245, 371] -> 
             RGBColor[
              0.9181120948679072, 0.9371527924326281, 0.9785685958465613], 
             UndirectedEdge[308, 397] -> 
             RGBColor[
              0.829384410837205, 0.7097948990647625, 0.604431236467769], 
             UndirectedEdge[58, 87] -> 
             RGBColor[
              0.7503980575630917, 0.8031176303601889, 0.9342069633723156], 
             UndirectedEdge[154, 332] -> 
             RGBColor[
              0.8397641569516759, 0.875610628666555, 0.9806663229845158], 
             UndirectedEdge[97, 180] -> 
             RGBColor[
              0.970490364443686, 0.9765601902928943, 0.8921969677313717], 
             UndirectedEdge[202, 300] -> 
             RGBColor[
              0.9926680808856487, 0.9867260913221649, 0.44334403564173774`], 
             UndirectedEdge[25, 317] -> 
             RGBColor[
              0.964156028649938, 0.8970905152053592, 0.5690078766187797], 
             UndirectedEdge[93, 128] -> 
             RGBColor[
              0.9868330482469811, 0.9880907783277695, 0.8350772845481265], 
             UndirectedEdge[68, 178] -> 
             RGBColor[
              0.6995582471109354, 0.7638834597892417, 0.9717742486247221], 
             UndirectedEdge[271, 273] -> 
             RGBColor[
              0.9770004679705219, 0.9807453692482495, 0.8511710498110989], 
             UndirectedEdge[149, 318] -> 
             RGBColor[
              0.8965927106323011, 0.8386937030844882, 0.6273005087006096], 
             UndirectedEdge[42, 358] -> 
             RGBColor[
              0.9688299239348804, 0.9088377383036105, 0.5395755118300746], 
             UndirectedEdge[155, 170] -> 
             RGBColor[
              0.9269138128173884, 0.7821925367456667, 0.5875021101157738], 
             UndirectedEdge[193, 338] -> 
             RGBColor[
              0.958760402262077, 0.8627725322420409, 0.50141353207679], 
             UndirectedEdge[79, 109] -> 
             RGBColor[
              0.983857264357485, 0.9727991330806696, 0.6529630493400771], 
             UndirectedEdge[173, 175] -> 
             RGBColor[
              0.9869919711021852, 0.9888888600067287, 0.8652402327438578], 
             UndirectedEdge[95, 178] -> 
             RGBColor[
              0.9330174289268245, 0.9460377524317868, 0.8568747762692785], 
             UndirectedEdge[243, 348] -> 
             RGBColor[
              0.9761788950799363, 0.9787597591911493, 0.7512422048296667], 
             UndirectedEdge[56, 83] -> 
             RGBColor[
              0.6974049333706108, 0.7616754878219245, 0.9721339703580492], 
             UndirectedEdge[205, 207] -> 
             RGBColor[
              0.9847861040972972, 0.9847372105245238, 0.7016182141877312], 
             UndirectedEdge[74, 302] -> 
             RGBColor[
              0.5077982383378955, 0.5903015595520471, 0.9586947231546248], 
             UndirectedEdge[179, 196] -> 
             RGBColor[
              0.9176252569000306, 0.9352463368202066, 0.9201354436469409], 
             UndirectedEdge[174, 338] -> 
             RGBColor[
              0.8878714248106759, 0.9105667769282708, 0.8622660325344018], 
             UndirectedEdge[159, 167] -> 
             RGBColor[
              0.9903394899793478, 0.9895445751393117, 0.7568038376269053], 
             UndirectedEdge[251, 356] -> 
             RGBColor[
              0.9644325211095194, 0.9724500897982618, 0.9207147387225064], 
             UndirectedEdge[238, 277] -> 
             RGBColor[
              0.9932765722702482, 0.988027592865907, 0.5095745676818553], 
             UndirectedEdge[163, 164] -> 
             RGBColor[
              0.9926266494206055, 0.9912189442960232, 0.7718590309275826], 
             UndirectedEdge[213, 230] -> 
             RGBColor[
              0.8280846383266576, 0.8662579825322236, 0.9833314961858821], 
             UndirectedEdge[246, 343] -> 
             RGBColor[
              0.9821587379710212, 0.9831608572222668, 0.7364655493797962], 
             UndirectedEdge[53, 95] -> 
             RGBColor[
              0.9948263827465791, 0.9913424807649032, 0.6782618737088846], 
             UndirectedEdge[139, 184] -> 
             RGBColor[
              0.7685697517147088, 0.817160520755429, 0.9064388759215243], 
             UndirectedEdge[101, 308] -> 
             RGBColor[
              0.9123421049808169, 0.7755143144234482, 0.612457605230385], 
             UndirectedEdge[3, 52] -> 
             RGBColor[
              0.9059448136648163, 0.5624612228944468, 0.40732123745685955`], 
             UndirectedEdge[136, 286] -> 
             RGBColor[
              0.9928854364525098, 0.9871909929016619, 0.467001847731488], 
             UndirectedEdge[164, 169] -> 
             RGBColor[
              0.9911535100924882, 0.9873587295495194, 0.6161064079552943], 
             UndirectedEdge[14, 102] -> 
             RGBColor[
              0.518481487125317, 0.5975163056870653, 0.959911215636712], 
             UndirectedEdge[232, 281] -> 
             RGBColor[
              0.9900394747808556, 0.9766891735188676, 0.5326217882179862], 
             UndirectedEdge[56, 349] -> 
             RGBColor[
              0.9626522062060308, 0.9658675733710815, 0.706551200938795], 
             UndirectedEdge[225, 324] -> 
             RGBColor[
              0.9134725389359977, 0.6234163130469306, 0.46511635165370013`], 
             UndirectedEdge[5, 272] -> 
             RGBColor[
              0.923531727950715, 0.9408110040643684, 0.9560899999527982], 
             UndirectedEdge[68, 371] -> 
             RGBColor[
              0.7395640810294977, 0.7953941390276066, 0.9621070913355798], 
             UndirectedEdge[151, 397] -> 
             RGBColor[
              0.8803360926315675, 0.9034356732546454, 0.7687104327756716], 
             UndirectedEdge[1, 356] -> 
             RGBColor[
              0.9489900220389618, 0.9105109802008049, 0.6349596622941686], 
             UndirectedEdge[96, 115] -> 
             RGBColor[
              0.968308744277808, 0.9729710042895787, 0.7709747122128204], 
             UndirectedEdge[328, 347] -> 
             RGBColor[
              0.9837480745485961, 0.9828639610774113, 0.6746864723009434], 
             UndirectedEdge[80, 159] -> 
             RGBColor[
              0.9926336387981626, 0.990493264632827, 0.7187838546323189], 
             UndirectedEdge[50, 121] -> 
             RGBColor[
              0.9939503946479276, 0.9894688307978704, 0.5829159751425699], 
             UndirectedEdge[108, 342] -> 
             RGBColor[
              0.8682268612276831, 0.8755037467624555, 0.6744962909292573], 
             UndirectedEdge[178, 315] -> 
             RGBColor[
              0.9089332383525428, 0.9299287449827967, 0.9809841684980605], 
             UndirectedEdge[146, 228] -> 
             RGBColor[
              0.8306764068801481, 0.8681749353617194, 0.9627384122521845], 
             UndirectedEdge[63, 152] -> 
             RGBColor[
              0.9262153002586595, 0.9424545469692962, 0.9365326182404017], 
             UndirectedEdge[43, 137] -> 
             RGBColor[
              0.9677725947056242, 0.9246941550628185, 0.6035375037795045], 
             UndirectedEdge[97, 141] -> 
             RGBColor[
              0.9793448395017402, 0.9482026428398005, 0.5749136461359741], 
             UndirectedEdge[25, 207] -> 
             RGBColor[
              0.9817530137447799, 0.9854576589835085, 0.8954248883074506], 
             UndirectedEdge[214, 310] -> 
             RGBColor[
              0.9885192525553612, 0.98952043013696, 0.8399292265870297], 
             UndirectedEdge[37, 87] -> 
             RGBColor[
              0.9796919872923646, 0.9843748978907401, 0.9192603477227426], 
             UndirectedEdge[146, 262] -> 
             RGBColor[
              0.976967270476087, 0.9803448842066405, 0.8290277494276972], 
             UndirectedEdge[322, 364] -> 
             RGBColor[
              0.9444672551521378, 0.8556602048762132, 0.6015787394399048], 
             UndirectedEdge[219, 311] -> 
             RGBColor[
              0.9799027376737037, 0.9432718326133642, 0.5299916271454198], 
             UndirectedEdge[5, 260] -> 
             RGBColor[
              0.9787974813817828, 0.9837077768472473, 0.9207745129048516], 
             UndirectedEdge[204, 389] -> 
             RGBColor[
              0.8205393335380562, 0.8599548987945007, 0.9464976571274539], 
             UndirectedEdge[275, 279] -> 
             RGBColor[
              0.9267147380054037, 0.925408597428826, 0.685759084927771], 
             UndirectedEdge[78, 289] -> 
             RGBColor[
              0.8763322872457369, 0.9040806741783658, 0.9793880196866673], 
             UndirectedEdge[163, 329] -> 
             RGBColor[
              0.9943970794329146, 0.9907775607232148, 0.6572172252737041], 
             UndirectedEdge[47, 181] -> 
             RGBColor[
              0.8932048700970587, 0.9135999500746117, 0.778890820154508], 
             UndirectedEdge[267, 291] -> 
             RGBColor[
              0.9524628654858611, 0.8457939206402425, 0.29854622613276827`], 
             UndirectedEdge[28, 301] -> 
             RGBColor[
              0.7451897063547377, 0.7959982049093169, 0.7872681837234832], 
             UndirectedEdge[174, 193] -> 
             RGBColor[
              0.8524250481207483, 0.7814669407055783, 0.6180073692630362], 
             UndirectedEdge[60, 263] -> 
             RGBColor[
              0.8801491458726752, 0.8612162733754407, 0.6412196545183826], 
             UndirectedEdge[122, 385] -> 
             RGBColor[
              0.8420061605684735, 0.8413315960987522, 0.6518937568281582], 
             UndirectedEdge[282, 350] -> 
             RGBColor[
              0.6716186362289422, 0.7415424646002406, 0.9691815192076392], 
             UndirectedEdge[142, 306] -> 
             RGBColor[
              0.8017655803010557, 0.845697334370374, 0.9807082584474711], 
             UndirectedEdge[6, 289] -> 
             RGBColor[
              0.8541728236206116, 0.8866608476435128, 0.9859257315838447], 
             UndirectedEdge[3, 117] -> 
             RGBColor[
              0.9052931275947469, 0.5610673322861373, 0.3363892304700429], 
             UndirectedEdge[6, 132] -> 
             RGBColor[
              0.9475362912082401, 0.956775674676082, 0.7902455583165611], 
             UndirectedEdge[22, 394] -> 
             RGBColor[
              0.9949386156322728, 0.9915825355589165, 0.6904777306955578], 
             UndirectedEdge[11, 391] -> 
             RGBColor[
              0.9639362126003477, 0.9726242669231471, 0.9459307645121535], 
             UndirectedEdge[34, 249] -> 
             RGBColor[
              0.6938726229209737, 0.5853079553584345, 0.5891388389163815], 
             UndirectedEdge[269, 306] -> 
             RGBColor[
              0.6883664830946388, 0.754598522455167, 0.97112219026541], 
             UndirectedEdge[69, 394] -> 
             RGBColor[
              0.9909672679687923, 0.9904179241447302, 0.7910128358377128], 
             UndirectedEdge[361, 369] -> 
             RGBColor[
              0.9845979975608187, 0.9867339251988692, 0.8527450467369482], 
             UndirectedEdge[85, 184] -> 
             RGBColor[
              0.9696577063187255, 0.9763254864217585, 0.9109053497009796], 
             UndirectedEdge[73, 96] -> 
             RGBColor[
              0.9908906356844138, 0.989173573043227, 0.7041351282937698], 
             UndirectedEdge[71, 382] -> 
             RGBColor[
              0.9937230745002601, 0.9909056034425989, 0.6979544678169861], 
             UndirectedEdge[122, 165] -> 
             RGBColor[
              0.8858327518068854, 0.8755692622686297, 0.6562619818600222], 
             UndirectedEdge[321, 331] -> 
             RGBColor[
              0.9894544351642727, 0.9747298422435149, 0.5291462544497686], 
             UndirectedEdge[296, 374] -> 
             RGBColor[
              0.8071238501608529, 0.6575899644880068, 0.5954084369292616], 
             UndirectedEdge[66, 297] -> 
             RGBColor[
              0.8892098954936838, 0.899539802176038, 0.6877501526055632], 
             UndirectedEdge[75, 145] -> 
             RGBColor[
              0.9930215868452472, 0.9874822048248107, 0.4818209777581218], 
             UndirectedEdge[105, 239] -> 
             RGBColor[
              0.8003744297944617, 0.84397785471718, 0.9807375013037644], 
             UndirectedEdge[92, 354] -> 
             RGBColor[
              0.8601902190204709, 0.8910064452898514, 0.954295447834529], 
             UndirectedEdge[188, 369] -> 
             RGBColor[
              0.9533682978701707, 0.8704621014732762, 0.5928452669136579], 
             UndirectedEdge[170, 251] -> 
             RGBColor[
              0.9758529672353999, 0.9809674398196793, 0.9013829023607834], 
             UndirectedEdge[53, 68] -> 
             RGBColor[
              0.76136720093069, 0.8091881881223582, 0.7931613460643281], 
             UndirectedEdge[274, 318] -> 
             RGBColor[
              0.9245672256428724, 0.9396793937924963, 0.8729327511839505], 
             UndirectedEdge[179, 359] -> 
             RGBColor[
              0.6920927877748111, 0.7579900404329241, 0.9709938926368477], 
             UndirectedEdge[20, 328] -> 
             RGBColor[
              0.9425328271183182, 0.9559859454209175, 0.9587337659918556], 
             UndirectedEdge[307, 352] -> 
             RGBColor[
              0.8831339438692075, 0.9093559694870139, 0.9781317339680682], 
             UndirectedEdge[6, 216] -> 
             RGBColor[
              0.9451534342981913, 0.9568823869520838, 0.9091187035452342], 
             UndirectedEdge[297, 385] -> 
             RGBColor[
              0.8502361241670271, 0.8690931958040209, 0.6838656113103225], 
             UndirectedEdge[40, 348] -> 
             RGBColor[
              0.9674649816847032, 0.9722609368487082, 0.765992587255194], 
             UndirectedEdge[229, 329] -> 
             RGBColor[
              0.9633846394840623, 0.9693494133710138, 0.786625558222263], 
             UndirectedEdge[6, 213] -> 
             RGBColor[
              0.8294812436684014, 0.8673715977218881, 0.983464705650142], 
             UndirectedEdge[189, 374] -> 
             RGBColor[
              0.9340902896293939, 0.7545317156620446, 0.44921433254055154`], 
             UndirectedEdge[97, 140] -> 
             RGBColor[
              0.9901950322252886, 0.9902134080960481, 0.8121572206775663], 
             UndirectedEdge[34, 386] -> 
             RGBColor[
              0.9387148758869401, 0.7761142674451338, 0.4268389729624986], 
             UndirectedEdge[162, 313] -> 
             RGBColor[
              0.8830707554303515, 0.7057841447417563, 0.6005070826746539], 
             UndirectedEdge[258, 392] -> 
             RGBColor[
              0.9696356978670841, 0.9745125061871374, 0.8125164218154082], 
             UndirectedEdge[45, 273] -> 
             RGBColor[
              0.994597370857158, 0.9920338882552684, 0.7391990766603176], 
             UndirectedEdge[226, 393] -> 
             RGBColor[
              0.9520995084948347, 0.8438601112815041, 0.5327341057924991], 
             UndirectedEdge[88, 168] -> 
             RGBColor[
              0.7996410934412647, 0.8442755887217995, 0.9771431696278335], 
             UndirectedEdge[188, 327] -> 
             RGBColor[
              0.8760266442848789, 0.8098616443810893, 0.6225547619463301], 
             UndirectedEdge[59, 349] -> 
             RGBColor[
              0.9930025822181969, 0.9865089508079321, 0.5590544423891495], 
             UndirectedEdge[260, 398] -> 
             RGBColor[
              0.9865106034988239, 0.9849242506452651, 0.6700102313711516], 
             UndirectedEdge[248, 353] -> 
             RGBColor[
              0.956987763050871, 0.959948873738969, 0.7039483568235925], 
             UndirectedEdge[30, 389] -> 
             RGBColor[
              0.8155575558772503, 0.817521027620612, 0.644659531100557], 
             UndirectedEdge[216, 311] -> 
             RGBColor[
              0.977264524942556, 0.94218086385006, 0.5737136395762275], 
             UndirectedEdge[66, 307] -> 
             RGBColor[
              0.8061790319082106, 0.8485124540050506, 0.9813160497953721], 
             UndirectedEdge[94, 225] -> 
             RGBColor[
              0.984845077054253, 0.9866070989701097, 0.8383952145212976], 
             UndirectedEdge[177, 324] -> 
             RGBColor[
              0.8869056324665474, 0.6052137225289682, 0.5822294909231738], 
             UndirectedEdge[79, 320] -> 
             RGBColor[
              0.8163355755699582, 0.8565355991458319, 0.9392302082293318], 
             UndirectedEdge[133, 234] -> 
             RGBColor[
              0.7193505794787756, 0.7761086887247712, 0.8645996571911357], 
             UndirectedEdge[35, 195] -> 
             RGBColor[
              0.94280173896892, 0.956788680476641, 0.9791565629760779], 
             UndirectedEdge[34, 86] -> 
             RGBColor[
              0.9150747294813624, 0.7609550255732493, 0.5992798326317653], 
             UndirectedEdge[98, 131] -> 
             RGBColor[
              0.9914424791818321, 0.9907292594705034, 0.7914837963184005], 
             UndirectedEdge[173, 261] -> 
             RGBColor[
              0.9742920571657474, 0.980183037592713, 0.9210298405723005], 
             UndirectedEdge[103, 331] -> 
             RGBColor[
              0.9936836888867343, 0.9888983741427666, 0.5538866989538409], 
             UndirectedEdge[135, 322] -> 
             RGBColor[
              0.9480316531455815, 0.8583185270635576, 0.5955451433808896], 
             UndirectedEdge[50, 181] -> 
             RGBColor[
              0.8931147044000263, 0.9134070947658095, 0.7690768404707033], 
             UndirectedEdge[35, 153] -> 
             RGBColor[
              0.962380410095093, 0.9668374956759533, 0.7082709871967772], 
             UndirectedEdge[121, 362] -> 
             RGBColor[
              0.9927093123809752, 0.9903002627625352, 0.7012258803273087], 
             UndirectedEdge[84, 152] -> 
             RGBColor[
              0.7481900762243061, 0.8033945038964967, 0.9755687308108789], 
             UndirectedEdge[295, 345] -> 
             RGBColor[
              0.9929388943832134, 0.9889662261499708, 0.593549738890772], 
             UndirectedEdge[22, 266] -> 
             RGBColor[
              0.9948821184258974, 0.9916739957889784, 0.6997604757032354], 
             UndirectedEdge[271, 335] -> 
             RGBColor[
              0.9754154414407146, 0.9800899200448505, 0.8774390413271739], 
             UndirectedEdge[175, 261] -> 
             RGBColor[
              0.9761012681537746, 0.9809311928308638, 0.8910465324127399], 
             UndirectedEdge[59, 254] -> 
             RGBColor[
              0.831668828935424, 0.8662807850339467, 0.8330896131081948], 
             UndirectedEdge[53, 270] -> 
             RGBColor[
              0.9947167372506291, 0.9911079601359266, 0.6663276381283092], 
             UndirectedEdge[214, 300] -> 
             RGBColor[
              0.9919471459985355, 0.9886771601470342, 0.6187844472990189], 
             UndirectedEdge[3, 386] -> 
             RGBColor[
              0.9058489254872855, 0.5622561277784903, 0.39688440108587186`], 
             UndirectedEdge[299, 336] -> 
             RGBColor[
              0.8284403904432045, 0.8667052121439198, 0.983322023673809], 
             UndirectedEdge[110, 351] -> 
             RGBColor[
              0.8443990985596307, 0.8788833180107739, 0.9635043736950223], 
             UndirectedEdge[172, 328] -> 
             RGBColor[
              0.9793555057885421, 0.9680467952255576, 0.6576221721351408], 
             UndirectedEdge[185, 302] -> 
             RGBColor[
              0.9086726173282265, 0.9274665473116248, 0.891438513811186], 
             UndirectedEdge[370, 391] -> 
             RGBColor[
              0.8442970346406266, 0.8783972678904315, 0.9429265003261175], 
             UndirectedEdge[50, 364] -> 
             RGBColor[
              0.9790867097850837, 0.980995332812097, 0.7516306561242734], 
             UndirectedEdge[73, 195] -> 
             RGBColor[
              0.9703969814145292, 0.9768037288432809, 0.9063800360799099], 
             UndirectedEdge[80, 332] -> 
             RGBColor[
              0.9653559950920387, 0.9725803563652418, 0.8941426113212364], 
             UndirectedEdge[5, 267] -> 
             RGBColor[
              0.9569078131570314, 0.8855894710884029, 0.5965423129348423], 
             UndirectedEdge[136, 246] -> 
             RGBColor[
              0.9817516627445974, 0.982290164474565, 0.6921579231606517], 
             UndirectedEdge[59, 246] -> 
             RGBColor[
              0.982893862521851, 0.9847332143039984, 0.8164793200747735], 
             UndirectedEdge[177, 200] -> 
             RGBColor[
              0.9325377362769036, 0.9489139181613578, 0.9889072596032411], 
             UndirectedEdge[17, 157] -> 
             RGBColor[
              0.9944788435645773, 0.991850990919307, 0.7314314813809218], 
             UndirectedEdge[151, 386] -> 
             RGBColor[
              0.9940594289749487, 0.989702044198307, 0.5947836887569484], 
             UndirectedEdge[4, 188] -> 
             RGBColor[
              0.9452779502528157, 0.8644283334669811, 0.6065401151292396], 
             UndirectedEdge[241, 255] -> 
             RGBColor[
              0.7422620283075394, 0.7924429955578162, 0.6904571928888967], 
             UndirectedEdge[62, 345] -> 
             RGBColor[
              0.988016360828226, 0.9868176057124769, 0.6700673099547203], 
             UndirectedEdge[57, 114] -> 
             RGBColor[
              0.8723791052898768, 0.9003472206947745, 0.9463342017779228], 
             UndirectedEdge[32, 137] -> 
             RGBColor[
              0.9594866986735151, 0.8750012630295598, 0.29711390395194676`], 
             UndirectedEdge[152, 175] -> 
             RGBColor[
              0.9277437820282675, 0.9430866134612189, 0.9112017197339768], 
             UndirectedEdge[99, 235] -> 
             RGBColor[
              0.9040523315456185, 0.9252949046481304, 0.9547951762048963], 
             UndirectedEdge[156, 256] -> 
             RGBColor[
              0.9251293639841086, 0.9424226917082132, 0.9679532911640536], 
             UndirectedEdge[48, 286] -> 
             RGBColor[
              0.9913290041901166, 0.9887499200596594, 0.6528982298276366], 
             UndirectedEdge[61, 262] -> 
             RGBColor[
              0.5921321770905073, 0.654018503077834, 0.8188225151602839], 
             UndirectedEdge[146, 385] -> 
             RGBColor[
              0.8372760116724587, 0.8733305967843266, 0.9633961991810687], 
             UndirectedEdge[29, 150] -> 
             RGBColor[
              0.8684214573771747, 0.8979197137128043, 0.9873120079252635], 
             UndirectedEdge[141, 220] -> 
             RGBColor[
              0.9689579200133916, 0.9414082476359857, 0.6351353187938578], 
             UndirectedEdge[152, 242] -> 
             RGBColor[
              0.8748382134860101, 0.7290515795326433, 0.6056114395355043], 
             UndirectedEdge[95, 151] -> 
             RGBColor[
              0.9945034731436528, 0.9906518097754129, 0.6431151561974333], 
             UndirectedEdge[252, 293] -> 
             RGBColor[
              0.9862485178821874, 0.9640128890498891, 0.5084131999617163], 
             UndirectedEdge[93, 390] -> 
             RGBColor[
              0.9750025041445595, 0.947827334553206, 0.6289602034571609], 
             UndirectedEdge[229, 249] -> 
             RGBColor[
              0.7187709558088351, 0.7790319878853056, 0.9738037809069657], 
             UndirectedEdge[96, 153] -> 
             RGBColor[
              0.9928282367588652, 0.9867046759655113, 0.49172561465229303`], 
             UndirectedEdge[202, 217] -> 
             RGBColor[
              0.9937702277391334, 0.9890834719976282, 0.5633059189815965], 
             UndirectedEdge[163, 304] -> 
             RGBColor[
              0.8620617070567231, 0.8902816523078834, 0.8541444705600627], 
             UndirectedEdge[18, 323] -> 
             RGBColor[
              0.977296064454811, 0.9339912643316413, 0.4585750627646281], 
             UndirectedEdge[152, 264] -> 
             RGBColor[
              0.913867183152705, 0.9335032213462486, 0.9689831482357742], 
             UndirectedEdge[23, 169] -> 
             RGBColor[
              0.9935264872146317, 0.9882061333177892, 0.5670481367171818], 
             UndirectedEdge[290, 342] -> 
             RGBColor[
              0.9761012931656333, 0.9600455601842128, 0.6512976304587463], 
             UndirectedEdge[285, 330] -> 
             RGBColor[
              0.9805316720063679, 0.9846410790873998, 0.9017150138677679], 
             UndirectedEdge[55, 192] -> 
             RGBColor[
              0.9674801675804512, 0.9497908845632663, 0.6577710810098765], 
             UndirectedEdge[161, 170] -> 
             RGBColor[
              0.978003420508758, 0.981856707512341, 0.865744326426567], 
             UndirectedEdge[42, 205] -> 
             RGBColor[
              0.9918700374565097, 0.9889313565382118, 0.6408575316293548], 
             UndirectedEdge[267, 398] -> 
             RGBColor[
              0.9646209352740724, 0.8868059448864207, 0.3457780314011422], 
             UndirectedEdge[32, 199] -> 
             RGBColor[
              0.8941295221498153, 0.8742204925118813, 0.6455704301822669], 
             UndirectedEdge[154, 385] -> 
             RGBColor[
              0.727661208166315, 0.7871737333403193, 0.9734901269155605], 
             UndirectedEdge[91, 190] -> 
             RGBColor[
              0.9845109922960866, 0.9731824926924875, 0.647190634654448], 
             UndirectedEdge[94, 380] -> 
             RGBColor[
              0.9842826894837644, 0.984202179083444, 0.6898079253370348], 
             UndirectedEdge[119, 288] -> 
             RGBColor[
              0.9805520571147401, 0.982653552355902, 0.7940095716828064], 
             UndirectedEdge[65, 251] -> 
             RGBColor[
              0.9753449967654058, 0.9383429603602258, 0.5844842810611068], 
             UndirectedEdge[198, 216] -> 
             RGBColor[
              0.9685055974933143, 0.975191726873375, 0.9005620623819186], 
             UndirectedEdge[101, 182] -> 
             RGBColor[
              0.7614037234157564, 0.8136431892128981, 0.977159988541956], 
             UndirectedEdge[11, 230] -> 
             RGBColor[
              0.9218193521606528, 0.940248217308703, 0.9837538454788466], 
             UndirectedEdge[53, 101] -> 
             RGBColor[
              0.9636166963781057, 0.9698457596028216, 0.8118835190497389], 
             UndirectedEdge[202, 264] -> 
             RGBColor[
              0.9768613936515178, 0.97860535009144, 0.6974477369843239], 
             UndirectedEdge[336, 367] -> 
             RGBColor[
              0.9338910118238393, 0.8861129481793713, 0.6348167678260102], 
             UndirectedEdge[13, 132] -> 
             RGBColor[
              0.9421771298420905, 0.9525024248732743, 0.789734396721278], 
             UndirectedEdge[146, 307] -> 
             RGBColor[
              0.8888049933135698, 0.9135854288771281, 0.968532126505343], 
             UndirectedEdge[75, 133] -> 
             RGBColor[
              0.9925545637784978, 0.9891730974727524, 0.6265090284954644], 
             UndirectedEdge[153, 369] -> 
             RGBColor[
              0.9845465748417341, 0.9834425156669466, 0.673298804782934], 
             UndirectedEdge[20, 181] -> 
             RGBColor[
              0.8510008803203777, 0.8842511121724703, 0.9855914808853319], 
             UndirectedEdge[112, 394] -> 
             RGBColor[
              0.9328562163384205, 0.9458300297250934, 0.8504411231455666], 
             UndirectedEdge[279, 306] -> 
             RGBColor[
              0.8849327479809475, 0.9110853686532089, 0.9888868695628545], 
             UndirectedEdge[34, 68] -> 
             RGBColor[
              0.7056997382397551, 0.5949097403796946, 0.5900699127584269], 
             UndirectedEdge[4, 284] -> 
             RGBColor[
              0.9347990016525829, 0.8228827941696768, 0.5981085071129553], 
             UndirectedEdge[193, 235] -> 
             RGBColor[
              0.9495920413207717, 0.8575986023038167, 0.5914423737383043], 
             UndirectedEdge[296, 316] -> 
             RGBColor[
              0.8666702266048784, 0.8917978497271086, 0.6999112449692687], 
             UndirectedEdge[117, 223] -> 
             RGBColor[
              0.771332590501909, 0.8165363383498376, 0.7331151123262771], 
             UndirectedEdge[37, 110] -> 
             RGBColor[
              0.9678445800884585, 0.9755391209964157, 0.9393149178202791], 
             UndirectedEdge[83, 349] -> 
             RGBColor[
              0.7257446230621611, 0.7770836054892676, 0.6850884153294214], 
             UndirectedEdge[192, 348] -> 
             RGBColor[
              0.9763006353521377, 0.9788505528868259, 0.7510361303037777], 
             UndirectedEdge[97, 394] -> 
             RGBColor[
              0.9925360254947484, 0.9910666456969426, 0.7650144638182832], 
             UndirectedEdge[2, 352] -> 
             RGBColor[
              0.940386646871942, 0.9549976194513161, 0.9835952284721203], 
             UndirectedEdge[69, 350] -> 
             RGBColor[
              0.7532341155347455, 0.8048721516375736, 0.9119951051941182], 
             UndirectedEdge[164, 304] -> 
             RGBColor[
              0.8598159100045919, 0.8893529575124755, 0.8913631396503411], 
             UndirectedEdge[141, 350] -> 
             RGBColor[
              0.7442245619307759, 0.7636225379595396, 0.644247377019761], 
             UndirectedEdge[114, 356] -> 
             RGBColor[
              0.9616072181234053, 0.9708873066556221, 0.9498731446625729], 
             UndirectedEdge[383, 390] -> 
             RGBColor[
              0.9780133925604833, 0.9498047772836945, 0.6118587016614877], 
             UndirectedEdge[297, 307] -> 
             RGBColor[
              0.9017651058081384, 0.9093480278968225, 0.6890015386345969], 
             UndirectedEdge[40, 58] -> 
             RGBColor[
              0.7294284007853853, 0.7874784946700372, 0.9697031225345617], 
             UndirectedEdge[173, 295] -> 
             RGBColor[
              0.9892697522883382, 0.9898307810635094, 0.8274915037805504], 
             UndirectedEdge[161, 239] -> 
             RGBColor[
              0.8969706650094937, 0.9181232862787693, 0.8834923398724415], 
             UndirectedEdge[35, 369] -> 
             RGBColor[
              0.9550137313216733, 0.9658963643780223, 0.9584848453205788], 
             UndirectedEdge[303, 313] -> 
             RGBColor[
              0.9036376318988617, 0.9260001353588054, 0.9906709580889923], 
             UndirectedEdge[237, 349] -> 
             RGBColor[
              0.9228991916389446, 0.9341695986221215, 0.7027595229214513], 
             UndirectedEdge[21, 263] -> 
             RGBColor[
              0.9001544678304245, 0.8770033068751861, 0.6431714775973336], 
             UndirectedEdge[126, 274] -> 
             RGBColor[
              0.938176920831777, 0.9505313953107943, 0.8742308560605866], 
             UndirectedEdge[331, 346] -> 
             RGBColor[
              0.9866198614647521, 0.9872980434448231, 0.793191019137496], 
             UndirectedEdge[106, 345] -> 
             RGBColor[
              0.9937632956889924, 0.9890686450433143, 0.5625514081033893]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.9930981029699048, 0.9876458650784864, 0.4901492857243145], 
             316 -> RGBColor[
              0.9924087044400677, 0.986054918934698, 0.42500967955588526`], 
             308 -> RGBColor[
              0.8918366433866016, 0.6017372844598674, 0.2314581827263479], 
             160 -> RGBColor[
              0.9931572817724736, 0.99143837441015, 0.7630650796246227], 245 -> 
             RGBColor[
              0.8854446033570201, 0.9114935082361452, 0.9889356907855631], 
             155 -> RGBColor[
              0.8895900557744938, 0.5915360548171535, 0.22958357495390364`], 
             213 -> RGBColor[
              0.7579059934595314, 0.8108011894802617, 0.9765046444600002], 
             352 -> RGBColor[
              0.9475336455157499, 0.9603912592481928, 0.9736960321117305], 27 -> 
             RGBColor[
              0.99454826841877, 0.9907476223393914, 0.647990845449543], 367 -> 
             RGBColor[
              0.9485709298801769, 0.8338079052362447, 0.27747716686740376`], 
             19 -> RGBColor[
              0.9950610838039037, 0.9918444825946036, 0.703807635391636], 164 -> 
             RGBColor[
              0.9903808523684744, 0.9902902495006153, 0.809077700017861], 190 -> 
             RGBColor[
              0.9842028513624264, 0.9583746496778858, 0.39313148989457525`], 
             103 -> RGBColor[
              0.9926613588073495, 0.9867117134763892, 0.44261237890271976`], 
             138 -> RGBColor[
              0.9948462733133558, 0.9921368158174075, 0.7350741188222116], 
             291 -> RGBColor[
              0.9676100282400794, 0.9024031611060671, 0.3286715053559796], 28 -> 
             RGBColor[
              0.4960785330873142, 0.6017779271003448, 0.9534722658016273], 
             337 -> RGBColor[
              0.8984675166566474, 0.9218776258037035, 0.9901778278817734], 
             195 -> RGBColor[
              0.9527559113628077, 0.9642860165662529, 0.9648560982177338], 
             114 -> RGBColor[
              0.9818177586382887, 0.9859602946798992, 0.9156619713240557], 93 -> 
             RGBColor[
              0.9797837950891534, 0.9844433679952637, 0.9191049410700876], 34 -> 
             RGBColor[
              0.8830509007993093, 0.5618432793332868, 0.22412714375325363`], 
             161 -> RGBColor[
              0.9917692711572328, 0.9908643963505023, 0.7860680075754897], 22 -> 
             RGBColor[
              0.9947283309067146, 0.9911327577939948, 0.667589536045451], 124 -> 
             RGBColor[
              0.7638332386800415, 0.8154315984952564, 0.9770954168703249], 84 -> 
             RGBColor[
              0.6296937704822898, 0.7102527961154351, 0.9639909467381014], 46 -> 
             RGBColor[
              0.9945708916523989, 0.9907960111485639, 0.6504532448156362], 
             241 -> RGBColor[
              0.9925249329479426, 0.9864199123578882, 0.42776326602909176`], 
             185 -> RGBColor[
              0.9909543156139771, 0.9905273912899638, 0.7995739299645763], 
             390 -> RGBColor[
              0.9702212131999656, 0.9112113011111482, 0.33881546584423405`], 
             121 -> RGBColor[
              0.9941774681806118, 0.9899545181236261, 0.6076315278398451], 
             322 -> RGBColor[
              0.9244844118493514, 0.7383128876003471, 0.2580965890765579], 
             126 -> RGBColor[
              0.8829970972010354, 0.9095419332631477, 0.9887022454634907], 
             236 -> RGBColor[
              0.9806103387997466, 0.9462562612419035, 0.37917525697763593`], 
             78 -> RGBColor[
              0.9453754211275218, 0.9587816590332203, 0.9773493430459291], 
             376 -> RGBColor[
              0.9897319838092536, 0.9900219256762162, 0.8198311312621519], 
             254 -> RGBColor[
              0.6683243893320351, 0.7408193594904537, 0.9675759873482581], 
             290 -> RGBColor[
              0.9733046642543789, 0.979611242827292, 0.9300724195453993], 251 -> 
             RGBColor[
              0.9874683646105168, 0.9890858609651786, 0.8573451594439228], 
             165 -> RGBColor[
              0.8033294614172664, 0.846286347879987, 0.9810320312395849], 100 -> 
             RGBColor[
              0.9662013034335865, 0.9743135679578309, 0.9420965565617845], 
             235 -> RGBColor[
              0.9758700570693939, 0.981524508588285, 0.9257298786711841], 70 -> 
             RGBColor[
              0.7033006226999979, 0.7681430588267255, 0.9710620914188923], 
             234 -> RGBColor[
              0.4465371021211449, 0.5611897270751728, 0.9496739271832719], 
             257 -> RGBColor[
              0.9937350429713578, 0.989008215337082, 0.5594762741444419], 135 -> 
             RGBColor[
              0.9715788944418117, 0.9783241665267681, 0.9329936976852213], 
             265 -> RGBColor[
              0.9935235534156595, 0.9885558605623173, 0.5364569411689146], 
             111 -> RGBColor[
              0.9879573662879647, 0.9892880757255732, 0.8492411361528371], 
             381 -> RGBColor[
              0.9858883073581551, 0.9884324666857078, 0.8835307971726473], 
             182 -> RGBColor[
              0.5899598802564805, 0.6779950340387672, 0.96086294934949], 188 -> 
             RGBColor[
              0.9295566996720268, 0.7584228185775369, 0.2621778709205801], 
             154 -> RGBColor[
              0.7396461373921873, 0.7965364511404064, 0.974684672655264], 336 -> 
             RGBColor[
              0.9192110937675015, 0.9384179911224979, 0.9921563687846167], 
             315 -> RGBColor[
              0.9470985581634156, 0.960066771813212, 0.974432521510277], 368 -> 
             RGBColor[
              0.9870036618968718, 0.9888936944507714, 0.8650464860210926], 
             269 -> RGBColor[
              0.4784696829954938, 0.5874822693261484, 0.9520860326190559], 
             208 -> RGBColor[
              0.9716016843049247, 0.9158679542982049, 0.34417833540690645`], 
             86 -> RGBColor[
              0.9470985581634156, 0.960066771813212, 0.974432521510277], 119 -> 
             RGBColor[
              0.9945349867427694, 0.9907192141774097, 0.6465452169818905], 
             377 -> RGBColor[
              0.976545629693551, 0.932545042987622, 0.36338462965597296`], 
             140 -> RGBColor[
              0.9904669138189112, 0.9903258381220493, 0.8076514390642309], 85 -> 
             RGBColor[
              0.9517174078102171, 0.9635115023171245, 0.9666140138471638], 
             351 -> RGBColor[
              0.7292509676407094, 0.7884156655243356, 0.9736485792828212], 
             242 -> RGBColor[
              0.8829900450056977, 0.5615669473877284, 0.22407636418735213`], 
             117 -> RGBColor[
              0.9932672551894938, 0.9880076645722745, 0.5085604609400857], 47 -> 
             RGBColor[
              0.9939036525093083, 0.989368854089719, 0.5778283818129042], 81 -> 
             RGBColor[
              0.9610278402022231, 0.9704552075506486, 0.9508538803571713], 
             275 -> RGBColor[
              0.9818272632426962, 0.95036123313542, 0.3839027786415972], 23 -> 
             RGBColor[
              0.9951268066127613, 0.9919850570371549, 0.7109611575416359], 
             328 -> RGBColor[
              0.9755699812806903, 0.9813007125563988, 0.926237828709159], 110 -> 
             RGBColor[
              0.959547229478552, 0.9693509704972122, 0.9533601681072233], 6 -> 
             RGBColor[
              0.9010564938772713, 0.9239420059635144, 0.9904247668402838], 
             218 -> RGBColor[
              0.9951556318612745, 0.992264743527124, 0.7299472470889401], 108 -> 
             RGBColor[
              0.7575558003784784, 0.8105276159837771, 0.9764697404864213], 
             297 -> RGBColor[
              0.9847959693936116, 0.9603753760678099, 0.39543564144478793`], 
             157 -> RGBColor[
              0.9938308805163931, 0.9917169248014589, 0.7519018052202078], 
             354 -> RGBColor[
              0.7488015435991302, 0.8036887240529346, 0.9755971979838367], 
             385 -> RGBColor[
              0.7156762789404427, 0.777811015540232, 0.972295581175857], 270 -> 
             RGBColor[
              0.9950476483200794, 0.9918157454532393, 0.7023452658915625], 
             392 -> RGBColor[
              0.994535498815278, 0.990720309448727, 0.646600952914301], 33 -> 
             RGBColor[
              0.7033006226999979, 0.7681430588267255, 0.9710620914188923], 
             252 -> RGBColor[
              0.99454826841877, 0.9907476223393914, 0.647990845449543], 394 -> 
             RGBColor[
              0.9951489003578309, 0.9920323133238382, 0.7133659253456646], 
             260 -> RGBColor[
              0.9810950391811458, 0.9854212916921066, 0.9168853468495755], 
             159 -> RGBColor[
              0.9944374639234123, 0.9905106227278742, 0.6359304599359327], 
             183 -> RGBColor[
              0.9946822468659847, 0.9920689866661322, 0.7377924615419899], 99 -> 
             RGBColor[
              0.8322346060218431, 0.8690653007079757, 0.9838604737386085], 
             329 -> RGBColor[
              0.9939217123930923, 0.9894074823549984, 0.579794088710104], 309 -> 
             RGBColor[
              0.8997062140793418, 0.9228653295050142, 0.9902959759477483], 17 -> 
             RGBColor[
              0.9951268066127613, 0.9919850570371549, 0.7109611575416359], 
             349 -> RGBColor[
              0.990991895897581, 0.9812756910384246, 0.4195056459101673], 347 -> 
             RGBColor[
              0.991926167816502, 0.9844272095984236, 0.42313511589272756`], 
             340 -> RGBColor[
              0.9848737240708053, 0.9880129104227875, 0.9003450679014151], 
             277 -> RGBColor[
              0.9927113144662119, 0.9868185635794038, 0.4480497440792934], 
             104 -> RGBColor[
              0.8178076717190462, 0.8575968358062114, 0.9824750839358987], 79 -> 
             RGBColor[
              0.9835116773525437, 0.9872236164834534, 0.912794608785579], 327 -> 
             RGBColor[
              0.8224965888977309, 0.8613004701846418, 0.9829316529720802], 
             191 -> RGBColor[
              0.9950132479967853, 0.9917421666401193, 0.6986010029951835], 50 -> 
             RGBColor[
              0.9937233211152434, 0.9889831434721147, 0.5582004224452948], 
             225 -> RGBColor[
              0.9938886437690299, 0.9917408113908721, 0.7509445186375109], 61 -> 
             RGBColor[
              0.18920555763331504`, 0.31619741577080834`, 0.9340863486514539],
              196 -> RGBColor[
              0.9876134143441128, 0.9891458427576286, 0.8549413099815601], 1 -> 
             RGBColor[
              0.9565833664694015, 0.865207641770265, 0.28583500658724703`], 
             263 -> RGBColor[
              0.9606872700703839, 0.8790510722587677, 0.30177789711989755`], 
             201 -> RGBColor[
              0.9496264551862436, 0.9619520732737856, 0.9701534512317656], 
             371 -> RGBColor[
              0.9507795863787943, 0.962812076629111, 0.9682015009075595], 293 -> 
             RGBColor[
              0.9779487673456047, 0.937278155760387, 0.36883555447388966`], 
             362 -> RGBColor[
              0.9912411565813384, 0.9906460074014444, 0.7948202328147723], 
             184 -> RGBColor[
              0.9875980048272339, 0.9891394705263927, 0.8551966855547953], 
             106 -> RGBColor[
              0.9950055470740765, 0.991725695145128, 0.6977628050829171], 206 -> 
             RGBColor[
              0.9845466448509956, 0.9878776547598437, 0.9057656170275481], 
             358 -> RGBColor[
              0.9469127501725392, 0.827233775251093, 0.27614295655215826`], 
             247 -> RGBColor[
              0.944438041770969, 0.9580825630439211, 0.9789360817888816], 220 -> 
             RGBColor[
              0.9691493116549689, 0.9765121876624174, 0.9371063476066693], 
             107 -> RGBColor[
              0.9637527974391588, 0.9724874761962473, 0.9462412385377107], 
             375 -> RGBColor[
              0.9500664601080605, 0.9622802282240348, 0.9694086376707924], 
             131 -> RGBColor[
              0.990693634487293, 0.9904195929448806, 0.8038940908548621], 127 -> 
             RGBColor[
              0.9861027501088815, 0.9885211442740605, 0.879976925833062], 210 -> 
             RGBColor[
              0.9389671700446511, 0.9540023958681635, 0.988196840589668], 357 -> 
             RGBColor[
              0.6901916528085199, 0.7579022319156415, 0.9697555118103984], 
             181 -> RGBColor[
              0.7925060876848091, 0.8378310460595044, 0.9799532584961118], 
             194 -> RGBColor[
              0.9840015822208105, 0.987588986732061, 0.911965327631257], 118 -> 
             RGBColor[
              0.9915299495520321, 0.990765430716467, 0.7900341859181265], 348 -> 
             RGBColor[
              0.993627233038455, 0.988777620791859, 0.5477418282737454], 276 -> 
             RGBColor[
              0.9009664104844937, 0.6431934245401149, 0.2390762841838989], 
             305 -> RGBColor[
              0.8285932336245045, 0.8661617692007586, 0.9835131563886589], 
             343 -> RGBColor[
              0.9935430194371534, 0.9885974964139762, 0.5385756974781768], 
             280 -> RGBColor[
              0.8818057113156129, 0.5561891647092145, 0.2230881271256702], 
             189 -> RGBColor[
              0.9948646277067709, 0.9914242828675949, 0.682424601605232], 168 -> 
             RGBColor[
              0.6599310704440303, 0.7342624349835583, 0.9667394197615263], 
             363 -> RGBColor[
              0.73439692210564, 0.7924357242630419, 0.9741614799322069], 41 -> 
             RGBColor[
              0.9127547460405782, 0.6918086713479827, 0.24865862463617577`], 
             14 -> RGBColor[
              0.858035974250634, 0.8896386113741305, 0.9863214312734239], 77 -> 
             RGBColor[
              0.9938716603506715, 0.9893004260972983, 0.5743462327780071], 51 -> 
             RGBColor[
              0.9929120584675252, 0.9913369682716023, 0.7671290644051899], 
             179 -> RGBColor[
              0.8476370994559485, 0.8813468308827848, 0.9853295773123216], 
             223 -> RGBColor[
              0.5493979258143242, 0.6450650121274007, 0.9576697637124686], 
             323 -> RGBColor[
              0.9603308209924326, 0.8778486858206146, 0.3003931597618172], 
             292 -> RGBColor[
              0.9600128683354547, 0.9696982431942767, 0.952571962980551], 396 -> 
             RGBColor[
              0.9837143740457597, 0.9567269009888411, 0.3912338477605264], 
             321 -> RGBColor[
              0.9842028513624264, 0.9583746496778858, 0.39313148989457525`], 
             143 -> RGBColor[
              0.9928888294617056, 0.9913273624807378, 0.7675140291463577], 
             112 -> RGBColor[
              0.8705635323190102, 0.8996277461263487, 0.9875163209454687], 
             197 -> RGBColor[
              0.9377511143795241, 0.9530954635442201, 0.9902553056326147], 54 -> 
             RGBColor[
              0.9788345532930401, 0.9837354250179633, 0.920711759828996], 71 -> 
             RGBColor[
              0.9943932174373962, 0.9904159839682918, 0.631114502990743], 177 -> 
             RGBColor[
              0.9407548308301295, 0.9553356303549474, 0.9851707971764582], 
             158 -> 
             RGBColor[
              0.9907718623586014, 0.9904519421800312, 0.8025976525800397], 
             226 -> RGBColor[
              0.9142138688124489, 0.6975936069146104, 0.2498326690684364], 
             350 -> RGBColor[
              0.5196825954897373, 0.6209407683095252, 0.9553304640584755], 
             203 -> RGBColor[
              0.7902985836625713, 0.8361065271396804, 0.9797332351254732], 
             115 -> RGBColor[
              0.9428742686530392, 0.9569163036130126, 0.9815831417801871], 
             173 -> RGBColor[
              0.985182760114158, 0.9881407047685778, 0.8952235409034184], 212 -> 
             RGBColor[
              0.9715045643658341, 0.9155403459388063, 0.3438010427831012], 
             129 -> RGBColor[
              0.9942690609386399, 0.9901504257715997, 0.6176008343062163], 
             279 -> RGBColor[
              0.8716022127681112, 0.9004559617222321, 0.9876153912139449], 26 -> 
             RGBColor[
              0.9926639402283325, 0.9867172348748501, 0.442893350646033], 40 -> 
             RGBColor[
              0.9413027303309515, 0.9557442529055573, 0.9842433462366427], 
             146 -> RGBColor[
              0.9588757444044745, 0.9688501780284212, 0.9544968171862804], 
             386 -> RGBColor[
              0.9943788509745709, 0.9903852555569806, 0.6295508021717436], 
             192 -> RGBColor[
              0.9589740376658206, 0.9689234849817926, 0.95433043233381], 300 -> 
             RGBColor[
              0.9926613588073495, 0.9867117134763892, 0.44261237890271976`], 
             221 -> RGBColor[
              0.9815894789221714, 0.9495591307878762, 0.38297903145815937`], 
             62 -> RGBColor[
              0.9835116773525437, 0.9872236164834534, 0.912794608785579], 286 -> 
             RGBColor[
              0.9930420039207138, 0.9875258748847511, 0.48404325042308827`], 
             152 -> RGBColor[
              0.8666863819663225, 0.8965362116775583, 0.9871465148836565], 64 -> 
             RGBColor[
              0.9950629810454223, 0.9918485406023716, 0.7040141384225366], 
             307 -> RGBColor[
              0.8187342422226651, 0.858320679725835, 0.9825674358244058], 37 -> 
             RGBColor[
              0.976141930698365, 0.9817272714956193, 0.9252696675333348], 148 -> 
             RGBColor[
              0.9214191180207684, 0.9401786097268311, 0.9923669721090197], 
             261 -> RGBColor[
              0.963401354217337, 0.9722253704168481, 0.9468361402411827], 387 -> 
             RGBColor[
              0.9778516482124185, 0.983002376018195, 0.9223755617477865], 15 -> 
             RGBColor[
              0.9930023290348572, 0.9874410143156499, 0.47972488394260204`], 
             136 -> RGBColor[
              0.9927288689843058, 0.9868561109185727, 0.4499604450398878], 
             198 -> RGBColor[
              0.9477608202675175, 0.9605606858060965, 0.9733114845136526], 63 -> 
             RGBColor[
              0.9857442185509964, 0.9883728822610343, 0.885918721597147], 310 -> 
             RGBColor[
              0.9858055719210008, 0.9883982534562408, 0.8849019374787414], 
             171 -> RGBColor[
              0.9628375644303192, 0.9718048969168112, 0.9477904892906773], 
             395 -> RGBColor[
              0.9233140255721495, 0.7336726960193483, 0.25715486880542443`], 
             311 -> RGBColor[
              0.9652786751660007, 0.8945389597594666, 0.31961463890227043`], 
             353 -> RGBColor[
              0.9240722183673883, 0.9422941199267354, 0.992620027188531], 59 -> 
             RGBColor[
              0.995013268538813, 0.9917422105774395, 0.6986032388681316], 397 -> 
             RGBColor[
              0.7669321782878086, 0.8178525136696574, 0.97740429020919], 229 -> 
             RGBColor[
              0.9328475665750322, 0.9492913443870291, 0.9934570277344219], 
             102 -> RGBColor[0.178927, 0.305394, 0.933501], 299 -> 
             RGBColor[
              0.7376696871189076, 0.7949924331653418, 0.9744876785630014], 
             128 -> RGBColor[
              0.9938823014048089, 0.9917381886602753, 0.7510496280261654], 12 -> 
             RGBColor[
              0.9935791135697694, 0.9916128126989145, 0.7560742350777349], 
             222 -> RGBColor[
              0.5433323057119659, 0.6401406684752347, 0.9571922558789123], 92 -> 
             RGBColor[
              0.9715788944418117, 0.9783241665267681, 0.9329936976852213], 
             271 -> RGBColor[
              0.9600446783547791, 0.9697219670546047, 0.9525181169152166], 
             361 -> RGBColor[
              0.9920160990533228, 0.990966466028723, 0.7819774305671608], 344 -> 
             RGBColor[
              0.9590545028333292, 0.968983495771971, 0.9541942257938947], 132 -> 
             RGBColor[
              0.994016088539209, 0.9896093433886498, 0.5900663497928385], 80 -> 
             RGBColor[
              0.9908298136729129, 0.9904759065377798, 0.8016372493287051], 
             324 -> RGBColor[
              0.8330564341029655, 0.25509181470298914`, 0.17928818466988933`],
              244 -> 
             RGBColor[
              0.9944495052534097, 0.9905363779151736, 0.6372410843956838], 
             150 -> RGBColor[
              0.8946608127405742, 0.9188422634312517, 0.9898147410639737], 
             125 -> RGBColor[
              0.9407830182315076, 0.9553566524727425, 0.9851230832583768], 
             258 -> RGBColor[
              0.9447358969188902, 0.9583047029255477, 0.9784318907165153], 
             133 -> RGBColor[
              0.9921640568364062, 0.9910276503743696, 0.7795253871989996], 
             255 -> RGBColor[
              0.49199912366713616`, 0.5984660787577442, 0.9531511197487017], 
             326 -> RGBColor[
              0.9900385762913688, 0.9901487095466383, 0.8147501003975938], 
             176 -> RGBColor[
              0.887145321777082, 0.9128496149395308, 0.9890979068267178], 230 -> 
             RGBColor[
              0.8982632831937838, 0.9217147755841857, 0.9901583479117642], 
             274 -> RGBColor[
              0.9933567444625186, 0.991520857358441, 0.7597594666576825], 87 -> 
             RGBColor[
              0.9832420438863642, 0.9870225242858608, 0.9132510279121504], 
             130 -> RGBColor[
              0.9822822956155327, 0.9863067455969183, 0.9148756313922293], 35 -> 
             RGBColor[
              0.9328475665750322, 0.9492913443870291, 0.9934570277344219], 
             379 -> RGBColor[
              0.9592125734585881, 0.8740765743119498, 0.2960489792561586], 31 -> 
             RGBColor[
              0.9858803157801309, 0.9884291619628206, 0.8836632383020504], 18 -> 
             RGBColor[
              0.9942613079171895, 0.9901338428426679, 0.616756965767439], 24 -> 
             RGBColor[
              0.9879958679599541, 0.9893039971563886, 0.8486030638088397], 
             151 -> RGBColor[
              0.9937400069753265, 0.9890188328396333, 0.5600165753421533], 
             137 -> RGBColor[
              0.9567167001764494, 0.865657407672381, 0.2863529828611705], 330 -> 
             RGBColor[
              0.9747041221652066, 0.9806549562457854, 0.9277035023394478], 
             296 -> RGBColor[
              0.740931748769689, 0.7975407805195192, 0.9748128103826521], 266 -> 
             RGBColor[
              0.9950359059450802, 0.9922152337839619, 0.7319314153610197], 
             302 -> RGBColor[
              0.826390919042476, 0.8644057033332858, 0.9833030976577956], 283 -> 
             RGBColor[
              0.7432797249484888, 0.7993750373556774, 0.9750468347050699], 
             388 -> RGBColor[
              0.9477808092651123, 0.9605755935677738, 0.97327764835469], 284 -> 
             RGBColor[
              0.9085988024715613, 0.6753317399829282, 0.24531465488801135`], 
             318 -> RGBColor[
              0.8557777068232262, 0.8878379302265517, 0.9861060357102186], 
             238 -> RGBColor[
              0.9938418300742846, 0.9892366221524103, 0.5710993912844171], 72 -> 
             RGBColor[
              0.9945706273296324, 0.9907954457888936, 0.650424474913719], 288 -> 
             RGBColor[
              0.9665691274867109, 0.9745878905343943, 0.9414739263837224], 
             382 -> RGBColor[
              0.9930529315631241, 0.991395222916906, 0.7647944326432292], 389 -> 
             RGBColor[
              0.6652086100067185, 0.7383852890007165, 0.9672654355837238], 
             172 -> RGBColor[
              0.983141030296394, 0.9547928778947162, 0.38900651556112265`], 
             243 -> RGBColor[
              0.9587305571214175, 0.9687418975904396, 0.954742581385588], 88 -> 
             RGBColor[
              0.939351116438499, 0.9542887424600408, 0.9875469194941408], 273 -> 
             RGBColor[
              0.9939562575862646, 0.9917687714418945, 0.7498239827069814], 
             202 -> RGBColor[
              0.992674802963948, 0.9867404691679408, 0.4440756923807557], 393 -> 
             RGBColor[
              0.9899851481772204, 0.9901266156483979, 0.8156355425165618], 98 -> 
             RGBColor[
              0.9921913238763713, 0.9910389259961262, 0.779073501781939], 30 -> 
             RGBColor[
              0.9659065017477823, 0.8966567662405075, 0.3220536266173901], 
             116 -> RGBColor[
              0.3978407779503856, 0.5190114186268795, 0.9465710404675799], 
             373 -> RGBColor[
              0.4763759693970103, 0.5857824983061768, 0.9519212078150576], 
             240 -> RGBColor[
              0.9374631330103835, 0.9528806875106414, 0.9907427829729991], 
             317 -> RGBColor[
              0.9413852607891128, 0.8053191217724534, 0.2716954088474019], 
             391 -> RGBColor[
              0.9824970040731734, 0.9864668748130739, 0.914512185978378], 73 -> 
             RGBColor[
              0.9880380514662509, 0.9893214411203091, 0.8479039739420859], 
             303 -> RGBColor[
              0.9081854043077002, 0.9296264056316198, 0.9911047286811916], 29 -> 
             RGBColor[
              0.8421821020137752, 0.8769971639943569, 0.9848092747865534], 
             360 -> RGBColor[
              0.9940830145844926, 0.9897524914322504, 0.597350836802289], 320 -> 
             RGBColor[
              0.6491594737873725, 0.7258475818082105, 0.9656658076730845], 75 -> 
             RGBColor[
              0.9929450707205896, 0.9873185445711351, 0.4734926697919292], 
             200 -> RGBColor[
              0.9243206417236778, 0.9424922059677683, 0.992643722030024], 301 -> 
             RGBColor[
              0.9943008796221611, 0.990218482718289, 0.6210641016453392], 156 -> 
             RGBColor[
              0.963401354217337, 0.9722253704168481, 0.9468361402411827], 25 -> 
             RGBColor[
              0.9869267965107631, 0.9888619086382651, 0.8663203443901576], 38 -> 
             RGBColor[
              0.9792639714615905, 0.9417146480682189, 0.37394487410903743`], 
             365 -> RGBColor[
              0.9425204144578389, 0.9566523997336152, 0.9821821246327065], 
             380 -> RGBColor[
              0.9927638686280528, 0.9869309716175407, 0.4537699402689851], 
             370 -> RGBColor[
              0.7060970652080797, 0.7703276609677892, 0.9713408146738569], 3 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 57 -> 
             RGBColor[
              0.762940451941465, 0.8147341467096498, 0.97700643223179], 227 -> 
             RGBColor[
              0.9895584373257761, 0.989950159745357, 0.8227072456172769], 39 -> 
             RGBColor[
              0.9943788509745709, 0.9903852555569806, 0.6295508021717436], 
             109 -> RGBColor[
              0.9842028513624264, 0.9583746496778858, 0.39313148989457525`], 
             256 -> RGBColor[
              0.8868573737508803, 0.9126200129995785, 0.9890704420869245], 
             339 -> RGBColor[
              0.7426683264812414, 0.7988974082262632, 0.9749858962196982], 
             287 -> RGBColor[
              0.9375135297499831, 0.9529182733165177, 0.9906574744384319], 
             239 -> RGBColor[
              0.8021720588617548, 0.8453821762070363, 0.9809166721693934], 
             285 -> RGBColor[
              0.9863592218475291, 0.9886272019290143, 0.8757265253960881], 
             345 -> RGBColor[
              0.9925210443039081, 0.9864115949415005, 0.42734001112386144`], 
             366 -> RGBColor[
              0.8219261603961775, 0.16953965367557855`, 0.16862982199842297`],
              216 -> RGBColor[
              0.9892503747191113, 0.9898227679406533, 0.8278126402501845], 21 -> 
             RGBColor[
              0.8396216655904651, 0.8749555414916046, 0.9845650580747696], 
             355 -> RGBColor[
              0.8247681077968233, 0.8631117176960401, 0.9831483124724845], 
             175 -> 
             RGBColor[
              0.9888011820902124, 0.9896370152448796, 0.8352569245842971], 7 -> 
             RGBColor[
              0.9946129130704702, 0.9908858907128012, 0.6550270168465631], 13 -> 
             RGBColor[
              0.8903381711449719, 0.9153955063578989, 0.9894024436497174], 
             294 -> RGBColor[
              0.6435830071437153, 0.7214912036834692, 0.9651099975930884], 
             193 -> RGBColor[
              0.9233140255721495, 0.7336726960193483, 0.25715486880542443`], 
             60 -> RGBColor[
              0.7996110216749666, 0.8433814744921138, 0.9806614119168676], 65 -> 
             RGBColor[
              0.9632216289202946, 0.8876000597552731, 0.3116234026782908], 69 -> 
             RGBColor[
              0.9867856355797537, 0.9888035349656222, 0.868659746329761], 217 -> 
             RGBColor[
              0.9948656525143188, 0.9914264748273158, 0.6825361455824375], 
             214 -> RGBColor[
              0.9912329331897215, 0.9906426068176792, 0.794956515695318], 170 -> 
             RGBColor[
              0.9642375698602831, 0.9728490186741798, 0.9454206452776441], 
             359 -> RGBColor[
              0.5365484760936737, 0.6346332499830635, 0.9566582079613737], 74 -> 
             RGBColor[
              0.18920555763331504`, 0.31619741577080834`, 0.9340863486514539],
              246 -> RGBColor[
              0.9707744565048889, 0.9777242180305573, 0.9343554012814156], 
             264 -> RGBColor[
              0.9610479843390876, 0.9704702310149391, 0.950819781587892], 278 -> 
             RGBColor[
              0.9204267262760075, 0.9393873034873151, 0.9922723168984858], 45 -> 
             RGBColor[
              0.9952384841280515, 0.9922990050686424, 0.7285741706136537], 
             306 -> RGBColor[
              0.8982632831937838, 0.9217147755841857, 0.9901583479117642], 
             237 -> RGBColor[
              0.8548064873803082, 0.8870635062058183, 0.9860133999327353], 
             228 -> RGBColor[
              0.7024770693558217, 0.7674996926950177, 0.9709800073180884], 
             180 -> RGBColor[
              0.9510575782557059, 0.9630194025157417, 0.9677309331718417], 
             383 -> RGBColor[
              0.9858055719210008, 0.9883982534562408, 0.8849019374787414], 53 -> 
             RGBColor[
              0.994385826181179, 0.990400174818614, 0.6303100103650559], 304 -> 
             RGBColor[
              0.7292509676407094, 0.7884156655243356, 0.9736485792828212], 48 -> 
             RGBColor[
              0.9896160044595194, 0.9899739652345677, 0.8217532092321849], 5 -> 
             RGBColor[
              0.9764999235824199, 0.981994262002388, 0.9246636789601277], 101 -> 
             RGBColor[
              0.9328475665750322, 0.9492913443870291, 0.9934570277344219], 
             333 -> RGBColor[
              0.8794420688740423, 0.5454564164247603, 0.22111584593424574`], 
             267 -> RGBColor[
              0.937315702731643, 0.7891846801744178, 0.26842094690955687`], 
             120 -> RGBColor[
              0.9865895222510982, 0.9887224370643406, 0.8719098517106091], 
             147 -> RGBColor[
              0.791965921181043, 0.837409063881345, 0.9798994197471594], 89 -> 
             RGBColor[
              0.9937798178010623, 0.9916958090564176, 0.7527480465593115], 43 -> 
             RGBColor[
              0.9788284892347989, 0.983730902453256, 0.9207220246978387], 199 -> 
             RGBColor[
              0.8260023471290501, 0.8640958666370236, 0.9832660353218107], 
             268 -> RGBColor[
              0.9845015614695132, 0.9878590116230106, 0.9065127653307626], 
             169 -> RGBColor[
              0.991926167816502, 0.9844272095984236, 0.42313511589272756`], 
             20 -> RGBColor[
              0.9094956729559462, 0.9306711782854362, 0.991229703274552], 4 -> 
             RGBColor[
              0.9609992008336045, 0.9704338483564254, 0.9509023593378991], 
             167 -> RGBColor[
              0.9862415160352833, 0.9885785275507493, 0.877677215317878], 142 -> 
             RGBColor[
              0.7052678774083275, 0.7696798931565622, 0.9712581689831782], 16 -> 
             RGBColor[
              0.6487159416569097, 0.725501091136924, 0.9656216005353634], 281 -> 
             RGBColor[
              0.9947289377273906, 0.9911340557220617, 0.667655584731165], 289 -> 
             RGBColor[
              0.807289153363952, 0.8493796893235113, 0.9814266963274055], 398 -> 
             RGBColor[
              0.991926167816502, 0.9844272095984236, 0.42313511589272756`], 
             178 -> RGBColor[
              0.8707679185416699, 0.8997907181523812, 0.9875358154858438], 58 -> 
             RGBColor[
              0.5175540712398192, 0.619212736434517, 0.9551628988324807], 186 -> 
             RGBColor[
              0.993192734106311, 0.9914530348612752, 0.7624775427052384], 122 -> 
             RGBColor[
              0.9683360421965044, 0.9048521766572724, 0.3314919324804594], 
             249 -> RGBColor[
              0.5046943450426381, 0.6087726313835822, 0.9541505340795094], 
             113 -> 
             RGBColor[
              0.9937305817263837, 0.9889986731851834, 0.5589906951606189], 52 -> 
             RGBColor[
              0.9945706273296324, 0.9907954457888936, 0.650424474913719], 187 -> 
             RGBColor[
              0.807289153363952, 0.8493796893235113, 0.9814266963274055], 259 -> 
             RGBColor[
              0.9947057559271495, 0.9910844721953856, 0.6651323888364137], 42 -> 
             RGBColor[
              0.9907470976972217, 0.990441701356128, 0.8030080671079909], 134 -> 
             RGBColor[
              0.9837144840751415, 0.9567272721437817, 0.39123427520389714`], 
             313 -> RGBColor[
              0.8990898594900233, 0.9223738650859912, 0.9902371874967929], 
             248 -> RGBColor[
              0.9899033077343535, 0.9776036275512026, 0.4152766864586538], 
             174 -> RGBColor[
              0.7815360706693472, 0.8292611853918083, 0.9788598697206481], 
             215 -> RGBColor[
              0.7273473494930196, 0.7869285445593266, 0.9734588444161825], 
             399 -> RGBColor[
              0.7901878600566663, 0.8360200290172168, 0.9797221992312074], 83 -> 
             RGBColor[
              0.4604973502267412, 0.5728915199401104, 0.9506711847486755], 95 -> 
             RGBColor[
              0.9952669393119791, 0.9922847867111924, 0.7262137370527132], 
             166 -> RGBColor[
              0.871114945716633, 0.9000674282018951, 0.9875689152475865], 384 -> 
             RGBColor[
              0.9441188823005422, 0.9578445344334524, 0.9794763355221927], 
             233 -> RGBColor[
              0.9948577209609003, 0.9914095100365569, 0.681672844940714], 295 -> 
             RGBColor[
              0.9933567444625186, 0.991520857358441, 0.7597594666576825], 141 -> 
             RGBColor[
              0.9687665283718144, 0.906304307609554, 0.33316428998104636`], 
             319 -> RGBColor[
              0.9946118693874363, 0.9920398837701337, 0.7389587984926139], 
             205 -> RGBColor[
              0.9929929772157977, 0.9874210117202957, 0.47870699615071877`], 
             224 -> RGBColor[
              0.961118261473204, 0.9705226435864949, 0.9507008207310451], 231 -> 
             RGBColor[
              0.9251485824842436, 0.9431523834563902, 0.9927226917588783], 
             332 -> RGBColor[
              0.9398821765111646, 0.9546848061927037, 0.9866479733137677], 68 -> 
             RGBColor[
              0.5283485756802009, 0.6279762014261022, 0.9560126817636002], 10 -> 
             RGBColor[0.52725584759805, 0.627089075542173, 0.9559266582061784]
              , 250 -> 
             RGBColor[
              0.9782466667244365, 0.9382830403152871, 0.36999283730707383`], 
             282 -> RGBColor[
              0.8235546769681472, 0.8621441608909562, 0.9830325743568028], 
             374 -> RGBColor[
              0.8733159515520168, 0.5176391484564943, 0.21600406347587103`], 
             232 -> RGBColor[
              0.9853500118343208, 0.9622442913156735, 0.3975879917048074], 
             253 -> RGBColor[
              0.9875132372961968, 0.9891044169738826, 0.8566015029154185], 55 -> 
             RGBColor[
              0.9759862974950818, 0.93065828414474, 0.36121172968594306`], 
             325 -> RGBColor[
              0.9799041889082455, 0.9438742518459912, 0.3764319979943718], 91 -> 
             RGBColor[
              0.9848191332297469, 0.9879903357070893, 0.9012497794143209], 
             105 -> RGBColor[
              0.7985768007271687, 0.8425735332273238, 0.9805583304381353], 36 -> 
             RGBColor[
              0.9928033369614125, 0.9870153903917367, 0.4580658247848779], 
             123 -> RGBColor[
              0.9930842802966114, 0.9914081864238287, 0.7642749030014239], 94 -> 
             RGBColor[
              0.9758015103394762, 0.9814733865493472, 0.9258459104050845], 
             312 -> RGBColor[
              0.9690258910681944, 0.9764201407908837, 0.9373152664668342], 96 -> 
             RGBColor[
              0.9937432199025767, 0.9890257049661448, 0.5603662826454537], 2 -> 
             RGBColor[
              0.933239648228134, 0.9496039796544395, 0.9934944248325102], 262 -> 
             RGBColor[
              0.9950587965476994, 0.9918395903848597, 0.7035586816691141], 
             272 -> RGBColor[
              0.8705635323190102, 0.8996277461263487, 0.9875163209454687], 97 -> 
             RGBColor[
              0.989923150631666, 0.9901009780700469, 0.8166630022909018], 372 -> 
             RGBColor[
              0.9930023290348572, 0.9874410143156499, 0.47972488394260204`], 
             356 -> RGBColor[
              0.941396677608522, 0.9558143186313449, 0.9840843180010901], 346 -> 
             RGBColor[
              0.978533703963385, 0.983511052080502, 0.9212210192700301], 341 -> 
             RGBColor[
              0.8803123092840844, 0.9074011562547976, 0.9884461679952334], 
             209 -> RGBColor[
              0.9753056305619806, 0.9811035602232197, 0.926685305522225], 378 -> 
             RGBColor[
              0.9857442185509964, 0.9883728822610343, 0.885918721597147], 66 -> 
             RGBColor[
              0.7936238215937561, 0.8387042282842662, 0.9800646637663384], 
             139 -> RGBColor[
              0.5495414986021835, 0.6451815709844653, 0.9576810662882533], 56 -> 
             RGBColor[
              0.9343125165144804, 0.9504594557037385, 0.9935967559674227], 
             335 -> RGBColor[
              0.9907862045266501, 0.9904578730350962, 0.8023599657391312], 
             314 -> RGBColor[
              0.9792070226229357, 0.9840132120343368, 0.9200812664090425], 
             144 -> RGBColor[
              0.884214442476941, 0.5671266503393498, 0.225098031450086], 298 -> 
             RGBColor[
              0.9827791583835883, 0.9535721989612568, 0.387600711513649], 204 -> 
             RGBColor[
              0.9758700570693939, 0.981524508588285, 0.9257298786711841], 207 -> 
             RGBColor[
              0.9765792309787967, 0.9820534093287518, 0.9245294322247436], 
             334 -> RGBColor[
              0.9901904191249183, 0.9902115004604938, 0.8122336716890212], 
             149 -> RGBColor[
              0.937407714441376, 0.7895494759424247, 0.2684949816910005], 219 -> 
             RGBColor[
              0.9945268001814068, 0.9920047054672617, 0.7403686153885692], 
             400 -> RGBColor[
              0.9453754211275218, 0.9587816590332203, 0.9773493430459291], 9 -> 
             RGBColor[
              0.9941579508736005, 0.9918521767994889, 0.7464814029703314], 11 -> 
             RGBColor[
              0.9453754211275218, 0.9587816590332203, 0.9773493430459291], 44 -> 
             RGBColor[
              0.9473774771888442, 0.8290762630096445, 0.2765168868180224], 
             153 -> RGBColor[
              0.9919132536151538, 0.9843836469648777, 0.4230849466591324], 32 -> 
             RGBColor[
              0.9622566971705807, 0.8843451183867388, 0.307874825042723], 162 -> 
             RGBColor[
              0.8670516513706797, 0.48919442439752137`, 0.21077697785251495`],
              90 -> RGBColor[
              0.9278976224810076, 0.945344393329107, 0.9929848976478666], 331 -> 
             RGBColor[
              0.9947060189661191, 0.9910850348091441, 0.6651610190049619], 8 -> 
             RGBColor[
              0.9935158032302192, 0.991586632246509, 0.7571234512459888], 364 -> 
             RGBColor[
              0.9644500984549241, 0.9730075221520794, 0.9450608898032519], 
             342 -> RGBColor[
              0.9788979220768877, 0.9404798775411338, 0.3725228413720934], 
             163 -> RGBColor[
              0.9948724464727368, 0.9921476390914311, 0.7346403618373041], 49 -> 
             RGBColor[
              0.7113281488530714, 0.7744142232689649, 0.9718622002043337], 
             338 -> RGBColor[
              0.9942067789520047, 0.9918723684647335, 0.7456721953481555], 76 -> 
             RGBColor[
              0.9945093942277652, 0.9906644743756158, 0.6437596296623695], 
             369 -> RGBColor[
              0.9771798960683146, 0.9825013843690155, 0.9235126629067356], 82 -> 
             RGBColor[
              0.891038580152386, 0.9159539934883149, 0.9894692492861071], 67 -> 
             RGBColor[
              0.9946083689951138, 0.9908761713950905, 0.6545324222868112], 
             211 -> RGBColor[
              0.9854029847147614, 0.9882317733004415, 
               0.8915738493484208]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9l3k0VX/Yxa95Hq55dufJNVwqktwdKpWiSIU0EZFIxkiFhGRKk6SkQSmp
pB/KUETKkBRJKFKkomiO97xrves9/5y1zh/nPOt8997PZ1M3B6/yFSWRSJki
JNL/3ts/DO24cJCK5nV1y/77Ko3lZYWuScZ0mN+qlk7aq4/eB/mPXtwxwb4A
OR12JwNxHx9Ith2jwf/gZSqz7q+Qdyy3+pArD+Lm5TdjDFiYM1UYwg9SQ29X
2KKlHBqC9m09tdiFDpVtoRdcBPKYc9LPJeyuEeqzuXSnPC2k9FRMraezsMB+
qPfQKQq6I3gfU3+TcIfBPGx4nIL8Fd9mbvRpo/7N7th1fizM+mea3hSjhZ8Z
LSkiZyzQGP/WbmWtCuJ9ksTtjChIHnHJO1enCcUQwYM1fkx4vDpZpshTRfpm
czLkVKDnbb39dC0d4+kq9utkZ4R2O2ctKznCg4vZApKlny7Cp7/zA1RU8O32
kpB6ZSpyIoJ3WjK58P7z3qXRxxhuit4+BRYyCPa/Y+f8nYP5GhlHJNN4EK1o
9HO9q47c7Oy/fZVSuCIc3nBrRhPpK7Iuqj8XwLndW3nTezZ8zq5c3baHglLr
s6b5vmwkTYiK1dgaorLxgb2iNxtas3m56k0GuDU23CM8QsNte1dLseU6sLZ6
cp6+xQxe5QmRhh5/heoGbjW5D1iQNdPIkF4iis3skTUHajUQcGakbr8EBQNH
FjpZltFhcMBsh2s+DZ1RpVnxyjQ4Osu6pGurIe+JTt1OjgUyig9/Of6Ghrkn
xN5pzKIjpD9qqGGBGUjC/fwyHhUrtmb9YrGo+DC4ND5ZSRyJSrmyp3K5KJ6z
9WrdSi3cdpFZvEuNjbwLV1pzVWUgOtz9ydFRC059h1zHfjOhturcjwdFE8K4
JdpOXBINxaY99q+NmDCpTJrzbb88zDu6rn92pkE5fLmnxWpp3Pywq1aZpo87
XdYfz/VyYctd82UwTR3db38at0tawKfx9OZ5ar+Fz/fnul6/zsRQWJRPWro8
ylaLTU/vUUeh3Oe93naGqO3Lr6d7C5BYTW4caJZAXqqDqpwXC+rWv2IEvWwM
2lW9f1tuhLzBwp4fS38JpQyOcJ8asTG8y3H2/mB5WGzcaxfxgoOReMOw6ksG
qEyhX/6xwBSByX9efnDjQ2u9wwhnBRvir+7O5AnNoFmmXZ8wREFJ7ZyG34mS
sC06/+bZbRYuL27dJT+LDddnSs+ME8l4+2SJ56d5bGTqTk2LfjSCYJaGo+I4
Bd5Bi6OjP4hB5Wjnj7E3LNQ+3JklViKPtQfOifvWUKFj4hujVWOKnf6skW0n
OKCLVAaYtqtgoVpO8E8PFu7NdSHHDehhVc/tniKaIfoDX/0j69Gx5ky54prX
dMx/fbycOkFH+SKRqakSPraLbFyZOE8XT/DBp8xOGzafrjf/sybjogZNJHYl
E9v8m6TuB+jCIK/O0/AfAxQty3rrtn6hxeuN4k8bzfBdMSs8cpCG2EYFP+dS
ZVx0eWWkL9SF44ITbzd3mcBqgxEnPIGLYxXDRXuimbh/8sfWoVoe9tlrP9Wh
9Qt9Z7c3rZakILj452RWCh2iEwaX9x0gIbuUTmpZR8adelUrs0AKrm3ZpVKV
bwY5tcM3bbw4SLxYaC33lYLUHW92L7dmg97Qte9Hsy5IHS1WpYfpcHsmI7ym
pAOHZas7Xv5hYLXg7ye1Q3TUX5469OwxH8+G9ocwEpiQXZSRnbBbHjZdgv2H
XwmQd7x/6Xt9wo9V6cvP1POxb3rQPuirDh7GrEjZRvh0qy9DTJ5lDPPVz1/6
KdGgesBGk9JMh4P7m+X7djHAL7UcvG47LZxUZWoqp5hhf+y2sfwfNHg8jyQ9
nmShtJiiraYij39Fmr4xM4Seq4PzIkx00OEwvdDvkAAH26ascqvYeHpD/Pr2
KDr6x59kL7dgoMnh7u2HsqKIyvCiPJnRwkThUKR4JQV9wwu5NAcJSNvNcy8z
/yTU/sL8V5FKh6O9+FgQ56NwjkvWT9IuGmoXD3hvrjDDJ5GB6MajNFR+//H4
yCQdod5gqd2XxMeWK1VzV5DhMefmCa0HmlhoOR61z5yB7ud2DdUxukg+Y375
4msueCMrv+5g0VHrOfN85xYyvoZ7vtQ7q46+OBvdzZJmONDnqiA4awDViwoR
EWQtVLL3KjotZSD8RcFfkpkRkJfUdT2Hh4aL32vmlRhC7/WSOh81DnYwboqu
LFeDQQVzU6mKKoI6RlyuV9FQEuK3iPaTgvTlAyxGHAP5nqFLxGL0cbpD4cCZ
FVw4F5oPhTYbod2YE5C2lYp+dklgWA0XFtfar8o5MJHTn5IQclkClIkBtm+p
HiZnSQ7/F0DD6cR0u+TNKuCPhw7bEHvBu97VV2axJvYdYYcbDqpissfFZ5sq
DU1Go5/tL0shdv7nr3+D6FBTm8sf7PonNLtyYbHMqBzMzhb2OvtyUbZlW/QR
cxPMOdUlm8Rlw7pj2tHIVxPL3tlK7Z2wAOnEMa/bycNCaZVfH3uMadikZJz+
EsR8CR3vVar5aLZ6Jjx8VB5ZNb69BzvZcFlppeemwUHfdI5/ynp1yB/Ipl57
xoWxV1q54W3Cb3s6/DQ/q0FI8Qm1fmOOq3pRqZxRDpqUU0ws3xsjLfrcOflh
Yj+OFcwtPmeB9HPrzM9NMUAapukqqp8UFu33v0Fb/lv4m6m88HcPHUG3T1tB
XABmjerwetBg8sx1vYDggORcha1eVRxoHy6I7VdnYWN6ACv4mD4eLfrbrddK
xt/+BV+jHxrg76SoX4CRCc657Fixx4YLiT8W5FEqG5XPfy+sPCkFzbahlZ6R
KmiIp/pl2fEwUtDJsf5NhfV2OceTfXzMpnZtKHqnCvF3hwsfbDeHzVbdm1GP
qJi/T5teZ8/C/VdTJJkiBuDheClvz2uhFSPouowyGWOOtN+Gdno4b7Df0nNM
FqQ139/vqdbGxiTDXz2qLCxWHgOlj4Yx+frOYuKcmNQPJ1bc5aJ5XleFwgcD
PKYnloSnsJCqXzD+KNYU73gOWwaYPHhwv0rsdyBy22lMItZZFSY7zSMLosQw
JLNPO+YvB5GUql0Dj7VhIpiJ+WFHhu0jpx/871ow06j7XLvJAvxWy4E6/2lh
0PlzjXlBOlgoo+1w+KIpkmRkTo3No4DNDhbc6qLBadO3Rx3GDLgNHy7yfk6F
l19ar/JZSTC7Nt0KiKdj1VutvkqyAt5eO19MC9XAxheso8EWSrC9u2CB9Fk6
XL4FjbSP03BY6q2rK8cInf7hdo3biPwv6Q9KV5LB+m0pzy6MsrDsBunimBcb
bWGm6Z3uylgRlr9AYUoLW1yu+3SupePINs6hFEV9SOd7PuznKSB1Rf3BYy58
CLUmMno38+HY29Pg4CpAVq3/8B9C347z5xR4tJrhYr13kaoVB+S0cwuuWLEh
CDx53tpQHfNXRy5Pz9RCxz1PUv80DaUOvpF275koizzZeNVPGsq7Zk/KJagh
6+EOsiJHAy/s2a9kkgTYGrfSKWE/G15vRq92+mig7+cz2Y63ZCy3SklUnjFB
5Nflj51q9JGeFniyuFcCLbEXKWuPcrFSso6VrEHwyxojrS9aNMwSr3Z0ljNC
GPv6q5ggJgoy77spEb75Zab3WryXBtKl9LUa79uFKUrZLgdv6WJj59WC9Nqf
wvu2zt6vO6lI9r0vMuAhADvGeWj+BQZoLg0PRMe4sKta+ybS3Bhb1njMt2xT
BWWXs+oGgSqs1habJS2Wx8i1820J6Ww0l4adfTNhjHTOaKV0lC70gnpGNG1V
8Nr4Rr9gozK4W6vsJpcQej5+r6wz97MwKC7+yy+Cg5cHvrX9ZklHWb1++e2I
r8JH1avTO47poS/C6V6YGg+c8i7N4TlUZM1t/6MbQgM/8iij2V4MXiO/63Je
kZCZ/Kfry289nHVcYTBNkkDR1Vj7iAR1aJntNg/sV8SJtI7/Vu8zRFrYTcPQ
XUygnXfK77M8UgWiokdieSi1EG7W92TA6O6He4eW6oPsd2pdsqEpOEWtPwuP
UyGv2FTSdlQEVrXFi6W1uMDgXck7Z/m4feTg7R2TVLgcOde49AcFN+7eufzw
LBlnaKk9vnupGFWt8qnu1UBwU6HkCp4F/hbY/fwR801oqhKqEnaQgrns27VC
czY6K/y8AvPlId8yKKHiRMw3bU66mUhDnK5ZkVoLsa9k635d0CH8oU9vuedI
xa41U+vfEHz8fXzCVf6jDvz1JwtYT9nI1ll9/d02Gn4uvy79d+iPsPXHwiLJ
QD0o/SwWLnFno/qXQVISkcO9I55jZSnTQg9TiUGWvQAhp8ZP1l5gIfHEOfVZ
r4j8bRx/P1hGRndu2I/lNtNC99LnHlsFxHOBddTRKE38FyjkTj60gJXO73ni
HzUg1rroYEgEA/Qds7r+zGdAPKt0R3I/FRFnC9T/3WEg49cEpy3KEE3+1Gzq
XkXE+a8pmS9Nwfk4Js/5NRPHbMs7lnlRYXCwIfPqVw4CbZkvUol8ZTU6BemG
yCJ7jYTb0A8DPGj8qh+6SRnCeer30vp14F5x61Cznxae6P+prbTkIDu0ep15
BxV3M6LmP+xSwviqRKvFjkbouTnjq5DAgf9rvnX4AqKn7Ax/tVidyJHYGlXj
3k/CnY/WSS7bSoP85kw51t4JoWS30t3Jf9oInXoSGSUmQGdCwM1WZw6GL0ka
hrUzEeq8SF3WUglLr/Y6664m9ofUhZYXQQwcc2/52pishT3qYxPl75gwNw3j
tw1ycfnLbblibT7m6nbmRYoTe+9DNWt1Hh3TdS4esZkUuDwQWeGTxoYhJUHj
j5oRdtzjrjk2zEO5BKecWsWDxPvMoLgPdBw6v0rrrygHap98tR5NymLB4h1F
dhkMZKY+ih6Zb4zkOclBohs1wYna0ZDz3hxLK2/tXtCgCfmZvVfDRhXRqU9V
qjoigMNYetb6x0x42a0+t1n+j7DE3PmSoqkBFMRFP9ZtIfTz0d3Pu4EJxqVb
z79LsDC69xzDPFoGad6dGrdIZjjJeufwm2cIewvbhLrLAsg8qe/I381C7oap
1KnPdAxxklfVvCDmedujqbpEA1+WRcT436WDo/H5g9SUAIL2N6cOTjEhssUq
pe2mGcLo/s/LDAhfN7TkZuSooyJ/TPxXLwvpK11KdhNcLV8xnEDfQEaOIGmd
Qroa7kb4hb+dMkfZ6LYXVuommKS8uHJB0wCTOWVS3o8YSPo7a79JljEmTxly
VCV+CO/X5BRWED6463ZneeUDGtRIxY/XE9zqpaBdZe3IwJ6v3bOb1jFhOvr8
0pMkGqKENna3OKLYTUp1SjDRRlDFRu/+5xZIvhpJm4nkYUwn61Agwd+BiTsb
GmToKO1eOD9alo7j+S13qirYuDko9ULtgA52TOycFxHBQaxJ7mcrWSUYBR7h
Wu2hI76pu7vWn47mkLfvfLrlEElXiAlvZ2NV6reJ8WpRyAYYCgt1NfHUo+tF
TjsP4pHjCdHyHJgbOSzMdGRC7JX8xXFLBh7sjqezZNm4uCiAK1AygNk3ebjE
m4Gx5skK8v/qiil+KvyfCo7tzhvc+ZiM1IS26rzjPLz88XLp/g42Yv1Dc1Ur
5XBJKY/hOKQG8Xx7C5HzOqi3zfhS3E/op+FdrtCHi6n8j3qs/XR4+wVvb6xW
h/SYhDTvPBfnlLmvH6to4mLo45wpE3PYkz/Zv/9E+FpDPyZTQhSGbc1X0zLZ
UHuRftzLgAr3vZsWzTthhqSZVZ7alzjIXFKfdi3VCEPSyQ+ObKeDom6po3NB
Hcd1U0jSW9VAKkpdWqNFgXWEVK0kWRdNv+vyLZIJrj+vELHbUgTpE0YbZy9R
wuZmg2CXKDOQ3/8TnTjDANPzy4JoBz56ltmrt2zSIfj2CX+Ka44mmTL31ydG
hZlNDzYZ0ChIbsny3MLXRIB7xrVPWxnwp7Qt6hngYuC9f7xnGw8/a8UUPTfz
kFRwXty+ko2FVSaGXbrmGL/739nwp4Q+KbdmX7BVx8LkE+vnuRO8+3+X1jSf
csSayOWm+OtPDeiwTx1XCSylonejweJPGt+EEnsWNuUbEZwdbbVuiwQTpZMq
+34TubppB2lPK5FTir/id2RG6ELZIuFLTJImNg6Wqk+nWMBvnYVWyS4W4HRD
cmW+IcFdRY+2PPoqFLfpO+UbzoRbb9Yy39dq4Aw+LQlZQEOu+Nyy1Qwuiuri
vllPG2Np/nyt8EoBsvN8Vt6yYyMofXrZglzG/8/dHsA7KtbChmnxql31FyjQ
LfmkUmHFwsmjMW5PzmijWPnYntNBZvhp8W7dP3kq1s6izN3TY4bt1gkee8QY
MMvxI3NIdLRclqztVSR44+bdeztFZSDRQZrsi6chfwU2TQZR8DNRTnXwuTxy
FmU80SXysdxUQuFQBh9XMmzcEhTY0Aj1K0x108bnXe5XZm0SYPeid99bY1nI
rAicPxE5Koy4ot3vnEFHo9dN0lAyFScqPcbfFTCRODKm+GVEB+PlA6N/YYEw
sXks43ABSt/UMFxtmciNJyWtymHge6Kh6GMNPiKylW8UhnCRPSDWPenPQX77
lVSOrzx6FSpl9dM4eHzoxg06m4yhVnLI9oXEdziHi4tix4WcrMurqt3oYERs
aBoMZEB50/kkB8tRocEsKTFGtCYS9Yy2HuxQwhax8cnmQxTYregkNxyVRHf4
wQ3NtWLYnXD4X7IbB9uHyvk2pwVodBs9EEtiIbCxWeyKjiq+y30s+rXOHGfI
LDPTf1zUFWybJa7Dg5t7bMOBRgayq2bN8pcmI2QsXOSyFaGjVrfoDSEMxBXM
lz5tJSD6n8GB2zsYCPhSf71UVBPZFc2ha5Ll0VHPmTesqIlkyT8ygioLrPZr
iKSe1ofyM/+YGndpzDnv/UrkEQfCYxn3gyMIPWVNB/g+FENy+8c/NVWGkK6h
/vEUU0fREUdfp1LCh0fTesv+9gjxOERjpk4Pg/cb5wb/IXrQ2b5PIqVcPFUq
9s8huMCE2dsfZMVHH+/Pcp0sNlJDKcJod2OsbLRJ3k9w0vnd6z15sjREZ4u+
CVDmY0qWRa5cxMUTyqOjFy6JYLO01WB5A+ELLTWdS8FMnNinMu30ShIL7q4T
zVFkou/lNrK1pzHiLou0txPnJfbmpJU6QxNNroedeo4Se4k8rT+gIYmB+QPd
AimifzbvORJWoos59xoVB43N4Tw0/HjNHDZG3VNn3u3XwzEF87dr50pj4z2X
j5y8AaGMV3zdpsNUhF2u+ZoroCC/tenBq1p5bDq6ODLNnQwz1RKSEHpo+myR
xynUw8+IyVT7HjbUt/TM/m7Dh4LgifAZl4//ohrP3on+LdRwT2q7QLynzP/6
1scH6NCJP/otW0wOPoHJ3f1Kkqh/7mGjROSz0Cmi8cU/Qq9dhRU8ESo8WnO2
nbqngHx7QbhiEA9L114tH/UWJ/qkz3DAdg2Ch5xqQg0pEOUXtC5mchCxXfL4
pW1aqCMz+spWEflkJBc899UDodtnmrJ3jw52hzmNX+fT0XTwWLKXlBhmekt8
xPT04WBw23LNbgZ4mrbj0W1moK1XjrOfzcTavfvedb77JWwNqLk/cpENfzdy
obqBAfzqVtUc6xagu+UXSat6Spg+mNZ9ocAQ++Ikr30eHxNWUWn9H8SocD1v
295zWQebLw7B5TkfmXFaRs5LNPG8Jmh+t7oxxg+Nz/BtzZHC9D2fdJONWhPS
3L1arcJH32bprFI0xEb+HEuXgxPCNNvFn4wJzvz7Ls69MIsOvs+cQg0vBg6l
fl70WoWGIUlWWzHx/8SfKTvyzCeEKratgzcI3huXesli3+DhpIrCvFKil2Xn
7y4dOc6Ej2To07goFXR+eTHnna8p7nlOr+hxoaFMYmkKlyaFKMcUQ+E0DwUa
49cWEvziOrxQN2UlE06/1zL7Nhni7qDy7YFEOsQX+W8N4XwVvtUIso16Toda
sEbPJSkd2Oybd4/9g+Ct16SlUhQaAlzZM3/uiQDdk3+VvvcLnWZs+xnJhH5y
Ehe031aGvKVNuf+AOkL35Jx6kaiPF4se3hwVCGDtRMudeKiDoQ5Fj/w5AqjZ
vAlq2msG0w4R4012FGzmtwRnmPCwSrbm8JIDbGT+nBpzqhgV6vrVhysc1McS
tTbjwUiiD0ys3Nmyg47/AeVaf08=
         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 7}], {
             RGBColor[
             0.9755981397699358, 0.928046766241533, 0.47043101171690505`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 35}], {
             RGBColor[
             0.9447154665222168, 0.907249493078647, 0.6396460171608345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 41}], {
             RGBColor[
             0.9346690562549897, 0.7785081565591239, 0.2672468156117114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 57}], {
             RGBColor[
             0.8597619092054332, 0.8399708942399574, 0.6314207194095185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 92}], {
             RGBColor[
             0.9640811304556065, 0.9217659041485166, 0.6094143521362342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 96}], {
             RGBColor[
             0.975163293185989, 0.9271166733682049, 0.4231006446163504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 114}], {
             RGBColor[
             0.9692005625538451, 0.9255839682250822, 0.6007484889556514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 153}], {
             RGBColor[
             0.9742483100422776, 0.9247956443675713, 0.35445997662318973`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 154}], {
             RGBColor[
             0.8481147519307943, 0.8308720464553356, 0.6302598396212555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 161}], {
             RGBColor[
             0.9741763188133171, 0.9280360190603836, 0.5359515070813683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 188}], {
             RGBColor[
             0.9430700330707141, 0.811815230173901, 0.27400643875391356`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 203}], {
             RGBColor[
             0.8734409750659864, 0.8506570844549727, 0.63278412085636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 222}], {
             RGBColor[
             0.7499578360906837, 0.7526741551227498, 0.6215136312330797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 312}], {
             RGBColor[
             0.9628046287687979, 0.9208138912805743, 0.6115751365270405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 327}], {
             RGBColor[
             0.8895399776835662, 0.8632540559774534, 0.6343833297796636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 337}], {
             RGBColor[
             0.9275254415630244, 0.8935426337869843, 0.6380064172345102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 356}], {
             RGBColor[
             0.9489900220389618, 0.9105109802008049, 0.6349596622941686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 361}], {
             RGBColor[
             0.9742997327613621, 0.928087053899494, 0.5339062185772039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[
             0.863431734910945, 0.8941541039693528, 0.9867795442994243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 98}], {
             RGBColor[
             0.9627154860522527, 0.9703214528252828, 0.8862839633072246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 106}], {
             RGBColor[
             0.9641225976511052, 0.9706648373997837, 0.8456286149577137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 107}], {
             RGBColor[
             0.9484962228336464, 0.9610457279253435, 0.9698678316851104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 197}], {
             RGBColor[
             0.935495381303829, 0.9513497215993298, 0.9918748652325624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 215}], {
             RGBColor[
             0.8302934988605768, 0.8682662621068831, 0.9834766346243463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 283}], {
             RGBColor[
             0.8382596865883114, 0.8744895085050585, 0.98427062976879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 352}], {
             RGBColor[
             0.940386646871942, 0.9549976194513161, 0.9835952284721203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 52}], {
             RGBColor[
             0.9059448136648163, 0.5624612228944468, 0.40732123745685955`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 86}], {
             RGBColor[
             0.8822087790817078, 0.547096885906606, 0.5693252607551386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 117}], {
             RGBColor[
             0.9052931275947469, 0.5610673322861373, 0.3363892304700429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 174}], {
             RGBColor[
             0.7994275353346736, 0.48169409269590413`, 0.571538934860324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 232}], {
             RGBColor[
             0.9013345059171605, 0.5481856456578367, 0.2809029958524037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 309}], {
             RGBColor[
             0.8585126070396709, 0.528496164752507, 0.5772569879738741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 371}], {
             RGBColor[
             0.8840492931893972, 0.5484695383145555, 0.5662097504537797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 386}], {
             RGBColor[
             0.9058489254872855, 0.5622561277784903, 0.39688440108587186`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 16}], {
             RGBColor[
             0.804857571245257, 0.8479674697466747, 0.9582619799366312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 73}], {
             RGBColor[
             0.9745186261499277, 0.9798776447383672, 0.8994031666399925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 115}], {
             RGBColor[
             0.9519367347433219, 0.963675075984719, 0.9662427505590432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 188}], {
             RGBColor[
             0.9452779502528157, 0.8644283334669811, 0.6065401151292396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 195}], {
             RGBColor[
             0.9568775560982061, 0.9673599324613391, 0.9578792287778164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 206}], {
             RGBColor[
             0.9727729228423001, 0.9791557515581346, 0.9283339881827236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 208}], {
             RGBColor[
             0.9663004425692645, 0.9431509013273152, 0.6475403473724028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 258}], {
             RGBColor[
             0.9528675488762473, 0.9643692756409865, 0.9646671250272072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 278}], {
             RGBColor[
             0.9407129635548059, 0.9549105759218703, 0.9715873381181925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 284}], {
             RGBColor[
             0.9347990016525829, 0.8228827941696768, 0.5981085071129553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 369}], {
             RGBColor[
             0.9690895484509595, 0.9764676163627204, 0.9372075111223174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 392}], {
             RGBColor[
             0.9777673498244412, 0.9805770789025763, 0.7987516561261001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 99}], {
             RGBColor[
             0.9043672648021315, 0.9255297813551819, 0.9542620763493681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 174}], {
             RGBColor[
             0.8790179971258836, 0.9056277236970982, 0.9517617743403879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 193}], {
             RGBColor[
             0.9499069745772847, 0.8578334790108681, 0.590909273882776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 223}], {
             RGBColor[
             0.762948924698372, 0.8135296370648943, 0.9411667213362982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 235}], {
             RGBColor[
             0.9761849903259069, 0.9817593852953366, 0.9251967788156559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 260}], {
             RGBColor[
             0.9787974813817828, 0.9837077768472473, 0.9207745129048516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 267}], {
             RGBColor[
             0.9569078131570314, 0.8855894710884029, 0.5965423129348423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 272}], {
             RGBColor[
             0.923531727950715, 0.9408110040643684, 0.9560899999527982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 275}], {
             RGBColor[
             0.979163593412558, 0.966177747568904, 0.6542832288008624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 291}], {
             RGBColor[
             0.9720549759112496, 0.9421987115542276, 0.6266675921580537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 321}], {
             RGBColor[
             0.9803513874724231, 0.9701844558401369, 0.6588975844273515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 338}], {
             RGBColor[
             0.9853533512672124, 0.9869333152335608, 0.8351679371541416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 384}], {
             RGBColor[
             0.960309402941481, 0.9699193982179202, 0.9520700072411602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 398}], {
             RGBColor[
             0.9842130456994609, 0.9832107358004059, 0.6738993974264276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 13}], {
             RGBColor[
             0.8956973325111216, 0.9196687561607066, 0.9899136052450006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 18}], {
             RGBColor[
             0.9476589008972304, 0.9570379244030911, 0.8035908663038613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 74}], {
             RGBColor[
             0.5451310257552932, 0.6200697108671613, 0.9622555577458689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 102}], {
             RGBColor[
             0.5399917469386356, 0.6146680029817572, 0.9619628834201419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 132}], {
             RGBColor[
             0.9475362912082401, 0.956775674676082, 0.7902455583165611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 160}], {
             RGBColor[
             0.9471068878248725, 0.9576901901868322, 0.8767449232324532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 166}], {
             RGBColor[
             0.886085719796952, 0.9120047170827048, 0.9889968410439351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 185}], {
             RGBColor[
             0.9460054047456241, 0.957234698626739, 0.8949993484024301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 198}], {
             RGBColor[
             0.9244086570723944, 0.9422513458848054, 0.9818681256769681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 213}], {
             RGBColor[
             0.8294812436684014, 0.8673715977218881, 0.983464705650142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 216}], {
             RGBColor[
             0.9451534342981913, 0.9568823869520838, 0.9091187035452342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 224}], {
             RGBColor[
             0.9310873776752376, 0.9472323247750046, 0.9705627937856645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 247}], {
             RGBColor[
             0.9227472678241202, 0.9410122845037178, 0.9846804243145827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 289}], {
             RGBColor[
             0.8541728236206116, 0.8866608476435128, 0.9859257315838447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 302}], {
             RGBColor[
             0.8637237064598736, 0.8941738546484002, 0.9868639322490397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 323}], {
             RGBColor[
             0.9306936574348519, 0.9008953458920645, 0.6454089633010505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 340}], {
             RGBColor[
             0.9429651089740383, 0.9559774581931509, 0.9453849173708495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 40}], {
             RGBColor[
             0.9679578217007108, 0.9733150718091792, 0.8196351815416029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 41}], {
             RGBColor[
             0.9536838295555241, 0.8413472810303919, 0.4518428207413694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 80}], {
             RGBColor[
             0.9927213633716916, 0.9906808986252905, 0.728332133087634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 96}], {
             RGBColor[
             0.9941780664865234, 0.9899557978394731, 0.6076966497460083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 114}], {
             RGBColor[
             0.9882153358543795, 0.9884230926963502, 0.7853444940853094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 153}], {
             RGBColor[
             0.993263083342812, 0.9876347688388394, 0.5390559817528477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 154}], {
             RGBColor[
             0.8671295252313287, 0.8937111709266038, 0.8148558447509135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 192}], {
             RGBColor[
             0.9767934753681453, 0.9799046878472969, 0.8046787245901865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 203}], {
             RGBColor[
             0.8924557483665208, 0.9134962089262408, 0.8173801259860181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 222}], {
             RGBColor[
             0.768972609391218, 0.8155132795940179, 0.8061096363627377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 228}], {
             RGBColor[
             0.848544991213146, 0.8791927917039095, 0.8130035120823258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 312}], {
             RGBColor[
             0.9818194020693323, 0.9836530157518424, 0.7961711416566986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 332}], {
             RGBColor[
             0.9672475447908173, 0.9727853484527524, 0.8208374950801653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 356}], {
             RGBColor[
             0.9680047953394961, 0.9733501046720731, 0.8195556674238266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 361}], {
             RGBColor[
             0.9933145060618964, 0.9909261783707621, 0.7185022237068619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 385}], {
             RGBColor[
             0.8551445960054564, 0.8843484531265167, 0.81366129901121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 17}], {
             RGBColor[
             0.9943213049214903, 0.991785844641832, 0.7340423043938124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.9165687344103421, 0.9332710868690568, 0.8708442546603792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 36}], {
             RGBColor[
             0.9931595700958158, 0.9893010113191228, 0.6075946380154333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 60}], {
             RGBColor[
             0.8965634124525929, 0.9174840533693114, 0.8688924315814281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 64}], {
             RGBColor[
             0.9942893921378207, 0.9917175864244403, 0.7305687948342627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.9422771916913026, 0.953770312867412, 0.873296350266048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 157}], {
             RGBColor[
             0.9936733418733061, 0.991651778523984, 0.7545126282330983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 171}], {
             RGBColor[
             0.9781766838302692, 0.9816957645816601, 0.8524569702683331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 182}], {
             RGBColor[
             0.7917378417433498, 0.8347908331426381, 0.8589932002977394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 210}], {
             RGBColor[
             0.9662414866374351, 0.9727945140573362, 0.8726601459178284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 253}], {
             RGBColor[
             0.990514520263208, 0.9903455246101958, 0.8068624770807036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 61}], {
             RGBColor[
             0.5916817542534578, 0.6540247962851486, 0.8402838758108926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 131}], {
             RGBColor[
             0.9924257926804467, 0.9911358848721847, 0.7751877469125967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 142}], {
             RGBColor[
             0.8497129141409641, 0.8807660349780255, 0.8588697859767548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 202}], {
             RGBColor[
             0.9934163769187743, 0.9892963229837148, 0.5952785476755436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 214}], {
             RGBColor[
             0.9926954420316609, 0.991247391808584, 0.7707189593328247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 215}], {
             RGBColor[
             0.86075265018331, 0.8893903606794078, 0.8599701236932569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 217}], {
             RGBColor[
             0.9945118016939596, 0.9916393258134024, 0.7145087742763845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 269}], {
             RGBColor[
             0.7363138169345471, 0.7896672230628187, 0.8492837177946937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 279}], {
             RGBColor[
             0.9328800818208558, 0.9461540692608605, 0.8670483970921381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 300}], {
             RGBColor[
             0.9934096548404749, 0.9892819451379391, 0.5945468909365256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 306}], {
             RGBColor[
             0.9462106170336921, 0.9567834761918372, 0.8683198754410477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 363}], {
             RGBColor[
             0.8642774364896202, 0.8921439505312654, 0.8603214414512692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 39}], {
             RGBColor[
             0.7608173492863104, 0.8087371655495768, 0.792738730188961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 177}], {
             RGBColor[
             0.7340053392140897, 0.7912123529485602, 0.9705487276913183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.7610602376524105, 0.8092566792048839, 0.8191756299057051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 200}], {
             RGBColor[
             0.7257882446608639, 0.7847906407549706, 0.9742851901181012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 216}], {
             RGBColor[
             0.7582531111585806, 0.8084559217414131, 0.8918696492281815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 219}], {
             RGBColor[
             0.7608913238897284, 0.8095468905047174, 0.8481476367973738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 241}], {
             RGBColor[
             0.7598903902729963, 0.8067544939500306, 0.691844962117635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 296}], {
             RGBColor[
             0.6340937981838695, 0.7123149280308461, 0.9653697342944152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 311}], {
             RGBColor[
             0.7462672613820254, 0.7608140176508198, 0.6377706485542244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 339}], {
             RGBColor[
             0.6349620870396457, 0.7129932418842181, 0.9654562772129383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 360}], {
             RGBColor[
             0.7606694310912713, 0.8084207834872117, 0.7766387475042337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 374}], {
             RGBColor[
             0.7002858995750334, 0.5723641119993337, 0.5859653608410247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 14}], {
             RGBColor[
             0.9017056976890779, 0.9242101352036753, 0.9818353871596766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 25}], {
             RGBColor[
             0.9661511088191425, 0.9738217838357427, 0.9218348437180434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 38}], {
             RGBColor[
             0.9623196962945562, 0.9502481535507197, 0.6756471085774833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 78}], {
             RGBColor[
             0.9453754211275218, 0.9587816590332203, 0.9773493430459291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 102}], {
             RGBColor[
             0.5621512105637609, 0.6320878295166101, 0.9554251715229646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 144}], {
             RGBColor[
             0.9147949318022315, 0.762954154686285, 0.6012236872480076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 205}], {
             RGBColor[
             0.9691841991716598, 0.973101335376758, 0.728028169598324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 207}], {
             RGBColor[
             0.9609773260531593, 0.9704175341809861, 0.9509393876353364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 213}], {
             RGBColor[
             0.8516407072935266, 0.884791424256741, 0.9769269937529647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 221}], {
             RGBColor[
             0.9634824500248467, 0.9541703949105482, 0.6801641872520443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 230}], {
             RGBColor[
             0.9218193521606528, 0.940248217308703, 0.9837538454788466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 250}], {
             RGBColor[
             0.9618110439259792, 0.9485323496742537, 0.6736710901765015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 289}], {
             RGBColor[
             0.8763322872457369, 0.9040806741783658, 0.9793880196866673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 358}], {
             RGBColor[
             0.9461440856500305, 0.8930077171421567, 0.6267461497990436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 391}], {
             RGBColor[
             0.9639362126003477, 0.9726242669231471, 0.9459307645121535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 118}], {
             RGBColor[
             0.9925545315609008, 0.9911891217076908, 0.7730542104979307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 126}], {
             RGBColor[
             0.9382881053854024, 0.9505773729810312, 0.8723882402706128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 149}], {
             RGBColor[
             0.9654934140055726, 0.8905811443206697, 0.5122846083843677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 199}], {
             RGBColor[
             0.9097907303494097, 0.927854339667969, 0.8696701351997728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 212}], {
             RGBColor[
             0.9825418389678018, 0.9535765793188604, 0.549937638930418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 238}], {
             RGBColor[
             0.993710471822027, 0.9904247174256624, 0.663586813181076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 259}], {
             RGBColor[
             0.9941424347484594, 0.99134864244715, 0.7106033119570743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 274}], {
             RGBColor[
             0.993467929016144, 0.9915668350286777, 0.7579168508677087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 299}], {
             RGBColor[
             0.8656244003443385, 0.8933026229321281, 0.8652809568203681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 318}], {
             RGBColor[
             0.9246784101964978, 0.9397253714627332, 0.8710901353939767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 336}], {
             RGBColor[
             0.9563951036686354, 0.9650154019107062, 0.8741153019311758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 367}], {
             RGBColor[
             0.9710750217249731, 0.9127103589675796, 0.5167757009725693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 18}], {
             RGBColor[
             0.9422997395310807, 0.9527646746002834, 0.8030797047085783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 69}], {
             RGBColor[
             0.9385619033623629, 0.9520995206617606, 0.9290310949897391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 74}], {
             RGBColor[
             0.5397718643891435, 0.6157964610643536, 0.9617443961505856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 88}], {
             RGBColor[
             0.9148446437917355, 0.9348421244089699, 0.9884746815719291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 132}], {
             RGBColor[
             0.9421771298420905, 0.9525024248732743, 0.789734396721278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[
             0.9404025424819416, 0.9528606722399742, 0.8985269413569741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 191}], {
             RGBColor[
             0.9426757095708787, 0.9535688364990091, 0.8440017233224504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 198}], {
             RGBColor[
             0.9190494957062447, 0.9379780960819977, 0.981356964081685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 216}], {
             RGBColor[
             0.9397942729320417, 0.9526091371492761, 0.908607541949951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 224}], {
             RGBColor[
             0.925728216309088, 0.9429590749721969, 0.9700516321903813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 302}], {
             RGBColor[
             0.858364545093724, 0.8899006048455924, 0.9863527706537565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 323}], {
             RGBColor[
             0.9253344960687022, 0.8966220960892568, 0.6448978017057673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 340}], {
             RGBColor[
             0.9376059476078886, 0.9517042083903432, 0.9448737557755662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 357}], {
             RGBColor[
             0.790264911976746, 0.8366488691367702, 0.9795789777300579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 38}], {
             RGBColor[
             0.9186499728561123, 0.9156766297211747, 0.6801331526912306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 102}], {
             RGBColor[
             0.518481487125317, 0.5975163056870653, 0.959911215636712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 205}], {
             RGBColor[
             0.9255144757332159, 0.9385298115472132, 0.7325142137120713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 207}], {
             RGBColor[
             0.9173076026147153, 0.9358460103514412, 0.9554254317490838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.8079709838550827, 0.8502199004271961, 0.9814130378667121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 224}], {
             RGBColor[
             0.909577117861919, 0.9300806274803126, 0.9685111260022345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 230}], {
             RGBColor[
             0.8781496287222089, 0.905676693479158, 0.988239889592594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 247}], {
             RGBColor[
             0.9012370080108015, 0.9238605872090258, 0.9826287565311527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 250}], {
             RGBColor[
             0.9181413204875353, 0.9139608258447087, 0.6781571342902488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 289}], {
             RGBColor[
             0.8326625638072931, 0.8695091503488208, 0.9838740638004146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 340}], {
             RGBColor[
             0.9214548491607197, 0.9388257608984589, 0.9433332495874195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 391}], {
             RGBColor[
             0.9202664891619037, 0.9380527430936022, 0.9504168086259009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 45}], {
             RGBColor[
             0.9941204065814544, 0.9898700096921462, 0.6041495272781279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 100}], {
             RGBColor[
             0.9796018162342218, 0.9808772911367404, 0.7109107202521933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 105}], {
             RGBColor[
             0.895789564881013, 0.9150072737714868, 0.7301416071903687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.9317829306769336, 0.9435343802209992, 0.7336206024440354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 155}], {
             RGBColor[
             0.9412961924046754, 0.7894885345664018, 0.35465422944825287`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 170}], {
             RGBColor[
             0.9786199494475701, 0.9801450164949148, 0.7125727646101231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 180}], {
             RGBColor[
             0.9720299536452816, 0.9752302084156959, 0.7237279085572219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 183}], {
             RGBColor[
             0.993842287950421, 0.989755000490891, 0.608758672742296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 239}], {
             RGBColor[
             0.897587193948306, 0.9164115952613431, 0.7303207780559977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 271}], {
             RGBColor[
             0.9765235036948181, 0.9785814906851273, 0.7161215004289093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 273}], {
             RGBColor[
             0.993479293310561, 0.9896048928787722, 0.6147744333247918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 326}], {
             RGBColor[
             0.991520452663113, 0.9887948619311441, 0.6472374921700979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 335}], {
             RGBColor[
             0.9918942667807537, 0.9889494436753731, 0.6410424248408666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 394}], {
             RGBColor[
             0.9940756146963441, 0.989736663819744, 0.5965454046441333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 73}], {
             RGBColor[
             0.8183769965615804, 0.8574112661286165, 0.9067627872387247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 85}], {
             RGBColor[
             0.8002166747335634, 0.8445062967270243, 0.9661178071912636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 96}], {
             RGBColor[
             0.8212295807797432, 0.8572633980515344, 0.7629939415904086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 110}], {
             RGBColor[
             0.8041315855677309, 0.847426030817068, 0.9594908843212934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 115}], {
             RGBColor[
             0.7957951051549745, 0.8412086973749683, 0.9736023711577753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 184}], {
             RGBColor[
             0.8181569732420718, 0.8573202808316583, 0.9104091430450794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 188}], {
             RGBColor[
             0.7891363206644683, 0.7419619548572305, 0.6138997357279717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 203}], {
             RGBColor[
             0.7195072626597405, 0.7808038091383022, 0.9726774178304183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 206}], {
             RGBColor[
             0.8166312932539527, 0.8566893729483838, 0.9356936087814558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 208}], {
             RGBColor[
             0.8101588129809172, 0.8206845227175644, 0.6548999679711349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 258}], {
             RGBColor[
             0.7967259192878999, 0.8419028970312359, 0.9720267456259393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 284}], {
             RGBColor[
             0.7786573720642356, 0.7004164155599261, 0.6054681277116873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 325}], {
             RGBColor[
             0.8143100652825777, 0.8346876714914575, 0.6710267992648676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 348}], {
             RGBColor[
             0.8211715873476824, 0.8571393559643915, 0.7566817144045543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 369}], {
             RGBColor[
             0.8129479188626121, 0.8540012377529698, 0.9445671317210496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 392}], {
             RGBColor[
             0.8216257202360939, 0.8581107002928254, 0.8061112767248322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 36}], {
             RGBColor[
             0.9939650717870869, 0.9895002237144458, 0.5845134911632569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 64}], {
             RGBColor[
             0.9950948938290918, 0.9919167988197632, 0.7074876479820862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 82}], {
             RGBColor[
             0.9430826933825737, 0.9539695252627349, 0.8502152034138715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 122}], {
             RGBColor[
             0.9817314244046329, 0.9484186168472136, 0.5212265450110476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 157}], {
             RGBColor[
             0.9944788435645773, 0.991850990919307, 0.7314314813809218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 187}], {
             RGBColor[
             0.9012079799883567, 0.9206823731803331, 0.8461939269345207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 218}], {
             RGBColor[
             0.9951412192370179, 0.9921249002821395, 0.720454202315288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 253}], {
             RGBColor[
             0.9913200219544791, 0.9905447370055187, 0.7837813302285273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 262}], {
             RGBColor[
             0.9950928015802303, 0.9919123237110072, 0.707259919605375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 298}], {
             RGBColor[
             0.9889529824981749, 0.9727786279992059, 0.5492809345276425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 74}], {
             RGBColor[
             0.5917334327752523, 0.6531656293067382, 0.7754216572094464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 132}], {
             RGBColor[
             0.9941386982281992, 0.9898715931156589, 0.6034116577801387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 140}], {
             RGBColor[
             0.9923641108680503, 0.9902298404823586, 0.7122042024158349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 191}], {
             RGBColor[
             0.9946372779569874, 0.9909380047413936, 0.6576789843813112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.9710110640923535, 0.9753472643243822, 0.7950342251405458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 216}], {
             RGBColor[
             0.9917558413181504, 0.9899783053916607, 0.7222848030088118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.9776897846951967, 0.9803282432145815, 0.7837288932492421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 247}], {
             RGBColor[
             0.9693496748440793, 0.9741082029432946, 0.7978465237781602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 302}], {
             RGBColor[
             0.9103261134798327, 0.9272697730879769, 0.8000300317126172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 311}], {
             RGBColor[
             0.9797699915415952, 0.9423364013010673, 0.46818580233485474`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 323}], {
             RGBColor[
             0.977296064454811, 0.9339912643316413, 0.4585750627646281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 340}], {
             RGBColor[
             0.9895675159939974, 0.9890733766327278, 0.758551016834427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 357}], {
             RGBColor[
             0.8422264803628547, 0.8740180373791547, 0.7932562387889187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 83}], {
             RGBColor[
             0.7277792170153224, 0.7823680012673571, 0.8272394100701558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 108}], {
             RGBColor[
             0.8763084420911911, 0.9011860492891903, 0.8401386879390287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 125}], {
             RGBColor[
             0.9679220510177056, 0.973600567533673, 0.8444653593250064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 179}], {
             RGBColor[
             0.9213490916299261, 0.9365956567386942, 0.8445686063519788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 196}], {
             RGBColor[
             0.9913372490740082, 0.990495162676116, 0.7793744726865981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 231}], {
             RGBColor[
             0.9601048331440736, 0.9674984330254969, 0.8482651635752572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 303}], {
             RGBColor[
             0.9516232440558019, 0.9607354441131117, 0.8474561820364138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 313}], {
             RGBColor[
             0.9470754716469635, 0.9571091738402974, 0.8470224114442144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 344}], {
             RGBColor[
             0.9770577933186164, 0.9804139891832873, 0.8290009305927654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 50}], {
             RGBColor[
             0.9516094970355948, 0.9598271608787754, 0.7747150628599233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 54}], {
             RGBColor[
             0.9441651131244932, 0.9572033016516998, 0.955970731551774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 116}], {
             RGBColor[
             0.6536682254531659, 0.7248412984561579, 0.9689003718710659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 121}], {
             RGBColor[
             0.951836570568279, 0.9603128482045311, 0.7994306155571985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 130}], {
             RGBColor[
             0.9458889842857394, 0.9584889619411773, 0.9530526673333906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 135}], {
             RGBColor[
             0.940537283698879, 0.9544976724061022, 0.9621117004798867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 147}], {
             RGBColor[
             0.8507307970684946, 0.8840401210833906, 0.9855645615108557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 158}], {
             RGBColor[
             0.9501337676572739, 0.9605615602327338, 0.8969136779272958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 172}], {
             RGBColor[
             0.9463183516261702, 0.9427320280900762, 0.6901181094178372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 181}], {
             RGBColor[
             0.8510008803203777, 0.8842511121724703, 0.9855914808853319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 265}], {
             RGBColor[
             0.9515096131858028, 0.9596135194238767, 0.7638433222217333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 322}], {
             RGBColor[
             0.9169900424026488, 0.8344920329428916, 0.624663146175555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 328}], {
             RGBColor[
             0.9425328271183182, 0.9559859454209175, 0.9587337659918556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 347}], {
             RGBColor[
             0.9507109203862241, 0.9575491939419298, 0.7071824095836398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 362}], {
             RGBColor[
             0.9503684147686423, 0.9606585928434404, 0.8930249680446621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 364}], {
             RGBColor[
             0.9369728857054351, 0.9518393502187579, 0.9681452965389019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 387}], {
             RGBColor[
             0.9436736605841824, 0.9568367771518156, 0.9568026325111691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.9162125012759388, 0.9309854659416706, 0.7213154414298237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 60}], {
             RGBColor[
             0.8196163436327158, 0.8591685079918592, 0.9826132349958185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 64}], {
             RGBColor[
             0.9173423233179437, 0.9334020410469881, 0.8442895982486531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 82}], {
             RGBColor[
             0.8653301228714256, 0.8954547674899598, 0.9870171536804384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 122}], {
             RGBColor[
             0.9039788538934848, 0.8899038590744385, 0.6580284952776145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 159}], {
             RGBColor[
             0.9170295647569386, 0.9327330821097394, 0.8102477590053512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 182}], {
             RGBColor[
             0.7147907729234728, 0.7764752877651859, 0.9727140037121298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 210}], {
             RGBColor[
             0.8892944178175581, 0.914478968679884, 0.9863809493322188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 263}], {
             RGBColor[
             0.9001544678304245, 0.8770033068751861, 0.6431714775973336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 29}], {
             RGBColor[
             0.9184552164602449, 0.9340649608941758, 0.8261994054160022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 45}], {
             RGBColor[
             0.9949834075173831, 0.9917158814313186, 0.6980818533295523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 91}], {
             RGBColor[
             0.9897737320682307, 0.9895615467505421, 0.784419657729886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 97}], {
             RGBColor[
             0.9923257407691903, 0.9906168679320209, 0.7421262691681765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 100}], {
             RGBColor[
             0.9804648171701505, 0.9827231628759128, 0.8048430463036178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 141}], {
             RGBColor[
             0.9817474296392645, 0.9487185327017744, 0.5003769130132487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 150}], {
             RGBColor[
             0.9446945718236444, 0.9549875106126233, 0.8287021385547124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 189}], {
             RGBColor[
             0.9947964793067428, 0.9912785203307948, 0.6750070688253416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 190}], {
             RGBColor[
             0.9894655911345704, 0.9747537037359403, 0.5303605129700131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 255}], {
             RGBColor[
             0.7433637272869253, 0.7947994182758695, 0.8103703278970764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 266}], {
             RGBColor[
             0.9948821184258974, 0.9916739957889784, 0.6997604757032354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 273}], {
             RGBColor[
             0.9943422942464897, 0.9914507646179447, 0.7087067593762162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 350}], {
             RGBColor[
             0.7572054631982259, 0.80603676305176, 0.8114600000519633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 365}], {
             RGBColor[
             0.9686243726822767, 0.973892578763805, 0.8248858303390787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 394}], {
             RGBColor[
             0.9949386156322728, 0.9915825355589165, 0.6904777306955578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[
             0.9780773234074922, 0.9812201322939018, 0.8309075189494036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 89}], {
             RGBColor[
             0.9944533122069118, 0.9918404330467863, 0.7318546020504737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 163}], {
             RGBColor[
             0.994999626542749, 0.9920663480642931, 0.72280075968947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 164}], {
             RGBColor[
             0.9927538294906179, 0.9911376532688851, 0.7600194287797484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 169}], {
             RGBColor[
             0.9935264872146317, 0.9882061333177892, 0.5670481367171818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 227}], {
             RGBColor[
             0.9923426219692687, 0.990967608391256, 0.7668342015794565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 245}], {
             RGBColor[
             0.9402857049848907, 0.95173928263665, 0.8499484241635995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 292}], {
             RGBColor[
             0.977569837474108, 0.9808416501157158, 0.8317665602610935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 304}], {
             RGBColor[
             0.8621888871267354, 0.8902003612807452, 0.8423048684122285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 353}], {
             RGBColor[
             0.9595995124900748, 0.9671395884819451, 0.8517905923650835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 378}], {
             RGBColor[
             0.9904355125818789, 0.9901789696490946, 0.7984399395693915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 25}], {
             RGBColor[
             0.9874613322353586, 0.9890829528973268, 0.8574617040994986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 76}], {
             RGBColor[
             0.9912526310938596, 0.9899842357660023, 0.7461813467356047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 104}], {
             RGBColor[
             0.9029017698395001, 0.9234504164813, 0.9155390738723692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 109}], {
             RGBColor[
             0.9860993596611902, 0.9738393234171372, 0.6208672768517074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 138}], {
             RGBColor[
             0.991421070636655, 0.9907204064868981, 0.7918385913155257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 144}], {
             RGBColor[
             0.9361051552184476, 0.7782153237478693, 0.5368505476294628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 207}], {
             RGBColor[
             0.9822875494693755, 0.9856787032425702, 0.8865662480167916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 233}], {
             RGBColor[
             0.9914267944604271, 0.9903567535964728, 0.7651379543747768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 242}], {
             RGBColor[
             0.9354929564828258, 0.7754354722720584, 0.5363397139980959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 317}], {
             RGBColor[
             0.9646905643745334, 0.897311559464421, 0.5601492363281207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 358}], {
             RGBColor[
             0.9674543090662466, 0.9082688862037408, 0.5623730101804989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 366}], {
             RGBColor[
             0.9049610141780657, 0.5794218254159835, 0.5086164429036313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 382}], {
             RGBColor[
             0.9905243997615392, 0.9903496100366473, 0.8066987482260344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[
             0.9907180953692641, 0.9897631915069405, 0.7550399870262636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 104}], {
             RGBColor[
             0.9023672341149047, 0.9232293722222382, 0.9243977141630282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 109}], {
             RGBColor[
             0.9855648239365947, 0.9736182791580754, 0.6297259171423664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 138}], {
             RGBColor[
             0.9908865349120595, 0.9904993622278363, 0.8006972316061847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 144}], {
             RGBColor[
             0.935570619493852, 0.7779942794888075, 0.5457091879201218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 205}], {
             RGBColor[
             0.9899598868632804, 0.9881414601792804, 0.6725136702704382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 207}], {
             RGBColor[
             0.9817530137447799, 0.9854576589835085, 0.8954248883074506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 233}], {
             RGBColor[
             0.9908922587358318, 0.990135709337411, 0.7739965946654358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 317}], {
             RGBColor[
             0.964156028649938, 0.8970905152053592, 0.5690078766187797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 358}], {
             RGBColor[
             0.9669197733416511, 0.908047841944679, 0.5712316504711579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 366}], {
             RGBColor[
             0.9044264784534704, 0.5792007811569218, 0.5174750831942903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 382}], {
             RGBColor[
             0.9899898640369436, 0.9901285657775856, 0.8155573885166933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 391}], {
             RGBColor[
             0.9847119002919682, 0.9876643917256696, 0.8904162651842678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 30}], {
             RGBColor[
             0.9792852209880574, 0.9416870005576787, 0.3824734886317116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 62}], {
             RGBColor[
             0.9880878087904381, 0.9869704256791517, 0.677843979715806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 77}], {
             RGBColor[
             0.993267800289502, 0.9880088304860741, 0.5086197917120201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 106}], {
             RGBColor[
             0.9938347436512045, 0.9892214650099891, 0.570328077864475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 111}], {
             RGBColor[
             0.9903106532581486, 0.9880026553002117, 0.6460672433994351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 160}], {
             RGBColor[
             0.9929106110004031, 0.9890778046425001, 0.6029792151353278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.9318894429724827, 0.9433923315383725, 0.7152311329468097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 173}], {
             RGBColor[
             0.9889233501712452, 0.987428969821714, 0.6690584457747257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 185}], {
             RGBColor[
             0.9918091279211547, 0.988622313082407, 0.6212336403053047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 197}], {
             RGBColor[
             0.9652075273039282, 0.9699063492095351, 0.7165743281393238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 204}], {
             RGBColor[
             0.9842669986488632, 0.9841208717315675, 0.6843116146586086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 345}], {
             RGBColor[
             0.9925924922661202, 0.9865644149081754, 0.43511668088494726`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 370}], {
             RGBColor[
             0.8493805027182061, 0.8785224479213196, 0.7071170826599449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 389}], {
             RGBColor[
             0.8289362751175255, 0.8625512619377833, 0.7050793931148784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 400}], {
             RGBColor[
             0.9690196806779272, 0.9727494469540352, 0.710121346845981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 51}], {
             RGBColor[
             0.9937301634431476, 0.9910422953054969, 0.7075599549273665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[
             0.9892749253197902, 0.9891683045357262, 0.7799780865404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 277}], {
             RGBColor[
             0.993629791442491, 0.9887830929593976, 0.5480202947644182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 287}], {
             RGBColor[
             0.9660308990843766, 0.9718329478279546, 0.8193241599439874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 376}], {
             RGBColor[
             0.9921401261140118, 0.9903847740078038, 0.7339109883558474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 377}], {
             RGBColor[
             0.9855469490561605, 0.9616463326635067, 0.505687737552758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 395}], {
             RGBColor[
             0.9589311469954598, 0.8622101591793698, 0.45257285712748374`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 396}], {
             RGBColor[
             0.9891313212322648, 0.9737372616641162, 0.5196123466050346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 44}], {
             RGBColor[
             0.7217280051380792, 0.7154270950549947, 0.6149945763098248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 47}], {
             RGBColor[
             0.7449910927983112, 0.795573390595032, 0.7656503238072657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 49}], {
             RGBColor[
             0.6037033409701928, 0.6880960751846549, 0.9626672330029804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 147}], {
             RGBColor[
             0.6440222271341787, 0.719593495490845, 0.9666858427743934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 211}], {
             RGBColor[
             0.7407407589010377, 0.7950048502003932, 0.9225230575750241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 301}], {
             RGBColor[
             0.7451897063547377, 0.7959982049093169, 0.7872681837234832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 328}], {
             RGBColor[
             0.7358242571840022, 0.7915393198283718, 0.9398550472553932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 347}], {
             RGBColor[
             0.7440023504519081, 0.7931025683493842, 0.6883036908471774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 362}], {
             RGBColor[
             0.7436598448343263, 0.7962119672508946, 0.8741462493081997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 372}], {
             RGBColor[
             0.7445404310610857, 0.7946094707079974, 0.7165985748721146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 380}], {
             RGBColor[
             0.7444212008576835, 0.7943544493589427, 0.7036211030353061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 390}], {
             RGBColor[
             0.7331498731436399, 0.7564946141057465, 0.6461438658229306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 45}], {
             RGBColor[
             0.9187102930709133, 0.9346480845314997, 0.8566917227001036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 91}], {
             RGBColor[
             0.913500617621761, 0.9324937498507231, 0.9430295271004372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 150}], {
             RGBColor[
             0.8684214573771747, 0.8979197137128043, 0.9873120079252635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 190}], {
             RGBColor[
             0.9131924766881008, 0.9176859068361214, 0.6889703823405644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 226}], {
             RGBColor[
             0.8781979854131121, 0.7872953854544836, 0.6173209719274949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 266}], {
             RGBColor[
             0.9186090039794277, 0.9346061988891594, 0.8583703450737865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 273}], {
             RGBColor[
             0.9180691798000199, 0.9343829677181257, 0.8673166287467674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 365}], {
             RGBColor[
             0.8923512582358071, 0.9168247818639861, 0.98349569970963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 62}], {
             RGBColor[
             0.974709089550163, 0.9419401913619805, 0.6174241177014845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 77}], {
             RGBColor[
             0.9798890810492269, 0.9429785961689029, 0.4481999296976986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 84}], {
             RGBColor[
             0.797800136115036, 0.8034547811779713, 0.6430222866777457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 204}], {
             RGBColor[
             0.970888279408588, 0.9390906374143962, 0.6238917526442871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 333}], {
             RGBColor[
             0.9226742853109122, 0.7210565913326339, 0.2715847362758179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 370}], {
             RGBColor[
             0.836001783477931, 0.8334922136041483, 0.6466972206456235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 389}], {
             RGBColor[
             0.8155575558772503, 0.817521027620612, 0.644659531100557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 400}], {
             RGBColor[
             0.955640961437652, 0.9277192126368639, 0.6497014848316596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 33}], {
             RGBColor[
             0.8445904692400644, 0.878286110394773, 0.9273626648604714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 106}], {
             RGBColor[
             0.9904429314271037, 0.9900774285539743, 0.7907130216924838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 156}], {
             RGBColor[
             0.9746408349987339, 0.9803272661898343, 0.9152496892716165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 173}], {
             RGBColor[
             0.9855315379471444, 0.9882849333656992, 0.8894433896027344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 175}], {
             RGBColor[
             0.9873407489351717, 0.9890330886038501, 0.8594600814431738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 197}], {
             RGBColor[
             0.9618157150798274, 0.9707623127535203, 0.9369592719673325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 204}], {
             RGBColor[
             0.9808751864247625, 0.9849768352755528, 0.9046965584866172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 214}], {
             RGBColor[
             0.9885566244849262, 0.98953588439025, 0.8393098769986842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 261}], {
             RGBColor[
             0.9746408349987339, 0.9803272661898343, 0.9152496892716165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 295}], {
             RGBColor[
             0.9896185301213247, 0.9899750096606308, 0.8217113524798665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 310}], {
             RGBColor[
             0.9858429438505658, 0.9884137077095307, 0.8842825878903959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 345}], {
             RGBColor[
             0.9892006800420194, 0.9874203784521606, 0.6555016247129559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 43}], {
             RGBColor[
             0.9705425932026899, 0.9340380104199975, 0.6142984248702809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 124}], {
             RGBColor[
             0.8630449679253112, 0.8498883584409975, 0.6424851209565239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 137}], {
             RGBColor[
             0.9594866986735151, 0.8750012630295598, 0.29711390395194676`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 199}], {
             RGBColor[
             0.8941295221498153, 0.8742204925118813, 0.6455704301822669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 238}], {
             RGBColor[
             0.9780492636224327, 0.9367908702695745, 0.43948710816357006`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 252}], {
             RGBColor[
             0.9784024827946753, 0.9375463703630651, 0.477932835246133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 293}], {
             RGBColor[
             0.9701027322580926, 0.9108116370735628, 0.33835518975830636`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 330}], {
             RGBColor[
             0.9684804096678936, 0.9325000373162621, 0.6177891636910854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 63}], {
             RGBColor[
             0.8445224206254971, 0.8782579705438799, 0.9284904065080197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 84}], {
             RGBColor[
             0.6664971965911439, 0.7391979274710803, 0.9675265190784968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 90}], {
             RGBColor[
             0.8155991225905028, 0.8567437260779163, 0.9820234945333794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 152}], {
             RGBColor[
             0.7849935023331602, 0.8323396352521419, 0.9791043031512744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 156}], {
             RGBColor[
             0.8333509884586674, 0.8701842146217869, 0.9589491158300375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 173}], {
             RGBColor[
             0.8442416914070779, 0.8781418817976516, 0.9331428161611554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 175}], {
             RGBColor[
             0.8460509023951052, 0.8788900370358026, 0.9031595080015947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 204}], {
             RGBColor[
             0.839585339884696, 0.8748337837075053, 0.9483959850450382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 214}], {
             RGBColor[
             0.8472667779448597, 0.8793928328222024, 0.8830093035571052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 256}], {
             RGBColor[
             0.7950789982254391, 0.840381535913152, 0.9800662667529084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 261}], {
             RGBColor[
             0.8333509884586674, 0.8701842146217869, 0.9589491158300375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 264}], {
             RGBColor[
             0.8321743035195428, 0.8693066449208323, 0.9609409365033922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 295}], {
             RGBColor[
             0.8483286835812582, 0.8798319580925833, 0.8654107790382874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 310}], {
             RGBColor[
             0.8445530973104993, 0.8782706561414831, 0.9279820144488169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 333}], {
             RGBColor[
             0.7913713457870202, 0.6567997376257428, 0.596088968676569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 381}], {
             RGBColor[
             0.8445944650290765, 0.8782877627562167, 0.9272964442957699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 53}], {
             RGBColor[
             0.9387183634902441, 0.7761217270759504, 0.4272185770591548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 68}], {
             RGBColor[
             0.7056997382397551, 0.5949097403796946, 0.5900699127584269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 86}], {
             RGBColor[
             0.9150747294813624, 0.7609550255732493, 0.5992798326317653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 95}], {
             RGBColor[
             0.9391589200556442, 0.7770640330222396, 0.4751704404029834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 151}], {
             RGBColor[
             0.9383954538873178, 0.7754310560864601, 0.3920718595477035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 244}], {
             RGBColor[
             0.9387502030263595, 0.7761898286242301, 0.4306841140744687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 249}], {
             RGBColor[
             0.6938726229209737, 0.5853079553584345, 0.5891388389163815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 253}], {
             RGBColor[
             0.935282069047753, 0.7754738481535848, 0.540364323334336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 270}], {
             RGBColor[
             0.9390492745596943, 0.776829512393263, 0.4632362048224081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 308}], {
             RGBColor[
             0.8874437720929554, 0.5817902818965771, 0.22779266323980077`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 386}], {
             RGBColor[
             0.9387148758869401, 0.7761142674451338, 0.4268389729624986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 397}], {
             RGBColor[
             0.824991539543559, 0.689847896501472, 0.6007657169812218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 41}], {
             RGBColor[
             0.9228011563078051, 0.8205500078675059, 0.6210578261852988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 57}], {
             RGBColor[
             0.8478940092582485, 0.8820127455483395, 0.9852317299831059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 92}], {
             RGBColor[
             0.9522132305084219, 0.9638077554568987, 0.9632253627098216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 114}], {
             RGBColor[
             0.9573326626066605, 0.9676258195334642, 0.9545594995292388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 153}], {
             RGBColor[
             0.962380410095093, 0.9668374956759533, 0.7082709871967772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 188}], {
             RGBColor[
             0.9312021331235295, 0.853857081482283, 0.627817449327501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 195}], {
             RGBColor[
             0.94280173896892, 0.956788680476641, 0.9791565629760779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 208}], {
             RGBColor[
             0.9522246254399784, 0.9325796493426171, 0.6688176815706641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 258}], {
             RGBColor[
             0.9387917317469612, 0.9537980236562884, 0.9859444592254686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 278}], {
             RGBColor[
             0.9266371464255199, 0.9443393239371721, 0.9928646723164538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 284}], {
             RGBColor[
             0.9207231845232968, 0.8123115421849787, 0.6193858413112167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 327}], {
             RGBColor[
             0.8776720777363816, 0.9052959072858355, 0.988194340353251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 337}], {
             RGBColor[
             0.9156575416158398, 0.9355844850953663, 0.9918174278080977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 354}], {
             RGBColor[
             0.8408245550870812, 0.8764900342199818, 0.9845271128591293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 369}], {
             RGBColor[
             0.9550137313216733, 0.9658963643780223, 0.9584848453205788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 392}], {
             RGBColor[
             0.9636915326951552, 0.9700058269178781, 0.8200289903243614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 55}], {
             RGBColor[
             0.9843948172282472, 0.9588368372682383, 0.4096387772354105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 60}], {
             RGBColor[
             0.8962071793181896, 0.9151984324419252, 0.7193636183508727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 64}], {
             RGBColor[
             0.9939331590034175, 0.9894319654970541, 0.5810399816037073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 82}], {
             RGBColor[
             0.9419209585568993, 0.9514846919400257, 0.7237675370354926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 122}], {
             RGBColor[
             0.9805696895789584, 0.9459337835245045, 0.39477887863266864`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 157}], {
             RGBColor[
             0.9933171087389028, 0.9893661575965977, 0.6049838150025428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 165}], {
             RGBColor[
             0.8980663991893394, 0.9166508691358619, 0.7195489280122314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 218}], {
             RGBColor[
             0.9939794844113435, 0.9896400669594303, 0.594006535936909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 262}], {
             RGBColor[
             0.993931066754556, 0.9894274903882982, 0.5808122532269959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 298}], {
             RGBColor[
             0.9877912476725004, 0.9702937946764967, 0.4228332681492635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 314}], {
             RGBColor[
             0.9860051797921741, 0.9855143012130367, 0.6890735455969602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 58}], {
             RGBColor[
             0.7468480009690921, 0.8004700039650682, 0.9402162831829077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 87}], {
             RGBColor[
             0.9796919872923646, 0.9843748978907401, 0.9192603477227426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 110}], {
             RGBColor[
             0.9678445800884585, 0.9755391209964157, 0.9393149178202791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 134}], {
             RGBColor[
             0.9799282073867532, 0.9692272718197006, 0.658251971368616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 159}], {
             RGBColor[
             0.9852896973108887, 0.9861189471117467, 0.7806000637346338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 167}], {
             RGBColor[
             0.9811917233668241, 0.9851528995231843, 0.9014734414256065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 201}], {
             RGBColor[
             0.9628841929423042, 0.9718396723847025, 0.9477115593825503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 236}], {
             RGBColor[
             0.9783761347490558, 0.9639917663687614, 0.6522224622554854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 243}], {
             RGBColor[
             0.9674362439098912, 0.9752345845430295, 0.9400061244594614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 263}], {
             RGBColor[
             0.9684146003843744, 0.9303891718771935, 0.6135237823266162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 348}], {
             RGBColor[
             0.98488458186841, 0.9852524461437392, 0.7365057479035402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 351}], {
             RGBColor[
             0.8526964491695372, 0.8850714685099774, 0.949459123408078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 78}], {
             RGBColor[
             0.9623196962945562, 0.9502481535507197, 0.6756471085774833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 102}], {
             RGBColor[
             0.5790954857307953, 0.6235543240341095, 0.6537229370545188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 205}], {
             RGBColor[
             0.9861284743386941, 0.9645678298942573, 0.4263259351298781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 207}], {
             RGBColor[
             0.9779216012201937, 0.9618840286984853, 0.6492371531668906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 213}], {
             RGBColor[
             0.8685849824605609, 0.8762579187742403, 0.6752247592845189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 221}], {
             RGBColor[
             0.980426725191881, 0.9456368894280476, 0.3784619527835984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 224}], {
             RGBColor[
             0.9701911164673973, 0.956118645827357, 0.6623228474200413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 230}], {
             RGBColor[
             0.9387636273276871, 0.9317147118262024, 0.6820516110104008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 247}], {
             RGBColor[
             0.9618510066162798, 0.9498986055560701, 0.6764404779489595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 250}], {
             RGBColor[
             0.9787553190930135, 0.9399988441917531, 0.3719688557080556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 289}], {
             RGBColor[
             0.8932765624127712, 0.8955471686958651, 0.6776857852182214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 358}], {
             RGBColor[
             0.9630883608170648, 0.884474211659656, 0.32504391533059784`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 391}], {
             RGBColor[
             0.980880487767382, 0.9640907614406464, 0.6442285300437077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 93}], {
             RGBColor[
             0.9870813230318621, 0.9874143117761222, 0.7743278716209157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 94}], {
             RGBColor[
             0.9850901806570236, 0.9859293210531639, 0.7776983562884141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 119}], {
             RGBColor[
             0.9944569188586702, 0.9905522348671951, 0.6380480095768171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 128}], {
             RGBColor[
             0.9941305761896899, 0.991061722108628, 0.6903002150989546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 177}], {
             RGBColor[
             0.9675668409023501, 0.972860442955964, 0.8073607996741009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 200}], {
             RGBColor[
             0.9593497463491243, 0.9664387307623745, 0.8110972621008838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 225}], {
             RGBColor[
             0.9941337473718004, 0.9910630334739263, 0.6902476604046273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 288}], {
             RGBColor[
             0.9804739892306409, 0.9824865730456875, 0.7855123642777331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 296}], {
             RGBColor[
             0.86765529987213, 0.8939630180382498, 0.8021818062771979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 316}], {
             RGBColor[
             0.9933937777073193, 0.9882200872458393, 0.5272802408638144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 324}], {
             RGBColor[
             0.9137176425387682, 0.6227385351299849, 0.4044194934208165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 355}], {
             RGBColor[
             0.9095734793856971, 0.9267484866265103, 0.806349557322114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 360}], {
             RGBColor[
             0.9942309327795318, 0.9900688734946155, 0.6134508194870163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 374}], {
             RGBColor[
             0.9338474012632938, 0.7540122020067375, 0.4227774328238073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 375}], {
             RGBColor[
             0.9722226555413157, 0.9763327418905077, 0.799479719921268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 380}], {
             RGBColor[
             0.9935713598013118, 0.9886581135872607, 0.5416603712203644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 383}], {
             RGBColor[
             0.9900922114477859, 0.9893917545066107, 0.7572263698252425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 390}], {
             RGBColor[
             0.9823000320872682, 0.9507982783340645, 0.48418313400798885`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 41}], {
             RGBColor[
             0.9270287381857648, 0.82377646212677, 0.6164509854364092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 55}], {
             RGBColor[
             0.9586445139130166, 0.9432012685251486, 0.6727275379612929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 58}], {
             RGBColor[
             0.7294284007853853, 0.7874784946700372, 0.9697031225345617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.9660662720019322, 0.9731100797216685, 0.8929402977826739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 87}], {
             RGBColor[
             0.9622723871086578, 0.971383388595709, 0.9487471870743965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 96}], {
             RGBColor[
             0.9675229751167641, 0.9723849789358511, 0.7723048144410483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 110}], {
             RGBColor[
             0.9504249799047517, 0.9625476117013847, 0.968801757171933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 146}], {
             RGBColor[
             0.950089237367713, 0.9622972154669893, 0.9693700817114616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 154}], {
             RGBColor[
             0.8404744338615694, 0.8761403520229818, 0.9794640094459534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 159}], {
             RGBColor[
             0.9678700971271819, 0.9731274378167157, 0.8100869030862876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 167}], {
             RGBColor[
             0.9637721231831173, 0.9721613902281533, 0.9309602807772603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 192}], {
             RGBColor[
             0.950138383998386, 0.9623338689436749, 0.9692868892852263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 203}], {
             RGBColor[
             0.8658006569967613, 0.8959253900226188, 0.981988290681058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 228}], {
             RGBColor[
             0.8218898998433866, 0.8616219728002875, 0.9776116767773655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 243}], {
             RGBColor[
             0.9500166437261846, 0.9622430752479985, 0.9694929638111154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 332}], {
             RGBColor[
             0.940592453421058, 0.9552145295491306, 0.9854456597752053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 348}], {
             RGBColor[
             0.9674649816847032, 0.9722609368487082, 0.765992587255194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 361}], {
             RGBColor[
             0.9666594146921371, 0.9733553594671401, 0.8831103884019018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 385}], {
             RGBColor[
             0.828489504635697, 0.8667776342228947, 0.9782694637062499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 57}], {
             RGBColor[
             0.8378475989910216, 0.7532714090288163, 0.6128325284339828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.9421668202411949, 0.8350664189373754, 0.5908261611606986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 96}], {
             RGBColor[
             0.9532489829715775, 0.8404171881570638, 0.4045124536408148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 114}], {
             RGBColor[
             0.9472862523394334, 0.838884483013941, 0.5821602979801157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 153}], {
             RGBColor[
             0.9523339998278659, 0.8380961591564302, 0.3358717856476541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 154}], {
             RGBColor[
             0.8262004417163827, 0.7441725612441945, 0.6116716486457199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 188}], {
             RGBColor[
             0.9211557228563025, 0.7251157449627599, 0.25541824777837796`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 203}], {
             RGBColor[
             0.8515266648515747, 0.7639575992438316, 0.6141959298808244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 222}], {
             RGBColor[
             0.7280435258762721, 0.6659746699116087, 0.6029254402575441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 258}], {
             RGBColor[
             0.9287453214797341, 0.8250566871367653, 0.6135452576763456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 312}], {
             RGBColor[
             0.9408903185543862, 0.8341144060694332, 0.5929869455515049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 327}], {
             RGBColor[
             0.8676256674691545, 0.7765545707663123, 0.6157951388041281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 356}], {
             RGBColor[
             0.9270757118245501, 0.8238114949896638, 0.616371471318633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 361}], {
             RGBColor[
             0.9523854225469505, 0.8413875686883528, 0.5153180276016682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 369}], {
             RGBColor[
             0.9449673210544464, 0.8371550278584992, 0.5860856437714557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 104}], {
             RGBColor[
             0.904277384708134, 0.9240192685811697, 0.8927415755219448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 109}], {
             RGBColor[
             0.987474974529824, 0.9744081755170069, 0.5980697785012831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 136}], {
             RGBColor[
             0.9917379833407638, 0.9886489061373503, 0.6264842560739393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 205}], {
             RGBColor[
             0.9918700374565097, 0.9889313565382118, 0.6408575316293548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 207}], {
             RGBColor[
             0.9836631643380092, 0.9862475553424399, 0.8637687496663673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 221}], {
             RGBColor[
             0.9861682883096965, 0.9700004160720022, 0.5929935492830751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 276}], {
             RGBColor[
             0.9458567540908577, 0.8168175629481214, 0.5210421756459449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 358}], {
             RGBColor[
             0.9688299239348804, 0.9088377383036105, 0.5395755118300746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 366}], {
             RGBColor[
             0.9063366290466996, 0.5799906775158532, 0.48581894455320696`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 376}], {
             RGBColor[
             0.9902395407532376, 0.9902318135161721, 0.8114195991850714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 124}], {
             RGBColor[
             0.8713308639574202, 0.8995812504742562, 0.9489087207840818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 137}], {
             RGBColor[
             0.9677725947056242, 0.9246941550628185, 0.6035375037795045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 199}], {
             RGBColor[
             0.9024154181819245, 0.9239133845451398, 0.9519940300098246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 238}], {
             RGBColor[
             0.9863351596545418, 0.9864837623028331, 0.7459107079911279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 252}], {
             RGBColor[
             0.9866883788267844, 0.9872392623963238, 0.7843564350736909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 277}], {
             RGBColor[
             0.9857699018505054, 0.9852747330163298, 0.6843858843885661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 293}], {
             RGBColor[
             0.9783886282902018, 0.9605045291068215, 0.6447787895858642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 299}], {
             RGBColor[
             0.8582490881768532, 0.8893616678092989, 0.9476048516304201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 330}], {
             RGBColor[
             0.9767663057000028, 0.9821929293495206, 0.9242127635186432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 367}], {
             RGBColor[
             0.963699709557488, 0.9087694038447504, 0.5990995957826213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 47}], {
             RGBColor[
             0.9706405648490763, 0.9092225585496818, 0.42717263431546326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 49}], {
             RGBColor[
             0.8293528130209578, 0.8017452431393047, 0.624189543511178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 54}], {
             RGBColor[
             0.9631060152409422, 0.9064058440138039, 0.5986143233235093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 93}], {
             RGBColor[
             0.9635806361389988, 0.9067598155024541, 0.5978109139440551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[
             0.9706298892968266, 0.9104072258349599, 0.5137832574220939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 211}], {
             RGBColor[
             0.9663902309518029, 0.9086540181550431, 0.5840453680832216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 301}], {
             RGBColor[
             0.9708391784055026, 0.9096473728639668, 0.4487904942316808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 316}], {
             RGBColor[
             0.969893090814456, 0.9075655909721713, 0.3507632831869538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 324}], {
             RGBColor[
             0.8902169556459049, 0.5420840388563168, 0.22790253574395586`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 328}], {
             RGBColor[
             0.9614737292347673, 0.9051884877830216, 0.6013773577635908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 362}], {
             RGBColor[
             0.9693093168850913, 0.9098611352055445, 0.5356685598163973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 372}], {
             RGBColor[
             0.9701899031118507, 0.9082586386626472, 0.3781208853803122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 380}], {
             RGBColor[
             0.9700706729084485, 0.9080036173135926, 0.36514341354350377`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 383}], {
             RGBColor[
             0.9665915245549226, 0.9087372582329427, 0.5807094121483818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 390}], {
             RGBColor[
             0.9587993451944049, 0.8701437820603963, 0.30766617633112825`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 91}], {
             RGBColor[
             0.9900288086788992, 0.9901446703878658, 0.8149119750139873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 97}], {
             RGBColor[
             0.9925808173798587, 0.9911999915693447, 0.7726185864522778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 100}], {
             RGBColor[
             0.980719893780819, 0.9833062865132367, 0.8353353635877191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 112}], {
             RGBColor[
             0.9329010082235308, 0.9459633755974955, 0.8580452457795612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 141}], {
             RGBColor[
             0.9820025062499329, 0.9493016563390982, 0.53086923029735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 180}], {
             RGBColor[
             0.9731480311918788, 0.9776592037921921, 0.8481525518927477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 190}], {
             RGBColor[
             0.9897206677452389, 0.9753368273732641, 0.5608528302541145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 266}], {
             RGBColor[
             0.9951371950365658, 0.9922571194263021, 0.7302527929873367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 271}], {
             RGBColor[
             0.9776415812414153, 0.9810104860616236, 0.8405461437644351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 273}], {
             RGBColor[
             0.994597370857158, 0.9920338882552684, 0.7391990766603176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 350}], {
             RGBColor[
             0.7574605398088944, 0.8066198866890838, 0.8419523173360646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 365}], {
             RGBColor[
             0.9688794492929451, 0.9744757024011288, 0.8553781476231801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 394}], {
             RGBColor[
             0.9951936922429412, 0.9921656591962403, 0.7209700479796591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 59}], {
             RGBColor[
             0.9947920800956059, 0.9912691108630016, 0.6745282418418839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 287}], {
             RGBColor[
             0.966042210701191, 0.9718571422325408, 0.8205553596270341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 373}], {
             RGBColor[
             0.7354734305247046, 0.7882892547273703, 0.8011872263153469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 395}], {
             RGBColor[
             0.9589424586122741, 0.8622343535839561, 0.45380405681053027`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 54}], {
             RGBColor[
             0.9863691029011743, 0.9865521395538411, 0.7492700708209501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 121}], {
             RGBColor[
             0.99404056034496, 0.9896616861066725, 0.5927299548263747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 128}], {
             RGBColor[
             0.9938929769570586, 0.9905535213749972, 0.6644390049195348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 130}], {
             RGBColor[
             0.9880929740624205, 0.9878377998433187, 0.7463520066025667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.9923377574339549, 0.9899103981348751, 0.690213017196472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 181}], {
             RGBColor[
             0.8932048700970587, 0.9135999500746117, 0.778890820154508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 265}], {
             RGBColor[
             0.9937136029624839, 0.9889623573260181, 0.5571426614909094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 311}], {
             RGBColor[
             0.9795911638376545, 0.9419539069245928, 0.44872151035758734`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 322}], {
             RGBColor[
             0.9591940321793299, 0.863840870845033, 0.417962485444731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 362}], {
             RGBColor[
             0.9925724045453234, 0.9900074307455817, 0.6863243073138383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 56}], {
             RGBColor[
             0.9619642604869999, 0.970216710469153, 0.9076749825998038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 71}], {
             RGBColor[
             0.9920046109484577, 0.9901949746014298, 0.7264338561114639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 83}], {
             RGBColor[
             0.7250566773431303, 0.7814327425873391, 0.8862121969904302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 103}], {
             RGBColor[
             0.9911386816334344, 0.9883428393554785, 0.6321827940674523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 108}], {
             RGBColor[
             0.8735859024189989, 0.9002507906091723, 0.8991114748593031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 120}], {
             RGBColor[
             0.9881027633553088, 0.9893482011494541, 0.8468315304713969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 143}], {
             RGBColor[
             0.9912524169606125, 0.9906506638576528, 0.7946336191892713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 196}], {
             RGBColor[
             0.9886147094018161, 0.9895599039960982, 0.8383472596068725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 231}], {
             RGBColor[
             0.9573822934718814, 0.966563174345479, 0.9072379504955316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 234}], {
             RGBColor[
             0.7180765532903322, 0.7755818461548702, 0.8857135682077284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 286}], {
             RGBColor[
             0.9913290041901166, 0.9887499200596594, 0.6528982298276366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 290}], {
             RGBColor[
             0.9814603343569491, 0.9847926040309298, 0.8759128143887921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 313}], {
             RGBColor[
             0.9443529319747713, 0.9561739151602795, 0.9059951983644889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 320}], {
             RGBColor[
             0.8193877391234459, 0.8579107735213891, 0.8937095084526347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 331}], {
             RGBColor[
             0.9921610117128192, 0.9905295000218559, 0.7434571141185734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 342}], {
             RGBColor[
             0.9842569632682036, 0.9652269213878508, 0.5971380253021391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 343}], {
             RGBColor[
             0.9915795119483364, 0.989285730824272, 0.6801644533551808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 344}], {
             RGBColor[
             0.9743352536464243, 0.9794787305032693, 0.8879737175130398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 349}], {
             RGBColor[
             0.9903039501785502, 0.9856248281364961, 0.6206294275711761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 147}], {
             RGBColor[
             0.7516470350170572, 0.805911643575155, 0.9758808099757466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 211}], {
             RGBColor[
             0.8483655667839164, 0.8813229982847033, 0.9317180247763772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 301}], {
             RGBColor[
             0.8528145142376162, 0.882316352993627, 0.7964631509248364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 328}], {
             RGBColor[
             0.8434490650668809, 0.8778574679126818, 0.9490500144567464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 347}], {
             RGBColor[
             0.8516271583347867, 0.8794207164336942, 0.6974986580485306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 372}], {
             RGBColor[
             0.8521652389439642, 0.8809276187923074, 0.7257935420734678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 380}], {
             RGBColor[
             0.8520460087405621, 0.8806725974432528, 0.7128160702366594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 54}], {
             RGBColor[
             0.9862789372041418, 0.986359284245039, 0.7394560911371454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 116}], {
             RGBColor[
             0.6957820495328145, 0.753997281049497, 0.7523857314564373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 121}], {
             RGBColor[
             0.9939503946479276, 0.9894688307978704, 0.5829159751425699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.988002808365388, 0.9876449445345166, 0.736538026918762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 135}], {
             RGBColor[
             0.9826511077785276, 0.9836536549994415, 0.745597060065258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 158}], {
             RGBColor[
             0.9922475917369225, 0.9897175428260729, 0.6803990375126672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 172}], {
             RGBColor[
             0.9884321757058188, 0.9718880106834155, 0.4736034690032087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 181}], {
             RGBColor[
             0.8931147044000263, 0.9134070947658095, 0.7690768404707033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 265}], {
             RGBColor[
             0.9936234372654514, 0.988769502017216, 0.5473286818071047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 276}], {
             RGBColor[
             0.9473448657998685, 0.8160882840061148, 0.39863835331459685`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 322}], {
             RGBColor[
             0.9591038664822974, 0.8636480155362309, 0.4081485057609263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 328}], {
             RGBColor[
             0.9846466511979668, 0.9851419280142568, 0.7422191255772269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 362}], {
             RGBColor[
             0.9924822388482909, 0.9898145754367795, 0.6765103276300335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 364}], {
             RGBColor[
             0.9790867097850837, 0.980995332812097, 0.7516306561242734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 59}], {
             RGBColor[
             0.9939626635031691, 0.9915395894245209, 0.7328661516366608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 136}], {
             RGBColor[
             0.9928204637259155, 0.9890965395950875, 0.6085447547225389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 194}], {
             RGBColor[
             0.9884568203441678, 0.9894629775018317, 0.8395471960182235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 246}], {
             RGBColor[
             0.981843257486207, 0.9845305931510798, 0.8507422328433027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 376}], {
             RGBColor[
             0.9913220211383894, 0.9906794469739093, 0.7934800978336709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 377}], {
             RGBColor[
             0.9847288440805381, 0.9619410056296122, 0.5652568470305814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 395}], {
             RGBColor[
             0.9581130420198374, 0.8625048321454754, 0.5121419666053072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 396}], {
             RGBColor[
             0.9883132162566424, 0.9740319346302218, 0.5791814560828581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 117}], {
             RGBColor[
             0.993918941259563, 0.989401555180584, 0.5794924679269023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 133}], {
             RGBColor[
             0.9933673420830194, 0.9909115480816315, 0.7149749310563593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 174}], {
             RGBColor[
             0.8880533489994897, 0.9100283155903509, 0.8146421723171835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 223}], {
             RGBColor[
             0.7719842765719783, 0.8179302289581472, 0.8040471193130938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 260}], {
             RGBColor[
             0.9878328332553892, 0.9881083687405001, 0.7836549108816473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 267}], {
             RGBColor[
             0.9659431650306377, 0.8899900629816557, 0.45942271091163794`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 272}], {
             RGBColor[
             0.9325670798243213, 0.945211595957621, 0.8189703979295939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 291}], {
             RGBColor[
             0.9810903277848559, 0.9465993034474803, 0.4895479901348493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 346}], {
             RGBColor[
             0.9865521656465087, 0.9871532489346978, 0.7858227470918746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 384}], {
             RGBColor[
             0.9693447548150873, 0.974319990111173, 0.8149504052179559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 68}], {
             RGBColor[
             0.76136720093069, 0.8091881881223582, 0.7931613460643281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 86}], {
             RGBColor[
             0.9707421921722973, 0.9752334733159129, 0.8023712659376665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 95}], {
             RGBColor[
             0.9948263827465791, 0.9913424807649032, 0.6782618737088846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 101}], {
             RGBColor[
             0.9636166963781057, 0.9698457596028216, 0.8118835190497389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 129}], {
             RGBColor[
             0.9943274435599094, 0.9902753002951068, 0.6239554223356361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 151}], {
             RGBColor[
             0.9940629165782527, 0.9897095038291237, 0.5951632928536046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 171}], {
             RGBColor[
             0.9786116953057491, 0.9811025358677126, 0.7890502498278666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 244}], {
             RGBColor[
             0.9944176657172943, 0.9904682763668937, 0.6337755473803699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 249}], {
             RGBColor[
             0.7495400856119085, 0.7995864031010981, 0.7922302722222827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 253}], {
             RGBColor[
             0.9909495317386878, 0.9897522958962484, 0.7434557566402371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 270}], {
             RGBColor[
             0.9947167372506291, 0.9911079601359266, 0.6663276381283092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 308}], {
             RGBColor[
             0.9431112347838904, 0.7960687296392407, 0.43088409654570187`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 386}], {
             RGBColor[
             0.994382338577875, 0.9903927151877974, 0.6299304062683997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 397}], {
             RGBColor[
             0.8806590022344938, 0.9041263442441356, 0.8038571502871229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 121}], {
             RGBColor[
             0.986506010736826, 0.9868449715707948, 0.7641716438344206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 128}], {
             RGBColor[
             0.9863584273489245, 0.9877368068391192, 0.8358806939275807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 130}], {
             RGBColor[
             0.9805584244542864, 0.9850210853074408, 0.9177936956106126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 158}], {
             RGBColor[
             0.9848032078258208, 0.9870936835989972, 0.8616547062045179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 181}], {
             RGBColor[
             0.8856703204889247, 0.9107832355387339, 0.9503325091625539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 265}], {
             RGBColor[
             0.9861790533543497, 0.9861456427901403, 0.7285843504989553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 311}], {
             RGBColor[
             0.9720566142295204, 0.939137192388715, 0.6201631993656332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 322}], {
             RGBColor[
             0.9516594825711957, 0.8610241563091552, 0.5894041744527769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 328}], {
             RGBColor[
             0.9772022672868652, 0.9825180687871811, 0.9234747942690775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 362}], {
             RGBColor[
             0.9850378549371892, 0.9871907162097038, 0.8577659963218842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 58}], {
             RGBColor[
             0.7467701843674506, 0.7749355102896285, 0.6581873142592118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 60}], {
             RGBColor[
             0.8877986595850242, 0.8870198793184269, 0.6709365708014053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 80}], {
             RGBColor[
             0.9834080555839974, 0.96056709534126, 0.5814244895073241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 87}], {
             RGBColor[
             0.979614170690723, 0.9588404042153004, 0.6372313787990467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 122}], {
             RGBColor[
             0.972161169845793, 0.9177552304010062, 0.3463518310832012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 146}], {
             RGBColor[
             0.9674310209497782, 0.9497542310865805, 0.6578542734361117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 159}], {
             RGBColor[
             0.985211880709247, 0.960584453436307, 0.49857109481093786`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.889657879456174, 0.8884723160123635, 0.671121880462764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 192}], {
             RGBColor[
             0.9674801675804512, 0.9497908845632663, 0.6577710810098765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 201}], {
             RGBColor[
             0.9628063763406627, 0.9463051787092628, 0.6656825904588544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 210}], {
             RGBColor[
             0.9574767337698664, 0.9423303400064518, 0.6747042851378056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 228}], {
             RGBColor[
             0.8392316834254517, 0.8490789884198788, 0.6660958685020157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 385}], {
             RGBColor[
             0.8458312882177623, 0.854234649842486, 0.6667536554309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 71}], {
             RGBColor[
             0.9643528669759382, 0.9704377198360151, 0.8123556294790828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 83}], {
             RGBColor[
             0.6974049333706108, 0.7616754878219245, 0.9721339703580492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 108}], {
             RGBColor[
             0.8459341584464795, 0.8804935358437578, 0.985033248226922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 120}], {
             RGBColor[
             0.9604510193827893, 0.9695909463840395, 0.9327533038390159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 143}], {
             RGBColor[
             0.963600672988093, 0.9708934090922381, 0.8805553925568902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 196}], {
             RGBColor[
             0.9609629654292966, 0.9698026492306835, 0.9242690329744914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 231}], {
             RGBColor[
             0.929730549499362, 0.9468059195800643, 0.9931597238631504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 237}], {
             RGBColor[
             0.8945595019473943, 0.9187614809547784, 0.989805077950079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 254}], {
             RGBColor[
             0.8013184529232578, 0.8456394075970961, 0.9805863716578405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 286}], {
             RGBColor[
             0.9636772602175971, 0.9689926652942448, 0.7388200031952554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 290}], {
             RGBColor[
             0.9538085903844297, 0.9650353492655153, 0.961834587756411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 320}], {
             RGBColor[
             0.7917359951509264, 0.8381535187559745, 0.9796312818202536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 331}], {
             RGBColor[
             0.9645092677402998, 0.9707722452564413, 0.8293788874861923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 342}], {
             RGBColor[
             0.9566052192956841, 0.9454696666224361, 0.6830597986697581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 343}], {
             RGBColor[
             0.9639277679758169, 0.9695284760588574, 0.7660862267227997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 344}], {
             RGBColor[
             0.9466835096739048, 0.9597214757378547, 0.9738954908806587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 349}], {
             RGBColor[
             0.9626522062060308, 0.9658675733710815, 0.706551200938795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 92}], {
             RGBColor[
             0.8672596731916383, 0.896529156618209, 0.9550000649585056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 114}], {
             RGBColor[
             0.8723791052898768, 0.9003472206947745, 0.9463342017779228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 153}], {
             RGBColor[
             0.8774268527783093, 0.8995588968372638, 0.7000456894454612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 188}], {
             RGBColor[
             0.846248575806746, 0.7865784826435933, 0.6195921515761851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 195}], {
             RGBColor[
             0.8578481816521364, 0.8895100816379513, 0.9709312652247619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 208}], {
             RGBColor[
             0.8672710681231948, 0.8653010505039274, 0.6605923838193482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 258}], {
             RGBColor[
             0.8538381744301775, 0.8865194248175987, 0.9777191614741526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 278}], {
             RGBColor[
             0.8416835891087362, 0.8770607250984825, 0.9846393745651378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 284}], {
             RGBColor[
             0.8357696272065132, 0.745032943346289, 0.6111605435599007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 327}], {
             RGBColor[
             0.7927185204195979, 0.8380173084471458, 0.9799690426019351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 337}], {
             RGBColor[
             0.8307039842990562, 0.8683058862566766, 0.9835921300567817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 354}], {
             RGBColor[
             0.7558709977702975, 0.8092114353812923, 0.9763018151078133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 392}], {
             RGBColor[
             0.8787379753783715, 0.9027272280791885, 0.8118036925730454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 60}], {
             RGBColor[
             0.6585825464573929, 0.7312971054633154, 0.9679121553746741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 80}], {
             RGBColor[
             0.7541919424563661, 0.8048443214861485, 0.8784000740805928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 87}], {
             RGBColor[
             0.7503980575630917, 0.8031176303601889, 0.9342069633723156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 110}], {
             RGBColor[
             0.7385506503591857, 0.7942818534658647, 0.9542615334698521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 159}], {
             RGBColor[
             0.7559957675816158, 0.8048616795811956, 0.7955466793842068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 167}], {
             RGBColor[
             0.7518977936375513, 0.8038956319926331, 0.9164200570751794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 192}], {
             RGBColor[
             0.7382640544528198, 0.7940681107081549, 0.9547466655831454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 201}], {
             RGBColor[
             0.7335902632130313, 0.7905824048541513, 0.9626581750321231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 210}], {
             RGBColor[
             0.7282606206422352, 0.7866075661513403, 0.9716798697110743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 228}], {
             RGBColor[
             0.6100155702978205, 0.6933562145647674, 0.9630714530752846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 236}], {
             RGBColor[
             0.749082205019783, 0.7827344988382103, 0.6671690779050583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 243}], {
             RGBColor[
             0.7381423141806184, 0.7939773170124783, 0.9549527401090343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 263}], {
             RGBColor[
             0.7391206706551016, 0.7491319043466423, 0.6284703979761892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 348}], {
             RGBColor[
             0.7555906521391371, 0.803995178613188, 0.7514523635531131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 351}], {
             RGBColor[
             0.6234025194402644, 0.7038142009794264, 0.964405739057651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 79}], {
             RGBColor[
             0.9892624729456784, 0.9894829135304464, 0.8056989238268553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[
             0.9895074253798117, 0.9896655986547502, 0.8052842832496943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 237}], {
             RGBColor[
             0.9249098779595606, 0.939402858391629, 0.8423083194004335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 246}], {
             RGBColor[
             0.982893862521851, 0.9847332143039984, 0.8164793200747735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 254}], {
             RGBColor[
             0.831668828935424, 0.8662807850339467, 0.8330896131081948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 349}], {
             RGBColor[
             0.9930025822181969, 0.9865089508079321, 0.5590544423891495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 373}], {
             RGBColor[
             0.7356946189679117, 0.7887623544418081, 0.8252622233415946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 395}], {
             RGBColor[
             0.9591636470554812, 0.8627074532983938, 0.477879053836778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 87}], {
             RGBColor[
             0.8914265327806654, 0.9152019993889873, 0.946956219914509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 122}], {
             RGBColor[
             0.8839735319357355, 0.8741168255746931, 0.6560766721986635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 146}], {
             RGBColor[
             0.8792433830397206, 0.9061158262602675, 0.967579114551574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 159}], {
             RGBColor[
             0.8970242427991895, 0.916946048609994, 0.8082959359264001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 165}], {
             RGBColor[
             0.8014702415461165, 0.8448339111860503, 0.9808467215782263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 201}], {
             RGBColor[
             0.874618738430605, 0.9026667738829497, 0.9754074315743166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 210}], {
             RGBColor[
             0.8692890958598088, 0.8986919351801386, 0.9844291262532678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 263}], {
             RGBColor[
             0.8801491458726752, 0.8612162733754407, 0.6412196545183826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 66}], {
             RGBColor[
             0.49141468961353557`, 0.5774508220275372, 0.9570755062088961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 98}], {
             RGBColor[
             0.5906984407548432, 0.6536181708834672, 0.8565799252166965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 107}], {
             RGBColor[
             0.5764791775362369, 0.6443424459835279, 0.9401637935945824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 131}], {
             RGBColor[
             0.5899495960603041, 0.6533085043578444, 0.868990219753158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 215}], {
             RGBColor[
             0.4582764535631673, 0.5515629801650674, 0.9537725965338182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 262}], {
             RGBColor[
             0.5921321770905073, 0.654018503077834, 0.8188225151602839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 269}], {
             RGBColor[
             0.33383762031440445`, 0.4518398425484784, 0.9430861906352549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 279}], {
             RGBColor[
             0.5304038852007131, 0.6083266887465202, 0.9608508699326994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 297}], {
             RGBColor[
             0.5870007635134633, 0.638286395919309, 0.6647609950481209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 298}], {
             RGBColor[
             0.5859923580084516, 0.6348848073660325, 0.6608435300825515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 300}], {
             RGBColor[
             0.5909334582203323, 0.6514545646235987, 0.6883493637770868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 306}], {
             RGBColor[
             0.5437344204135495, 0.6189560956774971, 0.962122348281609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 307}], {
             RGBColor[
             0.50396989992799, 0.5872590477483217, 0.9583268922379298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 314}], {
             RGBColor[
             0.5842062901281253, 0.6501053139025725, 0.9270838075302482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 352}], {
             RGBColor[
             0.5683696015745325, 0.6382943375095005, 0.9538911903815922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 77}], {
             RGBColor[
             0.9886916688516076, 0.9882620212903759, 0.743570420781793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 204}], {
             RGBColor[
             0.9796908672109688, 0.9843740625358692, 0.9192622437283815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 345}], {
             RGBColor[
             0.988016360828226, 0.9868176057124769, 0.6700673099547203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 370}], {
             RGBColor[
             0.8448043712803117, 0.8787756387256213, 0.942067711729718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 389}], {
             RGBColor[
             0.8243601436796311, 0.862804452742085, 0.9400300221846514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 400}], {
             RGBColor[
             0.9644435492400327, 0.9730026377583368, 0.9450719759157541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 90}], {
             RGBColor[
             0.956820920516002, 0.9668586377950706, 0.9394518096225069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 138}], {
             RGBColor[
             0.9902952459321761, 0.9902548490392209, 0.8104964202096794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 142}], {
             RGBColor[
             0.8455060479796619, 0.8790263877087983, 0.9285884452901626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 152}], {
             RGBColor[
             0.9262153002586595, 0.9424545469692962, 0.9365326182404017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 156}], {
             RGBColor[
             0.9745727863841667, 0.9802991263389411, 0.9163774309191648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 202}], {
             RGBColor[
             0.9892095107574722, 0.9875566757144876, 0.6649972069889514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 214}], {
             RGBColor[
             0.988488575870359, 0.9895077445393567, 0.8404376186462326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 217}], {
             RGBColor[
             0.9903049355326576, 0.989899678544175, 0.7842274335897923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 242}], {
             RGBColor[
             0.9343671317783471, 0.7749699148243814, 0.5549975428922496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 256}], {
             RGBColor[
             0.9363007961509383, 0.9504964476303064, 0.9374945818420357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 257}], {
             RGBColor[
             0.9897396307611771, 0.9886905487990582, 0.7226974978707945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 261}], {
             RGBColor[
             0.9745727863841667, 0.9802991263389411, 0.9163774309191648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 264}], {
             RGBColor[
             0.973396101445042, 0.9794215566379867, 0.9183692515925195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 268}], {
             RGBColor[
             0.9851228900102548, 0.9881159469420224, 0.8962157434639548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 317}], {
             RGBColor[
             0.9635647396700546, 0.8968460020167438, 0.5788070652222744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 381}], {
             RGBColor[
             0.9858162629545757, 0.988402674473371, 0.8847247593848971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 82}], {
             RGBColor[
             0.9430507805989041, 0.9539012670453433, 0.8467416938543219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 151}], {
             RGBColor[
             0.9944014940103745, 0.9904336867210024, 0.632015356882345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 157}], {
             RGBColor[
             0.9944469307809077, 0.9917827327019153, 0.7279579718213722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 171}], {
             RGBColor[
             0.9789502727378707, 0.9818267187595914, 0.825902313856607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 182}], {
             RGBColor[
             0.7925114306509514, 0.8349217873205694, 0.8324385438860133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 253}], {
             RGBColor[
             0.9912881091708096, 0.9904764787881271, 0.7803078206689775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 105}], {
             RGBColor[
             0.8808992148237317, 0.8650867964912985, 0.646090866558213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 113}], {
             RGBColor[
             0.9784761053233392, 0.9382993664702283, 0.4353070489194549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 148}], {
             RGBColor[
             0.9423203734705314, 0.9138893347410522, 0.6519951873936553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 161}], {
             RGBColor[
             0.9774954500387637, 0.9392322280528878, 0.5488457051268902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 168}], {
             RGBColor[
             0.8115763496821624, 0.8109312473694157, 0.6391814112199086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 170}], {
             RGBColor[
             0.9637295993902888, 0.9302245392147265, 0.6285220239779674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 180}], {
             RGBColor[
             0.9571396035880002, 0.9253097311355074, 0.6396771679250662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 239}], {
             RGBColor[
             0.8826968438910248, 0.8664911179811547, 0.6462700374238421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 251}], {
             RGBColor[
             0.9753449967654058, 0.9383429603602258, 0.5844842810611068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 282}], {
             RGBColor[
             0.8933881529442209, 0.8748721103231147, 0.6473279885175468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 312}], {
             RGBColor[
             0.9661237599942445, 0.9320101002730784, 0.6244693345725625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 326}], {
             RGBColor[
             0.9766301026058317, 0.9388743846509557, 0.5631867515379423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 356}], {
             RGBColor[
             0.9523091532644083, 0.9217071891933091, 0.6478538603396904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[
             0.8929075727350637, 0.9148715771401962, 0.8795690827741387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 107}], {
             RGBColor[
             0.8786883095164575, 0.9055958522402567, 0.9631529511520245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 131}], {
             RGBColor[
             0.8921587280405245, 0.9145619106145734, 0.8919793773106002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 215}], {
             RGBColor[
             0.7604855855433879, 0.8128163864217963, 0.9767617540912604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 297}], {
             RGBColor[
             0.8892098954936838, 0.899539802176038, 0.6877501526055632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 307}], {
             RGBColor[
             0.8061790319082106, 0.8485124540050506, 0.9813160497953721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 314}], {
             RGBColor[
             0.8864154221083459, 0.9113587201593014, 0.9500729650876905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 352}], {
             RGBColor[
             0.870578733554753, 0.8995477437662295, 0.9768803479390344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 85}], {
             RGBColor[
             0.9731628884026655, 0.9771938368561075, 0.8105732180669876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 127}], {
             RGBColor[
             0.9903555595519977, 0.9896986578345754, 0.7672546740599366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 139}], {
             RGBColor[
             0.7720749337986487, 0.8180288711897779, 0.8061067442875323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 184}], {
             RGBColor[
             0.9911031869111739, 0.9900078209607417, 0.7548645539208032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 305}], {
             RGBColor[
             0.9116008013098091, 0.9285189702979246, 0.8190227893377351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 325}], {
             RGBColor[
             0.9872562789516797, 0.9673752116205409, 0.5154822101405915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 86}], {
             RGBColor[
             0.7377235669218083, 0.7940214866196571, 0.9652226016369386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 95}], {
             RGBColor[
             0.76180775749609, 0.8101304940686473, 0.8411132094081567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 129}], {
             RGBColor[
             0.7613088183094203, 0.809063313598851, 0.7868067580349083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 151}], {
             RGBColor[
             0.7610442913277637, 0.8084975171328678, 0.7580146285528768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 178}], {
             RGBColor[
             0.6995582471109354, 0.7638834597892417, 0.9717742486247221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 229}], {
             RGBColor[
             0.7305980711276165, 0.7886337729065657, 0.9747348547490111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 249}], {
             RGBColor[
             0.5165214603614194, 0.6183744164048421, 0.9550816079215548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 308}], {
             RGBColor[
             0.7100926095334013, 0.6148567429429848, 0.593735432244974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 309}], {
             RGBColor[
             0.7140273948797713, 0.7754207654655583, 0.9731543288556743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 319}], {
             RGBColor[
             0.7614802225338186, 0.810008042598118, 0.8474857401281071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 334}], {
             RGBColor[
             0.7592694974025596, 0.809093850943298, 0.8841231767263107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 371}], {
             RGBColor[
             0.7395640810294977, 0.7953941390276066, 0.9621070913355798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 386}], {
             RGBColor[
             0.7613637133273858, 0.8091807284915414, 0.7927817419676719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 74}], {
             RGBColor[
             0.5879955966065344, 0.6525004753682153, 0.9013730474906074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 97}], {
             RGBColor[
             0.9883543931057099, 0.9894522565178345, 0.8426613743103314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 100}], {
             RGBColor[
             0.97649346950667, 0.9815585514617265, 0.9053781514457727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 132}], {
             RGBColor[
             0.9904008620594813, 0.989206439177136, 0.7293630480612997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 140}], {
             RGBColor[
             0.9886262746993324, 0.9895646865438358, 0.8381555926969959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 141}], {
             RGBColor[
             0.9777760819757841, 0.9475539212875881, 0.6009120181554036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 168}], {
             RGBColor[
             0.823358353011892, 0.8615329849745903, 0.9176995830456436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 191}], {
             RGBColor[
             0.9908994417882695, 0.9902728508028708, 0.7836303746624722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 216}], {
             RGBColor[
             0.9880180051494325, 0.9893131514531377, 0.8482361932899727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 219}], {
             RGBColor[
             0.9906562178805802, 0.990404120216442, 0.8045141808591652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 220}], {
             RGBColor[
             0.9779674736173614, 0.9826578613140198, 0.9028830469682152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 350}], {
             RGBColor[
             0.7532341155347455, 0.8048721516375736, 0.9119951051941182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 357}], {
             RGBColor[
             0.8384886441941368, 0.8733528834406319, 0.9192076290700797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 394}], {
             RGBColor[
             0.9909672679687923, 0.9904179241447302, 0.7910128358377128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 75}], {
             RGBColor[
             0.8481228467102937, 0.8777308016989303, 0.7222773806054108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 103}], {
             RGBColor[
             0.8479809907536737, 0.8774273861515574, 0.7068372351608061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 133}], {
             RGBColor[
             0.8477323397682021, 0.8795853546005475, 0.8752937393089459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.8481993628349513, 0.8778944619526059, 0.7306056885716035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 164}], {
             RGBColor[
             0.8468407375342362, 0.8792166541636703, 0.8900698957183766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 227}], {
             RGBColor[
             0.846429530012887, 0.8790466092860413, 0.8968846685180847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 234}], {
             RGBColor[
             0.5749188624105714, 0.6646663929509491, 0.9603680093010821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 280}], {
             RGBColor[
             0.7925531670078054, 0.66216611176797, 0.5970751092722812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 346}], {
             RGBColor[
             0.8409171633316914, 0.8758270554536138, 0.9461415553444612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 79}], {
             RGBColor[
             0.98895244739497, 0.9888198002258726, 0.7719545558881611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 109}], {
             RGBColor[
             0.9892980343999113, 0.9743953168230888, 0.5121229964426591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 120}], {
             RGBColor[
             0.9904913698442472, 0.9895692105163162, 0.7515121773506761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 143}], {
             RGBColor[
             0.993641023449551, 0.9908716732245149, 0.6993142660685503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 237}], {
             RGBColor[
             0.9245998524088521, 0.938739745087055, 0.8085639514617391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 286}], {
             RGBColor[
             0.9937176106790551, 0.9889709294265214, 0.5575788767069156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 320}], {
             RGBColor[
             0.8217763456123843, 0.8581317828882511, 0.7983901553319137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 321}], {
             RGBColor[
             0.9892980343999113, 0.9743953168230888, 0.5121229964426591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 343}], {
             RGBColor[
             0.9939681184372748, 0.9895067401911339, 0.5848451002344599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 382}], {
             RGBColor[
             0.9937230745002601, 0.9909056034425989, 0.6979544678169861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 119}], {
             RGBColor[
             0.9945528070362009, 0.9907573299831516, 0.6484848459478048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 200}], {
             RGBColor[
             0.9594456345266551, 0.966643825878331, 0.8215340984718715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 288}], {
             RGBColor[
             0.9805698774081717, 0.982691668161644, 0.7959492006487208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 341}], {
             RGBColor[
             0.9374414683068584, 0.9490983010218456, 0.8194353214544763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 355}], {
             RGBColor[
             0.9096693675632279, 0.9269535817424668, 0.8167863936931017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 374}], {
             RGBColor[
             0.9339432894408246, 0.7542172971226939, 0.433214269194795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 375}], {
             RGBColor[
             0.9723185437188464, 0.9765378370064641, 0.8099165562922557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 379}], {
             RGBColor[
             0.9768916003941103, 0.9324360100504216, 0.4732367270849388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 393}], {
             RGBColor[
             0.9922778877534264, 0.9904610307186457, 0.7330300087151405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 399}], {
             RGBColor[
             0.8923792436931494, 0.9134077374030551, 0.8150733370724632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 85}], {
             RGBColor[
             0.9698777296382339, 0.9764164717187167, 0.9072589938946249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 96}], {
             RGBColor[
             0.9908906356844138, 0.989173573043227, 0.7041351282937698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 110}], {
             RGBColor[
             0.9737926404724014, 0.9793362058087607, 0.9006320710246547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 115}], {
             RGBColor[
             0.9654561600596451, 0.9731188723666608, 0.9147435578611365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 184}], {
             RGBColor[
             0.9878180281467424, 0.9892304558233509, 0.8515503297484406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 188}], {
             RGBColor[
             0.9587973755691388, 0.8738721298489229, 0.5550409224313331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 195}], {
             RGBColor[
             0.9703969814145292, 0.9768037288432809, 0.9063800360799099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 203}], {
             RGBColor[
             0.8891683175644112, 0.9127139841299947, 0.9138186045337795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 206}], {
             RGBColor[
             0.9862923481586232, 0.9885995479400764, 0.876834795484817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 208}], {
             RGBColor[
             0.9798198678855878, 0.952594697709257, 0.5960411546744961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 258}], {
             RGBColor[
             0.9663869741925706, 0.9738130720229283, 0.9131679323293006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 284}], {
             RGBColor[
             0.9483184269689061, 0.8323265905516186, 0.5466093144150487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 348}], {
             RGBColor[
             0.990832642252353, 0.989049530956084, 0.6978229011079157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 369}], {
             RGBColor[
             0.9826089737672827, 0.9859114127446622, 0.8857083184244108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 392}], {
             RGBColor[
             0.9912867751407645, 0.9900208752845181, 0.7472524634281934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 132}], {
             RGBColor[
             0.591610823086262, 0.652903379579729, 0.7620763492221462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 140}], {
             RGBColor[
             0.5898362357261131, 0.6532616269464289, 0.8708688938578424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 191}], {
             RGBColor[
             0.5921094028150502, 0.6539697912054638, 0.8163436758233187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 198}], {
             RGBColor[
             0.5684831889504163, 0.6383790507884524, 0.9536989165825532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 216}], {
             RGBColor[
             0.5892279661762132, 0.6530100918557309, 0.8809494944508192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 219}], {
             RGBColor[
             0.5918661789073609, 0.654101060619035, 0.8372274820200116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 220}], {
             RGBColor[
             0.579177434644142, 0.646354801716613, 0.9355963481290617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 224}], {
             RGBColor[
             0.5751619095532595, 0.6433600296786517, 0.9423935846912495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 302}], {
             RGBColor[
             0.5077982383378955, 0.5903015595520471, 0.9586947231546248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 311}], {
             RGBColor[
             0.577242116399658, 0.6053681877651376, 0.6268504937768622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 323}], {
             RGBColor[
             0.5747681893128738, 0.5970230507957115, 0.6172397542066356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 340}], {
             RGBColor[
             0.5870396408520602, 0.652105163096798, 0.9172157082764345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 357}], {
             RGBColor[
             0.43969860522091747`, 0.537049823843225, 0.9519209302309262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 89}], {
             RGBColor[
             0.993362444260826, 0.9895071768137764, 0.6131203581756204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 133}], {
             RGBColor[
             0.9925545637784978, 0.9891730974727524, 0.6265090284954644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 145}], {
             RGBColor[
             0.9930215868452472, 0.9874822048248107, 0.4818209777581218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.9939087585966632, 0.9897330918312831, 0.6040665158146167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 164}], {
             RGBColor[
             0.991662961544532, 0.9888043970358752, 0.6412851849048951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 169}], {
             RGBColor[
             0.9924356192685457, 0.9858728770847793, 0.44831389284232837`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 209}], {
             RGBColor[
             0.984125350641285, 0.9842110523971774, 0.700088987657077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 227}], {
             RGBColor[
             0.9912517540231829, 0.9886343521582461, 0.648099957704603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 280}], {
             RGBColor[
             0.9373753910181013, 0.7717538546401748, 0.3482903984587997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 315}], {
             RGBColor[
             0.9700218144420025, 0.9736926581921735, 0.7239625956511031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[
             0.9061585329734057, 0.9241306550909136, 0.8131173567991341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 109}], {
             RGBColor[
             0.9893561227950958, 0.9745195620267508, 0.5184455597784724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 138}], {
             RGBColor[
             0.9946778337705605, 0.9914006450965116, 0.6894168742422906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 144}], {
             RGBColor[
             0.9393619183523532, 0.7788955623574828, 0.4344288305562278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 207}], {
             RGBColor[
             0.985544312603281, 0.9863589418521839, 0.7841445309435566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 233}], {
             RGBColor[
             0.9946835575943327, 0.9910369922060863, 0.6627162373015418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 242}], {
             RGBColor[
             0.9387497196167314, 0.7761157108816721, 0.4339179969248608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 257}], {
             RGBColor[
             0.9941222185995615, 0.989836344856349, 0.6016179519034057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 317}], {
             RGBColor[
             0.9679473275084389, 0.8979917980740346, 0.45772751925488575`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 358}], {
             RGBColor[
             0.9707110722001522, 0.9089491248133543, 0.4599512931072639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 366}], {
             RGBColor[
             0.9082177773119713, 0.5801020640255972, 0.4061947258303963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 382}], {
             RGBColor[
             0.9937811628954447, 0.9910298486462609, 0.7042770311527994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 78}], {
             RGBColor[
             0.9696235407390967, 0.9740410425652593, 0.7758477879119681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 102}], {
             RGBColor[
             0.5863993301753357, 0.6473472130486492, 0.7539236163890035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 111}], {
             RGBColor[
             0.9909145133193181, 0.9892942509114357, 0.7117936844654221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 160}], {
             RGBColor[
             0.9935144710615726, 0.9903694002537242, 0.668705656201315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 166}], {
             RGBColor[
             0.9324933030336522, 0.9446839271495967, 0.7809575740127968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 185}], {
             RGBColor[
             0.9924129879823242, 0.989913908693631, 0.6869600813712917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 370}], {
             RGBColor[
             0.8499843627793756, 0.8798140435325437, 0.772843523725932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 389}], {
             RGBColor[
             0.8295401351786951, 0.8638428575490074, 0.7708058341808655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 400}], {
             RGBColor[
             0.9696235407390967, 0.9740410425652593, 0.7758477879119681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 102}], {
             RGBColor[
             0.5621512105637609, 0.6320878295166101, 0.9554251715229646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 144}], {
             RGBColor[
             0.9147949318022315, 0.762954154686285, 0.6012236872480076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 160}], {
             RGBColor[
             0.9692663514499977, 0.9751100167216852, 0.8702072113352759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 185}], {
             RGBColor[
             0.9681648683707494, 0.9746545251615921, 0.8884616365052527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 207}], {
             RGBColor[
             0.9609773260531593, 0.9704175341809861, 0.9509393876353364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 213}], {
             RGBColor[
             0.8516407072935266, 0.884791424256741, 0.9769269937529647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 230}], {
             RGBColor[
             0.9218193521606528, 0.940248217308703, 0.9837538454788466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 247}], {
             RGBColor[
             0.9449067314492454, 0.9584321110385707, 0.9781427124174054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 289}], {
             RGBColor[
             0.8763322872457369, 0.9040806741783658, 0.9793880196866673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 370}], {
             RGBColor[
             0.8257362431678008, 0.8645546600005047, 0.9743450788598931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 391}], {
             RGBColor[
             0.9639362126003477, 0.9726242669231471, 0.9459307645121535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 400}], {
             RGBColor[
             0.9453754211275218, 0.9587816590332203, 0.9773493430459291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 109}], {
             RGBColor[
             0.983857264357485, 0.9727991330806696, 0.6529630493400771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 120}], {
             RGBColor[
             0.985050599801821, 0.987973026773897, 0.8923522302480941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 136}], {
             RGBColor[
             0.9881202731684248, 0.987039863701013, 0.6813775269127335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 237}], {
             RGBColor[
             0.919159082366426, 0.9371435613446358, 0.9494040043591572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 246}], {
             RGBColor[
             0.9771430669287163, 0.9824739172570054, 0.9235750050334973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 254}], {
             RGBColor[
             0.8259180333422894, 0.8640214879869536, 0.9401852980669185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 286}], {
             RGBColor[
             0.9882768406366288, 0.9873747456841022, 0.6984189296043337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 320}], {
             RGBColor[
             0.8163355755699582, 0.8565355991458319, 0.9392302082293318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 343}], {
             RGBColor[
             0.9885273483948486, 0.9879105564487147, 0.725685153131878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 349}], {
             RGBColor[
             0.9872517866250623, 0.984249653760939, 0.6661501273478732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 87}], {
             RGBColor[
             0.9870359287796385, 0.9887492154118203, 0.8574441386204277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 96}], {
             RGBColor[
             0.9922865167877448, 0.9897508057519624, 0.6810017659870794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 110}], {
             RGBColor[
             0.9751885215757324, 0.979913438517496, 0.8774987087179642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 146}], {
             RGBColor[
             0.9748527790386937, 0.9796630422831005, 0.8780670332574927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 154}], {
             RGBColor[
             0.8652379755325501, 0.8935061788390931, 0.8881609609919845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 159}], {
             RGBColor[
             0.9926336387981626, 0.990493264632827, 0.7187838546323189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 167}], {
             RGBColor[
             0.9885356648540982, 0.9895272170442646, 0.8396572323232916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 192}], {
             RGBColor[
             0.9749019256693667, 0.9796996957597862, 0.8779838408312575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 201}], {
             RGBColor[
             0.9702281344295782, 0.9762139899057827, 0.8858953502802354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 203}], {
             RGBColor[
             0.8905641986677422, 0.9132912168387302, 0.8906852422270891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 228}], {
             RGBColor[
             0.8466534415143673, 0.8789877996163988, 0.8863086283233967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 243}], {
             RGBColor[
             0.9747801853971652, 0.9796089020641097, 0.8781899153571465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 332}], {
             RGBColor[
             0.9653559950920387, 0.9725803563652418, 0.8941426113212364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 348}], {
             RGBColor[
             0.992228523355684, 0.9896267636648195, 0.6746895388012253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 361}], {
             RGBColor[
             0.9914229563631178, 0.9907211862832515, 0.791807339947933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 385}], {
             RGBColor[
             0.8532530463066779, 0.884143461039006, 0.886966415252281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 89}], {
             RGBColor[
             0.9774038290016427, 0.9810755083035332, 0.8518009634582414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 163}], {
             RGBColor[
             0.97795014333748, 0.9813014233210399, 0.8427471210972377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 169}], {
             RGBColor[
             0.9764770040093625, 0.9774412085745361, 0.6869944981249494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 209}], {
             RGBColor[
             0.9681667353821019, 0.9757793838869342, 0.9387695929396982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 227}], {
             RGBColor[
             0.9752931387639996, 0.9802026836480029, 0.8867805629872241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 240}], {
             RGBColor[
             0.9492454866063034, 0.961667947530645, 0.9707983316650852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 245}], {
             RGBColor[
             0.9232362217796216, 0.9409743578933969, 0.9698947855713672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 248}], {
             RGBColor[
             0.9754655739682883, 0.9740294175509256, 0.6830652834079125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 292}], {
             RGBColor[
             0.960520354268839, 0.9700767253724627, 0.9517129216688611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 304}], {
             RGBColor[
             0.8451394039214662, 0.8794354365374921, 0.9622512298199963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 315}], {
             RGBColor[
             0.9540631991828193, 0.9652609896819303, 0.9626432009337242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 329}], {
             RGBColor[
             0.9774747762976577, 0.9799313449528235, 0.7653239845336377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 353}], {
             RGBColor[
             0.9425500292848057, 0.9563746637386921, 0.9717369537728512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 378}], {
             RGBColor[
             0.9733860293766097, 0.9794140449058415, 0.9183863009771591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 151}], {
             RGBColor[
             0.9423892935638563, 0.9524864131639741, 0.7747429123141303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 157}], {
             RGBColor[
             0.9424347303343896, 0.9538354591448869, 0.8706855272531575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 171}], {
             RGBColor[
             0.9269380722913526, 0.943879445202563, 0.9686298692883922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 182}], {
             RGBColor[
             0.7404992302044333, 0.796974513763541, 0.9751660993177986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 253}], {
             RGBColor[
             0.9392759087242915, 0.9525292052310987, 0.9230353761007628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 108}], {
             RGBColor[
             0.6090265753026098, 0.6917095679619438, 0.9635704626175484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 120}], {
             RGBColor[
             0.7235434362389197, 0.7808069785022256, 0.9112905182296422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 125}], {
             RGBColor[
             0.7006401842291243, 0.7641240862064265, 0.9678971340035262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 179}], {
             RGBColor[
             0.6540672248413448, 0.7271191754114477, 0.9680003810304986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 196}], {
             RGBColor[
             0.724055382285427, 0.7810186813488695, 0.9028062473651178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 231}], {
             RGBColor[
             0.6928229663554923, 0.7580219516982503, 0.9716969382537769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 237}], {
             RGBColor[
             0.6576519188035247, 0.7299775130729644, 0.9683422923407055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 246}], {
             RGBColor[
             0.7156359033658151, 0.7753078689853339, 0.9425132930150455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 254}], {
             RGBColor[
             0.5644108697793881, 0.6568554397152822, 0.9591235860484668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 303}], {
             RGBColor[
             0.6843413772672207, 0.7512589627858651, 0.9708879567149336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 313}], {
             RGBColor[
             0.6797936048583822, 0.7476326925130508, 0.9704541861227343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 344}], {
             RGBColor[
             0.7097759265300352, 0.7709375078560408, 0.9524327052712851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 349}], {
             RGBColor[
             0.7257446230621611, 0.7770836054892676, 0.6850884153294214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.7787956964816487, 0.827798594722271, 0.978487922192984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 152}], {
             RGBColor[
             0.7481900762243061, 0.8033945038964967, 0.9755687308108789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 156}], {
             RGBColor[
             0.7965475623498134, 0.8412390832661416, 0.955413543489642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 175}], {
             RGBColor[
             0.8092474762862512, 0.8499449056801573, 0.8996239356611992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 204}], {
             RGBColor[
             0.8027819137758418, 0.8458886523518601, 0.9448604127046427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 256}], {
             RGBColor[
             0.758275572116585, 0.8114364045575069, 0.976530694412513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 261}], {
             RGBColor[
             0.7965475623498134, 0.8412390832661416, 0.955413543489642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 264}], {
             RGBColor[
             0.7953708774106887, 0.8403615135651872, 0.9574053641629967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 317}], {
             RGBColor[
             0.7855395156357012, 0.7577859589439442, 0.6178431777927517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 333}], {
             RGBColor[
             0.754567919678166, 0.6278546062700977, 0.5925533963361735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 381}], {
             RGBColor[
             0.8077910389202225, 0.8493426314005714, 0.9237608719553743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 389}], {
             RGBColor[
             0.6474511902445041, 0.7243190425580759, 0.9656281911609126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 96}], {
             RGBColor[
             0.972730313856397, 0.9762686036416346, 0.7634901482463088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 110}], {
             RGBColor[
             0.9556323186443845, 0.9664312364071683, 0.9599870909771936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 115}], {
             RGBColor[
             0.9472958382316281, 0.9602139029650685, 0.9740985778136755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 139}], {
             RGBColor[
             0.7506294532062003, 0.8043465366507949, 0.9621475400677086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 167}], {
             RGBColor[
             0.9689794619227502, 0.9760450149339368, 0.9221456145825209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 184}], {
             RGBColor[
             0.9696577063187255, 0.9763254864217585, 0.9109053497009796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 188}], {
             RGBColor[
             0.9406370537411219, 0.8609671604473307, 0.614395942383872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 203}], {
             RGBColor[
             0.8710079957363942, 0.8998090147284024, 0.9731736244863185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 258}], {
             RGBColor[
             0.9482266523645536, 0.9609081026213361, 0.9725229522818395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 284}], {
             RGBColor[
             0.9301581051408891, 0.8194216211500263, 0.6059643343675876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 325}], {
             RGBColor[
             0.9658107983592312, 0.9536928770815578, 0.6715230059207679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 348}], {
             RGBColor[
             0.972672320424336, 0.9761445615544917, 0.7571779210604546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 351}], {
             RGBColor[
             0.8404841877254632, 0.87596358392073, 0.9701312965649925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 369}], {
             RGBColor[
             0.9644486519392659, 0.97300644334307, 0.9450633383769498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 95}], {
             RGBColor[
             0.9711827487376974, 0.9761757792622021, 0.8503231292814951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 151}], {
             RGBColor[
             0.970419282569371, 0.9745428023264227, 0.7672245484262152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[
             0.9089332383525428, 0.9299287449827967, 0.9809841684980605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 229}], {
             RGBColor[
             0.939973062369224, 0.9546790581001205, 0.9839447746223495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 249}], {
             RGBColor[
             0.7258964516030268, 0.7844197015983971, 0.9642915277948932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 308}], {
             RGBColor[
             0.9194676007750087, 0.7809020281365397, 0.6029453521183125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 309}], {
             RGBColor[
             0.9234023861213787, 0.941466050659113, 0.9823642487290127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 334}], {
             RGBColor[
             0.968644488644167, 0.9751391361368529, 0.8933330965996491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 371}], {
             RGBColor[
             0.948939072271105, 0.9614394242211615, 0.9713170112089182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 386}], {
             RGBColor[
             0.9707387045689932, 0.9752260136850963, 0.8019916618410103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 110}], {
             RGBColor[
             0.9713946366824581, 0.9781867473915364, 0.9333055980096869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 134}], {
             RGBColor[
             0.9834782639807529, 0.9718748982148213, 0.6522426515580237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 159}], {
             RGBColor[
             0.9888397539048882, 0.9887665735068675, 0.7745907439240416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 167}], {
             RGBColor[
             0.9847417799608238, 0.987800525918305, 0.8954641216150142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 192}], {
             RGBColor[
             0.9711080407760924, 0.9779730046338266, 0.9337907301229802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 201}], {
             RGBColor[
             0.9664342495363039, 0.9744872987798232, 0.941702239571958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 210}], {
             RGBColor[
             0.9611046069655076, 0.9705124600770121, 0.9507239342509092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 228}], {
             RGBColor[
             0.8428595566210929, 0.8772611084904393, 0.9421155176151195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 236}], {
             RGBColor[
             0.9819261913430554, 0.9666393927638821, 0.6462131424448931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 243}], {
             RGBColor[
             0.9709863005038908, 0.9778822109381502, 0.9339968046488691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 263}], {
             RGBColor[
             0.971964656978374, 0.9330367982723142, 0.607514462516024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 348}], {
             RGBColor[
             0.9884346384624096, 0.9879000725388599, 0.7304964280929479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 351}], {
             RGBColor[
             0.8562465057635368, 0.8877190949050981, 0.9434498035974859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[
             0.9665408490824414, 0.9716437078226121, 0.7732688073273799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 132}], {
             RGBColor[
             0.966683602488854, 0.9719490429243454, 0.7888066346434897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 140}], {
             RGBColor[
             0.9649090151287051, 0.972307290291045, 0.8975991792791858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 168}], {
             RGBColor[
             0.7996410934412647, 0.8442755887217995, 0.9771431696278335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 282}], {
             RGBColor[
             0.881452896703323, 0.9082164516754985, 0.9852897469254718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 283}], {
             RGBColor[
             0.8413154206934939, 0.8768318899078591, 0.9812968770996053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 357}], {
             RGBColor[
             0.8147713846235094, 0.8560954871878412, 0.9786512156522695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 163}], {
             RGBColor[
             0.9943261321368995, 0.9919217240739244, 0.7436942041983078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 164}], {
             RGBColor[
             0.9920803350847683, 0.9909930292785165, 0.7809128732885862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 169}], {
             RGBColor[
             0.9928529928087821, 0.9880615093274205, 0.5879415812260196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 209}], {
             RGBColor[
             0.9845427241815214, 0.9863996846398186, 0.8397166760407682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 227}], {
             RGBColor[
             0.9916691275634192, 0.9908229844008873, 0.7877276460882943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 245}], {
             RGBColor[
             0.9396122105790412, 0.9515946586462813, 0.8708418686724373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.9377927645583376, 0.7739424868828161, 0.48791808684249083`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 292}], {
             RGBColor[
             0.9768963430682585, 0.9806970261253471, 0.8526600047699313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 304}], {
             RGBColor[
             0.8615153927208858, 0.8900557372903766, 0.8631983129210663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 315}], {
             RGBColor[
             0.9704391879822389, 0.9758812904348149, 0.8635902840347942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 329}], {
             RGBColor[
             0.9938507650970774, 0.990551645705708, 0.6662710676347077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 353}], {
             RGBColor[
             0.9589260180842253, 0.9669949644915765, 0.8726840368739213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 378}], {
             RGBColor[
             0.9897620181760294, 0.990034345658726, 0.8193333840782293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 138}], {
             RGBColor[
             0.9613719478971817, 0.9687406045732573, 0.8640295082350391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 142}], {
             RGBColor[
             0.8165827499446676, 0.8575121432428345, 0.9821215333155224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 152}], {
             RGBColor[
             0.897292002223665, 0.9209403025033327, 0.9900657062657615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 156}], {
             RGBColor[
             0.9456494883491723, 0.9587848818729776, 0.9699105189445246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 175}], {
             RGBColor[
             0.95834940228561, 0.9674907042869934, 0.9141209111160818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 202}], {
             RGBColor[
             0.9602862127224778, 0.9660424312485238, 0.7185302950143111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 242}], {
             RGBColor[
             0.9054438337433526, 0.7534556703584177, 0.6085306309176093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 256}], {
             RGBColor[
             0.9073774981159439, 0.9289822031643428, 0.9910276698673955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[
             0.9608163327261827, 0.9671763043330945, 0.7762305858961542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 261}], {
             RGBColor[
             0.9456494883491723, 0.9587848818729776, 0.9699105189445246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 264}], {
             RGBColor[
             0.9444728034100476, 0.9579073121720231, 0.9719023396178793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 268}], {
             RGBColor[
             0.9561995919752604, 0.9666017024760588, 0.9497488314893145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 317}], {
             RGBColor[
             0.9346414416350601, 0.8753317575507802, 0.6323401532476343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 333}], {
             RGBColor[
             0.903669845677525, 0.7454004048769336, 0.6070503717910561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 381}], {
             RGBColor[
             0.9568929649195814, 0.9668884300074074, 0.938257847410257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 141}], {
             RGBColor[
             0.9767928308007807, 0.9471473216583217, 0.6172070346976837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 150}], {
             RGBColor[
             0.9397399729851605, 0.9534162995691705, 0.9455322602391474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 186}], {
             RGBColor[
             0.989005933668029, 0.9897216852841823, 0.8318636610597796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 189}], {
             RGBColor[
             0.9898418804682589, 0.9897073092873421, 0.7918371905097765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 190}], {
             RGBColor[
             0.9845109922960866, 0.9731824926924875, 0.647190634654448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 226}], {
             RGBColor[
             0.949516501021098, 0.8427919713108498, 0.5755412242413787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 241}], {
             RGBColor[
             0.9886720330888448, 0.9872051240324887, 0.6645065227217064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 255}], {
             RGBColor[
             0.7384091284484415, 0.7932282072324167, 0.9272004495815114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 266}], {
             RGBColor[
             0.9899275195874135, 0.9901027847455256, 0.8165905973876704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 273}], {
             RGBColor[
             0.9893876954080058, 0.9898795535744919, 0.8255368810606512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 365}], {
             RGBColor[
             0.9636697738437929, 0.9723213677203522, 0.9417159520235137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 114}], {
             RGBColor[
             0.9766983265400502, 0.9821422306033336, 0.9243278345046385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 153}], {
             RGBColor[
             0.9817460740284827, 0.9813539067458229, 0.6780393221721769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 161}], {
             RGBColor[
             0.9816740827995223, 0.9845942814386353, 0.8595308526303556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 188}], {
             RGBColor[
             0.9505677970569193, 0.8683734925521525, 0.5975857843029007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 195}], {
             RGBColor[
             0.9621674029023097, 0.9713050915465105, 0.9489248979514775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 258}], {
             RGBColor[
             0.9581573956803509, 0.9683144347261579, 0.9557127942008683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 278}], {
             RGBColor[
             0.9460028103589095, 0.9588557350070417, 0.9626330072918536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 284}], {
             RGBColor[
             0.9400888484566865, 0.8268279532548481, 0.5891541762866164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 327}], {
             RGBColor[
             0.8970377416697712, 0.919812318355705, 0.9579626753286508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 337}], {
             RGBColor[
             0.9350232055492296, 0.9501008961652357, 0.9615857627834974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 354}], {
             RGBColor[
             0.8601902190204709, 0.8910064452898514, 0.954295447834529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 392}], {
             RGBColor[
             0.9830571966285448, 0.9845222379877476, 0.7897973252997612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 94}], {
             RGBColor[
             0.9777926527143148, 0.9829583772723054, 0.922475425737586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 119}], {
             RGBColor[
             0.9871593909159614, 0.9875812910863366, 0.782825079025989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 128}], {
             RGBColor[
             0.9868330482469811, 0.9880907783277695, 0.8350772845481265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 225}], {
             RGBColor[
             0.9868362194290916, 0.9880920896930678, 0.8350247298537992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 296}], {
             RGBColor[
             0.8603577719294212, 0.8909920742573914, 0.9469588757263698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 301}], {
             RGBColor[
             0.9870423373556572, 0.9873309253567764, 0.7700845213577134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 316}], {
             RGBColor[
             0.9860962497646105, 0.9852491434649808, 0.6720573103129864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 324}], {
             RGBColor[
             0.9064201145960594, 0.6197675913491264, 0.5491965628699884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 355}], {
             RGBColor[
             0.9022759514429883, 0.9237775428456518, 0.951126626771286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 380}], {
             RGBColor[
             0.9862738318586031, 0.9856871698064023, 0.6864374406695364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 383}], {
             RGBColor[
             0.9827946835050771, 0.9864208107257522, 0.9020034392744145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 390}], {
             RGBColor[
             0.9750025041445595, 0.947827334553206, 0.6289602034571609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 119}], {
             RGBColor[
             0.9851682485411228, 0.9860963003633785, 0.7861955636934874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 128}], {
             RGBColor[
             0.9848419058721425, 0.9866057876048113, 0.8384477692156249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 177}], {
             RGBColor[
             0.9582781705848028, 0.9684045084521473, 0.9555083537907714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 200}], {
             RGBColor[
             0.950061076031577, 0.9619827962585578, 0.9592448162175542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 225}], {
             RGBColor[
             0.984845077054253, 0.9866070989701097, 0.8383952145212976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 288}], {
             RGBColor[
             0.9711853189130935, 0.9780306385418708, 0.9336599183944034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 296}], {
             RGBColor[
             0.8583666295545826, 0.8895070835344332, 0.9503293603938683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 316}], {
             RGBColor[
             0.984105107389772, 0.9837641527420227, 0.6754277949804849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 324}], {
             RGBColor[
             0.9044289722212209, 0.6182826006261681, 0.5525670475374869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 355}], {
             RGBColor[
             0.9002848090681497, 0.9222925521226937, 0.9544971114387845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 375}], {
             RGBColor[
             0.9629339852237684, 0.971876807386691, 0.9476272740379384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 380}], {
             RGBColor[
             0.9842826894837644, 0.984202179083444, 0.6898079253370348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 383}], {
             RGBColor[
             0.9808035411302385, 0.984935820002794, 0.905373923941913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 390}], {
             RGBColor[
             0.9730113617697209, 0.9463423438302477, 0.6323306881246593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 129}], {
             RGBColor[
             0.9947680001253094, 0.991217606241396, 0.6719072856794648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 151}], {
             RGBColor[
             0.9945034731436528, 0.9906518097754129, 0.6431151561974333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 178}], {
             RGBColor[
             0.9330174289268245, 0.9460377524317868, 0.8568747762692785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 229}], {
             RGBColor[
             0.9640572529435056, 0.9707880655491108, 0.8598353823935676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 249}], {
             RGBColor[
             0.7499806421773085, 0.8005287090473873, 0.8401821355661113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 270}], {
             RGBColor[
             0.9951572938160292, 0.9920502660822158, 0.7142795014721379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 308}], {
             RGBColor[
             0.9435517913492903, 0.7970110355855299, 0.47883595988953054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 309}], {
             RGBColor[
             0.9474865766956604, 0.9575750581081033, 0.8582548565002308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 334}], {
             RGBColor[
             0.9927286792184487, 0.9912481435858431, 0.7692237043708672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 371}], {
             RGBColor[
             0.9730232628453868, 0.9775484316701517, 0.8472076189801363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 386}], {
             RGBColor[
             0.9948228951432749, 0.9913350211340866, 0.6778822696122284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 110}], {
             RGBColor[
             0.9766452246905644, 0.9791883377316786, 0.7568632253763385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 114}], {
             RGBColor[
             0.9877804892704327, 0.987492999823022, 0.7380141269847547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 115}], {
             RGBColor[
             0.968308744277808, 0.9729710042895787, 0.7709747122128204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 153}], {
             RGBColor[
             0.9928282367588652, 0.9867046759655113, 0.49172561465229303`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 154}], {
             RGBColor[
             0.866694678647382, 0.8927810780532757, 0.7675254776503588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 167}], {
             RGBColor[
             0.98999236796893, 0.988802116258447, 0.7190217489816659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 188}], {
             RGBColor[
             0.9616499597873018, 0.8737242617718408, 0.4112720767830169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 192}], {
             RGBColor[
             0.9763586287841987, 0.9789745949739688, 0.7573483574896318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 203}], {
             RGBColor[
             0.892020901782574, 0.9125661160529126, 0.7700497588854635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 228}], {
             RGBColor[
             0.8481101446291992, 0.8782626988305813, 0.7656731449817711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 243}], {
             RGBColor[
             0.9762368885119972, 0.9788838012782922, 0.7575544320155209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 258}], {
             RGBColor[
             0.9692395584107334, 0.9736652039458462, 0.7693990866809846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 284}], {
             RGBColor[
             0.951171011187069, 0.8321787224745365, 0.4028404687667325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 348}], {
             RGBColor[
             0.9936852264705158, 0.9889016628790019, 0.5540540554595996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 361}], {
             RGBColor[
             0.9928796594779498, 0.9899960854974339, 0.6711718566063073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 369}], {
             RGBColor[
             0.9854615579854457, 0.9857635446675801, 0.7419394727760946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 100}], {
             RGBColor[
             0.9780622270326262, 0.9822072730139388, 0.8793797794263432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 105}], {
             RGBColor[
             0.8942499756794173, 0.9163372556486853, 0.8986106663645186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 112}], {
             RGBColor[
             0.9302433414753382, 0.9448643620981978, 0.9020896616181853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 132}], {
             RGBColor[
             0.9919696195854375, 0.9898551607293484, 0.7033646760418701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 140}], {
             RGBColor[
             0.9901950322252886, 0.9902134080960481, 0.8121572206775663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 141}], {
             RGBColor[
             0.9793448395017402, 0.9482026428398005, 0.5749136461359741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 168}], {
             RGBColor[
             0.8249271105378482, 0.8621817065268026, 0.8917012110262141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 180}], {
             RGBColor[
             0.970490364443686, 0.9765601902928943, 0.8921969677313717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 220}], {
             RGBColor[
             0.9795362311433174, 0.9833065828662322, 0.8768846749487855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 282}], {
             RGBColor[
             0.9067389137999067, 0.9261225694805015, 0.8998477883238523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 350}], {
             RGBColor[
             0.7548028730607017, 0.805520873189786, 0.8859967331746887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 357}], {
             RGBColor[
             0.840057401720093, 0.8740016049928443, 0.8932092570506501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 394}], {
             RGBColor[
             0.9925360254947484, 0.9910666456969426, 0.7650144638182832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 107}], {
             RGBColor[
             0.9779720606577651, 0.9817632010961868, 0.8626573701598248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 131}], {
             RGBColor[
             0.9914424791818321, 0.9907292594705034, 0.7914837963184005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 215}], {
             RGBColor[
             0.8597693366846955, 0.8889837352777263, 0.8762661730990607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 283}], {
             RGBColor[
             0.8677355244124301, 0.8952069816759018, 0.8770601682435044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 297}], {
             RGBColor[
             0.9884936466349914, 0.975707151031968, 0.5872545716133635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 307}], {
             RGBColor[
             0.9054627830495182, 0.9246798028609806, 0.8808204688031724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 352}], {
             RGBColor[
             0.9698624846960606, 0.9757150926221595, 0.8763847669468348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 123}], {
             RGBColor[
             0.9126594431592272, 0.9302367435659022, 0.8740676883700162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 174}], {
             RGBColor[
             0.8068853383455952, 0.849163243049892, 0.9813601717296283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 187}], {
             RGBColor[
             0.8197618796928976, 0.8592224950157434, 0.9826435850330071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 193}], {
             RGBColor[
             0.8777743157969963, 0.801368998363662, 0.6205076712720164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[
             0.9136951189415587, 0.9306650221175499, 0.8569038604137743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 232}], {
             RGBColor[
             0.9087923089280819, 0.9156547960118246, 0.690724232721708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 235}], {
             RGBColor[
             0.9040523315456185, 0.9252949046481304, 0.9547951762048963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 275}], {
             RGBColor[
             0.9070309346322696, 0.9097132669216978, 0.6838816261901028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 279}], {
             RGBColor[
             0.8519184093949772, 0.884760631215104, 0.9857379324762767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 281}], {
             RGBColor[
             0.9134817718746169, 0.9300996782150187, 0.8257580292348867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 306}], {
             RGBColor[
             0.8652489446078134, 0.8953900381460806, 0.9870094108251863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 338}], {
             RGBColor[
             0.913220692486924, 0.9304688345863545, 0.864766334543382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 384}], {
             RGBColor[
             0.8881767441611926, 0.9134549175707141, 0.9816684046304006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 105}], {
             RGBColor[
             0.8823890520803777, 0.9084435505925773, 0.9613274434999599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 112}], {
             RGBColor[
             0.9183824178762983, 0.9369706570420897, 0.9648064387536266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 141}], {
             RGBColor[
             0.9674839159027004, 0.9403089377836924, 0.6376304232714154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 168}], {
             RGBColor[
             0.8130661869388084, 0.8542880014706946, 0.9544179881616555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 170}], {
             RGBColor[
             0.9652194366469348, 0.9735812933160053, 0.9437586009197143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 180}], {
             RGBColor[
             0.9586294408446462, 0.9686664852367863, 0.954913744866813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 220}], {
             RGBColor[
             0.9676753075442777, 0.9754128778101241, 0.9396014520842269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 271}], {
             RGBColor[
             0.9631229908941827, 0.9720177675062178, 0.9473073367385005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 273}], {
             RGBColor[
             0.9800787805099256, 0.9830411696998627, 0.8459602696343829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 282}], {
             RGBColor[
             0.8948779902008668, 0.9182288644243936, 0.9625645654592936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 350}], {
             RGBColor[
             0.7429419494616618, 0.797627168133678, 0.9487135103101301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 394}], {
             RGBColor[
             0.9806751018957087, 0.9831729406408345, 0.8277312409537245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 151}], {
             RGBColor[
             0.9632937867751794, 0.9691550886133312, 0.7767368015382876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 171}], {
             RGBColor[
             0.9478425655026756, 0.9605481206519202, 0.9706237585125497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 182}], {
             RGBColor[
             0.7614037234157564, 0.8136431892128981, 0.977159988541956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 244}], {
             RGBColor[
             0.963648535914221, 0.9699138611511013, 0.8153490560650529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 253}], {
             RGBColor[
             0.9601804019356145, 0.9691978806804559, 0.9250292653249201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 270}], {
             RGBColor[
             0.9639476074475558, 0.9705535449201341, 0.8479011468129922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 308}], {
             RGBColor[
             0.9123421049808169, 0.7755143144234482, 0.612457605230385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 397}], {
             RGBColor[
             0.8498898724314203, 0.8835719290283433, 0.9854306589718059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 160}], {
             RGBColor[
             0.5860421408862369, 0.6484161872050751, 0.8482830398123113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 166}], {
             RGBColor[
             0.5250209728583164, 0.6027307141009475, 0.9605349576237933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[
             0.5849406578069885, 0.6479606956449819, 0.8665374649822881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 213}], {
             RGBColor[
             0.46841649672976565`, 0.5580975947401308, 0.9550028222300001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 224}], {
             RGBColor[
             0.5700226307366021, 0.6379583217932474, 0.9421009103655226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 230}], {
             RGBColor[
             0.5385951415968919, 0.6135543877920928, 0.961829673955882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 247}], {
             RGBColor[
             0.5616825208854845, 0.6317382815219605, 0.9562185408944408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 250}], {
             RGBColor[
             0.5785868333622182, 0.6218385201576435, 0.651746918653537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 289}], {
             RGBColor[
             0.49310807668197604`, 0.5773868446617556, 0.9574638481637028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 302}], {
             RGBColor[
             0.5026589595212381, 0.5848998516666428, 0.9584020488288978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 340}], {
             RGBColor[
             0.5819003620354026, 0.6467034552113937, 0.9169230339507075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 370}], {
             RGBColor[
             0.4425120326040399, 0.5378608304838945, 0.9524209073369285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 391}], {
             RGBColor[
             0.5807120020365868, 0.6459304374065369, 0.924006592989189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 400}], {
             RGBColor[
             0.5621512105637609, 0.6320878295166101, 0.9554251715229646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 108}], {
             RGBColor[
             0.8751085795929139, 0.8986196647300831, 0.7095410596945706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 133}], {
             RGBColor[
             0.9924127078218778, 0.9888696819253794, 0.6110688830508597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 143}], {
             RGBColor[
             0.9927750941345276, 0.9890195379785636, 0.6050632040245387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 223}], {
             RGBColor[
             0.7710296423108369, 0.8158883628018949, 0.7001410713075942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 231}], {
             RGBColor[
             0.9589049706457966, 0.9649320484663897, 0.7176675353307991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 234}], {
             RGBColor[
             0.7195992304642472, 0.7739507202757809, 0.6961431530429958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 290}], {
             RGBColor[
             0.9829830115308642, 0.9831614781518405, 0.6863423992240596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 313}], {
             RGBColor[
             0.9458756091486864, 0.9545427892811902, 0.7164247831997563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 331}], {
             RGBColor[
             0.9936836888867343, 0.9888983741427666, 0.5538866989538409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 342}], {
             RGBColor[
             0.9857796404421186, 0.9635957955087615, 0.4075676101374066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 346}], {
             RGBColor[
             0.9855975313853673, 0.9851113827784457, 0.681916699086375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 109}], {
             RGBColor[
             0.9010052615407362, 0.9079857427420486, 0.687803286915237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 138}], {
             RGBColor[
             0.9063269725162011, 0.9248668258118095, 0.8587746013790551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 144}], {
             RGBColor[
             0.8510110570979936, 0.7123617430727807, 0.6037865576929924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 205}], {
             RGBColor[
             0.905400324467422, 0.9225089237632536, 0.7305910400433087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 207}], {
             RGBColor[
             0.8971934513489215, 0.9198251225674816, 0.9535022580803212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 233}], {
             RGBColor[
             0.9063326963399733, 0.9245031729213842, 0.8320739644383064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 358}], {
             RGBColor[
             0.8823602109457926, 0.8424153055286522, 0.6293090202440285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 366}], {
             RGBColor[
             0.8198669160576119, 0.5135682447408949, 0.5755524529671608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 382}], {
             RGBColor[
             0.9054303016410852, 0.9244960293615587, 0.8736347582895639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 112}], {
             RGBColor[
             0.8345701665230895, 0.8711006396768362, 0.984037325691802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 113}], {
             RGBColor[
             0.8961536912267762, 0.9157861032062535, 0.7697745127993771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 148}], {
             RGBColor[
             0.8599979593739686, 0.8913760714770774, 0.9864626512735775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 155}], {
             RGBColor[
             0.8440834282508313, 0.7170547940222387, 0.6050709526960195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 168}], {
             RGBColor[
             0.7292539355855996, 0.7884179841054411, 0.9736488750998309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 170}], {
             RGBColor[
             0.881407185293726, 0.9077112759507517, 0.9629894878578897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 180}], {
             RGBColor[
             0.8748171894914374, 0.9027964678715328, 0.9741446318049884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 239}], {
             RGBColor[
             0.8003744297944617, 0.84397785471718, 0.9807375013037644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 271}], {
             RGBColor[
             0.8793107395409739, 0.9061477501409643, 0.966538223676676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 282}], {
             RGBColor[
             0.811065738847658, 0.85235884705914, 0.981795452397469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 326}], {
             RGBColor[
             0.8943076885092688, 0.916361121386981, 0.8976542154178646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 350}], {
             RGBColor[
             0.659129698108453, 0.7317571507684244, 0.9679443972483055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 394}], {
             RGBColor[
             0.8968628505424998, 0.9173029232755809, 0.8469621278919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.9793791722566176, 0.9821065856706876, 0.8220020218103139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 173}], {
             RGBColor[
             0.9900941535941172, 0.9899331999568529, 0.7964931729931677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 197}], {
             RGBColor[
             0.9663783307268003, 0.972410579344674, 0.8440090553577659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 204}], {
             RGBColor[
             0.9854378020717351, 0.9866251018667065, 0.8117463418770505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 214}], {
             RGBColor[
             0.993119240131899, 0.9911841509814037, 0.7463596603891176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 215}], {
             RGBColor[
             0.861176448283548, 0.8893271198522272, 0.8356108247495497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 295}], {
             RGBColor[
             0.9941811457682976, 0.9916232762517845, 0.7287611358702998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 310}], {
             RGBColor[
             0.9904055594975387, 0.9900619743006844, 0.7913323712808292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 345}], {
             RGBColor[
             0.9937632956889924, 0.9890686450433143, 0.5625514081033893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 363}], {
             RGBColor[
             0.8647012345898583, 0.8920807097040849, 0.8359621425075621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 131}], {
             RGBColor[
             0.9772232159632259, 0.981453534570564, 0.8750676646962864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 197}], {
             RGBColor[
             0.9507519559093414, 0.9627914698702338, 0.9682482720851626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 215}], {
             RGBColor[
             0.8455500734660892, 0.879708010377787, 0.9598500414769466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 297}], {
             RGBColor[
             0.9742743834163852, 0.9664314261320286, 0.6708384399912493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 307}], {
             RGBColor[
             0.8912435198309119, 0.9154040779610412, 0.9644043371810582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 352}], {
             RGBColor[
             0.9556432214774544, 0.96643936772222, 0.9599686353247205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 363}], {
             RGBColor[
             0.8490748597723994, 0.8824616002296446, 0.9602013592349588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 143}], {
             RGBColor[
             0.875222314920092, 0.9009274892322574, 0.8719918848163895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 179}], {
             RGBColor[
             0.8025964499172134, 0.8459372234332809, 0.9808996588993715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 196}], {
             RGBColor[
             0.8725846073612955, 0.8998367293707028, 0.9157055252339907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 231}], {
             RGBColor[
             0.841352191431361, 0.8768399997200836, 0.9845962161226498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 234}], {
             RGBColor[
             0.6020464512498116, 0.685858671529475, 0.9630718338348466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 290}], {
             RGBColor[
             0.8654302323164287, 0.8950694294055346, 0.9532710800159103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 313}], {
             RGBColor[
             0.8283228299342509, 0.8664507405348841, 0.9833534639916071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 331}], {
             RGBColor[
             0.8761309096722987, 0.9008063253964607, 0.8208153797456916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 342}], {
             RGBColor[
             0.8682268612276831, 0.8755037467624555, 0.6744962909292573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 344}], {
             RGBColor[
             0.8583051516059037, 0.889755555877874, 0.965331983140158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 136}], {
             RGBColor[
             0.988465860173366, 0.9726153802982292, 0.4215459674672315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 205}], {
             RGBColor[
             0.988597914289112, 0.9728978306990907, 0.435919243022647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 207}], {
             RGBColor[
             0.9803910411706116, 0.9702140295033188, 0.6588304610596594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 233}], {
             RGBColor[
             0.9895302861616633, 0.9748920798572214, 0.5374021674176446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 286}], {
             RGBColor[
             0.98862242764157, 0.9729502622813184, 0.43858737015883176`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 320}], {
             RGBColor[
             0.8166811625748994, 0.8421111157430481, 0.6793986487838299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 343}], {
             RGBColor[
             0.9888729353997898, 0.9734860730459309, 0.465853593686376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 358}], {
             RGBColor[
             0.9655578007674828, 0.8928042124644894, 0.33463722322336675`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 366}], {
             RGBColor[
             0.9030645058793019, 0.5639571516767321, 0.28088065594649914`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 382}], {
             RGBColor[
             0.9886278914627753, 0.9748849362973959, 0.5789629612689022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 115}], {
             RGBColor[
             0.9512107490657956, 0.9631336370551125, 0.9674716549437052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 134}], {
             RGBColor[
             0.9716308567768468, 0.963039121320497, 0.6722972216555603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 167}], {
             RGBColor[
             0.9728943727569177, 0.9789647490239808, 0.9155186917125506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 192}], {
             RGBColor[
             0.9592606335721863, 0.9691372277395024, 0.9538453002205167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 203}], {
             RGBColor[
             0.8749229065705617, 0.9027287488184463, 0.9665467016163483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 243}], {
             RGBColor[
             0.9591388932999847, 0.9690464340438258, 0.9540513747464057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 348}], {
             RGBColor[
             0.9765872312585036, 0.9790642956445357, 0.7505509981904843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 351}], {
             RGBColor[
             0.8443990985596307, 0.8788833180107739, 0.9635043736950223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 369}], {
             RGBColor[
             0.9683635627734333, 0.9759261774331138, 0.9384364155069795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 160}], {
             RGBColor[
             0.9905573240302192, 0.9903632250678616, 0.8061531078887298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 166}], {
             RGBColor[
             0.9295361560022988, 0.9446777519637342, 0.9184050257002119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.9894558409509708, 0.9899077335077685, 0.8244075330587067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 197}], {
             RGBColor[
             0.9628542403337443, 0.9711917696348966, 0.9197482208927259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[
             0.9666663937077433, 0.9740348673793968, 0.9132952395993832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 155}], {
             RGBColor[
             0.880076794046752, 0.7455819004717511, 0.6085499479496862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 170}], {
             RGBColor[
             0.9174005510896466, 0.9362383824002642, 0.9664684831115564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 180}], {
             RGBColor[
             0.910810555287358, 0.9313235743210452, 0.9776236270586551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 183}], {
             RGBColor[
             0.9326228895924975, 0.9458483663962405, 0.8626543912437292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 271}], {
             RGBColor[
             0.9153041053368947, 0.9346748565904767, 0.9700172189303427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 273}], {
             RGBColor[
             0.9322598949526374, 0.9456982587841216, 0.868670151826225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 326}], {
             RGBColor[
             0.9303010543051895, 0.9448882278364934, 0.9011332106715313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 350}], {
             RGBColor[
             0.6951230639043737, 0.7602842572179369, 0.9714233925019722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 394}], {
             RGBColor[
             0.9328562163384205, 0.9458300297250934, 0.8504411231455666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 148}], {
             RGBColor[
             0.9575748498735761, 0.9645886414560072, 0.7756788336348193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 168}], {
             RGBColor[
             0.8268308260852071, 0.8616305540843708, 0.7628650574610727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 170}], {
             RGBColor[
             0.9789840757933335, 0.9809238459296816, 0.7522056702191315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 251}], {
             RGBColor[
             0.9905994731684502, 0.9890422670751811, 0.7081679273022708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 282}], {
             RGBColor[
             0.9086426293472655, 0.9255714170380698, 0.7710116347587108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 153}], {
             RGBColor[
             0.9868655061267213, 0.9851719708223885, 0.6693734589915941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 154}], {
             RGBColor[
             0.860731948015238, 0.8912483729101528, 0.9451733219896599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 188}], {
             RGBColor[
             0.9556872291551577, 0.8721915566287181, 0.588919921122318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 203}], {
             RGBColor[
             0.8860581711504301, 0.9110334109097897, 0.9476976032247644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 222}], {
             RGBColor[
             0.7625750321751272, 0.813050481577567, 0.936427113601484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 258}], {
             RGBColor[
             0.9632768277785895, 0.9721324988027235, 0.9470469310202855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 312}], {
             RGBColor[
             0.9754218248532416, 0.9811902177353915, 0.9264886188954449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 327}], {
             RGBColor[
             0.9021571737680099, 0.9236303824322705, 0.9492968121480679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 356}], {
             RGBColor[
             0.9616072181234053, 0.9708873066556221, 0.9498731446625729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 361}], {
             RGBColor[
             0.9869169288458057, 0.988463380354311, 0.8488197009456082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 369}], {
             RGBColor[
             0.9794988273533016, 0.9842308395244573, 0.9195873171153957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 392}], {
             RGBColor[
             0.9881766287267834, 0.9883403020643131, 0.7811314621191783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 184}], {
             RGBColor[
             0.9652361367401365, 0.9730278870697027, 0.9183899136674912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 188}], {
             RGBColor[
             0.936215484162533, 0.8576695610952747, 0.6218805063503836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 195}], {
             RGBColor[
             0.9478150900079234, 0.9606011600896327, 0.9732196199989605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 203}], {
             RGBColor[
             0.8665864261578053, 0.8965114153763465, 0.9806581884528301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 206}], {
             RGBColor[
             0.9637104567520174, 0.9723969791864282, 0.9436743794038676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 208}], {
             RGBColor[
             0.957237976478982, 0.9363921289556087, 0.6628807385935468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 258}], {
             RGBColor[
             0.9438050827859648, 0.9576105032692801, 0.9800075162483513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 284}], {
             RGBColor[
             0.9257365355623003, 0.8161240217979704, 0.6134488983340992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 325}], {
             RGBColor[
             0.9613892287806424, 0.9503952777295019, 0.6790075698872795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 369}], {
             RGBColor[
             0.9600270823606769, 0.969708843991014, 0.9525479023434613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 392}], {
             RGBColor[
             0.9687048837341586, 0.9738183065308699, 0.814092047347244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 121}], {
             RGBColor[
             0.6960091230654988, 0.7544829683752527, 0.7771012841537125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 130}], {
             RGBColor[
             0.6900615367829592, 0.7526590821118989, 0.9307233359299045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 135}], {
             RGBColor[
             0.6847098361960986, 0.7486677925768238, 0.9397823690764007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 147}], {
             RGBColor[
             0.5949033495657143, 0.6782102412541122, 0.9632352301073697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 172}], {
             RGBColor[
             0.6904909041233898, 0.7369021482607978, 0.6677887780143512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 265}], {
             RGBColor[
             0.6956821656830225, 0.7537836395945984, 0.7415139908182473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 276}], {
             RGBColor[
             0.6494035942174397, 0.5811024215834972, 0.5928236623257395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 322}], {
             RGBColor[
             0.6611625948998685, 0.6286621531136133, 0.6023338147720689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 328}], {
             RGBColor[
             0.686705379615538, 0.7501560655916392, 0.9364044345883695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 362}], {
             RGBColor[
             0.694540967265862, 0.754828713014162, 0.8706956366411761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 364}], {
             RGBColor[
             0.6811454382026549, 0.7460094703894795, 0.9458159651354159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 387}], {
             RGBColor[
             0.687846213081402, 0.7510068973225372, 0.9344733011076831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 223}], {
             RGBColor[
             0.771332590501909, 0.8165363383498376, 0.7331151123262771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 346}], {
             RGBColor[
             0.9859004795764394, 0.9857593583263883, 0.7148907401050579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 371}], {
             RGBColor[
             0.972023420784144, 0.9754098706006927, 0.7383809809238226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 126}], {
             RGBColor[
             0.9372635233765337, 0.9501536819898073, 0.8893682156908086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 149}], {
             RGBColor[
             0.9644688319967041, 0.8901574533294458, 0.5292645838045635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[
             0.9087661483405411, 0.9274306486767454, 0.8866501106199686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 212}], {
             RGBColor[
             0.9815172569589331, 0.9531528883276367, 0.5669176143506138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 259}], {
             RGBColor[
             0.9931178527395907, 0.9909249514559264, 0.7275832873772701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 293}], {
             RGBColor[
             0.9847393584488184, 0.964021793238427, 0.579434870196008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 299}], {
             RGBColor[
             0.8645998183354698, 0.8928789319409045, 0.8822609322405639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 336}], {
             RGBColor[
             0.9553705216597668, 0.9645917109194825, 0.8910952773513716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 367}], {
             RGBColor[
             0.9700504397161045, 0.9122866679763559, 0.5337556763927651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 200}], {
             RGBColor[
             0.9594278142332235, 0.966605710072589, 0.8195944695059573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 225}], {
             RGBColor[
             0.9942118152558996, 0.9912300127841409, 0.6987448678097007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 288}], {
             RGBColor[
             0.9805520571147401, 0.982653552355902, 0.7940095716828064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 296}], {
             RGBColor[
             0.8677333677562292, 0.8941299973484644, 0.8106790136822712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 316}], {
             RGBColor[
             0.9934718455914185, 0.9883870665560539, 0.5357774482688878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 324}], {
             RGBColor[
             0.9137957104228674, 0.6229055144401994, 0.41291670082588994`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 355}], {
             RGBColor[
             0.9096515472697964, 0.9269154659367249, 0.8148467647271875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 375}], {
             RGBColor[
             0.972300723425415, 0.9764997212007223, 0.8079769273263415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 380}], {
             RGBColor[
             0.9936494276854111, 0.9888250928974752, 0.5501575786254378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 383}], {
             RGBColor[
             0.9901702793318852, 0.9895587338168252, 0.7657235772303159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 390}], {
             RGBColor[
             0.9823780999713675, 0.950965257644279, 0.4926803414130623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 136}], {
             RGBColor[
             0.989659195617702, 0.9877892739914567, 0.6609351483752485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 237}], {
             RGBColor[
             0.9206980048157032, 0.9378929716350795, 0.9289616258216722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 246}], {
             RGBColor[
             0.9786819893779936, 0.9832233275474489, 0.9031326264960123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 254}], {
             RGBColor[
             0.8274569557915666, 0.8647708982773972, 0.9197429195294335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 286}], {
             RGBColor[
             0.989815763085906, 0.9881241559745458, 0.6779765510668487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 320}], {
             RGBColor[
             0.8178744980192354, 0.8572850094362756, 0.9187878296918468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 343}], {
             RGBColor[
             0.9900662708441258, 0.9886599667391585, 0.705242774594393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 349}], {
             RGBColor[
             0.9887907090743395, 0.9849990640513826, 0.6457077488103882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 130}], {
             RGBColor[
             0.9882298818980723, 0.9881306318602723, 0.7612535796160371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 158}], {
             RGBColor[
             0.9924746652696066, 0.9902032301518287, 0.7051145902099424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 181}], {
             RGBColor[
             0.8933417779327104, 0.9138927820915652, 0.7937923931679784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 250}], {
             RGBColor[
             0.9862120674525241, 0.9641187792194565, 0.4888121825734595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 265}], {
             RGBColor[
             0.9938505107981357, 0.9892551893429717, 0.5720442345043799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 322}], {
             RGBColor[
             0.9593309400149816, 0.8641337028619867, 0.43286405845820153`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 362}], {
             RGBColor[
             0.9927093123809752, 0.9903002627625352, 0.7012258803273087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 146}], {
             RGBColor[
             0.9636058933004894, 0.9368511773428467, 0.64299437483337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.9813867530599583, 0.9476813996925733, 0.483711196208196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 165}], {
             RGBColor[
             0.8858327518068854, 0.8755692622686297, 0.6562619818600222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 210}], {
             RGBColor[
             0.9536516061205778, 0.929427286262718, 0.6598443865350636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 228}], {
             RGBColor[
             0.835406555776163, 0.836175934676145, 0.6512359698992739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 262}], {
             RGBColor[
             0.9816974193721019, 0.9483458835210661, 0.5175253070747867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 298}], {
             RGBColor[
             0.9755576002900463, 0.9292121878092645, 0.35954632199705416`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 314}], {
             RGBColor[
             0.97377153240972, 0.9444326943458046, 0.6257865994447509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 385}], {
             RGBColor[
             0.8420061605684735, 0.8413315960987522, 0.6518937568281582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 174}], {
             RGBColor[
             0.8873101754829793, 0.9103346859078185, 0.871567386361036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 187}], {
             RGBColor[
             0.9001867168302817, 0.92039393787367, 0.8728507996644147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 193}], {
             RGBColor[
             0.9581991529343805, 0.8625404412215885, 0.5107148859034242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 218}], {
             RGBColor[
             0.994119956078943, 0.9918364649754763, 0.7471110750451819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 232}], {
             RGBColor[
             0.9892171460654662, 0.9768262388697511, 0.5809314473531156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 235}], {
             RGBColor[
             0.9844771686830027, 0.9864663475060569, 0.845002390836304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 275}], {
             RGBColor[
             0.9874557717696538, 0.9708847097796243, 0.5740888408215106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 279}], {
             RGBColor[
             0.9323432465323613, 0.9459320740730304, 0.8759451471076845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 281}], {
             RGBColor[
             0.993906609012001, 0.9912711210729452, 0.7159652438662945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 306}], {
             RGBColor[
             0.9456737817451977, 0.9565614810040072, 0.8772166254565941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 338}], {
             RGBColor[
             0.9936455296243081, 0.9916402774442811, 0.7549735491747898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.8602749694282454, 0.8405445030838187, 0.6317241998657477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 199}], {
             RGBColor[
             0.7949177929045458, 0.83976373256614, 0.9801807260960678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 238}], {
             RGBColor[
             0.878837534377163, 0.9023341103238334, 0.7740974040773709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 252}], {
             RGBColor[
             0.8791907535494057, 0.9030896104173238, 0.8125431311599339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 277}], {
             RGBColor[
             0.8782722765731267, 0.9011250810373301, 0.7125725804748091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 293}], {
             RGBColor[
             0.8708910030128231, 0.8763548771278217, 0.6729654856721072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 330}], {
             RGBColor[
             0.8692686804226241, 0.8980432773705209, 0.9523994596048864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 179}], {
             RGBColor[
             0.8942100588437281, 0.9183517416777636, 0.9852263302853492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 196}], {
             RGBColor[
             0.9641982162878102, 0.9722512476151856, 0.9200321966199685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 303}], {
             RGBColor[
             0.9244842112696039, 0.9424915290521811, 0.9881139059697842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 313}], {
             RGBColor[
             0.9199364388607654, 0.9388652587793669, 0.9876801353775848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 344}], {
             RGBColor[
             0.9499187605324184, 0.9621700741223567, 0.9696586545261358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 149}], {
             RGBColor[
             0.9102024058212057, 0.8495457046027862, 0.6285986135772457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 199}], {
             RGBColor[
             0.8544997221650428, 0.8868188999500857, 0.9859841403926507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 212}], {
             RGBColor[
             0.9272508307834347, 0.912541139600977, 0.666251644123296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 238}], {
             RGBColor[
             0.9384194636376599, 0.949389277707779, 0.779900818373954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 259}], {
             RGBColor[
             0.9388514265640924, 0.9503132027292667, 0.8269173171499522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 274}], {
             RGBColor[
             0.938176920831777, 0.9505313953107943, 0.8742308560605866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 299}], {
             RGBColor[
             0.8103333921599715, 0.8522671832142448, 0.981594962013246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 318}], {
             RGBColor[
             0.8693874020121308, 0.8986899317448497, 0.9874041405868547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 336}], {
             RGBColor[
             0.9011040954842684, 0.9239799621928229, 0.9904293071240537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 367}], {
             RGBColor[
             0.9157840135406061, 0.8716749192496962, 0.6330897061654472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 139}], {
             RGBColor[
             0.7678221243555325, 0.8168513576292629, 0.9188289960606577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 184}], {
             RGBColor[
             0.9868503774680577, 0.9888303074002266, 0.8675868056939287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 305}], {
             RGBColor[
             0.907347991866693, 0.9273414567374095, 0.9317450411108604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 325}], {
             RGBColor[
             0.9830034695085634, 0.9661976980600258, 0.6282044619137169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 177}], {
             RGBColor[
             0.9673185661174692, 0.9735369095076114, 0.8681102126013118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 225}], {
             RGBColor[
             0.9938854725869194, 0.9917395000255738, 0.7509970733318381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 296}], {
             RGBColor[
             0.867407025087249, 0.8946394845898973, 0.8629312192044087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 311}], {
             RGBColor[
             0.9795804882854049, 0.943138574209871, 0.5353321334642179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 316}], {
             RGBColor[
             0.9931455029224383, 0.9888965537974866, 0.5880296537910253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 324}], {
             RGBColor[
             0.9134693677538872, 0.6234150016816322, 0.4651689063480273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 380}], {
             RGBColor[
             0.9933230850164309, 0.989334580138908, 0.6024097841475753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 383}], {
             RGBColor[
             0.9898439366629048, 0.9900682210582581, 0.8179757827524534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 390}], {
             RGBColor[
             0.9820517573023873, 0.9514747448857117, 0.5449325469351998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 178}], {
             RGBColor[
             0.9325184897401548, 0.9449705719619905, 0.80256832489603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 229}], {
             RGBColor[
             0.963558313756836, 0.9697208850793144, 0.8055289310203191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 249}], {
             RGBColor[
             0.749481702990639, 0.799461528577591, 0.7858756841928629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 270}], {
             RGBColor[
             0.9946583546293597, 0.9909830856124195, 0.6599730500988894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 308}], {
             RGBColor[
             0.9430528521626207, 0.7959438551157336, 0.4245295085162821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 309}], {
             RGBColor[
             0.9469876375089908, 0.9565078776383069, 0.8039484051269823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 397}], {
             RGBColor[
             0.8806006196132242, 0.9040014697206286, 0.7975025622577031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 135}], {
             RGBColor[
             0.9769305950286722, 0.9823154560618432, 0.9239346645387253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 147}], {
             RGBColor[
             0.8871241083982879, 0.9118579047391316, 0.9473875255696944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 158}], {
             RGBColor[
             0.986527078987067, 0.9883793438884747, 0.8587366419861344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 172}], {
             RGBColor[
             0.9827116629559633, 0.9705498117458173, 0.651941073476676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 181}], {
             RGBColor[
             0.8873941916501709, 0.9120688958282114, 0.9474144449441706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 265}], {
             RGBColor[
             0.9879029245155961, 0.9874313030796178, 0.725666286280572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 322}], {
             RGBColor[
             0.9533833537324421, 0.8623098165986327, 0.5864861102343936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 328}], {
             RGBColor[
             0.9789261384481115, 0.9838037290766586, 0.9205567300506942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 347}], {
             RGBColor[
             0.9871042317160174, 0.985366977597671, 0.6690053736424784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 362}], {
             RGBColor[
             0.9867617260984356, 0.9884763764991813, 0.8548479321035007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 364}], {
             RGBColor[
             0.9733661970352284, 0.9796571338744988, 0.9299682605977406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 387}], {
             RGBColor[
             0.9800669719139756, 0.9846545608075566, 0.9186255965700079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 215}], {
             RGBColor[
             0.8590204919901563, 0.8886740687521035, 0.8886764676355223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 217}], {
             RGBColor[
             0.9927796435008058, 0.9909230338860981, 0.7432151182186497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 262}], {
             RGBColor[
             0.9928762155174962, 0.9911295916648701, 0.7537263862619881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 269}], {
             RGBColor[
             0.7345816587413934, 0.7889509311355145, 0.8779900617369589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 279}], {
             RGBColor[
             0.931147923627702, 0.9454377773335563, 0.8957547410344036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 297}], {
             RGBColor[
             0.9877448019404522, 0.9753974845063452, 0.599664866149825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 300}], {
             RGBColor[
             0.9916774966473212, 0.9885656532106348, 0.6232532348787909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 306}], {
             RGBColor[
             0.9444784588405384, 0.9560671842645332, 0.8970262193833132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 307}], {
             RGBColor[
             0.904713938354979, 0.9243701363353578, 0.8932307633396339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 314}], {
             RGBColor[
             0.9849503285551143, 0.9872164024896086, 0.8619876786319522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 352}], {
             RGBColor[
             0.9691136400015214, 0.9754054260965367, 0.8887950614832962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 363}], {
             RGBColor[
             0.8625452782964664, 0.8914276586039612, 0.8890277853935344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 140}], {
             RGBColor[
             0.9922415011790601, 0.9899675907553496, 0.6988588944285347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 191}], {
             RGBColor[
             0.9945146682679971, 0.9906757550143845, 0.644333676394011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 198}], {
             RGBColor[
             0.9708884544033632, 0.9750850145973732, 0.7816889171532455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 216}], {
             RGBColor[
             0.9916332316291601, 0.9897160556646516, 0.7089394950215115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 219}], {
             RGBColor[
             0.9942714443603079, 0.9908070244279558, 0.6652174825907038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 220}], {
             RGBColor[
             0.9815827000970889, 0.9830607655255337, 0.7635863486997538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 302}], {
             RGBColor[
             0.9102035037908425, 0.9270075233609678, 0.786684723725317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 323}], {
             RGBColor[
             0.9771734547658208, 0.9337290146046322, 0.44522975477732785`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 357}], {
             RGBColor[
             0.8421038706738644, 0.8737557876521457, 0.7799109308016184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 145}], {
             RGBColor[
             0.9926310799031555, 0.989336757726428, 0.6348373364616571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 164}], {
             RGBColor[
             0.9912724546024403, 0.9906589499374925, 0.7943015436084302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 223}], {
             RGBColor[
             0.7707809913253652, 0.8180463312508852, 0.868597575455734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 234}], {
             RGBColor[
             0.7193505794787756, 0.7761086887247712, 0.8645996571911357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 280}], {
             RGBColor[
             0.9369848840760095, 0.773608407541792, 0.5013067571623349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 346}], {
             RGBColor[
             0.9853488803998955, 0.9872693512274358, 0.8503732032345148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 167}], {
             RGBColor[
             0.9849780000552124, 0.9726528998472654, 0.6344557452608875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 201}], {
             RGBColor[
             0.9666704696306925, 0.9593396727087837, 0.6806938632178314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 236}], {
             RGBColor[
             0.9821624114374441, 0.9514917666928426, 0.38520476609076654`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 243}], {
             RGBColor[
             0.9712225205982795, 0.9627345848671107, 0.6729884282947425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 263}], {
             RGBColor[
             0.9722008770727627, 0.9178891722012748, 0.3465060861618974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 348}], {
             RGBColor[
             0.9886708585567983, 0.9727524464678203, 0.46948805173882124`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 351}], {
             RGBColor[
             0.8564827258579255, 0.8725714688340587, 0.6824414272433592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 221}], {
             RGBColor[
             0.9765841866819915, 0.9639416486573222, 0.6579863645716904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 276}], {
             RGBColor[
             0.9362726524631526, 0.8107587955334414, 0.5860349909345601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 322}], {
             RGBColor[
             0.9480316531455815, 0.8583185270635576, 0.5955451433808896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 364}], {
             RGBColor[
             0.9680144964483679, 0.9756658443394237, 0.9390272937442365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 376}], {
             RGBColor[
             0.9806554391255327, 0.9841730461014921, 0.8764124144736867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 377}], {
             RGBColor[
             0.9740622620676813, 0.9554346047571951, 0.6481891636705972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 194}], {
             RGBColor[
             0.9883652256025581, 0.9872225488253168, 0.6809628863355724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 237}], {
             RGBColor[
             0.923767678182307, 0.9369598085621955, 0.7179869224863116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 246}], {
             RGBColor[
             0.9817516627445974, 0.982290164474565, 0.6921579231606517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 254}], {
             RGBColor[
             0.8305266291581704, 0.8638377352045132, 0.7087682161940729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 286}], {
             RGBColor[
             0.9928854364525098, 0.9871909929016619, 0.467001847731488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 320}], {
             RGBColor[
             0.8209441713858392, 0.8563518463633917, 0.7078131263564862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 343}], {
             RGBColor[
             0.9931359442107296, 0.9877268036662745, 0.49426807125903227`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 349}], {
             RGBColor[
             0.9918603824409433, 0.9840659009784987, 0.43473304547502756`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 376}], {
             RGBColor[
             0.9912304263967797, 0.9884390182973944, 0.6348957881510199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 199}], {
             RGBColor[
             0.8913595236527497, 0.8648766371547023, 0.6348095090914906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 238}], {
             RGBColor[
             0.975279265125367, 0.9274470149123957, 0.4287261870727938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 252}], {
             RGBColor[
             0.9756324842976096, 0.9282025150058861, 0.46717191415535675`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 277}], {
             RGBColor[
             0.9747140073213306, 0.9262379856258924, 0.3672013634702319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 285}], {
             RGBColor[
             0.9715379610119892, 0.9271423048006977, 0.5810397541286293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 293}], {
             RGBColor[
             0.967332733761027, 0.901467781716384, 0.32759426866753005`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 330}], {
             RGBColor[
             0.965710411170828, 0.9231561819590832, 0.6070282426003091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 144}], {
             RGBColor[
             0.9395303578951484, 0.7796317330783786, 0.4800860751361488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 233}], {
             RGBColor[
             0.9948519971371281, 0.9917731629269821, 0.7083734818814629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 242}], {
             RGBColor[
             0.9389181591595268, 0.776851881602568, 0.47957524150478187`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 256}], {
             RGBColor[
             0.940851823532118, 0.952378414408493, 0.8620722804545681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 257}], {
             RGBColor[
             0.9942906581423568, 0.9905725155772448, 0.6472751964833268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 317}], {
             RGBColor[
             0.9681157670512344, 0.8987279687949304, 0.5033847638348068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 366}], {
             RGBColor[
             0.9083862168547667, 0.5808382347464931, 0.4518519704103173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 381}], {
             RGBColor[
             0.9903672903357554, 0.9902846412515577, 0.8093024579974295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 382}], {
             RGBColor[
             0.9939496024382399, 0.9917660193671567, 0.7499342757327204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 184}], {
             RGBColor[
             0.7685697517147088, 0.817160520755429, 0.9064388759215243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 305}], {
             RGBColor[
             0.689067366113344, 0.7556716700926119, 0.9705971113384562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 325}], {
             RGBColor[
             0.7647228437552145, 0.7945279114152282, 0.6670565321413126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 141}], {
             RGBColor[
             0.9796167210953628, 0.9483150728658016, 0.5704078645226386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 168}], {
             RGBColor[
             0.8251989921314707, 0.8622941365528038, 0.8871954294128785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 191}], {
             RGBColor[
             0.9927400809078482, 0.9910340023810843, 0.7531262210297072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 216}], {
             RGBColor[
             0.9898586442690112, 0.9900743030313512, 0.8177320396572076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 219}], {
             RGBColor[
             0.992496857000159, 0.9911652717946555, 0.7740100272264001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 220}], {
             RGBColor[
             0.97980811273694, 0.9834190128922333, 0.8723788933354502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 350}], {
             RGBColor[
             0.7550747546543242, 0.8056333032157872, 0.8814909515613532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 357}], {
             RGBColor[
             0.8403292833137155, 0.8741140350188454, 0.8887034754373146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 150}], {
             RGBColor[
             0.9317136705561944, 0.912573285520403, 0.66148951552251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 189}], {
             RGBColor[
             0.9818155780392926, 0.9488642952385744, 0.5077944457931391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 219}], {
             RGBColor[
             0.9816466642766106, 0.9491545065384079, 0.5367664526848078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 220}], {
             RGBColor[
             0.9689579200133916, 0.9414082476359857, 0.6351353187938578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 273}], {
             RGBColor[
             0.9813613929790395, 0.9490365395257243, 0.5414941363440139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 339}], {
             RGBColor[
             0.8557174274265279, 0.8526008579179086, 0.6540750931003723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 350}], {
             RGBColor[
             0.7442245619307759, 0.7636225379595396, 0.644247377019761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 357}], {
             RGBColor[
             0.8294790905901672, 0.8321032697625979, 0.6514599008957225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 394}], {
             RGBColor[
             0.9819577143648226, 0.9491683104666961, 0.5232651076633554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 202}], {
             RGBColor[
             0.8489713401861378, 0.8782101811622515, 0.707666930681967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 214}], {
             RGBColor[
             0.8482504052990245, 0.8801612499871208, 0.8831073423392481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 217}], {
             RGBColor[
             0.8500667649613232, 0.8805531839919389, 0.8268971572828079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 257}], {
             RGBColor[
             0.8495014601898427, 0.879344054246822, 0.7653672215638101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 268}], {
             RGBColor[
             0.8448847194389204, 0.8787694523897864, 0.9388854671569704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 275}], {
             RGBColor[
             0.8435475703255119, 0.8600205631459911, 0.6775804738123877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 279}], {
             RGBColor[
             0.7884350450882194, 0.8350679274393971, 0.9794367800985615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 300}], {
             RGBColor[
             0.8489646181078385, 0.8781958033164756, 0.706935273942949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 306}], {
             RGBColor[
             0.8017655803010557, 0.845697334370374, 0.9807082584474711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 338}], {
             RGBColor[
             0.8497373281801661, 0.8807761308106479, 0.8584651821656668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 363}], {
             RGBColor[
             0.7198323997569838, 0.781057808709802, 0.9727098244576926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 381}], {
             RGBColor[
             0.8455780923832413, 0.8790561799211349, 0.9273944830779127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 223}], {
             RGBColor[
             0.771143377638015, 0.8181961873040693, 0.8625918964294131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 234}], {
             RGBColor[
             0.7197129657914253, 0.7762585447779553, 0.8585939781648149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 260}], {
             RGBColor[
             0.9869919343214257, 0.9883743270864223, 0.8421996879979665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 267}], {
             RGBColor[
             0.9651022660966744, 0.8902560213275779, 0.5179674880279572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 272}], {
             RGBColor[
             0.9317261808903579, 0.9454775543035432, 0.8775151750459131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 290}], {
             RGBColor[
             0.9830967468580423, 0.9854693026540149, 0.8487932243458784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 291}], {
             RGBColor[
             0.9802494288508925, 0.9468652617934025, 0.5480927672511686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 321}], {
             RGBColor[
             0.988545840412066, 0.9748510060793119, 0.5803227595204665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 331}], {
             RGBColor[
             0.9937974242139124, 0.991206198644941, 0.7163375240756598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 342}], {
             RGBColor[
             0.9858933757692967, 0.9659036200109359, 0.5700184352592256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 398}], {
             RGBColor[
             0.9924074986391038, 0.9878772860395807, 0.5953245725195426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 207}], {
             RGBColor[
             0.9303968367278689, 0.7745900298340509, 0.5748137318374148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 233}], {
             RGBColor[
             0.9395360817189207, 0.7792680801879533, 0.4533854381954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 242}], {
             RGBColor[
             0.8836022437413193, 0.5643467988635391, 0.22458719781871905`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 317}], {
             RGBColor[
             0.9127998516330269, 0.6862228860559016, 0.24839672014874395`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 358}], {
             RGBColor[
             0.9155635963247402, 0.6971802127952214, 0.25062049400112213`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 366}], {
             RGBColor[
             0.8530703014365593, 0.3683331520074642, 0.19686392672425448`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 370}], {
             RGBColor[
             0.7951557538425104, 0.6687271556535694, 0.5982194230619715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 391}], {
             RGBColor[
             0.9333557232750572, 0.7767967625762119, 0.569805108714232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 162}], {
             RGBColor[
             0.9300748771702922, 0.7384201447380039, 0.3504631317884147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 164}], {
             RGBColor[
             0.9917394776691896, 0.9889680572895508, 0.6496134928710877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 227}], {
             RGBColor[
             0.9913282701478404, 0.9887980124119218, 0.6564282656707957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 280}], {
             RGBColor[
             0.9374519071427588, 0.7719175148938504, 0.3566187064249923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 359}], {
             RGBColor[
             0.7648232895317892, 0.8111395575307749, 0.723403746842844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 154}], {
             RGBColor[
             0.8492609408983309, 0.8826933145844138, 0.9645907449207722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 159}], {
             RGBColor[
             0.9766566041639434, 0.9796804003781476, 0.7952136385611066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 165}], {
             RGBColor[
             0.8811026029108704, 0.9075682629542041, 0.9677644242129326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 192}], {
             RGBColor[
             0.9589248910351476, 0.9688868315051069, 0.9544136247600452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 228}], {
             RGBColor[
             0.8306764068801481, 0.8681749353617194, 0.9627384122521845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 262}], {
             RGBColor[
             0.976967270476087, 0.9803448842066405, 0.8290277494276972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 297}], {
             RGBColor[
             0.9718358568990431, 0.9646127770481155, 0.6749662293155342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 307}], {
             RGBColor[
             0.8888049933135698, 0.9135854288771281, 0.968532126505343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 314}], {
             RGBColor[
             0.9690413835137051, 0.9764316950313789, 0.9372890417976615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 332}], {
             RGBColor[
             0.9493789604578196, 0.9617674921105624, 0.970572395250024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 385}], {
             RGBColor[
             0.8372760116724587, 0.8733305967843266, 0.9633961991810687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 172}], {
             RGBColor[
             0.8875534757387185, 0.8961009708880305, 0.6844529676541411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 211}], {
             RGBColor[
             0.8886844529479022, 0.9128204185908932, 0.9357366345477901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 328}], {
             RGBColor[
             0.8837679512308667, 0.9093548882188719, 0.9530686242281592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 347}], {
             RGBColor[
             0.8919460444987726, 0.9109181367398842, 0.7015172678199435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 364}], {
             RGBColor[
             0.8782080098179836, 0.9052082930167122, 0.9624801547752057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 372}], {
             RGBColor[
             0.89248412510795, 0.9124250390984974, 0.7298121518448808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 387}], {
             RGBColor[
             0.8849087846967307, 0.91020571994977, 0.951137490747473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 161}], {
             RGBColor[
             0.9565941945890006, 0.9655215030386667, 0.8892174898422547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 168}], {
             RGBColor[
             0.7906750942323993, 0.8372205223551947, 0.979553195935273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 170}], {
             RGBColor[
             0.9428283439405257, 0.9565138142005054, 0.9688938086933319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 251}], {
             RGBColor[
             0.9544437413156426, 0.9646322353460048, 0.9248560657764713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.8724868974944577, 0.9011613853088937, 0.9876997732329112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 312}], {
             RGBColor[
             0.9452225045444813, 0.9582993752588573, 0.9648411192879269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 326}], {
             RGBColor[
             0.9557288471560685, 0.9651636596367347, 0.9035585362533067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 356}], {
             RGBColor[
             0.9314078978146452, 0.947996464179088, 0.9882256450550548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 199}], {
             RGBColor[
             0.881705030785213, 0.8268226712897242, 0.6258805085064056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 212}], {
             RGBColor[
             0.9544561394036051, 0.8525449109406156, 0.30614801223705085`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 238}], {
             RGBColor[
             0.9656247722578304, 0.8893930490474176, 0.4197971864877088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 259}], {
             RGBColor[
             0.9660567351842628, 0.8903169740689052, 0.4668136852637071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 274}], {
             RGBColor[
             0.9653822294519474, 0.8905351666504329, 0.5141272241743415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 287}], {
             RGBColor[
             0.9374606220956796, 0.8712338746294712, 0.6295762280647161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 299}], {
             RGBColor[
             0.8375387007801418, 0.7922709545538833, 0.621491330127001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 318}], {
             RGBColor[
             0.8965927106323011, 0.8386937030844882, 0.6273005087006096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 336}], {
             RGBColor[
             0.9283094041044389, 0.8639837335324614, 0.6303256752378086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 367}], {
             RGBColor[
             0.9429893221607765, 0.8116786905893347, 0.27298607427920213`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 186}], {
             RGBColor[
             0.9439267734234427, 0.9551476491462635, 0.876146141884606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 189}], {
             RGBColor[
             0.9447627202236726, 0.9551332731494233, 0.8361196713346029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 226}], {
             RGBColor[
             0.9044373407765116, 0.8082179351729311, 0.619823705066205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 241}], {
             RGBColor[
             0.9435928728442584, 0.95263108789457, 0.7087890035465327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 255}], {
             RGBColor[
             0.6933299682038552, 0.758654171094498, 0.9714829304063377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 266}], {
             RGBColor[
             0.9448483593428272, 0.9555287486076068, 0.8608730782124967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 365}], {
             RGBColor[
             0.9185906135992066, 0.9377473315824334, 0.9859984328483401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 374}], {
             RGBColor[
             0.8839883821462955, 0.718240705943873, 0.6029094022699224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 399}], {
             RGBColor[
             0.8424243363986202, 0.8774311462242343, 0.9847684701475905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 171}], {
             RGBColor[
             0.9782887857028228, 0.9804118648782223, 0.7539035323164154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 182}], {
             RGBColor[
             0.7918499436159034, 0.8335069334392002, 0.7604397623458217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 244}], {
             RGBColor[
             0.994094756114368, 0.9897776053774034, 0.5986288298689186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 249}], {
             RGBColor[
             0.7492171760089823, 0.7988957321116077, 0.7570835547108314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 253}], {
             RGBColor[
             0.9906266221357616, 0.989061624906758, 0.7083090391287858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 270}], {
             RGBColor[
             0.9943938276477029, 0.9904172891464362, 0.6311809206168579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 308}], {
             RGBColor[
             0.9427883251809641, 0.7953780586497503, 0.3957373790342506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 386}], {
             RGBColor[
             0.9940594289749487, 0.989702044198307, 0.5947836887569484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 397}], {
             RGBColor[
             0.8803360926315675, 0.9034356732546454, 0.7687104327756716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 156}], {
             RGBColor[
             0.9150438680918298, 0.9343807910472032, 0.9669913275624196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 175}], {
             RGBColor[
             0.9277437820282675, 0.9430866134612189, 0.9112017197339768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 242}], {
             RGBColor[
             0.8748382134860101, 0.7290515795326433, 0.6056114395355043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 256}], {
             RGBColor[
             0.8767718778586013, 0.9045781123385683, 0.9881084784852905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 261}], {
             RGBColor[
             0.9150438680918298, 0.9343807910472032, 0.9669913275624196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 264}], {
             RGBColor[
             0.913867183152705, 0.9335032213462486, 0.9689831482357742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 317}], {
             RGBColor[
             0.9040358213777177, 0.8509276667250059, 0.6294209618655292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 333}], {
             RGBColor[
             0.8730642254201824, 0.7209963140511593, 0.6041311804089511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 381}], {
             RGBColor[
             0.9262873446622388, 0.9424843391816331, 0.9353386560281518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 154}], {
             RGBColor[
             0.8657796955036705, 0.890460049052642, 0.6988848096571982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 188}], {
             RGBColor[
             0.9607349766435903, 0.8714032327712073, 0.3426314087898562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 195}], {
             RGBColor[
             0.9723345824889807, 0.9743348317655653, 0.6939705224384332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 203}], {
             RGBColor[
             0.8911059186388626, 0.910245087052279, 0.7014090908923027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 258}], {
             RGBColor[
             0.968324575267022, 0.9713441749452127, 0.7007584186878237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 278}], {
             RGBColor[
             0.9561699899455807, 0.9618854752260964, 0.7076786317788091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 284}], {
             RGBColor[
             0.9502560280433576, 0.8298576934739029, 0.33419980077357186`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 312}], {
             RGBColor[
             0.9804695723416741, 0.9804018938778807, 0.6802001065629832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 327}], {
             RGBColor[
             0.9072049212564424, 0.9228420585747598, 0.7030082998156062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 337}], {
             RGBColor[
             0.9451903851359006, 0.9531306363842906, 0.7066313872704528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[
             0.966654965611838, 0.9700989827981112, 0.7035846323301111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 361}], {
             RGBColor[
             0.9919646763342382, 0.9876750564968003, 0.6025311886131466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 369}], {
             RGBColor[
             0.9845465748417341, 0.9834425156669466, 0.673298804782934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 392}], {
             RGBColor[
             0.993224376215216, 0.9875519782068023, 0.5348429497867166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 192}], {
             RGBColor[
             0.8493100875290039, 0.8827299680610995, 0.964507552494537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[
             0.7649723605273793, 0.8163214891400434, 0.9772089538903685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 222}], {
             RGBColor[
             0.6414892215520767, 0.7183385598078205, 0.9659384642670882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 228}], {
             RGBColor[
             0.7210616033740045, 0.7820180719177121, 0.9728323399866763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 312}], {
             RGBColor[
             0.8543360142301908, 0.886478295965645, 0.955999969561049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 332}], {
             RGBColor[
             0.8397641569516759, 0.875610628666555, 0.9806663229845158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 356}], {
             RGBColor[
             0.8405214075003546, 0.8761753848858757, 0.9793844953281771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 361}], {
             RGBColor[
             0.865831118222755, 0.8937514585845647, 0.8783310516112124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 385}], {
             RGBColor[
             0.727661208166315, 0.7871737333403193, 0.9734901269155605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 170}], {
             RGBColor[
             0.9269138128173884, 0.7821925367456667, 0.5875021101157738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 180}], {
             RGBColor[
             0.9203238170150998, 0.7772777286664476, 0.5986572540628727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 183}], {
             RGBColor[
             0.9421361513202393, 0.7918025207416428, 0.48368801824794677`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 239}], {
             RGBColor[
             0.8458810573181244, 0.718459115512095, 0.6052501235616485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 271}], {
             RGBColor[
             0.9248173670646365, 0.7806290109358791, 0.59105084593456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 326}], {
             RGBColor[
             0.9398143160329313, 0.790842382181896, 0.5221668376757487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 335}], {
             RGBColor[
             0.9401881301505719, 0.790996963926125, 0.5159717703465174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 337}], {
             RGBColor[
             0.8940287862155706, 0.7567068403104285, 0.6098807014178385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 354}], {
             RGBColor[
             0.819195799686812, 0.6976123894350441, 0.6025903864688702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 175}], {
             RGBColor[
             0.9761012681537746, 0.9809311928308638, 0.8910465324127399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 202}], {
             RGBColor[
             0.9780380785906425, 0.9794829197923944, 0.6954559163109693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 214}], {
             RGBColor[
             0.9773171437035293, 0.9814339886172636, 0.8708963279682503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 256}], {
             RGBColor[
             0.9251293639841086, 0.9424226917082132, 0.9679532911640536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 261}], {
             RGBColor[
             0.963401354217337, 0.9722253704168481, 0.9468361402411827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 264}], {
             RGBColor[
             0.9622246692782123, 0.9713478007158936, 0.9488279609145374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 295}], {
             RGBColor[
             0.9783790493399278, 0.9818731138876445, 0.8532978034494325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 310}], {
             RGBColor[
             0.9746034630691689, 0.9803118119365444, 0.915869038859962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 363}], {
             RGBColor[
             0.8488991381614885, 0.882330547339945, 0.9604988100866948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 381}], {
             RGBColor[
             0.974644830787746, 0.980328918551278, 0.9151834687069149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 187}], {
             RGBColor[
             0.9005600169401726, 0.9205483070624851, 0.8666642507738067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 218}], {
             RGBColor[
             0.9944932561888338, 0.9919908341642915, 0.7409245261545739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 253}], {
             RGBColor[
             0.990672058906295, 0.9904106708876708, 0.8042516540678131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 298}], {
             RGBColor[
             0.9883050194499907, 0.9726445618813578, 0.5697512583669284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.8916389750217053, 0.9141414941197679, 0.8912754555380757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 265}], {
             RGBColor[
             0.9921477078871304, 0.9895039013711742, 0.6695272968744772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 311}], {
             RGBColor[
             0.978025268762301, 0.942495450969749, 0.561106145741155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 322}], {
             RGBColor[
             0.9576281371039763, 0.8643824148901891, 0.5303471208282988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 362}], {
             RGBColor[
             0.9910065094699698, 0.9905489747907378, 0.798708942697406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 165}], {
             RGBColor[
             0.8988834626703393, 0.9183984853039306, 0.8084812455877588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 167}], {
             RGBColor[
             0.9903394899793478, 0.9895445751393117, 0.7568038376269053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 192}], {
             RGBColor[
             0.9767057507946164, 0.9797170538548334, 0.7951304461348714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 201}], {
             RGBColor[
             0.9720319595548279, 0.9762313480008299, 0.803041955583849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 210}], {
             RGBColor[
             0.9667023169840316, 0.9722565092980189, 0.8120636502628003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 228}], {
             RGBColor[
             0.848457266639617, 0.8790051577114459, 0.8034552336270105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 236}], {
             RGBColor[
             0.9875239013615794, 0.9683834419848889, 0.5075528584567843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 243}], {
             RGBColor[
             0.9765840105224148, 0.9796262601591569, 0.7953365206607603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 263}], {
             RGBColor[
             0.977562366996898, 0.9347808474933209, 0.4688541785279151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 166}], {
             RGBColor[
             0.9321361137445533, 0.9457529013060226, 0.8753169974361046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 185}], {
             RGBColor[
             0.9920557986932254, 0.9909828828500569, 0.7813195047945996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 213}], {
             RGBColor[
             0.8755316376160025, 0.9011197819452059, 0.8697848620423114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 224}], {
             RGBColor[
             0.9771377716228389, 0.9809805089983225, 0.8568829501778339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 247}], {
             RGBColor[
             0.9687976617717213, 0.9747604687270356, 0.8710005807067521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 289}], {
             RGBColor[
             0.9002232175682128, 0.9204090318668307, 0.8722458879760141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 302}], {
             RGBColor[
             0.9097741004074749, 0.927922038871718, 0.8731840886412091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 340}], {
             RGBColor[
             0.9890155029216394, 0.9897256424164688, 0.8317050737630189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 370}], {
             RGBColor[
             0.8496271734902767, 0.8808830176889696, 0.8672029471492397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 400}], {
             RGBColor[
             0.9692663514499977, 0.9751100167216852, 0.8702072113352759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 170}], {
             RGBColor[
             0.978003420508758, 0.981856707512341, 0.865744326426567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 222}], {
             RGBColor[
             0.7675507884345993, 0.8155025324128684, 0.871630131727201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 239}], {
             RGBColor[
             0.8969706650094937, 0.9181232862787693, 0.8834923398724415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 251}], {
             RGBColor[
             0.9896188178838747, 0.9899751286578404, 0.8217065835097062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 312}], {
             RGBColor[
             0.9803975811127136, 0.9836422685706929, 0.8616916370211619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 326}], {
             RGBColor[
             0.9909039237243008, 0.9905065529485703, 0.8004090539865417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 327}], {
             RGBColor[
             0.9071329300274819, 0.9260824332675721, 0.884499830273785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 337}], {
             RGBColor[
             0.9451183939069401, 0.9563710110771029, 0.8881229177286316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.9665829743828773, 0.9733393574909236, 0.8850761627882899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 179}], {
             RGBColor[
             0.8573443754133141, 0.685270627640153, 0.5980532775824183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 231}], {
             RGBColor[
             0.8961001169274616, 0.7161734039269558, 0.6017498348056967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 313}], {
             RGBColor[
             0.8830707554303515, 0.7057841447417563, 0.6005070826746539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 359}], {
             RGBColor[
             0.7018000637321767, 0.5619138371902924, 0.5837175929069444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 164}], {
             RGBColor[
             0.9926266494206055, 0.9912189442960232, 0.7718590309275826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 169}], {
             RGBColor[
             0.9933993071446194, 0.9882874243449273, 0.5788877388650158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 209}], {
             RGBColor[
             0.9850890385173587, 0.9866255996573254, 0.8306628336797646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 227}], {
             RGBColor[
             0.9922154418992564, 0.9910488994183941, 0.7786738037272904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 240}], {
             RGBColor[
             0.9661677897415601, 0.9725141633010362, 0.8626915724051516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 245}], {
             RGBColor[
             0.9401585249148785, 0.9518205736637881, 0.8617880263114336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 280}], {
             RGBColor[
             0.9383390788941748, 0.7741684019003228, 0.4788642444814871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 304}], {
             RGBColor[
             0.8620617070567231, 0.8902816523078834, 0.8541444705600627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 315}], {
             RGBColor[
             0.9709855023180762, 0.9761072054523215, 0.8545364416737906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 319}], {
             RGBColor[
             0.9947421579300866, 0.9920937614307824, 0.736799580164959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 329}], {
             RGBColor[
             0.9943970794329146, 0.9907775607232148, 0.6572172252737041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 371}], {
             RGBColor[
             0.9728260164257656, 0.977479857860271, 0.8514209313724318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 169}], {
             RGBColor[
             0.9911535100924882, 0.9873587295495194, 0.6161064079552943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 209}], {
             RGBColor[
             0.9828432414652275, 0.9856969048619175, 0.867881502770043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 227}], {
             RGBColor[
             0.9899696448471252, 0.9901202046229862, 0.8158924728175689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 245}], {
             RGBColor[
             0.9379127278627473, 0.9508918788683802, 0.899006695401712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 280}], {
             RGBColor[
             0.9360932818420437, 0.7732397071049149, 0.5160829135717655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 304}], {
             RGBColor[
             0.8598159100045919, 0.8893529575124755, 0.8913631396503411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 315}], {
             RGBColor[
             0.968739705265945, 0.9751785106569136, 0.891755110764069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 228}], {
             RGBColor[
             0.752903265386544, 0.8068930202875024, 0.9760060192788367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 262}], {
             RGBColor[
             0.8991941289824829, 0.9190629691324234, 0.8422953564543495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 298}], {
             RGBColor[
             0.8930543099004273, 0.8999292734206219, 0.6843163713766169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 307}], {
             RGBColor[
             0.8110318518199657, 0.852303513802911, 0.9817997335319953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 314}], {
             RGBColor[
             0.891268242020101, 0.915149779957162, 0.9505566488243138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 332}], {
             RGBColor[
             0.8716058189642155, 0.9004855770363454, 0.9838400022766763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 385}], {
             RGBColor[
             0.7595028701788545, 0.8120486817101096, 0.976663806207721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 185}], {
             RGBColor[
             0.931034630665305, 0.9452974097459295, 0.8935714226060814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 213}], {
             RGBColor[
             0.8145104695880822, 0.8554343088410784, 0.9820367798537933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 224}], {
             RGBColor[
             0.9161166035949184, 0.9352950358941949, 0.9691348679893158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 247}], {
             RGBColor[
             0.907776493743801, 0.9290749956229081, 0.983252498518234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 289}], {
             RGBColor[
             0.8392020495402925, 0.8747235587627031, 0.984497805787496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 302}], {
             RGBColor[
             0.8487529323795544, 0.8822365657675905, 0.985436006452691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 340}], {
             RGBColor[
             0.9279943348937192, 0.9440401693123412, 0.9439569915745007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 400}], {
             RGBColor[
             0.9082451834220774, 0.9294245436175577, 0.9824591291467578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 192}], {
             RGBColor[
             0.9726077768505519, 0.978751006266271, 0.916003823825844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[
             0.9679339856107634, 0.9752653004122674, 0.9239153332748218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.8882700498489273, 0.9123425273452148, 0.9287052252216756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 228}], {
             RGBColor[
             0.8443592926955525, 0.8780391101228835, 0.9243286113179832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 243}], {
             RGBColor[
             0.9724860365783504, 0.9786602125705944, 0.916209898351733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 348}], {
             RGBColor[
             0.9899343745368692, 0.9886780741713042, 0.7127095217958117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 351}], {
             RGBColor[
             0.8577462418379964, 0.8884970965375425, 0.9256628973003496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 170}], {
             RGBColor[
             0.8120843201521567, 0.853555726828869, 0.9560800325195853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 180}], {
             RGBColor[
             0.8054943243498681, 0.84864091874965, 0.967235176466684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 220}], {
             RGBColor[
             0.8145401910494996, 0.8553873113229878, 0.9519228836840978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 251}], {
             RGBColor[
             0.8236997175272736, 0.8616741479743684, 0.9120422896027245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 282}], {
             RGBColor[
             0.7417428737060887, 0.7982032979372573, 0.9748859970591646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 350}], {
             RGBColor[
             0.5898068329668837, 0.6776016016465417, 0.9610349419100009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 357}], {
             RGBColor[
             0.6750613616262751, 0.7460823334495998, 0.9682474657859623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 394}], {
             RGBColor[
             0.8275399854009307, 0.8631473741536982, 0.8400526725535955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 209}], {
             RGBColor[
             0.9836158991892413, 0.9827653849108215, 0.6749102107074763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 227}], {
             RGBColor[
             0.990742302571139, 0.9871886846718902, 0.6229211807550022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 240}], {
             RGBColor[
             0.9646946504134428, 0.9686539485545325, 0.7069389494328633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 245}], {
             RGBColor[
             0.9386853855867611, 0.9479603589172844, 0.7060354033391454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 280}], {
             RGBColor[
             0.9368659395660575, 0.7703081871538191, 0.32311162150919887`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 292}], {
             RGBColor[
             0.9759695180759784, 0.9770627263963501, 0.6878535394366393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 304}], {
             RGBColor[
             0.8605885677286057, 0.8864214375613796, 0.6983918475877744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 315}], {
             RGBColor[
             0.9695123629899588, 0.9722469907058178, 0.6987838187015023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 329}], {
             RGBColor[
             0.9929239401047971, 0.986917345976711, 0.5014646023014158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 353}], {
             RGBColor[
             0.9579991930919451, 0.9633606647625794, 0.7078775715406294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 378}], {
             RGBColor[
             0.9888351931837491, 0.9864000459297289, 0.6545269187449373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 180}], {
             RGBColor[
             0.9576475740579945, 0.9679342105949608, 0.9565757892247428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 239}], {
             RGBColor[
             0.8832048143610189, 0.909115597440608, 0.9631686587235188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 251}], {
             RGBColor[
             0.9758529672353999, 0.9809674398196793, 0.9013829023607834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 271}], {
             RGBColor[
             0.962141124107531, 0.9712854928643923, 0.9489693810964304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 282}], {
             RGBColor[
             0.8938961234142151, 0.917496589782568, 0.9642266098172234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 326}], {
             RGBColor[
             0.9771380730758259, 0.981498864110409, 0.880085372837619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 182}], {
             RGBColor[
             0.7763987223433999, 0.8248999654777891, 0.9543267193200837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 244}], {
             RGBColor[
             0.9786435348418645, 0.9811706374159923, 0.7925157868431806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 253}], {
             RGBColor[
             0.975175400863258, 0.980454656945347, 0.9021959961030479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 270}], {
             RGBColor[
             0.9789426063751994, 0.9818103211850252, 0.82506787759112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 308}], {
             RGBColor[
             0.9273371039084604, 0.7867710906883393, 0.5896243360085126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 397}], {
             RGBColor[
             0.8648848713590639, 0.8948287052932342, 0.9625973897499336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 211}], {
             RGBColor[
             0.9842720075055778, 0.9715123255975788, 0.6402901824547718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 328}], {
             RGBColor[
             0.9793555057885421, 0.9680467952255576, 0.6576221721351408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 347}], {
             RGBColor[
             0.987533599056448, 0.9696100437465699, 0.4060708157269251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 364}], {
             RGBColor[
             0.9737955643756591, 0.9639002000233978, 0.6670337026821873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 387}], {
             RGBColor[
             0.9804963392544063, 0.9688976269564555, 0.6556910386544545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 175}], {
             RGBColor[
             0.9869919711021852, 0.9888888600067287, 0.8652402327438578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 197}], {
             RGBColor[
             0.961466937246841, 0.9706180841563989, 0.9427394232680165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 204}], {
             RGBColor[
             0.980526408591776, 0.9848326066784314, 0.9104767097873012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 214}], {
             RGBColor[
             0.9882078466519397, 0.9893916557931286, 0.8450900282993682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 261}], {
             RGBColor[
             0.9742920571657474, 0.980183037592713, 0.9210298405723005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 295}], {
             RGBColor[
             0.9892697522883382, 0.9898307810635094, 0.8274915037805504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 310}], {
             RGBColor[
             0.9854941660175793, 0.9882694791124094, 0.8900627391910798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 345}], {
             RGBColor[
             0.988851902209033, 0.9872761498550392, 0.6612817760136399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 193}], {
             RGBColor[
             0.8524250481207483, 0.7814669407055783, 0.6180073692630362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 232}], {
             RGBColor[
             0.8834430412518339, 0.8957527383537409, 0.6882239307127278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 235}], {
             RGBColor[
             0.8787030638693705, 0.9053928469900466, 0.9522948741959161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 260}], {
             RGBColor[
             0.8813155549252465, 0.9073412385419575, 0.9478726082851118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 267}], {
             RGBColor[
             0.8594258867004951, 0.8092229327831131, 0.6236404083151025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 272}], {
             RGBColor[
             0.8260498014941786, 0.8644444657590784, 0.9831880953330584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 275}], {
             RGBColor[
             0.8816816669560217, 0.8898112092636141, 0.6813813241811226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 281}], {
             RGBColor[
             0.8881325041983689, 0.910197620556935, 0.8232577272259065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 291}], {
             RGBColor[
             0.8745730494547133, 0.8658321732489377, 0.6537656875383139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 338}], {
             RGBColor[
             0.8878714248106759, 0.9105667769282708, 0.8622660325344018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 384}], {
             RGBColor[
             0.8628274764849446, 0.8935528599126303, 0.9791681026214204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 398}], {
             RGBColor[
             0.8867311192429246, 0.9068441974951159, 0.7009974928066878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 204}], {
             RGBColor[
             0.9823356195798032, 0.9855807619165823, 0.8804934016277406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 214}], {
             RGBColor[
             0.990017057639967, 0.9901398110312793, 0.8151067201398076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 256}], {
             RGBColor[
             0.9378292779205464, 0.951128514122229, 0.9121636833356108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 261}], {
             RGBColor[
             0.9761012681537746, 0.9809311928308638, 0.8910465324127399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 264}], {
             RGBColor[
             0.97492458321465, 0.9800536231299093, 0.8930383530860946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 295}], {
             RGBColor[
             0.9910789632763655, 0.9905789363016603, 0.7975081956209897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 310}], {
             RGBColor[
             0.9873033770056066, 0.9890176343505601, 0.8600794310315192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 345}], {
             RGBColor[
             0.9906611131970602, 0.9880243050931901, 0.6312984678540793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 186}], {
             RGBColor[
             0.9401690279416965, 0.952151324900403, 0.8757877247659781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 226}], {
             RGBColor[
             0.9006795952947655, 0.8052216109270706, 0.619465287947577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 294}], {
             RGBColor[
             0.7653641644603987, 0.8171704093115, 0.9771039522099031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 341}], {
             RGBColor[
             0.8837288155305832, 0.9101253855971642, 0.9887720374109756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 368}], {
             RGBColor[
             0.9370744918369769, 0.950871654695151, 0.9270721964239053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 379}], {
             RGBColor[
             0.9231789476178351, 0.8934630946257403, 0.6425734430414383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 393}], {
             RGBColor[
             0.9385652349771512, 0.9514881152939643, 0.9023667246716398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 399}], {
             RGBColor[
             0.8386665909168742, 0.8744348219783737, 0.9844100530289626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 200}], {
             RGBColor[
             0.9325377362769036, 0.9489139181613578, 0.9889072596032411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 225}], {
             RGBColor[
             0.9673217372995797, 0.9735382208729098, 0.8680576579069845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 296}], {
             RGBColor[
             0.8408432897999092, 0.8764382054372333, 0.9799918037795552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 311}], {
             RGBColor[
             0.9530167529980651, 0.924937295057207, 0.6523927180393643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 324}], {
             RGBColor[
             0.8869056324665474, 0.6052137225289682, 0.5822294909231738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 339}], {
             RGBColor[
             0.8417115786556855, 0.8771165192906053, 0.9800783466980783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 360}], {
             RGBColor[
             0.967418922707311, 0.9725440608935989, 0.7912608169893736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 374}], {
             RGBColor[
             0.9070353911910731, 0.7364873894057209, 0.6005874303261646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 375}], {
             RGBColor[
             0.9454106454690949, 0.9588079292894911, 0.9772897174236252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 383}], {
             RGBColor[
             0.9632802013755651, 0.9718669419055941, 0.9350363673275998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 390}], {
             RGBColor[
             0.9554880220150475, 0.9332734657330478, 0.6619931315103461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 209}], {
             RGBColor[
             0.9230367745518253, 0.9404471391878004, 0.9571105605040344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 229}], {
             RGBColor[
             0.901807742558351, 0.9245410312697051, 0.9904964216101328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 240}], {
             RGBColor[
             0.9041155257760267, 0.9263357028315113, 0.9891392992294215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 245}], {
             RGBColor[
             0.8781062609493451, 0.9056421131942631, 0.9882357531357034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 248}], {
             RGBColor[
             0.9303356131380117, 0.9386971728517919, 0.7014062509722487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 309}], {
             RGBColor[
             0.8852370663105058, 0.9113280238286977, 0.9889158957167961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 315}], {
             RGBColor[
             0.9089332383525428, 0.9299287449827967, 0.9809841684980605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 319}], {
             RGBColor[
             0.9326898939645532, 0.9459153009612575, 0.8632473069892288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 329}], {
             RGBColor[
             0.9323448154673811, 0.9445991002536898, 0.7836649520979739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 334}], {
             RGBColor[
             0.9304791688332941, 0.9450011093064374, 0.8998847435874324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 371}], {
             RGBColor[
             0.9107737524602322, 0.931301397390746, 0.9778686581967017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 388}], {
             RGBColor[
             0.9092743639033911, 0.9301831558600775, 0.980406731920267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 196}], {
             RGBColor[
             0.9176252569000306, 0.9352463368202066, 0.9201354436469409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 231}], {
             RGBColor[
             0.8863928409700961, 0.9122496071695875, 0.9890261345356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 303}], {
             RGBColor[
             0.8779112518818244, 0.9054866182572023, 0.9882171529967566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 313}], {
             RGBColor[
             0.8733634794729859, 0.901860347984388, 0.9877833824045572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 344}], {
             RGBColor[
             0.9033458011446388, 0.9251651633273779, 0.9697619015531082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 359}], {
             RGBColor[
             0.6920927877748111, 0.7579900404329241, 0.9709938926368477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 239}], {
             RGBColor[
             0.8766148185587304, 0.904200789361389, 0.9743238026706176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 271}], {
             RGBColor[
             0.9555511283052425, 0.9663706847851732, 0.9601245250435291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 282}], {
             RGBColor[
             0.8873061276119265, 0.912581781703349, 0.9753817537643222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 326}], {
             RGBColor[
             0.9705480772735373, 0.97658405603119, 0.8912405167847177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 350}], {
             RGBColor[
             0.7353700868727215, 0.7919800854126334, 0.9615306986151586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 394}], {
             RGBColor[
             0.9731032393067685, 0.97752585791979, 0.8405484292587531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 250}], {
             RGBColor[
             0.8853763772046228, 0.8880570431873958, 0.6749730479015928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 265}], {
             RGBColor[
             0.8930148205502343, 0.9131934533109108, 0.7582050998325132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 322}], {
             RGBColor[
             0.8584952497670802, 0.7880719668299258, 0.6190249237863349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 362}], {
             RGBColor[
             0.8918736221330738, 0.9142385267304745, 0.8873867456554421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 244}], {
             RGBColor[
             0.7922046927549451, 0.8342657059769704, 0.799052016872587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 253}], {
             RGBColor[
             0.7887365587763386, 0.8335497255063249, 0.9087322261324542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 271}], {
             RGBColor[
             0.977363462610382, 0.9808954768603684, 0.8451552892286032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 273}], {
             RGBColor[
             0.9943192522261246, 0.9919188790540133, 0.7438082221244856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 335}], {
             RGBColor[
             0.9927342256963174, 0.9912634298506142, 0.7700762136405606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 305}], {
             RGBColor[
             0.9080956192258692, 0.9276506198635757, 0.9193549209717271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 325}], {
             RGBColor[
             0.9837510968677396, 0.966506861186192, 0.6158143417745836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 213}], {
             RGBColor[
             0.8744301545367542, 0.9006642903851128, 0.8880392872122882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 224}], {
             RGBColor[
             0.9760362885435905, 0.9805250174382294, 0.8751373753478107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 247}], {
             RGBColor[
             0.967696178692473, 0.9743049771669425, 0.889255005876729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 289}], {
             RGBColor[
             0.8991217344889646, 0.9199535403067376, 0.890500313145991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 302}], {
             RGBColor[
             0.9086726173282265, 0.9274665473116248, 0.891438513811186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 340}], {
             RGBColor[
             0.9879140198423912, 0.9892701508563757, 0.8499594989329957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 400}], {
             RGBColor[
             0.9681648683707494, 0.9746545251615921, 0.8884616365052527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 189}], {
             RGBColor[
             0.994028680906541, 0.991438658864435, 0.7224510721552352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 200}], {
             RGBColor[
             0.9587566879149945, 0.9669726204145217, 0.8775606323676313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 226}], {
             RGBColor[
             0.95370330145938, 0.8445233208879428, 0.5061551058868374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 241}], {
             RGBColor[
             0.9928588335271269, 0.9889364736095817, 0.5951204043671651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 255}], {
             RGBColor[
             0.7425959288867237, 0.7949595568095097, 0.85781433122697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 288}], {
             RGBColor[
             0.979880930796511, 0.9830204626978347, 0.8519757345444804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 341}], {
             RGBColor[
             0.9367525216951977, 0.9494270955580364, 0.8754618553502359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 374}], {
             RGBColor[
             0.933254342829164, 0.7545460916588848, 0.48924080309055473`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 393}], {
             RGBColor[
             0.9915889411417658, 0.9907898252548366, 0.7890565426109001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 399}], {
             RGBColor[
             0.8916902970814886, 0.9137365319392461, 0.871099870968223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 193}], {
             RGBColor[
             0.8653015894680507, 0.7915261926714298, 0.619290782566415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 218}], {
             RGBColor[
             0.9012223926126133, 0.9208222164253177, 0.8556869717081728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 232}], {
             RGBColor[
             0.8963195825991364, 0.9058119903195924, 0.6895073440161065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 235}], {
             RGBColor[
             0.8915796052166729, 0.9154520989558981, 0.9535782874992949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 275}], {
             RGBColor[
             0.8945582083033241, 0.8998704612294657, 0.6826647374845014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 279}], {
             RGBColor[
             0.8394456830660316, 0.8749178255228717, 0.9845210437706753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 281}], {
             RGBColor[
             0.9010090455456713, 0.9202568725227864, 0.8245411405292853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 298}], {
             RGBColor[
             0.8950341558737702, 0.9014759441423841, 0.6845137039205272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 306}], {
             RGBColor[
             0.8527762182788678, 0.8855472324538485, 0.9857925221195849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 195}], {
             RGBColor[
             0.9411563055174172, 0.8613544175718949, 0.6135169845691569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 203}], {
             RGBColor[
             0.8599276416672991, 0.7972646728586086, 0.6209555530230266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 206}], {
             RGBColor[
             0.9570516722615112, 0.8731502366686903, 0.5839717439740642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 208}], {
             RGBColor[
             0.9505791919884757, 0.8371453864378708, 0.3031781031637433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 258}], {
             RGBColor[
             0.9371462982954585, 0.8583637607515423, 0.6203048808185476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 278}], {
             RGBColor[
             0.9249917129740172, 0.848905061032426, 0.627225093909533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 284}], {
             RGBColor[
             0.919077751071794, 0.7168772792802325, 0.2537462629042957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 327}], {
             RGBColor[
             0.8760266442848789, 0.8098616443810893, 0.6225547619463301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 361}], {
             RGBColor[
             0.9607863993626748, 0.8746946423031299, 0.5220776507438705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 369}], {
             RGBColor[
             0.9533682978701707, 0.8704621014732762, 0.5928452669136579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 392}], {
             RGBColor[
             0.9620460992436524, 0.874571564013132, 0.45438941191744053`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 200}], {
             RGBColor[
             0.9595926347152244, 0.9669582444176816, 0.837534161817628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 219}], {
             RGBColor[
             0.9946957139440888, 0.9917144941674283, 0.7113966084969006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 241}], {
             RGBColor[
             0.9936947803273568, 0.9889220976127415, 0.5550939338171619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 255}], {
             RGBColor[
             0.7434318756869536, 0.7949451808126695, 0.8177878606769668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 339}], {
             RGBColor[
             0.8687664770940061, 0.8951608455469291, 0.8287052489124651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 360}], {
             RGBColor[
             0.9944738211456317, 0.9905883871499226, 0.6398877192037604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 374}], {
             RGBColor[
             0.9340902896293939, 0.7545317156620446, 0.44921433254055154`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 266}], {
             RGBColor[
             0.9896193786537533, 0.9752949417309238, 0.5625314526277975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 273}], {
             RGBColor[
             0.9890795544743455, 0.9750717105598901, 0.5714777363007784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 365}], {
             RGBColor[
             0.9633616329101327, 0.9575135247057505, 0.6876568072636409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 198}], {
             RGBColor[
             0.9713870341321513, 0.9761514262231079, 0.835956243754418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 216}], {
             RGBColor[
             0.9921318113579483, 0.9907824672903862, 0.7632068216226839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 219}], {
             RGBColor[
             0.994770024089096, 0.9918734360536905, 0.7194848091918764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 220}], {
             RGBColor[
             0.9820812798258771, 0.9841271771512683, 0.8178536753009265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 311}], {
             RGBColor[
             0.980145961581393, 0.9431405631997929, 0.509107820948727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 323}], {
             RGBColor[
             0.9776720344946089, 0.9347954262303669, 0.49949708137850035`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 339}], {
             RGBColor[
             0.8688407872390134, 0.8953197874331913, 0.8367934496074408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 357}], {
             RGBColor[
             0.8426024504026526, 0.8748221992778804, 0.834178257402791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 201}], {
             RGBColor[
             0.9543002464260321, 0.965437779127789, 0.9622419417827878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 203}], {
             RGBColor[
             0.8746363106641959, 0.9025150060607365, 0.9670318337296415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 228}], {
             RGBColor[
             0.8307255535108211, 0.8682115888384052, 0.9626552198259493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 243}], {
             RGBColor[
             0.9588522973936191, 0.968832691286116, 0.9545365068596989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 332}], {
             RGBColor[
             0.9494281070884926, 0.9618041455872481, 0.9704892028237888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 348}], {
             RGBColor[
             0.9763006353521377, 0.9788505528868259, 0.7510361303037777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 361}], {
             RGBColor[
             0.9754950683595717, 0.9799449755052578, 0.8681539314504854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 385}], {
             RGBColor[
             0.8373251583031316, 0.8733672502610124, 0.9633130067548334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 232}], {
             RGBColor[
             0.9543320187032351, 0.8479584936675109, 0.32737143025511595`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 235}], {
             RGBColor[
             0.9495920413207717, 0.8575986023038167, 0.5914423737383043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 260}], {
             RGBColor[
             0.9522045323766477, 0.8595469938557274, 0.5870201078274999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 275}], {
             RGBColor[
             0.9525706444074229, 0.8420169645773841, 0.3205288237235108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 281}], {
             RGBColor[
             0.95902148164977, 0.862403375870705, 0.46240522676829476`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 338}], {
             RGBColor[
             0.958760402262077, 0.8627725322420409, 0.50141353207679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 384}], {
             RGBColor[
             0.9337164539363458, 0.8457586152264003, 0.6183156021638085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 376}], {
             RGBColor[
             0.9868667830150321, 0.9888054562041386, 0.8658982294467045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 377}], {
             RGBColor[
             0.9802736059571807, 0.9600670148598415, 0.637674978643615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 396}], {
             RGBColor[
             0.983857978133285, 0.9721579438604511, 0.6515995876958918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 206}], {
             RGBColor[
             0.9686512781069017, 0.9760818356630483, 0.935310857622641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 208}], {
             RGBColor[
             0.9621787978338662, 0.9400769854322288, 0.6545172168123201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 258}], {
             RGBColor[
             0.9487459041408489, 0.9612953597459003, 0.9716439944671245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 278}], {
             RGBColor[
             0.9365913188194076, 0.951836660026784, 0.9785642075581098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 284}], {
             RGBColor[
             0.9306773569171845, 0.8198088782745905, 0.6050853765528725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 327}], {
             RGBColor[
             0.8876262501302693, 0.9127932433754473, 0.9738938755949069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 337}], {
             RGBColor[
             0.9256117140097275, 0.9430818211849782, 0.9775169630497536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 369}], {
             RGBColor[
             0.9649679037155612, 0.9733937004676342, 0.9441843805622347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 392}], {
             RGBColor[
             0.9736457050890428, 0.97750316300749, 0.8057285255660174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 231}], {
             RGBColor[
             0.9563809984141782, 0.9661491131070095, 0.9238320008702192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 234}], {
             RGBColor[
             0.7170752582326289, 0.7751677849164007, 0.902307618582416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 290}], {
             RGBColor[
             0.9804590392992458, 0.9843785427924603, 0.8925068647634797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 303}], {
             RGBColor[
             0.9478994093259066, 0.9593861241946242, 0.9230230193313759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 313}], {
             RGBColor[
             0.943351636917068, 0.95575985392181, 0.9225892487391765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 344}], {
             RGBColor[
             0.973333958588721, 0.9790646692647997, 0.9045677678877274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 204}], {
             RGBColor[
             0.956810585724459, 0.9673099860662526, 0.9579925921518994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 215}], {
             RGBColor[
             0.8325492319362718, 0.8700120040517734, 0.9818570750243986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 295}], {
             RGBColor[
             0.9655539294210214, 0.9723081604513306, 0.8750073861451486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 310}], {
             RGBColor[
             0.9617783431502624, 0.9707468585002305, 0.9375786215556781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 345}], {
             RGBColor[
             0.9651360793417161, 0.9697535292428603, 0.708797658378238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 216}], {
             RGBColor[
             0.9685055974933143, 0.975191726873375, 0.9005620623819186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 219}], {
             RGBColor[
             0.9711438102244622, 0.9762826956366791, 0.8568400499511108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 224}], {
             RGBColor[
             0.9544395408703608, 0.9655416646962958, 0.9620061526223489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 247}], {
             RGBColor[
             0.9460994310192432, 0.9593216244250089, 0.976123783151267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 302}], {
             RGBColor[
             0.8870758696549967, 0.9124831945696912, 0.978307291085724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 311}], {
             RGBColor[
             0.9565197477167591, 0.9275498227827816, 0.6464630617079615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 323}], {
             RGBColor[
             0.9540458206299751, 0.9192046858133556, 0.6368523221377349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 340}], {
             RGBColor[
             0.9663172721691614, 0.9742867981144421, 0.9368282762075338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 212}], {
             RGBColor[
             0.8987534557474421, 0.8898181062879149, 0.6635335390524559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 238}], {
             RGBColor[
             0.9099220886016673, 0.9266662443947169, 0.777182713303114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 252}], {
             RGBColor[
             0.9102753077739101, 0.9274217444882076, 0.8156284403856768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 277}], {
             RGBColor[
             0.909356830797631, 0.9254572151082137, 0.715657889700552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 287}], {
             RGBColor[
             0.8817579384395167, 0.9085070699767707, 0.9869617548801213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 293}], {
             RGBColor[
             0.9019755572373274, 0.9006870111987053, 0.6760507948978501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 299}], {
             RGBColor[
             0.7818360171239789, 0.8295441499011827, 0.978876856942406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 336}], {
             RGBColor[
             0.8726067204482758, 0.9012569288797607, 0.9877112020532137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 367}], {
             RGBColor[
             0.8872866385046134, 0.8489518859366342, 0.6303716010946072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 225}], {
             RGBColor[
             0.9591046427463539, 0.9671165086793202, 0.8717941203337675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 241}], {
             RGBColor[
             0.9584227873358102, 0.9644560591628282, 0.7102034940295578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 255}], {
             RGBColor[
             0.708159882695407, 0.7704791423627562, 0.9728974208893628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 288}], {
             RGBColor[
             0.9454448846051944, 0.9585400482510813, 0.9670588242068732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 296}], {
             RGBColor[
             0.8326261952466834, 0.8700164932436437, 0.983728266206338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 339}], {
             RGBColor[
             0.8334944841024596, 0.8706948070970157, 0.9838148091248611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 355}], {
             RGBColor[
             0.8745443747602506, 0.9028019618319042, 0.9878960172512543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 360}], {
             RGBColor[
             0.9592018281540852, 0.9661223487000093, 0.7949972794161565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 374}], {
             RGBColor[
             0.8988182966378473, 0.7300656772121312, 0.6043238927529475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 375}], {
             RGBColor[
             0.9371935509158691, 0.9523862170959015, 0.9810261798504083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 383}], {
             RGBColor[
             0.9550631068223393, 0.9654452297120045, 0.9387728297543827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 399}], {
             RGBColor[
             0.857254250890172, 0.8892561174924926, 0.9861829606306157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 210}], {
             RGBColor[
             0.9442968126154474, 0.9579772345709745, 0.9791751459107167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 228}], {
             RGBColor[
             0.8260517622710326, 0.8647258829844017, 0.9705667292749269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 236}], {
             RGBColor[
             0.9651183969929951, 0.9541041672578445, 0.6746643541047007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 243}], {
             RGBColor[
             0.9541785061538306, 0.9653469854321126, 0.9624480163086768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 263}], {
             RGBColor[
             0.9551568626283138, 0.9205015727662766, 0.6359656741758315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 348}], {
             RGBColor[
             0.9716268441123492, 0.9753648470328223, 0.7589476397527555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 351}], {
             RGBColor[
             0.8394387114134765, 0.8751838693990606, 0.9719010152572933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 214}], {
             RGBColor[
             0.9919538680768347, 0.9886915379928101, 0.6195161040380368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 217}], {
             RGBColor[
             0.9937702277391334, 0.9890834719976282, 0.5633059189815965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 257}], {
             RGBColor[
             0.993204922967653, 0.9878743422525114, 0.5017759832625988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 264}], {
             RGBColor[
             0.9768613936515178, 0.97860535009144, 0.6974477369843239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 268}], {
             RGBColor[
             0.9885881822167306, 0.9872997403954757, 0.6752942288557592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 279}], {
             RGBColor[
             0.9321385078660296, 0.9435982154450864, 0.7158455417973504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 300}], {
             RGBColor[
             0.9926680808856487, 0.9867260913221649, 0.44334403564173774`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 306}], {
             RGBColor[
             0.9454690430788659, 0.9542276223760633, 0.71711702014626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 363}], {
             RGBColor[
             0.863535862534794, 0.8895880967154913, 0.7091185861564813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 381}], {
             RGBColor[
             0.9892815551610517, 0.9875864679268243, 0.6638032447767015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 243}], {
             RGBColor[
             0.8745145703919944, 0.90242421236506, 0.9672379082555306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 258}], {
             RGBColor[
             0.8675172402907307, 0.897205615032614, 0.9790825629209943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 284}], {
             RGBColor[
             0.8494486930670664, 0.7557191335613043, 0.6125239450067422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 348}], {
             RGBColor[
             0.8919629083505132, 0.9124420739657697, 0.7637375316996093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 361}], {
             RGBColor[
             0.891157341357947, 0.9135364965842017, 0.880855332846317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 369}], {
             RGBColor[
             0.8837392398654429, 0.9093039557543479, 0.9516229490161043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 392}], {
             RGBColor[
             0.8924170412389247, 0.9134134182942037, 0.8131670940198871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 261}], {
             RGBColor[
             0.9696357056433654, 0.9768749395025665, 0.9362830094561834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 295}], {
             RGBColor[
             0.9846134007659563, 0.986522682973363, 0.8427446726644332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 310}], {
             RGBColor[
             0.9808378144951974, 0.9849613810222628, 0.9053159080749626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 345}], {
             RGBColor[
             0.984195550686651, 0.9839680517648928, 0.6765349448975227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 389}], {
             RGBColor[
             0.8205393335380562, 0.8599548987945007, 0.9464976571274539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 400}], {
             RGBColor[
             0.9606227390984579, 0.9701530838107526, 0.9515396108585565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 207}], {
             RGBColor[
             0.9847861040972972, 0.9847372105245238, 0.7016182141877312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 221}], {
             RGBColor[
             0.9872912280689845, 0.968490071254086, 0.43084301380443907`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 230}], {
             RGBColor[
             0.9456281302047908, 0.9545678936522407, 0.7344326720312415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 250}], {
             RGBColor[
             0.9856198219701171, 0.9628520260177914, 0.4243499167288963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 276}], {
             RGBColor[
             0.9469796938501457, 0.8153072181302052, 0.35889164016730885`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 358}], {
             RGBColor[
             0.9699528636941684, 0.9073273934856944, 0.3774249763514385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 391}], {
             RGBColor[
             0.9877449906444855, 0.9869439432666849, 0.6966095910645485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 208}], {
             RGBColor[
             0.9780741645779601, 0.9518728045290243, 0.6249719762172272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 258}], {
             RGBColor[
             0.9646412708849429, 0.9730911788426957, 0.9420987538720317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 278}], {
             RGBColor[
             0.9524866855635016, 0.9636324791235794, 0.9490189669630169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 284}], {
             RGBColor[
             0.9465727236612784, 0.831604697371386, 0.5755401359577798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 369}], {
             RGBColor[
             0.9808632704596552, 0.9851895195644296, 0.9146391399671419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 392}], {
             RGBColor[
             0.9895410718331368, 0.9892989821042854, 0.7761832849709245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 221}], {
             RGBColor[
             0.9790843549504841, 0.9658062700583141, 0.6537542318414515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 230}], {
             RGBColor[
             0.9374212570862903, 0.9518840924564688, 0.9573438900682538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 233}], {
             RGBColor[
             0.9857184759698485, 0.9867314596826544, 0.8031011385827288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 250}], {
             RGBColor[
             0.9774129488516166, 0.9601682248220195, 0.6472611347659087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 358}], {
             RGBColor[
             0.961745990575668, 0.9046435922899224, 0.6003361943884509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 366}], {
             RGBColor[
             0.8992526956874871, 0.5757965315021651, 0.5465796271115833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 391}], {
             RGBColor[
             0.9795381175259851, 0.984260142070913, 0.9195208091015608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[
             0.9581687906119074, 0.9370863286118762, 0.6613051130617109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 278}], {
             RGBColor[
             0.9460142052904661, 0.9276276288927601, 0.6682253261526961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 284}], {
             RGBColor[
             0.940100243388243, 0.7955998471405665, 0.2947464951474589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 369}], {
             RGBColor[
             0.9743907901866196, 0.9491846693336101, 0.633845499156821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 392}], {
             RGBColor[
             0.9830685915601014, 0.953294131873466, 0.4953896441606037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 227}], {
             RGBColor[
             0.9824320339438783, 0.9855268599842884, 0.8746962755697509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 229}], {
             RGBColor[
             0.9540765985685065, 0.9651974523051243, 0.9600711666283235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 240}], {
             RGBColor[
             0.9563843817861821, 0.9669921238669306, 0.9587140442476121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 245}], {
             RGBColor[
             0.9303751169595004, 0.9462985342296824, 0.957810498153894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 280}], {
             RGBColor[
             0.9285556709387968, 0.7686463624662171, 0.5748867163239475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 304}], {
             RGBColor[
             0.852278299101345, 0.8847596128737776, 0.9501669424025231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 315}], {
             RGBColor[
             0.9612020943626981, 0.9705851660182159, 0.950558913516251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 319}], {
             RGBColor[
             0.9849587499747084, 0.9865717219966768, 0.8328220520074194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 329}], {
             RGBColor[
             0.9846136714775364, 0.985255521289109, 0.7532396971161645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 334}], {
             RGBColor[
             0.9827480248434495, 0.9856575303418567, 0.869459488605623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 371}], {
             RGBColor[
             0.9630426084703875, 0.9719578184261652, 0.9474434032148922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 236}], {
             RGBColor[
             0.9597887544221988, 0.9501293285550335, 0.6836860487836519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 263}], {
             RGBColor[
             0.9498272200575175, 0.9165267340634655, 0.6449873688547827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 301}], {
             RGBColor[
             0.9898519321684612, 0.9892251280093654, 0.75631897549688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 328}], {
             RGBColor[
             0.9804864829977258, 0.9847662429284202, 0.9089058390287899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 347}], {
             RGBColor[
             0.9886645762656316, 0.9863294914494325, 0.6573544826205742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 372}], {
             RGBColor[
             0.9892026568748093, 0.9878363938080457, 0.6856493666455115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 387}], {
             RGBColor[
             0.98162731646359, 0.9856170746593182, 0.9069747055481037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 238}], {
             RGBColor[
             0.9826731972200593, 0.9523884840456083, 0.45745021703375915`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 259}], {
             RGBColor[
             0.9831051601464917, 0.9533124090670959, 0.5044667158097574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 293}], {
             RGBColor[
             0.9747266658557194, 0.9264092508495967, 0.3563182986284954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 299}], {
             RGBColor[
             0.8545871257423708, 0.855266389552074, 0.6591443606730514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 336}], {
             RGBColor[
             0.9453578290666678, 0.9269791685306521, 0.6679787057838589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 367}], {
             RGBColor[
             0.9600377471230055, 0.8746741255875254, 0.3106391048252525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 224}], {
             RGBColor[
             0.8595121274663677, 0.8906619165333782, 0.9636027325955226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 230}], {
             RGBColor[
             0.8280846383266576, 0.8662579825322236, 0.9833314961858821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 247}], {
             RGBColor[
             0.8511720176152502, 0.8844418762620914, 0.9777203631244409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 250}], {
             RGBColor[
             0.8680763300919839, 0.8745421148977743, 0.673248740883537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 289}], {
             RGBColor[
             0.7825975734117416, 0.8300904394018864, 0.9789656703937029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 302}], {
             RGBColor[
             0.7921484562510037, 0.8376034464067738, 0.9799038710588979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 340}], {
             RGBColor[
             0.8713898587651683, 0.8994070499515245, 0.9384248561807076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 391}], {
             RGBColor[
             0.8702014987663524, 0.8986340321466678, 0.945508415219189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 215}], {
             RGBColor[
             0.8592901413413705, 0.8887855756885029, 0.8842076800557502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 217}], {
             RGBColor[
             0.9930492928520201, 0.9910345408224975, 0.7387463306388777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 261}], {
             RGBColor[
             0.9773171437035293, 0.9814339886172636, 0.8708963279682503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 264}], {
             RGBColor[
             0.9761404587644045, 0.9805564189163092, 0.872888148641605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 295}], {
             RGBColor[
             0.9922948388261201, 0.99108173208806, 0.7773579911765003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 300}], {
             RGBColor[
             0.9919471459985355, 0.9886771601470342, 0.6187844472990189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 310}], {
             RGBColor[
             0.9885192525553612, 0.98952043013696, 0.8399292265870297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 363}], {
             RGBColor[
             0.8628149276476808, 0.8915391655403606, 0.8845589978137625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 217}], {
             RGBColor[
             0.8611065010036691, 0.8891775096933212, 0.82799749499931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 269}], {
             RGBColor[
             0.6029085162442567, 0.6872054069427376, 0.9627724385176192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 295}], {
             RGBColor[
             0.8603520469777691, 0.8892247009588838, 0.8666091555369324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 300}], {
             RGBColor[
             0.8600043541501845, 0.8868201290178579, 0.7080356116594511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 352}], {
             RGBColor[
             0.8374404975043848, 0.8736599019037596, 0.9735774382639565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 363}], {
             RGBColor[
             0.7308721357993297, 0.7896821344111842, 0.9738101621741947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 219}], {
             RGBColor[
             0.991888587450259, 0.9909137367039575, 0.7840906278193769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 220}], {
             RGBColor[
             0.9791998431870401, 0.9831674778015353, 0.8824594939284269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 311}], {
             RGBColor[
             0.977264524942556, 0.94218086385006, 0.5737136395762275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 323}], {
             RGBColor[
             0.9747905978557719, 0.9338357268806339, 0.5641029000060008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 339}], {
             RGBColor[
             0.8659593506001764, 0.8943600880834582, 0.9013992682349414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 357}], {
             RGBColor[
             0.8397210137638156, 0.8738624999281475, 0.8987840760302914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 268}], {
             RGBColor[
             0.9896836069919159, 0.9896427432251632, 0.7945244554566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 269}], {
             RGBColor[
             0.7366676677549063, 0.7894543720767322, 0.8173110891007467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 279}], {
             RGBColor[
             0.933233932641215, 0.945941218274774, 0.8350757683981912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 300}], {
             RGBColor[
             0.9937635056608342, 0.9890690941518525, 0.5625742622425787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 306}], {
             RGBColor[
             0.9465644678540512, 0.9565706252057508, 0.8363472467471008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 363}], {
             RGBColor[
             0.8646312873099794, 0.8919310995451788, 0.8283488127573222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 262}], {
             RGBColor[
             0.995107214204487, 0.9920521669559919, 0.7167529643790271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 269}], {
             RGBColor[
             0.7368126574283842, 0.7898735064266362, 0.841016639853998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 279}], {
             RGBColor[
             0.9333789223146929, 0.946360352624678, 0.8587813191514425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 298}], {
             RGBColor[
             0.9889673951224314, 0.9729184712441904, 0.5587739793012946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.993908495334312, 0.9894882285017566, 0.58627981299583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 306}], {
             RGBColor[
             0.9467094575275292, 0.9569897595556549, 0.8600527975003521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 314}], {
             RGBColor[
             0.9871813272421051, 0.9881389777807303, 0.8250142567489913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 220}], {
             RGBColor[
             0.9818380559181878, 0.9842584465648396, 0.8387374814976193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 241}], {
             RGBColor[
             0.9935258665646747, 0.989212308912575, 0.5840659407088304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 311}], {
             RGBColor[
             0.9799027376737037, 0.9432718326133642, 0.5299916271454198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 323}], {
             RGBColor[
             0.9774288105869198, 0.9349266956439382, 0.5203808875751932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 339}], {
             RGBColor[
             0.8685975633313241, 0.8954510568467624, 0.8576772558041337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 357}], {
             RGBColor[
             0.8423592264949633, 0.8749534686914516, 0.8550620635994839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 360}], {
             RGBColor[
             0.9943049073829497, 0.9908785984497561, 0.6688597260954291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 350}], {
             RGBColor[
             0.7444159535723531, 0.7987264779859713, 0.9462184058325724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 357}], {
             RGBColor[
             0.8296704822317444, 0.8672072097890295, 0.9534309297085339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 394}], {
             RGBColor[
             0.9821491060063998, 0.9842722504931278, 0.8252361364761669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 230}], {
             RGBColor[
             0.9399263810579777, 0.9356369531860309, 0.6865686896849618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 250}], {
             RGBColor[
             0.9799180728233039, 0.9439210855515816, 0.37648593438261657`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 276}], {
             RGBColor[
             0.9412779447033326, 0.7963762776639955, 0.31102765782102915`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 358}], {
             RGBColor[
             0.9642511145473553, 0.8883964530194846, 0.3295609940051588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 251}], {
             RGBColor[
             0.7654003351612413, 0.8146132647202067, 0.9072687076614175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 297}], {
             RGBColor[
             0.7640641375527888, 0.8002580222715223, 0.6763139486618501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 312}], {
             RGBColor[
             0.7561790983900801, 0.8082804046330592, 0.9472537611728733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 332}], {
             RGBColor[
             0.7416072411115653, 0.7974127373339692, 0.9719201145963401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 356}], {
             RGBColor[
             0.7423644916602439, 0.7979774935532897, 0.9706382869400012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 361}], {
             RGBColor[
             0.7676742023826444, 0.8155535672519788, 0.8695848432230366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 260}], {
             RGBColor[
             0.765246482497735, 0.8152431519097536, 0.937277555281022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 267}], {
             RGBColor[
             0.7433568142729836, 0.7171248461509092, 0.6130453553110127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 272}], {
             RGBColor[
             0.7099807290666672, 0.7723463791268748, 0.9725930423289686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 290}], {
             RGBColor[
             0.7613512950343515, 0.8123381274773464, 0.9438710916289339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 291}], {
             RGBColor[
             0.7585039770272017, 0.7737340866167339, 0.6431706345342241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 321}], {
             RGBColor[
             0.7668003885883753, 0.8017198309026432, 0.675400626803522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 331}], {
             RGBColor[
             0.7720519723902217, 0.8180750234682724, 0.8114153913587152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 342}], {
             RGBColor[
             0.7641479239456059, 0.7927724448342672, 0.665096302542281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 346}], {
             RGBColor[
             0.7639658148888546, 0.8142880321039514, 0.9394453914912493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 384}], {
             RGBColor[
             0.7467584040574332, 0.8014547732804266, 0.9685730496173306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 398}], {
             RGBColor[
             0.7706620468154131, 0.8147461108629122, 0.6904024398025981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 230}], {
             RGBColor[
             0.929690772333494, 0.9461187095853403, 0.9704295843214046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 247}], {
             RGBColor[
             0.9527781516220866, 0.964302603315208, 0.9648184512599633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 289}], {
             RGBColor[
             0.884203707418578, 0.9099511664550031, 0.9660637585292253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 302}], {
             RGBColor[
             0.89375459025784, 0.9174641734598903, 0.9670019591944203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 323}], {
             RGBColor[
             0.9607245412328183, 0.9241856647035547, 0.6255469902464311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 340}], {
             RGBColor[
             0.9729959927720047, 0.9792677770046412, 0.9255229443162301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 288}], {
             RGBColor[
             0.9802288856278704, 0.9831643509626332, 0.8462092225106166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 296}], {
             RGBColor[
             0.8674101962693594, 0.8946407959551956, 0.8628786645100814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 316}], {
             RGBColor[
             0.9931486741045488, 0.9888978651627851, 0.587977099096698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 324}], {
             RGBColor[
             0.9134725389359977, 0.6234163130469306, 0.46511635165370013`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 355}], {
             RGBColor[
             0.9093283757829266, 0.9274262645434561, 0.8670464155549977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 375}], {
             RGBColor[
             0.9719775519385452, 0.9770105198074535, 0.8601765781541517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 380}], {
             RGBColor[
             0.9933262561985413, 0.9893358915042064, 0.602357229453248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 383}], {
             RGBColor[
             0.9898471078450153, 0.9900695324235564, 0.8179232280581261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 390}], {
             RGBColor[
             0.9820549284844977, 0.9514760562510102, 0.5448799922408725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 255}], {
             RGBColor[
             0.7031064962397926, 0.6480298428361773, 0.6014918944085691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 266}], {
             RGBColor[
             0.9546248873787646, 0.8449044203492861, 0.4908820422147281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 294}], {
             RGBColor[
             0.7788984379780821, 0.7095424052990398, 0.6074713333307624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 341}], {
             RGBColor[
             0.8972630890482667, 0.802497381584704, 0.619139418531835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 368}], {
             RGBColor[
             0.9506087653546604, 0.8432436506826908, 0.5574395775447645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 393}], {
             RGBColor[
             0.9520995084948347, 0.8438601112815041, 0.5327341057924991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 399}], {
             RGBColor[
             0.8522008644345576, 0.7668068179659135, 0.6147774341498219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 280}], {
             RGBColor[
             0.9356820743206945, 0.7730696622272858, 0.5228976863714736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 304}], {
             RGBColor[
             0.8594047024832427, 0.8891829126348463, 0.8981779124500491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 315}], {
             RGBColor[
             0.9683284977445958, 0.9750084657792846, 0.898569883563777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 243}], {
             RGBColor[
             0.8306038132386195, 0.8681207951427287, 0.9628612943518382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 332}], {
             RGBColor[
             0.8211796229334931, 0.8610922494438606, 0.9788139903159281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 348}], {
             RGBColor[
             0.8480521511971384, 0.8781386567434384, 0.7593609177959169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 361}], {
             RGBColor[
             0.8472465842045722, 0.8792330793618703, 0.8764787189426246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 385}], {
             RGBColor[
             0.7090766741481322, 0.7726553541176249, 0.9716377942469727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 240}], {
             RGBColor[
             0.9351553497927079, 0.9510860159488352, 0.9920999053537105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 245}], {
             RGBColor[
             0.9091460849660262, 0.9303924263115871, 0.9911963592599925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 248}], {
             RGBColor[
             0.9613754371546929, 0.9634474859691158, 0.7043668570965378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 249}], {
             RGBColor[
             0.7187709558088351, 0.7790319878853056, 0.9738037809069657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 309}], {
             RGBColor[
             0.916276890327187, 0.9360783369460217, 0.9918765018410851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 315}], {
             RGBColor[
             0.939973062369224, 0.9546790581001205, 0.9839447746223495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 319}], {
             RGBColor[
             0.9637297179812343, 0.9706656140785814, 0.8662079131135179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[
             0.9633846394840623, 0.9693494133710138, 0.786625558222263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 334}], {
             RGBColor[
             0.9615189928499752, 0.9697514224237614, 0.9028453497117215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 371}], {
             RGBColor[
             0.9418135764769133, 0.95605171050807, 0.9808292643209907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 388}], {
             RGBColor[
             0.9403141879200723, 0.9549334689774014, 0.983367338044556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 247}], {
             RGBColor[
             0.9213506624823764, 0.9398986693140534, 0.9845472148503229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 250}], {
             RGBColor[
             0.9382549749591101, 0.9299989079497364, 0.680075592609419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 289}], {
             RGBColor[
             0.8527762182788678, 0.8855472324538485, 0.9857925221195849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 358}], {
             RGBColor[
             0.9225880166831615, 0.8744742754176393, 0.6331506522319612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 391}], {
             RGBColor[
             0.9403801436334787, 0.9540908251986298, 0.9523352669450711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 234}], {
             RGBColor[
             0.6858428423026942, 0.7521710552657814, 0.9711983094710751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 290}], {
             RGBColor[
             0.9492266233693112, 0.961381813141841, 0.9613975556521388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 313}], {
             RGBColor[
             0.9121192209871334, 0.9327631242711907, 0.9914799396278355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 331}], {
             RGBColor[
             0.9599273007251814, 0.9671187091327671, 0.8289418553819201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 359}], {
             RGBColor[
             0.7308485292889586, 0.7888928167197269, 0.974690449860126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 235}], {
             RGBColor[
             0.9806100344518573, 0.9718843999519793, 0.6616589351879958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 281}], {
             RGBColor[
             0.9900394747808556, 0.9766891735188676, 0.5326217882179862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 384}], {
             RGBColor[
             0.9647344470674315, 0.9600444128745629, 0.6885321636135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 386}], {
             RGBColor[
             0.9898644314044458, 0.9763147734363271, 0.5135693969382755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 242}], {
             RGBColor[
             0.938923882983299, 0.7764882287121426, 0.45287460456403306`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 317}], {
             RGBColor[
             0.9681214908750065, 0.8983643159045052, 0.4766841268940579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 358}], {
             RGBColor[
             0.9708852355667197, 0.9093216426438249, 0.47890790074643613`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 366}], {
             RGBColor[
             0.9083919406785389, 0.5804745818560677, 0.42515133346956846`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 382}], {
             RGBColor[
             0.9939553262620122, 0.9914023664767314, 0.7232336387919716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 290}], {
             RGBColor[
             0.7099208831877619, 0.7704004849512324, 0.9398731733643356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 313}], {
             RGBColor[
             0.6728134808055841, 0.7417817960805819, 0.9699555573400325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 331}], {
             RGBColor[
             0.7206215605436319, 0.7761373809421585, 0.8074174730941169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 342}], {
             RGBColor[
             0.7127175120990163, 0.7508348023081532, 0.6610983842776826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 346}], {
             RGBColor[
             0.712535403042265, 0.7723503895778374, 0.935447473226651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 275}], {
             RGBColor[
             0.9788486601560451, 0.9659428708618525, 0.6548163286563906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 281}], {
             RGBColor[
             0.9852994973983922, 0.9863292821551733, 0.7966927317011745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 384}], {
             RGBColor[
             0.959994469684968, 0.9696845215108687, 0.9526031070966884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 263}], {
             RGBColor[
             0.9706488044350652, 0.9126536667503355, 0.34047657704876677`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 351}], {
             RGBColor[
             0.854930653220228, 0.8673359633831196, 0.6764119181302286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 246}], {
             RGBColor[
             0.9127904719425985, 0.9323938621181878, 0.9601844006070754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 254}], {
             RGBColor[
             0.7615654383561716, 0.813941432848136, 0.9767946936404968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 286}], {
             RGBColor[
             0.923924245650511, 0.9372946905452847, 0.7350283251779117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 320}], {
             RGBColor[
             0.7519829805838403, 0.8064555440070145, 0.9758396038029099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 343}], {
             RGBColor[
             0.9241747534087308, 0.9378305013098973, 0.762294548705456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 349}], {
             RGBColor[
             0.9228991916389446, 0.9341695986221215, 0.7027595229214513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 252}], {
             RGBColor[
             0.9941950492465272, 0.9899921222459008, 0.60954511836698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 277}], {
             RGBColor[
             0.9932765722702482, 0.988027592865907, 0.5095745676818553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 287}], {
             RGBColor[
             0.9656776799121338, 0.9710774477344639, 0.7808784328614244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 293}], {
             RGBColor[
             0.9858952987099446, 0.9632573889563987, 0.4699674728791534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 299}], {
             RGBColor[
             0.865755758596596, 0.892114527658876, 0.7727935349237093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 336}], {
             RGBColor[
             0.9565264619208931, 0.9638273066374541, 0.7816278800345169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 367}], {
             RGBColor[
             0.9712063799772308, 0.9115222636943274, 0.42428827907591044`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 396}], {
             RGBColor[
             0.9887781020600221, 0.9729817615706257, 0.48116661952247175`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 271}], {
             RGBColor[
             0.881108368608267, 0.9075520716308205, 0.966717394542305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 326}], {
             RGBColor[
             0.8961053175765619, 0.9177654428768373, 0.8978333862834935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 335}], {
             RGBColor[
             0.8964791316942025, 0.9179200246210663, 0.8916383189542623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 337}], {
             RGBColor[
             0.850319787759201, 0.8836299010053699, 0.9855472500255834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 354}], {
             RGBColor[
             0.7754868012304426, 0.8245354501299854, 0.978256935076615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 245}], {
             RGBColor[
             0.9114538681837019, 0.9321870978733933, 0.9898392368792811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 248}], {
             RGBColor[
             0.9636832203723685, 0.965242157530922, 0.7030097347158264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 292}], {
             RGBColor[
             0.9487380006729191, 0.9612894653524591, 0.971657372976775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 304}], {
             RGBColor[
             0.8333570503255465, 0.8706481765174885, 0.9821956811279102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 309}], {
             RGBColor[
             0.9185846735448626, 0.9378730085078277, 0.9905193794603737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 315}], {
             RGBColor[
             0.9422808455868996, 0.9564737296619267, 0.9825876522416381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 319}], {
             RGBColor[
             0.96603750119891, 0.9724602856403876, 0.8648507907328065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 329}], {
             RGBColor[
             0.9656924227017379, 0.9711440849328199, 0.7852684358415516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 334}], {
             RGBColor[
             0.9638267760676509, 0.9715460939855676, 0.9014882273310101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 371}], {
             RGBColor[
             0.944121359694589, 0.9578463820698762, 0.9794721419402793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 388}], {
             RGBColor[
             0.9426219711377479, 0.9567281405392076, 0.9820102156638446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 255}], {
             RGBColor[
             0.7422620283075394, 0.7924429955578162, 0.6904571928888967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 288}], {
             RGBColor[
             0.9795470302173268, 0.9805039014461412, 0.6846185962064071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 339}], {
             RGBColor[
             0.8675966297145921, 0.8926586602920756, 0.701374581124395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 360}], {
             RGBColor[
             0.9933039737662176, 0.9880862018950693, 0.5125570514156903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 374}], {
             RGBColor[
             0.9329204422499797, 0.7520295304071912, 0.3218836647524814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 375}], {
             RGBColor[
             0.9712956965280015, 0.9743500702909615, 0.6985859518499421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 399}], {
             RGBColor[
             0.8913563965023045, 0.9112199706875526, 0.7037427326301495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 256}], {
             RGBColor[
             0.8849237093782889, 0.7370934801936535, 0.6065734031371384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 257}], {
             RGBColor[
             0.9383625439885277, 0.7752875813624052, 0.39177631916589706`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 268}], {
             RGBColor[
             0.9337458032376054, 0.7747129795053695, 0.5652945647590574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 317}], {
             RGBColor[
             0.9121876528974052, 0.6834430345800908, 0.24788588651737703`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 333}], {
             RGBColor[
             0.8812160569398699, 0.5535116819062443, 0.22259610506079894`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 381}], {
             RGBColor[
             0.9344391761819264, 0.774999707036718, 0.5538035806799997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 382}], {
             RGBColor[
             0.9380214882844109, 0.7764810851523172, 0.4944353984152907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 348}], {
             RGBColor[
             0.9761788950799363, 0.9787597591911493, 0.7512422048296667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 351}], {
             RGBColor[
             0.8439907623810634, 0.8785787815573876, 0.9641955803342046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 253}], {
             RGBColor[
             0.9909813712748032, 0.9898203974445281, 0.7469212936555512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 270}], {
             RGBColor[
             0.9947485767867446, 0.9911760616842065, 0.6697931751436232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 308}], {
             RGBColor[
             0.9431430743200057, 0.7961368311875205, 0.43434963356101586`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 397}], {
             RGBColor[
             0.8806908417706092, 0.9041944457924155, 0.8073226873024368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 248}], {
             RGBColor[
             0.9376739555456868, 0.9445485678936738, 0.7021061886221085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 292}], {
             RGBColor[
             0.9227287358462375, 0.9405958757152109, 0.9707538268830571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 304}], {
             RGBColor[
             0.8073477854988648, 0.8499545868802404, 0.9812921350341921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 315}], {
             RGBColor[
             0.9162715807602179, 0.9357801400246786, 0.98168410614792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 319}], {
             RGBColor[
             0.9400282363722282, 0.9517666960031395, 0.8639472446390886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 329}], {
             RGBColor[
             0.9396831578750562, 0.9504504952955718, 0.7843648897478335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 353}], {
             RGBColor[
             0.9047584108622042, 0.9268938140814402, 0.9907778589870471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 371}], {
             RGBColor[
             0.9181120948679072, 0.9371527924326281, 0.9785685958465613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 378}], {
             RGBColor[
             0.9355944109540082, 0.9499331952485897, 0.9374272061913551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 388}], {
             RGBColor[
             0.9166127063110663, 0.9360345509019594, 0.9811066695701265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 254}], {
             RGBColor[
             0.819549422918462, 0.8592717887605055, 0.9509656943148368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 286}], {
             RGBColor[
             0.9819082302128014, 0.9826250464576542, 0.709199325852252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 320}], {
             RGBColor[
             0.8099669651461308, 0.8517858999193839, 0.95001060447725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 343}], {
             RGBColor[
             0.9821587379710212, 0.9831608572222668, 0.7364655493797962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 344}], {
             RGBColor[
             0.964914479669109, 0.9733538569012641, 0.9442748135376551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 349}], {
             RGBColor[
             0.9808831762012349, 0.9794999545344909, 0.6769305235957914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 289}], {
             RGBColor[
             0.8758635975674605, 0.9037311261837162, 0.9801813890581436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 302}], {
             RGBColor[
             0.8854144804067225, 0.9112441331886034, 0.9811195897233386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 340}], {
             RGBColor[
             0.9646558829208871, 0.9730477367333543, 0.9396405748451484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 391}], {
             RGBColor[
             0.9634675229220713, 0.9722747189284975, 0.9467241338836299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 292}], {
             RGBColor[
             0.9749580880349041, 0.9736509353727396, 0.6839243247196024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 304}], {
             RGBColor[
             0.8595771376875314, 0.883009646537769, 0.6944626328707375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 315}], {
             RGBColor[
             0.9685009329488845, 0.9688351996822073, 0.6948546039844654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 319}], {
             RGBColor[
             0.9922575885608949, 0.9848217556606682, 0.5771177424756339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 329}], {
             RGBColor[
             0.9919125100637229, 0.9835055549531004, 0.4975353875843789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 353}], {
             RGBColor[
             0.956987763050871, 0.959948873738969, 0.7039483568235925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 388}], {
             RGBColor[
             0.9688420584997329, 0.9690896105594882, 0.6942771674066719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 270}], {
             RGBColor[
             0.7498709966813588, 0.8002941884184107, 0.828247899985536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 308}], {
             RGBColor[
             0.6982654942146198, 0.6052549579217248, 0.5928043584029287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 309}], {
             RGBColor[
             0.70220027956099, 0.7658189804442982, 0.9722232550136289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 334}], {
             RGBColor[
             0.7474423820837782, 0.7994920659220379, 0.8831921028842653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 386}], {
             RGBColor[
             0.7495365980086045, 0.7995789434702814, 0.7918506681256265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 397}], {
             RGBColor[
             0.6358132616652233, 0.7133125725266198, 0.9657774121443496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 265}], {
             RGBColor[
             0.985885110070048, 0.9634194504388022, 0.4532248892379942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 276}], {
             RGBColor[
             0.9396065386044651, 0.790738232427701, 0.30453456074548635`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 289}], {
             RGBColor[
             0.8927679100441943, 0.8938313648193992, 0.6757097668172396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 391}], {
             RGBColor[
             0.9803718353988049, 0.9623749575641805, 0.642252511642726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 282}], {
             RGBColor[
             0.9055115207893321, 0.9256150109280674, 0.9201888669003628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 312}], {
             RGBColor[
             0.9782471278393556, 0.9827530008780312, 0.8973302129553784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 356}], {
             RGBColor[
             0.9644325211095194, 0.9724500897982618, 0.9207147387225064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 277}], {
             RGBColor[
             0.993629791442491, 0.9887830929593976, 0.5480202947644182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 293}], {
             RGBColor[
             0.9862485178821874, 0.9640128890498891, 0.5084131999617163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 330}], {
             RGBColor[
             0.9846261952919884, 0.9857012892925884, 0.7878471738944954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 386}], {
             RGBColor[
             0.9909460441353839, 0.9897448362654316, 0.7430761525435811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 286}], {
             RGBColor[
             0.8306831966263745, 0.8641726171876024, 0.7258096188856732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 320}], {
             RGBColor[
             0.6587419315597038, 0.7333334706493322, 0.9666208975106714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 343}], {
             RGBColor[
             0.8309337043845942, 0.864708427952215, 0.7530758424132175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 344}], {
             RGBColor[
             0.8136894460826821, 0.8549014276312124, 0.9608851065710764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 349}], {
             RGBColor[
             0.829658142614808, 0.8610475252644392, 0.6935408166292127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 288}], {
             RGBColor[
             0.7292841255769236, 0.7865269846460692, 0.947312523066212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 341}], {
             RGBColor[
             0.6861557164756102, 0.7529336175062709, 0.9707986438719676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 360}], {
             RGBColor[
             0.7430410691258144, 0.7941092850949973, 0.7752509782754953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 374}], {
             RGBColor[
             0.6826575376095765, 0.5580526136071192, 0.5845775916122864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 393}], {
             RGBColor[
             0.7409921359221783, 0.7942963472030711, 0.8843933311326317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 399}], {
             RGBColor[
             0.6410934918619012, 0.7172430538874806, 0.9664366594899545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 261}], {
             RGBColor[
             0.9251293639841086, 0.9424226917082132, 0.9679532911640536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 264}], {
             RGBColor[
             0.9239526790449839, 0.9415451220072588, 0.9699451118374083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 317}], {
             RGBColor[
             0.9141213172699965, 0.8589695673860159, 0.6303829254671632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 333}], {
             RGBColor[
             0.8831497213124613, 0.7290382147121695, 0.6050931440105851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 381}], {
             RGBColor[
             0.9363728405545177, 0.9505262398426432, 0.9363006196297858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 268}], {
             RGBColor[
             0.9891183022204355, 0.9884336134800463, 0.7329945197376022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 338}], {
             RGBColor[
             0.9939709109616812, 0.9904402919009078, 0.6525742347462987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 381}], {
             RGBColor[
             0.9898116751647565, 0.9887203410113949, 0.7215035356585446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 382}], {
             RGBColor[
             0.993393987267241, 0.9902017191269941, 0.6621353533938356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 278}], {
             RGBColor[
             0.9325813115974488, 0.9488460032064314, 0.9853521038075006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 284}], {
             RGBColor[
             0.9266673496952258, 0.8168182214542379, 0.6118732728022633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 369}], {
             RGBColor[
             0.9609578964936023, 0.9704030436472816, 0.9509722768116254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 392}], {
             RGBColor[
             0.9696356978670841, 0.9745125061871374, 0.8125164218154082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 274}], {
             RGBColor[
             0.9940312501948341, 0.9913026647769133, 0.7124459277470481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 299}], {
             RGBColor[
             0.8661877215230285, 0.8930384526803637, 0.8198100336997076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 318}], {
             RGBColor[
             0.9252417313751878, 0.9394612012109687, 0.8256192122733161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 336}], {
             RGBColor[
             0.9569584248473255, 0.9647512316589417, 0.8286443788105151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 367}], {
             RGBColor[
             0.9716383429036632, 0.9124461887158152, 0.4713047778519087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 267}], {
             RGBColor[
             0.9592053709563944, 0.8873029859332622, 0.5926531468795662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 272}], {
             RGBColor[
             0.9258292857500781, 0.9425245189092276, 0.9522008338975221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 291}], {
             RGBColor[
             0.9743525337106126, 0.9439122263990869, 0.6227784261027776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 321}], {
             RGBColor[
             0.9826489452717861, 0.9718979706849962, 0.6550084183720754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 338}], {
             RGBColor[
             0.9876509090665753, 0.98864683007842, 0.8312787710988655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 342}], {
             RGBColor[
             0.9799964806290168, 0.9629505846166202, 0.6447040941108344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 384}], {
             RGBColor[
             0.9626069607408441, 0.9716329130627794, 0.9481808411858841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 398}], {
             RGBColor[
             0.9865106034988239, 0.9849242506452651, 0.6700102313711516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 264}], {
             RGBColor[
             0.9622246692782123, 0.9713478007158936, 0.9488279609145374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 295}], {
             RGBColor[
             0.9783790493399278, 0.9818731138876445, 0.8532978034494325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 310}], {
             RGBColor[
             0.9746034630691689, 0.9803118119365444, 0.915869038859962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 381}], {
             RGBColor[
             0.974644830787746, 0.980328918551278, 0.9151834687069149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 269}], {
             RGBColor[
             0.7367642397715966, 0.7896609298555041, 0.827822357144085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 298}], {
             RGBColor[
             0.9889189774656438, 0.9727058946730582, 0.5455796965913815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 300}], {
             RGBColor[
             0.9938600776775244, 0.9892756519306245, 0.5730855302859169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 306}], {
             RGBColor[
             0.9466610398707416, 0.9567771829845226, 0.846858514790439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 307}], {
             RGBColor[
             0.9068965193851822, 0.9250801350553474, 0.8430630587467599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 314}], {
             RGBColor[
             0.9871329095853175, 0.9879264012095983, 0.8118199740390784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 310}], {
             RGBColor[
             0.9734267781300442, 0.97943424223559, 0.9178608595333166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 333}], {
             RGBColor[
             0.9202450266065649, 0.7579633237198498, 0.5859678137610689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 381}], {
             RGBColor[
             0.9734681458486214, 0.9794513488503235, 0.9171752893802696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 322}], {
             RGBColor[
             0.9590039826325054, 0.8634343740813322, 0.39727676512273624`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 362}], {
             RGBColor[
             0.9923823549984989, 0.9896009339818808, 0.6656385869918435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 273}], {
             RGBColor[
             0.9944960817656724, 0.9919920026129282, 0.7408776990340005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 365}], {
             RGBColor[
             0.9687781602014596, 0.9744338167587885, 0.8570567699968631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 272}], {
             RGBColor[
             0.9039396175253266, 0.8444062131503832, 0.6279686339275128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 291}], {
             RGBColor[
             0.9524628654858611, 0.8457939206402425, 0.29854622613276827`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 321}], {
             RGBColor[
             0.9607592770470347, 0.8737796649261518, 0.33077621840206606`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 331}], {
             RGBColor[
             0.9660108608488811, 0.8901348574917809, 0.4667909829572594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 342}], {
             RGBColor[
             0.9581068124042653, 0.8648322788577758, 0.3204718941408251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 346}], {
             RGBColor[
             0.957924703347514, 0.88634786612746, 0.5948209830897935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 384}], {
             RGBColor[
             0.9407172925160926, 0.873514607303935, 0.6239486412158748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 398}], {
             RGBColor[
             0.9646209352740724, 0.8868059448864207, 0.3457780314011422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 338}], {
             RGBColor[
             0.9893541702107589, 0.989865690043872, 0.8260924803394591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 381}], {
             RGBColor[
             0.9851949344138342, 0.9881457391543592, 0.895021781251705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 279}], {
             RGBColor[
             0.6750359478818025, 0.7439691155241903, 0.9698507119165004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 298}], {
             RGBColor[
             0.7306244206895411, 0.7705272341437026, 0.6698433720663525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 300}], {
             RGBColor[
             0.7355655209014216, 0.7870969914012689, 0.6973492057608879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 306}], {
             RGBColor[
             0.6883664830946388, 0.754598522455167, 0.97112219026541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 307}], {
             RGBColor[
             0.6486019626090794, 0.7229014745259917, 0.9673267342217309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 314}], {
             RGBColor[
             0.7288383528092148, 0.7857477406802427, 0.9360836495140492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 308}], {
             RGBColor[
             0.9434421458533405, 0.7967765149565533, 0.4669017243089552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 397}], {
             RGBColor[
             0.880989913303944, 0.9048341295614484, 0.8398747780503762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 273}], {
             RGBColor[
             0.9770004679705219, 0.9807453692482495, 0.8511710498110989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 326}], {
             RGBColor[
             0.975041627323074, 0.9799353383006215, 0.8836341086564052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 335}], {
             RGBColor[
             0.9754154414407146, 0.9800899200448505, 0.8774390413271739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 394}], {
             RGBColor[
             0.977596789356305, 0.9808771401892215, 0.8329420211304406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 291}], {
             RGBColor[
             0.9190867802795448, 0.9010154536162078, 0.6580939131507242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 321}], {
             RGBColor[
             0.9273831918407183, 0.9290011979021172, 0.690323905420022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 331}], {
             RGBColor[
             0.9326347756425646, 0.9453563904677464, 0.8263386699752153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 338}], {
             RGBColor[
             0.9323851556355074, 0.9457500572955411, 0.8665942581468121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 342}], {
             RGBColor[
             0.924730727197949, 0.9200538118337412, 0.680019581158781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 346}], {
             RGBColor[
             0.9245486181411976, 0.9415693991034253, 0.9543686701077494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 384}], {
             RGBColor[
             0.9073412073097762, 0.9287361402799006, 0.9834963282338307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 398}], {
             RGBColor[
             0.9312448500677561, 0.942027477862386, 0.7053257184190982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 365}], {
             RGBColor[
             0.9682383360220517, 0.9742105855877548, 0.866003053669844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 394}], {
             RGBColor[
             0.9945525789720477, 0.9919005423828664, 0.7315949540263229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 287}], {
             RGBColor[
             0.9654351371062508, 0.9722195653374793, 0.8752084705480572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 299}], {
             RGBColor[
             0.865513215790713, 0.8932566452618914, 0.8671235726103419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 318}], {
             RGBColor[
             0.9245672256428724, 0.9396793937924963, 0.8729327511839505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 367}], {
             RGBColor[
             0.9709638371713478, 0.9126643812973428, 0.5186183167625431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 373}], {
             RGBColor[
             0.7348663569297644, 0.7886516778323089, 0.8558403372363701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 395}], {
             RGBColor[
             0.9583353850173341, 0.8625967766888947, 0.5084571677315535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 279}], {
             RGBColor[
             0.9267147380054037, 0.925408597428826, 0.685759084927771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 281}], {
             RGBColor[
             0.9882781004850434, 0.9707476444287408, 0.5257791816863812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 306}], {
             RGBColor[
             0.94004527321824, 0.9360380043598029, 0.6870305632766807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 338}], {
             RGBColor[
             0.9880170210973505, 0.9711168008000768, 0.5647874869948764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 384}], {
             RGBColor[
             0.9629730727716193, 0.9541028837844362, 0.681689557081895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 322}], {
             RGBColor[
             0.9127254111669225, 0.6907531560702309, 0.2485864366302284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 358}], {
             RGBColor[
             0.9239395803285164, 0.735213599895604, 0.2576096203680286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 376}], {
             RGBColor[
             0.9453491971468737, 0.8166076751081655, 0.5294537077230254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 377}], {
             RGBColor[
             0.9387560200890224, 0.7878692337638684, 0.30123045691993594`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 287}], {
             RGBColor[
             0.9651124221080976, 0.9698684184479607, 0.7193536092588626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 330}], {
             RGBColor[
             0.9837077183157092, 0.9837367599125946, 0.6878766232093706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 396}], {
             RGBColor[
             0.9882128442559858, 0.9717727322841224, 0.4196417959199099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 284}], {
             RGBColor[
             0.9145127643737845, 0.8073595217351217, 0.6187934858932486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 327}], {
             RGBColor[
             0.8714616575868692, 0.9003438868359785, 0.9876019849352831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 337}], {
             RGBColor[
             0.9094471214663274, 0.9306324646455093, 0.9912250723901297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 354}], {
             RGBColor[
             0.8346141349375689, 0.8715380137701249, 0.9839347574411612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 392}], {
             RGBColor[
             0.9574811125456428, 0.9650538064680211, 0.8194366349063934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 300}], {
             RGBColor[
             0.9321317857877304, 0.9435838375993106, 0.7151138850583323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 306}], {
             RGBColor[
             0.8849327479809475, 0.9110853686532089, 0.9888868695628545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 363}], {
             RGBColor[
             0.8029995674368756, 0.8464458429926369, 0.9808884355730759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 384}], {
             RGBColor[
             0.9694239100139663, 0.9744892950777571, 0.8235659601266789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 386}], {
             RGBColor[
             0.9945538943509807, 0.9907596556395212, 0.6486031934514543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 350}], {
             RGBColor[
             0.6716186362289422, 0.7415424646002406, 0.9691815192076392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 369}], {
             RGBColor[
             0.942889349269938, 0.8289165621759718, 0.5844136588973734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 392}], {
             RGBColor[
             0.9515671506434197, 0.8330260247158277, 0.44595780390115614`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 330}], {
             RGBColor[
             0.9805316720063679, 0.9846410790873998, 0.9017150138677679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 387}], {
             RGBColor[
             0.9821054350299738, 0.9858147889736046, 0.8990510435719372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 320}], {
             RGBColor[
             0.8211007388540432, 0.8566867283464807, 0.7248545290480863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 343}], {
             RGBColor[
             0.9932925116789336, 0.9880616856493636, 0.5113094739506325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 349}], {
             RGBColor[
             0.9920169499091473, 0.9844007829615878, 0.4517744481666278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 367}], {
             RGBColor[
             0.94304222981508, 0.8933630892763812, 0.6340673206529178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 373}], {
             RGBColor[
             0.7069447495734967, 0.7693503858113473, 0.9712893411267447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 395}], {
             RGBColor[
             0.9304137776610664, 0.843295484667933, 0.6239061716219282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 396}], {
             RGBColor[
             0.9606139518978714, 0.9548225871526794, 0.6909456610994791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 341}], {
             RGBColor[
             0.9234407183853977, 0.940994523394596, 0.9649600471894779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 355}], {
             RGBColor[
             0.8956686176417671, 0.9188498041152172, 0.9623111194281034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 360}], {
             RGBColor[
             0.9803260710356017, 0.9821701909833224, 0.7694123815930056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 374}], {
             RGBColor[
             0.9199425395193639, 0.7461135194954442, 0.5787389949297967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 375}], {
             RGBColor[
             0.9583177937973857, 0.9684340593792146, 0.9554412820272574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 379}], {
             RGBColor[
             0.9628908504726494, 0.9243322324231721, 0.6187614528199405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 393}], {
             RGBColor[
             0.9782771378319657, 0.9823572530913961, 0.8785547344501421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 399}], {
             RGBColor[
             0.8783784937716885, 0.9053039597758056, 0.9605980628074648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 302}], {
             RGBColor[
             0.816840036203214, 0.8568926963283985, 0.9823648969926005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 340}], {
             RGBColor[
             0.8960814387173787, 0.9186962998731494, 0.9408858821144104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 391}], {
             RGBColor[
             0.8948930787185627, 0.9179232820682925, 0.9479694411528918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 313}], {
             RGBColor[
             0.9361972618722011, 0.9509925539566415, 0.9601548035210961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 321}], {
             RGBColor[
             0.9787537578084027, 0.9689929462525888, 0.6616019547199873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 331}], {
             RGBColor[
             0.984005341610249, 0.985348138818218, 0.7976167192751806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 342}], {
             RGBColor[
             0.9761012931656333, 0.9600455601842128, 0.6512976304587463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 346}], {
             RGBColor[
             0.9759191841088819, 0.981561147453897, 0.9256467194077147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 321}], {
             RGBColor[
             0.9759064398012529, 0.9303889053919765, 0.36090149762527746`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 331}], {
             RGBColor[
             0.9811580236030992, 0.9467440979576056, 0.4969162621804708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 338}], {
             RGBColor[
             0.980908403596042, 0.9471377647854002, 0.5371718503520676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 342}], {
             RGBColor[
             0.9732539751584836, 0.9214415193236005, 0.3505971733640365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 384}], {
             RGBColor[
             0.9558644552703108, 0.9301238477697598, 0.6540739204390862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 398}], {
             RGBColor[
             0.9797680980282907, 0.9434151853522453, 0.37590331062435356`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 304}], {
             RGBColor[
             0.8446319179880821, 0.8790569543593061, 0.9631102711316861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 329}], {
             RGBColor[
             0.9769672903642735, 0.9795528627746375, 0.7661830258453275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 353}], {
             RGBColor[
             0.9420425433514215, 0.955996181560506, 0.9725959950845411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 378}], {
             RGBColor[
             0.9728785434432256, 0.9790355627276555, 0.919245342288849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 388}], {
             RGBColor[
             0.9538968388002835, 0.9651369183810252, 0.9629248056676205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 299}], {
             RGBColor[
             0.8578092272322562, 0.8661352944628644, 0.6716616165184455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 330}], {
             RGBColor[
             0.9763264447554056, 0.9589665560030862, 0.6482695284066686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 336}], {
             RGBColor[
             0.9485799305565531, 0.9378480734414425, 0.6804959616292532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 341}], {
             RGBColor[
             0.7619476582138999, 0.8144461799691334, 0.9767780827941609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 368}], {
             RGBColor[
             0.8152933345202935, 0.8551924490671203, 0.9150782418070904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 393}], {
             RGBColor[
             0.8167840776604678, 0.8558089096659336, 0.8903727700548251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 310}], {
             RGBColor[
             0.9895811581917597, 0.9899595554073408, 0.8223307020682119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 345}], {
             RGBColor[
             0.9929388943832134, 0.9889662261499708, 0.593549738890772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 363}], {
             RGBColor[
             0.8638768332840794, 0.8919782908107414, 0.8669604732949447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 316}], {
             RGBColor[
             0.8666702266048784, 0.8917978497271086, 0.6999112449692687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 324}], {
             RGBColor[
             0.7869940914363273, 0.5263162976112541, 0.5770504975262707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 360}], {
             RGBColor[
             0.8675073816770908, 0.8936466359758848, 0.7860818235924705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 374}], {
             RGBColor[
             0.8071238501608529, 0.6575899644880068, 0.5954084369292616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 375}], {
             RGBColor[
             0.8454991044388748, 0.879910504371777, 0.9721107240267223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 380}], {
             RGBColor[
             0.8668478086988709, 0.8922358760685299, 0.7142913753258187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 383}], {
             RGBColor[
             0.863368660345345, 0.89296951698788, 0.9298573739306968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 390}], {
             RGBColor[
             0.8555764809848273, 0.8543760408153337, 0.6568141381134431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 307}], {
             RGBColor[
             0.9017651058081384, 0.9093480278968225, 0.6890015386345969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 314}], {
             RGBColor[
             0.9820014960082737, 0.9721942940510733, 0.6577584539269152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 332}], {
             RGBColor[
             0.9623390729523881, 0.9575300911302568, 0.6910418073792779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 352}], {
             RGBColor[
             0.9661648074546807, 0.9603833176580013, 0.6845658367782592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 385}], {
             RGBColor[
             0.8502361241670271, 0.8690931958040209, 0.6838656113103225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 306}], {
             RGBColor[
             0.940521220788686, 0.9376434872727213, 0.6888795297127066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 307}], {
             RGBColor[
             0.9007567003031267, 0.9059464393435459, 0.6850840736690273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 314}], {
             RGBColor[
             0.980993090503262, 0.9687927054977967, 0.6538409889613457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 336}], {
             RGBColor[
             0.8284403904432045, 0.8667052121439198, 0.983322023673809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 367}], {
             RGBColor[
             0.8431203084995422, 0.8144001692007933, 0.6259824227152027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 306}], {
             RGBColor[
             0.9454623210005666, 0.9542132445302874, 0.7163853634072419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 307}], {
             RGBColor[
             0.9056978005150074, 0.9225161966011122, 0.7125899073635628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 314}], {
             RGBColor[
             0.9859341907151427, 0.985362462755363, 0.6813468226558812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 363}], {
             RGBColor[
             0.8635291404564948, 0.8895737188697155, 0.7083869294174634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 316}], {
             RGBColor[
             0.9933547920311143, 0.9881367008264935, 0.5230368906006122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 324}], {
             RGBColor[
             0.9136786568625632, 0.6226551487106391, 0.4001761431576143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 372}], {
             RGBColor[
             0.9936516043285091, 0.9888297485169695, 0.5503944927939706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 380}], {
             RGBColor[
             0.993532374125107, 0.9885747271679148, 0.5374170209571622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 383}], {
             RGBColor[
             0.990053225771581, 0.989308368087265, 0.7529830195620403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 390}], {
             RGBColor[
             0.9822610464110633, 0.9507148919147186, 0.47993978374478663`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 323}], {
             RGBColor[
             0.8933608700174542, 0.8711271945769502, 0.6418481287098063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 340}], {
             RGBColor[
             0.9056323215566406, 0.9262093068780366, 0.9418240827796054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 313}], {
             RGBColor[
             0.9036376318988617, 0.9260001353588054, 0.9906709580889923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 344}], {
             RGBColor[
             0.9336199535705147, 0.9493049507017954, 0.9726494772375431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 315}], {
             RGBColor[
             0.8381747629020625, 0.8742412186687738, 0.9740405503965491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 329}], {
             RGBColor[
             0.8615863400169008, 0.888911573939667, 0.7767213339964626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 353}], {
             RGBColor[
             0.8266615930040488, 0.8653548927255355, 0.9831343032356761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 378}], {
             RGBColor[
             0.8574975930958528, 0.8883942738926849, 0.9297836504399841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 325}], {
             RGBColor[
             0.9042487112663751, 0.9050180105233749, 0.6799725771915154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 314}], {
             RGBColor[
             0.8989706324228004, 0.921166945880086, 0.9513243511167242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 352}], {
             RGBColor[
             0.8831339438692075, 0.9093559694870139, 0.9781317339680682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 385}], {
             RGBColor[
             0.7672052605815539, 0.8180658476330336, 0.9774315085001314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 386}], {
             RGBColor[
             0.9431077471805862, 0.796061270008424, 0.43050449244904576`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 397}], {
             RGBColor[
             0.829384410837205, 0.7097948990647625, 0.604431236467769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 319}], {
             RGBColor[
             0.947159041733389, 0.9574526066375739, 0.8646273872201811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 329}], {
             RGBColor[
             0.9468139632362171, 0.9561364059300064, 0.7850450323289262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 334}], {
             RGBColor[
             0.9449483166021301, 0.956538414982754, 0.9012648238183847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 371}], {
             RGBColor[
             0.9252429002290681, 0.9428387030670626, 0.9792487384276539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 386}], {
             RGBColor[
             0.9470425325269564, 0.9566252925309975, 0.8099233890597459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 345}], {
             RGBColor[
             0.9891633081124545, 0.9874049241988707, 0.6561209743013015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 363}], {
             RGBColor[
             0.8601012470133205, 0.8904169888596414, 0.9295317087054742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 323}], {
             RGBColor[
             0.9628047480792167, 0.8861938227900406, 0.3100038993320438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 339}], {
             RGBColor[
             0.8539735008236211, 0.8467181839928649, 0.6473002675609842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 327}], {
             RGBColor[
             0.8957612399829626, 0.9188603054877628, 0.9601234597194572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 356}], {
             RGBColor[
             0.9552112843383582, 0.9661172297111142, 0.9606997922339622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 361}], {
             RGBColor[
             0.9805209950607585, 0.9836933034098033, 0.8596463485169975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 344}], {
             RGBColor[
             0.9290721811616762, 0.9456786804289811, 0.9722157066453438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 359}], {
             RGBColor[
             0.7178191677918485, 0.7785035575345274, 0.9734476977290833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 385}], {
             RGBColor[
             0.8474416507816892, 0.8809121137872844, 0.9461884237924498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 319}], {
             RGBColor[
             0.9708552137754259, 0.9760533277916729, 0.8566956600014455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 329}], {
             RGBColor[
             0.9705101352782539, 0.9747371270841052, 0.7771133051101905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 334}], {
             RGBColor[
             0.968644488644167, 0.9751391361368529, 0.8933330965996491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 371}], {
             RGBColor[
             0.948939072271105, 0.9614394242211615, 0.9713170112089182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 324}], {
             RGBColor[
             0.9127325692715166, 0.6205733668188436, 0.3021489321128873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 355}], {
             RGBColor[
             0.9085884061184455, 0.9245833183153691, 0.7040789960141849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 380}], {
             RGBColor[
             0.9925862865340602, 0.9864929452761193, 0.43938980991243515`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 383}], {
             RGBColor[
             0.9891071381805343, 0.9872265861954694, 0.6549558085173133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 390}], {
             RGBColor[
             0.9813149588200166, 0.948633110022923, 0.3819125727000596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 333}], {
             RGBColor[
             0.9104136648315775, 0.6753877690986068, 0.24640562739082383`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 370}], {
             RGBColor[
             0.8237411629985962, 0.7878233913701213, 0.6215181117606294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 381}], {
             RGBColor[
             0.963636784073634, 0.8968757942290806, 0.5776131030100247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 382}], {
             RGBColor[
             0.9672190961761185, 0.8983571723446797, 0.5182449207453156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 367}], {
             RGBColor[
             0.9021743183517015, 0.8608229177313982, 0.6317916012888112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 373}], {
             RGBColor[
             0.6660768381101183, 0.7368102142663642, 0.9690136217626382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 329}], {
             RGBColor[
             0.9942667908902643, 0.9907236830625661, 0.6593764436013589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 334}], {
             RGBColor[
             0.9924011442561773, 0.9911256921153138, 0.7755962350908175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 371}], {
             RGBColor[
             0.9726957278831153, 0.9774259801996223, 0.8535801497000868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 388}], {
             RGBColor[
             0.9711963393262744, 0.9763077386689538, 0.856118223423652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 343}], {
             RGBColor[
             0.821351246612263, 0.8572225391110934, 0.7521207525756306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 349}], {
             RGBColor[
             0.8200756848424767, 0.8535616364233176, 0.6925857267916259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 331}], {
             RGBColor[
             0.9894544351642727, 0.9747298422435149, 0.5291462544497686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 338}], {
             RGBColor[
             0.9892048151572155, 0.9751235090713096, 0.5694018426213654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 342}], {
             RGBColor[
             0.9815503867196571, 0.9494272636095098, 0.3828271656333343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 384}], {
             RGBColor[
             0.9641608668314843, 0.958109592055669, 0.686303912708384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 398}], {
             RGBColor[
             0.9880645095894642, 0.9714009296381547, 0.4081333028936514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 328}], {
             RGBColor[
             0.9500271965650209, 0.859806800078373, 0.5921672088928585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 362}], {
             RGBColor[
             0.9578627842153449, 0.8644794475008957, 0.5264584109456651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 364}], {
             RGBColor[
             0.9444672551521378, 0.8556602048762132, 0.6015787394399048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 340}], {
             RGBColor[
             0.972602272531619, 0.932930798121701, 0.6003691138316161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 375}], {
             RGBColor[
             0.891561447105513, 0.6086860214635119, 0.574348411170341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 380}], {
             RGBColor[
             0.9129101513655091, 0.621011393160265, 0.31652906246943724`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 383}], {
             RGBColor[
             0.9094310030119832, 0.6217450340796149, 0.5320950610743154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 390}], {
             RGBColor[
             0.9016388236514655, 0.5831515579070687, 0.2590518252570617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 335}], {
             RGBColor[
             0.9904123904090094, 0.9903032912908672, 0.8085550330683624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 337}], {
             RGBColor[
             0.9442530464740081, 0.9560131676751709, 0.9024639641396837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 354}], {
             RGBColor[
             0.8694200599452495, 0.8969187167997864, 0.8951736491907152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 337}], {
             RGBColor[
             0.8604820527771891, 0.8915890479941726, 0.9865547404269268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 354}], {
             RGBColor[
             0.7856490662484306, 0.8324945971187883, 0.9792644254779584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 356}], {
             RGBColor[
             0.8819466332531265, 0.9085573944079934, 0.9835079854865851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 392}], {
             RGBColor[
             0.9085160438565045, 0.9260103898166845, 0.8147663029431906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 347}], {
             RGBColor[
             0.9837480745485961, 0.9828639610774113, 0.6746864723009434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 362}], {
             RGBColor[
             0.9834055689310144, 0.9859733599789215, 0.8605290307619657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 372}], {
             RGBColor[
             0.9842861551577737, 0.9843708634360244, 0.7029813563258805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 387}], {
             RGBColor[
             0.9767108147465544, 0.9821515442872969, 0.9243066952284728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 334}], {
             RGBColor[
             0.9920560657590054, 0.9898094914077461, 0.6960138801995626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 353}], {
             RGBColor[
             0.9589969653802404, 0.9658508011408669, 0.7862070579493174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 371}], {
             RGBColor[
             0.9723506493859433, 0.9761097794920547, 0.7739977948088317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 388}], {
             RGBColor[
             0.9708512608291023, 0.974991537961386, 0.776535868532397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 342}], {
             RGBColor[
             0.9868019705215034, 0.9657824561751389, 0.5188419301885276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 346}], {
             RGBColor[
             0.9866198614647521, 0.9872980434448231, 0.793191019137496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 361}], {
             RGBColor[
             0.9659491377822437, 0.9728256361107133, 0.8843127019404643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 385}], {
             RGBColor[
             0.8277792277258036, 0.8662479108664678, 0.9794717772448124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 381}], {
             RGBColor[
             0.9326651881160988, 0.766944441555234, 0.5523233215534465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 371}], {
             RGBColor[
             0.9704850027518563, 0.9765117885448024, 0.8902175862982904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 388}], {
             RGBColor[
             0.9689856141950153, 0.9753935470141337, 0.8927556600218556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 337}], {
             RGBColor[
             0.9446268605916488, 0.9561677494193999, 0.8962688968104523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 354}], {
             RGBColor[
             0.8697938740628901, 0.8970732985440154, 0.8889785818614839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 367}], {
             RGBColor[
             0.9338910118238393, 0.8861129481793713, 0.6348167678260102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 354}], {
             RGBColor[
             0.8236345301278888, 0.862783174928319, 0.9828875129328051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 384}], {
             RGBColor[
             0.9691628306262734, 0.974858451449093, 0.8625742654351741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 398}], {
             RGBColor[
             0.9930664733842534, 0.9881497890315785, 0.5844036556204415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 360}], {
             RGBColor[
             0.8683756705328669, 0.8943249498292568, 0.7861683665109935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 374}], {
             RGBColor[
             0.8079921390166291, 0.6582682783413787, 0.5954949798477847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 368}], {
             RGBColor[
             0.9336579855904781, 0.9481474253527844, 0.9267463270081631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 379}], {
             RGBColor[
             0.9197624413713363, 0.8907388652833736, 0.6422475736256961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 393}], {
             RGBColor[
             0.9351487287306524, 0.9487638859515977, 0.9020408552558976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 399}], {
             RGBColor[
             0.8352500846703754, 0.8717105926360071, 0.9840841836132204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 346}], {
             RGBColor[
             0.9787158130201363, 0.961995464810818, 0.6468719303210617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 398}], {
             RGBColor[
             0.9854120449466949, 0.9624535435697787, 0.3978289786324105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 349}], {
             RGBColor[
             0.9922674576673671, 0.9849365937262005, 0.4790406716941721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 349}], {
             RGBColor[
             0.975023199365455, 0.9751295934051978, 0.686849935852031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 362}], {
             RGBColor[
             0.9915836621989202, 0.987536608499934, 0.6089776743537499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 372}], {
             RGBColor[
             0.9924642484256796, 0.9859341119570367, 0.4514299999176648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 387}], {
             RGBColor[
             0.9848889080144603, 0.9837147928083092, 0.672755338820257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 351}], {
             RGBColor[
             0.8614391003395823, 0.8885966431580974, 0.7606952037782833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 369}], {
             RGBColor[
             0.9854035645533847, 0.9856395025804372, 0.7356272455902405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 357}], {
             RGBColor[
             0.6049371241491286, 0.6894215001125834, 0.9625429879344369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 394}], {
             RGBColor[
             0.7574157479237841, 0.8064865408166817, 0.8343481947020701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 378}], {
             RGBColor[
             0.9549082184591924, 0.9653335010938848, 0.9392693743928391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 375}], {
             RGBColor[
             0.8874172839524419, 0.9126959729600375, 0.9762784750716385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 379}], {
             RGBColor[
             0.8919903406277057, 0.868594146003995, 0.6395986458643215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 366}], {
             RGBColor[
             0.8844194552843583, 0.49838671446333577`, 0.2223863892752906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 391}], {
             RGBColor[
             0.9647048771228564, 0.9068503250320834, 0.5953275712652681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 374}], {
             RGBColor[
             0.9336994830682547, 0.7536958199443724, 0.40667745013907997`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 375}], {
             RGBColor[
             0.9720747373462766, 0.9760163598281426, 0.7833797372365408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 369}], {
             RGBColor[
             0.9845979975608187, 0.9867339251988692, 0.8527450467369482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 385}], {
             RGBColor[
             0.8538461889968827, 0.8843887407844775, 0.8771365058715089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 377}], {
             RGBColor[
             0.9704978640742375, 0.9527762825698507, 0.6542227597296124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 387}], {
             RGBColor[
             0.9711508733336713, 0.9780049490851372, 0.9337182257755192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 382}], {
             RGBColor[
             0.9074895459796508, 0.5804674382962423, 0.46671212732082606`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 393}], {
             RGBColor[
             0.9884944050370461, 0.9895101550495846, 0.8403410142688272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 399}], {
             RGBColor[
             0.8885957609767691, 0.9124568617339941, 0.92238434262615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 392}], {
             RGBColor[
             0.9858576974417963, 0.9866108469088712, 0.7850568079105182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 389}], {
             RGBColor[
             0.6856528376073991, 0.7543564749842528, 0.9693031251287904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 391}], {
             RGBColor[
             0.8442970346406266, 0.8783972678904315, 0.9429265003261175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 400}], {
             RGBColor[
             0.8257362431678008, 0.8645546600005047, 0.9743450788598931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 395}], {
             RGBColor[
             0.69984499748458, 0.6597275971627625, 0.604538038310241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 375}], {
             RGBColor[
             0.9116912058300386, 0.7399596883402646, 0.5927063505733317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 399}], {
             RGBColor[
             0.8317519058043416, 0.6768295887368556, 0.5978631313535392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 379}], {
             RGBColor[
             0.9546395167833244, 0.9181784012679923, 0.6327288084634755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 383}], {
             RGBColor[
             0.9679360160145307, 0.9753392408401378, 0.9271552875747668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 399}], {
             RGBColor[
             0.8701271600823635, 0.8991501286206258, 0.974565418451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 377}], {
             RGBColor[
             0.9831388067514023, 0.9612834843319191, 0.5916078804590624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 393}], {
             RGBColor[
             0.9745988608179043, 0.9321015949801739, 0.5558422608863602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 399}], {
             RGBColor[
             0.8747002167576272, 0.8550483016645833, 0.637885589243683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 383}], {
             RGBColor[
             0.9892847202745267, 0.9876646125368908, 0.6693359388738632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 390}], {
             RGBColor[
             0.9814925409140092, 0.9490711363643445, 0.3962927030566096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 390}], {
             RGBColor[
             0.9780133925604833, 0.9498047772836945, 0.6118587016614877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 398}], {
             RGBColor[
             0.9680225250585222, 0.971135872015938, 0.7013057257074602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 400}], {
             RGBColor[
             0.8052920155671202, 0.8485834740169684, 0.9723073893148264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 399}], {
             RGBColor[
             0.8900865041169433, 0.9130733223328074, 0.8976788708738845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 396}], {
             RGBColor[
             0.9535141998089546, 0.8451997985040947, 0.3241943582829754]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.03217915333176364], {
             RGBColor[
             0.9565833664694015, 0.865207641770265, 0.28583500658724703`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.03217915333176364], {
             RGBColor[
             0.933239648228134, 0.9496039796544395, 0.9934944248325102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.03217915333176364], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.03217915333176364], {
             RGBColor[
             0.9609992008336045, 0.9704338483564254, 0.9509023593378991]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.03217915333176364], {
             RGBColor[
             0.9764999235824199, 0.981994262002388, 0.9246636789601277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.03217915333176364], {
             RGBColor[
             0.9010564938772713, 0.9239420059635144, 0.9904247668402838]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.03217915333176364], {
             RGBColor[
             0.9946129130704702, 0.9908858907128012, 0.6550270168465631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.03217915333176364], {
             RGBColor[
             0.9935158032302192, 0.991586632246509, 0.7571234512459888]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.03217915333176364], {
             RGBColor[
             0.9941579508736005, 0.9918521767994889, 0.7464814029703314]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.03217915333176364], {
             RGBColor[
             0.52725584759805, 0.627089075542173, 0.9559266582061784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.03217915333176364], {
             RGBColor[
             0.9453754211275218, 0.9587816590332203, 0.9773493430459291]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.03217915333176364], {
             RGBColor[
             0.9935791135697694, 0.9916128126989145, 0.7560742350777349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.03217915333176364], {
             RGBColor[
             0.8903381711449719, 0.9153955063578989, 0.9894024436497174]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.03217915333176364], {
             RGBColor[
             0.858035974250634, 0.8896386113741305, 0.9863214312734239]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.03217915333176364], {
             RGBColor[
             0.9930023290348572, 0.9874410143156499, 0.47972488394260204`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.03217915333176364], {
             RGBColor[
             0.6487159416569097, 0.725501091136924, 0.9656216005353634]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.03217915333176364], {
             RGBColor[
             0.9951268066127613, 0.9919850570371549, 0.7109611575416359]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.03217915333176364], {
             RGBColor[
             0.9942613079171895, 0.9901338428426679, 0.616756965767439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.03217915333176364], {
             RGBColor[
             0.9950610838039037, 0.9918444825946036, 0.703807635391636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.03217915333176364], {
             RGBColor[
             0.9094956729559462, 0.9306711782854362, 0.991229703274552]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.03217915333176364], {
             RGBColor[
             0.8396216655904651, 0.8749555414916046, 0.9845650580747696]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.03217915333176364], {
             RGBColor[
             0.9947283309067146, 0.9911327577939948, 0.667589536045451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.03217915333176364], {
             RGBColor[
             0.9951268066127613, 0.9919850570371549, 0.7109611575416359]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.03217915333176364], {
             RGBColor[
             0.9879958679599541, 0.9893039971563886, 0.8486030638088397]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.03217915333176364], {
             RGBColor[
             0.9869267965107631, 0.9888619086382651, 0.8663203443901576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.03217915333176364], {
             RGBColor[
             0.9926639402283325, 0.9867172348748501, 0.442893350646033]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.03217915333176364], {
             RGBColor[
             0.99454826841877, 0.9907476223393914, 0.647990845449543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.03217915333176364], {
             RGBColor[
             0.4960785330873142, 0.6017779271003448, 0.9534722658016273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.03217915333176364], {
             RGBColor[
             0.8421821020137752, 0.8769971639943569, 0.9848092747865534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.03217915333176364], {
             RGBColor[
             0.9659065017477823, 0.8966567662405075, 0.3220536266173901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.03217915333176364], {
             RGBColor[
             0.9858803157801309, 0.9884291619628206, 0.8836632383020504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.03217915333176364], {
             RGBColor[
             0.9622566971705807, 0.8843451183867388, 0.307874825042723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.03217915333176364], {
             RGBColor[
             0.7033006226999979, 0.7681430588267255, 0.9710620914188923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.03217915333176364], {
             RGBColor[
             0.8830509007993093, 0.5618432793332868, 0.22412714375325363`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.03217915333176364], {
             RGBColor[
             0.9328475665750322, 0.9492913443870291, 0.9934570277344219]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.03217915333176364], {
             RGBColor[
             0.9928033369614125, 0.9870153903917367, 0.4580658247848779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.03217915333176364], {
             RGBColor[
             0.976141930698365, 0.9817272714956193, 0.9252696675333348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.03217915333176364], {
             RGBColor[
             0.9792639714615905, 0.9417146480682189, 0.37394487410903743`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.03217915333176364], {
             RGBColor[
             0.9943788509745709, 0.9903852555569806, 0.6295508021717436]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.03217915333176364], {
             RGBColor[
             0.9413027303309515, 0.9557442529055573, 0.9842433462366427]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.03217915333176364], {
             RGBColor[
             0.9127547460405782, 0.6918086713479827, 0.24865862463617577`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.03217915333176364], {
             RGBColor[
             0.9907470976972217, 0.990441701356128, 0.8030080671079909]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.03217915333176364], {
             RGBColor[
             0.9788284892347989, 0.983730902453256, 0.9207220246978387]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.03217915333176364], {
             RGBColor[
             0.9473774771888442, 0.8290762630096445, 0.2765168868180224]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.03217915333176364], {
             RGBColor[
             0.9952384841280515, 0.9922990050686424, 0.7285741706136537]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.03217915333176364], {
             RGBColor[
             0.9945708916523989, 0.9907960111485639, 0.6504532448156362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.03217915333176364], {
             RGBColor[
             0.9939036525093083, 0.989368854089719, 0.5778283818129042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.03217915333176364], {
             RGBColor[
             0.9896160044595194, 0.9899739652345677, 0.8217532092321849]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.03217915333176364], {
             RGBColor[
             0.7113281488530714, 0.7744142232689649, 0.9718622002043337]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.03217915333176364], {
             RGBColor[
             0.9937233211152434, 0.9889831434721147, 0.5582004224452948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.03217915333176364], {
             RGBColor[
             0.9929120584675252, 0.9913369682716023, 0.7671290644051899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.03217915333176364], {
             RGBColor[
             0.9945706273296324, 0.9907954457888936, 0.650424474913719]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.03217915333176364], {
             RGBColor[
             0.994385826181179, 0.990400174818614, 0.6303100103650559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.03217915333176364], {
             RGBColor[
             0.9788345532930401, 0.9837354250179633, 0.920711759828996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.03217915333176364], {
             RGBColor[
             0.9759862974950818, 0.93065828414474, 0.36121172968594306`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.03217915333176364], {
             RGBColor[
             0.9343125165144804, 0.9504594557037385, 0.9935967559674227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.03217915333176364], {
             RGBColor[
             0.762940451941465, 0.8147341467096498, 0.97700643223179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.03217915333176364], {
             RGBColor[
             0.5175540712398192, 0.619212736434517, 0.9551628988324807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.03217915333176364], {
             RGBColor[
             0.995013268538813, 0.9917422105774395, 0.6986032388681316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.03217915333176364], {
             RGBColor[
             0.7996110216749666, 0.8433814744921138, 0.9806614119168676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.03217915333176364], {
             RGBColor[
             0.18920555763331504`, 0.31619741577080834`, 0.9340863486514539]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.03217915333176364], {
             RGBColor[
             0.9835116773525437, 0.9872236164834534, 0.912794608785579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.03217915333176364], {
             RGBColor[
             0.9857442185509964, 0.9883728822610343, 0.885918721597147]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.03217915333176364], {
             RGBColor[
             0.9950629810454223, 0.9918485406023716, 0.7040141384225366]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.03217915333176364], {
             RGBColor[
             0.9632216289202946, 0.8876000597552731, 0.3116234026782908]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.03217915333176364], {
             RGBColor[
             0.7936238215937561, 0.8387042282842662, 0.9800646637663384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.03217915333176364], {
             RGBColor[
             0.9946083689951138, 0.9908761713950905, 0.6545324222868112]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.03217915333176364], {
             RGBColor[
             0.5283485756802009, 0.6279762014261022, 0.9560126817636002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.03217915333176364], {
             RGBColor[
             0.9867856355797537, 0.9888035349656222, 0.868659746329761]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.03217915333176364], {
             RGBColor[
             0.7033006226999979, 0.7681430588267255, 0.9710620914188923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.03217915333176364], {
             RGBColor[
             0.9943932174373962, 0.9904159839682918, 0.631114502990743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.03217915333176364], {
             RGBColor[
             0.9945706273296324, 0.9907954457888936, 0.650424474913719]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.03217915333176364], {
             RGBColor[
             0.9880380514662509, 0.9893214411203091, 0.8479039739420859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.03217915333176364], {
             RGBColor[
             0.18920555763331504`, 0.31619741577080834`, 0.9340863486514539]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.03217915333176364], {
             RGBColor[
             0.9929450707205896, 0.9873185445711351, 0.4734926697919292]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.03217915333176364], {
             RGBColor[
             0.9945093942277652, 0.9906644743756158, 0.6437596296623695]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.03217915333176364], {
             RGBColor[
             0.9938716603506715, 0.9893004260972983, 0.5743462327780071]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.03217915333176364], {
             RGBColor[
             0.9453754211275218, 0.9587816590332203, 0.9773493430459291]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.03217915333176364], {
             RGBColor[
             0.9835116773525437, 0.9872236164834534, 0.912794608785579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.03217915333176364], {
             RGBColor[
             0.9908298136729129, 0.9904759065377798, 0.8016372493287051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.03217915333176364], {
             RGBColor[
             0.9610278402022231, 0.9704552075506486, 0.9508538803571713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.03217915333176364], {
             RGBColor[
             0.891038580152386, 0.9159539934883149, 0.9894692492861071]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.03217915333176364], {
             RGBColor[
             0.4604973502267412, 0.5728915199401104, 0.9506711847486755]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.03217915333176364], {
             RGBColor[
             0.6296937704822898, 0.7102527961154351, 0.9639909467381014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.03217915333176364], {
             RGBColor[
             0.9517174078102171, 0.9635115023171245, 0.9666140138471638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.03217915333176364], {
             RGBColor[
             0.9470985581634156, 0.960066771813212, 0.974432521510277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.03217915333176364], {
             RGBColor[
             0.9832420438863642, 0.9870225242858608, 0.9132510279121504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.03217915333176364], {
             RGBColor[
             0.939351116438499, 0.9542887424600408, 0.9875469194941408]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.03217915333176364], {
             RGBColor[
             0.9937798178010623, 0.9916958090564176, 0.7527480465593115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.03217915333176364], {
             RGBColor[
             0.9278976224810076, 0.945344393329107, 0.9929848976478666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.03217915333176364], {
             RGBColor[
             0.9848191332297469, 0.9879903357070893, 0.9012497794143209]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.03217915333176364], {
             RGBColor[
             0.9715788944418117, 0.9783241665267681, 0.9329936976852213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.03217915333176364], {
             RGBColor[
             0.9797837950891534, 0.9844433679952637, 0.9191049410700876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.03217915333176364], {
             RGBColor[
             0.9758015103394762, 0.9814733865493472, 0.9258459104050845]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.03217915333176364], {
             RGBColor[
             0.9952669393119791, 0.9922847867111924, 0.7262137370527132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.03217915333176364], {
             RGBColor[
             0.9937432199025767, 0.9890257049661448, 0.5603662826454537]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.03217915333176364], {
             RGBColor[
             0.989923150631666, 0.9901009780700469, 0.8166630022909018]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.03217915333176364], {
             RGBColor[
             0.9921913238763713, 0.9910389259961262, 0.779073501781939]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.03217915333176364], {
             RGBColor[
             0.8322346060218431, 0.8690653007079757, 0.9838604737386085]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.03217915333176364], {
             RGBColor[
             0.9662013034335865, 0.9743135679578309, 0.9420965565617845]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.03217915333176364], {
             RGBColor[
             0.9328475665750322, 0.9492913443870291, 0.9934570277344219]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.03217915333176364], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.03217915333176364], {
             RGBColor[
             0.9926613588073495, 0.9867117134763892, 0.44261237890271976`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.03217915333176364], {
             RGBColor[
             0.8178076717190462, 0.8575968358062114, 0.9824750839358987]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.03217915333176364], {
             RGBColor[
             0.7985768007271687, 0.8425735332273238, 0.9805583304381353]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.03217915333176364], {
             RGBColor[
             0.9950055470740765, 0.991725695145128, 0.6977628050829171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.03217915333176364], {
             RGBColor[
             0.9637527974391588, 0.9724874761962473, 0.9462412385377107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.03217915333176364], {
             RGBColor[
             0.7575558003784784, 0.8105276159837771, 0.9764697404864213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.03217915333176364], {
             RGBColor[
             0.9842028513624264, 0.9583746496778858, 0.39313148989457525`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.03217915333176364], {
             RGBColor[
             0.959547229478552, 0.9693509704972122, 0.9533601681072233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.03217915333176364], {
             RGBColor[
             0.9879573662879647, 0.9892880757255732, 0.8492411361528371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.03217915333176364], {
             RGBColor[
             0.8705635323190102, 0.8996277461263487, 0.9875163209454687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.03217915333176364], {
             RGBColor[
             0.9937305817263837, 0.9889986731851834, 0.5589906951606189]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.03217915333176364], {
             RGBColor[
             0.9818177586382887, 0.9859602946798992, 0.9156619713240557]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.03217915333176364], {
             RGBColor[
             0.9428742686530392, 0.9569163036130126, 0.9815831417801871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.03217915333176364], {
             RGBColor[
             0.3978407779503856, 0.5190114186268795, 0.9465710404675799]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.03217915333176364], {
             RGBColor[
             0.9932672551894938, 0.9880076645722745, 0.5085604609400857]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.03217915333176364], {
             RGBColor[
             0.9915299495520321, 0.990765430716467, 0.7900341859181265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.03217915333176364], {
             RGBColor[
             0.9945349867427694, 0.9907192141774097, 0.6465452169818905]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.03217915333176364], {
             RGBColor[
             0.9865895222510982, 0.9887224370643406, 0.8719098517106091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.03217915333176364], {
             RGBColor[
             0.9941774681806118, 0.9899545181236261, 0.6076315278398451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.03217915333176364], {
             RGBColor[
             0.9683360421965044, 0.9048521766572724, 0.3314919324804594]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.03217915333176364], {
             RGBColor[
             0.9930842802966114, 0.9914081864238287, 0.7642749030014239]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.03217915333176364], {
             RGBColor[
             0.7638332386800415, 0.8154315984952564, 0.9770954168703249]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.03217915333176364], {
             RGBColor[
             0.9407830182315076, 0.9553566524727425, 0.9851230832583768]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.03217915333176364], {
             RGBColor[
             0.8829970972010354, 0.9095419332631477, 0.9887022454634907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.03217915333176364], {
             RGBColor[
             0.9861027501088815, 0.9885211442740605, 0.879976925833062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.03217915333176364], {
             RGBColor[
             0.9938823014048089, 0.9917381886602753, 0.7510496280261654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.03217915333176364], {
             RGBColor[
             0.9942690609386399, 0.9901504257715997, 0.6176008343062163]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.03217915333176364], {
             RGBColor[
             0.9822822956155327, 0.9863067455969183, 0.9148756313922293]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.03217915333176364], {
             RGBColor[
             0.990693634487293, 0.9904195929448806, 0.8038940908548621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.03217915333176364], {
             RGBColor[
             0.994016088539209, 0.9896093433886498, 0.5900663497928385]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.03217915333176364], {
             RGBColor[
             0.9921640568364062, 0.9910276503743696, 0.7795253871989996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.03217915333176364], {
             RGBColor[
             0.9837144840751415, 0.9567272721437817, 0.39123427520389714`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.03217915333176364], {
             RGBColor[
             0.9715788944418117, 0.9783241665267681, 0.9329936976852213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.03217915333176364], {
             RGBColor[
             0.9927288689843058, 0.9868561109185727, 0.4499604450398878]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.03217915333176364], {
             RGBColor[
             0.9567167001764494, 0.865657407672381, 0.2863529828611705]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.03217915333176364], {
             RGBColor[
             0.9948462733133558, 0.9921368158174075, 0.7350741188222116]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.03217915333176364], {
             RGBColor[
             0.5495414986021835, 0.6451815709844653, 0.9576810662882533]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.03217915333176364], {
             RGBColor[
             0.9904669138189112, 0.9903258381220493, 0.8076514390642309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.03217915333176364], {
             RGBColor[
             0.9687665283718144, 0.906304307609554, 0.33316428998104636`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.03217915333176364], {
             RGBColor[
             0.7052678774083275, 0.7696798931565622, 0.9712581689831782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.03217915333176364], {
             RGBColor[
             0.9928888294617056, 0.9913273624807378, 0.7675140291463577]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.03217915333176364], {
             RGBColor[
             0.884214442476941, 0.5671266503393498, 0.225098031450086]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.03217915333176364], {
             RGBColor[
             0.9930981029699048, 0.9876458650784864, 0.4901492857243145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.03217915333176364], {
             RGBColor[
             0.9588757444044745, 0.9688501780284212, 0.9544968171862804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.03217915333176364], {
             RGBColor[
             0.791965921181043, 0.837409063881345, 0.9798994197471594]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.03217915333176364], {
             RGBColor[
             0.9214191180207684, 0.9401786097268311, 0.9923669721090197]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.03217915333176364], {
             RGBColor[
             0.937407714441376, 0.7895494759424247, 0.2684949816910005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.03217915333176364], {
             RGBColor[
             0.8946608127405742, 0.9188422634312517, 0.9898147410639737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.03217915333176364], {
             RGBColor[
             0.9937400069753265, 0.9890188328396333, 0.5600165753421533]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.03217915333176364], {
             RGBColor[
             0.8666863819663225, 0.8965362116775583, 0.9871465148836565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.03217915333176364], {
             RGBColor[
             0.9919132536151538, 0.9843836469648777, 0.4230849466591324]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.03217915333176364], {
             RGBColor[
             0.7396461373921873, 0.7965364511404064, 0.974684672655264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.03217915333176364], {
             RGBColor[
             0.8895900557744938, 0.5915360548171535, 0.22958357495390364`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.03217915333176364], {
             RGBColor[
             0.963401354217337, 0.9722253704168481, 0.9468361402411827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.03217915333176364], {
             RGBColor[
             0.9938308805163931, 0.9917169248014589, 0.7519018052202078]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.03217915333176364], {
             RGBColor[
             0.9907718623586014, 0.9904519421800312, 0.8025976525800397]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.03217915333176364], {
             RGBColor[
             0.9944374639234123, 0.9905106227278742, 0.6359304599359327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.03217915333176364], {
             RGBColor[
             0.9931572817724736, 0.99143837441015, 0.7630650796246227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.03217915333176364], {
             RGBColor[
             0.9917692711572328, 0.9908643963505023, 0.7860680075754897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.03217915333176364], {
             RGBColor[
             0.8670516513706797, 0.48919442439752137`, 0.21077697785251495`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.03217915333176364], {
             RGBColor[
             0.9948724464727368, 0.9921476390914311, 0.7346403618373041]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.03217915333176364], {
             RGBColor[
             0.9903808523684744, 0.9902902495006153, 0.809077700017861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.03217915333176364], {
             RGBColor[
             0.8033294614172664, 0.846286347879987, 0.9810320312395849]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.03217915333176364], {
             RGBColor[
             0.871114945716633, 0.9000674282018951, 0.9875689152475865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.03217915333176364], {
             RGBColor[
             0.9862415160352833, 0.9885785275507493, 0.877677215317878]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.03217915333176364], {
             RGBColor[
             0.6599310704440303, 0.7342624349835583, 0.9667394197615263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.03217915333176364], {
             RGBColor[
             0.991926167816502, 0.9844272095984236, 0.42313511589272756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.03217915333176364], {
             RGBColor[
             0.9642375698602831, 0.9728490186741798, 0.9454206452776441]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.03217915333176364], {
             RGBColor[
             0.9628375644303192, 0.9718048969168112, 0.9477904892906773]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.03217915333176364], {
             RGBColor[
             0.983141030296394, 0.9547928778947162, 0.38900651556112265`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.03217915333176364], {
             RGBColor[
             0.985182760114158, 0.9881407047685778, 0.8952235409034184]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.03217915333176364], {
             RGBColor[
             0.7815360706693472, 0.8292611853918083, 0.9788598697206481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.03217915333176364], {
             RGBColor[
             0.9888011820902124, 0.9896370152448796, 0.8352569245842971]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.03217915333176364], {
             RGBColor[
             0.887145321777082, 0.9128496149395308, 0.9890979068267178]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.03217915333176364], {
             RGBColor[
             0.9407548308301295, 0.9553356303549474, 0.9851707971764582]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.03217915333176364], {
             RGBColor[
             0.8707679185416699, 0.8997907181523812, 0.9875358154858438]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.03217915333176364], {
             RGBColor[
             0.8476370994559485, 0.8813468308827848, 0.9853295773123216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.03217915333176364], {
             RGBColor[
             0.9510575782557059, 0.9630194025157417, 0.9677309331718417]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.03217915333176364], {
             RGBColor[
             0.7925060876848091, 0.8378310460595044, 0.9799532584961118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.03217915333176364], {
             RGBColor[
             0.5899598802564805, 0.6779950340387672, 0.96086294934949]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.03217915333176364], {
             RGBColor[
             0.9946822468659847, 0.9920689866661322, 0.7377924615419899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.03217915333176364], {
             RGBColor[
             0.9875980048272339, 0.9891394705263927, 0.8551966855547953]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.03217915333176364], {
             RGBColor[
             0.9909543156139771, 0.9905273912899638, 0.7995739299645763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.03217915333176364], {
             RGBColor[
             0.993192734106311, 0.9914530348612752, 0.7624775427052384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.03217915333176364], {
             RGBColor[
             0.807289153363952, 0.8493796893235113, 0.9814266963274055]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.03217915333176364], {
             RGBColor[
             0.9295566996720268, 0.7584228185775369, 0.2621778709205801]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.03217915333176364], {
             RGBColor[
             0.9948646277067709, 0.9914242828675949, 0.682424601605232]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.03217915333176364], {
             RGBColor[
             0.9842028513624264, 0.9583746496778858, 0.39313148989457525`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.03217915333176364], {
             RGBColor[
             0.9950132479967853, 0.9917421666401193, 0.6986010029951835]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.03217915333176364], {
             RGBColor[
             0.9589740376658206, 0.9689234849817926, 0.95433043233381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.03217915333176364], {
             RGBColor[
             0.9233140255721495, 0.7336726960193483, 0.25715486880542443`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.03217915333176364], {
             RGBColor[
             0.9840015822208105, 0.987588986732061, 0.911965327631257]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.03217915333176364], {
             RGBColor[
             0.9527559113628077, 0.9642860165662529, 0.9648560982177338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.03217915333176364], {
             RGBColor[
             0.9876134143441128, 0.9891458427576286, 0.8549413099815601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.03217915333176364], {
             RGBColor[
             0.9377511143795241, 0.9530954635442201, 0.9902553056326147]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.03217915333176364], {
             RGBColor[
             0.9477608202675175, 0.9605606858060965, 0.9733114845136526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.03217915333176364], {
             RGBColor[
             0.8260023471290501, 0.8640958666370236, 0.9832660353218107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.03217915333176364], {
             RGBColor[
             0.9243206417236778, 0.9424922059677683, 0.992643722030024]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.03217915333176364], {
             RGBColor[
             0.9496264551862436, 0.9619520732737856, 0.9701534512317656]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.03217915333176364], {
             RGBColor[
             0.992674802963948, 0.9867404691679408, 0.4440756923807557]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.03217915333176364], {
             RGBColor[
             0.7902985836625713, 0.8361065271396804, 0.9797332351254732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.03217915333176364], {
             RGBColor[
             0.9758700570693939, 0.981524508588285, 0.9257298786711841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.03217915333176364], {
             RGBColor[
             0.9929929772157977, 0.9874210117202957, 0.47870699615071877`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.03217915333176364], {
             RGBColor[
             0.9845466448509956, 0.9878776547598437, 0.9057656170275481]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.03217915333176364], {
             RGBColor[
             0.9765792309787967, 0.9820534093287518, 0.9245294322247436]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.03217915333176364], {
             RGBColor[
             0.9716016843049247, 0.9158679542982049, 0.34417833540690645`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.03217915333176364], {
             RGBColor[
             0.9753056305619806, 0.9811035602232197, 0.926685305522225]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.03217915333176364], {
             RGBColor[
             0.9389671700446511, 0.9540023958681635, 0.988196840589668]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.03217915333176364], {
             RGBColor[
             0.9854029847147614, 0.9882317733004415, 0.8915738493484208]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.03217915333176364], {
             RGBColor[
             0.9715045643658341, 0.9155403459388063, 0.3438010427831012]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.03217915333176364], {
             RGBColor[
             0.7579059934595314, 0.8108011894802617, 0.9765046444600002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.03217915333176364], {
             RGBColor[
             0.9912329331897215, 0.9906426068176792, 0.794956515695318]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.03217915333176364], {
             RGBColor[
             0.7273473494930196, 0.7869285445593266, 0.9734588444161825]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.03217915333176364], {
             RGBColor[
             0.9892503747191113, 0.9898227679406533, 0.8278126402501845]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.03217915333176364], {
             RGBColor[
             0.9948656525143188, 0.9914264748273158, 0.6825361455824375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.03217915333176364], {
             RGBColor[
             0.9951556318612745, 0.992264743527124, 0.7299472470889401]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.03217915333176364], {
             RGBColor[
             0.9945268001814068, 0.9920047054672617, 0.7403686153885692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.03217915333176364], {
             RGBColor[
             0.9691493116549689, 0.9765121876624174, 0.9371063476066693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.03217915333176364], {
             RGBColor[
             0.9815894789221714, 0.9495591307878762, 0.38297903145815937`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.03217915333176364], {
             RGBColor[
             0.5433323057119659, 0.6401406684752347, 0.9571922558789123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.03217915333176364], {
             RGBColor[
             0.5493979258143242, 0.6450650121274007, 0.9576697637124686]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.03217915333176364], {
             RGBColor[
             0.961118261473204, 0.9705226435864949, 0.9507008207310451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.03217915333176364], {
             RGBColor[
             0.9938886437690299, 0.9917408113908721, 0.7509445186375109]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.03217915333176364], {
             RGBColor[
             0.9142138688124489, 0.6975936069146104, 0.2498326690684364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.03217915333176364], {
             RGBColor[
             0.9895584373257761, 0.989950159745357, 0.8227072456172769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.03217915333176364], {
             RGBColor[
             0.7024770693558217, 0.7674996926950177, 0.9709800073180884]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.03217915333176364], {
             RGBColor[
             0.9328475665750322, 0.9492913443870291, 0.9934570277344219]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.03217915333176364], {
             RGBColor[
             0.8982632831937838, 0.9217147755841857, 0.9901583479117642]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.03217915333176364], {
             RGBColor[
             0.9251485824842436, 0.9431523834563902, 0.9927226917588783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.03217915333176364], {
             RGBColor[
             0.9853500118343208, 0.9622442913156735, 0.3975879917048074]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.03217915333176364], {
             RGBColor[
             0.9948577209609003, 0.9914095100365569, 0.681672844940714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.03217915333176364], {
             RGBColor[
             0.4465371021211449, 0.5611897270751728, 0.9496739271832719]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.03217915333176364], {
             RGBColor[
             0.9758700570693939, 0.981524508588285, 0.9257298786711841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.03217915333176364], {
             RGBColor[
             0.9806103387997466, 0.9462562612419035, 0.37917525697763593`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.03217915333176364], {
             RGBColor[
             0.8548064873803082, 0.8870635062058183, 0.9860133999327353]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.03217915333176364], {
             RGBColor[
             0.9938418300742846, 0.9892366221524103, 0.5710993912844171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.03217915333176364], {
             RGBColor[
             0.8021720588617548, 0.8453821762070363, 0.9809166721693934]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.03217915333176364], {
             RGBColor[
             0.9374631330103835, 0.9528806875106414, 0.9907427829729991]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.03217915333176364], {
             RGBColor[
             0.9925249329479426, 0.9864199123578882, 0.42776326602909176`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.03217915333176364], {
             RGBColor[
             0.8829900450056977, 0.5615669473877284, 0.22407636418735213`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.03217915333176364], {
             RGBColor[
             0.9587305571214175, 0.9687418975904396, 0.954742581385588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.03217915333176364], {
             RGBColor[
             0.9944495052534097, 0.9905363779151736, 0.6372410843956838]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.03217915333176364], {
             RGBColor[
             0.8854446033570201, 0.9114935082361452, 0.9889356907855631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.03217915333176364], {
             RGBColor[
             0.9707744565048889, 0.9777242180305573, 0.9343554012814156]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.03217915333176364], {
             RGBColor[
             0.944438041770969, 0.9580825630439211, 0.9789360817888816]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.03217915333176364], {
             RGBColor[
             0.9899033077343535, 0.9776036275512026, 0.4152766864586538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.03217915333176364], {
             RGBColor[
             0.5046943450426381, 0.6087726313835822, 0.9541505340795094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.03217915333176364], {
             RGBColor[
             0.9782466667244365, 0.9382830403152871, 0.36999283730707383`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.03217915333176364], {
             RGBColor[
             0.9874683646105168, 0.9890858609651786, 0.8573451594439228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.03217915333176364], {
             RGBColor[
             0.99454826841877, 0.9907476223393914, 0.647990845449543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.03217915333176364], {
             RGBColor[
             0.9875132372961968, 0.9891044169738826, 0.8566015029154185]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.03217915333176364], {
             RGBColor[
             0.6683243893320351, 0.7408193594904537, 0.9675759873482581]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.03217915333176364], {
             RGBColor[
             0.49199912366713616`, 0.5984660787577442, 0.9531511197487017]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.03217915333176364], {
             RGBColor[
             0.8868573737508803, 0.9126200129995785, 0.9890704420869245]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.03217915333176364], {
             RGBColor[
             0.9937350429713578, 0.989008215337082, 0.5594762741444419]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.03217915333176364], {
             RGBColor[
             0.9447358969188902, 0.9583047029255477, 0.9784318907165153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.03217915333176364], {
             RGBColor[
             0.9947057559271495, 0.9910844721953856, 0.6651323888364137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.03217915333176364], {
             RGBColor[
             0.9810950391811458, 0.9854212916921066, 0.9168853468495755]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.03217915333176364], {
             RGBColor[
             0.963401354217337, 0.9722253704168481, 0.9468361402411827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.03217915333176364], {
             RGBColor[
             0.9950587965476994, 0.9918395903848597, 0.7035586816691141]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.03217915333176364], {
             RGBColor[
             0.9606872700703839, 0.8790510722587677, 0.30177789711989755`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.03217915333176364], {
             RGBColor[
             0.9610479843390876, 0.9704702310149391, 0.950819781587892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.03217915333176364], {
             RGBColor[
             0.9935235534156595, 0.9885558605623173, 0.5364569411689146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.03217915333176364], {
             RGBColor[
             0.9950359059450802, 0.9922152337839619, 0.7319314153610197]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.03217915333176364], {
             RGBColor[
             0.937315702731643, 0.7891846801744178, 0.26842094690955687`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.03217915333176364], {
             RGBColor[
             0.9845015614695132, 0.9878590116230106, 0.9065127653307626]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.03217915333176364], {
             RGBColor[
             0.4784696829954938, 0.5874822693261484, 0.9520860326190559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.03217915333176364], {
             RGBColor[
             0.9950476483200794, 0.9918157454532393, 0.7023452658915625]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.03217915333176364], {
             RGBColor[
             0.9600446783547791, 0.9697219670546047, 0.9525181169152166]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.03217915333176364], {
             RGBColor[
             0.8705635323190102, 0.8996277461263487, 0.9875163209454687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.03217915333176364], {
             RGBColor[
             0.9939562575862646, 0.9917687714418945, 0.7498239827069814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.03217915333176364], {
             RGBColor[
             0.9933567444625186, 0.991520857358441, 0.7597594666576825]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.03217915333176364], {
             RGBColor[
             0.9818272632426962, 0.95036123313542, 0.3839027786415972]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.03217915333176364], {
             RGBColor[
             0.9009664104844937, 0.6431934245401149, 0.2390762841838989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.03217915333176364], {
             RGBColor[
             0.9927113144662119, 0.9868185635794038, 0.4480497440792934]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.03217915333176364], {
             RGBColor[
             0.9204267262760075, 0.9393873034873151, 0.9922723168984858]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.03217915333176364], {
             RGBColor[
             0.8716022127681112, 0.9004559617222321, 0.9876153912139449]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.03217915333176364], {
             RGBColor[
             0.8818057113156129, 0.5561891647092145, 0.2230881271256702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.03217915333176364], {
             RGBColor[
             0.9947289377273906, 0.9911340557220617, 0.667655584731165]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.03217915333176364], {
             RGBColor[
             0.8235546769681472, 0.8621441608909562, 0.9830325743568028]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.03217915333176364], {
             RGBColor[
             0.7432797249484888, 0.7993750373556774, 0.9750468347050699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.03217915333176364], {
             RGBColor[
             0.9085988024715613, 0.6753317399829282, 0.24531465488801135`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.03217915333176364], {
             RGBColor[
             0.9863592218475291, 0.9886272019290143, 0.8757265253960881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.03217915333176364], {
             RGBColor[
             0.9930420039207138, 0.9875258748847511, 0.48404325042308827`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.03217915333176364], {
             RGBColor[
             0.9375135297499831, 0.9529182733165177, 0.9906574744384319]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.03217915333176364], {
             RGBColor[
             0.9665691274867109, 0.9745878905343943, 0.9414739263837224]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.03217915333176364], {
             RGBColor[
             0.807289153363952, 0.8493796893235113, 0.9814266963274055]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.03217915333176364], {
             RGBColor[
             0.9733046642543789, 0.979611242827292, 0.9300724195453993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.03217915333176364], {
             RGBColor[
             0.9676100282400794, 0.9024031611060671, 0.3286715053559796]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.03217915333176364], {
             RGBColor[
             0.9600128683354547, 0.9696982431942767, 0.952571962980551]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.03217915333176364], {
             RGBColor[
             0.9779487673456047, 0.937278155760387, 0.36883555447388966`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.03217915333176364], {
             RGBColor[
             0.6435830071437153, 0.7214912036834692, 0.9651099975930884]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.03217915333176364], {
             RGBColor[
             0.9933567444625186, 0.991520857358441, 0.7597594666576825]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.03217915333176364], {
             RGBColor[
             0.740931748769689, 0.7975407805195192, 0.9748128103826521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.03217915333176364], {
             RGBColor[
             0.9847959693936116, 0.9603753760678099, 0.39543564144478793`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.03217915333176364], {
             RGBColor[
             0.9827791583835883, 0.9535721989612568, 0.387600711513649]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.03217915333176364], {
             RGBColor[
             0.7376696871189076, 0.7949924331653418, 0.9744876785630014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.03217915333176364], {
             RGBColor[
             0.9926613588073495, 0.9867117134763892, 0.44261237890271976`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.03217915333176364], {
             RGBColor[
             0.9943008796221611, 0.990218482718289, 0.6210641016453392]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.03217915333176364], {
             RGBColor[
             0.826390919042476, 0.8644057033332858, 0.9833030976577956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.03217915333176364], {
             RGBColor[
             0.9081854043077002, 0.9296264056316198, 0.9911047286811916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.03217915333176364], {
             RGBColor[
             0.7292509676407094, 0.7884156655243356, 0.9736485792828212]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.03217915333176364], {
             RGBColor[
             0.8285932336245045, 0.8661617692007586, 0.9835131563886589]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.03217915333176364], {
             RGBColor[
             0.8982632831937838, 0.9217147755841857, 0.9901583479117642]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.03217915333176364], {
             RGBColor[
             0.8187342422226651, 0.858320679725835, 0.9825674358244058]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.03217915333176364], {
             RGBColor[
             0.8918366433866016, 0.6017372844598674, 0.2314581827263479]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.03217915333176364], {
             RGBColor[
             0.8997062140793418, 0.9228653295050142, 0.9902959759477483]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.03217915333176364], {
             RGBColor[
             0.9858055719210008, 0.9883982534562408, 0.8849019374787414]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.03217915333176364], {
             RGBColor[
             0.9652786751660007, 0.8945389597594666, 0.31961463890227043`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.03217915333176364], {
             RGBColor[
             0.9690258910681944, 0.9764201407908837, 0.9373152664668342]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.03217915333176364], {
             RGBColor[
             0.8990898594900233, 0.9223738650859912, 0.9902371874967929]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.03217915333176364], {
             RGBColor[
             0.9792070226229357, 0.9840132120343368, 0.9200812664090425]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.03217915333176364], {
             RGBColor[
             0.9470985581634156, 0.960066771813212, 0.974432521510277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.03217915333176364], {
             RGBColor[
             0.9924087044400677, 0.986054918934698, 0.42500967955588526`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.03217915333176364], {
             RGBColor[
             0.9413852607891128, 0.8053191217724534, 0.2716954088474019]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.03217915333176364], {
             RGBColor[
             0.8557777068232262, 0.8878379302265517, 0.9861060357102186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.03217915333176364], {
             RGBColor[
             0.9946118693874363, 0.9920398837701337, 0.7389587984926139]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.03217915333176364], {
             RGBColor[
             0.6491594737873725, 0.7258475818082105, 0.9656658076730845]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.03217915333176364], {
             RGBColor[
             0.9842028513624264, 0.9583746496778858, 0.39313148989457525`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.03217915333176364], {
             RGBColor[
             0.9244844118493514, 0.7383128876003471, 0.2580965890765579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.03217915333176364], {
             RGBColor[
             0.9603308209924326, 0.8778486858206146, 0.3003931597618172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.03217915333176364], {
             RGBColor[
             0.8330564341029655, 0.25509181470298914`, 0.17928818466988933`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.03217915333176364], {
             RGBColor[
             0.9799041889082455, 0.9438742518459912, 0.3764319979943718]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.03217915333176364], {
             RGBColor[
             0.9900385762913688, 0.9901487095466383, 0.8147501003975938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.03217915333176364], {
             RGBColor[
             0.8224965888977309, 0.8613004701846418, 0.9829316529720802]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.03217915333176364], {
             RGBColor[
             0.9755699812806903, 0.9813007125563988, 0.926237828709159]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.03217915333176364], {
             RGBColor[
             0.9939217123930923, 0.9894074823549984, 0.579794088710104]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.03217915333176364], {
             RGBColor[
             0.9747041221652066, 0.9806549562457854, 0.9277035023394478]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.03217915333176364], {
             RGBColor[
             0.9947060189661191, 0.9910850348091441, 0.6651610190049619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.03217915333176364], {
             RGBColor[
             0.9398821765111646, 0.9546848061927037, 0.9866479733137677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.03217915333176364], {
             RGBColor[
             0.8794420688740423, 0.5454564164247603, 0.22111584593424574`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.03217915333176364], {
             RGBColor[
             0.9901904191249183, 0.9902115004604938, 0.8122336716890212]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.03217915333176364], {
             RGBColor[
             0.9907862045266501, 0.9904578730350962, 0.8023599657391312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.03217915333176364], {
             RGBColor[
             0.9192110937675015, 0.9384179911224979, 0.9921563687846167]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.03217915333176364], {
             RGBColor[
             0.8984675166566474, 0.9218776258037035, 0.9901778278817734]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.03217915333176364], {
             RGBColor[
             0.9942067789520047, 0.9918723684647335, 0.7456721953481555]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.03217915333176364], {
             RGBColor[
             0.7426683264812414, 0.7988974082262632, 0.9749858962196982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.03217915333176364], {
             RGBColor[
             0.9848737240708053, 0.9880129104227875, 0.9003450679014151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.03217915333176364], {
             RGBColor[
             0.8803123092840844, 0.9074011562547976, 0.9884461679952334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.03217915333176364], {
             RGBColor[
             0.9788979220768877, 0.9404798775411338, 0.3725228413720934]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.03217915333176364], {
             RGBColor[
             0.9935430194371534, 0.9885974964139762, 0.5385756974781768]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.03217915333176364], {
             RGBColor[
             0.9590545028333292, 0.968983495771971, 0.9541942257938947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.03217915333176364], {
             RGBColor[
             0.9925210443039081, 0.9864115949415005, 0.42734001112386144`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.03217915333176364], {
             RGBColor[
             0.978533703963385, 0.983511052080502, 0.9212210192700301]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.03217915333176364], {
             RGBColor[
             0.991926167816502, 0.9844272095984236, 0.42313511589272756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.03217915333176364], {
             RGBColor[
             0.993627233038455, 0.988777620791859, 0.5477418282737454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.03217915333176364], {
             RGBColor[
             0.990991895897581, 0.9812756910384246, 0.4195056459101673]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.03217915333176364], {
             RGBColor[
             0.5196825954897373, 0.6209407683095252, 0.9553304640584755]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.03217915333176364], {
             RGBColor[
             0.7292509676407094, 0.7884156655243356, 0.9736485792828212]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.03217915333176364], {
             RGBColor[
             0.9475336455157499, 0.9603912592481928, 0.9736960321117305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.03217915333176364], {
             RGBColor[
             0.9240722183673883, 0.9422941199267354, 0.992620027188531]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.03217915333176364], {
             RGBColor[
             0.7488015435991302, 0.8036887240529346, 0.9755971979838367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.03217915333176364], {
             RGBColor[
             0.8247681077968233, 0.8631117176960401, 0.9831483124724845]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.03217915333176364], {
             RGBColor[
             0.941396677608522, 0.9558143186313449, 0.9840843180010901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.03217915333176364], {
             RGBColor[
             0.6901916528085199, 0.7579022319156415, 0.9697555118103984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.03217915333176364], {
             RGBColor[
             0.9469127501725392, 0.827233775251093, 0.27614295655215826`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.03217915333176364], {
             RGBColor[
             0.5365484760936737, 0.6346332499830635, 0.9566582079613737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.03217915333176364], {
             RGBColor[
             0.9940830145844926, 0.9897524914322504, 0.597350836802289]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.03217915333176364], {
             RGBColor[
             0.9920160990533228, 0.990966466028723, 0.7819774305671608]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.03217915333176364], {
             RGBColor[
             0.9912411565813384, 0.9906460074014444, 0.7948202328147723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.03217915333176364], {
             RGBColor[
             0.73439692210564, 0.7924357242630419, 0.9741614799322069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.03217915333176364], {
             RGBColor[
             0.9644500984549241, 0.9730075221520794, 0.9450608898032519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.03217915333176364], {
             RGBColor[
             0.9425204144578389, 0.9566523997336152, 0.9821821246327065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.03217915333176364], {
             RGBColor[
             0.8219261603961775, 0.16953965367557855`, 0.16862982199842297`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.03217915333176364], {
             RGBColor[
             0.9485709298801769, 0.8338079052362447, 0.27747716686740376`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.03217915333176364], {
             RGBColor[
             0.9870036618968718, 0.9888936944507714, 0.8650464860210926]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.03217915333176364], {
             RGBColor[
             0.9771798960683146, 0.9825013843690155, 0.9235126629067356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.03217915333176364], {
             RGBColor[
             0.7060970652080797, 0.7703276609677892, 0.9713408146738569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.03217915333176364], {
             RGBColor[
             0.9507795863787943, 0.962812076629111, 0.9682015009075595]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.03217915333176364], {
             RGBColor[
             0.9930023290348572, 0.9874410143156499, 0.47972488394260204`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.03217915333176364], {
             RGBColor[
             0.4763759693970103, 0.5857824983061768, 0.9519212078150576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.03217915333176364], {
             RGBColor[
             0.8733159515520168, 0.5176391484564943, 0.21600406347587103`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.03217915333176364], {
             RGBColor[
             0.9500664601080605, 0.9622802282240348, 0.9694086376707924]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.03217915333176364], {
             RGBColor[
             0.9897319838092536, 0.9900219256762162, 0.8198311312621519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.03217915333176364], {
             RGBColor[
             0.976545629693551, 0.932545042987622, 0.36338462965597296`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.03217915333176364], {
             RGBColor[
             0.9857442185509964, 0.9883728822610343, 0.885918721597147]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.03217915333176364], {
             RGBColor[
             0.9592125734585881, 0.8740765743119498, 0.2960489792561586]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.03217915333176364], {
             RGBColor[
             0.9927638686280528, 0.9869309716175407, 0.4537699402689851]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.03217915333176364], {
             RGBColor[
             0.9858883073581551, 0.9884324666857078, 0.8835307971726473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.03217915333176364], {
             RGBColor[
             0.9930529315631241, 0.991395222916906, 0.7647944326432292]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.03217915333176364], {
             RGBColor[
             0.9858055719210008, 0.9883982534562408, 0.8849019374787414]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.03217915333176364], {
             RGBColor[
             0.9441188823005422, 0.9578445344334524, 0.9794763355221927]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.03217915333176364], {
             RGBColor[
             0.7156762789404427, 0.777811015540232, 0.972295581175857]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.03217915333176364], {
             RGBColor[
             0.9943788509745709, 0.9903852555569806, 0.6295508021717436]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.03217915333176364], {
             RGBColor[
             0.9778516482124185, 0.983002376018195, 0.9223755617477865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.03217915333176364], {
             RGBColor[
             0.9477808092651123, 0.9605755935677738, 0.97327764835469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.03217915333176364], {
             RGBColor[
             0.6652086100067185, 0.7383852890007165, 0.9672654355837238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.03217915333176364], {
             RGBColor[
             0.9702212131999656, 0.9112113011111482, 0.33881546584423405`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.03217915333176364], {
             RGBColor[
             0.9824970040731734, 0.9864668748130739, 0.914512185978378]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.03217915333176364], {
             RGBColor[
             0.994535498815278, 0.990720309448727, 0.646600952914301]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.03217915333176364], {
             RGBColor[
             0.9899851481772204, 0.9901266156483979, 0.8156355425165618]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.03217915333176364], {
             RGBColor[
             0.9951489003578309, 0.9920323133238382, 0.7133659253456646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.03217915333176364], {
             RGBColor[
             0.9233140255721495, 0.7336726960193483, 0.25715486880542443`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.03217915333176364], {
             RGBColor[
             0.9837143740457597, 0.9567269009888411, 0.3912338477605264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.03217915333176364], {
             RGBColor[
             0.7669321782878086, 0.8178525136696574, 0.97740429020919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.03217915333176364], {
             RGBColor[
             0.991926167816502, 0.9844272095984236, 0.42313511589272756`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.03217915333176364], {
             RGBColor[
             0.7901878600566663, 0.8360200290172168, 0.9797221992312074]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.03217915333176364], {
             RGBColor[
             0.9453754211275218, 0.9587816590332203, 0.9773493430459291]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN2wucz2W+wPHn16rdrWxoc2ntsSnFoptQYTEuNY3rMEhyNxmZGTMj4zII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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[105, 155] -> 
             RGBColor[
              0.3609448647521152, 0.4866656792120809, 0.9442342850410239], 
             UndirectedEdge[1, 203] -> 
             RGBColor[
              0.32569030455946724`, 0.45491432460487713`, 0.9420324056815049],
              UndirectedEdge[187, 193] -> 
             RGBColor[
              0.8331367258093362, 0.8697846265391334, 0.9839465187292714], 
             UndirectedEdge[209, 371] -> 
             RGBColor[
              0.26203929742842424`, 0.3927502942212898, 0.9382341223849231], 
             UndirectedEdge[23, 245] -> 
             RGBColor[
              0.22165838805798918`, 0.35030739817543277`, 0.9359344893344789],
              UndirectedEdge[201, 236] -> 
             RGBColor[
              0.26347424346046877`, 0.3942585134818019, 0.9383158404386357], 
             UndirectedEdge[258, 369] -> 
             RGBColor[
              0.2551936052438994, 0.3855550376934007, 0.9378442703423086], 
             UndirectedEdge[161, 312] -> 
             RGBColor[
              0.44719691052756494`, 0.5614994937585587, 0.949788285319064], 
             UndirectedEdge[74, 132] -> 
             RGBColor[
              0.8119479189165777, 0.8530570556731545, 0.981880980170774], 
             UndirectedEdge[89, 169] -> 
             RGBColor[
              0.2196406470513075, 0.3481866244452415, 0.9358195819691286], 
             UndirectedEdge[124, 137] -> 
             RGBColor[
              0.22241368079166546`, 0.3511012587268517, 0.9359775021383063], 
             UndirectedEdge[186, 393] -> 
             RGBColor[
              0.23564383540018752`, 0.36500699006065973`, 0.9367309398710019],
              UndirectedEdge[84, 261] -> 
             RGBColor[
              0.17918769193352976`, 0.30566800375096304`, 0.9335158460199553],
              UndirectedEdge[58, 243] -> 
             RGBColor[
              0.2935914724788655, 0.42591363072274663`, 0.9400309720767858], 
             UndirectedEdge[205, 250] -> 
             RGBColor[
              0.9917478646376758, 0.990855544204543, 0.7864227690028461], 
             UndirectedEdge[327, 337] -> 
             RGBColor[
              0.3016677329619616, 0.43349195021963505`, 0.9405242352558603], 
             UndirectedEdge[38, 224] -> 
             RGBColor[
              0.970726359968221, 0.9129152797745752, 0.34077786564994345`], 
             UndirectedEdge[49, 301] -> 
             RGBColor[
              0.2562771522862687, 0.3866939143357813, 0.9379059767434073], 
             UndirectedEdge[22, 97] -> 
             RGBColor[
              0.36730142212889694`, 0.4910409193978484, 0.9446807120447999], 
             UndirectedEdge[163, 169] -> 
             RGBColor[
              0.23283585906700827`, 0.36205562889850595`, 0.936571029772856], 
             UndirectedEdge[126, 318] -> 
             RGBColor[
              0.2179296081019373, 0.3463882140233181, 0.9357221408322174], 
             UndirectedEdge[126, 149] -> 
             RGBColor[
              0.21613019133913786`, 0.3444969129160037, 0.9356196667095744], 
             UndirectedEdge[28, 47] -> 
             RGBColor[
              0.3610905157265072, 0.4852888096589335, 0.9442985989042187], 
             UndirectedEdge[203, 392] -> 
             RGBColor[
              0.26967339396164935`, 0.4007742137073859, 0.9386688728888566], 
             UndirectedEdge[116, 387] -> 
             RGBColor[
              0.35489504602512995`, 0.4804107437728069, 0.9438859559088182], 
             UndirectedEdge[114, 203] -> 
             RGBColor[
              0.3101377282501396, 0.4414434647009515, 0.9410414092716778], 
             UndirectedEdge[38, 207] -> 
             RGBColor[
              0.9528235149386215, 0.8477616286807421, 0.29603526485507003`], 
             UndirectedEdge[4, 73] -> 
             RGBColor[
              0.23765623707057423`, 0.3671221518098715, 0.9368455431690489], 
             UndirectedEdge[143, 223] -> 
             RGBColor[
              0.5393557196395969, 0.6369122967585245, 0.9568792044565808], 
             UndirectedEdge[70, 164] -> 
             RGBColor[
              0.26017432145076, 0.3907900862224582, 0.9381279147619799], 
             UndirectedEdge[291, 331] -> 
             RGBColor[
              0.5742920250264498, 0.6644126452364563, 0.9602056699966387], 
             UndirectedEdge[317, 381] -> 
             RGBColor[
              0.99188704610358, 0.9909130993174948, 0.7841161719227241], 
             UndirectedEdge[120, 349] -> 
             RGBColor[
              0.5058787275831391, 0.6095186078416714, 0.9543033325072602], 
             UndirectedEdge[102, 160] -> 
             RGBColor[
              0.8243873085977117, 0.18845711723458924`, 0.17098662029568146`],
              UndirectedEdge[84, 381] -> 
             RGBColor[
              0.5860370216699882, 0.6484140748343261, 0.8483679973313716], 
             UndirectedEdge[110, 203] -> 
             RGBColor[
              0.2734877597794271, 0.40478335402663146`, 0.9388860953793305], 
             UndirectedEdge[316, 355] -> 
             RGBColor[
              0.2426003366300466, 0.37231871392089444`, 0.937127102324821], 
             UndirectedEdge[62, 77] -> 
             RGBColor[
              0.5042166815429454, 0.5861598549701907, 0.9585479112851663], 
             UndirectedEdge[188, 361] -> 
             RGBColor[
              0.3113562197109362, 0.44025108193646334`, 0.9412013526638779], 
             UndirectedEdge[168, 282] -> 
             RGBColor[
              0.6585061316418895, 0.73314926196139, 0.9665973951785392], 
             UndirectedEdge[271, 394] -> 
             RGBColor[
              0.3328279171819992, 0.4625195049765876, 0.9424351072766638], 
             UndirectedEdge[160, 224] -> 
             RGBColor[
              0.9025695450570996, 0.5785729407895561, 0.26790552836760506`], 
             UndirectedEdge[97, 168] -> 
             RGBColor[
              0.5562174687857758, 0.6498761073301125, 0.9585804738963757], 
             UndirectedEdge[88, 132] -> 
             RGBColor[
              0.8947680641910523, 0.9166701790551881, 0.8954060764061295], 
             UndirectedEdge[329, 353] -> 
             RGBColor[
              0.22275923690238936`, 0.35146446010874544`, 0.9359971810476075],
              UndirectedEdge[189, 339] -> 
             RGBColor[
              0.333153622737486, 0.4622245787566195, 0.942476989061352], 
             UndirectedEdge[316, 380] -> 
             RGBColor[
              0.25988508585516024`, 0.3904860812728869, 0.9381114432226962], 
             UndirectedEdge[156, 295] -> 
             RGBColor[
              0.2141734445733891, 0.3424402480002911, 0.9355082328760125], 
             UndirectedEdge[154, 228] -> 
             RGBColor[
              0.39900760332101687`, 0.520022064116572, 0.9466453895484133], 
             UndirectedEdge[29, 91] -> 
             RGBColor[
              0.25152521102249714`, 0.3816993227770795, 0.9376353607183026], 
             UndirectedEdge[6, 198] -> 
             RGBColor[
              0.9099185860419527, 0.9263319020393368, 0.75030590143584], 
             UndirectedEdge[56, 254] -> 
             RGBColor[
              0.46022321075082034`, 0.5726042579779009, 0.9506674811679487], 
             UndirectedEdge[245, 315] -> 
             RGBColor[
              0.23658653725822024`, 0.3659978294842021, 0.9367846253472143], 
             UndirectedEdge[174, 281] -> 
             RGBColor[
              0.6802997161269625, 0.7500157979571946, 0.9688781332846546], 
             UndirectedEdge[89, 329] -> 
             RGBColor[
              0.22686082544463082`, 0.3557754897223749, 0.9362307604473317], 
             UndirectedEdge[260, 267] -> 
             RGBColor[
              0.6900764896095811, 0.7567221842679797, 0.9704893279445472], 
             UndirectedEdge[202, 363] -> 
             RGBColor[
              0.8594260597663401, 0.4513198993592995, 0.20428679439717456`], 
             UndirectedEdge[43, 238] -> 
             RGBColor[
              0.22832917766795519`, 0.3573188210079969, 0.9363143809342176], 
             UndirectedEdge[276, 377] -> 
             RGBColor[
              0.590222766132432, 0.6752773818608311, 0.9624624311800029], 
             UndirectedEdge[284, 369] -> 
             RGBColor[
              0.25072601947789425`, 0.3808593217920313, 0.9375898479421354], 
             UndirectedEdge[53, 249] -> 
             RGBColor[
              0.279406621010689, 0.4110044524581648, 0.9392231657702803], 
             UndirectedEdge[15, 105] -> 
             RGBColor[
              0.36060251301143975`, 0.486305845826277, 0.9442147886158565], 
             UndirectedEdge[97, 112] -> 
             RGBColor[
              0.38560280932821134`, 0.5084115053045399, 0.9457912479285857], 
             UndirectedEdge[120, 246] -> 
             RGBColor[
              0.505090585435528, 0.6088359587265868, 0.9542531127865411], 
             UndirectedEdge[53, 308] -> 
             RGBColor[
              0.27516616979901054`, 0.4065474693745552, 0.9389816783469607], 
             UndirectedEdge[188, 392] -> 
             RGBColor[
              0.25751756533120074`, 0.38799766709273437`, 0.9379766164312895],
              UndirectedEdge[91, 273] -> 
             RGBColor[
              0.26902930475390907`, 0.40009723511243644`, 0.9386321929613204],
              UndirectedEdge[327, 354] -> 
             RGBColor[
              0.2991827847858058, 0.430880112131681, 0.9403827211333795], 
             UndirectedEdge[51, 376] -> 
             RGBColor[
              0.405658343586251, 0.5257826010583926, 0.9470691688370954], 
             UndirectedEdge[202, 214] -> 
             RGBColor[
              0.9200563597791344, 0.7107376048071281, 0.556968147234525], 
             UndirectedEdge[69, 132] -> 
             RGBColor[
              0.6437204915353074, 0.7192373735289359, 0.9667380893382732], 
             UndirectedEdge[130, 387] -> 
             RGBColor[
              0.35198717062244894`, 0.47789208825307206`, 0.9437006686594926],
              UndirectedEdge[61, 306] -> 
             RGBColor[
              0.9818610097196364, 0.9499548547858537, 0.42826904779571534`], 
             UndirectedEdge[312, 356] -> 
             RGBColor[
              0.4906677898927829, 0.5973852420238213, 0.9530463122771483], 
             UndirectedEdge[18, 247] -> 
             RGBColor[
              0.926107052730001, 0.8138393200274576, 0.6108347292188259], 
             UndirectedEdge[56, 320] -> 
             RGBColor[
              0.5804145257698448, 0.6691464316920486, 0.9608367095033534], 
             UndirectedEdge[43, 124] -> 
             RGBColor[
              0.22535325774935577`, 0.3541909404893282, 0.9361449066973324], 
             UndirectedEdge[259, 318] -> 
             RGBColor[
              0.2174190793227137, 0.34585161590696, 0.9356930669735002], 
             UndirectedEdge[267, 384] -> 
             RGBColor[
              0.6598133920654725, 0.7330804224584619, 0.9674729852060762], 
             UndirectedEdge[44, 324] -> 
             RGBColor[
              0.2889570987994522, 0.4210426101494208, 0.9397670513516847], 
             UndirectedEdge[62, 204] -> 
             RGBColor[
              0.17899762953989296`, 0.30546823612459895`, 0.9335050222478098],
              UndirectedEdge[42, 109] -> 
             RGBColor[
              0.9631611562508396, 0.9703111795583055, 0.8704491819362283], 
             UndirectedEdge[8, 21] -> 
             RGBColor[
              0.3116185481608299, 0.44433005683844234`, 0.9410770362287135], 
             UndirectedEdge[48, 349] -> 
             RGBColor[
              0.43541101780241814`, 0.5515528720515495, 0.9489649829288928], 
             UndirectedEdge[222, 332] -> 
             RGBColor[
              0.5660742539559687, 0.6586036065728093, 0.9589825853511816], 
             UndirectedEdge[58, 167] -> 
             RGBColor[
              0.2911802301180382, 0.4233792621199214, 0.9398936553914501], 
             UndirectedEdge[76, 144] -> 
             RGBColor[
              0.8626912709570241, 0.4513693690163807, 0.2064327327986027], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.44236640792617826`, 0.5377470693075241, 0.9524063925246276], 
             UndirectedEdge[6, 166] -> 
             RGBColor[
              0.9090583234505556, 0.5897855777490221, 0.34432575904947005`], 
             UndirectedEdge[79, 343] -> 
             RGBColor[
              0.6565032648608529, 0.7307948803461315, 0.9669377087053699], 
             UndirectedEdge[142, 257] -> 
             RGBColor[
              0.822095571600614, 0.17084182242934073`, 0.16879205035911396`], 
             UndirectedEdge[175, 256] -> 
             RGBColor[
              0.20212025348377827`, 0.329771579948656, 0.9348218214745575], 
             UndirectedEdge[8, 171] -> 
             RGBColor[
              0.2917662705538139, 0.42384970493064567`, 0.9399323578314926], 
             UndirectedEdge[31, 214] -> 
             RGBColor[
              0.5834952534993698, 0.6486610383850888, 0.9230487158880236], 
             UndirectedEdge[41, 114] -> 
             RGBColor[
              0.3348490984330268, 0.46445119188281303`, 0.9425572663500889], 
             UndirectedEdge[72, 399] -> 
             RGBColor[
              0.23130276285488832`, 0.3604442475756538, 0.9364837222115884], 
             UndirectedEdge[278, 392] -> 
             RGBColor[
              0.2501824179205401, 0.3802879620889227, 0.9375588906376304], 
             UndirectedEdge[6, 323] -> 
             RGBColor[
              0.9117788938600264, 0.9278152609967583, 0.7504833392562442], 
             UndirectedEdge[132, 323] -> 
             RGBColor[
              0.8147163030891271, 0.8552644900665589, 0.9821450311245175], 
             UndirectedEdge[200, 355] -> 
             RGBColor[
              0.2507904105311417, 0.380927000871623, 0.9375935149173598], 
             UndirectedEdge[98, 215] -> 
             RGBColor[
              0.8984291495802124, 0.5426319701729883, 0.2667341084618861], 
             UndirectedEdge[12, 367] -> 
             RGBColor[
              0.21887583976336028`, 0.3473827634940262, 0.9357760273255111], 
             UndirectedEdge[88, 140] -> 
             RGBColor[
              0.8311193811821351, 0.8669473441407145, 0.8890621705145608], 
             UndirectedEdge[195, 327] -> 
             RGBColor[
              0.2821434199050674, 0.41297065928389304`, 0.9394123545109028], 
             UndirectedEdge[142, 381] -> 
             RGBColor[
              0.9073655012701238, 0.5791717949250715, 0.46576856864206445`], 
             UndirectedEdge[313, 359] -> 
             RGBColor[
              0.2641882368664749, 0.39500896582131095`, 0.9383565013068491], 
             UndirectedEdge[64, 82] -> 
             RGBColor[
              0.38908871359710695`, 0.5114308203756144, 0.9460133666661356], 
             UndirectedEdge[98, 297] -> 
             RGBColor[
              0.9621045612745434, 0.9478624391979251, 0.6712874553374975], 
             UndirectedEdge[139, 305] -> 
             RGBColor[
              0.20703664012749182`, 0.3349390140281161, 0.9351018024207747], 
             UndirectedEdge[288, 375] -> 
             RGBColor[
              0.24993566591258726`, 0.38002861008358335`, 0.9375448384758145],
              UndirectedEdge[136, 194] -> 
             RGBColor[
              0.5033185862068833, 0.6058836865205527, 0.954531849750919], 
             UndirectedEdge[254, 349] -> 
             RGBColor[
              0.45744526540329744`, 0.5701981413414695, 0.9504904729468453], 
             UndirectedEdge[348, 351] -> 
             RGBColor[
              0.2543498568494185, 0.38466820463406326`, 0.9377962201194567], 
             UndirectedEdge[65, 282] -> 
             RGBColor[
              0.5810969797016021, 0.6707307553552915, 0.9602123891284602], 
             UndirectedEdge[131, 215] -> 
             RGBColor[
              0.8708771882594211, 0.43978719004972067`, 0.21128818862239418`],
              UndirectedEdge[230, 250] -> 
             RGBColor[
              0.9785422248709081, 0.9480049704007043, 0.5891428358439234], 
             UndirectedEdge[26, 111] -> 
             RGBColor[
              0.6645955027358419, 0.5448101324102603, 0.5834436797495368], 
             UndirectedEdge[301, 390] -> 
             RGBColor[
              0.26155859013835736`, 0.392245040380827, 0.9382067468158966], 
             UndirectedEdge[3, 309] -> 
             RGBColor[
              0.32043505349243634`, 0.4484572206151509, 0.9417673069857059], 
             UndirectedEdge[90, 268] -> 
             RGBColor[
              0.7615624007787926, 0.45211356179516854`, 0.5677648921175946], 
             UndirectedEdge[17, 187] -> 
             RGBColor[
              0.6897252223294911, 0.7560947412907055, 0.9707766661911668], 
             UndirectedEdge[4, 206] -> 
             RGBColor[
              0.23187928370438585`, 0.3610502075420088, 0.9365165542210812], 
             UndirectedEdge[19, 231] -> 
             RGBColor[
              0.2915341164557601, 0.4237512190985569, 0.9399138086948555], 
             UndirectedEdge[76, 138] -> 
             RGBColor[
              0.8331436561867612, 0.2557622418600043, 0.17937170863583543`], 
             UndirectedEdge[28, 390] -> 
             RGBColor[
              0.2772941937947283, 0.40878415751856884`, 0.9391028661653874], 
             UndirectedEdge[123, 174] -> 
             RGBColor[
              0.8514507591880022, 0.8841310051490996, 0.9509891763922267], 
             UndirectedEdge[2, 98] -> 
             RGBColor[
              0.8980106482873484, 0.5394151858476, 0.26633335115120993`], 
             UndirectedEdge[20, 364] -> 
             RGBColor[
              0.37859437323609996`, 0.5023411502157933, 0.945344676578113], 
             UndirectedEdge[56, 196] -> 
             RGBColor[
              0.3744295737159023, 0.4977332530910004, 0.9451159345325955], 
             UndirectedEdge[360, 374] -> 
             RGBColor[
              0.293247724709362, 0.42540017170025574`, 0.9400169674113716], 
             UndirectedEdge[39, 360] -> 
             RGBColor[
              0.29174189371093673`, 0.42381744784571107`, 0.9399312125636886],
              UndirectedEdge[261, 264] -> 
             RGBColor[
              0.1847396920189574, 0.3115035078578844, 0.9338320242113725], 
             UndirectedEdge[101, 253] -> 
             RGBColor[
              0.3012788054166666, 0.43094522374745403`, 0.9405803668258977], 
             UndirectedEdge[141, 273] -> 
             RGBColor[
              0.31775067217972763`, 0.44656178652298995`, 0.9415805292809634],
              UndirectedEdge[171, 182] -> 
             RGBColor[
              0.2806534492526592, 0.41231494799395196`, 0.9392941707941435], 
             UndirectedEdge[156, 175] -> 
             RGBColor[
              0.18244584031582461`, 0.30909252427929373`, 0.9337013927503286],
              UndirectedEdge[121, 250] -> 
             RGBColor[
              0.7707116790518824, 0.8187741201767487, 0.9013688926659322], 
             UndirectedEdge[68, 308] -> 
             RGBColor[
              0.26890650081077455`, 0.39996816038198235`, 0.938625199458431], 
             UndirectedEdge[39, 390] -> 
             RGBColor[
              0.26969566944831447`, 0.40079762665621843`, 0.9386701414448686],
              UndirectedEdge[54, 181] -> 
             RGBColor[
              0.5096518890083631, 0.6127613709392468, 0.9545507619731439], 
             UndirectedEdge[196, 313] -> 
             RGBColor[
              0.2903662346350581, 0.4225237012570149, 0.9398472995528928], 
             UndirectedEdge[200, 241] -> 
             RGBColor[
              0.2808108014657587, 0.41248033514662596`, 0.9393031317698977], 
             UndirectedEdge[186, 255] -> 
             RGBColor[
              0.2544713249858168, 0.38479587534694254`, 0.9378031375501286], 
             UndirectedEdge[11, 38] -> 
             RGBColor[
              0.9446269367354516, 0.8152649274529434, 0.2894401056343812], 
             UndirectedEdge[173, 310] -> 
             RGBColor[
              0.20447288081658893`, 0.33224434044062834`, 0.9349558001207607],
              UndirectedEdge[106, 173] -> 
             RGBColor[
              0.5874312139478495, 0.658182594689114, 0.9541358462016971], 
             UndirectedEdge[51, 396] -> 
             RGBColor[
              0.3256114518738936, 0.4536350211799036, 0.9420717220904409], 
             UndirectedEdge[6, 18] -> 
             RGBColor[
              0.9692770544063248, 0.9734175595259907, 0.7474672305772001], 
             UndirectedEdge[238, 287] -> 
             RGBColor[
              0.24471825055354252`, 0.3745447757379873, 0.9372477143895912], 
             UndirectedEdge[93, 225] -> 
             RGBColor[
              0.25117310830966183`, 0.38132924050128825`, 0.9376153089896959],
              UndirectedEdge[116, 276] -> 
             RGBColor[
              0.5908937430052579, 0.6758585483037947, 0.9625051852330178], 
             UndirectedEdge[135, 276] -> 
             RGBColor[
              0.6344220971523353, 0.7122040883931675, 0.9656535874330512], 
             UndirectedEdge[147, 172] -> 
             RGBColor[
              0.29308124725627194`, 0.4253773516636531, 0.9400019155051696], 
             UndirectedEdge[185, 224] -> 
             RGBColor[
              0.8996759960158076, 0.5563318548969114, 0.2651346625378677], 
             UndirectedEdge[160, 166] -> 
             RGBColor[
              0.8271233428626157, 0.2094874755325008, 0.1736066497976622], 
             UndirectedEdge[63, 156] -> 
             RGBColor[
              0.5722602959769347, 0.592332243346744, 0.6137097186204522], 
             UndirectedEdge[247, 302] -> 
             RGBColor[
              0.9471422868502191, 0.8188837514344283, 0.3245541983516868], 
             UndirectedEdge[81, 240] -> 
             RGBColor[
              0.22946097871463872`, 0.3585084156683923, 0.9363788353294766], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.3163910437219365, 0.4480120932607672, 0.9413976728873965], 
             UndirectedEdge[12, 212] -> 
             RGBColor[
              0.2146670795751315, 0.34295908968538924`, 0.9355363446590942], 
             UndirectedEdge[18, 74] -> 
             RGBColor[
              0.8849400211257357, 0.9108459941170431, 0.9803872287207334], 
             UndirectedEdge[1, 7] -> 
             RGBColor[
              0.37469401379728373`, 0.4989628549076562, 0.945096149123624], 
             UndirectedEdge[231, 331] -> 
             RGBColor[
              0.38038829696430865`, 0.5038892359163952, 0.9454591932807552], 
             UndirectedEdge[58, 351] -> 
             RGBColor[
              0.27227774194596055`, 0.4035115485640963, 0.9388171866537756], 
             UndirectedEdge[142, 279] -> 
             RGBColor[
              0.8836168067234831, 0.49456770966954106`, 0.2217143859275474], 
             UndirectedEdge[303, 344] -> 
             RGBColor[
              0.3051201948561256, 0.4369324167818024, 0.9407277420647475], 
             UndirectedEdge[302, 323] -> 
             RGBColor[
              0.9087436394185031, 0.9180978599174181, 0.6943707488073377], 
             UndirectedEdge[144, 366] -> 
             RGBColor[
              0.8898592758254438, 0.5927585201905767, 0.22980821876360358`], 
             UndirectedEdge[56, 342] -> 
             RGBColor[
              0.5271466154555224, 0.626935692782203, 0.9559359367348119], 
             UndirectedEdge[137, 293] -> 
             RGBColor[
              0.2163935789679292, 0.34477375001360355`, 0.9356346662453872], 
             UndirectedEdge[39, 374] -> 
             RGBColor[
              0.2745978955714905, 0.40595017713076464`, 0.9389493159703898], 
             UndirectedEdge[4, 278] -> 
             RGBColor[
              0.24230606056995913`, 0.37200941112356267`, 0.9371103437385414],
              UndirectedEdge[238, 396] -> 
             RGBColor[
              0.25376131131834845`, 0.3840496059649667, 0.9377627033221374], 
             UndirectedEdge[118, 293] -> 
             RGBColor[
              0.20864634306607288`, 0.33663091387762584`, 0.9351934726217848],
              UndirectedEdge[201, 228] -> 
             RGBColor[
              0.3221417320475673, 0.45045653149250003`, 0.9418569760468667], 
             UndirectedEdge[212, 336] -> 
             RGBColor[
              0.21095186783418274`, 0.3390541665876225, 0.9353247688466104], 
             UndirectedEdge[186, 200] -> 
             RGBColor[
              0.2595636633022175, 0.3901482457903771, 0.9380931386838082], 
             UndirectedEdge[7, 356] -> 
             RGBColor[
              0.4538916995859768, 0.5657933672154302, 0.9506306565950378], 
             UndirectedEdge[215, 269] -> 
             RGBColor[
              0.9061735630089964, 0.5684125935804545, 0.32599457253607145`], 
             UndirectedEdge[36, 122] -> 
             RGBColor[
              0.4828824410191481, 0.5908684223901826, 0.952487665639901], 
             UndirectedEdge[297, 352] -> 
             RGBColor[
              0.970396577990795, 0.974814330666099, 0.7901511578367646], 
             UndirectedEdge[228, 243] -> 
             RGBColor[
              0.3281145647549416, 0.45673435736741674`, 0.9421971200335375], 
             UndirectedEdge[100, 271] -> 
             RGBColor[
              0.3417009842764249, 0.4702049097204598, 0.9430004912657755], 
             UndirectedEdge[157, 298] -> 
             RGBColor[
              0.6463369873520685, 0.7210185843298552, 0.9671902179184984], 
             UndirectedEdge[272, 384] -> 
             RGBColor[
              0.6977223834801167, 0.763785295951966, 0.9705061046650639], 
             UndirectedEdge[35, 114] -> 
             RGBColor[
              0.30495946572485455`, 0.43600078246607, 0.9407465148814157], 
             UndirectedEdge[15, 155] -> 
             RGBColor[
              0.30420326810120896`, 0.4370673007485326, 0.9406352981387334], 
             UndirectedEdge[36, 262] -> 
             RGBColor[
              0.7291600782306236, 0.787348496129779, 0.9720379295278863], 
             UndirectedEdge[111, 185] -> 
             RGBColor[
              0.8488843177529799, 0.35210056877181173`, 0.19347970101943163`],
              UndirectedEdge[26, 400] -> 
             RGBColor[
              0.4223618806328297, 0.5402016308185901, 0.9481469689308566], 
             UndirectedEdge[61, 131] -> 
             RGBColor[
              0.9579060415796807, 0.8592435772757068, 0.3867967672286041], 
             UndirectedEdge[168, 350] -> 
             RGBColor[
              0.5514466203488134, 0.6457438382038303, 0.9582764796526682], 
             UndirectedEdge[16, 208] -> 
             RGBColor[
              0.2374736143413805, 0.36693020374253915`, 0.9368351430747874], 
             UndirectedEdge[125, 303] -> 
             RGBColor[
              0.28379884955745593`, 0.41562096314419106`, 0.9394732966882988],
              UndirectedEdge[145, 164] -> 
             RGBColor[
              0.2402812832877892, 0.36988124182170756`, 0.9369950356677115], 
             UndirectedEdge[152, 256] -> 
             RGBColor[
              0.2044622657846265, 0.33223318336900387`, 0.9349551956103941], 
             UndirectedEdge[237, 246] -> 
             RGBColor[
              0.5111109439056949, 0.6137235569467266, 0.9547270574586124], 
             UndirectedEdge[16, 284] -> 
             RGBColor[
              0.24292930031788273`, 0.3726644756143127, 0.9371458363201851], 
             UndirectedEdge[240, 309] -> 
             RGBColor[
              0.2549984797573888, 0.3853499484354077, 0.9378331582345141], 
             UndirectedEdge[151, 249] -> 
             RGBColor[
              0.2927023996318287, 0.42432368443317114`, 0.9400043408205379], 
             UndirectedEdge[47, 311] -> 
             RGBColor[
              0.47663297852550124`, 0.5854636862286419, 0.9520871802976505], 
             UndirectedEdge[29, 190] -> 
             RGBColor[
              0.2407660977459846, 0.370390812556283, 0.937022645133887], 
             UndirectedEdge[99, 384] -> 
             RGBColor[
              0.863277719993484, 0.893302482160574, 0.9487341980321153], 
             UndirectedEdge[5, 398] -> 
             RGBColor[
              0.8904342144946242, 0.9153759950567726, 0.9860799767962038], 
             UndirectedEdge[36, 157] -> 
             RGBColor[
              0.49446056893751156`, 0.6004643909150807, 0.9533448937369567], 
             UndirectedEdge[40, 55] -> 
             RGBColor[
              0.37142239221905604`, 0.496129140733077, 0.9448876842896408], 
             UndirectedEdge[163, 319] -> 
             RGBColor[
              0.2432784612852803, 0.3730314659291315, 0.9371657205207411], 
             UndirectedEdge[13, 74] -> 
             RGBColor[
              0.8942268027978797, 0.9177720606824189, 0.9646671297303714], 
             UndirectedEdge[47, 158] -> 
             RGBColor[
              0.468503909528975, 0.5788641418068768, 0.9514472302084831], 
             UndirectedEdge[252, 330] -> 
             RGBColor[
              0.2245525377985933, 0.3533493330524997, 0.9360993068806954], 
             UndirectedEdge[102, 185] -> 
             RGBColor[
              0.8214937595564198, 0.16621603134194454`, 0.16821575446594406`],
              UndirectedEdge[41, 356] -> 
             RGBColor[
              0.4295993605310475, 0.5447525640945126, 0.9490827702313296], 
             UndirectedEdge[33, 175] -> 
             RGBColor[
              0.17893676407552545`, 0.30540426266245535`, 0.9335015560496566],
              UndirectedEdge[12, 126] -> 
             RGBColor[
              0.2152393660615204, 0.3435605990676429, 0.935568935527872], 
             UndirectedEdge[18, 191] -> 
             RGBColor[
              0.8120299641162554, 0.853850200152278, 0.9731302939895274], 
             UndirectedEdge[64, 171] -> 
             RGBColor[
              0.3360864294513485, 0.46223759897173367`, 0.9427563991656658], 
             UndirectedEdge[73, 184] -> 
             RGBColor[
              0.230439447723778, 0.35953684863551605`, 0.9364345576920319], 
             UndirectedEdge[93, 316] -> 
             RGBColor[
              0.2497588091651779, 0.37984272242869066`, 0.9375347667456857], 
             UndirectedEdge[20, 362] -> 
             RGBColor[
              0.406159003588231, 0.5262162475882044, 0.9471010704497052], 
             UndirectedEdge[32, 330] -> 
             RGBColor[
              0.2205286799485376, 0.349120003324768, 0.935870154128899], 
             UndirectedEdge[124, 277] -> 
             RGBColor[
              0.24054204876353127`, 0.3701553228701986, 0.9370098858757869], 
             UndirectedEdge[267, 331] -> 
             RGBColor[
              0.511645707636986, 0.6143827846807824, 0.9547069650679356], 
             UndirectedEdge[134, 167] -> 
             RGBColor[
              0.25893816716997997`, 0.3894908096966502, 0.9380575176044159], 
             UndirectedEdge[143, 398] -> 
             RGBColor[
              0.7820348247548993, 0.8302487551810782, 0.97550730112162], 
             UndirectedEdge[109, 320] -> 
             RGBColor[
              0.8519952349988198, 0.8825603077930796, 0.8596099472355513], 
             UndirectedEdge[28, 147] -> 
             RGBColor[
              0.2865134731880893, 0.418474204697066, 0.9396278904881377], 
             UndirectedEdge[54, 311] -> 
             RGBColor[
              0.48568276233296276`, 0.5933021541073054, 0.9526638245194523], 
             UndirectedEdge[160, 289] -> 
             RGBColor[
              0.863615444991354, 0.42809333252077686`, 0.20612813226240806`], 
             UndirectedEdge[209, 240] -> 
             RGBColor[
              0.24561974977362988`, 0.37549230857665095`, 0.9372990534365266],
              UndirectedEdge[31, 261] -> 
             RGBColor[
              0.18133289143212553`, 0.3079227444374911, 0.9336380119578622], 
             UndirectedEdge[245, 248] -> 
             RGBColor[
              0.2230533686520324, 0.3517736112266503, 0.9360139314156208], 
             UndirectedEdge[81, 245] -> 
             RGBColor[
              0.22480714766170556`, 0.3536169441618284, 0.9361138065357382], 
             UndirectedEdge[308, 386] -> 
             RGBColor[
              0.30022575986843436`, 0.4300559235597101, 0.9405124330603728], 
             UndirectedEdge[320, 349] -> 
             RGBColor[
              0.5776365804223218, 0.666740315055617, 0.9606597012822499], 
             UndirectedEdge[222, 356] -> 
             RGBColor[
              0.5616526527416191, 0.6550139515161355, 0.9586345007067291], 
             UndirectedEdge[200, 374] -> 
             RGBColor[
              0.27338169058223005`, 0.4046718685752019, 0.9388800548954654], 
             UndirectedEdge[73, 348] -> 
             RGBColor[
              0.2530355996274438, 0.3832868369650472, 0.9377213751149346], 
             UndirectedEdge[23, 81] -> 
             RGBColor[
              0.2165666874460731, 0.34495569799984427`, 0.9356445245171263], 
             UndirectedEdge[25, 233] -> 
             RGBColor[
              0.8330846738019452, 0.25530887740406205`, 0.17931522703752448`],
              UndirectedEdge[168, 170] -> 
             RGBColor[
              0.5575600626847299, 0.651038994684655, 0.958666022792408], 
             UndirectedEdge[73, 284] -> 
             RGBColor[
              0.24355703331110456`, 0.3733242627907594, 0.9371815847855014], 
             UndirectedEdge[143, 234] -> 
             RGBColor[
              0.4816918202752083, 0.5869870677287701, 0.9531992911334777], 
             UndirectedEdge[288, 374] -> 
             RGBColor[
              0.26056485892169184`, 0.3912005658659134, 0.9381501552932011], 
             UndirectedEdge[254, 344] -> 
             RGBColor[
              0.39507001975859724`, 0.5161718386350326, 0.946515977450629], 
             UndirectedEdge[6, 102] -> 
             RGBColor[
              0.9063222891856516, 0.5687552194511105, 0.3417057295474893], 
             UndirectedEdge[205, 276] -> 
             RGBColor[
              0.8804173286055655, 0.9045483902483498, 0.8526723312886473], 
             UndirectedEdge[101, 244] -> 
             RGBColor[
              0.2604390037563816, 0.39106828410749395`, 0.9381429880277227], 
             UndirectedEdge[58, 80] -> 
             RGBColor[
              0.31661369550810525`, 0.44773804311104304`, 0.9414289555561544],
              UndirectedEdge[23, 292] -> 
             RGBColor[
              0.21221830344661968`, 0.3403852707129492, 0.9353968904812151], 
             UndirectedEdge[101, 397] -> 
             RGBColor[
              0.2550956906132599, 0.3854521232084524, 0.9378386942489454], 
             UndirectedEdge[105, 168] -> 
             RGBColor[
              0.5437472998304071, 0.6390750737498879, 0.957785885757477], 
             UndirectedEdge[166, 340] -> 
             RGBColor[
              0.9092736160962124, 0.5902460669486567, 0.36775903489702405`], 
             UndirectedEdge[138, 317] -> 
             RGBColor[
              0.9049849697863369, 0.5700377324760639, 0.4855767081666582], 
             UndirectedEdge[71, 120] -> 
             RGBColor[
              0.7187491637803132, 0.7794609626924269, 0.9732879603430942], 
             UndirectedEdge[231, 290] -> 
             RGBColor[
              0.3569089205700484, 0.48355258019145775`, 0.9439631081789103], 
             UndirectedEdge[13, 224] -> 
             RGBColor[
              0.9697208187554422, 0.9510352770851425, 0.6530724790472836], 
             UndirectedEdge[40, 159] -> 
             RGBColor[
              0.33537336280871854`, 0.46490528333474357`, 0.9425906720125191],
              UndirectedEdge[20, 265] -> 
             RGBColor[
              0.49977683892029745`, 0.6035406289522859, 0.9541059564454999], 
             UndirectedEdge[43, 299] -> 
             RGBColor[
              0.22078197517346282`, 0.34938623266600927`, 0.9358845789172419],
              UndirectedEdge[219, 220] -> 
             RGBColor[
              0.4613111794873067, 0.5733857750910603, 0.9507812424766675], 
             UndirectedEdge[56, 290] -> 
             RGBColor[
              0.42803437429076585`, 0.5451635942026395, 0.9484949497272399], 
             UndirectedEdge[64, 157] -> 
             RGBColor[
              0.43410205704708005`, 0.5499866920911975, 0.9490010571312653], 
             UndirectedEdge[13, 340] -> 
             RGBColor[
              0.9787791287241259, 0.9808041152910011, 0.7551804074343922], 
             UndirectedEdge[16, 188] -> 
             RGBColor[
              0.25447321455412675`, 0.38479786140304184`, 0.9378032451582485],
              UndirectedEdge[171, 308] -> 
             RGBColor[
              0.26715048285961845`, 0.3981224741773486, 0.9385251968339084], 
             UndirectedEdge[288, 379] -> 
             RGBColor[
              0.23299167582952007`, 0.3622194021952592, 0.9365799033069708], 
             UndirectedEdge[81, 353] -> 
             RGBColor[
              0.2150475477536689, 0.34335898586410785`, 0.9355580117590097], 
             UndirectedEdge[153, 188] -> 
             RGBColor[
              0.2922583395910017, 0.4237094580639409, 0.939984452630228], 
             UndirectedEdge[148, 356] -> 
             RGBColor[
              0.5711332147381206, 0.6627106988393463, 0.9593808452755366], 
             UndirectedEdge[198, 247] -> 
             RGBColor[
              0.866748584365629, 0.7667536625408037, 0.6136734000774657], 
             UndirectedEdge[94, 375] -> 
             RGBColor[
              0.25748465436672835`, 0.3879630755823982, 0.9379747422005502], 
             UndirectedEdge[298, 307] -> 
             RGBColor[
              0.9043350538106595, 0.9251046086494896, 0.9386480207606034], 
             UndirectedEdge[9, 142] -> 
             RGBColor[
              0.8236257057163587, 0.18260310375199956`, 0.1702573085163904], 
             UndirectedEdge[203, 284] -> 
             RGBColor[
              0.26769783285159876`, 0.3986977737229138, 0.93855636760622], 
             UndirectedEdge[370, 400] -> 
             RGBColor[
              0.6104137657145253, 0.6900683539569277, 0.9649050090474223], 
             UndirectedEdge[63, 381] -> 
             RGBColor[
              0.975854040924288, 0.9316564884007599, 0.528376469194335], 
             UndirectedEdge[222, 251] -> 
             RGBColor[
              0.7136213718875605, 0.7756511419302459, 0.9724778106511085], 
             UndirectedEdge[103, 234] -> 
             RGBColor[
              0.34165277525472826`, 0.4703441947830308, 0.9429907906209125], 
             UndirectedEdge[150, 399] -> 
             RGBColor[
              0.2527398969113101, 0.3829760346617555, 0.9377045352827038], 
             UndirectedEdge[321, 338] -> 
             RGBColor[
              0.9060374188254435, 0.923886001186349, 0.8010879565228419], 
             UndirectedEdge[154, 203] -> 
             RGBColor[
              0.36077780249875213`, 0.4853053517709617, 0.9442681500235399], 
             UndirectedEdge[225, 390] -> 
             RGBColor[
              0.26170368970244295`, 0.3923975492225247, 0.9382150100214157], 
             UndirectedEdge[54, 121] -> 
             RGBColor[
              0.502593813473784, 0.607031307257596, 0.9539951244124792], 
             UndirectedEdge[234, 346] -> 
             RGBColor[
              0.34188570275875485`, 0.4705459448797419, 0.9430056325554994], 
             UndirectedEdge[358, 391] -> 
             RGBColor[
              0.8944837314108928, 0.5317010026573729, 0.24979314294089291`], 
             UndirectedEdge[74, 357] -> 
             RGBColor[
              0.7501817896070486, 0.8048048860165811, 0.9757247096384958], 
             UndirectedEdge[130, 364] -> 
             RGBColor[
              0.379967678176128, 0.5035306379305324, 0.9454321823545258], 
             UndirectedEdge[202, 381] -> 
             RGBColor[
              0.9247433274483484, 0.7127453819428937, 0.4824095946157798], 
             UndirectedEdge[98, 307] -> 
             RGBColor[
              0.9814050384421338, 0.9620825967866911, 0.6308199289588313], 
             UndirectedEdge[242, 317] -> 
             RGBColor[
              0.954486951543472, 0.8521857620679489, 0.5290777523178287], 
             UndirectedEdge[9, 279] -> 
             RGBColor[
              0.8856585389447988, 0.5102613582153388, 0.22366955100848618`], 
             UndirectedEdge[200, 399] -> 
             RGBColor[
              0.2527693356026074, 0.3830069765928298, 0.9377062117726225], 
             UndirectedEdge[275, 306] -> 
             RGBColor[
              0.9812383782660234, 0.9513676250265612, 0.559996794380909], 
             UndirectedEdge[121, 181] -> 
             RGBColor[
              0.5602542166801026, 0.6538786381225696, 0.9585244106973264], 
             UndirectedEdge[239, 271] -> 
             RGBColor[
              0.31565140111640955`, 0.4476420700773734, 0.9413406348615612], 
             UndirectedEdge[35, 354] -> 
             RGBColor[
              0.2804072432672092, 0.41205616989288285`, 0.9392801497275012], 
             UndirectedEdge[31, 310] -> 
             RGBColor[
              0.18289778193115996`, 0.30956754357176464`, 0.9337271301567341],
              UndirectedEdge[146, 154] -> 
             RGBColor[
              0.48274463326921224`, 0.5903240190384458, 0.9525963248033308], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.8938562482651202, 0.6317789737296462, 0.5786286100973383], 
             UndirectedEdge[265, 322] -> 
             RGBColor[
              0.5501554119867256, 0.6456799735265193, 0.9577293957987232], 
             UndirectedEdge[115, 284] -> 
             RGBColor[
              0.24130209476909242`, 0.37095417941174347`, 0.9370531693714164],
              UndirectedEdge[38, 391] -> 
             RGBColor[
              0.8930910009287811, 0.5270029957125417, 0.24438264801297166`], 
             UndirectedEdge[116, 328] -> 
             RGBColor[
              0.3628292631493686, 0.48868620423613895`, 0.944340137703926], 
             UndirectedEdge[92, 278] -> 
             RGBColor[
              0.2700397327532974, 0.4011592590046289, 0.9386897353410912], 
             UndirectedEdge[215, 217] -> 
             RGBColor[
              0.8210569332669986, 0.16285839306295227`, 0.16779744911786956`],
              UndirectedEdge[159, 210] -> 
             RGBColor[
              0.3156791522092831, 0.44703146697688845`, 0.9413656404050212], 
             UndirectedEdge[165, 298] -> 
             RGBColor[
              0.6780894534855002, 0.7467966667692734, 0.969689888365638], 
             UndirectedEdge[83, 254] -> 
             RGBColor[
              0.4111965295816905, 0.5301398109018447, 0.9475435443964437], 
             UndirectedEdge[103, 231] -> 
             RGBColor[
              0.3266251404157554, 0.4573222919288569, 0.942033452486374], 
             UndirectedEdge[245, 319] -> 
             RGBColor[
              0.2357412606353747, 0.36510939015995814`, 0.9367364880940181], 
             UndirectedEdge[58, 263] -> 
             RGBColor[
              0.28044730154374703`, 0.41209827368136553`, 0.9392824309870891],
              UndirectedEdge[206, 258] -> 
             RGBColor[
              0.24224766571092132`, 0.37194803442426605`, 0.9371070182377067],
              UndirectedEdge[213, 391] -> 
             RGBColor[
              0.8656794520004861, 0.4212316977913123, 0.20719030408487465`], 
             UndirectedEdge[78, 370] -> 
             RGBColor[
              0.8365302867115927, 0.5954450493775967, 0.5857332485541368], 
             UndirectedEdge[101, 270] -> 
             RGBColor[
              0.2552144898783262, 0.38557698876834556`, 0.937845459691343], 
             UndirectedEdge[135, 377] -> 
             RGBColor[
              0.4590787183907463, 0.5706961122538062, 0.9508478818462491], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.22879801729426974`, 0.3578116011814027, 0.9363410806573501], 
             UndirectedEdge[19, 83] -> 
             RGBColor[
              0.31363288900734776`, 0.44289778603368235`, 0.9413217134716801],
              UndirectedEdge[100, 112] -> 
             RGBColor[
              0.35276762831000186`, 0.47997132185075075`, 0.9436990192291159],
              UndirectedEdge[10, 296] -> 
             RGBColor[
              0.331723708667086, 0.46107618573568054`, 0.9423825762220581], 
             UndirectedEdge[85, 369] -> 
             RGBColor[
              0.24938070758750824`, 0.3794453136975352, 0.9375132344201885], 
             UndirectedEdge[79, 246] -> 
             RGBColor[
              0.5173044068287108, 0.618751689159956, 0.9552146295473145], 
             UndirectedEdge[227, 280] -> 
             RGBColor[
              0.23696761026347307`, 0.36639836137414694`, 0.9368063268911165],
              UndirectedEdge[112, 326] -> 
             RGBColor[
              0.3341557033790634, 0.4638506079381187, 0.9425130838303954], 
             UndirectedEdge[34, 308] -> 
             RGBColor[
              0.2866886948098787, 0.4183307981986623, 0.9396498632451982], 
             UndirectedEdge[29, 226] -> 
             RGBColor[
              0.23953161826969796`, 0.36909329635618626`, 0.936952343353961], 
             UndirectedEdge[204, 345] -> 
             RGBColor[
              0.1904371972329284, 0.3174919470804629, 0.9341564887046044], 
             UndirectedEdge[54, 265] -> 
             RGBColor[
              0.5219430916057815, 0.622739922920198, 0.9555183704657713], 
             UndirectedEdge[22, 100] -> 
             RGBColor[
              0.3344662411106874, 0.46260073594405915`, 0.9425884833453301], 
             UndirectedEdge[126, 336] -> 
             RGBColor[
              0.21152415432057162`, 0.33965567596987617`, 0.9353573597153882],
              UndirectedEdge[82, 157] -> 
             RGBColor[
              0.4242304983845992, 0.5414364441367214, 0.9483720501423687], 
             UndirectedEdge[344, 349] -> 
             RGBColor[
              0.3830038950089686, 0.5061604563464437, 0.9456256474062932], 
             UndirectedEdge[343, 349] -> 
             RGBColor[
              0.5837898565381997, 0.6715473011239714, 0.9612730023398459], 
             UndirectedEdge[2, 66] -> 
             RGBColor[
              0.8956170407292666, 0.531340985508409, 0.2570346377829214], 
             UndirectedEdge[211, 387] -> 
             RGBColor[
              0.27812297420375887`, 0.4096552582761729, 0.939150063983611], 
             UndirectedEdge[250, 265] -> 
             RGBColor[
              0.7900609571838799, 0.8344827358393506, 0.9028921387192244], 
             UndirectedEdge[217, 306] -> 
             RGBColor[
              0.8966008926384637, 0.5440937493586522, 0.25445421300955695`], 
             UndirectedEdge[374, 375] -> 
             RGBColor[
              0.26547453356081113`, 0.3963609452029792, 0.9384297540006862], 
             UndirectedEdge[38, 247] -> 
             RGBColor[
              0.9363993756149239, 0.7826453892822661, 0.2828200168311238], 
             UndirectedEdge[204, 310] -> 
             RGBColor[
              0.18075257528517846`, 0.3073127953728809, 0.9336049638117943], 
             UndirectedEdge[226, 266] -> 
             RGBColor[
              0.24681597923856835`, 0.37674962158963, 0.9373671769348919], 
             UndirectedEdge[319, 334] -> 
             RGBColor[
              0.25149135479282314`, 0.3816637377330832, 0.9376334326561084], 
             UndirectedEdge[73, 206] -> 
             RGBColor[
              0.23733902327111464`, 0.366788739994123, 0.9368274783124455], 
             UndirectedEdge[200, 255] -> 
             RGBColor[
              0.26556731627814384`, 0.3964584657216599, 0.9384350378391786], 
             UndirectedEdge[296, 383] -> 
             RGBColor[
              0.2908789334455868, 0.4230625802138626, 0.9398764969916824], 
             UndirectedEdge[235, 281] -> 
             RGBColor[
              0.6860438629162344, 0.7545031690861064, 0.9694506561545053], 
             UndirectedEdge[174, 272] -> 
             RGBColor[
              0.6878111560407678, 0.756042569748228, 0.9695182461395961], 
             UndirectedEdge[9, 131] -> 
             RGBColor[
              0.8740668087143025, 0.4643040105665355, 0.21434257277214977`], 
             UndirectedEdge[228, 361] -> 
             RGBColor[
              0.3617418491636495, 0.4877443408967252, 0.9442708486463184], 
             UndirectedEdge[149, 199] -> 
             RGBColor[
              0.2230106997449548, 0.3517287634999468, 0.9360115014844858], 
             UndirectedEdge[102, 400] -> 
             RGBColor[
              0.6044539714967849, 0.33060708272811645`, 0.5560794046708185], 
             UndirectedEdge[45, 350] -> 
             RGBColor[
              0.36412092231360993`, 0.48858020750687353`, 0.9444672858023867],
              UndirectedEdge[369, 392] -> 
             RGBColor[
              0.2527015805879449, 0.38293576177650346`, 0.937702353224772], 
             UndirectedEdge[82, 151] -> 
             RGBColor[
              0.34752633634939933`, 0.4754315781894705, 0.9433650487400788], 
             UndirectedEdge[260, 342] -> 
             RGBColor[
              0.706156116764429, 0.7697763499712335, 0.9717551750957918], 
             UndirectedEdge[296, 380] -> 
             RGBColor[
              0.28350610283773925`, 0.41531326778055483`, 0.939456625195691], 
             UndirectedEdge[105, 148] -> 
             RGBColor[
              0.520616067080279, 0.620721827134755, 0.9556738363326167], 
             UndirectedEdge[94, 288] -> 
             RGBColor[
              0.25257497972760906`, 0.38280269624533236`, 0.9376951434930652],
              UndirectedEdge[195, 258] -> 
             RGBColor[
              0.24931398381106837`, 0.3793751827779651, 0.9375094345998292], 
             UndirectedEdge[339, 374] -> 
             RGBColor[
              0.3209321143289635, 0.44937899853087393`, 0.9417809922375882], 
             UndirectedEdge[199, 367] -> 
             RGBColor[
              0.2225587298907346, 0.35125371452661747`, 0.9359857624699174], 
             UndirectedEdge[36, 298] -> 
             RGBColor[
              0.6715537144550077, 0.7414906593926315, 0.9691753710479567], 
             UndirectedEdge[147, 347] -> 
             RGBColor[
              0.28239395908436904`, 0.4141443341817761, 0.9393932902542057], 
             UndirectedEdge[38, 205] -> 
             RGBColor[
              0.9805298619657696, 0.9442896440229023, 0.524841136015259], 
             UndirectedEdge[16, 73] -> 
             RGBColor[
              0.24248824364408117`, 0.372200897085539, 0.937120718795097], 
             UndirectedEdge[108, 290] -> 
             RGBColor[
              0.3863513979794556, 0.5090598951690881, 0.945838947335492], 
             UndirectedEdge[225, 296] -> 
             RGBColor[
              0.2793148229194171, 0.41090796684390285`, 0.9392179380047856], 
             UndirectedEdge[24, 144] -> 
             RGBColor[
              0.8902955651891483, 0.5947396082931894, 0.23017226930310958`], 
             UndirectedEdge[209, 319] -> 
             RGBColor[
              0.24680833108244982`, 0.37674158289262827`, 0.9373667413837155],
              UndirectedEdge[80, 192] -> 
             RGBColor[
              0.3394530711598287, 0.46843892165637124`, 0.9428506274211075], 
             UndirectedEdge[42, 221] -> 
             RGBColor[
              0.9270423893059134, 0.944662453609973, 0.9929033247441504], 
             UndirectedEdge[22, 365] -> 
             RGBColor[
              0.27427955709376345`, 0.40561558320684826`, 0.9389311870650228],
              UndirectedEdge[80, 201] -> 
             RGBColor[
              0.30542134246892777`, 0.4359741704306982, 0.9407915676081757], 
             UndirectedEdge[39, 375] -> 
             RGBColor[
              0.2639687025623859, 0.39477822134843454`, 0.9383439991530031], 
             UndirectedEdge[15, 326] -> 
             RGBColor[
              0.3216255760176605, 0.45254598204008034`, 0.9417312126565649], 
             UndirectedEdge[86, 95] -> 
             RGBColor[
              0.2911574427094625, 0.42335531110870317`, 0.9398923576822427], 
             UndirectedEdge[59, 194] -> 
             RGBColor[
              0.3610366257463029, 0.4871335118181791, 0.9442259124337696], 
             UndirectedEdge[296, 324] -> 
             RGBColor[
              0.2907395975741168, 0.42291612937854317`, 0.9398685620199312], 
             UndirectedEdge[169, 245] -> 
             RGBColor[
              0.22529865841710267`, 0.3541335531293326, 0.936141797346133], 
             UndirectedEdge[258, 284] -> 
             RGBColor[
              0.24846567575091127`, 0.3784835572209025, 0.9374611247107626], 
             UndirectedEdge[33, 152] -> 
             RGBColor[
              0.18127877637637368`, 0.30786586608280325`, 0.9336349301854932],
              UndirectedEdge[246, 349] -> 
             RGBColor[
              0.44459099850605766`, 0.559504109937796, 0.9495499231817904], 
             UndirectedEdge[27, 395] -> 
             RGBColor[
              0.28524240829505776`, 0.41713823490432095`, 0.9395555052228516],
              UndirectedEdge[185, 340] -> 
             RGBColor[
              0.9087343059844912, 0.5861006931027701, 0.36724259092497624`], 
             UndirectedEdge[223, 321] -> 
             RGBColor[
              0.6359268279774656, 0.7126257479828174, 0.9663189746381065], 
             UndirectedEdge[274, 373] -> 
             RGBColor[
              0.24052488712014738`, 0.3701372848948911, 0.9370089085455846], 
             UndirectedEdge[156, 214] -> 
             RGBColor[
              0.5848663164286375, 0.6501021124541597, 0.9231267958935396], 
             UndirectedEdge[205, 221] -> 
             RGBColor[
              0.9585637141169614, 0.9664203575638242, 0.8602427231177231], 
             UndirectedEdge[97, 105] -> 
             RGBColor[
              0.42981427861771465`, 0.5467052578700499, 0.9486083636570456], 
             UndirectedEdge[130, 158] -> 
             RGBColor[
              0.4567607455909806, 0.5686928034323673, 0.9506989661864262], 
             UndirectedEdge[108, 143] -> 
             RGBColor[
              0.49610666284564264`, 0.5994724798522266, 0.954117792155521], 
             UndirectedEdge[176, 399] -> 
             RGBColor[
              0.22535125221155355`, 0.3541888325419396, 0.9361447924849214], 
             UndirectedEdge[150, 189] -> 
             RGBColor[
              0.28557376029945525`, 0.4174865068698732, 0.9395743752293106], 
             UndirectedEdge[253, 386] -> 
             RGBColor[
              0.3405394596215219, 0.4693798967384182, 0.942919851133231], 
             UndirectedEdge[46, 59] -> 
             RGBColor[
              0.30916725287120805`, 0.4399481765928165, 0.9410035436196971], 
             UndirectedEdge[186, 241] -> 
             RGBColor[
              0.2697148101734317, 0.4008177447719086, 0.9386712314808479], 
             UndirectedEdge[39, 93] -> 
             RGBColor[
              0.2591650880555334, 0.38972931793498194`, 0.9380704404131488], 
             UndirectedEdge[214, 264] -> 
             RGBColor[
              0.5869020540862017, 0.6522418018054821, 0.9232427281415339], 
             UndirectedEdge[234, 290] -> 
             RGBColor[
              0.37193655540902126`, 0.4965744830456317, 0.9449204463134487], 
             UndirectedEdge[148, 170] -> 
             RGBColor[
              0.5344288299346016, 0.632685748069522, 0.9565539733675475], 
             UndirectedEdge[50, 362] -> 
             RGBColor[
              0.4294033294821849, 0.5463267879239184, 0.948588402469489], 
             UndirectedEdge[271, 326] -> 
             RGBColor[
              0.3230890593454866, 0.4540841958078278, 0.941814555867055], 
             UndirectedEdge[61, 352] -> 
             RGBColor[
              0.9937500196167237, 0.9890402488671484, 0.5611063895673631], 
             UndirectedEdge[256, 333] -> 
             RGBColor[
              0.21043441051870343`, 0.338510286140365, 0.9352953004180034], 
             UndirectedEdge[100, 394] -> 
             RGBColor[
              0.3677410184422385, 0.49294051979882375`, 0.944653110407893], 
             UndirectedEdge[1, 114] -> 
             RGBColor[
              0.3444304570913155, 0.4727500831795342, 0.9431677820513322], 
             UndirectedEdge[218, 269] -> 
             RGBColor[
              0.9515613514707596, 0.9593431212476458, 0.7385846645144882], 
             UndirectedEdge[182, 253] -> 
             RGBColor[
              0.31490504522225604`, 0.4452672657366318, 0.9413563610246107], 
             UndirectedEdge[57, 354] -> 
             RGBColor[
              0.27649042962059545`, 0.4079393504099632, 0.939057092984733], 
             UndirectedEdge[40, 192] -> 
             RGBColor[
              0.34190093761815415`, 0.4705591405492272, 0.9430066033072686], 
             UndirectedEdge[262, 314] -> 
             RGBColor[
              0.9322274207027686, 0.9487209428474576, 0.9907658897447179], 
             UndirectedEdge[244, 253] -> 
             RGBColor[
              0.30087597692201773`, 0.4305218254587764, 0.9405574263390588], 
             UndirectedEdge[277, 330] -> 
             RGBColor[
              0.24129239010618297`, 0.3709439791957144, 0.9370526167052204], 
             UndirectedEdge[304, 329] -> 
             RGBColor[
              0.2271186296842969, 0.35604645832399684`, 0.9362454420173936], 
             UndirectedEdge[103, 223] -> 
             RGBColor[
              0.3993166746191169, 0.5202694238127852, 0.9466707039440156], 
             UndirectedEdge[92, 337] -> 
             RGBColor[
              0.2862035870447653, 0.41814849471251614`, 0.9396102429307109], 
             UndirectedEdge[226, 341] -> 
             RGBColor[
              0.23010886985563692`, 0.3591893903362524, 0.9364157317714874], 
             UndirectedEdge[193, 260] -> 
             RGBColor[
              0.8156468227717713, 0.8559278037169716, 0.9822546582008858], 
             UndirectedEdge[9, 214] -> 
             RGBColor[
              0.9047202658222255, 0.5928576663351037, 0.5422822863417485], 
             UndirectedEdge[8, 157] -> 
             RGBColor[
              0.38978189814954545`, 0.5115987980501094, 0.9461770157970921], 
             UndirectedEdge[103, 342] -> 
             RGBColor[
              0.4739621782432806, 0.580870006396498, 0.9525470714247991], 
             UndirectedEdge[165, 314] -> 
             RGBColor[
              0.7292803775430885, 0.7876149200721775, 0.9745725244009281], 
             UndirectedEdge[115, 392] -> 
             RGBColor[
              0.24327765587914302`, 0.37303061939621557`, 0.937165674654053], 
             UndirectedEdge[104, 233] -> 
             RGBColor[
              0.8756661600168449, 0.4553685127100845, 0.21500153588103987`], 
             UndirectedEdge[67, 139] -> 
             RGBColor[
              0.21205827028800195`, 0.34021706571655375`, 0.9353877768295796],
              UndirectedEdge[116, 364] -> 
             RGBColor[
              0.382875553578809, 0.5060492934502673, 0.9456174696038513], 
             UndirectedEdge[74, 220] -> 
             RGBColor[
              0.6500539956476187, 0.724027222159205, 0.9674931897567542], 
             UndirectedEdge[100, 168] -> 
             RGBColor[
              0.5233822877675662, 0.6214359238763232, 0.9564882451969059], 
             UndirectedEdge[129, 308] -> 
             RGBColor[
              0.2493864248848615, 0.3794513229395511, 0.9375135600118147], 
             UndirectedEdge[26, 185] -> 
             RGBColor[
              0.6394016686924645, 0.37581057943241813`, 0.5602833187259821], 
             UndirectedEdge[197, 215] -> 
             RGBColor[
              0.9040198154602492, 0.5694397771754294, 0.5010925431304881], 
             UndirectedEdge[178, 240] -> 
             RGBColor[
              0.24159747707370743`, 0.3712646449422136, 0.9370699909566852], 
             UndirectedEdge[52, 223] -> 
             RGBColor[
              0.42035633884682855`, 0.5384929234825571, 0.9480113327439608], 
             UndirectedEdge[192, 243] -> 
             RGBColor[
              0.31643084813058897`, 0.44661450926807483`, 0.9414526439417388],
              UndirectedEdge[124, 252] -> 
             RGBColor[
              0.22380219645594157`, 0.3525606767269839, 0.936056576051262], 
             UndirectedEdge[194, 396] -> 
             RGBColor[
              0.3331772870037427, 0.4601881672994485, 0.9425538104147095], 
             UndirectedEdge[269, 279] -> 
             RGBColor[
              0.9693542844710024, 0.9048940200148108, 0.380506034096984], 
             UndirectedEdge[57, 208] -> 
             RGBColor[
              0.2531470707031978, 0.383404000133339, 0.9377277232277921], 
             UndirectedEdge[169, 304] -> 
             RGBColor[
              0.21989845129097363`, 0.3484575930468634, 0.9358342635391905], 
             UndirectedEdge[209, 280] -> 
             RGBColor[
              0.24552309910713999`, 0.37539072259816386`, 0.9372935493240518],
              UndirectedEdge[226, 399] -> 
             RGBColor[
              0.23675652181007376`, 0.36617649402584324`, 0.9367943057159729],
              UndirectedEdge[206, 392] -> 
             RGBColor[
              0.23975564105496683`, 0.3693287585073688, 0.9369651011201702], 
             UndirectedEdge[48, 343] -> 
             RGBColor[
              0.5738217336869491, 0.6629134141226403, 0.9606378423662292], 
             UndirectedEdge[159, 263] -> 
             RGBColor[
              0.29675910238603487`, 0.4271452950122101, 0.9402881715572926], 
             UndirectedEdge[261, 295] -> 
             RGBColor[
              0.2109178597842839, 0.3390184219709439, 0.935322832138479], 
             UndirectedEdge[33, 204] -> 
             RGBColor[
              0.1789341933349501, 0.3054015606511163, 0.9335014096497838], 
             UndirectedEdge[64, 151] -> 
             RGBColor[
              0.35739789501188024`, 0.48398182614394664`, 0.9439940557289754],
              UndirectedEdge[210, 263] -> 
             RGBColor[
              0.2810036601000736, 0.41268304179923465`, 0.9393141147838132], 
             UndirectedEdge[19, 303] -> 
             RGBColor[
              0.2819979246761117, 0.4137280769086658, 0.939370736680536], 
             UndirectedEdge[248, 315] -> 
             RGBColor[
              0.229741057636631, 0.35880279637343554`, 0.9363947854097444], 
             UndirectedEdge[236, 351] -> 
             RGBColor[
              0.2481333456349381, 0.37813425719806837`, 0.9374421990022963], 
             UndirectedEdge[53, 386] -> 
             RGBColor[
              0.3143035505913172, 0.444852574192945, 0.9413141424158159], 
             UndirectedEdge[93, 301] -> 
             RGBColor[
              0.25102800874557624`, 0.38117673165959054`, 0.9376070457841768],
              UndirectedEdge[37, 159] -> 
             RGBColor[
              0.29061706023566036`, 0.4206896192842019, 0.9399383913431659], 
             UndirectedEdge[148, 326] -> 
             RGBColor[
              0.4816391300864997, 0.5869619633485583, 0.9531902603733251], 
             UndirectedEdge[13, 357] -> 
             RGBColor[
              0.8197351159980406, 0.8595406855045937, 0.9572525529228332], 
             UndirectedEdge[162, 231] -> 
             RGBColor[
              0.27738405997012383`, 0.4088786125667542, 0.9391079839111312], 
             UndirectedEdge[33, 84] -> 
             RGBColor[
              0.17893420048233583`, 0.30540156816347186`, 0.9335014100568169],
              UndirectedEdge[199, 293] -> 
             RGBColor[
              0.21851691429369074`, 0.3470055100682143, 0.9357555870509962], 
             UndirectedEdge[96, 167] -> 
             RGBColor[
              0.28523047788544853`, 0.41712569528738996`, 0.9395548258036737],
              UndirectedEdge[131, 307] -> 
             RGBColor[
              0.9538530771213425, 0.8592378166634234, 0.5753740091193393], 
             UndirectedEdge[174, 291] -> 
             RGBColor[
              0.7125484820155874, 0.7753675568103979, 0.9719838316093115], 
             UndirectedEdge[207, 250] -> 
             RGBColor[
              0.9640415176105277, 0.8943275288623829, 0.5576168978426572], 
             UndirectedEdge[364, 387] -> 
             RGBColor[
              0.3215492584874442, 0.4515282986156772, 0.941761191813439], 
             UndirectedEdge[103, 346] -> 
             RGBColor[
              0.3447990844282577, 0.4730693696510448, 0.9431912706592778], 
             UndirectedEdge[31, 106] -> 
             RGBColor[
              0.5658561150624204, 0.6355057978202503, 0.9529071762376704], 
             UndirectedEdge[128, 316] -> 
             RGBColor[
              0.29024632988181515`, 0.4207827161213608, 0.9398996026647567], 
             UndirectedEdge[185, 289] -> 
             RGBColor[
              0.8607218959500621, 0.40585224662813213`, 0.20335726643267069`],
              UndirectedEdge[20, 172] -> 
             RGBColor[
              0.3545418209166673, 0.4808311305362721, 0.9438368541227812], 
             UndirectedEdge[70, 234] -> 
             RGBColor[
              0.30827476436067847`, 0.438573607296341, 0.9409687003893238], 
             UndirectedEdge[119, 383] -> 
             RGBColor[
              0.2603673467577916, 0.3909929680586598, 0.93813890726766], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.5352140965427551, 0.633549940550514, 0.9565531607151321], 
             UndirectedEdge[20, 54] -> 
             RGBColor[
              0.4298252331165606, 0.5467147461063611, 0.9486090616680254], 
             UndirectedEdge[229, 334] -> 
             RGBColor[
              0.25414759898597045`, 0.3844556187956901, 0.9377847018333471], 
             UndirectedEdge[63, 142] -> 
             RGBColor[
              0.890072513149207, 0.5193941486818902, 0.23091004398772222`], 
             UndirectedEdge[230, 358] -> 
             RGBColor[
              0.9687169526811137, 0.9061370771638947, 0.3329716977842575], 
             UndirectedEdge[119, 296] -> 
             RGBColor[
              0.27100995406971695`, 0.4021790231237703, 0.9387449880097476], 
             UndirectedEdge[218, 262] -> 
             RGBColor[
              0.9243533171861171, 0.9424423464401257, 0.9900148507220045], 
             UndirectedEdge[100, 170] -> 
             RGBColor[
              0.4107918604538279, 0.5302289953510277, 0.9473962719925066], 
             UndirectedEdge[97, 357] -> 
             RGBColor[
              0.5589872751901463, 0.652039901144515, 0.958856542313451], 
             UndirectedEdge[375, 399] -> 
             RGBColor[
              0.24486217858118842`, 0.3746960532206071, 0.9372559108778432], 
             UndirectedEdge[199, 252] -> 
             RGBColor[
              0.2250679449332263, 0.3538910586296987, 0.9361286585545363], 
             UndirectedEdge[175, 345] -> 
             RGBColor[
              0.1904397679735038, 0.31749464909180203`, 0.9341566351044772], 
             UndirectedEdge[176, 186] -> 
             RGBColor[
              0.23214557991116364`, 0.36133010173948693`, 0.9365317193961071],
              UndirectedEdge[309, 371] -> 
             RGBColor[
              0.2714180274121831, 0.4026079340800466, 0.9387682271829105], 
             UndirectedEdge[326, 354] -> 
             RGBColor[
              0.3095818357707423, 0.4398872474233331, 0.94104533946662], 
             UndirectedEdge[38, 289] -> 
             RGBColor[
              0.9317722599024755, 0.7624356715057958, 0.27900046954474644`], 
             UndirectedEdge[120, 237] -> 
             RGBColor[
              0.5723986729827764, 0.663738054850602, 0.9594804667840822], 
             UndirectedEdge[275, 384] -> 
             RGBColor[
              0.8702642398197578, 0.8971991046411623, 0.8780681531351799], 
             UndirectedEdge[216, 220] -> 
             RGBColor[
              0.5672680445778805, 0.6593163046949915, 0.9592519182010989], 
             UndirectedEdge[50, 276] -> 
             RGBColor[
              0.6098568885565028, 0.6922609454050347, 0.9637197242270632], 
             UndirectedEdge[143, 321] -> 
             RGBColor[
              0.7212153553030598, 0.7818668166701053, 0.973033199931347], 
             UndirectedEdge[225, 316] -> 
             RGBColor[
              0.2556938059368381, 0.38608078033623494`, 0.9378727560317908], 
             UndirectedEdge[40, 332] -> 
             RGBColor[
              0.43326686926446056`, 0.5476890621459892, 0.9493828047697146], 
             UndirectedEdge[254, 343] -> 
             RGBColor[
              0.5958559812878284, 0.6815586834125604, 0.9621633323841816], 
             UndirectedEdge[37, 167] -> 
             RGBColor[
              0.26667449670074206`, 0.39762218254510395`, 0.9384980901263189],
              UndirectedEdge[26, 204] -> 
             RGBColor[
              0.3170199268376633, 0.4369570715354334, 0.9418741487280438], 
             UndirectedEdge[141, 189] -> 
             RGBColor[
              0.33030534537683665`, 0.4597575440654077, 0.9422954993465642], 
             UndirectedEdge[55, 210] -> 
             RGBColor[
              0.3517281816196206, 0.4782553243752219, 0.9436626526821428], 
             UndirectedEdge[41, 312] -> 
             RGBColor[
              0.40188874544580117`, 0.5222558384193261, 0.9469012891044913], 
             UndirectedEdge[102, 247] -> 
             RGBColor[
              0.8631522875093278, 0.40917697995257735`, 0.2050732281891151], 
             UndirectedEdge[30, 400] -> 
             RGBColor[
              0.284268969836752, 0.4086385761438802, 0.9397738211163575], 
             UndirectedEdge[57, 195] -> 
             RGBColor[
              0.25945106473985713`, 0.3900298975621752, 0.9380867263622563], 
             UndirectedEdge[301, 324] -> 
             RGBColor[
              0.2683877801719362, 0.39942295210177514`, 0.9385956590854276], 
             UndirectedEdge[290, 331] -> 
             RGBColor[
              0.42861309362707734`, 0.5456648518044729, 0.9485318252116084], 
             UndirectedEdge[49, 347] -> 
             RGBColor[
              0.2678932418389194, 0.3989031609582332, 0.9385674958589661], 
             UndirectedEdge[92, 258] -> 
             RGBColor[
              0.2702985516937192, 0.40143129412108086`, 0.93870447469686], 
             UndirectedEdge[234, 313] -> 
             RGBColor[
              0.3107738733861259, 0.4412003293347502, 0.9411110209512226], 
             UndirectedEdge[376, 377] -> 
             RGBColor[
              0.4266363429774569, 0.5439526897461481, 0.9484058684081864], 
             UndirectedEdge[223, 272] -> 
             RGBColor[
              0.5505420601979628, 0.6459225184451997, 0.9578086189518668], 
             UndirectedEdge[213, 302] -> 
             RGBColor[
              0.9491225739214294, 0.8267349297802298, 0.3261475838124945], 
             UndirectedEdge[121, 158] -> 
             RGBColor[
              0.5281560210081759, 0.6278198768688632, 0.9559975231544674], 
             UndirectedEdge[240, 248] -> 
             RGBColor[
              0.22770719970496556`, 0.3566650827332143, 0.9362789602093593], 
             UndirectedEdge[18, 132] -> 
             RGBColor[
              0.8722144636354254, 0.9008667885957915, 0.9791289224454733], 
             UndirectedEdge[59, 79] -> 
             RGBColor[
              0.46241207497172554`, 0.5712067102742551, 0.9517169387007705], 
             UndirectedEdge[109, 207] -> 
             RGBColor[
              0.9669761340347394, 0.8955410681699965, 0.508982709149612], 
             UndirectedEdge[190, 365] -> 
             RGBColor[
              0.24867185173243342`, 0.3787002612497945, 0.9374728661279003], 
             UndirectedEdge[78, 391] -> 
             RGBColor[
              0.8311173699138001, 0.24018731764171894`, 0.1774313346124849], 
             UndirectedEdge[159, 236] -> 
             RGBColor[
              0.2909783973419341, 0.4210694074929913, 0.9399589689568179], 
             UndirectedEdge[95, 334] -> 
             RGBColor[
              0.27158878350233817`, 0.4027874095573609, 0.9387779514896339], 
             UndirectedEdge[20, 147] -> 
             RGBColor[
              0.34619840677068126`, 0.47206167326583015`, 0.9433617090301424],
              UndirectedEdge[229, 388] -> 
             RGBColor[
              0.23513063549537086`, 0.3644675844219441, 0.9367017138956337], 
             UndirectedEdge[15, 271] -> 
             RGBColor[
              0.3053243996883596, 0.43824568113047624`, 0.940699144924056], 
             UndirectedEdge[53, 151] -> 
             RGBColor[
              0.302539739143033, 0.43466335198279643`, 0.9405645627526612], 
             UndirectedEdge[178, 309] -> 
             RGBColor[
              0.2573894464516083, 0.38786300602707646`, 0.9379693202506316], 
             UndirectedEdge[309, 386] -> 
             RGBColor[
              0.30507679489801537`, 0.4351546689491852, 0.9407886923288442], 
             UndirectedEdge[199, 299] -> 
             RGBColor[
              0.21996573354153404`, 0.3485283109581435, 0.9358380951638248], 
             UndirectedEdge[33, 90] -> 
             RGBColor[
              0.44237359411374266`, 0.5377546224462848, 0.9524068017673784], 
             UndirectedEdge[191, 216] -> 
             RGBColor[
              0.6689774683276695, 0.7413295497654275, 0.9676410801591727], 
             UndirectedEdge[188, 203] -> 
             RGBColor[
              0.2792417470878428, 0.4108311595116429, 0.9392137764442834], 
             UndirectedEdge[87, 263] -> 
             RGBColor[
              0.2761111635451054, 0.407540717717765, 0.9390354943428079], 
             UndirectedEdge[25, 76] -> 
             RGBColor[
              0.8478277754462535, 0.3686308171105509, 0.1934332378220659], 
             UndirectedEdge[329, 334] -> 
             RGBColor[
              0.2482689309678744, 0.37827676597959103`, 0.9374499203864265], 
             UndirectedEdge[42, 376] -> 
             RGBColor[
              0.6853095806395425, 0.7514657941798157, 0.9712763701432583], 
             UndirectedEdge[54, 130] -> 
             RGBColor[
              0.43119853805658864`, 0.5479042338211002, 0.9486965674444381], 
             UndirectedEdge[90, 256] -> 
             RGBColor[
              0.46555708352199543`, 0.5621219397324855, 0.9537270671922793], 
             UndirectedEdge[160, 302] -> 
             RGBColor[
              0.9083773079386029, 0.59816388871644, 0.2904675904582531], 
             UndirectedEdge[299, 367] -> 
             RGBColor[
              0.21672169883755696`, 0.34511862480058364`, 0.9356533521865525],
              UndirectedEdge[16, 96] -> 
             RGBColor[
              0.2643859994981743, 0.3952168268861021, 0.9383677635961609], 
             UndirectedEdge[5, 223] -> 
             RGBColor[
              0.6477551093793219, 0.7220395366342189, 0.9674518801311646], 
             UndirectedEdge[40, 228] -> 
             RGBColor[
              0.35358465424250685`, 0.48067898864856917`, 0.9437510793990673],
              UndirectedEdge[154, 222] -> 
             RGBColor[
              0.5175424648922109, 0.6185744663744461, 0.9553357375773506], 
             UndirectedEdge[85, 188] -> 
             RGBColor[
              0.25419669233076414`, 0.38450721901376617`, 0.937787497626706], 
             UndirectedEdge[281, 384] -> 
             RGBColor[
              0.6902109435663115, 0.7577585241609326, 0.9698659918101223], 
             UndirectedEdge[249, 334] -> 
             RGBColor[
              0.2654841590440016, 0.39637106219610324`, 0.9384303021577143], 
             UndirectedEdge[203, 243] -> 
             RGBColor[
              0.28988476393267687`, 0.4220176450218065, 0.9398198805086642], 
             UndirectedEdge[49, 147] -> 
             RGBColor[
              0.2702371158648362, 0.4013667211696683, 0.9387009760172913], 
             UndirectedEdge[99, 232] -> 
             RGBColor[
              0.7518421224806613, 0.804458883314896, 0.9388506680687247], 
             UndirectedEdge[84, 389] -> 
             RGBColor[
              0.1790075704625178, 0.3054786846645686, 0.933505588368647], 
             UndirectedEdge[76, 242] -> 
             RGBColor[
              0.8826456379438963, 0.5379102714518893, 0.22287275278700588`], 
             UndirectedEdge[129, 397] -> 
             RGBColor[
              0.24351700983454236`, 0.3732821955792575, 0.9371793055077206], 
             UndirectedEdge[177, 390] -> 
             RGBColor[
              0.2941038875347629, 0.4252352483079229, 0.9401047123377103], 
             UndirectedEdge[138, 144] -> 
             RGBColor[
              0.8488904911809813, 0.34529052811745564`, 0.1932170904993126], 
             UndirectedEdge[184, 325] -> 
             RGBColor[
              0.2146653182782982, 0.3429572384507447, 0.9355362443558451], 
             UndirectedEdge[69, 140] -> 
             RGBColor[
              0.5800718085263902, 0.6695145386144623, 0.9603941834467046], 
             UndirectedEdge[247, 391] -> 
             RGBColor[
              0.8636991649292758, 0.4133805194455108, 0.20559691862406698`], 
             UndirectedEdge[14, 391] -> 
             RGBColor[
              0.9073739340103057, 0.5740384053828973, 0.3971702369213773], 
             UndirectedEdge[229, 240] -> 
             RGBColor[
              0.24305133588145522`, 0.372792742729129, 0.9371527860649951], 
             UndirectedEdge[166, 400] -> 
             RGBColor[
              0.6071900057616888, 0.351637441026028, 0.5586994341727993], 
             UndirectedEdge[281, 386] -> 
             RGBColor[
              0.4856785944575267, 0.5902406468075978, 0.9535084650798691], 
             UndirectedEdge[150, 255] -> 
             RGBColor[
              0.26553787758684655`, 0.39642752379058566`, 0.9384333613492598],
              UndirectedEdge[103, 290] -> 
             RGBColor[
              0.3748499370785241, 0.4990979078169345, 0.9451060844172272], 
             UndirectedEdge[212, 299] -> 
             RGBColor[
              0.2125129386493282, 0.3406949509919467, 0.9354136695201356], 
             UndirectedEdge[206, 208] -> 
             RGBColor[
              0.23232439396841398`, 0.3615180466511231, 0.9365419025921359], 
             UndirectedEdge[75, 169] -> 
             RGBColor[
              0.2324382955275915, 0.3616377644115946, 0.9365483891174288], 
             UndirectedEdge[110, 167] -> 
             RGBColor[
              0.26956370563298526`, 0.40065892431931827`, 0.9386626263008084],
              UndirectedEdge[33, 214] -> 
             RGBColor[
              0.5813572401883383, 0.6464138508373214, 0.9229269591928677], 
             UndirectedEdge[98, 107] -> 
             RGBColor[
              0.9083938909149378, 0.6192253386491839, 0.2762763560175848], 
             UndirectedEdge[238, 252] -> 
             RGBColor[
              0.22677811637454098`, 0.3556885572456525, 0.9362260502881472], 
             UndirectedEdge[91, 241] -> 
             RGBColor[
              0.2767915804260243, 0.40825587900053273`, 0.9390742430775896], 
             UndirectedEdge[74, 219] -> 
             RGBColor[
              0.6359306602465759, 0.7123948141262615, 0.9664273391659474], 
             UndirectedEdge[45, 180] -> 
             RGBColor[
              0.33088455801292704`, 0.4597925392578639, 0.9423494940589101], 
             UndirectedEdge[187, 235] -> 
             RGBColor[
              0.792013758809907, 0.8376400126416226, 0.9798528182009743], 
             UndirectedEdge[114, 188] -> 
             RGBColor[0.297981899619691, 0.4286669180863, 0.9403491528141107],
              UndirectedEdge[81, 378] -> 
             RGBColor[
              0.21412094136701804`, 0.3423850638014996, 0.9355052428960813], 
             UndirectedEdge[19, 313] -> 
             RGBColor[
              0.27859623109563336`, 0.41015268127575305`, 0.9391770152634824],
              UndirectedEdge[195, 284] -> 
             RGBColor[
              0.24484639804506322`, 0.3746794668765958, 0.9372550121996561], 
             UndirectedEdge[64, 253] -> 
             RGBColor[
              0.3703380254209453, 0.4951899167144135, 0.9448185893961331], 
             UndirectedEdge[55, 122] -> 
             RGBColor[
              0.4248101196568824, 0.5423709068945195, 0.9482895030730654], 
             UndirectedEdge[99, 275] -> 
             RGBColor[
              0.9851141209349312, 0.987104803716967, 0.8512424005775606], 
             UndirectedEdge[118, 367] -> 
             RGBColor[
              0.21268815866311674`, 0.340879118336029, 0.9354236480407061], 
             UndirectedEdge[7, 96] -> 
             RGBColor[
              0.3381582412697068, 0.46529865529748227`, 0.9428420383243149], 
             UndirectedEdge[110, 115] -> 
             RGBColor[
              0.2470920216969208, 0.3770397597154611, 0.9373828971445268], 
             UndirectedEdge[68, 95] -> 
             RGBColor[
              0.2792515764807897, 0.4108414908268496, 0.9392143362136705], 
             UndirectedEdge[289, 302] -> 
             RGBColor[
              0.9425151711377706, 0.798674033657958, 0.3207346510653094], 
             UndirectedEdge[260, 321] -> 
             RGBColor[
              0.813370248803728, 0.8541302872991015, 0.9820328030897745], 
             UndirectedEdge[191, 220] -> 
             RGBColor[
              0.5771439386381384, 0.6670314281944398, 0.9602362550255482], 
             UndirectedEdge[169, 209] -> 
             RGBColor[
              0.23636572886417778`, 0.36576574586200267`, 0.9367720506358304],
              UndirectedEdge[32, 252] -> 
             RGBColor[
              0.2203092674216852, 0.34888938684748844`, 0.9358576589100864], 
             UndirectedEdge[75, 280] -> 
             RGBColor[
              0.24159566577055375`, 0.3712627411477558, 0.9370698878056503], 
             UndirectedEdge[14, 224] -> 
             RGBColor[
              0.9850092930497456, 0.9599506894449308, 0.4935654545583491], 
             UndirectedEdge[128, 311] -> 
             RGBColor[
              0.4227935959175786, 0.5388307190597109, 0.9486565824461703], 
             UndirectedEdge[132, 198] -> 
             RGBColor[
              0.8128559952710535, 0.8537811311091374, 0.9819675933041132], 
             UndirectedEdge[245, 388] -> 
             RGBColor[
              0.22663197894047044`, 0.3555349575367959, 0.9362177279774678], 
             UndirectedEdge[183, 273] -> 
             RGBColor[
              0.26718551324119244`, 0.3981592933294373, 0.9385271917623162], 
             UndirectedEdge[69, 220] -> 
             RGBColor[
              0.4818265682663484, 0.5902075400149862, 0.9523502989242535], 
             UndirectedEdge[37, 263] -> 
             RGBColor[
              0.25594156812645086`, 0.3863411941065481, 0.9378868657219579], 
             UndirectedEdge[235, 384] -> 
             RGBColor[
              0.7442607582282336, 0.800141428009943, 0.9751446149341176], 
             UndirectedEdge[132, 216] -> 
             RGBColor[
              0.7291619678468395, 0.7883461382089411, 0.9736397086151186], 
             UndirectedEdge[225, 380] -> 
             RGBColor[
              0.2612993849996442, 0.39197259934548456`, 0.9381919854667065], 
             UndirectedEdge[3, 371] -> 
             RGBColor[
              0.3210626317693298, 0.4491168451749269, 0.9418030466401561], 
             UndirectedEdge[269, 314] -> 
             RGBColor[
              0.9594354549874111, 0.9656217176549777, 0.7393357035372017], 
             UndirectedEdge[16, 206] -> 
             RGBColor[
              0.23671129027789278`, 0.36612895281767627`, 0.9367917298471292],
              UndirectedEdge[84, 256] -> 
             RGBColor[
              0.20211768989058865`, 0.32976888544967253`, 0.9348216754817178],
              UndirectedEdge[58, 348] -> 
             RGBColor[
              0.28088310771412667`, 0.4125563335981417, 0.9393072495037748], 
             UndirectedEdge[177, 360] -> 
             RGBColor[
              0.31615011179738517`, 0.4482550694974156, 0.9413657834565303], 
             UndirectedEdge[2, 106] -> 
             RGBColor[
              0.8834730056375308, 0.5519688209280622, 0.5686856052309635], 
             UndirectedEdge[256, 317] -> 
             RGBColor[
              0.6079677143241806, 0.6722679099328412, 0.8705698500730703], 
             UndirectedEdge[87, 351] -> 
             RGBColor[
              0.2679416039473189, 0.3989539926004958, 0.9385702500094941], 
             UndirectedEdge[48, 103] -> 
             RGBColor[
              0.3850045259376993, 0.5078933023022759, 0.9457531258399835], 
             UndirectedEdge[256, 381] -> 
             RGBColor[
              0.6092276972658053, 0.6727889452592876, 0.8496886719990233], 
             UndirectedEdge[91, 226] -> 
             RGBColor[
              0.25062761976227643`, 0.38075589745201466`, 0.9375842442239002],
              UndirectedEdge[105, 113] -> 
             RGBColor[
              0.6069298774587211, 0.6884337835985022, 0.9640833346207096], 
             UndirectedEdge[223, 291] -> 
             RGBColor[
              0.5752793861727824, 0.6652475055073694, 0.9602742044215822], 
             UndirectedEdge[203, 348] -> 
             RGBColor[
              0.277176399167938, 0.4086603478972015, 0.9390961579356532], 
             UndirectedEdge[259, 367] -> 
             RGBColor[
              0.21516769270569408`, 0.3434852658263162, 0.935564853836289], 
             UndirectedEdge[188, 206] -> 
             RGBColor[
              0.2493239941811602, 0.37938570431162577`, 0.937510004675597], 
             UndirectedEdge[250, 289] -> 
             RGBColor[
              0.9429902625743816, 0.8090015716874366, 0.5405821025323335], 
             UndirectedEdge[194, 377] -> 
             RGBColor[
              0.40146722310948635`, 0.5221524631532592, 0.9468021143463783], 
             UndirectedEdge[83, 231] -> 
             RGBColor[
              0.3307828964588674, 0.4609235312385056, 0.9422983810248817], 
             UndirectedEdge[276, 376] -> 
             RGBColor[
              0.6019797217390458, 0.6854606658855094, 0.9632115739949887], 
             UndirectedEdge[83, 120] -> 
             RGBColor[
              0.45962999176153224`, 0.5694602774020465, 0.9513564039568587], 
             UndirectedEdge[40, 243] -> 
             RGBColor[
              0.3138420416346276, 0.4443722151984709, 0.9412876874810078], 
             UndirectedEdge[4, 392] -> 
             RGBColor[
              0.24007285485442642`, 0.3696621703231174, 0.9369831659767736], 
             UndirectedEdge[81, 329] -> 
             RGBColor[
              0.22742713619850993`, 0.35637071823087746`, 0.9362630110069835],
              UndirectedEdge[131, 363] -> 
             RGBColor[
              0.8924893365860593, 0.5994472191560132, 0.23173103267921852`], 
             UndirectedEdge[167, 192] -> 
             RGBColor[
              0.3140196057697616, 0.4440801406652496, 0.941315327256403], 
             UndirectedEdge[41, 327] -> 
             RGBColor[
              0.32970622489449014`, 0.4599966933120725, 0.9422295669958778], 
             UndirectedEdge[24, 382] -> 
             RGBColor[
              0.9004669733536322, 0.6409255971753784, 0.23865954159958375`], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.6399409788041857, 0.37995595327830467`, 0.56079976269803], 
             UndirectedEdge[90, 261] -> 
             RGBColor[
              0.4426270855649366, 0.538021058033776, 0.9524212377305169], 
             UndirectedEdge[146, 297] -> 
             RGBColor[
              0.7409851288378926, 0.7966845449876518, 0.9658863907552364], 
             UndirectedEdge[5, 291] -> 
             RGBColor[
              0.7689673032381015, 0.8196158140703518, 0.9775611053894065], 
             UndirectedEdge[229, 315] -> 
             RGBColor[
              0.24508519381312066`, 0.3749304563693503, 0.9372686112653803], 
             UndirectedEdge[241, 360] -> 
             RGBColor[
              0.3006768355928906, 0.4332086382716799, 0.9404400442858039], 
             UndirectedEdge[59, 237] -> 
             RGBColor[
              0.4562186120487096, 0.5661785780610258, 0.9512293666120685], 
             UndirectedEdge[257, 381] -> 
             RGBColor[
              0.9078770993756948, 0.5831041621482105, 0.46625847556572675`], 
             UndirectedEdge[270, 308] -> 
             RGBColor[
              0.2553377632908749, 0.38570655694091993`, 0.9378524799298211], 
             UndirectedEdge[317, 382] -> 
             RGBColor[
              0.9447039927210837, 0.8118308485146293, 0.5211250046258997], 
             UndirectedEdge[23, 89] -> 
             RGBColor[
              0.21600037669219402`, 0.3443604694913417, 0.9356122739574746], 
             UndirectedEdge[57, 327] -> 
             RGBColor[
              0.2958997785397042, 0.4274294644124098, 0.9401957587844365], 
             UndirectedEdge[347, 362] -> 
             RGBColor[
              0.3423545559019188, 0.4682989085041503, 0.9431326516737686], 
             UndirectedEdge[43, 293] -> 
             RGBColor[
              0.21933315592561953`, 0.34786343177608003`, 0.9358020708044131],
              UndirectedEdge[73, 208] -> 
             RGBColor[
              0.23810134733460236`, 0.3675899909189858, 0.9368708915401036], 
             UndirectedEdge[53, 129] -> 
             RGBColor[
              0.26346421560774436`, 0.39424797357278596`, 0.9383152693672578],
              UndirectedEdge[324, 383] -> 
             RGBColor[
              0.2800969902621915, 0.41173007431343256`, 0.9392624812778436], 
             UndirectedEdge[368, 399] -> 
             RGBColor[
              0.22383026101092823`, 0.35259017435367035`, 0.9360581742861507],
              UndirectedEdge[51, 136] -> 
             RGBColor[
              0.4957527510770341, 0.5993305404010079, 0.9540497614266502], 
             UndirectedEdge[145, 359] -> 
             RGBColor[
              0.24179608967805666`, 0.37147339938215107`, 0.9370813016506819],
              UndirectedEdge[222, 297] -> 
             RGBColor[
              0.7757829604608912, 0.8249349923236523, 0.9686258035292561], 
             UndirectedEdge[81, 209] -> 
             RGBColor[
              0.23587421810878062`, 0.36524913689449845`, 0.9367440598254355],
              UndirectedEdge[31, 345] -> 
             RGBColor[
              0.1925824038789099, 0.3197466952793466, 0.9342786550495443], 
             UndirectedEdge[155, 180] -> 
             RGBColor[
              0.33540782096983857`, 0.46454677541701367`, 0.9426070871927383],
              UndirectedEdge[4, 369] -> 
             RGBColor[
              0.2448252232373639, 0.37465721081114345`, 0.937253806325683], 
             UndirectedEdge[102, 289] -> 
             RGBColor[
              0.8585251717968794, 0.3889672621761071, 0.20125368090273776`], 
             UndirectedEdge[70, 103] -> 
             RGBColor[
              0.3111881460301813, 0.44109703206764383`, 0.9411543384931023], 
             UndirectedEdge[177, 375] -> 
             RGBColor[
              0.28837692064883436`, 0.4192158430001391, 0.939778570045845], 
             UndirectedEdge[171, 253] -> 
             RGBColor[
              0.30746418261270597`, 0.43744644735605664`, 0.9409326149067666],
              UndirectedEdge[150, 241] -> 
             RGBColor[
              0.2807813627744614, 0.41244939321555174`, 0.939301455279979], 
             UndirectedEdge[24, 317] -> 
             RGBColor[
              0.946390043794504, 0.8194868126517976, 0.5225318869704552], 
             UndirectedEdge[80, 110] -> 
             RGBColor[
              0.29499717102305234`, 0.4250177053104399, 0.9401979264655129], 
             UndirectedEdge[176, 341] -> 
             RGBColor[
              0.21870360025711671`, 0.3472017288523488, 0.9357662185404361], 
             UndirectedEdge[154, 192] -> 
             RGBColor[
              0.3873238866966642, 0.5099022160172301, 0.9459009134566145], 
             UndirectedEdge[121, 322] -> 
             RGBColor[
              0.5308061338547281, 0.6299713578639174, 0.9562061497454312], 
             UndirectedEdge[268, 381] -> 
             RGBColor[
              0.9052330145226024, 0.5627805673219706, 0.46372649692433865`], 
             UndirectedEdge[76, 104] -> 
             RGBColor[
              0.8904092616611533, 0.5686904524165735, 0.22911954666558126`], 
             UndirectedEdge[91, 186] -> 
             RGBColor[
              0.2555444422624831, 0.38592378964428387`, 0.9378642499915], 
             UndirectedEdge[216, 357] -> 
             RGBColor[
              0.6673958385373104, 0.7400939685523675, 0.9674834380828405], 
             UndirectedEdge[210, 236] -> 
             RGBColor[
              0.27522295505597283`, 0.4066071542800159, 0.9389849121833385], 
             UndirectedEdge[26, 173] -> 
             RGBColor[
              0.34074023236907375`, 0.46188861660318076`, 0.9432249850370102],
              UndirectedEdge[10, 374] -> 
             RGBColor[
              0.31901480157328777`, 0.4477183185888486, 0.9416588227642095], 
             UndirectedEdge[289, 340] -> 
             RGBColor[
              0.9457657182249508, 0.8088519239369327, 0.40028051736176995`], 
             UndirectedEdge[65, 168] -> 
             RGBColor[
              0.592741338058181, 0.6798274166038522, 0.9613729899467283], 
             UndirectedEdge[40, 203] -> 
             RGBColor[
              0.31535485342024205`, 0.44596227630295887`, 0.941373839874194], 
             UndirectedEdge[167, 201] -> 
             RGBColor[
              0.27998787707886075`, 0.41161538943957654`, 0.9392562674434715],
              UndirectedEdge[41, 57] -> 
             RGBColor[
              0.3070138697292798, 0.4370559315903547, 0.9409039388472313], 
             UndirectedEdge[214, 363] -> 
             RGBColor[
              0.9231427936939823, 0.7280008749245814, 0.5596707462488172], 
             UndirectedEdge[22, 189] -> 
             RGBColor[
              0.29643257003583556`, 0.4288998043911114, 0.9401927683796281], 
             UndirectedEdge[41, 96] -> 
             RGBColor[
              0.3138659022147775, 0.44425785217656466`, 0.9412941519606068], 
             UndirectedEdge[31, 197] -> 
             RGBColor[
              0.5859844235922751, 0.6497599697422292, 0.884913356826519], 
             UndirectedEdge[275, 281] -> 
             RGBColor[
              0.8120473445077586, 0.8515608457173255, 0.8723741943555676], 
             UndirectedEdge[89, 353] -> 
             RGBColor[
              0.21448123699978983`, 0.34276375735560527`, 0.9355257611993579],
              UndirectedEdge[324, 375] -> 
             RGBColor[
              0.267401497471214, 0.3983863064493811, 0.938539491744696], 
             UndirectedEdge[5, 174] -> 
             RGBColor[
              0.7850242052221269, 0.8321595879372474, 0.979161507318894], 
             UndirectedEdge[36, 314] -> 
             RGBColor[
              0.7227446385125958, 0.7823089126955356, 0.9740580070832467], 
             UndirectedEdge[220, 357] -> 
             RGBColor[
              0.5755623088477795, 0.6657958469813797, 0.960078612949216], 
             UndirectedEdge[291, 342] -> 
             RGBColor[
              0.6499248897969461, 0.7258480880910823, 0.9661505719023658], 
             UndirectedEdge[21, 159] -> 
             RGBColor[
              0.3221758681761928, 0.45347427680941704`, 0.9417497393246208], 
             UndirectedEdge[220, 394] -> 
             RGBColor[
              0.4171512331180811, 0.5351366490894776, 0.9479674097431279], 
             UndirectedEdge[129, 249] -> 
             RGBColor[
              0.25362687609654, 0.3839083060231606, 0.9377550474351345], 
             UndirectedEdge[37, 58] -> 
             RGBColor[
              0.2743052593933725, 0.40564259795335733`, 0.9389326507729624], 
             UndirectedEdge[118, 259] -> 
             RGBColor[
              0.20854115618205327`, 0.33652035579328765`, 0.9351874823843499],
              UndirectedEdge[201, 243] -> 
             RGBColor[
              0.2823991194396881, 0.4141497580424017, 0.9393935841288071], 
             UndirectedEdge[40, 110] -> 
             RGBColor[
              0.29744503748137785`, 0.4271379242032959, 0.940353902351674], 
             UndirectedEdge[35, 278] -> 
             RGBColor[
              0.26672833715189703`, 0.3976787722729497, 0.9385011562603622], 
             UndirectedEdge[164, 315] -> 
             RGBColor[
              0.2429063670041037, 0.37264037124747484`, 0.9371445303018922], 
             UndirectedEdge[81, 304] -> 
             RGBColor[
              0.21940694053557647`, 0.34794098407935925`, 0.9358062727287957],
              UndirectedEdge[12, 299] -> 
             RGBColor[
              0.21628284341415968`, 0.3446573599255522, 0.9356283600194184], 
             UndirectedEdge[203, 258] -> 
             RGBColor[
              0.2721654186176039, 0.4033934896242831, 0.9388107900063931], 
             UndirectedEdge[250, 276] -> 
             RGBColor[
              0.8768966809261312, 0.9030925119563854, 0.9110185744810039], 
             UndirectedEdge[124, 238] -> 
             RGBColor[
              0.22624718755874168`, 0.35513051739741625`, 0.9361958146775262],
              UndirectedEdge[96, 154] -> 
             RGBColor[
              0.3585347588123511, 0.48294777063937044`, 0.9441404120038852], 
             UndirectedEdge[126, 238] -> 
             RGBColor[
              0.2206324276302094, 0.349229048716188, 0.9358760624058893], 
             UndirectedEdge[103, 108] -> 
             RGBColor[
              0.3560676178251626, 0.48282960690648735`, 0.9439092916429558], 
             UndirectedEdge[122, 210] -> 
             RGBColor[
              0.3730056479605837, 0.4966847962832106, 0.9450184340224643], 
             UndirectedEdge[108, 234] -> 
             RGBColor[
              0.3531542361556598, 0.4803061821351844, 0.9437236535391773], 
             UndirectedEdge[222, 361] -> 
             RGBColor[
              0.48027671073484357`, 0.5862967431545993, 0.9529611966752556], 
             UndirectedEdge[12, 274] -> 
             RGBColor[
              0.2245824786939262, 0.35338080283185697`, 0.936101011970391], 
             UndirectedEdge[141, 219] -> 
             RGBColor[
              0.4036258957264883, 0.5240221968760659, 0.9469396630566943], 
             UndirectedEdge[179, 344] -> 
             RGBColor[
              0.29513590341832135`, 0.4264382934400302, 0.9401591514378], 
             UndirectedEdge[14, 230] -> 
             RGBColor[
              0.9816071552805266, 0.9484744798894191, 0.4803487917647419], 
             UndirectedEdge[12, 118] -> 
             RGBColor[
              0.21224930323971947`, 0.34041785346099757`, 0.9353986558735721],
              UndirectedEdge[44, 49] -> 
             RGBColor[
              0.2768464709137847, 0.4083135723834269, 0.9390773690096643], 
             UndirectedEdge[224, 247] -> 
             RGBColor[
              0.9413345239687156, 0.7992928035075443, 0.30199213626103877`], 
             UndirectedEdge[161, 222] -> 
             RGBColor[
              0.5181817733764011, 0.6191282032508729, 0.9553764737486448], 
             UndirectedEdge[148, 168] -> 
             RGBColor[
              0.6470192572483401, 0.7238926765948177, 0.9656459465719469], 
             UndirectedEdge[219, 323] -> 
             RGBColor[
              0.6386990444191253, 0.7146022485196659, 0.9666913901196909], 
             UndirectedEdge[309, 334] -> 
             RGBColor[
              0.26609474286190404`, 0.39701282450196873`, 0.9384650740028659],
              UndirectedEdge[170, 326] -> 
             RGBColor[
              0.39217993552288943`, 0.5141082814383957, 0.9462103365937862], 
             UndirectedEdge[239, 354] -> 
             RGBColor[
              0.3021441775416652, 0.43344512169287874`, 0.940571418461126], 
             UndirectedEdge[11, 221] -> 
             RGBColor[
              0.9226607888866434, 0.8373956409938654, 0.6248416927368453], 
             UndirectedEdge[47, 322] -> 
             RGBColor[
              0.47115402237552717`, 0.5810156228019311, 0.9516558567994469], 
             UndirectedEdge[155, 271] -> 
             RGBColor[
              0.305666751429035, 0.4386055145162801, 0.9407186413492236], 
             UndirectedEdge[106, 363] -> 
             RGBColor[
              0.905503655257033, 0.714845634359743, 0.589529206598464], 
             UndirectedEdge[245, 378] -> 
             RGBColor[
              0.2192126419789341, 0.3477367639770881, 0.9357952077134337], 
             UndirectedEdge[155, 326] -> 
             RGBColor[
              0.32196792775833594`, 0.4529058154258842, 0.9417507090817323], 
             UndirectedEdge[10, 39] -> 
             RGBColor[
              0.3175089705748625, 0.446135594734304, 0.9415730679165266], 
             UndirectedEdge[25, 382] -> 
             RGBColor[
              0.8737460186049575, 0.5043450922501913, 0.21576589198201723`], 
             UndirectedEdge[177, 383] -> 
             RGBColor[
              0.3010724134398118, 0.43255961086419054`, 0.9405015595789926], 
             UndirectedEdge[177, 296] -> 
             RGBColor[
              0.3117150207517371, 0.4437456659293011, 0.9411076403210801], 
             UndirectedEdge[103, 143] -> 
             RGBColor[
              0.48460520194471113`, 0.589510492500073, 0.9533849292372562], 
             UndirectedEdge[84, 317] -> 
             RGBColor[
              0.5847770387283635, 0.6478930395078799, 0.8692491754054186], 
             UndirectedEdge[50, 328] -> 
             RGBColor[
              0.38179240870061343`, 0.505088601337379, 0.9455546766979714], 
             UndirectedEdge[332, 385] -> 
             RGBColor[
              0.5513213263478973, 0.6466265153287621, 0.9578211808481198], 
             UndirectedEdge[242, 257] -> 
             RGBColor[
              0.8704770048155868, 0.4443768248986645, 0.21122005596083127`], 
             UndirectedEdge[214, 217] -> 
             RGBColor[
              0.903299381606431, 0.5819361276170735, 0.5409216460120444], 
             UndirectedEdge[51, 59] -> 
             RGBColor[
              0.3534707906164537, 0.48058036569863427`, 0.9437438241095009], 
             UndirectedEdge[66, 131] -> 
             RGBColor[
              0.9476245332536402, 0.8250818486193503, 0.3026198784181737], 
             UndirectedEdge[66, 98] -> 
             RGBColor[
              0.9751764945744315, 0.9279266287426179, 0.3580657982576656], 
             UndirectedEdge[70, 346] -> 
             RGBColor[
              0.3114210735342079, 0.4412987821643549, 0.9411691804276892], 
             UndirectedEdge[151, 253] -> 
             RGBColor[
              0.3287756481732377, 0.4591906745282696, 0.9421702714700763], 
             UndirectedEdge[384, 398] -> 
             RGBColor[
              0.8439266207114591, 0.8788704640005567, 0.9814905615415767], 
             UndirectedEdge[123, 218] -> 
             RGBColor[
              0.9421799541639146, 0.955737423109728, 0.959839004250153], 
             UndirectedEdge[169, 280] -> 
             RGBColor[
              0.229855838803546, 0.3589234386574095, 0.9364013220273968], 
             UndirectedEdge[71, 109] -> 
             RGBColor[
              0.932608231427341, 0.9459491066410988, 0.8675350166916449], 
             UndirectedEdge[166, 302] -> 
             RGBColor[
              0.9060230690090321, 0.580068176669682, 0.28821316860056356`], 
             UndirectedEdge[89, 163] -> 
             RGBColor[
              0.23177803755773202`, 0.36094379142249916`, 0.9365107884028094],
              UndirectedEdge[102, 340] -> 
             RGBColor[
              0.9065375818313084, 0.569215708650745, 0.3651390053950433], 
             UndirectedEdge[380, 390] -> 
             RGBColor[
              0.2658949696207651, 0.39680285015917666`, 0.9384536972123212], 
             UndirectedEdge[172, 387] -> 
             RGBColor[
              0.29749670616801155`, 0.43001827893615596`, 0.9402533693581072],
              UndirectedEdge[61, 298] -> 
             RGBColor[
              0.9083880182689977, 0.925110369261773, 0.7500707788698681], 
             UndirectedEdge[10, 216] -> 
             RGBColor[
              0.5105137254220357, 0.6107590812291837, 0.9554696590225349], 
             UndirectedEdge[209, 229] -> 
             RGBColor[
              0.24946457527559712`, 0.37953346395523513`, 0.937518010560954], 
             UndirectedEdge[39, 119] -> 
             RGBColor[
              0.2567952159774935, 0.3872384321223937, 0.9379354797042159], 
             UndirectedEdge[33, 261] -> 
             RGBColor[
              0.17919487812109408`, 0.3056755568897237, 0.9335162552627061], 
             UndirectedEdge[102, 213] -> 
             RGBColor[
              0.8651325745805382, 0.41702815829837886`, 0.20666661364992278`],
              UndirectedEdge[155, 335] -> 
             RGBColor[
              0.29253189959404885`, 0.42479995244000324`, 0.9399706309684931],
              UndirectedEdge[76, 317] -> 
             RGBColor[
              0.9187857495623798, 0.676116573374989, 0.49879235046594833`], 
             UndirectedEdge[19, 179] -> 
             RGBColor[
              0.2720136332383074, 0.4032339535668936, 0.9388021460535885], 
             UndirectedEdge[48, 83] -> 
             RGBColor[
              0.38916228198081126`, 0.5114945416119245, 0.9460180543784913], 
             UndirectedEdge[288, 355] -> 
             RGBColor[
              0.2379735788706035, 0.36745569816233453`, 0.9368636153150954], 
             UndirectedEdge[7, 192] -> 
             RGBColor[
              0.36694736915401993`, 0.4922531006753419, 0.9446025397770442], 
             UndirectedEdge[341, 393] -> 
             RGBColor[
              0.2222018557461406, 0.35087861717352153`, 0.9359654390153307], 
             UndirectedEdge[244, 270] -> 
             RGBColor[
              0.2548116613836774, 0.3851535904796679, 0.9378225192045042], 
             UndirectedEdge[121, 265] -> 
             RGBColor[
              0.5725454192775208, 0.6638571901035208, 0.9594920191899539], 
             UndirectedEdge[156, 363] -> 
             RGBColor[
              0.5242360164158433, 0.390684407006331, 0.5704454430561892], 
             UndirectedEdge[133, 280] -> 
             RGBColor[
              0.26813571605602704`, 0.3991580167341666, 0.938581304406922], 
             UndirectedEdge[44, 362] -> 
             RGBColor[
              0.35130778497678417`, 0.477709319929344, 0.9436425248244668], 
             UndirectedEdge[116, 147] -> 
             RGBColor[
              0.35047958711339033`, 0.47576981650030403`, 0.9436345020558807],
              UndirectedEdge[83, 196] -> 
             RGBColor[
              0.32540289254677246`, 0.4552688060149441, 0.9419919977610904], 
             UndirectedEdge[109, 233] -> 
             RGBColor[
              0.9057773412404262, 0.5635119739368787, 0.4559259820875775], 
             UndirectedEdge[19, 125] -> 
             RGBColor[
              0.27618503388558474`, 0.4076183601292589, 0.9390397011494167], 
             UndirectedEdge[26, 160] -> 
             RGBColor[
              0.6422952177337565, 0.39805166532506286`, 0.5630541845557195], 
             UndirectedEdge[224, 302] -> 
             RGBColor[
              0.981469271203516, 0.9491536419267372, 0.38251204717050646`], 
             UndirectedEdge[58, 60] -> 
             RGBColor[
              0.3281696676840872, 0.4577472453898289, 0.942165291884663], 
             UndirectedEdge[165, 332] -> 
             RGBColor[
              0.5299851907540822, 0.6293048792717479, 0.9561415220973347], 
             UndirectedEdge[43, 252] -> 
             RGBColor[
              0.2258841865651551, 0.3547489803375645, 0.9361751423079533], 
             UndirectedEdge[292, 304] -> 
             RGBColor[
              0.21505855653612305`, 0.3433705567924642, 0.9355586386928844], 
             UndirectedEdge[63, 257] -> 
             RGBColor[
              0.8905841112547781, 0.5233265159050291, 0.23139995091138454`], 
             UndirectedEdge[94, 355] -> 
             RGBColor[
              0.2455225673247446, 0.37539016366114936`, 0.937293519039831], 
             UndirectedEdge[223, 290] -> 
             RGBColor[
              0.4296004547734099, 0.5464997120753861, 0.9486003596365518], 
             UndirectedEdge[141, 150] -> 
             RGBColor[
              0.3153323622893313, 0.4440199894984804, 0.9414428101102743], 
             UndirectedEdge[131, 306] -> 
             RGBColor[
              0.9464211476308863, 0.8210225463454206, 0.2979449525140816], 
             UndirectedEdge[151, 182] -> 
             RGBColor[
              0.301964914813191, 0.43405917516616493`, 0.9405318273574531], 
             UndirectedEdge[87, 201] -> 
             RGBColor[
              0.2832825017728496, 0.4150782488842294, 0.9394438914458336], 
             UndirectedEdge[72, 379] -> 
             RGBColor[
              0.22434193474233927`, 0.3531279758873717, 0.9360873133482011], 
             UndirectedEdge[23, 378] -> 
             RGBColor[
              0.21097218176330165`, 0.339075517815104, 0.9353259256948219], 
             UndirectedEdge[116, 322] -> 
             RGBColor[
              0.46231873384021377`, 0.5733629399471565, 0.9510928800267155], 
             UndirectedEdge[90, 175] -> 
             RGBColor[
              0.44236897151936794`, 0.5377497638065076, 0.9524065385174674], 
             UndirectedEdge[348, 369] -> 
             RGBColor[
              0.2602045857942335, 0.3908218959663191, 0.9381296382715687], 
             UndirectedEdge[134, 243] -> 
             RGBColor[
              0.2613494095308073, 0.3920251782994754, 0.9381948342897516], 
             UndirectedEdge[211, 372] -> 
             RGBColor[
              0.257077351430105, 0.3875349743715093, 0.9379515469008601], 
             UndirectedEdge[73, 188] -> 
             RGBColor[
              0.2551009475473486, 0.3854576485794885, 0.9378389936235647], 
             UndirectedEdge[55, 228] -> 
             RGBColor[
              0.38569491533937006`, 0.508491282902023, 0.9457971168421706], 
             UndirectedEdge[260, 384] -> 
             RGBColor[
              0.7786909364224193, 0.827038544894287, 0.9785762933282055], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.6353748988917614, 0.714796015346257, 0.9644853457536787], 
             UndirectedEdge[153, 203] -> 
             RGBColor[
              0.3044141682214503, 0.43648600467859244`, 0.9406767090877951], 
             UndirectedEdge[65, 148] -> 
             RGBColor[
              0.5696101053080527, 0.6614741699887192, 0.9592609405218679], 
             UndirectedEdge[42, 366] -> 
             RGBColor[
              0.9167531541973288, 0.7967074998480634, 0.6163680259642358], 
             UndirectedEdge[48, 313] -> 
             RGBColor[
              0.35412562406909687`, 0.4787494368539953, 0.9438733561702934], 
             UndirectedEdge[166, 213] -> 
             RGBColor[
              0.8678686088454421, 0.43805851659629047`, 0.20928664315190354`],
              UndirectedEdge[11, 78] -> 
             RGBColor[
              0.8826533057204708, 0.5284492493821207, 0.22248879223389445`], 
             UndirectedEdge[228, 348] -> 
             RGBColor[
              0.31540619999020275`, 0.44337706024281187`, 0.9414733974605265],
              UndirectedEdge[199, 336] -> 
             RGBColor[
              0.2184046627263886, 0.34688752655381927`, 0.9357491944902996], 
             UndirectedEdge[249, 309] -> 
             RGBColor[
              0.2701798653173872, 0.40130654721440506`, 0.9386977156833087], 
             UndirectedEdge[190, 273] -> 
             RGBColor[
              0.2582701914773965, 0.38878872489163985`, 0.9380194773769047], 
             UndirectedEdge[298, 314] -> 
             RGBColor[
              0.8746210569271528, 0.9028631061103101, 0.9879033312647884], 
             UndirectedEdge[7, 385] -> 
             RGBColor[
              0.4824130197414953, 0.5889482597885108, 0.9528759593947184], 
             UndirectedEdge[27, 194] -> 
             RGBColor[
              0.3427358884343137, 0.47023486345331306`, 0.943098158625497], 
             UndirectedEdge[39, 128] -> 
             RGBColor[
              0.2996526087721707, 0.4306693116276521, 0.9404352763322198], 
             UndirectedEdge[116, 265] -> 
             RGBColor[
              0.5040580192630065, 0.6072487721867599, 0.9543787494712381], 
             UndirectedEdge[231, 313] -> 
             RGBColor[
              0.295746238547153, 0.4281784264805763, 0.9401536828166841], 
             UndirectedEdge[96, 284] -> 
             RGBColor[
              0.2654547891651977, 0.3963401925913225, 0.9384286295865651], 
             UndirectedEdge[279, 300] -> 
             RGBColor[
              0.9178232089422185, 0.7078044246386144, 0.2525247911559355], 
             UndirectedEdge[22, 190] -> 
             RGBColor[
              0.26671069132338054`, 0.3976602253883686, 0.938500151356533], 
             UndirectedEdge[24, 207] -> 
             RGBColor[
              0.9210044213449331, 0.723918476562367, 0.2552656037171254], 
             UndirectedEdge[315, 329] -> 
             RGBColor[
              0.2392065257950246, 0.3687516035532512, 0.9369338298184597], 
             UndirectedEdge[239, 335] -> 
             RGBColor[
              0.3025165492814234, 0.4338365080010965, 0.9405926244808307], 
             UndirectedEdge[142, 300] -> 
             RGBColor[
              0.8557903757137784, 0.38014617017527513`, 0.1991125486638397], 
             UndirectedEdge[13, 88] -> 
             RGBColor[
              0.9770469480723544, 0.9813851840644524, 0.8781922259657269], 
             UndirectedEdge[18, 302] -> 
             RGBColor[
              0.9662417999648014, 0.9637001584466507, 0.6913546401282936], 
             UndirectedEdge[148, 251] -> 
             RGBColor[
              0.723101933884062, 0.7833478892534567, 0.9732241552199159], 
             UndirectedEdge[90, 257] -> 
             RGBColor[
              0.7642064856318851, 0.4724371566214084, 0.5702968707589827], 
             UndirectedEdge[134, 348] -> 
             RGBColor[
              0.24864104476606846`, 0.3786678811748705, 0.9374711117167406], 
             UndirectedEdge[158, 322] -> 
             RGBColor[
              0.5057660137173806, 0.6096426602918618, 0.9542348997632368], 
             UndirectedEdge[40, 385] -> 
             RGBColor[
              0.4573665882056296, 0.5672542996623962, 0.9512800229249427], 
             UndirectedEdge[228, 385] -> 
             RGBColor[
              0.4716391113259436, 0.5796164418313421, 0.9521894554774726], 
             UndirectedEdge[175, 214] -> 
             RGBColor[
              0.5813526175939636, 0.6464089921975442, 0.9229266959429565], 
             UndirectedEdge[7, 41] -> 
             RGBColor[
              0.36511265513899505`, 0.490663963610935, 0.9444856334223808], 
             UndirectedEdge[176, 379] -> 
             RGBColor[
              0.2183904240990045, 0.34687256085365753`, 0.9357483836215341], 
             UndirectedEdge[259, 336] -> 
             RGBColor[
              0.21101362554134806`, 0.339119077853518, 0.9353282858566712], 
             UndirectedEdge[213, 340] -> 
             RGBColor[
              0.9523731210086097, 0.8369128200592044, 0.40569345010895497`], 
             UndirectedEdge[55, 165] -> 
             RGBColor[
              0.4681407137086776, 0.5777449578588358, 0.9516464016172608], 
             UndirectedEdge[108, 231] -> 
             RGBColor[
              0.3381266013166869, 0.4672842792810106, 0.9427663154046388], 
             UndirectedEdge[38, 230] -> 
             RGBColor[
              0.9673242221990019, 0.9014390702190636, 0.3275612028563362], 
             UndirectedEdge[39, 316] -> 
             RGBColor[
              0.26368578568270973`, 0.3944808577699287, 0.9383278874552436], 
             UndirectedEdge[85, 167] -> 
             RGBColor[
              0.2624284668147709, 0.39315933592110447`, 0.9382562850057511], 
             UndirectedEdge[28, 328] -> 
             RGBColor[
              0.2988631492240676, 0.4313905924329009, 0.9403335261361829], 
             UndirectedEdge[79, 120] -> 
             RGBColor[
              0.5785921359057922, 0.6687661870638313, 0.9599680388727843], 
             UndirectedEdge[130, 347] -> 
             RGBColor[
              0.34522783768479254`, 0.47078760076913406`, 0.9433157346482299],
              UndirectedEdge[77, 160] -> 
             RGBColor[
              0.8294213428991457, 0.5471802126352212, 0.5797239248650322], 
             UndirectedEdge[108, 179] -> 
             RGBColor[
              0.3186061180992342, 0.4467670137493473, 0.9416546527633719], 
             UndirectedEdge[318, 373] -> 
             RGBColor[
              0.2370696348066011, 0.3665055956377041, 0.9368121370379159], 
             UndirectedEdge[48, 331] -> 
             RGBColor[
              0.43876768248625253`, 0.5544602462898143, 0.9491788666343646], 
             UndirectedEdge[222, 312] -> 
             RGBColor[
              0.5339420376563727, 0.632517225840949, 0.9564530195798908], 
             UndirectedEdge[292, 353] -> 
             RGBColor[
              0.2106991637542155, 0.3387885585772128, 0.9353103777230984], 
             UndirectedEdge[175, 204] -> 
             RGBColor[
              0.17892957074057536`, 0.30539670201133906`, 0.9335011463998728],
              UndirectedEdge[198, 340] -> 
             RGBColor[
              0.9101338786876096, 0.9267923912389714, 0.7737391772833939], 
             UndirectedEdge[14, 207] -> 
             RGBColor[
              0.9671064480201461, 0.8947970383510977, 0.44882285376347564`], 
             UndirectedEdge[45, 271] -> 
             RGBColor[
              0.30114348847212347`, 0.43385127835713033`, 0.9404610482153953],
              UndirectedEdge[112, 183] -> 
             RGBColor[
              0.2939274002864909, 0.42440137973285763`, 0.9401184016257302], 
             UndirectedEdge[85, 139] -> 
             RGBColor[
              0.2262390695271757, 0.3551219848315275, 0.9361953523676381], 
             UndirectedEdge[45, 97] -> 
             RGBColor[
              0.36889177075057233`, 0.4927124766331557, 0.9447712800460943], 
             UndirectedEdge[130, 181] -> 
             RGBColor[
              0.48885894126290724`, 0.5947515646860737, 0.9532258537292853], 
             UndirectedEdge[63, 90] -> 
             RGBColor[
              0.8321834271804781, 0.8209894828739578, 0.632414864387591], 
             UndirectedEdge[114, 361] -> 
             RGBColor[
              0.342252200873233, 0.470863387125772, 0.9430289854912723], 
             UndirectedEdge[75, 209] -> 
             RGBColor[
              0.24810555583118551`, 0.37810504835234904`, 0.9374406164140838],
              UndirectedEdge[42, 276] -> 
             RGBColor[
              0.8488960037945177, 0.8827904862944987, 0.9853329329150746], 
             UndirectedEdge[205, 358] -> 
             RGBColor[
              0.9819225924478814, 0.9489876509677333, 0.5302516309431803], 
             UndirectedEdge[76, 358] -> 
             RGBColor[
              0.9077605542707283, 0.6337524810989443, 0.26250704350549825`], 
             UndirectedEdge[90, 142] -> 
             RGBColor[
              0.763694887526314, 0.46850478939826945`, 0.5698069638353204], 
             UndirectedEdge[152, 381] -> 
             RGBColor[
              0.588381597564026, 0.6508783727536576, 0.8485015174600479], 
             UndirectedEdge[86, 309] -> 
             RGBColor[
              0.28566340206902835`, 0.417580726053311, 0.9395794801954747], 
             UndirectedEdge[104, 358] -> 
             RGBColor[
              0.9512253799690775, 0.8406018507565884, 0.299039239235954], 
             UndirectedEdge[16, 369] -> 
             RGBColor[
              0.24965722981087085`, 0.3797359560868109, 0.9375289819517311], 
             UndirectedEdge[278, 337] -> 
             RGBColor[
              0.26857947792754067`, 0.39962443859725516`, 0.9386065759890179],
              UndirectedEdge[100, 350] -> 
             RGBColor[
              0.4046784181179114, 0.524933838870203, 0.9470067288527668], 
             UndirectedEdge[90, 202] -> 
             RGBColor[
              0.7810727137045386, 0.6020783764160916, 0.5864479898090358], 
             UndirectedEdge[126, 367] -> 
             RGBColor[
              0.21567822148491766`, 0.34402186394267437`, 0.935593927695006], 
             UndirectedEdge[278, 327] -> 
             RGBColor[
              0.28550387867049365`, 0.4165027145117478, 0.9396037276662406], 
             UndirectedEdge[10, 200] -> 
             RGBColor[
              0.31629276558560215`, 0.4448572861787412, 0.9415038068416022], 
             UndirectedEdge[149, 299] -> 
             RGBColor[
              0.21717366869177715`, 0.345593673773913, 0.9356790912011209], 
             UndirectedEdge[57, 284] -> 
             RGBColor[
              0.2586027566797, 0.38913827200511253`, 0.9380384164731898], 
             UndirectedEdge[125, 313] -> 
             RGBColor[
              0.2803971559769777, 0.4120455675112783, 0.9392795752712453], 
             UndirectedEdge[125, 196] -> 
             RGBColor[
              0.2879550374250095, 0.4199893801105207, 0.9397099854388271], 
             UndirectedEdge[21, 210] -> 
             RGBColor[
              0.30642042589023155`, 0.43901202359644165`, 0.9407756825511414],
              UndirectedEdge[186, 374] -> 
             RGBColor[
              0.2622856992899031, 0.3930092782004845, 0.9382481546064155], 
             UndirectedEdge[6, 74] -> 
             RGBColor[
              0.909010509687477, 0.9256078266033538, 0.7502192883025007], 
             UndirectedEdge[7, 312] -> 
             RGBColor[
              0.42618108450073044`, 0.5432966415402436, 0.9484491754681994], 
             UndirectedEdge[238, 299] -> 
             RGBColor[
              0.22167590498284873`, 0.3503258095740973, 0.9359354868974357], 
             UndirectedEdge[155, 239] -> 
             RGBColor[
              0.3145302695292589, 0.4464636896954298, 0.9412767880762385], 
             UndirectedEdge[108, 331] -> 
             RGBColor[
              0.40983077437371584`, 0.5293965508940257, 0.9473350324373369], 
             UndirectedEdge[55, 87] -> 
             RGBColor[
              0.34683568506465234`, 0.47311300029375225`, 0.9433840322411374],
              UndirectedEdge[186, 288] -> 
             RGBColor[
              0.2467468316416792, 0.3766769430810886, 0.9373632390815438], 
             UndirectedEdge[178, 371] -> 
             RGBColor[
              0.25801702472850174`, 0.38852263058685255`, 0.9380050599050818],
              UndirectedEdge[212, 238] -> 
             RGBColor[
              0.22006014114382055`, 0.3486275393339343, 0.9358434715371114], 
             UndirectedEdge[292, 329] -> 
             RGBColor[
              0.22307875219905648`, 0.35180029094398246`, 0.9360153769710722],
              UndirectedEdge[268, 338] -> 
             RGBColor[
              0.9058036870049794, 0.5621593672391498, 0.39196047146640556`], 
             UndirectedEdge[68, 309] -> 
             RGBColor[
              0.27375753584035556`, 0.40506690577145743`, 0.9389014587269024],
              UndirectedEdge[129, 309] -> 
             RGBColor[
              0.25423745991444247`, 0.38455006832902616`, 0.9377898192802863],
              UndirectedEdge[137, 330] -> 
             RGBColor[
              0.22316402213431713`, 0.35188991505236755`, 0.9360202329677398],
              UndirectedEdge[111, 400] -> 
             RGBColor[
              0.631844529693345, 0.5164916201579837, 0.581343351224306], 
             UndirectedEdge[62, 370] -> 
             RGBColor[
              0.5051424414592518, 0.5868980307983699, 0.9586362110924191], 
             UndirectedEdge[163, 280] -> 
             RGBColor[
              0.24199322930997053`, 0.37168060563466715`, 0.9370925284610774],
              UndirectedEdge[316, 383] -> 
             RGBColor[
              0.2672579164630078, 0.3982353937061947, 0.9385313150186878], 
             UndirectedEdge[307, 314] -> 
             RGBColor[
              0.9555259778682477, 0.9659228619523936, 0.9435306567958934], 
             UndirectedEdge[126, 259] -> 
             RGBColor[
              0.2115312190038542, 0.33966310139993294`, 0.93535776203865], 
             UndirectedEdge[44, 372] -> 
             RGBColor[
              0.27471702429732014`, 0.4060753889748091, 0.9389561001750906], 
             UndirectedEdge[202, 279] -> 
             RGBColor[
              0.9009946329017078, 0.6281412966873632, 0.2383554119012628], 
             UndirectedEdge[148, 312] -> 
             RGBColor[
              0.5434225996528742, 0.6402139731641597, 0.9571993641486982], 
             UndirectedEdge[109, 358] -> 
             RGBColor[
              0.9813365611926588, 0.9487453119833825, 0.5399636854424916], 
             UndirectedEdge[142, 275] -> 
             RGBColor[
              0.906842307128124, 0.5789554407018784, 0.47443924955803846`], 
             UndirectedEdge[296, 375] -> 
             RGBColor[
              0.2781834406546093, 0.40971881234981117`, 0.9391535074585348], 
             UndirectedEdge[92, 195] -> 
             RGBColor[
              0.26667927398787117`, 0.3976272037767742, 0.9384983621857534], 
             UndirectedEdge[178, 248] -> 
             RGBColor[
              0.230098166399185, 0.35917814032488304`, 0.9364151222254768], 
             UndirectedEdge[41, 222] -> 
             RGBColor[
              0.4728736082946373, 0.5798845479116403, 0.9524894775340721], 
             UndirectedEdge[154, 356] -> 
             RGBColor[
              0.4742682171286211, 0.5834424825573183, 0.951929030274608], 
             UndirectedEdge[70, 133] -> 
             RGBColor[
              0.28753417910083867`, 0.4195470313278583, 0.9396860181798696], 
             UndirectedEdge[7, 80] -> 
             RGBColor[
              0.36191069619973304`, 0.48789058771288196`, 0.9442816074301521],
              UndirectedEdge[152, 261] -> 
             RGBColor[
              0.18153226782756765`, 0.3081323016702944, 0.9336493661486316], 
             UndirectedEdge[95, 229] -> 
             RGBColor[
              0.2643373458997902, 0.3951656888693841, 0.9383649928457094], 
             UndirectedEdge[30, 204] -> 
             RGBColor[
              0.17892701604158556`, 0.30539401686072354`, 0.9335010009135446],
              UndirectedEdge[133, 223] -> 
             RGBColor[
              0.3756627076897743, 0.49871942307299955`, 0.945202383630783], 
             UndirectedEdge[298, 306] -> 
             RGBColor[
              0.8969031243202032, 0.8868893383314866, 0.6612189641553454], 
             UndirectedEdge[40, 96] -> 
             RGBColor[
              0.313111809733841, 0.4436046951713676, 0.9412461018545393], 
             UndirectedEdge[122, 146] -> 
             RGBColor[
              0.49070941162852855`, 0.5972227097318854, 0.9531038334374095], 
             UndirectedEdge[223, 267] -> 
             RGBColor[
              0.5126330687833186, 0.6152176449516955, 0.954775499492879], 
             UndirectedEdge[54, 322] -> 
             RGBColor[
              0.48020380618298864`, 0.5888540906805946, 0.9522325010212487], 
             UndirectedEdge[41, 154] -> 
             RGBColor[
              0.3854891726816393, 0.5083130789528232, 0.945784007101951], 
             UndirectedEdge[245, 353] -> 
             RGBColor[
              0.220139248365585, 0.34871068603969635`, 0.9358479765763623], 
             UndirectedEdge[26, 62] -> 
             RGBColor[
              0.31709055637755623`, 0.43703130766003234`, 0.9418781709758536],
              UndirectedEdge[217, 269] -> 
             RGBColor[
              0.9079422992480835, 0.582007875379239, 0.32768831635612294`], 
             UndirectedEdge[172, 347] -> 
             RGBColor[
              0.29073737323035515`, 0.422913791452218, 0.9398684353468445], 
             UndirectedEdge[63, 261] -> 
             RGBColor[
              0.5690047111878296, 0.5889104173173967, 0.6135243178829187], 
             UndirectedEdge[195, 369] -> 
             RGBColor[
              0.2515743275380513, 0.381750947349094, 0.9376381578312021], 
             UndirectedEdge[65, 180] -> 
             RGBColor[
              0.4408011041078431, 0.5545376633487222, 0.9497736818591127], 
             UndirectedEdge[49, 211] -> 
             RGBColor[
              0.25920679804656954`, 0.3897731577801271, 0.9380728157354339], 
             UndirectedEdge[285, 387] -> 
             RGBColor[
              0.2661419288540897, 0.3970624199715206, 0.9384677611753156], 
             UndirectedEdge[329, 388] -> 
             RGBColor[
              0.22925196747727483`, 0.358288731605845, 0.9363669324487132], 
             UndirectedEdge[38, 102] -> 
             RGBColor[
              0.8925441235088332, 0.5227994562196083, 0.24385895757801979`], 
             UndirectedEdge[92, 188] -> 
             RGBColor[
              0.27737488016395806`, 0.40886896400844064`, 0.9391074611347503],
              UndirectedEdge[114, 153] -> 
             RGBColor[
              0.32315432075329853`, 0.4543217632532496, 0.9418120854576224], 
             UndirectedEdge[326, 337] -> 
             RGBColor[
              0.312066783946898, 0.44249908551128714`, 0.9411868535891006], 
             UndirectedEdge[38, 221] -> 
             RGBColor[
              0.9438250637656209, 0.9183985790902189, 0.6570073333224926], 
             UndirectedEdge[350, 394] -> 
             RGBColor[
              0.3958053510234857, 0.5172484341263308, 0.9464413448636552], 
             UndirectedEdge[286, 349] -> 
             RGBColor[
              0.5858145101958898, 0.6731289759492968, 0.9614748008949803], 
             UndirectedEdge[246, 320] -> 
             RGBColor[
              0.5768484382747107, 0.6660576659405324, 0.9606094815615308], 
             UndirectedEdge[322, 362] -> 
             RGBColor[
              0.45653757665465905`, 0.5683555921624378, 0.9507245098029286], 
             UndirectedEdge[80, 348] -> 
             RGBColor[
              0.2986858104115632, 0.42889469918101, 0.9404079890218355], 
             UndirectedEdge[78, 230] -> 
             RGBColor[
              0.9053505911840212, 0.6146233921482407, 0.26060988945584945`], 
             UndirectedEdge[248, 329] -> 
             RGBColor[
              0.22567335718883677`, 0.3545273852956994, 0.9361631358868661], 
             UndirectedEdge[43, 330] -> 
             RGBColor[
              0.2261035990920075, 0.35497959681484403`, 0.9361876375267658], 
             UndirectedEdge[63, 217] -> 
             RGBColor[
              0.8906933611547283, 0.5241662585096577, 0.23150456873895697`], 
             UndirectedEdge[79, 136] -> 
             RGBColor[
              0.6046940354323059, 0.6899568849766287, 0.9620228760179198], 
             UndirectedEdge[159, 243] -> 
             RGBColor[
              0.3099032733211534, 0.44096065205359114`, 0.9410367126469893], 
             UndirectedEdge[1, 327] -> 
             RGBColor[
              0.3392875835527789, 0.4682955846087937, 0.9428400826971212], 
             UndirectedEdge[304, 353] -> 
             RGBColor[
              0.21473904123945592`, 0.3430347259572272, 0.9355404427694197], 
             UndirectedEdge[240, 329] -> 
             RGBColor[
              0.23717266786335917`, 0.3666138899130299, 0.9368180046180745], 
             UndirectedEdge[10, 311] -> 
             RGBColor[
              0.4406499577202704, 0.5542970021663628, 0.9497943740304772], 
             UndirectedEdge[353, 378] -> 
             RGBColor[
              0.20945304207089746`, 0.33747880567936756`, 0.9352394129367053],
              UndirectedEdge[167, 243] -> 
             RGBColor[
              0.28596070978623506`, 0.41789321531449325`, 0.9395964114301423],
              UndirectedEdge[169, 292] -> 
             RGBColor[
              0.21585857380573317`, 0.34421142566684904`, 0.9356041984928691],
              UndirectedEdge[211, 347] -> 
             RGBColor[
              0.27136364126610246`, 0.4025507707922349, 0.9387651299723484], 
             UndirectedEdge[224, 340] -> 
             RGBColor[
              0.9847198182906963, 0.959331532205712, 0.46205791346696695`], 
             UndirectedEdge[144, 233] -> 
             RGBColor[
              0.8479481693127158, 0.33804742930989184`, 0.1923147220140613], 
             UndirectedEdge[273, 394] -> 
             RGBColor[
              0.3171526741702776, 0.4460438307034582, 0.9415424253765902], 
             UndirectedEdge[93, 94] -> 
             RGBColor[
              0.2526810398598759, 0.3829141721689455, 0.9377011834606958], 
             UndirectedEdge[358, 366] -> 
             RGBColor[
              0.934928559139148, 0.7751416322731404, 0.28588252947049914`], 
             UndirectedEdge[245, 329] -> 
             RGBColor[
              0.232518836810426, 0.36172241840646596`, 0.936552975824336], 
             UndirectedEdge[44, 93] -> 
             RGBColor[
              0.2715973273730923, 0.4027963897072362, 0.9387784380504338], 
             UndirectedEdge[218, 314] -> 
             RGBColor[
              0.9179378774680893, 0.9374027630058823, 0.9920349282773651], 
             UndirectedEdge[133, 346] -> 
             RGBColor[
              0.32114511749891506`, 0.4515193689112592, 0.9417229503460453], 
             UndirectedEdge[143, 272] -> 
             RGBColor[
              0.635830587523557, 0.7151635871324875, 0.9645228442451073], 
             UndirectedEdge[272, 346] -> 
             RGBColor[
              0.4960244700071036, 0.5987224642834593, 0.954329185667129], 
             UndirectedEdge[61, 269] -> 
             RGBColor[
              0.9932024163292561, 0.9878689808064407, 0.5015031511422814], 
             UndirectedEdge[158, 362] -> 
             RGBColor[
              0.4538874638081069, 0.5662041111673836, 0.9505158832119648], 
             UndirectedEdge[294, 393] -> 
             RGBColor[
              0.21778977524310467`, 0.34624124082276975`, 0.9357141775577711],
              UndirectedEdge[17, 298] -> 
             RGBColor[
              0.6794733687434446, 0.7479201915203444, 0.969798835244192], 
             UndirectedEdge[83, 179] -> 
             RGBColor[
              0.3112624132414147, 0.4404062657068423, 0.9411867183836149], 
             UndirectedEdge[223, 398] -> 
             RGBColor[
              0.696746297429305, 0.7610076864937902, 0.9687930758283795], 
             UndirectedEdge[52, 272] -> 
             RGBColor[
              0.5168312067307885, 0.6167442138565202, 0.9556549725324873], 
             UndirectedEdge[52, 174] -> 
             RGBColor[
              0.5576254346896334, 0.6486129747855855, 0.95972095993169], 
             UndirectedEdge[63, 317] -> 
             RGBColor[
              0.9745940579826633, 0.9311354530743134, 0.5492576472683819], 
             UndirectedEdge[145, 280] -> 
             RGBColor[
              0.23851863392834902`, 0.36802858558651175`, 0.9368946553942974],
              UndirectedEdge[152, 317] -> 
             RGBColor[
              0.5871216146224013, 0.6503573374272111, 0.8693826955340949], 
             UndirectedEdge[102, 391] -> 
             RGBColor[
              0.8198439128231849, 0.15353458638285297`, 0.16663585937096298`],
              UndirectedEdge[168, 251] -> 
             RGBColor[
              0.7462331666341901, 0.8017011358685895, 0.9753362046447762], 
             UndirectedEdge[89, 245] -> 
             RGBColor[
              0.22424083690782642`, 0.3530217156533258, 0.9360815559760864], 
             UndirectedEdge[293, 330] -> 
             RGBColor[
              0.21800150715905772`, 0.3464637844910152, 0.9357262353771553], 
             UndirectedEdge[166, 247] -> 
             RGBColor[
              0.8658883217742317, 0.43020733825048896`, 0.20769325769109587`],
              UndirectedEdge[8, 182] -> 
             RGBColor[
              0.29920713316336395`, 0.4316705233112208, 0.9403561039493367], 
             UndirectedEdge[2, 215] -> 
             RGBColor[
              0.8188696957350476, 0.14604632693877936`, 0.16570294798714186`],
              UndirectedEdge[61, 107] -> 
             RGBColor[
              0.9162817916828967, 0.6453128669663495, 0.3511545314597267], 
             UndirectedEdge[192, 361] -> 
             RGBColor[
              0.35005813253929685`, 0.4776244927973833, 0.9435263725545195], 
             UndirectedEdge[71, 321] -> 
             RGBColor[
              0.8444532383444727, 0.878825868324395, 0.985021184343525], 
             UndirectedEdge[26, 389] -> 
             RGBColor[
              0.31710049015279534`, 0.4370417486876464, 0.9418787366896577], 
             UndirectedEdge[134, 263] -> 
             RGBColor[
              0.24820523859568883`, 0.3782098212580943, 0.9374462932000549], 
             UndirectedEdge[105, 282] -> 
             RGBColor[
              0.5321029414738284, 0.6299784125013272, 0.956625284939209], 
             UndirectedEdge[323, 340] -> 
             RGBColor[
              0.9119941865056833, 0.9282757501963927, 0.7739166151037982], 
             UndirectedEdge[311, 323] -> 
             RGBColor[
              0.6747921418079339, 0.7440706990607763, 0.9694867808520644], 
             UndirectedEdge[29, 365] -> 
             RGBColor[
              0.24833496351636752`, 0.37834617037476265`, 0.9374536808423768],
              UndirectedEdge[321, 384] -> 
             RGBColor[
              0.7831071512596195, 0.8304885254895837, 0.9790164603513036], 
             UndirectedEdge[115, 195] -> 
             RGBColor[
              0.2421504028292495, 0.3718458049688061, 0.937101479260483], 
             UndirectedEdge[162, 359] -> 
             RGBColor[
              0.24582605828944576`, 0.3757091519074889, 0.9373108024012962], 
             UndirectedEdge[106, 295] -> 
             RGBColor[
              0.5954410834145789, 0.6666014753537031, 0.9545919964182874], 
             UndirectedEdge[24, 242] -> 
             RGBColor[
              0.9102499321760205, 0.681280510728698, 0.24661228929151274`], 
             UndirectedEdge[109, 286] -> 
             RGBColor[
              0.8601731647723879, 0.8889489686867593, 0.8604250468482817], 
             UndirectedEdge[287, 367] -> 
             RGBColor[
              0.23976404440825078`, 0.3693375909644736, 0.936965579678708], 
             UndirectedEdge[74, 140] -> 
             RGBColor[
              0.7482992359076605, 0.8033342207586809, 0.9755370742792053], 
             UndirectedEdge[168, 394] -> 
             RGBColor[
              0.5145092206731405, 0.613750519132451, 0.9559228612077943], 
             UndirectedEdge[68, 249] -> 
             RGBColor[
              0.2731469520224531, 0.4044251434655919, 0.9388666868817508], 
             UndirectedEdge[389, 400] -> 
             RGBColor[
              0.2843495171102985, 0.40872323643536973`, 0.9397784081644269], 
             UndirectedEdge[267, 346] -> 
             RGBColor[
              0.4581154785924594, 0.5680175907899552, 0.9512960662081413], 
             UndirectedEdge[16, 392] -> 
             RGBColor[
              0.24490486142793333`, 0.37474091559878486`, 0.9372583416028217],
              UndirectedEdge[13, 191] -> 
             RGBColor[
              0.8213167457883995, 0.8607762667176537, 0.9574101949991654], 
             UndirectedEdge[312, 327] -> 
             RGBColor[
              0.39077465425622554`, 0.5126293712413812, 0.9461931090416965], 
             UndirectedEdge[260, 291] -> 
             RGBColor[
              0.7527228069990448, 0.8067520448236535, 0.9759880328732503], 
             UndirectedEdge[83, 344] -> 
             RGBColor[
              0.33675515918736176`, 0.4661021259068189, 0.9426787188558917], 
             UndirectedEdge[200, 288] -> 
             RGBColor[
              0.25784282293400623`, 0.38833953345580596`, 0.9379951393705938],
              UndirectedEdge[297, 332] -> 
             RGBColor[
              0.736930313911651, 0.7933926635631983, 0.9655671808709663], 
             UndirectedEdge[189, 241] -> 
             RGBColor[
              0.2957543458619668, 0.428186947782479, 0.9401541445162689], 
             UndirectedEdge[276, 358] -> 
             RGBColor[
              0.8670714087363368, 0.8612246187195758, 0.654847436421338], 
             UndirectedEdge[11, 102] -> 
             RGBColor[
              0.8713798486298555, 0.4417965181232547, 0.21169331699237254`], 
             UndirectedEdge[96, 243] -> 
             RGBColor[
              0.2876417202462759, 0.4196600638902152, 0.9396921424890095], 
             UndirectedEdge[171, 397] -> 
             RGBColor[
              0.26128106780929927`, 0.39195334681705507`, 0.9381909423298143],
              UndirectedEdge[314, 385] -> 
             RGBColor[
              0.7506165131369036, 0.8049365561291917, 0.9762521831517132], 
             UndirectedEdge[11, 213] -> 
             RGBColor[
              0.9172153878071567, 0.709493629531714, 0.2522477617062842], 
             UndirectedEdge[68, 129] -> 
             RGBColor[
              0.25720454661950837`, 0.38766866458021304`, 0.9379587904787283],
              UndirectedEdge[137, 277] -> 
             RGBColor[
              0.23968446191505444`, 0.36925394471830275`, 0.9369610475734522],
              UndirectedEdge[35, 327] -> 
             RGBColor[
              0.29981659218631795`, 0.43154628389532945`, 0.9404188155272046],
              UndirectedEdge[155, 183] -> 
             RGBColor[
              0.2817396246657633, 0.4134565872206231, 0.9393560268770672], 
             UndirectedEdge[63, 256] -> 
             RGBColor[
              0.5919347091448884, 0.6130112990161062, 0.6148301473446811], 
             UndirectedEdge[144, 358] -> 
             RGBColor[
              0.9235073892649484, 0.7232807673563957, 0.2763524253689754], 
             UndirectedEdge[192, 332] -> 
             RGBColor[
              0.43585567576042195`, 0.5499313562155932, 0.9495477612304457], 
             UndirectedEdge[149, 259] -> 
             RGBColor[
              0.21561966255991427`, 0.3439603147996455, 0.9355905928508573], 
             UndirectedEdge[146, 165] -> 
             RGBColor[
              0.5340400056803238, 0.6325967606962016, 0.956460731981605], 
             UndirectedEdge[164, 280] -> 
             RGBColor[
              0.2407758584059484, 0.37040107162876656`, 0.9370232009890322], 
             UndirectedEdge[65, 105] -> 
             RGBColor[
              0.46633814789011974`, 0.5766565671437895, 0.9514008797073982], 
             UndirectedEdge[73, 369] -> 
             RGBColor[
              0.2502849628040927, 0.38039574326325765`, 0.9375647304170474], 
             UndirectedEdge[187, 281] -> 
             RGBColor[
              0.7379639441479849, 0.795257108792612, 0.9745741950769791], 
             UndirectedEdge[53, 253] -> 
             RGBColor[
              0.31547986955209806`, 0.4458714425532633, 0.9413890964198188], 
             UndirectedEdge[132, 191] -> 
             RGBColor[
              0.7390378619070974, 0.7960612617083893, 0.9746240454395679], 
             UndirectedEdge[29, 273] -> 
             RGBColor[
              0.25793330326133057`, 0.388434634016608, 0.9380002920913812], 
             UndirectedEdge[138, 366] -> 
             RGBColor[
              0.8603116610551809, 0.39715139303420033`, 0.20274719460083632`],
              UndirectedEdge[229, 309] -> 
             RGBColor[
              0.25884330525935606`, 0.3893911038139919, 0.9380521153589414], 
             UndirectedEdge[274, 287] -> 
             RGBColor[
              0.2454706833388167, 0.37533563030230443`, 0.937290564323588], 
             UndirectedEdge[251, 312] -> 
             RGBColor[
              0.6426365090387243, 0.7180224324379316, 0.9668896222215277], 
             UndirectedEdge[339, 360] -> 
             RGBColor[
              0.3380761124684098, 0.46724626924582036`, 0.942762888830887], 
             UndirectedEdge[150, 365] -> 
             RGBColor[
              0.26342074735738313`, 0.39420228568561005`, 0.9383127939147053],
              UndirectedEdge[61, 300] -> 
             RGBColor[
              0.9416713408004723, 0.7907793854302443, 0.3735219082012329], 
             UndirectedEdge[62, 389] -> 
             RGBColor[
              0.17907819285502502`, 0.305552913276812, 0.9335096102094239], 
             UndirectedEdge[374, 399] -> 
             RGBColor[
              0.255491371590293, 0.38586800900293716`, 0.9378612276952298], 
             UndirectedEdge[27, 51] -> 
             RGBColor[
              0.33517005330446453`, 0.4636817173337682, 0.9426160703012283], 
             UndirectedEdge[58, 159] -> 
             RGBColor[
              0.31512279365295653`, 0.44644669885901933`, 0.9413339566082971],
              UndirectedEdge[57, 153] -> 
             RGBColor[
              0.2953190920495516, 0.42692650296079127`, 0.9401587579547649], 
             UndirectedEdge[84, 264] -> 
             RGBColor[
              0.18447901438019912`, 0.31122951913163255`, 0.9338171790054831],
              UndirectedEdge[159, 201] -> 
             RGBColor[
              0.30393044061377905`, 0.43468282617867443`, 0.9406965686603185],
              UndirectedEdge[80, 87] -> 
             RGBColor[
              0.3122775575094636, 0.4431804871474425, 0.9411820189118731], 
             UndirectedEdge[39, 288] -> 
             RGBColor[
              0.2590590279232666, 0.38961784201136873`, 0.9380644004455181], 
             UndirectedEdge[91, 365] -> 
             RGBColor[
              0.259430965008946, 0.3900087714705911, 0.9380855817123159], 
             UndirectedEdge[5, 384] -> 
             RGBColor[
              0.7949354326614759, 0.8399023141409853, 0.9801493658443617], 
             UndirectedEdge[156, 381] -> 
             RGBColor[
              0.5895532840978516, 0.6521098895899253, 0.8485682432747944], 
             UndirectedEdge[2, 197] -> 
             RGBColor[
              0.9036013141673853, 0.5662229928500411, 0.5006917858198119], 
             UndirectedEdge[238, 293] -> 
             RGBColor[
              0.22022708573500543`, 0.3488030086841681, 0.935852978784607], 
             UndirectedEdge[85, 325] -> 
             RGBColor[
              0.22643759197523877`, 0.355330644511492, 0.9362066579273677], 
             UndirectedEdge[146, 332] -> 
             RGBColor[
              0.53127642233297, 0.6303531592368088, 0.9562431725771618], 
             UndirectedEdge[197, 204] -> 
             RGBColor[
              0.5838392169462935, 0.6475052215433456, 0.8847911904815791], 
             UndirectedEdge[20, 130] -> 
             RGBColor[
              0.4090322853711047, 0.5287049398531881, 0.9472841534241666], 
             UndirectedEdge[167, 348] -> 
             RGBColor[
              0.2732523450214962, 0.4045359181898883, 0.9388726888571313], 
             UndirectedEdge[83, 237] -> 
             RGBColor[
              0.4656503502316991, 0.5743478756221865, 0.9518303486289299], 
             UndirectedEdge[178, 334] -> 
             RGBColor[
              0.25269374017822266`, 0.3829275210087747, 0.9377019067250372], 
             UndirectedEdge[178, 388] -> 
             RGBColor[
              0.23367677668762307`, 0.36293948663502873`, 0.9366189187873238],
              UndirectedEdge[115, 184] -> 
             RGBColor[
              0.22818450918176583`, 0.35716676525650004`, 0.936306142277947], 
             UndirectedEdge[165, 385] -> 
             RGBColor[
              0.5540849096952511, 0.648870116788155, 0.9580387402525627], 
             UndirectedEdge[202, 257] -> 
             RGBColor[
              0.8394733977788387, 0.30441540944716294`, 0.18543307633282935`],
              UndirectedEdge[35, 57] -> 
             RGBColor[
              0.2771242370211076, 0.4086055221736117, 0.9390931873785582], 
             UndirectedEdge[115, 206] -> 
             RGBColor[
              0.23508408472910247`, 0.364418656615107, 0.9366990628983605], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.34476855469957235`, 0.4730429263345264, 0.9431893253319623], 
             UndirectedEdge[61, 98] -> 
             RGBColor[
              0.985458002900472, 0.9620883573989745, 0.44224268706809605`], 
             UndirectedEdge[33, 173] -> 
             RGBColor[
              0.20265449886636056`, 0.33033310571886365`, 0.9348522459587503],
              UndirectedEdge[6, 185] -> 
             RGBColor[
              0.9085190133388343, 0.5856402039031354, 0.34380931507742224`], 
             UndirectedEdge[300, 363] -> 
             RGBColor[
              0.8762546358068509, 0.5309830273105506, 0.21845617365184725`], 
             UndirectedEdge[34, 270] -> 
             RGBColor[
              0.28093807902462586`, 0.41228653639826196`, 0.9393223741835017],
              UndirectedEdge[162, 179] -> 
             RGBColor[
              0.25786357675267113`, 0.38836134703509095`, 0.9379963212698641],
              UndirectedEdge[11, 250] -> 
             RGBColor[
              0.9558449394073578, 0.8618308276345842, 0.5510217386219683], 
             UndirectedEdge[66, 314] -> 
             RGBColor[
              0.9492974340005453, 0.9317668939083206, 0.6707765260947278], 
             UndirectedEdge[153, 327] -> 
             RGBColor[
              0.31801144721476193`, 0.44986726468250904`, 0.9414843861034113],
              UndirectedEdge[153, 392] -> 
             RGBColor[
              0.28268998646480836`, 0.4136525122596839, 0.9394395490748012], 
             UndirectedEdge[110, 369] -> 
             RGBColor[
              0.2565159464057226, 0.38694490209574905`, 0.9379195757152459], 
             UndirectedEdge[321, 398] -> 
             RGBColor[
              0.8786059330927678, 0.9059622064053712, 0.9849470713031456], 
             UndirectedEdge[188, 278] -> 
             RGBColor[
              0.2597507710467335, 0.39034490789317966`, 0.9381037941930572], 
             UndirectedEdge[213, 289] -> 
             RGBColor[
              0.9043607109741805, 0.6566643735845665, 0.24180812561664938`], 
             UndirectedEdge[236, 263] -> 
             RGBColor[
              0.2563029052327246, 0.3867209823153376, 0.9379074433356098], 
             UndirectedEdge[93, 383] -> 
             RGBColor[
              0.2627372188358315, 0.39348385387124796`, 0.9382738679765928], 
             UndirectedEdge[56, 286] -> 
             RGBColor[
              0.5885924555434128, 0.6755350925857282, 0.9616518091160838], 
             UndirectedEdge[25, 144] -> 
             RGBColor[
              0.8635746104404736, 0.45815910336800225`, 0.20727861968554306`],
              UndirectedEdge[143, 331] -> 
             RGBColor[
              0.5383683584932644, 0.6360774364876114, 0.9568106700316372], 
             UndirectedEdge[76, 257] -> 
             RGBColor[
              0.8347758028344946, 0.2683076362057045, 0.1809346541089509], 
             UndirectedEdge[91, 189] -> 
             RGBColor[
              0.28158397795101814`, 0.4132929926548542, 0.9393471630269211], 
             UndirectedEdge[133, 145] -> 
             RGBColor[
              0.26764114093786784`, 0.3986381869271076, 0.9385531390856012], 
             UndirectedEdge[207, 230] -> 
             RGBColor[
              0.9543565255231943, 0.8529328333505086, 0.30199072149137773`], 
             UndirectedEdge[238, 336] -> 
             RGBColor[
              0.22011483416770328`, 0.34868502516977307`, 0.9358465862239105],
              UndirectedEdge[123, 306] -> 
             RGBColor[
              0.9723361250736168, 0.9460422517382365, 0.6339056761634236], 
             UndirectedEdge[272, 338] -> 
             RGBColor[
              0.8206526510459409, 0.8571827716487312, 0.7925776008366022], 
             UndirectedEdge[11, 289] -> 
             RGBColor[
              0.9106079850234978, 0.6814327334094423, 0.24683482895909917`], 
             UndirectedEdge[215, 300] -> 
             RGBColor[
              0.8546424874802127, 0.37132299820425807`, 0.1980133295950229], 
             UndirectedEdge[224, 289] -> 
             RGBColor[
              0.9367074082562672, 0.779083085731074, 0.29817258897466137`], 
             UndirectedEdge[65, 161] -> 
             RGBColor[
              0.4733844161827434, 0.5827596905831183, 0.9518498616922337], 
             UndirectedEdge[14, 247] -> 
             RGBColor[
              0.9506823086964485, 0.8296807989526216, 0.43560760573952945`], 
             UndirectedEdge[150, 226] -> 
             RGBColor[
              0.2546174021107136, 0.38494941166703367`, 0.9378114564262897], 
             UndirectedEdge[15, 180] -> 
             RGBColor[
              0.33506546922916314`, 0.4641869420312098, 0.9425875907675709], 
             UndirectedEdge[7, 114] -> 
             RGBColor[
              0.359141437487956, 0.48549199500373064`, 0.9441051527137969], 
             UndirectedEdge[108, 313] -> 
             RGBColor[
              0.3251887159565602, 0.4536857414582067, 0.9420295219732657], 
             UndirectedEdge[227, 315] -> 
             RGBColor[
              0.2390981188616284, 0.3686376609928552, 0.9369276562039764], 
             UndirectedEdge[174, 384] -> 
             RGBColor[
              0.7385166114389616, 0.7956540568810313, 0.9745720920642666], 
             UndirectedEdge[104, 138] -> 
             RGBColor[
              0.8766084818851104, 0.4626116115176483, 0.21590390436629117`], 
             UndirectedEdge[313, 344] -> 
             RGBColor[
              0.30171850127564737`, 0.43335702114888963`, 0.940534020647694], 
             UndirectedEdge[255, 374] -> 
             RGBColor[
              0.2682893522658295, 0.3993194981317673, 0.938590053761786], 
             UndirectedEdge[87, 167] -> 
             RGBColor[
              0.28684409211939654`, 0.41882170615632086`, 0.9396467187471687],
              UndirectedEdge[114, 312] -> 
             RGBColor[
              0.3959175277947622, 0.5170838698121216, 0.9465208083959076], 
             UndirectedEdge[50, 265] -> 
             RGBColor[
              0.5230211648142513, 0.6236511692879999, 0.9555932884652836], 
             UndirectedEdge[310, 345] -> 
             RGBColor[
              0.19226277251810686`, 0.3194107424533439, 0.9342604525163987], 
             UndirectedEdge[315, 334] -> 
             RGBColor[
              0.25233663141566864`, 0.38255217705732714`, 0.9376815699093048],
              UndirectedEdge[102, 302] -> 
             RGBColor[
              0.9032870347441282, 0.5590378183717704, 0.2855931390985828], 
             UndirectedEdge[172, 211] -> 
             RGBColor[
              0.2820509294380053, 0.413783788274112, 0.9393737552233123], 
             UndirectedEdge[264, 381] -> 
             RGBColor[
              0.5915890217554157, 0.6542495789412477, 0.8486841755227887], 
             UndirectedEdge[270, 397] -> 
             RGBColor[
              0.2494683482405557, 0.3795374295806264, 0.9375182254257268], 
             UndirectedEdge[48, 290] -> 
             RGBColor[
              0.4152883060919923, 0.5341235905648768, 0.9476827815325197], 
             UndirectedEdge[224, 323] -> 
             RGBColor[
              0.9029358765369997, 0.8985069119905342, 0.6718086867166897], 
             UndirectedEdge[10, 339] -> 
             RGBColor[
              0.3638431893323356, 0.48956441613441326`, 0.9444047441837249], 
             UndirectedEdge[254, 320] -> 
             RGBColor[
              0.5897027051719504, 0.6767516973442059, 0.9615500313265857], 
             UndirectedEdge[92, 392] -> 
             RGBColor[
              0.26780652703776464`, 0.39881201820418366`, 0.9385625575793235],
              UndirectedEdge[166, 224] -> 
             RGBColor[
              0.9002153061275288, 0.5604772287427979, 0.2656511065099155], 
             UndirectedEdge[108, 344] -> 
             RGBColor[
              0.3440988640451813, 0.47246287394932385`, 0.9431466532356487], 
             UndirectedEdge[180, 271] -> 
             RGBColor[
              0.3365289525569892, 0.46572515579895724`, 0.942670933978061], 
             UndirectedEdge[104, 207] -> 
             RGBColor[
              0.9368649528111581, 0.7873976069432023, 0.2680582629430743], 
             UndirectedEdge[45, 266] -> 
             RGBColor[
              0.2752485126978604, 0.4066340169820878, 0.9389863676532347], 
             UndirectedEdge[59, 373] -> 
             RGBColor[
              0.2921699969184407, 0.4220829828981863, 0.9400355750383738], 
             UndirectedEdge[107, 352] -> 
             RGBColor[
              0.9166859076311894, 0.6461772301173578, 0.39514005851685197`], 
             UndirectedEdge[99, 338] -> 
             RGBColor[
              0.9862079875593082, 0.9866999578573392, 0.7708056942036536], 
             UndirectedEdge[186, 341] -> 
             RGBColor[
              0.23502569235584353`, 0.3643572825285215, 0.9366957375390872], 
             UndirectedEdge[90, 156] -> 
             RGBColor[
              0.4458826703540418, 0.5414428840631231, 0.9526066384680504], 
             UndirectedEdge[34, 151] -> 
             RGBColor[
              0.31406226415390115`, 0.44644668080690353`, 0.9412327476508988],
              UndirectedEdge[174, 260] -> 
             RGBColor[
              0.7687797089830702, 0.819295818690549, 0.9775884348027377], 
             UndirectedEdge[13, 216] -> 
             RGBColor[
              0.8114408517281416, 0.8530611432182054, 0.956425858174716], 
             UndirectedEdge[9, 217] -> 
             RGBColor[
              0.8242465537218799, 0.18737521357976708`, 0.17085183326762515`],
              UndirectedEdge[87, 159] -> 
             RGBColor[
              0.3107866556543149, 0.4418891428954188, 0.9410870199640158], 
             UndirectedEdge[184, 305] -> 
             RGBColor[
              0.21033276310750965`, 0.33840344826638225`, 0.9352895117483098],
              UndirectedEdge[12, 259] -> 
             RGBColor[
              0.2147288372822968, 0.3430240009512847, 0.9355398616691548], 
             UndirectedEdge[27, 287] -> 
             RGBColor[
              0.27881505582512084`, 0.4103826799407336, 0.9391894770081045], 
             UndirectedEdge[188, 284] -> 
             RGBColor[
              0.25554200422115014`, 0.38592122710826227`, 0.9378641111486529],
              UndirectedEdge[118, 126] -> 
             RGBColor[
              0.20905168496127685`, 0.33705695390964574`, 0.935216556243067], 
             UndirectedEdge[209, 304] -> 
             RGBColor[
              0.23556571159456763`, 0.3649248769876179, 0.9367264908358456], 
             UndirectedEdge[48, 108] -> 
             RGBColor[
              0.3965059868386308, 0.5178552896544295, 0.9464859887582483], 
             UndirectedEdge[136, 376] -> 
             RGBColor[
              0.5284877060748537, 0.6276839131134415, 0.9561356038127271], 
             UndirectedEdge[48, 344] -> 
             RGBColor[
              0.373035772157718, 0.49752656934511247`, 0.9449904874326764], 
             UndirectedEdge[13, 198] -> 
             RGBColor[
              0.8951348791523555, 0.9184961361184019, 0.9647537428637106], 
             UndirectedEdge[286, 320] -> 
             RGBColor[
              0.7180719499645429, 0.7796825319520332, 0.9725343592747207], 
             UndirectedEdge[176, 368] -> 
             RGBColor[
              0.2143024966118115, 0.34257588987504495`, 0.9355155821986852], 
             UndirectedEdge[248, 388] -> 
             RGBColor[
              0.21978649931888122`, 0.34833992442602935`, 0.935827888039998], 
             UndirectedEdge[57, 188] -> 
             RGBColor[
              0.270146670915944, 0.40127165779384166`, 0.9386958253112532], 
             UndirectedEdge[39, 225] -> 
             RGBColor[
              0.26510008482719366`, 0.3959673758425263, 0.9384084296992539], 
             UndirectedEdge[355, 379] -> 
             RGBColor[
              0.2259392634266556, 0.3548068696110762, 0.9361782788537368], 
             UndirectedEdge[85, 348] -> 
             RGBColor[
              0.2521313444108594, 0.3823364073993248, 0.9376698791180758], 
             UndirectedEdge[118, 336] -> 
             RGBColor[
              0.20853409149877072`, 0.3365129303632308, 0.9351870800610882], 
             UndirectedEdge[195, 392] -> 
             RGBColor[
              0.24682195915511385`, 0.3767559068610679, 0.9373675174822926], 
             UndirectedEdge[193, 281] -> 
             RGBColor[
              0.7271668299156635, 0.7866477829836171, 0.9735443566828026], 
             UndirectedEdge[154, 312] -> 
             RGBColor[
              0.4465576020433747, 0.5609457568821319, 0.9497475491477698], 
             UndirectedEdge[53, 171] -> 
             RGBColor[
              0.28122827358250124`, 0.41291912481058346`, 0.9393269061893516],
              UndirectedEdge[115, 188] -> 
             RGBColor[
              0.25284600900533644`, 0.38308756520047255`, 0.9377105782094798],
              UndirectedEdge[319, 329] -> 
             RGBColor[
              0.2383612491721791, 0.3678631642290072, 0.9368856925652633], 
             UndirectedEdge[231, 359] -> 
             RGBColor[
              0.2771261222266016, 0.4086075036441148, 0.9390932947382222], 
             UndirectedEdge[288, 399] -> 
             RGBColor[
              0.23995250394206913`, 0.3695356738835413, 0.9369763121703581], 
             UndirectedEdge[140, 220] -> 
             RGBColor[
              0.5736797551483913, 0.6643251817234797, 0.9598909775899255], 
             UndirectedEdge[9, 215] -> 
             RGBColor[
              0.822477817482793, 0.1737799317809825, 0.1691580894475736], 
             UndirectedEdge[309, 329] -> 
             RGBColor[
              0.25296463724126, 0.3832122509978928, 0.9377173339120208], 
             UndirectedEdge[9, 61] -> 
             RGBColor[
              0.9095066708030527, 0.5932363190069687, 0.34466666805378354`], 
             UndirectedEdge[21, 82] -> 
             RGBColor[
              0.34606714839588365`, 0.4741677029250543, 0.94327207057399], 
             UndirectedEdge[154, 361] -> 
             RGBColor[
              0.39289227512184555`, 0.5147252741957822, 0.9462557262431346], 
             UndirectedEdge[160, 213] -> 
             RGBColor[
              0.8702228477750129, 0.45615422864304855`, 0.21154106500959308`],
              UndirectedEdge[331, 342] -> 
             RGBColor[
              0.5277253347918338, 0.6274369503840362, 0.9559728122191802], 
             UndirectedEdge[122, 159] -> 
             RGBColor[
              0.3887610902465449, 0.5111470494961861, 0.9459924907959437], 
             UndirectedEdge[258, 278] -> 
             RGBColor[
              0.25267444257649463`, 0.38290723800581994`, 0.937700807755167], 
             UndirectedEdge[37, 201] -> 
             RGBColor[
              0.26311290635419504`, 0.3938787252730125, 0.9382952628249838], 
             UndirectedEdge[61, 314] -> 
             RGBColor[
              0.9595789423265859, 0.965928622564677, 0.7549534149051582], 
             UndirectedEdge[297, 314] -> 
             RGBColor[
              0.9362255007006572, 0.9517027043636277, 0.9839981831745597], 
             UndirectedEdge[84, 175] -> 
             RGBColor[
              0.1789295778879611, 0.3053967095236947, 0.9335011468069058], 
             UndirectedEdge[72, 374] -> 
             RGBColor[
              0.25191511783451104`, 0.3821091395580259, 0.9376575653344313], 
             UndirectedEdge[168, 180] -> 
             RGBColor[
              0.5182102560481305, 0.6169561699548207, 0.9561586879091916], 
             UndirectedEdge[36, 60] -> 
             RGBColor[
              0.4386028192989782, 0.5525156396146701, 0.9496662072988238], 
             UndirectedEdge[347, 387] -> 
             RGBColor[
              0.2868094179961087, 0.41878526145427897`, 0.9396447441071433], 
             UndirectedEdge[140, 141] -> 
             RGBColor[
              0.5159944713875729, 0.6149616035084853, 0.9560493981699523], 
             UndirectedEdge[233, 382] -> 
             RGBColor[
              0.8581195774771997, 0.3842334181920808, 0.20080199431053547`], 
             UndirectedEdge[21, 122] -> 
             RGBColor[
              0.37950236392749337`, 0.5031276061157393, 0.9454025329420639], 
             UndirectedEdge[202, 268] -> 
             RGBColor[
              0.836829312925746, 0.2840918146209231, 0.18290109769144122`], 
             UndirectedEdge[196, 344] -> 
             RGBColor[
              0.3092763827236792, 0.441300833748132, 0.9409644308152758], 
             UndirectedEdge[109, 343] -> 
             RGBColor[
              0.8581485111146978, 0.8873672938614341, 0.8602232482931473], 
             UndirectedEdge[52, 117] -> 
             RGBColor[
              0.36808130040816744`, 0.4932352549346425, 0.9446747928738624], 
             UndirectedEdge[51, 194] -> 
             RGBColor[
              0.38048922371828053`, 0.5039823744655038, 0.945465414775287], 
             UndirectedEdge[223, 342] -> 
             RGBColor[
              0.5287126959381665, 0.6282718106549494, 0.9560413466441238], 
             UndirectedEdge[241, 374] -> 
             RGBColor[
              0.2835328374534444, 0.4153413675567334, 0.939458147692505], 
             UndirectedEdge[76, 109] -> 
             RGBColor[
              0.9205204428847344, 0.6768339136433675, 0.4700439928721189], 
             UndirectedEdge[90, 381] -> 
             RGBColor[
              0.849476415301395, 0.8807671291171392, 0.8672733890419332], 
             UndirectedEdge[75, 227] -> 
             RGBColor[
              0.2395500669875186, 0.36911268712833206`, 0.9369533939811485], 
             UndirectedEdge[209, 329] -> 
             RGBColor[
              0.24358590725750107`, 0.37335461113913604`, 0.9371832291140334],
              UndirectedEdge[24, 358] -> 
             RGBColor[
              0.9353648485028525, 0.777122720375753, 0.28624658001000514`], 
             UndirectedEdge[208, 369] -> 
             RGBColor[
              0.24527033350139205`, 0.37512504992025775`, 0.9372791546967377],
              UndirectedEdge[62, 400] -> 
             RGBColor[
              0.2843395833350594, 0.4087127954077557, 0.9397778424506229], 
             UndirectedEdge[127, 325] -> 
             RGBColor[
              0.21103171786447747`, 0.3391380940322466, 0.9353293161877081], 
             UndirectedEdge[43, 277] -> 
             RGBColor[
              0.2426240388727448, 0.37234362648077923`, 0.9371284521324783], 
             UndirectedEdge[70, 227] -> 
             RGBColor[
              0.25636607330828476`, 0.3867873759678386, 0.9379110406640643], 
             UndirectedEdge[25, 366] -> 
             RGBColor[
              0.8749957803146731, 0.510019968284747, 0.21680872378706678`], 
             UndirectedEdge[20, 387] -> 
             RGBColor[
              0.3506138656824209, 0.476702600538333, 0.94361316288308], 
             UndirectedEdge[328, 387] -> 
             RGBColor[
              0.30150296805800375`, 0.4341652094015489, 0.9404838599135137], 
             UndirectedEdge[249, 386] -> 
             RGBColor[
              0.3044662110801129, 0.4345129066433197, 0.9407539204836926], 
             UndirectedEdge[110, 243] -> 
             RGBColor[
              0.2719749479938126, 0.4031932929221435, 0.9387999429861442], 
             UndirectedEdge[47, 121] -> 
             RGBColor[
              0.4935440296663224, 0.5991928393789325, 0.9534184801906773], 
             UndirectedEdge[31, 156] -> 
             RGBColor[
              0.18458847622123073`, 0.3113445704668384, 0.9338234126953957], 
             UndirectedEdge[98, 283] -> 
             RGBColor[
              0.9432427006605664, 0.8062936865407971, 0.3064669136008217], 
             UndirectedEdge[38, 358] -> 
             RGBColor[
              0.9671839420965409, 0.9009658724941282, 0.3270162411479497], 
             UndirectedEdge[126, 199] -> 
             RGBColor[
              0.21892225618889471`, 0.3474315501002342, 0.9357786706722784], 
             UndirectedEdge[39, 200] -> 
             RGBColor[
              0.27187585958380484`, 0.4030891447206572, 0.9387943000477824], 
             UndirectedEdge[227, 304] -> 
             RGBColor[
              0.22701022275090071`, 0.35593251576360085`, 0.9362392684029103],
              UndirectedEdge[242, 333] -> 
             RGBColor[
              0.5569536477379948, 0.5184281382754727, 0.5938032026627618], 
             UndirectedEdge[30, 333] -> 
             RGBColor[
              0.1872437438170861, 0.31413542506377157`, 0.9339746262568631], 
             UndirectedEdge[85, 96] -> 
             RGBColor[
              0.2641094772748117, 0.3949261844968264, 0.9383520160646184], 
             UndirectedEdge[39, 94] -> 
             RGBColor[
              0.2666080163774077, 0.39755230751018356`, 0.9384943041702538], 
             UndirectedEdge[63, 138] -> 
             RGBColor[
              0.8889519646070447, 0.5107811215593289, 0.22983700543826907`], 
             UndirectedEdge[119, 324] -> 
             RGBColor[
              0.26022801088632164`, 0.3908465172233403, 0.9381309722959088], 
             UndirectedEdge[18, 224] -> 
             RGBColor[
              0.960434037083298, 0.9441092105197667, 0.6687925780376456], 
             UndirectedEdge[84, 204] -> 
             RGBColor[
              0.17892700714738574`, 0.30539400751235557`, 0.933501000407033], 
             UndirectedEdge[241, 288] -> 
             RGBColor[
              0.2679939698052205, 0.39900903243733754`, 0.9385732321676334], 
             UndirectedEdge[91, 266] -> 
             RGBColor[
              0.25880957199136756`, 0.38935564801052325`, 0.9380501942992334],
              UndirectedEdge[201, 263] -> 
             RGBColor[
              0.26925494850456955`, 0.4003344010010207, 0.9386450430391104], 
             UndirectedEdge[29, 266] -> 
             RGBColor[
              0.2477135704987891, 0.37769304691469485`, 0.9374182934292943], 
             UndirectedEdge[161, 326] -> 
             RGBColor[
              0.3854134409611904, 0.5082474839429573, 0.9457791815436909], 
             UndirectedEdge[174, 235] -> 
             RGBColor[
              0.7343495307888845, 0.7923987018062052, 0.9741567564086497], 
             UndirectedEdge[207, 233] -> 
             RGBColor[
              0.8786570254685007, 0.4672262975790694, 0.21740805642807715`], 
             UndirectedEdge[199, 212] -> 
             RGBColor[
              0.21834996970250586`, 0.3468300407179805, 0.9357460798035004], 
             UndirectedEdge[127, 184] -> 
             RGBColor[
              0.21412931839643223`, 0.34239386859054827`, 0.9355057199555137],
              UndirectedEdge[261, 381] -> 
             RGBColor[
              0.5862976993087463, 0.6486880635605781, 0.8483828425372609], 
             UndirectedEdge[221, 230] -> 
             RGBColor[
              0.9453580743501937, 0.9235697837599854, 0.6629627899588003], 
             UndirectedEdge[22, 273] -> 
             RGBColor[
              0.28387789683872655`, 0.4157040468486936, 0.9394777983140272], 
             UndirectedEdge[240, 292] -> 
             RGBColor[
              0.2251125947151853, 0.3539379883814973, 0.9361312012935654], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.4322766112650586, 0.5488154801889021, 0.9487714854439504], 
             UndirectedEdge[120, 343] -> 
             RGBColor[
              0.64428944346767, 0.7208791499127623, 0.9659761919445966], 
             UndirectedEdge[175, 310] -> 
             RGBColor[
              0.18075514602575382`, 0.30731549738422004`, 0.933605110211667], 
             UndirectedEdge[55, 201] -> 
             RGBColor[
              0.33997947002411655`, 0.46590668357700793`, 0.9429935809374401],
              UndirectedEdge[264, 333] -> 
             RGBColor[
              0.19279573500831393`, 0.31997091982232506`, 0.9342908039417687],
              UndirectedEdge[107, 197] -> 
             RGBColor[
              0.9139845567949747, 0.6460331456516251, 0.5106347906861869], 
             UndirectedEdge[131, 300] -> 
             RGBColor[
              0.9062314787117222, 0.661847076989811, 0.24319781291959908`], 
             UndirectedEdge[164, 227] -> 
             RGBColor[
              0.23873025962291325`, 0.36825101760934276`, 0.9369067071645306],
              UndirectedEdge[75, 315] -> 
             RGBColor[
              0.24372617436870905`, 0.3735020407664642, 0.9371912171185102], 
             UndirectedEdge[123, 193] -> 
             RGBColor[
              0.8983178729767032, 0.9207629901755221, 0.9556553997903747], 
             UndirectedEdge[157, 253] -> 
             RGBColor[
              0.40547981020843754`, 0.5251955404755204, 0.9471772728723662], 
             UndirectedEdge[87, 110] -> 
             RGBColor[
              0.27285833032697415`, 0.4041217837639711, 0.9388502503031707], 
             UndirectedEdge[112, 273] -> 
             RGBColor[
              0.30217928403804095`, 0.4330746327553852, 0.940588334197813], 
             UndirectedEdge[193, 384] -> 
             RGBColor[
              0.7853837252276628, 0.8322860419074539, 0.9792383154624147], 
             UndirectedEdge[95, 249] -> 
             RGBColor[
              0.2756739059578213, 0.4070811322697972, 0.9390105931700766], 
             UndirectedEdge[61, 66] -> 
             RGBColor[
              0.9830643953423903, 0.9540141570597834, 0.4329439736998075], 
             UndirectedEdge[113, 251] -> 
             RGBColor[
              0.8094157442625041, 0.8510598457172036, 0.9816336535080088], 
             UndirectedEdge[107, 131] -> 
             RGBColor[
              0.8808419295941465, 0.5163805585259162, 0.22083043617809295`], 
             UndirectedEdge[71, 343] -> 
             RGBColor[
              0.7966602927353739, 0.841489655974727, 0.98025763017568], 
             UndirectedEdge[113, 168] -> 
             RGBColor[
              0.7333330676267822, 0.7916046330585647, 0.9740554448600397], 
             UndirectedEdge[58, 201] -> 
             RGBColor[
              0.2876186397714912, 0.4196358048478299, 0.939690828090115], 
             UndirectedEdge[47, 130] -> 
             RGBColor[
              0.4221487542491271, 0.5400657659424366, 0.9481199232226362], 
             UndirectedEdge[17, 82] -> 
             RGBColor[
              0.4573668797759753, 0.5683380513272105, 0.9509806674680623], 
             UndirectedEdge[11, 25] -> 
             RGBColor[
              0.8860868883930885, 0.5548412704093811, 0.2257767948788701], 
             UndirectedEdge[73, 392] -> 
             RGBColor[
              0.24553259442115521`, 0.3754007027752315, 0.9372940900681379], 
             UndirectedEdge[155, 337] -> 
             RGBColor[
              0.29464447603044647`, 0.42702040421973947`, 0.9400909390712692],
              UndirectedEdge[159, 165] -> 
             RGBColor[
              0.43209168429834016`, 0.5465211004605023, 0.9493493893401392], 
             UndirectedEdge[226, 368] -> 
             RGBColor[
              0.2257077662103317, 0.35456355135894857`, 0.9361650954297367], 
             UndirectedEdge[188, 258] -> 
             RGBColor[
              0.2600095899871553, 0.39061694300963157`, 0.938118533548826], 
             UndirectedEdge[140, 350] -> 
             RGBColor[
              0.5523338730537959, 0.6464369667603329, 0.9583649127104528], 
             UndirectedEdge[14, 38] -> 
             RGBColor[
              0.9800741446959539, 0.9433032752196526, 0.4743933351284341], 
             UndirectedEdge[242, 268] -> 
             RGBColor[
              0.8678329199624942, 0.4240532300724246, 0.2086880773194431], 
             UndirectedEdge[20, 50] -> 
             RGBColor[
              0.4309033063250306, 0.5476259924741631, 0.9486839796675377], 
             UndirectedEdge[149, 212] -> 
             RGBColor[
              0.21555790485274898`, 0.34389540353375003`, 0.9355870758407967],
              UndirectedEdge[80, 361] -> 
             RGBColor[
              0.34502145958500996`, 0.47326197983492335`, 0.9432054402076274],
              UndirectedEdge[31, 204] -> 
             RGBColor[
              0.1810722066459815, 0.3076487481988837, 0.9336231663449399], 
             UndirectedEdge[209, 245] -> 
             RGBColor[
              0.2409659187206967, 0.37060083707008695`, 0.9370340246427882], 
             UndirectedEdge[113, 148] -> 
             RGBColor[
              0.7102018348766541, 0.7732513864434318, 0.9719433954351793], 
             UndirectedEdge[48, 231] -> 
             RGBColor[
              0.3670635094292236, 0.49234797467679914`, 0.9446101496016666], 
             UndirectedEdge[198, 224] -> 
             RGBColor[
              0.901075568718926, 0.8970235530331128, 0.6716312488962854], 
             UndirectedEdge[1, 188] -> 
             RGBColor[
              0.3135344759290187, 0.4421377779902256, 0.9413401492239378], 
             UndirectedEdge[256, 264] -> 
             RGBColor[
              0.2076696899760163, 0.3356043895565939, 0.9351378536731348], 
             UndirectedEdge[15, 170] -> 
             RGBColor[
              0.3744152758657625, 0.49826976676104406`, 0.9450949256507872], 
             UndirectedEdge[20, 322] -> 
             RGBColor[
              0.45803755349750475`, 0.5696547967126826, 0.9508200870009773], 
             UndirectedEdge[92, 153] -> 
             RGBColor[
              0.30254730129756563`, 0.4345238091753902, 0.940570393778262], 
             UndirectedEdge[189, 360] -> 
             RGBColor[
              0.30546923311788443`, 0.43824575192600135`, 0.9407129642351355],
              UndirectedEdge[272, 342] -> 
             RGBColor[
              0.6251875638221265, 0.7065231010289125, 0.9636849864326502], 
             UndirectedEdge[69, 219] -> 
             RGBColor[
              0.4677032328653056, 0.5785751319820428, 0.9512844483334466], 
             UndirectedEdge[86, 151] -> 
             RGBColor[
              0.30818593638346986`, 0.44059786327207706`, 0.9408861053327038],
              UndirectedEdge[72, 288] -> 
             RGBColor[
              0.2363762501862872, 0.36577680443863003`, 0.9367726498095597], 
             UndirectedEdge[266, 273] -> 
             RGBColor[
              0.265217664230201, 0.3960909592500517, 0.938415125672312], 
             UndirectedEdge[131, 297] -> 
             RGBColor[
              0.9345525999537521, 0.8450176590746574, 0.6158415354980056], 
             UndirectedEdge[219, 360] -> 
             RGBColor[
              0.37878978346753606`, 0.5025104047366595, 0.9453571279452656], 
             UndirectedEdge[58, 236] -> 
             RGBColor[
              0.27466659649964625`, 0.4060223861621468, 0.9389532283866143], 
             UndirectedEdge[272, 321] -> 
             RGBColor[
              0.7324016958614257, 0.7908770383567805, 0.9739626144266329], 
             UndirectedEdge[250, 391] -> 
             RGBColor[
              0.9043090036006871, 0.5735688958941825, 0.5059642810005588], 
             UndirectedEdge[122, 298] -> 
             RGBColor[
              0.634758859433705, 0.711422615804957, 0.9663329898214426], 
             UndirectedEdge[113, 282] -> 
             RGBColor[
              0.7216887092702036, 0.7825079718100041, 0.9728948440417715], 
             UndirectedEdge[237, 343] -> 
             RGBColor[
              0.6503098019378368, 0.7257667481329021, 0.9664501366166679], 
             UndirectedEdge[174, 398] -> 
             RGBColor[
              0.83401539327211, 0.8711277377968187, 0.9805027030161089], 
             UndirectedEdge[223, 384] -> 
             RGBColor[
              0.6012475155961567, 0.6855340055780029, 0.9628624648765374], 
             UndirectedEdge[143, 260] -> 
             RGBColor[
              0.7167991404658595, 0.7784168360748085, 0.9725930329082488], 
             UndirectedEdge[148, 161] -> 
             RGBColor[
              0.5276623353729026, 0.6268249505740837, 0.9561228183174523], 
             UndirectedEdge[137, 199] -> 
             RGBColor[
              0.22367942926895015`, 0.3524316406295666, 0.9360495846415806], 
             UndirectedEdge[147, 387] -> 
             RGBColor[
              0.28915329202202544`, 0.42124882166571403`, 0.9397782242654684],
              UndirectedEdge[138, 381] -> 
             RGBColor[
              0.9062449527279615, 0.5705587678025101, 0.4646955300926113], 
             UndirectedEdge[42, 207] -> 
             RGBColor[
              0.9360408404789141, 0.8740255032004962, 0.6319312562767279], 
             UndirectedEdge[185, 247] -> 
             RGBColor[
              0.8653490116625105, 0.42606196440460237`, 0.20717681371904806`],
              UndirectedEdge[49, 380] -> 
             RGBColor[
              0.2606135317686764, 0.39125172411413095`, 0.9381529271398318], 
             UndirectedEdge[63, 242] -> 
             RGBColor[
              0.9384539463641798, 0.7929291511512139, 0.2733380495894395], 
             UndirectedEdge[12, 238] -> 
             RGBColor[
              0.22383004590865202`, 0.3525899482675398, 0.9360581620363942], 
             UndirectedEdge[109, 382] -> 
             RGBColor[
              0.9464386860434384, 0.8125481887830079, 0.4923766470320703], 
             UndirectedEdge[4, 115] -> 
             RGBColor[
              0.23540129852856206`, 0.36475206843085556`, 0.936717127754964], 
             UndirectedEdge[187, 279] -> 
             RGBColor[
              0.8947917399967904, 0.8503099582405043, 0.6300514927715455], 
             UndirectedEdge[152, 156] -> 
             RGBColor[
              0.18478785261667285`, 0.31155412769964164`, 0.9338347668861651],
              UndirectedEdge[143, 290] -> 
             RGBColor[
              0.5148889820990041, 0.6157407807626738, 0.9553145849297924], 
             UndirectedEdge[48, 234] -> 
             RGBColor[
              0.38209114426819646`, 0.5053698775309731, 0.945567487736205], 
             UndirectedEdge[294, 341] -> 
             RGBColor[
              0.21717163219876068`, 0.3455915332906315, 0.9356789752258563], 
             UndirectedEdge[243, 351] -> 
             RGBColor[
              0.26705822161415743`, 0.39802550175866824`, 0.9385199426924677],
              UndirectedEdge[241, 399] -> 
             RGBColor[
              0.2629204824738216, 0.3936764755743613, 0.938284304569662], 
             UndirectedEdge[78, 207] -> 
             RGBColor[
              0.8908498839236407, 0.5609459506099194, 0.22908395145458324`], 
             UndirectedEdge[174, 267] -> 
             RGBColor[
              0.6499021646261236, 0.725337696254724, 0.9664851266806084], 
             UndirectedEdge[124, 293] -> 
             RGBColor[
              0.21725116581640602`, 0.3456751281654994, 0.9356835045477219], 
             UndirectedEdge[57, 392] -> 
             RGBColor[
              0.2605783177897506, 0.3912147119895847, 0.9381509217558264], 
             UndirectedEdge[272, 331] -> 
             RGBColor[
              0.5495546990516302, 0.6450876581742866, 0.9577400845269233], 
             UndirectedEdge[91, 255] -> 
             RGBColor[
              0.26154809523840944`, 0.39223400957556664`, 0.9382061491468703],
              UndirectedEdge[35, 337] -> 
             RGBColor[
              0.28289219144336497`, 0.41466800798083686`, 0.9394216638499819],
              UndirectedEdge[219, 339] -> 
             RGBColor[
              0.4064741730871376, 0.5264892315672777, 0.9471211527714821], 
             UndirectedEdge[166, 185] -> 
             RGBColor[
              0.8242297938213237, 0.1872463896398561, 0.17083578396792481`], 
             UndirectedEdge[137, 238] -> 
             RGBColor[
              0.22538960071026484`, 0.3542291392455204, 0.9361469763751915], 
             UndirectedEdge[218, 300] -> 
             RGBColor[
              0.9000302759419758, 0.7622535258714493, 0.6106034215734397], 
             UndirectedEdge[96, 110] -> 
             RGBColor[
              0.2712447160930261, 0.4024257728950402, 0.9387583573596757], 
             UndirectedEdge[225, 375] -> 
             RGBColor[
              0.2559767228165143, 0.3863781439147409, 0.9378888677295503], 
             UndirectedEdge[24, 25] -> 
             RGBColor[
              0.8754320696783777, 0.5120010563873596, 0.21717277432657275`], 
             UndirectedEdge[40, 361] -> 
             RGBColor[
              0.34746932604333547`, 0.4753821987277793, 0.9433614160937887], 
             UndirectedEdge[141, 394] -> 
             RGBColor[
              0.3594659493572627, 0.4857730708744833, 0.9441258303231546], 
             UndirectedEdge[200, 360] -> 
             RGBColor[
              0.29052568872167633`, 0.4225391392901483, 0.9398619514887643], 
             UndirectedEdge[68, 229] -> 
             RGBColor[
              0.2618103919644219, 0.39250970006517877`, 0.9382210865573835], 
             UndirectedEdge[96, 258] -> 
             RGBColor[
              0.26992237493120286`, 0.4010359084926919, 0.9386830519867384], 
             UndirectedEdge[106, 310] -> 
             RGBColor[
              0.5655364837016175, 0.6351698449942476, 0.952888973704525], 
             UndirectedEdge[15, 394] -> 
             RGBColor[
              0.33136443385417313`, 0.4609812912088401, 0.9423517640661736], 
             UndirectedEdge[115, 203] -> 
             RGBColor[
              0.265001837635785, 0.3958641118151241, 0.9384028346670469], 
             UndirectedEdge[218, 298] -> 
             RGBColor[
              0.8667469534105012, 0.8965845097029781, 0.9871522922420749], 
             UndirectedEdge[165, 262] -> 
             RGBColor[
              0.7356958172611161, 0.7926545035064209, 0.9725524468455675], 
             UndirectedEdge[141, 357] -> 
             RGBColor[
              0.5178770250869611, 0.6164322687663853, 0.9562370335292427], 
             UndirectedEdge[15, 239] -> 
             RGBColor[
              0.3141879177885835, 0.4461038563096259, 0.9412572916510711], 
             UndirectedEdge[80, 228] -> 
             RGBColor[
              0.35113678778418134`, 0.4785587697557132, 0.9435951035129062], 
             UndirectedEdge[260, 272] -> 
             RGBColor[
              0.7279854810242253, 0.7874270577614837, 0.9735224474035349], 
             UndirectedEdge[7, 361] -> 
             RGBColor[
              0.3725157575792012, 0.497076158853894, 0.9449573525635642], 
             UndirectedEdge[22, 255] -> 
             RGBColor[
              0.27639668732322686`, 0.40784082131182386`, 0.9390517544995772],
              UndirectedEdge[28, 380] -> 
             RGBColor[
              0.2768898890919296, 0.40835920764152867`, 0.9390798416106783], 
             UndirectedEdge[53, 397] -> 
             RGBColor[
              0.26929675474869136`, 0.4003783420142617, 0.9386474238428664], 
             UndirectedEdge[187, 306] -> 
             RGBColor[
              0.9071549779062498, 0.8950638881018478, 0.6621967951023203], 
             UndirectedEdge[208, 392] -> 
             RGBColor[
              0.24051796511845452`, 0.3701300094322317, 0.9370085143478284], 
             UndirectedEdge[33, 381] -> 
             RGBColor[
              0.5860442078575524, 0.648421627973087, 0.8483684065741224], 
             UndirectedEdge[290, 321] -> 
             RGBColor[
              0.6114600904368728, 0.6914542319869668, 0.964754355111318], 
             UndirectedEdge[20, 116] -> 
             RGBColor[
              0.4119401607737857, 0.531223595372923, 0.9474694406734923], 
             UndirectedEdge[33, 156] -> 
             RGBColor[
              0.18245046291019928`, 0.30909738291907096`, 0.9337016560002396],
              UndirectedEdge[9, 202] -> 
             RGBColor[
              0.8410035318945833, 0.31617669076982174`, 0.1868983344901058], 
             UndirectedEdge[76, 233] -> 
             RGBColor[
              0.8322013343184957, 0.24851914305244047`, 0.17846934015058413`],
              UndirectedEdge[115, 369] -> 
             RGBColor[
              0.24803002426208054`, 0.37802565988424164`, 0.9374363150029623],
              UndirectedEdge[183, 335] -> 
             RGBColor[
              0.2697259044179279, 0.4008294055262898, 0.9386718632816594], 
             UndirectedEdge[39, 296] -> 
             RGBColor[
              0.2873068026652887, 0.4193080442775966, 0.9396730694282384], 
             UndirectedEdge[10, 219] -> 
             RGBColor[
              0.4045568603314619, 0.5248285516252523, 0.9469989832981036], 
             UndirectedEdge[71, 143] -> 
             RGBColor[
              0.7478821300066041, 0.8031124171001021, 0.9755814141619994], 
             UndirectedEdge[232, 384] -> 
             RGBColor[
              0.6369922413654878, 0.7145531842390913, 0.965676420626344], 
             UndirectedEdge[1, 57] -> 
             RGBColor[
              0.31659522838756854`, 0.44535482288707584`, 0.9415144545484747],
              UndirectedEdge[288, 393] -> 
             RGBColor[
              0.23392299503197628`, 0.3631982777260886, 0.9366329405577875], 
             UndirectedEdge[328, 372] -> 
             RGBColor[
              0.2804573452843499, 0.4120449254968854, 0.9392853428307628], 
             UndirectedEdge[16, 115] -> 
             RGBColor[
              0.240233305102069, 0.36983081370652304`, 0.936992303381012], 
             UndirectedEdge[34, 244] -> 
             RGBColor[
              0.2861625929026812, 0.4177778317374103, 0.9396199025198813], 
             UndirectedEdge[233, 366] -> 
             RGBColor[
              0.8593693391869154, 0.3899082942266366, 0.20184482611558502`], 
             UndirectedEdge[100, 105] -> 
             RGBColor[
              0.3969790975995051, 0.5182650744162607, 0.9465161349575758], 
             UndirectedEdge[88, 282] -> 
             RGBColor[
              0.8185877701205739, 0.8571575543356513, 0.887813136638508], 
             UndirectedEdge[189, 219] -> 
             RGBColor[
              0.37386729373661226`, 0.4974887142474586, 0.9450712281757306], 
             UndirectedEdge[44, 328] -> 
             RGBColor[
              0.3036968641952127, 0.4364711333428047, 0.9406087990529493], 
             UndirectedEdge[153, 154] -> 
             RGBColor[
              0.3737943950019111, 0.49818365032325973`, 0.9450388262094847], 
             UndirectedEdge[73, 258] -> 
             RGBColor[
              0.2480246190771097, 0.3780199786921288, 0.9374360071856744], 
             UndirectedEdge[22, 141] -> 
             RGBColor[
              0.32619117202571163`, 0.45543328701971864`, 0.9420612032605917],
              UndirectedEdge[100, 273] -> 
             RGBColor[
              0.3260257412647034, 0.4537292354473304, 0.9421078093657018], 
             UndirectedEdge[230, 391] -> 
             RGBColor[
              0.8946240115133538, 0.5321742003823082, 0.2503381046492794], 
             UndirectedEdge[338, 384] -> 
             RGBColor[
              0.8713581064441347, 0.8967942587815345, 0.7976314467612728], 
             UndirectedEdge[76, 207] -> 
             RGBColor[
              0.8934001271128089, 0.5805482372855583, 0.23152606721261854`], 
             UndirectedEdge[144, 370] -> 
             RGBColor[
              0.8548273648949809, 0.7045756223106869, 0.6020207461756493], 
             UndirectedEdge[6, 340] -> 
             RGBColor[
              0.9935628356137232, 0.988639881211936, 0.5407325660065214], 
             UndirectedEdge[30, 370] -> 
             RGBColor[
              0.5050718279609444, 0.5868238115344944, 0.9586321897581539], 
             UndirectedEdge[164, 245] -> 
             RGBColor[
              0.23621867801950508`, 0.36561118610068966`, 0.9367636763077685],
              UndirectedEdge[56, 108] -> 
             RGBColor[
              0.40925205503740436`, 0.5288952932921922, 0.9472981569529686], 
             UndirectedEdge[50, 322] -> 
             RGBColor[
              0.4812818793914586, 0.5897653370483966, 0.952307419020761], 
             UndirectedEdge[379, 399] -> 
             RGBColor[
              0.22791818849812123`, 0.356886845332283, 0.9362909757089996], 
             UndirectedEdge[6, 13] -> 
             RGBColor[
              0.978563836078469, 0.9803436260913665, 0.7317471315868381], 
             UndirectedEdge[55, 60] -> 
             RGBColor[
              0.38053049793671245`, 0.5040181241190069, 0.9454680447319882], 
             UndirectedEdge[44, 47] -> 
             RGBColor[
              0.36592423069765223`, 0.4903693505688373, 0.9445738718209851], 
             UndirectedEdge[156, 264] -> 
             RGBColor[
              0.1879952768080626, 0.31492533388723165`, 0.9340174249489059], 
             UndirectedEdge[32, 43] -> 
             RGBColor[
              0.2218603287150994, 0.3505196506098328, 0.9359459895561568], 
             UndirectedEdge[144, 207] -> 
             RGBColor[
              0.9091469621070289, 0.6700765235430096, 0.2453714490760957], 
             UndirectedEdge[14, 213] -> 
             RGBColor[
              0.9526625957676589, 0.8375319772984231, 0.4372009912003371], 
             UndirectedEdge[127, 139] -> 
             RGBColor[
              0.2108331954164144, 0.3389294343522821, 0.9353180106279786], 
             UndirectedEdge[321, 342] -> 
             RGBColor[
              0.7105723316016292, 0.7732263305665302, 0.9721953421188899], 
             UndirectedEdge[82, 182] -> 
             RGBColor[
              0.3336557333984177, 0.4615081693978327, 0.9425511382946132], 
             UndirectedEdge[50, 172] -> 
             RGBColor[
              0.3777861468106212, 0.500941670871986, 0.945324186142565], 
             UndirectedEdge[80, 96] -> 
             RGBColor[
              0.31066394327551555`, 0.4414844762785116, 0.9410901259683782], 
             UndirectedEdge[78, 160] -> 
             RGBColor[
              0.835660765688327, 0.2751098484934552, 0.18178209553720334`], 
             UndirectedEdge[32, 293] -> 
             RGBColor[
              0.2137582367821496, 0.342003838286004, 0.9354845874065463], 
             UndirectedEdge[322, 328] -> 
             RGBColor[
              0.4089266558730876, 0.5271174055758985, 0.947690784031411], 
             UndirectedEdge[120, 254] -> 
             RGBColor[
              0.5179448523327678, 0.6195299901302602, 0.955193662551596], 
             UndirectedEdge[291, 321] -> 
             RGBColor[
              0.7571390218362452, 0.8102020254189503, 0.9764281998963484], 
             UndirectedEdge[65, 312] -> 
             RGBColor[
              0.4891446804627151, 0.5961487131731942, 0.9529264075234798], 
             UndirectedEdge[209, 334] -> 
             RGBColor[
              0.2567160128781451, 0.387155184643212, 0.9379309692048785], 
             UndirectedEdge[295, 310] -> 
             RGBColor[
              0.2124827502833183, 0.3406632211052174, 0.935411950337351], 
             UndirectedEdge[109, 205] -> 
             RGBColor[
              0.9946824810618875, 0.9920690835121566, 0.737788580309801], 
             UndirectedEdge[194, 376] -> 
             RGBColor[
              0.4132241787161002, 0.5323357471779375, 0.947551257161364], 
             UndirectedEdge[142, 338] -> 
             RGBColor[
              0.9079361737525008, 0.5785505948422507, 0.3940025431841314], 
             UndirectedEdge[232, 386] -> 
             RGBColor[
              0.4324598922567031, 0.5470353068857565, 0.9493188938960907], 
             UndirectedEdge[169, 378] -> 
             RGBColor[
              0.21461245212241514`, 0.34290167276900374`, 0.9355332337064761],
              UndirectedEdge[94, 324] -> 
             RGBColor[
              0.2700408112862358, 0.4011603926111301, 0.9386897967619465], 
             UndirectedEdge[196, 231] -> 
             RGBColor[
              0.3033041199951848, 0.43612223907981873`, 0.9405840929842658], 
             UndirectedEdge[207, 366] -> 
             RGBColor[
              0.9205681319812286, 0.7219373884597544, 0.2549015531776194], 
             UndirectedEdge[156, 310] -> 
             RGBColor[
              0.1842688448604277, 0.3110086176408356, 0.93380521016225], 
             UndirectedEdge[206, 369] -> 
             RGBColor[
              0.2445080094379043, 0.3743237989953949, 0.9372357414690795], 
             UndirectedEdge[119, 225] -> 
             RGBColor[
              0.24880323623162193`, 0.37883835468870003`, 0.9374803482807631],
              UndirectedEdge[69, 100] -> 
             RGBColor[
              0.4324163535905058, 0.5480114107243323, 0.9490359995890186], 
             UndirectedEdge[64, 182] -> 
             RGBColor[
              0.34352729206089855`, 0.4700584173523088, 0.9431801452835099], 
             UndirectedEdge[217, 268] -> 
             RGBColor[
              0.8200723347530428, 0.15529033743086842`, 0.16685459646896056`],
              UndirectedEdge[235, 275] -> 
             RGBColor[
              0.8660971591696807, 0.893943749566336, 0.8776528174795629], 
             UndirectedEdge[5, 99] -> 
             RGBColor[
              0.9097853137766493, 0.92980801321679, 0.9533236132867424], 
             UndirectedEdge[52, 267] -> 
             RGBColor[
              0.4789222153161444, 0.5860393403630161, 0.9526218530734996], 
             UndirectedEdge[290, 346] -> 
             RGBColor[
              0.3750828645825507, 0.4992996579136456, 0.9451209263518141], 
             UndirectedEdge[19, 108] -> 
             RGBColor[
              0.3209765938651673, 0.4492585340761873, 0.9417896478514372], 
             UndirectedEdge[92, 327] -> 
             RGBColor[
              0.3031279877877182, 0.4350267706270088, 0.9406073946079336], 
             UndirectedEdge[151, 244] -> 
             RGBColor[
              0.28793584651295273`, 0.41931373488830953`, 0.9397328926719012],
              UndirectedEdge[114, 327] -> 
             RGBColor[
              0.32373500724345117`, 0.4548247247048681, 0.941849086287294], 
             UndirectedEdge[99, 174] -> 
             RGBColor[
              0.8533664925541351, 0.885559755956836, 0.9477463395066474], 
             UndirectedEdge[180, 282] -> 
             RGBColor[
              0.5065658976915518, 0.60785950870626, 0.9549980870909234], 
             UndirectedEdge[199, 277] -> 
             RGBColor[
              0.24180779724081597`, 0.3714857047729135, 0.9370819683790612], 
             UndirectedEdge[237, 286] -> 
             RGBColor[
              0.652334455595527, 0.7273484229582274, 0.9666519351718024], 
             UndirectedEdge[290, 313] -> 
             RGBColor[
              0.34397103520992167`, 0.4699540423686539, 0.9432263147475373], 
             UndirectedEdge[56, 237] -> 
             RGBColor[
              0.5146770314008289, 0.6168123226982427, 0.9549542854004349], 
             UndirectedEdge[203, 361] -> 
             RGBColor[
              0.32351204834138475`, 0.4530276285511149, 0.941893609121445], 
             UndirectedEdge[169, 315] -> 
             RGBColor[
              0.23198634740170132`, 0.3611627382761178, 0.9365226513402567], 
             UndirectedEdge[23, 304] -> 
             RGBColor[
              0.2162581809318601, 0.34463143809296365`, 0.9356269555275363], 
             UndirectedEdge[129, 270] -> 
             RGBColor[
              0.24363580909960866`, 0.3734070611391507, 0.9371860709501183], 
             UndirectedEdge[85, 284] -> 
             RGBColor[
              0.24265277809452013`, 0.37237383322503703`, 0.9371300887886426],
              UndirectedEdge[203, 369] -> 
             RGBColor[
              0.2744257623445868, 0.405769254195412, 0.9389395132377659], 
             UndirectedEdge[1, 222] -> 
             RGBColor[
              0.48245496695292606`, 0.5881834392083616, 0.9530999932353155], 
             UndirectedEdge[25, 205] -> 
             RGBColor[
              0.9219898136234065, 0.68386598697934, 0.46117782525974793`], 
             UndirectedEdge[301, 380] -> 
             RGBColor[
              0.26115428543555863`, 0.39182009050378686`, 0.9381837222611874],
              UndirectedEdge[169, 329] -> 
             RGBColor[
              0.22791864695390707`, 0.3568873271983817, 0.9362910018173783], 
             UndirectedEdge[302, 340] -> 
             RGBColor[
              0.9905275811721996, 0.978922480132596, 0.484619975557615], 
             UndirectedEdge[205, 391] -> 
             RGBColor[
              0.9078296512801215, 0.575024774186147, 0.4476180378082022], 
             UndirectedEdge[96, 203] -> 
             RGBColor[
              0.28915453203189034`, 0.42125012499470316`, 0.9397782948821958],
              UndirectedEdge[4, 195] -> 
             RGBColor[
              0.2389456018045329, 0.3684773558957079, 0.9369189705832036], 
             UndirectedEdge[269, 298] -> 
             RGBColor[
              0.908244530929823, 0.9248034643520736, 0.7344530675019115], 
             UndirectedEdge[168, 220] -> 
             RGBColor[
              0.5727925024434088, 0.663632053166977, 0.9598025445321408], 
             UndirectedEdge[291, 338] -> 
             RGBColor[
              0.8453899770207604, 0.8765077587109009, 0.7950431863063177], 
             UndirectedEdge[10, 360] -> 
             RGBColor[
              0.336158799712734, 0.4655855893037951, 0.9426407193575084], 
             UndirectedEdge[87, 348] -> 
             RGBColor[
              0.27654696971548504`, 0.4079987776345412, 0.9390603128594934], 
             UndirectedEdge[259, 274] -> 
             RGBColor[
              0.22087433163626, 0.34948330516414705`, 0.9358898384811689], 
             UndirectedEdge[293, 336] -> 
             RGBColor[
              0.21111881242536762`, 0.33922963593785627`, 0.935334276094106], 
             UndirectedEdge[229, 245] -> 
             RGBColor[
              0.238397504828522, 0.36790127122256505`, 0.9368877572712566], 
             UndirectedEdge[173, 197] -> 
             RGBColor[
              0.607559522477704, 0.6724367666110929, 0.8861420267905455], 
             UndirectedEdge[19, 344] -> 
             RGBColor[
              0.2975063791842545, 0.4289298137668702, 0.9402941465258654], 
             UndirectedEdge[83, 125] -> 
             RGBColor[
              0.315433813888692, 0.4447906722692076, 0.9414242734794431], 
             UndirectedEdge[240, 315] -> 
             RGBColor[
              0.24124036831115342`, 0.3708893009907661, 0.9370496541409528], 
             UndirectedEdge[7, 154] -> 
             RGBColor[
              0.40978151173656857`, 0.5293538820737408, 0.9473318934656592], 
             UndirectedEdge[200, 225] -> 
             RGBColor[
              0.26388387983793327`, 0.3946890672869635, 0.9383391686243296], 
             UndirectedEdge[13, 140] -> 
             RGBColor[
              0.8178525622986523, 0.8580700202466935, 0.9570649175635426], 
             UndirectedEdge[104, 366] -> 
             RGBColor[
              0.9175772665295729, 0.7100796035907695, 0.25249503263058215`], 
             UndirectedEdge[116, 172] -> 
             RGBColor[
              0.3588230012593764, 0.484539273770746, 0.9441096471485195], 
             UndirectedEdge[143, 267] -> 
             RGBColor[
              0.5979215961089128, 0.6844587136389835, 0.9614897247861196], 
             UndirectedEdge[51, 395] -> 
             RGBColor[
              0.3229957435790246, 0.45088574591651165`, 0.9419227613726417], 
             UndirectedEdge[213, 224] -> 
             RGBColor[
              0.9433148110399261, 0.8071439818533458, 0.30358552172184644`], 
             UndirectedEdge[130, 362] -> 
             RGBColor[
              0.40753230852825906`, 0.5274057353029433, 0.9471885762261179], 
             UndirectedEdge[153, 278] -> 
             RGBColor[
              0.284923192180341, 0.41599975306012926`, 0.939566726836569], 
             UndirectedEdge[83, 303] -> 
             RGBColor[
              0.32124670467921895`, 0.4509003890486145, 0.9417553090105623], 
             UndirectedEdge[94, 296] -> 
             RGBColor[
              0.2808227544696311, 0.4124928985115602, 0.9393038124757853], 
             UndirectedEdge[147, 328] -> 
             RGBColor[
              0.29708750914626414`, 0.42952428212904603`, 0.9402324060605761],
              UndirectedEdge[78, 102] -> 
             RGBColor[
              0.8305704924938522, 0.23598377814878552`, 0.17690764417753302`],
              UndirectedEdge[22, 45] -> 
             RGBColor[
              0.2939087453063859, 0.4262471045807297, 0.94004904029495], 
             UndirectedEdge[199, 238] -> 
             RGBColor[
              0.22751293603602638`, 0.35646089930013114`, 0.9362678971808005],
              UndirectedEdge[21, 182] -> 
             RGBColor[
              0.30050572685967525`, 0.4327952999017487, 0.9404388491913643], 
             UndirectedEdge[126, 212] -> 
             RGBColor[
              0.21146946129668887`, 0.3395981901340374, 0.9353542450285892], 
             UndirectedEdge[273, 365] -> 
             RGBColor[
              0.26583905724777945`, 0.3967440827101195, 0.9384505130853945], 
             UndirectedEdge[149, 367] -> 
             RGBColor[
              0.21976666504097775`, 0.348319077342387, 0.9358267585072135], 
             UndirectedEdge[81, 89] -> 
             RGBColor[
              0.21914913629591037`, 0.3476700154777373, 0.9357915911587338], 
             UndirectedEdge[57, 337] -> 
             RGBColor[
              0.27897537779675124`, 0.41055118849791716`, 0.9391986071072138],
              UndirectedEdge[255, 288] -> 
             RGBColor[
              0.25275048461760563`, 0.38298716301237146`, 0.9377051382369141],
              UndirectedEdge[2, 283] -> 
             RGBColor[
              0.8636832468154017, 0.4097080433065882, 0.20543575312607748`], 
             UndirectedEdge[94, 128] -> 
             RGBColor[
              0.29316856057651314`, 0.42385416586161573`, 0.9400660193797667],
              UndirectedEdge[176, 393] -> 
             RGBColor[
              0.2193217433014607, 0.3478514363844869, 0.9358014208723507], 
             UndirectedEdge[65, 326] -> 
             RGBColor[
              0.4273612108963405, 0.5428967033575929, 0.9489173037481067], 
             UndirectedEdge[97, 282] -> 
             RGBColor[
              0.5445731104291971, 0.6407794460815519, 0.9574198730781076], 
             UndirectedEdge[12, 149] -> 
             RGBColor[
              0.21932780961758047`, 0.3478578124673555, 0.9358017663400795], 
             UndirectedEdge[78, 144] -> 
             RGBColor[
              0.8601410277678558, 0.4317670823407418, 0.2039906170405674], 
             UndirectedEdge[201, 348] -> 
             RGBColor[
              0.2696907546749492, 0.40079246091779686`, 0.9386698615557961], 
             UndirectedEdge[242, 381] -> 
             RGBColor[
              0.9557469344850966, 0.8527067973943953, 0.5081965742437817], 
             UndirectedEdge[43, 367] -> 
             RGBColor[
              0.22337497152266345`, 0.35211163623448327`, 0.9360322462233344],
              UndirectedEdge[111, 197] -> 
             RGBColor[
              0.931414792844472, 0.7553582824181725, 0.5263607215030722], 
             UndirectedEdge[69, 216] -> 
             RGBColor[
              0.5736600979558795, 0.6645056615859741, 0.959755124057878], 
             UndirectedEdge[197, 295] -> 
             RGBColor[
              0.6155693919444334, 0.6808556472756819, 0.8865981770071358], 
             UndirectedEdge[193, 275] -> 
             RGBColor[
              0.9072201261691099, 0.9260883634638468, 0.8817465180078601], 
             UndirectedEdge[149, 238] -> 
             RGBColor[
              0.2247208711862695, 0.3535262621159006, 0.9361088932180968], 
             UndirectedEdge[79, 349] -> 
             RGBColor[
              0.518092548976322, 0.6194343382750406, 0.9552648492680336], 
             UndirectedEdge[16, 110] -> 
             RGBColor[
              0.2487192272457111, 0.3787500559180304, 0.9374755640932957], 
             UndirectedEdge[49, 372] -> 
             RGBColor[
              0.25360695200292194`, 0.3838873645375076, 0.9377539127874779], 
             UndirectedEdge[320, 343] -> 
             RGBColor[
              0.7160472963068527, 0.7781008571267078, 0.9723325607195863], 
             UndirectedEdge[221, 358] -> 
             RGBColor[
              0.9452177942477327, 0.9230965860350502, 0.6624178282504138], 
             UndirectedEdge[240, 245] -> 
             RGBColor[
              0.2345526793265548, 0.3638601158439808, 0.9366688001468292], 
             UndirectedEdge[85, 115] -> 
             RGBColor[
              0.2399567828787064, 0.36954017131724737`, 0.9369765558494695], 
             UndirectedEdge[70, 280] -> 
             RGBColor[
              0.2584116720913199, 0.38893742998726233`, 0.9380275344885658], 
             UndirectedEdge[151, 171] -> 
             RGBColor[
              0.294524052203641, 0.4262383567855898, 0.940108081239609], 
             UndirectedEdge[23, 163] -> 
             RGBColor[
              0.22919558870789478`, 0.35822947394460614`, 0.9363637217612019],
              UndirectedEdge[255, 360] -> 
             RGBColor[
              0.28543335040527573`, 0.4171867688467138, 0.9395719503550848], 
             UndirectedEdge[165, 307] -> 
             RGBColor[
              0.7589943744265952, 0.8098564226113569, 0.9253172138967432], 
             UndirectedEdge[81, 169] -> 
             RGBColor[
              0.22020695780518662`, 0.3487818529537441, 0.9358518325287805], 
             UndirectedEdge[44, 316] -> 
             RGBColor[
              0.27611802500026855`, 0.4075479295421829, 0.9390358850925288], 
             UndirectedEdge[195, 337] -> 
             RGBColor[
              0.26521901916211443`, 0.39609238336940045`, 0.9384152028336801],
              UndirectedEdge[316, 390] -> 
             RGBColor[
              0.26028939055795897`, 0.3909110311499271, 0.9381344677774055], 
             UndirectedEdge[39, 177] -> 
             RGBColor[
              0.29750028265951367`, 0.4288050749279245, 0.9402981320155486], 
             UndirectedEdge[45, 190] -> 
             RGBColor[
              0.2683010399450559, 0.3993317826236759, 0.9385907193578275], 
             UndirectedEdge[287, 396] -> 
             RGBColor[
              0.2692564543945499, 0.400335983786869, 0.9386451287973171], 
             UndirectedEdge[136, 343] -> 
             RGBColor[
              0.6703913429941837, 0.7420698478255596, 0.9680310290897323], 
             UndirectedEdge[296, 360] -> 
             RGBColor[
              0.3059566318031602, 0.4387580388470877, 0.9407407208692202], 
             UndirectedEdge[167, 228] -> 
             RGBColor[
              0.32570332239411426`, 0.45419998876459156`, 0.9420598033482018],
              UndirectedEdge[123, 279] -> 
             RGBColor[
              0.9599728871641575, 0.901288321876893, 0.6017603738326488], 
             UndirectedEdge[33, 333] -> 
             RGBColor[
              0.1872509211104506, 0.3141429688541644, 0.9339750349931024], 
             UndirectedEdge[164, 209] -> 
             RGBColor[
              0.24728574846658016`, 0.37724337883335973`, 0.9373939295974659],
              UndirectedEdge[22, 29] -> 
             RGBColor[
              0.2663738031073146, 0.39730613451333674`, 0.9384809660710094], 
             UndirectedEdge[24, 366] -> 
             RGBColor[
              0.9017167350633479, 0.6466004732099342, 0.2397023734046333], 
             UndirectedEdge[178, 319] -> 
             RGBColor[
              0.24278605838252734`, 0.37251391925819094`, 0.9371376789038741],
              UndirectedEdge[294, 368] -> 
             RGBColor[
              0.21277052855345546`, 0.3409656943133277, 0.9354283388841056], 
             UndirectedEdge[13, 69] -> 
             RGBColor[
              0.7259993754166094, 0.7839523785382002, 0.9495242388978706], 
             UndirectedEdge[214, 295] -> 
             RGBColor[
              0.6130802218515281, 0.6797567159185416, 0.9247335360686406], 
             UndirectedEdge[80, 146] -> 
             RGBColor[
              0.4348738177323767, 0.548860724677587, 0.9495460387678236], 
             UndirectedEdge[56, 231] -> 
             RGBColor[
              0.37980957762799716`, 0.5033879783145618, 0.9454223177963867], 
             UndirectedEdge[134, 351] -> 
             RGBColor[
              0.24003567899790235`, 0.3696230961408251, 0.9369810488667414], 
             UndirectedEdge[143, 291] -> 
             RGBColor[
              0.6605679134983766, 0.7344885741946573, 0.9669884297148228], 
             UndirectedEdge[120, 320] -> 
             RGBColor[
              0.6381361673517921, 0.7160721638444079, 0.9653628908870006], 
             UndirectedEdge[132, 220] -> 
             RGBColor[
              0.6373284381573086, 0.7140480166379533, 0.9662348834814941], 
             UndirectedEdge[6, 247] -> 
             RGBColor[
              0.9501775412917424, 0.8286011525137683, 0.3806667888005933], 
             UndirectedEdge[166, 289] -> 
             RGBColor[
              0.8612612060617832, 0.40999762047401866`, 0.2038737104047185], 
             UndirectedEdge[114, 392] -> 
             RGBColor[
              0.2884135464934976, 0.418609972282043, 0.9398042492586839], 
             UndirectedEdge[305, 325] -> 
             RGBColor[
              0.20723516257555488`, 0.3351476737080805, 0.9351131079805042], 
             UndirectedEdge[44, 128] -> 
             RGBColor[
              0.3120848480897295, 0.44373638339990634`, 0.9411432739695049], 
             UndirectedEdge[90, 242] -> 
             RGBColor[
              0.8120763207412868, 0.7420397918675932, 0.6122349694370377], 
             UndirectedEdge[1, 337] -> 
             RGBColor[
              0.3223631828098259, 0.4514173086943011, 0.9418429310198984], 
             UndirectedEdge[74, 224] -> 
             RGBColor[
              0.9001674923644503, 0.8962994775971298, 0.6715446357629462], 
             UndirectedEdge[160, 370] -> 
             RGBColor[
              0.8303471028154521, 0.5479183884634005, 0.5798122246722852], 
             UndirectedEdge[30, 84] -> 
             RGBColor[
              0.1789270231889713, 0.3053940243730791, 0.9335010013205776], 
             UndirectedEdge[293, 299] -> 
             RGBColor[
              0.21267988324051307`, 0.34087042034218046`, 0.9354231767676313],
              UndirectedEdge[186, 399] -> 
             RGBColor[
              0.24167334431028037`, 0.3713443862181124, 0.9370743114835726], 
             UndirectedEdge[163, 371] -> 
             RGBColor[
              0.25850942763125473`, 0.3890401772577931, 0.9380331015219487], 
             UndirectedEdge[90, 138] -> 
             RGBColor[
              0.7625743389841517, 0.45989176227570816`, 0.5687339252858672], 
             UndirectedEdge[71, 286] -> 
             RGBColor[
              0.798684946393064, 0.8430713308000524, 0.9804594287308144], 
             UndirectedEdge[60, 201] -> 
             RGBColor[
              0.3169773146449097, 0.44598337270948407`, 0.9415279039366844], 
             UndirectedEdge[128, 380] -> 
             RGBColor[
              0.2958519089446212, 0.4266745351306104, 0.9402188320996724], 
             UndirectedEdge[54, 128] -> 
             RGBColor[
              0.3891023193866603, 0.5114426050266787, 0.9460142336150148], 
             UndirectedEdge[25, 138] -> 
             RGBColor[
              0.8340269956702107, 0.26255197621162585`, 0.18021759552277578`],
              UndirectedEdge[95, 129] -> 
             RGBColor[
              0.2597315005548766, 0.39032465338441835`, 0.9381026967670542], 
             UndirectedEdge[132, 302] -> 
             RGBColor[
              0.8932496977556434, 0.905911220002762, 0.6928483915783341], 
             UndirectedEdge[15, 100] -> 
             RGBColor[
              0.34023750094859895`, 0.4686666959527124, 0.9429171480552854], 
             UndirectedEdge[33, 63] -> 
             RGBColor[
              0.5687512197366357, 0.5886439817299056, 0.6135098819197802], 
             UndirectedEdge[275, 338] -> 
             RGBColor[
              0.9931945073855819, 0.9905965803379274, 0.7001396493067182], 
             UndirectedEdge[252, 277] -> 
             RGBColor[
              0.2410729775793306, 0.3707133627184349, 0.9370401214864079], 
             UndirectedEdge[146, 192] -> 
             RGBColor[
              0.43991049068666355`, 0.5532232376400468, 0.9498669711147159], 
             UndirectedEdge[237, 254] -> 
             RGBColor[
              0.5239652108029346, 0.6244175883504002, 0.9556676072236672], 
             UndirectedEdge[37, 236] -> 
             RGBColor[
              0.2501608630823501, 0.3802653065873294, 0.9375576631214831], 
             UndirectedEdge[265, 362] -> 
             RGBColor[
              0.4982768620774518, 0.6022414244020411, 0.9540103792474512], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.31424207897729384`, 0.44465323780495364`, 0.9413155746707285],
              UndirectedEdge[341, 379] -> 
             RGBColor[
              0.2212705365436844, 0.3498997416426921, 0.9359124017645142], 
             UndirectedEdge[324, 380] -> 
             RGBColor[
              0.27272415965434393`, 0.4039807618801248, 0.9388426094818522], 
             UndirectedEdge[63, 264] -> 
             RGBColor[
              0.5742960336344989, 0.5944719326980662, 0.6138256508684465], 
             UndirectedEdge[153, 337] -> 
             RGBColor[
              0.30108704647180895`, 0.43298898876801645`, 0.9404872344261885],
              UndirectedEdge[112, 155] -> 
             RGBColor[
              0.31673339546261187`, 0.44837192664657105`, 0.9414171693125639],
              UndirectedEdge[10, 177] -> 
             RGBColor[
              0.34191718866131093`, 0.47057321638600846`, 0.9430076388093683],
              UndirectedEdge[238, 367] -> 
             RGBColor[
              0.2242689013320493, 0.35305121314257126`, 0.9360831542035284], 
             UndirectedEdge[87, 228] -> 
             RGBColor[
              0.32899794708810315`, 0.4576628482092444, 0.9422474273505641], 
             UndirectedEdge[66, 352] -> 
             RGBColor[
              0.983468511290683, 0.9548785202107917, 0.47692950075693274`], 
             UndirectedEdge[86, 386] -> 
             RGBColor[
              0.31994974783175406`, 0.4507870854822257, 0.9416356849958585], 
             UndirectedEdge[52, 133] -> 
             RGBColor[
              0.34195185422260005`, 0.4695411184843201, 0.9430487372114036], 
             UndirectedEdge[105, 112] -> 
             RGBColor[
              0.37313264037284266`, 0.49761047172431544`, 0.944996659789687], 
             UndirectedEdge[4, 258] -> 
             RGBColor[
              0.24256487951038092`, 0.3722814462400146, 0.9371250830943101], 
             UndirectedEdge[141, 339] -> 
             RGBColor[
              0.36291222472736206`, 0.48875806138522676`, 0.9443454239423157],
              UndirectedEdge[251, 282] -> 
             RGBColor[
              0.7345888082776114, 0.7926044746200289, 0.9741756038265081], 
             UndirectedEdge[94, 390] -> 
             RGBColor[
              0.26321162125265696`, 0.393982480890182, 0.9383008844924156], 
             UndirectedEdge[239, 337] -> 
             RGBColor[
              0.304629125717821, 0.43605695978083275`, 0.9407129325836068], 
             UndirectedEdge[80, 243] -> 
             RGBColor[
              0.3113941751763021, 0.44225199630561496`, 0.9411317115948465], 
             UndirectedEdge[366, 382] -> 
             RGBColor[
              0.9000306839899277, 0.6389445090727658, 0.23829549106007777`], 
             UndirectedEdge[99, 306] -> 
             RGBColor[
              0.9742518584397497, 0.947471002545973, 0.6306628392778444], 
             UndirectedEdge[214, 261] -> 
             RGBColor[
              0.5816107316395323, 0.6466802864248125, 0.9229413951560062], 
             UndirectedEdge[21, 60] -> 
             RGBColor[
              0.33522274220732345`, 0.4647748233402267, 0.9425810746009868], 
             UndirectedEdge[60, 159] -> 
             RGBColor[
              0.344481468526375, 0.4727942667206735, 0.9431710324548666], 
             UndirectedEdge[9, 300] -> 
             RGBColor[
              0.8578321079350941, 0.3958398187210729, 0.2010677137447785], 
             UndirectedEdge[114, 369] -> 
             RGBColor[
              0.29316591487643506`, 0.4236050127700691, 0.9400748896075932], 
             UndirectedEdge[112, 350] -> 
             RGBColor[
              0.380831960891249, 0.5042792361782578, 0.945487253684878], 
             UndirectedEdge[18, 357] -> 
             RGBColor[
              0.8104483343258964, 0.8526146189392179, 0.9729726519131952], 
             UndirectedEdge[71, 320] -> 
             RGBColor[
              0.7905070166194959, 0.8366826699063725, 0.9796443291180839], 
             UndirectedEdge[226, 255] -> 
             RGBColor[
              0.24955450248561023`, 0.3796279831546734, 0.9375231317825289], 
             UndirectedEdge[208, 258] -> 
             RGBColor[
              0.24300998977440907`, 0.3727492853491289, 0.9371504314653649], 
             UndirectedEdge[11, 358] -> 
             RGBColor[
              0.9460196672175634, 0.8199629343977746, 0.2948506005623025], 
             UndirectedEdge[274, 299] -> 
             RGBColor[
              0.22242833776812287`, 0.35111666413841447`, 0.9359783368314325],
              UndirectedEdge[147, 372] -> 
             RGBColor[
              0.2681076692483716, 0.3991285377610505, 0.9385797071827175], 
             UndirectedEdge[335, 337] -> 
             RGBColor[
              0.282630755782611, 0.41439322252540617`, 0.9394067754758614], 
             UndirectedEdge[36, 218] -> 
             RGBColor[
              0.7148705349959443, 0.7760303162882036, 0.9733069680605333], 
             UndirectedEdge[262, 300] -> 
             RGBColor[
              0.9143198191766551, 0.7735717057130247, 0.6093343830407926], 
             UndirectedEdge[109, 136] -> 
             RGBColor[
              0.8063392816861509, 0.8465292984919313, 0.8553084156056971], 
             UndirectedEdge[219, 241] -> 
             RGBColor[
              0.36907489621161843`, 0.49245160059313714`, 0.9447983082263991],
              UndirectedEdge[37, 348] -> 
             RGBColor[
              0.2563773742968305, 0.38679925402332427`, 0.9379116842386436], 
             UndirectedEdge[291, 384] -> 
             RGBColor[
              0.7224597094549363, 0.7831102830141358, 0.9729716901347794], 
             UndirectedEdge[10, 241] -> 
             RGBColor[
              0.32644391245681637`, 0.4555267851602728, 0.9420818996386419], 
             UndirectedEdge[131, 314] -> 
             RGBColor[
              0.9241390802378358, 0.8369963141242439, 0.6246293196235244], 
             UndirectedEdge[1, 41] -> 
             RGBColor[
              0.3504016747423545, 0.4779220517867386, 0.943548262759916], 
             UndirectedEdge[78, 400] -> 
             RGBColor[
              0.6157274285874001, 0.4172598139869824, 0.5668748799123404], 
             UndirectedEdge[191, 357] -> 
             RGBColor[
              0.6772717325975683, 0.7478090920518159, 0.9684677749072899], 
             UndirectedEdge[215, 352] -> 
             RGBColor[
              0.906721166296464, 0.5695838616411621, 0.3855978109611532], 
             UndirectedEdge[96, 369] -> 
             RGBColor[
              0.27218271865818583`, 0.40341167306382075`, 0.9388117752181111],
              UndirectedEdge[212, 293] -> 
             RGBColor[
              0.2110641194014849, 0.3391721501020175, 0.935331161407307], 
             UndirectedEdge[66, 107] -> 
             RGBColor[
              0.906000283356856, 0.6111511383099929, 0.2669776426492963], 
             UndirectedEdge[146, 159] -> 
             RGBColor[
              0.433382915877228, 0.5475693804255631, 0.9494510398199664], 
             UndirectedEdge[11, 207] -> 
             RGBColor[
              0.931659240059644, 0.7667586905843885, 0.26386962426942273`], 
             UndirectedEdge[99, 218] -> 
             RGBColor[
              0.9440956875300477, 0.9571661739174645, 0.9565961673645738], 
             UndirectedEdge[131, 217] -> 
             RGBColor[
              0.8726459244985081, 0.4533824718485052, 0.21298193244244573`], 
             UndirectedEdge[81, 163] -> 
             RGBColor[
              0.23234434831161116`, 0.36153901993100174`, 0.9365430389624612],
              UndirectedEdge[50, 54] -> 
             RGBColor[
              0.4530695590105145, 0.5668252864420751, 0.9500963936878091], 
             UndirectedEdge[120, 286] -> 
             RGBColor[
              0.6463140971253603, 0.7224608247380875, 0.966177990499731], 
             UndirectedEdge[17, 253] -> 
             RGBColor[
              0.43861619159981363`, 0.5520971476660097, 0.9497858901980598], 
             UndirectedEdge[45, 365] -> 
             RGBColor[
              0.2758699057154388, 0.4072871404421556, 0.9390217550663172], 
             UndirectedEdge[35, 188] -> 
             RGBColor[
              0.27406348456255775`, 0.4053884772767613, 0.9389188820540213], 
             UndirectedEdge[99, 279] -> 
             RGBColor[
              0.9618886205302903, 0.9027170726846294, 0.5985175369470697], 
             UndirectedEdge[107, 363] -> 
             RGBColor[
              0.8508650866892753, 0.3855165088466559, 0.1960887969103411], 
             UndirectedEdge[105, 271] -> 
             RGBColor[
              0.36206599633926584`, 0.4878440595940245, 0.9442981318263466], 
             UndirectedEdge[191, 219] -> 
             RGBColor[
              0.5630206032370957, 0.6553990201614963, 0.9591704044347413], 
             UndirectedEdge[177, 339] -> 
             RGBColor[
              0.34383450141698674`, 0.4722338963280338, 0.9431298082827468], 
             UndirectedEdge[80, 167] -> 
             RGBColor[
              0.30898293281547473`, 0.43971762770278966`, 0.9409943949095109],
              UndirectedEdge[48, 56] -> 
             RGBColor[
              0.43818896314994105`, 0.5539589886879809, 0.9491419911499963], 
             UndirectedEdge[42, 136] -> 
             RGBColor[
              0.7754039881303256, 0.825013733522431, 0.9782569627328132], 
             UndirectedEdge[77, 102] -> 
             RGBColor[
              0.8243310697046711, 0.5080541422905515, 0.574849473505362], 
             UndirectedEdge[73, 203] -> 
             RGBColor[
              0.2672567761777972, 0.39823419519414005`, 0.9385312500811318], 
             UndirectedEdge[35, 284] -> 
             RGBColor[
              0.26251957032631373`, 0.3932550914880322, 0.9382614732159579], 
             UndirectedEdge[274, 367] -> 
             RGBColor[
              0.22502133411732347`, 0.3538420677068884, 0.9361260041375251], 
             UndirectedEdge[33, 310] -> 
             RGBColor[
              0.18075976862012855`, 0.3073203560239972, 0.9336053734615781], 
             UndirectedEdge[175, 295] -> 
             RGBColor[
              0.21065974573871524`, 0.33874712774367555`, 0.9353081329254295],
              UndirectedEdge[70, 75] -> 
             RGBColor[
              0.2609941288153654, 0.3916517557414475, 0.9381746015785979], 
             UndirectedEdge[57, 258] -> 
             RGBColor[
              0.26307034244570515`, 0.39383398790648194`, 0.9382928388733629],
              UndirectedEdge[70, 145] -> 
             RGBColor[
              0.2579170969731607, 0.3884176001802034, 0.937999369167245], 
             UndirectedEdge[12, 336] -> 
             RGBColor[
              0.21472177259901426`, 0.343016575521228, 0.9355394593458932], 
             UndirectedEdge[18, 216] -> 
             RGBColor[
              0.8021540700559975, 0.8461350766528297, 0.9721459571650781], 
             UndirectedEdge[158, 311] -> 
             RGBColor[
              0.5112449698673547, 0.6140907237185725, 0.9546662232614405], 
             UndirectedEdge[8, 36] -> 
             RGBColor[
              0.41499862525248465`, 0.5320708731128857, 0.9481621689265505], 
             UndirectedEdge[119, 200] -> 
             RGBColor[
              0.2555790109882331, 0.38596012356683096`, 0.9378662186292916], 
             UndirectedEdge[181, 362] -> 
             RGBColor[
              0.4859856594800335, 0.59226287242109, 0.9530427707548238], 
             UndirectedEdge[9, 306] -> 
             RGBColor[
              0.8980217768542582, 0.5550152880766823, 0.25581485333926096`], 
             UndirectedEdge[82, 253] -> 
             RGBColor[
              0.3604664667584644, 0.48663966875993736`, 0.9441895824072364], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.47490752561281135`, 0.5839962194337451, 0.9519697664459024], 
             UndirectedEdge[146, 314] -> 
             RGBColor[
              0.7305716091219763, 0.7886632000372383, 0.9746741748807553], 
             UndirectedEdge[27, 277] -> 
             RGBColor[
              0.277614773953709, 0.4091211075916136, 0.9391211227311855], 
             UndirectedEdge[6, 302] -> 
             RGBColor[
              0.9903122885265428, 0.9784619909329613, 0.461186699710061], 
             UndirectedEdge[93, 296] -> 
             RGBColor[
              0.27337982614775685`, 0.40466990893635857`, 0.9388799487186803],
              UndirectedEdge[153, 284] -> 
             RGBColor[
              0.2807144253547577, 0.4115760722752118, 0.9393270437921646], 
             UndirectedEdge[43, 199] -> 
             RGBColor[
              0.2266190062266405, 0.3555213223920431, 0.9362169892006067], 
             UndirectedEdge[213, 250] -> 
             RGBColor[
              0.9495976653580405, 0.8370624678097084, 0.5459950352795185], 
             UndirectedEdge[3, 232] -> 
             RGBColor[
              0.4478181508511241, 0.5603378585517222, 0.9502975085529524], 
             UndirectedEdge[5, 235] -> 
             RGBColor[
              0.7907683520113988, 0.8366469590661592, 0.9797340301887447], 
             UndirectedEdge[25, 391] -> 
             RGBColor[
              0.8345509525864179, 0.2665793386689794, 0.18071933725746053`], 
             UndirectedEdge[288, 341] -> 
             RGBColor[
              0.2333048519876323, 0.3625485701939505, 0.9365977382258728], 
             UndirectedEdge[181, 265] -> 
             RGBColor[
              0.5796034948121, 0.6695872537851715, 0.9600476567506184], 
             UndirectedEdge[295, 363] -> 
             RGBColor[
              0.5524499218387339, 0.42033901047071287`, 0.5720521832312901], 
             UndirectedEdge[278, 284] -> 
             RGBColor[
              0.24820685681048946`, 0.3782115221044505, 0.9374463853549939], 
             UndirectedEdge[167, 351] -> 
             RGBColor[
              0.2646469792533301, 0.39549113315584294`, 0.938382626007132], 
             UndirectedEdge[198, 311] -> 
             RGBColor[
              0.6729318339898602, 0.7425873401033549, 0.9693093430316602], 
             UndirectedEdge[54, 328] -> 
             RGBColor[
              0.38071433549214345`, 0.504177354969577, 0.9454797586984591], 
             UndirectedEdge[261, 310] -> 
             RGBColor[
              0.18101326007132248`, 0.3075867916114884, 0.9336198094247166], 
             UndirectedEdge[68, 319] -> 
             RGBColor[
              0.2591541477712746, 0.38971781900257185`, 0.9380698173801449], 
             UndirectedEdge[100, 141] -> 
             RGBColor[
              0.3683390164516885, 0.49345847561835543`, 0.9446912143122663], 
             UndirectedEdge[139, 325] -> 
             RGBColor[
              0.21136919529828035`, 0.33949280421247857`, 0.9353485350283102],
              UndirectedEdge[123, 338] -> 
             RGBColor[
              0.9842922541931751, 0.9852712070496027, 0.7740485310892328], 
             UndirectedEdge[317, 370] -> 
             RGBColor[
              0.9109218435003366, 0.9293228266692952, 0.8943803638429948], 
             UndirectedEdge[160, 400] -> 
             RGBColor[
              0.6095442446912597, 0.3697331530727862, 0.5609538560304888], 
             UndirectedEdge[150, 266] -> 
             RGBColor[
              0.2627993543398047, 0.39354916222554226`, 0.9382774065016228], 
             UndirectedEdge[134, 201] -> 
             RGBColor[
              0.255376576823433, 0.3857473524245587, 0.9378546903030808], 
             UndirectedEdge[161, 251] -> 
             RGBColor[
              0.6268762447587527, 0.7046334098478555, 0.9658130763902817], 
             UndirectedEdge[86, 371] -> 
             RGBColor[
              0.2862909803459218, 0.418240350613087, 0.9396152198499249], 
             UndirectedEdge[105, 350] -> 
             RGBColor[
              0.4250434301807523, 0.5425729887437677, 0.948304369413338], 
             UndirectedEdge[54, 362] -> 
             RGBColor[
              0.4283252562737149, 0.5454155415561164, 0.9485134844699766], 
             UndirectedEdge[4, 208] -> 
             RGBColor[
              0.23264160776787357`, 0.36185145846687167`, 0.9365599674487393],
              UndirectedEdge[176, 294] -> 
             RGBColor[
              0.21429151975408078`, 0.34256435250159695`, 0.9355149570828762],
              UndirectedEdge[113, 170] -> 
             RGBColor[
              0.6207426403130438, 0.7003977045332692, 0.9649634716556403], 
             UndirectedEdge[14, 205] -> 
             RGBColor[
              0.9948127950472943, 0.9913250536932577, 0.6776287249236647], 
             UndirectedEdge[262, 306] -> 
             RGBColor[
              0.9545094880958191, 0.9327471750686342, 0.664081522635275], 
             UndirectedEdge[47, 128] -> 
             RGBColor[
              0.3800525355791988, 0.5036041371480152, 0.945437589393213], 
             UndirectedEdge[257, 382] -> 
             RGBColor[
              0.8606940459931985, 0.4040219113453448, 0.20326730826890227`], 
             UndirectedEdge[165, 228] -> 
             RGBColor[
              0.4503029757321284, 0.5622948057743279, 0.9505097967266875], 
             UndirectedEdge[72, 341] -> 
             RGBColor[
              0.22465511090045148`, 0.353457143886063, 0.936105148267103], 
             UndirectedEdge[50, 116] -> 
             RGBColor[
              0.4351844866677396, 0.551334135708637, 0.9489567726932759], 
             UndirectedEdge[230, 247] -> 
             RGBColor[
              0.9379323861994966, 0.7878165939520326, 0.28877547346743154`], 
             UndirectedEdge[45, 100] -> 
             RGBColor[
              0.33605658973236274`, 0.46427229317936647`, 0.9426790513466246],
              UndirectedEdge[95, 386] -> 
             RGBColor[
              0.3105708355384495, 0.4409292540045774, 0.9411015698156122], 
             UndirectedEdge[182, 244] -> 
             RGBColor[
              0.27406524356197104`, 0.4053903260966717, 0.9389189822264357], 
             UndirectedEdge[104, 382] -> 
             RGBColor[
              0.9163275048198573, 0.7044047275562138, 0.25145220082553266`], 
             UndirectedEdge[58, 210] -> 
             RGBColor[
              0.2993673513669953, 0.4319844456460439, 0.9403598998348177], 
             UndirectedEdge[102, 370] -> 
             RGBColor[
              0.8252568296209774, 0.5087923181187306, 0.5749377733126149], 
             UndirectedEdge[1, 161] -> 
             RGBColor[
              0.3957098398241182, 0.5171657071259712, 0.9464352589744887], 
             UndirectedEdge[153, 356] -> 
             RGBColor[
              0.4179045828513193, 0.5346231354649491, 0.9483375893388631], 
             UndirectedEdge[1, 154] -> 
             RGBColor[
              0.39507053133992803`, 0.5166119702495444, 0.9463945228031945], 
             UndirectedEdge[341, 399] -> 
             RGBColor[
              0.22823136465623345`, 0.3572160133309742, 0.9363088106279014], 
             UndirectedEdge[373, 395] -> 
             RGBColor[
              0.2616949498810116, 0.3923883631160637, 0.9382145123015146], 
             UndirectedEdge[190, 266] -> 
             RGBColor[
              0.24805045871485498`, 0.3780471377897267, 0.9374374787148178], 
             UndirectedEdge[73, 85] -> 
             RGBColor[
              0.24221172142071856`, 0.3719102546962633, 0.9371049712635544], 
             UndirectedEdge[221, 250] -> 
             RGBColor[
              0.955043066437527, 0.9649644792718597, 0.9185889663100797], 
             UndirectedEdge[23, 353] -> 
             RGBColor[
              0.21189878814995255`, 0.34004943987771225`, 0.9353786945577505],
              UndirectedEdge[171, 270] -> 
             RGBColor[
              0.2613998670743656, 0.3920782123769482, 0.9381977077722119], 
             UndirectedEdge[277, 396] -> 
             RGBColor[
              0.26805617252313807`, 0.399074411437749, 0.9385767745203981], 
             UndirectedEdge[315, 371] -> 
             RGBColor[
              0.25765991596594773`, 0.388147286635405, 0.9379847230893494], 
             UndirectedEdge[207, 391] -> 
             RGBColor[
              0.8801233042529734, 0.4784967588439868, 0.2188121666480132], 
             UndirectedEdge[160, 247] -> 
             RGBColor[
              0.8682425607038025, 0.44830305029724704`, 0.2099476795487854], 
             UndirectedEdge[193, 232] -> 
             RGBColor[
              0.6739481277148399, 0.7434424430617759, 0.9693547854990241], 
             UndirectedEdge[22, 91] -> 
             RGBColor[
              0.2774698045998931, 0.40896873560916513`, 0.9391128669409485], 
             UndirectedEdge[78, 247] -> 
             RGBColor[
              0.874425744599943, 0.49582971121144337`, 0.21586870343063702`], 
             UndirectedEdge[87, 192] -> 
             RGBColor[
              0.3173142304637505, 0.44754300010990244`, 0.9415029512587653], 
             UndirectedEdge[226, 294] -> 
             RGBColor[
              0.22569678935260098`, 0.35455201398550057`, 0.9361644703139277],
              UndirectedEdge[177, 311] -> 
             RGBColor[
              0.42064126980492156`, 0.5369664823599833, 0.9485194381294991], 
             UndirectedEdge[189, 200] -> 
             RGBColor[
              0.28560319899075254`, 0.41751744880094743`, 0.9395760517192293],
              UndirectedEdge[67, 184] -> 
             RGBColor[
              0.2153543932680198, 0.3436814999548199, 0.9355754861571146], 
             UndirectedEdge[33, 256] -> 
             RGBColor[
              0.202124876078153, 0.3297764385884332, 0.9348220847244686], 
             UndirectedEdge[176, 226] -> 
             RGBColor[
              0.22722875741095702`, 0.3561622095472178, 0.9362517136285073], 
             UndirectedEdge[145, 162] -> 
             RGBColor[
              0.2420540274215789, 0.3717445083047905, 0.9370959908235907], 
             UndirectedEdge[286, 343] -> 
             RGBColor[
              0.7242252260804207, 0.7844895180203877, 0.9731476603323168], 
             UndirectedEdge[13, 18] -> 
             RGBColor[
              0.9544933475167275, 0.9655817936050558, 0.9619150720050708], 
             UndirectedEdge[86, 308] -> 
             RGBColor[
              0.28081236703944734`, 0.4124819806638359, 0.9393032209270034], 
             UndirectedEdge[364, 377] -> 
             RGBColor[
              0.3822045767059832, 0.5054681270073037, 0.9455747155508364], 
             UndirectedEdge[90, 152] -> 
             RGBColor[
              0.4447109838202162, 0.5402113672268555, 0.9525399126533038], 
             UndirectedEdge[1, 153] -> 
             RGBColor[
              0.33870689706262624`, 0.4677926231571751, 0.9428030818674495], 
             UndirectedEdge[92, 114] -> 
             RGBColor[
              0.3082708613262549, 0.43948126919774927`, 0.9409350939621447], 
             UndirectedEdge[132, 219] -> 
             RGBColor[
              0.6232051027562657, 0.7024156086050097, 0.9651690328906872], 
             UndirectedEdge[107, 215] -> 
             RGBColor[
              0.829252938362637, 0.22585647974036333`, 0.17564595285351675`], 
             UndirectedEdge[240, 319] -> 
             RGBColor[
              0.24039509168830792`, 0.37000086166652213`, 0.9370015168877566],
              UndirectedEdge[58, 110] -> 
             RGBColor[
              0.2771944683256158, 0.40867933972757164`, 0.939097186947452], 
             UndirectedEdge[67, 85] -> 
             RGBColor[
              0.22712666696496037`, 0.35605490601556716`, 0.9362458997286371],
              UndirectedEdge[125, 344] -> 
             RGBColor[
              0.2993073040655987, 0.4308227000023955, 0.9403967065336283], 
             UndirectedEdge[198, 219] -> 
             RGBColor[
              0.6368387366010516, 0.7131188895622445, 0.9665139522992866], 
             UndirectedEdge[16, 325] -> 
             RGBColor[
              0.22671411419860138`, 0.35562128690076766`, 0.9362224054589102],
              UndirectedEdge[119, 390] -> 
             RGBColor[
              0.2533988208527428, 0.3836686055023921, 0.9377420600263777], 
             UndirectedEdge[7, 153] -> 
             RGBColor[
              0.3534178774592668, 0.48053453498137155`, 0.9437404525299142], 
             UndirectedEdge[23, 164] -> 
             RGBColor[
              0.22797821780387265`, 0.3569499399387055, 0.9362943942891566], 
             UndirectedEdge[46, 373] -> 
             RGBColor[
              0.26731905714517273`, 0.3982996564396932, 0.9385347968900875], 
             UndirectedEdge[301, 316] -> 
             RGBColor[
              0.2555487063727525, 0.3859282714945373, 0.9378644928262717], 
             UndirectedEdge[22, 150] -> 
             RGBColor[
              0.28145958694833023`, 0.41316224982418415`, 0.9393400791433381],
              UndirectedEdge[161, 327] -> 
             RGBColor[
              0.3750143899762539, 0.4992403486513052, 0.9451165632104506], 
             UndirectedEdge[123, 281] -> 
             RGBColor[
              0.8031450913153519, 0.8462354724290008, 0.9462830761380823], 
             UndirectedEdge[111, 160] -> 
             RGBColor[
              0.8517778667942718, 0.37434165466445646`, 0.19625056684916897`],
              UndirectedEdge[277, 287] -> 
             RGBColor[
              0.25901311175833214`, 0.3895695812107696, 0.9380617855878519], 
             UndirectedEdge[48, 120] -> 
             RGBColor[
              0.49591060473188847`, 0.6008847208403402, 0.9536681725336434], 
             UndirectedEdge[6, 224] -> 
             RGBColor[
              0.9845045256450395, 0.9588710430060774, 0.43862463761941295`], 
             UndirectedEdge[103, 313] -> 
             RGBColor[
              0.31368725505562867`, 0.4437237541060531, 0.9412966590550009], 
             UndirectedEdge[8, 60] -> 
             RGBColor[
              0.33392414851101215`, 0.4636500467496988, 0.9424983293589592], 
             UndirectedEdge[284, 392] -> 
             RGBColor[
              0.24597365109495675`, 0.3758642813040053, 0.9373192075932261], 
             UndirectedEdge[218, 279] -> 
             RGBColor[
              0.9278567069516805, 0.8766750653657154, 0.6332052588371474], 
             UndirectedEdge[135, 221] -> 
             RGBColor[
              0.7125684826637311, 0.7740760557086418, 0.9732239792621271], 
             UndirectedEdge[95, 309] -> 
             RGBColor[
              0.2762844897757238, 0.4077228945756627, 0.9390453650152284], 
             UndirectedEdge[80, 385] -> 
             RGBColor[
              0.4549187217473041, 0.5651340807695402, 0.9511240470387816], 
             UndirectedEdge[272, 398] -> 
             RGBColor[
              0.7932211653132651, 0.8392589768677534, 0.976436715616906], 
             UndirectedEdge[33, 264] -> 
             RGBColor[
              0.18448620056776344`, 0.31123707227039327`, 0.9338175882482339],
              UndirectedEdge[76, 366] -> 
             RGBColor[
              0.8741124408312237, 0.5032302339331254, 0.2159628369001264], 
             UndirectedEdge[41, 258] -> 
             RGBColor[
              0.29687678880049106`, 0.4264012168061446, 0.9403266470848042], 
             UndirectedEdge[174, 232] -> 
             RGBColor[
              0.6270810139261389, 0.7068104580353534, 0.9646885621008761], 
             UndirectedEdge[61, 307] -> 
             RGBColor[
              0.9892929392100926, 0.9881701251038566, 0.7056981044009731], 
             UndirectedEdge[35, 392] -> 
             RGBColor[
              0.2644951314363644, 0.3953315314725043, 0.9383739784985945], 
             UndirectedEdge[212, 259] -> 
             RGBColor[
              0.2109589325174653, 0.33906159201767927`, 0.935325171169872], 
             UndirectedEdge[73, 110] -> 
             RGBColor[
              0.24934696023893294`, 0.3794098430944771, 0.9375113125586119], 
             UndirectedEdge[122, 228] -> 
             RGBColor[
              0.40697238168033323`, 0.5269207548100117, 0.9471528981824919], 
             UndirectedEdge[41, 203] -> 
             RGBColor[
              0.31610894590117855`, 0.4466154333081559, 0.9414218899802616], 
             UndirectedEdge[361, 385] -> 
             RGBColor[
              0.46552378312677223`, 0.5743196519105522, 0.9517997921721937], 
             UndirectedEdge[9, 269] -> 
             RGBColor[
              0.909363183463878, 0.5929294140972693, 0.329048956685827], 
             UndirectedEdge[192, 228] -> 
             RGBColor[
              0.35617346073846823`, 0.48292128271817314`, 0.9439160358597984],
              UndirectedEdge[47, 265] -> 
             RGBColor[
              0.5128933077983199, 0.6149014550415344, 0.9549417262439694], 
             UndirectedEdge[338, 398] -> 
             RGBColor[
              0.966856888277283, 0.9722679396973218, 0.803562057713115], 
             UndirectedEdge[71, 79] -> 
             RGBColor[
              0.730962985173496, 0.7893766931257962, 0.9742494771038676], 
             UndirectedEdge[77, 78] -> 
             RGBColor[
              0.8356045267952863, 0.5947068735494174, 0.5856449487468838], 
             UndirectedEdge[89, 164] -> 
             RGBColor[
              0.2305606666537099, 0.3596642574165986, 0.9364414609307642], 
             UndirectedEdge[123, 235] -> 
             RGBColor[
              0.8571949059772741, 0.8886183762780113, 0.9515616992620775], 
             UndirectedEdge[72, 393] -> 
             RGBColor[
              0.22527325394479547`, 0.3541068514182011, 0.9361403505990177], 
             UndirectedEdge[240, 371] -> 
             RGBColor[
              0.2556260580342823, 0.3860095729951837, 0.9378688978889642], 
             UndirectedEdge[196, 303] -> 
             RGBColor[
              0.29376792821553643`, 0.42609909688992764`, 0.9400410209699464],
              UndirectedEdge[105, 170] -> 
             RGBColor[
              0.4311568725166687, 0.5478681452245924, 0.9486939125530778], 
             UndirectedEdge[195, 208] -> 
             RGBColor[
              0.239390712068561, 0.3689451950048222, 0.9369443189542583], 
             UndirectedEdge[100, 180] -> 
             RGBColor[
              0.3714420538172285, 0.49614617062119337`, 0.9448889371092903], 
             UndirectedEdge[39, 355] -> 
             RGBColor[
              0.25200661552040216`, 0.3822053094271858, 0.9376627759922841], 
             UndirectedEdge[244, 397] -> 
             RGBColor[
              0.2546928621186111, 0.3850287249197748, 0.9378157537621064], 
             UndirectedEdge[225, 355] -> 
             RGBColor[
              0.24401463577453056`, 0.373805231993492, 0.9372076445688313], 
             UndirectedEdge[335, 354] -> 
             RGBColor[
              0.28014580760645524`, 0.41178138443745216`, 0.9392652613533807],
              UndirectedEdge[97, 100] -> 
             RGBColor[
              0.4094492665548738, 0.5290661079964851, 0.9473107230964745], 
             UndirectedEdge[2, 107] -> 
             RGBColor[
              0.828834437069773, 0.222639695414975, 0.17524519554284063`], 
             UndirectedEdge[128, 225] -> 
             RGBColor[
              0.2916606290262991, 0.42226923419395845`, 0.939980144908767], 
             UndirectedEdge[96, 228] -> 
             RGBColor[
              0.3273843328541551, 0.4559668373403135, 0.9421555344070691], 
             UndirectedEdge[262, 307] -> 
             RGBColor[
              0.9619414175862754, 0.970962445386637, 0.9415105792405329], 
             UndirectedEdge[86, 334] -> 
             RGBColor[
              0.28096769579564274`, 0.4126452410350092, 0.9393120666698803], 
             UndirectedEdge[255, 399] -> 
             RGBColor[
              0.24767699728620676`, 0.3776546061493952, 0.937416210638943], 
             UndirectedEdge[138, 242] -> 
             RGBColor[
              0.8688448581678534, 0.4318314305529642, 0.2096571104877158], 
             UndirectedEdge[27, 396] -> 
             RGBColor[
              0.28785811658992677`, 0.419887510167713, 0.9397044659406507], 
             UndirectedEdge[163, 209] -> 
             RGBColor[
              0.2485031193706023, 0.3785229128392603, 0.9374632570695112], 
             UndirectedEdge[63, 202] -> 
             RGBColor[
              0.9074503393274316, 0.6529677356997123, 0.2475510699614376], 
             UndirectedEdge[347, 372] -> 
             RGBColor[
              0.26576379522245486`, 0.3966649775496154, 0.9384462270243925], 
             UndirectedEdge[174, 275] -> 
             RGBColor[
              0.8603530123804088, 0.8894563784374243, 0.877080294609712], 
             UndirectedEdge[209, 315] -> 
             RGBColor[
              0.24765360770529532`, 0.37763002221687225`, 0.9374148786369118],
              UndirectedEdge[177, 374] -> 
             RGBColor[
              0.29900611365793894`, 0.43038779878246913`, 0.9403838868632315],
              UndirectedEdge[214, 215] -> 
             RGBColor[
              0.9015306453673441, 0.5683408458182889, 0.5392279021919928], 
             UndirectedEdge[160, 185] -> 
             RGBColor[
              0.8265840327508944, 0.20534210168661424`, 0.17309020582561438`],
              UndirectedEdge[63, 268] -> 
             RGBColor[
              0.8879400264016856, 0.5030029210787892, 0.2288679722699964], 
             UndirectedEdge[48, 196] -> 
             RGBColor[
              0.3616835055171287, 0.4866932494532377, 0.9443037663378753], 
             UndirectedEdge[34, 95] -> 
             RGBColor[
              0.29703377047989377`, 0.4292041286435296, 0.9402390000004376], 
             UndirectedEdge[84, 333] -> 
             RGBColor[
              0.18724373492288626`, 0.3141354157154036, 0.9339746257503516], 
             UndirectedEdge[102, 224] -> 
             RGBColor[
              0.8974792718626248, 0.5394468704448865, 0.26303107700793477`], 
             UndirectedEdge[105, 326] -> 
             RGBColor[
              0.37836717266856673`, 0.5021443605036287, 0.9453301995588554], 
             UndirectedEdge[134, 236] -> 
             RGBColor[
              0.24242453355158805`, 0.3721339337388756, 0.9371170905995801], 
             UndirectedEdge[92, 161] -> 
             RGBColor[
              0.35955024405905767`, 0.48389689314418627`, 0.9442025708853012],
              UndirectedEdge[77, 185] -> 
             RGBColor[
              0.8265277938578538, 0.5249391267425765, 0.5769530590352949], 
             UndirectedEdge[178, 329] -> 
             RGBColor[
              0.23956363455757862`, 0.36912694750469877`, 0.9369541666341921],
              UndirectedEdge[185, 400] -> 
             RGBColor[
              0.6066506956499677, 0.3474920671801415, 0.5581829902007515], 
             UndirectedEdge[317, 333] -> 
             RGBColor[
              0.5930937593564782, 0.6566344401985723, 0.8697228003417041], 
             UndirectedEdge[106, 215] -> 
             RGBColor[
              0.8838915069303948, 0.5551856052534505, 0.5690863625416396], 
             UndirectedEdge[14, 340] -> 
             RGBColor[
              0.9940676030184292, 0.9897195276507893, 0.5956733829454577], 
             UndirectedEdge[233, 358] -> 
             RGBColor[
              0.8930174526264201, 0.5204305413924555, 0.24838903272095686`], 
             UndirectedEdge[74, 191] -> 
             RGBColor[
              0.7517634193974077, 0.8060404672296411, 0.9758823517148281], 
             UndirectedEdge[53, 244] -> 
             RGBColor[
              0.27464006789181306`, 0.4059945029133032, 0.9389517176216438], 
             UndirectedEdge[4, 16] -> 
             RGBColor[
              0.23702850407735238`, 0.36646236463342485`, 0.9368097947037326],
              UndirectedEdge[149, 274] -> 
             RGBColor[
              0.22547330397154366`, 0.35431711668021776`, 0.9361517431520935],
              UndirectedEdge[326, 335] -> 
             RGBColor[
              0.3099542075105004, 0.4402786337315509, 0.9410665454863245], 
             UndirectedEdge[30, 77] -> 
             RGBColor[
              0.5041460680446381, 0.5860856357063153, 0.9585438899509009], 
             UndirectedEdge[129, 229] -> 
             RGBColor[
              0.24229031603850887`, 0.3719928626227475, 0.9371094471107673], 
             UndirectedEdge[216, 219] -> 
             RGBColor[
              0.5531447091768378, 0.647683896662048, 0.958186067610292], 
             UndirectedEdge[138, 233] -> 
             RGBColor[
              0.8184005545424529, 0.14244030215351539`, 0.165253697851294], 
             UndirectedEdge[28, 44] -> 
             RGBColor[
              0.29312282823703784`, 0.42542105591082463`, 0.9400042834805107],
              UndirectedEdge[163, 227] -> 
             RGBColor[
              0.23994763052693538`, 0.3695305516152434, 0.9369760346365759], 
             UndirectedEdge[15, 335] -> 
             RGBColor[
              0.2921895478533735, 0.4244401190541993, 0.9399511345433256], 
             UndirectedEdge[257, 268] -> 
             RGBColor[
              0.8199630848530925, 0.15445059482623982`, 0.16674997864138813`],
              UndirectedEdge[217, 279] -> 
             RGBColor[
              0.8842376547290044, 0.4993398194973086, 0.22230891067878217`], 
             UndirectedEdge[93, 119] -> 
             RGBColor[
              0.24286823945996167`, 0.3726002967811557, 0.9371423589946579], 
             UndirectedEdge[67, 305] -> 
             RGBColor[
              0.20792423756527648`, 0.33587193521215575`, 0.9351523497817738],
              UndirectedEdge[153, 195] -> 
             RGBColor[
              0.2815627334149148, 0.41246769783227444`, 0.9393753536812313], 
             UndirectedEdge[50, 135] -> 
             RGBColor[
              0.478712840814817, 0.5876796757980098, 0.9521051748933094], 
             UndirectedEdge[68, 334] -> 
             RGBColor[
              0.2690618295669699, 0.40013142075315566`, 0.938634045201308], 
             UndirectedEdge[95, 308] -> 
             RGBColor[
              0.2714334547461428, 0.4026241491861876, 0.9387691057467569], 
             UndirectedEdge[17, 36] -> 
             RGBColor[
              0.5275969503288876, 0.6273659981055699, 0.9559535110626505], 
             UndirectedEdge[41, 361] -> 
             RGBColor[
              0.34822341852427197`, 0.4760353557329764, 0.9434094661998561], 
             UndirectedEdge[117, 371] -> 
             RGBColor[
              0.31078136056287864`, 0.44021172480761495`, 0.9411479331302521],
              UndirectedEdge[89, 304] -> 
             RGBColor[
              0.21884062978169738`, 0.3473457555708567, 0.9357740221691438], 
             UndirectedEdge[267, 272] -> 
             RGBColor[
              0.6091079366672787, 0.6934689353256587, 0.9624191392814057], 
             UndirectedEdge[20, 158] -> 
             RGBColor[
              0.4553874406509526, 0.5675033157176284, 0.9506114604100135], 
             UndirectedEdge[30, 62] -> 
             RGBColor[
              0.17899764558147852`, 0.30546825298532254`, 0.9335050231613544],
              UndirectedEdge[197, 310] -> 
             RGBColor[
              0.5856647922314719, 0.6494240169162264, 0.8848951542933734], 
             UndirectedEdge[142, 268] -> 
             RGBColor[
              0.8194514867475214, 0.1505182276031009, 0.16626007171772583`], 
             UndirectedEdge[78, 213] -> 
             RGBColor[
              0.8764060316711535, 0.5036808895572449, 0.2174620888914447], 
             UndirectedEdge[48, 71] -> 
             RGBColor[
              0.6482814539995922, 0.7214952269023049, 0.9679496107647267], 
             UndirectedEdge[262, 269] -> 
             RGBColor[
              0.965850894705439, 0.9706613010892211, 0.7373156259818411], 
             UndirectedEdge[27, 376] -> 
             RGBColor[
              0.3679050083022842, 0.49203509004620194`, 0.9447019126873052], 
             UndirectedEdge[245, 292] -> 
             RGBColor[
              0.2204587636622521, 0.3490465168749334, 0.935866172499827], 
             UndirectedEdge[142, 217] -> 
             RGBColor[
              0.8222048215005642, 0.17168156503396934`, 0.16889666818668636`],
              UndirectedEdge[142, 363] -> 
             RGBColor[
              0.8420482335881154, 0.3177463123414773, 0.18764576842345915`], 
             UndirectedEdge[121, 130] -> 
             RGBColor[
              0.48180086572832803`, 0.5890215010044231, 0.9526702161686205], 
             UndirectedEdge[217, 300] -> 
             RGBColor[
              0.8564112237192996, 0.3849182800030426, 0.19970707341507446`], 
             UndirectedEdge[25, 109] -> 
             RGBColor[
              0.9214037823681839, 0.6836236479949891, 0.47088987975905927`], 
             UndirectedEdge[40, 146] -> 
             RGBColor[
              0.43732168419070216`, 0.5509809435704429, 0.9497020146539848], 
             UndirectedEdge[18, 140] -> 
             RGBColor[
              0.8085657806265083, 0.8511439536813179, 0.9727850165539047], 
             UndirectedEdge[170, 239] -> 
             RGBColor[
              0.38474227729381244`, 0.5076661557079413, 0.9457364155882924], 
             UndirectedEdge[152, 333] -> 
             RGBColor[
              0.18958831081692415`, 0.31659971363473505`, 0.9341081458790279],
              UndirectedEdge[14, 250] -> 
             RGBColor[
              0.99129214736786, 0.9898691754012934, 0.7359749681160213], 
             UndirectedEdge[55, 159] -> 
             RGBColor[
              0.36748362390558187`, 0.49271757758819734`, 0.9446367094556223],
              UndirectedEdge[234, 331] -> 
             RGBColor[
              0.3954159318032815, 0.5169111387705692, 0.9464165314152937], 
             UndirectedEdge[370, 389] -> 
             RGBColor[
              0.505152375234491, 0.5869084718259839, 0.9586367768062234], 
             UndirectedEdge[119, 316] -> 
             RGBColor[
              0.24738893708713797`, 0.3773518366161024, 0.9373998060367528], 
             UndirectedEdge[89, 227] -> 
             RGBColor[
              0.22675241851123462`, 0.35566154716197895`, 0.9362245868328485],
              UndirectedEdge[246, 254] -> 
             RGBColor[
              0.4566571232556863, 0.569515492226385, 0.9504402532261262], 
             UndirectedEdge[197, 345] -> 
             RGBColor[
              0.5953494141792219, 0.6596031686238084, 0.8854466791861835], 
             UndirectedEdge[231, 234] -> 
             RGBColor[
              0.3237117587462526, 0.454798867157554, 0.9418478143825956], 
             UndirectedEdge[89, 209] -> 
             RGBColor[
              0.23530790735490154`, 0.3646539083859959, 0.9367118092657838], 
             UndirectedEdge[233, 317] -> 
             RGBColor[
              0.9040426479180714, 0.5627946336685001, 0.48467433968140694`], 
             UndirectedEdge[48, 342] -> 
             RGBColor[
              0.5144005472567488, 0.6158956891444403, 0.9551237685400916], 
             UndirectedEdge[24, 104] -> 
             RGBColor[
              0.9180135558932775, 0.712060691693382, 0.25285908317008815`], 
             UndirectedEdge[118, 149] -> 
             RGBColor[
              0.21314012851733694`, 0.34135416730935836`, 0.9354493870552745],
              UndirectedEdge[34, 53] -> 
             RGBColor[
              0.30076648553276153`, 0.4331274488318972, 0.9404515726006413], 
             UndirectedEdge[29, 45] -> 
             RGBColor[
              0.26796415172899, 0.39897769174864406`, 0.938571534072304], 
             UndirectedEdge[35, 208] -> 
             RGBColor[
              0.25706388434981153`, 0.3875208196162586, 0.9379507799705602], 
             UndirectedEdge[69, 191] -> 
             RGBColor[
              0.5835359920161374, 0.6722207850854224, 0.9607394608823273], 
             UndirectedEdge[102, 166] -> 
             RGBColor[
              0.8220330696681408, 0.1703614051878311, 0.16873219843799186`], 
             UndirectedEdge[185, 213] -> 
             RGBColor[
              0.8673292987337209, 0.4339131427504039, 0.20877019917985573`], 
             UndirectedEdge[172, 364] -> 
             RGBColor[
              0.3254772137216906, 0.45565682861361634`, 0.9419848830531403], 
             UndirectedEdge[36, 55] -> 
             RGBColor[
              0.46160497467818506`, 0.5724389504821938, 0.9511318842995795], 
             UndirectedEdge[192, 203] -> 
             RGBColor[
              0.31794365991620344`, 0.4482045703725628, 0.9415387963349251], 
             UndirectedEdge[105, 394] -> 
             RGBColor[
              0.38810603050507936`, 0.5105796696723884, 0.9459507509684641], 
             UndirectedEdge[256, 261] -> 
             RGBColor[
              0.20237836752934693`, 0.3300428741759244, 0.934836520687607], 
             UndirectedEdge[215, 295] -> 
             RGBColor[
              0.5308377735120957, 0.2606789813644203, 0.5516093391744658], 
             UndirectedEdge[219, 357] -> 
             RGBColor[
              0.5614389734467367, 0.6541634389484363, 0.9590127623584092], 
             UndirectedEdge[204, 295] -> 
             RGBColor[
              0.21065717499813985`, 0.33874442573233643`, 0.9353079865255567],
              UndirectedEdge[24, 138] -> 
             RGBColor[
              0.8607479504188854, 0.399132481136813, 0.2031112451403423], 
             UndirectedEdge[135, 376] -> 
             RGBColor[
              0.47083567399736015`, 0.5808793962784845, 0.9515970246612349], 
             UndirectedEdge[127, 305] -> 
             RGBColor[
              0.20669916269368893`, 0.33458430384788407`, 0.9350825835801727],
              UndirectedEdge[54, 158] -> 
             RGBColor[
              0.4775536933364365, 0.5867026096855403, 0.9520238744302849], 
             UndirectedEdge[180, 350] -> 
             RGBColor[
              0.3995063863984757, 0.5204540849487005, 0.9466771715650524], 
             UndirectedEdge[46, 287] -> 
             RGBColor[
              0.27226485336384204`, 0.4034980018471065, 0.9388164526680909], 
             UndirectedEdge[41, 153] -> 
             RGBColor[
              0.32912553840433756`, 0.45949373186045395`, 0.9421925661662062],
              UndirectedEdge[163, 315] -> 
             RGBColor[
              0.24412373790812583`, 0.3739199052533755, 0.9372138577739373], 
             UndirectedEdge[17, 64] -> 
             RGBColor[
              0.46723843843845614`, 0.5768882992816866, 0.951609674456959], 
             UndirectedEdge[67, 127] -> 
             RGBColor[
              0.21172079285419906`, 0.33986235553632177`, 0.9353685579889777],
              UndirectedEdge[83, 246] -> 
             RGBColor[
              0.39834226268445083`, 0.5194457794981713, 0.946602994631389], 
             UndirectedEdge[44, 383] -> 
             RGBColor[
              0.28909643467092216`, 0.42118906098474024`, 0.9397749863234359],
              UndirectedEdge[5, 275] -> 
             RGBColor[
              0.916771833602923, 0.9337046356973782, 0.882657568389807], 
             UndirectedEdge[99, 123] -> 
             RGBColor[
              0.9762118677425246, 0.9817794304286422, 0.9251512823600752], 
             UndirectedEdge[278, 354] -> 
             RGBColor[
              0.2660945297513849, 0.3970126005093012, 0.9384650618665371], 
             UndirectedEdge[61, 215] -> 
             RGBColor[
              0.9063170503481712, 0.5687194984901538, 0.341612283904028], 
             UndirectedEdge[115, 208] -> 
             RGBColor[
              0.2358464087925902, 0.36521990753996986`, 0.9367424761260187], 
             UndirectedEdge[167, 203] -> 
             RGBColor[
              0.2874735215718495, 0.4194832764189812, 0.9396825638233285], 
             UndirectedEdge[242, 256] -> 
             RGBColor[
              0.5718276027056971, 0.5340616080097416, 0.5946502523941279], 
             UndirectedEdge[136, 254] -> 
             RGBColor[
              0.5440467518592814, 0.6407206880430576, 0.9572484996967315], 
             UndirectedEdge[65, 170] -> 
             RGBColor[
              0.4801509107444425, 0.5886204880785566, 0.952281016742329], 
             UndirectedEdge[247, 340] -> 
             RGBColor[
              0.9503928339373993, 0.8290616417134029, 0.4041000646481473], 
             UndirectedEdge[8, 17] -> 
             RGBColor[
              0.42291827954092154`, 0.5385004052405986, 0.9487856331227857], 
             UndirectedEdge[269, 300] -> 
             RGBColor[
              0.9415278534612976, 0.7904724805205449, 0.35790419683327634`], 
             UndirectedEdge[233, 242] -> 
             RGBColor[
              0.867902536299588, 0.4245883317454004, 0.20875474200246447`], 
             UndirectedEdge[242, 382] -> 
             RGBColor[
              0.9085638811026002, 0.6736245465915296, 0.24520540694695725`], 
             UndirectedEdge[144, 242] -> 
             RGBColor[
              0.8983924729381163, 0.6274385577093406, 0.23671813465048305`], 
             UndirectedEdge[81, 227] -> 
             RGBColor[
              0.2273187292651137, 0.35625677567048153`, 0.9362568373925002], 
             UndirectedEdge[224, 230] -> 
             RGBColor[
              0.9722593705527938, 0.9180864844443417, 0.3467333222862512], 
             UndirectedEdge[81, 248] -> 
             RGBColor[
              0.21796166804011632`, 0.3464219110510618, 0.9357239665982682], 
             UndirectedEdge[13, 323] -> 
             RGBColor[
              0.8969951869704291, 0.9199794950758233, 0.9649311806841149], 
             UndirectedEdge[10, 189] -> 
             RGBColor[
              0.3312363099818102, 0.46056389881459425`, 0.9423548195879734], 
             UndirectedEdge[135, 364] -> 
             RGBColor[
              0.42640390772588643`, 0.5423948335396401, 0.9487658718038847], 
             UndirectedEdge[39, 383] -> 
             RGBColor[
              0.27666419535336334`, 0.408121989212486, 0.9390669886861509], 
             UndirectedEdge[108, 196] -> 
             RGBColor[
              0.332746597404592, 0.4616295540574491, 0.9424599321408476], 
             UndirectedEdge[75, 89] -> 
             RGBColor[
              0.23138047401831524`, 0.3605259269355878, 0.9364881477473821], 
             UndirectedEdge[131, 269] -> 
             RGBColor[
              0.9577625542405059, 0.8589366723660075, 0.3711790558606476], 
             UndirectedEdge[36, 165] -> 
             RGBColor[
              0.5262130350709433, 0.6262424733544989, 0.9558445641840965], 
             UndirectedEdge[40, 41] -> 
             RGBColor[
              0.34006622360312927`, 0.4689700034848203, 0.942889696952605], 
             UndirectedEdge[86, 249] -> 
             RGBColor[
              0.2850528182511259, 0.41693896374744543`, 0.939544708350323], 
             UndirectedEdge[287, 395] -> 
             RGBColor[
              0.2666407460996809, 0.397586708523477, 0.938496168079518], 
             UndirectedEdge[177, 225] -> 
             RGBColor[
              0.2895083029136421, 0.42040499749423077`, 0.9398430005920957], 
             UndirectedEdge[74, 216] -> 
             RGBColor[
              0.7418875253371497, 0.7983253437301927, 0.9748980148903788], 
             UndirectedEdge[229, 371] -> 
             RGBColor[
              0.25947088353624953`, 0.3900507283737679, 0.9380878550133916], 
             UndirectedEdge[319, 371] -> 
             RGBColor[
              0.2568146393431022, 0.387258847311161, 0.937936585836153], 
             UndirectedEdge[169, 353] -> 
             RGBColor[
              0.21553905850906607`, 0.343875594831612, 0.9355860025694045], 
             UndirectedEdge[47, 362] -> 
             RGBColor[
              0.4192754724662534, 0.5375770736774529, 0.9479368402481747], 
             UndirectedEdge[83, 313] -> 
             RGBColor[
              0.31784501109874064`, 0.44732499341570175`, 0.9415615875935087],
              UndirectedEdge[87, 210] -> 
             RGBColor[
              0.2950312133683537, 0.42742688968244336`, 0.9401129631905363], 
             UndirectedEdge[91, 150] -> 
             RGBColor[
              0.2666109948635128, 0.3975554380879269, 0.9384944737906311], 
             UndirectedEdge[16, 258] -> 
             RGBColor[
              0.24739688608388788`, 0.37736019151568206`, 0.9374002587203583],
              UndirectedEdge[334, 388] -> 
             RGBColor[
              0.24238207309791887`, 0.372089305109921, 0.9371146725395583], 
             UndirectedEdge[67, 325] -> 
             RGBColor[
              0.21225679273606501`, 0.3404257253965182, 0.9353990823893092], 
             UndirectedEdge[279, 363] -> 
             RGBColor[
              0.9040810668165558, 0.6454045668048165, 0.24105801091555495`], 
             UndirectedEdge[192, 385] -> 
             RGBColor[
              0.45995539470159097`, 0.5694965937320001, 0.9514449793856737], 
             UndirectedEdge[216, 339] -> 
             RGBColor[
              0.5124310381777115, 0.6124197611712089, 0.9555918284959135], 
             UndirectedEdge[74, 323] -> 
             RGBColor[
              0.8274418605794372, 0.8652436955878107, 0.9834033373997775], 
             UndirectedEdge[60, 87] -> 
             RGBColor[
              0.32383352968544554`, 0.4531896894262284, 0.9419183552403817], 
             UndirectedEdge[74, 198] -> 
             RGBColor[
              0.8255815527613636, 0.8637603366303892, 0.9832258995793732], 
             UndirectedEdge[16, 348] -> 
             RGBColor[
              0.252407866634222, 0.38262704978860046`, 0.9376856266496183], 
             UndirectedEdge[88, 283] -> 
             RGBColor[
              0.9496145330722283, 0.8334245259791293, 0.5278793972462171], 
             UndirectedEdge[292, 388] -> 
             RGBColor[
              0.21719189432910094`, 0.3456128300743124, 0.9356801291242041], 
             UndirectedEdge[76, 382] -> 
             RGBColor[
              0.8728626791215081, 0.4975553578985697, 0.2149200050950769], 
             UndirectedEdge[131, 352] -> 
             RGBColor[
              0.9583101575279735, 0.8601079404267151, 0.43078229428572945`], 
             UndirectedEdge[123, 232] -> 
             RGBColor[
              0.7499263891145284, 0.8030301325071595, 0.9420935049543039], 
             UndirectedEdge[69, 357] -> 
             RGBColor[
              0.5819543622257783, 0.6709852038723623, 0.9605818188059951], 
             UndirectedEdge[241, 339] -> 
             RGBColor[
              0.32836122521249217`, 0.457187465102298, 0.9422040691120204], 
             UndirectedEdge[181, 322] -> 
             RGBColor[
              0.5378642093893072, 0.6357014215455682, 0.9567617873060958], 
             UndirectedEdge[140, 168] -> 
             RGBColor[
              0.6710377427034506, 0.7429390517664531, 0.9678464290545918], 
             UndirectedEdge[88, 357] -> 
             RGBColor[
              0.8330019348815232, 0.8684180093986145, 0.8892498058738514], 
             UndirectedEdge[125, 179] -> 
             RGBColor[
              0.2738145581196516, 0.4051268398024189, 0.9389047060613515], 
             UndirectedEdge[316, 324] -> 
             RGBColor[
              0.2671185805915378, 0.39808894287087526`, 0.9385233800469365], 
             UndirectedEdge[128, 390] -> 
             RGBColor[
              0.29625621364741994`, 0.42709948500765055`, 0.9402418566543815],
              UndirectedEdge[200, 339] -> 
             RGBColor[
              0.3182100783412779, 0.4465179661207665, 0.9416259763149808], 
             UndirectedEdge[85, 110] -> 
             RGBColor[
              0.2484427050223485, 0.37845941352875473`, 0.9374598165617531], 
             UndirectedEdge[178, 209] -> 
             RGBColor[
              0.24801071646784933`, 0.37800536616831976`, 0.9374352154526442],
              UndirectedEdge[380, 383] -> 
             RGBColor[
              0.2728634955258139, 0.4041272127154443, 0.9388505444536035], 
             UndirectedEdge[350, 357] -> 
             RGBColor[
              0.5542164267531839, 0.6479076320182329, 0.9585525480697432], 
             UndirectedEdge[98, 352] -> 
             RGBColor[
              0.9858621188487648, 0.9629527205499828, 0.4862282141252213], 
             UndirectedEdge[68, 151] -> 
             RGBColor[
              0.29628007015479707`, 0.4280840429902235, 0.9402080838641316], 
             UndirectedEdge[307, 385] -> 
             RGBColor[
              0.7803305100204103, 0.8271780586683711, 0.9269968726475282], 
             UndirectedEdge[94, 119] -> 
             RGBColor[
              0.25031116778183593`, 0.38042328635635736`, 0.9375662227517629],
              UndirectedEdge[116, 121] -> 
             RGBColor[
              0.48470874113100904`, 0.5915401565241579, 0.9528555034179461], 
             UndirectedEdge[1, 361] -> 
             RGBColor[
              0.35780477718256065`, 0.4843342470296975, 0.9440199819010995], 
             UndirectedEdge[180, 239] -> 
             RGBColor[
              0.3453924706572131, 0.47358333097810695`, 0.943229080705076], 
             UndirectedEdge[45, 394] -> 
             RGBColor[
              0.32718352263793704`, 0.4565868884354943, 0.9421136673575129], 
             UndirectedEdge[32, 124] -> 
             RGBColor[
              0.21977833860588586`, 0.34833134699925217`, 0.9358274232994656],
              UndirectedEdge[87, 243] -> 
             RGBColor[
              0.2892553344802239, 0.4213560747591461, 0.9397840354325044], 
             UndirectedEdge[188, 195] -> 
             RGBColor[
              0.25639031228130726`, 0.3868128526653249, 0.9379124210377194], 
             UndirectedEdge[122, 262] -> 
             RGBColor[
              0.6923652232093209, 0.7572804525421046, 0.9691955483013721], 
             UndirectedEdge[118, 212] -> 
             RGBColor[
              0.208479398474888, 0.33645544452739207`, 0.9351839653742893], 
             UndirectedEdge[35, 258] -> 
             RGBColor[
              0.2669871560923189, 0.3979508073894016, 0.938515895616131], 
             UndirectedEdge[183, 271] -> 
             RGBColor[
              0.28286075625291396`, 0.4146349676025667, 0.9394198736623899], 
             UndirectedEdge[130, 147] -> 
             RGBColor[
              0.34757171171070933`, 0.4732511609805692, 0.9434492148065551], 
             UndirectedEdge[124, 330] -> 
             RGBColor[
              0.22402160898279397`, 0.3527912932042634, 0.9360690712700745], 
             UndirectedEdge[46, 395] -> 
             RGBColor[
              0.27869220583377896`, 0.41025355681069386`, 0.939182480882838], 
             UndirectedEdge[206, 284] -> 
             RGBColor[
              0.23778007994491618`, 0.3672523185228967, 0.9368525958375336], 
             UndirectedEdge[179, 313] -> 
             RGBColor[
              0.2762257553297003, 0.407661160948913, 0.939042020175417], 
             UndirectedEdge[215, 363] -> 
             RGBColor[
              0.8409003453545498, 0.3089231403704602, 0.18654654935464235`], 
             UndirectedEdge[260, 338] -> 
             RGBColor[
              0.9016212039882432, 0.9204360205910522, 0.8006477894997438], 
             UndirectedEdge[88, 113] -> 
             RGBColor[
              0.8934147061054667, 0.915612925432826, 0.8952711863200087], 
             UndirectedEdge[95, 270] -> 
             RGBColor[
              0.26568283896088996`, 0.3965798873857872, 0.9384416166850604], 
             UndirectedEdge[16, 184] -> 
             RGBColor[
              0.22981171473055614`, 0.35887706145906934`, 0.9363988092267157],
              UndirectedEdge[38, 78] -> 
             RGBColor[
              0.9038175805994484, 0.6094521874784743, 0.2546544328195417], 
             UndirectedEdge[8, 210] -> 
             RGBColor[
              0.30512183219392025`, 0.43788724700591375`, 0.9406929373091137],
              UndirectedEdge[1, 96] -> 
             RGBColor[
              0.32344726087306624`, 0.45255674347328584`, 0.9419046676618501],
              UndirectedEdge[213, 247] -> 
             RGBColor[
              0.9089878266866289, 0.6768740913610367, 0.24562767290302676`], 
             UndirectedEdge[109, 366] -> 
             RGBColor[
              0.9476884477531541, 0.8182230648175637, 0.4934194788371198], 
             UndirectedEdge[223, 260] -> 
             RGBColor[
              0.6315106131402652, 0.7091757673875206, 0.9658788076150083], 
             UndirectedEdge[393, 399] -> 
             RGBColor[
              0.22884950770057744`, 0.3578657208631124, 0.9363440129598162], 
             UndirectedEdge[25, 358] -> 
             RGBColor[
              0.9086438937541778, 0.640542215450566, 0.2633529303924386], 
             UndirectedEdge[207, 358] -> 
             RGBColor[
              0.9542162454207332, 0.8524596356255733, 0.30144575978299126`], 
             UndirectedEdge[31, 33] -> 
             RGBColor[0.1810793999809316, 0.30765630885, 0.9336235759947237], 
             UndirectedEdge[355, 375] -> 
             RGBColor[
              0.24288325350972279`, 0.37261607749940034`, 0.9371432140225805],
              UndirectedEdge[25, 104] -> 
             RGBColor[
              0.8912926011446027, 0.575480186768195, 0.22996543355252164`], 
             UndirectedEdge[360, 375] -> 
             RGBColor[
              0.2826185317002574, 0.4142282159179257, 0.939411650593985], 
             UndirectedEdge[28, 347] -> 
             RGBColor[
              0.28416959916217255`, 0.4160106444856309, 0.9394944103298126], 
             UndirectedEdge[56, 143] -> 
             RGBColor[
              0.5377896391569529, 0.6355761788857779, 0.956773794547269], 
             UndirectedEdge[73, 115] -> 
             RGBColor[
              0.24086103809529086`, 0.3704906008829697, 0.9370280518463283], 
             UndirectedEdge[157, 218] -> 
             RGBColor[
              0.689653807893005, 0.7555582412254274, 0.971321814931075], 
             UndirectedEdge[267, 321] -> 
             RGBColor[
              0.6944927044467815, 0.7601721648632764, 0.9709294949676452], 
             UndirectedEdge[93, 324] -> 
             RGBColor[
              0.26259788296436154`, 0.3933374030359285, 0.9382659330048415], 
             UndirectedEdge[178, 245] -> 
             RGBColor[
              0.23694364602077422`, 0.3663731734356497, 0.9368049621629467], 
             UndirectedEdge[223, 331] -> 
             RGBColor[
              0.45307983116767014`, 0.5668363678003234, 0.9500964447383967], 
             UndirectedEdge[318, 367] -> 
             RGBColor[
              0.22156608180377718`, 0.3502103784497014, 0.9359292326298564], 
             UndirectedEdge[158, 265] -> 
             RGBColor[
              0.5475052991401734, 0.643528492531465, 0.9575207692077594], 
             UndirectedEdge[124, 199] -> 
             RGBColor[
              0.224537016117427, 0.35333301878146245`, 0.9360984229439153], 
             UndirectedEdge[38, 213] -> 
             RGBColor[
              0.9383796626861343, 0.7904965676280676, 0.28441340229193146`], 
             UndirectedEdge[128, 296] -> 
             RGBColor[
              0.3138673468643941, 0.4456099026290287, 0.9412447846377514], 
             UndirectedEdge[89, 315] -> 
             RGBColor[
              0.23092852589242507`, 0.36005090080011104`, 0.93646240997021], 
             UndirectedEdge[129, 178] -> 
             RGBColor[
              0.24083645723076108`, 0.3704647648358321, 0.9370266520024574], 
             UndirectedEdge[61, 279] -> 
             RGBColor[
              0.9694977718101772, 0.9052009249245101, 0.39612374546494056`], 
             UndirectedEdge[7, 332] -> 
             RGBColor[
              0.45831330080032634`, 0.5693830222721039, 0.9509787412394903], 
             UndirectedEdge[105, 180] -> 
             RGBColor[
              0.39180706588006936`, 0.513785320494758, 0.9461865776698615], 
             UndirectedEdge[75, 163] -> 
             RGBColor[
              0.24457568603401603`, 0.37439493138885227`, 0.9372395955511095],
              UndirectedEdge[15, 273] -> 
             RGBColor[
              0.28964915667663804`, 0.4217700068573468, 0.9398064630239824], 
             UndirectedEdge[149, 287] -> 
             RGBColor[
              0.24021601426247097`, 0.36981263993780294`, 0.9369913186932763],
              UndirectedEdge[123, 275] -> 
             RGBColor[
              0.9831983875687983, 0.9856760529092304, 0.8544852374631398], 
             UndirectedEdge[186, 226] -> 
             RGBColor[
              0.24355084950968384`, 0.37331776322339055`, 0.9371812326271585],
              UndirectedEdge[15, 183] -> 
             RGBColor[
              0.281397272925088, 0.41309675383481925`, 0.9393365304518997], 
             UndirectedEdge[35, 41] -> 
             RGBColor[
              0.3109306833758936, 0.44117275107327436`, 0.9411269955899995], 
             UndirectedEdge[47, 54] -> 
             RGBColor[
              0.44294170199458305`, 0.5580755721956097, 0.9494448314664949], 
             UndirectedEdge[19, 196] -> 
             RGBColor[
              0.2861541125436652, 0.4180964938749955, 0.9396074254310642], 
             UndirectedEdge[211, 328] -> 
             RGBColor[
              0.2860571913279975, 0.41793071873950494`, 0.9396042457787188], 
             UndirectedEdge[3, 86] -> 
             RGBColor[
              0.33530800642617503`, 0.4640896371481913, 0.9426142996527203], 
             UndirectedEdge[55, 58] -> 
             RGBColor[
              0.351171823063294, 0.4776705562573528, 0.9436309688854188], 
             UndirectedEdge[63, 214] -> 
             RGBColor[
              0.9711670732550739, 0.9296487112649943, 0.6029350218130802], 
             UndirectedEdge[26, 106] -> 
             RGBColor[
              0.7018038352541023, 0.7648141211568, 0.9611581586207743], 
             UndirectedEdge[89, 378] -> 
             RGBColor[
              0.2135546306131389, 0.341789835292997, 0.9354729923364294], 
             UndirectedEdge[191, 311] -> 
             RGBColor[
              0.5991137006259042, 0.6848674707026068, 0.961965795167115], 
             UndirectedEdge[147, 364] -> 
             RGBColor[
              0.31713379957570453`, 0.44688737134317436`, 0.9415097379605015],
              UndirectedEdge[137, 285] -> 
             RGBColor[
              0.23013560035880143`, 0.35921748578989005`, 0.9364172540340985],
              UndirectedEdge[104, 205] -> 
             RGBColor[
              0.9645712998383063, 0.8839256222853624, 0.49686413410326324`], 
             UndirectedEdge[191, 339] -> 
             RGBColor[
              0.5223069322379694, 0.6201348846706572, 0.9565761653203628], 
             UndirectedEdge[40, 167] -> 
             RGBColor[
              0.31143079927380024`, 0.4418378465956456, 0.9411503707956721], 
             UndirectedEdge[17, 262] -> 
             RGBColor[
              0.7370797325190604, 0.7937780282574919, 0.9726613937241215], 
             UndirectedEdge[96, 348] -> 
             RGBColor[
              0.27493335548153697`, 0.4063027667656103, 0.9389684199159984], 
             UndirectedEdge[60, 122] -> 
             RGBColor[
              0.4018079642776756, 0.5224475960269956, 0.9468238260723096], 
             UndirectedEdge[99, 187] -> 
             RGBColor[
              0.9110307205751575, 0.9308010667922535, 0.953442401298972], 
             UndirectedEdge[111, 166] -> 
             RGBColor[
              0.8494236278647009, 0.35624594261769826`, 0.19399614499147944`],
              UndirectedEdge[130, 172] -> 
             RGBColor[
              0.3559151258566954, 0.4820206182510111, 0.9439243598991939], 
             UndirectedEdge[205, 230] -> 
             RGBColor[
              0.9820628725503424, 0.9494608486926688, 0.5307965926515668], 
             UndirectedEdge[248, 319] -> 
             RGBColor[
              0.2288957810137855, 0.3579143570491916, 0.9363466481565481], 
             UndirectedEdge[77, 111] -> 
             RGBColor[
              0.8517216279012312, 0.6939386797204187, 0.6001134200588495], 
             UndirectedEdge[41, 188] -> 
             RGBColor[
              0.30395311727072993`, 0.43383888669350434`, 0.9407296335226945],
              UndirectedEdge[57, 278] -> 
             RGBColor[
              0.26281152350528336`, 0.39356195279003, 0.9382780995175941], 
             UndirectedEdge[56, 331] -> 
             RGBColor[
              0.4515137506850261, 0.565500249927577, 0.9499910348290849], 
             UndirectedEdge[40, 87] -> 
             RGBColor[
              0.31472542396778913`, 0.4453007060402985, 0.9413379947980343], 
             UndirectedEdge[142, 214] -> 
             RGBColor[
              0.9026785336009098, 0.577164017789306, 0.5403271212608096], 
             UndirectedEdge[341, 368] -> 
             RGBColor[
              0.2171826090564914, 0.3456030706640795, 0.9356796003416652], 
             UndirectedEdge[96, 188] -> 
             RGBColor[
              0.2769987034014417, 0.4084735783800516, 0.9390860384246287], 
             UndirectedEdge[142, 202] -> 
             RGBColor[
              0.8389617996732674, 0.300483042224024, 0.18494316940916705`], 
             UndirectedEdge[37, 351] -> 
             RGBColor[
              0.2477720085286644, 0.3777544689892789, 0.9374216213886444], 
             UndirectedEdge[83, 108] -> 
             RGBColor[
              0.3602253738682746, 0.48643084621613597`, 0.9441742201814636], 
             UndirectedEdge[72, 119] -> 
             RGBColor[
              0.2341124382405141, 0.36339739454965503`, 0.9366437290682574], 
             UndirectedEdge[170, 180] -> 
             RGBColor[
              0.40561982873439206`, 0.5257492414295251, 0.9470667147047922], 
             UndirectedEdge[196, 234] -> 
             RGBColor[
              0.3183317548341577, 0.44914414193399255`, 0.9415414311188043], 
             UndirectedEdge[218, 306] -> 
             RGBColor[
              0.9402199448611399, 0.9214289952270589, 0.6653505611679222], 
             UndirectedEdge[186, 189] -> 
             RGBColor[
              0.2745072076984255, 0.4058548584262301, 0.9389441514301794], 
             UndirectedEdge[20, 135] -> 
             RGBColor[
              0.45546851492086315`, 0.5675691354622958, 0.9506178428735257], 
             UndirectedEdge[79, 254] -> 
             RGBColor[
              0.5301586737259505, 0.6294457205636295, 0.9561551793123693], 
             UndirectedEdge[93, 355] -> 
             RGBColor[
              0.23807963900287032`, 0.36756717408594775`, 0.936869655282726], 
             UndirectedEdge[211, 301] -> 
             RGBColor[
              0.25974755171345176`, 0.39034152416978307`, 0.9381036108567895],
              UndirectedEdge[145, 227] -> 
             RGBColor[
              0.23647303514531387`, 0.36587853156708794`, 0.9367781615697957],
              UndirectedEdge[26, 345] -> 
             RGBColor[
              0.3285301240705917, 0.4490550186158963, 0.9425296374326482], 
             UndirectedEdge[132, 140] -> 
             RGBColor[
              0.7355736784173503, 0.7933550152374292, 0.9742787680039452], 
             UndirectedEdge[153, 258] -> 
             RGBColor[
              0.28518201112076286`, 0.41627178817658117`, 0.9395814661923377],
              UndirectedEdge[56, 344] -> 
             RGBColor[
              0.38578184035649155`, 0.5085665729828752, 0.9458026556273967], 
             UndirectedEdge[44, 390] -> 
             RGBColor[
              0.28212790876587335`, 0.4138646984284726, 0.9393781390821536], 
             UndirectedEdge[223, 346] -> 
             RGBColor[
              0.3995496021231435, 0.5204711739094963, 0.9466855458786024], 
             UndirectedEdge[114, 222] -> 
             RGBColor[
              0.4669023906435984, 0.574712579304436, 0.9521089968254883], 
             UndirectedEdge[85, 203] -> 
             RGBColor[
              0.2663525209612127, 0.3972837656284177, 0.9384797540842731], 
             UndirectedEdge[156, 261] -> 
             RGBColor[
              0.18270395436139325`, 0.3093638185065621, 0.9337160919633781], 
             UndirectedEdge[33, 295] -> 
             RGBColor[
              0.21066436833308994`, 0.3387519863834527, 0.9353083961753406], 
             UndirectedEdge[59, 395] -> 
             RGBColor[
              0.303543145607047, 0.434036883269187, 0.9406832590311243], 
             UndirectedEdge[334, 371] -> 
             RGBColor[
              0.26672232113879757`, 0.3976724490617448, 0.9385008136573162], 
             UndirectedEdge[40, 154] -> 
             RGBColor[
              0.3847350802007028, 0.5076599219476261, 0.9457359569958835], 
             UndirectedEdge[300, 306] -> 
             RGBColor[
              0.9301864468516778, 0.7525583544999579, 0.2846700934867103], 
             UndirectedEdge[61, 297] -> 
             RGBColor[
              0.9699924620425022, 0.9739499675150907, 0.7461656307796394], 
             UndirectedEdge[97, 350] -> 
             RGBColor[
              0.437513599136121, 0.5533740223239922, 0.9490989575522366], 
             UndirectedEdge[178, 229] -> 
             RGBColor[
              0.24544230257567465`, 0.37530580032079786`, 0.9372889480811126],
              UndirectedEdge[130, 265] -> 
             RGBColor[
              0.5011501438603255, 0.6047301166670249, 0.9541934622219126], 
             UndirectedEdge[110, 134] -> 
             RGBColor[
              0.24495240537755758`, 0.37479088730430044`, 0.9372610491604179],
              UndirectedEdge[147, 211] -> 
             RGBColor[
              0.2737075152920192, 0.40501433100367, 0.9388986101306735], 
             UndirectedEdge[78, 185] -> 
             RGBColor[
              0.832767216647035, 0.2528687626008105, 0.17901122970746597`], 
             UndirectedEdge[130, 135] -> 
             RGBColor[
              0.4568418198608912, 0.568758623177035, 0.9507053486499384], 
             UndirectedEdge[52, 384] -> 
             RGBColor[
              0.5675366621289825, 0.6563557009893235, 0.9607088184571579], 
             UndirectedEdge[77, 166] -> 
             RGBColor[
              0.827067103969575, 0.529084500588463, 0.5774695030073427], 
             UndirectedEdge[24, 76] -> 
             RGBColor[
              0.8745487301949283, 0.505211322035738, 0.2163268874396324], 
             UndirectedEdge[100, 220] -> 
             RGBColor[
              0.42602430021250687`, 0.5428220538333498, 0.9485327937322395], 
             UndirectedEdge[41, 369] -> 
             RGBColor[
              0.2991371325274741, 0.4287769813772735, 0.940455370316177], 
             UndirectedEdge[12, 318] -> 
             RGBColor[
              0.2211272263803799, 0.3497491135746699, 0.9359042404627222], 
             UndirectedEdge[118, 199] -> 
             RGBColor[
              0.21593219336709382`, 0.3442888044935889, 0.9356083910179783], 
             UndirectedEdge[11, 205] -> 
             RGBColor[
              0.9593655870867921, 0.8632867059265485, 0.49267549542961175`], 
             UndirectedEdge[120, 136] -> 
             RGBColor[
              0.5924802140391232, 0.6800411545432594, 0.9610613592571464], 
             UndirectedEdge[66, 215] -> 
             RGBColor[
              0.8960355420221306, 0.5345577698337973, 0.25743539509359753`], 
             UndirectedEdge[199, 287] -> 
             RGBColor[
              0.24300807911222783`, 0.3727472771220335, 0.9371503226559803], 
             UndirectedEdge[8, 64] -> 
             RGBColor[
              0.3546401133620532, 0.4815931742890025, 0.9438183323208591], 
             UndirectedEdge[312, 361] -> 
             RGBColor[
              0.40929184788600736`, 0.528668033662285, 0.9473730082456748], 
             UndirectedEdge[5, 193] -> 
             RGBColor[
              0.8318913190108279, 0.8687915729636699, 0.983827730717042], 
             UndirectedEdge[187, 232] -> 
             RGBColor[
              0.6847452419471614, 0.7520517688707707, 0.9703846238932006], 
             UndirectedEdge[115, 325] -> 
             RGBColor[
              0.22508690864981107`, 0.3539109906981984, 0.9361297385101415], 
             UndirectedEdge[137, 252] -> 
             RGBColor[
              0.22294460960746476`, 0.35165929857508804`, 0.9360077377489273],
              UndirectedEdge[296, 390] -> 
             RGBColor[
              0.283910407540538, 0.415738217657595, 0.9394796497504001], 
             UndirectedEdge[101, 171] -> 
             RGBColor[
              0.2670272094470698, 0.3979929060047742, 0.9385181765954305], 
             UndirectedEdge[234, 342] -> 
             RGBColor[
              0.47104879657377785`, 0.578346581625195, 0.9523614333210206], 
             UndirectedEdge[56, 343] -> 
             RGBColor[
              0.5865678018857227, 0.673953417760403, 0.9614500105609494], 
             UndirectedEdge[60, 146] -> 
             RGBColor[
              0.44642978990835863`, 0.5588699269563728, 0.9502823750963323], 
             UndirectedEdge[149, 336] -> 
             RGBColor[
              0.21561259787663173`, 0.3439528893695888, 0.9355901905275956], 
             UndirectedEdge[12, 199] -> 
             RGBColor[
              0.22211987446733733`, 0.350792449651586, 0.9359607703027832], 
             UndirectedEdge[42, 104] -> 
             RGBColor[
              0.9330499750272585, 0.8621677183315113, 0.6295247357296906], 
             UndirectedEdge[216, 323] -> 
             RGBColor[
              0.7446559095096992, 0.8005327781235971, 0.9751620658441222], 
             UndirectedEdge[110, 192] -> 
             RGBColor[
              0.30003384397733923`, 0.42938021827289985`, 0.940518858812405], 
             UndirectedEdge[93, 380] -> 
             RGBColor[
              0.25536438822798396`, 0.38573454143794017`, 0.9378539961806014],
              UndirectedEdge[34, 397] -> 
             RGBColor[
              0.28081927975955956`, 0.41216167083836874`, 0.939315608741104], 
             UndirectedEdge[249, 308] -> 
             RGBColor[
              0.2653288302878062, 0.39620780182492993`, 0.9384214564148372], 
             UndirectedEdge[116, 130] -> 
             RGBColor[
              0.4133134657138138, 0.5324130830876621, 0.947556946449905], 
             UndirectedEdge[81, 315] -> 
             RGBColor[
              0.23149483664630416`, 0.3606461293086136, 0.9364946605298619], 
             UndirectedEdge[99, 193] -> 
             RGBColor[
              0.9002336063428361, 0.9221917409832586, 0.9524125629047955], 
             UndirectedEdge[116, 135] -> 
             RGBColor[
              0.4597496952635722, 0.5712772786967698, 0.9508906358992639], 
             UndirectedEdge[304, 378] -> 
             RGBColor[
              0.21381243485280502`, 0.34206080389461896`, 0.9354876739064912],
              UndirectedEdge[56, 120] -> 
             RGBColor[
              0.5086566729306621, 0.6119247244781029, 0.9544803407283637], 
             UndirectedEdge[255, 393] -> 
             RGBColor[
              0.2416474883761139, 0.3713172099919425, 0.9370728390263723], 
             UndirectedEdge[106, 214] -> 
             RGBColor[
              0.9661339552698273, 0.9742633398075717, 0.9422105594358144], 
             UndirectedEdge[130, 328] -> 
             RGBColor[
              0.3599213877466876, 0.48616754871640405`, 0.9441548504546003], 
             UndirectedEdge[181, 250] -> 
             RGBColor[
              0.7777697545864616, 0.8245041838583995, 0.9019245302265969], 
             UndirectedEdge[102, 230] -> 
             RGBColor[
              0.8940771340934058, 0.5279706608893748, 0.24981441421432754`], 
             UndirectedEdge[45, 141] -> 
             RGBColor[
              0.32778152064738697`, 0.45710484425502595`, 0.9421517712618861],
              UndirectedEdge[225, 288] -> 
             RGBColor[
              0.25106704817739506`, 0.3812177645776751, 0.9376092690220652], 
             UndirectedEdge[208, 278] -> 
             RGBColor[
              0.24275117083398723`, 0.37247725023267697`, 0.9371356921095961],
              UndirectedEdge[342, 346] -> 
             RGBColor[
              0.4741951057473072, 0.5810717564932091, 0.9525619133593859], 
             UndirectedEdge[133, 164] -> 
             RGBColor[
              0.2698983654154672, 0.40101067296936244`, 0.9386816846803361], 
             UndirectedEdge[287, 373] -> 
             RGBColor[
              0.2552675974110747, 0.3856328081524763, 0.9378484840867676], 
             UndirectedEdge[122, 314] -> 
             RGBColor[
              0.6859497834912932, 0.7522408691078613, 0.9712156258567326], 
             UndirectedEdge[85, 351] -> 
             RGBColor[
              0.24352597864269326`, 0.37329162236527946`, 0.9371798162680766],
              UndirectedEdge[5, 338] -> 
             RGBColor[
              0.9178657002272999, 0.9332997898377504, 0.8022208620159], 
             UndirectedEdge[311, 339] -> 
             RGBColor[
              0.4425672704759462, 0.555957682108388, 0.9499165435038557], 
             UndirectedEdge[39, 324] -> 
             RGBColor[
              0.27652485948189337`, 0.40797553837716655`, 0.9390590537143996],
              UndirectedEdge[52, 346] -> 
             RGBColor[
              0.36583874865596927`, 0.4912928693208167, 0.944531899459223], 
             UndirectedEdge[272, 291] -> 
             RGBColor[
              0.6717542540567425, 0.7434987958813325, 0.9679178442101087], 
             UndirectedEdge[191, 323] -> 
             RGBColor[
              0.7545318035699571, 0.8082479016230455, 0.9761464026685716], 
             UndirectedEdge[60, 165] -> 
             RGBColor[
              0.4451385583294708, 0.557821646991312, 0.950180724616505], 
             UndirectedEdge[44, 301] -> 
             RGBColor[
              0.2773872245806669, 0.4088819387730828, 0.9391081641310199], 
             UndirectedEdge[11, 144] -> 
             RGBColor[
              0.9009503839038591, 0.6375798223152109, 0.23877628985540691`], 
             UndirectedEdge[333, 381] -> 
             RGBColor[
              0.5943537422981029, 0.6571554755250186, 0.8488416222676571], 
             UndirectedEdge[9, 363] -> 
             RGBColor[
              0.8440899658094313, 0.333439960887275, 0.18960093350439794`], 
             UndirectedEdge[153, 312] -> 
             RGBColor[
              0.39019396776607296`, 0.5121264097897626, 0.9461561082120249], 
             UndirectedEdge[55, 80] -> 
             RGBColor[
              0.36897452576073053`, 0.49400892184022105`, 0.9447317084034796],
              UndirectedEdge[7, 40] -> 
             RGBColor[
              0.36435856265805855`, 0.4900108066057379, 0.9444375833163132], 
             UndirectedEdge[51, 377] -> 
             RGBColor[
              0.39390138797963725`, 0.5155993170337143, 0.9463200260221095], 
             UndirectedEdge[112, 170] -> 
             RGBColor[
              0.3869454032271654, 0.5095743926590826, 0.9458767968246178], 
             UndirectedEdge[200, 375] -> 
             RGBColor[
              0.26275249757312547`, 0.3934999127928718, 0.9382747380780788], 
             UndirectedEdge[94, 200] -> 
             RGBColor[
              0.26539181138814727`, 0.3962739989546208, 0.9384250430953294], 
             UndirectedEdge[8, 253] -> 
             RGBColor[
              0.3260178665234107, 0.4568020226733255, 0.9419945480619598], 
             UndirectedEdge[31, 295] -> 
             RGBColor[
              0.21280238164412135`, 0.34099917393122015`, 0.9354301528704966],
              UndirectedEdge[301, 383] -> 
             RGBColor[
              0.2685271160434062, 0.39956940293709464`, 0.9386035940571789], 
             UndirectedEdge[327, 392] -> 
             RGBColor[
              0.28327067295496094`, 0.4141554737113025, 0.9394765499044728], 
             UndirectedEdge[119, 375] -> 
             RGBColor[
              0.24767185396681415`, 0.37764920019460835`, 0.9374159177345123],
              UndirectedEdge[160, 340] -> 
             RGBColor[
              0.9116278550257833, 0.6083417789954149, 0.37001345675471364`], 
             UndirectedEdge[151, 308] -> 
             RGBColor[
              0.28846194842015016`, 0.41986670134956156`, 0.9397628533972181],
              UndirectedEdge[221, 276] -> 
             RGBColor[
              0.8437125304054167, 0.8786573253156666, 0.9848385285958808], 
             UndirectedEdge[94, 316] -> 
             RGBColor[
              0.25720173748705216`, 0.38766571200389227`, 0.9379586305027907],
              UndirectedEdge[195, 206] -> 
             RGBColor[
              0.2386283880050733, 0.3681439440799593, 0.9369009057266002], 
             UndirectedEdge[159, 192] -> 
             RGBColor[
              0.3379621693046799, 0.46714757740434754`, 0.9427556284732501], 
             UndirectedEdge[220, 350] -> 
             RGBColor[
              0.454088632793754, 0.5671299681608568, 0.9503210281880017], 
             UndirectedEdge[229, 319] -> 
             RGBColor[
              0.24423991719027513`, 0.3740420170451063, 0.9372204740121839], 
             UndirectedEdge[69, 97] -> 
             RGBColor[
              0.46525153460871527`, 0.5764515941781216, 0.9511282282884884], 
             UndirectedEdge[90, 317] -> 
             RGBColor[
              0.8482164323597703, 0.8802460937906929, 0.8881545671159801], 
             UndirectedEdge[136, 237] -> 
             RGBColor[
              0.59850057250929, 0.6849287527633994, 0.9615353039292178], 
             UndirectedEdge[69, 141] -> 
             RGBColor[
              0.42414128450553, 0.540843961799992, 0.9485087195042803], 
             UndirectedEdge[48, 143] -> 
             RGBColor[
              0.5250435709581793, 0.6245361752480152, 0.9559616263525487], 
             UndirectedEdge[51, 246] -> 
             RGBColor[
              0.408363122473439, 0.5281253445843351, 0.9472415149560449], 
             UndirectedEdge[97, 132] -> 
             RGBColor[
              0.6207534044996754, 0.7002920708010887, 0.965012812845729], 
             UndirectedEdge[94, 383] -> 
             RGBColor[
              0.2701801471577058, 0.4013068434464496, 0.9386977317336979], 
             UndirectedEdge[246, 344] -> 
             RGBColor[
              0.3822157528613575, 0.505477807231359, 0.9455754276855741], 
             UndirectedEdge[155, 354] -> 
             RGBColor[
              0.29215952785429067`, 0.42440856613178546`, 0.9399494249487885],
              UndirectedEdge[107, 307] -> 
             RGBColor[
              0.9122288272245584, 0.6453071063540661, 0.539731773350462], 
             UndirectedEdge[310, 363] -> 
             RGBColor[
              0.5225453221257725, 0.38890738011125736`, 0.5703491605175277], 
             UndirectedEdge[99, 281] -> 
             RGBColor[
              0.8050608246814849, 0.8476642232367373, 0.943040239252503], 
             UndirectedEdge[123, 187] -> 
             RGBColor[
              0.9091149872090246, 0.929372315984517, 0.9566852381845512], 
             UndirectedEdge[23, 227] -> 
             RGBColor[
              0.22416996966139735`, 0.3529472296840859, 0.936077520191241], 
             UndirectedEdge[28, 211] -> 
             RGBColor[
              0.2754831553698227, 0.4068806413075249, 0.9389997302062802], 
             UndirectedEdge[327, 356] -> 
             RGBColor[
              0.4184852693414719, 0.5351260969165677, 0.9483745901685348], 
             UndirectedEdge[140, 219] -> 
             RGBColor[
              0.5595564197473485, 0.6526927736905361, 0.9588251269991186], 
             UndirectedEdge[104, 144] -> 
             RGBColor[
              0.9061560966553733, 0.6582187386740248, 0.24296492852905843`], 
             UndirectedEdge[49, 328] -> 
             RGBColor[
              0.2825867919008145, 0.4142831089055032, 0.9394066116653366], 
             UndirectedEdge[112, 271] -> 
             RGBColor[
              0.3178545270497625, 0.4495503070285146, 0.9414810160978866], 
             UndirectedEdge[106, 197] -> 
             RGBColor[
              0.9686231253627324, 0.9753622711647122, 0.9040752003743098], 
             UndirectedEdge[106, 204] -> 
             RGBColor[
              0.563710908416439, 0.6332510496213667, 0.9527850098927306], 
             UndirectedEdge[50, 158] -> 
             RGBColor[
              0.47863176654490647`, 0.5876138560533424, 0.9520987924297972], 
             UndirectedEdge[259, 299] -> 
             RGBColor[
              0.21257469635649348`, 0.34075986225784227`, 0.9354171865301963],
              UndirectedEdge[79, 286] -> 
             RGBColor[
              0.658527918518543, 0.7323765551714567, 0.9671395072605043], 
             UndirectedEdge[240, 388] -> 
             RGBColor[
              0.23128580999340365`, 0.36042642904335986`, 0.9364827567712063],
              UndirectedEdge[118, 299] -> 
             RGBColor[
              0.21009516231391617`, 0.33815371476755507`, 0.9352759807346135],
              UndirectedEdge[138, 257] -> 
             RGBColor[
              0.8209750230584517, 0.16222879530677942`, 0.1677190118096608], 
             UndirectedEdge[171, 244] -> 
             RGBColor[
              0.266624380952421, 0.39756950771609656`, 0.9384952361085915], 
             UndirectedEdge[161, 337] -> 
             RGBColor[
              0.35808998923330093`, 0.48236207273681253`, 0.9441194115332278],
              UndirectedEdge[119, 355] -> 
             RGBColor[
              0.2357097669248304, 0.3650762882733595, 0.9367346945737933], 
             UndirectedEdge[248, 292] -> 
             RGBColor[
              0.21361328404066288`, 0.34185148376416674`, 0.935476332562357], 
             UndirectedEdge[68, 386] -> 
             RGBColor[
              0.30804388160308127`, 0.43827326520037213`, 0.9409576635272863],
              UndirectedEdge[126, 299] -> 
             RGBColor[
              0.21308522513571704`, 0.34129646037420036`, 0.9354462603889135],
              UndirectedEdge[128, 383] -> 
             RGBColor[
              0.30322473955246876`, 0.43442384756391816`, 0.9406387038956638],
              UndirectedEdge[229, 248] -> 
             RGBColor[
              0.2315520252069328, 0.36070623811179847`, 0.9364979173337866], 
             UndirectedEdge[395, 396] -> 
             RGBColor[
              0.2756838068644868, 0.4070915387504564, 0.9390111570120642], 
             UndirectedEdge[81, 292] -> 
             RGBColor[
              0.21536706305033604`, 0.3436948166993449, 0.9355762076824743], 
             UndirectedEdge[34, 253] -> 
             RGBColor[
              0.3270023945629662, 0.4576547713773704, 0.9420572813180563], 
             UndirectedEdge[130, 322] -> 
             RGBColor[
              0.45941085843753277`, 0.5708442844274215, 0.95090759277739], 
             UndirectedEdge[74, 311] -> 
             RGBColor[
              0.6720237576353845, 0.741863264667372, 0.9692227298983209], 
             UndirectedEdge[232, 235] -> 
             RGBColor[
              0.6328251607154107, 0.7112978291642651, 0.965261084970727], 
             UndirectedEdge[207, 221] -> 
             RGBColor[
              0.9308573670898133, 0.869892342221664, 0.6314368519575342], 
             UndirectedEdge[140, 216] -> 
             RGBColor[
              0.6655132848379224, 0.7386233032944675, 0.96729580272355], 
             UndirectedEdge[31, 173] -> 
             RGBColor[
              0.20479251217739197`, 0.3325802932666311, 0.9349740026539064], 
             UndirectedEdge[37, 243] -> 
             RGBColor[
              0.2690857390615694, 0.4001565511479292, 0.9386354068116546], 
             UndirectedEdge[1, 35] -> 
             RGBColor[
              0.32051204203418227`, 0.44947164236999554`, 0.9417375112912428],
              UndirectedEdge[60, 210] -> 
             RGBColor[
              0.3287260262404138, 0.45833201350769803`, 0.942196975681387], 
             UndirectedEdge[35, 92] -> 
             RGBColor[
              0.28435244626912165`, 0.4162028283882106, 0.9395048232020553], 
             UndirectedEdge[52, 291] -> 
             RGBColor[
              0.5415685327056081, 0.6360692009186899, 0.9581205580022027], 
             UndirectedEdge[77, 400] -> 
             RGBColor[
              0.6094880057982189, 0.6893301781287484, 0.9648167092401694], 
             UndirectedEdge[77, 389] -> 
             RGBColor[
              0.5042266153181847, 0.5861702959978048, 0.9585484769989704], 
             UndirectedEdge[96, 361] -> 
             RGBColor[
              0.32126900465498376`, 0.45067004741952366`, 0.9417658711017902],
              UndirectedEdge[150, 374] -> 
             RGBColor[
              0.2733522518909328, 0.4046409266441276, 0.9388783784055468], 
             UndirectedEdge[80, 154] -> 
             RGBColor[
              0.38228721374237734`, 0.5055397030547701, 0.9455799811097223], 
             UndirectedEdge[200, 383] -> 
             RGBColor[
              0.27544799036410295`, 0.4068436806569232, 0.9389977276112265], 
             UndirectedEdge[144, 391] -> 
             RGBColor[
              0.8494144480971886, 0.3493178905748092, 0.19371883223399736`], 
             UndirectedEdge[196, 290] -> 
             RGBColor[
              0.3515289166579535, 0.47789785496789633`, 0.943656724915119], 
             UndirectedEdge[159, 228] -> 
             RGBColor[
              0.3496458859290326, 0.47726742550368945`, 0.9435001045650488], 
             UndirectedEdge[27, 377] -> 
             RGBColor[
              0.3561480526956704, 0.48185180602152367`, 0.9439527698723194], 
             UndirectedEdge[24, 233] -> 
             RGBColor[
              0.8598056285506199, 0.3918893823292492, 0.202208876655091], 
             UndirectedEdge[24, 109] -> 
             RGBColor[
              0.9481247371168586, 0.8202041529201762, 0.49378352937662584`], 
             UndirectedEdge[189, 255] -> 
             RGBColor[
              0.28051086067435194`, 0.4121650783575129, 0.9392860505855498], 
             UndirectedEdge[262, 298] -> 
             RGBColor[
              0.8810364966451805, 0.9079026895445534, 0.9858832537094278], 
             UndirectedEdge[249, 397] -> 
             RGBColor[
              0.25945941523748706`, 0.39003867446463636`, 0.938087201910743], 
             UndirectedEdge[128, 324] -> 
             RGBColor[
              0.3030854036809988, 0.43427739672859866`, 0.9406307689239126], 
             UndirectedEdge[7, 228] -> 
             RGBColor[
              0.37863108577837257`, 0.5023729487746839, 0.9453470158688431], 
             UndirectedEdge[115, 258] -> 
             RGBColor[
              0.24576968053509757`, 0.37564989531311277`, 0.9373075917715895],
              UndirectedEdge[375, 383] -> 
             RGBColor[
              0.26754083334268397`, 0.3985327572847006, 0.9385474267164473], 
             UndirectedEdge[257, 338] -> 
             RGBColor[
              0.9084477718580719, 0.5824829620653897, 0.3944924501077937], 
             UndirectedEdge[5, 321] -> 
             RGBColor[
              0.8296147450427847, 0.8669940565457998, 0.9836058756059307], 
             UndirectedEdge[65, 239] -> 
             RGBColor[
              0.4199235526672635, 0.5364545776271384, 0.9484433827426128], 
             UndirectedEdge[56, 71] -> 
             RGBColor[
              0.6610275221983658, 0.7325352305400676, 0.968761778959447], 
             UndirectedEdge[276, 322] -> 
             RGBColor[
              0.6369911357289768, 0.7142897496435541, 0.9658558315605028], 
             UndirectedEdge[239, 326] -> 
             RGBColor[
              0.3319525774457105, 0.4619423709869775, 0.94237270259407], 
             UndirectedEdge[379, 393] -> 
             RGBColor[
              0.22188867958802838`, 0.35054944917483033`, 0.9359476040964289],
              UndirectedEdge[131, 262] -> 
             RGBColor[
              0.9305545199558635, 0.8420358975584873, 0.6226092420681639], 
             UndirectedEdge[201, 210] -> 
             RGBColor[
              0.2881749983278178, 0.42022057296569904`, 0.9397225118868391], 
             UndirectedEdge[301, 372] -> 
             RGBColor[
              0.25414770566980416`, 0.3844557309271635, 0.9377847079088335], 
             UndirectedEdge[291, 398] -> 
             RGBColor[
              0.8179584912880846, 0.8585839639299231, 0.9789023010866215], 
             UndirectedEdge[28, 49] -> 
             RGBColor[
              0.27201275594263963`, 0.40323303147352313`, 0.938802096092898], 
             UndirectedEdge[6, 160] -> 
             RGBColor[
              0.9114125623801264, 0.6078812897957802, 0.3465801809071596], 
             UndirectedEdge[375, 379] -> 
             RGBColor[
              0.23790135046863936`, 0.36737978153232503`, 0.9368595020144559],
              UndirectedEdge[45, 112] -> 
             RGBColor[
              0.31221013250570034`, 0.4436176904874213, 0.9411595761787357], 
             UndirectedEdge[324, 390] -> 
             RGBColor[
              0.27312846435714266`, 0.404405711757165, 0.9388656340365613], 
             UndirectedEdge[169, 227] -> 
             RGBColor[
              0.22781024002051087`, 0.3567733846379857, 0.936284828202895], 
             UndirectedEdge[44, 380] -> 
             RGBColor[
              0.2817236040630746, 0.41343974855143245`, 0.9393551145274445], 
             UndirectedEdge[288, 360] -> 
             RGBColor[
              0.2777088570611381, 0.4090678365808599, 0.9391320518865], 
             UndirectedEdge[87, 134] -> 
             RGBColor[
              0.26223279186396886`, 0.39295366914130303`, 0.9382451416067781],
              UndirectedEdge[85, 258] -> 
             RGBColor[
              0.24712036386052527`, 0.3770695491264064, 0.9373845111888157], 
             UndirectedEdge[26, 77] -> 
             RGBColor[
              0.6422389788407158, 0.7176486903810251, 0.9669170377654001], 
             UndirectedEdge[90, 333] -> 
             RGBColor[
              0.4506831285542931, 0.5464884699982167, 0.9528800174609131], 
             UndirectedEdge[45, 91] -> 
             RGBColor[
              0.27906015322156846`, 0.41064029284447245`, 0.9392034349422431],
              UndirectedEdge[103, 133] -> 
             RGBColor[
              0.32091218999488846`, 0.4513176188145481, 0.9417081084114585], 
             UndirectedEdge[143, 342] -> 
             RGBColor[
              0.6140012232637606, 0.6975128793422373, 0.9627555719373643], 
             UndirectedEdge[75, 164] -> 
             RGBColor[
              0.2433583151299939, 0.3731153973829517, 0.9371702680790643], 
             UndirectedEdge[44, 211] -> 
             RGBColor[
              0.28031687034096775`, 0.4119611822174286, 0.9392750031230466], 
             UndirectedEdge[82, 171] -> 
             RGBColor[
              0.32621487078886763`, 0.45368735101725755`, 0.9421273921767691],
              UndirectedEdge[17, 122] -> 
             RGBColor[
              0.490802095307585, 0.5972979545178956, 0.9531111298361363], 
             UndirectedEdge[150, 186] -> 
             RGBColor[
              0.2595342246109202, 0.3901173038593028, 0.9380914621938894], 
             UndirectedEdge[180, 394] -> 
             RGBColor[
              0.36256898672280274`, 0.4884607658773212, 0.9443235531201786], 
             UndirectedEdge[156, 202] -> 
             RGBColor[
              0.5211495825009953, 0.37342113688887774`, 0.567742844041897], 
             UndirectedEdge[86, 178] -> 
             RGBColor[
              0.27226239938534696`, 0.40349542256011695`, 0.9388163129176459],
              UndirectedEdge[102, 250] -> 
             RGBColor[
              0.9037621261807391, 0.5693653564012491, 0.505440590565607], 
             UndirectedEdge[7, 222] -> 
             RGBColor[
              0.4971659473495666, 0.600925351032558, 0.9540373638977802], 
             UndirectedEdge[97, 220] -> 
             RGBColor[
              0.4588594812307164, 0.571262237287139, 0.9506250224317093], 
             UndirectedEdge[230, 289] -> 
             RGBColor[
              0.9333052704870481, 0.7676068761755623, 0.28495592618105414`], 
             UndirectedEdge[14, 289] -> 
             RGBColor[
              0.9460551929840001, 0.8094710811761514, 0.43178805845315205`], 
             UndirectedEdge[77, 370] -> 
             RGBColor[
              0.8302908639224114, 0.8675154135193626, 0.9836750778819656], 
             UndirectedEdge[151, 270] -> 
             RGBColor[
              0.28271133263489734`, 0.4138224395491612, 0.9394353643355215], 
             UndirectedEdge[173, 214] -> 
             RGBColor[
              0.6050703523847987, 0.6713378352539525, 0.9242773858520503], 
             UndirectedEdge[144, 317] -> 
             RGBColor[
              0.9345325845565998, 0.7656448596324403, 0.5126377323294256], 
             UndirectedEdge[31, 175] -> 
             RGBColor[
              0.18107477738655686`, 0.3076514502102228, 0.9336233127448126], 
             UndirectedEdge[163, 240] -> 
             RGBColor[
              0.2420898799764604, 0.3717821916131542, 0.9370980325735522], 
             UndirectedEdge[329, 371] -> 
             RGBColor[
              0.25359221551815353`, 0.38387187555766883`, 0.9377530735664711],
              UndirectedEdge[72, 375] -> 
             RGBColor[
              0.24128592482540645`, 0.37093718377569584`, 0.9370522485170447],
              UndirectedEdge[32, 238] -> 
             RGBColor[
              0.22275425852448527`, 0.3514592275179208, 0.9359968975363508], 
             UndirectedEdge[11, 14] -> 
             RGBColor[
              0.9589098698169762, 0.8623003371232989, 0.4422276945427869], 
             UndirectedEdge[79, 237] -> 
             RGBColor[
              0.5846124943759591, 0.6736537852839712, 0.9604419835448554], 
             UndirectedEdge[69, 74] -> 
             RGBColor[
              0.6564460490256175, 0.7292165790501876, 0.9679963956135333], 
             UndirectedEdge[16, 203] -> 
             RGBColor[
              0.2666290431845753, 0.3975744080176934, 0.9384955016158156], 
             UndirectedEdge[315, 319] -> 
             RGBColor[
              0.24242894961997336`, 0.37213857530674344`, 0.9371173420881417],
              UndirectedEdge[40, 80] -> 
             RGBColor[
              0.3368642646638673, 0.46619662758676733`, 0.9426856709603764], 
             UndirectedEdge[18, 198] -> 
             RGBColor[
              0.8858480974802114, 0.9115700695530261, 0.9804738418540726], 
             UndirectedEdge[300, 307] -> 
             RGBColor[
              0.9376183763421341, 0.7907736248179609, 0.5620991500919681], 
             UndirectedEdge[191, 198] -> 
             RGBColor[
              0.7526714957518834, 0.806764542665624, 0.9759689648481673], 
             UndirectedEdge[289, 391] -> 
             RGBColor[
              0.8590720492168273, 0.39317080166904056`, 0.2017773713376896], 
             UndirectedEdge[132, 357] -> 
             RGBColor[
              0.7374562321167385, 0.7948256804953293, 0.9744664033632358], 
             UndirectedEdge[157, 187] -> 
             RGBColor[
              0.656588840938115, 0.7291931341002164, 0.9681680488654731], 
             UndirectedEdge[38, 250] -> 
             RGBColor[
              0.9770092142863354, 0.9428337657309378, 0.5831873792076157], 
             UndirectedEdge[140, 191] -> 
             RGBColor[
              0.6753891788981803, 0.7463384267939157, 0.9682801395479993], 
             UndirectedEdge[204, 261] -> 
             RGBColor[
              0.17918768478614402`, 0.3056679962386074, 0.9335158456129223], 
             UndirectedEdge[337, 354] -> 
             RGBColor[
              0.28225838404285286`, 0.4140018362171884, 0.9393855694561568], 
             UndirectedEdge[300, 314] -> 
             RGBColor[
              0.9079043794586273, 0.7685321222787813, 0.6113544605961532], 
             UndirectedEdge[292, 378] -> 
             RGBColor[
              0.20977255736756456`, 0.3378146365146045, 0.93525760886017], 
             UndirectedEdge[153, 361] -> 
             RGBColor[
              0.3365286408445437, 0.46590592710341294`, 0.9426642853073897], 
             UndirectedEdge[240, 334] -> 
             RGBColor[
              0.2503027734840032, 0.3804144634171059, 0.9375657447089196], 
             UndirectedEdge[52, 260] -> 
             RGBColor[
              0.5977997596730911, 0.6799974627988412, 0.9637251611956289], 
             UndirectedEdge[128, 177] -> 
             RGBColor[
              0.32406082685861914`, 0.45510693327935664`, 0.9418698472250615],
              UndirectedEdge[16, 85] -> 
             RGBColor[
              0.2415839884274967, 0.3712504675198166, 0.9370692227982382], 
             UndirectedEdge[179, 303] -> 
             RGBColor[
              0.27962744891017854`, 0.4112365565818258, 0.9392357415924706], 
             UndirectedEdge[48, 320] -> 
             RGBColor[
              0.5676684575710711, 0.6581064280542859, 0.9600245413086331], 
             UndirectedEdge[136, 320] -> 
             RGBColor[
              0.6642380668783059, 0.7372628617572051, 0.9674177280321361], 
             UndirectedEdge[96, 192] -> 
             RGBColor[
              0.3157006162298024, 0.44584698924097155`, 0.9414110583152703], 
             UndirectedEdge[140, 357] -> 
             RGBColor[
              0.6738075491078213, 0.7451028455808557, 0.9681224974716671], 
             UndirectedEdge[202, 306] -> 
             RGBColor[
              0.913357870811167, 0.6728952265487068, 0.2705007142320376], 
             UndirectedEdge[114, 258] -> 
             RGBColor[
              0.29090557114945215`, 0.42122924819894025`, 0.9399461663762204],
              UndirectedEdge[87, 236] -> 
             RGBColor[
              0.2703304585010046, 0.4014648301985463, 0.938706291742333], 
             UndirectedEdge[116, 362] -> 
             RGBColor[
              0.41044018393094006`, 0.5299243908226783, 0.9473738634754435], 
             UndirectedEdge[36, 64] -> 
             RGBColor[
              0.45931878415001925`, 0.5704587671539738, 0.9509862102607236], 
             UndirectedEdge[245, 304] -> 
             RGBColor[
              0.22449864114749254`, 0.35329268425494775`, 0.9360962375461481],
              UndirectedEdge[187, 218] -> 
             RGBColor[
              0.8769988069965478, 0.9047590594733392, 0.9881301231890498], 
             UndirectedEdge[26, 370] -> 
             RGBColor[
              0.6431647387570222, 0.7183868662092043, 0.9670053375726531], 
             UndirectedEdge[91, 141] -> 
             RGBColor[
              0.3113425799408942, 0.43982647528346147`, 0.9412155979078848], 
             UndirectedEdge[55, 385] -> 
             RGBColor[
              0.4894768493024928, 0.5950665939158499, 0.9533260603680459], 
             UndirectedEdge[179, 231] -> 
             RGBColor[
              0.28916364068982703`, 0.4212596987717169, 0.9397788136067902], 
             UndirectedEdge[94, 177] -> 
             RGBColor[
              0.29101623446385616`, 0.4219899291618881, 0.9399288750630955], 
             UndirectedEdge[225, 383] -> 
             RGBColor[
              0.26867221560749177`, 0.39972191177879235`, 0.938611857262698], 
             UndirectedEdge[37, 134] -> 
             RGBColor[
              0.24206319644531432`, 0.3717541455300861, 0.9370965129859282], 
             UndirectedEdge[255, 341] -> 
             RGBColor[
              0.24102934533176992`, 0.3706675024598044, 0.9370376366944575], 
             UndirectedEdge[206, 278] -> 
             RGBColor[
              0.24198884677049953`, 0.37167599930781414`, 0.937092278881938], 
             UndirectedEdge[131, 279] -> 
             RGBColor[
              0.934057909721427, 0.776268616484077, 0.26579965018330676`], 
             UndirectedEdge[7, 203] -> 
             RGBColor[
              0.3404012849561078, 0.4676562364290735, 0.9429697763439697], 
             UndirectedEdge[101, 151] -> 
             RGBColor[
              0.2883386750076016, 0.41973713317698713`, 0.9397558331587401], 
             UndirectedEdge[200, 296] -> 
             RGBColor[
              0.2860905976760283, 0.41802973572203384`, 0.939603808353314], 
             UndirectedEdge[86, 229] -> 
             RGBColor[
              0.27371625819309475`, 0.4050235203470323, 0.9388991080259558], 
             UndirectedEdge[138, 382] -> 
             RGBColor[
              0.8590618993454652, 0.3914765169996446, 0.2017043627957868], 
             UndirectedEdge[195, 278] -> 
             RGBColor[
              0.24905516487064655`, 0.3791031476615132, 0.9374946952440605], 
             UndirectedEdge[65, 113] -> 
             RGBColor[
              0.6559239156864949, 0.7291861264524664, 0.9676704388099608], 
             UndirectedEdge[249, 270] -> 
             RGBColor[
              0.25957821450255336`, 0.3901635400245296, 0.9380939673531408], 
             UndirectedEdge[319, 388] -> 
             RGBColor[
              0.23247439130222355`, 0.3616757033593372, 0.9365504447183952], 
             UndirectedEdge[138, 256] -> 
             RGBColor[
              0.522325620948562, 0.25191357841785655`, 0.5511492082429574], 
             UndirectedEdge[246, 286] -> 
             RGBColor[
              0.5850263680482788, 0.6724463268342122, 0.9614245811742612], 
             UndirectedEdge[188, 208] -> 
             RGBColor[
              0.25008631824464794`, 0.38018695523648866`, 0.9375534179032552],
              UndirectedEdge[173, 345] -> 
             RGBColor[
              0.21415750276433887`, 0.34242349214821033`, 0.9355073250135709],
              UndirectedEdge[84, 156] -> 
             RGBColor[
              0.18244327672263497`, 0.3090898297803102, 0.9337012467574888], 
             UndirectedEdge[136, 349] -> 
             RGBColor[
              0.5319806271096528, 0.6307093057544687, 0.9563581696523957], 
             UndirectedEdge[117, 346] -> 
             RGBColor[
              0.3472745636844825, 0.4752135053615816, 0.9433490060085041], 
             UndirectedEdge[26, 197] -> 
             RGBColor[
              0.7219321437839568, 0.7790682930787789, 0.8931643392096228], 
             UndirectedEdge[328, 362] -> 
             RGBColor[
              0.35704810596381387`, 0.4836788564514203, 0.9439717674801389], 
             UndirectedEdge[187, 275] -> 
             RGBColor[
              0.9180172404014313, 0.9346976892728417, 0.8827763564020366], 
             UndirectedEdge[20, 121] -> 
             RGBColor[
              0.48042756078829996`, 0.5878320132896839, 0.9525827103922078], 
             UndirectedEdge[198, 302] -> 
             RGBColor[
              0.9068833316004294, 0.9166145009599966, 0.6941933109869335], 
             UndirectedEdge[1, 312] -> 
             RGBColor[
              0.4114701041040899, 0.5305547297160472, 0.9475118048057347], 
             UndirectedEdge[89, 292] -> 
             RGBColor[
              0.21480075229645693`, 0.3430995881908423, 0.9355439571228226], 
             UndirectedEdge[304, 315] -> 
             RGBColor[
              0.23118633013209117`, 0.360321869401733, 0.9364770915402718], 
             UndirectedEdge[21, 64] -> 
             RGBColor[
              0.3559387070583645, 0.4827179508795304, 0.9439010775628867], 
             UndirectedEdge[201, 351] -> 
             RGBColor[
              0.26108538890678307`, 0.3917476758837515, 0.9381797987057969], 
             UndirectedEdge[17, 218] -> 
             RGBColor[
              0.7227901892843811, 0.7824598484159166, 0.9739304322567687], 
             UndirectedEdge[266, 365] -> 
             RGBColor[
              0.25561932448523794`, 0.3860024956082064, 0.9378685144233075], 
             UndirectedEdge[112, 180] -> 
             RGBColor[
              0.34759559659056605`, 0.4754915679292482, 0.9433694619414015], 
             UndirectedEdge[247, 289] -> 
             RGBColor[
              0.9023804239029701, 0.648813195238765, 0.2402147401558417], 
             UndirectedEdge[15, 45] -> 
             RGBColor[
              0.29968000514429743`, 0.4323130645893829, 0.9403777050049051], 
             UndirectedEdge[57, 92] -> 
             RGBColor[
              0.2804356326225079, 0.4120860089052909, 0.9392817664592872], 
             UndirectedEdge[53, 86] -> 
             RGBColor[
              0.2948901577623302, 0.4272786312970708, 0.9401049302824465], 
             UndirectedEdge[114, 154] -> 
             RGBColor[
              0.3795179550306004, 0.5031411103456188, 0.9454035263933673], 
             UndirectedEdge[71, 237] -> 
             RGBColor[
              0.7247695222504801, 0.7843485609125668, 0.9737619050151656], 
             UndirectedEdge[241, 375] -> 
             RGBColor[
              0.2729036444443398, 0.40416941177440335`, 0.9388528308751185], 
             UndirectedEdge[100, 282] -> 
             RGBColor[
              0.5117379294109875, 0.6123392626277626, 0.9553276443786378], 
             UndirectedEdge[55, 146] -> 
             RGBColor[
              0.4694319452875655, 0.5787932378238967, 0.951748052097088], 
             UndirectedEdge[309, 319] -> 
             RGBColor[
              0.25618706106620875`, 0.38659922275138503`, 0.9379008461817029],
              UndirectedEdge[13, 302] -> 
             RGBColor[
              0.9755285816369456, 0.9706262250120263, 0.6756345411379316], 
             UndirectedEdge[110, 348] -> 
             RGBColor[
              0.25926658322907375`, 0.3898359957975386, 0.9380762204131332], 
             UndirectedEdge[217, 363] -> 
             RGBColor[
              0.8426690815936368, 0.3225184221692448, 0.1882402931746939], 
             UndirectedEdge[39, 380] -> 
             RGBColor[
              0.2692913647455158, 0.4003726767791782, 0.9386471168901593], 
             UndirectedEdge[248, 304] -> 
             RGBColor[
              0.2176531615259033, 0.3460976511441812, 0.9357063976086782], 
             UndirectedEdge[204, 400] -> 
             RGBColor[
              0.2842689537951664, 0.40863855928315673`, 0.939773820202813], 
             UndirectedEdge[69, 168] -> 
             RGBColor[
              0.5791845558214077, 0.6688214100579597, 0.9603057503889199], 
             UndirectedEdge[68, 86] -> 
             RGBColor[
              0.28863048877409425`, 0.42069932230449786`, 0.9397484513939167],
              UndirectedEdge[175, 264] -> 
             RGBColor[
              0.18448157797338877`, 0.31123221363061604`, 0.9338173249983228],
              UndirectedEdge[1, 92] -> 
             RGBColor[
              0.3238234376355826, 0.4529521291016748, 0.9419260903719718], 
             UndirectedEdge[368, 393] -> 
             RGBColor[
              0.21780075210083538`, 0.3462527781962177, 0.93571480267358], 
             UndirectedEdge[332, 361] -> 
             RGBColor[
              0.4414240641856033, 0.5547544143941453, 0.9499025740169657], 
             UndirectedEdge[80, 203] -> 
             RGBColor[
              0.31290698696191654`, 0.4438420574101029, 0.9412178639880329], 
             UndirectedEdge[20, 347] -> 
             RGBColor[
              0.3438545327447645, 0.469598113054395, 0.9432282288718172], 
             UndirectedEdge[18, 311] -> 
             RGBColor[
              0.7322903023542322, 0.7896729975900088, 0.9664706721730203], 
             UndirectedEdge[170, 282] -> 
             RGBColor[
              0.5459157043281511, 0.6419423334360943, 0.9575054219741398], 
             UndirectedEdge[198, 323] -> 
             RGBColor[
              0.828349936933913, 0.8659677710237936, 0.9834899505331167], 
             UndirectedEdge[168, 357] -> 
             RGBColor[
              0.6729202964028389, 0.7444097170243531, 0.9680340644138824], 
             UndirectedEdge[180, 326] -> 
             RGBColor[
              0.3528301288862901, 0.48002545670856134`, 0.9437030017105699], 
             UndirectedEdge[18, 340] -> 
             RGBColor[
              0.9694923470519816, 0.9738780487256253, 0.770900506424754], 
             UndirectedEdge[74, 340] -> 
             RGBColor[
              0.9092258023331339, 0.9260683158029884, 0.7736525641500547], 
             UndirectedEdge[173, 204] -> 
             RGBColor[
              0.20264730553141047`, 0.33032554506774736`, 0.9348518363089665],
              UndirectedEdge[26, 30] -> 
             RGBColor[
              0.31701994287924884`, 0.4369570883961569, 0.9418741496415883], 
             UndirectedEdge[169, 240] -> 
             RGBColor[
              0.22995248947003588`, 0.35902502463589653`, 0.9364068261398715],
              UndirectedEdge[95, 371] -> 
             RGBColor[
              0.27691206805261726`, 0.40838251913543877`, 0.9390811046696785],
              UndirectedEdge[65, 356] -> 
             RGBColor[
              0.5168552955479615, 0.6186454388483807, 0.9551078886503179], 
             UndirectedEdge[264, 310] -> 
             RGBColor[
              0.18630458251799184`, 0.3131483069921579, 0.9339211424102444], 
             UndirectedEdge[96, 114] -> 
             RGBColor[
              0.3078946845637386, 0.4390858835693603, 0.940913671252023], 
             UndirectedEdge[244, 308] -> 
             RGBColor[
              0.2605622771689302, 0.3911978522800683, 0.9381500082662007], 
             UndirectedEdge[187, 298] -> 
             RGBColor[
              0.8336819864556111, 0.8702194025777671, 0.983998526176473], 
             UndirectedEdge[58, 228] -> 
             RGBColor[
              0.3333340850867448, 0.46222040417284493`, 0.9424943639948453], 
             UndirectedEdge[36, 82] -> 
             RGBColor[
              0.4494472254875384, 0.5619085191994977, 0.950357203271827], 
             UndirectedEdge[72, 355] -> 
             RGBColor[
              0.2293238377834227, 0.358364271854447, 0.9363710253563257], 
             UndirectedEdge[22, 350] -> 
             RGBColor[
              0.36253057369193453`, 0.4869086502715662, 0.9443767178010922], 
             UndirectedEdge[58, 192] -> 
             RGBColor[
              0.32165036846239214`, 0.45210055607350297`, 0.9417498879030466],
              UndirectedEdge[3, 174] -> 
             RGBColor[
              0.5493425209245979, 0.6414387311936623, 0.9591931799908751], 
             UndirectedEdge[44, 54] -> 
             RGBColor[
              0.3749740145051137, 0.4982078184475008, 0.9451505160427869], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.416297218948796, 0.5331956497034136, 0.948244914168578], 
             UndirectedEdge[170, 271] -> 
             RGBColor[
              0.37587875919358854`, 0.49980798052879155`, 0.9451782688612774],
              UndirectedEdge[192, 201] -> 
             RGBColor[
              0.3104580154232146, 0.4403366833931581, 0.941112499955068], 
             UndirectedEdge[274, 395] -> 
             RGBColor[
              0.2518980358087536, 0.3820911852658918, 0.9376565925383351], 
             UndirectedEdge[208, 284] -> 
             RGBColor[
              0.23854240400840393`, 0.3680535694477596, 0.9368960090651918], 
             UndirectedEdge[237, 320] -> 
             RGBColor[
              0.644156525821959, 0.7209597620645476, 0.9658368355590718], 
             UndirectedEdge[119, 380] -> 
             RGBColor[
              0.25299451614994406`, 0.383243655625352, 0.9377190354716685], 
             UndirectedEdge[342, 398] -> 
             RGBColor[
              0.7713918010534688, 0.8216082690775031, 0.9746694433091629], 
             UndirectedEdge[90, 264] -> 
             RGBColor[
              0.44791840801160593`, 0.5435825734144455, 0.9527225707160447], 
             UndirectedEdge[212, 367] -> 
             RGBColor[
              0.21510593499852879`, 0.3434203545604207, 0.9355613368262283], 
             UndirectedEdge[92, 284] -> 
             RGBColor[
              0.26583096592771405`, 0.3967355782197115, 0.9384500522966869], 
             UndirectedEdge[267, 342] -> 
             RGBColor[
              0.5872785724074823, 0.6758182275354083, 0.9606518669736626], 
             UndirectedEdge[107, 297] -> 
             RGBColor[
              0.892928350056968, 0.6310869487653001, 0.5801992997291281], 
             UndirectedEdge[163, 245] -> 
             RGBColor[
              0.2374360489235272, 0.36689072010659024`, 0.9368330037798137], 
             UndirectedEdge[72, 200] -> 
             RGBColor[
              0.24919308184682543`, 0.37924810714791846`, 0.937502549411824], 
             UndirectedEdge[254, 286] -> 
             RGBColor[
              0.5978806349455185, 0.6831403582378857, 0.9623651309393161], 
             UndirectedEdge[269, 307] -> 
             RGBColor[
              0.9891494518709179, 0.9878632201941573, 0.6900803930330166], 
             UndirectedEdge[240, 304] -> 
             RGBColor[
              0.22915247220042573`, 0.35818415576151175`, 0.9363612663398866],
              UndirectedEdge[228, 332] -> 
             RGBColor[
              0.44753939238477464`, 0.5600512043149352, 0.9502922373222444], 
             UndirectedEdge[104, 109] -> 
             RGBColor[
              0.9639852685830836, 0.8836832833010115, 0.5065761886025747], 
             UndirectedEdge[28, 372] -> 
             RGBColor[
              0.2698833093261751, 0.4009948480649053, 0.9386808272583244], 
             UndirectedEdge[28, 362] -> 
             RGBColor[
              0.34647407000563907`, 0.4726287790194402, 0.9433672519077005], 
             UndirectedEdge[209, 227] -> 
             RGBColor[
              0.24347750032410487`, 0.3732406685787401, 0.9371770554995502], 
             UndirectedEdge[245, 371] -> 
             RGBColor[
              0.25097222698134913`, 0.38111810148861974`, 0.9376038690952258],
              UndirectedEdge[308, 397] -> 
             RGBColor[
              0.25521896402580857`, 0.3855816913810268, 0.9378457144874233], 
             UndirectedEdge[58, 87] -> 
             RGBColor[
              0.29447485481202706`, 0.42684212156457424`, 0.9400812793938123],
              UndirectedEdge[154, 332] -> 
             RGBColor[
              0.47868981834297064`, 0.5870321376139921, 0.9522771149190605], 
             UndirectedEdge[97, 180] -> 
             RGBColor[
              0.40427723483543804`, 0.5245863540749827, 0.9469811658087601], 
             UndirectedEdge[202, 300] -> 
             RGBColor[
              0.873168201892003, 0.5137197571930974, 0.21575357463755512`], 
             UndirectedEdge[25, 317] -> 
             RGBColor[
              0.9196690890458292, 0.6829063077266104, 0.4996382373528887], 
             UndirectedEdge[93, 128] -> 
             RGBColor[
              0.2857256322546389, 0.41603117628641406`, 0.9396421556226617], 
             UndirectedEdge[68, 178] -> 
             RGBColor[
              0.2603565331566741, 0.3909816022782634, 0.9381382914490737], 
             UndirectedEdge[271, 273] -> 
             RGBColor[
              0.2911126400044641, 0.42330822062509427`, 0.9398898062344726], 
             UndirectedEdge[149, 318] -> 
             RGBColor[
              0.22201805165799737`, 0.3506854274230307, 0.9359549716444248], 
             UndirectedEdge[42, 358] -> 
             RGBColor[
              0.9504012676368335, 0.9272297470138823, 0.6629122325696076], 
             UndirectedEdge[155, 170] -> 
             RGBColor[
              0.3747576276064379, 0.498629600146848, 0.9451144220759548], 
             UndirectedEdge[193, 338] -> 
             RGBColor[
              0.9083139927934867, 0.9256835176042191, 0.801309811633953], 
             UndirectedEdge[79, 109] -> 
             RGBColor[
              0.79245120355282, 0.8352543310125031, 0.854215095221335], 
             UndirectedEdge[173, 175] -> 
             RGBColor[
              0.20264987627198583`, 0.3303282470790865, 0.9348519827088393], 
             UndirectedEdge[95, 178] -> 
             RGBColor[
              0.2628834870920424, 0.39363759108246865`, 0.9382821977373995], 
             UndirectedEdge[243, 348] -> 
             RGBColor[
              0.27566358738232355`, 0.40707028679271356`, 0.9390100055424669],
              UndirectedEdge[56, 83] -> 
             RGBColor[
              0.4019083501795848, 0.5225345452496872, 0.9468302225732115], 
             UndirectedEdge[205, 207] -> 
             RGBColor[
              0.967562165289962, 0.8957834071543473, 0.4992706546503005], 
             UndirectedEdge[74, 302] -> 
             RGBColor[
              0.9059752552459537, 0.9158904255240137, 0.6941066978535942], 
             UndirectedEdge[179, 196] -> 
             RGBColor[
              0.2837836367777321, 0.41560497354815545`, 0.9394724303429989], 
             UndirectedEdge[174, 338] -> 
             RGBColor[
              0.8614468790047858, 0.8890515325777966, 0.796643588235805], 
             UndirectedEdge[159, 167] -> 
             RGBColor[
              0.30749203096032607`, 0.43842628345076595`, 0.9408993959616536],
              UndirectedEdge[251, 356] -> 
             RGBColor[
              0.6703471241239707, 0.7405191581131181, 0.9690711033483659], 
             UndirectedEdge[238, 277] -> 
             RGBColor[
              0.24351796868213066`, 0.3732832033888673, 0.9371793601126722], 
             UndirectedEdge[163, 164] -> 
             RGBColor[
              0.24375587866941067`, 0.373533261869863, 0.9371929087344915], 
             UndirectedEdge[213, 230] -> 
             RGBColor[
              0.939912673270707, 0.7956677722978341, 0.2903688589282392], 
             UndirectedEdge[246, 343] -> 
             RGBColor[
              0.5830017143905886, 0.6708646520088869, 0.9612227826191269], 
             UndirectedEdge[53, 95] -> 
             RGBColor[
              0.2855112454690256, 0.4174207998194225, 0.9395708151022], 
             UndirectedEdge[139, 184] -> 
             RGBColor[
              0.21446679583023515`, 0.34274857877078024`, 0.9355249387961155],
              UndirectedEdge[101, 308] -> 
             RGBColor[
              0.26096510566357906`, 0.39162125056874597`, 0.9381729487530396],
              UndirectedEdge[3, 52] -> 
             RGBColor[
              0.3783625716146186, 0.5021403753019544, 0.9453299063837663], 
             UndirectedEdge[136, 286] -> 
             RGBColor[
              0.6724159966518739, 0.7436515226508849, 0.9682328276448666], 
             UndirectedEdge[164, 169] -> 
             RGBColor[
              0.23161848816298614`, 0.3607760948926053, 0.9365017023008109], 
             UndirectedEdge[14, 102] -> 
             RGBColor[
              0.9068270565903578, 0.5698348658899638, 0.39664654648642544`], 
             UndirectedEdge[232, 281] -> 
             RGBColor[
              0.5787753460534887, 0.6689149253152545, 0.9599824618467317], 
             UndirectedEdge[56, 349] -> 
             RGBColor[
              0.44815708600119175`, 0.5625928756893122, 0.949777151123613], 
             UndirectedEdge[225, 324] -> 
             RGBColor[
              0.2685328797360218, 0.39957546094347285`, 0.9386039222909468], 
             UndirectedEdge[5, 272] -> 
             RGBColor[
              0.744229977263282, 0.800290827008182, 0.9750955199196911], 
             UndirectedEdge[68, 371] -> 
             RGBColor[
              0.27438511411724903`, 0.40572653033123346`, 0.9389371983813526],
              UndirectedEdge[151, 397] -> 
             RGBColor[
              0.28259253336983103`, 0.413697573989268, 0.9394285988931239], 
             UndirectedEdge[1, 356] -> 
             RGBColor[
              0.43918071918933627`, 0.5530514553912338, 0.949693285932573], 
             UndirectedEdge[96, 115] -> 
             RGBColor[
              0.262758793949384, 0.3935065306835328, 0.9382750966473921], 
             UndirectedEdge[328, 347] -> 
             RGBColor[
              0.29474363512034735`, 0.42706072191761096`, 0.940098925902251], 
             UndirectedEdge[80, 159] -> 
             RGBColor[
              0.3329254963503931, 0.4627850644418876, 0.9424346961263579], 
             UndirectedEdge[50, 121] -> 
             RGBColor[
              0.5036718866822538, 0.607942553625398, 0.9540700424119916], 
             UndirectedEdge[108, 342] -> 
             RGBColor[
              0.48546363914421214`, 0.5908319937486516, 0.9532799343430639], 
             UndirectedEdge[178, 315] -> 
             RGBColor[
              0.24363133500537287`, 0.37340235858243487`, 0.9371858161570703],
              UndirectedEdge[146, 228] -> 
             RGBColor[
              0.45159420731101624`, 0.5633430857393887, 0.9506114472065146], 
             UndirectedEdge[63, 152] -> 
             RGBColor[
              0.5710886094431091, 0.5911007265104762, 0.6136429928057057], 
             UndirectedEdge[43, 137] -> 
             RGBColor[
              0.22449567090087896`, 0.35328956233743236`, 0.9360960683949977],
              UndirectedEdge[97, 141] -> 
             RGBColor[
              0.401174197469898, 0.5218986590721447, 0.9467834430117361], 
             UndirectedEdge[25, 207] -> 
             RGBColor[
              0.8942834665962583, 0.5873379716371798, 0.2323719540995589], 
             UndirectedEdge[214, 310] -> 
             RGBColor[
              0.5831756221385668, 0.6483250855590861, 0.9230305133548782], 
             UndirectedEdge[37, 87] -> 
             RGBColor[
              0.2699691213947309, 0.4010850419897568, 0.9386857141286811], 
             UndirectedEdge[146, 262] -> 
             RGBColor[
              0.736987048840004, 0.7937027834714817, 0.9726540973253948], 
             UndirectedEdge[322, 364] -> 
             RGBColor[
              0.428972946302528, 0.5444804947900268, 0.9489681159313363], 
             UndirectedEdge[219, 311] -> 
             RGBColor[
              0.48328094147507245`, 0.5912218175992272, 0.9525107826182344], 
             UndirectedEdge[5, 260] -> 
             RGBColor[
              0.8251985302055844, 0.863544075950503, 0.9831657085828327], 
             UndirectedEdge[204, 389] -> 
             RGBColor[
              0.17900756331513207`, 0.305478677152213, 0.9335055879616141], 
             UndirectedEdge[275, 279] -> 
             RGBColor[
              0.9688751403565641, 0.9066136951652177, 0.5278514920501343], 
             UndirectedEdge[78, 289] -> 
             RGBColor[
              0.8697986288874946, 0.4756199934349731, 0.21204915614425965`], 
             UndirectedEdge[163, 329] -> 
             RGBColor[
              0.2400560374603316, 0.3696444941756393, 0.936982208251059], 
             UndirectedEdge[47, 181] -> 
             RGBColor[
              0.5006021052009016, 0.6049229030605833, 0.9539741177513421], 
             UndirectedEdge[267, 291] -> 
             RGBColor[
              0.6338452626420983, 0.7127939223878283, 0.964884724751121], 
             UndirectedEdge[28, 301] -> 
             RGBColor[
              0.27255350960952185`, 0.40380139786317903`, 0.9388328912142536],
              UndirectedEdge[174, 193] -> 
             RGBColor[
              0.7754724977883137, 0.8245433157037161, 0.9782504569369469], 
             UndirectedEdge[60, 263] -> 
             RGBColor[
              0.3098059764171655, 0.4384458415430197, 0.9411195068336586], 
             UndirectedEdge[122, 385] -> 
             RGBColor[
              0.510754315643456, 0.6134960658238386, 0.9546818417083673], 
             UndirectedEdge[282, 350] -> 
             RGBColor[
              0.5398022619922347, 0.6366471769552697, 0.9571158788344], 
             UndirectedEdge[142, 306] -> 
             RGBColor[
              0.8959800446329425, 0.5393216395308846, 0.25385968825832217`], 
             UndirectedEdge[6, 289] -> 
             RGBColor[
              0.9455504255792939, 0.808391434737298, 0.3768472415142159], 
             UndirectedEdge[3, 117] -> 
             RGBColor[
              0.35979838664313185`, 0.4860610113427193, 0.9441470129330474], 
             UndirectedEdge[6, 132] -> 
             RGBColor[
              0.896284952197167, 0.9156286210821021, 0.7489609820272407], 
             UndirectedEdge[22, 394] -> 
             RGBColor[
              0.32559317401626164`, 0.45491533120018696`, 0.9420230993562184],
              UndirectedEdge[11, 391] -> 
             RGBColor[
              0.8719267260498035, 0.4460000576161881, 0.2122170074273244], 
             UndirectedEdge[34, 249] -> 
             RGBColor[
              0.2909291460215572, 0.4227877812822719, 0.9398913506685179], 
             UndirectedEdge[269, 306] -> 
             RGBColor[
              0.9817175223804617, 0.9496479498761543, 0.4126513364277588], 
             UndirectedEdge[69, 394] -> 
             RGBColor[
              0.42354328649608, 0.5403260059804602, 0.948470615599907], 
             UndirectedEdge[361, 369] -> 
             RGBColor[
              0.30654023496768024`, 0.43518917662023243`, 0.9409270894573605],
              UndirectedEdge[85, 184] -> 
             RGBColor[
              0.22953519250719354`, 0.35858641906979366`, 0.9363830616951732],
              UndirectedEdge[73, 96] -> 
             RGBColor[
              0.26501373249139615`, 0.3958766140625488, 0.9384035120614771], 
             UndirectedEdge[71, 382] -> 
             RGBColor[
              0.8849504676641144, 0.7666705508963009, 0.612411028914603], 
             UndirectedEdge[122, 165] -> 
             RGBColor[
              0.48941818004964077`, 0.5961744297668246, 0.9530021829575823], 
             UndirectedEdge[321, 331] -> 
             RGBColor[
              0.634939466831133, 0.7117908877119044, 0.9662504402131629], 
             UndirectedEdge[296, 374] -> 
             RGBColor[
              0.2888126336637139, 0.4208907681321412, 0.9397588242759214], 
             UndirectedEdge[66, 297] -> 
             RGBColor[
              0.9597109537164616, 0.9397882388587341, 0.661988741969209], 
             UndirectedEdge[75, 145] -> 
             RGBColor[
              0.24110109065239455`, 0.37074291134069687`, 0.9370417224843294],
              UndirectedEdge[105, 239] -> 
             RGBColor[
              0.37092951443948974`, 0.4957022347731742, 0.9448562785533615], 
             UndirectedEdge[92, 354] -> 
             RGBColor[
              0.2837186388686095, 0.41553665662456213`, 0.9394687288082302], 
             UndirectedEdge[188, 369] -> 
             RGBColor[
              0.26226993371413826`, 0.39299270758076044`, 0.9382472567801988],
              UndirectedEdge[170, 251] -> 
             RGBColor[
              0.6336427393204518, 0.7104942073432939, 0.966244231440377], 
             UndirectedEdge[53, 68] -> 
             RGBColor[
              0.28298429153365734`, 0.4147648110152172, 0.9394269088138741], 
             UndirectedEdge[274, 318] -> 
             RGBColor[
              0.2272727207343431, 0.3562084177875322, 0.9362542172747363], 
             UndirectedEdge[179, 359] -> 
             RGBColor[
              0.2576056390091489, 0.3880902381124516, 0.9379816320969553], 
             UndirectedEdge[20, 328] -> 
             RGBColor[
              0.3585480828066595, 0.484978061001665, 0.9440673446781876], 
             UndirectedEdge[307, 352] -> 
             RGBColor[
              0.9896970551583855, 0.989034488254865, 0.7496836314580985], 
             UndirectedEdge[6, 216] -> 
             RGBColor[
              0.8262245586177389, 0.8608969091391403, 0.7419780167468455], 
             UndirectedEdge[297, 385] -> 
             RGBColor[
              0.76103003285282, 0.8129579010796052, 0.9674643990261943], 
             UndirectedEdge[40, 348] -> 
             RGBColor[
              0.3011336768698887, 0.43101491807386594`, 0.9405639649079968], 
             UndirectedEdge[229, 329] -> 
             RGBColor[
              0.2410174933653264, 0.37065504529161414`, 0.937036961742502], 
             UndirectedEdge[6, 213] -> 
             RGBColor[
              0.9521578283629528, 0.8364523308595698, 0.38226017426140096`], 
             UndirectedEdge[189, 374] -> 
             RGBColor[
              0.2883252349784382, 0.42037848121105487`, 0.9397310676418367], 
             UndirectedEdge[97, 140] -> 
             RGBColor[
              0.5571047214907582, 0.6505692358866151, 0.9586689069541604], 
             UndirectedEdge[34, 386] -> 
             RGBColor[
              0.32582607560218535`, 0.4566359030170521, 0.9419823273140535], 
             UndirectedEdge[162, 313] -> 
             RGBColor[
              0.26444617460999714`, 0.3952800747439503, 0.938371190479758], 
             UndirectedEdge[258, 392] -> 
             RGBColor[
              0.25044123686096187`, 0.3805599972053746, 0.9375736299933992], 
             UndirectedEdge[45, 273] -> 
             RGBColor[
              0.2854682454604019, 0.41737560408400093`, 0.9395683663153217], 
             UndirectedEdge[226, 393] -> 
             RGBColor[
              0.2307270128999809, 0.3598390978683905, 0.9364509341034022], 
             UndirectedEdge[88, 168] -> 
             RGBColor[
              0.8302321284771527, 0.8662542155842119, 0.8889737374567761], 
             UndirectedEdge[188, 327] -> 
             RGBColor[
              0.2928390260811543, 0.4242124195155595, 0.9400214534598996], 
             UndirectedEdge[59, 349] -> 
             RGBColor[
              0.38969866664907243`, 0.5119591310520951, 0.9460522323352465], 
             UndirectedEdge[260, 398] -> 
             RGBColor[
              0.8741897182555676, 0.9025122258100744, 0.9845069042800476], 
             UndirectedEdge[248, 353] -> 
             RGBColor[
              0.21329376874399575`, 0.34151565292892977`, 0.9354581366388923],
              UndirectedEdge[30, 389] -> 
             RGBColor[
              0.17900757935671766`, 0.3054786940129366, 0.9335055888751587], 
             UndirectedEdge[216, 311] -> 
             RGBColor[
              0.5892378065656463, 0.6771523472031584, 0.9609814583426657], 
             UndirectedEdge[66, 307] -> 
             RGBColor[
              0.9790114308840521, 0.9540083964475, 0.6215212155905427], 
             UndirectedEdge[94, 225] -> 
             RGBColor[
              0.2586160366315361, 0.3891522300764899, 0.9380391727468009], 
             UndirectedEdge[177, 324] -> 
             RGBColor[
              0.3009330775683418, 0.4324131600288711, 0.9404936246072413], 
             UndirectedEdge[79, 320] -> 
             RGBColor[
              0.6503499887449748, 0.725987894277777, 0.9663244076477739], 
             UndirectedEdge[133, 234] -> 
             RGBColor[
              0.31799880832538563`, 0.4487941940432452, 0.9415224703076799], 
             UndirectedEdge[35, 195] -> 
             RGBColor[
              0.2633678783864708, 0.39414671704509485`, 0.9383097831050244], 
             UndirectedEdge[34, 86] -> 
             RGBColor[
              0.30641268277319833`, 0.4390619601211778, 0.940773115180684], 
             UndirectedEdge[98, 131] -> 
             RGBColor[
              0.9500181408117219, 0.8331560489585412, 0.3119185917864623], 
             UndirectedEdge[173, 261] -> 
             RGBColor[
              0.2029079903175545, 0.3305995413063548, 0.9348666819218888], 
             UndirectedEdge[103, 331] -> 
             RGBColor[
              0.39832931347278433`, 0.519434563541872, 0.9466021695190721], 
             UndirectedEdge[135, 322] -> 
             RGBColor[
              0.5058470879872912, 0.6097084800365293, 0.954241282226749], 
             UndirectedEdge[50, 181] -> 
             RGBColor[
              0.5107299622168331, 0.6136726173070488, 0.9546256799726562], 
             UndirectedEdge[35, 153] -> 
             RGBColor[
              0.2992359056961653, 0.4310433224437109, 0.940381814697533], 
             UndirectedEdge[121, 362] -> 
             RGBColor[
              0.4789275839454543, 0.5865328087394392, 0.9524871331941591], 
             UndirectedEdge[84, 152] -> 
             RGBColor[
              0.18127159018880934`, 0.30785831294404253`, 0.9336345209427424],
              UndirectedEdge[295, 345] -> 
             RGBColor[
              0.22216737223106828`, 0.3508423728127994, 0.9359634752301611], 
             UndirectedEdge[22, 266] -> 
             RGBColor[
              0.27365816407618504`, 0.40496245974678047`, 0.9388957996519403],
              UndirectedEdge[271, 335] -> 
             RGBColor[
              0.2936530311811995, 0.4259783328219468, 0.9400344777538158], 
             UndirectedEdge[175, 261] -> 
             RGBColor[
              0.1791902555267194, 0.3056706982499465, 0.9335159920127951], 
             UndirectedEdge[59, 254] -> 
             RGBColor[
              0.401764791398701, 0.521970513340684, 0.9469425623795822], 
             UndirectedEdge[53, 270] -> 
             RGBColor[
              0.26941555401375766`, 0.4005032075741548, 0.9386541892852642], 
             UndirectedEdge[214, 300] -> 
             RGBColor[
              0.9368849358196452, 0.7904007327583793, 0.5711375264891978], 
             UndirectedEdge[3, 386] -> 
             RGBColor[
              0.35472139925516205`, 0.48166358004406556`, 0.9438235117860897],
              UndirectedEdge[299, 336] -> 
             RGBColor[
              0.2125676316732109, 0.34075243682778544`, 0.9354167842069347], 
             UndirectedEdge[110, 351] -> 
             RGBColor[
              0.25066121746090764`, 0.3807912107634932, 0.9375861575631339], 
             UndirectedEdge[172, 328] -> 
             RGBColor[
              0.3054309232922502, 0.438293739399488, 0.9407075511532149], 
             UndirectedEdge[185, 302] -> 
             RGBColor[
              0.905483758897311, 0.5759228028237954, 0.28769672462851575`], 
             UndirectedEdge[370, 391] -> 
             RGBColor[
              0.8258037070409253, 0.5129958576116641, 0.5754614637475668], 
             UndirectedEdge[50, 364] -> 
             RGBColor[
              0.4018386991300539, 0.5224516905515073, 0.9468320085978967], 
             UndirectedEdge[73, 195] -> 
             RGBColor[
              0.2444053413712617, 0.37421588834782205`, 0.937229894674568], 
             UndirectedEdge[80, 332] -> 
             RGBColor[
              0.4308190028061351, 0.5455688432531333, 0.9492268288835535], 
             UndirectedEdge[5, 267] -> 
             RGBColor[
              0.7063209858486378, 0.7695859535146778, 0.9720624004607035], 
             UndirectedEdge[136, 246] -> 
             RGBColor[
              0.5311924849620417, 0.6300266566393842, 0.9563079499316767], 
             UndirectedEdge[59, 246] -> 
             RGBColor[
              0.38891052450146135`, 0.5112764819370106, 0.9460020126145274], 
             UndirectedEdge[177, 200] -> 
             RGBColor[
              0.2962840776702533, 0.42752676637236176`, 0.9402288709406241], 
             UndirectedEdge[17, 157] -> 
             RGBColor[
              0.5023802232259484, 0.6068939230427937, 0.9539683579331921], 
             UndirectedEdge[151, 386] -> 
             RGBColor[
              0.3275993292124569, 0.45817180616795133`, 0.9420953174660733], 
             UndirectedEdge[4, 188] -> 
             RGBColor[
              0.24964120798061978`, 0.37971911612737436`, 0.9375280695322004],
              UndirectedEdge[241, 255] -> 
             RGBColor[
              0.2757184631493581, 0.40712796470319146`, 0.9390131306362182], 
             UndirectedEdge[62, 345] -> 
             RGBColor[
              0.19050782677282135`, 0.3175661832050619, 0.9341605109524143], 
             UndirectedEdge[57, 114] -> 
             RGBColor[
              0.3010426520782409, 0.43188396298315035`, 0.9405234581386476], 
             UndirectedEdge[32, 137] -> 
             RGBColor[
              0.21892075175740905`, 0.34742996884735633`, 0.9357785849971308],
              UndirectedEdge[152, 175] -> 
             RGBColor[
              0.181274153781999, 0.307861007443026, 0.9336346669355821], 
             UndirectedEdge[99, 235] -> 
             RGBColor[
              0.8591106393434069, 0.8900471270857477, 0.9483188623764983], 
             UndirectedEdge[156, 256] -> 
             RGBColor[
              0.20563395231845213`, 0.3334647002052716, 0.9350219214251405], 
             UndirectedEdge[48, 286] -> 
             RGBColor[
              0.5758463873446392, 0.6644950889479655, 0.9608396409213635], 
             UndirectedEdge[61, 262] -> 
             RGBColor[
              0.9659943820446136, 0.9709682059989204, 0.7529333373497976], 
             UndirectedEdge[146, 385] -> 
             RGBColor[
              0.5553761412741389, 0.6499183967532158, 0.95814039073239], 
             UndirectedEdge[29, 150] -> 
             RGBColor[
              0.2555149933709343, 0.38589283699209853`, 0.937862572920692], 
             UndirectedEdge[141, 220] -> 
             RGBColor[
              0.4177492311275311, 0.5356546049090093, 0.9480055136475012], 
             UndirectedEdge[152, 242] -> 
             RGBColor[
              0.5509815030039178, 0.5121510355041116, 0.5934630978551525], 
             UndirectedEdge[95, 151] -> 
             RGBColor[
              0.2988070240901653, 0.4307400317944288, 0.9403519901524575], 
             UndirectedEdge[252, 293] -> 
             RGBColor[
              0.21778209463220533`, 0.3462331680137357, 0.9357137401583427], 
             UndirectedEdge[93, 390] -> 
             RGBColor[
              0.2557686929307827, 0.3861594913149804, 0.9378770207353105], 
             UndirectedEdge[229, 249] -> 
             RGBColor[
              0.2582327214414536, 0.38874934150812634`, 0.9380173435137897], 
             UndirectedEdge[96, 153] -> 
             RGBColor[
              0.3021711245350493, 0.4341284235470012, 0.9405489710681403], 
             UndirectedEdge[202, 217] -> 
             RGBColor[
              0.8395826476787889, 0.30525515205179155`, 0.18553769416040178`],
              UndirectedEdge[163, 304] -> 
             RGBColor[
              0.23203584179739814`, 0.3612147600241211, 0.9365254699728711], 
             UndirectedEdge[18, 323] -> 
             RGBColor[
              0.8877084052982851, 0.9130534285104475, 0.9806512796744769], 
             UndirectedEdge[152, 264] -> 
             RGBColor[
              0.186823590274237, 0.31369381705096394`, 0.9339506991341594], 
             UndirectedEdge[23, 169] -> 
             RGBColor[
              0.21705819820147026`, 0.34547230696734843`, 0.9356725153275212],
              UndirectedEdge[290, 342] -> 
             RGBColor[
              0.5042459583975736, 0.6071002946590989, 0.9544767271173353], 
             UndirectedEdge[285, 330] -> 
             RGBColor[
              0.23174352854992997`, 0.3609075202673017, 0.9365088231658666], 
             UndirectedEdge[55, 192] -> 
             RGBColor[
              0.3740111987150174, 0.498371434802681, 0.9450526407503718], 
             UndirectedEdge[161, 170] -> 
             RGBColor[
              0.43820314080929235`, 0.5539712686639211, 0.9491428945379133], 
             UndirectedEdge[42, 205] -> 
             RGBColor[
              0.9637471875060623, 0.9705535185426564, 0.8607371274369169], 
             UndirectedEdge[267, 398] -> 
             RGBColor[
              0.7553121738986209, 0.8085541033742493, 0.9734035961579184], 
             UndirectedEdge[32, 199] -> 
             RGBColor[
              0.22104408708317058`, 0.349661728901967, 0.9358995058027398], 
             UndirectedEdge[154, 385] -> 
             RGBColor[
              0.5027895372841396, 0.606597375130399, 0.9541743330742887], 
             UndirectedEdge[91, 190] -> 
             RGBColor[
              0.25186209923856306`, 0.38205341365211143`, 0.9376545460038261],
              UndirectedEdge[94, 380] -> 
             RGBColor[
              0.2628073165498582, 0.39355753101314184`, 0.9382778599377064], 
             UndirectedEdge[119, 288] -> 
             RGBColor[
              0.2427621793276949, 0.37248882085754254`, 0.9371363190270272], 
             UndirectedEdge[65, 251] -> 
             RGBColor[
              0.6688240146939028, 0.7392826292624911, 0.9689511985946974], 
             UndirectedEdge[198, 216] -> 
             RGBColor[
              0.7427956016916255, 0.7990494191661757, 0.974984628023718], 
             UndirectedEdge[101, 182] -> 
             RGBColor[
              0.2744680720566198, 0.40581372438534935`, 0.9389419227132746], 
             UndirectedEdge[11, 230] -> 
             RGBColor[
              0.9461599473200244, 0.8204361321227099, 0.29539556227068897`], 
             UndirectedEdge[53, 101] -> 
             RGBColor[
              0.27504289638646184`, 0.40641790120198085`, 0.9389746581084827],
              UndirectedEdge[202, 264] -> 
             RGBColor[
              0.5231853201585595, 0.37556082624020004`, 0.5678587762898913], 
             UndirectedEdge[336, 367] -> 
             RGBColor[
              0.21516062802241154`, 0.34347784039625945`, 0.9355644515130273],
              UndirectedEdge[13, 132] -> 
             RGBColor[
              0.8815012453075697, 0.9077928551611671, 0.9634088234551113], 
             UndirectedEdge[146, 307] -> 
             RGBColor[
              0.760285606005483, 0.8109047025764178, 0.9254188643765703], 
             UndirectedEdge[75, 133] -> 
             RGBColor[
              0.27071817278007254`, 0.4018723424883518, 0.9387283714969541], 
             UndirectedEdge[153, 369] -> 
             RGBColor[
              0.28744235484774583`, 0.41864755274771004`, 0.9397101894237105],
              UndirectedEdge[20, 181] -> 
             RGBColor[
              0.4874856363228792, 0.5935620769713348, 0.9531383479528726], 
             UndirectedEdge[112, 394] -> 
             RGBColor[
              0.34389456121557604`, 0.47228591710687856`, 0.9431336352400042],
              UndirectedEdge[279, 306] -> 
             RGBColor[
              0.9580128778613826, 0.8669798939942239, 0.307271930750418], 
             UndirectedEdge[34, 68] -> 
             RGBColor[
              0.29450681654452554`, 0.42654813983932427`, 0.9400950937121118],
              UndirectedEdge[4, 284] -> 
             RGBColor[
              0.23809729374437577`, 0.3675857303386453, 0.936870660694137], 
             UndirectedEdge[193, 235] -> 
             RGBColor[
              0.7812166445775857, 0.8290306868326278, 0.9788229798067978], 
             UndirectedEdge[296, 316] -> 
             RGBColor[
              0.27790052377493313`, 0.40942144877130526`, 0.9391373957607753],
              UndirectedEdge[117, 223] -> 
             RGBColor[
              0.40179215387534173`, 0.5224135595233219, 0.9468284392932418], 
             UndirectedEdge[37, 110] -> 
             RGBColor[
              0.2526887349083196, 0.3829222601527542, 0.9377016216823209], 
             UndirectedEdge[83, 349] -> 
             RGBColor[
              0.3991304048320619, 0.5201284286132558, 0.946653214352108], 
             UndirectedEdge[192, 348] -> 
             RGBColor[
              0.30372248336585006`, 0.4332572121434699, 0.9407289213687278], 
             UndirectedEdge[97, 394] -> 
             RGBColor[
              0.40057619946044803`, 0.521380703252613, 0.9467453391073628], 
             UndirectedEdge[2, 352] -> 
             RGBColor[
              0.9063026650036, 0.5663670773157738, 0.3851970536504771], 
             UndirectedEdge[69, 350] -> 
             RGBColor[
              0.4604806861717529, 0.5723193250518395, 0.9508242340447808], 
             UndirectedEdge[164, 304] -> 
             RGBColor[
              0.230818470893376, 0.3599352260182205, 0.936456142500826], 
             UndirectedEdge[141, 350] -> 
             RGBColor[
              0.3964033490329356, 0.5177663899458625, 0.9464794487680284], 
             UndirectedEdge[114, 356] -> 
             RGBColor[
              0.4236281428800086, 0.5395805954873082, 0.9487022895227458], 
             UndirectedEdge[383, 390] -> 
             RGBColor[
              0.27326780022861263`, 0.40455216259248444`, 0.9388735690083126],
              UndirectedEdge[297, 307] -> 
             RGBColor[
              0.965939497584164, 0.9739442069028073, 0.9347428726703746], 
             UndirectedEdge[40, 58] -> 
             RGBColor[
              0.31906156196643076`, 0.449858262003899, 0.9415849314423156], 
             UndirectedEdge[173, 295] -> 
             RGBColor[
              0.23437748052955032`, 0.36367597080008385`, 0.9366588228345232],
              UndirectedEdge[161, 239] -> 
             RGBColor[
              0.3779757827321134, 0.5018053582125028, 0.9453052605381971], 
             UndirectedEdge[35, 369] -> 
             RGBColor[
              0.26924749981930185`, 0.40032657196053045`, 0.9386446188475038],
              UndirectedEdge[303, 313] -> 
             RGBColor[
              0.2862100467675046, 0.4181552842906852, 0.9396106108023645], 
             UndirectedEdge[237, 349] -> 
             RGBColor[
              0.5118990860533059, 0.6144062060618112, 0.9547772771793315], 
             UndirectedEdge[21, 263] -> 
             RGBColor[
              0.2875003760669833, 0.4191258516317633, 0.9396982137034129], 
             UndirectedEdge[126, 274] -> 
             RGBColor[
              0.22138486041548355`, 0.35001990328050514`, 0.9359189123398861],
              UndirectedEdge[331, 346] -> 
             RGBColor[
              0.3985622409768109, 0.5196363136385831, 0.946617011453659], 
             UndirectedEdge[106, 345] -> 
             RGBColor[
              0.5752211056493675, 0.6453489967018295, 0.953440498597335]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.23802405881018981`, 0.36750875577945274`, 0.9368664900729765],
              316 -> RGBColor[
              0.25427950679235417`, 0.38459426226363735`, 0.9377922137877805],
              308 -> RGBColor[
              0.2610883790761277, 0.39175081874132034`, 0.9381799689915176], 
             160 -> RGBColor[
              0.8294775817921864, 0.22758318757925894`, 0.17586107165535175`],
              245 -> RGBColor[
              0.22989884827362161`, 0.3589686443374169, 0.9364037713530907], 
             155 -> RGBColor[
              0.30454561984188433`, 0.43742713413433654`, 0.9406547945639009],
              213 -> RGBColor[
              0.9109681137578394, 0.6847252697068382, 0.24722105836383443`], 
             352 -> RGBColor[
              0.9941541355650164, 0.9899046120181566, 0.6050919166244885], 27 -> 
             RGBColor[
              0.2974167180204977, 0.42993420632157753`, 0.9402488141514381], 
             367 -> RGBColor[
              0.21931469518675756`, 0.34784402836905765`, 0.9358010194926452],
              19 -> RGBColor[
              0.2743841090042405, 0.40572547389373365`, 0.9389371411416538], 
             164 -> RGBColor[
              0.24253850776538854`, 0.3722537278639624, 0.9371235812624463], 
             190 -> RGBColor[
              0.2411029859620505, 0.37074490343131483`, 0.9370418304194105], 
             103 -> RGBColor[
              0.34456615692423104`, 0.4728676195543337, 0.943176428724691], 
             138 -> RGBColor[
              0.8193428764107183, 0.14968340096107918`, 0.16615606633654534`],
              291 -> RGBColor[
              0.696491580031562, 0.7628237829435023, 0.9703834296798242], 28 -> 
             RGBColor[
              0.2882891132658928, 0.42034051500092084`, 0.9397290105637445], 
             337 -> RGBColor[
              0.2847433322190086, 0.4166136743051424, 0.9395270835786375], 
             195 -> RGBColor[
              0.24569470610522032`, 0.37557109243365844`, 0.9373033220887227],
              114 -> RGBColor[
              0.3288778807819878, 0.45927922327560866`, 0.9421767856415051], 
             93 -> RGBColor[
              0.2452381115380016, 0.3750911825937439, 0.9372773197035907], 34 -> 
             RGBColor[
              0.3122890105436297, 0.4449107776560043, 0.9411197574988789], 
             161 -> RGBColor[
              0.4314366462475933, 0.5481104711684827, 0.9487117394878181], 22 -> 
             RGBColor[
              0.29231839668471055`, 0.42457554734542235`, 0.9399584722936555],
              124 -> RGBColor[
              0.22327126764014227`, 0.35200263687874755`, 0.936026340440641], 
             84 -> RGBColor[
              0.17892701429477148`, 0.30539401502471114`, 0.9335010008140661],
              46 -> RGBColor[
              0.2843163130979401, 0.41616485013432336`, 0.9395027654714108], 
             241 -> RGBColor[
              0.290961948336973, 0.42314983412815754`, 0.9398812245669373], 
             185 -> RGBColor[
              0.8236904837096025, 0.18310101579396953`, 0.170319339995877], 
             390 -> RGBColor[
              0.26629927432356376`, 0.3972278000362168, 0.9384767217670303], 
             121 -> RGBColor[
              0.5531961411455233, 0.6481485744409189, 0.9579687731366617], 
             322 -> RGBColor[
              0.5084161265639328, 0.611794141286916, 0.9544435263542006], 126 -> 
             RGBColor[
              0.21204174778307774`, 0.3401996995162911, 0.935386835897367], 
             236 -> RGBColor[
              0.2505222001886238, 0.3806450947961188, 0.9375782407351351], 78 -> 
             RGBColor[
              0.8418439495844675, 0.3226365094076515, 0.18770311941905493`], 
             376 -> RGBColor[
              0.43839329858407067`, 0.5541359737708264, 0.9491550112231723], 
             254 -> RGBColor[
              0.46951139015292603`, 0.5802095236300584, 0.951380802991181], 
             290 -> RGBColor[
              0.4051337172328171, 0.5253281960795354, 0.9470357401097634], 
             251 -> RGBColor[
              0.822315843269912, 0.8611563485272284, 0.9829144132927453], 165 -> 
             RGBColor[
              0.532748774101436, 0.6315484807311408, 0.9563590815017777], 100 -> 
             RGBColor[
              0.37661408553666426`, 0.5006259245426959, 0.9452184943970047], 
             235 -> RGBColor[
              0.7400936775781565, 0.7968860729351169, 0.9747292792785006], 70 -> 
             RGBColor[
              0.2778101351361315, 0.409326444580954, 0.9391322482615135], 234 -> 
             RGBColor[
              0.3387393935852255, 0.4678207700117279, 0.942805152517134], 257 -> 
             RGBColor[
              0.8226071697061851, 0.17477418965247965`, 0.16928195728277629`],
              135 -> 
             RGBColor[
              0.5032780494106496, 0.6076228187861427, 0.9540390380992975], 
             265 -> RGBColor[
              0.5918946974095183, 0.6795658057661227, 0.9610152652432459], 
             111 -> RGBColor[
              0.8740781517963572, 0.5211001217496539, 0.21664006204298622`], 
             381 -> RGBColor[
              0.9931470290452047, 0.9914341346439413, 0.7632349938486772], 
             182 -> RGBColor[
              0.2880943118622093, 0.4201357663745271, 0.9397179169119876], 
             188 -> RGBColor[
              0.26708591845739416`, 0.39805461289699134`, 0.9385215199867163],
              154 -> RGBColor[
              0.4301580292792129, 0.547002997415629, 0.9486302671452295], 336 -> 
             RGBColor[
              0.2110065608580655, 0.33911165242346125`, 0.9353278835334095], 
             315 -> RGBColor[
              0.24327422624281886`, 0.37302701463098736`, 0.937165479341338], 
             368 -> RGBColor[
              0.21278150541118618`, 0.3409772316867757, 0.9354289639999145], 
             269 -> RGBColor[
              0.9930589289900814, 0.9875620758967413, 0.48588543977432486`], 
             208 -> RGBColor[
              0.2330867180319017, 0.36231929757598597`, 0.9365853158197941], 
             86 -> RGBColor[
              0.30053635500276704`, 0.4332131425863514, 0.940426472862489], 
             119 -> RGBColor[
              0.24049836738192176`, 0.3701094109685675, 0.9370073982857251], 
             377 -> RGBColor[
              0.41487938737084307`, 0.5337694057214698, 0.9476567255932007], 
             140 -> RGBColor[
              0.6719249954084331, 0.7436321803229556, 0.9679348621123766], 85 -> 
             RGBColor[
              0.2413074662041341, 0.37095982513054093`, 0.9370534752666957], 
             351 -> RGBColor[
              0.24574449108125243`, 0.37562341960001794`, 0.9373061572694574],
              242 -> RGBColor[
              0.9183468399249884, 0.7139794601448493, 0.25315815463888625`], 
             117 -> RGBColor[
              0.3495171154366807, 0.47715589097540734`, 0.9434918994231435], 
             47 -> RGBColor[
              0.43389191818712153`, 0.5502371043169462, 0.948868187244693], 
             81 -> RGBColor[
              0.2197154470497895, 0.34826524398623987`, 0.9358238417183856], 
             275 -> RGBColor[
              0.992100640761205, 0.9910014261975552, 0.7805763556806252], 23 -> 
             RGBColor[
              0.21341792784235675`, 0.34164615201344867`, 0.935465207315867], 
             328 -> 
             RGBColor[
              0.3094371851822424, 0.44244066986488095`, 0.9409380417086214], 
             110 -> RGBColor[
              0.25557794384056287`, 0.3859590019269685, 0.9378661578568105], 
             6 -> RGBColor[
              0.9933475429680663, 0.9881793920123014, 0.5172992901589675], 
             218 -> RGBColor[
              0.9100637739514378, 0.9311241665985504, 0.9912838892546516], 
             108 -> RGBColor[
              0.3675690787260941, 0.49279159425864094`, 0.9446421545612206], 
             297 -> RGBColor[
              0.9466390204165737, 0.9597240493140413, 0.9752103990490407], 
             157 -> RGBColor[
              0.46924384183457235`, 0.5799923158523045, 0.9513597406074984], 
             354 -> RGBColor[
              0.27977343586669706`, 0.4113899981292344, 0.939244055333676], 
             385 -> RGBColor[
              0.5754210452890663, 0.6661917528451691, 0.9597183990033479], 
             270 -> RGBColor[
              0.249587147505622, 0.3796622951405196, 0.9375249908681246], 392 -> 
             RGBColor[
              0.24794921220500737`, 0.3779407212884774, 0.9374317128758627], 
             33 -> RGBColor[
              0.17894138666990014`, 0.3054091213022326, 0.9335018192995677], 
             252 -> RGBColor[
              0.2243331252717409, 0.35311871657522015`, 0.9360868116618829], 
             394 -> RGBColor[
              0.35886795134781274`, 0.48525511505495156`, 0.9440877264187814],
              260 -> RGBColor[
              0.8089540339665278, 0.8506803067038047, 0.9815926360666765], 
             159 -> RGBColor[
              0.3314345944952444, 0.46149372018986384`, 0.9423396971785006], 
             183 -> RGBColor[
              0.2589336294896423, 0.3894860403069097, 0.9380572591902335], 99 -> 
             RGBColor[
              0.9781276011086575, 0.9832081812363787, 0.921908445474496], 329 -> 
             RGBColor[
              0.23513882534723038`, 0.36447619247551505`, 0.9367021802955814],
              309 -> RGBColor[
              0.27079044913528966`, 0.40194830952027055`, 0.9387324875284604],
              17 -> RGBColor[
              0.5355166046173245, 0.6337955302332828, 0.9565769752588857], 
             349 -> RGBColor[
              0.4453791406536688, 0.5601867590528806, 0.9496001429025095], 
             347 -> RGBColor[
              0.2800500850584523, 0.411680773970341, 0.9392598100958807], 340 -> 
             RGBColor[
              0.99377812825938, 0.9891003704115706, 0.5641658418540755], 277 -> 
             RGBColor[
              0.2578128298869203, 0.3883080088616496, 0.9379934313109329], 
             104 -> RGBColor[
              0.9338740873595025, 0.7755398220742175, 0.265651742396037], 79 -> 
             RGBColor[
              0.590805957298975, 0.6786819174972005, 0.9609295556335575], 327 -> 
             RGBColor[
              0.3185921337049145, 0.45037022613412764`, 0.941521386933083], 
             191 -> RGBColor[
              0.6788533623879274, 0.7490446732648759, 0.968625416983622], 50 -> 
             RGBColor[
              0.45414763221898446`, 0.5677365328098771, 0.9501713116873214], 
             225 -> RGBColor[
              0.2571081050813221, 0.3875672984088326, 0.9379532982758011], 61 -> 
             RGBColor[
              0.9933459036684309, 0.98817588571614, 0.5171208625102379], 196 -> 
             RGBColor[
              0.29792411608308994`, 0.43046751385625726`, 0.9402777097204745],
              1 -> RGBColor[
              0.3599830334006432, 0.48622094308345976`, 0.9441587784611594], 
             263 -> RGBColor[
              0.26208361027682536`, 0.3927968698345563, 0.9382366459360847], 
             201 -> RGBColor[
              0.27642628673231373`, 0.407871932167485, 0.9390534401421363], 
             371 -> RGBColor[
              0.27204560568907665`, 0.4032675586398226, 0.9388039668373608], 
             293 -> RGBColor[
              0.21123106399266978`, 0.3393476194522512, 0.9353406686548026], 
             362 -> RGBColor[
              0.40465902674538534`, 0.5249170430379596, 0.9470054932516565], 
             184 -> RGBColor[
              0.21776291881025298`, 0.3462130130090464, 0.9357126481236506], 
             106 -> RGBColor[
              0.948494816832878, 0.9611080992427333, 0.9720690197854612], 206 -> 
             RGBColor[
              0.23156206990492625`, 0.36071679572626025`, 0.9364984893644777],
              358 -> RGBColor[
              0.9685766725786527, 0.9056638794389593, 0.332426736075871], 247 -> 
             RGBColor[
              0.9070075396154186, 0.6690229130152352, 0.24403428744221908`], 
             220 -> RGBColor[
              0.4754345148883495, 0.5850181831240037, 0.9518470930674744], 
             107 -> RGBColor[
              0.8392176796973624, 0.30244984821655896`, 0.1851882004092155], 
             375 -> RGBColor[
              0.25484534055170655`, 0.38518898942064916`, 0.9378244371832996],
              131 -> RGBColor[
              0.9224661794909306, 0.7303112688352736, 0.2564726719469704], 
             127 -> 
             RGBColor[
              0.21049571798261152`, 0.33857472417205015`, 0.9352987917873766],
              210 -> RGBColor[
              0.2999237099233219, 0.432569213763913, 0.9403915836315417], 357 -> 
             RGBColor[
              0.6756901028072094, 0.7465735108387558, 0.9683101328309576], 
             181 -> RGBColor[
              0.5673122922146817, 0.6596087018042204, 0.9590800482579911], 
             194 -> RGBColor[
              0.3880550588481297, 0.5105355205850486, 0.9459475030995558], 
             118 -> RGBColor[
              0.20606162213947596`, 0.33391420830300045`, 0.935046276588767], 
             348 -> RGBColor[
              0.26295522261758464`, 0.39371298966810864`, 0.9382862829694559],
              276 -> RGBColor[
              0.765566144894021, 0.8167853580001923, 0.977268136766805], 305 -> 
             RGBColor[
              0.20290260740476634`, 0.33059388352371805`, 0.9348663753729688],
              343 -> RGBColor[
              0.7222005724227306, 0.7829078431950623, 0.9729458617771823], 
             280 -> RGBColor[
              0.23901320904650822`, 0.3685484153935707, 0.9369228207156182], 
             189 -> RGBColor[
              0.30054674338696064`, 0.4332240614368005, 0.9404270644656005], 
             168 -> RGBColor[
              0.6701504899984683, 0.7422459232099505, 0.9677579959968072], 
             363 -> RGBColor[
              0.8625124936811881, 0.46858316947675277`, 0.2069893934114667], 
             41 -> RGBColor[
              0.34082031608406577`, 0.4696231604900174, 0.9429377470586726], 
             14 -> RGBColor[
              0.9943570777774785, 0.9903386848900081, 0.6271809240368398], 77 -> 
             RGBColor[
              0.8293651040061051, 0.8667772376911834, 0.9835867780747127], 51 -> 
             RGBColor[
              0.3729233885884314, 0.4974292283459589, 0.9449833264510183], 
             179 -> RGBColor[
              0.2696431574723743, 0.40074243324005365`, 0.9386671509655232], 
             223 -> RGBColor[
              0.4540671923140028, 0.5676712280712366, 0.9501649791633402], 
             323 -> RGBColor[
              0.8302102447519867, 0.867451129981215, 0.983667388353521], 292 -> 
             RGBColor[
              0.2110186790508826, 0.3391243894124498, 0.9353285736465631], 
             396 -> RGBColor[
              0.2782995151593558, 0.4098408140138484, 0.9391601177298633], 
             321 -> RGBColor[
              0.8177864636409283, 0.8575802678943982, 0.9824729701128726], 
             143 -> 
             RGBColor[
              0.6246442469651912, 0.7061533654458123, 0.9635934297498213], 
             112 -> RGBColor[
              0.3289211710833394, 0.45931671915880556`, 0.9421795440612271], 
             197 -> RGBColor[
              0.988751433892587, 0.9896164430866911, 0.8360813809631582], 54 -> 
             RGBColor[
              0.4519914858020445, 0.5659140400742732, 0.9500214756882968], 71 -> 
             RGBColor[
              0.871120013048017, 0.9000714687543917, 0.9875693985741776], 177 -> 
             RGBColor[
              0.3219085007459621, 0.453242696579629, 0.9417327029083903], 158 -> 
             RGBColor[
              0.5031159008708285, 0.6074911792968075, 0.9540262731722731], 
             226 -> RGBColor[
              0.23863402700947722`, 0.3681498710311214, 0.9369012268595588], 
             350 -> RGBColor[
              0.4327427506991586, 0.5492417531977101, 0.948794963308529], 203 -> 
             RGBColor[
              0.29139757571829134`, 0.42360770612629445`, 0.9399060329018505],
              115 -> RGBColor[
              0.2386060995532787, 0.36812051750395375`, 0.9368996364322433], 
             173 -> RGBColor[
              0.22636761106282094`, 0.3552570901354948, 0.936202672617933], 
             212 -> RGBColor[
              0.21089717481030001`, 0.33899668075178374`, 0.9353216541598114],
              129 -> RGBColor[
              0.23768447069359533`, 0.36715182713778177`, 0.936847151032112], 
             279 -> RGBColor[
              0.9456496399519233, 0.8222259641328803, 0.2751266284196432], 26 -> 
             RGBColor[
              0.45511285367532656`, 0.5685201430708667, 0.9502472974560874], 
             40 -> RGBColor[
              0.3393121311221928, 0.4683168464796233, 0.9428416468465376], 
             146 -> RGBColor[
              0.5353312372592116, 0.6336450406612625, 0.9565623824614321], 
             386 -> RGBColor[
              0.3393631406607411, 0.4683610283780999, 0.942844897129228], 192 -> 
             RGBColor[
              0.34448974411411554`, 0.4728014346188312, 0.9431715597679996], 
             300 -> RGBColor[
              0.8899967779325137, 0.5933828851443484, 0.2299229538922278], 
             221 -> RGBColor[
              0.9218589159168126, 0.9405292926311409, 0.9924089204249567], 62 -> 
             RGBColor[
              0.1790682590797859, 0.30554247224919795`, 0.9335090444956198], 
             286 -> RGBColor[
              0.726249879738111, 0.7860711928457129, 0.9733494588874512], 152 -> 
             RGBColor[
              0.18361616608284723`, 0.3103226108633739, 0.9337680410714186], 
             64 -> RGBColor[
              0.3989602722595878, 0.5199810683300905, 0.9466423736550322], 
             307 -> RGBColor[
              0.9852399747517544, 0.9881643644915732, 0.8942753462917085], 37 -> 
             RGBColor[
              0.24979952597607638`, 0.3798855183785399, 0.9375370855078312], 
             148 -> RGBColor[
              0.6238880244982119, 0.7055394299796848, 0.9635338971470865], 
             261 -> RGBColor[
              0.17944836957228805`, 0.3059419924772149, 0.9335306912258446], 
             387 -> RGBColor[
              0.2935687509337651, 0.4258897489382169, 0.9400296781184059], 15 -> 
             RGBColor[
              0.3038609163605336, 0.43670746736272875`, 0.940615801713566], 
             136 -> RGBColor[
              0.6185821135656369, 0.7012318524560568, 0.9631161964022821], 
             198 -> RGBColor[
              0.8264896291158393, 0.8644844120663722, 0.9833125127127125], 63 -> 
             RGBColor[
              0.9585610528033711, 0.8718788421575785, 0.2935179445399928], 
             310 -> RGBColor[
              0.18257815057035692`, 0.3092315907457619, 0.9337089276235886], 
             171 -> RGBColor[
              0.2732125866431092, 0.40449412961337683`, 0.9388704246762993], 
             395 -> RGBColor[
              0.27306809856961783`, 0.40434226348706437`, 0.938862196294265], 
             311 -> RGBColor[
              0.519374038863881, 0.6206902681403376, 0.955306173350608], 353 -> 
             RGBColor[
              0.21037964845754836`, 0.3384527277419758, 0.9352921817996338], 
             59 -> RGBColor[
              0.3340181926444761, 0.4637315030513096, 0.9425043217679835], 
             397 -> RGBColor[
              0.2493495489754894, 0.37941256402073326`, 0.9375114599833291], 
             229 -> RGBColor[
              0.24689616138342244`, 0.3768338981077132, 0.9373717431894225], 
             102 -> RGBColor[
              0.819297035403237, 0.14933104688991955`, 0.16611216893601113`], 
             299 -> RGBColor[
              0.21412870248835636`, 0.3423932212321097, 0.9355056848804599], 
             128 -> RGBColor[
              0.3262131529712761, 0.45697116997908427`, 0.9420069915417328], 
             12 -> RGBColor[
              0.218436984339963, 0.3469214986189947, 0.935751035158377], 222 -> 
             RGBColor[
              0.6049269005052089, 0.6901459353332633, 0.9620412080094716], 92 -> 
             RGBColor[
              0.28766384187052196`, 0.4196833151198899, 0.9396934022827843], 
             271 -> RGBColor[
              0.30678788301618565`, 0.43978389489822367`, 0.9407824881345462],
              361 -> RGBColor[
              0.35562652096447817`, 0.48244755097593534`, 0.9438811853410396],
              344 -> RGBColor[
              0.32062864936426844`, 0.45213415364000675`, 0.941651151910077], 
             132 -> RGBColor[
              0.7992223614262676, 0.8430778501519028, 0.9806226738955138], 80 -> 
             RGBColor[
              0.3344163982055418, 0.46407640869391137`, 0.9425296950742152], 
             324 -> RGBColor[
              0.2799576543907215, 0.4115836234781131, 0.9392545463060924], 
             244 -> RGBColor[
              0.2600361752617328, 0.3906448858188163, 0.9381200475408837], 
             150 -> RGBColor[
              0.2706007772119499, 0.40174895230294594`, 0.9387216859930206], 
             125 -> RGBColor[
              0.277985958766929, 0.4095112463647842, 0.9391422611571797], 258 -> 
             RGBColor[
              0.2529332615169164, 0.38317927312227185`, 0.9377155471109357], 
             133 -> RGBColor[
              0.29725822306554583`, 0.42976761807476255`, 0.9402397880982258],
              255 -> RGBColor[
              0.26047497796174324`, 0.3911060952782254, 0.938145036705499], 
             326 -> RGBColor[
              0.3393902356747875, 0.4683844967174319, 0.9428466235995638], 
             176 -> RGBColor[
              0.21582348781243682`, 0.34417454806331416`, 0.935602200397456], 
             230 -> RGBColor[
              0.9688572327835747, 0.9066102748888301, 0.333516659492644], 274 -> 
             RGBColor[
              0.2307279730478894, 0.35984010704471925`, 0.9364509887824051], 
             87 -> RGBColor[
              0.29013871681338543`, 0.4222845656009737, 0.9398343427495309], 
             130 -> RGBColor[
              0.4104055903111328, 0.5298944275679272, 0.9473716592005793], 35 -> 
             RGBColor[
              0.28104105066772134`, 0.4127223416565313, 0.9393162441213263], 
             379 -> RGBColor[
              0.22095736038557218`, 0.3495705736440009, 0.9358945668456122], 
             31 -> RGBColor[
              0.183217413291963, 0.30990349639776743`, 0.9337453326898797], 
             18 -> RGBColor[
              0.9452065658445834, 0.95865572703968, 0.9776351709954327], 24 -> 
             RGBColor[
              0.9021530244270525, 0.6485815613125467, 0.24006642394413927`], 
             151 -> 
             RGBColor[
              0.3158355177641727, 0.44798258395780277`, 0.9413457378029186], 
             137 -> RGBColor[
              0.22155609394318862`, 0.3501998805749559, 0.9359286638359716], 
             330 -> RGBColor[
              0.22477195032544567`, 0.3535799495297792, 0.936111802099508], 
             296 -> RGBColor[
              0.30152154075751214`, 0.43424863527897317`, 0.94048257773377], 
             266 -> RGBColor[
              0.2549979314676595, 0.3853493721481386, 0.937833127010225], 302 -> 
             RGBColor[
              0.9872770340850194, 0.9687445898536212, 0.4050741092611545], 
             283 -> RGBColor[
              0.9089152991886196, 0.6765865439997854, 0.2455693155756892], 
             388 -> RGBColor[
              0.22336510960731928`, 0.352101270736175, 0.9360316846018449], 
             284 -> RGBColor[
              0.24399808998490613`, 0.37378784131953313`, 0.9372067023105894],
              318 -> RGBColor[
              0.2238174684207968, 0.35257672853034516`, 0.9360574457670676], 
             238 -> RGBColor[
              0.22922310747734106`, 0.35825839791608494`, 0.9363652889144115],
              72 -> RGBColor[
              0.22772650909910638`, 0.3566853781307425, 0.9362800598507899], 
             288 -> RGBColor[
              0.245025991273468, 0.37486823074651754`, 0.9372652397683294], 
             382 -> RGBColor[
              0.898780922280212, 0.63326963303821, 0.23725265925502825`], 389 -> 
             RGBColor[
              0.17908812663026416`, 0.30556335430442605`, 0.933510175923228], 
             172 -> RGBColor[
              0.301424661402258, 0.4341468089340951, 0.9404770605978084], 243 -> 
             RGBColor[
              0.2883719521470624, 0.4204275839173185, 0.939733728115478], 88 -> 
             RGBColor[
              0.9903137669558371, 0.9902625079584733, 0.8101894789167451], 
             273 -> RGBColor[
              0.2754373969927425, 0.40683254635196486`, 0.938997124334399], 
             202 -> RGBColor[
              0.8563396258514921, 0.4340566292418462, 0.20158419538288244`], 
             393 -> RGBColor[
              0.22281999879048459`, 0.3515283247056597, 0.9360006413472455], 
             98 -> RGBColor[
              0.9775701021325132, 0.9360008290818089, 0.3673645116259542], 30 -> 
             RGBColor[
              0.17892703208317115`, 0.3053940337214471, 0.9335010018270892], 
             116 -> RGBColor[
              0.4162213411164948, 0.534931738607397, 0.9477422336992305], 373 -> 
             RGBColor[
              0.2503218011924054, 0.380434462745063, 0.9375668283087641], 240 -> 
             RGBColor[
              0.23920651037948798`, 0.3687515873505448, 0.9369338289405676], 
             317 -> RGBColor[
              0.9906270631619555, 0.9903920639910485, 0.8049973499967711], 
             391 -> RGBColor[
              0.8203907902431329, 0.1577381258757864, 0.16715954980591485`], 
             73 -> RGBColor[
              0.24311597663730303`, 0.3728606842619857, 0.9371564672604132], 
             303 -> RGBColor[
              0.28961174034798287`, 0.421730679923598, 0.9398043322194181], 
             29 -> RGBColor[
              0.2404292095299187, 0.3700367216812511, 0.9370034598483634], 
             360 -> RGBColor[
              0.3103917228488082, 0.4432674424152022, 0.9409988640046705], 
             320 -> RGBColor[
              0.7098940201909748, 0.7732938710583535, 0.9717192596619902], 75 -> 
             RGBColor[
              0.24417812249459925`, 0.373977066901941, 0.9372169548956822], 
             200 -> RGBColor[
              0.27065965459454444`, 0.40181083616509444`, 0.9387250389728581],
              301 -> RGBColor[
              0.2568179059531509, 0.3872622807254372, 0.9379367718647629], 
             156 -> RGBColor[
              0.18595953915049845`, 0.3127856445359093, 0.9339014927009116], 
             25 -> RGBColor[
              0.8487111149297029, 0.3754205514621725, 0.19427912470900624`], 
             38 -> RGBColor[
              0.9657912116144293, 0.896267865549297, 0.32160574622002847`], 
             365 -> RGBColor[
              0.25624071750281635`, 0.38665561906827417`, 0.93790390183639], 
             380 -> RGBColor[
              0.26549066491796636`, 0.3963779002821365, 0.9384306726576119], 
             370 -> RGBColor[
              0.8312166238387177, 0.8682535893475418, 0.9837633776892186], 3 -> 
             RGBColor[
              0.370079657849583, 0.49496613171003123`, 0.9448021264429514], 
             57 -> RGBColor[
              0.2732074233744939, 0.404488702690692, 0.9388701306357901], 227 -> 
             RGBColor[
              0.23492201148043795`, 0.36424830735472313`, 0.9366898330666149],
              39 -> RGBColor[
              0.27309206457306523`, 0.40436745327622, 0.9388635611227067], 
             109 -> RGBColor[
              0.9940964498066649, 0.9918267445278057, 0.7475006348091123], 
             256 -> RGBColor[
              0.22530836548640581`, 0.35414375587463387`, 0.9361423501493695],
              339 -> 
             RGBColor[
              0.36576050208801136`, 0.49122509607643855`, 0.9445269136571035],
              287 -> RGBColor[
              0.260213393629744, 0.3908311535598896, 0.9381301398647709], 239 -> 
             RGBColor[
              0.32451491921663345`, 0.4555002452565231, 0.9418987815885761], 
             285 -> RGBColor[
              0.23871510677441427`, 0.3682350910048242, 0.9369058442322252], 
             345 -> RGBColor[
              0.20194739446585683`, 0.3295898941609259, 0.9348119774092088], 
             366 -> RGBColor[
              0.9012804456996433, 0.6446193851073215, 0.2393383228651273], 
             216 -> RGBColor[
              0.6591015742674116, 0.7336144262659793, 0.9666567433347234], 21 -> 
             RGBColor[
              0.31291714185714126`, 0.44545483342897024`, 0.9411597814707411],
              355 -> RGBColor[
              0.23092116646773903`, 0.3600431655781515, 0.9364619908618614], 
             175 -> RGBColor[
              0.17893214148115075`, 0.3053994040226782, 0.9335012927997455], 
             7 -> RGBColor[
              0.38940499419392427`, 0.5117047667318526, 0.9460335197860889], 
             13 -> RGBColor[
              0.9637801291888717, 0.9725078601704316, 0.9461949730147088], 
             294 -> RGBColor[
              0.21275955169572475`, 0.34095415693987974`, 0.9354277137682966],
              193 -> RGBColor[
              0.8223396115770147, 0.8611753007301386, 0.9829166803350949], 60 -> 
             RGBColor[
              0.35752834255750565`, 0.4840948132514831, 0.9440023677312325], 
             65 -> RGBColor[
              0.5153321861178936, 0.6174089099977538, 0.9549879838966494], 69 -> 
             RGBColor[
              0.48821862164434726`, 0.5953968969059689, 0.9528535047810326], 
             217 -> RGBColor[
              0.8228256695060855, 0.17645367486173685`, 0.16949119293792111`],
              214 -> RGBColor[
              0.9837730937067766, 0.9874185803724101, 0.9123520990861677], 
             170 -> RGBColor[
              0.44496963537099143`, 0.5598320661593594, 0.9495740495880086], 
             359 -> RGBColor[
              0.2455681205459235, 0.37543804298484945`, 0.9372961132283874], 
             74 -> RGBColor[
              0.8246734764068878, 0.8630362611944062, 0.983139286446034], 246 -> 
             RGBColor[
              0.4438028563584466, 0.5588214608227114, 0.9494997034610714], 
             264 -> RGBColor[
              0.19003101446562676`, 0.31706502323855396`, 0.9341333571969002],
              278 -> 
             RGBColor[
              0.2524156236360728, 0.382635202889368, 0.9376860683993983], 45 -> 
             RGBColor[
              0.2954990939280613, 0.427918661816037, 0.9401396082962444], 306 -> 
             RGBColor[
              0.9703761157708419, 0.9117338238555674, 0.33941723308119276`], 
             237 -> RGBColor[
              0.5784190314529432, 0.6686256530707418, 0.9599544114561535], 
             228 -> RGBColor[
              0.36785717736282086`, 0.49304113081751505`, 0.9446605119515972],
              180 -> RGBColor[
              0.36627002209779275`, 0.4916664166996908, 0.9445593798215759], 
             383 -> RGBColor[
              0.28023632613366145`, 0.41187652514875206`, 0.939270416249595], 
             53 -> RGBColor[
              0.28924396052189333`, 0.4213441200077901, 0.9397833877024038], 
             304 -> RGBColor[
              0.21909843402136348`, 0.34761672417247863`, 0.9357887037392056],
              48 -> RGBColor[
              0.4254428949511675, 0.5429189850502182, 0.948329822955276], 5 -> 
             RGBColor[
              0.8414430264446411, 0.8764078451972013, 0.9847387810989889], 
             101 -> RGBColor[
              0.2608418322510304, 0.39149168239617155`, 0.9381659285145616], 
             333 -> RGBColor[
              0.19556045555100107`, 0.3228768164060961, 0.9344482506866372], 
             267 -> RGBColor[
              0.5711989452526345, 0.6627640618321545, 0.9593860198224179], 
             120 -> RGBColor[
              0.5663783145126094, 0.6588504566304622, 0.9590065221120109], 
             147 -> RGBColor[
              0.28473783311028583`, 0.41660789439321116`, 0.9395267704125309],
              89 -> RGBColor[
              0.21858282554203126`, 0.3470747869692347, 0.9357593405990821], 
             43 -> RGBColor[
              0.2274352478585693, 0.35637924409990884`, 0.9362634729540237], 
             199 -> RGBColor[
              0.22580276459471169`, 0.35466340068417734`, 0.9361705054471896],
              268 -> RGBColor[0.817319, 0.134127, 0.164218], 169 -> 
             RGBColor[
              0.22069846856058375`, 0.34929846192124825`, 0.9358798233391753],
              20 -> RGBColor[
              0.4076589804310767, 0.5275154521384491, 0.9471966476477539], 4 -> 
             RGBColor[
              0.23219649750384544`, 0.36138361935775737`, 0.9365346190776845],
              167 -> RGBColor[
              0.2835494674254077, 0.415358846711668, 0.9394590947448065], 142 -> 
             RGBColor[
              0.8215839734950429, 0.16690945520620182`, 0.16830214343545163`],
              16 -> RGBColor[
              0.2418605106508593, 0.3715411099090923, 0.9370849703297808], 
             281 -> RGBColor[
              0.6319940482543123, 0.7121202652370958, 0.9641720330305101], 
             289 -> RGBColor[
              0.8977533081905217, 0.6286034774622947, 0.23639519286946437`], 
             398 -> RGBColor[
              0.9394254025446074, 0.954344144916344, 0.9874211724934188], 178 -> 
             RGBColor[
              0.24398844376792686`, 0.3737777025338824, 0.9372061529728027], 
             58 -> RGBColor[
              0.2988109928106687, 0.43139967752817476`, 0.9403282160380936], 
             186 -> RGBColor[
              0.24846767200989045`, 0.3784856554156597, 0.9374612383947583], 
             122 -> RGBColor[
              0.44608758599784554`, 0.5608003788025082, 0.9496452844133868], 
             249 -> RGBColor[
              0.2695692814994847, 0.4006647849085395, 0.938662943838157], 113 -> 
             RGBColor[
              0.7965156452550962, 0.8409633429071789, 0.9803528937232722], 52 -> 
             RGBColor[
              0.38664548537965426`, 0.5093146188938776, 0.9458576863245813], 
             187 -> RGBColor[
              0.8439338400416576, 0.8783939523481282, 0.9849763571234479], 
             259 -> RGBColor[
              0.2110206902246306, 0.3391265032835748, 0.9353286881799328], 42 -> 
             RGBColor[
              0.9322258626950144, 0.9487956145888052, 0.9933977290633442], 
             134 -> RGBColor[
              0.2343268669145523, 0.36362277268163234`, 0.9366559404640252], 
             313 -> RGBColor[
              0.2828083531870263, 0.41457988865777246`, 0.939416889385311], 
             248 -> RGBColor[
              0.21620788903044316`, 0.3445785781158837, 0.9356240914781508], 
             174 -> RGBColor[
              0.7286053839996127, 0.7879113306772935, 0.9735842335387989], 
             215 -> RGBColor[
              0.8192881970279116, 0.1492631112641677, 0.166103705297818], 399 -> 
             RGBColor[
              0.2348790166106703, 0.36420311702056507`, 0.9366873845723869], 
             83 -> RGBColor[
              0.35288166901045503`, 0.480070098173631, 0.9437062858017065], 
             95 -> RGBColor[
              0.2817785304161579, 0.4134974796310549, 0.9393582425019963], 
             166 -> RGBColor[
              0.8247691039330448, 0.19139176348574266`, 0.17135222793997262`],
              384 -> 
             RGBColor[
              0.7484278388783107, 0.8033967830847693, 0.9755599505897345], 
             233 -> RGBColor[
              0.8174582326741875, 0.1351972033459516, 0.16435132936604271`], 
             295 -> RGBColor[
              0.24238734999627973`, 0.3720948514646729, 0.9371149730511135], 
             141 -> RGBColor[
              0.3600639473667127, 0.48629102669401497`, 0.9441639342275279], 
             319 -> RGBColor[
              0.24158367299712782`, 0.37125013598249945`, 0.9370692048349454],
              205 -> RGBColor[
              0.9952685123171101, 0.9923114224965074, 0.7280765258104895], 
             224 -> RGBColor[
              0.9756615083220127, 0.9295626939998534, 0.3599499850798584], 
             231 -> RGBColor[
              0.30868412390727973`, 0.44177696430338015`, 0.9408904762480571],
              332 -> RGBColor[
              0.5272216074067284, 0.6270612778123552, 0.9559239626928917], 68 -> 
             RGBColor[
              0.2767246225454214, 0.4081855020226443, 0.9390704299253445], 10 -> 
             RGBColor[
              0.3619258765766598, 0.48790373619238797`, 0.9442825747103464], 
             250 -> RGBColor[
              0.9882272169582415, 0.9893996659125786, 0.8447690121952027], 
             282 -> RGBColor[
              0.6468617732853108, 0.7240526007128293, 0.965436794360271], 374 -> 
             RGBColor[
              0.2761037265699157, 0.40753290098530925`, 0.9390350708180728], 
             232 -> RGBColor[
              0.5255566438526651, 0.6257095853934133, 0.9557928906629534], 
             253 -> RGBColor[
              0.34171577858230273`, 0.47039876509873646`, 0.9429948051372339],
              55 -> RGBColor[
              0.4035326533159193, 0.5239414349865308, 0.9469337217327439], 
             325 -> RGBColor[
              0.21156771774634342`, 0.33970146389244305`, 0.9353598405880397],
              91 -> RGBColor[
              0.26262121251507564`, 0.39336192387290797`, 0.9382672615882417],
              105 -> RGBColor[
              0.417344109662346, 0.5359042242898253, 0.9478137755181469], 36 -> 
             RGBColor[
              0.5196772960404508, 0.620936465977857, 0.9553300468664151], 123 -> 
             RGBColor[
              0.9742961343763916, 0.9803506796209057, 0.9283941192456544], 94 -> 
             RGBColor[
              0.26012396818175015`, 0.3907371617441472, 0.9381250472178008], 
             312 -> RGBColor[
              0.46295717480753656`, 0.5748885163486347, 0.9508648311503101], 
             96 -> 
             RGBColor[
              0.2869114883454893, 0.4188925438631119, 0.939650556862541], 2 -> 
             RGBColor[
              0.8184511944421836, 0.14282954261339104`, 0.16530219067646573`],
              262 -> RGBColor[
              0.9386428604207964, 0.9537605262817009, 0.9887458121893573], 
             272 -> RGBColor[
              0.6470169280819229, 0.7241738088191627, 0.9654522587403933], 97 -> 
             RGBColor[
              0.44228444757308333`, 0.5575062914502744, 0.9494029517959442], 
             372 -> RGBColor[
              0.2514775053864574, 0.3816491811288898, 0.9376326439529042], 
             356 -> RGBColor[
              0.5183784049780293, 0.6198819676990077, 0.9552277934039866], 
             346 -> RGBColor[
              0.3450320119322843, 0.4732711197477559, 0.9432061125938647], 
             341 -> RGBColor[
              0.2215837127017966, 0.35022890964138337`, 0.935930236683416], 
             209 -> RGBColor[
              0.2520329891677718, 0.3822330298027571, 0.9376642779324855], 
             378 -> RGBColor[
              0.20852643568424656`, 0.3365048836167593, 0.9351866440737768], 
             66 -> RGBColor[
              0.9727828870163496, 0.9198524284034268, 0.3487670848893771], 
             139 -> RGBColor[
              0.2111706728502173, 0.3392841445325141, 0.9353372294685806], 56 -> 
             RGBColor[
              0.45093503134871465`, 0.5649989923257436, 0.9499541593447165], 
             335 -> RGBColor[
              0.28051817934621337`, 0.41217277074566994`, 0.9392864673730853],
              314 -> RGBColor[
              0.9258119809847409, 0.9436813594132142, 0.9927859673000785], 
             144 -> RGBColor[
              0.8784381059512442, 0.540897655273832, 0.22027811466207986`], 
             298 -> RGBColor[
              0.8234301328695646, 0.862044852807406, 0.9830206952294982], 204 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 207 -> 
             RGBColor[
              0.9398558182628138, 0.7992553918121872, 0.27046478349011155`], 
             334 -> RGBColor[
              0.26139903658851843`, 0.39207733948366696`, 0.9381976604772716],
              149 -> RGBColor[
              0.22021863489519794`, 0.34879412631571627`, 0.9358524975217819],
              219 -> RGBColor[
              0.4471878440862639, 0.5617533670581167, 0.9497153918858607], 
             400 -> RGBColor[
              0.38961090759033284`, 0.5118831185663134, 0.9460466404056259], 
             9 -> RGBColor[
              0.8256674379376745, 0.1982967522977973, 0.17221247359732916`], 
             11 -> RGBColor[
              0.9234626618564741, 0.7342619893565898, 0.25727446504873397`], 
             44 -> RGBColor[
              0.29795654320818293`, 0.4305015968207284, 0.940279556397277], 
             153 -> RGBColor[
              0.3174307607246093, 0.4493643032308905, 0.9414473852737397], 32 -> 
             RGBColor[
              0.21628540957162948`, 0.3446600571197567, 0.9356285061582901], 
             162 -> RGBColor[
              0.246083996032968, 0.37598026083012825`, 0.9373254915742051], 
             90 -> RGBColor[
              0.7058058015575851, 0.7701001235903371, 0.9713117842351892], 
             331 -> RGBColor[
              0.45209247002133757`, 0.5660015075294104, 0.9500279103134532], 
             8 -> RGBColor[
              0.3103199544645186, 0.44320528024791445`, 0.9409942909866859], 
             364 -> RGBColor[
              0.34952976604112324`, 0.4771668482931376, 0.9434927055084721], 
             342 -> RGBColor[
              0.6033581995623302, 0.6888723932386622, 0.9619177141249072], 
             163 -> RGBColor[
              0.2449732495734328, 0.3748127958757636, 0.9372622362065367], 49 -> 
             RGBColor[
              0.2557363986193865, 0.3861255479461254, 0.9378751816220516], 
             338 -> RGBColor[
              0.9942883740099587, 0.9901917344782997, 0.6197029429328111], 76 -> 
             RGBColor[
              0.8469444359628041, 0.36184108275892934`, 0.19258735093512552`],
              369 -> RGBColor[
              0.25745394897088236`, 0.38793080226452953`, 0.9379729935736814],
              82 -> RGBColor[
              0.37921715493462604`, 0.5028805724211383, 0.9453843596772389], 
             67 -> RGBColor[
              0.2129458677257866, 0.3411499869005934, 0.9354383241905787], 
             211 -> RGBColor[
              0.2626771974737526, 0.39342076761412886`, 
               0.9382704498488161]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9l3k0VX/Yxa95Hq55dufJNVwqktwdKpWiSIU0EZFIxkiFhGRKk6SkQSmp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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 7}], {
             RGBColor[
             0.37469401379728373`, 0.4989628549076562, 0.945096149123624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 35}], {
             RGBColor[
             0.32051204203418227`, 0.44947164236999554`, 0.9417375112912428]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 41}], {
             RGBColor[
             0.3504016747423545, 0.4779220517867386, 0.943548262759916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 57}], {
             RGBColor[
             0.31659522838756854`, 0.44535482288707584`, 0.9415144545484747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 92}], {
             RGBColor[
             0.3238234376355826, 0.4529521291016748, 0.9419260903719718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 96}], {
             RGBColor[
             0.32344726087306624`, 0.45255674347328584`, 0.9419046676618501]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 114}], {
             RGBColor[
             0.3444304570913155, 0.4727500831795342, 0.9431677820513322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 153}], {
             RGBColor[
             0.33870689706262624`, 0.4677926231571751, 0.9428030818674495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 154}], {
             RGBColor[
             0.39507053133992803`, 0.5166119702495444, 0.9463945228031945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 161}], {
             RGBColor[
             0.3957098398241182, 0.5171657071259712, 0.9464352589744887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 188}], {
             RGBColor[
             0.3135344759290187, 0.4421377779902256, 0.9413401492239378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 203}], {
             RGBColor[
             0.32569030455946724`, 0.45491432460487713`, 0.9420324056815049]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 222}], {
             RGBColor[
             0.48245496695292606`, 0.5881834392083616, 0.9530999932353155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 312}], {
             RGBColor[
             0.4114701041040899, 0.5305547297160472, 0.9475118048057347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 327}], {
             RGBColor[
             0.3392875835527789, 0.4682955846087937, 0.9428400826971212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 337}], {
             RGBColor[
             0.3223631828098259, 0.4514173086943011, 0.9418429310198984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 356}], {
             RGBColor[
             0.43918071918933627`, 0.5530514553912338, 0.949693285932573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 361}], {
             RGBColor[
             0.35780477718256065`, 0.4843342470296975, 0.9440199819010995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[
             0.8956170407292666, 0.531340985508409, 0.2570346377829214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 98}], {
             RGBColor[
             0.8980106482873484, 0.5394151858476, 0.26633335115120993`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 106}], {
             RGBColor[
             0.8834730056375308, 0.5519688209280622, 0.5686856052309635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 107}], {
             RGBColor[
             0.828834437069773, 0.222639695414975, 0.17524519554284063`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 197}], {
             RGBColor[
             0.9036013141673853, 0.5662229928500411, 0.5006917858198119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 215}], {
             RGBColor[
             0.8188696957350476, 0.14604632693877936`, 0.16570294798714186`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 283}], {
             RGBColor[
             0.8636832468154017, 0.4097080433065882, 0.20543575312607748`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 352}], {
             RGBColor[
             0.9063026650036, 0.5663670773157738, 0.3851970536504771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 52}], {
             RGBColor[
             0.3783625716146186, 0.5021403753019544, 0.9453299063837663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 86}], {
             RGBColor[
             0.33530800642617503`, 0.4640896371481913, 0.9426142996527203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 117}], {
             RGBColor[
             0.35979838664313185`, 0.4860610113427193, 0.9441470129330474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 174}], {
             RGBColor[
             0.5493425209245979, 0.6414387311936623, 0.9591931799908751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 232}], {
             RGBColor[
             0.4478181508511241, 0.5603378585517222, 0.9502975085529524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 309}], {
             RGBColor[
             0.32043505349243634`, 0.4484572206151509, 0.9417673069857059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 371}], {
             RGBColor[
             0.3210626317693298, 0.4491168451749269, 0.9418030466401561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 386}], {
             RGBColor[
             0.35472139925516205`, 0.48166358004406556`, 0.9438235117860897]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 16}], {
             RGBColor[
             0.23702850407735238`, 0.36646236463342485`, 0.9368097947037326]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 73}], {
             RGBColor[
             0.23765623707057423`, 0.3671221518098715, 0.9368455431690489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 115}], {
             RGBColor[
             0.23540129852856206`, 0.36475206843085556`, 0.936717127754964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 188}], {
             RGBColor[
             0.24964120798061978`, 0.37971911612737436`, 0.9375280695322004]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 195}], {
             RGBColor[
             0.2389456018045329, 0.3684773558957079, 0.9369189705832036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 206}], {
             RGBColor[
             0.23187928370438585`, 0.3610502075420088, 0.9365165542210812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 208}], {
             RGBColor[
             0.23264160776787357`, 0.36185145846687167`, 0.9365599674487393]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 258}], {
             RGBColor[
             0.24256487951038092`, 0.3722814462400146, 0.9371250830943101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 278}], {
             RGBColor[
             0.24230606056995913`, 0.37200941112356267`, 0.9371103437385414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 284}], {
             RGBColor[
             0.23809729374437577`, 0.3675857303386453, 0.936870660694137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 369}], {
             RGBColor[
             0.2448252232373639, 0.37465721081114345`, 0.937253806325683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 392}], {
             RGBColor[
             0.24007285485442642`, 0.3696621703231174, 0.9369831659767736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 99}], {
             RGBColor[
             0.9097853137766493, 0.92980801321679, 0.9533236132867424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 174}], {
             RGBColor[
             0.7850242052221269, 0.8321595879372474, 0.979161507318894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 193}], {
             RGBColor[
             0.8318913190108279, 0.8687915729636699, 0.983827730717042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 223}], {
             RGBColor[
             0.6477551093793219, 0.7220395366342189, 0.9674518801311646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 235}], {
             RGBColor[
             0.7907683520113988, 0.8366469590661592, 0.9797340301887447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 260}], {
             RGBColor[
             0.8251985302055844, 0.863544075950503, 0.9831657085828327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 267}], {
             RGBColor[
             0.7063209858486378, 0.7695859535146778, 0.9720624004607035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 272}], {
             RGBColor[
             0.744229977263282, 0.800290827008182, 0.9750955199196911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 275}], {
             RGBColor[
             0.916771833602923, 0.9337046356973782, 0.882657568389807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 291}], {
             RGBColor[
             0.7689673032381015, 0.8196158140703518, 0.9775611053894065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 321}], {
             RGBColor[
             0.8296147450427847, 0.8669940565457998, 0.9836058756059307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 338}], {
             RGBColor[
             0.9178657002272999, 0.9332997898377504, 0.8022208620159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 384}], {
             RGBColor[
             0.7949354326614759, 0.8399023141409853, 0.9801493658443617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 398}], {
             RGBColor[
             0.8904342144946242, 0.9153759950567726, 0.9860799767962038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 13}], {
             RGBColor[
             0.978563836078469, 0.9803436260913665, 0.7317471315868381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 18}], {
             RGBColor[
             0.9692770544063248, 0.9734175595259907, 0.7474672305772001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 74}], {
             RGBColor[
             0.909010509687477, 0.9256078266033538, 0.7502192883025007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 102}], {
             RGBColor[
             0.9063222891856516, 0.5687552194511105, 0.3417057295474893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 132}], {
             RGBColor[
             0.896284952197167, 0.9156286210821021, 0.7489609820272407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 160}], {
             RGBColor[
             0.9114125623801264, 0.6078812897957802, 0.3465801809071596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 166}], {
             RGBColor[
             0.9090583234505556, 0.5897855777490221, 0.34432575904947005`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 185}], {
             RGBColor[
             0.9085190133388343, 0.5856402039031354, 0.34380931507742224`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 198}], {
             RGBColor[
             0.9099185860419527, 0.9263319020393368, 0.75030590143584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 213}], {
             RGBColor[
             0.9521578283629528, 0.8364523308595698, 0.38226017426140096`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 216}], {
             RGBColor[
             0.8262245586177389, 0.8608969091391403, 0.7419780167468455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 224}], {
             RGBColor[
             0.9845045256450395, 0.9588710430060774, 0.43862463761941295`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 247}], {
             RGBColor[
             0.9501775412917424, 0.8286011525137683, 0.3806667888005933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 289}], {
             RGBColor[
             0.9455504255792939, 0.808391434737298, 0.3768472415142159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 302}], {
             RGBColor[
             0.9903122885265428, 0.9784619909329613, 0.461186699710061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 323}], {
             RGBColor[
             0.9117788938600264, 0.9278152609967583, 0.7504833392562442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 340}], {
             RGBColor[
             0.9935628356137232, 0.988639881211936, 0.5407325660065214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 40}], {
             RGBColor[
             0.36435856265805855`, 0.4900108066057379, 0.9444375833163132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 41}], {
             RGBColor[
             0.36511265513899505`, 0.490663963610935, 0.9444856334223808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 80}], {
             RGBColor[
             0.36191069619973304`, 0.48789058771288196`, 0.9442816074301521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 96}], {
             RGBColor[
             0.3381582412697068, 0.46529865529748227`, 0.9428420383243149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 114}], {
             RGBColor[
             0.359141437487956, 0.48549199500373064`, 0.9441051527137969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 153}], {
             RGBColor[
             0.3534178774592668, 0.48053453498137155`, 0.9437404525299142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 154}], {
             RGBColor[
             0.40978151173656857`, 0.5293538820737408, 0.9473318934656592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 192}], {
             RGBColor[
             0.36694736915401993`, 0.4922531006753419, 0.9446025397770442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 203}], {
             RGBColor[
             0.3404012849561078, 0.4676562364290735, 0.9429697763439697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 222}], {
             RGBColor[
             0.4971659473495666, 0.600925351032558, 0.9540373638977802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 228}], {
             RGBColor[
             0.37863108577837257`, 0.5023729487746839, 0.9453470158688431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 312}], {
             RGBColor[
             0.42618108450073044`, 0.5432966415402436, 0.9484491754681994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 332}], {
             RGBColor[
             0.45831330080032634`, 0.5693830222721039, 0.9509787412394903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 356}], {
             RGBColor[
             0.4538916995859768, 0.5657933672154302, 0.9506306565950378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 361}], {
             RGBColor[
             0.3725157575792012, 0.497076158853894, 0.9449573525635642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 385}], {
             RGBColor[
             0.4824130197414953, 0.5889482597885108, 0.9528759593947184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 17}], {
             RGBColor[
             0.42291827954092154`, 0.5385004052405986, 0.9487856331227857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.3116185481608299, 0.44433005683844234`, 0.9410770362287135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 36}], {
             RGBColor[
             0.41499862525248465`, 0.5320708731128857, 0.9481621689265505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 60}], {
             RGBColor[
             0.33392414851101215`, 0.4636500467496988, 0.9424983293589592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 64}], {
             RGBColor[
             0.3546401133620532, 0.4815931742890025, 0.9438183323208591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.34476855469957235`, 0.4730429263345264, 0.9431893253319623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 157}], {
             RGBColor[
             0.38978189814954545`, 0.5115987980501094, 0.9461770157970921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 171}], {
             RGBColor[
             0.2917662705538139, 0.42384970493064567`, 0.9399323578314926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 182}], {
             RGBColor[
             0.29920713316336395`, 0.4316705233112208, 0.9403561039493367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 210}], {
             RGBColor[
             0.30512183219392025`, 0.43788724700591375`, 0.9406929373091137]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 253}], {
             RGBColor[
             0.3260178665234107, 0.4568020226733255, 0.9419945480619598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 61}], {
             RGBColor[
             0.9095066708030527, 0.5932363190069687, 0.34466666805378354`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 131}], {
             RGBColor[
             0.8740668087143025, 0.4643040105665355, 0.21434257277214977`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 142}], {
             RGBColor[
             0.8236257057163587, 0.18260310375199956`, 0.1702573085163904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 202}], {
             RGBColor[
             0.8410035318945833, 0.31617669076982174`, 0.1868983344901058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 214}], {
             RGBColor[
             0.9047202658222255, 0.5928576663351037, 0.5422822863417485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 215}], {
             RGBColor[
             0.822477817482793, 0.1737799317809825, 0.1691580894475736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 217}], {
             RGBColor[
             0.8242465537218799, 0.18737521357976708`, 0.17085183326762515`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 269}], {
             RGBColor[
             0.909363183463878, 0.5929294140972693, 0.329048956685827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 279}], {
             RGBColor[
             0.8856585389447988, 0.5102613582153388, 0.22366955100848618`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 300}], {
             RGBColor[
             0.8578321079350941, 0.3958398187210729, 0.2010677137447785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 306}], {
             RGBColor[
             0.8980217768542582, 0.5550152880766823, 0.25581485333926096`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 363}], {
             RGBColor[
             0.8440899658094313, 0.333439960887275, 0.18960093350439794`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 39}], {
             RGBColor[
             0.3175089705748625, 0.446135594734304, 0.9415730679165266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 177}], {
             RGBColor[
             0.34191718866131093`, 0.47057321638600846`, 0.9430076388093683]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.3312363099818102, 0.46056389881459425`, 0.9423548195879734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 200}], {
             RGBColor[
             0.31629276558560215`, 0.4448572861787412, 0.9415038068416022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 216}], {
             RGBColor[
             0.5105137254220357, 0.6107590812291837, 0.9554696590225349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 219}], {
             RGBColor[
             0.4045568603314619, 0.5248285516252523, 0.9469989832981036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 241}], {
             RGBColor[
             0.32644391245681637`, 0.4555267851602728, 0.9420818996386419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 296}], {
             RGBColor[
             0.331723708667086, 0.46107618573568054`, 0.9423825762220581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 311}], {
             RGBColor[
             0.4406499577202704, 0.5542970021663628, 0.9497943740304772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 339}], {
             RGBColor[
             0.3638431893323356, 0.48956441613441326`, 0.9444047441837249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 360}], {
             RGBColor[
             0.336158799712734, 0.4655855893037951, 0.9426407193575084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 374}], {
             RGBColor[
             0.31901480157328777`, 0.4477183185888486, 0.9416588227642095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 14}], {
             RGBColor[
             0.9589098698169762, 0.8623003371232989, 0.4422276945427869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 25}], {
             RGBColor[
             0.8860868883930885, 0.5548412704093811, 0.2257767948788701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 38}], {
             RGBColor[
             0.9446269367354516, 0.8152649274529434, 0.2894401056343812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 78}], {
             RGBColor[
             0.8826533057204708, 0.5284492493821207, 0.22248879223389445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 102}], {
             RGBColor[
             0.8713798486298555, 0.4417965181232547, 0.21169331699237254`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 144}], {
             RGBColor[
             0.9009503839038591, 0.6375798223152109, 0.23877628985540691`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 205}], {
             RGBColor[
             0.9593655870867921, 0.8632867059265485, 0.49267549542961175`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 207}], {
             RGBColor[
             0.931659240059644, 0.7667586905843885, 0.26386962426942273`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 213}], {
             RGBColor[
             0.9172153878071567, 0.709493629531714, 0.2522477617062842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 221}], {
             RGBColor[
             0.9226607888866434, 0.8373956409938654, 0.6248416927368453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 230}], {
             RGBColor[
             0.9461599473200244, 0.8204361321227099, 0.29539556227068897`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 250}], {
             RGBColor[
             0.9558449394073578, 0.8618308276345842, 0.5510217386219683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 289}], {
             RGBColor[
             0.9106079850234978, 0.6814327334094423, 0.24683482895909917`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 358}], {
             RGBColor[
             0.9460196672175634, 0.8199629343977746, 0.2948506005623025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 391}], {
             RGBColor[
             0.8719267260498035, 0.4460000576161881, 0.2122170074273244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 118}], {
             RGBColor[
             0.21224930323971947`, 0.34041785346099757`, 0.9353986558735721]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 126}], {
             RGBColor[
             0.2152393660615204, 0.3435605990676429, 0.935568935527872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 149}], {
             RGBColor[
             0.21932780961758047`, 0.3478578124673555, 0.9358017663400795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 199}], {
             RGBColor[
             0.22211987446733733`, 0.350792449651586, 0.9359607703027832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 212}], {
             RGBColor[
             0.2146670795751315, 0.34295908968538924`, 0.9355363446590942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 238}], {
             RGBColor[
             0.22383004590865202`, 0.3525899482675398, 0.9360581620363942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 259}], {
             RGBColor[
             0.2147288372822968, 0.3430240009512847, 0.9355398616691548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 274}], {
             RGBColor[
             0.2245824786939262, 0.35338080283185697`, 0.936101011970391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 299}], {
             RGBColor[
             0.21628284341415968`, 0.3446573599255522, 0.9356283600194184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 318}], {
             RGBColor[
             0.2211272263803799, 0.3497491135746699, 0.9359042404627222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 336}], {
             RGBColor[
             0.21472177259901426`, 0.343016575521228, 0.9355394593458932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 367}], {
             RGBColor[
             0.21887583976336028`, 0.3473827634940262, 0.9357760273255111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 18}], {
             RGBColor[
             0.9544933475167275, 0.9655817936050558, 0.9619150720050708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 69}], {
             RGBColor[
             0.7259993754166094, 0.7839523785382002, 0.9495242388978706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 74}], {
             RGBColor[
             0.8942268027978797, 0.9177720606824189, 0.9646671297303714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 88}], {
             RGBColor[
             0.9770469480723544, 0.9813851840644524, 0.8781922259657269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 132}], {
             RGBColor[
             0.8815012453075697, 0.9077928551611671, 0.9634088234551113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[
             0.8178525622986523, 0.8580700202466935, 0.9570649175635426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 191}], {
             RGBColor[
             0.8213167457883995, 0.8607762667176537, 0.9574101949991654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 198}], {
             RGBColor[
             0.8951348791523555, 0.9184961361184019, 0.9647537428637106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 216}], {
             RGBColor[
             0.8114408517281416, 0.8530611432182054, 0.956425858174716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 224}], {
             RGBColor[
             0.9697208187554422, 0.9510352770851425, 0.6530724790472836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 302}], {
             RGBColor[
             0.9755285816369456, 0.9706262250120263, 0.6756345411379316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 323}], {
             RGBColor[
             0.8969951869704291, 0.9199794950758233, 0.9649311806841149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 340}], {
             RGBColor[
             0.9787791287241259, 0.9808041152910011, 0.7551804074343922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 357}], {
             RGBColor[
             0.8197351159980406, 0.8595406855045937, 0.9572525529228332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 38}], {
             RGBColor[
             0.9800741446959539, 0.9433032752196526, 0.4743933351284341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 102}], {
             RGBColor[
             0.9068270565903578, 0.5698348658899638, 0.39664654648642544`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 205}], {
             RGBColor[
             0.9948127950472943, 0.9913250536932577, 0.6776287249236647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 207}], {
             RGBColor[
             0.9671064480201461, 0.8947970383510977, 0.44882285376347564`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.9526625957676589, 0.8375319772984231, 0.4372009912003371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 224}], {
             RGBColor[
             0.9850092930497456, 0.9599506894449308, 0.4935654545583491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 230}], {
             RGBColor[
             0.9816071552805266, 0.9484744798894191, 0.4803487917647419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 247}], {
             RGBColor[
             0.9506823086964485, 0.8296807989526216, 0.43560760573952945`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 250}], {
             RGBColor[
             0.99129214736786, 0.9898691754012934, 0.7359749681160213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 289}], {
             RGBColor[
             0.9460551929840001, 0.8094710811761514, 0.43178805845315205`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 340}], {
             RGBColor[
             0.9940676030184292, 0.9897195276507893, 0.5956733829454577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 391}], {
             RGBColor[
             0.9073739340103057, 0.5740384053828973, 0.3971702369213773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 45}], {
             RGBColor[
             0.29968000514429743`, 0.4323130645893829, 0.9403777050049051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 100}], {
             RGBColor[
             0.34023750094859895`, 0.4686666959527124, 0.9429171480552854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 105}], {
             RGBColor[
             0.36060251301143975`, 0.486305845826277, 0.9442147886158565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.3163910437219365, 0.4480120932607672, 0.9413976728873965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 155}], {
             RGBColor[
             0.30420326810120896`, 0.4370673007485326, 0.9406352981387334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 170}], {
             RGBColor[
             0.3744152758657625, 0.49826976676104406`, 0.9450949256507872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 180}], {
             RGBColor[
             0.33506546922916314`, 0.4641869420312098, 0.9425875907675709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 183}], {
             RGBColor[
             0.281397272925088, 0.41309675383481925`, 0.9393365304518997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 239}], {
             RGBColor[
             0.3141879177885835, 0.4461038563096259, 0.9412572916510711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 271}], {
             RGBColor[
             0.3053243996883596, 0.43824568113047624`, 0.940699144924056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 273}], {
             RGBColor[
             0.28964915667663804`, 0.4217700068573468, 0.9398064630239824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 326}], {
             RGBColor[
             0.3216255760176605, 0.45254598204008034`, 0.9417312126565649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 335}], {
             RGBColor[
             0.2921895478533735, 0.4244401190541993, 0.9399511345433256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 394}], {
             RGBColor[
             0.33136443385417313`, 0.4609812912088401, 0.9423517640661736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 73}], {
             RGBColor[
             0.24248824364408117`, 0.372200897085539, 0.937120718795097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 85}], {
             RGBColor[
             0.2415839884274967, 0.3712504675198166, 0.9370692227982382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 96}], {
             RGBColor[
             0.2643859994981743, 0.3952168268861021, 0.9383677635961609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 110}], {
             RGBColor[
             0.2487192272457111, 0.3787500559180304, 0.9374755640932957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 115}], {
             RGBColor[
             0.240233305102069, 0.36983081370652304`, 0.936992303381012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 184}], {
             RGBColor[
             0.22981171473055614`, 0.35887706145906934`, 0.9363988092267157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 188}], {
             RGBColor[
             0.25447321455412675`, 0.38479786140304184`, 0.9378032451582485]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 203}], {
             RGBColor[
             0.2666290431845753, 0.3975744080176934, 0.9384955016158156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 206}], {
             RGBColor[
             0.23671129027789278`, 0.36612895281767627`, 0.9367917298471292]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 208}], {
             RGBColor[
             0.2374736143413805, 0.36693020374253915`, 0.9368351430747874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 258}], {
             RGBColor[
             0.24739688608388788`, 0.37736019151568206`, 0.9374002587203583]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 284}], {
             RGBColor[
             0.24292930031788273`, 0.3726644756143127, 0.9371458363201851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 325}], {
             RGBColor[
             0.22671411419860138`, 0.35562128690076766`, 0.9362224054589102]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 348}], {
             RGBColor[
             0.252407866634222, 0.38262704978860046`, 0.9376856266496183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 369}], {
             RGBColor[
             0.24965722981087085`, 0.3797359560868109, 0.9375289819517311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 392}], {
             RGBColor[
             0.24490486142793333`, 0.37474091559878486`, 0.9372583416028217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 36}], {
             RGBColor[
             0.5275969503288876, 0.6273659981055699, 0.9559535110626505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 64}], {
             RGBColor[
             0.46723843843845614`, 0.5768882992816866, 0.951609674456959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 82}], {
             RGBColor[
             0.4573668797759753, 0.5683380513272105, 0.9509806674680623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 122}], {
             RGBColor[
             0.490802095307585, 0.5972979545178956, 0.9531111298361363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 157}], {
             RGBColor[
             0.5023802232259484, 0.6068939230427937, 0.9539683579331921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 187}], {
             RGBColor[
             0.6897252223294911, 0.7560947412907055, 0.9707766661911668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 218}], {
             RGBColor[
             0.7227901892843811, 0.7824598484159166, 0.9739304322567687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 253}], {
             RGBColor[
             0.43861619159981363`, 0.5520971476660097, 0.9497858901980598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 262}], {
             RGBColor[
             0.7370797325190604, 0.7937780282574919, 0.9726613937241215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 298}], {
             RGBColor[
             0.6794733687434446, 0.7479201915203444, 0.969798835244192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 74}], {
             RGBColor[
             0.8849400211257357, 0.9108459941170431, 0.9803872287207334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 132}], {
             RGBColor[
             0.8722144636354254, 0.9008667885957915, 0.9791289224454733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 140}], {
             RGBColor[
             0.8085657806265083, 0.8511439536813179, 0.9727850165539047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 191}], {
             RGBColor[
             0.8120299641162554, 0.853850200152278, 0.9731302939895274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.8858480974802114, 0.9115700695530261, 0.9804738418540726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 216}], {
             RGBColor[
             0.8021540700559975, 0.8461350766528297, 0.9721459571650781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.960434037083298, 0.9441092105197667, 0.6687925780376456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 247}], {
             RGBColor[
             0.926107052730001, 0.8138393200274576, 0.6108347292188259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 302}], {
             RGBColor[
             0.9662417999648014, 0.9637001584466507, 0.6913546401282936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 311}], {
             RGBColor[
             0.7322903023542322, 0.7896729975900088, 0.9664706721730203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 323}], {
             RGBColor[
             0.8877084052982851, 0.9130534285104475, 0.9806512796744769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 340}], {
             RGBColor[
             0.9694923470519816, 0.9738780487256253, 0.770900506424754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 357}], {
             RGBColor[
             0.8104483343258964, 0.8526146189392179, 0.9729726519131952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 83}], {
             RGBColor[
             0.31363288900734776`, 0.44289778603368235`, 0.9413217134716801]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 108}], {
             RGBColor[
             0.3209765938651673, 0.4492585340761873, 0.9417896478514372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 125}], {
             RGBColor[
             0.27618503388558474`, 0.4076183601292589, 0.9390397011494167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 179}], {
             RGBColor[
             0.2720136332383074, 0.4032339535668936, 0.9388021460535885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 196}], {
             RGBColor[
             0.2861541125436652, 0.4180964938749955, 0.9396074254310642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 231}], {
             RGBColor[
             0.2915341164557601, 0.4237512190985569, 0.9399138086948555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 303}], {
             RGBColor[
             0.2819979246761117, 0.4137280769086658, 0.939370736680536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 313}], {
             RGBColor[
             0.27859623109563336`, 0.41015268127575305`, 0.9391770152634824]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 344}], {
             RGBColor[
             0.2975063791842545, 0.4289298137668702, 0.9402941465258654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 50}], {
             RGBColor[
             0.4309033063250306, 0.5476259924741631, 0.9486839796675377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 54}], {
             RGBColor[
             0.4298252331165606, 0.5467147461063611, 0.9486090616680254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 116}], {
             RGBColor[
             0.4119401607737857, 0.531223595372923, 0.9474694406734923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 121}], {
             RGBColor[
             0.48042756078829996`, 0.5878320132896839, 0.9525827103922078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 130}], {
             RGBColor[
             0.4090322853711047, 0.5287049398531881, 0.9472841534241666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 135}], {
             RGBColor[
             0.45546851492086315`, 0.5675691354622958, 0.9506178428735257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 147}], {
             RGBColor[
             0.34619840677068126`, 0.47206167326583015`, 0.9433617090301424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 158}], {
             RGBColor[
             0.4553874406509526, 0.5675033157176284, 0.9506114604100135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 172}], {
             RGBColor[
             0.3545418209166673, 0.4808311305362721, 0.9438368541227812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 181}], {
             RGBColor[
             0.4874856363228792, 0.5935620769713348, 0.9531383479528726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 265}], {
             RGBColor[
             0.49977683892029745`, 0.6035406289522859, 0.9541059564454999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 322}], {
             RGBColor[
             0.45803755349750475`, 0.5696547967126826, 0.9508200870009773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 328}], {
             RGBColor[
             0.3585480828066595, 0.484978061001665, 0.9440673446781876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 347}], {
             RGBColor[
             0.3438545327447645, 0.469598113054395, 0.9432282288718172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 362}], {
             RGBColor[
             0.406159003588231, 0.5262162475882044, 0.9471010704497052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 364}], {
             RGBColor[
             0.37859437323609996`, 0.5023411502157933, 0.945344676578113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 387}], {
             RGBColor[
             0.3506138656824209, 0.476702600538333, 0.94361316288308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.416297218948796, 0.5331956497034136, 0.948244914168578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 60}], {
             RGBColor[
             0.33522274220732345`, 0.4647748233402267, 0.9425810746009868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 64}], {
             RGBColor[
             0.3559387070583645, 0.4827179508795304, 0.9439010775628867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 82}], {
             RGBColor[
             0.34606714839588365`, 0.4741677029250543, 0.94327207057399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 122}], {
             RGBColor[
             0.37950236392749337`, 0.5031276061157393, 0.9454025329420639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 159}], {
             RGBColor[
             0.3221758681761928, 0.45347427680941704`, 0.9417497393246208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 182}], {
             RGBColor[
             0.30050572685967525`, 0.4327952999017487, 0.9404388491913643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 210}], {
             RGBColor[
             0.30642042589023155`, 0.43901202359644165`, 0.9407756825511414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 263}], {
             RGBColor[
             0.2875003760669833, 0.4191258516317633, 0.9396982137034129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 29}], {
             RGBColor[
             0.2663738031073146, 0.39730613451333674`, 0.9384809660710094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 45}], {
             RGBColor[
             0.2939087453063859, 0.4262471045807297, 0.94004904029495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 91}], {
             RGBColor[
             0.2774698045998931, 0.40896873560916513`, 0.9391128669409485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 97}], {
             RGBColor[
             0.36730142212889694`, 0.4910409193978484, 0.9446807120447999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 100}], {
             RGBColor[
             0.3344662411106874, 0.46260073594405915`, 0.9425884833453301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 141}], {
             RGBColor[
             0.32619117202571163`, 0.45543328701971864`, 0.9420612032605917]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 150}], {
             RGBColor[
             0.28145958694833023`, 0.41316224982418415`, 0.9393400791433381]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 189}], {
             RGBColor[
             0.29643257003583556`, 0.4288998043911114, 0.9401927683796281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 190}], {
             RGBColor[
             0.26671069132338054`, 0.3976602253883686, 0.938500151356533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 255}], {
             RGBColor[
             0.27639668732322686`, 0.40784082131182386`, 0.9390517544995772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 266}], {
             RGBColor[
             0.27365816407618504`, 0.40496245974678047`, 0.9388957996519403]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 273}], {
             RGBColor[
             0.28387789683872655`, 0.4157040468486936, 0.9394777983140272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 350}], {
             RGBColor[
             0.36253057369193453`, 0.4869086502715662, 0.9443767178010922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 365}], {
             RGBColor[
             0.27427955709376345`, 0.40561558320684826`, 0.9389311870650228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 394}], {
             RGBColor[
             0.32559317401626164`, 0.45491533120018696`, 0.9420230993562184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[
             0.2165666874460731, 0.34495569799984427`, 0.9356445245171263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 89}], {
             RGBColor[
             0.21600037669219402`, 0.3443604694913417, 0.9356122739574746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 163}], {
             RGBColor[
             0.22919558870789478`, 0.35822947394460614`, 0.9363637217612019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 164}], {
             RGBColor[
             0.22797821780387265`, 0.3569499399387055, 0.9362943942891566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 169}], {
             RGBColor[
             0.21705819820147026`, 0.34547230696734843`, 0.9356725153275212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 227}], {
             RGBColor[
             0.22416996966139735`, 0.3529472296840859, 0.936077520191241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 245}], {
             RGBColor[
             0.22165838805798918`, 0.35030739817543277`, 0.9359344893344789]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 292}], {
             RGBColor[
             0.21221830344661968`, 0.3403852707129492, 0.9353968904812151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 304}], {
             RGBColor[
             0.2162581809318601, 0.34463143809296365`, 0.9356269555275363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 353}], {
             RGBColor[
             0.21189878814995255`, 0.34004943987771225`, 0.9353786945577505]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 378}], {
             RGBColor[
             0.21097218176330165`, 0.339075517815104, 0.9353259256948219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 25}], {
             RGBColor[
             0.8754320696783777, 0.5120010563873596, 0.21717277432657275`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 76}], {
             RGBColor[
             0.8745487301949283, 0.505211322035738, 0.2163268874396324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 104}], {
             RGBColor[
             0.9180135558932775, 0.712060691693382, 0.25285908317008815`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 109}], {
             RGBColor[
             0.9481247371168586, 0.8202041529201762, 0.49378352937662584`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 138}], {
             RGBColor[
             0.8607479504188854, 0.399132481136813, 0.2031112451403423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 144}], {
             RGBColor[
             0.8902955651891483, 0.5947396082931894, 0.23017226930310958`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 207}], {
             RGBColor[
             0.9210044213449331, 0.723918476562367, 0.2552656037171254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 233}], {
             RGBColor[
             0.8598056285506199, 0.3918893823292492, 0.202208876655091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 242}], {
             RGBColor[
             0.9102499321760205, 0.681280510728698, 0.24661228929151274`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 317}], {
             RGBColor[
             0.946390043794504, 0.8194868126517976, 0.5225318869704552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 358}], {
             RGBColor[
             0.9353648485028525, 0.777122720375753, 0.28624658001000514`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 366}], {
             RGBColor[
             0.9017167350633479, 0.6466004732099342, 0.2397023734046333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 382}], {
             RGBColor[
             0.9004669733536322, 0.6409255971753784, 0.23865954159958375`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[
             0.8478277754462535, 0.3686308171105509, 0.1934332378220659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 104}], {
             RGBColor[
             0.8912926011446027, 0.575480186768195, 0.22996543355252164`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 109}], {
             RGBColor[
             0.9214037823681839, 0.6836236479949891, 0.47088987975905927`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 138}], {
             RGBColor[
             0.8340269956702107, 0.26255197621162585`, 0.18021759552277578`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 144}], {
             RGBColor[
             0.8635746104404736, 0.45815910336800225`, 0.20727861968554306`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 205}], {
             RGBColor[
             0.9219898136234065, 0.68386598697934, 0.46117782525974793`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 207}], {
             RGBColor[
             0.8942834665962583, 0.5873379716371798, 0.2323719540995589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 233}], {
             RGBColor[
             0.8330846738019452, 0.25530887740406205`, 0.17931522703752448`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 317}], {
             RGBColor[
             0.9196690890458292, 0.6829063077266104, 0.4996382373528887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 358}], {
             RGBColor[
             0.9086438937541778, 0.640542215450566, 0.2633529303924386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 366}], {
             RGBColor[
             0.8749957803146731, 0.510019968284747, 0.21680872378706678`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 382}], {
             RGBColor[
             0.8737460186049575, 0.5043450922501913, 0.21576589198201723`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 391}], {
             RGBColor[
             0.8345509525864179, 0.2665793386689794, 0.18071933725746053`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 30}], {
             RGBColor[
             0.31701994287924884`, 0.4369570883961569, 0.9418741496415883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 62}], {
             RGBColor[
             0.31709055637755623`, 0.43703130766003234`, 0.9418781709758536]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 77}], {
             RGBColor[
             0.6422389788407158, 0.7176486903810251, 0.9669170377654001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 106}], {
             RGBColor[
             0.7018038352541023, 0.7648141211568, 0.9611581586207743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 111}], {
             RGBColor[
             0.6645955027358419, 0.5448101324102603, 0.5834436797495368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 160}], {
             RGBColor[
             0.6422952177337565, 0.39805166532506286`, 0.5630541845557195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.6399409788041857, 0.37995595327830467`, 0.56079976269803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 173}], {
             RGBColor[
             0.34074023236907375`, 0.46188861660318076`, 0.9432249850370102]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 185}], {
             RGBColor[
             0.6394016686924645, 0.37581057943241813`, 0.5602833187259821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 197}], {
             RGBColor[
             0.7219321437839568, 0.7790682930787789, 0.8931643392096228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 204}], {
             RGBColor[
             0.3170199268376633, 0.4369570715354334, 0.9418741487280438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 345}], {
             RGBColor[
             0.3285301240705917, 0.4490550186158963, 0.9425296374326482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 370}], {
             RGBColor[
             0.6431647387570222, 0.7183868662092043, 0.9670053375726531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 389}], {
             RGBColor[
             0.31710049015279534`, 0.4370417486876464, 0.9418787366896577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 400}], {
             RGBColor[
             0.4223618806328297, 0.5402016308185901, 0.9481469689308566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 51}], {
             RGBColor[
             0.33517005330446453`, 0.4636817173337682, 0.9426160703012283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[
             0.3427358884343137, 0.47023486345331306`, 0.943098158625497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 277}], {
             RGBColor[
             0.277614773953709, 0.4091211075916136, 0.9391211227311855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 287}], {
             RGBColor[
             0.27881505582512084`, 0.4103826799407336, 0.9391894770081045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 376}], {
             RGBColor[
             0.3679050083022842, 0.49203509004620194`, 0.9447019126873052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 377}], {
             RGBColor[
             0.3561480526956704, 0.48185180602152367`, 0.9439527698723194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 395}], {
             RGBColor[
             0.28524240829505776`, 0.41713823490432095`, 0.9395555052228516]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 396}], {
             RGBColor[
             0.28785811658992677`, 0.419887510167713, 0.9397044659406507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 44}], {
             RGBColor[
             0.29312282823703784`, 0.42542105591082463`, 0.9400042834805107]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 47}], {
             RGBColor[
             0.3610905157265072, 0.4852888096589335, 0.9442985989042187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 49}], {
             RGBColor[
             0.27201275594263963`, 0.40323303147352313`, 0.938802096092898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 147}], {
             RGBColor[
             0.2865134731880893, 0.418474204697066, 0.9396278904881377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 211}], {
             RGBColor[
             0.2754831553698227, 0.4068806413075249, 0.9389997302062802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 301}], {
             RGBColor[
             0.27255350960952185`, 0.40380139786317903`, 0.9388328912142536]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 328}], {
             RGBColor[
             0.2988631492240676, 0.4313905924329009, 0.9403335261361829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 347}], {
             RGBColor[
             0.28416959916217255`, 0.4160106444856309, 0.9394944103298126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 362}], {
             RGBColor[
             0.34647407000563907`, 0.4726287790194402, 0.9433672519077005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 372}], {
             RGBColor[
             0.2698833093261751, 0.4009948480649053, 0.9386808272583244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 380}], {
             RGBColor[
             0.2768898890919296, 0.40835920764152867`, 0.9390798416106783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 390}], {
             RGBColor[
             0.2772941937947283, 0.40878415751856884`, 0.9391028661653874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 45}], {
             RGBColor[
             0.26796415172899, 0.39897769174864406`, 0.938571534072304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 91}], {
             RGBColor[
             0.25152521102249714`, 0.3816993227770795, 0.9376353607183026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 150}], {
             RGBColor[
             0.2555149933709343, 0.38589283699209853`, 0.937862572920692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 190}], {
             RGBColor[
             0.2407660977459846, 0.370390812556283, 0.937022645133887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 226}], {
             RGBColor[
             0.23953161826969796`, 0.36909329635618626`, 0.936952343353961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 266}], {
             RGBColor[
             0.2477135704987891, 0.37769304691469485`, 0.9374182934292943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 273}], {
             RGBColor[
             0.25793330326133057`, 0.388434634016608, 0.9380002920913812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 365}], {
             RGBColor[
             0.24833496351636752`, 0.37834617037476265`, 0.9374536808423768]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 62}], {
             RGBColor[
             0.17899764558147852`, 0.30546825298532254`, 0.9335050231613544]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 77}], {
             RGBColor[
             0.5041460680446381, 0.5860856357063153, 0.9585438899509009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 84}], {
             RGBColor[
             0.1789270231889713, 0.3053940243730791, 0.9335010013205776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 204}], {
             RGBColor[
             0.17892701604158556`, 0.30539401686072354`, 0.9335010009135446]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 333}], {
             RGBColor[
             0.1872437438170861, 0.31413542506377157`, 0.9339746262568631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 370}], {
             RGBColor[
             0.5050718279609444, 0.5868238115344944, 0.9586321897581539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 389}], {
             RGBColor[
             0.17900757935671766`, 0.3054786940129366, 0.9335055888751587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 400}], {
             RGBColor[
             0.284268969836752, 0.4086385761438802, 0.9397738211163575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 33}], {
             RGBColor[0.1810793999809316, 0.30765630885, 0.9336235759947237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 106}], {
             RGBColor[
             0.5658561150624204, 0.6355057978202503, 0.9529071762376704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 156}], {
             RGBColor[
             0.18458847622123073`, 0.3113445704668384, 0.9338234126953957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 173}], {
             RGBColor[
             0.20479251217739197`, 0.3325802932666311, 0.9349740026539064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 175}], {
             RGBColor[
             0.18107477738655686`, 0.3076514502102228, 0.9336233127448126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 197}], {
             RGBColor[
             0.5859844235922751, 0.6497599697422292, 0.884913356826519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 204}], {
             RGBColor[
             0.1810722066459815, 0.3076487481988837, 0.9336231663449399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 214}], {
             RGBColor[
             0.5834952534993698, 0.6486610383850888, 0.9230487158880236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 261}], {
             RGBColor[
             0.18133289143212553`, 0.3079227444374911, 0.9336380119578622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 295}], {
             RGBColor[
             0.21280238164412135`, 0.34099917393122015`, 0.9354301528704966]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 310}], {
             RGBColor[
             0.18289778193115996`, 0.30956754357176464`, 0.9337271301567341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 345}], {
             RGBColor[
             0.1925824038789099, 0.3197466952793466, 0.9342786550495443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 43}], {
             RGBColor[
             0.2218603287150994, 0.3505196506098328, 0.9359459895561568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 124}], {
             RGBColor[
             0.21977833860588586`, 0.34833134699925217`, 0.9358274232994656]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 137}], {
             RGBColor[
             0.21892075175740905`, 0.34742996884735633`, 0.9357785849971308]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 199}], {
             RGBColor[
             0.22104408708317058`, 0.349661728901967, 0.9358995058027398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 238}], {
             RGBColor[
             0.22275425852448527`, 0.3514592275179208, 0.9359968975363508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 252}], {
             RGBColor[
             0.2203092674216852, 0.34888938684748844`, 0.9358576589100864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 293}], {
             RGBColor[
             0.2137582367821496, 0.342003838286004, 0.9354845874065463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 330}], {
             RGBColor[
             0.2205286799485376, 0.349120003324768, 0.935870154128899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 63}], {
             RGBColor[
             0.5687512197366357, 0.5886439817299056, 0.6135098819197802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 84}], {
             RGBColor[
             0.17893420048233583`, 0.30540156816347186`, 0.9335014100568169]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 90}], {
             RGBColor[
             0.44237359411374266`, 0.5377546224462848, 0.9524068017673784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 152}], {
             RGBColor[
             0.18127877637637368`, 0.30786586608280325`, 0.9336349301854932]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 156}], {
             RGBColor[
             0.18245046291019928`, 0.30909738291907096`, 0.9337016560002396]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 173}], {
             RGBColor[
             0.20265449886636056`, 0.33033310571886365`, 0.9348522459587503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 175}], {
             RGBColor[
             0.17893676407552545`, 0.30540426266245535`, 0.9335015560496566]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 204}], {
             RGBColor[
             0.1789341933349501, 0.3054015606511163, 0.9335014096497838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 214}], {
             RGBColor[
             0.5813572401883383, 0.6464138508373214, 0.9229269591928677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 256}], {
             RGBColor[
             0.202124876078153, 0.3297764385884332, 0.9348220847244686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 261}], {
             RGBColor[
             0.17919487812109408`, 0.3056755568897237, 0.9335162552627061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 264}], {
             RGBColor[
             0.18448620056776344`, 0.31123707227039327`, 0.9338175882482339]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 295}], {
             RGBColor[
             0.21066436833308994`, 0.3387519863834527, 0.9353083961753406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 310}], {
             RGBColor[
             0.18075976862012855`, 0.3073203560239972, 0.9336053734615781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 333}], {
             RGBColor[
             0.1872509211104506, 0.3141429688541644, 0.9339750349931024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 381}], {
             RGBColor[
             0.5860442078575524, 0.648421627973087, 0.8483684065741224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 53}], {
             RGBColor[
             0.30076648553276153`, 0.4331274488318972, 0.9404515726006413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 68}], {
             RGBColor[
             0.29450681654452554`, 0.42654813983932427`, 0.9400950937121118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 86}], {
             RGBColor[
             0.30641268277319833`, 0.4390619601211778, 0.940773115180684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 95}], {
             RGBColor[
             0.29703377047989377`, 0.4292041286435296, 0.9402390000004376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 151}], {
             RGBColor[
             0.31406226415390115`, 0.44644668080690353`, 0.9412327476508988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 244}], {
             RGBColor[
             0.2861625929026812, 0.4177778317374103, 0.9396199025198813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 249}], {
             RGBColor[
             0.2909291460215572, 0.4227877812822719, 0.9398913506685179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 253}], {
             RGBColor[
             0.3270023945629662, 0.4576547713773704, 0.9420572813180563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 270}], {
             RGBColor[
             0.28093807902462586`, 0.41228653639826196`, 0.9393223741835017]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 308}], {
             RGBColor[
             0.2866886948098787, 0.4183307981986623, 0.9396498632451982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 386}], {
             RGBColor[
             0.32582607560218535`, 0.4566359030170521, 0.9419823273140535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 397}], {
             RGBColor[
             0.28081927975955956`, 0.41216167083836874`, 0.939315608741104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 41}], {
             RGBColor[
             0.3109306833758936, 0.44117275107327436`, 0.9411269955899995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 57}], {
             RGBColor[
             0.2771242370211076, 0.4086055221736117, 0.9390931873785582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 92}], {
             RGBColor[
             0.28435244626912165`, 0.4162028283882106, 0.9395048232020553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 114}], {
             RGBColor[
             0.30495946572485455`, 0.43600078246607, 0.9407465148814157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 153}], {
             RGBColor[
             0.2992359056961653, 0.4310433224437109, 0.940381814697533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 188}], {
             RGBColor[
             0.27406348456255775`, 0.4053884772767613, 0.9389188820540213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 195}], {
             RGBColor[
             0.2633678783864708, 0.39414671704509485`, 0.9383097831050244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 208}], {
             RGBColor[
             0.25706388434981153`, 0.3875208196162586, 0.9379507799705602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 258}], {
             RGBColor[
             0.2669871560923189, 0.3979508073894016, 0.938515895616131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 278}], {
             RGBColor[
             0.26672833715189703`, 0.3976787722729497, 0.9385011562603622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 284}], {
             RGBColor[
             0.26251957032631373`, 0.3932550914880322, 0.9382614732159579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 327}], {
             RGBColor[
             0.29981659218631795`, 0.43154628389532945`, 0.9404188155272046]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 337}], {
             RGBColor[
             0.28289219144336497`, 0.41466800798083686`, 0.9394216638499819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 354}], {
             RGBColor[
             0.2804072432672092, 0.41205616989288285`, 0.9392801497275012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 369}], {
             RGBColor[
             0.26924749981930185`, 0.40032657196053045`, 0.9386446188475038]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 392}], {
             RGBColor[
             0.2644951314363644, 0.3953315314725043, 0.9383739784985945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 55}], {
             RGBColor[
             0.46160497467818506`, 0.5724389504821938, 0.9511318842995795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 60}], {
             RGBColor[
             0.4386028192989782, 0.5525156396146701, 0.9496662072988238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 64}], {
             RGBColor[
             0.45931878415001925`, 0.5704587671539738, 0.9509862102607236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 82}], {
             RGBColor[
             0.4494472254875384, 0.5619085191994977, 0.950357203271827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 122}], {
             RGBColor[
             0.4828824410191481, 0.5908684223901826, 0.952487665639901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 157}], {
             RGBColor[
             0.49446056893751156`, 0.6004643909150807, 0.9533448937369567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 165}], {
             RGBColor[
             0.5262130350709433, 0.6262424733544989, 0.9558445641840965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 218}], {
             RGBColor[
             0.7148705349959443, 0.7760303162882036, 0.9733069680605333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 262}], {
             RGBColor[
             0.7291600782306236, 0.787348496129779, 0.9720379295278863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 298}], {
             RGBColor[
             0.6715537144550077, 0.7414906593926315, 0.9691753710479567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 314}], {
             RGBColor[
             0.7227446385125958, 0.7823089126955356, 0.9740580070832467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 58}], {
             RGBColor[
             0.2743052593933725, 0.40564259795335733`, 0.9389326507729624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 87}], {
             RGBColor[
             0.2699691213947309, 0.4010850419897568, 0.9386857141286811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 110}], {
             RGBColor[
             0.2526887349083196, 0.3829222601527542, 0.9377016216823209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 134}], {
             RGBColor[
             0.24206319644531432`, 0.3717541455300861, 0.9370965129859282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 159}], {
             RGBColor[
             0.29061706023566036`, 0.4206896192842019, 0.9399383913431659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 167}], {
             RGBColor[
             0.26667449670074206`, 0.39762218254510395`, 0.9384980901263189]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 201}], {
             RGBColor[
             0.26311290635419504`, 0.3938787252730125, 0.9382952628249838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 236}], {
             RGBColor[
             0.2501608630823501, 0.3802653065873294, 0.9375576631214831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 243}], {
             RGBColor[
             0.2690857390615694, 0.4001565511479292, 0.9386354068116546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 263}], {
             RGBColor[
             0.25594156812645086`, 0.3863411941065481, 0.9378868657219579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 348}], {
             RGBColor[
             0.2563773742968305, 0.38679925402332427`, 0.9379116842386436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 351}], {
             RGBColor[
             0.2477720085286644, 0.3777544689892789, 0.9374216213886444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 78}], {
             RGBColor[
             0.9038175805994484, 0.6094521874784743, 0.2546544328195417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 102}], {
             RGBColor[
             0.8925441235088332, 0.5227994562196083, 0.24385895757801979`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 205}], {
             RGBColor[
             0.9805298619657696, 0.9442896440229023, 0.524841136015259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 207}], {
             RGBColor[
             0.9528235149386215, 0.8477616286807421, 0.29603526485507003`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 213}], {
             RGBColor[
             0.9383796626861343, 0.7904965676280676, 0.28441340229193146`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 221}], {
             RGBColor[
             0.9438250637656209, 0.9183985790902189, 0.6570073333224926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 224}], {
             RGBColor[
             0.970726359968221, 0.9129152797745752, 0.34077786564994345`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 230}], {
             RGBColor[
             0.9673242221990019, 0.9014390702190636, 0.3275612028563362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 247}], {
             RGBColor[
             0.9363993756149239, 0.7826453892822661, 0.2828200168311238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 250}], {
             RGBColor[
             0.9770092142863354, 0.9428337657309378, 0.5831873792076157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 289}], {
             RGBColor[
             0.9317722599024755, 0.7624356715057958, 0.27900046954474644`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 358}], {
             RGBColor[
             0.9671839420965409, 0.9009658724941282, 0.3270162411479497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 391}], {
             RGBColor[
             0.8930910009287811, 0.5270029957125417, 0.24438264801297166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 93}], {
             RGBColor[
             0.2591650880555334, 0.38972931793498194`, 0.9380704404131488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 94}], {
             RGBColor[
             0.2666080163774077, 0.39755230751018356`, 0.9384943041702538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 119}], {
             RGBColor[
             0.2567952159774935, 0.3872384321223937, 0.9379354797042159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 128}], {
             RGBColor[
             0.2996526087721707, 0.4306693116276521, 0.9404352763322198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 177}], {
             RGBColor[
             0.29750028265951367`, 0.4288050749279245, 0.9402981320155486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 200}], {
             RGBColor[
             0.27187585958380484`, 0.4030891447206572, 0.9387943000477824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 225}], {
             RGBColor[
             0.26510008482719366`, 0.3959673758425263, 0.9384084296992539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 288}], {
             RGBColor[
             0.2590590279232666, 0.38961784201136873`, 0.9380644004455181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 296}], {
             RGBColor[
             0.2873068026652887, 0.4193080442775966, 0.9396730694282384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 316}], {
             RGBColor[
             0.26368578568270973`, 0.3944808577699287, 0.9383278874552436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 324}], {
             RGBColor[
             0.27652485948189337`, 0.40797553837716655`, 0.9390590537143996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 355}], {
             RGBColor[
             0.25200661552040216`, 0.3822053094271858, 0.9376627759922841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 360}], {
             RGBColor[
             0.29174189371093673`, 0.42381744784571107`, 0.9399312125636886]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 374}], {
             RGBColor[
             0.2745978955714905, 0.40595017713076464`, 0.9389493159703898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 375}], {
             RGBColor[
             0.2639687025623859, 0.39477822134843454`, 0.9383439991530031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 380}], {
             RGBColor[
             0.2692913647455158, 0.4003726767791782, 0.9386471168901593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 383}], {
             RGBColor[
             0.27666419535336334`, 0.408121989212486, 0.9390669886861509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 390}], {
             RGBColor[
             0.26969566944831447`, 0.40079762665621843`, 0.9386701414448686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 41}], {
             RGBColor[
             0.34006622360312927`, 0.4689700034848203, 0.942889696952605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 55}], {
             RGBColor[
             0.37142239221905604`, 0.496129140733077, 0.9448876842896408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 58}], {
             RGBColor[
             0.31906156196643076`, 0.449858262003899, 0.9415849314423156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.3368642646638673, 0.46619662758676733`, 0.9426856709603764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 87}], {
             RGBColor[
             0.31472542396778913`, 0.4453007060402985, 0.9413379947980343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 96}], {
             RGBColor[
             0.313111809733841, 0.4436046951713676, 0.9412461018545393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 110}], {
             RGBColor[
             0.29744503748137785`, 0.4271379242032959, 0.940353902351674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 146}], {
             RGBColor[
             0.43732168419070216`, 0.5509809435704429, 0.9497020146539848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 154}], {
             RGBColor[
             0.3847350802007028, 0.5076599219476261, 0.9457359569958835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 159}], {
             RGBColor[
             0.33537336280871854`, 0.46490528333474357`, 0.9425906720125191]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 167}], {
             RGBColor[
             0.31143079927380024`, 0.4418378465956456, 0.9411503707956721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 192}], {
             RGBColor[
             0.34190093761815415`, 0.4705591405492272, 0.9430066033072686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 203}], {
             RGBColor[
             0.31535485342024205`, 0.44596227630295887`, 0.941373839874194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 228}], {
             RGBColor[
             0.35358465424250685`, 0.48067898864856917`, 0.9437510793990673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 243}], {
             RGBColor[
             0.3138420416346276, 0.4443722151984709, 0.9412876874810078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 332}], {
             RGBColor[
             0.43326686926446056`, 0.5476890621459892, 0.9493828047697146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 348}], {
             RGBColor[
             0.3011336768698887, 0.43101491807386594`, 0.9405639649079968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 361}], {
             RGBColor[
             0.34746932604333547`, 0.4753821987277793, 0.9433614160937887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 385}], {
             RGBColor[
             0.4573665882056296, 0.5672542996623962, 0.9512800229249427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 57}], {
             RGBColor[
             0.3070138697292798, 0.4370559315903547, 0.9409039388472313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.31424207897729384`, 0.44465323780495364`, 0.9413155746707285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 96}], {
             RGBColor[
             0.3138659022147775, 0.44425785217656466`, 0.9412941519606068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 114}], {
             RGBColor[
             0.3348490984330268, 0.46445119188281303`, 0.9425572663500889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 153}], {
             RGBColor[
             0.32912553840433756`, 0.45949373186045395`, 0.9421925661662062]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 154}], {
             RGBColor[
             0.3854891726816393, 0.5083130789528232, 0.945784007101951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 188}], {
             RGBColor[
             0.30395311727072993`, 0.43383888669350434`, 0.9407296335226945]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 203}], {
             RGBColor[
             0.31610894590117855`, 0.4466154333081559, 0.9414218899802616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 222}], {
             RGBColor[
             0.4728736082946373, 0.5798845479116403, 0.9524894775340721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 258}], {
             RGBColor[
             0.29687678880049106`, 0.4264012168061446, 0.9403266470848042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 312}], {
             RGBColor[
             0.40188874544580117`, 0.5222558384193261, 0.9469012891044913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 327}], {
             RGBColor[
             0.32970622489449014`, 0.4599966933120725, 0.9422295669958778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 356}], {
             RGBColor[
             0.4295993605310475, 0.5447525640945126, 0.9490827702313296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 361}], {
             RGBColor[
             0.34822341852427197`, 0.4760353557329764, 0.9434094661998561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 369}], {
             RGBColor[
             0.2991371325274741, 0.4287769813772735, 0.940455370316177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 104}], {
             RGBColor[
             0.9330499750272585, 0.8621677183315113, 0.6295247357296906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 109}], {
             RGBColor[
             0.9631611562508396, 0.9703111795583055, 0.8704491819362283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 136}], {
             RGBColor[
             0.7754039881303256, 0.825013733522431, 0.9782569627328132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 205}], {
             RGBColor[
             0.9637471875060623, 0.9705535185426564, 0.8607371274369169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 207}], {
             RGBColor[
             0.9360408404789141, 0.8740255032004962, 0.6319312562767279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 221}], {
             RGBColor[
             0.9270423893059134, 0.944662453609973, 0.9929033247441504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 276}], {
             RGBColor[
             0.8488960037945177, 0.8827904862944987, 0.9853329329150746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 358}], {
             RGBColor[
             0.9504012676368335, 0.9272297470138823, 0.6629122325696076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 366}], {
             RGBColor[
             0.9167531541973288, 0.7967074998480634, 0.6163680259642358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 376}], {
             RGBColor[
             0.6853095806395425, 0.7514657941798157, 0.9712763701432583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 124}], {
             RGBColor[
             0.22535325774935577`, 0.3541909404893282, 0.9361449066973324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 137}], {
             RGBColor[
             0.22449567090087896`, 0.35328956233743236`, 0.9360960683949977]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 199}], {
             RGBColor[
             0.2266190062266405, 0.3555213223920431, 0.9362169892006067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 238}], {
             RGBColor[
             0.22832917766795519`, 0.3573188210079969, 0.9363143809342176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 252}], {
             RGBColor[
             0.2258841865651551, 0.3547489803375645, 0.9361751423079533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 277}], {
             RGBColor[
             0.2426240388727448, 0.37234362648077923`, 0.9371284521324783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 293}], {
             RGBColor[
             0.21933315592561953`, 0.34786343177608003`, 0.9358020708044131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 299}], {
             RGBColor[
             0.22078197517346282`, 0.34938623266600927`, 0.9358845789172419]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 330}], {
             RGBColor[
             0.2261035990920075, 0.35497959681484403`, 0.9361876375267658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 367}], {
             RGBColor[
             0.22337497152266345`, 0.35211163623448327`, 0.9360322462233344]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 47}], {
             RGBColor[
             0.36592423069765223`, 0.4903693505688373, 0.9445738718209851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 49}], {
             RGBColor[
             0.2768464709137847, 0.4083135723834269, 0.9390773690096643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 54}], {
             RGBColor[
             0.3749740145051137, 0.4982078184475008, 0.9451505160427869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 93}], {
             RGBColor[
             0.2715973273730923, 0.4027963897072362, 0.9387784380504338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[
             0.3120848480897295, 0.44373638339990634`, 0.9411432739695049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 211}], {
             RGBColor[
             0.28031687034096775`, 0.4119611822174286, 0.9392750031230466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 301}], {
             RGBColor[
             0.2773872245806669, 0.4088819387730828, 0.9391081641310199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 316}], {
             RGBColor[
             0.27611802500026855`, 0.4075479295421829, 0.9390358850925288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 324}], {
             RGBColor[
             0.2889570987994522, 0.4210426101494208, 0.9397670513516847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 328}], {
             RGBColor[
             0.3036968641952127, 0.4364711333428047, 0.9406087990529493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 362}], {
             RGBColor[
             0.35130778497678417`, 0.477709319929344, 0.9436425248244668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 372}], {
             RGBColor[
             0.27471702429732014`, 0.4060753889748091, 0.9389561001750906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 380}], {
             RGBColor[
             0.2817236040630746, 0.41343974855143245`, 0.9393551145274445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 383}], {
             RGBColor[
             0.28909643467092216`, 0.42118906098474024`, 0.9397749863234359]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 390}], {
             RGBColor[
             0.28212790876587335`, 0.4138646984284726, 0.9393781390821536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 91}], {
             RGBColor[
             0.27906015322156846`, 0.41064029284447245`, 0.9392034349422431]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 97}], {
             RGBColor[
             0.36889177075057233`, 0.4927124766331557, 0.9447712800460943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 100}], {
             RGBColor[
             0.33605658973236274`, 0.46427229317936647`, 0.9426790513466246]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 112}], {
             RGBColor[
             0.31221013250570034`, 0.4436176904874213, 0.9411595761787357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 141}], {
             RGBColor[
             0.32778152064738697`, 0.45710484425502595`, 0.9421517712618861]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 180}], {
             RGBColor[
             0.33088455801292704`, 0.4597925392578639, 0.9423494940589101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 190}], {
             RGBColor[
             0.2683010399450559, 0.3993317826236759, 0.9385907193578275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 266}], {
             RGBColor[
             0.2752485126978604, 0.4066340169820878, 0.9389863676532347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 271}], {
             RGBColor[
             0.30114348847212347`, 0.43385127835713033`, 0.9404610482153953]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 273}], {
             RGBColor[
             0.2854682454604019, 0.41737560408400093`, 0.9395683663153217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 350}], {
             RGBColor[
             0.36412092231360993`, 0.48858020750687353`, 0.9444672858023867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 365}], {
             RGBColor[
             0.2758699057154388, 0.4072871404421556, 0.9390217550663172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 394}], {
             RGBColor[
             0.32718352263793704`, 0.4565868884354943, 0.9421136673575129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 59}], {
             RGBColor[
             0.30916725287120805`, 0.4399481765928165, 0.9410035436196971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 287}], {
             RGBColor[
             0.27226485336384204`, 0.4034980018471065, 0.9388164526680909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 373}], {
             RGBColor[
             0.26731905714517273`, 0.3982996564396932, 0.9385347968900875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 395}], {
             RGBColor[
             0.27869220583377896`, 0.41025355681069386`, 0.939182480882838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 54}], {
             RGBColor[
             0.44294170199458305`, 0.5580755721956097, 0.9494448314664949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 121}], {
             RGBColor[
             0.4935440296663224, 0.5991928393789325, 0.9534184801906773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 128}], {
             RGBColor[
             0.3800525355791988, 0.5036041371480152, 0.945437589393213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 130}], {
             RGBColor[
             0.4221487542491271, 0.5400657659424366, 0.9481199232226362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.468503909528975, 0.5788641418068768, 0.9514472302084831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 181}], {
             RGBColor[
             0.5006021052009016, 0.6049229030605833, 0.9539741177513421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 265}], {
             RGBColor[
             0.5128933077983199, 0.6149014550415344, 0.9549417262439694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 311}], {
             RGBColor[
             0.47663297852550124`, 0.5854636862286419, 0.9520871802976505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 322}], {
             RGBColor[
             0.47115402237552717`, 0.5810156228019311, 0.9516558567994469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 362}], {
             RGBColor[
             0.4192754724662534, 0.5375770736774529, 0.9479368402481747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 56}], {
             RGBColor[
             0.43818896314994105`, 0.5539589886879809, 0.9491419911499963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 71}], {
             RGBColor[
             0.6482814539995922, 0.7214952269023049, 0.9679496107647267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 83}], {
             RGBColor[
             0.38916228198081126`, 0.5114945416119245, 0.9460180543784913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 103}], {
             RGBColor[
             0.3850045259376993, 0.5078933023022759, 0.9457531258399835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 108}], {
             RGBColor[
             0.3965059868386308, 0.5178552896544295, 0.9464859887582483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 120}], {
             RGBColor[
             0.49591060473188847`, 0.6008847208403402, 0.9536681725336434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 143}], {
             RGBColor[
             0.5250435709581793, 0.6245361752480152, 0.9559616263525487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 196}], {
             RGBColor[
             0.3616835055171287, 0.4866932494532377, 0.9443037663378753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 231}], {
             RGBColor[
             0.3670635094292236, 0.49234797467679914`, 0.9446101496016666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 234}], {
             RGBColor[
             0.38209114426819646`, 0.5053698775309731, 0.945567487736205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 286}], {
             RGBColor[
             0.5758463873446392, 0.6644950889479655, 0.9608396409213635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 290}], {
             RGBColor[
             0.4152883060919923, 0.5341235905648768, 0.9476827815325197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 313}], {
             RGBColor[
             0.35412562406909687`, 0.4787494368539953, 0.9438733561702934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 320}], {
             RGBColor[
             0.5676684575710711, 0.6581064280542859, 0.9600245413086331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 331}], {
             RGBColor[
             0.43876768248625253`, 0.5544602462898143, 0.9491788666343646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 342}], {
             RGBColor[
             0.5144005472567488, 0.6158956891444403, 0.9551237685400916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 343}], {
             RGBColor[
             0.5738217336869491, 0.6629134141226403, 0.9606378423662292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 344}], {
             RGBColor[
             0.373035772157718, 0.49752656934511247`, 0.9449904874326764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 349}], {
             RGBColor[
             0.43541101780241814`, 0.5515528720515495, 0.9489649829288928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 147}], {
             RGBColor[
             0.2702371158648362, 0.4013667211696683, 0.9387009760172913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 211}], {
             RGBColor[
             0.25920679804656954`, 0.3897731577801271, 0.9380728157354339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 301}], {
             RGBColor[
             0.2562771522862687, 0.3866939143357813, 0.9379059767434073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 328}], {
             RGBColor[
             0.2825867919008145, 0.4142831089055032, 0.9394066116653366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 347}], {
             RGBColor[
             0.2678932418389194, 0.3989031609582332, 0.9385674958589661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 372}], {
             RGBColor[
             0.25360695200292194`, 0.3838873645375076, 0.9377539127874779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 380}], {
             RGBColor[
             0.2606135317686764, 0.39125172411413095`, 0.9381529271398318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 54}], {
             RGBColor[
             0.4530695590105145, 0.5668252864420751, 0.9500963936878091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 116}], {
             RGBColor[
             0.4351844866677396, 0.551334135708637, 0.9489567726932759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 121}], {
             RGBColor[
             0.5036718866822538, 0.607942553625398, 0.9540700424119916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.4322766112650586, 0.5488154801889021, 0.9487714854439504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 135}], {
             RGBColor[
             0.478712840814817, 0.5876796757980098, 0.9521051748933094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 158}], {
             RGBColor[
             0.47863176654490647`, 0.5876138560533424, 0.9520987924297972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 172}], {
             RGBColor[
             0.3777861468106212, 0.500941670871986, 0.945324186142565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 181}], {
             RGBColor[
             0.5107299622168331, 0.6136726173070488, 0.9546256799726562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 265}], {
             RGBColor[
             0.5230211648142513, 0.6236511692879999, 0.9555932884652836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 276}], {
             RGBColor[
             0.6098568885565028, 0.6922609454050347, 0.9637197242270632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 322}], {
             RGBColor[
             0.4812818793914586, 0.5897653370483966, 0.952307419020761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 328}], {
             RGBColor[
             0.38179240870061343`, 0.505088601337379, 0.9455546766979714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 362}], {
             RGBColor[
             0.4294033294821849, 0.5463267879239184, 0.948588402469489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 364}], {
             RGBColor[
             0.4018386991300539, 0.5224516905515073, 0.9468320085978967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 59}], {
             RGBColor[
             0.3534707906164537, 0.48058036569863427`, 0.9437438241095009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 136}], {
             RGBColor[
             0.4957527510770341, 0.5993305404010079, 0.9540497614266502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 194}], {
             RGBColor[
             0.38048922371828053`, 0.5039823744655038, 0.945465414775287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 246}], {
             RGBColor[
             0.408363122473439, 0.5281253445843351, 0.9472415149560449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 376}], {
             RGBColor[
             0.405658343586251, 0.5257826010583926, 0.9470691688370954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 377}], {
             RGBColor[
             0.39390138797963725`, 0.5155993170337143, 0.9463200260221095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 395}], {
             RGBColor[
             0.3229957435790246, 0.45088574591651165`, 0.9419227613726417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 396}], {
             RGBColor[
             0.3256114518738936, 0.4536350211799036, 0.9420717220904409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 117}], {
             RGBColor[
             0.36808130040816744`, 0.4932352549346425, 0.9446747928738624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 133}], {
             RGBColor[
             0.34195185422260005`, 0.4695411184843201, 0.9430487372114036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 174}], {
             RGBColor[
             0.5576254346896334, 0.6486129747855855, 0.95972095993169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 223}], {
             RGBColor[
             0.42035633884682855`, 0.5384929234825571, 0.9480113327439608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 260}], {
             RGBColor[
             0.5977997596730911, 0.6799974627988412, 0.9637251611956289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 267}], {
             RGBColor[
             0.4789222153161444, 0.5860393403630161, 0.9526218530734996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 272}], {
             RGBColor[
             0.5168312067307885, 0.6167442138565202, 0.9556549725324873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 291}], {
             RGBColor[
             0.5415685327056081, 0.6360692009186899, 0.9581205580022027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 346}], {
             RGBColor[
             0.36583874865596927`, 0.4912928693208167, 0.944531899459223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 384}], {
             RGBColor[
             0.5675366621289825, 0.6563557009893235, 0.9607088184571579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 68}], {
             RGBColor[
             0.28298429153365734`, 0.4147648110152172, 0.9394269088138741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 86}], {
             RGBColor[
             0.2948901577623302, 0.4272786312970708, 0.9401049302824465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 95}], {
             RGBColor[
             0.2855112454690256, 0.4174207998194225, 0.9395708151022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 101}], {
             RGBColor[
             0.27504289638646184`, 0.40641790120198085`, 0.9389746581084827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 129}], {
             RGBColor[
             0.26346421560774436`, 0.39424797357278596`, 0.9383152693672578]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 151}], {
             RGBColor[
             0.302539739143033, 0.43466335198279643`, 0.9405645627526612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 171}], {
             RGBColor[
             0.28122827358250124`, 0.41291912481058346`, 0.9393269061893516]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 244}], {
             RGBColor[
             0.27464006789181306`, 0.4059945029133032, 0.9389517176216438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 249}], {
             RGBColor[
             0.279406621010689, 0.4110044524581648, 0.9392231657702803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 253}], {
             RGBColor[
             0.31547986955209806`, 0.4458714425532633, 0.9413890964198188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 270}], {
             RGBColor[
             0.26941555401375766`, 0.4005032075741548, 0.9386541892852642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 308}], {
             RGBColor[
             0.27516616979901054`, 0.4065474693745552, 0.9389816783469607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 386}], {
             RGBColor[
             0.3143035505913172, 0.444852574192945, 0.9413141424158159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 397}], {
             RGBColor[
             0.26929675474869136`, 0.4003783420142617, 0.9386474238428664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 121}], {
             RGBColor[
             0.502593813473784, 0.607031307257596, 0.9539951244124792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 128}], {
             RGBColor[
             0.3891023193866603, 0.5114426050266787, 0.9460142336150148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 130}], {
             RGBColor[
             0.43119853805658864`, 0.5479042338211002, 0.9486965674444381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 158}], {
             RGBColor[
             0.4775536933364365, 0.5867026096855403, 0.9520238744302849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 181}], {
             RGBColor[
             0.5096518890083631, 0.6127613709392468, 0.9545507619731439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 265}], {
             RGBColor[
             0.5219430916057815, 0.622739922920198, 0.9555183704657713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 311}], {
             RGBColor[
             0.48568276233296276`, 0.5933021541073054, 0.9526638245194523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 322}], {
             RGBColor[
             0.48020380618298864`, 0.5888540906805946, 0.9522325010212487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 328}], {
             RGBColor[
             0.38071433549214345`, 0.504177354969577, 0.9454797586984591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 362}], {
             RGBColor[
             0.4283252562737149, 0.5454155415561164, 0.9485134844699766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 58}], {
             RGBColor[
             0.351171823063294, 0.4776705562573528, 0.9436309688854188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 60}], {
             RGBColor[
             0.38053049793671245`, 0.5040181241190069, 0.9454680447319882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 80}], {
             RGBColor[
             0.36897452576073053`, 0.49400892184022105`, 0.9447317084034796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 87}], {
             RGBColor[
             0.34683568506465234`, 0.47311300029375225`, 0.9433840322411374]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 122}], {
             RGBColor[
             0.4248101196568824, 0.5423709068945195, 0.9482895030730654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 146}], {
             RGBColor[
             0.4694319452875655, 0.5787932378238967, 0.951748052097088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 159}], {
             RGBColor[
             0.36748362390558187`, 0.49271757758819734`, 0.9446367094556223]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.4681407137086776, 0.5777449578588358, 0.9516464016172608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 192}], {
             RGBColor[
             0.3740111987150174, 0.498371434802681, 0.9450526407503718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 201}], {
             RGBColor[
             0.33997947002411655`, 0.46590668357700793`, 0.9429935809374401]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 210}], {
             RGBColor[
             0.3517281816196206, 0.4782553243752219, 0.9436626526821428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 228}], {
             RGBColor[
             0.38569491533937006`, 0.508491282902023, 0.9457971168421706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 385}], {
             RGBColor[
             0.4894768493024928, 0.5950665939158499, 0.9533260603680459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 71}], {
             RGBColor[
             0.6610275221983658, 0.7325352305400676, 0.968761778959447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 83}], {
             RGBColor[
             0.4019083501795848, 0.5225345452496872, 0.9468302225732115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 108}], {
             RGBColor[
             0.40925205503740436`, 0.5288952932921922, 0.9472981569529686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 120}], {
             RGBColor[
             0.5086566729306621, 0.6119247244781029, 0.9544803407283637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 143}], {
             RGBColor[
             0.5377896391569529, 0.6355761788857779, 0.956773794547269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 196}], {
             RGBColor[
             0.3744295737159023, 0.4977332530910004, 0.9451159345325955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 231}], {
             RGBColor[
             0.37980957762799716`, 0.5033879783145618, 0.9454223177963867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 237}], {
             RGBColor[
             0.5146770314008289, 0.6168123226982427, 0.9549542854004349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 254}], {
             RGBColor[
             0.46022321075082034`, 0.5726042579779009, 0.9506674811679487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 286}], {
             RGBColor[
             0.5885924555434128, 0.6755350925857282, 0.9616518091160838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 290}], {
             RGBColor[
             0.42803437429076585`, 0.5451635942026395, 0.9484949497272399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 320}], {
             RGBColor[
             0.5804145257698448, 0.6691464316920486, 0.9608367095033534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 331}], {
             RGBColor[
             0.4515137506850261, 0.565500249927577, 0.9499910348290849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 342}], {
             RGBColor[
             0.5271466154555224, 0.626935692782203, 0.9559359367348119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 343}], {
             RGBColor[
             0.5865678018857227, 0.673953417760403, 0.9614500105609494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 344}], {
             RGBColor[
             0.38578184035649155`, 0.5085665729828752, 0.9458026556273967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 349}], {
             RGBColor[
             0.44815708600119175`, 0.5625928756893122, 0.949777151123613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 92}], {
             RGBColor[
             0.2804356326225079, 0.4120860089052909, 0.9392817664592872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 114}], {
             RGBColor[
             0.3010426520782409, 0.43188396298315035`, 0.9405234581386476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 153}], {
             RGBColor[
             0.2953190920495516, 0.42692650296079127`, 0.9401587579547649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 188}], {
             RGBColor[
             0.270146670915944, 0.40127165779384166`, 0.9386958253112532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 195}], {
             RGBColor[
             0.25945106473985713`, 0.3900298975621752, 0.9380867263622563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 208}], {
             RGBColor[
             0.2531470707031978, 0.383404000133339, 0.9377277232277921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 258}], {
             RGBColor[
             0.26307034244570515`, 0.39383398790648194`, 0.9382928388733629]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 278}], {
             RGBColor[
             0.26281152350528336`, 0.39356195279003, 0.9382780995175941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 284}], {
             RGBColor[
             0.2586027566797, 0.38913827200511253`, 0.9380384164731898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 327}], {
             RGBColor[
             0.2958997785397042, 0.4274294644124098, 0.9401957587844365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 337}], {
             RGBColor[
             0.27897537779675124`, 0.41055118849791716`, 0.9391986071072138]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 354}], {
             RGBColor[
             0.27649042962059545`, 0.4079393504099632, 0.939057092984733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 392}], {
             RGBColor[
             0.2605783177897506, 0.3912147119895847, 0.9381509217558264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 60}], {
             RGBColor[
             0.3281696676840872, 0.4577472453898289, 0.942165291884663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 80}], {
             RGBColor[
             0.31661369550810525`, 0.44773804311104304`, 0.9414289555561544]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 87}], {
             RGBColor[
             0.29447485481202706`, 0.42684212156457424`, 0.9400812793938123]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 110}], {
             RGBColor[
             0.2771944683256158, 0.40867933972757164`, 0.939097186947452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 159}], {
             RGBColor[
             0.31512279365295653`, 0.44644669885901933`, 0.9413339566082971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 167}], {
             RGBColor[
             0.2911802301180382, 0.4233792621199214, 0.9398936553914501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 192}], {
             RGBColor[
             0.32165036846239214`, 0.45210055607350297`, 0.9417498879030466]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 201}], {
             RGBColor[
             0.2876186397714912, 0.4196358048478299, 0.939690828090115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 210}], {
             RGBColor[
             0.2993673513669953, 0.4319844456460439, 0.9403598998348177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 228}], {
             RGBColor[
             0.3333340850867448, 0.46222040417284493`, 0.9424943639948453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 236}], {
             RGBColor[
             0.27466659649964625`, 0.4060223861621468, 0.9389532283866143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 243}], {
             RGBColor[
             0.2935914724788655, 0.42591363072274663`, 0.9400309720767858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 263}], {
             RGBColor[
             0.28044730154374703`, 0.41209827368136553`, 0.9392824309870891]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 348}], {
             RGBColor[
             0.28088310771412667`, 0.4125563335981417, 0.9393072495037748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 351}], {
             RGBColor[
             0.27227774194596055`, 0.4035115485640963, 0.9388171866537756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 79}], {
             RGBColor[
             0.46241207497172554`, 0.5712067102742551, 0.9517169387007705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[
             0.3610366257463029, 0.4871335118181791, 0.9442259124337696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 237}], {
             RGBColor[
             0.4562186120487096, 0.5661785780610258, 0.9512293666120685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 246}], {
             RGBColor[
             0.38891052450146135`, 0.5112764819370106, 0.9460020126145274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 254}], {
             RGBColor[
             0.401764791398701, 0.521970513340684, 0.9469425623795822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 349}], {
             RGBColor[
             0.38969866664907243`, 0.5119591310520951, 0.9460522323352465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 373}], {
             RGBColor[
             0.2921699969184407, 0.4220829828981863, 0.9400355750383738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 395}], {
             RGBColor[
             0.303543145607047, 0.434036883269187, 0.9406832590311243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 87}], {
             RGBColor[
             0.32383352968544554`, 0.4531896894262284, 0.9419183552403817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 122}], {
             RGBColor[
             0.4018079642776756, 0.5224475960269956, 0.9468238260723096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 146}], {
             RGBColor[
             0.44642978990835863`, 0.5588699269563728, 0.9502823750963323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 159}], {
             RGBColor[
             0.344481468526375, 0.4727942667206735, 0.9431710324548666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 165}], {
             RGBColor[
             0.4451385583294708, 0.557821646991312, 0.950180724616505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 201}], {
             RGBColor[
             0.3169773146449097, 0.44598337270948407`, 0.9415279039366844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 210}], {
             RGBColor[
             0.3287260262404138, 0.45833201350769803`, 0.942196975681387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 263}], {
             RGBColor[
             0.3098059764171655, 0.4384458415430197, 0.9411195068336586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 66}], {
             RGBColor[
             0.9830643953423903, 0.9540141570597834, 0.4329439736998075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 98}], {
             RGBColor[
             0.985458002900472, 0.9620883573989745, 0.44224268706809605`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 107}], {
             RGBColor[
             0.9162817916828967, 0.6453128669663495, 0.3511545314597267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 131}], {
             RGBColor[
             0.9579060415796807, 0.8592435772757068, 0.3867967672286041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 215}], {
             RGBColor[
             0.9063170503481712, 0.5687194984901538, 0.341612283904028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 262}], {
             RGBColor[
             0.9659943820446136, 0.9709682059989204, 0.7529333373497976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 269}], {
             RGBColor[
             0.9932024163292561, 0.9878689808064407, 0.5015031511422814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 279}], {
             RGBColor[
             0.9694977718101772, 0.9052009249245101, 0.39612374546494056`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 297}], {
             RGBColor[
             0.9699924620425022, 0.9739499675150907, 0.7461656307796394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 298}], {
             RGBColor[
             0.9083880182689977, 0.925110369261773, 0.7500707788698681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 300}], {
             RGBColor[
             0.9416713408004723, 0.7907793854302443, 0.3735219082012329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 306}], {
             RGBColor[
             0.9818610097196364, 0.9499548547858537, 0.42826904779571534`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 307}], {
             RGBColor[
             0.9892929392100926, 0.9881701251038566, 0.7056981044009731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 314}], {
             RGBColor[
             0.9595789423265859, 0.965928622564677, 0.7549534149051582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 352}], {
             RGBColor[
             0.9937500196167237, 0.9890402488671484, 0.5611063895673631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 77}], {
             RGBColor[
             0.5042166815429454, 0.5861598549701907, 0.9585479112851663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 204}], {
             RGBColor[
             0.17899762953989296`, 0.30546823612459895`, 0.9335050222478098]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 345}], {
             RGBColor[
             0.19050782677282135`, 0.3175661832050619, 0.9341605109524143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 370}], {
             RGBColor[
             0.5051424414592518, 0.5868980307983699, 0.9586362110924191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 389}], {
             RGBColor[
             0.17907819285502502`, 0.305552913276812, 0.9335096102094239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 400}], {
             RGBColor[
             0.2843395833350594, 0.4087127954077557, 0.9397778424506229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 90}], {
             RGBColor[
             0.8321834271804781, 0.8209894828739578, 0.632414864387591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 138}], {
             RGBColor[
             0.8889519646070447, 0.5107811215593289, 0.22983700543826907`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 142}], {
             RGBColor[
             0.890072513149207, 0.5193941486818902, 0.23091004398772222`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 152}], {
             RGBColor[
             0.5710886094431091, 0.5911007265104762, 0.6136429928057057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 156}], {
             RGBColor[
             0.5722602959769347, 0.592332243346744, 0.6137097186204522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 202}], {
             RGBColor[
             0.9074503393274316, 0.6529677356997123, 0.2475510699614376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 214}], {
             RGBColor[
             0.9711670732550739, 0.9296487112649943, 0.6029350218130802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 217}], {
             RGBColor[
             0.8906933611547283, 0.5241662585096577, 0.23150456873895697`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 242}], {
             RGBColor[
             0.9384539463641798, 0.7929291511512139, 0.2733380495894395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 256}], {
             RGBColor[
             0.5919347091448884, 0.6130112990161062, 0.6148301473446811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 257}], {
             RGBColor[
             0.8905841112547781, 0.5233265159050291, 0.23139995091138454`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 261}], {
             RGBColor[
             0.5690047111878296, 0.5889104173173967, 0.6135243178829187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 264}], {
             RGBColor[
             0.5742960336344989, 0.5944719326980662, 0.6138256508684465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 268}], {
             RGBColor[
             0.8879400264016856, 0.5030029210787892, 0.2288679722699964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 317}], {
             RGBColor[
             0.9745940579826633, 0.9311354530743134, 0.5492576472683819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 381}], {
             RGBColor[
             0.975854040924288, 0.9316564884007599, 0.528376469194335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 82}], {
             RGBColor[
             0.38908871359710695`, 0.5114308203756144, 0.9460133666661356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 151}], {
             RGBColor[
             0.35739789501188024`, 0.48398182614394664`, 0.9439940557289754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 157}], {
             RGBColor[
             0.43410205704708005`, 0.5499866920911975, 0.9490010571312653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 171}], {
             RGBColor[
             0.3360864294513485, 0.46223759897173367`, 0.9427563991656658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 182}], {
             RGBColor[
             0.34352729206089855`, 0.4700584173523088, 0.9431801452835099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 253}], {
             RGBColor[
             0.3703380254209453, 0.4951899167144135, 0.9448185893961331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 105}], {
             RGBColor[
             0.46633814789011974`, 0.5766565671437895, 0.9514008797073982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 113}], {
             RGBColor[
             0.6559239156864949, 0.7291861264524664, 0.9676704388099608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 148}], {
             RGBColor[
             0.5696101053080527, 0.6614741699887192, 0.9592609405218679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 161}], {
             RGBColor[
             0.4733844161827434, 0.5827596905831183, 0.9518498616922337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 168}], {
             RGBColor[
             0.592741338058181, 0.6798274166038522, 0.9613729899467283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 170}], {
             RGBColor[
             0.4801509107444425, 0.5886204880785566, 0.952281016742329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 180}], {
             RGBColor[
             0.4408011041078431, 0.5545376633487222, 0.9497736818591127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 239}], {
             RGBColor[
             0.4199235526672635, 0.5364545776271384, 0.9484433827426128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 251}], {
             RGBColor[
             0.6688240146939028, 0.7392826292624911, 0.9689511985946974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 282}], {
             RGBColor[
             0.5810969797016021, 0.6707307553552915, 0.9602123891284602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 312}], {
             RGBColor[
             0.4891446804627151, 0.5961487131731942, 0.9529264075234798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 326}], {
             RGBColor[
             0.4273612108963405, 0.5428967033575929, 0.9489173037481067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 356}], {
             RGBColor[
             0.5168552955479615, 0.6186454388483807, 0.9551078886503179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[
             0.9751764945744315, 0.9279266287426179, 0.3580657982576656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 107}], {
             RGBColor[
             0.906000283356856, 0.6111511383099929, 0.2669776426492963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 131}], {
             RGBColor[
             0.9476245332536402, 0.8250818486193503, 0.3026198784181737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 215}], {
             RGBColor[
             0.8960355420221306, 0.5345577698337973, 0.25743539509359753`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 297}], {
             RGBColor[
             0.9597109537164616, 0.9397882388587341, 0.661988741969209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 307}], {
             RGBColor[
             0.9790114308840521, 0.9540083964475, 0.6215212155905427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 314}], {
             RGBColor[
             0.9492974340005453, 0.9317668939083206, 0.6707765260947278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 352}], {
             RGBColor[
             0.983468511290683, 0.9548785202107917, 0.47692950075693274`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 85}], {
             RGBColor[
             0.22712666696496037`, 0.35605490601556716`, 0.9362458997286371]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 127}], {
             RGBColor[
             0.21172079285419906`, 0.33986235553632177`, 0.9353685579889777]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 139}], {
             RGBColor[
             0.21205827028800195`, 0.34021706571655375`, 0.9353877768295796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 184}], {
             RGBColor[
             0.2153543932680198, 0.3436814999548199, 0.9355754861571146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 305}], {
             RGBColor[
             0.20792423756527648`, 0.33587193521215575`, 0.9351523497817738]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 325}], {
             RGBColor[
             0.21225679273606501`, 0.3404257253965182, 0.9353990823893092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 86}], {
             RGBColor[
             0.28863048877409425`, 0.42069932230449786`, 0.9397484513939167]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 95}], {
             RGBColor[
             0.2792515764807897, 0.4108414908268496, 0.9392143362136705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 129}], {
             RGBColor[
             0.25720454661950837`, 0.38766866458021304`, 0.9379587904787283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 151}], {
             RGBColor[
             0.29628007015479707`, 0.4280840429902235, 0.9402080838641316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 178}], {
             RGBColor[
             0.2603565331566741, 0.3909816022782634, 0.9381382914490737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 229}], {
             RGBColor[
             0.2618103919644219, 0.39250970006517877`, 0.9382210865573835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 249}], {
             RGBColor[
             0.2731469520224531, 0.4044251434655919, 0.9388666868817508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 308}], {
             RGBColor[
             0.26890650081077455`, 0.39996816038198235`, 0.938625199458431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 309}], {
             RGBColor[
             0.27375753584035556`, 0.40506690577145743`, 0.9389014587269024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 319}], {
             RGBColor[
             0.2591541477712746, 0.38971781900257185`, 0.9380698173801449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 334}], {
             RGBColor[
             0.2690618295669699, 0.40013142075315566`, 0.938634045201308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 371}], {
             RGBColor[
             0.27438511411724903`, 0.40572653033123346`, 0.9389371983813526]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 386}], {
             RGBColor[
             0.30804388160308127`, 0.43827326520037213`, 0.9409576635272863]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 74}], {
             RGBColor[
             0.6564460490256175, 0.7292165790501876, 0.9679963956135333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 97}], {
             RGBColor[
             0.46525153460871527`, 0.5764515941781216, 0.9511282282884884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 100}], {
             RGBColor[
             0.4324163535905058, 0.5480114107243323, 0.9490359995890186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 132}], {
             RGBColor[
             0.6437204915353074, 0.7192373735289359, 0.9667380893382732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 140}], {
             RGBColor[
             0.5800718085263902, 0.6695145386144623, 0.9603941834467046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 141}], {
             RGBColor[
             0.42414128450553, 0.540843961799992, 0.9485087195042803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 168}], {
             RGBColor[
             0.5791845558214077, 0.6688214100579597, 0.9603057503889199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 191}], {
             RGBColor[
             0.5835359920161374, 0.6722207850854224, 0.9607394608823273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 216}], {
             RGBColor[
             0.5736600979558795, 0.6645056615859741, 0.959755124057878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 219}], {
             RGBColor[
             0.4677032328653056, 0.5785751319820428, 0.9512844483334466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 220}], {
             RGBColor[
             0.4818265682663484, 0.5902075400149862, 0.9523502989242535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 350}], {
             RGBColor[
             0.4604806861717529, 0.5723193250518395, 0.9508242340447808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 357}], {
             RGBColor[
             0.5819543622257783, 0.6709852038723623, 0.9605818188059951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 394}], {
             RGBColor[
             0.42354328649608, 0.5403260059804602, 0.948470615599907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 75}], {
             RGBColor[
             0.2609941288153654, 0.3916517557414475, 0.9381746015785979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 103}], {
             RGBColor[
             0.3111881460301813, 0.44109703206764383`, 0.9411543384931023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 133}], {
             RGBColor[
             0.28753417910083867`, 0.4195470313278583, 0.9396860181798696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.2579170969731607, 0.3884176001802034, 0.937999369167245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 164}], {
             RGBColor[
             0.26017432145076, 0.3907900862224582, 0.9381279147619799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 227}], {
             RGBColor[
             0.25636607330828476`, 0.3867873759678386, 0.9379110406640643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 234}], {
             RGBColor[
             0.30827476436067847`, 0.438573607296341, 0.9409687003893238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 280}], {
             RGBColor[
             0.2584116720913199, 0.38893742998726233`, 0.9380275344885658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 346}], {
             RGBColor[
             0.3114210735342079, 0.4412987821643549, 0.9411691804276892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 79}], {
             RGBColor[
             0.730962985173496, 0.7893766931257962, 0.9742494771038676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 109}], {
             RGBColor[
             0.932608231427341, 0.9459491066410988, 0.8675350166916449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 120}], {
             RGBColor[
             0.7187491637803132, 0.7794609626924269, 0.9732879603430942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 143}], {
             RGBColor[
             0.7478821300066041, 0.8031124171001021, 0.9755814141619994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 237}], {
             RGBColor[
             0.7247695222504801, 0.7843485609125668, 0.9737619050151656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 286}], {
             RGBColor[
             0.798684946393064, 0.8430713308000524, 0.9804594287308144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 320}], {
             RGBColor[
             0.7905070166194959, 0.8366826699063725, 0.9796443291180839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 321}], {
             RGBColor[
             0.8444532383444727, 0.878825868324395, 0.985021184343525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 343}], {
             RGBColor[
             0.7966602927353739, 0.841489655974727, 0.98025763017568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 382}], {
             RGBColor[
             0.8849504676641144, 0.7666705508963009, 0.612411028914603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 119}], {
             RGBColor[
             0.2341124382405141, 0.36339739454965503`, 0.9366437290682574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 200}], {
             RGBColor[
             0.24919308184682543`, 0.37924810714791846`, 0.937502549411824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 288}], {
             RGBColor[
             0.2363762501862872, 0.36577680443863003`, 0.9367726498095597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 341}], {
             RGBColor[
             0.22465511090045148`, 0.353457143886063, 0.936105148267103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 355}], {
             RGBColor[
             0.2293238377834227, 0.358364271854447, 0.9363710253563257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 374}], {
             RGBColor[
             0.25191511783451104`, 0.3821091395580259, 0.9376575653344313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 375}], {
             RGBColor[
             0.24128592482540645`, 0.37093718377569584`, 0.9370522485170447]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 379}], {
             RGBColor[
             0.22434193474233927`, 0.3531279758873717, 0.9360873133482011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 393}], {
             RGBColor[
             0.22527325394479547`, 0.3541068514182011, 0.9361403505990177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 399}], {
             RGBColor[
             0.23130276285488832`, 0.3604442475756538, 0.9364837222115884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 85}], {
             RGBColor[
             0.24221172142071856`, 0.3719102546962633, 0.9371049712635544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 96}], {
             RGBColor[
             0.26501373249139615`, 0.3958766140625488, 0.9384035120614771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 110}], {
             RGBColor[
             0.24934696023893294`, 0.3794098430944771, 0.9375113125586119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 115}], {
             RGBColor[
             0.24086103809529086`, 0.3704906008829697, 0.9370280518463283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 184}], {
             RGBColor[
             0.230439447723778, 0.35953684863551605`, 0.9364345576920319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 188}], {
             RGBColor[
             0.2551009475473486, 0.3854576485794885, 0.9378389936235647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 195}], {
             RGBColor[
             0.2444053413712617, 0.37421588834782205`, 0.937229894674568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 203}], {
             RGBColor[
             0.2672567761777972, 0.39823419519414005`, 0.9385312500811318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 206}], {
             RGBColor[
             0.23733902327111464`, 0.366788739994123, 0.9368274783124455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 208}], {
             RGBColor[
             0.23810134733460236`, 0.3675899909189858, 0.9368708915401036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 258}], {
             RGBColor[
             0.2480246190771097, 0.3780199786921288, 0.9374360071856744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 284}], {
             RGBColor[
             0.24355703331110456`, 0.3733242627907594, 0.9371815847855014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 348}], {
             RGBColor[
             0.2530355996274438, 0.3832868369650472, 0.9377213751149346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 369}], {
             RGBColor[
             0.2502849628040927, 0.38039574326325765`, 0.9375647304170474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 392}], {
             RGBColor[
             0.24553259442115521`, 0.3754007027752315, 0.9372940900681379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 132}], {
             RGBColor[
             0.8119479189165777, 0.8530570556731545, 0.981880980170774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 140}], {
             RGBColor[
             0.7482992359076605, 0.8033342207586809, 0.9755370742792053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 191}], {
             RGBColor[
             0.7517634193974077, 0.8060404672296411, 0.9758823517148281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 198}], {
             RGBColor[
             0.8255815527613636, 0.8637603366303892, 0.9832258995793732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 216}], {
             RGBColor[
             0.7418875253371497, 0.7983253437301927, 0.9748980148903788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 219}], {
             RGBColor[
             0.6359306602465759, 0.7123948141262615, 0.9664273391659474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 220}], {
             RGBColor[
             0.6500539956476187, 0.724027222159205, 0.9674931897567542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 224}], {
             RGBColor[
             0.9001674923644503, 0.8962994775971298, 0.6715446357629462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 302}], {
             RGBColor[
             0.9059752552459537, 0.9158904255240137, 0.6941066978535942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 311}], {
             RGBColor[
             0.6720237576353845, 0.741863264667372, 0.9692227298983209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 323}], {
             RGBColor[
             0.8274418605794372, 0.8652436955878107, 0.9834033373997775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 340}], {
             RGBColor[
             0.9092258023331339, 0.9260683158029884, 0.7736525641500547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 357}], {
             RGBColor[
             0.7501817896070486, 0.8048048860165811, 0.9757247096384958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 89}], {
             RGBColor[
             0.23138047401831524`, 0.3605259269355878, 0.9364881477473821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 133}], {
             RGBColor[
             0.27071817278007254`, 0.4018723424883518, 0.9387283714969541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 145}], {
             RGBColor[
             0.24110109065239455`, 0.37074291134069687`, 0.9370417224843294]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.24457568603401603`, 0.37439493138885227`, 0.9372395955511095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 164}], {
             RGBColor[
             0.2433583151299939, 0.3731153973829517, 0.9371702680790643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 169}], {
             RGBColor[
             0.2324382955275915, 0.3616377644115946, 0.9365483891174288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 209}], {
             RGBColor[
             0.24810555583118551`, 0.37810504835234904`, 0.9374406164140838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 227}], {
             RGBColor[
             0.2395500669875186, 0.36911268712833206`, 0.9369533939811485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 280}], {
             RGBColor[
             0.24159566577055375`, 0.3712627411477558, 0.9370698878056503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 315}], {
             RGBColor[
             0.24372617436870905`, 0.3735020407664642, 0.9371912171185102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[
             0.8904092616611533, 0.5686904524165735, 0.22911954666558126`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 109}], {
             RGBColor[
             0.9205204428847344, 0.6768339136433675, 0.4700439928721189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 138}], {
             RGBColor[
             0.8331436561867612, 0.2557622418600043, 0.17937170863583543`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 144}], {
             RGBColor[
             0.8626912709570241, 0.4513693690163807, 0.2064327327986027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 207}], {
             RGBColor[
             0.8934001271128089, 0.5805482372855583, 0.23152606721261854`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 233}], {
             RGBColor[
             0.8322013343184957, 0.24851914305244047`, 0.17846934015058413`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 242}], {
             RGBColor[
             0.8826456379438963, 0.5379102714518893, 0.22287275278700588`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 257}], {
             RGBColor[
             0.8347758028344946, 0.2683076362057045, 0.1809346541089509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 317}], {
             RGBColor[
             0.9187857495623798, 0.676116573374989, 0.49879235046594833`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 358}], {
             RGBColor[
             0.9077605542707283, 0.6337524810989443, 0.26250704350549825`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 366}], {
             RGBColor[
             0.8741124408312237, 0.5032302339331254, 0.2159628369001264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 382}], {
             RGBColor[
             0.8728626791215081, 0.4975553578985697, 0.2149200050950769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 78}], {
             RGBColor[
             0.8356045267952863, 0.5947068735494174, 0.5856449487468838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 102}], {
             RGBColor[
             0.8243310697046711, 0.5080541422905515, 0.574849473505362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 111}], {
             RGBColor[
             0.8517216279012312, 0.6939386797204187, 0.6001134200588495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 160}], {
             RGBColor[
             0.8294213428991457, 0.5471802126352212, 0.5797239248650322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 166}], {
             RGBColor[
             0.827067103969575, 0.529084500588463, 0.5774695030073427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 185}], {
             RGBColor[
             0.8265277938578538, 0.5249391267425765, 0.5769530590352949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 370}], {
             RGBColor[
             0.8302908639224114, 0.8675154135193626, 0.9836750778819656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 389}], {
             RGBColor[
             0.5042266153181847, 0.5861702959978048, 0.9585484769989704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 400}], {
             RGBColor[
             0.6094880057982189, 0.6893301781287484, 0.9648167092401694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 102}], {
             RGBColor[
             0.8305704924938522, 0.23598377814878552`, 0.17690764417753302`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 144}], {
             RGBColor[
             0.8601410277678558, 0.4317670823407418, 0.2039906170405674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 160}], {
             RGBColor[
             0.835660765688327, 0.2751098484934552, 0.18178209553720334`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 185}], {
             RGBColor[
             0.832767216647035, 0.2528687626008105, 0.17901122970746597`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 207}], {
             RGBColor[
             0.8908498839236407, 0.5609459506099194, 0.22908395145458324`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 213}], {
             RGBColor[
             0.8764060316711535, 0.5036808895572449, 0.2174620888914447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 230}], {
             RGBColor[
             0.9053505911840212, 0.6146233921482407, 0.26060988945584945`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 247}], {
             RGBColor[
             0.874425744599943, 0.49582971121144337`, 0.21586870343063702`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 289}], {
             RGBColor[
             0.8697986288874946, 0.4756199934349731, 0.21204915614425965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 370}], {
             RGBColor[
             0.8365302867115927, 0.5954450493775967, 0.5857332485541368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 391}], {
             RGBColor[
             0.8311173699138001, 0.24018731764171894`, 0.1774313346124849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 400}], {
             RGBColor[
             0.6157274285874001, 0.4172598139869824, 0.5668748799123404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 109}], {
             RGBColor[
             0.79245120355282, 0.8352543310125031, 0.854215095221335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 120}], {
             RGBColor[
             0.5785921359057922, 0.6687661870638313, 0.9599680388727843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 136}], {
             RGBColor[
             0.6046940354323059, 0.6899568849766287, 0.9620228760179198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 237}], {
             RGBColor[
             0.5846124943759591, 0.6736537852839712, 0.9604419835448554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 246}], {
             RGBColor[
             0.5173044068287108, 0.618751689159956, 0.9552146295473145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 254}], {
             RGBColor[
             0.5301586737259505, 0.6294457205636295, 0.9561551793123693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 286}], {
             RGBColor[
             0.658527918518543, 0.7323765551714567, 0.9671395072605043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 320}], {
             RGBColor[
             0.6503499887449748, 0.725987894277777, 0.9663244076477739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 343}], {
             RGBColor[
             0.6565032648608529, 0.7307948803461315, 0.9669377087053699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 349}], {
             RGBColor[
             0.518092548976322, 0.6194343382750406, 0.9552648492680336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 87}], {
             RGBColor[
             0.3122775575094636, 0.4431804871474425, 0.9411820189118731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 96}], {
             RGBColor[
             0.31066394327551555`, 0.4414844762785116, 0.9410901259683782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 110}], {
             RGBColor[
             0.29499717102305234`, 0.4250177053104399, 0.9401979264655129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 146}], {
             RGBColor[
             0.4348738177323767, 0.548860724677587, 0.9495460387678236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 154}], {
             RGBColor[
             0.38228721374237734`, 0.5055397030547701, 0.9455799811097223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 159}], {
             RGBColor[
             0.3329254963503931, 0.4627850644418876, 0.9424346961263579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 167}], {
             RGBColor[
             0.30898293281547473`, 0.43971762770278966`, 0.9409943949095109]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 192}], {
             RGBColor[
             0.3394530711598287, 0.46843892165637124`, 0.9428506274211075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 201}], {
             RGBColor[
             0.30542134246892777`, 0.4359741704306982, 0.9407915676081757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 203}], {
             RGBColor[
             0.31290698696191654`, 0.4438420574101029, 0.9412178639880329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 228}], {
             RGBColor[
             0.35113678778418134`, 0.4785587697557132, 0.9435951035129062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 243}], {
             RGBColor[
             0.3113941751763021, 0.44225199630561496`, 0.9411317115948465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 332}], {
             RGBColor[
             0.4308190028061351, 0.5455688432531333, 0.9492268288835535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 348}], {
             RGBColor[
             0.2986858104115632, 0.42889469918101, 0.9404079890218355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 361}], {
             RGBColor[
             0.34502145958500996`, 0.47326197983492335`, 0.9432054402076274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 385}], {
             RGBColor[
             0.4549187217473041, 0.5651340807695402, 0.9511240470387816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 89}], {
             RGBColor[
             0.21914913629591037`, 0.3476700154777373, 0.9357915911587338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 163}], {
             RGBColor[
             0.23234434831161116`, 0.36153901993100174`, 0.9365430389624612]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 169}], {
             RGBColor[
             0.22020695780518662`, 0.3487818529537441, 0.9358518325287805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 209}], {
             RGBColor[
             0.23587421810878062`, 0.36524913689449845`, 0.9367440598254355]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 227}], {
             RGBColor[
             0.2273187292651137, 0.35625677567048153`, 0.9362568373925002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 240}], {
             RGBColor[
             0.22946097871463872`, 0.3585084156683923, 0.9363788353294766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 245}], {
             RGBColor[
             0.22480714766170556`, 0.3536169441618284, 0.9361138065357382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 248}], {
             RGBColor[
             0.21796166804011632`, 0.3464219110510618, 0.9357239665982682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 292}], {
             RGBColor[
             0.21536706305033604`, 0.3436948166993449, 0.9355762076824743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 304}], {
             RGBColor[
             0.21940694053557647`, 0.34794098407935925`, 0.9358062727287957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 315}], {
             RGBColor[
             0.23149483664630416`, 0.3606461293086136, 0.9364946605298619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 329}], {
             RGBColor[
             0.22742713619850993`, 0.35637071823087746`, 0.9362630110069835]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 353}], {
             RGBColor[
             0.2150475477536689, 0.34335898586410785`, 0.9355580117590097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 378}], {
             RGBColor[
             0.21412094136701804`, 0.3423850638014996, 0.9355052428960813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 151}], {
             RGBColor[
             0.34752633634939933`, 0.4754315781894705, 0.9433650487400788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 157}], {
             RGBColor[
             0.4242304983845992, 0.5414364441367214, 0.9483720501423687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 171}], {
             RGBColor[
             0.32621487078886763`, 0.45368735101725755`, 0.9421273921767691]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 182}], {
             RGBColor[
             0.3336557333984177, 0.4615081693978327, 0.9425511382946132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 253}], {
             RGBColor[
             0.3604664667584644, 0.48663966875993736`, 0.9441895824072364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 108}], {
             RGBColor[
             0.3602253738682746, 0.48643084621613597`, 0.9441742201814636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 120}], {
             RGBColor[
             0.45962999176153224`, 0.5694602774020465, 0.9513564039568587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 125}], {
             RGBColor[
             0.315433813888692, 0.4447906722692076, 0.9414242734794431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 179}], {
             RGBColor[
             0.3112624132414147, 0.4404062657068423, 0.9411867183836149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 196}], {
             RGBColor[
             0.32540289254677246`, 0.4552688060149441, 0.9419919977610904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 231}], {
             RGBColor[
             0.3307828964588674, 0.4609235312385056, 0.9422983810248817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 237}], {
             RGBColor[
             0.4656503502316991, 0.5743478756221865, 0.9518303486289299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 246}], {
             RGBColor[
             0.39834226268445083`, 0.5194457794981713, 0.946602994631389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 254}], {
             RGBColor[
             0.4111965295816905, 0.5301398109018447, 0.9475435443964437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 303}], {
             RGBColor[
             0.32124670467921895`, 0.4509003890486145, 0.9417553090105623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 313}], {
             RGBColor[
             0.31784501109874064`, 0.44732499341570175`, 0.9415615875935087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 344}], {
             RGBColor[
             0.33675515918736176`, 0.4661021259068189, 0.9426787188558917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 349}], {
             RGBColor[
             0.3991304048320619, 0.5201284286132558, 0.946653214352108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.44236640792617826`, 0.5377470693075241, 0.9524063925246276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 152}], {
             RGBColor[
             0.18127159018880934`, 0.30785831294404253`, 0.9336345209427424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 156}], {
             RGBColor[
             0.18244327672263497`, 0.3090898297803102, 0.9337012467574888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 175}], {
             RGBColor[
             0.1789295778879611, 0.3053967095236947, 0.9335011468069058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 204}], {
             RGBColor[
             0.17892700714738574`, 0.30539400751235557`, 0.933501000407033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 256}], {
             RGBColor[
             0.20211768989058865`, 0.32976888544967253`, 0.9348216754817178]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 261}], {
             RGBColor[
             0.17918769193352976`, 0.30566800375096304`, 0.9335158460199553]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 264}], {
             RGBColor[
             0.18447901438019912`, 0.31122951913163255`, 0.9338171790054831]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 317}], {
             RGBColor[
             0.5847770387283635, 0.6478930395078799, 0.8692491754054186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 333}], {
             RGBColor[
             0.18724373492288626`, 0.3141354157154036, 0.9339746257503516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 381}], {
             RGBColor[
             0.5860370216699882, 0.6484140748343261, 0.8483679973313716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 389}], {
             RGBColor[
             0.1790075704625178, 0.3054786846645686, 0.933505588368647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 96}], {
             RGBColor[
             0.2641094772748117, 0.3949261844968264, 0.9383520160646184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 110}], {
             RGBColor[
             0.2484427050223485, 0.37845941352875473`, 0.9374598165617531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 115}], {
             RGBColor[
             0.2399567828787064, 0.36954017131724737`, 0.9369765558494695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 139}], {
             RGBColor[
             0.2262390695271757, 0.3551219848315275, 0.9361953523676381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 167}], {
             RGBColor[
             0.2624284668147709, 0.39315933592110447`, 0.9382562850057511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 184}], {
             RGBColor[
             0.22953519250719354`, 0.35858641906979366`, 0.9363830616951732]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 188}], {
             RGBColor[
             0.25419669233076414`, 0.38450721901376617`, 0.937787497626706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 203}], {
             RGBColor[
             0.2663525209612127, 0.3972837656284177, 0.9384797540842731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 258}], {
             RGBColor[
             0.24712036386052527`, 0.3770695491264064, 0.9373845111888157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 284}], {
             RGBColor[
             0.24265277809452013`, 0.37237383322503703`, 0.9371300887886426]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 325}], {
             RGBColor[
             0.22643759197523877`, 0.355330644511492, 0.9362066579273677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 348}], {
             RGBColor[
             0.2521313444108594, 0.3823364073993248, 0.9376698791180758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 351}], {
             RGBColor[
             0.24352597864269326`, 0.37329162236527946`, 0.9371798162680766]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 369}], {
             RGBColor[
             0.24938070758750824`, 0.3794453136975352, 0.9375132344201885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 95}], {
             RGBColor[
             0.2911574427094625, 0.42335531110870317`, 0.9398923576822427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 151}], {
             RGBColor[
             0.30818593638346986`, 0.44059786327207706`, 0.9408861053327038]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[
             0.27226239938534696`, 0.40349542256011695`, 0.9388163129176459]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 229}], {
             RGBColor[
             0.27371625819309475`, 0.4050235203470323, 0.9388991080259558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 249}], {
             RGBColor[
             0.2850528182511259, 0.41693896374744543`, 0.939544708350323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 308}], {
             RGBColor[
             0.28081236703944734`, 0.4124819806638359, 0.9393032209270034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 309}], {
             RGBColor[
             0.28566340206902835`, 0.417580726053311, 0.9395794801954747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 334}], {
             RGBColor[
             0.28096769579564274`, 0.4126452410350092, 0.9393120666698803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 371}], {
             RGBColor[
             0.2862909803459218, 0.418240350613087, 0.9396152198499249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 386}], {
             RGBColor[
             0.31994974783175406`, 0.4507870854822257, 0.9416356849958585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 110}], {
             RGBColor[
             0.27285833032697415`, 0.4041217837639711, 0.9388502503031707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 134}], {
             RGBColor[
             0.26223279186396886`, 0.39295366914130303`, 0.9382451416067781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 159}], {
             RGBColor[
             0.3107866556543149, 0.4418891428954188, 0.9410870199640158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 167}], {
             RGBColor[
             0.28684409211939654`, 0.41882170615632086`, 0.9396467187471687]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 192}], {
             RGBColor[
             0.3173142304637505, 0.44754300010990244`, 0.9415029512587653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 201}], {
             RGBColor[
             0.2832825017728496, 0.4150782488842294, 0.9394438914458336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 210}], {
             RGBColor[
             0.2950312133683537, 0.42742688968244336`, 0.9401129631905363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 228}], {
             RGBColor[
             0.32899794708810315`, 0.4576628482092444, 0.9422474273505641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 236}], {
             RGBColor[
             0.2703304585010046, 0.4014648301985463, 0.938706291742333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 243}], {
             RGBColor[
             0.2892553344802239, 0.4213560747591461, 0.9397840354325044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 263}], {
             RGBColor[
             0.2761111635451054, 0.407540717717765, 0.9390354943428079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 348}], {
             RGBColor[
             0.27654696971548504`, 0.4079987776345412, 0.9390603128594934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 351}], {
             RGBColor[
             0.2679416039473189, 0.3989539926004958, 0.9385702500094941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[
             0.8934147061054667, 0.915612925432826, 0.8952711863200087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 132}], {
             RGBColor[
             0.8947680641910523, 0.9166701790551881, 0.8954060764061295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 140}], {
             RGBColor[
             0.8311193811821351, 0.8669473441407145, 0.8890621705145608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 168}], {
             RGBColor[
             0.8302321284771527, 0.8662542155842119, 0.8889737374567761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 282}], {
             RGBColor[
             0.8185877701205739, 0.8571575543356513, 0.887813136638508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 283}], {
             RGBColor[
             0.9496145330722283, 0.8334245259791293, 0.5278793972462171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 357}], {
             RGBColor[
             0.8330019348815232, 0.8684180093986145, 0.8892498058738514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 163}], {
             RGBColor[
             0.23177803755773202`, 0.36094379142249916`, 0.9365107884028094]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 164}], {
             RGBColor[
             0.2305606666537099, 0.3596642574165986, 0.9364414609307642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 169}], {
             RGBColor[
             0.2196406470513075, 0.3481866244452415, 0.9358195819691286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 209}], {
             RGBColor[
             0.23530790735490154`, 0.3646539083859959, 0.9367118092657838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 227}], {
             RGBColor[
             0.22675241851123462`, 0.35566154716197895`, 0.9362245868328485]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 245}], {
             RGBColor[
             0.22424083690782642`, 0.3530217156533258, 0.9360815559760864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.22879801729426974`, 0.3578116011814027, 0.9363410806573501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 292}], {
             RGBColor[
             0.21480075229645693`, 0.3430995881908423, 0.9355439571228226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 304}], {
             RGBColor[
             0.21884062978169738`, 0.3473457555708567, 0.9357740221691438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 315}], {
             RGBColor[
             0.23092852589242507`, 0.36005090080011104`, 0.93646240997021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 329}], {
             RGBColor[
             0.22686082544463082`, 0.3557754897223749, 0.9362307604473317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 353}], {
             RGBColor[
             0.21448123699978983`, 0.34276375735560527`, 0.9355257611993579]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 378}], {
             RGBColor[
             0.2135546306131389, 0.341789835292997, 0.9354729923364294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 138}], {
             RGBColor[
             0.7625743389841517, 0.45989176227570816`, 0.5687339252858672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 142}], {
             RGBColor[
             0.763694887526314, 0.46850478939826945`, 0.5698069638353204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 152}], {
             RGBColor[
             0.4447109838202162, 0.5402113672268555, 0.9525399126533038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 156}], {
             RGBColor[
             0.4458826703540418, 0.5414428840631231, 0.9526066384680504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 175}], {
             RGBColor[
             0.44236897151936794`, 0.5377497638065076, 0.9524065385174674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 202}], {
             RGBColor[
             0.7810727137045386, 0.6020783764160916, 0.5864479898090358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 242}], {
             RGBColor[
             0.8120763207412868, 0.7420397918675932, 0.6122349694370377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 256}], {
             RGBColor[
             0.46555708352199543`, 0.5621219397324855, 0.9537270671922793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[
             0.7642064856318851, 0.4724371566214084, 0.5702968707589827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 261}], {
             RGBColor[
             0.4426270855649366, 0.538021058033776, 0.9524212377305169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 264}], {
             RGBColor[
             0.44791840801160593`, 0.5435825734144455, 0.9527225707160447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 268}], {
             RGBColor[
             0.7615624007787926, 0.45211356179516854`, 0.5677648921175946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 317}], {
             RGBColor[
             0.8482164323597703, 0.8802460937906929, 0.8881545671159801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 333}], {
             RGBColor[
             0.4506831285542931, 0.5464884699982167, 0.9528800174609131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 381}], {
             RGBColor[
             0.849476415301395, 0.8807671291171392, 0.8672733890419332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 141}], {
             RGBColor[
             0.3113425799408942, 0.43982647528346147`, 0.9412155979078848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 150}], {
             RGBColor[
             0.2666109948635128, 0.3975554380879269, 0.9384944737906311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 186}], {
             RGBColor[
             0.2555444422624831, 0.38592378964428387`, 0.9378642499915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 189}], {
             RGBColor[
             0.28158397795101814`, 0.4132929926548542, 0.9393471630269211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 190}], {
             RGBColor[
             0.25186209923856306`, 0.38205341365211143`, 0.9376545460038261]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 226}], {
             RGBColor[
             0.25062761976227643`, 0.38075589745201466`, 0.9375842442239002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 241}], {
             RGBColor[
             0.2767915804260243, 0.40825587900053273`, 0.9390742430775896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 255}], {
             RGBColor[
             0.26154809523840944`, 0.39223400957556664`, 0.9382061491468703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 266}], {
             RGBColor[
             0.25880957199136756`, 0.38935564801052325`, 0.9380501942992334]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 273}], {
             RGBColor[
             0.26902930475390907`, 0.40009723511243644`, 0.9386321929613204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 365}], {
             RGBColor[
             0.259430965008946, 0.3900087714705911, 0.9380855817123159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 114}], {
             RGBColor[
             0.3082708613262549, 0.43948126919774927`, 0.9409350939621447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 153}], {
             RGBColor[
             0.30254730129756563`, 0.4345238091753902, 0.940570393778262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 161}], {
             RGBColor[
             0.35955024405905767`, 0.48389689314418627`, 0.9442025708853012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 188}], {
             RGBColor[
             0.27737488016395806`, 0.40886896400844064`, 0.9391074611347503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 195}], {
             RGBColor[
             0.26667927398787117`, 0.3976272037767742, 0.9384983621857534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 258}], {
             RGBColor[
             0.2702985516937192, 0.40143129412108086`, 0.93870447469686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 278}], {
             RGBColor[
             0.2700397327532974, 0.4011592590046289, 0.9386897353410912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 284}], {
             RGBColor[
             0.26583096592771405`, 0.3967355782197115, 0.9384500522966869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 327}], {
             RGBColor[
             0.3031279877877182, 0.4350267706270088, 0.9406073946079336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 337}], {
             RGBColor[
             0.2862035870447653, 0.41814849471251614`, 0.9396102429307109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 354}], {
             RGBColor[
             0.2837186388686095, 0.41553665662456213`, 0.9394687288082302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 392}], {
             RGBColor[
             0.26780652703776464`, 0.39881201820418366`, 0.9385625575793235]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 94}], {
             RGBColor[
             0.2526810398598759, 0.3829141721689455, 0.9377011834606958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 119}], {
             RGBColor[
             0.24286823945996167`, 0.3726002967811557, 0.9371423589946579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 128}], {
             RGBColor[
             0.2857256322546389, 0.41603117628641406`, 0.9396421556226617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 225}], {
             RGBColor[
             0.25117310830966183`, 0.38132924050128825`, 0.9376153089896959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 296}], {
             RGBColor[
             0.27337982614775685`, 0.40466990893635857`, 0.9388799487186803]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 301}], {
             RGBColor[
             0.25102800874557624`, 0.38117673165959054`, 0.9376070457841768]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 316}], {
             RGBColor[
             0.2497588091651779, 0.37984272242869066`, 0.9375347667456857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 324}], {
             RGBColor[
             0.26259788296436154`, 0.3933374030359285, 0.9382659330048415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 355}], {
             RGBColor[
             0.23807963900287032`, 0.36756717408594775`, 0.936869655282726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 380}], {
             RGBColor[
             0.25536438822798396`, 0.38573454143794017`, 0.9378539961806014]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 383}], {
             RGBColor[
             0.2627372188358315, 0.39348385387124796`, 0.9382738679765928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 390}], {
             RGBColor[
             0.2557686929307827, 0.3861594913149804, 0.9378770207353105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 119}], {
             RGBColor[
             0.25031116778183593`, 0.38042328635635736`, 0.9375662227517629]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 128}], {
             RGBColor[
             0.29316856057651314`, 0.42385416586161573`, 0.9400660193797667]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 177}], {
             RGBColor[
             0.29101623446385616`, 0.4219899291618881, 0.9399288750630955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 200}], {
             RGBColor[
             0.26539181138814727`, 0.3962739989546208, 0.9384250430953294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 225}], {
             RGBColor[
             0.2586160366315361, 0.3891522300764899, 0.9380391727468009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 288}], {
             RGBColor[
             0.25257497972760906`, 0.38280269624533236`, 0.9376951434930652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 296}], {
             RGBColor[
             0.2808227544696311, 0.4124928985115602, 0.9393038124757853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 316}], {
             RGBColor[
             0.25720173748705216`, 0.38766571200389227`, 0.9379586305027907]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 324}], {
             RGBColor[
             0.2700408112862358, 0.4011603926111301, 0.9386897967619465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 355}], {
             RGBColor[
             0.2455225673247446, 0.37539016366114936`, 0.937293519039831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 375}], {
             RGBColor[
             0.25748465436672835`, 0.3879630755823982, 0.9379747422005502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 380}], {
             RGBColor[
             0.2628073165498582, 0.39355753101314184`, 0.9382778599377064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 383}], {
             RGBColor[
             0.2701801471577058, 0.4013068434464496, 0.9386977317336979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 390}], {
             RGBColor[
             0.26321162125265696`, 0.393982480890182, 0.9383008844924156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 129}], {
             RGBColor[
             0.2597315005548766, 0.39032465338441835`, 0.9381026967670542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 151}], {
             RGBColor[
             0.2988070240901653, 0.4307400317944288, 0.9403519901524575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 178}], {
             RGBColor[
             0.2628834870920424, 0.39363759108246865`, 0.9382821977373995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 229}], {
             RGBColor[
             0.2643373458997902, 0.3951656888693841, 0.9383649928457094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 249}], {
             RGBColor[
             0.2756739059578213, 0.4070811322697972, 0.9390105931700766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 270}], {
             RGBColor[
             0.26568283896088996`, 0.3965798873857872, 0.9384416166850604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 308}], {
             RGBColor[
             0.2714334547461428, 0.4026241491861876, 0.9387691057467569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 309}], {
             RGBColor[
             0.2762844897757238, 0.4077228945756627, 0.9390453650152284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 334}], {
             RGBColor[
             0.27158878350233817`, 0.4027874095573609, 0.9387779514896339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 371}], {
             RGBColor[
             0.27691206805261726`, 0.40838251913543877`, 0.9390811046696785]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 386}], {
             RGBColor[
             0.3105708355384495, 0.4409292540045774, 0.9411015698156122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 110}], {
             RGBColor[
             0.2712447160930261, 0.4024257728950402, 0.9387583573596757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 114}], {
             RGBColor[
             0.3078946845637386, 0.4390858835693603, 0.940913671252023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 115}], {
             RGBColor[
             0.262758793949384, 0.3935065306835328, 0.9382750966473921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 153}], {
             RGBColor[
             0.3021711245350493, 0.4341284235470012, 0.9405489710681403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 154}], {
             RGBColor[
             0.3585347588123511, 0.48294777063937044`, 0.9441404120038852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 167}], {
             RGBColor[
             0.28523047788544853`, 0.41712569528738996`, 0.9395548258036737]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 188}], {
             RGBColor[
             0.2769987034014417, 0.4084735783800516, 0.9390860384246287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 192}], {
             RGBColor[
             0.3157006162298024, 0.44584698924097155`, 0.9414110583152703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 203}], {
             RGBColor[
             0.28915453203189034`, 0.42125012499470316`, 0.9397782948821958]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 228}], {
             RGBColor[
             0.3273843328541551, 0.4559668373403135, 0.9421555344070691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 243}], {
             RGBColor[
             0.2876417202462759, 0.4196600638902152, 0.9396921424890095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 258}], {
             RGBColor[
             0.26992237493120286`, 0.4010359084926919, 0.9386830519867384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 284}], {
             RGBColor[
             0.2654547891651977, 0.3963401925913225, 0.9384286295865651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 348}], {
             RGBColor[
             0.27493335548153697`, 0.4063027667656103, 0.9389684199159984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 361}], {
             RGBColor[
             0.32126900465498376`, 0.45067004741952366`, 0.9417658711017902]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 369}], {
             RGBColor[
             0.27218271865818583`, 0.40341167306382075`, 0.9388117752181111]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 100}], {
             RGBColor[
             0.4094492665548738, 0.5290661079964851, 0.9473107230964745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 105}], {
             RGBColor[
             0.42981427861771465`, 0.5467052578700499, 0.9486083636570456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 112}], {
             RGBColor[
             0.38560280932821134`, 0.5084115053045399, 0.9457912479285857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 132}], {
             RGBColor[
             0.6207534044996754, 0.7002920708010887, 0.965012812845729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 140}], {
             RGBColor[
             0.5571047214907582, 0.6505692358866151, 0.9586689069541604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 141}], {
             RGBColor[
             0.401174197469898, 0.5218986590721447, 0.9467834430117361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 168}], {
             RGBColor[
             0.5562174687857758, 0.6498761073301125, 0.9585804738963757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 180}], {
             RGBColor[
             0.40427723483543804`, 0.5245863540749827, 0.9469811658087601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 220}], {
             RGBColor[
             0.4588594812307164, 0.571262237287139, 0.9506250224317093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 282}], {
             RGBColor[
             0.5445731104291971, 0.6407794460815519, 0.9574198730781076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 350}], {
             RGBColor[
             0.437513599136121, 0.5533740223239922, 0.9490989575522366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 357}], {
             RGBColor[
             0.5589872751901463, 0.652039901144515, 0.958856542313451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 394}], {
             RGBColor[
             0.40057619946044803`, 0.521380703252613, 0.9467453391073628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 107}], {
             RGBColor[
             0.9083938909149378, 0.6192253386491839, 0.2762763560175848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 131}], {
             RGBColor[
             0.9500181408117219, 0.8331560489585412, 0.3119185917864623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 215}], {
             RGBColor[
             0.8984291495802124, 0.5426319701729883, 0.2667341084618861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 283}], {
             RGBColor[
             0.9432427006605664, 0.8062936865407971, 0.3064669136008217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 297}], {
             RGBColor[
             0.9621045612745434, 0.9478624391979251, 0.6712874553374975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 307}], {
             RGBColor[
             0.9814050384421338, 0.9620825967866911, 0.6308199289588313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 352}], {
             RGBColor[
             0.9858621188487648, 0.9629527205499828, 0.4862282141252213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 123}], {
             RGBColor[
             0.9762118677425246, 0.9817794304286422, 0.9251512823600752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 174}], {
             RGBColor[
             0.8533664925541351, 0.885559755956836, 0.9477463395066474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 187}], {
             RGBColor[
             0.9110307205751575, 0.9308010667922535, 0.953442401298972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 193}], {
             RGBColor[
             0.9002336063428361, 0.9221917409832586, 0.9524125629047955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[
             0.9440956875300477, 0.9571661739174645, 0.9565961673645738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 232}], {
             RGBColor[
             0.7518421224806613, 0.804458883314896, 0.9388506680687247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 235}], {
             RGBColor[
             0.8591106393434069, 0.8900471270857477, 0.9483188623764983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 275}], {
             RGBColor[
             0.9851141209349312, 0.987104803716967, 0.8512424005775606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 279}], {
             RGBColor[
             0.9618886205302903, 0.9027170726846294, 0.5985175369470697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 281}], {
             RGBColor[
             0.8050608246814849, 0.8476642232367373, 0.943040239252503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 306}], {
             RGBColor[
             0.9742518584397497, 0.947471002545973, 0.6306628392778444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 338}], {
             RGBColor[
             0.9862079875593082, 0.9866999578573392, 0.7708056942036536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 384}], {
             RGBColor[
             0.863277719993484, 0.893302482160574, 0.9487341980321153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 105}], {
             RGBColor[
             0.3969790975995051, 0.5182650744162607, 0.9465161349575758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 112}], {
             RGBColor[
             0.35276762831000186`, 0.47997132185075075`, 0.9436990192291159]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 141}], {
             RGBColor[
             0.3683390164516885, 0.49345847561835543`, 0.9446912143122663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 168}], {
             RGBColor[
             0.5233822877675662, 0.6214359238763232, 0.9564882451969059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 170}], {
             RGBColor[
             0.4107918604538279, 0.5302289953510277, 0.9473962719925066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 180}], {
             RGBColor[
             0.3714420538172285, 0.49614617062119337`, 0.9448889371092903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 220}], {
             RGBColor[
             0.42602430021250687`, 0.5428220538333498, 0.9485327937322395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 271}], {
             RGBColor[
             0.3417009842764249, 0.4702049097204598, 0.9430004912657755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 273}], {
             RGBColor[
             0.3260257412647034, 0.4537292354473304, 0.9421078093657018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 282}], {
             RGBColor[
             0.5117379294109875, 0.6123392626277626, 0.9553276443786378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 350}], {
             RGBColor[
             0.4046784181179114, 0.524933838870203, 0.9470067288527668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 394}], {
             RGBColor[
             0.3677410184422385, 0.49294051979882375`, 0.944653110407893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 151}], {
             RGBColor[
             0.2883386750076016, 0.41973713317698713`, 0.9397558331587401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 171}], {
             RGBColor[
             0.2670272094470698, 0.3979929060047742, 0.9385181765954305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 182}], {
             RGBColor[
             0.2744680720566198, 0.40581372438534935`, 0.9389419227132746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 244}], {
             RGBColor[
             0.2604390037563816, 0.39106828410749395`, 0.9381429880277227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 253}], {
             RGBColor[
             0.3012788054166666, 0.43094522374745403`, 0.9405803668258977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 270}], {
             RGBColor[
             0.2552144898783262, 0.38557698876834556`, 0.937845459691343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 308}], {
             RGBColor[
             0.26096510566357906`, 0.39162125056874597`, 0.9381729487530396]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 397}], {
             RGBColor[
             0.2550956906132599, 0.3854521232084524, 0.9378386942489454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 160}], {
             RGBColor[
             0.8243873085977117, 0.18845711723458924`, 0.17098662029568146`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 166}], {
             RGBColor[
             0.8220330696681408, 0.1703614051878311, 0.16873219843799186`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[
             0.8214937595564198, 0.16621603134194454`, 0.16821575446594406`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 213}], {
             RGBColor[
             0.8651325745805382, 0.41702815829837886`, 0.20666661364992278`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 224}], {
             RGBColor[
             0.8974792718626248, 0.5394468704448865, 0.26303107700793477`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 230}], {
             RGBColor[
             0.8940771340934058, 0.5279706608893748, 0.24981441421432754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 247}], {
             RGBColor[
             0.8631522875093278, 0.40917697995257735`, 0.2050732281891151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 250}], {
             RGBColor[
             0.9037621261807391, 0.5693653564012491, 0.505440590565607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 289}], {
             RGBColor[
             0.8585251717968794, 0.3889672621761071, 0.20125368090273776`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 302}], {
             RGBColor[
             0.9032870347441282, 0.5590378183717704, 0.2855931390985828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 340}], {
             RGBColor[
             0.9065375818313084, 0.569215708650745, 0.3651390053950433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 370}], {
             RGBColor[
             0.8252568296209774, 0.5087923181187306, 0.5749377733126149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 391}], {
             RGBColor[
             0.8198439128231849, 0.15353458638285297`, 0.16663585937096298`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 400}], {
             RGBColor[
             0.6044539714967849, 0.33060708272811645`, 0.5560794046708185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 108}], {
             RGBColor[
             0.3560676178251626, 0.48282960690648735`, 0.9439092916429558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 133}], {
             RGBColor[
             0.32091218999488846`, 0.4513176188145481, 0.9417081084114585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 143}], {
             RGBColor[
             0.48460520194471113`, 0.589510492500073, 0.9533849292372562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 223}], {
             RGBColor[
             0.3993166746191169, 0.5202694238127852, 0.9466707039440156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 231}], {
             RGBColor[
             0.3266251404157554, 0.4573222919288569, 0.942033452486374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 234}], {
             RGBColor[
             0.34165277525472826`, 0.4703441947830308, 0.9429907906209125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 290}], {
             RGBColor[
             0.3748499370785241, 0.4990979078169345, 0.9451060844172272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 313}], {
             RGBColor[
             0.31368725505562867`, 0.4437237541060531, 0.9412966590550009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 331}], {
             RGBColor[
             0.39832931347278433`, 0.519434563541872, 0.9466021695190721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 342}], {
             RGBColor[
             0.4739621782432806, 0.580870006396498, 0.9525470714247991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 346}], {
             RGBColor[
             0.3447990844282577, 0.4730693696510448, 0.9431912706592778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 109}], {
             RGBColor[
             0.9639852685830836, 0.8836832833010115, 0.5065761886025747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 138}], {
             RGBColor[
             0.8766084818851104, 0.4626116115176483, 0.21590390436629117`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 144}], {
             RGBColor[
             0.9061560966553733, 0.6582187386740248, 0.24296492852905843`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 205}], {
             RGBColor[
             0.9645712998383063, 0.8839256222853624, 0.49686413410326324`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 207}], {
             RGBColor[
             0.9368649528111581, 0.7873976069432023, 0.2680582629430743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 233}], {
             RGBColor[
             0.8756661600168449, 0.4553685127100845, 0.21500153588103987`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 358}], {
             RGBColor[
             0.9512253799690775, 0.8406018507565884, 0.299039239235954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 366}], {
             RGBColor[
             0.9175772665295729, 0.7100796035907695, 0.25249503263058215`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 382}], {
             RGBColor[
             0.9163275048198573, 0.7044047275562138, 0.25145220082553266`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 112}], {
             RGBColor[
             0.37313264037284266`, 0.49761047172431544`, 0.944996659789687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 113}], {
             RGBColor[
             0.6069298774587211, 0.6884337835985022, 0.9640833346207096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 148}], {
             RGBColor[
             0.520616067080279, 0.620721827134755, 0.9556738363326167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 155}], {
             RGBColor[
             0.3609448647521152, 0.4866656792120809, 0.9442342850410239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 168}], {
             RGBColor[
             0.5437472998304071, 0.6390750737498879, 0.957785885757477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 170}], {
             RGBColor[
             0.4311568725166687, 0.5478681452245924, 0.9486939125530778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 180}], {
             RGBColor[
             0.39180706588006936`, 0.513785320494758, 0.9461865776698615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 239}], {
             RGBColor[
             0.37092951443948974`, 0.4957022347731742, 0.9448562785533615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 271}], {
             RGBColor[
             0.36206599633926584`, 0.4878440595940245, 0.9442981318263466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 282}], {
             RGBColor[
             0.5321029414738284, 0.6299784125013272, 0.956625284939209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 326}], {
             RGBColor[
             0.37836717266856673`, 0.5021443605036287, 0.9453301995588554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 350}], {
             RGBColor[
             0.4250434301807523, 0.5425729887437677, 0.948304369413338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 394}], {
             RGBColor[
             0.38810603050507936`, 0.5105796696723884, 0.9459507509684641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.8938562482651202, 0.6317789737296462, 0.5786286100973383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 173}], {
             RGBColor[
             0.5874312139478495, 0.658182594689114, 0.9541358462016971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 197}], {
             RGBColor[
             0.9686231253627324, 0.9753622711647122, 0.9040752003743098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 204}], {
             RGBColor[
             0.563710908416439, 0.6332510496213667, 0.9527850098927306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 214}], {
             RGBColor[
             0.9661339552698273, 0.9742633398075717, 0.9422105594358144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 215}], {
             RGBColor[
             0.8838915069303948, 0.5551856052534505, 0.5690863625416396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 295}], {
             RGBColor[
             0.5954410834145789, 0.6666014753537031, 0.9545919964182874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 310}], {
             RGBColor[
             0.5655364837016175, 0.6351698449942476, 0.952888973704525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 345}], {
             RGBColor[
             0.5752211056493675, 0.6453489967018295, 0.953440498597335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 363}], {
             RGBColor[
             0.905503655257033, 0.714845634359743, 0.589529206598464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 131}], {
             RGBColor[
             0.8808419295941465, 0.5163805585259162, 0.22083043617809295`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 197}], {
             RGBColor[
             0.9139845567949747, 0.6460331456516251, 0.5106347906861869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 215}], {
             RGBColor[
             0.829252938362637, 0.22585647974036333`, 0.17564595285351675`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 297}], {
             RGBColor[
             0.892928350056968, 0.6310869487653001, 0.5801992997291281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 307}], {
             RGBColor[
             0.9122288272245584, 0.6453071063540661, 0.539731773350462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 352}], {
             RGBColor[
             0.9166859076311894, 0.6461772301173578, 0.39514005851685197`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 363}], {
             RGBColor[
             0.8508650866892753, 0.3855165088466559, 0.1960887969103411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 143}], {
             RGBColor[
             0.49610666284564264`, 0.5994724798522266, 0.954117792155521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 179}], {
             RGBColor[
             0.3186061180992342, 0.4467670137493473, 0.9416546527633719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 196}], {
             RGBColor[
             0.332746597404592, 0.4616295540574491, 0.9424599321408476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 231}], {
             RGBColor[
             0.3381266013166869, 0.4672842792810106, 0.9427663154046388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 234}], {
             RGBColor[
             0.3531542361556598, 0.4803061821351844, 0.9437236535391773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 290}], {
             RGBColor[
             0.3863513979794556, 0.5090598951690881, 0.945838947335492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 313}], {
             RGBColor[
             0.3251887159565602, 0.4536857414582067, 0.9420295219732657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 331}], {
             RGBColor[
             0.40983077437371584`, 0.5293965508940257, 0.9473350324373369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 342}], {
             RGBColor[
             0.48546363914421214`, 0.5908319937486516, 0.9532799343430639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 344}], {
             RGBColor[
             0.3440988640451813, 0.47246287394932385`, 0.9431466532356487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 136}], {
             RGBColor[
             0.8063392816861509, 0.8465292984919313, 0.8553084156056971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 205}], {
             RGBColor[
             0.9946824810618875, 0.9920690835121566, 0.737788580309801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 207}], {
             RGBColor[
             0.9669761340347394, 0.8955410681699965, 0.508982709149612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 233}], {
             RGBColor[
             0.9057773412404262, 0.5635119739368787, 0.4559259820875775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 286}], {
             RGBColor[
             0.8601731647723879, 0.8889489686867593, 0.8604250468482817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 320}], {
             RGBColor[
             0.8519952349988198, 0.8825603077930796, 0.8596099472355513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 343}], {
             RGBColor[
             0.8581485111146978, 0.8873672938614341, 0.8602232482931473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 358}], {
             RGBColor[
             0.9813365611926588, 0.9487453119833825, 0.5399636854424916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 366}], {
             RGBColor[
             0.9476884477531541, 0.8182230648175637, 0.4934194788371198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 382}], {
             RGBColor[
             0.9464386860434384, 0.8125481887830079, 0.4923766470320703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 115}], {
             RGBColor[
             0.2470920216969208, 0.3770397597154611, 0.9373828971445268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 134}], {
             RGBColor[
             0.24495240537755758`, 0.37479088730430044`, 0.9372610491604179]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 167}], {
             RGBColor[
             0.26956370563298526`, 0.40065892431931827`, 0.9386626263008084]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 192}], {
             RGBColor[
             0.30003384397733923`, 0.42938021827289985`, 0.940518858812405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 203}], {
             RGBColor[
             0.2734877597794271, 0.40478335402663146`, 0.9388860953793305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 243}], {
             RGBColor[
             0.2719749479938126, 0.4031932929221435, 0.9387999429861442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 348}], {
             RGBColor[
             0.25926658322907375`, 0.3898359957975386, 0.9380762204131332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 351}], {
             RGBColor[
             0.25066121746090764`, 0.3807912107634932, 0.9375861575631339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 369}], {
             RGBColor[
             0.2565159464057226, 0.38694490209574905`, 0.9379195757152459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 160}], {
             RGBColor[
             0.8517778667942718, 0.37434165466445646`, 0.19625056684916897`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 166}], {
             RGBColor[
             0.8494236278647009, 0.35624594261769826`, 0.19399614499147944`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.8488843177529799, 0.35210056877181173`, 0.19347970101943163`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 197}], {
             RGBColor[
             0.931414792844472, 0.7553582824181725, 0.5263607215030722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[
             0.631844529693345, 0.5164916201579837, 0.581343351224306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 155}], {
             RGBColor[
             0.31673339546261187`, 0.44837192664657105`, 0.9414171693125639]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 170}], {
             RGBColor[
             0.3869454032271654, 0.5095743926590826, 0.9458767968246178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 180}], {
             RGBColor[
             0.34759559659056605`, 0.4754915679292482, 0.9433694619414015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 183}], {
             RGBColor[
             0.2939274002864909, 0.42440137973285763`, 0.9401184016257302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 271}], {
             RGBColor[
             0.3178545270497625, 0.4495503070285146, 0.9414810160978866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 273}], {
             RGBColor[
             0.30217928403804095`, 0.4330746327553852, 0.940588334197813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 326}], {
             RGBColor[
             0.3341557033790634, 0.4638506079381187, 0.9425130838303954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 350}], {
             RGBColor[
             0.380831960891249, 0.5042792361782578, 0.945487253684878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 394}], {
             RGBColor[
             0.34389456121557604`, 0.47228591710687856`, 0.9431336352400042]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 148}], {
             RGBColor[
             0.7102018348766541, 0.7732513864434318, 0.9719433954351793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 168}], {
             RGBColor[
             0.7333330676267822, 0.7916046330585647, 0.9740554448600397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 170}], {
             RGBColor[
             0.6207426403130438, 0.7003977045332692, 0.9649634716556403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 251}], {
             RGBColor[
             0.8094157442625041, 0.8510598457172036, 0.9816336535080088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 282}], {
             RGBColor[
             0.7216887092702036, 0.7825079718100041, 0.9728948440417715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 153}], {
             RGBColor[
             0.32315432075329853`, 0.4543217632532496, 0.9418120854576224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 154}], {
             RGBColor[
             0.3795179550306004, 0.5031411103456188, 0.9454035263933673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 188}], {
             RGBColor[
             0.297981899619691, 0.4286669180863, 0.9403491528141107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 203}], {
             RGBColor[
             0.3101377282501396, 0.4414434647009515, 0.9410414092716778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 222}], {
             RGBColor[
             0.4669023906435984, 0.574712579304436, 0.9521089968254883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 258}], {
             RGBColor[
             0.29090557114945215`, 0.42122924819894025`, 0.9399461663762204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 312}], {
             RGBColor[
             0.3959175277947622, 0.5170838698121216, 0.9465208083959076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 327}], {
             RGBColor[
             0.32373500724345117`, 0.4548247247048681, 0.941849086287294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 356}], {
             RGBColor[
             0.4236281428800086, 0.5395805954873082, 0.9487022895227458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 361}], {
             RGBColor[
             0.342252200873233, 0.470863387125772, 0.9430289854912723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 369}], {
             RGBColor[
             0.29316591487643506`, 0.4236050127700691, 0.9400748896075932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 392}], {
             RGBColor[
             0.2884135464934976, 0.418609972282043, 0.9398042492586839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 184}], {
             RGBColor[
             0.22818450918176583`, 0.35716676525650004`, 0.936306142277947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 188}], {
             RGBColor[
             0.25284600900533644`, 0.38308756520047255`, 0.9377105782094798]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 195}], {
             RGBColor[
             0.2421504028292495, 0.3718458049688061, 0.937101479260483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 203}], {
             RGBColor[
             0.265001837635785, 0.3958641118151241, 0.9384028346670469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 206}], {
             RGBColor[
             0.23508408472910247`, 0.364418656615107, 0.9366990628983605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 208}], {
             RGBColor[
             0.2358464087925902, 0.36521990753996986`, 0.9367424761260187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 258}], {
             RGBColor[
             0.24576968053509757`, 0.37564989531311277`, 0.9373075917715895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 284}], {
             RGBColor[
             0.24130209476909242`, 0.37095417941174347`, 0.9370531693714164]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 325}], {
             RGBColor[
             0.22508690864981107`, 0.3539109906981984, 0.9361297385101415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 369}], {
             RGBColor[
             0.24803002426208054`, 0.37802565988424164`, 0.9374363150029623]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 392}], {
             RGBColor[
             0.24327765587914302`, 0.37303061939621557`, 0.937165674654053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 121}], {
             RGBColor[
             0.48470874113100904`, 0.5915401565241579, 0.9528555034179461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 130}], {
             RGBColor[
             0.4133134657138138, 0.5324130830876621, 0.947556946449905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 135}], {
             RGBColor[
             0.4597496952635722, 0.5712772786967698, 0.9508906358992639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 147}], {
             RGBColor[
             0.35047958711339033`, 0.47576981650030403`, 0.9436345020558807]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 172}], {
             RGBColor[
             0.3588230012593764, 0.484539273770746, 0.9441096471485195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 265}], {
             RGBColor[
             0.5040580192630065, 0.6072487721867599, 0.9543787494712381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 276}], {
             RGBColor[
             0.5908937430052579, 0.6758585483037947, 0.9625051852330178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 322}], {
             RGBColor[
             0.46231873384021377`, 0.5733629399471565, 0.9510928800267155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 328}], {
             RGBColor[
             0.3628292631493686, 0.48868620423613895`, 0.944340137703926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 362}], {
             RGBColor[
             0.41044018393094006`, 0.5299243908226783, 0.9473738634754435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 364}], {
             RGBColor[
             0.382875553578809, 0.5060492934502673, 0.9456174696038513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 387}], {
             RGBColor[
             0.35489504602512995`, 0.4804107437728069, 0.9438859559088182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 223}], {
             RGBColor[
             0.40179215387534173`, 0.5224135595233219, 0.9468284392932418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 346}], {
             RGBColor[
             0.3472745636844825, 0.4752135053615816, 0.9433490060085041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 371}], {
             RGBColor[
             0.31078136056287864`, 0.44021172480761495`, 0.9411479331302521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 126}], {
             RGBColor[
             0.20905168496127685`, 0.33705695390964574`, 0.935216556243067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 149}], {
             RGBColor[
             0.21314012851733694`, 0.34135416730935836`, 0.9354493870552745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[
             0.21593219336709382`, 0.3442888044935889, 0.9356083910179783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 212}], {
             RGBColor[
             0.208479398474888, 0.33645544452739207`, 0.9351839653742893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 259}], {
             RGBColor[
             0.20854115618205327`, 0.33652035579328765`, 0.9351874823843499]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 293}], {
             RGBColor[
             0.20864634306607288`, 0.33663091387762584`, 0.9351934726217848]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 299}], {
             RGBColor[
             0.21009516231391617`, 0.33815371476755507`, 0.9352759807346135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 336}], {
             RGBColor[
             0.20853409149877072`, 0.3365129303632308, 0.9351870800610882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 367}], {
             RGBColor[
             0.21268815866311674`, 0.340879118336029, 0.9354236480407061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 200}], {
             RGBColor[
             0.2555790109882331, 0.38596012356683096`, 0.9378662186292916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 225}], {
             RGBColor[
             0.24880323623162193`, 0.37883835468870003`, 0.9374803482807631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 288}], {
             RGBColor[
             0.2427621793276949, 0.37248882085754254`, 0.9371363190270272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 296}], {
             RGBColor[
             0.27100995406971695`, 0.4021790231237703, 0.9387449880097476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 316}], {
             RGBColor[
             0.24738893708713797`, 0.3773518366161024, 0.9373998060367528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 324}], {
             RGBColor[
             0.26022801088632164`, 0.3908465172233403, 0.9381309722959088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 355}], {
             RGBColor[
             0.2357097669248304, 0.3650762882733595, 0.9367346945737933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 375}], {
             RGBColor[
             0.24767185396681415`, 0.37764920019460835`, 0.9374159177345123]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 380}], {
             RGBColor[
             0.25299451614994406`, 0.383243655625352, 0.9377190354716685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 383}], {
             RGBColor[
             0.2603673467577916, 0.3909929680586598, 0.93813890726766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 390}], {
             RGBColor[
             0.2533988208527428, 0.3836686055023921, 0.9377420600263777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 136}], {
             RGBColor[
             0.5924802140391232, 0.6800411545432594, 0.9610613592571464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 237}], {
             RGBColor[
             0.5723986729827764, 0.663738054850602, 0.9594804667840822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 246}], {
             RGBColor[
             0.505090585435528, 0.6088359587265868, 0.9542531127865411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 254}], {
             RGBColor[
             0.5179448523327678, 0.6195299901302602, 0.955193662551596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 286}], {
             RGBColor[
             0.6463140971253603, 0.7224608247380875, 0.966177990499731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 320}], {
             RGBColor[
             0.6381361673517921, 0.7160721638444079, 0.9653628908870006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 343}], {
             RGBColor[
             0.64428944346767, 0.7208791499127623, 0.9659761919445966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 349}], {
             RGBColor[
             0.5058787275831391, 0.6095186078416714, 0.9543033325072602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 130}], {
             RGBColor[
             0.48180086572832803`, 0.5890215010044231, 0.9526702161686205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 158}], {
             RGBColor[
             0.5281560210081759, 0.6278198768688632, 0.9559975231544674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 181}], {
             RGBColor[
             0.5602542166801026, 0.6538786381225696, 0.9585244106973264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 250}], {
             RGBColor[
             0.7707116790518824, 0.8187741201767487, 0.9013688926659322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 265}], {
             RGBColor[
             0.5725454192775208, 0.6638571901035208, 0.9594920191899539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 322}], {
             RGBColor[
             0.5308061338547281, 0.6299713578639174, 0.9562061497454312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 362}], {
             RGBColor[
             0.4789275839454543, 0.5865328087394392, 0.9524871331941591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 146}], {
             RGBColor[
             0.49070941162852855`, 0.5972227097318854, 0.9531038334374095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.3887610902465449, 0.5111470494961861, 0.9459924907959437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 165}], {
             RGBColor[
             0.48941818004964077`, 0.5961744297668246, 0.9530021829575823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 210}], {
             RGBColor[
             0.3730056479605837, 0.4966847962832106, 0.9450184340224643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 228}], {
             RGBColor[
             0.40697238168033323`, 0.5269207548100117, 0.9471528981824919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 262}], {
             RGBColor[
             0.6923652232093209, 0.7572804525421046, 0.9691955483013721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 298}], {
             RGBColor[
             0.634758859433705, 0.711422615804957, 0.9663329898214426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 314}], {
             RGBColor[
             0.6859497834912932, 0.7522408691078613, 0.9712156258567326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 385}], {
             RGBColor[
             0.510754315643456, 0.6134960658238386, 0.9546818417083673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 174}], {
             RGBColor[
             0.8514507591880022, 0.8841310051490996, 0.9509891763922267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 187}], {
             RGBColor[
             0.9091149872090246, 0.929372315984517, 0.9566852381845512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 193}], {
             RGBColor[
             0.8983178729767032, 0.9207629901755221, 0.9556553997903747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 218}], {
             RGBColor[
             0.9421799541639146, 0.955737423109728, 0.959839004250153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 232}], {
             RGBColor[
             0.7499263891145284, 0.8030301325071595, 0.9420935049543039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 235}], {
             RGBColor[
             0.8571949059772741, 0.8886183762780113, 0.9515616992620775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 275}], {
             RGBColor[
             0.9831983875687983, 0.9856760529092304, 0.8544852374631398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 279}], {
             RGBColor[
             0.9599728871641575, 0.901288321876893, 0.6017603738326488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 281}], {
             RGBColor[
             0.8031450913153519, 0.8462354724290008, 0.9462830761380823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 306}], {
             RGBColor[
             0.9723361250736168, 0.9460422517382365, 0.6339056761634236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 338}], {
             RGBColor[
             0.9842922541931751, 0.9852712070496027, 0.7740485310892328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.22241368079166546`, 0.3511012587268517, 0.9359775021383063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 199}], {
             RGBColor[
             0.224537016117427, 0.35333301878146245`, 0.9360984229439153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 238}], {
             RGBColor[
             0.22624718755874168`, 0.35513051739741625`, 0.9361958146775262]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 252}], {
             RGBColor[
             0.22380219645594157`, 0.3525606767269839, 0.936056576051262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 277}], {
             RGBColor[
             0.24054204876353127`, 0.3701553228701986, 0.9370098858757869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 293}], {
             RGBColor[
             0.21725116581640602`, 0.3456751281654994, 0.9356835045477219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 330}], {
             RGBColor[
             0.22402160898279397`, 0.3527912932042634, 0.9360690712700745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 179}], {
             RGBColor[
             0.2738145581196516, 0.4051268398024189, 0.9389047060613515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 196}], {
             RGBColor[
             0.2879550374250095, 0.4199893801105207, 0.9397099854388271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 303}], {
             RGBColor[
             0.28379884955745593`, 0.41562096314419106`, 0.9394732966882988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 313}], {
             RGBColor[
             0.2803971559769777, 0.4120455675112783, 0.9392795752712453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 344}], {
             RGBColor[
             0.2993073040655987, 0.4308227000023955, 0.9403967065336283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 149}], {
             RGBColor[
             0.21613019133913786`, 0.3444969129160037, 0.9356196667095744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 199}], {
             RGBColor[
             0.21892225618889471`, 0.3474315501002342, 0.9357786706722784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 212}], {
             RGBColor[
             0.21146946129668887`, 0.3395981901340374, 0.9353542450285892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 238}], {
             RGBColor[
             0.2206324276302094, 0.349229048716188, 0.9358760624058893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 259}], {
             RGBColor[
             0.2115312190038542, 0.33966310139993294`, 0.93535776203865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 274}], {
             RGBColor[
             0.22138486041548355`, 0.35001990328050514`, 0.9359189123398861]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 299}], {
             RGBColor[
             0.21308522513571704`, 0.34129646037420036`, 0.9354462603889135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 318}], {
             RGBColor[
             0.2179296081019373, 0.3463882140233181, 0.9357221408322174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 336}], {
             RGBColor[
             0.21152415432057162`, 0.33965567596987617`, 0.9353573597153882]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 367}], {
             RGBColor[
             0.21567822148491766`, 0.34402186394267437`, 0.935593927695006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 139}], {
             RGBColor[
             0.2108331954164144, 0.3389294343522821, 0.9353180106279786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 184}], {
             RGBColor[
             0.21412931839643223`, 0.34239386859054827`, 0.9355057199555137]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 305}], {
             RGBColor[
             0.20669916269368893`, 0.33458430384788407`, 0.9350825835801727]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 325}], {
             RGBColor[
             0.21103171786447747`, 0.3391380940322466, 0.9353293161877081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 177}], {
             RGBColor[
             0.32406082685861914`, 0.45510693327935664`, 0.9418698472250615]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 225}], {
             RGBColor[
             0.2916606290262991, 0.42226923419395845`, 0.939980144908767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 296}], {
             RGBColor[
             0.3138673468643941, 0.4456099026290287, 0.9412447846377514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 311}], {
             RGBColor[
             0.4227935959175786, 0.5388307190597109, 0.9486565824461703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 316}], {
             RGBColor[
             0.29024632988181515`, 0.4207827161213608, 0.9398996026647567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 324}], {
             RGBColor[
             0.3030854036809988, 0.43427739672859866`, 0.9406307689239126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 380}], {
             RGBColor[
             0.2958519089446212, 0.4266745351306104, 0.9402188320996724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 383}], {
             RGBColor[
             0.30322473955246876`, 0.43442384756391816`, 0.9406387038956638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 390}], {
             RGBColor[
             0.29625621364741994`, 0.42709948500765055`, 0.9402418566543815]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 178}], {
             RGBColor[
             0.24083645723076108`, 0.3704647648358321, 0.9370266520024574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 229}], {
             RGBColor[
             0.24229031603850887`, 0.3719928626227475, 0.9371094471107673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 249}], {
             RGBColor[
             0.25362687609654, 0.3839083060231606, 0.9377550474351345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 270}], {
             RGBColor[
             0.24363580909960866`, 0.3734070611391507, 0.9371860709501183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 308}], {
             RGBColor[
             0.2493864248848615, 0.3794513229395511, 0.9375135600118147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 309}], {
             RGBColor[
             0.25423745991444247`, 0.38455006832902616`, 0.9377898192802863]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 397}], {
             RGBColor[
             0.24351700983454236`, 0.3732821955792575, 0.9371793055077206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 135}], {
             RGBColor[
             0.4568418198608912, 0.568758623177035, 0.9507053486499384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 147}], {
             RGBColor[
             0.34757171171070933`, 0.4732511609805692, 0.9434492148065551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 158}], {
             RGBColor[
             0.4567607455909806, 0.5686928034323673, 0.9506989661864262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 172}], {
             RGBColor[
             0.3559151258566954, 0.4820206182510111, 0.9439243598991939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 181}], {
             RGBColor[
             0.48885894126290724`, 0.5947515646860737, 0.9532258537292853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 265}], {
             RGBColor[
             0.5011501438603255, 0.6047301166670249, 0.9541934622219126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 322}], {
             RGBColor[
             0.45941085843753277`, 0.5708442844274215, 0.95090759277739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 328}], {
             RGBColor[
             0.3599213877466876, 0.48616754871640405`, 0.9441548504546003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 347}], {
             RGBColor[
             0.34522783768479254`, 0.47078760076913406`, 0.9433157346482299]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 362}], {
             RGBColor[
             0.40753230852825906`, 0.5274057353029433, 0.9471885762261179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 364}], {
             RGBColor[
             0.379967678176128, 0.5035306379305324, 0.9454321823545258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 387}], {
             RGBColor[
             0.35198717062244894`, 0.47789208825307206`, 0.9437006686594926]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 215}], {
             RGBColor[
             0.8708771882594211, 0.43978719004972067`, 0.21128818862239418`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 217}], {
             RGBColor[
             0.8726459244985081, 0.4533824718485052, 0.21298193244244573`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 262}], {
             RGBColor[
             0.9305545199558635, 0.8420358975584873, 0.6226092420681639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 269}], {
             RGBColor[
             0.9577625542405059, 0.8589366723660075, 0.3711790558606476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 279}], {
             RGBColor[
             0.934057909721427, 0.776268616484077, 0.26579965018330676`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 297}], {
             RGBColor[
             0.9345525999537521, 0.8450176590746574, 0.6158415354980056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 300}], {
             RGBColor[
             0.9062314787117222, 0.661847076989811, 0.24319781291959908`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 306}], {
             RGBColor[
             0.9464211476308863, 0.8210225463454206, 0.2979449525140816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 307}], {
             RGBColor[
             0.9538530771213425, 0.8592378166634234, 0.5753740091193393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 314}], {
             RGBColor[
             0.9241390802378358, 0.8369963141242439, 0.6246293196235244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 352}], {
             RGBColor[
             0.9583101575279735, 0.8601079404267151, 0.43078229428572945`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 363}], {
             RGBColor[
             0.8924893365860593, 0.5994472191560132, 0.23173103267921852`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 140}], {
             RGBColor[
             0.7355736784173503, 0.7933550152374292, 0.9742787680039452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 191}], {
             RGBColor[
             0.7390378619070974, 0.7960612617083893, 0.9746240454395679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 198}], {
             RGBColor[
             0.8128559952710535, 0.8537811311091374, 0.9819675933041132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 216}], {
             RGBColor[
             0.7291619678468395, 0.7883461382089411, 0.9736397086151186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 219}], {
             RGBColor[
             0.6232051027562657, 0.7024156086050097, 0.9651690328906872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 220}], {
             RGBColor[
             0.6373284381573086, 0.7140480166379533, 0.9662348834814941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 302}], {
             RGBColor[
             0.8932496977556434, 0.905911220002762, 0.6928483915783341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 323}], {
             RGBColor[
             0.8147163030891271, 0.8552644900665589, 0.9821450311245175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 357}], {
             RGBColor[
             0.7374562321167385, 0.7948256804953293, 0.9744664033632358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 145}], {
             RGBColor[
             0.26764114093786784`, 0.3986381869271076, 0.9385531390856012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 164}], {
             RGBColor[
             0.2698983654154672, 0.40101067296936244`, 0.9386816846803361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 223}], {
             RGBColor[
             0.3756627076897743, 0.49871942307299955`, 0.945202383630783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 234}], {
             RGBColor[
             0.31799880832538563`, 0.4487941940432452, 0.9415224703076799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 280}], {
             RGBColor[
             0.26813571605602704`, 0.3991580167341666, 0.938581304406922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 346}], {
             RGBColor[
             0.32114511749891506`, 0.4515193689112592, 0.9417229503460453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 167}], {
             RGBColor[
             0.25893816716997997`, 0.3894908096966502, 0.9380575176044159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 201}], {
             RGBColor[
             0.255376576823433, 0.3857473524245587, 0.9378546903030808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 236}], {
             RGBColor[
             0.24242453355158805`, 0.3721339337388756, 0.9371170905995801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 243}], {
             RGBColor[
             0.2613494095308073, 0.3920251782994754, 0.9381948342897516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 263}], {
             RGBColor[
             0.24820523859568883`, 0.3782098212580943, 0.9374462932000549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 348}], {
             RGBColor[
             0.24864104476606846`, 0.3786678811748705, 0.9374711117167406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 351}], {
             RGBColor[
             0.24003567899790235`, 0.3696230961408251, 0.9369810488667414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 221}], {
             RGBColor[
             0.7125684826637311, 0.7740760557086418, 0.9732239792621271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 276}], {
             RGBColor[
             0.6344220971523353, 0.7122040883931675, 0.9656535874330512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 322}], {
             RGBColor[
             0.5058470879872912, 0.6097084800365293, 0.954241282226749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 364}], {
             RGBColor[
             0.42640390772588643`, 0.5423948335396401, 0.9487658718038847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 376}], {
             RGBColor[
             0.47083567399736015`, 0.5808793962784845, 0.9515970246612349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 377}], {
             RGBColor[
             0.4590787183907463, 0.5706961122538062, 0.9508478818462491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 194}], {
             RGBColor[
             0.5033185862068833, 0.6058836865205527, 0.954531849750919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 237}], {
             RGBColor[
             0.59850057250929, 0.6849287527633994, 0.9615353039292178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 246}], {
             RGBColor[
             0.5311924849620417, 0.6300266566393842, 0.9563079499316767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 254}], {
             RGBColor[
             0.5440467518592814, 0.6407206880430576, 0.9572484996967315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 286}], {
             RGBColor[
             0.6724159966518739, 0.7436515226508849, 0.9682328276448666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 320}], {
             RGBColor[
             0.6642380668783059, 0.7372628617572051, 0.9674177280321361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 343}], {
             RGBColor[
             0.6703913429941837, 0.7420698478255596, 0.9680310290897323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 349}], {
             RGBColor[
             0.5319806271096528, 0.6307093057544687, 0.9563581696523957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 376}], {
             RGBColor[
             0.5284877060748537, 0.6276839131134415, 0.9561356038127271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 199}], {
             RGBColor[
             0.22367942926895015`, 0.3524316406295666, 0.9360495846415806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 238}], {
             RGBColor[
             0.22538960071026484`, 0.3542291392455204, 0.9361469763751915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 252}], {
             RGBColor[
             0.22294460960746476`, 0.35165929857508804`, 0.9360077377489273]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 277}], {
             RGBColor[
             0.23968446191505444`, 0.36925394471830275`, 0.9369610475734522]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 285}], {
             RGBColor[
             0.23013560035880143`, 0.35921748578989005`, 0.9364172540340985]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 293}], {
             RGBColor[
             0.2163935789679292, 0.34477375001360355`, 0.9356346662453872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 330}], {
             RGBColor[
             0.22316402213431713`, 0.35188991505236755`, 0.9360202329677398]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 144}], {
             RGBColor[
             0.8488904911809813, 0.34529052811745564`, 0.1932170904993126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 233}], {
             RGBColor[
             0.8184005545424529, 0.14244030215351539`, 0.165253697851294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 242}], {
             RGBColor[
             0.8688448581678534, 0.4318314305529642, 0.2096571104877158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 256}], {
             RGBColor[
             0.522325620948562, 0.25191357841785655`, 0.5511492082429574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 257}], {
             RGBColor[
             0.8209750230584517, 0.16222879530677942`, 0.1677190118096608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 317}], {
             RGBColor[
             0.9049849697863369, 0.5700377324760639, 0.4855767081666582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 366}], {
             RGBColor[
             0.8603116610551809, 0.39715139303420033`, 0.20274719460083632`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 381}], {
             RGBColor[
             0.9062449527279615, 0.5705587678025101, 0.4646955300926113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 382}], {
             RGBColor[
             0.8590618993454652, 0.3914765169996446, 0.2017043627957868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 184}], {
             RGBColor[
             0.21446679583023515`, 0.34274857877078024`, 0.9355249387961155]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 305}], {
             RGBColor[
             0.20703664012749182`, 0.3349390140281161, 0.9351018024207747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 325}], {
             RGBColor[
             0.21136919529828035`, 0.33949280421247857`, 0.9353485350283102]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 141}], {
             RGBColor[
             0.5159944713875729, 0.6149616035084853, 0.9560493981699523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 168}], {
             RGBColor[
             0.6710377427034506, 0.7429390517664531, 0.9678464290545918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 191}], {
             RGBColor[
             0.6753891788981803, 0.7463384267939157, 0.9682801395479993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 216}], {
             RGBColor[
             0.6655132848379224, 0.7386233032944675, 0.96729580272355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 219}], {
             RGBColor[
             0.5595564197473485, 0.6526927736905361, 0.9588251269991186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 220}], {
             RGBColor[
             0.5736797551483913, 0.6643251817234797, 0.9598909775899255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 350}], {
             RGBColor[
             0.5523338730537959, 0.6464369667603329, 0.9583649127104528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 357}], {
             RGBColor[
             0.6738075491078213, 0.7451028455808557, 0.9681224974716671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 150}], {
             RGBColor[
             0.3153323622893313, 0.4440199894984804, 0.9414428101102743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 189}], {
             RGBColor[
             0.33030534537683665`, 0.4597575440654077, 0.9422954993465642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 219}], {
             RGBColor[
             0.4036258957264883, 0.5240221968760659, 0.9469396630566943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 220}], {
             RGBColor[
             0.4177492311275311, 0.5356546049090093, 0.9480055136475012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 273}], {
             RGBColor[
             0.31775067217972763`, 0.44656178652298995`, 0.9415805292809634]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 339}], {
             RGBColor[
             0.36291222472736206`, 0.48875806138522676`, 0.9443454239423157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 350}], {
             RGBColor[
             0.3964033490329356, 0.5177663899458625, 0.9464794487680284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 357}], {
             RGBColor[
             0.5178770250869611, 0.6164322687663853, 0.9562370335292427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 394}], {
             RGBColor[
             0.3594659493572627, 0.4857730708744833, 0.9441258303231546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 202}], {
             RGBColor[
             0.8389617996732674, 0.300483042224024, 0.18494316940916705`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 214}], {
             RGBColor[
             0.9026785336009098, 0.577164017789306, 0.5403271212608096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 217}], {
             RGBColor[
             0.8222048215005642, 0.17168156503396934`, 0.16889666818668636`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 257}], {
             RGBColor[
             0.822095571600614, 0.17084182242934073`, 0.16879205035911396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 268}], {
             RGBColor[
             0.8194514867475214, 0.1505182276031009, 0.16626007171772583`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 275}], {
             RGBColor[
             0.906842307128124, 0.5789554407018784, 0.47443924955803846`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 279}], {
             RGBColor[
             0.8836168067234831, 0.49456770966954106`, 0.2217143859275474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 300}], {
             RGBColor[
             0.8557903757137784, 0.38014617017527513`, 0.1991125486638397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 306}], {
             RGBColor[
             0.8959800446329425, 0.5393216395308846, 0.25385968825832217`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 338}], {
             RGBColor[
             0.9079361737525008, 0.5785505948422507, 0.3940025431841314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 363}], {
             RGBColor[
             0.8420482335881154, 0.3177463123414773, 0.18764576842345915`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 381}], {
             RGBColor[
             0.9073655012701238, 0.5791717949250715, 0.46576856864206445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 223}], {
             RGBColor[
             0.5393557196395969, 0.6369122967585245, 0.9568792044565808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 234}], {
             RGBColor[
             0.4816918202752083, 0.5869870677287701, 0.9531992911334777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 260}], {
             RGBColor[
             0.7167991404658595, 0.7784168360748085, 0.9725930329082488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 267}], {
             RGBColor[
             0.5979215961089128, 0.6844587136389835, 0.9614897247861196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 272}], {
             RGBColor[
             0.635830587523557, 0.7151635871324875, 0.9645228442451073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 290}], {
             RGBColor[
             0.5148889820990041, 0.6157407807626738, 0.9553145849297924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 291}], {
             RGBColor[
             0.6605679134983766, 0.7344885741946573, 0.9669884297148228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 321}], {
             RGBColor[
             0.7212153553030598, 0.7818668166701053, 0.973033199931347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 331}], {
             RGBColor[
             0.5383683584932644, 0.6360774364876114, 0.9568106700316372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 342}], {
             RGBColor[
             0.6140012232637606, 0.6975128793422373, 0.9627555719373643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 398}], {
             RGBColor[
             0.7820348247548993, 0.8302487551810782, 0.97550730112162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 207}], {
             RGBColor[
             0.9091469621070289, 0.6700765235430096, 0.2453714490760957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 233}], {
             RGBColor[
             0.8479481693127158, 0.33804742930989184`, 0.1923147220140613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 242}], {
             RGBColor[
             0.8983924729381163, 0.6274385577093406, 0.23671813465048305`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 317}], {
             RGBColor[
             0.9345325845565998, 0.7656448596324403, 0.5126377323294256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 358}], {
             RGBColor[
             0.9235073892649484, 0.7232807673563957, 0.2763524253689754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 366}], {
             RGBColor[
             0.8898592758254438, 0.5927585201905767, 0.22980821876360358`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 370}], {
             RGBColor[
             0.8548273648949809, 0.7045756223106869, 0.6020207461756493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 391}], {
             RGBColor[
             0.8494144480971886, 0.3493178905748092, 0.19371883223399736`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 162}], {
             RGBColor[
             0.2420540274215789, 0.3717445083047905, 0.9370959908235907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 164}], {
             RGBColor[
             0.2402812832877892, 0.36988124182170756`, 0.9369950356677115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 227}], {
             RGBColor[
             0.23647303514531387`, 0.36587853156708794`, 0.9367781615697957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 280}], {
             RGBColor[
             0.23851863392834902`, 0.36802858558651175`, 0.9368946553942974]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 359}], {
             RGBColor[
             0.24179608967805666`, 0.37147339938215107`, 0.9370813016506819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 154}], {
             RGBColor[
             0.48274463326921224`, 0.5903240190384458, 0.9525963248033308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 159}], {
             RGBColor[
             0.433382915877228, 0.5475693804255631, 0.9494510398199664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 165}], {
             RGBColor[
             0.5340400056803238, 0.6325967606962016, 0.956460731981605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 192}], {
             RGBColor[
             0.43991049068666355`, 0.5532232376400468, 0.9498669711147159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 228}], {
             RGBColor[
             0.45159420731101624`, 0.5633430857393887, 0.9506114472065146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 262}], {
             RGBColor[
             0.736987048840004, 0.7937027834714817, 0.9726540973253948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 297}], {
             RGBColor[
             0.7409851288378926, 0.7966845449876518, 0.9658863907552364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 307}], {
             RGBColor[
             0.760285606005483, 0.8109047025764178, 0.9254188643765703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 314}], {
             RGBColor[
             0.7305716091219763, 0.7886632000372383, 0.9746741748807553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 332}], {
             RGBColor[
             0.53127642233297, 0.6303531592368088, 0.9562431725771618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 385}], {
             RGBColor[
             0.5553761412741389, 0.6499183967532158, 0.95814039073239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 172}], {
             RGBColor[
             0.29308124725627194`, 0.4253773516636531, 0.9400019155051696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 211}], {
             RGBColor[
             0.2737075152920192, 0.40501433100367, 0.9388986101306735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 328}], {
             RGBColor[
             0.29708750914626414`, 0.42952428212904603`, 0.9402324060605761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 347}], {
             RGBColor[
             0.28239395908436904`, 0.4141443341817761, 0.9393932902542057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 364}], {
             RGBColor[
             0.31713379957570453`, 0.44688737134317436`, 0.9415097379605015]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 372}], {
             RGBColor[
             0.2681076692483716, 0.3991285377610505, 0.9385797071827175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 387}], {
             RGBColor[
             0.28915329202202544`, 0.42124882166571403`, 0.9397782242654684]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 161}], {
             RGBColor[
             0.5276623353729026, 0.6268249505740837, 0.9561228183174523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 168}], {
             RGBColor[
             0.6470192572483401, 0.7238926765948177, 0.9656459465719469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 170}], {
             RGBColor[
             0.5344288299346016, 0.632685748069522, 0.9565539733675475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 251}], {
             RGBColor[
             0.723101933884062, 0.7833478892534567, 0.9732241552199159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.6353748988917614, 0.714796015346257, 0.9644853457536787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 312}], {
             RGBColor[
             0.5434225996528742, 0.6402139731641597, 0.9571993641486982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 326}], {
             RGBColor[
             0.4816391300864997, 0.5869619633485583, 0.9531902603733251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 356}], {
             RGBColor[
             0.5711332147381206, 0.6627106988393463, 0.9593808452755366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 199}], {
             RGBColor[
             0.2230106997449548, 0.3517287634999468, 0.9360115014844858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 212}], {
             RGBColor[
             0.21555790485274898`, 0.34389540353375003`, 0.9355870758407967]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 238}], {
             RGBColor[
             0.2247208711862695, 0.3535262621159006, 0.9361088932180968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 259}], {
             RGBColor[
             0.21561966255991427`, 0.3439603147996455, 0.9355905928508573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 274}], {
             RGBColor[
             0.22547330397154366`, 0.35431711668021776`, 0.9361517431520935]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 287}], {
             RGBColor[
             0.24021601426247097`, 0.36981263993780294`, 0.9369913186932763]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 299}], {
             RGBColor[
             0.21717366869177715`, 0.345593673773913, 0.9356790912011209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 318}], {
             RGBColor[
             0.22201805165799737`, 0.3506854274230307, 0.9359549716444248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 336}], {
             RGBColor[
             0.21561259787663173`, 0.3439528893695888, 0.9355901905275956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 367}], {
             RGBColor[
             0.21976666504097775`, 0.348319077342387, 0.9358267585072135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 186}], {
             RGBColor[
             0.2595342246109202, 0.3901173038593028, 0.9380914621938894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 189}], {
             RGBColor[
             0.28557376029945525`, 0.4174865068698732, 0.9395743752293106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 226}], {
             RGBColor[
             0.2546174021107136, 0.38494941166703367`, 0.9378114564262897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 241}], {
             RGBColor[
             0.2807813627744614, 0.41244939321555174`, 0.939301455279979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 255}], {
             RGBColor[
             0.26553787758684655`, 0.39642752379058566`, 0.9384333613492598]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 266}], {
             RGBColor[
             0.2627993543398047, 0.39354916222554226`, 0.9382774065016228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 365}], {
             RGBColor[
             0.26342074735738313`, 0.39420228568561005`, 0.9383127939147053]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 374}], {
             RGBColor[
             0.2733522518909328, 0.4046409266441276, 0.9388783784055468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 399}], {
             RGBColor[
             0.2527398969113101, 0.3829760346617555, 0.9377045352827038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 171}], {
             RGBColor[
             0.294524052203641, 0.4262383567855898, 0.940108081239609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 182}], {
             RGBColor[
             0.301964914813191, 0.43405917516616493`, 0.9405318273574531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 244}], {
             RGBColor[
             0.28793584651295273`, 0.41931373488830953`, 0.9397328926719012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 249}], {
             RGBColor[
             0.2927023996318287, 0.42432368443317114`, 0.9400043408205379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 253}], {
             RGBColor[
             0.3287756481732377, 0.4591906745282696, 0.9421702714700763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 270}], {
             RGBColor[
             0.28271133263489734`, 0.4138224395491612, 0.9394353643355215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 308}], {
             RGBColor[
             0.28846194842015016`, 0.41986670134956156`, 0.9397628533972181]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 386}], {
             RGBColor[
             0.3275993292124569, 0.45817180616795133`, 0.9420953174660733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 397}], {
             RGBColor[
             0.28259253336983103`, 0.413697573989268, 0.9394285988931239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 156}], {
             RGBColor[
             0.18478785261667285`, 0.31155412769964164`, 0.9338347668861651]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 175}], {
             RGBColor[
             0.181274153781999, 0.307861007443026, 0.9336346669355821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 242}], {
             RGBColor[
             0.5509815030039178, 0.5121510355041116, 0.5934630978551525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 256}], {
             RGBColor[
             0.2044622657846265, 0.33223318336900387`, 0.9349551956103941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 261}], {
             RGBColor[
             0.18153226782756765`, 0.3081323016702944, 0.9336493661486316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 264}], {
             RGBColor[
             0.186823590274237, 0.31369381705096394`, 0.9339506991341594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 317}], {
             RGBColor[
             0.5871216146224013, 0.6503573374272111, 0.8693826955340949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 333}], {
             RGBColor[
             0.18958831081692415`, 0.31659971363473505`, 0.9341081458790279]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 381}], {
             RGBColor[
             0.588381597564026, 0.6508783727536576, 0.8485015174600479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 154}], {
             RGBColor[
             0.3737943950019111, 0.49818365032325973`, 0.9450388262094847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 188}], {
             RGBColor[
             0.2922583395910017, 0.4237094580639409, 0.939984452630228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 195}], {
             RGBColor[
             0.2815627334149148, 0.41246769783227444`, 0.9393753536812313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 203}], {
             RGBColor[
             0.3044141682214503, 0.43648600467859244`, 0.9406767090877951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 258}], {
             RGBColor[
             0.28518201112076286`, 0.41627178817658117`, 0.9395814661923377]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 278}], {
             RGBColor[
             0.284923192180341, 0.41599975306012926`, 0.939566726836569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 284}], {
             RGBColor[
             0.2807144253547577, 0.4115760722752118, 0.9393270437921646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 312}], {
             RGBColor[
             0.39019396776607296`, 0.5121264097897626, 0.9461561082120249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 327}], {
             RGBColor[
             0.31801144721476193`, 0.44986726468250904`, 0.9414843861034113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 337}], {
             RGBColor[
             0.30108704647180895`, 0.43298898876801645`, 0.9404872344261885]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[
             0.4179045828513193, 0.5346231354649491, 0.9483375893388631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 361}], {
             RGBColor[
             0.3365286408445437, 0.46590592710341294`, 0.9426642853073897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 369}], {
             RGBColor[
             0.28744235484774583`, 0.41864755274771004`, 0.9397101894237105]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 392}], {
             RGBColor[
             0.28268998646480836`, 0.4136525122596839, 0.9394395490748012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 192}], {
             RGBColor[
             0.3873238866966642, 0.5099022160172301, 0.9459009134566145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[
             0.36077780249875213`, 0.4853053517709617, 0.9442681500235399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 222}], {
             RGBColor[
             0.5175424648922109, 0.6185744663744461, 0.9553357375773506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 228}], {
             RGBColor[
             0.39900760332101687`, 0.520022064116572, 0.9466453895484133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 312}], {
             RGBColor[
             0.4465576020433747, 0.5609457568821319, 0.9497475491477698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 332}], {
             RGBColor[
             0.47868981834297064`, 0.5870321376139921, 0.9522771149190605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 356}], {
             RGBColor[
             0.4742682171286211, 0.5834424825573183, 0.951929030274608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 361}], {
             RGBColor[
             0.39289227512184555`, 0.5147252741957822, 0.9462557262431346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 385}], {
             RGBColor[
             0.5027895372841396, 0.606597375130399, 0.9541743330742887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 170}], {
             RGBColor[
             0.3747576276064379, 0.498629600146848, 0.9451144220759548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 180}], {
             RGBColor[
             0.33540782096983857`, 0.46454677541701367`, 0.9426070871927383]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 183}], {
             RGBColor[
             0.2817396246657633, 0.4134565872206231, 0.9393560268770672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 239}], {
             RGBColor[
             0.3145302695292589, 0.4464636896954298, 0.9412767880762385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 271}], {
             RGBColor[
             0.305666751429035, 0.4386055145162801, 0.9407186413492236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 326}], {
             RGBColor[
             0.32196792775833594`, 0.4529058154258842, 0.9417507090817323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 335}], {
             RGBColor[
             0.29253189959404885`, 0.42479995244000324`, 0.9399706309684931]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 337}], {
             RGBColor[
             0.29464447603044647`, 0.42702040421973947`, 0.9400909390712692]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 354}], {
             RGBColor[
             0.29215952785429067`, 0.42440856613178546`, 0.9399494249487885]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 175}], {
             RGBColor[
             0.18244584031582461`, 0.30909252427929373`, 0.9337013927503286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 202}], {
             RGBColor[
             0.5211495825009953, 0.37342113688887774`, 0.567742844041897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 214}], {
             RGBColor[
             0.5848663164286375, 0.6501021124541597, 0.9231267958935396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 256}], {
             RGBColor[
             0.20563395231845213`, 0.3334647002052716, 0.9350219214251405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 261}], {
             RGBColor[
             0.18270395436139325`, 0.3093638185065621, 0.9337160919633781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 264}], {
             RGBColor[
             0.1879952768080626, 0.31492533388723165`, 0.9340174249489059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 295}], {
             RGBColor[
             0.2141734445733891, 0.3424402480002911, 0.9355082328760125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 310}], {
             RGBColor[
             0.1842688448604277, 0.3110086176408356, 0.93380521016225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 363}], {
             RGBColor[
             0.5242360164158433, 0.390684407006331, 0.5704454430561892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 381}], {
             RGBColor[
             0.5895532840978516, 0.6521098895899253, 0.8485682432747944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 187}], {
             RGBColor[
             0.656588840938115, 0.7291931341002164, 0.9681680488654731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 218}], {
             RGBColor[
             0.689653807893005, 0.7555582412254274, 0.971321814931075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 253}], {
             RGBColor[
             0.40547981020843754`, 0.5251955404755204, 0.9471772728723662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 298}], {
             RGBColor[
             0.6463369873520685, 0.7210185843298552, 0.9671902179184984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.5352140965427551, 0.633549940550514, 0.9565531607151321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 265}], {
             RGBColor[
             0.5475052991401734, 0.643528492531465, 0.9575207692077594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 311}], {
             RGBColor[
             0.5112449698673547, 0.6140907237185725, 0.9546662232614405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 322}], {
             RGBColor[
             0.5057660137173806, 0.6096426602918618, 0.9542348997632368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 362}], {
             RGBColor[
             0.4538874638081069, 0.5662041111673836, 0.9505158832119648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 165}], {
             RGBColor[
             0.43209168429834016`, 0.5465211004605023, 0.9493493893401392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 167}], {
             RGBColor[
             0.30749203096032607`, 0.43842628345076595`, 0.9408993959616536]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 192}], {
             RGBColor[
             0.3379621693046799, 0.46714757740434754`, 0.9427556284732501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 201}], {
             RGBColor[
             0.30393044061377905`, 0.43468282617867443`, 0.9406965686603185]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 210}], {
             RGBColor[
             0.3156791522092831, 0.44703146697688845`, 0.9413656404050212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 228}], {
             RGBColor[
             0.3496458859290326, 0.47726742550368945`, 0.9435001045650488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 236}], {
             RGBColor[
             0.2909783973419341, 0.4210694074929913, 0.9399589689568179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 243}], {
             RGBColor[
             0.3099032733211534, 0.44096065205359114`, 0.9410367126469893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 263}], {
             RGBColor[
             0.29675910238603487`, 0.4271452950122101, 0.9402881715572926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 166}], {
             RGBColor[
             0.8271233428626157, 0.2094874755325008, 0.1736066497976622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 185}], {
             RGBColor[
             0.8265840327508944, 0.20534210168661424`, 0.17309020582561438`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 213}], {
             RGBColor[
             0.8702228477750129, 0.45615422864304855`, 0.21154106500959308`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 224}], {
             RGBColor[
             0.9025695450570996, 0.5785729407895561, 0.26790552836760506`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 247}], {
             RGBColor[
             0.8682425607038025, 0.44830305029724704`, 0.2099476795487854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 289}], {
             RGBColor[
             0.863615444991354, 0.42809333252077686`, 0.20612813226240806`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 302}], {
             RGBColor[
             0.9083773079386029, 0.59816388871644, 0.2904675904582531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 340}], {
             RGBColor[
             0.9116278550257833, 0.6083417789954149, 0.37001345675471364`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 370}], {
             RGBColor[
             0.8303471028154521, 0.5479183884634005, 0.5798122246722852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 400}], {
             RGBColor[
             0.6095442446912597, 0.3697331530727862, 0.5609538560304888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 170}], {
             RGBColor[
             0.43820314080929235`, 0.5539712686639211, 0.9491428945379133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 222}], {
             RGBColor[
             0.5181817733764011, 0.6191282032508729, 0.9553764737486448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 239}], {
             RGBColor[
             0.3779757827321134, 0.5018053582125028, 0.9453052605381971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 251}], {
             RGBColor[
             0.6268762447587527, 0.7046334098478555, 0.9658130763902817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 312}], {
             RGBColor[
             0.44719691052756494`, 0.5614994937585587, 0.949788285319064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 326}], {
             RGBColor[
             0.3854134409611904, 0.5082474839429573, 0.9457791815436909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 327}], {
             RGBColor[
             0.3750143899762539, 0.4992403486513052, 0.9451165632104506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 337}], {
             RGBColor[
             0.35808998923330093`, 0.48236207273681253`, 0.9441194115332278]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.47490752561281135`, 0.5839962194337451, 0.9519697664459024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 179}], {
             RGBColor[
             0.25786357675267113`, 0.38836134703509095`, 0.9379963212698641]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 231}], {
             RGBColor[
             0.27738405997012383`, 0.4088786125667542, 0.9391079839111312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 313}], {
             RGBColor[
             0.26444617460999714`, 0.3952800747439503, 0.938371190479758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 359}], {
             RGBColor[
             0.24582605828944576`, 0.3757091519074889, 0.9373108024012962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 164}], {
             RGBColor[
             0.24375587866941067`, 0.373533261869863, 0.9371929087344915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 169}], {
             RGBColor[
             0.23283585906700827`, 0.36205562889850595`, 0.936571029772856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 209}], {
             RGBColor[
             0.2485031193706023, 0.3785229128392603, 0.9374632570695112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 227}], {
             RGBColor[
             0.23994763052693538`, 0.3695305516152434, 0.9369760346365759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 240}], {
             RGBColor[
             0.2420898799764604, 0.3717821916131542, 0.9370980325735522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 245}], {
             RGBColor[
             0.2374360489235272, 0.36689072010659024`, 0.9368330037798137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 280}], {
             RGBColor[
             0.24199322930997053`, 0.37168060563466715`, 0.9370925284610774]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 304}], {
             RGBColor[
             0.23203584179739814`, 0.3612147600241211, 0.9365254699728711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 315}], {
             RGBColor[
             0.24412373790812583`, 0.3739199052533755, 0.9372138577739373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 319}], {
             RGBColor[
             0.2432784612852803, 0.3730314659291315, 0.9371657205207411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 329}], {
             RGBColor[
             0.2400560374603316, 0.3696444941756393, 0.936982208251059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 371}], {
             RGBColor[
             0.25850942763125473`, 0.3890401772577931, 0.9380331015219487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 169}], {
             RGBColor[
             0.23161848816298614`, 0.3607760948926053, 0.9365017023008109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 209}], {
             RGBColor[
             0.24728574846658016`, 0.37724337883335973`, 0.9373939295974659]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 227}], {
             RGBColor[
             0.23873025962291325`, 0.36825101760934276`, 0.9369067071645306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 245}], {
             RGBColor[
             0.23621867801950508`, 0.36561118610068966`, 0.9367636763077685]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 280}], {
             RGBColor[
             0.2407758584059484, 0.37040107162876656`, 0.9370232009890322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 304}], {
             RGBColor[
             0.230818470893376, 0.3599352260182205, 0.936456142500826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 315}], {
             RGBColor[
             0.2429063670041037, 0.37264037124747484`, 0.9371445303018922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 228}], {
             RGBColor[
             0.4503029757321284, 0.5622948057743279, 0.9505097967266875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 262}], {
             RGBColor[
             0.7356958172611161, 0.7926545035064209, 0.9725524468455675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 298}], {
             RGBColor[
             0.6780894534855002, 0.7467966667692734, 0.969689888365638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 307}], {
             RGBColor[
             0.7589943744265952, 0.8098564226113569, 0.9253172138967432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 314}], {
             RGBColor[
             0.7292803775430885, 0.7876149200721775, 0.9745725244009281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 332}], {
             RGBColor[
             0.5299851907540822, 0.6293048792717479, 0.9561415220973347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 385}], {
             RGBColor[
             0.5540849096952511, 0.648870116788155, 0.9580387402525627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 185}], {
             RGBColor[
             0.8242297938213237, 0.1872463896398561, 0.17083578396792481`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 213}], {
             RGBColor[
             0.8678686088454421, 0.43805851659629047`, 0.20928664315190354`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 224}], {
             RGBColor[
             0.9002153061275288, 0.5604772287427979, 0.2656511065099155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 247}], {
             RGBColor[
             0.8658883217742317, 0.43020733825048896`, 0.20769325769109587`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 289}], {
             RGBColor[
             0.8612612060617832, 0.40999762047401866`, 0.2038737104047185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 302}], {
             RGBColor[
             0.9060230690090321, 0.580068176669682, 0.28821316860056356`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 340}], {
             RGBColor[
             0.9092736160962124, 0.5902460669486567, 0.36775903489702405`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 400}], {
             RGBColor[
             0.6071900057616888, 0.351637441026028, 0.5586994341727993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 192}], {
             RGBColor[
             0.3140196057697616, 0.4440801406652496, 0.941315327256403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[
             0.27998787707886075`, 0.41161538943957654`, 0.9392562674434715]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.2874735215718495, 0.4194832764189812, 0.9396825638233285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 228}], {
             RGBColor[
             0.32570332239411426`, 0.45419998876459156`, 0.9420598033482018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 243}], {
             RGBColor[
             0.28596070978623506`, 0.41789321531449325`, 0.9395964114301423]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 348}], {
             RGBColor[
             0.2732523450214962, 0.4045359181898883, 0.9388726888571313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 351}], {
             RGBColor[
             0.2646469792533301, 0.39549113315584294`, 0.938382626007132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 170}], {
             RGBColor[
             0.5575600626847299, 0.651038994684655, 0.958666022792408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 180}], {
             RGBColor[
             0.5182102560481305, 0.6169561699548207, 0.9561586879091916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 220}], {
             RGBColor[
             0.5727925024434088, 0.663632053166977, 0.9598025445321408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 251}], {
             RGBColor[
             0.7462331666341901, 0.8017011358685895, 0.9753362046447762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 282}], {
             RGBColor[
             0.6585061316418895, 0.73314926196139, 0.9665973951785392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 350}], {
             RGBColor[
             0.5514466203488134, 0.6457438382038303, 0.9582764796526682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 357}], {
             RGBColor[
             0.6729202964028389, 0.7444097170243531, 0.9680340644138824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 394}], {
             RGBColor[
             0.5145092206731405, 0.613750519132451, 0.9559228612077943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 209}], {
             RGBColor[
             0.23636572886417778`, 0.36576574586200267`, 0.9367720506358304]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 227}], {
             RGBColor[
             0.22781024002051087`, 0.3567733846379857, 0.936284828202895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 240}], {
             RGBColor[
             0.22995248947003588`, 0.35902502463589653`, 0.9364068261398715]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 245}], {
             RGBColor[
             0.22529865841710267`, 0.3541335531293326, 0.936141797346133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 280}], {
             RGBColor[
             0.229855838803546, 0.3589234386574095, 0.9364013220273968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 292}], {
             RGBColor[
             0.21585857380573317`, 0.34421142566684904`, 0.9356041984928691]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 304}], {
             RGBColor[
             0.21989845129097363`, 0.3484575930468634, 0.9358342635391905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 315}], {
             RGBColor[
             0.23198634740170132`, 0.3611627382761178, 0.9365226513402567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 329}], {
             RGBColor[
             0.22791864695390707`, 0.3568873271983817, 0.9362910018173783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 353}], {
             RGBColor[
             0.21553905850906607`, 0.343875594831612, 0.9355860025694045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 378}], {
             RGBColor[
             0.21461245212241514`, 0.34290167276900374`, 0.9355332337064761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 180}], {
             RGBColor[
             0.40561982873439206`, 0.5257492414295251, 0.9470667147047922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 239}], {
             RGBColor[
             0.38474227729381244`, 0.5076661557079413, 0.9457364155882924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 251}], {
             RGBColor[
             0.6336427393204518, 0.7104942073432939, 0.966244231440377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 271}], {
             RGBColor[
             0.37587875919358854`, 0.49980798052879155`, 0.9451782688612774]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 282}], {
             RGBColor[
             0.5459157043281511, 0.6419423334360943, 0.9575054219741398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 326}], {
             RGBColor[
             0.39217993552288943`, 0.5141082814383957, 0.9462103365937862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 182}], {
             RGBColor[
             0.2806534492526592, 0.41231494799395196`, 0.9392941707941435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 244}], {
             RGBColor[
             0.266624380952421, 0.39756950771609656`, 0.9384952361085915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 253}], {
             RGBColor[
             0.30746418261270597`, 0.43744644735605664`, 0.9409326149067666]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 270}], {
             RGBColor[
             0.2613998670743656, 0.3920782123769482, 0.9381977077722119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 308}], {
             RGBColor[
             0.26715048285961845`, 0.3981224741773486, 0.9385251968339084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 397}], {
             RGBColor[
             0.26128106780929927`, 0.39195334681705507`, 0.9381909423298143]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 211}], {
             RGBColor[
             0.2820509294380053, 0.413783788274112, 0.9393737552233123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 328}], {
             RGBColor[
             0.3054309232922502, 0.438293739399488, 0.9407075511532149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 347}], {
             RGBColor[
             0.29073737323035515`, 0.422913791452218, 0.9398684353468445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 364}], {
             RGBColor[
             0.3254772137216906, 0.45565682861361634`, 0.9419848830531403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 387}], {
             RGBColor[
             0.29749670616801155`, 0.43001827893615596`, 0.9402533693581072]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 175}], {
             RGBColor[
             0.20264987627198583`, 0.3303282470790865, 0.9348519827088393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 197}], {
             RGBColor[
             0.607559522477704, 0.6724367666110929, 0.8861420267905455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 204}], {
             RGBColor[
             0.20264730553141047`, 0.33032554506774736`, 0.9348518363089665]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 214}], {
             RGBColor[
             0.6050703523847987, 0.6713378352539525, 0.9242773858520503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 261}], {
             RGBColor[
             0.2029079903175545, 0.3305995413063548, 0.9348666819218888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 295}], {
             RGBColor[
             0.23437748052955032`, 0.36367597080008385`, 0.9366588228345232]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 310}], {
             RGBColor[
             0.20447288081658893`, 0.33224434044062834`, 0.9349558001207607]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 345}], {
             RGBColor[
             0.21415750276433887`, 0.34242349214821033`, 0.9355073250135709]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 193}], {
             RGBColor[
             0.7754724977883137, 0.8245433157037161, 0.9782504569369469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 232}], {
             RGBColor[
             0.6270810139261389, 0.7068104580353534, 0.9646885621008761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 235}], {
             RGBColor[
             0.7343495307888845, 0.7923987018062052, 0.9741567564086497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 260}], {
             RGBColor[
             0.7687797089830702, 0.819295818690549, 0.9775884348027377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 267}], {
             RGBColor[
             0.6499021646261236, 0.725337696254724, 0.9664851266806084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 272}], {
             RGBColor[
             0.6878111560407678, 0.756042569748228, 0.9695182461395961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 275}], {
             RGBColor[
             0.8603530123804088, 0.8894563784374243, 0.877080294609712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 281}], {
             RGBColor[
             0.6802997161269625, 0.7500157979571946, 0.9688781332846546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 291}], {
             RGBColor[
             0.7125484820155874, 0.7753675568103979, 0.9719838316093115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 338}], {
             RGBColor[
             0.8614468790047858, 0.8890515325777966, 0.796643588235805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 384}], {
             RGBColor[
             0.7385166114389616, 0.7956540568810313, 0.9745720920642666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 398}], {
             RGBColor[
             0.83401539327211, 0.8711277377968187, 0.9805027030161089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 204}], {
             RGBColor[
             0.17892957074057536`, 0.30539670201133906`, 0.9335011463998728]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 214}], {
             RGBColor[
             0.5813526175939636, 0.6464089921975442, 0.9229266959429565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 256}], {
             RGBColor[
             0.20212025348377827`, 0.329771579948656, 0.9348218214745575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 261}], {
             RGBColor[
             0.1791902555267194, 0.3056706982499465, 0.9335159920127951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 264}], {
             RGBColor[
             0.18448157797338877`, 0.31123221363061604`, 0.9338173249983228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 295}], {
             RGBColor[
             0.21065974573871524`, 0.33874712774367555`, 0.9353081329254295]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 310}], {
             RGBColor[
             0.18075514602575382`, 0.30731549738422004`, 0.933605110211667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 345}], {
             RGBColor[
             0.1904397679735038, 0.31749464909180203`, 0.9341566351044772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 186}], {
             RGBColor[
             0.23214557991116364`, 0.36133010173948693`, 0.9365317193961071]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 226}], {
             RGBColor[
             0.22722875741095702`, 0.3561622095472178, 0.9362517136285073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 294}], {
             RGBColor[
             0.21429151975408078`, 0.34256435250159695`, 0.9355149570828762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 341}], {
             RGBColor[
             0.21870360025711671`, 0.3472017288523488, 0.9357662185404361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 368}], {
             RGBColor[
             0.2143024966118115, 0.34257588987504495`, 0.9355155821986852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 379}], {
             RGBColor[
             0.2183904240990045, 0.34687256085365753`, 0.9357483836215341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 393}], {
             RGBColor[
             0.2193217433014607, 0.3478514363844869, 0.9358014208723507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 399}], {
             RGBColor[
             0.22535125221155355`, 0.3541888325419396, 0.9361447924849214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 200}], {
             RGBColor[
             0.2962840776702533, 0.42752676637236176`, 0.9402288709406241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 225}], {
             RGBColor[
             0.2895083029136421, 0.42040499749423077`, 0.9398430005920957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 296}], {
             RGBColor[
             0.3117150207517371, 0.4437456659293011, 0.9411076403210801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 311}], {
             RGBColor[
             0.42064126980492156`, 0.5369664823599833, 0.9485194381294991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 324}], {
             RGBColor[
             0.3009330775683418, 0.4324131600288711, 0.9404936246072413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 339}], {
             RGBColor[
             0.34383450141698674`, 0.4722338963280338, 0.9431298082827468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 360}], {
             RGBColor[
             0.31615011179738517`, 0.4482550694974156, 0.9413657834565303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 374}], {
             RGBColor[
             0.29900611365793894`, 0.43038779878246913`, 0.9403838868632315]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 375}], {
             RGBColor[
             0.28837692064883436`, 0.4192158430001391, 0.939778570045845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 383}], {
             RGBColor[
             0.3010724134398118, 0.43255961086419054`, 0.9405015595789926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 390}], {
             RGBColor[
             0.2941038875347629, 0.4252352483079229, 0.9401047123377103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 209}], {
             RGBColor[
             0.24801071646784933`, 0.37800536616831976`, 0.9374352154526442]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 229}], {
             RGBColor[
             0.24544230257567465`, 0.37530580032079786`, 0.9372889480811126]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 240}], {
             RGBColor[
             0.24159747707370743`, 0.3712646449422136, 0.9370699909566852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 245}], {
             RGBColor[
             0.23694364602077422`, 0.3663731734356497, 0.9368049621629467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 248}], {
             RGBColor[
             0.230098166399185, 0.35917814032488304`, 0.9364151222254768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 309}], {
             RGBColor[
             0.2573894464516083, 0.38786300602707646`, 0.9379693202506316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 315}], {
             RGBColor[
             0.24363133500537287`, 0.37340235858243487`, 0.9371858161570703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 319}], {
             RGBColor[
             0.24278605838252734`, 0.37251391925819094`, 0.9371376789038741]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 329}], {
             RGBColor[
             0.23956363455757862`, 0.36912694750469877`, 0.9369541666341921]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 334}], {
             RGBColor[
             0.25269374017822266`, 0.3829275210087747, 0.9377019067250372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 371}], {
             RGBColor[
             0.25801702472850174`, 0.38852263058685255`, 0.9380050599050818]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 388}], {
             RGBColor[
             0.23367677668762307`, 0.36293948663502873`, 0.9366189187873238]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 196}], {
             RGBColor[
             0.2837836367777321, 0.41560497354815545`, 0.9394724303429989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 231}], {
             RGBColor[
             0.28916364068982703`, 0.4212596987717169, 0.9397788136067902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 303}], {
             RGBColor[
             0.27962744891017854`, 0.4112365565818258, 0.9392357415924706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 313}], {
             RGBColor[
             0.2762257553297003, 0.407661160948913, 0.939042020175417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 344}], {
             RGBColor[
             0.29513590341832135`, 0.4264382934400302, 0.9401591514378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 359}], {
             RGBColor[
             0.2576056390091489, 0.3880902381124516, 0.9379816320969553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 239}], {
             RGBColor[
             0.3453924706572131, 0.47358333097810695`, 0.943229080705076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 271}], {
             RGBColor[
             0.3365289525569892, 0.46572515579895724`, 0.942670933978061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 282}], {
             RGBColor[
             0.5065658976915518, 0.60785950870626, 0.9549980870909234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 326}], {
             RGBColor[
             0.3528301288862901, 0.48002545670856134`, 0.9437030017105699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 350}], {
             RGBColor[
             0.3995063863984757, 0.5204540849487005, 0.9466771715650524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 394}], {
             RGBColor[
             0.36256898672280274`, 0.4884607658773212, 0.9443235531201786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 250}], {
             RGBColor[
             0.7777697545864616, 0.8245041838583995, 0.9019245302265969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 265}], {
             RGBColor[
             0.5796034948121, 0.6695872537851715, 0.9600476567506184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 322}], {
             RGBColor[
             0.5378642093893072, 0.6357014215455682, 0.9567617873060958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 362}], {
             RGBColor[
             0.4859856594800335, 0.59226287242109, 0.9530427707548238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 244}], {
             RGBColor[
             0.27406524356197104`, 0.4053903260966717, 0.9389189822264357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 253}], {
             RGBColor[
             0.31490504522225604`, 0.4452672657366318, 0.9413563610246107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 271}], {
             RGBColor[
             0.28286075625291396`, 0.4146349676025667, 0.9394198736623899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 273}], {
             RGBColor[
             0.26718551324119244`, 0.3981592933294373, 0.9385271917623162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 335}], {
             RGBColor[
             0.2697259044179279, 0.4008294055262898, 0.9386718632816594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 305}], {
             RGBColor[
             0.21033276310750965`, 0.33840344826638225`, 0.9352895117483098]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 325}], {
             RGBColor[
             0.2146653182782982, 0.3429572384507447, 0.9355362443558451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 213}], {
             RGBColor[
             0.8673292987337209, 0.4339131427504039, 0.20877019917985573`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 224}], {
             RGBColor[
             0.8996759960158076, 0.5563318548969114, 0.2651346625378677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 247}], {
             RGBColor[
             0.8653490116625105, 0.42606196440460237`, 0.20717681371904806`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 289}], {
             RGBColor[
             0.8607218959500621, 0.40585224662813213`, 0.20335726643267069`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 302}], {
             RGBColor[
             0.905483758897311, 0.5759228028237954, 0.28769672462851575`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 340}], {
             RGBColor[
             0.9087343059844912, 0.5861006931027701, 0.36724259092497624`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 400}], {
             RGBColor[
             0.6066506956499677, 0.3474920671801415, 0.5581829902007515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 189}], {
             RGBColor[
             0.2745072076984255, 0.4058548584262301, 0.9389441514301794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 200}], {
             RGBColor[
             0.2595636633022175, 0.3901482457903771, 0.9380931386838082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 226}], {
             RGBColor[
             0.24355084950968384`, 0.37331776322339055`, 0.9371812326271585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 241}], {
             RGBColor[
             0.2697148101734317, 0.4008177447719086, 0.9386712314808479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 255}], {
             RGBColor[
             0.2544713249858168, 0.38479587534694254`, 0.9378031375501286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 288}], {
             RGBColor[
             0.2467468316416792, 0.3766769430810886, 0.9373632390815438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 341}], {
             RGBColor[
             0.23502569235584353`, 0.3643572825285215, 0.9366957375390872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 374}], {
             RGBColor[
             0.2622856992899031, 0.3930092782004845, 0.9382481546064155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 393}], {
             RGBColor[
             0.23564383540018752`, 0.36500699006065973`, 0.9367309398710019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 399}], {
             RGBColor[
             0.24167334431028037`, 0.3713443862181124, 0.9370743114835726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 193}], {
             RGBColor[
             0.8331367258093362, 0.8697846265391334, 0.9839465187292714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 218}], {
             RGBColor[
             0.8769988069965478, 0.9047590594733392, 0.9881301231890498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 232}], {
             RGBColor[
             0.6847452419471614, 0.7520517688707707, 0.9703846238932006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 235}], {
             RGBColor[
             0.792013758809907, 0.8376400126416226, 0.9798528182009743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 275}], {
             RGBColor[
             0.9180172404014313, 0.9346976892728417, 0.8827763564020366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 279}], {
             RGBColor[
             0.8947917399967904, 0.8503099582405043, 0.6300514927715455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 281}], {
             RGBColor[
             0.7379639441479849, 0.795257108792612, 0.9745741950769791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 298}], {
             RGBColor[
             0.8336819864556111, 0.8702194025777671, 0.983998526176473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 306}], {
             RGBColor[
             0.9071549779062498, 0.8950638881018478, 0.6621967951023203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 195}], {
             RGBColor[
             0.25639031228130726`, 0.3868128526653249, 0.9379124210377194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 203}], {
             RGBColor[
             0.2792417470878428, 0.4108311595116429, 0.9392137764442834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 206}], {
             RGBColor[
             0.2493239941811602, 0.37938570431162577`, 0.937510004675597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 208}], {
             RGBColor[
             0.25008631824464794`, 0.38018695523648866`, 0.9375534179032552]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 258}], {
             RGBColor[
             0.2600095899871553, 0.39061694300963157`, 0.938118533548826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 278}], {
             RGBColor[
             0.2597507710467335, 0.39034490789317966`, 0.9381037941930572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 284}], {
             RGBColor[
             0.25554200422115014`, 0.38592122710826227`, 0.9378641111486529]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 327}], {
             RGBColor[
             0.2928390260811543, 0.4242124195155595, 0.9400214534598996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 361}], {
             RGBColor[
             0.3113562197109362, 0.44025108193646334`, 0.9412013526638779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 369}], {
             RGBColor[
             0.26226993371413826`, 0.39299270758076044`, 0.9382472567801988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 392}], {
             RGBColor[
             0.25751756533120074`, 0.38799766709273437`, 0.9379766164312895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 200}], {
             RGBColor[
             0.28560319899075254`, 0.41751744880094743`, 0.9395760517192293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 219}], {
             RGBColor[
             0.37386729373661226`, 0.4974887142474586, 0.9450712281757306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 241}], {
             RGBColor[
             0.2957543458619668, 0.428186947782479, 0.9401541445162689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 255}], {
             RGBColor[
             0.28051086067435194`, 0.4121650783575129, 0.9392860505855498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 339}], {
             RGBColor[
             0.333153622737486, 0.4622245787566195, 0.942476989061352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 360}], {
             RGBColor[
             0.30546923311788443`, 0.43824575192600135`, 0.9407129642351355]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 374}], {
             RGBColor[
             0.2883252349784382, 0.42037848121105487`, 0.9397310676418367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 266}], {
             RGBColor[
             0.24805045871485498`, 0.3780471377897267, 0.9374374787148178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 273}], {
             RGBColor[
             0.2582701914773965, 0.38878872489163985`, 0.9380194773769047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 365}], {
             RGBColor[
             0.24867185173243342`, 0.3787002612497945, 0.9374728661279003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 198}], {
             RGBColor[
             0.7526714957518834, 0.806764542665624, 0.9759689648481673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 216}], {
             RGBColor[
             0.6689774683276695, 0.7413295497654275, 0.9676410801591727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 219}], {
             RGBColor[
             0.5630206032370957, 0.6553990201614963, 0.9591704044347413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 220}], {
             RGBColor[
             0.5771439386381384, 0.6670314281944398, 0.9602362550255482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 311}], {
             RGBColor[
             0.5991137006259042, 0.6848674707026068, 0.961965795167115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 323}], {
             RGBColor[
             0.7545318035699571, 0.8082479016230455, 0.9761464026685716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 339}], {
             RGBColor[
             0.5223069322379694, 0.6201348846706572, 0.9565761653203628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 357}], {
             RGBColor[
             0.6772717325975683, 0.7478090920518159, 0.9684677749072899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 201}], {
             RGBColor[
             0.3104580154232146, 0.4403366833931581, 0.941112499955068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 203}], {
             RGBColor[
             0.31794365991620344`, 0.4482045703725628, 0.9415387963349251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 228}], {
             RGBColor[
             0.35617346073846823`, 0.48292128271817314`, 0.9439160358597984]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 243}], {
             RGBColor[
             0.31643084813058897`, 0.44661450926807483`, 0.9414526439417388]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 332}], {
             RGBColor[
             0.43585567576042195`, 0.5499313562155932, 0.9495477612304457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 348}], {
             RGBColor[
             0.30372248336585006`, 0.4332572121434699, 0.9407289213687278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 361}], {
             RGBColor[
             0.35005813253929685`, 0.4776244927973833, 0.9435263725545195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 385}], {
             RGBColor[
             0.45995539470159097`, 0.5694965937320001, 0.9514449793856737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 232}], {
             RGBColor[
             0.6739481277148399, 0.7434424430617759, 0.9693547854990241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 235}], {
             RGBColor[
             0.7812166445775857, 0.8290306868326278, 0.9788229798067978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 260}], {
             RGBColor[
             0.8156468227717713, 0.8559278037169716, 0.9822546582008858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 275}], {
             RGBColor[
             0.9072201261691099, 0.9260883634638468, 0.8817465180078601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 281}], {
             RGBColor[
             0.7271668299156635, 0.7866477829836171, 0.9735443566828026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 338}], {
             RGBColor[
             0.9083139927934867, 0.9256835176042191, 0.801309811633953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 384}], {
             RGBColor[
             0.7853837252276628, 0.8322860419074539, 0.9792383154624147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 376}], {
             RGBColor[
             0.4132241787161002, 0.5323357471779375, 0.947551257161364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 377}], {
             RGBColor[
             0.40146722310948635`, 0.5221524631532592, 0.9468021143463783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 396}], {
             RGBColor[
             0.3331772870037427, 0.4601881672994485, 0.9425538104147095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 206}], {
             RGBColor[
             0.2386283880050733, 0.3681439440799593, 0.9369009057266002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 208}], {
             RGBColor[
             0.239390712068561, 0.3689451950048222, 0.9369443189542583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 258}], {
             RGBColor[
             0.24931398381106837`, 0.3793751827779651, 0.9375094345998292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 278}], {
             RGBColor[
             0.24905516487064655`, 0.3791031476615132, 0.9374946952440605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 284}], {
             RGBColor[
             0.24484639804506322`, 0.3746794668765958, 0.9372550121996561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 327}], {
             RGBColor[
             0.2821434199050674, 0.41297065928389304`, 0.9394123545109028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 337}], {
             RGBColor[
             0.26521901916211443`, 0.39609238336940045`, 0.9384152028336801]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 369}], {
             RGBColor[
             0.2515743275380513, 0.381750947349094, 0.9376381578312021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 392}], {
             RGBColor[
             0.24682195915511385`, 0.3767559068610679, 0.9373675174822926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 231}], {
             RGBColor[
             0.3033041199951848, 0.43612223907981873`, 0.9405840929842658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 234}], {
             RGBColor[
             0.3183317548341577, 0.44914414193399255`, 0.9415414311188043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 290}], {
             RGBColor[
             0.3515289166579535, 0.47789785496789633`, 0.943656724915119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 303}], {
             RGBColor[
             0.29376792821553643`, 0.42609909688992764`, 0.9400410209699464]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 313}], {
             RGBColor[
             0.2903662346350581, 0.4225237012570149, 0.9398472995528928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 344}], {
             RGBColor[
             0.3092763827236792, 0.441300833748132, 0.9409644308152758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 204}], {
             RGBColor[
             0.5838392169462935, 0.6475052215433456, 0.8847911904815791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 215}], {
             RGBColor[
             0.9040198154602492, 0.5694397771754294, 0.5010925431304881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 295}], {
             RGBColor[
             0.6155693919444334, 0.6808556472756819, 0.8865981770071358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 310}], {
             RGBColor[
             0.5856647922314719, 0.6494240169162264, 0.8848951542933734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 345}], {
             RGBColor[
             0.5953494141792219, 0.6596031686238084, 0.8854466791861835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 216}], {
             RGBColor[
             0.7427956016916255, 0.7990494191661757, 0.974984628023718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 219}], {
             RGBColor[
             0.6368387366010516, 0.7131188895622445, 0.9665139522992866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 224}], {
             RGBColor[
             0.901075568718926, 0.8970235530331128, 0.6716312488962854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 247}], {
             RGBColor[
             0.866748584365629, 0.7667536625408037, 0.6136734000774657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 302}], {
             RGBColor[
             0.9068833316004294, 0.9166145009599966, 0.6941933109869335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 311}], {
             RGBColor[
             0.6729318339898602, 0.7425873401033549, 0.9693093430316602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 323}], {
             RGBColor[
             0.828349936933913, 0.8659677710237936, 0.9834899505331167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 340}], {
             RGBColor[
             0.9101338786876096, 0.9267923912389714, 0.7737391772833939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 212}], {
             RGBColor[
             0.21834996970250586`, 0.3468300407179805, 0.9357460798035004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 238}], {
             RGBColor[
             0.22751293603602638`, 0.35646089930013114`, 0.9362678971808005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 252}], {
             RGBColor[
             0.2250679449332263, 0.3538910586296987, 0.9361286585545363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 277}], {
             RGBColor[
             0.24180779724081597`, 0.3714857047729135, 0.9370819683790612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 287}], {
             RGBColor[
             0.24300807911222783`, 0.3727472771220335, 0.9371503226559803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 293}], {
             RGBColor[
             0.21851691429369074`, 0.3470055100682143, 0.9357555870509962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 299}], {
             RGBColor[
             0.21996573354153404`, 0.3485283109581435, 0.9358380951638248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 336}], {
             RGBColor[
             0.2184046627263886, 0.34688752655381927`, 0.9357491944902996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 367}], {
             RGBColor[
             0.2225587298907346, 0.35125371452661747`, 0.9359857624699174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 225}], {
             RGBColor[
             0.26388387983793327`, 0.3946890672869635, 0.9383391686243296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 241}], {
             RGBColor[
             0.2808108014657587, 0.41248033514662596`, 0.9393031317698977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 255}], {
             RGBColor[
             0.26556731627814384`, 0.3964584657216599, 0.9384350378391786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 288}], {
             RGBColor[
             0.25784282293400623`, 0.38833953345580596`, 0.9379951393705938]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 296}], {
             RGBColor[
             0.2860905976760283, 0.41802973572203384`, 0.939603808353314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 339}], {
             RGBColor[
             0.3182100783412779, 0.4465179661207665, 0.9416259763149808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 355}], {
             RGBColor[
             0.2507904105311417, 0.380927000871623, 0.9375935149173598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 360}], {
             RGBColor[
             0.29052568872167633`, 0.4225391392901483, 0.9398619514887643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 374}], {
             RGBColor[
             0.27338169058223005`, 0.4046718685752019, 0.9388800548954654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 375}], {
             RGBColor[
             0.26275249757312547`, 0.3934999127928718, 0.9382747380780788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 383}], {
             RGBColor[
             0.27544799036410295`, 0.4068436806569232, 0.9389977276112265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 399}], {
             RGBColor[
             0.2527693356026074, 0.3830069765928298, 0.9377062117726225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 210}], {
             RGBColor[
             0.2881749983278178, 0.42022057296569904`, 0.9397225118868391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 228}], {
             RGBColor[
             0.3221417320475673, 0.45045653149250003`, 0.9418569760468667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 236}], {
             RGBColor[
             0.26347424346046877`, 0.3942585134818019, 0.9383158404386357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 243}], {
             RGBColor[
             0.2823991194396881, 0.4141497580424017, 0.9393935841288071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 263}], {
             RGBColor[
             0.26925494850456955`, 0.4003344010010207, 0.9386450430391104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 348}], {
             RGBColor[
             0.2696907546749492, 0.40079246091779686`, 0.9386698615557961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 351}], {
             RGBColor[
             0.26108538890678307`, 0.3917476758837515, 0.9381797987057969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 214}], {
             RGBColor[
             0.9200563597791344, 0.7107376048071281, 0.556968147234525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 217}], {
             RGBColor[
             0.8395826476787889, 0.30525515205179155`, 0.18553769416040178`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 257}], {
             RGBColor[
             0.8394733977788387, 0.30441540944716294`, 0.18543307633282935`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 264}], {
             RGBColor[
             0.5231853201585595, 0.37556082624020004`, 0.5678587762898913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 268}], {
             RGBColor[
             0.836829312925746, 0.2840918146209231, 0.18290109769144122`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 279}], {
             RGBColor[
             0.9009946329017078, 0.6281412966873632, 0.2383554119012628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 300}], {
             RGBColor[
             0.873168201892003, 0.5137197571930974, 0.21575357463755512`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 306}], {
             RGBColor[
             0.913357870811167, 0.6728952265487068, 0.2705007142320376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 363}], {
             RGBColor[
             0.8594260597663401, 0.4513198993592995, 0.20428679439717456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 381}], {
             RGBColor[
             0.9247433274483484, 0.7127453819428937, 0.4824095946157798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 243}], {
             RGBColor[
             0.28988476393267687`, 0.4220176450218065, 0.9398198805086642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 258}], {
             RGBColor[
             0.2721654186176039, 0.4033934896242831, 0.9388107900063931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 284}], {
             RGBColor[
             0.26769783285159876`, 0.3986977737229138, 0.93855636760622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 348}], {
             RGBColor[
             0.277176399167938, 0.4086603478972015, 0.9390961579356532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 361}], {
             RGBColor[
             0.32351204834138475`, 0.4530276285511149, 0.941893609121445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 369}], {
             RGBColor[
             0.2744257623445868, 0.405769254195412, 0.9389395132377659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 392}], {
             RGBColor[
             0.26967339396164935`, 0.4007742137073859, 0.9386688728888566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 261}], {
             RGBColor[
             0.17918768478614402`, 0.3056679962386074, 0.9335158456129223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 295}], {
             RGBColor[
             0.21065717499813985`, 0.33874442573233643`, 0.9353079865255567]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 310}], {
             RGBColor[
             0.18075257528517846`, 0.3073127953728809, 0.9336049638117943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 345}], {
             RGBColor[
             0.1904371972329284, 0.3174919470804629, 0.9341564887046044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 389}], {
             RGBColor[
             0.17900756331513207`, 0.305478677152213, 0.9335055879616141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 400}], {
             RGBColor[
             0.2842689537951664, 0.40863855928315673`, 0.939773820202813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 207}], {
             RGBColor[
             0.967562165289962, 0.8957834071543473, 0.4992706546503005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 221}], {
             RGBColor[
             0.9585637141169614, 0.9664203575638242, 0.8602427231177231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 230}], {
             RGBColor[
             0.9820628725503424, 0.9494608486926688, 0.5307965926515668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 250}], {
             RGBColor[
             0.9917478646376758, 0.990855544204543, 0.7864227690028461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 276}], {
             RGBColor[
             0.8804173286055655, 0.9045483902483498, 0.8526723312886473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 358}], {
             RGBColor[
             0.9819225924478814, 0.9489876509677333, 0.5302516309431803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 391}], {
             RGBColor[
             0.9078296512801215, 0.575024774186147, 0.4476180378082022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 208}], {
             RGBColor[
             0.23232439396841398`, 0.3615180466511231, 0.9365419025921359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 258}], {
             RGBColor[
             0.24224766571092132`, 0.37194803442426605`, 0.9371070182377067]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 278}], {
             RGBColor[
             0.24198884677049953`, 0.37167599930781414`, 0.937092278881938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 284}], {
             RGBColor[
             0.23778007994491618`, 0.3672523185228967, 0.9368525958375336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 369}], {
             RGBColor[
             0.2445080094379043, 0.3743237989953949, 0.9372357414690795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 392}], {
             RGBColor[
             0.23975564105496683`, 0.3693287585073688, 0.9369651011201702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 221}], {
             RGBColor[
             0.9308573670898133, 0.869892342221664, 0.6314368519575342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 230}], {
             RGBColor[
             0.9543565255231943, 0.8529328333505086, 0.30199072149137773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 233}], {
             RGBColor[
             0.8786570254685007, 0.4672262975790694, 0.21740805642807715`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 250}], {
             RGBColor[
             0.9640415176105277, 0.8943275288623829, 0.5576168978426572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 358}], {
             RGBColor[
             0.9542162454207332, 0.8524596356255733, 0.30144575978299126`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 366}], {
             RGBColor[
             0.9205681319812286, 0.7219373884597544, 0.2549015531776194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 391}], {
             RGBColor[
             0.8801233042529734, 0.4784967588439868, 0.2188121666480132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[
             0.24300998977440907`, 0.3727492853491289, 0.9371504314653649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 278}], {
             RGBColor[
             0.24275117083398723`, 0.37247725023267697`, 0.9371356921095961]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 284}], {
             RGBColor[
             0.23854240400840393`, 0.3680535694477596, 0.9368960090651918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 369}], {
             RGBColor[
             0.24527033350139205`, 0.37512504992025775`, 0.9372791546967377]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 392}], {
             RGBColor[
             0.24051796511845452`, 0.3701300094322317, 0.9370085143478284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 227}], {
             RGBColor[
             0.24347750032410487`, 0.3732406685787401, 0.9371770554995502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 229}], {
             RGBColor[
             0.24946457527559712`, 0.37953346395523513`, 0.937518010560954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 240}], {
             RGBColor[
             0.24561974977362988`, 0.37549230857665095`, 0.9372990534365266]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 245}], {
             RGBColor[
             0.2409659187206967, 0.37060083707008695`, 0.9370340246427882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 280}], {
             RGBColor[
             0.24552309910713999`, 0.37539072259816386`, 0.9372935493240518]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 304}], {
             RGBColor[
             0.23556571159456763`, 0.3649248769876179, 0.9367264908358456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 315}], {
             RGBColor[
             0.24765360770529532`, 0.37763002221687225`, 0.9374148786369118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 319}], {
             RGBColor[
             0.24680833108244982`, 0.37674158289262827`, 0.9373667413837155]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 329}], {
             RGBColor[
             0.24358590725750107`, 0.37335461113913604`, 0.9371832291140334]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 334}], {
             RGBColor[
             0.2567160128781451, 0.387155184643212, 0.9379309692048785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 371}], {
             RGBColor[
             0.26203929742842424`, 0.3927502942212898, 0.9382341223849231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 236}], {
             RGBColor[
             0.27522295505597283`, 0.4066071542800159, 0.9389849121833385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 263}], {
             RGBColor[
             0.2810036601000736, 0.41268304179923465`, 0.9393141147838132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 301}], {
             RGBColor[
             0.25974755171345176`, 0.39034152416978307`, 0.9381036108567895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 328}], {
             RGBColor[
             0.2860571913279975, 0.41793071873950494`, 0.9396042457787188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 347}], {
             RGBColor[
             0.27136364126610246`, 0.4025507707922349, 0.9387651299723484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 372}], {
             RGBColor[
             0.257077351430105, 0.3875349743715093, 0.9379515469008601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 387}], {
             RGBColor[
             0.27812297420375887`, 0.4096552582761729, 0.939150063983611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 238}], {
             RGBColor[
             0.22006014114382055`, 0.3486275393339343, 0.9358434715371114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 259}], {
             RGBColor[
             0.2109589325174653, 0.33906159201767927`, 0.935325171169872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 293}], {
             RGBColor[
             0.2110641194014849, 0.3391721501020175, 0.935331161407307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 299}], {
             RGBColor[
             0.2125129386493282, 0.3406949509919467, 0.9354136695201356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 336}], {
             RGBColor[
             0.21095186783418274`, 0.3390541665876225, 0.9353247688466104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 367}], {
             RGBColor[
             0.21510593499852879`, 0.3434203545604207, 0.9355613368262283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 224}], {
             RGBColor[
             0.9433148110399261, 0.8071439818533458, 0.30358552172184644`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 230}], {
             RGBColor[
             0.939912673270707, 0.7956677722978341, 0.2903688589282392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 247}], {
             RGBColor[
             0.9089878266866289, 0.6768740913610367, 0.24562767290302676`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 250}], {
             RGBColor[
             0.9495976653580405, 0.8370624678097084, 0.5459950352795185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 289}], {
             RGBColor[
             0.9043607109741805, 0.6566643735845665, 0.24180812561664938`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 302}], {
             RGBColor[
             0.9491225739214294, 0.8267349297802298, 0.3261475838124945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 340}], {
             RGBColor[
             0.9523731210086097, 0.8369128200592044, 0.40569345010895497`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 391}], {
             RGBColor[
             0.8656794520004861, 0.4212316977913123, 0.20719030408487465`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 215}], {
             RGBColor[
             0.9015306453673441, 0.5683408458182889, 0.5392279021919928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 217}], {
             RGBColor[
             0.903299381606431, 0.5819361276170735, 0.5409216460120444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 261}], {
             RGBColor[
             0.5816107316395323, 0.6466802864248125, 0.9229413951560062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 264}], {
             RGBColor[
             0.5869020540862017, 0.6522418018054821, 0.9232427281415339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 295}], {
             RGBColor[
             0.6130802218515281, 0.6797567159185416, 0.9247335360686406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 300}], {
             RGBColor[
             0.9368849358196452, 0.7904007327583793, 0.5711375264891978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 310}], {
             RGBColor[
             0.5831756221385668, 0.6483250855590861, 0.9230305133548782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 363}], {
             RGBColor[
             0.9231427936939823, 0.7280008749245814, 0.5596707462488172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 217}], {
             RGBColor[
             0.8210569332669986, 0.16285839306295227`, 0.16779744911786956`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 269}], {
             RGBColor[
             0.9061735630089964, 0.5684125935804545, 0.32599457253607145`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 295}], {
             RGBColor[
             0.5308377735120957, 0.2606789813644203, 0.5516093391744658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 300}], {
             RGBColor[
             0.8546424874802127, 0.37132299820425807`, 0.1980133295950229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 352}], {
             RGBColor[
             0.906721166296464, 0.5695838616411621, 0.3855978109611532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 363}], {
             RGBColor[
             0.8409003453545498, 0.3089231403704602, 0.18654654935464235`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 219}], {
             RGBColor[
             0.5531447091768378, 0.647683896662048, 0.958186067610292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 220}], {
             RGBColor[
             0.5672680445778805, 0.6593163046949915, 0.9592519182010989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 311}], {
             RGBColor[
             0.5892378065656463, 0.6771523472031584, 0.9609814583426657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 323}], {
             RGBColor[
             0.7446559095096992, 0.8005327781235971, 0.9751620658441222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 339}], {
             RGBColor[
             0.5124310381777115, 0.6124197611712089, 0.9555918284959135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 357}], {
             RGBColor[
             0.6673958385373104, 0.7400939685523675, 0.9674834380828405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 268}], {
             RGBColor[
             0.8200723347530428, 0.15529033743086842`, 0.16685459646896056`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 269}], {
             RGBColor[
             0.9079422992480835, 0.582007875379239, 0.32768831635612294`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 279}], {
             RGBColor[
             0.8842376547290044, 0.4993398194973086, 0.22230891067878217`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 300}], {
             RGBColor[
             0.8564112237192996, 0.3849182800030426, 0.19970707341507446`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 306}], {
             RGBColor[
             0.8966008926384637, 0.5440937493586522, 0.25445421300955695`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 363}], {
             RGBColor[
             0.8426690815936368, 0.3225184221692448, 0.1882402931746939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 262}], {
             RGBColor[
             0.9243533171861171, 0.9424423464401257, 0.9900148507220045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 269}], {
             RGBColor[
             0.9515613514707596, 0.9593431212476458, 0.7385846645144882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 279}], {
             RGBColor[
             0.9278567069516805, 0.8766750653657154, 0.6332052588371474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 298}], {
             RGBColor[
             0.8667469534105012, 0.8965845097029781, 0.9871522922420749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.9000302759419758, 0.7622535258714493, 0.6106034215734397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 306}], {
             RGBColor[
             0.9402199448611399, 0.9214289952270589, 0.6653505611679222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 314}], {
             RGBColor[
             0.9179378774680893, 0.9374027630058823, 0.9920349282773651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 220}], {
             RGBColor[
             0.4613111794873067, 0.5733857750910603, 0.9507812424766675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 241}], {
             RGBColor[
             0.36907489621161843`, 0.49245160059313714`, 0.9447983082263991]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 311}], {
             RGBColor[
             0.48328094147507245`, 0.5912218175992272, 0.9525107826182344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 323}], {
             RGBColor[
             0.6386990444191253, 0.7146022485196659, 0.9666913901196909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 339}], {
             RGBColor[
             0.4064741730871376, 0.5264892315672777, 0.9471211527714821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 357}], {
             RGBColor[
             0.5614389734467367, 0.6541634389484363, 0.9590127623584092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 360}], {
             RGBColor[
             0.37878978346753606`, 0.5025104047366595, 0.9453571279452656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 350}], {
             RGBColor[
             0.454088632793754, 0.5671299681608568, 0.9503210281880017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 357}], {
             RGBColor[
             0.5755623088477795, 0.6657958469813797, 0.960078612949216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 394}], {
             RGBColor[
             0.4171512331180811, 0.5351366490894776, 0.9479674097431279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 230}], {
             RGBColor[
             0.9453580743501937, 0.9235697837599854, 0.6629627899588003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 250}], {
             RGBColor[
             0.955043066437527, 0.9649644792718597, 0.9185889663100797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 276}], {
             RGBColor[
             0.8437125304054167, 0.8786573253156666, 0.9848385285958808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 358}], {
             RGBColor[
             0.9452177942477327, 0.9230965860350502, 0.6624178282504138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 251}], {
             RGBColor[
             0.7136213718875605, 0.7756511419302459, 0.9724778106511085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 297}], {
             RGBColor[
             0.7757829604608912, 0.8249349923236523, 0.9686258035292561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 312}], {
             RGBColor[
             0.5339420376563727, 0.632517225840949, 0.9564530195798908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 332}], {
             RGBColor[
             0.5660742539559687, 0.6586036065728093, 0.9589825853511816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 356}], {
             RGBColor[
             0.5616526527416191, 0.6550139515161355, 0.9586345007067291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 361}], {
             RGBColor[
             0.48027671073484357`, 0.5862967431545993, 0.9529611966752556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 260}], {
             RGBColor[
             0.6315106131402652, 0.7091757673875206, 0.9658788076150083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 267}], {
             RGBColor[
             0.5126330687833186, 0.6152176449516955, 0.954775499492879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 272}], {
             RGBColor[
             0.5505420601979628, 0.6459225184451997, 0.9578086189518668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 290}], {
             RGBColor[
             0.4296004547734099, 0.5464997120753861, 0.9486003596365518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 291}], {
             RGBColor[
             0.5752793861727824, 0.6652475055073694, 0.9602742044215822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 321}], {
             RGBColor[
             0.6359268279774656, 0.7126257479828174, 0.9663189746381065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 331}], {
             RGBColor[
             0.45307983116767014`, 0.5668363678003234, 0.9500964447383967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 342}], {
             RGBColor[
             0.5287126959381665, 0.6282718106549494, 0.9560413466441238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 346}], {
             RGBColor[
             0.3995496021231435, 0.5204711739094963, 0.9466855458786024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 384}], {
             RGBColor[
             0.6012475155961567, 0.6855340055780029, 0.9628624648765374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 398}], {
             RGBColor[
             0.696746297429305, 0.7610076864937902, 0.9687930758283795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 230}], {
             RGBColor[
             0.9722593705527938, 0.9180864844443417, 0.3467333222862512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 247}], {
             RGBColor[
             0.9413345239687156, 0.7992928035075443, 0.30199213626103877`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 289}], {
             RGBColor[
             0.9367074082562672, 0.779083085731074, 0.29817258897466137`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 302}], {
             RGBColor[
             0.981469271203516, 0.9491536419267372, 0.38251204717050646`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 323}], {
             RGBColor[
             0.9029358765369997, 0.8985069119905342, 0.6718086867166897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 340}], {
             RGBColor[
             0.9847198182906963, 0.959331532205712, 0.46205791346696695`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 288}], {
             RGBColor[
             0.25106704817739506`, 0.3812177645776751, 0.9376092690220652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 296}], {
             RGBColor[
             0.2793148229194171, 0.41090796684390285`, 0.9392179380047856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 316}], {
             RGBColor[
             0.2556938059368381, 0.38608078033623494`, 0.9378727560317908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 324}], {
             RGBColor[
             0.2685328797360218, 0.39957546094347285`, 0.9386039222909468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 355}], {
             RGBColor[
             0.24401463577453056`, 0.373805231993492, 0.9372076445688313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 375}], {
             RGBColor[
             0.2559767228165143, 0.3863781439147409, 0.9378888677295503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 380}], {
             RGBColor[
             0.2612993849996442, 0.39197259934548456`, 0.9381919854667065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 383}], {
             RGBColor[
             0.26867221560749177`, 0.39972191177879235`, 0.938611857262698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 390}], {
             RGBColor[
             0.26170368970244295`, 0.3923975492225247, 0.9382150100214157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 255}], {
             RGBColor[
             0.24955450248561023`, 0.3796279831546734, 0.9375231317825289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 266}], {
             RGBColor[
             0.24681597923856835`, 0.37674962158963, 0.9373671769348919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 294}], {
             RGBColor[
             0.22569678935260098`, 0.35455201398550057`, 0.9361644703139277]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 341}], {
             RGBColor[
             0.23010886985563692`, 0.3591893903362524, 0.9364157317714874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 368}], {
             RGBColor[
             0.2257077662103317, 0.35456355135894857`, 0.9361650954297367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 393}], {
             RGBColor[
             0.2307270128999809, 0.3598390978683905, 0.9364509341034022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 399}], {
             RGBColor[
             0.23675652181007376`, 0.36617649402584324`, 0.9367943057159729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 280}], {
             RGBColor[
             0.23696761026347307`, 0.36639836137414694`, 0.9368063268911165]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 304}], {
             RGBColor[
             0.22701022275090071`, 0.35593251576360085`, 0.9362392684029103]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 315}], {
             RGBColor[
             0.2390981188616284, 0.3686376609928552, 0.9369276562039764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 243}], {
             RGBColor[
             0.3281145647549416, 0.45673435736741674`, 0.9421971200335375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 332}], {
             RGBColor[
             0.44753939238477464`, 0.5600512043149352, 0.9502922373222444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 348}], {
             RGBColor[
             0.31540619999020275`, 0.44337706024281187`, 0.9414733974605265]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 361}], {
             RGBColor[
             0.3617418491636495, 0.4877443408967252, 0.9442708486463184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 385}], {
             RGBColor[
             0.4716391113259436, 0.5796164418313421, 0.9521894554774726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 240}], {
             RGBColor[
             0.24305133588145522`, 0.372792742729129, 0.9371527860649951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 245}], {
             RGBColor[
             0.238397504828522, 0.36790127122256505`, 0.9368877572712566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 248}], {
             RGBColor[
             0.2315520252069328, 0.36070623811179847`, 0.9364979173337866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 249}], {
             RGBColor[
             0.2582327214414536, 0.38874934150812634`, 0.9380173435137897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 309}], {
             RGBColor[
             0.25884330525935606`, 0.3893911038139919, 0.9380521153589414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 315}], {
             RGBColor[
             0.24508519381312066`, 0.3749304563693503, 0.9372686112653803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 319}], {
             RGBColor[
             0.24423991719027513`, 0.3740420170451063, 0.9372204740121839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[
             0.2410174933653264, 0.37065504529161414`, 0.937036961742502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 334}], {
             RGBColor[
             0.25414759898597045`, 0.3844556187956901, 0.9377847018333471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 371}], {
             RGBColor[
             0.25947088353624953`, 0.3900507283737679, 0.9380878550133916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 388}], {
             RGBColor[
             0.23513063549537086`, 0.3644675844219441, 0.9367017138956337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 247}], {
             RGBColor[
             0.9379323861994966, 0.7878165939520326, 0.28877547346743154`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 250}], {
             RGBColor[
             0.9785422248709081, 0.9480049704007043, 0.5891428358439234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 289}], {
             RGBColor[
             0.9333052704870481, 0.7676068761755623, 0.28495592618105414`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 358}], {
             RGBColor[
             0.9687169526811137, 0.9061370771638947, 0.3329716977842575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 391}], {
             RGBColor[
             0.8946240115133538, 0.5321742003823082, 0.2503381046492794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 234}], {
             RGBColor[
             0.3237117587462526, 0.454798867157554, 0.9418478143825956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 290}], {
             RGBColor[
             0.3569089205700484, 0.48355258019145775`, 0.9439631081789103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 313}], {
             RGBColor[
             0.295746238547153, 0.4281784264805763, 0.9401536828166841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 331}], {
             RGBColor[
             0.38038829696430865`, 0.5038892359163952, 0.9454591932807552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 359}], {
             RGBColor[
             0.2771261222266016, 0.4086075036441148, 0.9390932947382222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 235}], {
             RGBColor[
             0.6328251607154107, 0.7112978291642651, 0.965261084970727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 281}], {
             RGBColor[
             0.5787753460534887, 0.6689149253152545, 0.9599824618467317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 384}], {
             RGBColor[
             0.6369922413654878, 0.7145531842390913, 0.965676420626344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 386}], {
             RGBColor[
             0.4324598922567031, 0.5470353068857565, 0.9493188938960907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 242}], {
             RGBColor[
             0.867902536299588, 0.4245883317454004, 0.20875474200246447`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 317}], {
             RGBColor[
             0.9040426479180714, 0.5627946336685001, 0.48467433968140694`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 358}], {
             RGBColor[
             0.8930174526264201, 0.5204305413924555, 0.24838903272095686`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 366}], {
             RGBColor[
             0.8593693391869154, 0.3899082942266366, 0.20184482611558502`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 382}], {
             RGBColor[
             0.8581195774771997, 0.3842334181920808, 0.20080199431053547`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 290}], {
             RGBColor[
             0.37193655540902126`, 0.4965744830456317, 0.9449204463134487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 313}], {
             RGBColor[
             0.3107738733861259, 0.4412003293347502, 0.9411110209512226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 331}], {
             RGBColor[
             0.3954159318032815, 0.5169111387705692, 0.9464165314152937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 342}], {
             RGBColor[
             0.47104879657377785`, 0.578346581625195, 0.9523614333210206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 346}], {
             RGBColor[
             0.34188570275875485`, 0.4705459448797419, 0.9430056325554994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 275}], {
             RGBColor[
             0.8660971591696807, 0.893943749566336, 0.8776528174795629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 281}], {
             RGBColor[
             0.6860438629162344, 0.7545031690861064, 0.9694506561545053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 384}], {
             RGBColor[
             0.7442607582282336, 0.800141428009943, 0.9751446149341176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 263}], {
             RGBColor[
             0.2563029052327246, 0.3867209823153376, 0.9379074433356098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 351}], {
             RGBColor[
             0.2481333456349381, 0.37813425719806837`, 0.9374421990022963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 246}], {
             RGBColor[
             0.5111109439056949, 0.6137235569467266, 0.9547270574586124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 254}], {
             RGBColor[
             0.5239652108029346, 0.6244175883504002, 0.9556676072236672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 286}], {
             RGBColor[
             0.652334455595527, 0.7273484229582274, 0.9666519351718024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 320}], {
             RGBColor[
             0.644156525821959, 0.7209597620645476, 0.9658368355590718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 343}], {
             RGBColor[
             0.6503098019378368, 0.7257667481329021, 0.9664501366166679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 349}], {
             RGBColor[
             0.5118990860533059, 0.6144062060618112, 0.9547772771793315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 252}], {
             RGBColor[
             0.22677811637454098`, 0.3556885572456525, 0.9362260502881472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 277}], {
             RGBColor[
             0.24351796868213066`, 0.3732832033888673, 0.9371793601126722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 287}], {
             RGBColor[
             0.24471825055354252`, 0.3745447757379873, 0.9372477143895912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 293}], {
             RGBColor[
             0.22022708573500543`, 0.3488030086841681, 0.935852978784607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 299}], {
             RGBColor[
             0.22167590498284873`, 0.3503258095740973, 0.9359354868974357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 336}], {
             RGBColor[
             0.22011483416770328`, 0.34868502516977307`, 0.9358465862239105]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 367}], {
             RGBColor[
             0.2242689013320493, 0.35305121314257126`, 0.9360831542035284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 396}], {
             RGBColor[
             0.25376131131834845`, 0.3840496059649667, 0.9377627033221374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 271}], {
             RGBColor[
             0.31565140111640955`, 0.4476420700773734, 0.9413406348615612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 326}], {
             RGBColor[
             0.3319525774457105, 0.4619423709869775, 0.94237270259407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 335}], {
             RGBColor[
             0.3025165492814234, 0.4338365080010965, 0.9405926244808307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 337}], {
             RGBColor[
             0.304629125717821, 0.43605695978083275`, 0.9407129325836068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 354}], {
             RGBColor[
             0.3021441775416652, 0.43344512169287874`, 0.940571418461126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 245}], {
             RGBColor[
             0.2345526793265548, 0.3638601158439808, 0.9366688001468292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 248}], {
             RGBColor[
             0.22770719970496556`, 0.3566650827332143, 0.9362789602093593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 292}], {
             RGBColor[
             0.2251125947151853, 0.3539379883814973, 0.9361312012935654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 304}], {
             RGBColor[
             0.22915247220042573`, 0.35818415576151175`, 0.9363612663398866]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 309}], {
             RGBColor[
             0.2549984797573888, 0.3853499484354077, 0.9378331582345141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 315}], {
             RGBColor[
             0.24124036831115342`, 0.3708893009907661, 0.9370496541409528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 319}], {
             RGBColor[
             0.24039509168830792`, 0.37000086166652213`, 0.9370015168877566]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 329}], {
             RGBColor[
             0.23717266786335917`, 0.3666138899130299, 0.9368180046180745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 334}], {
             RGBColor[
             0.2503027734840032, 0.3804144634171059, 0.9375657447089196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 371}], {
             RGBColor[
             0.2556260580342823, 0.3860095729951837, 0.9378688978889642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 388}], {
             RGBColor[
             0.23128580999340365`, 0.36042642904335986`, 0.9364827567712063]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 255}], {
             RGBColor[
             0.2757184631493581, 0.40712796470319146`, 0.9390131306362182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 288}], {
             RGBColor[
             0.2679939698052205, 0.39900903243733754`, 0.9385732321676334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 339}], {
             RGBColor[
             0.32836122521249217`, 0.457187465102298, 0.9422040691120204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 360}], {
             RGBColor[
             0.3006768355928906, 0.4332086382716799, 0.9404400442858039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 374}], {
             RGBColor[
             0.2835328374534444, 0.4153413675567334, 0.939458147692505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 375}], {
             RGBColor[
             0.2729036444443398, 0.40416941177440335`, 0.9388528308751185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 399}], {
             RGBColor[
             0.2629204824738216, 0.3936764755743613, 0.938284304569662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 256}], {
             RGBColor[
             0.5718276027056971, 0.5340616080097416, 0.5946502523941279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 257}], {
             RGBColor[
             0.8704770048155868, 0.4443768248986645, 0.21122005596083127`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 268}], {
             RGBColor[
             0.8678329199624942, 0.4240532300724246, 0.2086880773194431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 317}], {
             RGBColor[
             0.954486951543472, 0.8521857620679489, 0.5290777523178287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 333}], {
             RGBColor[
             0.5569536477379948, 0.5184281382754727, 0.5938032026627618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 381}], {
             RGBColor[
             0.9557469344850966, 0.8527067973943953, 0.5081965742437817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 382}], {
             RGBColor[
             0.9085638811026002, 0.6736245465915296, 0.24520540694695725`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 348}], {
             RGBColor[
             0.27566358738232355`, 0.40707028679271356`, 0.9390100055424669]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 351}], {
             RGBColor[
             0.26705822161415743`, 0.39802550175866824`, 0.9385199426924677]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 253}], {
             RGBColor[
             0.30087597692201773`, 0.4305218254587764, 0.9405574263390588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 270}], {
             RGBColor[
             0.2548116613836774, 0.3851535904796679, 0.9378225192045042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 308}], {
             RGBColor[
             0.2605622771689302, 0.3911978522800683, 0.9381500082662007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 397}], {
             RGBColor[
             0.2546928621186111, 0.3850287249197748, 0.9378157537621064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 248}], {
             RGBColor[
             0.2230533686520324, 0.3517736112266503, 0.9360139314156208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 292}], {
             RGBColor[
             0.2204587636622521, 0.3490465168749334, 0.935866172499827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 304}], {
             RGBColor[
             0.22449864114749254`, 0.35329268425494775`, 0.9360962375461481]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 315}], {
             RGBColor[
             0.23658653725822024`, 0.3659978294842021, 0.9367846253472143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 319}], {
             RGBColor[
             0.2357412606353747, 0.36510939015995814`, 0.9367364880940181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 329}], {
             RGBColor[
             0.232518836810426, 0.36172241840646596`, 0.936552975824336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 353}], {
             RGBColor[
             0.220139248365585, 0.34871068603969635`, 0.9358479765763623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 371}], {
             RGBColor[
             0.25097222698134913`, 0.38111810148861974`, 0.9376038690952258]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 378}], {
             RGBColor[
             0.2192126419789341, 0.3477367639770881, 0.9357952077134337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 388}], {
             RGBColor[
             0.22663197894047044`, 0.3555349575367959, 0.9362177279774678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 254}], {
             RGBColor[
             0.4566571232556863, 0.569515492226385, 0.9504402532261262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 286}], {
             RGBColor[
             0.5850263680482788, 0.6724463268342122, 0.9614245811742612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 320}], {
             RGBColor[
             0.5768484382747107, 0.6660576659405324, 0.9606094815615308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 343}], {
             RGBColor[
             0.5830017143905886, 0.6708646520088869, 0.9612227826191269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 344}], {
             RGBColor[
             0.3822157528613575, 0.505477807231359, 0.9455754276855741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 349}], {
             RGBColor[
             0.44459099850605766`, 0.559504109937796, 0.9495499231817904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 289}], {
             RGBColor[
             0.9023804239029701, 0.648813195238765, 0.2402147401558417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 302}], {
             RGBColor[
             0.9471422868502191, 0.8188837514344283, 0.3245541983516868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 340}], {
             RGBColor[
             0.9503928339373993, 0.8290616417134029, 0.4041000646481473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 391}], {
             RGBColor[
             0.8636991649292758, 0.4133805194455108, 0.20559691862406698`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 292}], {
             RGBColor[
             0.21361328404066288`, 0.34185148376416674`, 0.935476332562357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 304}], {
             RGBColor[
             0.2176531615259033, 0.3460976511441812, 0.9357063976086782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 315}], {
             RGBColor[
             0.229741057636631, 0.35880279637343554`, 0.9363947854097444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 319}], {
             RGBColor[
             0.2288957810137855, 0.3579143570491916, 0.9363466481565481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 329}], {
             RGBColor[
             0.22567335718883677`, 0.3545273852956994, 0.9361631358868661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 353}], {
             RGBColor[
             0.21329376874399575`, 0.34151565292892977`, 0.9354581366388923]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 388}], {
             RGBColor[
             0.21978649931888122`, 0.34833992442602935`, 0.935827888039998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 270}], {
             RGBColor[
             0.25957821450255336`, 0.3901635400245296, 0.9380939673531408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 308}], {
             RGBColor[
             0.2653288302878062, 0.39620780182492993`, 0.9384214564148372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 309}], {
             RGBColor[
             0.2701798653173872, 0.40130654721440506`, 0.9386977156833087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 334}], {
             RGBColor[
             0.2654841590440016, 0.39637106219610324`, 0.9384303021577143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 386}], {
             RGBColor[
             0.3044662110801129, 0.4345129066433197, 0.9407539204836926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 397}], {
             RGBColor[
             0.25945941523748706`, 0.39003867446463636`, 0.938087201910743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 265}], {
             RGBColor[
             0.7900609571838799, 0.8344827358393506, 0.9028921387192244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 276}], {
             RGBColor[
             0.8768966809261312, 0.9030925119563854, 0.9110185744810039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 289}], {
             RGBColor[
             0.9429902625743816, 0.8090015716874366, 0.5405821025323335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 391}], {
             RGBColor[
             0.9043090036006871, 0.5735688958941825, 0.5059642810005588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 282}], {
             RGBColor[
             0.7345888082776114, 0.7926044746200289, 0.9741756038265081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 312}], {
             RGBColor[
             0.6426365090387243, 0.7180224324379316, 0.9668896222215277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 356}], {
             RGBColor[
             0.6703471241239707, 0.7405191581131181, 0.9690711033483659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 277}], {
             RGBColor[
             0.2410729775793306, 0.3707133627184349, 0.9370401214864079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 293}], {
             RGBColor[
             0.21778209463220533`, 0.3462331680137357, 0.9357137401583427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 330}], {
             RGBColor[
             0.2245525377985933, 0.3533493330524997, 0.9360993068806954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 386}], {
             RGBColor[
             0.3405394596215219, 0.4693798967384182, 0.942919851133231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 286}], {
             RGBColor[
             0.5978806349455185, 0.6831403582378857, 0.9623651309393161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 320}], {
             RGBColor[
             0.5897027051719504, 0.6767516973442059, 0.9615500313265857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 343}], {
             RGBColor[
             0.5958559812878284, 0.6815586834125604, 0.9621633323841816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 344}], {
             RGBColor[
             0.39507001975859724`, 0.5161718386350326, 0.946515977450629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 349}], {
             RGBColor[
             0.45744526540329744`, 0.5701981413414695, 0.9504904729468453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 288}], {
             RGBColor[
             0.25275048461760563`, 0.38298716301237146`, 0.9377051382369141]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 341}], {
             RGBColor[
             0.24102934533176992`, 0.3706675024598044, 0.9370376366944575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 360}], {
             RGBColor[
             0.28543335040527573`, 0.4171867688467138, 0.9395719503550848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 374}], {
             RGBColor[
             0.2682893522658295, 0.3993194981317673, 0.938590053761786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 393}], {
             RGBColor[
             0.2416474883761139, 0.3713172099919425, 0.9370728390263723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 399}], {
             RGBColor[
             0.24767699728620676`, 0.3776546061493952, 0.937416210638943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 261}], {
             RGBColor[
             0.20237836752934693`, 0.3300428741759244, 0.934836520687607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 264}], {
             RGBColor[
             0.2076696899760163, 0.3356043895565939, 0.9351378536731348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 317}], {
             RGBColor[
             0.6079677143241806, 0.6722679099328412, 0.8705698500730703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 333}], {
             RGBColor[
             0.21043441051870343`, 0.338510286140365, 0.9352953004180034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 381}], {
             RGBColor[
             0.6092276972658053, 0.6727889452592876, 0.8496886719990233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 268}], {
             RGBColor[
             0.8199630848530925, 0.15445059482623982`, 0.16674997864138813`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 338}], {
             RGBColor[
             0.9084477718580719, 0.5824829620653897, 0.3944924501077937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 381}], {
             RGBColor[
             0.9078770993756948, 0.5831041621482105, 0.46625847556572675`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 382}], {
             RGBColor[
             0.8606940459931985, 0.4040219113453448, 0.20326730826890227`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 278}], {
             RGBColor[
             0.25267444257649463`, 0.38290723800581994`, 0.937700807755167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 284}], {
             RGBColor[
             0.24846567575091127`, 0.3784835572209025, 0.9374611247107626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 369}], {
             RGBColor[
             0.2551936052438994, 0.3855550376934007, 0.9378442703423086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 392}], {
             RGBColor[
             0.25044123686096187`, 0.3805599972053746, 0.9375736299933992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 274}], {
             RGBColor[
             0.22087433163626, 0.34948330516414705`, 0.9358898384811689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 299}], {
             RGBColor[
             0.21257469635649348`, 0.34075986225784227`, 0.9354171865301963]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 318}], {
             RGBColor[
             0.2174190793227137, 0.34585161590696, 0.9356930669735002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 336}], {
             RGBColor[
             0.21101362554134806`, 0.339119077853518, 0.9353282858566712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 367}], {
             RGBColor[
             0.21516769270569408`, 0.3434852658263162, 0.935564853836289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 267}], {
             RGBColor[
             0.6900764896095811, 0.7567221842679797, 0.9704893279445472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 272}], {
             RGBColor[
             0.7279854810242253, 0.7874270577614837, 0.9735224474035349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 291}], {
             RGBColor[
             0.7527228069990448, 0.8067520448236535, 0.9759880328732503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 321}], {
             RGBColor[
             0.813370248803728, 0.8541302872991015, 0.9820328030897745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 338}], {
             RGBColor[
             0.9016212039882432, 0.9204360205910522, 0.8006477894997438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 342}], {
             RGBColor[
             0.706156116764429, 0.7697763499712335, 0.9717551750957918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 384}], {
             RGBColor[
             0.7786909364224193, 0.827038544894287, 0.9785762933282055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 398}], {
             RGBColor[
             0.8741897182555676, 0.9025122258100744, 0.9845069042800476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 264}], {
             RGBColor[
             0.1847396920189574, 0.3115035078578844, 0.9338320242113725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 295}], {
             RGBColor[
             0.2109178597842839, 0.3390184219709439, 0.935322832138479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 310}], {
             RGBColor[
             0.18101326007132248`, 0.3075867916114884, 0.9336198094247166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 381}], {
             RGBColor[
             0.5862976993087463, 0.6486880635605781, 0.8483828425372609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 269}], {
             RGBColor[
             0.965850894705439, 0.9706613010892211, 0.7373156259818411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 298}], {
             RGBColor[
             0.8810364966451805, 0.9079026895445534, 0.9858832537094278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 300}], {
             RGBColor[
             0.9143198191766551, 0.7735717057130247, 0.6093343830407926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 306}], {
             RGBColor[
             0.9545094880958191, 0.9327471750686342, 0.664081522635275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 307}], {
             RGBColor[
             0.9619414175862754, 0.970962445386637, 0.9415105792405329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 314}], {
             RGBColor[
             0.9322274207027686, 0.9487209428474576, 0.9907658897447179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 310}], {
             RGBColor[
             0.18630458251799184`, 0.3131483069921579, 0.9339211424102444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 333}], {
             RGBColor[
             0.19279573500831393`, 0.31997091982232506`, 0.9342908039417687]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 381}], {
             RGBColor[
             0.5915890217554157, 0.6542495789412477, 0.8486841755227887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 322}], {
             RGBColor[
             0.5501554119867256, 0.6456799735265193, 0.9577293957987232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 362}], {
             RGBColor[
             0.4982768620774518, 0.6022414244020411, 0.9540103792474512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 273}], {
             RGBColor[
             0.265217664230201, 0.3960909592500517, 0.938415125672312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 365}], {
             RGBColor[
             0.25561932448523794`, 0.3860024956082064, 0.9378685144233075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 272}], {
             RGBColor[
             0.6091079366672787, 0.6934689353256587, 0.9624191392814057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 291}], {
             RGBColor[
             0.6338452626420983, 0.7127939223878283, 0.964884724751121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 321}], {
             RGBColor[
             0.6944927044467815, 0.7601721648632764, 0.9709294949676452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 331}], {
             RGBColor[
             0.511645707636986, 0.6143827846807824, 0.9547069650679356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 342}], {
             RGBColor[
             0.5872785724074823, 0.6758182275354083, 0.9606518669736626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 346}], {
             RGBColor[
             0.4581154785924594, 0.5680175907899552, 0.9512960662081413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 384}], {
             RGBColor[
             0.6598133920654725, 0.7330804224584619, 0.9674729852060762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 398}], {
             RGBColor[
             0.7553121738986209, 0.8085541033742493, 0.9734035961579184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 338}], {
             RGBColor[
             0.9058036870049794, 0.5621593672391498, 0.39196047146640556`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 381}], {
             RGBColor[
             0.9052330145226024, 0.5627805673219706, 0.46372649692433865`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 279}], {
             RGBColor[
             0.9693542844710024, 0.9048940200148108, 0.380506034096984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 298}], {
             RGBColor[
             0.908244530929823, 0.9248034643520736, 0.7344530675019115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 300}], {
             RGBColor[
             0.9415278534612976, 0.7904724805205449, 0.35790419683327634`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 306}], {
             RGBColor[
             0.9817175223804617, 0.9496479498761543, 0.4126513364277588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 307}], {
             RGBColor[
             0.9891494518709179, 0.9878632201941573, 0.6900803930330166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 314}], {
             RGBColor[
             0.9594354549874111, 0.9656217176549777, 0.7393357035372017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 308}], {
             RGBColor[
             0.2553377632908749, 0.38570655694091993`, 0.9378524799298211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 397}], {
             RGBColor[
             0.2494683482405557, 0.3795374295806264, 0.9375182254257268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 273}], {
             RGBColor[
             0.2911126400044641, 0.42330822062509427`, 0.9398898062344726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 326}], {
             RGBColor[
             0.3230890593454866, 0.4540841958078278, 0.941814555867055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 335}], {
             RGBColor[
             0.2936530311811995, 0.4259783328219468, 0.9400344777538158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 394}], {
             RGBColor[
             0.3328279171819992, 0.4625195049765876, 0.9424351072766638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 291}], {
             RGBColor[
             0.6717542540567425, 0.7434987958813325, 0.9679178442101087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 321}], {
             RGBColor[
             0.7324016958614257, 0.7908770383567805, 0.9739626144266329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 331}], {
             RGBColor[
             0.5495546990516302, 0.6450876581742866, 0.9577400845269233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 338}], {
             RGBColor[
             0.8206526510459409, 0.8571827716487312, 0.7925776008366022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 342}], {
             RGBColor[
             0.6251875638221265, 0.7065231010289125, 0.9636849864326502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 346}], {
             RGBColor[
             0.4960244700071036, 0.5987224642834593, 0.954329185667129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 384}], {
             RGBColor[
             0.6977223834801167, 0.763785295951966, 0.9705061046650639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 398}], {
             RGBColor[
             0.7932211653132651, 0.8392589768677534, 0.976436715616906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 365}], {
             RGBColor[
             0.26583905724777945`, 0.3967440827101195, 0.9384505130853945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 394}], {
             RGBColor[
             0.3171526741702776, 0.4460438307034582, 0.9415424253765902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 287}], {
             RGBColor[
             0.2454706833388167, 0.37533563030230443`, 0.937290564323588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 299}], {
             RGBColor[
             0.22242833776812287`, 0.35111666413841447`, 0.9359783368314325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 318}], {
             RGBColor[
             0.2272727207343431, 0.3562084177875322, 0.9362542172747363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 367}], {
             RGBColor[
             0.22502133411732347`, 0.3538420677068884, 0.9361260041375251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 373}], {
             RGBColor[
             0.24052488712014738`, 0.3701372848948911, 0.9370089085455846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 395}], {
             RGBColor[
             0.2518980358087536, 0.3820911852658918, 0.9376565925383351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 279}], {
             RGBColor[
             0.9688751403565641, 0.9066136951652177, 0.5278514920501343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 281}], {
             RGBColor[
             0.8120473445077586, 0.8515608457173255, 0.8723741943555676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 306}], {
             RGBColor[
             0.9812383782660234, 0.9513676250265612, 0.559996794380909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 338}], {
             RGBColor[
             0.9931945073855819, 0.9905965803379274, 0.7001396493067182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 384}], {
             RGBColor[
             0.8702642398197578, 0.8971991046411623, 0.8780681531351799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 322}], {
             RGBColor[
             0.6369911357289768, 0.7142897496435541, 0.9658558315605028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 358}], {
             RGBColor[
             0.8670714087363368, 0.8612246187195758, 0.654847436421338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 376}], {
             RGBColor[
             0.6019797217390458, 0.6854606658855094, 0.9632115739949887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 377}], {
             RGBColor[
             0.590222766132432, 0.6752773818608311, 0.9624624311800029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 287}], {
             RGBColor[
             0.25901311175833214`, 0.3895695812107696, 0.9380617855878519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 330}], {
             RGBColor[
             0.24129239010618297`, 0.3709439791957144, 0.9370526167052204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 396}], {
             RGBColor[
             0.26805617252313807`, 0.399074411437749, 0.9385767745203981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 284}], {
             RGBColor[
             0.24820685681048946`, 0.3782115221044505, 0.9374463853549939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 327}], {
             RGBColor[
             0.28550387867049365`, 0.4165027145117478, 0.9396037276662406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 337}], {
             RGBColor[
             0.26857947792754067`, 0.39962443859725516`, 0.9386065759890179]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 354}], {
             RGBColor[
             0.2660945297513849, 0.3970126005093012, 0.9384650618665371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 392}], {
             RGBColor[
             0.2501824179205401, 0.3802879620889227, 0.9375588906376304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 300}], {
             RGBColor[
             0.9178232089422185, 0.7078044246386144, 0.2525247911559355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 306}], {
             RGBColor[
             0.9580128778613826, 0.8669798939942239, 0.307271930750418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 363}], {
             RGBColor[
             0.9040810668165558, 0.6454045668048165, 0.24105801091555495`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 384}], {
             RGBColor[
             0.6902109435663115, 0.7577585241609326, 0.9698659918101223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 386}], {
             RGBColor[
             0.4856785944575267, 0.5902406468075978, 0.9535084650798691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 350}], {
             RGBColor[
             0.5398022619922347, 0.6366471769552697, 0.9571158788344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 369}], {
             RGBColor[
             0.25072601947789425`, 0.3808593217920313, 0.9375898479421354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 392}], {
             RGBColor[
             0.24597365109495675`, 0.3758642813040053, 0.9373192075932261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 330}], {
             RGBColor[
             0.23174352854992997`, 0.3609075202673017, 0.9365088231658666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 387}], {
             RGBColor[
             0.2661419288540897, 0.3970624199715206, 0.9384677611753156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 320}], {
             RGBColor[
             0.7180719499645429, 0.7796825319520332, 0.9725343592747207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 343}], {
             RGBColor[
             0.7242252260804207, 0.7844895180203877, 0.9731476603323168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 349}], {
             RGBColor[
             0.5858145101958898, 0.6731289759492968, 0.9614748008949803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 367}], {
             RGBColor[
             0.23976404440825078`, 0.3693375909644736, 0.936965579678708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 373}], {
             RGBColor[
             0.2552675974110747, 0.3856328081524763, 0.9378484840867676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 395}], {
             RGBColor[
             0.2666407460996809, 0.397586708523477, 0.938496168079518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 396}], {
             RGBColor[
             0.2692564543945499, 0.400335983786869, 0.9386451287973171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 341}], {
             RGBColor[
             0.2333048519876323, 0.3625485701939505, 0.9365977382258728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 355}], {
             RGBColor[
             0.2379735788706035, 0.36745569816233453`, 0.9368636153150954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 360}], {
             RGBColor[
             0.2777088570611381, 0.4090678365808599, 0.9391320518865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 374}], {
             RGBColor[
             0.26056485892169184`, 0.3912005658659134, 0.9381501552932011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 375}], {
             RGBColor[
             0.24993566591258726`, 0.38002861008358335`, 0.9375448384758145]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 379}], {
             RGBColor[
             0.23299167582952007`, 0.3622194021952592, 0.9365799033069708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 393}], {
             RGBColor[
             0.23392299503197628`, 0.3631982777260886, 0.9366329405577875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 399}], {
             RGBColor[
             0.23995250394206913`, 0.3695356738835413, 0.9369763121703581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 302}], {
             RGBColor[
             0.9425151711377706, 0.798674033657958, 0.3207346510653094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 340}], {
             RGBColor[
             0.9457657182249508, 0.8088519239369327, 0.40028051736176995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 391}], {
             RGBColor[
             0.8590720492168273, 0.39317080166904056`, 0.2017773713376896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 313}], {
             RGBColor[
             0.34397103520992167`, 0.4699540423686539, 0.9432263147475373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 321}], {
             RGBColor[
             0.6114600904368728, 0.6914542319869668, 0.964754355111318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 331}], {
             RGBColor[
             0.42861309362707734`, 0.5456648518044729, 0.9485318252116084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 342}], {
             RGBColor[
             0.5042459583975736, 0.6071002946590989, 0.9544767271173353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 346}], {
             RGBColor[
             0.3750828645825507, 0.4992996579136456, 0.9451209263518141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 321}], {
             RGBColor[
             0.7571390218362452, 0.8102020254189503, 0.9764281998963484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 331}], {
             RGBColor[
             0.5742920250264498, 0.6644126452364563, 0.9602056699966387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 338}], {
             RGBColor[
             0.8453899770207604, 0.8765077587109009, 0.7950431863063177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 342}], {
             RGBColor[
             0.6499248897969461, 0.7258480880910823, 0.9661505719023658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 384}], {
             RGBColor[
             0.7224597094549363, 0.7831102830141358, 0.9729716901347794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 398}], {
             RGBColor[
             0.8179584912880846, 0.8585839639299231, 0.9789023010866215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 304}], {
             RGBColor[
             0.21505855653612305`, 0.3433705567924642, 0.9355586386928844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 329}], {
             RGBColor[
             0.22307875219905648`, 0.35180029094398246`, 0.9360153769710722]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 353}], {
             RGBColor[
             0.2106991637542155, 0.3387885585772128, 0.9353103777230984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 378}], {
             RGBColor[
             0.20977255736756456`, 0.3378146365146045, 0.93525760886017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 388}], {
             RGBColor[
             0.21719189432910094`, 0.3456128300743124, 0.9356801291242041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 299}], {
             RGBColor[
             0.21267988324051307`, 0.34087042034218046`, 0.9354231767676313]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 330}], {
             RGBColor[
             0.21800150715905772`, 0.3464637844910152, 0.9357262353771553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 336}], {
             RGBColor[
             0.21111881242536762`, 0.33922963593785627`, 0.935334276094106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 341}], {
             RGBColor[
             0.21717163219876068`, 0.3455915332906315, 0.9356789752258563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 368}], {
             RGBColor[
             0.21277052855345546`, 0.3409656943133277, 0.9354283388841056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 393}], {
             RGBColor[
             0.21778977524310467`, 0.34624124082276975`, 0.9357141775577711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 310}], {
             RGBColor[
             0.2124827502833183, 0.3406632211052174, 0.935411950337351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 345}], {
             RGBColor[
             0.22216737223106828`, 0.3508423728127994, 0.9359634752301611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 363}], {
             RGBColor[
             0.5524499218387339, 0.42033901047071287`, 0.5720521832312901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 316}], {
             RGBColor[
             0.27790052377493313`, 0.40942144877130526`, 0.9391373957607753]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 324}], {
             RGBColor[
             0.2907395975741168, 0.42291612937854317`, 0.9398685620199312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 360}], {
             RGBColor[
             0.3059566318031602, 0.4387580388470877, 0.9407407208692202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 374}], {
             RGBColor[
             0.2888126336637139, 0.4208907681321412, 0.9397588242759214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 375}], {
             RGBColor[
             0.2781834406546093, 0.40971881234981117`, 0.9391535074585348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 380}], {
             RGBColor[
             0.28350610283773925`, 0.41531326778055483`, 0.939456625195691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 383}], {
             RGBColor[
             0.2908789334455868, 0.4230625802138626, 0.9398764969916824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 390}], {
             RGBColor[
             0.283910407540538, 0.415738217657595, 0.9394796497504001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 307}], {
             RGBColor[
             0.965939497584164, 0.9739442069028073, 0.9347428726703746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 314}], {
             RGBColor[
             0.9362255007006572, 0.9517027043636277, 0.9839981831745597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 332}], {
             RGBColor[
             0.736930313911651, 0.7933926635631983, 0.9655671808709663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 352}], {
             RGBColor[
             0.970396577990795, 0.974814330666099, 0.7901511578367646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 385}], {
             RGBColor[
             0.76103003285282, 0.8129579010796052, 0.9674643990261943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 306}], {
             RGBColor[
             0.8969031243202032, 0.8868893383314866, 0.6612189641553454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 307}], {
             RGBColor[
             0.9043350538106595, 0.9251046086494896, 0.9386480207606034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 314}], {
             RGBColor[
             0.8746210569271528, 0.9028631061103101, 0.9879033312647884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 336}], {
             RGBColor[
             0.2125676316732109, 0.34075243682778544`, 0.9354167842069347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 367}], {
             RGBColor[
             0.21672169883755696`, 0.34511862480058364`, 0.9356533521865525]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 306}], {
             RGBColor[
             0.9301864468516778, 0.7525583544999579, 0.2846700934867103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 307}], {
             RGBColor[
             0.9376183763421341, 0.7907736248179609, 0.5620991500919681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 314}], {
             RGBColor[
             0.9079043794586273, 0.7685321222787813, 0.6113544605961532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 363}], {
             RGBColor[
             0.8762546358068509, 0.5309830273105506, 0.21845617365184725`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 316}], {
             RGBColor[
             0.2555487063727525, 0.3859282714945373, 0.9378644928262717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 324}], {
             RGBColor[
             0.2683877801719362, 0.39942295210177514`, 0.9385956590854276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 372}], {
             RGBColor[
             0.25414770566980416`, 0.3844557309271635, 0.9377847079088335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 380}], {
             RGBColor[
             0.26115428543555863`, 0.39182009050378686`, 0.9381837222611874]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 383}], {
             RGBColor[
             0.2685271160434062, 0.39956940293709464`, 0.9386035940571789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 390}], {
             RGBColor[
             0.26155859013835736`, 0.392245040380827, 0.9382067468158966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 323}], {
             RGBColor[
             0.9087436394185031, 0.9180978599174181, 0.6943707488073377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 340}], {
             RGBColor[
             0.9905275811721996, 0.978922480132596, 0.484619975557615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 313}], {
             RGBColor[
             0.2862100467675046, 0.4181552842906852, 0.9396106108023645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 344}], {
             RGBColor[
             0.3051201948561256, 0.4369324167818024, 0.9407277420647475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 315}], {
             RGBColor[
             0.23118633013209117`, 0.360321869401733, 0.9364770915402718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 329}], {
             RGBColor[
             0.2271186296842969, 0.35604645832399684`, 0.9362454420173936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 353}], {
             RGBColor[
             0.21473904123945592`, 0.3430347259572272, 0.9355404427694197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 378}], {
             RGBColor[
             0.21381243485280502`, 0.34206080389461896`, 0.9354876739064912]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 325}], {
             RGBColor[
             0.20723516257555488`, 0.3351476737080805, 0.9351131079805042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 314}], {
             RGBColor[
             0.9555259778682477, 0.9659228619523936, 0.9435306567958934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 352}], {
             RGBColor[
             0.9896970551583855, 0.989034488254865, 0.7496836314580985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 385}], {
             RGBColor[
             0.7803305100204103, 0.8271780586683711, 0.9269968726475282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 386}], {
             RGBColor[
             0.30022575986843436`, 0.4300559235597101, 0.9405124330603728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 397}], {
             RGBColor[
             0.25521896402580857`, 0.3855816913810268, 0.9378457144874233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 319}], {
             RGBColor[
             0.25618706106620875`, 0.38659922275138503`, 0.9379008461817029]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 329}], {
             RGBColor[
             0.25296463724126, 0.3832122509978928, 0.9377173339120208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 334}], {
             RGBColor[
             0.26609474286190404`, 0.39701282450196873`, 0.9384650740028659]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 371}], {
             RGBColor[
             0.2714180274121831, 0.4026079340800466, 0.9387682271829105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 386}], {
             RGBColor[
             0.30507679489801537`, 0.4351546689491852, 0.9407886923288442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 345}], {
             RGBColor[
             0.19226277251810686`, 0.3194107424533439, 0.9342604525163987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 363}], {
             RGBColor[
             0.5225453221257725, 0.38890738011125736`, 0.5703491605175277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 323}], {
             RGBColor[
             0.6747921418079339, 0.7440706990607763, 0.9694867808520644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 339}], {
             RGBColor[
             0.4425672704759462, 0.555957682108388, 0.9499165435038557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 327}], {
             RGBColor[
             0.39077465425622554`, 0.5126293712413812, 0.9461931090416965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 356}], {
             RGBColor[
             0.4906677898927829, 0.5973852420238213, 0.9530463122771483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 361}], {
             RGBColor[
             0.40929184788600736`, 0.528668033662285, 0.9473730082456748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 344}], {
             RGBColor[
             0.30171850127564737`, 0.43335702114888963`, 0.940534020647694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 359}], {
             RGBColor[
             0.2641882368664749, 0.39500896582131095`, 0.9383565013068491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 385}], {
             RGBColor[
             0.7506165131369036, 0.8049365561291917, 0.9762521831517132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 319}], {
             RGBColor[
             0.24242894961997336`, 0.37213857530674344`, 0.9371173420881417]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 329}], {
             RGBColor[
             0.2392065257950246, 0.3687516035532512, 0.9369338298184597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 334}], {
             RGBColor[
             0.25233663141566864`, 0.38255217705732714`, 0.9376815699093048]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 371}], {
             RGBColor[
             0.25765991596594773`, 0.388147286635405, 0.9379847230893494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 324}], {
             RGBColor[
             0.2671185805915378, 0.39808894287087526`, 0.9385233800469365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 355}], {
             RGBColor[
             0.2426003366300466, 0.37231871392089444`, 0.937127102324821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 380}], {
             RGBColor[
             0.25988508585516024`, 0.3904860812728869, 0.9381114432226962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 383}], {
             RGBColor[
             0.2672579164630078, 0.3982353937061947, 0.9385313150186878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 390}], {
             RGBColor[
             0.26028939055795897`, 0.3909110311499271, 0.9381344677774055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 333}], {
             RGBColor[
             0.5930937593564782, 0.6566344401985723, 0.8697228003417041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 370}], {
             RGBColor[
             0.9109218435003366, 0.9293228266692952, 0.8943803638429948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 381}], {
             RGBColor[
             0.99188704610358, 0.9909130993174948, 0.7841161719227241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 382}], {
             RGBColor[
             0.9447039927210837, 0.8118308485146293, 0.5211250046258997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 367}], {
             RGBColor[
             0.22156608180377718`, 0.3502103784497014, 0.9359292326298564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 373}], {
             RGBColor[
             0.2370696348066011, 0.3665055956377041, 0.9368121370379159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 329}], {
             RGBColor[
             0.2383612491721791, 0.3678631642290072, 0.9368856925652633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 334}], {
             RGBColor[
             0.25149135479282314`, 0.3816637377330832, 0.9376334326561084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 371}], {
             RGBColor[
             0.2568146393431022, 0.387258847311161, 0.937936585836153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 388}], {
             RGBColor[
             0.23247439130222355`, 0.3616757033593372, 0.9365504447183952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 343}], {
             RGBColor[
             0.7160472963068527, 0.7781008571267078, 0.9723325607195863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 349}], {
             RGBColor[
             0.5776365804223218, 0.666740315055617, 0.9606597012822499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 331}], {
             RGBColor[
             0.634939466831133, 0.7117908877119044, 0.9662504402131629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 338}], {
             RGBColor[
             0.9060374188254435, 0.923886001186349, 0.8010879565228419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 342}], {
             RGBColor[
             0.7105723316016292, 0.7732263305665302, 0.9721953421188899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 384}], {
             RGBColor[
             0.7831071512596195, 0.8304885254895837, 0.9790164603513036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 398}], {
             RGBColor[
             0.8786059330927678, 0.9059622064053712, 0.9849470713031456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 328}], {
             RGBColor[
             0.4089266558730876, 0.5271174055758985, 0.947690784031411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 362}], {
             RGBColor[
             0.45653757665465905`, 0.5683555921624378, 0.9507245098029286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 364}], {
             RGBColor[
             0.428972946302528, 0.5444804947900268, 0.9489681159313363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 340}], {
             RGBColor[
             0.9119941865056833, 0.9282757501963927, 0.7739166151037982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 375}], {
             RGBColor[
             0.267401497471214, 0.3983863064493811, 0.938539491744696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 380}], {
             RGBColor[
             0.27272415965434393`, 0.4039807618801248, 0.9388426094818522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 383}], {
             RGBColor[
             0.2800969902621915, 0.41173007431343256`, 0.9392624812778436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 390}], {
             RGBColor[
             0.27312846435714266`, 0.404405711757165, 0.9388656340365613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 335}], {
             RGBColor[
             0.3099542075105004, 0.4402786337315509, 0.9410665454863245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 337}], {
             RGBColor[
             0.312066783946898, 0.44249908551128714`, 0.9411868535891006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 354}], {
             RGBColor[
             0.3095818357707423, 0.4398872474233331, 0.94104533946662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 337}], {
             RGBColor[
             0.3016677329619616, 0.43349195021963505`, 0.9405242352558603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 354}], {
             RGBColor[
             0.2991827847858058, 0.430880112131681, 0.9403827211333795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 356}], {
             RGBColor[
             0.4184852693414719, 0.5351260969165677, 0.9483745901685348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 392}], {
             RGBColor[
             0.28327067295496094`, 0.4141554737113025, 0.9394765499044728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 347}], {
             RGBColor[
             0.29474363512034735`, 0.42706072191761096`, 0.940098925902251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 362}], {
             RGBColor[
             0.35704810596381387`, 0.4836788564514203, 0.9439717674801389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 372}], {
             RGBColor[
             0.2804573452843499, 0.4120449254968854, 0.9392853428307628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 387}], {
             RGBColor[
             0.30150296805800375`, 0.4341652094015489, 0.9404838599135137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 334}], {
             RGBColor[
             0.2482689309678744, 0.37827676597959103`, 0.9374499203864265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 353}], {
             RGBColor[
             0.22275923690238936`, 0.35146446010874544`, 0.9359971810476075]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 371}], {
             RGBColor[
             0.25359221551815353`, 0.38387187555766883`, 0.9377530735664711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 388}], {
             RGBColor[
             0.22925196747727483`, 0.358288731605845, 0.9363669324487132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 342}], {
             RGBColor[
             0.5277253347918338, 0.6274369503840362, 0.9559728122191802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 346}], {
             RGBColor[
             0.3985622409768109, 0.5196363136385831, 0.946617011453659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 361}], {
             RGBColor[
             0.4414240641856033, 0.5547544143941453, 0.9499025740169657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 385}], {
             RGBColor[
             0.5513213263478973, 0.6466265153287621, 0.9578211808481198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 381}], {
             RGBColor[
             0.5943537422981029, 0.6571554755250186, 0.8488416222676571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 371}], {
             RGBColor[
             0.26672232113879757`, 0.3976724490617448, 0.9385008136573162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 388}], {
             RGBColor[
             0.24238207309791887`, 0.372089305109921, 0.9371146725395583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 337}], {
             RGBColor[
             0.282630755782611, 0.41439322252540617`, 0.9394067754758614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 354}], {
             RGBColor[
             0.28014580760645524`, 0.41178138443745216`, 0.9392652613533807]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 367}], {
             RGBColor[
             0.21516062802241154`, 0.34347784039625945`, 0.9355644515130273]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 354}], {
             RGBColor[
             0.28225838404285286`, 0.4140018362171884, 0.9393855694561568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 384}], {
             RGBColor[
             0.8713581064441347, 0.8967942587815345, 0.7976314467612728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 398}], {
             RGBColor[
             0.966856888277283, 0.9722679396973218, 0.803562057713115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 360}], {
             RGBColor[
             0.3380761124684098, 0.46724626924582036`, 0.942762888830887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 374}], {
             RGBColor[
             0.3209321143289635, 0.44937899853087393`, 0.9417809922375882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 368}], {
             RGBColor[
             0.2171826090564914, 0.3456030706640795, 0.9356796003416652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 379}], {
             RGBColor[
             0.2212705365436844, 0.3498997416426921, 0.9359124017645142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 393}], {
             RGBColor[
             0.2222018557461406, 0.35087861717352153`, 0.9359654390153307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 399}], {
             RGBColor[
             0.22823136465623345`, 0.3572160133309742, 0.9363088106279014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 346}], {
             RGBColor[
             0.4741951057473072, 0.5810717564932091, 0.9525619133593859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 398}], {
             RGBColor[
             0.7713918010534688, 0.8216082690775031, 0.9746694433091629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 349}], {
             RGBColor[
             0.5837898565381997, 0.6715473011239714, 0.9612730023398459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 349}], {
             RGBColor[
             0.3830038950089686, 0.5061604563464437, 0.9456256474062932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 362}], {
             RGBColor[
             0.3423545559019188, 0.4682989085041503, 0.9431326516737686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 372}], {
             RGBColor[
             0.26576379522245486`, 0.3966649775496154, 0.9384462270243925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 387}], {
             RGBColor[
             0.2868094179961087, 0.41878526145427897`, 0.9396447441071433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 351}], {
             RGBColor[
             0.2543498568494185, 0.38466820463406326`, 0.9377962201194567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 369}], {
             RGBColor[
             0.2602045857942335, 0.3908218959663191, 0.9381296382715687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 357}], {
             RGBColor[
             0.5542164267531839, 0.6479076320182329, 0.9585525480697432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 394}], {
             RGBColor[
             0.3958053510234857, 0.5172484341263308, 0.9464413448636552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 378}], {
             RGBColor[
             0.20945304207089746`, 0.33747880567936756`, 0.9352394129367053]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 375}], {
             RGBColor[
             0.24288325350972279`, 0.37261607749940034`, 0.9371432140225805]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 379}], {
             RGBColor[
             0.2259392634266556, 0.3548068696110762, 0.9361782788537368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 366}], {
             RGBColor[
             0.934928559139148, 0.7751416322731404, 0.28588252947049914`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 391}], {
             RGBColor[
             0.8944837314108928, 0.5317010026573729, 0.24979314294089291`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 374}], {
             RGBColor[
             0.293247724709362, 0.42540017170025574`, 0.9400169674113716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 375}], {
             RGBColor[
             0.2826185317002574, 0.4142282159179257, 0.939411650593985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 369}], {
             RGBColor[
             0.30654023496768024`, 0.43518917662023243`, 0.9409270894573605]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 385}], {
             RGBColor[
             0.46552378312677223`, 0.5743196519105522, 0.9517997921721937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 377}], {
             RGBColor[
             0.3822045767059832, 0.5054681270073037, 0.9455747155508364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 387}], {
             RGBColor[
             0.3215492584874442, 0.4515282986156772, 0.941761191813439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 382}], {
             RGBColor[
             0.9000306839899277, 0.6389445090727658, 0.23829549106007777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 393}], {
             RGBColor[
             0.21780075210083538`, 0.3462527781962177, 0.93571480267358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 399}], {
             RGBColor[
             0.22383026101092823`, 0.35259017435367035`, 0.9360581742861507]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 392}], {
             RGBColor[
             0.2527015805879449, 0.38293576177650346`, 0.937702353224772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 389}], {
             RGBColor[
             0.505152375234491, 0.5869084718259839, 0.9586367768062234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 391}], {
             RGBColor[
             0.8258037070409253, 0.5129958576116641, 0.5754614637475668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 400}], {
             RGBColor[
             0.6104137657145253, 0.6900683539569277, 0.9649050090474223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 395}], {
             RGBColor[
             0.2616949498810116, 0.3923883631160637, 0.9382145123015146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 375}], {
             RGBColor[
             0.26547453356081113`, 0.3963609452029792, 0.9384297540006862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 399}], {
             RGBColor[
             0.255491371590293, 0.38586800900293716`, 0.9378612276952298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 379}], {
             RGBColor[
             0.23790135046863936`, 0.36737978153232503`, 0.9368595020144559]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 383}], {
             RGBColor[
             0.26754083334268397`, 0.3985327572847006, 0.9385474267164473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 399}], {
             RGBColor[
             0.24486217858118842`, 0.3746960532206071, 0.9372559108778432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 377}], {
             RGBColor[
             0.4266363429774569, 0.5439526897461481, 0.9484058684081864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 393}], {
             RGBColor[
             0.22188867958802838`, 0.35054944917483033`, 0.9359476040964289]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 399}], {
             RGBColor[
             0.22791818849812123`, 0.356886845332283, 0.9362909757089996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 383}], {
             RGBColor[
             0.2728634955258139, 0.4041272127154443, 0.9388505444536035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 390}], {
             RGBColor[
             0.2658949696207651, 0.39680285015917666`, 0.9384536972123212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 390}], {
             RGBColor[
             0.27326780022861263`, 0.40455216259248444`, 0.9388735690083126]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 398}], {
             RGBColor[
             0.8439266207114591, 0.8788704640005567, 0.9814905615415767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 400}], {
             RGBColor[
             0.2843495171102985, 0.40872323643536973`, 0.9397784081644269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 399}], {
             RGBColor[
             0.22884950770057744`, 0.3578657208631124, 0.9363440129598162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 396}], {
             RGBColor[
             0.2756838068644868, 0.4070915387504564, 0.9390111570120642]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.03217915333176364], {
             RGBColor[
             0.3599830334006432, 0.48622094308345976`, 0.9441587784611594]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.03217915333176364], {
             RGBColor[
             0.8184511944421836, 0.14282954261339104`, 0.16530219067646573`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.03217915333176364], {
             RGBColor[
             0.370079657849583, 0.49496613171003123`, 0.9448021264429514]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.03217915333176364], {
             RGBColor[
             0.23219649750384544`, 0.36138361935775737`, 0.9365346190776845]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.03217915333176364], {
             RGBColor[
             0.8414430264446411, 0.8764078451972013, 0.9847387810989889]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.03217915333176364], {
             RGBColor[
             0.9933475429680663, 0.9881793920123014, 0.5172992901589675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.03217915333176364], {
             RGBColor[
             0.38940499419392427`, 0.5117047667318526, 0.9460335197860889]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.03217915333176364], {
             RGBColor[
             0.3103199544645186, 0.44320528024791445`, 0.9409942909866859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.03217915333176364], {
             RGBColor[
             0.8256674379376745, 0.1982967522977973, 0.17221247359732916`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.03217915333176364], {
             RGBColor[
             0.3619258765766598, 0.48790373619238797`, 0.9442825747103464]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.03217915333176364], {
             RGBColor[
             0.9234626618564741, 0.7342619893565898, 0.25727446504873397`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.03217915333176364], {
             RGBColor[
             0.218436984339963, 0.3469214986189947, 0.935751035158377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.03217915333176364], {
             RGBColor[
             0.9637801291888717, 0.9725078601704316, 0.9461949730147088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.03217915333176364], {
             RGBColor[
             0.9943570777774785, 0.9903386848900081, 0.6271809240368398]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.03217915333176364], {
             RGBColor[
             0.3038609163605336, 0.43670746736272875`, 0.940615801713566]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.03217915333176364], {
             RGBColor[
             0.2418605106508593, 0.3715411099090923, 0.9370849703297808]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.03217915333176364], {
             RGBColor[
             0.5355166046173245, 0.6337955302332828, 0.9565769752588857]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.03217915333176364], {
             RGBColor[
             0.9452065658445834, 0.95865572703968, 0.9776351709954327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.03217915333176364], {
             RGBColor[
             0.2743841090042405, 0.40572547389373365`, 0.9389371411416538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.03217915333176364], {
             RGBColor[
             0.4076589804310767, 0.5275154521384491, 0.9471966476477539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.03217915333176364], {
             RGBColor[
             0.31291714185714126`, 0.44545483342897024`, 0.9411597814707411]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.03217915333176364], {
             RGBColor[
             0.29231839668471055`, 0.42457554734542235`, 0.9399584722936555]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.03217915333176364], {
             RGBColor[
             0.21341792784235675`, 0.34164615201344867`, 0.935465207315867]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.03217915333176364], {
             RGBColor[
             0.9021530244270525, 0.6485815613125467, 0.24006642394413927`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.03217915333176364], {
             RGBColor[
             0.8487111149297029, 0.3754205514621725, 0.19427912470900624`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.03217915333176364], {
             RGBColor[
             0.45511285367532656`, 0.5685201430708667, 0.9502472974560874]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.03217915333176364], {
             RGBColor[
             0.2974167180204977, 0.42993420632157753`, 0.9402488141514381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.03217915333176364], {
             RGBColor[
             0.2882891132658928, 0.42034051500092084`, 0.9397290105637445]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.03217915333176364], {
             RGBColor[
             0.2404292095299187, 0.3700367216812511, 0.9370034598483634]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.03217915333176364], {
             RGBColor[
             0.17892703208317115`, 0.3053940337214471, 0.9335010018270892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.03217915333176364], {
             RGBColor[
             0.183217413291963, 0.30990349639776743`, 0.9337453326898797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.03217915333176364], {
             RGBColor[
             0.21628540957162948`, 0.3446600571197567, 0.9356285061582901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.03217915333176364], {
             RGBColor[
             0.17894138666990014`, 0.3054091213022326, 0.9335018192995677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.03217915333176364], {
             RGBColor[
             0.3122890105436297, 0.4449107776560043, 0.9411197574988789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.03217915333176364], {
             RGBColor[
             0.28104105066772134`, 0.4127223416565313, 0.9393162441213263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.03217915333176364], {
             RGBColor[
             0.5196772960404508, 0.620936465977857, 0.9553300468664151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.03217915333176364], {
             RGBColor[
             0.24979952597607638`, 0.3798855183785399, 0.9375370855078312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.03217915333176364], {
             RGBColor[
             0.9657912116144293, 0.896267865549297, 0.32160574622002847`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.03217915333176364], {
             RGBColor[
             0.27309206457306523`, 0.40436745327622, 0.9388635611227067]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.03217915333176364], {
             RGBColor[
             0.3393121311221928, 0.4683168464796233, 0.9428416468465376]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.03217915333176364], {
             RGBColor[
             0.34082031608406577`, 0.4696231604900174, 0.9429377470586726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.03217915333176364], {
             RGBColor[
             0.9322258626950144, 0.9487956145888052, 0.9933977290633442]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.03217915333176364], {
             RGBColor[
             0.2274352478585693, 0.35637924409990884`, 0.9362634729540237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.03217915333176364], {
             RGBColor[
             0.29795654320818293`, 0.4305015968207284, 0.940279556397277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.03217915333176364], {
             RGBColor[
             0.2954990939280613, 0.427918661816037, 0.9401396082962444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.03217915333176364], {
             RGBColor[
             0.2843163130979401, 0.41616485013432336`, 0.9395027654714108]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.03217915333176364], {
             RGBColor[
             0.43389191818712153`, 0.5502371043169462, 0.948868187244693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.03217915333176364], {
             RGBColor[
             0.4254428949511675, 0.5429189850502182, 0.948329822955276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.03217915333176364], {
             RGBColor[
             0.2557363986193865, 0.3861255479461254, 0.9378751816220516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.03217915333176364], {
             RGBColor[
             0.45414763221898446`, 0.5677365328098771, 0.9501713116873214]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.03217915333176364], {
             RGBColor[
             0.3729233885884314, 0.4974292283459589, 0.9449833264510183]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.03217915333176364], {
             RGBColor[
             0.38664548537965426`, 0.5093146188938776, 0.9458576863245813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.03217915333176364], {
             RGBColor[
             0.28924396052189333`, 0.4213441200077901, 0.9397833877024038]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.03217915333176364], {
             RGBColor[
             0.4519914858020445, 0.5659140400742732, 0.9500214756882968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.03217915333176364], {
             RGBColor[
             0.4035326533159193, 0.5239414349865308, 0.9469337217327439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.03217915333176364], {
             RGBColor[
             0.45093503134871465`, 0.5649989923257436, 0.9499541593447165]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.03217915333176364], {
             RGBColor[
             0.2732074233744939, 0.404488702690692, 0.9388701306357901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.03217915333176364], {
             RGBColor[
             0.2988109928106687, 0.43139967752817476`, 0.9403282160380936]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.03217915333176364], {
             RGBColor[
             0.3340181926444761, 0.4637315030513096, 0.9425043217679835]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.03217915333176364], {
             RGBColor[
             0.35752834255750565`, 0.4840948132514831, 0.9440023677312325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.03217915333176364], {
             RGBColor[
             0.9933459036684309, 0.98817588571614, 0.5171208625102379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.03217915333176364], {
             RGBColor[
             0.1790682590797859, 0.30554247224919795`, 0.9335090444956198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.03217915333176364], {
             RGBColor[
             0.9585610528033711, 0.8718788421575785, 0.2935179445399928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.03217915333176364], {
             RGBColor[
             0.3989602722595878, 0.5199810683300905, 0.9466423736550322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.03217915333176364], {
             RGBColor[
             0.5153321861178936, 0.6174089099977538, 0.9549879838966494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.03217915333176364], {
             RGBColor[
             0.9727828870163496, 0.9198524284034268, 0.3487670848893771]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.03217915333176364], {
             RGBColor[
             0.2129458677257866, 0.3411499869005934, 0.9354383241905787]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.03217915333176364], {
             RGBColor[
             0.2767246225454214, 0.4081855020226443, 0.9390704299253445]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.03217915333176364], {
             RGBColor[
             0.48821862164434726`, 0.5953968969059689, 0.9528535047810326]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.03217915333176364], {
             RGBColor[
             0.2778101351361315, 0.409326444580954, 0.9391322482615135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.03217915333176364], {
             RGBColor[
             0.871120013048017, 0.9000714687543917, 0.9875693985741776]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.03217915333176364], {
             RGBColor[
             0.22772650909910638`, 0.3566853781307425, 0.9362800598507899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.03217915333176364], {
             RGBColor[
             0.24311597663730303`, 0.3728606842619857, 0.9371564672604132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.03217915333176364], {
             RGBColor[
             0.8246734764068878, 0.8630362611944062, 0.983139286446034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.03217915333176364], {
             RGBColor[
             0.24417812249459925`, 0.373977066901941, 0.9372169548956822]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.03217915333176364], {
             RGBColor[
             0.8469444359628041, 0.36184108275892934`, 0.19258735093512552`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.03217915333176364], {
             RGBColor[
             0.8293651040061051, 0.8667772376911834, 0.9835867780747127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.03217915333176364], {
             RGBColor[
             0.8418439495844675, 0.3226365094076515, 0.18770311941905493`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.03217915333176364], {
             RGBColor[
             0.590805957298975, 0.6786819174972005, 0.9609295556335575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.03217915333176364], {
             RGBColor[
             0.3344163982055418, 0.46407640869391137`, 0.9425296950742152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.03217915333176364], {
             RGBColor[
             0.2197154470497895, 0.34826524398623987`, 0.9358238417183856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.03217915333176364], {
             RGBColor[
             0.37921715493462604`, 0.5028805724211383, 0.9453843596772389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.03217915333176364], {
             RGBColor[
             0.35288166901045503`, 0.480070098173631, 0.9437062858017065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.03217915333176364], {
             RGBColor[
             0.17892701429477148`, 0.30539401502471114`, 0.9335010008140661]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.03217915333176364], {
             RGBColor[
             0.2413074662041341, 0.37095982513054093`, 0.9370534752666957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.03217915333176364], {
             RGBColor[
             0.30053635500276704`, 0.4332131425863514, 0.940426472862489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.03217915333176364], {
             RGBColor[
             0.29013871681338543`, 0.4222845656009737, 0.9398343427495309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.03217915333176364], {
             RGBColor[
             0.9903137669558371, 0.9902625079584733, 0.8101894789167451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.03217915333176364], {
             RGBColor[
             0.21858282554203126`, 0.3470747869692347, 0.9357593405990821]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.03217915333176364], {
             RGBColor[
             0.7058058015575851, 0.7701001235903371, 0.9713117842351892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.03217915333176364], {
             RGBColor[
             0.26262121251507564`, 0.39336192387290797`, 0.9382672615882417]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.03217915333176364], {
             RGBColor[
             0.28766384187052196`, 0.4196833151198899, 0.9396934022827843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.03217915333176364], {
             RGBColor[
             0.2452381115380016, 0.3750911825937439, 0.9372773197035907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.03217915333176364], {
             RGBColor[
             0.26012396818175015`, 0.3907371617441472, 0.9381250472178008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.03217915333176364], {
             RGBColor[
             0.2817785304161579, 0.4134974796310549, 0.9393582425019963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.03217915333176364], {
             RGBColor[
             0.2869114883454893, 0.4188925438631119, 0.939650556862541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.03217915333176364], {
             RGBColor[
             0.44228444757308333`, 0.5575062914502744, 0.9494029517959442]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.03217915333176364], {
             RGBColor[
             0.9775701021325132, 0.9360008290818089, 0.3673645116259542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.03217915333176364], {
             RGBColor[
             0.9781276011086575, 0.9832081812363787, 0.921908445474496]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.03217915333176364], {
             RGBColor[
             0.37661408553666426`, 0.5006259245426959, 0.9452184943970047]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.03217915333176364], {
             RGBColor[
             0.2608418322510304, 0.39149168239617155`, 0.9381659285145616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.03217915333176364], {
             RGBColor[
             0.819297035403237, 0.14933104688991955`, 0.16611216893601113`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.03217915333176364], {
             RGBColor[
             0.34456615692423104`, 0.4728676195543337, 0.943176428724691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.03217915333176364], {
             RGBColor[
             0.9338740873595025, 0.7755398220742175, 0.265651742396037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.03217915333176364], {
             RGBColor[
             0.417344109662346, 0.5359042242898253, 0.9478137755181469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.03217915333176364], {
             RGBColor[
             0.948494816832878, 0.9611080992427333, 0.9720690197854612]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.03217915333176364], {
             RGBColor[
             0.8392176796973624, 0.30244984821655896`, 0.1851882004092155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.03217915333176364], {
             RGBColor[
             0.3675690787260941, 0.49279159425864094`, 0.9446421545612206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.03217915333176364], {
             RGBColor[
             0.9940964498066649, 0.9918267445278057, 0.7475006348091123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.03217915333176364], {
             RGBColor[
             0.25557794384056287`, 0.3859590019269685, 0.9378661578568105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.03217915333176364], {
             RGBColor[
             0.8740781517963572, 0.5211001217496539, 0.21664006204298622`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.03217915333176364], {
             RGBColor[
             0.3289211710833394, 0.45931671915880556`, 0.9421795440612271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.03217915333176364], {
             RGBColor[
             0.7965156452550962, 0.8409633429071789, 0.9803528937232722]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.03217915333176364], {
             RGBColor[
             0.3288778807819878, 0.45927922327560866`, 0.9421767856415051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.03217915333176364], {
             RGBColor[
             0.2386060995532787, 0.36812051750395375`, 0.9368996364322433]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.03217915333176364], {
             RGBColor[
             0.4162213411164948, 0.534931738607397, 0.9477422336992305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.03217915333176364], {
             RGBColor[
             0.3495171154366807, 0.47715589097540734`, 0.9434918994231435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.03217915333176364], {
             RGBColor[
             0.20606162213947596`, 0.33391420830300045`, 0.935046276588767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.03217915333176364], {
             RGBColor[
             0.24049836738192176`, 0.3701094109685675, 0.9370073982857251]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.03217915333176364], {
             RGBColor[
             0.5663783145126094, 0.6588504566304622, 0.9590065221120109]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.03217915333176364], {
             RGBColor[
             0.5531961411455233, 0.6481485744409189, 0.9579687731366617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.03217915333176364], {
             RGBColor[
             0.44608758599784554`, 0.5608003788025082, 0.9496452844133868]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.03217915333176364], {
             RGBColor[
             0.9742961343763916, 0.9803506796209057, 0.9283941192456544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.03217915333176364], {
             RGBColor[
             0.22327126764014227`, 0.35200263687874755`, 0.936026340440641]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.03217915333176364], {
             RGBColor[
             0.277985958766929, 0.4095112463647842, 0.9391422611571797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.03217915333176364], {
             RGBColor[
             0.21204174778307774`, 0.3401996995162911, 0.935386835897367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.03217915333176364], {
             RGBColor[
             0.21049571798261152`, 0.33857472417205015`, 0.9352987917873766]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.03217915333176364], {
             RGBColor[
             0.3262131529712761, 0.45697116997908427`, 0.9420069915417328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.03217915333176364], {
             RGBColor[
             0.23768447069359533`, 0.36715182713778177`, 0.936847151032112]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.03217915333176364], {
             RGBColor[
             0.4104055903111328, 0.5298944275679272, 0.9473716592005793]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.03217915333176364], {
             RGBColor[
             0.9224661794909306, 0.7303112688352736, 0.2564726719469704]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.03217915333176364], {
             RGBColor[
             0.7992223614262676, 0.8430778501519028, 0.9806226738955138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.03217915333176364], {
             RGBColor[
             0.29725822306554583`, 0.42976761807476255`, 0.9402397880982258]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.03217915333176364], {
             RGBColor[
             0.2343268669145523, 0.36362277268163234`, 0.9366559404640252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.03217915333176364], {
             RGBColor[
             0.5032780494106496, 0.6076228187861427, 0.9540390380992975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.03217915333176364], {
             RGBColor[
             0.6185821135656369, 0.7012318524560568, 0.9631161964022821]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.03217915333176364], {
             RGBColor[
             0.22155609394318862`, 0.3501998805749559, 0.9359286638359716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.03217915333176364], {
             RGBColor[
             0.8193428764107183, 0.14968340096107918`, 0.16615606633654534`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.03217915333176364], {
             RGBColor[
             0.2111706728502173, 0.3392841445325141, 0.9353372294685806]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.03217915333176364], {
             RGBColor[
             0.6719249954084331, 0.7436321803229556, 0.9679348621123766]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.03217915333176364], {
             RGBColor[
             0.3600639473667127, 0.48629102669401497`, 0.9441639342275279]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.03217915333176364], {
             RGBColor[
             0.8215839734950429, 0.16690945520620182`, 0.16830214343545163`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.03217915333176364], {
             RGBColor[
             0.6246442469651912, 0.7061533654458123, 0.9635934297498213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.03217915333176364], {
             RGBColor[
             0.8784381059512442, 0.540897655273832, 0.22027811466207986`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.03217915333176364], {
             RGBColor[
             0.23802405881018981`, 0.36750875577945274`, 0.9368664900729765]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.03217915333176364], {
             RGBColor[
             0.5353312372592116, 0.6336450406612625, 0.9565623824614321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.03217915333176364], {
             RGBColor[
             0.28473783311028583`, 0.41660789439321116`, 0.9395267704125309]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.03217915333176364], {
             RGBColor[
             0.6238880244982119, 0.7055394299796848, 0.9635338971470865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.03217915333176364], {
             RGBColor[
             0.22021863489519794`, 0.34879412631571627`, 0.9358524975217819]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.03217915333176364], {
             RGBColor[
             0.2706007772119499, 0.40174895230294594`, 0.9387216859930206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.03217915333176364], {
             RGBColor[
             0.3158355177641727, 0.44798258395780277`, 0.9413457378029186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.03217915333176364], {
             RGBColor[
             0.18361616608284723`, 0.3103226108633739, 0.9337680410714186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.03217915333176364], {
             RGBColor[
             0.3174307607246093, 0.4493643032308905, 0.9414473852737397]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.03217915333176364], {
             RGBColor[
             0.4301580292792129, 0.547002997415629, 0.9486302671452295]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.03217915333176364], {
             RGBColor[
             0.30454561984188433`, 0.43742713413433654`, 0.9406547945639009]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.03217915333176364], {
             RGBColor[
             0.18595953915049845`, 0.3127856445359093, 0.9339014927009116]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.03217915333176364], {
             RGBColor[
             0.46924384183457235`, 0.5799923158523045, 0.9513597406074984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.03217915333176364], {
             RGBColor[
             0.5031159008708285, 0.6074911792968075, 0.9540262731722731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.03217915333176364], {
             RGBColor[
             0.3314345944952444, 0.46149372018986384`, 0.9423396971785006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.03217915333176364], {
             RGBColor[
             0.8294775817921864, 0.22758318757925894`, 0.17586107165535175`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.03217915333176364], {
             RGBColor[
             0.4314366462475933, 0.5481104711684827, 0.9487117394878181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.03217915333176364], {
             RGBColor[
             0.246083996032968, 0.37598026083012825`, 0.9373254915742051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.03217915333176364], {
             RGBColor[
             0.2449732495734328, 0.3748127958757636, 0.9372622362065367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.03217915333176364], {
             RGBColor[
             0.24253850776538854`, 0.3722537278639624, 0.9371235812624463]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.03217915333176364], {
             RGBColor[
             0.532748774101436, 0.6315484807311408, 0.9563590815017777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.03217915333176364], {
             RGBColor[
             0.8247691039330448, 0.19139176348574266`, 0.17135222793997262`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.03217915333176364], {
             RGBColor[
             0.2835494674254077, 0.415358846711668, 0.9394590947448065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.03217915333176364], {
             RGBColor[
             0.6701504899984683, 0.7422459232099505, 0.9677579959968072]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.03217915333176364], {
             RGBColor[
             0.22069846856058375`, 0.34929846192124825`, 0.9358798233391753]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.03217915333176364], {
             RGBColor[
             0.44496963537099143`, 0.5598320661593594, 0.9495740495880086]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.03217915333176364], {
             RGBColor[
             0.2732125866431092, 0.40449412961337683`, 0.9388704246762993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.03217915333176364], {
             RGBColor[
             0.301424661402258, 0.4341468089340951, 0.9404770605978084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.03217915333176364], {
             RGBColor[
             0.22636761106282094`, 0.3552570901354948, 0.936202672617933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.03217915333176364], {
             RGBColor[
             0.7286053839996127, 0.7879113306772935, 0.9735842335387989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.03217915333176364], {
             RGBColor[
             0.17893214148115075`, 0.3053994040226782, 0.9335012927997455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.03217915333176364], {
             RGBColor[
             0.21582348781243682`, 0.34417454806331416`, 0.935602200397456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.03217915333176364], {
             RGBColor[
             0.3219085007459621, 0.453242696579629, 0.9417327029083903]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.03217915333176364], {
             RGBColor[
             0.24398844376792686`, 0.3737777025338824, 0.9372061529728027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.03217915333176364], {
             RGBColor[
             0.2696431574723743, 0.40074243324005365`, 0.9386671509655232]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.03217915333176364], {
             RGBColor[
             0.36627002209779275`, 0.4916664166996908, 0.9445593798215759]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.03217915333176364], {
             RGBColor[
             0.5673122922146817, 0.6596087018042204, 0.9590800482579911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.03217915333176364], {
             RGBColor[
             0.2880943118622093, 0.4201357663745271, 0.9397179169119876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.03217915333176364], {
             RGBColor[
             0.2589336294896423, 0.3894860403069097, 0.9380572591902335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.03217915333176364], {
             RGBColor[
             0.21776291881025298`, 0.3462130130090464, 0.9357126481236506]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.03217915333176364], {
             RGBColor[
             0.8236904837096025, 0.18310101579396953`, 0.170319339995877]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.03217915333176364], {
             RGBColor[
             0.24846767200989045`, 0.3784856554156597, 0.9374612383947583]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.03217915333176364], {
             RGBColor[
             0.8439338400416576, 0.8783939523481282, 0.9849763571234479]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.03217915333176364], {
             RGBColor[
             0.26708591845739416`, 0.39805461289699134`, 0.9385215199867163]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.03217915333176364], {
             RGBColor[
             0.30054674338696064`, 0.4332240614368005, 0.9404270644656005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.03217915333176364], {
             RGBColor[
             0.2411029859620505, 0.37074490343131483`, 0.9370418304194105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.03217915333176364], {
             RGBColor[
             0.6788533623879274, 0.7490446732648759, 0.968625416983622]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.03217915333176364], {
             RGBColor[
             0.34448974411411554`, 0.4728014346188312, 0.9431715597679996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.03217915333176364], {
             RGBColor[
             0.8223396115770147, 0.8611753007301386, 0.9829166803350949]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.03217915333176364], {
             RGBColor[
             0.3880550588481297, 0.5105355205850486, 0.9459475030995558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.03217915333176364], {
             RGBColor[
             0.24569470610522032`, 0.37557109243365844`, 0.9373033220887227]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.03217915333176364], {
             RGBColor[
             0.29792411608308994`, 0.43046751385625726`, 0.9402777097204745]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.03217915333176364], {
             RGBColor[
             0.988751433892587, 0.9896164430866911, 0.8360813809631582]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.03217915333176364], {
             RGBColor[
             0.8264896291158393, 0.8644844120663722, 0.9833125127127125]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.03217915333176364], {
             RGBColor[
             0.22580276459471169`, 0.35466340068417734`, 0.9361705054471896]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.03217915333176364], {
             RGBColor[
             0.27065965459454444`, 0.40181083616509444`, 0.9387250389728581]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.03217915333176364], {
             RGBColor[
             0.27642628673231373`, 0.407871932167485, 0.9390534401421363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.03217915333176364], {
             RGBColor[
             0.8563396258514921, 0.4340566292418462, 0.20158419538288244`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.03217915333176364], {
             RGBColor[
             0.29139757571829134`, 0.42360770612629445`, 0.9399060329018505]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.03217915333176364], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.03217915333176364], {
             RGBColor[
             0.9952685123171101, 0.9923114224965074, 0.7280765258104895]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.03217915333176364], {
             RGBColor[
             0.23156206990492625`, 0.36071679572626025`, 0.9364984893644777]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.03217915333176364], {
             RGBColor[
             0.9398558182628138, 0.7992553918121872, 0.27046478349011155`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.03217915333176364], {
             RGBColor[
             0.2330867180319017, 0.36231929757598597`, 0.9365853158197941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.03217915333176364], {
             RGBColor[
             0.2520329891677718, 0.3822330298027571, 0.9376642779324855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.03217915333176364], {
             RGBColor[
             0.2999237099233219, 0.432569213763913, 0.9403915836315417]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.03217915333176364], {
             RGBColor[
             0.2626771974737526, 0.39342076761412886`, 0.9382704498488161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.03217915333176364], {
             RGBColor[
             0.21089717481030001`, 0.33899668075178374`, 0.9353216541598114]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.03217915333176364], {
             RGBColor[
             0.9109681137578394, 0.6847252697068382, 0.24722105836383443`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.03217915333176364], {
             RGBColor[
             0.9837730937067766, 0.9874185803724101, 0.9123520990861677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.03217915333176364], {
             RGBColor[
             0.8192881970279116, 0.1492631112641677, 0.166103705297818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.03217915333176364], {
             RGBColor[
             0.6591015742674116, 0.7336144262659793, 0.9666567433347234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.03217915333176364], {
             RGBColor[
             0.8228256695060855, 0.17645367486173685`, 0.16949119293792111`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.03217915333176364], {
             RGBColor[
             0.9100637739514378, 0.9311241665985504, 0.9912838892546516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.03217915333176364], {
             RGBColor[
             0.4471878440862639, 0.5617533670581167, 0.9497153918858607]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.03217915333176364], {
             RGBColor[
             0.4754345148883495, 0.5850181831240037, 0.9518470930674744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.03217915333176364], {
             RGBColor[
             0.9218589159168126, 0.9405292926311409, 0.9924089204249567]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.03217915333176364], {
             RGBColor[
             0.6049269005052089, 0.6901459353332633, 0.9620412080094716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.03217915333176364], {
             RGBColor[
             0.4540671923140028, 0.5676712280712366, 0.9501649791633402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.03217915333176364], {
             RGBColor[
             0.9756615083220127, 0.9295626939998534, 0.3599499850798584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.03217915333176364], {
             RGBColor[
             0.2571081050813221, 0.3875672984088326, 0.9379532982758011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.03217915333176364], {
             RGBColor[
             0.23863402700947722`, 0.3681498710311214, 0.9369012268595588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.03217915333176364], {
             RGBColor[
             0.23492201148043795`, 0.36424830735472313`, 0.9366898330666149]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.03217915333176364], {
             RGBColor[
             0.36785717736282086`, 0.49304113081751505`, 0.9446605119515972]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.03217915333176364], {
             RGBColor[
             0.24689616138342244`, 0.3768338981077132, 0.9373717431894225]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.03217915333176364], {
             RGBColor[
             0.9688572327835747, 0.9066102748888301, 0.333516659492644]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.03217915333176364], {
             RGBColor[
             0.30868412390727973`, 0.44177696430338015`, 0.9408904762480571]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.03217915333176364], {
             RGBColor[
             0.5255566438526651, 0.6257095853934133, 0.9557928906629534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.03217915333176364], {
             RGBColor[
             0.8174582326741875, 0.1351972033459516, 0.16435132936604271`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.03217915333176364], {
             RGBColor[
             0.3387393935852255, 0.4678207700117279, 0.942805152517134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.03217915333176364], {
             RGBColor[
             0.7400936775781565, 0.7968860729351169, 0.9747292792785006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.03217915333176364], {
             RGBColor[
             0.2505222001886238, 0.3806450947961188, 0.9375782407351351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.03217915333176364], {
             RGBColor[
             0.5784190314529432, 0.6686256530707418, 0.9599544114561535]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.03217915333176364], {
             RGBColor[
             0.22922310747734106`, 0.35825839791608494`, 0.9363652889144115]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.03217915333176364], {
             RGBColor[
             0.32451491921663345`, 0.4555002452565231, 0.9418987815885761]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.03217915333176364], {
             RGBColor[
             0.23920651037948798`, 0.3687515873505448, 0.9369338289405676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.03217915333176364], {
             RGBColor[
             0.290961948336973, 0.42314983412815754`, 0.9398812245669373]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.03217915333176364], {
             RGBColor[
             0.9183468399249884, 0.7139794601448493, 0.25315815463888625`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.03217915333176364], {
             RGBColor[
             0.2883719521470624, 0.4204275839173185, 0.939733728115478]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.03217915333176364], {
             RGBColor[
             0.2600361752617328, 0.3906448858188163, 0.9381200475408837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.03217915333176364], {
             RGBColor[
             0.22989884827362161`, 0.3589686443374169, 0.9364037713530907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.03217915333176364], {
             RGBColor[
             0.4438028563584466, 0.5588214608227114, 0.9494997034610714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.03217915333176364], {
             RGBColor[
             0.9070075396154186, 0.6690229130152352, 0.24403428744221908`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.03217915333176364], {
             RGBColor[
             0.21620788903044316`, 0.3445785781158837, 0.9356240914781508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.03217915333176364], {
             RGBColor[
             0.2695692814994847, 0.4006647849085395, 0.938662943838157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.03217915333176364], {
             RGBColor[
             0.9882272169582415, 0.9893996659125786, 0.8447690121952027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.03217915333176364], {
             RGBColor[
             0.822315843269912, 0.8611563485272284, 0.9829144132927453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.03217915333176364], {
             RGBColor[
             0.2243331252717409, 0.35311871657522015`, 0.9360868116618829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.03217915333176364], {
             RGBColor[
             0.34171577858230273`, 0.47039876509873646`, 0.9429948051372339]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.03217915333176364], {
             RGBColor[
             0.46951139015292603`, 0.5802095236300584, 0.951380802991181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.03217915333176364], {
             RGBColor[
             0.26047497796174324`, 0.3911060952782254, 0.938145036705499]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.03217915333176364], {
             RGBColor[
             0.22530836548640581`, 0.35414375587463387`, 0.9361423501493695]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.03217915333176364], {
             RGBColor[
             0.8226071697061851, 0.17477418965247965`, 0.16928195728277629`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.03217915333176364], {
             RGBColor[
             0.2529332615169164, 0.38317927312227185`, 0.9377155471109357]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.03217915333176364], {
             RGBColor[
             0.2110206902246306, 0.3391265032835748, 0.9353286881799328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.03217915333176364], {
             RGBColor[
             0.8089540339665278, 0.8506803067038047, 0.9815926360666765]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.03217915333176364], {
             RGBColor[
             0.17944836957228805`, 0.3059419924772149, 0.9335306912258446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.03217915333176364], {
             RGBColor[
             0.9386428604207964, 0.9537605262817009, 0.9887458121893573]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.03217915333176364], {
             RGBColor[
             0.26208361027682536`, 0.3927968698345563, 0.9382366459360847]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.03217915333176364], {
             RGBColor[
             0.19003101446562676`, 0.31706502323855396`, 0.9341333571969002]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.03217915333176364], {
             RGBColor[
             0.5918946974095183, 0.6795658057661227, 0.9610152652432459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.03217915333176364], {
             RGBColor[
             0.2549979314676595, 0.3853493721481386, 0.937833127010225]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.03217915333176364], {
             RGBColor[
             0.5711989452526345, 0.6627640618321545, 0.9593860198224179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.03217915333176364], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.03217915333176364], {
             RGBColor[
             0.9930589289900814, 0.9875620758967413, 0.48588543977432486`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.03217915333176364], {
             RGBColor[
             0.249587147505622, 0.3796622951405196, 0.9375249908681246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.03217915333176364], {
             RGBColor[
             0.30678788301618565`, 0.43978389489822367`, 0.9407824881345462]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.03217915333176364], {
             RGBColor[
             0.6470169280819229, 0.7241738088191627, 0.9654522587403933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.03217915333176364], {
             RGBColor[
             0.2754373969927425, 0.40683254635196486`, 0.938997124334399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.03217915333176364], {
             RGBColor[
             0.2307279730478894, 0.35984010704471925`, 0.9364509887824051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.03217915333176364], {
             RGBColor[
             0.992100640761205, 0.9910014261975552, 0.7805763556806252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.03217915333176364], {
             RGBColor[
             0.765566144894021, 0.8167853580001923, 0.977268136766805]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.03217915333176364], {
             RGBColor[
             0.2578128298869203, 0.3883080088616496, 0.9379934313109329]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.03217915333176364], {
             RGBColor[
             0.2524156236360728, 0.382635202889368, 0.9376860683993983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.03217915333176364], {
             RGBColor[
             0.9456496399519233, 0.8222259641328803, 0.2751266284196432]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.03217915333176364], {
             RGBColor[
             0.23901320904650822`, 0.3685484153935707, 0.9369228207156182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.03217915333176364], {
             RGBColor[
             0.6319940482543123, 0.7121202652370958, 0.9641720330305101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.03217915333176364], {
             RGBColor[
             0.6468617732853108, 0.7240526007128293, 0.965436794360271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.03217915333176364], {
             RGBColor[
             0.9089152991886196, 0.6765865439997854, 0.2455693155756892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.03217915333176364], {
             RGBColor[
             0.24399808998490613`, 0.37378784131953313`, 0.9372067023105894]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.03217915333176364], {
             RGBColor[
             0.23871510677441427`, 0.3682350910048242, 0.9369058442322252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.03217915333176364], {
             RGBColor[
             0.726249879738111, 0.7860711928457129, 0.9733494588874512]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.03217915333176364], {
             RGBColor[
             0.260213393629744, 0.3908311535598896, 0.9381301398647709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.03217915333176364], {
             RGBColor[
             0.245025991273468, 0.37486823074651754`, 0.9372652397683294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.03217915333176364], {
             RGBColor[
             0.8977533081905217, 0.6286034774622947, 0.23639519286946437`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.03217915333176364], {
             RGBColor[
             0.4051337172328171, 0.5253281960795354, 0.9470357401097634]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.03217915333176364], {
             RGBColor[
             0.696491580031562, 0.7628237829435023, 0.9703834296798242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.03217915333176364], {
             RGBColor[
             0.2110186790508826, 0.3391243894124498, 0.9353285736465631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.03217915333176364], {
             RGBColor[
             0.21123106399266978`, 0.3393476194522512, 0.9353406686548026]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.03217915333176364], {
             RGBColor[
             0.21275955169572475`, 0.34095415693987974`, 0.9354277137682966]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.03217915333176364], {
             RGBColor[
             0.24238734999627973`, 0.3720948514646729, 0.9371149730511135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.03217915333176364], {
             RGBColor[
             0.30152154075751214`, 0.43424863527897317`, 0.94048257773377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.03217915333176364], {
             RGBColor[
             0.9466390204165737, 0.9597240493140413, 0.9752103990490407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.03217915333176364], {
             RGBColor[
             0.8234301328695646, 0.862044852807406, 0.9830206952294982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.03217915333176364], {
             RGBColor[
             0.21412870248835636`, 0.3423932212321097, 0.9355056848804599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.03217915333176364], {
             RGBColor[
             0.8899967779325137, 0.5933828851443484, 0.2299229538922278]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.03217915333176364], {
             RGBColor[
             0.2568179059531509, 0.3872622807254372, 0.9379367718647629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.03217915333176364], {
             RGBColor[
             0.9872770340850194, 0.9687445898536212, 0.4050741092611545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.03217915333176364], {
             RGBColor[
             0.28961174034798287`, 0.421730679923598, 0.9398043322194181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.03217915333176364], {
             RGBColor[
             0.21909843402136348`, 0.34761672417247863`, 0.9357887037392056]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.03217915333176364], {
             RGBColor[
             0.20290260740476634`, 0.33059388352371805`, 0.9348663753729688]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.03217915333176364], {
             RGBColor[
             0.9703761157708419, 0.9117338238555674, 0.33941723308119276`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.03217915333176364], {
             RGBColor[
             0.9852399747517544, 0.9881643644915732, 0.8942753462917085]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.03217915333176364], {
             RGBColor[
             0.2610883790761277, 0.39175081874132034`, 0.9381799689915176]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.03217915333176364], {
             RGBColor[
             0.27079044913528966`, 0.40194830952027055`, 0.9387324875284604]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.03217915333176364], {
             RGBColor[
             0.18257815057035692`, 0.3092315907457619, 0.9337089276235886]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.03217915333176364], {
             RGBColor[
             0.519374038863881, 0.6206902681403376, 0.955306173350608]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.03217915333176364], {
             RGBColor[
             0.46295717480753656`, 0.5748885163486347, 0.9508648311503101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.03217915333176364], {
             RGBColor[
             0.2828083531870263, 0.41457988865777246`, 0.939416889385311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.03217915333176364], {
             RGBColor[
             0.9258119809847409, 0.9436813594132142, 0.9927859673000785]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.03217915333176364], {
             RGBColor[
             0.24327422624281886`, 0.37302701463098736`, 0.937165479341338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.03217915333176364], {
             RGBColor[
             0.25427950679235417`, 0.38459426226363735`, 0.9377922137877805]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.03217915333176364], {
             RGBColor[
             0.9906270631619555, 0.9903920639910485, 0.8049973499967711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.03217915333176364], {
             RGBColor[
             0.2238174684207968, 0.35257672853034516`, 0.9360574457670676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.03217915333176364], {
             RGBColor[
             0.24158367299712782`, 0.37125013598249945`, 0.9370692048349454]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.03217915333176364], {
             RGBColor[
             0.7098940201909748, 0.7732938710583535, 0.9717192596619902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.03217915333176364], {
             RGBColor[
             0.8177864636409283, 0.8575802678943982, 0.9824729701128726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.03217915333176364], {
             RGBColor[
             0.5084161265639328, 0.611794141286916, 0.9544435263542006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.03217915333176364], {
             RGBColor[
             0.8302102447519867, 0.867451129981215, 0.983667388353521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.03217915333176364], {
             RGBColor[
             0.2799576543907215, 0.4115836234781131, 0.9392545463060924]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.03217915333176364], {
             RGBColor[
             0.21156771774634342`, 0.33970146389244305`, 0.9353598405880397]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.03217915333176364], {
             RGBColor[
             0.3393902356747875, 0.4683844967174319, 0.9428466235995638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.03217915333176364], {
             RGBColor[
             0.3185921337049145, 0.45037022613412764`, 0.941521386933083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.03217915333176364], {
             RGBColor[
             0.3094371851822424, 0.44244066986488095`, 0.9409380417086214]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.03217915333176364], {
             RGBColor[
             0.23513882534723038`, 0.36447619247551505`, 0.9367021802955814]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.03217915333176364], {
             RGBColor[
             0.22477195032544567`, 0.3535799495297792, 0.936111802099508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.03217915333176364], {
             RGBColor[
             0.45209247002133757`, 0.5660015075294104, 0.9500279103134532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.03217915333176364], {
             RGBColor[
             0.5272216074067284, 0.6270612778123552, 0.9559239626928917]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.03217915333176364], {
             RGBColor[
             0.19556045555100107`, 0.3228768164060961, 0.9344482506866372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.03217915333176364], {
             RGBColor[
             0.26139903658851843`, 0.39207733948366696`, 0.9381976604772716]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.03217915333176364], {
             RGBColor[
             0.28051817934621337`, 0.41217277074566994`, 0.9392864673730853]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.03217915333176364], {
             RGBColor[
             0.2110065608580655, 0.33911165242346125`, 0.9353278835334095]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.03217915333176364], {
             RGBColor[
             0.2847433322190086, 0.4166136743051424, 0.9395270835786375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.03217915333176364], {
             RGBColor[
             0.9942883740099587, 0.9901917344782997, 0.6197029429328111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.03217915333176364], {
             RGBColor[
             0.36576050208801136`, 0.49122509607643855`, 0.9445269136571035]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.03217915333176364], {
             RGBColor[
             0.99377812825938, 0.9891003704115706, 0.5641658418540755]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.03217915333176364], {
             RGBColor[
             0.2215837127017966, 0.35022890964138337`, 0.935930236683416]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.03217915333176364], {
             RGBColor[
             0.6033581995623302, 0.6888723932386622, 0.9619177141249072]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.03217915333176364], {
             RGBColor[
             0.7222005724227306, 0.7829078431950623, 0.9729458617771823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.03217915333176364], {
             RGBColor[
             0.32062864936426844`, 0.45213415364000675`, 0.941651151910077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.03217915333176364], {
             RGBColor[
             0.20194739446585683`, 0.3295898941609259, 0.9348119774092088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.03217915333176364], {
             RGBColor[
             0.3450320119322843, 0.4732711197477559, 0.9432061125938647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.03217915333176364], {
             RGBColor[
             0.2800500850584523, 0.411680773970341, 0.9392598100958807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.03217915333176364], {
             RGBColor[
             0.26295522261758464`, 0.39371298966810864`, 0.9382862829694559]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.03217915333176364], {
             RGBColor[
             0.4453791406536688, 0.5601867590528806, 0.9496001429025095]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.03217915333176364], {
             RGBColor[
             0.4327427506991586, 0.5492417531977101, 0.948794963308529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.03217915333176364], {
             RGBColor[
             0.24574449108125243`, 0.37562341960001794`, 0.9373061572694574]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.03217915333176364], {
             RGBColor[
             0.9941541355650164, 0.9899046120181566, 0.6050919166244885]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.03217915333176364], {
             RGBColor[
             0.21037964845754836`, 0.3384527277419758, 0.9352921817996338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.03217915333176364], {
             RGBColor[
             0.27977343586669706`, 0.4113899981292344, 0.939244055333676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.03217915333176364], {
             RGBColor[
             0.23092116646773903`, 0.3600431655781515, 0.9364619908618614]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.03217915333176364], {
             RGBColor[
             0.5183784049780293, 0.6198819676990077, 0.9552277934039866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.03217915333176364], {
             RGBColor[
             0.6756901028072094, 0.7465735108387558, 0.9683101328309576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.03217915333176364], {
             RGBColor[
             0.9685766725786527, 0.9056638794389593, 0.332426736075871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.03217915333176364], {
             RGBColor[
             0.2455681205459235, 0.37543804298484945`, 0.9372961132283874]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.03217915333176364], {
             RGBColor[
             0.3103917228488082, 0.4432674424152022, 0.9409988640046705]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.03217915333176364], {
             RGBColor[
             0.35562652096447817`, 0.48244755097593534`, 0.9438811853410396]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.03217915333176364], {
             RGBColor[
             0.40465902674538534`, 0.5249170430379596, 0.9470054932516565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.03217915333176364], {
             RGBColor[
             0.8625124936811881, 0.46858316947675277`, 0.2069893934114667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.03217915333176364], {
             RGBColor[
             0.34952976604112324`, 0.4771668482931376, 0.9434927055084721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.03217915333176364], {
             RGBColor[
             0.25624071750281635`, 0.38665561906827417`, 0.93790390183639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.03217915333176364], {
             RGBColor[
             0.9012804456996433, 0.6446193851073215, 0.2393383228651273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.03217915333176364], {
             RGBColor[
             0.21931469518675756`, 0.34784402836905765`, 0.9358010194926452]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.03217915333176364], {
             RGBColor[
             0.21278150541118618`, 0.3409772316867757, 0.9354289639999145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.03217915333176364], {
             RGBColor[
             0.25745394897088236`, 0.38793080226452953`, 0.9379729935736814]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.03217915333176364], {
             RGBColor[
             0.8312166238387177, 0.8682535893475418, 0.9837633776892186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.03217915333176364], {
             RGBColor[
             0.27204560568907665`, 0.4032675586398226, 0.9388039668373608]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.03217915333176364], {
             RGBColor[
             0.2514775053864574, 0.3816491811288898, 0.9376326439529042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.03217915333176364], {
             RGBColor[
             0.2503218011924054, 0.380434462745063, 0.9375668283087641]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.03217915333176364], {
             RGBColor[
             0.2761037265699157, 0.40753290098530925`, 0.9390350708180728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.03217915333176364], {
             RGBColor[
             0.25484534055170655`, 0.38518898942064916`, 0.9378244371832996]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.03217915333176364], {
             RGBColor[
             0.43839329858407067`, 0.5541359737708264, 0.9491550112231723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.03217915333176364], {
             RGBColor[
             0.41487938737084307`, 0.5337694057214698, 0.9476567255932007]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.03217915333176364], {
             RGBColor[
             0.20852643568424656`, 0.3365048836167593, 0.9351866440737768]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.03217915333176364], {
             RGBColor[
             0.22095736038557218`, 0.3495705736440009, 0.9358945668456122]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.03217915333176364], {
             RGBColor[
             0.26549066491796636`, 0.3963779002821365, 0.9384306726576119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.03217915333176364], {
             RGBColor[
             0.9931470290452047, 0.9914341346439413, 0.7632349938486772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.03217915333176364], {
             RGBColor[
             0.898780922280212, 0.63326963303821, 0.23725265925502825`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.03217915333176364], {
             RGBColor[
             0.28023632613366145`, 0.41187652514875206`, 0.939270416249595]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.03217915333176364], {
             RGBColor[
             0.7484278388783107, 0.8033967830847693, 0.9755599505897345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.03217915333176364], {
             RGBColor[
             0.5754210452890663, 0.6661917528451691, 0.9597183990033479]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.03217915333176364], {
             RGBColor[
             0.3393631406607411, 0.4683610283780999, 0.942844897129228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.03217915333176364], {
             RGBColor[
             0.2935687509337651, 0.4258897489382169, 0.9400296781184059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.03217915333176364], {
             RGBColor[
             0.22336510960731928`, 0.352101270736175, 0.9360316846018449]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.03217915333176364], {
             RGBColor[
             0.17908812663026416`, 0.30556335430442605`, 0.933510175923228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.03217915333176364], {
             RGBColor[
             0.26629927432356376`, 0.3972278000362168, 0.9384767217670303]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.03217915333176364], {
             RGBColor[
             0.8203907902431329, 0.1577381258757864, 0.16715954980591485`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.03217915333176364], {
             RGBColor[
             0.24794921220500737`, 0.3779407212884774, 0.9374317128758627]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.03217915333176364], {
             RGBColor[
             0.22281999879048459`, 0.3515283247056597, 0.9360006413472455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.03217915333176364], {
             RGBColor[
             0.35886795134781274`, 0.48525511505495156`, 0.9440877264187814]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.03217915333176364], {
             RGBColor[
             0.27306809856961783`, 0.40434226348706437`, 0.938862196294265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.03217915333176364], {
             RGBColor[
             0.2782995151593558, 0.4098408140138484, 0.9391601177298633]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.03217915333176364], {
             RGBColor[
             0.2493495489754894, 0.37941256402073326`, 0.9375114599833291]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.03217915333176364], {
             RGBColor[
             0.9394254025446074, 0.954344144916344, 0.9874211724934188]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.03217915333176364], {
             RGBColor[
             0.2348790166106703, 0.36420311702056507`, 0.9366873845723869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.03217915333176364], {
             RGBColor[
             0.38961090759033284`, 0.5118831185663134, 0.9460466404056259]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{3.8349504055390835`*^9, 3.834957759852075*^9, 
  3.835018922383715*^9, 3.835019017360054*^9, 3.835020551743785*^9, 
  3.835044643191966*^9, 3.835045032973324*^9, 3.8350457083859315`*^9},
 CellLabel->
  "Out[331]=",ExpressionUUID->"2f9785d6-10c6-46c7-a325-4c1c6379537a"]
}, Open  ]],

Cell["Estimated with Max-Min Deviation v Calculated: (r = 3)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 3.8349503922098827`*^9}, {3.8349504781120467`*^9, 
  3.8349504928656063`*^9}},ExpressionUUID->"f503430c-0327-477b-95c6-\
28ec80df9ba0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphinf4", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsif4", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}],
      "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"mMDi3f400", ",", "krif4"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502554527807`*^9}, {3.8349577716948586`*^9, 
   3.8349577796673746`*^9}, {3.835018835203446*^9, 3.8350188366714215`*^9}, {
   3.8350443464072504`*^9, 3.835044352231003*^9}, {3.8350449386312246`*^9, 
   3.835044944694197*^9}, {3.835045609955904*^9, 3.8350456124786654`*^9}},
 CellLabel->
  "In[332]:=",ExpressionUUID->"54fe7390-3203-4a26-877e-427844a1f6d3"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN2wucz2W+wPHn16rdrWxoc2ntsSnFoptQYTEuNY3rMEhyNxmZGTMj4zII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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[105, 155] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[1, 203] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139], 
             UndirectedEdge[187, 193] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[209, 371] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[23, 245] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[201, 236] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[258, 369] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[161, 312] -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 
             UndirectedEdge[74, 132] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[89, 169] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[124, 137] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[186, 393] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[84, 261] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[58, 243] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[205, 250] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[327, 337] -> 
             RGBColor[
              0.6371962142857142, 0.7050402142857143, 0.9257404285714286], 
             UndirectedEdge[38, 224] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[49, 301] -> 
             RGBColor[
              0.7026543571428572, 0.7596784285714285, 0.7296359999999997], 
             UndirectedEdge[22, 97] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[163, 169] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[126, 318] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[126, 149] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[28, 47] -> 
             RGBColor[
              0.7262382142857143, 0.6266562857142857, 0.5947413571428571], 
             UndirectedEdge[203, 392] -> 
             RGBColor[0.8450535, 0.847972142857143, 0.6584182857142857], 
             UndirectedEdge[116, 387] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[114, 203] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139], 
             UndirectedEdge[38, 207] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[4, 73] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[143, 223] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[70, 164] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[291, 331] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[317, 381] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.4924907142857143], 
             UndirectedEdge[120, 349] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[102, 160] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[84, 381] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[110, 203] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[316, 355] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[62, 77] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[188, 361] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[168, 282] -> 
             RGBColor[
              0.6325285714285713, 0.7084724285714286, 0.9666597142857143], 
             UndirectedEdge[271, 394] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[160, 224] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[97, 168] -> 
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[88, 132] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[329, 353] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[189, 339] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[316, 380] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[156, 295] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[154, 228] -> 
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861], 
             UndirectedEdge[29, 91] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[6, 198] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285716], 
             UndirectedEdge[56, 254] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714286, 0.6064375714285715], 
             UndirectedEdge[245, 315] -> 
             RGBColor[
              0.6325285714285713, 0.7084724285714286, 0.9666597142857143], 
             UndirectedEdge[174, 281] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[89, 329] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[260, 267] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[202, 363] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714286, 0.6064375714285715], 
             UndirectedEdge[43, 238] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[276, 377] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[284, 369] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[53, 249] -> 
             RGBColor[
              0.6515733571428571, 0.5649184285714285, 0.5891733571428572], 
             UndirectedEdge[15, 105] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[97, 112] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[120, 246] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[53, 308] -> 
             RGBColor[0.9376635, 0.7931411428571429, 0.571257857142857], 
             UndirectedEdge[188, 392] -> 
             RGBColor[
              0.9527067142857144, 0.8455740000000003, 0.30492278571428577`], 
             UndirectedEdge[91, 273] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139], 
             UndirectedEdge[327, 354] -> 
             RGBColor[
              0.5716229285714285, 0.6540043571428571, 0.9628416428571429], 
             UndirectedEdge[51, 376] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[202, 214] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714286, 0.6064375714285715], 
             UndirectedEdge[69, 132] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[130, 387] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[61, 306] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[312, 356] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285716], 
             UndirectedEdge[18, 247] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[56, 320] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.3713353571428568], 
             UndirectedEdge[43, 124] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[259, 318] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[267, 384] -> 
             RGBColor[0.6164135, 0.6895405, 0.9609201428571428], 
             UndirectedEdge[44, 324] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[62, 204] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[42, 109] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[8, 21] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[48, 349] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[222, 332] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[58, 167] -> 
             RGBColor[
              0.6515733571428571, 0.5649184285714285, 0.5891733571428571], 
             UndirectedEdge[76, 144] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[6, 166] -> 
             RGBColor[0.8450535, 0.847972142857143, 0.6584182857142857], 
             UndirectedEdge[79, 343] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[142, 257] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[175, 256] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139], 
             UndirectedEdge[8, 171] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[31, 214] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[41, 114] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[72, 399] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[278, 392] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[6, 323] -> 
             RGBColor[0.894471, 0.5250334285714287, 0.2542395714285715], 
             UndirectedEdge[132, 323] -> 
             RGBColor[0.905308, 0.5610991428571428, 0.33800799999999964`], 
             UndirectedEdge[200, 355] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[98, 215] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[12, 367] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[88, 140] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[195, 327] -> 
             RGBColor[
              0.6371962142857143, 0.7050402142857143, 0.9257404285714286], 
             UndirectedEdge[142, 381] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[313, 359] -> 
             RGBColor[
              0.4257709285714286, 0.5385553571428572, 0.9492239285714286], 
             UndirectedEdge[64, 82] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[98, 297] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[139, 305] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[288, 375] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[136, 194] -> 
             RGBColor[
              0.8718352857142857, 0.5016841428571427, 0.2144070714285714], 
             UndirectedEdge[254, 349] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[348, 351] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[65, 282] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285715, 0.6650532857142857], 
             UndirectedEdge[131, 215] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[230, 250] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[26, 111] -> 
             RGBColor[0.8527905, 0.6452381428571428, 0.5918934285714286], 
             UndirectedEdge[301, 390] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[3, 309] -> 
             RGBColor[
              0.7857647142857143, 0.8328318571428571, 0.9792104285714285], 
             UndirectedEdge[90, 268] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[17, 187] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[4, 206] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[19, 231] -> 
             RGBColor[
              0.7664822142857144, 0.7853505714285716, 0.6514355714285716], 
             UndirectedEdge[76, 138] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[28, 390] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[123, 174] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[2, 98] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[20, 364] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[56, 196] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.3713353571428568], 
             UndirectedEdge[360, 374] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[39, 360] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[261, 264] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[101, 253] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[141, 273] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.3713353571428568], 
             UndirectedEdge[171, 182] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[156, 175] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[121, 250] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[68, 308] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[39, 390] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[54, 181] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[196, 313] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[200, 241] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[186, 255] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[11, 38] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[173, 310] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[106, 173] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[51, 396] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[6, 18] -> 
             RGBColor[0.8450535, 0.847972142857143, 0.6584182857142857], 
             UndirectedEdge[238, 287] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[93, 225] -> 
             RGBColor[
              0.9231166428571429, 0.6982394285714284, 0.4760250714285714], 
             UndirectedEdge[116, 276] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[135, 276] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[147, 172] -> 
             RGBColor[
              0.6325285714285713, 0.7084724285714286, 0.9666597142857143], 
             UndirectedEdge[185, 224] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[160, 166] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[63, 156] -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             UndirectedEdge[247, 302] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[81, 240] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[15, 112] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[12, 212] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[18, 74] -> 
             RGBColor[
              0.6399127142857144, 0.7173828571428571, 0.9655927142857142], 
             UndirectedEdge[1, 7] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[231, 331] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[58, 351] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[142, 279] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[303, 344] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[302, 323] -> 
             RGBColor[
              0.8799727857142857, 0.5454292857142857, 0.5731102142857143], 
             UndirectedEdge[144, 366] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[56, 342] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.3713353571428568], 
             UndirectedEdge[137, 293] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[39, 374] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[4, 278] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[238, 396] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[118, 293] -> 
             RGBColor[
              0.9231166428571429, 0.6982394285714284, 0.4760250714285715], 
             UndirectedEdge[201, 228] -> 
             RGBColor[
              0.7664822142857144, 0.7853505714285716, 0.6514355714285716], 
             UndirectedEdge[212, 336] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[186, 200] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[7, 356] -> RGBColor[0.984192, 0.987731, 0.911643],
              UndirectedEdge[215, 269] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[36, 122] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[297, 352] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[228, 243] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[100, 271] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[157, 298] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[272, 384] -> 
             RGBColor[
              0.6371962142857143, 0.7050402142857143, 0.9257404285714286], 
             UndirectedEdge[35, 114] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139], 
             UndirectedEdge[15, 155] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[36, 262] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[111, 185] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[26, 400] -> 
             RGBColor[
              0.8975810714285715, 0.6807742857142856, 0.5899719285714284], 
             UndirectedEdge[61, 131] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[168, 350] -> 
             RGBColor[0.2954693571428571, 0.41833978571428565`, 0.9404875], 
             UndirectedEdge[16, 208] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[125, 303] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[145, 164] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[152, 256] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[237, 246] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[16, 284] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[240, 309] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[151, 249] -> 
             RGBColor[
              0.7026543571428571, 0.7596784285714285, 0.7296359999999997], 
             UndirectedEdge[47, 311] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.3713353571428568], 
             UndirectedEdge[29, 190] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[99, 384] -> 
             RGBColor[
              0.4257709285714286, 0.5385553571428572, 0.9492239285714286], 
             UndirectedEdge[5, 398] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[36, 157] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[40, 55] -> 
             RGBColor[0.8527905, 0.6452381428571428, 0.5918934285714286], 
             UndirectedEdge[163, 319] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285716], 
             UndirectedEdge[13, 74] -> 
             RGBColor[0.48667657142857146`, 0.5930234285714285, 0.953042], 
             UndirectedEdge[47, 158] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.4924907142857143], 
             UndirectedEdge[252, 330] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[102, 185] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[41, 356] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[33, 175] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[12, 126] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[18, 191] -> 
             RGBColor[0.8048095, 0.689277857142857, 0.6017240714285714], 
             UndirectedEdge[64, 171] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[73, 184] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[93, 316] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[20, 362] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[32, 330] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[124, 277] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[267, 331] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[134, 167] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.49249071428571434`], 
             UndirectedEdge[143, 398] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[109, 320] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[28, 147] -> 
             RGBColor[0.48667657142857146`, 0.5930234285714285, 0.953042], 
             UndirectedEdge[54, 311] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[160, 289] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[209, 240] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[31, 261] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[245, 248] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[81, 245] -> 
             RGBColor[
              0.6325285714285713, 0.7084724285714286, 0.9666597142857143], 
             UndirectedEdge[308, 386] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[320, 349] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[222, 356] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[200, 374] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[73, 348] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[23, 81] -> 
             RGBColor[0.48667657142857146`, 0.5930234285714285, 0.953042], 
             UndirectedEdge[25, 233] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[168, 170] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[73, 284] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[143, 234] -> 
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[288, 374] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[254, 344] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[6, 102] -> 
             RGBColor[
              0.6918173571428571, 0.7236127142857143, 0.6458675714285715], 
             UndirectedEdge[205, 276] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[101, 244] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[58, 80] -> 
             RGBColor[0.5652478571428571, 0.655645, 0.9600247142857143], 
             UndirectedEdge[23, 292] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[101, 397] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[105, 168] -> 
             RGBColor[
              0.6918173571428571, 0.7236127142857143, 0.6458675714285715], 
             UndirectedEdge[166, 340] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[138, 317] -> 
             RGBColor[0.9376635, 0.7931411428571429, 0.5712578571428572], 
             UndirectedEdge[71, 120] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[231, 290] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[13, 224] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[40, 159] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285715, 0.6650532857142858], 
             UndirectedEdge[20, 265] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[43, 299] -> 
             RGBColor[
              0.5716229285714285, 0.6540043571428571, 0.9628416428571429], 
             UndirectedEdge[219, 220] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[56, 290] -> 
             RGBColor[
              0.8720902142857143, 0.7421052857142856, 0.6083590714285714], 
             UndirectedEdge[64, 157] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[13, 340] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[16, 188] -> 
             RGBColor[
              0.8934179285714285, 0.8304337142857143, 0.6257149285714285], 
             UndirectedEdge[171, 308] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[288, 379] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285715], 
             UndirectedEdge[81, 353] -> 
             RGBColor[0.5652478571428571, 0.655645, 0.9600247142857143], 
             UndirectedEdge[153, 188] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[148, 356] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[198, 247] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[94, 375] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[298, 307] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[9, 142] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[203, 284] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139], 
             UndirectedEdge[370, 400] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[63, 381] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[222, 251] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[103, 234] -> 
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[150, 399] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[321, 338] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[154, 203] -> 
             RGBColor[
              0.6399127142857144, 0.7173828571428571, 0.9655927142857142], 
             UndirectedEdge[225, 390] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.3548697142857139], 
             UndirectedEdge[54, 121] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[234, 346] -> 
             RGBColor[
              0.6325285714285713, 0.7084724285714286, 0.9666597142857143], 
             UndirectedEdge[358, 391] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[74, 357] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[130, 364] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[202, 381] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.4924907142857143], 
             UndirectedEdge[98, 307] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[242, 317] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714286], 
             UndirectedEdge[9, 279] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[200, 399] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[275, 306] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[121, 181] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[239, 271] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[35, 354] -> 
             RGBColor[
              0.7857647142857143, 0.8328318571428571, 0.9792104285714285], 
             UndirectedEdge[31, 310] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[146, 154] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[265, 322] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.3713353571428568], 
             UndirectedEdge[115, 284] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[38, 391] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[116, 328] -> 
             RGBColor[
              0.7664822142857144, 0.7853505714285716, 0.6514355714285714], 
             UndirectedEdge[92, 278] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[215, 217] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[159, 210] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285716], 
             UndirectedEdge[165, 298] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[83, 254] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[103, 231] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[245, 319] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[58, 263] -> 
             RGBColor[
              0.7026543571428572, 0.7596784285714285, 0.7296359999999997], 
             UndirectedEdge[206, 258] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[213, 391] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[78, 370] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[101, 270] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[135, 377] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.38869121428571396`], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[19, 83] -> 
             RGBColor[
              0.7664822142857144, 0.7853505714285716, 0.6514355714285716], 
             UndirectedEdge[100, 112] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[10, 296] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[85, 369] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[79, 246] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[227, 280] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[112, 326] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[34, 308] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[29, 226] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[204, 345] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285715, 0.6650532857142858], 
             UndirectedEdge[54, 265] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[22, 100] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[126, 336] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[82, 157] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[344, 349] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[343, 349] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[2, 66] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[211, 387] -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             UndirectedEdge[250, 265] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[217, 306] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[374, 375] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[38, 247] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[204, 310] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[226, 266] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[319, 334] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[73, 206] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[200, 255] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[296, 383] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[235, 281] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[174, 272] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[9, 131] -> RGBColor[0.984192, 0.987731, 0.911643],
              UndirectedEdge[228, 361] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[149, 199] -> 
             RGBColor[
              0.7026543571428571, 0.7596784285714285, 0.7296359999999997], 
             UndirectedEdge[102, 400] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[45, 350] -> 
             RGBColor[0.5815595, 0.6465625, 0.922572], 
             UndirectedEdge[369, 392] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[82, 151] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[260, 342] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[296, 380] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[105, 148] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285716], 
             UndirectedEdge[94, 288] -> 
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[195, 258] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[339, 374] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139], 
             UndirectedEdge[199, 367] -> 
             RGBColor[
              0.6918173571428572, 0.7236127142857143, 0.6458675714285715], 
             UndirectedEdge[36, 298] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[147, 347] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[38, 205] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[16, 73] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[108, 290] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[225, 296] -> 
             RGBColor[0.8527905, 0.6452381428571428, 0.5918934285714286], 
             UndirectedEdge[24, 144] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[209, 319] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[80, 192] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[42, 221] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[22, 365] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[80, 201] -> 
             RGBColor[0.8450535, 0.847972142857143, 0.6584182857142857], 
             UndirectedEdge[39, 375] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[15, 326] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[86, 95] -> 
             RGBColor[0.5652478571428571, 0.655645, 0.9600247142857143], 
             UndirectedEdge[59, 194] -> 
             RGBColor[0.9376635, 0.7931411428571429, 0.5712578571428572], 
             UndirectedEdge[296, 324] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285715, 0.6650532857142858], 
             UndirectedEdge[169, 245] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[258, 284] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[33, 152] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[246, 349] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[27, 395] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[185, 340] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[223, 321] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[274, 373] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[156, 214] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[205, 221] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[97, 105] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285715], 
             UndirectedEdge[130, 158] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[108, 143] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[176, 399] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[150, 189] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[253, 386] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[46, 59] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[186, 241] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285715], 
             UndirectedEdge[39, 93] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[214, 264] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[234, 290] -> 
             RGBColor[
              0.6325285714285713, 0.7084724285714286, 0.9666597142857143], 
             UndirectedEdge[148, 170] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[50, 362] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[271, 326] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[61, 352] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[256, 333] -> 
             RGBColor[
              0.8261372142857144, 0.7776062857142858, 0.6190799285714286], 
             UndirectedEdge[100, 394] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[1, 114] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[218, 269] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[182, 253] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[57, 354] -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             UndirectedEdge[40, 192] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[262, 314] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[244, 253] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[277, 330] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[304, 329] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[103, 223] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[92, 337] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[226, 341] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[193, 260] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[9, 214] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[8, 157] -> RGBColor[0.984192, 0.987731, 0.911643],
              UndirectedEdge[103, 342] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[165, 314] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[115, 392] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[104, 233] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[67, 139] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[116, 364] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[74, 220] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[100, 168] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[129, 308] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[26, 185] -> 
             RGBColor[
              0.8975810714285715, 0.6807742857142856, 0.5899719285714284], 
             UndirectedEdge[197, 215] -> 
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861], 
             UndirectedEdge[178, 240] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[52, 223] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[192, 243] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[124, 252] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[194, 396] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714286, 0.6064375714285715], 
             UndirectedEdge[269, 279] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[57, 208] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[169, 304] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[209, 280] -> 
             RGBColor[
              0.8934179285714285, 0.8304337142857143, 0.6257149285714285], 
             UndirectedEdge[226, 399] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[206, 392] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285715], 
             UndirectedEdge[48, 343] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[159, 263] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[261, 295] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[33, 204] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[64, 151] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[210, 263] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[19, 303] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285716], 
             UndirectedEdge[248, 315] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[236, 351] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[53, 386] -> 
             RGBColor[0.9376635, 0.7931411428571429, 0.571257857142857], 
             UndirectedEdge[93, 301] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[37, 159] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285715], 
             UndirectedEdge[148, 326] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[13, 357] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[162, 231] -> 
             RGBColor[
              0.7664822142857144, 0.7853505714285716, 0.6514355714285716], 
             UndirectedEdge[33, 84] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[199, 293] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[96, 167] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714286, 0.6064375714285714], 
             UndirectedEdge[131, 307] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[174, 291] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[207, 250] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[364, 387] -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             UndirectedEdge[103, 346] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[31, 106] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[128, 316] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.38869121428571396`], 
             UndirectedEdge[185, 289] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[20, 172] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[70, 234] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[119, 383] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[20, 54] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[229, 334] -> 
             RGBColor[
              0.7857647142857143, 0.8328318571428571, 0.9792104285714285], 
             UndirectedEdge[63, 142] -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             UndirectedEdge[230, 358] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[119, 296] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[218, 262] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[100, 170] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[97, 357] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[375, 399] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[199, 252] -> 
             RGBColor[
              0.7026543571428572, 0.7596784285714285, 0.7296359999999997], 
             UndirectedEdge[175, 345] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[176, 186] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285716], 
             UndirectedEdge[309, 371] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139], 
             UndirectedEdge[326, 354] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[38, 289] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[120, 237] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[275, 384] -> 
             RGBColor[
              0.6371962142857143, 0.7050402142857143, 0.9257404285714286], 
             UndirectedEdge[216, 220] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[50, 276] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[143, 321] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[225, 316] -> 
             RGBColor[0.893163, 0.5900125714285714, 0.23176292857142858`], 
             UndirectedEdge[40, 332] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[254, 343] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[37, 167] -> 
             RGBColor[0.9376635, 0.7931411428571429, 0.5712578571428572], 
             UndirectedEdge[26, 204] -> 
             RGBColor[0.8527905, 0.6452381428571428, 0.5918934285714286], 
             UndirectedEdge[141, 189] -> 
             RGBColor[0.9376635, 0.7931411428571429, 0.571257857142857], 
             UndirectedEdge[55, 210] -> 
             RGBColor[
              0.9183637857142857, 0.6962739999999998, 0.5547922142857142], 
             UndirectedEdge[41, 312] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[102, 247] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[30, 400] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[57, 195] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[301, 324] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[290, 331] -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             UndirectedEdge[49, 347] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[92, 258] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[234, 313] -> 
             RGBColor[0.48667657142857146`, 0.5930234285714285, 0.953042], 
             UndirectedEdge[376, 377] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[223, 272] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[213, 302] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[121, 158] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[240, 248] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[18, 132] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139], 
             UndirectedEdge[59, 79] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[109, 207] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[190, 365] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[78, 391] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[159, 236] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[95, 334] -> 
             RGBColor[
              0.7857647142857143, 0.8328318571428571, 0.9792104285714285], 
             UndirectedEdge[20, 147] -> 
             RGBColor[0.48667657142857146`, 0.5930234285714285, 0.953042], 
             UndirectedEdge[229, 388] -> 
             RGBColor[0.5652478571428571, 0.655645, 0.9600247142857143], 
             UndirectedEdge[15, 271] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[53, 151] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.3713353571428568], 
             UndirectedEdge[178, 309] -> 
             RGBColor[0.8450535, 0.847972142857143, 0.6584182857142857], 
             UndirectedEdge[309, 386] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[199, 299] -> 
             RGBColor[
              0.35110607142857136`, 0.47681749999999995`, 0.9436559285714285],
              UndirectedEdge[33, 90] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[191, 216] -> 
             RGBColor[
              0.8720902142857143, 0.7421052857142856, 0.6083590714285714], 
             UndirectedEdge[188, 203] -> 
             RGBColor[
              0.8261372142857144, 0.7776062857142858, 0.6190799285714286], 
             UndirectedEdge[87, 263] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.38869121428571396`], 
             UndirectedEdge[25, 76] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[329, 334] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[42, 376] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[54, 130] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[90, 256] -> 
             RGBColor[
              0.7857647142857143, 0.8328318571428571, 0.9792104285714285], 
             UndirectedEdge[160, 302] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[299, 367] -> 
             RGBColor[0.6309117142857144, 0.6691446428571429, 0.6420495], 
             UndirectedEdge[16, 96] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[5, 223] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[40, 228] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[154, 222] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[85, 188] -> 
             RGBColor[
              0.9527067142857144, 0.8455740000000003, 0.30492278571428577`], 
             UndirectedEdge[281, 384] -> 
             RGBColor[
              0.6419490714285714, 0.7070056428571428, 0.8469732857142858], 
             UndirectedEdge[249, 334] -> 
             RGBColor[
              0.6325285714285713, 0.7084724285714286, 0.9666597142857143], 
             UndirectedEdge[203, 243] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[49, 147] -> 
             RGBColor[0.4120117142857142, 0.5312855714285714, 0.947474], 
             UndirectedEdge[99, 232] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[84, 389] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[76, 242] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[129, 397] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[177, 390] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[138, 144] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285715], 
             UndirectedEdge[184, 325] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[69, 140] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[247, 391] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[14, 391] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[229, 240] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[166, 400] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[281, 386] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[150, 255] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[103, 290] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[212, 299] -> 
             RGBColor[
              0.6309117142857142, 0.6691446428571429, 0.6420495000000002], 
             UndirectedEdge[206, 208] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[75, 169] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[110, 167] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714286, 0.6064375714285714], 
             UndirectedEdge[33, 214] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[98, 107] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[238, 252] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[91, 241] -> 
             RGBColor[0.8450535, 0.847972142857143, 0.6584182857142857], 
             UndirectedEdge[74, 219] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[45, 180] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[187, 235] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[114, 188] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.38869121428571396`], 
             UndirectedEdge[81, 378] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[19, 313] -> 
             RGBColor[
              0.7664822142857144, 0.7853505714285716, 0.6514355714285716], 
             UndirectedEdge[195, 284] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[64, 253] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[55, 122] -> 
             RGBColor[
              0.9183637857142857, 0.6962739999999998, 0.5547922142857142], 
             UndirectedEdge[99, 275] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[118, 367] -> 
             RGBColor[
              0.9120792857142856, 0.6603784285714285, 0.27110128571428577`], 
             UndirectedEdge[7, 96] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[110, 115] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[68, 95] -> 
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285], 
             UndirectedEdge[289, 302] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[260, 321] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[191, 220] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.3713353571428568], 
             UndirectedEdge[169, 209] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[32, 252] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[75, 280] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[14, 224] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[128, 311] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[132, 198] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[245, 388] -> 
             RGBColor[
              0.6325285714285713, 0.7084724285714286, 0.9666597142857143], 
             UndirectedEdge[183, 273] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[69, 220] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[37, 263] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[235, 384] -> 
             RGBColor[
              0.5716229285714285, 0.6540043571428571, 0.9628416428571429], 
             UndirectedEdge[132, 216] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[225, 380] -> 
             RGBColor[
              0.9183637857142857, 0.6962739999999998, 0.5547922142857142], 
             UndirectedEdge[3, 371] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[269, 314] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[16, 206] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[84, 256] -> 
             RGBColor[
              0.6399127142857144, 0.7173828571428571, 0.9655927142857142], 
             UndirectedEdge[58, 348] -> 
             RGBColor[0.48667657142857146`, 0.5930234285714285, 0.953042], 
             UndirectedEdge[177, 360] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[2, 106] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[256, 317] -> 
             RGBColor[0.8048095, 0.689277857142857, 0.6017240714285714], 
             UndirectedEdge[87, 351] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[48, 103] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[256, 381] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[91, 226] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[105, 113] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285716], 
             UndirectedEdge[223, 291] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[203, 348] -> 
             RGBColor[
              0.6399127142857144, 0.7173828571428571, 0.9655927142857142], 
             UndirectedEdge[259, 367] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[188, 206] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[250, 289] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[194, 377] -> 
             RGBColor[
              0.9124627142857143, 0.6868797142857144, 0.24822857142857144`], 
             UndirectedEdge[83, 231] -> 
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861], 
             UndirectedEdge[276, 376] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[83, 120] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[40, 243] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[4, 392] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285715, 0.6650532857142858], 
             UndirectedEdge[81, 329] -> 
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[131, 363] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[167, 192] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.4924907142857143], 
             UndirectedEdge[41, 327] -> 
             RGBColor[
              0.6419490714285714, 0.7070056428571428, 0.8469732857142858], 
             UndirectedEdge[24, 382] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.7855097857142856, 0.5924107142857142, 0.5852584285714286], 
             UndirectedEdge[90, 261] -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             UndirectedEdge[146, 297] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[5, 291] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[229, 315] -> 
             RGBColor[0.5652478571428571, 0.655645, 0.9600247142857143], 
             UndirectedEdge[241, 360] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285715, 0.6650532857142857], 
             UndirectedEdge[59, 237] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[257, 381] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[270, 308] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[317, 382] -> 
             RGBColor[0.9376635, 0.7931411428571429, 0.571257857142857], 
             UndirectedEdge[23, 89] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[57, 327] -> 
             RGBColor[
              0.5716229285714285, 0.6540043571428571, 0.9628416428571429], 
             UndirectedEdge[347, 362] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[43, 293] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[73, 208] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[53, 129] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.3713353571428568], 
             UndirectedEdge[324, 383] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[368, 399] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[51, 136] -> 
             RGBColor[
              0.9231166428571429, 0.6982394285714284, 0.4760250714285714], 
             UndirectedEdge[145, 359] -> 
             RGBColor[
              0.6419490714285714, 0.7070056428571428, 0.8469732857142858], 
             UndirectedEdge[222, 297] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[81, 209] -> 
             RGBColor[
              0.6325285714285713, 0.7084724285714286, 0.9666597142857143], 
             UndirectedEdge[31, 345] -> 
             RGBColor[
              0.7664822142857144, 0.7853505714285716, 0.6514355714285714], 
             UndirectedEdge[155, 180] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[4, 369] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[102, 289] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[70, 103] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[177, 375] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[171, 253] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[150, 241] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[24, 317] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.49249071428571434`], 
             UndirectedEdge[80, 110] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[176, 341] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[154, 192] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[121, 322] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.49249071428571434`], 
             UndirectedEdge[268, 381] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[76, 104] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[91, 186] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[216, 357] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[210, 236] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[26, 173] -> 
             RGBColor[
              0.8975810714285715, 0.6807742857142856, 0.5899719285714284], 
             UndirectedEdge[10, 374] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[289, 340] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[65, 168] -> 
             RGBColor[
              0.6918173571428571, 0.7236127142857143, 0.6458675714285715], 
             UndirectedEdge[40, 203] -> 
             RGBColor[
              0.7857647142857143, 0.8328318571428571, 0.9792104285714285], 
             UndirectedEdge[167, 201] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714286], 
             UndirectedEdge[41, 57] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[214, 363] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[22, 189] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[41, 96] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[31, 197] -> 
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861], 
             UndirectedEdge[275, 281] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[89, 353] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[324, 375] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[5, 174] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[36, 314] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[220, 357] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[291, 342] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[21, 159] -> 
             RGBColor[0.894471, 0.5250334285714287, 0.2542395714285715], 
             UndirectedEdge[220, 394] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[129, 249] -> 
             RGBColor[
              0.7026543571428571, 0.7596784285714285, 0.7296359999999997], 
             UndirectedEdge[37, 58] -> 
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[118, 259] -> 
             RGBColor[
              0.8975810714285715, 0.6807742857142856, 0.5899719285714284], 
             UndirectedEdge[201, 243] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[40, 110] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[35, 278] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[164, 315] -> 
             RGBColor[
              0.7026543571428571, 0.7596784285714285, 0.7296359999999997], 
             UndirectedEdge[81, 304] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[12, 299] -> 
             RGBColor[0.6164135, 0.6895405, 0.9609201428571428], 
             UndirectedEdge[203, 258] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[250, 276] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[124, 238] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[96, 154] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[126, 238] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[103, 108] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[122, 210] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[108, 234] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[222, 361] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[12, 274] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[141, 219] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.4924907142857143], 
             UndirectedEdge[179, 344] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[14, 230] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[12, 118] -> 
             RGBColor[
              0.8975810714285715, 0.6807742857142856, 0.5899719285714285], 
             UndirectedEdge[44, 49] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[224, 247] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[161, 222] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[148, 168] -> 
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[219, 323] -> 
             RGBColor[
              0.9055083571428572, 0.5628944285714286, 0.45916335714285716`], 
             UndirectedEdge[309, 334] -> 
             RGBColor[
              0.7857647142857143, 0.8328318571428571, 0.9792104285714285], 
             UndirectedEdge[170, 326] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[239, 354] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[11, 221] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[47, 322] -> 
             RGBColor[0.891135, 0.5985512857142856, 0.23087271428571426`], 
             UndirectedEdge[155, 271] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[106, 363] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[245, 378] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[155, 326] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[10, 39] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[25, 382] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[177, 383] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[177, 296] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[103, 143] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[84, 317] -> 
             RGBColor[
              0.7262382142857143, 0.6266562857142857, 0.5947413571428571], 
             UndirectedEdge[50, 328] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[332, 385] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[242, 257] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285716], 
             UndirectedEdge[214, 217] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[51, 59] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[66, 131] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[66, 98] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[70, 346] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[151, 253] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[384, 398] -> 
             RGBColor[
              0.6419490714285714, 0.7070056428571428, 0.8469732857142858], 
             UndirectedEdge[123, 218] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[169, 280] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[71, 109] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[166, 302] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[89, 163] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285715], 
             UndirectedEdge[102, 340] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[380, 390] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[172, 387] -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             UndirectedEdge[61, 298] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[10, 216] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[209, 229] -> 
             RGBColor[
              0.7857647142857143, 0.8328318571428571, 0.9792104285714285], 
             UndirectedEdge[39, 119] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[33, 261] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[102, 213] -> 
             RGBColor[
              0.6918173571428572, 0.7236127142857143, 0.6458675714285715], 
             UndirectedEdge[155, 335] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[76, 317] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.3713353571428568], 
             UndirectedEdge[19, 179] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285715, 0.6650532857142857], 
             UndirectedEdge[48, 83] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[288, 355] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[7, 192] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[341, 393] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[244, 270] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[121, 265] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[156, 363] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[133, 280] -> 
             RGBColor[
              0.9527067142857144, 0.8455740000000003, 0.30492278571428577`], 
             UndirectedEdge[44, 362] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[116, 147] -> 
             RGBColor[0.48667657142857146`, 0.5930234285714285, 0.953042], 
             UndirectedEdge[83, 196] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[109, 233] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[19, 125] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285715, 0.6650532857142857], 
             UndirectedEdge[26, 160] -> 
             RGBColor[
              0.9231166428571429, 0.6982394285714284, 0.4760250714285715], 
             UndirectedEdge[224, 302] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[58, 60] -> 
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[165, 332] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[43, 252] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[292, 304] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[63, 257] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[94, 355] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[223, 290] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[141, 150] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.4924907142857143], 
             UndirectedEdge[131, 306] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[151, 182] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139], 
             UndirectedEdge[87, 201] -> 
             RGBColor[
              0.9527067142857144, 0.8455740000000003, 0.30492278571428577`], 
             UndirectedEdge[72, 379] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[23, 378] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[116, 322] -> 
             RGBColor[
              0.7262382142857143, 0.6266562857142857, 0.5947413571428571], 
             UndirectedEdge[90, 175] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[348, 369] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[134, 243] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[211, 372] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[73, 188] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.38869121428571396`], 
             UndirectedEdge[55, 228] -> 
             RGBColor[0.7069385, 0.5297891428571427, 0.5782757142857142], 
             UndirectedEdge[260, 384] -> 
             RGBColor[
              0.6419490714285714, 0.7070056428571428, 0.8469732857142858], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[153, 203] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[65, 148] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285716], 
             UndirectedEdge[42, 366] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[48, 313] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[166, 213] -> 
             RGBColor[0.8450535, 0.847972142857143, 0.6584182857142857], 
             UndirectedEdge[11, 78] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[228, 348] -> 
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861], 
             UndirectedEdge[199, 336] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[249, 309] -> 
             RGBColor[0.5652478571428571, 0.655645, 0.9600247142857143], 
             UndirectedEdge[190, 273] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[298, 314] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[7, 385] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[27, 194] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.3713353571428568], 
             UndirectedEdge[39, 128] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[116, 265] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[231, 313] -> 
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861], 
             UndirectedEdge[96, 284] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[279, 300] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[22, 190] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[24, 207] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[315, 329] -> 
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[239, 335] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[142, 300] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[13, 88] -> 
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[18, 302] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[148, 251] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[90, 257] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[134, 348] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[158, 322] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.49249071428571434`], 
             UndirectedEdge[40, 385] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[228, 385] -> 
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861], 
             UndirectedEdge[175, 214] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[7, 41] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[176, 379] -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 
             UndirectedEdge[259, 336] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[213, 340] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[55, 165] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.3548697142857139], 
             UndirectedEdge[108, 231] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[38, 230] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[39, 316] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[85, 167] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714286], 
             UndirectedEdge[28, 328] -> 
             RGBColor[
              0.7664822142857144, 0.7853505714285716, 0.6514355714285714], 
             UndirectedEdge[79, 120] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[130, 347] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[77, 160] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[108, 179] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[318, 373] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[48, 331] -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             UndirectedEdge[222, 312] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[292, 353] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[175, 204] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[198, 340] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[14, 207] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[45, 271] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[112, 183] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[85, 139] -> 
             RGBColor[
              0.6918173571428571, 0.7236127142857143, 0.6458675714285715], 
             UndirectedEdge[45, 97] -> RGBColor[0.984192, 0.987731, 0.911643],
              UndirectedEdge[130, 181] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[63, 90] -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             UndirectedEdge[114, 361] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[75, 209] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[42, 276] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[205, 358] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[76, 358] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[90, 142] -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             UndirectedEdge[152, 381] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[86, 309] -> 
             RGBColor[0.5652478571428571, 0.655645, 0.9600247142857143], 
             UndirectedEdge[104, 358] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[16, 369] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[278, 337] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[100, 350] -> 
             RGBColor[
              0.5863123571428571, 0.6485279285714286, 0.8438048571428571], 
             UndirectedEdge[90, 202] -> 
             RGBColor[
              0.8720902142857143, 0.7421052857142856, 0.6083590714285714], 
             UndirectedEdge[126, 367] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[278, 327] -> 
             RGBColor[0.6164135, 0.6895405, 0.9609201428571428], 
             UndirectedEdge[10, 200] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[149, 299] -> 
             RGBColor[
              0.6417487142857142, 0.7052103571428572, 0.7258179285714282], 
             UndirectedEdge[57, 284] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[125, 313] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[125, 196] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[21, 210] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[186, 374] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[6, 74] -> 
             RGBColor[
              0.7664822142857144, 0.7853505714285716, 0.6514355714285716], 
             UndirectedEdge[7, 312] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285715], 
             UndirectedEdge[238, 299] -> 
             RGBColor[
              0.6417487142857142, 0.7052103571428572, 0.7258179285714282], 
             UndirectedEdge[155, 239] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[108, 331] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[55, 87] -> 
             RGBColor[0.893163, 0.5900125714285714, 0.23176292857142858`], 
             UndirectedEdge[186, 288] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[178, 371] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[212, 238] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[292, 329] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[268, 338] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[68, 309] -> 
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285], 
             UndirectedEdge[129, 309] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139], 
             UndirectedEdge[137, 330] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[111, 400] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[62, 370] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[163, 280] -> 
             RGBColor[
              0.9527067142857144, 0.8455740000000003, 0.30492278571428577`], 
             UndirectedEdge[316, 383] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[307, 314] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[126, 259] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[44, 372] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[202, 279] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714286, 0.6064375714285715], 
             UndirectedEdge[148, 312] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285715], 
             UndirectedEdge[109, 358] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[142, 275] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[296, 375] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[92, 195] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[178, 248] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[41, 222] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[154, 356] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[70, 133] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[7, 80] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[152, 261] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[95, 229] -> 
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285], 
             UndirectedEdge[30, 204] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[133, 223] -> 
             RGBColor[
              0.7664822142857144, 0.7853505714285716, 0.6514355714285716], 
             UndirectedEdge[298, 306] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[40, 96] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[122, 146] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[223, 267] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[54, 322] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.3713353571428568], 
             UndirectedEdge[41, 154] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[245, 353] -> 
             RGBColor[
              0.7857647142857143, 0.8328318571428571, 0.9792104285714285], 
             UndirectedEdge[26, 62] -> 
             RGBColor[
              0.8975810714285715, 0.6807742857142856, 0.5899719285714284], 
             UndirectedEdge[217, 269] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[172, 347] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[63, 261] -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             UndirectedEdge[195, 369] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[65, 180] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285716], 
             UndirectedEdge[49, 211] -> 
             RGBColor[
              0.6325285714285713, 0.7084724285714286, 0.9666597142857143], 
             UndirectedEdge[285, 387] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[329, 388] -> 
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[38, 102] -> 
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[92, 188] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.38869121428571396`], 
             UndirectedEdge[114, 153] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[326, 337] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[38, 221] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[350, 394] -> 
             RGBColor[
              0.5863123571428572, 0.6485279285714285, 0.8438048571428571], 
             UndirectedEdge[286, 349] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[246, 320] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[322, 362] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714286, 0.6064375714285715], 
             UndirectedEdge[80, 348] -> 
             RGBColor[
              0.6399127142857144, 0.7173828571428571, 0.9655927142857142], 
             UndirectedEdge[78, 230] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[248, 329] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[43, 330] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[63, 217] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[79, 136] -> 
             RGBColor[
              0.8975810714285715, 0.6807742857142856, 0.5899719285714285], 
             UndirectedEdge[159, 243] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[1, 327] -> 
             RGBColor[
              0.6417487142857142, 0.7052103571428572, 0.7258179285714282], 
             UndirectedEdge[304, 353] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[240, 329] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[10, 311] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[353, 378] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[167, 243] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714286, 0.6064375714285715], 
             UndirectedEdge[169, 292] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[211, 347] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[224, 340] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[144, 233] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[273, 394] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[93, 94] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[358, 366] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[245, 329] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[44, 93] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[218, 314] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[133, 346] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285715, 0.6650532857142857], 
             UndirectedEdge[143, 272] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[272, 346] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[61, 269] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[158, 362] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[294, 393] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139], 
             UndirectedEdge[17, 298] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[83, 179] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[223, 398] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[52, 272] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[52, 174] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[63, 317] -> 
             RGBColor[
              0.8720902142857143, 0.7421052857142856, 0.6083590714285714], 
             UndirectedEdge[145, 280] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[152, 317] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.49249071428571434`], 
             UndirectedEdge[102, 391] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[168, 251] -> 
             RGBColor[
              0.6325285714285713, 0.7084724285714286, 0.9666597142857143], 
             UndirectedEdge[89, 245] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[293, 330] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[166, 247] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[8, 182] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[2, 215] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[61, 107] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[192, 361] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[71, 321] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[26, 389] -> 
             RGBColor[0.8527905, 0.6452381428571428, 0.5918934285714286], 
             UndirectedEdge[134, 263] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[105, 282] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285715, 0.6650532857142857], 
             UndirectedEdge[323, 340] -> 
             RGBColor[
              0.8799727857142857, 0.5454292857142857, 0.5731102142857143], 
             UndirectedEdge[311, 323] -> 
             RGBColor[0.905308, 0.5610991428571428, 0.33800799999999964`], 
             UndirectedEdge[29, 365] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[321, 384] -> 
             RGBColor[
              0.6419490714285714, 0.7070056428571428, 0.8469732857142858], 
             UndirectedEdge[115, 195] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[162, 359] -> 
             RGBColor[
              0.6309117142857142, 0.6691446428571429, 0.6420495000000002], 
             UndirectedEdge[106, 295] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[24, 242] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[109, 286] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[287, 367] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[74, 140] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[168, 394] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[68, 249] -> 
             RGBColor[0.5652478571428571, 0.655645, 0.9600247142857143], 
             UndirectedEdge[389, 400] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[267, 346] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[16, 392] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285715, 0.6650532857142858], 
             UndirectedEdge[13, 191] -> 
             RGBColor[
              0.6515733571428571, 0.5649184285714285, 0.5891733571428571], 
             UndirectedEdge[312, 327] -> 
             RGBColor[
              0.6309117142857142, 0.6691446428571429, 0.6420495000000002], 
             UndirectedEdge[260, 291] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[83, 344] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[200, 288] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[297, 332] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[189, 241] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285715], 
             UndirectedEdge[276, 358] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[11, 102] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[96, 243] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[171, 397] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[314, 385] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[11, 213] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[68, 129] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139], 
             UndirectedEdge[137, 277] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[35, 327] -> 
             RGBColor[
              0.5043422142857142, 0.6011769285714286, 0.9562066428571429], 
             UndirectedEdge[155, 183] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[63, 256] -> 
             RGBColor[
              0.7857647142857143, 0.8328318571428571, 0.9792104285714285], 
             UndirectedEdge[144, 358] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[192, 332] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[149, 259] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[146, 165] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[164, 280] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.38869121428571396`], 
             UndirectedEdge[65, 105] -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 
             UndirectedEdge[73, 369] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[187, 281] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[53, 253] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714286, 0.6064375714285715], 
             UndirectedEdge[132, 191] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.3713353571428568], 
             UndirectedEdge[29, 273] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[138, 366] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[229, 309] -> 
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285], 
             UndirectedEdge[274, 287] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[251, 312] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285715, 0.6650532857142858], 
             UndirectedEdge[339, 360] -> 
             RGBColor[
              0.7857647142857143, 0.8328318571428571, 0.9792104285714285], 
             UndirectedEdge[150, 365] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[61, 300] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[62, 389] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[374, 399] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[27, 51] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[58, 159] -> 
             RGBColor[
              0.6918173571428572, 0.7236127142857143, 0.6458675714285715], 
             UndirectedEdge[57, 153] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[84, 264] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[159, 201] -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 
             UndirectedEdge[80, 87] -> 
             RGBColor[
              0.8261372142857144, 0.7776062857142858, 0.6190799285714286], 
             UndirectedEdge[39, 288] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[91, 365] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[5, 384] -> 
             RGBColor[
              0.5716229285714285, 0.6540043571428571, 0.9628416428571429], 
             UndirectedEdge[156, 381] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[2, 197] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[238, 293] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[85, 325] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[146, 332] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[197, 204] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[20, 130] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[167, 348] -> 
             RGBColor[
              0.7262382142857143, 0.6266562857142857, 0.594741357142857], 
             UndirectedEdge[83, 237] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[178, 334] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285715, 0.6650532857142857], 
             UndirectedEdge[178, 388] -> 
             RGBColor[
              0.6918173571428571, 0.7236127142857143, 0.6458675714285715], 
             UndirectedEdge[115, 184] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[165, 385] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[202, 257] -> 
             RGBColor[0.9376635, 0.7931411428571429, 0.571257857142857], 
             UndirectedEdge[35, 57] -> 
             RGBColor[
              0.7857647142857143, 0.8328318571428571, 0.9792104285714285], 
             UndirectedEdge[115, 206] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[61, 98] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[33, 173] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[6, 185] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[300, 363] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[34, 270] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[162, 179] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285715, 0.6650532857142857], 
             UndirectedEdge[11, 250] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[66, 314] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[153, 327] -> 
             RGBColor[0.6164135, 0.6895405, 0.9609201428571428], 
             UndirectedEdge[153, 392] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[110, 369] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[321, 398] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[188, 278] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[213, 289] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[236, 263] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[93, 383] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[56, 286] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.3713353571428568], 
             UndirectedEdge[25, 144] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[143, 331] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[76, 257] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[91, 189] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[133, 145] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[207, 230] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[238, 336] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[123, 306] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[272, 338] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[11, 289] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[215, 300] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[224, 289] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[65, 161] -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 
             UndirectedEdge[14, 247] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[150, 226] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[15, 180] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[7, 114] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[108, 313] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[227, 315] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[174, 384] -> 
             RGBColor[0.6164135, 0.6895405, 0.9609201428571428], 
             UndirectedEdge[104, 138] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[313, 344] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[255, 374] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[87, 167] -> 
             RGBColor[
              0.9124627142857143, 0.6868797142857144, 0.24822857142857144`], 
             UndirectedEdge[114, 312] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[50, 265] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[310, 345] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[315, 334] -> 
             RGBColor[
              0.6325285714285713, 0.7084724285714286, 0.9666597142857143], 
             UndirectedEdge[102, 302] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[172, 211] -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             UndirectedEdge[264, 381] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[270, 397] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[48, 290] -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             UndirectedEdge[224, 323] -> 
             RGBColor[
              0.9055083571428572, 0.5628944285714286, 0.45916335714285716`], 
             UndirectedEdge[10, 339] -> 
             RGBColor[
              0.6399127142857144, 0.7173828571428571, 0.9655927142857142], 
             UndirectedEdge[254, 320] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[92, 392] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[166, 224] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[108, 344] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[180, 271] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[104, 207] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[45, 266] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[59, 373] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[107, 352] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[99, 338] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[186, 341] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[90, 156] -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             UndirectedEdge[34, 151] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[174, 260] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[13, 216] -> 
             RGBColor[
              0.6325285714285713, 0.7084724285714286, 0.9666597142857143], 
             UndirectedEdge[9, 217] -> RGBColor[0.984192, 0.987731, 0.911643],
              UndirectedEdge[87, 159] -> 
             RGBColor[
              0.9527067142857144, 0.8455740000000003, 0.30492278571428577`], 
             UndirectedEdge[184, 305] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[12, 259] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[27, 287] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[188, 284] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.38869121428571396`], 
             UndirectedEdge[118, 126] -> 
             RGBColor[
              0.8975810714285715, 0.6807742857142856, 0.5899719285714284], 
             UndirectedEdge[209, 304] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[48, 108] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[136, 376] -> 
             RGBColor[
              0.9231166428571429, 0.6982394285714284, 0.4760250714285715], 
             UndirectedEdge[48, 344] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[13, 198] -> 
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[286, 320] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[176, 368] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[248, 388] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[57, 188] -> 
             RGBColor[
              0.8934179285714285, 0.8304337142857143, 0.6257149285714285], 
             UndirectedEdge[39, 225] -> 
             RGBColor[
              0.9183637857142857, 0.6962739999999998, 0.5547922142857142], 
             UndirectedEdge[355, 379] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[85, 348] -> 
             RGBColor[
              0.7664822142857144, 0.7853505714285716, 0.6514355714285716], 
             UndirectedEdge[118, 336] -> 
             RGBColor[
              0.9231166428571429, 0.6982394285714284, 0.4760250714285715], 
             UndirectedEdge[195, 392] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285715], 
             UndirectedEdge[193, 281] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[154, 312] -> 
             RGBColor[
              0.7664822142857144, 0.7853505714285716, 0.6514355714285714], 
             UndirectedEdge[53, 171] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.4924907142857143], 
             UndirectedEdge[115, 188] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[319, 329] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[231, 359] -> 
             RGBColor[
              0.4257709285714286, 0.5385553571428572, 0.9492239285714286], 
             UndirectedEdge[288, 399] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[140, 220] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[9, 215] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[309, 329] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[9, 61] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[21, 82] -> 
             RGBColor[
              0.9055083571428572, 0.5628944285714286, 0.45916335714285716`], 
             UndirectedEdge[154, 361] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[160, 213] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[331, 342] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[122, 159] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285715], 
             UndirectedEdge[258, 278] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[37, 201] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285715], 
             UndirectedEdge[61, 314] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[297, 314] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[84, 175] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[72, 374] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[168, 180] -> 
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[36, 60] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[347, 387] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[140, 141] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.49249071428571434`], 
             UndirectedEdge[233, 382] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[21, 122] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[202, 268] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.4924907142857143], 
             UndirectedEdge[196, 344] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[109, 343] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[52, 117] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[51, 194] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.49249071428571434`], 
             UndirectedEdge[223, 342] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[241, 374] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[76, 109] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[90, 381] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[75, 227] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[209, 329] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[24, 358] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[208, 369] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[62, 400] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[127, 325] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[43, 277] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[70, 227] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[25, 366] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[20, 387] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[328, 387] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285715, 0.6650532857142857], 
             UndirectedEdge[249, 386] -> 
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[110, 243] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[47, 121] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.4924907142857143], 
             UndirectedEdge[31, 156] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[98, 283] -> 
             RGBColor[
              0.7857647142857143, 0.8328318571428571, 0.9792104285714285], 
             UndirectedEdge[38, 358] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[126, 199] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[39, 200] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[227, 304] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[242, 333] -> 
             RGBColor[
              0.9527067142857144, 0.8455740000000003, 0.30492278571428577`], 
             UndirectedEdge[30, 333] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[85, 96] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[39, 94] -> 
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[63, 138] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[119, 324] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[18, 224] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[84, 204] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[241, 288] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285716], 
             UndirectedEdge[91, 266] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[201, 263] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[29, 266] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[161, 326] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[174, 235] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[207, 233] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[199, 212] -> 
             RGBColor[
              0.6918173571428572, 0.7236127142857143, 0.6458675714285715], 
             UndirectedEdge[127, 184] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[261, 381] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[221, 230] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[22, 273] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[240, 292] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[120, 343] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[175, 310] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[55, 201] -> 
             RGBColor[
              0.9120792857142856, 0.6603784285714285, 0.27110128571428577`], 
             UndirectedEdge[264, 333] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[107, 197] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[131, 300] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[164, 227] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[75, 315] -> 
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[123, 193] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[157, 253] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[87, 110] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[112, 273] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[193, 384] -> 
             RGBColor[
              0.6417487142857142, 0.7052103571428572, 0.7258179285714282], 
             UndirectedEdge[95, 249] -> 
             RGBColor[0.5652478571428571, 0.655645, 0.9600247142857143], 
             UndirectedEdge[61, 66] -> 
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861], 
             UndirectedEdge[113, 251] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[107, 131] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[71, 343] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[113, 168] -> 
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[58, 201] -> 
             RGBColor[
              0.6918173571428572, 0.7236127142857143, 0.6458675714285715], 
             UndirectedEdge[47, 130] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.4924907142857143], 
             UndirectedEdge[17, 82] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[11, 25] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[73, 392] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[155, 337] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[159, 165] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[226, 368] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[188, 258] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[140, 350] -> 
             RGBColor[
              0.5863123571428571, 0.6485279285714286, 0.8438048571428571], 
             UndirectedEdge[14, 38] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[242, 268] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[20, 50] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[149, 212] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[80, 361] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[31, 204] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[209, 245] -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             UndirectedEdge[113, 148] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[48, 231] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[198, 224] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[1, 188] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.38869121428571396`], 
             UndirectedEdge[256, 264] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[15, 170] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[20, 322] -> 
             RGBColor[
              0.7262382142857143, 0.6266562857142857, 0.5947413571428571], 
             UndirectedEdge[92, 153] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[189, 360] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[272, 342] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[69, 219] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[86, 151] -> 
             RGBColor[
              0.7026543571428572, 0.7596784285714285, 0.7296359999999997], 
             UndirectedEdge[72, 288] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[266, 273] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[131, 297] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[219, 360] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[58, 236] -> 
             RGBColor[
              0.7026543571428572, 0.7596784285714285, 0.7296359999999997], 
             UndirectedEdge[272, 321] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[250, 391] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[122, 298] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[113, 282] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[237, 343] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[174, 398] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[223, 384] -> 
             RGBColor[
              0.4257709285714286, 0.5385553571428572, 0.9492239285714286], 
             UndirectedEdge[143, 260] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[148, 161] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285715], 
             UndirectedEdge[137, 199] -> 
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[147, 387] -> 
             RGBColor[
              0.6325285714285713, 0.7084724285714286, 0.9666597142857143], 
             UndirectedEdge[138, 381] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[42, 207] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[185, 247] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[49, 380] -> 
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[63, 242] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285715, 0.6650532857142858], 
             UndirectedEdge[12, 238] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[109, 382] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[4, 115] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[187, 279] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[152, 156] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[143, 290] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[48, 234] -> 
             RGBColor[
              0.6325285714285713, 0.7084724285714286, 0.9666597142857143], 
             UndirectedEdge[294, 341] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139], 
             UndirectedEdge[243, 351] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[241, 399] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[78, 207] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[174, 267] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[124, 293] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[57, 392] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285715, 0.6650532857142858], 
             UndirectedEdge[272, 331] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[91, 255] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[35, 337] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[219, 339] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[166, 185] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[137, 238] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[218, 300] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[96, 110] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[225, 375] -> 
             RGBColor[
              0.9231166428571429, 0.6982394285714284, 0.4760250714285715], 
             UndirectedEdge[24, 25] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[40, 361] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[141, 394] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.4924907142857143], 
             UndirectedEdge[200, 360] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[68, 229] -> 
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285], 
             UndirectedEdge[96, 258] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[106, 310] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[15, 394] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[115, 203] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[218, 298] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[165, 262] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[141, 357] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714286, 0.6064375714285715], 
             UndirectedEdge[15, 239] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[80, 228] -> 
             RGBColor[
              0.6399127142857144, 0.7173828571428571, 0.9655927142857142], 
             UndirectedEdge[260, 272] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[7, 361] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[22, 255] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[28, 380] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[53, 397] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714286, 0.6064375714285715], 
             UndirectedEdge[187, 306] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[208, 392] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285715], 
             UndirectedEdge[33, 381] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[290, 321] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[20, 116] -> 
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861], 
             UndirectedEdge[33, 156] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[9, 202] -> 
             RGBColor[0.9376635, 0.7931411428571429, 0.5712578571428572], 
             UndirectedEdge[76, 233] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[115, 369] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[183, 335] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[39, 296] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[10, 219] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[71, 143] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[232, 384] -> 
             RGBColor[
              0.6419490714285714, 0.7070056428571428, 0.8469732857142858], 
             UndirectedEdge[1, 57] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[288, 393] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[328, 372] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[16, 115] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[34, 244] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[233, 366] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[100, 105] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[88, 282] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[189, 219] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[44, 328] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[153, 154] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[73, 258] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[22, 141] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714286, 0.6064375714285714], 
             UndirectedEdge[100, 273] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[230, 391] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[338, 384] -> 
             RGBColor[
              0.6419490714285714, 0.7070056428571428, 0.8469732857142858], 
             UndirectedEdge[76, 207] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[144, 370] -> 
             RGBColor[
              0.7664822142857144, 0.7853505714285716, 0.6514355714285716], 
             UndirectedEdge[6, 340] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[30, 370] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[164, 245] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[56, 108] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.4924907142857143], 
             UndirectedEdge[50, 322] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.49249071428571434`], 
             UndirectedEdge[379, 399] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[6, 13] -> 
             RGBColor[
              0.6918173571428571, 0.7236127142857143, 0.6458675714285715], 
             UndirectedEdge[55, 60] -> 
             RGBColor[
              0.9183637857142857, 0.6962739999999998, 0.5547922142857142], 
             UndirectedEdge[44, 47] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.49249071428571434`], 
             UndirectedEdge[156, 264] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[32, 43] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285715, 0.6650532857142857], 
             UndirectedEdge[144, 207] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[14, 213] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[127, 139] -> 
             RGBColor[
              0.7026543571428571, 0.7596784285714285, 0.7296359999999997], 
             UndirectedEdge[321, 342] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[82, 182] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[50, 172] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[80, 96] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[78, 160] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[32, 293] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[322, 328] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714286], 
             UndirectedEdge[120, 254] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[291, 321] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[65, 312] -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 
             UndirectedEdge[209, 334] -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             UndirectedEdge[295, 310] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[109, 205] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[194, 376] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.4924907142857143], 
             UndirectedEdge[142, 338] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[232, 386] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[169, 378] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[94, 324] -> 
             RGBColor[
              0.6918173571428572, 0.7236127142857143, 0.6458675714285715], 
             UndirectedEdge[196, 231] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[207, 366] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[156, 310] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[206, 369] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[119, 225] -> 
             RGBColor[
              0.8975810714285715, 0.6807742857142856, 0.5899719285714285], 
             UndirectedEdge[69, 100] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[64, 182] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[217, 268] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[235, 275] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[5, 99] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[52, 267] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[290, 346] -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             UndirectedEdge[19, 108] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[92, 327] -> 
             RGBColor[
              0.6417487142857142, 0.7052103571428572, 0.7258179285714282], 
             UndirectedEdge[151, 244] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[114, 327] -> 
             RGBColor[
              0.6417487142857142, 0.7052103571428572, 0.7258179285714282], 
             UndirectedEdge[99, 174] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[180, 282] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[199, 277] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[237, 286] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[290, 313] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[56, 237] -> 
             RGBColor[
              0.8720902142857143, 0.7421052857142856, 0.6083590714285714], 
             UndirectedEdge[203, 361] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[169, 315] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[23, 304] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[129, 270] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[85, 284] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[203, 369] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139], 
             UndirectedEdge[1, 222] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[25, 205] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[301, 380] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[169, 329] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[302, 340] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[205, 391] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[96, 203] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[4, 195] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[269, 298] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[168, 220] -> 
             RGBColor[
              0.7026543571428572, 0.7596784285714285, 0.7296359999999997], 
             UndirectedEdge[291, 338] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[10, 360] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[87, 348] -> 
             RGBColor[
              0.7475659285714287, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[259, 274] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[293, 336] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[229, 245] -> 
             RGBColor[
              0.7857647142857143, 0.8328318571428571, 0.9792104285714285], 
             UndirectedEdge[173, 197] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[19, 344] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[83, 125] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[240, 315] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[7, 154] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[200, 225] -> 
             RGBColor[
              0.8975810714285715, 0.6807742857142856, 0.5899719285714285], 
             UndirectedEdge[13, 140] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[104, 366] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[116, 172] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[143, 267] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[51, 395] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[213, 224] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[130, 362] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[153, 278] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[83, 303] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[94, 296] -> 
             RGBColor[
              0.6325285714285713, 0.7084724285714286, 0.9666597142857143], 
             UndirectedEdge[147, 328] -> 
             RGBColor[
              0.6918173571428572, 0.7236127142857143, 0.6458675714285715], 
             UndirectedEdge[78, 102] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[22, 45] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[199, 238] -> 
             RGBColor[
              0.7026543571428572, 0.7596784285714285, 0.7296359999999997], 
             UndirectedEdge[21, 182] -> 
             RGBColor[0.7679015, 0.4570657142857143, 0.5683967142857143], 
             UndirectedEdge[126, 212] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[273, 365] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[149, 367] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[81, 89] -> 
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[57, 337] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[255, 288] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[2, 283] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139], 
             UndirectedEdge[94, 128] -> 
             RGBColor[
              0.7026543571428572, 0.7596784285714285, 0.7296359999999997], 
             UndirectedEdge[176, 393] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[65, 326] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[97, 282] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[12, 149] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[78, 144] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[201, 348] -> 
             RGBColor[
              0.7664822142857144, 0.7853505714285716, 0.6514355714285716], 
             UndirectedEdge[242, 381] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[43, 367] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285715, 0.6650532857142858], 
             UndirectedEdge[111, 197] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[69, 216] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[197, 295] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[193, 275] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[149, 238] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[79, 349] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[16, 110] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[49, 372] -> 
             RGBColor[
              0.7026543571428572, 0.7596784285714285, 0.7296359999999997], 
             UndirectedEdge[320, 343] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[221, 358] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[240, 245] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[85, 115] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[70, 280] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[151, 171] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[23, 163] -> 
             RGBColor[
              0.7664822142857144, 0.7853505714285716, 0.6514355714285714], 
             UndirectedEdge[255, 360] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[165, 307] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[81, 169] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[44, 316] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[195, 337] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[316, 390] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.38869121428571396`], 
             UndirectedEdge[39, 177] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[45, 190] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[287, 396] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[136, 343] -> 
             RGBColor[
              0.9183637857142857, 0.6962739999999998, 0.5547922142857142], 
             UndirectedEdge[296, 360] -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             UndirectedEdge[167, 228] -> 
             RGBColor[
              0.7262382142857143, 0.6266562857142857, 0.594741357142857], 
             UndirectedEdge[123, 279] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[33, 333] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[164, 209] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[22, 29] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[24, 366] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[178, 319] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285716], 
             UndirectedEdge[294, 368] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[13, 69] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[214, 295] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[80, 146] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139], 
             UndirectedEdge[56, 231] -> 
             RGBColor[
              0.7262382142857143, 0.6266562857142857, 0.594741357142857], 
             UndirectedEdge[134, 351] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[143, 291] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[120, 320] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[132, 220] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[6, 247] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[166, 289] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[114, 392] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[305, 325] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[44, 128] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[90, 242] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285715, 0.6650532857142858], 
             UndirectedEdge[1, 337] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[74, 224] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[160, 370] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[30, 84] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[293, 299] -> 
             RGBColor[
              0.6419490714285714, 0.7070056428571428, 0.8469732857142858], 
             UndirectedEdge[186, 399] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[163, 371] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[90, 138] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[71, 286] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[60, 201] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285715], 
             UndirectedEdge[128, 380] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[54, 128] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[25, 138] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[95, 129] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139], 
             UndirectedEdge[132, 302] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[15, 100] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[33, 63] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[275, 338] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[252, 277] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[146, 192] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[237, 254] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[37, 236] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[265, 362] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[341, 379] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[324, 380] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285716], 
             UndirectedEdge[63, 264] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[153, 337] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[112, 155] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[10, 177] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[238, 367] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[87, 228] -> 
             RGBColor[
              0.7475659285714287, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[66, 352] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[86, 386] -> 
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[52, 133] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[105, 112] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[4, 258] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[141, 339] -> 
             RGBColor[0.8048095, 0.689277857142857, 0.6017240714285714], 
             UndirectedEdge[251, 282] -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             UndirectedEdge[94, 390] -> 
             RGBColor[
              0.7026543571428572, 0.7596784285714285, 0.7296359999999997], 
             UndirectedEdge[239, 337] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[80, 243] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[366, 382] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[99, 306] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[214, 261] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[21, 60] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[60, 159] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285715], 
             UndirectedEdge[9, 300] -> RGBColor[0.984192, 0.987731, 0.911643],
              UndirectedEdge[114, 369] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[112, 350] -> 
             RGBColor[0.586112, 0.6467326428571428, 0.7226494999999997], 
             UndirectedEdge[18, 357] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[71, 320] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[226, 255] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[208, 258] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[11, 358] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[274, 299] -> 
             RGBColor[
              0.6371962142857143, 0.7050402142857143, 0.9257404285714286], 
             UndirectedEdge[147, 372] -> 
             RGBColor[
              0.7026543571428572, 0.7596784285714285, 0.7296359999999997], 
             UndirectedEdge[335, 337] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[36, 218] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[262, 300] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[109, 136] -> 
             RGBColor[
              0.9231166428571429, 0.6982394285714284, 0.4760250714285714], 
             UndirectedEdge[219, 241] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[37, 348] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[291, 384] -> 
             RGBColor[
              0.6419490714285714, 0.7070056428571428, 0.8469732857142858], 
             UndirectedEdge[10, 241] -> 
             RGBColor[
              0.7664822142857144, 0.7853505714285716, 0.6514355714285714], 
             UndirectedEdge[131, 314] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[1, 41] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[78, 400] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[191, 357] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714286, 0.6064375714285715], 
             UndirectedEdge[215, 352] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[96, 369] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[212, 293] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[66, 107] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[146, 159] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[11, 207] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[99, 218] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[131, 217] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[81, 163] -> 
             RGBColor[
              0.6918173571428572, 0.7236127142857143, 0.6458675714285715], 
             UndirectedEdge[50, 54] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[120, 286] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[17, 253] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[45, 365] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[35, 188] -> 
             RGBColor[
              0.8261372142857144, 0.7776062857142858, 0.6190799285714286], 
             UndirectedEdge[99, 279] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[107, 363] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[105, 271] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285716], 
             UndirectedEdge[191, 219] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.4924907142857143], 
             UndirectedEdge[177, 339] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[80, 167] -> 
             RGBColor[0.8048095, 0.689277857142857, 0.6017240714285714], 
             UndirectedEdge[48, 56] -> 
             RGBColor[
              0.8720902142857143, 0.7421052857142856, 0.6083590714285714], 
             UndirectedEdge[42, 136] -> 
             RGBColor[
              0.9183637857142857, 0.6962739999999998, 0.5547922142857142], 
             UndirectedEdge[77, 102] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[73, 203] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139], 
             UndirectedEdge[35, 284] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139], 
             UndirectedEdge[274, 367] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285715], 
             UndirectedEdge[33, 310] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[175, 295] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[70, 75] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[57, 258] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[70, 145] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[12, 336] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[18, 216] -> 
             RGBColor[
              0.7857647142857143, 0.8328318571428571, 0.9792104285714285], 
             UndirectedEdge[158, 311] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[8, 36] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[119, 200] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[181, 362] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[9, 306] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[82, 253] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285716], 
             UndirectedEdge[146, 314] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[27, 277] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[6, 302] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[93, 296] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[153, 284] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[43, 199] -> 
             RGBColor[
              0.6325285714285713, 0.7084724285714286, 0.9666597142857143], 
             UndirectedEdge[213, 250] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285716], 
             UndirectedEdge[3, 232] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[5, 235] -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             UndirectedEdge[25, 391] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[288, 341] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[181, 265] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[295, 363] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[278, 284] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[167, 351] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714286, 0.6064375714285715], 
             UndirectedEdge[198, 311] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[54, 328] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[261, 310] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[68, 319] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[100, 141] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.49249071428571434`], 
             UndirectedEdge[139, 325] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[123, 338] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[317, 370] -> 
             RGBColor[
              0.7262382142857143, 0.6266562857142857, 0.594741357142857], 
             UndirectedEdge[160, 400] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[150, 266] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[134, 201] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[161, 251] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285715, 0.6650532857142857], 
             UndirectedEdge[86, 371] -> 
             RGBColor[
              0.7026543571428572, 0.7596784285714285, 0.7296359999999997], 
             UndirectedEdge[105, 350] -> 
             RGBColor[0.575275, 0.6106669285714287, 0.6388810714285715], 
             UndirectedEdge[54, 362] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[4, 208] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[176, 294] -> 
             RGBColor[0.8450535, 0.847972142857143, 0.6584182857142857], 
             UndirectedEdge[113, 170] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[14, 205] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[262, 306] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[47, 128] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.3713353571428568], 
             UndirectedEdge[257, 382] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[165, 228] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[72, 341] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[50, 116] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[230, 247] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[45, 100] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[95, 386] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[182, 244] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[104, 382] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[58, 210] -> 
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[102, 370] -> 
             RGBColor[0.48667657142857146`, 0.5930234285714285, 0.953042], 
             UndirectedEdge[1, 161] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[153, 356] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[1, 154] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[341, 399] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[373, 395] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[190, 266] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[73, 85] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[221, 250] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[23, 353] -> 
             RGBColor[
              0.6399127142857144, 0.7173828571428571, 0.9655927142857142], 
             UndirectedEdge[171, 270] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[277, 396] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[315, 371] -> 
             RGBColor[
              0.7026543571428572, 0.7596784285714285, 0.7296359999999997], 
             UndirectedEdge[207, 391] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[160, 247] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[193, 232] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[22, 91] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[78, 247] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[87, 192] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[226, 294] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[177, 311] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[189, 200] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[67, 184] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[33, 256] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[176, 226] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285716], 
             UndirectedEdge[145, 162] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[286, 343] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[13, 18] -> 
             RGBColor[0.5652478571428571, 0.655645, 0.9600247142857143], 
             UndirectedEdge[86, 308] -> 
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[364, 377] -> 
             RGBColor[
              0.8934179285714285, 0.8304337142857143, 0.6257149285714285], 
             UndirectedEdge[90, 152] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[1, 153] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[92, 114] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[132, 219] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[107, 215] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[240, 319] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[58, 110] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[67, 85] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[125, 344] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[198, 219] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[16, 325] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[119, 390] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[7, 153] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[23, 164] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[46, 373] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[301, 316] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.38869121428571396`], 
             UndirectedEdge[22, 150] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[161, 327] -> 
             RGBColor[
              0.6309117142857142, 0.6691446428571429, 0.6420495000000002], 
             UndirectedEdge[123, 281] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[111, 160] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[277, 287] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[48, 120] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[6, 224] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[103, 313] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[8, 60] -> RGBColor[0.984192, 0.987731, 0.911643], 
             UndirectedEdge[284, 392] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[218, 279] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[135, 221] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[95, 309] -> 
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285], 
             UndirectedEdge[80, 385] -> 
             RGBColor[
              0.6399127142857144, 0.7173828571428571, 0.9655927142857142], 
             UndirectedEdge[272, 398] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[33, 264] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[76, 366] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[41, 258] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[174, 232] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[61, 307] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[35, 392] -> 
             RGBColor[0.8450535, 0.847972142857143, 0.6584182857142857], 
             UndirectedEdge[212, 259] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[73, 110] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[122, 228] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[41, 203] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[361, 385] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[9, 269] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[192, 228] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[47, 265] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.3713353571428568], 
             UndirectedEdge[338, 398] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[71, 79] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[77, 78] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[89, 164] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[123, 235] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[72, 393] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[240, 371] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[196, 303] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[105, 170] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[195, 208] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[100, 180] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[39, 355] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[244, 397] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[225, 355] -> 
             RGBColor[
              0.9231166428571429, 0.6982394285714284, 0.4760250714285715], 
             UndirectedEdge[335, 354] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[97, 100] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[2, 107] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[128, 225] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.3548697142857139], 
             UndirectedEdge[96, 228] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[262, 307] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[86, 334] -> 
             RGBColor[
              0.6325285714285713, 0.7084724285714286, 0.9666597142857143], 
             UndirectedEdge[255, 399] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[138, 242] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285715], 
             UndirectedEdge[27, 396] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[163, 209] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285715, 0.6650532857142857], 
             UndirectedEdge[63, 202] -> 
             RGBColor[
              0.8720902142857143, 0.7421052857142856, 0.6083590714285714], 
             UndirectedEdge[347, 372] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[174, 275] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[209, 315] -> 
             RGBColor[
              0.6325285714285713, 0.7084724285714286, 0.9666597142857143], 
             UndirectedEdge[177, 374] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[214, 215] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[160, 185] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[63, 268] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[48, 196] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[34, 95] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[84, 333] -> 
             RGBColor[
              0.7475659285714287, 0.7149847142857144, 0.6120972142857143], 
             UndirectedEdge[102, 224] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[105, 326] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[134, 236] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[92, 161] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[77, 185] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[178, 329] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285716], 
             UndirectedEdge[185, 400] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[317, 333] -> 
             RGBColor[
              0.9124627142857143, 0.6868797142857144, 0.24822857142857144`], 
             UndirectedEdge[106, 215] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[14, 340] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[233, 358] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[74, 191] -> 
             RGBColor[
              0.7262382142857143, 0.6266562857142857, 0.5947413571428571], 
             UndirectedEdge[53, 244] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.4924907142857143], 
             UndirectedEdge[4, 16] -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             UndirectedEdge[149, 274] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[326, 335] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[30, 77] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[129, 229] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139], 
             UndirectedEdge[216, 219] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[138, 233] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[28, 44] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[163, 227] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[15, 335] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[257, 268] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[217, 279] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[93, 119] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[67, 305] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[153, 195] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[50, 135] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[68, 334] -> 
             RGBColor[
              0.7857647142857143, 0.8328318571428571, 0.9792104285714285], 
             UndirectedEdge[95, 308] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[17, 36] -> 
             RGBColor[
              0.6399127142857144, 0.7173828571428571, 0.9655927142857142], 
             UndirectedEdge[41, 361] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[117, 371] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[89, 304] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[267, 272] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[20, 158] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[30, 62] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[197, 310] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[142, 268] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[78, 213] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[48, 71] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[262, 269] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[27, 376] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[245, 292] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[142, 217] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[142, 363] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[121, 130] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[217, 300] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[25, 109] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[40, 146] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[18, 140] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[170, 239] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[152, 333] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[14, 250] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[55, 159] -> 
             RGBColor[
              0.9120792857142856, 0.6603784285714285, 0.27110128571428577`], 
             UndirectedEdge[234, 331] -> 
             RGBColor[
              0.6325285714285713, 0.7084724285714286, 0.9666597142857143], 
             UndirectedEdge[370, 389] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[119, 316] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[89, 227] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[246, 254] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[197, 345] -> 
             RGBColor[
              0.7664822142857144, 0.7853505714285716, 0.6514355714285714], 
             UndirectedEdge[231, 234] -> 
             RGBColor[0.48667657142857146`, 0.5930234285714285, 0.953042], 
             UndirectedEdge[89, 209] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[233, 317] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.49249071428571434`], 
             UndirectedEdge[48, 342] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[24, 104] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[118, 149] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.3548697142857139], 
             UndirectedEdge[34, 53] -> 
             RGBColor[0.9376635, 0.7931411428571429, 0.5712578571428572], 
             UndirectedEdge[29, 45] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[35, 208] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[69, 191] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714286, 0.6064375714285714], 
             UndirectedEdge[102, 166] -> 
             RGBColor[0.5652478571428571, 0.655645, 0.9600247142857143], 
             UndirectedEdge[185, 213] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[172, 364] -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             UndirectedEdge[36, 55] -> 
             RGBColor[
              0.7855097857142856, 0.5924107142857142, 0.5852584285714285], 
             UndirectedEdge[192, 203] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[105, 394] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[256, 261] -> 
             RGBColor[
              0.7857647142857143, 0.8328318571428571, 0.9792104285714285], 
             UndirectedEdge[215, 295] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[219, 357] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[204, 295] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[24, 138] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[135, 376] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[127, 305] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[54, 158] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[180, 350] -> 
             RGBColor[0.5815595, 0.6465625, 0.922572], 
             UndirectedEdge[46, 287] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[41, 153] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[163, 315] -> 
             RGBColor[
              0.6918173571428571, 0.7236127142857143, 0.6458675714285715], 
             UndirectedEdge[17, 64] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[67, 127] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[83, 246] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[44, 383] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[5, 275] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[99, 123] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[278, 354] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[61, 215] -> 
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861], 
             UndirectedEdge[115, 208] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[167, 203] -> 
             RGBColor[0.8048095, 0.689277857142857, 0.6017240714285714], 
             UndirectedEdge[242, 256] -> 
             RGBColor[0.8450535, 0.847972142857143, 0.6584182857142857], 
             UndirectedEdge[136, 254] -> 
             RGBColor[
              0.8975810714285715, 0.6807742857142856, 0.5899719285714284], 
             UndirectedEdge[65, 170] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[247, 340] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[8, 17] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[269, 300] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[233, 242] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[242, 382] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285716], 
             UndirectedEdge[144, 242] -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 
             UndirectedEdge[81, 227] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[224, 230] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[81, 248] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[13, 323] -> 
             RGBColor[
              0.6146653571428571, 0.3327062857142857, 0.5558460000000001], 
             UndirectedEdge[10, 189] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[135, 364] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[39, 383] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[108, 196] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[75, 89] -> RGBColor[0.984192, 0.987731, 0.911643],
              UndirectedEdge[131, 269] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[36, 165] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139], 
             UndirectedEdge[40, 41] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[86, 249] -> 
             RGBColor[0.4120117142857142, 0.5312855714285714, 0.947474], 
             UndirectedEdge[287, 395] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[177, 225] -> 
             RGBColor[
              0.9231166428571429, 0.6982394285714284, 0.4760250714285714], 
             UndirectedEdge[74, 216] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[229, 371] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139], 
             UndirectedEdge[319, 371] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[169, 353] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[47, 362] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714286, 0.6064375714285715], 
             UndirectedEdge[83, 313] -> 
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861], 
             UndirectedEdge[87, 210] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[91, 150] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[16, 258] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[334, 388] -> 
             RGBColor[
              0.6325285714285713, 0.7084724285714286, 0.9666597142857143], 
             UndirectedEdge[67, 325] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[279, 363] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[192, 385] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[216, 339] -> 
             RGBColor[
              0.7857647142857143, 0.8328318571428571, 0.9792104285714285], 
             UndirectedEdge[74, 323] -> 
             RGBColor[0.6893302142857143, 0.39444414285714285`, 0.561414], 
             UndirectedEdge[60, 87] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[74, 198] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[16, 348] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[88, 283] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[292, 388] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[76, 382] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[131, 352] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[123, 232] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[69, 357] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[241, 339] -> 
             RGBColor[0.8450535, 0.847972142857143, 0.6584182857142857], 
             UndirectedEdge[181, 322] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.49249071428571434`], 
             UndirectedEdge[140, 168] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[88, 357] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[125, 179] -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             UndirectedEdge[316, 324] -> 
             RGBColor[
              0.9527067142857144, 0.8455740000000003, 0.30492278571428577`], 
             UndirectedEdge[128, 390] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[200, 339] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[85, 110] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[178, 209] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285715, 0.6650532857142857], 
             UndirectedEdge[380, 383] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[350, 357] -> 
             RGBColor[
              0.5607767857142858, 0.6310627857142856, 0.9577517142857143], 
             UndirectedEdge[98, 352] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[68, 151] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139], 
             UndirectedEdge[307, 385] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[94, 119] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[116, 121] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[1, 361] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[180, 239] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[45, 394] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[32, 124] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[87, 243] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[188, 195] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[122, 262] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[118, 212] -> 
             RGBColor[
              0.9120792857142856, 0.6603784285714285, 0.27110128571428577`], 
             UndirectedEdge[35, 258] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[183, 271] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[130, 147] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[124, 330] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[46, 395] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[206, 284] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[179, 313] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[215, 363] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[260, 338] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[88, 113] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[95, 270] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[16, 184] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[38, 78] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[8, 210] -> RGBColor[0.984192, 0.987731, 0.911643],
              UndirectedEdge[1, 96] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[213, 247] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[109, 366] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[223, 260] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[393, 399] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[25, 358] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[207, 358] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[31, 33] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[355, 375] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[25, 104] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[360, 375] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[28, 347] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[56, 143] -> 
             RGBColor[0.9376635, 0.7931411428571429, 0.571257857142857], 
             UndirectedEdge[73, 115] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[157, 218] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[267, 321] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[93, 324] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[178, 245] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285715, 0.6650532857142857], 
             UndirectedEdge[223, 331] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[318, 367] -> 
             RGBColor[
              0.7664822142857144, 0.7853505714285716, 0.6514355714285714], 
             UndirectedEdge[158, 265] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[124, 199] -> 
             RGBColor[
              0.7026543571428571, 0.7596784285714285, 0.7296359999999997], 
             UndirectedEdge[38, 213] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285715], 
             UndirectedEdge[128, 296] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[89, 315] -> 
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[129, 178] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[61, 279] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[7, 332] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[105, 180] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285716], 
             UndirectedEdge[75, 163] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285715], 
             UndirectedEdge[15, 273] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[149, 287] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[123, 275] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[186, 226] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[15, 183] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[35, 41] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[47, 54] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.3713353571428568], 
             UndirectedEdge[19, 196] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[211, 328] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285715, 0.6650532857142858], 
             UndirectedEdge[3, 86] -> 
             RGBColor[
              0.6325285714285713, 0.7084724285714286, 0.9666597142857143], 
             UndirectedEdge[55, 58] -> 
             RGBColor[
              0.6322736428571428, 0.46805128571428556`, 0.5727077142857142], 
             UndirectedEdge[63, 214] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[26, 106] -> 
             RGBColor[
              0.9231166428571429, 0.6982394285714284, 0.4760250714285715], 
             UndirectedEdge[89, 378] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[191, 311] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.3713353571428568], 
             UndirectedEdge[147, 364] -> 
             RGBColor[
              0.6325285714285713, 0.7084724285714286, 0.9666597142857143], 
             UndirectedEdge[137, 285] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[104, 205] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[191, 339] -> 
             RGBColor[0.8048095, 0.689277857142857, 0.6017240714285714], 
             UndirectedEdge[40, 167] -> 
             RGBColor[
              0.8720902142857143, 0.7421052857142856, 0.6083590714285714], 
             UndirectedEdge[17, 262] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[96, 348] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[60, 122] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[99, 187] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[111, 166] -> 
             RGBColor[
              0.7857647142857143, 0.8328318571428571, 0.9792104285714285], 
             UndirectedEdge[130, 172] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[205, 230] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[248, 319] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[77, 111] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[41, 188] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[57, 278] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[56, 331] -> 
             RGBColor[
              0.8720902142857143, 0.7421052857142856, 0.6083590714285714], 
             UndirectedEdge[40, 87] -> 
             RGBColor[
              0.8934179285714285, 0.8304337142857143, 0.6257149285714285], 
             UndirectedEdge[142, 214] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[341, 368] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[96, 188] -> 
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286], 
             UndirectedEdge[142, 202] -> 
             RGBColor[
              0.8720902142857143, 0.7421052857142856, 0.6083590714285714], 
             UndirectedEdge[37, 351] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[83, 108] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[72, 119] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[170, 180] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[196, 234] -> 
             RGBColor[
              0.7026543571428571, 0.7596784285714285, 0.7296359999999997], 
             UndirectedEdge[218, 306] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[186, 189] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[20, 135] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[79, 254] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[93, 355] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[211, 301] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[145, 227] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[26, 345] -> 
             RGBColor[
              0.9120792857142856, 0.6603784285714285, 0.27110128571428577`], 
             UndirectedEdge[132, 140] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[153, 258] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[56, 344] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714286, 0.6064375714285715], 
             UndirectedEdge[44, 390] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[223, 346] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[114, 222] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[85, 203] -> 
             RGBColor[0.8450535, 0.847972142857143, 0.6584182857142857], 
             UndirectedEdge[156, 261] -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             UndirectedEdge[33, 295] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[59, 395] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[334, 371] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[40, 154] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[300, 306] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[61, 297] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[97, 350] -> 
             RGBColor[0.5815595, 0.6465625, 0.922572], 
             UndirectedEdge[178, 229] -> 
             RGBColor[0.8450535, 0.847972142857143, 0.6584182857142857], 
             UndirectedEdge[130, 265] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[110, 134] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[147, 211] -> 
             RGBColor[
              0.6325285714285713, 0.7084724285714286, 0.9666597142857143], 
             UndirectedEdge[78, 185] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[130, 135] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[52, 384] -> 
             RGBColor[
              0.6417487142857142, 0.7052103571428572, 0.7258179285714282], 
             UndirectedEdge[77, 166] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[24, 76] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[100, 220] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[41, 369] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[12, 318] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[118, 199] -> 
             RGBColor[
              0.6322736428571428, 0.46805128571428556`, 0.5727077142857142], 
             UndirectedEdge[11, 205] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[120, 136] -> 
             RGBColor[
              0.9231166428571429, 0.6982394285714284, 0.4760250714285714], 
             UndirectedEdge[66, 215] -> 
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861], 
             UndirectedEdge[199, 287] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[8, 64] -> RGBColor[0.984192, 0.987731, 0.911643], 
             UndirectedEdge[312, 361] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[5, 193] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[187, 232] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[115, 325] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[137, 252] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[296, 390] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[101, 171] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[234, 342] -> 
             RGBColor[
              0.7026543571428572, 0.7596784285714285, 0.7296359999999997], 
             UndirectedEdge[56, 343] -> 
             RGBColor[0.9376635, 0.7931411428571429, 0.571257857142857], 
             UndirectedEdge[60, 146] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[149, 336] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[12, 199] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[42, 104] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[216, 323] -> 
             RGBColor[
              0.8351822142857143, 0.5098931428571428, 0.5750317142857142], 
             UndirectedEdge[110, 192] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[93, 380] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[34, 397] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[249, 308] -> 
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[116, 130] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[81, 315] -> 
             RGBColor[0.4120117142857142, 0.5312855714285714, 0.947474], 
             UndirectedEdge[99, 193] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[116, 135] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[304, 378] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[56, 120] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.4924907142857143], 
             UndirectedEdge[255, 393] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[106, 214] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[130, 328] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[181, 250] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[102, 230] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[45, 141] -> 
             RGBColor[0.9376635, 0.7931411428571429, 0.5712578571428572], 
             UndirectedEdge[225, 288] -> 
             RGBColor[
              0.9183637857142857, 0.6962739999999998, 0.5547922142857142], 
             UndirectedEdge[208, 278] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[342, 346] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[133, 164] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[287, 373] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[122, 314] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[85, 351] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[5, 338] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[311, 339] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139], 
             UndirectedEdge[39, 324] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285715], 
             UndirectedEdge[52, 346] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[272, 291] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[191, 323] -> 
             RGBColor[
              0.8542270000000001, 0.3663391428571428, 0.19754535714285715`], 
             UndirectedEdge[60, 165] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[44, 301] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[11, 144] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[333, 381] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[9, 363] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[153, 312] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[55, 80] -> 
             RGBColor[
              0.7855097857142856, 0.5924107142857142, 0.5852584285714286], 
             UndirectedEdge[7, 40] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[51, 377] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[112, 170] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[200, 375] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[94, 200] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[8, 253] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[31, 295] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[301, 383] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[327, 392] -> 
             RGBColor[0.6309117142857144, 0.6691446428571429, 0.6420495], 
             UndirectedEdge[119, 375] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[160, 340] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[151, 308] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[221, 276] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[94, 316] -> 
             RGBColor[
              0.6729010714285715, 0.6532468571428572, 0.6065292142857144], 
             UndirectedEdge[195, 206] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[159, 192] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[220, 350] -> 
             RGBColor[0.586112, 0.6467326428571428, 0.7226494999999997], 
             UndirectedEdge[229, 319] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[69, 97] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[90, 317] -> 
             RGBColor[
              0.8720902142857143, 0.7421052857142856, 0.6083590714285714], 
             UndirectedEdge[136, 237] -> 
             RGBColor[0.8527905, 0.6452381428571428, 0.5918934285714286], 
             UndirectedEdge[69, 141] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714286, 0.6064375714285714], 
             UndirectedEdge[48, 143] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[51, 246] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[97, 132] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[94, 383] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[246, 344] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[155, 354] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[107, 307] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[310, 363] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[99, 281] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[123, 187] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[23, 227] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[28, 211] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[327, 356] -> 
             RGBColor[
              0.6371962142857142, 0.7050402142857143, 0.9257404285714286], 
             UndirectedEdge[140, 219] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[104, 144] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[49, 328] -> 
             RGBColor[
              0.6918173571428572, 0.7236127142857143, 0.6458675714285715], 
             UndirectedEdge[112, 271] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[106, 197] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[106, 204] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[50, 158] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[259, 299] -> 
             RGBColor[0.6164135, 0.6895405, 0.9609201428571428], 
             UndirectedEdge[79, 286] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[240, 388] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[118, 299] -> 
             RGBColor[0.571368, 0.41358321428571415`, 0.5688896428571428], 
             UndirectedEdge[138, 257] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[171, 244] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[161, 337] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285716], 
             UndirectedEdge[119, 355] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[248, 292] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[68, 386] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[126, 299] -> 
             RGBColor[0.6164135, 0.6895405, 0.9609201428571428], 
             UndirectedEdge[128, 383] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[229, 248] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[395, 396] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[81, 292] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[34, 253] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[130, 322] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.49249071428571434`], 
             UndirectedEdge[74, 311] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[232, 235] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[207, 221] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[140, 216] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[31, 173] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[37, 243] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[1, 35] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139], 
             UndirectedEdge[60, 210] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[35, 92] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139], 
             UndirectedEdge[52, 291] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[77, 400] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[77, 389] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[96, 361] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[150, 374] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[80, 154] -> 
             RGBColor[
              0.6399127142857144, 0.7173828571428571, 0.9655927142857142], 
             UndirectedEdge[200, 383] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[144, 391] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[196, 290] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[159, 228] -> 
             RGBColor[
              0.7664822142857144, 0.7853505714285716, 0.6514355714285716], 
             UndirectedEdge[27, 377] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.38869121428571396`], 
             UndirectedEdge[24, 233] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[24, 109] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[189, 255] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[262, 298] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[249, 397] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[128, 324] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[7, 228] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[115, 258] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[375, 383] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[257, 338] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[5, 321] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[65, 239] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[56, 71] -> 
             RGBColor[0.9376635, 0.7931411428571429, 0.571257857142857], 
             UndirectedEdge[276, 322] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.49249071428571434`], 
             UndirectedEdge[239, 326] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[379, 393] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[131, 262] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[201, 210] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285716], 
             UndirectedEdge[301, 372] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[291, 398] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[28, 49] -> 
             RGBColor[0.48667657142857146`, 0.5930234285714285, 0.953042], 
             UndirectedEdge[6, 160] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[375, 379] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[45, 112] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[324, 390] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[169, 227] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[44, 380] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[288, 360] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[87, 134] -> 
             RGBColor[
              0.9637440714285714, 0.8834350000000002, 0.5098465714285715], 
             UndirectedEdge[85, 258] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[26, 77] -> 
             RGBColor[
              0.8975810714285715, 0.6807742857142856, 0.5899719285714284], 
             UndirectedEdge[90, 333] -> 
             RGBColor[
              0.8934179285714285, 0.8304337142857143, 0.6257149285714285], 
             UndirectedEdge[45, 91] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[103, 133] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285715], 
             UndirectedEdge[143, 342] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[75, 164] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[44, 211] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[82, 171] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[17, 122] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[150, 186] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[180, 394] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[156, 202] -> 
             RGBColor[
              0.8720902142857143, 0.7421052857142856, 0.6083590714285714], 
             UndirectedEdge[86, 178] -> 
             RGBColor[
              0.6918173571428572, 0.7236127142857143, 0.6458675714285715], 
             UndirectedEdge[102, 250] -> 
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[7, 222] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[97, 220] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[230, 289] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[14, 289] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[77, 370] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[151, 270] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[173, 214] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[144, 317] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714286], 
             UndirectedEdge[31, 175] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[163, 240] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[329, 371] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[72, 375] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[32, 238] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[11, 14] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[79, 237] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[69, 74] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[16, 203] -> 
             RGBColor[
              0.7857647142857143, 0.8328318571428571, 0.9792104285714285], 
             UndirectedEdge[315, 319] -> 
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[40, 80] -> 
             RGBColor[
              0.7857647142857143, 0.8328318571428571, 0.9792104285714285], 
             UndirectedEdge[18, 198] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[300, 307] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[191, 198] -> 
             RGBColor[0.9376635, 0.7931411428571429, 0.571257857142857], 
             UndirectedEdge[289, 391] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[132, 357] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[157, 187] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[38, 250] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[140, 191] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.49249071428571434`], 
             UndirectedEdge[204, 261] -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             UndirectedEdge[337, 354] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[300, 314] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[292, 378] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[153, 361] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[240, 334] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[52, 260] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[128, 177] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[16, 85] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285715, 0.6650532857142858], 
             UndirectedEdge[179, 303] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[48, 320] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[136, 320] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.3548697142857139], 
             UndirectedEdge[96, 192] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[140, 357] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[202, 306] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714286, 0.6064375714285715], 
             UndirectedEdge[114, 258] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[87, 236] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.38869121428571396`], 
             UndirectedEdge[116, 362] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[36, 64] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[245, 304] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[187, 218] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[26, 370] -> 
             RGBColor[0.7069385, 0.5297891428571427, 0.5782757142857142], 
             UndirectedEdge[91, 141] -> 
             RGBColor[0.8048095, 0.689277857142857, 0.6017240714285714], 
             UndirectedEdge[55, 385] -> 
             RGBColor[0.7069385, 0.5297891428571427, 0.5782757142857142], 
             UndirectedEdge[179, 231] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[94, 177] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[225, 383] -> 
             RGBColor[
              0.8975810714285715, 0.6807742857142856, 0.5899719285714284], 
             UndirectedEdge[37, 134] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[255, 341] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[206, 278] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[131, 279] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[7, 203] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[101, 151] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139], 
             UndirectedEdge[200, 296] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[86, 229] -> 
             RGBColor[0.5652478571428571, 0.655645, 0.9600247142857143], 
             UndirectedEdge[138, 382] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[195, 278] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[65, 113] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285716], 
             UndirectedEdge[249, 270] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[319, 388] -> 
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[138, 256] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[246, 286] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[188, 208] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[173, 345] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[84, 156] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[136, 349] -> 
             RGBColor[
              0.9183637857142857, 0.6962739999999998, 0.5547922142857142], 
             UndirectedEdge[117, 346] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[26, 197] -> 
             RGBColor[0.7069385, 0.5297891428571427, 0.5782757142857142], 
             UndirectedEdge[328, 362] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[187, 275] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[20, 121] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[198, 302] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[1, 312] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[89, 292] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[304, 315] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[21, 64] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[201, 351] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[17, 218] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[266, 365] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[112, 180] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[247, 289] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[15, 45] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[57, 92] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[53, 86] -> 
             RGBColor[
              0.6515733571428571, 0.5649184285714285, 0.5891733571428572], 
             UndirectedEdge[114, 154] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[71, 237] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[241, 375] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[100, 282] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[55, 146] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.3548697142857139], 
             UndirectedEdge[309, 319] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[13, 302] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[110, 348] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[217, 363] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[39, 380] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[248, 304] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[204, 400] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[69, 168] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[68, 86] -> 
             RGBColor[0.5652478571428571, 0.655645, 0.9600247142857143], 
             UndirectedEdge[175, 264] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[1, 92] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[368, 393] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[332, 361] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[80, 203] -> 
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285], 
             UndirectedEdge[20, 347] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[18, 311] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139], 
             UndirectedEdge[170, 282] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[198, 323] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[168, 357] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[180, 326] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[18, 340] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[74, 340] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[173, 204] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[26, 30] -> 
             RGBColor[
              0.9183637857142857, 0.6962739999999998, 0.5547922142857142], 
             UndirectedEdge[169, 240] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[95, 371] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139], 
             UndirectedEdge[65, 356] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285716], 
             UndirectedEdge[264, 310] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[96, 114] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[244, 308] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[187, 298] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[58, 228] -> 
             RGBColor[0.48667657142857146`, 0.5930234285714285, 0.953042], 
             UndirectedEdge[36, 82] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[72, 355] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[22, 350] -> 
             RGBColor[
              0.5607767857142857, 0.6310627857142858, 0.9577517142857143], 
             UndirectedEdge[58, 192] -> 
             RGBColor[
              0.7028547142857142, 0.7614737142857142, 0.8507913571428571], 
             UndirectedEdge[3, 174] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[44, 54] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[21, 36] -> 
             RGBColor[0.7679015, 0.4570657142857143, 0.5683967142857143], 
             UndirectedEdge[170, 271] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[192, 201] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[274, 395] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[208, 284] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[237, 320] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[119, 380] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[342, 398] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[90, 264] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[212, 367] -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 
             UndirectedEdge[92, 284] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[267, 342] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[107, 297] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[163, 245] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285715, 0.6650532857142857], 
             UndirectedEdge[72, 200] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[254, 286] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[269, 307] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[240, 304] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[228, 332] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[104, 109] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[28, 372] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[28, 362] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[209, 227] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[245, 371] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[308, 397] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[58, 87] -> 
             RGBColor[
              0.6729010714285715, 0.6532468571428572, 0.6065292142857144], 
             UndirectedEdge[154, 332] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[97, 180] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[202, 300] -> 
             RGBColor[0.9376635, 0.7931411428571429, 0.571257857142857], 
             UndirectedEdge[25, 317] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.3713353571428568], 
             UndirectedEdge[93, 128] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[68, 178] -> 
             RGBColor[0.8450535, 0.847972142857143, 0.6584182857142857], 
             UndirectedEdge[271, 273] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[149, 318] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[42, 358] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[155, 170] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[193, 338] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[79, 109] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[173, 175] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[95, 178] -> 
             RGBColor[0.8450535, 0.847972142857143, 0.6584182857142857], 
             UndirectedEdge[243, 348] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[56, 83] -> 
             RGBColor[
              0.7262382142857143, 0.6266562857142857, 0.594741357142857], 
             UndirectedEdge[205, 207] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[74, 302] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[179, 196] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[174, 338] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[159, 167] -> 
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714286], 
             UndirectedEdge[251, 356] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[238, 277] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[163, 164] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[213, 230] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[246, 343] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[53, 95] -> 
             RGBColor[0.8048095, 0.689277857142857, 0.6017240714285714], 
             UndirectedEdge[139, 184] -> 
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[101, 308] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[3, 52] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[136, 286] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.3548697142857139], 
             UndirectedEdge[164, 169] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[14, 102] -> 
             RGBColor[
              0.6773191428571428, 0.7440085714285714, 0.9647382142857143], 
             UndirectedEdge[232, 281] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[56, 349] -> 
             RGBColor[0.9376635, 0.7931411428571429, 0.571257857142857], 
             UndirectedEdge[225, 324] -> 
             RGBColor[
              0.9120792857142856, 0.6603784285714285, 0.27110128571428577`], 
             UndirectedEdge[5, 272] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[68, 371] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139], 
             UndirectedEdge[151, 397] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[1, 356] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[96, 115] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[328, 347] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[80, 159] -> 
             RGBColor[0.8450535, 0.847972142857143, 0.6584182857142857], 
             UndirectedEdge[50, 121] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[108, 342] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[178, 315] -> 
             RGBColor[
              0.6918173571428571, 0.7236127142857143, 0.6458675714285715], 
             UndirectedEdge[146, 228] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[63, 152] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[43, 137] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[97, 141] -> 
             RGBColor[0.9376635, 0.7931411428571429, 0.5712578571428572], 
             UndirectedEdge[25, 207] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[214, 310] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[37, 87] -> 
             RGBColor[
              0.9589912142857143, 0.8814695714285716, 0.5886137142857143], 
             UndirectedEdge[146, 262] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[322, 364] -> 
             RGBColor[
              0.8720902142857143, 0.7421052857142856, 0.6083590714285714], 
             UndirectedEdge[219, 311] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[5, 260] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[204, 389] -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             UndirectedEdge[275, 279] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[78, 289] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[163, 329] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285716], 
             UndirectedEdge[47, 181] -> 
             RGBColor[
              0.9424163571428572, 0.7951065714285714, 0.4924907142857143], 
             UndirectedEdge[267, 291] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[28, 301] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[174, 193] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[60, 263] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[122, 385] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[282, 350] -> 
             RGBColor[
              0.5159862142857142, 0.5955266428571429, 0.9596732142857143], 
             UndirectedEdge[142, 306] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[6, 289] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[3, 117] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[6, 132] -> 
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711], 
             UndirectedEdge[22, 394] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[11, 391] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[34, 249] -> 
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[269, 306] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[69, 394] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[361, 369] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[85, 184] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285716], 
             UndirectedEdge[73, 96] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[71, 382] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[122, 165] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[321, 331] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[296, 374] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[66, 297] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[75, 145] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[105, 239] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[92, 354] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[188, 369] -> 
             RGBColor[
              0.9635437142857144, 0.8816397142857144, 0.38869121428571396`], 
             UndirectedEdge[170, 251] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[53, 68] -> 
             RGBColor[0.8048095, 0.689277857142857, 0.6017240714285714], 
             UndirectedEdge[274, 318] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[179, 359] -> 
             RGBColor[
              0.5716229285714285, 0.6540043571428571, 0.9628416428571429], 
             UndirectedEdge[20, 328] -> 
             RGBColor[
              0.7664822142857144, 0.7853505714285716, 0.6514355714285714], 
             UndirectedEdge[307, 352] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[6, 216] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285715, 0.6650532857142857], 
             UndirectedEdge[297, 385] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[40, 348] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[229, 329] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[6, 213] -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 
             UndirectedEdge[189, 374] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[97, 140] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[34, 386] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[162, 313] -> 
             RGBColor[
              0.7664822142857144, 0.7853505714285716, 0.6514355714285716], 
             UndirectedEdge[258, 392] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[45, 273] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[226, 393] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[88, 168] -> 
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[188, 327] -> 
             RGBColor[
              0.6119954285714286, 0.5987787857142859, 0.6027111428571429], 
             UndirectedEdge[59, 349] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[260, 398] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[248, 353] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[30, 389] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[216, 311] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[66, 307] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[94, 225] -> 
             RGBColor[
              0.6322736428571428, 0.46805128571428556`, 0.5727077142857143], 
             UndirectedEdge[177, 324] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[79, 320] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[133, 234] -> 
             RGBColor[
              0.6918173571428571, 0.7236127142857143, 0.6458675714285715], 
             UndirectedEdge[35, 195] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[34, 86] -> 
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[98, 131] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[173, 261] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[103, 331] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[135, 322] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.3713353571428568], 
             UndirectedEdge[50, 181] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[35, 153] -> 
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286], 
             UndirectedEdge[121, 362] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[84, 152] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[295, 345] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285715], 
             UndirectedEdge[22, 266] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[271, 335] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[175, 261] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[59, 254] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[53, 270] -> 
             RGBColor[
              0.9168807857142858, 0.7776414285714286, 0.6064375714285715], 
             UndirectedEdge[214, 300] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[3, 386] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[299, 336] -> 
             RGBColor[
              0.6419490714285714, 0.7070056428571428, 0.8469732857142858], 
             UndirectedEdge[110, 351] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[172, 328] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285715, 0.6650532857142858], 
             UndirectedEdge[185, 302] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[370, 391] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[50, 364] -> 
             RGBColor[
              0.9233715714285714, 0.9386605714285714, 0.8699770714285715], 
             UndirectedEdge[73, 195] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[80, 332] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139], 
             UndirectedEdge[5, 267] -> 
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285], 
             UndirectedEdge[136, 246] -> 
             RGBColor[
              0.9229162857142856, 0.6964441428571427, 0.3548697142857139], 
             UndirectedEdge[59, 246] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[177, 200] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[17, 157] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[151, 386] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[4, 188] -> 
             RGBColor[
              0.8934179285714285, 0.8304337142857143, 0.6257149285714285], 
             UndirectedEdge[241, 255] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[62, 345] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[57, 114] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[32, 137] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285716], 
             UndirectedEdge[152, 175] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[99, 235] -> 
             RGBColor[
              0.7071934285714285, 0.7702102857142856, 0.9722277142857143], 
             UndirectedEdge[156, 256] -> 
             RGBColor[
              0.7857647142857143, 0.8328318571428571, 0.9792104285714285], 
             UndirectedEdge[48, 286] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[61, 262] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[146, 385] -> 
             RGBColor[
              0.7773192142857144, 0.8214162857142857, 0.7352039999999996], 
             UndirectedEdge[29, 150] -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             UndirectedEdge[141, 220] -> 
             RGBColor[
              0.9422159999999999, 0.7933112857142857, 0.3713353571428568], 
             UndirectedEdge[152, 242] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[95, 151] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139], 
             UndirectedEdge[252, 293] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[93, 390] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[229, 249] -> 
             RGBColor[0.5652478571428571, 0.655645, 0.9600247142857143], 
             UndirectedEdge[96, 153] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[202, 217] -> 
             RGBColor[0.9376635, 0.7931411428571429, 0.571257857142857], 
             UndirectedEdge[163, 304] -> 
             RGBColor[
              0.9571247857142857, 0.9363357142857144, 0.6631317857142858], 
             UndirectedEdge[18, 323] -> 
             RGBColor[0.7679015, 0.4570657142857143, 0.5683967142857143], 
             UndirectedEdge[152, 264] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[23, 169] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[290, 342] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[285, 330] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[55, 192] -> 
             RGBColor[
              0.9231166428571429, 0.6982394285714284, 0.4760250714285715], 
             UndirectedEdge[161, 170] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[42, 205] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[267, 398] -> 
             RGBColor[
              0.9681621428571429, 0.9741967142857143, 0.8680555714285714], 
             UndirectedEdge[32, 199] -> 
             RGBColor[
              0.6918173571428571, 0.7236127142857143, 0.6458675714285715], 
             UndirectedEdge[154, 385] -> 
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861], 
             UndirectedEdge[91, 190] -> 
             RGBColor[
              0.8560908571428572, 0.8858331428571429, 0.8633420714285714], 
             UndirectedEdge[94, 380] -> 
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585], 
             UndirectedEdge[119, 288] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[65, 251] -> 
             RGBColor[
              0.9123342142857143, 0.9007995714285715, 0.6650532857142857], 
             UndirectedEdge[198, 216] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[101, 182] -> 
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285], 
             UndirectedEdge[11, 230] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[53, 101] -> 
             RGBColor[0.8048095, 0.689277857142857, 0.6017240714285714], 
             UndirectedEdge[202, 264] -> 
             RGBColor[0.9376635, 0.7931411428571429, 0.571257857142857], 
             UndirectedEdge[336, 367] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[13, 132] -> 
             RGBColor[
              0.7026543571428572, 0.7596784285714285, 0.7296359999999997], 
             UndirectedEdge[146, 307] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[75, 133] -> 
             RGBColor[
              0.9779074999999999, 0.9518354285714287, 0.6279520714285715], 
             UndirectedEdge[153, 369] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[20, 181] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[112, 394] -> 
             RGBColor[
              0.9934973571428571, 0.9898665714285715, 0.6329533571428568], 
             UndirectedEdge[279, 306] -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             UndirectedEdge[34, 68] -> 
             RGBColor[
              0.8513379999999999, 0.8838677142857143, 0.9421092142857143], 
             UndirectedEdge[4, 284] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[193, 235] -> 
             RGBColor[
              0.9231712142857142, 0.9368652857142856, 0.7488217142857139], 
             UndirectedEdge[296, 316] -> 
             RGBColor[
              0.8934179285714285, 0.8304337142857143, 0.6257149285714285], 
             UndirectedEdge[117, 223] -> 
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142], 
             UndirectedEdge[37, 110] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[83, 349] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[192, 348] -> 
             RGBColor[
              0.7775195714285714, 0.8232115714285715, 0.8563593571428572], 
             UndirectedEdge[97, 394] -> 
             RGBColor[
              0.9889448571428572, 0.9896964285714286, 0.8328758571428572], 
             UndirectedEdge[2, 352] -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 
             UndirectedEdge[69, 350] -> 
             RGBColor[
              0.5607767857142857, 0.6310627857142858, 0.9577517142857143], 
             UndirectedEdge[164, 304] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[141, 350] -> 
             RGBColor[0.535031, 0.4519726428571428, 0.5821868571428572], 
             UndirectedEdge[114, 356] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[383, 390] -> 
             RGBColor[
              0.9679617857142857, 0.9724014285714286, 0.746900214285714], 
             UndirectedEdge[297, 307] -> 
             RGBColor[
              0.9887444999999999, 0.9879011428571429, 0.7117204999999996], 
             UndirectedEdge[40, 58] -> 
             RGBColor[
              0.6325285714285713, 0.7084724285714286, 0.9666597142857143], 
             UndirectedEdge[173, 295] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[161, 239] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286], 
             UndirectedEdge[35, 369] -> 
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139], 
             UndirectedEdge[303, 313] -> 
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265], 
             UndirectedEdge[237, 349] -> 
             RGBColor[
              0.9186187142857143, 0.9366951428571428, 0.9487442142857143], 
             UndirectedEdge[21, 263] -> 
             RGBColor[0.905308, 0.5610991428571428, 0.33800799999999964`], 
             UndirectedEdge[126, 274] -> 
             RGBColor[
              0.9634092857142857, 0.9722312857142857, 0.9468227142857142], 
             UndirectedEdge[331, 346] -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             UndirectedEdge[106, 345] -> 
             RGBColor[
              0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             316 -> RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             308 -> RGBColor[0.984192, 0.987731, 0.911643], 160 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             245 -> RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             155 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117979999999993], 213 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 352 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 27 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 367 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 19 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 164 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 190 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             103 -> RGBColor[0.984192, 0.987731, 0.911643], 138 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 291 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 28 -> 
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861], 337 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 195 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 114 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 93 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 34 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 161 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 22 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             124 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117979999999993], 84 -> 
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861], 46 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 241 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 185 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             390 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117979999999993], 121 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             322 -> RGBColor[
              0.891135, 0.5985512857142856, 0.23087271428571426`], 126 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             236 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117979999999993], 78 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             376 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             254 -> RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             290 -> RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             251 -> RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             165 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117979999999993], 100 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             235 -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 70 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             234 -> RGBColor[
              0.4120117142857142, 0.5312855714285714, 0.947474], 257 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 135 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 265 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 111 -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             381 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             182 -> RGBColor[
              0.718484, 0.7800044285714286, 0.9725754285714285], 188 -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             154 -> RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861],
              336 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             315 -> RGBColor[
              0.4120117142857142, 0.5312855714285714, 0.947474], 368 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             269 -> RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             208 -> RGBColor[0.984192, 0.987731, 0.911643], 86 -> 
             RGBColor[0.4120117142857142, 0.5312855714285714, 0.947474], 119 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             377 -> RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             140 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 85 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 351 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             242 -> RGBColor[0.971623, 0.9159398571428573, 0.344261142857143],
              117 -> RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 47 -> 
             RGBColor[0.891135, 0.5985512857142856, 0.23087271428571426`], 81 -> 
             RGBColor[0.4120117142857142, 0.5312855714285714, 0.947474], 275 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 23 -> 
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861], 328 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 110 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 6 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 218 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             108 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             297 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117979999999993], 157 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 354 -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             385 -> RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861],
              270 -> RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             392 -> RGBColor[0.971623, 0.9159398571428573, 0.344261142857143],
              33 -> RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             252 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117979999999993], 394 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             260 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             159 -> RGBColor[0.971623, 0.9159398571428573, 0.344261142857143],
              183 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 99 -> 
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861], 329 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 309 -> 
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285], 17 -> 
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861], 349 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 347 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             340 -> RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             277 -> RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             104 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 79 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             327 -> RGBColor[
              0.2902004285714285, 0.42234942857142854`, 0.9398378571428572], 
             191 -> RGBColor[
              0.891135, 0.5985512857142856, 0.23087271428571426`], 50 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             225 -> RGBColor[
              0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`],
              61 -> RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861],
              196 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117979999999993], 1 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 263 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 201 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 371 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 293 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             362 -> RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             184 -> RGBColor[0.984192, 0.987731, 0.911643], 106 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             206 -> RGBColor[0.984192, 0.987731, 0.911643], 358 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             247 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             220 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117979999999993], 107 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 375 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             131 -> RGBColor[0.984192, 0.987731, 0.911643], 127 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 210 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 357 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             181 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             194 -> RGBColor[
              0.891135, 0.5985512857142856, 0.23087271428571426`], 118 -> 
             RGBColor[
              0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`],
              348 -> RGBColor[
              0.5613414285714287, 0.6547612857142857, 0.95861], 276 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             305 -> RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             343 -> RGBColor[0.984192, 0.987731, 0.911643], 280 -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             189 -> RGBColor[0.984192, 0.987731, 0.911643], 168 -> 
             RGBColor[0.4120117142857142, 0.5312855714285714, 0.947474], 363 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 41 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 14 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 77 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 51 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             179 -> RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             223 -> RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861],
              323 -> RGBColor[0.817319, 0.134127, 0.164218], 292 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             396 -> RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             321 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             143 -> RGBColor[0.984192, 0.987731, 0.911643], 112 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 197 -> 
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861], 54 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 71 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 177 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             158 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             226 -> RGBColor[0.984192, 0.987731, 0.911643], 350 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 203 -> 
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285], 115 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             173 -> RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             212 -> RGBColor[0.971623, 0.9159398571428573, 0.344261142857143],
              129 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117979999999993], 279 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 26 -> 
             RGBColor[
              0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`],
              40 -> RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             146 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117979999999993], 386 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 192 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             300 -> RGBColor[0.984192, 0.987731, 0.911643], 221 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 62 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             286 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117979999999993], 152 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 64 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 307 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 37 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 148 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 261 -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             387 -> RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 15 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 136 -> 
             RGBColor[
              0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`],
              198 -> RGBColor[0.984192, 0.987731, 0.911643], 63 -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             310 -> RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             171 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             395 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 311 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 353 -> 
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285], 59 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 397 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             229 -> RGBColor[
              0.718484, 0.7800044285714286, 0.9725754285714285], 102 -> 
             RGBColor[0.4120117142857142, 0.5312855714285714, 0.947474], 299 -> 
             RGBColor[
              0.2902004285714285, 0.42234942857142854`, 0.9398378571428572], 
             128 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117979999999993], 12 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             222 -> RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 92 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 271 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 361 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             344 -> RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             132 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117979999999993], 80 -> 
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285], 324 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 244 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             150 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             125 -> RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             258 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             133 -> RGBColor[0.971623, 0.9159398571428573, 0.344261142857143],
              255 -> RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             326 -> RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             176 -> RGBColor[0.971623, 0.9159398571428573, 0.344261142857143],
              230 -> RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             274 -> RGBColor[0.984192, 0.987731, 0.911643], 87 -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             130 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 35 -> 
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285], 379 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 31 -> 
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861], 18 -> 
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285], 24 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             151 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117979999999993], 137 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 330 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             296 -> RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             266 -> RGBColor[0.984192, 0.987731, 0.911643], 302 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             283 -> RGBColor[
              0.718484, 0.7800044285714286, 0.9725754285714285], 388 -> 
             RGBColor[0.4120117142857142, 0.5312855714285714, 0.947474], 284 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 318 -> 
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861], 238 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 72 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 288 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 382 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 389 -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             172 -> RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             243 -> RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 88 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 273 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 202 -> 
             RGBColor[0.891135, 0.5985512857142856, 0.23087271428571426`], 
             393 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117979999999993], 98 -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 30 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 116 -> 
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861], 373 -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             240 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             317 -> RGBColor[
              0.891135, 0.5985512857142856, 0.23087271428571426`], 391 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 73 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 303 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 29 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             360 -> RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             320 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117979999999993], 75 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 200 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             301 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117979999999993], 156 -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 25 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 38 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 365 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 380 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 370 -> 
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861], 3 -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 57 -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             227 -> RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 39 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 109 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             256 -> RGBColor[
              0.718484, 0.7800044285714286, 0.9725754285714285], 339 -> 
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285], 287 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             239 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             285 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117979999999993], 345 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 366 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             216 -> RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 21 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 355 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             175 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117979999999993], 7 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 13 -> 
             RGBColor[0.4120117142857142, 0.5312855714285714, 0.947474], 294 -> 
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285], 193 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 60 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 65 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 69 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             217 -> RGBColor[0.984192, 0.987731, 0.911643], 214 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             170 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             359 -> RGBColor[
              0.2902004285714285, 0.42234942857142854`, 0.9398378571428572], 
             74 -> RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861], 
             246 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117979999999993], 264 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 278 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 45 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 306 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             237 -> RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             228 -> RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861],
              180 -> RGBColor[0.984192, 0.987731, 0.911643], 383 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 53 -> 
             RGBColor[0.891135, 0.5985512857142856, 0.23087271428571426`], 
             304 -> RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 48 -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 5 -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             101 -> RGBColor[
              0.718484, 0.7800044285714286, 0.9725754285714285], 333 -> 
             RGBColor[
              0.9337904285714287, 0.7752081428571431, 0.2655844285714286], 
             267 -> RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             120 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             147 -> RGBColor[
              0.4120117142857142, 0.5312855714285714, 0.947474], 89 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 43 -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             199 -> RGBColor[
              0.4120117142857142, 0.5312855714285714, 0.947474], 268 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             169 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 20 -> 
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861], 4 -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             167 -> RGBColor[
              0.891135, 0.5985512857142856, 0.23087271428571426`], 142 -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 16 -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             281 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             289 -> RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             398 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             178 -> RGBColor[0.971623, 0.9159398571428573, 0.344261142857143],
              58 -> RGBColor[
              0.4120117142857142, 0.5312855714285714, 0.947474], 186 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 122 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 249 -> 
             RGBColor[0.4120117142857142, 0.5312855714285714, 0.947474], 113 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 52 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 187 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             259 -> RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 42 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 134 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             313 -> RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861],
              248 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             174 -> RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             215 -> RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861],
              399 -> RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 83 -> 
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861], 95 -> 
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285], 166 -> 
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285], 384 -> 
             RGBColor[
              0.2902004285714285, 0.42234942857142854`, 0.9398378571428572], 
             233 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             295 -> RGBColor[0.984192, 0.987731, 0.911643], 141 -> 
             RGBColor[0.891135, 0.5985512857142856, 0.23087271428571426`], 
             319 -> RGBColor[0.984192, 0.987731, 0.911643], 205 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 224 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             231 -> RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861],
              332 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117979999999993], 68 -> 
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285], 10 -> 
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861], 250 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 282 -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             374 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117979999999993], 232 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             253 -> RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 55 -> 
             RGBColor[
              0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`],
              325 -> RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 91 -> 
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285], 105 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 36 -> 
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285], 123 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 94 -> 
             RGBColor[0.4120117142857142, 0.5312855714285714, 0.947474], 312 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 96 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 2 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 262 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 272 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 97 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 372 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 356 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 346 -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             341 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117979999999993], 209 -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             378 -> RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 66 -> 
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861], 139 -> 
             RGBColor[0.4120117142857142, 0.5312855714285714, 0.947474], 56 -> 
             RGBColor[0.891135, 0.5985512857142856, 0.23087271428571426`], 
             335 -> RGBColor[0.984192, 0.987731, 0.911643], 314 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 144 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 298 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 204 -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             207 -> RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             334 -> RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             149 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117979999999993], 219 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             400 -> RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 9 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 11 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 44 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 
             153 -> RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 32 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 162 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 90 -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             331 -> RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 8 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 364 -> 
             RGBColor[
              0.8530454285714285, 0.8856592857142856, 0.9858454285714285], 
             342 -> RGBColor[
              0.993297, 0.9880712857142857, 0.5117979999999993], 163 -> 
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143], 49 -> 
             RGBColor[0.4120117142857142, 0.5312855714285714, 0.947474], 338 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 76 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 369 -> 
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993], 82 -> 
             RGBColor[
              0.9936977142857143, 0.9916618571428572, 0.7541087142857144], 67 -> 
             RGBColor[
              0.9426265714285714, 0.9567315714285715, 0.9820024285714285], 
             211 -> RGBColor[
              0.8530454285714285, 0.8856592857142856, 
               0.9858454285714285]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9l3k0VX/Yxa95Hq55dufJNVwqktwdKpWiSIU0EZFIxkiFhGRKk6SkQSmp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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 7}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 35}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 41}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 57}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 92}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 96}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 114}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 153}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 154}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 161}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 188}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.38869121428571396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 203}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 222}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 312}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 327}], {
             RGBColor[
             0.6417487142857142, 0.7052103571428572, 0.7258179285714282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 337}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 356}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 361}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 98}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 106}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 107}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 197}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 215}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 283}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 352}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 52}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 86}], {
             RGBColor[
             0.6325285714285713, 0.7084724285714286, 0.9666597142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 117}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 174}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 232}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 309}], {
             RGBColor[
             0.7857647142857143, 0.8328318571428571, 0.9792104285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 371}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 386}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 16}], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 73}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 115}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 188}], {
             RGBColor[
             0.8934179285714285, 0.8304337142857143, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 195}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 206}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 208}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 258}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 278}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 284}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 369}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 392}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285715, 0.6650532857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 99}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 174}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 193}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 223}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 235}], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 260}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 267}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 272}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 275}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 291}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 321}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 338}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 384}], {
             RGBColor[
             0.5716229285714285, 0.6540043571428571, 0.9628416428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 398}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 13}], {
             RGBColor[
             0.6918173571428571, 0.7236127142857143, 0.6458675714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 18}], {
             RGBColor[0.8450535, 0.847972142857143, 0.6584182857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 74}], {
             RGBColor[
             0.7664822142857144, 0.7853505714285716, 0.6514355714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 102}], {
             RGBColor[
             0.6918173571428571, 0.7236127142857143, 0.6458675714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 132}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 160}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 166}], {
             RGBColor[0.8450535, 0.847972142857143, 0.6584182857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 185}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 198}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 213}], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 216}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285715, 0.6650532857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 224}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 247}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 289}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 302}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 323}], {
             RGBColor[0.894471, 0.5250334285714287, 0.2542395714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 340}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 40}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 41}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 80}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 96}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 114}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 153}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 154}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 192}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 203}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 222}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 228}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 312}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 332}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 356}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 361}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 385}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 17}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{8, 36}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 60}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 64}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 157}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 171}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 182}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 210}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 253}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 61}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 131}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 142}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 202}], {
             RGBColor[0.9376635, 0.7931411428571429, 0.5712578571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 214}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 215}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 217}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 269}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 279}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 300}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 306}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 363}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 39}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 177}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 200}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 216}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 219}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 241}], {
             RGBColor[
             0.7664822142857144, 0.7853505714285716, 0.6514355714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 296}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 311}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 339}], {
             RGBColor[
             0.6399127142857144, 0.7173828571428571, 0.9655927142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 360}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 374}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 14}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 25}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 38}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 78}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 102}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 144}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 205}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 207}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 213}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 221}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 230}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 250}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 289}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 358}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 391}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 118}], {
             RGBColor[
             0.8975810714285715, 0.6807742857142856, 0.5899719285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 126}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 149}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 199}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 212}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 238}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 259}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 274}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 299}], {
             RGBColor[0.6164135, 0.6895405, 0.9609201428571428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 318}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 336}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 367}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 18}], {
             RGBColor[0.5652478571428571, 0.655645, 0.9600247142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 69}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 74}], {
             RGBColor[0.48667657142857146`, 0.5930234285714285, 0.953042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 88}], {
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 132}], {
             RGBColor[
             0.7026543571428572, 0.7596784285714285, 0.7296359999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 191}], {
             RGBColor[
             0.6515733571428571, 0.5649184285714285, 0.5891733571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 198}], {
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 216}], {
             RGBColor[
             0.6325285714285713, 0.7084724285714286, 0.9666597142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 224}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 302}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 323}], {
             RGBColor[
             0.6146653571428571, 0.3327062857142857, 0.5558460000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 340}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 357}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 38}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 102}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 205}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 207}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 224}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 230}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 247}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 250}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 289}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 340}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 391}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 45}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 100}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 105}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 155}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 170}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 180}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 183}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 239}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 271}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 273}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 326}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 335}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 394}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 73}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 85}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285715, 0.6650532857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 96}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 110}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 115}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 184}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 188}], {
             RGBColor[
             0.8934179285714285, 0.8304337142857143, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 203}], {
             RGBColor[
             0.7857647142857143, 0.8328318571428571, 0.9792104285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 206}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 208}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 258}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 284}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 325}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 348}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 369}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 392}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285715, 0.6650532857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 36}], {
             RGBColor[
             0.6399127142857144, 0.7173828571428571, 0.9655927142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 64}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 82}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 122}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 157}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 187}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 218}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 253}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 262}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 298}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 74}], {
             RGBColor[
             0.6399127142857144, 0.7173828571428571, 0.9655927142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 132}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 140}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 191}], {
             RGBColor[0.8048095, 0.689277857142857, 0.6017240714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 216}], {
             RGBColor[
             0.7857647142857143, 0.8328318571428571, 0.9792104285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 247}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 302}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 311}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 323}], {
             RGBColor[0.7679015, 0.4570657142857143, 0.5683967142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 340}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 357}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 83}], {
             RGBColor[
             0.7664822142857144, 0.7853505714285716, 0.6514355714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 108}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 125}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285715, 0.6650532857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 179}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285715, 0.6650532857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 196}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 231}], {
             RGBColor[
             0.7664822142857144, 0.7853505714285716, 0.6514355714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 303}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 313}], {
             RGBColor[
             0.7664822142857144, 0.7853505714285716, 0.6514355714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 344}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 50}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 54}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 116}], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 121}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 130}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 135}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 147}], {
             RGBColor[0.48667657142857146`, 0.5930234285714285, 0.953042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 158}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 172}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 181}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 265}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 322}], {
             RGBColor[
             0.7262382142857143, 0.6266562857142857, 0.5947413571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 328}], {
             RGBColor[
             0.7664822142857144, 0.7853505714285716, 0.6514355714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 347}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 362}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 364}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 387}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[0.7679015, 0.4570657142857143, 0.5683967142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 60}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{21, 64}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{21, 82}], {
             RGBColor[
             0.9055083571428572, 0.5628944285714286, 0.45916335714285716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 122}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{21, 159}], {
             RGBColor[0.894471, 0.5250334285714287, 0.2542395714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 182}], {
             RGBColor[0.7679015, 0.4570657142857143, 0.5683967142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 210}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{21, 263}], {
             RGBColor[0.905308, 0.5610991428571428, 0.33800799999999964`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 29}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 45}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 91}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 97}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 100}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 141}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714286, 0.6064375714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 150}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 189}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 190}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 255}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 266}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 273}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 350}], {
             RGBColor[
             0.5607767857142857, 0.6310627857142858, 0.9577517142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 365}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 394}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[0.48667657142857146`, 0.5930234285714285, 0.953042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 89}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 163}], {
             RGBColor[
             0.7664822142857144, 0.7853505714285716, 0.6514355714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 164}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 169}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 227}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 245}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 292}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 304}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 353}], {
             RGBColor[
             0.6399127142857144, 0.7173828571428571, 0.9655927142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 378}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 25}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 76}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 104}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 109}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 138}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 144}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 207}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 233}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 242}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 317}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 358}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 366}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 382}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 104}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 109}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 138}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 144}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 205}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 207}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 233}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 317}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.3713353571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 358}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 366}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 382}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 391}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 30}], {
             RGBColor[
             0.9183637857142857, 0.6962739999999998, 0.5547922142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 62}], {
             RGBColor[
             0.8975810714285715, 0.6807742857142856, 0.5899719285714284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 77}], {
             RGBColor[
             0.8975810714285715, 0.6807742857142856, 0.5899719285714284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 106}], {
             RGBColor[
             0.9231166428571429, 0.6982394285714284, 0.4760250714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 111}], {
             RGBColor[0.8527905, 0.6452381428571428, 0.5918934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 160}], {
             RGBColor[
             0.9231166428571429, 0.6982394285714284, 0.4760250714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.7855097857142856, 0.5924107142857142, 0.5852584285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 173}], {
             RGBColor[
             0.8975810714285715, 0.6807742857142856, 0.5899719285714284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 185}], {
             RGBColor[
             0.8975810714285715, 0.6807742857142856, 0.5899719285714284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 197}], {
             RGBColor[0.7069385, 0.5297891428571427, 0.5782757142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 204}], {
             RGBColor[0.8527905, 0.6452381428571428, 0.5918934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 345}], {
             RGBColor[
             0.9120792857142856, 0.6603784285714285, 0.27110128571428577`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 370}], {
             RGBColor[0.7069385, 0.5297891428571427, 0.5782757142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 389}], {
             RGBColor[0.8527905, 0.6452381428571428, 0.5918934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 400}], {
             RGBColor[
             0.8975810714285715, 0.6807742857142856, 0.5899719285714284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 51}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.3713353571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 277}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 287}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 376}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 377}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.38869121428571396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 395}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 396}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 44}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 47}], {
             RGBColor[
             0.7262382142857143, 0.6266562857142857, 0.5947413571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 49}], {
             RGBColor[0.48667657142857146`, 0.5930234285714285, 0.953042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 147}], {
             RGBColor[0.48667657142857146`, 0.5930234285714285, 0.953042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 211}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 301}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 328}], {
             RGBColor[
             0.7664822142857144, 0.7853505714285716, 0.6514355714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 347}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 362}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 372}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 380}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 390}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 45}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 91}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 150}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 190}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 226}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 266}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 273}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 365}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 62}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 77}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 84}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 204}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 333}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 370}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 389}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 400}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 33}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 106}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 156}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 173}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 175}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 197}], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 204}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 214}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 261}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 295}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 310}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 345}], {
             RGBColor[
             0.7664822142857144, 0.7853505714285716, 0.6514355714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 43}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285715, 0.6650532857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 124}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 137}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 199}], {
             RGBColor[
             0.6918173571428571, 0.7236127142857143, 0.6458675714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 238}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 252}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 293}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 330}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 63}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 84}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 90}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 152}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 156}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 173}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 175}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 204}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 214}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 256}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 261}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 264}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 295}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 310}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 333}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 381}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 53}], {
             RGBColor[0.9376635, 0.7931411428571429, 0.5712578571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 68}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 86}], {
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 95}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 151}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 244}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 249}], {
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 253}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 270}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 308}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 386}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 397}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 41}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 57}], {
             RGBColor[
             0.7857647142857143, 0.8328318571428571, 0.9792104285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 92}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 114}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 153}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 188}], {
             RGBColor[
             0.8261372142857144, 0.7776062857142858, 0.6190799285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 195}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 208}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 258}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 278}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 284}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 327}], {
             RGBColor[
             0.5043422142857142, 0.6011769285714286, 0.9562066428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 337}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 354}], {
             RGBColor[
             0.7857647142857143, 0.8328318571428571, 0.9792104285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 369}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 392}], {
             RGBColor[0.8450535, 0.847972142857143, 0.6584182857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 55}], {
             RGBColor[
             0.7855097857142856, 0.5924107142857142, 0.5852584285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 60}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 64}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 82}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 122}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 157}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 165}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 218}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 262}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 298}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 314}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 58}], {
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 87}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 110}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 134}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 159}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 167}], {
             RGBColor[0.9376635, 0.7931411428571429, 0.5712578571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 201}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 236}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 243}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 263}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 348}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 351}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 78}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 102}], {
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 205}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 207}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 213}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 221}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 224}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 230}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 247}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 250}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 289}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 358}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 391}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 93}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 94}], {
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 119}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 128}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 177}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 200}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 225}], {
             RGBColor[
             0.9183637857142857, 0.6962739999999998, 0.5547922142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 288}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 296}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 316}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 324}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 355}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 360}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 374}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 375}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 380}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 383}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 390}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 41}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 55}], {
             RGBColor[0.8527905, 0.6452381428571428, 0.5918934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 58}], {
             RGBColor[
             0.6325285714285713, 0.7084724285714286, 0.9666597142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.7857647142857143, 0.8328318571428571, 0.9792104285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 87}], {
             RGBColor[
             0.8934179285714285, 0.8304337142857143, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 96}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 110}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 146}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 154}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 159}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285715, 0.6650532857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 167}], {
             RGBColor[
             0.8720902142857143, 0.7421052857142856, 0.6083590714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 192}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 203}], {
             RGBColor[
             0.7857647142857143, 0.8328318571428571, 0.9792104285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 228}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 243}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 332}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 348}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 361}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 385}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 57}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 96}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 114}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 153}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 154}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 188}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 203}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 222}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 258}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 312}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 327}], {
             RGBColor[
             0.6419490714285714, 0.7070056428571428, 0.8469732857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 356}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 361}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 369}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 104}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 109}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 136}], {
             RGBColor[
             0.9183637857142857, 0.6962739999999998, 0.5547922142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 205}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 207}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 221}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 276}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 358}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 366}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 376}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 124}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 137}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 199}], {
             RGBColor[
             0.6325285714285713, 0.7084724285714286, 0.9666597142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 238}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 252}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 277}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 293}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 299}], {
             RGBColor[
             0.5716229285714285, 0.6540043571428571, 0.9628416428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 330}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 367}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285715, 0.6650532857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 47}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 49}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 54}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 93}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 211}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 301}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 316}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 324}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 328}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 362}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 372}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 380}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 383}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 390}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 91}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 97}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 100}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 112}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 141}], {
             RGBColor[0.9376635, 0.7931411428571429, 0.5712578571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 180}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 190}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 266}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 271}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 273}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 350}], {
             RGBColor[0.5815595, 0.6465625, 0.922572]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{45, 365}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 394}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 59}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 287}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 373}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 395}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 54}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.3713353571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 121}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.4924907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 128}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.3713353571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 130}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.4924907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.4924907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 181}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.4924907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 265}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.3713353571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 311}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.3713353571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 322}], {
             RGBColor[0.891135, 0.5985512857142856, 0.23087271428571426`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 362}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714286, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 56}], {
             RGBColor[
             0.8720902142857143, 0.7421052857142856, 0.6083590714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 71}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 83}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 103}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 108}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 120}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 143}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 196}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 231}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 234}], {
             RGBColor[
             0.6325285714285713, 0.7084724285714286, 0.9666597142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 286}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 290}], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 313}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 320}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 331}], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 342}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 343}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 344}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 349}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 147}], {
             RGBColor[0.4120117142857142, 0.5312855714285714, 0.947474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 211}], {
             RGBColor[
             0.6325285714285713, 0.7084724285714286, 0.9666597142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 301}], {
             RGBColor[
             0.7026543571428572, 0.7596784285714285, 0.7296359999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 328}], {
             RGBColor[
             0.6918173571428572, 0.7236127142857143, 0.6458675714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 347}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 372}], {
             RGBColor[
             0.7026543571428572, 0.7596784285714285, 0.7296359999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 380}], {
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 54}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 116}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 121}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 135}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 158}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 172}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 181}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 265}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 276}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 322}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 328}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 362}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 364}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 59}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 136}], {
             RGBColor[
             0.9231166428571429, 0.6982394285714284, 0.4760250714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 194}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 246}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 376}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 377}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 395}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 396}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 117}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 133}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 174}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 223}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 260}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 267}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 272}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 291}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 346}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 384}], {
             RGBColor[
             0.6417487142857142, 0.7052103571428572, 0.7258179285714282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 68}], {
             RGBColor[0.8048095, 0.689277857142857, 0.6017240714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 86}], {
             RGBColor[
             0.6515733571428571, 0.5649184285714285, 0.5891733571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 95}], {
             RGBColor[0.8048095, 0.689277857142857, 0.6017240714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 101}], {
             RGBColor[0.8048095, 0.689277857142857, 0.6017240714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 129}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.3713353571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 151}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.3713353571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 171}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.4924907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 244}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.4924907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 249}], {
             RGBColor[
             0.6515733571428571, 0.5649184285714285, 0.5891733571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 253}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714286, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 270}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714286, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 308}], {
             RGBColor[0.9376635, 0.7931411428571429, 0.571257857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 386}], {
             RGBColor[0.9376635, 0.7931411428571429, 0.571257857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 397}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714286, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 121}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 128}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 130}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 158}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 181}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 265}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 311}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 322}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.3713353571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 328}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 362}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 58}], {
             RGBColor[
             0.6322736428571428, 0.46805128571428556`, 0.5727077142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 60}], {
             RGBColor[
             0.9183637857142857, 0.6962739999999998, 0.5547922142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 80}], {
             RGBColor[
             0.7855097857142856, 0.5924107142857142, 0.5852584285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 87}], {
             RGBColor[0.893163, 0.5900125714285714, 0.23176292857142858`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 122}], {
             RGBColor[
             0.9183637857142857, 0.6962739999999998, 0.5547922142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 146}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.3548697142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 159}], {
             RGBColor[
             0.9120792857142856, 0.6603784285714285, 0.27110128571428577`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.3548697142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 192}], {
             RGBColor[
             0.9231166428571429, 0.6982394285714284, 0.4760250714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 201}], {
             RGBColor[
             0.9120792857142856, 0.6603784285714285, 0.27110128571428577`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 210}], {
             RGBColor[
             0.9183637857142857, 0.6962739999999998, 0.5547922142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 228}], {
             RGBColor[0.7069385, 0.5297891428571427, 0.5782757142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 385}], {
             RGBColor[0.7069385, 0.5297891428571427, 0.5782757142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 71}], {
             RGBColor[0.9376635, 0.7931411428571429, 0.571257857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 83}], {
             RGBColor[
             0.7262382142857143, 0.6266562857142857, 0.594741357142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 108}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.4924907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 120}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.4924907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 143}], {
             RGBColor[0.9376635, 0.7931411428571429, 0.571257857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 196}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.3713353571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 231}], {
             RGBColor[
             0.7262382142857143, 0.6266562857142857, 0.594741357142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 237}], {
             RGBColor[
             0.8720902142857143, 0.7421052857142856, 0.6083590714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 254}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714286, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 286}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.3713353571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 290}], {
             RGBColor[
             0.8720902142857143, 0.7421052857142856, 0.6083590714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 320}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.3713353571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 331}], {
             RGBColor[
             0.8720902142857143, 0.7421052857142856, 0.6083590714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 342}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.3713353571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 343}], {
             RGBColor[0.9376635, 0.7931411428571429, 0.571257857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 344}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714286, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 349}], {
             RGBColor[0.9376635, 0.7931411428571429, 0.571257857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 92}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 114}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 153}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 188}], {
             RGBColor[
             0.8934179285714285, 0.8304337142857143, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 195}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 208}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 258}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 278}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 284}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 327}], {
             RGBColor[
             0.5716229285714285, 0.6540043571428571, 0.9628416428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 337}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 354}], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 392}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285715, 0.6650532857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 60}], {
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 80}], {
             RGBColor[0.5652478571428571, 0.655645, 0.9600247142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 87}], {
             RGBColor[
             0.6729010714285715, 0.6532468571428572, 0.6065292142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 110}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 159}], {
             RGBColor[
             0.6918173571428572, 0.7236127142857143, 0.6458675714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 167}], {
             RGBColor[
             0.6515733571428571, 0.5649184285714285, 0.5891733571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 192}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 201}], {
             RGBColor[
             0.6918173571428572, 0.7236127142857143, 0.6458675714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 210}], {
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 228}], {
             RGBColor[0.48667657142857146`, 0.5930234285714285, 0.953042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 236}], {
             RGBColor[
             0.7026543571428572, 0.7596784285714285, 0.7296359999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 243}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 263}], {
             RGBColor[
             0.7026543571428572, 0.7596784285714285, 0.7296359999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 348}], {
             RGBColor[0.48667657142857146`, 0.5930234285714285, 0.953042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 351}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 79}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[0.9376635, 0.7931411428571429, 0.5712578571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 237}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 246}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 254}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 349}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 373}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 395}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 87}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 122}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 146}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 159}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 165}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 201}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 210}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 263}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 66}], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 98}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 107}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 131}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 215}], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 262}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 269}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 279}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 297}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 298}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 300}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 306}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 307}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 314}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 352}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 77}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 204}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 345}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 370}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 389}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 400}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 90}], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 138}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 142}], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 152}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 156}], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 202}], {
             RGBColor[
             0.8720902142857143, 0.7421052857142856, 0.6083590714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 214}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 217}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 242}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285715, 0.6650532857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 256}], {
             RGBColor[
             0.7857647142857143, 0.8328318571428571, 0.9792104285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 257}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 261}], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 264}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 268}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 317}], {
             RGBColor[
             0.8720902142857143, 0.7421052857142856, 0.6083590714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 381}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 82}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 151}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 157}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 171}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 182}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 253}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 105}], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 113}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 148}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 161}], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 168}], {
             RGBColor[
             0.6918173571428571, 0.7236127142857143, 0.6458675714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 170}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 180}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 239}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 251}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285715, 0.6650532857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 282}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285715, 0.6650532857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 312}], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 326}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 356}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 107}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 131}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 215}], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 297}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 307}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 314}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 352}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 85}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 127}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 139}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 184}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 305}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 325}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 86}], {
             RGBColor[0.5652478571428571, 0.655645, 0.9600247142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 95}], {
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 129}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 151}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 178}], {
             RGBColor[0.8450535, 0.847972142857143, 0.6584182857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 229}], {
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 249}], {
             RGBColor[0.5652478571428571, 0.655645, 0.9600247142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 308}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 309}], {
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 319}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 334}], {
             RGBColor[
             0.7857647142857143, 0.8328318571428571, 0.9792104285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 371}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 386}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 74}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 97}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 100}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 132}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 140}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 141}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714286, 0.6064375714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 168}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 191}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714286, 0.6064375714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 216}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 219}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 220}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 350}], {
             RGBColor[
             0.5607767857142857, 0.6310627857142858, 0.9577517142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 357}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 394}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 75}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 103}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 133}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 164}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 227}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 234}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 280}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 346}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 79}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 109}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 120}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 143}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 237}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 286}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 320}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 321}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 343}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 382}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 119}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 200}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 288}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 341}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 355}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 374}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 375}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 379}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 393}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 399}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 85}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 96}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 110}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 115}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 184}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 188}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.38869121428571396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 195}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 203}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 206}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 208}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 258}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 284}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 348}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 369}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 392}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 132}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 140}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 191}], {
             RGBColor[
             0.7262382142857143, 0.6266562857142857, 0.5947413571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 198}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 216}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 219}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 220}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 224}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 302}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 311}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 323}], {
             RGBColor[0.6893302142857143, 0.39444414285714285`, 0.561414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 340}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 357}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 89}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 133}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 145}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 164}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 169}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 209}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 227}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 280}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 315}], {
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 109}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 138}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 144}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 207}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 233}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 242}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 257}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 317}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.3713353571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 358}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 366}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 382}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 78}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 102}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 111}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 160}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 166}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 185}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 370}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 389}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 400}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 102}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 144}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 160}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 185}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 207}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 213}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 230}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 247}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 289}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 370}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 391}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 400}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 109}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 120}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 136}], {
             RGBColor[
             0.8975810714285715, 0.6807742857142856, 0.5899719285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 237}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 246}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 254}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 286}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 320}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 343}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 349}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 87}], {
             RGBColor[
             0.8261372142857144, 0.7776062857142858, 0.6190799285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 96}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 110}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 146}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 154}], {
             RGBColor[
             0.6399127142857144, 0.7173828571428571, 0.9655927142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 159}], {
             RGBColor[0.8450535, 0.847972142857143, 0.6584182857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 167}], {
             RGBColor[0.8048095, 0.689277857142857, 0.6017240714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 192}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 201}], {
             RGBColor[0.8450535, 0.847972142857143, 0.6584182857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 203}], {
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 228}], {
             RGBColor[
             0.6399127142857144, 0.7173828571428571, 0.9655927142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 243}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 332}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 348}], {
             RGBColor[
             0.6399127142857144, 0.7173828571428571, 0.9655927142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 361}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 385}], {
             RGBColor[
             0.6399127142857144, 0.7173828571428571, 0.9655927142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 89}], {
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 163}], {
             RGBColor[
             0.6918173571428572, 0.7236127142857143, 0.6458675714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 169}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 209}], {
             RGBColor[
             0.6325285714285713, 0.7084724285714286, 0.9666597142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 227}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 240}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 245}], {
             RGBColor[
             0.6325285714285713, 0.7084724285714286, 0.9666597142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 248}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 292}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 304}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 315}], {
             RGBColor[0.4120117142857142, 0.5312855714285714, 0.947474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 329}], {
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 353}], {
             RGBColor[0.5652478571428571, 0.655645, 0.9600247142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 378}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 151}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 157}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 171}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 182}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 253}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 108}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 120}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 125}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 179}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 196}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 231}], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 237}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 246}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 254}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 303}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 313}], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 344}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 349}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 152}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 156}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 175}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 204}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 256}], {
             RGBColor[
             0.6399127142857144, 0.7173828571428571, 0.9655927142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 261}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 264}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 317}], {
             RGBColor[
             0.7262382142857143, 0.6266562857142857, 0.5947413571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 333}], {
             RGBColor[
             0.7475659285714287, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 381}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 389}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 96}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 110}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 115}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 139}], {
             RGBColor[
             0.6918173571428571, 0.7236127142857143, 0.6458675714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 167}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 184}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 188}], {
             RGBColor[
             0.9527067142857144, 0.8455740000000003, 0.30492278571428577`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 203}], {
             RGBColor[0.8450535, 0.847972142857143, 0.6584182857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 258}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 284}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 325}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 348}], {
             RGBColor[
             0.7664822142857144, 0.7853505714285716, 0.6514355714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 351}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 369}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 95}], {
             RGBColor[0.5652478571428571, 0.655645, 0.9600247142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 151}], {
             RGBColor[
             0.7026543571428572, 0.7596784285714285, 0.7296359999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[
             0.6918173571428572, 0.7236127142857143, 0.6458675714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 229}], {
             RGBColor[0.5652478571428571, 0.655645, 0.9600247142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 249}], {
             RGBColor[0.4120117142857142, 0.5312855714285714, 0.947474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 308}], {
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 309}], {
             RGBColor[0.5652478571428571, 0.655645, 0.9600247142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 334}], {
             RGBColor[
             0.6325285714285713, 0.7084724285714286, 0.9666597142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 371}], {
             RGBColor[
             0.7026543571428572, 0.7596784285714285, 0.7296359999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 386}], {
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 110}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 134}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 159}], {
             RGBColor[
             0.9527067142857144, 0.8455740000000003, 0.30492278571428577`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 167}], {
             RGBColor[
             0.9124627142857143, 0.6868797142857144, 0.24822857142857144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 192}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 201}], {
             RGBColor[
             0.9527067142857144, 0.8455740000000003, 0.30492278571428577`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 210}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 228}], {
             RGBColor[
             0.7475659285714287, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 236}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.38869121428571396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 243}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 263}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.38869121428571396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 348}], {
             RGBColor[
             0.7475659285714287, 0.7149847142857144, 0.6120972142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 351}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 132}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 140}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 168}], {
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 282}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 283}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 357}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 163}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 164}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 169}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 209}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 227}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 245}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 292}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 304}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 315}], {
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 329}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 353}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 378}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 138}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 142}], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 152}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 156}], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 175}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 202}], {
             RGBColor[
             0.8720902142857143, 0.7421052857142856, 0.6083590714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 242}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285715, 0.6650532857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 256}], {
             RGBColor[
             0.7857647142857143, 0.8328318571428571, 0.9792104285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 261}], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 264}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 268}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 317}], {
             RGBColor[
             0.8720902142857143, 0.7421052857142856, 0.6083590714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 333}], {
             RGBColor[
             0.8934179285714285, 0.8304337142857143, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 381}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 141}], {
             RGBColor[0.8048095, 0.689277857142857, 0.6017240714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 150}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 186}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 189}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 190}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 226}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 241}], {
             RGBColor[0.8450535, 0.847972142857143, 0.6584182857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 255}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 266}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 273}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 365}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 114}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 153}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 161}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 188}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.38869121428571396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 195}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 258}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 278}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 284}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 327}], {
             RGBColor[
             0.6417487142857142, 0.7052103571428572, 0.7258179285714282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 337}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 354}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 392}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 94}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 119}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 128}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 225}], {
             RGBColor[
             0.9231166428571429, 0.6982394285714284, 0.4760250714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 296}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 301}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 316}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 324}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 355}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 380}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 383}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 390}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 119}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 128}], {
             RGBColor[
             0.7026543571428572, 0.7596784285714285, 0.7296359999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 177}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 200}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 225}], {
             RGBColor[
             0.6322736428571428, 0.46805128571428556`, 0.5727077142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 288}], {
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 296}], {
             RGBColor[
             0.6325285714285713, 0.7084724285714286, 0.9666597142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 316}], {
             RGBColor[
             0.6729010714285715, 0.6532468571428572, 0.6065292142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 324}], {
             RGBColor[
             0.6918173571428572, 0.7236127142857143, 0.6458675714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 355}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 375}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 380}], {
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 383}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 390}], {
             RGBColor[
             0.7026543571428572, 0.7596784285714285, 0.7296359999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 129}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 151}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 178}], {
             RGBColor[0.8450535, 0.847972142857143, 0.6584182857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 229}], {
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 249}], {
             RGBColor[0.5652478571428571, 0.655645, 0.9600247142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 270}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 308}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 309}], {
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 334}], {
             RGBColor[
             0.7857647142857143, 0.8328318571428571, 0.9792104285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 371}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 386}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 110}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 114}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 115}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 153}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 154}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 167}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714286, 0.6064375714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 188}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 192}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 203}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 228}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 243}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 258}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 284}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 348}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 361}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 369}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 100}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 105}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 112}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 132}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 140}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 141}], {
             RGBColor[0.9376635, 0.7931411428571429, 0.5712578571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 168}], {
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 180}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 220}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 282}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 350}], {
             RGBColor[0.5815595, 0.6465625, 0.922572]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{97, 357}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 394}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 107}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 131}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 215}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 283}], {
             RGBColor[
             0.7857647142857143, 0.8328318571428571, 0.9792104285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 297}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 307}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 352}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 123}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 174}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 187}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 193}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 232}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 235}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 275}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 279}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 281}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 306}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 338}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 384}], {
             RGBColor[
             0.4257709285714286, 0.5385553571428572, 0.9492239285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 105}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 112}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 141}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 168}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 170}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 180}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 220}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 271}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 273}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 282}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 350}], {
             RGBColor[
             0.5863123571428571, 0.6485279285714286, 0.8438048571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 394}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 151}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 171}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 182}], {
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 244}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 253}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 270}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 308}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 397}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 160}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 166}], {
             RGBColor[0.5652478571428571, 0.655645, 0.9600247142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 213}], {
             RGBColor[
             0.6918173571428572, 0.7236127142857143, 0.6458675714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 224}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 230}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 247}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 250}], {
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 289}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 302}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 340}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 370}], {
             RGBColor[0.48667657142857146`, 0.5930234285714285, 0.953042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 391}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 400}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 108}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 133}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 143}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 223}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 231}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 234}], {
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 290}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 313}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 331}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 342}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 346}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 109}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 138}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 144}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 205}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 207}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 233}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 358}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 366}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 382}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 112}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 113}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 148}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 155}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 168}], {
             RGBColor[
             0.6918173571428571, 0.7236127142857143, 0.6458675714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 170}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 180}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 239}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 271}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 282}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285715, 0.6650532857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 326}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 350}], {
             RGBColor[0.575275, 0.6106669285714287, 0.6388810714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 394}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 173}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 197}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 204}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 214}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 215}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 295}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 310}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 345}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 363}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 131}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 197}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 215}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 297}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 307}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 352}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 363}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 143}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 179}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 196}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 231}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 234}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 290}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 313}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 331}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 342}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 344}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 136}], {
             RGBColor[
             0.9231166428571429, 0.6982394285714284, 0.4760250714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 205}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 207}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 233}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 286}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 320}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 343}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 358}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 366}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 382}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 115}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 134}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 167}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714286, 0.6064375714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 192}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 203}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 243}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 348}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 351}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 369}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 160}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 166}], {
             RGBColor[
             0.7857647142857143, 0.8328318571428571, 0.9792104285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 197}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 155}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 170}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 180}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 183}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 271}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 273}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 326}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 350}], {
             RGBColor[0.586112, 0.6467326428571428, 0.7226494999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 394}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 148}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 168}], {
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 170}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 251}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 282}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 153}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 154}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 188}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.38869121428571396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 203}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 222}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 258}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 312}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 327}], {
             RGBColor[
             0.6417487142857142, 0.7052103571428572, 0.7258179285714282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 356}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 361}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 369}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 392}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 184}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 188}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 195}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 203}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 206}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 208}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 258}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 284}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 325}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 369}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 392}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 121}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 130}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 135}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 147}], {
             RGBColor[0.48667657142857146`, 0.5930234285714285, 0.953042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 172}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 265}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 276}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 322}], {
             RGBColor[
             0.7262382142857143, 0.6266562857142857, 0.5947413571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 328}], {
             RGBColor[
             0.7664822142857144, 0.7853505714285716, 0.6514355714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 362}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 364}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 387}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 223}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 346}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 371}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 126}], {
             RGBColor[
             0.8975810714285715, 0.6807742857142856, 0.5899719285714284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 149}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.3548697142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[
             0.6322736428571428, 0.46805128571428556`, 0.5727077142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 212}], {
             RGBColor[
             0.9120792857142856, 0.6603784285714285, 0.27110128571428577`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 259}], {
             RGBColor[
             0.8975810714285715, 0.6807742857142856, 0.5899719285714284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 293}], {
             RGBColor[
             0.9231166428571429, 0.6982394285714284, 0.4760250714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 299}], {
             RGBColor[0.571368, 0.41358321428571415`, 0.5688896428571428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 336}], {
             RGBColor[
             0.9231166428571429, 0.6982394285714284, 0.4760250714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 367}], {
             RGBColor[
             0.9120792857142856, 0.6603784285714285, 0.27110128571428577`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 200}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 225}], {
             RGBColor[
             0.8975810714285715, 0.6807742857142856, 0.5899719285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 288}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 296}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 316}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 324}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 355}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 375}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 380}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 383}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 390}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 136}], {
             RGBColor[
             0.9231166428571429, 0.6982394285714284, 0.4760250714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 237}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 246}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 254}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 286}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 320}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 343}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 349}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 130}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 158}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 181}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 250}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 265}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 322}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 362}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 146}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 165}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 210}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 228}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 262}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 298}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 314}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 385}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 174}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 187}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 193}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 218}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 232}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 235}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 275}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 279}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 281}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 306}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 338}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 199}], {
             RGBColor[
             0.7026543571428571, 0.7596784285714285, 0.7296359999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 238}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 252}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 277}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 293}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 330}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 179}], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 196}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 303}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 313}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 344}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 149}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 199}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 212}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 238}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 259}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 274}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 299}], {
             RGBColor[0.6164135, 0.6895405, 0.9609201428571428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 318}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 336}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 367}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 139}], {
             RGBColor[
             0.7026543571428571, 0.7596784285714285, 0.7296359999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 184}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 305}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 325}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 177}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 225}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.3548697142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 296}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 311}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 316}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.38869121428571396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 324}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 380}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 383}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 390}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 178}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 229}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 249}], {
             RGBColor[
             0.7026543571428571, 0.7596784285714285, 0.7296359999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 270}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 308}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 309}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 397}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 135}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 147}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 158}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 172}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 181}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 265}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 322}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 328}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 347}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 362}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 364}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 387}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 215}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 217}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 262}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 269}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 279}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 297}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 300}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 306}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 307}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 314}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 352}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 363}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 140}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 191}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.3713353571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 198}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 216}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 219}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 220}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 302}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 323}], {
             RGBColor[0.905308, 0.5610991428571428, 0.33800799999999964`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 357}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 145}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 164}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 223}], {
             RGBColor[
             0.7664822142857144, 0.7853505714285716, 0.6514355714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 234}], {
             RGBColor[
             0.6918173571428571, 0.7236127142857143, 0.6458675714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 280}], {
             RGBColor[
             0.9527067142857144, 0.8455740000000003, 0.30492278571428577`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 346}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285715, 0.6650532857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 167}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 201}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 236}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 243}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 263}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 348}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 351}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 221}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 276}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 322}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.3713353571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 364}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 376}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 377}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.38869121428571396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 194}], {
             RGBColor[
             0.8718352857142857, 0.5016841428571427, 0.2144070714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 237}], {
             RGBColor[0.8527905, 0.6452381428571428, 0.5918934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 246}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.3548697142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 254}], {
             RGBColor[
             0.8975810714285715, 0.6807742857142856, 0.5899719285714284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 286}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.3548697142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 320}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.3548697142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 343}], {
             RGBColor[
             0.9183637857142857, 0.6962739999999998, 0.5547922142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 349}], {
             RGBColor[
             0.9183637857142857, 0.6962739999999998, 0.5547922142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 376}], {
             RGBColor[
             0.9231166428571429, 0.6982394285714284, 0.4760250714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 199}], {
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 238}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 252}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 277}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 285}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 293}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 330}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 144}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 233}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 242}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 256}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 257}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 317}], {
             RGBColor[0.9376635, 0.7931411428571429, 0.5712578571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 366}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 381}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 382}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 184}], {
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 305}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 325}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 141}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 168}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 191}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 216}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 219}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 220}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 350}], {
             RGBColor[
             0.5863123571428571, 0.6485279285714286, 0.8438048571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 357}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 150}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.4924907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 189}], {
             RGBColor[0.9376635, 0.7931411428571429, 0.571257857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 219}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.4924907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 220}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.3713353571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 273}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.3713353571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 339}], {
             RGBColor[0.8048095, 0.689277857142857, 0.6017240714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 350}], {
             RGBColor[0.535031, 0.4519726428571428, 0.5821868571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 357}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714286, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 394}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.4924907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 202}], {
             RGBColor[
             0.8720902142857143, 0.7421052857142856, 0.6083590714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 214}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 217}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 257}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 268}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 275}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 279}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 300}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 306}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 338}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 363}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 381}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 223}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 234}], {
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 260}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 267}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 272}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 290}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 291}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 321}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 331}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 342}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 398}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 207}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 233}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 242}], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 317}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 358}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 366}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 370}], {
             RGBColor[
             0.7664822142857144, 0.7853505714285716, 0.6514355714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 391}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 162}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 164}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 227}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 280}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 359}], {
             RGBColor[
             0.6419490714285714, 0.7070056428571428, 0.8469732857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 154}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 159}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 165}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 192}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 228}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 262}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 297}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 307}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 314}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 332}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 385}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 172}], {
             RGBColor[
             0.6325285714285713, 0.7084724285714286, 0.9666597142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 211}], {
             RGBColor[
             0.6325285714285713, 0.7084724285714286, 0.9666597142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 328}], {
             RGBColor[
             0.6918173571428572, 0.7236127142857143, 0.6458675714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 347}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 364}], {
             RGBColor[
             0.6325285714285713, 0.7084724285714286, 0.9666597142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 372}], {
             RGBColor[
             0.7026543571428572, 0.7596784285714285, 0.7296359999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 387}], {
             RGBColor[
             0.6325285714285713, 0.7084724285714286, 0.9666597142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 161}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 168}], {
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 170}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 251}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 312}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 326}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 356}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 199}], {
             RGBColor[
             0.7026543571428571, 0.7596784285714285, 0.7296359999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 212}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 238}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 259}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 274}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 287}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 299}], {
             RGBColor[
             0.6417487142857142, 0.7052103571428572, 0.7258179285714282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 318}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 336}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 367}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 186}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 189}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 226}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 241}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 255}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 266}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 365}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 374}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 399}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 171}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 182}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 244}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 249}], {
             RGBColor[
             0.7026543571428571, 0.7596784285714285, 0.7296359999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 253}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 270}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 308}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 386}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 397}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 156}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 175}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 242}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 256}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 261}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 264}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 317}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 333}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 381}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 154}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 188}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 195}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 203}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 258}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 278}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 284}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 312}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 327}], {
             RGBColor[0.6164135, 0.6895405, 0.9609201428571428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 337}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 361}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 369}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 392}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 192}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[
             0.6399127142857144, 0.7173828571428571, 0.9655927142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 222}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 228}], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 312}], {
             RGBColor[
             0.7664822142857144, 0.7853505714285716, 0.6514355714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 332}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 356}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 361}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 385}], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 170}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 180}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 183}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 239}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 271}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 326}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 335}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 337}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 354}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 175}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 202}], {
             RGBColor[
             0.8720902142857143, 0.7421052857142856, 0.6083590714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 214}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 256}], {
             RGBColor[
             0.7857647142857143, 0.8328318571428571, 0.9792104285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 261}], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 264}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 295}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 310}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 363}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 381}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 187}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 218}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 253}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 298}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 265}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 311}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 322}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 362}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 165}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 167}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 192}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 201}], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 210}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 228}], {
             RGBColor[
             0.7664822142857144, 0.7853505714285716, 0.6514355714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 236}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 243}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 263}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 166}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 185}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 213}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 224}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 247}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 289}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 302}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 340}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 370}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 400}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 170}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 222}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 239}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 251}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285715, 0.6650532857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 312}], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 326}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 327}], {
             RGBColor[
             0.6309117142857142, 0.6691446428571429, 0.6420495000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 337}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 179}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285715, 0.6650532857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 231}], {
             RGBColor[
             0.7664822142857144, 0.7853505714285716, 0.6514355714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 313}], {
             RGBColor[
             0.7664822142857144, 0.7853505714285716, 0.6514355714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 359}], {
             RGBColor[
             0.6309117142857142, 0.6691446428571429, 0.6420495000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 164}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 169}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 209}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285715, 0.6650532857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 227}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 240}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 245}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285715, 0.6650532857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 280}], {
             RGBColor[
             0.9527067142857144, 0.8455740000000003, 0.30492278571428577`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 304}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 315}], {
             RGBColor[
             0.6918173571428571, 0.7236127142857143, 0.6458675714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 319}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 329}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 371}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 169}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 209}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 227}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 245}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 280}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.38869121428571396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 304}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 315}], {
             RGBColor[
             0.7026543571428571, 0.7596784285714285, 0.7296359999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 228}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 262}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 298}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 307}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 314}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 332}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 385}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 185}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 213}], {
             RGBColor[0.8450535, 0.847972142857143, 0.6584182857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 224}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 247}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 289}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 302}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 340}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 400}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 192}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.4924907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[0.8048095, 0.689277857142857, 0.6017240714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 228}], {
             RGBColor[
             0.7262382142857143, 0.6266562857142857, 0.594741357142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 243}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714286, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 348}], {
             RGBColor[
             0.7262382142857143, 0.6266562857142857, 0.594741357142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 351}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714286, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 170}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 180}], {
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 220}], {
             RGBColor[
             0.7026543571428572, 0.7596784285714285, 0.7296359999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 251}], {
             RGBColor[
             0.6325285714285713, 0.7084724285714286, 0.9666597142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 282}], {
             RGBColor[
             0.6325285714285713, 0.7084724285714286, 0.9666597142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 350}], {
             RGBColor[0.2954693571428571, 0.41833978571428565`, 0.9404875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 357}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 394}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 209}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 227}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 240}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 245}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 280}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 292}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 304}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 315}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 329}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 353}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 378}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 180}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 239}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 251}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 271}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 282}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 326}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 182}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 244}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 253}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 270}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 308}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 397}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 211}], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 328}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285715, 0.6650532857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 347}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 364}], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 387}], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 175}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 197}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 204}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 214}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 261}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 295}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 310}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 345}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 193}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 232}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 235}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 260}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 267}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 272}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 275}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 281}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 291}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 338}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 384}], {
             RGBColor[0.6164135, 0.6895405, 0.9609201428571428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 398}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 204}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 214}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 256}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 261}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 264}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 295}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 310}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 345}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 186}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 226}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 294}], {
             RGBColor[0.8450535, 0.847972142857143, 0.6584182857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 341}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 368}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 379}], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 393}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 399}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 200}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 225}], {
             RGBColor[
             0.9231166428571429, 0.6982394285714284, 0.4760250714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 296}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 311}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 324}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 339}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 360}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 374}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 375}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 383}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 390}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 209}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285715, 0.6650532857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 229}], {
             RGBColor[0.8450535, 0.847972142857143, 0.6584182857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 240}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 245}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285715, 0.6650532857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 248}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 309}], {
             RGBColor[0.8450535, 0.847972142857143, 0.6584182857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 315}], {
             RGBColor[
             0.6918173571428571, 0.7236127142857143, 0.6458675714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 319}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 329}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 334}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285715, 0.6650532857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 371}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 388}], {
             RGBColor[
             0.6918173571428571, 0.7236127142857143, 0.6458675714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 196}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 231}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 303}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 313}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 344}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 359}], {
             RGBColor[
             0.5716229285714285, 0.6540043571428571, 0.9628416428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 239}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 271}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 282}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 326}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 350}], {
             RGBColor[0.5815595, 0.6465625, 0.922572]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{180, 394}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 250}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 265}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 322}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 362}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 244}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 253}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 271}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 273}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 335}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 305}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 325}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 213}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 224}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 247}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 289}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 302}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 340}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 400}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 189}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 200}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 226}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 241}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 255}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 288}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 341}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 374}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 393}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 399}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 193}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 218}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 232}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 235}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 275}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 279}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 281}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 298}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 306}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 195}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 203}], {
             RGBColor[
             0.8261372142857144, 0.7776062857142858, 0.6190799285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 206}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 208}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 258}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 278}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 284}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.38869121428571396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 327}], {
             RGBColor[
             0.6119954285714286, 0.5987787857142859, 0.6027111428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 361}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 369}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.38869121428571396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 392}], {
             RGBColor[
             0.9527067142857144, 0.8455740000000003, 0.30492278571428577`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 200}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 219}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 241}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 255}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 339}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 360}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 374}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 266}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 273}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 365}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 198}], {
             RGBColor[0.9376635, 0.7931411428571429, 0.571257857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 216}], {
             RGBColor[
             0.8720902142857143, 0.7421052857142856, 0.6083590714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 219}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.4924907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 220}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.3713353571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 311}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.3713353571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 323}], {
             RGBColor[
             0.8542270000000001, 0.3663391428571428, 0.19754535714285715`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 339}], {
             RGBColor[0.8048095, 0.689277857142857, 0.6017240714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 357}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714286, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 201}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 203}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 228}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 243}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 332}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 348}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 361}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 385}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 232}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 235}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 260}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 275}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 281}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 338}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 384}], {
             RGBColor[
             0.6417487142857142, 0.7052103571428572, 0.7258179285714282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 376}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.4924907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 377}], {
             RGBColor[
             0.9124627142857143, 0.6868797142857144, 0.24822857142857144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 396}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714286, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 206}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 208}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 258}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 278}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 284}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 327}], {
             RGBColor[
             0.6371962142857143, 0.7050402142857143, 0.9257404285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 337}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 369}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 392}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 231}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 234}], {
             RGBColor[
             0.7026543571428571, 0.7596784285714285, 0.7296359999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 290}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 303}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 313}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 344}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 204}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 215}], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 295}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 310}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 345}], {
             RGBColor[
             0.7664822142857144, 0.7853505714285716, 0.6514355714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 216}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 219}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 224}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 247}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 302}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 311}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 323}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{198, 340}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 212}], {
             RGBColor[
             0.6918173571428572, 0.7236127142857143, 0.6458675714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 238}], {
             RGBColor[
             0.7026543571428572, 0.7596784285714285, 0.7296359999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 252}], {
             RGBColor[
             0.7026543571428572, 0.7596784285714285, 0.7296359999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 277}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 287}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 293}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 299}], {
             RGBColor[
             0.35110607142857136`, 0.47681749999999995`, 0.9436559285714285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 336}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 367}], {
             RGBColor[
             0.6918173571428572, 0.7236127142857143, 0.6458675714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 225}], {
             RGBColor[
             0.8975810714285715, 0.6807742857142856, 0.5899719285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 241}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 255}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 288}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 296}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 339}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 355}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 360}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 374}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 375}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 383}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 399}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 210}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 228}], {
             RGBColor[
             0.7664822142857144, 0.7853505714285716, 0.6514355714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 236}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 243}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 263}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 348}], {
             RGBColor[
             0.7664822142857144, 0.7853505714285716, 0.6514355714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 351}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 214}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714286, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 217}], {
             RGBColor[0.9376635, 0.7931411428571429, 0.571257857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 257}], {
             RGBColor[0.9376635, 0.7931411428571429, 0.571257857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 264}], {
             RGBColor[0.9376635, 0.7931411428571429, 0.571257857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 268}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.4924907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 279}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714286, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 300}], {
             RGBColor[0.9376635, 0.7931411428571429, 0.571257857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 306}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714286, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 363}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714286, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 381}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.4924907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 243}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 258}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 284}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 348}], {
             RGBColor[
             0.6399127142857144, 0.7173828571428571, 0.9655927142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 361}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 369}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 392}], {
             RGBColor[0.8450535, 0.847972142857143, 0.6584182857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 261}], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 295}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 310}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 345}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285715, 0.6650532857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 389}], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 400}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 207}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 221}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 230}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 250}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 276}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 358}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 391}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 208}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 258}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 278}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 284}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 369}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 392}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 221}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 230}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 233}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 250}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 358}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 366}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 391}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 278}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 284}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 369}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 392}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 227}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 229}], {
             RGBColor[
             0.7857647142857143, 0.8328318571428571, 0.9792104285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 240}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 245}], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 280}], {
             RGBColor[
             0.8934179285714285, 0.8304337142857143, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 304}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 315}], {
             RGBColor[
             0.6325285714285713, 0.7084724285714286, 0.9666597142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 319}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 329}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 334}], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 371}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 236}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 263}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 301}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 328}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285715, 0.6650532857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 347}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 372}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 387}], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 238}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 259}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 293}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 299}], {
             RGBColor[
             0.6309117142857142, 0.6691446428571429, 0.6420495000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 336}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 367}], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 224}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 230}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 247}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 250}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 289}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 302}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 340}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 391}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 215}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 217}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 261}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 264}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 295}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 300}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 310}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 363}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 217}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 269}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 295}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 300}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 352}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 363}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 219}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 220}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 311}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 323}], {
             RGBColor[
             0.8351822142857143, 0.5098931428571428, 0.5750317142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 339}], {
             RGBColor[
             0.7857647142857143, 0.8328318571428571, 0.9792104285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 357}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 268}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 269}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 279}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 300}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 306}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 363}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 262}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 269}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 279}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 298}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 306}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 314}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 220}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 241}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 311}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 323}], {
             RGBColor[
             0.9055083571428572, 0.5628944285714286, 0.45916335714285716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 339}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 357}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 360}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 350}], {
             RGBColor[0.586112, 0.6467326428571428, 0.7226494999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 357}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 394}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 230}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 250}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 276}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 358}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 251}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 297}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 312}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 332}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 356}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 361}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 260}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 267}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 272}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 290}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 291}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 321}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 331}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 342}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 346}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 384}], {
             RGBColor[
             0.4257709285714286, 0.5385553571428572, 0.9492239285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 398}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 230}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 247}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 289}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 302}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 323}], {
             RGBColor[
             0.9055083571428572, 0.5628944285714286, 0.45916335714285716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 340}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 288}], {
             RGBColor[
             0.9183637857142857, 0.6962739999999998, 0.5547922142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 296}], {
             RGBColor[0.8527905, 0.6452381428571428, 0.5918934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 316}], {
             RGBColor[0.893163, 0.5900125714285714, 0.23176292857142858`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 324}], {
             RGBColor[
             0.9120792857142856, 0.6603784285714285, 0.27110128571428577`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 355}], {
             RGBColor[
             0.9231166428571429, 0.6982394285714284, 0.4760250714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 375}], {
             RGBColor[
             0.9231166428571429, 0.6982394285714284, 0.4760250714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 380}], {
             RGBColor[
             0.9183637857142857, 0.6962739999999998, 0.5547922142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 383}], {
             RGBColor[
             0.8975810714285715, 0.6807742857142856, 0.5899719285714284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 390}], {
             RGBColor[
             0.9229162857142856, 0.6964441428571427, 0.3548697142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 255}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 266}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 294}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 341}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 368}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 393}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 399}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 280}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 304}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 315}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 243}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 332}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 348}], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 361}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 385}], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 240}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 245}], {
             RGBColor[
             0.7857647142857143, 0.8328318571428571, 0.9792104285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 248}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 249}], {
             RGBColor[0.5652478571428571, 0.655645, 0.9600247142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 309}], {
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 315}], {
             RGBColor[0.5652478571428571, 0.655645, 0.9600247142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 319}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 334}], {
             RGBColor[
             0.7857647142857143, 0.8328318571428571, 0.9792104285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 371}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 388}], {
             RGBColor[0.5652478571428571, 0.655645, 0.9600247142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 247}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 250}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 289}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 358}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 391}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 234}], {
             RGBColor[0.48667657142857146`, 0.5930234285714285, 0.953042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 290}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 313}], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 331}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 359}], {
             RGBColor[
             0.4257709285714286, 0.5385553571428572, 0.9492239285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 235}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 281}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 384}], {
             RGBColor[
             0.6419490714285714, 0.7070056428571428, 0.8469732857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 386}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 242}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 317}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 358}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 366}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 382}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 290}], {
             RGBColor[
             0.6325285714285713, 0.7084724285714286, 0.9666597142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 313}], {
             RGBColor[0.48667657142857146`, 0.5930234285714285, 0.953042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 331}], {
             RGBColor[
             0.6325285714285713, 0.7084724285714286, 0.9666597142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 342}], {
             RGBColor[
             0.7026543571428572, 0.7596784285714285, 0.7296359999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 346}], {
             RGBColor[
             0.6325285714285713, 0.7084724285714286, 0.9666597142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 275}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 281}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 384}], {
             RGBColor[
             0.5716229285714285, 0.6540043571428571, 0.9628416428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 263}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 351}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 246}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 254}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 286}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 320}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 343}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 349}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 252}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 277}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 287}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 293}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 299}], {
             RGBColor[
             0.6417487142857142, 0.7052103571428572, 0.7258179285714282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 336}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 367}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 396}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 271}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 326}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 335}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 337}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 354}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 245}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 248}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 292}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 304}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 309}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 315}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 319}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 329}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 334}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 371}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 388}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 255}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 288}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 339}], {
             RGBColor[0.8450535, 0.847972142857143, 0.6584182857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 360}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285715, 0.6650532857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 374}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 375}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 399}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 256}], {
             RGBColor[0.8450535, 0.847972142857143, 0.6584182857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 257}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 268}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 317}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 333}], {
             RGBColor[
             0.9527067142857144, 0.8455740000000003, 0.30492278571428577`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 381}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 382}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 348}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 351}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 253}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 270}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 308}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 397}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 248}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 292}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 304}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 315}], {
             RGBColor[
             0.6325285714285713, 0.7084724285714286, 0.9666597142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 319}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 329}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 353}], {
             RGBColor[
             0.7857647142857143, 0.8328318571428571, 0.9792104285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 371}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 378}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 388}], {
             RGBColor[
             0.6325285714285713, 0.7084724285714286, 0.9666597142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 254}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 286}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 320}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 343}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 344}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 349}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 289}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 302}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 340}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 391}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 292}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 304}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 315}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 319}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 329}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 353}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 388}], {
             RGBColor[
             0.7028547142857142, 0.7614737142857142, 0.8507913571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 270}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 308}], {
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 309}], {
             RGBColor[0.5652478571428571, 0.655645, 0.9600247142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 334}], {
             RGBColor[
             0.6325285714285713, 0.7084724285714286, 0.9666597142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 386}], {
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 397}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 265}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 276}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 289}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 391}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 282}], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 312}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285715, 0.6650532857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 356}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 277}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 293}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 330}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 386}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 286}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 320}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 343}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 344}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 349}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 288}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 341}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 360}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 374}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 393}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 399}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 261}], {
             RGBColor[
             0.7857647142857143, 0.8328318571428571, 0.9792104285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 264}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 317}], {
             RGBColor[0.8048095, 0.689277857142857, 0.6017240714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 333}], {
             RGBColor[
             0.8261372142857144, 0.7776062857142858, 0.6190799285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 381}], {
             RGBColor[
             0.8560908571428572, 0.8858331428571429, 0.8633420714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 268}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 338}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 381}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 382}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 278}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 284}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 369}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 392}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 274}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 299}], {
             RGBColor[0.6164135, 0.6895405, 0.9609201428571428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 318}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 336}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 367}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 267}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 272}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 291}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 321}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 338}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 342}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 384}], {
             RGBColor[
             0.6419490714285714, 0.7070056428571428, 0.8469732857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 398}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 264}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 295}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 310}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 381}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 269}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 298}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 300}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 306}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 307}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 314}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 310}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 333}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 381}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 322}], {
             RGBColor[
             0.9422159999999999, 0.7933112857142857, 0.3713353571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 362}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 273}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 365}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 272}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 291}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 321}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 331}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 342}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 346}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 384}], {
             RGBColor[0.6164135, 0.6895405, 0.9609201428571428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 398}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 338}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 381}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 279}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 298}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 300}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 306}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 307}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 314}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 308}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 397}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 273}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 326}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 335}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 394}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 291}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 321}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 331}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 338}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 342}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 346}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 384}], {
             RGBColor[
             0.6371962142857143, 0.7050402142857143, 0.9257404285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 398}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 365}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 394}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 287}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 299}], {
             RGBColor[
             0.6371962142857143, 0.7050402142857143, 0.9257404285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 318}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 367}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 373}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 395}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 279}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 281}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 306}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 338}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 384}], {
             RGBColor[
             0.6371962142857143, 0.7050402142857143, 0.9257404285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 322}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.49249071428571434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 358}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 376}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 377}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 287}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 330}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 396}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 284}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 327}], {
             RGBColor[0.6164135, 0.6895405, 0.9609201428571428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 337}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 354}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 392}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 300}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 306}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 363}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 384}], {
             RGBColor[
             0.6419490714285714, 0.7070056428571428, 0.8469732857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 386}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 350}], {
             RGBColor[
             0.5159862142857142, 0.5955266428571429, 0.9596732142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 369}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 392}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 330}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 387}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 320}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 343}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 349}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 367}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 373}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 395}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 396}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 341}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 355}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 360}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 374}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 375}], {
             RGBColor[
             0.9889448571428572, 0.9896964285714286, 0.8328758571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 379}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 393}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 399}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 302}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 340}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 391}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 313}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 321}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 331}], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 342}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 346}], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 321}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 331}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 338}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 342}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 384}], {
             RGBColor[
             0.6419490714285714, 0.7070056428571428, 0.8469732857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 398}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 304}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 329}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 353}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 378}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 388}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 299}], {
             RGBColor[
             0.6419490714285714, 0.7070056428571428, 0.8469732857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 330}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 336}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 341}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 368}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 393}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 310}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 345}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 363}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 316}], {
             RGBColor[
             0.8934179285714285, 0.8304337142857143, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 324}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285715, 0.6650532857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 360}], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 374}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 375}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 380}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 383}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 390}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 307}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 314}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 332}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 352}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 385}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 306}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 307}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 314}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 336}], {
             RGBColor[
             0.6419490714285714, 0.7070056428571428, 0.8469732857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 367}], {
             RGBColor[0.6309117142857144, 0.6691446428571429, 0.6420495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 306}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 307}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 314}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 363}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 316}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.38869121428571396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 324}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 372}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 380}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 383}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 390}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 323}], {
             RGBColor[
             0.8799727857142857, 0.5454292857142857, 0.5731102142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 340}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 313}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 344}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 315}], {
             RGBColor[
             0.6773191428571428, 0.7440085714285714, 0.9647382142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 329}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 353}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 378}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 325}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 314}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 352}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 385}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 386}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 397}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 319}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 329}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 334}], {
             RGBColor[
             0.7857647142857143, 0.8328318571428571, 0.9792104285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 371}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 386}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 345}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 363}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 323}], {
             RGBColor[0.905308, 0.5610991428571428, 0.33800799999999964`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 339}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 327}], {
             RGBColor[
             0.6309117142857142, 0.6691446428571429, 0.6420495000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 356}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 361}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 344}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 359}], {
             RGBColor[
             0.4257709285714286, 0.5385553571428572, 0.9492239285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 385}], {
             RGBColor[0.7727667142857143, 0.8212461428571429, 0.9351265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 319}], {
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 329}], {
             RGBColor[0.698101857142857, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 334}], {
             RGBColor[
             0.6325285714285713, 0.7084724285714286, 0.9666597142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 371}], {
             RGBColor[
             0.7026543571428572, 0.7596784285714285, 0.7296359999999997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 324}], {
             RGBColor[
             0.9527067142857144, 0.8455740000000003, 0.30492278571428577`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 355}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 380}], {
             RGBColor[
             0.9589912142857143, 0.8814695714285716, 0.5886137142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 383}], {
             RGBColor[0.9382085, 0.8659698571428573, 0.6237934285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 390}], {
             RGBColor[
             0.9635437142857144, 0.8816397142857144, 0.38869121428571396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 333}], {
             RGBColor[
             0.9124627142857143, 0.6868797142857144, 0.24822857142857144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 370}], {
             RGBColor[
             0.7262382142857143, 0.6266562857142857, 0.594741357142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 381}], {
             RGBColor[
             0.9424163571428572, 0.7951065714285714, 0.4924907142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 382}], {
             RGBColor[0.9376635, 0.7931411428571429, 0.571257857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 367}], {
             RGBColor[
             0.7664822142857144, 0.7853505714285716, 0.6514355714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 373}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 329}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 334}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 371}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 388}], {
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 343}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 349}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 331}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 338}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 342}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 384}], {
             RGBColor[
             0.6419490714285714, 0.7070056428571428, 0.8469732857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 398}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 328}], {
             RGBColor[0.931379, 0.7572455714285715, 0.2875669285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 362}], {
             RGBColor[
             0.9168807857142858, 0.7776414285714286, 0.6064375714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 364}], {
             RGBColor[
             0.8720902142857143, 0.7421052857142856, 0.6083590714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 340}], {
             RGBColor[
             0.8799727857142857, 0.5454292857142857, 0.5731102142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 375}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 380}], {
             RGBColor[
             0.9779074999999999, 0.9518354285714287, 0.6279520714285716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 383}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 390}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 335}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 337}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 354}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 337}], {
             RGBColor[
             0.6371962142857142, 0.7050402142857143, 0.9257404285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 354}], {
             RGBColor[
             0.5716229285714285, 0.6540043571428571, 0.9628416428571429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 356}], {
             RGBColor[
             0.6371962142857142, 0.7050402142857143, 0.9257404285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 392}], {
             RGBColor[0.6309117142857144, 0.6691446428571429, 0.6420495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 347}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 362}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 372}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 387}], {
             RGBColor[
             0.9123342142857143, 0.9007995714285715, 0.6650532857142857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 334}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 353}], {
             RGBColor[
             0.8513379999999999, 0.8838677142857143, 0.9421092142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 371}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 388}], {
             RGBColor[0.6981018571428571, 0.7595082857142856, 0.9295585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 342}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 346}], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 361}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 385}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 381}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 371}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 388}], {
             RGBColor[
             0.6325285714285713, 0.7084724285714286, 0.9666597142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 337}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 354}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 367}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 354}], {
             RGBColor[
             0.9186187142857143, 0.9366951428571428, 0.9487442142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 384}], {
             RGBColor[
             0.6419490714285714, 0.7070056428571428, 0.8469732857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 398}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 360}], {
             RGBColor[
             0.7857647142857143, 0.8328318571428571, 0.9792104285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 374}], {
             RGBColor[0.8558905, 0.8840378571428571, 0.7421867142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 368}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 379}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 393}], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 399}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 346}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 398}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 349}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 349}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 362}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 372}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 387}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 351}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 369}], {
             RGBColor[
             0.7773192142857144, 0.8214162857142857, 0.7352039999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 357}], {
             RGBColor[
             0.5607767857142858, 0.6310627857142856, 0.9577517142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 394}], {
             RGBColor[
             0.5863123571428572, 0.6485279285714285, 0.8438048571428571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 378}], {
             RGBColor[0.8305552857142857, 0.868368, 0.9772889285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 375}], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 379}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 366}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 391}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 374}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 375}], {
             RGBColor[
             0.9233715714285714, 0.9386605714285714, 0.8699770714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 369}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 385}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 377}], {
             RGBColor[
             0.8934179285714285, 0.8304337142857143, 0.6257149285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 387}], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 382}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 393}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 399}], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 392}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 389}], {
             RGBColor[
             0.7071934285714285, 0.7702102857142856, 0.9722277142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 391}], {
             RGBColor[
             0.7775195714285714, 0.8232115714285715, 0.8563593571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 400}], {
             RGBColor[0.751984, 0.8057464285714286, 0.9703062142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 395}], {
             RGBColor[
             0.9231712142857142, 0.9368652857142856, 0.7488217142857139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 375}], {
             RGBColor[
             0.9934973571428571, 0.9898665714285715, 0.6329533571428568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 399}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 379}], {
             RGBColor[
             0.9826603571428572, 0.9538008571428572, 0.5491849285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 383}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 399}], {
             RGBColor[
             0.9681621428571429, 0.9741967142857143, 0.8680555714285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 377}], {
             RGBColor[
             0.9637440714285714, 0.8834350000000002, 0.5098465714285715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 393}], {
             RGBColor[0.98246, 0.9520055714285716, 0.4280295714285711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 399}], {
             RGBColor[
             0.9571247857142857, 0.9363357142857144, 0.6631317857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 383}], {
             RGBColor[
             0.9634092857142857, 0.9722312857142857, 0.9468227142857142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 390}], {
             RGBColor[
             0.9887444999999999, 0.9879011428571429, 0.7117204999999996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 390}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 398}], {
             RGBColor[
             0.6419490714285714, 0.7070056428571428, 0.8469732857142858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 400}], {
             RGBColor[0.897836, 0.9211954285714286, 0.9839239285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 399}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 396}], {
             RGBColor[
             0.9679617857142857, 0.9724014285714286, 0.746900214285714]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.03217915333176364], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.03217915333176364], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.03217915333176364], {
             RGBColor[0.4120117142857142, 0.5312855714285714, 0.947474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.03217915333176364], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.03217915333176364], {
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.03217915333176364], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.03217915333176364], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.03217915333176364], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.03217915333176364], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.03217915333176364], {
             RGBColor[
             0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.03217915333176364], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.03217915333176364], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.03217915333176364], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.03217915333176364], {
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.03217915333176364], {
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.03217915333176364], {
             RGBColor[0.891135, 0.5985512857142856, 0.23087271428571426`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.03217915333176364], {
             RGBColor[0.4120117142857142, 0.5312855714285714, 0.947474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.03217915333176364], {
             RGBColor[0.891135, 0.5985512857142856, 0.23087271428571426`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.03217915333176364], {
             RGBColor[
             0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.03217915333176364], {
             RGBColor[0.891135, 0.5985512857142856, 0.23087271428571426`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.03217915333176364], {
             RGBColor[0.4120117142857142, 0.5312855714285714, 0.947474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.03217915333176364], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.03217915333176364], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.03217915333176364], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.03217915333176364], {
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.03217915333176364], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.03217915333176364], {
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.03217915333176364], {
             RGBColor[0.4120117142857142, 0.5312855714285714, 0.947474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.03217915333176364], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.03217915333176364], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.03217915333176364], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.03217915333176364], {
             RGBColor[0.4120117142857142, 0.5312855714285714, 0.947474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.03217915333176364], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.03217915333176364], {
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.03217915333176364], {
             RGBColor[0.4120117142857142, 0.5312855714285714, 0.947474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.03217915333176364], {
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.03217915333176364], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.03217915333176364], {
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.03217915333176364], {
             RGBColor[0.4120117142857142, 0.5312855714285714, 0.947474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.03217915333176364], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.03217915333176364], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.03217915333176364], {
             RGBColor[
             0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.03217915333176364], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.03217915333176364], {
             RGBColor[
             0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.03217915333176364], {
             RGBColor[0.4120117142857142, 0.5312855714285714, 0.947474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.03217915333176364], {
             RGBColor[0.891135, 0.5985512857142856, 0.23087271428571426`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.03217915333176364], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.03217915333176364], {
             RGBColor[0.4120117142857142, 0.5312855714285714, 0.947474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.03217915333176364], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.03217915333176364], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.03217915333176364], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.03217915333176364], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.03217915333176364], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.03217915333176364], {
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.03217915333176364], {
             RGBColor[0.891135, 0.5985512857142856, 0.23087271428571426`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.03217915333176364], {
             RGBColor[0.4120117142857142, 0.5312855714285714, 0.947474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.03217915333176364], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.03217915333176364], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.03217915333176364], {
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.03217915333176364], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.03217915333176364], {
             RGBColor[0.891135, 0.5985512857142856, 0.23087271428571426`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.03217915333176364], {
             RGBColor[0.891135, 0.5985512857142856, 0.23087271428571426`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.03217915333176364], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.03217915333176364], {
             RGBColor[0.4120117142857142, 0.5312855714285714, 0.947474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.03217915333176364], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.03217915333176364], {
             RGBColor[0.891135, 0.5985512857142856, 0.23087271428571426`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.03217915333176364], {
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.03217915333176364], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.03217915333176364], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.03217915333176364], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.03217915333176364], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.03217915333176364], {
             RGBColor[
             0.8525355714285714, 0.40481699999999976`, 0.19794142857142855`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.03217915333176364], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.03217915333176364], {
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.03217915333176364], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.03217915333176364], {
             RGBColor[0.4120117142857142, 0.5312855714285714, 0.947474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.03217915333176364], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.03217915333176364], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.03217915333176364], {
             RGBColor[0.4120117142857142, 0.5312855714285714, 0.947474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.03217915333176364], {
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.03217915333176364], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.03217915333176364], {
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.03217915333176364], {
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.03217915333176364], {
             RGBColor[
             0.2902004285714285, 0.42234942857142854`, 0.9398378571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.03217915333176364], {
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.03217915333176364], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.03217915333176364], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.03217915333176364], {
             RGBColor[0.4120117142857142, 0.5312855714285714, 0.947474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.03217915333176364], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.03217915333176364], {
             RGBColor[0.891135, 0.5985512857142856, 0.23087271428571426`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.03217915333176364], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.03217915333176364], {
             RGBColor[0.891135, 0.5985512857142856, 0.23087271428571426`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.03217915333176364], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.03217915333176364], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.03217915333176364], {
             RGBColor[
             0.2902004285714285, 0.42234942857142854`, 0.9398378571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.03217915333176364], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.03217915333176364], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.03217915333176364], {
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.03217915333176364], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.03217915333176364], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.03217915333176364], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.03217915333176364], {
             RGBColor[0.718484, 0.7800044285714286, 0.9725754285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.03217915333176364], {
             RGBColor[
             0.2902004285714285, 0.42234942857142854`, 0.9398378571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.03217915333176364], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.03217915333176364], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.03217915333176364], {
             RGBColor[
             0.9337904285714287, 0.7752081428571431, 0.2655844285714286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.03217915333176364], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.03217915333176364], {
             RGBColor[
             0.2902004285714285, 0.42234942857142854`, 0.9398378571428572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.03217915333176364], {
             RGBColor[0.5613414285714287, 0.6547612857142857, 0.95861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.03217915333176364], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.03217915333176364], {
             RGBColor[0.4120117142857142, 0.5312855714285714, 0.947474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.03217915333176364], {
             RGBColor[
             0.8530454285714285, 0.8856592857142856, 0.9858454285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.03217915333176364], {
             RGBColor[0.971623, 0.9159398571428573, 0.344261142857143]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.03217915333176364], {
             RGBColor[0.993297, 0.9880712857142857, 0.5117979999999993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.03217915333176364], {
             RGBColor[
             0.9936977142857143, 0.9916618571428572, 0.7541087142857144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.03217915333176364], {
             RGBColor[
             0.9426265714285714, 0.9567315714285715, 0.9820024285714285]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN2wucz2W+wPHn16rdrWxoc2ntsSnFoptQYTEuNY3rMEhyNxmZGTMj4zII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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[105, 155] -> 
             RGBColor[
              0.3609448647521152, 0.4866656792120809, 0.9442342850410239], 
             UndirectedEdge[1, 203] -> 
             RGBColor[
              0.32569030455946724`, 0.45491432460487713`, 0.9420324056815049],
              UndirectedEdge[187, 193] -> 
             RGBColor[
              0.8331367258093362, 0.8697846265391334, 0.9839465187292714], 
             UndirectedEdge[209, 371] -> 
             RGBColor[
              0.26203929742842424`, 0.3927502942212898, 0.9382341223849231], 
             UndirectedEdge[23, 245] -> 
             RGBColor[
              0.22165838805798918`, 0.35030739817543277`, 0.9359344893344789],
              UndirectedEdge[201, 236] -> 
             RGBColor[
              0.26347424346046877`, 0.3942585134818019, 0.9383158404386357], 
             UndirectedEdge[258, 369] -> 
             RGBColor[
              0.2551936052438994, 0.3855550376934007, 0.9378442703423086], 
             UndirectedEdge[161, 312] -> 
             RGBColor[
              0.44719691052756494`, 0.5614994937585587, 0.949788285319064], 
             UndirectedEdge[74, 132] -> 
             RGBColor[
              0.8119479189165777, 0.8530570556731545, 0.981880980170774], 
             UndirectedEdge[89, 169] -> 
             RGBColor[
              0.2196406470513075, 0.3481866244452415, 0.9358195819691286], 
             UndirectedEdge[124, 137] -> 
             RGBColor[
              0.22241368079166546`, 0.3511012587268517, 0.9359775021383063], 
             UndirectedEdge[186, 393] -> 
             RGBColor[
              0.23564383540018752`, 0.36500699006065973`, 0.9367309398710019],
              UndirectedEdge[84, 261] -> 
             RGBColor[
              0.17918769193352976`, 0.30566800375096304`, 0.9335158460199553],
              UndirectedEdge[58, 243] -> 
             RGBColor[
              0.2935914724788655, 0.42591363072274663`, 0.9400309720767858], 
             UndirectedEdge[205, 250] -> 
             RGBColor[
              0.9917478646376758, 0.990855544204543, 0.7864227690028461], 
             UndirectedEdge[327, 337] -> 
             RGBColor[
              0.3016677329619616, 0.43349195021963505`, 0.9405242352558603], 
             UndirectedEdge[38, 224] -> 
             RGBColor[
              0.970726359968221, 0.9129152797745752, 0.34077786564994345`], 
             UndirectedEdge[49, 301] -> 
             RGBColor[
              0.2562771522862687, 0.3866939143357813, 0.9379059767434073], 
             UndirectedEdge[22, 97] -> 
             RGBColor[
              0.36730142212889694`, 0.4910409193978484, 0.9446807120447999], 
             UndirectedEdge[163, 169] -> 
             RGBColor[
              0.23283585906700827`, 0.36205562889850595`, 0.936571029772856], 
             UndirectedEdge[126, 318] -> 
             RGBColor[
              0.2179296081019373, 0.3463882140233181, 0.9357221408322174], 
             UndirectedEdge[126, 149] -> 
             RGBColor[
              0.21613019133913786`, 0.3444969129160037, 0.9356196667095744], 
             UndirectedEdge[28, 47] -> 
             RGBColor[
              0.3610905157265072, 0.4852888096589335, 0.9442985989042187], 
             UndirectedEdge[203, 392] -> 
             RGBColor[
              0.26967339396164935`, 0.4007742137073859, 0.9386688728888566], 
             UndirectedEdge[116, 387] -> 
             RGBColor[
              0.35489504602512995`, 0.4804107437728069, 0.9438859559088182], 
             UndirectedEdge[114, 203] -> 
             RGBColor[
              0.3101377282501396, 0.4414434647009515, 0.9410414092716778], 
             UndirectedEdge[38, 207] -> 
             RGBColor[
              0.9528235149386215, 0.8477616286807421, 0.29603526485507003`], 
             UndirectedEdge[4, 73] -> 
             RGBColor[
              0.23765623707057423`, 0.3671221518098715, 0.9368455431690489], 
             UndirectedEdge[143, 223] -> 
             RGBColor[
              0.5393557196395969, 0.6369122967585245, 0.9568792044565808], 
             UndirectedEdge[70, 164] -> 
             RGBColor[
              0.26017432145076, 0.3907900862224582, 0.9381279147619799], 
             UndirectedEdge[291, 331] -> 
             RGBColor[
              0.5742920250264498, 0.6644126452364563, 0.9602056699966387], 
             UndirectedEdge[317, 381] -> 
             RGBColor[
              0.99188704610358, 0.9909130993174948, 0.7841161719227241], 
             UndirectedEdge[120, 349] -> 
             RGBColor[
              0.5058787275831391, 0.6095186078416714, 0.9543033325072602], 
             UndirectedEdge[102, 160] -> 
             RGBColor[
              0.8243873085977117, 0.18845711723458924`, 0.17098662029568146`],
              UndirectedEdge[84, 381] -> 
             RGBColor[
              0.5860370216699882, 0.6484140748343261, 0.8483679973313716], 
             UndirectedEdge[110, 203] -> 
             RGBColor[
              0.2734877597794271, 0.40478335402663146`, 0.9388860953793305], 
             UndirectedEdge[316, 355] -> 
             RGBColor[
              0.2426003366300466, 0.37231871392089444`, 0.937127102324821], 
             UndirectedEdge[62, 77] -> 
             RGBColor[
              0.5042166815429454, 0.5861598549701907, 0.9585479112851663], 
             UndirectedEdge[188, 361] -> 
             RGBColor[
              0.3113562197109362, 0.44025108193646334`, 0.9412013526638779], 
             UndirectedEdge[168, 282] -> 
             RGBColor[
              0.6585061316418895, 0.73314926196139, 0.9665973951785392], 
             UndirectedEdge[271, 394] -> 
             RGBColor[
              0.3328279171819992, 0.4625195049765876, 0.9424351072766638], 
             UndirectedEdge[160, 224] -> 
             RGBColor[
              0.9025695450570996, 0.5785729407895561, 0.26790552836760506`], 
             UndirectedEdge[97, 168] -> 
             RGBColor[
              0.5562174687857758, 0.6498761073301125, 0.9585804738963757], 
             UndirectedEdge[88, 132] -> 
             RGBColor[
              0.8947680641910523, 0.9166701790551881, 0.8954060764061295], 
             UndirectedEdge[329, 353] -> 
             RGBColor[
              0.22275923690238936`, 0.35146446010874544`, 0.9359971810476075],
              UndirectedEdge[189, 339] -> 
             RGBColor[
              0.333153622737486, 0.4622245787566195, 0.942476989061352], 
             UndirectedEdge[316, 380] -> 
             RGBColor[
              0.25988508585516024`, 0.3904860812728869, 0.9381114432226962], 
             UndirectedEdge[156, 295] -> 
             RGBColor[
              0.2141734445733891, 0.3424402480002911, 0.9355082328760125], 
             UndirectedEdge[154, 228] -> 
             RGBColor[
              0.39900760332101687`, 0.520022064116572, 0.9466453895484133], 
             UndirectedEdge[29, 91] -> 
             RGBColor[
              0.25152521102249714`, 0.3816993227770795, 0.9376353607183026], 
             UndirectedEdge[6, 198] -> 
             RGBColor[
              0.9099185860419527, 0.9263319020393368, 0.75030590143584], 
             UndirectedEdge[56, 254] -> 
             RGBColor[
              0.46022321075082034`, 0.5726042579779009, 0.9506674811679487], 
             UndirectedEdge[245, 315] -> 
             RGBColor[
              0.23658653725822024`, 0.3659978294842021, 0.9367846253472143], 
             UndirectedEdge[174, 281] -> 
             RGBColor[
              0.6802997161269625, 0.7500157979571946, 0.9688781332846546], 
             UndirectedEdge[89, 329] -> 
             RGBColor[
              0.22686082544463082`, 0.3557754897223749, 0.9362307604473317], 
             UndirectedEdge[260, 267] -> 
             RGBColor[
              0.6900764896095811, 0.7567221842679797, 0.9704893279445472], 
             UndirectedEdge[202, 363] -> 
             RGBColor[
              0.8594260597663401, 0.4513198993592995, 0.20428679439717456`], 
             UndirectedEdge[43, 238] -> 
             RGBColor[
              0.22832917766795519`, 0.3573188210079969, 0.9363143809342176], 
             UndirectedEdge[276, 377] -> 
             RGBColor[
              0.590222766132432, 0.6752773818608311, 0.9624624311800029], 
             UndirectedEdge[284, 369] -> 
             RGBColor[
              0.25072601947789425`, 0.3808593217920313, 0.9375898479421354], 
             UndirectedEdge[53, 249] -> 
             RGBColor[
              0.279406621010689, 0.4110044524581648, 0.9392231657702803], 
             UndirectedEdge[15, 105] -> 
             RGBColor[
              0.36060251301143975`, 0.486305845826277, 0.9442147886158565], 
             UndirectedEdge[97, 112] -> 
             RGBColor[
              0.38560280932821134`, 0.5084115053045399, 0.9457912479285857], 
             UndirectedEdge[120, 246] -> 
             RGBColor[
              0.505090585435528, 0.6088359587265868, 0.9542531127865411], 
             UndirectedEdge[53, 308] -> 
             RGBColor[
              0.27516616979901054`, 0.4065474693745552, 0.9389816783469607], 
             UndirectedEdge[188, 392] -> 
             RGBColor[
              0.25751756533120074`, 0.38799766709273437`, 0.9379766164312895],
              UndirectedEdge[91, 273] -> 
             RGBColor[
              0.26902930475390907`, 0.40009723511243644`, 0.9386321929613204],
              UndirectedEdge[327, 354] -> 
             RGBColor[
              0.2991827847858058, 0.430880112131681, 0.9403827211333795], 
             UndirectedEdge[51, 376] -> 
             RGBColor[
              0.405658343586251, 0.5257826010583926, 0.9470691688370954], 
             UndirectedEdge[202, 214] -> 
             RGBColor[
              0.9200563597791344, 0.7107376048071281, 0.556968147234525], 
             UndirectedEdge[69, 132] -> 
             RGBColor[
              0.6437204915353074, 0.7192373735289359, 0.9667380893382732], 
             UndirectedEdge[130, 387] -> 
             RGBColor[
              0.35198717062244894`, 0.47789208825307206`, 0.9437006686594926],
              UndirectedEdge[61, 306] -> 
             RGBColor[
              0.9818610097196364, 0.9499548547858537, 0.42826904779571534`], 
             UndirectedEdge[312, 356] -> 
             RGBColor[
              0.4906677898927829, 0.5973852420238213, 0.9530463122771483], 
             UndirectedEdge[18, 247] -> 
             RGBColor[
              0.926107052730001, 0.8138393200274576, 0.6108347292188259], 
             UndirectedEdge[56, 320] -> 
             RGBColor[
              0.5804145257698448, 0.6691464316920486, 0.9608367095033534], 
             UndirectedEdge[43, 124] -> 
             RGBColor[
              0.22535325774935577`, 0.3541909404893282, 0.9361449066973324], 
             UndirectedEdge[259, 318] -> 
             RGBColor[
              0.2174190793227137, 0.34585161590696, 0.9356930669735002], 
             UndirectedEdge[267, 384] -> 
             RGBColor[
              0.6598133920654725, 0.7330804224584619, 0.9674729852060762], 
             UndirectedEdge[44, 324] -> 
             RGBColor[
              0.2889570987994522, 0.4210426101494208, 0.9397670513516847], 
             UndirectedEdge[62, 204] -> 
             RGBColor[
              0.17899762953989296`, 0.30546823612459895`, 0.9335050222478098],
              UndirectedEdge[42, 109] -> 
             RGBColor[
              0.9631611562508396, 0.9703111795583055, 0.8704491819362283], 
             UndirectedEdge[8, 21] -> 
             RGBColor[
              0.3116185481608299, 0.44433005683844234`, 0.9410770362287135], 
             UndirectedEdge[48, 349] -> 
             RGBColor[
              0.43541101780241814`, 0.5515528720515495, 0.9489649829288928], 
             UndirectedEdge[222, 332] -> 
             RGBColor[
              0.5660742539559687, 0.6586036065728093, 0.9589825853511816], 
             UndirectedEdge[58, 167] -> 
             RGBColor[
              0.2911802301180382, 0.4233792621199214, 0.9398936553914501], 
             UndirectedEdge[76, 144] -> 
             RGBColor[
              0.8626912709570241, 0.4513693690163807, 0.2064327327986027], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.44236640792617826`, 0.5377470693075241, 0.9524063925246276], 
             UndirectedEdge[6, 166] -> 
             RGBColor[
              0.9090583234505556, 0.5897855777490221, 0.34432575904947005`], 
             UndirectedEdge[79, 343] -> 
             RGBColor[
              0.6565032648608529, 0.7307948803461315, 0.9669377087053699], 
             UndirectedEdge[142, 257] -> 
             RGBColor[
              0.822095571600614, 0.17084182242934073`, 0.16879205035911396`], 
             UndirectedEdge[175, 256] -> 
             RGBColor[
              0.20212025348377827`, 0.329771579948656, 0.9348218214745575], 
             UndirectedEdge[8, 171] -> 
             RGBColor[
              0.2917662705538139, 0.42384970493064567`, 0.9399323578314926], 
             UndirectedEdge[31, 214] -> 
             RGBColor[
              0.5834952534993698, 0.6486610383850888, 0.9230487158880236], 
             UndirectedEdge[41, 114] -> 
             RGBColor[
              0.3348490984330268, 0.46445119188281303`, 0.9425572663500889], 
             UndirectedEdge[72, 399] -> 
             RGBColor[
              0.23130276285488832`, 0.3604442475756538, 0.9364837222115884], 
             UndirectedEdge[278, 392] -> 
             RGBColor[
              0.2501824179205401, 0.3802879620889227, 0.9375588906376304], 
             UndirectedEdge[6, 323] -> 
             RGBColor[
              0.9117788938600264, 0.9278152609967583, 0.7504833392562442], 
             UndirectedEdge[132, 323] -> 
             RGBColor[
              0.8147163030891271, 0.8552644900665589, 0.9821450311245175], 
             UndirectedEdge[200, 355] -> 
             RGBColor[
              0.2507904105311417, 0.380927000871623, 0.9375935149173598], 
             UndirectedEdge[98, 215] -> 
             RGBColor[
              0.8984291495802124, 0.5426319701729883, 0.2667341084618861], 
             UndirectedEdge[12, 367] -> 
             RGBColor[
              0.21887583976336028`, 0.3473827634940262, 0.9357760273255111], 
             UndirectedEdge[88, 140] -> 
             RGBColor[
              0.8311193811821351, 0.8669473441407145, 0.8890621705145608], 
             UndirectedEdge[195, 327] -> 
             RGBColor[
              0.2821434199050674, 0.41297065928389304`, 0.9394123545109028], 
             UndirectedEdge[142, 381] -> 
             RGBColor[
              0.9073655012701238, 0.5791717949250715, 0.46576856864206445`], 
             UndirectedEdge[313, 359] -> 
             RGBColor[
              0.2641882368664749, 0.39500896582131095`, 0.9383565013068491], 
             UndirectedEdge[64, 82] -> 
             RGBColor[
              0.38908871359710695`, 0.5114308203756144, 0.9460133666661356], 
             UndirectedEdge[98, 297] -> 
             RGBColor[
              0.9621045612745434, 0.9478624391979251, 0.6712874553374975], 
             UndirectedEdge[139, 305] -> 
             RGBColor[
              0.20703664012749182`, 0.3349390140281161, 0.9351018024207747], 
             UndirectedEdge[288, 375] -> 
             RGBColor[
              0.24993566591258726`, 0.38002861008358335`, 0.9375448384758145],
              UndirectedEdge[136, 194] -> 
             RGBColor[
              0.5033185862068833, 0.6058836865205527, 0.954531849750919], 
             UndirectedEdge[254, 349] -> 
             RGBColor[
              0.45744526540329744`, 0.5701981413414695, 0.9504904729468453], 
             UndirectedEdge[348, 351] -> 
             RGBColor[
              0.2543498568494185, 0.38466820463406326`, 0.9377962201194567], 
             UndirectedEdge[65, 282] -> 
             RGBColor[
              0.5810969797016021, 0.6707307553552915, 0.9602123891284602], 
             UndirectedEdge[131, 215] -> 
             RGBColor[
              0.8708771882594211, 0.43978719004972067`, 0.21128818862239418`],
              UndirectedEdge[230, 250] -> 
             RGBColor[
              0.9785422248709081, 0.9480049704007043, 0.5891428358439234], 
             UndirectedEdge[26, 111] -> 
             RGBColor[
              0.6645955027358419, 0.5448101324102603, 0.5834436797495368], 
             UndirectedEdge[301, 390] -> 
             RGBColor[
              0.26155859013835736`, 0.392245040380827, 0.9382067468158966], 
             UndirectedEdge[3, 309] -> 
             RGBColor[
              0.32043505349243634`, 0.4484572206151509, 0.9417673069857059], 
             UndirectedEdge[90, 268] -> 
             RGBColor[
              0.7615624007787926, 0.45211356179516854`, 0.5677648921175946], 
             UndirectedEdge[17, 187] -> 
             RGBColor[
              0.6897252223294911, 0.7560947412907055, 0.9707766661911668], 
             UndirectedEdge[4, 206] -> 
             RGBColor[
              0.23187928370438585`, 0.3610502075420088, 0.9365165542210812], 
             UndirectedEdge[19, 231] -> 
             RGBColor[
              0.2915341164557601, 0.4237512190985569, 0.9399138086948555], 
             UndirectedEdge[76, 138] -> 
             RGBColor[
              0.8331436561867612, 0.2557622418600043, 0.17937170863583543`], 
             UndirectedEdge[28, 390] -> 
             RGBColor[
              0.2772941937947283, 0.40878415751856884`, 0.9391028661653874], 
             UndirectedEdge[123, 174] -> 
             RGBColor[
              0.8514507591880022, 0.8841310051490996, 0.9509891763922267], 
             UndirectedEdge[2, 98] -> 
             RGBColor[
              0.8980106482873484, 0.5394151858476, 0.26633335115120993`], 
             UndirectedEdge[20, 364] -> 
             RGBColor[
              0.37859437323609996`, 0.5023411502157933, 0.945344676578113], 
             UndirectedEdge[56, 196] -> 
             RGBColor[
              0.3744295737159023, 0.4977332530910004, 0.9451159345325955], 
             UndirectedEdge[360, 374] -> 
             RGBColor[
              0.293247724709362, 0.42540017170025574`, 0.9400169674113716], 
             UndirectedEdge[39, 360] -> 
             RGBColor[
              0.29174189371093673`, 0.42381744784571107`, 0.9399312125636886],
              UndirectedEdge[261, 264] -> 
             RGBColor[
              0.1847396920189574, 0.3115035078578844, 0.9338320242113725], 
             UndirectedEdge[101, 253] -> 
             RGBColor[
              0.3012788054166666, 0.43094522374745403`, 0.9405803668258977], 
             UndirectedEdge[141, 273] -> 
             RGBColor[
              0.31775067217972763`, 0.44656178652298995`, 0.9415805292809634],
              UndirectedEdge[171, 182] -> 
             RGBColor[
              0.2806534492526592, 0.41231494799395196`, 0.9392941707941435], 
             UndirectedEdge[156, 175] -> 
             RGBColor[
              0.18244584031582461`, 0.30909252427929373`, 0.9337013927503286],
              UndirectedEdge[121, 250] -> 
             RGBColor[
              0.7707116790518824, 0.8187741201767487, 0.9013688926659322], 
             UndirectedEdge[68, 308] -> 
             RGBColor[
              0.26890650081077455`, 0.39996816038198235`, 0.938625199458431], 
             UndirectedEdge[39, 390] -> 
             RGBColor[
              0.26969566944831447`, 0.40079762665621843`, 0.9386701414448686],
              UndirectedEdge[54, 181] -> 
             RGBColor[
              0.5096518890083631, 0.6127613709392468, 0.9545507619731439], 
             UndirectedEdge[196, 313] -> 
             RGBColor[
              0.2903662346350581, 0.4225237012570149, 0.9398472995528928], 
             UndirectedEdge[200, 241] -> 
             RGBColor[
              0.2808108014657587, 0.41248033514662596`, 0.9393031317698977], 
             UndirectedEdge[186, 255] -> 
             RGBColor[
              0.2544713249858168, 0.38479587534694254`, 0.9378031375501286], 
             UndirectedEdge[11, 38] -> 
             RGBColor[
              0.9446269367354516, 0.8152649274529434, 0.2894401056343812], 
             UndirectedEdge[173, 310] -> 
             RGBColor[
              0.20447288081658893`, 0.33224434044062834`, 0.9349558001207607],
              UndirectedEdge[106, 173] -> 
             RGBColor[
              0.5874312139478495, 0.658182594689114, 0.9541358462016971], 
             UndirectedEdge[51, 396] -> 
             RGBColor[
              0.3256114518738936, 0.4536350211799036, 0.9420717220904409], 
             UndirectedEdge[6, 18] -> 
             RGBColor[
              0.9692770544063248, 0.9734175595259907, 0.7474672305772001], 
             UndirectedEdge[238, 287] -> 
             RGBColor[
              0.24471825055354252`, 0.3745447757379873, 0.9372477143895912], 
             UndirectedEdge[93, 225] -> 
             RGBColor[
              0.25117310830966183`, 0.38132924050128825`, 0.9376153089896959],
              UndirectedEdge[116, 276] -> 
             RGBColor[
              0.5908937430052579, 0.6758585483037947, 0.9625051852330178], 
             UndirectedEdge[135, 276] -> 
             RGBColor[
              0.6344220971523353, 0.7122040883931675, 0.9656535874330512], 
             UndirectedEdge[147, 172] -> 
             RGBColor[
              0.29308124725627194`, 0.4253773516636531, 0.9400019155051696], 
             UndirectedEdge[185, 224] -> 
             RGBColor[
              0.8996759960158076, 0.5563318548969114, 0.2651346625378677], 
             UndirectedEdge[160, 166] -> 
             RGBColor[
              0.8271233428626157, 0.2094874755325008, 0.1736066497976622], 
             UndirectedEdge[63, 156] -> 
             RGBColor[
              0.5722602959769347, 0.592332243346744, 0.6137097186204522], 
             UndirectedEdge[247, 302] -> 
             RGBColor[
              0.9471422868502191, 0.8188837514344283, 0.3245541983516868], 
             UndirectedEdge[81, 240] -> 
             RGBColor[
              0.22946097871463872`, 0.3585084156683923, 0.9363788353294766], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.3163910437219365, 0.4480120932607672, 0.9413976728873965], 
             UndirectedEdge[12, 212] -> 
             RGBColor[
              0.2146670795751315, 0.34295908968538924`, 0.9355363446590942], 
             UndirectedEdge[18, 74] -> 
             RGBColor[
              0.8849400211257357, 0.9108459941170431, 0.9803872287207334], 
             UndirectedEdge[1, 7] -> 
             RGBColor[
              0.37469401379728373`, 0.4989628549076562, 0.945096149123624], 
             UndirectedEdge[231, 331] -> 
             RGBColor[
              0.38038829696430865`, 0.5038892359163952, 0.9454591932807552], 
             UndirectedEdge[58, 351] -> 
             RGBColor[
              0.27227774194596055`, 0.4035115485640963, 0.9388171866537756], 
             UndirectedEdge[142, 279] -> 
             RGBColor[
              0.8836168067234831, 0.49456770966954106`, 0.2217143859275474], 
             UndirectedEdge[303, 344] -> 
             RGBColor[
              0.3051201948561256, 0.4369324167818024, 0.9407277420647475], 
             UndirectedEdge[302, 323] -> 
             RGBColor[
              0.9087436394185031, 0.9180978599174181, 0.6943707488073377], 
             UndirectedEdge[144, 366] -> 
             RGBColor[
              0.8898592758254438, 0.5927585201905767, 0.22980821876360358`], 
             UndirectedEdge[56, 342] -> 
             RGBColor[
              0.5271466154555224, 0.626935692782203, 0.9559359367348119], 
             UndirectedEdge[137, 293] -> 
             RGBColor[
              0.2163935789679292, 0.34477375001360355`, 0.9356346662453872], 
             UndirectedEdge[39, 374] -> 
             RGBColor[
              0.2745978955714905, 0.40595017713076464`, 0.9389493159703898], 
             UndirectedEdge[4, 278] -> 
             RGBColor[
              0.24230606056995913`, 0.37200941112356267`, 0.9371103437385414],
              UndirectedEdge[238, 396] -> 
             RGBColor[
              0.25376131131834845`, 0.3840496059649667, 0.9377627033221374], 
             UndirectedEdge[118, 293] -> 
             RGBColor[
              0.20864634306607288`, 0.33663091387762584`, 0.9351934726217848],
              UndirectedEdge[201, 228] -> 
             RGBColor[
              0.3221417320475673, 0.45045653149250003`, 0.9418569760468667], 
             UndirectedEdge[212, 336] -> 
             RGBColor[
              0.21095186783418274`, 0.3390541665876225, 0.9353247688466104], 
             UndirectedEdge[186, 200] -> 
             RGBColor[
              0.2595636633022175, 0.3901482457903771, 0.9380931386838082], 
             UndirectedEdge[7, 356] -> 
             RGBColor[
              0.4538916995859768, 0.5657933672154302, 0.9506306565950378], 
             UndirectedEdge[215, 269] -> 
             RGBColor[
              0.9061735630089964, 0.5684125935804545, 0.32599457253607145`], 
             UndirectedEdge[36, 122] -> 
             RGBColor[
              0.4828824410191481, 0.5908684223901826, 0.952487665639901], 
             UndirectedEdge[297, 352] -> 
             RGBColor[
              0.970396577990795, 0.974814330666099, 0.7901511578367646], 
             UndirectedEdge[228, 243] -> 
             RGBColor[
              0.3281145647549416, 0.45673435736741674`, 0.9421971200335375], 
             UndirectedEdge[100, 271] -> 
             RGBColor[
              0.3417009842764249, 0.4702049097204598, 0.9430004912657755], 
             UndirectedEdge[157, 298] -> 
             RGBColor[
              0.6463369873520685, 0.7210185843298552, 0.9671902179184984], 
             UndirectedEdge[272, 384] -> 
             RGBColor[
              0.6977223834801167, 0.763785295951966, 0.9705061046650639], 
             UndirectedEdge[35, 114] -> 
             RGBColor[
              0.30495946572485455`, 0.43600078246607, 0.9407465148814157], 
             UndirectedEdge[15, 155] -> 
             RGBColor[
              0.30420326810120896`, 0.4370673007485326, 0.9406352981387334], 
             UndirectedEdge[36, 262] -> 
             RGBColor[
              0.7291600782306236, 0.787348496129779, 0.9720379295278863], 
             UndirectedEdge[111, 185] -> 
             RGBColor[
              0.8488843177529799, 0.35210056877181173`, 0.19347970101943163`],
              UndirectedEdge[26, 400] -> 
             RGBColor[
              0.4223618806328297, 0.5402016308185901, 0.9481469689308566], 
             UndirectedEdge[61, 131] -> 
             RGBColor[
              0.9579060415796807, 0.8592435772757068, 0.3867967672286041], 
             UndirectedEdge[168, 350] -> 
             RGBColor[
              0.5514466203488134, 0.6457438382038303, 0.9582764796526682], 
             UndirectedEdge[16, 208] -> 
             RGBColor[
              0.2374736143413805, 0.36693020374253915`, 0.9368351430747874], 
             UndirectedEdge[125, 303] -> 
             RGBColor[
              0.28379884955745593`, 0.41562096314419106`, 0.9394732966882988],
              UndirectedEdge[145, 164] -> 
             RGBColor[
              0.2402812832877892, 0.36988124182170756`, 0.9369950356677115], 
             UndirectedEdge[152, 256] -> 
             RGBColor[
              0.2044622657846265, 0.33223318336900387`, 0.9349551956103941], 
             UndirectedEdge[237, 246] -> 
             RGBColor[
              0.5111109439056949, 0.6137235569467266, 0.9547270574586124], 
             UndirectedEdge[16, 284] -> 
             RGBColor[
              0.24292930031788273`, 0.3726644756143127, 0.9371458363201851], 
             UndirectedEdge[240, 309] -> 
             RGBColor[
              0.2549984797573888, 0.3853499484354077, 0.9378331582345141], 
             UndirectedEdge[151, 249] -> 
             RGBColor[
              0.2927023996318287, 0.42432368443317114`, 0.9400043408205379], 
             UndirectedEdge[47, 311] -> 
             RGBColor[
              0.47663297852550124`, 0.5854636862286419, 0.9520871802976505], 
             UndirectedEdge[29, 190] -> 
             RGBColor[
              0.2407660977459846, 0.370390812556283, 0.937022645133887], 
             UndirectedEdge[99, 384] -> 
             RGBColor[
              0.863277719993484, 0.893302482160574, 0.9487341980321153], 
             UndirectedEdge[5, 398] -> 
             RGBColor[
              0.8904342144946242, 0.9153759950567726, 0.9860799767962038], 
             UndirectedEdge[36, 157] -> 
             RGBColor[
              0.49446056893751156`, 0.6004643909150807, 0.9533448937369567], 
             UndirectedEdge[40, 55] -> 
             RGBColor[
              0.37142239221905604`, 0.496129140733077, 0.9448876842896408], 
             UndirectedEdge[163, 319] -> 
             RGBColor[
              0.2432784612852803, 0.3730314659291315, 0.9371657205207411], 
             UndirectedEdge[13, 74] -> 
             RGBColor[
              0.8942268027978797, 0.9177720606824189, 0.9646671297303714], 
             UndirectedEdge[47, 158] -> 
             RGBColor[
              0.468503909528975, 0.5788641418068768, 0.9514472302084831], 
             UndirectedEdge[252, 330] -> 
             RGBColor[
              0.2245525377985933, 0.3533493330524997, 0.9360993068806954], 
             UndirectedEdge[102, 185] -> 
             RGBColor[
              0.8214937595564198, 0.16621603134194454`, 0.16821575446594406`],
              UndirectedEdge[41, 356] -> 
             RGBColor[
              0.4295993605310475, 0.5447525640945126, 0.9490827702313296], 
             UndirectedEdge[33, 175] -> 
             RGBColor[
              0.17893676407552545`, 0.30540426266245535`, 0.9335015560496566],
              UndirectedEdge[12, 126] -> 
             RGBColor[
              0.2152393660615204, 0.3435605990676429, 0.935568935527872], 
             UndirectedEdge[18, 191] -> 
             RGBColor[
              0.8120299641162554, 0.853850200152278, 0.9731302939895274], 
             UndirectedEdge[64, 171] -> 
             RGBColor[
              0.3360864294513485, 0.46223759897173367`, 0.9427563991656658], 
             UndirectedEdge[73, 184] -> 
             RGBColor[
              0.230439447723778, 0.35953684863551605`, 0.9364345576920319], 
             UndirectedEdge[93, 316] -> 
             RGBColor[
              0.2497588091651779, 0.37984272242869066`, 0.9375347667456857], 
             UndirectedEdge[20, 362] -> 
             RGBColor[
              0.406159003588231, 0.5262162475882044, 0.9471010704497052], 
             UndirectedEdge[32, 330] -> 
             RGBColor[
              0.2205286799485376, 0.349120003324768, 0.935870154128899], 
             UndirectedEdge[124, 277] -> 
             RGBColor[
              0.24054204876353127`, 0.3701553228701986, 0.9370098858757869], 
             UndirectedEdge[267, 331] -> 
             RGBColor[
              0.511645707636986, 0.6143827846807824, 0.9547069650679356], 
             UndirectedEdge[134, 167] -> 
             RGBColor[
              0.25893816716997997`, 0.3894908096966502, 0.9380575176044159], 
             UndirectedEdge[143, 398] -> 
             RGBColor[
              0.7820348247548993, 0.8302487551810782, 0.97550730112162], 
             UndirectedEdge[109, 320] -> 
             RGBColor[
              0.8519952349988198, 0.8825603077930796, 0.8596099472355513], 
             UndirectedEdge[28, 147] -> 
             RGBColor[
              0.2865134731880893, 0.418474204697066, 0.9396278904881377], 
             UndirectedEdge[54, 311] -> 
             RGBColor[
              0.48568276233296276`, 0.5933021541073054, 0.9526638245194523], 
             UndirectedEdge[160, 289] -> 
             RGBColor[
              0.863615444991354, 0.42809333252077686`, 0.20612813226240806`], 
             UndirectedEdge[209, 240] -> 
             RGBColor[
              0.24561974977362988`, 0.37549230857665095`, 0.9372990534365266],
              UndirectedEdge[31, 261] -> 
             RGBColor[
              0.18133289143212553`, 0.3079227444374911, 0.9336380119578622], 
             UndirectedEdge[245, 248] -> 
             RGBColor[
              0.2230533686520324, 0.3517736112266503, 0.9360139314156208], 
             UndirectedEdge[81, 245] -> 
             RGBColor[
              0.22480714766170556`, 0.3536169441618284, 0.9361138065357382], 
             UndirectedEdge[308, 386] -> 
             RGBColor[
              0.30022575986843436`, 0.4300559235597101, 0.9405124330603728], 
             UndirectedEdge[320, 349] -> 
             RGBColor[
              0.5776365804223218, 0.666740315055617, 0.9606597012822499], 
             UndirectedEdge[222, 356] -> 
             RGBColor[
              0.5616526527416191, 0.6550139515161355, 0.9586345007067291], 
             UndirectedEdge[200, 374] -> 
             RGBColor[
              0.27338169058223005`, 0.4046718685752019, 0.9388800548954654], 
             UndirectedEdge[73, 348] -> 
             RGBColor[
              0.2530355996274438, 0.3832868369650472, 0.9377213751149346], 
             UndirectedEdge[23, 81] -> 
             RGBColor[
              0.2165666874460731, 0.34495569799984427`, 0.9356445245171263], 
             UndirectedEdge[25, 233] -> 
             RGBColor[
              0.8330846738019452, 0.25530887740406205`, 0.17931522703752448`],
              UndirectedEdge[168, 170] -> 
             RGBColor[
              0.5575600626847299, 0.651038994684655, 0.958666022792408], 
             UndirectedEdge[73, 284] -> 
             RGBColor[
              0.24355703331110456`, 0.3733242627907594, 0.9371815847855014], 
             UndirectedEdge[143, 234] -> 
             RGBColor[
              0.4816918202752083, 0.5869870677287701, 0.9531992911334777], 
             UndirectedEdge[288, 374] -> 
             RGBColor[
              0.26056485892169184`, 0.3912005658659134, 0.9381501552932011], 
             UndirectedEdge[254, 344] -> 
             RGBColor[
              0.39507001975859724`, 0.5161718386350326, 0.946515977450629], 
             UndirectedEdge[6, 102] -> 
             RGBColor[
              0.9063222891856516, 0.5687552194511105, 0.3417057295474893], 
             UndirectedEdge[205, 276] -> 
             RGBColor[
              0.8804173286055655, 0.9045483902483498, 0.8526723312886473], 
             UndirectedEdge[101, 244] -> 
             RGBColor[
              0.2604390037563816, 0.39106828410749395`, 0.9381429880277227], 
             UndirectedEdge[58, 80] -> 
             RGBColor[
              0.31661369550810525`, 0.44773804311104304`, 0.9414289555561544],
              UndirectedEdge[23, 292] -> 
             RGBColor[
              0.21221830344661968`, 0.3403852707129492, 0.9353968904812151], 
             UndirectedEdge[101, 397] -> 
             RGBColor[
              0.2550956906132599, 0.3854521232084524, 0.9378386942489454], 
             UndirectedEdge[105, 168] -> 
             RGBColor[
              0.5437472998304071, 0.6390750737498879, 0.957785885757477], 
             UndirectedEdge[166, 340] -> 
             RGBColor[
              0.9092736160962124, 0.5902460669486567, 0.36775903489702405`], 
             UndirectedEdge[138, 317] -> 
             RGBColor[
              0.9049849697863369, 0.5700377324760639, 0.4855767081666582], 
             UndirectedEdge[71, 120] -> 
             RGBColor[
              0.7187491637803132, 0.7794609626924269, 0.9732879603430942], 
             UndirectedEdge[231, 290] -> 
             RGBColor[
              0.3569089205700484, 0.48355258019145775`, 0.9439631081789103], 
             UndirectedEdge[13, 224] -> 
             RGBColor[
              0.9697208187554422, 0.9510352770851425, 0.6530724790472836], 
             UndirectedEdge[40, 159] -> 
             RGBColor[
              0.33537336280871854`, 0.46490528333474357`, 0.9425906720125191],
              UndirectedEdge[20, 265] -> 
             RGBColor[
              0.49977683892029745`, 0.6035406289522859, 0.9541059564454999], 
             UndirectedEdge[43, 299] -> 
             RGBColor[
              0.22078197517346282`, 0.34938623266600927`, 0.9358845789172419],
              UndirectedEdge[219, 220] -> 
             RGBColor[
              0.4613111794873067, 0.5733857750910603, 0.9507812424766675], 
             UndirectedEdge[56, 290] -> 
             RGBColor[
              0.42803437429076585`, 0.5451635942026395, 0.9484949497272399], 
             UndirectedEdge[64, 157] -> 
             RGBColor[
              0.43410205704708005`, 0.5499866920911975, 0.9490010571312653], 
             UndirectedEdge[13, 340] -> 
             RGBColor[
              0.9787791287241259, 0.9808041152910011, 0.7551804074343922], 
             UndirectedEdge[16, 188] -> 
             RGBColor[
              0.25447321455412675`, 0.38479786140304184`, 0.9378032451582485],
              UndirectedEdge[171, 308] -> 
             RGBColor[
              0.26715048285961845`, 0.3981224741773486, 0.9385251968339084], 
             UndirectedEdge[288, 379] -> 
             RGBColor[
              0.23299167582952007`, 0.3622194021952592, 0.9365799033069708], 
             UndirectedEdge[81, 353] -> 
             RGBColor[
              0.2150475477536689, 0.34335898586410785`, 0.9355580117590097], 
             UndirectedEdge[153, 188] -> 
             RGBColor[
              0.2922583395910017, 0.4237094580639409, 0.939984452630228], 
             UndirectedEdge[148, 356] -> 
             RGBColor[
              0.5711332147381206, 0.6627106988393463, 0.9593808452755366], 
             UndirectedEdge[198, 247] -> 
             RGBColor[
              0.866748584365629, 0.7667536625408037, 0.6136734000774657], 
             UndirectedEdge[94, 375] -> 
             RGBColor[
              0.25748465436672835`, 0.3879630755823982, 0.9379747422005502], 
             UndirectedEdge[298, 307] -> 
             RGBColor[
              0.9043350538106595, 0.9251046086494896, 0.9386480207606034], 
             UndirectedEdge[9, 142] -> 
             RGBColor[
              0.8236257057163587, 0.18260310375199956`, 0.1702573085163904], 
             UndirectedEdge[203, 284] -> 
             RGBColor[
              0.26769783285159876`, 0.3986977737229138, 0.93855636760622], 
             UndirectedEdge[370, 400] -> 
             RGBColor[
              0.6104137657145253, 0.6900683539569277, 0.9649050090474223], 
             UndirectedEdge[63, 381] -> 
             RGBColor[
              0.975854040924288, 0.9316564884007599, 0.528376469194335], 
             UndirectedEdge[222, 251] -> 
             RGBColor[
              0.7136213718875605, 0.7756511419302459, 0.9724778106511085], 
             UndirectedEdge[103, 234] -> 
             RGBColor[
              0.34165277525472826`, 0.4703441947830308, 0.9429907906209125], 
             UndirectedEdge[150, 399] -> 
             RGBColor[
              0.2527398969113101, 0.3829760346617555, 0.9377045352827038], 
             UndirectedEdge[321, 338] -> 
             RGBColor[
              0.9060374188254435, 0.923886001186349, 0.8010879565228419], 
             UndirectedEdge[154, 203] -> 
             RGBColor[
              0.36077780249875213`, 0.4853053517709617, 0.9442681500235399], 
             UndirectedEdge[225, 390] -> 
             RGBColor[
              0.26170368970244295`, 0.3923975492225247, 0.9382150100214157], 
             UndirectedEdge[54, 121] -> 
             RGBColor[
              0.502593813473784, 0.607031307257596, 0.9539951244124792], 
             UndirectedEdge[234, 346] -> 
             RGBColor[
              0.34188570275875485`, 0.4705459448797419, 0.9430056325554994], 
             UndirectedEdge[358, 391] -> 
             RGBColor[
              0.8944837314108928, 0.5317010026573729, 0.24979314294089291`], 
             UndirectedEdge[74, 357] -> 
             RGBColor[
              0.7501817896070486, 0.8048048860165811, 0.9757247096384958], 
             UndirectedEdge[130, 364] -> 
             RGBColor[
              0.379967678176128, 0.5035306379305324, 0.9454321823545258], 
             UndirectedEdge[202, 381] -> 
             RGBColor[
              0.9247433274483484, 0.7127453819428937, 0.4824095946157798], 
             UndirectedEdge[98, 307] -> 
             RGBColor[
              0.9814050384421338, 0.9620825967866911, 0.6308199289588313], 
             UndirectedEdge[242, 317] -> 
             RGBColor[
              0.954486951543472, 0.8521857620679489, 0.5290777523178287], 
             UndirectedEdge[9, 279] -> 
             RGBColor[
              0.8856585389447988, 0.5102613582153388, 0.22366955100848618`], 
             UndirectedEdge[200, 399] -> 
             RGBColor[
              0.2527693356026074, 0.3830069765928298, 0.9377062117726225], 
             UndirectedEdge[275, 306] -> 
             RGBColor[
              0.9812383782660234, 0.9513676250265612, 0.559996794380909], 
             UndirectedEdge[121, 181] -> 
             RGBColor[
              0.5602542166801026, 0.6538786381225696, 0.9585244106973264], 
             UndirectedEdge[239, 271] -> 
             RGBColor[
              0.31565140111640955`, 0.4476420700773734, 0.9413406348615612], 
             UndirectedEdge[35, 354] -> 
             RGBColor[
              0.2804072432672092, 0.41205616989288285`, 0.9392801497275012], 
             UndirectedEdge[31, 310] -> 
             RGBColor[
              0.18289778193115996`, 0.30956754357176464`, 0.9337271301567341],
              UndirectedEdge[146, 154] -> 
             RGBColor[
              0.48274463326921224`, 0.5903240190384458, 0.9525963248033308], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.8938562482651202, 0.6317789737296462, 0.5786286100973383], 
             UndirectedEdge[265, 322] -> 
             RGBColor[
              0.5501554119867256, 0.6456799735265193, 0.9577293957987232], 
             UndirectedEdge[115, 284] -> 
             RGBColor[
              0.24130209476909242`, 0.37095417941174347`, 0.9370531693714164],
              UndirectedEdge[38, 391] -> 
             RGBColor[
              0.8930910009287811, 0.5270029957125417, 0.24438264801297166`], 
             UndirectedEdge[116, 328] -> 
             RGBColor[
              0.3628292631493686, 0.48868620423613895`, 0.944340137703926], 
             UndirectedEdge[92, 278] -> 
             RGBColor[
              0.2700397327532974, 0.4011592590046289, 0.9386897353410912], 
             UndirectedEdge[215, 217] -> 
             RGBColor[
              0.8210569332669986, 0.16285839306295227`, 0.16779744911786956`],
              UndirectedEdge[159, 210] -> 
             RGBColor[
              0.3156791522092831, 0.44703146697688845`, 0.9413656404050212], 
             UndirectedEdge[165, 298] -> 
             RGBColor[
              0.6780894534855002, 0.7467966667692734, 0.969689888365638], 
             UndirectedEdge[83, 254] -> 
             RGBColor[
              0.4111965295816905, 0.5301398109018447, 0.9475435443964437], 
             UndirectedEdge[103, 231] -> 
             RGBColor[
              0.3266251404157554, 0.4573222919288569, 0.942033452486374], 
             UndirectedEdge[245, 319] -> 
             RGBColor[
              0.2357412606353747, 0.36510939015995814`, 0.9367364880940181], 
             UndirectedEdge[58, 263] -> 
             RGBColor[
              0.28044730154374703`, 0.41209827368136553`, 0.9392824309870891],
              UndirectedEdge[206, 258] -> 
             RGBColor[
              0.24224766571092132`, 0.37194803442426605`, 0.9371070182377067],
              UndirectedEdge[213, 391] -> 
             RGBColor[
              0.8656794520004861, 0.4212316977913123, 0.20719030408487465`], 
             UndirectedEdge[78, 370] -> 
             RGBColor[
              0.8365302867115927, 0.5954450493775967, 0.5857332485541368], 
             UndirectedEdge[101, 270] -> 
             RGBColor[
              0.2552144898783262, 0.38557698876834556`, 0.937845459691343], 
             UndirectedEdge[135, 377] -> 
             RGBColor[
              0.4590787183907463, 0.5706961122538062, 0.9508478818462491], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.22879801729426974`, 0.3578116011814027, 0.9363410806573501], 
             UndirectedEdge[19, 83] -> 
             RGBColor[
              0.31363288900734776`, 0.44289778603368235`, 0.9413217134716801],
              UndirectedEdge[100, 112] -> 
             RGBColor[
              0.35276762831000186`, 0.47997132185075075`, 0.9436990192291159],
              UndirectedEdge[10, 296] -> 
             RGBColor[
              0.331723708667086, 0.46107618573568054`, 0.9423825762220581], 
             UndirectedEdge[85, 369] -> 
             RGBColor[
              0.24938070758750824`, 0.3794453136975352, 0.9375132344201885], 
             UndirectedEdge[79, 246] -> 
             RGBColor[
              0.5173044068287108, 0.618751689159956, 0.9552146295473145], 
             UndirectedEdge[227, 280] -> 
             RGBColor[
              0.23696761026347307`, 0.36639836137414694`, 0.9368063268911165],
              UndirectedEdge[112, 326] -> 
             RGBColor[
              0.3341557033790634, 0.4638506079381187, 0.9425130838303954], 
             UndirectedEdge[34, 308] -> 
             RGBColor[
              0.2866886948098787, 0.4183307981986623, 0.9396498632451982], 
             UndirectedEdge[29, 226] -> 
             RGBColor[
              0.23953161826969796`, 0.36909329635618626`, 0.936952343353961], 
             UndirectedEdge[204, 345] -> 
             RGBColor[
              0.1904371972329284, 0.3174919470804629, 0.9341564887046044], 
             UndirectedEdge[54, 265] -> 
             RGBColor[
              0.5219430916057815, 0.622739922920198, 0.9555183704657713], 
             UndirectedEdge[22, 100] -> 
             RGBColor[
              0.3344662411106874, 0.46260073594405915`, 0.9425884833453301], 
             UndirectedEdge[126, 336] -> 
             RGBColor[
              0.21152415432057162`, 0.33965567596987617`, 0.9353573597153882],
              UndirectedEdge[82, 157] -> 
             RGBColor[
              0.4242304983845992, 0.5414364441367214, 0.9483720501423687], 
             UndirectedEdge[344, 349] -> 
             RGBColor[
              0.3830038950089686, 0.5061604563464437, 0.9456256474062932], 
             UndirectedEdge[343, 349] -> 
             RGBColor[
              0.5837898565381997, 0.6715473011239714, 0.9612730023398459], 
             UndirectedEdge[2, 66] -> 
             RGBColor[
              0.8956170407292666, 0.531340985508409, 0.2570346377829214], 
             UndirectedEdge[211, 387] -> 
             RGBColor[
              0.27812297420375887`, 0.4096552582761729, 0.939150063983611], 
             UndirectedEdge[250, 265] -> 
             RGBColor[
              0.7900609571838799, 0.8344827358393506, 0.9028921387192244], 
             UndirectedEdge[217, 306] -> 
             RGBColor[
              0.8966008926384637, 0.5440937493586522, 0.25445421300955695`], 
             UndirectedEdge[374, 375] -> 
             RGBColor[
              0.26547453356081113`, 0.3963609452029792, 0.9384297540006862], 
             UndirectedEdge[38, 247] -> 
             RGBColor[
              0.9363993756149239, 0.7826453892822661, 0.2828200168311238], 
             UndirectedEdge[204, 310] -> 
             RGBColor[
              0.18075257528517846`, 0.3073127953728809, 0.9336049638117943], 
             UndirectedEdge[226, 266] -> 
             RGBColor[
              0.24681597923856835`, 0.37674962158963, 0.9373671769348919], 
             UndirectedEdge[319, 334] -> 
             RGBColor[
              0.25149135479282314`, 0.3816637377330832, 0.9376334326561084], 
             UndirectedEdge[73, 206] -> 
             RGBColor[
              0.23733902327111464`, 0.366788739994123, 0.9368274783124455], 
             UndirectedEdge[200, 255] -> 
             RGBColor[
              0.26556731627814384`, 0.3964584657216599, 0.9384350378391786], 
             UndirectedEdge[296, 383] -> 
             RGBColor[
              0.2908789334455868, 0.4230625802138626, 0.9398764969916824], 
             UndirectedEdge[235, 281] -> 
             RGBColor[
              0.6860438629162344, 0.7545031690861064, 0.9694506561545053], 
             UndirectedEdge[174, 272] -> 
             RGBColor[
              0.6878111560407678, 0.756042569748228, 0.9695182461395961], 
             UndirectedEdge[9, 131] -> 
             RGBColor[
              0.8740668087143025, 0.4643040105665355, 0.21434257277214977`], 
             UndirectedEdge[228, 361] -> 
             RGBColor[
              0.3617418491636495, 0.4877443408967252, 0.9442708486463184], 
             UndirectedEdge[149, 199] -> 
             RGBColor[
              0.2230106997449548, 0.3517287634999468, 0.9360115014844858], 
             UndirectedEdge[102, 400] -> 
             RGBColor[
              0.6044539714967849, 0.33060708272811645`, 0.5560794046708185], 
             UndirectedEdge[45, 350] -> 
             RGBColor[
              0.36412092231360993`, 0.48858020750687353`, 0.9444672858023867],
              UndirectedEdge[369, 392] -> 
             RGBColor[
              0.2527015805879449, 0.38293576177650346`, 0.937702353224772], 
             UndirectedEdge[82, 151] -> 
             RGBColor[
              0.34752633634939933`, 0.4754315781894705, 0.9433650487400788], 
             UndirectedEdge[260, 342] -> 
             RGBColor[
              0.706156116764429, 0.7697763499712335, 0.9717551750957918], 
             UndirectedEdge[296, 380] -> 
             RGBColor[
              0.28350610283773925`, 0.41531326778055483`, 0.939456625195691], 
             UndirectedEdge[105, 148] -> 
             RGBColor[
              0.520616067080279, 0.620721827134755, 0.9556738363326167], 
             UndirectedEdge[94, 288] -> 
             RGBColor[
              0.25257497972760906`, 0.38280269624533236`, 0.9376951434930652],
              UndirectedEdge[195, 258] -> 
             RGBColor[
              0.24931398381106837`, 0.3793751827779651, 0.9375094345998292], 
             UndirectedEdge[339, 374] -> 
             RGBColor[
              0.3209321143289635, 0.44937899853087393`, 0.9417809922375882], 
             UndirectedEdge[199, 367] -> 
             RGBColor[
              0.2225587298907346, 0.35125371452661747`, 0.9359857624699174], 
             UndirectedEdge[36, 298] -> 
             RGBColor[
              0.6715537144550077, 0.7414906593926315, 0.9691753710479567], 
             UndirectedEdge[147, 347] -> 
             RGBColor[
              0.28239395908436904`, 0.4141443341817761, 0.9393932902542057], 
             UndirectedEdge[38, 205] -> 
             RGBColor[
              0.9805298619657696, 0.9442896440229023, 0.524841136015259], 
             UndirectedEdge[16, 73] -> 
             RGBColor[
              0.24248824364408117`, 0.372200897085539, 0.937120718795097], 
             UndirectedEdge[108, 290] -> 
             RGBColor[
              0.3863513979794556, 0.5090598951690881, 0.945838947335492], 
             UndirectedEdge[225, 296] -> 
             RGBColor[
              0.2793148229194171, 0.41090796684390285`, 0.9392179380047856], 
             UndirectedEdge[24, 144] -> 
             RGBColor[
              0.8902955651891483, 0.5947396082931894, 0.23017226930310958`], 
             UndirectedEdge[209, 319] -> 
             RGBColor[
              0.24680833108244982`, 0.37674158289262827`, 0.9373667413837155],
              UndirectedEdge[80, 192] -> 
             RGBColor[
              0.3394530711598287, 0.46843892165637124`, 0.9428506274211075], 
             UndirectedEdge[42, 221] -> 
             RGBColor[
              0.9270423893059134, 0.944662453609973, 0.9929033247441504], 
             UndirectedEdge[22, 365] -> 
             RGBColor[
              0.27427955709376345`, 0.40561558320684826`, 0.9389311870650228],
              UndirectedEdge[80, 201] -> 
             RGBColor[
              0.30542134246892777`, 0.4359741704306982, 0.9407915676081757], 
             UndirectedEdge[39, 375] -> 
             RGBColor[
              0.2639687025623859, 0.39477822134843454`, 0.9383439991530031], 
             UndirectedEdge[15, 326] -> 
             RGBColor[
              0.3216255760176605, 0.45254598204008034`, 0.9417312126565649], 
             UndirectedEdge[86, 95] -> 
             RGBColor[
              0.2911574427094625, 0.42335531110870317`, 0.9398923576822427], 
             UndirectedEdge[59, 194] -> 
             RGBColor[
              0.3610366257463029, 0.4871335118181791, 0.9442259124337696], 
             UndirectedEdge[296, 324] -> 
             RGBColor[
              0.2907395975741168, 0.42291612937854317`, 0.9398685620199312], 
             UndirectedEdge[169, 245] -> 
             RGBColor[
              0.22529865841710267`, 0.3541335531293326, 0.936141797346133], 
             UndirectedEdge[258, 284] -> 
             RGBColor[
              0.24846567575091127`, 0.3784835572209025, 0.9374611247107626], 
             UndirectedEdge[33, 152] -> 
             RGBColor[
              0.18127877637637368`, 0.30786586608280325`, 0.9336349301854932],
              UndirectedEdge[246, 349] -> 
             RGBColor[
              0.44459099850605766`, 0.559504109937796, 0.9495499231817904], 
             UndirectedEdge[27, 395] -> 
             RGBColor[
              0.28524240829505776`, 0.41713823490432095`, 0.9395555052228516],
              UndirectedEdge[185, 340] -> 
             RGBColor[
              0.9087343059844912, 0.5861006931027701, 0.36724259092497624`], 
             UndirectedEdge[223, 321] -> 
             RGBColor[
              0.6359268279774656, 0.7126257479828174, 0.9663189746381065], 
             UndirectedEdge[274, 373] -> 
             RGBColor[
              0.24052488712014738`, 0.3701372848948911, 0.9370089085455846], 
             UndirectedEdge[156, 214] -> 
             RGBColor[
              0.5848663164286375, 0.6501021124541597, 0.9231267958935396], 
             UndirectedEdge[205, 221] -> 
             RGBColor[
              0.9585637141169614, 0.9664203575638242, 0.8602427231177231], 
             UndirectedEdge[97, 105] -> 
             RGBColor[
              0.42981427861771465`, 0.5467052578700499, 0.9486083636570456], 
             UndirectedEdge[130, 158] -> 
             RGBColor[
              0.4567607455909806, 0.5686928034323673, 0.9506989661864262], 
             UndirectedEdge[108, 143] -> 
             RGBColor[
              0.49610666284564264`, 0.5994724798522266, 0.954117792155521], 
             UndirectedEdge[176, 399] -> 
             RGBColor[
              0.22535125221155355`, 0.3541888325419396, 0.9361447924849214], 
             UndirectedEdge[150, 189] -> 
             RGBColor[
              0.28557376029945525`, 0.4174865068698732, 0.9395743752293106], 
             UndirectedEdge[253, 386] -> 
             RGBColor[
              0.3405394596215219, 0.4693798967384182, 0.942919851133231], 
             UndirectedEdge[46, 59] -> 
             RGBColor[
              0.30916725287120805`, 0.4399481765928165, 0.9410035436196971], 
             UndirectedEdge[186, 241] -> 
             RGBColor[
              0.2697148101734317, 0.4008177447719086, 0.9386712314808479], 
             UndirectedEdge[39, 93] -> 
             RGBColor[
              0.2591650880555334, 0.38972931793498194`, 0.9380704404131488], 
             UndirectedEdge[214, 264] -> 
             RGBColor[
              0.5869020540862017, 0.6522418018054821, 0.9232427281415339], 
             UndirectedEdge[234, 290] -> 
             RGBColor[
              0.37193655540902126`, 0.4965744830456317, 0.9449204463134487], 
             UndirectedEdge[148, 170] -> 
             RGBColor[
              0.5344288299346016, 0.632685748069522, 0.9565539733675475], 
             UndirectedEdge[50, 362] -> 
             RGBColor[
              0.4294033294821849, 0.5463267879239184, 0.948588402469489], 
             UndirectedEdge[271, 326] -> 
             RGBColor[
              0.3230890593454866, 0.4540841958078278, 0.941814555867055], 
             UndirectedEdge[61, 352] -> 
             RGBColor[
              0.9937500196167237, 0.9890402488671484, 0.5611063895673631], 
             UndirectedEdge[256, 333] -> 
             RGBColor[
              0.21043441051870343`, 0.338510286140365, 0.9352953004180034], 
             UndirectedEdge[100, 394] -> 
             RGBColor[
              0.3677410184422385, 0.49294051979882375`, 0.944653110407893], 
             UndirectedEdge[1, 114] -> 
             RGBColor[
              0.3444304570913155, 0.4727500831795342, 0.9431677820513322], 
             UndirectedEdge[218, 269] -> 
             RGBColor[
              0.9515613514707596, 0.9593431212476458, 0.7385846645144882], 
             UndirectedEdge[182, 253] -> 
             RGBColor[
              0.31490504522225604`, 0.4452672657366318, 0.9413563610246107], 
             UndirectedEdge[57, 354] -> 
             RGBColor[
              0.27649042962059545`, 0.4079393504099632, 0.939057092984733], 
             UndirectedEdge[40, 192] -> 
             RGBColor[
              0.34190093761815415`, 0.4705591405492272, 0.9430066033072686], 
             UndirectedEdge[262, 314] -> 
             RGBColor[
              0.9322274207027686, 0.9487209428474576, 0.9907658897447179], 
             UndirectedEdge[244, 253] -> 
             RGBColor[
              0.30087597692201773`, 0.4305218254587764, 0.9405574263390588], 
             UndirectedEdge[277, 330] -> 
             RGBColor[
              0.24129239010618297`, 0.3709439791957144, 0.9370526167052204], 
             UndirectedEdge[304, 329] -> 
             RGBColor[
              0.2271186296842969, 0.35604645832399684`, 0.9362454420173936], 
             UndirectedEdge[103, 223] -> 
             RGBColor[
              0.3993166746191169, 0.5202694238127852, 0.9466707039440156], 
             UndirectedEdge[92, 337] -> 
             RGBColor[
              0.2862035870447653, 0.41814849471251614`, 0.9396102429307109], 
             UndirectedEdge[226, 341] -> 
             RGBColor[
              0.23010886985563692`, 0.3591893903362524, 0.9364157317714874], 
             UndirectedEdge[193, 260] -> 
             RGBColor[
              0.8156468227717713, 0.8559278037169716, 0.9822546582008858], 
             UndirectedEdge[9, 214] -> 
             RGBColor[
              0.9047202658222255, 0.5928576663351037, 0.5422822863417485], 
             UndirectedEdge[8, 157] -> 
             RGBColor[
              0.38978189814954545`, 0.5115987980501094, 0.9461770157970921], 
             UndirectedEdge[103, 342] -> 
             RGBColor[
              0.4739621782432806, 0.580870006396498, 0.9525470714247991], 
             UndirectedEdge[165, 314] -> 
             RGBColor[
              0.7292803775430885, 0.7876149200721775, 0.9745725244009281], 
             UndirectedEdge[115, 392] -> 
             RGBColor[
              0.24327765587914302`, 0.37303061939621557`, 0.937165674654053], 
             UndirectedEdge[104, 233] -> 
             RGBColor[
              0.8756661600168449, 0.4553685127100845, 0.21500153588103987`], 
             UndirectedEdge[67, 139] -> 
             RGBColor[
              0.21205827028800195`, 0.34021706571655375`, 0.9353877768295796],
              UndirectedEdge[116, 364] -> 
             RGBColor[
              0.382875553578809, 0.5060492934502673, 0.9456174696038513], 
             UndirectedEdge[74, 220] -> 
             RGBColor[
              0.6500539956476187, 0.724027222159205, 0.9674931897567542], 
             UndirectedEdge[100, 168] -> 
             RGBColor[
              0.5233822877675662, 0.6214359238763232, 0.9564882451969059], 
             UndirectedEdge[129, 308] -> 
             RGBColor[
              0.2493864248848615, 0.3794513229395511, 0.9375135600118147], 
             UndirectedEdge[26, 185] -> 
             RGBColor[
              0.6394016686924645, 0.37581057943241813`, 0.5602833187259821], 
             UndirectedEdge[197, 215] -> 
             RGBColor[
              0.9040198154602492, 0.5694397771754294, 0.5010925431304881], 
             UndirectedEdge[178, 240] -> 
             RGBColor[
              0.24159747707370743`, 0.3712646449422136, 0.9370699909566852], 
             UndirectedEdge[52, 223] -> 
             RGBColor[
              0.42035633884682855`, 0.5384929234825571, 0.9480113327439608], 
             UndirectedEdge[192, 243] -> 
             RGBColor[
              0.31643084813058897`, 0.44661450926807483`, 0.9414526439417388],
              UndirectedEdge[124, 252] -> 
             RGBColor[
              0.22380219645594157`, 0.3525606767269839, 0.936056576051262], 
             UndirectedEdge[194, 396] -> 
             RGBColor[
              0.3331772870037427, 0.4601881672994485, 0.9425538104147095], 
             UndirectedEdge[269, 279] -> 
             RGBColor[
              0.9693542844710024, 0.9048940200148108, 0.380506034096984], 
             UndirectedEdge[57, 208] -> 
             RGBColor[
              0.2531470707031978, 0.383404000133339, 0.9377277232277921], 
             UndirectedEdge[169, 304] -> 
             RGBColor[
              0.21989845129097363`, 0.3484575930468634, 0.9358342635391905], 
             UndirectedEdge[209, 280] -> 
             RGBColor[
              0.24552309910713999`, 0.37539072259816386`, 0.9372935493240518],
              UndirectedEdge[226, 399] -> 
             RGBColor[
              0.23675652181007376`, 0.36617649402584324`, 0.9367943057159729],
              UndirectedEdge[206, 392] -> 
             RGBColor[
              0.23975564105496683`, 0.3693287585073688, 0.9369651011201702], 
             UndirectedEdge[48, 343] -> 
             RGBColor[
              0.5738217336869491, 0.6629134141226403, 0.9606378423662292], 
             UndirectedEdge[159, 263] -> 
             RGBColor[
              0.29675910238603487`, 0.4271452950122101, 0.9402881715572926], 
             UndirectedEdge[261, 295] -> 
             RGBColor[
              0.2109178597842839, 0.3390184219709439, 0.935322832138479], 
             UndirectedEdge[33, 204] -> 
             RGBColor[
              0.1789341933349501, 0.3054015606511163, 0.9335014096497838], 
             UndirectedEdge[64, 151] -> 
             RGBColor[
              0.35739789501188024`, 0.48398182614394664`, 0.9439940557289754],
              UndirectedEdge[210, 263] -> 
             RGBColor[
              0.2810036601000736, 0.41268304179923465`, 0.9393141147838132], 
             UndirectedEdge[19, 303] -> 
             RGBColor[
              0.2819979246761117, 0.4137280769086658, 0.939370736680536], 
             UndirectedEdge[248, 315] -> 
             RGBColor[
              0.229741057636631, 0.35880279637343554`, 0.9363947854097444], 
             UndirectedEdge[236, 351] -> 
             RGBColor[
              0.2481333456349381, 0.37813425719806837`, 0.9374421990022963], 
             UndirectedEdge[53, 386] -> 
             RGBColor[
              0.3143035505913172, 0.444852574192945, 0.9413141424158159], 
             UndirectedEdge[93, 301] -> 
             RGBColor[
              0.25102800874557624`, 0.38117673165959054`, 0.9376070457841768],
              UndirectedEdge[37, 159] -> 
             RGBColor[
              0.29061706023566036`, 0.4206896192842019, 0.9399383913431659], 
             UndirectedEdge[148, 326] -> 
             RGBColor[
              0.4816391300864997, 0.5869619633485583, 0.9531902603733251], 
             UndirectedEdge[13, 357] -> 
             RGBColor[
              0.8197351159980406, 0.8595406855045937, 0.9572525529228332], 
             UndirectedEdge[162, 231] -> 
             RGBColor[
              0.27738405997012383`, 0.4088786125667542, 0.9391079839111312], 
             UndirectedEdge[33, 84] -> 
             RGBColor[
              0.17893420048233583`, 0.30540156816347186`, 0.9335014100568169],
              UndirectedEdge[199, 293] -> 
             RGBColor[
              0.21851691429369074`, 0.3470055100682143, 0.9357555870509962], 
             UndirectedEdge[96, 167] -> 
             RGBColor[
              0.28523047788544853`, 0.41712569528738996`, 0.9395548258036737],
              UndirectedEdge[131, 307] -> 
             RGBColor[
              0.9538530771213425, 0.8592378166634234, 0.5753740091193393], 
             UndirectedEdge[174, 291] -> 
             RGBColor[
              0.7125484820155874, 0.7753675568103979, 0.9719838316093115], 
             UndirectedEdge[207, 250] -> 
             RGBColor[
              0.9640415176105277, 0.8943275288623829, 0.5576168978426572], 
             UndirectedEdge[364, 387] -> 
             RGBColor[
              0.3215492584874442, 0.4515282986156772, 0.941761191813439], 
             UndirectedEdge[103, 346] -> 
             RGBColor[
              0.3447990844282577, 0.4730693696510448, 0.9431912706592778], 
             UndirectedEdge[31, 106] -> 
             RGBColor[
              0.5658561150624204, 0.6355057978202503, 0.9529071762376704], 
             UndirectedEdge[128, 316] -> 
             RGBColor[
              0.29024632988181515`, 0.4207827161213608, 0.9398996026647567], 
             UndirectedEdge[185, 289] -> 
             RGBColor[
              0.8607218959500621, 0.40585224662813213`, 0.20335726643267069`],
              UndirectedEdge[20, 172] -> 
             RGBColor[
              0.3545418209166673, 0.4808311305362721, 0.9438368541227812], 
             UndirectedEdge[70, 234] -> 
             RGBColor[
              0.30827476436067847`, 0.438573607296341, 0.9409687003893238], 
             UndirectedEdge[119, 383] -> 
             RGBColor[
              0.2603673467577916, 0.3909929680586598, 0.93813890726766], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.5352140965427551, 0.633549940550514, 0.9565531607151321], 
             UndirectedEdge[20, 54] -> 
             RGBColor[
              0.4298252331165606, 0.5467147461063611, 0.9486090616680254], 
             UndirectedEdge[229, 334] -> 
             RGBColor[
              0.25414759898597045`, 0.3844556187956901, 0.9377847018333471], 
             UndirectedEdge[63, 142] -> 
             RGBColor[
              0.890072513149207, 0.5193941486818902, 0.23091004398772222`], 
             UndirectedEdge[230, 358] -> 
             RGBColor[
              0.9687169526811137, 0.9061370771638947, 0.3329716977842575], 
             UndirectedEdge[119, 296] -> 
             RGBColor[
              0.27100995406971695`, 0.4021790231237703, 0.9387449880097476], 
             UndirectedEdge[218, 262] -> 
             RGBColor[
              0.9243533171861171, 0.9424423464401257, 0.9900148507220045], 
             UndirectedEdge[100, 170] -> 
             RGBColor[
              0.4107918604538279, 0.5302289953510277, 0.9473962719925066], 
             UndirectedEdge[97, 357] -> 
             RGBColor[
              0.5589872751901463, 0.652039901144515, 0.958856542313451], 
             UndirectedEdge[375, 399] -> 
             RGBColor[
              0.24486217858118842`, 0.3746960532206071, 0.9372559108778432], 
             UndirectedEdge[199, 252] -> 
             RGBColor[
              0.2250679449332263, 0.3538910586296987, 0.9361286585545363], 
             UndirectedEdge[175, 345] -> 
             RGBColor[
              0.1904397679735038, 0.31749464909180203`, 0.9341566351044772], 
             UndirectedEdge[176, 186] -> 
             RGBColor[
              0.23214557991116364`, 0.36133010173948693`, 0.9365317193961071],
              UndirectedEdge[309, 371] -> 
             RGBColor[
              0.2714180274121831, 0.4026079340800466, 0.9387682271829105], 
             UndirectedEdge[326, 354] -> 
             RGBColor[
              0.3095818357707423, 0.4398872474233331, 0.94104533946662], 
             UndirectedEdge[38, 289] -> 
             RGBColor[
              0.9317722599024755, 0.7624356715057958, 0.27900046954474644`], 
             UndirectedEdge[120, 237] -> 
             RGBColor[
              0.5723986729827764, 0.663738054850602, 0.9594804667840822], 
             UndirectedEdge[275, 384] -> 
             RGBColor[
              0.8702642398197578, 0.8971991046411623, 0.8780681531351799], 
             UndirectedEdge[216, 220] -> 
             RGBColor[
              0.5672680445778805, 0.6593163046949915, 0.9592519182010989], 
             UndirectedEdge[50, 276] -> 
             RGBColor[
              0.6098568885565028, 0.6922609454050347, 0.9637197242270632], 
             UndirectedEdge[143, 321] -> 
             RGBColor[
              0.7212153553030598, 0.7818668166701053, 0.973033199931347], 
             UndirectedEdge[225, 316] -> 
             RGBColor[
              0.2556938059368381, 0.38608078033623494`, 0.9378727560317908], 
             UndirectedEdge[40, 332] -> 
             RGBColor[
              0.43326686926446056`, 0.5476890621459892, 0.9493828047697146], 
             UndirectedEdge[254, 343] -> 
             RGBColor[
              0.5958559812878284, 0.6815586834125604, 0.9621633323841816], 
             UndirectedEdge[37, 167] -> 
             RGBColor[
              0.26667449670074206`, 0.39762218254510395`, 0.9384980901263189],
              UndirectedEdge[26, 204] -> 
             RGBColor[
              0.3170199268376633, 0.4369570715354334, 0.9418741487280438], 
             UndirectedEdge[141, 189] -> 
             RGBColor[
              0.33030534537683665`, 0.4597575440654077, 0.9422954993465642], 
             UndirectedEdge[55, 210] -> 
             RGBColor[
              0.3517281816196206, 0.4782553243752219, 0.9436626526821428], 
             UndirectedEdge[41, 312] -> 
             RGBColor[
              0.40188874544580117`, 0.5222558384193261, 0.9469012891044913], 
             UndirectedEdge[102, 247] -> 
             RGBColor[
              0.8631522875093278, 0.40917697995257735`, 0.2050732281891151], 
             UndirectedEdge[30, 400] -> 
             RGBColor[
              0.284268969836752, 0.4086385761438802, 0.9397738211163575], 
             UndirectedEdge[57, 195] -> 
             RGBColor[
              0.25945106473985713`, 0.3900298975621752, 0.9380867263622563], 
             UndirectedEdge[301, 324] -> 
             RGBColor[
              0.2683877801719362, 0.39942295210177514`, 0.9385956590854276], 
             UndirectedEdge[290, 331] -> 
             RGBColor[
              0.42861309362707734`, 0.5456648518044729, 0.9485318252116084], 
             UndirectedEdge[49, 347] -> 
             RGBColor[
              0.2678932418389194, 0.3989031609582332, 0.9385674958589661], 
             UndirectedEdge[92, 258] -> 
             RGBColor[
              0.2702985516937192, 0.40143129412108086`, 0.93870447469686], 
             UndirectedEdge[234, 313] -> 
             RGBColor[
              0.3107738733861259, 0.4412003293347502, 0.9411110209512226], 
             UndirectedEdge[376, 377] -> 
             RGBColor[
              0.4266363429774569, 0.5439526897461481, 0.9484058684081864], 
             UndirectedEdge[223, 272] -> 
             RGBColor[
              0.5505420601979628, 0.6459225184451997, 0.9578086189518668], 
             UndirectedEdge[213, 302] -> 
             RGBColor[
              0.9491225739214294, 0.8267349297802298, 0.3261475838124945], 
             UndirectedEdge[121, 158] -> 
             RGBColor[
              0.5281560210081759, 0.6278198768688632, 0.9559975231544674], 
             UndirectedEdge[240, 248] -> 
             RGBColor[
              0.22770719970496556`, 0.3566650827332143, 0.9362789602093593], 
             UndirectedEdge[18, 132] -> 
             RGBColor[
              0.8722144636354254, 0.9008667885957915, 0.9791289224454733], 
             UndirectedEdge[59, 79] -> 
             RGBColor[
              0.46241207497172554`, 0.5712067102742551, 0.9517169387007705], 
             UndirectedEdge[109, 207] -> 
             RGBColor[
              0.9669761340347394, 0.8955410681699965, 0.508982709149612], 
             UndirectedEdge[190, 365] -> 
             RGBColor[
              0.24867185173243342`, 0.3787002612497945, 0.9374728661279003], 
             UndirectedEdge[78, 391] -> 
             RGBColor[
              0.8311173699138001, 0.24018731764171894`, 0.1774313346124849], 
             UndirectedEdge[159, 236] -> 
             RGBColor[
              0.2909783973419341, 0.4210694074929913, 0.9399589689568179], 
             UndirectedEdge[95, 334] -> 
             RGBColor[
              0.27158878350233817`, 0.4027874095573609, 0.9387779514896339], 
             UndirectedEdge[20, 147] -> 
             RGBColor[
              0.34619840677068126`, 0.47206167326583015`, 0.9433617090301424],
              UndirectedEdge[229, 388] -> 
             RGBColor[
              0.23513063549537086`, 0.3644675844219441, 0.9367017138956337], 
             UndirectedEdge[15, 271] -> 
             RGBColor[
              0.3053243996883596, 0.43824568113047624`, 0.940699144924056], 
             UndirectedEdge[53, 151] -> 
             RGBColor[
              0.302539739143033, 0.43466335198279643`, 0.9405645627526612], 
             UndirectedEdge[178, 309] -> 
             RGBColor[
              0.2573894464516083, 0.38786300602707646`, 0.9379693202506316], 
             UndirectedEdge[309, 386] -> 
             RGBColor[
              0.30507679489801537`, 0.4351546689491852, 0.9407886923288442], 
             UndirectedEdge[199, 299] -> 
             RGBColor[
              0.21996573354153404`, 0.3485283109581435, 0.9358380951638248], 
             UndirectedEdge[33, 90] -> 
             RGBColor[
              0.44237359411374266`, 0.5377546224462848, 0.9524068017673784], 
             UndirectedEdge[191, 216] -> 
             RGBColor[
              0.6689774683276695, 0.7413295497654275, 0.9676410801591727], 
             UndirectedEdge[188, 203] -> 
             RGBColor[
              0.2792417470878428, 0.4108311595116429, 0.9392137764442834], 
             UndirectedEdge[87, 263] -> 
             RGBColor[
              0.2761111635451054, 0.407540717717765, 0.9390354943428079], 
             UndirectedEdge[25, 76] -> 
             RGBColor[
              0.8478277754462535, 0.3686308171105509, 0.1934332378220659], 
             UndirectedEdge[329, 334] -> 
             RGBColor[
              0.2482689309678744, 0.37827676597959103`, 0.9374499203864265], 
             UndirectedEdge[42, 376] -> 
             RGBColor[
              0.6853095806395425, 0.7514657941798157, 0.9712763701432583], 
             UndirectedEdge[54, 130] -> 
             RGBColor[
              0.43119853805658864`, 0.5479042338211002, 0.9486965674444381], 
             UndirectedEdge[90, 256] -> 
             RGBColor[
              0.46555708352199543`, 0.5621219397324855, 0.9537270671922793], 
             UndirectedEdge[160, 302] -> 
             RGBColor[
              0.9083773079386029, 0.59816388871644, 0.2904675904582531], 
             UndirectedEdge[299, 367] -> 
             RGBColor[
              0.21672169883755696`, 0.34511862480058364`, 0.9356533521865525],
              UndirectedEdge[16, 96] -> 
             RGBColor[
              0.2643859994981743, 0.3952168268861021, 0.9383677635961609], 
             UndirectedEdge[5, 223] -> 
             RGBColor[
              0.6477551093793219, 0.7220395366342189, 0.9674518801311646], 
             UndirectedEdge[40, 228] -> 
             RGBColor[
              0.35358465424250685`, 0.48067898864856917`, 0.9437510793990673],
              UndirectedEdge[154, 222] -> 
             RGBColor[
              0.5175424648922109, 0.6185744663744461, 0.9553357375773506], 
             UndirectedEdge[85, 188] -> 
             RGBColor[
              0.25419669233076414`, 0.38450721901376617`, 0.937787497626706], 
             UndirectedEdge[281, 384] -> 
             RGBColor[
              0.6902109435663115, 0.7577585241609326, 0.9698659918101223], 
             UndirectedEdge[249, 334] -> 
             RGBColor[
              0.2654841590440016, 0.39637106219610324`, 0.9384303021577143], 
             UndirectedEdge[203, 243] -> 
             RGBColor[
              0.28988476393267687`, 0.4220176450218065, 0.9398198805086642], 
             UndirectedEdge[49, 147] -> 
             RGBColor[
              0.2702371158648362, 0.4013667211696683, 0.9387009760172913], 
             UndirectedEdge[99, 232] -> 
             RGBColor[
              0.7518421224806613, 0.804458883314896, 0.9388506680687247], 
             UndirectedEdge[84, 389] -> 
             RGBColor[
              0.1790075704625178, 0.3054786846645686, 0.933505588368647], 
             UndirectedEdge[76, 242] -> 
             RGBColor[
              0.8826456379438963, 0.5379102714518893, 0.22287275278700588`], 
             UndirectedEdge[129, 397] -> 
             RGBColor[
              0.24351700983454236`, 0.3732821955792575, 0.9371793055077206], 
             UndirectedEdge[177, 390] -> 
             RGBColor[
              0.2941038875347629, 0.4252352483079229, 0.9401047123377103], 
             UndirectedEdge[138, 144] -> 
             RGBColor[
              0.8488904911809813, 0.34529052811745564`, 0.1932170904993126], 
             UndirectedEdge[184, 325] -> 
             RGBColor[
              0.2146653182782982, 0.3429572384507447, 0.9355362443558451], 
             UndirectedEdge[69, 140] -> 
             RGBColor[
              0.5800718085263902, 0.6695145386144623, 0.9603941834467046], 
             UndirectedEdge[247, 391] -> 
             RGBColor[
              0.8636991649292758, 0.4133805194455108, 0.20559691862406698`], 
             UndirectedEdge[14, 391] -> 
             RGBColor[
              0.9073739340103057, 0.5740384053828973, 0.3971702369213773], 
             UndirectedEdge[229, 240] -> 
             RGBColor[
              0.24305133588145522`, 0.372792742729129, 0.9371527860649951], 
             UndirectedEdge[166, 400] -> 
             RGBColor[
              0.6071900057616888, 0.351637441026028, 0.5586994341727993], 
             UndirectedEdge[281, 386] -> 
             RGBColor[
              0.4856785944575267, 0.5902406468075978, 0.9535084650798691], 
             UndirectedEdge[150, 255] -> 
             RGBColor[
              0.26553787758684655`, 0.39642752379058566`, 0.9384333613492598],
              UndirectedEdge[103, 290] -> 
             RGBColor[
              0.3748499370785241, 0.4990979078169345, 0.9451060844172272], 
             UndirectedEdge[212, 299] -> 
             RGBColor[
              0.2125129386493282, 0.3406949509919467, 0.9354136695201356], 
             UndirectedEdge[206, 208] -> 
             RGBColor[
              0.23232439396841398`, 0.3615180466511231, 0.9365419025921359], 
             UndirectedEdge[75, 169] -> 
             RGBColor[
              0.2324382955275915, 0.3616377644115946, 0.9365483891174288], 
             UndirectedEdge[110, 167] -> 
             RGBColor[
              0.26956370563298526`, 0.40065892431931827`, 0.9386626263008084],
              UndirectedEdge[33, 214] -> 
             RGBColor[
              0.5813572401883383, 0.6464138508373214, 0.9229269591928677], 
             UndirectedEdge[98, 107] -> 
             RGBColor[
              0.9083938909149378, 0.6192253386491839, 0.2762763560175848], 
             UndirectedEdge[238, 252] -> 
             RGBColor[
              0.22677811637454098`, 0.3556885572456525, 0.9362260502881472], 
             UndirectedEdge[91, 241] -> 
             RGBColor[
              0.2767915804260243, 0.40825587900053273`, 0.9390742430775896], 
             UndirectedEdge[74, 219] -> 
             RGBColor[
              0.6359306602465759, 0.7123948141262615, 0.9664273391659474], 
             UndirectedEdge[45, 180] -> 
             RGBColor[
              0.33088455801292704`, 0.4597925392578639, 0.9423494940589101], 
             UndirectedEdge[187, 235] -> 
             RGBColor[
              0.792013758809907, 0.8376400126416226, 0.9798528182009743], 
             UndirectedEdge[114, 188] -> 
             RGBColor[0.297981899619691, 0.4286669180863, 0.9403491528141107],
              UndirectedEdge[81, 378] -> 
             RGBColor[
              0.21412094136701804`, 0.3423850638014996, 0.9355052428960813], 
             UndirectedEdge[19, 313] -> 
             RGBColor[
              0.27859623109563336`, 0.41015268127575305`, 0.9391770152634824],
              UndirectedEdge[195, 284] -> 
             RGBColor[
              0.24484639804506322`, 0.3746794668765958, 0.9372550121996561], 
             UndirectedEdge[64, 253] -> 
             RGBColor[
              0.3703380254209453, 0.4951899167144135, 0.9448185893961331], 
             UndirectedEdge[55, 122] -> 
             RGBColor[
              0.4248101196568824, 0.5423709068945195, 0.9482895030730654], 
             UndirectedEdge[99, 275] -> 
             RGBColor[
              0.9851141209349312, 0.987104803716967, 0.8512424005775606], 
             UndirectedEdge[118, 367] -> 
             RGBColor[
              0.21268815866311674`, 0.340879118336029, 0.9354236480407061], 
             UndirectedEdge[7, 96] -> 
             RGBColor[
              0.3381582412697068, 0.46529865529748227`, 0.9428420383243149], 
             UndirectedEdge[110, 115] -> 
             RGBColor[
              0.2470920216969208, 0.3770397597154611, 0.9373828971445268], 
             UndirectedEdge[68, 95] -> 
             RGBColor[
              0.2792515764807897, 0.4108414908268496, 0.9392143362136705], 
             UndirectedEdge[289, 302] -> 
             RGBColor[
              0.9425151711377706, 0.798674033657958, 0.3207346510653094], 
             UndirectedEdge[260, 321] -> 
             RGBColor[
              0.813370248803728, 0.8541302872991015, 0.9820328030897745], 
             UndirectedEdge[191, 220] -> 
             RGBColor[
              0.5771439386381384, 0.6670314281944398, 0.9602362550255482], 
             UndirectedEdge[169, 209] -> 
             RGBColor[
              0.23636572886417778`, 0.36576574586200267`, 0.9367720506358304],
              UndirectedEdge[32, 252] -> 
             RGBColor[
              0.2203092674216852, 0.34888938684748844`, 0.9358576589100864], 
             UndirectedEdge[75, 280] -> 
             RGBColor[
              0.24159566577055375`, 0.3712627411477558, 0.9370698878056503], 
             UndirectedEdge[14, 224] -> 
             RGBColor[
              0.9850092930497456, 0.9599506894449308, 0.4935654545583491], 
             UndirectedEdge[128, 311] -> 
             RGBColor[
              0.4227935959175786, 0.5388307190597109, 0.9486565824461703], 
             UndirectedEdge[132, 198] -> 
             RGBColor[
              0.8128559952710535, 0.8537811311091374, 0.9819675933041132], 
             UndirectedEdge[245, 388] -> 
             RGBColor[
              0.22663197894047044`, 0.3555349575367959, 0.9362177279774678], 
             UndirectedEdge[183, 273] -> 
             RGBColor[
              0.26718551324119244`, 0.3981592933294373, 0.9385271917623162], 
             UndirectedEdge[69, 220] -> 
             RGBColor[
              0.4818265682663484, 0.5902075400149862, 0.9523502989242535], 
             UndirectedEdge[37, 263] -> 
             RGBColor[
              0.25594156812645086`, 0.3863411941065481, 0.9378868657219579], 
             UndirectedEdge[235, 384] -> 
             RGBColor[
              0.7442607582282336, 0.800141428009943, 0.9751446149341176], 
             UndirectedEdge[132, 216] -> 
             RGBColor[
              0.7291619678468395, 0.7883461382089411, 0.9736397086151186], 
             UndirectedEdge[225, 380] -> 
             RGBColor[
              0.2612993849996442, 0.39197259934548456`, 0.9381919854667065], 
             UndirectedEdge[3, 371] -> 
             RGBColor[
              0.3210626317693298, 0.4491168451749269, 0.9418030466401561], 
             UndirectedEdge[269, 314] -> 
             RGBColor[
              0.9594354549874111, 0.9656217176549777, 0.7393357035372017], 
             UndirectedEdge[16, 206] -> 
             RGBColor[
              0.23671129027789278`, 0.36612895281767627`, 0.9367917298471292],
              UndirectedEdge[84, 256] -> 
             RGBColor[
              0.20211768989058865`, 0.32976888544967253`, 0.9348216754817178],
              UndirectedEdge[58, 348] -> 
             RGBColor[
              0.28088310771412667`, 0.4125563335981417, 0.9393072495037748], 
             UndirectedEdge[177, 360] -> 
             RGBColor[
              0.31615011179738517`, 0.4482550694974156, 0.9413657834565303], 
             UndirectedEdge[2, 106] -> 
             RGBColor[
              0.8834730056375308, 0.5519688209280622, 0.5686856052309635], 
             UndirectedEdge[256, 317] -> 
             RGBColor[
              0.6079677143241806, 0.6722679099328412, 0.8705698500730703], 
             UndirectedEdge[87, 351] -> 
             RGBColor[
              0.2679416039473189, 0.3989539926004958, 0.9385702500094941], 
             UndirectedEdge[48, 103] -> 
             RGBColor[
              0.3850045259376993, 0.5078933023022759, 0.9457531258399835], 
             UndirectedEdge[256, 381] -> 
             RGBColor[
              0.6092276972658053, 0.6727889452592876, 0.8496886719990233], 
             UndirectedEdge[91, 226] -> 
             RGBColor[
              0.25062761976227643`, 0.38075589745201466`, 0.9375842442239002],
              UndirectedEdge[105, 113] -> 
             RGBColor[
              0.6069298774587211, 0.6884337835985022, 0.9640833346207096], 
             UndirectedEdge[223, 291] -> 
             RGBColor[
              0.5752793861727824, 0.6652475055073694, 0.9602742044215822], 
             UndirectedEdge[203, 348] -> 
             RGBColor[
              0.277176399167938, 0.4086603478972015, 0.9390961579356532], 
             UndirectedEdge[259, 367] -> 
             RGBColor[
              0.21516769270569408`, 0.3434852658263162, 0.935564853836289], 
             UndirectedEdge[188, 206] -> 
             RGBColor[
              0.2493239941811602, 0.37938570431162577`, 0.937510004675597], 
             UndirectedEdge[250, 289] -> 
             RGBColor[
              0.9429902625743816, 0.8090015716874366, 0.5405821025323335], 
             UndirectedEdge[194, 377] -> 
             RGBColor[
              0.40146722310948635`, 0.5221524631532592, 0.9468021143463783], 
             UndirectedEdge[83, 231] -> 
             RGBColor[
              0.3307828964588674, 0.4609235312385056, 0.9422983810248817], 
             UndirectedEdge[276, 376] -> 
             RGBColor[
              0.6019797217390458, 0.6854606658855094, 0.9632115739949887], 
             UndirectedEdge[83, 120] -> 
             RGBColor[
              0.45962999176153224`, 0.5694602774020465, 0.9513564039568587], 
             UndirectedEdge[40, 243] -> 
             RGBColor[
              0.3138420416346276, 0.4443722151984709, 0.9412876874810078], 
             UndirectedEdge[4, 392] -> 
             RGBColor[
              0.24007285485442642`, 0.3696621703231174, 0.9369831659767736], 
             UndirectedEdge[81, 329] -> 
             RGBColor[
              0.22742713619850993`, 0.35637071823087746`, 0.9362630110069835],
              UndirectedEdge[131, 363] -> 
             RGBColor[
              0.8924893365860593, 0.5994472191560132, 0.23173103267921852`], 
             UndirectedEdge[167, 192] -> 
             RGBColor[
              0.3140196057697616, 0.4440801406652496, 0.941315327256403], 
             UndirectedEdge[41, 327] -> 
             RGBColor[
              0.32970622489449014`, 0.4599966933120725, 0.9422295669958778], 
             UndirectedEdge[24, 382] -> 
             RGBColor[
              0.9004669733536322, 0.6409255971753784, 0.23865954159958375`], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.6399409788041857, 0.37995595327830467`, 0.56079976269803], 
             UndirectedEdge[90, 261] -> 
             RGBColor[
              0.4426270855649366, 0.538021058033776, 0.9524212377305169], 
             UndirectedEdge[146, 297] -> 
             RGBColor[
              0.7409851288378926, 0.7966845449876518, 0.9658863907552364], 
             UndirectedEdge[5, 291] -> 
             RGBColor[
              0.7689673032381015, 0.8196158140703518, 0.9775611053894065], 
             UndirectedEdge[229, 315] -> 
             RGBColor[
              0.24508519381312066`, 0.3749304563693503, 0.9372686112653803], 
             UndirectedEdge[241, 360] -> 
             RGBColor[
              0.3006768355928906, 0.4332086382716799, 0.9404400442858039], 
             UndirectedEdge[59, 237] -> 
             RGBColor[
              0.4562186120487096, 0.5661785780610258, 0.9512293666120685], 
             UndirectedEdge[257, 381] -> 
             RGBColor[
              0.9078770993756948, 0.5831041621482105, 0.46625847556572675`], 
             UndirectedEdge[270, 308] -> 
             RGBColor[
              0.2553377632908749, 0.38570655694091993`, 0.9378524799298211], 
             UndirectedEdge[317, 382] -> 
             RGBColor[
              0.9447039927210837, 0.8118308485146293, 0.5211250046258997], 
             UndirectedEdge[23, 89] -> 
             RGBColor[
              0.21600037669219402`, 0.3443604694913417, 0.9356122739574746], 
             UndirectedEdge[57, 327] -> 
             RGBColor[
              0.2958997785397042, 0.4274294644124098, 0.9401957587844365], 
             UndirectedEdge[347, 362] -> 
             RGBColor[
              0.3423545559019188, 0.4682989085041503, 0.9431326516737686], 
             UndirectedEdge[43, 293] -> 
             RGBColor[
              0.21933315592561953`, 0.34786343177608003`, 0.9358020708044131],
              UndirectedEdge[73, 208] -> 
             RGBColor[
              0.23810134733460236`, 0.3675899909189858, 0.9368708915401036], 
             UndirectedEdge[53, 129] -> 
             RGBColor[
              0.26346421560774436`, 0.39424797357278596`, 0.9383152693672578],
              UndirectedEdge[324, 383] -> 
             RGBColor[
              0.2800969902621915, 0.41173007431343256`, 0.9392624812778436], 
             UndirectedEdge[368, 399] -> 
             RGBColor[
              0.22383026101092823`, 0.35259017435367035`, 0.9360581742861507],
              UndirectedEdge[51, 136] -> 
             RGBColor[
              0.4957527510770341, 0.5993305404010079, 0.9540497614266502], 
             UndirectedEdge[145, 359] -> 
             RGBColor[
              0.24179608967805666`, 0.37147339938215107`, 0.9370813016506819],
              UndirectedEdge[222, 297] -> 
             RGBColor[
              0.7757829604608912, 0.8249349923236523, 0.9686258035292561], 
             UndirectedEdge[81, 209] -> 
             RGBColor[
              0.23587421810878062`, 0.36524913689449845`, 0.9367440598254355],
              UndirectedEdge[31, 345] -> 
             RGBColor[
              0.1925824038789099, 0.3197466952793466, 0.9342786550495443], 
             UndirectedEdge[155, 180] -> 
             RGBColor[
              0.33540782096983857`, 0.46454677541701367`, 0.9426070871927383],
              UndirectedEdge[4, 369] -> 
             RGBColor[
              0.2448252232373639, 0.37465721081114345`, 0.937253806325683], 
             UndirectedEdge[102, 289] -> 
             RGBColor[
              0.8585251717968794, 0.3889672621761071, 0.20125368090273776`], 
             UndirectedEdge[70, 103] -> 
             RGBColor[
              0.3111881460301813, 0.44109703206764383`, 0.9411543384931023], 
             UndirectedEdge[177, 375] -> 
             RGBColor[
              0.28837692064883436`, 0.4192158430001391, 0.939778570045845], 
             UndirectedEdge[171, 253] -> 
             RGBColor[
              0.30746418261270597`, 0.43744644735605664`, 0.9409326149067666],
              UndirectedEdge[150, 241] -> 
             RGBColor[
              0.2807813627744614, 0.41244939321555174`, 0.939301455279979], 
             UndirectedEdge[24, 317] -> 
             RGBColor[
              0.946390043794504, 0.8194868126517976, 0.5225318869704552], 
             UndirectedEdge[80, 110] -> 
             RGBColor[
              0.29499717102305234`, 0.4250177053104399, 0.9401979264655129], 
             UndirectedEdge[176, 341] -> 
             RGBColor[
              0.21870360025711671`, 0.3472017288523488, 0.9357662185404361], 
             UndirectedEdge[154, 192] -> 
             RGBColor[
              0.3873238866966642, 0.5099022160172301, 0.9459009134566145], 
             UndirectedEdge[121, 322] -> 
             RGBColor[
              0.5308061338547281, 0.6299713578639174, 0.9562061497454312], 
             UndirectedEdge[268, 381] -> 
             RGBColor[
              0.9052330145226024, 0.5627805673219706, 0.46372649692433865`], 
             UndirectedEdge[76, 104] -> 
             RGBColor[
              0.8904092616611533, 0.5686904524165735, 0.22911954666558126`], 
             UndirectedEdge[91, 186] -> 
             RGBColor[
              0.2555444422624831, 0.38592378964428387`, 0.9378642499915], 
             UndirectedEdge[216, 357] -> 
             RGBColor[
              0.6673958385373104, 0.7400939685523675, 0.9674834380828405], 
             UndirectedEdge[210, 236] -> 
             RGBColor[
              0.27522295505597283`, 0.4066071542800159, 0.9389849121833385], 
             UndirectedEdge[26, 173] -> 
             RGBColor[
              0.34074023236907375`, 0.46188861660318076`, 0.9432249850370102],
              UndirectedEdge[10, 374] -> 
             RGBColor[
              0.31901480157328777`, 0.4477183185888486, 0.9416588227642095], 
             UndirectedEdge[289, 340] -> 
             RGBColor[
              0.9457657182249508, 0.8088519239369327, 0.40028051736176995`], 
             UndirectedEdge[65, 168] -> 
             RGBColor[
              0.592741338058181, 0.6798274166038522, 0.9613729899467283], 
             UndirectedEdge[40, 203] -> 
             RGBColor[
              0.31535485342024205`, 0.44596227630295887`, 0.941373839874194], 
             UndirectedEdge[167, 201] -> 
             RGBColor[
              0.27998787707886075`, 0.41161538943957654`, 0.9392562674434715],
              UndirectedEdge[41, 57] -> 
             RGBColor[
              0.3070138697292798, 0.4370559315903547, 0.9409039388472313], 
             UndirectedEdge[214, 363] -> 
             RGBColor[
              0.9231427936939823, 0.7280008749245814, 0.5596707462488172], 
             UndirectedEdge[22, 189] -> 
             RGBColor[
              0.29643257003583556`, 0.4288998043911114, 0.9401927683796281], 
             UndirectedEdge[41, 96] -> 
             RGBColor[
              0.3138659022147775, 0.44425785217656466`, 0.9412941519606068], 
             UndirectedEdge[31, 197] -> 
             RGBColor[
              0.5859844235922751, 0.6497599697422292, 0.884913356826519], 
             UndirectedEdge[275, 281] -> 
             RGBColor[
              0.8120473445077586, 0.8515608457173255, 0.8723741943555676], 
             UndirectedEdge[89, 353] -> 
             RGBColor[
              0.21448123699978983`, 0.34276375735560527`, 0.9355257611993579],
              UndirectedEdge[324, 375] -> 
             RGBColor[
              0.267401497471214, 0.3983863064493811, 0.938539491744696], 
             UndirectedEdge[5, 174] -> 
             RGBColor[
              0.7850242052221269, 0.8321595879372474, 0.979161507318894], 
             UndirectedEdge[36, 314] -> 
             RGBColor[
              0.7227446385125958, 0.7823089126955356, 0.9740580070832467], 
             UndirectedEdge[220, 357] -> 
             RGBColor[
              0.5755623088477795, 0.6657958469813797, 0.960078612949216], 
             UndirectedEdge[291, 342] -> 
             RGBColor[
              0.6499248897969461, 0.7258480880910823, 0.9661505719023658], 
             UndirectedEdge[21, 159] -> 
             RGBColor[
              0.3221758681761928, 0.45347427680941704`, 0.9417497393246208], 
             UndirectedEdge[220, 394] -> 
             RGBColor[
              0.4171512331180811, 0.5351366490894776, 0.9479674097431279], 
             UndirectedEdge[129, 249] -> 
             RGBColor[
              0.25362687609654, 0.3839083060231606, 0.9377550474351345], 
             UndirectedEdge[37, 58] -> 
             RGBColor[
              0.2743052593933725, 0.40564259795335733`, 0.9389326507729624], 
             UndirectedEdge[118, 259] -> 
             RGBColor[
              0.20854115618205327`, 0.33652035579328765`, 0.9351874823843499],
              UndirectedEdge[201, 243] -> 
             RGBColor[
              0.2823991194396881, 0.4141497580424017, 0.9393935841288071], 
             UndirectedEdge[40, 110] -> 
             RGBColor[
              0.29744503748137785`, 0.4271379242032959, 0.940353902351674], 
             UndirectedEdge[35, 278] -> 
             RGBColor[
              0.26672833715189703`, 0.3976787722729497, 0.9385011562603622], 
             UndirectedEdge[164, 315] -> 
             RGBColor[
              0.2429063670041037, 0.37264037124747484`, 0.9371445303018922], 
             UndirectedEdge[81, 304] -> 
             RGBColor[
              0.21940694053557647`, 0.34794098407935925`, 0.9358062727287957],
              UndirectedEdge[12, 299] -> 
             RGBColor[
              0.21628284341415968`, 0.3446573599255522, 0.9356283600194184], 
             UndirectedEdge[203, 258] -> 
             RGBColor[
              0.2721654186176039, 0.4033934896242831, 0.9388107900063931], 
             UndirectedEdge[250, 276] -> 
             RGBColor[
              0.8768966809261312, 0.9030925119563854, 0.9110185744810039], 
             UndirectedEdge[124, 238] -> 
             RGBColor[
              0.22624718755874168`, 0.35513051739741625`, 0.9361958146775262],
              UndirectedEdge[96, 154] -> 
             RGBColor[
              0.3585347588123511, 0.48294777063937044`, 0.9441404120038852], 
             UndirectedEdge[126, 238] -> 
             RGBColor[
              0.2206324276302094, 0.349229048716188, 0.9358760624058893], 
             UndirectedEdge[103, 108] -> 
             RGBColor[
              0.3560676178251626, 0.48282960690648735`, 0.9439092916429558], 
             UndirectedEdge[122, 210] -> 
             RGBColor[
              0.3730056479605837, 0.4966847962832106, 0.9450184340224643], 
             UndirectedEdge[108, 234] -> 
             RGBColor[
              0.3531542361556598, 0.4803061821351844, 0.9437236535391773], 
             UndirectedEdge[222, 361] -> 
             RGBColor[
              0.48027671073484357`, 0.5862967431545993, 0.9529611966752556], 
             UndirectedEdge[12, 274] -> 
             RGBColor[
              0.2245824786939262, 0.35338080283185697`, 0.936101011970391], 
             UndirectedEdge[141, 219] -> 
             RGBColor[
              0.4036258957264883, 0.5240221968760659, 0.9469396630566943], 
             UndirectedEdge[179, 344] -> 
             RGBColor[
              0.29513590341832135`, 0.4264382934400302, 0.9401591514378], 
             UndirectedEdge[14, 230] -> 
             RGBColor[
              0.9816071552805266, 0.9484744798894191, 0.4803487917647419], 
             UndirectedEdge[12, 118] -> 
             RGBColor[
              0.21224930323971947`, 0.34041785346099757`, 0.9353986558735721],
              UndirectedEdge[44, 49] -> 
             RGBColor[
              0.2768464709137847, 0.4083135723834269, 0.9390773690096643], 
             UndirectedEdge[224, 247] -> 
             RGBColor[
              0.9413345239687156, 0.7992928035075443, 0.30199213626103877`], 
             UndirectedEdge[161, 222] -> 
             RGBColor[
              0.5181817733764011, 0.6191282032508729, 0.9553764737486448], 
             UndirectedEdge[148, 168] -> 
             RGBColor[
              0.6470192572483401, 0.7238926765948177, 0.9656459465719469], 
             UndirectedEdge[219, 323] -> 
             RGBColor[
              0.6386990444191253, 0.7146022485196659, 0.9666913901196909], 
             UndirectedEdge[309, 334] -> 
             RGBColor[
              0.26609474286190404`, 0.39701282450196873`, 0.9384650740028659],
              UndirectedEdge[170, 326] -> 
             RGBColor[
              0.39217993552288943`, 0.5141082814383957, 0.9462103365937862], 
             UndirectedEdge[239, 354] -> 
             RGBColor[
              0.3021441775416652, 0.43344512169287874`, 0.940571418461126], 
             UndirectedEdge[11, 221] -> 
             RGBColor[
              0.9226607888866434, 0.8373956409938654, 0.6248416927368453], 
             UndirectedEdge[47, 322] -> 
             RGBColor[
              0.47115402237552717`, 0.5810156228019311, 0.9516558567994469], 
             UndirectedEdge[155, 271] -> 
             RGBColor[
              0.305666751429035, 0.4386055145162801, 0.9407186413492236], 
             UndirectedEdge[106, 363] -> 
             RGBColor[
              0.905503655257033, 0.714845634359743, 0.589529206598464], 
             UndirectedEdge[245, 378] -> 
             RGBColor[
              0.2192126419789341, 0.3477367639770881, 0.9357952077134337], 
             UndirectedEdge[155, 326] -> 
             RGBColor[
              0.32196792775833594`, 0.4529058154258842, 0.9417507090817323], 
             UndirectedEdge[10, 39] -> 
             RGBColor[
              0.3175089705748625, 0.446135594734304, 0.9415730679165266], 
             UndirectedEdge[25, 382] -> 
             RGBColor[
              0.8737460186049575, 0.5043450922501913, 0.21576589198201723`], 
             UndirectedEdge[177, 383] -> 
             RGBColor[
              0.3010724134398118, 0.43255961086419054`, 0.9405015595789926], 
             UndirectedEdge[177, 296] -> 
             RGBColor[
              0.3117150207517371, 0.4437456659293011, 0.9411076403210801], 
             UndirectedEdge[103, 143] -> 
             RGBColor[
              0.48460520194471113`, 0.589510492500073, 0.9533849292372562], 
             UndirectedEdge[84, 317] -> 
             RGBColor[
              0.5847770387283635, 0.6478930395078799, 0.8692491754054186], 
             UndirectedEdge[50, 328] -> 
             RGBColor[
              0.38179240870061343`, 0.505088601337379, 0.9455546766979714], 
             UndirectedEdge[332, 385] -> 
             RGBColor[
              0.5513213263478973, 0.6466265153287621, 0.9578211808481198], 
             UndirectedEdge[242, 257] -> 
             RGBColor[
              0.8704770048155868, 0.4443768248986645, 0.21122005596083127`], 
             UndirectedEdge[214, 217] -> 
             RGBColor[
              0.903299381606431, 0.5819361276170735, 0.5409216460120444], 
             UndirectedEdge[51, 59] -> 
             RGBColor[
              0.3534707906164537, 0.48058036569863427`, 0.9437438241095009], 
             UndirectedEdge[66, 131] -> 
             RGBColor[
              0.9476245332536402, 0.8250818486193503, 0.3026198784181737], 
             UndirectedEdge[66, 98] -> 
             RGBColor[
              0.9751764945744315, 0.9279266287426179, 0.3580657982576656], 
             UndirectedEdge[70, 346] -> 
             RGBColor[
              0.3114210735342079, 0.4412987821643549, 0.9411691804276892], 
             UndirectedEdge[151, 253] -> 
             RGBColor[
              0.3287756481732377, 0.4591906745282696, 0.9421702714700763], 
             UndirectedEdge[384, 398] -> 
             RGBColor[
              0.8439266207114591, 0.8788704640005567, 0.9814905615415767], 
             UndirectedEdge[123, 218] -> 
             RGBColor[
              0.9421799541639146, 0.955737423109728, 0.959839004250153], 
             UndirectedEdge[169, 280] -> 
             RGBColor[
              0.229855838803546, 0.3589234386574095, 0.9364013220273968], 
             UndirectedEdge[71, 109] -> 
             RGBColor[
              0.932608231427341, 0.9459491066410988, 0.8675350166916449], 
             UndirectedEdge[166, 302] -> 
             RGBColor[
              0.9060230690090321, 0.580068176669682, 0.28821316860056356`], 
             UndirectedEdge[89, 163] -> 
             RGBColor[
              0.23177803755773202`, 0.36094379142249916`, 0.9365107884028094],
              UndirectedEdge[102, 340] -> 
             RGBColor[
              0.9065375818313084, 0.569215708650745, 0.3651390053950433], 
             UndirectedEdge[380, 390] -> 
             RGBColor[
              0.2658949696207651, 0.39680285015917666`, 0.9384536972123212], 
             UndirectedEdge[172, 387] -> 
             RGBColor[
              0.29749670616801155`, 0.43001827893615596`, 0.9402533693581072],
              UndirectedEdge[61, 298] -> 
             RGBColor[
              0.9083880182689977, 0.925110369261773, 0.7500707788698681], 
             UndirectedEdge[10, 216] -> 
             RGBColor[
              0.5105137254220357, 0.6107590812291837, 0.9554696590225349], 
             UndirectedEdge[209, 229] -> 
             RGBColor[
              0.24946457527559712`, 0.37953346395523513`, 0.937518010560954], 
             UndirectedEdge[39, 119] -> 
             RGBColor[
              0.2567952159774935, 0.3872384321223937, 0.9379354797042159], 
             UndirectedEdge[33, 261] -> 
             RGBColor[
              0.17919487812109408`, 0.3056755568897237, 0.9335162552627061], 
             UndirectedEdge[102, 213] -> 
             RGBColor[
              0.8651325745805382, 0.41702815829837886`, 0.20666661364992278`],
              UndirectedEdge[155, 335] -> 
             RGBColor[
              0.29253189959404885`, 0.42479995244000324`, 0.9399706309684931],
              UndirectedEdge[76, 317] -> 
             RGBColor[
              0.9187857495623798, 0.676116573374989, 0.49879235046594833`], 
             UndirectedEdge[19, 179] -> 
             RGBColor[
              0.2720136332383074, 0.4032339535668936, 0.9388021460535885], 
             UndirectedEdge[48, 83] -> 
             RGBColor[
              0.38916228198081126`, 0.5114945416119245, 0.9460180543784913], 
             UndirectedEdge[288, 355] -> 
             RGBColor[
              0.2379735788706035, 0.36745569816233453`, 0.9368636153150954], 
             UndirectedEdge[7, 192] -> 
             RGBColor[
              0.36694736915401993`, 0.4922531006753419, 0.9446025397770442], 
             UndirectedEdge[341, 393] -> 
             RGBColor[
              0.2222018557461406, 0.35087861717352153`, 0.9359654390153307], 
             UndirectedEdge[244, 270] -> 
             RGBColor[
              0.2548116613836774, 0.3851535904796679, 0.9378225192045042], 
             UndirectedEdge[121, 265] -> 
             RGBColor[
              0.5725454192775208, 0.6638571901035208, 0.9594920191899539], 
             UndirectedEdge[156, 363] -> 
             RGBColor[
              0.5242360164158433, 0.390684407006331, 0.5704454430561892], 
             UndirectedEdge[133, 280] -> 
             RGBColor[
              0.26813571605602704`, 0.3991580167341666, 0.938581304406922], 
             UndirectedEdge[44, 362] -> 
             RGBColor[
              0.35130778497678417`, 0.477709319929344, 0.9436425248244668], 
             UndirectedEdge[116, 147] -> 
             RGBColor[
              0.35047958711339033`, 0.47576981650030403`, 0.9436345020558807],
              UndirectedEdge[83, 196] -> 
             RGBColor[
              0.32540289254677246`, 0.4552688060149441, 0.9419919977610904], 
             UndirectedEdge[109, 233] -> 
             RGBColor[
              0.9057773412404262, 0.5635119739368787, 0.4559259820875775], 
             UndirectedEdge[19, 125] -> 
             RGBColor[
              0.27618503388558474`, 0.4076183601292589, 0.9390397011494167], 
             UndirectedEdge[26, 160] -> 
             RGBColor[
              0.6422952177337565, 0.39805166532506286`, 0.5630541845557195], 
             UndirectedEdge[224, 302] -> 
             RGBColor[
              0.981469271203516, 0.9491536419267372, 0.38251204717050646`], 
             UndirectedEdge[58, 60] -> 
             RGBColor[
              0.3281696676840872, 0.4577472453898289, 0.942165291884663], 
             UndirectedEdge[165, 332] -> 
             RGBColor[
              0.5299851907540822, 0.6293048792717479, 0.9561415220973347], 
             UndirectedEdge[43, 252] -> 
             RGBColor[
              0.2258841865651551, 0.3547489803375645, 0.9361751423079533], 
             UndirectedEdge[292, 304] -> 
             RGBColor[
              0.21505855653612305`, 0.3433705567924642, 0.9355586386928844], 
             UndirectedEdge[63, 257] -> 
             RGBColor[
              0.8905841112547781, 0.5233265159050291, 0.23139995091138454`], 
             UndirectedEdge[94, 355] -> 
             RGBColor[
              0.2455225673247446, 0.37539016366114936`, 0.937293519039831], 
             UndirectedEdge[223, 290] -> 
             RGBColor[
              0.4296004547734099, 0.5464997120753861, 0.9486003596365518], 
             UndirectedEdge[141, 150] -> 
             RGBColor[
              0.3153323622893313, 0.4440199894984804, 0.9414428101102743], 
             UndirectedEdge[131, 306] -> 
             RGBColor[
              0.9464211476308863, 0.8210225463454206, 0.2979449525140816], 
             UndirectedEdge[151, 182] -> 
             RGBColor[
              0.301964914813191, 0.43405917516616493`, 0.9405318273574531], 
             UndirectedEdge[87, 201] -> 
             RGBColor[
              0.2832825017728496, 0.4150782488842294, 0.9394438914458336], 
             UndirectedEdge[72, 379] -> 
             RGBColor[
              0.22434193474233927`, 0.3531279758873717, 0.9360873133482011], 
             UndirectedEdge[23, 378] -> 
             RGBColor[
              0.21097218176330165`, 0.339075517815104, 0.9353259256948219], 
             UndirectedEdge[116, 322] -> 
             RGBColor[
              0.46231873384021377`, 0.5733629399471565, 0.9510928800267155], 
             UndirectedEdge[90, 175] -> 
             RGBColor[
              0.44236897151936794`, 0.5377497638065076, 0.9524065385174674], 
             UndirectedEdge[348, 369] -> 
             RGBColor[
              0.2602045857942335, 0.3908218959663191, 0.9381296382715687], 
             UndirectedEdge[134, 243] -> 
             RGBColor[
              0.2613494095308073, 0.3920251782994754, 0.9381948342897516], 
             UndirectedEdge[211, 372] -> 
             RGBColor[
              0.257077351430105, 0.3875349743715093, 0.9379515469008601], 
             UndirectedEdge[73, 188] -> 
             RGBColor[
              0.2551009475473486, 0.3854576485794885, 0.9378389936235647], 
             UndirectedEdge[55, 228] -> 
             RGBColor[
              0.38569491533937006`, 0.508491282902023, 0.9457971168421706], 
             UndirectedEdge[260, 384] -> 
             RGBColor[
              0.7786909364224193, 0.827038544894287, 0.9785762933282055], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.6353748988917614, 0.714796015346257, 0.9644853457536787], 
             UndirectedEdge[153, 203] -> 
             RGBColor[
              0.3044141682214503, 0.43648600467859244`, 0.9406767090877951], 
             UndirectedEdge[65, 148] -> 
             RGBColor[
              0.5696101053080527, 0.6614741699887192, 0.9592609405218679], 
             UndirectedEdge[42, 366] -> 
             RGBColor[
              0.9167531541973288, 0.7967074998480634, 0.6163680259642358], 
             UndirectedEdge[48, 313] -> 
             RGBColor[
              0.35412562406909687`, 0.4787494368539953, 0.9438733561702934], 
             UndirectedEdge[166, 213] -> 
             RGBColor[
              0.8678686088454421, 0.43805851659629047`, 0.20928664315190354`],
              UndirectedEdge[11, 78] -> 
             RGBColor[
              0.8826533057204708, 0.5284492493821207, 0.22248879223389445`], 
             UndirectedEdge[228, 348] -> 
             RGBColor[
              0.31540619999020275`, 0.44337706024281187`, 0.9414733974605265],
              UndirectedEdge[199, 336] -> 
             RGBColor[
              0.2184046627263886, 0.34688752655381927`, 0.9357491944902996], 
             UndirectedEdge[249, 309] -> 
             RGBColor[
              0.2701798653173872, 0.40130654721440506`, 0.9386977156833087], 
             UndirectedEdge[190, 273] -> 
             RGBColor[
              0.2582701914773965, 0.38878872489163985`, 0.9380194773769047], 
             UndirectedEdge[298, 314] -> 
             RGBColor[
              0.8746210569271528, 0.9028631061103101, 0.9879033312647884], 
             UndirectedEdge[7, 385] -> 
             RGBColor[
              0.4824130197414953, 0.5889482597885108, 0.9528759593947184], 
             UndirectedEdge[27, 194] -> 
             RGBColor[
              0.3427358884343137, 0.47023486345331306`, 0.943098158625497], 
             UndirectedEdge[39, 128] -> 
             RGBColor[
              0.2996526087721707, 0.4306693116276521, 0.9404352763322198], 
             UndirectedEdge[116, 265] -> 
             RGBColor[
              0.5040580192630065, 0.6072487721867599, 0.9543787494712381], 
             UndirectedEdge[231, 313] -> 
             RGBColor[
              0.295746238547153, 0.4281784264805763, 0.9401536828166841], 
             UndirectedEdge[96, 284] -> 
             RGBColor[
              0.2654547891651977, 0.3963401925913225, 0.9384286295865651], 
             UndirectedEdge[279, 300] -> 
             RGBColor[
              0.9178232089422185, 0.7078044246386144, 0.2525247911559355], 
             UndirectedEdge[22, 190] -> 
             RGBColor[
              0.26671069132338054`, 0.3976602253883686, 0.938500151356533], 
             UndirectedEdge[24, 207] -> 
             RGBColor[
              0.9210044213449331, 0.723918476562367, 0.2552656037171254], 
             UndirectedEdge[315, 329] -> 
             RGBColor[
              0.2392065257950246, 0.3687516035532512, 0.9369338298184597], 
             UndirectedEdge[239, 335] -> 
             RGBColor[
              0.3025165492814234, 0.4338365080010965, 0.9405926244808307], 
             UndirectedEdge[142, 300] -> 
             RGBColor[
              0.8557903757137784, 0.38014617017527513`, 0.1991125486638397], 
             UndirectedEdge[13, 88] -> 
             RGBColor[
              0.9770469480723544, 0.9813851840644524, 0.8781922259657269], 
             UndirectedEdge[18, 302] -> 
             RGBColor[
              0.9662417999648014, 0.9637001584466507, 0.6913546401282936], 
             UndirectedEdge[148, 251] -> 
             RGBColor[
              0.723101933884062, 0.7833478892534567, 0.9732241552199159], 
             UndirectedEdge[90, 257] -> 
             RGBColor[
              0.7642064856318851, 0.4724371566214084, 0.5702968707589827], 
             UndirectedEdge[134, 348] -> 
             RGBColor[
              0.24864104476606846`, 0.3786678811748705, 0.9374711117167406], 
             UndirectedEdge[158, 322] -> 
             RGBColor[
              0.5057660137173806, 0.6096426602918618, 0.9542348997632368], 
             UndirectedEdge[40, 385] -> 
             RGBColor[
              0.4573665882056296, 0.5672542996623962, 0.9512800229249427], 
             UndirectedEdge[228, 385] -> 
             RGBColor[
              0.4716391113259436, 0.5796164418313421, 0.9521894554774726], 
             UndirectedEdge[175, 214] -> 
             RGBColor[
              0.5813526175939636, 0.6464089921975442, 0.9229266959429565], 
             UndirectedEdge[7, 41] -> 
             RGBColor[
              0.36511265513899505`, 0.490663963610935, 0.9444856334223808], 
             UndirectedEdge[176, 379] -> 
             RGBColor[
              0.2183904240990045, 0.34687256085365753`, 0.9357483836215341], 
             UndirectedEdge[259, 336] -> 
             RGBColor[
              0.21101362554134806`, 0.339119077853518, 0.9353282858566712], 
             UndirectedEdge[213, 340] -> 
             RGBColor[
              0.9523731210086097, 0.8369128200592044, 0.40569345010895497`], 
             UndirectedEdge[55, 165] -> 
             RGBColor[
              0.4681407137086776, 0.5777449578588358, 0.9516464016172608], 
             UndirectedEdge[108, 231] -> 
             RGBColor[
              0.3381266013166869, 0.4672842792810106, 0.9427663154046388], 
             UndirectedEdge[38, 230] -> 
             RGBColor[
              0.9673242221990019, 0.9014390702190636, 0.3275612028563362], 
             UndirectedEdge[39, 316] -> 
             RGBColor[
              0.26368578568270973`, 0.3944808577699287, 0.9383278874552436], 
             UndirectedEdge[85, 167] -> 
             RGBColor[
              0.2624284668147709, 0.39315933592110447`, 0.9382562850057511], 
             UndirectedEdge[28, 328] -> 
             RGBColor[
              0.2988631492240676, 0.4313905924329009, 0.9403335261361829], 
             UndirectedEdge[79, 120] -> 
             RGBColor[
              0.5785921359057922, 0.6687661870638313, 0.9599680388727843], 
             UndirectedEdge[130, 347] -> 
             RGBColor[
              0.34522783768479254`, 0.47078760076913406`, 0.9433157346482299],
              UndirectedEdge[77, 160] -> 
             RGBColor[
              0.8294213428991457, 0.5471802126352212, 0.5797239248650322], 
             UndirectedEdge[108, 179] -> 
             RGBColor[
              0.3186061180992342, 0.4467670137493473, 0.9416546527633719], 
             UndirectedEdge[318, 373] -> 
             RGBColor[
              0.2370696348066011, 0.3665055956377041, 0.9368121370379159], 
             UndirectedEdge[48, 331] -> 
             RGBColor[
              0.43876768248625253`, 0.5544602462898143, 0.9491788666343646], 
             UndirectedEdge[222, 312] -> 
             RGBColor[
              0.5339420376563727, 0.632517225840949, 0.9564530195798908], 
             UndirectedEdge[292, 353] -> 
             RGBColor[
              0.2106991637542155, 0.3387885585772128, 0.9353103777230984], 
             UndirectedEdge[175, 204] -> 
             RGBColor[
              0.17892957074057536`, 0.30539670201133906`, 0.9335011463998728],
              UndirectedEdge[198, 340] -> 
             RGBColor[
              0.9101338786876096, 0.9267923912389714, 0.7737391772833939], 
             UndirectedEdge[14, 207] -> 
             RGBColor[
              0.9671064480201461, 0.8947970383510977, 0.44882285376347564`], 
             UndirectedEdge[45, 271] -> 
             RGBColor[
              0.30114348847212347`, 0.43385127835713033`, 0.9404610482153953],
              UndirectedEdge[112, 183] -> 
             RGBColor[
              0.2939274002864909, 0.42440137973285763`, 0.9401184016257302], 
             UndirectedEdge[85, 139] -> 
             RGBColor[
              0.2262390695271757, 0.3551219848315275, 0.9361953523676381], 
             UndirectedEdge[45, 97] -> 
             RGBColor[
              0.36889177075057233`, 0.4927124766331557, 0.9447712800460943], 
             UndirectedEdge[130, 181] -> 
             RGBColor[
              0.48885894126290724`, 0.5947515646860737, 0.9532258537292853], 
             UndirectedEdge[63, 90] -> 
             RGBColor[
              0.8321834271804781, 0.8209894828739578, 0.632414864387591], 
             UndirectedEdge[114, 361] -> 
             RGBColor[
              0.342252200873233, 0.470863387125772, 0.9430289854912723], 
             UndirectedEdge[75, 209] -> 
             RGBColor[
              0.24810555583118551`, 0.37810504835234904`, 0.9374406164140838],
              UndirectedEdge[42, 276] -> 
             RGBColor[
              0.8488960037945177, 0.8827904862944987, 0.9853329329150746], 
             UndirectedEdge[205, 358] -> 
             RGBColor[
              0.9819225924478814, 0.9489876509677333, 0.5302516309431803], 
             UndirectedEdge[76, 358] -> 
             RGBColor[
              0.9077605542707283, 0.6337524810989443, 0.26250704350549825`], 
             UndirectedEdge[90, 142] -> 
             RGBColor[
              0.763694887526314, 0.46850478939826945`, 0.5698069638353204], 
             UndirectedEdge[152, 381] -> 
             RGBColor[
              0.588381597564026, 0.6508783727536576, 0.8485015174600479], 
             UndirectedEdge[86, 309] -> 
             RGBColor[
              0.28566340206902835`, 0.417580726053311, 0.9395794801954747], 
             UndirectedEdge[104, 358] -> 
             RGBColor[
              0.9512253799690775, 0.8406018507565884, 0.299039239235954], 
             UndirectedEdge[16, 369] -> 
             RGBColor[
              0.24965722981087085`, 0.3797359560868109, 0.9375289819517311], 
             UndirectedEdge[278, 337] -> 
             RGBColor[
              0.26857947792754067`, 0.39962443859725516`, 0.9386065759890179],
              UndirectedEdge[100, 350] -> 
             RGBColor[
              0.4046784181179114, 0.524933838870203, 0.9470067288527668], 
             UndirectedEdge[90, 202] -> 
             RGBColor[
              0.7810727137045386, 0.6020783764160916, 0.5864479898090358], 
             UndirectedEdge[126, 367] -> 
             RGBColor[
              0.21567822148491766`, 0.34402186394267437`, 0.935593927695006], 
             UndirectedEdge[278, 327] -> 
             RGBColor[
              0.28550387867049365`, 0.4165027145117478, 0.9396037276662406], 
             UndirectedEdge[10, 200] -> 
             RGBColor[
              0.31629276558560215`, 0.4448572861787412, 0.9415038068416022], 
             UndirectedEdge[149, 299] -> 
             RGBColor[
              0.21717366869177715`, 0.345593673773913, 0.9356790912011209], 
             UndirectedEdge[57, 284] -> 
             RGBColor[
              0.2586027566797, 0.38913827200511253`, 0.9380384164731898], 
             UndirectedEdge[125, 313] -> 
             RGBColor[
              0.2803971559769777, 0.4120455675112783, 0.9392795752712453], 
             UndirectedEdge[125, 196] -> 
             RGBColor[
              0.2879550374250095, 0.4199893801105207, 0.9397099854388271], 
             UndirectedEdge[21, 210] -> 
             RGBColor[
              0.30642042589023155`, 0.43901202359644165`, 0.9407756825511414],
              UndirectedEdge[186, 374] -> 
             RGBColor[
              0.2622856992899031, 0.3930092782004845, 0.9382481546064155], 
             UndirectedEdge[6, 74] -> 
             RGBColor[
              0.909010509687477, 0.9256078266033538, 0.7502192883025007], 
             UndirectedEdge[7, 312] -> 
             RGBColor[
              0.42618108450073044`, 0.5432966415402436, 0.9484491754681994], 
             UndirectedEdge[238, 299] -> 
             RGBColor[
              0.22167590498284873`, 0.3503258095740973, 0.9359354868974357], 
             UndirectedEdge[155, 239] -> 
             RGBColor[
              0.3145302695292589, 0.4464636896954298, 0.9412767880762385], 
             UndirectedEdge[108, 331] -> 
             RGBColor[
              0.40983077437371584`, 0.5293965508940257, 0.9473350324373369], 
             UndirectedEdge[55, 87] -> 
             RGBColor[
              0.34683568506465234`, 0.47311300029375225`, 0.9433840322411374],
              UndirectedEdge[186, 288] -> 
             RGBColor[
              0.2467468316416792, 0.3766769430810886, 0.9373632390815438], 
             UndirectedEdge[178, 371] -> 
             RGBColor[
              0.25801702472850174`, 0.38852263058685255`, 0.9380050599050818],
              UndirectedEdge[212, 238] -> 
             RGBColor[
              0.22006014114382055`, 0.3486275393339343, 0.9358434715371114], 
             UndirectedEdge[292, 329] -> 
             RGBColor[
              0.22307875219905648`, 0.35180029094398246`, 0.9360153769710722],
              UndirectedEdge[268, 338] -> 
             RGBColor[
              0.9058036870049794, 0.5621593672391498, 0.39196047146640556`], 
             UndirectedEdge[68, 309] -> 
             RGBColor[
              0.27375753584035556`, 0.40506690577145743`, 0.9389014587269024],
              UndirectedEdge[129, 309] -> 
             RGBColor[
              0.25423745991444247`, 0.38455006832902616`, 0.9377898192802863],
              UndirectedEdge[137, 330] -> 
             RGBColor[
              0.22316402213431713`, 0.35188991505236755`, 0.9360202329677398],
              UndirectedEdge[111, 400] -> 
             RGBColor[
              0.631844529693345, 0.5164916201579837, 0.581343351224306], 
             UndirectedEdge[62, 370] -> 
             RGBColor[
              0.5051424414592518, 0.5868980307983699, 0.9586362110924191], 
             UndirectedEdge[163, 280] -> 
             RGBColor[
              0.24199322930997053`, 0.37168060563466715`, 0.9370925284610774],
              UndirectedEdge[316, 383] -> 
             RGBColor[
              0.2672579164630078, 0.3982353937061947, 0.9385313150186878], 
             UndirectedEdge[307, 314] -> 
             RGBColor[
              0.9555259778682477, 0.9659228619523936, 0.9435306567958934], 
             UndirectedEdge[126, 259] -> 
             RGBColor[
              0.2115312190038542, 0.33966310139993294`, 0.93535776203865], 
             UndirectedEdge[44, 372] -> 
             RGBColor[
              0.27471702429732014`, 0.4060753889748091, 0.9389561001750906], 
             UndirectedEdge[202, 279] -> 
             RGBColor[
              0.9009946329017078, 0.6281412966873632, 0.2383554119012628], 
             UndirectedEdge[148, 312] -> 
             RGBColor[
              0.5434225996528742, 0.6402139731641597, 0.9571993641486982], 
             UndirectedEdge[109, 358] -> 
             RGBColor[
              0.9813365611926588, 0.9487453119833825, 0.5399636854424916], 
             UndirectedEdge[142, 275] -> 
             RGBColor[
              0.906842307128124, 0.5789554407018784, 0.47443924955803846`], 
             UndirectedEdge[296, 375] -> 
             RGBColor[
              0.2781834406546093, 0.40971881234981117`, 0.9391535074585348], 
             UndirectedEdge[92, 195] -> 
             RGBColor[
              0.26667927398787117`, 0.3976272037767742, 0.9384983621857534], 
             UndirectedEdge[178, 248] -> 
             RGBColor[
              0.230098166399185, 0.35917814032488304`, 0.9364151222254768], 
             UndirectedEdge[41, 222] -> 
             RGBColor[
              0.4728736082946373, 0.5798845479116403, 0.9524894775340721], 
             UndirectedEdge[154, 356] -> 
             RGBColor[
              0.4742682171286211, 0.5834424825573183, 0.951929030274608], 
             UndirectedEdge[70, 133] -> 
             RGBColor[
              0.28753417910083867`, 0.4195470313278583, 0.9396860181798696], 
             UndirectedEdge[7, 80] -> 
             RGBColor[
              0.36191069619973304`, 0.48789058771288196`, 0.9442816074301521],
              UndirectedEdge[152, 261] -> 
             RGBColor[
              0.18153226782756765`, 0.3081323016702944, 0.9336493661486316], 
             UndirectedEdge[95, 229] -> 
             RGBColor[
              0.2643373458997902, 0.3951656888693841, 0.9383649928457094], 
             UndirectedEdge[30, 204] -> 
             RGBColor[
              0.17892701604158556`, 0.30539401686072354`, 0.9335010009135446],
              UndirectedEdge[133, 223] -> 
             RGBColor[
              0.3756627076897743, 0.49871942307299955`, 0.945202383630783], 
             UndirectedEdge[298, 306] -> 
             RGBColor[
              0.8969031243202032, 0.8868893383314866, 0.6612189641553454], 
             UndirectedEdge[40, 96] -> 
             RGBColor[
              0.313111809733841, 0.4436046951713676, 0.9412461018545393], 
             UndirectedEdge[122, 146] -> 
             RGBColor[
              0.49070941162852855`, 0.5972227097318854, 0.9531038334374095], 
             UndirectedEdge[223, 267] -> 
             RGBColor[
              0.5126330687833186, 0.6152176449516955, 0.954775499492879], 
             UndirectedEdge[54, 322] -> 
             RGBColor[
              0.48020380618298864`, 0.5888540906805946, 0.9522325010212487], 
             UndirectedEdge[41, 154] -> 
             RGBColor[
              0.3854891726816393, 0.5083130789528232, 0.945784007101951], 
             UndirectedEdge[245, 353] -> 
             RGBColor[
              0.220139248365585, 0.34871068603969635`, 0.9358479765763623], 
             UndirectedEdge[26, 62] -> 
             RGBColor[
              0.31709055637755623`, 0.43703130766003234`, 0.9418781709758536],
              UndirectedEdge[217, 269] -> 
             RGBColor[
              0.9079422992480835, 0.582007875379239, 0.32768831635612294`], 
             UndirectedEdge[172, 347] -> 
             RGBColor[
              0.29073737323035515`, 0.422913791452218, 0.9398684353468445], 
             UndirectedEdge[63, 261] -> 
             RGBColor[
              0.5690047111878296, 0.5889104173173967, 0.6135243178829187], 
             UndirectedEdge[195, 369] -> 
             RGBColor[
              0.2515743275380513, 0.381750947349094, 0.9376381578312021], 
             UndirectedEdge[65, 180] -> 
             RGBColor[
              0.4408011041078431, 0.5545376633487222, 0.9497736818591127], 
             UndirectedEdge[49, 211] -> 
             RGBColor[
              0.25920679804656954`, 0.3897731577801271, 0.9380728157354339], 
             UndirectedEdge[285, 387] -> 
             RGBColor[
              0.2661419288540897, 0.3970624199715206, 0.9384677611753156], 
             UndirectedEdge[329, 388] -> 
             RGBColor[
              0.22925196747727483`, 0.358288731605845, 0.9363669324487132], 
             UndirectedEdge[38, 102] -> 
             RGBColor[
              0.8925441235088332, 0.5227994562196083, 0.24385895757801979`], 
             UndirectedEdge[92, 188] -> 
             RGBColor[
              0.27737488016395806`, 0.40886896400844064`, 0.9391074611347503],
              UndirectedEdge[114, 153] -> 
             RGBColor[
              0.32315432075329853`, 0.4543217632532496, 0.9418120854576224], 
             UndirectedEdge[326, 337] -> 
             RGBColor[
              0.312066783946898, 0.44249908551128714`, 0.9411868535891006], 
             UndirectedEdge[38, 221] -> 
             RGBColor[
              0.9438250637656209, 0.9183985790902189, 0.6570073333224926], 
             UndirectedEdge[350, 394] -> 
             RGBColor[
              0.3958053510234857, 0.5172484341263308, 0.9464413448636552], 
             UndirectedEdge[286, 349] -> 
             RGBColor[
              0.5858145101958898, 0.6731289759492968, 0.9614748008949803], 
             UndirectedEdge[246, 320] -> 
             RGBColor[
              0.5768484382747107, 0.6660576659405324, 0.9606094815615308], 
             UndirectedEdge[322, 362] -> 
             RGBColor[
              0.45653757665465905`, 0.5683555921624378, 0.9507245098029286], 
             UndirectedEdge[80, 348] -> 
             RGBColor[
              0.2986858104115632, 0.42889469918101, 0.9404079890218355], 
             UndirectedEdge[78, 230] -> 
             RGBColor[
              0.9053505911840212, 0.6146233921482407, 0.26060988945584945`], 
             UndirectedEdge[248, 329] -> 
             RGBColor[
              0.22567335718883677`, 0.3545273852956994, 0.9361631358868661], 
             UndirectedEdge[43, 330] -> 
             RGBColor[
              0.2261035990920075, 0.35497959681484403`, 0.9361876375267658], 
             UndirectedEdge[63, 217] -> 
             RGBColor[
              0.8906933611547283, 0.5241662585096577, 0.23150456873895697`], 
             UndirectedEdge[79, 136] -> 
             RGBColor[
              0.6046940354323059, 0.6899568849766287, 0.9620228760179198], 
             UndirectedEdge[159, 243] -> 
             RGBColor[
              0.3099032733211534, 0.44096065205359114`, 0.9410367126469893], 
             UndirectedEdge[1, 327] -> 
             RGBColor[
              0.3392875835527789, 0.4682955846087937, 0.9428400826971212], 
             UndirectedEdge[304, 353] -> 
             RGBColor[
              0.21473904123945592`, 0.3430347259572272, 0.9355404427694197], 
             UndirectedEdge[240, 329] -> 
             RGBColor[
              0.23717266786335917`, 0.3666138899130299, 0.9368180046180745], 
             UndirectedEdge[10, 311] -> 
             RGBColor[
              0.4406499577202704, 0.5542970021663628, 0.9497943740304772], 
             UndirectedEdge[353, 378] -> 
             RGBColor[
              0.20945304207089746`, 0.33747880567936756`, 0.9352394129367053],
              UndirectedEdge[167, 243] -> 
             RGBColor[
              0.28596070978623506`, 0.41789321531449325`, 0.9395964114301423],
              UndirectedEdge[169, 292] -> 
             RGBColor[
              0.21585857380573317`, 0.34421142566684904`, 0.9356041984928691],
              UndirectedEdge[211, 347] -> 
             RGBColor[
              0.27136364126610246`, 0.4025507707922349, 0.9387651299723484], 
             UndirectedEdge[224, 340] -> 
             RGBColor[
              0.9847198182906963, 0.959331532205712, 0.46205791346696695`], 
             UndirectedEdge[144, 233] -> 
             RGBColor[
              0.8479481693127158, 0.33804742930989184`, 0.1923147220140613], 
             UndirectedEdge[273, 394] -> 
             RGBColor[
              0.3171526741702776, 0.4460438307034582, 0.9415424253765902], 
             UndirectedEdge[93, 94] -> 
             RGBColor[
              0.2526810398598759, 0.3829141721689455, 0.9377011834606958], 
             UndirectedEdge[358, 366] -> 
             RGBColor[
              0.934928559139148, 0.7751416322731404, 0.28588252947049914`], 
             UndirectedEdge[245, 329] -> 
             RGBColor[
              0.232518836810426, 0.36172241840646596`, 0.936552975824336], 
             UndirectedEdge[44, 93] -> 
             RGBColor[
              0.2715973273730923, 0.4027963897072362, 0.9387784380504338], 
             UndirectedEdge[218, 314] -> 
             RGBColor[
              0.9179378774680893, 0.9374027630058823, 0.9920349282773651], 
             UndirectedEdge[133, 346] -> 
             RGBColor[
              0.32114511749891506`, 0.4515193689112592, 0.9417229503460453], 
             UndirectedEdge[143, 272] -> 
             RGBColor[
              0.635830587523557, 0.7151635871324875, 0.9645228442451073], 
             UndirectedEdge[272, 346] -> 
             RGBColor[
              0.4960244700071036, 0.5987224642834593, 0.954329185667129], 
             UndirectedEdge[61, 269] -> 
             RGBColor[
              0.9932024163292561, 0.9878689808064407, 0.5015031511422814], 
             UndirectedEdge[158, 362] -> 
             RGBColor[
              0.4538874638081069, 0.5662041111673836, 0.9505158832119648], 
             UndirectedEdge[294, 393] -> 
             RGBColor[
              0.21778977524310467`, 0.34624124082276975`, 0.9357141775577711],
              UndirectedEdge[17, 298] -> 
             RGBColor[
              0.6794733687434446, 0.7479201915203444, 0.969798835244192], 
             UndirectedEdge[83, 179] -> 
             RGBColor[
              0.3112624132414147, 0.4404062657068423, 0.9411867183836149], 
             UndirectedEdge[223, 398] -> 
             RGBColor[
              0.696746297429305, 0.7610076864937902, 0.9687930758283795], 
             UndirectedEdge[52, 272] -> 
             RGBColor[
              0.5168312067307885, 0.6167442138565202, 0.9556549725324873], 
             UndirectedEdge[52, 174] -> 
             RGBColor[
              0.5576254346896334, 0.6486129747855855, 0.95972095993169], 
             UndirectedEdge[63, 317] -> 
             RGBColor[
              0.9745940579826633, 0.9311354530743134, 0.5492576472683819], 
             UndirectedEdge[145, 280] -> 
             RGBColor[
              0.23851863392834902`, 0.36802858558651175`, 0.9368946553942974],
              UndirectedEdge[152, 317] -> 
             RGBColor[
              0.5871216146224013, 0.6503573374272111, 0.8693826955340949], 
             UndirectedEdge[102, 391] -> 
             RGBColor[
              0.8198439128231849, 0.15353458638285297`, 0.16663585937096298`],
              UndirectedEdge[168, 251] -> 
             RGBColor[
              0.7462331666341901, 0.8017011358685895, 0.9753362046447762], 
             UndirectedEdge[89, 245] -> 
             RGBColor[
              0.22424083690782642`, 0.3530217156533258, 0.9360815559760864], 
             UndirectedEdge[293, 330] -> 
             RGBColor[
              0.21800150715905772`, 0.3464637844910152, 0.9357262353771553], 
             UndirectedEdge[166, 247] -> 
             RGBColor[
              0.8658883217742317, 0.43020733825048896`, 0.20769325769109587`],
              UndirectedEdge[8, 182] -> 
             RGBColor[
              0.29920713316336395`, 0.4316705233112208, 0.9403561039493367], 
             UndirectedEdge[2, 215] -> 
             RGBColor[
              0.8188696957350476, 0.14604632693877936`, 0.16570294798714186`],
              UndirectedEdge[61, 107] -> 
             RGBColor[
              0.9162817916828967, 0.6453128669663495, 0.3511545314597267], 
             UndirectedEdge[192, 361] -> 
             RGBColor[
              0.35005813253929685`, 0.4776244927973833, 0.9435263725545195], 
             UndirectedEdge[71, 321] -> 
             RGBColor[
              0.8444532383444727, 0.878825868324395, 0.985021184343525], 
             UndirectedEdge[26, 389] -> 
             RGBColor[
              0.31710049015279534`, 0.4370417486876464, 0.9418787366896577], 
             UndirectedEdge[134, 263] -> 
             RGBColor[
              0.24820523859568883`, 0.3782098212580943, 0.9374462932000549], 
             UndirectedEdge[105, 282] -> 
             RGBColor[
              0.5321029414738284, 0.6299784125013272, 0.956625284939209], 
             UndirectedEdge[323, 340] -> 
             RGBColor[
              0.9119941865056833, 0.9282757501963927, 0.7739166151037982], 
             UndirectedEdge[311, 323] -> 
             RGBColor[
              0.6747921418079339, 0.7440706990607763, 0.9694867808520644], 
             UndirectedEdge[29, 365] -> 
             RGBColor[
              0.24833496351636752`, 0.37834617037476265`, 0.9374536808423768],
              UndirectedEdge[321, 384] -> 
             RGBColor[
              0.7831071512596195, 0.8304885254895837, 0.9790164603513036], 
             UndirectedEdge[115, 195] -> 
             RGBColor[
              0.2421504028292495, 0.3718458049688061, 0.937101479260483], 
             UndirectedEdge[162, 359] -> 
             RGBColor[
              0.24582605828944576`, 0.3757091519074889, 0.9373108024012962], 
             UndirectedEdge[106, 295] -> 
             RGBColor[
              0.5954410834145789, 0.6666014753537031, 0.9545919964182874], 
             UndirectedEdge[24, 242] -> 
             RGBColor[
              0.9102499321760205, 0.681280510728698, 0.24661228929151274`], 
             UndirectedEdge[109, 286] -> 
             RGBColor[
              0.8601731647723879, 0.8889489686867593, 0.8604250468482817], 
             UndirectedEdge[287, 367] -> 
             RGBColor[
              0.23976404440825078`, 0.3693375909644736, 0.936965579678708], 
             UndirectedEdge[74, 140] -> 
             RGBColor[
              0.7482992359076605, 0.8033342207586809, 0.9755370742792053], 
             UndirectedEdge[168, 394] -> 
             RGBColor[
              0.5145092206731405, 0.613750519132451, 0.9559228612077943], 
             UndirectedEdge[68, 249] -> 
             RGBColor[
              0.2731469520224531, 0.4044251434655919, 0.9388666868817508], 
             UndirectedEdge[389, 400] -> 
             RGBColor[
              0.2843495171102985, 0.40872323643536973`, 0.9397784081644269], 
             UndirectedEdge[267, 346] -> 
             RGBColor[
              0.4581154785924594, 0.5680175907899552, 0.9512960662081413], 
             UndirectedEdge[16, 392] -> 
             RGBColor[
              0.24490486142793333`, 0.37474091559878486`, 0.9372583416028217],
              UndirectedEdge[13, 191] -> 
             RGBColor[
              0.8213167457883995, 0.8607762667176537, 0.9574101949991654], 
             UndirectedEdge[312, 327] -> 
             RGBColor[
              0.39077465425622554`, 0.5126293712413812, 0.9461931090416965], 
             UndirectedEdge[260, 291] -> 
             RGBColor[
              0.7527228069990448, 0.8067520448236535, 0.9759880328732503], 
             UndirectedEdge[83, 344] -> 
             RGBColor[
              0.33675515918736176`, 0.4661021259068189, 0.9426787188558917], 
             UndirectedEdge[200, 288] -> 
             RGBColor[
              0.25784282293400623`, 0.38833953345580596`, 0.9379951393705938],
              UndirectedEdge[297, 332] -> 
             RGBColor[
              0.736930313911651, 0.7933926635631983, 0.9655671808709663], 
             UndirectedEdge[189, 241] -> 
             RGBColor[
              0.2957543458619668, 0.428186947782479, 0.9401541445162689], 
             UndirectedEdge[276, 358] -> 
             RGBColor[
              0.8670714087363368, 0.8612246187195758, 0.654847436421338], 
             UndirectedEdge[11, 102] -> 
             RGBColor[
              0.8713798486298555, 0.4417965181232547, 0.21169331699237254`], 
             UndirectedEdge[96, 243] -> 
             RGBColor[
              0.2876417202462759, 0.4196600638902152, 0.9396921424890095], 
             UndirectedEdge[171, 397] -> 
             RGBColor[
              0.26128106780929927`, 0.39195334681705507`, 0.9381909423298143],
              UndirectedEdge[314, 385] -> 
             RGBColor[
              0.7506165131369036, 0.8049365561291917, 0.9762521831517132], 
             UndirectedEdge[11, 213] -> 
             RGBColor[
              0.9172153878071567, 0.709493629531714, 0.2522477617062842], 
             UndirectedEdge[68, 129] -> 
             RGBColor[
              0.25720454661950837`, 0.38766866458021304`, 0.9379587904787283],
              UndirectedEdge[137, 277] -> 
             RGBColor[
              0.23968446191505444`, 0.36925394471830275`, 0.9369610475734522],
              UndirectedEdge[35, 327] -> 
             RGBColor[
              0.29981659218631795`, 0.43154628389532945`, 0.9404188155272046],
              UndirectedEdge[155, 183] -> 
             RGBColor[
              0.2817396246657633, 0.4134565872206231, 0.9393560268770672], 
             UndirectedEdge[63, 256] -> 
             RGBColor[
              0.5919347091448884, 0.6130112990161062, 0.6148301473446811], 
             UndirectedEdge[144, 358] -> 
             RGBColor[
              0.9235073892649484, 0.7232807673563957, 0.2763524253689754], 
             UndirectedEdge[192, 332] -> 
             RGBColor[
              0.43585567576042195`, 0.5499313562155932, 0.9495477612304457], 
             UndirectedEdge[149, 259] -> 
             RGBColor[
              0.21561966255991427`, 0.3439603147996455, 0.9355905928508573], 
             UndirectedEdge[146, 165] -> 
             RGBColor[
              0.5340400056803238, 0.6325967606962016, 0.956460731981605], 
             UndirectedEdge[164, 280] -> 
             RGBColor[
              0.2407758584059484, 0.37040107162876656`, 0.9370232009890322], 
             UndirectedEdge[65, 105] -> 
             RGBColor[
              0.46633814789011974`, 0.5766565671437895, 0.9514008797073982], 
             UndirectedEdge[73, 369] -> 
             RGBColor[
              0.2502849628040927, 0.38039574326325765`, 0.9375647304170474], 
             UndirectedEdge[187, 281] -> 
             RGBColor[
              0.7379639441479849, 0.795257108792612, 0.9745741950769791], 
             UndirectedEdge[53, 253] -> 
             RGBColor[
              0.31547986955209806`, 0.4458714425532633, 0.9413890964198188], 
             UndirectedEdge[132, 191] -> 
             RGBColor[
              0.7390378619070974, 0.7960612617083893, 0.9746240454395679], 
             UndirectedEdge[29, 273] -> 
             RGBColor[
              0.25793330326133057`, 0.388434634016608, 0.9380002920913812], 
             UndirectedEdge[138, 366] -> 
             RGBColor[
              0.8603116610551809, 0.39715139303420033`, 0.20274719460083632`],
              UndirectedEdge[229, 309] -> 
             RGBColor[
              0.25884330525935606`, 0.3893911038139919, 0.9380521153589414], 
             UndirectedEdge[274, 287] -> 
             RGBColor[
              0.2454706833388167, 0.37533563030230443`, 0.937290564323588], 
             UndirectedEdge[251, 312] -> 
             RGBColor[
              0.6426365090387243, 0.7180224324379316, 0.9668896222215277], 
             UndirectedEdge[339, 360] -> 
             RGBColor[
              0.3380761124684098, 0.46724626924582036`, 0.942762888830887], 
             UndirectedEdge[150, 365] -> 
             RGBColor[
              0.26342074735738313`, 0.39420228568561005`, 0.9383127939147053],
              UndirectedEdge[61, 300] -> 
             RGBColor[
              0.9416713408004723, 0.7907793854302443, 0.3735219082012329], 
             UndirectedEdge[62, 389] -> 
             RGBColor[
              0.17907819285502502`, 0.305552913276812, 0.9335096102094239], 
             UndirectedEdge[374, 399] -> 
             RGBColor[
              0.255491371590293, 0.38586800900293716`, 0.9378612276952298], 
             UndirectedEdge[27, 51] -> 
             RGBColor[
              0.33517005330446453`, 0.4636817173337682, 0.9426160703012283], 
             UndirectedEdge[58, 159] -> 
             RGBColor[
              0.31512279365295653`, 0.44644669885901933`, 0.9413339566082971],
              UndirectedEdge[57, 153] -> 
             RGBColor[
              0.2953190920495516, 0.42692650296079127`, 0.9401587579547649], 
             UndirectedEdge[84, 264] -> 
             RGBColor[
              0.18447901438019912`, 0.31122951913163255`, 0.9338171790054831],
              UndirectedEdge[159, 201] -> 
             RGBColor[
              0.30393044061377905`, 0.43468282617867443`, 0.9406965686603185],
              UndirectedEdge[80, 87] -> 
             RGBColor[
              0.3122775575094636, 0.4431804871474425, 0.9411820189118731], 
             UndirectedEdge[39, 288] -> 
             RGBColor[
              0.2590590279232666, 0.38961784201136873`, 0.9380644004455181], 
             UndirectedEdge[91, 365] -> 
             RGBColor[
              0.259430965008946, 0.3900087714705911, 0.9380855817123159], 
             UndirectedEdge[5, 384] -> 
             RGBColor[
              0.7949354326614759, 0.8399023141409853, 0.9801493658443617], 
             UndirectedEdge[156, 381] -> 
             RGBColor[
              0.5895532840978516, 0.6521098895899253, 0.8485682432747944], 
             UndirectedEdge[2, 197] -> 
             RGBColor[
              0.9036013141673853, 0.5662229928500411, 0.5006917858198119], 
             UndirectedEdge[238, 293] -> 
             RGBColor[
              0.22022708573500543`, 0.3488030086841681, 0.935852978784607], 
             UndirectedEdge[85, 325] -> 
             RGBColor[
              0.22643759197523877`, 0.355330644511492, 0.9362066579273677], 
             UndirectedEdge[146, 332] -> 
             RGBColor[
              0.53127642233297, 0.6303531592368088, 0.9562431725771618], 
             UndirectedEdge[197, 204] -> 
             RGBColor[
              0.5838392169462935, 0.6475052215433456, 0.8847911904815791], 
             UndirectedEdge[20, 130] -> 
             RGBColor[
              0.4090322853711047, 0.5287049398531881, 0.9472841534241666], 
             UndirectedEdge[167, 348] -> 
             RGBColor[
              0.2732523450214962, 0.4045359181898883, 0.9388726888571313], 
             UndirectedEdge[83, 237] -> 
             RGBColor[
              0.4656503502316991, 0.5743478756221865, 0.9518303486289299], 
             UndirectedEdge[178, 334] -> 
             RGBColor[
              0.25269374017822266`, 0.3829275210087747, 0.9377019067250372], 
             UndirectedEdge[178, 388] -> 
             RGBColor[
              0.23367677668762307`, 0.36293948663502873`, 0.9366189187873238],
              UndirectedEdge[115, 184] -> 
             RGBColor[
              0.22818450918176583`, 0.35716676525650004`, 0.936306142277947], 
             UndirectedEdge[165, 385] -> 
             RGBColor[
              0.5540849096952511, 0.648870116788155, 0.9580387402525627], 
             UndirectedEdge[202, 257] -> 
             RGBColor[
              0.8394733977788387, 0.30441540944716294`, 0.18543307633282935`],
              UndirectedEdge[35, 57] -> 
             RGBColor[
              0.2771242370211076, 0.4086055221736117, 0.9390931873785582], 
             UndirectedEdge[115, 206] -> 
             RGBColor[
              0.23508408472910247`, 0.364418656615107, 0.9366990628983605], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.34476855469957235`, 0.4730429263345264, 0.9431893253319623], 
             UndirectedEdge[61, 98] -> 
             RGBColor[
              0.985458002900472, 0.9620883573989745, 0.44224268706809605`], 
             UndirectedEdge[33, 173] -> 
             RGBColor[
              0.20265449886636056`, 0.33033310571886365`, 0.9348522459587503],
              UndirectedEdge[6, 185] -> 
             RGBColor[
              0.9085190133388343, 0.5856402039031354, 0.34380931507742224`], 
             UndirectedEdge[300, 363] -> 
             RGBColor[
              0.8762546358068509, 0.5309830273105506, 0.21845617365184725`], 
             UndirectedEdge[34, 270] -> 
             RGBColor[
              0.28093807902462586`, 0.41228653639826196`, 0.9393223741835017],
              UndirectedEdge[162, 179] -> 
             RGBColor[
              0.25786357675267113`, 0.38836134703509095`, 0.9379963212698641],
              UndirectedEdge[11, 250] -> 
             RGBColor[
              0.9558449394073578, 0.8618308276345842, 0.5510217386219683], 
             UndirectedEdge[66, 314] -> 
             RGBColor[
              0.9492974340005453, 0.9317668939083206, 0.6707765260947278], 
             UndirectedEdge[153, 327] -> 
             RGBColor[
              0.31801144721476193`, 0.44986726468250904`, 0.9414843861034113],
              UndirectedEdge[153, 392] -> 
             RGBColor[
              0.28268998646480836`, 0.4136525122596839, 0.9394395490748012], 
             UndirectedEdge[110, 369] -> 
             RGBColor[
              0.2565159464057226, 0.38694490209574905`, 0.9379195757152459], 
             UndirectedEdge[321, 398] -> 
             RGBColor[
              0.8786059330927678, 0.9059622064053712, 0.9849470713031456], 
             UndirectedEdge[188, 278] -> 
             RGBColor[
              0.2597507710467335, 0.39034490789317966`, 0.9381037941930572], 
             UndirectedEdge[213, 289] -> 
             RGBColor[
              0.9043607109741805, 0.6566643735845665, 0.24180812561664938`], 
             UndirectedEdge[236, 263] -> 
             RGBColor[
              0.2563029052327246, 0.3867209823153376, 0.9379074433356098], 
             UndirectedEdge[93, 383] -> 
             RGBColor[
              0.2627372188358315, 0.39348385387124796`, 0.9382738679765928], 
             UndirectedEdge[56, 286] -> 
             RGBColor[
              0.5885924555434128, 0.6755350925857282, 0.9616518091160838], 
             UndirectedEdge[25, 144] -> 
             RGBColor[
              0.8635746104404736, 0.45815910336800225`, 0.20727861968554306`],
              UndirectedEdge[143, 331] -> 
             RGBColor[
              0.5383683584932644, 0.6360774364876114, 0.9568106700316372], 
             UndirectedEdge[76, 257] -> 
             RGBColor[
              0.8347758028344946, 0.2683076362057045, 0.1809346541089509], 
             UndirectedEdge[91, 189] -> 
             RGBColor[
              0.28158397795101814`, 0.4132929926548542, 0.9393471630269211], 
             UndirectedEdge[133, 145] -> 
             RGBColor[
              0.26764114093786784`, 0.3986381869271076, 0.9385531390856012], 
             UndirectedEdge[207, 230] -> 
             RGBColor[
              0.9543565255231943, 0.8529328333505086, 0.30199072149137773`], 
             UndirectedEdge[238, 336] -> 
             RGBColor[
              0.22011483416770328`, 0.34868502516977307`, 0.9358465862239105],
              UndirectedEdge[123, 306] -> 
             RGBColor[
              0.9723361250736168, 0.9460422517382365, 0.6339056761634236], 
             UndirectedEdge[272, 338] -> 
             RGBColor[
              0.8206526510459409, 0.8571827716487312, 0.7925776008366022], 
             UndirectedEdge[11, 289] -> 
             RGBColor[
              0.9106079850234978, 0.6814327334094423, 0.24683482895909917`], 
             UndirectedEdge[215, 300] -> 
             RGBColor[
              0.8546424874802127, 0.37132299820425807`, 0.1980133295950229], 
             UndirectedEdge[224, 289] -> 
             RGBColor[
              0.9367074082562672, 0.779083085731074, 0.29817258897466137`], 
             UndirectedEdge[65, 161] -> 
             RGBColor[
              0.4733844161827434, 0.5827596905831183, 0.9518498616922337], 
             UndirectedEdge[14, 247] -> 
             RGBColor[
              0.9506823086964485, 0.8296807989526216, 0.43560760573952945`], 
             UndirectedEdge[150, 226] -> 
             RGBColor[
              0.2546174021107136, 0.38494941166703367`, 0.9378114564262897], 
             UndirectedEdge[15, 180] -> 
             RGBColor[
              0.33506546922916314`, 0.4641869420312098, 0.9425875907675709], 
             UndirectedEdge[7, 114] -> 
             RGBColor[
              0.359141437487956, 0.48549199500373064`, 0.9441051527137969], 
             UndirectedEdge[108, 313] -> 
             RGBColor[
              0.3251887159565602, 0.4536857414582067, 0.9420295219732657], 
             UndirectedEdge[227, 315] -> 
             RGBColor[
              0.2390981188616284, 0.3686376609928552, 0.9369276562039764], 
             UndirectedEdge[174, 384] -> 
             RGBColor[
              0.7385166114389616, 0.7956540568810313, 0.9745720920642666], 
             UndirectedEdge[104, 138] -> 
             RGBColor[
              0.8766084818851104, 0.4626116115176483, 0.21590390436629117`], 
             UndirectedEdge[313, 344] -> 
             RGBColor[
              0.30171850127564737`, 0.43335702114888963`, 0.940534020647694], 
             UndirectedEdge[255, 374] -> 
             RGBColor[
              0.2682893522658295, 0.3993194981317673, 0.938590053761786], 
             UndirectedEdge[87, 167] -> 
             RGBColor[
              0.28684409211939654`, 0.41882170615632086`, 0.9396467187471687],
              UndirectedEdge[114, 312] -> 
             RGBColor[
              0.3959175277947622, 0.5170838698121216, 0.9465208083959076], 
             UndirectedEdge[50, 265] -> 
             RGBColor[
              0.5230211648142513, 0.6236511692879999, 0.9555932884652836], 
             UndirectedEdge[310, 345] -> 
             RGBColor[
              0.19226277251810686`, 0.3194107424533439, 0.9342604525163987], 
             UndirectedEdge[315, 334] -> 
             RGBColor[
              0.25233663141566864`, 0.38255217705732714`, 0.9376815699093048],
              UndirectedEdge[102, 302] -> 
             RGBColor[
              0.9032870347441282, 0.5590378183717704, 0.2855931390985828], 
             UndirectedEdge[172, 211] -> 
             RGBColor[
              0.2820509294380053, 0.413783788274112, 0.9393737552233123], 
             UndirectedEdge[264, 381] -> 
             RGBColor[
              0.5915890217554157, 0.6542495789412477, 0.8486841755227887], 
             UndirectedEdge[270, 397] -> 
             RGBColor[
              0.2494683482405557, 0.3795374295806264, 0.9375182254257268], 
             UndirectedEdge[48, 290] -> 
             RGBColor[
              0.4152883060919923, 0.5341235905648768, 0.9476827815325197], 
             UndirectedEdge[224, 323] -> 
             RGBColor[
              0.9029358765369997, 0.8985069119905342, 0.6718086867166897], 
             UndirectedEdge[10, 339] -> 
             RGBColor[
              0.3638431893323356, 0.48956441613441326`, 0.9444047441837249], 
             UndirectedEdge[254, 320] -> 
             RGBColor[
              0.5897027051719504, 0.6767516973442059, 0.9615500313265857], 
             UndirectedEdge[92, 392] -> 
             RGBColor[
              0.26780652703776464`, 0.39881201820418366`, 0.9385625575793235],
              UndirectedEdge[166, 224] -> 
             RGBColor[
              0.9002153061275288, 0.5604772287427979, 0.2656511065099155], 
             UndirectedEdge[108, 344] -> 
             RGBColor[
              0.3440988640451813, 0.47246287394932385`, 0.9431466532356487], 
             UndirectedEdge[180, 271] -> 
             RGBColor[
              0.3365289525569892, 0.46572515579895724`, 0.942670933978061], 
             UndirectedEdge[104, 207] -> 
             RGBColor[
              0.9368649528111581, 0.7873976069432023, 0.2680582629430743], 
             UndirectedEdge[45, 266] -> 
             RGBColor[
              0.2752485126978604, 0.4066340169820878, 0.9389863676532347], 
             UndirectedEdge[59, 373] -> 
             RGBColor[
              0.2921699969184407, 0.4220829828981863, 0.9400355750383738], 
             UndirectedEdge[107, 352] -> 
             RGBColor[
              0.9166859076311894, 0.6461772301173578, 0.39514005851685197`], 
             UndirectedEdge[99, 338] -> 
             RGBColor[
              0.9862079875593082, 0.9866999578573392, 0.7708056942036536], 
             UndirectedEdge[186, 341] -> 
             RGBColor[
              0.23502569235584353`, 0.3643572825285215, 0.9366957375390872], 
             UndirectedEdge[90, 156] -> 
             RGBColor[
              0.4458826703540418, 0.5414428840631231, 0.9526066384680504], 
             UndirectedEdge[34, 151] -> 
             RGBColor[
              0.31406226415390115`, 0.44644668080690353`, 0.9412327476508988],
              UndirectedEdge[174, 260] -> 
             RGBColor[
              0.7687797089830702, 0.819295818690549, 0.9775884348027377], 
             UndirectedEdge[13, 216] -> 
             RGBColor[
              0.8114408517281416, 0.8530611432182054, 0.956425858174716], 
             UndirectedEdge[9, 217] -> 
             RGBColor[
              0.8242465537218799, 0.18737521357976708`, 0.17085183326762515`],
              UndirectedEdge[87, 159] -> 
             RGBColor[
              0.3107866556543149, 0.4418891428954188, 0.9410870199640158], 
             UndirectedEdge[184, 305] -> 
             RGBColor[
              0.21033276310750965`, 0.33840344826638225`, 0.9352895117483098],
              UndirectedEdge[12, 259] -> 
             RGBColor[
              0.2147288372822968, 0.3430240009512847, 0.9355398616691548], 
             UndirectedEdge[27, 287] -> 
             RGBColor[
              0.27881505582512084`, 0.4103826799407336, 0.9391894770081045], 
             UndirectedEdge[188, 284] -> 
             RGBColor[
              0.25554200422115014`, 0.38592122710826227`, 0.9378641111486529],
              UndirectedEdge[118, 126] -> 
             RGBColor[
              0.20905168496127685`, 0.33705695390964574`, 0.935216556243067], 
             UndirectedEdge[209, 304] -> 
             RGBColor[
              0.23556571159456763`, 0.3649248769876179, 0.9367264908358456], 
             UndirectedEdge[48, 108] -> 
             RGBColor[
              0.3965059868386308, 0.5178552896544295, 0.9464859887582483], 
             UndirectedEdge[136, 376] -> 
             RGBColor[
              0.5284877060748537, 0.6276839131134415, 0.9561356038127271], 
             UndirectedEdge[48, 344] -> 
             RGBColor[
              0.373035772157718, 0.49752656934511247`, 0.9449904874326764], 
             UndirectedEdge[13, 198] -> 
             RGBColor[
              0.8951348791523555, 0.9184961361184019, 0.9647537428637106], 
             UndirectedEdge[286, 320] -> 
             RGBColor[
              0.7180719499645429, 0.7796825319520332, 0.9725343592747207], 
             UndirectedEdge[176, 368] -> 
             RGBColor[
              0.2143024966118115, 0.34257588987504495`, 0.9355155821986852], 
             UndirectedEdge[248, 388] -> 
             RGBColor[
              0.21978649931888122`, 0.34833992442602935`, 0.935827888039998], 
             UndirectedEdge[57, 188] -> 
             RGBColor[
              0.270146670915944, 0.40127165779384166`, 0.9386958253112532], 
             UndirectedEdge[39, 225] -> 
             RGBColor[
              0.26510008482719366`, 0.3959673758425263, 0.9384084296992539], 
             UndirectedEdge[355, 379] -> 
             RGBColor[
              0.2259392634266556, 0.3548068696110762, 0.9361782788537368], 
             UndirectedEdge[85, 348] -> 
             RGBColor[
              0.2521313444108594, 0.3823364073993248, 0.9376698791180758], 
             UndirectedEdge[118, 336] -> 
             RGBColor[
              0.20853409149877072`, 0.3365129303632308, 0.9351870800610882], 
             UndirectedEdge[195, 392] -> 
             RGBColor[
              0.24682195915511385`, 0.3767559068610679, 0.9373675174822926], 
             UndirectedEdge[193, 281] -> 
             RGBColor[
              0.7271668299156635, 0.7866477829836171, 0.9735443566828026], 
             UndirectedEdge[154, 312] -> 
             RGBColor[
              0.4465576020433747, 0.5609457568821319, 0.9497475491477698], 
             UndirectedEdge[53, 171] -> 
             RGBColor[
              0.28122827358250124`, 0.41291912481058346`, 0.9393269061893516],
              UndirectedEdge[115, 188] -> 
             RGBColor[
              0.25284600900533644`, 0.38308756520047255`, 0.9377105782094798],
              UndirectedEdge[319, 329] -> 
             RGBColor[
              0.2383612491721791, 0.3678631642290072, 0.9368856925652633], 
             UndirectedEdge[231, 359] -> 
             RGBColor[
              0.2771261222266016, 0.4086075036441148, 0.9390932947382222], 
             UndirectedEdge[288, 399] -> 
             RGBColor[
              0.23995250394206913`, 0.3695356738835413, 0.9369763121703581], 
             UndirectedEdge[140, 220] -> 
             RGBColor[
              0.5736797551483913, 0.6643251817234797, 0.9598909775899255], 
             UndirectedEdge[9, 215] -> 
             RGBColor[
              0.822477817482793, 0.1737799317809825, 0.1691580894475736], 
             UndirectedEdge[309, 329] -> 
             RGBColor[
              0.25296463724126, 0.3832122509978928, 0.9377173339120208], 
             UndirectedEdge[9, 61] -> 
             RGBColor[
              0.9095066708030527, 0.5932363190069687, 0.34466666805378354`], 
             UndirectedEdge[21, 82] -> 
             RGBColor[
              0.34606714839588365`, 0.4741677029250543, 0.94327207057399], 
             UndirectedEdge[154, 361] -> 
             RGBColor[
              0.39289227512184555`, 0.5147252741957822, 0.9462557262431346], 
             UndirectedEdge[160, 213] -> 
             RGBColor[
              0.8702228477750129, 0.45615422864304855`, 0.21154106500959308`],
              UndirectedEdge[331, 342] -> 
             RGBColor[
              0.5277253347918338, 0.6274369503840362, 0.9559728122191802], 
             UndirectedEdge[122, 159] -> 
             RGBColor[
              0.3887610902465449, 0.5111470494961861, 0.9459924907959437], 
             UndirectedEdge[258, 278] -> 
             RGBColor[
              0.25267444257649463`, 0.38290723800581994`, 0.937700807755167], 
             UndirectedEdge[37, 201] -> 
             RGBColor[
              0.26311290635419504`, 0.3938787252730125, 0.9382952628249838], 
             UndirectedEdge[61, 314] -> 
             RGBColor[
              0.9595789423265859, 0.965928622564677, 0.7549534149051582], 
             UndirectedEdge[297, 314] -> 
             RGBColor[
              0.9362255007006572, 0.9517027043636277, 0.9839981831745597], 
             UndirectedEdge[84, 175] -> 
             RGBColor[
              0.1789295778879611, 0.3053967095236947, 0.9335011468069058], 
             UndirectedEdge[72, 374] -> 
             RGBColor[
              0.25191511783451104`, 0.3821091395580259, 0.9376575653344313], 
             UndirectedEdge[168, 180] -> 
             RGBColor[
              0.5182102560481305, 0.6169561699548207, 0.9561586879091916], 
             UndirectedEdge[36, 60] -> 
             RGBColor[
              0.4386028192989782, 0.5525156396146701, 0.9496662072988238], 
             UndirectedEdge[347, 387] -> 
             RGBColor[
              0.2868094179961087, 0.41878526145427897`, 0.9396447441071433], 
             UndirectedEdge[140, 141] -> 
             RGBColor[
              0.5159944713875729, 0.6149616035084853, 0.9560493981699523], 
             UndirectedEdge[233, 382] -> 
             RGBColor[
              0.8581195774771997, 0.3842334181920808, 0.20080199431053547`], 
             UndirectedEdge[21, 122] -> 
             RGBColor[
              0.37950236392749337`, 0.5031276061157393, 0.9454025329420639], 
             UndirectedEdge[202, 268] -> 
             RGBColor[
              0.836829312925746, 0.2840918146209231, 0.18290109769144122`], 
             UndirectedEdge[196, 344] -> 
             RGBColor[
              0.3092763827236792, 0.441300833748132, 0.9409644308152758], 
             UndirectedEdge[109, 343] -> 
             RGBColor[
              0.8581485111146978, 0.8873672938614341, 0.8602232482931473], 
             UndirectedEdge[52, 117] -> 
             RGBColor[
              0.36808130040816744`, 0.4932352549346425, 0.9446747928738624], 
             UndirectedEdge[51, 194] -> 
             RGBColor[
              0.38048922371828053`, 0.5039823744655038, 0.945465414775287], 
             UndirectedEdge[223, 342] -> 
             RGBColor[
              0.5287126959381665, 0.6282718106549494, 0.9560413466441238], 
             UndirectedEdge[241, 374] -> 
             RGBColor[
              0.2835328374534444, 0.4153413675567334, 0.939458147692505], 
             UndirectedEdge[76, 109] -> 
             RGBColor[
              0.9205204428847344, 0.6768339136433675, 0.4700439928721189], 
             UndirectedEdge[90, 381] -> 
             RGBColor[
              0.849476415301395, 0.8807671291171392, 0.8672733890419332], 
             UndirectedEdge[75, 227] -> 
             RGBColor[
              0.2395500669875186, 0.36911268712833206`, 0.9369533939811485], 
             UndirectedEdge[209, 329] -> 
             RGBColor[
              0.24358590725750107`, 0.37335461113913604`, 0.9371832291140334],
              UndirectedEdge[24, 358] -> 
             RGBColor[
              0.9353648485028525, 0.777122720375753, 0.28624658001000514`], 
             UndirectedEdge[208, 369] -> 
             RGBColor[
              0.24527033350139205`, 0.37512504992025775`, 0.9372791546967377],
              UndirectedEdge[62, 400] -> 
             RGBColor[
              0.2843395833350594, 0.4087127954077557, 0.9397778424506229], 
             UndirectedEdge[127, 325] -> 
             RGBColor[
              0.21103171786447747`, 0.3391380940322466, 0.9353293161877081], 
             UndirectedEdge[43, 277] -> 
             RGBColor[
              0.2426240388727448, 0.37234362648077923`, 0.9371284521324783], 
             UndirectedEdge[70, 227] -> 
             RGBColor[
              0.25636607330828476`, 0.3867873759678386, 0.9379110406640643], 
             UndirectedEdge[25, 366] -> 
             RGBColor[
              0.8749957803146731, 0.510019968284747, 0.21680872378706678`], 
             UndirectedEdge[20, 387] -> 
             RGBColor[
              0.3506138656824209, 0.476702600538333, 0.94361316288308], 
             UndirectedEdge[328, 387] -> 
             RGBColor[
              0.30150296805800375`, 0.4341652094015489, 0.9404838599135137], 
             UndirectedEdge[249, 386] -> 
             RGBColor[
              0.3044662110801129, 0.4345129066433197, 0.9407539204836926], 
             UndirectedEdge[110, 243] -> 
             RGBColor[
              0.2719749479938126, 0.4031932929221435, 0.9387999429861442], 
             UndirectedEdge[47, 121] -> 
             RGBColor[
              0.4935440296663224, 0.5991928393789325, 0.9534184801906773], 
             UndirectedEdge[31, 156] -> 
             RGBColor[
              0.18458847622123073`, 0.3113445704668384, 0.9338234126953957], 
             UndirectedEdge[98, 283] -> 
             RGBColor[
              0.9432427006605664, 0.8062936865407971, 0.3064669136008217], 
             UndirectedEdge[38, 358] -> 
             RGBColor[
              0.9671839420965409, 0.9009658724941282, 0.3270162411479497], 
             UndirectedEdge[126, 199] -> 
             RGBColor[
              0.21892225618889471`, 0.3474315501002342, 0.9357786706722784], 
             UndirectedEdge[39, 200] -> 
             RGBColor[
              0.27187585958380484`, 0.4030891447206572, 0.9387943000477824], 
             UndirectedEdge[227, 304] -> 
             RGBColor[
              0.22701022275090071`, 0.35593251576360085`, 0.9362392684029103],
              UndirectedEdge[242, 333] -> 
             RGBColor[
              0.5569536477379948, 0.5184281382754727, 0.5938032026627618], 
             UndirectedEdge[30, 333] -> 
             RGBColor[
              0.1872437438170861, 0.31413542506377157`, 0.9339746262568631], 
             UndirectedEdge[85, 96] -> 
             RGBColor[
              0.2641094772748117, 0.3949261844968264, 0.9383520160646184], 
             UndirectedEdge[39, 94] -> 
             RGBColor[
              0.2666080163774077, 0.39755230751018356`, 0.9384943041702538], 
             UndirectedEdge[63, 138] -> 
             RGBColor[
              0.8889519646070447, 0.5107811215593289, 0.22983700543826907`], 
             UndirectedEdge[119, 324] -> 
             RGBColor[
              0.26022801088632164`, 0.3908465172233403, 0.9381309722959088], 
             UndirectedEdge[18, 224] -> 
             RGBColor[
              0.960434037083298, 0.9441092105197667, 0.6687925780376456], 
             UndirectedEdge[84, 204] -> 
             RGBColor[
              0.17892700714738574`, 0.30539400751235557`, 0.933501000407033], 
             UndirectedEdge[241, 288] -> 
             RGBColor[
              0.2679939698052205, 0.39900903243733754`, 0.9385732321676334], 
             UndirectedEdge[91, 266] -> 
             RGBColor[
              0.25880957199136756`, 0.38935564801052325`, 0.9380501942992334],
              UndirectedEdge[201, 263] -> 
             RGBColor[
              0.26925494850456955`, 0.4003344010010207, 0.9386450430391104], 
             UndirectedEdge[29, 266] -> 
             RGBColor[
              0.2477135704987891, 0.37769304691469485`, 0.9374182934292943], 
             UndirectedEdge[161, 326] -> 
             RGBColor[
              0.3854134409611904, 0.5082474839429573, 0.9457791815436909], 
             UndirectedEdge[174, 235] -> 
             RGBColor[
              0.7343495307888845, 0.7923987018062052, 0.9741567564086497], 
             UndirectedEdge[207, 233] -> 
             RGBColor[
              0.8786570254685007, 0.4672262975790694, 0.21740805642807715`], 
             UndirectedEdge[199, 212] -> 
             RGBColor[
              0.21834996970250586`, 0.3468300407179805, 0.9357460798035004], 
             UndirectedEdge[127, 184] -> 
             RGBColor[
              0.21412931839643223`, 0.34239386859054827`, 0.9355057199555137],
              UndirectedEdge[261, 381] -> 
             RGBColor[
              0.5862976993087463, 0.6486880635605781, 0.8483828425372609], 
             UndirectedEdge[221, 230] -> 
             RGBColor[
              0.9453580743501937, 0.9235697837599854, 0.6629627899588003], 
             UndirectedEdge[22, 273] -> 
             RGBColor[
              0.28387789683872655`, 0.4157040468486936, 0.9394777983140272], 
             UndirectedEdge[240, 292] -> 
             RGBColor[
              0.2251125947151853, 0.3539379883814973, 0.9361312012935654], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.4322766112650586, 0.5488154801889021, 0.9487714854439504], 
             UndirectedEdge[120, 343] -> 
             RGBColor[
              0.64428944346767, 0.7208791499127623, 0.9659761919445966], 
             UndirectedEdge[175, 310] -> 
             RGBColor[
              0.18075514602575382`, 0.30731549738422004`, 0.933605110211667], 
             UndirectedEdge[55, 201] -> 
             RGBColor[
              0.33997947002411655`, 0.46590668357700793`, 0.9429935809374401],
              UndirectedEdge[264, 333] -> 
             RGBColor[
              0.19279573500831393`, 0.31997091982232506`, 0.9342908039417687],
              UndirectedEdge[107, 197] -> 
             RGBColor[
              0.9139845567949747, 0.6460331456516251, 0.5106347906861869], 
             UndirectedEdge[131, 300] -> 
             RGBColor[
              0.9062314787117222, 0.661847076989811, 0.24319781291959908`], 
             UndirectedEdge[164, 227] -> 
             RGBColor[
              0.23873025962291325`, 0.36825101760934276`, 0.9369067071645306],
              UndirectedEdge[75, 315] -> 
             RGBColor[
              0.24372617436870905`, 0.3735020407664642, 0.9371912171185102], 
             UndirectedEdge[123, 193] -> 
             RGBColor[
              0.8983178729767032, 0.9207629901755221, 0.9556553997903747], 
             UndirectedEdge[157, 253] -> 
             RGBColor[
              0.40547981020843754`, 0.5251955404755204, 0.9471772728723662], 
             UndirectedEdge[87, 110] -> 
             RGBColor[
              0.27285833032697415`, 0.4041217837639711, 0.9388502503031707], 
             UndirectedEdge[112, 273] -> 
             RGBColor[
              0.30217928403804095`, 0.4330746327553852, 0.940588334197813], 
             UndirectedEdge[193, 384] -> 
             RGBColor[
              0.7853837252276628, 0.8322860419074539, 0.9792383154624147], 
             UndirectedEdge[95, 249] -> 
             RGBColor[
              0.2756739059578213, 0.4070811322697972, 0.9390105931700766], 
             UndirectedEdge[61, 66] -> 
             RGBColor[
              0.9830643953423903, 0.9540141570597834, 0.4329439736998075], 
             UndirectedEdge[113, 251] -> 
             RGBColor[
              0.8094157442625041, 0.8510598457172036, 0.9816336535080088], 
             UndirectedEdge[107, 131] -> 
             RGBColor[
              0.8808419295941465, 0.5163805585259162, 0.22083043617809295`], 
             UndirectedEdge[71, 343] -> 
             RGBColor[
              0.7966602927353739, 0.841489655974727, 0.98025763017568], 
             UndirectedEdge[113, 168] -> 
             RGBColor[
              0.7333330676267822, 0.7916046330585647, 0.9740554448600397], 
             UndirectedEdge[58, 201] -> 
             RGBColor[
              0.2876186397714912, 0.4196358048478299, 0.939690828090115], 
             UndirectedEdge[47, 130] -> 
             RGBColor[
              0.4221487542491271, 0.5400657659424366, 0.9481199232226362], 
             UndirectedEdge[17, 82] -> 
             RGBColor[
              0.4573668797759753, 0.5683380513272105, 0.9509806674680623], 
             UndirectedEdge[11, 25] -> 
             RGBColor[
              0.8860868883930885, 0.5548412704093811, 0.2257767948788701], 
             UndirectedEdge[73, 392] -> 
             RGBColor[
              0.24553259442115521`, 0.3754007027752315, 0.9372940900681379], 
             UndirectedEdge[155, 337] -> 
             RGBColor[
              0.29464447603044647`, 0.42702040421973947`, 0.9400909390712692],
              UndirectedEdge[159, 165] -> 
             RGBColor[
              0.43209168429834016`, 0.5465211004605023, 0.9493493893401392], 
             UndirectedEdge[226, 368] -> 
             RGBColor[
              0.2257077662103317, 0.35456355135894857`, 0.9361650954297367], 
             UndirectedEdge[188, 258] -> 
             RGBColor[
              0.2600095899871553, 0.39061694300963157`, 0.938118533548826], 
             UndirectedEdge[140, 350] -> 
             RGBColor[
              0.5523338730537959, 0.6464369667603329, 0.9583649127104528], 
             UndirectedEdge[14, 38] -> 
             RGBColor[
              0.9800741446959539, 0.9433032752196526, 0.4743933351284341], 
             UndirectedEdge[242, 268] -> 
             RGBColor[
              0.8678329199624942, 0.4240532300724246, 0.2086880773194431], 
             UndirectedEdge[20, 50] -> 
             RGBColor[
              0.4309033063250306, 0.5476259924741631, 0.9486839796675377], 
             UndirectedEdge[149, 212] -> 
             RGBColor[
              0.21555790485274898`, 0.34389540353375003`, 0.9355870758407967],
              UndirectedEdge[80, 361] -> 
             RGBColor[
              0.34502145958500996`, 0.47326197983492335`, 0.9432054402076274],
              UndirectedEdge[31, 204] -> 
             RGBColor[
              0.1810722066459815, 0.3076487481988837, 0.9336231663449399], 
             UndirectedEdge[209, 245] -> 
             RGBColor[
              0.2409659187206967, 0.37060083707008695`, 0.9370340246427882], 
             UndirectedEdge[113, 148] -> 
             RGBColor[
              0.7102018348766541, 0.7732513864434318, 0.9719433954351793], 
             UndirectedEdge[48, 231] -> 
             RGBColor[
              0.3670635094292236, 0.49234797467679914`, 0.9446101496016666], 
             UndirectedEdge[198, 224] -> 
             RGBColor[
              0.901075568718926, 0.8970235530331128, 0.6716312488962854], 
             UndirectedEdge[1, 188] -> 
             RGBColor[
              0.3135344759290187, 0.4421377779902256, 0.9413401492239378], 
             UndirectedEdge[256, 264] -> 
             RGBColor[
              0.2076696899760163, 0.3356043895565939, 0.9351378536731348], 
             UndirectedEdge[15, 170] -> 
             RGBColor[
              0.3744152758657625, 0.49826976676104406`, 0.9450949256507872], 
             UndirectedEdge[20, 322] -> 
             RGBColor[
              0.45803755349750475`, 0.5696547967126826, 0.9508200870009773], 
             UndirectedEdge[92, 153] -> 
             RGBColor[
              0.30254730129756563`, 0.4345238091753902, 0.940570393778262], 
             UndirectedEdge[189, 360] -> 
             RGBColor[
              0.30546923311788443`, 0.43824575192600135`, 0.9407129642351355],
              UndirectedEdge[272, 342] -> 
             RGBColor[
              0.6251875638221265, 0.7065231010289125, 0.9636849864326502], 
             UndirectedEdge[69, 219] -> 
             RGBColor[
              0.4677032328653056, 0.5785751319820428, 0.9512844483334466], 
             UndirectedEdge[86, 151] -> 
             RGBColor[
              0.30818593638346986`, 0.44059786327207706`, 0.9408861053327038],
              UndirectedEdge[72, 288] -> 
             RGBColor[
              0.2363762501862872, 0.36577680443863003`, 0.9367726498095597], 
             UndirectedEdge[266, 273] -> 
             RGBColor[
              0.265217664230201, 0.3960909592500517, 0.938415125672312], 
             UndirectedEdge[131, 297] -> 
             RGBColor[
              0.9345525999537521, 0.8450176590746574, 0.6158415354980056], 
             UndirectedEdge[219, 360] -> 
             RGBColor[
              0.37878978346753606`, 0.5025104047366595, 0.9453571279452656], 
             UndirectedEdge[58, 236] -> 
             RGBColor[
              0.27466659649964625`, 0.4060223861621468, 0.9389532283866143], 
             UndirectedEdge[272, 321] -> 
             RGBColor[
              0.7324016958614257, 0.7908770383567805, 0.9739626144266329], 
             UndirectedEdge[250, 391] -> 
             RGBColor[
              0.9043090036006871, 0.5735688958941825, 0.5059642810005588], 
             UndirectedEdge[122, 298] -> 
             RGBColor[
              0.634758859433705, 0.711422615804957, 0.9663329898214426], 
             UndirectedEdge[113, 282] -> 
             RGBColor[
              0.7216887092702036, 0.7825079718100041, 0.9728948440417715], 
             UndirectedEdge[237, 343] -> 
             RGBColor[
              0.6503098019378368, 0.7257667481329021, 0.9664501366166679], 
             UndirectedEdge[174, 398] -> 
             RGBColor[
              0.83401539327211, 0.8711277377968187, 0.9805027030161089], 
             UndirectedEdge[223, 384] -> 
             RGBColor[
              0.6012475155961567, 0.6855340055780029, 0.9628624648765374], 
             UndirectedEdge[143, 260] -> 
             RGBColor[
              0.7167991404658595, 0.7784168360748085, 0.9725930329082488], 
             UndirectedEdge[148, 161] -> 
             RGBColor[
              0.5276623353729026, 0.6268249505740837, 0.9561228183174523], 
             UndirectedEdge[137, 199] -> 
             RGBColor[
              0.22367942926895015`, 0.3524316406295666, 0.9360495846415806], 
             UndirectedEdge[147, 387] -> 
             RGBColor[
              0.28915329202202544`, 0.42124882166571403`, 0.9397782242654684],
              UndirectedEdge[138, 381] -> 
             RGBColor[
              0.9062449527279615, 0.5705587678025101, 0.4646955300926113], 
             UndirectedEdge[42, 207] -> 
             RGBColor[
              0.9360408404789141, 0.8740255032004962, 0.6319312562767279], 
             UndirectedEdge[185, 247] -> 
             RGBColor[
              0.8653490116625105, 0.42606196440460237`, 0.20717681371904806`],
              UndirectedEdge[49, 380] -> 
             RGBColor[
              0.2606135317686764, 0.39125172411413095`, 0.9381529271398318], 
             UndirectedEdge[63, 242] -> 
             RGBColor[
              0.9384539463641798, 0.7929291511512139, 0.2733380495894395], 
             UndirectedEdge[12, 238] -> 
             RGBColor[
              0.22383004590865202`, 0.3525899482675398, 0.9360581620363942], 
             UndirectedEdge[109, 382] -> 
             RGBColor[
              0.9464386860434384, 0.8125481887830079, 0.4923766470320703], 
             UndirectedEdge[4, 115] -> 
             RGBColor[
              0.23540129852856206`, 0.36475206843085556`, 0.936717127754964], 
             UndirectedEdge[187, 279] -> 
             RGBColor[
              0.8947917399967904, 0.8503099582405043, 0.6300514927715455], 
             UndirectedEdge[152, 156] -> 
             RGBColor[
              0.18478785261667285`, 0.31155412769964164`, 0.9338347668861651],
              UndirectedEdge[143, 290] -> 
             RGBColor[
              0.5148889820990041, 0.6157407807626738, 0.9553145849297924], 
             UndirectedEdge[48, 234] -> 
             RGBColor[
              0.38209114426819646`, 0.5053698775309731, 0.945567487736205], 
             UndirectedEdge[294, 341] -> 
             RGBColor[
              0.21717163219876068`, 0.3455915332906315, 0.9356789752258563], 
             UndirectedEdge[243, 351] -> 
             RGBColor[
              0.26705822161415743`, 0.39802550175866824`, 0.9385199426924677],
              UndirectedEdge[241, 399] -> 
             RGBColor[
              0.2629204824738216, 0.3936764755743613, 0.938284304569662], 
             UndirectedEdge[78, 207] -> 
             RGBColor[
              0.8908498839236407, 0.5609459506099194, 0.22908395145458324`], 
             UndirectedEdge[174, 267] -> 
             RGBColor[
              0.6499021646261236, 0.725337696254724, 0.9664851266806084], 
             UndirectedEdge[124, 293] -> 
             RGBColor[
              0.21725116581640602`, 0.3456751281654994, 0.9356835045477219], 
             UndirectedEdge[57, 392] -> 
             RGBColor[
              0.2605783177897506, 0.3912147119895847, 0.9381509217558264], 
             UndirectedEdge[272, 331] -> 
             RGBColor[
              0.5495546990516302, 0.6450876581742866, 0.9577400845269233], 
             UndirectedEdge[91, 255] -> 
             RGBColor[
              0.26154809523840944`, 0.39223400957556664`, 0.9382061491468703],
              UndirectedEdge[35, 337] -> 
             RGBColor[
              0.28289219144336497`, 0.41466800798083686`, 0.9394216638499819],
              UndirectedEdge[219, 339] -> 
             RGBColor[
              0.4064741730871376, 0.5264892315672777, 0.9471211527714821], 
             UndirectedEdge[166, 185] -> 
             RGBColor[
              0.8242297938213237, 0.1872463896398561, 0.17083578396792481`], 
             UndirectedEdge[137, 238] -> 
             RGBColor[
              0.22538960071026484`, 0.3542291392455204, 0.9361469763751915], 
             UndirectedEdge[218, 300] -> 
             RGBColor[
              0.9000302759419758, 0.7622535258714493, 0.6106034215734397], 
             UndirectedEdge[96, 110] -> 
             RGBColor[
              0.2712447160930261, 0.4024257728950402, 0.9387583573596757], 
             UndirectedEdge[225, 375] -> 
             RGBColor[
              0.2559767228165143, 0.3863781439147409, 0.9378888677295503], 
             UndirectedEdge[24, 25] -> 
             RGBColor[
              0.8754320696783777, 0.5120010563873596, 0.21717277432657275`], 
             UndirectedEdge[40, 361] -> 
             RGBColor[
              0.34746932604333547`, 0.4753821987277793, 0.9433614160937887], 
             UndirectedEdge[141, 394] -> 
             RGBColor[
              0.3594659493572627, 0.4857730708744833, 0.9441258303231546], 
             UndirectedEdge[200, 360] -> 
             RGBColor[
              0.29052568872167633`, 0.4225391392901483, 0.9398619514887643], 
             UndirectedEdge[68, 229] -> 
             RGBColor[
              0.2618103919644219, 0.39250970006517877`, 0.9382210865573835], 
             UndirectedEdge[96, 258] -> 
             RGBColor[
              0.26992237493120286`, 0.4010359084926919, 0.9386830519867384], 
             UndirectedEdge[106, 310] -> 
             RGBColor[
              0.5655364837016175, 0.6351698449942476, 0.952888973704525], 
             UndirectedEdge[15, 394] -> 
             RGBColor[
              0.33136443385417313`, 0.4609812912088401, 0.9423517640661736], 
             UndirectedEdge[115, 203] -> 
             RGBColor[
              0.265001837635785, 0.3958641118151241, 0.9384028346670469], 
             UndirectedEdge[218, 298] -> 
             RGBColor[
              0.8667469534105012, 0.8965845097029781, 0.9871522922420749], 
             UndirectedEdge[165, 262] -> 
             RGBColor[
              0.7356958172611161, 0.7926545035064209, 0.9725524468455675], 
             UndirectedEdge[141, 357] -> 
             RGBColor[
              0.5178770250869611, 0.6164322687663853, 0.9562370335292427], 
             UndirectedEdge[15, 239] -> 
             RGBColor[
              0.3141879177885835, 0.4461038563096259, 0.9412572916510711], 
             UndirectedEdge[80, 228] -> 
             RGBColor[
              0.35113678778418134`, 0.4785587697557132, 0.9435951035129062], 
             UndirectedEdge[260, 272] -> 
             RGBColor[
              0.7279854810242253, 0.7874270577614837, 0.9735224474035349], 
             UndirectedEdge[7, 361] -> 
             RGBColor[
              0.3725157575792012, 0.497076158853894, 0.9449573525635642], 
             UndirectedEdge[22, 255] -> 
             RGBColor[
              0.27639668732322686`, 0.40784082131182386`, 0.9390517544995772],
              UndirectedEdge[28, 380] -> 
             RGBColor[
              0.2768898890919296, 0.40835920764152867`, 0.9390798416106783], 
             UndirectedEdge[53, 397] -> 
             RGBColor[
              0.26929675474869136`, 0.4003783420142617, 0.9386474238428664], 
             UndirectedEdge[187, 306] -> 
             RGBColor[
              0.9071549779062498, 0.8950638881018478, 0.6621967951023203], 
             UndirectedEdge[208, 392] -> 
             RGBColor[
              0.24051796511845452`, 0.3701300094322317, 0.9370085143478284], 
             UndirectedEdge[33, 381] -> 
             RGBColor[
              0.5860442078575524, 0.648421627973087, 0.8483684065741224], 
             UndirectedEdge[290, 321] -> 
             RGBColor[
              0.6114600904368728, 0.6914542319869668, 0.964754355111318], 
             UndirectedEdge[20, 116] -> 
             RGBColor[
              0.4119401607737857, 0.531223595372923, 0.9474694406734923], 
             UndirectedEdge[33, 156] -> 
             RGBColor[
              0.18245046291019928`, 0.30909738291907096`, 0.9337016560002396],
              UndirectedEdge[9, 202] -> 
             RGBColor[
              0.8410035318945833, 0.31617669076982174`, 0.1868983344901058], 
             UndirectedEdge[76, 233] -> 
             RGBColor[
              0.8322013343184957, 0.24851914305244047`, 0.17846934015058413`],
              UndirectedEdge[115, 369] -> 
             RGBColor[
              0.24803002426208054`, 0.37802565988424164`, 0.9374363150029623],
              UndirectedEdge[183, 335] -> 
             RGBColor[
              0.2697259044179279, 0.4008294055262898, 0.9386718632816594], 
             UndirectedEdge[39, 296] -> 
             RGBColor[
              0.2873068026652887, 0.4193080442775966, 0.9396730694282384], 
             UndirectedEdge[10, 219] -> 
             RGBColor[
              0.4045568603314619, 0.5248285516252523, 0.9469989832981036], 
             UndirectedEdge[71, 143] -> 
             RGBColor[
              0.7478821300066041, 0.8031124171001021, 0.9755814141619994], 
             UndirectedEdge[232, 384] -> 
             RGBColor[
              0.6369922413654878, 0.7145531842390913, 0.965676420626344], 
             UndirectedEdge[1, 57] -> 
             RGBColor[
              0.31659522838756854`, 0.44535482288707584`, 0.9415144545484747],
              UndirectedEdge[288, 393] -> 
             RGBColor[
              0.23392299503197628`, 0.3631982777260886, 0.9366329405577875], 
             UndirectedEdge[328, 372] -> 
             RGBColor[
              0.2804573452843499, 0.4120449254968854, 0.9392853428307628], 
             UndirectedEdge[16, 115] -> 
             RGBColor[
              0.240233305102069, 0.36983081370652304`, 0.936992303381012], 
             UndirectedEdge[34, 244] -> 
             RGBColor[
              0.2861625929026812, 0.4177778317374103, 0.9396199025198813], 
             UndirectedEdge[233, 366] -> 
             RGBColor[
              0.8593693391869154, 0.3899082942266366, 0.20184482611558502`], 
             UndirectedEdge[100, 105] -> 
             RGBColor[
              0.3969790975995051, 0.5182650744162607, 0.9465161349575758], 
             UndirectedEdge[88, 282] -> 
             RGBColor[
              0.8185877701205739, 0.8571575543356513, 0.887813136638508], 
             UndirectedEdge[189, 219] -> 
             RGBColor[
              0.37386729373661226`, 0.4974887142474586, 0.9450712281757306], 
             UndirectedEdge[44, 328] -> 
             RGBColor[
              0.3036968641952127, 0.4364711333428047, 0.9406087990529493], 
             UndirectedEdge[153, 154] -> 
             RGBColor[
              0.3737943950019111, 0.49818365032325973`, 0.9450388262094847], 
             UndirectedEdge[73, 258] -> 
             RGBColor[
              0.2480246190771097, 0.3780199786921288, 0.9374360071856744], 
             UndirectedEdge[22, 141] -> 
             RGBColor[
              0.32619117202571163`, 0.45543328701971864`, 0.9420612032605917],
              UndirectedEdge[100, 273] -> 
             RGBColor[
              0.3260257412647034, 0.4537292354473304, 0.9421078093657018], 
             UndirectedEdge[230, 391] -> 
             RGBColor[
              0.8946240115133538, 0.5321742003823082, 0.2503381046492794], 
             UndirectedEdge[338, 384] -> 
             RGBColor[
              0.8713581064441347, 0.8967942587815345, 0.7976314467612728], 
             UndirectedEdge[76, 207] -> 
             RGBColor[
              0.8934001271128089, 0.5805482372855583, 0.23152606721261854`], 
             UndirectedEdge[144, 370] -> 
             RGBColor[
              0.8548273648949809, 0.7045756223106869, 0.6020207461756493], 
             UndirectedEdge[6, 340] -> 
             RGBColor[
              0.9935628356137232, 0.988639881211936, 0.5407325660065214], 
             UndirectedEdge[30, 370] -> 
             RGBColor[
              0.5050718279609444, 0.5868238115344944, 0.9586321897581539], 
             UndirectedEdge[164, 245] -> 
             RGBColor[
              0.23621867801950508`, 0.36561118610068966`, 0.9367636763077685],
              UndirectedEdge[56, 108] -> 
             RGBColor[
              0.40925205503740436`, 0.5288952932921922, 0.9472981569529686], 
             UndirectedEdge[50, 322] -> 
             RGBColor[
              0.4812818793914586, 0.5897653370483966, 0.952307419020761], 
             UndirectedEdge[379, 399] -> 
             RGBColor[
              0.22791818849812123`, 0.356886845332283, 0.9362909757089996], 
             UndirectedEdge[6, 13] -> 
             RGBColor[
              0.978563836078469, 0.9803436260913665, 0.7317471315868381], 
             UndirectedEdge[55, 60] -> 
             RGBColor[
              0.38053049793671245`, 0.5040181241190069, 0.9454680447319882], 
             UndirectedEdge[44, 47] -> 
             RGBColor[
              0.36592423069765223`, 0.4903693505688373, 0.9445738718209851], 
             UndirectedEdge[156, 264] -> 
             RGBColor[
              0.1879952768080626, 0.31492533388723165`, 0.9340174249489059], 
             UndirectedEdge[32, 43] -> 
             RGBColor[
              0.2218603287150994, 0.3505196506098328, 0.9359459895561568], 
             UndirectedEdge[144, 207] -> 
             RGBColor[
              0.9091469621070289, 0.6700765235430096, 0.2453714490760957], 
             UndirectedEdge[14, 213] -> 
             RGBColor[
              0.9526625957676589, 0.8375319772984231, 0.4372009912003371], 
             UndirectedEdge[127, 139] -> 
             RGBColor[
              0.2108331954164144, 0.3389294343522821, 0.9353180106279786], 
             UndirectedEdge[321, 342] -> 
             RGBColor[
              0.7105723316016292, 0.7732263305665302, 0.9721953421188899], 
             UndirectedEdge[82, 182] -> 
             RGBColor[
              0.3336557333984177, 0.4615081693978327, 0.9425511382946132], 
             UndirectedEdge[50, 172] -> 
             RGBColor[
              0.3777861468106212, 0.500941670871986, 0.945324186142565], 
             UndirectedEdge[80, 96] -> 
             RGBColor[
              0.31066394327551555`, 0.4414844762785116, 0.9410901259683782], 
             UndirectedEdge[78, 160] -> 
             RGBColor[
              0.835660765688327, 0.2751098484934552, 0.18178209553720334`], 
             UndirectedEdge[32, 293] -> 
             RGBColor[
              0.2137582367821496, 0.342003838286004, 0.9354845874065463], 
             UndirectedEdge[322, 328] -> 
             RGBColor[
              0.4089266558730876, 0.5271174055758985, 0.947690784031411], 
             UndirectedEdge[120, 254] -> 
             RGBColor[
              0.5179448523327678, 0.6195299901302602, 0.955193662551596], 
             UndirectedEdge[291, 321] -> 
             RGBColor[
              0.7571390218362452, 0.8102020254189503, 0.9764281998963484], 
             UndirectedEdge[65, 312] -> 
             RGBColor[
              0.4891446804627151, 0.5961487131731942, 0.9529264075234798], 
             UndirectedEdge[209, 334] -> 
             RGBColor[
              0.2567160128781451, 0.387155184643212, 0.9379309692048785], 
             UndirectedEdge[295, 310] -> 
             RGBColor[
              0.2124827502833183, 0.3406632211052174, 0.935411950337351], 
             UndirectedEdge[109, 205] -> 
             RGBColor[
              0.9946824810618875, 0.9920690835121566, 0.737788580309801], 
             UndirectedEdge[194, 376] -> 
             RGBColor[
              0.4132241787161002, 0.5323357471779375, 0.947551257161364], 
             UndirectedEdge[142, 338] -> 
             RGBColor[
              0.9079361737525008, 0.5785505948422507, 0.3940025431841314], 
             UndirectedEdge[232, 386] -> 
             RGBColor[
              0.4324598922567031, 0.5470353068857565, 0.9493188938960907], 
             UndirectedEdge[169, 378] -> 
             RGBColor[
              0.21461245212241514`, 0.34290167276900374`, 0.9355332337064761],
              UndirectedEdge[94, 324] -> 
             RGBColor[
              0.2700408112862358, 0.4011603926111301, 0.9386897967619465], 
             UndirectedEdge[196, 231] -> 
             RGBColor[
              0.3033041199951848, 0.43612223907981873`, 0.9405840929842658], 
             UndirectedEdge[207, 366] -> 
             RGBColor[
              0.9205681319812286, 0.7219373884597544, 0.2549015531776194], 
             UndirectedEdge[156, 310] -> 
             RGBColor[
              0.1842688448604277, 0.3110086176408356, 0.93380521016225], 
             UndirectedEdge[206, 369] -> 
             RGBColor[
              0.2445080094379043, 0.3743237989953949, 0.9372357414690795], 
             UndirectedEdge[119, 225] -> 
             RGBColor[
              0.24880323623162193`, 0.37883835468870003`, 0.9374803482807631],
              UndirectedEdge[69, 100] -> 
             RGBColor[
              0.4324163535905058, 0.5480114107243323, 0.9490359995890186], 
             UndirectedEdge[64, 182] -> 
             RGBColor[
              0.34352729206089855`, 0.4700584173523088, 0.9431801452835099], 
             UndirectedEdge[217, 268] -> 
             RGBColor[
              0.8200723347530428, 0.15529033743086842`, 0.16685459646896056`],
              UndirectedEdge[235, 275] -> 
             RGBColor[
              0.8660971591696807, 0.893943749566336, 0.8776528174795629], 
             UndirectedEdge[5, 99] -> 
             RGBColor[
              0.9097853137766493, 0.92980801321679, 0.9533236132867424], 
             UndirectedEdge[52, 267] -> 
             RGBColor[
              0.4789222153161444, 0.5860393403630161, 0.9526218530734996], 
             UndirectedEdge[290, 346] -> 
             RGBColor[
              0.3750828645825507, 0.4992996579136456, 0.9451209263518141], 
             UndirectedEdge[19, 108] -> 
             RGBColor[
              0.3209765938651673, 0.4492585340761873, 0.9417896478514372], 
             UndirectedEdge[92, 327] -> 
             RGBColor[
              0.3031279877877182, 0.4350267706270088, 0.9406073946079336], 
             UndirectedEdge[151, 244] -> 
             RGBColor[
              0.28793584651295273`, 0.41931373488830953`, 0.9397328926719012],
              UndirectedEdge[114, 327] -> 
             RGBColor[
              0.32373500724345117`, 0.4548247247048681, 0.941849086287294], 
             UndirectedEdge[99, 174] -> 
             RGBColor[
              0.8533664925541351, 0.885559755956836, 0.9477463395066474], 
             UndirectedEdge[180, 282] -> 
             RGBColor[
              0.5065658976915518, 0.60785950870626, 0.9549980870909234], 
             UndirectedEdge[199, 277] -> 
             RGBColor[
              0.24180779724081597`, 0.3714857047729135, 0.9370819683790612], 
             UndirectedEdge[237, 286] -> 
             RGBColor[
              0.652334455595527, 0.7273484229582274, 0.9666519351718024], 
             UndirectedEdge[290, 313] -> 
             RGBColor[
              0.34397103520992167`, 0.4699540423686539, 0.9432263147475373], 
             UndirectedEdge[56, 237] -> 
             RGBColor[
              0.5146770314008289, 0.6168123226982427, 0.9549542854004349], 
             UndirectedEdge[203, 361] -> 
             RGBColor[
              0.32351204834138475`, 0.4530276285511149, 0.941893609121445], 
             UndirectedEdge[169, 315] -> 
             RGBColor[
              0.23198634740170132`, 0.3611627382761178, 0.9365226513402567], 
             UndirectedEdge[23, 304] -> 
             RGBColor[
              0.2162581809318601, 0.34463143809296365`, 0.9356269555275363], 
             UndirectedEdge[129, 270] -> 
             RGBColor[
              0.24363580909960866`, 0.3734070611391507, 0.9371860709501183], 
             UndirectedEdge[85, 284] -> 
             RGBColor[
              0.24265277809452013`, 0.37237383322503703`, 0.9371300887886426],
              UndirectedEdge[203, 369] -> 
             RGBColor[
              0.2744257623445868, 0.405769254195412, 0.9389395132377659], 
             UndirectedEdge[1, 222] -> 
             RGBColor[
              0.48245496695292606`, 0.5881834392083616, 0.9530999932353155], 
             UndirectedEdge[25, 205] -> 
             RGBColor[
              0.9219898136234065, 0.68386598697934, 0.46117782525974793`], 
             UndirectedEdge[301, 380] -> 
             RGBColor[
              0.26115428543555863`, 0.39182009050378686`, 0.9381837222611874],
              UndirectedEdge[169, 329] -> 
             RGBColor[
              0.22791864695390707`, 0.3568873271983817, 0.9362910018173783], 
             UndirectedEdge[302, 340] -> 
             RGBColor[
              0.9905275811721996, 0.978922480132596, 0.484619975557615], 
             UndirectedEdge[205, 391] -> 
             RGBColor[
              0.9078296512801215, 0.575024774186147, 0.4476180378082022], 
             UndirectedEdge[96, 203] -> 
             RGBColor[
              0.28915453203189034`, 0.42125012499470316`, 0.9397782948821958],
              UndirectedEdge[4, 195] -> 
             RGBColor[
              0.2389456018045329, 0.3684773558957079, 0.9369189705832036], 
             UndirectedEdge[269, 298] -> 
             RGBColor[
              0.908244530929823, 0.9248034643520736, 0.7344530675019115], 
             UndirectedEdge[168, 220] -> 
             RGBColor[
              0.5727925024434088, 0.663632053166977, 0.9598025445321408], 
             UndirectedEdge[291, 338] -> 
             RGBColor[
              0.8453899770207604, 0.8765077587109009, 0.7950431863063177], 
             UndirectedEdge[10, 360] -> 
             RGBColor[
              0.336158799712734, 0.4655855893037951, 0.9426407193575084], 
             UndirectedEdge[87, 348] -> 
             RGBColor[
              0.27654696971548504`, 0.4079987776345412, 0.9390603128594934], 
             UndirectedEdge[259, 274] -> 
             RGBColor[
              0.22087433163626, 0.34948330516414705`, 0.9358898384811689], 
             UndirectedEdge[293, 336] -> 
             RGBColor[
              0.21111881242536762`, 0.33922963593785627`, 0.935334276094106], 
             UndirectedEdge[229, 245] -> 
             RGBColor[
              0.238397504828522, 0.36790127122256505`, 0.9368877572712566], 
             UndirectedEdge[173, 197] -> 
             RGBColor[
              0.607559522477704, 0.6724367666110929, 0.8861420267905455], 
             UndirectedEdge[19, 344] -> 
             RGBColor[
              0.2975063791842545, 0.4289298137668702, 0.9402941465258654], 
             UndirectedEdge[83, 125] -> 
             RGBColor[
              0.315433813888692, 0.4447906722692076, 0.9414242734794431], 
             UndirectedEdge[240, 315] -> 
             RGBColor[
              0.24124036831115342`, 0.3708893009907661, 0.9370496541409528], 
             UndirectedEdge[7, 154] -> 
             RGBColor[
              0.40978151173656857`, 0.5293538820737408, 0.9473318934656592], 
             UndirectedEdge[200, 225] -> 
             RGBColor[
              0.26388387983793327`, 0.3946890672869635, 0.9383391686243296], 
             UndirectedEdge[13, 140] -> 
             RGBColor[
              0.8178525622986523, 0.8580700202466935, 0.9570649175635426], 
             UndirectedEdge[104, 366] -> 
             RGBColor[
              0.9175772665295729, 0.7100796035907695, 0.25249503263058215`], 
             UndirectedEdge[116, 172] -> 
             RGBColor[
              0.3588230012593764, 0.484539273770746, 0.9441096471485195], 
             UndirectedEdge[143, 267] -> 
             RGBColor[
              0.5979215961089128, 0.6844587136389835, 0.9614897247861196], 
             UndirectedEdge[51, 395] -> 
             RGBColor[
              0.3229957435790246, 0.45088574591651165`, 0.9419227613726417], 
             UndirectedEdge[213, 224] -> 
             RGBColor[
              0.9433148110399261, 0.8071439818533458, 0.30358552172184644`], 
             UndirectedEdge[130, 362] -> 
             RGBColor[
              0.40753230852825906`, 0.5274057353029433, 0.9471885762261179], 
             UndirectedEdge[153, 278] -> 
             RGBColor[
              0.284923192180341, 0.41599975306012926`, 0.939566726836569], 
             UndirectedEdge[83, 303] -> 
             RGBColor[
              0.32124670467921895`, 0.4509003890486145, 0.9417553090105623], 
             UndirectedEdge[94, 296] -> 
             RGBColor[
              0.2808227544696311, 0.4124928985115602, 0.9393038124757853], 
             UndirectedEdge[147, 328] -> 
             RGBColor[
              0.29708750914626414`, 0.42952428212904603`, 0.9402324060605761],
              UndirectedEdge[78, 102] -> 
             RGBColor[
              0.8305704924938522, 0.23598377814878552`, 0.17690764417753302`],
              UndirectedEdge[22, 45] -> 
             RGBColor[
              0.2939087453063859, 0.4262471045807297, 0.94004904029495], 
             UndirectedEdge[199, 238] -> 
             RGBColor[
              0.22751293603602638`, 0.35646089930013114`, 0.9362678971808005],
              UndirectedEdge[21, 182] -> 
             RGBColor[
              0.30050572685967525`, 0.4327952999017487, 0.9404388491913643], 
             UndirectedEdge[126, 212] -> 
             RGBColor[
              0.21146946129668887`, 0.3395981901340374, 0.9353542450285892], 
             UndirectedEdge[273, 365] -> 
             RGBColor[
              0.26583905724777945`, 0.3967440827101195, 0.9384505130853945], 
             UndirectedEdge[149, 367] -> 
             RGBColor[
              0.21976666504097775`, 0.348319077342387, 0.9358267585072135], 
             UndirectedEdge[81, 89] -> 
             RGBColor[
              0.21914913629591037`, 0.3476700154777373, 0.9357915911587338], 
             UndirectedEdge[57, 337] -> 
             RGBColor[
              0.27897537779675124`, 0.41055118849791716`, 0.9391986071072138],
              UndirectedEdge[255, 288] -> 
             RGBColor[
              0.25275048461760563`, 0.38298716301237146`, 0.9377051382369141],
              UndirectedEdge[2, 283] -> 
             RGBColor[
              0.8636832468154017, 0.4097080433065882, 0.20543575312607748`], 
             UndirectedEdge[94, 128] -> 
             RGBColor[
              0.29316856057651314`, 0.42385416586161573`, 0.9400660193797667],
              UndirectedEdge[176, 393] -> 
             RGBColor[
              0.2193217433014607, 0.3478514363844869, 0.9358014208723507], 
             UndirectedEdge[65, 326] -> 
             RGBColor[
              0.4273612108963405, 0.5428967033575929, 0.9489173037481067], 
             UndirectedEdge[97, 282] -> 
             RGBColor[
              0.5445731104291971, 0.6407794460815519, 0.9574198730781076], 
             UndirectedEdge[12, 149] -> 
             RGBColor[
              0.21932780961758047`, 0.3478578124673555, 0.9358017663400795], 
             UndirectedEdge[78, 144] -> 
             RGBColor[
              0.8601410277678558, 0.4317670823407418, 0.2039906170405674], 
             UndirectedEdge[201, 348] -> 
             RGBColor[
              0.2696907546749492, 0.40079246091779686`, 0.9386698615557961], 
             UndirectedEdge[242, 381] -> 
             RGBColor[
              0.9557469344850966, 0.8527067973943953, 0.5081965742437817], 
             UndirectedEdge[43, 367] -> 
             RGBColor[
              0.22337497152266345`, 0.35211163623448327`, 0.9360322462233344],
              UndirectedEdge[111, 197] -> 
             RGBColor[
              0.931414792844472, 0.7553582824181725, 0.5263607215030722], 
             UndirectedEdge[69, 216] -> 
             RGBColor[
              0.5736600979558795, 0.6645056615859741, 0.959755124057878], 
             UndirectedEdge[197, 295] -> 
             RGBColor[
              0.6155693919444334, 0.6808556472756819, 0.8865981770071358], 
             UndirectedEdge[193, 275] -> 
             RGBColor[
              0.9072201261691099, 0.9260883634638468, 0.8817465180078601], 
             UndirectedEdge[149, 238] -> 
             RGBColor[
              0.2247208711862695, 0.3535262621159006, 0.9361088932180968], 
             UndirectedEdge[79, 349] -> 
             RGBColor[
              0.518092548976322, 0.6194343382750406, 0.9552648492680336], 
             UndirectedEdge[16, 110] -> 
             RGBColor[
              0.2487192272457111, 0.3787500559180304, 0.9374755640932957], 
             UndirectedEdge[49, 372] -> 
             RGBColor[
              0.25360695200292194`, 0.3838873645375076, 0.9377539127874779], 
             UndirectedEdge[320, 343] -> 
             RGBColor[
              0.7160472963068527, 0.7781008571267078, 0.9723325607195863], 
             UndirectedEdge[221, 358] -> 
             RGBColor[
              0.9452177942477327, 0.9230965860350502, 0.6624178282504138], 
             UndirectedEdge[240, 245] -> 
             RGBColor[
              0.2345526793265548, 0.3638601158439808, 0.9366688001468292], 
             UndirectedEdge[85, 115] -> 
             RGBColor[
              0.2399567828787064, 0.36954017131724737`, 0.9369765558494695], 
             UndirectedEdge[70, 280] -> 
             RGBColor[
              0.2584116720913199, 0.38893742998726233`, 0.9380275344885658], 
             UndirectedEdge[151, 171] -> 
             RGBColor[
              0.294524052203641, 0.4262383567855898, 0.940108081239609], 
             UndirectedEdge[23, 163] -> 
             RGBColor[
              0.22919558870789478`, 0.35822947394460614`, 0.9363637217612019],
              UndirectedEdge[255, 360] -> 
             RGBColor[
              0.28543335040527573`, 0.4171867688467138, 0.9395719503550848], 
             UndirectedEdge[165, 307] -> 
             RGBColor[
              0.7589943744265952, 0.8098564226113569, 0.9253172138967432], 
             UndirectedEdge[81, 169] -> 
             RGBColor[
              0.22020695780518662`, 0.3487818529537441, 0.9358518325287805], 
             UndirectedEdge[44, 316] -> 
             RGBColor[
              0.27611802500026855`, 0.4075479295421829, 0.9390358850925288], 
             UndirectedEdge[195, 337] -> 
             RGBColor[
              0.26521901916211443`, 0.39609238336940045`, 0.9384152028336801],
              UndirectedEdge[316, 390] -> 
             RGBColor[
              0.26028939055795897`, 0.3909110311499271, 0.9381344677774055], 
             UndirectedEdge[39, 177] -> 
             RGBColor[
              0.29750028265951367`, 0.4288050749279245, 0.9402981320155486], 
             UndirectedEdge[45, 190] -> 
             RGBColor[
              0.2683010399450559, 0.3993317826236759, 0.9385907193578275], 
             UndirectedEdge[287, 396] -> 
             RGBColor[
              0.2692564543945499, 0.400335983786869, 0.9386451287973171], 
             UndirectedEdge[136, 343] -> 
             RGBColor[
              0.6703913429941837, 0.7420698478255596, 0.9680310290897323], 
             UndirectedEdge[296, 360] -> 
             RGBColor[
              0.3059566318031602, 0.4387580388470877, 0.9407407208692202], 
             UndirectedEdge[167, 228] -> 
             RGBColor[
              0.32570332239411426`, 0.45419998876459156`, 0.9420598033482018],
              UndirectedEdge[123, 279] -> 
             RGBColor[
              0.9599728871641575, 0.901288321876893, 0.6017603738326488], 
             UndirectedEdge[33, 333] -> 
             RGBColor[
              0.1872509211104506, 0.3141429688541644, 0.9339750349931024], 
             UndirectedEdge[164, 209] -> 
             RGBColor[
              0.24728574846658016`, 0.37724337883335973`, 0.9373939295974659],
              UndirectedEdge[22, 29] -> 
             RGBColor[
              0.2663738031073146, 0.39730613451333674`, 0.9384809660710094], 
             UndirectedEdge[24, 366] -> 
             RGBColor[
              0.9017167350633479, 0.6466004732099342, 0.2397023734046333], 
             UndirectedEdge[178, 319] -> 
             RGBColor[
              0.24278605838252734`, 0.37251391925819094`, 0.9371376789038741],
              UndirectedEdge[294, 368] -> 
             RGBColor[
              0.21277052855345546`, 0.3409656943133277, 0.9354283388841056], 
             UndirectedEdge[13, 69] -> 
             RGBColor[
              0.7259993754166094, 0.7839523785382002, 0.9495242388978706], 
             UndirectedEdge[214, 295] -> 
             RGBColor[
              0.6130802218515281, 0.6797567159185416, 0.9247335360686406], 
             UndirectedEdge[80, 146] -> 
             RGBColor[
              0.4348738177323767, 0.548860724677587, 0.9495460387678236], 
             UndirectedEdge[56, 231] -> 
             RGBColor[
              0.37980957762799716`, 0.5033879783145618, 0.9454223177963867], 
             UndirectedEdge[134, 351] -> 
             RGBColor[
              0.24003567899790235`, 0.3696230961408251, 0.9369810488667414], 
             UndirectedEdge[143, 291] -> 
             RGBColor[
              0.6605679134983766, 0.7344885741946573, 0.9669884297148228], 
             UndirectedEdge[120, 320] -> 
             RGBColor[
              0.6381361673517921, 0.7160721638444079, 0.9653628908870006], 
             UndirectedEdge[132, 220] -> 
             RGBColor[
              0.6373284381573086, 0.7140480166379533, 0.9662348834814941], 
             UndirectedEdge[6, 247] -> 
             RGBColor[
              0.9501775412917424, 0.8286011525137683, 0.3806667888005933], 
             UndirectedEdge[166, 289] -> 
             RGBColor[
              0.8612612060617832, 0.40999762047401866`, 0.2038737104047185], 
             UndirectedEdge[114, 392] -> 
             RGBColor[
              0.2884135464934976, 0.418609972282043, 0.9398042492586839], 
             UndirectedEdge[305, 325] -> 
             RGBColor[
              0.20723516257555488`, 0.3351476737080805, 0.9351131079805042], 
             UndirectedEdge[44, 128] -> 
             RGBColor[
              0.3120848480897295, 0.44373638339990634`, 0.9411432739695049], 
             UndirectedEdge[90, 242] -> 
             RGBColor[
              0.8120763207412868, 0.7420397918675932, 0.6122349694370377], 
             UndirectedEdge[1, 337] -> 
             RGBColor[
              0.3223631828098259, 0.4514173086943011, 0.9418429310198984], 
             UndirectedEdge[74, 224] -> 
             RGBColor[
              0.9001674923644503, 0.8962994775971298, 0.6715446357629462], 
             UndirectedEdge[160, 370] -> 
             RGBColor[
              0.8303471028154521, 0.5479183884634005, 0.5798122246722852], 
             UndirectedEdge[30, 84] -> 
             RGBColor[
              0.1789270231889713, 0.3053940243730791, 0.9335010013205776], 
             UndirectedEdge[293, 299] -> 
             RGBColor[
              0.21267988324051307`, 0.34087042034218046`, 0.9354231767676313],
              UndirectedEdge[186, 399] -> 
             RGBColor[
              0.24167334431028037`, 0.3713443862181124, 0.9370743114835726], 
             UndirectedEdge[163, 371] -> 
             RGBColor[
              0.25850942763125473`, 0.3890401772577931, 0.9380331015219487], 
             UndirectedEdge[90, 138] -> 
             RGBColor[
              0.7625743389841517, 0.45989176227570816`, 0.5687339252858672], 
             UndirectedEdge[71, 286] -> 
             RGBColor[
              0.798684946393064, 0.8430713308000524, 0.9804594287308144], 
             UndirectedEdge[60, 201] -> 
             RGBColor[
              0.3169773146449097, 0.44598337270948407`, 0.9415279039366844], 
             UndirectedEdge[128, 380] -> 
             RGBColor[
              0.2958519089446212, 0.4266745351306104, 0.9402188320996724], 
             UndirectedEdge[54, 128] -> 
             RGBColor[
              0.3891023193866603, 0.5114426050266787, 0.9460142336150148], 
             UndirectedEdge[25, 138] -> 
             RGBColor[
              0.8340269956702107, 0.26255197621162585`, 0.18021759552277578`],
              UndirectedEdge[95, 129] -> 
             RGBColor[
              0.2597315005548766, 0.39032465338441835`, 0.9381026967670542], 
             UndirectedEdge[132, 302] -> 
             RGBColor[
              0.8932496977556434, 0.905911220002762, 0.6928483915783341], 
             UndirectedEdge[15, 100] -> 
             RGBColor[
              0.34023750094859895`, 0.4686666959527124, 0.9429171480552854], 
             UndirectedEdge[33, 63] -> 
             RGBColor[
              0.5687512197366357, 0.5886439817299056, 0.6135098819197802], 
             UndirectedEdge[275, 338] -> 
             RGBColor[
              0.9931945073855819, 0.9905965803379274, 0.7001396493067182], 
             UndirectedEdge[252, 277] -> 
             RGBColor[
              0.2410729775793306, 0.3707133627184349, 0.9370401214864079], 
             UndirectedEdge[146, 192] -> 
             RGBColor[
              0.43991049068666355`, 0.5532232376400468, 0.9498669711147159], 
             UndirectedEdge[237, 254] -> 
             RGBColor[
              0.5239652108029346, 0.6244175883504002, 0.9556676072236672], 
             UndirectedEdge[37, 236] -> 
             RGBColor[
              0.2501608630823501, 0.3802653065873294, 0.9375576631214831], 
             UndirectedEdge[265, 362] -> 
             RGBColor[
              0.4982768620774518, 0.6022414244020411, 0.9540103792474512], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.31424207897729384`, 0.44465323780495364`, 0.9413155746707285],
              UndirectedEdge[341, 379] -> 
             RGBColor[
              0.2212705365436844, 0.3498997416426921, 0.9359124017645142], 
             UndirectedEdge[324, 380] -> 
             RGBColor[
              0.27272415965434393`, 0.4039807618801248, 0.9388426094818522], 
             UndirectedEdge[63, 264] -> 
             RGBColor[
              0.5742960336344989, 0.5944719326980662, 0.6138256508684465], 
             UndirectedEdge[153, 337] -> 
             RGBColor[
              0.30108704647180895`, 0.43298898876801645`, 0.9404872344261885],
              UndirectedEdge[112, 155] -> 
             RGBColor[
              0.31673339546261187`, 0.44837192664657105`, 0.9414171693125639],
              UndirectedEdge[10, 177] -> 
             RGBColor[
              0.34191718866131093`, 0.47057321638600846`, 0.9430076388093683],
              UndirectedEdge[238, 367] -> 
             RGBColor[
              0.2242689013320493, 0.35305121314257126`, 0.9360831542035284], 
             UndirectedEdge[87, 228] -> 
             RGBColor[
              0.32899794708810315`, 0.4576628482092444, 0.9422474273505641], 
             UndirectedEdge[66, 352] -> 
             RGBColor[
              0.983468511290683, 0.9548785202107917, 0.47692950075693274`], 
             UndirectedEdge[86, 386] -> 
             RGBColor[
              0.31994974783175406`, 0.4507870854822257, 0.9416356849958585], 
             UndirectedEdge[52, 133] -> 
             RGBColor[
              0.34195185422260005`, 0.4695411184843201, 0.9430487372114036], 
             UndirectedEdge[105, 112] -> 
             RGBColor[
              0.37313264037284266`, 0.49761047172431544`, 0.944996659789687], 
             UndirectedEdge[4, 258] -> 
             RGBColor[
              0.24256487951038092`, 0.3722814462400146, 0.9371250830943101], 
             UndirectedEdge[141, 339] -> 
             RGBColor[
              0.36291222472736206`, 0.48875806138522676`, 0.9443454239423157],
              UndirectedEdge[251, 282] -> 
             RGBColor[
              0.7345888082776114, 0.7926044746200289, 0.9741756038265081], 
             UndirectedEdge[94, 390] -> 
             RGBColor[
              0.26321162125265696`, 0.393982480890182, 0.9383008844924156], 
             UndirectedEdge[239, 337] -> 
             RGBColor[
              0.304629125717821, 0.43605695978083275`, 0.9407129325836068], 
             UndirectedEdge[80, 243] -> 
             RGBColor[
              0.3113941751763021, 0.44225199630561496`, 0.9411317115948465], 
             UndirectedEdge[366, 382] -> 
             RGBColor[
              0.9000306839899277, 0.6389445090727658, 0.23829549106007777`], 
             UndirectedEdge[99, 306] -> 
             RGBColor[
              0.9742518584397497, 0.947471002545973, 0.6306628392778444], 
             UndirectedEdge[214, 261] -> 
             RGBColor[
              0.5816107316395323, 0.6466802864248125, 0.9229413951560062], 
             UndirectedEdge[21, 60] -> 
             RGBColor[
              0.33522274220732345`, 0.4647748233402267, 0.9425810746009868], 
             UndirectedEdge[60, 159] -> 
             RGBColor[
              0.344481468526375, 0.4727942667206735, 0.9431710324548666], 
             UndirectedEdge[9, 300] -> 
             RGBColor[
              0.8578321079350941, 0.3958398187210729, 0.2010677137447785], 
             UndirectedEdge[114, 369] -> 
             RGBColor[
              0.29316591487643506`, 0.4236050127700691, 0.9400748896075932], 
             UndirectedEdge[112, 350] -> 
             RGBColor[
              0.380831960891249, 0.5042792361782578, 0.945487253684878], 
             UndirectedEdge[18, 357] -> 
             RGBColor[
              0.8104483343258964, 0.8526146189392179, 0.9729726519131952], 
             UndirectedEdge[71, 320] -> 
             RGBColor[
              0.7905070166194959, 0.8366826699063725, 0.9796443291180839], 
             UndirectedEdge[226, 255] -> 
             RGBColor[
              0.24955450248561023`, 0.3796279831546734, 0.9375231317825289], 
             UndirectedEdge[208, 258] -> 
             RGBColor[
              0.24300998977440907`, 0.3727492853491289, 0.9371504314653649], 
             UndirectedEdge[11, 358] -> 
             RGBColor[
              0.9460196672175634, 0.8199629343977746, 0.2948506005623025], 
             UndirectedEdge[274, 299] -> 
             RGBColor[
              0.22242833776812287`, 0.35111666413841447`, 0.9359783368314325],
              UndirectedEdge[147, 372] -> 
             RGBColor[
              0.2681076692483716, 0.3991285377610505, 0.9385797071827175], 
             UndirectedEdge[335, 337] -> 
             RGBColor[
              0.282630755782611, 0.41439322252540617`, 0.9394067754758614], 
             UndirectedEdge[36, 218] -> 
             RGBColor[
              0.7148705349959443, 0.7760303162882036, 0.9733069680605333], 
             UndirectedEdge[262, 300] -> 
             RGBColor[
              0.9143198191766551, 0.7735717057130247, 0.6093343830407926], 
             UndirectedEdge[109, 136] -> 
             RGBColor[
              0.8063392816861509, 0.8465292984919313, 0.8553084156056971], 
             UndirectedEdge[219, 241] -> 
             RGBColor[
              0.36907489621161843`, 0.49245160059313714`, 0.9447983082263991],
              UndirectedEdge[37, 348] -> 
             RGBColor[
              0.2563773742968305, 0.38679925402332427`, 0.9379116842386436], 
             UndirectedEdge[291, 384] -> 
             RGBColor[
              0.7224597094549363, 0.7831102830141358, 0.9729716901347794], 
             UndirectedEdge[10, 241] -> 
             RGBColor[
              0.32644391245681637`, 0.4555267851602728, 0.9420818996386419], 
             UndirectedEdge[131, 314] -> 
             RGBColor[
              0.9241390802378358, 0.8369963141242439, 0.6246293196235244], 
             UndirectedEdge[1, 41] -> 
             RGBColor[
              0.3504016747423545, 0.4779220517867386, 0.943548262759916], 
             UndirectedEdge[78, 400] -> 
             RGBColor[
              0.6157274285874001, 0.4172598139869824, 0.5668748799123404], 
             UndirectedEdge[191, 357] -> 
             RGBColor[
              0.6772717325975683, 0.7478090920518159, 0.9684677749072899], 
             UndirectedEdge[215, 352] -> 
             RGBColor[
              0.906721166296464, 0.5695838616411621, 0.3855978109611532], 
             UndirectedEdge[96, 369] -> 
             RGBColor[
              0.27218271865818583`, 0.40341167306382075`, 0.9388117752181111],
              UndirectedEdge[212, 293] -> 
             RGBColor[
              0.2110641194014849, 0.3391721501020175, 0.935331161407307], 
             UndirectedEdge[66, 107] -> 
             RGBColor[
              0.906000283356856, 0.6111511383099929, 0.2669776426492963], 
             UndirectedEdge[146, 159] -> 
             RGBColor[
              0.433382915877228, 0.5475693804255631, 0.9494510398199664], 
             UndirectedEdge[11, 207] -> 
             RGBColor[
              0.931659240059644, 0.7667586905843885, 0.26386962426942273`], 
             UndirectedEdge[99, 218] -> 
             RGBColor[
              0.9440956875300477, 0.9571661739174645, 0.9565961673645738], 
             UndirectedEdge[131, 217] -> 
             RGBColor[
              0.8726459244985081, 0.4533824718485052, 0.21298193244244573`], 
             UndirectedEdge[81, 163] -> 
             RGBColor[
              0.23234434831161116`, 0.36153901993100174`, 0.9365430389624612],
              UndirectedEdge[50, 54] -> 
             RGBColor[
              0.4530695590105145, 0.5668252864420751, 0.9500963936878091], 
             UndirectedEdge[120, 286] -> 
             RGBColor[
              0.6463140971253603, 0.7224608247380875, 0.966177990499731], 
             UndirectedEdge[17, 253] -> 
             RGBColor[
              0.43861619159981363`, 0.5520971476660097, 0.9497858901980598], 
             UndirectedEdge[45, 365] -> 
             RGBColor[
              0.2758699057154388, 0.4072871404421556, 0.9390217550663172], 
             UndirectedEdge[35, 188] -> 
             RGBColor[
              0.27406348456255775`, 0.4053884772767613, 0.9389188820540213], 
             UndirectedEdge[99, 279] -> 
             RGBColor[
              0.9618886205302903, 0.9027170726846294, 0.5985175369470697], 
             UndirectedEdge[107, 363] -> 
             RGBColor[
              0.8508650866892753, 0.3855165088466559, 0.1960887969103411], 
             UndirectedEdge[105, 271] -> 
             RGBColor[
              0.36206599633926584`, 0.4878440595940245, 0.9442981318263466], 
             UndirectedEdge[191, 219] -> 
             RGBColor[
              0.5630206032370957, 0.6553990201614963, 0.9591704044347413], 
             UndirectedEdge[177, 339] -> 
             RGBColor[
              0.34383450141698674`, 0.4722338963280338, 0.9431298082827468], 
             UndirectedEdge[80, 167] -> 
             RGBColor[
              0.30898293281547473`, 0.43971762770278966`, 0.9409943949095109],
              UndirectedEdge[48, 56] -> 
             RGBColor[
              0.43818896314994105`, 0.5539589886879809, 0.9491419911499963], 
             UndirectedEdge[42, 136] -> 
             RGBColor[
              0.7754039881303256, 0.825013733522431, 0.9782569627328132], 
             UndirectedEdge[77, 102] -> 
             RGBColor[
              0.8243310697046711, 0.5080541422905515, 0.574849473505362], 
             UndirectedEdge[73, 203] -> 
             RGBColor[
              0.2672567761777972, 0.39823419519414005`, 0.9385312500811318], 
             UndirectedEdge[35, 284] -> 
             RGBColor[
              0.26251957032631373`, 0.3932550914880322, 0.9382614732159579], 
             UndirectedEdge[274, 367] -> 
             RGBColor[
              0.22502133411732347`, 0.3538420677068884, 0.9361260041375251], 
             UndirectedEdge[33, 310] -> 
             RGBColor[
              0.18075976862012855`, 0.3073203560239972, 0.9336053734615781], 
             UndirectedEdge[175, 295] -> 
             RGBColor[
              0.21065974573871524`, 0.33874712774367555`, 0.9353081329254295],
              UndirectedEdge[70, 75] -> 
             RGBColor[
              0.2609941288153654, 0.3916517557414475, 0.9381746015785979], 
             UndirectedEdge[57, 258] -> 
             RGBColor[
              0.26307034244570515`, 0.39383398790648194`, 0.9382928388733629],
              UndirectedEdge[70, 145] -> 
             RGBColor[
              0.2579170969731607, 0.3884176001802034, 0.937999369167245], 
             UndirectedEdge[12, 336] -> 
             RGBColor[
              0.21472177259901426`, 0.343016575521228, 0.9355394593458932], 
             UndirectedEdge[18, 216] -> 
             RGBColor[
              0.8021540700559975, 0.8461350766528297, 0.9721459571650781], 
             UndirectedEdge[158, 311] -> 
             RGBColor[
              0.5112449698673547, 0.6140907237185725, 0.9546662232614405], 
             UndirectedEdge[8, 36] -> 
             RGBColor[
              0.41499862525248465`, 0.5320708731128857, 0.9481621689265505], 
             UndirectedEdge[119, 200] -> 
             RGBColor[
              0.2555790109882331, 0.38596012356683096`, 0.9378662186292916], 
             UndirectedEdge[181, 362] -> 
             RGBColor[
              0.4859856594800335, 0.59226287242109, 0.9530427707548238], 
             UndirectedEdge[9, 306] -> 
             RGBColor[
              0.8980217768542582, 0.5550152880766823, 0.25581485333926096`], 
             UndirectedEdge[82, 253] -> 
             RGBColor[
              0.3604664667584644, 0.48663966875993736`, 0.9441895824072364], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.47490752561281135`, 0.5839962194337451, 0.9519697664459024], 
             UndirectedEdge[146, 314] -> 
             RGBColor[
              0.7305716091219763, 0.7886632000372383, 0.9746741748807553], 
             UndirectedEdge[27, 277] -> 
             RGBColor[
              0.277614773953709, 0.4091211075916136, 0.9391211227311855], 
             UndirectedEdge[6, 302] -> 
             RGBColor[
              0.9903122885265428, 0.9784619909329613, 0.461186699710061], 
             UndirectedEdge[93, 296] -> 
             RGBColor[
              0.27337982614775685`, 0.40466990893635857`, 0.9388799487186803],
              UndirectedEdge[153, 284] -> 
             RGBColor[
              0.2807144253547577, 0.4115760722752118, 0.9393270437921646], 
             UndirectedEdge[43, 199] -> 
             RGBColor[
              0.2266190062266405, 0.3555213223920431, 0.9362169892006067], 
             UndirectedEdge[213, 250] -> 
             RGBColor[
              0.9495976653580405, 0.8370624678097084, 0.5459950352795185], 
             UndirectedEdge[3, 232] -> 
             RGBColor[
              0.4478181508511241, 0.5603378585517222, 0.9502975085529524], 
             UndirectedEdge[5, 235] -> 
             RGBColor[
              0.7907683520113988, 0.8366469590661592, 0.9797340301887447], 
             UndirectedEdge[25, 391] -> 
             RGBColor[
              0.8345509525864179, 0.2665793386689794, 0.18071933725746053`], 
             UndirectedEdge[288, 341] -> 
             RGBColor[
              0.2333048519876323, 0.3625485701939505, 0.9365977382258728], 
             UndirectedEdge[181, 265] -> 
             RGBColor[
              0.5796034948121, 0.6695872537851715, 0.9600476567506184], 
             UndirectedEdge[295, 363] -> 
             RGBColor[
              0.5524499218387339, 0.42033901047071287`, 0.5720521832312901], 
             UndirectedEdge[278, 284] -> 
             RGBColor[
              0.24820685681048946`, 0.3782115221044505, 0.9374463853549939], 
             UndirectedEdge[167, 351] -> 
             RGBColor[
              0.2646469792533301, 0.39549113315584294`, 0.938382626007132], 
             UndirectedEdge[198, 311] -> 
             RGBColor[
              0.6729318339898602, 0.7425873401033549, 0.9693093430316602], 
             UndirectedEdge[54, 328] -> 
             RGBColor[
              0.38071433549214345`, 0.504177354969577, 0.9454797586984591], 
             UndirectedEdge[261, 310] -> 
             RGBColor[
              0.18101326007132248`, 0.3075867916114884, 0.9336198094247166], 
             UndirectedEdge[68, 319] -> 
             RGBColor[
              0.2591541477712746, 0.38971781900257185`, 0.9380698173801449], 
             UndirectedEdge[100, 141] -> 
             RGBColor[
              0.3683390164516885, 0.49345847561835543`, 0.9446912143122663], 
             UndirectedEdge[139, 325] -> 
             RGBColor[
              0.21136919529828035`, 0.33949280421247857`, 0.9353485350283102],
              UndirectedEdge[123, 338] -> 
             RGBColor[
              0.9842922541931751, 0.9852712070496027, 0.7740485310892328], 
             UndirectedEdge[317, 370] -> 
             RGBColor[
              0.9109218435003366, 0.9293228266692952, 0.8943803638429948], 
             UndirectedEdge[160, 400] -> 
             RGBColor[
              0.6095442446912597, 0.3697331530727862, 0.5609538560304888], 
             UndirectedEdge[150, 266] -> 
             RGBColor[
              0.2627993543398047, 0.39354916222554226`, 0.9382774065016228], 
             UndirectedEdge[134, 201] -> 
             RGBColor[
              0.255376576823433, 0.3857473524245587, 0.9378546903030808], 
             UndirectedEdge[161, 251] -> 
             RGBColor[
              0.6268762447587527, 0.7046334098478555, 0.9658130763902817], 
             UndirectedEdge[86, 371] -> 
             RGBColor[
              0.2862909803459218, 0.418240350613087, 0.9396152198499249], 
             UndirectedEdge[105, 350] -> 
             RGBColor[
              0.4250434301807523, 0.5425729887437677, 0.948304369413338], 
             UndirectedEdge[54, 362] -> 
             RGBColor[
              0.4283252562737149, 0.5454155415561164, 0.9485134844699766], 
             UndirectedEdge[4, 208] -> 
             RGBColor[
              0.23264160776787357`, 0.36185145846687167`, 0.9365599674487393],
              UndirectedEdge[176, 294] -> 
             RGBColor[
              0.21429151975408078`, 0.34256435250159695`, 0.9355149570828762],
              UndirectedEdge[113, 170] -> 
             RGBColor[
              0.6207426403130438, 0.7003977045332692, 0.9649634716556403], 
             UndirectedEdge[14, 205] -> 
             RGBColor[
              0.9948127950472943, 0.9913250536932577, 0.6776287249236647], 
             UndirectedEdge[262, 306] -> 
             RGBColor[
              0.9545094880958191, 0.9327471750686342, 0.664081522635275], 
             UndirectedEdge[47, 128] -> 
             RGBColor[
              0.3800525355791988, 0.5036041371480152, 0.945437589393213], 
             UndirectedEdge[257, 382] -> 
             RGBColor[
              0.8606940459931985, 0.4040219113453448, 0.20326730826890227`], 
             UndirectedEdge[165, 228] -> 
             RGBColor[
              0.4503029757321284, 0.5622948057743279, 0.9505097967266875], 
             UndirectedEdge[72, 341] -> 
             RGBColor[
              0.22465511090045148`, 0.353457143886063, 0.936105148267103], 
             UndirectedEdge[50, 116] -> 
             RGBColor[
              0.4351844866677396, 0.551334135708637, 0.9489567726932759], 
             UndirectedEdge[230, 247] -> 
             RGBColor[
              0.9379323861994966, 0.7878165939520326, 0.28877547346743154`], 
             UndirectedEdge[45, 100] -> 
             RGBColor[
              0.33605658973236274`, 0.46427229317936647`, 0.9426790513466246],
              UndirectedEdge[95, 386] -> 
             RGBColor[
              0.3105708355384495, 0.4409292540045774, 0.9411015698156122], 
             UndirectedEdge[182, 244] -> 
             RGBColor[
              0.27406524356197104`, 0.4053903260966717, 0.9389189822264357], 
             UndirectedEdge[104, 382] -> 
             RGBColor[
              0.9163275048198573, 0.7044047275562138, 0.25145220082553266`], 
             UndirectedEdge[58, 210] -> 
             RGBColor[
              0.2993673513669953, 0.4319844456460439, 0.9403598998348177], 
             UndirectedEdge[102, 370] -> 
             RGBColor[
              0.8252568296209774, 0.5087923181187306, 0.5749377733126149], 
             UndirectedEdge[1, 161] -> 
             RGBColor[
              0.3957098398241182, 0.5171657071259712, 0.9464352589744887], 
             UndirectedEdge[153, 356] -> 
             RGBColor[
              0.4179045828513193, 0.5346231354649491, 0.9483375893388631], 
             UndirectedEdge[1, 154] -> 
             RGBColor[
              0.39507053133992803`, 0.5166119702495444, 0.9463945228031945], 
             UndirectedEdge[341, 399] -> 
             RGBColor[
              0.22823136465623345`, 0.3572160133309742, 0.9363088106279014], 
             UndirectedEdge[373, 395] -> 
             RGBColor[
              0.2616949498810116, 0.3923883631160637, 0.9382145123015146], 
             UndirectedEdge[190, 266] -> 
             RGBColor[
              0.24805045871485498`, 0.3780471377897267, 0.9374374787148178], 
             UndirectedEdge[73, 85] -> 
             RGBColor[
              0.24221172142071856`, 0.3719102546962633, 0.9371049712635544], 
             UndirectedEdge[221, 250] -> 
             RGBColor[
              0.955043066437527, 0.9649644792718597, 0.9185889663100797], 
             UndirectedEdge[23, 353] -> 
             RGBColor[
              0.21189878814995255`, 0.34004943987771225`, 0.9353786945577505],
              UndirectedEdge[171, 270] -> 
             RGBColor[
              0.2613998670743656, 0.3920782123769482, 0.9381977077722119], 
             UndirectedEdge[277, 396] -> 
             RGBColor[
              0.26805617252313807`, 0.399074411437749, 0.9385767745203981], 
             UndirectedEdge[315, 371] -> 
             RGBColor[
              0.25765991596594773`, 0.388147286635405, 0.9379847230893494], 
             UndirectedEdge[207, 391] -> 
             RGBColor[
              0.8801233042529734, 0.4784967588439868, 0.2188121666480132], 
             UndirectedEdge[160, 247] -> 
             RGBColor[
              0.8682425607038025, 0.44830305029724704`, 0.2099476795487854], 
             UndirectedEdge[193, 232] -> 
             RGBColor[
              0.6739481277148399, 0.7434424430617759, 0.9693547854990241], 
             UndirectedEdge[22, 91] -> 
             RGBColor[
              0.2774698045998931, 0.40896873560916513`, 0.9391128669409485], 
             UndirectedEdge[78, 247] -> 
             RGBColor[
              0.874425744599943, 0.49582971121144337`, 0.21586870343063702`], 
             UndirectedEdge[87, 192] -> 
             RGBColor[
              0.3173142304637505, 0.44754300010990244`, 0.9415029512587653], 
             UndirectedEdge[226, 294] -> 
             RGBColor[
              0.22569678935260098`, 0.35455201398550057`, 0.9361644703139277],
              UndirectedEdge[177, 311] -> 
             RGBColor[
              0.42064126980492156`, 0.5369664823599833, 0.9485194381294991], 
             UndirectedEdge[189, 200] -> 
             RGBColor[
              0.28560319899075254`, 0.41751744880094743`, 0.9395760517192293],
              UndirectedEdge[67, 184] -> 
             RGBColor[
              0.2153543932680198, 0.3436814999548199, 0.9355754861571146], 
             UndirectedEdge[33, 256] -> 
             RGBColor[
              0.202124876078153, 0.3297764385884332, 0.9348220847244686], 
             UndirectedEdge[176, 226] -> 
             RGBColor[
              0.22722875741095702`, 0.3561622095472178, 0.9362517136285073], 
             UndirectedEdge[145, 162] -> 
             RGBColor[
              0.2420540274215789, 0.3717445083047905, 0.9370959908235907], 
             UndirectedEdge[286, 343] -> 
             RGBColor[
              0.7242252260804207, 0.7844895180203877, 0.9731476603323168], 
             UndirectedEdge[13, 18] -> 
             RGBColor[
              0.9544933475167275, 0.9655817936050558, 0.9619150720050708], 
             UndirectedEdge[86, 308] -> 
             RGBColor[
              0.28081236703944734`, 0.4124819806638359, 0.9393032209270034], 
             UndirectedEdge[364, 377] -> 
             RGBColor[
              0.3822045767059832, 0.5054681270073037, 0.9455747155508364], 
             UndirectedEdge[90, 152] -> 
             RGBColor[
              0.4447109838202162, 0.5402113672268555, 0.9525399126533038], 
             UndirectedEdge[1, 153] -> 
             RGBColor[
              0.33870689706262624`, 0.4677926231571751, 0.9428030818674495], 
             UndirectedEdge[92, 114] -> 
             RGBColor[
              0.3082708613262549, 0.43948126919774927`, 0.9409350939621447], 
             UndirectedEdge[132, 219] -> 
             RGBColor[
              0.6232051027562657, 0.7024156086050097, 0.9651690328906872], 
             UndirectedEdge[107, 215] -> 
             RGBColor[
              0.829252938362637, 0.22585647974036333`, 0.17564595285351675`], 
             UndirectedEdge[240, 319] -> 
             RGBColor[
              0.24039509168830792`, 0.37000086166652213`, 0.9370015168877566],
              UndirectedEdge[58, 110] -> 
             RGBColor[
              0.2771944683256158, 0.40867933972757164`, 0.939097186947452], 
             UndirectedEdge[67, 85] -> 
             RGBColor[
              0.22712666696496037`, 0.35605490601556716`, 0.9362458997286371],
              UndirectedEdge[125, 344] -> 
             RGBColor[
              0.2993073040655987, 0.4308227000023955, 0.9403967065336283], 
             UndirectedEdge[198, 219] -> 
             RGBColor[
              0.6368387366010516, 0.7131188895622445, 0.9665139522992866], 
             UndirectedEdge[16, 325] -> 
             RGBColor[
              0.22671411419860138`, 0.35562128690076766`, 0.9362224054589102],
              UndirectedEdge[119, 390] -> 
             RGBColor[
              0.2533988208527428, 0.3836686055023921, 0.9377420600263777], 
             UndirectedEdge[7, 153] -> 
             RGBColor[
              0.3534178774592668, 0.48053453498137155`, 0.9437404525299142], 
             UndirectedEdge[23, 164] -> 
             RGBColor[
              0.22797821780387265`, 0.3569499399387055, 0.9362943942891566], 
             UndirectedEdge[46, 373] -> 
             RGBColor[
              0.26731905714517273`, 0.3982996564396932, 0.9385347968900875], 
             UndirectedEdge[301, 316] -> 
             RGBColor[
              0.2555487063727525, 0.3859282714945373, 0.9378644928262717], 
             UndirectedEdge[22, 150] -> 
             RGBColor[
              0.28145958694833023`, 0.41316224982418415`, 0.9393400791433381],
              UndirectedEdge[161, 327] -> 
             RGBColor[
              0.3750143899762539, 0.4992403486513052, 0.9451165632104506], 
             UndirectedEdge[123, 281] -> 
             RGBColor[
              0.8031450913153519, 0.8462354724290008, 0.9462830761380823], 
             UndirectedEdge[111, 160] -> 
             RGBColor[
              0.8517778667942718, 0.37434165466445646`, 0.19625056684916897`],
              UndirectedEdge[277, 287] -> 
             RGBColor[
              0.25901311175833214`, 0.3895695812107696, 0.9380617855878519], 
             UndirectedEdge[48, 120] -> 
             RGBColor[
              0.49591060473188847`, 0.6008847208403402, 0.9536681725336434], 
             UndirectedEdge[6, 224] -> 
             RGBColor[
              0.9845045256450395, 0.9588710430060774, 0.43862463761941295`], 
             UndirectedEdge[103, 313] -> 
             RGBColor[
              0.31368725505562867`, 0.4437237541060531, 0.9412966590550009], 
             UndirectedEdge[8, 60] -> 
             RGBColor[
              0.33392414851101215`, 0.4636500467496988, 0.9424983293589592], 
             UndirectedEdge[284, 392] -> 
             RGBColor[
              0.24597365109495675`, 0.3758642813040053, 0.9373192075932261], 
             UndirectedEdge[218, 279] -> 
             RGBColor[
              0.9278567069516805, 0.8766750653657154, 0.6332052588371474], 
             UndirectedEdge[135, 221] -> 
             RGBColor[
              0.7125684826637311, 0.7740760557086418, 0.9732239792621271], 
             UndirectedEdge[95, 309] -> 
             RGBColor[
              0.2762844897757238, 0.4077228945756627, 0.9390453650152284], 
             UndirectedEdge[80, 385] -> 
             RGBColor[
              0.4549187217473041, 0.5651340807695402, 0.9511240470387816], 
             UndirectedEdge[272, 398] -> 
             RGBColor[
              0.7932211653132651, 0.8392589768677534, 0.976436715616906], 
             UndirectedEdge[33, 264] -> 
             RGBColor[
              0.18448620056776344`, 0.31123707227039327`, 0.9338175882482339],
              UndirectedEdge[76, 366] -> 
             RGBColor[
              0.8741124408312237, 0.5032302339331254, 0.2159628369001264], 
             UndirectedEdge[41, 258] -> 
             RGBColor[
              0.29687678880049106`, 0.4264012168061446, 0.9403266470848042], 
             UndirectedEdge[174, 232] -> 
             RGBColor[
              0.6270810139261389, 0.7068104580353534, 0.9646885621008761], 
             UndirectedEdge[61, 307] -> 
             RGBColor[
              0.9892929392100926, 0.9881701251038566, 0.7056981044009731], 
             UndirectedEdge[35, 392] -> 
             RGBColor[
              0.2644951314363644, 0.3953315314725043, 0.9383739784985945], 
             UndirectedEdge[212, 259] -> 
             RGBColor[
              0.2109589325174653, 0.33906159201767927`, 0.935325171169872], 
             UndirectedEdge[73, 110] -> 
             RGBColor[
              0.24934696023893294`, 0.3794098430944771, 0.9375113125586119], 
             UndirectedEdge[122, 228] -> 
             RGBColor[
              0.40697238168033323`, 0.5269207548100117, 0.9471528981824919], 
             UndirectedEdge[41, 203] -> 
             RGBColor[
              0.31610894590117855`, 0.4466154333081559, 0.9414218899802616], 
             UndirectedEdge[361, 385] -> 
             RGBColor[
              0.46552378312677223`, 0.5743196519105522, 0.9517997921721937], 
             UndirectedEdge[9, 269] -> 
             RGBColor[
              0.909363183463878, 0.5929294140972693, 0.329048956685827], 
             UndirectedEdge[192, 228] -> 
             RGBColor[
              0.35617346073846823`, 0.48292128271817314`, 0.9439160358597984],
              UndirectedEdge[47, 265] -> 
             RGBColor[
              0.5128933077983199, 0.6149014550415344, 0.9549417262439694], 
             UndirectedEdge[338, 398] -> 
             RGBColor[
              0.966856888277283, 0.9722679396973218, 0.803562057713115], 
             UndirectedEdge[71, 79] -> 
             RGBColor[
              0.730962985173496, 0.7893766931257962, 0.9742494771038676], 
             UndirectedEdge[77, 78] -> 
             RGBColor[
              0.8356045267952863, 0.5947068735494174, 0.5856449487468838], 
             UndirectedEdge[89, 164] -> 
             RGBColor[
              0.2305606666537099, 0.3596642574165986, 0.9364414609307642], 
             UndirectedEdge[123, 235] -> 
             RGBColor[
              0.8571949059772741, 0.8886183762780113, 0.9515616992620775], 
             UndirectedEdge[72, 393] -> 
             RGBColor[
              0.22527325394479547`, 0.3541068514182011, 0.9361403505990177], 
             UndirectedEdge[240, 371] -> 
             RGBColor[
              0.2556260580342823, 0.3860095729951837, 0.9378688978889642], 
             UndirectedEdge[196, 303] -> 
             RGBColor[
              0.29376792821553643`, 0.42609909688992764`, 0.9400410209699464],
              UndirectedEdge[105, 170] -> 
             RGBColor[
              0.4311568725166687, 0.5478681452245924, 0.9486939125530778], 
             UndirectedEdge[195, 208] -> 
             RGBColor[
              0.239390712068561, 0.3689451950048222, 0.9369443189542583], 
             UndirectedEdge[100, 180] -> 
             RGBColor[
              0.3714420538172285, 0.49614617062119337`, 0.9448889371092903], 
             UndirectedEdge[39, 355] -> 
             RGBColor[
              0.25200661552040216`, 0.3822053094271858, 0.9376627759922841], 
             UndirectedEdge[244, 397] -> 
             RGBColor[
              0.2546928621186111, 0.3850287249197748, 0.9378157537621064], 
             UndirectedEdge[225, 355] -> 
             RGBColor[
              0.24401463577453056`, 0.373805231993492, 0.9372076445688313], 
             UndirectedEdge[335, 354] -> 
             RGBColor[
              0.28014580760645524`, 0.41178138443745216`, 0.9392652613533807],
              UndirectedEdge[97, 100] -> 
             RGBColor[
              0.4094492665548738, 0.5290661079964851, 0.9473107230964745], 
             UndirectedEdge[2, 107] -> 
             RGBColor[
              0.828834437069773, 0.222639695414975, 0.17524519554284063`], 
             UndirectedEdge[128, 225] -> 
             RGBColor[
              0.2916606290262991, 0.42226923419395845`, 0.939980144908767], 
             UndirectedEdge[96, 228] -> 
             RGBColor[
              0.3273843328541551, 0.4559668373403135, 0.9421555344070691], 
             UndirectedEdge[262, 307] -> 
             RGBColor[
              0.9619414175862754, 0.970962445386637, 0.9415105792405329], 
             UndirectedEdge[86, 334] -> 
             RGBColor[
              0.28096769579564274`, 0.4126452410350092, 0.9393120666698803], 
             UndirectedEdge[255, 399] -> 
             RGBColor[
              0.24767699728620676`, 0.3776546061493952, 0.937416210638943], 
             UndirectedEdge[138, 242] -> 
             RGBColor[
              0.8688448581678534, 0.4318314305529642, 0.2096571104877158], 
             UndirectedEdge[27, 396] -> 
             RGBColor[
              0.28785811658992677`, 0.419887510167713, 0.9397044659406507], 
             UndirectedEdge[163, 209] -> 
             RGBColor[
              0.2485031193706023, 0.3785229128392603, 0.9374632570695112], 
             UndirectedEdge[63, 202] -> 
             RGBColor[
              0.9074503393274316, 0.6529677356997123, 0.2475510699614376], 
             UndirectedEdge[347, 372] -> 
             RGBColor[
              0.26576379522245486`, 0.3966649775496154, 0.9384462270243925], 
             UndirectedEdge[174, 275] -> 
             RGBColor[
              0.8603530123804088, 0.8894563784374243, 0.877080294609712], 
             UndirectedEdge[209, 315] -> 
             RGBColor[
              0.24765360770529532`, 0.37763002221687225`, 0.9374148786369118],
              UndirectedEdge[177, 374] -> 
             RGBColor[
              0.29900611365793894`, 0.43038779878246913`, 0.9403838868632315],
              UndirectedEdge[214, 215] -> 
             RGBColor[
              0.9015306453673441, 0.5683408458182889, 0.5392279021919928], 
             UndirectedEdge[160, 185] -> 
             RGBColor[
              0.8265840327508944, 0.20534210168661424`, 0.17309020582561438`],
              UndirectedEdge[63, 268] -> 
             RGBColor[
              0.8879400264016856, 0.5030029210787892, 0.2288679722699964], 
             UndirectedEdge[48, 196] -> 
             RGBColor[
              0.3616835055171287, 0.4866932494532377, 0.9443037663378753], 
             UndirectedEdge[34, 95] -> 
             RGBColor[
              0.29703377047989377`, 0.4292041286435296, 0.9402390000004376], 
             UndirectedEdge[84, 333] -> 
             RGBColor[
              0.18724373492288626`, 0.3141354157154036, 0.9339746257503516], 
             UndirectedEdge[102, 224] -> 
             RGBColor[
              0.8974792718626248, 0.5394468704448865, 0.26303107700793477`], 
             UndirectedEdge[105, 326] -> 
             RGBColor[
              0.37836717266856673`, 0.5021443605036287, 0.9453301995588554], 
             UndirectedEdge[134, 236] -> 
             RGBColor[
              0.24242453355158805`, 0.3721339337388756, 0.9371170905995801], 
             UndirectedEdge[92, 161] -> 
             RGBColor[
              0.35955024405905767`, 0.48389689314418627`, 0.9442025708853012],
              UndirectedEdge[77, 185] -> 
             RGBColor[
              0.8265277938578538, 0.5249391267425765, 0.5769530590352949], 
             UndirectedEdge[178, 329] -> 
             RGBColor[
              0.23956363455757862`, 0.36912694750469877`, 0.9369541666341921],
              UndirectedEdge[185, 400] -> 
             RGBColor[
              0.6066506956499677, 0.3474920671801415, 0.5581829902007515], 
             UndirectedEdge[317, 333] -> 
             RGBColor[
              0.5930937593564782, 0.6566344401985723, 0.8697228003417041], 
             UndirectedEdge[106, 215] -> 
             RGBColor[
              0.8838915069303948, 0.5551856052534505, 0.5690863625416396], 
             UndirectedEdge[14, 340] -> 
             RGBColor[
              0.9940676030184292, 0.9897195276507893, 0.5956733829454577], 
             UndirectedEdge[233, 358] -> 
             RGBColor[
              0.8930174526264201, 0.5204305413924555, 0.24838903272095686`], 
             UndirectedEdge[74, 191] -> 
             RGBColor[
              0.7517634193974077, 0.8060404672296411, 0.9758823517148281], 
             UndirectedEdge[53, 244] -> 
             RGBColor[
              0.27464006789181306`, 0.4059945029133032, 0.9389517176216438], 
             UndirectedEdge[4, 16] -> 
             RGBColor[
              0.23702850407735238`, 0.36646236463342485`, 0.9368097947037326],
              UndirectedEdge[149, 274] -> 
             RGBColor[
              0.22547330397154366`, 0.35431711668021776`, 0.9361517431520935],
              UndirectedEdge[326, 335] -> 
             RGBColor[
              0.3099542075105004, 0.4402786337315509, 0.9410665454863245], 
             UndirectedEdge[30, 77] -> 
             RGBColor[
              0.5041460680446381, 0.5860856357063153, 0.9585438899509009], 
             UndirectedEdge[129, 229] -> 
             RGBColor[
              0.24229031603850887`, 0.3719928626227475, 0.9371094471107673], 
             UndirectedEdge[216, 219] -> 
             RGBColor[
              0.5531447091768378, 0.647683896662048, 0.958186067610292], 
             UndirectedEdge[138, 233] -> 
             RGBColor[
              0.8184005545424529, 0.14244030215351539`, 0.165253697851294], 
             UndirectedEdge[28, 44] -> 
             RGBColor[
              0.29312282823703784`, 0.42542105591082463`, 0.9400042834805107],
              UndirectedEdge[163, 227] -> 
             RGBColor[
              0.23994763052693538`, 0.3695305516152434, 0.9369760346365759], 
             UndirectedEdge[15, 335] -> 
             RGBColor[
              0.2921895478533735, 0.4244401190541993, 0.9399511345433256], 
             UndirectedEdge[257, 268] -> 
             RGBColor[
              0.8199630848530925, 0.15445059482623982`, 0.16674997864138813`],
              UndirectedEdge[217, 279] -> 
             RGBColor[
              0.8842376547290044, 0.4993398194973086, 0.22230891067878217`], 
             UndirectedEdge[93, 119] -> 
             RGBColor[
              0.24286823945996167`, 0.3726002967811557, 0.9371423589946579], 
             UndirectedEdge[67, 305] -> 
             RGBColor[
              0.20792423756527648`, 0.33587193521215575`, 0.9351523497817738],
              UndirectedEdge[153, 195] -> 
             RGBColor[
              0.2815627334149148, 0.41246769783227444`, 0.9393753536812313], 
             UndirectedEdge[50, 135] -> 
             RGBColor[
              0.478712840814817, 0.5876796757980098, 0.9521051748933094], 
             UndirectedEdge[68, 334] -> 
             RGBColor[
              0.2690618295669699, 0.40013142075315566`, 0.938634045201308], 
             UndirectedEdge[95, 308] -> 
             RGBColor[
              0.2714334547461428, 0.4026241491861876, 0.9387691057467569], 
             UndirectedEdge[17, 36] -> 
             RGBColor[
              0.5275969503288876, 0.6273659981055699, 0.9559535110626505], 
             UndirectedEdge[41, 361] -> 
             RGBColor[
              0.34822341852427197`, 0.4760353557329764, 0.9434094661998561], 
             UndirectedEdge[117, 371] -> 
             RGBColor[
              0.31078136056287864`, 0.44021172480761495`, 0.9411479331302521],
              UndirectedEdge[89, 304] -> 
             RGBColor[
              0.21884062978169738`, 0.3473457555708567, 0.9357740221691438], 
             UndirectedEdge[267, 272] -> 
             RGBColor[
              0.6091079366672787, 0.6934689353256587, 0.9624191392814057], 
             UndirectedEdge[20, 158] -> 
             RGBColor[
              0.4553874406509526, 0.5675033157176284, 0.9506114604100135], 
             UndirectedEdge[30, 62] -> 
             RGBColor[
              0.17899764558147852`, 0.30546825298532254`, 0.9335050231613544],
              UndirectedEdge[197, 310] -> 
             RGBColor[
              0.5856647922314719, 0.6494240169162264, 0.8848951542933734], 
             UndirectedEdge[142, 268] -> 
             RGBColor[
              0.8194514867475214, 0.1505182276031009, 0.16626007171772583`], 
             UndirectedEdge[78, 213] -> 
             RGBColor[
              0.8764060316711535, 0.5036808895572449, 0.2174620888914447], 
             UndirectedEdge[48, 71] -> 
             RGBColor[
              0.6482814539995922, 0.7214952269023049, 0.9679496107647267], 
             UndirectedEdge[262, 269] -> 
             RGBColor[
              0.965850894705439, 0.9706613010892211, 0.7373156259818411], 
             UndirectedEdge[27, 376] -> 
             RGBColor[
              0.3679050083022842, 0.49203509004620194`, 0.9447019126873052], 
             UndirectedEdge[245, 292] -> 
             RGBColor[
              0.2204587636622521, 0.3490465168749334, 0.935866172499827], 
             UndirectedEdge[142, 217] -> 
             RGBColor[
              0.8222048215005642, 0.17168156503396934`, 0.16889666818668636`],
              UndirectedEdge[142, 363] -> 
             RGBColor[
              0.8420482335881154, 0.3177463123414773, 0.18764576842345915`], 
             UndirectedEdge[121, 130] -> 
             RGBColor[
              0.48180086572832803`, 0.5890215010044231, 0.9526702161686205], 
             UndirectedEdge[217, 300] -> 
             RGBColor[
              0.8564112237192996, 0.3849182800030426, 0.19970707341507446`], 
             UndirectedEdge[25, 109] -> 
             RGBColor[
              0.9214037823681839, 0.6836236479949891, 0.47088987975905927`], 
             UndirectedEdge[40, 146] -> 
             RGBColor[
              0.43732168419070216`, 0.5509809435704429, 0.9497020146539848], 
             UndirectedEdge[18, 140] -> 
             RGBColor[
              0.8085657806265083, 0.8511439536813179, 0.9727850165539047], 
             UndirectedEdge[170, 239] -> 
             RGBColor[
              0.38474227729381244`, 0.5076661557079413, 0.9457364155882924], 
             UndirectedEdge[152, 333] -> 
             RGBColor[
              0.18958831081692415`, 0.31659971363473505`, 0.9341081458790279],
              UndirectedEdge[14, 250] -> 
             RGBColor[
              0.99129214736786, 0.9898691754012934, 0.7359749681160213], 
             UndirectedEdge[55, 159] -> 
             RGBColor[
              0.36748362390558187`, 0.49271757758819734`, 0.9446367094556223],
              UndirectedEdge[234, 331] -> 
             RGBColor[
              0.3954159318032815, 0.5169111387705692, 0.9464165314152937], 
             UndirectedEdge[370, 389] -> 
             RGBColor[
              0.505152375234491, 0.5869084718259839, 0.9586367768062234], 
             UndirectedEdge[119, 316] -> 
             RGBColor[
              0.24738893708713797`, 0.3773518366161024, 0.9373998060367528], 
             UndirectedEdge[89, 227] -> 
             RGBColor[
              0.22675241851123462`, 0.35566154716197895`, 0.9362245868328485],
              UndirectedEdge[246, 254] -> 
             RGBColor[
              0.4566571232556863, 0.569515492226385, 0.9504402532261262], 
             UndirectedEdge[197, 345] -> 
             RGBColor[
              0.5953494141792219, 0.6596031686238084, 0.8854466791861835], 
             UndirectedEdge[231, 234] -> 
             RGBColor[
              0.3237117587462526, 0.454798867157554, 0.9418478143825956], 
             UndirectedEdge[89, 209] -> 
             RGBColor[
              0.23530790735490154`, 0.3646539083859959, 0.9367118092657838], 
             UndirectedEdge[233, 317] -> 
             RGBColor[
              0.9040426479180714, 0.5627946336685001, 0.48467433968140694`], 
             UndirectedEdge[48, 342] -> 
             RGBColor[
              0.5144005472567488, 0.6158956891444403, 0.9551237685400916], 
             UndirectedEdge[24, 104] -> 
             RGBColor[
              0.9180135558932775, 0.712060691693382, 0.25285908317008815`], 
             UndirectedEdge[118, 149] -> 
             RGBColor[
              0.21314012851733694`, 0.34135416730935836`, 0.9354493870552745],
              UndirectedEdge[34, 53] -> 
             RGBColor[
              0.30076648553276153`, 0.4331274488318972, 0.9404515726006413], 
             UndirectedEdge[29, 45] -> 
             RGBColor[
              0.26796415172899, 0.39897769174864406`, 0.938571534072304], 
             UndirectedEdge[35, 208] -> 
             RGBColor[
              0.25706388434981153`, 0.3875208196162586, 0.9379507799705602], 
             UndirectedEdge[69, 191] -> 
             RGBColor[
              0.5835359920161374, 0.6722207850854224, 0.9607394608823273], 
             UndirectedEdge[102, 166] -> 
             RGBColor[
              0.8220330696681408, 0.1703614051878311, 0.16873219843799186`], 
             UndirectedEdge[185, 213] -> 
             RGBColor[
              0.8673292987337209, 0.4339131427504039, 0.20877019917985573`], 
             UndirectedEdge[172, 364] -> 
             RGBColor[
              0.3254772137216906, 0.45565682861361634`, 0.9419848830531403], 
             UndirectedEdge[36, 55] -> 
             RGBColor[
              0.46160497467818506`, 0.5724389504821938, 0.9511318842995795], 
             UndirectedEdge[192, 203] -> 
             RGBColor[
              0.31794365991620344`, 0.4482045703725628, 0.9415387963349251], 
             UndirectedEdge[105, 394] -> 
             RGBColor[
              0.38810603050507936`, 0.5105796696723884, 0.9459507509684641], 
             UndirectedEdge[256, 261] -> 
             RGBColor[
              0.20237836752934693`, 0.3300428741759244, 0.934836520687607], 
             UndirectedEdge[215, 295] -> 
             RGBColor[
              0.5308377735120957, 0.2606789813644203, 0.5516093391744658], 
             UndirectedEdge[219, 357] -> 
             RGBColor[
              0.5614389734467367, 0.6541634389484363, 0.9590127623584092], 
             UndirectedEdge[204, 295] -> 
             RGBColor[
              0.21065717499813985`, 0.33874442573233643`, 0.9353079865255567],
              UndirectedEdge[24, 138] -> 
             RGBColor[
              0.8607479504188854, 0.399132481136813, 0.2031112451403423], 
             UndirectedEdge[135, 376] -> 
             RGBColor[
              0.47083567399736015`, 0.5808793962784845, 0.9515970246612349], 
             UndirectedEdge[127, 305] -> 
             RGBColor[
              0.20669916269368893`, 0.33458430384788407`, 0.9350825835801727],
              UndirectedEdge[54, 158] -> 
             RGBColor[
              0.4775536933364365, 0.5867026096855403, 0.9520238744302849], 
             UndirectedEdge[180, 350] -> 
             RGBColor[
              0.3995063863984757, 0.5204540849487005, 0.9466771715650524], 
             UndirectedEdge[46, 287] -> 
             RGBColor[
              0.27226485336384204`, 0.4034980018471065, 0.9388164526680909], 
             UndirectedEdge[41, 153] -> 
             RGBColor[
              0.32912553840433756`, 0.45949373186045395`, 0.9421925661662062],
              UndirectedEdge[163, 315] -> 
             RGBColor[
              0.24412373790812583`, 0.3739199052533755, 0.9372138577739373], 
             UndirectedEdge[17, 64] -> 
             RGBColor[
              0.46723843843845614`, 0.5768882992816866, 0.951609674456959], 
             UndirectedEdge[67, 127] -> 
             RGBColor[
              0.21172079285419906`, 0.33986235553632177`, 0.9353685579889777],
              UndirectedEdge[83, 246] -> 
             RGBColor[
              0.39834226268445083`, 0.5194457794981713, 0.946602994631389], 
             UndirectedEdge[44, 383] -> 
             RGBColor[
              0.28909643467092216`, 0.42118906098474024`, 0.9397749863234359],
              UndirectedEdge[5, 275] -> 
             RGBColor[
              0.916771833602923, 0.9337046356973782, 0.882657568389807], 
             UndirectedEdge[99, 123] -> 
             RGBColor[
              0.9762118677425246, 0.9817794304286422, 0.9251512823600752], 
             UndirectedEdge[278, 354] -> 
             RGBColor[
              0.2660945297513849, 0.3970126005093012, 0.9384650618665371], 
             UndirectedEdge[61, 215] -> 
             RGBColor[
              0.9063170503481712, 0.5687194984901538, 0.341612283904028], 
             UndirectedEdge[115, 208] -> 
             RGBColor[
              0.2358464087925902, 0.36521990753996986`, 0.9367424761260187], 
             UndirectedEdge[167, 203] -> 
             RGBColor[
              0.2874735215718495, 0.4194832764189812, 0.9396825638233285], 
             UndirectedEdge[242, 256] -> 
             RGBColor[
              0.5718276027056971, 0.5340616080097416, 0.5946502523941279], 
             UndirectedEdge[136, 254] -> 
             RGBColor[
              0.5440467518592814, 0.6407206880430576, 0.9572484996967315], 
             UndirectedEdge[65, 170] -> 
             RGBColor[
              0.4801509107444425, 0.5886204880785566, 0.952281016742329], 
             UndirectedEdge[247, 340] -> 
             RGBColor[
              0.9503928339373993, 0.8290616417134029, 0.4041000646481473], 
             UndirectedEdge[8, 17] -> 
             RGBColor[
              0.42291827954092154`, 0.5385004052405986, 0.9487856331227857], 
             UndirectedEdge[269, 300] -> 
             RGBColor[
              0.9415278534612976, 0.7904724805205449, 0.35790419683327634`], 
             UndirectedEdge[233, 242] -> 
             RGBColor[
              0.867902536299588, 0.4245883317454004, 0.20875474200246447`], 
             UndirectedEdge[242, 382] -> 
             RGBColor[
              0.9085638811026002, 0.6736245465915296, 0.24520540694695725`], 
             UndirectedEdge[144, 242] -> 
             RGBColor[
              0.8983924729381163, 0.6274385577093406, 0.23671813465048305`], 
             UndirectedEdge[81, 227] -> 
             RGBColor[
              0.2273187292651137, 0.35625677567048153`, 0.9362568373925002], 
             UndirectedEdge[224, 230] -> 
             RGBColor[
              0.9722593705527938, 0.9180864844443417, 0.3467333222862512], 
             UndirectedEdge[81, 248] -> 
             RGBColor[
              0.21796166804011632`, 0.3464219110510618, 0.9357239665982682], 
             UndirectedEdge[13, 323] -> 
             RGBColor[
              0.8969951869704291, 0.9199794950758233, 0.9649311806841149], 
             UndirectedEdge[10, 189] -> 
             RGBColor[
              0.3312363099818102, 0.46056389881459425`, 0.9423548195879734], 
             UndirectedEdge[135, 364] -> 
             RGBColor[
              0.42640390772588643`, 0.5423948335396401, 0.9487658718038847], 
             UndirectedEdge[39, 383] -> 
             RGBColor[
              0.27666419535336334`, 0.408121989212486, 0.9390669886861509], 
             UndirectedEdge[108, 196] -> 
             RGBColor[
              0.332746597404592, 0.4616295540574491, 0.9424599321408476], 
             UndirectedEdge[75, 89] -> 
             RGBColor[
              0.23138047401831524`, 0.3605259269355878, 0.9364881477473821], 
             UndirectedEdge[131, 269] -> 
             RGBColor[
              0.9577625542405059, 0.8589366723660075, 0.3711790558606476], 
             UndirectedEdge[36, 165] -> 
             RGBColor[
              0.5262130350709433, 0.6262424733544989, 0.9558445641840965], 
             UndirectedEdge[40, 41] -> 
             RGBColor[
              0.34006622360312927`, 0.4689700034848203, 0.942889696952605], 
             UndirectedEdge[86, 249] -> 
             RGBColor[
              0.2850528182511259, 0.41693896374744543`, 0.939544708350323], 
             UndirectedEdge[287, 395] -> 
             RGBColor[
              0.2666407460996809, 0.397586708523477, 0.938496168079518], 
             UndirectedEdge[177, 225] -> 
             RGBColor[
              0.2895083029136421, 0.42040499749423077`, 0.9398430005920957], 
             UndirectedEdge[74, 216] -> 
             RGBColor[
              0.7418875253371497, 0.7983253437301927, 0.9748980148903788], 
             UndirectedEdge[229, 371] -> 
             RGBColor[
              0.25947088353624953`, 0.3900507283737679, 0.9380878550133916], 
             UndirectedEdge[319, 371] -> 
             RGBColor[
              0.2568146393431022, 0.387258847311161, 0.937936585836153], 
             UndirectedEdge[169, 353] -> 
             RGBColor[
              0.21553905850906607`, 0.343875594831612, 0.9355860025694045], 
             UndirectedEdge[47, 362] -> 
             RGBColor[
              0.4192754724662534, 0.5375770736774529, 0.9479368402481747], 
             UndirectedEdge[83, 313] -> 
             RGBColor[
              0.31784501109874064`, 0.44732499341570175`, 0.9415615875935087],
              UndirectedEdge[87, 210] -> 
             RGBColor[
              0.2950312133683537, 0.42742688968244336`, 0.9401129631905363], 
             UndirectedEdge[91, 150] -> 
             RGBColor[
              0.2666109948635128, 0.3975554380879269, 0.9384944737906311], 
             UndirectedEdge[16, 258] -> 
             RGBColor[
              0.24739688608388788`, 0.37736019151568206`, 0.9374002587203583],
              UndirectedEdge[334, 388] -> 
             RGBColor[
              0.24238207309791887`, 0.372089305109921, 0.9371146725395583], 
             UndirectedEdge[67, 325] -> 
             RGBColor[
              0.21225679273606501`, 0.3404257253965182, 0.9353990823893092], 
             UndirectedEdge[279, 363] -> 
             RGBColor[
              0.9040810668165558, 0.6454045668048165, 0.24105801091555495`], 
             UndirectedEdge[192, 385] -> 
             RGBColor[
              0.45995539470159097`, 0.5694965937320001, 0.9514449793856737], 
             UndirectedEdge[216, 339] -> 
             RGBColor[
              0.5124310381777115, 0.6124197611712089, 0.9555918284959135], 
             UndirectedEdge[74, 323] -> 
             RGBColor[
              0.8274418605794372, 0.8652436955878107, 0.9834033373997775], 
             UndirectedEdge[60, 87] -> 
             RGBColor[
              0.32383352968544554`, 0.4531896894262284, 0.9419183552403817], 
             UndirectedEdge[74, 198] -> 
             RGBColor[
              0.8255815527613636, 0.8637603366303892, 0.9832258995793732], 
             UndirectedEdge[16, 348] -> 
             RGBColor[
              0.252407866634222, 0.38262704978860046`, 0.9376856266496183], 
             UndirectedEdge[88, 283] -> 
             RGBColor[
              0.9496145330722283, 0.8334245259791293, 0.5278793972462171], 
             UndirectedEdge[292, 388] -> 
             RGBColor[
              0.21719189432910094`, 0.3456128300743124, 0.9356801291242041], 
             UndirectedEdge[76, 382] -> 
             RGBColor[
              0.8728626791215081, 0.4975553578985697, 0.2149200050950769], 
             UndirectedEdge[131, 352] -> 
             RGBColor[
              0.9583101575279735, 0.8601079404267151, 0.43078229428572945`], 
             UndirectedEdge[123, 232] -> 
             RGBColor[
              0.7499263891145284, 0.8030301325071595, 0.9420935049543039], 
             UndirectedEdge[69, 357] -> 
             RGBColor[
              0.5819543622257783, 0.6709852038723623, 0.9605818188059951], 
             UndirectedEdge[241, 339] -> 
             RGBColor[
              0.32836122521249217`, 0.457187465102298, 0.9422040691120204], 
             UndirectedEdge[181, 322] -> 
             RGBColor[
              0.5378642093893072, 0.6357014215455682, 0.9567617873060958], 
             UndirectedEdge[140, 168] -> 
             RGBColor[
              0.6710377427034506, 0.7429390517664531, 0.9678464290545918], 
             UndirectedEdge[88, 357] -> 
             RGBColor[
              0.8330019348815232, 0.8684180093986145, 0.8892498058738514], 
             UndirectedEdge[125, 179] -> 
             RGBColor[
              0.2738145581196516, 0.4051268398024189, 0.9389047060613515], 
             UndirectedEdge[316, 324] -> 
             RGBColor[
              0.2671185805915378, 0.39808894287087526`, 0.9385233800469365], 
             UndirectedEdge[128, 390] -> 
             RGBColor[
              0.29625621364741994`, 0.42709948500765055`, 0.9402418566543815],
              UndirectedEdge[200, 339] -> 
             RGBColor[
              0.3182100783412779, 0.4465179661207665, 0.9416259763149808], 
             UndirectedEdge[85, 110] -> 
             RGBColor[
              0.2484427050223485, 0.37845941352875473`, 0.9374598165617531], 
             UndirectedEdge[178, 209] -> 
             RGBColor[
              0.24801071646784933`, 0.37800536616831976`, 0.9374352154526442],
              UndirectedEdge[380, 383] -> 
             RGBColor[
              0.2728634955258139, 0.4041272127154443, 0.9388505444536035], 
             UndirectedEdge[350, 357] -> 
             RGBColor[
              0.5542164267531839, 0.6479076320182329, 0.9585525480697432], 
             UndirectedEdge[98, 352] -> 
             RGBColor[
              0.9858621188487648, 0.9629527205499828, 0.4862282141252213], 
             UndirectedEdge[68, 151] -> 
             RGBColor[
              0.29628007015479707`, 0.4280840429902235, 0.9402080838641316], 
             UndirectedEdge[307, 385] -> 
             RGBColor[
              0.7803305100204103, 0.8271780586683711, 0.9269968726475282], 
             UndirectedEdge[94, 119] -> 
             RGBColor[
              0.25031116778183593`, 0.38042328635635736`, 0.9375662227517629],
              UndirectedEdge[116, 121] -> 
             RGBColor[
              0.48470874113100904`, 0.5915401565241579, 0.9528555034179461], 
             UndirectedEdge[1, 361] -> 
             RGBColor[
              0.35780477718256065`, 0.4843342470296975, 0.9440199819010995], 
             UndirectedEdge[180, 239] -> 
             RGBColor[
              0.3453924706572131, 0.47358333097810695`, 0.943229080705076], 
             UndirectedEdge[45, 394] -> 
             RGBColor[
              0.32718352263793704`, 0.4565868884354943, 0.9421136673575129], 
             UndirectedEdge[32, 124] -> 
             RGBColor[
              0.21977833860588586`, 0.34833134699925217`, 0.9358274232994656],
              UndirectedEdge[87, 243] -> 
             RGBColor[
              0.2892553344802239, 0.4213560747591461, 0.9397840354325044], 
             UndirectedEdge[188, 195] -> 
             RGBColor[
              0.25639031228130726`, 0.3868128526653249, 0.9379124210377194], 
             UndirectedEdge[122, 262] -> 
             RGBColor[
              0.6923652232093209, 0.7572804525421046, 0.9691955483013721], 
             UndirectedEdge[118, 212] -> 
             RGBColor[
              0.208479398474888, 0.33645544452739207`, 0.9351839653742893], 
             UndirectedEdge[35, 258] -> 
             RGBColor[
              0.2669871560923189, 0.3979508073894016, 0.938515895616131], 
             UndirectedEdge[183, 271] -> 
             RGBColor[
              0.28286075625291396`, 0.4146349676025667, 0.9394198736623899], 
             UndirectedEdge[130, 147] -> 
             RGBColor[
              0.34757171171070933`, 0.4732511609805692, 0.9434492148065551], 
             UndirectedEdge[124, 330] -> 
             RGBColor[
              0.22402160898279397`, 0.3527912932042634, 0.9360690712700745], 
             UndirectedEdge[46, 395] -> 
             RGBColor[
              0.27869220583377896`, 0.41025355681069386`, 0.939182480882838], 
             UndirectedEdge[206, 284] -> 
             RGBColor[
              0.23778007994491618`, 0.3672523185228967, 0.9368525958375336], 
             UndirectedEdge[179, 313] -> 
             RGBColor[
              0.2762257553297003, 0.407661160948913, 0.939042020175417], 
             UndirectedEdge[215, 363] -> 
             RGBColor[
              0.8409003453545498, 0.3089231403704602, 0.18654654935464235`], 
             UndirectedEdge[260, 338] -> 
             RGBColor[
              0.9016212039882432, 0.9204360205910522, 0.8006477894997438], 
             UndirectedEdge[88, 113] -> 
             RGBColor[
              0.8934147061054667, 0.915612925432826, 0.8952711863200087], 
             UndirectedEdge[95, 270] -> 
             RGBColor[
              0.26568283896088996`, 0.3965798873857872, 0.9384416166850604], 
             UndirectedEdge[16, 184] -> 
             RGBColor[
              0.22981171473055614`, 0.35887706145906934`, 0.9363988092267157],
              UndirectedEdge[38, 78] -> 
             RGBColor[
              0.9038175805994484, 0.6094521874784743, 0.2546544328195417], 
             UndirectedEdge[8, 210] -> 
             RGBColor[
              0.30512183219392025`, 0.43788724700591375`, 0.9406929373091137],
              UndirectedEdge[1, 96] -> 
             RGBColor[
              0.32344726087306624`, 0.45255674347328584`, 0.9419046676618501],
              UndirectedEdge[213, 247] -> 
             RGBColor[
              0.9089878266866289, 0.6768740913610367, 0.24562767290302676`], 
             UndirectedEdge[109, 366] -> 
             RGBColor[
              0.9476884477531541, 0.8182230648175637, 0.4934194788371198], 
             UndirectedEdge[223, 260] -> 
             RGBColor[
              0.6315106131402652, 0.7091757673875206, 0.9658788076150083], 
             UndirectedEdge[393, 399] -> 
             RGBColor[
              0.22884950770057744`, 0.3578657208631124, 0.9363440129598162], 
             UndirectedEdge[25, 358] -> 
             RGBColor[
              0.9086438937541778, 0.640542215450566, 0.2633529303924386], 
             UndirectedEdge[207, 358] -> 
             RGBColor[
              0.9542162454207332, 0.8524596356255733, 0.30144575978299126`], 
             UndirectedEdge[31, 33] -> 
             RGBColor[0.1810793999809316, 0.30765630885, 0.9336235759947237], 
             UndirectedEdge[355, 375] -> 
             RGBColor[
              0.24288325350972279`, 0.37261607749940034`, 0.9371432140225805],
              UndirectedEdge[25, 104] -> 
             RGBColor[
              0.8912926011446027, 0.575480186768195, 0.22996543355252164`], 
             UndirectedEdge[360, 375] -> 
             RGBColor[
              0.2826185317002574, 0.4142282159179257, 0.939411650593985], 
             UndirectedEdge[28, 347] -> 
             RGBColor[
              0.28416959916217255`, 0.4160106444856309, 0.9394944103298126], 
             UndirectedEdge[56, 143] -> 
             RGBColor[
              0.5377896391569529, 0.6355761788857779, 0.956773794547269], 
             UndirectedEdge[73, 115] -> 
             RGBColor[
              0.24086103809529086`, 0.3704906008829697, 0.9370280518463283], 
             UndirectedEdge[157, 218] -> 
             RGBColor[
              0.689653807893005, 0.7555582412254274, 0.971321814931075], 
             UndirectedEdge[267, 321] -> 
             RGBColor[
              0.6944927044467815, 0.7601721648632764, 0.9709294949676452], 
             UndirectedEdge[93, 324] -> 
             RGBColor[
              0.26259788296436154`, 0.3933374030359285, 0.9382659330048415], 
             UndirectedEdge[178, 245] -> 
             RGBColor[
              0.23694364602077422`, 0.3663731734356497, 0.9368049621629467], 
             UndirectedEdge[223, 331] -> 
             RGBColor[
              0.45307983116767014`, 0.5668363678003234, 0.9500964447383967], 
             UndirectedEdge[318, 367] -> 
             RGBColor[
              0.22156608180377718`, 0.3502103784497014, 0.9359292326298564], 
             UndirectedEdge[158, 265] -> 
             RGBColor[
              0.5475052991401734, 0.643528492531465, 0.9575207692077594], 
             UndirectedEdge[124, 199] -> 
             RGBColor[
              0.224537016117427, 0.35333301878146245`, 0.9360984229439153], 
             UndirectedEdge[38, 213] -> 
             RGBColor[
              0.9383796626861343, 0.7904965676280676, 0.28441340229193146`], 
             UndirectedEdge[128, 296] -> 
             RGBColor[
              0.3138673468643941, 0.4456099026290287, 0.9412447846377514], 
             UndirectedEdge[89, 315] -> 
             RGBColor[
              0.23092852589242507`, 0.36005090080011104`, 0.93646240997021], 
             UndirectedEdge[129, 178] -> 
             RGBColor[
              0.24083645723076108`, 0.3704647648358321, 0.9370266520024574], 
             UndirectedEdge[61, 279] -> 
             RGBColor[
              0.9694977718101772, 0.9052009249245101, 0.39612374546494056`], 
             UndirectedEdge[7, 332] -> 
             RGBColor[
              0.45831330080032634`, 0.5693830222721039, 0.9509787412394903], 
             UndirectedEdge[105, 180] -> 
             RGBColor[
              0.39180706588006936`, 0.513785320494758, 0.9461865776698615], 
             UndirectedEdge[75, 163] -> 
             RGBColor[
              0.24457568603401603`, 0.37439493138885227`, 0.9372395955511095],
              UndirectedEdge[15, 273] -> 
             RGBColor[
              0.28964915667663804`, 0.4217700068573468, 0.9398064630239824], 
             UndirectedEdge[149, 287] -> 
             RGBColor[
              0.24021601426247097`, 0.36981263993780294`, 0.9369913186932763],
              UndirectedEdge[123, 275] -> 
             RGBColor[
              0.9831983875687983, 0.9856760529092304, 0.8544852374631398], 
             UndirectedEdge[186, 226] -> 
             RGBColor[
              0.24355084950968384`, 0.37331776322339055`, 0.9371812326271585],
              UndirectedEdge[15, 183] -> 
             RGBColor[
              0.281397272925088, 0.41309675383481925`, 0.9393365304518997], 
             UndirectedEdge[35, 41] -> 
             RGBColor[
              0.3109306833758936, 0.44117275107327436`, 0.9411269955899995], 
             UndirectedEdge[47, 54] -> 
             RGBColor[
              0.44294170199458305`, 0.5580755721956097, 0.9494448314664949], 
             UndirectedEdge[19, 196] -> 
             RGBColor[
              0.2861541125436652, 0.4180964938749955, 0.9396074254310642], 
             UndirectedEdge[211, 328] -> 
             RGBColor[
              0.2860571913279975, 0.41793071873950494`, 0.9396042457787188], 
             UndirectedEdge[3, 86] -> 
             RGBColor[
              0.33530800642617503`, 0.4640896371481913, 0.9426142996527203], 
             UndirectedEdge[55, 58] -> 
             RGBColor[
              0.351171823063294, 0.4776705562573528, 0.9436309688854188], 
             UndirectedEdge[63, 214] -> 
             RGBColor[
              0.9711670732550739, 0.9296487112649943, 0.6029350218130802], 
             UndirectedEdge[26, 106] -> 
             RGBColor[
              0.7018038352541023, 0.7648141211568, 0.9611581586207743], 
             UndirectedEdge[89, 378] -> 
             RGBColor[
              0.2135546306131389, 0.341789835292997, 0.9354729923364294], 
             UndirectedEdge[191, 311] -> 
             RGBColor[
              0.5991137006259042, 0.6848674707026068, 0.961965795167115], 
             UndirectedEdge[147, 364] -> 
             RGBColor[
              0.31713379957570453`, 0.44688737134317436`, 0.9415097379605015],
              UndirectedEdge[137, 285] -> 
             RGBColor[
              0.23013560035880143`, 0.35921748578989005`, 0.9364172540340985],
              UndirectedEdge[104, 205] -> 
             RGBColor[
              0.9645712998383063, 0.8839256222853624, 0.49686413410326324`], 
             UndirectedEdge[191, 339] -> 
             RGBColor[
              0.5223069322379694, 0.6201348846706572, 0.9565761653203628], 
             UndirectedEdge[40, 167] -> 
             RGBColor[
              0.31143079927380024`, 0.4418378465956456, 0.9411503707956721], 
             UndirectedEdge[17, 262] -> 
             RGBColor[
              0.7370797325190604, 0.7937780282574919, 0.9726613937241215], 
             UndirectedEdge[96, 348] -> 
             RGBColor[
              0.27493335548153697`, 0.4063027667656103, 0.9389684199159984], 
             UndirectedEdge[60, 122] -> 
             RGBColor[
              0.4018079642776756, 0.5224475960269956, 0.9468238260723096], 
             UndirectedEdge[99, 187] -> 
             RGBColor[
              0.9110307205751575, 0.9308010667922535, 0.953442401298972], 
             UndirectedEdge[111, 166] -> 
             RGBColor[
              0.8494236278647009, 0.35624594261769826`, 0.19399614499147944`],
              UndirectedEdge[130, 172] -> 
             RGBColor[
              0.3559151258566954, 0.4820206182510111, 0.9439243598991939], 
             UndirectedEdge[205, 230] -> 
             RGBColor[
              0.9820628725503424, 0.9494608486926688, 0.5307965926515668], 
             UndirectedEdge[248, 319] -> 
             RGBColor[
              0.2288957810137855, 0.3579143570491916, 0.9363466481565481], 
             UndirectedEdge[77, 111] -> 
             RGBColor[
              0.8517216279012312, 0.6939386797204187, 0.6001134200588495], 
             UndirectedEdge[41, 188] -> 
             RGBColor[
              0.30395311727072993`, 0.43383888669350434`, 0.9407296335226945],
              UndirectedEdge[57, 278] -> 
             RGBColor[
              0.26281152350528336`, 0.39356195279003, 0.9382780995175941], 
             UndirectedEdge[56, 331] -> 
             RGBColor[
              0.4515137506850261, 0.565500249927577, 0.9499910348290849], 
             UndirectedEdge[40, 87] -> 
             RGBColor[
              0.31472542396778913`, 0.4453007060402985, 0.9413379947980343], 
             UndirectedEdge[142, 214] -> 
             RGBColor[
              0.9026785336009098, 0.577164017789306, 0.5403271212608096], 
             UndirectedEdge[341, 368] -> 
             RGBColor[
              0.2171826090564914, 0.3456030706640795, 0.9356796003416652], 
             UndirectedEdge[96, 188] -> 
             RGBColor[
              0.2769987034014417, 0.4084735783800516, 0.9390860384246287], 
             UndirectedEdge[142, 202] -> 
             RGBColor[
              0.8389617996732674, 0.300483042224024, 0.18494316940916705`], 
             UndirectedEdge[37, 351] -> 
             RGBColor[
              0.2477720085286644, 0.3777544689892789, 0.9374216213886444], 
             UndirectedEdge[83, 108] -> 
             RGBColor[
              0.3602253738682746, 0.48643084621613597`, 0.9441742201814636], 
             UndirectedEdge[72, 119] -> 
             RGBColor[
              0.2341124382405141, 0.36339739454965503`, 0.9366437290682574], 
             UndirectedEdge[170, 180] -> 
             RGBColor[
              0.40561982873439206`, 0.5257492414295251, 0.9470667147047922], 
             UndirectedEdge[196, 234] -> 
             RGBColor[
              0.3183317548341577, 0.44914414193399255`, 0.9415414311188043], 
             UndirectedEdge[218, 306] -> 
             RGBColor[
              0.9402199448611399, 0.9214289952270589, 0.6653505611679222], 
             UndirectedEdge[186, 189] -> 
             RGBColor[
              0.2745072076984255, 0.4058548584262301, 0.9389441514301794], 
             UndirectedEdge[20, 135] -> 
             RGBColor[
              0.45546851492086315`, 0.5675691354622958, 0.9506178428735257], 
             UndirectedEdge[79, 254] -> 
             RGBColor[
              0.5301586737259505, 0.6294457205636295, 0.9561551793123693], 
             UndirectedEdge[93, 355] -> 
             RGBColor[
              0.23807963900287032`, 0.36756717408594775`, 0.936869655282726], 
             UndirectedEdge[211, 301] -> 
             RGBColor[
              0.25974755171345176`, 0.39034152416978307`, 0.9381036108567895],
              UndirectedEdge[145, 227] -> 
             RGBColor[
              0.23647303514531387`, 0.36587853156708794`, 0.9367781615697957],
              UndirectedEdge[26, 345] -> 
             RGBColor[
              0.3285301240705917, 0.4490550186158963, 0.9425296374326482], 
             UndirectedEdge[132, 140] -> 
             RGBColor[
              0.7355736784173503, 0.7933550152374292, 0.9742787680039452], 
             UndirectedEdge[153, 258] -> 
             RGBColor[
              0.28518201112076286`, 0.41627178817658117`, 0.9395814661923377],
              UndirectedEdge[56, 344] -> 
             RGBColor[
              0.38578184035649155`, 0.5085665729828752, 0.9458026556273967], 
             UndirectedEdge[44, 390] -> 
             RGBColor[
              0.28212790876587335`, 0.4138646984284726, 0.9393781390821536], 
             UndirectedEdge[223, 346] -> 
             RGBColor[
              0.3995496021231435, 0.5204711739094963, 0.9466855458786024], 
             UndirectedEdge[114, 222] -> 
             RGBColor[
              0.4669023906435984, 0.574712579304436, 0.9521089968254883], 
             UndirectedEdge[85, 203] -> 
             RGBColor[
              0.2663525209612127, 0.3972837656284177, 0.9384797540842731], 
             UndirectedEdge[156, 261] -> 
             RGBColor[
              0.18270395436139325`, 0.3093638185065621, 0.9337160919633781], 
             UndirectedEdge[33, 295] -> 
             RGBColor[
              0.21066436833308994`, 0.3387519863834527, 0.9353083961753406], 
             UndirectedEdge[59, 395] -> 
             RGBColor[
              0.303543145607047, 0.434036883269187, 0.9406832590311243], 
             UndirectedEdge[334, 371] -> 
             RGBColor[
              0.26672232113879757`, 0.3976724490617448, 0.9385008136573162], 
             UndirectedEdge[40, 154] -> 
             RGBColor[
              0.3847350802007028, 0.5076599219476261, 0.9457359569958835], 
             UndirectedEdge[300, 306] -> 
             RGBColor[
              0.9301864468516778, 0.7525583544999579, 0.2846700934867103], 
             UndirectedEdge[61, 297] -> 
             RGBColor[
              0.9699924620425022, 0.9739499675150907, 0.7461656307796394], 
             UndirectedEdge[97, 350] -> 
             RGBColor[
              0.437513599136121, 0.5533740223239922, 0.9490989575522366], 
             UndirectedEdge[178, 229] -> 
             RGBColor[
              0.24544230257567465`, 0.37530580032079786`, 0.9372889480811126],
              UndirectedEdge[130, 265] -> 
             RGBColor[
              0.5011501438603255, 0.6047301166670249, 0.9541934622219126], 
             UndirectedEdge[110, 134] -> 
             RGBColor[
              0.24495240537755758`, 0.37479088730430044`, 0.9372610491604179],
              UndirectedEdge[147, 211] -> 
             RGBColor[
              0.2737075152920192, 0.40501433100367, 0.9388986101306735], 
             UndirectedEdge[78, 185] -> 
             RGBColor[
              0.832767216647035, 0.2528687626008105, 0.17901122970746597`], 
             UndirectedEdge[130, 135] -> 
             RGBColor[
              0.4568418198608912, 0.568758623177035, 0.9507053486499384], 
             UndirectedEdge[52, 384] -> 
             RGBColor[
              0.5675366621289825, 0.6563557009893235, 0.9607088184571579], 
             UndirectedEdge[77, 166] -> 
             RGBColor[
              0.827067103969575, 0.529084500588463, 0.5774695030073427], 
             UndirectedEdge[24, 76] -> 
             RGBColor[
              0.8745487301949283, 0.505211322035738, 0.2163268874396324], 
             UndirectedEdge[100, 220] -> 
             RGBColor[
              0.42602430021250687`, 0.5428220538333498, 0.9485327937322395], 
             UndirectedEdge[41, 369] -> 
             RGBColor[
              0.2991371325274741, 0.4287769813772735, 0.940455370316177], 
             UndirectedEdge[12, 318] -> 
             RGBColor[
              0.2211272263803799, 0.3497491135746699, 0.9359042404627222], 
             UndirectedEdge[118, 199] -> 
             RGBColor[
              0.21593219336709382`, 0.3442888044935889, 0.9356083910179783], 
             UndirectedEdge[11, 205] -> 
             RGBColor[
              0.9593655870867921, 0.8632867059265485, 0.49267549542961175`], 
             UndirectedEdge[120, 136] -> 
             RGBColor[
              0.5924802140391232, 0.6800411545432594, 0.9610613592571464], 
             UndirectedEdge[66, 215] -> 
             RGBColor[
              0.8960355420221306, 0.5345577698337973, 0.25743539509359753`], 
             UndirectedEdge[199, 287] -> 
             RGBColor[
              0.24300807911222783`, 0.3727472771220335, 0.9371503226559803], 
             UndirectedEdge[8, 64] -> 
             RGBColor[
              0.3546401133620532, 0.4815931742890025, 0.9438183323208591], 
             UndirectedEdge[312, 361] -> 
             RGBColor[
              0.40929184788600736`, 0.528668033662285, 0.9473730082456748], 
             UndirectedEdge[5, 193] -> 
             RGBColor[
              0.8318913190108279, 0.8687915729636699, 0.983827730717042], 
             UndirectedEdge[187, 232] -> 
             RGBColor[
              0.6847452419471614, 0.7520517688707707, 0.9703846238932006], 
             UndirectedEdge[115, 325] -> 
             RGBColor[
              0.22508690864981107`, 0.3539109906981984, 0.9361297385101415], 
             UndirectedEdge[137, 252] -> 
             RGBColor[
              0.22294460960746476`, 0.35165929857508804`, 0.9360077377489273],
              UndirectedEdge[296, 390] -> 
             RGBColor[
              0.283910407540538, 0.415738217657595, 0.9394796497504001], 
             UndirectedEdge[101, 171] -> 
             RGBColor[
              0.2670272094470698, 0.3979929060047742, 0.9385181765954305], 
             UndirectedEdge[234, 342] -> 
             RGBColor[
              0.47104879657377785`, 0.578346581625195, 0.9523614333210206], 
             UndirectedEdge[56, 343] -> 
             RGBColor[
              0.5865678018857227, 0.673953417760403, 0.9614500105609494], 
             UndirectedEdge[60, 146] -> 
             RGBColor[
              0.44642978990835863`, 0.5588699269563728, 0.9502823750963323], 
             UndirectedEdge[149, 336] -> 
             RGBColor[
              0.21561259787663173`, 0.3439528893695888, 0.9355901905275956], 
             UndirectedEdge[12, 199] -> 
             RGBColor[
              0.22211987446733733`, 0.350792449651586, 0.9359607703027832], 
             UndirectedEdge[42, 104] -> 
             RGBColor[
              0.9330499750272585, 0.8621677183315113, 0.6295247357296906], 
             UndirectedEdge[216, 323] -> 
             RGBColor[
              0.7446559095096992, 0.8005327781235971, 0.9751620658441222], 
             UndirectedEdge[110, 192] -> 
             RGBColor[
              0.30003384397733923`, 0.42938021827289985`, 0.940518858812405], 
             UndirectedEdge[93, 380] -> 
             RGBColor[
              0.25536438822798396`, 0.38573454143794017`, 0.9378539961806014],
              UndirectedEdge[34, 397] -> 
             RGBColor[
              0.28081927975955956`, 0.41216167083836874`, 0.939315608741104], 
             UndirectedEdge[249, 308] -> 
             RGBColor[
              0.2653288302878062, 0.39620780182492993`, 0.9384214564148372], 
             UndirectedEdge[116, 130] -> 
             RGBColor[
              0.4133134657138138, 0.5324130830876621, 0.947556946449905], 
             UndirectedEdge[81, 315] -> 
             RGBColor[
              0.23149483664630416`, 0.3606461293086136, 0.9364946605298619], 
             UndirectedEdge[99, 193] -> 
             RGBColor[
              0.9002336063428361, 0.9221917409832586, 0.9524125629047955], 
             UndirectedEdge[116, 135] -> 
             RGBColor[
              0.4597496952635722, 0.5712772786967698, 0.9508906358992639], 
             UndirectedEdge[304, 378] -> 
             RGBColor[
              0.21381243485280502`, 0.34206080389461896`, 0.9354876739064912],
              UndirectedEdge[56, 120] -> 
             RGBColor[
              0.5086566729306621, 0.6119247244781029, 0.9544803407283637], 
             UndirectedEdge[255, 393] -> 
             RGBColor[
              0.2416474883761139, 0.3713172099919425, 0.9370728390263723], 
             UndirectedEdge[106, 214] -> 
             RGBColor[
              0.9661339552698273, 0.9742633398075717, 0.9422105594358144], 
             UndirectedEdge[130, 328] -> 
             RGBColor[
              0.3599213877466876, 0.48616754871640405`, 0.9441548504546003], 
             UndirectedEdge[181, 250] -> 
             RGBColor[
              0.7777697545864616, 0.8245041838583995, 0.9019245302265969], 
             UndirectedEdge[102, 230] -> 
             RGBColor[
              0.8940771340934058, 0.5279706608893748, 0.24981441421432754`], 
             UndirectedEdge[45, 141] -> 
             RGBColor[
              0.32778152064738697`, 0.45710484425502595`, 0.9421517712618861],
              UndirectedEdge[225, 288] -> 
             RGBColor[
              0.25106704817739506`, 0.3812177645776751, 0.9376092690220652], 
             UndirectedEdge[208, 278] -> 
             RGBColor[
              0.24275117083398723`, 0.37247725023267697`, 0.9371356921095961],
              UndirectedEdge[342, 346] -> 
             RGBColor[
              0.4741951057473072, 0.5810717564932091, 0.9525619133593859], 
             UndirectedEdge[133, 164] -> 
             RGBColor[
              0.2698983654154672, 0.40101067296936244`, 0.9386816846803361], 
             UndirectedEdge[287, 373] -> 
             RGBColor[
              0.2552675974110747, 0.3856328081524763, 0.9378484840867676], 
             UndirectedEdge[122, 314] -> 
             RGBColor[
              0.6859497834912932, 0.7522408691078613, 0.9712156258567326], 
             UndirectedEdge[85, 351] -> 
             RGBColor[
              0.24352597864269326`, 0.37329162236527946`, 0.9371798162680766],
              UndirectedEdge[5, 338] -> 
             RGBColor[
              0.9178657002272999, 0.9332997898377504, 0.8022208620159], 
             UndirectedEdge[311, 339] -> 
             RGBColor[
              0.4425672704759462, 0.555957682108388, 0.9499165435038557], 
             UndirectedEdge[39, 324] -> 
             RGBColor[
              0.27652485948189337`, 0.40797553837716655`, 0.9390590537143996],
              UndirectedEdge[52, 346] -> 
             RGBColor[
              0.36583874865596927`, 0.4912928693208167, 0.944531899459223], 
             UndirectedEdge[272, 291] -> 
             RGBColor[
              0.6717542540567425, 0.7434987958813325, 0.9679178442101087], 
             UndirectedEdge[191, 323] -> 
             RGBColor[
              0.7545318035699571, 0.8082479016230455, 0.9761464026685716], 
             UndirectedEdge[60, 165] -> 
             RGBColor[
              0.4451385583294708, 0.557821646991312, 0.950180724616505], 
             UndirectedEdge[44, 301] -> 
             RGBColor[
              0.2773872245806669, 0.4088819387730828, 0.9391081641310199], 
             UndirectedEdge[11, 144] -> 
             RGBColor[
              0.9009503839038591, 0.6375798223152109, 0.23877628985540691`], 
             UndirectedEdge[333, 381] -> 
             RGBColor[
              0.5943537422981029, 0.6571554755250186, 0.8488416222676571], 
             UndirectedEdge[9, 363] -> 
             RGBColor[
              0.8440899658094313, 0.333439960887275, 0.18960093350439794`], 
             UndirectedEdge[153, 312] -> 
             RGBColor[
              0.39019396776607296`, 0.5121264097897626, 0.9461561082120249], 
             UndirectedEdge[55, 80] -> 
             RGBColor[
              0.36897452576073053`, 0.49400892184022105`, 0.9447317084034796],
              UndirectedEdge[7, 40] -> 
             RGBColor[
              0.36435856265805855`, 0.4900108066057379, 0.9444375833163132], 
             UndirectedEdge[51, 377] -> 
             RGBColor[
              0.39390138797963725`, 0.5155993170337143, 0.9463200260221095], 
             UndirectedEdge[112, 170] -> 
             RGBColor[
              0.3869454032271654, 0.5095743926590826, 0.9458767968246178], 
             UndirectedEdge[200, 375] -> 
             RGBColor[
              0.26275249757312547`, 0.3934999127928718, 0.9382747380780788], 
             UndirectedEdge[94, 200] -> 
             RGBColor[
              0.26539181138814727`, 0.3962739989546208, 0.9384250430953294], 
             UndirectedEdge[8, 253] -> 
             RGBColor[
              0.3260178665234107, 0.4568020226733255, 0.9419945480619598], 
             UndirectedEdge[31, 295] -> 
             RGBColor[
              0.21280238164412135`, 0.34099917393122015`, 0.9354301528704966],
              UndirectedEdge[301, 383] -> 
             RGBColor[
              0.2685271160434062, 0.39956940293709464`, 0.9386035940571789], 
             UndirectedEdge[327, 392] -> 
             RGBColor[
              0.28327067295496094`, 0.4141554737113025, 0.9394765499044728], 
             UndirectedEdge[119, 375] -> 
             RGBColor[
              0.24767185396681415`, 0.37764920019460835`, 0.9374159177345123],
              UndirectedEdge[160, 340] -> 
             RGBColor[
              0.9116278550257833, 0.6083417789954149, 0.37001345675471364`], 
             UndirectedEdge[151, 308] -> 
             RGBColor[
              0.28846194842015016`, 0.41986670134956156`, 0.9397628533972181],
              UndirectedEdge[221, 276] -> 
             RGBColor[
              0.8437125304054167, 0.8786573253156666, 0.9848385285958808], 
             UndirectedEdge[94, 316] -> 
             RGBColor[
              0.25720173748705216`, 0.38766571200389227`, 0.9379586305027907],
              UndirectedEdge[195, 206] -> 
             RGBColor[
              0.2386283880050733, 0.3681439440799593, 0.9369009057266002], 
             UndirectedEdge[159, 192] -> 
             RGBColor[
              0.3379621693046799, 0.46714757740434754`, 0.9427556284732501], 
             UndirectedEdge[220, 350] -> 
             RGBColor[
              0.454088632793754, 0.5671299681608568, 0.9503210281880017], 
             UndirectedEdge[229, 319] -> 
             RGBColor[
              0.24423991719027513`, 0.3740420170451063, 0.9372204740121839], 
             UndirectedEdge[69, 97] -> 
             RGBColor[
              0.46525153460871527`, 0.5764515941781216, 0.9511282282884884], 
             UndirectedEdge[90, 317] -> 
             RGBColor[
              0.8482164323597703, 0.8802460937906929, 0.8881545671159801], 
             UndirectedEdge[136, 237] -> 
             RGBColor[
              0.59850057250929, 0.6849287527633994, 0.9615353039292178], 
             UndirectedEdge[69, 141] -> 
             RGBColor[
              0.42414128450553, 0.540843961799992, 0.9485087195042803], 
             UndirectedEdge[48, 143] -> 
             RGBColor[
              0.5250435709581793, 0.6245361752480152, 0.9559616263525487], 
             UndirectedEdge[51, 246] -> 
             RGBColor[
              0.408363122473439, 0.5281253445843351, 0.9472415149560449], 
             UndirectedEdge[97, 132] -> 
             RGBColor[
              0.6207534044996754, 0.7002920708010887, 0.965012812845729], 
             UndirectedEdge[94, 383] -> 
             RGBColor[
              0.2701801471577058, 0.4013068434464496, 0.9386977317336979], 
             UndirectedEdge[246, 344] -> 
             RGBColor[
              0.3822157528613575, 0.505477807231359, 0.9455754276855741], 
             UndirectedEdge[155, 354] -> 
             RGBColor[
              0.29215952785429067`, 0.42440856613178546`, 0.9399494249487885],
              UndirectedEdge[107, 307] -> 
             RGBColor[
              0.9122288272245584, 0.6453071063540661, 0.539731773350462], 
             UndirectedEdge[310, 363] -> 
             RGBColor[
              0.5225453221257725, 0.38890738011125736`, 0.5703491605175277], 
             UndirectedEdge[99, 281] -> 
             RGBColor[
              0.8050608246814849, 0.8476642232367373, 0.943040239252503], 
             UndirectedEdge[123, 187] -> 
             RGBColor[
              0.9091149872090246, 0.929372315984517, 0.9566852381845512], 
             UndirectedEdge[23, 227] -> 
             RGBColor[
              0.22416996966139735`, 0.3529472296840859, 0.936077520191241], 
             UndirectedEdge[28, 211] -> 
             RGBColor[
              0.2754831553698227, 0.4068806413075249, 0.9389997302062802], 
             UndirectedEdge[327, 356] -> 
             RGBColor[
              0.4184852693414719, 0.5351260969165677, 0.9483745901685348], 
             UndirectedEdge[140, 219] -> 
             RGBColor[
              0.5595564197473485, 0.6526927736905361, 0.9588251269991186], 
             UndirectedEdge[104, 144] -> 
             RGBColor[
              0.9061560966553733, 0.6582187386740248, 0.24296492852905843`], 
             UndirectedEdge[49, 328] -> 
             RGBColor[
              0.2825867919008145, 0.4142831089055032, 0.9394066116653366], 
             UndirectedEdge[112, 271] -> 
             RGBColor[
              0.3178545270497625, 0.4495503070285146, 0.9414810160978866], 
             UndirectedEdge[106, 197] -> 
             RGBColor[
              0.9686231253627324, 0.9753622711647122, 0.9040752003743098], 
             UndirectedEdge[106, 204] -> 
             RGBColor[
              0.563710908416439, 0.6332510496213667, 0.9527850098927306], 
             UndirectedEdge[50, 158] -> 
             RGBColor[
              0.47863176654490647`, 0.5876138560533424, 0.9520987924297972], 
             UndirectedEdge[259, 299] -> 
             RGBColor[
              0.21257469635649348`, 0.34075986225784227`, 0.9354171865301963],
              UndirectedEdge[79, 286] -> 
             RGBColor[
              0.658527918518543, 0.7323765551714567, 0.9671395072605043], 
             UndirectedEdge[240, 388] -> 
             RGBColor[
              0.23128580999340365`, 0.36042642904335986`, 0.9364827567712063],
              UndirectedEdge[118, 299] -> 
             RGBColor[
              0.21009516231391617`, 0.33815371476755507`, 0.9352759807346135],
              UndirectedEdge[138, 257] -> 
             RGBColor[
              0.8209750230584517, 0.16222879530677942`, 0.1677190118096608], 
             UndirectedEdge[171, 244] -> 
             RGBColor[
              0.266624380952421, 0.39756950771609656`, 0.9384952361085915], 
             UndirectedEdge[161, 337] -> 
             RGBColor[
              0.35808998923330093`, 0.48236207273681253`, 0.9441194115332278],
              UndirectedEdge[119, 355] -> 
             RGBColor[
              0.2357097669248304, 0.3650762882733595, 0.9367346945737933], 
             UndirectedEdge[248, 292] -> 
             RGBColor[
              0.21361328404066288`, 0.34185148376416674`, 0.935476332562357], 
             UndirectedEdge[68, 386] -> 
             RGBColor[
              0.30804388160308127`, 0.43827326520037213`, 0.9409576635272863],
              UndirectedEdge[126, 299] -> 
             RGBColor[
              0.21308522513571704`, 0.34129646037420036`, 0.9354462603889135],
              UndirectedEdge[128, 383] -> 
             RGBColor[
              0.30322473955246876`, 0.43442384756391816`, 0.9406387038956638],
              UndirectedEdge[229, 248] -> 
             RGBColor[
              0.2315520252069328, 0.36070623811179847`, 0.9364979173337866], 
             UndirectedEdge[395, 396] -> 
             RGBColor[
              0.2756838068644868, 0.4070915387504564, 0.9390111570120642], 
             UndirectedEdge[81, 292] -> 
             RGBColor[
              0.21536706305033604`, 0.3436948166993449, 0.9355762076824743], 
             UndirectedEdge[34, 253] -> 
             RGBColor[
              0.3270023945629662, 0.4576547713773704, 0.9420572813180563], 
             UndirectedEdge[130, 322] -> 
             RGBColor[
              0.45941085843753277`, 0.5708442844274215, 0.95090759277739], 
             UndirectedEdge[74, 311] -> 
             RGBColor[
              0.6720237576353845, 0.741863264667372, 0.9692227298983209], 
             UndirectedEdge[232, 235] -> 
             RGBColor[
              0.6328251607154107, 0.7112978291642651, 0.965261084970727], 
             UndirectedEdge[207, 221] -> 
             RGBColor[
              0.9308573670898133, 0.869892342221664, 0.6314368519575342], 
             UndirectedEdge[140, 216] -> 
             RGBColor[
              0.6655132848379224, 0.7386233032944675, 0.96729580272355], 
             UndirectedEdge[31, 173] -> 
             RGBColor[
              0.20479251217739197`, 0.3325802932666311, 0.9349740026539064], 
             UndirectedEdge[37, 243] -> 
             RGBColor[
              0.2690857390615694, 0.4001565511479292, 0.9386354068116546], 
             UndirectedEdge[1, 35] -> 
             RGBColor[
              0.32051204203418227`, 0.44947164236999554`, 0.9417375112912428],
              UndirectedEdge[60, 210] -> 
             RGBColor[
              0.3287260262404138, 0.45833201350769803`, 0.942196975681387], 
             UndirectedEdge[35, 92] -> 
             RGBColor[
              0.28435244626912165`, 0.4162028283882106, 0.9395048232020553], 
             UndirectedEdge[52, 291] -> 
             RGBColor[
              0.5415685327056081, 0.6360692009186899, 0.9581205580022027], 
             UndirectedEdge[77, 400] -> 
             RGBColor[
              0.6094880057982189, 0.6893301781287484, 0.9648167092401694], 
             UndirectedEdge[77, 389] -> 
             RGBColor[
              0.5042266153181847, 0.5861702959978048, 0.9585484769989704], 
             UndirectedEdge[96, 361] -> 
             RGBColor[
              0.32126900465498376`, 0.45067004741952366`, 0.9417658711017902],
              UndirectedEdge[150, 374] -> 
             RGBColor[
              0.2733522518909328, 0.4046409266441276, 0.9388783784055468], 
             UndirectedEdge[80, 154] -> 
             RGBColor[
              0.38228721374237734`, 0.5055397030547701, 0.9455799811097223], 
             UndirectedEdge[200, 383] -> 
             RGBColor[
              0.27544799036410295`, 0.4068436806569232, 0.9389977276112265], 
             UndirectedEdge[144, 391] -> 
             RGBColor[
              0.8494144480971886, 0.3493178905748092, 0.19371883223399736`], 
             UndirectedEdge[196, 290] -> 
             RGBColor[
              0.3515289166579535, 0.47789785496789633`, 0.943656724915119], 
             UndirectedEdge[159, 228] -> 
             RGBColor[
              0.3496458859290326, 0.47726742550368945`, 0.9435001045650488], 
             UndirectedEdge[27, 377] -> 
             RGBColor[
              0.3561480526956704, 0.48185180602152367`, 0.9439527698723194], 
             UndirectedEdge[24, 233] -> 
             RGBColor[
              0.8598056285506199, 0.3918893823292492, 0.202208876655091], 
             UndirectedEdge[24, 109] -> 
             RGBColor[
              0.9481247371168586, 0.8202041529201762, 0.49378352937662584`], 
             UndirectedEdge[189, 255] -> 
             RGBColor[
              0.28051086067435194`, 0.4121650783575129, 0.9392860505855498], 
             UndirectedEdge[262, 298] -> 
             RGBColor[
              0.8810364966451805, 0.9079026895445534, 0.9858832537094278], 
             UndirectedEdge[249, 397] -> 
             RGBColor[
              0.25945941523748706`, 0.39003867446463636`, 0.938087201910743], 
             UndirectedEdge[128, 324] -> 
             RGBColor[
              0.3030854036809988, 0.43427739672859866`, 0.9406307689239126], 
             UndirectedEdge[7, 228] -> 
             RGBColor[
              0.37863108577837257`, 0.5023729487746839, 0.9453470158688431], 
             UndirectedEdge[115, 258] -> 
             RGBColor[
              0.24576968053509757`, 0.37564989531311277`, 0.9373075917715895],
              UndirectedEdge[375, 383] -> 
             RGBColor[
              0.26754083334268397`, 0.3985327572847006, 0.9385474267164473], 
             UndirectedEdge[257, 338] -> 
             RGBColor[
              0.9084477718580719, 0.5824829620653897, 0.3944924501077937], 
             UndirectedEdge[5, 321] -> 
             RGBColor[
              0.8296147450427847, 0.8669940565457998, 0.9836058756059307], 
             UndirectedEdge[65, 239] -> 
             RGBColor[
              0.4199235526672635, 0.5364545776271384, 0.9484433827426128], 
             UndirectedEdge[56, 71] -> 
             RGBColor[
              0.6610275221983658, 0.7325352305400676, 0.968761778959447], 
             UndirectedEdge[276, 322] -> 
             RGBColor[
              0.6369911357289768, 0.7142897496435541, 0.9658558315605028], 
             UndirectedEdge[239, 326] -> 
             RGBColor[
              0.3319525774457105, 0.4619423709869775, 0.94237270259407], 
             UndirectedEdge[379, 393] -> 
             RGBColor[
              0.22188867958802838`, 0.35054944917483033`, 0.9359476040964289],
              UndirectedEdge[131, 262] -> 
             RGBColor[
              0.9305545199558635, 0.8420358975584873, 0.6226092420681639], 
             UndirectedEdge[201, 210] -> 
             RGBColor[
              0.2881749983278178, 0.42022057296569904`, 0.9397225118868391], 
             UndirectedEdge[301, 372] -> 
             RGBColor[
              0.25414770566980416`, 0.3844557309271635, 0.9377847079088335], 
             UndirectedEdge[291, 398] -> 
             RGBColor[
              0.8179584912880846, 0.8585839639299231, 0.9789023010866215], 
             UndirectedEdge[28, 49] -> 
             RGBColor[
              0.27201275594263963`, 0.40323303147352313`, 0.938802096092898], 
             UndirectedEdge[6, 160] -> 
             RGBColor[
              0.9114125623801264, 0.6078812897957802, 0.3465801809071596], 
             UndirectedEdge[375, 379] -> 
             RGBColor[
              0.23790135046863936`, 0.36737978153232503`, 0.9368595020144559],
              UndirectedEdge[45, 112] -> 
             RGBColor[
              0.31221013250570034`, 0.4436176904874213, 0.9411595761787357], 
             UndirectedEdge[324, 390] -> 
             RGBColor[
              0.27312846435714266`, 0.404405711757165, 0.9388656340365613], 
             UndirectedEdge[169, 227] -> 
             RGBColor[
              0.22781024002051087`, 0.3567733846379857, 0.936284828202895], 
             UndirectedEdge[44, 380] -> 
             RGBColor[
              0.2817236040630746, 0.41343974855143245`, 0.9393551145274445], 
             UndirectedEdge[288, 360] -> 
             RGBColor[
              0.2777088570611381, 0.4090678365808599, 0.9391320518865], 
             UndirectedEdge[87, 134] -> 
             RGBColor[
              0.26223279186396886`, 0.39295366914130303`, 0.9382451416067781],
              UndirectedEdge[85, 258] -> 
             RGBColor[
              0.24712036386052527`, 0.3770695491264064, 0.9373845111888157], 
             UndirectedEdge[26, 77] -> 
             RGBColor[
              0.6422389788407158, 0.7176486903810251, 0.9669170377654001], 
             UndirectedEdge[90, 333] -> 
             RGBColor[
              0.4506831285542931, 0.5464884699982167, 0.9528800174609131], 
             UndirectedEdge[45, 91] -> 
             RGBColor[
              0.27906015322156846`, 0.41064029284447245`, 0.9392034349422431],
              UndirectedEdge[103, 133] -> 
             RGBColor[
              0.32091218999488846`, 0.4513176188145481, 0.9417081084114585], 
             UndirectedEdge[143, 342] -> 
             RGBColor[
              0.6140012232637606, 0.6975128793422373, 0.9627555719373643], 
             UndirectedEdge[75, 164] -> 
             RGBColor[
              0.2433583151299939, 0.3731153973829517, 0.9371702680790643], 
             UndirectedEdge[44, 211] -> 
             RGBColor[
              0.28031687034096775`, 0.4119611822174286, 0.9392750031230466], 
             UndirectedEdge[82, 171] -> 
             RGBColor[
              0.32621487078886763`, 0.45368735101725755`, 0.9421273921767691],
              UndirectedEdge[17, 122] -> 
             RGBColor[
              0.490802095307585, 0.5972979545178956, 0.9531111298361363], 
             UndirectedEdge[150, 186] -> 
             RGBColor[
              0.2595342246109202, 0.3901173038593028, 0.9380914621938894], 
             UndirectedEdge[180, 394] -> 
             RGBColor[
              0.36256898672280274`, 0.4884607658773212, 0.9443235531201786], 
             UndirectedEdge[156, 202] -> 
             RGBColor[
              0.5211495825009953, 0.37342113688887774`, 0.567742844041897], 
             UndirectedEdge[86, 178] -> 
             RGBColor[
              0.27226239938534696`, 0.40349542256011695`, 0.9388163129176459],
              UndirectedEdge[102, 250] -> 
             RGBColor[
              0.9037621261807391, 0.5693653564012491, 0.505440590565607], 
             UndirectedEdge[7, 222] -> 
             RGBColor[
              0.4971659473495666, 0.600925351032558, 0.9540373638977802], 
             UndirectedEdge[97, 220] -> 
             RGBColor[
              0.4588594812307164, 0.571262237287139, 0.9506250224317093], 
             UndirectedEdge[230, 289] -> 
             RGBColor[
              0.9333052704870481, 0.7676068761755623, 0.28495592618105414`], 
             UndirectedEdge[14, 289] -> 
             RGBColor[
              0.9460551929840001, 0.8094710811761514, 0.43178805845315205`], 
             UndirectedEdge[77, 370] -> 
             RGBColor[
              0.8302908639224114, 0.8675154135193626, 0.9836750778819656], 
             UndirectedEdge[151, 270] -> 
             RGBColor[
              0.28271133263489734`, 0.4138224395491612, 0.9394353643355215], 
             UndirectedEdge[173, 214] -> 
             RGBColor[
              0.6050703523847987, 0.6713378352539525, 0.9242773858520503], 
             UndirectedEdge[144, 317] -> 
             RGBColor[
              0.9345325845565998, 0.7656448596324403, 0.5126377323294256], 
             UndirectedEdge[31, 175] -> 
             RGBColor[
              0.18107477738655686`, 0.3076514502102228, 0.9336233127448126], 
             UndirectedEdge[163, 240] -> 
             RGBColor[
              0.2420898799764604, 0.3717821916131542, 0.9370980325735522], 
             UndirectedEdge[329, 371] -> 
             RGBColor[
              0.25359221551815353`, 0.38387187555766883`, 0.9377530735664711],
              UndirectedEdge[72, 375] -> 
             RGBColor[
              0.24128592482540645`, 0.37093718377569584`, 0.9370522485170447],
              UndirectedEdge[32, 238] -> 
             RGBColor[
              0.22275425852448527`, 0.3514592275179208, 0.9359968975363508], 
             UndirectedEdge[11, 14] -> 
             RGBColor[
              0.9589098698169762, 0.8623003371232989, 0.4422276945427869], 
             UndirectedEdge[79, 237] -> 
             RGBColor[
              0.5846124943759591, 0.6736537852839712, 0.9604419835448554], 
             UndirectedEdge[69, 74] -> 
             RGBColor[
              0.6564460490256175, 0.7292165790501876, 0.9679963956135333], 
             UndirectedEdge[16, 203] -> 
             RGBColor[
              0.2666290431845753, 0.3975744080176934, 0.9384955016158156], 
             UndirectedEdge[315, 319] -> 
             RGBColor[
              0.24242894961997336`, 0.37213857530674344`, 0.9371173420881417],
              UndirectedEdge[40, 80] -> 
             RGBColor[
              0.3368642646638673, 0.46619662758676733`, 0.9426856709603764], 
             UndirectedEdge[18, 198] -> 
             RGBColor[
              0.8858480974802114, 0.9115700695530261, 0.9804738418540726], 
             UndirectedEdge[300, 307] -> 
             RGBColor[
              0.9376183763421341, 0.7907736248179609, 0.5620991500919681], 
             UndirectedEdge[191, 198] -> 
             RGBColor[
              0.7526714957518834, 0.806764542665624, 0.9759689648481673], 
             UndirectedEdge[289, 391] -> 
             RGBColor[
              0.8590720492168273, 0.39317080166904056`, 0.2017773713376896], 
             UndirectedEdge[132, 357] -> 
             RGBColor[
              0.7374562321167385, 0.7948256804953293, 0.9744664033632358], 
             UndirectedEdge[157, 187] -> 
             RGBColor[
              0.656588840938115, 0.7291931341002164, 0.9681680488654731], 
             UndirectedEdge[38, 250] -> 
             RGBColor[
              0.9770092142863354, 0.9428337657309378, 0.5831873792076157], 
             UndirectedEdge[140, 191] -> 
             RGBColor[
              0.6753891788981803, 0.7463384267939157, 0.9682801395479993], 
             UndirectedEdge[204, 261] -> 
             RGBColor[
              0.17918768478614402`, 0.3056679962386074, 0.9335158456129223], 
             UndirectedEdge[337, 354] -> 
             RGBColor[
              0.28225838404285286`, 0.4140018362171884, 0.9393855694561568], 
             UndirectedEdge[300, 314] -> 
             RGBColor[
              0.9079043794586273, 0.7685321222787813, 0.6113544605961532], 
             UndirectedEdge[292, 378] -> 
             RGBColor[
              0.20977255736756456`, 0.3378146365146045, 0.93525760886017], 
             UndirectedEdge[153, 361] -> 
             RGBColor[
              0.3365286408445437, 0.46590592710341294`, 0.9426642853073897], 
             UndirectedEdge[240, 334] -> 
             RGBColor[
              0.2503027734840032, 0.3804144634171059, 0.9375657447089196], 
             UndirectedEdge[52, 260] -> 
             RGBColor[
              0.5977997596730911, 0.6799974627988412, 0.9637251611956289], 
             UndirectedEdge[128, 177] -> 
             RGBColor[
              0.32406082685861914`, 0.45510693327935664`, 0.9418698472250615],
              UndirectedEdge[16, 85] -> 
             RGBColor[
              0.2415839884274967, 0.3712504675198166, 0.9370692227982382], 
             UndirectedEdge[179, 303] -> 
             RGBColor[
              0.27962744891017854`, 0.4112365565818258, 0.9392357415924706], 
             UndirectedEdge[48, 320] -> 
             RGBColor[
              0.5676684575710711, 0.6581064280542859, 0.9600245413086331], 
             UndirectedEdge[136, 320] -> 
             RGBColor[
              0.6642380668783059, 0.7372628617572051, 0.9674177280321361], 
             UndirectedEdge[96, 192] -> 
             RGBColor[
              0.3157006162298024, 0.44584698924097155`, 0.9414110583152703], 
             UndirectedEdge[140, 357] -> 
             RGBColor[
              0.6738075491078213, 0.7451028455808557, 0.9681224974716671], 
             UndirectedEdge[202, 306] -> 
             RGBColor[
              0.913357870811167, 0.6728952265487068, 0.2705007142320376], 
             UndirectedEdge[114, 258] -> 
             RGBColor[
              0.29090557114945215`, 0.42122924819894025`, 0.9399461663762204],
              UndirectedEdge[87, 236] -> 
             RGBColor[
              0.2703304585010046, 0.4014648301985463, 0.938706291742333], 
             UndirectedEdge[116, 362] -> 
             RGBColor[
              0.41044018393094006`, 0.5299243908226783, 0.9473738634754435], 
             UndirectedEdge[36, 64] -> 
             RGBColor[
              0.45931878415001925`, 0.5704587671539738, 0.9509862102607236], 
             UndirectedEdge[245, 304] -> 
             RGBColor[
              0.22449864114749254`, 0.35329268425494775`, 0.9360962375461481],
              UndirectedEdge[187, 218] -> 
             RGBColor[
              0.8769988069965478, 0.9047590594733392, 0.9881301231890498], 
             UndirectedEdge[26, 370] -> 
             RGBColor[
              0.6431647387570222, 0.7183868662092043, 0.9670053375726531], 
             UndirectedEdge[91, 141] -> 
             RGBColor[
              0.3113425799408942, 0.43982647528346147`, 0.9412155979078848], 
             UndirectedEdge[55, 385] -> 
             RGBColor[
              0.4894768493024928, 0.5950665939158499, 0.9533260603680459], 
             UndirectedEdge[179, 231] -> 
             RGBColor[
              0.28916364068982703`, 0.4212596987717169, 0.9397788136067902], 
             UndirectedEdge[94, 177] -> 
             RGBColor[
              0.29101623446385616`, 0.4219899291618881, 0.9399288750630955], 
             UndirectedEdge[225, 383] -> 
             RGBColor[
              0.26867221560749177`, 0.39972191177879235`, 0.938611857262698], 
             UndirectedEdge[37, 134] -> 
             RGBColor[
              0.24206319644531432`, 0.3717541455300861, 0.9370965129859282], 
             UndirectedEdge[255, 341] -> 
             RGBColor[
              0.24102934533176992`, 0.3706675024598044, 0.9370376366944575], 
             UndirectedEdge[206, 278] -> 
             RGBColor[
              0.24198884677049953`, 0.37167599930781414`, 0.937092278881938], 
             UndirectedEdge[131, 279] -> 
             RGBColor[
              0.934057909721427, 0.776268616484077, 0.26579965018330676`], 
             UndirectedEdge[7, 203] -> 
             RGBColor[
              0.3404012849561078, 0.4676562364290735, 0.9429697763439697], 
             UndirectedEdge[101, 151] -> 
             RGBColor[
              0.2883386750076016, 0.41973713317698713`, 0.9397558331587401], 
             UndirectedEdge[200, 296] -> 
             RGBColor[
              0.2860905976760283, 0.41802973572203384`, 0.939603808353314], 
             UndirectedEdge[86, 229] -> 
             RGBColor[
              0.27371625819309475`, 0.4050235203470323, 0.9388991080259558], 
             UndirectedEdge[138, 382] -> 
             RGBColor[
              0.8590618993454652, 0.3914765169996446, 0.2017043627957868], 
             UndirectedEdge[195, 278] -> 
             RGBColor[
              0.24905516487064655`, 0.3791031476615132, 0.9374946952440605], 
             UndirectedEdge[65, 113] -> 
             RGBColor[
              0.6559239156864949, 0.7291861264524664, 0.9676704388099608], 
             UndirectedEdge[249, 270] -> 
             RGBColor[
              0.25957821450255336`, 0.3901635400245296, 0.9380939673531408], 
             UndirectedEdge[319, 388] -> 
             RGBColor[
              0.23247439130222355`, 0.3616757033593372, 0.9365504447183952], 
             UndirectedEdge[138, 256] -> 
             RGBColor[
              0.522325620948562, 0.25191357841785655`, 0.5511492082429574], 
             UndirectedEdge[246, 286] -> 
             RGBColor[
              0.5850263680482788, 0.6724463268342122, 0.9614245811742612], 
             UndirectedEdge[188, 208] -> 
             RGBColor[
              0.25008631824464794`, 0.38018695523648866`, 0.9375534179032552],
              UndirectedEdge[173, 345] -> 
             RGBColor[
              0.21415750276433887`, 0.34242349214821033`, 0.9355073250135709],
              UndirectedEdge[84, 156] -> 
             RGBColor[
              0.18244327672263497`, 0.3090898297803102, 0.9337012467574888], 
             UndirectedEdge[136, 349] -> 
             RGBColor[
              0.5319806271096528, 0.6307093057544687, 0.9563581696523957], 
             UndirectedEdge[117, 346] -> 
             RGBColor[
              0.3472745636844825, 0.4752135053615816, 0.9433490060085041], 
             UndirectedEdge[26, 197] -> 
             RGBColor[
              0.7219321437839568, 0.7790682930787789, 0.8931643392096228], 
             UndirectedEdge[328, 362] -> 
             RGBColor[
              0.35704810596381387`, 0.4836788564514203, 0.9439717674801389], 
             UndirectedEdge[187, 275] -> 
             RGBColor[
              0.9180172404014313, 0.9346976892728417, 0.8827763564020366], 
             UndirectedEdge[20, 121] -> 
             RGBColor[
              0.48042756078829996`, 0.5878320132896839, 0.9525827103922078], 
             UndirectedEdge[198, 302] -> 
             RGBColor[
              0.9068833316004294, 0.9166145009599966, 0.6941933109869335], 
             UndirectedEdge[1, 312] -> 
             RGBColor[
              0.4114701041040899, 0.5305547297160472, 0.9475118048057347], 
             UndirectedEdge[89, 292] -> 
             RGBColor[
              0.21480075229645693`, 0.3430995881908423, 0.9355439571228226], 
             UndirectedEdge[304, 315] -> 
             RGBColor[
              0.23118633013209117`, 0.360321869401733, 0.9364770915402718], 
             UndirectedEdge[21, 64] -> 
             RGBColor[
              0.3559387070583645, 0.4827179508795304, 0.9439010775628867], 
             UndirectedEdge[201, 351] -> 
             RGBColor[
              0.26108538890678307`, 0.3917476758837515, 0.9381797987057969], 
             UndirectedEdge[17, 218] -> 
             RGBColor[
              0.7227901892843811, 0.7824598484159166, 0.9739304322567687], 
             UndirectedEdge[266, 365] -> 
             RGBColor[
              0.25561932448523794`, 0.3860024956082064, 0.9378685144233075], 
             UndirectedEdge[112, 180] -> 
             RGBColor[
              0.34759559659056605`, 0.4754915679292482, 0.9433694619414015], 
             UndirectedEdge[247, 289] -> 
             RGBColor[
              0.9023804239029701, 0.648813195238765, 0.2402147401558417], 
             UndirectedEdge[15, 45] -> 
             RGBColor[
              0.29968000514429743`, 0.4323130645893829, 0.9403777050049051], 
             UndirectedEdge[57, 92] -> 
             RGBColor[
              0.2804356326225079, 0.4120860089052909, 0.9392817664592872], 
             UndirectedEdge[53, 86] -> 
             RGBColor[
              0.2948901577623302, 0.4272786312970708, 0.9401049302824465], 
             UndirectedEdge[114, 154] -> 
             RGBColor[
              0.3795179550306004, 0.5031411103456188, 0.9454035263933673], 
             UndirectedEdge[71, 237] -> 
             RGBColor[
              0.7247695222504801, 0.7843485609125668, 0.9737619050151656], 
             UndirectedEdge[241, 375] -> 
             RGBColor[
              0.2729036444443398, 0.40416941177440335`, 0.9388528308751185], 
             UndirectedEdge[100, 282] -> 
             RGBColor[
              0.5117379294109875, 0.6123392626277626, 0.9553276443786378], 
             UndirectedEdge[55, 146] -> 
             RGBColor[
              0.4694319452875655, 0.5787932378238967, 0.951748052097088], 
             UndirectedEdge[309, 319] -> 
             RGBColor[
              0.25618706106620875`, 0.38659922275138503`, 0.9379008461817029],
              UndirectedEdge[13, 302] -> 
             RGBColor[
              0.9755285816369456, 0.9706262250120263, 0.6756345411379316], 
             UndirectedEdge[110, 348] -> 
             RGBColor[
              0.25926658322907375`, 0.3898359957975386, 0.9380762204131332], 
             UndirectedEdge[217, 363] -> 
             RGBColor[
              0.8426690815936368, 0.3225184221692448, 0.1882402931746939], 
             UndirectedEdge[39, 380] -> 
             RGBColor[
              0.2692913647455158, 0.4003726767791782, 0.9386471168901593], 
             UndirectedEdge[248, 304] -> 
             RGBColor[
              0.2176531615259033, 0.3460976511441812, 0.9357063976086782], 
             UndirectedEdge[204, 400] -> 
             RGBColor[
              0.2842689537951664, 0.40863855928315673`, 0.939773820202813], 
             UndirectedEdge[69, 168] -> 
             RGBColor[
              0.5791845558214077, 0.6688214100579597, 0.9603057503889199], 
             UndirectedEdge[68, 86] -> 
             RGBColor[
              0.28863048877409425`, 0.42069932230449786`, 0.9397484513939167],
              UndirectedEdge[175, 264] -> 
             RGBColor[
              0.18448157797338877`, 0.31123221363061604`, 0.9338173249983228],
              UndirectedEdge[1, 92] -> 
             RGBColor[
              0.3238234376355826, 0.4529521291016748, 0.9419260903719718], 
             UndirectedEdge[368, 393] -> 
             RGBColor[
              0.21780075210083538`, 0.3462527781962177, 0.93571480267358], 
             UndirectedEdge[332, 361] -> 
             RGBColor[
              0.4414240641856033, 0.5547544143941453, 0.9499025740169657], 
             UndirectedEdge[80, 203] -> 
             RGBColor[
              0.31290698696191654`, 0.4438420574101029, 0.9412178639880329], 
             UndirectedEdge[20, 347] -> 
             RGBColor[
              0.3438545327447645, 0.469598113054395, 0.9432282288718172], 
             UndirectedEdge[18, 311] -> 
             RGBColor[
              0.7322903023542322, 0.7896729975900088, 0.9664706721730203], 
             UndirectedEdge[170, 282] -> 
             RGBColor[
              0.5459157043281511, 0.6419423334360943, 0.9575054219741398], 
             UndirectedEdge[198, 323] -> 
             RGBColor[
              0.828349936933913, 0.8659677710237936, 0.9834899505331167], 
             UndirectedEdge[168, 357] -> 
             RGBColor[
              0.6729202964028389, 0.7444097170243531, 0.9680340644138824], 
             UndirectedEdge[180, 326] -> 
             RGBColor[
              0.3528301288862901, 0.48002545670856134`, 0.9437030017105699], 
             UndirectedEdge[18, 340] -> 
             RGBColor[
              0.9694923470519816, 0.9738780487256253, 0.770900506424754], 
             UndirectedEdge[74, 340] -> 
             RGBColor[
              0.9092258023331339, 0.9260683158029884, 0.7736525641500547], 
             UndirectedEdge[173, 204] -> 
             RGBColor[
              0.20264730553141047`, 0.33032554506774736`, 0.9348518363089665],
              UndirectedEdge[26, 30] -> 
             RGBColor[
              0.31701994287924884`, 0.4369570883961569, 0.9418741496415883], 
             UndirectedEdge[169, 240] -> 
             RGBColor[
              0.22995248947003588`, 0.35902502463589653`, 0.9364068261398715],
              UndirectedEdge[95, 371] -> 
             RGBColor[
              0.27691206805261726`, 0.40838251913543877`, 0.9390811046696785],
              UndirectedEdge[65, 356] -> 
             RGBColor[
              0.5168552955479615, 0.6186454388483807, 0.9551078886503179], 
             UndirectedEdge[264, 310] -> 
             RGBColor[
              0.18630458251799184`, 0.3131483069921579, 0.9339211424102444], 
             UndirectedEdge[96, 114] -> 
             RGBColor[
              0.3078946845637386, 0.4390858835693603, 0.940913671252023], 
             UndirectedEdge[244, 308] -> 
             RGBColor[
              0.2605622771689302, 0.3911978522800683, 0.9381500082662007], 
             UndirectedEdge[187, 298] -> 
             RGBColor[
              0.8336819864556111, 0.8702194025777671, 0.983998526176473], 
             UndirectedEdge[58, 228] -> 
             RGBColor[
              0.3333340850867448, 0.46222040417284493`, 0.9424943639948453], 
             UndirectedEdge[36, 82] -> 
             RGBColor[
              0.4494472254875384, 0.5619085191994977, 0.950357203271827], 
             UndirectedEdge[72, 355] -> 
             RGBColor[
              0.2293238377834227, 0.358364271854447, 0.9363710253563257], 
             UndirectedEdge[22, 350] -> 
             RGBColor[
              0.36253057369193453`, 0.4869086502715662, 0.9443767178010922], 
             UndirectedEdge[58, 192] -> 
             RGBColor[
              0.32165036846239214`, 0.45210055607350297`, 0.9417498879030466],
              UndirectedEdge[3, 174] -> 
             RGBColor[
              0.5493425209245979, 0.6414387311936623, 0.9591931799908751], 
             UndirectedEdge[44, 54] -> 
             RGBColor[
              0.3749740145051137, 0.4982078184475008, 0.9451505160427869], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.416297218948796, 0.5331956497034136, 0.948244914168578], 
             UndirectedEdge[170, 271] -> 
             RGBColor[
              0.37587875919358854`, 0.49980798052879155`, 0.9451782688612774],
              UndirectedEdge[192, 201] -> 
             RGBColor[
              0.3104580154232146, 0.4403366833931581, 0.941112499955068], 
             UndirectedEdge[274, 395] -> 
             RGBColor[
              0.2518980358087536, 0.3820911852658918, 0.9376565925383351], 
             UndirectedEdge[208, 284] -> 
             RGBColor[
              0.23854240400840393`, 0.3680535694477596, 0.9368960090651918], 
             UndirectedEdge[237, 320] -> 
             RGBColor[
              0.644156525821959, 0.7209597620645476, 0.9658368355590718], 
             UndirectedEdge[119, 380] -> 
             RGBColor[
              0.25299451614994406`, 0.383243655625352, 0.9377190354716685], 
             UndirectedEdge[342, 398] -> 
             RGBColor[
              0.7713918010534688, 0.8216082690775031, 0.9746694433091629], 
             UndirectedEdge[90, 264] -> 
             RGBColor[
              0.44791840801160593`, 0.5435825734144455, 0.9527225707160447], 
             UndirectedEdge[212, 367] -> 
             RGBColor[
              0.21510593499852879`, 0.3434203545604207, 0.9355613368262283], 
             UndirectedEdge[92, 284] -> 
             RGBColor[
              0.26583096592771405`, 0.3967355782197115, 0.9384500522966869], 
             UndirectedEdge[267, 342] -> 
             RGBColor[
              0.5872785724074823, 0.6758182275354083, 0.9606518669736626], 
             UndirectedEdge[107, 297] -> 
             RGBColor[
              0.892928350056968, 0.6310869487653001, 0.5801992997291281], 
             UndirectedEdge[163, 245] -> 
             RGBColor[
              0.2374360489235272, 0.36689072010659024`, 0.9368330037798137], 
             UndirectedEdge[72, 200] -> 
             RGBColor[
              0.24919308184682543`, 0.37924810714791846`, 0.937502549411824], 
             UndirectedEdge[254, 286] -> 
             RGBColor[
              0.5978806349455185, 0.6831403582378857, 0.9623651309393161], 
             UndirectedEdge[269, 307] -> 
             RGBColor[
              0.9891494518709179, 0.9878632201941573, 0.6900803930330166], 
             UndirectedEdge[240, 304] -> 
             RGBColor[
              0.22915247220042573`, 0.35818415576151175`, 0.9363612663398866],
              UndirectedEdge[228, 332] -> 
             RGBColor[
              0.44753939238477464`, 0.5600512043149352, 0.9502922373222444], 
             UndirectedEdge[104, 109] -> 
             RGBColor[
              0.9639852685830836, 0.8836832833010115, 0.5065761886025747], 
             UndirectedEdge[28, 372] -> 
             RGBColor[
              0.2698833093261751, 0.4009948480649053, 0.9386808272583244], 
             UndirectedEdge[28, 362] -> 
             RGBColor[
              0.34647407000563907`, 0.4726287790194402, 0.9433672519077005], 
             UndirectedEdge[209, 227] -> 
             RGBColor[
              0.24347750032410487`, 0.3732406685787401, 0.9371770554995502], 
             UndirectedEdge[245, 371] -> 
             RGBColor[
              0.25097222698134913`, 0.38111810148861974`, 0.9376038690952258],
              UndirectedEdge[308, 397] -> 
             RGBColor[
              0.25521896402580857`, 0.3855816913810268, 0.9378457144874233], 
             UndirectedEdge[58, 87] -> 
             RGBColor[
              0.29447485481202706`, 0.42684212156457424`, 0.9400812793938123],
              UndirectedEdge[154, 332] -> 
             RGBColor[
              0.47868981834297064`, 0.5870321376139921, 0.9522771149190605], 
             UndirectedEdge[97, 180] -> 
             RGBColor[
              0.40427723483543804`, 0.5245863540749827, 0.9469811658087601], 
             UndirectedEdge[202, 300] -> 
             RGBColor[
              0.873168201892003, 0.5137197571930974, 0.21575357463755512`], 
             UndirectedEdge[25, 317] -> 
             RGBColor[
              0.9196690890458292, 0.6829063077266104, 0.4996382373528887], 
             UndirectedEdge[93, 128] -> 
             RGBColor[
              0.2857256322546389, 0.41603117628641406`, 0.9396421556226617], 
             UndirectedEdge[68, 178] -> 
             RGBColor[
              0.2603565331566741, 0.3909816022782634, 0.9381382914490737], 
             UndirectedEdge[271, 273] -> 
             RGBColor[
              0.2911126400044641, 0.42330822062509427`, 0.9398898062344726], 
             UndirectedEdge[149, 318] -> 
             RGBColor[
              0.22201805165799737`, 0.3506854274230307, 0.9359549716444248], 
             UndirectedEdge[42, 358] -> 
             RGBColor[
              0.9504012676368335, 0.9272297470138823, 0.6629122325696076], 
             UndirectedEdge[155, 170] -> 
             RGBColor[
              0.3747576276064379, 0.498629600146848, 0.9451144220759548], 
             UndirectedEdge[193, 338] -> 
             RGBColor[
              0.9083139927934867, 0.9256835176042191, 0.801309811633953], 
             UndirectedEdge[79, 109] -> 
             RGBColor[
              0.79245120355282, 0.8352543310125031, 0.854215095221335], 
             UndirectedEdge[173, 175] -> 
             RGBColor[
              0.20264987627198583`, 0.3303282470790865, 0.9348519827088393], 
             UndirectedEdge[95, 178] -> 
             RGBColor[
              0.2628834870920424, 0.39363759108246865`, 0.9382821977373995], 
             UndirectedEdge[243, 348] -> 
             RGBColor[
              0.27566358738232355`, 0.40707028679271356`, 0.9390100055424669],
              UndirectedEdge[56, 83] -> 
             RGBColor[
              0.4019083501795848, 0.5225345452496872, 0.9468302225732115], 
             UndirectedEdge[205, 207] -> 
             RGBColor[
              0.967562165289962, 0.8957834071543473, 0.4992706546503005], 
             UndirectedEdge[74, 302] -> 
             RGBColor[
              0.9059752552459537, 0.9158904255240137, 0.6941066978535942], 
             UndirectedEdge[179, 196] -> 
             RGBColor[
              0.2837836367777321, 0.41560497354815545`, 0.9394724303429989], 
             UndirectedEdge[174, 338] -> 
             RGBColor[
              0.8614468790047858, 0.8890515325777966, 0.796643588235805], 
             UndirectedEdge[159, 167] -> 
             RGBColor[
              0.30749203096032607`, 0.43842628345076595`, 0.9408993959616536],
              UndirectedEdge[251, 356] -> 
             RGBColor[
              0.6703471241239707, 0.7405191581131181, 0.9690711033483659], 
             UndirectedEdge[238, 277] -> 
             RGBColor[
              0.24351796868213066`, 0.3732832033888673, 0.9371793601126722], 
             UndirectedEdge[163, 164] -> 
             RGBColor[
              0.24375587866941067`, 0.373533261869863, 0.9371929087344915], 
             UndirectedEdge[213, 230] -> 
             RGBColor[
              0.939912673270707, 0.7956677722978341, 0.2903688589282392], 
             UndirectedEdge[246, 343] -> 
             RGBColor[
              0.5830017143905886, 0.6708646520088869, 0.9612227826191269], 
             UndirectedEdge[53, 95] -> 
             RGBColor[
              0.2855112454690256, 0.4174207998194225, 0.9395708151022], 
             UndirectedEdge[139, 184] -> 
             RGBColor[
              0.21446679583023515`, 0.34274857877078024`, 0.9355249387961155],
              UndirectedEdge[101, 308] -> 
             RGBColor[
              0.26096510566357906`, 0.39162125056874597`, 0.9381729487530396],
              UndirectedEdge[3, 52] -> 
             RGBColor[
              0.3783625716146186, 0.5021403753019544, 0.9453299063837663], 
             UndirectedEdge[136, 286] -> 
             RGBColor[
              0.6724159966518739, 0.7436515226508849, 0.9682328276448666], 
             UndirectedEdge[164, 169] -> 
             RGBColor[
              0.23161848816298614`, 0.3607760948926053, 0.9365017023008109], 
             UndirectedEdge[14, 102] -> 
             RGBColor[
              0.9068270565903578, 0.5698348658899638, 0.39664654648642544`], 
             UndirectedEdge[232, 281] -> 
             RGBColor[
              0.5787753460534887, 0.6689149253152545, 0.9599824618467317], 
             UndirectedEdge[56, 349] -> 
             RGBColor[
              0.44815708600119175`, 0.5625928756893122, 0.949777151123613], 
             UndirectedEdge[225, 324] -> 
             RGBColor[
              0.2685328797360218, 0.39957546094347285`, 0.9386039222909468], 
             UndirectedEdge[5, 272] -> 
             RGBColor[
              0.744229977263282, 0.800290827008182, 0.9750955199196911], 
             UndirectedEdge[68, 371] -> 
             RGBColor[
              0.27438511411724903`, 0.40572653033123346`, 0.9389371983813526],
              UndirectedEdge[151, 397] -> 
             RGBColor[
              0.28259253336983103`, 0.413697573989268, 0.9394285988931239], 
             UndirectedEdge[1, 356] -> 
             RGBColor[
              0.43918071918933627`, 0.5530514553912338, 0.949693285932573], 
             UndirectedEdge[96, 115] -> 
             RGBColor[
              0.262758793949384, 0.3935065306835328, 0.9382750966473921], 
             UndirectedEdge[328, 347] -> 
             RGBColor[
              0.29474363512034735`, 0.42706072191761096`, 0.940098925902251], 
             UndirectedEdge[80, 159] -> 
             RGBColor[
              0.3329254963503931, 0.4627850644418876, 0.9424346961263579], 
             UndirectedEdge[50, 121] -> 
             RGBColor[
              0.5036718866822538, 0.607942553625398, 0.9540700424119916], 
             UndirectedEdge[108, 342] -> 
             RGBColor[
              0.48546363914421214`, 0.5908319937486516, 0.9532799343430639], 
             UndirectedEdge[178, 315] -> 
             RGBColor[
              0.24363133500537287`, 0.37340235858243487`, 0.9371858161570703],
              UndirectedEdge[146, 228] -> 
             RGBColor[
              0.45159420731101624`, 0.5633430857393887, 0.9506114472065146], 
             UndirectedEdge[63, 152] -> 
             RGBColor[
              0.5710886094431091, 0.5911007265104762, 0.6136429928057057], 
             UndirectedEdge[43, 137] -> 
             RGBColor[
              0.22449567090087896`, 0.35328956233743236`, 0.9360960683949977],
              UndirectedEdge[97, 141] -> 
             RGBColor[
              0.401174197469898, 0.5218986590721447, 0.9467834430117361], 
             UndirectedEdge[25, 207] -> 
             RGBColor[
              0.8942834665962583, 0.5873379716371798, 0.2323719540995589], 
             UndirectedEdge[214, 310] -> 
             RGBColor[
              0.5831756221385668, 0.6483250855590861, 0.9230305133548782], 
             UndirectedEdge[37, 87] -> 
             RGBColor[
              0.2699691213947309, 0.4010850419897568, 0.9386857141286811], 
             UndirectedEdge[146, 262] -> 
             RGBColor[
              0.736987048840004, 0.7937027834714817, 0.9726540973253948], 
             UndirectedEdge[322, 364] -> 
             RGBColor[
              0.428972946302528, 0.5444804947900268, 0.9489681159313363], 
             UndirectedEdge[219, 311] -> 
             RGBColor[
              0.48328094147507245`, 0.5912218175992272, 0.9525107826182344], 
             UndirectedEdge[5, 260] -> 
             RGBColor[
              0.8251985302055844, 0.863544075950503, 0.9831657085828327], 
             UndirectedEdge[204, 389] -> 
             RGBColor[
              0.17900756331513207`, 0.305478677152213, 0.9335055879616141], 
             UndirectedEdge[275, 279] -> 
             RGBColor[
              0.9688751403565641, 0.9066136951652177, 0.5278514920501343], 
             UndirectedEdge[78, 289] -> 
             RGBColor[
              0.8697986288874946, 0.4756199934349731, 0.21204915614425965`], 
             UndirectedEdge[163, 329] -> 
             RGBColor[
              0.2400560374603316, 0.3696444941756393, 0.936982208251059], 
             UndirectedEdge[47, 181] -> 
             RGBColor[
              0.5006021052009016, 0.6049229030605833, 0.9539741177513421], 
             UndirectedEdge[267, 291] -> 
             RGBColor[
              0.6338452626420983, 0.7127939223878283, 0.964884724751121], 
             UndirectedEdge[28, 301] -> 
             RGBColor[
              0.27255350960952185`, 0.40380139786317903`, 0.9388328912142536],
              UndirectedEdge[174, 193] -> 
             RGBColor[
              0.7754724977883137, 0.8245433157037161, 0.9782504569369469], 
             UndirectedEdge[60, 263] -> 
             RGBColor[
              0.3098059764171655, 0.4384458415430197, 0.9411195068336586], 
             UndirectedEdge[122, 385] -> 
             RGBColor[
              0.510754315643456, 0.6134960658238386, 0.9546818417083673], 
             UndirectedEdge[282, 350] -> 
             RGBColor[
              0.5398022619922347, 0.6366471769552697, 0.9571158788344], 
             UndirectedEdge[142, 306] -> 
             RGBColor[
              0.8959800446329425, 0.5393216395308846, 0.25385968825832217`], 
             UndirectedEdge[6, 289] -> 
             RGBColor[
              0.9455504255792939, 0.808391434737298, 0.3768472415142159], 
             UndirectedEdge[3, 117] -> 
             RGBColor[
              0.35979838664313185`, 0.4860610113427193, 0.9441470129330474], 
             UndirectedEdge[6, 132] -> 
             RGBColor[
              0.896284952197167, 0.9156286210821021, 0.7489609820272407], 
             UndirectedEdge[22, 394] -> 
             RGBColor[
              0.32559317401626164`, 0.45491533120018696`, 0.9420230993562184],
              UndirectedEdge[11, 391] -> 
             RGBColor[
              0.8719267260498035, 0.4460000576161881, 0.2122170074273244], 
             UndirectedEdge[34, 249] -> 
             RGBColor[
              0.2909291460215572, 0.4227877812822719, 0.9398913506685179], 
             UndirectedEdge[269, 306] -> 
             RGBColor[
              0.9817175223804617, 0.9496479498761543, 0.4126513364277588], 
             UndirectedEdge[69, 394] -> 
             RGBColor[
              0.42354328649608, 0.5403260059804602, 0.948470615599907], 
             UndirectedEdge[361, 369] -> 
             RGBColor[
              0.30654023496768024`, 0.43518917662023243`, 0.9409270894573605],
              UndirectedEdge[85, 184] -> 
             RGBColor[
              0.22953519250719354`, 0.35858641906979366`, 0.9363830616951732],
              UndirectedEdge[73, 96] -> 
             RGBColor[
              0.26501373249139615`, 0.3958766140625488, 0.9384035120614771], 
             UndirectedEdge[71, 382] -> 
             RGBColor[
              0.8849504676641144, 0.7666705508963009, 0.612411028914603], 
             UndirectedEdge[122, 165] -> 
             RGBColor[
              0.48941818004964077`, 0.5961744297668246, 0.9530021829575823], 
             UndirectedEdge[321, 331] -> 
             RGBColor[
              0.634939466831133, 0.7117908877119044, 0.9662504402131629], 
             UndirectedEdge[296, 374] -> 
             RGBColor[
              0.2888126336637139, 0.4208907681321412, 0.9397588242759214], 
             UndirectedEdge[66, 297] -> 
             RGBColor[
              0.9597109537164616, 0.9397882388587341, 0.661988741969209], 
             UndirectedEdge[75, 145] -> 
             RGBColor[
              0.24110109065239455`, 0.37074291134069687`, 0.9370417224843294],
              UndirectedEdge[105, 239] -> 
             RGBColor[
              0.37092951443948974`, 0.4957022347731742, 0.9448562785533615], 
             UndirectedEdge[92, 354] -> 
             RGBColor[
              0.2837186388686095, 0.41553665662456213`, 0.9394687288082302], 
             UndirectedEdge[188, 369] -> 
             RGBColor[
              0.26226993371413826`, 0.39299270758076044`, 0.9382472567801988],
              UndirectedEdge[170, 251] -> 
             RGBColor[
              0.6336427393204518, 0.7104942073432939, 0.966244231440377], 
             UndirectedEdge[53, 68] -> 
             RGBColor[
              0.28298429153365734`, 0.4147648110152172, 0.9394269088138741], 
             UndirectedEdge[274, 318] -> 
             RGBColor[
              0.2272727207343431, 0.3562084177875322, 0.9362542172747363], 
             UndirectedEdge[179, 359] -> 
             RGBColor[
              0.2576056390091489, 0.3880902381124516, 0.9379816320969553], 
             UndirectedEdge[20, 328] -> 
             RGBColor[
              0.3585480828066595, 0.484978061001665, 0.9440673446781876], 
             UndirectedEdge[307, 352] -> 
             RGBColor[
              0.9896970551583855, 0.989034488254865, 0.7496836314580985], 
             UndirectedEdge[6, 216] -> 
             RGBColor[
              0.8262245586177389, 0.8608969091391403, 0.7419780167468455], 
             UndirectedEdge[297, 385] -> 
             RGBColor[
              0.76103003285282, 0.8129579010796052, 0.9674643990261943], 
             UndirectedEdge[40, 348] -> 
             RGBColor[
              0.3011336768698887, 0.43101491807386594`, 0.9405639649079968], 
             UndirectedEdge[229, 329] -> 
             RGBColor[
              0.2410174933653264, 0.37065504529161414`, 0.937036961742502], 
             UndirectedEdge[6, 213] -> 
             RGBColor[
              0.9521578283629528, 0.8364523308595698, 0.38226017426140096`], 
             UndirectedEdge[189, 374] -> 
             RGBColor[
              0.2883252349784382, 0.42037848121105487`, 0.9397310676418367], 
             UndirectedEdge[97, 140] -> 
             RGBColor[
              0.5571047214907582, 0.6505692358866151, 0.9586689069541604], 
             UndirectedEdge[34, 386] -> 
             RGBColor[
              0.32582607560218535`, 0.4566359030170521, 0.9419823273140535], 
             UndirectedEdge[162, 313] -> 
             RGBColor[
              0.26444617460999714`, 0.3952800747439503, 0.938371190479758], 
             UndirectedEdge[258, 392] -> 
             RGBColor[
              0.25044123686096187`, 0.3805599972053746, 0.9375736299933992], 
             UndirectedEdge[45, 273] -> 
             RGBColor[
              0.2854682454604019, 0.41737560408400093`, 0.9395683663153217], 
             UndirectedEdge[226, 393] -> 
             RGBColor[
              0.2307270128999809, 0.3598390978683905, 0.9364509341034022], 
             UndirectedEdge[88, 168] -> 
             RGBColor[
              0.8302321284771527, 0.8662542155842119, 0.8889737374567761], 
             UndirectedEdge[188, 327] -> 
             RGBColor[
              0.2928390260811543, 0.4242124195155595, 0.9400214534598996], 
             UndirectedEdge[59, 349] -> 
             RGBColor[
              0.38969866664907243`, 0.5119591310520951, 0.9460522323352465], 
             UndirectedEdge[260, 398] -> 
             RGBColor[
              0.8741897182555676, 0.9025122258100744, 0.9845069042800476], 
             UndirectedEdge[248, 353] -> 
             RGBColor[
              0.21329376874399575`, 0.34151565292892977`, 0.9354581366388923],
              UndirectedEdge[30, 389] -> 
             RGBColor[
              0.17900757935671766`, 0.3054786940129366, 0.9335055888751587], 
             UndirectedEdge[216, 311] -> 
             RGBColor[
              0.5892378065656463, 0.6771523472031584, 0.9609814583426657], 
             UndirectedEdge[66, 307] -> 
             RGBColor[
              0.9790114308840521, 0.9540083964475, 0.6215212155905427], 
             UndirectedEdge[94, 225] -> 
             RGBColor[
              0.2586160366315361, 0.3891522300764899, 0.9380391727468009], 
             UndirectedEdge[177, 324] -> 
             RGBColor[
              0.3009330775683418, 0.4324131600288711, 0.9404936246072413], 
             UndirectedEdge[79, 320] -> 
             RGBColor[
              0.6503499887449748, 0.725987894277777, 0.9663244076477739], 
             UndirectedEdge[133, 234] -> 
             RGBColor[
              0.31799880832538563`, 0.4487941940432452, 0.9415224703076799], 
             UndirectedEdge[35, 195] -> 
             RGBColor[
              0.2633678783864708, 0.39414671704509485`, 0.9383097831050244], 
             UndirectedEdge[34, 86] -> 
             RGBColor[
              0.30641268277319833`, 0.4390619601211778, 0.940773115180684], 
             UndirectedEdge[98, 131] -> 
             RGBColor[
              0.9500181408117219, 0.8331560489585412, 0.3119185917864623], 
             UndirectedEdge[173, 261] -> 
             RGBColor[
              0.2029079903175545, 0.3305995413063548, 0.9348666819218888], 
             UndirectedEdge[103, 331] -> 
             RGBColor[
              0.39832931347278433`, 0.519434563541872, 0.9466021695190721], 
             UndirectedEdge[135, 322] -> 
             RGBColor[
              0.5058470879872912, 0.6097084800365293, 0.954241282226749], 
             UndirectedEdge[50, 181] -> 
             RGBColor[
              0.5107299622168331, 0.6136726173070488, 0.9546256799726562], 
             UndirectedEdge[35, 153] -> 
             RGBColor[
              0.2992359056961653, 0.4310433224437109, 0.940381814697533], 
             UndirectedEdge[121, 362] -> 
             RGBColor[
              0.4789275839454543, 0.5865328087394392, 0.9524871331941591], 
             UndirectedEdge[84, 152] -> 
             RGBColor[
              0.18127159018880934`, 0.30785831294404253`, 0.9336345209427424],
              UndirectedEdge[295, 345] -> 
             RGBColor[
              0.22216737223106828`, 0.3508423728127994, 0.9359634752301611], 
             UndirectedEdge[22, 266] -> 
             RGBColor[
              0.27365816407618504`, 0.40496245974678047`, 0.9388957996519403],
              UndirectedEdge[271, 335] -> 
             RGBColor[
              0.2936530311811995, 0.4259783328219468, 0.9400344777538158], 
             UndirectedEdge[175, 261] -> 
             RGBColor[
              0.1791902555267194, 0.3056706982499465, 0.9335159920127951], 
             UndirectedEdge[59, 254] -> 
             RGBColor[
              0.401764791398701, 0.521970513340684, 0.9469425623795822], 
             UndirectedEdge[53, 270] -> 
             RGBColor[
              0.26941555401375766`, 0.4005032075741548, 0.9386541892852642], 
             UndirectedEdge[214, 300] -> 
             RGBColor[
              0.9368849358196452, 0.7904007327583793, 0.5711375264891978], 
             UndirectedEdge[3, 386] -> 
             RGBColor[
              0.35472139925516205`, 0.48166358004406556`, 0.9438235117860897],
              UndirectedEdge[299, 336] -> 
             RGBColor[
              0.2125676316732109, 0.34075243682778544`, 0.9354167842069347], 
             UndirectedEdge[110, 351] -> 
             RGBColor[
              0.25066121746090764`, 0.3807912107634932, 0.9375861575631339], 
             UndirectedEdge[172, 328] -> 
             RGBColor[
              0.3054309232922502, 0.438293739399488, 0.9407075511532149], 
             UndirectedEdge[185, 302] -> 
             RGBColor[
              0.905483758897311, 0.5759228028237954, 0.28769672462851575`], 
             UndirectedEdge[370, 391] -> 
             RGBColor[
              0.8258037070409253, 0.5129958576116641, 0.5754614637475668], 
             UndirectedEdge[50, 364] -> 
             RGBColor[
              0.4018386991300539, 0.5224516905515073, 0.9468320085978967], 
             UndirectedEdge[73, 195] -> 
             RGBColor[
              0.2444053413712617, 0.37421588834782205`, 0.937229894674568], 
             UndirectedEdge[80, 332] -> 
             RGBColor[
              0.4308190028061351, 0.5455688432531333, 0.9492268288835535], 
             UndirectedEdge[5, 267] -> 
             RGBColor[
              0.7063209858486378, 0.7695859535146778, 0.9720624004607035], 
             UndirectedEdge[136, 246] -> 
             RGBColor[
              0.5311924849620417, 0.6300266566393842, 0.9563079499316767], 
             UndirectedEdge[59, 246] -> 
             RGBColor[
              0.38891052450146135`, 0.5112764819370106, 0.9460020126145274], 
             UndirectedEdge[177, 200] -> 
             RGBColor[
              0.2962840776702533, 0.42752676637236176`, 0.9402288709406241], 
             UndirectedEdge[17, 157] -> 
             RGBColor[
              0.5023802232259484, 0.6068939230427937, 0.9539683579331921], 
             UndirectedEdge[151, 386] -> 
             RGBColor[
              0.3275993292124569, 0.45817180616795133`, 0.9420953174660733], 
             UndirectedEdge[4, 188] -> 
             RGBColor[
              0.24964120798061978`, 0.37971911612737436`, 0.9375280695322004],
              UndirectedEdge[241, 255] -> 
             RGBColor[
              0.2757184631493581, 0.40712796470319146`, 0.9390131306362182], 
             UndirectedEdge[62, 345] -> 
             RGBColor[
              0.19050782677282135`, 0.3175661832050619, 0.9341605109524143], 
             UndirectedEdge[57, 114] -> 
             RGBColor[
              0.3010426520782409, 0.43188396298315035`, 0.9405234581386476], 
             UndirectedEdge[32, 137] -> 
             RGBColor[
              0.21892075175740905`, 0.34742996884735633`, 0.9357785849971308],
              UndirectedEdge[152, 175] -> 
             RGBColor[
              0.181274153781999, 0.307861007443026, 0.9336346669355821], 
             UndirectedEdge[99, 235] -> 
             RGBColor[
              0.8591106393434069, 0.8900471270857477, 0.9483188623764983], 
             UndirectedEdge[156, 256] -> 
             RGBColor[
              0.20563395231845213`, 0.3334647002052716, 0.9350219214251405], 
             UndirectedEdge[48, 286] -> 
             RGBColor[
              0.5758463873446392, 0.6644950889479655, 0.9608396409213635], 
             UndirectedEdge[61, 262] -> 
             RGBColor[
              0.9659943820446136, 0.9709682059989204, 0.7529333373497976], 
             UndirectedEdge[146, 385] -> 
             RGBColor[
              0.5553761412741389, 0.6499183967532158, 0.95814039073239], 
             UndirectedEdge[29, 150] -> 
             RGBColor[
              0.2555149933709343, 0.38589283699209853`, 0.937862572920692], 
             UndirectedEdge[141, 220] -> 
             RGBColor[
              0.4177492311275311, 0.5356546049090093, 0.9480055136475012], 
             UndirectedEdge[152, 242] -> 
             RGBColor[
              0.5509815030039178, 0.5121510355041116, 0.5934630978551525], 
             UndirectedEdge[95, 151] -> 
             RGBColor[
              0.2988070240901653, 0.4307400317944288, 0.9403519901524575], 
             UndirectedEdge[252, 293] -> 
             RGBColor[
              0.21778209463220533`, 0.3462331680137357, 0.9357137401583427], 
             UndirectedEdge[93, 390] -> 
             RGBColor[
              0.2557686929307827, 0.3861594913149804, 0.9378770207353105], 
             UndirectedEdge[229, 249] -> 
             RGBColor[
              0.2582327214414536, 0.38874934150812634`, 0.9380173435137897], 
             UndirectedEdge[96, 153] -> 
             RGBColor[
              0.3021711245350493, 0.4341284235470012, 0.9405489710681403], 
             UndirectedEdge[202, 217] -> 
             RGBColor[
              0.8395826476787889, 0.30525515205179155`, 0.18553769416040178`],
              UndirectedEdge[163, 304] -> 
             RGBColor[
              0.23203584179739814`, 0.3612147600241211, 0.9365254699728711], 
             UndirectedEdge[18, 323] -> 
             RGBColor[
              0.8877084052982851, 0.9130534285104475, 0.9806512796744769], 
             UndirectedEdge[152, 264] -> 
             RGBColor[
              0.186823590274237, 0.31369381705096394`, 0.9339506991341594], 
             UndirectedEdge[23, 169] -> 
             RGBColor[
              0.21705819820147026`, 0.34547230696734843`, 0.9356725153275212],
              UndirectedEdge[290, 342] -> 
             RGBColor[
              0.5042459583975736, 0.6071002946590989, 0.9544767271173353], 
             UndirectedEdge[285, 330] -> 
             RGBColor[
              0.23174352854992997`, 0.3609075202673017, 0.9365088231658666], 
             UndirectedEdge[55, 192] -> 
             RGBColor[
              0.3740111987150174, 0.498371434802681, 0.9450526407503718], 
             UndirectedEdge[161, 170] -> 
             RGBColor[
              0.43820314080929235`, 0.5539712686639211, 0.9491428945379133], 
             UndirectedEdge[42, 205] -> 
             RGBColor[
              0.9637471875060623, 0.9705535185426564, 0.8607371274369169], 
             UndirectedEdge[267, 398] -> 
             RGBColor[
              0.7553121738986209, 0.8085541033742493, 0.9734035961579184], 
             UndirectedEdge[32, 199] -> 
             RGBColor[
              0.22104408708317058`, 0.349661728901967, 0.9358995058027398], 
             UndirectedEdge[154, 385] -> 
             RGBColor[
              0.5027895372841396, 0.606597375130399, 0.9541743330742887], 
             UndirectedEdge[91, 190] -> 
             RGBColor[
              0.25186209923856306`, 0.38205341365211143`, 0.9376545460038261],
              UndirectedEdge[94, 380] -> 
             RGBColor[
              0.2628073165498582, 0.39355753101314184`, 0.9382778599377064], 
             UndirectedEdge[119, 288] -> 
             RGBColor[
              0.2427621793276949, 0.37248882085754254`, 0.9371363190270272], 
             UndirectedEdge[65, 251] -> 
             RGBColor[
              0.6688240146939028, 0.7392826292624911, 0.9689511985946974], 
             UndirectedEdge[198, 216] -> 
             RGBColor[
              0.7427956016916255, 0.7990494191661757, 0.974984628023718], 
             UndirectedEdge[101, 182] -> 
             RGBColor[
              0.2744680720566198, 0.40581372438534935`, 0.9389419227132746], 
             UndirectedEdge[11, 230] -> 
             RGBColor[
              0.9461599473200244, 0.8204361321227099, 0.29539556227068897`], 
             UndirectedEdge[53, 101] -> 
             RGBColor[
              0.27504289638646184`, 0.40641790120198085`, 0.9389746581084827],
              UndirectedEdge[202, 264] -> 
             RGBColor[
              0.5231853201585595, 0.37556082624020004`, 0.5678587762898913], 
             UndirectedEdge[336, 367] -> 
             RGBColor[
              0.21516062802241154`, 0.34347784039625945`, 0.9355644515130273],
              UndirectedEdge[13, 132] -> 
             RGBColor[
              0.8815012453075697, 0.9077928551611671, 0.9634088234551113], 
             UndirectedEdge[146, 307] -> 
             RGBColor[
              0.760285606005483, 0.8109047025764178, 0.9254188643765703], 
             UndirectedEdge[75, 133] -> 
             RGBColor[
              0.27071817278007254`, 0.4018723424883518, 0.9387283714969541], 
             UndirectedEdge[153, 369] -> 
             RGBColor[
              0.28744235484774583`, 0.41864755274771004`, 0.9397101894237105],
              UndirectedEdge[20, 181] -> 
             RGBColor[
              0.4874856363228792, 0.5935620769713348, 0.9531383479528726], 
             UndirectedEdge[112, 394] -> 
             RGBColor[
              0.34389456121557604`, 0.47228591710687856`, 0.9431336352400042],
              UndirectedEdge[279, 306] -> 
             RGBColor[
              0.9580128778613826, 0.8669798939942239, 0.307271930750418], 
             UndirectedEdge[34, 68] -> 
             RGBColor[
              0.29450681654452554`, 0.42654813983932427`, 0.9400950937121118],
              UndirectedEdge[4, 284] -> 
             RGBColor[
              0.23809729374437577`, 0.3675857303386453, 0.936870660694137], 
             UndirectedEdge[193, 235] -> 
             RGBColor[
              0.7812166445775857, 0.8290306868326278, 0.9788229798067978], 
             UndirectedEdge[296, 316] -> 
             RGBColor[
              0.27790052377493313`, 0.40942144877130526`, 0.9391373957607753],
              UndirectedEdge[117, 223] -> 
             RGBColor[
              0.40179215387534173`, 0.5224135595233219, 0.9468284392932418], 
             UndirectedEdge[37, 110] -> 
             RGBColor[
              0.2526887349083196, 0.3829222601527542, 0.9377016216823209], 
             UndirectedEdge[83, 349] -> 
             RGBColor[
              0.3991304048320619, 0.5201284286132558, 0.946653214352108], 
             UndirectedEdge[192, 348] -> 
             RGBColor[
              0.30372248336585006`, 0.4332572121434699, 0.9407289213687278], 
             UndirectedEdge[97, 394] -> 
             RGBColor[
              0.40057619946044803`, 0.521380703252613, 0.9467453391073628], 
             UndirectedEdge[2, 352] -> 
             RGBColor[
              0.9063026650036, 0.5663670773157738, 0.3851970536504771], 
             UndirectedEdge[69, 350] -> 
             RGBColor[
              0.4604806861717529, 0.5723193250518395, 0.9508242340447808], 
             UndirectedEdge[164, 304] -> 
             RGBColor[
              0.230818470893376, 0.3599352260182205, 0.936456142500826], 
             UndirectedEdge[141, 350] -> 
             RGBColor[
              0.3964033490329356, 0.5177663899458625, 0.9464794487680284], 
             UndirectedEdge[114, 356] -> 
             RGBColor[
              0.4236281428800086, 0.5395805954873082, 0.9487022895227458], 
             UndirectedEdge[383, 390] -> 
             RGBColor[
              0.27326780022861263`, 0.40455216259248444`, 0.9388735690083126],
              UndirectedEdge[297, 307] -> 
             RGBColor[
              0.965939497584164, 0.9739442069028073, 0.9347428726703746], 
             UndirectedEdge[40, 58] -> 
             RGBColor[
              0.31906156196643076`, 0.449858262003899, 0.9415849314423156], 
             UndirectedEdge[173, 295] -> 
             RGBColor[
              0.23437748052955032`, 0.36367597080008385`, 0.9366588228345232],
              UndirectedEdge[161, 239] -> 
             RGBColor[
              0.3779757827321134, 0.5018053582125028, 0.9453052605381971], 
             UndirectedEdge[35, 369] -> 
             RGBColor[
              0.26924749981930185`, 0.40032657196053045`, 0.9386446188475038],
              UndirectedEdge[303, 313] -> 
             RGBColor[
              0.2862100467675046, 0.4181552842906852, 0.9396106108023645], 
             UndirectedEdge[237, 349] -> 
             RGBColor[
              0.5118990860533059, 0.6144062060618112, 0.9547772771793315], 
             UndirectedEdge[21, 263] -> 
             RGBColor[
              0.2875003760669833, 0.4191258516317633, 0.9396982137034129], 
             UndirectedEdge[126, 274] -> 
             RGBColor[
              0.22138486041548355`, 0.35001990328050514`, 0.9359189123398861],
              UndirectedEdge[331, 346] -> 
             RGBColor[
              0.3985622409768109, 0.5196363136385831, 0.946617011453659], 
             UndirectedEdge[106, 345] -> 
             RGBColor[
              0.5752211056493675, 0.6453489967018295, 0.953440498597335]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.23802405881018981`, 0.36750875577945274`, 0.9368664900729765],
              316 -> RGBColor[
              0.25427950679235417`, 0.38459426226363735`, 0.9377922137877805],
              308 -> RGBColor[
              0.2610883790761277, 0.39175081874132034`, 0.9381799689915176], 
             160 -> RGBColor[
              0.8294775817921864, 0.22758318757925894`, 0.17586107165535175`],
              245 -> RGBColor[
              0.22989884827362161`, 0.3589686443374169, 0.9364037713530907], 
             155 -> RGBColor[
              0.30454561984188433`, 0.43742713413433654`, 0.9406547945639009],
              213 -> RGBColor[
              0.9109681137578394, 0.6847252697068382, 0.24722105836383443`], 
             352 -> RGBColor[
              0.9941541355650164, 0.9899046120181566, 0.6050919166244885], 27 -> 
             RGBColor[
              0.2974167180204977, 0.42993420632157753`, 0.9402488141514381], 
             367 -> RGBColor[
              0.21931469518675756`, 0.34784402836905765`, 0.9358010194926452],
              19 -> RGBColor[
              0.2743841090042405, 0.40572547389373365`, 0.9389371411416538], 
             164 -> RGBColor[
              0.24253850776538854`, 0.3722537278639624, 0.9371235812624463], 
             190 -> RGBColor[
              0.2411029859620505, 0.37074490343131483`, 0.9370418304194105], 
             103 -> RGBColor[
              0.34456615692423104`, 0.4728676195543337, 0.943176428724691], 
             138 -> RGBColor[
              0.8193428764107183, 0.14968340096107918`, 0.16615606633654534`],
              291 -> RGBColor[
              0.696491580031562, 0.7628237829435023, 0.9703834296798242], 28 -> 
             RGBColor[
              0.2882891132658928, 0.42034051500092084`, 0.9397290105637445], 
             337 -> RGBColor[
              0.2847433322190086, 0.4166136743051424, 0.9395270835786375], 
             195 -> RGBColor[
              0.24569470610522032`, 0.37557109243365844`, 0.9373033220887227],
              114 -> RGBColor[
              0.3288778807819878, 0.45927922327560866`, 0.9421767856415051], 
             93 -> RGBColor[
              0.2452381115380016, 0.3750911825937439, 0.9372773197035907], 34 -> 
             RGBColor[
              0.3122890105436297, 0.4449107776560043, 0.9411197574988789], 
             161 -> RGBColor[
              0.4314366462475933, 0.5481104711684827, 0.9487117394878181], 22 -> 
             RGBColor[
              0.29231839668471055`, 0.42457554734542235`, 0.9399584722936555],
              124 -> 
             RGBColor[
              0.22327126764014227`, 0.35200263687874755`, 0.936026340440641], 
             84 -> RGBColor[
              0.17892701429477148`, 0.30539401502471114`, 0.9335010008140661],
              46 -> RGBColor[
              0.2843163130979401, 0.41616485013432336`, 0.9395027654714108], 
             241 -> RGBColor[
              0.290961948336973, 0.42314983412815754`, 0.9398812245669373], 
             185 -> RGBColor[
              0.8236904837096025, 0.18310101579396953`, 0.170319339995877], 
             390 -> RGBColor[
              0.26629927432356376`, 0.3972278000362168, 0.9384767217670303], 
             121 -> RGBColor[
              0.5531961411455233, 0.6481485744409189, 0.9579687731366617], 
             322 -> RGBColor[
              0.5084161265639328, 0.611794141286916, 0.9544435263542006], 126 -> 
             RGBColor[
              0.21204174778307774`, 0.3401996995162911, 0.935386835897367], 
             236 -> RGBColor[
              0.2505222001886238, 0.3806450947961188, 0.9375782407351351], 78 -> 
             RGBColor[
              0.8418439495844675, 0.3226365094076515, 0.18770311941905493`], 
             376 -> RGBColor[
              0.43839329858407067`, 0.5541359737708264, 0.9491550112231723], 
             254 -> RGBColor[
              0.46951139015292603`, 0.5802095236300584, 0.951380802991181], 
             290 -> RGBColor[
              0.4051337172328171, 0.5253281960795354, 0.9470357401097634], 
             251 -> RGBColor[
              0.822315843269912, 0.8611563485272284, 0.9829144132927453], 165 -> 
             RGBColor[
              0.532748774101436, 0.6315484807311408, 0.9563590815017777], 100 -> 
             RGBColor[
              0.37661408553666426`, 0.5006259245426959, 0.9452184943970047], 
             235 -> RGBColor[
              0.7400936775781565, 0.7968860729351169, 0.9747292792785006], 70 -> 
             RGBColor[
              0.2778101351361315, 0.409326444580954, 0.9391322482615135], 234 -> 
             RGBColor[
              0.3387393935852255, 0.4678207700117279, 0.942805152517134], 257 -> 
             RGBColor[
              0.8226071697061851, 0.17477418965247965`, 0.16928195728277629`],
              135 -> RGBColor[
              0.5032780494106496, 0.6076228187861427, 0.9540390380992975], 
             265 -> RGBColor[
              0.5918946974095183, 0.6795658057661227, 0.9610152652432459], 
             111 -> RGBColor[
              0.8740781517963572, 0.5211001217496539, 0.21664006204298622`], 
             381 -> 
             RGBColor[
              0.9931470290452047, 0.9914341346439413, 0.7632349938486772], 
             182 -> RGBColor[
              0.2880943118622093, 0.4201357663745271, 0.9397179169119876], 
             188 -> RGBColor[
              0.26708591845739416`, 0.39805461289699134`, 0.9385215199867163],
              154 -> RGBColor[
              0.4301580292792129, 0.547002997415629, 0.9486302671452295], 336 -> 
             RGBColor[
              0.2110065608580655, 0.33911165242346125`, 0.9353278835334095], 
             315 -> RGBColor[
              0.24327422624281886`, 0.37302701463098736`, 0.937165479341338], 
             368 -> RGBColor[
              0.21278150541118618`, 0.3409772316867757, 0.9354289639999145], 
             269 -> RGBColor[
              0.9930589289900814, 0.9875620758967413, 0.48588543977432486`], 
             208 -> RGBColor[
              0.2330867180319017, 0.36231929757598597`, 0.9365853158197941], 
             86 -> RGBColor[
              0.30053635500276704`, 0.4332131425863514, 0.940426472862489], 
             119 -> RGBColor[
              0.24049836738192176`, 0.3701094109685675, 0.9370073982857251], 
             377 -> RGBColor[
              0.41487938737084307`, 0.5337694057214698, 0.9476567255932007], 
             140 -> RGBColor[
              0.6719249954084331, 0.7436321803229556, 0.9679348621123766], 85 -> 
             RGBColor[
              0.2413074662041341, 0.37095982513054093`, 0.9370534752666957], 
             351 -> RGBColor[
              0.24574449108125243`, 0.37562341960001794`, 0.9373061572694574],
              242 -> RGBColor[
              0.9183468399249884, 0.7139794601448493, 0.25315815463888625`], 
             117 -> RGBColor[
              0.3495171154366807, 0.47715589097540734`, 0.9434918994231435], 
             47 -> RGBColor[
              0.43389191818712153`, 0.5502371043169462, 0.948868187244693], 
             81 -> RGBColor[
              0.2197154470497895, 0.34826524398623987`, 0.9358238417183856], 
             275 -> RGBColor[
              0.992100640761205, 0.9910014261975552, 0.7805763556806252], 23 -> 
             RGBColor[
              0.21341792784235675`, 0.34164615201344867`, 0.935465207315867], 
             328 -> RGBColor[
              0.3094371851822424, 0.44244066986488095`, 0.9409380417086214], 
             110 -> RGBColor[
              0.25557794384056287`, 0.3859590019269685, 0.9378661578568105], 
             6 -> RGBColor[
              0.9933475429680663, 0.9881793920123014, 0.5172992901589675], 
             218 -> 
             RGBColor[
              0.9100637739514378, 0.9311241665985504, 0.9912838892546516], 
             108 -> RGBColor[
              0.3675690787260941, 0.49279159425864094`, 0.9446421545612206], 
             297 -> RGBColor[
              0.9466390204165737, 0.9597240493140413, 0.9752103990490407], 
             157 -> RGBColor[
              0.46924384183457235`, 0.5799923158523045, 0.9513597406074984], 
             354 -> RGBColor[
              0.27977343586669706`, 0.4113899981292344, 0.939244055333676], 
             385 -> RGBColor[
              0.5754210452890663, 0.6661917528451691, 0.9597183990033479], 
             270 -> RGBColor[
              0.249587147505622, 0.3796622951405196, 0.9375249908681246], 392 -> 
             RGBColor[
              0.24794921220500737`, 0.3779407212884774, 0.9374317128758627], 
             33 -> RGBColor[
              0.17894138666990014`, 0.3054091213022326, 0.9335018192995677], 
             252 -> RGBColor[
              0.2243331252717409, 0.35311871657522015`, 0.9360868116618829], 
             394 -> RGBColor[
              0.35886795134781274`, 0.48525511505495156`, 0.9440877264187814],
              260 -> RGBColor[
              0.8089540339665278, 0.8506803067038047, 0.9815926360666765], 
             159 -> RGBColor[
              0.3314345944952444, 0.46149372018986384`, 0.9423396971785006], 
             183 -> RGBColor[
              0.2589336294896423, 0.3894860403069097, 0.9380572591902335], 99 -> 
             RGBColor[
              0.9781276011086575, 0.9832081812363787, 0.921908445474496], 329 -> 
             RGBColor[
              0.23513882534723038`, 0.36447619247551505`, 0.9367021802955814],
              309 -> RGBColor[
              0.27079044913528966`, 0.40194830952027055`, 0.9387324875284604],
              17 -> RGBColor[
              0.5355166046173245, 0.6337955302332828, 0.9565769752588857], 
             349 -> RGBColor[
              0.4453791406536688, 0.5601867590528806, 0.9496001429025095], 
             347 -> RGBColor[
              0.2800500850584523, 0.411680773970341, 0.9392598100958807], 340 -> 
             RGBColor[
              0.99377812825938, 0.9891003704115706, 0.5641658418540755], 277 -> 
             RGBColor[
              0.2578128298869203, 0.3883080088616496, 0.9379934313109329], 
             104 -> RGBColor[
              0.9338740873595025, 0.7755398220742175, 0.265651742396037], 79 -> 
             RGBColor[
              0.590805957298975, 0.6786819174972005, 0.9609295556335575], 327 -> 
             RGBColor[
              0.3185921337049145, 0.45037022613412764`, 0.941521386933083], 
             191 -> RGBColor[
              0.6788533623879274, 0.7490446732648759, 0.968625416983622], 50 -> 
             RGBColor[
              0.45414763221898446`, 0.5677365328098771, 0.9501713116873214], 
             225 -> RGBColor[
              0.2571081050813221, 0.3875672984088326, 0.9379532982758011], 61 -> 
             RGBColor[
              0.9933459036684309, 0.98817588571614, 0.5171208625102379], 196 -> 
             RGBColor[
              0.29792411608308994`, 0.43046751385625726`, 0.9402777097204745],
              1 -> RGBColor[
              0.3599830334006432, 0.48622094308345976`, 0.9441587784611594], 
             263 -> RGBColor[
              0.26208361027682536`, 0.3927968698345563, 0.9382366459360847], 
             201 -> RGBColor[
              0.27642628673231373`, 0.407871932167485, 0.9390534401421363], 
             371 -> RGBColor[
              0.27204560568907665`, 0.4032675586398226, 0.9388039668373608], 
             293 -> RGBColor[
              0.21123106399266978`, 0.3393476194522512, 0.9353406686548026], 
             362 -> RGBColor[
              0.40465902674538534`, 0.5249170430379596, 0.9470054932516565], 
             184 -> RGBColor[
              0.21776291881025298`, 0.3462130130090464, 0.9357126481236506], 
             106 -> RGBColor[
              0.948494816832878, 0.9611080992427333, 0.9720690197854612], 206 -> 
             RGBColor[
              0.23156206990492625`, 0.36071679572626025`, 0.9364984893644777],
              358 -> RGBColor[
              0.9685766725786527, 0.9056638794389593, 0.332426736075871], 247 -> 
             RGBColor[
              0.9070075396154186, 0.6690229130152352, 0.24403428744221908`], 
             220 -> RGBColor[
              0.4754345148883495, 0.5850181831240037, 0.9518470930674744], 
             107 -> RGBColor[
              0.8392176796973624, 0.30244984821655896`, 0.1851882004092155], 
             375 -> RGBColor[
              0.25484534055170655`, 0.38518898942064916`, 0.9378244371832996],
              131 -> RGBColor[
              0.9224661794909306, 0.7303112688352736, 0.2564726719469704], 
             127 -> RGBColor[
              0.21049571798261152`, 0.33857472417205015`, 0.9352987917873766],
              210 -> RGBColor[
              0.2999237099233219, 0.432569213763913, 0.9403915836315417], 357 -> 
             RGBColor[
              0.6756901028072094, 0.7465735108387558, 0.9683101328309576], 
             181 -> 
             RGBColor[
              0.5673122922146817, 0.6596087018042204, 0.9590800482579911], 
             194 -> RGBColor[
              0.3880550588481297, 0.5105355205850486, 0.9459475030995558], 
             118 -> RGBColor[
              0.20606162213947596`, 0.33391420830300045`, 0.935046276588767], 
             348 -> RGBColor[
              0.26295522261758464`, 0.39371298966810864`, 0.9382862829694559],
              276 -> RGBColor[
              0.765566144894021, 0.8167853580001923, 0.977268136766805], 305 -> 
             RGBColor[
              0.20290260740476634`, 0.33059388352371805`, 0.9348663753729688],
              343 -> RGBColor[
              0.7222005724227306, 0.7829078431950623, 0.9729458617771823], 
             280 -> RGBColor[
              0.23901320904650822`, 0.3685484153935707, 0.9369228207156182], 
             189 -> RGBColor[
              0.30054674338696064`, 0.4332240614368005, 0.9404270644656005], 
             168 -> RGBColor[
              0.6701504899984683, 0.7422459232099505, 0.9677579959968072], 
             363 -> RGBColor[
              0.8625124936811881, 0.46858316947675277`, 0.2069893934114667], 
             41 -> RGBColor[
              0.34082031608406577`, 0.4696231604900174, 0.9429377470586726], 
             14 -> RGBColor[
              0.9943570777774785, 0.9903386848900081, 0.6271809240368398], 77 -> 
             RGBColor[
              0.8293651040061051, 0.8667772376911834, 0.9835867780747127], 51 -> 
             RGBColor[
              0.3729233885884314, 0.4974292283459589, 0.9449833264510183], 
             179 -> RGBColor[
              0.2696431574723743, 0.40074243324005365`, 0.9386671509655232], 
             223 -> RGBColor[
              0.4540671923140028, 0.5676712280712366, 0.9501649791633402], 
             323 -> RGBColor[
              0.8302102447519867, 0.867451129981215, 0.983667388353521], 292 -> 
             RGBColor[
              0.2110186790508826, 0.3391243894124498, 0.9353285736465631], 
             396 -> RGBColor[
              0.2782995151593558, 0.4098408140138484, 0.9391601177298633], 
             321 -> RGBColor[
              0.8177864636409283, 0.8575802678943982, 0.9824729701128726], 
             143 -> RGBColor[
              0.6246442469651912, 0.7061533654458123, 0.9635934297498213], 
             112 -> RGBColor[
              0.3289211710833394, 0.45931671915880556`, 0.9421795440612271], 
             197 -> RGBColor[
              0.988751433892587, 0.9896164430866911, 0.8360813809631582], 54 -> 
             RGBColor[
              0.4519914858020445, 0.5659140400742732, 0.9500214756882968], 71 -> 
             RGBColor[
              0.871120013048017, 0.9000714687543917, 0.9875693985741776], 177 -> 
             RGBColor[
              0.3219085007459621, 0.453242696579629, 0.9417327029083903], 158 -> 
             RGBColor[
              0.5031159008708285, 0.6074911792968075, 0.9540262731722731], 
             226 -> RGBColor[
              0.23863402700947722`, 0.3681498710311214, 0.9369012268595588], 
             350 -> RGBColor[
              0.4327427506991586, 0.5492417531977101, 0.948794963308529], 203 -> 
             RGBColor[
              0.29139757571829134`, 0.42360770612629445`, 0.9399060329018505],
              115 -> RGBColor[
              0.2386060995532787, 0.36812051750395375`, 0.9368996364322433], 
             173 -> RGBColor[
              0.22636761106282094`, 0.3552570901354948, 0.936202672617933], 
             212 -> RGBColor[
              0.21089717481030001`, 0.33899668075178374`, 0.9353216541598114],
              129 -> RGBColor[
              0.23768447069359533`, 0.36715182713778177`, 0.936847151032112], 
             279 -> RGBColor[
              0.9456496399519233, 0.8222259641328803, 0.2751266284196432], 26 -> 
             RGBColor[
              0.45511285367532656`, 0.5685201430708667, 0.9502472974560874], 
             40 -> RGBColor[
              0.3393121311221928, 0.4683168464796233, 0.9428416468465376], 
             146 -> RGBColor[
              0.5353312372592116, 0.6336450406612625, 0.9565623824614321], 
             386 -> RGBColor[
              0.3393631406607411, 0.4683610283780999, 0.942844897129228], 192 -> 
             RGBColor[
              0.34448974411411554`, 0.4728014346188312, 0.9431715597679996], 
             300 -> RGBColor[
              0.8899967779325137, 0.5933828851443484, 0.2299229538922278], 
             221 -> RGBColor[
              0.9218589159168126, 0.9405292926311409, 0.9924089204249567], 62 -> 
             RGBColor[
              0.1790682590797859, 0.30554247224919795`, 0.9335090444956198], 
             286 -> RGBColor[
              0.726249879738111, 0.7860711928457129, 0.9733494588874512], 152 -> 
             RGBColor[
              0.18361616608284723`, 0.3103226108633739, 0.9337680410714186], 
             64 -> RGBColor[
              0.3989602722595878, 0.5199810683300905, 0.9466423736550322], 
             307 -> RGBColor[
              0.9852399747517544, 0.9881643644915732, 0.8942753462917085], 37 -> 
             RGBColor[
              0.24979952597607638`, 0.3798855183785399, 0.9375370855078312], 
             148 -> RGBColor[
              0.6238880244982119, 0.7055394299796848, 0.9635338971470865], 
             261 -> RGBColor[
              0.17944836957228805`, 0.3059419924772149, 0.9335306912258446], 
             387 -> RGBColor[
              0.2935687509337651, 0.4258897489382169, 0.9400296781184059], 15 -> 
             RGBColor[
              0.3038609163605336, 0.43670746736272875`, 0.940615801713566], 
             136 -> RGBColor[
              0.6185821135656369, 0.7012318524560568, 0.9631161964022821], 
             198 -> RGBColor[
              0.8264896291158393, 0.8644844120663722, 0.9833125127127125], 63 -> 
             RGBColor[
              0.9585610528033711, 0.8718788421575785, 0.2935179445399928], 
             310 -> RGBColor[
              0.18257815057035692`, 0.3092315907457619, 0.9337089276235886], 
             171 -> RGBColor[
              0.2732125866431092, 0.40449412961337683`, 0.9388704246762993], 
             395 -> RGBColor[
              0.27306809856961783`, 0.40434226348706437`, 0.938862196294265], 
             311 -> RGBColor[
              0.519374038863881, 0.6206902681403376, 0.955306173350608], 353 -> 
             RGBColor[
              0.21037964845754836`, 0.3384527277419758, 0.9352921817996338], 
             59 -> RGBColor[
              0.3340181926444761, 0.4637315030513096, 0.9425043217679835], 
             397 -> RGBColor[
              0.2493495489754894, 0.37941256402073326`, 0.9375114599833291], 
             229 -> RGBColor[
              0.24689616138342244`, 0.3768338981077132, 0.9373717431894225], 
             102 -> RGBColor[
              0.819297035403237, 0.14933104688991955`, 0.16611216893601113`], 
             299 -> RGBColor[
              0.21412870248835636`, 0.3423932212321097, 0.9355056848804599], 
             128 -> RGBColor[
              0.3262131529712761, 0.45697116997908427`, 0.9420069915417328], 
             12 -> RGBColor[
              0.218436984339963, 0.3469214986189947, 0.935751035158377], 222 -> 
             RGBColor[
              0.6049269005052089, 0.6901459353332633, 0.9620412080094716], 92 -> 
             RGBColor[
              0.28766384187052196`, 0.4196833151198899, 0.9396934022827843], 
             271 -> RGBColor[
              0.30678788301618565`, 0.43978389489822367`, 0.9407824881345462],
              361 -> RGBColor[
              0.35562652096447817`, 0.48244755097593534`, 0.9438811853410396],
              344 -> 
             RGBColor[
              0.32062864936426844`, 0.45213415364000675`, 0.941651151910077], 
             132 -> RGBColor[
              0.7992223614262676, 0.8430778501519028, 0.9806226738955138], 80 -> 
             RGBColor[
              0.3344163982055418, 0.46407640869391137`, 0.9425296950742152], 
             324 -> RGBColor[
              0.2799576543907215, 0.4115836234781131, 0.9392545463060924], 
             244 -> RGBColor[
              0.2600361752617328, 0.3906448858188163, 0.9381200475408837], 
             150 -> RGBColor[
              0.2706007772119499, 0.40174895230294594`, 0.9387216859930206], 
             125 -> RGBColor[
              0.277985958766929, 0.4095112463647842, 0.9391422611571797], 258 -> 
             RGBColor[
              0.2529332615169164, 0.38317927312227185`, 0.9377155471109357], 
             133 -> RGBColor[
              0.29725822306554583`, 0.42976761807476255`, 0.9402397880982258],
              255 -> RGBColor[
              0.26047497796174324`, 0.3911060952782254, 0.938145036705499], 
             326 -> RGBColor[
              0.3393902356747875, 0.4683844967174319, 0.9428466235995638], 
             176 -> RGBColor[
              0.21582348781243682`, 0.34417454806331416`, 0.935602200397456], 
             230 -> RGBColor[
              0.9688572327835747, 0.9066102748888301, 0.333516659492644], 274 -> 
             RGBColor[
              0.2307279730478894, 0.35984010704471925`, 0.9364509887824051], 
             87 -> RGBColor[
              0.29013871681338543`, 0.4222845656009737, 0.9398343427495309], 
             130 -> RGBColor[
              0.4104055903111328, 0.5298944275679272, 0.9473716592005793], 35 -> 
             RGBColor[
              0.28104105066772134`, 0.4127223416565313, 0.9393162441213263], 
             379 -> RGBColor[
              0.22095736038557218`, 0.3495705736440009, 0.9358945668456122], 
             31 -> RGBColor[
              0.183217413291963, 0.30990349639776743`, 0.9337453326898797], 
             18 -> RGBColor[
              0.9452065658445834, 0.95865572703968, 0.9776351709954327], 24 -> 
             RGBColor[
              0.9021530244270525, 0.6485815613125467, 0.24006642394413927`], 
             151 -> RGBColor[
              0.3158355177641727, 0.44798258395780277`, 0.9413457378029186], 
             137 -> RGBColor[
              0.22155609394318862`, 0.3501998805749559, 0.9359286638359716], 
             330 -> RGBColor[
              0.22477195032544567`, 0.3535799495297792, 0.936111802099508], 
             296 -> 
             RGBColor[
              0.30152154075751214`, 0.43424863527897317`, 0.94048257773377], 
             266 -> RGBColor[
              0.2549979314676595, 0.3853493721481386, 0.937833127010225], 302 -> 
             RGBColor[
              0.9872770340850194, 0.9687445898536212, 0.4050741092611545], 
             283 -> RGBColor[
              0.9089152991886196, 0.6765865439997854, 0.2455693155756892], 
             388 -> RGBColor[
              0.22336510960731928`, 0.352101270736175, 0.9360316846018449], 
             284 -> RGBColor[
              0.24399808998490613`, 0.37378784131953313`, 0.9372067023105894],
              318 -> RGBColor[
              0.2238174684207968, 0.35257672853034516`, 0.9360574457670676], 
             238 -> RGBColor[
              0.22922310747734106`, 0.35825839791608494`, 0.9363652889144115],
              72 -> RGBColor[
              0.22772650909910638`, 0.3566853781307425, 0.9362800598507899], 
             288 -> RGBColor[
              0.245025991273468, 0.37486823074651754`, 0.9372652397683294], 
             382 -> RGBColor[
              0.898780922280212, 0.63326963303821, 0.23725265925502825`], 389 -> 
             RGBColor[
              0.17908812663026416`, 0.30556335430442605`, 0.933510175923228], 
             172 -> RGBColor[
              0.301424661402258, 0.4341468089340951, 0.9404770605978084], 243 -> 
             RGBColor[
              0.2883719521470624, 0.4204275839173185, 0.939733728115478], 88 -> 
             RGBColor[
              0.9903137669558371, 0.9902625079584733, 0.8101894789167451], 
             273 -> RGBColor[
              0.2754373969927425, 0.40683254635196486`, 0.938997124334399], 
             202 -> RGBColor[
              0.8563396258514921, 0.4340566292418462, 0.20158419538288244`], 
             393 -> RGBColor[
              0.22281999879048459`, 0.3515283247056597, 0.9360006413472455], 
             98 -> RGBColor[
              0.9775701021325132, 0.9360008290818089, 0.3673645116259542], 30 -> 
             RGBColor[
              0.17892703208317115`, 0.3053940337214471, 0.9335010018270892], 
             116 -> RGBColor[
              0.4162213411164948, 0.534931738607397, 0.9477422336992305], 373 -> 
             RGBColor[
              0.2503218011924054, 0.380434462745063, 0.9375668283087641], 240 -> 
             RGBColor[
              0.23920651037948798`, 0.3687515873505448, 0.9369338289405676], 
             317 -> RGBColor[
              0.9906270631619555, 0.9903920639910485, 0.8049973499967711], 
             391 -> 
             RGBColor[
              0.8203907902431329, 0.1577381258757864, 0.16715954980591485`], 
             73 -> RGBColor[
              0.24311597663730303`, 0.3728606842619857, 0.9371564672604132], 
             303 -> RGBColor[
              0.28961174034798287`, 0.421730679923598, 0.9398043322194181], 
             29 -> RGBColor[
              0.2404292095299187, 0.3700367216812511, 0.9370034598483634], 
             360 -> RGBColor[
              0.3103917228488082, 0.4432674424152022, 0.9409988640046705], 
             320 -> RGBColor[
              0.7098940201909748, 0.7732938710583535, 0.9717192596619902], 75 -> 
             RGBColor[
              0.24417812249459925`, 0.373977066901941, 0.9372169548956822], 
             200 -> RGBColor[
              0.27065965459454444`, 0.40181083616509444`, 0.9387250389728581],
              301 -> RGBColor[
              0.2568179059531509, 0.3872622807254372, 0.9379367718647629], 
             156 -> RGBColor[
              0.18595953915049845`, 0.3127856445359093, 0.9339014927009116], 
             25 -> RGBColor[
              0.8487111149297029, 0.3754205514621725, 0.19427912470900624`], 
             38 -> RGBColor[
              0.9657912116144293, 0.896267865549297, 0.32160574622002847`], 
             365 -> RGBColor[
              0.25624071750281635`, 0.38665561906827417`, 0.93790390183639], 
             380 -> RGBColor[
              0.26549066491796636`, 0.3963779002821365, 0.9384306726576119], 
             370 -> RGBColor[
              0.8312166238387177, 0.8682535893475418, 0.9837633776892186], 3 -> 
             RGBColor[
              0.370079657849583, 0.49496613171003123`, 0.9448021264429514], 
             57 -> RGBColor[
              0.2732074233744939, 0.404488702690692, 0.9388701306357901], 227 -> 
             RGBColor[
              0.23492201148043795`, 0.36424830735472313`, 0.9366898330666149],
              39 -> RGBColor[
              0.27309206457306523`, 0.40436745327622, 0.9388635611227067], 
             109 -> RGBColor[
              0.9940964498066649, 0.9918267445278057, 0.7475006348091123], 
             256 -> RGBColor[
              0.22530836548640581`, 0.35414375587463387`, 0.9361423501493695],
              339 -> RGBColor[
              0.36576050208801136`, 0.49122509607643855`, 0.9445269136571035],
              287 -> RGBColor[
              0.260213393629744, 0.3908311535598896, 0.9381301398647709], 239 -> 
             RGBColor[
              0.32451491921663345`, 0.4555002452565231, 0.9418987815885761], 
             285 -> 
             RGBColor[
              0.23871510677441427`, 0.3682350910048242, 0.9369058442322252], 
             345 -> RGBColor[
              0.20194739446585683`, 0.3295898941609259, 0.9348119774092088], 
             366 -> RGBColor[
              0.9012804456996433, 0.6446193851073215, 0.2393383228651273], 
             216 -> RGBColor[
              0.6591015742674116, 0.7336144262659793, 0.9666567433347234], 21 -> 
             RGBColor[
              0.31291714185714126`, 0.44545483342897024`, 0.9411597814707411],
              355 -> RGBColor[
              0.23092116646773903`, 0.3600431655781515, 0.9364619908618614], 
             175 -> RGBColor[
              0.17893214148115075`, 0.3053994040226782, 0.9335012927997455], 
             7 -> RGBColor[
              0.38940499419392427`, 0.5117047667318526, 0.9460335197860889], 
             13 -> RGBColor[
              0.9637801291888717, 0.9725078601704316, 0.9461949730147088], 
             294 -> RGBColor[
              0.21275955169572475`, 0.34095415693987974`, 0.9354277137682966],
              193 -> RGBColor[
              0.8223396115770147, 0.8611753007301386, 0.9829166803350949], 60 -> 
             RGBColor[
              0.35752834255750565`, 0.4840948132514831, 0.9440023677312325], 
             65 -> RGBColor[
              0.5153321861178936, 0.6174089099977538, 0.9549879838966494], 69 -> 
             RGBColor[
              0.48821862164434726`, 0.5953968969059689, 0.9528535047810326], 
             217 -> RGBColor[
              0.8228256695060855, 0.17645367486173685`, 0.16949119293792111`],
              214 -> RGBColor[
              0.9837730937067766, 0.9874185803724101, 0.9123520990861677], 
             170 -> RGBColor[
              0.44496963537099143`, 0.5598320661593594, 0.9495740495880086], 
             359 -> RGBColor[
              0.2455681205459235, 0.37543804298484945`, 0.9372961132283874], 
             74 -> RGBColor[
              0.8246734764068878, 0.8630362611944062, 0.983139286446034], 246 -> 
             RGBColor[
              0.4438028563584466, 0.5588214608227114, 0.9494997034610714], 
             264 -> RGBColor[
              0.19003101446562676`, 0.31706502323855396`, 0.9341333571969002],
              278 -> RGBColor[
              0.2524156236360728, 0.382635202889368, 0.9376860683993983], 45 -> 
             RGBColor[
              0.2954990939280613, 0.427918661816037, 0.9401396082962444], 306 -> 
             RGBColor[
              0.9703761157708419, 0.9117338238555674, 0.33941723308119276`], 
             237 -> 
             RGBColor[
              0.5784190314529432, 0.6686256530707418, 0.9599544114561535], 
             228 -> RGBColor[
              0.36785717736282086`, 0.49304113081751505`, 0.9446605119515972],
              180 -> RGBColor[
              0.36627002209779275`, 0.4916664166996908, 0.9445593798215759], 
             383 -> RGBColor[
              0.28023632613366145`, 0.41187652514875206`, 0.939270416249595], 
             53 -> RGBColor[
              0.28924396052189333`, 0.4213441200077901, 0.9397833877024038], 
             304 -> RGBColor[
              0.21909843402136348`, 0.34761672417247863`, 0.9357887037392056],
              48 -> RGBColor[
              0.4254428949511675, 0.5429189850502182, 0.948329822955276], 5 -> 
             RGBColor[
              0.8414430264446411, 0.8764078451972013, 0.9847387810989889], 
             101 -> RGBColor[
              0.2608418322510304, 0.39149168239617155`, 0.9381659285145616], 
             333 -> RGBColor[
              0.19556045555100107`, 0.3228768164060961, 0.9344482506866372], 
             267 -> RGBColor[
              0.5711989452526345, 0.6627640618321545, 0.9593860198224179], 
             120 -> RGBColor[
              0.5663783145126094, 0.6588504566304622, 0.9590065221120109], 
             147 -> RGBColor[
              0.28473783311028583`, 0.41660789439321116`, 0.9395267704125309],
              89 -> RGBColor[
              0.21858282554203126`, 0.3470747869692347, 0.9357593405990821], 
             43 -> RGBColor[
              0.2274352478585693, 0.35637924409990884`, 0.9362634729540237], 
             199 -> RGBColor[
              0.22580276459471169`, 0.35466340068417734`, 0.9361705054471896],
              268 -> RGBColor[0.817319, 0.134127, 0.164218], 169 -> 
             RGBColor[
              0.22069846856058375`, 0.34929846192124825`, 0.9358798233391753],
              20 -> RGBColor[
              0.4076589804310767, 0.5275154521384491, 0.9471966476477539], 4 -> 
             RGBColor[
              0.23219649750384544`, 0.36138361935775737`, 0.9365346190776845],
              167 -> RGBColor[
              0.2835494674254077, 0.415358846711668, 0.9394590947448065], 142 -> 
             RGBColor[
              0.8215839734950429, 0.16690945520620182`, 0.16830214343545163`],
              16 -> RGBColor[
              0.2418605106508593, 0.3715411099090923, 0.9370849703297808], 
             281 -> RGBColor[
              0.6319940482543123, 0.7121202652370958, 0.9641720330305101], 
             289 -> 
             RGBColor[
              0.8977533081905217, 0.6286034774622947, 0.23639519286946437`], 
             398 -> RGBColor[
              0.9394254025446074, 0.954344144916344, 0.9874211724934188], 178 -> 
             RGBColor[
              0.24398844376792686`, 0.3737777025338824, 0.9372061529728027], 
             58 -> RGBColor[
              0.2988109928106687, 0.43139967752817476`, 0.9403282160380936], 
             186 -> RGBColor[
              0.24846767200989045`, 0.3784856554156597, 0.9374612383947583], 
             122 -> RGBColor[
              0.44608758599784554`, 0.5608003788025082, 0.9496452844133868], 
             249 -> RGBColor[
              0.2695692814994847, 0.4006647849085395, 0.938662943838157], 113 -> 
             RGBColor[
              0.7965156452550962, 0.8409633429071789, 0.9803528937232722], 52 -> 
             RGBColor[
              0.38664548537965426`, 0.5093146188938776, 0.9458576863245813], 
             187 -> RGBColor[
              0.8439338400416576, 0.8783939523481282, 0.9849763571234479], 
             259 -> RGBColor[
              0.2110206902246306, 0.3391265032835748, 0.9353286881799328], 42 -> 
             RGBColor[
              0.9322258626950144, 0.9487956145888052, 0.9933977290633442], 
             134 -> RGBColor[
              0.2343268669145523, 0.36362277268163234`, 0.9366559404640252], 
             313 -> RGBColor[
              0.2828083531870263, 0.41457988865777246`, 0.939416889385311], 
             248 -> RGBColor[
              0.21620788903044316`, 0.3445785781158837, 0.9356240914781508], 
             174 -> RGBColor[
              0.7286053839996127, 0.7879113306772935, 0.9735842335387989], 
             215 -> RGBColor[
              0.8192881970279116, 0.1492631112641677, 0.166103705297818], 399 -> 
             RGBColor[
              0.2348790166106703, 0.36420311702056507`, 0.9366873845723869], 
             83 -> RGBColor[
              0.35288166901045503`, 0.480070098173631, 0.9437062858017065], 
             95 -> RGBColor[
              0.2817785304161579, 0.4134974796310549, 0.9393582425019963], 
             166 -> RGBColor[
              0.8247691039330448, 0.19139176348574266`, 0.17135222793997262`],
              384 -> RGBColor[
              0.7484278388783107, 0.8033967830847693, 0.9755599505897345], 
             233 -> RGBColor[
              0.8174582326741875, 0.1351972033459516, 0.16435132936604271`], 
             295 -> RGBColor[
              0.24238734999627973`, 0.3720948514646729, 0.9371149730511135], 
             141 -> 
             RGBColor[
              0.3600639473667127, 0.48629102669401497`, 0.9441639342275279], 
             319 -> RGBColor[
              0.24158367299712782`, 0.37125013598249945`, 0.9370692048349454],
              205 -> RGBColor[
              0.9952685123171101, 0.9923114224965074, 0.7280765258104895], 
             224 -> RGBColor[
              0.9756615083220127, 0.9295626939998534, 0.3599499850798584], 
             231 -> RGBColor[
              0.30868412390727973`, 0.44177696430338015`, 0.9408904762480571],
              332 -> RGBColor[
              0.5272216074067284, 0.6270612778123552, 0.9559239626928917], 68 -> 
             RGBColor[
              0.2767246225454214, 0.4081855020226443, 0.9390704299253445], 10 -> 
             RGBColor[
              0.3619258765766598, 0.48790373619238797`, 0.9442825747103464], 
             250 -> RGBColor[
              0.9882272169582415, 0.9893996659125786, 0.8447690121952027], 
             282 -> RGBColor[
              0.6468617732853108, 0.7240526007128293, 0.965436794360271], 374 -> 
             RGBColor[
              0.2761037265699157, 0.40753290098530925`, 0.9390350708180728], 
             232 -> RGBColor[
              0.5255566438526651, 0.6257095853934133, 0.9557928906629534], 
             253 -> RGBColor[
              0.34171577858230273`, 0.47039876509873646`, 0.9429948051372339],
              55 -> RGBColor[
              0.4035326533159193, 0.5239414349865308, 0.9469337217327439], 
             325 -> RGBColor[
              0.21156771774634342`, 0.33970146389244305`, 0.9353598405880397],
              91 -> RGBColor[
              0.26262121251507564`, 0.39336192387290797`, 0.9382672615882417],
              105 -> RGBColor[
              0.417344109662346, 0.5359042242898253, 0.9478137755181469], 36 -> 
             RGBColor[
              0.5196772960404508, 0.620936465977857, 0.9553300468664151], 123 -> 
             RGBColor[
              0.9742961343763916, 0.9803506796209057, 0.9283941192456544], 94 -> 
             RGBColor[
              0.26012396818175015`, 0.3907371617441472, 0.9381250472178008], 
             312 -> RGBColor[
              0.46295717480753656`, 0.5748885163486347, 0.9508648311503101], 
             96 -> RGBColor[
              0.2869114883454893, 0.4188925438631119, 0.939650556862541], 2 -> 
             RGBColor[
              0.8184511944421836, 0.14282954261339104`, 0.16530219067646573`],
              262 -> RGBColor[
              0.9386428604207964, 0.9537605262817009, 0.9887458121893573], 
             272 -> 
             RGBColor[
              0.6470169280819229, 0.7241738088191627, 0.9654522587403933], 97 -> 
             RGBColor[
              0.44228444757308333`, 0.5575062914502744, 0.9494029517959442], 
             372 -> RGBColor[
              0.2514775053864574, 0.3816491811288898, 0.9376326439529042], 
             356 -> RGBColor[
              0.5183784049780293, 0.6198819676990077, 0.9552277934039866], 
             346 -> RGBColor[
              0.3450320119322843, 0.4732711197477559, 0.9432061125938647], 
             341 -> RGBColor[
              0.2215837127017966, 0.35022890964138337`, 0.935930236683416], 
             209 -> RGBColor[
              0.2520329891677718, 0.3822330298027571, 0.9376642779324855], 
             378 -> RGBColor[
              0.20852643568424656`, 0.3365048836167593, 0.9351866440737768], 
             66 -> RGBColor[
              0.9727828870163496, 0.9198524284034268, 0.3487670848893771], 
             139 -> RGBColor[
              0.2111706728502173, 0.3392841445325141, 0.9353372294685806], 56 -> 
             RGBColor[
              0.45093503134871465`, 0.5649989923257436, 0.9499541593447165], 
             335 -> RGBColor[
              0.28051817934621337`, 0.41217277074566994`, 0.9392864673730853],
              314 -> RGBColor[
              0.9258119809847409, 0.9436813594132142, 0.9927859673000785], 
             144 -> RGBColor[
              0.8784381059512442, 0.540897655273832, 0.22027811466207986`], 
             298 -> RGBColor[
              0.8234301328695646, 0.862044852807406, 0.9830206952294982], 204 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 207 -> 
             RGBColor[
              0.9398558182628138, 0.7992553918121872, 0.27046478349011155`], 
             334 -> RGBColor[
              0.26139903658851843`, 0.39207733948366696`, 0.9381976604772716],
              149 -> RGBColor[
              0.22021863489519794`, 0.34879412631571627`, 0.9358524975217819],
              219 -> RGBColor[
              0.4471878440862639, 0.5617533670581167, 0.9497153918858607], 
             400 -> RGBColor[
              0.38961090759033284`, 0.5118831185663134, 0.9460466404056259], 
             9 -> RGBColor[
              0.8256674379376745, 0.1982967522977973, 0.17221247359732916`], 
             11 -> RGBColor[
              0.9234626618564741, 0.7342619893565898, 0.25727446504873397`], 
             44 -> RGBColor[
              0.29795654320818293`, 0.4305015968207284, 0.940279556397277], 
             153 -> RGBColor[
              0.3174307607246093, 0.4493643032308905, 0.9414473852737397], 32 -> 
             RGBColor[
              0.21628540957162948`, 0.3446600571197567, 0.9356285061582901], 
             162 -> RGBColor[
              0.246083996032968, 0.37598026083012825`, 0.9373254915742051], 
             90 -> RGBColor[
              0.7058058015575851, 0.7701001235903371, 0.9713117842351892], 
             331 -> RGBColor[
              0.45209247002133757`, 0.5660015075294104, 0.9500279103134532], 
             8 -> RGBColor[
              0.3103199544645186, 0.44320528024791445`, 0.9409942909866859], 
             364 -> RGBColor[
              0.34952976604112324`, 0.4771668482931376, 0.9434927055084721], 
             342 -> RGBColor[
              0.6033581995623302, 0.6888723932386622, 0.9619177141249072], 
             163 -> RGBColor[
              0.2449732495734328, 0.3748127958757636, 0.9372622362065367], 49 -> 
             RGBColor[
              0.2557363986193865, 0.3861255479461254, 0.9378751816220516], 
             338 -> RGBColor[
              0.9942883740099587, 0.9901917344782997, 0.6197029429328111], 76 -> 
             RGBColor[
              0.8469444359628041, 0.36184108275892934`, 0.19258735093512552`],
              369 -> RGBColor[
              0.25745394897088236`, 0.38793080226452953`, 0.9379729935736814],
              82 -> RGBColor[
              0.37921715493462604`, 0.5028805724211383, 0.9453843596772389], 
             67 -> RGBColor[
              0.2129458677257866, 0.3411499869005934, 0.9354383241905787], 
             211 -> RGBColor[
              0.2626771974737526, 0.39342076761412886`, 
               0.9382704498488161]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9l3k0VX/Yxa95Hq55dufJNVwqktwdKpWiSIU0EZFIxkiFhGRKk6SkQSmp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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 7}], {
             RGBColor[
             0.37469401379728373`, 0.4989628549076562, 0.945096149123624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 35}], {
             RGBColor[
             0.32051204203418227`, 0.44947164236999554`, 0.9417375112912428]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 41}], {
             RGBColor[
             0.3504016747423545, 0.4779220517867386, 0.943548262759916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 57}], {
             RGBColor[
             0.31659522838756854`, 0.44535482288707584`, 0.9415144545484747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 92}], {
             RGBColor[
             0.3238234376355826, 0.4529521291016748, 0.9419260903719718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 96}], {
             RGBColor[
             0.32344726087306624`, 0.45255674347328584`, 0.9419046676618501]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 114}], {
             RGBColor[
             0.3444304570913155, 0.4727500831795342, 0.9431677820513322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 153}], {
             RGBColor[
             0.33870689706262624`, 0.4677926231571751, 0.9428030818674495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 154}], {
             RGBColor[
             0.39507053133992803`, 0.5166119702495444, 0.9463945228031945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 161}], {
             RGBColor[
             0.3957098398241182, 0.5171657071259712, 0.9464352589744887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 188}], {
             RGBColor[
             0.3135344759290187, 0.4421377779902256, 0.9413401492239378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 203}], {
             RGBColor[
             0.32569030455946724`, 0.45491432460487713`, 0.9420324056815049]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 222}], {
             RGBColor[
             0.48245496695292606`, 0.5881834392083616, 0.9530999932353155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 312}], {
             RGBColor[
             0.4114701041040899, 0.5305547297160472, 0.9475118048057347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 327}], {
             RGBColor[
             0.3392875835527789, 0.4682955846087937, 0.9428400826971212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 337}], {
             RGBColor[
             0.3223631828098259, 0.4514173086943011, 0.9418429310198984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 356}], {
             RGBColor[
             0.43918071918933627`, 0.5530514553912338, 0.949693285932573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 361}], {
             RGBColor[
             0.35780477718256065`, 0.4843342470296975, 0.9440199819010995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[
             0.8956170407292666, 0.531340985508409, 0.2570346377829214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 98}], {
             RGBColor[
             0.8980106482873484, 0.5394151858476, 0.26633335115120993`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 106}], {
             RGBColor[
             0.8834730056375308, 0.5519688209280622, 0.5686856052309635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 107}], {
             RGBColor[
             0.828834437069773, 0.222639695414975, 0.17524519554284063`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 197}], {
             RGBColor[
             0.9036013141673853, 0.5662229928500411, 0.5006917858198119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 215}], {
             RGBColor[
             0.8188696957350476, 0.14604632693877936`, 0.16570294798714186`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 283}], {
             RGBColor[
             0.8636832468154017, 0.4097080433065882, 0.20543575312607748`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 352}], {
             RGBColor[
             0.9063026650036, 0.5663670773157738, 0.3851970536504771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 52}], {
             RGBColor[
             0.3783625716146186, 0.5021403753019544, 0.9453299063837663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 86}], {
             RGBColor[
             0.33530800642617503`, 0.4640896371481913, 0.9426142996527203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 117}], {
             RGBColor[
             0.35979838664313185`, 0.4860610113427193, 0.9441470129330474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 174}], {
             RGBColor[
             0.5493425209245979, 0.6414387311936623, 0.9591931799908751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 232}], {
             RGBColor[
             0.4478181508511241, 0.5603378585517222, 0.9502975085529524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 309}], {
             RGBColor[
             0.32043505349243634`, 0.4484572206151509, 0.9417673069857059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 371}], {
             RGBColor[
             0.3210626317693298, 0.4491168451749269, 0.9418030466401561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 386}], {
             RGBColor[
             0.35472139925516205`, 0.48166358004406556`, 0.9438235117860897]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 16}], {
             RGBColor[
             0.23702850407735238`, 0.36646236463342485`, 0.9368097947037326]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 73}], {
             RGBColor[
             0.23765623707057423`, 0.3671221518098715, 0.9368455431690489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 115}], {
             RGBColor[
             0.23540129852856206`, 0.36475206843085556`, 0.936717127754964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 188}], {
             RGBColor[
             0.24964120798061978`, 0.37971911612737436`, 0.9375280695322004]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 195}], {
             RGBColor[
             0.2389456018045329, 0.3684773558957079, 0.9369189705832036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 206}], {
             RGBColor[
             0.23187928370438585`, 0.3610502075420088, 0.9365165542210812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 208}], {
             RGBColor[
             0.23264160776787357`, 0.36185145846687167`, 0.9365599674487393]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 258}], {
             RGBColor[
             0.24256487951038092`, 0.3722814462400146, 0.9371250830943101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 278}], {
             RGBColor[
             0.24230606056995913`, 0.37200941112356267`, 0.9371103437385414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 284}], {
             RGBColor[
             0.23809729374437577`, 0.3675857303386453, 0.936870660694137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 369}], {
             RGBColor[
             0.2448252232373639, 0.37465721081114345`, 0.937253806325683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 392}], {
             RGBColor[
             0.24007285485442642`, 0.3696621703231174, 0.9369831659767736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 99}], {
             RGBColor[
             0.9097853137766493, 0.92980801321679, 0.9533236132867424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 174}], {
             RGBColor[
             0.7850242052221269, 0.8321595879372474, 0.979161507318894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 193}], {
             RGBColor[
             0.8318913190108279, 0.8687915729636699, 0.983827730717042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 223}], {
             RGBColor[
             0.6477551093793219, 0.7220395366342189, 0.9674518801311646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 235}], {
             RGBColor[
             0.7907683520113988, 0.8366469590661592, 0.9797340301887447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 260}], {
             RGBColor[
             0.8251985302055844, 0.863544075950503, 0.9831657085828327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 267}], {
             RGBColor[
             0.7063209858486378, 0.7695859535146778, 0.9720624004607035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 272}], {
             RGBColor[
             0.744229977263282, 0.800290827008182, 0.9750955199196911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 275}], {
             RGBColor[
             0.916771833602923, 0.9337046356973782, 0.882657568389807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 291}], {
             RGBColor[
             0.7689673032381015, 0.8196158140703518, 0.9775611053894065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 321}], {
             RGBColor[
             0.8296147450427847, 0.8669940565457998, 0.9836058756059307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 338}], {
             RGBColor[
             0.9178657002272999, 0.9332997898377504, 0.8022208620159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 384}], {
             RGBColor[
             0.7949354326614759, 0.8399023141409853, 0.9801493658443617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 398}], {
             RGBColor[
             0.8904342144946242, 0.9153759950567726, 0.9860799767962038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 13}], {
             RGBColor[
             0.978563836078469, 0.9803436260913665, 0.7317471315868381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 18}], {
             RGBColor[
             0.9692770544063248, 0.9734175595259907, 0.7474672305772001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 74}], {
             RGBColor[
             0.909010509687477, 0.9256078266033538, 0.7502192883025007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 102}], {
             RGBColor[
             0.9063222891856516, 0.5687552194511105, 0.3417057295474893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 132}], {
             RGBColor[
             0.896284952197167, 0.9156286210821021, 0.7489609820272407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 160}], {
             RGBColor[
             0.9114125623801264, 0.6078812897957802, 0.3465801809071596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 166}], {
             RGBColor[
             0.9090583234505556, 0.5897855777490221, 0.34432575904947005`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 185}], {
             RGBColor[
             0.9085190133388343, 0.5856402039031354, 0.34380931507742224`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 198}], {
             RGBColor[
             0.9099185860419527, 0.9263319020393368, 0.75030590143584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 213}], {
             RGBColor[
             0.9521578283629528, 0.8364523308595698, 0.38226017426140096`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 216}], {
             RGBColor[
             0.8262245586177389, 0.8608969091391403, 0.7419780167468455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 224}], {
             RGBColor[
             0.9845045256450395, 0.9588710430060774, 0.43862463761941295`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 247}], {
             RGBColor[
             0.9501775412917424, 0.8286011525137683, 0.3806667888005933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 289}], {
             RGBColor[
             0.9455504255792939, 0.808391434737298, 0.3768472415142159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 302}], {
             RGBColor[
             0.9903122885265428, 0.9784619909329613, 0.461186699710061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 323}], {
             RGBColor[
             0.9117788938600264, 0.9278152609967583, 0.7504833392562442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 340}], {
             RGBColor[
             0.9935628356137232, 0.988639881211936, 0.5407325660065214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 40}], {
             RGBColor[
             0.36435856265805855`, 0.4900108066057379, 0.9444375833163132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 41}], {
             RGBColor[
             0.36511265513899505`, 0.490663963610935, 0.9444856334223808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 80}], {
             RGBColor[
             0.36191069619973304`, 0.48789058771288196`, 0.9442816074301521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 96}], {
             RGBColor[
             0.3381582412697068, 0.46529865529748227`, 0.9428420383243149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 114}], {
             RGBColor[
             0.359141437487956, 0.48549199500373064`, 0.9441051527137969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 153}], {
             RGBColor[
             0.3534178774592668, 0.48053453498137155`, 0.9437404525299142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 154}], {
             RGBColor[
             0.40978151173656857`, 0.5293538820737408, 0.9473318934656592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 192}], {
             RGBColor[
             0.36694736915401993`, 0.4922531006753419, 0.9446025397770442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 203}], {
             RGBColor[
             0.3404012849561078, 0.4676562364290735, 0.9429697763439697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 222}], {
             RGBColor[
             0.4971659473495666, 0.600925351032558, 0.9540373638977802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 228}], {
             RGBColor[
             0.37863108577837257`, 0.5023729487746839, 0.9453470158688431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 312}], {
             RGBColor[
             0.42618108450073044`, 0.5432966415402436, 0.9484491754681994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 332}], {
             RGBColor[
             0.45831330080032634`, 0.5693830222721039, 0.9509787412394903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 356}], {
             RGBColor[
             0.4538916995859768, 0.5657933672154302, 0.9506306565950378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 361}], {
             RGBColor[
             0.3725157575792012, 0.497076158853894, 0.9449573525635642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 385}], {
             RGBColor[
             0.4824130197414953, 0.5889482597885108, 0.9528759593947184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 17}], {
             RGBColor[
             0.42291827954092154`, 0.5385004052405986, 0.9487856331227857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.3116185481608299, 0.44433005683844234`, 0.9410770362287135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 36}], {
             RGBColor[
             0.41499862525248465`, 0.5320708731128857, 0.9481621689265505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 60}], {
             RGBColor[
             0.33392414851101215`, 0.4636500467496988, 0.9424983293589592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 64}], {
             RGBColor[
             0.3546401133620532, 0.4815931742890025, 0.9438183323208591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.34476855469957235`, 0.4730429263345264, 0.9431893253319623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 157}], {
             RGBColor[
             0.38978189814954545`, 0.5115987980501094, 0.9461770157970921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 171}], {
             RGBColor[
             0.2917662705538139, 0.42384970493064567`, 0.9399323578314926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 182}], {
             RGBColor[
             0.29920713316336395`, 0.4316705233112208, 0.9403561039493367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 210}], {
             RGBColor[
             0.30512183219392025`, 0.43788724700591375`, 0.9406929373091137]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 253}], {
             RGBColor[
             0.3260178665234107, 0.4568020226733255, 0.9419945480619598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 61}], {
             RGBColor[
             0.9095066708030527, 0.5932363190069687, 0.34466666805378354`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 131}], {
             RGBColor[
             0.8740668087143025, 0.4643040105665355, 0.21434257277214977`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 142}], {
             RGBColor[
             0.8236257057163587, 0.18260310375199956`, 0.1702573085163904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 202}], {
             RGBColor[
             0.8410035318945833, 0.31617669076982174`, 0.1868983344901058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 214}], {
             RGBColor[
             0.9047202658222255, 0.5928576663351037, 0.5422822863417485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 215}], {
             RGBColor[
             0.822477817482793, 0.1737799317809825, 0.1691580894475736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 217}], {
             RGBColor[
             0.8242465537218799, 0.18737521357976708`, 0.17085183326762515`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 269}], {
             RGBColor[
             0.909363183463878, 0.5929294140972693, 0.329048956685827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 279}], {
             RGBColor[
             0.8856585389447988, 0.5102613582153388, 0.22366955100848618`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 300}], {
             RGBColor[
             0.8578321079350941, 0.3958398187210729, 0.2010677137447785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 306}], {
             RGBColor[
             0.8980217768542582, 0.5550152880766823, 0.25581485333926096`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 363}], {
             RGBColor[
             0.8440899658094313, 0.333439960887275, 0.18960093350439794`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 39}], {
             RGBColor[
             0.3175089705748625, 0.446135594734304, 0.9415730679165266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 177}], {
             RGBColor[
             0.34191718866131093`, 0.47057321638600846`, 0.9430076388093683]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.3312363099818102, 0.46056389881459425`, 0.9423548195879734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 200}], {
             RGBColor[
             0.31629276558560215`, 0.4448572861787412, 0.9415038068416022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 216}], {
             RGBColor[
             0.5105137254220357, 0.6107590812291837, 0.9554696590225349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 219}], {
             RGBColor[
             0.4045568603314619, 0.5248285516252523, 0.9469989832981036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 241}], {
             RGBColor[
             0.32644391245681637`, 0.4555267851602728, 0.9420818996386419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 296}], {
             RGBColor[
             0.331723708667086, 0.46107618573568054`, 0.9423825762220581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 311}], {
             RGBColor[
             0.4406499577202704, 0.5542970021663628, 0.9497943740304772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 339}], {
             RGBColor[
             0.3638431893323356, 0.48956441613441326`, 0.9444047441837249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 360}], {
             RGBColor[
             0.336158799712734, 0.4655855893037951, 0.9426407193575084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 374}], {
             RGBColor[
             0.31901480157328777`, 0.4477183185888486, 0.9416588227642095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 14}], {
             RGBColor[
             0.9589098698169762, 0.8623003371232989, 0.4422276945427869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 25}], {
             RGBColor[
             0.8860868883930885, 0.5548412704093811, 0.2257767948788701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 38}], {
             RGBColor[
             0.9446269367354516, 0.8152649274529434, 0.2894401056343812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 78}], {
             RGBColor[
             0.8826533057204708, 0.5284492493821207, 0.22248879223389445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 102}], {
             RGBColor[
             0.8713798486298555, 0.4417965181232547, 0.21169331699237254`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 144}], {
             RGBColor[
             0.9009503839038591, 0.6375798223152109, 0.23877628985540691`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 205}], {
             RGBColor[
             0.9593655870867921, 0.8632867059265485, 0.49267549542961175`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 207}], {
             RGBColor[
             0.931659240059644, 0.7667586905843885, 0.26386962426942273`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 213}], {
             RGBColor[
             0.9172153878071567, 0.709493629531714, 0.2522477617062842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 221}], {
             RGBColor[
             0.9226607888866434, 0.8373956409938654, 0.6248416927368453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 230}], {
             RGBColor[
             0.9461599473200244, 0.8204361321227099, 0.29539556227068897`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 250}], {
             RGBColor[
             0.9558449394073578, 0.8618308276345842, 0.5510217386219683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 289}], {
             RGBColor[
             0.9106079850234978, 0.6814327334094423, 0.24683482895909917`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 358}], {
             RGBColor[
             0.9460196672175634, 0.8199629343977746, 0.2948506005623025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 391}], {
             RGBColor[
             0.8719267260498035, 0.4460000576161881, 0.2122170074273244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 118}], {
             RGBColor[
             0.21224930323971947`, 0.34041785346099757`, 0.9353986558735721]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 126}], {
             RGBColor[
             0.2152393660615204, 0.3435605990676429, 0.935568935527872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 149}], {
             RGBColor[
             0.21932780961758047`, 0.3478578124673555, 0.9358017663400795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 199}], {
             RGBColor[
             0.22211987446733733`, 0.350792449651586, 0.9359607703027832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 212}], {
             RGBColor[
             0.2146670795751315, 0.34295908968538924`, 0.9355363446590942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 238}], {
             RGBColor[
             0.22383004590865202`, 0.3525899482675398, 0.9360581620363942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 259}], {
             RGBColor[
             0.2147288372822968, 0.3430240009512847, 0.9355398616691548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 274}], {
             RGBColor[
             0.2245824786939262, 0.35338080283185697`, 0.936101011970391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 299}], {
             RGBColor[
             0.21628284341415968`, 0.3446573599255522, 0.9356283600194184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 318}], {
             RGBColor[
             0.2211272263803799, 0.3497491135746699, 0.9359042404627222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 336}], {
             RGBColor[
             0.21472177259901426`, 0.343016575521228, 0.9355394593458932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 367}], {
             RGBColor[
             0.21887583976336028`, 0.3473827634940262, 0.9357760273255111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 18}], {
             RGBColor[
             0.9544933475167275, 0.9655817936050558, 0.9619150720050708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 69}], {
             RGBColor[
             0.7259993754166094, 0.7839523785382002, 0.9495242388978706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 74}], {
             RGBColor[
             0.8942268027978797, 0.9177720606824189, 0.9646671297303714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 88}], {
             RGBColor[
             0.9770469480723544, 0.9813851840644524, 0.8781922259657269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 132}], {
             RGBColor[
             0.8815012453075697, 0.9077928551611671, 0.9634088234551113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[
             0.8178525622986523, 0.8580700202466935, 0.9570649175635426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 191}], {
             RGBColor[
             0.8213167457883995, 0.8607762667176537, 0.9574101949991654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 198}], {
             RGBColor[
             0.8951348791523555, 0.9184961361184019, 0.9647537428637106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 216}], {
             RGBColor[
             0.8114408517281416, 0.8530611432182054, 0.956425858174716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 224}], {
             RGBColor[
             0.9697208187554422, 0.9510352770851425, 0.6530724790472836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 302}], {
             RGBColor[
             0.9755285816369456, 0.9706262250120263, 0.6756345411379316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 323}], {
             RGBColor[
             0.8969951869704291, 0.9199794950758233, 0.9649311806841149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 340}], {
             RGBColor[
             0.9787791287241259, 0.9808041152910011, 0.7551804074343922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 357}], {
             RGBColor[
             0.8197351159980406, 0.8595406855045937, 0.9572525529228332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 38}], {
             RGBColor[
             0.9800741446959539, 0.9433032752196526, 0.4743933351284341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 102}], {
             RGBColor[
             0.9068270565903578, 0.5698348658899638, 0.39664654648642544`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 205}], {
             RGBColor[
             0.9948127950472943, 0.9913250536932577, 0.6776287249236647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 207}], {
             RGBColor[
             0.9671064480201461, 0.8947970383510977, 0.44882285376347564`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.9526625957676589, 0.8375319772984231, 0.4372009912003371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 224}], {
             RGBColor[
             0.9850092930497456, 0.9599506894449308, 0.4935654545583491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 230}], {
             RGBColor[
             0.9816071552805266, 0.9484744798894191, 0.4803487917647419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 247}], {
             RGBColor[
             0.9506823086964485, 0.8296807989526216, 0.43560760573952945`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 250}], {
             RGBColor[
             0.99129214736786, 0.9898691754012934, 0.7359749681160213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 289}], {
             RGBColor[
             0.9460551929840001, 0.8094710811761514, 0.43178805845315205`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 340}], {
             RGBColor[
             0.9940676030184292, 0.9897195276507893, 0.5956733829454577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 391}], {
             RGBColor[
             0.9073739340103057, 0.5740384053828973, 0.3971702369213773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 45}], {
             RGBColor[
             0.29968000514429743`, 0.4323130645893829, 0.9403777050049051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 100}], {
             RGBColor[
             0.34023750094859895`, 0.4686666959527124, 0.9429171480552854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 105}], {
             RGBColor[
             0.36060251301143975`, 0.486305845826277, 0.9442147886158565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.3163910437219365, 0.4480120932607672, 0.9413976728873965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 155}], {
             RGBColor[
             0.30420326810120896`, 0.4370673007485326, 0.9406352981387334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 170}], {
             RGBColor[
             0.3744152758657625, 0.49826976676104406`, 0.9450949256507872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 180}], {
             RGBColor[
             0.33506546922916314`, 0.4641869420312098, 0.9425875907675709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 183}], {
             RGBColor[
             0.281397272925088, 0.41309675383481925`, 0.9393365304518997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 239}], {
             RGBColor[
             0.3141879177885835, 0.4461038563096259, 0.9412572916510711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 271}], {
             RGBColor[
             0.3053243996883596, 0.43824568113047624`, 0.940699144924056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 273}], {
             RGBColor[
             0.28964915667663804`, 0.4217700068573468, 0.9398064630239824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 326}], {
             RGBColor[
             0.3216255760176605, 0.45254598204008034`, 0.9417312126565649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 335}], {
             RGBColor[
             0.2921895478533735, 0.4244401190541993, 0.9399511345433256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 394}], {
             RGBColor[
             0.33136443385417313`, 0.4609812912088401, 0.9423517640661736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 73}], {
             RGBColor[
             0.24248824364408117`, 0.372200897085539, 0.937120718795097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 85}], {
             RGBColor[
             0.2415839884274967, 0.3712504675198166, 0.9370692227982382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 96}], {
             RGBColor[
             0.2643859994981743, 0.3952168268861021, 0.9383677635961609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 110}], {
             RGBColor[
             0.2487192272457111, 0.3787500559180304, 0.9374755640932957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 115}], {
             RGBColor[
             0.240233305102069, 0.36983081370652304`, 0.936992303381012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 184}], {
             RGBColor[
             0.22981171473055614`, 0.35887706145906934`, 0.9363988092267157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 188}], {
             RGBColor[
             0.25447321455412675`, 0.38479786140304184`, 0.9378032451582485]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 203}], {
             RGBColor[
             0.2666290431845753, 0.3975744080176934, 0.9384955016158156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 206}], {
             RGBColor[
             0.23671129027789278`, 0.36612895281767627`, 0.9367917298471292]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 208}], {
             RGBColor[
             0.2374736143413805, 0.36693020374253915`, 0.9368351430747874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 258}], {
             RGBColor[
             0.24739688608388788`, 0.37736019151568206`, 0.9374002587203583]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 284}], {
             RGBColor[
             0.24292930031788273`, 0.3726644756143127, 0.9371458363201851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 325}], {
             RGBColor[
             0.22671411419860138`, 0.35562128690076766`, 0.9362224054589102]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 348}], {
             RGBColor[
             0.252407866634222, 0.38262704978860046`, 0.9376856266496183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 369}], {
             RGBColor[
             0.24965722981087085`, 0.3797359560868109, 0.9375289819517311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 392}], {
             RGBColor[
             0.24490486142793333`, 0.37474091559878486`, 0.9372583416028217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 36}], {
             RGBColor[
             0.5275969503288876, 0.6273659981055699, 0.9559535110626505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 64}], {
             RGBColor[
             0.46723843843845614`, 0.5768882992816866, 0.951609674456959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 82}], {
             RGBColor[
             0.4573668797759753, 0.5683380513272105, 0.9509806674680623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 122}], {
             RGBColor[
             0.490802095307585, 0.5972979545178956, 0.9531111298361363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 157}], {
             RGBColor[
             0.5023802232259484, 0.6068939230427937, 0.9539683579331921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 187}], {
             RGBColor[
             0.6897252223294911, 0.7560947412907055, 0.9707766661911668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 218}], {
             RGBColor[
             0.7227901892843811, 0.7824598484159166, 0.9739304322567687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 253}], {
             RGBColor[
             0.43861619159981363`, 0.5520971476660097, 0.9497858901980598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 262}], {
             RGBColor[
             0.7370797325190604, 0.7937780282574919, 0.9726613937241215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 298}], {
             RGBColor[
             0.6794733687434446, 0.7479201915203444, 0.969798835244192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 74}], {
             RGBColor[
             0.8849400211257357, 0.9108459941170431, 0.9803872287207334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 132}], {
             RGBColor[
             0.8722144636354254, 0.9008667885957915, 0.9791289224454733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 140}], {
             RGBColor[
             0.8085657806265083, 0.8511439536813179, 0.9727850165539047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 191}], {
             RGBColor[
             0.8120299641162554, 0.853850200152278, 0.9731302939895274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.8858480974802114, 0.9115700695530261, 0.9804738418540726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 216}], {
             RGBColor[
             0.8021540700559975, 0.8461350766528297, 0.9721459571650781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.960434037083298, 0.9441092105197667, 0.6687925780376456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 247}], {
             RGBColor[
             0.926107052730001, 0.8138393200274576, 0.6108347292188259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 302}], {
             RGBColor[
             0.9662417999648014, 0.9637001584466507, 0.6913546401282936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 311}], {
             RGBColor[
             0.7322903023542322, 0.7896729975900088, 0.9664706721730203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 323}], {
             RGBColor[
             0.8877084052982851, 0.9130534285104475, 0.9806512796744769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 340}], {
             RGBColor[
             0.9694923470519816, 0.9738780487256253, 0.770900506424754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 357}], {
             RGBColor[
             0.8104483343258964, 0.8526146189392179, 0.9729726519131952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 83}], {
             RGBColor[
             0.31363288900734776`, 0.44289778603368235`, 0.9413217134716801]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 108}], {
             RGBColor[
             0.3209765938651673, 0.4492585340761873, 0.9417896478514372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 125}], {
             RGBColor[
             0.27618503388558474`, 0.4076183601292589, 0.9390397011494167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 179}], {
             RGBColor[
             0.2720136332383074, 0.4032339535668936, 0.9388021460535885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 196}], {
             RGBColor[
             0.2861541125436652, 0.4180964938749955, 0.9396074254310642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 231}], {
             RGBColor[
             0.2915341164557601, 0.4237512190985569, 0.9399138086948555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 303}], {
             RGBColor[
             0.2819979246761117, 0.4137280769086658, 0.939370736680536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 313}], {
             RGBColor[
             0.27859623109563336`, 0.41015268127575305`, 0.9391770152634824]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 344}], {
             RGBColor[
             0.2975063791842545, 0.4289298137668702, 0.9402941465258654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 50}], {
             RGBColor[
             0.4309033063250306, 0.5476259924741631, 0.9486839796675377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 54}], {
             RGBColor[
             0.4298252331165606, 0.5467147461063611, 0.9486090616680254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 116}], {
             RGBColor[
             0.4119401607737857, 0.531223595372923, 0.9474694406734923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 121}], {
             RGBColor[
             0.48042756078829996`, 0.5878320132896839, 0.9525827103922078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 130}], {
             RGBColor[
             0.4090322853711047, 0.5287049398531881, 0.9472841534241666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 135}], {
             RGBColor[
             0.45546851492086315`, 0.5675691354622958, 0.9506178428735257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 147}], {
             RGBColor[
             0.34619840677068126`, 0.47206167326583015`, 0.9433617090301424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 158}], {
             RGBColor[
             0.4553874406509526, 0.5675033157176284, 0.9506114604100135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 172}], {
             RGBColor[
             0.3545418209166673, 0.4808311305362721, 0.9438368541227812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 181}], {
             RGBColor[
             0.4874856363228792, 0.5935620769713348, 0.9531383479528726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 265}], {
             RGBColor[
             0.49977683892029745`, 0.6035406289522859, 0.9541059564454999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 322}], {
             RGBColor[
             0.45803755349750475`, 0.5696547967126826, 0.9508200870009773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 328}], {
             RGBColor[
             0.3585480828066595, 0.484978061001665, 0.9440673446781876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 347}], {
             RGBColor[
             0.3438545327447645, 0.469598113054395, 0.9432282288718172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 362}], {
             RGBColor[
             0.406159003588231, 0.5262162475882044, 0.9471010704497052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 364}], {
             RGBColor[
             0.37859437323609996`, 0.5023411502157933, 0.945344676578113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 387}], {
             RGBColor[
             0.3506138656824209, 0.476702600538333, 0.94361316288308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.416297218948796, 0.5331956497034136, 0.948244914168578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 60}], {
             RGBColor[
             0.33522274220732345`, 0.4647748233402267, 0.9425810746009868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 64}], {
             RGBColor[
             0.3559387070583645, 0.4827179508795304, 0.9439010775628867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 82}], {
             RGBColor[
             0.34606714839588365`, 0.4741677029250543, 0.94327207057399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 122}], {
             RGBColor[
             0.37950236392749337`, 0.5031276061157393, 0.9454025329420639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 159}], {
             RGBColor[
             0.3221758681761928, 0.45347427680941704`, 0.9417497393246208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 182}], {
             RGBColor[
             0.30050572685967525`, 0.4327952999017487, 0.9404388491913643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 210}], {
             RGBColor[
             0.30642042589023155`, 0.43901202359644165`, 0.9407756825511414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 263}], {
             RGBColor[
             0.2875003760669833, 0.4191258516317633, 0.9396982137034129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 29}], {
             RGBColor[
             0.2663738031073146, 0.39730613451333674`, 0.9384809660710094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 45}], {
             RGBColor[
             0.2939087453063859, 0.4262471045807297, 0.94004904029495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 91}], {
             RGBColor[
             0.2774698045998931, 0.40896873560916513`, 0.9391128669409485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 97}], {
             RGBColor[
             0.36730142212889694`, 0.4910409193978484, 0.9446807120447999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 100}], {
             RGBColor[
             0.3344662411106874, 0.46260073594405915`, 0.9425884833453301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 141}], {
             RGBColor[
             0.32619117202571163`, 0.45543328701971864`, 0.9420612032605917]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 150}], {
             RGBColor[
             0.28145958694833023`, 0.41316224982418415`, 0.9393400791433381]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 189}], {
             RGBColor[
             0.29643257003583556`, 0.4288998043911114, 0.9401927683796281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 190}], {
             RGBColor[
             0.26671069132338054`, 0.3976602253883686, 0.938500151356533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 255}], {
             RGBColor[
             0.27639668732322686`, 0.40784082131182386`, 0.9390517544995772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 266}], {
             RGBColor[
             0.27365816407618504`, 0.40496245974678047`, 0.9388957996519403]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 273}], {
             RGBColor[
             0.28387789683872655`, 0.4157040468486936, 0.9394777983140272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 350}], {
             RGBColor[
             0.36253057369193453`, 0.4869086502715662, 0.9443767178010922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 365}], {
             RGBColor[
             0.27427955709376345`, 0.40561558320684826`, 0.9389311870650228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 394}], {
             RGBColor[
             0.32559317401626164`, 0.45491533120018696`, 0.9420230993562184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[
             0.2165666874460731, 0.34495569799984427`, 0.9356445245171263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 89}], {
             RGBColor[
             0.21600037669219402`, 0.3443604694913417, 0.9356122739574746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 163}], {
             RGBColor[
             0.22919558870789478`, 0.35822947394460614`, 0.9363637217612019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 164}], {
             RGBColor[
             0.22797821780387265`, 0.3569499399387055, 0.9362943942891566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 169}], {
             RGBColor[
             0.21705819820147026`, 0.34547230696734843`, 0.9356725153275212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 227}], {
             RGBColor[
             0.22416996966139735`, 0.3529472296840859, 0.936077520191241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 245}], {
             RGBColor[
             0.22165838805798918`, 0.35030739817543277`, 0.9359344893344789]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 292}], {
             RGBColor[
             0.21221830344661968`, 0.3403852707129492, 0.9353968904812151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 304}], {
             RGBColor[
             0.2162581809318601, 0.34463143809296365`, 0.9356269555275363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 353}], {
             RGBColor[
             0.21189878814995255`, 0.34004943987771225`, 0.9353786945577505]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 378}], {
             RGBColor[
             0.21097218176330165`, 0.339075517815104, 0.9353259256948219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 25}], {
             RGBColor[
             0.8754320696783777, 0.5120010563873596, 0.21717277432657275`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 76}], {
             RGBColor[
             0.8745487301949283, 0.505211322035738, 0.2163268874396324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 104}], {
             RGBColor[
             0.9180135558932775, 0.712060691693382, 0.25285908317008815`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 109}], {
             RGBColor[
             0.9481247371168586, 0.8202041529201762, 0.49378352937662584`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 138}], {
             RGBColor[
             0.8607479504188854, 0.399132481136813, 0.2031112451403423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 144}], {
             RGBColor[
             0.8902955651891483, 0.5947396082931894, 0.23017226930310958`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 207}], {
             RGBColor[
             0.9210044213449331, 0.723918476562367, 0.2552656037171254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 233}], {
             RGBColor[
             0.8598056285506199, 0.3918893823292492, 0.202208876655091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 242}], {
             RGBColor[
             0.9102499321760205, 0.681280510728698, 0.24661228929151274`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 317}], {
             RGBColor[
             0.946390043794504, 0.8194868126517976, 0.5225318869704552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 358}], {
             RGBColor[
             0.9353648485028525, 0.777122720375753, 0.28624658001000514`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 366}], {
             RGBColor[
             0.9017167350633479, 0.6466004732099342, 0.2397023734046333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 382}], {
             RGBColor[
             0.9004669733536322, 0.6409255971753784, 0.23865954159958375`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[
             0.8478277754462535, 0.3686308171105509, 0.1934332378220659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 104}], {
             RGBColor[
             0.8912926011446027, 0.575480186768195, 0.22996543355252164`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 109}], {
             RGBColor[
             0.9214037823681839, 0.6836236479949891, 0.47088987975905927`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 138}], {
             RGBColor[
             0.8340269956702107, 0.26255197621162585`, 0.18021759552277578`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 144}], {
             RGBColor[
             0.8635746104404736, 0.45815910336800225`, 0.20727861968554306`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 205}], {
             RGBColor[
             0.9219898136234065, 0.68386598697934, 0.46117782525974793`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 207}], {
             RGBColor[
             0.8942834665962583, 0.5873379716371798, 0.2323719540995589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 233}], {
             RGBColor[
             0.8330846738019452, 0.25530887740406205`, 0.17931522703752448`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 317}], {
             RGBColor[
             0.9196690890458292, 0.6829063077266104, 0.4996382373528887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 358}], {
             RGBColor[
             0.9086438937541778, 0.640542215450566, 0.2633529303924386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 366}], {
             RGBColor[
             0.8749957803146731, 0.510019968284747, 0.21680872378706678`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 382}], {
             RGBColor[
             0.8737460186049575, 0.5043450922501913, 0.21576589198201723`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 391}], {
             RGBColor[
             0.8345509525864179, 0.2665793386689794, 0.18071933725746053`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 30}], {
             RGBColor[
             0.31701994287924884`, 0.4369570883961569, 0.9418741496415883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 62}], {
             RGBColor[
             0.31709055637755623`, 0.43703130766003234`, 0.9418781709758536]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 77}], {
             RGBColor[
             0.6422389788407158, 0.7176486903810251, 0.9669170377654001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 106}], {
             RGBColor[
             0.7018038352541023, 0.7648141211568, 0.9611581586207743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 111}], {
             RGBColor[
             0.6645955027358419, 0.5448101324102603, 0.5834436797495368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 160}], {
             RGBColor[
             0.6422952177337565, 0.39805166532506286`, 0.5630541845557195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.6399409788041857, 0.37995595327830467`, 0.56079976269803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 173}], {
             RGBColor[
             0.34074023236907375`, 0.46188861660318076`, 0.9432249850370102]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 185}], {
             RGBColor[
             0.6394016686924645, 0.37581057943241813`, 0.5602833187259821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 197}], {
             RGBColor[
             0.7219321437839568, 0.7790682930787789, 0.8931643392096228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 204}], {
             RGBColor[
             0.3170199268376633, 0.4369570715354334, 0.9418741487280438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 345}], {
             RGBColor[
             0.3285301240705917, 0.4490550186158963, 0.9425296374326482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 370}], {
             RGBColor[
             0.6431647387570222, 0.7183868662092043, 0.9670053375726531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 389}], {
             RGBColor[
             0.31710049015279534`, 0.4370417486876464, 0.9418787366896577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 400}], {
             RGBColor[
             0.4223618806328297, 0.5402016308185901, 0.9481469689308566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 51}], {
             RGBColor[
             0.33517005330446453`, 0.4636817173337682, 0.9426160703012283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[
             0.3427358884343137, 0.47023486345331306`, 0.943098158625497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 277}], {
             RGBColor[
             0.277614773953709, 0.4091211075916136, 0.9391211227311855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 287}], {
             RGBColor[
             0.27881505582512084`, 0.4103826799407336, 0.9391894770081045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 376}], {
             RGBColor[
             0.3679050083022842, 0.49203509004620194`, 0.9447019126873052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 377}], {
             RGBColor[
             0.3561480526956704, 0.48185180602152367`, 0.9439527698723194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 395}], {
             RGBColor[
             0.28524240829505776`, 0.41713823490432095`, 0.9395555052228516]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 396}], {
             RGBColor[
             0.28785811658992677`, 0.419887510167713, 0.9397044659406507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 44}], {
             RGBColor[
             0.29312282823703784`, 0.42542105591082463`, 0.9400042834805107]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 47}], {
             RGBColor[
             0.3610905157265072, 0.4852888096589335, 0.9442985989042187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 49}], {
             RGBColor[
             0.27201275594263963`, 0.40323303147352313`, 0.938802096092898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 147}], {
             RGBColor[
             0.2865134731880893, 0.418474204697066, 0.9396278904881377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 211}], {
             RGBColor[
             0.2754831553698227, 0.4068806413075249, 0.9389997302062802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 301}], {
             RGBColor[
             0.27255350960952185`, 0.40380139786317903`, 0.9388328912142536]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 328}], {
             RGBColor[
             0.2988631492240676, 0.4313905924329009, 0.9403335261361829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 347}], {
             RGBColor[
             0.28416959916217255`, 0.4160106444856309, 0.9394944103298126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 362}], {
             RGBColor[
             0.34647407000563907`, 0.4726287790194402, 0.9433672519077005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 372}], {
             RGBColor[
             0.2698833093261751, 0.4009948480649053, 0.9386808272583244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 380}], {
             RGBColor[
             0.2768898890919296, 0.40835920764152867`, 0.9390798416106783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 390}], {
             RGBColor[
             0.2772941937947283, 0.40878415751856884`, 0.9391028661653874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 45}], {
             RGBColor[
             0.26796415172899, 0.39897769174864406`, 0.938571534072304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 91}], {
             RGBColor[
             0.25152521102249714`, 0.3816993227770795, 0.9376353607183026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 150}], {
             RGBColor[
             0.2555149933709343, 0.38589283699209853`, 0.937862572920692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 190}], {
             RGBColor[
             0.2407660977459846, 0.370390812556283, 0.937022645133887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 226}], {
             RGBColor[
             0.23953161826969796`, 0.36909329635618626`, 0.936952343353961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 266}], {
             RGBColor[
             0.2477135704987891, 0.37769304691469485`, 0.9374182934292943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 273}], {
             RGBColor[
             0.25793330326133057`, 0.388434634016608, 0.9380002920913812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 365}], {
             RGBColor[
             0.24833496351636752`, 0.37834617037476265`, 0.9374536808423768]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 62}], {
             RGBColor[
             0.17899764558147852`, 0.30546825298532254`, 0.9335050231613544]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 77}], {
             RGBColor[
             0.5041460680446381, 0.5860856357063153, 0.9585438899509009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 84}], {
             RGBColor[
             0.1789270231889713, 0.3053940243730791, 0.9335010013205776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 204}], {
             RGBColor[
             0.17892701604158556`, 0.30539401686072354`, 0.9335010009135446]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 333}], {
             RGBColor[
             0.1872437438170861, 0.31413542506377157`, 0.9339746262568631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 370}], {
             RGBColor[
             0.5050718279609444, 0.5868238115344944, 0.9586321897581539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 389}], {
             RGBColor[
             0.17900757935671766`, 0.3054786940129366, 0.9335055888751587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 400}], {
             RGBColor[
             0.284268969836752, 0.4086385761438802, 0.9397738211163575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 33}], {
             RGBColor[0.1810793999809316, 0.30765630885, 0.9336235759947237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 106}], {
             RGBColor[
             0.5658561150624204, 0.6355057978202503, 0.9529071762376704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 156}], {
             RGBColor[
             0.18458847622123073`, 0.3113445704668384, 0.9338234126953957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 173}], {
             RGBColor[
             0.20479251217739197`, 0.3325802932666311, 0.9349740026539064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 175}], {
             RGBColor[
             0.18107477738655686`, 0.3076514502102228, 0.9336233127448126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 197}], {
             RGBColor[
             0.5859844235922751, 0.6497599697422292, 0.884913356826519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 204}], {
             RGBColor[
             0.1810722066459815, 0.3076487481988837, 0.9336231663449399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 214}], {
             RGBColor[
             0.5834952534993698, 0.6486610383850888, 0.9230487158880236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 261}], {
             RGBColor[
             0.18133289143212553`, 0.3079227444374911, 0.9336380119578622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 295}], {
             RGBColor[
             0.21280238164412135`, 0.34099917393122015`, 0.9354301528704966]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 310}], {
             RGBColor[
             0.18289778193115996`, 0.30956754357176464`, 0.9337271301567341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 345}], {
             RGBColor[
             0.1925824038789099, 0.3197466952793466, 0.9342786550495443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 43}], {
             RGBColor[
             0.2218603287150994, 0.3505196506098328, 0.9359459895561568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 124}], {
             RGBColor[
             0.21977833860588586`, 0.34833134699925217`, 0.9358274232994656]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 137}], {
             RGBColor[
             0.21892075175740905`, 0.34742996884735633`, 0.9357785849971308]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 199}], {
             RGBColor[
             0.22104408708317058`, 0.349661728901967, 0.9358995058027398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 238}], {
             RGBColor[
             0.22275425852448527`, 0.3514592275179208, 0.9359968975363508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 252}], {
             RGBColor[
             0.2203092674216852, 0.34888938684748844`, 0.9358576589100864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 293}], {
             RGBColor[
             0.2137582367821496, 0.342003838286004, 0.9354845874065463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 330}], {
             RGBColor[
             0.2205286799485376, 0.349120003324768, 0.935870154128899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 63}], {
             RGBColor[
             0.5687512197366357, 0.5886439817299056, 0.6135098819197802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 84}], {
             RGBColor[
             0.17893420048233583`, 0.30540156816347186`, 0.9335014100568169]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 90}], {
             RGBColor[
             0.44237359411374266`, 0.5377546224462848, 0.9524068017673784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 152}], {
             RGBColor[
             0.18127877637637368`, 0.30786586608280325`, 0.9336349301854932]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 156}], {
             RGBColor[
             0.18245046291019928`, 0.30909738291907096`, 0.9337016560002396]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 173}], {
             RGBColor[
             0.20265449886636056`, 0.33033310571886365`, 0.9348522459587503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 175}], {
             RGBColor[
             0.17893676407552545`, 0.30540426266245535`, 0.9335015560496566]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 204}], {
             RGBColor[
             0.1789341933349501, 0.3054015606511163, 0.9335014096497838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 214}], {
             RGBColor[
             0.5813572401883383, 0.6464138508373214, 0.9229269591928677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 256}], {
             RGBColor[
             0.202124876078153, 0.3297764385884332, 0.9348220847244686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 261}], {
             RGBColor[
             0.17919487812109408`, 0.3056755568897237, 0.9335162552627061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 264}], {
             RGBColor[
             0.18448620056776344`, 0.31123707227039327`, 0.9338175882482339]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 295}], {
             RGBColor[
             0.21066436833308994`, 0.3387519863834527, 0.9353083961753406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 310}], {
             RGBColor[
             0.18075976862012855`, 0.3073203560239972, 0.9336053734615781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 333}], {
             RGBColor[
             0.1872509211104506, 0.3141429688541644, 0.9339750349931024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 381}], {
             RGBColor[
             0.5860442078575524, 0.648421627973087, 0.8483684065741224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 53}], {
             RGBColor[
             0.30076648553276153`, 0.4331274488318972, 0.9404515726006413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 68}], {
             RGBColor[
             0.29450681654452554`, 0.42654813983932427`, 0.9400950937121118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 86}], {
             RGBColor[
             0.30641268277319833`, 0.4390619601211778, 0.940773115180684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 95}], {
             RGBColor[
             0.29703377047989377`, 0.4292041286435296, 0.9402390000004376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 151}], {
             RGBColor[
             0.31406226415390115`, 0.44644668080690353`, 0.9412327476508988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 244}], {
             RGBColor[
             0.2861625929026812, 0.4177778317374103, 0.9396199025198813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 249}], {
             RGBColor[
             0.2909291460215572, 0.4227877812822719, 0.9398913506685179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 253}], {
             RGBColor[
             0.3270023945629662, 0.4576547713773704, 0.9420572813180563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 270}], {
             RGBColor[
             0.28093807902462586`, 0.41228653639826196`, 0.9393223741835017]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 308}], {
             RGBColor[
             0.2866886948098787, 0.4183307981986623, 0.9396498632451982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 386}], {
             RGBColor[
             0.32582607560218535`, 0.4566359030170521, 0.9419823273140535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 397}], {
             RGBColor[
             0.28081927975955956`, 0.41216167083836874`, 0.939315608741104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 41}], {
             RGBColor[
             0.3109306833758936, 0.44117275107327436`, 0.9411269955899995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 57}], {
             RGBColor[
             0.2771242370211076, 0.4086055221736117, 0.9390931873785582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 92}], {
             RGBColor[
             0.28435244626912165`, 0.4162028283882106, 0.9395048232020553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 114}], {
             RGBColor[
             0.30495946572485455`, 0.43600078246607, 0.9407465148814157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 153}], {
             RGBColor[
             0.2992359056961653, 0.4310433224437109, 0.940381814697533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 188}], {
             RGBColor[
             0.27406348456255775`, 0.4053884772767613, 0.9389188820540213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 195}], {
             RGBColor[
             0.2633678783864708, 0.39414671704509485`, 0.9383097831050244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 208}], {
             RGBColor[
             0.25706388434981153`, 0.3875208196162586, 0.9379507799705602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 258}], {
             RGBColor[
             0.2669871560923189, 0.3979508073894016, 0.938515895616131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 278}], {
             RGBColor[
             0.26672833715189703`, 0.3976787722729497, 0.9385011562603622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 284}], {
             RGBColor[
             0.26251957032631373`, 0.3932550914880322, 0.9382614732159579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 327}], {
             RGBColor[
             0.29981659218631795`, 0.43154628389532945`, 0.9404188155272046]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 337}], {
             RGBColor[
             0.28289219144336497`, 0.41466800798083686`, 0.9394216638499819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 354}], {
             RGBColor[
             0.2804072432672092, 0.41205616989288285`, 0.9392801497275012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 369}], {
             RGBColor[
             0.26924749981930185`, 0.40032657196053045`, 0.9386446188475038]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 392}], {
             RGBColor[
             0.2644951314363644, 0.3953315314725043, 0.9383739784985945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 55}], {
             RGBColor[
             0.46160497467818506`, 0.5724389504821938, 0.9511318842995795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 60}], {
             RGBColor[
             0.4386028192989782, 0.5525156396146701, 0.9496662072988238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 64}], {
             RGBColor[
             0.45931878415001925`, 0.5704587671539738, 0.9509862102607236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 82}], {
             RGBColor[
             0.4494472254875384, 0.5619085191994977, 0.950357203271827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 122}], {
             RGBColor[
             0.4828824410191481, 0.5908684223901826, 0.952487665639901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 157}], {
             RGBColor[
             0.49446056893751156`, 0.6004643909150807, 0.9533448937369567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 165}], {
             RGBColor[
             0.5262130350709433, 0.6262424733544989, 0.9558445641840965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 218}], {
             RGBColor[
             0.7148705349959443, 0.7760303162882036, 0.9733069680605333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 262}], {
             RGBColor[
             0.7291600782306236, 0.787348496129779, 0.9720379295278863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 298}], {
             RGBColor[
             0.6715537144550077, 0.7414906593926315, 0.9691753710479567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 314}], {
             RGBColor[
             0.7227446385125958, 0.7823089126955356, 0.9740580070832467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 58}], {
             RGBColor[
             0.2743052593933725, 0.40564259795335733`, 0.9389326507729624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 87}], {
             RGBColor[
             0.2699691213947309, 0.4010850419897568, 0.9386857141286811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 110}], {
             RGBColor[
             0.2526887349083196, 0.3829222601527542, 0.9377016216823209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 134}], {
             RGBColor[
             0.24206319644531432`, 0.3717541455300861, 0.9370965129859282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 159}], {
             RGBColor[
             0.29061706023566036`, 0.4206896192842019, 0.9399383913431659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 167}], {
             RGBColor[
             0.26667449670074206`, 0.39762218254510395`, 0.9384980901263189]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 201}], {
             RGBColor[
             0.26311290635419504`, 0.3938787252730125, 0.9382952628249838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 236}], {
             RGBColor[
             0.2501608630823501, 0.3802653065873294, 0.9375576631214831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 243}], {
             RGBColor[
             0.2690857390615694, 0.4001565511479292, 0.9386354068116546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 263}], {
             RGBColor[
             0.25594156812645086`, 0.3863411941065481, 0.9378868657219579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 348}], {
             RGBColor[
             0.2563773742968305, 0.38679925402332427`, 0.9379116842386436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 351}], {
             RGBColor[
             0.2477720085286644, 0.3777544689892789, 0.9374216213886444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 78}], {
             RGBColor[
             0.9038175805994484, 0.6094521874784743, 0.2546544328195417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 102}], {
             RGBColor[
             0.8925441235088332, 0.5227994562196083, 0.24385895757801979`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 205}], {
             RGBColor[
             0.9805298619657696, 0.9442896440229023, 0.524841136015259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 207}], {
             RGBColor[
             0.9528235149386215, 0.8477616286807421, 0.29603526485507003`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 213}], {
             RGBColor[
             0.9383796626861343, 0.7904965676280676, 0.28441340229193146`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 221}], {
             RGBColor[
             0.9438250637656209, 0.9183985790902189, 0.6570073333224926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 224}], {
             RGBColor[
             0.970726359968221, 0.9129152797745752, 0.34077786564994345`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 230}], {
             RGBColor[
             0.9673242221990019, 0.9014390702190636, 0.3275612028563362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 247}], {
             RGBColor[
             0.9363993756149239, 0.7826453892822661, 0.2828200168311238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 250}], {
             RGBColor[
             0.9770092142863354, 0.9428337657309378, 0.5831873792076157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 289}], {
             RGBColor[
             0.9317722599024755, 0.7624356715057958, 0.27900046954474644`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 358}], {
             RGBColor[
             0.9671839420965409, 0.9009658724941282, 0.3270162411479497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 391}], {
             RGBColor[
             0.8930910009287811, 0.5270029957125417, 0.24438264801297166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 93}], {
             RGBColor[
             0.2591650880555334, 0.38972931793498194`, 0.9380704404131488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 94}], {
             RGBColor[
             0.2666080163774077, 0.39755230751018356`, 0.9384943041702538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 119}], {
             RGBColor[
             0.2567952159774935, 0.3872384321223937, 0.9379354797042159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 128}], {
             RGBColor[
             0.2996526087721707, 0.4306693116276521, 0.9404352763322198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 177}], {
             RGBColor[
             0.29750028265951367`, 0.4288050749279245, 0.9402981320155486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 200}], {
             RGBColor[
             0.27187585958380484`, 0.4030891447206572, 0.9387943000477824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 225}], {
             RGBColor[
             0.26510008482719366`, 0.3959673758425263, 0.9384084296992539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 288}], {
             RGBColor[
             0.2590590279232666, 0.38961784201136873`, 0.9380644004455181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 296}], {
             RGBColor[
             0.2873068026652887, 0.4193080442775966, 0.9396730694282384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 316}], {
             RGBColor[
             0.26368578568270973`, 0.3944808577699287, 0.9383278874552436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 324}], {
             RGBColor[
             0.27652485948189337`, 0.40797553837716655`, 0.9390590537143996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 355}], {
             RGBColor[
             0.25200661552040216`, 0.3822053094271858, 0.9376627759922841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 360}], {
             RGBColor[
             0.29174189371093673`, 0.42381744784571107`, 0.9399312125636886]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 374}], {
             RGBColor[
             0.2745978955714905, 0.40595017713076464`, 0.9389493159703898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 375}], {
             RGBColor[
             0.2639687025623859, 0.39477822134843454`, 0.9383439991530031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 380}], {
             RGBColor[
             0.2692913647455158, 0.4003726767791782, 0.9386471168901593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 383}], {
             RGBColor[
             0.27666419535336334`, 0.408121989212486, 0.9390669886861509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 390}], {
             RGBColor[
             0.26969566944831447`, 0.40079762665621843`, 0.9386701414448686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 41}], {
             RGBColor[
             0.34006622360312927`, 0.4689700034848203, 0.942889696952605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 55}], {
             RGBColor[
             0.37142239221905604`, 0.496129140733077, 0.9448876842896408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 58}], {
             RGBColor[
             0.31906156196643076`, 0.449858262003899, 0.9415849314423156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.3368642646638673, 0.46619662758676733`, 0.9426856709603764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 87}], {
             RGBColor[
             0.31472542396778913`, 0.4453007060402985, 0.9413379947980343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 96}], {
             RGBColor[
             0.313111809733841, 0.4436046951713676, 0.9412461018545393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 110}], {
             RGBColor[
             0.29744503748137785`, 0.4271379242032959, 0.940353902351674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 146}], {
             RGBColor[
             0.43732168419070216`, 0.5509809435704429, 0.9497020146539848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 154}], {
             RGBColor[
             0.3847350802007028, 0.5076599219476261, 0.9457359569958835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 159}], {
             RGBColor[
             0.33537336280871854`, 0.46490528333474357`, 0.9425906720125191]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 167}], {
             RGBColor[
             0.31143079927380024`, 0.4418378465956456, 0.9411503707956721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 192}], {
             RGBColor[
             0.34190093761815415`, 0.4705591405492272, 0.9430066033072686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 203}], {
             RGBColor[
             0.31535485342024205`, 0.44596227630295887`, 0.941373839874194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 228}], {
             RGBColor[
             0.35358465424250685`, 0.48067898864856917`, 0.9437510793990673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 243}], {
             RGBColor[
             0.3138420416346276, 0.4443722151984709, 0.9412876874810078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 332}], {
             RGBColor[
             0.43326686926446056`, 0.5476890621459892, 0.9493828047697146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 348}], {
             RGBColor[
             0.3011336768698887, 0.43101491807386594`, 0.9405639649079968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 361}], {
             RGBColor[
             0.34746932604333547`, 0.4753821987277793, 0.9433614160937887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 385}], {
             RGBColor[
             0.4573665882056296, 0.5672542996623962, 0.9512800229249427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 57}], {
             RGBColor[
             0.3070138697292798, 0.4370559315903547, 0.9409039388472313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.31424207897729384`, 0.44465323780495364`, 0.9413155746707285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 96}], {
             RGBColor[
             0.3138659022147775, 0.44425785217656466`, 0.9412941519606068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 114}], {
             RGBColor[
             0.3348490984330268, 0.46445119188281303`, 0.9425572663500889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 153}], {
             RGBColor[
             0.32912553840433756`, 0.45949373186045395`, 0.9421925661662062]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 154}], {
             RGBColor[
             0.3854891726816393, 0.5083130789528232, 0.945784007101951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 188}], {
             RGBColor[
             0.30395311727072993`, 0.43383888669350434`, 0.9407296335226945]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 203}], {
             RGBColor[
             0.31610894590117855`, 0.4466154333081559, 0.9414218899802616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 222}], {
             RGBColor[
             0.4728736082946373, 0.5798845479116403, 0.9524894775340721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 258}], {
             RGBColor[
             0.29687678880049106`, 0.4264012168061446, 0.9403266470848042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 312}], {
             RGBColor[
             0.40188874544580117`, 0.5222558384193261, 0.9469012891044913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 327}], {
             RGBColor[
             0.32970622489449014`, 0.4599966933120725, 0.9422295669958778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 356}], {
             RGBColor[
             0.4295993605310475, 0.5447525640945126, 0.9490827702313296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 361}], {
             RGBColor[
             0.34822341852427197`, 0.4760353557329764, 0.9434094661998561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 369}], {
             RGBColor[
             0.2991371325274741, 0.4287769813772735, 0.940455370316177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 104}], {
             RGBColor[
             0.9330499750272585, 0.8621677183315113, 0.6295247357296906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 109}], {
             RGBColor[
             0.9631611562508396, 0.9703111795583055, 0.8704491819362283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 136}], {
             RGBColor[
             0.7754039881303256, 0.825013733522431, 0.9782569627328132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 205}], {
             RGBColor[
             0.9637471875060623, 0.9705535185426564, 0.8607371274369169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 207}], {
             RGBColor[
             0.9360408404789141, 0.8740255032004962, 0.6319312562767279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 221}], {
             RGBColor[
             0.9270423893059134, 0.944662453609973, 0.9929033247441504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 276}], {
             RGBColor[
             0.8488960037945177, 0.8827904862944987, 0.9853329329150746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 358}], {
             RGBColor[
             0.9504012676368335, 0.9272297470138823, 0.6629122325696076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 366}], {
             RGBColor[
             0.9167531541973288, 0.7967074998480634, 0.6163680259642358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 376}], {
             RGBColor[
             0.6853095806395425, 0.7514657941798157, 0.9712763701432583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 124}], {
             RGBColor[
             0.22535325774935577`, 0.3541909404893282, 0.9361449066973324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 137}], {
             RGBColor[
             0.22449567090087896`, 0.35328956233743236`, 0.9360960683949977]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 199}], {
             RGBColor[
             0.2266190062266405, 0.3555213223920431, 0.9362169892006067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 238}], {
             RGBColor[
             0.22832917766795519`, 0.3573188210079969, 0.9363143809342176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 252}], {
             RGBColor[
             0.2258841865651551, 0.3547489803375645, 0.9361751423079533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 277}], {
             RGBColor[
             0.2426240388727448, 0.37234362648077923`, 0.9371284521324783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 293}], {
             RGBColor[
             0.21933315592561953`, 0.34786343177608003`, 0.9358020708044131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 299}], {
             RGBColor[
             0.22078197517346282`, 0.34938623266600927`, 0.9358845789172419]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 330}], {
             RGBColor[
             0.2261035990920075, 0.35497959681484403`, 0.9361876375267658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 367}], {
             RGBColor[
             0.22337497152266345`, 0.35211163623448327`, 0.9360322462233344]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 47}], {
             RGBColor[
             0.36592423069765223`, 0.4903693505688373, 0.9445738718209851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 49}], {
             RGBColor[
             0.2768464709137847, 0.4083135723834269, 0.9390773690096643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 54}], {
             RGBColor[
             0.3749740145051137, 0.4982078184475008, 0.9451505160427869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 93}], {
             RGBColor[
             0.2715973273730923, 0.4027963897072362, 0.9387784380504338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[
             0.3120848480897295, 0.44373638339990634`, 0.9411432739695049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 211}], {
             RGBColor[
             0.28031687034096775`, 0.4119611822174286, 0.9392750031230466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 301}], {
             RGBColor[
             0.2773872245806669, 0.4088819387730828, 0.9391081641310199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 316}], {
             RGBColor[
             0.27611802500026855`, 0.4075479295421829, 0.9390358850925288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 324}], {
             RGBColor[
             0.2889570987994522, 0.4210426101494208, 0.9397670513516847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 328}], {
             RGBColor[
             0.3036968641952127, 0.4364711333428047, 0.9406087990529493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 362}], {
             RGBColor[
             0.35130778497678417`, 0.477709319929344, 0.9436425248244668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 372}], {
             RGBColor[
             0.27471702429732014`, 0.4060753889748091, 0.9389561001750906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 380}], {
             RGBColor[
             0.2817236040630746, 0.41343974855143245`, 0.9393551145274445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 383}], {
             RGBColor[
             0.28909643467092216`, 0.42118906098474024`, 0.9397749863234359]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 390}], {
             RGBColor[
             0.28212790876587335`, 0.4138646984284726, 0.9393781390821536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 91}], {
             RGBColor[
             0.27906015322156846`, 0.41064029284447245`, 0.9392034349422431]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 97}], {
             RGBColor[
             0.36889177075057233`, 0.4927124766331557, 0.9447712800460943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 100}], {
             RGBColor[
             0.33605658973236274`, 0.46427229317936647`, 0.9426790513466246]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 112}], {
             RGBColor[
             0.31221013250570034`, 0.4436176904874213, 0.9411595761787357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 141}], {
             RGBColor[
             0.32778152064738697`, 0.45710484425502595`, 0.9421517712618861]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 180}], {
             RGBColor[
             0.33088455801292704`, 0.4597925392578639, 0.9423494940589101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 190}], {
             RGBColor[
             0.2683010399450559, 0.3993317826236759, 0.9385907193578275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 266}], {
             RGBColor[
             0.2752485126978604, 0.4066340169820878, 0.9389863676532347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 271}], {
             RGBColor[
             0.30114348847212347`, 0.43385127835713033`, 0.9404610482153953]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 273}], {
             RGBColor[
             0.2854682454604019, 0.41737560408400093`, 0.9395683663153217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 350}], {
             RGBColor[
             0.36412092231360993`, 0.48858020750687353`, 0.9444672858023867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 365}], {
             RGBColor[
             0.2758699057154388, 0.4072871404421556, 0.9390217550663172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 394}], {
             RGBColor[
             0.32718352263793704`, 0.4565868884354943, 0.9421136673575129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 59}], {
             RGBColor[
             0.30916725287120805`, 0.4399481765928165, 0.9410035436196971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 287}], {
             RGBColor[
             0.27226485336384204`, 0.4034980018471065, 0.9388164526680909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 373}], {
             RGBColor[
             0.26731905714517273`, 0.3982996564396932, 0.9385347968900875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 395}], {
             RGBColor[
             0.27869220583377896`, 0.41025355681069386`, 0.939182480882838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 54}], {
             RGBColor[
             0.44294170199458305`, 0.5580755721956097, 0.9494448314664949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 121}], {
             RGBColor[
             0.4935440296663224, 0.5991928393789325, 0.9534184801906773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 128}], {
             RGBColor[
             0.3800525355791988, 0.5036041371480152, 0.945437589393213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 130}], {
             RGBColor[
             0.4221487542491271, 0.5400657659424366, 0.9481199232226362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.468503909528975, 0.5788641418068768, 0.9514472302084831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 181}], {
             RGBColor[
             0.5006021052009016, 0.6049229030605833, 0.9539741177513421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 265}], {
             RGBColor[
             0.5128933077983199, 0.6149014550415344, 0.9549417262439694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 311}], {
             RGBColor[
             0.47663297852550124`, 0.5854636862286419, 0.9520871802976505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 322}], {
             RGBColor[
             0.47115402237552717`, 0.5810156228019311, 0.9516558567994469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 362}], {
             RGBColor[
             0.4192754724662534, 0.5375770736774529, 0.9479368402481747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 56}], {
             RGBColor[
             0.43818896314994105`, 0.5539589886879809, 0.9491419911499963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 71}], {
             RGBColor[
             0.6482814539995922, 0.7214952269023049, 0.9679496107647267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 83}], {
             RGBColor[
             0.38916228198081126`, 0.5114945416119245, 0.9460180543784913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 103}], {
             RGBColor[
             0.3850045259376993, 0.5078933023022759, 0.9457531258399835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 108}], {
             RGBColor[
             0.3965059868386308, 0.5178552896544295, 0.9464859887582483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 120}], {
             RGBColor[
             0.49591060473188847`, 0.6008847208403402, 0.9536681725336434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 143}], {
             RGBColor[
             0.5250435709581793, 0.6245361752480152, 0.9559616263525487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 196}], {
             RGBColor[
             0.3616835055171287, 0.4866932494532377, 0.9443037663378753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 231}], {
             RGBColor[
             0.3670635094292236, 0.49234797467679914`, 0.9446101496016666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 234}], {
             RGBColor[
             0.38209114426819646`, 0.5053698775309731, 0.945567487736205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 286}], {
             RGBColor[
             0.5758463873446392, 0.6644950889479655, 0.9608396409213635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 290}], {
             RGBColor[
             0.4152883060919923, 0.5341235905648768, 0.9476827815325197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 313}], {
             RGBColor[
             0.35412562406909687`, 0.4787494368539953, 0.9438733561702934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 320}], {
             RGBColor[
             0.5676684575710711, 0.6581064280542859, 0.9600245413086331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 331}], {
             RGBColor[
             0.43876768248625253`, 0.5544602462898143, 0.9491788666343646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 342}], {
             RGBColor[
             0.5144005472567488, 0.6158956891444403, 0.9551237685400916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 343}], {
             RGBColor[
             0.5738217336869491, 0.6629134141226403, 0.9606378423662292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 344}], {
             RGBColor[
             0.373035772157718, 0.49752656934511247`, 0.9449904874326764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 349}], {
             RGBColor[
             0.43541101780241814`, 0.5515528720515495, 0.9489649829288928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 147}], {
             RGBColor[
             0.2702371158648362, 0.4013667211696683, 0.9387009760172913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 211}], {
             RGBColor[
             0.25920679804656954`, 0.3897731577801271, 0.9380728157354339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 301}], {
             RGBColor[
             0.2562771522862687, 0.3866939143357813, 0.9379059767434073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 328}], {
             RGBColor[
             0.2825867919008145, 0.4142831089055032, 0.9394066116653366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 347}], {
             RGBColor[
             0.2678932418389194, 0.3989031609582332, 0.9385674958589661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 372}], {
             RGBColor[
             0.25360695200292194`, 0.3838873645375076, 0.9377539127874779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 380}], {
             RGBColor[
             0.2606135317686764, 0.39125172411413095`, 0.9381529271398318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 54}], {
             RGBColor[
             0.4530695590105145, 0.5668252864420751, 0.9500963936878091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 116}], {
             RGBColor[
             0.4351844866677396, 0.551334135708637, 0.9489567726932759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 121}], {
             RGBColor[
             0.5036718866822538, 0.607942553625398, 0.9540700424119916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.4322766112650586, 0.5488154801889021, 0.9487714854439504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 135}], {
             RGBColor[
             0.478712840814817, 0.5876796757980098, 0.9521051748933094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 158}], {
             RGBColor[
             0.47863176654490647`, 0.5876138560533424, 0.9520987924297972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 172}], {
             RGBColor[
             0.3777861468106212, 0.500941670871986, 0.945324186142565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 181}], {
             RGBColor[
             0.5107299622168331, 0.6136726173070488, 0.9546256799726562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 265}], {
             RGBColor[
             0.5230211648142513, 0.6236511692879999, 0.9555932884652836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 276}], {
             RGBColor[
             0.6098568885565028, 0.6922609454050347, 0.9637197242270632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 322}], {
             RGBColor[
             0.4812818793914586, 0.5897653370483966, 0.952307419020761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 328}], {
             RGBColor[
             0.38179240870061343`, 0.505088601337379, 0.9455546766979714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 362}], {
             RGBColor[
             0.4294033294821849, 0.5463267879239184, 0.948588402469489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 364}], {
             RGBColor[
             0.4018386991300539, 0.5224516905515073, 0.9468320085978967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 59}], {
             RGBColor[
             0.3534707906164537, 0.48058036569863427`, 0.9437438241095009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 136}], {
             RGBColor[
             0.4957527510770341, 0.5993305404010079, 0.9540497614266502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 194}], {
             RGBColor[
             0.38048922371828053`, 0.5039823744655038, 0.945465414775287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 246}], {
             RGBColor[
             0.408363122473439, 0.5281253445843351, 0.9472415149560449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 376}], {
             RGBColor[
             0.405658343586251, 0.5257826010583926, 0.9470691688370954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 377}], {
             RGBColor[
             0.39390138797963725`, 0.5155993170337143, 0.9463200260221095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 395}], {
             RGBColor[
             0.3229957435790246, 0.45088574591651165`, 0.9419227613726417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 396}], {
             RGBColor[
             0.3256114518738936, 0.4536350211799036, 0.9420717220904409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 117}], {
             RGBColor[
             0.36808130040816744`, 0.4932352549346425, 0.9446747928738624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 133}], {
             RGBColor[
             0.34195185422260005`, 0.4695411184843201, 0.9430487372114036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 174}], {
             RGBColor[
             0.5576254346896334, 0.6486129747855855, 0.95972095993169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 223}], {
             RGBColor[
             0.42035633884682855`, 0.5384929234825571, 0.9480113327439608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 260}], {
             RGBColor[
             0.5977997596730911, 0.6799974627988412, 0.9637251611956289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 267}], {
             RGBColor[
             0.4789222153161444, 0.5860393403630161, 0.9526218530734996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 272}], {
             RGBColor[
             0.5168312067307885, 0.6167442138565202, 0.9556549725324873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 291}], {
             RGBColor[
             0.5415685327056081, 0.6360692009186899, 0.9581205580022027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 346}], {
             RGBColor[
             0.36583874865596927`, 0.4912928693208167, 0.944531899459223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 384}], {
             RGBColor[
             0.5675366621289825, 0.6563557009893235, 0.9607088184571579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 68}], {
             RGBColor[
             0.28298429153365734`, 0.4147648110152172, 0.9394269088138741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 86}], {
             RGBColor[
             0.2948901577623302, 0.4272786312970708, 0.9401049302824465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 95}], {
             RGBColor[
             0.2855112454690256, 0.4174207998194225, 0.9395708151022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 101}], {
             RGBColor[
             0.27504289638646184`, 0.40641790120198085`, 0.9389746581084827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 129}], {
             RGBColor[
             0.26346421560774436`, 0.39424797357278596`, 0.9383152693672578]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 151}], {
             RGBColor[
             0.302539739143033, 0.43466335198279643`, 0.9405645627526612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 171}], {
             RGBColor[
             0.28122827358250124`, 0.41291912481058346`, 0.9393269061893516]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 244}], {
             RGBColor[
             0.27464006789181306`, 0.4059945029133032, 0.9389517176216438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 249}], {
             RGBColor[
             0.279406621010689, 0.4110044524581648, 0.9392231657702803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 253}], {
             RGBColor[
             0.31547986955209806`, 0.4458714425532633, 0.9413890964198188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 270}], {
             RGBColor[
             0.26941555401375766`, 0.4005032075741548, 0.9386541892852642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 308}], {
             RGBColor[
             0.27516616979901054`, 0.4065474693745552, 0.9389816783469607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 386}], {
             RGBColor[
             0.3143035505913172, 0.444852574192945, 0.9413141424158159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 397}], {
             RGBColor[
             0.26929675474869136`, 0.4003783420142617, 0.9386474238428664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 121}], {
             RGBColor[
             0.502593813473784, 0.607031307257596, 0.9539951244124792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 128}], {
             RGBColor[
             0.3891023193866603, 0.5114426050266787, 0.9460142336150148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 130}], {
             RGBColor[
             0.43119853805658864`, 0.5479042338211002, 0.9486965674444381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 158}], {
             RGBColor[
             0.4775536933364365, 0.5867026096855403, 0.9520238744302849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 181}], {
             RGBColor[
             0.5096518890083631, 0.6127613709392468, 0.9545507619731439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 265}], {
             RGBColor[
             0.5219430916057815, 0.622739922920198, 0.9555183704657713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 311}], {
             RGBColor[
             0.48568276233296276`, 0.5933021541073054, 0.9526638245194523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 322}], {
             RGBColor[
             0.48020380618298864`, 0.5888540906805946, 0.9522325010212487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 328}], {
             RGBColor[
             0.38071433549214345`, 0.504177354969577, 0.9454797586984591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 362}], {
             RGBColor[
             0.4283252562737149, 0.5454155415561164, 0.9485134844699766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 58}], {
             RGBColor[
             0.351171823063294, 0.4776705562573528, 0.9436309688854188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 60}], {
             RGBColor[
             0.38053049793671245`, 0.5040181241190069, 0.9454680447319882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 80}], {
             RGBColor[
             0.36897452576073053`, 0.49400892184022105`, 0.9447317084034796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 87}], {
             RGBColor[
             0.34683568506465234`, 0.47311300029375225`, 0.9433840322411374]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 122}], {
             RGBColor[
             0.4248101196568824, 0.5423709068945195, 0.9482895030730654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 146}], {
             RGBColor[
             0.4694319452875655, 0.5787932378238967, 0.951748052097088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 159}], {
             RGBColor[
             0.36748362390558187`, 0.49271757758819734`, 0.9446367094556223]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.4681407137086776, 0.5777449578588358, 0.9516464016172608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 192}], {
             RGBColor[
             0.3740111987150174, 0.498371434802681, 0.9450526407503718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 201}], {
             RGBColor[
             0.33997947002411655`, 0.46590668357700793`, 0.9429935809374401]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 210}], {
             RGBColor[
             0.3517281816196206, 0.4782553243752219, 0.9436626526821428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 228}], {
             RGBColor[
             0.38569491533937006`, 0.508491282902023, 0.9457971168421706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 385}], {
             RGBColor[
             0.4894768493024928, 0.5950665939158499, 0.9533260603680459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 71}], {
             RGBColor[
             0.6610275221983658, 0.7325352305400676, 0.968761778959447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 83}], {
             RGBColor[
             0.4019083501795848, 0.5225345452496872, 0.9468302225732115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 108}], {
             RGBColor[
             0.40925205503740436`, 0.5288952932921922, 0.9472981569529686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 120}], {
             RGBColor[
             0.5086566729306621, 0.6119247244781029, 0.9544803407283637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 143}], {
             RGBColor[
             0.5377896391569529, 0.6355761788857779, 0.956773794547269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 196}], {
             RGBColor[
             0.3744295737159023, 0.4977332530910004, 0.9451159345325955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 231}], {
             RGBColor[
             0.37980957762799716`, 0.5033879783145618, 0.9454223177963867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 237}], {
             RGBColor[
             0.5146770314008289, 0.6168123226982427, 0.9549542854004349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 254}], {
             RGBColor[
             0.46022321075082034`, 0.5726042579779009, 0.9506674811679487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 286}], {
             RGBColor[
             0.5885924555434128, 0.6755350925857282, 0.9616518091160838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 290}], {
             RGBColor[
             0.42803437429076585`, 0.5451635942026395, 0.9484949497272399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 320}], {
             RGBColor[
             0.5804145257698448, 0.6691464316920486, 0.9608367095033534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 331}], {
             RGBColor[
             0.4515137506850261, 0.565500249927577, 0.9499910348290849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 342}], {
             RGBColor[
             0.5271466154555224, 0.626935692782203, 0.9559359367348119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 343}], {
             RGBColor[
             0.5865678018857227, 0.673953417760403, 0.9614500105609494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 344}], {
             RGBColor[
             0.38578184035649155`, 0.5085665729828752, 0.9458026556273967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 349}], {
             RGBColor[
             0.44815708600119175`, 0.5625928756893122, 0.949777151123613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 92}], {
             RGBColor[
             0.2804356326225079, 0.4120860089052909, 0.9392817664592872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 114}], {
             RGBColor[
             0.3010426520782409, 0.43188396298315035`, 0.9405234581386476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 153}], {
             RGBColor[
             0.2953190920495516, 0.42692650296079127`, 0.9401587579547649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 188}], {
             RGBColor[
             0.270146670915944, 0.40127165779384166`, 0.9386958253112532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 195}], {
             RGBColor[
             0.25945106473985713`, 0.3900298975621752, 0.9380867263622563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 208}], {
             RGBColor[
             0.2531470707031978, 0.383404000133339, 0.9377277232277921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 258}], {
             RGBColor[
             0.26307034244570515`, 0.39383398790648194`, 0.9382928388733629]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 278}], {
             RGBColor[
             0.26281152350528336`, 0.39356195279003, 0.9382780995175941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 284}], {
             RGBColor[
             0.2586027566797, 0.38913827200511253`, 0.9380384164731898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 327}], {
             RGBColor[
             0.2958997785397042, 0.4274294644124098, 0.9401957587844365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 337}], {
             RGBColor[
             0.27897537779675124`, 0.41055118849791716`, 0.9391986071072138]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 354}], {
             RGBColor[
             0.27649042962059545`, 0.4079393504099632, 0.939057092984733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 392}], {
             RGBColor[
             0.2605783177897506, 0.3912147119895847, 0.9381509217558264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 60}], {
             RGBColor[
             0.3281696676840872, 0.4577472453898289, 0.942165291884663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 80}], {
             RGBColor[
             0.31661369550810525`, 0.44773804311104304`, 0.9414289555561544]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 87}], {
             RGBColor[
             0.29447485481202706`, 0.42684212156457424`, 0.9400812793938123]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 110}], {
             RGBColor[
             0.2771944683256158, 0.40867933972757164`, 0.939097186947452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 159}], {
             RGBColor[
             0.31512279365295653`, 0.44644669885901933`, 0.9413339566082971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 167}], {
             RGBColor[
             0.2911802301180382, 0.4233792621199214, 0.9398936553914501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 192}], {
             RGBColor[
             0.32165036846239214`, 0.45210055607350297`, 0.9417498879030466]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 201}], {
             RGBColor[
             0.2876186397714912, 0.4196358048478299, 0.939690828090115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 210}], {
             RGBColor[
             0.2993673513669953, 0.4319844456460439, 0.9403598998348177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 228}], {
             RGBColor[
             0.3333340850867448, 0.46222040417284493`, 0.9424943639948453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 236}], {
             RGBColor[
             0.27466659649964625`, 0.4060223861621468, 0.9389532283866143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 243}], {
             RGBColor[
             0.2935914724788655, 0.42591363072274663`, 0.9400309720767858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 263}], {
             RGBColor[
             0.28044730154374703`, 0.41209827368136553`, 0.9392824309870891]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 348}], {
             RGBColor[
             0.28088310771412667`, 0.4125563335981417, 0.9393072495037748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 351}], {
             RGBColor[
             0.27227774194596055`, 0.4035115485640963, 0.9388171866537756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 79}], {
             RGBColor[
             0.46241207497172554`, 0.5712067102742551, 0.9517169387007705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[
             0.3610366257463029, 0.4871335118181791, 0.9442259124337696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 237}], {
             RGBColor[
             0.4562186120487096, 0.5661785780610258, 0.9512293666120685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 246}], {
             RGBColor[
             0.38891052450146135`, 0.5112764819370106, 0.9460020126145274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 254}], {
             RGBColor[
             0.401764791398701, 0.521970513340684, 0.9469425623795822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 349}], {
             RGBColor[
             0.38969866664907243`, 0.5119591310520951, 0.9460522323352465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 373}], {
             RGBColor[
             0.2921699969184407, 0.4220829828981863, 0.9400355750383738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 395}], {
             RGBColor[
             0.303543145607047, 0.434036883269187, 0.9406832590311243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 87}], {
             RGBColor[
             0.32383352968544554`, 0.4531896894262284, 0.9419183552403817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 122}], {
             RGBColor[
             0.4018079642776756, 0.5224475960269956, 0.9468238260723096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 146}], {
             RGBColor[
             0.44642978990835863`, 0.5588699269563728, 0.9502823750963323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 159}], {
             RGBColor[
             0.344481468526375, 0.4727942667206735, 0.9431710324548666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 165}], {
             RGBColor[
             0.4451385583294708, 0.557821646991312, 0.950180724616505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 201}], {
             RGBColor[
             0.3169773146449097, 0.44598337270948407`, 0.9415279039366844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 210}], {
             RGBColor[
             0.3287260262404138, 0.45833201350769803`, 0.942196975681387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 263}], {
             RGBColor[
             0.3098059764171655, 0.4384458415430197, 0.9411195068336586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 66}], {
             RGBColor[
             0.9830643953423903, 0.9540141570597834, 0.4329439736998075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 98}], {
             RGBColor[
             0.985458002900472, 0.9620883573989745, 0.44224268706809605`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 107}], {
             RGBColor[
             0.9162817916828967, 0.6453128669663495, 0.3511545314597267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 131}], {
             RGBColor[
             0.9579060415796807, 0.8592435772757068, 0.3867967672286041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 215}], {
             RGBColor[
             0.9063170503481712, 0.5687194984901538, 0.341612283904028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 262}], {
             RGBColor[
             0.9659943820446136, 0.9709682059989204, 0.7529333373497976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 269}], {
             RGBColor[
             0.9932024163292561, 0.9878689808064407, 0.5015031511422814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 279}], {
             RGBColor[
             0.9694977718101772, 0.9052009249245101, 0.39612374546494056`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 297}], {
             RGBColor[
             0.9699924620425022, 0.9739499675150907, 0.7461656307796394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 298}], {
             RGBColor[
             0.9083880182689977, 0.925110369261773, 0.7500707788698681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 300}], {
             RGBColor[
             0.9416713408004723, 0.7907793854302443, 0.3735219082012329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 306}], {
             RGBColor[
             0.9818610097196364, 0.9499548547858537, 0.42826904779571534`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 307}], {
             RGBColor[
             0.9892929392100926, 0.9881701251038566, 0.7056981044009731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 314}], {
             RGBColor[
             0.9595789423265859, 0.965928622564677, 0.7549534149051582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 352}], {
             RGBColor[
             0.9937500196167237, 0.9890402488671484, 0.5611063895673631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 77}], {
             RGBColor[
             0.5042166815429454, 0.5861598549701907, 0.9585479112851663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 204}], {
             RGBColor[
             0.17899762953989296`, 0.30546823612459895`, 0.9335050222478098]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 345}], {
             RGBColor[
             0.19050782677282135`, 0.3175661832050619, 0.9341605109524143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 370}], {
             RGBColor[
             0.5051424414592518, 0.5868980307983699, 0.9586362110924191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 389}], {
             RGBColor[
             0.17907819285502502`, 0.305552913276812, 0.9335096102094239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 400}], {
             RGBColor[
             0.2843395833350594, 0.4087127954077557, 0.9397778424506229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 90}], {
             RGBColor[
             0.8321834271804781, 0.8209894828739578, 0.632414864387591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 138}], {
             RGBColor[
             0.8889519646070447, 0.5107811215593289, 0.22983700543826907`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 142}], {
             RGBColor[
             0.890072513149207, 0.5193941486818902, 0.23091004398772222`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 152}], {
             RGBColor[
             0.5710886094431091, 0.5911007265104762, 0.6136429928057057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 156}], {
             RGBColor[
             0.5722602959769347, 0.592332243346744, 0.6137097186204522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 202}], {
             RGBColor[
             0.9074503393274316, 0.6529677356997123, 0.2475510699614376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 214}], {
             RGBColor[
             0.9711670732550739, 0.9296487112649943, 0.6029350218130802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 217}], {
             RGBColor[
             0.8906933611547283, 0.5241662585096577, 0.23150456873895697`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 242}], {
             RGBColor[
             0.9384539463641798, 0.7929291511512139, 0.2733380495894395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 256}], {
             RGBColor[
             0.5919347091448884, 0.6130112990161062, 0.6148301473446811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 257}], {
             RGBColor[
             0.8905841112547781, 0.5233265159050291, 0.23139995091138454`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 261}], {
             RGBColor[
             0.5690047111878296, 0.5889104173173967, 0.6135243178829187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 264}], {
             RGBColor[
             0.5742960336344989, 0.5944719326980662, 0.6138256508684465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 268}], {
             RGBColor[
             0.8879400264016856, 0.5030029210787892, 0.2288679722699964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 317}], {
             RGBColor[
             0.9745940579826633, 0.9311354530743134, 0.5492576472683819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 381}], {
             RGBColor[
             0.975854040924288, 0.9316564884007599, 0.528376469194335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 82}], {
             RGBColor[
             0.38908871359710695`, 0.5114308203756144, 0.9460133666661356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 151}], {
             RGBColor[
             0.35739789501188024`, 0.48398182614394664`, 0.9439940557289754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 157}], {
             RGBColor[
             0.43410205704708005`, 0.5499866920911975, 0.9490010571312653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 171}], {
             RGBColor[
             0.3360864294513485, 0.46223759897173367`, 0.9427563991656658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 182}], {
             RGBColor[
             0.34352729206089855`, 0.4700584173523088, 0.9431801452835099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 253}], {
             RGBColor[
             0.3703380254209453, 0.4951899167144135, 0.9448185893961331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 105}], {
             RGBColor[
             0.46633814789011974`, 0.5766565671437895, 0.9514008797073982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 113}], {
             RGBColor[
             0.6559239156864949, 0.7291861264524664, 0.9676704388099608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 148}], {
             RGBColor[
             0.5696101053080527, 0.6614741699887192, 0.9592609405218679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 161}], {
             RGBColor[
             0.4733844161827434, 0.5827596905831183, 0.9518498616922337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 168}], {
             RGBColor[
             0.592741338058181, 0.6798274166038522, 0.9613729899467283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 170}], {
             RGBColor[
             0.4801509107444425, 0.5886204880785566, 0.952281016742329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 180}], {
             RGBColor[
             0.4408011041078431, 0.5545376633487222, 0.9497736818591127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 239}], {
             RGBColor[
             0.4199235526672635, 0.5364545776271384, 0.9484433827426128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 251}], {
             RGBColor[
             0.6688240146939028, 0.7392826292624911, 0.9689511985946974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 282}], {
             RGBColor[
             0.5810969797016021, 0.6707307553552915, 0.9602123891284602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 312}], {
             RGBColor[
             0.4891446804627151, 0.5961487131731942, 0.9529264075234798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 326}], {
             RGBColor[
             0.4273612108963405, 0.5428967033575929, 0.9489173037481067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 356}], {
             RGBColor[
             0.5168552955479615, 0.6186454388483807, 0.9551078886503179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[
             0.9751764945744315, 0.9279266287426179, 0.3580657982576656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 107}], {
             RGBColor[
             0.906000283356856, 0.6111511383099929, 0.2669776426492963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 131}], {
             RGBColor[
             0.9476245332536402, 0.8250818486193503, 0.3026198784181737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 215}], {
             RGBColor[
             0.8960355420221306, 0.5345577698337973, 0.25743539509359753`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 297}], {
             RGBColor[
             0.9597109537164616, 0.9397882388587341, 0.661988741969209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 307}], {
             RGBColor[
             0.9790114308840521, 0.9540083964475, 0.6215212155905427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 314}], {
             RGBColor[
             0.9492974340005453, 0.9317668939083206, 0.6707765260947278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 352}], {
             RGBColor[
             0.983468511290683, 0.9548785202107917, 0.47692950075693274`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 85}], {
             RGBColor[
             0.22712666696496037`, 0.35605490601556716`, 0.9362458997286371]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 127}], {
             RGBColor[
             0.21172079285419906`, 0.33986235553632177`, 0.9353685579889777]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 139}], {
             RGBColor[
             0.21205827028800195`, 0.34021706571655375`, 0.9353877768295796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 184}], {
             RGBColor[
             0.2153543932680198, 0.3436814999548199, 0.9355754861571146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 305}], {
             RGBColor[
             0.20792423756527648`, 0.33587193521215575`, 0.9351523497817738]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 325}], {
             RGBColor[
             0.21225679273606501`, 0.3404257253965182, 0.9353990823893092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 86}], {
             RGBColor[
             0.28863048877409425`, 0.42069932230449786`, 0.9397484513939167]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 95}], {
             RGBColor[
             0.2792515764807897, 0.4108414908268496, 0.9392143362136705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 129}], {
             RGBColor[
             0.25720454661950837`, 0.38766866458021304`, 0.9379587904787283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 151}], {
             RGBColor[
             0.29628007015479707`, 0.4280840429902235, 0.9402080838641316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 178}], {
             RGBColor[
             0.2603565331566741, 0.3909816022782634, 0.9381382914490737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 229}], {
             RGBColor[
             0.2618103919644219, 0.39250970006517877`, 0.9382210865573835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 249}], {
             RGBColor[
             0.2731469520224531, 0.4044251434655919, 0.9388666868817508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 308}], {
             RGBColor[
             0.26890650081077455`, 0.39996816038198235`, 0.938625199458431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 309}], {
             RGBColor[
             0.27375753584035556`, 0.40506690577145743`, 0.9389014587269024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 319}], {
             RGBColor[
             0.2591541477712746, 0.38971781900257185`, 0.9380698173801449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 334}], {
             RGBColor[
             0.2690618295669699, 0.40013142075315566`, 0.938634045201308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 371}], {
             RGBColor[
             0.27438511411724903`, 0.40572653033123346`, 0.9389371983813526]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 386}], {
             RGBColor[
             0.30804388160308127`, 0.43827326520037213`, 0.9409576635272863]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 74}], {
             RGBColor[
             0.6564460490256175, 0.7292165790501876, 0.9679963956135333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 97}], {
             RGBColor[
             0.46525153460871527`, 0.5764515941781216, 0.9511282282884884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 100}], {
             RGBColor[
             0.4324163535905058, 0.5480114107243323, 0.9490359995890186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 132}], {
             RGBColor[
             0.6437204915353074, 0.7192373735289359, 0.9667380893382732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 140}], {
             RGBColor[
             0.5800718085263902, 0.6695145386144623, 0.9603941834467046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 141}], {
             RGBColor[
             0.42414128450553, 0.540843961799992, 0.9485087195042803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 168}], {
             RGBColor[
             0.5791845558214077, 0.6688214100579597, 0.9603057503889199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 191}], {
             RGBColor[
             0.5835359920161374, 0.6722207850854224, 0.9607394608823273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 216}], {
             RGBColor[
             0.5736600979558795, 0.6645056615859741, 0.959755124057878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 219}], {
             RGBColor[
             0.4677032328653056, 0.5785751319820428, 0.9512844483334466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 220}], {
             RGBColor[
             0.4818265682663484, 0.5902075400149862, 0.9523502989242535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 350}], {
             RGBColor[
             0.4604806861717529, 0.5723193250518395, 0.9508242340447808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 357}], {
             RGBColor[
             0.5819543622257783, 0.6709852038723623, 0.9605818188059951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 394}], {
             RGBColor[
             0.42354328649608, 0.5403260059804602, 0.948470615599907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 75}], {
             RGBColor[
             0.2609941288153654, 0.3916517557414475, 0.9381746015785979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 103}], {
             RGBColor[
             0.3111881460301813, 0.44109703206764383`, 0.9411543384931023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 133}], {
             RGBColor[
             0.28753417910083867`, 0.4195470313278583, 0.9396860181798696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.2579170969731607, 0.3884176001802034, 0.937999369167245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 164}], {
             RGBColor[
             0.26017432145076, 0.3907900862224582, 0.9381279147619799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 227}], {
             RGBColor[
             0.25636607330828476`, 0.3867873759678386, 0.9379110406640643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 234}], {
             RGBColor[
             0.30827476436067847`, 0.438573607296341, 0.9409687003893238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 280}], {
             RGBColor[
             0.2584116720913199, 0.38893742998726233`, 0.9380275344885658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 346}], {
             RGBColor[
             0.3114210735342079, 0.4412987821643549, 0.9411691804276892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 79}], {
             RGBColor[
             0.730962985173496, 0.7893766931257962, 0.9742494771038676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 109}], {
             RGBColor[
             0.932608231427341, 0.9459491066410988, 0.8675350166916449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 120}], {
             RGBColor[
             0.7187491637803132, 0.7794609626924269, 0.9732879603430942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 143}], {
             RGBColor[
             0.7478821300066041, 0.8031124171001021, 0.9755814141619994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 237}], {
             RGBColor[
             0.7247695222504801, 0.7843485609125668, 0.9737619050151656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 286}], {
             RGBColor[
             0.798684946393064, 0.8430713308000524, 0.9804594287308144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 320}], {
             RGBColor[
             0.7905070166194959, 0.8366826699063725, 0.9796443291180839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 321}], {
             RGBColor[
             0.8444532383444727, 0.878825868324395, 0.985021184343525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 343}], {
             RGBColor[
             0.7966602927353739, 0.841489655974727, 0.98025763017568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 382}], {
             RGBColor[
             0.8849504676641144, 0.7666705508963009, 0.612411028914603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 119}], {
             RGBColor[
             0.2341124382405141, 0.36339739454965503`, 0.9366437290682574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 200}], {
             RGBColor[
             0.24919308184682543`, 0.37924810714791846`, 0.937502549411824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 288}], {
             RGBColor[
             0.2363762501862872, 0.36577680443863003`, 0.9367726498095597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 341}], {
             RGBColor[
             0.22465511090045148`, 0.353457143886063, 0.936105148267103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 355}], {
             RGBColor[
             0.2293238377834227, 0.358364271854447, 0.9363710253563257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 374}], {
             RGBColor[
             0.25191511783451104`, 0.3821091395580259, 0.9376575653344313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 375}], {
             RGBColor[
             0.24128592482540645`, 0.37093718377569584`, 0.9370522485170447]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 379}], {
             RGBColor[
             0.22434193474233927`, 0.3531279758873717, 0.9360873133482011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 393}], {
             RGBColor[
             0.22527325394479547`, 0.3541068514182011, 0.9361403505990177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 399}], {
             RGBColor[
             0.23130276285488832`, 0.3604442475756538, 0.9364837222115884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 85}], {
             RGBColor[
             0.24221172142071856`, 0.3719102546962633, 0.9371049712635544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 96}], {
             RGBColor[
             0.26501373249139615`, 0.3958766140625488, 0.9384035120614771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 110}], {
             RGBColor[
             0.24934696023893294`, 0.3794098430944771, 0.9375113125586119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 115}], {
             RGBColor[
             0.24086103809529086`, 0.3704906008829697, 0.9370280518463283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 184}], {
             RGBColor[
             0.230439447723778, 0.35953684863551605`, 0.9364345576920319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 188}], {
             RGBColor[
             0.2551009475473486, 0.3854576485794885, 0.9378389936235647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 195}], {
             RGBColor[
             0.2444053413712617, 0.37421588834782205`, 0.937229894674568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 203}], {
             RGBColor[
             0.2672567761777972, 0.39823419519414005`, 0.9385312500811318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 206}], {
             RGBColor[
             0.23733902327111464`, 0.366788739994123, 0.9368274783124455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 208}], {
             RGBColor[
             0.23810134733460236`, 0.3675899909189858, 0.9368708915401036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 258}], {
             RGBColor[
             0.2480246190771097, 0.3780199786921288, 0.9374360071856744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 284}], {
             RGBColor[
             0.24355703331110456`, 0.3733242627907594, 0.9371815847855014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 348}], {
             RGBColor[
             0.2530355996274438, 0.3832868369650472, 0.9377213751149346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 369}], {
             RGBColor[
             0.2502849628040927, 0.38039574326325765`, 0.9375647304170474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 392}], {
             RGBColor[
             0.24553259442115521`, 0.3754007027752315, 0.9372940900681379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 132}], {
             RGBColor[
             0.8119479189165777, 0.8530570556731545, 0.981880980170774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 140}], {
             RGBColor[
             0.7482992359076605, 0.8033342207586809, 0.9755370742792053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 191}], {
             RGBColor[
             0.7517634193974077, 0.8060404672296411, 0.9758823517148281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 198}], {
             RGBColor[
             0.8255815527613636, 0.8637603366303892, 0.9832258995793732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 216}], {
             RGBColor[
             0.7418875253371497, 0.7983253437301927, 0.9748980148903788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 219}], {
             RGBColor[
             0.6359306602465759, 0.7123948141262615, 0.9664273391659474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 220}], {
             RGBColor[
             0.6500539956476187, 0.724027222159205, 0.9674931897567542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 224}], {
             RGBColor[
             0.9001674923644503, 0.8962994775971298, 0.6715446357629462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 302}], {
             RGBColor[
             0.9059752552459537, 0.9158904255240137, 0.6941066978535942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 311}], {
             RGBColor[
             0.6720237576353845, 0.741863264667372, 0.9692227298983209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 323}], {
             RGBColor[
             0.8274418605794372, 0.8652436955878107, 0.9834033373997775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 340}], {
             RGBColor[
             0.9092258023331339, 0.9260683158029884, 0.7736525641500547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 357}], {
             RGBColor[
             0.7501817896070486, 0.8048048860165811, 0.9757247096384958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 89}], {
             RGBColor[
             0.23138047401831524`, 0.3605259269355878, 0.9364881477473821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 133}], {
             RGBColor[
             0.27071817278007254`, 0.4018723424883518, 0.9387283714969541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 145}], {
             RGBColor[
             0.24110109065239455`, 0.37074291134069687`, 0.9370417224843294]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.24457568603401603`, 0.37439493138885227`, 0.9372395955511095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 164}], {
             RGBColor[
             0.2433583151299939, 0.3731153973829517, 0.9371702680790643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 169}], {
             RGBColor[
             0.2324382955275915, 0.3616377644115946, 0.9365483891174288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 209}], {
             RGBColor[
             0.24810555583118551`, 0.37810504835234904`, 0.9374406164140838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 227}], {
             RGBColor[
             0.2395500669875186, 0.36911268712833206`, 0.9369533939811485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 280}], {
             RGBColor[
             0.24159566577055375`, 0.3712627411477558, 0.9370698878056503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 315}], {
             RGBColor[
             0.24372617436870905`, 0.3735020407664642, 0.9371912171185102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[
             0.8904092616611533, 0.5686904524165735, 0.22911954666558126`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 109}], {
             RGBColor[
             0.9205204428847344, 0.6768339136433675, 0.4700439928721189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 138}], {
             RGBColor[
             0.8331436561867612, 0.2557622418600043, 0.17937170863583543`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 144}], {
             RGBColor[
             0.8626912709570241, 0.4513693690163807, 0.2064327327986027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 207}], {
             RGBColor[
             0.8934001271128089, 0.5805482372855583, 0.23152606721261854`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 233}], {
             RGBColor[
             0.8322013343184957, 0.24851914305244047`, 0.17846934015058413`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 242}], {
             RGBColor[
             0.8826456379438963, 0.5379102714518893, 0.22287275278700588`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 257}], {
             RGBColor[
             0.8347758028344946, 0.2683076362057045, 0.1809346541089509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 317}], {
             RGBColor[
             0.9187857495623798, 0.676116573374989, 0.49879235046594833`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 358}], {
             RGBColor[
             0.9077605542707283, 0.6337524810989443, 0.26250704350549825`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 366}], {
             RGBColor[
             0.8741124408312237, 0.5032302339331254, 0.2159628369001264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 382}], {
             RGBColor[
             0.8728626791215081, 0.4975553578985697, 0.2149200050950769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 78}], {
             RGBColor[
             0.8356045267952863, 0.5947068735494174, 0.5856449487468838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 102}], {
             RGBColor[
             0.8243310697046711, 0.5080541422905515, 0.574849473505362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 111}], {
             RGBColor[
             0.8517216279012312, 0.6939386797204187, 0.6001134200588495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 160}], {
             RGBColor[
             0.8294213428991457, 0.5471802126352212, 0.5797239248650322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 166}], {
             RGBColor[
             0.827067103969575, 0.529084500588463, 0.5774695030073427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 185}], {
             RGBColor[
             0.8265277938578538, 0.5249391267425765, 0.5769530590352949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 370}], {
             RGBColor[
             0.8302908639224114, 0.8675154135193626, 0.9836750778819656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 389}], {
             RGBColor[
             0.5042266153181847, 0.5861702959978048, 0.9585484769989704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 400}], {
             RGBColor[
             0.6094880057982189, 0.6893301781287484, 0.9648167092401694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 102}], {
             RGBColor[
             0.8305704924938522, 0.23598377814878552`, 0.17690764417753302`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 144}], {
             RGBColor[
             0.8601410277678558, 0.4317670823407418, 0.2039906170405674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 160}], {
             RGBColor[
             0.835660765688327, 0.2751098484934552, 0.18178209553720334`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 185}], {
             RGBColor[
             0.832767216647035, 0.2528687626008105, 0.17901122970746597`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 207}], {
             RGBColor[
             0.8908498839236407, 0.5609459506099194, 0.22908395145458324`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 213}], {
             RGBColor[
             0.8764060316711535, 0.5036808895572449, 0.2174620888914447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 230}], {
             RGBColor[
             0.9053505911840212, 0.6146233921482407, 0.26060988945584945`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 247}], {
             RGBColor[
             0.874425744599943, 0.49582971121144337`, 0.21586870343063702`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 289}], {
             RGBColor[
             0.8697986288874946, 0.4756199934349731, 0.21204915614425965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 370}], {
             RGBColor[
             0.8365302867115927, 0.5954450493775967, 0.5857332485541368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 391}], {
             RGBColor[
             0.8311173699138001, 0.24018731764171894`, 0.1774313346124849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 400}], {
             RGBColor[
             0.6157274285874001, 0.4172598139869824, 0.5668748799123404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 109}], {
             RGBColor[
             0.79245120355282, 0.8352543310125031, 0.854215095221335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 120}], {
             RGBColor[
             0.5785921359057922, 0.6687661870638313, 0.9599680388727843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 136}], {
             RGBColor[
             0.6046940354323059, 0.6899568849766287, 0.9620228760179198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 237}], {
             RGBColor[
             0.5846124943759591, 0.6736537852839712, 0.9604419835448554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 246}], {
             RGBColor[
             0.5173044068287108, 0.618751689159956, 0.9552146295473145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 254}], {
             RGBColor[
             0.5301586737259505, 0.6294457205636295, 0.9561551793123693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 286}], {
             RGBColor[
             0.658527918518543, 0.7323765551714567, 0.9671395072605043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 320}], {
             RGBColor[
             0.6503499887449748, 0.725987894277777, 0.9663244076477739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 343}], {
             RGBColor[
             0.6565032648608529, 0.7307948803461315, 0.9669377087053699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 349}], {
             RGBColor[
             0.518092548976322, 0.6194343382750406, 0.9552648492680336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 87}], {
             RGBColor[
             0.3122775575094636, 0.4431804871474425, 0.9411820189118731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 96}], {
             RGBColor[
             0.31066394327551555`, 0.4414844762785116, 0.9410901259683782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 110}], {
             RGBColor[
             0.29499717102305234`, 0.4250177053104399, 0.9401979264655129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 146}], {
             RGBColor[
             0.4348738177323767, 0.548860724677587, 0.9495460387678236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 154}], {
             RGBColor[
             0.38228721374237734`, 0.5055397030547701, 0.9455799811097223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 159}], {
             RGBColor[
             0.3329254963503931, 0.4627850644418876, 0.9424346961263579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 167}], {
             RGBColor[
             0.30898293281547473`, 0.43971762770278966`, 0.9409943949095109]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 192}], {
             RGBColor[
             0.3394530711598287, 0.46843892165637124`, 0.9428506274211075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 201}], {
             RGBColor[
             0.30542134246892777`, 0.4359741704306982, 0.9407915676081757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 203}], {
             RGBColor[
             0.31290698696191654`, 0.4438420574101029, 0.9412178639880329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 228}], {
             RGBColor[
             0.35113678778418134`, 0.4785587697557132, 0.9435951035129062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 243}], {
             RGBColor[
             0.3113941751763021, 0.44225199630561496`, 0.9411317115948465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 332}], {
             RGBColor[
             0.4308190028061351, 0.5455688432531333, 0.9492268288835535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 348}], {
             RGBColor[
             0.2986858104115632, 0.42889469918101, 0.9404079890218355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 361}], {
             RGBColor[
             0.34502145958500996`, 0.47326197983492335`, 0.9432054402076274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 385}], {
             RGBColor[
             0.4549187217473041, 0.5651340807695402, 0.9511240470387816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 89}], {
             RGBColor[
             0.21914913629591037`, 0.3476700154777373, 0.9357915911587338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 163}], {
             RGBColor[
             0.23234434831161116`, 0.36153901993100174`, 0.9365430389624612]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 169}], {
             RGBColor[
             0.22020695780518662`, 0.3487818529537441, 0.9358518325287805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 209}], {
             RGBColor[
             0.23587421810878062`, 0.36524913689449845`, 0.9367440598254355]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 227}], {
             RGBColor[
             0.2273187292651137, 0.35625677567048153`, 0.9362568373925002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 240}], {
             RGBColor[
             0.22946097871463872`, 0.3585084156683923, 0.9363788353294766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 245}], {
             RGBColor[
             0.22480714766170556`, 0.3536169441618284, 0.9361138065357382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 248}], {
             RGBColor[
             0.21796166804011632`, 0.3464219110510618, 0.9357239665982682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 292}], {
             RGBColor[
             0.21536706305033604`, 0.3436948166993449, 0.9355762076824743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 304}], {
             RGBColor[
             0.21940694053557647`, 0.34794098407935925`, 0.9358062727287957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 315}], {
             RGBColor[
             0.23149483664630416`, 0.3606461293086136, 0.9364946605298619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 329}], {
             RGBColor[
             0.22742713619850993`, 0.35637071823087746`, 0.9362630110069835]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 353}], {
             RGBColor[
             0.2150475477536689, 0.34335898586410785`, 0.9355580117590097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 378}], {
             RGBColor[
             0.21412094136701804`, 0.3423850638014996, 0.9355052428960813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 151}], {
             RGBColor[
             0.34752633634939933`, 0.4754315781894705, 0.9433650487400788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 157}], {
             RGBColor[
             0.4242304983845992, 0.5414364441367214, 0.9483720501423687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 171}], {
             RGBColor[
             0.32621487078886763`, 0.45368735101725755`, 0.9421273921767691]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 182}], {
             RGBColor[
             0.3336557333984177, 0.4615081693978327, 0.9425511382946132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 253}], {
             RGBColor[
             0.3604664667584644, 0.48663966875993736`, 0.9441895824072364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 108}], {
             RGBColor[
             0.3602253738682746, 0.48643084621613597`, 0.9441742201814636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 120}], {
             RGBColor[
             0.45962999176153224`, 0.5694602774020465, 0.9513564039568587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 125}], {
             RGBColor[
             0.315433813888692, 0.4447906722692076, 0.9414242734794431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 179}], {
             RGBColor[
             0.3112624132414147, 0.4404062657068423, 0.9411867183836149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 196}], {
             RGBColor[
             0.32540289254677246`, 0.4552688060149441, 0.9419919977610904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 231}], {
             RGBColor[
             0.3307828964588674, 0.4609235312385056, 0.9422983810248817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 237}], {
             RGBColor[
             0.4656503502316991, 0.5743478756221865, 0.9518303486289299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 246}], {
             RGBColor[
             0.39834226268445083`, 0.5194457794981713, 0.946602994631389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 254}], {
             RGBColor[
             0.4111965295816905, 0.5301398109018447, 0.9475435443964437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 303}], {
             RGBColor[
             0.32124670467921895`, 0.4509003890486145, 0.9417553090105623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 313}], {
             RGBColor[
             0.31784501109874064`, 0.44732499341570175`, 0.9415615875935087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 344}], {
             RGBColor[
             0.33675515918736176`, 0.4661021259068189, 0.9426787188558917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 349}], {
             RGBColor[
             0.3991304048320619, 0.5201284286132558, 0.946653214352108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.44236640792617826`, 0.5377470693075241, 0.9524063925246276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 152}], {
             RGBColor[
             0.18127159018880934`, 0.30785831294404253`, 0.9336345209427424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 156}], {
             RGBColor[
             0.18244327672263497`, 0.3090898297803102, 0.9337012467574888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 175}], {
             RGBColor[
             0.1789295778879611, 0.3053967095236947, 0.9335011468069058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 204}], {
             RGBColor[
             0.17892700714738574`, 0.30539400751235557`, 0.933501000407033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 256}], {
             RGBColor[
             0.20211768989058865`, 0.32976888544967253`, 0.9348216754817178]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 261}], {
             RGBColor[
             0.17918769193352976`, 0.30566800375096304`, 0.9335158460199553]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 264}], {
             RGBColor[
             0.18447901438019912`, 0.31122951913163255`, 0.9338171790054831]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 317}], {
             RGBColor[
             0.5847770387283635, 0.6478930395078799, 0.8692491754054186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 333}], {
             RGBColor[
             0.18724373492288626`, 0.3141354157154036, 0.9339746257503516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 381}], {
             RGBColor[
             0.5860370216699882, 0.6484140748343261, 0.8483679973313716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 389}], {
             RGBColor[
             0.1790075704625178, 0.3054786846645686, 0.933505588368647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 96}], {
             RGBColor[
             0.2641094772748117, 0.3949261844968264, 0.9383520160646184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 110}], {
             RGBColor[
             0.2484427050223485, 0.37845941352875473`, 0.9374598165617531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 115}], {
             RGBColor[
             0.2399567828787064, 0.36954017131724737`, 0.9369765558494695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 139}], {
             RGBColor[
             0.2262390695271757, 0.3551219848315275, 0.9361953523676381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 167}], {
             RGBColor[
             0.2624284668147709, 0.39315933592110447`, 0.9382562850057511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 184}], {
             RGBColor[
             0.22953519250719354`, 0.35858641906979366`, 0.9363830616951732]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 188}], {
             RGBColor[
             0.25419669233076414`, 0.38450721901376617`, 0.937787497626706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 203}], {
             RGBColor[
             0.2663525209612127, 0.3972837656284177, 0.9384797540842731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 258}], {
             RGBColor[
             0.24712036386052527`, 0.3770695491264064, 0.9373845111888157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 284}], {
             RGBColor[
             0.24265277809452013`, 0.37237383322503703`, 0.9371300887886426]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 325}], {
             RGBColor[
             0.22643759197523877`, 0.355330644511492, 0.9362066579273677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 348}], {
             RGBColor[
             0.2521313444108594, 0.3823364073993248, 0.9376698791180758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 351}], {
             RGBColor[
             0.24352597864269326`, 0.37329162236527946`, 0.9371798162680766]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 369}], {
             RGBColor[
             0.24938070758750824`, 0.3794453136975352, 0.9375132344201885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 95}], {
             RGBColor[
             0.2911574427094625, 0.42335531110870317`, 0.9398923576822427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 151}], {
             RGBColor[
             0.30818593638346986`, 0.44059786327207706`, 0.9408861053327038]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[
             0.27226239938534696`, 0.40349542256011695`, 0.9388163129176459]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 229}], {
             RGBColor[
             0.27371625819309475`, 0.4050235203470323, 0.9388991080259558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 249}], {
             RGBColor[
             0.2850528182511259, 0.41693896374744543`, 0.939544708350323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 308}], {
             RGBColor[
             0.28081236703944734`, 0.4124819806638359, 0.9393032209270034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 309}], {
             RGBColor[
             0.28566340206902835`, 0.417580726053311, 0.9395794801954747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 334}], {
             RGBColor[
             0.28096769579564274`, 0.4126452410350092, 0.9393120666698803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 371}], {
             RGBColor[
             0.2862909803459218, 0.418240350613087, 0.9396152198499249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 386}], {
             RGBColor[
             0.31994974783175406`, 0.4507870854822257, 0.9416356849958585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 110}], {
             RGBColor[
             0.27285833032697415`, 0.4041217837639711, 0.9388502503031707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 134}], {
             RGBColor[
             0.26223279186396886`, 0.39295366914130303`, 0.9382451416067781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 159}], {
             RGBColor[
             0.3107866556543149, 0.4418891428954188, 0.9410870199640158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 167}], {
             RGBColor[
             0.28684409211939654`, 0.41882170615632086`, 0.9396467187471687]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 192}], {
             RGBColor[
             0.3173142304637505, 0.44754300010990244`, 0.9415029512587653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 201}], {
             RGBColor[
             0.2832825017728496, 0.4150782488842294, 0.9394438914458336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 210}], {
             RGBColor[
             0.2950312133683537, 0.42742688968244336`, 0.9401129631905363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 228}], {
             RGBColor[
             0.32899794708810315`, 0.4576628482092444, 0.9422474273505641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 236}], {
             RGBColor[
             0.2703304585010046, 0.4014648301985463, 0.938706291742333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 243}], {
             RGBColor[
             0.2892553344802239, 0.4213560747591461, 0.9397840354325044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 263}], {
             RGBColor[
             0.2761111635451054, 0.407540717717765, 0.9390354943428079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 348}], {
             RGBColor[
             0.27654696971548504`, 0.4079987776345412, 0.9390603128594934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 351}], {
             RGBColor[
             0.2679416039473189, 0.3989539926004958, 0.9385702500094941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[
             0.8934147061054667, 0.915612925432826, 0.8952711863200087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 132}], {
             RGBColor[
             0.8947680641910523, 0.9166701790551881, 0.8954060764061295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 140}], {
             RGBColor[
             0.8311193811821351, 0.8669473441407145, 0.8890621705145608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 168}], {
             RGBColor[
             0.8302321284771527, 0.8662542155842119, 0.8889737374567761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 282}], {
             RGBColor[
             0.8185877701205739, 0.8571575543356513, 0.887813136638508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 283}], {
             RGBColor[
             0.9496145330722283, 0.8334245259791293, 0.5278793972462171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 357}], {
             RGBColor[
             0.8330019348815232, 0.8684180093986145, 0.8892498058738514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 163}], {
             RGBColor[
             0.23177803755773202`, 0.36094379142249916`, 0.9365107884028094]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 164}], {
             RGBColor[
             0.2305606666537099, 0.3596642574165986, 0.9364414609307642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 169}], {
             RGBColor[
             0.2196406470513075, 0.3481866244452415, 0.9358195819691286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 209}], {
             RGBColor[
             0.23530790735490154`, 0.3646539083859959, 0.9367118092657838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 227}], {
             RGBColor[
             0.22675241851123462`, 0.35566154716197895`, 0.9362245868328485]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 245}], {
             RGBColor[
             0.22424083690782642`, 0.3530217156533258, 0.9360815559760864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.22879801729426974`, 0.3578116011814027, 0.9363410806573501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 292}], {
             RGBColor[
             0.21480075229645693`, 0.3430995881908423, 0.9355439571228226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 304}], {
             RGBColor[
             0.21884062978169738`, 0.3473457555708567, 0.9357740221691438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 315}], {
             RGBColor[
             0.23092852589242507`, 0.36005090080011104`, 0.93646240997021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 329}], {
             RGBColor[
             0.22686082544463082`, 0.3557754897223749, 0.9362307604473317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 353}], {
             RGBColor[
             0.21448123699978983`, 0.34276375735560527`, 0.9355257611993579]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 378}], {
             RGBColor[
             0.2135546306131389, 0.341789835292997, 0.9354729923364294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 138}], {
             RGBColor[
             0.7625743389841517, 0.45989176227570816`, 0.5687339252858672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 142}], {
             RGBColor[
             0.763694887526314, 0.46850478939826945`, 0.5698069638353204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 152}], {
             RGBColor[
             0.4447109838202162, 0.5402113672268555, 0.9525399126533038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 156}], {
             RGBColor[
             0.4458826703540418, 0.5414428840631231, 0.9526066384680504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 175}], {
             RGBColor[
             0.44236897151936794`, 0.5377497638065076, 0.9524065385174674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 202}], {
             RGBColor[
             0.7810727137045386, 0.6020783764160916, 0.5864479898090358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 242}], {
             RGBColor[
             0.8120763207412868, 0.7420397918675932, 0.6122349694370377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 256}], {
             RGBColor[
             0.46555708352199543`, 0.5621219397324855, 0.9537270671922793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[
             0.7642064856318851, 0.4724371566214084, 0.5702968707589827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 261}], {
             RGBColor[
             0.4426270855649366, 0.538021058033776, 0.9524212377305169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 264}], {
             RGBColor[
             0.44791840801160593`, 0.5435825734144455, 0.9527225707160447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 268}], {
             RGBColor[
             0.7615624007787926, 0.45211356179516854`, 0.5677648921175946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 317}], {
             RGBColor[
             0.8482164323597703, 0.8802460937906929, 0.8881545671159801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 333}], {
             RGBColor[
             0.4506831285542931, 0.5464884699982167, 0.9528800174609131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 381}], {
             RGBColor[
             0.849476415301395, 0.8807671291171392, 0.8672733890419332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 141}], {
             RGBColor[
             0.3113425799408942, 0.43982647528346147`, 0.9412155979078848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 150}], {
             RGBColor[
             0.2666109948635128, 0.3975554380879269, 0.9384944737906311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 186}], {
             RGBColor[
             0.2555444422624831, 0.38592378964428387`, 0.9378642499915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 189}], {
             RGBColor[
             0.28158397795101814`, 0.4132929926548542, 0.9393471630269211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 190}], {
             RGBColor[
             0.25186209923856306`, 0.38205341365211143`, 0.9376545460038261]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 226}], {
             RGBColor[
             0.25062761976227643`, 0.38075589745201466`, 0.9375842442239002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 241}], {
             RGBColor[
             0.2767915804260243, 0.40825587900053273`, 0.9390742430775896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 255}], {
             RGBColor[
             0.26154809523840944`, 0.39223400957556664`, 0.9382061491468703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 266}], {
             RGBColor[
             0.25880957199136756`, 0.38935564801052325`, 0.9380501942992334]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 273}], {
             RGBColor[
             0.26902930475390907`, 0.40009723511243644`, 0.9386321929613204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 365}], {
             RGBColor[
             0.259430965008946, 0.3900087714705911, 0.9380855817123159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 114}], {
             RGBColor[
             0.3082708613262549, 0.43948126919774927`, 0.9409350939621447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 153}], {
             RGBColor[
             0.30254730129756563`, 0.4345238091753902, 0.940570393778262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 161}], {
             RGBColor[
             0.35955024405905767`, 0.48389689314418627`, 0.9442025708853012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 188}], {
             RGBColor[
             0.27737488016395806`, 0.40886896400844064`, 0.9391074611347503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 195}], {
             RGBColor[
             0.26667927398787117`, 0.3976272037767742, 0.9384983621857534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 258}], {
             RGBColor[
             0.2702985516937192, 0.40143129412108086`, 0.93870447469686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 278}], {
             RGBColor[
             0.2700397327532974, 0.4011592590046289, 0.9386897353410912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 284}], {
             RGBColor[
             0.26583096592771405`, 0.3967355782197115, 0.9384500522966869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 327}], {
             RGBColor[
             0.3031279877877182, 0.4350267706270088, 0.9406073946079336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 337}], {
             RGBColor[
             0.2862035870447653, 0.41814849471251614`, 0.9396102429307109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 354}], {
             RGBColor[
             0.2837186388686095, 0.41553665662456213`, 0.9394687288082302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 392}], {
             RGBColor[
             0.26780652703776464`, 0.39881201820418366`, 0.9385625575793235]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 94}], {
             RGBColor[
             0.2526810398598759, 0.3829141721689455, 0.9377011834606958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 119}], {
             RGBColor[
             0.24286823945996167`, 0.3726002967811557, 0.9371423589946579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 128}], {
             RGBColor[
             0.2857256322546389, 0.41603117628641406`, 0.9396421556226617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 225}], {
             RGBColor[
             0.25117310830966183`, 0.38132924050128825`, 0.9376153089896959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 296}], {
             RGBColor[
             0.27337982614775685`, 0.40466990893635857`, 0.9388799487186803]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 301}], {
             RGBColor[
             0.25102800874557624`, 0.38117673165959054`, 0.9376070457841768]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 316}], {
             RGBColor[
             0.2497588091651779, 0.37984272242869066`, 0.9375347667456857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 324}], {
             RGBColor[
             0.26259788296436154`, 0.3933374030359285, 0.9382659330048415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 355}], {
             RGBColor[
             0.23807963900287032`, 0.36756717408594775`, 0.936869655282726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 380}], {
             RGBColor[
             0.25536438822798396`, 0.38573454143794017`, 0.9378539961806014]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 383}], {
             RGBColor[
             0.2627372188358315, 0.39348385387124796`, 0.9382738679765928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 390}], {
             RGBColor[
             0.2557686929307827, 0.3861594913149804, 0.9378770207353105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 119}], {
             RGBColor[
             0.25031116778183593`, 0.38042328635635736`, 0.9375662227517629]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 128}], {
             RGBColor[
             0.29316856057651314`, 0.42385416586161573`, 0.9400660193797667]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 177}], {
             RGBColor[
             0.29101623446385616`, 0.4219899291618881, 0.9399288750630955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 200}], {
             RGBColor[
             0.26539181138814727`, 0.3962739989546208, 0.9384250430953294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 225}], {
             RGBColor[
             0.2586160366315361, 0.3891522300764899, 0.9380391727468009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 288}], {
             RGBColor[
             0.25257497972760906`, 0.38280269624533236`, 0.9376951434930652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 296}], {
             RGBColor[
             0.2808227544696311, 0.4124928985115602, 0.9393038124757853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 316}], {
             RGBColor[
             0.25720173748705216`, 0.38766571200389227`, 0.9379586305027907]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 324}], {
             RGBColor[
             0.2700408112862358, 0.4011603926111301, 0.9386897967619465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 355}], {
             RGBColor[
             0.2455225673247446, 0.37539016366114936`, 0.937293519039831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 375}], {
             RGBColor[
             0.25748465436672835`, 0.3879630755823982, 0.9379747422005502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 380}], {
             RGBColor[
             0.2628073165498582, 0.39355753101314184`, 0.9382778599377064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 383}], {
             RGBColor[
             0.2701801471577058, 0.4013068434464496, 0.9386977317336979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 390}], {
             RGBColor[
             0.26321162125265696`, 0.393982480890182, 0.9383008844924156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 129}], {
             RGBColor[
             0.2597315005548766, 0.39032465338441835`, 0.9381026967670542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 151}], {
             RGBColor[
             0.2988070240901653, 0.4307400317944288, 0.9403519901524575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 178}], {
             RGBColor[
             0.2628834870920424, 0.39363759108246865`, 0.9382821977373995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 229}], {
             RGBColor[
             0.2643373458997902, 0.3951656888693841, 0.9383649928457094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 249}], {
             RGBColor[
             0.2756739059578213, 0.4070811322697972, 0.9390105931700766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 270}], {
             RGBColor[
             0.26568283896088996`, 0.3965798873857872, 0.9384416166850604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 308}], {
             RGBColor[
             0.2714334547461428, 0.4026241491861876, 0.9387691057467569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 309}], {
             RGBColor[
             0.2762844897757238, 0.4077228945756627, 0.9390453650152284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 334}], {
             RGBColor[
             0.27158878350233817`, 0.4027874095573609, 0.9387779514896339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 371}], {
             RGBColor[
             0.27691206805261726`, 0.40838251913543877`, 0.9390811046696785]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 386}], {
             RGBColor[
             0.3105708355384495, 0.4409292540045774, 0.9411015698156122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 110}], {
             RGBColor[
             0.2712447160930261, 0.4024257728950402, 0.9387583573596757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 114}], {
             RGBColor[
             0.3078946845637386, 0.4390858835693603, 0.940913671252023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 115}], {
             RGBColor[
             0.262758793949384, 0.3935065306835328, 0.9382750966473921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 153}], {
             RGBColor[
             0.3021711245350493, 0.4341284235470012, 0.9405489710681403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 154}], {
             RGBColor[
             0.3585347588123511, 0.48294777063937044`, 0.9441404120038852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 167}], {
             RGBColor[
             0.28523047788544853`, 0.41712569528738996`, 0.9395548258036737]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 188}], {
             RGBColor[
             0.2769987034014417, 0.4084735783800516, 0.9390860384246287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 192}], {
             RGBColor[
             0.3157006162298024, 0.44584698924097155`, 0.9414110583152703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 203}], {
             RGBColor[
             0.28915453203189034`, 0.42125012499470316`, 0.9397782948821958]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 228}], {
             RGBColor[
             0.3273843328541551, 0.4559668373403135, 0.9421555344070691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 243}], {
             RGBColor[
             0.2876417202462759, 0.4196600638902152, 0.9396921424890095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 258}], {
             RGBColor[
             0.26992237493120286`, 0.4010359084926919, 0.9386830519867384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 284}], {
             RGBColor[
             0.2654547891651977, 0.3963401925913225, 0.9384286295865651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 348}], {
             RGBColor[
             0.27493335548153697`, 0.4063027667656103, 0.9389684199159984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 361}], {
             RGBColor[
             0.32126900465498376`, 0.45067004741952366`, 0.9417658711017902]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 369}], {
             RGBColor[
             0.27218271865818583`, 0.40341167306382075`, 0.9388117752181111]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 100}], {
             RGBColor[
             0.4094492665548738, 0.5290661079964851, 0.9473107230964745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 105}], {
             RGBColor[
             0.42981427861771465`, 0.5467052578700499, 0.9486083636570456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 112}], {
             RGBColor[
             0.38560280932821134`, 0.5084115053045399, 0.9457912479285857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 132}], {
             RGBColor[
             0.6207534044996754, 0.7002920708010887, 0.965012812845729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 140}], {
             RGBColor[
             0.5571047214907582, 0.6505692358866151, 0.9586689069541604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 141}], {
             RGBColor[
             0.401174197469898, 0.5218986590721447, 0.9467834430117361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 168}], {
             RGBColor[
             0.5562174687857758, 0.6498761073301125, 0.9585804738963757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 180}], {
             RGBColor[
             0.40427723483543804`, 0.5245863540749827, 0.9469811658087601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 220}], {
             RGBColor[
             0.4588594812307164, 0.571262237287139, 0.9506250224317093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 282}], {
             RGBColor[
             0.5445731104291971, 0.6407794460815519, 0.9574198730781076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 350}], {
             RGBColor[
             0.437513599136121, 0.5533740223239922, 0.9490989575522366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 357}], {
             RGBColor[
             0.5589872751901463, 0.652039901144515, 0.958856542313451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 394}], {
             RGBColor[
             0.40057619946044803`, 0.521380703252613, 0.9467453391073628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 107}], {
             RGBColor[
             0.9083938909149378, 0.6192253386491839, 0.2762763560175848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 131}], {
             RGBColor[
             0.9500181408117219, 0.8331560489585412, 0.3119185917864623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 215}], {
             RGBColor[
             0.8984291495802124, 0.5426319701729883, 0.2667341084618861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 283}], {
             RGBColor[
             0.9432427006605664, 0.8062936865407971, 0.3064669136008217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 297}], {
             RGBColor[
             0.9621045612745434, 0.9478624391979251, 0.6712874553374975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 307}], {
             RGBColor[
             0.9814050384421338, 0.9620825967866911, 0.6308199289588313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 352}], {
             RGBColor[
             0.9858621188487648, 0.9629527205499828, 0.4862282141252213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 123}], {
             RGBColor[
             0.9762118677425246, 0.9817794304286422, 0.9251512823600752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 174}], {
             RGBColor[
             0.8533664925541351, 0.885559755956836, 0.9477463395066474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 187}], {
             RGBColor[
             0.9110307205751575, 0.9308010667922535, 0.953442401298972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 193}], {
             RGBColor[
             0.9002336063428361, 0.9221917409832586, 0.9524125629047955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[
             0.9440956875300477, 0.9571661739174645, 0.9565961673645738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 232}], {
             RGBColor[
             0.7518421224806613, 0.804458883314896, 0.9388506680687247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 235}], {
             RGBColor[
             0.8591106393434069, 0.8900471270857477, 0.9483188623764983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 275}], {
             RGBColor[
             0.9851141209349312, 0.987104803716967, 0.8512424005775606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 279}], {
             RGBColor[
             0.9618886205302903, 0.9027170726846294, 0.5985175369470697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 281}], {
             RGBColor[
             0.8050608246814849, 0.8476642232367373, 0.943040239252503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 306}], {
             RGBColor[
             0.9742518584397497, 0.947471002545973, 0.6306628392778444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 338}], {
             RGBColor[
             0.9862079875593082, 0.9866999578573392, 0.7708056942036536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 384}], {
             RGBColor[
             0.863277719993484, 0.893302482160574, 0.9487341980321153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 105}], {
             RGBColor[
             0.3969790975995051, 0.5182650744162607, 0.9465161349575758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 112}], {
             RGBColor[
             0.35276762831000186`, 0.47997132185075075`, 0.9436990192291159]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 141}], {
             RGBColor[
             0.3683390164516885, 0.49345847561835543`, 0.9446912143122663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 168}], {
             RGBColor[
             0.5233822877675662, 0.6214359238763232, 0.9564882451969059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 170}], {
             RGBColor[
             0.4107918604538279, 0.5302289953510277, 0.9473962719925066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 180}], {
             RGBColor[
             0.3714420538172285, 0.49614617062119337`, 0.9448889371092903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 220}], {
             RGBColor[
             0.42602430021250687`, 0.5428220538333498, 0.9485327937322395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 271}], {
             RGBColor[
             0.3417009842764249, 0.4702049097204598, 0.9430004912657755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 273}], {
             RGBColor[
             0.3260257412647034, 0.4537292354473304, 0.9421078093657018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 282}], {
             RGBColor[
             0.5117379294109875, 0.6123392626277626, 0.9553276443786378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 350}], {
             RGBColor[
             0.4046784181179114, 0.524933838870203, 0.9470067288527668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 394}], {
             RGBColor[
             0.3677410184422385, 0.49294051979882375`, 0.944653110407893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 151}], {
             RGBColor[
             0.2883386750076016, 0.41973713317698713`, 0.9397558331587401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 171}], {
             RGBColor[
             0.2670272094470698, 0.3979929060047742, 0.9385181765954305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 182}], {
             RGBColor[
             0.2744680720566198, 0.40581372438534935`, 0.9389419227132746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 244}], {
             RGBColor[
             0.2604390037563816, 0.39106828410749395`, 0.9381429880277227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 253}], {
             RGBColor[
             0.3012788054166666, 0.43094522374745403`, 0.9405803668258977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 270}], {
             RGBColor[
             0.2552144898783262, 0.38557698876834556`, 0.937845459691343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 308}], {
             RGBColor[
             0.26096510566357906`, 0.39162125056874597`, 0.9381729487530396]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 397}], {
             RGBColor[
             0.2550956906132599, 0.3854521232084524, 0.9378386942489454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 160}], {
             RGBColor[
             0.8243873085977117, 0.18845711723458924`, 0.17098662029568146`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 166}], {
             RGBColor[
             0.8220330696681408, 0.1703614051878311, 0.16873219843799186`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[
             0.8214937595564198, 0.16621603134194454`, 0.16821575446594406`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 213}], {
             RGBColor[
             0.8651325745805382, 0.41702815829837886`, 0.20666661364992278`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 224}], {
             RGBColor[
             0.8974792718626248, 0.5394468704448865, 0.26303107700793477`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 230}], {
             RGBColor[
             0.8940771340934058, 0.5279706608893748, 0.24981441421432754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 247}], {
             RGBColor[
             0.8631522875093278, 0.40917697995257735`, 0.2050732281891151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 250}], {
             RGBColor[
             0.9037621261807391, 0.5693653564012491, 0.505440590565607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 289}], {
             RGBColor[
             0.8585251717968794, 0.3889672621761071, 0.20125368090273776`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 302}], {
             RGBColor[
             0.9032870347441282, 0.5590378183717704, 0.2855931390985828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 340}], {
             RGBColor[
             0.9065375818313084, 0.569215708650745, 0.3651390053950433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 370}], {
             RGBColor[
             0.8252568296209774, 0.5087923181187306, 0.5749377733126149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 391}], {
             RGBColor[
             0.8198439128231849, 0.15353458638285297`, 0.16663585937096298`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 400}], {
             RGBColor[
             0.6044539714967849, 0.33060708272811645`, 0.5560794046708185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 108}], {
             RGBColor[
             0.3560676178251626, 0.48282960690648735`, 0.9439092916429558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 133}], {
             RGBColor[
             0.32091218999488846`, 0.4513176188145481, 0.9417081084114585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 143}], {
             RGBColor[
             0.48460520194471113`, 0.589510492500073, 0.9533849292372562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 223}], {
             RGBColor[
             0.3993166746191169, 0.5202694238127852, 0.9466707039440156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 231}], {
             RGBColor[
             0.3266251404157554, 0.4573222919288569, 0.942033452486374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 234}], {
             RGBColor[
             0.34165277525472826`, 0.4703441947830308, 0.9429907906209125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 290}], {
             RGBColor[
             0.3748499370785241, 0.4990979078169345, 0.9451060844172272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 313}], {
             RGBColor[
             0.31368725505562867`, 0.4437237541060531, 0.9412966590550009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 331}], {
             RGBColor[
             0.39832931347278433`, 0.519434563541872, 0.9466021695190721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 342}], {
             RGBColor[
             0.4739621782432806, 0.580870006396498, 0.9525470714247991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 346}], {
             RGBColor[
             0.3447990844282577, 0.4730693696510448, 0.9431912706592778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 109}], {
             RGBColor[
             0.9639852685830836, 0.8836832833010115, 0.5065761886025747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 138}], {
             RGBColor[
             0.8766084818851104, 0.4626116115176483, 0.21590390436629117`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 144}], {
             RGBColor[
             0.9061560966553733, 0.6582187386740248, 0.24296492852905843`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 205}], {
             RGBColor[
             0.9645712998383063, 0.8839256222853624, 0.49686413410326324`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 207}], {
             RGBColor[
             0.9368649528111581, 0.7873976069432023, 0.2680582629430743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 233}], {
             RGBColor[
             0.8756661600168449, 0.4553685127100845, 0.21500153588103987`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 358}], {
             RGBColor[
             0.9512253799690775, 0.8406018507565884, 0.299039239235954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 366}], {
             RGBColor[
             0.9175772665295729, 0.7100796035907695, 0.25249503263058215`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 382}], {
             RGBColor[
             0.9163275048198573, 0.7044047275562138, 0.25145220082553266`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 112}], {
             RGBColor[
             0.37313264037284266`, 0.49761047172431544`, 0.944996659789687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 113}], {
             RGBColor[
             0.6069298774587211, 0.6884337835985022, 0.9640833346207096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 148}], {
             RGBColor[
             0.520616067080279, 0.620721827134755, 0.9556738363326167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 155}], {
             RGBColor[
             0.3609448647521152, 0.4866656792120809, 0.9442342850410239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 168}], {
             RGBColor[
             0.5437472998304071, 0.6390750737498879, 0.957785885757477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 170}], {
             RGBColor[
             0.4311568725166687, 0.5478681452245924, 0.9486939125530778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 180}], {
             RGBColor[
             0.39180706588006936`, 0.513785320494758, 0.9461865776698615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 239}], {
             RGBColor[
             0.37092951443948974`, 0.4957022347731742, 0.9448562785533615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 271}], {
             RGBColor[
             0.36206599633926584`, 0.4878440595940245, 0.9442981318263466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 282}], {
             RGBColor[
             0.5321029414738284, 0.6299784125013272, 0.956625284939209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 326}], {
             RGBColor[
             0.37836717266856673`, 0.5021443605036287, 0.9453301995588554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 350}], {
             RGBColor[
             0.4250434301807523, 0.5425729887437677, 0.948304369413338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 394}], {
             RGBColor[
             0.38810603050507936`, 0.5105796696723884, 0.9459507509684641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.8938562482651202, 0.6317789737296462, 0.5786286100973383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 173}], {
             RGBColor[
             0.5874312139478495, 0.658182594689114, 0.9541358462016971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 197}], {
             RGBColor[
             0.9686231253627324, 0.9753622711647122, 0.9040752003743098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 204}], {
             RGBColor[
             0.563710908416439, 0.6332510496213667, 0.9527850098927306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 214}], {
             RGBColor[
             0.9661339552698273, 0.9742633398075717, 0.9422105594358144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 215}], {
             RGBColor[
             0.8838915069303948, 0.5551856052534505, 0.5690863625416396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 295}], {
             RGBColor[
             0.5954410834145789, 0.6666014753537031, 0.9545919964182874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 310}], {
             RGBColor[
             0.5655364837016175, 0.6351698449942476, 0.952888973704525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 345}], {
             RGBColor[
             0.5752211056493675, 0.6453489967018295, 0.953440498597335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 363}], {
             RGBColor[
             0.905503655257033, 0.714845634359743, 0.589529206598464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 131}], {
             RGBColor[
             0.8808419295941465, 0.5163805585259162, 0.22083043617809295`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 197}], {
             RGBColor[
             0.9139845567949747, 0.6460331456516251, 0.5106347906861869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 215}], {
             RGBColor[
             0.829252938362637, 0.22585647974036333`, 0.17564595285351675`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 297}], {
             RGBColor[
             0.892928350056968, 0.6310869487653001, 0.5801992997291281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 307}], {
             RGBColor[
             0.9122288272245584, 0.6453071063540661, 0.539731773350462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 352}], {
             RGBColor[
             0.9166859076311894, 0.6461772301173578, 0.39514005851685197`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 363}], {
             RGBColor[
             0.8508650866892753, 0.3855165088466559, 0.1960887969103411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 143}], {
             RGBColor[
             0.49610666284564264`, 0.5994724798522266, 0.954117792155521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 179}], {
             RGBColor[
             0.3186061180992342, 0.4467670137493473, 0.9416546527633719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 196}], {
             RGBColor[
             0.332746597404592, 0.4616295540574491, 0.9424599321408476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 231}], {
             RGBColor[
             0.3381266013166869, 0.4672842792810106, 0.9427663154046388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 234}], {
             RGBColor[
             0.3531542361556598, 0.4803061821351844, 0.9437236535391773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 290}], {
             RGBColor[
             0.3863513979794556, 0.5090598951690881, 0.945838947335492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 313}], {
             RGBColor[
             0.3251887159565602, 0.4536857414582067, 0.9420295219732657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 331}], {
             RGBColor[
             0.40983077437371584`, 0.5293965508940257, 0.9473350324373369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 342}], {
             RGBColor[
             0.48546363914421214`, 0.5908319937486516, 0.9532799343430639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 344}], {
             RGBColor[
             0.3440988640451813, 0.47246287394932385`, 0.9431466532356487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 136}], {
             RGBColor[
             0.8063392816861509, 0.8465292984919313, 0.8553084156056971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 205}], {
             RGBColor[
             0.9946824810618875, 0.9920690835121566, 0.737788580309801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 207}], {
             RGBColor[
             0.9669761340347394, 0.8955410681699965, 0.508982709149612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 233}], {
             RGBColor[
             0.9057773412404262, 0.5635119739368787, 0.4559259820875775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 286}], {
             RGBColor[
             0.8601731647723879, 0.8889489686867593, 0.8604250468482817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 320}], {
             RGBColor[
             0.8519952349988198, 0.8825603077930796, 0.8596099472355513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 343}], {
             RGBColor[
             0.8581485111146978, 0.8873672938614341, 0.8602232482931473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 358}], {
             RGBColor[
             0.9813365611926588, 0.9487453119833825, 0.5399636854424916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 366}], {
             RGBColor[
             0.9476884477531541, 0.8182230648175637, 0.4934194788371198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 382}], {
             RGBColor[
             0.9464386860434384, 0.8125481887830079, 0.4923766470320703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 115}], {
             RGBColor[
             0.2470920216969208, 0.3770397597154611, 0.9373828971445268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 134}], {
             RGBColor[
             0.24495240537755758`, 0.37479088730430044`, 0.9372610491604179]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 167}], {
             RGBColor[
             0.26956370563298526`, 0.40065892431931827`, 0.9386626263008084]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 192}], {
             RGBColor[
             0.30003384397733923`, 0.42938021827289985`, 0.940518858812405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 203}], {
             RGBColor[
             0.2734877597794271, 0.40478335402663146`, 0.9388860953793305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 243}], {
             RGBColor[
             0.2719749479938126, 0.4031932929221435, 0.9387999429861442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 348}], {
             RGBColor[
             0.25926658322907375`, 0.3898359957975386, 0.9380762204131332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 351}], {
             RGBColor[
             0.25066121746090764`, 0.3807912107634932, 0.9375861575631339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 369}], {
             RGBColor[
             0.2565159464057226, 0.38694490209574905`, 0.9379195757152459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 160}], {
             RGBColor[
             0.8517778667942718, 0.37434165466445646`, 0.19625056684916897`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 166}], {
             RGBColor[
             0.8494236278647009, 0.35624594261769826`, 0.19399614499147944`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.8488843177529799, 0.35210056877181173`, 0.19347970101943163`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 197}], {
             RGBColor[
             0.931414792844472, 0.7553582824181725, 0.5263607215030722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[
             0.631844529693345, 0.5164916201579837, 0.581343351224306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 155}], {
             RGBColor[
             0.31673339546261187`, 0.44837192664657105`, 0.9414171693125639]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 170}], {
             RGBColor[
             0.3869454032271654, 0.5095743926590826, 0.9458767968246178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 180}], {
             RGBColor[
             0.34759559659056605`, 0.4754915679292482, 0.9433694619414015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 183}], {
             RGBColor[
             0.2939274002864909, 0.42440137973285763`, 0.9401184016257302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 271}], {
             RGBColor[
             0.3178545270497625, 0.4495503070285146, 0.9414810160978866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 273}], {
             RGBColor[
             0.30217928403804095`, 0.4330746327553852, 0.940588334197813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 326}], {
             RGBColor[
             0.3341557033790634, 0.4638506079381187, 0.9425130838303954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 350}], {
             RGBColor[
             0.380831960891249, 0.5042792361782578, 0.945487253684878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 394}], {
             RGBColor[
             0.34389456121557604`, 0.47228591710687856`, 0.9431336352400042]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 148}], {
             RGBColor[
             0.7102018348766541, 0.7732513864434318, 0.9719433954351793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 168}], {
             RGBColor[
             0.7333330676267822, 0.7916046330585647, 0.9740554448600397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 170}], {
             RGBColor[
             0.6207426403130438, 0.7003977045332692, 0.9649634716556403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 251}], {
             RGBColor[
             0.8094157442625041, 0.8510598457172036, 0.9816336535080088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 282}], {
             RGBColor[
             0.7216887092702036, 0.7825079718100041, 0.9728948440417715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 153}], {
             RGBColor[
             0.32315432075329853`, 0.4543217632532496, 0.9418120854576224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 154}], {
             RGBColor[
             0.3795179550306004, 0.5031411103456188, 0.9454035263933673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 188}], {
             RGBColor[
             0.297981899619691, 0.4286669180863, 0.9403491528141107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 203}], {
             RGBColor[
             0.3101377282501396, 0.4414434647009515, 0.9410414092716778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 222}], {
             RGBColor[
             0.4669023906435984, 0.574712579304436, 0.9521089968254883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 258}], {
             RGBColor[
             0.29090557114945215`, 0.42122924819894025`, 0.9399461663762204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 312}], {
             RGBColor[
             0.3959175277947622, 0.5170838698121216, 0.9465208083959076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 327}], {
             RGBColor[
             0.32373500724345117`, 0.4548247247048681, 0.941849086287294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 356}], {
             RGBColor[
             0.4236281428800086, 0.5395805954873082, 0.9487022895227458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 361}], {
             RGBColor[
             0.342252200873233, 0.470863387125772, 0.9430289854912723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 369}], {
             RGBColor[
             0.29316591487643506`, 0.4236050127700691, 0.9400748896075932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 392}], {
             RGBColor[
             0.2884135464934976, 0.418609972282043, 0.9398042492586839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 184}], {
             RGBColor[
             0.22818450918176583`, 0.35716676525650004`, 0.936306142277947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 188}], {
             RGBColor[
             0.25284600900533644`, 0.38308756520047255`, 0.9377105782094798]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 195}], {
             RGBColor[
             0.2421504028292495, 0.3718458049688061, 0.937101479260483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 203}], {
             RGBColor[
             0.265001837635785, 0.3958641118151241, 0.9384028346670469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 206}], {
             RGBColor[
             0.23508408472910247`, 0.364418656615107, 0.9366990628983605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 208}], {
             RGBColor[
             0.2358464087925902, 0.36521990753996986`, 0.9367424761260187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 258}], {
             RGBColor[
             0.24576968053509757`, 0.37564989531311277`, 0.9373075917715895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 284}], {
             RGBColor[
             0.24130209476909242`, 0.37095417941174347`, 0.9370531693714164]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 325}], {
             RGBColor[
             0.22508690864981107`, 0.3539109906981984, 0.9361297385101415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 369}], {
             RGBColor[
             0.24803002426208054`, 0.37802565988424164`, 0.9374363150029623]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 392}], {
             RGBColor[
             0.24327765587914302`, 0.37303061939621557`, 0.937165674654053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 121}], {
             RGBColor[
             0.48470874113100904`, 0.5915401565241579, 0.9528555034179461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 130}], {
             RGBColor[
             0.4133134657138138, 0.5324130830876621, 0.947556946449905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 135}], {
             RGBColor[
             0.4597496952635722, 0.5712772786967698, 0.9508906358992639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 147}], {
             RGBColor[
             0.35047958711339033`, 0.47576981650030403`, 0.9436345020558807]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 172}], {
             RGBColor[
             0.3588230012593764, 0.484539273770746, 0.9441096471485195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 265}], {
             RGBColor[
             0.5040580192630065, 0.6072487721867599, 0.9543787494712381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 276}], {
             RGBColor[
             0.5908937430052579, 0.6758585483037947, 0.9625051852330178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 322}], {
             RGBColor[
             0.46231873384021377`, 0.5733629399471565, 0.9510928800267155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 328}], {
             RGBColor[
             0.3628292631493686, 0.48868620423613895`, 0.944340137703926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 362}], {
             RGBColor[
             0.41044018393094006`, 0.5299243908226783, 0.9473738634754435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 364}], {
             RGBColor[
             0.382875553578809, 0.5060492934502673, 0.9456174696038513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 387}], {
             RGBColor[
             0.35489504602512995`, 0.4804107437728069, 0.9438859559088182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 223}], {
             RGBColor[
             0.40179215387534173`, 0.5224135595233219, 0.9468284392932418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 346}], {
             RGBColor[
             0.3472745636844825, 0.4752135053615816, 0.9433490060085041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 371}], {
             RGBColor[
             0.31078136056287864`, 0.44021172480761495`, 0.9411479331302521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 126}], {
             RGBColor[
             0.20905168496127685`, 0.33705695390964574`, 0.935216556243067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 149}], {
             RGBColor[
             0.21314012851733694`, 0.34135416730935836`, 0.9354493870552745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[
             0.21593219336709382`, 0.3442888044935889, 0.9356083910179783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 212}], {
             RGBColor[
             0.208479398474888, 0.33645544452739207`, 0.9351839653742893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 259}], {
             RGBColor[
             0.20854115618205327`, 0.33652035579328765`, 0.9351874823843499]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 293}], {
             RGBColor[
             0.20864634306607288`, 0.33663091387762584`, 0.9351934726217848]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 299}], {
             RGBColor[
             0.21009516231391617`, 0.33815371476755507`, 0.9352759807346135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 336}], {
             RGBColor[
             0.20853409149877072`, 0.3365129303632308, 0.9351870800610882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 367}], {
             RGBColor[
             0.21268815866311674`, 0.340879118336029, 0.9354236480407061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 200}], {
             RGBColor[
             0.2555790109882331, 0.38596012356683096`, 0.9378662186292916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 225}], {
             RGBColor[
             0.24880323623162193`, 0.37883835468870003`, 0.9374803482807631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 288}], {
             RGBColor[
             0.2427621793276949, 0.37248882085754254`, 0.9371363190270272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 296}], {
             RGBColor[
             0.27100995406971695`, 0.4021790231237703, 0.9387449880097476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 316}], {
             RGBColor[
             0.24738893708713797`, 0.3773518366161024, 0.9373998060367528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 324}], {
             RGBColor[
             0.26022801088632164`, 0.3908465172233403, 0.9381309722959088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 355}], {
             RGBColor[
             0.2357097669248304, 0.3650762882733595, 0.9367346945737933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 375}], {
             RGBColor[
             0.24767185396681415`, 0.37764920019460835`, 0.9374159177345123]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 380}], {
             RGBColor[
             0.25299451614994406`, 0.383243655625352, 0.9377190354716685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 383}], {
             RGBColor[
             0.2603673467577916, 0.3909929680586598, 0.93813890726766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 390}], {
             RGBColor[
             0.2533988208527428, 0.3836686055023921, 0.9377420600263777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 136}], {
             RGBColor[
             0.5924802140391232, 0.6800411545432594, 0.9610613592571464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 237}], {
             RGBColor[
             0.5723986729827764, 0.663738054850602, 0.9594804667840822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 246}], {
             RGBColor[
             0.505090585435528, 0.6088359587265868, 0.9542531127865411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 254}], {
             RGBColor[
             0.5179448523327678, 0.6195299901302602, 0.955193662551596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 286}], {
             RGBColor[
             0.6463140971253603, 0.7224608247380875, 0.966177990499731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 320}], {
             RGBColor[
             0.6381361673517921, 0.7160721638444079, 0.9653628908870006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 343}], {
             RGBColor[
             0.64428944346767, 0.7208791499127623, 0.9659761919445966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 349}], {
             RGBColor[
             0.5058787275831391, 0.6095186078416714, 0.9543033325072602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 130}], {
             RGBColor[
             0.48180086572832803`, 0.5890215010044231, 0.9526702161686205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 158}], {
             RGBColor[
             0.5281560210081759, 0.6278198768688632, 0.9559975231544674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 181}], {
             RGBColor[
             0.5602542166801026, 0.6538786381225696, 0.9585244106973264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 250}], {
             RGBColor[
             0.7707116790518824, 0.8187741201767487, 0.9013688926659322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 265}], {
             RGBColor[
             0.5725454192775208, 0.6638571901035208, 0.9594920191899539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 322}], {
             RGBColor[
             0.5308061338547281, 0.6299713578639174, 0.9562061497454312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 362}], {
             RGBColor[
             0.4789275839454543, 0.5865328087394392, 0.9524871331941591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 146}], {
             RGBColor[
             0.49070941162852855`, 0.5972227097318854, 0.9531038334374095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.3887610902465449, 0.5111470494961861, 0.9459924907959437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 165}], {
             RGBColor[
             0.48941818004964077`, 0.5961744297668246, 0.9530021829575823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 210}], {
             RGBColor[
             0.3730056479605837, 0.4966847962832106, 0.9450184340224643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 228}], {
             RGBColor[
             0.40697238168033323`, 0.5269207548100117, 0.9471528981824919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 262}], {
             RGBColor[
             0.6923652232093209, 0.7572804525421046, 0.9691955483013721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 298}], {
             RGBColor[
             0.634758859433705, 0.711422615804957, 0.9663329898214426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 314}], {
             RGBColor[
             0.6859497834912932, 0.7522408691078613, 0.9712156258567326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 385}], {
             RGBColor[
             0.510754315643456, 0.6134960658238386, 0.9546818417083673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 174}], {
             RGBColor[
             0.8514507591880022, 0.8841310051490996, 0.9509891763922267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 187}], {
             RGBColor[
             0.9091149872090246, 0.929372315984517, 0.9566852381845512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 193}], {
             RGBColor[
             0.8983178729767032, 0.9207629901755221, 0.9556553997903747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 218}], {
             RGBColor[
             0.9421799541639146, 0.955737423109728, 0.959839004250153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 232}], {
             RGBColor[
             0.7499263891145284, 0.8030301325071595, 0.9420935049543039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 235}], {
             RGBColor[
             0.8571949059772741, 0.8886183762780113, 0.9515616992620775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 275}], {
             RGBColor[
             0.9831983875687983, 0.9856760529092304, 0.8544852374631398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 279}], {
             RGBColor[
             0.9599728871641575, 0.901288321876893, 0.6017603738326488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 281}], {
             RGBColor[
             0.8031450913153519, 0.8462354724290008, 0.9462830761380823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 306}], {
             RGBColor[
             0.9723361250736168, 0.9460422517382365, 0.6339056761634236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 338}], {
             RGBColor[
             0.9842922541931751, 0.9852712070496027, 0.7740485310892328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.22241368079166546`, 0.3511012587268517, 0.9359775021383063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 199}], {
             RGBColor[
             0.224537016117427, 0.35333301878146245`, 0.9360984229439153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 238}], {
             RGBColor[
             0.22624718755874168`, 0.35513051739741625`, 0.9361958146775262]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 252}], {
             RGBColor[
             0.22380219645594157`, 0.3525606767269839, 0.936056576051262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 277}], {
             RGBColor[
             0.24054204876353127`, 0.3701553228701986, 0.9370098858757869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 293}], {
             RGBColor[
             0.21725116581640602`, 0.3456751281654994, 0.9356835045477219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 330}], {
             RGBColor[
             0.22402160898279397`, 0.3527912932042634, 0.9360690712700745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 179}], {
             RGBColor[
             0.2738145581196516, 0.4051268398024189, 0.9389047060613515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 196}], {
             RGBColor[
             0.2879550374250095, 0.4199893801105207, 0.9397099854388271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 303}], {
             RGBColor[
             0.28379884955745593`, 0.41562096314419106`, 0.9394732966882988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 313}], {
             RGBColor[
             0.2803971559769777, 0.4120455675112783, 0.9392795752712453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 344}], {
             RGBColor[
             0.2993073040655987, 0.4308227000023955, 0.9403967065336283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 149}], {
             RGBColor[
             0.21613019133913786`, 0.3444969129160037, 0.9356196667095744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 199}], {
             RGBColor[
             0.21892225618889471`, 0.3474315501002342, 0.9357786706722784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 212}], {
             RGBColor[
             0.21146946129668887`, 0.3395981901340374, 0.9353542450285892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 238}], {
             RGBColor[
             0.2206324276302094, 0.349229048716188, 0.9358760624058893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 259}], {
             RGBColor[
             0.2115312190038542, 0.33966310139993294`, 0.93535776203865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 274}], {
             RGBColor[
             0.22138486041548355`, 0.35001990328050514`, 0.9359189123398861]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 299}], {
             RGBColor[
             0.21308522513571704`, 0.34129646037420036`, 0.9354462603889135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 318}], {
             RGBColor[
             0.2179296081019373, 0.3463882140233181, 0.9357221408322174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 336}], {
             RGBColor[
             0.21152415432057162`, 0.33965567596987617`, 0.9353573597153882]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 367}], {
             RGBColor[
             0.21567822148491766`, 0.34402186394267437`, 0.935593927695006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 139}], {
             RGBColor[
             0.2108331954164144, 0.3389294343522821, 0.9353180106279786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 184}], {
             RGBColor[
             0.21412931839643223`, 0.34239386859054827`, 0.9355057199555137]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 305}], {
             RGBColor[
             0.20669916269368893`, 0.33458430384788407`, 0.9350825835801727]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 325}], {
             RGBColor[
             0.21103171786447747`, 0.3391380940322466, 0.9353293161877081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 177}], {
             RGBColor[
             0.32406082685861914`, 0.45510693327935664`, 0.9418698472250615]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 225}], {
             RGBColor[
             0.2916606290262991, 0.42226923419395845`, 0.939980144908767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 296}], {
             RGBColor[
             0.3138673468643941, 0.4456099026290287, 0.9412447846377514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 311}], {
             RGBColor[
             0.4227935959175786, 0.5388307190597109, 0.9486565824461703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 316}], {
             RGBColor[
             0.29024632988181515`, 0.4207827161213608, 0.9398996026647567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 324}], {
             RGBColor[
             0.3030854036809988, 0.43427739672859866`, 0.9406307689239126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 380}], {
             RGBColor[
             0.2958519089446212, 0.4266745351306104, 0.9402188320996724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 383}], {
             RGBColor[
             0.30322473955246876`, 0.43442384756391816`, 0.9406387038956638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 390}], {
             RGBColor[
             0.29625621364741994`, 0.42709948500765055`, 0.9402418566543815]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 178}], {
             RGBColor[
             0.24083645723076108`, 0.3704647648358321, 0.9370266520024574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 229}], {
             RGBColor[
             0.24229031603850887`, 0.3719928626227475, 0.9371094471107673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 249}], {
             RGBColor[
             0.25362687609654, 0.3839083060231606, 0.9377550474351345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 270}], {
             RGBColor[
             0.24363580909960866`, 0.3734070611391507, 0.9371860709501183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 308}], {
             RGBColor[
             0.2493864248848615, 0.3794513229395511, 0.9375135600118147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 309}], {
             RGBColor[
             0.25423745991444247`, 0.38455006832902616`, 0.9377898192802863]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 397}], {
             RGBColor[
             0.24351700983454236`, 0.3732821955792575, 0.9371793055077206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 135}], {
             RGBColor[
             0.4568418198608912, 0.568758623177035, 0.9507053486499384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 147}], {
             RGBColor[
             0.34757171171070933`, 0.4732511609805692, 0.9434492148065551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 158}], {
             RGBColor[
             0.4567607455909806, 0.5686928034323673, 0.9506989661864262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 172}], {
             RGBColor[
             0.3559151258566954, 0.4820206182510111, 0.9439243598991939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 181}], {
             RGBColor[
             0.48885894126290724`, 0.5947515646860737, 0.9532258537292853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 265}], {
             RGBColor[
             0.5011501438603255, 0.6047301166670249, 0.9541934622219126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 322}], {
             RGBColor[
             0.45941085843753277`, 0.5708442844274215, 0.95090759277739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 328}], {
             RGBColor[
             0.3599213877466876, 0.48616754871640405`, 0.9441548504546003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 347}], {
             RGBColor[
             0.34522783768479254`, 0.47078760076913406`, 0.9433157346482299]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 362}], {
             RGBColor[
             0.40753230852825906`, 0.5274057353029433, 0.9471885762261179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 364}], {
             RGBColor[
             0.379967678176128, 0.5035306379305324, 0.9454321823545258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 387}], {
             RGBColor[
             0.35198717062244894`, 0.47789208825307206`, 0.9437006686594926]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 215}], {
             RGBColor[
             0.8708771882594211, 0.43978719004972067`, 0.21128818862239418`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 217}], {
             RGBColor[
             0.8726459244985081, 0.4533824718485052, 0.21298193244244573`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 262}], {
             RGBColor[
             0.9305545199558635, 0.8420358975584873, 0.6226092420681639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 269}], {
             RGBColor[
             0.9577625542405059, 0.8589366723660075, 0.3711790558606476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 279}], {
             RGBColor[
             0.934057909721427, 0.776268616484077, 0.26579965018330676`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 297}], {
             RGBColor[
             0.9345525999537521, 0.8450176590746574, 0.6158415354980056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 300}], {
             RGBColor[
             0.9062314787117222, 0.661847076989811, 0.24319781291959908`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 306}], {
             RGBColor[
             0.9464211476308863, 0.8210225463454206, 0.2979449525140816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 307}], {
             RGBColor[
             0.9538530771213425, 0.8592378166634234, 0.5753740091193393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 314}], {
             RGBColor[
             0.9241390802378358, 0.8369963141242439, 0.6246293196235244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 352}], {
             RGBColor[
             0.9583101575279735, 0.8601079404267151, 0.43078229428572945`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 363}], {
             RGBColor[
             0.8924893365860593, 0.5994472191560132, 0.23173103267921852`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 140}], {
             RGBColor[
             0.7355736784173503, 0.7933550152374292, 0.9742787680039452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 191}], {
             RGBColor[
             0.7390378619070974, 0.7960612617083893, 0.9746240454395679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 198}], {
             RGBColor[
             0.8128559952710535, 0.8537811311091374, 0.9819675933041132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 216}], {
             RGBColor[
             0.7291619678468395, 0.7883461382089411, 0.9736397086151186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 219}], {
             RGBColor[
             0.6232051027562657, 0.7024156086050097, 0.9651690328906872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 220}], {
             RGBColor[
             0.6373284381573086, 0.7140480166379533, 0.9662348834814941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 302}], {
             RGBColor[
             0.8932496977556434, 0.905911220002762, 0.6928483915783341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 323}], {
             RGBColor[
             0.8147163030891271, 0.8552644900665589, 0.9821450311245175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 357}], {
             RGBColor[
             0.7374562321167385, 0.7948256804953293, 0.9744664033632358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 145}], {
             RGBColor[
             0.26764114093786784`, 0.3986381869271076, 0.9385531390856012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 164}], {
             RGBColor[
             0.2698983654154672, 0.40101067296936244`, 0.9386816846803361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 223}], {
             RGBColor[
             0.3756627076897743, 0.49871942307299955`, 0.945202383630783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 234}], {
             RGBColor[
             0.31799880832538563`, 0.4487941940432452, 0.9415224703076799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 280}], {
             RGBColor[
             0.26813571605602704`, 0.3991580167341666, 0.938581304406922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 346}], {
             RGBColor[
             0.32114511749891506`, 0.4515193689112592, 0.9417229503460453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 167}], {
             RGBColor[
             0.25893816716997997`, 0.3894908096966502, 0.9380575176044159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 201}], {
             RGBColor[
             0.255376576823433, 0.3857473524245587, 0.9378546903030808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 236}], {
             RGBColor[
             0.24242453355158805`, 0.3721339337388756, 0.9371170905995801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 243}], {
             RGBColor[
             0.2613494095308073, 0.3920251782994754, 0.9381948342897516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 263}], {
             RGBColor[
             0.24820523859568883`, 0.3782098212580943, 0.9374462932000549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 348}], {
             RGBColor[
             0.24864104476606846`, 0.3786678811748705, 0.9374711117167406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 351}], {
             RGBColor[
             0.24003567899790235`, 0.3696230961408251, 0.9369810488667414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 221}], {
             RGBColor[
             0.7125684826637311, 0.7740760557086418, 0.9732239792621271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 276}], {
             RGBColor[
             0.6344220971523353, 0.7122040883931675, 0.9656535874330512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 322}], {
             RGBColor[
             0.5058470879872912, 0.6097084800365293, 0.954241282226749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 364}], {
             RGBColor[
             0.42640390772588643`, 0.5423948335396401, 0.9487658718038847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 376}], {
             RGBColor[
             0.47083567399736015`, 0.5808793962784845, 0.9515970246612349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 377}], {
             RGBColor[
             0.4590787183907463, 0.5706961122538062, 0.9508478818462491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 194}], {
             RGBColor[
             0.5033185862068833, 0.6058836865205527, 0.954531849750919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 237}], {
             RGBColor[
             0.59850057250929, 0.6849287527633994, 0.9615353039292178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 246}], {
             RGBColor[
             0.5311924849620417, 0.6300266566393842, 0.9563079499316767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 254}], {
             RGBColor[
             0.5440467518592814, 0.6407206880430576, 0.9572484996967315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 286}], {
             RGBColor[
             0.6724159966518739, 0.7436515226508849, 0.9682328276448666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 320}], {
             RGBColor[
             0.6642380668783059, 0.7372628617572051, 0.9674177280321361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 343}], {
             RGBColor[
             0.6703913429941837, 0.7420698478255596, 0.9680310290897323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 349}], {
             RGBColor[
             0.5319806271096528, 0.6307093057544687, 0.9563581696523957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 376}], {
             RGBColor[
             0.5284877060748537, 0.6276839131134415, 0.9561356038127271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 199}], {
             RGBColor[
             0.22367942926895015`, 0.3524316406295666, 0.9360495846415806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 238}], {
             RGBColor[
             0.22538960071026484`, 0.3542291392455204, 0.9361469763751915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 252}], {
             RGBColor[
             0.22294460960746476`, 0.35165929857508804`, 0.9360077377489273]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 277}], {
             RGBColor[
             0.23968446191505444`, 0.36925394471830275`, 0.9369610475734522]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 285}], {
             RGBColor[
             0.23013560035880143`, 0.35921748578989005`, 0.9364172540340985]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 293}], {
             RGBColor[
             0.2163935789679292, 0.34477375001360355`, 0.9356346662453872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 330}], {
             RGBColor[
             0.22316402213431713`, 0.35188991505236755`, 0.9360202329677398]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 144}], {
             RGBColor[
             0.8488904911809813, 0.34529052811745564`, 0.1932170904993126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 233}], {
             RGBColor[
             0.8184005545424529, 0.14244030215351539`, 0.165253697851294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 242}], {
             RGBColor[
             0.8688448581678534, 0.4318314305529642, 0.2096571104877158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 256}], {
             RGBColor[
             0.522325620948562, 0.25191357841785655`, 0.5511492082429574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 257}], {
             RGBColor[
             0.8209750230584517, 0.16222879530677942`, 0.1677190118096608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 317}], {
             RGBColor[
             0.9049849697863369, 0.5700377324760639, 0.4855767081666582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 366}], {
             RGBColor[
             0.8603116610551809, 0.39715139303420033`, 0.20274719460083632`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 381}], {
             RGBColor[
             0.9062449527279615, 0.5705587678025101, 0.4646955300926113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 382}], {
             RGBColor[
             0.8590618993454652, 0.3914765169996446, 0.2017043627957868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 184}], {
             RGBColor[
             0.21446679583023515`, 0.34274857877078024`, 0.9355249387961155]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 305}], {
             RGBColor[
             0.20703664012749182`, 0.3349390140281161, 0.9351018024207747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 325}], {
             RGBColor[
             0.21136919529828035`, 0.33949280421247857`, 0.9353485350283102]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 141}], {
             RGBColor[
             0.5159944713875729, 0.6149616035084853, 0.9560493981699523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 168}], {
             RGBColor[
             0.6710377427034506, 0.7429390517664531, 0.9678464290545918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 191}], {
             RGBColor[
             0.6753891788981803, 0.7463384267939157, 0.9682801395479993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 216}], {
             RGBColor[
             0.6655132848379224, 0.7386233032944675, 0.96729580272355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 219}], {
             RGBColor[
             0.5595564197473485, 0.6526927736905361, 0.9588251269991186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 220}], {
             RGBColor[
             0.5736797551483913, 0.6643251817234797, 0.9598909775899255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 350}], {
             RGBColor[
             0.5523338730537959, 0.6464369667603329, 0.9583649127104528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 357}], {
             RGBColor[
             0.6738075491078213, 0.7451028455808557, 0.9681224974716671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 150}], {
             RGBColor[
             0.3153323622893313, 0.4440199894984804, 0.9414428101102743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 189}], {
             RGBColor[
             0.33030534537683665`, 0.4597575440654077, 0.9422954993465642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 219}], {
             RGBColor[
             0.4036258957264883, 0.5240221968760659, 0.9469396630566943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 220}], {
             RGBColor[
             0.4177492311275311, 0.5356546049090093, 0.9480055136475012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 273}], {
             RGBColor[
             0.31775067217972763`, 0.44656178652298995`, 0.9415805292809634]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 339}], {
             RGBColor[
             0.36291222472736206`, 0.48875806138522676`, 0.9443454239423157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 350}], {
             RGBColor[
             0.3964033490329356, 0.5177663899458625, 0.9464794487680284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 357}], {
             RGBColor[
             0.5178770250869611, 0.6164322687663853, 0.9562370335292427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 394}], {
             RGBColor[
             0.3594659493572627, 0.4857730708744833, 0.9441258303231546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 202}], {
             RGBColor[
             0.8389617996732674, 0.300483042224024, 0.18494316940916705`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 214}], {
             RGBColor[
             0.9026785336009098, 0.577164017789306, 0.5403271212608096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 217}], {
             RGBColor[
             0.8222048215005642, 0.17168156503396934`, 0.16889666818668636`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 257}], {
             RGBColor[
             0.822095571600614, 0.17084182242934073`, 0.16879205035911396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 268}], {
             RGBColor[
             0.8194514867475214, 0.1505182276031009, 0.16626007171772583`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 275}], {
             RGBColor[
             0.906842307128124, 0.5789554407018784, 0.47443924955803846`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 279}], {
             RGBColor[
             0.8836168067234831, 0.49456770966954106`, 0.2217143859275474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 300}], {
             RGBColor[
             0.8557903757137784, 0.38014617017527513`, 0.1991125486638397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 306}], {
             RGBColor[
             0.8959800446329425, 0.5393216395308846, 0.25385968825832217`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 338}], {
             RGBColor[
             0.9079361737525008, 0.5785505948422507, 0.3940025431841314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 363}], {
             RGBColor[
             0.8420482335881154, 0.3177463123414773, 0.18764576842345915`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 381}], {
             RGBColor[
             0.9073655012701238, 0.5791717949250715, 0.46576856864206445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 223}], {
             RGBColor[
             0.5393557196395969, 0.6369122967585245, 0.9568792044565808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 234}], {
             RGBColor[
             0.4816918202752083, 0.5869870677287701, 0.9531992911334777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 260}], {
             RGBColor[
             0.7167991404658595, 0.7784168360748085, 0.9725930329082488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 267}], {
             RGBColor[
             0.5979215961089128, 0.6844587136389835, 0.9614897247861196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 272}], {
             RGBColor[
             0.635830587523557, 0.7151635871324875, 0.9645228442451073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 290}], {
             RGBColor[
             0.5148889820990041, 0.6157407807626738, 0.9553145849297924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 291}], {
             RGBColor[
             0.6605679134983766, 0.7344885741946573, 0.9669884297148228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 321}], {
             RGBColor[
             0.7212153553030598, 0.7818668166701053, 0.973033199931347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 331}], {
             RGBColor[
             0.5383683584932644, 0.6360774364876114, 0.9568106700316372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 342}], {
             RGBColor[
             0.6140012232637606, 0.6975128793422373, 0.9627555719373643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 398}], {
             RGBColor[
             0.7820348247548993, 0.8302487551810782, 0.97550730112162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 207}], {
             RGBColor[
             0.9091469621070289, 0.6700765235430096, 0.2453714490760957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 233}], {
             RGBColor[
             0.8479481693127158, 0.33804742930989184`, 0.1923147220140613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 242}], {
             RGBColor[
             0.8983924729381163, 0.6274385577093406, 0.23671813465048305`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 317}], {
             RGBColor[
             0.9345325845565998, 0.7656448596324403, 0.5126377323294256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 358}], {
             RGBColor[
             0.9235073892649484, 0.7232807673563957, 0.2763524253689754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 366}], {
             RGBColor[
             0.8898592758254438, 0.5927585201905767, 0.22980821876360358`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 370}], {
             RGBColor[
             0.8548273648949809, 0.7045756223106869, 0.6020207461756493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 391}], {
             RGBColor[
             0.8494144480971886, 0.3493178905748092, 0.19371883223399736`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 162}], {
             RGBColor[
             0.2420540274215789, 0.3717445083047905, 0.9370959908235907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 164}], {
             RGBColor[
             0.2402812832877892, 0.36988124182170756`, 0.9369950356677115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 227}], {
             RGBColor[
             0.23647303514531387`, 0.36587853156708794`, 0.9367781615697957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 280}], {
             RGBColor[
             0.23851863392834902`, 0.36802858558651175`, 0.9368946553942974]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 359}], {
             RGBColor[
             0.24179608967805666`, 0.37147339938215107`, 0.9370813016506819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 154}], {
             RGBColor[
             0.48274463326921224`, 0.5903240190384458, 0.9525963248033308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 159}], {
             RGBColor[
             0.433382915877228, 0.5475693804255631, 0.9494510398199664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 165}], {
             RGBColor[
             0.5340400056803238, 0.6325967606962016, 0.956460731981605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 192}], {
             RGBColor[
             0.43991049068666355`, 0.5532232376400468, 0.9498669711147159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 228}], {
             RGBColor[
             0.45159420731101624`, 0.5633430857393887, 0.9506114472065146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 262}], {
             RGBColor[
             0.736987048840004, 0.7937027834714817, 0.9726540973253948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 297}], {
             RGBColor[
             0.7409851288378926, 0.7966845449876518, 0.9658863907552364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 307}], {
             RGBColor[
             0.760285606005483, 0.8109047025764178, 0.9254188643765703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 314}], {
             RGBColor[
             0.7305716091219763, 0.7886632000372383, 0.9746741748807553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 332}], {
             RGBColor[
             0.53127642233297, 0.6303531592368088, 0.9562431725771618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 385}], {
             RGBColor[
             0.5553761412741389, 0.6499183967532158, 0.95814039073239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 172}], {
             RGBColor[
             0.29308124725627194`, 0.4253773516636531, 0.9400019155051696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 211}], {
             RGBColor[
             0.2737075152920192, 0.40501433100367, 0.9388986101306735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 328}], {
             RGBColor[
             0.29708750914626414`, 0.42952428212904603`, 0.9402324060605761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 347}], {
             RGBColor[
             0.28239395908436904`, 0.4141443341817761, 0.9393932902542057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 364}], {
             RGBColor[
             0.31713379957570453`, 0.44688737134317436`, 0.9415097379605015]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 372}], {
             RGBColor[
             0.2681076692483716, 0.3991285377610505, 0.9385797071827175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 387}], {
             RGBColor[
             0.28915329202202544`, 0.42124882166571403`, 0.9397782242654684]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 161}], {
             RGBColor[
             0.5276623353729026, 0.6268249505740837, 0.9561228183174523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 168}], {
             RGBColor[
             0.6470192572483401, 0.7238926765948177, 0.9656459465719469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 170}], {
             RGBColor[
             0.5344288299346016, 0.632685748069522, 0.9565539733675475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 251}], {
             RGBColor[
             0.723101933884062, 0.7833478892534567, 0.9732241552199159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.6353748988917614, 0.714796015346257, 0.9644853457536787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 312}], {
             RGBColor[
             0.5434225996528742, 0.6402139731641597, 0.9571993641486982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 326}], {
             RGBColor[
             0.4816391300864997, 0.5869619633485583, 0.9531902603733251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 356}], {
             RGBColor[
             0.5711332147381206, 0.6627106988393463, 0.9593808452755366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 199}], {
             RGBColor[
             0.2230106997449548, 0.3517287634999468, 0.9360115014844858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 212}], {
             RGBColor[
             0.21555790485274898`, 0.34389540353375003`, 0.9355870758407967]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 238}], {
             RGBColor[
             0.2247208711862695, 0.3535262621159006, 0.9361088932180968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 259}], {
             RGBColor[
             0.21561966255991427`, 0.3439603147996455, 0.9355905928508573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 274}], {
             RGBColor[
             0.22547330397154366`, 0.35431711668021776`, 0.9361517431520935]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 287}], {
             RGBColor[
             0.24021601426247097`, 0.36981263993780294`, 0.9369913186932763]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 299}], {
             RGBColor[
             0.21717366869177715`, 0.345593673773913, 0.9356790912011209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 318}], {
             RGBColor[
             0.22201805165799737`, 0.3506854274230307, 0.9359549716444248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 336}], {
             RGBColor[
             0.21561259787663173`, 0.3439528893695888, 0.9355901905275956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 367}], {
             RGBColor[
             0.21976666504097775`, 0.348319077342387, 0.9358267585072135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 186}], {
             RGBColor[
             0.2595342246109202, 0.3901173038593028, 0.9380914621938894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 189}], {
             RGBColor[
             0.28557376029945525`, 0.4174865068698732, 0.9395743752293106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 226}], {
             RGBColor[
             0.2546174021107136, 0.38494941166703367`, 0.9378114564262897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 241}], {
             RGBColor[
             0.2807813627744614, 0.41244939321555174`, 0.939301455279979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 255}], {
             RGBColor[
             0.26553787758684655`, 0.39642752379058566`, 0.9384333613492598]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 266}], {
             RGBColor[
             0.2627993543398047, 0.39354916222554226`, 0.9382774065016228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 365}], {
             RGBColor[
             0.26342074735738313`, 0.39420228568561005`, 0.9383127939147053]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 374}], {
             RGBColor[
             0.2733522518909328, 0.4046409266441276, 0.9388783784055468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 399}], {
             RGBColor[
             0.2527398969113101, 0.3829760346617555, 0.9377045352827038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 171}], {
             RGBColor[
             0.294524052203641, 0.4262383567855898, 0.940108081239609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 182}], {
             RGBColor[
             0.301964914813191, 0.43405917516616493`, 0.9405318273574531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 244}], {
             RGBColor[
             0.28793584651295273`, 0.41931373488830953`, 0.9397328926719012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 249}], {
             RGBColor[
             0.2927023996318287, 0.42432368443317114`, 0.9400043408205379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 253}], {
             RGBColor[
             0.3287756481732377, 0.4591906745282696, 0.9421702714700763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 270}], {
             RGBColor[
             0.28271133263489734`, 0.4138224395491612, 0.9394353643355215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 308}], {
             RGBColor[
             0.28846194842015016`, 0.41986670134956156`, 0.9397628533972181]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 386}], {
             RGBColor[
             0.3275993292124569, 0.45817180616795133`, 0.9420953174660733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 397}], {
             RGBColor[
             0.28259253336983103`, 0.413697573989268, 0.9394285988931239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 156}], {
             RGBColor[
             0.18478785261667285`, 0.31155412769964164`, 0.9338347668861651]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 175}], {
             RGBColor[
             0.181274153781999, 0.307861007443026, 0.9336346669355821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 242}], {
             RGBColor[
             0.5509815030039178, 0.5121510355041116, 0.5934630978551525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 256}], {
             RGBColor[
             0.2044622657846265, 0.33223318336900387`, 0.9349551956103941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 261}], {
             RGBColor[
             0.18153226782756765`, 0.3081323016702944, 0.9336493661486316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 264}], {
             RGBColor[
             0.186823590274237, 0.31369381705096394`, 0.9339506991341594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 317}], {
             RGBColor[
             0.5871216146224013, 0.6503573374272111, 0.8693826955340949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 333}], {
             RGBColor[
             0.18958831081692415`, 0.31659971363473505`, 0.9341081458790279]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 381}], {
             RGBColor[
             0.588381597564026, 0.6508783727536576, 0.8485015174600479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 154}], {
             RGBColor[
             0.3737943950019111, 0.49818365032325973`, 0.9450388262094847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 188}], {
             RGBColor[
             0.2922583395910017, 0.4237094580639409, 0.939984452630228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 195}], {
             RGBColor[
             0.2815627334149148, 0.41246769783227444`, 0.9393753536812313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 203}], {
             RGBColor[
             0.3044141682214503, 0.43648600467859244`, 0.9406767090877951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 258}], {
             RGBColor[
             0.28518201112076286`, 0.41627178817658117`, 0.9395814661923377]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 278}], {
             RGBColor[
             0.284923192180341, 0.41599975306012926`, 0.939566726836569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 284}], {
             RGBColor[
             0.2807144253547577, 0.4115760722752118, 0.9393270437921646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 312}], {
             RGBColor[
             0.39019396776607296`, 0.5121264097897626, 0.9461561082120249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 327}], {
             RGBColor[
             0.31801144721476193`, 0.44986726468250904`, 0.9414843861034113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 337}], {
             RGBColor[
             0.30108704647180895`, 0.43298898876801645`, 0.9404872344261885]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[
             0.4179045828513193, 0.5346231354649491, 0.9483375893388631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 361}], {
             RGBColor[
             0.3365286408445437, 0.46590592710341294`, 0.9426642853073897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 369}], {
             RGBColor[
             0.28744235484774583`, 0.41864755274771004`, 0.9397101894237105]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 392}], {
             RGBColor[
             0.28268998646480836`, 0.4136525122596839, 0.9394395490748012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 192}], {
             RGBColor[
             0.3873238866966642, 0.5099022160172301, 0.9459009134566145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[
             0.36077780249875213`, 0.4853053517709617, 0.9442681500235399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 222}], {
             RGBColor[
             0.5175424648922109, 0.6185744663744461, 0.9553357375773506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 228}], {
             RGBColor[
             0.39900760332101687`, 0.520022064116572, 0.9466453895484133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 312}], {
             RGBColor[
             0.4465576020433747, 0.5609457568821319, 0.9497475491477698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 332}], {
             RGBColor[
             0.47868981834297064`, 0.5870321376139921, 0.9522771149190605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 356}], {
             RGBColor[
             0.4742682171286211, 0.5834424825573183, 0.951929030274608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 361}], {
             RGBColor[
             0.39289227512184555`, 0.5147252741957822, 0.9462557262431346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 385}], {
             RGBColor[
             0.5027895372841396, 0.606597375130399, 0.9541743330742887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 170}], {
             RGBColor[
             0.3747576276064379, 0.498629600146848, 0.9451144220759548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 180}], {
             RGBColor[
             0.33540782096983857`, 0.46454677541701367`, 0.9426070871927383]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 183}], {
             RGBColor[
             0.2817396246657633, 0.4134565872206231, 0.9393560268770672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 239}], {
             RGBColor[
             0.3145302695292589, 0.4464636896954298, 0.9412767880762385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 271}], {
             RGBColor[
             0.305666751429035, 0.4386055145162801, 0.9407186413492236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 326}], {
             RGBColor[
             0.32196792775833594`, 0.4529058154258842, 0.9417507090817323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 335}], {
             RGBColor[
             0.29253189959404885`, 0.42479995244000324`, 0.9399706309684931]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 337}], {
             RGBColor[
             0.29464447603044647`, 0.42702040421973947`, 0.9400909390712692]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 354}], {
             RGBColor[
             0.29215952785429067`, 0.42440856613178546`, 0.9399494249487885]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 175}], {
             RGBColor[
             0.18244584031582461`, 0.30909252427929373`, 0.9337013927503286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 202}], {
             RGBColor[
             0.5211495825009953, 0.37342113688887774`, 0.567742844041897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 214}], {
             RGBColor[
             0.5848663164286375, 0.6501021124541597, 0.9231267958935396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 256}], {
             RGBColor[
             0.20563395231845213`, 0.3334647002052716, 0.9350219214251405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 261}], {
             RGBColor[
             0.18270395436139325`, 0.3093638185065621, 0.9337160919633781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 264}], {
             RGBColor[
             0.1879952768080626, 0.31492533388723165`, 0.9340174249489059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 295}], {
             RGBColor[
             0.2141734445733891, 0.3424402480002911, 0.9355082328760125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 310}], {
             RGBColor[
             0.1842688448604277, 0.3110086176408356, 0.93380521016225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 363}], {
             RGBColor[
             0.5242360164158433, 0.390684407006331, 0.5704454430561892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 381}], {
             RGBColor[
             0.5895532840978516, 0.6521098895899253, 0.8485682432747944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 187}], {
             RGBColor[
             0.656588840938115, 0.7291931341002164, 0.9681680488654731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 218}], {
             RGBColor[
             0.689653807893005, 0.7555582412254274, 0.971321814931075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 253}], {
             RGBColor[
             0.40547981020843754`, 0.5251955404755204, 0.9471772728723662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 298}], {
             RGBColor[
             0.6463369873520685, 0.7210185843298552, 0.9671902179184984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.5352140965427551, 0.633549940550514, 0.9565531607151321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 265}], {
             RGBColor[
             0.5475052991401734, 0.643528492531465, 0.9575207692077594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 311}], {
             RGBColor[
             0.5112449698673547, 0.6140907237185725, 0.9546662232614405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 322}], {
             RGBColor[
             0.5057660137173806, 0.6096426602918618, 0.9542348997632368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 362}], {
             RGBColor[
             0.4538874638081069, 0.5662041111673836, 0.9505158832119648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 165}], {
             RGBColor[
             0.43209168429834016`, 0.5465211004605023, 0.9493493893401392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 167}], {
             RGBColor[
             0.30749203096032607`, 0.43842628345076595`, 0.9408993959616536]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 192}], {
             RGBColor[
             0.3379621693046799, 0.46714757740434754`, 0.9427556284732501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 201}], {
             RGBColor[
             0.30393044061377905`, 0.43468282617867443`, 0.9406965686603185]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 210}], {
             RGBColor[
             0.3156791522092831, 0.44703146697688845`, 0.9413656404050212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 228}], {
             RGBColor[
             0.3496458859290326, 0.47726742550368945`, 0.9435001045650488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 236}], {
             RGBColor[
             0.2909783973419341, 0.4210694074929913, 0.9399589689568179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 243}], {
             RGBColor[
             0.3099032733211534, 0.44096065205359114`, 0.9410367126469893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 263}], {
             RGBColor[
             0.29675910238603487`, 0.4271452950122101, 0.9402881715572926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 166}], {
             RGBColor[
             0.8271233428626157, 0.2094874755325008, 0.1736066497976622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 185}], {
             RGBColor[
             0.8265840327508944, 0.20534210168661424`, 0.17309020582561438`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 213}], {
             RGBColor[
             0.8702228477750129, 0.45615422864304855`, 0.21154106500959308`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 224}], {
             RGBColor[
             0.9025695450570996, 0.5785729407895561, 0.26790552836760506`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 247}], {
             RGBColor[
             0.8682425607038025, 0.44830305029724704`, 0.2099476795487854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 289}], {
             RGBColor[
             0.863615444991354, 0.42809333252077686`, 0.20612813226240806`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 302}], {
             RGBColor[
             0.9083773079386029, 0.59816388871644, 0.2904675904582531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 340}], {
             RGBColor[
             0.9116278550257833, 0.6083417789954149, 0.37001345675471364`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 370}], {
             RGBColor[
             0.8303471028154521, 0.5479183884634005, 0.5798122246722852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 400}], {
             RGBColor[
             0.6095442446912597, 0.3697331530727862, 0.5609538560304888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 170}], {
             RGBColor[
             0.43820314080929235`, 0.5539712686639211, 0.9491428945379133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 222}], {
             RGBColor[
             0.5181817733764011, 0.6191282032508729, 0.9553764737486448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 239}], {
             RGBColor[
             0.3779757827321134, 0.5018053582125028, 0.9453052605381971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 251}], {
             RGBColor[
             0.6268762447587527, 0.7046334098478555, 0.9658130763902817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 312}], {
             RGBColor[
             0.44719691052756494`, 0.5614994937585587, 0.949788285319064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 326}], {
             RGBColor[
             0.3854134409611904, 0.5082474839429573, 0.9457791815436909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 327}], {
             RGBColor[
             0.3750143899762539, 0.4992403486513052, 0.9451165632104506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 337}], {
             RGBColor[
             0.35808998923330093`, 0.48236207273681253`, 0.9441194115332278]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.47490752561281135`, 0.5839962194337451, 0.9519697664459024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 179}], {
             RGBColor[
             0.25786357675267113`, 0.38836134703509095`, 0.9379963212698641]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 231}], {
             RGBColor[
             0.27738405997012383`, 0.4088786125667542, 0.9391079839111312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 313}], {
             RGBColor[
             0.26444617460999714`, 0.3952800747439503, 0.938371190479758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 359}], {
             RGBColor[
             0.24582605828944576`, 0.3757091519074889, 0.9373108024012962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 164}], {
             RGBColor[
             0.24375587866941067`, 0.373533261869863, 0.9371929087344915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 169}], {
             RGBColor[
             0.23283585906700827`, 0.36205562889850595`, 0.936571029772856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 209}], {
             RGBColor[
             0.2485031193706023, 0.3785229128392603, 0.9374632570695112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 227}], {
             RGBColor[
             0.23994763052693538`, 0.3695305516152434, 0.9369760346365759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 240}], {
             RGBColor[
             0.2420898799764604, 0.3717821916131542, 0.9370980325735522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 245}], {
             RGBColor[
             0.2374360489235272, 0.36689072010659024`, 0.9368330037798137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 280}], {
             RGBColor[
             0.24199322930997053`, 0.37168060563466715`, 0.9370925284610774]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 304}], {
             RGBColor[
             0.23203584179739814`, 0.3612147600241211, 0.9365254699728711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 315}], {
             RGBColor[
             0.24412373790812583`, 0.3739199052533755, 0.9372138577739373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 319}], {
             RGBColor[
             0.2432784612852803, 0.3730314659291315, 0.9371657205207411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 329}], {
             RGBColor[
             0.2400560374603316, 0.3696444941756393, 0.936982208251059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 371}], {
             RGBColor[
             0.25850942763125473`, 0.3890401772577931, 0.9380331015219487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 169}], {
             RGBColor[
             0.23161848816298614`, 0.3607760948926053, 0.9365017023008109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 209}], {
             RGBColor[
             0.24728574846658016`, 0.37724337883335973`, 0.9373939295974659]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 227}], {
             RGBColor[
             0.23873025962291325`, 0.36825101760934276`, 0.9369067071645306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 245}], {
             RGBColor[
             0.23621867801950508`, 0.36561118610068966`, 0.9367636763077685]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 280}], {
             RGBColor[
             0.2407758584059484, 0.37040107162876656`, 0.9370232009890322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 304}], {
             RGBColor[
             0.230818470893376, 0.3599352260182205, 0.936456142500826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 315}], {
             RGBColor[
             0.2429063670041037, 0.37264037124747484`, 0.9371445303018922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 228}], {
             RGBColor[
             0.4503029757321284, 0.5622948057743279, 0.9505097967266875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 262}], {
             RGBColor[
             0.7356958172611161, 0.7926545035064209, 0.9725524468455675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 298}], {
             RGBColor[
             0.6780894534855002, 0.7467966667692734, 0.969689888365638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 307}], {
             RGBColor[
             0.7589943744265952, 0.8098564226113569, 0.9253172138967432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 314}], {
             RGBColor[
             0.7292803775430885, 0.7876149200721775, 0.9745725244009281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 332}], {
             RGBColor[
             0.5299851907540822, 0.6293048792717479, 0.9561415220973347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 385}], {
             RGBColor[
             0.5540849096952511, 0.648870116788155, 0.9580387402525627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 185}], {
             RGBColor[
             0.8242297938213237, 0.1872463896398561, 0.17083578396792481`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 213}], {
             RGBColor[
             0.8678686088454421, 0.43805851659629047`, 0.20928664315190354`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 224}], {
             RGBColor[
             0.9002153061275288, 0.5604772287427979, 0.2656511065099155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 247}], {
             RGBColor[
             0.8658883217742317, 0.43020733825048896`, 0.20769325769109587`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 289}], {
             RGBColor[
             0.8612612060617832, 0.40999762047401866`, 0.2038737104047185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 302}], {
             RGBColor[
             0.9060230690090321, 0.580068176669682, 0.28821316860056356`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 340}], {
             RGBColor[
             0.9092736160962124, 0.5902460669486567, 0.36775903489702405`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 400}], {
             RGBColor[
             0.6071900057616888, 0.351637441026028, 0.5586994341727993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 192}], {
             RGBColor[
             0.3140196057697616, 0.4440801406652496, 0.941315327256403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[
             0.27998787707886075`, 0.41161538943957654`, 0.9392562674434715]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.2874735215718495, 0.4194832764189812, 0.9396825638233285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 228}], {
             RGBColor[
             0.32570332239411426`, 0.45419998876459156`, 0.9420598033482018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 243}], {
             RGBColor[
             0.28596070978623506`, 0.41789321531449325`, 0.9395964114301423]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 348}], {
             RGBColor[
             0.2732523450214962, 0.4045359181898883, 0.9388726888571313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 351}], {
             RGBColor[
             0.2646469792533301, 0.39549113315584294`, 0.938382626007132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 170}], {
             RGBColor[
             0.5575600626847299, 0.651038994684655, 0.958666022792408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 180}], {
             RGBColor[
             0.5182102560481305, 0.6169561699548207, 0.9561586879091916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 220}], {
             RGBColor[
             0.5727925024434088, 0.663632053166977, 0.9598025445321408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 251}], {
             RGBColor[
             0.7462331666341901, 0.8017011358685895, 0.9753362046447762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 282}], {
             RGBColor[
             0.6585061316418895, 0.73314926196139, 0.9665973951785392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 350}], {
             RGBColor[
             0.5514466203488134, 0.6457438382038303, 0.9582764796526682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 357}], {
             RGBColor[
             0.6729202964028389, 0.7444097170243531, 0.9680340644138824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 394}], {
             RGBColor[
             0.5145092206731405, 0.613750519132451, 0.9559228612077943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 209}], {
             RGBColor[
             0.23636572886417778`, 0.36576574586200267`, 0.9367720506358304]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 227}], {
             RGBColor[
             0.22781024002051087`, 0.3567733846379857, 0.936284828202895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 240}], {
             RGBColor[
             0.22995248947003588`, 0.35902502463589653`, 0.9364068261398715]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 245}], {
             RGBColor[
             0.22529865841710267`, 0.3541335531293326, 0.936141797346133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 280}], {
             RGBColor[
             0.229855838803546, 0.3589234386574095, 0.9364013220273968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 292}], {
             RGBColor[
             0.21585857380573317`, 0.34421142566684904`, 0.9356041984928691]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 304}], {
             RGBColor[
             0.21989845129097363`, 0.3484575930468634, 0.9358342635391905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 315}], {
             RGBColor[
             0.23198634740170132`, 0.3611627382761178, 0.9365226513402567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 329}], {
             RGBColor[
             0.22791864695390707`, 0.3568873271983817, 0.9362910018173783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 353}], {
             RGBColor[
             0.21553905850906607`, 0.343875594831612, 0.9355860025694045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 378}], {
             RGBColor[
             0.21461245212241514`, 0.34290167276900374`, 0.9355332337064761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 180}], {
             RGBColor[
             0.40561982873439206`, 0.5257492414295251, 0.9470667147047922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 239}], {
             RGBColor[
             0.38474227729381244`, 0.5076661557079413, 0.9457364155882924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 251}], {
             RGBColor[
             0.6336427393204518, 0.7104942073432939, 0.966244231440377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 271}], {
             RGBColor[
             0.37587875919358854`, 0.49980798052879155`, 0.9451782688612774]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 282}], {
             RGBColor[
             0.5459157043281511, 0.6419423334360943, 0.9575054219741398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 326}], {
             RGBColor[
             0.39217993552288943`, 0.5141082814383957, 0.9462103365937862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 182}], {
             RGBColor[
             0.2806534492526592, 0.41231494799395196`, 0.9392941707941435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 244}], {
             RGBColor[
             0.266624380952421, 0.39756950771609656`, 0.9384952361085915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 253}], {
             RGBColor[
             0.30746418261270597`, 0.43744644735605664`, 0.9409326149067666]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 270}], {
             RGBColor[
             0.2613998670743656, 0.3920782123769482, 0.9381977077722119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 308}], {
             RGBColor[
             0.26715048285961845`, 0.3981224741773486, 0.9385251968339084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 397}], {
             RGBColor[
             0.26128106780929927`, 0.39195334681705507`, 0.9381909423298143]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 211}], {
             RGBColor[
             0.2820509294380053, 0.413783788274112, 0.9393737552233123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 328}], {
             RGBColor[
             0.3054309232922502, 0.438293739399488, 0.9407075511532149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 347}], {
             RGBColor[
             0.29073737323035515`, 0.422913791452218, 0.9398684353468445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 364}], {
             RGBColor[
             0.3254772137216906, 0.45565682861361634`, 0.9419848830531403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 387}], {
             RGBColor[
             0.29749670616801155`, 0.43001827893615596`, 0.9402533693581072]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 175}], {
             RGBColor[
             0.20264987627198583`, 0.3303282470790865, 0.9348519827088393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 197}], {
             RGBColor[
             0.607559522477704, 0.6724367666110929, 0.8861420267905455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 204}], {
             RGBColor[
             0.20264730553141047`, 0.33032554506774736`, 0.9348518363089665]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 214}], {
             RGBColor[
             0.6050703523847987, 0.6713378352539525, 0.9242773858520503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 261}], {
             RGBColor[
             0.2029079903175545, 0.3305995413063548, 0.9348666819218888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 295}], {
             RGBColor[
             0.23437748052955032`, 0.36367597080008385`, 0.9366588228345232]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 310}], {
             RGBColor[
             0.20447288081658893`, 0.33224434044062834`, 0.9349558001207607]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 345}], {
             RGBColor[
             0.21415750276433887`, 0.34242349214821033`, 0.9355073250135709]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 193}], {
             RGBColor[
             0.7754724977883137, 0.8245433157037161, 0.9782504569369469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 232}], {
             RGBColor[
             0.6270810139261389, 0.7068104580353534, 0.9646885621008761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 235}], {
             RGBColor[
             0.7343495307888845, 0.7923987018062052, 0.9741567564086497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 260}], {
             RGBColor[
             0.7687797089830702, 0.819295818690549, 0.9775884348027377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 267}], {
             RGBColor[
             0.6499021646261236, 0.725337696254724, 0.9664851266806084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 272}], {
             RGBColor[
             0.6878111560407678, 0.756042569748228, 0.9695182461395961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 275}], {
             RGBColor[
             0.8603530123804088, 0.8894563784374243, 0.877080294609712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 281}], {
             RGBColor[
             0.6802997161269625, 0.7500157979571946, 0.9688781332846546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 291}], {
             RGBColor[
             0.7125484820155874, 0.7753675568103979, 0.9719838316093115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 338}], {
             RGBColor[
             0.8614468790047858, 0.8890515325777966, 0.796643588235805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 384}], {
             RGBColor[
             0.7385166114389616, 0.7956540568810313, 0.9745720920642666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 398}], {
             RGBColor[
             0.83401539327211, 0.8711277377968187, 0.9805027030161089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 204}], {
             RGBColor[
             0.17892957074057536`, 0.30539670201133906`, 0.9335011463998728]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 214}], {
             RGBColor[
             0.5813526175939636, 0.6464089921975442, 0.9229266959429565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 256}], {
             RGBColor[
             0.20212025348377827`, 0.329771579948656, 0.9348218214745575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 261}], {
             RGBColor[
             0.1791902555267194, 0.3056706982499465, 0.9335159920127951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 264}], {
             RGBColor[
             0.18448157797338877`, 0.31123221363061604`, 0.9338173249983228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 295}], {
             RGBColor[
             0.21065974573871524`, 0.33874712774367555`, 0.9353081329254295]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 310}], {
             RGBColor[
             0.18075514602575382`, 0.30731549738422004`, 0.933605110211667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 345}], {
             RGBColor[
             0.1904397679735038, 0.31749464909180203`, 0.9341566351044772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 186}], {
             RGBColor[
             0.23214557991116364`, 0.36133010173948693`, 0.9365317193961071]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 226}], {
             RGBColor[
             0.22722875741095702`, 0.3561622095472178, 0.9362517136285073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 294}], {
             RGBColor[
             0.21429151975408078`, 0.34256435250159695`, 0.9355149570828762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 341}], {
             RGBColor[
             0.21870360025711671`, 0.3472017288523488, 0.9357662185404361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 368}], {
             RGBColor[
             0.2143024966118115, 0.34257588987504495`, 0.9355155821986852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 379}], {
             RGBColor[
             0.2183904240990045, 0.34687256085365753`, 0.9357483836215341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 393}], {
             RGBColor[
             0.2193217433014607, 0.3478514363844869, 0.9358014208723507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 399}], {
             RGBColor[
             0.22535125221155355`, 0.3541888325419396, 0.9361447924849214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 200}], {
             RGBColor[
             0.2962840776702533, 0.42752676637236176`, 0.9402288709406241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 225}], {
             RGBColor[
             0.2895083029136421, 0.42040499749423077`, 0.9398430005920957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 296}], {
             RGBColor[
             0.3117150207517371, 0.4437456659293011, 0.9411076403210801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 311}], {
             RGBColor[
             0.42064126980492156`, 0.5369664823599833, 0.9485194381294991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 324}], {
             RGBColor[
             0.3009330775683418, 0.4324131600288711, 0.9404936246072413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 339}], {
             RGBColor[
             0.34383450141698674`, 0.4722338963280338, 0.9431298082827468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 360}], {
             RGBColor[
             0.31615011179738517`, 0.4482550694974156, 0.9413657834565303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 374}], {
             RGBColor[
             0.29900611365793894`, 0.43038779878246913`, 0.9403838868632315]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 375}], {
             RGBColor[
             0.28837692064883436`, 0.4192158430001391, 0.939778570045845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 383}], {
             RGBColor[
             0.3010724134398118, 0.43255961086419054`, 0.9405015595789926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 390}], {
             RGBColor[
             0.2941038875347629, 0.4252352483079229, 0.9401047123377103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 209}], {
             RGBColor[
             0.24801071646784933`, 0.37800536616831976`, 0.9374352154526442]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 229}], {
             RGBColor[
             0.24544230257567465`, 0.37530580032079786`, 0.9372889480811126]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 240}], {
             RGBColor[
             0.24159747707370743`, 0.3712646449422136, 0.9370699909566852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 245}], {
             RGBColor[
             0.23694364602077422`, 0.3663731734356497, 0.9368049621629467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 248}], {
             RGBColor[
             0.230098166399185, 0.35917814032488304`, 0.9364151222254768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 309}], {
             RGBColor[
             0.2573894464516083, 0.38786300602707646`, 0.9379693202506316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 315}], {
             RGBColor[
             0.24363133500537287`, 0.37340235858243487`, 0.9371858161570703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 319}], {
             RGBColor[
             0.24278605838252734`, 0.37251391925819094`, 0.9371376789038741]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 329}], {
             RGBColor[
             0.23956363455757862`, 0.36912694750469877`, 0.9369541666341921]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 334}], {
             RGBColor[
             0.25269374017822266`, 0.3829275210087747, 0.9377019067250372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 371}], {
             RGBColor[
             0.25801702472850174`, 0.38852263058685255`, 0.9380050599050818]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 388}], {
             RGBColor[
             0.23367677668762307`, 0.36293948663502873`, 0.9366189187873238]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 196}], {
             RGBColor[
             0.2837836367777321, 0.41560497354815545`, 0.9394724303429989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 231}], {
             RGBColor[
             0.28916364068982703`, 0.4212596987717169, 0.9397788136067902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 303}], {
             RGBColor[
             0.27962744891017854`, 0.4112365565818258, 0.9392357415924706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 313}], {
             RGBColor[
             0.2762257553297003, 0.407661160948913, 0.939042020175417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 344}], {
             RGBColor[
             0.29513590341832135`, 0.4264382934400302, 0.9401591514378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 359}], {
             RGBColor[
             0.2576056390091489, 0.3880902381124516, 0.9379816320969553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 239}], {
             RGBColor[
             0.3453924706572131, 0.47358333097810695`, 0.943229080705076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 271}], {
             RGBColor[
             0.3365289525569892, 0.46572515579895724`, 0.942670933978061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 282}], {
             RGBColor[
             0.5065658976915518, 0.60785950870626, 0.9549980870909234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 326}], {
             RGBColor[
             0.3528301288862901, 0.48002545670856134`, 0.9437030017105699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 350}], {
             RGBColor[
             0.3995063863984757, 0.5204540849487005, 0.9466771715650524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 394}], {
             RGBColor[
             0.36256898672280274`, 0.4884607658773212, 0.9443235531201786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 250}], {
             RGBColor[
             0.7777697545864616, 0.8245041838583995, 0.9019245302265969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 265}], {
             RGBColor[
             0.5796034948121, 0.6695872537851715, 0.9600476567506184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 322}], {
             RGBColor[
             0.5378642093893072, 0.6357014215455682, 0.9567617873060958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 362}], {
             RGBColor[
             0.4859856594800335, 0.59226287242109, 0.9530427707548238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 244}], {
             RGBColor[
             0.27406524356197104`, 0.4053903260966717, 0.9389189822264357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 253}], {
             RGBColor[
             0.31490504522225604`, 0.4452672657366318, 0.9413563610246107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 271}], {
             RGBColor[
             0.28286075625291396`, 0.4146349676025667, 0.9394198736623899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 273}], {
             RGBColor[
             0.26718551324119244`, 0.3981592933294373, 0.9385271917623162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 335}], {
             RGBColor[
             0.2697259044179279, 0.4008294055262898, 0.9386718632816594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 305}], {
             RGBColor[
             0.21033276310750965`, 0.33840344826638225`, 0.9352895117483098]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 325}], {
             RGBColor[
             0.2146653182782982, 0.3429572384507447, 0.9355362443558451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 213}], {
             RGBColor[
             0.8673292987337209, 0.4339131427504039, 0.20877019917985573`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 224}], {
             RGBColor[
             0.8996759960158076, 0.5563318548969114, 0.2651346625378677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 247}], {
             RGBColor[
             0.8653490116625105, 0.42606196440460237`, 0.20717681371904806`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 289}], {
             RGBColor[
             0.8607218959500621, 0.40585224662813213`, 0.20335726643267069`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 302}], {
             RGBColor[
             0.905483758897311, 0.5759228028237954, 0.28769672462851575`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 340}], {
             RGBColor[
             0.9087343059844912, 0.5861006931027701, 0.36724259092497624`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 400}], {
             RGBColor[
             0.6066506956499677, 0.3474920671801415, 0.5581829902007515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 189}], {
             RGBColor[
             0.2745072076984255, 0.4058548584262301, 0.9389441514301794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 200}], {
             RGBColor[
             0.2595636633022175, 0.3901482457903771, 0.9380931386838082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 226}], {
             RGBColor[
             0.24355084950968384`, 0.37331776322339055`, 0.9371812326271585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 241}], {
             RGBColor[
             0.2697148101734317, 0.4008177447719086, 0.9386712314808479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 255}], {
             RGBColor[
             0.2544713249858168, 0.38479587534694254`, 0.9378031375501286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 288}], {
             RGBColor[
             0.2467468316416792, 0.3766769430810886, 0.9373632390815438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 341}], {
             RGBColor[
             0.23502569235584353`, 0.3643572825285215, 0.9366957375390872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 374}], {
             RGBColor[
             0.2622856992899031, 0.3930092782004845, 0.9382481546064155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 393}], {
             RGBColor[
             0.23564383540018752`, 0.36500699006065973`, 0.9367309398710019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 399}], {
             RGBColor[
             0.24167334431028037`, 0.3713443862181124, 0.9370743114835726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 193}], {
             RGBColor[
             0.8331367258093362, 0.8697846265391334, 0.9839465187292714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 218}], {
             RGBColor[
             0.8769988069965478, 0.9047590594733392, 0.9881301231890498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 232}], {
             RGBColor[
             0.6847452419471614, 0.7520517688707707, 0.9703846238932006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 235}], {
             RGBColor[
             0.792013758809907, 0.8376400126416226, 0.9798528182009743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 275}], {
             RGBColor[
             0.9180172404014313, 0.9346976892728417, 0.8827763564020366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 279}], {
             RGBColor[
             0.8947917399967904, 0.8503099582405043, 0.6300514927715455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 281}], {
             RGBColor[
             0.7379639441479849, 0.795257108792612, 0.9745741950769791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 298}], {
             RGBColor[
             0.8336819864556111, 0.8702194025777671, 0.983998526176473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 306}], {
             RGBColor[
             0.9071549779062498, 0.8950638881018478, 0.6621967951023203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 195}], {
             RGBColor[
             0.25639031228130726`, 0.3868128526653249, 0.9379124210377194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 203}], {
             RGBColor[
             0.2792417470878428, 0.4108311595116429, 0.9392137764442834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 206}], {
             RGBColor[
             0.2493239941811602, 0.37938570431162577`, 0.937510004675597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 208}], {
             RGBColor[
             0.25008631824464794`, 0.38018695523648866`, 0.9375534179032552]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 258}], {
             RGBColor[
             0.2600095899871553, 0.39061694300963157`, 0.938118533548826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 278}], {
             RGBColor[
             0.2597507710467335, 0.39034490789317966`, 0.9381037941930572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 284}], {
             RGBColor[
             0.25554200422115014`, 0.38592122710826227`, 0.9378641111486529]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 327}], {
             RGBColor[
             0.2928390260811543, 0.4242124195155595, 0.9400214534598996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 361}], {
             RGBColor[
             0.3113562197109362, 0.44025108193646334`, 0.9412013526638779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 369}], {
             RGBColor[
             0.26226993371413826`, 0.39299270758076044`, 0.9382472567801988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 392}], {
             RGBColor[
             0.25751756533120074`, 0.38799766709273437`, 0.9379766164312895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 200}], {
             RGBColor[
             0.28560319899075254`, 0.41751744880094743`, 0.9395760517192293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 219}], {
             RGBColor[
             0.37386729373661226`, 0.4974887142474586, 0.9450712281757306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 241}], {
             RGBColor[
             0.2957543458619668, 0.428186947782479, 0.9401541445162689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 255}], {
             RGBColor[
             0.28051086067435194`, 0.4121650783575129, 0.9392860505855498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 339}], {
             RGBColor[
             0.333153622737486, 0.4622245787566195, 0.942476989061352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 360}], {
             RGBColor[
             0.30546923311788443`, 0.43824575192600135`, 0.9407129642351355]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 374}], {
             RGBColor[
             0.2883252349784382, 0.42037848121105487`, 0.9397310676418367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 266}], {
             RGBColor[
             0.24805045871485498`, 0.3780471377897267, 0.9374374787148178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 273}], {
             RGBColor[
             0.2582701914773965, 0.38878872489163985`, 0.9380194773769047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 365}], {
             RGBColor[
             0.24867185173243342`, 0.3787002612497945, 0.9374728661279003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 198}], {
             RGBColor[
             0.7526714957518834, 0.806764542665624, 0.9759689648481673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 216}], {
             RGBColor[
             0.6689774683276695, 0.7413295497654275, 0.9676410801591727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 219}], {
             RGBColor[
             0.5630206032370957, 0.6553990201614963, 0.9591704044347413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 220}], {
             RGBColor[
             0.5771439386381384, 0.6670314281944398, 0.9602362550255482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 311}], {
             RGBColor[
             0.5991137006259042, 0.6848674707026068, 0.961965795167115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 323}], {
             RGBColor[
             0.7545318035699571, 0.8082479016230455, 0.9761464026685716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 339}], {
             RGBColor[
             0.5223069322379694, 0.6201348846706572, 0.9565761653203628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 357}], {
             RGBColor[
             0.6772717325975683, 0.7478090920518159, 0.9684677749072899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 201}], {
             RGBColor[
             0.3104580154232146, 0.4403366833931581, 0.941112499955068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 203}], {
             RGBColor[
             0.31794365991620344`, 0.4482045703725628, 0.9415387963349251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 228}], {
             RGBColor[
             0.35617346073846823`, 0.48292128271817314`, 0.9439160358597984]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 243}], {
             RGBColor[
             0.31643084813058897`, 0.44661450926807483`, 0.9414526439417388]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 332}], {
             RGBColor[
             0.43585567576042195`, 0.5499313562155932, 0.9495477612304457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 348}], {
             RGBColor[
             0.30372248336585006`, 0.4332572121434699, 0.9407289213687278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 361}], {
             RGBColor[
             0.35005813253929685`, 0.4776244927973833, 0.9435263725545195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 385}], {
             RGBColor[
             0.45995539470159097`, 0.5694965937320001, 0.9514449793856737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 232}], {
             RGBColor[
             0.6739481277148399, 0.7434424430617759, 0.9693547854990241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 235}], {
             RGBColor[
             0.7812166445775857, 0.8290306868326278, 0.9788229798067978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 260}], {
             RGBColor[
             0.8156468227717713, 0.8559278037169716, 0.9822546582008858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 275}], {
             RGBColor[
             0.9072201261691099, 0.9260883634638468, 0.8817465180078601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 281}], {
             RGBColor[
             0.7271668299156635, 0.7866477829836171, 0.9735443566828026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 338}], {
             RGBColor[
             0.9083139927934867, 0.9256835176042191, 0.801309811633953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 384}], {
             RGBColor[
             0.7853837252276628, 0.8322860419074539, 0.9792383154624147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 376}], {
             RGBColor[
             0.4132241787161002, 0.5323357471779375, 0.947551257161364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 377}], {
             RGBColor[
             0.40146722310948635`, 0.5221524631532592, 0.9468021143463783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 396}], {
             RGBColor[
             0.3331772870037427, 0.4601881672994485, 0.9425538104147095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 206}], {
             RGBColor[
             0.2386283880050733, 0.3681439440799593, 0.9369009057266002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 208}], {
             RGBColor[
             0.239390712068561, 0.3689451950048222, 0.9369443189542583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 258}], {
             RGBColor[
             0.24931398381106837`, 0.3793751827779651, 0.9375094345998292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 278}], {
             RGBColor[
             0.24905516487064655`, 0.3791031476615132, 0.9374946952440605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 284}], {
             RGBColor[
             0.24484639804506322`, 0.3746794668765958, 0.9372550121996561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 327}], {
             RGBColor[
             0.2821434199050674, 0.41297065928389304`, 0.9394123545109028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 337}], {
             RGBColor[
             0.26521901916211443`, 0.39609238336940045`, 0.9384152028336801]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 369}], {
             RGBColor[
             0.2515743275380513, 0.381750947349094, 0.9376381578312021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 392}], {
             RGBColor[
             0.24682195915511385`, 0.3767559068610679, 0.9373675174822926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 231}], {
             RGBColor[
             0.3033041199951848, 0.43612223907981873`, 0.9405840929842658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 234}], {
             RGBColor[
             0.3183317548341577, 0.44914414193399255`, 0.9415414311188043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 290}], {
             RGBColor[
             0.3515289166579535, 0.47789785496789633`, 0.943656724915119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 303}], {
             RGBColor[
             0.29376792821553643`, 0.42609909688992764`, 0.9400410209699464]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 313}], {
             RGBColor[
             0.2903662346350581, 0.4225237012570149, 0.9398472995528928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 344}], {
             RGBColor[
             0.3092763827236792, 0.441300833748132, 0.9409644308152758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 204}], {
             RGBColor[
             0.5838392169462935, 0.6475052215433456, 0.8847911904815791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 215}], {
             RGBColor[
             0.9040198154602492, 0.5694397771754294, 0.5010925431304881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 295}], {
             RGBColor[
             0.6155693919444334, 0.6808556472756819, 0.8865981770071358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 310}], {
             RGBColor[
             0.5856647922314719, 0.6494240169162264, 0.8848951542933734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 345}], {
             RGBColor[
             0.5953494141792219, 0.6596031686238084, 0.8854466791861835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 216}], {
             RGBColor[
             0.7427956016916255, 0.7990494191661757, 0.974984628023718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 219}], {
             RGBColor[
             0.6368387366010516, 0.7131188895622445, 0.9665139522992866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 224}], {
             RGBColor[
             0.901075568718926, 0.8970235530331128, 0.6716312488962854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 247}], {
             RGBColor[
             0.866748584365629, 0.7667536625408037, 0.6136734000774657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 302}], {
             RGBColor[
             0.9068833316004294, 0.9166145009599966, 0.6941933109869335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 311}], {
             RGBColor[
             0.6729318339898602, 0.7425873401033549, 0.9693093430316602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 323}], {
             RGBColor[
             0.828349936933913, 0.8659677710237936, 0.9834899505331167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 340}], {
             RGBColor[
             0.9101338786876096, 0.9267923912389714, 0.7737391772833939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 212}], {
             RGBColor[
             0.21834996970250586`, 0.3468300407179805, 0.9357460798035004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 238}], {
             RGBColor[
             0.22751293603602638`, 0.35646089930013114`, 0.9362678971808005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 252}], {
             RGBColor[
             0.2250679449332263, 0.3538910586296987, 0.9361286585545363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 277}], {
             RGBColor[
             0.24180779724081597`, 0.3714857047729135, 0.9370819683790612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 287}], {
             RGBColor[
             0.24300807911222783`, 0.3727472771220335, 0.9371503226559803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 293}], {
             RGBColor[
             0.21851691429369074`, 0.3470055100682143, 0.9357555870509962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 299}], {
             RGBColor[
             0.21996573354153404`, 0.3485283109581435, 0.9358380951638248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 336}], {
             RGBColor[
             0.2184046627263886, 0.34688752655381927`, 0.9357491944902996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 367}], {
             RGBColor[
             0.2225587298907346, 0.35125371452661747`, 0.9359857624699174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 225}], {
             RGBColor[
             0.26388387983793327`, 0.3946890672869635, 0.9383391686243296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 241}], {
             RGBColor[
             0.2808108014657587, 0.41248033514662596`, 0.9393031317698977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 255}], {
             RGBColor[
             0.26556731627814384`, 0.3964584657216599, 0.9384350378391786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 288}], {
             RGBColor[
             0.25784282293400623`, 0.38833953345580596`, 0.9379951393705938]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 296}], {
             RGBColor[
             0.2860905976760283, 0.41802973572203384`, 0.939603808353314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 339}], {
             RGBColor[
             0.3182100783412779, 0.4465179661207665, 0.9416259763149808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 355}], {
             RGBColor[
             0.2507904105311417, 0.380927000871623, 0.9375935149173598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 360}], {
             RGBColor[
             0.29052568872167633`, 0.4225391392901483, 0.9398619514887643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 374}], {
             RGBColor[
             0.27338169058223005`, 0.4046718685752019, 0.9388800548954654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 375}], {
             RGBColor[
             0.26275249757312547`, 0.3934999127928718, 0.9382747380780788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 383}], {
             RGBColor[
             0.27544799036410295`, 0.4068436806569232, 0.9389977276112265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 399}], {
             RGBColor[
             0.2527693356026074, 0.3830069765928298, 0.9377062117726225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 210}], {
             RGBColor[
             0.2881749983278178, 0.42022057296569904`, 0.9397225118868391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 228}], {
             RGBColor[
             0.3221417320475673, 0.45045653149250003`, 0.9418569760468667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 236}], {
             RGBColor[
             0.26347424346046877`, 0.3942585134818019, 0.9383158404386357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 243}], {
             RGBColor[
             0.2823991194396881, 0.4141497580424017, 0.9393935841288071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 263}], {
             RGBColor[
             0.26925494850456955`, 0.4003344010010207, 0.9386450430391104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 348}], {
             RGBColor[
             0.2696907546749492, 0.40079246091779686`, 0.9386698615557961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 351}], {
             RGBColor[
             0.26108538890678307`, 0.3917476758837515, 0.9381797987057969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 214}], {
             RGBColor[
             0.9200563597791344, 0.7107376048071281, 0.556968147234525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 217}], {
             RGBColor[
             0.8395826476787889, 0.30525515205179155`, 0.18553769416040178`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 257}], {
             RGBColor[
             0.8394733977788387, 0.30441540944716294`, 0.18543307633282935`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 264}], {
             RGBColor[
             0.5231853201585595, 0.37556082624020004`, 0.5678587762898913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 268}], {
             RGBColor[
             0.836829312925746, 0.2840918146209231, 0.18290109769144122`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 279}], {
             RGBColor[
             0.9009946329017078, 0.6281412966873632, 0.2383554119012628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 300}], {
             RGBColor[
             0.873168201892003, 0.5137197571930974, 0.21575357463755512`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 306}], {
             RGBColor[
             0.913357870811167, 0.6728952265487068, 0.2705007142320376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 363}], {
             RGBColor[
             0.8594260597663401, 0.4513198993592995, 0.20428679439717456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 381}], {
             RGBColor[
             0.9247433274483484, 0.7127453819428937, 0.4824095946157798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 243}], {
             RGBColor[
             0.28988476393267687`, 0.4220176450218065, 0.9398198805086642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 258}], {
             RGBColor[
             0.2721654186176039, 0.4033934896242831, 0.9388107900063931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 284}], {
             RGBColor[
             0.26769783285159876`, 0.3986977737229138, 0.93855636760622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 348}], {
             RGBColor[
             0.277176399167938, 0.4086603478972015, 0.9390961579356532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 361}], {
             RGBColor[
             0.32351204834138475`, 0.4530276285511149, 0.941893609121445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 369}], {
             RGBColor[
             0.2744257623445868, 0.405769254195412, 0.9389395132377659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 392}], {
             RGBColor[
             0.26967339396164935`, 0.4007742137073859, 0.9386688728888566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 261}], {
             RGBColor[
             0.17918768478614402`, 0.3056679962386074, 0.9335158456129223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 295}], {
             RGBColor[
             0.21065717499813985`, 0.33874442573233643`, 0.9353079865255567]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 310}], {
             RGBColor[
             0.18075257528517846`, 0.3073127953728809, 0.9336049638117943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 345}], {
             RGBColor[
             0.1904371972329284, 0.3174919470804629, 0.9341564887046044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 389}], {
             RGBColor[
             0.17900756331513207`, 0.305478677152213, 0.9335055879616141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 400}], {
             RGBColor[
             0.2842689537951664, 0.40863855928315673`, 0.939773820202813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 207}], {
             RGBColor[
             0.967562165289962, 0.8957834071543473, 0.4992706546503005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 221}], {
             RGBColor[
             0.9585637141169614, 0.9664203575638242, 0.8602427231177231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 230}], {
             RGBColor[
             0.9820628725503424, 0.9494608486926688, 0.5307965926515668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 250}], {
             RGBColor[
             0.9917478646376758, 0.990855544204543, 0.7864227690028461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 276}], {
             RGBColor[
             0.8804173286055655, 0.9045483902483498, 0.8526723312886473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 358}], {
             RGBColor[
             0.9819225924478814, 0.9489876509677333, 0.5302516309431803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 391}], {
             RGBColor[
             0.9078296512801215, 0.575024774186147, 0.4476180378082022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 208}], {
             RGBColor[
             0.23232439396841398`, 0.3615180466511231, 0.9365419025921359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 258}], {
             RGBColor[
             0.24224766571092132`, 0.37194803442426605`, 0.9371070182377067]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 278}], {
             RGBColor[
             0.24198884677049953`, 0.37167599930781414`, 0.937092278881938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 284}], {
             RGBColor[
             0.23778007994491618`, 0.3672523185228967, 0.9368525958375336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 369}], {
             RGBColor[
             0.2445080094379043, 0.3743237989953949, 0.9372357414690795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 392}], {
             RGBColor[
             0.23975564105496683`, 0.3693287585073688, 0.9369651011201702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 221}], {
             RGBColor[
             0.9308573670898133, 0.869892342221664, 0.6314368519575342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 230}], {
             RGBColor[
             0.9543565255231943, 0.8529328333505086, 0.30199072149137773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 233}], {
             RGBColor[
             0.8786570254685007, 0.4672262975790694, 0.21740805642807715`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 250}], {
             RGBColor[
             0.9640415176105277, 0.8943275288623829, 0.5576168978426572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 358}], {
             RGBColor[
             0.9542162454207332, 0.8524596356255733, 0.30144575978299126`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 366}], {
             RGBColor[
             0.9205681319812286, 0.7219373884597544, 0.2549015531776194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 391}], {
             RGBColor[
             0.8801233042529734, 0.4784967588439868, 0.2188121666480132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[
             0.24300998977440907`, 0.3727492853491289, 0.9371504314653649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 278}], {
             RGBColor[
             0.24275117083398723`, 0.37247725023267697`, 0.9371356921095961]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 284}], {
             RGBColor[
             0.23854240400840393`, 0.3680535694477596, 0.9368960090651918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 369}], {
             RGBColor[
             0.24527033350139205`, 0.37512504992025775`, 0.9372791546967377]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 392}], {
             RGBColor[
             0.24051796511845452`, 0.3701300094322317, 0.9370085143478284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 227}], {
             RGBColor[
             0.24347750032410487`, 0.3732406685787401, 0.9371770554995502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 229}], {
             RGBColor[
             0.24946457527559712`, 0.37953346395523513`, 0.937518010560954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 240}], {
             RGBColor[
             0.24561974977362988`, 0.37549230857665095`, 0.9372990534365266]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 245}], {
             RGBColor[
             0.2409659187206967, 0.37060083707008695`, 0.9370340246427882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 280}], {
             RGBColor[
             0.24552309910713999`, 0.37539072259816386`, 0.9372935493240518]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 304}], {
             RGBColor[
             0.23556571159456763`, 0.3649248769876179, 0.9367264908358456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 315}], {
             RGBColor[
             0.24765360770529532`, 0.37763002221687225`, 0.9374148786369118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 319}], {
             RGBColor[
             0.24680833108244982`, 0.37674158289262827`, 0.9373667413837155]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 329}], {
             RGBColor[
             0.24358590725750107`, 0.37335461113913604`, 0.9371832291140334]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 334}], {
             RGBColor[
             0.2567160128781451, 0.387155184643212, 0.9379309692048785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 371}], {
             RGBColor[
             0.26203929742842424`, 0.3927502942212898, 0.9382341223849231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 236}], {
             RGBColor[
             0.27522295505597283`, 0.4066071542800159, 0.9389849121833385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 263}], {
             RGBColor[
             0.2810036601000736, 0.41268304179923465`, 0.9393141147838132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 301}], {
             RGBColor[
             0.25974755171345176`, 0.39034152416978307`, 0.9381036108567895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 328}], {
             RGBColor[
             0.2860571913279975, 0.41793071873950494`, 0.9396042457787188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 347}], {
             RGBColor[
             0.27136364126610246`, 0.4025507707922349, 0.9387651299723484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 372}], {
             RGBColor[
             0.257077351430105, 0.3875349743715093, 0.9379515469008601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 387}], {
             RGBColor[
             0.27812297420375887`, 0.4096552582761729, 0.939150063983611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 238}], {
             RGBColor[
             0.22006014114382055`, 0.3486275393339343, 0.9358434715371114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 259}], {
             RGBColor[
             0.2109589325174653, 0.33906159201767927`, 0.935325171169872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 293}], {
             RGBColor[
             0.2110641194014849, 0.3391721501020175, 0.935331161407307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 299}], {
             RGBColor[
             0.2125129386493282, 0.3406949509919467, 0.9354136695201356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 336}], {
             RGBColor[
             0.21095186783418274`, 0.3390541665876225, 0.9353247688466104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 367}], {
             RGBColor[
             0.21510593499852879`, 0.3434203545604207, 0.9355613368262283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 224}], {
             RGBColor[
             0.9433148110399261, 0.8071439818533458, 0.30358552172184644`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 230}], {
             RGBColor[
             0.939912673270707, 0.7956677722978341, 0.2903688589282392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 247}], {
             RGBColor[
             0.9089878266866289, 0.6768740913610367, 0.24562767290302676`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 250}], {
             RGBColor[
             0.9495976653580405, 0.8370624678097084, 0.5459950352795185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 289}], {
             RGBColor[
             0.9043607109741805, 0.6566643735845665, 0.24180812561664938`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 302}], {
             RGBColor[
             0.9491225739214294, 0.8267349297802298, 0.3261475838124945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 340}], {
             RGBColor[
             0.9523731210086097, 0.8369128200592044, 0.40569345010895497`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 391}], {
             RGBColor[
             0.8656794520004861, 0.4212316977913123, 0.20719030408487465`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 215}], {
             RGBColor[
             0.9015306453673441, 0.5683408458182889, 0.5392279021919928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 217}], {
             RGBColor[
             0.903299381606431, 0.5819361276170735, 0.5409216460120444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 261}], {
             RGBColor[
             0.5816107316395323, 0.6466802864248125, 0.9229413951560062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 264}], {
             RGBColor[
             0.5869020540862017, 0.6522418018054821, 0.9232427281415339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 295}], {
             RGBColor[
             0.6130802218515281, 0.6797567159185416, 0.9247335360686406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 300}], {
             RGBColor[
             0.9368849358196452, 0.7904007327583793, 0.5711375264891978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 310}], {
             RGBColor[
             0.5831756221385668, 0.6483250855590861, 0.9230305133548782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 363}], {
             RGBColor[
             0.9231427936939823, 0.7280008749245814, 0.5596707462488172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 217}], {
             RGBColor[
             0.8210569332669986, 0.16285839306295227`, 0.16779744911786956`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 269}], {
             RGBColor[
             0.9061735630089964, 0.5684125935804545, 0.32599457253607145`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 295}], {
             RGBColor[
             0.5308377735120957, 0.2606789813644203, 0.5516093391744658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 300}], {
             RGBColor[
             0.8546424874802127, 0.37132299820425807`, 0.1980133295950229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 352}], {
             RGBColor[
             0.906721166296464, 0.5695838616411621, 0.3855978109611532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 363}], {
             RGBColor[
             0.8409003453545498, 0.3089231403704602, 0.18654654935464235`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 219}], {
             RGBColor[
             0.5531447091768378, 0.647683896662048, 0.958186067610292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 220}], {
             RGBColor[
             0.5672680445778805, 0.6593163046949915, 0.9592519182010989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 311}], {
             RGBColor[
             0.5892378065656463, 0.6771523472031584, 0.9609814583426657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 323}], {
             RGBColor[
             0.7446559095096992, 0.8005327781235971, 0.9751620658441222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 339}], {
             RGBColor[
             0.5124310381777115, 0.6124197611712089, 0.9555918284959135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 357}], {
             RGBColor[
             0.6673958385373104, 0.7400939685523675, 0.9674834380828405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 268}], {
             RGBColor[
             0.8200723347530428, 0.15529033743086842`, 0.16685459646896056`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 269}], {
             RGBColor[
             0.9079422992480835, 0.582007875379239, 0.32768831635612294`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 279}], {
             RGBColor[
             0.8842376547290044, 0.4993398194973086, 0.22230891067878217`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 300}], {
             RGBColor[
             0.8564112237192996, 0.3849182800030426, 0.19970707341507446`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 306}], {
             RGBColor[
             0.8966008926384637, 0.5440937493586522, 0.25445421300955695`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 363}], {
             RGBColor[
             0.8426690815936368, 0.3225184221692448, 0.1882402931746939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 262}], {
             RGBColor[
             0.9243533171861171, 0.9424423464401257, 0.9900148507220045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 269}], {
             RGBColor[
             0.9515613514707596, 0.9593431212476458, 0.7385846645144882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 279}], {
             RGBColor[
             0.9278567069516805, 0.8766750653657154, 0.6332052588371474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 298}], {
             RGBColor[
             0.8667469534105012, 0.8965845097029781, 0.9871522922420749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.9000302759419758, 0.7622535258714493, 0.6106034215734397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 306}], {
             RGBColor[
             0.9402199448611399, 0.9214289952270589, 0.6653505611679222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 314}], {
             RGBColor[
             0.9179378774680893, 0.9374027630058823, 0.9920349282773651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 220}], {
             RGBColor[
             0.4613111794873067, 0.5733857750910603, 0.9507812424766675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 241}], {
             RGBColor[
             0.36907489621161843`, 0.49245160059313714`, 0.9447983082263991]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 311}], {
             RGBColor[
             0.48328094147507245`, 0.5912218175992272, 0.9525107826182344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 323}], {
             RGBColor[
             0.6386990444191253, 0.7146022485196659, 0.9666913901196909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 339}], {
             RGBColor[
             0.4064741730871376, 0.5264892315672777, 0.9471211527714821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 357}], {
             RGBColor[
             0.5614389734467367, 0.6541634389484363, 0.9590127623584092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 360}], {
             RGBColor[
             0.37878978346753606`, 0.5025104047366595, 0.9453571279452656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 350}], {
             RGBColor[
             0.454088632793754, 0.5671299681608568, 0.9503210281880017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 357}], {
             RGBColor[
             0.5755623088477795, 0.6657958469813797, 0.960078612949216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 394}], {
             RGBColor[
             0.4171512331180811, 0.5351366490894776, 0.9479674097431279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 230}], {
             RGBColor[
             0.9453580743501937, 0.9235697837599854, 0.6629627899588003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 250}], {
             RGBColor[
             0.955043066437527, 0.9649644792718597, 0.9185889663100797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 276}], {
             RGBColor[
             0.8437125304054167, 0.8786573253156666, 0.9848385285958808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 358}], {
             RGBColor[
             0.9452177942477327, 0.9230965860350502, 0.6624178282504138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 251}], {
             RGBColor[
             0.7136213718875605, 0.7756511419302459, 0.9724778106511085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 297}], {
             RGBColor[
             0.7757829604608912, 0.8249349923236523, 0.9686258035292561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 312}], {
             RGBColor[
             0.5339420376563727, 0.632517225840949, 0.9564530195798908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 332}], {
             RGBColor[
             0.5660742539559687, 0.6586036065728093, 0.9589825853511816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 356}], {
             RGBColor[
             0.5616526527416191, 0.6550139515161355, 0.9586345007067291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 361}], {
             RGBColor[
             0.48027671073484357`, 0.5862967431545993, 0.9529611966752556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 260}], {
             RGBColor[
             0.6315106131402652, 0.7091757673875206, 0.9658788076150083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 267}], {
             RGBColor[
             0.5126330687833186, 0.6152176449516955, 0.954775499492879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 272}], {
             RGBColor[
             0.5505420601979628, 0.6459225184451997, 0.9578086189518668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 290}], {
             RGBColor[
             0.4296004547734099, 0.5464997120753861, 0.9486003596365518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 291}], {
             RGBColor[
             0.5752793861727824, 0.6652475055073694, 0.9602742044215822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 321}], {
             RGBColor[
             0.6359268279774656, 0.7126257479828174, 0.9663189746381065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 331}], {
             RGBColor[
             0.45307983116767014`, 0.5668363678003234, 0.9500964447383967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 342}], {
             RGBColor[
             0.5287126959381665, 0.6282718106549494, 0.9560413466441238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 346}], {
             RGBColor[
             0.3995496021231435, 0.5204711739094963, 0.9466855458786024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 384}], {
             RGBColor[
             0.6012475155961567, 0.6855340055780029, 0.9628624648765374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 398}], {
             RGBColor[
             0.696746297429305, 0.7610076864937902, 0.9687930758283795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 230}], {
             RGBColor[
             0.9722593705527938, 0.9180864844443417, 0.3467333222862512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 247}], {
             RGBColor[
             0.9413345239687156, 0.7992928035075443, 0.30199213626103877`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 289}], {
             RGBColor[
             0.9367074082562672, 0.779083085731074, 0.29817258897466137`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 302}], {
             RGBColor[
             0.981469271203516, 0.9491536419267372, 0.38251204717050646`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 323}], {
             RGBColor[
             0.9029358765369997, 0.8985069119905342, 0.6718086867166897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 340}], {
             RGBColor[
             0.9847198182906963, 0.959331532205712, 0.46205791346696695`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 288}], {
             RGBColor[
             0.25106704817739506`, 0.3812177645776751, 0.9376092690220652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 296}], {
             RGBColor[
             0.2793148229194171, 0.41090796684390285`, 0.9392179380047856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 316}], {
             RGBColor[
             0.2556938059368381, 0.38608078033623494`, 0.9378727560317908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 324}], {
             RGBColor[
             0.2685328797360218, 0.39957546094347285`, 0.9386039222909468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 355}], {
             RGBColor[
             0.24401463577453056`, 0.373805231993492, 0.9372076445688313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 375}], {
             RGBColor[
             0.2559767228165143, 0.3863781439147409, 0.9378888677295503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 380}], {
             RGBColor[
             0.2612993849996442, 0.39197259934548456`, 0.9381919854667065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 383}], {
             RGBColor[
             0.26867221560749177`, 0.39972191177879235`, 0.938611857262698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 390}], {
             RGBColor[
             0.26170368970244295`, 0.3923975492225247, 0.9382150100214157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 255}], {
             RGBColor[
             0.24955450248561023`, 0.3796279831546734, 0.9375231317825289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 266}], {
             RGBColor[
             0.24681597923856835`, 0.37674962158963, 0.9373671769348919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 294}], {
             RGBColor[
             0.22569678935260098`, 0.35455201398550057`, 0.9361644703139277]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 341}], {
             RGBColor[
             0.23010886985563692`, 0.3591893903362524, 0.9364157317714874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 368}], {
             RGBColor[
             0.2257077662103317, 0.35456355135894857`, 0.9361650954297367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 393}], {
             RGBColor[
             0.2307270128999809, 0.3598390978683905, 0.9364509341034022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 399}], {
             RGBColor[
             0.23675652181007376`, 0.36617649402584324`, 0.9367943057159729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 280}], {
             RGBColor[
             0.23696761026347307`, 0.36639836137414694`, 0.9368063268911165]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 304}], {
             RGBColor[
             0.22701022275090071`, 0.35593251576360085`, 0.9362392684029103]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 315}], {
             RGBColor[
             0.2390981188616284, 0.3686376609928552, 0.9369276562039764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 243}], {
             RGBColor[
             0.3281145647549416, 0.45673435736741674`, 0.9421971200335375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 332}], {
             RGBColor[
             0.44753939238477464`, 0.5600512043149352, 0.9502922373222444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 348}], {
             RGBColor[
             0.31540619999020275`, 0.44337706024281187`, 0.9414733974605265]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 361}], {
             RGBColor[
             0.3617418491636495, 0.4877443408967252, 0.9442708486463184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 385}], {
             RGBColor[
             0.4716391113259436, 0.5796164418313421, 0.9521894554774726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 240}], {
             RGBColor[
             0.24305133588145522`, 0.372792742729129, 0.9371527860649951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 245}], {
             RGBColor[
             0.238397504828522, 0.36790127122256505`, 0.9368877572712566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 248}], {
             RGBColor[
             0.2315520252069328, 0.36070623811179847`, 0.9364979173337866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 249}], {
             RGBColor[
             0.2582327214414536, 0.38874934150812634`, 0.9380173435137897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 309}], {
             RGBColor[
             0.25884330525935606`, 0.3893911038139919, 0.9380521153589414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 315}], {
             RGBColor[
             0.24508519381312066`, 0.3749304563693503, 0.9372686112653803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 319}], {
             RGBColor[
             0.24423991719027513`, 0.3740420170451063, 0.9372204740121839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[
             0.2410174933653264, 0.37065504529161414`, 0.937036961742502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 334}], {
             RGBColor[
             0.25414759898597045`, 0.3844556187956901, 0.9377847018333471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 371}], {
             RGBColor[
             0.25947088353624953`, 0.3900507283737679, 0.9380878550133916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 388}], {
             RGBColor[
             0.23513063549537086`, 0.3644675844219441, 0.9367017138956337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 247}], {
             RGBColor[
             0.9379323861994966, 0.7878165939520326, 0.28877547346743154`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 250}], {
             RGBColor[
             0.9785422248709081, 0.9480049704007043, 0.5891428358439234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 289}], {
             RGBColor[
             0.9333052704870481, 0.7676068761755623, 0.28495592618105414`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 358}], {
             RGBColor[
             0.9687169526811137, 0.9061370771638947, 0.3329716977842575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 391}], {
             RGBColor[
             0.8946240115133538, 0.5321742003823082, 0.2503381046492794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 234}], {
             RGBColor[
             0.3237117587462526, 0.454798867157554, 0.9418478143825956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 290}], {
             RGBColor[
             0.3569089205700484, 0.48355258019145775`, 0.9439631081789103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 313}], {
             RGBColor[
             0.295746238547153, 0.4281784264805763, 0.9401536828166841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 331}], {
             RGBColor[
             0.38038829696430865`, 0.5038892359163952, 0.9454591932807552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 359}], {
             RGBColor[
             0.2771261222266016, 0.4086075036441148, 0.9390932947382222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 235}], {
             RGBColor[
             0.6328251607154107, 0.7112978291642651, 0.965261084970727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 281}], {
             RGBColor[
             0.5787753460534887, 0.6689149253152545, 0.9599824618467317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 384}], {
             RGBColor[
             0.6369922413654878, 0.7145531842390913, 0.965676420626344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 386}], {
             RGBColor[
             0.4324598922567031, 0.5470353068857565, 0.9493188938960907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 242}], {
             RGBColor[
             0.867902536299588, 0.4245883317454004, 0.20875474200246447`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 317}], {
             RGBColor[
             0.9040426479180714, 0.5627946336685001, 0.48467433968140694`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 358}], {
             RGBColor[
             0.8930174526264201, 0.5204305413924555, 0.24838903272095686`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 366}], {
             RGBColor[
             0.8593693391869154, 0.3899082942266366, 0.20184482611558502`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 382}], {
             RGBColor[
             0.8581195774771997, 0.3842334181920808, 0.20080199431053547`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 290}], {
             RGBColor[
             0.37193655540902126`, 0.4965744830456317, 0.9449204463134487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 313}], {
             RGBColor[
             0.3107738733861259, 0.4412003293347502, 0.9411110209512226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 331}], {
             RGBColor[
             0.3954159318032815, 0.5169111387705692, 0.9464165314152937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 342}], {
             RGBColor[
             0.47104879657377785`, 0.578346581625195, 0.9523614333210206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 346}], {
             RGBColor[
             0.34188570275875485`, 0.4705459448797419, 0.9430056325554994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 275}], {
             RGBColor[
             0.8660971591696807, 0.893943749566336, 0.8776528174795629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 281}], {
             RGBColor[
             0.6860438629162344, 0.7545031690861064, 0.9694506561545053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 384}], {
             RGBColor[
             0.7442607582282336, 0.800141428009943, 0.9751446149341176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 263}], {
             RGBColor[
             0.2563029052327246, 0.3867209823153376, 0.9379074433356098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 351}], {
             RGBColor[
             0.2481333456349381, 0.37813425719806837`, 0.9374421990022963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 246}], {
             RGBColor[
             0.5111109439056949, 0.6137235569467266, 0.9547270574586124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 254}], {
             RGBColor[
             0.5239652108029346, 0.6244175883504002, 0.9556676072236672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 286}], {
             RGBColor[
             0.652334455595527, 0.7273484229582274, 0.9666519351718024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 320}], {
             RGBColor[
             0.644156525821959, 0.7209597620645476, 0.9658368355590718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 343}], {
             RGBColor[
             0.6503098019378368, 0.7257667481329021, 0.9664501366166679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 349}], {
             RGBColor[
             0.5118990860533059, 0.6144062060618112, 0.9547772771793315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 252}], {
             RGBColor[
             0.22677811637454098`, 0.3556885572456525, 0.9362260502881472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 277}], {
             RGBColor[
             0.24351796868213066`, 0.3732832033888673, 0.9371793601126722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 287}], {
             RGBColor[
             0.24471825055354252`, 0.3745447757379873, 0.9372477143895912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 293}], {
             RGBColor[
             0.22022708573500543`, 0.3488030086841681, 0.935852978784607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 299}], {
             RGBColor[
             0.22167590498284873`, 0.3503258095740973, 0.9359354868974357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 336}], {
             RGBColor[
             0.22011483416770328`, 0.34868502516977307`, 0.9358465862239105]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 367}], {
             RGBColor[
             0.2242689013320493, 0.35305121314257126`, 0.9360831542035284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 396}], {
             RGBColor[
             0.25376131131834845`, 0.3840496059649667, 0.9377627033221374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 271}], {
             RGBColor[
             0.31565140111640955`, 0.4476420700773734, 0.9413406348615612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 326}], {
             RGBColor[
             0.3319525774457105, 0.4619423709869775, 0.94237270259407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 335}], {
             RGBColor[
             0.3025165492814234, 0.4338365080010965, 0.9405926244808307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 337}], {
             RGBColor[
             0.304629125717821, 0.43605695978083275`, 0.9407129325836068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 354}], {
             RGBColor[
             0.3021441775416652, 0.43344512169287874`, 0.940571418461126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 245}], {
             RGBColor[
             0.2345526793265548, 0.3638601158439808, 0.9366688001468292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 248}], {
             RGBColor[
             0.22770719970496556`, 0.3566650827332143, 0.9362789602093593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 292}], {
             RGBColor[
             0.2251125947151853, 0.3539379883814973, 0.9361312012935654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 304}], {
             RGBColor[
             0.22915247220042573`, 0.35818415576151175`, 0.9363612663398866]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 309}], {
             RGBColor[
             0.2549984797573888, 0.3853499484354077, 0.9378331582345141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 315}], {
             RGBColor[
             0.24124036831115342`, 0.3708893009907661, 0.9370496541409528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 319}], {
             RGBColor[
             0.24039509168830792`, 0.37000086166652213`, 0.9370015168877566]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 329}], {
             RGBColor[
             0.23717266786335917`, 0.3666138899130299, 0.9368180046180745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 334}], {
             RGBColor[
             0.2503027734840032, 0.3804144634171059, 0.9375657447089196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 371}], {
             RGBColor[
             0.2556260580342823, 0.3860095729951837, 0.9378688978889642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 388}], {
             RGBColor[
             0.23128580999340365`, 0.36042642904335986`, 0.9364827567712063]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 255}], {
             RGBColor[
             0.2757184631493581, 0.40712796470319146`, 0.9390131306362182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 288}], {
             RGBColor[
             0.2679939698052205, 0.39900903243733754`, 0.9385732321676334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 339}], {
             RGBColor[
             0.32836122521249217`, 0.457187465102298, 0.9422040691120204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 360}], {
             RGBColor[
             0.3006768355928906, 0.4332086382716799, 0.9404400442858039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 374}], {
             RGBColor[
             0.2835328374534444, 0.4153413675567334, 0.939458147692505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 375}], {
             RGBColor[
             0.2729036444443398, 0.40416941177440335`, 0.9388528308751185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 399}], {
             RGBColor[
             0.2629204824738216, 0.3936764755743613, 0.938284304569662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 256}], {
             RGBColor[
             0.5718276027056971, 0.5340616080097416, 0.5946502523941279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 257}], {
             RGBColor[
             0.8704770048155868, 0.4443768248986645, 0.21122005596083127`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 268}], {
             RGBColor[
             0.8678329199624942, 0.4240532300724246, 0.2086880773194431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 317}], {
             RGBColor[
             0.954486951543472, 0.8521857620679489, 0.5290777523178287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 333}], {
             RGBColor[
             0.5569536477379948, 0.5184281382754727, 0.5938032026627618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 381}], {
             RGBColor[
             0.9557469344850966, 0.8527067973943953, 0.5081965742437817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 382}], {
             RGBColor[
             0.9085638811026002, 0.6736245465915296, 0.24520540694695725`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 348}], {
             RGBColor[
             0.27566358738232355`, 0.40707028679271356`, 0.9390100055424669]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 351}], {
             RGBColor[
             0.26705822161415743`, 0.39802550175866824`, 0.9385199426924677]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 253}], {
             RGBColor[
             0.30087597692201773`, 0.4305218254587764, 0.9405574263390588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 270}], {
             RGBColor[
             0.2548116613836774, 0.3851535904796679, 0.9378225192045042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 308}], {
             RGBColor[
             0.2605622771689302, 0.3911978522800683, 0.9381500082662007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 397}], {
             RGBColor[
             0.2546928621186111, 0.3850287249197748, 0.9378157537621064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 248}], {
             RGBColor[
             0.2230533686520324, 0.3517736112266503, 0.9360139314156208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 292}], {
             RGBColor[
             0.2204587636622521, 0.3490465168749334, 0.935866172499827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 304}], {
             RGBColor[
             0.22449864114749254`, 0.35329268425494775`, 0.9360962375461481]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 315}], {
             RGBColor[
             0.23658653725822024`, 0.3659978294842021, 0.9367846253472143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 319}], {
             RGBColor[
             0.2357412606353747, 0.36510939015995814`, 0.9367364880940181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 329}], {
             RGBColor[
             0.232518836810426, 0.36172241840646596`, 0.936552975824336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 353}], {
             RGBColor[
             0.220139248365585, 0.34871068603969635`, 0.9358479765763623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 371}], {
             RGBColor[
             0.25097222698134913`, 0.38111810148861974`, 0.9376038690952258]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 378}], {
             RGBColor[
             0.2192126419789341, 0.3477367639770881, 0.9357952077134337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 388}], {
             RGBColor[
             0.22663197894047044`, 0.3555349575367959, 0.9362177279774678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 254}], {
             RGBColor[
             0.4566571232556863, 0.569515492226385, 0.9504402532261262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 286}], {
             RGBColor[
             0.5850263680482788, 0.6724463268342122, 0.9614245811742612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 320}], {
             RGBColor[
             0.5768484382747107, 0.6660576659405324, 0.9606094815615308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 343}], {
             RGBColor[
             0.5830017143905886, 0.6708646520088869, 0.9612227826191269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 344}], {
             RGBColor[
             0.3822157528613575, 0.505477807231359, 0.9455754276855741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 349}], {
             RGBColor[
             0.44459099850605766`, 0.559504109937796, 0.9495499231817904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 289}], {
             RGBColor[
             0.9023804239029701, 0.648813195238765, 0.2402147401558417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 302}], {
             RGBColor[
             0.9471422868502191, 0.8188837514344283, 0.3245541983516868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 340}], {
             RGBColor[
             0.9503928339373993, 0.8290616417134029, 0.4041000646481473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 391}], {
             RGBColor[
             0.8636991649292758, 0.4133805194455108, 0.20559691862406698`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 292}], {
             RGBColor[
             0.21361328404066288`, 0.34185148376416674`, 0.935476332562357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 304}], {
             RGBColor[
             0.2176531615259033, 0.3460976511441812, 0.9357063976086782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 315}], {
             RGBColor[
             0.229741057636631, 0.35880279637343554`, 0.9363947854097444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 319}], {
             RGBColor[
             0.2288957810137855, 0.3579143570491916, 0.9363466481565481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 329}], {
             RGBColor[
             0.22567335718883677`, 0.3545273852956994, 0.9361631358868661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 353}], {
             RGBColor[
             0.21329376874399575`, 0.34151565292892977`, 0.9354581366388923]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 388}], {
             RGBColor[
             0.21978649931888122`, 0.34833992442602935`, 0.935827888039998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 270}], {
             RGBColor[
             0.25957821450255336`, 0.3901635400245296, 0.9380939673531408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 308}], {
             RGBColor[
             0.2653288302878062, 0.39620780182492993`, 0.9384214564148372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 309}], {
             RGBColor[
             0.2701798653173872, 0.40130654721440506`, 0.9386977156833087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 334}], {
             RGBColor[
             0.2654841590440016, 0.39637106219610324`, 0.9384303021577143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 386}], {
             RGBColor[
             0.3044662110801129, 0.4345129066433197, 0.9407539204836926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 397}], {
             RGBColor[
             0.25945941523748706`, 0.39003867446463636`, 0.938087201910743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 265}], {
             RGBColor[
             0.7900609571838799, 0.8344827358393506, 0.9028921387192244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 276}], {
             RGBColor[
             0.8768966809261312, 0.9030925119563854, 0.9110185744810039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 289}], {
             RGBColor[
             0.9429902625743816, 0.8090015716874366, 0.5405821025323335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 391}], {
             RGBColor[
             0.9043090036006871, 0.5735688958941825, 0.5059642810005588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 282}], {
             RGBColor[
             0.7345888082776114, 0.7926044746200289, 0.9741756038265081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 312}], {
             RGBColor[
             0.6426365090387243, 0.7180224324379316, 0.9668896222215277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 356}], {
             RGBColor[
             0.6703471241239707, 0.7405191581131181, 0.9690711033483659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 277}], {
             RGBColor[
             0.2410729775793306, 0.3707133627184349, 0.9370401214864079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 293}], {
             RGBColor[
             0.21778209463220533`, 0.3462331680137357, 0.9357137401583427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 330}], {
             RGBColor[
             0.2245525377985933, 0.3533493330524997, 0.9360993068806954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 386}], {
             RGBColor[
             0.3405394596215219, 0.4693798967384182, 0.942919851133231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 286}], {
             RGBColor[
             0.5978806349455185, 0.6831403582378857, 0.9623651309393161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 320}], {
             RGBColor[
             0.5897027051719504, 0.6767516973442059, 0.9615500313265857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 343}], {
             RGBColor[
             0.5958559812878284, 0.6815586834125604, 0.9621633323841816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 344}], {
             RGBColor[
             0.39507001975859724`, 0.5161718386350326, 0.946515977450629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 349}], {
             RGBColor[
             0.45744526540329744`, 0.5701981413414695, 0.9504904729468453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 288}], {
             RGBColor[
             0.25275048461760563`, 0.38298716301237146`, 0.9377051382369141]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 341}], {
             RGBColor[
             0.24102934533176992`, 0.3706675024598044, 0.9370376366944575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 360}], {
             RGBColor[
             0.28543335040527573`, 0.4171867688467138, 0.9395719503550848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 374}], {
             RGBColor[
             0.2682893522658295, 0.3993194981317673, 0.938590053761786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 393}], {
             RGBColor[
             0.2416474883761139, 0.3713172099919425, 0.9370728390263723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 399}], {
             RGBColor[
             0.24767699728620676`, 0.3776546061493952, 0.937416210638943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 261}], {
             RGBColor[
             0.20237836752934693`, 0.3300428741759244, 0.934836520687607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 264}], {
             RGBColor[
             0.2076696899760163, 0.3356043895565939, 0.9351378536731348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 317}], {
             RGBColor[
             0.6079677143241806, 0.6722679099328412, 0.8705698500730703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 333}], {
             RGBColor[
             0.21043441051870343`, 0.338510286140365, 0.9352953004180034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 381}], {
             RGBColor[
             0.6092276972658053, 0.6727889452592876, 0.8496886719990233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 268}], {
             RGBColor[
             0.8199630848530925, 0.15445059482623982`, 0.16674997864138813`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 338}], {
             RGBColor[
             0.9084477718580719, 0.5824829620653897, 0.3944924501077937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 381}], {
             RGBColor[
             0.9078770993756948, 0.5831041621482105, 0.46625847556572675`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 382}], {
             RGBColor[
             0.8606940459931985, 0.4040219113453448, 0.20326730826890227`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 278}], {
             RGBColor[
             0.25267444257649463`, 0.38290723800581994`, 0.937700807755167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 284}], {
             RGBColor[
             0.24846567575091127`, 0.3784835572209025, 0.9374611247107626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 369}], {
             RGBColor[
             0.2551936052438994, 0.3855550376934007, 0.9378442703423086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 392}], {
             RGBColor[
             0.25044123686096187`, 0.3805599972053746, 0.9375736299933992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 274}], {
             RGBColor[
             0.22087433163626, 0.34948330516414705`, 0.9358898384811689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 299}], {
             RGBColor[
             0.21257469635649348`, 0.34075986225784227`, 0.9354171865301963]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 318}], {
             RGBColor[
             0.2174190793227137, 0.34585161590696, 0.9356930669735002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 336}], {
             RGBColor[
             0.21101362554134806`, 0.339119077853518, 0.9353282858566712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 367}], {
             RGBColor[
             0.21516769270569408`, 0.3434852658263162, 0.935564853836289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 267}], {
             RGBColor[
             0.6900764896095811, 0.7567221842679797, 0.9704893279445472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 272}], {
             RGBColor[
             0.7279854810242253, 0.7874270577614837, 0.9735224474035349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 291}], {
             RGBColor[
             0.7527228069990448, 0.8067520448236535, 0.9759880328732503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 321}], {
             RGBColor[
             0.813370248803728, 0.8541302872991015, 0.9820328030897745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 338}], {
             RGBColor[
             0.9016212039882432, 0.9204360205910522, 0.8006477894997438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 342}], {
             RGBColor[
             0.706156116764429, 0.7697763499712335, 0.9717551750957918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 384}], {
             RGBColor[
             0.7786909364224193, 0.827038544894287, 0.9785762933282055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 398}], {
             RGBColor[
             0.8741897182555676, 0.9025122258100744, 0.9845069042800476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 264}], {
             RGBColor[
             0.1847396920189574, 0.3115035078578844, 0.9338320242113725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 295}], {
             RGBColor[
             0.2109178597842839, 0.3390184219709439, 0.935322832138479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 310}], {
             RGBColor[
             0.18101326007132248`, 0.3075867916114884, 0.9336198094247166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 381}], {
             RGBColor[
             0.5862976993087463, 0.6486880635605781, 0.8483828425372609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 269}], {
             RGBColor[
             0.965850894705439, 0.9706613010892211, 0.7373156259818411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 298}], {
             RGBColor[
             0.8810364966451805, 0.9079026895445534, 0.9858832537094278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 300}], {
             RGBColor[
             0.9143198191766551, 0.7735717057130247, 0.6093343830407926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 306}], {
             RGBColor[
             0.9545094880958191, 0.9327471750686342, 0.664081522635275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 307}], {
             RGBColor[
             0.9619414175862754, 0.970962445386637, 0.9415105792405329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 314}], {
             RGBColor[
             0.9322274207027686, 0.9487209428474576, 0.9907658897447179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 310}], {
             RGBColor[
             0.18630458251799184`, 0.3131483069921579, 0.9339211424102444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 333}], {
             RGBColor[
             0.19279573500831393`, 0.31997091982232506`, 0.9342908039417687]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 381}], {
             RGBColor[
             0.5915890217554157, 0.6542495789412477, 0.8486841755227887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 322}], {
             RGBColor[
             0.5501554119867256, 0.6456799735265193, 0.9577293957987232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 362}], {
             RGBColor[
             0.4982768620774518, 0.6022414244020411, 0.9540103792474512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 273}], {
             RGBColor[
             0.265217664230201, 0.3960909592500517, 0.938415125672312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 365}], {
             RGBColor[
             0.25561932448523794`, 0.3860024956082064, 0.9378685144233075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 272}], {
             RGBColor[
             0.6091079366672787, 0.6934689353256587, 0.9624191392814057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 291}], {
             RGBColor[
             0.6338452626420983, 0.7127939223878283, 0.964884724751121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 321}], {
             RGBColor[
             0.6944927044467815, 0.7601721648632764, 0.9709294949676452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 331}], {
             RGBColor[
             0.511645707636986, 0.6143827846807824, 0.9547069650679356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 342}], {
             RGBColor[
             0.5872785724074823, 0.6758182275354083, 0.9606518669736626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 346}], {
             RGBColor[
             0.4581154785924594, 0.5680175907899552, 0.9512960662081413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 384}], {
             RGBColor[
             0.6598133920654725, 0.7330804224584619, 0.9674729852060762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 398}], {
             RGBColor[
             0.7553121738986209, 0.8085541033742493, 0.9734035961579184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 338}], {
             RGBColor[
             0.9058036870049794, 0.5621593672391498, 0.39196047146640556`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 381}], {
             RGBColor[
             0.9052330145226024, 0.5627805673219706, 0.46372649692433865`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 279}], {
             RGBColor[
             0.9693542844710024, 0.9048940200148108, 0.380506034096984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 298}], {
             RGBColor[
             0.908244530929823, 0.9248034643520736, 0.7344530675019115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 300}], {
             RGBColor[
             0.9415278534612976, 0.7904724805205449, 0.35790419683327634`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 306}], {
             RGBColor[
             0.9817175223804617, 0.9496479498761543, 0.4126513364277588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 307}], {
             RGBColor[
             0.9891494518709179, 0.9878632201941573, 0.6900803930330166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 314}], {
             RGBColor[
             0.9594354549874111, 0.9656217176549777, 0.7393357035372017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 308}], {
             RGBColor[
             0.2553377632908749, 0.38570655694091993`, 0.9378524799298211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 397}], {
             RGBColor[
             0.2494683482405557, 0.3795374295806264, 0.9375182254257268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 273}], {
             RGBColor[
             0.2911126400044641, 0.42330822062509427`, 0.9398898062344726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 326}], {
             RGBColor[
             0.3230890593454866, 0.4540841958078278, 0.941814555867055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 335}], {
             RGBColor[
             0.2936530311811995, 0.4259783328219468, 0.9400344777538158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 394}], {
             RGBColor[
             0.3328279171819992, 0.4625195049765876, 0.9424351072766638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 291}], {
             RGBColor[
             0.6717542540567425, 0.7434987958813325, 0.9679178442101087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 321}], {
             RGBColor[
             0.7324016958614257, 0.7908770383567805, 0.9739626144266329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 331}], {
             RGBColor[
             0.5495546990516302, 0.6450876581742866, 0.9577400845269233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 338}], {
             RGBColor[
             0.8206526510459409, 0.8571827716487312, 0.7925776008366022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 342}], {
             RGBColor[
             0.6251875638221265, 0.7065231010289125, 0.9636849864326502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 346}], {
             RGBColor[
             0.4960244700071036, 0.5987224642834593, 0.954329185667129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 384}], {
             RGBColor[
             0.6977223834801167, 0.763785295951966, 0.9705061046650639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 398}], {
             RGBColor[
             0.7932211653132651, 0.8392589768677534, 0.976436715616906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 365}], {
             RGBColor[
             0.26583905724777945`, 0.3967440827101195, 0.9384505130853945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 394}], {
             RGBColor[
             0.3171526741702776, 0.4460438307034582, 0.9415424253765902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 287}], {
             RGBColor[
             0.2454706833388167, 0.37533563030230443`, 0.937290564323588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 299}], {
             RGBColor[
             0.22242833776812287`, 0.35111666413841447`, 0.9359783368314325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 318}], {
             RGBColor[
             0.2272727207343431, 0.3562084177875322, 0.9362542172747363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 367}], {
             RGBColor[
             0.22502133411732347`, 0.3538420677068884, 0.9361260041375251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 373}], {
             RGBColor[
             0.24052488712014738`, 0.3701372848948911, 0.9370089085455846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 395}], {
             RGBColor[
             0.2518980358087536, 0.3820911852658918, 0.9376565925383351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 279}], {
             RGBColor[
             0.9688751403565641, 0.9066136951652177, 0.5278514920501343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 281}], {
             RGBColor[
             0.8120473445077586, 0.8515608457173255, 0.8723741943555676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 306}], {
             RGBColor[
             0.9812383782660234, 0.9513676250265612, 0.559996794380909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 338}], {
             RGBColor[
             0.9931945073855819, 0.9905965803379274, 0.7001396493067182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 384}], {
             RGBColor[
             0.8702642398197578, 0.8971991046411623, 0.8780681531351799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 322}], {
             RGBColor[
             0.6369911357289768, 0.7142897496435541, 0.9658558315605028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 358}], {
             RGBColor[
             0.8670714087363368, 0.8612246187195758, 0.654847436421338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 376}], {
             RGBColor[
             0.6019797217390458, 0.6854606658855094, 0.9632115739949887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 377}], {
             RGBColor[
             0.590222766132432, 0.6752773818608311, 0.9624624311800029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 287}], {
             RGBColor[
             0.25901311175833214`, 0.3895695812107696, 0.9380617855878519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 330}], {
             RGBColor[
             0.24129239010618297`, 0.3709439791957144, 0.9370526167052204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 396}], {
             RGBColor[
             0.26805617252313807`, 0.399074411437749, 0.9385767745203981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 284}], {
             RGBColor[
             0.24820685681048946`, 0.3782115221044505, 0.9374463853549939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 327}], {
             RGBColor[
             0.28550387867049365`, 0.4165027145117478, 0.9396037276662406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 337}], {
             RGBColor[
             0.26857947792754067`, 0.39962443859725516`, 0.9386065759890179]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 354}], {
             RGBColor[
             0.2660945297513849, 0.3970126005093012, 0.9384650618665371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 392}], {
             RGBColor[
             0.2501824179205401, 0.3802879620889227, 0.9375588906376304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 300}], {
             RGBColor[
             0.9178232089422185, 0.7078044246386144, 0.2525247911559355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 306}], {
             RGBColor[
             0.9580128778613826, 0.8669798939942239, 0.307271930750418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 363}], {
             RGBColor[
             0.9040810668165558, 0.6454045668048165, 0.24105801091555495`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 384}], {
             RGBColor[
             0.6902109435663115, 0.7577585241609326, 0.9698659918101223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 386}], {
             RGBColor[
             0.4856785944575267, 0.5902406468075978, 0.9535084650798691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 350}], {
             RGBColor[
             0.5398022619922347, 0.6366471769552697, 0.9571158788344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 369}], {
             RGBColor[
             0.25072601947789425`, 0.3808593217920313, 0.9375898479421354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 392}], {
             RGBColor[
             0.24597365109495675`, 0.3758642813040053, 0.9373192075932261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 330}], {
             RGBColor[
             0.23174352854992997`, 0.3609075202673017, 0.9365088231658666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 387}], {
             RGBColor[
             0.2661419288540897, 0.3970624199715206, 0.9384677611753156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 320}], {
             RGBColor[
             0.7180719499645429, 0.7796825319520332, 0.9725343592747207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 343}], {
             RGBColor[
             0.7242252260804207, 0.7844895180203877, 0.9731476603323168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 349}], {
             RGBColor[
             0.5858145101958898, 0.6731289759492968, 0.9614748008949803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 367}], {
             RGBColor[
             0.23976404440825078`, 0.3693375909644736, 0.936965579678708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 373}], {
             RGBColor[
             0.2552675974110747, 0.3856328081524763, 0.9378484840867676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 395}], {
             RGBColor[
             0.2666407460996809, 0.397586708523477, 0.938496168079518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 396}], {
             RGBColor[
             0.2692564543945499, 0.400335983786869, 0.9386451287973171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 341}], {
             RGBColor[
             0.2333048519876323, 0.3625485701939505, 0.9365977382258728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 355}], {
             RGBColor[
             0.2379735788706035, 0.36745569816233453`, 0.9368636153150954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 360}], {
             RGBColor[
             0.2777088570611381, 0.4090678365808599, 0.9391320518865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 374}], {
             RGBColor[
             0.26056485892169184`, 0.3912005658659134, 0.9381501552932011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 375}], {
             RGBColor[
             0.24993566591258726`, 0.38002861008358335`, 0.9375448384758145]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 379}], {
             RGBColor[
             0.23299167582952007`, 0.3622194021952592, 0.9365799033069708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 393}], {
             RGBColor[
             0.23392299503197628`, 0.3631982777260886, 0.9366329405577875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 399}], {
             RGBColor[
             0.23995250394206913`, 0.3695356738835413, 0.9369763121703581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 302}], {
             RGBColor[
             0.9425151711377706, 0.798674033657958, 0.3207346510653094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 340}], {
             RGBColor[
             0.9457657182249508, 0.8088519239369327, 0.40028051736176995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 391}], {
             RGBColor[
             0.8590720492168273, 0.39317080166904056`, 0.2017773713376896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 313}], {
             RGBColor[
             0.34397103520992167`, 0.4699540423686539, 0.9432263147475373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 321}], {
             RGBColor[
             0.6114600904368728, 0.6914542319869668, 0.964754355111318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 331}], {
             RGBColor[
             0.42861309362707734`, 0.5456648518044729, 0.9485318252116084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 342}], {
             RGBColor[
             0.5042459583975736, 0.6071002946590989, 0.9544767271173353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 346}], {
             RGBColor[
             0.3750828645825507, 0.4992996579136456, 0.9451209263518141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 321}], {
             RGBColor[
             0.7571390218362452, 0.8102020254189503, 0.9764281998963484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 331}], {
             RGBColor[
             0.5742920250264498, 0.6644126452364563, 0.9602056699966387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 338}], {
             RGBColor[
             0.8453899770207604, 0.8765077587109009, 0.7950431863063177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 342}], {
             RGBColor[
             0.6499248897969461, 0.7258480880910823, 0.9661505719023658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 384}], {
             RGBColor[
             0.7224597094549363, 0.7831102830141358, 0.9729716901347794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 398}], {
             RGBColor[
             0.8179584912880846, 0.8585839639299231, 0.9789023010866215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 304}], {
             RGBColor[
             0.21505855653612305`, 0.3433705567924642, 0.9355586386928844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 329}], {
             RGBColor[
             0.22307875219905648`, 0.35180029094398246`, 0.9360153769710722]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 353}], {
             RGBColor[
             0.2106991637542155, 0.3387885585772128, 0.9353103777230984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 378}], {
             RGBColor[
             0.20977255736756456`, 0.3378146365146045, 0.93525760886017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 388}], {
             RGBColor[
             0.21719189432910094`, 0.3456128300743124, 0.9356801291242041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 299}], {
             RGBColor[
             0.21267988324051307`, 0.34087042034218046`, 0.9354231767676313]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 330}], {
             RGBColor[
             0.21800150715905772`, 0.3464637844910152, 0.9357262353771553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 336}], {
             RGBColor[
             0.21111881242536762`, 0.33922963593785627`, 0.935334276094106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 341}], {
             RGBColor[
             0.21717163219876068`, 0.3455915332906315, 0.9356789752258563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 368}], {
             RGBColor[
             0.21277052855345546`, 0.3409656943133277, 0.9354283388841056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 393}], {
             RGBColor[
             0.21778977524310467`, 0.34624124082276975`, 0.9357141775577711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 310}], {
             RGBColor[
             0.2124827502833183, 0.3406632211052174, 0.935411950337351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 345}], {
             RGBColor[
             0.22216737223106828`, 0.3508423728127994, 0.9359634752301611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 363}], {
             RGBColor[
             0.5524499218387339, 0.42033901047071287`, 0.5720521832312901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 316}], {
             RGBColor[
             0.27790052377493313`, 0.40942144877130526`, 0.9391373957607753]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 324}], {
             RGBColor[
             0.2907395975741168, 0.42291612937854317`, 0.9398685620199312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 360}], {
             RGBColor[
             0.3059566318031602, 0.4387580388470877, 0.9407407208692202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 374}], {
             RGBColor[
             0.2888126336637139, 0.4208907681321412, 0.9397588242759214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 375}], {
             RGBColor[
             0.2781834406546093, 0.40971881234981117`, 0.9391535074585348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 380}], {
             RGBColor[
             0.28350610283773925`, 0.41531326778055483`, 0.939456625195691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 383}], {
             RGBColor[
             0.2908789334455868, 0.4230625802138626, 0.9398764969916824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 390}], {
             RGBColor[
             0.283910407540538, 0.415738217657595, 0.9394796497504001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 307}], {
             RGBColor[
             0.965939497584164, 0.9739442069028073, 0.9347428726703746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 314}], {
             RGBColor[
             0.9362255007006572, 0.9517027043636277, 0.9839981831745597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 332}], {
             RGBColor[
             0.736930313911651, 0.7933926635631983, 0.9655671808709663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 352}], {
             RGBColor[
             0.970396577990795, 0.974814330666099, 0.7901511578367646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 385}], {
             RGBColor[
             0.76103003285282, 0.8129579010796052, 0.9674643990261943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 306}], {
             RGBColor[
             0.8969031243202032, 0.8868893383314866, 0.6612189641553454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 307}], {
             RGBColor[
             0.9043350538106595, 0.9251046086494896, 0.9386480207606034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 314}], {
             RGBColor[
             0.8746210569271528, 0.9028631061103101, 0.9879033312647884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 336}], {
             RGBColor[
             0.2125676316732109, 0.34075243682778544`, 0.9354167842069347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 367}], {
             RGBColor[
             0.21672169883755696`, 0.34511862480058364`, 0.9356533521865525]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 306}], {
             RGBColor[
             0.9301864468516778, 0.7525583544999579, 0.2846700934867103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 307}], {
             RGBColor[
             0.9376183763421341, 0.7907736248179609, 0.5620991500919681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 314}], {
             RGBColor[
             0.9079043794586273, 0.7685321222787813, 0.6113544605961532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 363}], {
             RGBColor[
             0.8762546358068509, 0.5309830273105506, 0.21845617365184725`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 316}], {
             RGBColor[
             0.2555487063727525, 0.3859282714945373, 0.9378644928262717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 324}], {
             RGBColor[
             0.2683877801719362, 0.39942295210177514`, 0.9385956590854276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 372}], {
             RGBColor[
             0.25414770566980416`, 0.3844557309271635, 0.9377847079088335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 380}], {
             RGBColor[
             0.26115428543555863`, 0.39182009050378686`, 0.9381837222611874]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 383}], {
             RGBColor[
             0.2685271160434062, 0.39956940293709464`, 0.9386035940571789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 390}], {
             RGBColor[
             0.26155859013835736`, 0.392245040380827, 0.9382067468158966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 323}], {
             RGBColor[
             0.9087436394185031, 0.9180978599174181, 0.6943707488073377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 340}], {
             RGBColor[
             0.9905275811721996, 0.978922480132596, 0.484619975557615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 313}], {
             RGBColor[
             0.2862100467675046, 0.4181552842906852, 0.9396106108023645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 344}], {
             RGBColor[
             0.3051201948561256, 0.4369324167818024, 0.9407277420647475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 315}], {
             RGBColor[
             0.23118633013209117`, 0.360321869401733, 0.9364770915402718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 329}], {
             RGBColor[
             0.2271186296842969, 0.35604645832399684`, 0.9362454420173936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 353}], {
             RGBColor[
             0.21473904123945592`, 0.3430347259572272, 0.9355404427694197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 378}], {
             RGBColor[
             0.21381243485280502`, 0.34206080389461896`, 0.9354876739064912]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 325}], {
             RGBColor[
             0.20723516257555488`, 0.3351476737080805, 0.9351131079805042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 314}], {
             RGBColor[
             0.9555259778682477, 0.9659228619523936, 0.9435306567958934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 352}], {
             RGBColor[
             0.9896970551583855, 0.989034488254865, 0.7496836314580985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 385}], {
             RGBColor[
             0.7803305100204103, 0.8271780586683711, 0.9269968726475282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 386}], {
             RGBColor[
             0.30022575986843436`, 0.4300559235597101, 0.9405124330603728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 397}], {
             RGBColor[
             0.25521896402580857`, 0.3855816913810268, 0.9378457144874233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 319}], {
             RGBColor[
             0.25618706106620875`, 0.38659922275138503`, 0.9379008461817029]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 329}], {
             RGBColor[
             0.25296463724126, 0.3832122509978928, 0.9377173339120208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 334}], {
             RGBColor[
             0.26609474286190404`, 0.39701282450196873`, 0.9384650740028659]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 371}], {
             RGBColor[
             0.2714180274121831, 0.4026079340800466, 0.9387682271829105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 386}], {
             RGBColor[
             0.30507679489801537`, 0.4351546689491852, 0.9407886923288442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 345}], {
             RGBColor[
             0.19226277251810686`, 0.3194107424533439, 0.9342604525163987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 363}], {
             RGBColor[
             0.5225453221257725, 0.38890738011125736`, 0.5703491605175277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 323}], {
             RGBColor[
             0.6747921418079339, 0.7440706990607763, 0.9694867808520644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 339}], {
             RGBColor[
             0.4425672704759462, 0.555957682108388, 0.9499165435038557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 327}], {
             RGBColor[
             0.39077465425622554`, 0.5126293712413812, 0.9461931090416965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 356}], {
             RGBColor[
             0.4906677898927829, 0.5973852420238213, 0.9530463122771483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 361}], {
             RGBColor[
             0.40929184788600736`, 0.528668033662285, 0.9473730082456748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 344}], {
             RGBColor[
             0.30171850127564737`, 0.43335702114888963`, 0.940534020647694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 359}], {
             RGBColor[
             0.2641882368664749, 0.39500896582131095`, 0.9383565013068491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 385}], {
             RGBColor[
             0.7506165131369036, 0.8049365561291917, 0.9762521831517132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 319}], {
             RGBColor[
             0.24242894961997336`, 0.37213857530674344`, 0.9371173420881417]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 329}], {
             RGBColor[
             0.2392065257950246, 0.3687516035532512, 0.9369338298184597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 334}], {
             RGBColor[
             0.25233663141566864`, 0.38255217705732714`, 0.9376815699093048]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 371}], {
             RGBColor[
             0.25765991596594773`, 0.388147286635405, 0.9379847230893494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 324}], {
             RGBColor[
             0.2671185805915378, 0.39808894287087526`, 0.9385233800469365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 355}], {
             RGBColor[
             0.2426003366300466, 0.37231871392089444`, 0.937127102324821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 380}], {
             RGBColor[
             0.25988508585516024`, 0.3904860812728869, 0.9381114432226962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 383}], {
             RGBColor[
             0.2672579164630078, 0.3982353937061947, 0.9385313150186878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 390}], {
             RGBColor[
             0.26028939055795897`, 0.3909110311499271, 0.9381344677774055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 333}], {
             RGBColor[
             0.5930937593564782, 0.6566344401985723, 0.8697228003417041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 370}], {
             RGBColor[
             0.9109218435003366, 0.9293228266692952, 0.8943803638429948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 381}], {
             RGBColor[
             0.99188704610358, 0.9909130993174948, 0.7841161719227241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 382}], {
             RGBColor[
             0.9447039927210837, 0.8118308485146293, 0.5211250046258997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 367}], {
             RGBColor[
             0.22156608180377718`, 0.3502103784497014, 0.9359292326298564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 373}], {
             RGBColor[
             0.2370696348066011, 0.3665055956377041, 0.9368121370379159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 329}], {
             RGBColor[
             0.2383612491721791, 0.3678631642290072, 0.9368856925652633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 334}], {
             RGBColor[
             0.25149135479282314`, 0.3816637377330832, 0.9376334326561084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 371}], {
             RGBColor[
             0.2568146393431022, 0.387258847311161, 0.937936585836153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 388}], {
             RGBColor[
             0.23247439130222355`, 0.3616757033593372, 0.9365504447183952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 343}], {
             RGBColor[
             0.7160472963068527, 0.7781008571267078, 0.9723325607195863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 349}], {
             RGBColor[
             0.5776365804223218, 0.666740315055617, 0.9606597012822499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 331}], {
             RGBColor[
             0.634939466831133, 0.7117908877119044, 0.9662504402131629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 338}], {
             RGBColor[
             0.9060374188254435, 0.923886001186349, 0.8010879565228419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 342}], {
             RGBColor[
             0.7105723316016292, 0.7732263305665302, 0.9721953421188899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 384}], {
             RGBColor[
             0.7831071512596195, 0.8304885254895837, 0.9790164603513036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 398}], {
             RGBColor[
             0.8786059330927678, 0.9059622064053712, 0.9849470713031456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 328}], {
             RGBColor[
             0.4089266558730876, 0.5271174055758985, 0.947690784031411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 362}], {
             RGBColor[
             0.45653757665465905`, 0.5683555921624378, 0.9507245098029286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 364}], {
             RGBColor[
             0.428972946302528, 0.5444804947900268, 0.9489681159313363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 340}], {
             RGBColor[
             0.9119941865056833, 0.9282757501963927, 0.7739166151037982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 375}], {
             RGBColor[
             0.267401497471214, 0.3983863064493811, 0.938539491744696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 380}], {
             RGBColor[
             0.27272415965434393`, 0.4039807618801248, 0.9388426094818522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 383}], {
             RGBColor[
             0.2800969902621915, 0.41173007431343256`, 0.9392624812778436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 390}], {
             RGBColor[
             0.27312846435714266`, 0.404405711757165, 0.9388656340365613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 335}], {
             RGBColor[
             0.3099542075105004, 0.4402786337315509, 0.9410665454863245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 337}], {
             RGBColor[
             0.312066783946898, 0.44249908551128714`, 0.9411868535891006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 354}], {
             RGBColor[
             0.3095818357707423, 0.4398872474233331, 0.94104533946662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 337}], {
             RGBColor[
             0.3016677329619616, 0.43349195021963505`, 0.9405242352558603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 354}], {
             RGBColor[
             0.2991827847858058, 0.430880112131681, 0.9403827211333795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 356}], {
             RGBColor[
             0.4184852693414719, 0.5351260969165677, 0.9483745901685348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 392}], {
             RGBColor[
             0.28327067295496094`, 0.4141554737113025, 0.9394765499044728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 347}], {
             RGBColor[
             0.29474363512034735`, 0.42706072191761096`, 0.940098925902251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 362}], {
             RGBColor[
             0.35704810596381387`, 0.4836788564514203, 0.9439717674801389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 372}], {
             RGBColor[
             0.2804573452843499, 0.4120449254968854, 0.9392853428307628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 387}], {
             RGBColor[
             0.30150296805800375`, 0.4341652094015489, 0.9404838599135137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 334}], {
             RGBColor[
             0.2482689309678744, 0.37827676597959103`, 0.9374499203864265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 353}], {
             RGBColor[
             0.22275923690238936`, 0.35146446010874544`, 0.9359971810476075]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 371}], {
             RGBColor[
             0.25359221551815353`, 0.38387187555766883`, 0.9377530735664711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 388}], {
             RGBColor[
             0.22925196747727483`, 0.358288731605845, 0.9363669324487132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 342}], {
             RGBColor[
             0.5277253347918338, 0.6274369503840362, 0.9559728122191802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 346}], {
             RGBColor[
             0.3985622409768109, 0.5196363136385831, 0.946617011453659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 361}], {
             RGBColor[
             0.4414240641856033, 0.5547544143941453, 0.9499025740169657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 385}], {
             RGBColor[
             0.5513213263478973, 0.6466265153287621, 0.9578211808481198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 381}], {
             RGBColor[
             0.5943537422981029, 0.6571554755250186, 0.8488416222676571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 371}], {
             RGBColor[
             0.26672232113879757`, 0.3976724490617448, 0.9385008136573162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 388}], {
             RGBColor[
             0.24238207309791887`, 0.372089305109921, 0.9371146725395583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 337}], {
             RGBColor[
             0.282630755782611, 0.41439322252540617`, 0.9394067754758614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 354}], {
             RGBColor[
             0.28014580760645524`, 0.41178138443745216`, 0.9392652613533807]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 367}], {
             RGBColor[
             0.21516062802241154`, 0.34347784039625945`, 0.9355644515130273]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 354}], {
             RGBColor[
             0.28225838404285286`, 0.4140018362171884, 0.9393855694561568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 384}], {
             RGBColor[
             0.8713581064441347, 0.8967942587815345, 0.7976314467612728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 398}], {
             RGBColor[
             0.966856888277283, 0.9722679396973218, 0.803562057713115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 360}], {
             RGBColor[
             0.3380761124684098, 0.46724626924582036`, 0.942762888830887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 374}], {
             RGBColor[
             0.3209321143289635, 0.44937899853087393`, 0.9417809922375882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 368}], {
             RGBColor[
             0.2171826090564914, 0.3456030706640795, 0.9356796003416652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 379}], {
             RGBColor[
             0.2212705365436844, 0.3498997416426921, 0.9359124017645142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 393}], {
             RGBColor[
             0.2222018557461406, 0.35087861717352153`, 0.9359654390153307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 399}], {
             RGBColor[
             0.22823136465623345`, 0.3572160133309742, 0.9363088106279014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 346}], {
             RGBColor[
             0.4741951057473072, 0.5810717564932091, 0.9525619133593859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 398}], {
             RGBColor[
             0.7713918010534688, 0.8216082690775031, 0.9746694433091629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 349}], {
             RGBColor[
             0.5837898565381997, 0.6715473011239714, 0.9612730023398459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 349}], {
             RGBColor[
             0.3830038950089686, 0.5061604563464437, 0.9456256474062932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 362}], {
             RGBColor[
             0.3423545559019188, 0.4682989085041503, 0.9431326516737686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 372}], {
             RGBColor[
             0.26576379522245486`, 0.3966649775496154, 0.9384462270243925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 387}], {
             RGBColor[
             0.2868094179961087, 0.41878526145427897`, 0.9396447441071433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 351}], {
             RGBColor[
             0.2543498568494185, 0.38466820463406326`, 0.9377962201194567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 369}], {
             RGBColor[
             0.2602045857942335, 0.3908218959663191, 0.9381296382715687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 357}], {
             RGBColor[
             0.5542164267531839, 0.6479076320182329, 0.9585525480697432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 394}], {
             RGBColor[
             0.3958053510234857, 0.5172484341263308, 0.9464413448636552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 378}], {
             RGBColor[
             0.20945304207089746`, 0.33747880567936756`, 0.9352394129367053]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 375}], {
             RGBColor[
             0.24288325350972279`, 0.37261607749940034`, 0.9371432140225805]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 379}], {
             RGBColor[
             0.2259392634266556, 0.3548068696110762, 0.9361782788537368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 366}], {
             RGBColor[
             0.934928559139148, 0.7751416322731404, 0.28588252947049914`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 391}], {
             RGBColor[
             0.8944837314108928, 0.5317010026573729, 0.24979314294089291`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 374}], {
             RGBColor[
             0.293247724709362, 0.42540017170025574`, 0.9400169674113716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 375}], {
             RGBColor[
             0.2826185317002574, 0.4142282159179257, 0.939411650593985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 369}], {
             RGBColor[
             0.30654023496768024`, 0.43518917662023243`, 0.9409270894573605]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 385}], {
             RGBColor[
             0.46552378312677223`, 0.5743196519105522, 0.9517997921721937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 377}], {
             RGBColor[
             0.3822045767059832, 0.5054681270073037, 0.9455747155508364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 387}], {
             RGBColor[
             0.3215492584874442, 0.4515282986156772, 0.941761191813439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 382}], {
             RGBColor[
             0.9000306839899277, 0.6389445090727658, 0.23829549106007777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 393}], {
             RGBColor[
             0.21780075210083538`, 0.3462527781962177, 0.93571480267358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 399}], {
             RGBColor[
             0.22383026101092823`, 0.35259017435367035`, 0.9360581742861507]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 392}], {
             RGBColor[
             0.2527015805879449, 0.38293576177650346`, 0.937702353224772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 389}], {
             RGBColor[
             0.505152375234491, 0.5869084718259839, 0.9586367768062234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 391}], {
             RGBColor[
             0.8258037070409253, 0.5129958576116641, 0.5754614637475668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 400}], {
             RGBColor[
             0.6104137657145253, 0.6900683539569277, 0.9649050090474223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 395}], {
             RGBColor[
             0.2616949498810116, 0.3923883631160637, 0.9382145123015146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 375}], {
             RGBColor[
             0.26547453356081113`, 0.3963609452029792, 0.9384297540006862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 399}], {
             RGBColor[
             0.255491371590293, 0.38586800900293716`, 0.9378612276952298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 379}], {
             RGBColor[
             0.23790135046863936`, 0.36737978153232503`, 0.9368595020144559]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 383}], {
             RGBColor[
             0.26754083334268397`, 0.3985327572847006, 0.9385474267164473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 399}], {
             RGBColor[
             0.24486217858118842`, 0.3746960532206071, 0.9372559108778432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 377}], {
             RGBColor[
             0.4266363429774569, 0.5439526897461481, 0.9484058684081864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 393}], {
             RGBColor[
             0.22188867958802838`, 0.35054944917483033`, 0.9359476040964289]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 399}], {
             RGBColor[
             0.22791818849812123`, 0.356886845332283, 0.9362909757089996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 383}], {
             RGBColor[
             0.2728634955258139, 0.4041272127154443, 0.9388505444536035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 390}], {
             RGBColor[
             0.2658949696207651, 0.39680285015917666`, 0.9384536972123212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 390}], {
             RGBColor[
             0.27326780022861263`, 0.40455216259248444`, 0.9388735690083126]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 398}], {
             RGBColor[
             0.8439266207114591, 0.8788704640005567, 0.9814905615415767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 400}], {
             RGBColor[
             0.2843495171102985, 0.40872323643536973`, 0.9397784081644269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 399}], {
             RGBColor[
             0.22884950770057744`, 0.3578657208631124, 0.9363440129598162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 396}], {
             RGBColor[
             0.2756838068644868, 0.4070915387504564, 0.9390111570120642]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.03217915333176364], {
             RGBColor[
             0.3599830334006432, 0.48622094308345976`, 0.9441587784611594]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.03217915333176364], {
             RGBColor[
             0.8184511944421836, 0.14282954261339104`, 0.16530219067646573`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.03217915333176364], {
             RGBColor[
             0.370079657849583, 0.49496613171003123`, 0.9448021264429514]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.03217915333176364], {
             RGBColor[
             0.23219649750384544`, 0.36138361935775737`, 0.9365346190776845]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.03217915333176364], {
             RGBColor[
             0.8414430264446411, 0.8764078451972013, 0.9847387810989889]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.03217915333176364], {
             RGBColor[
             0.9933475429680663, 0.9881793920123014, 0.5172992901589675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.03217915333176364], {
             RGBColor[
             0.38940499419392427`, 0.5117047667318526, 0.9460335197860889]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.03217915333176364], {
             RGBColor[
             0.3103199544645186, 0.44320528024791445`, 0.9409942909866859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.03217915333176364], {
             RGBColor[
             0.8256674379376745, 0.1982967522977973, 0.17221247359732916`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.03217915333176364], {
             RGBColor[
             0.3619258765766598, 0.48790373619238797`, 0.9442825747103464]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.03217915333176364], {
             RGBColor[
             0.9234626618564741, 0.7342619893565898, 0.25727446504873397`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.03217915333176364], {
             RGBColor[
             0.218436984339963, 0.3469214986189947, 0.935751035158377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.03217915333176364], {
             RGBColor[
             0.9637801291888717, 0.9725078601704316, 0.9461949730147088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.03217915333176364], {
             RGBColor[
             0.9943570777774785, 0.9903386848900081, 0.6271809240368398]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.03217915333176364], {
             RGBColor[
             0.3038609163605336, 0.43670746736272875`, 0.940615801713566]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.03217915333176364], {
             RGBColor[
             0.2418605106508593, 0.3715411099090923, 0.9370849703297808]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.03217915333176364], {
             RGBColor[
             0.5355166046173245, 0.6337955302332828, 0.9565769752588857]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.03217915333176364], {
             RGBColor[
             0.9452065658445834, 0.95865572703968, 0.9776351709954327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.03217915333176364], {
             RGBColor[
             0.2743841090042405, 0.40572547389373365`, 0.9389371411416538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.03217915333176364], {
             RGBColor[
             0.4076589804310767, 0.5275154521384491, 0.9471966476477539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.03217915333176364], {
             RGBColor[
             0.31291714185714126`, 0.44545483342897024`, 0.9411597814707411]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.03217915333176364], {
             RGBColor[
             0.29231839668471055`, 0.42457554734542235`, 0.9399584722936555]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.03217915333176364], {
             RGBColor[
             0.21341792784235675`, 0.34164615201344867`, 0.935465207315867]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.03217915333176364], {
             RGBColor[
             0.9021530244270525, 0.6485815613125467, 0.24006642394413927`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.03217915333176364], {
             RGBColor[
             0.8487111149297029, 0.3754205514621725, 0.19427912470900624`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.03217915333176364], {
             RGBColor[
             0.45511285367532656`, 0.5685201430708667, 0.9502472974560874]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.03217915333176364], {
             RGBColor[
             0.2974167180204977, 0.42993420632157753`, 0.9402488141514381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.03217915333176364], {
             RGBColor[
             0.2882891132658928, 0.42034051500092084`, 0.9397290105637445]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.03217915333176364], {
             RGBColor[
             0.2404292095299187, 0.3700367216812511, 0.9370034598483634]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.03217915333176364], {
             RGBColor[
             0.17892703208317115`, 0.3053940337214471, 0.9335010018270892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.03217915333176364], {
             RGBColor[
             0.183217413291963, 0.30990349639776743`, 0.9337453326898797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.03217915333176364], {
             RGBColor[
             0.21628540957162948`, 0.3446600571197567, 0.9356285061582901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.03217915333176364], {
             RGBColor[
             0.17894138666990014`, 0.3054091213022326, 0.9335018192995677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.03217915333176364], {
             RGBColor[
             0.3122890105436297, 0.4449107776560043, 0.9411197574988789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.03217915333176364], {
             RGBColor[
             0.28104105066772134`, 0.4127223416565313, 0.9393162441213263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.03217915333176364], {
             RGBColor[
             0.5196772960404508, 0.620936465977857, 0.9553300468664151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.03217915333176364], {
             RGBColor[
             0.24979952597607638`, 0.3798855183785399, 0.9375370855078312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.03217915333176364], {
             RGBColor[
             0.9657912116144293, 0.896267865549297, 0.32160574622002847`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.03217915333176364], {
             RGBColor[
             0.27309206457306523`, 0.40436745327622, 0.9388635611227067]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.03217915333176364], {
             RGBColor[
             0.3393121311221928, 0.4683168464796233, 0.9428416468465376]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.03217915333176364], {
             RGBColor[
             0.34082031608406577`, 0.4696231604900174, 0.9429377470586726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.03217915333176364], {
             RGBColor[
             0.9322258626950144, 0.9487956145888052, 0.9933977290633442]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.03217915333176364], {
             RGBColor[
             0.2274352478585693, 0.35637924409990884`, 0.9362634729540237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.03217915333176364], {
             RGBColor[
             0.29795654320818293`, 0.4305015968207284, 0.940279556397277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.03217915333176364], {
             RGBColor[
             0.2954990939280613, 0.427918661816037, 0.9401396082962444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.03217915333176364], {
             RGBColor[
             0.2843163130979401, 0.41616485013432336`, 0.9395027654714108]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.03217915333176364], {
             RGBColor[
             0.43389191818712153`, 0.5502371043169462, 0.948868187244693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.03217915333176364], {
             RGBColor[
             0.4254428949511675, 0.5429189850502182, 0.948329822955276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.03217915333176364], {
             RGBColor[
             0.2557363986193865, 0.3861255479461254, 0.9378751816220516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.03217915333176364], {
             RGBColor[
             0.45414763221898446`, 0.5677365328098771, 0.9501713116873214]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.03217915333176364], {
             RGBColor[
             0.3729233885884314, 0.4974292283459589, 0.9449833264510183]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.03217915333176364], {
             RGBColor[
             0.38664548537965426`, 0.5093146188938776, 0.9458576863245813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.03217915333176364], {
             RGBColor[
             0.28924396052189333`, 0.4213441200077901, 0.9397833877024038]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.03217915333176364], {
             RGBColor[
             0.4519914858020445, 0.5659140400742732, 0.9500214756882968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.03217915333176364], {
             RGBColor[
             0.4035326533159193, 0.5239414349865308, 0.9469337217327439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.03217915333176364], {
             RGBColor[
             0.45093503134871465`, 0.5649989923257436, 0.9499541593447165]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.03217915333176364], {
             RGBColor[
             0.2732074233744939, 0.404488702690692, 0.9388701306357901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.03217915333176364], {
             RGBColor[
             0.2988109928106687, 0.43139967752817476`, 0.9403282160380936]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.03217915333176364], {
             RGBColor[
             0.3340181926444761, 0.4637315030513096, 0.9425043217679835]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.03217915333176364], {
             RGBColor[
             0.35752834255750565`, 0.4840948132514831, 0.9440023677312325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.03217915333176364], {
             RGBColor[
             0.9933459036684309, 0.98817588571614, 0.5171208625102379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.03217915333176364], {
             RGBColor[
             0.1790682590797859, 0.30554247224919795`, 0.9335090444956198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.03217915333176364], {
             RGBColor[
             0.9585610528033711, 0.8718788421575785, 0.2935179445399928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.03217915333176364], {
             RGBColor[
             0.3989602722595878, 0.5199810683300905, 0.9466423736550322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.03217915333176364], {
             RGBColor[
             0.5153321861178936, 0.6174089099977538, 0.9549879838966494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.03217915333176364], {
             RGBColor[
             0.9727828870163496, 0.9198524284034268, 0.3487670848893771]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.03217915333176364], {
             RGBColor[
             0.2129458677257866, 0.3411499869005934, 0.9354383241905787]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.03217915333176364], {
             RGBColor[
             0.2767246225454214, 0.4081855020226443, 0.9390704299253445]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.03217915333176364], {
             RGBColor[
             0.48821862164434726`, 0.5953968969059689, 0.9528535047810326]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.03217915333176364], {
             RGBColor[
             0.2778101351361315, 0.409326444580954, 0.9391322482615135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.03217915333176364], {
             RGBColor[
             0.871120013048017, 0.9000714687543917, 0.9875693985741776]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.03217915333176364], {
             RGBColor[
             0.22772650909910638`, 0.3566853781307425, 0.9362800598507899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.03217915333176364], {
             RGBColor[
             0.24311597663730303`, 0.3728606842619857, 0.9371564672604132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.03217915333176364], {
             RGBColor[
             0.8246734764068878, 0.8630362611944062, 0.983139286446034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.03217915333176364], {
             RGBColor[
             0.24417812249459925`, 0.373977066901941, 0.9372169548956822]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.03217915333176364], {
             RGBColor[
             0.8469444359628041, 0.36184108275892934`, 0.19258735093512552`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.03217915333176364], {
             RGBColor[
             0.8293651040061051, 0.8667772376911834, 0.9835867780747127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.03217915333176364], {
             RGBColor[
             0.8418439495844675, 0.3226365094076515, 0.18770311941905493`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.03217915333176364], {
             RGBColor[
             0.590805957298975, 0.6786819174972005, 0.9609295556335575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.03217915333176364], {
             RGBColor[
             0.3344163982055418, 0.46407640869391137`, 0.9425296950742152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.03217915333176364], {
             RGBColor[
             0.2197154470497895, 0.34826524398623987`, 0.9358238417183856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.03217915333176364], {
             RGBColor[
             0.37921715493462604`, 0.5028805724211383, 0.9453843596772389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.03217915333176364], {
             RGBColor[
             0.35288166901045503`, 0.480070098173631, 0.9437062858017065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.03217915333176364], {
             RGBColor[
             0.17892701429477148`, 0.30539401502471114`, 0.9335010008140661]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.03217915333176364], {
             RGBColor[
             0.2413074662041341, 0.37095982513054093`, 0.9370534752666957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.03217915333176364], {
             RGBColor[
             0.30053635500276704`, 0.4332131425863514, 0.940426472862489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.03217915333176364], {
             RGBColor[
             0.29013871681338543`, 0.4222845656009737, 0.9398343427495309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.03217915333176364], {
             RGBColor[
             0.9903137669558371, 0.9902625079584733, 0.8101894789167451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.03217915333176364], {
             RGBColor[
             0.21858282554203126`, 0.3470747869692347, 0.9357593405990821]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.03217915333176364], {
             RGBColor[
             0.7058058015575851, 0.7701001235903371, 0.9713117842351892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.03217915333176364], {
             RGBColor[
             0.26262121251507564`, 0.39336192387290797`, 0.9382672615882417]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.03217915333176364], {
             RGBColor[
             0.28766384187052196`, 0.4196833151198899, 0.9396934022827843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.03217915333176364], {
             RGBColor[
             0.2452381115380016, 0.3750911825937439, 0.9372773197035907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.03217915333176364], {
             RGBColor[
             0.26012396818175015`, 0.3907371617441472, 0.9381250472178008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.03217915333176364], {
             RGBColor[
             0.2817785304161579, 0.4134974796310549, 0.9393582425019963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.03217915333176364], {
             RGBColor[
             0.2869114883454893, 0.4188925438631119, 0.939650556862541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.03217915333176364], {
             RGBColor[
             0.44228444757308333`, 0.5575062914502744, 0.9494029517959442]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.03217915333176364], {
             RGBColor[
             0.9775701021325132, 0.9360008290818089, 0.3673645116259542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.03217915333176364], {
             RGBColor[
             0.9781276011086575, 0.9832081812363787, 0.921908445474496]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.03217915333176364], {
             RGBColor[
             0.37661408553666426`, 0.5006259245426959, 0.9452184943970047]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.03217915333176364], {
             RGBColor[
             0.2608418322510304, 0.39149168239617155`, 0.9381659285145616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.03217915333176364], {
             RGBColor[
             0.819297035403237, 0.14933104688991955`, 0.16611216893601113`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.03217915333176364], {
             RGBColor[
             0.34456615692423104`, 0.4728676195543337, 0.943176428724691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.03217915333176364], {
             RGBColor[
             0.9338740873595025, 0.7755398220742175, 0.265651742396037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.03217915333176364], {
             RGBColor[
             0.417344109662346, 0.5359042242898253, 0.9478137755181469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.03217915333176364], {
             RGBColor[
             0.948494816832878, 0.9611080992427333, 0.9720690197854612]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.03217915333176364], {
             RGBColor[
             0.8392176796973624, 0.30244984821655896`, 0.1851882004092155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.03217915333176364], {
             RGBColor[
             0.3675690787260941, 0.49279159425864094`, 0.9446421545612206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.03217915333176364], {
             RGBColor[
             0.9940964498066649, 0.9918267445278057, 0.7475006348091123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.03217915333176364], {
             RGBColor[
             0.25557794384056287`, 0.3859590019269685, 0.9378661578568105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.03217915333176364], {
             RGBColor[
             0.8740781517963572, 0.5211001217496539, 0.21664006204298622`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.03217915333176364], {
             RGBColor[
             0.3289211710833394, 0.45931671915880556`, 0.9421795440612271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.03217915333176364], {
             RGBColor[
             0.7965156452550962, 0.8409633429071789, 0.9803528937232722]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.03217915333176364], {
             RGBColor[
             0.3288778807819878, 0.45927922327560866`, 0.9421767856415051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.03217915333176364], {
             RGBColor[
             0.2386060995532787, 0.36812051750395375`, 0.9368996364322433]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.03217915333176364], {
             RGBColor[
             0.4162213411164948, 0.534931738607397, 0.9477422336992305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.03217915333176364], {
             RGBColor[
             0.3495171154366807, 0.47715589097540734`, 0.9434918994231435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.03217915333176364], {
             RGBColor[
             0.20606162213947596`, 0.33391420830300045`, 0.935046276588767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.03217915333176364], {
             RGBColor[
             0.24049836738192176`, 0.3701094109685675, 0.9370073982857251]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.03217915333176364], {
             RGBColor[
             0.5663783145126094, 0.6588504566304622, 0.9590065221120109]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.03217915333176364], {
             RGBColor[
             0.5531961411455233, 0.6481485744409189, 0.9579687731366617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.03217915333176364], {
             RGBColor[
             0.44608758599784554`, 0.5608003788025082, 0.9496452844133868]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.03217915333176364], {
             RGBColor[
             0.9742961343763916, 0.9803506796209057, 0.9283941192456544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.03217915333176364], {
             RGBColor[
             0.22327126764014227`, 0.35200263687874755`, 0.936026340440641]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.03217915333176364], {
             RGBColor[
             0.277985958766929, 0.4095112463647842, 0.9391422611571797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.03217915333176364], {
             RGBColor[
             0.21204174778307774`, 0.3401996995162911, 0.935386835897367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.03217915333176364], {
             RGBColor[
             0.21049571798261152`, 0.33857472417205015`, 0.9352987917873766]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.03217915333176364], {
             RGBColor[
             0.3262131529712761, 0.45697116997908427`, 0.9420069915417328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.03217915333176364], {
             RGBColor[
             0.23768447069359533`, 0.36715182713778177`, 0.936847151032112]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.03217915333176364], {
             RGBColor[
             0.4104055903111328, 0.5298944275679272, 0.9473716592005793]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.03217915333176364], {
             RGBColor[
             0.9224661794909306, 0.7303112688352736, 0.2564726719469704]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.03217915333176364], {
             RGBColor[
             0.7992223614262676, 0.8430778501519028, 0.9806226738955138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.03217915333176364], {
             RGBColor[
             0.29725822306554583`, 0.42976761807476255`, 0.9402397880982258]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.03217915333176364], {
             RGBColor[
             0.2343268669145523, 0.36362277268163234`, 0.9366559404640252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.03217915333176364], {
             RGBColor[
             0.5032780494106496, 0.6076228187861427, 0.9540390380992975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.03217915333176364], {
             RGBColor[
             0.6185821135656369, 0.7012318524560568, 0.9631161964022821]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.03217915333176364], {
             RGBColor[
             0.22155609394318862`, 0.3501998805749559, 0.9359286638359716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.03217915333176364], {
             RGBColor[
             0.8193428764107183, 0.14968340096107918`, 0.16615606633654534`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.03217915333176364], {
             RGBColor[
             0.2111706728502173, 0.3392841445325141, 0.9353372294685806]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.03217915333176364], {
             RGBColor[
             0.6719249954084331, 0.7436321803229556, 0.9679348621123766]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.03217915333176364], {
             RGBColor[
             0.3600639473667127, 0.48629102669401497`, 0.9441639342275279]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.03217915333176364], {
             RGBColor[
             0.8215839734950429, 0.16690945520620182`, 0.16830214343545163`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.03217915333176364], {
             RGBColor[
             0.6246442469651912, 0.7061533654458123, 0.9635934297498213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.03217915333176364], {
             RGBColor[
             0.8784381059512442, 0.540897655273832, 0.22027811466207986`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.03217915333176364], {
             RGBColor[
             0.23802405881018981`, 0.36750875577945274`, 0.9368664900729765]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.03217915333176364], {
             RGBColor[
             0.5353312372592116, 0.6336450406612625, 0.9565623824614321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.03217915333176364], {
             RGBColor[
             0.28473783311028583`, 0.41660789439321116`, 0.9395267704125309]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.03217915333176364], {
             RGBColor[
             0.6238880244982119, 0.7055394299796848, 0.9635338971470865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.03217915333176364], {
             RGBColor[
             0.22021863489519794`, 0.34879412631571627`, 0.9358524975217819]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.03217915333176364], {
             RGBColor[
             0.2706007772119499, 0.40174895230294594`, 0.9387216859930206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.03217915333176364], {
             RGBColor[
             0.3158355177641727, 0.44798258395780277`, 0.9413457378029186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.03217915333176364], {
             RGBColor[
             0.18361616608284723`, 0.3103226108633739, 0.9337680410714186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.03217915333176364], {
             RGBColor[
             0.3174307607246093, 0.4493643032308905, 0.9414473852737397]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.03217915333176364], {
             RGBColor[
             0.4301580292792129, 0.547002997415629, 0.9486302671452295]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.03217915333176364], {
             RGBColor[
             0.30454561984188433`, 0.43742713413433654`, 0.9406547945639009]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.03217915333176364], {
             RGBColor[
             0.18595953915049845`, 0.3127856445359093, 0.9339014927009116]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.03217915333176364], {
             RGBColor[
             0.46924384183457235`, 0.5799923158523045, 0.9513597406074984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.03217915333176364], {
             RGBColor[
             0.5031159008708285, 0.6074911792968075, 0.9540262731722731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.03217915333176364], {
             RGBColor[
             0.3314345944952444, 0.46149372018986384`, 0.9423396971785006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.03217915333176364], {
             RGBColor[
             0.8294775817921864, 0.22758318757925894`, 0.17586107165535175`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.03217915333176364], {
             RGBColor[
             0.4314366462475933, 0.5481104711684827, 0.9487117394878181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.03217915333176364], {
             RGBColor[
             0.246083996032968, 0.37598026083012825`, 0.9373254915742051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.03217915333176364], {
             RGBColor[
             0.2449732495734328, 0.3748127958757636, 0.9372622362065367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.03217915333176364], {
             RGBColor[
             0.24253850776538854`, 0.3722537278639624, 0.9371235812624463]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.03217915333176364], {
             RGBColor[
             0.532748774101436, 0.6315484807311408, 0.9563590815017777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.03217915333176364], {
             RGBColor[
             0.8247691039330448, 0.19139176348574266`, 0.17135222793997262`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.03217915333176364], {
             RGBColor[
             0.2835494674254077, 0.415358846711668, 0.9394590947448065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.03217915333176364], {
             RGBColor[
             0.6701504899984683, 0.7422459232099505, 0.9677579959968072]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.03217915333176364], {
             RGBColor[
             0.22069846856058375`, 0.34929846192124825`, 0.9358798233391753]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.03217915333176364], {
             RGBColor[
             0.44496963537099143`, 0.5598320661593594, 0.9495740495880086]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.03217915333176364], {
             RGBColor[
             0.2732125866431092, 0.40449412961337683`, 0.9388704246762993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.03217915333176364], {
             RGBColor[
             0.301424661402258, 0.4341468089340951, 0.9404770605978084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.03217915333176364], {
             RGBColor[
             0.22636761106282094`, 0.3552570901354948, 0.936202672617933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.03217915333176364], {
             RGBColor[
             0.7286053839996127, 0.7879113306772935, 0.9735842335387989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.03217915333176364], {
             RGBColor[
             0.17893214148115075`, 0.3053994040226782, 0.9335012927997455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.03217915333176364], {
             RGBColor[
             0.21582348781243682`, 0.34417454806331416`, 0.935602200397456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.03217915333176364], {
             RGBColor[
             0.3219085007459621, 0.453242696579629, 0.9417327029083903]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.03217915333176364], {
             RGBColor[
             0.24398844376792686`, 0.3737777025338824, 0.9372061529728027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.03217915333176364], {
             RGBColor[
             0.2696431574723743, 0.40074243324005365`, 0.9386671509655232]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.03217915333176364], {
             RGBColor[
             0.36627002209779275`, 0.4916664166996908, 0.9445593798215759]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.03217915333176364], {
             RGBColor[
             0.5673122922146817, 0.6596087018042204, 0.9590800482579911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.03217915333176364], {
             RGBColor[
             0.2880943118622093, 0.4201357663745271, 0.9397179169119876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.03217915333176364], {
             RGBColor[
             0.2589336294896423, 0.3894860403069097, 0.9380572591902335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.03217915333176364], {
             RGBColor[
             0.21776291881025298`, 0.3462130130090464, 0.9357126481236506]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.03217915333176364], {
             RGBColor[
             0.8236904837096025, 0.18310101579396953`, 0.170319339995877]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.03217915333176364], {
             RGBColor[
             0.24846767200989045`, 0.3784856554156597, 0.9374612383947583]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.03217915333176364], {
             RGBColor[
             0.8439338400416576, 0.8783939523481282, 0.9849763571234479]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.03217915333176364], {
             RGBColor[
             0.26708591845739416`, 0.39805461289699134`, 0.9385215199867163]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.03217915333176364], {
             RGBColor[
             0.30054674338696064`, 0.4332240614368005, 0.9404270644656005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.03217915333176364], {
             RGBColor[
             0.2411029859620505, 0.37074490343131483`, 0.9370418304194105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.03217915333176364], {
             RGBColor[
             0.6788533623879274, 0.7490446732648759, 0.968625416983622]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.03217915333176364], {
             RGBColor[
             0.34448974411411554`, 0.4728014346188312, 0.9431715597679996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.03217915333176364], {
             RGBColor[
             0.8223396115770147, 0.8611753007301386, 0.9829166803350949]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.03217915333176364], {
             RGBColor[
             0.3880550588481297, 0.5105355205850486, 0.9459475030995558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.03217915333176364], {
             RGBColor[
             0.24569470610522032`, 0.37557109243365844`, 0.9373033220887227]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.03217915333176364], {
             RGBColor[
             0.29792411608308994`, 0.43046751385625726`, 0.9402777097204745]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.03217915333176364], {
             RGBColor[
             0.988751433892587, 0.9896164430866911, 0.8360813809631582]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.03217915333176364], {
             RGBColor[
             0.8264896291158393, 0.8644844120663722, 0.9833125127127125]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.03217915333176364], {
             RGBColor[
             0.22580276459471169`, 0.35466340068417734`, 0.9361705054471896]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.03217915333176364], {
             RGBColor[
             0.27065965459454444`, 0.40181083616509444`, 0.9387250389728581]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.03217915333176364], {
             RGBColor[
             0.27642628673231373`, 0.407871932167485, 0.9390534401421363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.03217915333176364], {
             RGBColor[
             0.8563396258514921, 0.4340566292418462, 0.20158419538288244`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.03217915333176364], {
             RGBColor[
             0.29139757571829134`, 0.42360770612629445`, 0.9399060329018505]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.03217915333176364], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.03217915333176364], {
             RGBColor[
             0.9952685123171101, 0.9923114224965074, 0.7280765258104895]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.03217915333176364], {
             RGBColor[
             0.23156206990492625`, 0.36071679572626025`, 0.9364984893644777]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.03217915333176364], {
             RGBColor[
             0.9398558182628138, 0.7992553918121872, 0.27046478349011155`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.03217915333176364], {
             RGBColor[
             0.2330867180319017, 0.36231929757598597`, 0.9365853158197941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.03217915333176364], {
             RGBColor[
             0.2520329891677718, 0.3822330298027571, 0.9376642779324855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.03217915333176364], {
             RGBColor[
             0.2999237099233219, 0.432569213763913, 0.9403915836315417]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.03217915333176364], {
             RGBColor[
             0.2626771974737526, 0.39342076761412886`, 0.9382704498488161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.03217915333176364], {
             RGBColor[
             0.21089717481030001`, 0.33899668075178374`, 0.9353216541598114]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.03217915333176364], {
             RGBColor[
             0.9109681137578394, 0.6847252697068382, 0.24722105836383443`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.03217915333176364], {
             RGBColor[
             0.9837730937067766, 0.9874185803724101, 0.9123520990861677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.03217915333176364], {
             RGBColor[
             0.8192881970279116, 0.1492631112641677, 0.166103705297818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.03217915333176364], {
             RGBColor[
             0.6591015742674116, 0.7336144262659793, 0.9666567433347234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.03217915333176364], {
             RGBColor[
             0.8228256695060855, 0.17645367486173685`, 0.16949119293792111`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.03217915333176364], {
             RGBColor[
             0.9100637739514378, 0.9311241665985504, 0.9912838892546516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.03217915333176364], {
             RGBColor[
             0.4471878440862639, 0.5617533670581167, 0.9497153918858607]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.03217915333176364], {
             RGBColor[
             0.4754345148883495, 0.5850181831240037, 0.9518470930674744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.03217915333176364], {
             RGBColor[
             0.9218589159168126, 0.9405292926311409, 0.9924089204249567]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.03217915333176364], {
             RGBColor[
             0.6049269005052089, 0.6901459353332633, 0.9620412080094716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.03217915333176364], {
             RGBColor[
             0.4540671923140028, 0.5676712280712366, 0.9501649791633402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.03217915333176364], {
             RGBColor[
             0.9756615083220127, 0.9295626939998534, 0.3599499850798584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.03217915333176364], {
             RGBColor[
             0.2571081050813221, 0.3875672984088326, 0.9379532982758011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.03217915333176364], {
             RGBColor[
             0.23863402700947722`, 0.3681498710311214, 0.9369012268595588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.03217915333176364], {
             RGBColor[
             0.23492201148043795`, 0.36424830735472313`, 0.9366898330666149]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.03217915333176364], {
             RGBColor[
             0.36785717736282086`, 0.49304113081751505`, 0.9446605119515972]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.03217915333176364], {
             RGBColor[
             0.24689616138342244`, 0.3768338981077132, 0.9373717431894225]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.03217915333176364], {
             RGBColor[
             0.9688572327835747, 0.9066102748888301, 0.333516659492644]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.03217915333176364], {
             RGBColor[
             0.30868412390727973`, 0.44177696430338015`, 0.9408904762480571]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.03217915333176364], {
             RGBColor[
             0.5255566438526651, 0.6257095853934133, 0.9557928906629534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.03217915333176364], {
             RGBColor[
             0.8174582326741875, 0.1351972033459516, 0.16435132936604271`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.03217915333176364], {
             RGBColor[
             0.3387393935852255, 0.4678207700117279, 0.942805152517134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.03217915333176364], {
             RGBColor[
             0.7400936775781565, 0.7968860729351169, 0.9747292792785006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.03217915333176364], {
             RGBColor[
             0.2505222001886238, 0.3806450947961188, 0.9375782407351351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.03217915333176364], {
             RGBColor[
             0.5784190314529432, 0.6686256530707418, 0.9599544114561535]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.03217915333176364], {
             RGBColor[
             0.22922310747734106`, 0.35825839791608494`, 0.9363652889144115]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.03217915333176364], {
             RGBColor[
             0.32451491921663345`, 0.4555002452565231, 0.9418987815885761]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.03217915333176364], {
             RGBColor[
             0.23920651037948798`, 0.3687515873505448, 0.9369338289405676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.03217915333176364], {
             RGBColor[
             0.290961948336973, 0.42314983412815754`, 0.9398812245669373]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.03217915333176364], {
             RGBColor[
             0.9183468399249884, 0.7139794601448493, 0.25315815463888625`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.03217915333176364], {
             RGBColor[
             0.2883719521470624, 0.4204275839173185, 0.939733728115478]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.03217915333176364], {
             RGBColor[
             0.2600361752617328, 0.3906448858188163, 0.9381200475408837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.03217915333176364], {
             RGBColor[
             0.22989884827362161`, 0.3589686443374169, 0.9364037713530907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.03217915333176364], {
             RGBColor[
             0.4438028563584466, 0.5588214608227114, 0.9494997034610714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.03217915333176364], {
             RGBColor[
             0.9070075396154186, 0.6690229130152352, 0.24403428744221908`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.03217915333176364], {
             RGBColor[
             0.21620788903044316`, 0.3445785781158837, 0.9356240914781508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.03217915333176364], {
             RGBColor[
             0.2695692814994847, 0.4006647849085395, 0.938662943838157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.03217915333176364], {
             RGBColor[
             0.9882272169582415, 0.9893996659125786, 0.8447690121952027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.03217915333176364], {
             RGBColor[
             0.822315843269912, 0.8611563485272284, 0.9829144132927453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.03217915333176364], {
             RGBColor[
             0.2243331252717409, 0.35311871657522015`, 0.9360868116618829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.03217915333176364], {
             RGBColor[
             0.34171577858230273`, 0.47039876509873646`, 0.9429948051372339]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.03217915333176364], {
             RGBColor[
             0.46951139015292603`, 0.5802095236300584, 0.951380802991181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.03217915333176364], {
             RGBColor[
             0.26047497796174324`, 0.3911060952782254, 0.938145036705499]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.03217915333176364], {
             RGBColor[
             0.22530836548640581`, 0.35414375587463387`, 0.9361423501493695]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.03217915333176364], {
             RGBColor[
             0.8226071697061851, 0.17477418965247965`, 0.16928195728277629`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.03217915333176364], {
             RGBColor[
             0.2529332615169164, 0.38317927312227185`, 0.9377155471109357]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.03217915333176364], {
             RGBColor[
             0.2110206902246306, 0.3391265032835748, 0.9353286881799328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.03217915333176364], {
             RGBColor[
             0.8089540339665278, 0.8506803067038047, 0.9815926360666765]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.03217915333176364], {
             RGBColor[
             0.17944836957228805`, 0.3059419924772149, 0.9335306912258446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.03217915333176364], {
             RGBColor[
             0.9386428604207964, 0.9537605262817009, 0.9887458121893573]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.03217915333176364], {
             RGBColor[
             0.26208361027682536`, 0.3927968698345563, 0.9382366459360847]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.03217915333176364], {
             RGBColor[
             0.19003101446562676`, 0.31706502323855396`, 0.9341333571969002]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.03217915333176364], {
             RGBColor[
             0.5918946974095183, 0.6795658057661227, 0.9610152652432459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.03217915333176364], {
             RGBColor[
             0.2549979314676595, 0.3853493721481386, 0.937833127010225]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.03217915333176364], {
             RGBColor[
             0.5711989452526345, 0.6627640618321545, 0.9593860198224179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.03217915333176364], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.03217915333176364], {
             RGBColor[
             0.9930589289900814, 0.9875620758967413, 0.48588543977432486`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.03217915333176364], {
             RGBColor[
             0.249587147505622, 0.3796622951405196, 0.9375249908681246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.03217915333176364], {
             RGBColor[
             0.30678788301618565`, 0.43978389489822367`, 0.9407824881345462]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.03217915333176364], {
             RGBColor[
             0.6470169280819229, 0.7241738088191627, 0.9654522587403933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.03217915333176364], {
             RGBColor[
             0.2754373969927425, 0.40683254635196486`, 0.938997124334399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.03217915333176364], {
             RGBColor[
             0.2307279730478894, 0.35984010704471925`, 0.9364509887824051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.03217915333176364], {
             RGBColor[
             0.992100640761205, 0.9910014261975552, 0.7805763556806252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.03217915333176364], {
             RGBColor[
             0.765566144894021, 0.8167853580001923, 0.977268136766805]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.03217915333176364], {
             RGBColor[
             0.2578128298869203, 0.3883080088616496, 0.9379934313109329]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.03217915333176364], {
             RGBColor[
             0.2524156236360728, 0.382635202889368, 0.9376860683993983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.03217915333176364], {
             RGBColor[
             0.9456496399519233, 0.8222259641328803, 0.2751266284196432]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.03217915333176364], {
             RGBColor[
             0.23901320904650822`, 0.3685484153935707, 0.9369228207156182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.03217915333176364], {
             RGBColor[
             0.6319940482543123, 0.7121202652370958, 0.9641720330305101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.03217915333176364], {
             RGBColor[
             0.6468617732853108, 0.7240526007128293, 0.965436794360271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.03217915333176364], {
             RGBColor[
             0.9089152991886196, 0.6765865439997854, 0.2455693155756892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.03217915333176364], {
             RGBColor[
             0.24399808998490613`, 0.37378784131953313`, 0.9372067023105894]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.03217915333176364], {
             RGBColor[
             0.23871510677441427`, 0.3682350910048242, 0.9369058442322252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.03217915333176364], {
             RGBColor[
             0.726249879738111, 0.7860711928457129, 0.9733494588874512]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.03217915333176364], {
             RGBColor[
             0.260213393629744, 0.3908311535598896, 0.9381301398647709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.03217915333176364], {
             RGBColor[
             0.245025991273468, 0.37486823074651754`, 0.9372652397683294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.03217915333176364], {
             RGBColor[
             0.8977533081905217, 0.6286034774622947, 0.23639519286946437`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.03217915333176364], {
             RGBColor[
             0.4051337172328171, 0.5253281960795354, 0.9470357401097634]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.03217915333176364], {
             RGBColor[
             0.696491580031562, 0.7628237829435023, 0.9703834296798242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.03217915333176364], {
             RGBColor[
             0.2110186790508826, 0.3391243894124498, 0.9353285736465631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.03217915333176364], {
             RGBColor[
             0.21123106399266978`, 0.3393476194522512, 0.9353406686548026]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.03217915333176364], {
             RGBColor[
             0.21275955169572475`, 0.34095415693987974`, 0.9354277137682966]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.03217915333176364], {
             RGBColor[
             0.24238734999627973`, 0.3720948514646729, 0.9371149730511135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.03217915333176364], {
             RGBColor[
             0.30152154075751214`, 0.43424863527897317`, 0.94048257773377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.03217915333176364], {
             RGBColor[
             0.9466390204165737, 0.9597240493140413, 0.9752103990490407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.03217915333176364], {
             RGBColor[
             0.8234301328695646, 0.862044852807406, 0.9830206952294982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.03217915333176364], {
             RGBColor[
             0.21412870248835636`, 0.3423932212321097, 0.9355056848804599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.03217915333176364], {
             RGBColor[
             0.8899967779325137, 0.5933828851443484, 0.2299229538922278]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.03217915333176364], {
             RGBColor[
             0.2568179059531509, 0.3872622807254372, 0.9379367718647629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.03217915333176364], {
             RGBColor[
             0.9872770340850194, 0.9687445898536212, 0.4050741092611545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.03217915333176364], {
             RGBColor[
             0.28961174034798287`, 0.421730679923598, 0.9398043322194181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.03217915333176364], {
             RGBColor[
             0.21909843402136348`, 0.34761672417247863`, 0.9357887037392056]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.03217915333176364], {
             RGBColor[
             0.20290260740476634`, 0.33059388352371805`, 0.9348663753729688]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.03217915333176364], {
             RGBColor[
             0.9703761157708419, 0.9117338238555674, 0.33941723308119276`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.03217915333176364], {
             RGBColor[
             0.9852399747517544, 0.9881643644915732, 0.8942753462917085]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.03217915333176364], {
             RGBColor[
             0.2610883790761277, 0.39175081874132034`, 0.9381799689915176]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.03217915333176364], {
             RGBColor[
             0.27079044913528966`, 0.40194830952027055`, 0.9387324875284604]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.03217915333176364], {
             RGBColor[
             0.18257815057035692`, 0.3092315907457619, 0.9337089276235886]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.03217915333176364], {
             RGBColor[
             0.519374038863881, 0.6206902681403376, 0.955306173350608]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.03217915333176364], {
             RGBColor[
             0.46295717480753656`, 0.5748885163486347, 0.9508648311503101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.03217915333176364], {
             RGBColor[
             0.2828083531870263, 0.41457988865777246`, 0.939416889385311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.03217915333176364], {
             RGBColor[
             0.9258119809847409, 0.9436813594132142, 0.9927859673000785]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.03217915333176364], {
             RGBColor[
             0.24327422624281886`, 0.37302701463098736`, 0.937165479341338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.03217915333176364], {
             RGBColor[
             0.25427950679235417`, 0.38459426226363735`, 0.9377922137877805]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.03217915333176364], {
             RGBColor[
             0.9906270631619555, 0.9903920639910485, 0.8049973499967711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.03217915333176364], {
             RGBColor[
             0.2238174684207968, 0.35257672853034516`, 0.9360574457670676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.03217915333176364], {
             RGBColor[
             0.24158367299712782`, 0.37125013598249945`, 0.9370692048349454]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.03217915333176364], {
             RGBColor[
             0.7098940201909748, 0.7732938710583535, 0.9717192596619902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.03217915333176364], {
             RGBColor[
             0.8177864636409283, 0.8575802678943982, 0.9824729701128726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.03217915333176364], {
             RGBColor[
             0.5084161265639328, 0.611794141286916, 0.9544435263542006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.03217915333176364], {
             RGBColor[
             0.8302102447519867, 0.867451129981215, 0.983667388353521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.03217915333176364], {
             RGBColor[
             0.2799576543907215, 0.4115836234781131, 0.9392545463060924]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.03217915333176364], {
             RGBColor[
             0.21156771774634342`, 0.33970146389244305`, 0.9353598405880397]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.03217915333176364], {
             RGBColor[
             0.3393902356747875, 0.4683844967174319, 0.9428466235995638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.03217915333176364], {
             RGBColor[
             0.3185921337049145, 0.45037022613412764`, 0.941521386933083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.03217915333176364], {
             RGBColor[
             0.3094371851822424, 0.44244066986488095`, 0.9409380417086214]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.03217915333176364], {
             RGBColor[
             0.23513882534723038`, 0.36447619247551505`, 0.9367021802955814]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.03217915333176364], {
             RGBColor[
             0.22477195032544567`, 0.3535799495297792, 0.936111802099508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.03217915333176364], {
             RGBColor[
             0.45209247002133757`, 0.5660015075294104, 0.9500279103134532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.03217915333176364], {
             RGBColor[
             0.5272216074067284, 0.6270612778123552, 0.9559239626928917]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.03217915333176364], {
             RGBColor[
             0.19556045555100107`, 0.3228768164060961, 0.9344482506866372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.03217915333176364], {
             RGBColor[
             0.26139903658851843`, 0.39207733948366696`, 0.9381976604772716]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.03217915333176364], {
             RGBColor[
             0.28051817934621337`, 0.41217277074566994`, 0.9392864673730853]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.03217915333176364], {
             RGBColor[
             0.2110065608580655, 0.33911165242346125`, 0.9353278835334095]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.03217915333176364], {
             RGBColor[
             0.2847433322190086, 0.4166136743051424, 0.9395270835786375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.03217915333176364], {
             RGBColor[
             0.9942883740099587, 0.9901917344782997, 0.6197029429328111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.03217915333176364], {
             RGBColor[
             0.36576050208801136`, 0.49122509607643855`, 0.9445269136571035]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.03217915333176364], {
             RGBColor[
             0.99377812825938, 0.9891003704115706, 0.5641658418540755]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.03217915333176364], {
             RGBColor[
             0.2215837127017966, 0.35022890964138337`, 0.935930236683416]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.03217915333176364], {
             RGBColor[
             0.6033581995623302, 0.6888723932386622, 0.9619177141249072]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.03217915333176364], {
             RGBColor[
             0.7222005724227306, 0.7829078431950623, 0.9729458617771823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.03217915333176364], {
             RGBColor[
             0.32062864936426844`, 0.45213415364000675`, 0.941651151910077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.03217915333176364], {
             RGBColor[
             0.20194739446585683`, 0.3295898941609259, 0.9348119774092088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.03217915333176364], {
             RGBColor[
             0.3450320119322843, 0.4732711197477559, 0.9432061125938647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.03217915333176364], {
             RGBColor[
             0.2800500850584523, 0.411680773970341, 0.9392598100958807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.03217915333176364], {
             RGBColor[
             0.26295522261758464`, 0.39371298966810864`, 0.9382862829694559]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.03217915333176364], {
             RGBColor[
             0.4453791406536688, 0.5601867590528806, 0.9496001429025095]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.03217915333176364], {
             RGBColor[
             0.4327427506991586, 0.5492417531977101, 0.948794963308529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.03217915333176364], {
             RGBColor[
             0.24574449108125243`, 0.37562341960001794`, 0.9373061572694574]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.03217915333176364], {
             RGBColor[
             0.9941541355650164, 0.9899046120181566, 0.6050919166244885]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.03217915333176364], {
             RGBColor[
             0.21037964845754836`, 0.3384527277419758, 0.9352921817996338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.03217915333176364], {
             RGBColor[
             0.27977343586669706`, 0.4113899981292344, 0.939244055333676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.03217915333176364], {
             RGBColor[
             0.23092116646773903`, 0.3600431655781515, 0.9364619908618614]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.03217915333176364], {
             RGBColor[
             0.5183784049780293, 0.6198819676990077, 0.9552277934039866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.03217915333176364], {
             RGBColor[
             0.6756901028072094, 0.7465735108387558, 0.9683101328309576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.03217915333176364], {
             RGBColor[
             0.9685766725786527, 0.9056638794389593, 0.332426736075871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.03217915333176364], {
             RGBColor[
             0.2455681205459235, 0.37543804298484945`, 0.9372961132283874]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.03217915333176364], {
             RGBColor[
             0.3103917228488082, 0.4432674424152022, 0.9409988640046705]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.03217915333176364], {
             RGBColor[
             0.35562652096447817`, 0.48244755097593534`, 0.9438811853410396]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.03217915333176364], {
             RGBColor[
             0.40465902674538534`, 0.5249170430379596, 0.9470054932516565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.03217915333176364], {
             RGBColor[
             0.8625124936811881, 0.46858316947675277`, 0.2069893934114667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.03217915333176364], {
             RGBColor[
             0.34952976604112324`, 0.4771668482931376, 0.9434927055084721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.03217915333176364], {
             RGBColor[
             0.25624071750281635`, 0.38665561906827417`, 0.93790390183639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.03217915333176364], {
             RGBColor[
             0.9012804456996433, 0.6446193851073215, 0.2393383228651273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.03217915333176364], {
             RGBColor[
             0.21931469518675756`, 0.34784402836905765`, 0.9358010194926452]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.03217915333176364], {
             RGBColor[
             0.21278150541118618`, 0.3409772316867757, 0.9354289639999145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.03217915333176364], {
             RGBColor[
             0.25745394897088236`, 0.38793080226452953`, 0.9379729935736814]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.03217915333176364], {
             RGBColor[
             0.8312166238387177, 0.8682535893475418, 0.9837633776892186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.03217915333176364], {
             RGBColor[
             0.27204560568907665`, 0.4032675586398226, 0.9388039668373608]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.03217915333176364], {
             RGBColor[
             0.2514775053864574, 0.3816491811288898, 0.9376326439529042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.03217915333176364], {
             RGBColor[
             0.2503218011924054, 0.380434462745063, 0.9375668283087641]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.03217915333176364], {
             RGBColor[
             0.2761037265699157, 0.40753290098530925`, 0.9390350708180728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.03217915333176364], {
             RGBColor[
             0.25484534055170655`, 0.38518898942064916`, 0.9378244371832996]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.03217915333176364], {
             RGBColor[
             0.43839329858407067`, 0.5541359737708264, 0.9491550112231723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.03217915333176364], {
             RGBColor[
             0.41487938737084307`, 0.5337694057214698, 0.9476567255932007]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.03217915333176364], {
             RGBColor[
             0.20852643568424656`, 0.3365048836167593, 0.9351866440737768]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.03217915333176364], {
             RGBColor[
             0.22095736038557218`, 0.3495705736440009, 0.9358945668456122]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.03217915333176364], {
             RGBColor[
             0.26549066491796636`, 0.3963779002821365, 0.9384306726576119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.03217915333176364], {
             RGBColor[
             0.9931470290452047, 0.9914341346439413, 0.7632349938486772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.03217915333176364], {
             RGBColor[
             0.898780922280212, 0.63326963303821, 0.23725265925502825`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.03217915333176364], {
             RGBColor[
             0.28023632613366145`, 0.41187652514875206`, 0.939270416249595]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.03217915333176364], {
             RGBColor[
             0.7484278388783107, 0.8033967830847693, 0.9755599505897345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.03217915333176364], {
             RGBColor[
             0.5754210452890663, 0.6661917528451691, 0.9597183990033479]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.03217915333176364], {
             RGBColor[
             0.3393631406607411, 0.4683610283780999, 0.942844897129228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.03217915333176364], {
             RGBColor[
             0.2935687509337651, 0.4258897489382169, 0.9400296781184059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.03217915333176364], {
             RGBColor[
             0.22336510960731928`, 0.352101270736175, 0.9360316846018449]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.03217915333176364], {
             RGBColor[
             0.17908812663026416`, 0.30556335430442605`, 0.933510175923228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.03217915333176364], {
             RGBColor[
             0.26629927432356376`, 0.3972278000362168, 0.9384767217670303]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.03217915333176364], {
             RGBColor[
             0.8203907902431329, 0.1577381258757864, 0.16715954980591485`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.03217915333176364], {
             RGBColor[
             0.24794921220500737`, 0.3779407212884774, 0.9374317128758627]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.03217915333176364], {
             RGBColor[
             0.22281999879048459`, 0.3515283247056597, 0.9360006413472455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.03217915333176364], {
             RGBColor[
             0.35886795134781274`, 0.48525511505495156`, 0.9440877264187814]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.03217915333176364], {
             RGBColor[
             0.27306809856961783`, 0.40434226348706437`, 0.938862196294265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.03217915333176364], {
             RGBColor[
             0.2782995151593558, 0.4098408140138484, 0.9391601177298633]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.03217915333176364], {
             RGBColor[
             0.2493495489754894, 0.37941256402073326`, 0.9375114599833291]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.03217915333176364], {
             RGBColor[
             0.9394254025446074, 0.954344144916344, 0.9874211724934188]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.03217915333176364], {
             RGBColor[
             0.2348790166106703, 0.36420311702056507`, 0.9366873845723869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.03217915333176364], {
             RGBColor[
             0.38961090759033284`, 0.5118831185663134, 0.9460466404056259]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{{3.8349502435193233`*^9, 3.8349502581408367`*^9}, 
   3.8349577843740606`*^9, 3.83501892289773*^9, 3.8350190217900667`*^9, 
   3.835020556050778*^9, 3.835044646730012*^9, 3.835045035421321*^9, 
   3.83504571337293*^9},
 CellLabel->
  "Out[332]=",ExpressionUUID->"f876ef1b-cad8-459a-b86f-42adc8e76765"]
}, Open  ]],

Cell["Estimated with Max-Min Deviation v Calculated: (r = 6)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 3.8349503922098827`*^9}, {3.8349504781120467`*^9, 
  3.834950521977162*^9}},ExpressionUUID->"32cc93a8-cede-4827-bb46-\
858e9816ddae"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphinf4", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsif4", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}],
      "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"mMDi6f400", ",", "krif4"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502554527807`*^9}, {3.8349505249112787`*^9, 3.834950525026289*^9}, {
   3.834957796266032*^9, 3.834957804349044*^9}, {3.835018837121126*^9, 
   3.835018838508815*^9}, {3.8350443533371973`*^9, 3.835044357496614*^9}, {
   3.8350449455086536`*^9, 3.835044948398612*^9}, {3.8350456133625484`*^9, 
   3.835045615019519*^9}},
 CellLabel->
  "In[333]:=",ExpressionUUID->"42e52372-481f-4e6c-9597-f17b30180536"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN2wucz2W+wPHn16rdrWxoc2ntsSnFoptQYTEuNY3rMEhyNxmZGTMj4zII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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[105, 155] -> 
             RGBColor[
              0.9253284230769231, 0.9397734615384615, 0.8453367692307694], 
             UndirectedEdge[1, 203] -> 
             RGBColor[
              0.9780118846153847, 0.9805349230769231, 0.7805222692307692], 
             UndirectedEdge[187, 193] -> 
             RGBColor[
              0.9299049615384615, 0.7720675384615385, 0.5742108461538461], 
             UndirectedEdge[209, 371] -> 
             RGBColor[
              0.940251846153846, 0.9529624615384615, 0.9081504230769231], 
             UndirectedEdge[23, 245] -> 
             RGBColor[
              0.970551423076923, 0.974970923076923, 0.7931508846153845], 
             UndirectedEdge[201, 236] -> 
             RGBColor[
              0.8732950384615384, 0.8825242307692306, 0.6794716923076921], 
             UndirectedEdge[258, 369] -> 
             RGBColor[
              0.9869913461538461, 0.9698530769230769, 0.5759824230769228], 
             UndirectedEdge[161, 312] -> 
             RGBColor[
              0.9066710384615385, 0.9237494615384616, 0.7505689230769231], 
             UndirectedEdge[74, 132] -> 
             RGBColor[
              0.6057970384615384, 0.6693183461538461, 0.853020923076923], 
             UndirectedEdge[89, 169] -> 
             RGBColor[
              0.9392186923076922, 0.7872180769230768, 0.30880673076923054`], 
             UndirectedEdge[124, 137] -> 
             RGBColor[
              0.9220335769230769, 0.792949846153846, 0.6053503846153846], 
             UndirectedEdge[186, 393] -> 
             RGBColor[
              0.9756383846153847, 0.9294846923076923, 0.3598601538461537], 
             UndirectedEdge[84, 261] -> 
             RGBColor[
              0.9241556923076923, 0.9394729230769231, 0.8781770384615384], 
             UndirectedEdge[58, 243] -> 
             RGBColor[
              0.9422756538461539, 0.9521396153846153, 0.7539649230769232], 
             UndirectedEdge[205, 250] -> 
             RGBColor[0.9740421153846153, 0.931222, 0.5605805769230767], 
             UndirectedEdge[327, 337] -> 
             RGBColor[
              0.9563479999999999, 0.9664519999999999, 0.9381238076923077], 
             UndirectedEdge[38, 224] -> 
             RGBColor[0.8970252692307692, 0.558147, 0.5442448076923077], 
             UndirectedEdge[49, 301] -> 
             RGBColor[
              0.948407346153846, 0.9274946923076921, 0.6654507692307691], 
             UndirectedEdge[22, 97] -> 
             RGBColor[
              0.9852851923076922, 0.9691475384615383, 0.6042578076923074], 
             UndirectedEdge[163, 169] -> 
             RGBColor[
              0.8971774615384615, 0.6259886923076922, 0.23591469230769227`], 
             UndirectedEdge[126, 318] -> 
             RGBColor[
              0.9427031923076923, 0.9530540769230769, 0.8004998461538462], 
             UndirectedEdge[126, 149] -> 
             RGBColor[
              0.9456953076923076, 0.8080097692307692, 0.4237151923076922], 
             UndirectedEdge[28, 47] -> 
             RGBColor[
              0.9854723461538462, 0.986098923076923, 0.7678936538461538], 
             UndirectedEdge[203, 392] -> 
             RGBColor[
              0.9772666923076923, 0.9811488461538462, 0.8598974615384615], 
             UndirectedEdge[116, 387] -> 
             RGBColor[
              0.7649390769230768, 0.8138719230769231, 0.8918957307692307], 
             UndirectedEdge[114, 203] -> 
             RGBColor[
              0.9755605384615385, 0.9804433076923078, 0.8881728461538461], 
             UndirectedEdge[38, 207] -> 
             RGBColor[0.8970252692307692, 0.558147, 0.5442448076923077], 
             UndirectedEdge[4, 73] -> 
             RGBColor[
              0.9921893461538461, 0.9908536923076923, 0.7657011923076924], 
             UndirectedEdge[143, 223] -> 
             RGBColor[
              0.7511891538461539, 0.8044676153846154, 0.9532517307692308], 
             UndirectedEdge[70, 164] -> 
             RGBColor[
              0.9600779615384615, 0.9663346923076923, 0.7556629230769232], 
             UndirectedEdge[291, 331] -> 
             RGBColor[
              0.9153949615384616, 0.7344932307692309, 0.5809571538461538], 
             UndirectedEdge[317, 381] -> 
             RGBColor[
              0.9467231538461538, 0.8190013846153845, 0.3149500384615383], 
             UndirectedEdge[120, 349] -> 
             RGBColor[
              0.9946406923076923, 0.9909453076923077, 0.6580506153846155], 
             UndirectedEdge[102, 160] -> 
             RGBColor[
              0.5239531538461539, 0.4016707307692309, 0.5729432307692308], 
             UndirectedEdge[84, 381] -> 
             RGBColor[
              0.9184242692307691, 0.9180673076923076, 0.6838933846153844], 
             UndirectedEdge[110, 203] -> 
             RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 
             UndirectedEdge[316, 355] -> 
             RGBColor[
              0.9513988461538461, 0.8441884615384614, 0.28408142307692297`], 
             UndirectedEdge[62, 77] -> 
             RGBColor[
              0.9909067307692307, 0.9881103076923077, 0.6260964230769229], 
             UndirectedEdge[188, 361] -> 
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079], 
             UndirectedEdge[168, 282] -> 
             RGBColor[
              0.7558055384615384, 0.8094480769230769, 0.976218923076923], 
             UndirectedEdge[271, 394] -> 
             RGBColor[
              0.9910166153846154, 0.9905531538461538, 0.7985414615384614], 
             UndirectedEdge[160, 224] -> 
             RGBColor[
              0.922855423076923, 0.7400572307692308, 0.5683285384615384], 
             UndirectedEdge[97, 168] -> 
             RGBColor[
              0.8186411923076922, 0.8398282307692306, 0.6740243076923075], 
             UndirectedEdge[88, 132] -> 
             RGBColor[
              0.9597603076923076, 0.9678630769230769, 0.8815730384615384], 
             UndirectedEdge[329, 353] -> 
             RGBColor[
              0.9784394230769231, 0.9814493846153847, 0.8270571923076925], 
             UndirectedEdge[189, 339] -> 
             RGBColor[
              0.9385456923076922, 0.9522569230769231, 0.9364258076923078], 
             UndirectedEdge[316, 380] -> 
             RGBColor[
              0.9135511538461538, 0.6888743076923075, 0.24898430769230764`], 
             UndirectedEdge[156, 295] -> 
             RGBColor[
              0.9683733461538461, 0.9035196153846152, 0.5220423076923076], 
             UndirectedEdge[154, 228] -> 
             RGBColor[
              0.8635703846153846, 0.8938200000000001, 0.9633867307692308], 
             UndirectedEdge[29, 91] -> 
             RGBColor[
              0.9241556923076923, 0.9394729230769231, 0.8781770384615384], 
             UndirectedEdge[6, 198] -> 
             RGBColor[
              0.8312933461538462, 0.5938827692307692, 0.5855608461538462], 
             UndirectedEdge[56, 254] -> 
             RGBColor[
              0.9184242692307691, 0.9180673076923076, 0.6838933846153844], 
             UndirectedEdge[245, 315] -> 
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077], 
             UndirectedEdge[174, 281] -> 
             RGBColor[
              0.9096491923076923, 0.8343726153846154, 0.6252469615384615], 
             UndirectedEdge[89, 329] -> 
             RGBColor[
              0.9881640769230768, 0.9701536153846153, 0.5431421538461538], 
             UndirectedEdge[260, 267] -> 
             RGBColor[
              0.9299049615384615, 0.7720675384615385, 0.5742108461538461], 
             UndirectedEdge[202, 363] -> 
             RGBColor[
              0.8242042692307692, 0.6892845384615385, 0.6006973461538461], 
             UndirectedEdge[43, 238] -> 
             RGBColor[
              0.9063533846153846, 0.9252778461538462, 0.8764790384615384], 
             UndirectedEdge[276, 377] -> 
             RGBColor[
              0.9825425384615385, 0.9511908461538461, 0.5213035384615385], 
             UndirectedEdge[284, 369] -> 
             RGBColor[
              0.9546825384615384, 0.8505576923076921, 0.32135434615384595`], 
             UndirectedEdge[53, 249] -> 
             RGBColor[0.9418481153846154, 0.9512251538461538, 0.70743], 
             UndirectedEdge[15, 105] -> 
             RGBColor[
              0.8998062692307691, 0.851733846153846, 0.6299532692307692], 
             UndirectedEdge[97, 112] -> 
             RGBColor[
              0.9852851923076922, 0.9691475384615383, 0.6042578076923074], 
             UndirectedEdge[120, 246] -> 
             RGBColor[
              0.9386457692307693, 0.7759994615384616, 0.4178328846153846], 
             UndirectedEdge[53, 308] -> 
             RGBColor[
              0.9682634615384615, 0.9010767692307691, 0.34959726923076906`], 
             UndirectedEdge[188, 392] -> 
             RGBColor[
              0.9927227692307692, 0.9912586923076924, 0.7702660769230769], 
             UndirectedEdge[91, 273] -> 
             RGBColor[
              0.9927227692307692, 0.9912586923076924, 0.7702660769230769], 
             UndirectedEdge[327, 354] -> 
             RGBColor[0.873390923076923, 0.9018822307692307, 0.987786], 
             UndirectedEdge[51, 376] -> 
             RGBColor[
              0.9934679615384615, 0.9906447692307693, 0.6908908846153845], 
             UndirectedEdge[202, 214] -> 
             RGBColor[0.9055917692307691, 0.657318, 0.24258], 
             UndirectedEdge[69, 132] -> 
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079], 
             UndirectedEdge[130, 387] -> 
             RGBColor[0.9740421153846153, 0.931222, 0.5605805769230767], 
             UndirectedEdge[61, 306] -> 
             RGBColor[0.597801423076923, 0.6647725, 0.9300236923076923], 
             UndirectedEdge[312, 356] -> 
             RGBColor[0.9062435, 0.922835, 0.7040339999999999], 
             UndirectedEdge[18, 247] -> 
             RGBColor[
              0.9385456923076922, 0.9522569230769231, 0.9364258076923078], 
             UndirectedEdge[56, 320] -> 
             RGBColor[
              0.8459681153846152, 0.8611762307692306, 0.6767479999999998], 
             UndirectedEdge[43, 124] -> 
             RGBColor[0.8834368461538462, 0.909604, 0.9787390384615384], 
             UndirectedEdge[259, 318] -> 
             RGBColor[0.9249835, 0.8943368461538461, 0.6419141538461539], 
             UndirectedEdge[267, 384] -> 
             RGBColor[
              0.8515311923076923, 0.7106325384615384, 0.6034210384615384], 
             UndirectedEdge[44, 324] -> 
             RGBColor[
              0.9315962307692307, 0.7439891538461539, 0.4119505769230769], 
             UndirectedEdge[62, 204] -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 
             UndirectedEdge[42, 109] -> 
             RGBColor[
              0.9784394230769231, 0.9814493846153847, 0.8270571923076925], 
             UndirectedEdge[8, 21] -> 
             RGBColor[
              0.9780118846153847, 0.9805349230769231, 0.7805222692307692], 
             UndirectedEdge[48, 349] -> 
             RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 
             UndirectedEdge[222, 332] -> 
             RGBColor[
              0.8460639999999999, 0.8805342307692307, 0.9850623076923077], 
             UndirectedEdge[58, 167] -> 
             RGBColor[
              0.9190414615384614, 0.9379941538461538, 0.9821350384615385], 
             UndirectedEdge[76, 144] -> 
             RGBColor[
              0.9603040769230768, 0.8695204615384615, 0.34319296153846146`], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.9086996153846154, 0.929363076923077, 0.967808423076923], 
             UndirectedEdge[6, 166] -> 
             RGBColor[0.8908973076923077, 0.915168, 0.9661104230769231], 
             UndirectedEdge[79, 343] -> 
             RGBColor[
              0.9291448846153846, 0.7438975384615385, 0.5196011538461538], 
             UndirectedEdge[142, 257] -> 
             RGBColor[
              0.9580541538461538, 0.9671575384615384, 0.909848423076923], 
             UndirectedEdge[175, 256] -> 
             RGBColor[
              0.9207433846153845, 0.9380618461538461, 0.9347278076923078], 
             UndirectedEdge[8, 171] -> 
             RGBColor[
              0.993358076923077, 0.988201923076923, 0.518445846153846], 
             UndirectedEdge[31, 214] -> 
             RGBColor[
              0.9449578846153845, 0.8618534615384615, 0.6052693846153845], 
             UndirectedEdge[41, 114] -> 
             RGBColor[
              0.9917618076923076, 0.9899392307692307, 0.7191662692307691], 
             UndirectedEdge[72, 399] -> 
             RGBColor[
              0.9640748076923076, 0.9541792307692306, 0.6782424230769228], 
             UndirectedEdge[278, 392] -> 
             RGBColor[
              0.9241556923076923, 0.9394729230769231, 0.8781770384615384], 
             UndirectedEdge[6, 323] -> 
             RGBColor[
              0.9070985769230769, 0.9246639230769231, 0.7971038461538461], 
             UndirectedEdge[132, 323] -> 
             RGBColor[
              0.9934679615384615, 0.9906447692307693, 0.6908908846153845], 
             UndirectedEdge[200, 355] -> 
             RGBColor[0.9249835, 0.8943368461538461, 0.6419141538461538], 
             UndirectedEdge[98, 215] -> 
             RGBColor[
              0.8740445769230769, 0.8059824615384614, 0.6218509615384615], 
             UndirectedEdge[12, 367] -> 
             RGBColor[
              0.9929305384615386, 0.9872874615384615, 0.47191092307692306`], 
             UndirectedEdge[88, 140] -> 
             RGBColor[0.872058423076923, 0.5392972307692308, 0.578549], 
             UndirectedEdge[195, 327] -> 
             RGBColor[
              0.9368437692307692, 0.9521892307692307, 0.9838330384615385], 
             UndirectedEdge[142, 381] -> 
             RGBColor[
              0.9540288846153845, 0.9464574615384613, 0.6872893846153845], 
             UndirectedEdge[313, 359] -> 
             RGBColor[
              0.6433323846153847, 0.7177426923076924, 0.9673883846153846], 
             UndirectedEdge[64, 82] -> 
             RGBColor[
              0.9771568076923077, 0.9787060000000001, 0.6874524230769229], 
             UndirectedEdge[98, 297] -> 
             RGBColor[
              0.9546825384615384, 0.8505576923076921, 0.32135434615384595`], 
             UndirectedEdge[139, 305] -> 
             RGBColor[
              0.8282616923076923, 0.8663391538461538, 0.9833643076923078], 
             UndirectedEdge[288, 375] -> 
             RGBColor[0.9740421153846153, 0.931222, 0.5605805769230768], 
             UndirectedEdge[136, 194] -> 
             RGBColor[
              0.9135511538461538, 0.6888743076923075, 0.24898430769230764`], 
             UndirectedEdge[254, 349] -> 
             RGBColor[
              0.9253284230769231, 0.9397734615384615, 0.8453367692307694], 
             UndirectedEdge[348, 351] -> 
             RGBColor[
              0.9063533846153846, 0.9252778461538462, 0.8764790384615384], 
             UndirectedEdge[65, 282] -> 
             RGBColor[
              0.9161600769230769, 0.9349270769230769, 0.9551798076923077], 
             UndirectedEdge[131, 215] -> 
             RGBColor[
              0.8893788846153846, 0.8659466923076923, 0.6385181538461537], 
             UndirectedEdge[230, 250] -> 
             RGBColor[
              0.9830209999999999, 0.9860073076923077, 0.8755442307692307], 
             UndirectedEdge[26, 111] -> 
             RGBColor[
              0.9789957307692307, 0.9653072307692306, 0.6529851923076921], 
             UndirectedEdge[301, 390] -> 
             RGBColor[
              0.981259923076923, 0.9484474615384615, 0.381698769230769], 
             UndirectedEdge[3, 309] -> 
             RGBColor[0.7554602692307693, 0.6873368461538463, 0.6048775], 
             UndirectedEdge[90, 268] -> 
             RGBColor[
              0.9602921923076924, 0.9218176923076924, 0.6219365769230768], 
             UndirectedEdge[17, 187] -> 
             RGBColor[
              0.9854723461538462, 0.986098923076923, 0.7678936538461538], 
             UndirectedEdge[4, 206] -> 
             RGBColor[
              0.9910166153846154, 0.9905531538461538, 0.7985414615384614], 
             UndirectedEdge[19, 231] -> 
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461], 
             UndirectedEdge[76, 138] -> 
             RGBColor[
              0.9570016538461538, 0.8705522307692307, 0.5721887692307692], 
             UndirectedEdge[28, 390] -> 
             RGBColor[0.9846172692307692, 0.98427, 0.6748238076923075], 
             UndirectedEdge[123, 174] -> 
             RGBColor[
              0.9265019230769231, 0.9435581538461539, 0.969506423076923], 
             UndirectedEdge[2, 98] -> 
             RGBColor[
              0.9449578846153845, 0.8618534615384615, 0.6052693846153845], 
             UndirectedEdge[20, 364] -> 
             RGBColor[
              0.9190414615384614, 0.9379941538461538, 0.9821350384615385], 
             UndirectedEdge[56, 196] -> 
             RGBColor[
              0.981259923076923, 0.9484474615384613, 0.38169876923076884`], 
             UndirectedEdge[360, 374] -> 
             RGBColor[
              0.9513988461538461, 0.8441884615384614, 0.28408142307692297`], 
             UndirectedEdge[39, 360] -> 
             RGBColor[
              0.9666671923076922, 0.9028140769230768, 0.5503176923076922], 
             UndirectedEdge[261, 264] -> 
             RGBColor[0.941958, 0.953668, 0.8798750384615385], 
             UndirectedEdge[101, 253] -> 
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153], 
             UndirectedEdge[141, 273] -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.8268168461538462], 
             UndirectedEdge[171, 182] -> 
             RGBColor[
              0.7665353461538462, 0.8121346153846154, 0.6911753076923075], 
             UndirectedEdge[156, 175] -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.8268168461538462], 
             UndirectedEdge[121, 250] -> 
             RGBColor[
              0.9913342692307692, 0.9890247692307692, 0.6726313461538461], 
             UndirectedEdge[68, 308] -> 
             RGBColor[
              0.7422958076923076, 0.7268383846153844, 0.6153965769230769], 
             UndirectedEdge[39, 390] -> 
             RGBColor[
              0.9909067307692307, 0.9881103076923077, 0.6260964230769229], 
             UndirectedEdge[54, 181] -> 
             RGBColor[
              0.9563479999999999, 0.9664519999999999, 0.9381238076923077], 
             UndirectedEdge[196, 313] -> 
             RGBColor[
              0.9184242692307691, 0.9180673076923076, 0.6838933846153844], 
             UndirectedEdge[200, 241] -> 
             RGBColor[
              0.9427031923076923, 0.9530540769230769, 0.8004998461538462], 
             UndirectedEdge[186, 255] -> 
             RGBColor[0.9249835, 0.8943368461538461, 0.6419141538461539], 
             UndirectedEdge[11, 38] -> 
             RGBColor[
              0.9053385384615384, 0.5611644615384616, 0.3413319230769231], 
             UndirectedEdge[173, 310] -> 
             RGBColor[
              0.9528317307692307, 0.9162536923076923, 0.6345651923076923], 
             UndirectedEdge[106, 173] -> 
             RGBColor[
              0.9434394615384615, 0.8126321538461538, 0.27767711538461537`], 
             UndirectedEdge[51, 396] -> 
             RGBColor[
              0.9877365384615384, 0.9692391538461538, 0.4966072307692305], 
             UndirectedEdge[6, 18] -> 
             RGBColor[
              0.9029410769230769, 0.9238667692307692, 0.9330298076923078], 
             UndirectedEdge[238, 287] -> 
             RGBColor[
              0.9241556923076923, 0.9394729230769231, 0.8781770384615384], 
             UndirectedEdge[93, 225] -> 
             RGBColor[
              0.9921893461538461, 0.9908536923076923, 0.7657011923076924], 
             UndirectedEdge[116, 276] -> 
             RGBColor[
              0.7552922692307692, 0.7742090769230768, 0.6474980769230768], 
             UndirectedEdge[135, 276] -> 
             RGBColor[
              0.9779574999999999, 0.9494792307692307, 0.6106945769230768], 
             UndirectedEdge[147, 172] -> 
             RGBColor[
              0.8950004230769231, 0.8849094615384614, 0.6603567692307691], 
             UndirectedEdge[185, 224] -> 
             RGBColor[
              0.9854723461538462, 0.986098923076923, 0.7678936538461538], 
             UndirectedEdge[160, 166] -> 
             RGBColor[
              0.9153949615384616, 0.7344932307692309, 0.5809571538461538], 
             UndirectedEdge[63, 156] -> 
             RGBColor[
              0.9910166153846154, 0.9905531538461538, 0.7985414615384614], 
             UndirectedEdge[247, 302] -> 
             RGBColor[
              0.8555886153846154, 0.8876871538461538, 0.9860880000000001], 
             UndirectedEdge[81, 240] -> 
             RGBColor[
              0.9600779615384615, 0.9663346923076923, 0.7556629230769232], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.9666671923076922, 0.9028140769230768, 0.5503176923076922], 
             UndirectedEdge[12, 212] -> 
             RGBColor[0.987309, 0.9683246923076922, 0.45007230769230755`], 
             UndirectedEdge[18, 74] -> 
             RGBColor[
              0.6023847307692307, 0.6679072692307693, 0.9095716923076924], 
             UndirectedEdge[1, 7] -> 
             RGBColor[
              0.9900556538461538, 0.9892336923076923, 0.7474416538461539], 
             UndirectedEdge[231, 331] -> 
             RGBColor[
              0.9543501538461538, 0.9654750000000001, 0.9621574615384615], 
             UndirectedEdge[58, 351] -> 
             RGBColor[
              0.8555886153846154, 0.8876871538461538, 0.9860880000000001], 
             UndirectedEdge[142, 279] -> 
             RGBColor[
              0.9605054999999999, 0.9672491538461538, 0.8021978461538462], 
             UndirectedEdge[303, 344] -> 
             RGBColor[
              0.9709789615384615, 0.9758853846153845, 0.8396858076923079], 
             UndirectedEdge[302, 323] -> 
             RGBColor[
              0.9070985769230769, 0.9246639230769231, 0.7971038461538461], 
             UndirectedEdge[144, 366] -> 
             RGBColor[
              0.9523446923076924, 0.8379641538461539, 0.33678865384615375`], 
             UndirectedEdge[56, 342] -> 
             RGBColor[
              0.9877365384615384, 0.9692391538461538, 0.4966072307692305], 
             UndirectedEdge[137, 293] -> 
             RGBColor[
              0.890127923076923, 0.5939783846153845, 0.2300323846153846], 
             UndirectedEdge[39, 374] -> 
             RGBColor[0.9740421153846153, 0.931222, 0.5605805769230768], 
             UndirectedEdge[4, 278] -> 
             RGBColor[
              0.9224495384615384, 0.9387673846153846, 0.906452423076923], 
             UndirectedEdge[238, 396] -> 
             RGBColor[
              0.9869913461538461, 0.9698530769230769, 0.5759824230769228], 
             UndirectedEdge[118, 293] -> 
             RGBColor[
              0.9149840384615384, 0.7609395384615385, 0.5994680769230769], 
             UndirectedEdge[201, 228] -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             UndirectedEdge[212, 336] -> 
             RGBColor[
              0.9881640769230768, 0.9701536153846153, 0.5431421538461538], 
             UndirectedEdge[186, 200] -> 
             RGBColor[0.9249835, 0.8943368461538461, 0.6419141538461539], 
             UndirectedEdge[7, 356] -> 
             RGBColor[
              0.989200576923077, 0.9874047692307693, 0.6543718076923076], 
             UndirectedEdge[215, 269] -> 
             RGBColor[
              0.709359076923077, 0.7722076923076924, 0.9721228461538461], 
             UndirectedEdge[36, 122] -> 
             RGBColor[
              0.9756383846153845, 0.929484692307692, 0.35986015384615355`], 
             UndirectedEdge[297, 352] -> 
             RGBColor[
              0.9789957307692307, 0.9653072307692306, 0.6529851923076921], 
             UndirectedEdge[228, 243] -> 
             RGBColor[
              0.8793441153846154, 0.9024014615384615, 0.7478452307692308], 
             UndirectedEdge[100, 271] -> 
             RGBColor[
              0.9909067307692307, 0.9881103076923077, 0.6260964230769229], 
             UndirectedEdge[157, 298] -> 
             RGBColor[
              0.936194423076923, 0.7759078461538462, 0.5254834615384615], 
             UndirectedEdge[272, 384] -> 
             RGBColor[
              0.9046472307692308, 0.9245723076923077, 0.904754423076923], 
             UndirectedEdge[35, 114] -> 
             RGBColor[
              0.9830209999999999, 0.9860073076923077, 0.8755442307692307], 
             UndirectedEdge[15, 155] -> 
             RGBColor[
              0.9695460769230768, 0.9038201538461537, 0.48920203846153865`], 
             UndirectedEdge[36, 262] -> 
             RGBColor[
              0.9659137307692307, 0.9407804615384615, 0.6437751923076922], 
             UndirectedEdge[111, 185] -> 
             RGBColor[
              0.9877365384615384, 0.9692391538461538, 0.4966072307692305], 
             UndirectedEdge[26, 400] -> 
             RGBColor[
              0.9850448076923077, 0.9851844615384615, 0.7213587307692308], 
             UndirectedEdge[61, 131] -> 
             RGBColor[
              0.5888225384615384, 0.6099871923076923, 0.6150600384615384], 
             UndirectedEdge[168, 350] -> 
             RGBColor[
              0.5435493076923077, 0.6395036153846154, 0.9575193076923076], 
             UndirectedEdge[16, 208] -> 
             RGBColor[
              0.8801991923076924, 0.9042303846153845, 0.8409150769230771], 
             UndirectedEdge[125, 303] -> 
             RGBColor[
              0.9640748076923076, 0.9541792307692306, 0.6782424230769228], 
             UndirectedEdge[145, 164] -> 
             RGBColor[0.9382182307692308, 0.775085, 0.3712979615384616], 
             UndirectedEdge[152, 256] -> 
             RGBColor[
              0.9253284230769231, 0.9397734615384615, 0.8453367692307694], 
             UndirectedEdge[237, 246] -> 
             RGBColor[
              0.8871358076923077, 0.7390226923076924, 0.6068170384615384], 
             UndirectedEdge[16, 284] -> 
             RGBColor[
              0.8467176538461538, 0.7846344615384615, 0.6191272692307692], 
             UndirectedEdge[240, 309] -> 
             RGBColor[
              0.7627659999999999, 0.8147929230769231, 0.9772168461538462], 
             UndirectedEdge[151, 249] -> 
             RGBColor[
              0.940251846153846, 0.9529624615384615, 0.9081504230769231], 
             UndirectedEdge[47, 311] -> 
             RGBColor[0.9531997692307692, 0.839793076923077, 0.4298585], 
             UndirectedEdge[29, 190] -> 
             RGBColor[
              0.9253284230769231, 0.9397734615384615, 0.8453367692307694], 
             UndirectedEdge[99, 384] -> 
             RGBColor[0.873390923076923, 0.9018822307692307, 0.987786], 
             UndirectedEdge[5, 398] -> 
             RGBColor[
              0.9448402307692307, 0.806180846153846, 0.33064534615384605`], 
             UndirectedEdge[36, 157] -> 
             RGBColor[
              0.9796636538461538, 0.9501847692307692, 0.5824191923076921], 
             UndirectedEdge[40, 55] -> 
             RGBColor[
              0.9917618076923076, 0.9899392307692307, 0.7191662692307691], 
             UndirectedEdge[163, 319] -> 
             RGBColor[
              0.9456953076923076, 0.8080097692307692, 0.4237151923076923], 
             UndirectedEdge[13, 74] -> 
             RGBColor[
              0.5550322692307692, 0.6317276538461538, 0.9626298846153847], 
             UndirectedEdge[47, 158] -> 
             RGBColor[
              0.9780118846153847, 0.9805349230769231, 0.7805222692307692], 
             UndirectedEdge[252, 330] -> 
             RGBColor[
              0.9291448846153846, 0.7438975384615385, 0.5196011538461538], 
             UndirectedEdge[102, 185] -> 
             RGBColor[
              0.5865700769230768, 0.6477124230769231, 0.7725083461538461], 
             UndirectedEdge[41, 356] -> 
             RGBColor[
              0.993358076923077, 0.988201923076923, 0.518445846153846], 
             UndirectedEdge[33, 175] -> 
             RGBColor[
              0.9563479999999999, 0.9664519999999999, 0.9381238076923077], 
             UndirectedEdge[12, 126] -> 
             RGBColor[
              0.9937856153846154, 0.9891163846153846, 0.5649807692307692], 
             UndirectedEdge[18, 191] -> 
             RGBColor[
              0.9016085769230768, 0.5612817692307692, 0.5237928076923077], 
             UndirectedEdge[64, 171] -> 
             RGBColor[
              0.9771568076923077, 0.9787060000000001, 0.6874524230769229], 
             UndirectedEdge[73, 184] -> 
             RGBColor[
              0.9937856153846154, 0.9891163846153845, 0.5649807692307693], 
             UndirectedEdge[93, 316] -> 
             RGBColor[
              0.9695460769230768, 0.9038201538461537, 0.48920203846153865`], 
             UndirectedEdge[20, 362] -> 
             RGBColor[
              0.9427031923076923, 0.9530540769230769, 0.8004998461538462], 
             UndirectedEdge[32, 330] -> 
             RGBColor[
              0.936194423076923, 0.7759078461538462, 0.5254834615384614], 
             UndirectedEdge[124, 277] -> 
             RGBColor[
              0.966393923076923, 0.9741737692307693, 0.9290768461538462], 
             UndirectedEdge[267, 331] -> 
             RGBColor[0.9224445, 0.7665035384615385, 0.5868394615384616], 
             UndirectedEdge[134, 167] -> 
             RGBColor[
              0.9640748076923076, 0.9541792307692306, 0.6782424230769228], 
             UndirectedEdge[143, 398] -> 
             RGBColor[
              0.9294940384615384, 0.7985138461538461, 0.5927217692307691], 
             UndirectedEdge[109, 320] -> 
             RGBColor[
              0.8528722692307692, 0.8828823846153846, 0.8381913846153848], 
             UndirectedEdge[28, 147] -> 
             RGBColor[0.8983577692307692, 0.920732, 0.9534818076923077], 
             UndirectedEdge[54, 311] -> 
             RGBColor[
              0.9490422692307692, 0.8389959230769231, 0.5657844615384616], 
             UndirectedEdge[160, 289] -> 
             RGBColor[
              0.922855423076923, 0.7400572307692308, 0.5683285384615384], 
             UndirectedEdge[209, 240] -> 
             RGBColor[0.9089955384615384, 0.9302723846153845, 0.991182], 
             UndirectedEdge[31, 261] -> 
             RGBColor[
              0.9772666923076923, 0.9811488461538462, 0.8598974615384615], 
             UndirectedEdge[245, 248] -> 
             RGBColor[
              0.9374974230769231, 0.8562894615384615, 0.6178980000000001], 
             UndirectedEdge[81, 245] -> 
             RGBColor[
              0.9701238846153846, 0.9740564615384615, 0.7466159615384615], 
             UndirectedEdge[308, 386] -> 
             RGBColor[
              0.9666671923076922, 0.9028140769230768, 0.5503176923076922], 
             UndirectedEdge[320, 349] -> 
             RGBColor[
              0.8528722692307692, 0.8828823846153846, 0.8381913846153848], 
             UndirectedEdge[222, 356] -> 
             RGBColor[
              0.8789165769230769, 0.9014869999999999, 0.7013103076923076], 
             UndirectedEdge[200, 374] -> 
             RGBColor[0.9249835, 0.8943368461538461, 0.6419141538461538], 
             UndirectedEdge[73, 348] -> 
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079], 
             UndirectedEdge[23, 81] -> 
             RGBColor[
              0.9937856153846154, 0.9891163846153846, 0.5649807692307692], 
             UndirectedEdge[25, 233] -> 
             RGBColor[
              0.9609330384615384, 0.9681636153846154, 0.8487327692307695], 
             UndirectedEdge[168, 170] -> 
             RGBColor[
              0.7366707307692307, 0.43266799999999994`, 0.5652839230769231], 
             UndirectedEdge[73, 284] -> 
             RGBColor[
              0.9615866923076923, 0.8722638461538461, 0.482797730769231], 
             UndirectedEdge[143, 234] -> 
             RGBColor[
              0.7221059230769231, 0.7808565384615385, 0.9509621923076923], 
             UndirectedEdge[288, 374] -> 
             RGBColor[0.9740421153846153, 0.931222, 0.5605805769230768], 
             UndirectedEdge[254, 344] -> 
             RGBColor[
              0.9253284230769231, 0.9397734615384615, 0.8453367692307694], 
             UndirectedEdge[6, 102] -> 
             RGBColor[0.49945550000000005`, 0.5823455, 0.9580965], 
             UndirectedEdge[205, 276] -> 
             RGBColor[
              0.9643953076923076, 0.8915591538461538, 0.3161829230769229], 
             UndirectedEdge[101, 244] -> 
             RGBColor[0.8970252692307692, 0.558147, 0.5442448076923077], 
             UndirectedEdge[58, 80] -> 
             RGBColor[
              0.9385456923076922, 0.9522569230769231, 0.9364258076923078], 
             UndirectedEdge[23, 292] -> 
             RGBColor[
              0.9946406923076923, 0.9909453076923077, 0.6580506153846155], 
             UndirectedEdge[101, 397] -> 
             RGBColor[
              0.9517646923076921, 0.9633172307692307, 0.9585758076923077], 
             UndirectedEdge[105, 168] -> 
             RGBColor[
              0.7558055384615384, 0.8094480769230769, 0.976218923076923], 
             UndirectedEdge[166, 340] -> 
             RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 
             UndirectedEdge[138, 317] -> 
             RGBColor[
              0.9490422692307692, 0.8389959230769231, 0.5657844615384616], 
             UndirectedEdge[71, 120] -> 
             RGBColor[
              0.9780118846153847, 0.9805349230769231, 0.7805222692307692], 
             UndirectedEdge[231, 290] -> 
             RGBColor[
              0.772811923076923, 0.8225146923076923, 0.9681698846153846], 
             UndirectedEdge[13, 224] -> 
             RGBColor[
              0.9339623846153846, 0.9491221538461538, 0.9568778076923077], 
             UndirectedEdge[40, 159] -> 
             RGBColor[
              0.9921893461538461, 0.9908536923076923, 0.7657011923076924], 
             UndirectedEdge[20, 265] -> 
             RGBColor[
              0.9190414615384614, 0.9379941538461538, 0.9821350384615385], 
             UndirectedEdge[43, 299] -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             UndirectedEdge[219, 220] -> 
             RGBColor[
              0.9605054999999999, 0.9672491538461538, 0.8021978461538462], 
             UndirectedEdge[56, 290] -> 
             RGBColor[
              0.7899970384615385, 0.816782923076923, 0.6716262307692306], 
             UndirectedEdge[64, 157] -> 
             RGBColor[
              0.9755605384615385, 0.9804433076923078, 0.8881728461538461], 
             UndirectedEdge[13, 340] -> 
             RGBColor[
              0.9265019230769231, 0.9435581538461539, 0.969506423076923], 
             UndirectedEdge[16, 188] -> 
             RGBColor[
              0.8790264615384615, 0.9039298461538461, 0.8737553461538461], 
             UndirectedEdge[171, 308] -> 
             RGBColor[
              0.9682634615384615, 0.9010767692307691, 0.34959726923076906`], 
             UndirectedEdge[288, 379] -> 
             RGBColor[
              0.9852851923076922, 0.9691475384615383, 0.6042578076923074], 
             UndirectedEdge[81, 353] -> 
             RGBColor[
              0.9775843461538463, 0.9796204615384616, 0.7339873461538462], 
             UndirectedEdge[153, 188] -> 
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079], 
             UndirectedEdge[148, 356] -> 
             RGBColor[
              0.9112319230769231, 0.6088353846153848, 0.30084992307692304`], 
             UndirectedEdge[198, 247] -> 
             RGBColor[
              0.8668979615384615, 0.6222729230769231, 0.5889568461538461], 
             UndirectedEdge[94, 375] -> 
             RGBColor[
              0.8073981153846153, 0.8019026923076922, 0.6303470769230769], 
             UndirectedEdge[298, 307] -> 
             RGBColor[
              0.7968773461538461, 0.6679365384615384, 0.5979736538461538], 
             UndirectedEdge[9, 142] -> 
             RGBColor[0.926797846153846, 0.9444674615384614, 0.99288], 
             UndirectedEdge[203, 284] -> 
             RGBColor[
              0.9449578846153845, 0.8618534615384615, 0.6052693846153845], 
             UndirectedEdge[370, 400] -> 
             RGBColor[
              0.9066710384615385, 0.9237494615384616, 0.7505689230769231], 
             UndirectedEdge[63, 381] -> 
             RGBColor[
              0.9852851923076922, 0.9691475384615383, 0.6042578076923074], 
             UndirectedEdge[222, 251] -> 
             RGBColor[
              0.8756141538461538, 0.9025187692307692, 0.9303061153846155], 
             UndirectedEdge[103, 234] -> 
             RGBColor[
              0.7358558461538461, 0.7902608461538461, 0.8896061923076922], 
             UndirectedEdge[150, 399] -> 
             RGBColor[
              0.966393923076923, 0.9741737692307693, 0.9290768461538462], 
             UndirectedEdge[321, 338] -> 
             RGBColor[
              0.9615866923076923, 0.8722638461538461, 0.482797730769231], 
             UndirectedEdge[154, 203] -> 
             RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 
             UndirectedEdge[225, 390] -> 
             RGBColor[
              0.9909067307692307, 0.9881103076923077, 0.6260964230769229], 
             UndirectedEdge[54, 121] -> 
             RGBColor[
              0.9896281153846154, 0.9883192307692308, 0.7009067307692309], 
             UndirectedEdge[234, 346] -> 
             RGBColor[
              0.6511926153846154, 0.7249855384615385, 0.9675437692307692], 
             UndirectedEdge[358, 391] -> 
             RGBColor[
              0.9392186923076922, 0.7872180769230768, 0.30880673076923054`], 
             UndirectedEdge[74, 357] -> 
             RGBColor[0.5194276538461539, 0.6033375, 0.9592338846153846], 
             UndirectedEdge[130, 364] -> 
             RGBColor[
              0.9528317307692307, 0.9162536923076923, 0.6345651923076923], 
             UndirectedEdge[202, 381] -> 
             RGBColor[
              0.9321691538461538, 0.755207769230769, 0.3029244230769229], 
             UndirectedEdge[98, 307] -> 
             RGBColor[
              0.8193907307692307, 0.7632864615384615, 0.6164035769230769], 
             UndirectedEdge[242, 317] -> 
             RGBColor[
              0.9467231538461538, 0.8190013846153845, 0.3149500384615383], 
             UndirectedEdge[9, 279] -> 
             RGBColor[
              0.9605054999999999, 0.9672491538461538, 0.8021978461538462], 
             UndirectedEdge[200, 399] -> 
             RGBColor[
              0.9190414615384614, 0.9379941538461538, 0.9821350384615385], 
             UndirectedEdge[275, 306] -> 
             RGBColor[
              0.952418346153846, 0.8674174615384616, 0.5926407692307691], 
             UndirectedEdge[121, 181] -> 
             RGBColor[
              0.9600779615384615, 0.9663346923076923, 0.7556629230769232], 
             UndirectedEdge[239, 271] -> 
             RGBColor[
              0.9755605384615385, 0.9804433076923078, 0.8881728461538461], 
             UndirectedEdge[35, 354] -> 
             RGBColor[0.8983577692307692, 0.920732, 0.9534818076923077], 
             UndirectedEdge[31, 310] -> 
             RGBColor[
              0.9543501538461538, 0.9654750000000001, 0.9621574615384615], 
             UndirectedEdge[146, 154] -> 
             RGBColor[
              0.9086996153846154, 0.929363076923077, 0.967808423076923], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.9449578846153845, 0.8618534615384615, 0.6052693846153845], 
             UndirectedEdge[265, 322] -> 
             RGBColor[0.9696963461538461, 0.973142, 0.7000810384615384], 
             UndirectedEdge[115, 284] -> 
             RGBColor[
              0.8918468846153846, 0.8201775384615384, 0.6235489615384615], 
             UndirectedEdge[38, 391] -> 
             RGBColor[
              0.8992894615384615, 0.5412872307692307, 0.2729583846153844], 
             UndirectedEdge[116, 328] -> 
             RGBColor[
              0.7422958076923076, 0.7268383846153844, 0.6153965769230769], 
             UndirectedEdge[92, 278] -> 
             RGBColor[
              0.9207433846153845, 0.9380618461538461, 0.9347278076923078], 
             UndirectedEdge[215, 217] -> 
             RGBColor[
              0.9075261153846155, 0.9255783846153847, 0.8436387692307694], 
             UndirectedEdge[159, 210] -> 
             RGBColor[
              0.9921893461538461, 0.9908536923076923, 0.7657011923076924], 
             UndirectedEdge[165, 298] -> 
             RGBColor[
              0.9049381153846152, 0.7532177692307691, 0.6085150384615384], 
             UndirectedEdge[83, 254] -> 
             RGBColor[
              0.7558055384615384, 0.8094480769230769, 0.976218923076923], 
             UndirectedEdge[103, 231] -> 
             RGBColor[
              0.9681000769230769, 0.9748793076923077, 0.9008014615384614], 
             UndirectedEdge[245, 319] -> 
             RGBColor[
              0.970551423076923, 0.974970923076923, 0.7931508846153845], 
             UndirectedEdge[58, 263] -> 
             RGBColor[
              0.9422756538461539, 0.9521396153846153, 0.7539649230769232], 
             UndirectedEdge[206, 258] -> 
             RGBColor[
              0.9927227692307692, 0.9912586923076924, 0.7702660769230769], 
             UndirectedEdge[213, 391] -> 
             RGBColor[
              0.9640748076923076, 0.9541792307692306, 0.6782424230769228], 
             UndirectedEdge[78, 370] -> 
             RGBColor[
              0.9066710384615385, 0.9237494615384616, 0.7505689230769231], 
             UndirectedEdge[101, 270] -> 
             RGBColor[
              0.9677526538461538, 0.9273816923076923, 0.6093079615384615], 
             UndirectedEdge[135, 377] -> 
             RGBColor[
              0.9904831923076922, 0.9901481538461538, 0.7939765769230772], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.9321691538461538, 0.755207769230769, 0.3029244230769229], 
             UndirectedEdge[19, 83] -> 
             RGBColor[
              0.8163769999999999, 0.8566879999999999, 0.9453107307692308], 
             UndirectedEdge[100, 112] -> 
             RGBColor[
              0.9909067307692307, 0.9881103076923077, 0.6260964230769229], 
             UndirectedEdge[10, 296] -> 
             RGBColor[
              0.6547052307692307, 0.7295116923076923, 0.9666754615384615], 
             UndirectedEdge[85, 369] -> 
             RGBColor[
              0.9869913461538461, 0.9698530769230769, 0.5759824230769228], 
             UndirectedEdge[79, 246] -> 
             RGBColor[
              0.936194423076923, 0.7759078461538462, 0.5254834615384615], 
             UndirectedEdge[227, 280] -> 
             RGBColor[
              0.936194423076923, 0.7759078461538462, 0.5254834615384615], 
             UndirectedEdge[112, 326] -> 
             RGBColor[
              0.9917618076923076, 0.9899392307692307, 0.7191662692307691], 
             UndirectedEdge[34, 308] -> 
             RGBColor[
              0.8996342307692307, 0.6207099230769227, 0.23717703846153837`], 
             UndirectedEdge[29, 226] -> 
             RGBColor[
              0.8763830384615384, 0.756837923076923, 0.6110013461538462], 
             UndirectedEdge[204, 345] -> 
             RGBColor[
              0.9291448846153846, 0.7438975384615385, 0.5196011538461538], 
             UndirectedEdge[54, 265] -> 
             RGBColor[
              0.966393923076923, 0.9741737692307693, 0.9290768461538462], 
             UndirectedEdge[22, 100] -> 
             RGBColor[
              0.9909067307692307, 0.9881103076923077, 0.6260964230769229], 
             UndirectedEdge[126, 336] -> 
             RGBColor[
              0.9946406923076923, 0.9909453076923077, 0.6580506153846155], 
             UndirectedEdge[82, 157] -> 
             RGBColor[
              0.9909067307692307, 0.9881103076923077, 0.6260964230769229], 
             UndirectedEdge[344, 349] -> 
             RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 
             UndirectedEdge[343, 349] -> 
             RGBColor[
              0.9320237692307692, 0.7449036153846155, 0.4584855000000002], 
             UndirectedEdge[2, 66] -> 
             RGBColor[0.8362434615384615, 0.872472, 0.9606630384615384], 
             UndirectedEdge[211, 387] -> 
             RGBColor[
              0.9909067307692307, 0.9881103076923077, 0.6260964230769229], 
             UndirectedEdge[250, 265] -> 
             RGBColor[
              0.9681000769230769, 0.9748793076923077, 0.9008014615384614], 
             UndirectedEdge[217, 306] -> 
             RGBColor[
              0.9858998846153846, 0.9870133846153846, 0.8144285769230771], 
             UndirectedEdge[374, 375] -> 
             RGBColor[
              0.9587737692307692, 0.8725963846153846, 0.2943443076923076], 
             UndirectedEdge[38, 247] -> 
             RGBColor[0.8542561153846153, 0.5251021538461538, 0.576851], 
             UndirectedEdge[204, 310] -> 
             RGBColor[
              0.9681000769230769, 0.9748793076923077, 0.9008014615384614], 
             UndirectedEdge[226, 266] -> 
             RGBColor[
              0.9335971538461538, 0.7682553076923075, 0.28696811538461525`], 
             UndirectedEdge[319, 334] -> 
             RGBColor[
              0.9780118846153847, 0.9805349230769231, 0.7805222692307692], 
             UndirectedEdge[73, 206] -> 
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079], 
             UndirectedEdge[200, 255] -> 
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484], 
             UndirectedEdge[296, 383] -> 
             RGBColor[
              0.772811923076923, 0.8225146923076923, 0.9681698846153846], 
             UndirectedEdge[235, 281] -> 
             RGBColor[
              0.9587078076923077, 0.8712577692307693, 0.5439133846153845], 
             UndirectedEdge[174, 272] -> 
             RGBColor[
              0.940251846153846, 0.9529624615384615, 0.9081504230769231], 
             UndirectedEdge[9, 131] -> 
             RGBColor[
              0.9427858076923076, 0.908531923076923, 0.6436121538461538], 
             UndirectedEdge[228, 361] -> 
             RGBColor[
              0.8801991923076924, 0.9042303846153845, 0.8409150769230771], 
             UndirectedEdge[149, 199] -> 
             RGBColor[
              0.9369544999999999, 0.804077846153846, 0.5800931538461538], 
             UndirectedEdge[102, 400] -> 
             RGBColor[
              0.5861425384615384, 0.6467979615384616, 0.7259734230769231], 
             UndirectedEdge[45, 350] -> 
             RGBColor[
              0.7118994615384615, 0.7695284615384617, 0.8594774230769231], 
             UndirectedEdge[369, 392] -> 
             RGBColor[
              0.9869913461538461, 0.9698530769230769, 0.5759824230769228], 
             UndirectedEdge[82, 151] -> 
             RGBColor[
              0.9909067307692307, 0.9881103076923077, 0.6260964230769229], 
             UndirectedEdge[260, 342] -> 
             RGBColor[
              0.9854723461538462, 0.986098923076923, 0.7678936538461538], 
             UndirectedEdge[296, 380] -> 
             RGBColor[
              0.7409062692307693, 0.6235432307692308, 0.5928518846153846], 
             UndirectedEdge[105, 148] -> 
             RGBColor[
              0.8427747307692308, 0.5594924615384618, 0.5812059230769231], 
             UndirectedEdge[94, 288] -> 
             RGBColor[
              0.8226664615384615, 0.8605283076923076, 0.896583346153846], 
             UndirectedEdge[195, 258] -> 
             RGBColor[
              0.9698062307692308, 0.9755848461538461, 0.8725260769230769], 
             UndirectedEdge[339, 374] -> 
             RGBColor[0.9249835, 0.8943368461538461, 0.6419141538461538], 
             UndirectedEdge[199, 367] -> 
             RGBColor[0.9846172692307692, 0.98427, 0.6748238076923075], 
             UndirectedEdge[36, 298] -> 
             RGBColor[
              0.9265476153846153, 0.7362449999999999, 0.28108580769230757`], 
             UndirectedEdge[147, 347] -> 
             RGBColor[
              0.8585807307692308, 0.7426428461538461, 0.6093033461538462], 
             UndirectedEdge[38, 205] -> 
             RGBColor[
              0.8880463846153845, 0.5033616923076922, 0.22928115384615383`], 
             UndirectedEdge[16, 73] -> 
             RGBColor[
              0.8801991923076924, 0.9042303846153845, 0.8409150769230771], 
             UndirectedEdge[108, 290] -> 
             RGBColor[
              0.7877328461538462, 0.8336426923076923, 0.9429126538461539], 
             UndirectedEdge[225, 296] -> 
             RGBColor[0.7940223076923076, 0.837483, 0.8941852692307691], 
             UndirectedEdge[24, 144] -> 
             RGBColor[
              0.989200576923077, 0.9874047692307693, 0.6543718076923076], 
             UndirectedEdge[209, 319] -> 
             RGBColor[
              0.9427031923076923, 0.9530540769230769, 0.8004998461538462], 
             UndirectedEdge[80, 192] -> 
             RGBColor[
              0.9490422692307692, 0.8389959230769231, 0.5657844615384616], 
             UndirectedEdge[42, 221] -> 
             RGBColor[0.8895648076923077, 0.552583, 0.556873423076923], 
             UndirectedEdge[22, 365] -> 
             RGBColor[
              0.9909067307692307, 0.9881103076923077, 0.6260964230769229], 
             UndirectedEdge[80, 201] -> 
             RGBColor[
              0.8756141538461538, 0.9025187692307692, 0.9303061153846155], 
             UndirectedEdge[39, 375] -> 
             RGBColor[0.9740421153846153, 0.931222, 0.5605805769230768], 
             UndirectedEdge[15, 326] -> 
             RGBColor[
              0.9691185384615384, 0.9029056923076921, 0.4426671153846153], 
             UndirectedEdge[86, 95] -> 
             RGBColor[
              0.9543501538461538, 0.9654750000000001, 0.9621574615384615], 
             UndirectedEdge[59, 194] -> 
             RGBColor[
              0.9377906923076923, 0.7741705384615385, 0.32476303846153837`], 
             UndirectedEdge[296, 324] -> 
             RGBColor[
              0.7964736538461539, 0.8375746153846154, 0.7865346923076922], 
             UndirectedEdge[169, 245] -> 
             RGBColor[
              0.9220335769230769, 0.792949846153846, 0.6053503846153846], 
             UndirectedEdge[258, 284] -> 
             RGBColor[0.9604139615384615, 0.8719633076923077, 0.515638], 
             UndirectedEdge[33, 152] -> 
             RGBColor[
              0.9609330384615384, 0.9681636153846154, 0.8487327692307695], 
             UndirectedEdge[246, 349] -> 
             RGBColor[
              0.9390733076923077, 0.7769139230769231, 0.4643678076923079], 
             UndirectedEdge[27, 395] -> 
             RGBColor[
              0.8760288461538461, 0.5299577692307693, 0.21826776923076924`], 
             UndirectedEdge[185, 340] -> 
             RGBColor[
              0.9780118846153847, 0.9805349230769231, 0.7805222692307692], 
             UndirectedEdge[223, 321] -> 
             RGBColor[0.7678179615384615, 0.814878, 0.8307800769230771], 
             UndirectedEdge[274, 373] -> 
             RGBColor[
              0.8273501153846152, 0.794842769230769, 0.6228078846153846], 
             UndirectedEdge[156, 214] -> 
             RGBColor[0.9604139615384615, 0.8719633076923077, 0.515638], 
             UndirectedEdge[205, 221] -> 
             RGBColor[
              0.8880463846153845, 0.5033616923076922, 0.22928115384615383`], 
             UndirectedEdge[97, 105] -> 
             RGBColor[
              0.9184242692307691, 0.9180673076923076, 0.6838933846153844], 
             UndirectedEdge[130, 158] -> 
             RGBColor[
              0.9602921923076924, 0.9218176923076924, 0.6219365769230769], 
             UndirectedEdge[108, 143] -> 
             RGBColor[
              0.9692710769230769, 0.9766030000000001, 0.9369002307692307], 
             UndirectedEdge[176, 399] -> 
             RGBColor[
              0.970551423076923, 0.974970923076923, 0.7931508846153845], 
             UndirectedEdge[150, 189] -> 
             RGBColor[
              0.9858981538461538, 0.9884365384615384, 0.8833676153846155], 
             UndirectedEdge[253, 386] -> 
             RGBColor[
              0.9830209999999999, 0.9860073076923077, 0.8755442307692307], 
             UndirectedEdge[46, 59] -> 
             RGBColor[
              0.9937856153846154, 0.9891163846153845, 0.5649807692307693], 
             UndirectedEdge[186, 241] -> 
             RGBColor[
              0.9764934615384615, 0.9313136153846153, 0.45292999999999994`], 
             UndirectedEdge[39, 93] -> 
             RGBColor[
              0.9921893461538461, 0.9908536923076923, 0.7657011923076924], 
             UndirectedEdge[214, 264] -> 
             RGBColor[
              0.9096491923076923, 0.8343726153846154, 0.6252469615384615], 
             UndirectedEdge[234, 290] -> 
             RGBColor[
              0.5405676923076923, 0.6378962307692307, 0.9569746153846154], 
             UndirectedEdge[148, 170] -> 
             RGBColor[
              0.8236399230769231, 0.18271238461538486`, 0.1702709230769231], 
             UndirectedEdge[50, 362] -> 
             RGBColor[
              0.9934679615384615, 0.9906447692307693, 0.6908908846153845], 
             UndirectedEdge[271, 326] -> 
             RGBColor[
              0.9917618076923076, 0.9899392307692307, 0.7191662692307691], 
             UndirectedEdge[61, 352] -> 
             RGBColor[0.597801423076923, 0.6647725, 0.9300236923076923], 
             UndirectedEdge[256, 333] -> 
             RGBColor[
              0.9240458076923077, 0.9370300769230768, 0.7057319999999999], 
             UndirectedEdge[100, 394] -> 
             RGBColor[
              0.9926128846153845, 0.9888158461538461, 0.5978210384615383], 
             UndirectedEdge[1, 114] -> 
             RGBColor[
              0.9917618076923076, 0.9899392307692307, 0.7191662692307691], 
             UndirectedEdge[218, 269] -> 
             RGBColor[
              0.7080265769230769, 0.4096226923076923, 0.5628858461538462], 
             UndirectedEdge[182, 253] -> 
             RGBColor[
              0.7586496153846154, 0.8100316153846154, 0.9406231153846154], 
             UndirectedEdge[57, 354] -> 
             RGBColor[0.8908973076923077, 0.915168, 0.9661104230769231], 
             UndirectedEdge[40, 192] -> 
             RGBColor[
              0.950748423076923, 0.8397014615384616, 0.5375090769230768], 
             UndirectedEdge[262, 314] -> 
             RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 
             UndirectedEdge[244, 253] -> 
             RGBColor[0.8970252692307692, 0.558147, 0.5442448076923077], 
             UndirectedEdge[277, 330] -> 
             RGBColor[
              0.9876043076923076, 0.989142076923077, 0.8550922307692308], 
             UndirectedEdge[304, 329] -> 
             RGBColor[
              0.9075261153846155, 0.9255783846153847, 0.8436387692307694], 
             UndirectedEdge[103, 223] -> 
             RGBColor[
              0.7649390769230768, 0.8138719230769231, 0.8918957307692307], 
             UndirectedEdge[92, 337] -> 
             RGBColor[
              0.9858981538461538, 0.9884365384615384, 0.8833676153846155], 
             UndirectedEdge[226, 341] -> 
             RGBColor[
              0.9448402307692307, 0.806180846153846, 0.33064534615384605`], 
             UndirectedEdge[193, 260] -> 
             RGBColor[
              0.9299049615384615, 0.7720675384615385, 0.5742108461538462], 
             UndirectedEdge[9, 214] -> 
             RGBColor[
              0.9274514999999999, 0.8485676923076921, 0.6269449615384615], 
             UndirectedEdge[8, 157] -> 
             RGBColor[
              0.9917618076923076, 0.9899392307692307, 0.7191662692307691], 
             UndirectedEdge[103, 342] -> 
             RGBColor[
              0.9917618076923076, 0.9899392307692307, 0.7191662692307691], 
             UndirectedEdge[165, 314] -> 
             RGBColor[
              0.9443042307692306, 0.9577532307692307, 0.971204423076923], 
             UndirectedEdge[115, 392] -> 
             RGBColor[
              0.9241556923076923, 0.9394729230769231, 0.8781770384615384], 
             UndirectedEdge[104, 233] -> 
             RGBColor[
              0.8460639999999999, 0.8805342307692307, 0.9850623076923077], 
             UndirectedEdge[67, 139] -> 
             RGBColor[0.9418481153846154, 0.9512251538461538, 0.70743], 
             UndirectedEdge[116, 364] -> 
             RGBColor[
              0.7437286923076922, 0.7989036153846154, 0.9658803461538461], 
             UndirectedEdge[74, 220] -> 
             RGBColor[
              0.5728345769230768, 0.6459227307692307, 0.9643278846153847], 
             UndirectedEdge[100, 168] -> 
             RGBColor[
              0.8242627307692307, 0.8587909999999999, 0.6958629230769229], 
             UndirectedEdge[129, 308] -> 
             RGBColor[
              0.9649610384615384, 0.9021085384615383, 0.5785930769230769], 
             UndirectedEdge[26, 185] -> 
             RGBColor[
              0.9854723461538462, 0.986098923076923, 0.7678936538461538], 
             UndirectedEdge[197, 215] -> 
             RGBColor[
              0.8820039615384615, 0.837538769230769, 0.6282552692307692], 
             UndirectedEdge[178, 240] -> 
             RGBColor[
              0.9563479999999999, 0.9664519999999999, 0.9381238076923077], 
             UndirectedEdge[52, 223] -> 
             RGBColor[
              0.7609138076923077, 0.793171846153846, 0.6693366923076921], 
             UndirectedEdge[192, 243] -> 
             RGBColor[
              0.9527722307692308, 0.8388786153846155, 0.38332357692307695`], 
             UndirectedEdge[124, 252] -> 
             RGBColor[0.9079345, 0.7289292307692308, 0.5935857692307692], 
             UndirectedEdge[194, 396] -> 
             RGBColor[
              0.9321691538461538, 0.755207769230769, 0.3029244230769229], 
             UndirectedEdge[269, 279] -> 
             RGBColor[
              0.7964736538461539, 0.8375746153846154, 0.7865346923076922], 
             UndirectedEdge[57, 208] -> 
             RGBColor[
              0.9784394230769231, 0.9814493846153847, 0.8270571923076925], 
             UndirectedEdge[169, 304] -> 
             RGBColor[
              0.8585807307692308, 0.7426428461538461, 0.6093033461538462], 
             UndirectedEdge[209, 280] -> 
             RGBColor[
              0.8871358076923077, 0.7390226923076924, 0.6068170384615384], 
             UndirectedEdge[226, 399] -> 
             RGBColor[
              0.9220335769230769, 0.792949846153846, 0.6053503846153846], 
             UndirectedEdge[206, 392] -> 
             RGBColor[
              0.9927227692307692, 0.9912586923076924, 0.7702660769230769], 
             UndirectedEdge[48, 343] -> 
             RGBColor[
              0.9320237692307692, 0.7449036153846155, 0.4584855000000002], 
             UndirectedEdge[159, 263] -> 
             RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076925], 
             UndirectedEdge[261, 295] -> 
             RGBColor[
              0.9683733461538461, 0.9035196153846152, 0.5220423076923076], 
             UndirectedEdge[33, 204] -> 
             RGBColor[
              0.9580541538461538, 0.9671575384615384, 0.909848423076923], 
             UndirectedEdge[64, 151] -> 
             RGBColor[
              0.9755605384615385, 0.9804433076923078, 0.8881728461538461], 
             UndirectedEdge[210, 263] -> 
             RGBColor[
              0.9913342692307692, 0.9890247692307692, 0.6726313461538461], 
             UndirectedEdge[19, 303] -> 
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461], 
             UndirectedEdge[248, 315] -> 
             RGBColor[
              0.9374974230769231, 0.8562894615384615, 0.6178980000000001], 
             UndirectedEdge[236, 351] -> 
             RGBColor[
              0.9006219615384615, 0.9038722307692306, 0.6821953846153844], 
             UndirectedEdge[53, 386] -> 
             RGBColor[
              0.9909067307692307, 0.9881103076923077, 0.6260964230769229], 
             UndirectedEdge[93, 301] -> 
             RGBColor[
              0.9825425384615385, 0.9511908461538461, 0.5213035384615385], 
             UndirectedEdge[37, 159] -> 
             RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 
             UndirectedEdge[148, 326] -> 
             RGBColor[
              0.9120870000000001, 0.610664307692308, 0.3939197692307692], 
             UndirectedEdge[13, 357] -> 
             RGBColor[
              0.8555886153846154, 0.8876871538461538, 0.9860880000000001], 
             UndirectedEdge[162, 231] -> 
             RGBColor[
              0.8821043461538461, 0.5470189999999999, 0.5695020384615385], 
             UndirectedEdge[33, 84] -> 
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484], 
             UndirectedEdge[199, 293] -> 
             RGBColor[
              0.9299049615384615, 0.7720675384615385, 0.5742108461538461], 
             UndirectedEdge[96, 167] -> 
             RGBColor[
              0.9584532692307692, 0.9352164615384615, 0.6564038076923076], 
             UndirectedEdge[131, 307] -> 
             RGBColor[
              0.8347250384615383, 0.8232506923076923, 0.6330707692307691], 
             UndirectedEdge[174, 291] -> 
             RGBColor[
              0.8800862692307692, 0.7070123846153846, 0.6009347307692308], 
             UndirectedEdge[207, 250] -> 
             RGBColor[
              0.9830209999999999, 0.9860073076923077, 0.8755442307692307], 
             UndirectedEdge[364, 387] -> 
             RGBColor[
              0.9681000769230769, 0.9748793076923077, 0.9008014615384614], 
             UndirectedEdge[103, 346] -> 
             RGBColor[
              0.9046472307692308, 0.9245723076923077, 0.904754423076923], 
             UndirectedEdge[31, 106] -> 
             RGBColor[
              0.9449578846153845, 0.8618534615384615, 0.6052693846153845], 
             UndirectedEdge[128, 316] -> 
             RGBColor[
              0.9454568076923076, 0.8878457692307691, 0.6243023076923077], 
             UndirectedEdge[185, 289] -> 
             RGBColor[
              0.9854723461538462, 0.986098923076923, 0.7678936538461538], 
             UndirectedEdge[20, 172] -> 
             RGBColor[
              0.9306050384615384, 0.9132996153846153, 0.6637527692307691], 
             UndirectedEdge[70, 234] -> 
             RGBColor[
              0.7045995384615383, 0.7675707692307692, 0.9726377692307693], 
             UndirectedEdge[119, 383] -> 
             RGBColor[
              0.9709789615384615, 0.9758853846153845, 0.8396858076923079], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.9443042307692306, 0.9577532307692307, 0.971204423076923], 
             UndirectedEdge[20, 54] -> 
             RGBColor[
              0.9385456923076922, 0.9522569230769231, 0.9364258076923078], 
             UndirectedEdge[229, 334] -> 
             RGBColor[
              0.9692710769230769, 0.9766030000000001, 0.9369002307692307], 
             UndirectedEdge[63, 142] -> 
             RGBColor[
              0.9580541538461538, 0.9671575384615384, 0.909848423076923], 
             UndirectedEdge[230, 358] -> 
             RGBColor[
              0.9369544999999999, 0.804077846153846, 0.5800931538461538], 
             UndirectedEdge[119, 296] -> 
             RGBColor[
              0.7969011923076923, 0.838489076923077, 0.8330696153846155], 
             UndirectedEdge[218, 262] -> 
             RGBColor[0.8895648076923077, 0.552583, 0.556873423076923], 
             UndirectedEdge[100, 170] -> 
             RGBColor[0.904911, 0.5602499999999999, 0.2947969999999999], 
             UndirectedEdge[97, 357] -> 
             RGBColor[
              0.9006219615384615, 0.9038722307692306, 0.6821953846153844], 
             UndirectedEdge[375, 399] -> 
             RGBColor[
              0.9528317307692307, 0.9162536923076923, 0.6345651923076923], 
             UndirectedEdge[199, 252] -> 
             RGBColor[
              0.922855423076923, 0.7400572307692308, 0.5683285384615384], 
             UndirectedEdge[175, 345] -> 
             RGBColor[
              0.9274387307692307, 0.7431920000000001, 0.5478765384615385], 
             UndirectedEdge[176, 186] -> 
             RGBColor[
              0.9764934615384615, 0.9313136153846153, 0.45292999999999994`], 
             UndirectedEdge[309, 371] -> 
             RGBColor[0.7940223076923076, 0.837483, 0.8941852692307691], 
             UndirectedEdge[326, 354] -> 
             RGBColor[
              0.9070985769230769, 0.9246639230769231, 0.7971038461538461], 
             UndirectedEdge[38, 289] -> 
             RGBColor[0.8970252692307692, 0.558147, 0.5442448076923077], 
             UndirectedEdge[120, 237] -> 
             RGBColor[
              0.9427031923076923, 0.9530540769230769, 0.8004998461538462], 
             UndirectedEdge[275, 384] -> 
             RGBColor[
              0.8740445769230769, 0.8059824615384614, 0.6218509615384615], 
             UndirectedEdge[216, 220] -> 
             RGBColor[
              0.9354108846153845, 0.8801239999999997, 0.6333492692307692], 
             UndirectedEdge[50, 276] -> 
             RGBColor[
              0.9813698076923076, 0.9508903076923076, 0.5541438076923075], 
             UndirectedEdge[143, 321] -> 
             RGBColor[
              0.9784394230769231, 0.9814493846153847, 0.8270571923076925], 
             UndirectedEdge[225, 316] -> 
             RGBColor[
              0.9666671923076922, 0.9028140769230768, 0.5503176923076922], 
             UndirectedEdge[40, 332] -> 
             RGBColor[
              0.9580541538461538, 0.9671575384615384, 0.909848423076923], 
             UndirectedEdge[254, 343] -> 
             RGBColor[
              0.8622839615384615, 0.6928173076923078, 0.5992367307692308], 
             UndirectedEdge[37, 167] -> 
             RGBColor[
              0.9709789615384615, 0.9758853846153845, 0.8396858076923079], 
             UndirectedEdge[26, 204] -> 
             RGBColor[
              0.9830209999999999, 0.9860073076923077, 0.8755442307692307], 
             UndirectedEdge[141, 189] -> 
             RGBColor[
              0.9858981538461538, 0.9884365384615384, 0.8833676153846155], 
             UndirectedEdge[55, 210] -> 
             RGBColor[
              0.9917618076923076, 0.9899392307692307, 0.7191662692307691], 
             UndirectedEdge[41, 312] -> 
             RGBColor[
              0.9070985769230769, 0.9246639230769231, 0.7971038461538461], 
             UndirectedEdge[102, 247] -> 
             RGBColor[
              0.5350601153846153, 0.6107356538461539, 0.9614925000000001], 
             UndirectedEdge[30, 400] -> 
             RGBColor[
              0.9929305384615386, 0.9872874615384615, 0.47191092307692306`], 
             UndirectedEdge[57, 195] -> 
             RGBColor[
              0.9543501538461538, 0.9654750000000001, 0.9621574615384615], 
             UndirectedEdge[301, 324] -> 
             RGBColor[0.982115, 0.9502763846153846, 0.47476861538461523`], 
             UndirectedEdge[290, 331] -> 
             RGBColor[
              0.7802723846153847, 0.8280786923076924, 0.9555412692307692], 
             UndirectedEdge[49, 347] -> 
             RGBColor[
              0.9119876538461538, 0.7852280769230768, 0.6143973461538461], 
             UndirectedEdge[92, 258] -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.8268168461538462], 
             UndirectedEdge[234, 313] -> 
             RGBColor[
              0.6689949230769231, 0.7391806153846153, 0.9692417692307692], 
             UndirectedEdge[376, 377] -> 
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079], 
             UndirectedEdge[223, 272] -> 
             RGBColor[
              0.7649390769230768, 0.8138719230769231, 0.8918957307692307], 
             UndirectedEdge[213, 302] -> 
             RGBColor[0.8834368461538462, 0.909604, 0.9787390384615384], 
             UndirectedEdge[121, 158] -> 
             RGBColor[
              0.9775843461538463, 0.9796204615384616, 0.7339873461538462], 
             UndirectedEdge[240, 248] -> 
             RGBColor[
              0.9274514999999999, 0.8485676923076921, 0.6269449615384615], 
             UndirectedEdge[18, 132] -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.8268168461538462], 
             UndirectedEdge[59, 79] -> 
             RGBColor[
              0.9909067307692307, 0.9881103076923077, 0.6260964230769229], 
             UndirectedEdge[109, 207] -> 
             RGBColor[
              0.9858998846153846, 0.9870133846153846, 0.8144285769230771], 
             UndirectedEdge[190, 365] -> 
             RGBColor[
              0.9937856153846154, 0.9891163846153845, 0.5649807692307693], 
             UndirectedEdge[78, 391] -> 
             RGBColor[0.987309, 0.9683246923076922, 0.45007230769230755`], 
             UndirectedEdge[159, 236] -> 
             RGBColor[
              0.9881640769230768, 0.9701536153846153, 0.5431421538461538], 
             UndirectedEdge[95, 334] -> 
             RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 
             UndirectedEdge[20, 147] -> 
             RGBColor[
              0.8555886153846154, 0.8876871538461538, 0.9860880000000001], 
             UndirectedEdge[229, 388] -> 
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461], 
             UndirectedEdge[15, 271] -> 
             RGBColor[
              0.9666671923076922, 0.9028140769230768, 0.5503176923076922], 
             UndirectedEdge[53, 151] -> 
             RGBColor[
              0.9909067307692307, 0.9881103076923077, 0.6260964230769229], 
             UndirectedEdge[178, 309] -> 
             RGBColor[
              0.7923161538461538, 0.8367774615384616, 0.9224606538461539], 
             UndirectedEdge[309, 386] -> 
             RGBColor[0.7940223076923076, 0.837483, 0.8941852692307691], 
             UndirectedEdge[199, 299] -> 
             RGBColor[0.843703923076923, 0.878036, 0.9480344230769231], 
             UndirectedEdge[33, 90] -> 
             RGBColor[
              0.9443042307692306, 0.9577532307692307, 0.971204423076923], 
             UndirectedEdge[191, 216] -> 
             RGBColor[
              0.8806714615384614, 0.47495376923076904`, 0.21901826923076917`],
              UndirectedEdge[188, 203] -> 
             RGBColor[
              0.9772666923076923, 0.9811488461538462, 0.8598974615384615], 
             UndirectedEdge[87, 263] -> 
             RGBColor[0.987309, 0.9683246923076922, 0.45007230769230755`], 
             UndirectedEdge[25, 76] -> 
             RGBColor[
              0.9615866923076923, 0.8722638461538461, 0.482797730769231], 
             UndirectedEdge[329, 334] -> 
             RGBColor[
              0.9784394230769231, 0.9814493846153847, 0.8270571923076925], 
             UndirectedEdge[42, 376] -> 
             RGBColor[
              0.9772666923076923, 0.9811488461538462, 0.8598974615384615], 
             UndirectedEdge[54, 130] -> 
             RGBColor[
              0.9723359615384615, 0.9305164615384616, 0.5888559615384615], 
             UndirectedEdge[90, 256] -> 
             RGBColor[
              0.9086996153846154, 0.929363076923077, 0.967808423076923], 
             UndirectedEdge[160, 302] -> 
             RGBColor[
              0.8444816538461539, 0.6786222307692309, 0.5975387307692308], 
             UndirectedEdge[299, 367] -> 
             RGBColor[0.8515896538461538, 0.880139, 0.6985866153846153], 
             UndirectedEdge[16, 96] -> 
             RGBColor[0.8676735, 0.8635614615384615, 0.6576330769230768], 
             UndirectedEdge[5, 223] -> 
             RGBColor[
              0.7665353461538462, 0.8121346153846154, 0.6911753076923075], 
             UndirectedEdge[40, 228] -> 
             RGBColor[
              0.8773203076923077, 0.9032243076923077, 0.9020307307692307], 
             UndirectedEdge[154, 222] -> 
             RGBColor[
              0.8635703846153846, 0.8938200000000001, 0.9633867307692308], 
             UndirectedEdge[85, 188] -> 
             RGBColor[
              0.9927227692307692, 0.9912586923076924, 0.7702660769230769], 
             UndirectedEdge[281, 384] -> 
             RGBColor[
              0.8740445769230769, 0.8059824615384614, 0.6218509615384615], 
             UndirectedEdge[249, 334] -> 
             RGBColor[
              0.9265019230769231, 0.9435581538461539, 0.969506423076923], 
             UndirectedEdge[203, 243] -> 
             RGBColor[
              0.9775843461538463, 0.9796204615384616, 0.7339873461538462], 
             UndirectedEdge[49, 147] -> 
             RGBColor[0.873390923076923, 0.9018822307692307, 0.987786], 
             UndirectedEdge[99, 232] -> 
             RGBColor[
              0.9517646923076921, 0.9633172307692307, 0.9585758076923077], 
             UndirectedEdge[84, 389] -> 
             RGBColor[
              0.7558055384615384, 0.8094480769230769, 0.976218923076923], 
             UndirectedEdge[76, 242] -> 
             RGBColor[
              0.9546825384615384, 0.8505576923076921, 0.32135434615384595`], 
             UndirectedEdge[129, 397] -> 
             RGBColor[
              0.9563479999999999, 0.9664519999999999, 0.9381238076923077], 
             UndirectedEdge[177, 390] -> 
             RGBColor[0.9062435, 0.922835, 0.7040339999999999], 
             UndirectedEdge[138, 144] -> 
             RGBColor[
              0.989200576923077, 0.9874047692307693, 0.6543718076923076], 
             UndirectedEdge[184, 325] -> 
             RGBColor[
              0.9909067307692307, 0.9881103076923077, 0.6260964230769229], 
             UndirectedEdge[69, 140] -> 
             RGBColor[
              0.9061936153846154, 0.5629933846153846, 0.43440176923076945`], 
             UndirectedEdge[247, 391] -> 
             RGBColor[
              0.9362265769230769, 0.9322623846153845, 0.6855913846153845], 
             UndirectedEdge[14, 391] -> 
             RGBColor[
              0.8732950384615384, 0.8825242307692306, 0.6794716923076921], 
             UndirectedEdge[229, 240] -> 
             RGBColor[
              0.9517646923076921, 0.9633172307692307, 0.9585758076923077], 
             UndirectedEdge[166, 400] -> 
             RGBColor[
              0.9775843461538463, 0.9796204615384616, 0.7339873461538462], 
             UndirectedEdge[281, 386] -> 
             RGBColor[
              0.9587078076923077, 0.8712577692307693, 0.5439133846153845], 
             UndirectedEdge[150, 255] -> 
             RGBColor[
              0.9385456923076922, 0.9522569230769231, 0.9364258076923078], 
             UndirectedEdge[103, 290] -> 
             RGBColor[0.7940223076923076, 0.837483, 0.8941852692307691], 
             UndirectedEdge[212, 299] -> 
             RGBColor[
              0.8459681153846152, 0.8611762307692306, 0.6767479999999998], 
             UndirectedEdge[206, 208] -> 
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079], 
             UndirectedEdge[75, 169] -> 
             RGBColor[
              0.9461228461538461, 0.8089242307692307, 0.4702501153846156], 
             UndirectedEdge[110, 167] -> 
             RGBColor[
              0.9543501538461538, 0.9654750000000001, 0.9621574615384615], 
             UndirectedEdge[33, 214] -> 
             RGBColor[
              0.9274514999999999, 0.8485676923076921, 0.6269449615384615], 
             UndirectedEdge[98, 107] -> 
             RGBColor[
              0.9449578846153845, 0.8618534615384615, 0.6052693846153845], 
             UndirectedEdge[238, 252] -> 
             RGBColor[
              0.9308510384615385, 0.744603076923077, 0.4913257692307692], 
             UndirectedEdge[91, 241] -> 
             RGBColor[
              0.9934679615384615, 0.9906447692307693, 0.6908908846153845], 
             UndirectedEdge[74, 219] -> 
             RGBColor[
              0.6065422307692308, 0.668704423076923, 0.7736457307692307], 
             UndirectedEdge[45, 180] -> 
             RGBColor[
              0.9927227692307692, 0.9912586923076924, 0.7702660769230769], 
             UndirectedEdge[187, 235] -> 
             RGBColor[
              0.9830209999999999, 0.9860073076923077, 0.8755442307692307], 
             UndirectedEdge[114, 188] -> 
             RGBColor[
              0.9910166153846154, 0.9905531538461538, 0.7985414615384614], 
             UndirectedEdge[81, 378] -> 
             RGBColor[
              0.9896281153846154, 0.9883192307692308, 0.7009067307692309], 
             UndirectedEdge[19, 313] -> 
             RGBColor[
              0.9161600769230769, 0.9349270769230769, 0.9551798076923077], 
             UndirectedEdge[195, 284] -> 
             RGBColor[
              0.9374974230769231, 0.8562894615384615, 0.6178980000000001], 
             UndirectedEdge[64, 253] -> 
             RGBColor[
              0.9692710769230769, 0.9766030000000001, 0.9369002307692307], 
             UndirectedEdge[55, 122] -> 
             RGBColor[
              0.9877365384615384, 0.9692391538461538, 0.4966072307692305], 
             UndirectedEdge[99, 275] -> 
             RGBColor[
              0.9274514999999999, 0.8485676923076921, 0.6269449615384615], 
             UndirectedEdge[118, 367] -> 
             RGBColor[0.9696963461538461, 0.973142, 0.7000810384615384], 
             UndirectedEdge[7, 96] -> 
             RGBColor[
              0.9779574999999999, 0.9494792307692307, 0.6106945769230768], 
             UndirectedEdge[110, 115] -> 
             RGBColor[
              0.9086996153846154, 0.929363076923077, 0.967808423076923], 
             UndirectedEdge[68, 95] -> 
             RGBColor[
              0.7511891538461539, 0.8044676153846154, 0.9532517307692308], 
             UndirectedEdge[289, 302] -> 
             RGBColor[0.8983577692307692, 0.920732, 0.9534818076923077], 
             UndirectedEdge[260, 321] -> 
             RGBColor[
              0.9858998846153846, 0.9870133846153846, 0.8144285769230771], 
             UndirectedEdge[191, 220] -> 
             RGBColor[0.872058423076923, 0.5392972307692308, 0.578549], 
             UndirectedEdge[169, 209] -> 
             RGBColor[
              0.894185346153846, 0.7710329999999999, 0.6126993461538461], 
             UndirectedEdge[32, 252] -> 
             RGBColor[
              0.8760288461538461, 0.5299577692307693, 0.21826776923076924`], 
             UndirectedEdge[75, 280] -> 
             RGBColor[
              0.9390733076923077, 0.7769139230769231, 0.4643678076923079], 
             UndirectedEdge[14, 224] -> 
             RGBColor[0.8710308461538461, 0.899384, 0.9507581153846154], 
             UndirectedEdge[128, 311] -> 
             RGBColor[
              0.9295380384615384, 0.8247331538461539, 0.6114936923076923], 
             UndirectedEdge[132, 198] -> 
             RGBColor[
              0.9176627307692308, 0.6598636153846155, 0.47934788461538463`], 
             UndirectedEdge[245, 388] -> 
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077], 
             UndirectedEdge[183, 273] -> 
             RGBColor[
              0.9926128846153845, 0.9888158461538461, 0.5978210384615383], 
             UndirectedEdge[69, 220] -> 
             RGBColor[
              0.9609330384615384, 0.9681636153846154, 0.8487327692307695], 
             UndirectedEdge[37, 263] -> 
             RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076925], 
             UndirectedEdge[235, 384] -> 
             RGBColor[
              0.9046472307692308, 0.9245723076923077, 0.904754423076923], 
             UndirectedEdge[132, 216] -> 
             RGBColor[
              0.9683733461538461, 0.9035196153846152, 0.5220423076923076], 
             UndirectedEdge[225, 380] -> 
             RGBColor[
              0.936194423076923, 0.7759078461538462, 0.5254834615384615], 
             UndirectedEdge[3, 371] -> 
             RGBColor[
              0.950748423076923, 0.8397014615384616, 0.5375090769230768], 
             UndirectedEdge[269, 314] -> 
             RGBColor[
              0.7802723846153847, 0.8280786923076924, 0.9555412692307692], 
             UndirectedEdge[16, 206] -> 
             RGBColor[
              0.8790264615384615, 0.9039298461538461, 0.8737553461538461], 
             UndirectedEdge[84, 256] -> 
             RGBColor[0.8555886153846154, 0.8876871538461538, 0.986088], 
             UndirectedEdge[58, 348] -> 
             RGBColor[0.941958, 0.953668, 0.8798750384615385], 
             UndirectedEdge[177, 360] -> 
             RGBColor[
              0.8820039615384615, 0.837538769230769, 0.6282552692307692], 
             UndirectedEdge[2, 106] -> 
             RGBColor[
              0.9449578846153845, 0.8618534615384615, 0.6052693846153845], 
             UndirectedEdge[256, 317] -> 
             RGBColor[
              0.8838874999999999, 0.7886212307692309, 0.6171446538461538], 
             UndirectedEdge[87, 351] -> 
             RGBColor[
              0.9006219615384615, 0.9038722307692306, 0.6821953846153844], 
             UndirectedEdge[48, 103] -> 
             RGBColor[
              0.9921893461538461, 0.9908536923076923, 0.7657011923076924], 
             UndirectedEdge[256, 381] -> 
             RGBColor[
              0.9184242692307691, 0.9180673076923076, 0.6838933846153844], 
             UndirectedEdge[91, 226] -> 
             RGBColor[
              0.9449501153846154, 0.8086236923076923, 0.5030903846153846], 
             UndirectedEdge[105, 113] -> 
             RGBColor[
              0.8998062692307691, 0.851733846153846, 0.6299532692307692], 
             UndirectedEdge[223, 291] -> 
             RGBColor[
              0.7047734999999999, 0.5679218461538462, 0.5846800384615385], 
             UndirectedEdge[203, 348] -> 
             RGBColor[
              0.9772666923076923, 0.9811488461538462, 0.8598974615384615], 
             UndirectedEdge[259, 367] -> 
             RGBColor[
              0.9756383846153847, 0.9294846923076923, 0.3598601538461537], 
             UndirectedEdge[188, 206] -> 
             RGBColor[
              0.9927227692307692, 0.9912586923076924, 0.7702660769230769], 
             UndirectedEdge[250, 289] -> 
             RGBColor[
              0.9830209999999999, 0.9860073076923077, 0.8755442307692307], 
             UndirectedEdge[194, 377] -> 
             RGBColor[
              0.9390733076923077, 0.7769139230769231, 0.4643678076923079], 
             UndirectedEdge[83, 231] -> 
             RGBColor[
              0.8014560769230769, 0.8455599999999999, 0.9705679615384615], 
             UndirectedEdge[276, 376] -> 
             RGBColor[
              0.9813698076923076, 0.9508903076923076, 0.5541438076923075], 
             UndirectedEdge[83, 120] -> 
             RGBColor[
              0.8251178076923076, 0.860619923076923, 0.7889327692307692], 
             UndirectedEdge[40, 243] -> 
             RGBColor[
              0.9913342692307692, 0.9890247692307692, 0.6726313461538461], 
             UndirectedEdge[4, 392] -> 
             RGBColor[
              0.9910166153846154, 0.9905531538461538, 0.7985414615384614], 
             UndirectedEdge[81, 329] -> 
             RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076925], 
             UndirectedEdge[131, 363] -> 
             RGBColor[
              0.8620519615384615, 0.8445986923076922, 0.6357944615384614], 
             UndirectedEdge[167, 192] -> 
             RGBColor[
              0.9295380384615384, 0.8247331538461539, 0.6114936923076923], 
             UndirectedEdge[41, 327] -> 
             RGBColor[
              0.9605054999999999, 0.9672491538461538, 0.8021978461538462], 
             UndirectedEdge[24, 382] -> 
             RGBColor[
              0.9779574999999999, 0.9494792307692307, 0.6106945769230768], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.9692710769230769, 0.9766030000000001, 0.9369002307692307], 
             UndirectedEdge[90, 261] -> 
             RGBColor[
              0.9772666923076923, 0.9811488461538462, 0.8598974615384615], 
             UndirectedEdge[146, 297] -> 
             RGBColor[
              0.9184242692307691, 0.9180673076923076, 0.6838933846153844], 
             UndirectedEdge[5, 291] -> 
             RGBColor[
              0.9307411538461539, 0.7421602307692308, 0.3188807307692307], 
             UndirectedEdge[229, 315] -> 
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461], 
             UndirectedEdge[241, 360] -> 
             RGBColor[
              0.9691185384615384, 0.9029056923076921, 0.4426671153846153], 
             UndirectedEdge[59, 237] -> 
             RGBColor[0.9418481153846154, 0.9512251538461538, 0.70743], 
             UndirectedEdge[257, 381] -> 
             RGBColor[
              0.9852851923076922, 0.9691475384615383, 0.6042578076923074], 
             UndirectedEdge[270, 308] -> 
             RGBColor[
              0.9513988461538461, 0.8441884615384614, 0.28408142307692297`], 
             UndirectedEdge[317, 382] -> 
             RGBColor[
              0.9411016153846153, 0.8000386153846153, 0.29311142307692295`], 
             UndirectedEdge[23, 89] -> 
             RGBColor[
              0.9877365384615384, 0.9692391538461538, 0.4966072307692305], 
             UndirectedEdge[57, 327] -> 
             RGBColor[
              0.9443042307692306, 0.9577532307692307, 0.971204423076923], 
             UndirectedEdge[347, 362] -> 
             RGBColor[
              0.9456953076923076, 0.8080097692307692, 0.4237151923076923], 
             UndirectedEdge[43, 293] -> 
             RGBColor[
              0.8515311923076923, 0.7106325384615384, 0.6034210384615385], 
             UndirectedEdge[73, 208] -> 
             RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 
             UndirectedEdge[53, 129] -> 
             RGBColor[
              0.989200576923077, 0.9874047692307693, 0.6543718076923076], 
             UndirectedEdge[324, 383] -> 
             RGBColor[
              0.970551423076923, 0.974970923076923, 0.7931508846153845], 
             UndirectedEdge[368, 399] -> 
             RGBColor[
              0.9640748076923076, 0.9541792307692306, 0.6782424230769228], 
             UndirectedEdge[51, 136] -> 
             RGBColor[
              0.9691185384615384, 0.9029056923076921, 0.4426671153846153], 
             UndirectedEdge[145, 359] -> 
             RGBColor[
              0.6570772692307693, 0.5548831538461538, 0.5864194230769231], 
             UndirectedEdge[222, 297] -> 
             RGBColor[
              0.8732950384615384, 0.8825242307692306, 0.6794716923076921], 
             UndirectedEdge[81, 209] -> 
             RGBColor[
              0.9422756538461539, 0.9521396153846153, 0.7539649230769232], 
             UndirectedEdge[31, 345] -> 
             RGBColor[
              0.9153949615384616, 0.7344932307692309, 0.5809571538461538], 
             UndirectedEdge[155, 180] -> 
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079], 
             UndirectedEdge[4, 369] -> 
             RGBColor[
              0.9852851923076922, 0.9691475384615383, 0.6042578076923074], 
             UndirectedEdge[102, 289] -> 
             RGBColor[
              0.5778292692307692, 0.6437805000000001, 0.9288863076923077], 
             UndirectedEdge[70, 103] -> 
             RGBColor[
              0.9580541538461538, 0.9671575384615384, 0.909848423076923], 
             UndirectedEdge[177, 375] -> 
             RGBColor[
              0.8893788846153846, 0.8659466923076923, 0.6385181538461538], 
             UndirectedEdge[171, 253] -> 
             RGBColor[0.9846172692307692, 0.98427, 0.6748238076923075], 
             UndirectedEdge[150, 241] -> 
             RGBColor[
              0.9900556538461538, 0.9892336923076923, 0.7474416538461539], 
             UndirectedEdge[24, 317] -> 
             RGBColor[
              0.9490422692307692, 0.8389959230769231, 0.5657844615384616], 
             UndirectedEdge[80, 110] -> 
             RGBColor[
              0.9738543846153846, 0.9797377692307693, 0.9164482307692308], 
             UndirectedEdge[176, 341] -> 
             RGBColor[
              0.993358076923077, 0.988201923076923, 0.518445846153846], 
             UndirectedEdge[154, 192] -> 
             RGBColor[
              0.9369985000000001, 0.8302971538461539, 0.5988650769230769], 
             UndirectedEdge[121, 322] -> 
             RGBColor[
              0.9929305384615386, 0.9872874615384615, 0.47191092307692306`], 
             UndirectedEdge[268, 381] -> 
             RGBColor[
              0.9700168461538461, 0.9105219230769229, 0.33802153846153826`], 
             UndirectedEdge[76, 104] -> 
             RGBColor[
              0.8467176538461538, 0.7846344615384615, 0.6191272692307692], 
             UndirectedEdge[91, 186] -> 
             RGBColor[
              0.9757482692307692, 0.9319275384615384, 0.5323051923076922], 
             UndirectedEdge[216, 357] -> 
             RGBColor[
              0.8820039615384615, 0.837538769230769, 0.6282552692307692], 
             UndirectedEdge[210, 236] -> 
             RGBColor[
              0.9852851923076922, 0.9691475384615383, 0.6042578076923074], 
             UndirectedEdge[26, 173] -> 
             RGBColor[
              0.9677526538461538, 0.9273816923076923, 0.6093079615384615], 
             UndirectedEdge[10, 374] -> 
             RGBColor[
              0.8347250384615383, 0.8232506923076923, 0.6330707692307692], 
             UndirectedEdge[289, 340] -> 
             RGBColor[
              0.9692710769230769, 0.9766030000000001, 0.9369002307692307], 
             UndirectedEdge[65, 168] -> 
             RGBColor[
              0.8163769999999999, 0.8566879999999999, 0.9453107307692308], 
             UndirectedEdge[40, 203] -> 
             RGBColor[
              0.9755605384615385, 0.9804433076923078, 0.8881728461538461], 
             UndirectedEdge[167, 201] -> 
             RGBColor[
              0.8561099230769231, 0.8882559999999999, 0.9760153461538461], 
             UndirectedEdge[41, 57] -> 
             RGBColor[
              0.9780118846153847, 0.9805349230769231, 0.7805222692307692], 
             UndirectedEdge[214, 363] -> 
             RGBColor[
              0.8467176538461538, 0.7846344615384615, 0.6191272692307692], 
             UndirectedEdge[22, 189] -> 
             RGBColor[
              0.9876043076923076, 0.989142076923077, 0.8550922307692308], 
             UndirectedEdge[41, 96] -> 
             RGBColor[0.982115, 0.9502763846153846, 0.47476861538461523`], 
             UndirectedEdge[31, 197] -> 
             RGBColor[
              0.9529172692307692, 0.8934097692307691, 0.6116736923076922], 
             UndirectedEdge[275, 281] -> 
             RGBColor[
              0.9281051538461538, 0.752667923076923, 0.26100992307692306`], 
             UndirectedEdge[89, 353] -> 
             RGBColor[
              0.9715352692307693, 0.9597432307692306, 0.6656138076923075], 
             UndirectedEdge[324, 375] -> 
             RGBColor[
              0.9764934615384615, 0.9313136153846153, 0.45292999999999994`], 
             UndirectedEdge[5, 174] -> 
             RGBColor[0.9418481153846154, 0.9512251538461538, 0.70743], 
             UndirectedEdge[36, 314] -> 
             RGBColor[
              0.9659137307692307, 0.9407804615384615, 0.6437751923076922], 
             UndirectedEdge[220, 357] -> 
             RGBColor[0.873390923076923, 0.9018822307692307, 0.987786], 
             UndirectedEdge[291, 342] -> 
             RGBColor[
              0.9315962307692307, 0.7439891538461539, 0.4119505769230769], 
             UndirectedEdge[21, 159] -> 
             RGBColor[
              0.9784394230769231, 0.9814493846153847, 0.8270571923076925], 
             UndirectedEdge[220, 394] -> 
             RGBColor[
              0.9597603076923076, 0.9678630769230769, 0.8815730384615384], 
             UndirectedEdge[129, 249] -> 
             RGBColor[
              0.9385456923076922, 0.9522569230769231, 0.9364258076923078], 
             UndirectedEdge[37, 58] -> 
             RGBColor[
              0.9431307307692307, 0.9539685384615384, 0.8470347692307695], 
             UndirectedEdge[118, 259] -> 
             RGBColor[
              0.9528317307692307, 0.9162536923076923, 0.6345651923076923], 
             UndirectedEdge[201, 243] -> 
             RGBColor[
              0.8793441153846154, 0.9024014615384615, 0.7478452307692308], 
             UndirectedEdge[40, 110] -> 
             RGBColor[
              0.9755605384615385, 0.9804433076923078, 0.8881728461538461], 
             UndirectedEdge[35, 278] -> 
             RGBColor[
              0.9161600769230769, 0.9349270769230769, 0.9551798076923077], 
             UndirectedEdge[164, 315] -> 
             RGBColor[
              0.9701238846153846, 0.9740564615384615, 0.7466159615384615], 
             UndirectedEdge[81, 304] -> 
             RGBColor[
              0.9066710384615385, 0.9237494615384616, 0.7505689230769231], 
             UndirectedEdge[12, 299] -> 
             RGBColor[
              0.8520171923076922, 0.8810534615384615, 0.7451215384615385], 
             UndirectedEdge[203, 258] -> 
             RGBColor[
              0.9772666923076923, 0.9811488461538462, 0.8598974615384615], 
             UndirectedEdge[250, 276] -> 
             RGBColor[
              0.9796636538461538, 0.9501847692307692, 0.5824191923076921], 
             UndirectedEdge[124, 238] -> 
             RGBColor[
              0.9698062307692308, 0.9755848461538461, 0.8725260769230769], 
             UndirectedEdge[96, 154] -> 
             RGBColor[
              0.9659137307692307, 0.9407804615384615, 0.6437751923076922], 
             UndirectedEdge[126, 238] -> 
             RGBColor[
              0.9934679615384615, 0.9906447692307693, 0.6908908846153845], 
             UndirectedEdge[103, 108] -> 
             RGBColor[
              0.9830209999999999, 0.9860073076923077, 0.8755442307692307], 
             UndirectedEdge[122, 210] -> 
             RGBColor[
              0.9852851923076922, 0.9691475384615383, 0.6042578076923074], 
             UndirectedEdge[108, 234] -> 
             RGBColor[
              0.7295663846153846, 0.7864205384615384, 0.938333576923077], 
             UndirectedEdge[222, 361] -> 
             RGBColor[
              0.8801991923076924, 0.9042303846153845, 0.8409150769230771], 
             UndirectedEdge[12, 274] -> 
             RGBColor[0.968691, 0.9019912307692306, 0.3961321923076923], 
             UndirectedEdge[141, 219] -> 
             RGBColor[
              0.9900556538461538, 0.9892336923076923, 0.7474416538461539], 
             UndirectedEdge[179, 344] -> 
             RGBColor[
              0.9709789615384615, 0.9758853846153845, 0.8396858076923079], 
             UndirectedEdge[14, 230] -> 
             RGBColor[0.8710308461538461, 0.899384, 0.9507581153846154], 
             UndirectedEdge[12, 118] -> 
             RGBColor[
              0.9701238846153846, 0.9740564615384615, 0.7466159615384615], 
             UndirectedEdge[44, 49] -> 
             RGBColor[
              0.8978885769230769, 0.7212074615384616, 0.6026327307692307], 
             UndirectedEdge[224, 247] -> 
             RGBColor[
              0.9339623846153846, 0.9491221538461538, 0.9568778076923077], 
             UndirectedEdge[161, 222] -> 
             RGBColor[
              0.8793441153846154, 0.9024014615384615, 0.7478452307692308], 
             UndirectedEdge[148, 168] -> 
             RGBColor[
              0.7429916538461538, 0.4812533846153848, 0.5713368461538462], 
             UndirectedEdge[219, 323] -> 
             RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076922], 
             UndirectedEdge[309, 334] -> 
             RGBColor[
              0.7802723846153847, 0.8280786923076924, 0.9555412692307692], 
             UndirectedEdge[170, 326] -> 
             RGBColor[
              0.9057660769230769, 0.5620789230769231, 0.38786684615384615`], 
             UndirectedEdge[239, 354] -> 
             RGBColor[0.8908973076923077, 0.915168, 0.9661104230769231], 
             UndirectedEdge[11, 221] -> 
             RGBColor[
              0.9053385384615384, 0.5611644615384616, 0.3413319230769231], 
             UndirectedEdge[47, 322] -> 
             RGBColor[
              0.993358076923077, 0.988201923076923, 0.518445846153846], 
             UndirectedEdge[155, 271] -> 
             RGBColor[
              0.9921893461538461, 0.9908536923076923, 0.7657011923076924], 
             UndirectedEdge[106, 363] -> 
             RGBColor[
              0.8467176538461538, 0.7846344615384615, 0.6191272692307692], 
             UndirectedEdge[245, 378] -> 
             RGBColor[
              0.966393923076923, 0.9741737692307693, 0.9290768461538462], 
             UndirectedEdge[155, 326] -> 
             RGBColor[
              0.9946406923076923, 0.9909453076923077, 0.6580506153846155], 
             UndirectedEdge[10, 39] -> 
             RGBColor[
              0.8499933846153845, 0.8818763076923077, 0.8993070384615384], 
             UndirectedEdge[25, 382] -> 
             RGBColor[
              0.9825425384615385, 0.9511908461538461, 0.5213035384615385], 
             UndirectedEdge[177, 383] -> 
             RGBColor[0.8834368461538462, 0.909604, 0.9787390384615384], 
             UndirectedEdge[177, 296] -> 
             RGBColor[
              0.709359076923077, 0.7722076923076924, 0.9721228461538461], 
             UndirectedEdge[103, 143] -> 
             RGBColor[
              0.9755605384615385, 0.9804433076923078, 0.8881728461538461], 
             UndirectedEdge[84, 317] -> 
             RGBColor[
              0.8838874999999999, 0.7886212307692309, 0.6171446538461538], 
             UndirectedEdge[50, 328] -> 
             RGBColor[
              0.9683733461538461, 0.9035196153846152, 0.5220423076923076], 
             UndirectedEdge[332, 385] -> 
             RGBColor[
              0.9580541538461538, 0.9671575384615384, 0.909848423076923], 
             UndirectedEdge[242, 257] -> 
             RGBColor[
              0.9852851923076922, 0.9691475384615383, 0.6042578076923074], 
             UndirectedEdge[214, 217] -> 
             RGBColor[
              0.9615866923076923, 0.8722638461538461, 0.482797730769231], 
             UndirectedEdge[51, 59] -> 
             RGBColor[
              0.993358076923077, 0.988201923076923, 0.518445846153846], 
             UndirectedEdge[66, 131] -> 
             RGBColor[
              0.8347250384615383, 0.8232506923076923, 0.6330707692307692], 
             UndirectedEdge[66, 98] -> 
             RGBColor[
              0.8193907307692307, 0.7632864615384615, 0.6164035769230769], 
             UndirectedEdge[70, 346] -> 
             RGBColor[0.873390923076923, 0.9018822307692307, 0.987786], 
             UndirectedEdge[151, 253] -> 
             RGBColor[
              0.9830209999999999, 0.9860073076923077, 0.8755442307692307], 
             UndirectedEdge[384, 398] -> 
             RGBColor[
              0.8585807307692308, 0.7426428461538461, 0.6093033461538462], 
             UndirectedEdge[123, 218] -> 
             RGBColor[0.8895648076923077, 0.552583, 0.556873423076923], 
             UndirectedEdge[169, 280] -> 
             RGBColor[
              0.890127923076923, 0.5939783846153845, 0.2300323846153846], 
             UndirectedEdge[71, 109] -> 
             RGBColor[
              0.9784394230769231, 0.9814493846153847, 0.8270571923076925], 
             UndirectedEdge[166, 302] -> 
             RGBColor[0.8908973076923077, 0.915168, 0.9661104230769231], 
             UndirectedEdge[89, 163] -> 
             RGBColor[
              0.9392186923076922, 0.7872180769230768, 0.30880673076923054`], 
             UndirectedEdge[102, 340] -> 
             RGBColor[0.5703688076923077, 0.6382165, 0.9415149230769231], 
             UndirectedEdge[380, 390] -> 
             RGBColor[
              0.9377906923076923, 0.7741705384615385, 0.32476303846153837`], 
             UndirectedEdge[172, 387] -> 
             RGBColor[
              0.9796636538461538, 0.9501847692307692, 0.5824191923076921], 
             UndirectedEdge[61, 298] -> 
             RGBColor[
              0.5509748461538461, 0.45467303846153845`, 0.5799629230769231], 
             UndirectedEdge[10, 216] -> 
             RGBColor[
              0.8273501153846152, 0.794842769230769, 0.6228078846153846], 
             UndirectedEdge[209, 229] -> 
             RGBColor[
              0.9339623846153846, 0.9491221538461538, 0.9568778076923077], 
             UndirectedEdge[39, 119] -> 
             RGBColor[
              0.9921893461538461, 0.9908536923076923, 0.7657011923076924], 
             UndirectedEdge[33, 261] -> 
             RGBColor[
              0.9597603076923076, 0.9678630769230769, 0.8815730384615384], 
             UndirectedEdge[102, 213] -> 
             RGBColor[
              0.5629083461538462, 0.6326525000000001, 0.9541435384615384], 
             UndirectedEdge[155, 335] -> 
             RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 
             UndirectedEdge[76, 317] -> 
             RGBColor[
              0.9201457692307692, 0.7211116153846153, 0.2546056153846154], 
             UndirectedEdge[19, 179] -> 
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461], 
             UndirectedEdge[48, 83] -> 
             RGBColor[
              0.8255453461538461, 0.8615343846153846, 0.8354676923076925], 
             UndirectedEdge[288, 355] -> 
             RGBColor[0.9740421153846153, 0.931222, 0.5605805769230768], 
             UndirectedEdge[7, 192] -> 
             RGBColor[
              0.9490422692307692, 0.8389959230769231, 0.5657844615384616], 
             UndirectedEdge[341, 393] -> 
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998], 
             UndirectedEdge[244, 270] -> 
             RGBColor[
              0.8880463846153845, 0.5033616923076922, 0.22928115384615383`], 
             UndirectedEdge[121, 265] -> 
             RGBColor[
              0.9701238846153846, 0.9740564615384615, 0.7466159615384615], 
             UndirectedEdge[156, 363] -> 
             RGBColor[
              0.8790264615384615, 0.9039298461538461, 0.8737553461538461], 
             UndirectedEdge[133, 280] -> 
             RGBColor[
              0.9390733076923077, 0.7769139230769231, 0.4643678076923079], 
             UndirectedEdge[44, 362] -> 
             RGBColor[
              0.9315962307692307, 0.7439891538461539, 0.4119505769230769], 
             UndirectedEdge[116, 147] -> 
             RGBColor[
              0.6802758461538462, 0.7485966153846153, 0.9698333076923077], 
             UndirectedEdge[83, 196] -> 
             RGBColor[
              0.8186411923076922, 0.8398282307692306, 0.6740243076923075], 
             UndirectedEdge[109, 233] -> 
             RGBColor[
              0.9609330384615384, 0.9681636153846154, 0.8487327692307695], 
             UndirectedEdge[19, 125] -> 
             RGBColor[
              0.9789957307692307, 0.9653072307692306, 0.6529851923076921], 
             UndirectedEdge[26, 160] -> 
             RGBColor[
              0.922855423076923, 0.7400572307692308, 0.5683285384615384], 
             UndirectedEdge[224, 302] -> 
             RGBColor[0.8983577692307692, 0.920732, 0.9534818076923077], 
             UndirectedEdge[58, 60] -> 
             RGBColor[
              0.9265019230769231, 0.9435581538461539, 0.969506423076923], 
             UndirectedEdge[165, 332] -> 
             RGBColor[0.926797846153846, 0.9444674615384614, 0.99288], 
             UndirectedEdge[43, 252] -> 
             RGBColor[
              0.8444816538461539, 0.6786222307692309, 0.5975387307692308], 
             UndirectedEdge[292, 304] -> 
             RGBColor[
              0.9075261153846155, 0.9255783846153847, 0.8436387692307694], 
             UndirectedEdge[63, 257] -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 
             UndirectedEdge[94, 355] -> 
             RGBColor[
              0.8073981153846153, 0.8019026923076922, 0.6303470769230769], 
             UndirectedEdge[223, 290] -> 
             RGBColor[
              0.5696509230769231, 0.6615073076923077, 0.9592641538461538], 
             UndirectedEdge[141, 150] -> 
             RGBColor[
              0.9858981538461538, 0.9884365384615384, 0.8833676153846155], 
             UndirectedEdge[131, 306] -> 
             RGBColor[
              0.9677526538461538, 0.9273816923076923, 0.6093079615384616], 
             UndirectedEdge[151, 182] -> 
             RGBColor[
              0.7649390769230768, 0.8138719230769231, 0.8918957307692307], 
             UndirectedEdge[87, 201] -> 
             RGBColor[
              0.8732950384615384, 0.8825242307692306, 0.6794716923076921], 
             UndirectedEdge[72, 379] -> 
             RGBColor[
              0.981259923076923, 0.9484474615384613, 0.38169876923076884`], 
             UndirectedEdge[23, 378] -> 
             RGBColor[
              0.9900556538461538, 0.9892336923076923, 0.7474416538461539], 
             UndirectedEdge[116, 322] -> 
             RGBColor[
              0.7665353461538462, 0.8121346153846154, 0.6911753076923076], 
             UndirectedEdge[90, 175] -> 
             RGBColor[
              0.9738543846153846, 0.9797377692307693, 0.9164482307692308], 
             UndirectedEdge[348, 369] -> 
             RGBColor[
              0.9869913461538461, 0.9698530769230769, 0.5759824230769228], 
             UndirectedEdge[134, 243] -> 
             RGBColor[0.987309, 0.9683246923076922, 0.45007230769230755`], 
             UndirectedEdge[211, 372] -> 
             RGBColor[
              0.9682634615384615, 0.9010767692307691, 0.34959726923076906`], 
             UndirectedEdge[73, 188] -> 
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079], 
             UndirectedEdge[55, 228] -> 
             RGBColor[
              0.8797716538461539, 0.903315923076923, 0.7943801538461538], 
             UndirectedEdge[260, 384] -> 
             RGBColor[0.8983577692307692, 0.920732, 0.9534818076923077], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.8427747307692308, 0.5594924615384618, 0.5812059230769231], 
             UndirectedEdge[153, 203] -> 
             RGBColor[
              0.9784394230769231, 0.9814493846153847, 0.8270571923076925], 
             UndirectedEdge[65, 148] -> 
             RGBColor[
              0.9033461923076923, 0.6067323846153849, 0.5502977307692307], 
             UndirectedEdge[42, 366] -> 
             RGBColor[
              0.9369985000000001, 0.8302971538461539, 0.5988650769230769], 
             UndirectedEdge[48, 313] -> 
             RGBColor[
              0.9253284230769231, 0.9397734615384615, 0.8453367692307694], 
             UndirectedEdge[166, 213] -> 
             RGBColor[
              0.9543501538461538, 0.9654750000000001, 0.9621574615384615], 
             UndirectedEdge[11, 78] -> 
             RGBColor[
              0.993358076923077, 0.9882019230769231, 0.5184458461538463], 
             UndirectedEdge[228, 348] -> 
             RGBColor[
              0.8790264615384615, 0.9039298461538461, 0.8737553461538461], 
             UndirectedEdge[199, 336] -> 
             RGBColor[
              0.9858998846153846, 0.9870133846153846, 0.8144285769230771], 
             UndirectedEdge[249, 309] -> 
             RGBColor[
              0.7449636923076923, 0.8005978461538461, 0.9755188461538462], 
             UndirectedEdge[190, 273] -> 
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079], 
             UndirectedEdge[298, 314] -> 
             RGBColor[0.9224445, 0.7665035384615385, 0.5868394615384616], 
             UndirectedEdge[7, 385] -> 
             RGBColor[
              0.9876043076923076, 0.989142076923077, 0.8550922307692308], 
             UndirectedEdge[27, 194] -> 
             RGBColor[
              0.8760288461538461, 0.5299577692307693, 0.21826776923076924`], 
             UndirectedEdge[39, 128] -> 
             RGBColor[
              0.9681000769230769, 0.9748793076923077, 0.9008014615384614], 
             UndirectedEdge[116, 265] -> 
             RGBColor[
              0.7437286923076922, 0.7989036153846154, 0.9658803461538461], 
             UndirectedEdge[231, 313] -> 
             RGBColor[
              0.9012391538461538, 0.9237990769230768, 0.9804370384615384], 
             UndirectedEdge[96, 284] -> 
             RGBColor[
              0.9490609999999999, 0.831594923076923, 0.29951573076923066`], 
             UndirectedEdge[279, 300] -> 
             RGBColor[
              0.9917618076923076, 0.9899392307692307, 0.7191662692307691], 
             UndirectedEdge[22, 190] -> 
             RGBColor[
              0.9921893461538461, 0.9908536923076923, 0.7657011923076924], 
             UndirectedEdge[24, 207] -> 
             RGBColor[
              0.9813148461538461, 0.9853017692307693, 0.9038196153846154], 
             UndirectedEdge[315, 329] -> 
             RGBColor[
              0.9709789615384615, 0.9758853846153845, 0.8396858076923079], 
             UndirectedEdge[239, 335] -> 
             RGBColor[
              0.9784394230769231, 0.9814493846153847, 0.8270571923076925], 
             UndirectedEdge[142, 300] -> 
             RGBColor[
              0.9580541538461538, 0.9671575384615384, 0.909848423076923], 
             UndirectedEdge[13, 88] -> 
             RGBColor[0.9089955384615384, 0.9302723846153845, 0.991182], 
             UndirectedEdge[18, 302] -> 
             RGBColor[
              0.9029410769230769, 0.9238667692307692, 0.9330298076923078], 
             UndirectedEdge[148, 251] -> 
             RGBColor[
              0.9079295000000001, 0.6098671538461541, 0.5298457307692308], 
             UndirectedEdge[90, 257] -> 
             RGBColor[
              0.9755605384615385, 0.9804433076923078, 0.8881728461538461], 
             UndirectedEdge[134, 348] -> 
             RGBColor[
              0.9869913461538461, 0.9698530769230769, 0.5759824230769228], 
             UndirectedEdge[158, 322] -> 
             RGBColor[
              0.9771568076923077, 0.9787060000000001, 0.6874524230769229], 
             UndirectedEdge[40, 385] -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 
             UndirectedEdge[228, 385] -> 
             RGBColor[
              0.8773203076923077, 0.9032243076923077, 0.9020307307692307], 
             UndirectedEdge[175, 214] -> 
             RGBColor[
              0.9570016538461538, 0.8705522307692307, 0.5721887692307692], 
             UndirectedEdge[7, 41] -> 
             RGBColor[
              0.9900556538461538, 0.9892336923076923, 0.7474416538461539], 
             UndirectedEdge[176, 379] -> 
             RGBColor[
              0.9877365384615384, 0.9692391538461538, 0.4966072307692305], 
             UndirectedEdge[259, 336] -> 
             RGBColor[
              0.9769209999999999, 0.9322280769230769, 0.49946492307692325`], 
             UndirectedEdge[213, 340] -> 
             RGBColor[
              0.9543501538461538, 0.9654750000000001, 0.9621574615384615], 
             UndirectedEdge[55, 165] -> 
             RGBColor[
              0.9605054999999999, 0.9672491538461538, 0.8021978461538462], 
             UndirectedEdge[108, 231] -> 
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461], 
             UndirectedEdge[38, 230] -> 
             RGBColor[0.8970252692307692, 0.558147, 0.5442448076923077], 
             UndirectedEdge[39, 316] -> 
             RGBColor[
              0.9666671923076922, 0.9028140769230768, 0.5503176923076922], 
             UndirectedEdge[85, 167] -> 
             RGBColor[
              0.9698062307692308, 0.9755848461538461, 0.8725260769230769], 
             UndirectedEdge[28, 328] -> 
             RGBColor[
              0.9603777307692307, 0.8989737692307691, 0.5990450769230768], 
             UndirectedEdge[79, 120] -> 
             RGBColor[
              0.9917618076923076, 0.9899392307692307, 0.7191662692307691], 
             UndirectedEdge[130, 347] -> 
             RGBColor[
              0.9279756153846153, 0.7492925384615383, 0.26512949999999996`], 
             UndirectedEdge[77, 160] -> 
             RGBColor[
              0.9307411538461539, 0.7421602307692308, 0.3188807307692307], 
             UndirectedEdge[108, 179] -> 
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461], 
             UndirectedEdge[318, 373] -> 
             RGBColor[
              0.8009347692307691, 0.8449911538461539, 0.9806406153846154], 
             UndirectedEdge[48, 331] -> 
             RGBColor[
              0.9784394230769231, 0.9814493846153847, 0.8270571923076925], 
             UndirectedEdge[222, 312] -> 
             RGBColor[
              0.792657076923077, 0.8379489999999999, 0.9799683076923077], 
             UndirectedEdge[292, 353] -> 
             RGBColor[
              0.9784394230769231, 0.9814493846153847, 0.8270571923076925], 
             UndirectedEdge[175, 204] -> 
             RGBColor[
              0.9876043076923076, 0.989142076923077, 0.8550922307692308], 
             UndirectedEdge[198, 340] -> 
             RGBColor[
              0.902206653846154, 0.6497537692307693, 0.5689792692307691], 
             UndirectedEdge[14, 207] -> 
             RGBColor[0.8710308461538461, 0.899384, 0.9507581153846154], 
             UndirectedEdge[45, 271] -> 
             RGBColor[
              0.9910166153846154, 0.9905531538461538, 0.7985414615384614], 
             UndirectedEdge[112, 183] -> 
             RGBColor[
              0.9909067307692307, 0.9881103076923077, 0.6260964230769229], 
             UndirectedEdge[85, 139] -> 
             RGBColor[0.941958, 0.953668, 0.8798750384615385], 
             UndirectedEdge[45, 97] -> 
             RGBColor[
              0.9869913461538461, 0.9698530769230769, 0.5759824230769228], 
             UndirectedEdge[130, 181] -> 
             RGBColor[
              0.9427858076923076, 0.908531923076923, 0.6436121538461539], 
             UndirectedEdge[63, 90] -> 
             RGBColor[
              0.9755605384615385, 0.9804433076923078, 0.8881728461538461], 
             UndirectedEdge[114, 361] -> 
             RGBColor[
              0.9921893461538461, 0.9908536923076923, 0.7657011923076924], 
             UndirectedEdge[75, 209] -> 
             RGBColor[
              0.9431307307692307, 0.9539685384615384, 0.8470347692307695], 
             UndirectedEdge[42, 276] -> 
             RGBColor[
              0.9659137307692307, 0.9407804615384615, 0.6437751923076921], 
             UndirectedEdge[205, 358] -> 
             RGBColor[
              0.9279756153846153, 0.7492925384615383, 0.26512949999999996`], 
             UndirectedEdge[76, 358] -> 
             RGBColor[
              0.9126413076923077, 0.6893283076923076, 0.24846230769230765`], 
             UndirectedEdge[90, 142] -> 
             RGBColor[
              0.9443042307692306, 0.9577532307692307, 0.971204423076923], 
             UndirectedEdge[152, 381] -> 
             RGBColor[
              0.9881640769230768, 0.9701536153846153, 0.5431421538461538], 
             UndirectedEdge[86, 309] -> 
             RGBColor[
              0.772811923076923, 0.8225146923076923, 0.9681698846153846], 
             UndirectedEdge[104, 358] -> 
             RGBColor[
              0.8312538076923077, 0.721294846153846, 0.6065796538461539], 
             UndirectedEdge[16, 369] -> 
             RGBColor[
              0.8732950384615384, 0.8825242307692306, 0.6794716923076921], 
             UndirectedEdge[278, 337] -> 
             RGBColor[
              0.9207433846153845, 0.9380618461538461, 0.9347278076923078], 
             UndirectedEdge[100, 350] -> 
             RGBColor[
              0.711789576923077, 0.7670856153846154, 0.6870323846153845], 
             UndirectedEdge[90, 202] -> 
             RGBColor[0.9224445, 0.7665035384615385, 0.5868394615384614], 
             UndirectedEdge[126, 367] -> 
             RGBColor[
              0.993358076923077, 0.988201923076923, 0.518445846153846], 
             UndirectedEdge[278, 327] -> 
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484], 
             UndirectedEdge[10, 200] -> 
             RGBColor[
              0.8009347692307691, 0.8449911538461539, 0.9806406153846154], 
             UndirectedEdge[149, 299] -> 
             RGBColor[
              0.8039268846153845, 0.6999468461538461, 0.6038559615384615], 
             UndirectedEdge[57, 284] -> 
             RGBColor[
              0.9449578846153845, 0.8618534615384615, 0.6052693846153845], 
             UndirectedEdge[125, 313] -> 
             RGBColor[
              0.9184242692307691, 0.9180673076923076, 0.6838933846153844], 
             UndirectedEdge[125, 196] -> 
             RGBColor[
              0.981259923076923, 0.9484474615384613, 0.38169876923076884`], 
             UndirectedEdge[21, 210] -> 
             RGBColor[
              0.9755605384615385, 0.9804433076923078, 0.8881728461538461], 
             UndirectedEdge[186, 374] -> 
             RGBColor[
              0.9587737692307692, 0.8725963846153846, 0.2943443076923076], 
             UndirectedEdge[6, 74] -> 
             RGBColor[0.5194276538461539, 0.6033375, 0.9592338846153846], 
             UndirectedEdge[7, 312] -> 
             RGBColor[
              0.9029410769230769, 0.9238667692307692, 0.9330298076923078], 
             UndirectedEdge[238, 299] -> 
             RGBColor[
              0.8516995384615385, 0.8825818461538462, 0.8710316538461538], 
             UndirectedEdge[155, 239] -> 
             RGBColor[
              0.9784394230769231, 0.9814493846153847, 0.8270571923076925], 
             UndirectedEdge[108, 331] -> 
             RGBColor[
              0.9692710769230769, 0.9766030000000001, 0.9369002307692307], 
             UndirectedEdge[55, 87] -> 
             RGBColor[
              0.9877365384615384, 0.9692391538461538, 0.4966072307692305], 
             UndirectedEdge[186, 288] -> 
             RGBColor[0.9740421153846153, 0.931222, 0.5605805769230767], 
             UndirectedEdge[178, 371] -> 
             RGBColor[
              0.9876043076923076, 0.989142076923077, 0.8550922307692308], 
             UndirectedEdge[212, 238] -> 
             RGBColor[
              0.9869913461538461, 0.9698530769230769, 0.5759824230769228], 
             UndirectedEdge[292, 329] -> 
             RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 
             UndirectedEdge[268, 338] -> 
             RGBColor[
              0.9434394615384615, 0.8126321538461538, 0.27767711538461537`], 
             UndirectedEdge[68, 309] -> 
             RGBColor[
              0.5696509230769231, 0.6615073076923077, 0.9592641538461538], 
             UndirectedEdge[129, 309] -> 
             RGBColor[
              0.7923161538461538, 0.8367774615384616, 0.9224606538461539], 
             UndirectedEdge[137, 330] -> 
             RGBColor[
              0.9432439615384615, 0.8079181538461537, 0.5313657692307692], 
             UndirectedEdge[111, 400] -> 
             RGBColor[0.987309, 0.9683246923076922, 0.45007230769230755`], 
             UndirectedEdge[62, 370] -> 
             RGBColor[
              0.9046472307692308, 0.9245723076923077, 0.904754423076923], 
             UndirectedEdge[163, 280] -> 
             RGBColor[
              0.890127923076923, 0.5939783846153845, 0.2300323846153846], 
             UndirectedEdge[316, 383] -> 
             RGBColor[
              0.9454568076923076, 0.8878457692307691, 0.6243023076923077], 
             UndirectedEdge[307, 314] -> 
             RGBColor[0.8362434615384615, 0.872472, 0.9606630384615384], 
             UndirectedEdge[126, 259] -> 
             RGBColor[
              0.9764934615384615, 0.9313136153846153, 0.45292999999999994`], 
             UndirectedEdge[44, 372] -> 
             RGBColor[
              0.9065016153846153, 0.6568639999999999, 0.24310199999999996`], 
             UndirectedEdge[202, 279] -> 
             RGBColor[
              0.9386457692307693, 0.7759994615384616, 0.4178328846153846], 
             UndirectedEdge[148, 312] -> 
             RGBColor[
              0.8249724230769231, 0.5452973846153848, 0.5795079230769231], 
             UndirectedEdge[109, 358] -> 
             RGBColor[
              0.9461228461538461, 0.8089242307692307, 0.4702501153846156], 
             UndirectedEdge[142, 275] -> 
             RGBColor[
              0.9274514999999999, 0.8485676923076921, 0.6269449615384615], 
             UndirectedEdge[296, 375] -> 
             RGBColor[0.7787539615384615, 0.7788573846153846, 0.627949], 
             UndirectedEdge[92, 195] -> 
             RGBColor[
              0.966393923076923, 0.9741737692307693, 0.9290768461538462], 
             UndirectedEdge[178, 248] -> 
             RGBColor[
              0.9570016538461538, 0.8705522307692307, 0.5721887692307692], 
             UndirectedEdge[41, 222] -> 
             RGBColor[
              0.8797716538461539, 0.903315923076923, 0.7943801538461538], 
             UndirectedEdge[154, 356] -> 
             RGBColor[
              0.9771568076923077, 0.9787060000000001, 0.6874524230769229], 
             UndirectedEdge[70, 133] -> 
             RGBColor[
              0.9609330384615384, 0.9681636153846154, 0.8487327692307695], 
             UndirectedEdge[7, 80] -> 
             RGBColor[
              0.9858981538461538, 0.9884365384615384, 0.8833676153846155], 
             UndirectedEdge[152, 261] -> 
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079], 
             UndirectedEdge[95, 229] -> 
             RGBColor[
              0.9692710769230769, 0.9766030000000001, 0.9369002307692307], 
             UndirectedEdge[30, 204] -> 
             RGBColor[
              0.9909067307692307, 0.9881103076923077, 0.6260964230769229], 
             UndirectedEdge[133, 223] -> 
             RGBColor[0.7678179615384615, 0.814878, 0.8307800769230771], 
             UndirectedEdge[298, 306] -> 
             RGBColor[
              0.9299049615384615, 0.7720675384615385, 0.5742108461538462], 
             UndirectedEdge[40, 96] -> 
             RGBColor[
              0.9796636538461538, 0.9501847692307692, 0.5824191923076921], 
             UndirectedEdge[122, 146] -> 
             RGBColor[
              0.9184242692307691, 0.9180673076923076, 0.6838933846153844], 
             UndirectedEdge[223, 267] -> 
             RGBColor[
              0.7118230384615385, 0.5999321538461538, 0.5905623461538462], 
             UndirectedEdge[54, 322] -> 
             RGBColor[
              0.989200576923077, 0.9874047692307693, 0.6543718076923076], 
             UndirectedEdge[41, 154] -> 
             RGBColor[
              0.9780118846153847, 0.9805349230769231, 0.7805222692307692], 
             UndirectedEdge[245, 353] -> 
             RGBColor[
              0.9543501538461538, 0.9654750000000001, 0.9621574615384615], 
             UndirectedEdge[26, 62] -> 
             RGBColor[
              0.9830209999999999, 0.9860073076923077, 0.8755442307692307], 
             UndirectedEdge[217, 269] -> 
             RGBColor[
              0.7969011923076923, 0.838489076923077, 0.8330696153846155], 
             UndirectedEdge[172, 347] -> 
             RGBColor[
              0.9335971538461538, 0.7682553076923075, 0.28696811538461525`], 
             UndirectedEdge[63, 261] -> 
             RGBColor[
              0.9910166153846154, 0.9905531538461538, 0.7985414615384614], 
             UndirectedEdge[195, 369] -> 
             RGBColor[
              0.9640748076923076, 0.9541792307692306, 0.6782424230769228], 
             UndirectedEdge[65, 180] -> 
             RGBColor[
              0.9847271538461537, 0.9867128461538461, 0.8472688461538461], 
             UndirectedEdge[49, 211] -> 
             RGBColor[
              0.9596504230769229, 0.9654202307692307, 0.7091279999999999], 
             UndirectedEdge[285, 387] -> 
             RGBColor[
              0.9291448846153846, 0.7438975384615385, 0.5196011538461538], 
             UndirectedEdge[329, 388] -> 
             RGBColor[
              0.9709789615384615, 0.9758853846153845, 0.8396858076923079], 
             UndirectedEdge[38, 102] -> 
             RGBColor[0.498123, 0.2197605, 0.5488595000000001], 
             UndirectedEdge[92, 188] -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.8268168461538462], 
             UndirectedEdge[114, 153] -> 
             RGBColor[
              0.9921893461538461, 0.9908536923076923, 0.7657011923076924], 
             UndirectedEdge[326, 337] -> 
             RGBColor[
              0.9900556538461538, 0.9892336923076923, 0.7474416538461539], 
             UndirectedEdge[38, 221] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[350, 394] -> 
             RGBColor[
              0.7118994615384615, 0.7695284615384617, 0.8594774230769231], 
             UndirectedEdge[286, 349] -> 
             RGBColor[
              0.9937856153846154, 0.9891163846153845, 0.5649807692307693], 
             UndirectedEdge[246, 320] -> 
             RGBColor[
              0.7968773461538461, 0.6679365384615384, 0.5979736538461538], 
             UndirectedEdge[322, 362] -> 
             RGBColor[
              0.993358076923077, 0.988201923076923, 0.518445846153846], 
             UndirectedEdge[80, 348] -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.8268168461538462], 
             UndirectedEdge[78, 230] -> 
             RGBColor[
              0.9850448076923077, 0.9851844615384615, 0.7213587307692308], 
             UndirectedEdge[248, 329] -> 
             RGBColor[
              0.9615866923076923, 0.8722638461538461, 0.482797730769231], 
             UndirectedEdge[43, 330] -> 
             RGBColor[
              0.9046472307692308, 0.9245723076923077, 0.904754423076923], 
             UndirectedEdge[63, 217] -> 
             RGBColor[
              0.9921893461538461, 0.9908536923076923, 0.7657011923076924], 
             UndirectedEdge[79, 136] -> 
             RGBColor[
              0.9666671923076922, 0.9028140769230768, 0.5503176923076922], 
             UndirectedEdge[159, 243] -> 
             RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076925], 
             UndirectedEdge[1, 327] -> 
             RGBColor[
              0.9605054999999999, 0.9672491538461538, 0.8021978461538462], 
             UndirectedEdge[304, 353] -> 
             RGBColor[0.8908973076923077, 0.915168, 0.9661104230769231], 
             UndirectedEdge[240, 329] -> 
             RGBColor[
              0.9609330384615384, 0.9681636153846154, 0.8487327692307695], 
             UndirectedEdge[10, 311] -> 
             RGBColor[
              0.811431346153846, 0.7317301538461538, 0.6099992692307692], 
             UndirectedEdge[353, 378] -> 
             RGBColor[
              0.9738543846153846, 0.9797377692307693, 0.9164482307692308], 
             UndirectedEdge[167, 243] -> 
             RGBColor[
              0.9701238846153846, 0.9740564615384615, 0.7466159615384615], 
             UndirectedEdge[169, 292] -> 
             RGBColor[
              0.9461228461538461, 0.8089242307692307, 0.4702501153846156], 
             UndirectedEdge[211, 347] -> 
             RGBColor[
              0.9448402307692307, 0.806180846153846, 0.33064534615384605`], 
             UndirectedEdge[224, 340] -> 
             RGBColor[
              0.9692710769230769, 0.9766030000000001, 0.9369002307692307], 
             UndirectedEdge[144, 233] -> 
             RGBColor[0.9596504230769229, 0.9654202307692307, 0.709128], 
             UndirectedEdge[273, 394] -> 
             RGBColor[
              0.9927227692307692, 0.9912586923076924, 0.7702660769230769], 
             UndirectedEdge[93, 94] -> 
             RGBColor[
              0.8255453461538461, 0.8615343846153846, 0.8354676923076925], 
             UndirectedEdge[358, 366] -> 
             RGBColor[0.904681923076923, 0.657772, 0.242058], 
             UndirectedEdge[245, 329] -> 
             RGBColor[
              0.9709789615384615, 0.9758853846153845, 0.8396858076923079], 
             UndirectedEdge[44, 93] -> 
             RGBColor[
              0.9320237692307692, 0.7449036153846155, 0.4584855000000002], 
             UndirectedEdge[218, 314] -> 
             RGBColor[0.8895648076923077, 0.552583, 0.556873423076923], 
             UndirectedEdge[133, 346] -> 
             RGBColor[
              0.9075261153846155, 0.9255783846153847, 0.8436387692307694], 
             UndirectedEdge[143, 272] -> 
             RGBColor[
              0.9755605384615385, 0.9804433076923078, 0.8881728461538461], 
             UndirectedEdge[272, 346] -> 
             RGBColor[
              0.9046472307692308, 0.9245723076923077, 0.904754423076923], 
             UndirectedEdge[61, 269] -> 
             RGBColor[
              0.4088027307692308, 0.5162481923076923, 0.9486647307692307], 
             UndirectedEdge[158, 362] -> 
             RGBColor[
              0.9780118846153847, 0.9805349230769231, 0.7805222692307692], 
             UndirectedEdge[294, 393] -> 
             RGBColor[
              0.9771568076923077, 0.9787060000000001, 0.6874524230769229], 
             UndirectedEdge[17, 298] -> 
             RGBColor[
              0.9386457692307693, 0.7759994615384616, 0.4178328846153846], 
             UndirectedEdge[83, 179] -> 
             RGBColor[
              0.8014560769230769, 0.8455599999999999, 0.9705679615384615], 
             UndirectedEdge[223, 398] -> 
             RGBColor[
              0.7188725769230768, 0.6319424615384615, 0.5964446538461539], 
             UndirectedEdge[52, 272] -> 
             RGBColor[
              0.9852851923076922, 0.9691475384615383, 0.6042578076923074], 
             UndirectedEdge[52, 174] -> 
             RGBColor[
              0.9362265769230769, 0.9322623846153845, 0.6855913846153845], 
             UndirectedEdge[63, 317] -> 
             RGBColor[
              0.950748423076923, 0.8397014615384616, 0.5375090769230768], 
             UndirectedEdge[145, 280] -> 
             RGBColor[
              0.8830783846153846, 0.5619680769230769, 0.22415007692307692`], 
             UndirectedEdge[152, 317] -> 
             RGBColor[
              0.9536273076923076, 0.8407075384615386, 0.47639342307692334`], 
             UndirectedEdge[102, 391] -> 
             RGBColor[
              0.5800934615384614, 0.6269207307692306, 0.6575998846153844], 
             UndirectedEdge[168, 251] -> 
             RGBColor[
              0.8209603076923075, 0.8598227692307692, 0.9248587307692309], 
             UndirectedEdge[89, 245] -> 
             RGBColor[
              0.9640748076923076, 0.9541792307692306, 0.6782424230769228], 
             UndirectedEdge[293, 330] -> 
             RGBColor[
              0.936194423076923, 0.7759078461538462, 0.5254834615384614], 
             UndirectedEdge[166, 247] -> 
             RGBColor[
              0.9265019230769231, 0.9435581538461539, 0.969506423076923], 
             UndirectedEdge[8, 182] -> 
             RGBColor[
              0.7673904230769231, 0.8139635384615385, 0.7842451538461538], 
             UndirectedEdge[2, 215] -> 
             RGBColor[0.8908973076923077, 0.915168, 0.9661104230769231], 
             UndirectedEdge[61, 107] -> 
             RGBColor[
              0.5903409615384615, 0.6592085000000001, 0.9426523076923077], 
             UndirectedEdge[192, 361] -> 
             RGBColor[
              0.9536273076923076, 0.8407075384615386, 0.47639342307692334`], 
             UndirectedEdge[71, 321] -> 
             RGBColor[
              0.9784394230769231, 0.9814493846153847, 0.8270571923076925], 
             UndirectedEdge[26, 389] -> 
             RGBColor[
              0.8163769999999999, 0.8566879999999999, 0.9453107307692308], 
             UndirectedEdge[134, 263] -> 
             RGBColor[0.987309, 0.9683246923076922, 0.45007230769230755`], 
             UndirectedEdge[105, 282] -> 
             RGBColor[0.8555886153846154, 0.8876871538461538, 0.986088], 
             UndirectedEdge[323, 340] -> 
             RGBColor[
              0.9780118846153847, 0.9805349230769231, 0.7805222692307692], 
             UndirectedEdge[311, 323] -> 
             RGBColor[
              0.9531997692307692, 0.839793076923077, 0.4298584999999999], 
             UndirectedEdge[29, 365] -> 
             RGBColor[
              0.9240458076923077, 0.9370300769230768, 0.7057319999999999], 
             UndirectedEdge[321, 384] -> 
             RGBColor[
              0.9075261153846155, 0.9255783846153847, 0.8436387692307694], 
             UndirectedEdge[115, 195] -> 
             RGBColor[
              0.9012391538461538, 0.9237990769230768, 0.9804370384615384], 
             UndirectedEdge[162, 359] -> 
             RGBColor[
              0.624197576923077, 0.3409626153846154, 0.5564533846153846], 
             UndirectedEdge[106, 295] -> 
             RGBColor[
              0.9360645384615384, 0.7842242307692305, 0.2674142307692307], 
             UndirectedEdge[24, 242] -> 
             RGBColor[
              0.9835790384615384, 0.9684419999999998, 0.6325331923076922], 
             UndirectedEdge[109, 286] -> 
             RGBColor[
              0.9937856153846154, 0.9891163846153845, 0.5649807692307693], 
             UndirectedEdge[287, 367] -> 
             RGBColor[
              0.9240458076923077, 0.9370300769230768, 0.7057319999999999], 
             UndirectedEdge[74, 140] -> 
             RGBColor[
              0.5180951538461538, 0.24075249999999998`, 0.5499968846153847], 
             UndirectedEdge[168, 394] -> 
             RGBColor[
              0.8243726153846154, 0.8612338461538461, 0.8683079615384615], 
             UndirectedEdge[68, 249] -> 
             RGBColor[
              0.7158804615384615, 0.7769867692307693, 0.9732293076923078], 
             UndirectedEdge[389, 400] -> 
             RGBColor[
              0.8246902692307692, 0.8597054615384615, 0.7423978461538462], 
             UndirectedEdge[267, 346] -> 
             RGBColor[
              0.8515311923076923, 0.7106325384615384, 0.6034210384615384], 
             UndirectedEdge[16, 392] -> 
             RGBColor[
              0.8790264615384615, 0.9039298461538461, 0.8737553461538461], 
             UndirectedEdge[13, 191] -> 
             RGBColor[0.8542561153846153, 0.5251021538461538, 0.576851], 
             UndirectedEdge[312, 327] -> 
             RGBColor[0.873390923076923, 0.9018822307692307, 0.987786], 
             UndirectedEdge[260, 291] -> 
             RGBColor[
              0.922855423076923, 0.7400572307692308, 0.5683285384615384], 
             UndirectedEdge[83, 344] -> 
             RGBColor[
              0.8255453461538461, 0.8615343846153846, 0.8354676923076925], 
             UndirectedEdge[200, 288] -> 
             RGBColor[
              0.940251846153846, 0.9529624615384615, 0.9081504230769231], 
             UndirectedEdge[297, 332] -> 
             RGBColor[
              0.9540288846153845, 0.9464574615384613, 0.6872893846153845], 
             UndirectedEdge[189, 241] -> 
             RGBColor[
              0.9900556538461538, 0.9892336923076923, 0.7474416538461539], 
             UndirectedEdge[276, 358] -> 
             RGBColor[
              0.9335971538461538, 0.7682553076923075, 0.28696811538461525`], 
             UndirectedEdge[11, 102] -> 
             RGBColor[
              0.5861425384615385, 0.6467979615384616, 0.7259734230769231], 
             UndirectedEdge[96, 243] -> 
             RGBColor[
              0.9816874615384615, 0.949361923076923, 0.42823369230769226`], 
             UndirectedEdge[171, 397] -> 
             RGBColor[0.9596504230769229, 0.9654202307692307, 0.709128], 
             UndirectedEdge[314, 385] -> 
             RGBColor[
              0.9755605384615385, 0.9804433076923078, 0.8881728461538461], 
             UndirectedEdge[11, 213] -> 
             RGBColor[
              0.9701238846153846, 0.9740564615384615, 0.7466159615384615], 
             UndirectedEdge[68, 129] -> 
             RGBColor[
              0.763232923076923, 0.8131663846153846, 0.9201711153846155], 
             UndirectedEdge[137, 277] -> 
             RGBColor[
              0.9415378076923075, 0.8072126153846153, 0.5596411538461539], 
             UndirectedEdge[35, 327] -> 
             RGBColor[
              0.9517646923076921, 0.9633172307692307, 0.9585758076923077], 
             UndirectedEdge[155, 183] -> 
             RGBColor[
              0.9937856153846154, 0.9891163846153845, 0.5649807692307693], 
             UndirectedEdge[63, 256] -> 
             RGBColor[
              0.9224495384615384, 0.9387673846153846, 0.906452423076923], 
             UndirectedEdge[144, 358] -> 
             RGBColor[
              0.9448402307692307, 0.806180846153846, 0.33064534615384605`], 
             UndirectedEdge[192, 332] -> 
             RGBColor[
              0.9194921153846153, 0.8170113846153846, 0.6205406538461539], 
             UndirectedEdge[149, 259] -> 
             RGBColor[
              0.9279756153846153, 0.7492925384615383, 0.26512949999999996`], 
             UndirectedEdge[146, 165] -> 
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484], 
             UndirectedEdge[164, 280] -> 
             RGBColor[0.9382182307692308, 0.775085, 0.3712979615384616], 
             UndirectedEdge[65, 105] -> 
             RGBColor[
              0.9161600769230769, 0.9349270769230769, 0.9551798076923077], 
             UndirectedEdge[73, 369] -> 
             RGBColor[
              0.9881640769230768, 0.9701536153846153, 0.5431421538461538], 
             UndirectedEdge[187, 281] -> 
             RGBColor[
              0.952418346153846, 0.8674174615384616, 0.5926407692307691], 
             UndirectedEdge[53, 253] -> 
             RGBColor[0.9846172692307692, 0.98427, 0.6748238076923075], 
             UndirectedEdge[132, 191] -> 
             RGBColor[
              0.9050208846153847, 0.5626928461538462, 0.46724203846153844`], 
             UndirectedEdge[29, 273] -> 
             RGBColor[
              0.9241556923076923, 0.9394729230769231, 0.8781770384615384], 
             UndirectedEdge[138, 366] -> 
             RGBColor[
              0.9490422692307692, 0.8389959230769231, 0.5657844615384616], 
             UndirectedEdge[229, 309] -> 
             RGBColor[
              0.7877328461538462, 0.8336426923076923, 0.9429126538461539], 
             UndirectedEdge[274, 287] -> 
             RGBColor[
              0.8998062692307691, 0.851733846153846, 0.6299532692307692], 
             UndirectedEdge[251, 312] -> 
             RGBColor[
              0.9029410769230769, 0.9238667692307692, 0.9330298076923078], 
             UndirectedEdge[339, 360] -> 
             RGBColor[
              0.9176085769230768, 0.8659289230769229, 0.6316512692307692], 
             UndirectedEdge[150, 365] -> 
             RGBColor[
              0.989200576923077, 0.9874047692307693, 0.6543718076923076], 
             UndirectedEdge[61, 300] -> 
             RGBColor[
              0.6040908846153845, 0.6686128076923077, 0.8812963076923076], 
             UndirectedEdge[62, 389] -> 
             RGBColor[
              0.8226664615384615, 0.8605283076923076, 0.896583346153846], 
             UndirectedEdge[374, 399] -> 
             RGBColor[
              0.9528317307692307, 0.9162536923076923, 0.6345651923076923], 
             UndirectedEdge[27, 51] -> 
             RGBColor[
              0.9315962307692307, 0.7439891538461539, 0.4119505769230769], 
             UndirectedEdge[58, 159] -> 
             RGBColor[
              0.9431307307692307, 0.9539685384615384, 0.8470347692307695], 
             UndirectedEdge[57, 153] -> 
             RGBColor[
              0.9784394230769231, 0.9814493846153847, 0.8270571923076925], 
             UndirectedEdge[84, 264] -> 
             RGBColor[0.873390923076923, 0.9018822307692307, 0.987786], 
             UndirectedEdge[159, 201] -> 
             RGBColor[
              0.8801991923076924, 0.9042303846153845, 0.8409150769230771], 
             UndirectedEdge[80, 87] -> 
             RGBColor[
              0.9835790384615384, 0.9684419999999998, 0.6325331923076922], 
             UndirectedEdge[39, 288] -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 
             UndirectedEdge[91, 365] -> 
             RGBColor[
              0.9926128846153845, 0.9888158461538461, 0.5978210384615383], 
             UndirectedEdge[5, 384] -> 
             RGBColor[0.9062435, 0.922835, 0.7040339999999998], 
             UndirectedEdge[156, 381] -> 
             RGBColor[
              0.9869913461538461, 0.9698530769230769, 0.5759824230769228], 
             UndirectedEdge[2, 197] -> 
             RGBColor[
              0.9529172692307692, 0.8934097692307691, 0.6116736923076922], 
             UndirectedEdge[238, 293] -> 
             RGBColor[
              0.9379005769230768, 0.7766133846153846, 0.4972080769230769], 
             UndirectedEdge[85, 325] -> 
             RGBColor[
              0.9910166153846154, 0.9905531538461538, 0.7985414615384614], 
             UndirectedEdge[146, 332] -> 
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484], 
             UndirectedEdge[197, 204] -> 
             RGBColor[
              0.9666671923076922, 0.9028140769230768, 0.5503176923076922], 
             UndirectedEdge[20, 130] -> 
             RGBColor[0.9249835, 0.8943368461538461, 0.6419141538461538], 
             UndirectedEdge[167, 348] -> 
             RGBColor[
              0.9698062307692308, 0.9755848461538461, 0.8725260769230769], 
             UndirectedEdge[83, 237] -> 
             RGBColor[
              0.773607846153846, 0.8236431538461537, 0.9779169230769231], 
             UndirectedEdge[178, 334] -> 
             RGBColor[
              0.9738543846153846, 0.9797377692307693, 0.9164482307692308], 
             UndirectedEdge[178, 388] -> 
             RGBColor[
              0.966393923076923, 0.9741737692307693, 0.9290768461538462], 
             UndirectedEdge[115, 184] -> 
             RGBColor[
              0.9240458076923077, 0.9370300769230768, 0.7057319999999999], 
             UndirectedEdge[165, 385] -> 
             RGBColor[
              0.9580541538461538, 0.9671575384615384, 0.909848423076923], 
             UndirectedEdge[202, 257] -> 
             RGBColor[
              0.936194423076923, 0.7759078461538462, 0.5254834615384614], 
             UndirectedEdge[35, 57] -> 
             RGBColor[
              0.9692710769230769, 0.9766030000000001, 0.9369002307692307], 
             UndirectedEdge[115, 206] -> 
             RGBColor[
              0.9241556923076923, 0.9394729230769231, 0.8781770384615384], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.993358076923077, 0.988201923076923, 0.518445846153846], 
             UndirectedEdge[61, 98] -> 
             RGBColor[
              0.5734882307692307, 0.5500229615384615, 0.5983928461538461], 
             UndirectedEdge[33, 173] -> 
             RGBColor[
              0.9427858076923076, 0.908531923076923, 0.6436121538461538], 
             UndirectedEdge[6, 185] -> 
             RGBColor[
              0.9070985769230769, 0.9246639230769231, 0.7971038461538461], 
             UndirectedEdge[300, 363] -> 
             RGBColor[
              0.8773203076923077, 0.9032243076923077, 0.9020307307692307], 
             UndirectedEdge[34, 270] -> 
             RGBColor[
              0.9070091538461538, 0.6491178461538459, 0.24743992307692303`], 
             UndirectedEdge[162, 179] -> 
             RGBColor[
              0.8821043461538461, 0.5470189999999999, 0.5695020384615385], 
             UndirectedEdge[11, 250] -> 
             RGBColor[
              0.9913342692307692, 0.9890247692307692, 0.6726313461538461], 
             UndirectedEdge[66, 314] -> 
             RGBColor[0.8362434615384615, 0.872472, 0.9606630384615384], 
             UndirectedEdge[153, 327] -> 
             RGBColor[
              0.9609330384615384, 0.9681636153846154, 0.8487327692307695], 
             UndirectedEdge[153, 392] -> 
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079], 
             UndirectedEdge[110, 369] -> 
             RGBColor[
              0.9715352692307693, 0.9597432307692306, 0.6656138076923075], 
             UndirectedEdge[321, 398] -> 
             RGBColor[
              0.9461228461538461, 0.8089242307692307, 0.4702501153846156], 
             UndirectedEdge[188, 278] -> 
             RGBColor[
              0.9241556923076923, 0.9394729230769231, 0.8781770384615384], 
             UndirectedEdge[213, 289] -> 
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461], 
             UndirectedEdge[236, 263] -> 
             RGBColor[0.987309, 0.9683246923076922, 0.45007230769230755`], 
             UndirectedEdge[93, 383] -> 
             RGBColor[
              0.9709789615384615, 0.9758853846153845, 0.8396858076923079], 
             UndirectedEdge[56, 286] -> 
             RGBColor[
              0.9868814615384616, 0.9674102307692306, 0.40353738461538435`], 
             UndirectedEdge[25, 144] -> 
             RGBColor[
              0.9937856153846154, 0.9891163846153845, 0.5649807692307693], 
             UndirectedEdge[143, 331] -> 
             RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 
             UndirectedEdge[76, 257] -> 
             RGBColor[
              0.9587078076923077, 0.8712577692307693, 0.5439133846153845], 
             UndirectedEdge[91, 189] -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.8268168461538462], 
             UndirectedEdge[133, 145] -> 
             RGBColor[
              0.9390733076923077, 0.7769139230769231, 0.4643678076923079], 
             UndirectedEdge[207, 230] -> 
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153], 
             UndirectedEdge[238, 336] -> 
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079], 
             UndirectedEdge[123, 306] -> 
             RGBColor[
              0.9692710769230769, 0.9766030000000001, 0.9369002307692307], 
             UndirectedEdge[272, 338] -> 
             RGBColor[
              0.9587078076923077, 0.8712577692307693, 0.5439133846153845], 
             UndirectedEdge[11, 289] -> 
             RGBColor[
              0.9850448076923077, 0.9851844615384615, 0.7213587307692308], 
             UndirectedEdge[215, 300] -> 
             RGBColor[
              0.9046472307692308, 0.9245723076923077, 0.904754423076923], 
             UndirectedEdge[224, 289] -> 
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153], 
             UndirectedEdge[65, 161] -> 
             RGBColor[
              0.9850448076923077, 0.9851844615384615, 0.7213587307692308], 
             UndirectedEdge[14, 247] -> 
             RGBColor[
              0.8282616923076923, 0.8663391538461538, 0.9833643076923078], 
             UndirectedEdge[150, 226] -> 
             RGBColor[
              0.9415378076923075, 0.8072126153846153, 0.5596411538461539], 
             UndirectedEdge[15, 180] -> 
             RGBColor[
              0.9683733461538461, 0.9035196153846152, 0.5220423076923076], 
             UndirectedEdge[7, 114] -> 
             RGBColor[
              0.9876043076923076, 0.989142076923077, 0.8550922307692308], 
             UndirectedEdge[108, 313] -> 
             RGBColor[
              0.9161600769230769, 0.9349270769230769, 0.9551798076923077], 
             UndirectedEdge[227, 315] -> 
             RGBColor[
              0.9681000769230769, 0.9748793076923077, 0.9008014615384614], 
             UndirectedEdge[174, 384] -> 
             RGBColor[
              0.8555886153846154, 0.8876871538461538, 0.9860880000000001], 
             UndirectedEdge[104, 138] -> 
             RGBColor[
              0.8756141538461538, 0.9025187692307692, 0.9303061153846155], 
             UndirectedEdge[313, 344] -> 
             RGBColor[
              0.9253284230769231, 0.9397734615384615, 0.8453367692307694], 
             UndirectedEdge[255, 374] -> 
             RGBColor[0.9249835, 0.8943368461538461, 0.6419141538461538], 
             UndirectedEdge[87, 167] -> 
             RGBColor[
              0.9640748076923076, 0.9541792307692306, 0.6782424230769228], 
             UndirectedEdge[114, 312] -> 
             RGBColor[
              0.9046472307692308, 0.9245723076923077, 0.904754423076923], 
             UndirectedEdge[50, 265] -> 
             RGBColor[
              0.9698062307692308, 0.9755848461538461, 0.8725260769230769], 
             UndirectedEdge[310, 345] -> 
             RGBColor[0.9079345, 0.7289292307692308, 0.5935857692307692], 
             UndirectedEdge[315, 334] -> 
             RGBColor[
              0.9543501538461538, 0.9654750000000001, 0.9621574615384615], 
             UndirectedEdge[102, 302] -> 
             RGBColor[0.4994555, 0.5823455, 0.9580965], 
             UndirectedEdge[172, 211] -> 
             RGBColor[
              0.981259923076923, 0.9484474615384615, 0.381698769230769], 
             UndirectedEdge[264, 381] -> 
             RGBColor[
              0.9362265769230769, 0.9322623846153845, 0.6855913846153845], 
             UndirectedEdge[270, 397] -> 
             RGBColor[
              0.9427858076923076, 0.908531923076923, 0.6436121538461539], 
             UndirectedEdge[48, 290] -> 
             RGBColor[
              0.7969011923076923, 0.838489076923077, 0.8330696153846155], 
             UndirectedEdge[224, 323] -> 
             RGBColor[
              0.9854723461538462, 0.986098923076923, 0.7678936538461538], 
             UndirectedEdge[10, 339] -> 
             RGBColor[
              0.8009347692307691, 0.8449911538461539, 0.9806406153846154], 
             UndirectedEdge[254, 320] -> 
             RGBColor[
              0.7831324615384615, 0.8307960769230769, 0.9789426153846154], 
             UndirectedEdge[92, 392] -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.8268168461538462], 
             UndirectedEdge[166, 224] -> 
             RGBColor[
              0.9692710769230769, 0.9766030000000001, 0.9369002307692307], 
             UndirectedEdge[108, 344] -> 
             RGBColor[
              0.9858998846153846, 0.9870133846153846, 0.8144285769230771], 
             UndirectedEdge[180, 271] -> 
             RGBColor[
              0.9910166153846154, 0.9905531538461538, 0.7985414615384614], 
             UndirectedEdge[104, 207] -> 
             RGBColor[0.8710308461538461, 0.899384, 0.9507581153846154], 
             UndirectedEdge[45, 266] -> 
             RGBColor[
              0.9813698076923076, 0.9508903076923076, 0.5541438076923075], 
             UndirectedEdge[59, 373] -> 
             RGBColor[0.8515896538461538, 0.880139, 0.6985866153846152], 
             UndirectedEdge[107, 352] -> 
             RGBColor[
              0.9692710769230769, 0.9766030000000001, 0.9369002307692307], 
             UndirectedEdge[99, 338] -> 
             RGBColor[
              0.9274514999999999, 0.8485676923076921, 0.6269449615384615], 
             UndirectedEdge[186, 341] -> 
             RGBColor[
              0.9756383846153847, 0.9294846923076923, 0.3598601538461537], 
             UndirectedEdge[90, 156] -> 
             RGBColor[
              0.9772666923076923, 0.9811488461538462, 0.8598974615384615], 
             UndirectedEdge[34, 151] -> 
             RGBColor[
              0.9222774999999999, 0.7077434615384615, 0.5136761923076922], 
             UndirectedEdge[174, 260] -> 
             RGBColor[
              0.9339623846153846, 0.9491221538461538, 0.9568778076923077], 
             UndirectedEdge[13, 216] -> 
             RGBColor[
              0.9176085769230768, 0.8659289230769229, 0.6316512692307692], 
             UndirectedEdge[9, 217] -> 
             RGBColor[
              0.9609330384615384, 0.9681636153846154, 0.8487327692307695], 
             UndirectedEdge[87, 159] -> 
             RGBColor[
              0.9881640769230768, 0.9701536153846153, 0.5431421538461538], 
             UndirectedEdge[184, 305] -> 
             RGBColor[
              0.8789165769230769, 0.9014869999999999, 0.7013103076923075], 
             UndirectedEdge[12, 259] -> 
             RGBColor[
              0.9760659230769231, 0.9303991538461538, 0.40639507692307697`], 
             UndirectedEdge[27, 287] -> 
             RGBColor[
              0.8622839615384615, 0.6928173076923078, 0.5992367307692308], 
             UndirectedEdge[188, 284] -> 
             RGBColor[0.9604139615384615, 0.8719633076923077, 0.515638], 
             UndirectedEdge[118, 126] -> 
             RGBColor[
              0.970551423076923, 0.974970923076923, 0.7931508846153845], 
             UndirectedEdge[209, 304] -> 
             RGBColor[
              0.8555886153846154, 0.8876871538461538, 0.9860880000000001], 
             UndirectedEdge[48, 108] -> 
             RGBColor[
              0.9858998846153846, 0.9870133846153846, 0.8144285769230771], 
             UndirectedEdge[136, 376] -> 
             RGBColor[
              0.9683733461538461, 0.9035196153846152, 0.5220423076923076], 
             UndirectedEdge[48, 344] -> 
             RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 
             UndirectedEdge[13, 198] -> 
             RGBColor[
              0.8668979615384615, 0.6222729230769231, 0.5889568461538461], 
             UndirectedEdge[286, 320] -> 
             RGBColor[0.8515896538461538, 0.880139, 0.6985866153846152], 
             UndirectedEdge[176, 368] -> 
             RGBColor[
              0.9877365384615384, 0.9692391538461538, 0.4966072307692305], 
             UndirectedEdge[248, 388] -> 
             RGBColor[
              0.9374974230769231, 0.8562894615384615, 0.6178980000000001], 
             UndirectedEdge[57, 188] -> 
             RGBColor[
              0.9772666923076923, 0.9811488461538462, 0.8598974615384615], 
             UndirectedEdge[39, 225] -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 
             UndirectedEdge[355, 379] -> 
             RGBColor[
              0.9700168461538461, 0.9105219230769229, 0.33802153846153826`], 
             UndirectedEdge[85, 348] -> 
             RGBColor[
              0.9927227692307692, 0.9912586923076924, 0.7702660769230769], 
             UndirectedEdge[118, 336] -> 
             RGBColor[
              0.9709789615384615, 0.9758853846153845, 0.8396858076923079], 
             UndirectedEdge[195, 392] -> 
             RGBColor[
              0.9698062307692308, 0.9755848461538461, 0.8725260769230769], 
             UndirectedEdge[193, 281] -> 
             RGBColor[0.9055917692307691, 0.657318, 0.24258], 
             UndirectedEdge[154, 312] -> 
             RGBColor[0.8908973076923077, 0.915168, 0.9661104230769231], 
             UndirectedEdge[53, 171] -> 
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998], 
             UndirectedEdge[115, 188] -> 
             RGBColor[
              0.9241556923076923, 0.9394729230769231, 0.8781770384615384], 
             UndirectedEdge[319, 329] -> 
             RGBColor[
              0.9946406923076923, 0.9909453076923077, 0.6580506153846155], 
             UndirectedEdge[231, 359] -> 
             RGBColor[
              0.6889829230769231, 0.7538546153846154, 0.9617374230769231], 
             UndirectedEdge[288, 399] -> 
             RGBColor[
              0.9681000769230769, 0.9748793076923077, 0.9008014615384614], 
             UndirectedEdge[140, 220] -> 
             RGBColor[0.872058423076923, 0.5392972307692308, 0.578549], 
             UndirectedEdge[9, 215] -> 
             RGBColor[0.873390923076923, 0.9018822307692307, 0.987786], 
             UndirectedEdge[309, 329] -> 
             RGBColor[
              0.7969011923076923, 0.838489076923077, 0.8330696153846155], 
             UndirectedEdge[9, 61] -> 
             RGBColor[
              0.5728345769230768, 0.6459227307692307, 0.9643278846153847], 
             UndirectedEdge[21, 82] -> 
             RGBColor[
              0.9771568076923077, 0.9787060000000001, 0.6874524230769229], 
             UndirectedEdge[154, 361] -> 
             RGBColor[
              0.9784394230769231, 0.9814493846153847, 0.8270571923076925], 
             UndirectedEdge[160, 213] -> 
             RGBColor[0.9079345, 0.7289292307692308, 0.5935857692307693], 
             UndirectedEdge[331, 342] -> 
             RGBColor[
              0.9780118846153847, 0.9805349230769231, 0.7805222692307692], 
             UndirectedEdge[122, 159] -> 
             RGBColor[
              0.9881640769230768, 0.9701536153846153, 0.5431421538461538], 
             UndirectedEdge[258, 278] -> 
             RGBColor[
              0.9241556923076923, 0.9394729230769231, 0.8781770384615384], 
             UndirectedEdge[37, 201] -> 
             RGBColor[
              0.8801991923076924, 0.9042303846153845, 0.8409150769230771], 
             UndirectedEdge[61, 314] -> 
             RGBColor[
              0.5903409615384615, 0.6592085000000001, 0.9426523076923077], 
             UndirectedEdge[297, 314] -> 
             RGBColor[
              0.9715352692307693, 0.9597432307692306, 0.6656138076923075], 
             UndirectedEdge[84, 175] -> 
             RGBColor[
              0.9207433846153845, 0.9380618461538461, 0.9347278076923078], 
             UndirectedEdge[72, 374] -> 
             RGBColor[
              0.9700168461538461, 0.9105219230769229, 0.33802153846153826`], 
             UndirectedEdge[168, 180] -> 
             RGBColor[
              0.8243726153846154, 0.8612338461538461, 0.8683079615384615], 
             UndirectedEdge[36, 60] -> 
             RGBColor[
              0.9659137307692307, 0.9407804615384615, 0.6437751923076922], 
             UndirectedEdge[347, 387] -> 
             RGBColor[
              0.9432439615384615, 0.8079181538461537, 0.5313657692307692], 
             UndirectedEdge[140, 141] -> 
             RGBColor[
              0.9016085769230768, 0.5612817692307692, 0.5237928076923077], 
             UndirectedEdge[233, 382] -> 
             RGBColor[
              0.948407346153846, 0.9274946923076921, 0.6654507692307691], 
             UndirectedEdge[21, 122] -> 
             RGBColor[
              0.9715352692307693, 0.9597432307692306, 0.6656138076923075], 
             UndirectedEdge[202, 268] -> 
             RGBColor[
              0.9209260769230769, 0.7172822307692308, 0.2592471923076923], 
             UndirectedEdge[196, 344] -> 
             RGBColor[
              0.9881640769230768, 0.9701536153846153, 0.5431421538461538], 
             UndirectedEdge[109, 343] -> 
             RGBColor[
              0.9320237692307692, 0.7449036153846155, 0.4584855000000002], 
             UndirectedEdge[52, 117] -> 
             RGBColor[
              0.9877365384615384, 0.9692391538461538, 0.4966072307692305], 
             UndirectedEdge[51, 194] -> 
             RGBColor[
              0.9386457692307693, 0.7759994615384616, 0.4178328846153846], 
             UndirectedEdge[223, 342] -> 
             RGBColor[
              0.7673904230769231, 0.8139635384615385, 0.7842451538461538], 
             UndirectedEdge[241, 374] -> 
             RGBColor[
              0.9764934615384615, 0.9313136153846153, 0.45292999999999994`], 
             UndirectedEdge[76, 109] -> 
             RGBColor[
              0.9615866923076923, 0.8722638461538461, 0.482797730769231], 
             UndirectedEdge[90, 381] -> 
             RGBColor[
              0.9715352692307693, 0.9597432307692306, 0.6656138076923075], 
             UndirectedEdge[75, 227] -> 
             RGBColor[
              0.9921893461538461, 0.9908536923076923, 0.7657011923076924], 
             UndirectedEdge[209, 329] -> 
             RGBColor[
              0.9431307307692307, 0.9539685384615384, 0.8470347692307695], 
             UndirectedEdge[24, 358] -> 
             RGBColor[
              0.9415378076923075, 0.8072126153846153, 0.5596411538461539], 
             UndirectedEdge[208, 369] -> 
             RGBColor[
              0.9881640769230768, 0.9701536153846153, 0.5431421538461538], 
             UndirectedEdge[62, 400] -> 
             RGBColor[
              0.9913342692307692, 0.9890247692307692, 0.6726313461538461], 
             UndirectedEdge[127, 325] -> 
             RGBColor[
              0.9921893461538461, 0.9908536923076923, 0.7657011923076924], 
             UndirectedEdge[43, 277] -> 
             RGBColor[
              0.9029410769230769, 0.9238667692307692, 0.9330298076923078], 
             UndirectedEdge[70, 227] -> 
             RGBColor[
              0.9580541538461538, 0.9671575384615384, 0.909848423076923], 
             UndirectedEdge[25, 366] -> 
             RGBColor[
              0.9536273076923076, 0.8407075384615386, 0.47639342307692334`], 
             UndirectedEdge[20, 387] -> 
             RGBColor[
              0.940251846153846, 0.9529624615384615, 0.9081504230769231], 
             UndirectedEdge[328, 387] -> 
             RGBColor[
              0.9666671923076922, 0.9028140769230768, 0.5503176923076922], 
             UndirectedEdge[249, 386] -> 
             RGBColor[
              0.940251846153846, 0.9529624615384615, 0.9081504230769231], 
             UndirectedEdge[110, 243] -> 
             RGBColor[
              0.9775843461538463, 0.9796204615384616, 0.7339873461538462], 
             UndirectedEdge[47, 121] -> 
             RGBColor[
              0.9937856153846154, 0.9891163846153846, 0.5649807692307692], 
             UndirectedEdge[31, 156] -> 
             RGBColor[
              0.9772666923076923, 0.9811488461538462, 0.8598974615384615], 
             UndirectedEdge[98, 283] -> 
             RGBColor[
              0.9374974230769231, 0.8562894615384615, 0.6178980000000001], 
             UndirectedEdge[38, 358] -> 
             RGBColor[
              0.8572482307692307, 0.3800578461538461, 0.20006634615384614`], 
             UndirectedEdge[126, 199] -> 
             RGBColor[
              0.9854723461538462, 0.986098923076923, 0.7678936538461538], 
             UndirectedEdge[39, 200] -> 
             RGBColor[
              0.940251846153846, 0.9529624615384615, 0.9081504230769231], 
             UndirectedEdge[227, 304] -> 
             RGBColor[
              0.9046472307692308, 0.9245723076923077, 0.904754423076923], 
             UndirectedEdge[242, 333] -> 
             RGBColor[
              0.9868814615384616, 0.9674102307692306, 0.40353738461538435`], 
             UndirectedEdge[30, 333] -> 
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998], 
             UndirectedEdge[85, 96] -> 
             RGBColor[
              0.9813698076923076, 0.9508903076923076, 0.5541438076923075], 
             UndirectedEdge[39, 94] -> 
             RGBColor[
              0.8226664615384615, 0.8605283076923076, 0.896583346153846], 
             UndirectedEdge[63, 138] -> 
             RGBColor[
              0.9876043076923076, 0.989142076923077, 0.8550922307692308], 
             UndirectedEdge[119, 324] -> 
             RGBColor[
              0.9946406923076923, 0.9909453076923077, 0.6580506153846155], 
             UndirectedEdge[18, 224] -> 
             RGBColor[
              0.9813148461538461, 0.9853017692307693, 0.9038196153846154], 
             UndirectedEdge[84, 204] -> 
             RGBColor[
              0.9224495384615384, 0.9387673846153846, 0.906452423076923], 
             UndirectedEdge[241, 288] -> 
             RGBColor[
              0.9917618076923076, 0.9899392307692307, 0.7191662692307691], 
             UndirectedEdge[91, 266] -> 
             RGBColor[
              0.9813698076923076, 0.9508903076923076, 0.5541438076923075], 
             UndirectedEdge[201, 263] -> 
             RGBColor[
              0.8793441153846154, 0.9024014615384615, 0.7478452307692308], 
             UndirectedEdge[29, 266] -> 
             RGBColor[
              0.9128027307692308, 0.8991045384615384, 0.6620547692307691], 
             UndirectedEdge[161, 326] -> 
             RGBColor[
              0.9937856153846154, 0.9891163846153846, 0.5649807692307692], 
             UndirectedEdge[174, 235] -> 
             RGBColor[
              0.940251846153846, 0.9529624615384615, 0.9081504230769231], 
             UndirectedEdge[207, 233] -> 
             RGBColor[
              0.9517646923076921, 0.9633172307692307, 0.9585758076923077], 
             UndirectedEdge[199, 212] -> 
             RGBColor[
              0.9789957307692307, 0.9653072307692306, 0.6529851923076921], 
             UndirectedEdge[127, 184] -> 
             RGBColor[
              0.9937856153846154, 0.9891163846153845, 0.5649807692307693], 
             UndirectedEdge[261, 381] -> 
             RGBColor[
              0.9869913461538461, 0.9698530769230769, 0.5759824230769228], 
             UndirectedEdge[221, 230] -> 
             RGBColor[0.8970252692307692, 0.558147, 0.5442448076923077], 
             UndirectedEdge[22, 273] -> 
             RGBColor[
              0.9910166153846154, 0.9905531538461538, 0.7985414615384614], 
             UndirectedEdge[240, 292] -> 
             RGBColor[
              0.9609330384615384, 0.9681636153846154, 0.8487327692307695], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.9757482692307692, 0.9319275384615384, 0.5323051923076922], 
             UndirectedEdge[120, 343] -> 
             RGBColor[
              0.9315962307692307, 0.7439891538461539, 0.4119505769230769], 
             UndirectedEdge[175, 310] -> 
             RGBColor[
              0.966393923076923, 0.9741737692307693, 0.9290768461538462], 
             UndirectedEdge[55, 201] -> 
             RGBColor[
              0.8797716538461539, 0.903315923076923, 0.7943801538461538], 
             UndirectedEdge[264, 333] -> 
             RGBColor[
              0.9418481153846154, 0.9512251538461538, 0.7074299999999999], 
             UndirectedEdge[107, 197] -> 
             RGBColor[
              0.9529172692307692, 0.8934097692307691, 0.6116736923076922], 
             UndirectedEdge[131, 300] -> 
             RGBColor[0.9740421153846153, 0.931222, 0.5605805769230767], 
             UndirectedEdge[164, 227] -> 
             RGBColor[
              0.9913342692307692, 0.9890247692307692, 0.6726313461538461], 
             UndirectedEdge[75, 315] -> 
             RGBColor[
              0.9709789615384615, 0.9758853846153845, 0.8396858076923079], 
             UndirectedEdge[123, 193] -> 
             RGBColor[0.9224445, 0.7665035384615385, 0.5868394615384614], 
             UndirectedEdge[157, 253] -> 
             RGBColor[
              0.9830209999999999, 0.9860073076923077, 0.8755442307692307], 
             UndirectedEdge[87, 110] -> 
             RGBColor[
              0.9715352692307693, 0.9597432307692306, 0.6656138076923075], 
             UndirectedEdge[112, 273] -> 
             RGBColor[
              0.9910166153846154, 0.9905531538461538, 0.7985414615384614], 
             UndirectedEdge[193, 384] -> 
             RGBColor[
              0.8515311923076923, 0.7106325384615384, 0.6034210384615384], 
             UndirectedEdge[95, 249] -> 
             RGBColor[
              0.9265019230769231, 0.9435581538461539, 0.969506423076923], 
             UndirectedEdge[61, 66] -> 
             RGBColor[0.4647738076923076, 0.5606415, 0.9537865], 
             UndirectedEdge[113, 251] -> 
             RGBColor[
              0.9649610384615384, 0.9021085384615383, 0.5785930769230769], 
             UndirectedEdge[107, 131] -> 
             RGBColor[
              0.9602921923076924, 0.9218176923076924, 0.6219365769230768], 
             UndirectedEdge[71, 343] -> 
             RGBColor[
              0.9153949615384616, 0.7344932307692309, 0.5809571538461538], 
             UndirectedEdge[113, 168] -> 
             RGBColor[
              0.8000231923076921, 0.773494769230769, 0.6200841923076923], 
             UndirectedEdge[58, 201] -> 
             RGBColor[
              0.8282616923076923, 0.8663391538461538, 0.9833643076923078], 
             UndirectedEdge[47, 130] -> 
             RGBColor[
              0.9764934615384615, 0.9313136153846153, 0.45292999999999994`], 
             UndirectedEdge[17, 82] -> 
             RGBColor[
              0.993358076923077, 0.988201923076923, 0.518445846153846], 
             UndirectedEdge[11, 25] -> 
             RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076925], 
             UndirectedEdge[73, 392] -> 
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079], 
             UndirectedEdge[155, 337] -> 
             RGBColor[
              0.9904831923076922, 0.9901481538461538, 0.7939765769230772], 
             UndirectedEdge[159, 165] -> 
             RGBColor[
              0.9609330384615384, 0.9681636153846154, 0.8487327692307695], 
             UndirectedEdge[226, 368] -> 
             RGBColor[
              0.9392186923076922, 0.7872180769230768, 0.30880673076923054`], 
             UndirectedEdge[188, 258] -> 
             RGBColor[
              0.9927227692307692, 0.9912586923076924, 0.7702660769230769], 
             UndirectedEdge[140, 350] -> 
             RGBColor[
              0.624197576923077, 0.3409626153846154, 0.5564533846153846], 
             UndirectedEdge[14, 38] -> 
             RGBColor[
              0.791324576923077, 0.47536399999999995`, 0.5707313076923077], 
             UndirectedEdge[242, 268] -> 
             RGBColor[
              0.9700168461538461, 0.9105219230769229, 0.33802153846153826`], 
             UndirectedEdge[20, 50] -> 
             RGBColor[0.941958, 0.953668, 0.8798750384615385], 
             UndirectedEdge[149, 212] -> 
             RGBColor[
              0.9392186923076922, 0.7872180769230768, 0.30880673076923054`], 
             UndirectedEdge[80, 361] -> 
             RGBColor[
              0.9904831923076922, 0.9901481538461538, 0.7939765769230772], 
             UndirectedEdge[31, 204] -> 
             RGBColor[
              0.9755605384615385, 0.9804433076923078, 0.8881728461538461], 
             UndirectedEdge[209, 245] -> 
             RGBColor[
              0.9190414615384614, 0.9379941538461538, 0.9821350384615385], 
             UndirectedEdge[113, 148] -> 
             RGBColor[
              0.8869923846153847, 0.5235391538461539, 0.2250711923076923], 
             UndirectedEdge[48, 231] -> 
             RGBColor[
              0.9709789615384615, 0.9758853846153845, 0.8396858076923079], 
             UndirectedEdge[198, 224] -> 
             RGBColor[
              0.9096671153846154, 0.6553177692307692, 0.5563506538461538], 
             UndirectedEdge[1, 188] -> 
             RGBColor[
              0.9934679615384615, 0.9906447692307693, 0.6908908846153845], 
             UndirectedEdge[256, 264] -> 
             RGBColor[0.873390923076923, 0.9018822307692307, 0.987786], 
             UndirectedEdge[15, 170] -> 
             RGBColor[
              0.8806714615384614, 0.47495376923076904`, 0.21901826923076917`],
              UndirectedEdge[20, 322] -> 
             RGBColor[
              0.9418481153846154, 0.9512251538461538, 0.7074299999999999], 
             UndirectedEdge[92, 153] -> 
             RGBColor[
              0.9904831923076922, 0.9901481538461538, 0.7939765769230772], 
             UndirectedEdge[189, 360] -> 
             RGBColor[
              0.9649610384615384, 0.9021085384615383, 0.5785930769230769], 
             UndirectedEdge[272, 342] -> 
             RGBColor[
              0.9917618076923076, 0.9899392307692307, 0.7191662692307691], 
             UndirectedEdge[69, 219] -> 
             RGBColor[
              0.9946406923076923, 0.9909453076923077, 0.6580506153846155], 
             UndirectedEdge[86, 151] -> 
             RGBColor[
              0.9681000769230769, 0.9748793076923077, 0.9008014615384614], 
             UndirectedEdge[72, 288] -> 
             RGBColor[
              0.9852851923076922, 0.9691475384615383, 0.6042578076923074], 
             UndirectedEdge[266, 273] -> 
             RGBColor[
              0.9813698076923076, 0.9508903076923076, 0.5541438076923075], 
             UndirectedEdge[131, 297] -> 
             RGBColor[
              0.9700168461538461, 0.9105219230769229, 0.33802153846153826`], 
             UndirectedEdge[219, 360] -> 
             RGBColor[
              0.9691185384615384, 0.9029056923076921, 0.4426671153846153], 
             UndirectedEdge[58, 236] -> 
             RGBColor[
              0.9362265769230769, 0.9322623846153845, 0.6855913846153845], 
             UndirectedEdge[272, 321] -> 
             RGBColor[
              0.9921893461538461, 0.9908536923076923, 0.7657011923076924], 
             UndirectedEdge[250, 391] -> 
             RGBColor[
              0.9852851923076922, 0.9691475384615383, 0.6042578076923074], 
             UndirectedEdge[122, 298] -> 
             RGBColor[
              0.9321691538461538, 0.755207769230769, 0.3029244230769229], 
             UndirectedEdge[113, 282] -> 
             RGBColor[
              0.8998062692307691, 0.851733846153846, 0.6299532692307692], 
             UndirectedEdge[237, 343] -> 
             RGBColor[
              0.8800862692307692, 0.7070123846153846, 0.6009347307692308], 
             UndirectedEdge[174, 398] -> 
             RGBColor[
              0.894185346153846, 0.7710329999999999, 0.6126993461538461], 
             UndirectedEdge[223, 384] -> 
             RGBColor[
              0.6802758461538462, 0.7485966153846153, 0.9698333076923077], 
             UndirectedEdge[143, 260] -> 
             RGBColor[
              0.9692710769230769, 0.9766030000000001, 0.9369002307692307], 
             UndirectedEdge[148, 161] -> 
             RGBColor[
              0.9116594615384617, 0.6097498461538464, 0.34738484615384624`], 
             UndirectedEdge[137, 199] -> 
             RGBColor[
              0.9369544999999999, 0.804077846153846, 0.5800931538461538], 
             UndirectedEdge[147, 387] -> 
             RGBColor[
              0.9046472307692308, 0.9245723076923077, 0.904754423076923], 
             UndirectedEdge[138, 381] -> 
             RGBColor[
              0.9835790384615384, 0.9684419999999998, 0.6325331923076922], 
             UndirectedEdge[42, 207] -> 
             RGBColor[
              0.9692710769230769, 0.9766030000000001, 0.9369002307692307], 
             UndirectedEdge[185, 247] -> 
             RGBColor[
              0.9427031923076923, 0.9530540769230769, 0.8004998461538462], 
             UndirectedEdge[49, 380] -> 
             RGBColor[
              0.9049381153846152, 0.7532177692307691, 0.6085150384615384], 
             UndirectedEdge[63, 242] -> 
             RGBColor[
              0.9852851923076922, 0.9691475384615383, 0.6042578076923074], 
             UndirectedEdge[12, 238] -> 
             RGBColor[
              0.9930404230769231, 0.9897303076923077, 0.6443559615384615], 
             UndirectedEdge[109, 382] -> 
             RGBColor[
              0.9825425384615385, 0.9511908461538461, 0.5213035384615385], 
             UndirectedEdge[4, 115] -> 
             RGBColor[
              0.9224495384615384, 0.9387673846153846, 0.906452423076923], 
             UndirectedEdge[187, 279] -> 
             RGBColor[
              0.9854723461538462, 0.986098923076923, 0.7678936538461538], 
             UndirectedEdge[152, 156] -> 
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079], 
             UndirectedEdge[143, 290] -> 
             RGBColor[
              0.7802723846153847, 0.8280786923076924, 0.9555412692307692], 
             UndirectedEdge[48, 234] -> 
             RGBColor[
              0.7387347307692308, 0.791266923076923, 0.8284905384615386], 
             UndirectedEdge[294, 341] -> 
             RGBColor[
              0.9771568076923077, 0.9787060000000001, 0.6874524230769229], 
             UndirectedEdge[243, 351] -> 
             RGBColor[
              0.9066710384615385, 0.9237494615384616, 0.7505689230769231], 
             UndirectedEdge[241, 399] -> 
             RGBColor[
              0.970551423076923, 0.974970923076923, 0.7931508846153845], 
             UndirectedEdge[78, 207] -> 
             RGBColor[
              0.9850448076923077, 0.9851844615384615, 0.7213587307692308], 
             UndirectedEdge[174, 267] -> 
             RGBColor[
              0.8871358076923077, 0.7390226923076924, 0.6068170384615384], 
             UndirectedEdge[124, 293] -> 
             RGBColor[
              0.9149840384615384, 0.7609395384615385, 0.5994680769230769], 
             UndirectedEdge[57, 392] -> 
             RGBColor[
              0.9772666923076923, 0.9811488461538462, 0.8598974615384615], 
             UndirectedEdge[272, 331] -> 
             RGBColor[
              0.9755605384615385, 0.9804433076923078, 0.8881728461538461], 
             UndirectedEdge[91, 255] -> 
             RGBColor[0.941958, 0.953668, 0.8798750384615385], 
             UndirectedEdge[35, 337] -> 
             RGBColor[
              0.9813148461538461, 0.9853017692307693, 0.9038196153846154], 
             UndirectedEdge[219, 339] -> 
             RGBColor[
              0.9427031923076923, 0.9530540769230769, 0.8004998461538462], 
             UndirectedEdge[166, 185] -> 
             RGBColor[
              0.9780118846153847, 0.9805349230769231, 0.7805222692307692], 
             UndirectedEdge[137, 238] -> 
             RGBColor[
              0.9449501153846154, 0.8086236923076923, 0.5030903846153846], 
             UndirectedEdge[218, 300] -> 
             RGBColor[
              0.9033147307692307, 0.5619873076923076, 0.49551742307692304`], 
             UndirectedEdge[96, 110] -> 
             RGBColor[
              0.9659137307692307, 0.9407804615384615, 0.6437751923076922], 
             UndirectedEdge[225, 375] -> 
             RGBColor[0.9740421153846153, 0.931222, 0.5605805769230768], 
             UndirectedEdge[24, 25] -> 
             RGBColor[
              0.9904831923076922, 0.9901481538461538, 0.7939765769230772], 
             UndirectedEdge[40, 361] -> 
             RGBColor[
              0.9921893461538461, 0.9908536923076923, 0.7657011923076924], 
             UndirectedEdge[141, 394] -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.8268168461538462], 
             UndirectedEdge[200, 360] -> 
             RGBColor[
              0.9176085769230768, 0.8659289230769229, 0.6316512692307692], 
             UndirectedEdge[68, 229] -> 
             RGBColor[
              0.7586496153846154, 0.8100316153846154, 0.9406231153846154], 
             UndirectedEdge[96, 258] -> 
             RGBColor[
              0.9813698076923076, 0.9508903076923076, 0.5541438076923075], 
             UndirectedEdge[106, 310] -> 
             RGBColor[
              0.9374974230769231, 0.8562894615384615, 0.6178980000000001], 
             UndirectedEdge[15, 394] -> 
             RGBColor[
              0.9683733461538461, 0.9035196153846152, 0.5220423076923076], 
             UndirectedEdge[115, 203] -> 
             RGBColor[
              0.9086996153846154, 0.929363076923077, 0.967808423076923], 
             UndirectedEdge[218, 298] -> 
             RGBColor[
              0.8501986923076923, 0.34804753846153846`, 0.19418403846153848`],
              UndirectedEdge[165, 262] -> 
             RGBColor[
              0.9443042307692306, 0.9577532307692307, 0.971204423076923], 
             UndirectedEdge[141, 357] -> 
             RGBColor[
              0.9029410769230769, 0.9238667692307692, 0.9330298076923078], 
             UndirectedEdge[15, 239] -> 
             RGBColor[
              0.9529172692307692, 0.8934097692307691, 0.6116736923076922], 
             UndirectedEdge[80, 228] -> 
             RGBColor[
              0.8756141538461538, 0.9025187692307692, 0.9303061153846155], 
             UndirectedEdge[260, 272] -> 
             RGBColor[
              0.9830209999999999, 0.9860073076923077, 0.8755442307692307], 
             UndirectedEdge[7, 361] -> 
             RGBColor[
              0.9904831923076922, 0.9901481538461538, 0.7939765769230772], 
             UndirectedEdge[22, 255] -> 
             RGBColor[
              0.940251846153846, 0.9529624615384615, 0.9081504230769231], 
             UndirectedEdge[28, 380] -> 
             RGBColor[
              0.9299049615384615, 0.7720675384615385, 0.5742108461538461], 
             UndirectedEdge[53, 397] -> 
             RGBColor[0.9596504230769229, 0.9654202307692307, 0.709128], 
             UndirectedEdge[187, 306] -> 
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153], 
             UndirectedEdge[208, 392] -> 
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079], 
             UndirectedEdge[33, 381] -> 
             RGBColor[
              0.9540288846153845, 0.9464574615384613, 0.6872893846153845], 
             UndirectedEdge[290, 321] -> 
             RGBColor[
              0.7969011923076923, 0.838489076923077, 0.8330696153846155], 
             UndirectedEdge[20, 116] -> 
             RGBColor[
              0.7158804615384615, 0.7769867692307693, 0.9732293076923078], 
             UndirectedEdge[33, 156] -> 
             RGBColor[
              0.9597603076923076, 0.9678630769230769, 0.8815730384615384], 
             UndirectedEdge[9, 202] -> 
             RGBColor[
              0.9049381153846152, 0.7532177692307691, 0.6085150384615384], 
             UndirectedEdge[76, 233] -> 
             RGBColor[
              0.9274514999999999, 0.8485676923076921, 0.6269449615384615], 
             UndirectedEdge[115, 369] -> 
             RGBColor[
              0.9184242692307691, 0.9180673076923076, 0.6838933846153844], 
             UndirectedEdge[183, 335] -> 
             RGBColor[
              0.9937856153846154, 0.9891163846153845, 0.5649807692307693], 
             UndirectedEdge[39, 296] -> 
             RGBColor[0.7940223076923076, 0.837483, 0.8941852692307691], 
             UndirectedEdge[10, 219] -> 
             RGBColor[
              0.8524447307692307, 0.8819679230769231, 0.7916564615384615], 
             UndirectedEdge[71, 143] -> 
             RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 
             UndirectedEdge[232, 384] -> 
             RGBColor[0.8983577692307692, 0.920732, 0.9534818076923077], 
             UndirectedEdge[1, 57] -> 
             RGBColor[
              0.9780118846153847, 0.9805349230769231, 0.7805222692307692], 
             UndirectedEdge[288, 393] -> 
             RGBColor[
              0.9909067307692307, 0.9881103076923077, 0.6260964230769229], 
             UndirectedEdge[328, 372] -> 
             RGBColor[
              0.944023923076923, 0.8157805384615381, 0.27381853846153836`], 
             UndirectedEdge[16, 115] -> 
             RGBColor[
              0.8104593846153847, 0.8521440769230768, 0.9816663076923077], 
             UndirectedEdge[34, 244] -> 
             RGBColor[
              0.8362817692307691, 0.2798831538461537, 0.1823767692307692], 
             UndirectedEdge[233, 366] -> 
             RGBColor[
              0.9194921153846153, 0.8170113846153846, 0.6205406538461539], 
             UndirectedEdge[100, 105] -> 
             RGBColor[
              0.9240458076923077, 0.9370300769230768, 0.7057319999999998], 
             UndirectedEdge[88, 282] -> 
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484], 
             UndirectedEdge[189, 219] -> 
             RGBColor[
              0.9900556538461538, 0.9892336923076923, 0.7474416538461539], 
             UndirectedEdge[44, 328] -> 
             RGBColor[
              0.9065016153846153, 0.6568639999999999, 0.24310199999999996`], 
             UndirectedEdge[153, 154] -> 
             RGBColor[
              0.9784394230769231, 0.9814493846153847, 0.8270571923076925], 
             UndirectedEdge[73, 258] -> 
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079], 
             UndirectedEdge[22, 141] -> 
             RGBColor[
              0.9876043076923076, 0.989142076923077, 0.8550922307692308], 
             UndirectedEdge[100, 273] -> 
             RGBColor[
              0.9926128846153845, 0.9888158461538461, 0.5978210384615383], 
             UndirectedEdge[230, 391] -> 
             RGBColor[
              0.9789957307692307, 0.9653072307692306, 0.6529851923076921], 
             UndirectedEdge[338, 384] -> 
             RGBColor[
              0.8740445769230769, 0.8059824615384614, 0.6218509615384615], 
             UndirectedEdge[76, 207] -> 
             RGBColor[
              0.952418346153846, 0.8674174615384616, 0.5926407692307691], 
             UndirectedEdge[144, 370] -> 
             RGBColor[0.9062435, 0.922835, 0.7040339999999998], 
             UndirectedEdge[6, 340] -> 
             RGBColor[0.8908973076923077, 0.915168, 0.9661104230769231], 
             UndirectedEdge[30, 370] -> 
             RGBColor[0.9062435, 0.922835, 0.7040339999999998], 
             UndirectedEdge[164, 245] -> 
             RGBColor[
              0.9701238846153846, 0.9740564615384615, 0.7466159615384615], 
             UndirectedEdge[56, 108] -> 
             RGBColor[
              0.9789957307692307, 0.9653072307692306, 0.6529851923076921], 
             UndirectedEdge[50, 322] -> 
             RGBColor[
              0.9926128846153845, 0.9888158461538461, 0.5978210384615383], 
             UndirectedEdge[379, 399] -> 
             RGBColor[
              0.9640748076923076, 0.9541792307692306, 0.6782424230769228], 
             UndirectedEdge[6, 13] -> 
             RGBColor[
              0.8555886153846154, 0.8876871538461538, 0.9860880000000001], 
             UndirectedEdge[55, 60] -> 
             RGBColor[
              0.9780118846153847, 0.9805349230769231, 0.7805222692307692], 
             UndirectedEdge[44, 47] -> 
             RGBColor[
              0.9315962307692307, 0.7439891538461539, 0.4119505769230769], 
             UndirectedEdge[156, 264] -> 
             RGBColor[0.941958, 0.953668, 0.8798750384615385], 
             UndirectedEdge[32, 43] -> 
             RGBColor[
              0.8515311923076923, 0.7106325384615384, 0.6034210384615384], 
             UndirectedEdge[144, 207] -> 
             RGBColor[0.9846172692307692, 0.98427, 0.6748238076923075], 
             UndirectedEdge[14, 213] -> 
             RGBColor[
              0.8561099230769231, 0.8882559999999999, 0.9760153461538461], 
             UndirectedEdge[127, 139] -> 
             RGBColor[
              0.9431307307692307, 0.9539685384615384, 0.8470347692307695], 
             UndirectedEdge[321, 342] -> 
             RGBColor[
              0.9946406923076923, 0.9909453076923077, 0.6580506153846155], 
             UndirectedEdge[82, 182] -> 
             RGBColor[
              0.7665353461538462, 0.8121346153846154, 0.6911753076923075], 
             UndirectedEdge[50, 172] -> 
             RGBColor[
              0.9813698076923076, 0.9508903076923076, 0.5541438076923075], 
             UndirectedEdge[80, 96] -> 
             RGBColor[
              0.9779574999999999, 0.9494792307692307, 0.6106945769230768], 
             UndirectedEdge[78, 160] -> 
             RGBColor[
              0.9311686923076923, 0.7430746923076924, 0.36541565384615393`], 
             UndirectedEdge[32, 293] -> 
             RGBColor[
              0.8830783846153846, 0.5619680769230769, 0.22415007692307692`], 
             UndirectedEdge[322, 328] -> 
             RGBColor[
              0.9682634615384615, 0.9010767692307691, 0.34959726923076906`], 
             UndirectedEdge[120, 254] -> 
             RGBColor[0.9249008846153846, 0.938859, 0.7988018461538461], 
             UndirectedEdge[291, 321] -> 
             RGBColor[
              0.9320237692307692, 0.7449036153846155, 0.4584855000000002], 
             UndirectedEdge[65, 312] -> 
             RGBColor[0.8983577692307692, 0.920732, 0.9534818076923077], 
             UndirectedEdge[209, 334] -> 
             RGBColor[
              0.9265019230769231, 0.9435581538461539, 0.969506423076923], 
             UndirectedEdge[295, 310] -> 
             RGBColor[
              0.9454568076923076, 0.8878457692307691, 0.6243023076923077], 
             UndirectedEdge[109, 205] -> 
             RGBColor[
              0.9769209999999999, 0.9322280769230769, 0.49946492307692325`], 
             UndirectedEdge[194, 376] -> 
             RGBColor[
              0.9379005769230768, 0.7766133846153846, 0.49720807692307695`], 
             UndirectedEdge[142, 338] -> 
             RGBColor[
              0.9274514999999999, 0.8485676923076921, 0.6269449615384615], 
             UndirectedEdge[232, 386] -> 
             RGBColor[
              0.9830209999999999, 0.9860073076923077, 0.8755442307692307], 
             UndirectedEdge[169, 378] -> 
             RGBColor[
              0.9415378076923075, 0.8072126153846153, 0.5596411538461539], 
             UndirectedEdge[94, 324] -> 
             RGBColor[
              0.8251178076923076, 0.860619923076923, 0.7889327692307692], 
             UndirectedEdge[196, 231] -> 
             RGBColor[
              0.9640748076923076, 0.9541792307692306, 0.6782424230769228], 
             UndirectedEdge[207, 366] -> 
             RGBColor[
              0.9444589615384615, 0.8358611538461539, 0.5862364615384615], 
             UndirectedEdge[156, 310] -> 
             RGBColor[
              0.9698062307692308, 0.9755848461538461, 0.8725260769230769], 
             UndirectedEdge[206, 369] -> 
             RGBColor[
              0.9869913461538461, 0.9698530769230769, 0.5759824230769228], 
             UndirectedEdge[119, 225] -> 
             RGBColor[
              0.9921893461538461, 0.9908536923076923, 0.7657011923076924], 
             UndirectedEdge[69, 100] -> 
             RGBColor[
              0.9937856153846154, 0.9891163846153845, 0.5649807692307693], 
             UndirectedEdge[64, 182] -> 
             RGBColor[
              0.7511891538461539, 0.8044676153846154, 0.9532517307692308], 
             UndirectedEdge[217, 268] -> 
             RGBColor[
              0.9769209999999999, 0.9322280769230769, 0.49946492307692325`], 
             UndirectedEdge[235, 275] -> 
             RGBColor[
              0.9587078076923077, 0.8712577692307693, 0.5439133846153845], 
             UndirectedEdge[5, 99] -> 
             RGBColor[0.9596504230769229, 0.9654202307692307, 0.709128], 
             UndirectedEdge[52, 267] -> 
             RGBColor[
              0.9321691538461538, 0.755207769230769, 0.3029244230769229], 
             UndirectedEdge[290, 346] -> 
             RGBColor[
              0.709359076923077, 0.7722076923076924, 0.9721228461538461], 
             UndirectedEdge[19, 108] -> 
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153], 
             UndirectedEdge[92, 327] -> 
             RGBColor[
              0.9563479999999999, 0.9664519999999999, 0.9381238076923077], 
             UndirectedEdge[151, 244] -> 
             RGBColor[
              0.9033147307692307, 0.5619873076923076, 0.495517423076923], 
             UndirectedEdge[114, 327] -> 
             RGBColor[
              0.9580541538461538, 0.9671575384615384, 0.909848423076923], 
             UndirectedEdge[99, 174] -> 
             RGBColor[0.9089955384615384, 0.9302723846153845, 0.991182], 
             UndirectedEdge[180, 282] -> 
             RGBColor[
              0.9241556923076923, 0.9394729230769231, 0.8781770384615384], 
             UndirectedEdge[199, 277] -> 
             RGBColor[
              0.9813148461538461, 0.9853017692307693, 0.9038196153846154], 
             UndirectedEdge[237, 286] -> 
             RGBColor[
              0.9418481153846154, 0.9512251538461538, 0.7074299999999999], 
             UndirectedEdge[290, 313] -> 
             RGBColor[
              0.7271613846153846, 0.7864027692307692, 0.9738208461538461], 
             UndirectedEdge[56, 237] -> 
             RGBColor[
              0.9362265769230769, 0.9322623846153845, 0.6855913846153845], 
             UndirectedEdge[203, 361] -> 
             RGBColor[
              0.9784394230769231, 0.9814493846153847, 0.8270571923076925], 
             UndirectedEdge[169, 315] -> 
             RGBColor[
              0.9220335769230769, 0.792949846153846, 0.6053503846153846], 
             UndirectedEdge[23, 304] -> 
             RGBColor[
              0.9070985769230769, 0.9246639230769231, 0.7971038461538461], 
             UndirectedEdge[129, 270] -> 
             RGBColor[
              0.9723359615384615, 0.9305164615384616, 0.5888559615384615], 
             UndirectedEdge[85, 284] -> 
             RGBColor[0.9604139615384615, 0.8719633076923077, 0.515638], 
             UndirectedEdge[203, 369] -> 
             RGBColor[
              0.9715352692307693, 0.9597432307692306, 0.6656138076923075], 
             UndirectedEdge[1, 222] -> 
             RGBColor[
              0.8797716538461539, 0.903315923076923, 0.7943801538461538], 
             UndirectedEdge[25, 205] -> 
             RGBColor[
              0.9769209999999999, 0.9322280769230769, 0.49946492307692325`], 
             UndirectedEdge[301, 380] -> 
             RGBColor[
              0.9265476153846153, 0.7362449999999999, 0.28108580769230757`], 
             UndirectedEdge[169, 329] -> 
             RGBColor[
              0.9461228461538461, 0.8089242307692307, 0.4702501153846156], 
             UndirectedEdge[302, 340] -> 
             RGBColor[0.8908973076923077, 0.915168, 0.9661104230769231], 
             UndirectedEdge[205, 391] -> 
             RGBColor[
              0.9700168461538461, 0.9105219230769229, 0.33802153846153826`], 
             UndirectedEdge[96, 203] -> 
             RGBColor[
              0.9659137307692307, 0.9407804615384615, 0.6437751923076922], 
             UndirectedEdge[4, 195] -> 
             RGBColor[
              0.9681000769230769, 0.9748793076923077, 0.9008014615384614], 
             UndirectedEdge[269, 298] -> 
             RGBColor[
              0.7409062692307693, 0.6235432307692308, 0.5928518846153846], 
             UndirectedEdge[168, 220] -> 
             RGBColor[
              0.7914101538461538, 0.8378382307692307, 0.9796149230769231], 
             UndirectedEdge[291, 338] -> 
             RGBColor[
              0.8985422307692308, 0.6253076923076923, 0.2366976923076923], 
             UndirectedEdge[10, 360] -> 
             RGBColor[
              0.8273501153846152, 0.794842769230769, 0.6228078846153846], 
             UndirectedEdge[87, 348] -> 
             RGBColor[
              0.9869913461538461, 0.9698530769230769, 0.5759824230769228], 
             UndirectedEdge[259, 274] -> 
             RGBColor[
              0.9513988461538461, 0.8441884615384614, 0.28408142307692297`], 
             UndirectedEdge[293, 336] -> 
             RGBColor[
              0.9390733076923077, 0.7769139230769231, 0.4643678076923079], 
             UndirectedEdge[229, 245] -> 
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461], 
             UndirectedEdge[173, 197] -> 
             RGBColor[
              0.9513988461538461, 0.8441884615384614, 0.28408142307692297`], 
             UndirectedEdge[19, 344] -> 
             RGBColor[
              0.9858998846153846, 0.9870133846153846, 0.8144285769230771], 
             UndirectedEdge[83, 125] -> 
             RGBColor[
              0.8186411923076922, 0.8398282307692306, 0.6740243076923075], 
             UndirectedEdge[240, 315] -> 
             RGBColor[
              0.9368437692307692, 0.9521892307692307, 0.9838330384615385], 
             UndirectedEdge[7, 154] -> 
             RGBColor[
              0.9738543846153846, 0.9797377692307693, 0.9164482307692308], 
             UndirectedEdge[200, 225] -> 
             RGBColor[
              0.940251846153846, 0.9529624615384615, 0.9081504230769231], 
             UndirectedEdge[13, 140] -> 
             RGBColor[0.8542561153846153, 0.5251021538461538, 0.576851], 
             UndirectedEdge[104, 366] -> 
             RGBColor[
              0.8387582692307692, 0.7530781538461538, 0.6127229615384615], 
             UndirectedEdge[116, 172] -> 
             RGBColor[
              0.7552922692307692, 0.7742090769230768, 0.6474980769230768], 
             UndirectedEdge[143, 267] -> 
             RGBColor[0.9224445, 0.7665035384615385, 0.5868394615384614], 
             UndirectedEdge[51, 395] -> 
             RGBColor[
              0.9386457692307693, 0.7759994615384616, 0.4178328846153846], 
             UndirectedEdge[213, 224] -> 
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461], 
             UndirectedEdge[130, 362] -> 
             RGBColor[
              0.9764934615384615, 0.9313136153846153, 0.45292999999999994`], 
             UndirectedEdge[153, 278] -> 
             RGBColor[
              0.9253284230769231, 0.9397734615384615, 0.8453367692307694], 
             UndirectedEdge[83, 303] -> 
             RGBColor[
              0.8014560769230769, 0.8455599999999999, 0.9705679615384615], 
             UndirectedEdge[94, 296] -> 
             RGBColor[
              0.6273783076923076, 0.7081636923076923, 0.9639517692307692], 
             UndirectedEdge[147, 328] -> 
             RGBColor[
              0.8820039615384615, 0.837538769230769, 0.6282552692307692], 
             UndirectedEdge[78, 102] -> 
             RGBColor[
              0.5861425384615385, 0.6467979615384616, 0.7259734230769231], 
             UndirectedEdge[22, 45] -> 
             RGBColor[
              0.9910166153846154, 0.9905531538461538, 0.7985414615384614], 
             UndirectedEdge[199, 238] -> 
             RGBColor[
              0.9847271538461537, 0.9867128461538461, 0.8472688461538461], 
             UndirectedEdge[21, 182] -> 
             RGBColor[
              0.7511891538461539, 0.8044676153846154, 0.9532517307692308], 
             UndirectedEdge[126, 212] -> 
             RGBColor[
              0.9877365384615384, 0.9692391538461538, 0.4966072307692305], 
             UndirectedEdge[273, 365] -> 
             RGBColor[
              0.9926128846153845, 0.9888158461538461, 0.5978210384615383], 
             UndirectedEdge[149, 367] -> 
             RGBColor[
              0.9448402307692307, 0.806180846153846, 0.33064534615384605`], 
             UndirectedEdge[81, 89] -> 
             RGBColor[0.987309, 0.9683246923076922, 0.45007230769230755`], 
             UndirectedEdge[57, 337] -> 
             RGBColor[
              0.9738543846153846, 0.9797377692307693, 0.9164482307692308], 
             UndirectedEdge[255, 288] -> 
             RGBColor[
              0.940251846153846, 0.9529624615384615, 0.9081504230769231], 
             UndirectedEdge[2, 283] -> 
             RGBColor[
              0.9543501538461538, 0.9654750000000001, 0.9621574615384615], 
             UndirectedEdge[94, 128] -> 
             RGBColor[
              0.8014560769230769, 0.8455599999999999, 0.9705679615384615], 
             UndirectedEdge[176, 393] -> 
             RGBColor[
              0.993358076923077, 0.988201923076923, 0.518445846153846], 
             UndirectedEdge[65, 326] -> 
             RGBColor[
              0.9854723461538462, 0.986098923076923, 0.7678936538461538], 
             UndirectedEdge[97, 282] -> 
             RGBColor[
              0.9184242692307691, 0.9180673076923076, 0.6838933846153844], 
             UndirectedEdge[12, 149] -> 
             RGBColor[
              0.9452677692307692, 0.8070953076923076, 0.37718026923076925`], 
             UndirectedEdge[78, 144] -> 
             RGBColor[
              0.9929305384615386, 0.9872874615384615, 0.47191092307692306`], 
             UndirectedEdge[201, 348] -> 
             RGBColor[
              0.8790264615384615, 0.9039298461538461, 0.8737553461538461], 
             UndirectedEdge[242, 381] -> 
             RGBColor[
              0.981259923076923, 0.9484474615384613, 0.38169876923076884`], 
             UndirectedEdge[43, 367] -> 
             RGBColor[0.9062435, 0.922835, 0.7040339999999999], 
             UndirectedEdge[111, 197] -> 
             RGBColor[
              0.962641923076923, 0.8821139999999996, 0.3277586538461536], 
             UndirectedEdge[69, 216] -> 
             RGBColor[
              0.9695460769230768, 0.9038201538461537, 0.48920203846153865`], 
             UndirectedEdge[197, 295] -> 
             RGBColor[
              0.944023923076923, 0.8157805384615381, 0.27381853846153836`], 
             UndirectedEdge[193, 275] -> 
             RGBColor[0.9055917692307691, 0.657318, 0.24258], 
             UndirectedEdge[149, 238] -> 
             RGBColor[
              0.9449501153846154, 0.8086236923076923, 0.5030903846153846], 
             UndirectedEdge[79, 349] -> 
             RGBColor[
              0.9921893461538461, 0.9908536923076923, 0.7657011923076924], 
             UndirectedEdge[16, 110] -> 
             RGBColor[
              0.8635703846153846, 0.8938200000000001, 0.9633867307692308], 
             UndirectedEdge[49, 372] -> 
             RGBColor[
              0.9354108846153845, 0.8801239999999997, 0.6333492692307692], 
             UndirectedEdge[320, 343] -> 
             RGBColor[
              0.7898278076923076, 0.6359262307692308, 0.5920913461538462], 
             UndirectedEdge[221, 358] -> 
             RGBColor[
              0.8572482307692307, 0.3800578461538461, 0.20006634615384614`], 
             UndirectedEdge[240, 245] -> 
             RGBColor[
              0.9368437692307692, 0.9521892307692307, 0.9838330384615385], 
             UndirectedEdge[85, 115] -> 
             RGBColor[
              0.9241556923076923, 0.9394729230769231, 0.8781770384615384], 
             UndirectedEdge[70, 280] -> 
             RGBColor[
              0.9049381153846152, 0.7532177692307691, 0.6085150384615384], 
             UndirectedEdge[151, 171] -> 
             RGBColor[
              0.9909067307692307, 0.9881103076923077, 0.6260964230769229], 
             UndirectedEdge[23, 163] -> 
             RGBColor[
              0.9456953076923076, 0.8080097692307692, 0.4237151923076922], 
             UndirectedEdge[255, 360] -> 
             RGBColor[
              0.9176085769230768, 0.8659289230769229, 0.6316512692307692], 
             UndirectedEdge[165, 307] -> 
             RGBColor[
              0.8187370769230768, 0.8591862307692306, 0.9823386153846154], 
             UndirectedEdge[81, 169] -> 
             RGBColor[
              0.9452677692307692, 0.8070953076923076, 0.37718026923076925`], 
             UndirectedEdge[44, 316] -> 
             RGBColor[
              0.9065016153846153, 0.6568639999999999, 0.24310199999999996`], 
             UndirectedEdge[195, 337] -> 
             RGBColor[
              0.966393923076923, 0.9741737692307693, 0.9290768461538462], 
             UndirectedEdge[316, 390] -> 
             RGBColor[
              0.9682634615384615, 0.9010767692307691, 0.34959726923076906`], 
             UndirectedEdge[39, 177] -> 
             RGBColor[
              0.9046472307692308, 0.9245723076923077, 0.904754423076923], 
             UndirectedEdge[45, 190] -> 
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079], 
             UndirectedEdge[287, 396] -> 
             RGBColor[
              0.9184242692307691, 0.9180673076923076, 0.6838933846153844], 
             UndirectedEdge[136, 343] -> 
             RGBColor[
              0.9065016153846153, 0.6568639999999999, 0.24310199999999996`], 
             UndirectedEdge[296, 360] -> 
             RGBColor[
              0.7713790384615384, 0.7504494615384614, 0.6176861153846154], 
             UndirectedEdge[167, 228] -> 
             RGBColor[
              0.8561099230769231, 0.8882559999999999, 0.9760153461538461], 
             UndirectedEdge[123, 279] -> 
             RGBColor[
              0.9780118846153847, 0.9805349230769231, 0.7805222692307692], 
             UndirectedEdge[33, 333] -> 
             RGBColor[
              0.9596504230769229, 0.9654202307692307, 0.7091279999999999], 
             UndirectedEdge[164, 209] -> 
             RGBColor[
              0.9422756538461539, 0.9521396153846153, 0.7539649230769232], 
             UndirectedEdge[22, 29] -> 
             RGBColor[
              0.9224495384615384, 0.9387673846153846, 0.906452423076923], 
             UndirectedEdge[24, 366] -> 
             RGBColor[
              0.9490422692307692, 0.8389959230769231, 0.5657844615384616], 
             UndirectedEdge[178, 319] -> 
             RGBColor[
              0.9900556538461538, 0.9892336923076923, 0.7474416538461539], 
             UndirectedEdge[294, 368] -> 
             RGBColor[
              0.9715352692307693, 0.9597432307692306, 0.6656138076923075], 
             UndirectedEdge[13, 69] -> 
             RGBColor[
              0.9431307307692307, 0.9539685384615384, 0.8470347692307695], 
             UndirectedEdge[214, 295] -> 
             RGBColor[
              0.9360645384615384, 0.7842242307692305, 0.2674142307692307], 
             UndirectedEdge[80, 146] -> 
             RGBColor[
              0.9207433846153845, 0.9380618461538461, 0.9347278076923078], 
             UndirectedEdge[56, 231] -> 
             RGBColor[
              0.9640748076923076, 0.9541792307692306, 0.6782424230769228], 
             UndirectedEdge[134, 351] -> 
             RGBColor[
              0.9006219615384615, 0.9038722307692306, 0.6821953846153844], 
             UndirectedEdge[143, 291] -> 
             RGBColor[
              0.9153949615384616, 0.7344932307692309, 0.5809571538461538], 
             UndirectedEdge[120, 320] -> 
             RGBColor[
              0.8524447307692307, 0.8819679230769231, 0.7916564615384615], 
             UndirectedEdge[132, 220] -> 
             RGBColor[
              0.9597603076923076, 0.9678630769230769, 0.8815730384615384], 
             UndirectedEdge[6, 247] -> 
             RGBColor[
              0.8555886153846154, 0.8876871538461538, 0.9860880000000001], 
             UndirectedEdge[166, 289] -> 
             RGBColor[
              0.9692710769230769, 0.9766030000000001, 0.9369002307692307], 
             UndirectedEdge[114, 392] -> 
             RGBColor[
              0.9910166153846154, 0.9905531538461538, 0.7985414615384614], 
             UndirectedEdge[305, 325] -> 
             RGBColor[
              0.8773203076923077, 0.9032243076923077, 0.9020307307692307], 
             UndirectedEdge[44, 128] -> 
             RGBColor[0.9079345, 0.7289292307692308, 0.5935857692307693], 
             UndirectedEdge[90, 242] -> 
             RGBColor[
              0.9715352692307693, 0.9597432307692306, 0.6656138076923075], 
             UndirectedEdge[1, 337] -> 
             RGBColor[
              0.9900556538461538, 0.9892336923076923, 0.7474416538461539], 
             UndirectedEdge[74, 224] -> 
             RGBColor[0.597801423076923, 0.6647725, 0.9300236923076923], 
             UndirectedEdge[160, 370] -> 
             RGBColor[
              0.8444816538461539, 0.6786222307692309, 0.5975387307692308], 
             UndirectedEdge[30, 84] -> 
             RGBColor[
              0.9240458076923077, 0.9370300769230768, 0.7057319999999998], 
             UndirectedEdge[293, 299] -> 
             RGBColor[
              0.7968773461538461, 0.6679365384615384, 0.5979736538461538], 
             UndirectedEdge[186, 399] -> 
             RGBColor[
              0.9528317307692307, 0.9162536923076923, 0.6345651923076923], 
             UndirectedEdge[163, 371] -> 
             RGBColor[
              0.9432439615384615, 0.8079181538461537, 0.5313657692307692], 
             UndirectedEdge[90, 138] -> 
             RGBColor[
              0.9738543846153846, 0.9797377692307693, 0.9164482307692308], 
             UndirectedEdge[71, 286] -> 
             RGBColor[
              0.9771568076923077, 0.9787060000000001, 0.6874524230769229], 
             UndirectedEdge[60, 201] -> 
             RGBColor[
              0.8635703846153846, 0.8938200000000001, 0.9633867307692308], 
             UndirectedEdge[128, 380] -> 
             RGBColor[
              0.9149840384615384, 0.7609395384615385, 0.5994680769230769], 
             UndirectedEdge[54, 128] -> 
             RGBColor[
              0.966393923076923, 0.9741737692307693, 0.9290768461538462], 
             UndirectedEdge[25, 138] -> 
             RGBColor[
              0.9904831923076922, 0.9901481538461538, 0.7939765769230772], 
             UndirectedEdge[95, 129] -> 
             RGBColor[
              0.9738543846153846, 0.9797377692307693, 0.9164482307692308], 
             UndirectedEdge[132, 302] -> 
             RGBColor[
              0.9063533846153846, 0.9252778461538462, 0.8764790384615384], 
             UndirectedEdge[15, 100] -> 
             RGBColor[
              0.9682634615384615, 0.9010767692307691, 0.34959726923076906`], 
             UndirectedEdge[33, 63] -> 
             RGBColor[
              0.9580541538461538, 0.9671575384615384, 0.909848423076923], 
             UndirectedEdge[275, 338] -> 
             RGBColor[
              0.9281051538461538, 0.752667923076923, 0.26100992307692306`], 
             UndirectedEdge[252, 277] -> 
             RGBColor[
              0.9274387307692307, 0.7431920000000001, 0.5478765384615385], 
             UndirectedEdge[146, 192] -> 
             RGBColor[
              0.8838874999999999, 0.7886212307692309, 0.6171446538461538], 
             UndirectedEdge[237, 254] -> 
             RGBColor[0.873390923076923, 0.9018822307692307, 0.987786], 
             UndirectedEdge[37, 236] -> 
             RGBColor[
              0.9881640769230768, 0.9701536153846153, 0.5431421538461538], 
             UndirectedEdge[265, 362] -> 
             RGBColor[
              0.970551423076923, 0.974970923076923, 0.7931508846153845], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.9900556538461538, 0.9892336923076923, 0.7474416538461539], 
             UndirectedEdge[341, 379] -> 
             RGBColor[
              0.9868814615384616, 0.9674102307692306, 0.40353738461538435`], 
             UndirectedEdge[324, 380] -> 
             RGBColor[
              0.9386457692307693, 0.7759994615384616, 0.4178328846153846], 
             UndirectedEdge[63, 264] -> 
             RGBColor[
              0.940251846153846, 0.9529624615384615, 0.9081504230769231], 
             UndirectedEdge[153, 337] -> 
             RGBColor[
              0.9904831923076922, 0.9901481538461538, 0.7939765769230772], 
             UndirectedEdge[112, 155] -> 
             RGBColor[
              0.9921893461538461, 0.9908536923076923, 0.7657011923076924], 
             UndirectedEdge[10, 177] -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             UndirectedEdge[238, 367] -> 
             RGBColor[
              0.9926128846153845, 0.9888158461538461, 0.5978210384615383], 
             UndirectedEdge[87, 228] -> 
             RGBColor[
              0.8732950384615384, 0.8825242307692306, 0.6794716923076921], 
             UndirectedEdge[66, 352] -> 
             RGBColor[0.843703923076923, 0.878036, 0.9480344230769231], 
             UndirectedEdge[86, 386] -> 
             RGBColor[
              0.9681000769230769, 0.9748793076923077, 0.9008014615384614], 
             UndirectedEdge[52, 133] -> 
             RGBColor[
              0.9881640769230768, 0.9701536153846153, 0.5431421538461538], 
             UndirectedEdge[105, 112] -> 
             RGBColor[
              0.9224495384615384, 0.9387673846153846, 0.906452423076923], 
             UndirectedEdge[4, 258] -> 
             RGBColor[
              0.9910166153846154, 0.9905531538461538, 0.7985414615384614], 
             UndirectedEdge[141, 339] -> 
             RGBColor[
              0.9385456923076922, 0.9522569230769231, 0.9364258076923078], 
             UndirectedEdge[251, 282] -> 
             RGBColor[
              0.9207433846153845, 0.9380618461538461, 0.9347278076923078], 
             UndirectedEdge[94, 390] -> 
             RGBColor[
              0.8242627307692307, 0.8587909999999999, 0.695862923076923], 
             UndirectedEdge[239, 337] -> 
             RGBColor[
              0.9738543846153846, 0.9797377692307693, 0.9164482307692308], 
             UndirectedEdge[80, 243] -> 
             RGBColor[
              0.9896281153846154, 0.9883192307692308, 0.7009067307692309], 
             UndirectedEdge[366, 382] -> 
             RGBColor[
              0.9411016153846153, 0.8000386153846153, 0.29311142307692295`], 
             UndirectedEdge[99, 306] -> 
             RGBColor[
              0.9517646923076921, 0.9633172307692307, 0.9585758076923077], 
             UndirectedEdge[214, 261] -> 
             RGBColor[0.9604139615384615, 0.8719633076923077, 0.515638], 
             UndirectedEdge[21, 60] -> 
             RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 
             UndirectedEdge[60, 159] -> 
             RGBColor[
              0.9784394230769231, 0.9814493846153847, 0.8270571923076925], 
             UndirectedEdge[9, 300] -> 
             RGBColor[
              0.9580541538461538, 0.9671575384615384, 0.909848423076923], 
             UndirectedEdge[114, 369] -> 
             RGBColor[
              0.9852851923076922, 0.9691475384615383, 0.6042578076923074], 
             UndirectedEdge[112, 350] -> 
             RGBColor[
              0.7101933076923077, 0.7688229230769231, 0.8877528076923076], 
             UndirectedEdge[18, 357] -> 
             RGBColor[
              0.9029410769230769, 0.9238667692307692, 0.9330298076923078], 
             UndirectedEdge[71, 320] -> 
             RGBColor[0.8362434615384615, 0.872472, 0.9606630384615384], 
             UndirectedEdge[226, 255] -> 
             RGBColor[
              0.894185346153846, 0.7710329999999999, 0.6126993461538461], 
             UndirectedEdge[208, 258] -> 
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079], 
             UndirectedEdge[11, 358] -> 
             RGBColor[
              0.9452677692307692, 0.8070953076923076, 0.37718026923076925`], 
             UndirectedEdge[274, 299] -> 
             RGBColor[
              0.8273501153846152, 0.794842769230769, 0.6228078846153846], 
             UndirectedEdge[147, 372] -> 
             RGBColor[
              0.8820039615384615, 0.837538769230769, 0.6282552692307692], 
             UndirectedEdge[335, 337] -> 
             RGBColor[
              0.9904831923076922, 0.9901481538461538, 0.7939765769230772], 
             UndirectedEdge[36, 218] -> 
             RGBColor[
              0.8936679230769231, 0.5223244615384615, 0.2511197692307691], 
             UndirectedEdge[262, 300] -> 
             RGBColor[
              0.9755605384615385, 0.9804433076923078, 0.8881728461538461], 
             UndirectedEdge[109, 136] -> 
             RGBColor[
              0.9695460769230768, 0.9038201538461537, 0.48920203846153865`], 
             UndirectedEdge[219, 241] -> 
             RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076922], 
             UndirectedEdge[37, 348] -> 
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079], 
             UndirectedEdge[291, 384] -> 
             RGBColor[
              0.8444816538461539, 0.6786222307692309, 0.5975387307692308], 
             UndirectedEdge[10, 241] -> 
             RGBColor[
              0.8524447307692307, 0.8819679230769231, 0.7916564615384615], 
             UndirectedEdge[131, 314] -> 
             RGBColor[
              0.9602921923076924, 0.9218176923076924, 0.6219365769230769], 
             UndirectedEdge[1, 41] -> 
             RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076922], 
             UndirectedEdge[78, 400] -> 
             RGBColor[
              0.993358076923077, 0.9882019230769231, 0.5184458461538463], 
             UndirectedEdge[191, 357] -> 
             RGBColor[0.8186515000000001, 0.496712, 0.573455], 
             UndirectedEdge[215, 352] -> 
             RGBColor[0.8983577692307692, 0.920732, 0.9534818076923077], 
             UndirectedEdge[96, 369] -> 
             RGBColor[
              0.9756383846153845, 0.929484692307692, 0.35986015384615355`], 
             UndirectedEdge[212, 293] -> 
             RGBColor[
              0.9321691538461538, 0.755207769230769, 0.3029244230769229], 
             UndirectedEdge[66, 107] -> 
             RGBColor[0.8362434615384615, 0.872472, 0.9606630384615384], 
             UndirectedEdge[146, 159] -> 
             RGBColor[
              0.9253284230769231, 0.9397734615384615, 0.8453367692307694], 
             UndirectedEdge[11, 207] -> 
             RGBColor[
              0.9850448076923077, 0.9851844615384615, 0.7213587307692308], 
             UndirectedEdge[99, 218] -> 
             RGBColor[0.872058423076923, 0.5392972307692308, 0.578549], 
             UndirectedEdge[131, 217] -> 
             RGBColor[
              0.9769209999999999, 0.9322280769230769, 0.49946492307692325`], 
             UndirectedEdge[81, 163] -> 
             RGBColor[
              0.9452677692307692, 0.8070953076923076, 0.37718026923076925`], 
             UndirectedEdge[50, 54] -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.8268168461538462], 
             UndirectedEdge[120, 286] -> 
             RGBColor[
              0.993358076923077, 0.988201923076923, 0.518445846153846], 
             UndirectedEdge[17, 253] -> 
             RGBColor[
              0.9854723461538462, 0.986098923076923, 0.7678936538461538], 
             UndirectedEdge[45, 365] -> 
             RGBColor[
              0.9926128846153845, 0.9888158461538461, 0.5978210384615383], 
             UndirectedEdge[35, 188] -> 
             RGBColor[
              0.9847271538461537, 0.9867128461538461, 0.8472688461538461], 
             UndirectedEdge[99, 279] -> 
             RGBColor[
              0.9605054999999999, 0.9672491538461538, 0.8021978461538462], 
             UndirectedEdge[107, 363] -> 
             RGBColor[
              0.8635703846153846, 0.8938200000000001, 0.9633867307692308], 
             UndirectedEdge[105, 271] -> 
             RGBColor[
              0.9224495384615384, 0.9387673846153846, 0.906452423076923], 
             UndirectedEdge[191, 219] -> 
             RGBColor[
              0.9057660769230769, 0.5620789230769231, 0.38786684615384615`], 
             UndirectedEdge[177, 339] -> 
             RGBColor[
              0.8555886153846154, 0.8876871538461538, 0.9860880000000001], 
             UndirectedEdge[80, 167] -> 
             RGBColor[
              0.966393923076923, 0.9741737692307693, 0.9290768461538462], 
             UndirectedEdge[48, 56] -> 
             RGBColor[
              0.9881640769230768, 0.9701536153846153, 0.5431421538461538], 
             UndirectedEdge[42, 136] -> 
             RGBColor[
              0.9529172692307692, 0.8934097692307691, 0.6116736923076922], 
             UndirectedEdge[77, 102] -> 
             RGBColor[0.585715, 0.6458834999999999, 0.6794384999999998], 
             UndirectedEdge[73, 203] -> 
             RGBColor[
              0.9784394230769231, 0.9814493846153847, 0.8270571923076925], 
             UndirectedEdge[35, 284] -> 
             RGBColor[
              0.952418346153846, 0.8674174615384616, 0.5926407692307691], 
             UndirectedEdge[274, 367] -> 
             RGBColor[
              0.9682634615384615, 0.9010767692307691, 0.34959726923076906`], 
             UndirectedEdge[33, 310] -> 
             RGBColor[
              0.9368437692307692, 0.9521892307692307, 0.9838330384615385], 
             UndirectedEdge[175, 295] -> 
             RGBColor[
              0.9649610384615384, 0.9021085384615383, 0.5785930769230769], 
             UndirectedEdge[70, 75] -> 
             RGBColor[
              0.9609330384615384, 0.9681636153846154, 0.8487327692307695], 
             UndirectedEdge[57, 258] -> 
             RGBColor[
              0.9772666923076923, 0.9811488461538462, 0.8598974615384615], 
             UndirectedEdge[70, 145] -> 
             RGBColor[
              0.9049381153846152, 0.7532177692307691, 0.6085150384615384], 
             UndirectedEdge[12, 336] -> 
             RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076925], 
             UndirectedEdge[18, 216] -> 
             RGBColor[
              0.9649610384615384, 0.9021085384615383, 0.5785930769230769], 
             UndirectedEdge[158, 311] -> 
             RGBColor[
              0.9369985000000001, 0.8302971538461539, 0.5988650769230769], 
             UndirectedEdge[8, 36] -> 
             RGBColor[0.982115, 0.9502763846153846, 0.47476861538461523`], 
             UndirectedEdge[119, 200] -> 
             RGBColor[
              0.9431307307692307, 0.9539685384615384, 0.8470347692307695], 
             UndirectedEdge[181, 362] -> 
             RGBColor[
              0.9605054999999999, 0.9672491538461538, 0.8021978461538462], 
             UndirectedEdge[9, 306] -> 
             RGBColor[
              0.9517646923076921, 0.9633172307692307, 0.9585758076923077], 
             UndirectedEdge[82, 253] -> 
             RGBColor[0.9846172692307692, 0.98427, 0.6748238076923075], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.9929305384615386, 0.9872874615384615, 0.47191092307692306`], 
             UndirectedEdge[146, 314] -> 
             RGBColor[
              0.9086996153846154, 0.929363076923077, 0.967808423076923], 
             UndirectedEdge[27, 277] -> 
             RGBColor[
              0.9274387307692307, 0.7431920000000001, 0.5478765384615385], 
             UndirectedEdge[6, 302] -> RGBColor[0.819984, 0.859297, 0.982692],
              UndirectedEdge[93, 296] -> 
             RGBColor[
              0.7969011923076923, 0.838489076923077, 0.8330696153846155], 
             UndirectedEdge[153, 284] -> 
             RGBColor[
              0.9615866923076923, 0.8722638461538461, 0.482797730769231], 
             UndirectedEdge[43, 199] -> 
             RGBColor[0.8983577692307692, 0.920732, 0.9534818076923077], 
             UndirectedEdge[213, 250] -> 
             RGBColor[
              0.9681000769230769, 0.9748793076923077, 0.9008014615384614], 
             UndirectedEdge[3, 232] -> 
             RGBColor[
              0.9444589615384615, 0.8358611538461539, 0.5862364615384615], 
             UndirectedEdge[5, 235] -> 
             RGBColor[
              0.9909067307692307, 0.9881103076923077, 0.6260964230769229], 
             UndirectedEdge[25, 391] -> 
             RGBColor[
              0.9881640769230768, 0.9701536153846153, 0.5431421538461538], 
             UndirectedEdge[288, 341] -> 
             RGBColor[
              0.9909067307692307, 0.9881103076923077, 0.6260964230769229], 
             UndirectedEdge[181, 265] -> 
             RGBColor[
              0.9368437692307692, 0.9521892307692307, 0.9838330384615385], 
             UndirectedEdge[295, 363] -> 
             RGBColor[
              0.8546770384615384, 0.816190769230769, 0.6255315769230769], 
             UndirectedEdge[278, 284] -> 
             RGBColor[
              0.8918468846153846, 0.8201775384615384, 0.6235489615384615], 
             UndirectedEdge[167, 351] -> 
             RGBColor[0.8834368461538462, 0.909604, 0.9787390384615384], 
             UndirectedEdge[198, 311] -> 
             RGBColor[
              0.8773945384615385, 0.5090119230769231, 0.21831550000000002`], 
             UndirectedEdge[54, 328] -> 
             RGBColor[
              0.9649610384615384, 0.9021085384615383, 0.5785930769230769], 
             UndirectedEdge[261, 310] -> 
             RGBColor[
              0.9698062307692308, 0.9755848461538461, 0.8725260769230769], 
             UndirectedEdge[68, 319] -> 
             RGBColor[
              0.7673904230769231, 0.8139635384615385, 0.7842451538461538], 
             UndirectedEdge[100, 141] -> 
             RGBColor[
              0.989200576923077, 0.9874047692307693, 0.6543718076923076], 
             UndirectedEdge[139, 325] -> 
             RGBColor[
              0.940251846153846, 0.9529624615384615, 0.9081504230769231], 
             UndirectedEdge[123, 338] -> 
             RGBColor[
              0.9449578846153845, 0.8618534615384615, 0.6052693846153845], 
             UndirectedEdge[317, 370] -> 
             RGBColor[
              0.8660851923076923, 0.7744261538461539, 0.6154466538461538], 
             UndirectedEdge[160, 400] -> 
             RGBColor[
              0.9311686923076923, 0.7430746923076924, 0.36541565384615393`], 
             UndirectedEdge[150, 266] -> 
             RGBColor[
              0.9779574999999999, 0.9494792307692307, 0.6106945769230768], 
             UndirectedEdge[134, 201] -> 
             RGBColor[
              0.8732950384615384, 0.8825242307692306, 0.6794716923076921], 
             UndirectedEdge[161, 251] -> 
             RGBColor[
              0.9896281153846154, 0.9883192307692308, 0.7009067307692309], 
             UndirectedEdge[86, 371] -> 
             RGBColor[
              0.9681000769230769, 0.9748793076923077, 0.9008014615384614], 
             UndirectedEdge[105, 350] -> 
             RGBColor[
              0.6433323846153847, 0.7177426923076924, 0.9673883846153846], 
             UndirectedEdge[54, 362] -> 
             RGBColor[
              0.9900556538461538, 0.9892336923076923, 0.7474416538461539], 
             UndirectedEdge[4, 208] -> 
             RGBColor[
              0.9921893461538461, 0.9908536923076923, 0.7657011923076924], 
             UndirectedEdge[176, 294] -> 
             RGBColor[
              0.9780118846153847, 0.9805349230769231, 0.7805222692307692], 
             UndirectedEdge[113, 170] -> 
             RGBColor[
              0.8806714615384614, 0.47495376923076904`, 0.21901826923076917`],
              UndirectedEdge[14, 205] -> 
             RGBColor[
              0.8620519615384615, 0.8445986923076922, 0.6357944615384615], 
             UndirectedEdge[262, 306] -> 
             RGBColor[
              0.9692710769230769, 0.9766030000000001, 0.9369002307692307], 
             UndirectedEdge[47, 128] -> 
             RGBColor[
              0.970551423076923, 0.974970923076923, 0.7931508846153845], 
             UndirectedEdge[257, 382] -> 
             RGBColor[
              0.9796636538461538, 0.9501847692307692, 0.5824191923076921], 
             UndirectedEdge[165, 228] -> 
             RGBColor[
              0.8460639999999999, 0.8805342307692307, 0.9850623076923077], 
             UndirectedEdge[72, 341] -> 
             RGBColor[
              0.9868814615384616, 0.9674102307692306, 0.40353738461538435`], 
             UndirectedEdge[50, 116] -> 
             RGBColor[
              0.7666452307692307, 0.8145774615384616, 0.8636203461538461], 
             UndirectedEdge[230, 247] -> 
             RGBColor[
              0.9339623846153846, 0.9491221538461538, 0.9568778076923077], 
             UndirectedEdge[45, 100] -> 
             RGBColor[
              0.9926128846153845, 0.9888158461538461, 0.5978210384615383], 
             UndirectedEdge[95, 386] -> 
             RGBColor[
              0.9755605384615385, 0.9804433076923078, 0.8881728461538461], 
             UndirectedEdge[182, 244] -> 
             RGBColor[
              0.6789433461538461, 0.38601161538461537`, 0.5605963076923077], 
             UndirectedEdge[104, 382] -> 
             RGBColor[0.8676735, 0.8635614615384615, 0.6576330769230768], 
             UndirectedEdge[58, 210] -> 
             RGBColor[
              0.940251846153846, 0.9529624615384615, 0.9081504230769231], 
             UndirectedEdge[102, 370] -> 
             RGBColor[0.4994555, 0.5823455, 0.9580965], 
             UndirectedEdge[1, 161] -> 
             RGBColor[
              0.9937856153846154, 0.9891163846153846, 0.5649807692307692], 
             UndirectedEdge[153, 356] -> 
             RGBColor[
              0.9937856153846154, 0.9891163846153845, 0.5649807692307693], 
             UndirectedEdge[1, 154] -> 
             RGBColor[
              0.9780118846153847, 0.9805349230769231, 0.7805222692307692], 
             UndirectedEdge[341, 399] -> 
             RGBColor[0.9696963461538461, 0.973142, 0.7000810384615384], 
             UndirectedEdge[373, 395] -> 
             RGBColor[
              0.7968773461538461, 0.6679365384615384, 0.5979736538461539], 
             UndirectedEdge[190, 266] -> 
             RGBColor[
              0.9825425384615385, 0.9511908461538461, 0.5213035384615385], 
             UndirectedEdge[73, 85] -> 
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079], 
             UndirectedEdge[221, 250] -> 
             RGBColor[
              0.9033147307692307, 0.5619873076923076, 0.49551742307692304`], 
             UndirectedEdge[23, 353] -> 
             RGBColor[
              0.9780118846153847, 0.9805349230769231, 0.7805222692307692], 
             UndirectedEdge[171, 270] -> 
             RGBColor[
              0.9756383846153847, 0.9294846923076923, 0.3598601538461537], 
             UndirectedEdge[277, 396] -> 
             RGBColor[
              0.9835790384615384, 0.9684419999999998, 0.6325331923076922], 
             UndirectedEdge[315, 371] -> 
             RGBColor[
              0.9681000769230769, 0.9748793076923077, 0.9008014615384614], 
             UndirectedEdge[207, 391] -> 
             RGBColor[
              0.9789957307692307, 0.9653072307692306, 0.6529851923076921], 
             UndirectedEdge[160, 247] -> 
             RGBColor[
              0.8800862692307692, 0.7070123846153846, 0.6009347307692308], 
             UndirectedEdge[193, 232] -> 
             RGBColor[
              0.9299049615384615, 0.7720675384615385, 0.5742108461538462], 
             UndirectedEdge[22, 91] -> 
             RGBColor[
              0.9910166153846154, 0.9905531538461538, 0.7985414615384614], 
             UndirectedEdge[78, 247] -> 
             RGBColor[
              0.9422756538461539, 0.9521396153846153, 0.7539649230769232], 
             UndirectedEdge[87, 192] -> 
             RGBColor[
              0.9467231538461538, 0.8190013846153845, 0.3149500384615383], 
             UndirectedEdge[226, 294] -> 
             RGBColor[
              0.9294940384615384, 0.7985138461538461, 0.5927217692307691], 
             UndirectedEdge[177, 311] -> 
             RGBColor[
              0.8660851923076923, 0.7744261538461539, 0.6154466538461538], 
             UndirectedEdge[189, 200] -> 
             RGBColor[
              0.9385456923076922, 0.9522569230769231, 0.9364258076923078], 
             UndirectedEdge[67, 184] -> 
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998], 
             UndirectedEdge[33, 256] -> 
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484], 
             UndirectedEdge[176, 226] -> 
             RGBColor[
              0.9456953076923076, 0.8080097692307692, 0.4237151923076922], 
             UndirectedEdge[145, 162] -> 
             RGBColor[
              0.8501986923076923, 0.34804753846153846`, 0.19418403846153848`],
              UndirectedEdge[286, 343] -> 
             RGBColor[
              0.9307411538461539, 0.7421602307692308, 0.3188807307692307], 
             UndirectedEdge[13, 18] -> 
             RGBColor[
              0.9385456923076922, 0.9522569230769231, 0.9364258076923078], 
             UndirectedEdge[86, 308] -> 
             RGBColor[
              0.9454568076923076, 0.8878457692307691, 0.6243023076923077], 
             UndirectedEdge[364, 377] -> 
             RGBColor[
              0.9709789615384615, 0.9758853846153845, 0.8396858076923079], 
             UndirectedEdge[90, 152] -> 
             RGBColor[
              0.9784394230769231, 0.9814493846153847, 0.8270571923076925], 
             UndirectedEdge[1, 153] -> 
             RGBColor[
              0.9946406923076923, 0.9909453076923077, 0.6580506153846155], 
             UndirectedEdge[92, 114] -> 
             RGBColor[
              0.9876043076923076, 0.989142076923077, 0.8550922307692308], 
             UndirectedEdge[132, 219] -> 
             RGBColor[
              0.9934679615384615, 0.9906447692307693, 0.6908908846153845], 
             UndirectedEdge[107, 215] -> 
             RGBColor[0.8908973076923077, 0.915168, 0.9661104230769231], 
             UndirectedEdge[240, 319] -> 
             RGBColor[
              0.9605054999999999, 0.9672491538461538, 0.8021978461538462], 
             UndirectedEdge[58, 110] -> 
             RGBColor[
              0.9265019230769231, 0.9435581538461539, 0.969506423076923], 
             UndirectedEdge[67, 85] -> 
             RGBColor[
              0.9926128846153845, 0.9888158461538461, 0.5978210384615383], 
             UndirectedEdge[125, 344] -> 
             RGBColor[
              0.9881640769230768, 0.9701536153846153, 0.5431421538461538], 
             UndirectedEdge[198, 219] -> 
             RGBColor[
              0.9184079230769231, 0.6592496923076923, 0.3999726923076923], 
             UndirectedEdge[16, 325] -> 
             RGBColor[
              0.8773203076923077, 0.9032243076923077, 0.9020307307692307], 
             UndirectedEdge[119, 390] -> 
             RGBColor[
              0.9937856153846154, 0.9891163846153845, 0.5649807692307693], 
             UndirectedEdge[7, 153] -> 
             RGBColor[
              0.9904831923076922, 0.9901481538461538, 0.7939765769230772], 
             UndirectedEdge[23, 164] -> 
             RGBColor[
              0.9937856153846154, 0.9891163846153846, 0.5649807692307692], 
             UndirectedEdge[46, 373] -> 
             RGBColor[
              0.8528722692307692, 0.8828823846153846, 0.8381913846153848], 
             UndirectedEdge[301, 316] -> 
             RGBColor[
              0.9570203846153845, 0.8631512307692305, 0.30592003846153826`], 
             UndirectedEdge[22, 150] -> 
             RGBColor[
              0.9876043076923076, 0.989142076923077, 0.8550922307692308], 
             UndirectedEdge[161, 327] -> 
             RGBColor[
              0.9600779615384615, 0.9663346923076923, 0.7556629230769232], 
             UndirectedEdge[123, 281] -> 
             RGBColor[
              0.9449578846153845, 0.8618534615384615, 0.6052693846153845], 
             UndirectedEdge[111, 160] -> 
             RGBColor[
              0.9251196153846153, 0.7231974615384615, 0.2970421153846152], 
             UndirectedEdge[277, 287] -> 
             RGBColor[
              0.9207433846153845, 0.9380618461538461, 0.9347278076923078], 
             UndirectedEdge[48, 120] -> 
             RGBColor[
              0.9946406923076923, 0.9909453076923077, 0.6580506153846155], 
             UndirectedEdge[6, 224] -> 
             RGBColor[0.8983577692307692, 0.920732, 0.9534818076923077], 
             UndirectedEdge[103, 313] -> 
             RGBColor[
              0.9224495384615384, 0.9387673846153846, 0.906452423076923], 
             UndirectedEdge[8, 60] -> 
             RGBColor[
              0.9780118846153847, 0.9805349230769231, 0.7805222692307692], 
             UndirectedEdge[284, 392] -> 
             RGBColor[0.9604139615384615, 0.8719633076923077, 0.515638], 
             UndirectedEdge[218, 279] -> 
             RGBColor[
              0.9057660769230769, 0.5620789230769231, 0.38786684615384615`], 
             UndirectedEdge[135, 221] -> 
             RGBColor[
              0.9016085769230768, 0.5612817692307692, 0.5237928076923077], 
             UndirectedEdge[95, 309] -> 
             RGBColor[
              0.7802723846153847, 0.8280786923076924, 0.9555412692307692], 
             UndirectedEdge[80, 385] -> 
             RGBColor[
              0.9876043076923076, 0.989142076923077, 0.8550922307692308], 
             UndirectedEdge[272, 398] -> 
             RGBColor[
              0.9432439615384615, 0.8079181538461537, 0.5313657692307692], 
             UndirectedEdge[33, 264] -> 
             RGBColor[0.9089955384615384, 0.9302723846153845, 0.991182], 
             UndirectedEdge[76, 366] -> 
             RGBColor[
              0.9201457692307692, 0.7211116153846153, 0.2546056153846154], 
             UndirectedEdge[41, 258] -> 
             RGBColor[
              0.9934679615384615, 0.9906447692307693, 0.6908908846153845], 
             UndirectedEdge[174, 232] -> 
             RGBColor[
              0.9339623846153846, 0.9491221538461538, 0.9568778076923077], 
             UndirectedEdge[61, 307] -> 
             RGBColor[0.4647738076923076, 0.5606415, 0.9537865], 
             UndirectedEdge[35, 392] -> 
             RGBColor[
              0.9847271538461537, 0.9867128461538461, 0.8472688461538461], 
             UndirectedEdge[212, 259] -> 
             RGBColor[
              0.9700168461538461, 0.9105219230769229, 0.33802153846153826`], 
             UndirectedEdge[73, 110] -> 
             RGBColor[
              0.9784394230769231, 0.9814493846153847, 0.8270571923076925], 
             UndirectedEdge[122, 228] -> 
             RGBColor[
              0.8732950384615384, 0.8825242307692306, 0.6794716923076921], 
             UndirectedEdge[41, 203] -> 
             RGBColor[
              0.9780118846153847, 0.9805349230769231, 0.7805222692307692], 
             UndirectedEdge[361, 385] -> 
             RGBColor[
              0.9921893461538461, 0.9908536923076923, 0.7657011923076924], 
             UndirectedEdge[9, 269] -> 
             RGBColor[
              0.7627659999999999, 0.8147929230769231, 0.9772168461538462], 
             UndirectedEdge[192, 228] -> 
             RGBColor[
              0.8387582692307692, 0.7530781538461538, 0.6127229615384615], 
             UndirectedEdge[47, 265] -> 
             RGBColor[
              0.970551423076923, 0.974970923076923, 0.7931508846153845], 
             UndirectedEdge[338, 398] -> 
             RGBColor[
              0.9126413076923077, 0.6893283076923076, 0.24846230769230765`], 
             UndirectedEdge[71, 79] -> 
             RGBColor[
              0.9755605384615385, 0.9804433076923078, 0.8881728461538461], 
             UndirectedEdge[77, 78] -> 
             RGBColor[
              0.9929305384615386, 0.9872874615384615, 0.47191092307692306`], 
             UndirectedEdge[89, 164] -> 
             RGBColor[0.987309, 0.9683246923076922, 0.45007230769230755`], 
             UndirectedEdge[123, 235] -> 
             RGBColor[
              0.9755605384615385, 0.9804433076923078, 0.8881728461538461], 
             UndirectedEdge[72, 393] -> 
             RGBColor[
              0.9868814615384616, 0.9674102307692306, 0.40353738461538435`], 
             UndirectedEdge[240, 371] -> 
             RGBColor[
              0.9580541538461538, 0.9671575384615384, 0.909848423076923], 
             UndirectedEdge[196, 303] -> 
             RGBColor[
              0.9640748076923076, 0.9541792307692306, 0.6782424230769228], 
             UndirectedEdge[105, 170] -> 
             RGBColor[0.8364538076923077, 0.5109070769230769, 0.575153], 
             UndirectedEdge[195, 208] -> 
             RGBColor[
              0.9709789615384615, 0.9758853846153845, 0.8396858076923079], 
             UndirectedEdge[100, 180] -> 
             RGBColor[
              0.9926128846153845, 0.9888158461538461, 0.5978210384615383], 
             UndirectedEdge[39, 355] -> 
             RGBColor[0.9740421153846153, 0.931222, 0.5605805769230768], 
             UndirectedEdge[244, 397] -> 
             RGBColor[0.872058423076923, 0.5392972307692308, 0.578549], 
             UndirectedEdge[225, 355] -> 
             RGBColor[0.9740421153846153, 0.931222, 0.5605805769230768], 
             UndirectedEdge[335, 354] -> 
             RGBColor[
              0.9075261153846155, 0.9255783846153847, 0.8436387692307694], 
             UndirectedEdge[97, 100] -> 
             RGBColor[
              0.9868814615384616, 0.9674102307692306, 0.40353738461538435`], 
             UndirectedEdge[2, 107] -> 
             RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 
             UndirectedEdge[128, 225] -> 
             RGBColor[
              0.9681000769230769, 0.9748793076923077, 0.9008014615384614], 
             UndirectedEdge[96, 228] -> 
             RGBColor[0.8676735, 0.8635614615384615, 0.6576330769230767], 
             UndirectedEdge[262, 307] -> 
             RGBColor[0.8362434615384615, 0.872472, 0.9606630384615384], 
             UndirectedEdge[86, 334] -> 
             RGBColor[
              0.9543501538461538, 0.9654750000000001, 0.9621574615384615], 
             UndirectedEdge[255, 399] -> 
             RGBColor[
              0.9190414615384614, 0.9379941538461538, 0.9821350384615385], 
             UndirectedEdge[138, 242] -> 
             RGBColor[
              0.9835790384615384, 0.9684419999999998, 0.6325331923076922], 
             UndirectedEdge[27, 396] -> 
             RGBColor[
              0.9251196153846153, 0.7231974615384615, 0.2970421153846152], 
             UndirectedEdge[163, 209] -> 
             RGBColor[
              0.894185346153846, 0.7710329999999999, 0.6126993461538461], 
             UndirectedEdge[63, 202] -> 
             RGBColor[
              0.936194423076923, 0.7759078461538462, 0.5254834615384615], 
             UndirectedEdge[347, 372] -> 
             RGBColor[
              0.9206006923076921, 0.7208846153846151, 0.2548666153846153], 
             UndirectedEdge[174, 275] -> 
             RGBColor[
              0.9096491923076923, 0.8343726153846154, 0.6252469615384615], 
             UndirectedEdge[209, 315] -> 
             RGBColor[
              0.9190414615384614, 0.9379941538461538, 0.9821350384615385], 
             UndirectedEdge[177, 374] -> 
             RGBColor[
              0.8893788846153846, 0.8659466923076923, 0.6385181538461538], 
             UndirectedEdge[214, 215] -> 
             RGBColor[
              0.8740445769230769, 0.8059824615384614, 0.6218509615384615], 
             UndirectedEdge[160, 185] -> 
             RGBColor[
              0.9315962307692307, 0.7439891538461539, 0.4119505769230769], 
             UndirectedEdge[63, 268] -> 
             RGBColor[0.9740421153846153, 0.931222, 0.5605805769230768], 
             UndirectedEdge[48, 196] -> 
             RGBColor[
              0.9881640769230768, 0.9701536153846153, 0.5431421538461538], 
             UndirectedEdge[34, 95] -> 
             RGBColor[
              0.908527576923077, 0.6983391538461536, 0.5750321923076922], 
             UndirectedEdge[84, 333] -> 
             RGBColor[
              0.9240458076923077, 0.9370300769230768, 0.7057319999999999], 
             UndirectedEdge[102, 224] -> 
             RGBColor[
              0.5778292692307692, 0.6437805000000001, 0.9288863076923077], 
             UndirectedEdge[105, 326] -> 
             RGBColor[0.9249008846153846, 0.938859, 0.7988018461538461], 
             UndirectedEdge[134, 236] -> 
             RGBColor[
              0.981259923076923, 0.9484474615384613, 0.38169876923076884`], 
             UndirectedEdge[92, 161] -> 
             RGBColor[
              0.9896281153846154, 0.9883192307692308, 0.7009067307692309], 
             UndirectedEdge[77, 185] -> 
             RGBColor[
              0.993358076923077, 0.988201923076923, 0.518445846153846], 
             UndirectedEdge[178, 329] -> 
             RGBColor[
              0.9904831923076922, 0.9901481538461538, 0.7939765769230772], 
             UndirectedEdge[185, 400] -> 
             RGBColor[
              0.9937856153846154, 0.9891163846153846, 0.5649807692307692], 
             UndirectedEdge[317, 333] -> 
             RGBColor[
              0.9523446923076924, 0.8379641538461539, 0.33678865384615375`], 
             UndirectedEdge[106, 215] -> 
             RGBColor[
              0.8740445769230769, 0.8059824615384614, 0.6218509615384615], 
             UndirectedEdge[14, 340] -> 
             RGBColor[
              0.8635703846153846, 0.8938200000000001, 0.9633867307692308], 
             UndirectedEdge[233, 358] -> 
             RGBColor[
              0.9119876538461538, 0.7852280769230768, 0.6143973461538461], 
             UndirectedEdge[74, 191] -> 
             RGBColor[
              0.5180951538461538, 0.24075249999999998`, 0.5499968846153847], 
             UndirectedEdge[53, 244] -> 
             RGBColor[0.904911, 0.5602499999999999, 0.2947969999999999], 
             UndirectedEdge[4, 16] -> 
             RGBColor[
              0.8773203076923077, 0.9032243076923077, 0.9020307307692307], 
             UndirectedEdge[149, 274] -> 
             RGBColor[
              0.9206006923076921, 0.7208846153846151, 0.2548666153846153], 
             UndirectedEdge[326, 335] -> 
             RGBColor[
              0.9946406923076923, 0.9909453076923077, 0.6580506153846155], 
             UndirectedEdge[30, 77] -> 
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998], 
             UndirectedEdge[129, 229] -> 
             RGBColor[
              0.9813148461538461, 0.9853017692307693, 0.9038196153846154], 
             UndirectedEdge[216, 219] -> 
             RGBColor[
              0.9691185384615384, 0.9029056923076921, 0.4426671153846153], 
             UndirectedEdge[138, 233] -> 
             RGBColor[
              0.9563479999999999, 0.9664519999999999, 0.9381238076923077], 
             UndirectedEdge[28, 44] -> 
             RGBColor[
              0.922855423076923, 0.7400572307692308, 0.5683285384615384], 
             UndirectedEdge[163, 227] -> 
             RGBColor[
              0.9432439615384615, 0.8079181538461537, 0.5313657692307692], 
             UndirectedEdge[15, 335] -> 
             RGBColor[
              0.9695460769230768, 0.9038201538461537, 0.48920203846153865`], 
             UndirectedEdge[257, 268] -> 
             RGBColor[0.9740421153846153, 0.931222, 0.5605805769230768], 
             UndirectedEdge[217, 279] -> 
             RGBColor[
              0.9946406923076923, 0.9909453076923077, 0.6580506153846155], 
             UndirectedEdge[93, 119] -> 
             RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 
             UndirectedEdge[67, 305] -> 
             RGBColor[
              0.8789165769230769, 0.9014869999999999, 0.7013103076923075], 
             UndirectedEdge[153, 195] -> 
             RGBColor[
              0.9709789615384615, 0.9758853846153845, 0.8396858076923079], 
             UndirectedEdge[50, 135] -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.8268168461538462], 
             UndirectedEdge[68, 334] -> 
             RGBColor[
              0.7511891538461539, 0.8044676153846154, 0.9532517307692308], 
             UndirectedEdge[95, 308] -> 
             RGBColor[
              0.9529172692307692, 0.8934097692307691, 0.6116736923076922], 
             UndirectedEdge[17, 36] -> 
             RGBColor[0.982115, 0.9502763846153846, 0.47476861538461523`], 
             UndirectedEdge[41, 361] -> 
             RGBColor[
              0.9946406923076923, 0.9909453076923077, 0.6580506153846155], 
             UndirectedEdge[117, 371] -> 
             RGBColor[
              0.9917618076923076, 0.9899392307692307, 0.7191662692307691], 
             UndirectedEdge[89, 304] -> 
             RGBColor[
              0.9006219615384615, 0.9038722307692306, 0.6821953846153844], 
             UndirectedEdge[267, 272] -> 
             RGBColor[
              0.936194423076923, 0.7759078461538462, 0.5254834615384614], 
             UndirectedEdge[20, 158] -> 
             RGBColor[
              0.9265019230769231, 0.9435581538461539, 0.969506423076923], 
             UndirectedEdge[30, 62] -> 
             RGBColor[
              0.9909067307692307, 0.9881103076923077, 0.6260964230769229], 
             UndirectedEdge[197, 310] -> 
             RGBColor[
              0.9454568076923076, 0.8878457692307691, 0.6243023076923077], 
             UndirectedEdge[142, 268] -> 
             RGBColor[
              0.9427858076923076, 0.908531923076923, 0.6436121538461538], 
             UndirectedEdge[78, 213] -> 
             RGBColor[
              0.9701238846153846, 0.9740564615384615, 0.7466159615384615], 
             UndirectedEdge[48, 71] -> 
             RGBColor[
              0.9784394230769231, 0.9814493846153847, 0.8270571923076925], 
             UndirectedEdge[262, 269] -> 
             RGBColor[
              0.7802723846153847, 0.8280786923076924, 0.9555412692307692], 
             UndirectedEdge[27, 376] -> 
             RGBColor[
              0.9308510384615385, 0.744603076923077, 0.49132576923076926`], 
             UndirectedEdge[245, 292] -> 
             RGBColor[
              0.9709789615384615, 0.9758853846153845, 0.8396858076923079], 
             UndirectedEdge[142, 217] -> 
             RGBColor[
              0.9609330384615384, 0.9681636153846154, 0.8487327692307695], 
             UndirectedEdge[142, 363] -> 
             RGBColor[
              0.8460639999999999, 0.8805342307692307, 0.9850623076923077], 
             UndirectedEdge[121, 130] -> 
             RGBColor[
              0.9760659230769231, 0.9303991538461538, 0.40639507692307697`], 
             UndirectedEdge[217, 300] -> 
             RGBColor[
              0.9921893461538461, 0.9908536923076923, 0.7657011923076924], 
             UndirectedEdge[25, 109] -> 
             RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 
             UndirectedEdge[40, 146] -> 
             RGBColor[
              0.9224495384615384, 0.9387673846153846, 0.906452423076923], 
             UndirectedEdge[18, 140] -> 
             RGBColor[
              0.9016085769230768, 0.5612817692307692, 0.5237928076923077], 
             UndirectedEdge[170, 239] -> 
             RGBColor[0.8895648076923077, 0.552583, 0.556873423076923], 
             UndirectedEdge[152, 333] -> 
             RGBColor[
              0.9937856153846154, 0.9891163846153845, 0.5649807692307693], 
             UndirectedEdge[14, 250] -> 
             RGBColor[
              0.8773203076923077, 0.9032243076923077, 0.9020307307692307], 
             UndirectedEdge[55, 159] -> 
             RGBColor[
              0.9946406923076923, 0.9909453076923077, 0.6580506153846155], 
             UndirectedEdge[234, 331] -> 
             RGBColor[
              0.7221059230769231, 0.7808565384615385, 0.9509621923076923], 
             UndirectedEdge[370, 389] -> 
             RGBColor[0.7380032307692308, 0.795253, 0.9745209230769231], 
             UndirectedEdge[119, 316] -> 
             RGBColor[
              0.9695460769230768, 0.9038201538461537, 0.48920203846153865`], 
             UndirectedEdge[89, 227] -> 
             RGBColor[
              0.9852851923076922, 0.9691475384615383, 0.6042578076923074], 
             UndirectedEdge[246, 254] -> 
             RGBColor[0.8693335, 0.7248276153846154, 0.6051190384615384], 
             UndirectedEdge[197, 345] -> 
             RGBColor[
              0.9065016153846153, 0.6568639999999999, 0.24310199999999996`], 
             UndirectedEdge[231, 234] -> 
             RGBColor[
              0.7146454615384615, 0.7752925384615383, 0.9635908076923076], 
             UndirectedEdge[89, 209] -> 
             RGBColor[
              0.9362265769230769, 0.9322623846153845, 0.6855913846153845], 
             UndirectedEdge[233, 317] -> 
             RGBColor[
              0.9194921153846153, 0.8170113846153846, 0.6205406538461539], 
             UndirectedEdge[48, 342] -> 
             RGBColor[
              0.9946406923076923, 0.9909453076923077, 0.6580506153846155], 
             UndirectedEdge[24, 104] -> 
             RGBColor[
              0.8756141538461538, 0.9025187692307692, 0.9303061153846155], 
             UndirectedEdge[118, 149] -> 
             RGBColor[
              0.9220335769230769, 0.792949846153846, 0.6053503846153846], 
             UndirectedEdge[34, 53] -> 
             RGBColor[
              0.9238737692307692, 0.7060061538461537, 0.3129557692307691], 
             UndirectedEdge[29, 45] -> 
             RGBColor[
              0.9241556923076923, 0.9394729230769231, 0.8781770384615384], 
             UndirectedEdge[35, 208] -> 
             RGBColor[
              0.9858998846153846, 0.9870133846153846, 0.8144285769230771], 
             UndirectedEdge[69, 191] -> 
             RGBColor[
              0.9061936153846154, 0.5629933846153846, 0.43440176923076945`], 
             UndirectedEdge[102, 166] -> 
             RGBColor[0.5703688076923077, 0.6382165, 0.9415149230769231], 
             UndirectedEdge[185, 213] -> 
             RGBColor[
              0.970551423076923, 0.974970923076923, 0.7931508846153845], 
             UndirectedEdge[172, 364] -> 
             RGBColor[
              0.9584532692307692, 0.9352164615384615, 0.6564038076923076], 
             UndirectedEdge[36, 55] -> 
             RGBColor[0.982115, 0.9502763846153846, 0.47476861538461523`], 
             UndirectedEdge[192, 203] -> 
             RGBColor[
              0.9369985000000001, 0.8302971538461539, 0.5988650769230769], 
             UndirectedEdge[105, 394] -> 
             RGBColor[
              0.9241556923076923, 0.9394729230769231, 0.8781770384615384], 
             UndirectedEdge[256, 261] -> 
             RGBColor[
              0.9241556923076923, 0.9394729230769231, 0.8781770384615384], 
             UndirectedEdge[215, 295] -> 
             RGBColor[
              0.8820039615384615, 0.837538769230769, 0.6282552692307692], 
             UndirectedEdge[219, 357] -> 
             RGBColor[
              0.9070985769230769, 0.9246639230769231, 0.7971038461538461], 
             UndirectedEdge[204, 295] -> 
             RGBColor[
              0.9666671923076922, 0.9028140769230768, 0.5503176923076922], 
             UndirectedEdge[24, 138] -> 
             RGBColor[
              0.9858981538461538, 0.9884365384615384, 0.8833676153846155], 
             UndirectedEdge[135, 376] -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.8268168461538462], 
             UndirectedEdge[127, 305] -> 
             RGBColor[
              0.8801991923076924, 0.9042303846153845, 0.8409150769230771], 
             UndirectedEdge[54, 158] -> 
             RGBColor[
              0.9738543846153846, 0.9797377692307693, 0.9164482307692308], 
             UndirectedEdge[180, 350] -> 
             RGBColor[
              0.7118994615384615, 0.7695284615384617, 0.8594774230769231], 
             UndirectedEdge[46, 287] -> 
             RGBColor[
              0.9253284230769231, 0.9397734615384615, 0.8453367692307694], 
             UndirectedEdge[41, 153] -> 
             RGBColor[
              0.9946406923076923, 0.9909453076923077, 0.6580506153846155], 
             UndirectedEdge[163, 315] -> 
             RGBColor[
              0.9220335769230769, 0.792949846153846, 0.6053503846153846], 
             UndirectedEdge[17, 64] -> 
             RGBColor[
              0.9780118846153847, 0.9805349230769231, 0.7805222692307692], 
             UndirectedEdge[67, 127] -> 
             RGBColor[
              0.9937856153846154, 0.9891163846153845, 0.5649807692307693], 
             UndirectedEdge[83, 246] -> 
             RGBColor[
              0.769550423076923, 0.6465885384615384, 0.5952499615384615], 
             UndirectedEdge[44, 383] -> 
             RGBColor[0.9079345, 0.7289292307692308, 0.5935857692307693], 
             UndirectedEdge[5, 275] -> 
             RGBColor[
              0.9603040769230768, 0.8695204615384615, 0.34319296153846146`], 
             UndirectedEdge[99, 123] -> 
             RGBColor[
              0.9443042307692306, 0.9577532307692307, 0.971204423076923], 
             UndirectedEdge[278, 354] -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 
             UndirectedEdge[61, 215] -> 
             RGBColor[0.5194276538461539, 0.6033375, 0.9592338846153846], 
             UndirectedEdge[115, 208] -> 
             RGBColor[
              0.9253284230769231, 0.9397734615384615, 0.8453367692307694], 
             UndirectedEdge[167, 203] -> 
             RGBColor[
              0.9543501538461538, 0.9654750000000001, 0.9621574615384615], 
             UndirectedEdge[242, 256] -> 
             RGBColor[
              0.9184242692307691, 0.9180673076923076, 0.6838933846153844], 
             UndirectedEdge[136, 254] -> 
             RGBColor[
              0.8998062692307691, 0.851733846153846, 0.6299532692307692], 
             UndirectedEdge[65, 170] -> 
             RGBColor[0.8970252692307692, 0.558147, 0.5442448076923077], 
             UndirectedEdge[247, 340] -> 
             RGBColor[
              0.9265019230769231, 0.9435581538461539, 0.969506423076923], 
             UndirectedEdge[8, 17] -> 
             RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076922], 
             UndirectedEdge[269, 300] -> 
             RGBColor[0.7940223076923076, 0.837483, 0.8941852692307691], 
             UndirectedEdge[233, 242] -> 
             RGBColor[
              0.9540288846153845, 0.9464574615384613, 0.6872893846153845], 
             UndirectedEdge[242, 382] -> 
             RGBColor[
              0.9756383846153845, 0.929484692307692, 0.35986015384615355`], 
             UndirectedEdge[144, 242] -> 
             RGBColor[
              0.9868814615384616, 0.9674102307692306, 0.40353738461538435`], 
             UndirectedEdge[81, 227] -> 
             RGBColor[
              0.9913342692307692, 0.9890247692307692, 0.6726313461538461], 
             UndirectedEdge[224, 230] -> 
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153], 
             UndirectedEdge[81, 248] -> 
             RGBColor[
              0.9607316153846154, 0.870434923076923, 0.38972788461538466`], 
             UndirectedEdge[13, 323] -> 
             RGBColor[
              0.9427031923076923, 0.9530540769230769, 0.8004998461538462], 
             UndirectedEdge[10, 189] -> 
             RGBColor[
              0.8482872307692306, 0.8811707692307692, 0.9275824230769232], 
             UndirectedEdge[135, 364] -> 
             RGBColor[
              0.966393923076923, 0.9741737692307693, 0.9290768461538462], 
             UndirectedEdge[39, 383] -> 
             RGBColor[
              0.9681000769230769, 0.9748793076923077, 0.9008014615384614], 
             UndirectedEdge[108, 196] -> 
             RGBColor[
              0.9789957307692307, 0.9653072307692306, 0.6529851923076921], 
             UndirectedEdge[75, 89] -> 
             RGBColor[
              0.9881640769230768, 0.9701536153846153, 0.5431421538461538], 
             UndirectedEdge[131, 269] -> 
             RGBColor[
              0.7787539615384615, 0.7788573846153846, 0.6279489999999999], 
             UndirectedEdge[36, 165] -> 
             RGBColor[
              0.948407346153846, 0.9274946923076921, 0.6654507692307692], 
             UndirectedEdge[40, 41] -> 
             RGBColor[
              0.9917618076923076, 0.9899392307692307, 0.7191662692307691], 
             UndirectedEdge[86, 249] -> 
             RGBColor[
              0.9190414615384614, 0.9379941538461538, 0.9821350384615385], 
             UndirectedEdge[287, 395] -> 
             RGBColor[0.8693335, 0.7248276153846154, 0.6051190384615385], 
             UndirectedEdge[177, 225] -> 
             RGBColor[
              0.9046472307692308, 0.9245723076923077, 0.904754423076923], 
             UndirectedEdge[74, 216] -> 
             RGBColor[
              0.5814476153846153, 0.5815792692307691, 0.6047971538461538], 
             UndirectedEdge[229, 371] -> 
             RGBColor[
              0.9830209999999999, 0.9860073076923077, 0.8755442307692307], 
             UndirectedEdge[319, 371] -> 
             RGBColor[
              0.9917618076923076, 0.9899392307692307, 0.7191662692307691], 
             UndirectedEdge[169, 353] -> 
             RGBColor[
              0.9294940384615384, 0.7985138461538461, 0.5927217692307691], 
             UndirectedEdge[47, 362] -> 
             RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076922], 
             UndirectedEdge[83, 313] -> 
             RGBColor[
              0.7558055384615384, 0.8094480769230769, 0.976218923076923], 
             UndirectedEdge[87, 210] -> 
             RGBColor[
              0.9852851923076922, 0.9691475384615383, 0.6042578076923074], 
             UndirectedEdge[91, 150] -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.8268168461538462], 
             UndirectedEdge[16, 258] -> 
             RGBColor[
              0.8790264615384615, 0.9039298461538461, 0.8737553461538461], 
             UndirectedEdge[334, 388] -> 
             RGBColor[
              0.9543501538461538, 0.9654750000000001, 0.9621574615384615], 
             UndirectedEdge[67, 325] -> 
             RGBColor[
              0.9909067307692307, 0.9881103076923077, 0.6260964230769229], 
             UndirectedEdge[279, 363] -> 
             RGBColor[
              0.8797716538461539, 0.903315923076923, 0.7943801538461538], 
             UndirectedEdge[192, 385] -> 
             RGBColor[
              0.950748423076923, 0.8397014615384616, 0.5375090769230768], 
             UndirectedEdge[216, 339] -> 
             RGBColor[
              0.9176085769230768, 0.8659289230769229, 0.6316512692307692], 
             UndirectedEdge[74, 323] -> 
             RGBColor[
              0.6065422307692308, 0.668704423076923, 0.7736457307692307], 
             UndirectedEdge[60, 87] -> 
             RGBColor[
              0.9715352692307693, 0.9597432307692306, 0.6656138076923075], 
             UndirectedEdge[74, 198] -> 
             RGBColor[0.530737, 0.3379232692307692, 0.5621027307692308], 
             UndirectedEdge[16, 348] -> 
             RGBColor[
              0.8790264615384615, 0.9039298461538461, 0.8737553461538461], 
             UndirectedEdge[88, 283] -> 
             RGBColor[
              0.9368437692307692, 0.9521892307692307, 0.9838330384615385], 
             UndirectedEdge[292, 388] -> 
             RGBColor[
              0.9709789615384615, 0.9758853846153845, 0.8396858076923079], 
             UndirectedEdge[76, 382] -> 
             RGBColor[
              0.9490609999999999, 0.831594923076923, 0.29951573076923066`], 
             UndirectedEdge[131, 352] -> 
             RGBColor[
              0.9677526538461538, 0.9273816923076923, 0.6093079615384616], 
             UndirectedEdge[123, 232] -> 
             RGBColor[
              0.9692710769230769, 0.9766030000000001, 0.9369002307692307], 
             UndirectedEdge[69, 357] -> 
             RGBColor[
              0.9075261153846155, 0.9255783846153847, 0.8436387692307694], 
             UndirectedEdge[241, 339] -> 
             RGBColor[
              0.9427031923076923, 0.9530540769230769, 0.8004998461538462], 
             UndirectedEdge[181, 322] -> 
             RGBColor[
              0.9596504230769229, 0.9654202307692307, 0.7091279999999999], 
             UndirectedEdge[140, 168] -> 
             RGBColor[
              0.7366707307692307, 0.43266799999999994`, 0.5652839230769231], 
             UndirectedEdge[88, 357] -> 
             RGBColor[0.873390923076923, 0.9018822307692307, 0.987786], 
             UndirectedEdge[125, 179] -> 
             RGBColor[
              0.9640748076923076, 0.9541792307692306, 0.6782424230769228], 
             UndirectedEdge[316, 324] -> 
             RGBColor[
              0.9691185384615384, 0.9029056923076921, 0.4426671153846153], 
             UndirectedEdge[128, 390] -> 
             RGBColor[0.9696963461538461, 0.973142, 0.7000810384615384], 
             UndirectedEdge[200, 339] -> 
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484], 
             UndirectedEdge[85, 110] -> 
             RGBColor[
              0.9772666923076923, 0.9811488461538462, 0.8598974615384615], 
             UndirectedEdge[178, 209] -> 
             RGBColor[
              0.9385456923076922, 0.9522569230769231, 0.9364258076923078], 
             UndirectedEdge[380, 383] -> 
             RGBColor[
              0.9149840384615384, 0.7609395384615385, 0.5994680769230769], 
             UndirectedEdge[350, 357] -> 
             RGBColor[
              0.6255300769230769, 0.7035476153846154, 0.9656903846153846], 
             UndirectedEdge[98, 352] -> 
             RGBColor[
              0.952418346153846, 0.8674174615384616, 0.5926407692307691], 
             UndirectedEdge[68, 151] -> 
             RGBColor[
              0.7649390769230768, 0.8138719230769231, 0.8918957307692307], 
             UndirectedEdge[307, 385] -> 
             RGBColor[
              0.8499933846153845, 0.8818763076923077, 0.8993070384615384], 
             UndirectedEdge[94, 119] -> 
             RGBColor[
              0.8255453461538461, 0.8615343846153846, 0.8354676923076925], 
             UndirectedEdge[116, 121] -> 
             RGBColor[
              0.7669628846153846, 0.8130490769230769, 0.7377102307692308], 
             UndirectedEdge[1, 361] -> 
             RGBColor[
              0.9946406923076923, 0.9909453076923077, 0.6580506153846155], 
             UndirectedEdge[180, 239] -> 
             RGBColor[
              0.9772666923076923, 0.9811488461538462, 0.8598974615384615], 
             UndirectedEdge[45, 394] -> 
             RGBColor[
              0.9927227692307692, 0.9912586923076924, 0.7702660769230769], 
             UndirectedEdge[32, 124] -> 
             RGBColor[
              0.9149840384615384, 0.7609395384615385, 0.5994680769230769], 
             UndirectedEdge[87, 243] -> 
             RGBColor[0.987309, 0.9683246923076922, 0.45007230769230755`], 
             UndirectedEdge[188, 195] -> 
             RGBColor[
              0.9698062307692308, 0.9755848461538461, 0.8725260769230769], 
             UndirectedEdge[122, 262] -> 
             RGBColor[
              0.9715352692307693, 0.9597432307692306, 0.6656138076923075], 
             UndirectedEdge[118, 212] -> 
             RGBColor[
              0.9640748076923076, 0.9541792307692306, 0.6782424230769228], 
             UndirectedEdge[35, 258] -> 
             RGBColor[
              0.9847271538461537, 0.9867128461538461, 0.8472688461538461], 
             UndirectedEdge[183, 271] -> 
             RGBColor[
              0.9909067307692307, 0.9881103076923077, 0.6260964230769229], 
             UndirectedEdge[130, 147] -> 
             RGBColor[
              0.8893788846153846, 0.8659466923076923, 0.6385181538461537], 
             UndirectedEdge[124, 330] -> 
             RGBColor[
              0.9681000769230769, 0.9748793076923077, 0.9008014615384614], 
             UndirectedEdge[46, 395] -> 
             RGBColor[
              0.9390733076923077, 0.7769139230769231, 0.4643678076923079], 
             UndirectedEdge[206, 284] -> 
             RGBColor[0.9604139615384615, 0.8719633076923077, 0.515638], 
             UndirectedEdge[179, 313] -> 
             RGBColor[
              0.9012391538461538, 0.9237990769230768, 0.9804370384615384], 
             UndirectedEdge[215, 363] -> 
             RGBColor[
              0.792657076923077, 0.8379489999999999, 0.9799683076923077], 
             UndirectedEdge[260, 338] -> 
             RGBColor[
              0.952418346153846, 0.8674174615384616, 0.5926407692307691], 
             UndirectedEdge[88, 113] -> 
             RGBColor[
              0.9354108846153845, 0.8801239999999997, 0.6333492692307692], 
             UndirectedEdge[95, 270] -> 
             RGBColor[
              0.9602921923076924, 0.9218176923076924, 0.6219365769230768], 
             UndirectedEdge[16, 184] -> 
             RGBColor[
              0.8789165769230769, 0.9014869999999999, 0.7013103076923076], 
             UndirectedEdge[38, 78] -> 
             RGBColor[
              0.9053385384615384, 0.5611644615384616, 0.34133192307692317`], 
             UndirectedEdge[8, 210] -> 
             RGBColor[
              0.9917618076923076, 0.9899392307692307, 0.7191662692307691], 
             UndirectedEdge[1, 96] -> 
             RGBColor[0.982115, 0.9502763846153846, 0.47476861538461523`], 
             UndirectedEdge[213, 247] -> 
             RGBColor[
              0.9190414615384614, 0.9379941538461538, 0.9821350384615385], 
             UndirectedEdge[109, 366] -> 
             RGBColor[
              0.9536273076923076, 0.8407075384615386, 0.47639342307692334`], 
             UndirectedEdge[223, 260] -> 
             RGBColor[
              0.7586496153846154, 0.8100316153846154, 0.9406231153846154], 
             UndirectedEdge[393, 399] -> 
             RGBColor[0.9696963461538461, 0.973142, 0.7000810384615384], 
             UndirectedEdge[25, 358] -> 
             RGBColor[
              0.9461228461538461, 0.8089242307692307, 0.4702501153846156], 
             UndirectedEdge[207, 358] -> 
             RGBColor[
              0.9369544999999999, 0.804077846153846, 0.5800931538461538], 
             UndirectedEdge[31, 33] -> 
             RGBColor[
              0.9443042307692306, 0.9577532307692307, 0.971204423076923], 
             UndirectedEdge[355, 375] -> 
             RGBColor[
              0.9587737692307692, 0.8725963846153846, 0.2943443076923076], 
             UndirectedEdge[25, 104] -> 
             RGBColor[
              0.8801991923076924, 0.9042303846153845, 0.8409150769230771], 
             UndirectedEdge[360, 375] -> 
             RGBColor[
              0.9513988461538461, 0.8441884615384614, 0.28408142307692297`], 
             UndirectedEdge[28, 347] -> 
             RGBColor[
              0.9369544999999999, 0.804077846153846, 0.5800931538461538], 
             UndirectedEdge[56, 143] -> 
             RGBColor[
              0.9715352692307693, 0.9597432307692306, 0.6656138076923075], 
             UndirectedEdge[73, 115] -> 
             RGBColor[
              0.9253284230769231, 0.9397734615384615, 0.8453367692307694], 
             UndirectedEdge[157, 218] -> 
             RGBColor[
              0.9033147307692307, 0.5619873076923076, 0.495517423076923], 
             UndirectedEdge[267, 321] -> 
             RGBColor[
              0.9390733076923077, 0.7769139230769231, 0.4643678076923079], 
             UndirectedEdge[93, 324] -> 
             RGBColor[
              0.9946406923076923, 0.9909453076923077, 0.6580506153846155], 
             UndirectedEdge[178, 245] -> 
             RGBColor[
              0.966393923076923, 0.9741737692307693, 0.9290768461538462], 
             UndirectedEdge[223, 331] -> 
             RGBColor[
              0.7511891538461539, 0.8044676153846154, 0.9532517307692308], 
             UndirectedEdge[318, 367] -> 
             RGBColor[
              0.9418481153846154, 0.9512251538461538, 0.7074299999999999], 
             UndirectedEdge[158, 265] -> 
             RGBColor[
              0.9543501538461538, 0.9654750000000001, 0.9621574615384615], 
             UndirectedEdge[124, 199] -> 
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461], 
             UndirectedEdge[38, 213] -> 
             RGBColor[
              0.8821043461538461, 0.5470189999999999, 0.5695020384615385], 
             UndirectedEdge[128, 296] -> 
             RGBColor[
              0.772811923076923, 0.8225146923076923, 0.9681698846153846], 
             UndirectedEdge[89, 315] -> 
             RGBColor[
              0.9640748076923076, 0.9541792307692306, 0.6782424230769228], 
             UndirectedEdge[129, 178] -> 
             RGBColor[
              0.9858981538461538, 0.9884365384615384, 0.8833676153846155], 
             UndirectedEdge[61, 279] -> 
             RGBColor[
              0.6065422307692308, 0.668704423076923, 0.7736457307692307], 
             UndirectedEdge[7, 332] -> 
             RGBColor[
              0.9563479999999999, 0.9664519999999999, 0.9381238076923077], 
             UndirectedEdge[105, 180] -> 
             RGBColor[
              0.9241556923076923, 0.9394729230769231, 0.8781770384615384], 
             UndirectedEdge[75, 163] -> 
             RGBColor[
              0.9461228461538461, 0.8089242307692307, 0.4702501153846156], 
             UndirectedEdge[15, 273] -> 
             RGBColor[
              0.9683733461538461, 0.9035196153846152, 0.5220423076923076], 
             UndirectedEdge[149, 287] -> 
             RGBColor[
              0.8763830384615384, 0.756837923076923, 0.6110013461538462], 
             UndirectedEdge[123, 275] -> 
             RGBColor[
              0.9449578846153845, 0.8618534615384615, 0.6052693846153845], 
             UndirectedEdge[186, 226] -> 
             RGBColor[
              0.9279756153846153, 0.7492925384615383, 0.26512949999999996`], 
             UndirectedEdge[15, 183] -> 
             RGBColor[
              0.9682634615384615, 0.9010767692307691, 0.34959726923076906`], 
             UndirectedEdge[35, 41] -> 
             RGBColor[
              0.9854723461538462, 0.986098923076923, 0.7678936538461538], 
             UndirectedEdge[47, 54] -> 
             RGBColor[
              0.9900556538461538, 0.9892336923076923, 0.7474416538461539], 
             UndirectedEdge[19, 196] -> 
             RGBColor[
              0.9789957307692307, 0.9653072307692306, 0.6529851923076921], 
             UndirectedEdge[211, 328] -> 
             RGBColor[
              0.9682634615384615, 0.9010767692307691, 0.34959726923076906`], 
             UndirectedEdge[3, 86] -> 
             RGBColor[
              0.9295380384615384, 0.8247331538461539, 0.6114936923076923], 
             UndirectedEdge[55, 58] -> 
             RGBColor[
              0.9427031923076923, 0.9530540769230769, 0.8004998461538462], 
             UndirectedEdge[63, 214] -> 
             RGBColor[
              0.9587078076923077, 0.8712577692307693, 0.5439133846153845], 
             UndirectedEdge[26, 106] -> 
             RGBColor[
              0.952418346153846, 0.8674174615384616, 0.5926407692307691], 
             UndirectedEdge[89, 378] -> 
             RGBColor[
              0.9835790384615384, 0.9684419999999998, 0.6325331923076922], 
             UndirectedEdge[191, 311] -> 
             RGBColor[
              0.8647526923076923, 0.4118411538461539, 0.20620965384615386`], 
             UndirectedEdge[147, 364] -> 
             RGBColor[0.8834368461538462, 0.909604, 0.9787390384615384], 
             UndirectedEdge[137, 285] -> 
             RGBColor[
              0.8830783846153846, 0.5619680769230769, 0.22415007692307692`], 
             UndirectedEdge[104, 205] -> 
             RGBColor[
              0.8620519615384615, 0.8445986923076922, 0.6357944615384615], 
             UndirectedEdge[191, 339] -> 
             RGBColor[0.8542561153846153, 0.5251021538461538, 0.576851], 
             UndirectedEdge[40, 167] -> 
             RGBColor[
              0.9681000769230769, 0.9748793076923077, 0.9008014615384614], 
             UndirectedEdge[17, 262] -> 
             RGBColor[
              0.9780118846153847, 0.9805349230769231, 0.7805222692307692], 
             UndirectedEdge[96, 348] -> 
             RGBColor[
              0.9813698076923076, 0.9508903076923076, 0.5541438076923075], 
             UndirectedEdge[60, 122] -> 
             RGBColor[
              0.9715352692307693, 0.9597432307692306, 0.6656138076923075], 
             UndirectedEdge[99, 187] -> 
             RGBColor[
              0.9517646923076921, 0.9633172307692307, 0.9585758076923077], 
             UndirectedEdge[111, 166] -> 
             RGBColor[
              0.9715352692307693, 0.9597432307692306, 0.6656138076923075], 
             UndirectedEdge[130, 172] -> 
             RGBColor[
              0.9643953076923076, 0.8915591538461538, 0.3161829230769229], 
             UndirectedEdge[205, 230] -> 
             RGBColor[
              0.9677526538461538, 0.9273816923076923, 0.6093079615384616], 
             UndirectedEdge[248, 319] -> 
             RGBColor[
              0.9611591538461538, 0.8713493846153846, 0.43626280769230763`], 
             UndirectedEdge[77, 111] -> 
             RGBColor[
              0.9868814615384616, 0.9674102307692306, 0.40353738461538435`], 
             UndirectedEdge[41, 188] -> 
             RGBColor[
              0.9934679615384615, 0.9906447692307693, 0.6908908846153845], 
             UndirectedEdge[57, 278] -> 
             RGBColor[
              0.9086996153846154, 0.929363076923077, 0.967808423076923], 
             UndirectedEdge[56, 331] -> 
             RGBColor[
              0.9715352692307693, 0.9597432307692306, 0.6656138076923075], 
             UndirectedEdge[40, 87] -> 
             RGBColor[
              0.9852851923076922, 0.9691475384615383, 0.6042578076923074], 
             UndirectedEdge[142, 214] -> 
             RGBColor[
              0.9274514999999999, 0.8485676923076921, 0.6269449615384615], 
             UndirectedEdge[341, 368] -> 
             RGBColor[
              0.9868814615384616, 0.9674102307692306, 0.40353738461538435`], 
             UndirectedEdge[96, 188] -> 
             RGBColor[
              0.9813698076923076, 0.9508903076923076, 0.5541438076923075], 
             UndirectedEdge[142, 202] -> 
             RGBColor[
              0.9049381153846152, 0.7532177692307691, 0.6085150384615384], 
             UndirectedEdge[37, 351] -> 
             RGBColor[
              0.9075261153846155, 0.9255783846153847, 0.8436387692307694], 
             UndirectedEdge[83, 108] -> 
             RGBColor[
              0.8163769999999999, 0.8566879999999999, 0.9453107307692308], 
             UndirectedEdge[72, 119] -> 
             RGBColor[
              0.9881640769230768, 0.9701536153846153, 0.5431421538461538], 
             UndirectedEdge[170, 180] -> 
             RGBColor[
              0.9050208846153847, 0.5626928461538462, 0.46724203846153844`], 
             UndirectedEdge[196, 234] -> 
             RGBColor[
              0.7318305769230768, 0.7695607692307691, 0.6670471538461537], 
             UndirectedEdge[218, 306] -> 
             RGBColor[0.8970252692307692, 0.558147, 0.5442448076923077], 
             UndirectedEdge[186, 189] -> 
             RGBColor[
              0.9723359615384615, 0.9305164615384616, 0.5888559615384616], 
             UndirectedEdge[20, 135] -> 
             RGBColor[
              0.9385456923076922, 0.9522569230769231, 0.9364258076923078], 
             UndirectedEdge[79, 254] -> 
             RGBColor[
              0.9224495384615384, 0.9387673846153846, 0.906452423076923], 
             UndirectedEdge[93, 355] -> 
             RGBColor[
              0.9769209999999999, 0.9322280769230769, 0.49946492307692325`], 
             UndirectedEdge[211, 301] -> 
             RGBColor[
              0.981259923076923, 0.9484474615384615, 0.381698769230769], 
             UndirectedEdge[145, 227] -> 
             RGBColor[
              0.936194423076923, 0.7759078461538462, 0.5254834615384614], 
             UndirectedEdge[26, 345] -> 
             RGBColor[
              0.922855423076923, 0.7400572307692308, 0.5683285384615384], 
             UndirectedEdge[132, 140] -> 
             RGBColor[
              0.9050208846153847, 0.5626928461538462, 0.46724203846153844`], 
             UndirectedEdge[153, 258] -> 
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079], 
             UndirectedEdge[56, 344] -> 
             RGBColor[
              0.9881640769230768, 0.9701536153846153, 0.5431421538461538], 
             UndirectedEdge[44, 390] -> 
             RGBColor[
              0.9307411538461539, 0.7421602307692308, 0.3188807307692307], 
             UndirectedEdge[223, 346] -> 
             RGBColor[
              0.6802758461538462, 0.7485966153846153, 0.9698333076923077], 
             UndirectedEdge[114, 222] -> 
             RGBColor[
              0.8773203076923077, 0.9032243076923077, 0.9020307307692307], 
             UndirectedEdge[85, 203] -> 
             RGBColor[
              0.9772666923076923, 0.9811488461538462, 0.8598974615384615], 
             UndirectedEdge[156, 261] -> 
             RGBColor[
              0.9927227692307692, 0.9912586923076924, 0.7702660769230769], 
             UndirectedEdge[33, 295] -> 
             RGBColor[
              0.9354108846153845, 0.8801239999999997, 0.6333492692307692], 
             UndirectedEdge[59, 395] -> 
             RGBColor[
              0.9377906923076923, 0.7741705384615385, 0.32476303846153837`], 
             UndirectedEdge[334, 371] -> 
             RGBColor[
              0.9755605384615385, 0.9804433076923078, 0.8881728461538461], 
             UndirectedEdge[40, 154] -> 
             RGBColor[
              0.9755605384615385, 0.9804433076923078, 0.8881728461538461], 
             UndirectedEdge[300, 306] -> 
             RGBColor[
              0.9830209999999999, 0.9860073076923077, 0.8755442307692307], 
             UndirectedEdge[61, 297] -> 
             RGBColor[
              0.6000656153846153, 0.6479127307692306, 0.658737269230769], 
             UndirectedEdge[97, 350] -> 
             RGBColor[
              0.7061680384615385, 0.748122846153846, 0.665193769230769], 
             UndirectedEdge[178, 229] -> 
             RGBColor[
              0.9813148461538461, 0.9853017692307693, 0.9038196153846154], 
             UndirectedEdge[130, 265] -> 
             RGBColor[
              0.9528317307692307, 0.9162536923076923, 0.6345651923076923], 
             UndirectedEdge[110, 134] -> 
             RGBColor[
              0.9715352692307693, 0.9597432307692306, 0.6656138076923075], 
             UndirectedEdge[147, 211] -> 
             RGBColor[0.9062435, 0.922835, 0.7040339999999999], 
             UndirectedEdge[78, 185] -> 
             RGBColor[
              0.9937856153846154, 0.9891163846153846, 0.5649807692307692], 
             UndirectedEdge[130, 135] -> 
             RGBColor[
              0.9723359615384615, 0.9305164615384616, 0.5888559615384616], 
             UndirectedEdge[52, 384] -> 
             RGBColor[
              0.9006219615384615, 0.9038722307692306, 0.6821953846153844], 
             UndirectedEdge[77, 166] -> 
             RGBColor[
              0.9771568076923077, 0.9787060000000001, 0.687452423076923], 
             UndirectedEdge[24, 76] -> 
             RGBColor[
              0.9570016538461538, 0.8705522307692307, 0.5721887692307692], 
             UndirectedEdge[100, 220] -> 
             RGBColor[0.9596504230769229, 0.9654202307692307, 0.709128], 
             UndirectedEdge[41, 369] -> 
             RGBColor[
              0.9877365384615384, 0.9692391538461538, 0.4966072307692305], 
             UndirectedEdge[12, 318] -> 
             RGBColor[
              0.9422756538461539, 0.9521396153846153, 0.7539649230769232], 
             UndirectedEdge[118, 199] -> 
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461], 
             UndirectedEdge[11, 205] -> 
             RGBColor[
              0.9760659230769231, 0.9303991538461538, 0.40639507692307697`], 
             UndirectedEdge[120, 136] -> 
             RGBColor[
              0.9691185384615384, 0.9029056923076921, 0.4426671153846153], 
             UndirectedEdge[66, 215] -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             UndirectedEdge[199, 287] -> 
             RGBColor[
              0.9161600769230769, 0.9349270769230769, 0.9551798076923077], 
             UndirectedEdge[8, 64] -> 
             RGBColor[
              0.9780118846153847, 0.9805349230769231, 0.7805222692307692], 
             UndirectedEdge[312, 361] -> 
             RGBColor[
              0.9075261153846155, 0.9255783846153847, 0.8436387692307694], 
             UndirectedEdge[5, 193] -> 
             RGBColor[
              0.9377906923076923, 0.7741705384615385, 0.32476303846153837`], 
             UndirectedEdge[187, 232] -> 
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153], 
             UndirectedEdge[115, 325] -> 
             RGBColor[
              0.9224495384615384, 0.9387673846153846, 0.906452423076923], 
             UndirectedEdge[137, 252] -> 
             RGBColor[
              0.8830783846153846, 0.5619680769230769, 0.22415007692307692`], 
             UndirectedEdge[296, 390] -> 
             RGBColor[
              0.795618576923077, 0.8357456923076922, 0.6934648461538461], 
             UndirectedEdge[101, 171] -> 
             RGBColor[0.9846172692307692, 0.98427, 0.6748238076923075], 
             UndirectedEdge[234, 342] -> 
             RGBColor[
              0.7383071923076923, 0.7903524615384615, 0.7819556153846153], 
             UndirectedEdge[56, 343] -> 
             RGBColor[
              0.9251196153846153, 0.7231974615384615, 0.2970421153846152], 
             UndirectedEdge[60, 146] -> 
             RGBColor[
              0.9086996153846154, 0.929363076923077, 0.967808423076923], 
             UndirectedEdge[149, 336] -> 
             RGBColor[
              0.9461228461538461, 0.8089242307692307, 0.4702501153846156], 
             UndirectedEdge[12, 199] -> 
             RGBColor[
              0.9850448076923077, 0.9851844615384615, 0.7213587307692308], 
             UndirectedEdge[42, 104] -> 
             RGBColor[
              0.8635703846153846, 0.8938200000000001, 0.9633867307692308], 
             UndirectedEdge[216, 323] -> 
             RGBColor[
              0.9691185384615384, 0.9029056923076921, 0.4426671153846153], 
             UndirectedEdge[110, 192] -> 
             RGBColor[
              0.9369985000000001, 0.8302971538461539, 0.5988650769230769], 
             UndirectedEdge[93, 380] -> 
             RGBColor[
              0.9390733076923077, 0.7769139230769231, 0.4643678076923079], 
             UndirectedEdge[34, 397] -> 
             RGBColor[
              0.8910211923076922, 0.6850533846153843, 0.5967077692307692], 
             UndirectedEdge[249, 308] -> 
             RGBColor[
              0.9176085769230768, 0.8659289230769229, 0.6316512692307692], 
             UndirectedEdge[116, 130] -> 
             RGBColor[
              0.7496707307692307, 0.7552463076923077, 0.6256594615384615], 
             UndirectedEdge[81, 315] -> 
             RGBColor[
              0.9701238846153846, 0.9740564615384615, 0.7466159615384615], 
             UndirectedEdge[99, 193] -> 
             RGBColor[
              0.9049381153846152, 0.7532177692307691, 0.6085150384615384], 
             UndirectedEdge[116, 135] -> 
             RGBColor[
              0.763232923076923, 0.8131663846153846, 0.9201711153846155], 
             UndirectedEdge[304, 378] -> 
             RGBColor[
              0.9029410769230769, 0.9238667692307692, 0.9330298076923078], 
             UndirectedEdge[56, 120] -> 
             RGBColor[
              0.9877365384615384, 0.9692391538461538, 0.4966072307692305], 
             UndirectedEdge[255, 393] -> 
             RGBColor[
              0.9418481153846154, 0.9512251538461538, 0.7074299999999999], 
             UndirectedEdge[106, 214] -> 
             RGBColor[
              0.9281051538461538, 0.752667923076923, 0.26100992307692306`], 
             UndirectedEdge[130, 328] -> 
             RGBColor[
              0.9513988461538461, 0.8441884615384614, 0.28408142307692297`], 
             UndirectedEdge[181, 250] -> 
             RGBColor[
              0.9580541538461538, 0.9671575384615384, 0.909848423076923], 
             UndirectedEdge[102, 230] -> 
             RGBColor[
              0.5778292692307692, 0.6437805000000001, 0.9288863076923077], 
             UndirectedEdge[45, 141] -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.8268168461538462], 
             UndirectedEdge[225, 288] -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 
             UndirectedEdge[208, 278] -> 
             RGBColor[
              0.9253284230769231, 0.9397734615384615, 0.8453367692307694], 
             UndirectedEdge[342, 346] -> 
             RGBColor[
              0.9070985769230769, 0.9246639230769231, 0.7971038461538461], 
             UndirectedEdge[133, 164] -> 
             RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076925], 
             UndirectedEdge[287, 373] -> 
             RGBColor[
              0.7831324615384615, 0.8307960769230769, 0.9789426153846154], 
             UndirectedEdge[122, 314] -> 
             RGBColor[
              0.9715352692307693, 0.9597432307692306, 0.6656138076923075], 
             UndirectedEdge[85, 351] -> 
             RGBColor[
              0.9063533846153846, 0.9252778461538462, 0.8764790384615384], 
             UndirectedEdge[5, 338] -> 
             RGBColor[
              0.9603040769230768, 0.8695204615384615, 0.34319296153846146`], 
             UndirectedEdge[311, 339] -> 
             RGBColor[
              0.9016898076923077, 0.8028163076923077, 0.6188426538461539], 
             UndirectedEdge[39, 324] -> 
             RGBColor[
              0.9917618076923076, 0.9899392307692307, 0.7191662692307691], 
             UndirectedEdge[52, 346] -> 
             RGBColor[
              0.9006219615384615, 0.9038722307692306, 0.6821953846153844], 
             UndirectedEdge[272, 291] -> 
             RGBColor[
              0.9291448846153846, 0.7438975384615385, 0.5196011538461538], 
             UndirectedEdge[191, 323] -> 
             RGBColor[
              0.9057660769230769, 0.5620789230769231, 0.38786684615384615`], 
             UndirectedEdge[60, 165] -> 
             RGBColor[
              0.9443042307692306, 0.9577532307692307, 0.971204423076923], 
             UndirectedEdge[44, 301] -> 
             RGBColor[
              0.919498076923077, 0.7042346923076923, 0.2752034999999999], 
             UndirectedEdge[11, 144] -> 
             RGBColor[
              0.9929305384615386, 0.9872874615384615, 0.47191092307692306`], 
             UndirectedEdge[333, 381] -> 
             RGBColor[
              0.9868814615384616, 0.9674102307692306, 0.40353738461538435`], 
             UndirectedEdge[9, 363] -> 
             RGBColor[
              0.8460639999999999, 0.8805342307692307, 0.9850623076923077], 
             UndirectedEdge[153, 312] -> 
             RGBColor[
              0.9075261153846155, 0.9255783846153847, 0.8436387692307694], 
             UndirectedEdge[55, 80] -> 
             RGBColor[
              0.9900556538461538, 0.9892336923076923, 0.7474416538461539], 
             UndirectedEdge[7, 40] -> 
             RGBColor[
              0.9876043076923076, 0.989142076923077, 0.8550922307692308], 
             UndirectedEdge[51, 377] -> 
             RGBColor[
              0.9946406923076923, 0.9909453076923077, 0.6580506153846155], 
             UndirectedEdge[112, 170] -> 
             RGBColor[
              0.9033147307692307, 0.5619873076923076, 0.495517423076923], 
             UndirectedEdge[200, 375] -> 
             RGBColor[0.9249835, 0.8943368461538461, 0.6419141538461538], 
             UndirectedEdge[94, 200] -> 
             RGBColor[
              0.773607846153846, 0.8236431538461537, 0.9779169230769231], 
             UndirectedEdge[8, 253] -> 
             RGBColor[
              0.9854723461538462, 0.986098923076923, 0.7678936538461538], 
             UndirectedEdge[31, 295] -> 
             RGBColor[
              0.9529172692307692, 0.8934097692307691, 0.6116736923076922], 
             UndirectedEdge[301, 383] -> 
             RGBColor[
              0.9584532692307692, 0.9352164615384615, 0.6564038076923076], 
             UndirectedEdge[327, 392] -> 
             RGBColor[
              0.9597603076923076, 0.9678630769230769, 0.8815730384615384], 
             UndirectedEdge[119, 375] -> 
             RGBColor[
              0.9769209999999999, 0.9322280769230769, 0.49946492307692325`], 
             UndirectedEdge[160, 340] -> 
             RGBColor[
              0.9153949615384616, 0.7344932307692309, 0.5809571538461538], 
             UndirectedEdge[151, 308] -> 
             RGBColor[
              0.9666671923076922, 0.9028140769230768, 0.5503176923076922], 
             UndirectedEdge[221, 276] -> 
             RGBColor[
              0.8936679230769231, 0.5223244615384615, 0.2511197692307691], 
             UndirectedEdge[94, 316] -> 
             RGBColor[
              0.8000231923076921, 0.773494769230769, 0.6200841923076923], 
             UndirectedEdge[195, 206] -> 
             RGBColor[
              0.9698062307692308, 0.9755848461538461, 0.8725260769230769], 
             UndirectedEdge[159, 192] -> 
             RGBColor[
              0.9536273076923076, 0.8407075384615386, 0.47639342307692334`], 
             UndirectedEdge[220, 350] -> 
             RGBColor[
              0.6789369999999999, 0.7461328461538461, 0.9707843846153846], 
             UndirectedEdge[229, 319] -> 
             RGBColor[
              0.9854723461538462, 0.986098923076923, 0.7678936538461538], 
             UndirectedEdge[69, 97] -> 
             RGBColor[
              0.9881640769230768, 0.9701536153846153, 0.5431421538461538], 
             UndirectedEdge[90, 317] -> 
             RGBColor[
              0.9369985000000001, 0.8302971538461539, 0.5988650769230769], 
             UndirectedEdge[136, 237] -> 
             RGBColor[
              0.9176085769230768, 0.8659289230769229, 0.6316512692307692], 
             UndirectedEdge[69, 141] -> 
             RGBColor[
              0.9904831923076922, 0.9901481538461538, 0.7939765769230772], 
             UndirectedEdge[48, 143] -> 
             RGBColor[
              0.9784394230769231, 0.9814493846153847, 0.8270571923076925], 
             UndirectedEdge[51, 246] -> 
             RGBColor[
              0.9386457692307693, 0.7759994615384616, 0.4178328846153846], 
             UndirectedEdge[97, 132] -> 
             RGBColor[
              0.9869913461538461, 0.9698530769230769, 0.5759824230769228], 
             UndirectedEdge[94, 383] -> 
             RGBColor[
              0.8014560769230769, 0.8455599999999999, 0.9705679615384615], 
             UndirectedEdge[246, 344] -> 
             RGBColor[
              0.9390733076923077, 0.7769139230769231, 0.4643678076923079], 
             UndirectedEdge[155, 354] -> 
             RGBColor[
              0.9075261153846155, 0.9255783846153847, 0.8436387692307694], 
             UndirectedEdge[107, 307] -> 
             RGBColor[0.8362434615384615, 0.872472, 0.9606630384615384], 
             UndirectedEdge[310, 363] -> 
             RGBColor[
              0.8561099230769231, 0.8882559999999999, 0.9760153461538461], 
             UndirectedEdge[99, 281] -> 
             RGBColor[
              0.9274514999999999, 0.8485676923076921, 0.6269449615384615], 
             UndirectedEdge[123, 187] -> 
             RGBColor[
              0.9692710769230769, 0.9766030000000001, 0.9369002307692307], 
             UndirectedEdge[23, 227] -> 
             RGBColor[
              0.9917618076923076, 0.9899392307692307, 0.7191662692307691], 
             UndirectedEdge[28, 211] -> 
             RGBColor[0.9846172692307692, 0.98427, 0.6748238076923075], 
             UndirectedEdge[327, 356] -> 
             RGBColor[
              0.9596504230769229, 0.9654202307692307, 0.7091279999999999], 
             UndirectedEdge[140, 219] -> 
             RGBColor[
              0.9057660769230769, 0.5620789230769231, 0.38786684615384615`], 
             UndirectedEdge[104, 144] -> 
             RGBColor[
              0.8789165769230769, 0.9014869999999999, 0.7013103076923076], 
             UndirectedEdge[49, 328] -> 
             RGBColor[
              0.9354108846153845, 0.8801239999999997, 0.6333492692307692], 
             UndirectedEdge[112, 271] -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 
             UndirectedEdge[106, 197] -> 
             RGBColor[
              0.9360645384615384, 0.7842242307692305, 0.2674142307692307], 
             UndirectedEdge[106, 204] -> 
             RGBColor[
              0.9587078076923077, 0.8712577692307693, 0.5439133846153845], 
             UndirectedEdge[50, 158] -> 
             RGBColor[
              0.9772666923076923, 0.9811488461538462, 0.8598974615384615], 
             UndirectedEdge[259, 299] -> 
             RGBColor[
              0.8347250384615383, 0.8232506923076923, 0.6330707692307691], 
             UndirectedEdge[79, 286] -> 
             RGBColor[
              0.9909067307692307, 0.9881103076923077, 0.6260964230769229], 
             UndirectedEdge[240, 388] -> 
             RGBColor[
              0.9368437692307692, 0.9521892307692307, 0.9838330384615385], 
             UndirectedEdge[118, 299] -> 
             RGBColor[0.8287829999999999, 0.866908, 0.9732916538461538], 
             UndirectedEdge[138, 257] -> 
             RGBColor[
              0.9876043076923076, 0.989142076923077, 0.8550922307692308], 
             UndirectedEdge[171, 244] -> 
             RGBColor[0.904911, 0.5602499999999999, 0.2947969999999999], 
             UndirectedEdge[161, 337] -> 
             RGBColor[
              0.9896281153846154, 0.9883192307692308, 0.7009067307692309], 
             UndirectedEdge[119, 355] -> 
             RGBColor[
              0.9769209999999999, 0.9322280769230769, 0.49946492307692325`], 
             UndirectedEdge[248, 292] -> 
             RGBColor[
              0.9615866923076923, 0.8722638461538461, 0.482797730769231], 
             UndirectedEdge[68, 386] -> 
             RGBColor[
              0.7649390769230768, 0.8138719230769231, 0.8918957307692307], 
             UndirectedEdge[126, 299] -> 
             RGBColor[
              0.8524447307692307, 0.8819679230769231, 0.7916564615384615], 
             UndirectedEdge[128, 383] -> 
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077], 
             UndirectedEdge[229, 248] -> 
             RGBColor[
              0.952418346153846, 0.8674174615384616, 0.5926407692307691], 
             UndirectedEdge[395, 396] -> 
             RGBColor[
              0.9321691538461538, 0.755207769230769, 0.3029244230769229], 
             UndirectedEdge[81, 292] -> 
             RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076925], 
             UndirectedEdge[34, 253] -> 
             RGBColor[
              0.9159880384615384, 0.7039031538461538, 0.5624035769230769], 
             UndirectedEdge[130, 322] -> 
             RGBColor[
              0.9756383846153847, 0.9294846923076923, 0.3598601538461537], 
             UndirectedEdge[74, 311] -> 
             RGBColor[
              0.5655288461538461, 0.5184666538461539, 0.5919885384615384], 
             UndirectedEdge[232, 235] -> 
             RGBColor[
              0.9830209999999999, 0.9860073076923077, 0.8755442307692307], 
             UndirectedEdge[207, 221] -> 
             RGBColor[0.8970252692307692, 0.558147, 0.5442448076923077], 
             UndirectedEdge[140, 216] -> 
             RGBColor[
              0.8806714615384614, 0.47495376923076904`, 0.21901826923076917`],
              UndirectedEdge[31, 173] -> 
             RGBColor[
              0.9602921923076924, 0.9218176923076924, 0.6219365769230768], 
             UndirectedEdge[37, 243] -> 
             RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076925], 
             UndirectedEdge[1, 35] -> 
             RGBColor[
              0.9854723461538462, 0.986098923076923, 0.7678936538461538], 
             UndirectedEdge[60, 210] -> 
             RGBColor[
              0.9755605384615385, 0.9804433076923078, 0.8881728461538461], 
             UndirectedEdge[35, 92] -> 
             RGBColor[
              0.9813148461538461, 0.9853017692307693, 0.9038196153846154], 
             UndirectedEdge[52, 291] -> 
             RGBColor[
              0.9251196153846153, 0.7231974615384615, 0.2970421153846152], 
             UndirectedEdge[77, 400] -> 
             RGBColor[
              0.9929305384615386, 0.9872874615384615, 0.47191092307692306`], 
             UndirectedEdge[77, 389] -> 
             RGBColor[
              0.8242627307692307, 0.8587909999999999, 0.6958629230769229], 
             UndirectedEdge[96, 361] -> 
             RGBColor[
              0.9825425384615385, 0.9511908461538461, 0.5213035384615385], 
             UndirectedEdge[150, 374] -> 
             RGBColor[
              0.9723359615384615, 0.9305164615384616, 0.5888559615384615], 
             UndirectedEdge[80, 154] -> 
             RGBColor[
              0.9738543846153846, 0.9797377692307693, 0.9164482307692308], 
             UndirectedEdge[200, 383] -> 
             RGBColor[
              0.9190414615384614, 0.9379941538461538, 0.9821350384615385], 
             UndirectedEdge[144, 391] -> 
             RGBColor[
              0.9868814615384616, 0.9674102307692306, 0.40353738461538435`], 
             UndirectedEdge[196, 290] -> 
             RGBColor[
              0.7899970384615385, 0.816782923076923, 0.6716262307692306], 
             UndirectedEdge[159, 228] -> 
             RGBColor[
              0.8801991923076924, 0.9042303846153845, 0.8409150769230771], 
             UndirectedEdge[27, 377] -> 
             RGBColor[
              0.9320237692307692, 0.7449036153846155, 0.4584855000000002], 
             UndirectedEdge[24, 233] -> 
             RGBColor[
              0.9563479999999999, 0.9664519999999999, 0.9381238076923077], 
             UndirectedEdge[24, 109] -> 
             RGBColor[
              0.9904831923076922, 0.9901481538461538, 0.7939765769230772], 
             UndirectedEdge[189, 255] -> 
             RGBColor[
              0.9385456923076922, 0.9522569230769231, 0.9364258076923078], 
             UndirectedEdge[262, 298] -> 
             RGBColor[0.9224445, 0.7665035384615385, 0.5868394615384614], 
             UndirectedEdge[249, 397] -> 
             RGBColor[0.9089955384615384, 0.9302723846153845, 0.991182], 
             UndirectedEdge[128, 324] -> 
             RGBColor[
              0.970551423076923, 0.974970923076923, 0.7931508846153845], 
             UndirectedEdge[7, 228] -> 
             RGBColor[
              0.8756141538461538, 0.9025187692307692, 0.9303061153846155], 
             UndirectedEdge[115, 258] -> 
             RGBColor[
              0.9241556923076923, 0.9394729230769231, 0.8781770384615384], 
             UndirectedEdge[375, 383] -> 
             RGBColor[
              0.9528317307692307, 0.9162536923076923, 0.6345651923076923], 
             UndirectedEdge[257, 338] -> 
             RGBColor[
              0.9587078076923077, 0.8712577692307693, 0.5439133846153845], 
             UndirectedEdge[5, 321] -> 
             RGBColor[
              0.9937856153846154, 0.9891163846153845, 0.5649807692307693], 
             UndirectedEdge[65, 239] -> 
             RGBColor[
              0.9692710769230769, 0.9766030000000001, 0.9369002307692307], 
             UndirectedEdge[56, 71] -> 
             RGBColor[
              0.9715352692307693, 0.9597432307692306, 0.6656138076923075], 
             UndirectedEdge[276, 322] -> 
             RGBColor[
              0.981259923076923, 0.9484474615384615, 0.381698769230769], 
             UndirectedEdge[239, 326] -> 
             RGBColor[
              0.9780118846153847, 0.9805349230769231, 0.7805222692307692], 
             UndirectedEdge[379, 393] -> 
             RGBColor[
              0.9868814615384616, 0.9674102307692306, 0.40353738461538435`], 
             UndirectedEdge[131, 262] -> 
             RGBColor[
              0.9602921923076924, 0.9218176923076924, 0.6219365769230769], 
             UndirectedEdge[201, 210] -> 
             RGBColor[
              0.8773203076923077, 0.9032243076923077, 0.9020307307692307], 
             UndirectedEdge[301, 372] -> 
             RGBColor[
              0.9570203846153845, 0.8631512307692305, 0.30592003846153826`], 
             UndirectedEdge[291, 398] -> 
             RGBColor[
              0.8830783846153846, 0.5619680769230769, 0.22415007692307692`], 
             UndirectedEdge[28, 49] -> 
             RGBColor[
              0.9517646923076921, 0.9633172307692307, 0.9585758076923077], 
             UndirectedEdge[6, 160] -> 
             RGBColor[
              0.8444816538461539, 0.6786222307692309, 0.5975387307692308], 
             UndirectedEdge[375, 379] -> 
             RGBColor[
              0.9700168461538461, 0.9105219230769229, 0.33802153846153826`], 
             UndirectedEdge[45, 112] -> 
             RGBColor[
              0.9910166153846154, 0.9905531538461538, 0.7985414615384614], 
             UndirectedEdge[324, 390] -> 
             RGBColor[
              0.993358076923077, 0.988201923076923, 0.518445846153846], 
             UndirectedEdge[169, 227] -> 
             RGBColor[
              0.9432439615384615, 0.8079181538461537, 0.5313657692307692], 
             UndirectedEdge[44, 380] -> 
             RGBColor[
              0.8760288461538461, 0.5299577692307693, 0.21826776923076924`], 
             UndirectedEdge[288, 360] -> 
             RGBColor[
              0.9666671923076922, 0.9028140769230768, 0.5503176923076922], 
             UndirectedEdge[87, 134] -> 
             RGBColor[
              0.981259923076923, 0.9484474615384613, 0.38169876923076884`], 
             UndirectedEdge[85, 258] -> 
             RGBColor[
              0.9927227692307692, 0.9912586923076924, 0.7702660769230769], 
             UndirectedEdge[26, 77] -> 
             RGBColor[0.9846172692307692, 0.98427, 0.6748238076923075], 
             UndirectedEdge[90, 333] -> 
             RGBColor[
              0.9771568076923077, 0.9787060000000001, 0.6874524230769229], 
             UndirectedEdge[45, 91] -> 
             RGBColor[
              0.9927227692307692, 0.9912586923076924, 0.7702660769230769], 
             UndirectedEdge[103, 133] -> 
             RGBColor[
              0.9921893461538461, 0.9908536923076923, 0.7657011923076924], 
             UndirectedEdge[143, 342] -> 
             RGBColor[
              0.9780118846153847, 0.9805349230769231, 0.7805222692307692], 
             UndirectedEdge[75, 164] -> 
             RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076925], 
             UndirectedEdge[44, 211] -> 
             RGBColor[
              0.9307411538461539, 0.7421602307692308, 0.3188807307692307], 
             UndirectedEdge[82, 171] -> 
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998], 
             UndirectedEdge[17, 122] -> 
             RGBColor[
              0.9877365384615384, 0.9692391538461538, 0.4966072307692305], 
             UndirectedEdge[150, 186] -> 
             RGBColor[
              0.9723359615384615, 0.9305164615384616, 0.5888559615384615], 
             UndirectedEdge[180, 394] -> 
             RGBColor[
              0.9927227692307692, 0.9912586923076924, 0.7702660769230769], 
             UndirectedEdge[156, 202] -> 
             RGBColor[
              0.9379005769230768, 0.7766133846153846, 0.4972080769230769], 
             UndirectedEdge[86, 178] -> 
             RGBColor[
              0.966393923076923, 0.9741737692307693, 0.9290768461538462], 
             UndirectedEdge[102, 250] -> 
             RGBColor[
              0.5841187307692308, 0.6476208076923078, 0.880158923076923], 
             UndirectedEdge[7, 222] -> 
             RGBColor[
              0.8756141538461538, 0.9025187692307692, 0.9303061153846155], 
             UndirectedEdge[97, 220] -> 
             RGBColor[
              0.9540288846153845, 0.9464574615384613, 0.6872893846153845], 
             UndirectedEdge[230, 289] -> 
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153], 
             UndirectedEdge[14, 289] -> 
             RGBColor[0.8710308461538461, 0.899384, 0.9507581153846154], 
             UndirectedEdge[77, 370] -> 
             RGBColor[0.9062435, 0.922835, 0.7040339999999998], 
             UndirectedEdge[151, 270] -> 
             RGBColor[0.9740421153846153, 0.931222, 0.5605805769230768], 
             UndirectedEdge[173, 214] -> 
             RGBColor[
              0.9434394615384615, 0.8126321538461538, 0.27767711538461537`], 
             UndirectedEdge[144, 317] -> 
             RGBColor[
              0.9523446923076924, 0.8379641538461539, 0.33678865384615375`], 
             UndirectedEdge[31, 175] -> 
             RGBColor[
              0.9738543846153846, 0.9797377692307693, 0.9164482307692308], 
             UndirectedEdge[163, 240] -> 
             RGBColor[
              0.9119876538461538, 0.7852280769230768, 0.6143973461538461], 
             UndirectedEdge[329, 371] -> 
             RGBColor[
              0.9921893461538461, 0.9908536923076923, 0.7657011923076924], 
             UndirectedEdge[72, 375] -> 
             RGBColor[
              0.9700168461538461, 0.9105219230769229, 0.33802153846153826`], 
             UndirectedEdge[32, 238] -> 
             RGBColor[
              0.9379005769230768, 0.7766133846153846, 0.49720807692307695`], 
             UndirectedEdge[11, 14] -> 
             RGBColor[
              0.8793441153846154, 0.9024014615384615, 0.7478452307692308], 
             UndirectedEdge[79, 237] -> 
             RGBColor[
              0.940251846153846, 0.9529624615384615, 0.9081504230769231], 
             UndirectedEdge[69, 74] -> 
             RGBColor[
              0.6069697692307692, 0.6696188846153845, 0.820180653846154], 
             UndirectedEdge[16, 203] -> 
             RGBColor[
              0.8635703846153846, 0.8938200000000001, 0.9633867307692308], 
             UndirectedEdge[315, 319] -> 
             RGBColor[
              0.970551423076923, 0.974970923076923, 0.7931508846153845], 
             UndirectedEdge[40, 80] -> 
             RGBColor[
              0.9876043076923076, 0.989142076923077, 0.8550922307692308], 
             UndirectedEdge[18, 198] -> 
             RGBColor[
              0.9142504230769231, 0.6584525384615385, 0.5358986538461539], 
             UndirectedEdge[300, 307] -> 
             RGBColor[
              0.8499933846153845, 0.8818763076923077, 0.8993070384615384], 
             UndirectedEdge[191, 198] -> 
             RGBColor[
              0.8299608461538461, 0.23129776923076925`, 0.17632384615384616`],
              UndirectedEdge[289, 391] -> 
             RGBColor[
              0.9789957307692307, 0.9653072307692306, 0.6529851923076921], 
             UndirectedEdge[132, 357] -> 
             RGBColor[
              0.9063533846153846, 0.9252778461538462, 0.8764790384615384], 
             UndirectedEdge[157, 187] -> 
             RGBColor[
              0.9830209999999999, 0.9860073076923077, 0.8755442307692307], 
             UndirectedEdge[38, 250] -> 
             RGBColor[
              0.9033147307692307, 0.5619873076923076, 0.49551742307692304`], 
             UndirectedEdge[140, 191] -> 
             RGBColor[0.817319, 0.134127, 0.164218], UndirectedEdge[204, 261] -> 
             RGBColor[
              0.9910166153846154, 0.9905531538461538, 0.7985414615384614], 
             UndirectedEdge[337, 354] -> 
             RGBColor[
              0.9029410769230769, 0.9238667692307692, 0.9330298076923078], 
             UndirectedEdge[300, 314] -> 
             RGBColor[
              0.9755605384615385, 0.9804433076923078, 0.8881728461538461], 
             UndirectedEdge[292, 378] -> 
             RGBColor[
              0.9904831923076922, 0.9901481538461538, 0.7939765769230772], 
             UndirectedEdge[153, 361] -> 
             RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 
             UndirectedEdge[240, 334] -> 
             RGBColor[
              0.9443042307692306, 0.9577532307692307, 0.971204423076923], 
             UndirectedEdge[52, 260] -> 
             RGBColor[
              0.9789957307692307, 0.9653072307692306, 0.6529851923076921], 
             UndirectedEdge[128, 177] -> 
             RGBColor[0.8834368461538462, 0.909604, 0.9787390384615384], 
             UndirectedEdge[16, 85] -> 
             RGBColor[
              0.8790264615384615, 0.9039298461538461, 0.8737553461538461], 
             UndirectedEdge[179, 303] -> 
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077], 
             UndirectedEdge[48, 320] -> 
             RGBColor[
              0.8528722692307692, 0.8828823846153846, 0.8381913846153848], 
             UndirectedEdge[136, 320] -> 
             RGBColor[
              0.8273501153846152, 0.794842769230769, 0.6228078846153846], 
             UndirectedEdge[96, 192] -> 
             RGBColor[
              0.9411016153846153, 0.8000386153846153, 0.29311142307692295`], 
             UndirectedEdge[140, 357] -> 
             RGBColor[0.8186515000000001, 0.496712, 0.573455], 
             UndirectedEdge[202, 306] -> 
             RGBColor[
              0.9299049615384615, 0.7720675384615385, 0.5742108461538462], 
             UndirectedEdge[114, 258] -> 
             RGBColor[
              0.9910166153846154, 0.9905531538461538, 0.7985414615384614], 
             UndirectedEdge[87, 236] -> 
             RGBColor[
              0.981259923076923, 0.9484474615384613, 0.38169876923076884`], 
             UndirectedEdge[116, 362] -> 
             RGBColor[
              0.7673904230769231, 0.8139635384615385, 0.7842451538461538], 
             UndirectedEdge[36, 64] -> 
             RGBColor[
              0.9659137307692307, 0.9407804615384615, 0.6437751923076922], 
             UndirectedEdge[245, 304] -> 
             RGBColor[0.8834368461538462, 0.909604, 0.9787390384615384], 
             UndirectedEdge[187, 218] -> 
             RGBColor[0.8970252692307692, 0.558147, 0.5442448076923077], 
             UndirectedEdge[26, 370] -> 
             RGBColor[0.8983577692307692, 0.920732, 0.9534818076923077], 
             UndirectedEdge[91, 141] -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.8268168461538462], 
             UndirectedEdge[55, 385] -> 
             RGBColor[
              0.9917618076923076, 0.9899392307692307, 0.7191662692307691], 
             UndirectedEdge[179, 231] -> 
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077], 
             UndirectedEdge[94, 177] -> 
             RGBColor[0.7380032307692308, 0.795253, 0.9745209230769231], 
             UndirectedEdge[225, 383] -> 
             RGBColor[
              0.9681000769230769, 0.9748793076923077, 0.9008014615384614], 
             UndirectedEdge[37, 134] -> 
             RGBColor[
              0.9881640769230768, 0.9701536153846153, 0.5431421538461538], 
             UndirectedEdge[255, 341] -> 
             RGBColor[
              0.9418481153846154, 0.9512251538461538, 0.7074299999999999], 
             UndirectedEdge[206, 278] -> 
             RGBColor[
              0.9241556923076923, 0.9394729230769231, 0.8781770384615384], 
             UndirectedEdge[131, 279] -> 
             RGBColor[
              0.9764934615384615, 0.9313136153846153, 0.45292999999999994`], 
             UndirectedEdge[7, 203] -> 
             RGBColor[
              0.9738543846153846, 0.9797377692307693, 0.9164482307692308], 
             UndirectedEdge[101, 151] -> 
             RGBColor[
              0.9830209999999999, 0.9860073076923077, 0.8755442307692307], 
             UndirectedEdge[200, 296] -> 
             RGBColor[
              0.7449636923076923, 0.8005978461538461, 0.9755188461538462], 
             UndirectedEdge[86, 229] -> 
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461], 
             UndirectedEdge[138, 382] -> 
             RGBColor[
              0.9779574999999999, 0.9494792307692307, 0.6106945769230768], 
             UndirectedEdge[195, 278] -> 
             RGBColor[
              0.9012391538461538, 0.9237990769230768, 0.9804370384615384], 
             UndirectedEdge[65, 113] -> 
             RGBColor[
              0.9603777307692307, 0.8989737692307691, 0.5990450769230768], 
             UndirectedEdge[249, 270] -> 
             RGBColor[0.9249835, 0.8943368461538461, 0.6419141538461538], 
             UndirectedEdge[319, 388] -> 
             RGBColor[
              0.970551423076923, 0.974970923076923, 0.7931508846153845], 
             UndirectedEdge[138, 256] -> 
             RGBColor[
              0.9207433846153845, 0.9380618461538461, 0.9347278076923078], 
             UndirectedEdge[246, 286] -> 
             RGBColor[
              0.9377906923076923, 0.7741705384615385, 0.32476303846153837`], 
             UndirectedEdge[188, 208] -> 
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079], 
             UndirectedEdge[173, 345] -> 
             RGBColor[
              0.9138765384615384, 0.6852719230769231, 0.2533648846153846], 
             UndirectedEdge[84, 156] -> 
             RGBColor[
              0.9241556923076923, 0.9394729230769231, 0.8781770384615384], 
             UndirectedEdge[136, 349] -> 
             RGBColor[
              0.9695460769230768, 0.9038201538461537, 0.48920203846153865`], 
             UndirectedEdge[117, 346] -> 
             RGBColor[
              0.9070985769230769, 0.9246639230769231, 0.7971038461538461], 
             UndirectedEdge[26, 197] -> 
             RGBColor[
              0.9603777307692307, 0.8989737692307691, 0.5990450769230768], 
             UndirectedEdge[328, 362] -> 
             RGBColor[
              0.9691185384615384, 0.9029056923076921, 0.4426671153846153], 
             UndirectedEdge[187, 275] -> 
             RGBColor[
              0.952418346153846, 0.8674174615384616, 0.5926407692307691], 
             UndirectedEdge[20, 121] -> 
             RGBColor[
              0.9422756538461539, 0.9521396153846153, 0.7539649230769232], 
             UndirectedEdge[198, 302] -> 
             RGBColor[
              0.8312933461538462, 0.5938827692307693, 0.5855608461538462], 
             UndirectedEdge[1, 312] -> 
             RGBColor[
              0.9070985769230769, 0.9246639230769231, 0.7971038461538461], 
             UndirectedEdge[89, 292] -> 
             RGBColor[
              0.9881640769230768, 0.9701536153846153, 0.5431421538461538], 
             UndirectedEdge[304, 315] -> 
             RGBColor[0.8834368461538462, 0.909604, 0.9787390384615384], 
             UndirectedEdge[21, 64] -> 
             RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 
             UndirectedEdge[201, 351] -> 
             RGBColor[
              0.792657076923077, 0.8379489999999999, 0.9799683076923077], 
             UndirectedEdge[17, 218] -> 
             RGBColor[
              0.9057660769230769, 0.5620789230769231, 0.3878668461538461], 
             UndirectedEdge[266, 365] -> 
             RGBColor[
              0.981259923076923, 0.9484474615384615, 0.381698769230769], 
             UndirectedEdge[112, 180] -> 
             RGBColor[
              0.9910166153846154, 0.9905531538461538, 0.7985414615384614], 
             UndirectedEdge[247, 289] -> 
             RGBColor[
              0.9339623846153846, 0.9491221538461538, 0.9568778076923077], 
             UndirectedEdge[15, 45] -> 
             RGBColor[
              0.9683733461538461, 0.9035196153846152, 0.5220423076923076], 
             UndirectedEdge[57, 92] -> 
             RGBColor[
              0.9738543846153846, 0.9797377692307693, 0.9164482307692308], 
             UndirectedEdge[53, 86] -> 
             RGBColor[0.9696963461538461, 0.973142, 0.7000810384615384], 
             UndirectedEdge[114, 154] -> 
             RGBColor[
              0.9755605384615385, 0.9804433076923078, 0.8881728461538461], 
             UndirectedEdge[71, 237] -> 
             RGBColor[
              0.9265019230769231, 0.9435581538461539, 0.969506423076923], 
             UndirectedEdge[241, 375] -> 
             RGBColor[
              0.9764934615384615, 0.9313136153846153, 0.45292999999999994`], 
             UndirectedEdge[100, 282] -> 
             RGBColor[
              0.9240458076923077, 0.9370300769230768, 0.7057319999999998], 
             UndirectedEdge[55, 146] -> 
             RGBColor[0.9249008846153846, 0.938859, 0.7988018461538461], 
             UndirectedEdge[309, 319] -> 
             RGBColor[
              0.7964736538461539, 0.8375746153846154, 0.7865346923076922], 
             UndirectedEdge[13, 302] -> 
             RGBColor[
              0.8555886153846154, 0.8876871538461538, 0.9860880000000001], 
             UndirectedEdge[110, 348] -> 
             RGBColor[
              0.9772666923076923, 0.9811488461538462, 0.8598974615384615], 
             UndirectedEdge[217, 363] -> 
             RGBColor[
              0.8801991923076924, 0.9042303846153845, 0.8409150769230771], 
             UndirectedEdge[39, 380] -> 
             RGBColor[
              0.936194423076923, 0.7759078461538462, 0.5254834615384615], 
             UndirectedEdge[248, 304] -> 
             RGBColor[
              0.8740445769230769, 0.8059824615384614, 0.6218509615384615], 
             UndirectedEdge[204, 400] -> 
             RGBColor[
              0.9913342692307692, 0.9890247692307692, 0.6726313461538461], 
             UndirectedEdge[69, 168] -> 
             RGBColor[
              0.8255453461538461, 0.8615343846153846, 0.8354676923076925], 
             UndirectedEdge[68, 86] -> 
             RGBColor[
              0.7437286923076922, 0.7989036153846154, 0.9658803461538461], 
             UndirectedEdge[175, 264] -> 
             RGBColor[
              0.9385456923076922, 0.9522569230769231, 0.9364258076923078], 
             UndirectedEdge[1, 92] -> 
             RGBColor[
              0.9900556538461538, 0.9892336923076923, 0.7474416538461539], 
             UndirectedEdge[368, 393] -> 
             RGBColor[
              0.9868814615384616, 0.9674102307692306, 0.40353738461538435`], 
             UndirectedEdge[332, 361] -> 
             RGBColor[
              0.9609330384615384, 0.9681636153846154, 0.8487327692307695], 
             UndirectedEdge[80, 203] -> 
             RGBColor[
              0.9738543846153846, 0.9797377692307693, 0.9164482307692308], 
             UndirectedEdge[20, 347] -> 
             RGBColor[
              0.894185346153846, 0.7710329999999999, 0.6126993461538461], 
             UndirectedEdge[18, 311] -> 
             RGBColor[
              0.9490422692307692, 0.8389959230769231, 0.5657844615384616], 
             UndirectedEdge[170, 282] -> 
             RGBColor[0.8364538076923077, 0.5109070769230769, 0.575153], 
             UndirectedEdge[198, 323] -> 
             RGBColor[
              0.9184079230769231, 0.6592496923076923, 0.3999726923076923], 
             UndirectedEdge[168, 357] -> 
             RGBColor[0.7380032307692308, 0.795253, 0.9745209230769231], 
             UndirectedEdge[180, 326] -> 
             RGBColor[
              0.9934679615384615, 0.9906447692307693, 0.6908908846153845], 
             UndirectedEdge[18, 340] -> 
             RGBColor[
              0.9738543846153846, 0.9797377692307693, 0.9164482307692308], 
             UndirectedEdge[74, 340] -> 
             RGBColor[
              0.5903409615384615, 0.6592085000000001, 0.9426523076923077], 
             UndirectedEdge[173, 204] -> 
             RGBColor[0.9740421153846153, 0.931222, 0.5605805769230767], 
             UndirectedEdge[26, 30] -> 
             RGBColor[0.9846172692307692, 0.98427, 0.6748238076923075], 
             UndirectedEdge[169, 240] -> 
             RGBColor[
              0.9119876538461538, 0.7852280769230768, 0.6143973461538461], 
             UndirectedEdge[95, 371] -> 
             RGBColor[
              0.9755605384615385, 0.9804433076923078, 0.8881728461538461], 
             UndirectedEdge[65, 356] -> 
             RGBColor[0.9846172692307692, 0.98427, 0.6748238076923075], 
             UndirectedEdge[264, 310] -> 
             RGBColor[
              0.9190414615384614, 0.9379941538461538, 0.9821350384615385], 
             UndirectedEdge[96, 114] -> 
             RGBColor[
              0.9796636538461538, 0.9501847692307692, 0.5824191923076921], 
             UndirectedEdge[244, 308] -> 
             RGBColor[
              0.8806714615384614, 0.47495376923076904`, 0.21901826923076917`],
              UndirectedEdge[187, 298] -> 
             RGBColor[
              0.9299049615384615, 0.7720675384615385, 0.5742108461538461], 
             UndirectedEdge[58, 228] -> 
             RGBColor[
              0.8282616923076923, 0.8663391538461538, 0.9833643076923078], 
             UndirectedEdge[36, 82] -> 
             RGBColor[
              0.981259923076923, 0.9484474615384615, 0.381698769230769], 
             UndirectedEdge[72, 355] -> 
             RGBColor[
              0.9700168461538461, 0.9105219230769229, 0.33802153846153826`], 
             UndirectedEdge[22, 350] -> 
             RGBColor[
              0.7101933076923077, 0.7688229230769231, 0.8877528076923076], 
             UndirectedEdge[58, 192] -> 
             RGBColor[
              0.9016898076923077, 0.8028163076923077, 0.6188426538461539], 
             UndirectedEdge[3, 174] -> 
             RGBColor[
              0.9016898076923077, 0.8028163076923077, 0.6188426538461539], 
             UndirectedEdge[44, 54] -> 
             RGBColor[
              0.9274387307692307, 0.7431920000000001, 0.5478765384615385], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.9659137307692307, 0.9407804615384615, 0.6437751923076921], 
             UndirectedEdge[170, 271] -> 
             RGBColor[
              0.9033147307692307, 0.5619873076923076, 0.49551742307692304`], 
             UndirectedEdge[192, 201] -> 
             RGBColor[
              0.8387582692307692, 0.7530781538461538, 0.6127229615384615], 
             UndirectedEdge[274, 395] -> 
             RGBColor[
              0.9135511538461538, 0.6888743076923075, 0.24898430769230764`], 
             UndirectedEdge[208, 284] -> 
             RGBColor[
              0.9615866923076923, 0.8722638461538461, 0.482797730769231], 
             UndirectedEdge[237, 320] -> 
             RGBColor[
              0.8009347692307691, 0.8449911538461539, 0.9806406153846154], 
             UndirectedEdge[119, 380] -> 
             RGBColor[
              0.9390733076923077, 0.7769139230769231, 0.4643678076923079], 
             UndirectedEdge[342, 398] -> 
             RGBColor[
              0.9456953076923076, 0.8080097692307692, 0.4237151923076922], 
             UndirectedEdge[90, 264] -> 
             RGBColor[
              0.9265019230769231, 0.9435581538461539, 0.969506423076923], 
             UndirectedEdge[212, 367] -> 
             RGBColor[
              0.9868814615384616, 0.9674102307692306, 0.40353738461538435`], 
             UndirectedEdge[92, 284] -> 
             RGBColor[
              0.9570016538461538, 0.8705522307692307, 0.5721887692307692], 
             UndirectedEdge[267, 342] -> 
             RGBColor[
              0.9386457692307693, 0.7759994615384616, 0.4178328846153846], 
             UndirectedEdge[107, 297] -> 
             RGBColor[
              0.9715352692307693, 0.9597432307692306, 0.6656138076923075], 
             UndirectedEdge[163, 245] -> 
             RGBColor[
              0.9220335769230769, 0.792949846153846, 0.6053503846153846], 
             UndirectedEdge[72, 200] -> 
             RGBColor[
              0.9362265769230769, 0.9322623846153845, 0.6855913846153845], 
             UndirectedEdge[254, 286] -> 
             RGBColor[
              0.9240458076923077, 0.9370300769230768, 0.7057319999999999], 
             UndirectedEdge[269, 307] -> 
             RGBColor[
              0.6547052307692307, 0.7295116923076923, 0.9666754615384615], 
             UndirectedEdge[240, 304] -> 
             RGBColor[0.873390923076923, 0.9018822307692307, 0.987786], 
             UndirectedEdge[228, 332] -> 
             RGBColor[
              0.8460639999999999, 0.8805342307692307, 0.9850623076923077], 
             UndirectedEdge[104, 109] -> 
             RGBColor[
              0.8801991923076924, 0.9042303846153845, 0.8409150769230771], 
             UndirectedEdge[28, 372] -> 
             RGBColor[
              0.9603777307692307, 0.8989737692307691, 0.5990450769230768], 
             UndirectedEdge[28, 362] -> 
             RGBColor[
              0.9854723461538462, 0.986098923076923, 0.7678936538461538], 
             UndirectedEdge[209, 227] -> 
             RGBColor[
              0.940251846153846, 0.9529624615384615, 0.9081504230769231], 
             UndirectedEdge[245, 371] -> 
             RGBColor[
              0.9681000769230769, 0.9748793076923077, 0.9008014615384614], 
             UndirectedEdge[308, 397] -> 
             RGBColor[
              0.9354108846153845, 0.8801239999999997, 0.6333492692307692], 
             UndirectedEdge[58, 87] -> 
             RGBColor[
              0.9362265769230769, 0.9322623846153845, 0.6855913846153845], 
             UndirectedEdge[154, 332] -> 
             RGBColor[
              0.9443042307692306, 0.9577532307692307, 0.971204423076923], 
             UndirectedEdge[97, 180] -> 
             RGBColor[
              0.9869913461538461, 0.9698530769230769, 0.5759824230769228], 
             UndirectedEdge[202, 300] -> 
             RGBColor[
              0.936194423076923, 0.7759078461538462, 0.5254834615384614], 
             UndirectedEdge[25, 317] -> 
             RGBColor[
              0.9536273076923076, 0.8407075384615386, 0.47639342307692334`], 
             UndirectedEdge[93, 128] -> 
             RGBColor[
              0.9709789615384615, 0.9758853846153845, 0.8396858076923079], 
             UndirectedEdge[68, 178] -> 
             RGBColor[
              0.763232923076923, 0.8131663846153846, 0.9201711153846155], 
             UndirectedEdge[271, 273] -> 
             RGBColor[
              0.9910166153846154, 0.9905531538461538, 0.7985414615384614], 
             UndirectedEdge[149, 318] -> 
             RGBColor[
              0.894185346153846, 0.7710329999999999, 0.6126993461538461], 
             UndirectedEdge[42, 358] -> 
             RGBColor[
              0.9294940384615384, 0.7985138461538461, 0.5927217692307691], 
             UndirectedEdge[155, 170] -> 
             RGBColor[
              0.9061936153846154, 0.5629933846153846, 0.43440176923076945`], 
             UndirectedEdge[193, 338] -> 
             RGBColor[0.9055917692307691, 0.657318, 0.24258], 
             UndirectedEdge[79, 109] -> 
             RGBColor[
              0.9921893461538461, 0.9908536923076923, 0.7657011923076924], 
             UndirectedEdge[173, 175] -> 
             RGBColor[
              0.9723359615384615, 0.9305164615384616, 0.5888559615384616], 
             UndirectedEdge[95, 178] -> 
             RGBColor[
              0.9738543846153846, 0.9797377692307693, 0.9164482307692308], 
             UndirectedEdge[243, 348] -> 
             RGBColor[
              0.9930404230769231, 0.9897303076923077, 0.6443559615384615], 
             UndirectedEdge[56, 83] -> 
             RGBColor[
              0.8186411923076922, 0.8398282307692306, 0.6740243076923075], 
             UndirectedEdge[205, 207] -> 
             RGBColor[
              0.9677526538461538, 0.9273816923076923, 0.6093079615384616], 
             UndirectedEdge[74, 302] -> 
             RGBColor[0.5194276538461539, 0.6033375, 0.9592338846153846], 
             UndirectedEdge[179, 196] -> 
             RGBColor[
              0.9640748076923076, 0.9541792307692306, 0.6782424230769228], 
             UndirectedEdge[174, 338] -> 
             RGBColor[
              0.9096491923076923, 0.8343726153846154, 0.6252469615384615], 
             UndirectedEdge[159, 167] -> 
             RGBColor[
              0.9709789615384615, 0.9758853846153845, 0.8396858076923079], 
             UndirectedEdge[251, 356] -> 
             RGBColor[
              0.989200576923077, 0.9874047692307693, 0.6543718076923076], 
             UndirectedEdge[238, 277] -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.8268168461538462], 
             UndirectedEdge[163, 164] -> 
             RGBColor[
              0.9452677692307692, 0.8070953076923076, 0.3771802692307693], 
             UndirectedEdge[213, 230] -> 
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461], 
             UndirectedEdge[246, 343] -> 
             RGBColor[
              0.8760288461538461, 0.5299577692307693, 0.21826776923076924`], 
             UndirectedEdge[53, 95] -> 
             RGBColor[
              0.9771568076923077, 0.9787060000000001, 0.687452423076923], 
             UndirectedEdge[139, 184] -> 
             RGBColor[
              0.9418481153846154, 0.9512251538461538, 0.7074299999999999], 
             UndirectedEdge[101, 308] -> 
             RGBColor[
              0.9603777307692307, 0.8989737692307691, 0.5990450769230768], 
             UndirectedEdge[3, 52] -> 
             RGBColor[
              0.9467231538461538, 0.8190013846153845, 0.3149500384615383], 
             UndirectedEdge[136, 286] -> 
             RGBColor[
              0.9682634615384615, 0.9010767692307691, 0.34959726923076906`], 
             UndirectedEdge[164, 169] -> 
             RGBColor[
              0.9452677692307692, 0.8070953076923076, 0.37718026923076925`], 
             UndirectedEdge[14, 102] -> 
             RGBColor[
              0.47212857692307697`, 0.5609974999999999, 0.9553728076923077], 
             UndirectedEdge[232, 281] -> 
             RGBColor[
              0.952418346153846, 0.8674174615384616, 0.5926407692307691], 
             UndirectedEdge[56, 349] -> 
             RGBColor[
              0.9881640769230768, 0.9701536153846153, 0.5431421538461538], 
             UndirectedEdge[225, 324] -> 
             RGBColor[
              0.9917618076923076, 0.9899392307692307, 0.7191662692307691], 
             UndirectedEdge[5, 272] -> 
             RGBColor[
              0.9909067307692307, 0.9881103076923077, 0.6260964230769229], 
             UndirectedEdge[68, 371] -> 
             RGBColor[
              0.7649390769230768, 0.8138719230769231, 0.8918957307692307], 
             UndirectedEdge[151, 397] -> 
             RGBColor[
              0.9580541538461538, 0.9671575384615384, 0.909848423076923], 
             UndirectedEdge[1, 356] -> 
             RGBColor[
              0.993358076923077, 0.988201923076923, 0.518445846153846], 
             UndirectedEdge[96, 115] -> 
             RGBColor[
              0.9128027307692308, 0.8991045384615384, 0.662054769230769], 
             UndirectedEdge[328, 347] -> 
             RGBColor[
              0.9206006923076921, 0.7208846153846151, 0.2548666153846153], 
             UndirectedEdge[80, 159] -> 
             RGBColor[
              0.9904831923076922, 0.9901481538461538, 0.7939765769230772], 
             UndirectedEdge[50, 121] -> 
             RGBColor[
              0.9930404230769231, 0.9897303076923077, 0.6443559615384615], 
             UndirectedEdge[108, 342] -> 
             RGBColor[
              0.9854723461538462, 0.986098923076923, 0.7678936538461538], 
             UndirectedEdge[178, 315] -> 
             RGBColor[
              0.966393923076923, 0.9741737692307693, 0.9290768461538462], 
             UndirectedEdge[146, 228] -> 
             RGBColor[
              0.8104593846153847, 0.8521440769230768, 0.9816663076923077], 
             UndirectedEdge[63, 152] -> 
             RGBColor[
              0.9921893461538461, 0.9908536923076923, 0.7657011923076924], 
             UndirectedEdge[43, 137] -> 
             RGBColor[
              0.8585807307692308, 0.7426428461538461, 0.6093033461538462], 
             UndirectedEdge[97, 141] -> 
             RGBColor[
              0.9835790384615384, 0.9684419999999998, 0.6325331923076922], 
             UndirectedEdge[25, 207] -> 
             RGBColor[
              0.9858998846153846, 0.9870133846153846, 0.8144285769230771], 
             UndirectedEdge[214, 310] -> 
             RGBColor[
              0.9374974230769231, 0.8562894615384615, 0.6178980000000001], 
             UndirectedEdge[37, 87] -> 
             RGBColor[
              0.9881640769230768, 0.9701536153846153, 0.5431421538461538], 
             UndirectedEdge[146, 262] -> 
             RGBColor[
              0.9086996153846154, 0.929363076923077, 0.967808423076923], 
             UndirectedEdge[322, 364] -> 
             RGBColor[0.9696963461538461, 0.973142, 0.7000810384615384], 
             UndirectedEdge[219, 311] -> 
             RGBColor[0.9531997692307692, 0.839793076923077, 0.4298585], 
             UndirectedEdge[5, 260] -> 
             RGBColor[0.9846172692307692, 0.98427, 0.6748238076923075], 
             UndirectedEdge[204, 389] -> 
             RGBColor[
              0.8226664615384615, 0.8605283076923076, 0.896583346153846], 
             UndirectedEdge[275, 279] -> 
             RGBColor[
              0.9611591538461538, 0.8713493846153846, 0.43626280769230763`], 
             UndirectedEdge[78, 289] -> 
             RGBColor[
              0.9850448076923077, 0.9851844615384615, 0.7213587307692308], 
             UndirectedEdge[163, 329] -> 
             RGBColor[
              0.9461228461538461, 0.8089242307692307, 0.4702501153846156], 
             UndirectedEdge[47, 181] -> 
             RGBColor[
              0.9605054999999999, 0.9672491538461538, 0.8021978461538462], 
             UndirectedEdge[267, 291] -> 
             RGBColor[
              0.8760288461538461, 0.5299577692307693, 0.21826776923076924`], 
             UndirectedEdge[28, 301] -> 
             RGBColor[
              0.9733741923076922, 0.9463444615384615, 0.6311465769230767], 
             UndirectedEdge[174, 193] -> 
             RGBColor[
              0.8871358076923077, 0.7390226923076924, 0.6068170384615384], 
             UndirectedEdge[60, 263] -> 
             RGBColor[
              0.9775843461538463, 0.9796204615384616, 0.7339873461538462], 
             UndirectedEdge[122, 385] -> 
             RGBColor[
              0.9852851923076922, 0.9691475384615383, 0.6042578076923074], 
             UndirectedEdge[282, 350] -> 
             RGBColor[
              0.6433323846153847, 0.7177426923076924, 0.9673883846153846], 
             UndirectedEdge[142, 306] -> 
             RGBColor[
              0.9517646923076921, 0.9633172307692307, 0.9585758076923077], 
             UndirectedEdge[6, 289] -> 
             RGBColor[0.8983577692307692, 0.920732, 0.9534818076923077], 
             UndirectedEdge[3, 117] -> 
             RGBColor[
              0.9531997692307692, 0.839793076923077, 0.4298584999999999], 
             UndirectedEdge[6, 132] -> 
             RGBColor[
              0.9063533846153846, 0.9252778461538462, 0.8764790384615384], 
             UndirectedEdge[22, 394] -> 
             RGBColor[
              0.9910166153846154, 0.9905531538461538, 0.7985414615384614], 
             UndirectedEdge[11, 391] -> 
             RGBColor[0.987309, 0.9683246923076922, 0.45007230769230755`], 
             UndirectedEdge[34, 249] -> 
             RGBColor[
              0.8732188846153845, 0.6708583076923075, 0.5950097692307692], 
             UndirectedEdge[269, 306] -> 
             RGBColor[
              0.7877328461538462, 0.8336426923076923, 0.9429126538461539], 
             UndirectedEdge[69, 394] -> 
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079], 
             UndirectedEdge[361, 369] -> 
             RGBColor[
              0.9881640769230768, 0.9701536153846153, 0.5431421538461538], 
             UndirectedEdge[85, 184] -> 
             RGBColor[
              0.9926128846153845, 0.9888158461538461, 0.5978210384615383], 
             UndirectedEdge[73, 96] -> 
             RGBColor[
              0.9825425384615385, 0.9511908461538461, 0.5213035384615385], 
             UndirectedEdge[71, 382] -> 
             RGBColor[
              0.9659137307692307, 0.9407804615384615, 0.6437751923076921], 
             UndirectedEdge[122, 165] -> 
             RGBColor[
              0.9540288846153845, 0.9464574615384613, 0.6872893846153845], 
             UndirectedEdge[321, 331] -> 
             RGBColor[
              0.9784394230769231, 0.9814493846153847, 0.8270571923076925], 
             UndirectedEdge[296, 374] -> 
             RGBColor[0.7787539615384615, 0.7788573846153846, 0.627949], 
             UndirectedEdge[66, 297] -> 
             RGBColor[
              0.8459681153846152, 0.8611762307692306, 0.6767479999999998], 
             UndirectedEdge[75, 145] -> 
             RGBColor[
              0.9390733076923077, 0.7769139230769231, 0.4643678076923079], 
             UndirectedEdge[105, 239] -> 
             RGBColor[
              0.9086996153846154, 0.929363076923077, 0.967808423076923], 
             UndirectedEdge[92, 354] -> 
             RGBColor[
              0.9029410769230769, 0.9238667692307692, 0.9330298076923078], 
             UndirectedEdge[188, 369] -> 
             RGBColor[
              0.9869913461538461, 0.9698530769230769, 0.5759824230769228], 
             UndirectedEdge[170, 251] -> 
             RGBColor[
              0.9016085769230768, 0.5612817692307692, 0.5237928076923077], 
             UndirectedEdge[53, 68] -> 
             RGBColor[
              0.7665353461538462, 0.8121346153846154, 0.6911753076923075], 
             UndirectedEdge[274, 318] -> 
             RGBColor[
              0.9176085769230768, 0.8659289230769229, 0.6316512692307692], 
             UndirectedEdge[179, 359] -> 
             RGBColor[
              0.6889829230769231, 0.7538546153846154, 0.9617374230769231], 
             UndirectedEdge[20, 328] -> 
             RGBColor[
              0.9176085769230768, 0.8659289230769229, 0.6316512692307692], 
             UndirectedEdge[307, 352] -> 
             RGBColor[0.843703923076923, 0.878036, 0.9480344230769231], 
             UndirectedEdge[6, 216] -> 
             RGBColor[
              0.8820039615384615, 0.837538769230769, 0.6282552692307692], 
             UndirectedEdge[297, 385] -> 
             RGBColor[
              0.9852851923076922, 0.9691475384615383, 0.6042578076923074], 
             UndirectedEdge[40, 348] -> 
             RGBColor[
              0.9910166153846154, 0.9905531538461538, 0.7985414615384614], 
             UndirectedEdge[229, 329] -> 
             RGBColor[
              0.9858998846153846, 0.9870133846153846, 0.8144285769230771], 
             UndirectedEdge[6, 213] -> 
             RGBColor[0.8834368461538462, 0.909604, 0.9787390384615384], 
             UndirectedEdge[189, 374] -> 
             RGBColor[
              0.9723359615384615, 0.9305164615384616, 0.5888559615384615], 
             UndirectedEdge[97, 140] -> 
             RGBColor[
              0.8992894615384615, 0.5412872307692307, 0.2729583846153844], 
             UndirectedEdge[34, 386] -> 
             RGBColor[
              0.9222774999999999, 0.7077434615384615, 0.5136761923076922], 
             UndirectedEdge[162, 313] -> 
             RGBColor[0.8364538076923077, 0.5109070769230769, 0.575153], 
             UndirectedEdge[258, 392] -> 
             RGBColor[
              0.9927227692307692, 0.9912586923076924, 0.7702660769230769], 
             UndirectedEdge[45, 273] -> 
             RGBColor[
              0.9927227692307692, 0.9912586923076924, 0.7702660769230769], 
             UndirectedEdge[226, 393] -> 
             RGBColor[
              0.9448402307692307, 0.806180846153846, 0.33064534615384605`], 
             UndirectedEdge[88, 168] -> 
             RGBColor[
              0.7914101538461538, 0.8378382307692307, 0.9796149230769231], 
             UndirectedEdge[188, 327] -> 
             RGBColor[
              0.9597603076923076, 0.9678630769230769, 0.8815730384615384], 
             UndirectedEdge[59, 349] -> 
             RGBColor[
              0.9937856153846154, 0.9891163846153845, 0.5649807692307693], 
             UndirectedEdge[260, 398] -> 
             RGBColor[
              0.9369544999999999, 0.804077846153846, 0.5800931538461538], 
             UndirectedEdge[248, 353] -> 
             RGBColor[
              0.9449578846153845, 0.8618534615384615, 0.6052693846153845], 
             UndirectedEdge[30, 389] -> 
             RGBColor[
              0.8242627307692307, 0.8587909999999999, 0.6958629230769229], 
             UndirectedEdge[216, 311] -> 
             RGBColor[
              0.9281051538461538, 0.7526679230769229, 0.26100992307692306`], 
             UndirectedEdge[66, 307] -> 
             RGBColor[0.7106763076923076, 0.773905, 0.9717972307692307], 
             UndirectedEdge[94, 225] -> 
             RGBColor[
              0.8226664615384615, 0.8605283076923076, 0.896583346153846], 
             UndirectedEdge[177, 324] -> 
             RGBColor[
              0.9070985769230769, 0.9246639230769231, 0.7971038461538461], 
             UndirectedEdge[79, 320] -> 
             RGBColor[
              0.8499933846153845, 0.8818763076923077, 0.8993070384615384], 
             UndirectedEdge[133, 234] -> 
             RGBColor[
              0.7387347307692308, 0.791266923076923, 0.8284905384615386], 
             UndirectedEdge[35, 195] -> 
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461], 
             UndirectedEdge[34, 86] -> 
             RGBColor[
              0.9010671153846153, 0.6927751538461537, 0.5876608076923077], 
             UndirectedEdge[98, 131] -> 
             RGBColor[
              0.9434394615384615, 0.8126321538461538, 0.27767711538461537`], 
             UndirectedEdge[173, 261] -> 
             RGBColor[
              0.9757482692307692, 0.9319275384615384, 0.5323051923076922], 
             UndirectedEdge[103, 331] -> 
             RGBColor[
              0.9755605384615385, 0.9804433076923078, 0.8881728461538461], 
             UndirectedEdge[135, 322] -> 
             RGBColor[
              0.989200576923077, 0.9874047692307693, 0.6543718076923076], 
             UndirectedEdge[50, 181] -> 
             RGBColor[
              0.9597603076923076, 0.9678630769230769, 0.8815730384615384], 
             UndirectedEdge[35, 153] -> 
             RGBColor[
              0.9858998846153846, 0.9870133846153846, 0.8144285769230771], 
             UndirectedEdge[121, 362] -> 
             RGBColor[
              0.9937856153846154, 0.9891163846153846, 0.5649807692307692], 
             UndirectedEdge[84, 152] -> 
             RGBColor[
              0.9253284230769231, 0.9397734615384615, 0.8453367692307694], 
             UndirectedEdge[295, 345] -> 
             RGBColor[
              0.9065016153846153, 0.6568639999999999, 0.24310199999999996`], 
             UndirectedEdge[22, 266] -> 
             RGBColor[
              0.9796636538461538, 0.9501847692307692, 0.5824191923076921], 
             UndirectedEdge[271, 335] -> 
             RGBColor[
              0.9921893461538461, 0.9908536923076923, 0.7657011923076924], 
             UndirectedEdge[175, 261] -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.8268168461538462], 
             UndirectedEdge[59, 254] -> 
             RGBColor[
              0.9240458076923077, 0.9370300769230768, 0.7057319999999998], 
             UndirectedEdge[53, 270] -> 
             RGBColor[
              0.9756383846153847, 0.9294846923076923, 0.3598601538461537], 
             UndirectedEdge[214, 300] -> 
             RGBColor[
              0.9587078076923077, 0.8712577692307693, 0.5439133846153845], 
             UndirectedEdge[3, 386] -> 
             RGBColor[
              0.950748423076923, 0.8397014615384616, 0.5375090769230768], 
             UndirectedEdge[299, 336] -> 
             RGBColor[
              0.8528722692307692, 0.8828823846153846, 0.8381913846153848], 
             UndirectedEdge[110, 351] -> 
             RGBColor[0.8908973076923077, 0.915168, 0.9661104230769231], 
             UndirectedEdge[172, 328] -> 
             RGBColor[
              0.9570203846153845, 0.8631512307692305, 0.30592003846153826`], 
             UndirectedEdge[185, 302] -> 
             RGBColor[
              0.9070985769230769, 0.9246639230769231, 0.7971038461538461], 
             UndirectedEdge[370, 391] -> 
             RGBColor[
              0.9006219615384615, 0.9038722307692306, 0.6821953846153844], 
             UndirectedEdge[50, 364] -> 
             RGBColor[
              0.9698062307692308, 0.9755848461538461, 0.8725260769230769], 
             UndirectedEdge[73, 195] -> 
             RGBColor[
              0.9709789615384615, 0.9758853846153845, 0.8396858076923079], 
             UndirectedEdge[80, 332] -> 
             RGBColor[
              0.9563479999999999, 0.9664519999999999, 0.9381238076923077], 
             UndirectedEdge[5, 267] -> 
             RGBColor[
              0.9377906923076923, 0.7741705384615385, 0.32476303846153837`], 
             UndirectedEdge[136, 246] -> 
             RGBColor[
              0.9135511538461538, 0.6888743076923075, 0.24898430769230764`], 
             UndirectedEdge[59, 246] -> 
             RGBColor[
              0.9377906923076923, 0.7741705384615385, 0.32476303846153837`], 
             UndirectedEdge[177, 200] -> 
             RGBColor[
              0.8555886153846154, 0.8876871538461538, 0.9860880000000001], 
             UndirectedEdge[17, 157] -> 
             RGBColor[
              0.9917618076923076, 0.9899392307692307, 0.7191662692307691], 
             UndirectedEdge[151, 386] -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 
             UndirectedEdge[4, 188] -> 
             RGBColor[
              0.9910166153846154, 0.9905531538461538, 0.7985414615384614], 
             UndirectedEdge[241, 255] -> 
             RGBColor[
              0.9427031923076923, 0.9530540769230769, 0.8004998461538462], 
             UndirectedEdge[62, 345] -> 
             RGBColor[
              0.9291448846153846, 0.7438975384615385, 0.5196011538461538], 
             UndirectedEdge[57, 114] -> 
             RGBColor[
              0.9755605384615385, 0.9804433076923078, 0.8881728461538461], 
             UndirectedEdge[32, 137] -> 
             RGBColor[
              0.890127923076923, 0.5939783846153845, 0.2300323846153846], 
             UndirectedEdge[152, 175] -> 
             RGBColor[
              0.9904831923076922, 0.9901481538461538, 0.7939765769230772], 
             UndirectedEdge[99, 235] -> 
             RGBColor[
              0.9580541538461538, 0.9671575384615384, 0.909848423076923], 
             UndirectedEdge[156, 256] -> 
             RGBColor[
              0.9241556923076923, 0.9394729230769231, 0.8781770384615384], 
             UndirectedEdge[48, 286] -> 
             RGBColor[
              0.9937856153846154, 0.9891163846153845, 0.5649807692307693], 
             UndirectedEdge[61, 262] -> 
             RGBColor[
              0.5903409615384615, 0.6592085000000001, 0.9426523076923077], 
             UndirectedEdge[146, 385] -> 
             RGBColor[
              0.9224495384615384, 0.9387673846153846, 0.906452423076923], 
             UndirectedEdge[29, 150] -> 
             RGBColor[
              0.9207433846153845, 0.9380618461538461, 0.9347278076923078], 
             UndirectedEdge[141, 220] -> 
             RGBColor[
              0.9563479999999999, 0.9664519999999999, 0.9381238076923077], 
             UndirectedEdge[152, 242] -> 
             RGBColor[
              0.9881640769230768, 0.9701536153846153, 0.5431421538461538], 
             UndirectedEdge[95, 151] -> 
             RGBColor[
              0.9755605384615385, 0.9804433076923078, 0.8881728461538461], 
             UndirectedEdge[252, 293] -> 
             RGBColor[
              0.8760288461538461, 0.5299577692307693, 0.21826776923076924`], 
             UndirectedEdge[93, 390] -> 
             RGBColor[
              0.9937856153846154, 0.9891163846153845, 0.5649807692307693], 
             UndirectedEdge[229, 249] -> 
             RGBColor[
              0.9339623846153846, 0.9491221538461538, 0.9568778076923077], 
             UndirectedEdge[96, 153] -> 
             RGBColor[
              0.9825425384615385, 0.9511908461538461, 0.5213035384615385], 
             UndirectedEdge[202, 217] -> 
             RGBColor[
              0.9390733076923077, 0.7769139230769231, 0.4643678076923079], 
             UndirectedEdge[163, 304] -> 
             RGBColor[
              0.8585807307692308, 0.7426428461538461, 0.6093033461538462], 
             UndirectedEdge[18, 323] -> 
             RGBColor[
              0.9900556538461538, 0.9892336923076923, 0.7474416538461539], 
             UndirectedEdge[152, 264] -> 
             RGBColor[
              0.9431307307692307, 0.9539685384615384, 0.8470347692307695], 
             UndirectedEdge[23, 169] -> 
             RGBColor[
              0.9456953076923076, 0.8080097692307692, 0.4237151923076922], 
             UndirectedEdge[290, 342] -> 
             RGBColor[
              0.7964736538461539, 0.8375746153846154, 0.7865346923076922], 
             UndirectedEdge[285, 330] -> 
             RGBColor[
              0.9291448846153846, 0.7438975384615385, 0.5196011538461538], 
             UndirectedEdge[55, 192] -> 
             RGBColor[0.9531997692307692, 0.839793076923077, 0.4298585], 
             UndirectedEdge[161, 170] -> 
             RGBColor[
              0.9053385384615384, 0.5611644615384616, 0.3413319230769231], 
             UndirectedEdge[42, 205] -> 
             RGBColor[
              0.9602921923076924, 0.9218176923076924, 0.6219365769230768], 
             UndirectedEdge[267, 398] -> 
             RGBColor[
              0.890127923076923, 0.5939783846153845, 0.2300323846153846], 
             UndirectedEdge[32, 199] -> 
             RGBColor[
              0.9299049615384615, 0.7720675384615385, 0.5742108461538462], 
             UndirectedEdge[154, 385] -> 
             RGBColor[
              0.9755605384615385, 0.9804433076923078, 0.8881728461538461], 
             UndirectedEdge[91, 190] -> 
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079], 
             UndirectedEdge[94, 380] -> 
             RGBColor[
              0.769550423076923, 0.6465885384615384, 0.5952499615384615], 
             UndirectedEdge[119, 288] -> 
             RGBColor[
              0.9921893461538461, 0.9908536923076923, 0.7657011923076924], 
             UndirectedEdge[65, 251] -> 
             RGBColor[
              0.9813148461538461, 0.9853017692307693, 0.9038196153846154], 
             UndirectedEdge[198, 216] -> 
             RGBColor[
              0.8933133076923077, 0.5721245384615383, 0.23112411538461536`], 
             UndirectedEdge[101, 182] -> 
             RGBColor[
              0.7586496153846154, 0.8100316153846154, 0.9406231153846154], 
             UndirectedEdge[11, 230] -> 
             RGBColor[
              0.9850448076923077, 0.9851844615384615, 0.7213587307692308], 
             UndirectedEdge[53, 101] -> 
             RGBColor[0.9846172692307692, 0.98427, 0.6748238076923075], 
             UndirectedEdge[202, 264] -> 
             RGBColor[
              0.8871358076923077, 0.7390226923076924, 0.6068170384615386], 
             UndirectedEdge[336, 367] -> 
             RGBColor[
              0.9937856153846154, 0.9891163846153845, 0.5649807692307693], 
             UndirectedEdge[13, 132] -> 
             RGBColor[0.941958, 0.953668, 0.8798750384615385], 
             UndirectedEdge[146, 307] -> 
             RGBColor[
              0.7831324615384615, 0.8307960769230769, 0.9789426153846154], 
             UndirectedEdge[75, 133] -> 
             RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 
             UndirectedEdge[153, 369] -> 
             RGBColor[
              0.9881640769230768, 0.9701536153846153, 0.5431421538461538], 
             UndirectedEdge[20, 181] -> 
             RGBColor[0.9089955384615384, 0.9302723846153845, 0.991182], 
             UndirectedEdge[112, 394] -> 
             RGBColor[
              0.9910166153846154, 0.9905531538461538, 0.7985414615384614], 
             UndirectedEdge[279, 306] -> 
             RGBColor[
              0.9854723461538462, 0.986098923076923, 0.7678936538461538], 
             UndirectedEdge[34, 68] -> 
             RGBColor[
              0.6979061153846153, 0.5317677692307691, 0.5787550769230769], 
             UndirectedEdge[4, 284] -> 
             RGBColor[
              0.9587078076923077, 0.8712577692307693, 0.5439133846153845], 
             UndirectedEdge[193, 235] -> 
             RGBColor[
              0.936194423076923, 0.7759078461538462, 0.5254834615384614], 
             UndirectedEdge[296, 316] -> 
             RGBColor[
              0.7713790384615384, 0.7504494615384614, 0.6176861153846154], 
             UndirectedEdge[117, 223] -> 
             RGBColor[
              0.7673904230769231, 0.8139635384615385, 0.7842451538461538], 
             UndirectedEdge[37, 110] -> 
             RGBColor[
              0.9784394230769231, 0.9814493846153847, 0.8270571923076925], 
             UndirectedEdge[83, 349] -> 
             RGBColor[
              0.8255453461538461, 0.8615343846153846, 0.8354676923076925], 
             UndirectedEdge[192, 348] -> 
             RGBColor[
              0.9524545769230769, 0.8404070000000001, 0.5092336923076923], 
             UndirectedEdge[97, 394] -> 
             RGBColor[
              0.9869913461538461, 0.9698530769230769, 0.5759824230769228], 
             UndirectedEdge[2, 352] -> 
             RGBColor[
              0.9692710769230769, 0.9766030000000001, 0.9369002307692307], 
             UndirectedEdge[69, 350] -> 
             RGBColor[
              0.7130721923076924, 0.7698290000000001, 0.8266371538461541], 
             UndirectedEdge[164, 304] -> 
             RGBColor[
              0.9066710384615385, 0.9237494615384616, 0.7505689230769231], 
             UndirectedEdge[141, 350] -> 
             RGBColor[
              0.7084871538461539, 0.7681173846153846, 0.9160281923076924], 
             UndirectedEdge[114, 356] -> 
             RGBColor[
              0.9909067307692307, 0.9881103076923077, 0.6260964230769229], 
             UndirectedEdge[383, 390] -> 
             RGBColor[0.9696963461538461, 0.973142, 0.7000810384615384], 
             UndirectedEdge[297, 307] -> 
             RGBColor[
              0.8459681153846152, 0.8611762307692306, 0.6767479999999998], 
             UndirectedEdge[40, 58] -> 
             RGBColor[
              0.940251846153846, 0.9529624615384615, 0.9081504230769231], 
             UndirectedEdge[173, 295] -> 
             RGBColor[
              0.9513988461538461, 0.8441884615384614, 0.28408142307692297`], 
             UndirectedEdge[161, 239] -> 
             RGBColor[
              0.9775843461538463, 0.9796204615384616, 0.7339873461538462], 
             UndirectedEdge[35, 369] -> 
             RGBColor[
              0.9789957307692307, 0.9653072307692306, 0.6529851923076921], 
             UndirectedEdge[303, 313] -> 
             RGBColor[
              0.9012391538461538, 0.9237990769230768, 0.9804370384615384], 
             UndirectedEdge[237, 349] -> 
             RGBColor[
              0.9431307307692307, 0.9539685384615384, 0.8470347692307695], 
             UndirectedEdge[21, 263] -> 
             RGBColor[
              0.9775843461538463, 0.9796204615384616, 0.7339873461538462], 
             UndirectedEdge[126, 274] -> 
             RGBColor[
              0.9691185384615384, 0.9029056923076921, 0.4426671153846153], 
             UndirectedEdge[331, 346] -> 
             RGBColor[0.8908973076923077, 0.915168, 0.9661104230769231], 
             UndirectedEdge[106, 345] -> 
             RGBColor[
              0.8985422307692308, 0.6253076923076923, 0.2366976923076923]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.8830783846153846, 0.5619680769230769, 0.22415007692307692`], 
             316 -> RGBColor[
              0.944023923076923, 0.8157805384615381, 0.27381853846153836`], 
             308 -> RGBColor[
              0.944023923076923, 0.8157805384615381, 0.27381853846153836`], 
             160 -> RGBColor[
              0.8689793076923077, 0.4979474615384617, 0.21238546153846155`], 
             245 -> RGBColor[0.9468896923076923, 0.959911, 0.974786076923077],
              155 -> RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 
             213 -> RGBColor[0.9468896923076923, 0.959911, 0.974786076923077],
              352 -> RGBColor[
              0.9767315384615384, 0.982167, 0.9242716153846153], 27 -> 
             RGBColor[
              0.8689793076923077, 0.4979474615384617, 0.21238546153846155`], 
             367 -> RGBColor[
              0.992503, 0.9863729999999999, 0.4253759999999998], 19 -> 
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153], 164 -> 
             RGBColor[
              0.993358076923077, 0.9882019230769231, 0.5184458461538463], 190 -> 
             RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 
             103 -> RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 138 -> 
             RGBColor[
              0.9858981538461538, 0.9884365384615384, 0.8833676153846155], 
             291 -> RGBColor[
              0.8689793076923077, 0.4979474615384617, 0.21238546153846155`], 
             28 -> RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153],
              337 -> RGBColor[
              0.9858981538461538, 0.9884365384615384, 0.8833676153846155], 
             195 -> RGBColor[0.9468896923076923, 0.959911, 0.974786076923077],
              114 -> RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 93 -> 
             RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 34 -> 
             RGBColor[
              0.8552445384615384, 0.42563930769230734`, 0.2005355384615384], 
             161 -> RGBColor[
              0.993358076923077, 0.9882019230769231, 0.5184458461538463], 22 -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 124 -> 
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077], 84 -> 
             RGBColor[0.8555886153846154, 0.8876871538461538, 0.986088], 46 -> 
             RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 
             241 -> RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076922], 
             185 -> RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076922], 
             390 -> RGBColor[
              0.992503, 0.9863729999999999, 0.4253759999999998], 121 -> 
             RGBColor[
              0.993358076923077, 0.9882019230769231, 0.5184458461538463], 322 -> 
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998], 126 -> 
             RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076922], 
             236 -> RGBColor[
              0.981259923076923, 0.9484474615384613, 0.38169876923076884`], 
             78 -> RGBColor[
              0.993358076923077, 0.9882019230769231, 0.5184458461538463], 376 -> 
             RGBColor[
              0.9927227692307692, 0.9912586923076924, 0.7702660769230769], 
             254 -> RGBColor[
              0.8555886153846154, 0.8876871538461538, 0.986088], 290 -> 
             RGBColor[
              0.5987341538461539, 0.6851183846153847, 0.9615536923076923], 
             251 -> RGBColor[
              0.9858981538461538, 0.9884365384615384, 0.8833676153846155], 
             165 -> RGBColor[0.926797846153846, 0.9444674615384614, 0.99288], 
             100 -> RGBColor[
              0.992503, 0.9863729999999999, 0.4253759999999998], 235 -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 70 -> 
             RGBColor[0.926797846153846, 0.9444674615384614, 0.99288], 234 -> 
             RGBColor[
              0.48240123076923075`, 0.5906740769230768, 0.9523955384615385], 
             257 -> RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 135 -> 
             RGBColor[
              0.9858981538461538, 0.9884365384615384, 0.8833676153846155], 
             265 -> RGBColor[0.9468896923076923, 0.959911, 0.974786076923077],
              111 -> RGBColor[
              0.981259923076923, 0.9484474615384613, 0.38169876923076884`], 
             381 -> RGBColor[
              0.981259923076923, 0.9484474615384613, 0.38169876923076884`], 
             182 -> RGBColor[
              0.5405676923076923, 0.6378962307692307, 0.9569746153846154], 
             188 -> RGBColor[
              0.9927227692307692, 0.9912586923076924, 0.7702660769230769], 
             154 -> RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 336 -> 
             RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 
             315 -> RGBColor[0.9468896923076923, 0.959911, 0.974786076923077],
              368 -> RGBColor[
              0.981259923076923, 0.9484474615384613, 0.38169876923076884`], 
             269 -> RGBColor[
              0.5987341538461539, 0.6851183846153847, 0.9615536923076923], 
             208 -> RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 86 -> 
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077], 119 -> 
             RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 
             377 -> RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 
             140 -> RGBColor[0.817319, 0.134127, 0.164218], 85 -> 
             RGBColor[
              0.9927227692307692, 0.9912586923076924, 0.7702660769230769], 
             351 -> RGBColor[0.819984, 0.859297, 0.982692], 242 -> 
             RGBColor[
              0.981259923076923, 0.9484474615384613, 0.38169876923076884`], 
             117 -> RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076922], 47 -> 
             RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076922], 81 -> 
             RGBColor[
              0.993358076923077, 0.9882019230769231, 0.5184458461538463], 275 -> 
             RGBColor[
              0.9281051538461538, 0.752667923076923, 0.26100992307692306`], 
             23 -> RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076922], 
             328 -> RGBColor[
              0.944023923076923, 0.8157805384615381, 0.27381853846153836`], 
             110 -> RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 6 -> 
             RGBColor[0.819984, 0.859297, 0.982692], 218 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 108 -> 
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153], 297 -> 
             RGBColor[
              0.981259923076923, 0.9484474615384613, 0.38169876923076884`], 
             157 -> RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 354 -> 
             RGBColor[0.819984, 0.859297, 0.982692], 385 -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 270 -> 
             RGBColor[
              0.9587737692307692, 0.8725963846153846, 0.2943443076923076], 
             392 -> RGBColor[
              0.9927227692307692, 0.9912586923076924, 0.7702660769230769], 33 -> 
             RGBColor[0.926797846153846, 0.9444674615384614, 0.99288], 252 -> 
             RGBColor[
              0.8689793076923077, 0.4979474615384617, 0.21238546153846155`], 
             394 -> RGBColor[
              0.9927227692307692, 0.9912586923076924, 0.7702660769230769], 
             260 -> RGBColor[
              0.9767315384615384, 0.982167, 0.9242716153846153], 159 -> 
             RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 
             183 -> RGBColor[
              0.992503, 0.9863729999999999, 0.4253759999999998], 99 -> 
             RGBColor[0.926797846153846, 0.9444674615384614, 0.99288], 329 -> 
             RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 
             309 -> RGBColor[
              0.5987341538461539, 0.6851183846153847, 0.9615536923076923], 17 -> 
             RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076922], 
             349 -> RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 
             347 -> RGBColor[
              0.8971774615384615, 0.6259886923076922, 0.23591469230769227`], 
             340 -> RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 277 -> 
             RGBColor[
              0.9858981538461538, 0.9884365384615384, 0.8833676153846155], 
             104 -> RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 79 -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 327 -> 
             RGBColor[0.926797846153846, 0.9444674615384614, 0.99288], 191 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 50 -> 
             RGBColor[
              0.9927227692307692, 0.9912586923076924, 0.7702660769230769], 
             225 -> RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 61 -> 
             RGBColor[
              0.21887130769230764`, 0.34737799999999996`, 0.9357757692307692],
              196 -> RGBColor[
              0.981259923076923, 0.9484474615384613, 0.38169876923076884`], 1 -> 
             RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076922], 
             263 -> RGBColor[
              0.993358076923077, 0.9882019230769231, 0.5184458461538463], 201 -> R\
GBColor[0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 371 -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 293 -> 
             RGBColor[
              0.8830783846153846, 0.5619680769230769, 0.22415007692307692`], 
             362 -> RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076922], 
             184 -> RGBColor[
              0.992503, 0.9863729999999999, 0.4253759999999998], 106 -> 
             RGBColor[
              0.9281051538461538, 0.752667923076923, 0.26100992307692306`], 
             206 -> RGBColor[
              0.9927227692307692, 0.9912586923076924, 0.7702660769230769], 
             358 -> RGBColor[
              0.8971774615384615, 0.6259886923076922, 0.23591469230769227`], 
             247 -> RGBColor[
              0.8911932307692307, 0.9160773076923077, 0.989484], 220 -> 
             RGBColor[0.926797846153846, 0.9444674615384614, 0.99288], 107 -> 
             RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 375 -> 
             RGBColor[
              0.9587737692307692, 0.8725963846153846, 0.2943443076923076], 
             131 -> RGBColor[
              0.9587737692307692, 0.8725963846153846, 0.2943443076923076], 
             127 -> RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 
             210 -> RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 357 -> 
             RGBColor[0.819984, 0.859297, 0.982692], 181 -> 
             RGBColor[0.926797846153846, 0.9444674615384614, 0.99288], 194 -> 
             RGBColor[
              0.8830783846153846, 0.5619680769230769, 0.22415007692307692`], 
             118 -> RGBColor[0.9468896923076923, 0.959911, 0.974786076923077],
              348 -> RGBColor[
              0.9927227692307692, 0.9912586923076924, 0.7702660769230769], 
             276 -> RGBColor[
              0.9700168461538461, 0.9105219230769229, 0.3380215384615382], 
             305 -> RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             343 -> RGBColor[
              0.8689793076923077, 0.4979474615384617, 0.21238546153846155`], 
             280 -> RGBColor[
              0.8830783846153846, 0.5619680769230769, 0.22415007692307692`], 
             189 -> RGBColor[
              0.9858981538461538, 0.9884365384615384, 0.8833676153846155], 
             168 -> RGBColor[
              0.6560224615384614, 0.7312089999999999, 0.9663498461538461], 
             363 -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 41 -> 
             RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076922], 14 -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 77 -> 
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998], 51 -> 
             RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076922], 
             179 -> RGBColor[0.9468896923076923, 0.959911, 0.974786076923077],
              223 -> RGBColor[
              0.5405676923076923, 0.6378962307692307, 0.9569746153846154], 
             323 -> RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076922], 
             292 -> RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 
             396 -> RGBColor[
              0.981259923076923, 0.9484474615384613, 0.38169876923076884`], 
             321 -> RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 
             143 -> RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 112 -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 197 -> 
             RGBColor[
              0.944023923076923, 0.8157805384615381, 0.27381853846153836`], 
             54 -> RGBColor[
              0.9858981538461538, 0.9884365384615384, 0.8833676153846155], 71 -> 
             RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 177 -> 
             RGBColor[0.819984, 0.859297, 0.982692], 158 -> 
             RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 226 -> 
             RGBColor[
              0.8971774615384615, 0.6259886923076922, 0.23591469230769227`], 
             350 -> RGBColor[
              0.43107615384615394`, 0.5477982307692308, 0.9486887692307693], 
             203 -> RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 115 -> 
             RGBColor[0.8555886153846154, 0.8876871538461538, 0.986088], 173 -> 
             RGBColor[
              0.9587737692307692, 0.8725963846153846, 0.2943443076923076], 
             212 -> RGBColor[
              0.981259923076923, 0.9484474615384613, 0.38169876923076884`], 
             129 -> RGBColor[
              0.9858981538461538, 0.9884365384615384, 0.8833676153846155], 
             279 -> 
             RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076922], 26 -> 
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153], 40 -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 146 -> 
             RGBColor[0.8555886153846154, 0.8876871538461538, 0.986088], 386 -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 192 -> 
             RGBColor[
              0.9121863846153846, 0.6895553076923078, 0.24820130769230772`], 
             300 -> RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 221 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 62 -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 286 -> 
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998], 152 -> 
             RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 64 -> 
             RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 307 -> 
             RGBColor[0.7106763076923076, 0.773905, 0.9717972307692307], 37 -> 
             RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 
             148 -> RGBColor[
              0.8299608461538462, 0.2312977692307697, 0.17632384615384622`], 
             261 -> RGBColor[
              0.9927227692307692, 0.9912586923076924, 0.7702660769230769], 
             387 -> RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 15 -> 
             RGBColor[
              0.944023923076923, 0.8157805384615381, 0.27381853846153836`], 
             136 -> RGBColor[
              0.944023923076923, 0.8157805384615381, 0.27381853846153836`], 
             198 -> RGBColor[
              0.8426026923076924, 0.3284685384615385, 0.18842969230769233`], 
             63 -> RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 310 -> 
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077], 171 -> 
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998], 395 -> 
             RGBColor[
              0.8830783846153846, 0.5619680769230769, 0.22415007692307692`], 
             311 -> RGBColor[
              0.9121863846153846, 0.6895553076923078, 0.24820130769230772`], 
             353 -> RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 
             59 -> RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998],
              397 -> RGBColor[0.926797846153846, 0.9444674615384614, 0.99288],
              229 -> RGBColor[
              0.9767315384615384, 0.982167, 0.9242716153846153], 102 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 299 -> 
             RGBColor[0.7106763076923076, 0.773905, 0.9717972307692307], 128 -> 
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077], 12 -> 
             RGBColor[
              0.993358076923077, 0.9882019230769231, 0.5184458461538463], 222 -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 92 -> 
             RGBColor[
              0.9858981538461538, 0.9884365384615384, 0.8833676153846155], 
             271 -> RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 361 -> 
             RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 
             344 -> RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 
             132 -> RGBColor[
              0.9927227692307692, 0.9912586923076924, 0.7702660769230769], 80 -> 
             RGBColor[
              0.9858981538461538, 0.9884365384615384, 0.8833676153846155], 
             324 -> RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076922], 
             244 -> RGBColor[0.817319, 0.134127, 0.164218], 150 -> 
             RGBColor[
              0.9858981538461538, 0.9884365384615384, 0.8833676153846155], 
             125 -> RGBColor[
              0.981259923076923, 0.9484474615384613, 0.38169876923076884`], 
             258 -> RGBColor[
              0.9927227692307692, 0.9912586923076924, 0.7702660769230769], 
             133 -> RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 
             255 -> RGBColor[
              0.8911932307692307, 0.9160773076923077, 0.989484], 326 -> 
             RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076922], 
             176 -> RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076922], 
             230 -> RGBColor[
              0.9767315384615384, 0.982167, 0.9242716153846153], 274 -> 
             RGBColor[
              0.944023923076923, 0.8157805384615381, 0.27381853846153836`], 
             87 -> RGBColor[
              0.981259923076923, 0.9484474615384613, 0.38169876923076884`], 
             130 -> 
             RGBColor[
              0.9587737692307692, 0.8725963846153846, 0.2943443076923076], 35 -> 
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153], 379 -> 
             RGBColor[
              0.981259923076923, 0.9484474615384613, 0.38169876923076884`], 
             31 -> RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 18 -> 
             RGBColor[
              0.9858981538461538, 0.9884365384615384, 0.8833676153846155], 24 -> 
             RGBColor[
              0.9858981538461538, 0.9884365384615384, 0.8833676153846155], 
             151 -> RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 137 -> 
             RGBColor[
              0.8971774615384615, 0.6259886923076922, 0.23591469230769227`], 
             330 -> RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 296 -> 
             RGBColor[
              0.5987341538461539, 0.6851183846153847, 0.9615536923076923], 
             266 -> RGBColor[
              0.9700168461538461, 0.9105219230769229, 0.3380215384615382], 
             302 -> RGBColor[0.819984, 0.859297, 0.982692], 283 -> 
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077], 388 -> 
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077], 284 -> 
             RGBColor[
              0.9281051538461538, 0.752667923076923, 0.26100992307692306`], 
             318 -> RGBColor[
              0.8911932307692307, 0.9160773076923077, 0.989484], 238 -> 
             RGBColor[
              0.9927227692307692, 0.9912586923076924, 0.7702660769230769], 72 -> 
             RGBColor[
              0.981259923076923, 0.9484474615384613, 0.38169876923076884`], 
             288 -> RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 382 -> 
             RGBColor[
              0.9700168461538461, 0.9105219230769229, 0.3380215384615382], 
             389 -> RGBColor[
              0.6560224615384614, 0.7312089999999999, 0.9663498461538461], 
             172 -> RGBColor[
              0.9700168461538461, 0.9105219230769229, 0.3380215384615382], 
             243 -> RGBColor[
              0.993358076923077, 0.9882019230769231, 0.5184458461538463], 88 -> 
             RGBColor[0.926797846153846, 0.9444674615384614, 0.99288], 273 -> 
             RGBColor[
              0.9927227692307692, 0.9912586923076924, 0.7702660769230769], 
             202 -> RGBColor[
              0.8830783846153846, 0.5619680769230769, 0.22415007692307692`], 
             393 -> RGBColor[
              0.992503, 0.9863729999999999, 0.4253759999999998], 98 -> 
             RGBColor[
              0.9281051538461538, 0.752667923076923, 0.26100992307692306`], 
             30 -> RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998],
              116 -> RGBColor[
              0.5405676923076923, 0.6378962307692307, 0.9569746153846154], 
             373 -> RGBColor[
              0.7106763076923076, 0.773905, 0.9717972307692307], 240 -> 
             RGBColor[0.926797846153846, 0.9444674615384614, 0.99288], 317 -> 
             RGBColor[
              0.9121863846153846, 0.6895553076923078, 0.24820130769230772`], 
             391 -> RGBColor[
              0.981259923076923, 0.9484474615384613, 0.38169876923076884`], 
             73 -> RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 
             303 -> RGBColor[0.9468896923076923, 0.959911, 0.974786076923077],
              29 -> RGBColor[
              0.8555886153846154, 0.8876871538461538, 0.986088], 360 -> 
             RGBColor[
              0.944023923076923, 0.8157805384615381, 0.27381853846153836`], 
             320 -> RGBColor[
              0.7106763076923076, 0.773905, 0.9717972307692307], 75 -> 
             RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 
             200 -> RGBColor[
              0.8911932307692307, 0.9160773076923077, 0.989484], 301 -> 
             RGBColor[
              0.9700168461538461, 0.9105219230769229, 0.3380215384615382], 
             156 -> RGBColor[
              0.9927227692307692, 0.9912586923076924, 0.7702660769230769], 25 -> 
             RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 38 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 365 -> 
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998], 380 -> 
             RGBColor[
              0.8830783846153846, 0.5619680769230769, 0.22415007692307692`], 
             370 -> RGBColor[0.819984, 0.859297, 0.982692], 3 -> 
             RGBColor[
              0.9121863846153846, 0.6895553076923078, 0.24820130769230772`], 
             57 -> RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 227 -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 39 -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 
             109 -> 
             RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 
             256 -> RGBColor[
              0.8555886153846154, 0.8876871538461538, 0.986088], 339 -> 
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484], 287 -> 
             RGBColor[0.8555886153846154, 0.8876871538461538, 0.986088], 239 -> 
             RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 285 -> 
             RGBColor[
              0.8689793076923077, 0.4979474615384617, 0.21238546153846155`], 
             345 -> RGBColor[
              0.8689793076923077, 0.4979474615384617, 0.21238546153846155`], 
             366 -> RGBColor[
              0.9121863846153846, 0.6895553076923078, 0.24820130769230772`], 
             216 -> RGBColor[
              0.944023923076923, 0.8157805384615381, 0.27381853846153836`], 
             21 -> RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 355 -> 
             RGBColor[
              0.9587737692307692, 0.8725963846153846, 0.2943443076923076], 
             175 -> RGBColor[
              0.9858981538461538, 0.9884365384615384, 0.8833676153846155], 7 -> 
             RGBColor[
              0.9858981538461538, 0.9884365384615384, 0.8833676153846155], 13 -> 
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484], 294 -> 
             RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 193 -> 
             RGBColor[
              0.8830783846153846, 0.5619680769230769, 0.22415007692307692`], 
             60 -> RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 65 -> 
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153], 69 -> 
             RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 
             217 -> RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 
             214 -> RGBColor[
              0.9281051538461538, 0.752667923076923, 0.26100992307692306`], 
             170 -> RGBColor[0.817319, 0.134127, 0.164218], 359 -> 
             RGBColor[
              0.43107615384615394`, 0.5477982307692308, 0.9486887692307693], 
             74 -> RGBColor[
              0.21887130769230764`, 0.34737799999999996`, 0.9357757692307692],
              246 -> RGBColor[
              0.8830783846153846, 0.5619680769230769, 0.22415007692307692`], 
             264 -> 
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484], 278 -> 
             RGBColor[0.8555886153846154, 0.8876871538461538, 0.986088], 45 -> 
             RGBColor[
              0.9927227692307692, 0.9912586923076924, 0.7702660769230769], 
             306 -> RGBColor[
              0.9767315384615384, 0.982167, 0.9242716153846153], 237 -> 
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484], 228 -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             180 -> RGBColor[
              0.9927227692307692, 0.9912586923076924, 0.7702660769230769], 
             383 -> RGBColor[0.9468896923076923, 0.959911, 0.974786076923077],
              53 -> RGBColor[
              0.992503, 0.9863729999999999, 0.4253759999999998], 304 -> 
             RGBColor[0.819984, 0.859297, 0.982692], 48 -> 
             RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 5 -> 
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998], 101 -> 
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153], 333 -> 
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998], 267 -> 
             RGBColor[
              0.8830783846153846, 0.5619680769230769, 0.22415007692307692`], 
             120 -> RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076922], 
             147 -> RGBColor[0.819984, 0.859297, 0.982692], 89 -> 
             RGBColor[
              0.981259923076923, 0.9484474615384613, 0.38169876923076884`], 
             43 -> RGBColor[0.819984, 0.859297, 0.982692], 199 -> 
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153], 268 -> 
             RGBColor[
              0.9587737692307692, 0.8725963846153846, 0.2943443076923076], 
             169 -> RGBColor[
              0.8971774615384615, 0.6259886923076922, 0.23591469230769227`], 
             20 -> RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484],
              4 -> RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 167 -> 
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077], 142 -> 
             RGBColor[0.926797846153846, 0.9444674615384614, 0.99288], 16 -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             281 -> 
             RGBColor[
              0.9281051538461538, 0.752667923076923, 0.26100992307692306`], 
             289 -> RGBColor[
              0.9767315384615384, 0.982167, 0.9242716153846153], 398 -> 
             RGBColor[
              0.8971774615384615, 0.6259886923076922, 0.23591469230769227`], 
             178 -> RGBColor[
              0.9858981538461538, 0.9884365384615384, 0.8833676153846155], 58 -> 
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484], 186 -> 
             RGBColor[
              0.9587737692307692, 0.8725963846153846, 0.2943443076923076], 
             122 -> RGBColor[
              0.981259923076923, 0.9484474615384613, 0.38169876923076884`], 
             249 -> RGBColor[
              0.8911932307692307, 0.9160773076923077, 0.989484], 113 -> 
             RGBColor[
              0.944023923076923, 0.8157805384615381, 0.27381853846153836`], 
             52 -> RGBColor[
              0.981259923076923, 0.9484474615384613, 0.38169876923076884`], 
             187 -> RGBColor[
              0.9767315384615384, 0.982167, 0.9242716153846153], 259 -> 
             RGBColor[
              0.9587737692307692, 0.8725963846153846, 0.2943443076923076], 42 -> 
             RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 134 -> 
             RGBColor[
              0.981259923076923, 0.9484474615384613, 0.38169876923076884`], 
             313 -> RGBColor[
              0.8555886153846154, 0.8876871538461538, 0.986088], 248 -> 
             RGBColor[
              0.9281051538461538, 0.752667923076923, 0.26100992307692306`], 
             174 -> RGBColor[
              0.8911932307692307, 0.9160773076923077, 0.989484], 215 -> 
             RGBColor[0.819984, 0.859297, 0.982692], 399 -> 
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077], 83 -> 
             RGBColor[
              0.6560224615384614, 0.7312089999999999, 0.9663498461538461], 95 -> 
             RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 166 -> 
             RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 384 -> 
             RGBColor[0.819984, 0.859297, 0.982692], 233 -> 
             RGBColor[0.926797846153846, 0.9444674615384614, 0.99288], 295 -> 
             RGBColor[
              0.944023923076923, 0.8157805384615381, 0.27381853846153836`], 
             141 -> RGBColor[
              0.9858981538461538, 0.9884365384615384, 0.8833676153846155], 
             319 -> 
             RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076922], 
             205 -> RGBColor[
              0.9587737692307692, 0.8725963846153846, 0.2943443076923076], 
             224 -> RGBColor[
              0.9767315384615384, 0.982167, 0.9242716153846153], 231 -> 
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077], 332 -> 
             RGBColor[0.926797846153846, 0.9444674615384614, 0.99288], 68 -> 
             RGBColor[
              0.5405676923076923, 0.6378962307692307, 0.9569746153846154], 10 -> 
             RGBColor[0.7106763076923076, 0.773905, 0.9717972307692307], 250 -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 282 -> 
             RGBColor[0.8555886153846154, 0.8876871538461538, 0.986088], 374 -> 
             RGBColor[
              0.9587737692307692, 0.8725963846153846, 0.2943443076923076], 
             232 -> RGBColor[
              0.9767315384615384, 0.982167, 0.9242716153846153], 253 -> 
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153], 55 -> 
             RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076922], 
             325 -> RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 91 -> 
             RGBColor[
              0.9927227692307692, 0.9912586923076924, 0.7702660769230769], 
             105 -> RGBColor[
              0.8555886153846154, 0.8876871538461538, 0.986088], 36 -> 
             RGBColor[
              0.9700168461538461, 0.9105219230769229, 0.3380215384615382], 
             123 -> RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 94 -> 
             RGBColor[
              0.6560224615384614, 0.7312089999999999, 0.9663498461538461], 
             312 -> RGBColor[0.819984, 0.859297, 0.982692], 96 -> 
             RGBColor[
              0.9700168461538461, 0.9105219230769229, 0.3380215384615382], 2 -> 
             RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 262 -> 
             RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 272 -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 97 -> 
             RGBColor[
              0.981259923076923, 0.9484474615384613, 0.38169876923076884`], 
             372 -> RGBColor[
              0.944023923076923, 0.8157805384615381, 0.27381853846153836`], 
             356 -> 
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998], 346 -> 
             RGBColor[0.819984, 0.859297, 0.982692], 341 -> 
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998], 209 -> 
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484], 378 -> 
             RGBColor[
              0.9858981538461538, 0.9884365384615384, 0.8833676153846155], 66 -> 
             RGBColor[0.7106763076923076, 0.773905, 0.9717972307692307], 139 -> 
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484], 56 -> 
             RGBColor[
              0.981259923076923, 0.9484474615384613, 0.38169876923076884`], 
             335 -> RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 
             314 -> RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 144 -> 
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998], 298 -> 
             RGBColor[
              0.8830783846153846, 0.5619680769230769, 0.22415007692307692`], 
             204 -> RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.826816846153846], 207 -> 
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153], 334 -> 
             RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 149 -> 
             RGBColor[
              0.8971774615384615, 0.6259886923076922, 0.23591469230769227`], 
             219 -> RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076922], 
             400 -> RGBColor[
              0.993358076923077, 0.9882019230769231, 0.5184458461538463], 9 -> 
             RGBColor[0.926797846153846, 0.9444674615384614, 0.99288], 11 -> 
             RGBColor[
              0.993358076923077, 0.9882019230769231, 0.5184458461538463], 44 -> 
             RGBColor[
              0.8689793076923077, 0.4979474615384617, 0.21238546153846155`], 
             153 -> RGBColor[
              0.9950682307692308, 0.9918597692307692, 0.7045855384615389], 32 -> 
             RGBColor[
              0.8830783846153846, 0.5619680769230769, 0.22415007692307692`], 
             162 -> RGBColor[0.817319, 0.134127, 0.164218], 90 -> 
             RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 331 -> 
             RGBColor[
              0.9618106153846154, 0.9710390000000001, 0.949528846153846], 8 -> 
             RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076922], 
             364 -> RGBColor[0.9468896923076923, 0.959911, 0.974786076923077],
              342 -> RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076922], 
             163 -> RGBColor[
              0.8971774615384615, 0.6259886923076922, 0.23591469230769227`], 
             49 -> RGBColor[0.926797846153846, 0.9444674615384614, 0.99288], 
             338 -> RGBColor[
              0.9281051538461538, 0.752667923076923, 0.26100992307692306`], 
             76 -> RGBColor[
              0.9281051538461538, 0.752667923076923, 0.26100992307692306`], 
             369 -> RGBColor[
              0.981259923076923, 0.9484474615384613, 0.38169876923076884`], 
             82 -> RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998],
              67 -> RGBColor[
              0.992503, 0.9863729999999999, 0.4253759999999998], 211 -> 
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9l3k0VX/Yxa95Hq55dufJNVwqktwdKpWiSIU0EZFIxkiFhGRKk6SkQSmp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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 7}], {
             RGBColor[
             0.9900556538461538, 0.9892336923076923, 0.7474416538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 35}], {
             RGBColor[
             0.9854723461538462, 0.986098923076923, 0.7678936538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 41}], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 57}], {
             RGBColor[
             0.9780118846153847, 0.9805349230769231, 0.7805222692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 92}], {
             RGBColor[
             0.9900556538461538, 0.9892336923076923, 0.7474416538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 96}], {
             RGBColor[0.982115, 0.9502763846153846, 0.47476861538461523`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 114}], {
             RGBColor[
             0.9917618076923076, 0.9899392307692307, 0.7191662692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 153}], {
             RGBColor[
             0.9946406923076923, 0.9909453076923077, 0.6580506153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 154}], {
             RGBColor[
             0.9780118846153847, 0.9805349230769231, 0.7805222692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 161}], {
             RGBColor[
             0.9937856153846154, 0.9891163846153846, 0.5649807692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 188}], {
             RGBColor[
             0.9934679615384615, 0.9906447692307693, 0.6908908846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 203}], {
             RGBColor[
             0.9780118846153847, 0.9805349230769231, 0.7805222692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 222}], {
             RGBColor[
             0.8797716538461539, 0.903315923076923, 0.7943801538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 312}], {
             RGBColor[
             0.9070985769230769, 0.9246639230769231, 0.7971038461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 327}], {
             RGBColor[
             0.9605054999999999, 0.9672491538461538, 0.8021978461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 337}], {
             RGBColor[
             0.9900556538461538, 0.9892336923076923, 0.7474416538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 356}], {
             RGBColor[
             0.993358076923077, 0.988201923076923, 0.518445846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 361}], {
             RGBColor[
             0.9946406923076923, 0.9909453076923077, 0.6580506153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[0.8362434615384615, 0.872472, 0.9606630384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 98}], {
             RGBColor[
             0.9449578846153845, 0.8618534615384615, 0.6052693846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 106}], {
             RGBColor[
             0.9449578846153845, 0.8618534615384615, 0.6052693846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 107}], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 197}], {
             RGBColor[
             0.9529172692307692, 0.8934097692307691, 0.6116736923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 215}], {
             RGBColor[0.8908973076923077, 0.915168, 0.9661104230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 283}], {
             RGBColor[
             0.9543501538461538, 0.9654750000000001, 0.9621574615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 352}], {
             RGBColor[
             0.9692710769230769, 0.9766030000000001, 0.9369002307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 52}], {
             RGBColor[
             0.9467231538461538, 0.8190013846153845, 0.3149500384615383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 86}], {
             RGBColor[
             0.9295380384615384, 0.8247331538461539, 0.6114936923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 117}], {
             RGBColor[
             0.9531997692307692, 0.839793076923077, 0.4298584999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 174}], {
             RGBColor[
             0.9016898076923077, 0.8028163076923077, 0.6188426538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 232}], {
             RGBColor[
             0.9444589615384615, 0.8358611538461539, 0.5862364615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 309}], {
             RGBColor[0.7554602692307693, 0.6873368461538463, 0.6048775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 371}], {
             RGBColor[
             0.950748423076923, 0.8397014615384616, 0.5375090769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 386}], {
             RGBColor[
             0.950748423076923, 0.8397014615384616, 0.5375090769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 16}], {
             RGBColor[
             0.8773203076923077, 0.9032243076923077, 0.9020307307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 73}], {
             RGBColor[
             0.9921893461538461, 0.9908536923076923, 0.7657011923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 115}], {
             RGBColor[
             0.9224495384615384, 0.9387673846153846, 0.906452423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 188}], {
             RGBColor[
             0.9910166153846154, 0.9905531538461538, 0.7985414615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 195}], {
             RGBColor[
             0.9681000769230769, 0.9748793076923077, 0.9008014615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 206}], {
             RGBColor[
             0.9910166153846154, 0.9905531538461538, 0.7985414615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 208}], {
             RGBColor[
             0.9921893461538461, 0.9908536923076923, 0.7657011923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 258}], {
             RGBColor[
             0.9910166153846154, 0.9905531538461538, 0.7985414615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 278}], {
             RGBColor[
             0.9224495384615384, 0.9387673846153846, 0.906452423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 284}], {
             RGBColor[
             0.9587078076923077, 0.8712577692307693, 0.5439133846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 369}], {
             RGBColor[
             0.9852851923076922, 0.9691475384615383, 0.6042578076923074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 392}], {
             RGBColor[
             0.9910166153846154, 0.9905531538461538, 0.7985414615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 99}], {
             RGBColor[0.9596504230769229, 0.9654202307692307, 0.709128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 174}], {
             RGBColor[0.9418481153846154, 0.9512251538461538, 0.70743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 193}], {
             RGBColor[
             0.9377906923076923, 0.7741705384615385, 0.32476303846153837`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 223}], {
             RGBColor[
             0.7665353461538462, 0.8121346153846154, 0.6911753076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 235}], {
             RGBColor[
             0.9909067307692307, 0.9881103076923077, 0.6260964230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 260}], {
             RGBColor[0.9846172692307692, 0.98427, 0.6748238076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 267}], {
             RGBColor[
             0.9377906923076923, 0.7741705384615385, 0.32476303846153837`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 272}], {
             RGBColor[
             0.9909067307692307, 0.9881103076923077, 0.6260964230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 275}], {
             RGBColor[
             0.9603040769230768, 0.8695204615384615, 0.34319296153846146`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 291}], {
             RGBColor[
             0.9307411538461539, 0.7421602307692308, 0.3188807307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 321}], {
             RGBColor[
             0.9937856153846154, 0.9891163846153845, 0.5649807692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 338}], {
             RGBColor[
             0.9603040769230768, 0.8695204615384615, 0.34319296153846146`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 384}], {
             RGBColor[0.9062435, 0.922835, 0.7040339999999998]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{5, 398}], {
             RGBColor[
             0.9448402307692307, 0.806180846153846, 0.33064534615384605`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 13}], {
             RGBColor[
             0.8555886153846154, 0.8876871538461538, 0.9860880000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 18}], {
             RGBColor[
             0.9029410769230769, 0.9238667692307692, 0.9330298076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 74}], {
             RGBColor[0.5194276538461539, 0.6033375, 0.9592338846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 102}], {
             RGBColor[0.49945550000000005`, 0.5823455, 0.9580965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 132}], {
             RGBColor[
             0.9063533846153846, 0.9252778461538462, 0.8764790384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 160}], {
             RGBColor[
             0.8444816538461539, 0.6786222307692309, 0.5975387307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 166}], {
             RGBColor[0.8908973076923077, 0.915168, 0.9661104230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 185}], {
             RGBColor[
             0.9070985769230769, 0.9246639230769231, 0.7971038461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 198}], {
             RGBColor[
             0.8312933461538462, 0.5938827692307692, 0.5855608461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 213}], {
             RGBColor[0.8834368461538462, 0.909604, 0.9787390384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 216}], {
             RGBColor[
             0.8820039615384615, 0.837538769230769, 0.6282552692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 224}], {
             RGBColor[0.8983577692307692, 0.920732, 0.9534818076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 247}], {
             RGBColor[
             0.8555886153846154, 0.8876871538461538, 0.9860880000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 289}], {
             RGBColor[0.8983577692307692, 0.920732, 0.9534818076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 302}], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 323}], {
             RGBColor[
             0.9070985769230769, 0.9246639230769231, 0.7971038461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 340}], {
             RGBColor[0.8908973076923077, 0.915168, 0.9661104230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 40}], {
             RGBColor[
             0.9876043076923076, 0.989142076923077, 0.8550922307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 41}], {
             RGBColor[
             0.9900556538461538, 0.9892336923076923, 0.7474416538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 80}], {
             RGBColor[
             0.9858981538461538, 0.9884365384615384, 0.8833676153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 96}], {
             RGBColor[
             0.9779574999999999, 0.9494792307692307, 0.6106945769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 114}], {
             RGBColor[
             0.9876043076923076, 0.989142076923077, 0.8550922307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 153}], {
             RGBColor[
             0.9904831923076922, 0.9901481538461538, 0.7939765769230772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 154}], {
             RGBColor[
             0.9738543846153846, 0.9797377692307693, 0.9164482307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 192}], {
             RGBColor[
             0.9490422692307692, 0.8389959230769231, 0.5657844615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 203}], {
             RGBColor[
             0.9738543846153846, 0.9797377692307693, 0.9164482307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 222}], {
             RGBColor[
             0.8756141538461538, 0.9025187692307692, 0.9303061153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 228}], {
             RGBColor[
             0.8756141538461538, 0.9025187692307692, 0.9303061153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 312}], {
             RGBColor[
             0.9029410769230769, 0.9238667692307692, 0.9330298076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 332}], {
             RGBColor[
             0.9563479999999999, 0.9664519999999999, 0.9381238076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 356}], {
             RGBColor[
             0.989200576923077, 0.9874047692307693, 0.6543718076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 361}], {
             RGBColor[
             0.9904831923076922, 0.9901481538461538, 0.7939765769230772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 385}], {
             RGBColor[
             0.9876043076923076, 0.989142076923077, 0.8550922307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 17}], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.9780118846153847, 0.9805349230769231, 0.7805222692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 36}], {
             RGBColor[0.982115, 0.9502763846153846, 0.47476861538461523`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 60}], {
             RGBColor[
             0.9780118846153847, 0.9805349230769231, 0.7805222692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 64}], {
             RGBColor[
             0.9780118846153847, 0.9805349230769231, 0.7805222692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.993358076923077, 0.988201923076923, 0.518445846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 157}], {
             RGBColor[
             0.9917618076923076, 0.9899392307692307, 0.7191662692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 171}], {
             RGBColor[
             0.993358076923077, 0.988201923076923, 0.518445846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 182}], {
             RGBColor[
             0.7673904230769231, 0.8139635384615385, 0.7842451538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 210}], {
             RGBColor[
             0.9917618076923076, 0.9899392307692307, 0.7191662692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 253}], {
             RGBColor[
             0.9854723461538462, 0.986098923076923, 0.7678936538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 61}], {
             RGBColor[
             0.5728345769230768, 0.6459227307692307, 0.9643278846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 131}], {
             RGBColor[
             0.9427858076923076, 0.908531923076923, 0.6436121538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 142}], {
             RGBColor[0.926797846153846, 0.9444674615384614, 0.99288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 202}], {
             RGBColor[
             0.9049381153846152, 0.7532177692307691, 0.6085150384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 214}], {
             RGBColor[
             0.9274514999999999, 0.8485676923076921, 0.6269449615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 215}], {
             RGBColor[0.873390923076923, 0.9018822307692307, 0.987786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 217}], {
             RGBColor[
             0.9609330384615384, 0.9681636153846154, 0.8487327692307695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 269}], {
             RGBColor[
             0.7627659999999999, 0.8147929230769231, 0.9772168461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 279}], {
             RGBColor[
             0.9605054999999999, 0.9672491538461538, 0.8021978461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 300}], {
             RGBColor[
             0.9580541538461538, 0.9671575384615384, 0.909848423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 306}], {
             RGBColor[
             0.9517646923076921, 0.9633172307692307, 0.9585758076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 363}], {
             RGBColor[
             0.8460639999999999, 0.8805342307692307, 0.9850623076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 39}], {
             RGBColor[
             0.8499933846153845, 0.8818763076923077, 0.8993070384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 177}], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.8482872307692306, 0.8811707692307692, 0.9275824230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 200}], {
             RGBColor[
             0.8009347692307691, 0.8449911538461539, 0.9806406153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 216}], {
             RGBColor[
             0.8273501153846152, 0.794842769230769, 0.6228078846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 219}], {
             RGBColor[
             0.8524447307692307, 0.8819679230769231, 0.7916564615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 241}], {
             RGBColor[
             0.8524447307692307, 0.8819679230769231, 0.7916564615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 296}], {
             RGBColor[
             0.6547052307692307, 0.7295116923076923, 0.9666754615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 311}], {
             RGBColor[
             0.811431346153846, 0.7317301538461538, 0.6099992692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 339}], {
             RGBColor[
             0.8009347692307691, 0.8449911538461539, 0.9806406153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 360}], {
             RGBColor[
             0.8273501153846152, 0.794842769230769, 0.6228078846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 374}], {
             RGBColor[
             0.8347250384615383, 0.8232506923076923, 0.6330707692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 14}], {
             RGBColor[
             0.8793441153846154, 0.9024014615384615, 0.7478452307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 25}], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 38}], {
             RGBColor[
             0.9053385384615384, 0.5611644615384616, 0.3413319230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 78}], {
             RGBColor[
             0.993358076923077, 0.9882019230769231, 0.5184458461538463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 102}], {
             RGBColor[
             0.5861425384615385, 0.6467979615384616, 0.7259734230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 144}], {
             RGBColor[
             0.9929305384615386, 0.9872874615384615, 0.47191092307692306`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 205}], {
             RGBColor[
             0.9760659230769231, 0.9303991538461538, 0.40639507692307697`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 207}], {
             RGBColor[
             0.9850448076923077, 0.9851844615384615, 0.7213587307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 213}], {
             RGBColor[
             0.9701238846153846, 0.9740564615384615, 0.7466159615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 221}], {
             RGBColor[
             0.9053385384615384, 0.5611644615384616, 0.3413319230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 230}], {
             RGBColor[
             0.9850448076923077, 0.9851844615384615, 0.7213587307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 250}], {
             RGBColor[
             0.9913342692307692, 0.9890247692307692, 0.6726313461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 289}], {
             RGBColor[
             0.9850448076923077, 0.9851844615384615, 0.7213587307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 358}], {
             RGBColor[
             0.9452677692307692, 0.8070953076923076, 0.37718026923076925`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 391}], {
             RGBColor[0.987309, 0.9683246923076922, 0.45007230769230755`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 118}], {
             RGBColor[
             0.9701238846153846, 0.9740564615384615, 0.7466159615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 126}], {
             RGBColor[
             0.9937856153846154, 0.9891163846153846, 0.5649807692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 149}], {
             RGBColor[
             0.9452677692307692, 0.8070953076923076, 0.37718026923076925`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 199}], {
             RGBColor[
             0.9850448076923077, 0.9851844615384615, 0.7213587307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 212}], {
             RGBColor[0.987309, 0.9683246923076922, 0.45007230769230755`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 238}], {
             RGBColor[
             0.9930404230769231, 0.9897303076923077, 0.6443559615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 259}], {
             RGBColor[
             0.9760659230769231, 0.9303991538461538, 0.40639507692307697`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 274}], {
             RGBColor[0.968691, 0.9019912307692306, 0.3961321923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 299}], {
             RGBColor[
             0.8520171923076922, 0.8810534615384615, 0.7451215384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 318}], {
             RGBColor[
             0.9422756538461539, 0.9521396153846153, 0.7539649230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 336}], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 367}], {
             RGBColor[
             0.9929305384615386, 0.9872874615384615, 0.47191092307692306`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 18}], {
             RGBColor[
             0.9385456923076922, 0.9522569230769231, 0.9364258076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 69}], {
             RGBColor[
             0.9431307307692307, 0.9539685384615384, 0.8470347692307695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 74}], {
             RGBColor[
             0.5550322692307692, 0.6317276538461538, 0.9626298846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 88}], {
             RGBColor[0.9089955384615384, 0.9302723846153845, 0.991182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 132}], {
             RGBColor[0.941958, 0.953668, 0.8798750384615385]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[0.8542561153846153, 0.5251021538461538, 0.576851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 191}], {
             RGBColor[0.8542561153846153, 0.5251021538461538, 0.576851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 198}], {
             RGBColor[
             0.8668979615384615, 0.6222729230769231, 0.5889568461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 216}], {
             RGBColor[
             0.9176085769230768, 0.8659289230769229, 0.6316512692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 224}], {
             RGBColor[
             0.9339623846153846, 0.9491221538461538, 0.9568778076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 302}], {
             RGBColor[
             0.8555886153846154, 0.8876871538461538, 0.9860880000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 323}], {
             RGBColor[
             0.9427031923076923, 0.9530540769230769, 0.8004998461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 340}], {
             RGBColor[
             0.9265019230769231, 0.9435581538461539, 0.969506423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 357}], {
             RGBColor[
             0.8555886153846154, 0.8876871538461538, 0.9860880000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 38}], {
             RGBColor[
             0.791324576923077, 0.47536399999999995`, 0.5707313076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 102}], {
             RGBColor[
             0.47212857692307697`, 0.5609974999999999, 0.9553728076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 205}], {
             RGBColor[
             0.8620519615384615, 0.8445986923076922, 0.6357944615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 207}], {
             RGBColor[0.8710308461538461, 0.899384, 0.9507581153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.8561099230769231, 0.8882559999999999, 0.9760153461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 224}], {
             RGBColor[0.8710308461538461, 0.899384, 0.9507581153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 230}], {
             RGBColor[0.8710308461538461, 0.899384, 0.9507581153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 247}], {
             RGBColor[
             0.8282616923076923, 0.8663391538461538, 0.9833643076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 250}], {
             RGBColor[
             0.8773203076923077, 0.9032243076923077, 0.9020307307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 289}], {
             RGBColor[0.8710308461538461, 0.899384, 0.9507581153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 340}], {
             RGBColor[
             0.8635703846153846, 0.8938200000000001, 0.9633867307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 391}], {
             RGBColor[
             0.8732950384615384, 0.8825242307692306, 0.6794716923076921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 45}], {
             RGBColor[
             0.9683733461538461, 0.9035196153846152, 0.5220423076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 100}], {
             RGBColor[
             0.9682634615384615, 0.9010767692307691, 0.34959726923076906`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 105}], {
             RGBColor[
             0.8998062692307691, 0.851733846153846, 0.6299532692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.9666671923076922, 0.9028140769230768, 0.5503176923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 155}], {
             RGBColor[
             0.9695460769230768, 0.9038201538461537, 0.48920203846153865`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 170}], {
             RGBColor[
             0.8806714615384614, 0.47495376923076904`, 0.21901826923076917`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 180}], {
             RGBColor[
             0.9683733461538461, 0.9035196153846152, 0.5220423076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 183}], {
             RGBColor[
             0.9682634615384615, 0.9010767692307691, 0.34959726923076906`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 239}], {
             RGBColor[
             0.9529172692307692, 0.8934097692307691, 0.6116736923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 271}], {
             RGBColor[
             0.9666671923076922, 0.9028140769230768, 0.5503176923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 273}], {
             RGBColor[
             0.9683733461538461, 0.9035196153846152, 0.5220423076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 326}], {
             RGBColor[
             0.9691185384615384, 0.9029056923076921, 0.4426671153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 335}], {
             RGBColor[
             0.9695460769230768, 0.9038201538461537, 0.48920203846153865`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 394}], {
             RGBColor[
             0.9683733461538461, 0.9035196153846152, 0.5220423076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 73}], {
             RGBColor[
             0.8801991923076924, 0.9042303846153845, 0.8409150769230771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 85}], {
             RGBColor[
             0.8790264615384615, 0.9039298461538461, 0.8737553461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 96}], {
             RGBColor[0.8676735, 0.8635614615384615, 0.6576330769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 110}], {
             RGBColor[
             0.8635703846153846, 0.8938200000000001, 0.9633867307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 115}], {
             RGBColor[
             0.8104593846153847, 0.8521440769230768, 0.9816663076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 184}], {
             RGBColor[
             0.8789165769230769, 0.9014869999999999, 0.7013103076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 188}], {
             RGBColor[
             0.8790264615384615, 0.9039298461538461, 0.8737553461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 203}], {
             RGBColor[
             0.8635703846153846, 0.8938200000000001, 0.9633867307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 206}], {
             RGBColor[
             0.8790264615384615, 0.9039298461538461, 0.8737553461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 208}], {
             RGBColor[
             0.8801991923076924, 0.9042303846153845, 0.8409150769230771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 258}], {
             RGBColor[
             0.8790264615384615, 0.9039298461538461, 0.8737553461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 284}], {
             RGBColor[
             0.8467176538461538, 0.7846344615384615, 0.6191272692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 325}], {
             RGBColor[
             0.8773203076923077, 0.9032243076923077, 0.9020307307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 348}], {
             RGBColor[
             0.8790264615384615, 0.9039298461538461, 0.8737553461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 369}], {
             RGBColor[
             0.8732950384615384, 0.8825242307692306, 0.6794716923076921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 392}], {
             RGBColor[
             0.8790264615384615, 0.9039298461538461, 0.8737553461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 36}], {
             RGBColor[0.982115, 0.9502763846153846, 0.47476861538461523`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 64}], {
             RGBColor[
             0.9780118846153847, 0.9805349230769231, 0.7805222692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 82}], {
             RGBColor[
             0.993358076923077, 0.988201923076923, 0.518445846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 122}], {
             RGBColor[
             0.9877365384615384, 0.9692391538461538, 0.4966072307692305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 157}], {
             RGBColor[
             0.9917618076923076, 0.9899392307692307, 0.7191662692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 187}], {
             RGBColor[
             0.9854723461538462, 0.986098923076923, 0.7678936538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 218}], {
             RGBColor[
             0.9057660769230769, 0.5620789230769231, 0.3878668461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 253}], {
             RGBColor[
             0.9854723461538462, 0.986098923076923, 0.7678936538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 262}], {
             RGBColor[
             0.9780118846153847, 0.9805349230769231, 0.7805222692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 298}], {
             RGBColor[
             0.9386457692307693, 0.7759994615384616, 0.4178328846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 74}], {
             RGBColor[
             0.6023847307692307, 0.6679072692307693, 0.9095716923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 132}], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.8268168461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 140}], {
             RGBColor[
             0.9016085769230768, 0.5612817692307692, 0.5237928076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 191}], {
             RGBColor[
             0.9016085769230768, 0.5612817692307692, 0.5237928076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.9142504230769231, 0.6584525384615385, 0.5358986538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 216}], {
             RGBColor[
             0.9649610384615384, 0.9021085384615383, 0.5785930769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.9813148461538461, 0.9853017692307693, 0.9038196153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 247}], {
             RGBColor[
             0.9385456923076922, 0.9522569230769231, 0.9364258076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 302}], {
             RGBColor[
             0.9029410769230769, 0.9238667692307692, 0.9330298076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 311}], {
             RGBColor[
             0.9490422692307692, 0.8389959230769231, 0.5657844615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 323}], {
             RGBColor[
             0.9900556538461538, 0.9892336923076923, 0.7474416538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 340}], {
             RGBColor[
             0.9738543846153846, 0.9797377692307693, 0.9164482307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 357}], {
             RGBColor[
             0.9029410769230769, 0.9238667692307692, 0.9330298076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 83}], {
             RGBColor[
             0.8163769999999999, 0.8566879999999999, 0.9453107307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 108}], {
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 125}], {
             RGBColor[
             0.9789957307692307, 0.9653072307692306, 0.6529851923076921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 179}], {
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 196}], {
             RGBColor[
             0.9789957307692307, 0.9653072307692306, 0.6529851923076921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 231}], {
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 303}], {
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 313}], {
             RGBColor[
             0.9161600769230769, 0.9349270769230769, 0.9551798076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 344}], {
             RGBColor[
             0.9858998846153846, 0.9870133846153846, 0.8144285769230771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 50}], {
             RGBColor[0.941958, 0.953668, 0.8798750384615385]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{20, 54}], {
             RGBColor[
             0.9385456923076922, 0.9522569230769231, 0.9364258076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 116}], {
             RGBColor[
             0.7158804615384615, 0.7769867692307693, 0.9732293076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 121}], {
             RGBColor[
             0.9422756538461539, 0.9521396153846153, 0.7539649230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 130}], {
             RGBColor[0.9249835, 0.8943368461538461, 0.6419141538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 135}], {
             RGBColor[
             0.9385456923076922, 0.9522569230769231, 0.9364258076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 147}], {
             RGBColor[
             0.8555886153846154, 0.8876871538461538, 0.9860880000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 158}], {
             RGBColor[
             0.9265019230769231, 0.9435581538461539, 0.969506423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 172}], {
             RGBColor[
             0.9306050384615384, 0.9132996153846153, 0.6637527692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 181}], {
             RGBColor[0.9089955384615384, 0.9302723846153845, 0.991182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 265}], {
             RGBColor[
             0.9190414615384614, 0.9379941538461538, 0.9821350384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 322}], {
             RGBColor[
             0.9418481153846154, 0.9512251538461538, 0.7074299999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 328}], {
             RGBColor[
             0.9176085769230768, 0.8659289230769229, 0.6316512692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 347}], {
             RGBColor[
             0.894185346153846, 0.7710329999999999, 0.6126993461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 362}], {
             RGBColor[
             0.9427031923076923, 0.9530540769230769, 0.8004998461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 364}], {
             RGBColor[
             0.9190414615384614, 0.9379941538461538, 0.9821350384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 387}], {
             RGBColor[
             0.940251846153846, 0.9529624615384615, 0.9081504230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.9659137307692307, 0.9407804615384615, 0.6437751923076921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 60}], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 64}], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 82}], {
             RGBColor[
             0.9771568076923077, 0.9787060000000001, 0.6874524230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 122}], {
             RGBColor[
             0.9715352692307693, 0.9597432307692306, 0.6656138076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 159}], {
             RGBColor[
             0.9784394230769231, 0.9814493846153847, 0.8270571923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 182}], {
             RGBColor[
             0.7511891538461539, 0.8044676153846154, 0.9532517307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 210}], {
             RGBColor[
             0.9755605384615385, 0.9804433076923078, 0.8881728461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 263}], {
             RGBColor[
             0.9775843461538463, 0.9796204615384616, 0.7339873461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 29}], {
             RGBColor[
             0.9224495384615384, 0.9387673846153846, 0.906452423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 45}], {
             RGBColor[
             0.9910166153846154, 0.9905531538461538, 0.7985414615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 91}], {
             RGBColor[
             0.9910166153846154, 0.9905531538461538, 0.7985414615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 97}], {
             RGBColor[
             0.9852851923076922, 0.9691475384615383, 0.6042578076923074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 100}], {
             RGBColor[
             0.9909067307692307, 0.9881103076923077, 0.6260964230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 141}], {
             RGBColor[
             0.9876043076923076, 0.989142076923077, 0.8550922307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 150}], {
             RGBColor[
             0.9876043076923076, 0.989142076923077, 0.8550922307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 189}], {
             RGBColor[
             0.9876043076923076, 0.989142076923077, 0.8550922307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 190}], {
             RGBColor[
             0.9921893461538461, 0.9908536923076923, 0.7657011923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 255}], {
             RGBColor[
             0.940251846153846, 0.9529624615384615, 0.9081504230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 266}], {
             RGBColor[
             0.9796636538461538, 0.9501847692307692, 0.5824191923076921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 273}], {
             RGBColor[
             0.9910166153846154, 0.9905531538461538, 0.7985414615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 350}], {
             RGBColor[
             0.7101933076923077, 0.7688229230769231, 0.8877528076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 365}], {
             RGBColor[
             0.9909067307692307, 0.9881103076923077, 0.6260964230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 394}], {
             RGBColor[
             0.9910166153846154, 0.9905531538461538, 0.7985414615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[
             0.9937856153846154, 0.9891163846153846, 0.5649807692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 89}], {
             RGBColor[
             0.9877365384615384, 0.9692391538461538, 0.4966072307692305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 163}], {
             RGBColor[
             0.9456953076923076, 0.8080097692307692, 0.4237151923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 164}], {
             RGBColor[
             0.9937856153846154, 0.9891163846153846, 0.5649807692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 169}], {
             RGBColor[
             0.9456953076923076, 0.8080097692307692, 0.4237151923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 227}], {
             RGBColor[
             0.9917618076923076, 0.9899392307692307, 0.7191662692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 245}], {
             RGBColor[
             0.970551423076923, 0.974970923076923, 0.7931508846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 292}], {
             RGBColor[
             0.9946406923076923, 0.9909453076923077, 0.6580506153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 304}], {
             RGBColor[
             0.9070985769230769, 0.9246639230769231, 0.7971038461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 353}], {
             RGBColor[
             0.9780118846153847, 0.9805349230769231, 0.7805222692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 378}], {
             RGBColor[
             0.9900556538461538, 0.9892336923076923, 0.7474416538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 25}], {
             RGBColor[
             0.9904831923076922, 0.9901481538461538, 0.7939765769230772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 76}], {
             RGBColor[
             0.9570016538461538, 0.8705522307692307, 0.5721887692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 104}], {
             RGBColor[
             0.8756141538461538, 0.9025187692307692, 0.9303061153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 109}], {
             RGBColor[
             0.9904831923076922, 0.9901481538461538, 0.7939765769230772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 138}], {
             RGBColor[
             0.9858981538461538, 0.9884365384615384, 0.8833676153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 144}], {
             RGBColor[
             0.989200576923077, 0.9874047692307693, 0.6543718076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 207}], {
             RGBColor[
             0.9813148461538461, 0.9853017692307693, 0.9038196153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 233}], {
             RGBColor[
             0.9563479999999999, 0.9664519999999999, 0.9381238076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 242}], {
             RGBColor[
             0.9835790384615384, 0.9684419999999998, 0.6325331923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 317}], {
             RGBColor[
             0.9490422692307692, 0.8389959230769231, 0.5657844615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 358}], {
             RGBColor[
             0.9415378076923075, 0.8072126153846153, 0.5596411538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 366}], {
             RGBColor[
             0.9490422692307692, 0.8389959230769231, 0.5657844615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 382}], {
             RGBColor[
             0.9779574999999999, 0.9494792307692307, 0.6106945769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[
             0.9615866923076923, 0.8722638461538461, 0.482797730769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 104}], {
             RGBColor[
             0.8801991923076924, 0.9042303846153845, 0.8409150769230771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 109}], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 138}], {
             RGBColor[
             0.9904831923076922, 0.9901481538461538, 0.7939765769230772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 144}], {
             RGBColor[
             0.9937856153846154, 0.9891163846153845, 0.5649807692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 205}], {
             RGBColor[
             0.9769209999999999, 0.9322280769230769, 0.49946492307692325`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 207}], {
             RGBColor[
             0.9858998846153846, 0.9870133846153846, 0.8144285769230771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 233}], {
             RGBColor[
             0.9609330384615384, 0.9681636153846154, 0.8487327692307695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 317}], {
             RGBColor[
             0.9536273076923076, 0.8407075384615386, 0.47639342307692334`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 358}], {
             RGBColor[
             0.9461228461538461, 0.8089242307692307, 0.4702501153846156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 366}], {
             RGBColor[
             0.9536273076923076, 0.8407075384615386, 0.47639342307692334`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 382}], {
             RGBColor[
             0.9825425384615385, 0.9511908461538461, 0.5213035384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 391}], {
             RGBColor[
             0.9881640769230768, 0.9701536153846153, 0.5431421538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 30}], {
             RGBColor[0.9846172692307692, 0.98427, 0.6748238076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 62}], {
             RGBColor[
             0.9830209999999999, 0.9860073076923077, 0.8755442307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 77}], {
             RGBColor[0.9846172692307692, 0.98427, 0.6748238076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 106}], {
             RGBColor[
             0.952418346153846, 0.8674174615384616, 0.5926407692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 111}], {
             RGBColor[
             0.9789957307692307, 0.9653072307692306, 0.6529851923076921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 160}], {
             RGBColor[
             0.922855423076923, 0.7400572307692308, 0.5683285384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.9692710769230769, 0.9766030000000001, 0.9369002307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 173}], {
             RGBColor[
             0.9677526538461538, 0.9273816923076923, 0.6093079615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 185}], {
             RGBColor[
             0.9854723461538462, 0.986098923076923, 0.7678936538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 197}], {
             RGBColor[
             0.9603777307692307, 0.8989737692307691, 0.5990450769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 204}], {
             RGBColor[
             0.9830209999999999, 0.9860073076923077, 0.8755442307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 345}], {
             RGBColor[
             0.922855423076923, 0.7400572307692308, 0.5683285384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 370}], {
             RGBColor[0.8983577692307692, 0.920732, 0.9534818076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 389}], {
             RGBColor[
             0.8163769999999999, 0.8566879999999999, 0.9453107307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 400}], {
             RGBColor[
             0.9850448076923077, 0.9851844615384615, 0.7213587307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 51}], {
             RGBColor[
             0.9315962307692307, 0.7439891538461539, 0.4119505769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[
             0.8760288461538461, 0.5299577692307693, 0.21826776923076924`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 277}], {
             RGBColor[
             0.9274387307692307, 0.7431920000000001, 0.5478765384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 287}], {
             RGBColor[
             0.8622839615384615, 0.6928173076923078, 0.5992367307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 376}], {
             RGBColor[
             0.9308510384615385, 0.744603076923077, 0.49132576923076926`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 377}], {
             RGBColor[
             0.9320237692307692, 0.7449036153846155, 0.4584855000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 395}], {
             RGBColor[
             0.8760288461538461, 0.5299577692307693, 0.21826776923076924`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 396}], {
             RGBColor[
             0.9251196153846153, 0.7231974615384615, 0.2970421153846152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 44}], {
             RGBColor[
             0.922855423076923, 0.7400572307692308, 0.5683285384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 47}], {
             RGBColor[
             0.9854723461538462, 0.986098923076923, 0.7678936538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 49}], {
             RGBColor[
             0.9517646923076921, 0.9633172307692307, 0.9585758076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 147}], {
             RGBColor[0.8983577692307692, 0.920732, 0.9534818076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 211}], {
             RGBColor[0.9846172692307692, 0.98427, 0.6748238076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 301}], {
             RGBColor[
             0.9733741923076922, 0.9463444615384615, 0.6311465769230767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 328}], {
             RGBColor[
             0.9603777307692307, 0.8989737692307691, 0.5990450769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 347}], {
             RGBColor[
             0.9369544999999999, 0.804077846153846, 0.5800931538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 362}], {
             RGBColor[
             0.9854723461538462, 0.986098923076923, 0.7678936538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 372}], {
             RGBColor[
             0.9603777307692307, 0.8989737692307691, 0.5990450769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 380}], {
             RGBColor[
             0.9299049615384615, 0.7720675384615385, 0.5742108461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 390}], {
             RGBColor[0.9846172692307692, 0.98427, 0.6748238076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 45}], {
             RGBColor[
             0.9241556923076923, 0.9394729230769231, 0.8781770384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 91}], {
             RGBColor[
             0.9241556923076923, 0.9394729230769231, 0.8781770384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 150}], {
             RGBColor[
             0.9207433846153845, 0.9380618461538461, 0.9347278076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 190}], {
             RGBColor[
             0.9253284230769231, 0.9397734615384615, 0.8453367692307694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 226}], {
             RGBColor[
             0.8763830384615384, 0.756837923076923, 0.6110013461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 266}], {
             RGBColor[
             0.9128027307692308, 0.8991045384615384, 0.6620547692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 273}], {
             RGBColor[
             0.9241556923076923, 0.9394729230769231, 0.8781770384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 365}], {
             RGBColor[
             0.9240458076923077, 0.9370300769230768, 0.7057319999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 62}], {
             RGBColor[
             0.9909067307692307, 0.9881103076923077, 0.6260964230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 77}], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 84}], {
             RGBColor[
             0.9240458076923077, 0.9370300769230768, 0.7057319999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 204}], {
             RGBColor[
             0.9909067307692307, 0.9881103076923077, 0.6260964230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 333}], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 370}], {
             RGBColor[0.9062435, 0.922835, 0.7040339999999998]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{30, 389}], {
             RGBColor[
             0.8242627307692307, 0.8587909999999999, 0.6958629230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 400}], {
             RGBColor[
             0.9929305384615386, 0.9872874615384615, 0.47191092307692306`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 33}], {
             RGBColor[
             0.9443042307692306, 0.9577532307692307, 0.971204423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 106}], {
             RGBColor[
             0.9449578846153845, 0.8618534615384615, 0.6052693846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 156}], {
             RGBColor[
             0.9772666923076923, 0.9811488461538462, 0.8598974615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 173}], {
             RGBColor[
             0.9602921923076924, 0.9218176923076924, 0.6219365769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 175}], {
             RGBColor[
             0.9738543846153846, 0.9797377692307693, 0.9164482307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 197}], {
             RGBColor[
             0.9529172692307692, 0.8934097692307691, 0.6116736923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 204}], {
             RGBColor[
             0.9755605384615385, 0.9804433076923078, 0.8881728461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 214}], {
             RGBColor[
             0.9449578846153845, 0.8618534615384615, 0.6052693846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 261}], {
             RGBColor[
             0.9772666923076923, 0.9811488461538462, 0.8598974615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 295}], {
             RGBColor[
             0.9529172692307692, 0.8934097692307691, 0.6116736923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 310}], {
             RGBColor[
             0.9543501538461538, 0.9654750000000001, 0.9621574615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 345}], {
             RGBColor[
             0.9153949615384616, 0.7344932307692309, 0.5809571538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 43}], {
             RGBColor[
             0.8515311923076923, 0.7106325384615384, 0.6034210384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 124}], {
             RGBColor[
             0.9149840384615384, 0.7609395384615385, 0.5994680769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 137}], {
             RGBColor[
             0.890127923076923, 0.5939783846153845, 0.2300323846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 199}], {
             RGBColor[
             0.9299049615384615, 0.7720675384615385, 0.5742108461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 238}], {
             RGBColor[
             0.9379005769230768, 0.7766133846153846, 0.49720807692307695`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 252}], {
             RGBColor[
             0.8760288461538461, 0.5299577692307693, 0.21826776923076924`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 293}], {
             RGBColor[
             0.8830783846153846, 0.5619680769230769, 0.22415007692307692`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 330}], {
             RGBColor[
             0.936194423076923, 0.7759078461538462, 0.5254834615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 63}], {
             RGBColor[
             0.9580541538461538, 0.9671575384615384, 0.909848423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 84}], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 90}], {
             RGBColor[
             0.9443042307692306, 0.9577532307692307, 0.971204423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 152}], {
             RGBColor[
             0.9609330384615384, 0.9681636153846154, 0.8487327692307695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 156}], {
             RGBColor[
             0.9597603076923076, 0.9678630769230769, 0.8815730384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 173}], {
             RGBColor[
             0.9427858076923076, 0.908531923076923, 0.6436121538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 175}], {
             RGBColor[
             0.9563479999999999, 0.9664519999999999, 0.9381238076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 204}], {
             RGBColor[
             0.9580541538461538, 0.9671575384615384, 0.909848423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 214}], {
             RGBColor[
             0.9274514999999999, 0.8485676923076921, 0.6269449615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 256}], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 261}], {
             RGBColor[
             0.9597603076923076, 0.9678630769230769, 0.8815730384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 264}], {
             RGBColor[0.9089955384615384, 0.9302723846153845, 0.991182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 295}], {
             RGBColor[
             0.9354108846153845, 0.8801239999999997, 0.6333492692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 310}], {
             RGBColor[
             0.9368437692307692, 0.9521892307692307, 0.9838330384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 333}], {
             RGBColor[
             0.9596504230769229, 0.9654202307692307, 0.7091279999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 381}], {
             RGBColor[
             0.9540288846153845, 0.9464574615384613, 0.6872893846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 53}], {
             RGBColor[
             0.9238737692307692, 0.7060061538461537, 0.3129557692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 68}], {
             RGBColor[
             0.6979061153846153, 0.5317677692307691, 0.5787550769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 86}], {
             RGBColor[
             0.9010671153846153, 0.6927751538461537, 0.5876608076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 95}], {
             RGBColor[
             0.908527576923077, 0.6983391538461536, 0.5750321923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 151}], {
             RGBColor[
             0.9222774999999999, 0.7077434615384615, 0.5136761923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 244}], {
             RGBColor[
             0.8362817692307691, 0.2798831538461537, 0.1823767692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 249}], {
             RGBColor[
             0.8732188846153845, 0.6708583076923075, 0.5950097692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 253}], {
             RGBColor[
             0.9159880384615384, 0.7039031538461538, 0.5624035769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 270}], {
             RGBColor[
             0.9070091538461538, 0.6491178461538459, 0.24743992307692303`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 308}], {
             RGBColor[
             0.8996342307692307, 0.6207099230769227, 0.23717703846153837`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 386}], {
             RGBColor[
             0.9222774999999999, 0.7077434615384615, 0.5136761923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 397}], {
             RGBColor[
             0.8910211923076922, 0.6850533846153843, 0.5967077692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 41}], {
             RGBColor[
             0.9854723461538462, 0.986098923076923, 0.7678936538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 57}], {
             RGBColor[
             0.9692710769230769, 0.9766030000000001, 0.9369002307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 92}], {
             RGBColor[
             0.9813148461538461, 0.9853017692307693, 0.9038196153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 114}], {
             RGBColor[
             0.9830209999999999, 0.9860073076923077, 0.8755442307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 153}], {
             RGBColor[
             0.9858998846153846, 0.9870133846153846, 0.8144285769230771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 188}], {
             RGBColor[
             0.9847271538461537, 0.9867128461538461, 0.8472688461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 195}], {
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 208}], {
             RGBColor[
             0.9858998846153846, 0.9870133846153846, 0.8144285769230771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 258}], {
             RGBColor[
             0.9847271538461537, 0.9867128461538461, 0.8472688461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 278}], {
             RGBColor[
             0.9161600769230769, 0.9349270769230769, 0.9551798076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 284}], {
             RGBColor[
             0.952418346153846, 0.8674174615384616, 0.5926407692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 327}], {
             RGBColor[
             0.9517646923076921, 0.9633172307692307, 0.9585758076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 337}], {
             RGBColor[
             0.9813148461538461, 0.9853017692307693, 0.9038196153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 354}], {
             RGBColor[0.8983577692307692, 0.920732, 0.9534818076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 369}], {
             RGBColor[
             0.9789957307692307, 0.9653072307692306, 0.6529851923076921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 392}], {
             RGBColor[
             0.9847271538461537, 0.9867128461538461, 0.8472688461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 55}], {
             RGBColor[0.982115, 0.9502763846153846, 0.47476861538461523`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 60}], {
             RGBColor[
             0.9659137307692307, 0.9407804615384615, 0.6437751923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 64}], {
             RGBColor[
             0.9659137307692307, 0.9407804615384615, 0.6437751923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 82}], {
             RGBColor[
             0.981259923076923, 0.9484474615384615, 0.381698769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 122}], {
             RGBColor[
             0.9756383846153845, 0.929484692307692, 0.35986015384615355`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 157}], {
             RGBColor[
             0.9796636538461538, 0.9501847692307692, 0.5824191923076921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 165}], {
             RGBColor[
             0.948407346153846, 0.9274946923076921, 0.6654507692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 218}], {
             RGBColor[
             0.8936679230769231, 0.5223244615384615, 0.2511197692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 262}], {
             RGBColor[
             0.9659137307692307, 0.9407804615384615, 0.6437751923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 298}], {
             RGBColor[
             0.9265476153846153, 0.7362449999999999, 0.28108580769230757`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 314}], {
             RGBColor[
             0.9659137307692307, 0.9407804615384615, 0.6437751923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 58}], {
             RGBColor[
             0.9431307307692307, 0.9539685384615384, 0.8470347692307695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 87}], {
             RGBColor[
             0.9881640769230768, 0.9701536153846153, 0.5431421538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 110}], {
             RGBColor[
             0.9784394230769231, 0.9814493846153847, 0.8270571923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 134}], {
             RGBColor[
             0.9881640769230768, 0.9701536153846153, 0.5431421538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 159}], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 167}], {
             RGBColor[
             0.9709789615384615, 0.9758853846153845, 0.8396858076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 201}], {
             RGBColor[
             0.8801991923076924, 0.9042303846153845, 0.8409150769230771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 236}], {
             RGBColor[
             0.9881640769230768, 0.9701536153846153, 0.5431421538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 243}], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 263}], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 348}], {
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 351}], {
             RGBColor[
             0.9075261153846155, 0.9255783846153847, 0.8436387692307694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 78}], {
             RGBColor[
             0.9053385384615384, 0.5611644615384616, 0.34133192307692317`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 102}], {
             RGBColor[0.498123, 0.2197605, 0.5488595000000001]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{38, 205}], {
             RGBColor[
             0.8880463846153845, 0.5033616923076922, 0.22928115384615383`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 207}], {
             RGBColor[0.8970252692307692, 0.558147, 0.5442448076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 213}], {
             RGBColor[
             0.8821043461538461, 0.5470189999999999, 0.5695020384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 221}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 224}], {
             RGBColor[0.8970252692307692, 0.558147, 0.5442448076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 230}], {
             RGBColor[0.8970252692307692, 0.558147, 0.5442448076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 247}], {
             RGBColor[0.8542561153846153, 0.5251021538461538, 0.576851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 250}], {
             RGBColor[
             0.9033147307692307, 0.5619873076923076, 0.49551742307692304`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 289}], {
             RGBColor[0.8970252692307692, 0.558147, 0.5442448076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 358}], {
             RGBColor[
             0.8572482307692307, 0.3800578461538461, 0.20006634615384614`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 391}], {
             RGBColor[
             0.8992894615384615, 0.5412872307692307, 0.2729583846153844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 93}], {
             RGBColor[
             0.9921893461538461, 0.9908536923076923, 0.7657011923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 94}], {
             RGBColor[
             0.8226664615384615, 0.8605283076923076, 0.896583346153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 119}], {
             RGBColor[
             0.9921893461538461, 0.9908536923076923, 0.7657011923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 128}], {
             RGBColor[
             0.9681000769230769, 0.9748793076923077, 0.9008014615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 177}], {
             RGBColor[
             0.9046472307692308, 0.9245723076923077, 0.904754423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 200}], {
             RGBColor[
             0.940251846153846, 0.9529624615384615, 0.9081504230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 225}], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 288}], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 296}], {
             RGBColor[0.7940223076923076, 0.837483, 0.8941852692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 316}], {
             RGBColor[
             0.9666671923076922, 0.9028140769230768, 0.5503176923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 324}], {
             RGBColor[
             0.9917618076923076, 0.9899392307692307, 0.7191662692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 355}], {
             RGBColor[0.9740421153846153, 0.931222, 0.5605805769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 360}], {
             RGBColor[
             0.9666671923076922, 0.9028140769230768, 0.5503176923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 374}], {
             RGBColor[0.9740421153846153, 0.931222, 0.5605805769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 375}], {
             RGBColor[0.9740421153846153, 0.931222, 0.5605805769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 380}], {
             RGBColor[
             0.936194423076923, 0.7759078461538462, 0.5254834615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 383}], {
             RGBColor[
             0.9681000769230769, 0.9748793076923077, 0.9008014615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 390}], {
             RGBColor[
             0.9909067307692307, 0.9881103076923077, 0.6260964230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 41}], {
             RGBColor[
             0.9917618076923076, 0.9899392307692307, 0.7191662692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 55}], {
             RGBColor[
             0.9917618076923076, 0.9899392307692307, 0.7191662692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 58}], {
             RGBColor[
             0.940251846153846, 0.9529624615384615, 0.9081504230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.9876043076923076, 0.989142076923077, 0.8550922307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 87}], {
             RGBColor[
             0.9852851923076922, 0.9691475384615383, 0.6042578076923074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 96}], {
             RGBColor[
             0.9796636538461538, 0.9501847692307692, 0.5824191923076921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 110}], {
             RGBColor[
             0.9755605384615385, 0.9804433076923078, 0.8881728461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 146}], {
             RGBColor[
             0.9224495384615384, 0.9387673846153846, 0.906452423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 154}], {
             RGBColor[
             0.9755605384615385, 0.9804433076923078, 0.8881728461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 159}], {
             RGBColor[
             0.9921893461538461, 0.9908536923076923, 0.7657011923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 167}], {
             RGBColor[
             0.9681000769230769, 0.9748793076923077, 0.9008014615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 192}], {
             RGBColor[
             0.950748423076923, 0.8397014615384616, 0.5375090769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 203}], {
             RGBColor[
             0.9755605384615385, 0.9804433076923078, 0.8881728461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 228}], {
             RGBColor[
             0.8773203076923077, 0.9032243076923077, 0.9020307307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 243}], {
             RGBColor[
             0.9913342692307692, 0.9890247692307692, 0.6726313461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 332}], {
             RGBColor[
             0.9580541538461538, 0.9671575384615384, 0.909848423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 348}], {
             RGBColor[
             0.9910166153846154, 0.9905531538461538, 0.7985414615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 361}], {
             RGBColor[
             0.9921893461538461, 0.9908536923076923, 0.7657011923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 385}], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 57}], {
             RGBColor[
             0.9780118846153847, 0.9805349230769231, 0.7805222692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.9900556538461538, 0.9892336923076923, 0.7474416538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 96}], {
             RGBColor[0.982115, 0.9502763846153846, 0.47476861538461523`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 114}], {
             RGBColor[
             0.9917618076923076, 0.9899392307692307, 0.7191662692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 153}], {
             RGBColor[
             0.9946406923076923, 0.9909453076923077, 0.6580506153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 154}], {
             RGBColor[
             0.9780118846153847, 0.9805349230769231, 0.7805222692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 188}], {
             RGBColor[
             0.9934679615384615, 0.9906447692307693, 0.6908908846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 203}], {
             RGBColor[
             0.9780118846153847, 0.9805349230769231, 0.7805222692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 222}], {
             RGBColor[
             0.8797716538461539, 0.903315923076923, 0.7943801538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 258}], {
             RGBColor[
             0.9934679615384615, 0.9906447692307693, 0.6908908846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 312}], {
             RGBColor[
             0.9070985769230769, 0.9246639230769231, 0.7971038461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 327}], {
             RGBColor[
             0.9605054999999999, 0.9672491538461538, 0.8021978461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 356}], {
             RGBColor[
             0.993358076923077, 0.988201923076923, 0.518445846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 361}], {
             RGBColor[
             0.9946406923076923, 0.9909453076923077, 0.6580506153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 369}], {
             RGBColor[
             0.9877365384615384, 0.9692391538461538, 0.4966072307692305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 104}], {
             RGBColor[
             0.8635703846153846, 0.8938200000000001, 0.9633867307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 109}], {
             RGBColor[
             0.9784394230769231, 0.9814493846153847, 0.8270571923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 136}], {
             RGBColor[
             0.9529172692307692, 0.8934097692307691, 0.6116736923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 205}], {
             RGBColor[
             0.9602921923076924, 0.9218176923076924, 0.6219365769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 207}], {
             RGBColor[
             0.9692710769230769, 0.9766030000000001, 0.9369002307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 221}], {
             RGBColor[0.8895648076923077, 0.552583, 0.556873423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 276}], {
             RGBColor[
             0.9659137307692307, 0.9407804615384615, 0.6437751923076921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 358}], {
             RGBColor[
             0.9294940384615384, 0.7985138461538461, 0.5927217692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 366}], {
             RGBColor[
             0.9369985000000001, 0.8302971538461539, 0.5988650769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 376}], {
             RGBColor[
             0.9772666923076923, 0.9811488461538462, 0.8598974615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 124}], {
             RGBColor[0.8834368461538462, 0.909604, 0.9787390384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 137}], {
             RGBColor[
             0.8585807307692308, 0.7426428461538461, 0.6093033461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 199}], {
             RGBColor[0.8983577692307692, 0.920732, 0.9534818076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 238}], {
             RGBColor[
             0.9063533846153846, 0.9252778461538462, 0.8764790384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 252}], {
             RGBColor[
             0.8444816538461539, 0.6786222307692309, 0.5975387307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 277}], {
             RGBColor[
             0.9029410769230769, 0.9238667692307692, 0.9330298076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 293}], {
             RGBColor[
             0.8515311923076923, 0.7106325384615384, 0.6034210384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 299}], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 330}], {
             RGBColor[
             0.9046472307692308, 0.9245723076923077, 0.904754423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 367}], {
             RGBColor[0.9062435, 0.922835, 0.7040339999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{44, 47}], {
             RGBColor[
             0.9315962307692307, 0.7439891538461539, 0.4119505769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 49}], {
             RGBColor[
             0.8978885769230769, 0.7212074615384616, 0.6026327307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 54}], {
             RGBColor[
             0.9274387307692307, 0.7431920000000001, 0.5478765384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 93}], {
             RGBColor[
             0.9320237692307692, 0.7449036153846155, 0.4584855000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[0.9079345, 0.7289292307692308, 0.5935857692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 211}], {
             RGBColor[
             0.9307411538461539, 0.7421602307692308, 0.3188807307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 301}], {
             RGBColor[
             0.919498076923077, 0.7042346923076923, 0.2752034999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 316}], {
             RGBColor[
             0.9065016153846153, 0.6568639999999999, 0.24310199999999996`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 324}], {
             RGBColor[
             0.9315962307692307, 0.7439891538461539, 0.4119505769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 328}], {
             RGBColor[
             0.9065016153846153, 0.6568639999999999, 0.24310199999999996`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 362}], {
             RGBColor[
             0.9315962307692307, 0.7439891538461539, 0.4119505769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 372}], {
             RGBColor[
             0.9065016153846153, 0.6568639999999999, 0.24310199999999996`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 380}], {
             RGBColor[
             0.8760288461538461, 0.5299577692307693, 0.21826776923076924`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 383}], {
             RGBColor[0.9079345, 0.7289292307692308, 0.5935857692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 390}], {
             RGBColor[
             0.9307411538461539, 0.7421602307692308, 0.3188807307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 91}], {
             RGBColor[
             0.9927227692307692, 0.9912586923076924, 0.7702660769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 97}], {
             RGBColor[
             0.9869913461538461, 0.9698530769230769, 0.5759824230769228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 100}], {
             RGBColor[
             0.9926128846153845, 0.9888158461538461, 0.5978210384615383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 112}], {
             RGBColor[
             0.9910166153846154, 0.9905531538461538, 0.7985414615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 141}], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.8268168461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 180}], {
             RGBColor[
             0.9927227692307692, 0.9912586923076924, 0.7702660769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 190}], {
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 266}], {
             RGBColor[
             0.9813698076923076, 0.9508903076923076, 0.5541438076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 271}], {
             RGBColor[
             0.9910166153846154, 0.9905531538461538, 0.7985414615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 273}], {
             RGBColor[
             0.9927227692307692, 0.9912586923076924, 0.7702660769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 350}], {
             RGBColor[
             0.7118994615384615, 0.7695284615384617, 0.8594774230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 365}], {
             RGBColor[
             0.9926128846153845, 0.9888158461538461, 0.5978210384615383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 394}], {
             RGBColor[
             0.9927227692307692, 0.9912586923076924, 0.7702660769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 59}], {
             RGBColor[
             0.9937856153846154, 0.9891163846153845, 0.5649807692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 287}], {
             RGBColor[
             0.9253284230769231, 0.9397734615384615, 0.8453367692307694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 373}], {
             RGBColor[
             0.8528722692307692, 0.8828823846153846, 0.8381913846153848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 395}], {
             RGBColor[
             0.9390733076923077, 0.7769139230769231, 0.4643678076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 54}], {
             RGBColor[
             0.9900556538461538, 0.9892336923076923, 0.7474416538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 121}], {
             RGBColor[
             0.9937856153846154, 0.9891163846153846, 0.5649807692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 128}], {
             RGBColor[
             0.970551423076923, 0.974970923076923, 0.7931508846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 130}], {
             RGBColor[
             0.9764934615384615, 0.9313136153846153, 0.45292999999999994`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.9780118846153847, 0.9805349230769231, 0.7805222692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 181}], {
             RGBColor[
             0.9605054999999999, 0.9672491538461538, 0.8021978461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 265}], {
             RGBColor[
             0.970551423076923, 0.974970923076923, 0.7931508846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 311}], {
             RGBColor[0.9531997692307692, 0.839793076923077, 0.4298585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 322}], {
             RGBColor[
             0.993358076923077, 0.988201923076923, 0.518445846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 362}], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 56}], {
             RGBColor[
             0.9881640769230768, 0.9701536153846153, 0.5431421538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 71}], {
             RGBColor[
             0.9784394230769231, 0.9814493846153847, 0.8270571923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 83}], {
             RGBColor[
             0.8255453461538461, 0.8615343846153846, 0.8354676923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 103}], {
             RGBColor[
             0.9921893461538461, 0.9908536923076923, 0.7657011923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 108}], {
             RGBColor[
             0.9858998846153846, 0.9870133846153846, 0.8144285769230771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 120}], {
             RGBColor[
             0.9946406923076923, 0.9909453076923077, 0.6580506153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 143}], {
             RGBColor[
             0.9784394230769231, 0.9814493846153847, 0.8270571923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 196}], {
             RGBColor[
             0.9881640769230768, 0.9701536153846153, 0.5431421538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 231}], {
             RGBColor[
             0.9709789615384615, 0.9758853846153845, 0.8396858076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 234}], {
             RGBColor[
             0.7387347307692308, 0.791266923076923, 0.8284905384615386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 286}], {
             RGBColor[
             0.9937856153846154, 0.9891163846153845, 0.5649807692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 290}], {
             RGBColor[
             0.7969011923076923, 0.838489076923077, 0.8330696153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 313}], {
             RGBColor[
             0.9253284230769231, 0.9397734615384615, 0.8453367692307694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 320}], {
             RGBColor[
             0.8528722692307692, 0.8828823846153846, 0.8381913846153848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 331}], {
             RGBColor[
             0.9784394230769231, 0.9814493846153847, 0.8270571923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 342}], {
             RGBColor[
             0.9946406923076923, 0.9909453076923077, 0.6580506153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 343}], {
             RGBColor[
             0.9320237692307692, 0.7449036153846155, 0.4584855000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 344}], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 349}], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 147}], {
             RGBColor[0.873390923076923, 0.9018822307692307, 0.987786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 211}], {
             RGBColor[
             0.9596504230769229, 0.9654202307692307, 0.7091279999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 301}], {
             RGBColor[
             0.948407346153846, 0.9274946923076921, 0.6654507692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 328}], {
             RGBColor[
             0.9354108846153845, 0.8801239999999997, 0.6333492692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 347}], {
             RGBColor[
             0.9119876538461538, 0.7852280769230768, 0.6143973461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 372}], {
             RGBColor[
             0.9354108846153845, 0.8801239999999997, 0.6333492692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 380}], {
             RGBColor[
             0.9049381153846152, 0.7532177692307691, 0.6085150384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 54}], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.8268168461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 116}], {
             RGBColor[
             0.7666452307692307, 0.8145774615384616, 0.8636203461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 121}], {
             RGBColor[
             0.9930404230769231, 0.9897303076923077, 0.6443559615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.9757482692307692, 0.9319275384615384, 0.5323051923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 135}], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.8268168461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 158}], {
             RGBColor[
             0.9772666923076923, 0.9811488461538462, 0.8598974615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 172}], {
             RGBColor[
             0.9813698076923076, 0.9508903076923076, 0.5541438076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 181}], {
             RGBColor[
             0.9597603076923076, 0.9678630769230769, 0.8815730384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 265}], {
             RGBColor[
             0.9698062307692308, 0.9755848461538461, 0.8725260769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 276}], {
             RGBColor[
             0.9813698076923076, 0.9508903076923076, 0.5541438076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 322}], {
             RGBColor[
             0.9926128846153845, 0.9888158461538461, 0.5978210384615383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 328}], {
             RGBColor[
             0.9683733461538461, 0.9035196153846152, 0.5220423076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 362}], {
             RGBColor[
             0.9934679615384615, 0.9906447692307693, 0.6908908846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 364}], {
             RGBColor[
             0.9698062307692308, 0.9755848461538461, 0.8725260769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 59}], {
             RGBColor[
             0.993358076923077, 0.988201923076923, 0.518445846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 136}], {
             RGBColor[
             0.9691185384615384, 0.9029056923076921, 0.4426671153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 194}], {
             RGBColor[
             0.9386457692307693, 0.7759994615384616, 0.4178328846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 246}], {
             RGBColor[
             0.9386457692307693, 0.7759994615384616, 0.4178328846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 376}], {
             RGBColor[
             0.9934679615384615, 0.9906447692307693, 0.6908908846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 377}], {
             RGBColor[
             0.9946406923076923, 0.9909453076923077, 0.6580506153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 395}], {
             RGBColor[
             0.9386457692307693, 0.7759994615384616, 0.4178328846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 396}], {
             RGBColor[
             0.9877365384615384, 0.9692391538461538, 0.4966072307692305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 117}], {
             RGBColor[
             0.9877365384615384, 0.9692391538461538, 0.4966072307692305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 133}], {
             RGBColor[
             0.9881640769230768, 0.9701536153846153, 0.5431421538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 174}], {
             RGBColor[
             0.9362265769230769, 0.9322623846153845, 0.6855913846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 223}], {
             RGBColor[
             0.7609138076923077, 0.793171846153846, 0.6693366923076921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 260}], {
             RGBColor[
             0.9789957307692307, 0.9653072307692306, 0.6529851923076921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 267}], {
             RGBColor[
             0.9321691538461538, 0.755207769230769, 0.3029244230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 272}], {
             RGBColor[
             0.9852851923076922, 0.9691475384615383, 0.6042578076923074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 291}], {
             RGBColor[
             0.9251196153846153, 0.7231974615384615, 0.2970421153846152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 346}], {
             RGBColor[
             0.9006219615384615, 0.9038722307692306, 0.6821953846153844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 384}], {
             RGBColor[
             0.9006219615384615, 0.9038722307692306, 0.6821953846153844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 68}], {
             RGBColor[
             0.7665353461538462, 0.8121346153846154, 0.6911753076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 86}], {
             RGBColor[0.9696963461538461, 0.973142, 0.7000810384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 95}], {
             RGBColor[
             0.9771568076923077, 0.9787060000000001, 0.687452423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 101}], {
             RGBColor[0.9846172692307692, 0.98427, 0.6748238076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 129}], {
             RGBColor[
             0.989200576923077, 0.9874047692307693, 0.6543718076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 151}], {
             RGBColor[
             0.9909067307692307, 0.9881103076923077, 0.6260964230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 171}], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 244}], {
             RGBColor[0.904911, 0.5602499999999999, 0.2947969999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 249}], {
             RGBColor[0.9418481153846154, 0.9512251538461538, 0.70743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 253}], {
             RGBColor[0.9846172692307692, 0.98427, 0.6748238076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 270}], {
             RGBColor[
             0.9756383846153847, 0.9294846923076923, 0.3598601538461537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 308}], {
             RGBColor[
             0.9682634615384615, 0.9010767692307691, 0.34959726923076906`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 386}], {
             RGBColor[
             0.9909067307692307, 0.9881103076923077, 0.6260964230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 397}], {
             RGBColor[0.9596504230769229, 0.9654202307692307, 0.709128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 121}], {
             RGBColor[
             0.9896281153846154, 0.9883192307692308, 0.7009067307692309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 128}], {
             RGBColor[
             0.966393923076923, 0.9741737692307693, 0.9290768461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 130}], {
             RGBColor[
             0.9723359615384615, 0.9305164615384616, 0.5888559615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 158}], {
             RGBColor[
             0.9738543846153846, 0.9797377692307693, 0.9164482307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 181}], {
             RGBColor[
             0.9563479999999999, 0.9664519999999999, 0.9381238076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 265}], {
             RGBColor[
             0.966393923076923, 0.9741737692307693, 0.9290768461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 311}], {
             RGBColor[
             0.9490422692307692, 0.8389959230769231, 0.5657844615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 322}], {
             RGBColor[
             0.989200576923077, 0.9874047692307693, 0.6543718076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 328}], {
             RGBColor[
             0.9649610384615384, 0.9021085384615383, 0.5785930769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 362}], {
             RGBColor[
             0.9900556538461538, 0.9892336923076923, 0.7474416538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 58}], {
             RGBColor[
             0.9427031923076923, 0.9530540769230769, 0.8004998461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 60}], {
             RGBColor[
             0.9780118846153847, 0.9805349230769231, 0.7805222692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 80}], {
             RGBColor[
             0.9900556538461538, 0.9892336923076923, 0.7474416538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 87}], {
             RGBColor[
             0.9877365384615384, 0.9692391538461538, 0.4966072307692305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 122}], {
             RGBColor[
             0.9877365384615384, 0.9692391538461538, 0.4966072307692305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 146}], {
             RGBColor[0.9249008846153846, 0.938859, 0.7988018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 159}], {
             RGBColor[
             0.9946406923076923, 0.9909453076923077, 0.6580506153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.9605054999999999, 0.9672491538461538, 0.8021978461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 192}], {
             RGBColor[0.9531997692307692, 0.839793076923077, 0.4298585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 201}], {
             RGBColor[
             0.8797716538461539, 0.903315923076923, 0.7943801538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 210}], {
             RGBColor[
             0.9917618076923076, 0.9899392307692307, 0.7191662692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 228}], {
             RGBColor[
             0.8797716538461539, 0.903315923076923, 0.7943801538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 385}], {
             RGBColor[
             0.9917618076923076, 0.9899392307692307, 0.7191662692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 71}], {
             RGBColor[
             0.9715352692307693, 0.9597432307692306, 0.6656138076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 83}], {
             RGBColor[
             0.8186411923076922, 0.8398282307692306, 0.6740243076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 108}], {
             RGBColor[
             0.9789957307692307, 0.9653072307692306, 0.6529851923076921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 120}], {
             RGBColor[
             0.9877365384615384, 0.9692391538461538, 0.4966072307692305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 143}], {
             RGBColor[
             0.9715352692307693, 0.9597432307692306, 0.6656138076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 196}], {
             RGBColor[
             0.981259923076923, 0.9484474615384613, 0.38169876923076884`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 231}], {
             RGBColor[
             0.9640748076923076, 0.9541792307692306, 0.6782424230769228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 237}], {
             RGBColor[
             0.9362265769230769, 0.9322623846153845, 0.6855913846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 254}], {
             RGBColor[
             0.9184242692307691, 0.9180673076923076, 0.6838933846153844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 286}], {
             RGBColor[
             0.9868814615384616, 0.9674102307692306, 0.40353738461538435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 290}], {
             RGBColor[
             0.7899970384615385, 0.816782923076923, 0.6716262307692306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 320}], {
             RGBColor[
             0.8459681153846152, 0.8611762307692306, 0.6767479999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 331}], {
             RGBColor[
             0.9715352692307693, 0.9597432307692306, 0.6656138076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 342}], {
             RGBColor[
             0.9877365384615384, 0.9692391538461538, 0.4966072307692305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 343}], {
             RGBColor[
             0.9251196153846153, 0.7231974615384615, 0.2970421153846152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 344}], {
             RGBColor[
             0.9881640769230768, 0.9701536153846153, 0.5431421538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 349}], {
             RGBColor[
             0.9881640769230768, 0.9701536153846153, 0.5431421538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 92}], {
             RGBColor[
             0.9738543846153846, 0.9797377692307693, 0.9164482307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 114}], {
             RGBColor[
             0.9755605384615385, 0.9804433076923078, 0.8881728461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 153}], {
             RGBColor[
             0.9784394230769231, 0.9814493846153847, 0.8270571923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 188}], {
             RGBColor[
             0.9772666923076923, 0.9811488461538462, 0.8598974615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 195}], {
             RGBColor[
             0.9543501538461538, 0.9654750000000001, 0.9621574615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 208}], {
             RGBColor[
             0.9784394230769231, 0.9814493846153847, 0.8270571923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 258}], {
             RGBColor[
             0.9772666923076923, 0.9811488461538462, 0.8598974615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 278}], {
             RGBColor[
             0.9086996153846154, 0.929363076923077, 0.967808423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 284}], {
             RGBColor[
             0.9449578846153845, 0.8618534615384615, 0.6052693846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 327}], {
             RGBColor[
             0.9443042307692306, 0.9577532307692307, 0.971204423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 337}], {
             RGBColor[
             0.9738543846153846, 0.9797377692307693, 0.9164482307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 354}], {
             RGBColor[0.8908973076923077, 0.915168, 0.9661104230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 392}], {
             RGBColor[
             0.9772666923076923, 0.9811488461538462, 0.8598974615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 60}], {
             RGBColor[
             0.9265019230769231, 0.9435581538461539, 0.969506423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 80}], {
             RGBColor[
             0.9385456923076922, 0.9522569230769231, 0.9364258076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 87}], {
             RGBColor[
             0.9362265769230769, 0.9322623846153845, 0.6855913846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 110}], {
             RGBColor[
             0.9265019230769231, 0.9435581538461539, 0.969506423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 159}], {
             RGBColor[
             0.9431307307692307, 0.9539685384615384, 0.8470347692307695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 167}], {
             RGBColor[
             0.9190414615384614, 0.9379941538461538, 0.9821350384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 192}], {
             RGBColor[
             0.9016898076923077, 0.8028163076923077, 0.6188426538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 201}], {
             RGBColor[
             0.8282616923076923, 0.8663391538461538, 0.9833643076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 210}], {
             RGBColor[
             0.940251846153846, 0.9529624615384615, 0.9081504230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 228}], {
             RGBColor[
             0.8282616923076923, 0.8663391538461538, 0.9833643076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 236}], {
             RGBColor[
             0.9362265769230769, 0.9322623846153845, 0.6855913846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 243}], {
             RGBColor[
             0.9422756538461539, 0.9521396153846153, 0.7539649230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 263}], {
             RGBColor[
             0.9422756538461539, 0.9521396153846153, 0.7539649230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 348}], {
             RGBColor[0.941958, 0.953668, 0.8798750384615385]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{58, 351}], {
             RGBColor[
             0.8555886153846154, 0.8876871538461538, 0.9860880000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 79}], {
             RGBColor[
             0.9909067307692307, 0.9881103076923077, 0.6260964230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[
             0.9377906923076923, 0.7741705384615385, 0.32476303846153837`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 237}], {
             RGBColor[0.9418481153846154, 0.9512251538461538, 0.70743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 246}], {
             RGBColor[
             0.9377906923076923, 0.7741705384615385, 0.32476303846153837`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 254}], {
             RGBColor[
             0.9240458076923077, 0.9370300769230768, 0.7057319999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 349}], {
             RGBColor[
             0.9937856153846154, 0.9891163846153845, 0.5649807692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 373}], {
             RGBColor[0.8515896538461538, 0.880139, 0.6985866153846152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 395}], {
             RGBColor[
             0.9377906923076923, 0.7741705384615385, 0.32476303846153837`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 87}], {
             RGBColor[
             0.9715352692307693, 0.9597432307692306, 0.6656138076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 122}], {
             RGBColor[
             0.9715352692307693, 0.9597432307692306, 0.6656138076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 146}], {
             RGBColor[
             0.9086996153846154, 0.929363076923077, 0.967808423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 159}], {
             RGBColor[
             0.9784394230769231, 0.9814493846153847, 0.8270571923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 165}], {
             RGBColor[
             0.9443042307692306, 0.9577532307692307, 0.971204423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 201}], {
             RGBColor[
             0.8635703846153846, 0.8938200000000001, 0.9633867307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 210}], {
             RGBColor[
             0.9755605384615385, 0.9804433076923078, 0.8881728461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 263}], {
             RGBColor[
             0.9775843461538463, 0.9796204615384616, 0.7339873461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 66}], {
             RGBColor[0.4647738076923076, 0.5606415, 0.9537865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 98}], {
             RGBColor[
             0.5734882307692307, 0.5500229615384615, 0.5983928461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 107}], {
             RGBColor[
             0.5903409615384615, 0.6592085000000001, 0.9426523076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 131}], {
             RGBColor[
             0.5888225384615384, 0.6099871923076923, 0.6150600384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 215}], {
             RGBColor[0.5194276538461539, 0.6033375, 0.9592338846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 262}], {
             RGBColor[
             0.5903409615384615, 0.6592085000000001, 0.9426523076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 269}], {
             RGBColor[
             0.4088027307692308, 0.5162481923076923, 0.9486647307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 279}], {
             RGBColor[
             0.6065422307692308, 0.668704423076923, 0.7736457307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 297}], {
             RGBColor[
             0.6000656153846153, 0.6479127307692306, 0.658737269230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 298}], {
             RGBColor[
             0.5509748461538461, 0.45467303846153845`, 0.5799629230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 300}], {
             RGBColor[
             0.6040908846153845, 0.6686128076923077, 0.8812963076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 306}], {
             RGBColor[0.597801423076923, 0.6647725, 0.9300236923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 307}], {
             RGBColor[0.4647738076923076, 0.5606415, 0.9537865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 314}], {
             RGBColor[
             0.5903409615384615, 0.6592085000000001, 0.9426523076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 352}], {
             RGBColor[0.597801423076923, 0.6647725, 0.9300236923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 77}], {
             RGBColor[
             0.9909067307692307, 0.9881103076923077, 0.6260964230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 204}], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 345}], {
             RGBColor[
             0.9291448846153846, 0.7438975384615385, 0.5196011538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 370}], {
             RGBColor[
             0.9046472307692308, 0.9245723076923077, 0.904754423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 389}], {
             RGBColor[
             0.8226664615384615, 0.8605283076923076, 0.896583346153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 400}], {
             RGBColor[
             0.9913342692307692, 0.9890247692307692, 0.6726313461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 90}], {
             RGBColor[
             0.9755605384615385, 0.9804433076923078, 0.8881728461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 138}], {
             RGBColor[
             0.9876043076923076, 0.989142076923077, 0.8550922307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 142}], {
             RGBColor[
             0.9580541538461538, 0.9671575384615384, 0.909848423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 152}], {
             RGBColor[
             0.9921893461538461, 0.9908536923076923, 0.7657011923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 156}], {
             RGBColor[
             0.9910166153846154, 0.9905531538461538, 0.7985414615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 202}], {
             RGBColor[
             0.936194423076923, 0.7759078461538462, 0.5254834615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 214}], {
             RGBColor[
             0.9587078076923077, 0.8712577692307693, 0.5439133846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 217}], {
             RGBColor[
             0.9921893461538461, 0.9908536923076923, 0.7657011923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 242}], {
             RGBColor[
             0.9852851923076922, 0.9691475384615383, 0.6042578076923074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 256}], {
             RGBColor[
             0.9224495384615384, 0.9387673846153846, 0.906452423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 257}], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 261}], {
             RGBColor[
             0.9910166153846154, 0.9905531538461538, 0.7985414615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 264}], {
             RGBColor[
             0.940251846153846, 0.9529624615384615, 0.9081504230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 268}], {
             RGBColor[0.9740421153846153, 0.931222, 0.5605805769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 317}], {
             RGBColor[
             0.950748423076923, 0.8397014615384616, 0.5375090769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 381}], {
             RGBColor[
             0.9852851923076922, 0.9691475384615383, 0.6042578076923074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 82}], {
             RGBColor[
             0.9771568076923077, 0.9787060000000001, 0.6874524230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 151}], {
             RGBColor[
             0.9755605384615385, 0.9804433076923078, 0.8881728461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 157}], {
             RGBColor[
             0.9755605384615385, 0.9804433076923078, 0.8881728461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 171}], {
             RGBColor[
             0.9771568076923077, 0.9787060000000001, 0.6874524230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 182}], {
             RGBColor[
             0.7511891538461539, 0.8044676153846154, 0.9532517307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 253}], {
             RGBColor[
             0.9692710769230769, 0.9766030000000001, 0.9369002307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 105}], {
             RGBColor[
             0.9161600769230769, 0.9349270769230769, 0.9551798076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 113}], {
             RGBColor[
             0.9603777307692307, 0.8989737692307691, 0.5990450769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 148}], {
             RGBColor[
             0.9033461923076923, 0.6067323846153849, 0.5502977307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 161}], {
             RGBColor[
             0.9850448076923077, 0.9851844615384615, 0.7213587307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 168}], {
             RGBColor[
             0.8163769999999999, 0.8566879999999999, 0.9453107307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 170}], {
             RGBColor[0.8970252692307692, 0.558147, 0.5442448076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 180}], {
             RGBColor[
             0.9847271538461537, 0.9867128461538461, 0.8472688461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 239}], {
             RGBColor[
             0.9692710769230769, 0.9766030000000001, 0.9369002307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 251}], {
             RGBColor[
             0.9813148461538461, 0.9853017692307693, 0.9038196153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 282}], {
             RGBColor[
             0.9161600769230769, 0.9349270769230769, 0.9551798076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 312}], {
             RGBColor[0.8983577692307692, 0.920732, 0.9534818076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 326}], {
             RGBColor[
             0.9854723461538462, 0.986098923076923, 0.7678936538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 356}], {
             RGBColor[0.9846172692307692, 0.98427, 0.6748238076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[
             0.8193907307692307, 0.7632864615384615, 0.6164035769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 107}], {
             RGBColor[0.8362434615384615, 0.872472, 0.9606630384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 131}], {
             RGBColor[
             0.8347250384615383, 0.8232506923076923, 0.6330707692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 215}], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 297}], {
             RGBColor[
             0.8459681153846152, 0.8611762307692306, 0.6767479999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 307}], {
             RGBColor[0.7106763076923076, 0.773905, 0.9717972307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 314}], {
             RGBColor[0.8362434615384615, 0.872472, 0.9606630384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 352}], {
             RGBColor[0.843703923076923, 0.878036, 0.9480344230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 85}], {
             RGBColor[
             0.9926128846153845, 0.9888158461538461, 0.5978210384615383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 127}], {
             RGBColor[
             0.9937856153846154, 0.9891163846153845, 0.5649807692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 139}], {
             RGBColor[0.9418481153846154, 0.9512251538461538, 0.70743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 184}], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 305}], {
             RGBColor[
             0.8789165769230769, 0.9014869999999999, 0.7013103076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 325}], {
             RGBColor[
             0.9909067307692307, 0.9881103076923077, 0.6260964230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 86}], {
             RGBColor[
             0.7437286923076922, 0.7989036153846154, 0.9658803461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 95}], {
             RGBColor[
             0.7511891538461539, 0.8044676153846154, 0.9532517307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 129}], {
             RGBColor[
             0.763232923076923, 0.8131663846153846, 0.9201711153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 151}], {
             RGBColor[
             0.7649390769230768, 0.8138719230769231, 0.8918957307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 178}], {
             RGBColor[
             0.763232923076923, 0.8131663846153846, 0.9201711153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 229}], {
             RGBColor[
             0.7586496153846154, 0.8100316153846154, 0.9406231153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 249}], {
             RGBColor[
             0.7158804615384615, 0.7769867692307693, 0.9732293076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 308}], {
             RGBColor[
             0.7422958076923076, 0.7268383846153844, 0.6153965769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 309}], {
             RGBColor[
             0.5696509230769231, 0.6615073076923077, 0.9592641538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 319}], {
             RGBColor[
             0.7673904230769231, 0.8139635384615385, 0.7842451538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 334}], {
             RGBColor[
             0.7511891538461539, 0.8044676153846154, 0.9532517307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 371}], {
             RGBColor[
             0.7649390769230768, 0.8138719230769231, 0.8918957307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 386}], {
             RGBColor[
             0.7649390769230768, 0.8138719230769231, 0.8918957307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 74}], {
             RGBColor[
             0.6069697692307692, 0.6696188846153845, 0.820180653846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 97}], {
             RGBColor[
             0.9881640769230768, 0.9701536153846153, 0.5431421538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 100}], {
             RGBColor[
             0.9937856153846154, 0.9891163846153845, 0.5649807692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 132}], {
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 140}], {
             RGBColor[
             0.9061936153846154, 0.5629933846153846, 0.43440176923076945`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 141}], {
             RGBColor[
             0.9904831923076922, 0.9901481538461538, 0.7939765769230772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 168}], {
             RGBColor[
             0.8255453461538461, 0.8615343846153846, 0.8354676923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 191}], {
             RGBColor[
             0.9061936153846154, 0.5629933846153846, 0.43440176923076945`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 216}], {
             RGBColor[
             0.9695460769230768, 0.9038201538461537, 0.48920203846153865`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 219}], {
             RGBColor[
             0.9946406923076923, 0.9909453076923077, 0.6580506153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 220}], {
             RGBColor[
             0.9609330384615384, 0.9681636153846154, 0.8487327692307695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 350}], {
             RGBColor[
             0.7130721923076924, 0.7698290000000001, 0.8266371538461541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 357}], {
             RGBColor[
             0.9075261153846155, 0.9255783846153847, 0.8436387692307694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 394}], {
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 75}], {
             RGBColor[
             0.9609330384615384, 0.9681636153846154, 0.8487327692307695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 103}], {
             RGBColor[
             0.9580541538461538, 0.9671575384615384, 0.909848423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 133}], {
             RGBColor[
             0.9609330384615384, 0.9681636153846154, 0.8487327692307695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.9049381153846152, 0.7532177692307691, 0.6085150384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 164}], {
             RGBColor[
             0.9600779615384615, 0.9663346923076923, 0.7556629230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 227}], {
             RGBColor[
             0.9580541538461538, 0.9671575384615384, 0.909848423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 234}], {
             RGBColor[
             0.7045995384615383, 0.7675707692307692, 0.9726377692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 280}], {
             RGBColor[
             0.9049381153846152, 0.7532177692307691, 0.6085150384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 346}], {
             RGBColor[0.873390923076923, 0.9018822307692307, 0.987786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 79}], {
             RGBColor[
             0.9755605384615385, 0.9804433076923078, 0.8881728461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 109}], {
             RGBColor[
             0.9784394230769231, 0.9814493846153847, 0.8270571923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 120}], {
             RGBColor[
             0.9780118846153847, 0.9805349230769231, 0.7805222692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 143}], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 237}], {
             RGBColor[
             0.9265019230769231, 0.9435581538461539, 0.969506423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 286}], {
             RGBColor[
             0.9771568076923077, 0.9787060000000001, 0.6874524230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 320}], {
             RGBColor[0.8362434615384615, 0.872472, 0.9606630384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 321}], {
             RGBColor[
             0.9784394230769231, 0.9814493846153847, 0.8270571923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 343}], {
             RGBColor[
             0.9153949615384616, 0.7344932307692309, 0.5809571538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 382}], {
             RGBColor[
             0.9659137307692307, 0.9407804615384615, 0.6437751923076921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 119}], {
             RGBColor[
             0.9881640769230768, 0.9701536153846153, 0.5431421538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 200}], {
             RGBColor[
             0.9362265769230769, 0.9322623846153845, 0.6855913846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 288}], {
             RGBColor[
             0.9852851923076922, 0.9691475384615383, 0.6042578076923074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 341}], {
             RGBColor[
             0.9868814615384616, 0.9674102307692306, 0.40353738461538435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 355}], {
             RGBColor[
             0.9700168461538461, 0.9105219230769229, 0.33802153846153826`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 374}], {
             RGBColor[
             0.9700168461538461, 0.9105219230769229, 0.33802153846153826`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 375}], {
             RGBColor[
             0.9700168461538461, 0.9105219230769229, 0.33802153846153826`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 379}], {
             RGBColor[
             0.981259923076923, 0.9484474615384613, 0.38169876923076884`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 393}], {
             RGBColor[
             0.9868814615384616, 0.9674102307692306, 0.40353738461538435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 399}], {
             RGBColor[
             0.9640748076923076, 0.9541792307692306, 0.6782424230769228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 85}], {
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 96}], {
             RGBColor[
             0.9825425384615385, 0.9511908461538461, 0.5213035384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 110}], {
             RGBColor[
             0.9784394230769231, 0.9814493846153847, 0.8270571923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 115}], {
             RGBColor[
             0.9253284230769231, 0.9397734615384615, 0.8453367692307694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 184}], {
             RGBColor[
             0.9937856153846154, 0.9891163846153845, 0.5649807692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 188}], {
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 195}], {
             RGBColor[
             0.9709789615384615, 0.9758853846153845, 0.8396858076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 203}], {
             RGBColor[
             0.9784394230769231, 0.9814493846153847, 0.8270571923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 206}], {
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 208}], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 258}], {
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 284}], {
             RGBColor[
             0.9615866923076923, 0.8722638461538461, 0.482797730769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 348}], {
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 369}], {
             RGBColor[
             0.9881640769230768, 0.9701536153846153, 0.5431421538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 392}], {
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 132}], {
             RGBColor[
             0.6057970384615384, 0.6693183461538461, 0.853020923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 140}], {
             RGBColor[
             0.5180951538461538, 0.24075249999999998`, 0.5499968846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 191}], {
             RGBColor[
             0.5180951538461538, 0.24075249999999998`, 0.5499968846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 198}], {
             RGBColor[0.530737, 0.3379232692307692, 0.5621027307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 216}], {
             RGBColor[
             0.5814476153846153, 0.5815792692307691, 0.6047971538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 219}], {
             RGBColor[
             0.6065422307692308, 0.668704423076923, 0.7736457307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 220}], {
             RGBColor[
             0.5728345769230768, 0.6459227307692307, 0.9643278846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 224}], {
             RGBColor[0.597801423076923, 0.6647725, 0.9300236923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 302}], {
             RGBColor[0.5194276538461539, 0.6033375, 0.9592338846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 311}], {
             RGBColor[
             0.5655288461538461, 0.5184666538461539, 0.5919885384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 323}], {
             RGBColor[
             0.6065422307692308, 0.668704423076923, 0.7736457307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 340}], {
             RGBColor[
             0.5903409615384615, 0.6592085000000001, 0.9426523076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 357}], {
             RGBColor[0.5194276538461539, 0.6033375, 0.9592338846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 89}], {
             RGBColor[
             0.9881640769230768, 0.9701536153846153, 0.5431421538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 133}], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 145}], {
             RGBColor[
             0.9390733076923077, 0.7769139230769231, 0.4643678076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.9461228461538461, 0.8089242307692307, 0.4702501153846156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 164}], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 169}], {
             RGBColor[
             0.9461228461538461, 0.8089242307692307, 0.4702501153846156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 209}], {
             RGBColor[
             0.9431307307692307, 0.9539685384615384, 0.8470347692307695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 227}], {
             RGBColor[
             0.9921893461538461, 0.9908536923076923, 0.7657011923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 280}], {
             RGBColor[
             0.9390733076923077, 0.7769139230769231, 0.4643678076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 315}], {
             RGBColor[
             0.9709789615384615, 0.9758853846153845, 0.8396858076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[
             0.8467176538461538, 0.7846344615384615, 0.6191272692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 109}], {
             RGBColor[
             0.9615866923076923, 0.8722638461538461, 0.482797730769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 138}], {
             RGBColor[
             0.9570016538461538, 0.8705522307692307, 0.5721887692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 144}], {
             RGBColor[
             0.9603040769230768, 0.8695204615384615, 0.34319296153846146`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 207}], {
             RGBColor[
             0.952418346153846, 0.8674174615384616, 0.5926407692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 233}], {
             RGBColor[
             0.9274514999999999, 0.8485676923076921, 0.6269449615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 242}], {
             RGBColor[
             0.9546825384615384, 0.8505576923076921, 0.32135434615384595`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 257}], {
             RGBColor[
             0.9587078076923077, 0.8712577692307693, 0.5439133846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 317}], {
             RGBColor[
             0.9201457692307692, 0.7211116153846153, 0.2546056153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 358}], {
             RGBColor[
             0.9126413076923077, 0.6893283076923076, 0.24846230769230765`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 366}], {
             RGBColor[
             0.9201457692307692, 0.7211116153846153, 0.2546056153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 382}], {
             RGBColor[
             0.9490609999999999, 0.831594923076923, 0.29951573076923066`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 78}], {
             RGBColor[
             0.9929305384615386, 0.9872874615384615, 0.47191092307692306`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 102}], {
             RGBColor[0.585715, 0.6458834999999999, 0.6794384999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 111}], {
             RGBColor[
             0.9868814615384616, 0.9674102307692306, 0.40353738461538435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 160}], {
             RGBColor[
             0.9307411538461539, 0.7421602307692308, 0.3188807307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 166}], {
             RGBColor[
             0.9771568076923077, 0.9787060000000001, 0.687452423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 185}], {
             RGBColor[
             0.993358076923077, 0.988201923076923, 0.518445846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 370}], {
             RGBColor[0.9062435, 0.922835, 0.7040339999999998]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{77, 389}], {
             RGBColor[
             0.8242627307692307, 0.8587909999999999, 0.6958629230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 400}], {
             RGBColor[
             0.9929305384615386, 0.9872874615384615, 0.47191092307692306`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 102}], {
             RGBColor[
             0.5861425384615385, 0.6467979615384616, 0.7259734230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 144}], {
             RGBColor[
             0.9929305384615386, 0.9872874615384615, 0.47191092307692306`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 160}], {
             RGBColor[
             0.9311686923076923, 0.7430746923076924, 0.36541565384615393`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 185}], {
             RGBColor[
             0.9937856153846154, 0.9891163846153846, 0.5649807692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 207}], {
             RGBColor[
             0.9850448076923077, 0.9851844615384615, 0.7213587307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 213}], {
             RGBColor[
             0.9701238846153846, 0.9740564615384615, 0.7466159615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 230}], {
             RGBColor[
             0.9850448076923077, 0.9851844615384615, 0.7213587307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 247}], {
             RGBColor[
             0.9422756538461539, 0.9521396153846153, 0.7539649230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 289}], {
             RGBColor[
             0.9850448076923077, 0.9851844615384615, 0.7213587307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 370}], {
             RGBColor[
             0.9066710384615385, 0.9237494615384616, 0.7505689230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 391}], {
             RGBColor[0.987309, 0.9683246923076922, 0.45007230769230755`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 400}], {
             RGBColor[
             0.993358076923077, 0.9882019230769231, 0.5184458461538463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 109}], {
             RGBColor[
             0.9921893461538461, 0.9908536923076923, 0.7657011923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 120}], {
             RGBColor[
             0.9917618076923076, 0.9899392307692307, 0.7191662692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 136}], {
             RGBColor[
             0.9666671923076922, 0.9028140769230768, 0.5503176923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 237}], {
             RGBColor[
             0.940251846153846, 0.9529624615384615, 0.9081504230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 246}], {
             RGBColor[
             0.936194423076923, 0.7759078461538462, 0.5254834615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 254}], {
             RGBColor[
             0.9224495384615384, 0.9387673846153846, 0.906452423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 286}], {
             RGBColor[
             0.9909067307692307, 0.9881103076923077, 0.6260964230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 320}], {
             RGBColor[
             0.8499933846153845, 0.8818763076923077, 0.8993070384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 343}], {
             RGBColor[
             0.9291448846153846, 0.7438975384615385, 0.5196011538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 349}], {
             RGBColor[
             0.9921893461538461, 0.9908536923076923, 0.7657011923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 87}], {
             RGBColor[
             0.9835790384615384, 0.9684419999999998, 0.6325331923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 96}], {
             RGBColor[
             0.9779574999999999, 0.9494792307692307, 0.6106945769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 110}], {
             RGBColor[
             0.9738543846153846, 0.9797377692307693, 0.9164482307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 146}], {
             RGBColor[
             0.9207433846153845, 0.9380618461538461, 0.9347278076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 154}], {
             RGBColor[
             0.9738543846153846, 0.9797377692307693, 0.9164482307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 159}], {
             RGBColor[
             0.9904831923076922, 0.9901481538461538, 0.7939765769230772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 167}], {
             RGBColor[
             0.966393923076923, 0.9741737692307693, 0.9290768461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 192}], {
             RGBColor[
             0.9490422692307692, 0.8389959230769231, 0.5657844615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 201}], {
             RGBColor[
             0.8756141538461538, 0.9025187692307692, 0.9303061153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 203}], {
             RGBColor[
             0.9738543846153846, 0.9797377692307693, 0.9164482307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 228}], {
             RGBColor[
             0.8756141538461538, 0.9025187692307692, 0.9303061153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 243}], {
             RGBColor[
             0.9896281153846154, 0.9883192307692308, 0.7009067307692309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 332}], {
             RGBColor[
             0.9563479999999999, 0.9664519999999999, 0.9381238076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 348}], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.8268168461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 361}], {
             RGBColor[
             0.9904831923076922, 0.9901481538461538, 0.7939765769230772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 385}], {
             RGBColor[
             0.9876043076923076, 0.989142076923077, 0.8550922307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 89}], {
             RGBColor[0.987309, 0.9683246923076922, 0.45007230769230755`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 163}], {
             RGBColor[
             0.9452677692307692, 0.8070953076923076, 0.37718026923076925`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 169}], {
             RGBColor[
             0.9452677692307692, 0.8070953076923076, 0.37718026923076925`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 209}], {
             RGBColor[
             0.9422756538461539, 0.9521396153846153, 0.7539649230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 227}], {
             RGBColor[
             0.9913342692307692, 0.9890247692307692, 0.6726313461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 240}], {
             RGBColor[
             0.9600779615384615, 0.9663346923076923, 0.7556629230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 245}], {
             RGBColor[
             0.9701238846153846, 0.9740564615384615, 0.7466159615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 248}], {
             RGBColor[
             0.9607316153846154, 0.870434923076923, 0.38972788461538466`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 292}], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 304}], {
             RGBColor[
             0.9066710384615385, 0.9237494615384616, 0.7505689230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 315}], {
             RGBColor[
             0.9701238846153846, 0.9740564615384615, 0.7466159615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 329}], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 353}], {
             RGBColor[
             0.9775843461538463, 0.9796204615384616, 0.7339873461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 378}], {
             RGBColor[
             0.9896281153846154, 0.9883192307692308, 0.7009067307692309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 151}], {
             RGBColor[
             0.9909067307692307, 0.9881103076923077, 0.6260964230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 157}], {
             RGBColor[
             0.9909067307692307, 0.9881103076923077, 0.6260964230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 171}], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 182}], {
             RGBColor[
             0.7665353461538462, 0.8121346153846154, 0.6911753076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 253}], {
             RGBColor[0.9846172692307692, 0.98427, 0.6748238076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 108}], {
             RGBColor[
             0.8163769999999999, 0.8566879999999999, 0.9453107307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 120}], {
             RGBColor[
             0.8251178076923076, 0.860619923076923, 0.7889327692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 125}], {
             RGBColor[
             0.8186411923076922, 0.8398282307692306, 0.6740243076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 179}], {
             RGBColor[
             0.8014560769230769, 0.8455599999999999, 0.9705679615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 196}], {
             RGBColor[
             0.8186411923076922, 0.8398282307692306, 0.6740243076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 231}], {
             RGBColor[
             0.8014560769230769, 0.8455599999999999, 0.9705679615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 237}], {
             RGBColor[
             0.773607846153846, 0.8236431538461537, 0.9779169230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 246}], {
             RGBColor[
             0.769550423076923, 0.6465885384615384, 0.5952499615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 254}], {
             RGBColor[
             0.7558055384615384, 0.8094480769230769, 0.976218923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 303}], {
             RGBColor[
             0.8014560769230769, 0.8455599999999999, 0.9705679615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 313}], {
             RGBColor[
             0.7558055384615384, 0.8094480769230769, 0.976218923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 344}], {
             RGBColor[
             0.8255453461538461, 0.8615343846153846, 0.8354676923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 349}], {
             RGBColor[
             0.8255453461538461, 0.8615343846153846, 0.8354676923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.9086996153846154, 0.929363076923077, 0.967808423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 152}], {
             RGBColor[
             0.9253284230769231, 0.9397734615384615, 0.8453367692307694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 156}], {
             RGBColor[
             0.9241556923076923, 0.9394729230769231, 0.8781770384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 175}], {
             RGBColor[
             0.9207433846153845, 0.9380618461538461, 0.9347278076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 204}], {
             RGBColor[
             0.9224495384615384, 0.9387673846153846, 0.906452423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 256}], {
             RGBColor[0.8555886153846154, 0.8876871538461538, 0.986088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 261}], {
             RGBColor[
             0.9241556923076923, 0.9394729230769231, 0.8781770384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 264}], {
             RGBColor[0.873390923076923, 0.9018822307692307, 0.987786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 317}], {
             RGBColor[
             0.8838874999999999, 0.7886212307692309, 0.6171446538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 333}], {
             RGBColor[
             0.9240458076923077, 0.9370300769230768, 0.7057319999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 381}], {
             RGBColor[
             0.9184242692307691, 0.9180673076923076, 0.6838933846153844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 389}], {
             RGBColor[
             0.7558055384615384, 0.8094480769230769, 0.976218923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 96}], {
             RGBColor[
             0.9813698076923076, 0.9508903076923076, 0.5541438076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 110}], {
             RGBColor[
             0.9772666923076923, 0.9811488461538462, 0.8598974615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 115}], {
             RGBColor[
             0.9241556923076923, 0.9394729230769231, 0.8781770384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 139}], {
             RGBColor[0.941958, 0.953668, 0.8798750384615385]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{85, 167}], {
             RGBColor[
             0.9698062307692308, 0.9755848461538461, 0.8725260769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 184}], {
             RGBColor[
             0.9926128846153845, 0.9888158461538461, 0.5978210384615383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 188}], {
             RGBColor[
             0.9927227692307692, 0.9912586923076924, 0.7702660769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 203}], {
             RGBColor[
             0.9772666923076923, 0.9811488461538462, 0.8598974615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 258}], {
             RGBColor[
             0.9927227692307692, 0.9912586923076924, 0.7702660769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 284}], {
             RGBColor[0.9604139615384615, 0.8719633076923077, 0.515638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 325}], {
             RGBColor[
             0.9910166153846154, 0.9905531538461538, 0.7985414615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 348}], {
             RGBColor[
             0.9927227692307692, 0.9912586923076924, 0.7702660769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 351}], {
             RGBColor[
             0.9063533846153846, 0.9252778461538462, 0.8764790384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 369}], {
             RGBColor[
             0.9869913461538461, 0.9698530769230769, 0.5759824230769228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 95}], {
             RGBColor[
             0.9543501538461538, 0.9654750000000001, 0.9621574615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 151}], {
             RGBColor[
             0.9681000769230769, 0.9748793076923077, 0.9008014615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[
             0.966393923076923, 0.9741737692307693, 0.9290768461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 229}], {
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 249}], {
             RGBColor[
             0.9190414615384614, 0.9379941538461538, 0.9821350384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 308}], {
             RGBColor[
             0.9454568076923076, 0.8878457692307691, 0.6243023076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 309}], {
             RGBColor[
             0.772811923076923, 0.8225146923076923, 0.9681698846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 334}], {
             RGBColor[
             0.9543501538461538, 0.9654750000000001, 0.9621574615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 371}], {
             RGBColor[
             0.9681000769230769, 0.9748793076923077, 0.9008014615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 386}], {
             RGBColor[
             0.9681000769230769, 0.9748793076923077, 0.9008014615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 110}], {
             RGBColor[
             0.9715352692307693, 0.9597432307692306, 0.6656138076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 134}], {
             RGBColor[
             0.981259923076923, 0.9484474615384613, 0.38169876923076884`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 159}], {
             RGBColor[
             0.9881640769230768, 0.9701536153846153, 0.5431421538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 167}], {
             RGBColor[
             0.9640748076923076, 0.9541792307692306, 0.6782424230769228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 192}], {
             RGBColor[
             0.9467231538461538, 0.8190013846153845, 0.3149500384615383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 201}], {
             RGBColor[
             0.8732950384615384, 0.8825242307692306, 0.6794716923076921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 210}], {
             RGBColor[
             0.9852851923076922, 0.9691475384615383, 0.6042578076923074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 228}], {
             RGBColor[
             0.8732950384615384, 0.8825242307692306, 0.6794716923076921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 236}], {
             RGBColor[
             0.981259923076923, 0.9484474615384613, 0.38169876923076884`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 243}], {
             RGBColor[0.987309, 0.9683246923076922, 0.45007230769230755`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 263}], {
             RGBColor[0.987309, 0.9683246923076922, 0.45007230769230755`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 348}], {
             RGBColor[
             0.9869913461538461, 0.9698530769230769, 0.5759824230769228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 351}], {
             RGBColor[
             0.9006219615384615, 0.9038722307692306, 0.6821953846153844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[
             0.9354108846153845, 0.8801239999999997, 0.6333492692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 132}], {
             RGBColor[
             0.9597603076923076, 0.9678630769230769, 0.8815730384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 140}], {
             RGBColor[0.872058423076923, 0.5392972307692308, 0.578549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 168}], {
             RGBColor[
             0.7914101538461538, 0.8378382307692307, 0.9796149230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 282}], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 283}], {
             RGBColor[
             0.9368437692307692, 0.9521892307692307, 0.9838330384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 357}], {
             RGBColor[0.873390923076923, 0.9018822307692307, 0.987786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 163}], {
             RGBColor[
             0.9392186923076922, 0.7872180769230768, 0.30880673076923054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 164}], {
             RGBColor[0.987309, 0.9683246923076922, 0.45007230769230755`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 169}], {
             RGBColor[
             0.9392186923076922, 0.7872180769230768, 0.30880673076923054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 209}], {
             RGBColor[
             0.9362265769230769, 0.9322623846153845, 0.6855913846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 227}], {
             RGBColor[
             0.9852851923076922, 0.9691475384615383, 0.6042578076923074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 245}], {
             RGBColor[
             0.9640748076923076, 0.9541792307692306, 0.6782424230769228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.9321691538461538, 0.755207769230769, 0.3029244230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 292}], {
             RGBColor[
             0.9881640769230768, 0.9701536153846153, 0.5431421538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 304}], {
             RGBColor[
             0.9006219615384615, 0.9038722307692306, 0.6821953846153844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 315}], {
             RGBColor[
             0.9640748076923076, 0.9541792307692306, 0.6782424230769228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 329}], {
             RGBColor[
             0.9881640769230768, 0.9701536153846153, 0.5431421538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 353}], {
             RGBColor[
             0.9715352692307693, 0.9597432307692306, 0.6656138076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 378}], {
             RGBColor[
             0.9835790384615384, 0.9684419999999998, 0.6325331923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 138}], {
             RGBColor[
             0.9738543846153846, 0.9797377692307693, 0.9164482307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 142}], {
             RGBColor[
             0.9443042307692306, 0.9577532307692307, 0.971204423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 152}], {
             RGBColor[
             0.9784394230769231, 0.9814493846153847, 0.8270571923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 156}], {
             RGBColor[
             0.9772666923076923, 0.9811488461538462, 0.8598974615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 175}], {
             RGBColor[
             0.9738543846153846, 0.9797377692307693, 0.9164482307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 202}], {
             RGBColor[0.9224445, 0.7665035384615385, 0.5868394615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 242}], {
             RGBColor[
             0.9715352692307693, 0.9597432307692306, 0.6656138076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 256}], {
             RGBColor[
             0.9086996153846154, 0.929363076923077, 0.967808423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[
             0.9755605384615385, 0.9804433076923078, 0.8881728461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 261}], {
             RGBColor[
             0.9772666923076923, 0.9811488461538462, 0.8598974615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 264}], {
             RGBColor[
             0.9265019230769231, 0.9435581538461539, 0.969506423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 268}], {
             RGBColor[
             0.9602921923076924, 0.9218176923076924, 0.6219365769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 317}], {
             RGBColor[
             0.9369985000000001, 0.8302971538461539, 0.5988650769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 333}], {
             RGBColor[
             0.9771568076923077, 0.9787060000000001, 0.6874524230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 381}], {
             RGBColor[
             0.9715352692307693, 0.9597432307692306, 0.6656138076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 141}], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.8268168461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 150}], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.8268168461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 186}], {
             RGBColor[
             0.9757482692307692, 0.9319275384615384, 0.5323051923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 189}], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.8268168461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 190}], {
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 226}], {
             RGBColor[
             0.9449501153846154, 0.8086236923076923, 0.5030903846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 241}], {
             RGBColor[
             0.9934679615384615, 0.9906447692307693, 0.6908908846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 255}], {
             RGBColor[0.941958, 0.953668, 0.8798750384615385]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{91, 266}], {
             RGBColor[
             0.9813698076923076, 0.9508903076923076, 0.5541438076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 273}], {
             RGBColor[
             0.9927227692307692, 0.9912586923076924, 0.7702660769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 365}], {
             RGBColor[
             0.9926128846153845, 0.9888158461538461, 0.5978210384615383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 114}], {
             RGBColor[
             0.9876043076923076, 0.989142076923077, 0.8550922307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 153}], {
             RGBColor[
             0.9904831923076922, 0.9901481538461538, 0.7939765769230772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 161}], {
             RGBColor[
             0.9896281153846154, 0.9883192307692308, 0.7009067307692309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 188}], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.8268168461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 195}], {
             RGBColor[
             0.966393923076923, 0.9741737692307693, 0.9290768461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 258}], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.8268168461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 278}], {
             RGBColor[
             0.9207433846153845, 0.9380618461538461, 0.9347278076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 284}], {
             RGBColor[
             0.9570016538461538, 0.8705522307692307, 0.5721887692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 327}], {
             RGBColor[
             0.9563479999999999, 0.9664519999999999, 0.9381238076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 337}], {
             RGBColor[
             0.9858981538461538, 0.9884365384615384, 0.8833676153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 354}], {
             RGBColor[
             0.9029410769230769, 0.9238667692307692, 0.9330298076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 392}], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.8268168461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 94}], {
             RGBColor[
             0.8255453461538461, 0.8615343846153846, 0.8354676923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 119}], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 128}], {
             RGBColor[
             0.9709789615384615, 0.9758853846153845, 0.8396858076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 225}], {
             RGBColor[
             0.9921893461538461, 0.9908536923076923, 0.7657011923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 296}], {
             RGBColor[
             0.7969011923076923, 0.838489076923077, 0.8330696153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 301}], {
             RGBColor[
             0.9825425384615385, 0.9511908461538461, 0.5213035384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 316}], {
             RGBColor[
             0.9695460769230768, 0.9038201538461537, 0.48920203846153865`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 324}], {
             RGBColor[
             0.9946406923076923, 0.9909453076923077, 0.6580506153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 355}], {
             RGBColor[
             0.9769209999999999, 0.9322280769230769, 0.49946492307692325`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 380}], {
             RGBColor[
             0.9390733076923077, 0.7769139230769231, 0.4643678076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 383}], {
             RGBColor[
             0.9709789615384615, 0.9758853846153845, 0.8396858076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 390}], {
             RGBColor[
             0.9937856153846154, 0.9891163846153845, 0.5649807692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 119}], {
             RGBColor[
             0.8255453461538461, 0.8615343846153846, 0.8354676923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 128}], {
             RGBColor[
             0.8014560769230769, 0.8455599999999999, 0.9705679615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 177}], {
             RGBColor[0.7380032307692308, 0.795253, 0.9745209230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 200}], {
             RGBColor[
             0.773607846153846, 0.8236431538461537, 0.9779169230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 225}], {
             RGBColor[
             0.8226664615384615, 0.8605283076923076, 0.896583346153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 288}], {
             RGBColor[
             0.8226664615384615, 0.8605283076923076, 0.896583346153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 296}], {
             RGBColor[
             0.6273783076923076, 0.7081636923076923, 0.9639517692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 316}], {
             RGBColor[
             0.8000231923076921, 0.773494769230769, 0.6200841923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 324}], {
             RGBColor[
             0.8251178076923076, 0.860619923076923, 0.7889327692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 355}], {
             RGBColor[
             0.8073981153846153, 0.8019026923076922, 0.6303470769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 375}], {
             RGBColor[
             0.8073981153846153, 0.8019026923076922, 0.6303470769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 380}], {
             RGBColor[
             0.769550423076923, 0.6465885384615384, 0.5952499615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 383}], {
             RGBColor[
             0.8014560769230769, 0.8455599999999999, 0.9705679615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 390}], {
             RGBColor[
             0.8242627307692307, 0.8587909999999999, 0.695862923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 129}], {
             RGBColor[
             0.9738543846153846, 0.9797377692307693, 0.9164482307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 151}], {
             RGBColor[
             0.9755605384615385, 0.9804433076923078, 0.8881728461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 178}], {
             RGBColor[
             0.9738543846153846, 0.9797377692307693, 0.9164482307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 229}], {
             RGBColor[
             0.9692710769230769, 0.9766030000000001, 0.9369002307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 249}], {
             RGBColor[
             0.9265019230769231, 0.9435581538461539, 0.969506423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 270}], {
             RGBColor[
             0.9602921923076924, 0.9218176923076924, 0.6219365769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 308}], {
             RGBColor[
             0.9529172692307692, 0.8934097692307691, 0.6116736923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 309}], {
             RGBColor[
             0.7802723846153847, 0.8280786923076924, 0.9555412692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 334}], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 371}], {
             RGBColor[
             0.9755605384615385, 0.9804433076923078, 0.8881728461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 386}], {
             RGBColor[
             0.9755605384615385, 0.9804433076923078, 0.8881728461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 110}], {
             RGBColor[
             0.9659137307692307, 0.9407804615384615, 0.6437751923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 114}], {
             RGBColor[
             0.9796636538461538, 0.9501847692307692, 0.5824191923076921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 115}], {
             RGBColor[
             0.9128027307692308, 0.8991045384615384, 0.662054769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 153}], {
             RGBColor[
             0.9825425384615385, 0.9511908461538461, 0.5213035384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 154}], {
             RGBColor[
             0.9659137307692307, 0.9407804615384615, 0.6437751923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 167}], {
             RGBColor[
             0.9584532692307692, 0.9352164615384615, 0.6564038076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 188}], {
             RGBColor[
             0.9813698076923076, 0.9508903076923076, 0.5541438076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 192}], {
             RGBColor[
             0.9411016153846153, 0.8000386153846153, 0.29311142307692295`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 203}], {
             RGBColor[
             0.9659137307692307, 0.9407804615384615, 0.6437751923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 228}], {
             RGBColor[0.8676735, 0.8635614615384615, 0.6576330769230767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 243}], {
             RGBColor[
             0.9816874615384615, 0.949361923076923, 0.42823369230769226`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 258}], {
             RGBColor[
             0.9813698076923076, 0.9508903076923076, 0.5541438076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 284}], {
             RGBColor[
             0.9490609999999999, 0.831594923076923, 0.29951573076923066`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 348}], {
             RGBColor[
             0.9813698076923076, 0.9508903076923076, 0.5541438076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 361}], {
             RGBColor[
             0.9825425384615385, 0.9511908461538461, 0.5213035384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 369}], {
             RGBColor[
             0.9756383846153845, 0.929484692307692, 0.35986015384615355`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 100}], {
             RGBColor[
             0.9868814615384616, 0.9674102307692306, 0.40353738461538435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 105}], {
             RGBColor[
             0.9184242692307691, 0.9180673076923076, 0.6838933846153844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 112}], {
             RGBColor[
             0.9852851923076922, 0.9691475384615383, 0.6042578076923074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 132}], {
             RGBColor[
             0.9869913461538461, 0.9698530769230769, 0.5759824230769228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 140}], {
             RGBColor[
             0.8992894615384615, 0.5412872307692307, 0.2729583846153844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 141}], {
             RGBColor[
             0.9835790384615384, 0.9684419999999998, 0.6325331923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 168}], {
             RGBColor[
             0.8186411923076922, 0.8398282307692306, 0.6740243076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 180}], {
             RGBColor[
             0.9869913461538461, 0.9698530769230769, 0.5759824230769228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 220}], {
             RGBColor[
             0.9540288846153845, 0.9464574615384613, 0.6872893846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 282}], {
             RGBColor[
             0.9184242692307691, 0.9180673076923076, 0.6838933846153844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 350}], {
             RGBColor[
             0.7061680384615385, 0.748122846153846, 0.665193769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 357}], {
             RGBColor[
             0.9006219615384615, 0.9038722307692306, 0.6821953846153844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 394}], {
             RGBColor[
             0.9869913461538461, 0.9698530769230769, 0.5759824230769228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 107}], {
             RGBColor[
             0.9449578846153845, 0.8618534615384615, 0.6052693846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 131}], {
             RGBColor[
             0.9434394615384615, 0.8126321538461538, 0.27767711538461537`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 215}], {
             RGBColor[
             0.8740445769230769, 0.8059824615384614, 0.6218509615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 283}], {
             RGBColor[
             0.9374974230769231, 0.8562894615384615, 0.6178980000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 297}], {
             RGBColor[
             0.9546825384615384, 0.8505576923076921, 0.32135434615384595`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 307}], {
             RGBColor[
             0.8193907307692307, 0.7632864615384615, 0.6164035769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 352}], {
             RGBColor[
             0.952418346153846, 0.8674174615384616, 0.5926407692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 123}], {
             RGBColor[
             0.9443042307692306, 0.9577532307692307, 0.971204423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 174}], {
             RGBColor[0.9089955384615384, 0.9302723846153845, 0.991182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 187}], {
             RGBColor[
             0.9517646923076921, 0.9633172307692307, 0.9585758076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 193}], {
             RGBColor[
             0.9049381153846152, 0.7532177692307691, 0.6085150384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[0.872058423076923, 0.5392972307692308, 0.578549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 232}], {
             RGBColor[
             0.9517646923076921, 0.9633172307692307, 0.9585758076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 235}], {
             RGBColor[
             0.9580541538461538, 0.9671575384615384, 0.909848423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 275}], {
             RGBColor[
             0.9274514999999999, 0.8485676923076921, 0.6269449615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 279}], {
             RGBColor[
             0.9605054999999999, 0.9672491538461538, 0.8021978461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 281}], {
             RGBColor[
             0.9274514999999999, 0.8485676923076921, 0.6269449615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 306}], {
             RGBColor[
             0.9517646923076921, 0.9633172307692307, 0.9585758076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 338}], {
             RGBColor[
             0.9274514999999999, 0.8485676923076921, 0.6269449615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 384}], {
             RGBColor[0.873390923076923, 0.9018822307692307, 0.987786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 105}], {
             RGBColor[
             0.9240458076923077, 0.9370300769230768, 0.7057319999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 112}], {
             RGBColor[
             0.9909067307692307, 0.9881103076923077, 0.6260964230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 141}], {
             RGBColor[
             0.989200576923077, 0.9874047692307693, 0.6543718076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 168}], {
             RGBColor[
             0.8242627307692307, 0.8587909999999999, 0.6958629230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 170}], {
             RGBColor[0.904911, 0.5602499999999999, 0.2947969999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 180}], {
             RGBColor[
             0.9926128846153845, 0.9888158461538461, 0.5978210384615383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 220}], {
             RGBColor[0.9596504230769229, 0.9654202307692307, 0.709128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 271}], {
             RGBColor[
             0.9909067307692307, 0.9881103076923077, 0.6260964230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 273}], {
             RGBColor[
             0.9926128846153845, 0.9888158461538461, 0.5978210384615383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 282}], {
             RGBColor[
             0.9240458076923077, 0.9370300769230768, 0.7057319999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 350}], {
             RGBColor[
             0.711789576923077, 0.7670856153846154, 0.6870323846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 394}], {
             RGBColor[
             0.9926128846153845, 0.9888158461538461, 0.5978210384615383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 151}], {
             RGBColor[
             0.9830209999999999, 0.9860073076923077, 0.8755442307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 171}], {
             RGBColor[0.9846172692307692, 0.98427, 0.6748238076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 182}], {
             RGBColor[
             0.7586496153846154, 0.8100316153846154, 0.9406231153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 244}], {
             RGBColor[0.8970252692307692, 0.558147, 0.5442448076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 253}], {
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 270}], {
             RGBColor[
             0.9677526538461538, 0.9273816923076923, 0.6093079615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 308}], {
             RGBColor[
             0.9603777307692307, 0.8989737692307691, 0.5990450769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 397}], {
             RGBColor[
             0.9517646923076921, 0.9633172307692307, 0.9585758076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 160}], {
             RGBColor[
             0.5239531538461539, 0.4016707307692309, 0.5729432307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 166}], {
             RGBColor[0.5703688076923077, 0.6382165, 0.9415149230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[
             0.5865700769230768, 0.6477124230769231, 0.7725083461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 213}], {
             RGBColor[
             0.5629083461538462, 0.6326525000000001, 0.9541435384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 224}], {
             RGBColor[
             0.5778292692307692, 0.6437805000000001, 0.9288863076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 230}], {
             RGBColor[
             0.5778292692307692, 0.6437805000000001, 0.9288863076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 247}], {
             RGBColor[
             0.5350601153846153, 0.6107356538461539, 0.9614925000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 250}], {
             RGBColor[
             0.5841187307692308, 0.6476208076923078, 0.880158923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 289}], {
             RGBColor[
             0.5778292692307692, 0.6437805000000001, 0.9288863076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 302}], {
             RGBColor[0.4994555, 0.5823455, 0.9580965]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{102, 340}], {
             RGBColor[0.5703688076923077, 0.6382165, 0.9415149230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 370}], {
             RGBColor[0.4994555, 0.5823455, 0.9580965]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{102, 391}], {
             RGBColor[
             0.5800934615384614, 0.6269207307692306, 0.6575998846153844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 400}], {
             RGBColor[
             0.5861425384615384, 0.6467979615384616, 0.7259734230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 108}], {
             RGBColor[
             0.9830209999999999, 0.9860073076923077, 0.8755442307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 133}], {
             RGBColor[
             0.9921893461538461, 0.9908536923076923, 0.7657011923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 143}], {
             RGBColor[
             0.9755605384615385, 0.9804433076923078, 0.8881728461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 223}], {
             RGBColor[
             0.7649390769230768, 0.8138719230769231, 0.8918957307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 231}], {
             RGBColor[
             0.9681000769230769, 0.9748793076923077, 0.9008014615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 234}], {
             RGBColor[
             0.7358558461538461, 0.7902608461538461, 0.8896061923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 290}], {
             RGBColor[0.7940223076923076, 0.837483, 0.8941852692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 313}], {
             RGBColor[
             0.9224495384615384, 0.9387673846153846, 0.906452423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 331}], {
             RGBColor[
             0.9755605384615385, 0.9804433076923078, 0.8881728461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 342}], {
             RGBColor[
             0.9917618076923076, 0.9899392307692307, 0.7191662692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 346}], {
             RGBColor[
             0.9046472307692308, 0.9245723076923077, 0.904754423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 109}], {
             RGBColor[
             0.8801991923076924, 0.9042303846153845, 0.8409150769230771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 138}], {
             RGBColor[
             0.8756141538461538, 0.9025187692307692, 0.9303061153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 144}], {
             RGBColor[
             0.8789165769230769, 0.9014869999999999, 0.7013103076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 205}], {
             RGBColor[
             0.8620519615384615, 0.8445986923076922, 0.6357944615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 207}], {
             RGBColor[0.8710308461538461, 0.899384, 0.9507581153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 233}], {
             RGBColor[
             0.8460639999999999, 0.8805342307692307, 0.9850623076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 358}], {
             RGBColor[
             0.8312538076923077, 0.721294846153846, 0.6065796538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 366}], {
             RGBColor[
             0.8387582692307692, 0.7530781538461538, 0.6127229615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 382}], {
             RGBColor[0.8676735, 0.8635614615384615, 0.6576330769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 112}], {
             RGBColor[
             0.9224495384615384, 0.9387673846153846, 0.906452423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 113}], {
             RGBColor[
             0.8998062692307691, 0.851733846153846, 0.6299532692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 148}], {
             RGBColor[
             0.8427747307692308, 0.5594924615384618, 0.5812059230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 155}], {
             RGBColor[
             0.9253284230769231, 0.9397734615384615, 0.8453367692307694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 168}], {
             RGBColor[
             0.7558055384615384, 0.8094480769230769, 0.976218923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 170}], {
             RGBColor[0.8364538076923077, 0.5109070769230769, 0.575153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 180}], {
             RGBColor[
             0.9241556923076923, 0.9394729230769231, 0.8781770384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 239}], {
             RGBColor[
             0.9086996153846154, 0.929363076923077, 0.967808423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 271}], {
             RGBColor[
             0.9224495384615384, 0.9387673846153846, 0.906452423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 282}], {
             RGBColor[0.8555886153846154, 0.8876871538461538, 0.986088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 326}], {
             RGBColor[0.9249008846153846, 0.938859, 0.7988018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 350}], {
             RGBColor[
             0.6433323846153847, 0.7177426923076924, 0.9673883846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 394}], {
             RGBColor[
             0.9241556923076923, 0.9394729230769231, 0.8781770384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.9449578846153845, 0.8618534615384615, 0.6052693846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 173}], {
             RGBColor[
             0.9434394615384615, 0.8126321538461538, 0.27767711538461537`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 197}], {
             RGBColor[
             0.9360645384615384, 0.7842242307692305, 0.2674142307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 204}], {
             RGBColor[
             0.9587078076923077, 0.8712577692307693, 0.5439133846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 214}], {
             RGBColor[
             0.9281051538461538, 0.752667923076923, 0.26100992307692306`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 215}], {
             RGBColor[
             0.8740445769230769, 0.8059824615384614, 0.6218509615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 295}], {
             RGBColor[
             0.9360645384615384, 0.7842242307692305, 0.2674142307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 310}], {
             RGBColor[
             0.9374974230769231, 0.8562894615384615, 0.6178980000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 345}], {
             RGBColor[
             0.8985422307692308, 0.6253076923076923, 0.2366976923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 363}], {
             RGBColor[
             0.8467176538461538, 0.7846344615384615, 0.6191272692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 131}], {
             RGBColor[
             0.9602921923076924, 0.9218176923076924, 0.6219365769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 197}], {
             RGBColor[
             0.9529172692307692, 0.8934097692307691, 0.6116736923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 215}], {
             RGBColor[0.8908973076923077, 0.915168, 0.9661104230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 297}], {
             RGBColor[
             0.9715352692307693, 0.9597432307692306, 0.6656138076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 307}], {
             RGBColor[0.8362434615384615, 0.872472, 0.9606630384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 352}], {
             RGBColor[
             0.9692710769230769, 0.9766030000000001, 0.9369002307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 363}], {
             RGBColor[
             0.8635703846153846, 0.8938200000000001, 0.9633867307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 143}], {
             RGBColor[
             0.9692710769230769, 0.9766030000000001, 0.9369002307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 179}], {
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 196}], {
             RGBColor[
             0.9789957307692307, 0.9653072307692306, 0.6529851923076921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 231}], {
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 234}], {
             RGBColor[
             0.7295663846153846, 0.7864205384615384, 0.938333576923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 290}], {
             RGBColor[
             0.7877328461538462, 0.8336426923076923, 0.9429126538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 313}], {
             RGBColor[
             0.9161600769230769, 0.9349270769230769, 0.9551798076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 331}], {
             RGBColor[
             0.9692710769230769, 0.9766030000000001, 0.9369002307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 342}], {
             RGBColor[
             0.9854723461538462, 0.986098923076923, 0.7678936538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 344}], {
             RGBColor[
             0.9858998846153846, 0.9870133846153846, 0.8144285769230771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 136}], {
             RGBColor[
             0.9695460769230768, 0.9038201538461537, 0.48920203846153865`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 205}], {
             RGBColor[
             0.9769209999999999, 0.9322280769230769, 0.49946492307692325`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 207}], {
             RGBColor[
             0.9858998846153846, 0.9870133846153846, 0.8144285769230771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 233}], {
             RGBColor[
             0.9609330384615384, 0.9681636153846154, 0.8487327692307695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 286}], {
             RGBColor[
             0.9937856153846154, 0.9891163846153845, 0.5649807692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 320}], {
             RGBColor[
             0.8528722692307692, 0.8828823846153846, 0.8381913846153848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 343}], {
             RGBColor[
             0.9320237692307692, 0.7449036153846155, 0.4584855000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 358}], {
             RGBColor[
             0.9461228461538461, 0.8089242307692307, 0.4702501153846156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 366}], {
             RGBColor[
             0.9536273076923076, 0.8407075384615386, 0.47639342307692334`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 382}], {
             RGBColor[
             0.9825425384615385, 0.9511908461538461, 0.5213035384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 115}], {
             RGBColor[
             0.9086996153846154, 0.929363076923077, 0.967808423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 134}], {
             RGBColor[
             0.9715352692307693, 0.9597432307692306, 0.6656138076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 167}], {
             RGBColor[
             0.9543501538461538, 0.9654750000000001, 0.9621574615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 192}], {
             RGBColor[
             0.9369985000000001, 0.8302971538461539, 0.5988650769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 203}], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 243}], {
             RGBColor[
             0.9775843461538463, 0.9796204615384616, 0.7339873461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 348}], {
             RGBColor[
             0.9772666923076923, 0.9811488461538462, 0.8598974615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 351}], {
             RGBColor[0.8908973076923077, 0.915168, 0.9661104230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 369}], {
             RGBColor[
             0.9715352692307693, 0.9597432307692306, 0.6656138076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 160}], {
             RGBColor[
             0.9251196153846153, 0.7231974615384615, 0.2970421153846152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 166}], {
             RGBColor[
             0.9715352692307693, 0.9597432307692306, 0.6656138076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.9877365384615384, 0.9692391538461538, 0.4966072307692305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 197}], {
             RGBColor[
             0.962641923076923, 0.8821139999999996, 0.3277586538461536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[0.987309, 0.9683246923076922, 0.45007230769230755`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 155}], {
             RGBColor[
             0.9921893461538461, 0.9908536923076923, 0.7657011923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 170}], {
             RGBColor[
             0.9033147307692307, 0.5619873076923076, 0.495517423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 180}], {
             RGBColor[
             0.9910166153846154, 0.9905531538461538, 0.7985414615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 183}], {
             RGBColor[
             0.9909067307692307, 0.9881103076923077, 0.6260964230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 271}], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 273}], {
             RGBColor[
             0.9910166153846154, 0.9905531538461538, 0.7985414615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 326}], {
             RGBColor[
             0.9917618076923076, 0.9899392307692307, 0.7191662692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 350}], {
             RGBColor[
             0.7101933076923077, 0.7688229230769231, 0.8877528076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 394}], {
             RGBColor[
             0.9910166153846154, 0.9905531538461538, 0.7985414615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 148}], {
             RGBColor[
             0.8869923846153847, 0.5235391538461539, 0.2250711923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 168}], {
             RGBColor[
             0.8000231923076921, 0.773494769230769, 0.6200841923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 170}], {
             RGBColor[
             0.8806714615384614, 0.47495376923076904`, 0.21901826923076917`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 251}], {
             RGBColor[
             0.9649610384615384, 0.9021085384615383, 0.5785930769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 282}], {
             RGBColor[
             0.8998062692307691, 0.851733846153846, 0.6299532692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 153}], {
             RGBColor[
             0.9921893461538461, 0.9908536923076923, 0.7657011923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 154}], {
             RGBColor[
             0.9755605384615385, 0.9804433076923078, 0.8881728461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 188}], {
             RGBColor[
             0.9910166153846154, 0.9905531538461538, 0.7985414615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 203}], {
             RGBColor[
             0.9755605384615385, 0.9804433076923078, 0.8881728461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 222}], {
             RGBColor[
             0.8773203076923077, 0.9032243076923077, 0.9020307307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 258}], {
             RGBColor[
             0.9910166153846154, 0.9905531538461538, 0.7985414615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 312}], {
             RGBColor[
             0.9046472307692308, 0.9245723076923077, 0.904754423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 327}], {
             RGBColor[
             0.9580541538461538, 0.9671575384615384, 0.909848423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 356}], {
             RGBColor[
             0.9909067307692307, 0.9881103076923077, 0.6260964230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 361}], {
             RGBColor[
             0.9921893461538461, 0.9908536923076923, 0.7657011923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 369}], {
             RGBColor[
             0.9852851923076922, 0.9691475384615383, 0.6042578076923074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 392}], {
             RGBColor[
             0.9910166153846154, 0.9905531538461538, 0.7985414615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 184}], {
             RGBColor[
             0.9240458076923077, 0.9370300769230768, 0.7057319999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 188}], {
             RGBColor[
             0.9241556923076923, 0.9394729230769231, 0.8781770384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 195}], {
             RGBColor[
             0.9012391538461538, 0.9237990769230768, 0.9804370384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 203}], {
             RGBColor[
             0.9086996153846154, 0.929363076923077, 0.967808423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 206}], {
             RGBColor[
             0.9241556923076923, 0.9394729230769231, 0.8781770384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 208}], {
             RGBColor[
             0.9253284230769231, 0.9397734615384615, 0.8453367692307694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 258}], {
             RGBColor[
             0.9241556923076923, 0.9394729230769231, 0.8781770384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 284}], {
             RGBColor[
             0.8918468846153846, 0.8201775384615384, 0.6235489615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 325}], {
             RGBColor[
             0.9224495384615384, 0.9387673846153846, 0.906452423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 369}], {
             RGBColor[
             0.9184242692307691, 0.9180673076923076, 0.6838933846153844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 392}], {
             RGBColor[
             0.9241556923076923, 0.9394729230769231, 0.8781770384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 121}], {
             RGBColor[
             0.7669628846153846, 0.8130490769230769, 0.7377102307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 130}], {
             RGBColor[
             0.7496707307692307, 0.7552463076923077, 0.6256594615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 135}], {
             RGBColor[
             0.763232923076923, 0.8131663846153846, 0.9201711153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 147}], {
             RGBColor[
             0.6802758461538462, 0.7485966153846153, 0.9698333076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 172}], {
             RGBColor[
             0.7552922692307692, 0.7742090769230768, 0.6474980769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 265}], {
             RGBColor[
             0.7437286923076922, 0.7989036153846154, 0.9658803461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 276}], {
             RGBColor[
             0.7552922692307692, 0.7742090769230768, 0.6474980769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 322}], {
             RGBColor[
             0.7665353461538462, 0.8121346153846154, 0.6911753076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 328}], {
             RGBColor[
             0.7422958076923076, 0.7268383846153844, 0.6153965769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 362}], {
             RGBColor[
             0.7673904230769231, 0.8139635384615385, 0.7842451538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 364}], {
             RGBColor[
             0.7437286923076922, 0.7989036153846154, 0.9658803461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 387}], {
             RGBColor[
             0.7649390769230768, 0.8138719230769231, 0.8918957307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 223}], {
             RGBColor[
             0.7673904230769231, 0.8139635384615385, 0.7842451538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 346}], {
             RGBColor[
             0.9070985769230769, 0.9246639230769231, 0.7971038461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 371}], {
             RGBColor[
             0.9917618076923076, 0.9899392307692307, 0.7191662692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 126}], {
             RGBColor[
             0.970551423076923, 0.974970923076923, 0.7931508846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 149}], {
             RGBColor[
             0.9220335769230769, 0.792949846153846, 0.6053503846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 212}], {
             RGBColor[
             0.9640748076923076, 0.9541792307692306, 0.6782424230769228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 259}], {
             RGBColor[
             0.9528317307692307, 0.9162536923076923, 0.6345651923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 293}], {
             RGBColor[
             0.9149840384615384, 0.7609395384615385, 0.5994680769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 299}], {
             RGBColor[0.8287829999999999, 0.866908, 0.9732916538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 336}], {
             RGBColor[
             0.9709789615384615, 0.9758853846153845, 0.8396858076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 367}], {
             RGBColor[0.9696963461538461, 0.973142, 0.7000810384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 200}], {
             RGBColor[
             0.9431307307692307, 0.9539685384615384, 0.8470347692307695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 225}], {
             RGBColor[
             0.9921893461538461, 0.9908536923076923, 0.7657011923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 288}], {
             RGBColor[
             0.9921893461538461, 0.9908536923076923, 0.7657011923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 296}], {
             RGBColor[
             0.7969011923076923, 0.838489076923077, 0.8330696153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 316}], {
             RGBColor[
             0.9695460769230768, 0.9038201538461537, 0.48920203846153865`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 324}], {
             RGBColor[
             0.9946406923076923, 0.9909453076923077, 0.6580506153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 355}], {
             RGBColor[
             0.9769209999999999, 0.9322280769230769, 0.49946492307692325`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 375}], {
             RGBColor[
             0.9769209999999999, 0.9322280769230769, 0.49946492307692325`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 380}], {
             RGBColor[
             0.9390733076923077, 0.7769139230769231, 0.4643678076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 383}], {
             RGBColor[
             0.9709789615384615, 0.9758853846153845, 0.8396858076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 390}], {
             RGBColor[
             0.9937856153846154, 0.9891163846153845, 0.5649807692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 136}], {
             RGBColor[
             0.9691185384615384, 0.9029056923076921, 0.4426671153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 237}], {
             RGBColor[
             0.9427031923076923, 0.9530540769230769, 0.8004998461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 246}], {
             RGBColor[
             0.9386457692307693, 0.7759994615384616, 0.4178328846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 254}], {
             RGBColor[0.9249008846153846, 0.938859, 0.7988018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 286}], {
             RGBColor[
             0.993358076923077, 0.988201923076923, 0.518445846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 320}], {
             RGBColor[
             0.8524447307692307, 0.8819679230769231, 0.7916564615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 343}], {
             RGBColor[
             0.9315962307692307, 0.7439891538461539, 0.4119505769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 349}], {
             RGBColor[
             0.9946406923076923, 0.9909453076923077, 0.6580506153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 130}], {
             RGBColor[
             0.9760659230769231, 0.9303991538461538, 0.40639507692307697`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 158}], {
             RGBColor[
             0.9775843461538463, 0.9796204615384616, 0.7339873461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 181}], {
             RGBColor[
             0.9600779615384615, 0.9663346923076923, 0.7556629230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 250}], {
             RGBColor[
             0.9913342692307692, 0.9890247692307692, 0.6726313461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 265}], {
             RGBColor[
             0.9701238846153846, 0.9740564615384615, 0.7466159615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 322}], {
             RGBColor[
             0.9929305384615386, 0.9872874615384615, 0.47191092307692306`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 362}], {
             RGBColor[
             0.9937856153846154, 0.9891163846153846, 0.5649807692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 146}], {
             RGBColor[
             0.9184242692307691, 0.9180673076923076, 0.6838933846153844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.9881640769230768, 0.9701536153846153, 0.5431421538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 165}], {
             RGBColor[
             0.9540288846153845, 0.9464574615384613, 0.6872893846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 210}], {
             RGBColor[
             0.9852851923076922, 0.9691475384615383, 0.6042578076923074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 228}], {
             RGBColor[
             0.8732950384615384, 0.8825242307692306, 0.6794716923076921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 262}], {
             RGBColor[
             0.9715352692307693, 0.9597432307692306, 0.6656138076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 298}], {
             RGBColor[
             0.9321691538461538, 0.755207769230769, 0.3029244230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 314}], {
             RGBColor[
             0.9715352692307693, 0.9597432307692306, 0.6656138076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 385}], {
             RGBColor[
             0.9852851923076922, 0.9691475384615383, 0.6042578076923074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 174}], {
             RGBColor[
             0.9265019230769231, 0.9435581538461539, 0.969506423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 187}], {
             RGBColor[
             0.9692710769230769, 0.9766030000000001, 0.9369002307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 193}], {
             RGBColor[0.9224445, 0.7665035384615385, 0.5868394615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 218}], {
             RGBColor[0.8895648076923077, 0.552583, 0.556873423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 232}], {
             RGBColor[
             0.9692710769230769, 0.9766030000000001, 0.9369002307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 235}], {
             RGBColor[
             0.9755605384615385, 0.9804433076923078, 0.8881728461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 275}], {
             RGBColor[
             0.9449578846153845, 0.8618534615384615, 0.6052693846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 279}], {
             RGBColor[
             0.9780118846153847, 0.9805349230769231, 0.7805222692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 281}], {
             RGBColor[
             0.9449578846153845, 0.8618534615384615, 0.6052693846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 306}], {
             RGBColor[
             0.9692710769230769, 0.9766030000000001, 0.9369002307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 338}], {
             RGBColor[
             0.9449578846153845, 0.8618534615384615, 0.6052693846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.9220335769230769, 0.792949846153846, 0.6053503846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 199}], {
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 238}], {
             RGBColor[
             0.9698062307692308, 0.9755848461538461, 0.8725260769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 252}], {
             RGBColor[0.9079345, 0.7289292307692308, 0.5935857692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 277}], {
             RGBColor[
             0.966393923076923, 0.9741737692307693, 0.9290768461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 293}], {
             RGBColor[
             0.9149840384615384, 0.7609395384615385, 0.5994680769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 330}], {
             RGBColor[
             0.9681000769230769, 0.9748793076923077, 0.9008014615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 179}], {
             RGBColor[
             0.9640748076923076, 0.9541792307692306, 0.6782424230769228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 196}], {
             RGBColor[
             0.981259923076923, 0.9484474615384613, 0.38169876923076884`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 303}], {
             RGBColor[
             0.9640748076923076, 0.9541792307692306, 0.6782424230769228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 313}], {
             RGBColor[
             0.9184242692307691, 0.9180673076923076, 0.6838933846153844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 344}], {
             RGBColor[
             0.9881640769230768, 0.9701536153846153, 0.5431421538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 149}], {
             RGBColor[
             0.9456953076923076, 0.8080097692307692, 0.4237151923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 199}], {
             RGBColor[
             0.9854723461538462, 0.986098923076923, 0.7678936538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 212}], {
             RGBColor[
             0.9877365384615384, 0.9692391538461538, 0.4966072307692305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 238}], {
             RGBColor[
             0.9934679615384615, 0.9906447692307693, 0.6908908846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 259}], {
             RGBColor[
             0.9764934615384615, 0.9313136153846153, 0.45292999999999994`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 274}], {
             RGBColor[
             0.9691185384615384, 0.9029056923076921, 0.4426671153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 299}], {
             RGBColor[
             0.8524447307692307, 0.8819679230769231, 0.7916564615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 318}], {
             RGBColor[
             0.9427031923076923, 0.9530540769230769, 0.8004998461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 336}], {
             RGBColor[
             0.9946406923076923, 0.9909453076923077, 0.6580506153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 367}], {
             RGBColor[
             0.993358076923077, 0.988201923076923, 0.518445846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 139}], {
             RGBColor[
             0.9431307307692307, 0.9539685384615384, 0.8470347692307695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 184}], {
             RGBColor[
             0.9937856153846154, 0.9891163846153845, 0.5649807692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 305}], {
             RGBColor[
             0.8801991923076924, 0.9042303846153845, 0.8409150769230771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 325}], {
             RGBColor[
             0.9921893461538461, 0.9908536923076923, 0.7657011923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 177}], {
             RGBColor[0.8834368461538462, 0.909604, 0.9787390384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 225}], {
             RGBColor[
             0.9681000769230769, 0.9748793076923077, 0.9008014615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 296}], {
             RGBColor[
             0.772811923076923, 0.8225146923076923, 0.9681698846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 311}], {
             RGBColor[
             0.9295380384615384, 0.8247331538461539, 0.6114936923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 316}], {
             RGBColor[
             0.9454568076923076, 0.8878457692307691, 0.6243023076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 324}], {
             RGBColor[
             0.970551423076923, 0.974970923076923, 0.7931508846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 380}], {
             RGBColor[
             0.9149840384615384, 0.7609395384615385, 0.5994680769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 383}], {
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 390}], {
             RGBColor[0.9696963461538461, 0.973142, 0.7000810384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 178}], {
             RGBColor[
             0.9858981538461538, 0.9884365384615384, 0.8833676153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 229}], {
             RGBColor[
             0.9813148461538461, 0.9853017692307693, 0.9038196153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 249}], {
             RGBColor[
             0.9385456923076922, 0.9522569230769231, 0.9364258076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 270}], {
             RGBColor[
             0.9723359615384615, 0.9305164615384616, 0.5888559615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 308}], {
             RGBColor[
             0.9649610384615384, 0.9021085384615383, 0.5785930769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 309}], {
             RGBColor[
             0.7923161538461538, 0.8367774615384616, 0.9224606538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 397}], {
             RGBColor[
             0.9563479999999999, 0.9664519999999999, 0.9381238076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 135}], {
             RGBColor[
             0.9723359615384615, 0.9305164615384616, 0.5888559615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 147}], {
             RGBColor[
             0.8893788846153846, 0.8659466923076923, 0.6385181538461537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 158}], {
             RGBColor[
             0.9602921923076924, 0.9218176923076924, 0.6219365769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 172}], {
             RGBColor[
             0.9643953076923076, 0.8915591538461538, 0.3161829230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 181}], {
             RGBColor[
             0.9427858076923076, 0.908531923076923, 0.6436121538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 265}], {
             RGBColor[
             0.9528317307692307, 0.9162536923076923, 0.6345651923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 322}], {
             RGBColor[
             0.9756383846153847, 0.9294846923076923, 0.3598601538461537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 328}], {
             RGBColor[
             0.9513988461538461, 0.8441884615384614, 0.28408142307692297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 347}], {
             RGBColor[
             0.9279756153846153, 0.7492925384615383, 0.26512949999999996`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 362}], {
             RGBColor[
             0.9764934615384615, 0.9313136153846153, 0.45292999999999994`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 364}], {
             RGBColor[
             0.9528317307692307, 0.9162536923076923, 0.6345651923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 387}], {
             RGBColor[0.9740421153846153, 0.931222, 0.5605805769230767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 215}], {
             RGBColor[
             0.8893788846153846, 0.8659466923076923, 0.6385181538461537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 217}], {
             RGBColor[
             0.9769209999999999, 0.9322280769230769, 0.49946492307692325`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 262}], {
             RGBColor[
             0.9602921923076924, 0.9218176923076924, 0.6219365769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 269}], {
             RGBColor[
             0.7787539615384615, 0.7788573846153846, 0.6279489999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 279}], {
             RGBColor[
             0.9764934615384615, 0.9313136153846153, 0.45292999999999994`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 297}], {
             RGBColor[
             0.9700168461538461, 0.9105219230769229, 0.33802153846153826`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 300}], {
             RGBColor[0.9740421153846153, 0.931222, 0.5605805769230767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 306}], {
             RGBColor[
             0.9677526538461538, 0.9273816923076923, 0.6093079615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 307}], {
             RGBColor[
             0.8347250384615383, 0.8232506923076923, 0.6330707692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 314}], {
             RGBColor[
             0.9602921923076924, 0.9218176923076924, 0.6219365769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 352}], {
             RGBColor[
             0.9677526538461538, 0.9273816923076923, 0.6093079615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 363}], {
             RGBColor[
             0.8620519615384615, 0.8445986923076922, 0.6357944615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 140}], {
             RGBColor[
             0.9050208846153847, 0.5626928461538462, 0.46724203846153844`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 191}], {
             RGBColor[
             0.9050208846153847, 0.5626928461538462, 0.46724203846153844`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 198}], {
             RGBColor[
             0.9176627307692308, 0.6598636153846155, 0.47934788461538463`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 216}], {
             RGBColor[
             0.9683733461538461, 0.9035196153846152, 0.5220423076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 219}], {
             RGBColor[
             0.9934679615384615, 0.9906447692307693, 0.6908908846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 220}], {
             RGBColor[
             0.9597603076923076, 0.9678630769230769, 0.8815730384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 302}], {
             RGBColor[
             0.9063533846153846, 0.9252778461538462, 0.8764790384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 323}], {
             RGBColor[
             0.9934679615384615, 0.9906447692307693, 0.6908908846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 357}], {
             RGBColor[
             0.9063533846153846, 0.9252778461538462, 0.8764790384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 145}], {
             RGBColor[
             0.9390733076923077, 0.7769139230769231, 0.4643678076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 164}], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 223}], {
             RGBColor[0.7678179615384615, 0.814878, 0.8307800769230771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 234}], {
             RGBColor[
             0.7387347307692308, 0.791266923076923, 0.8284905384615386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 280}], {
             RGBColor[
             0.9390733076923077, 0.7769139230769231, 0.4643678076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 346}], {
             RGBColor[
             0.9075261153846155, 0.9255783846153847, 0.8436387692307694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 167}], {
             RGBColor[
             0.9640748076923076, 0.9541792307692306, 0.6782424230769228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 201}], {
             RGBColor[
             0.8732950384615384, 0.8825242307692306, 0.6794716923076921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 236}], {
             RGBColor[
             0.981259923076923, 0.9484474615384613, 0.38169876923076884`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 243}], {
             RGBColor[0.987309, 0.9683246923076922, 0.45007230769230755`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 263}], {
             RGBColor[0.987309, 0.9683246923076922, 0.45007230769230755`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 348}], {
             RGBColor[
             0.9869913461538461, 0.9698530769230769, 0.5759824230769228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 351}], {
             RGBColor[
             0.9006219615384615, 0.9038722307692306, 0.6821953846153844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 221}], {
             RGBColor[
             0.9016085769230768, 0.5612817692307692, 0.5237928076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 276}], {
             RGBColor[
             0.9779574999999999, 0.9494792307692307, 0.6106945769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 322}], {
             RGBColor[
             0.989200576923077, 0.9874047692307693, 0.6543718076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 364}], {
             RGBColor[
             0.966393923076923, 0.9741737692307693, 0.9290768461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 376}], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.8268168461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 377}], {
             RGBColor[
             0.9904831923076922, 0.9901481538461538, 0.7939765769230772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 194}], {
             RGBColor[
             0.9135511538461538, 0.6888743076923075, 0.24898430769230764`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 237}], {
             RGBColor[
             0.9176085769230768, 0.8659289230769229, 0.6316512692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 246}], {
             RGBColor[
             0.9135511538461538, 0.6888743076923075, 0.24898430769230764`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 254}], {
             RGBColor[
             0.8998062692307691, 0.851733846153846, 0.6299532692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 286}], {
             RGBColor[
             0.9682634615384615, 0.9010767692307691, 0.34959726923076906`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 320}], {
             RGBColor[
             0.8273501153846152, 0.794842769230769, 0.6228078846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 343}], {
             RGBColor[
             0.9065016153846153, 0.6568639999999999, 0.24310199999999996`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 349}], {
             RGBColor[
             0.9695460769230768, 0.9038201538461537, 0.48920203846153865`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 376}], {
             RGBColor[
             0.9683733461538461, 0.9035196153846152, 0.5220423076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 199}], {
             RGBColor[
             0.9369544999999999, 0.804077846153846, 0.5800931538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 238}], {
             RGBColor[
             0.9449501153846154, 0.8086236923076923, 0.5030903846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 252}], {
             RGBColor[
             0.8830783846153846, 0.5619680769230769, 0.22415007692307692`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 277}], {
             RGBColor[
             0.9415378076923075, 0.8072126153846153, 0.5596411538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 285}], {
             RGBColor[
             0.8830783846153846, 0.5619680769230769, 0.22415007692307692`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 293}], {
             RGBColor[
             0.890127923076923, 0.5939783846153845, 0.2300323846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 330}], {
             RGBColor[
             0.9432439615384615, 0.8079181538461537, 0.5313657692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 144}], {
             RGBColor[
             0.989200576923077, 0.9874047692307693, 0.6543718076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 233}], {
             RGBColor[
             0.9563479999999999, 0.9664519999999999, 0.9381238076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 242}], {
             RGBColor[
             0.9835790384615384, 0.9684419999999998, 0.6325331923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 256}], {
             RGBColor[
             0.9207433846153845, 0.9380618461538461, 0.9347278076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 257}], {
             RGBColor[
             0.9876043076923076, 0.989142076923077, 0.8550922307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 317}], {
             RGBColor[
             0.9490422692307692, 0.8389959230769231, 0.5657844615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 366}], {
             RGBColor[
             0.9490422692307692, 0.8389959230769231, 0.5657844615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 381}], {
             RGBColor[
             0.9835790384615384, 0.9684419999999998, 0.6325331923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 382}], {
             RGBColor[
             0.9779574999999999, 0.9494792307692307, 0.6106945769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 184}], {
             RGBColor[
             0.9418481153846154, 0.9512251538461538, 0.7074299999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 305}], {
             RGBColor[
             0.8282616923076923, 0.8663391538461538, 0.9833643076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 325}], {
             RGBColor[
             0.940251846153846, 0.9529624615384615, 0.9081504230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 141}], {
             RGBColor[
             0.9016085769230768, 0.5612817692307692, 0.5237928076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 168}], {
             RGBColor[
             0.7366707307692307, 0.43266799999999994`, 0.5652839230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 191}], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 216}], {
             RGBColor[
             0.8806714615384614, 0.47495376923076904`, 0.21901826923076917`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 219}], {
             RGBColor[
             0.9057660769230769, 0.5620789230769231, 0.38786684615384615`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 220}], {
             RGBColor[0.872058423076923, 0.5392972307692308, 0.578549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 350}], {
             RGBColor[
             0.624197576923077, 0.3409626153846154, 0.5564533846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 357}], {
             RGBColor[0.8186515000000001, 0.496712, 0.573455]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{141, 150}], {
             RGBColor[
             0.9858981538461538, 0.9884365384615384, 0.8833676153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 189}], {
             RGBColor[
             0.9858981538461538, 0.9884365384615384, 0.8833676153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 219}], {
             RGBColor[
             0.9900556538461538, 0.9892336923076923, 0.7474416538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 220}], {
             RGBColor[
             0.9563479999999999, 0.9664519999999999, 0.9381238076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 273}], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.8268168461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 339}], {
             RGBColor[
             0.9385456923076922, 0.9522569230769231, 0.9364258076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 350}], {
             RGBColor[
             0.7084871538461539, 0.7681173846153846, 0.9160281923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 357}], {
             RGBColor[
             0.9029410769230769, 0.9238667692307692, 0.9330298076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 394}], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.8268168461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 202}], {
             RGBColor[
             0.9049381153846152, 0.7532177692307691, 0.6085150384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 214}], {
             RGBColor[
             0.9274514999999999, 0.8485676923076921, 0.6269449615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 217}], {
             RGBColor[
             0.9609330384615384, 0.9681636153846154, 0.8487327692307695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 257}], {
             RGBColor[
             0.9580541538461538, 0.9671575384615384, 0.909848423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 268}], {
             RGBColor[
             0.9427858076923076, 0.908531923076923, 0.6436121538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 275}], {
             RGBColor[
             0.9274514999999999, 0.8485676923076921, 0.6269449615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 279}], {
             RGBColor[
             0.9605054999999999, 0.9672491538461538, 0.8021978461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 300}], {
             RGBColor[
             0.9580541538461538, 0.9671575384615384, 0.909848423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 306}], {
             RGBColor[
             0.9517646923076921, 0.9633172307692307, 0.9585758076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 338}], {
             RGBColor[
             0.9274514999999999, 0.8485676923076921, 0.6269449615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 363}], {
             RGBColor[
             0.8460639999999999, 0.8805342307692307, 0.9850623076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 381}], {
             RGBColor[
             0.9540288846153845, 0.9464574615384613, 0.6872893846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 223}], {
             RGBColor[
             0.7511891538461539, 0.8044676153846154, 0.9532517307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 234}], {
             RGBColor[
             0.7221059230769231, 0.7808565384615385, 0.9509621923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 260}], {
             RGBColor[
             0.9692710769230769, 0.9766030000000001, 0.9369002307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 267}], {
             RGBColor[0.9224445, 0.7665035384615385, 0.5868394615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 272}], {
             RGBColor[
             0.9755605384615385, 0.9804433076923078, 0.8881728461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 290}], {
             RGBColor[
             0.7802723846153847, 0.8280786923076924, 0.9555412692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 291}], {
             RGBColor[
             0.9153949615384616, 0.7344932307692309, 0.5809571538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 321}], {
             RGBColor[
             0.9784394230769231, 0.9814493846153847, 0.8270571923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 331}], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 342}], {
             RGBColor[
             0.9780118846153847, 0.9805349230769231, 0.7805222692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 398}], {
             RGBColor[
             0.9294940384615384, 0.7985138461538461, 0.5927217692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 207}], {
             RGBColor[0.9846172692307692, 0.98427, 0.6748238076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 233}], {
             RGBColor[0.9596504230769229, 0.9654202307692307, 0.709128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 242}], {
             RGBColor[
             0.9868814615384616, 0.9674102307692306, 0.40353738461538435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 317}], {
             RGBColor[
             0.9523446923076924, 0.8379641538461539, 0.33678865384615375`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 358}], {
             RGBColor[
             0.9448402307692307, 0.806180846153846, 0.33064534615384605`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 366}], {
             RGBColor[
             0.9523446923076924, 0.8379641538461539, 0.33678865384615375`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 370}], {
             RGBColor[0.9062435, 0.922835, 0.7040339999999998]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{144, 391}], {
             RGBColor[
             0.9868814615384616, 0.9674102307692306, 0.40353738461538435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 162}], {
             RGBColor[
             0.8501986923076923, 0.34804753846153846`, 0.19418403846153848`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 164}], {
             RGBColor[0.9382182307692308, 0.775085, 0.3712979615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 227}], {
             RGBColor[
             0.936194423076923, 0.7759078461538462, 0.5254834615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 280}], {
             RGBColor[
             0.8830783846153846, 0.5619680769230769, 0.22415007692307692`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 359}], {
             RGBColor[
             0.6570772692307693, 0.5548831538461538, 0.5864194230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 154}], {
             RGBColor[
             0.9086996153846154, 0.929363076923077, 0.967808423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 159}], {
             RGBColor[
             0.9253284230769231, 0.9397734615384615, 0.8453367692307694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 165}], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 192}], {
             RGBColor[
             0.8838874999999999, 0.7886212307692309, 0.6171446538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 228}], {
             RGBColor[
             0.8104593846153847, 0.8521440769230768, 0.9816663076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 262}], {
             RGBColor[
             0.9086996153846154, 0.929363076923077, 0.967808423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 297}], {
             RGBColor[
             0.9184242692307691, 0.9180673076923076, 0.6838933846153844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 307}], {
             RGBColor[
             0.7831324615384615, 0.8307960769230769, 0.9789426153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 314}], {
             RGBColor[
             0.9086996153846154, 0.929363076923077, 0.967808423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 332}], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 385}], {
             RGBColor[
             0.9224495384615384, 0.9387673846153846, 0.906452423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 172}], {
             RGBColor[
             0.8950004230769231, 0.8849094615384614, 0.6603567692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 211}], {
             RGBColor[0.9062435, 0.922835, 0.7040339999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{147, 328}], {
             RGBColor[
             0.8820039615384615, 0.837538769230769, 0.6282552692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 347}], {
             RGBColor[
             0.8585807307692308, 0.7426428461538461, 0.6093033461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 364}], {
             RGBColor[0.8834368461538462, 0.909604, 0.9787390384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 372}], {
             RGBColor[
             0.8820039615384615, 0.837538769230769, 0.6282552692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 387}], {
             RGBColor[
             0.9046472307692308, 0.9245723076923077, 0.904754423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 161}], {
             RGBColor[
             0.9116594615384617, 0.6097498461538464, 0.34738484615384624`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 168}], {
             RGBColor[
             0.7429916538461538, 0.4812533846153848, 0.5713368461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 170}], {
             RGBColor[
             0.8236399230769231, 0.18271238461538486`, 0.1702709230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 251}], {
             RGBColor[
             0.9079295000000001, 0.6098671538461541, 0.5298457307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.8427747307692308, 0.5594924615384618, 0.5812059230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 312}], {
             RGBColor[
             0.8249724230769231, 0.5452973846153848, 0.5795079230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 326}], {
             RGBColor[
             0.9120870000000001, 0.610664307692308, 0.3939197692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 356}], {
             RGBColor[
             0.9112319230769231, 0.6088353846153848, 0.30084992307692304`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 199}], {
             RGBColor[
             0.9369544999999999, 0.804077846153846, 0.5800931538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 212}], {
             RGBColor[
             0.9392186923076922, 0.7872180769230768, 0.30880673076923054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 238}], {
             RGBColor[
             0.9449501153846154, 0.8086236923076923, 0.5030903846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 259}], {
             RGBColor[
             0.9279756153846153, 0.7492925384615383, 0.26512949999999996`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 274}], {
             RGBColor[
             0.9206006923076921, 0.7208846153846151, 0.2548666153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 287}], {
             RGBColor[
             0.8763830384615384, 0.756837923076923, 0.6110013461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 299}], {
             RGBColor[
             0.8039268846153845, 0.6999468461538461, 0.6038559615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 318}], {
             RGBColor[
             0.894185346153846, 0.7710329999999999, 0.6126993461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 336}], {
             RGBColor[
             0.9461228461538461, 0.8089242307692307, 0.4702501153846156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 367}], {
             RGBColor[
             0.9448402307692307, 0.806180846153846, 0.33064534615384605`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 186}], {
             RGBColor[
             0.9723359615384615, 0.9305164615384616, 0.5888559615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 189}], {
             RGBColor[
             0.9858981538461538, 0.9884365384615384, 0.8833676153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 226}], {
             RGBColor[
             0.9415378076923075, 0.8072126153846153, 0.5596411538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 241}], {
             RGBColor[
             0.9900556538461538, 0.9892336923076923, 0.7474416538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 255}], {
             RGBColor[
             0.9385456923076922, 0.9522569230769231, 0.9364258076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 266}], {
             RGBColor[
             0.9779574999999999, 0.9494792307692307, 0.6106945769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 365}], {
             RGBColor[
             0.989200576923077, 0.9874047692307693, 0.6543718076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 374}], {
             RGBColor[
             0.9723359615384615, 0.9305164615384616, 0.5888559615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 399}], {
             RGBColor[
             0.966393923076923, 0.9741737692307693, 0.9290768461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 171}], {
             RGBColor[
             0.9909067307692307, 0.9881103076923077, 0.6260964230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 182}], {
             RGBColor[
             0.7649390769230768, 0.8138719230769231, 0.8918957307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 244}], {
             RGBColor[
             0.9033147307692307, 0.5619873076923076, 0.495517423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 249}], {
             RGBColor[
             0.940251846153846, 0.9529624615384615, 0.9081504230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 253}], {
             RGBColor[
             0.9830209999999999, 0.9860073076923077, 0.8755442307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 270}], {
             RGBColor[0.9740421153846153, 0.931222, 0.5605805769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 308}], {
             RGBColor[
             0.9666671923076922, 0.9028140769230768, 0.5503176923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 386}], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 397}], {
             RGBColor[
             0.9580541538461538, 0.9671575384615384, 0.909848423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 156}], {
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 175}], {
             RGBColor[
             0.9904831923076922, 0.9901481538461538, 0.7939765769230772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 242}], {
             RGBColor[
             0.9881640769230768, 0.9701536153846153, 0.5431421538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 256}], {
             RGBColor[
             0.9253284230769231, 0.9397734615384615, 0.8453367692307694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 261}], {
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 264}], {
             RGBColor[
             0.9431307307692307, 0.9539685384615384, 0.8470347692307695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 317}], {
             RGBColor[
             0.9536273076923076, 0.8407075384615386, 0.47639342307692334`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 333}], {
             RGBColor[
             0.9937856153846154, 0.9891163846153845, 0.5649807692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 381}], {
             RGBColor[
             0.9881640769230768, 0.9701536153846153, 0.5431421538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 154}], {
             RGBColor[
             0.9784394230769231, 0.9814493846153847, 0.8270571923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 188}], {
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 195}], {
             RGBColor[
             0.9709789615384615, 0.9758853846153845, 0.8396858076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 203}], {
             RGBColor[
             0.9784394230769231, 0.9814493846153847, 0.8270571923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 258}], {
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 278}], {
             RGBColor[
             0.9253284230769231, 0.9397734615384615, 0.8453367692307694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 284}], {
             RGBColor[
             0.9615866923076923, 0.8722638461538461, 0.482797730769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 312}], {
             RGBColor[
             0.9075261153846155, 0.9255783846153847, 0.8436387692307694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 327}], {
             RGBColor[
             0.9609330384615384, 0.9681636153846154, 0.8487327692307695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 337}], {
             RGBColor[
             0.9904831923076922, 0.9901481538461538, 0.7939765769230772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[
             0.9937856153846154, 0.9891163846153845, 0.5649807692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 361}], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 369}], {
             RGBColor[
             0.9881640769230768, 0.9701536153846153, 0.5431421538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 392}], {
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 192}], {
             RGBColor[
             0.9369985000000001, 0.8302971538461539, 0.5988650769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 222}], {
             RGBColor[
             0.8635703846153846, 0.8938200000000001, 0.9633867307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 228}], {
             RGBColor[
             0.8635703846153846, 0.8938200000000001, 0.9633867307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 312}], {
             RGBColor[0.8908973076923077, 0.915168, 0.9661104230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 332}], {
             RGBColor[
             0.9443042307692306, 0.9577532307692307, 0.971204423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 356}], {
             RGBColor[
             0.9771568076923077, 0.9787060000000001, 0.6874524230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 361}], {
             RGBColor[
             0.9784394230769231, 0.9814493846153847, 0.8270571923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 385}], {
             RGBColor[
             0.9755605384615385, 0.9804433076923078, 0.8881728461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 170}], {
             RGBColor[
             0.9061936153846154, 0.5629933846153846, 0.43440176923076945`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 180}], {
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 183}], {
             RGBColor[
             0.9937856153846154, 0.9891163846153845, 0.5649807692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 239}], {
             RGBColor[
             0.9784394230769231, 0.9814493846153847, 0.8270571923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 271}], {
             RGBColor[
             0.9921893461538461, 0.9908536923076923, 0.7657011923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 326}], {
             RGBColor[
             0.9946406923076923, 0.9909453076923077, 0.6580506153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 335}], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 337}], {
             RGBColor[
             0.9904831923076922, 0.9901481538461538, 0.7939765769230772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 354}], {
             RGBColor[
             0.9075261153846155, 0.9255783846153847, 0.8436387692307694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 175}], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.8268168461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 202}], {
             RGBColor[
             0.9379005769230768, 0.7766133846153846, 0.4972080769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 214}], {
             RGBColor[0.9604139615384615, 0.8719633076923077, 0.515638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 256}], {
             RGBColor[
             0.9241556923076923, 0.9394729230769231, 0.8781770384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 261}], {
             RGBColor[
             0.9927227692307692, 0.9912586923076924, 0.7702660769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 264}], {
             RGBColor[0.941958, 0.953668, 0.8798750384615385]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{156, 295}], {
             RGBColor[
             0.9683733461538461, 0.9035196153846152, 0.5220423076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 310}], {
             RGBColor[
             0.9698062307692308, 0.9755848461538461, 0.8725260769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 363}], {
             RGBColor[
             0.8790264615384615, 0.9039298461538461, 0.8737553461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 381}], {
             RGBColor[
             0.9869913461538461, 0.9698530769230769, 0.5759824230769228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 187}], {
             RGBColor[
             0.9830209999999999, 0.9860073076923077, 0.8755442307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 218}], {
             RGBColor[
             0.9033147307692307, 0.5619873076923076, 0.495517423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 253}], {
             RGBColor[
             0.9830209999999999, 0.9860073076923077, 0.8755442307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 298}], {
             RGBColor[
             0.936194423076923, 0.7759078461538462, 0.5254834615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.9443042307692306, 0.9577532307692307, 0.971204423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 265}], {
             RGBColor[
             0.9543501538461538, 0.9654750000000001, 0.9621574615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 311}], {
             RGBColor[
             0.9369985000000001, 0.8302971538461539, 0.5988650769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 322}], {
             RGBColor[
             0.9771568076923077, 0.9787060000000001, 0.6874524230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 362}], {
             RGBColor[
             0.9780118846153847, 0.9805349230769231, 0.7805222692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 165}], {
             RGBColor[
             0.9609330384615384, 0.9681636153846154, 0.8487327692307695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 167}], {
             RGBColor[
             0.9709789615384615, 0.9758853846153845, 0.8396858076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 192}], {
             RGBColor[
             0.9536273076923076, 0.8407075384615386, 0.47639342307692334`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 201}], {
             RGBColor[
             0.8801991923076924, 0.9042303846153845, 0.8409150769230771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 210}], {
             RGBColor[
             0.9921893461538461, 0.9908536923076923, 0.7657011923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 228}], {
             RGBColor[
             0.8801991923076924, 0.9042303846153845, 0.8409150769230771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 236}], {
             RGBColor[
             0.9881640769230768, 0.9701536153846153, 0.5431421538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 243}], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 263}], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 166}], {
             RGBColor[
             0.9153949615384616, 0.7344932307692309, 0.5809571538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 185}], {
             RGBColor[
             0.9315962307692307, 0.7439891538461539, 0.4119505769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 213}], {
             RGBColor[0.9079345, 0.7289292307692308, 0.5935857692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 224}], {
             RGBColor[
             0.922855423076923, 0.7400572307692308, 0.5683285384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 247}], {
             RGBColor[
             0.8800862692307692, 0.7070123846153846, 0.6009347307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 289}], {
             RGBColor[
             0.922855423076923, 0.7400572307692308, 0.5683285384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 302}], {
             RGBColor[
             0.8444816538461539, 0.6786222307692309, 0.5975387307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 340}], {
             RGBColor[
             0.9153949615384616, 0.7344932307692309, 0.5809571538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 370}], {
             RGBColor[
             0.8444816538461539, 0.6786222307692309, 0.5975387307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 400}], {
             RGBColor[
             0.9311686923076923, 0.7430746923076924, 0.36541565384615393`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 170}], {
             RGBColor[
             0.9053385384615384, 0.5611644615384616, 0.3413319230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 222}], {
             RGBColor[
             0.8793441153846154, 0.9024014615384615, 0.7478452307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 239}], {
             RGBColor[
             0.9775843461538463, 0.9796204615384616, 0.7339873461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 251}], {
             RGBColor[
             0.9896281153846154, 0.9883192307692308, 0.7009067307692309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 312}], {
             RGBColor[
             0.9066710384615385, 0.9237494615384616, 0.7505689230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 326}], {
             RGBColor[
             0.9937856153846154, 0.9891163846153846, 0.5649807692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 327}], {
             RGBColor[
             0.9600779615384615, 0.9663346923076923, 0.7556629230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 337}], {
             RGBColor[
             0.9896281153846154, 0.9883192307692308, 0.7009067307692309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.9929305384615386, 0.9872874615384615, 0.47191092307692306`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 179}], {
             RGBColor[
             0.8821043461538461, 0.5470189999999999, 0.5695020384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 231}], {
             RGBColor[
             0.8821043461538461, 0.5470189999999999, 0.5695020384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 313}], {
             RGBColor[0.8364538076923077, 0.5109070769230769, 0.575153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 359}], {
             RGBColor[
             0.624197576923077, 0.3409626153846154, 0.5564533846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 164}], {
             RGBColor[
             0.9452677692307692, 0.8070953076923076, 0.3771802692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 169}], {
             RGBColor[
             0.8971774615384615, 0.6259886923076922, 0.23591469230769227`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 209}], {
             RGBColor[
             0.894185346153846, 0.7710329999999999, 0.6126993461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 227}], {
             RGBColor[
             0.9432439615384615, 0.8079181538461537, 0.5313657692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 240}], {
             RGBColor[
             0.9119876538461538, 0.7852280769230768, 0.6143973461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 245}], {
             RGBColor[
             0.9220335769230769, 0.792949846153846, 0.6053503846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 280}], {
             RGBColor[
             0.890127923076923, 0.5939783846153845, 0.2300323846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 304}], {
             RGBColor[
             0.8585807307692308, 0.7426428461538461, 0.6093033461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 315}], {
             RGBColor[
             0.9220335769230769, 0.792949846153846, 0.6053503846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 319}], {
             RGBColor[
             0.9456953076923076, 0.8080097692307692, 0.4237151923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 329}], {
             RGBColor[
             0.9461228461538461, 0.8089242307692307, 0.4702501153846156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 371}], {
             RGBColor[
             0.9432439615384615, 0.8079181538461537, 0.5313657692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 169}], {
             RGBColor[
             0.9452677692307692, 0.8070953076923076, 0.37718026923076925`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 209}], {
             RGBColor[
             0.9422756538461539, 0.9521396153846153, 0.7539649230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 227}], {
             RGBColor[
             0.9913342692307692, 0.9890247692307692, 0.6726313461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 245}], {
             RGBColor[
             0.9701238846153846, 0.9740564615384615, 0.7466159615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 280}], {
             RGBColor[0.9382182307692308, 0.775085, 0.3712979615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 304}], {
             RGBColor[
             0.9066710384615385, 0.9237494615384616, 0.7505689230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 315}], {
             RGBColor[
             0.9701238846153846, 0.9740564615384615, 0.7466159615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 228}], {
             RGBColor[
             0.8460639999999999, 0.8805342307692307, 0.9850623076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 262}], {
             RGBColor[
             0.9443042307692306, 0.9577532307692307, 0.971204423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 298}], {
             RGBColor[
             0.9049381153846152, 0.7532177692307691, 0.6085150384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 307}], {
             RGBColor[
             0.8187370769230768, 0.8591862307692306, 0.9823386153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 314}], {
             RGBColor[
             0.9443042307692306, 0.9577532307692307, 0.971204423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 332}], {
             RGBColor[0.926797846153846, 0.9444674615384614, 0.99288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 385}], {
             RGBColor[
             0.9580541538461538, 0.9671575384615384, 0.909848423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 185}], {
             RGBColor[
             0.9780118846153847, 0.9805349230769231, 0.7805222692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 213}], {
             RGBColor[
             0.9543501538461538, 0.9654750000000001, 0.9621574615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 224}], {
             RGBColor[
             0.9692710769230769, 0.9766030000000001, 0.9369002307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 247}], {
             RGBColor[
             0.9265019230769231, 0.9435581538461539, 0.969506423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 289}], {
             RGBColor[
             0.9692710769230769, 0.9766030000000001, 0.9369002307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 302}], {
             RGBColor[0.8908973076923077, 0.915168, 0.9661104230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 340}], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 400}], {
             RGBColor[
             0.9775843461538463, 0.9796204615384616, 0.7339873461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 192}], {
             RGBColor[
             0.9295380384615384, 0.8247331538461539, 0.6114936923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[
             0.8561099230769231, 0.8882559999999999, 0.9760153461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.9543501538461538, 0.9654750000000001, 0.9621574615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 228}], {
             RGBColor[
             0.8561099230769231, 0.8882559999999999, 0.9760153461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 243}], {
             RGBColor[
             0.9701238846153846, 0.9740564615384615, 0.7466159615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 348}], {
             RGBColor[
             0.9698062307692308, 0.9755848461538461, 0.8725260769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 351}], {
             RGBColor[0.8834368461538462, 0.909604, 0.9787390384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 170}], {
             RGBColor[
             0.7366707307692307, 0.43266799999999994`, 0.5652839230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 180}], {
             RGBColor[
             0.8243726153846154, 0.8612338461538461, 0.8683079615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 220}], {
             RGBColor[
             0.7914101538461538, 0.8378382307692307, 0.9796149230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 251}], {
             RGBColor[
             0.8209603076923075, 0.8598227692307692, 0.9248587307692309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 282}], {
             RGBColor[
             0.7558055384615384, 0.8094480769230769, 0.976218923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 350}], {
             RGBColor[
             0.5435493076923077, 0.6395036153846154, 0.9575193076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 357}], {
             RGBColor[0.7380032307692308, 0.795253, 0.9745209230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 394}], {
             RGBColor[
             0.8243726153846154, 0.8612338461538461, 0.8683079615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 209}], {
             RGBColor[
             0.894185346153846, 0.7710329999999999, 0.6126993461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 227}], {
             RGBColor[
             0.9432439615384615, 0.8079181538461537, 0.5313657692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 240}], {
             RGBColor[
             0.9119876538461538, 0.7852280769230768, 0.6143973461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 245}], {
             RGBColor[
             0.9220335769230769, 0.792949846153846, 0.6053503846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 280}], {
             RGBColor[
             0.890127923076923, 0.5939783846153845, 0.2300323846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 292}], {
             RGBColor[
             0.9461228461538461, 0.8089242307692307, 0.4702501153846156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 304}], {
             RGBColor[
             0.8585807307692308, 0.7426428461538461, 0.6093033461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 315}], {
             RGBColor[
             0.9220335769230769, 0.792949846153846, 0.6053503846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 329}], {
             RGBColor[
             0.9461228461538461, 0.8089242307692307, 0.4702501153846156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 353}], {
             RGBColor[
             0.9294940384615384, 0.7985138461538461, 0.5927217692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 378}], {
             RGBColor[
             0.9415378076923075, 0.8072126153846153, 0.5596411538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 180}], {
             RGBColor[
             0.9050208846153847, 0.5626928461538462, 0.46724203846153844`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 239}], {
             RGBColor[0.8895648076923077, 0.552583, 0.556873423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 251}], {
             RGBColor[
             0.9016085769230768, 0.5612817692307692, 0.5237928076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 271}], {
             RGBColor[
             0.9033147307692307, 0.5619873076923076, 0.49551742307692304`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 282}], {
             RGBColor[0.8364538076923077, 0.5109070769230769, 0.575153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 326}], {
             RGBColor[
             0.9057660769230769, 0.5620789230769231, 0.38786684615384615`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 182}], {
             RGBColor[
             0.7665353461538462, 0.8121346153846154, 0.6911753076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 244}], {
             RGBColor[0.904911, 0.5602499999999999, 0.2947969999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 253}], {
             RGBColor[0.9846172692307692, 0.98427, 0.6748238076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 270}], {
             RGBColor[
             0.9756383846153847, 0.9294846923076923, 0.3598601538461537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 308}], {
             RGBColor[
             0.9682634615384615, 0.9010767692307691, 0.34959726923076906`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 397}], {
             RGBColor[0.9596504230769229, 0.9654202307692307, 0.709128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 211}], {
             RGBColor[
             0.981259923076923, 0.9484474615384615, 0.381698769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 328}], {
             RGBColor[
             0.9570203846153845, 0.8631512307692305, 0.30592003846153826`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 347}], {
             RGBColor[
             0.9335971538461538, 0.7682553076923075, 0.28696811538461525`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 364}], {
             RGBColor[
             0.9584532692307692, 0.9352164615384615, 0.6564038076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 387}], {
             RGBColor[
             0.9796636538461538, 0.9501847692307692, 0.5824191923076921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 175}], {
             RGBColor[
             0.9723359615384615, 0.9305164615384616, 0.5888559615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 197}], {
             RGBColor[
             0.9513988461538461, 0.8441884615384614, 0.28408142307692297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 204}], {
             RGBColor[0.9740421153846153, 0.931222, 0.5605805769230767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 214}], {
             RGBColor[
             0.9434394615384615, 0.8126321538461538, 0.27767711538461537`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 261}], {
             RGBColor[
             0.9757482692307692, 0.9319275384615384, 0.5323051923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 295}], {
             RGBColor[
             0.9513988461538461, 0.8441884615384614, 0.28408142307692297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 310}], {
             RGBColor[
             0.9528317307692307, 0.9162536923076923, 0.6345651923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 345}], {
             RGBColor[
             0.9138765384615384, 0.6852719230769231, 0.2533648846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 193}], {
             RGBColor[
             0.8871358076923077, 0.7390226923076924, 0.6068170384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 232}], {
             RGBColor[
             0.9339623846153846, 0.9491221538461538, 0.9568778076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 235}], {
             RGBColor[
             0.940251846153846, 0.9529624615384615, 0.9081504230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 260}], {
             RGBColor[
             0.9339623846153846, 0.9491221538461538, 0.9568778076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 267}], {
             RGBColor[
             0.8871358076923077, 0.7390226923076924, 0.6068170384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 272}], {
             RGBColor[
             0.940251846153846, 0.9529624615384615, 0.9081504230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 275}], {
             RGBColor[
             0.9096491923076923, 0.8343726153846154, 0.6252469615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 281}], {
             RGBColor[
             0.9096491923076923, 0.8343726153846154, 0.6252469615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 291}], {
             RGBColor[
             0.8800862692307692, 0.7070123846153846, 0.6009347307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 338}], {
             RGBColor[
             0.9096491923076923, 0.8343726153846154, 0.6252469615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 384}], {
             RGBColor[
             0.8555886153846154, 0.8876871538461538, 0.9860880000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 398}], {
             RGBColor[
             0.894185346153846, 0.7710329999999999, 0.6126993461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 204}], {
             RGBColor[
             0.9876043076923076, 0.989142076923077, 0.8550922307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 214}], {
             RGBColor[
             0.9570016538461538, 0.8705522307692307, 0.5721887692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 256}], {
             RGBColor[
             0.9207433846153845, 0.9380618461538461, 0.9347278076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 261}], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.8268168461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 264}], {
             RGBColor[
             0.9385456923076922, 0.9522569230769231, 0.9364258076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 295}], {
             RGBColor[
             0.9649610384615384, 0.9021085384615383, 0.5785930769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 310}], {
             RGBColor[
             0.966393923076923, 0.9741737692307693, 0.9290768461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 345}], {
             RGBColor[
             0.9274387307692307, 0.7431920000000001, 0.5478765384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 186}], {
             RGBColor[
             0.9764934615384615, 0.9313136153846153, 0.45292999999999994`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 226}], {
             RGBColor[
             0.9456953076923076, 0.8080097692307692, 0.4237151923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 294}], {
             RGBColor[
             0.9780118846153847, 0.9805349230769231, 0.7805222692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 341}], {
             RGBColor[
             0.993358076923077, 0.988201923076923, 0.518445846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 368}], {
             RGBColor[
             0.9877365384615384, 0.9692391538461538, 0.4966072307692305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 379}], {
             RGBColor[
             0.9877365384615384, 0.9692391538461538, 0.4966072307692305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 393}], {
             RGBColor[
             0.993358076923077, 0.988201923076923, 0.518445846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 399}], {
             RGBColor[
             0.970551423076923, 0.974970923076923, 0.7931508846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 200}], {
             RGBColor[
             0.8555886153846154, 0.8876871538461538, 0.9860880000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 225}], {
             RGBColor[
             0.9046472307692308, 0.9245723076923077, 0.904754423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 296}], {
             RGBColor[
             0.709359076923077, 0.7722076923076924, 0.9721228461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 311}], {
             RGBColor[
             0.8660851923076923, 0.7744261538461539, 0.6154466538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 324}], {
             RGBColor[
             0.9070985769230769, 0.9246639230769231, 0.7971038461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 339}], {
             RGBColor[
             0.8555886153846154, 0.8876871538461538, 0.9860880000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 360}], {
             RGBColor[
             0.8820039615384615, 0.837538769230769, 0.6282552692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 374}], {
             RGBColor[
             0.8893788846153846, 0.8659466923076923, 0.6385181538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 375}], {
             RGBColor[
             0.8893788846153846, 0.8659466923076923, 0.6385181538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 383}], {
             RGBColor[0.8834368461538462, 0.909604, 0.9787390384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 390}], {
             RGBColor[0.9062435, 0.922835, 0.7040339999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{178, 209}], {
             RGBColor[
             0.9385456923076922, 0.9522569230769231, 0.9364258076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 229}], {
             RGBColor[
             0.9813148461538461, 0.9853017692307693, 0.9038196153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 240}], {
             RGBColor[
             0.9563479999999999, 0.9664519999999999, 0.9381238076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 245}], {
             RGBColor[
             0.966393923076923, 0.9741737692307693, 0.9290768461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 248}], {
             RGBColor[
             0.9570016538461538, 0.8705522307692307, 0.5721887692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 309}], {
             RGBColor[
             0.7923161538461538, 0.8367774615384616, 0.9224606538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 315}], {
             RGBColor[
             0.966393923076923, 0.9741737692307693, 0.9290768461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 319}], {
             RGBColor[
             0.9900556538461538, 0.9892336923076923, 0.7474416538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 329}], {
             RGBColor[
             0.9904831923076922, 0.9901481538461538, 0.7939765769230772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 334}], {
             RGBColor[
             0.9738543846153846, 0.9797377692307693, 0.9164482307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 371}], {
             RGBColor[
             0.9876043076923076, 0.989142076923077, 0.8550922307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 388}], {
             RGBColor[
             0.966393923076923, 0.9741737692307693, 0.9290768461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 196}], {
             RGBColor[
             0.9640748076923076, 0.9541792307692306, 0.6782424230769228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 231}], {
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 303}], {
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 313}], {
             RGBColor[
             0.9012391538461538, 0.9237990769230768, 0.9804370384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 344}], {
             RGBColor[
             0.9709789615384615, 0.9758853846153845, 0.8396858076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 359}], {
             RGBColor[
             0.6889829230769231, 0.7538546153846154, 0.9617374230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 239}], {
             RGBColor[
             0.9772666923076923, 0.9811488461538462, 0.8598974615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 271}], {
             RGBColor[
             0.9910166153846154, 0.9905531538461538, 0.7985414615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 282}], {
             RGBColor[
             0.9241556923076923, 0.9394729230769231, 0.8781770384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 326}], {
             RGBColor[
             0.9934679615384615, 0.9906447692307693, 0.6908908846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 350}], {
             RGBColor[
             0.7118994615384615, 0.7695284615384617, 0.8594774230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 394}], {
             RGBColor[
             0.9927227692307692, 0.9912586923076924, 0.7702660769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 250}], {
             RGBColor[
             0.9580541538461538, 0.9671575384615384, 0.909848423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 265}], {
             RGBColor[
             0.9368437692307692, 0.9521892307692307, 0.9838330384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 322}], {
             RGBColor[
             0.9596504230769229, 0.9654202307692307, 0.7091279999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 362}], {
             RGBColor[
             0.9605054999999999, 0.9672491538461538, 0.8021978461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 244}], {
             RGBColor[
             0.6789433461538461, 0.38601161538461537`, 0.5605963076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 253}], {
             RGBColor[
             0.7586496153846154, 0.8100316153846154, 0.9406231153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 271}], {
             RGBColor[
             0.9909067307692307, 0.9881103076923077, 0.6260964230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 273}], {
             RGBColor[
             0.9926128846153845, 0.9888158461538461, 0.5978210384615383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 335}], {
             RGBColor[
             0.9937856153846154, 0.9891163846153845, 0.5649807692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 305}], {
             RGBColor[
             0.8789165769230769, 0.9014869999999999, 0.7013103076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 325}], {
             RGBColor[
             0.9909067307692307, 0.9881103076923077, 0.6260964230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 213}], {
             RGBColor[
             0.970551423076923, 0.974970923076923, 0.7931508846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 224}], {
             RGBColor[
             0.9854723461538462, 0.986098923076923, 0.7678936538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 247}], {
             RGBColor[
             0.9427031923076923, 0.9530540769230769, 0.8004998461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 289}], {
             RGBColor[
             0.9854723461538462, 0.986098923076923, 0.7678936538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 302}], {
             RGBColor[
             0.9070985769230769, 0.9246639230769231, 0.7971038461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 340}], {
             RGBColor[
             0.9780118846153847, 0.9805349230769231, 0.7805222692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 400}], {
             RGBColor[
             0.9937856153846154, 0.9891163846153846, 0.5649807692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 189}], {
             RGBColor[
             0.9723359615384615, 0.9305164615384616, 0.5888559615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 200}], {
             RGBColor[0.9249835, 0.8943368461538461, 0.6419141538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 226}], {
             RGBColor[
             0.9279756153846153, 0.7492925384615383, 0.26512949999999996`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 241}], {
             RGBColor[
             0.9764934615384615, 0.9313136153846153, 0.45292999999999994`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 255}], {
             RGBColor[0.9249835, 0.8943368461538461, 0.6419141538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 288}], {
             RGBColor[0.9740421153846153, 0.931222, 0.5605805769230767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 341}], {
             RGBColor[
             0.9756383846153847, 0.9294846923076923, 0.3598601538461537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 374}], {
             RGBColor[
             0.9587737692307692, 0.8725963846153846, 0.2943443076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 393}], {
             RGBColor[
             0.9756383846153847, 0.9294846923076923, 0.3598601538461537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 399}], {
             RGBColor[
             0.9528317307692307, 0.9162536923076923, 0.6345651923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 193}], {
             RGBColor[
             0.9299049615384615, 0.7720675384615385, 0.5742108461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 218}], {
             RGBColor[0.8970252692307692, 0.558147, 0.5442448076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 232}], {
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 235}], {
             RGBColor[
             0.9830209999999999, 0.9860073076923077, 0.8755442307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 275}], {
             RGBColor[
             0.952418346153846, 0.8674174615384616, 0.5926407692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 279}], {
             RGBColor[
             0.9854723461538462, 0.986098923076923, 0.7678936538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 281}], {
             RGBColor[
             0.952418346153846, 0.8674174615384616, 0.5926407692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 298}], {
             RGBColor[
             0.9299049615384615, 0.7720675384615385, 0.5742108461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 306}], {
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 195}], {
             RGBColor[
             0.9698062307692308, 0.9755848461538461, 0.8725260769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 203}], {
             RGBColor[
             0.9772666923076923, 0.9811488461538462, 0.8598974615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 206}], {
             RGBColor[
             0.9927227692307692, 0.9912586923076924, 0.7702660769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 208}], {
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 258}], {
             RGBColor[
             0.9927227692307692, 0.9912586923076924, 0.7702660769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 278}], {
             RGBColor[
             0.9241556923076923, 0.9394729230769231, 0.8781770384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 284}], {
             RGBColor[0.9604139615384615, 0.8719633076923077, 0.515638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 327}], {
             RGBColor[
             0.9597603076923076, 0.9678630769230769, 0.8815730384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 361}], {
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 369}], {
             RGBColor[
             0.9869913461538461, 0.9698530769230769, 0.5759824230769228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 392}], {
             RGBColor[
             0.9927227692307692, 0.9912586923076924, 0.7702660769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 200}], {
             RGBColor[
             0.9385456923076922, 0.9522569230769231, 0.9364258076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 219}], {
             RGBColor[
             0.9900556538461538, 0.9892336923076923, 0.7474416538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 241}], {
             RGBColor[
             0.9900556538461538, 0.9892336923076923, 0.7474416538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 255}], {
             RGBColor[
             0.9385456923076922, 0.9522569230769231, 0.9364258076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 339}], {
             RGBColor[
             0.9385456923076922, 0.9522569230769231, 0.9364258076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 360}], {
             RGBColor[
             0.9649610384615384, 0.9021085384615383, 0.5785930769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 374}], {
             RGBColor[
             0.9723359615384615, 0.9305164615384616, 0.5888559615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 266}], {
             RGBColor[
             0.9825425384615385, 0.9511908461538461, 0.5213035384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 273}], {
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 365}], {
             RGBColor[
             0.9937856153846154, 0.9891163846153845, 0.5649807692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 198}], {
             RGBColor[
             0.8299608461538461, 0.23129776923076925`, 0.17632384615384616`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 216}], {
             RGBColor[
             0.8806714615384614, 0.47495376923076904`, 0.21901826923076917`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 219}], {
             RGBColor[
             0.9057660769230769, 0.5620789230769231, 0.38786684615384615`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 220}], {
             RGBColor[0.872058423076923, 0.5392972307692308, 0.578549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 311}], {
             RGBColor[
             0.8647526923076923, 0.4118411538461539, 0.20620965384615386`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 323}], {
             RGBColor[
             0.9057660769230769, 0.5620789230769231, 0.38786684615384615`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 339}], {
             RGBColor[0.8542561153846153, 0.5251021538461538, 0.576851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 357}], {
             RGBColor[0.8186515000000001, 0.496712, 0.573455]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{192, 201}], {
             RGBColor[
             0.8387582692307692, 0.7530781538461538, 0.6127229615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 203}], {
             RGBColor[
             0.9369985000000001, 0.8302971538461539, 0.5988650769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 228}], {
             RGBColor[
             0.8387582692307692, 0.7530781538461538, 0.6127229615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 243}], {
             RGBColor[
             0.9527722307692308, 0.8388786153846155, 0.38332357692307695`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 332}], {
             RGBColor[
             0.9194921153846153, 0.8170113846153846, 0.6205406538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 348}], {
             RGBColor[
             0.9524545769230769, 0.8404070000000001, 0.5092336923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 361}], {
             RGBColor[
             0.9536273076923076, 0.8407075384615386, 0.47639342307692334`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 385}], {
             RGBColor[
             0.950748423076923, 0.8397014615384616, 0.5375090769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 232}], {
             RGBColor[
             0.9299049615384615, 0.7720675384615385, 0.5742108461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 235}], {
             RGBColor[
             0.936194423076923, 0.7759078461538462, 0.5254834615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 260}], {
             RGBColor[
             0.9299049615384615, 0.7720675384615385, 0.5742108461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 275}], {
             RGBColor[0.9055917692307691, 0.657318, 0.24258]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{193, 281}], {
             RGBColor[0.9055917692307691, 0.657318, 0.24258]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{193, 338}], {
             RGBColor[0.9055917692307691, 0.657318, 0.24258]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{193, 384}], {
             RGBColor[
             0.8515311923076923, 0.7106325384615384, 0.6034210384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 376}], {
             RGBColor[
             0.9379005769230768, 0.7766133846153846, 0.49720807692307695`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 377}], {
             RGBColor[
             0.9390733076923077, 0.7769139230769231, 0.4643678076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 396}], {
             RGBColor[
             0.9321691538461538, 0.755207769230769, 0.3029244230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 206}], {
             RGBColor[
             0.9698062307692308, 0.9755848461538461, 0.8725260769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 208}], {
             RGBColor[
             0.9709789615384615, 0.9758853846153845, 0.8396858076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 258}], {
             RGBColor[
             0.9698062307692308, 0.9755848461538461, 0.8725260769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 278}], {
             RGBColor[
             0.9012391538461538, 0.9237990769230768, 0.9804370384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 284}], {
             RGBColor[
             0.9374974230769231, 0.8562894615384615, 0.6178980000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 327}], {
             RGBColor[
             0.9368437692307692, 0.9521892307692307, 0.9838330384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 337}], {
             RGBColor[
             0.966393923076923, 0.9741737692307693, 0.9290768461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 369}], {
             RGBColor[
             0.9640748076923076, 0.9541792307692306, 0.6782424230769228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 392}], {
             RGBColor[
             0.9698062307692308, 0.9755848461538461, 0.8725260769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 231}], {
             RGBColor[
             0.9640748076923076, 0.9541792307692306, 0.6782424230769228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 234}], {
             RGBColor[
             0.7318305769230768, 0.7695607692307691, 0.6670471538461537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 290}], {
             RGBColor[
             0.7899970384615385, 0.816782923076923, 0.6716262307692306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 303}], {
             RGBColor[
             0.9640748076923076, 0.9541792307692306, 0.6782424230769228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 313}], {
             RGBColor[
             0.9184242692307691, 0.9180673076923076, 0.6838933846153844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 344}], {
             RGBColor[
             0.9881640769230768, 0.9701536153846153, 0.5431421538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 204}], {
             RGBColor[
             0.9666671923076922, 0.9028140769230768, 0.5503176923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 215}], {
             RGBColor[
             0.8820039615384615, 0.837538769230769, 0.6282552692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 295}], {
             RGBColor[
             0.944023923076923, 0.8157805384615381, 0.27381853846153836`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 310}], {
             RGBColor[
             0.9454568076923076, 0.8878457692307691, 0.6243023076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 345}], {
             RGBColor[
             0.9065016153846153, 0.6568639999999999, 0.24310199999999996`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 216}], {
             RGBColor[
             0.8933133076923077, 0.5721245384615383, 0.23112411538461536`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 219}], {
             RGBColor[
             0.9184079230769231, 0.6592496923076923, 0.3999726923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 224}], {
             RGBColor[
             0.9096671153846154, 0.6553177692307692, 0.5563506538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 247}], {
             RGBColor[
             0.8668979615384615, 0.6222729230769231, 0.5889568461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 302}], {
             RGBColor[
             0.8312933461538462, 0.5938827692307693, 0.5855608461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 311}], {
             RGBColor[
             0.8773945384615385, 0.5090119230769231, 0.21831550000000002`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 323}], {
             RGBColor[
             0.9184079230769231, 0.6592496923076923, 0.3999726923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 340}], {
             RGBColor[
             0.902206653846154, 0.6497537692307693, 0.5689792692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 212}], {
             RGBColor[
             0.9789957307692307, 0.9653072307692306, 0.6529851923076921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 238}], {
             RGBColor[
             0.9847271538461537, 0.9867128461538461, 0.8472688461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 252}], {
             RGBColor[
             0.922855423076923, 0.7400572307692308, 0.5683285384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 277}], {
             RGBColor[
             0.9813148461538461, 0.9853017692307693, 0.9038196153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 287}], {
             RGBColor[
             0.9161600769230769, 0.9349270769230769, 0.9551798076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 293}], {
             RGBColor[
             0.9299049615384615, 0.7720675384615385, 0.5742108461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 299}], {
             RGBColor[0.843703923076923, 0.878036, 0.9480344230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 336}], {
             RGBColor[
             0.9858998846153846, 0.9870133846153846, 0.8144285769230771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 367}], {
             RGBColor[0.9846172692307692, 0.98427, 0.6748238076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 225}], {
             RGBColor[
             0.940251846153846, 0.9529624615384615, 0.9081504230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 241}], {
             RGBColor[
             0.9427031923076923, 0.9530540769230769, 0.8004998461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 255}], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 288}], {
             RGBColor[
             0.940251846153846, 0.9529624615384615, 0.9081504230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 296}], {
             RGBColor[
             0.7449636923076923, 0.8005978461538461, 0.9755188461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 339}], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 355}], {
             RGBColor[0.9249835, 0.8943368461538461, 0.6419141538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 360}], {
             RGBColor[
             0.9176085769230768, 0.8659289230769229, 0.6316512692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 374}], {
             RGBColor[0.9249835, 0.8943368461538461, 0.6419141538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 375}], {
             RGBColor[0.9249835, 0.8943368461538461, 0.6419141538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 383}], {
             RGBColor[
             0.9190414615384614, 0.9379941538461538, 0.9821350384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 399}], {
             RGBColor[
             0.9190414615384614, 0.9379941538461538, 0.9821350384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 210}], {
             RGBColor[
             0.8773203076923077, 0.9032243076923077, 0.9020307307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 228}], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 236}], {
             RGBColor[
             0.8732950384615384, 0.8825242307692306, 0.6794716923076921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 243}], {
             RGBColor[
             0.8793441153846154, 0.9024014615384615, 0.7478452307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 263}], {
             RGBColor[
             0.8793441153846154, 0.9024014615384615, 0.7478452307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 348}], {
             RGBColor[
             0.8790264615384615, 0.9039298461538461, 0.8737553461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 351}], {
             RGBColor[
             0.792657076923077, 0.8379489999999999, 0.9799683076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 214}], {
             RGBColor[0.9055917692307691, 0.657318, 0.24258]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{202, 217}], {
             RGBColor[
             0.9390733076923077, 0.7769139230769231, 0.4643678076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 257}], {
             RGBColor[
             0.936194423076923, 0.7759078461538462, 0.5254834615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 264}], {
             RGBColor[
             0.8871358076923077, 0.7390226923076924, 0.6068170384615386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 268}], {
             RGBColor[
             0.9209260769230769, 0.7172822307692308, 0.2592471923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 279}], {
             RGBColor[
             0.9386457692307693, 0.7759994615384616, 0.4178328846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 300}], {
             RGBColor[
             0.936194423076923, 0.7759078461538462, 0.5254834615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 306}], {
             RGBColor[
             0.9299049615384615, 0.7720675384615385, 0.5742108461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 363}], {
             RGBColor[
             0.8242042692307692, 0.6892845384615385, 0.6006973461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 381}], {
             RGBColor[
             0.9321691538461538, 0.755207769230769, 0.3029244230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 243}], {
             RGBColor[
             0.9775843461538463, 0.9796204615384616, 0.7339873461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 258}], {
             RGBColor[
             0.9772666923076923, 0.9811488461538462, 0.8598974615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 284}], {
             RGBColor[
             0.9449578846153845, 0.8618534615384615, 0.6052693846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 348}], {
             RGBColor[
             0.9772666923076923, 0.9811488461538462, 0.8598974615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 361}], {
             RGBColor[
             0.9784394230769231, 0.9814493846153847, 0.8270571923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 369}], {
             RGBColor[
             0.9715352692307693, 0.9597432307692306, 0.6656138076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 392}], {
             RGBColor[
             0.9772666923076923, 0.9811488461538462, 0.8598974615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 261}], {
             RGBColor[
             0.9910166153846154, 0.9905531538461538, 0.7985414615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 295}], {
             RGBColor[
             0.9666671923076922, 0.9028140769230768, 0.5503176923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 310}], {
             RGBColor[
             0.9681000769230769, 0.9748793076923077, 0.9008014615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 345}], {
             RGBColor[
             0.9291448846153846, 0.7438975384615385, 0.5196011538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 389}], {
             RGBColor[
             0.8226664615384615, 0.8605283076923076, 0.896583346153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 400}], {
             RGBColor[
             0.9913342692307692, 0.9890247692307692, 0.6726313461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 207}], {
             RGBColor[
             0.9677526538461538, 0.9273816923076923, 0.6093079615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 221}], {
             RGBColor[
             0.8880463846153845, 0.5033616923076922, 0.22928115384615383`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 230}], {
             RGBColor[
             0.9677526538461538, 0.9273816923076923, 0.6093079615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 250}], {
             RGBColor[0.9740421153846153, 0.931222, 0.5605805769230767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 276}], {
             RGBColor[
             0.9643953076923076, 0.8915591538461538, 0.3161829230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 358}], {
             RGBColor[
             0.9279756153846153, 0.7492925384615383, 0.26512949999999996`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 391}], {
             RGBColor[
             0.9700168461538461, 0.9105219230769229, 0.33802153846153826`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 208}], {
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 258}], {
             RGBColor[
             0.9927227692307692, 0.9912586923076924, 0.7702660769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 278}], {
             RGBColor[
             0.9241556923076923, 0.9394729230769231, 0.8781770384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 284}], {
             RGBColor[0.9604139615384615, 0.8719633076923077, 0.515638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 369}], {
             RGBColor[
             0.9869913461538461, 0.9698530769230769, 0.5759824230769228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 392}], {
             RGBColor[
             0.9927227692307692, 0.9912586923076924, 0.7702660769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 221}], {
             RGBColor[0.8970252692307692, 0.558147, 0.5442448076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 230}], {
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 233}], {
             RGBColor[
             0.9517646923076921, 0.9633172307692307, 0.9585758076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 250}], {
             RGBColor[
             0.9830209999999999, 0.9860073076923077, 0.8755442307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 358}], {
             RGBColor[
             0.9369544999999999, 0.804077846153846, 0.5800931538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 366}], {
             RGBColor[
             0.9444589615384615, 0.8358611538461539, 0.5862364615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 391}], {
             RGBColor[
             0.9789957307692307, 0.9653072307692306, 0.6529851923076921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 278}], {
             RGBColor[
             0.9253284230769231, 0.9397734615384615, 0.8453367692307694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 284}], {
             RGBColor[
             0.9615866923076923, 0.8722638461538461, 0.482797730769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 369}], {
             RGBColor[
             0.9881640769230768, 0.9701536153846153, 0.5431421538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 392}], {
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 227}], {
             RGBColor[
             0.940251846153846, 0.9529624615384615, 0.9081504230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 229}], {
             RGBColor[
             0.9339623846153846, 0.9491221538461538, 0.9568778076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 240}], {
             RGBColor[0.9089955384615384, 0.9302723846153845, 0.991182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 245}], {
             RGBColor[
             0.9190414615384614, 0.9379941538461538, 0.9821350384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 280}], {
             RGBColor[
             0.8871358076923077, 0.7390226923076924, 0.6068170384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 304}], {
             RGBColor[
             0.8555886153846154, 0.8876871538461538, 0.9860880000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 315}], {
             RGBColor[
             0.9190414615384614, 0.9379941538461538, 0.9821350384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 319}], {
             RGBColor[
             0.9427031923076923, 0.9530540769230769, 0.8004998461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 329}], {
             RGBColor[
             0.9431307307692307, 0.9539685384615384, 0.8470347692307695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 334}], {
             RGBColor[
             0.9265019230769231, 0.9435581538461539, 0.969506423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 371}], {
             RGBColor[
             0.940251846153846, 0.9529624615384615, 0.9081504230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 236}], {
             RGBColor[
             0.9852851923076922, 0.9691475384615383, 0.6042578076923074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 263}], {
             RGBColor[
             0.9913342692307692, 0.9890247692307692, 0.6726313461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 301}], {
             RGBColor[
             0.981259923076923, 0.9484474615384615, 0.381698769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 328}], {
             RGBColor[
             0.9682634615384615, 0.9010767692307691, 0.34959726923076906`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 347}], {
             RGBColor[
             0.9448402307692307, 0.806180846153846, 0.33064534615384605`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 372}], {
             RGBColor[
             0.9682634615384615, 0.9010767692307691, 0.34959726923076906`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 387}], {
             RGBColor[
             0.9909067307692307, 0.9881103076923077, 0.6260964230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 238}], {
             RGBColor[
             0.9869913461538461, 0.9698530769230769, 0.5759824230769228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 259}], {
             RGBColor[
             0.9700168461538461, 0.9105219230769229, 0.33802153846153826`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 293}], {
             RGBColor[
             0.9321691538461538, 0.755207769230769, 0.3029244230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 299}], {
             RGBColor[
             0.8459681153846152, 0.8611762307692306, 0.6767479999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 336}], {
             RGBColor[
             0.9881640769230768, 0.9701536153846153, 0.5431421538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 367}], {
             RGBColor[
             0.9868814615384616, 0.9674102307692306, 0.40353738461538435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 224}], {
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 230}], {
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 247}], {
             RGBColor[
             0.9190414615384614, 0.9379941538461538, 0.9821350384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 250}], {
             RGBColor[
             0.9681000769230769, 0.9748793076923077, 0.9008014615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 289}], {
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 302}], {
             RGBColor[0.8834368461538462, 0.909604, 0.9787390384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 340}], {
             RGBColor[
             0.9543501538461538, 0.9654750000000001, 0.9621574615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 391}], {
             RGBColor[
             0.9640748076923076, 0.9541792307692306, 0.6782424230769228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 215}], {
             RGBColor[
             0.8740445769230769, 0.8059824615384614, 0.6218509615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 217}], {
             RGBColor[
             0.9615866923076923, 0.8722638461538461, 0.482797730769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 261}], {
             RGBColor[0.9604139615384615, 0.8719633076923077, 0.515638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 264}], {
             RGBColor[
             0.9096491923076923, 0.8343726153846154, 0.6252469615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 295}], {
             RGBColor[
             0.9360645384615384, 0.7842242307692305, 0.2674142307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 300}], {
             RGBColor[
             0.9587078076923077, 0.8712577692307693, 0.5439133846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 310}], {
             RGBColor[
             0.9374974230769231, 0.8562894615384615, 0.6178980000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 363}], {
             RGBColor[
             0.8467176538461538, 0.7846344615384615, 0.6191272692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 217}], {
             RGBColor[
             0.9075261153846155, 0.9255783846153847, 0.8436387692307694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 269}], {
             RGBColor[
             0.709359076923077, 0.7722076923076924, 0.9721228461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 295}], {
             RGBColor[
             0.8820039615384615, 0.837538769230769, 0.6282552692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 300}], {
             RGBColor[
             0.9046472307692308, 0.9245723076923077, 0.904754423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 352}], {
             RGBColor[0.8983577692307692, 0.920732, 0.9534818076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 363}], {
             RGBColor[
             0.792657076923077, 0.8379489999999999, 0.9799683076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 219}], {
             RGBColor[
             0.9691185384615384, 0.9029056923076921, 0.4426671153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 220}], {
             RGBColor[
             0.9354108846153845, 0.8801239999999997, 0.6333492692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 311}], {
             RGBColor[
             0.9281051538461538, 0.7526679230769229, 0.26100992307692306`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 323}], {
             RGBColor[
             0.9691185384615384, 0.9029056923076921, 0.4426671153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 339}], {
             RGBColor[
             0.9176085769230768, 0.8659289230769229, 0.6316512692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 357}], {
             RGBColor[
             0.8820039615384615, 0.837538769230769, 0.6282552692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 268}], {
             RGBColor[
             0.9769209999999999, 0.9322280769230769, 0.49946492307692325`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 269}], {
             RGBColor[
             0.7969011923076923, 0.838489076923077, 0.8330696153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 279}], {
             RGBColor[
             0.9946406923076923, 0.9909453076923077, 0.6580506153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 300}], {
             RGBColor[
             0.9921893461538461, 0.9908536923076923, 0.7657011923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 306}], {
             RGBColor[
             0.9858998846153846, 0.9870133846153846, 0.8144285769230771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 363}], {
             RGBColor[
             0.8801991923076924, 0.9042303846153845, 0.8409150769230771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 262}], {
             RGBColor[0.8895648076923077, 0.552583, 0.556873423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 269}], {
             RGBColor[
             0.7080265769230769, 0.4096226923076923, 0.5628858461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 279}], {
             RGBColor[
             0.9057660769230769, 0.5620789230769231, 0.38786684615384615`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 298}], {
             RGBColor[
             0.8501986923076923, 0.34804753846153846`, 0.19418403846153848`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.9033147307692307, 0.5619873076923076, 0.49551742307692304`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 306}], {
             RGBColor[0.8970252692307692, 0.558147, 0.5442448076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 314}], {
             RGBColor[0.8895648076923077, 0.552583, 0.556873423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 220}], {
             RGBColor[
             0.9605054999999999, 0.9672491538461538, 0.8021978461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 241}], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 311}], {
             RGBColor[0.9531997692307692, 0.839793076923077, 0.4298585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 323}], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 339}], {
             RGBColor[
             0.9427031923076923, 0.9530540769230769, 0.8004998461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 357}], {
             RGBColor[
             0.9070985769230769, 0.9246639230769231, 0.7971038461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 360}], {
             RGBColor[
             0.9691185384615384, 0.9029056923076921, 0.4426671153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 350}], {
             RGBColor[
             0.6789369999999999, 0.7461328461538461, 0.9707843846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 357}], {
             RGBColor[0.873390923076923, 0.9018822307692307, 0.987786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 394}], {
             RGBColor[
             0.9597603076923076, 0.9678630769230769, 0.8815730384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 230}], {
             RGBColor[0.8970252692307692, 0.558147, 0.5442448076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 250}], {
             RGBColor[
             0.9033147307692307, 0.5619873076923076, 0.49551742307692304`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 276}], {
             RGBColor[
             0.8936679230769231, 0.5223244615384615, 0.2511197692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 358}], {
             RGBColor[
             0.8572482307692307, 0.3800578461538461, 0.20006634615384614`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 251}], {
             RGBColor[
             0.8756141538461538, 0.9025187692307692, 0.9303061153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 297}], {
             RGBColor[
             0.8732950384615384, 0.8825242307692306, 0.6794716923076921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 312}], {
             RGBColor[
             0.792657076923077, 0.8379489999999999, 0.9799683076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 332}], {
             RGBColor[
             0.8460639999999999, 0.8805342307692307, 0.9850623076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 356}], {
             RGBColor[
             0.8789165769230769, 0.9014869999999999, 0.7013103076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 361}], {
             RGBColor[
             0.8801991923076924, 0.9042303846153845, 0.8409150769230771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 260}], {
             RGBColor[
             0.7586496153846154, 0.8100316153846154, 0.9406231153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 267}], {
             RGBColor[
             0.7118230384615385, 0.5999321538461538, 0.5905623461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 272}], {
             RGBColor[
             0.7649390769230768, 0.8138719230769231, 0.8918957307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 290}], {
             RGBColor[
             0.5696509230769231, 0.6615073076923077, 0.9592641538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 291}], {
             RGBColor[
             0.7047734999999999, 0.5679218461538462, 0.5846800384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 321}], {
             RGBColor[0.7678179615384615, 0.814878, 0.8307800769230771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 331}], {
             RGBColor[
             0.7511891538461539, 0.8044676153846154, 0.9532517307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 342}], {
             RGBColor[
             0.7673904230769231, 0.8139635384615385, 0.7842451538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 346}], {
             RGBColor[
             0.6802758461538462, 0.7485966153846153, 0.9698333076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 384}], {
             RGBColor[
             0.6802758461538462, 0.7485966153846153, 0.9698333076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 398}], {
             RGBColor[
             0.7188725769230768, 0.6319424615384615, 0.5964446538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 230}], {
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 247}], {
             RGBColor[
             0.9339623846153846, 0.9491221538461538, 0.9568778076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 289}], {
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 302}], {
             RGBColor[0.8983577692307692, 0.920732, 0.9534818076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 323}], {
             RGBColor[
             0.9854723461538462, 0.986098923076923, 0.7678936538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 340}], {
             RGBColor[
             0.9692710769230769, 0.9766030000000001, 0.9369002307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 288}], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 296}], {
             RGBColor[0.7940223076923076, 0.837483, 0.8941852692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 316}], {
             RGBColor[
             0.9666671923076922, 0.9028140769230768, 0.5503176923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 324}], {
             RGBColor[
             0.9917618076923076, 0.9899392307692307, 0.7191662692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 355}], {
             RGBColor[0.9740421153846153, 0.931222, 0.5605805769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 375}], {
             RGBColor[0.9740421153846153, 0.931222, 0.5605805769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 380}], {
             RGBColor[
             0.936194423076923, 0.7759078461538462, 0.5254834615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 383}], {
             RGBColor[
             0.9681000769230769, 0.9748793076923077, 0.9008014615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 390}], {
             RGBColor[
             0.9909067307692307, 0.9881103076923077, 0.6260964230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 255}], {
             RGBColor[
             0.894185346153846, 0.7710329999999999, 0.6126993461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 266}], {
             RGBColor[
             0.9335971538461538, 0.7682553076923075, 0.28696811538461525`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 294}], {
             RGBColor[
             0.9294940384615384, 0.7985138461538461, 0.5927217692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 341}], {
             RGBColor[
             0.9448402307692307, 0.806180846153846, 0.33064534615384605`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 368}], {
             RGBColor[
             0.9392186923076922, 0.7872180769230768, 0.30880673076923054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 393}], {
             RGBColor[
             0.9448402307692307, 0.806180846153846, 0.33064534615384605`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 399}], {
             RGBColor[
             0.9220335769230769, 0.792949846153846, 0.6053503846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 280}], {
             RGBColor[
             0.936194423076923, 0.7759078461538462, 0.5254834615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 304}], {
             RGBColor[
             0.9046472307692308, 0.9245723076923077, 0.904754423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 315}], {
             RGBColor[
             0.9681000769230769, 0.9748793076923077, 0.9008014615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 243}], {
             RGBColor[
             0.8793441153846154, 0.9024014615384615, 0.7478452307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 332}], {
             RGBColor[
             0.8460639999999999, 0.8805342307692307, 0.9850623076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 348}], {
             RGBColor[
             0.8790264615384615, 0.9039298461538461, 0.8737553461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 361}], {
             RGBColor[
             0.8801991923076924, 0.9042303846153845, 0.8409150769230771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 385}], {
             RGBColor[
             0.8773203076923077, 0.9032243076923077, 0.9020307307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 240}], {
             RGBColor[
             0.9517646923076921, 0.9633172307692307, 0.9585758076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 245}], {
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 248}], {
             RGBColor[
             0.952418346153846, 0.8674174615384616, 0.5926407692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 249}], {
             RGBColor[
             0.9339623846153846, 0.9491221538461538, 0.9568778076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 309}], {
             RGBColor[
             0.7877328461538462, 0.8336426923076923, 0.9429126538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 315}], {
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 319}], {
             RGBColor[
             0.9854723461538462, 0.986098923076923, 0.7678936538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[
             0.9858998846153846, 0.9870133846153846, 0.8144285769230771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 334}], {
             RGBColor[
             0.9692710769230769, 0.9766030000000001, 0.9369002307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 371}], {
             RGBColor[
             0.9830209999999999, 0.9860073076923077, 0.8755442307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 388}], {
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 247}], {
             RGBColor[
             0.9339623846153846, 0.9491221538461538, 0.9568778076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 250}], {
             RGBColor[
             0.9830209999999999, 0.9860073076923077, 0.8755442307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 289}], {
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 358}], {
             RGBColor[
             0.9369544999999999, 0.804077846153846, 0.5800931538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 391}], {
             RGBColor[
             0.9789957307692307, 0.9653072307692306, 0.6529851923076921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 234}], {
             RGBColor[
             0.7146454615384615, 0.7752925384615383, 0.9635908076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 290}], {
             RGBColor[
             0.772811923076923, 0.8225146923076923, 0.9681698846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 313}], {
             RGBColor[
             0.9012391538461538, 0.9237990769230768, 0.9804370384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 331}], {
             RGBColor[
             0.9543501538461538, 0.9654750000000001, 0.9621574615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 359}], {
             RGBColor[
             0.6889829230769231, 0.7538546153846154, 0.9617374230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 235}], {
             RGBColor[
             0.9830209999999999, 0.9860073076923077, 0.8755442307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 281}], {
             RGBColor[
             0.952418346153846, 0.8674174615384616, 0.5926407692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 384}], {
             RGBColor[0.8983577692307692, 0.920732, 0.9534818076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 386}], {
             RGBColor[
             0.9830209999999999, 0.9860073076923077, 0.8755442307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 242}], {
             RGBColor[
             0.9540288846153845, 0.9464574615384613, 0.6872893846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 317}], {
             RGBColor[
             0.9194921153846153, 0.8170113846153846, 0.6205406538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 358}], {
             RGBColor[
             0.9119876538461538, 0.7852280769230768, 0.6143973461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 366}], {
             RGBColor[
             0.9194921153846153, 0.8170113846153846, 0.6205406538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 382}], {
             RGBColor[
             0.948407346153846, 0.9274946923076921, 0.6654507692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 290}], {
             RGBColor[
             0.5405676923076923, 0.6378962307692307, 0.9569746153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 313}], {
             RGBColor[
             0.6689949230769231, 0.7391806153846153, 0.9692417692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 331}], {
             RGBColor[
             0.7221059230769231, 0.7808565384615385, 0.9509621923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 342}], {
             RGBColor[
             0.7383071923076923, 0.7903524615384615, 0.7819556153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 346}], {
             RGBColor[
             0.6511926153846154, 0.7249855384615385, 0.9675437692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 275}], {
             RGBColor[
             0.9587078076923077, 0.8712577692307693, 0.5439133846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 281}], {
             RGBColor[
             0.9587078076923077, 0.8712577692307693, 0.5439133846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 384}], {
             RGBColor[
             0.9046472307692308, 0.9245723076923077, 0.904754423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 263}], {
             RGBColor[0.987309, 0.9683246923076922, 0.45007230769230755`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 351}], {
             RGBColor[
             0.9006219615384615, 0.9038722307692306, 0.6821953846153844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 246}], {
             RGBColor[
             0.8871358076923077, 0.7390226923076924, 0.6068170384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 254}], {
             RGBColor[0.873390923076923, 0.9018822307692307, 0.987786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 286}], {
             RGBColor[
             0.9418481153846154, 0.9512251538461538, 0.7074299999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 320}], {
             RGBColor[
             0.8009347692307691, 0.8449911538461539, 0.9806406153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 343}], {
             RGBColor[
             0.8800862692307692, 0.7070123846153846, 0.6009347307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 349}], {
             RGBColor[
             0.9431307307692307, 0.9539685384615384, 0.8470347692307695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 252}], {
             RGBColor[
             0.9308510384615385, 0.744603076923077, 0.4913257692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 277}], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.8268168461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 287}], {
             RGBColor[
             0.9241556923076923, 0.9394729230769231, 0.8781770384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 293}], {
             RGBColor[
             0.9379005769230768, 0.7766133846153846, 0.4972080769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 299}], {
             RGBColor[
             0.8516995384615385, 0.8825818461538462, 0.8710316538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 336}], {
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 367}], {
             RGBColor[
             0.9926128846153845, 0.9888158461538461, 0.5978210384615383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 396}], {
             RGBColor[
             0.9869913461538461, 0.9698530769230769, 0.5759824230769228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 271}], {
             RGBColor[
             0.9755605384615385, 0.9804433076923078, 0.8881728461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 326}], {
             RGBColor[
             0.9780118846153847, 0.9805349230769231, 0.7805222692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 335}], {
             RGBColor[
             0.9784394230769231, 0.9814493846153847, 0.8270571923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 337}], {
             RGBColor[
             0.9738543846153846, 0.9797377692307693, 0.9164482307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 354}], {
             RGBColor[0.8908973076923077, 0.915168, 0.9661104230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 245}], {
             RGBColor[
             0.9368437692307692, 0.9521892307692307, 0.9838330384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 248}], {
             RGBColor[
             0.9274514999999999, 0.8485676923076921, 0.6269449615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 292}], {
             RGBColor[
             0.9609330384615384, 0.9681636153846154, 0.8487327692307695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 304}], {
             RGBColor[0.873390923076923, 0.9018822307692307, 0.987786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 309}], {
             RGBColor[
             0.7627659999999999, 0.8147929230769231, 0.9772168461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 315}], {
             RGBColor[
             0.9368437692307692, 0.9521892307692307, 0.9838330384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 319}], {
             RGBColor[
             0.9605054999999999, 0.9672491538461538, 0.8021978461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 329}], {
             RGBColor[
             0.9609330384615384, 0.9681636153846154, 0.8487327692307695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 334}], {
             RGBColor[
             0.9443042307692306, 0.9577532307692307, 0.971204423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 371}], {
             RGBColor[
             0.9580541538461538, 0.9671575384615384, 0.909848423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 388}], {
             RGBColor[
             0.9368437692307692, 0.9521892307692307, 0.9838330384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 255}], {
             RGBColor[
             0.9427031923076923, 0.9530540769230769, 0.8004998461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 288}], {
             RGBColor[
             0.9917618076923076, 0.9899392307692307, 0.7191662692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 339}], {
             RGBColor[
             0.9427031923076923, 0.9530540769230769, 0.8004998461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 360}], {
             RGBColor[
             0.9691185384615384, 0.9029056923076921, 0.4426671153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 374}], {
             RGBColor[
             0.9764934615384615, 0.9313136153846153, 0.45292999999999994`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 375}], {
             RGBColor[
             0.9764934615384615, 0.9313136153846153, 0.45292999999999994`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 399}], {
             RGBColor[
             0.970551423076923, 0.974970923076923, 0.7931508846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 256}], {
             RGBColor[
             0.9184242692307691, 0.9180673076923076, 0.6838933846153844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 257}], {
             RGBColor[
             0.9852851923076922, 0.9691475384615383, 0.6042578076923074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 268}], {
             RGBColor[
             0.9700168461538461, 0.9105219230769229, 0.33802153846153826`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 317}], {
             RGBColor[
             0.9467231538461538, 0.8190013846153845, 0.3149500384615383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 333}], {
             RGBColor[
             0.9868814615384616, 0.9674102307692306, 0.40353738461538435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 381}], {
             RGBColor[
             0.981259923076923, 0.9484474615384613, 0.38169876923076884`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 382}], {
             RGBColor[
             0.9756383846153845, 0.929484692307692, 0.35986015384615355`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 348}], {
             RGBColor[
             0.9930404230769231, 0.9897303076923077, 0.6443559615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 351}], {
             RGBColor[
             0.9066710384615385, 0.9237494615384616, 0.7505689230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 253}], {
             RGBColor[0.8970252692307692, 0.558147, 0.5442448076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 270}], {
             RGBColor[
             0.8880463846153845, 0.5033616923076922, 0.22928115384615383`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 308}], {
             RGBColor[
             0.8806714615384614, 0.47495376923076904`, 0.21901826923076917`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 397}], {
             RGBColor[0.872058423076923, 0.5392972307692308, 0.578549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 248}], {
             RGBColor[
             0.9374974230769231, 0.8562894615384615, 0.6178980000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 292}], {
             RGBColor[
             0.9709789615384615, 0.9758853846153845, 0.8396858076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 304}], {
             RGBColor[0.8834368461538462, 0.909604, 0.9787390384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 315}], {
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 319}], {
             RGBColor[
             0.970551423076923, 0.974970923076923, 0.7931508846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 329}], {
             RGBColor[
             0.9709789615384615, 0.9758853846153845, 0.8396858076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 353}], {
             RGBColor[
             0.9543501538461538, 0.9654750000000001, 0.9621574615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 371}], {
             RGBColor[
             0.9681000769230769, 0.9748793076923077, 0.9008014615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 378}], {
             RGBColor[
             0.966393923076923, 0.9741737692307693, 0.9290768461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 388}], {
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 254}], {
             RGBColor[0.8693335, 0.7248276153846154, 0.6051190384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 286}], {
             RGBColor[
             0.9377906923076923, 0.7741705384615385, 0.32476303846153837`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 320}], {
             RGBColor[
             0.7968773461538461, 0.6679365384615384, 0.5979736538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 343}], {
             RGBColor[
             0.8760288461538461, 0.5299577692307693, 0.21826776923076924`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 344}], {
             RGBColor[
             0.9390733076923077, 0.7769139230769231, 0.4643678076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 349}], {
             RGBColor[
             0.9390733076923077, 0.7769139230769231, 0.4643678076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 289}], {
             RGBColor[
             0.9339623846153846, 0.9491221538461538, 0.9568778076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 302}], {
             RGBColor[
             0.8555886153846154, 0.8876871538461538, 0.9860880000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 340}], {
             RGBColor[
             0.9265019230769231, 0.9435581538461539, 0.969506423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 391}], {
             RGBColor[
             0.9362265769230769, 0.9322623846153845, 0.6855913846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 292}], {
             RGBColor[
             0.9615866923076923, 0.8722638461538461, 0.482797730769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 304}], {
             RGBColor[
             0.8740445769230769, 0.8059824615384614, 0.6218509615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 315}], {
             RGBColor[
             0.9374974230769231, 0.8562894615384615, 0.6178980000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 319}], {
             RGBColor[
             0.9611591538461538, 0.8713493846153846, 0.43626280769230763`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 329}], {
             RGBColor[
             0.9615866923076923, 0.8722638461538461, 0.482797730769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 353}], {
             RGBColor[
             0.9449578846153845, 0.8618534615384615, 0.6052693846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 388}], {
             RGBColor[
             0.9374974230769231, 0.8562894615384615, 0.6178980000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 270}], {
             RGBColor[0.9249835, 0.8943368461538461, 0.6419141538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 308}], {
             RGBColor[
             0.9176085769230768, 0.8659289230769229, 0.6316512692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 309}], {
             RGBColor[
             0.7449636923076923, 0.8005978461538461, 0.9755188461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 334}], {
             RGBColor[
             0.9265019230769231, 0.9435581538461539, 0.969506423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 386}], {
             RGBColor[
             0.940251846153846, 0.9529624615384615, 0.9081504230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 397}], {
             RGBColor[0.9089955384615384, 0.9302723846153845, 0.991182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 265}], {
             RGBColor[
             0.9681000769230769, 0.9748793076923077, 0.9008014615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 276}], {
             RGBColor[
             0.9796636538461538, 0.9501847692307692, 0.5824191923076921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 289}], {
             RGBColor[
             0.9830209999999999, 0.9860073076923077, 0.8755442307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 391}], {
             RGBColor[
             0.9852851923076922, 0.9691475384615383, 0.6042578076923074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 282}], {
             RGBColor[
             0.9207433846153845, 0.9380618461538461, 0.9347278076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 312}], {
             RGBColor[
             0.9029410769230769, 0.9238667692307692, 0.9330298076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 356}], {
             RGBColor[
             0.989200576923077, 0.9874047692307693, 0.6543718076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 277}], {
             RGBColor[
             0.9274387307692307, 0.7431920000000001, 0.5478765384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 293}], {
             RGBColor[
             0.8760288461538461, 0.5299577692307693, 0.21826776923076924`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 330}], {
             RGBColor[
             0.9291448846153846, 0.7438975384615385, 0.5196011538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 386}], {
             RGBColor[
             0.9830209999999999, 0.9860073076923077, 0.8755442307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 286}], {
             RGBColor[
             0.9240458076923077, 0.9370300769230768, 0.7057319999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 320}], {
             RGBColor[
             0.7831324615384615, 0.8307960769230769, 0.9789426153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 343}], {
             RGBColor[
             0.8622839615384615, 0.6928173076923078, 0.5992367307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 344}], {
             RGBColor[
             0.9253284230769231, 0.9397734615384615, 0.8453367692307694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 349}], {
             RGBColor[
             0.9253284230769231, 0.9397734615384615, 0.8453367692307694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 288}], {
             RGBColor[
             0.940251846153846, 0.9529624615384615, 0.9081504230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 341}], {
             RGBColor[
             0.9418481153846154, 0.9512251538461538, 0.7074299999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 360}], {
             RGBColor[
             0.9176085769230768, 0.8659289230769229, 0.6316512692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 374}], {
             RGBColor[0.9249835, 0.8943368461538461, 0.6419141538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 393}], {
             RGBColor[
             0.9418481153846154, 0.9512251538461538, 0.7074299999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 399}], {
             RGBColor[
             0.9190414615384614, 0.9379941538461538, 0.9821350384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 261}], {
             RGBColor[
             0.9241556923076923, 0.9394729230769231, 0.8781770384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 264}], {
             RGBColor[0.873390923076923, 0.9018822307692307, 0.987786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 317}], {
             RGBColor[
             0.8838874999999999, 0.7886212307692309, 0.6171446538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 333}], {
             RGBColor[
             0.9240458076923077, 0.9370300769230768, 0.7057319999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 381}], {
             RGBColor[
             0.9184242692307691, 0.9180673076923076, 0.6838933846153844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 268}], {
             RGBColor[0.9740421153846153, 0.931222, 0.5605805769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 338}], {
             RGBColor[
             0.9587078076923077, 0.8712577692307693, 0.5439133846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 381}], {
             RGBColor[
             0.9852851923076922, 0.9691475384615383, 0.6042578076923074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 382}], {
             RGBColor[
             0.9796636538461538, 0.9501847692307692, 0.5824191923076921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 278}], {
             RGBColor[
             0.9241556923076923, 0.9394729230769231, 0.8781770384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 284}], {
             RGBColor[0.9604139615384615, 0.8719633076923077, 0.515638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 369}], {
             RGBColor[
             0.9869913461538461, 0.9698530769230769, 0.5759824230769228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 392}], {
             RGBColor[
             0.9927227692307692, 0.9912586923076924, 0.7702660769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 274}], {
             RGBColor[
             0.9513988461538461, 0.8441884615384614, 0.28408142307692297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 299}], {
             RGBColor[
             0.8347250384615383, 0.8232506923076923, 0.6330707692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 318}], {
             RGBColor[0.9249835, 0.8943368461538461, 0.6419141538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 336}], {
             RGBColor[
             0.9769209999999999, 0.9322280769230769, 0.49946492307692325`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 367}], {
             RGBColor[
             0.9756383846153847, 0.9294846923076923, 0.3598601538461537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 267}], {
             RGBColor[
             0.9299049615384615, 0.7720675384615385, 0.5742108461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 272}], {
             RGBColor[
             0.9830209999999999, 0.9860073076923077, 0.8755442307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 291}], {
             RGBColor[
             0.922855423076923, 0.7400572307692308, 0.5683285384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 321}], {
             RGBColor[
             0.9858998846153846, 0.9870133846153846, 0.8144285769230771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 338}], {
             RGBColor[
             0.952418346153846, 0.8674174615384616, 0.5926407692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 342}], {
             RGBColor[
             0.9854723461538462, 0.986098923076923, 0.7678936538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 384}], {
             RGBColor[0.8983577692307692, 0.920732, 0.9534818076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 398}], {
             RGBColor[
             0.9369544999999999, 0.804077846153846, 0.5800931538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 264}], {
             RGBColor[0.941958, 0.953668, 0.8798750384615385]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{261, 295}], {
             RGBColor[
             0.9683733461538461, 0.9035196153846152, 0.5220423076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 310}], {
             RGBColor[
             0.9698062307692308, 0.9755848461538461, 0.8725260769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 381}], {
             RGBColor[
             0.9869913461538461, 0.9698530769230769, 0.5759824230769228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 269}], {
             RGBColor[
             0.7802723846153847, 0.8280786923076924, 0.9555412692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 298}], {
             RGBColor[0.9224445, 0.7665035384615385, 0.5868394615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 300}], {
             RGBColor[
             0.9755605384615385, 0.9804433076923078, 0.8881728461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 306}], {
             RGBColor[
             0.9692710769230769, 0.9766030000000001, 0.9369002307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 307}], {
             RGBColor[0.8362434615384615, 0.872472, 0.9606630384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 314}], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 310}], {
             RGBColor[
             0.9190414615384614, 0.9379941538461538, 0.9821350384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 333}], {
             RGBColor[
             0.9418481153846154, 0.9512251538461538, 0.7074299999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 381}], {
             RGBColor[
             0.9362265769230769, 0.9322623846153845, 0.6855913846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 322}], {
             RGBColor[0.9696963461538461, 0.973142, 0.7000810384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 362}], {
             RGBColor[
             0.970551423076923, 0.974970923076923, 0.7931508846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 273}], {
             RGBColor[
             0.9813698076923076, 0.9508903076923076, 0.5541438076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 365}], {
             RGBColor[
             0.981259923076923, 0.9484474615384615, 0.381698769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 272}], {
             RGBColor[
             0.936194423076923, 0.7759078461538462, 0.5254834615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 291}], {
             RGBColor[
             0.8760288461538461, 0.5299577692307693, 0.21826776923076924`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 321}], {
             RGBColor[
             0.9390733076923077, 0.7769139230769231, 0.4643678076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 331}], {
             RGBColor[0.9224445, 0.7665035384615385, 0.5868394615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 342}], {
             RGBColor[
             0.9386457692307693, 0.7759994615384616, 0.4178328846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 346}], {
             RGBColor[
             0.8515311923076923, 0.7106325384615384, 0.6034210384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 384}], {
             RGBColor[
             0.8515311923076923, 0.7106325384615384, 0.6034210384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 398}], {
             RGBColor[
             0.890127923076923, 0.5939783846153845, 0.2300323846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 338}], {
             RGBColor[
             0.9434394615384615, 0.8126321538461538, 0.27767711538461537`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 381}], {
             RGBColor[
             0.9700168461538461, 0.9105219230769229, 0.33802153846153826`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 279}], {
             RGBColor[
             0.7964736538461539, 0.8375746153846154, 0.7865346923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 298}], {
             RGBColor[
             0.7409062692307693, 0.6235432307692308, 0.5928518846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 300}], {
             RGBColor[0.7940223076923076, 0.837483, 0.8941852692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 306}], {
             RGBColor[
             0.7877328461538462, 0.8336426923076923, 0.9429126538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 307}], {
             RGBColor[
             0.6547052307692307, 0.7295116923076923, 0.9666754615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 314}], {
             RGBColor[
             0.7802723846153847, 0.8280786923076924, 0.9555412692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 308}], {
             RGBColor[
             0.9513988461538461, 0.8441884615384614, 0.28408142307692297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 397}], {
             RGBColor[
             0.9427858076923076, 0.908531923076923, 0.6436121538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 273}], {
             RGBColor[
             0.9910166153846154, 0.9905531538461538, 0.7985414615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 326}], {
             RGBColor[
             0.9917618076923076, 0.9899392307692307, 0.7191662692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 335}], {
             RGBColor[
             0.9921893461538461, 0.9908536923076923, 0.7657011923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 394}], {
             RGBColor[
             0.9910166153846154, 0.9905531538461538, 0.7985414615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 291}], {
             RGBColor[
             0.9291448846153846, 0.7438975384615385, 0.5196011538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 321}], {
             RGBColor[
             0.9921893461538461, 0.9908536923076923, 0.7657011923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 331}], {
             RGBColor[
             0.9755605384615385, 0.9804433076923078, 0.8881728461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 338}], {
             RGBColor[
             0.9587078076923077, 0.8712577692307693, 0.5439133846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 342}], {
             RGBColor[
             0.9917618076923076, 0.9899392307692307, 0.7191662692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 346}], {
             RGBColor[
             0.9046472307692308, 0.9245723076923077, 0.904754423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 384}], {
             RGBColor[
             0.9046472307692308, 0.9245723076923077, 0.904754423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 398}], {
             RGBColor[
             0.9432439615384615, 0.8079181538461537, 0.5313657692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 365}], {
             RGBColor[
             0.9926128846153845, 0.9888158461538461, 0.5978210384615383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 394}], {
             RGBColor[
             0.9927227692307692, 0.9912586923076924, 0.7702660769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 287}], {
             RGBColor[
             0.8998062692307691, 0.851733846153846, 0.6299532692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 299}], {
             RGBColor[
             0.8273501153846152, 0.794842769230769, 0.6228078846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 318}], {
             RGBColor[
             0.9176085769230768, 0.8659289230769229, 0.6316512692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 367}], {
             RGBColor[
             0.9682634615384615, 0.9010767692307691, 0.34959726923076906`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 373}], {
             RGBColor[
             0.8273501153846152, 0.794842769230769, 0.6228078846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 395}], {
             RGBColor[
             0.9135511538461538, 0.6888743076923075, 0.24898430769230764`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 279}], {
             RGBColor[
             0.9611591538461538, 0.8713493846153846, 0.43626280769230763`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 281}], {
             RGBColor[
             0.9281051538461538, 0.752667923076923, 0.26100992307692306`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 306}], {
             RGBColor[
             0.952418346153846, 0.8674174615384616, 0.5926407692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 338}], {
             RGBColor[
             0.9281051538461538, 0.752667923076923, 0.26100992307692306`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 384}], {
             RGBColor[
             0.8740445769230769, 0.8059824615384614, 0.6218509615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 322}], {
             RGBColor[
             0.981259923076923, 0.9484474615384615, 0.381698769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 358}], {
             RGBColor[
             0.9335971538461538, 0.7682553076923075, 0.28696811538461525`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 376}], {
             RGBColor[
             0.9813698076923076, 0.9508903076923076, 0.5541438076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 377}], {
             RGBColor[
             0.9825425384615385, 0.9511908461538461, 0.5213035384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 287}], {
             RGBColor[
             0.9207433846153845, 0.9380618461538461, 0.9347278076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 330}], {
             RGBColor[
             0.9876043076923076, 0.989142076923077, 0.8550922307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 396}], {
             RGBColor[
             0.9835790384615384, 0.9684419999999998, 0.6325331923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 284}], {
             RGBColor[
             0.8918468846153846, 0.8201775384615384, 0.6235489615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 327}], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 337}], {
             RGBColor[
             0.9207433846153845, 0.9380618461538461, 0.9347278076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 354}], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 392}], {
             RGBColor[
             0.9241556923076923, 0.9394729230769231, 0.8781770384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 300}], {
             RGBColor[
             0.9917618076923076, 0.9899392307692307, 0.7191662692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 306}], {
             RGBColor[
             0.9854723461538462, 0.986098923076923, 0.7678936538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 363}], {
             RGBColor[
             0.8797716538461539, 0.903315923076923, 0.7943801538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 384}], {
             RGBColor[
             0.8740445769230769, 0.8059824615384614, 0.6218509615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 386}], {
             RGBColor[
             0.9587078076923077, 0.8712577692307693, 0.5439133846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 350}], {
             RGBColor[
             0.6433323846153847, 0.7177426923076924, 0.9673883846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 369}], {
             RGBColor[
             0.9546825384615384, 0.8505576923076921, 0.32135434615384595`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 392}], {
             RGBColor[0.9604139615384615, 0.8719633076923077, 0.515638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 330}], {
             RGBColor[
             0.9291448846153846, 0.7438975384615385, 0.5196011538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 387}], {
             RGBColor[
             0.9291448846153846, 0.7438975384615385, 0.5196011538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 320}], {
             RGBColor[0.8515896538461538, 0.880139, 0.6985866153846152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 343}], {
             RGBColor[
             0.9307411538461539, 0.7421602307692308, 0.3188807307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 349}], {
             RGBColor[
             0.9937856153846154, 0.9891163846153845, 0.5649807692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 367}], {
             RGBColor[
             0.9240458076923077, 0.9370300769230768, 0.7057319999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 373}], {
             RGBColor[
             0.7831324615384615, 0.8307960769230769, 0.9789426153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 395}], {
             RGBColor[0.8693335, 0.7248276153846154, 0.6051190384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 396}], {
             RGBColor[
             0.9184242692307691, 0.9180673076923076, 0.6838933846153844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 341}], {
             RGBColor[
             0.9909067307692307, 0.9881103076923077, 0.6260964230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 355}], {
             RGBColor[0.9740421153846153, 0.931222, 0.5605805769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 360}], {
             RGBColor[
             0.9666671923076922, 0.9028140769230768, 0.5503176923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 374}], {
             RGBColor[0.9740421153846153, 0.931222, 0.5605805769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 375}], {
             RGBColor[0.9740421153846153, 0.931222, 0.5605805769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 379}], {
             RGBColor[
             0.9852851923076922, 0.9691475384615383, 0.6042578076923074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 393}], {
             RGBColor[
             0.9909067307692307, 0.9881103076923077, 0.6260964230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 399}], {
             RGBColor[
             0.9681000769230769, 0.9748793076923077, 0.9008014615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 302}], {
             RGBColor[0.8983577692307692, 0.920732, 0.9534818076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 340}], {
             RGBColor[
             0.9692710769230769, 0.9766030000000001, 0.9369002307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 391}], {
             RGBColor[
             0.9789957307692307, 0.9653072307692306, 0.6529851923076921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 313}], {
             RGBColor[
             0.7271613846153846, 0.7864027692307692, 0.9738208461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 321}], {
             RGBColor[
             0.7969011923076923, 0.838489076923077, 0.8330696153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 331}], {
             RGBColor[
             0.7802723846153847, 0.8280786923076924, 0.9555412692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 342}], {
             RGBColor[
             0.7964736538461539, 0.8375746153846154, 0.7865346923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 346}], {
             RGBColor[
             0.709359076923077, 0.7722076923076924, 0.9721228461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 321}], {
             RGBColor[
             0.9320237692307692, 0.7449036153846155, 0.4584855000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 331}], {
             RGBColor[
             0.9153949615384616, 0.7344932307692309, 0.5809571538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 338}], {
             RGBColor[
             0.8985422307692308, 0.6253076923076923, 0.2366976923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 342}], {
             RGBColor[
             0.9315962307692307, 0.7439891538461539, 0.4119505769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 384}], {
             RGBColor[
             0.8444816538461539, 0.6786222307692309, 0.5975387307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 398}], {
             RGBColor[
             0.8830783846153846, 0.5619680769230769, 0.22415007692307692`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 304}], {
             RGBColor[
             0.9075261153846155, 0.9255783846153847, 0.8436387692307694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 329}], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 353}], {
             RGBColor[
             0.9784394230769231, 0.9814493846153847, 0.8270571923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 378}], {
             RGBColor[
             0.9904831923076922, 0.9901481538461538, 0.7939765769230772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 388}], {
             RGBColor[
             0.9709789615384615, 0.9758853846153845, 0.8396858076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 299}], {
             RGBColor[
             0.7968773461538461, 0.6679365384615384, 0.5979736538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 330}], {
             RGBColor[
             0.936194423076923, 0.7759078461538462, 0.5254834615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 336}], {
             RGBColor[
             0.9390733076923077, 0.7769139230769231, 0.4643678076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 341}], {
             RGBColor[
             0.9771568076923077, 0.9787060000000001, 0.6874524230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 368}], {
             RGBColor[
             0.9715352692307693, 0.9597432307692306, 0.6656138076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 393}], {
             RGBColor[
             0.9771568076923077, 0.9787060000000001, 0.6874524230769229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 310}], {
             RGBColor[
             0.9454568076923076, 0.8878457692307691, 0.6243023076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 345}], {
             RGBColor[
             0.9065016153846153, 0.6568639999999999, 0.24310199999999996`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 363}], {
             RGBColor[
             0.8546770384615384, 0.816190769230769, 0.6255315769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 316}], {
             RGBColor[
             0.7713790384615384, 0.7504494615384614, 0.6176861153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 324}], {
             RGBColor[
             0.7964736538461539, 0.8375746153846154, 0.7865346923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 360}], {
             RGBColor[
             0.7713790384615384, 0.7504494615384614, 0.6176861153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 374}], {
             RGBColor[0.7787539615384615, 0.7788573846153846, 0.627949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 375}], {
             RGBColor[0.7787539615384615, 0.7788573846153846, 0.627949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 380}], {
             RGBColor[
             0.7409062692307693, 0.6235432307692308, 0.5928518846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 383}], {
             RGBColor[
             0.772811923076923, 0.8225146923076923, 0.9681698846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 390}], {
             RGBColor[
             0.795618576923077, 0.8357456923076922, 0.6934648461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 307}], {
             RGBColor[
             0.8459681153846152, 0.8611762307692306, 0.6767479999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 314}], {
             RGBColor[
             0.9715352692307693, 0.9597432307692306, 0.6656138076923075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 332}], {
             RGBColor[
             0.9540288846153845, 0.9464574615384613, 0.6872893846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 352}], {
             RGBColor[
             0.9789957307692307, 0.9653072307692306, 0.6529851923076921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 385}], {
             RGBColor[
             0.9852851923076922, 0.9691475384615383, 0.6042578076923074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 306}], {
             RGBColor[
             0.9299049615384615, 0.7720675384615385, 0.5742108461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 307}], {
             RGBColor[
             0.7968773461538461, 0.6679365384615384, 0.5979736538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 314}], {
             RGBColor[0.9224445, 0.7665035384615385, 0.5868394615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 336}], {
             RGBColor[
             0.8528722692307692, 0.8828823846153846, 0.8381913846153848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 367}], {
             RGBColor[0.8515896538461538, 0.880139, 0.6985866153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 306}], {
             RGBColor[
             0.9830209999999999, 0.9860073076923077, 0.8755442307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 307}], {
             RGBColor[
             0.8499933846153845, 0.8818763076923077, 0.8993070384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 314}], {
             RGBColor[
             0.9755605384615385, 0.9804433076923078, 0.8881728461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 363}], {
             RGBColor[
             0.8773203076923077, 0.9032243076923077, 0.9020307307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 316}], {
             RGBColor[
             0.9570203846153845, 0.8631512307692305, 0.30592003846153826`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 324}], {
             RGBColor[0.982115, 0.9502763846153846, 0.47476861538461523`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 372}], {
             RGBColor[
             0.9570203846153845, 0.8631512307692305, 0.30592003846153826`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 380}], {
             RGBColor[
             0.9265476153846153, 0.7362449999999999, 0.28108580769230757`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 383}], {
             RGBColor[
             0.9584532692307692, 0.9352164615384615, 0.6564038076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 390}], {
             RGBColor[
             0.981259923076923, 0.9484474615384615, 0.381698769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 323}], {
             RGBColor[
             0.9070985769230769, 0.9246639230769231, 0.7971038461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 340}], {
             RGBColor[0.8908973076923077, 0.915168, 0.9661104230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 313}], {
             RGBColor[
             0.9012391538461538, 0.9237990769230768, 0.9804370384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 344}], {
             RGBColor[
             0.9709789615384615, 0.9758853846153845, 0.8396858076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 315}], {
             RGBColor[0.8834368461538462, 0.909604, 0.9787390384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 329}], {
             RGBColor[
             0.9075261153846155, 0.9255783846153847, 0.8436387692307694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 353}], {
             RGBColor[0.8908973076923077, 0.915168, 0.9661104230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 378}], {
             RGBColor[
             0.9029410769230769, 0.9238667692307692, 0.9330298076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 325}], {
             RGBColor[
             0.8773203076923077, 0.9032243076923077, 0.9020307307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 314}], {
             RGBColor[0.8362434615384615, 0.872472, 0.9606630384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 352}], {
             RGBColor[0.843703923076923, 0.878036, 0.9480344230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 385}], {
             RGBColor[
             0.8499933846153845, 0.8818763076923077, 0.8993070384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 386}], {
             RGBColor[
             0.9666671923076922, 0.9028140769230768, 0.5503176923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 397}], {
             RGBColor[
             0.9354108846153845, 0.8801239999999997, 0.6333492692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 319}], {
             RGBColor[
             0.7964736538461539, 0.8375746153846154, 0.7865346923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 329}], {
             RGBColor[
             0.7969011923076923, 0.838489076923077, 0.8330696153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 334}], {
             RGBColor[
             0.7802723846153847, 0.8280786923076924, 0.9555412692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 371}], {
             RGBColor[0.7940223076923076, 0.837483, 0.8941852692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 386}], {
             RGBColor[0.7940223076923076, 0.837483, 0.8941852692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 345}], {
             RGBColor[0.9079345, 0.7289292307692308, 0.5935857692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 363}], {
             RGBColor[
             0.8561099230769231, 0.8882559999999999, 0.9760153461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 323}], {
             RGBColor[
             0.9531997692307692, 0.839793076923077, 0.4298584999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 339}], {
             RGBColor[
             0.9016898076923077, 0.8028163076923077, 0.6188426538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 327}], {
             RGBColor[0.873390923076923, 0.9018822307692307, 0.987786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 356}], {
             RGBColor[0.9062435, 0.922835, 0.7040339999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{312, 361}], {
             RGBColor[
             0.9075261153846155, 0.9255783846153847, 0.8436387692307694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 344}], {
             RGBColor[
             0.9253284230769231, 0.9397734615384615, 0.8453367692307694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 359}], {
             RGBColor[
             0.6433323846153847, 0.7177426923076924, 0.9673883846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 385}], {
             RGBColor[
             0.9755605384615385, 0.9804433076923078, 0.8881728461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 319}], {
             RGBColor[
             0.970551423076923, 0.974970923076923, 0.7931508846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 329}], {
             RGBColor[
             0.9709789615384615, 0.9758853846153845, 0.8396858076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 334}], {
             RGBColor[
             0.9543501538461538, 0.9654750000000001, 0.9621574615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 371}], {
             RGBColor[
             0.9681000769230769, 0.9748793076923077, 0.9008014615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 324}], {
             RGBColor[
             0.9691185384615384, 0.9029056923076921, 0.4426671153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 355}], {
             RGBColor[
             0.9513988461538461, 0.8441884615384614, 0.28408142307692297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 380}], {
             RGBColor[
             0.9135511538461538, 0.6888743076923075, 0.24898430769230764`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 383}], {
             RGBColor[
             0.9454568076923076, 0.8878457692307691, 0.6243023076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 390}], {
             RGBColor[
             0.9682634615384615, 0.9010767692307691, 0.34959726923076906`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 333}], {
             RGBColor[
             0.9523446923076924, 0.8379641538461539, 0.33678865384615375`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 370}], {
             RGBColor[
             0.8660851923076923, 0.7744261538461539, 0.6154466538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 381}], {
             RGBColor[
             0.9467231538461538, 0.8190013846153845, 0.3149500384615383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 382}], {
             RGBColor[
             0.9411016153846153, 0.8000386153846153, 0.29311142307692295`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 367}], {
             RGBColor[
             0.9418481153846154, 0.9512251538461538, 0.7074299999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 373}], {
             RGBColor[
             0.8009347692307691, 0.8449911538461539, 0.9806406153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 329}], {
             RGBColor[
             0.9946406923076923, 0.9909453076923077, 0.6580506153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 334}], {
             RGBColor[
             0.9780118846153847, 0.9805349230769231, 0.7805222692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 371}], {
             RGBColor[
             0.9917618076923076, 0.9899392307692307, 0.7191662692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 388}], {
             RGBColor[
             0.970551423076923, 0.974970923076923, 0.7931508846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 343}], {
             RGBColor[
             0.7898278076923076, 0.6359262307692308, 0.5920913461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 349}], {
             RGBColor[
             0.8528722692307692, 0.8828823846153846, 0.8381913846153848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 331}], {
             RGBColor[
             0.9784394230769231, 0.9814493846153847, 0.8270571923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 338}], {
             RGBColor[
             0.9615866923076923, 0.8722638461538461, 0.482797730769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 342}], {
             RGBColor[
             0.9946406923076923, 0.9909453076923077, 0.6580506153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 384}], {
             RGBColor[
             0.9075261153846155, 0.9255783846153847, 0.8436387692307694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 398}], {
             RGBColor[
             0.9461228461538461, 0.8089242307692307, 0.4702501153846156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 328}], {
             RGBColor[
             0.9682634615384615, 0.9010767692307691, 0.34959726923076906`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 362}], {
             RGBColor[
             0.993358076923077, 0.988201923076923, 0.518445846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 364}], {
             RGBColor[0.9696963461538461, 0.973142, 0.7000810384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 340}], {
             RGBColor[
             0.9780118846153847, 0.9805349230769231, 0.7805222692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 375}], {
             RGBColor[
             0.9764934615384615, 0.9313136153846153, 0.45292999999999994`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 380}], {
             RGBColor[
             0.9386457692307693, 0.7759994615384616, 0.4178328846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 383}], {
             RGBColor[
             0.970551423076923, 0.974970923076923, 0.7931508846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 390}], {
             RGBColor[
             0.993358076923077, 0.988201923076923, 0.518445846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 335}], {
             RGBColor[
             0.9946406923076923, 0.9909453076923077, 0.6580506153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 337}], {
             RGBColor[
             0.9900556538461538, 0.9892336923076923, 0.7474416538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 354}], {
             RGBColor[
             0.9070985769230769, 0.9246639230769231, 0.7971038461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 337}], {
             RGBColor[
             0.9563479999999999, 0.9664519999999999, 0.9381238076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 354}], {
             RGBColor[0.873390923076923, 0.9018822307692307, 0.987786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 356}], {
             RGBColor[
             0.9596504230769229, 0.9654202307692307, 0.7091279999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 392}], {
             RGBColor[
             0.9597603076923076, 0.9678630769230769, 0.8815730384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 347}], {
             RGBColor[
             0.9206006923076921, 0.7208846153846151, 0.2548666153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 362}], {
             RGBColor[
             0.9691185384615384, 0.9029056923076921, 0.4426671153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 372}], {
             RGBColor[
             0.944023923076923, 0.8157805384615381, 0.27381853846153836`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 387}], {
             RGBColor[
             0.9666671923076922, 0.9028140769230768, 0.5503176923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 334}], {
             RGBColor[
             0.9784394230769231, 0.9814493846153847, 0.8270571923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 353}], {
             RGBColor[
             0.9784394230769231, 0.9814493846153847, 0.8270571923076925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 371}], {
             RGBColor[
             0.9921893461538461, 0.9908536923076923, 0.7657011923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 388}], {
             RGBColor[
             0.9709789615384615, 0.9758853846153845, 0.8396858076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 342}], {
             RGBColor[
             0.9780118846153847, 0.9805349230769231, 0.7805222692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 346}], {
             RGBColor[0.8908973076923077, 0.915168, 0.9661104230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 361}], {
             RGBColor[
             0.9609330384615384, 0.9681636153846154, 0.8487327692307695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 385}], {
             RGBColor[
             0.9580541538461538, 0.9671575384615384, 0.909848423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 381}], {
             RGBColor[
             0.9868814615384616, 0.9674102307692306, 0.40353738461538435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 371}], {
             RGBColor[
             0.9755605384615385, 0.9804433076923078, 0.8881728461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 388}], {
             RGBColor[
             0.9543501538461538, 0.9654750000000001, 0.9621574615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 337}], {
             RGBColor[
             0.9904831923076922, 0.9901481538461538, 0.7939765769230772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 354}], {
             RGBColor[
             0.9075261153846155, 0.9255783846153847, 0.8436387692307694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 367}], {
             RGBColor[
             0.9937856153846154, 0.9891163846153845, 0.5649807692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 354}], {
             RGBColor[
             0.9029410769230769, 0.9238667692307692, 0.9330298076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 384}], {
             RGBColor[
             0.8740445769230769, 0.8059824615384614, 0.6218509615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 398}], {
             RGBColor[
             0.9126413076923077, 0.6893283076923076, 0.24846230769230765`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 360}], {
             RGBColor[
             0.9176085769230768, 0.8659289230769229, 0.6316512692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 374}], {
             RGBColor[0.9249835, 0.8943368461538461, 0.6419141538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 368}], {
             RGBColor[
             0.9868814615384616, 0.9674102307692306, 0.40353738461538435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 379}], {
             RGBColor[
             0.9868814615384616, 0.9674102307692306, 0.40353738461538435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 393}], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 399}], {
             RGBColor[0.9696963461538461, 0.973142, 0.7000810384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 346}], {
             RGBColor[
             0.9070985769230769, 0.9246639230769231, 0.7971038461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 398}], {
             RGBColor[
             0.9456953076923076, 0.8080097692307692, 0.4237151923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 349}], {
             RGBColor[
             0.9320237692307692, 0.7449036153846155, 0.4584855000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 349}], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 362}], {
             RGBColor[
             0.9456953076923076, 0.8080097692307692, 0.4237151923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 372}], {
             RGBColor[
             0.9206006923076921, 0.7208846153846151, 0.2548666153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 387}], {
             RGBColor[
             0.9432439615384615, 0.8079181538461537, 0.5313657692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 351}], {
             RGBColor[
             0.9063533846153846, 0.9252778461538462, 0.8764790384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 369}], {
             RGBColor[
             0.9869913461538461, 0.9698530769230769, 0.5759824230769228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 357}], {
             RGBColor[
             0.6255300769230769, 0.7035476153846154, 0.9656903846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 394}], {
             RGBColor[
             0.7118994615384615, 0.7695284615384617, 0.8594774230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 378}], {
             RGBColor[
             0.9738543846153846, 0.9797377692307693, 0.9164482307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 375}], {
             RGBColor[
             0.9587737692307692, 0.8725963846153846, 0.2943443076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 379}], {
             RGBColor[
             0.9700168461538461, 0.9105219230769229, 0.33802153846153826`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 366}], {
             RGBColor[0.904681923076923, 0.657772, 0.242058]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{358, 391}], {
             RGBColor[
             0.9392186923076922, 0.7872180769230768, 0.30880673076923054`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 374}], {
             RGBColor[
             0.9513988461538461, 0.8441884615384614, 0.28408142307692297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 375}], {
             RGBColor[
             0.9513988461538461, 0.8441884615384614, 0.28408142307692297`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 369}], {
             RGBColor[
             0.9881640769230768, 0.9701536153846153, 0.5431421538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 385}], {
             RGBColor[
             0.9921893461538461, 0.9908536923076923, 0.7657011923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 377}], {
             RGBColor[
             0.9709789615384615, 0.9758853846153845, 0.8396858076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 387}], {
             RGBColor[
             0.9681000769230769, 0.9748793076923077, 0.9008014615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 382}], {
             RGBColor[
             0.9411016153846153, 0.8000386153846153, 0.29311142307692295`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 393}], {
             RGBColor[
             0.9868814615384616, 0.9674102307692306, 0.40353738461538435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 399}], {
             RGBColor[
             0.9640748076923076, 0.9541792307692306, 0.6782424230769228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 392}], {
             RGBColor[
             0.9869913461538461, 0.9698530769230769, 0.5759824230769228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 389}], {
             RGBColor[0.7380032307692308, 0.795253, 0.9745209230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 391}], {
             RGBColor[
             0.9006219615384615, 0.9038722307692306, 0.6821953846153844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 400}], {
             RGBColor[
             0.9066710384615385, 0.9237494615384616, 0.7505689230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 395}], {
             RGBColor[
             0.7968773461538461, 0.6679365384615384, 0.5979736538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 375}], {
             RGBColor[
             0.9587737692307692, 0.8725963846153846, 0.2943443076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 399}], {
             RGBColor[
             0.9528317307692307, 0.9162536923076923, 0.6345651923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 379}], {
             RGBColor[
             0.9700168461538461, 0.9105219230769229, 0.33802153846153826`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 383}], {
             RGBColor[
             0.9528317307692307, 0.9162536923076923, 0.6345651923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 399}], {
             RGBColor[
             0.9528317307692307, 0.9162536923076923, 0.6345651923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 377}], {
             RGBColor[0.9938955, 0.9915592307692308, 0.7374258076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 393}], {
             RGBColor[
             0.9868814615384616, 0.9674102307692306, 0.40353738461538435`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 399}], {
             RGBColor[
             0.9640748076923076, 0.9541792307692306, 0.6782424230769228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 383}], {
             RGBColor[
             0.9149840384615384, 0.7609395384615385, 0.5994680769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 390}], {
             RGBColor[
             0.9377906923076923, 0.7741705384615385, 0.32476303846153837`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 390}], {
             RGBColor[0.9696963461538461, 0.973142, 0.7000810384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 398}], {
             RGBColor[
             0.8585807307692308, 0.7426428461538461, 0.6093033461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 400}], {
             RGBColor[
             0.8246902692307692, 0.8597054615384615, 0.7423978461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 399}], {
             RGBColor[0.9696963461538461, 0.973142, 0.7000810384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 396}], {
             RGBColor[
             0.9321691538461538, 0.755207769230769, 0.3029244230769229]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.03217915333176364], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.03217915333176364], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.03217915333176364], {
             RGBColor[
             0.9121863846153846, 0.6895553076923078, 0.24820130769230772`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.03217915333176364], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.03217915333176364], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.03217915333176364], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.03217915333176364], {
             RGBColor[
             0.9858981538461538, 0.9884365384615384, 0.8833676153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.03217915333176364], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.03217915333176364], {
             RGBColor[0.926797846153846, 0.9444674615384614, 0.99288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.03217915333176364], {
             RGBColor[0.7106763076923076, 0.773905, 0.9717972307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.03217915333176364], {
             RGBColor[
             0.993358076923077, 0.9882019230769231, 0.5184458461538463]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.03217915333176364], {
             RGBColor[
             0.993358076923077, 0.9882019230769231, 0.5184458461538463]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.03217915333176364], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.03217915333176364], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.03217915333176364], {
             RGBColor[
             0.944023923076923, 0.8157805384615381, 0.27381853846153836`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.03217915333176364], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.03217915333176364], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.03217915333176364], {
             RGBColor[
             0.9858981538461538, 0.9884365384615384, 0.8833676153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.03217915333176364], {
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.03217915333176364], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.03217915333176364], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.03217915333176364], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.03217915333176364], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.03217915333176364], {
             RGBColor[
             0.9858981538461538, 0.9884365384615384, 0.8833676153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.03217915333176364], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.03217915333176364], {
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.03217915333176364], {
             RGBColor[
             0.8689793076923077, 0.4979474615384617, 0.21238546153846155`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.03217915333176364], {
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.03217915333176364], {
             RGBColor[0.8555886153846154, 0.8876871538461538, 0.986088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.03217915333176364], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.03217915333176364], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.03217915333176364], {
             RGBColor[
             0.8830783846153846, 0.5619680769230769, 0.22415007692307692`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.03217915333176364], {
             RGBColor[0.926797846153846, 0.9444674615384614, 0.99288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.03217915333176364], {
             RGBColor[
             0.8552445384615384, 0.42563930769230734`, 0.2005355384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.03217915333176364], {
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.03217915333176364], {
             RGBColor[
             0.9700168461538461, 0.9105219230769229, 0.3380215384615382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.03217915333176364], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.03217915333176364], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.03217915333176364], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.03217915333176364], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.03217915333176364], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.03217915333176364], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.03217915333176364], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.03217915333176364], {
             RGBColor[
             0.8689793076923077, 0.4979474615384617, 0.21238546153846155`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.03217915333176364], {
             RGBColor[
             0.9927227692307692, 0.9912586923076924, 0.7702660769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.03217915333176364], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.03217915333176364], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.03217915333176364], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.03217915333176364], {
             RGBColor[0.926797846153846, 0.9444674615384614, 0.99288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.03217915333176364], {
             RGBColor[
             0.9927227692307692, 0.9912586923076924, 0.7702660769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.03217915333176364], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.03217915333176364], {
             RGBColor[
             0.981259923076923, 0.9484474615384613, 0.38169876923076884`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.03217915333176364], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.03217915333176364], {
             RGBColor[
             0.9858981538461538, 0.9884365384615384, 0.8833676153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.03217915333176364], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.03217915333176364], {
             RGBColor[
             0.981259923076923, 0.9484474615384613, 0.38169876923076884`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.03217915333176364], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.03217915333176364], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.03217915333176364], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.03217915333176364], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.03217915333176364], {
             RGBColor[
             0.21887130769230764`, 0.34737799999999996`, 0.9357757692307692]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.03217915333176364], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.03217915333176364], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.03217915333176364], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.03217915333176364], {
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.03217915333176364], {
             RGBColor[0.7106763076923076, 0.773905, 0.9717972307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.03217915333176364], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.03217915333176364], {
             RGBColor[
             0.5405676923076923, 0.6378962307692307, 0.9569746153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.03217915333176364], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.03217915333176364], {
             RGBColor[0.926797846153846, 0.9444674615384614, 0.99288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.03217915333176364], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.03217915333176364], {
             RGBColor[
             0.981259923076923, 0.9484474615384613, 0.38169876923076884`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.03217915333176364], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.03217915333176364], {
             RGBColor[
             0.21887130769230764`, 0.34737799999999996`, 0.9357757692307692]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.03217915333176364], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.03217915333176364], {
             RGBColor[
             0.9281051538461538, 0.752667923076923, 0.26100992307692306`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.03217915333176364], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.03217915333176364], {
             RGBColor[
             0.993358076923077, 0.9882019230769231, 0.5184458461538463]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.03217915333176364], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.03217915333176364], {
             RGBColor[
             0.9858981538461538, 0.9884365384615384, 0.8833676153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.03217915333176364], {
             RGBColor[
             0.993358076923077, 0.9882019230769231, 0.5184458461538463]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.03217915333176364], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.03217915333176364], {
             RGBColor[
             0.6560224615384614, 0.7312089999999999, 0.9663498461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.03217915333176364], {
             RGBColor[0.8555886153846154, 0.8876871538461538, 0.986088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.03217915333176364], {
             RGBColor[
             0.9927227692307692, 0.9912586923076924, 0.7702660769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.03217915333176364], {
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.03217915333176364], {
             RGBColor[
             0.981259923076923, 0.9484474615384613, 0.38169876923076884`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.03217915333176364], {
             RGBColor[0.926797846153846, 0.9444674615384614, 0.99288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.03217915333176364], {
             RGBColor[
             0.981259923076923, 0.9484474615384613, 0.38169876923076884`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.03217915333176364], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.03217915333176364], {
             RGBColor[
             0.9927227692307692, 0.9912586923076924, 0.7702660769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.03217915333176364], {
             RGBColor[
             0.9858981538461538, 0.9884365384615384, 0.8833676153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.03217915333176364], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.03217915333176364], {
             RGBColor[
             0.6560224615384614, 0.7312089999999999, 0.9663498461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.03217915333176364], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.03217915333176364], {
             RGBColor[
             0.9700168461538461, 0.9105219230769229, 0.3380215384615382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.03217915333176364], {
             RGBColor[
             0.981259923076923, 0.9484474615384613, 0.38169876923076884`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.03217915333176364], {
             RGBColor[
             0.9281051538461538, 0.752667923076923, 0.26100992307692306`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.03217915333176364], {
             RGBColor[0.926797846153846, 0.9444674615384614, 0.99288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.03217915333176364], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.03217915333176364], {
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.03217915333176364], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.03217915333176364], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.03217915333176364], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.03217915333176364], {
             RGBColor[0.8555886153846154, 0.8876871538461538, 0.986088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.03217915333176364], {
             RGBColor[
             0.9281051538461538, 0.752667923076923, 0.26100992307692306`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.03217915333176364], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.03217915333176364], {
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.03217915333176364], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.03217915333176364], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.03217915333176364], {
             RGBColor[
             0.981259923076923, 0.9484474615384613, 0.38169876923076884`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.03217915333176364], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.03217915333176364], {
             RGBColor[
             0.944023923076923, 0.8157805384615381, 0.27381853846153836`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.03217915333176364], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.03217915333176364], {
             RGBColor[0.8555886153846154, 0.8876871538461538, 0.986088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.03217915333176364], {
             RGBColor[
             0.5405676923076923, 0.6378962307692307, 0.9569746153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.03217915333176364], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.03217915333176364], {
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.03217915333176364], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.03217915333176364], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.03217915333176364], {
             RGBColor[
             0.993358076923077, 0.9882019230769231, 0.5184458461538463]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.03217915333176364], {
             RGBColor[
             0.981259923076923, 0.9484474615384613, 0.38169876923076884`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.03217915333176364], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.03217915333176364], {
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.03217915333176364], {
             RGBColor[
             0.981259923076923, 0.9484474615384613, 0.38169876923076884`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.03217915333176364], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.03217915333176364], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.03217915333176364], {
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.03217915333176364], {
             RGBColor[
             0.9858981538461538, 0.9884365384615384, 0.8833676153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.03217915333176364], {
             RGBColor[
             0.9587737692307692, 0.8725963846153846, 0.2943443076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.03217915333176364], {
             RGBColor[
             0.9587737692307692, 0.8725963846153846, 0.2943443076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.03217915333176364], {
             RGBColor[
             0.9927227692307692, 0.9912586923076924, 0.7702660769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.03217915333176364], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.03217915333176364], {
             RGBColor[
             0.981259923076923, 0.9484474615384613, 0.38169876923076884`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.03217915333176364], {
             RGBColor[
             0.9858981538461538, 0.9884365384615384, 0.8833676153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.03217915333176364], {
             RGBColor[
             0.944023923076923, 0.8157805384615381, 0.27381853846153836`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.03217915333176364], {
             RGBColor[
             0.8971774615384615, 0.6259886923076922, 0.23591469230769227`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.03217915333176364], {
             RGBColor[
             0.9858981538461538, 0.9884365384615384, 0.8833676153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.03217915333176364], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.03217915333176364], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.03217915333176364], {
             RGBColor[
             0.9858981538461538, 0.9884365384615384, 0.8833676153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.03217915333176364], {
             RGBColor[0.926797846153846, 0.9444674615384614, 0.99288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.03217915333176364], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.03217915333176364], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.03217915333176364], {
             RGBColor[
             0.8830783846153846, 0.5619680769230769, 0.22415007692307692`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.03217915333176364], {
             RGBColor[0.8555886153846154, 0.8876871538461538, 0.986088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.03217915333176364], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.03217915333176364], {
             RGBColor[
             0.8299608461538462, 0.2312977692307697, 0.17632384615384622`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.03217915333176364], {
             RGBColor[
             0.8971774615384615, 0.6259886923076922, 0.23591469230769227`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.03217915333176364], {
             RGBColor[
             0.9858981538461538, 0.9884365384615384, 0.8833676153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.03217915333176364], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.03217915333176364], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.03217915333176364], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.03217915333176364], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.03217915333176364], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.03217915333176364], {
             RGBColor[
             0.9927227692307692, 0.9912586923076924, 0.7702660769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.03217915333176364], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.03217915333176364], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.03217915333176364], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.03217915333176364], {
             RGBColor[
             0.8689793076923077, 0.4979474615384617, 0.21238546153846155`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.03217915333176364], {
             RGBColor[
             0.993358076923077, 0.9882019230769231, 0.5184458461538463]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.03217915333176364], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.03217915333176364], {
             RGBColor[
             0.8971774615384615, 0.6259886923076922, 0.23591469230769227`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.03217915333176364], {
             RGBColor[
             0.993358076923077, 0.9882019230769231, 0.5184458461538463]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.03217915333176364], {
             RGBColor[0.926797846153846, 0.9444674615384614, 0.99288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.03217915333176364], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.03217915333176364], {
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.03217915333176364], {
             RGBColor[
             0.6560224615384614, 0.7312089999999999, 0.9663498461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.03217915333176364], {
             RGBColor[
             0.8971774615384615, 0.6259886923076922, 0.23591469230769227`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.03217915333176364], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.03217915333176364], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.03217915333176364], {
             RGBColor[
             0.9700168461538461, 0.9105219230769229, 0.3380215384615382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.03217915333176364], {
             RGBColor[
             0.9587737692307692, 0.8725963846153846, 0.2943443076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.03217915333176364], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.03217915333176364], {
             RGBColor[
             0.9858981538461538, 0.9884365384615384, 0.8833676153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.03217915333176364], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.03217915333176364], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.03217915333176364], {
             RGBColor[
             0.9858981538461538, 0.9884365384615384, 0.8833676153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.03217915333176364], {
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.03217915333176364], {
             RGBColor[
             0.9927227692307692, 0.9912586923076924, 0.7702660769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.03217915333176364], {
             RGBColor[0.926797846153846, 0.9444674615384614, 0.99288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.03217915333176364], {
             RGBColor[
             0.5405676923076923, 0.6378962307692307, 0.9569746153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.03217915333176364], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.03217915333176364], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.03217915333176364], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.03217915333176364], {
             RGBColor[
             0.9587737692307692, 0.8725963846153846, 0.2943443076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.03217915333176364], {
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.03217915333176364], {
             RGBColor[
             0.9927227692307692, 0.9912586923076924, 0.7702660769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.03217915333176364], {
             RGBColor[
             0.9858981538461538, 0.9884365384615384, 0.8833676153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.03217915333176364], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.03217915333176364], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.03217915333176364], {
             RGBColor[
             0.9121863846153846, 0.6895553076923078, 0.24820130769230772`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.03217915333176364], {
             RGBColor[
             0.8830783846153846, 0.5619680769230769, 0.22415007692307692`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.03217915333176364], {
             RGBColor[
             0.8830783846153846, 0.5619680769230769, 0.22415007692307692`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.03217915333176364], {
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.03217915333176364], {
             RGBColor[
             0.981259923076923, 0.9484474615384613, 0.38169876923076884`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.03217915333176364], {
             RGBColor[
             0.944023923076923, 0.8157805384615381, 0.27381853846153836`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.03217915333176364], {
             RGBColor[
             0.8426026923076924, 0.3284685384615385, 0.18842969230769233`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.03217915333176364], {
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.03217915333176364], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.03217915333176364], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.03217915333176364], {
             RGBColor[
             0.8830783846153846, 0.5619680769230769, 0.22415007692307692`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.03217915333176364], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.03217915333176364], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.03217915333176364], {
             RGBColor[
             0.9587737692307692, 0.8725963846153846, 0.2943443076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.03217915333176364], {
             RGBColor[
             0.9927227692307692, 0.9912586923076924, 0.7702660769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.03217915333176364], {
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.03217915333176364], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.03217915333176364], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.03217915333176364], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.03217915333176364], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.03217915333176364], {
             RGBColor[
             0.981259923076923, 0.9484474615384613, 0.38169876923076884`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.03217915333176364], {
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.03217915333176364], {
             RGBColor[
             0.9281051538461538, 0.752667923076923, 0.26100992307692306`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.03217915333176364], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.03217915333176364], {
             RGBColor[
             0.944023923076923, 0.8157805384615381, 0.27381853846153836`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.03217915333176364], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.03217915333176364], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.03217915333176364], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.03217915333176364], {
             RGBColor[0.926797846153846, 0.9444674615384614, 0.99288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.03217915333176364], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.03217915333176364], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.03217915333176364], {
             RGBColor[
             0.5405676923076923, 0.6378962307692307, 0.9569746153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.03217915333176364], {
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.03217915333176364], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.03217915333176364], {
             RGBColor[
             0.8971774615384615, 0.6259886923076922, 0.23591469230769227`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.03217915333176364], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.03217915333176364], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.03217915333176364], {
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.03217915333176364], {
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.03217915333176364], {
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.03217915333176364], {
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.03217915333176364], {
             RGBColor[0.926797846153846, 0.9444674615384614, 0.99288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.03217915333176364], {
             RGBColor[
             0.48240123076923075`, 0.5906740769230768, 0.9523955384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.03217915333176364], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.03217915333176364], {
             RGBColor[
             0.981259923076923, 0.9484474615384613, 0.38169876923076884`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.03217915333176364], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.03217915333176364], {
             RGBColor[
             0.9927227692307692, 0.9912586923076924, 0.7702660769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.03217915333176364], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.03217915333176364], {
             RGBColor[0.926797846153846, 0.9444674615384614, 0.99288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.03217915333176364], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.03217915333176364], {
             RGBColor[
             0.981259923076923, 0.9484474615384613, 0.38169876923076884`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.03217915333176364], {
             RGBColor[
             0.993358076923077, 0.9882019230769231, 0.5184458461538463]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.03217915333176364], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.03217915333176364], {
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.03217915333176364], {
             RGBColor[
             0.8830783846153846, 0.5619680769230769, 0.22415007692307692`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.03217915333176364], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.03217915333176364], {
             RGBColor[
             0.9281051538461538, 0.752667923076923, 0.26100992307692306`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.03217915333176364], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.03217915333176364], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.03217915333176364], {
             RGBColor[
             0.9858981538461538, 0.9884365384615384, 0.8833676153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.03217915333176364], {
             RGBColor[
             0.8689793076923077, 0.4979474615384617, 0.21238546153846155`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.03217915333176364], {
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.03217915333176364], {
             RGBColor[0.8555886153846154, 0.8876871538461538, 0.986088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.03217915333176364], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.03217915333176364], {
             RGBColor[0.8555886153846154, 0.8876871538461538, 0.986088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.03217915333176364], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.03217915333176364], {
             RGBColor[
             0.9927227692307692, 0.9912586923076924, 0.7702660769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.03217915333176364], {
             RGBColor[
             0.9587737692307692, 0.8725963846153846, 0.2943443076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.03217915333176364], {
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.03217915333176364], {
             RGBColor[
             0.9927227692307692, 0.9912586923076924, 0.7702660769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.03217915333176364], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.03217915333176364], {
             RGBColor[
             0.993358076923077, 0.9882019230769231, 0.5184458461538463]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.03217915333176364], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.03217915333176364], {
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.03217915333176364], {
             RGBColor[
             0.9700168461538461, 0.9105219230769229, 0.3380215384615382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.03217915333176364], {
             RGBColor[
             0.8830783846153846, 0.5619680769230769, 0.22415007692307692`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.03217915333176364], {
             RGBColor[
             0.9587737692307692, 0.8725963846153846, 0.2943443076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.03217915333176364], {
             RGBColor[
             0.5987341538461539, 0.6851183846153847, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.03217915333176364], {
             RGBColor[
             0.9587737692307692, 0.8725963846153846, 0.2943443076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.03217915333176364], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.03217915333176364], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.03217915333176364], {
             RGBColor[
             0.9927227692307692, 0.9912586923076924, 0.7702660769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.03217915333176364], {
             RGBColor[
             0.944023923076923, 0.8157805384615381, 0.27381853846153836`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.03217915333176364], {
             RGBColor[
             0.9281051538461538, 0.752667923076923, 0.26100992307692306`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.03217915333176364], {
             RGBColor[
             0.9700168461538461, 0.9105219230769229, 0.3380215384615382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.03217915333176364], {
             RGBColor[
             0.9858981538461538, 0.9884365384615384, 0.8833676153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.03217915333176364], {
             RGBColor[0.8555886153846154, 0.8876871538461538, 0.986088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.03217915333176364], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.03217915333176364], {
             RGBColor[
             0.8830783846153846, 0.5619680769230769, 0.22415007692307692`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.03217915333176364], {
             RGBColor[
             0.9281051538461538, 0.752667923076923, 0.26100992307692306`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.03217915333176364], {
             RGBColor[0.8555886153846154, 0.8876871538461538, 0.986088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.03217915333176364], {
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.03217915333176364], {
             RGBColor[
             0.9281051538461538, 0.752667923076923, 0.26100992307692306`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.03217915333176364], {
             RGBColor[
             0.8689793076923077, 0.4979474615384617, 0.21238546153846155`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.03217915333176364], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.03217915333176364], {
             RGBColor[0.8555886153846154, 0.8876871538461538, 0.986088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.03217915333176364], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.03217915333176364], {
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.03217915333176364], {
             RGBColor[
             0.5987341538461539, 0.6851183846153847, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.03217915333176364], {
             RGBColor[
             0.8689793076923077, 0.4979474615384617, 0.21238546153846155`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.03217915333176364], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.03217915333176364], {
             RGBColor[
             0.8830783846153846, 0.5619680769230769, 0.22415007692307692`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.03217915333176364], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.03217915333176364], {
             RGBColor[
             0.944023923076923, 0.8157805384615381, 0.27381853846153836`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.03217915333176364], {
             RGBColor[
             0.5987341538461539, 0.6851183846153847, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.03217915333176364], {
             RGBColor[
             0.981259923076923, 0.9484474615384613, 0.38169876923076884`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.03217915333176364], {
             RGBColor[
             0.8830783846153846, 0.5619680769230769, 0.22415007692307692`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.03217915333176364], {
             RGBColor[0.7106763076923076, 0.773905, 0.9717972307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.03217915333176364], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.03217915333176364], {
             RGBColor[
             0.9700168461538461, 0.9105219230769229, 0.3380215384615382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.03217915333176364], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.03217915333176364], {
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.03217915333176364], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.03217915333176364], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.03217915333176364], {
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.03217915333176364], {
             RGBColor[0.7106763076923076, 0.773905, 0.9717972307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.03217915333176364], {
             RGBColor[
             0.944023923076923, 0.8157805384615381, 0.27381853846153836`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.03217915333176364], {
             RGBColor[
             0.5987341538461539, 0.6851183846153847, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.03217915333176364], {
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.03217915333176364], {
             RGBColor[
             0.9121863846153846, 0.6895553076923078, 0.24820130769230772`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.03217915333176364], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.03217915333176364], {
             RGBColor[0.8555886153846154, 0.8876871538461538, 0.986088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.03217915333176364], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.03217915333176364], {
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.03217915333176364], {
             RGBColor[
             0.944023923076923, 0.8157805384615381, 0.27381853846153836`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.03217915333176364], {
             RGBColor[
             0.9121863846153846, 0.6895553076923078, 0.24820130769230772`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.03217915333176364], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.03217915333176364], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.03217915333176364], {
             RGBColor[0.7106763076923076, 0.773905, 0.9717972307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.03217915333176364], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.03217915333176364], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.03217915333176364], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.03217915333176364], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.03217915333176364], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.03217915333176364], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.03217915333176364], {
             RGBColor[0.926797846153846, 0.9444674615384614, 0.99288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.03217915333176364], {
             RGBColor[
             0.944023923076923, 0.8157805384615381, 0.27381853846153836`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.03217915333176364], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.03217915333176364], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.03217915333176364], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.03217915333176364], {
             RGBColor[0.926797846153846, 0.9444674615384614, 0.99288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.03217915333176364], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.03217915333176364], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.03217915333176364], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.03217915333176364], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.03217915333176364], {
             RGBColor[
             0.9858981538461538, 0.9884365384615384, 0.8833676153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.03217915333176364], {
             RGBColor[
             0.9281051538461538, 0.752667923076923, 0.26100992307692306`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.03217915333176364], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.03217915333176364], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.03217915333176364], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.03217915333176364], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.03217915333176364], {
             RGBColor[
             0.8689793076923077, 0.4979474615384617, 0.21238546153846155`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.03217915333176364], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.03217915333176364], {
             RGBColor[
             0.8689793076923077, 0.4979474615384617, 0.21238546153846155`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.03217915333176364], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.03217915333176364], {
             RGBColor[
             0.8971774615384615, 0.6259886923076922, 0.23591469230769227`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.03217915333176364], {
             RGBColor[
             0.9927227692307692, 0.9912586923076924, 0.7702660769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.03217915333176364], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.03217915333176364], {
             RGBColor[
             0.43107615384615394`, 0.5477982307692308, 0.9486887692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.03217915333176364], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.03217915333176364], {
             RGBColor[0.9767315384615384, 0.982167, 0.9242716153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.03217915333176364], {
             RGBColor[
             0.9618106153846154, 0.9710390000000001, 0.949528846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.03217915333176364], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.03217915333176364], {
             RGBColor[
             0.9587737692307692, 0.8725963846153846, 0.2943443076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.03217915333176364], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.03217915333176364], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.03217915333176364], {
             RGBColor[
             0.8971774615384615, 0.6259886923076922, 0.23591469230769227`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.03217915333176364], {
             RGBColor[
             0.43107615384615394`, 0.5477982307692308, 0.9486887692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.03217915333176364], {
             RGBColor[
             0.944023923076923, 0.8157805384615381, 0.27381853846153836`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.03217915333176364], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.03217915333176364], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.03217915333176364], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.03217915333176364], {
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.03217915333176364], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.03217915333176364], {
             RGBColor[
             0.9121863846153846, 0.6895553076923078, 0.24820130769230772`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.03217915333176364], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.03217915333176364], {
             RGBColor[
             0.981259923076923, 0.9484474615384613, 0.38169876923076884`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.03217915333176364], {
             RGBColor[
             0.981259923076923, 0.9484474615384613, 0.38169876923076884`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.03217915333176364], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.03217915333176364], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.03217915333176364], {
             RGBColor[
             0.944023923076923, 0.8157805384615381, 0.27381853846153836`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.03217915333176364], {
             RGBColor[0.7106763076923076, 0.773905, 0.9717972307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.03217915333176364], {
             RGBColor[
             0.9587737692307692, 0.8725963846153846, 0.2943443076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.03217915333176364], {
             RGBColor[
             0.9587737692307692, 0.8725963846153846, 0.2943443076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.03217915333176364], {
             RGBColor[
             0.9927227692307692, 0.9912586923076924, 0.7702660769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.03217915333176364], {
             RGBColor[
             0.9950682307692308, 0.9918597692307692, 0.7045855384615389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.03217915333176364], {
             RGBColor[
             0.9858981538461538, 0.9884365384615384, 0.8833676153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.03217915333176364], {
             RGBColor[
             0.981259923076923, 0.9484474615384613, 0.38169876923076884`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.03217915333176364], {
             RGBColor[
             0.8830783846153846, 0.5619680769230769, 0.22415007692307692`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.03217915333176364], {
             RGBColor[
             0.981259923076923, 0.9484474615384613, 0.38169876923076884`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.03217915333176364], {
             RGBColor[
             0.9700168461538461, 0.9105219230769229, 0.3380215384615382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.03217915333176364], {
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.03217915333176364], {
             RGBColor[0.819984, 0.859297, 0.982692]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.03217915333176364], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.03217915333176364], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.03217915333176364], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.826816846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.03217915333176364], {
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.03217915333176364], {
             RGBColor[
             0.6560224615384614, 0.7312089999999999, 0.9663498461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.03217915333176364], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.03217915333176364], {
             RGBColor[
             0.981259923076923, 0.9484474615384613, 0.38169876923076884`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.03217915333176364], {
             RGBColor[
             0.9927227692307692, 0.9912586923076924, 0.7702660769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.03217915333176364], {
             RGBColor[0.992503, 0.9863729999999999, 0.4253759999999998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.03217915333176364], {
             RGBColor[
             0.9927227692307692, 0.9912586923076924, 0.7702660769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.03217915333176364], {
             RGBColor[
             0.8830783846153846, 0.5619680769230769, 0.22415007692307692`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.03217915333176364], {
             RGBColor[
             0.981259923076923, 0.9484474615384613, 0.38169876923076884`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.03217915333176364], {
             RGBColor[0.926797846153846, 0.9444674615384614, 0.99288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.03217915333176364], {
             RGBColor[
             0.8971774615384615, 0.6259886923076922, 0.23591469230769227`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.03217915333176364], {
             RGBColor[0.9468896923076923, 0.959911, 0.974786076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.03217915333176364], {
             RGBColor[
             0.993358076923077, 0.9882019230769231, 0.5184458461538463]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1WVbEAYUBWBQ7G7FxG4UGzBQsRM7EEXFFhsLCzAx1qGbLuzcjE03Y2Eu
zM3cdDPWMxa6dC/PPrzn/oJzbkh8Ysz4wICAgFUi42YiM0FkISvZyE4OcpKL
3OQhL/nITwEKUojCFKEoxShOCYIpSSlKU4aylCOE8lSgIpWoTBWqUo3q1KAm
tahNKHWoSxj1qE8DGtKIxjQhnAgiaUozmtOCKFrSitZE04a2tKM9HehIJzrT
ha50ozsx9KAnvehNH/rSj/4MYCCxDCKOwQwhnqEMYzgJjGAkoxjNGMYyjvEk
MoGJTGIyU5jKNJKYzgxmMovZJDOHucxjPgtIIZU0FrKIxSxhKctIZzkrWMkq
nuBJnuJpnuFZnuN5XuBFVrOGl3iZtazjFV7lNV5nPRvYyCY2s4WtbGM7O9jJ
Lt7gTXazh73s4y3eZj8HeId3OcghDnOE93ifD/iQoxzjOCc4ySk+4mM+4VNO
c4aznOM8F/iMz7nIJS5zhatc4wu+5Do3+IqvucktbnOHb/iW7/ieH/iRn/iZ
u9zjPg/4hV/5jd95yCP+4E/+4m/+4V8ek1H+QDKRmSCykJVsZCcHOclFbvKQ
l3zkpwAFKURhilCUYhSnBMGUpBSlKUNZyhFCeSpQkUpUpgpVqUZ1alCTWtQm
lDrUJYx61KcBDWlEY5oQTgSRNKUZzWlBFC1pRWuiaUNb2tGeDnSkE53pQle6
0Z0YetCTXvSmD33pR38GMJBYBhHHYIYQz1CGMZwERjCSUYxmDGMZR8Z4JzKB
iUxiMlOYyjSSmM4MZjKL2SQzh7nMYz4LSCGVNBayiMUsYSnLSGc5K1gZ+P//
+A+Q3qse
          "], {Null, CompressedData["
1:eJxN2wucz2W+wPHn16rdrWxoc2ntsSnFoptQYTEuNY3rMEhyNxmZGTMj4zII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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[105, 155] -> 
             RGBColor[
              0.3609448647521152, 0.4866656792120809, 0.9442342850410239], 
             UndirectedEdge[1, 203] -> 
             RGBColor[
              0.32569030455946724`, 0.45491432460487713`, 0.9420324056815049],
              UndirectedEdge[187, 193] -> 
             RGBColor[
              0.8331367258093362, 0.8697846265391334, 0.9839465187292714], 
             UndirectedEdge[209, 371] -> 
             RGBColor[
              0.26203929742842424`, 0.3927502942212898, 0.9382341223849231], 
             UndirectedEdge[23, 245] -> 
             RGBColor[
              0.22165838805798918`, 0.35030739817543277`, 0.9359344893344789],
              UndirectedEdge[201, 236] -> 
             RGBColor[
              0.26347424346046877`, 0.3942585134818019, 0.9383158404386357], 
             UndirectedEdge[258, 369] -> 
             RGBColor[
              0.2551936052438994, 0.3855550376934007, 0.9378442703423086], 
             UndirectedEdge[161, 312] -> 
             RGBColor[
              0.44719691052756494`, 0.5614994937585587, 0.949788285319064], 
             UndirectedEdge[74, 132] -> 
             RGBColor[
              0.8119479189165777, 0.8530570556731545, 0.981880980170774], 
             UndirectedEdge[89, 169] -> 
             RGBColor[
              0.2196406470513075, 0.3481866244452415, 0.9358195819691286], 
             UndirectedEdge[124, 137] -> 
             RGBColor[
              0.22241368079166546`, 0.3511012587268517, 0.9359775021383063], 
             UndirectedEdge[186, 393] -> 
             RGBColor[
              0.23564383540018752`, 0.36500699006065973`, 0.9367309398710019],
              UndirectedEdge[84, 261] -> 
             RGBColor[
              0.17918769193352976`, 0.30566800375096304`, 0.9335158460199553],
              UndirectedEdge[58, 243] -> 
             RGBColor[
              0.2935914724788655, 0.42591363072274663`, 0.9400309720767858], 
             UndirectedEdge[205, 250] -> 
             RGBColor[
              0.9917478646376758, 0.990855544204543, 0.7864227690028461], 
             UndirectedEdge[327, 337] -> 
             RGBColor[
              0.3016677329619616, 0.43349195021963505`, 0.9405242352558603], 
             UndirectedEdge[38, 224] -> 
             RGBColor[
              0.970726359968221, 0.9129152797745752, 0.34077786564994345`], 
             UndirectedEdge[49, 301] -> 
             RGBColor[
              0.2562771522862687, 0.3866939143357813, 0.9379059767434073], 
             UndirectedEdge[22, 97] -> 
             RGBColor[
              0.36730142212889694`, 0.4910409193978484, 0.9446807120447999], 
             UndirectedEdge[163, 169] -> 
             RGBColor[
              0.23283585906700827`, 0.36205562889850595`, 0.936571029772856], 
             UndirectedEdge[126, 318] -> 
             RGBColor[
              0.2179296081019373, 0.3463882140233181, 0.9357221408322174], 
             UndirectedEdge[126, 149] -> 
             RGBColor[
              0.21613019133913786`, 0.3444969129160037, 0.9356196667095744], 
             UndirectedEdge[28, 47] -> 
             RGBColor[
              0.3610905157265072, 0.4852888096589335, 0.9442985989042187], 
             UndirectedEdge[203, 392] -> 
             RGBColor[
              0.26967339396164935`, 0.4007742137073859, 0.9386688728888566], 
             UndirectedEdge[116, 387] -> 
             RGBColor[
              0.35489504602512995`, 0.4804107437728069, 0.9438859559088182], 
             UndirectedEdge[114, 203] -> 
             RGBColor[
              0.3101377282501396, 0.4414434647009515, 0.9410414092716778], 
             UndirectedEdge[38, 207] -> 
             RGBColor[
              0.9528235149386215, 0.8477616286807421, 0.29603526485507003`], 
             UndirectedEdge[4, 73] -> 
             RGBColor[
              0.23765623707057423`, 0.3671221518098715, 0.9368455431690489], 
             UndirectedEdge[143, 223] -> 
             RGBColor[
              0.5393557196395969, 0.6369122967585245, 0.9568792044565808], 
             UndirectedEdge[70, 164] -> 
             RGBColor[
              0.26017432145076, 0.3907900862224582, 0.9381279147619799], 
             UndirectedEdge[291, 331] -> 
             RGBColor[
              0.5742920250264498, 0.6644126452364563, 0.9602056699966387], 
             UndirectedEdge[317, 381] -> 
             RGBColor[
              0.99188704610358, 0.9909130993174948, 0.7841161719227241], 
             UndirectedEdge[120, 349] -> 
             RGBColor[
              0.5058787275831391, 0.6095186078416714, 0.9543033325072602], 
             UndirectedEdge[102, 160] -> 
             RGBColor[
              0.8243873085977117, 0.18845711723458924`, 0.17098662029568146`],
              UndirectedEdge[84, 381] -> 
             RGBColor[
              0.5860370216699882, 0.6484140748343261, 0.8483679973313716], 
             UndirectedEdge[110, 203] -> 
             RGBColor[
              0.2734877597794271, 0.40478335402663146`, 0.9388860953793305], 
             UndirectedEdge[316, 355] -> 
             RGBColor[
              0.2426003366300466, 0.37231871392089444`, 0.937127102324821], 
             UndirectedEdge[62, 77] -> 
             RGBColor[
              0.5042166815429454, 0.5861598549701907, 0.9585479112851663], 
             UndirectedEdge[188, 361] -> 
             RGBColor[
              0.3113562197109362, 0.44025108193646334`, 0.9412013526638779], 
             UndirectedEdge[168, 282] -> 
             RGBColor[
              0.6585061316418895, 0.73314926196139, 0.9665973951785392], 
             UndirectedEdge[271, 394] -> 
             RGBColor[
              0.3328279171819992, 0.4625195049765876, 0.9424351072766638], 
             UndirectedEdge[160, 224] -> 
             RGBColor[
              0.9025695450570996, 0.5785729407895561, 0.26790552836760506`], 
             UndirectedEdge[97, 168] -> 
             RGBColor[
              0.5562174687857758, 0.6498761073301125, 0.9585804738963757], 
             UndirectedEdge[88, 132] -> 
             RGBColor[
              0.8947680641910523, 0.9166701790551881, 0.8954060764061295], 
             UndirectedEdge[329, 353] -> 
             RGBColor[
              0.22275923690238936`, 0.35146446010874544`, 0.9359971810476075],
              UndirectedEdge[189, 339] -> 
             RGBColor[
              0.333153622737486, 0.4622245787566195, 0.942476989061352], 
             UndirectedEdge[316, 380] -> 
             RGBColor[
              0.25988508585516024`, 0.3904860812728869, 0.9381114432226962], 
             UndirectedEdge[156, 295] -> 
             RGBColor[
              0.2141734445733891, 0.3424402480002911, 0.9355082328760125], 
             UndirectedEdge[154, 228] -> 
             RGBColor[
              0.39900760332101687`, 0.520022064116572, 0.9466453895484133], 
             UndirectedEdge[29, 91] -> 
             RGBColor[
              0.25152521102249714`, 0.3816993227770795, 0.9376353607183026], 
             UndirectedEdge[6, 198] -> 
             RGBColor[
              0.9099185860419527, 0.9263319020393368, 0.75030590143584], 
             UndirectedEdge[56, 254] -> 
             RGBColor[
              0.46022321075082034`, 0.5726042579779009, 0.9506674811679487], 
             UndirectedEdge[245, 315] -> 
             RGBColor[
              0.23658653725822024`, 0.3659978294842021, 0.9367846253472143], 
             UndirectedEdge[174, 281] -> 
             RGBColor[
              0.6802997161269625, 0.7500157979571946, 0.9688781332846546], 
             UndirectedEdge[89, 329] -> 
             RGBColor[
              0.22686082544463082`, 0.3557754897223749, 0.9362307604473317], 
             UndirectedEdge[260, 267] -> 
             RGBColor[
              0.6900764896095811, 0.7567221842679797, 0.9704893279445472], 
             UndirectedEdge[202, 363] -> 
             RGBColor[
              0.8594260597663401, 0.4513198993592995, 0.20428679439717456`], 
             UndirectedEdge[43, 238] -> 
             RGBColor[
              0.22832917766795519`, 0.3573188210079969, 0.9363143809342176], 
             UndirectedEdge[276, 377] -> 
             RGBColor[
              0.590222766132432, 0.6752773818608311, 0.9624624311800029], 
             UndirectedEdge[284, 369] -> 
             RGBColor[
              0.25072601947789425`, 0.3808593217920313, 0.9375898479421354], 
             UndirectedEdge[53, 249] -> 
             RGBColor[
              0.279406621010689, 0.4110044524581648, 0.9392231657702803], 
             UndirectedEdge[15, 105] -> 
             RGBColor[
              0.36060251301143975`, 0.486305845826277, 0.9442147886158565], 
             UndirectedEdge[97, 112] -> 
             RGBColor[
              0.38560280932821134`, 0.5084115053045399, 0.9457912479285857], 
             UndirectedEdge[120, 246] -> 
             RGBColor[
              0.505090585435528, 0.6088359587265868, 0.9542531127865411], 
             UndirectedEdge[53, 308] -> 
             RGBColor[
              0.27516616979901054`, 0.4065474693745552, 0.9389816783469607], 
             UndirectedEdge[188, 392] -> 
             RGBColor[
              0.25751756533120074`, 0.38799766709273437`, 0.9379766164312895],
              UndirectedEdge[91, 273] -> 
             RGBColor[
              0.26902930475390907`, 0.40009723511243644`, 0.9386321929613204],
              UndirectedEdge[327, 354] -> 
             RGBColor[
              0.2991827847858058, 0.430880112131681, 0.9403827211333795], 
             UndirectedEdge[51, 376] -> 
             RGBColor[
              0.405658343586251, 0.5257826010583926, 0.9470691688370954], 
             UndirectedEdge[202, 214] -> 
             RGBColor[
              0.9200563597791344, 0.7107376048071281, 0.556968147234525], 
             UndirectedEdge[69, 132] -> 
             RGBColor[
              0.6437204915353074, 0.7192373735289359, 0.9667380893382732], 
             UndirectedEdge[130, 387] -> 
             RGBColor[
              0.35198717062244894`, 0.47789208825307206`, 0.9437006686594926],
              UndirectedEdge[61, 306] -> 
             RGBColor[
              0.9818610097196364, 0.9499548547858537, 0.42826904779571534`], 
             UndirectedEdge[312, 356] -> 
             RGBColor[
              0.4906677898927829, 0.5973852420238213, 0.9530463122771483], 
             UndirectedEdge[18, 247] -> 
             RGBColor[
              0.926107052730001, 0.8138393200274576, 0.6108347292188259], 
             UndirectedEdge[56, 320] -> 
             RGBColor[
              0.5804145257698448, 0.6691464316920486, 0.9608367095033534], 
             UndirectedEdge[43, 124] -> 
             RGBColor[
              0.22535325774935577`, 0.3541909404893282, 0.9361449066973324], 
             UndirectedEdge[259, 318] -> 
             RGBColor[
              0.2174190793227137, 0.34585161590696, 0.9356930669735002], 
             UndirectedEdge[267, 384] -> 
             RGBColor[
              0.6598133920654725, 0.7330804224584619, 0.9674729852060762], 
             UndirectedEdge[44, 324] -> 
             RGBColor[
              0.2889570987994522, 0.4210426101494208, 0.9397670513516847], 
             UndirectedEdge[62, 204] -> 
             RGBColor[
              0.17899762953989296`, 0.30546823612459895`, 0.9335050222478098],
              UndirectedEdge[42, 109] -> 
             RGBColor[
              0.9631611562508396, 0.9703111795583055, 0.8704491819362283], 
             UndirectedEdge[8, 21] -> 
             RGBColor[
              0.3116185481608299, 0.44433005683844234`, 0.9410770362287135], 
             UndirectedEdge[48, 349] -> 
             RGBColor[
              0.43541101780241814`, 0.5515528720515495, 0.9489649829288928], 
             UndirectedEdge[222, 332] -> 
             RGBColor[
              0.5660742539559687, 0.6586036065728093, 0.9589825853511816], 
             UndirectedEdge[58, 167] -> 
             RGBColor[
              0.2911802301180382, 0.4233792621199214, 0.9398936553914501], 
             UndirectedEdge[76, 144] -> 
             RGBColor[
              0.8626912709570241, 0.4513693690163807, 0.2064327327986027], 
             UndirectedEdge[84, 90] -> 
             RGBColor[
              0.44236640792617826`, 0.5377470693075241, 0.9524063925246276], 
             UndirectedEdge[6, 166] -> 
             RGBColor[
              0.9090583234505556, 0.5897855777490221, 0.34432575904947005`], 
             UndirectedEdge[79, 343] -> 
             RGBColor[
              0.6565032648608529, 0.7307948803461315, 0.9669377087053699], 
             UndirectedEdge[142, 257] -> 
             RGBColor[
              0.822095571600614, 0.17084182242934073`, 0.16879205035911396`], 
             UndirectedEdge[175, 256] -> 
             RGBColor[
              0.20212025348377827`, 0.329771579948656, 0.9348218214745575], 
             UndirectedEdge[8, 171] -> 
             RGBColor[
              0.2917662705538139, 0.42384970493064567`, 0.9399323578314926], 
             UndirectedEdge[31, 214] -> 
             RGBColor[
              0.5834952534993698, 0.6486610383850888, 0.9230487158880236], 
             UndirectedEdge[41, 114] -> 
             RGBColor[
              0.3348490984330268, 0.46445119188281303`, 0.9425572663500889], 
             UndirectedEdge[72, 399] -> 
             RGBColor[
              0.23130276285488832`, 0.3604442475756538, 0.9364837222115884], 
             UndirectedEdge[278, 392] -> 
             RGBColor[
              0.2501824179205401, 0.3802879620889227, 0.9375588906376304], 
             UndirectedEdge[6, 323] -> 
             RGBColor[
              0.9117788938600264, 0.9278152609967583, 0.7504833392562442], 
             UndirectedEdge[132, 323] -> 
             RGBColor[
              0.8147163030891271, 0.8552644900665589, 0.9821450311245175], 
             UndirectedEdge[200, 355] -> 
             RGBColor[
              0.2507904105311417, 0.380927000871623, 0.9375935149173598], 
             UndirectedEdge[98, 215] -> 
             RGBColor[
              0.8984291495802124, 0.5426319701729883, 0.2667341084618861], 
             UndirectedEdge[12, 367] -> 
             RGBColor[
              0.21887583976336028`, 0.3473827634940262, 0.9357760273255111], 
             UndirectedEdge[88, 140] -> 
             RGBColor[
              0.8311193811821351, 0.8669473441407145, 0.8890621705145608], 
             UndirectedEdge[195, 327] -> 
             RGBColor[
              0.2821434199050674, 0.41297065928389304`, 0.9394123545109028], 
             UndirectedEdge[142, 381] -> 
             RGBColor[
              0.9073655012701238, 0.5791717949250715, 0.46576856864206445`], 
             UndirectedEdge[313, 359] -> 
             RGBColor[
              0.2641882368664749, 0.39500896582131095`, 0.9383565013068491], 
             UndirectedEdge[64, 82] -> 
             RGBColor[
              0.38908871359710695`, 0.5114308203756144, 0.9460133666661356], 
             UndirectedEdge[98, 297] -> 
             RGBColor[
              0.9621045612745434, 0.9478624391979251, 0.6712874553374975], 
             UndirectedEdge[139, 305] -> 
             RGBColor[
              0.20703664012749182`, 0.3349390140281161, 0.9351018024207747], 
             UndirectedEdge[288, 375] -> 
             RGBColor[
              0.24993566591258726`, 0.38002861008358335`, 0.9375448384758145],
              UndirectedEdge[136, 194] -> 
             RGBColor[
              0.5033185862068833, 0.6058836865205527, 0.954531849750919], 
             UndirectedEdge[254, 349] -> 
             RGBColor[
              0.45744526540329744`, 0.5701981413414695, 0.9504904729468453], 
             UndirectedEdge[348, 351] -> 
             RGBColor[
              0.2543498568494185, 0.38466820463406326`, 0.9377962201194567], 
             UndirectedEdge[65, 282] -> 
             RGBColor[
              0.5810969797016021, 0.6707307553552915, 0.9602123891284602], 
             UndirectedEdge[131, 215] -> 
             RGBColor[
              0.8708771882594211, 0.43978719004972067`, 0.21128818862239418`],
              UndirectedEdge[230, 250] -> 
             RGBColor[
              0.9785422248709081, 0.9480049704007043, 0.5891428358439234], 
             UndirectedEdge[26, 111] -> 
             RGBColor[
              0.6645955027358419, 0.5448101324102603, 0.5834436797495368], 
             UndirectedEdge[301, 390] -> 
             RGBColor[
              0.26155859013835736`, 0.392245040380827, 0.9382067468158966], 
             UndirectedEdge[3, 309] -> 
             RGBColor[
              0.32043505349243634`, 0.4484572206151509, 0.9417673069857059], 
             UndirectedEdge[90, 268] -> 
             RGBColor[
              0.7615624007787926, 0.45211356179516854`, 0.5677648921175946], 
             UndirectedEdge[17, 187] -> 
             RGBColor[
              0.6897252223294911, 0.7560947412907055, 0.9707766661911668], 
             UndirectedEdge[4, 206] -> 
             RGBColor[
              0.23187928370438585`, 0.3610502075420088, 0.9365165542210812], 
             UndirectedEdge[19, 231] -> 
             RGBColor[
              0.2915341164557601, 0.4237512190985569, 0.9399138086948555], 
             UndirectedEdge[76, 138] -> 
             RGBColor[
              0.8331436561867612, 0.2557622418600043, 0.17937170863583543`], 
             UndirectedEdge[28, 390] -> 
             RGBColor[
              0.2772941937947283, 0.40878415751856884`, 0.9391028661653874], 
             UndirectedEdge[123, 174] -> 
             RGBColor[
              0.8514507591880022, 0.8841310051490996, 0.9509891763922267], 
             UndirectedEdge[2, 98] -> 
             RGBColor[
              0.8980106482873484, 0.5394151858476, 0.26633335115120993`], 
             UndirectedEdge[20, 364] -> 
             RGBColor[
              0.37859437323609996`, 0.5023411502157933, 0.945344676578113], 
             UndirectedEdge[56, 196] -> 
             RGBColor[
              0.3744295737159023, 0.4977332530910004, 0.9451159345325955], 
             UndirectedEdge[360, 374] -> 
             RGBColor[
              0.293247724709362, 0.42540017170025574`, 0.9400169674113716], 
             UndirectedEdge[39, 360] -> 
             RGBColor[
              0.29174189371093673`, 0.42381744784571107`, 0.9399312125636886],
              UndirectedEdge[261, 264] -> 
             RGBColor[
              0.1847396920189574, 0.3115035078578844, 0.9338320242113725], 
             UndirectedEdge[101, 253] -> 
             RGBColor[
              0.3012788054166666, 0.43094522374745403`, 0.9405803668258977], 
             UndirectedEdge[141, 273] -> 
             RGBColor[
              0.31775067217972763`, 0.44656178652298995`, 0.9415805292809634],
              UndirectedEdge[171, 182] -> 
             RGBColor[
              0.2806534492526592, 0.41231494799395196`, 0.9392941707941435], 
             UndirectedEdge[156, 175] -> 
             RGBColor[
              0.18244584031582461`, 0.30909252427929373`, 0.9337013927503286],
              UndirectedEdge[121, 250] -> 
             RGBColor[
              0.7707116790518824, 0.8187741201767487, 0.9013688926659322], 
             UndirectedEdge[68, 308] -> 
             RGBColor[
              0.26890650081077455`, 0.39996816038198235`, 0.938625199458431], 
             UndirectedEdge[39, 390] -> 
             RGBColor[
              0.26969566944831447`, 0.40079762665621843`, 0.9386701414448686],
              UndirectedEdge[54, 181] -> 
             RGBColor[
              0.5096518890083631, 0.6127613709392468, 0.9545507619731439], 
             UndirectedEdge[196, 313] -> 
             RGBColor[
              0.2903662346350581, 0.4225237012570149, 0.9398472995528928], 
             UndirectedEdge[200, 241] -> 
             RGBColor[
              0.2808108014657587, 0.41248033514662596`, 0.9393031317698977], 
             UndirectedEdge[186, 255] -> 
             RGBColor[
              0.2544713249858168, 0.38479587534694254`, 0.9378031375501286], 
             UndirectedEdge[11, 38] -> 
             RGBColor[
              0.9446269367354516, 0.8152649274529434, 0.2894401056343812], 
             UndirectedEdge[173, 310] -> 
             RGBColor[
              0.20447288081658893`, 0.33224434044062834`, 0.9349558001207607],
              UndirectedEdge[106, 173] -> 
             RGBColor[
              0.5874312139478495, 0.658182594689114, 0.9541358462016971], 
             UndirectedEdge[51, 396] -> 
             RGBColor[
              0.3256114518738936, 0.4536350211799036, 0.9420717220904409], 
             UndirectedEdge[6, 18] -> 
             RGBColor[
              0.9692770544063248, 0.9734175595259907, 0.7474672305772001], 
             UndirectedEdge[238, 287] -> 
             RGBColor[
              0.24471825055354252`, 0.3745447757379873, 0.9372477143895912], 
             UndirectedEdge[93, 225] -> 
             RGBColor[
              0.25117310830966183`, 0.38132924050128825`, 0.9376153089896959],
              UndirectedEdge[116, 276] -> 
             RGBColor[
              0.5908937430052579, 0.6758585483037947, 0.9625051852330178], 
             UndirectedEdge[135, 276] -> 
             RGBColor[
              0.6344220971523353, 0.7122040883931675, 0.9656535874330512], 
             UndirectedEdge[147, 172] -> 
             RGBColor[
              0.29308124725627194`, 0.4253773516636531, 0.9400019155051696], 
             UndirectedEdge[185, 224] -> 
             RGBColor[
              0.8996759960158076, 0.5563318548969114, 0.2651346625378677], 
             UndirectedEdge[160, 166] -> 
             RGBColor[
              0.8271233428626157, 0.2094874755325008, 0.1736066497976622], 
             UndirectedEdge[63, 156] -> 
             RGBColor[
              0.5722602959769347, 0.592332243346744, 0.6137097186204522], 
             UndirectedEdge[247, 302] -> 
             RGBColor[
              0.9471422868502191, 0.8188837514344283, 0.3245541983516868], 
             UndirectedEdge[81, 240] -> 
             RGBColor[
              0.22946097871463872`, 0.3585084156683923, 0.9363788353294766], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.3163910437219365, 0.4480120932607672, 0.9413976728873965], 
             UndirectedEdge[12, 212] -> 
             RGBColor[
              0.2146670795751315, 0.34295908968538924`, 0.9355363446590942], 
             UndirectedEdge[18, 74] -> 
             RGBColor[
              0.8849400211257357, 0.9108459941170431, 0.9803872287207334], 
             UndirectedEdge[1, 7] -> 
             RGBColor[
              0.37469401379728373`, 0.4989628549076562, 0.945096149123624], 
             UndirectedEdge[231, 331] -> 
             RGBColor[
              0.38038829696430865`, 0.5038892359163952, 0.9454591932807552], 
             UndirectedEdge[58, 351] -> 
             RGBColor[
              0.27227774194596055`, 0.4035115485640963, 0.9388171866537756], 
             UndirectedEdge[142, 279] -> 
             RGBColor[
              0.8836168067234831, 0.49456770966954106`, 0.2217143859275474], 
             UndirectedEdge[303, 344] -> 
             RGBColor[
              0.3051201948561256, 0.4369324167818024, 0.9407277420647475], 
             UndirectedEdge[302, 323] -> 
             RGBColor[
              0.9087436394185031, 0.9180978599174181, 0.6943707488073377], 
             UndirectedEdge[144, 366] -> 
             RGBColor[
              0.8898592758254438, 0.5927585201905767, 0.22980821876360358`], 
             UndirectedEdge[56, 342] -> 
             RGBColor[
              0.5271466154555224, 0.626935692782203, 0.9559359367348119], 
             UndirectedEdge[137, 293] -> 
             RGBColor[
              0.2163935789679292, 0.34477375001360355`, 0.9356346662453872], 
             UndirectedEdge[39, 374] -> 
             RGBColor[
              0.2745978955714905, 0.40595017713076464`, 0.9389493159703898], 
             UndirectedEdge[4, 278] -> 
             RGBColor[
              0.24230606056995913`, 0.37200941112356267`, 0.9371103437385414],
              UndirectedEdge[238, 396] -> 
             RGBColor[
              0.25376131131834845`, 0.3840496059649667, 0.9377627033221374], 
             UndirectedEdge[118, 293] -> 
             RGBColor[
              0.20864634306607288`, 0.33663091387762584`, 0.9351934726217848],
              UndirectedEdge[201, 228] -> 
             RGBColor[
              0.3221417320475673, 0.45045653149250003`, 0.9418569760468667], 
             UndirectedEdge[212, 336] -> 
             RGBColor[
              0.21095186783418274`, 0.3390541665876225, 0.9353247688466104], 
             UndirectedEdge[186, 200] -> 
             RGBColor[
              0.2595636633022175, 0.3901482457903771, 0.9380931386838082], 
             UndirectedEdge[7, 356] -> 
             RGBColor[
              0.4538916995859768, 0.5657933672154302, 0.9506306565950378], 
             UndirectedEdge[215, 269] -> 
             RGBColor[
              0.9061735630089964, 0.5684125935804545, 0.32599457253607145`], 
             UndirectedEdge[36, 122] -> 
             RGBColor[
              0.4828824410191481, 0.5908684223901826, 0.952487665639901], 
             UndirectedEdge[297, 352] -> 
             RGBColor[
              0.970396577990795, 0.974814330666099, 0.7901511578367646], 
             UndirectedEdge[228, 243] -> 
             RGBColor[
              0.3281145647549416, 0.45673435736741674`, 0.9421971200335375], 
             UndirectedEdge[100, 271] -> 
             RGBColor[
              0.3417009842764249, 0.4702049097204598, 0.9430004912657755], 
             UndirectedEdge[157, 298] -> 
             RGBColor[
              0.6463369873520685, 0.7210185843298552, 0.9671902179184984], 
             UndirectedEdge[272, 384] -> 
             RGBColor[
              0.6977223834801167, 0.763785295951966, 0.9705061046650639], 
             UndirectedEdge[35, 114] -> 
             RGBColor[
              0.30495946572485455`, 0.43600078246607, 0.9407465148814157], 
             UndirectedEdge[15, 155] -> 
             RGBColor[
              0.30420326810120896`, 0.4370673007485326, 0.9406352981387334], 
             UndirectedEdge[36, 262] -> 
             RGBColor[
              0.7291600782306236, 0.787348496129779, 0.9720379295278863], 
             UndirectedEdge[111, 185] -> 
             RGBColor[
              0.8488843177529799, 0.35210056877181173`, 0.19347970101943163`],
              UndirectedEdge[26, 400] -> 
             RGBColor[
              0.4223618806328297, 0.5402016308185901, 0.9481469689308566], 
             UndirectedEdge[61, 131] -> 
             RGBColor[
              0.9579060415796807, 0.8592435772757068, 0.3867967672286041], 
             UndirectedEdge[168, 350] -> 
             RGBColor[
              0.5514466203488134, 0.6457438382038303, 0.9582764796526682], 
             UndirectedEdge[16, 208] -> 
             RGBColor[
              0.2374736143413805, 0.36693020374253915`, 0.9368351430747874], 
             UndirectedEdge[125, 303] -> 
             RGBColor[
              0.28379884955745593`, 0.41562096314419106`, 0.9394732966882988],
              UndirectedEdge[145, 164] -> 
             RGBColor[
              0.2402812832877892, 0.36988124182170756`, 0.9369950356677115], 
             UndirectedEdge[152, 256] -> 
             RGBColor[
              0.2044622657846265, 0.33223318336900387`, 0.9349551956103941], 
             UndirectedEdge[237, 246] -> 
             RGBColor[
              0.5111109439056949, 0.6137235569467266, 0.9547270574586124], 
             UndirectedEdge[16, 284] -> 
             RGBColor[
              0.24292930031788273`, 0.3726644756143127, 0.9371458363201851], 
             UndirectedEdge[240, 309] -> 
             RGBColor[
              0.2549984797573888, 0.3853499484354077, 0.9378331582345141], 
             UndirectedEdge[151, 249] -> 
             RGBColor[
              0.2927023996318287, 0.42432368443317114`, 0.9400043408205379], 
             UndirectedEdge[47, 311] -> 
             RGBColor[
              0.47663297852550124`, 0.5854636862286419, 0.9520871802976505], 
             UndirectedEdge[29, 190] -> 
             RGBColor[
              0.2407660977459846, 0.370390812556283, 0.937022645133887], 
             UndirectedEdge[99, 384] -> 
             RGBColor[
              0.863277719993484, 0.893302482160574, 0.9487341980321153], 
             UndirectedEdge[5, 398] -> 
             RGBColor[
              0.8904342144946242, 0.9153759950567726, 0.9860799767962038], 
             UndirectedEdge[36, 157] -> 
             RGBColor[
              0.49446056893751156`, 0.6004643909150807, 0.9533448937369567], 
             UndirectedEdge[40, 55] -> 
             RGBColor[
              0.37142239221905604`, 0.496129140733077, 0.9448876842896408], 
             UndirectedEdge[163, 319] -> 
             RGBColor[
              0.2432784612852803, 0.3730314659291315, 0.9371657205207411], 
             UndirectedEdge[13, 74] -> 
             RGBColor[
              0.8942268027978797, 0.9177720606824189, 0.9646671297303714], 
             UndirectedEdge[47, 158] -> 
             RGBColor[
              0.468503909528975, 0.5788641418068768, 0.9514472302084831], 
             UndirectedEdge[252, 330] -> 
             RGBColor[
              0.2245525377985933, 0.3533493330524997, 0.9360993068806954], 
             UndirectedEdge[102, 185] -> 
             RGBColor[
              0.8214937595564198, 0.16621603134194454`, 0.16821575446594406`],
              UndirectedEdge[41, 356] -> 
             RGBColor[
              0.4295993605310475, 0.5447525640945126, 0.9490827702313296], 
             UndirectedEdge[33, 175] -> 
             RGBColor[
              0.17893676407552545`, 0.30540426266245535`, 0.9335015560496566],
              UndirectedEdge[12, 126] -> 
             RGBColor[
              0.2152393660615204, 0.3435605990676429, 0.935568935527872], 
             UndirectedEdge[18, 191] -> 
             RGBColor[
              0.8120299641162554, 0.853850200152278, 0.9731302939895274], 
             UndirectedEdge[64, 171] -> 
             RGBColor[
              0.3360864294513485, 0.46223759897173367`, 0.9427563991656658], 
             UndirectedEdge[73, 184] -> 
             RGBColor[
              0.230439447723778, 0.35953684863551605`, 0.9364345576920319], 
             UndirectedEdge[93, 316] -> 
             RGBColor[
              0.2497588091651779, 0.37984272242869066`, 0.9375347667456857], 
             UndirectedEdge[20, 362] -> 
             RGBColor[
              0.406159003588231, 0.5262162475882044, 0.9471010704497052], 
             UndirectedEdge[32, 330] -> 
             RGBColor[
              0.2205286799485376, 0.349120003324768, 0.935870154128899], 
             UndirectedEdge[124, 277] -> 
             RGBColor[
              0.24054204876353127`, 0.3701553228701986, 0.9370098858757869], 
             UndirectedEdge[267, 331] -> 
             RGBColor[
              0.511645707636986, 0.6143827846807824, 0.9547069650679356], 
             UndirectedEdge[134, 167] -> 
             RGBColor[
              0.25893816716997997`, 0.3894908096966502, 0.9380575176044159], 
             UndirectedEdge[143, 398] -> 
             RGBColor[
              0.7820348247548993, 0.8302487551810782, 0.97550730112162], 
             UndirectedEdge[109, 320] -> 
             RGBColor[
              0.8519952349988198, 0.8825603077930796, 0.8596099472355513], 
             UndirectedEdge[28, 147] -> 
             RGBColor[
              0.2865134731880893, 0.418474204697066, 0.9396278904881377], 
             UndirectedEdge[54, 311] -> 
             RGBColor[
              0.48568276233296276`, 0.5933021541073054, 0.9526638245194523], 
             UndirectedEdge[160, 289] -> 
             RGBColor[
              0.863615444991354, 0.42809333252077686`, 0.20612813226240806`], 
             UndirectedEdge[209, 240] -> 
             RGBColor[
              0.24561974977362988`, 0.37549230857665095`, 0.9372990534365266],
              UndirectedEdge[31, 261] -> 
             RGBColor[
              0.18133289143212553`, 0.3079227444374911, 0.9336380119578622], 
             UndirectedEdge[245, 248] -> 
             RGBColor[
              0.2230533686520324, 0.3517736112266503, 0.9360139314156208], 
             UndirectedEdge[81, 245] -> 
             RGBColor[
              0.22480714766170556`, 0.3536169441618284, 0.9361138065357382], 
             UndirectedEdge[308, 386] -> 
             RGBColor[
              0.30022575986843436`, 0.4300559235597101, 0.9405124330603728], 
             UndirectedEdge[320, 349] -> 
             RGBColor[
              0.5776365804223218, 0.666740315055617, 0.9606597012822499], 
             UndirectedEdge[222, 356] -> 
             RGBColor[
              0.5616526527416191, 0.6550139515161355, 0.9586345007067291], 
             UndirectedEdge[200, 374] -> 
             RGBColor[
              0.27338169058223005`, 0.4046718685752019, 0.9388800548954654], 
             UndirectedEdge[73, 348] -> 
             RGBColor[
              0.2530355996274438, 0.3832868369650472, 0.9377213751149346], 
             UndirectedEdge[23, 81] -> 
             RGBColor[
              0.2165666874460731, 0.34495569799984427`, 0.9356445245171263], 
             UndirectedEdge[25, 233] -> 
             RGBColor[
              0.8330846738019452, 0.25530887740406205`, 0.17931522703752448`],
              UndirectedEdge[168, 170] -> 
             RGBColor[
              0.5575600626847299, 0.651038994684655, 0.958666022792408], 
             UndirectedEdge[73, 284] -> 
             RGBColor[
              0.24355703331110456`, 0.3733242627907594, 0.9371815847855014], 
             UndirectedEdge[143, 234] -> 
             RGBColor[
              0.4816918202752083, 0.5869870677287701, 0.9531992911334777], 
             UndirectedEdge[288, 374] -> 
             RGBColor[
              0.26056485892169184`, 0.3912005658659134, 0.9381501552932011], 
             UndirectedEdge[254, 344] -> 
             RGBColor[
              0.39507001975859724`, 0.5161718386350326, 0.946515977450629], 
             UndirectedEdge[6, 102] -> 
             RGBColor[
              0.9063222891856516, 0.5687552194511105, 0.3417057295474893], 
             UndirectedEdge[205, 276] -> 
             RGBColor[
              0.8804173286055655, 0.9045483902483498, 0.8526723312886473], 
             UndirectedEdge[101, 244] -> 
             RGBColor[
              0.2604390037563816, 0.39106828410749395`, 0.9381429880277227], 
             UndirectedEdge[58, 80] -> 
             RGBColor[
              0.31661369550810525`, 0.44773804311104304`, 0.9414289555561544],
              UndirectedEdge[23, 292] -> 
             RGBColor[
              0.21221830344661968`, 0.3403852707129492, 0.9353968904812151], 
             UndirectedEdge[101, 397] -> 
             RGBColor[
              0.2550956906132599, 0.3854521232084524, 0.9378386942489454], 
             UndirectedEdge[105, 168] -> 
             RGBColor[
              0.5437472998304071, 0.6390750737498879, 0.957785885757477], 
             UndirectedEdge[166, 340] -> 
             RGBColor[
              0.9092736160962124, 0.5902460669486567, 0.36775903489702405`], 
             UndirectedEdge[138, 317] -> 
             RGBColor[
              0.9049849697863369, 0.5700377324760639, 0.4855767081666582], 
             UndirectedEdge[71, 120] -> 
             RGBColor[
              0.7187491637803132, 0.7794609626924269, 0.9732879603430942], 
             UndirectedEdge[231, 290] -> 
             RGBColor[
              0.3569089205700484, 0.48355258019145775`, 0.9439631081789103], 
             UndirectedEdge[13, 224] -> 
             RGBColor[
              0.9697208187554422, 0.9510352770851425, 0.6530724790472836], 
             UndirectedEdge[40, 159] -> 
             RGBColor[
              0.33537336280871854`, 0.46490528333474357`, 0.9425906720125191],
              UndirectedEdge[20, 265] -> 
             RGBColor[
              0.49977683892029745`, 0.6035406289522859, 0.9541059564454999], 
             UndirectedEdge[43, 299] -> 
             RGBColor[
              0.22078197517346282`, 0.34938623266600927`, 0.9358845789172419],
              UndirectedEdge[219, 220] -> 
             RGBColor[
              0.4613111794873067, 0.5733857750910603, 0.9507812424766675], 
             UndirectedEdge[56, 290] -> 
             RGBColor[
              0.42803437429076585`, 0.5451635942026395, 0.9484949497272399], 
             UndirectedEdge[64, 157] -> 
             RGBColor[
              0.43410205704708005`, 0.5499866920911975, 0.9490010571312653], 
             UndirectedEdge[13, 340] -> 
             RGBColor[
              0.9787791287241259, 0.9808041152910011, 0.7551804074343922], 
             UndirectedEdge[16, 188] -> 
             RGBColor[
              0.25447321455412675`, 0.38479786140304184`, 0.9378032451582485],
              UndirectedEdge[171, 308] -> 
             RGBColor[
              0.26715048285961845`, 0.3981224741773486, 0.9385251968339084], 
             UndirectedEdge[288, 379] -> 
             RGBColor[
              0.23299167582952007`, 0.3622194021952592, 0.9365799033069708], 
             UndirectedEdge[81, 353] -> 
             RGBColor[
              0.2150475477536689, 0.34335898586410785`, 0.9355580117590097], 
             UndirectedEdge[153, 188] -> 
             RGBColor[
              0.2922583395910017, 0.4237094580639409, 0.939984452630228], 
             UndirectedEdge[148, 356] -> 
             RGBColor[
              0.5711332147381206, 0.6627106988393463, 0.9593808452755366], 
             UndirectedEdge[198, 247] -> 
             RGBColor[
              0.866748584365629, 0.7667536625408037, 0.6136734000774657], 
             UndirectedEdge[94, 375] -> 
             RGBColor[
              0.25748465436672835`, 0.3879630755823982, 0.9379747422005502], 
             UndirectedEdge[298, 307] -> 
             RGBColor[
              0.9043350538106595, 0.9251046086494896, 0.9386480207606034], 
             UndirectedEdge[9, 142] -> 
             RGBColor[
              0.8236257057163587, 0.18260310375199956`, 0.1702573085163904], 
             UndirectedEdge[203, 284] -> 
             RGBColor[
              0.26769783285159876`, 0.3986977737229138, 0.93855636760622], 
             UndirectedEdge[370, 400] -> 
             RGBColor[
              0.6104137657145253, 0.6900683539569277, 0.9649050090474223], 
             UndirectedEdge[63, 381] -> 
             RGBColor[
              0.975854040924288, 0.9316564884007599, 0.528376469194335], 
             UndirectedEdge[222, 251] -> 
             RGBColor[
              0.7136213718875605, 0.7756511419302459, 0.9724778106511085], 
             UndirectedEdge[103, 234] -> 
             RGBColor[
              0.34165277525472826`, 0.4703441947830308, 0.9429907906209125], 
             UndirectedEdge[150, 399] -> 
             RGBColor[
              0.2527398969113101, 0.3829760346617555, 0.9377045352827038], 
             UndirectedEdge[321, 338] -> 
             RGBColor[
              0.9060374188254435, 0.923886001186349, 0.8010879565228419], 
             UndirectedEdge[154, 203] -> 
             RGBColor[
              0.36077780249875213`, 0.4853053517709617, 0.9442681500235399], 
             UndirectedEdge[225, 390] -> 
             RGBColor[
              0.26170368970244295`, 0.3923975492225247, 0.9382150100214157], 
             UndirectedEdge[54, 121] -> 
             RGBColor[
              0.502593813473784, 0.607031307257596, 0.9539951244124792], 
             UndirectedEdge[234, 346] -> 
             RGBColor[
              0.34188570275875485`, 0.4705459448797419, 0.9430056325554994], 
             UndirectedEdge[358, 391] -> 
             RGBColor[
              0.8944837314108928, 0.5317010026573729, 0.24979314294089291`], 
             UndirectedEdge[74, 357] -> 
             RGBColor[
              0.7501817896070486, 0.8048048860165811, 0.9757247096384958], 
             UndirectedEdge[130, 364] -> 
             RGBColor[
              0.379967678176128, 0.5035306379305324, 0.9454321823545258], 
             UndirectedEdge[202, 381] -> 
             RGBColor[
              0.9247433274483484, 0.7127453819428937, 0.4824095946157798], 
             UndirectedEdge[98, 307] -> 
             RGBColor[
              0.9814050384421338, 0.9620825967866911, 0.6308199289588313], 
             UndirectedEdge[242, 317] -> 
             RGBColor[
              0.954486951543472, 0.8521857620679489, 0.5290777523178287], 
             UndirectedEdge[9, 279] -> 
             RGBColor[
              0.8856585389447988, 0.5102613582153388, 0.22366955100848618`], 
             UndirectedEdge[200, 399] -> 
             RGBColor[
              0.2527693356026074, 0.3830069765928298, 0.9377062117726225], 
             UndirectedEdge[275, 306] -> 
             RGBColor[
              0.9812383782660234, 0.9513676250265612, 0.559996794380909], 
             UndirectedEdge[121, 181] -> 
             RGBColor[
              0.5602542166801026, 0.6538786381225696, 0.9585244106973264], 
             UndirectedEdge[239, 271] -> 
             RGBColor[
              0.31565140111640955`, 0.4476420700773734, 0.9413406348615612], 
             UndirectedEdge[35, 354] -> 
             RGBColor[
              0.2804072432672092, 0.41205616989288285`, 0.9392801497275012], 
             UndirectedEdge[31, 310] -> 
             RGBColor[
              0.18289778193115996`, 0.30956754357176464`, 0.9337271301567341],
              UndirectedEdge[146, 154] -> 
             RGBColor[
              0.48274463326921224`, 0.5903240190384458, 0.9525963248033308], 
             UndirectedEdge[106, 107] -> 
             RGBColor[
              0.8938562482651202, 0.6317789737296462, 0.5786286100973383], 
             UndirectedEdge[265, 322] -> 
             RGBColor[
              0.5501554119867256, 0.6456799735265193, 0.9577293957987232], 
             UndirectedEdge[115, 284] -> 
             RGBColor[
              0.24130209476909242`, 0.37095417941174347`, 0.9370531693714164],
              UndirectedEdge[38, 391] -> 
             RGBColor[
              0.8930910009287811, 0.5270029957125417, 0.24438264801297166`], 
             UndirectedEdge[116, 328] -> 
             RGBColor[
              0.3628292631493686, 0.48868620423613895`, 0.944340137703926], 
             UndirectedEdge[92, 278] -> 
             RGBColor[
              0.2700397327532974, 0.4011592590046289, 0.9386897353410912], 
             UndirectedEdge[215, 217] -> 
             RGBColor[
              0.8210569332669986, 0.16285839306295227`, 0.16779744911786956`],
              UndirectedEdge[159, 210] -> 
             RGBColor[
              0.3156791522092831, 0.44703146697688845`, 0.9413656404050212], 
             UndirectedEdge[165, 298] -> 
             RGBColor[
              0.6780894534855002, 0.7467966667692734, 0.969689888365638], 
             UndirectedEdge[83, 254] -> 
             RGBColor[
              0.4111965295816905, 0.5301398109018447, 0.9475435443964437], 
             UndirectedEdge[103, 231] -> 
             RGBColor[
              0.3266251404157554, 0.4573222919288569, 0.942033452486374], 
             UndirectedEdge[245, 319] -> 
             RGBColor[
              0.2357412606353747, 0.36510939015995814`, 0.9367364880940181], 
             UndirectedEdge[58, 263] -> 
             RGBColor[
              0.28044730154374703`, 0.41209827368136553`, 0.9392824309870891],
              UndirectedEdge[206, 258] -> 
             RGBColor[
              0.24224766571092132`, 0.37194803442426605`, 0.9371070182377067],
              UndirectedEdge[213, 391] -> 
             RGBColor[
              0.8656794520004861, 0.4212316977913123, 0.20719030408487465`], 
             UndirectedEdge[78, 370] -> 
             RGBColor[
              0.8365302867115927, 0.5954450493775967, 0.5857332485541368], 
             UndirectedEdge[101, 270] -> 
             RGBColor[
              0.2552144898783262, 0.38557698876834556`, 0.937845459691343], 
             UndirectedEdge[135, 377] -> 
             RGBColor[
              0.4590787183907463, 0.5706961122538062, 0.9508478818462491], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.22879801729426974`, 0.3578116011814027, 0.9363410806573501], 
             UndirectedEdge[19, 83] -> 
             RGBColor[
              0.31363288900734776`, 0.44289778603368235`, 0.9413217134716801],
              UndirectedEdge[100, 112] -> 
             RGBColor[
              0.35276762831000186`, 0.47997132185075075`, 0.9436990192291159],
              UndirectedEdge[10, 296] -> 
             RGBColor[
              0.331723708667086, 0.46107618573568054`, 0.9423825762220581], 
             UndirectedEdge[85, 369] -> 
             RGBColor[
              0.24938070758750824`, 0.3794453136975352, 0.9375132344201885], 
             UndirectedEdge[79, 246] -> 
             RGBColor[
              0.5173044068287108, 0.618751689159956, 0.9552146295473145], 
             UndirectedEdge[227, 280] -> 
             RGBColor[
              0.23696761026347307`, 0.36639836137414694`, 0.9368063268911165],
              UndirectedEdge[112, 326] -> 
             RGBColor[
              0.3341557033790634, 0.4638506079381187, 0.9425130838303954], 
             UndirectedEdge[34, 308] -> 
             RGBColor[
              0.2866886948098787, 0.4183307981986623, 0.9396498632451982], 
             UndirectedEdge[29, 226] -> 
             RGBColor[
              0.23953161826969796`, 0.36909329635618626`, 0.936952343353961], 
             UndirectedEdge[204, 345] -> 
             RGBColor[
              0.1904371972329284, 0.3174919470804629, 0.9341564887046044], 
             UndirectedEdge[54, 265] -> 
             RGBColor[
              0.5219430916057815, 0.622739922920198, 0.9555183704657713], 
             UndirectedEdge[22, 100] -> 
             RGBColor[
              0.3344662411106874, 0.46260073594405915`, 0.9425884833453301], 
             UndirectedEdge[126, 336] -> 
             RGBColor[
              0.21152415432057162`, 0.33965567596987617`, 0.9353573597153882],
              UndirectedEdge[82, 157] -> 
             RGBColor[
              0.4242304983845992, 0.5414364441367214, 0.9483720501423687], 
             UndirectedEdge[344, 349] -> 
             RGBColor[
              0.3830038950089686, 0.5061604563464437, 0.9456256474062932], 
             UndirectedEdge[343, 349] -> 
             RGBColor[
              0.5837898565381997, 0.6715473011239714, 0.9612730023398459], 
             UndirectedEdge[2, 66] -> 
             RGBColor[
              0.8956170407292666, 0.531340985508409, 0.2570346377829214], 
             UndirectedEdge[211, 387] -> 
             RGBColor[
              0.27812297420375887`, 0.4096552582761729, 0.939150063983611], 
             UndirectedEdge[250, 265] -> 
             RGBColor[
              0.7900609571838799, 0.8344827358393506, 0.9028921387192244], 
             UndirectedEdge[217, 306] -> 
             RGBColor[
              0.8966008926384637, 0.5440937493586522, 0.25445421300955695`], 
             UndirectedEdge[374, 375] -> 
             RGBColor[
              0.26547453356081113`, 0.3963609452029792, 0.9384297540006862], 
             UndirectedEdge[38, 247] -> 
             RGBColor[
              0.9363993756149239, 0.7826453892822661, 0.2828200168311238], 
             UndirectedEdge[204, 310] -> 
             RGBColor[
              0.18075257528517846`, 0.3073127953728809, 0.9336049638117943], 
             UndirectedEdge[226, 266] -> 
             RGBColor[
              0.24681597923856835`, 0.37674962158963, 0.9373671769348919], 
             UndirectedEdge[319, 334] -> 
             RGBColor[
              0.25149135479282314`, 0.3816637377330832, 0.9376334326561084], 
             UndirectedEdge[73, 206] -> 
             RGBColor[
              0.23733902327111464`, 0.366788739994123, 0.9368274783124455], 
             UndirectedEdge[200, 255] -> 
             RGBColor[
              0.26556731627814384`, 0.3964584657216599, 0.9384350378391786], 
             UndirectedEdge[296, 383] -> 
             RGBColor[
              0.2908789334455868, 0.4230625802138626, 0.9398764969916824], 
             UndirectedEdge[235, 281] -> 
             RGBColor[
              0.6860438629162344, 0.7545031690861064, 0.9694506561545053], 
             UndirectedEdge[174, 272] -> 
             RGBColor[
              0.6878111560407678, 0.756042569748228, 0.9695182461395961], 
             UndirectedEdge[9, 131] -> 
             RGBColor[
              0.8740668087143025, 0.4643040105665355, 0.21434257277214977`], 
             UndirectedEdge[228, 361] -> 
             RGBColor[
              0.3617418491636495, 0.4877443408967252, 0.9442708486463184], 
             UndirectedEdge[149, 199] -> 
             RGBColor[
              0.2230106997449548, 0.3517287634999468, 0.9360115014844858], 
             UndirectedEdge[102, 400] -> 
             RGBColor[
              0.6044539714967849, 0.33060708272811645`, 0.5560794046708185], 
             UndirectedEdge[45, 350] -> 
             RGBColor[
              0.36412092231360993`, 0.48858020750687353`, 0.9444672858023867],
              UndirectedEdge[369, 392] -> 
             RGBColor[
              0.2527015805879449, 0.38293576177650346`, 0.937702353224772], 
             UndirectedEdge[82, 151] -> 
             RGBColor[
              0.34752633634939933`, 0.4754315781894705, 0.9433650487400788], 
             UndirectedEdge[260, 342] -> 
             RGBColor[
              0.706156116764429, 0.7697763499712335, 0.9717551750957918], 
             UndirectedEdge[296, 380] -> 
             RGBColor[
              0.28350610283773925`, 0.41531326778055483`, 0.939456625195691], 
             UndirectedEdge[105, 148] -> 
             RGBColor[
              0.520616067080279, 0.620721827134755, 0.9556738363326167], 
             UndirectedEdge[94, 288] -> 
             RGBColor[
              0.25257497972760906`, 0.38280269624533236`, 0.9376951434930652],
              UndirectedEdge[195, 258] -> 
             RGBColor[
              0.24931398381106837`, 0.3793751827779651, 0.9375094345998292], 
             UndirectedEdge[339, 374] -> 
             RGBColor[
              0.3209321143289635, 0.44937899853087393`, 0.9417809922375882], 
             UndirectedEdge[199, 367] -> 
             RGBColor[
              0.2225587298907346, 0.35125371452661747`, 0.9359857624699174], 
             UndirectedEdge[36, 298] -> 
             RGBColor[
              0.6715537144550077, 0.7414906593926315, 0.9691753710479567], 
             UndirectedEdge[147, 347] -> 
             RGBColor[
              0.28239395908436904`, 0.4141443341817761, 0.9393932902542057], 
             UndirectedEdge[38, 205] -> 
             RGBColor[
              0.9805298619657696, 0.9442896440229023, 0.524841136015259], 
             UndirectedEdge[16, 73] -> 
             RGBColor[
              0.24248824364408117`, 0.372200897085539, 0.937120718795097], 
             UndirectedEdge[108, 290] -> 
             RGBColor[
              0.3863513979794556, 0.5090598951690881, 0.945838947335492], 
             UndirectedEdge[225, 296] -> 
             RGBColor[
              0.2793148229194171, 0.41090796684390285`, 0.9392179380047856], 
             UndirectedEdge[24, 144] -> 
             RGBColor[
              0.8902955651891483, 0.5947396082931894, 0.23017226930310958`], 
             UndirectedEdge[209, 319] -> 
             RGBColor[
              0.24680833108244982`, 0.37674158289262827`, 0.9373667413837155],
              UndirectedEdge[80, 192] -> 
             RGBColor[
              0.3394530711598287, 0.46843892165637124`, 0.9428506274211075], 
             UndirectedEdge[42, 221] -> 
             RGBColor[
              0.9270423893059134, 0.944662453609973, 0.9929033247441504], 
             UndirectedEdge[22, 365] -> 
             RGBColor[
              0.27427955709376345`, 0.40561558320684826`, 0.9389311870650228],
              UndirectedEdge[80, 201] -> 
             RGBColor[
              0.30542134246892777`, 0.4359741704306982, 0.9407915676081757], 
             UndirectedEdge[39, 375] -> 
             RGBColor[
              0.2639687025623859, 0.39477822134843454`, 0.9383439991530031], 
             UndirectedEdge[15, 326] -> 
             RGBColor[
              0.3216255760176605, 0.45254598204008034`, 0.9417312126565649], 
             UndirectedEdge[86, 95] -> 
             RGBColor[
              0.2911574427094625, 0.42335531110870317`, 0.9398923576822427], 
             UndirectedEdge[59, 194] -> 
             RGBColor[
              0.3610366257463029, 0.4871335118181791, 0.9442259124337696], 
             UndirectedEdge[296, 324] -> 
             RGBColor[
              0.2907395975741168, 0.42291612937854317`, 0.9398685620199312], 
             UndirectedEdge[169, 245] -> 
             RGBColor[
              0.22529865841710267`, 0.3541335531293326, 0.936141797346133], 
             UndirectedEdge[258, 284] -> 
             RGBColor[
              0.24846567575091127`, 0.3784835572209025, 0.9374611247107626], 
             UndirectedEdge[33, 152] -> 
             RGBColor[
              0.18127877637637368`, 0.30786586608280325`, 0.9336349301854932],
              UndirectedEdge[246, 349] -> 
             RGBColor[
              0.44459099850605766`, 0.559504109937796, 0.9495499231817904], 
             UndirectedEdge[27, 395] -> 
             RGBColor[
              0.28524240829505776`, 0.41713823490432095`, 0.9395555052228516],
              UndirectedEdge[185, 340] -> 
             RGBColor[
              0.9087343059844912, 0.5861006931027701, 0.36724259092497624`], 
             UndirectedEdge[223, 321] -> 
             RGBColor[
              0.6359268279774656, 0.7126257479828174, 0.9663189746381065], 
             UndirectedEdge[274, 373] -> 
             RGBColor[
              0.24052488712014738`, 0.3701372848948911, 0.9370089085455846], 
             UndirectedEdge[156, 214] -> 
             RGBColor[
              0.5848663164286375, 0.6501021124541597, 0.9231267958935396], 
             UndirectedEdge[205, 221] -> 
             RGBColor[
              0.9585637141169614, 0.9664203575638242, 0.8602427231177231], 
             UndirectedEdge[97, 105] -> 
             RGBColor[
              0.42981427861771465`, 0.5467052578700499, 0.9486083636570456], 
             UndirectedEdge[130, 158] -> 
             RGBColor[
              0.4567607455909806, 0.5686928034323673, 0.9506989661864262], 
             UndirectedEdge[108, 143] -> 
             RGBColor[
              0.49610666284564264`, 0.5994724798522266, 0.954117792155521], 
             UndirectedEdge[176, 399] -> 
             RGBColor[
              0.22535125221155355`, 0.3541888325419396, 0.9361447924849214], 
             UndirectedEdge[150, 189] -> 
             RGBColor[
              0.28557376029945525`, 0.4174865068698732, 0.9395743752293106], 
             UndirectedEdge[253, 386] -> 
             RGBColor[
              0.3405394596215219, 0.4693798967384182, 0.942919851133231], 
             UndirectedEdge[46, 59] -> 
             RGBColor[
              0.30916725287120805`, 0.4399481765928165, 0.9410035436196971], 
             UndirectedEdge[186, 241] -> 
             RGBColor[
              0.2697148101734317, 0.4008177447719086, 0.9386712314808479], 
             UndirectedEdge[39, 93] -> 
             RGBColor[
              0.2591650880555334, 0.38972931793498194`, 0.9380704404131488], 
             UndirectedEdge[214, 264] -> 
             RGBColor[
              0.5869020540862017, 0.6522418018054821, 0.9232427281415339], 
             UndirectedEdge[234, 290] -> 
             RGBColor[
              0.37193655540902126`, 0.4965744830456317, 0.9449204463134487], 
             UndirectedEdge[148, 170] -> 
             RGBColor[
              0.5344288299346016, 0.632685748069522, 0.9565539733675475], 
             UndirectedEdge[50, 362] -> 
             RGBColor[
              0.4294033294821849, 0.5463267879239184, 0.948588402469489], 
             UndirectedEdge[271, 326] -> 
             RGBColor[
              0.3230890593454866, 0.4540841958078278, 0.941814555867055], 
             UndirectedEdge[61, 352] -> 
             RGBColor[
              0.9937500196167237, 0.9890402488671484, 0.5611063895673631], 
             UndirectedEdge[256, 333] -> 
             RGBColor[
              0.21043441051870343`, 0.338510286140365, 0.9352953004180034], 
             UndirectedEdge[100, 394] -> 
             RGBColor[
              0.3677410184422385, 0.49294051979882375`, 0.944653110407893], 
             UndirectedEdge[1, 114] -> 
             RGBColor[
              0.3444304570913155, 0.4727500831795342, 0.9431677820513322], 
             UndirectedEdge[218, 269] -> 
             RGBColor[
              0.9515613514707596, 0.9593431212476458, 0.7385846645144882], 
             UndirectedEdge[182, 253] -> 
             RGBColor[
              0.31490504522225604`, 0.4452672657366318, 0.9413563610246107], 
             UndirectedEdge[57, 354] -> 
             RGBColor[
              0.27649042962059545`, 0.4079393504099632, 0.939057092984733], 
             UndirectedEdge[40, 192] -> 
             RGBColor[
              0.34190093761815415`, 0.4705591405492272, 0.9430066033072686], 
             UndirectedEdge[262, 314] -> 
             RGBColor[
              0.9322274207027686, 0.9487209428474576, 0.9907658897447179], 
             UndirectedEdge[244, 253] -> 
             RGBColor[
              0.30087597692201773`, 0.4305218254587764, 0.9405574263390588], 
             UndirectedEdge[277, 330] -> 
             RGBColor[
              0.24129239010618297`, 0.3709439791957144, 0.9370526167052204], 
             UndirectedEdge[304, 329] -> 
             RGBColor[
              0.2271186296842969, 0.35604645832399684`, 0.9362454420173936], 
             UndirectedEdge[103, 223] -> 
             RGBColor[
              0.3993166746191169, 0.5202694238127852, 0.9466707039440156], 
             UndirectedEdge[92, 337] -> 
             RGBColor[
              0.2862035870447653, 0.41814849471251614`, 0.9396102429307109], 
             UndirectedEdge[226, 341] -> 
             RGBColor[
              0.23010886985563692`, 0.3591893903362524, 0.9364157317714874], 
             UndirectedEdge[193, 260] -> 
             RGBColor[
              0.8156468227717713, 0.8559278037169716, 0.9822546582008858], 
             UndirectedEdge[9, 214] -> 
             RGBColor[
              0.9047202658222255, 0.5928576663351037, 0.5422822863417485], 
             UndirectedEdge[8, 157] -> 
             RGBColor[
              0.38978189814954545`, 0.5115987980501094, 0.9461770157970921], 
             UndirectedEdge[103, 342] -> 
             RGBColor[
              0.4739621782432806, 0.580870006396498, 0.9525470714247991], 
             UndirectedEdge[165, 314] -> 
             RGBColor[
              0.7292803775430885, 0.7876149200721775, 0.9745725244009281], 
             UndirectedEdge[115, 392] -> 
             RGBColor[
              0.24327765587914302`, 0.37303061939621557`, 0.937165674654053], 
             UndirectedEdge[104, 233] -> 
             RGBColor[
              0.8756661600168449, 0.4553685127100845, 0.21500153588103987`], 
             UndirectedEdge[67, 139] -> 
             RGBColor[
              0.21205827028800195`, 0.34021706571655375`, 0.9353877768295796],
              UndirectedEdge[116, 364] -> 
             RGBColor[
              0.382875553578809, 0.5060492934502673, 0.9456174696038513], 
             UndirectedEdge[74, 220] -> 
             RGBColor[
              0.6500539956476187, 0.724027222159205, 0.9674931897567542], 
             UndirectedEdge[100, 168] -> 
             RGBColor[
              0.5233822877675662, 0.6214359238763232, 0.9564882451969059], 
             UndirectedEdge[129, 308] -> 
             RGBColor[
              0.2493864248848615, 0.3794513229395511, 0.9375135600118147], 
             UndirectedEdge[26, 185] -> 
             RGBColor[
              0.6394016686924645, 0.37581057943241813`, 0.5602833187259821], 
             UndirectedEdge[197, 215] -> 
             RGBColor[
              0.9040198154602492, 0.5694397771754294, 0.5010925431304881], 
             UndirectedEdge[178, 240] -> 
             RGBColor[
              0.24159747707370743`, 0.3712646449422136, 0.9370699909566852], 
             UndirectedEdge[52, 223] -> 
             RGBColor[
              0.42035633884682855`, 0.5384929234825571, 0.9480113327439608], 
             UndirectedEdge[192, 243] -> 
             RGBColor[
              0.31643084813058897`, 0.44661450926807483`, 0.9414526439417388],
              UndirectedEdge[124, 252] -> 
             RGBColor[
              0.22380219645594157`, 0.3525606767269839, 0.936056576051262], 
             UndirectedEdge[194, 396] -> 
             RGBColor[
              0.3331772870037427, 0.4601881672994485, 0.9425538104147095], 
             UndirectedEdge[269, 279] -> 
             RGBColor[
              0.9693542844710024, 0.9048940200148108, 0.380506034096984], 
             UndirectedEdge[57, 208] -> 
             RGBColor[
              0.2531470707031978, 0.383404000133339, 0.9377277232277921], 
             UndirectedEdge[169, 304] -> 
             RGBColor[
              0.21989845129097363`, 0.3484575930468634, 0.9358342635391905], 
             UndirectedEdge[209, 280] -> 
             RGBColor[
              0.24552309910713999`, 0.37539072259816386`, 0.9372935493240518],
              UndirectedEdge[226, 399] -> 
             RGBColor[
              0.23675652181007376`, 0.36617649402584324`, 0.9367943057159729],
              UndirectedEdge[206, 392] -> 
             RGBColor[
              0.23975564105496683`, 0.3693287585073688, 0.9369651011201702], 
             UndirectedEdge[48, 343] -> 
             RGBColor[
              0.5738217336869491, 0.6629134141226403, 0.9606378423662292], 
             UndirectedEdge[159, 263] -> 
             RGBColor[
              0.29675910238603487`, 0.4271452950122101, 0.9402881715572926], 
             UndirectedEdge[261, 295] -> 
             RGBColor[
              0.2109178597842839, 0.3390184219709439, 0.935322832138479], 
             UndirectedEdge[33, 204] -> 
             RGBColor[
              0.1789341933349501, 0.3054015606511163, 0.9335014096497838], 
             UndirectedEdge[64, 151] -> 
             RGBColor[
              0.35739789501188024`, 0.48398182614394664`, 0.9439940557289754],
              UndirectedEdge[210, 263] -> 
             RGBColor[
              0.2810036601000736, 0.41268304179923465`, 0.9393141147838132], 
             UndirectedEdge[19, 303] -> 
             RGBColor[
              0.2819979246761117, 0.4137280769086658, 0.939370736680536], 
             UndirectedEdge[248, 315] -> 
             RGBColor[
              0.229741057636631, 0.35880279637343554`, 0.9363947854097444], 
             UndirectedEdge[236, 351] -> 
             RGBColor[
              0.2481333456349381, 0.37813425719806837`, 0.9374421990022963], 
             UndirectedEdge[53, 386] -> 
             RGBColor[
              0.3143035505913172, 0.444852574192945, 0.9413141424158159], 
             UndirectedEdge[93, 301] -> 
             RGBColor[
              0.25102800874557624`, 0.38117673165959054`, 0.9376070457841768],
              UndirectedEdge[37, 159] -> 
             RGBColor[
              0.29061706023566036`, 0.4206896192842019, 0.9399383913431659], 
             UndirectedEdge[148, 326] -> 
             RGBColor[
              0.4816391300864997, 0.5869619633485583, 0.9531902603733251], 
             UndirectedEdge[13, 357] -> 
             RGBColor[
              0.8197351159980406, 0.8595406855045937, 0.9572525529228332], 
             UndirectedEdge[162, 231] -> 
             RGBColor[
              0.27738405997012383`, 0.4088786125667542, 0.9391079839111312], 
             UndirectedEdge[33, 84] -> 
             RGBColor[
              0.17893420048233583`, 0.30540156816347186`, 0.9335014100568169],
              UndirectedEdge[199, 293] -> 
             RGBColor[
              0.21851691429369074`, 0.3470055100682143, 0.9357555870509962], 
             UndirectedEdge[96, 167] -> 
             RGBColor[
              0.28523047788544853`, 0.41712569528738996`, 0.9395548258036737],
              UndirectedEdge[131, 307] -> 
             RGBColor[
              0.9538530771213425, 0.8592378166634234, 0.5753740091193393], 
             UndirectedEdge[174, 291] -> 
             RGBColor[
              0.7125484820155874, 0.7753675568103979, 0.9719838316093115], 
             UndirectedEdge[207, 250] -> 
             RGBColor[
              0.9640415176105277, 0.8943275288623829, 0.5576168978426572], 
             UndirectedEdge[364, 387] -> 
             RGBColor[
              0.3215492584874442, 0.4515282986156772, 0.941761191813439], 
             UndirectedEdge[103, 346] -> 
             RGBColor[
              0.3447990844282577, 0.4730693696510448, 0.9431912706592778], 
             UndirectedEdge[31, 106] -> 
             RGBColor[
              0.5658561150624204, 0.6355057978202503, 0.9529071762376704], 
             UndirectedEdge[128, 316] -> 
             RGBColor[
              0.29024632988181515`, 0.4207827161213608, 0.9398996026647567], 
             UndirectedEdge[185, 289] -> 
             RGBColor[
              0.8607218959500621, 0.40585224662813213`, 0.20335726643267069`],
              UndirectedEdge[20, 172] -> 
             RGBColor[
              0.3545418209166673, 0.4808311305362721, 0.9438368541227812], 
             UndirectedEdge[70, 234] -> 
             RGBColor[
              0.30827476436067847`, 0.438573607296341, 0.9409687003893238], 
             UndirectedEdge[119, 383] -> 
             RGBColor[
              0.2603673467577916, 0.3909929680586598, 0.93813890726766], 
             UndirectedEdge[158, 181] -> 
             RGBColor[
              0.5352140965427551, 0.633549940550514, 0.9565531607151321], 
             UndirectedEdge[20, 54] -> 
             RGBColor[
              0.4298252331165606, 0.5467147461063611, 0.9486090616680254], 
             UndirectedEdge[229, 334] -> 
             RGBColor[
              0.25414759898597045`, 0.3844556187956901, 0.9377847018333471], 
             UndirectedEdge[63, 142] -> 
             RGBColor[
              0.890072513149207, 0.5193941486818902, 0.23091004398772222`], 
             UndirectedEdge[230, 358] -> 
             RGBColor[
              0.9687169526811137, 0.9061370771638947, 0.3329716977842575], 
             UndirectedEdge[119, 296] -> 
             RGBColor[
              0.27100995406971695`, 0.4021790231237703, 0.9387449880097476], 
             UndirectedEdge[218, 262] -> 
             RGBColor[
              0.9243533171861171, 0.9424423464401257, 0.9900148507220045], 
             UndirectedEdge[100, 170] -> 
             RGBColor[
              0.4107918604538279, 0.5302289953510277, 0.9473962719925066], 
             UndirectedEdge[97, 357] -> 
             RGBColor[
              0.5589872751901463, 0.652039901144515, 0.958856542313451], 
             UndirectedEdge[375, 399] -> 
             RGBColor[
              0.24486217858118842`, 0.3746960532206071, 0.9372559108778432], 
             UndirectedEdge[199, 252] -> 
             RGBColor[
              0.2250679449332263, 0.3538910586296987, 0.9361286585545363], 
             UndirectedEdge[175, 345] -> 
             RGBColor[
              0.1904397679735038, 0.31749464909180203`, 0.9341566351044772], 
             UndirectedEdge[176, 186] -> 
             RGBColor[
              0.23214557991116364`, 0.36133010173948693`, 0.9365317193961071],
              UndirectedEdge[309, 371] -> 
             RGBColor[
              0.2714180274121831, 0.4026079340800466, 0.9387682271829105], 
             UndirectedEdge[326, 354] -> 
             RGBColor[
              0.3095818357707423, 0.4398872474233331, 0.94104533946662], 
             UndirectedEdge[38, 289] -> 
             RGBColor[
              0.9317722599024755, 0.7624356715057958, 0.27900046954474644`], 
             UndirectedEdge[120, 237] -> 
             RGBColor[
              0.5723986729827764, 0.663738054850602, 0.9594804667840822], 
             UndirectedEdge[275, 384] -> 
             RGBColor[
              0.8702642398197578, 0.8971991046411623, 0.8780681531351799], 
             UndirectedEdge[216, 220] -> 
             RGBColor[
              0.5672680445778805, 0.6593163046949915, 0.9592519182010989], 
             UndirectedEdge[50, 276] -> 
             RGBColor[
              0.6098568885565028, 0.6922609454050347, 0.9637197242270632], 
             UndirectedEdge[143, 321] -> 
             RGBColor[
              0.7212153553030598, 0.7818668166701053, 0.973033199931347], 
             UndirectedEdge[225, 316] -> 
             RGBColor[
              0.2556938059368381, 0.38608078033623494`, 0.9378727560317908], 
             UndirectedEdge[40, 332] -> 
             RGBColor[
              0.43326686926446056`, 0.5476890621459892, 0.9493828047697146], 
             UndirectedEdge[254, 343] -> 
             RGBColor[
              0.5958559812878284, 0.6815586834125604, 0.9621633323841816], 
             UndirectedEdge[37, 167] -> 
             RGBColor[
              0.26667449670074206`, 0.39762218254510395`, 0.9384980901263189],
              UndirectedEdge[26, 204] -> 
             RGBColor[
              0.3170199268376633, 0.4369570715354334, 0.9418741487280438], 
             UndirectedEdge[141, 189] -> 
             RGBColor[
              0.33030534537683665`, 0.4597575440654077, 0.9422954993465642], 
             UndirectedEdge[55, 210] -> 
             RGBColor[
              0.3517281816196206, 0.4782553243752219, 0.9436626526821428], 
             UndirectedEdge[41, 312] -> 
             RGBColor[
              0.40188874544580117`, 0.5222558384193261, 0.9469012891044913], 
             UndirectedEdge[102, 247] -> 
             RGBColor[
              0.8631522875093278, 0.40917697995257735`, 0.2050732281891151], 
             UndirectedEdge[30, 400] -> 
             RGBColor[
              0.284268969836752, 0.4086385761438802, 0.9397738211163575], 
             UndirectedEdge[57, 195] -> 
             RGBColor[
              0.25945106473985713`, 0.3900298975621752, 0.9380867263622563], 
             UndirectedEdge[301, 324] -> 
             RGBColor[
              0.2683877801719362, 0.39942295210177514`, 0.9385956590854276], 
             UndirectedEdge[290, 331] -> 
             RGBColor[
              0.42861309362707734`, 0.5456648518044729, 0.9485318252116084], 
             UndirectedEdge[49, 347] -> 
             RGBColor[
              0.2678932418389194, 0.3989031609582332, 0.9385674958589661], 
             UndirectedEdge[92, 258] -> 
             RGBColor[
              0.2702985516937192, 0.40143129412108086`, 0.93870447469686], 
             UndirectedEdge[234, 313] -> 
             RGBColor[
              0.3107738733861259, 0.4412003293347502, 0.9411110209512226], 
             UndirectedEdge[376, 377] -> 
             RGBColor[
              0.4266363429774569, 0.5439526897461481, 0.9484058684081864], 
             UndirectedEdge[223, 272] -> 
             RGBColor[
              0.5505420601979628, 0.6459225184451997, 0.9578086189518668], 
             UndirectedEdge[213, 302] -> 
             RGBColor[
              0.9491225739214294, 0.8267349297802298, 0.3261475838124945], 
             UndirectedEdge[121, 158] -> 
             RGBColor[
              0.5281560210081759, 0.6278198768688632, 0.9559975231544674], 
             UndirectedEdge[240, 248] -> 
             RGBColor[
              0.22770719970496556`, 0.3566650827332143, 0.9362789602093593], 
             UndirectedEdge[18, 132] -> 
             RGBColor[
              0.8722144636354254, 0.9008667885957915, 0.9791289224454733], 
             UndirectedEdge[59, 79] -> 
             RGBColor[
              0.46241207497172554`, 0.5712067102742551, 0.9517169387007705], 
             UndirectedEdge[109, 207] -> 
             RGBColor[
              0.9669761340347394, 0.8955410681699965, 0.508982709149612], 
             UndirectedEdge[190, 365] -> 
             RGBColor[
              0.24867185173243342`, 0.3787002612497945, 0.9374728661279003], 
             UndirectedEdge[78, 391] -> 
             RGBColor[
              0.8311173699138001, 0.24018731764171894`, 0.1774313346124849], 
             UndirectedEdge[159, 236] -> 
             RGBColor[
              0.2909783973419341, 0.4210694074929913, 0.9399589689568179], 
             UndirectedEdge[95, 334] -> 
             RGBColor[
              0.27158878350233817`, 0.4027874095573609, 0.9387779514896339], 
             UndirectedEdge[20, 147] -> 
             RGBColor[
              0.34619840677068126`, 0.47206167326583015`, 0.9433617090301424],
              UndirectedEdge[229, 388] -> 
             RGBColor[
              0.23513063549537086`, 0.3644675844219441, 0.9367017138956337], 
             UndirectedEdge[15, 271] -> 
             RGBColor[
              0.3053243996883596, 0.43824568113047624`, 0.940699144924056], 
             UndirectedEdge[53, 151] -> 
             RGBColor[
              0.302539739143033, 0.43466335198279643`, 0.9405645627526612], 
             UndirectedEdge[178, 309] -> 
             RGBColor[
              0.2573894464516083, 0.38786300602707646`, 0.9379693202506316], 
             UndirectedEdge[309, 386] -> 
             RGBColor[
              0.30507679489801537`, 0.4351546689491852, 0.9407886923288442], 
             UndirectedEdge[199, 299] -> 
             RGBColor[
              0.21996573354153404`, 0.3485283109581435, 0.9358380951638248], 
             UndirectedEdge[33, 90] -> 
             RGBColor[
              0.44237359411374266`, 0.5377546224462848, 0.9524068017673784], 
             UndirectedEdge[191, 216] -> 
             RGBColor[
              0.6689774683276695, 0.7413295497654275, 0.9676410801591727], 
             UndirectedEdge[188, 203] -> 
             RGBColor[
              0.2792417470878428, 0.4108311595116429, 0.9392137764442834], 
             UndirectedEdge[87, 263] -> 
             RGBColor[
              0.2761111635451054, 0.407540717717765, 0.9390354943428079], 
             UndirectedEdge[25, 76] -> 
             RGBColor[
              0.8478277754462535, 0.3686308171105509, 0.1934332378220659], 
             UndirectedEdge[329, 334] -> 
             RGBColor[
              0.2482689309678744, 0.37827676597959103`, 0.9374499203864265], 
             UndirectedEdge[42, 376] -> 
             RGBColor[
              0.6853095806395425, 0.7514657941798157, 0.9712763701432583], 
             UndirectedEdge[54, 130] -> 
             RGBColor[
              0.43119853805658864`, 0.5479042338211002, 0.9486965674444381], 
             UndirectedEdge[90, 256] -> 
             RGBColor[
              0.46555708352199543`, 0.5621219397324855, 0.9537270671922793], 
             UndirectedEdge[160, 302] -> 
             RGBColor[
              0.9083773079386029, 0.59816388871644, 0.2904675904582531], 
             UndirectedEdge[299, 367] -> 
             RGBColor[
              0.21672169883755696`, 0.34511862480058364`, 0.9356533521865525],
              UndirectedEdge[16, 96] -> 
             RGBColor[
              0.2643859994981743, 0.3952168268861021, 0.9383677635961609], 
             UndirectedEdge[5, 223] -> 
             RGBColor[
              0.6477551093793219, 0.7220395366342189, 0.9674518801311646], 
             UndirectedEdge[40, 228] -> 
             RGBColor[
              0.35358465424250685`, 0.48067898864856917`, 0.9437510793990673],
              UndirectedEdge[154, 222] -> 
             RGBColor[
              0.5175424648922109, 0.6185744663744461, 0.9553357375773506], 
             UndirectedEdge[85, 188] -> 
             RGBColor[
              0.25419669233076414`, 0.38450721901376617`, 0.937787497626706], 
             UndirectedEdge[281, 384] -> 
             RGBColor[
              0.6902109435663115, 0.7577585241609326, 0.9698659918101223], 
             UndirectedEdge[249, 334] -> 
             RGBColor[
              0.2654841590440016, 0.39637106219610324`, 0.9384303021577143], 
             UndirectedEdge[203, 243] -> 
             RGBColor[
              0.28988476393267687`, 0.4220176450218065, 0.9398198805086642], 
             UndirectedEdge[49, 147] -> 
             RGBColor[
              0.2702371158648362, 0.4013667211696683, 0.9387009760172913], 
             UndirectedEdge[99, 232] -> 
             RGBColor[
              0.7518421224806613, 0.804458883314896, 0.9388506680687247], 
             UndirectedEdge[84, 389] -> 
             RGBColor[
              0.1790075704625178, 0.3054786846645686, 0.933505588368647], 
             UndirectedEdge[76, 242] -> 
             RGBColor[
              0.8826456379438963, 0.5379102714518893, 0.22287275278700588`], 
             UndirectedEdge[129, 397] -> 
             RGBColor[
              0.24351700983454236`, 0.3732821955792575, 0.9371793055077206], 
             UndirectedEdge[177, 390] -> 
             RGBColor[
              0.2941038875347629, 0.4252352483079229, 0.9401047123377103], 
             UndirectedEdge[138, 144] -> 
             RGBColor[
              0.8488904911809813, 0.34529052811745564`, 0.1932170904993126], 
             UndirectedEdge[184, 325] -> 
             RGBColor[
              0.2146653182782982, 0.3429572384507447, 0.9355362443558451], 
             UndirectedEdge[69, 140] -> 
             RGBColor[
              0.5800718085263902, 0.6695145386144623, 0.9603941834467046], 
             UndirectedEdge[247, 391] -> 
             RGBColor[
              0.8636991649292758, 0.4133805194455108, 0.20559691862406698`], 
             UndirectedEdge[14, 391] -> 
             RGBColor[
              0.9073739340103057, 0.5740384053828973, 0.3971702369213773], 
             UndirectedEdge[229, 240] -> 
             RGBColor[
              0.24305133588145522`, 0.372792742729129, 0.9371527860649951], 
             UndirectedEdge[166, 400] -> 
             RGBColor[
              0.6071900057616888, 0.351637441026028, 0.5586994341727993], 
             UndirectedEdge[281, 386] -> 
             RGBColor[
              0.4856785944575267, 0.5902406468075978, 0.9535084650798691], 
             UndirectedEdge[150, 255] -> 
             RGBColor[
              0.26553787758684655`, 0.39642752379058566`, 0.9384333613492598],
              UndirectedEdge[103, 290] -> 
             RGBColor[
              0.3748499370785241, 0.4990979078169345, 0.9451060844172272], 
             UndirectedEdge[212, 299] -> 
             RGBColor[
              0.2125129386493282, 0.3406949509919467, 0.9354136695201356], 
             UndirectedEdge[206, 208] -> 
             RGBColor[
              0.23232439396841398`, 0.3615180466511231, 0.9365419025921359], 
             UndirectedEdge[75, 169] -> 
             RGBColor[
              0.2324382955275915, 0.3616377644115946, 0.9365483891174288], 
             UndirectedEdge[110, 167] -> 
             RGBColor[
              0.26956370563298526`, 0.40065892431931827`, 0.9386626263008084],
              UndirectedEdge[33, 214] -> 
             RGBColor[
              0.5813572401883383, 0.6464138508373214, 0.9229269591928677], 
             UndirectedEdge[98, 107] -> 
             RGBColor[
              0.9083938909149378, 0.6192253386491839, 0.2762763560175848], 
             UndirectedEdge[238, 252] -> 
             RGBColor[
              0.22677811637454098`, 0.3556885572456525, 0.9362260502881472], 
             UndirectedEdge[91, 241] -> 
             RGBColor[
              0.2767915804260243, 0.40825587900053273`, 0.9390742430775896], 
             UndirectedEdge[74, 219] -> 
             RGBColor[
              0.6359306602465759, 0.7123948141262615, 0.9664273391659474], 
             UndirectedEdge[45, 180] -> 
             RGBColor[
              0.33088455801292704`, 0.4597925392578639, 0.9423494940589101], 
             UndirectedEdge[187, 235] -> 
             RGBColor[
              0.792013758809907, 0.8376400126416226, 0.9798528182009743], 
             UndirectedEdge[114, 188] -> 
             RGBColor[0.297981899619691, 0.4286669180863, 0.9403491528141107],
              UndirectedEdge[81, 378] -> 
             RGBColor[
              0.21412094136701804`, 0.3423850638014996, 0.9355052428960813], 
             UndirectedEdge[19, 313] -> 
             RGBColor[
              0.27859623109563336`, 0.41015268127575305`, 0.9391770152634824],
              UndirectedEdge[195, 284] -> 
             RGBColor[
              0.24484639804506322`, 0.3746794668765958, 0.9372550121996561], 
             UndirectedEdge[64, 253] -> 
             RGBColor[
              0.3703380254209453, 0.4951899167144135, 0.9448185893961331], 
             UndirectedEdge[55, 122] -> 
             RGBColor[
              0.4248101196568824, 0.5423709068945195, 0.9482895030730654], 
             UndirectedEdge[99, 275] -> 
             RGBColor[
              0.9851141209349312, 0.987104803716967, 0.8512424005775606], 
             UndirectedEdge[118, 367] -> 
             RGBColor[
              0.21268815866311674`, 0.340879118336029, 0.9354236480407061], 
             UndirectedEdge[7, 96] -> 
             RGBColor[
              0.3381582412697068, 0.46529865529748227`, 0.9428420383243149], 
             UndirectedEdge[110, 115] -> 
             RGBColor[
              0.2470920216969208, 0.3770397597154611, 0.9373828971445268], 
             UndirectedEdge[68, 95] -> 
             RGBColor[
              0.2792515764807897, 0.4108414908268496, 0.9392143362136705], 
             UndirectedEdge[289, 302] -> 
             RGBColor[
              0.9425151711377706, 0.798674033657958, 0.3207346510653094], 
             UndirectedEdge[260, 321] -> 
             RGBColor[
              0.813370248803728, 0.8541302872991015, 0.9820328030897745], 
             UndirectedEdge[191, 220] -> 
             RGBColor[
              0.5771439386381384, 0.6670314281944398, 0.9602362550255482], 
             UndirectedEdge[169, 209] -> 
             RGBColor[
              0.23636572886417778`, 0.36576574586200267`, 0.9367720506358304],
              UndirectedEdge[32, 252] -> 
             RGBColor[
              0.2203092674216852, 0.34888938684748844`, 0.9358576589100864], 
             UndirectedEdge[75, 280] -> 
             RGBColor[
              0.24159566577055375`, 0.3712627411477558, 0.9370698878056503], 
             UndirectedEdge[14, 224] -> 
             RGBColor[
              0.9850092930497456, 0.9599506894449308, 0.4935654545583491], 
             UndirectedEdge[128, 311] -> 
             RGBColor[
              0.4227935959175786, 0.5388307190597109, 0.9486565824461703], 
             UndirectedEdge[132, 198] -> 
             RGBColor[
              0.8128559952710535, 0.8537811311091374, 0.9819675933041132], 
             UndirectedEdge[245, 388] -> 
             RGBColor[
              0.22663197894047044`, 0.3555349575367959, 0.9362177279774678], 
             UndirectedEdge[183, 273] -> 
             RGBColor[
              0.26718551324119244`, 0.3981592933294373, 0.9385271917623162], 
             UndirectedEdge[69, 220] -> 
             RGBColor[
              0.4818265682663484, 0.5902075400149862, 0.9523502989242535], 
             UndirectedEdge[37, 263] -> 
             RGBColor[
              0.25594156812645086`, 0.3863411941065481, 0.9378868657219579], 
             UndirectedEdge[235, 384] -> 
             RGBColor[
              0.7442607582282336, 0.800141428009943, 0.9751446149341176], 
             UndirectedEdge[132, 216] -> 
             RGBColor[
              0.7291619678468395, 0.7883461382089411, 0.9736397086151186], 
             UndirectedEdge[225, 380] -> 
             RGBColor[
              0.2612993849996442, 0.39197259934548456`, 0.9381919854667065], 
             UndirectedEdge[3, 371] -> 
             RGBColor[
              0.3210626317693298, 0.4491168451749269, 0.9418030466401561], 
             UndirectedEdge[269, 314] -> 
             RGBColor[
              0.9594354549874111, 0.9656217176549777, 0.7393357035372017], 
             UndirectedEdge[16, 206] -> 
             RGBColor[
              0.23671129027789278`, 0.36612895281767627`, 0.9367917298471292],
              UndirectedEdge[84, 256] -> 
             RGBColor[
              0.20211768989058865`, 0.32976888544967253`, 0.9348216754817178],
              UndirectedEdge[58, 348] -> 
             RGBColor[
              0.28088310771412667`, 0.4125563335981417, 0.9393072495037748], 
             UndirectedEdge[177, 360] -> 
             RGBColor[
              0.31615011179738517`, 0.4482550694974156, 0.9413657834565303], 
             UndirectedEdge[2, 106] -> 
             RGBColor[
              0.8834730056375308, 0.5519688209280622, 0.5686856052309635], 
             UndirectedEdge[256, 317] -> 
             RGBColor[
              0.6079677143241806, 0.6722679099328412, 0.8705698500730703], 
             UndirectedEdge[87, 351] -> 
             RGBColor[
              0.2679416039473189, 0.3989539926004958, 0.9385702500094941], 
             UndirectedEdge[48, 103] -> 
             RGBColor[
              0.3850045259376993, 0.5078933023022759, 0.9457531258399835], 
             UndirectedEdge[256, 381] -> 
             RGBColor[
              0.6092276972658053, 0.6727889452592876, 0.8496886719990233], 
             UndirectedEdge[91, 226] -> 
             RGBColor[
              0.25062761976227643`, 0.38075589745201466`, 0.9375842442239002],
              UndirectedEdge[105, 113] -> 
             RGBColor[
              0.6069298774587211, 0.6884337835985022, 0.9640833346207096], 
             UndirectedEdge[223, 291] -> 
             RGBColor[
              0.5752793861727824, 0.6652475055073694, 0.9602742044215822], 
             UndirectedEdge[203, 348] -> 
             RGBColor[
              0.277176399167938, 0.4086603478972015, 0.9390961579356532], 
             UndirectedEdge[259, 367] -> 
             RGBColor[
              0.21516769270569408`, 0.3434852658263162, 0.935564853836289], 
             UndirectedEdge[188, 206] -> 
             RGBColor[
              0.2493239941811602, 0.37938570431162577`, 0.937510004675597], 
             UndirectedEdge[250, 289] -> 
             RGBColor[
              0.9429902625743816, 0.8090015716874366, 0.5405821025323335], 
             UndirectedEdge[194, 377] -> 
             RGBColor[
              0.40146722310948635`, 0.5221524631532592, 0.9468021143463783], 
             UndirectedEdge[83, 231] -> 
             RGBColor[
              0.3307828964588674, 0.4609235312385056, 0.9422983810248817], 
             UndirectedEdge[276, 376] -> 
             RGBColor[
              0.6019797217390458, 0.6854606658855094, 0.9632115739949887], 
             UndirectedEdge[83, 120] -> 
             RGBColor[
              0.45962999176153224`, 0.5694602774020465, 0.9513564039568587], 
             UndirectedEdge[40, 243] -> 
             RGBColor[
              0.3138420416346276, 0.4443722151984709, 0.9412876874810078], 
             UndirectedEdge[4, 392] -> 
             RGBColor[
              0.24007285485442642`, 0.3696621703231174, 0.9369831659767736], 
             UndirectedEdge[81, 329] -> 
             RGBColor[
              0.22742713619850993`, 0.35637071823087746`, 0.9362630110069835],
              UndirectedEdge[131, 363] -> 
             RGBColor[
              0.8924893365860593, 0.5994472191560132, 0.23173103267921852`], 
             UndirectedEdge[167, 192] -> 
             RGBColor[
              0.3140196057697616, 0.4440801406652496, 0.941315327256403], 
             UndirectedEdge[41, 327] -> 
             RGBColor[
              0.32970622489449014`, 0.4599966933120725, 0.9422295669958778], 
             UndirectedEdge[24, 382] -> 
             RGBColor[
              0.9004669733536322, 0.6409255971753784, 0.23865954159958375`], 
             UndirectedEdge[26, 166] -> 
             RGBColor[
              0.6399409788041857, 0.37995595327830467`, 0.56079976269803], 
             UndirectedEdge[90, 261] -> 
             RGBColor[
              0.4426270855649366, 0.538021058033776, 0.9524212377305169], 
             UndirectedEdge[146, 297] -> 
             RGBColor[
              0.7409851288378926, 0.7966845449876518, 0.9658863907552364], 
             UndirectedEdge[5, 291] -> 
             RGBColor[
              0.7689673032381015, 0.8196158140703518, 0.9775611053894065], 
             UndirectedEdge[229, 315] -> 
             RGBColor[
              0.24508519381312066`, 0.3749304563693503, 0.9372686112653803], 
             UndirectedEdge[241, 360] -> 
             RGBColor[
              0.3006768355928906, 0.4332086382716799, 0.9404400442858039], 
             UndirectedEdge[59, 237] -> 
             RGBColor[
              0.4562186120487096, 0.5661785780610258, 0.9512293666120685], 
             UndirectedEdge[257, 381] -> 
             RGBColor[
              0.9078770993756948, 0.5831041621482105, 0.46625847556572675`], 
             UndirectedEdge[270, 308] -> 
             RGBColor[
              0.2553377632908749, 0.38570655694091993`, 0.9378524799298211], 
             UndirectedEdge[317, 382] -> 
             RGBColor[
              0.9447039927210837, 0.8118308485146293, 0.5211250046258997], 
             UndirectedEdge[23, 89] -> 
             RGBColor[
              0.21600037669219402`, 0.3443604694913417, 0.9356122739574746], 
             UndirectedEdge[57, 327] -> 
             RGBColor[
              0.2958997785397042, 0.4274294644124098, 0.9401957587844365], 
             UndirectedEdge[347, 362] -> 
             RGBColor[
              0.3423545559019188, 0.4682989085041503, 0.9431326516737686], 
             UndirectedEdge[43, 293] -> 
             RGBColor[
              0.21933315592561953`, 0.34786343177608003`, 0.9358020708044131],
              UndirectedEdge[73, 208] -> 
             RGBColor[
              0.23810134733460236`, 0.3675899909189858, 0.9368708915401036], 
             UndirectedEdge[53, 129] -> 
             RGBColor[
              0.26346421560774436`, 0.39424797357278596`, 0.9383152693672578],
              UndirectedEdge[324, 383] -> 
             RGBColor[
              0.2800969902621915, 0.41173007431343256`, 0.9392624812778436], 
             UndirectedEdge[368, 399] -> 
             RGBColor[
              0.22383026101092823`, 0.35259017435367035`, 0.9360581742861507],
              UndirectedEdge[51, 136] -> 
             RGBColor[
              0.4957527510770341, 0.5993305404010079, 0.9540497614266502], 
             UndirectedEdge[145, 359] -> 
             RGBColor[
              0.24179608967805666`, 0.37147339938215107`, 0.9370813016506819],
              UndirectedEdge[222, 297] -> 
             RGBColor[
              0.7757829604608912, 0.8249349923236523, 0.9686258035292561], 
             UndirectedEdge[81, 209] -> 
             RGBColor[
              0.23587421810878062`, 0.36524913689449845`, 0.9367440598254355],
              UndirectedEdge[31, 345] -> 
             RGBColor[
              0.1925824038789099, 0.3197466952793466, 0.9342786550495443], 
             UndirectedEdge[155, 180] -> 
             RGBColor[
              0.33540782096983857`, 0.46454677541701367`, 0.9426070871927383],
              UndirectedEdge[4, 369] -> 
             RGBColor[
              0.2448252232373639, 0.37465721081114345`, 0.937253806325683], 
             UndirectedEdge[102, 289] -> 
             RGBColor[
              0.8585251717968794, 0.3889672621761071, 0.20125368090273776`], 
             UndirectedEdge[70, 103] -> 
             RGBColor[
              0.3111881460301813, 0.44109703206764383`, 0.9411543384931023], 
             UndirectedEdge[177, 375] -> 
             RGBColor[
              0.28837692064883436`, 0.4192158430001391, 0.939778570045845], 
             UndirectedEdge[171, 253] -> 
             RGBColor[
              0.30746418261270597`, 0.43744644735605664`, 0.9409326149067666],
              UndirectedEdge[150, 241] -> 
             RGBColor[
              0.2807813627744614, 0.41244939321555174`, 0.939301455279979], 
             UndirectedEdge[24, 317] -> 
             RGBColor[
              0.946390043794504, 0.8194868126517976, 0.5225318869704552], 
             UndirectedEdge[80, 110] -> 
             RGBColor[
              0.29499717102305234`, 0.4250177053104399, 0.9401979264655129], 
             UndirectedEdge[176, 341] -> 
             RGBColor[
              0.21870360025711671`, 0.3472017288523488, 0.9357662185404361], 
             UndirectedEdge[154, 192] -> 
             RGBColor[
              0.3873238866966642, 0.5099022160172301, 0.9459009134566145], 
             UndirectedEdge[121, 322] -> 
             RGBColor[
              0.5308061338547281, 0.6299713578639174, 0.9562061497454312], 
             UndirectedEdge[268, 381] -> 
             RGBColor[
              0.9052330145226024, 0.5627805673219706, 0.46372649692433865`], 
             UndirectedEdge[76, 104] -> 
             RGBColor[
              0.8904092616611533, 0.5686904524165735, 0.22911954666558126`], 
             UndirectedEdge[91, 186] -> 
             RGBColor[
              0.2555444422624831, 0.38592378964428387`, 0.9378642499915], 
             UndirectedEdge[216, 357] -> 
             RGBColor[
              0.6673958385373104, 0.7400939685523675, 0.9674834380828405], 
             UndirectedEdge[210, 236] -> 
             RGBColor[
              0.27522295505597283`, 0.4066071542800159, 0.9389849121833385], 
             UndirectedEdge[26, 173] -> 
             RGBColor[
              0.34074023236907375`, 0.46188861660318076`, 0.9432249850370102],
              UndirectedEdge[10, 374] -> 
             RGBColor[
              0.31901480157328777`, 0.4477183185888486, 0.9416588227642095], 
             UndirectedEdge[289, 340] -> 
             RGBColor[
              0.9457657182249508, 0.8088519239369327, 0.40028051736176995`], 
             UndirectedEdge[65, 168] -> 
             RGBColor[
              0.592741338058181, 0.6798274166038522, 0.9613729899467283], 
             UndirectedEdge[40, 203] -> 
             RGBColor[
              0.31535485342024205`, 0.44596227630295887`, 0.941373839874194], 
             UndirectedEdge[167, 201] -> 
             RGBColor[
              0.27998787707886075`, 0.41161538943957654`, 0.9392562674434715],
              UndirectedEdge[41, 57] -> 
             RGBColor[
              0.3070138697292798, 0.4370559315903547, 0.9409039388472313], 
             UndirectedEdge[214, 363] -> 
             RGBColor[
              0.9231427936939823, 0.7280008749245814, 0.5596707462488172], 
             UndirectedEdge[22, 189] -> 
             RGBColor[
              0.29643257003583556`, 0.4288998043911114, 0.9401927683796281], 
             UndirectedEdge[41, 96] -> 
             RGBColor[
              0.3138659022147775, 0.44425785217656466`, 0.9412941519606068], 
             UndirectedEdge[31, 197] -> 
             RGBColor[
              0.5859844235922751, 0.6497599697422292, 0.884913356826519], 
             UndirectedEdge[275, 281] -> 
             RGBColor[
              0.8120473445077586, 0.8515608457173255, 0.8723741943555676], 
             UndirectedEdge[89, 353] -> 
             RGBColor[
              0.21448123699978983`, 0.34276375735560527`, 0.9355257611993579],
              UndirectedEdge[324, 375] -> 
             RGBColor[
              0.267401497471214, 0.3983863064493811, 0.938539491744696], 
             UndirectedEdge[5, 174] -> 
             RGBColor[
              0.7850242052221269, 0.8321595879372474, 0.979161507318894], 
             UndirectedEdge[36, 314] -> 
             RGBColor[
              0.7227446385125958, 0.7823089126955356, 0.9740580070832467], 
             UndirectedEdge[220, 357] -> 
             RGBColor[
              0.5755623088477795, 0.6657958469813797, 0.960078612949216], 
             UndirectedEdge[291, 342] -> 
             RGBColor[
              0.6499248897969461, 0.7258480880910823, 0.9661505719023658], 
             UndirectedEdge[21, 159] -> 
             RGBColor[
              0.3221758681761928, 0.45347427680941704`, 0.9417497393246208], 
             UndirectedEdge[220, 394] -> 
             RGBColor[
              0.4171512331180811, 0.5351366490894776, 0.9479674097431279], 
             UndirectedEdge[129, 249] -> 
             RGBColor[
              0.25362687609654, 0.3839083060231606, 0.9377550474351345], 
             UndirectedEdge[37, 58] -> 
             RGBColor[
              0.2743052593933725, 0.40564259795335733`, 0.9389326507729624], 
             UndirectedEdge[118, 259] -> 
             RGBColor[
              0.20854115618205327`, 0.33652035579328765`, 0.9351874823843499],
              UndirectedEdge[201, 243] -> 
             RGBColor[
              0.2823991194396881, 0.4141497580424017, 0.9393935841288071], 
             UndirectedEdge[40, 110] -> 
             RGBColor[
              0.29744503748137785`, 0.4271379242032959, 0.940353902351674], 
             UndirectedEdge[35, 278] -> 
             RGBColor[
              0.26672833715189703`, 0.3976787722729497, 0.9385011562603622], 
             UndirectedEdge[164, 315] -> 
             RGBColor[
              0.2429063670041037, 0.37264037124747484`, 0.9371445303018922], 
             UndirectedEdge[81, 304] -> 
             RGBColor[
              0.21940694053557647`, 0.34794098407935925`, 0.9358062727287957],
              UndirectedEdge[12, 299] -> 
             RGBColor[
              0.21628284341415968`, 0.3446573599255522, 0.9356283600194184], 
             UndirectedEdge[203, 258] -> 
             RGBColor[
              0.2721654186176039, 0.4033934896242831, 0.9388107900063931], 
             UndirectedEdge[250, 276] -> 
             RGBColor[
              0.8768966809261312, 0.9030925119563854, 0.9110185744810039], 
             UndirectedEdge[124, 238] -> 
             RGBColor[
              0.22624718755874168`, 0.35513051739741625`, 0.9361958146775262],
              UndirectedEdge[96, 154] -> 
             RGBColor[
              0.3585347588123511, 0.48294777063937044`, 0.9441404120038852], 
             UndirectedEdge[126, 238] -> 
             RGBColor[
              0.2206324276302094, 0.349229048716188, 0.9358760624058893], 
             UndirectedEdge[103, 108] -> 
             RGBColor[
              0.3560676178251626, 0.48282960690648735`, 0.9439092916429558], 
             UndirectedEdge[122, 210] -> 
             RGBColor[
              0.3730056479605837, 0.4966847962832106, 0.9450184340224643], 
             UndirectedEdge[108, 234] -> 
             RGBColor[
              0.3531542361556598, 0.4803061821351844, 0.9437236535391773], 
             UndirectedEdge[222, 361] -> 
             RGBColor[
              0.48027671073484357`, 0.5862967431545993, 0.9529611966752556], 
             UndirectedEdge[12, 274] -> 
             RGBColor[
              0.2245824786939262, 0.35338080283185697`, 0.936101011970391], 
             UndirectedEdge[141, 219] -> 
             RGBColor[
              0.4036258957264883, 0.5240221968760659, 0.9469396630566943], 
             UndirectedEdge[179, 344] -> 
             RGBColor[
              0.29513590341832135`, 0.4264382934400302, 0.9401591514378], 
             UndirectedEdge[14, 230] -> 
             RGBColor[
              0.9816071552805266, 0.9484744798894191, 0.4803487917647419], 
             UndirectedEdge[12, 118] -> 
             RGBColor[
              0.21224930323971947`, 0.34041785346099757`, 0.9353986558735721],
              UndirectedEdge[44, 49] -> 
             RGBColor[
              0.2768464709137847, 0.4083135723834269, 0.9390773690096643], 
             UndirectedEdge[224, 247] -> 
             RGBColor[
              0.9413345239687156, 0.7992928035075443, 0.30199213626103877`], 
             UndirectedEdge[161, 222] -> 
             RGBColor[
              0.5181817733764011, 0.6191282032508729, 0.9553764737486448], 
             UndirectedEdge[148, 168] -> 
             RGBColor[
              0.6470192572483401, 0.7238926765948177, 0.9656459465719469], 
             UndirectedEdge[219, 323] -> 
             RGBColor[
              0.6386990444191253, 0.7146022485196659, 0.9666913901196909], 
             UndirectedEdge[309, 334] -> 
             RGBColor[
              0.26609474286190404`, 0.39701282450196873`, 0.9384650740028659],
              UndirectedEdge[170, 326] -> 
             RGBColor[
              0.39217993552288943`, 0.5141082814383957, 0.9462103365937862], 
             UndirectedEdge[239, 354] -> 
             RGBColor[
              0.3021441775416652, 0.43344512169287874`, 0.940571418461126], 
             UndirectedEdge[11, 221] -> 
             RGBColor[
              0.9226607888866434, 0.8373956409938654, 0.6248416927368453], 
             UndirectedEdge[47, 322] -> 
             RGBColor[
              0.47115402237552717`, 0.5810156228019311, 0.9516558567994469], 
             UndirectedEdge[155, 271] -> 
             RGBColor[
              0.305666751429035, 0.4386055145162801, 0.9407186413492236], 
             UndirectedEdge[106, 363] -> 
             RGBColor[
              0.905503655257033, 0.714845634359743, 0.589529206598464], 
             UndirectedEdge[245, 378] -> 
             RGBColor[
              0.2192126419789341, 0.3477367639770881, 0.9357952077134337], 
             UndirectedEdge[155, 326] -> 
             RGBColor[
              0.32196792775833594`, 0.4529058154258842, 0.9417507090817323], 
             UndirectedEdge[10, 39] -> 
             RGBColor[
              0.3175089705748625, 0.446135594734304, 0.9415730679165266], 
             UndirectedEdge[25, 382] -> 
             RGBColor[
              0.8737460186049575, 0.5043450922501913, 0.21576589198201723`], 
             UndirectedEdge[177, 383] -> 
             RGBColor[
              0.3010724134398118, 0.43255961086419054`, 0.9405015595789926], 
             UndirectedEdge[177, 296] -> 
             RGBColor[
              0.3117150207517371, 0.4437456659293011, 0.9411076403210801], 
             UndirectedEdge[103, 143] -> 
             RGBColor[
              0.48460520194471113`, 0.589510492500073, 0.9533849292372562], 
             UndirectedEdge[84, 317] -> 
             RGBColor[
              0.5847770387283635, 0.6478930395078799, 0.8692491754054186], 
             UndirectedEdge[50, 328] -> 
             RGBColor[
              0.38179240870061343`, 0.505088601337379, 0.9455546766979714], 
             UndirectedEdge[332, 385] -> 
             RGBColor[
              0.5513213263478973, 0.6466265153287621, 0.9578211808481198], 
             UndirectedEdge[242, 257] -> 
             RGBColor[
              0.8704770048155868, 0.4443768248986645, 0.21122005596083127`], 
             UndirectedEdge[214, 217] -> 
             RGBColor[
              0.903299381606431, 0.5819361276170735, 0.5409216460120444], 
             UndirectedEdge[51, 59] -> 
             RGBColor[
              0.3534707906164537, 0.48058036569863427`, 0.9437438241095009], 
             UndirectedEdge[66, 131] -> 
             RGBColor[
              0.9476245332536402, 0.8250818486193503, 0.3026198784181737], 
             UndirectedEdge[66, 98] -> 
             RGBColor[
              0.9751764945744315, 0.9279266287426179, 0.3580657982576656], 
             UndirectedEdge[70, 346] -> 
             RGBColor[
              0.3114210735342079, 0.4412987821643549, 0.9411691804276892], 
             UndirectedEdge[151, 253] -> 
             RGBColor[
              0.3287756481732377, 0.4591906745282696, 0.9421702714700763], 
             UndirectedEdge[384, 398] -> 
             RGBColor[
              0.8439266207114591, 0.8788704640005567, 0.9814905615415767], 
             UndirectedEdge[123, 218] -> 
             RGBColor[
              0.9421799541639146, 0.955737423109728, 0.959839004250153], 
             UndirectedEdge[169, 280] -> 
             RGBColor[
              0.229855838803546, 0.3589234386574095, 0.9364013220273968], 
             UndirectedEdge[71, 109] -> 
             RGBColor[
              0.932608231427341, 0.9459491066410988, 0.8675350166916449], 
             UndirectedEdge[166, 302] -> 
             RGBColor[
              0.9060230690090321, 0.580068176669682, 0.28821316860056356`], 
             UndirectedEdge[89, 163] -> 
             RGBColor[
              0.23177803755773202`, 0.36094379142249916`, 0.9365107884028094],
              UndirectedEdge[102, 340] -> 
             RGBColor[
              0.9065375818313084, 0.569215708650745, 0.3651390053950433], 
             UndirectedEdge[380, 390] -> 
             RGBColor[
              0.2658949696207651, 0.39680285015917666`, 0.9384536972123212], 
             UndirectedEdge[172, 387] -> 
             RGBColor[
              0.29749670616801155`, 0.43001827893615596`, 0.9402533693581072],
              UndirectedEdge[61, 298] -> 
             RGBColor[
              0.9083880182689977, 0.925110369261773, 0.7500707788698681], 
             UndirectedEdge[10, 216] -> 
             RGBColor[
              0.5105137254220357, 0.6107590812291837, 0.9554696590225349], 
             UndirectedEdge[209, 229] -> 
             RGBColor[
              0.24946457527559712`, 0.37953346395523513`, 0.937518010560954], 
             UndirectedEdge[39, 119] -> 
             RGBColor[
              0.2567952159774935, 0.3872384321223937, 0.9379354797042159], 
             UndirectedEdge[33, 261] -> 
             RGBColor[
              0.17919487812109408`, 0.3056755568897237, 0.9335162552627061], 
             UndirectedEdge[102, 213] -> 
             RGBColor[
              0.8651325745805382, 0.41702815829837886`, 0.20666661364992278`],
              UndirectedEdge[155, 335] -> 
             RGBColor[
              0.29253189959404885`, 0.42479995244000324`, 0.9399706309684931],
              UndirectedEdge[76, 317] -> 
             RGBColor[
              0.9187857495623798, 0.676116573374989, 0.49879235046594833`], 
             UndirectedEdge[19, 179] -> 
             RGBColor[
              0.2720136332383074, 0.4032339535668936, 0.9388021460535885], 
             UndirectedEdge[48, 83] -> 
             RGBColor[
              0.38916228198081126`, 0.5114945416119245, 0.9460180543784913], 
             UndirectedEdge[288, 355] -> 
             RGBColor[
              0.2379735788706035, 0.36745569816233453`, 0.9368636153150954], 
             UndirectedEdge[7, 192] -> 
             RGBColor[
              0.36694736915401993`, 0.4922531006753419, 0.9446025397770442], 
             UndirectedEdge[341, 393] -> 
             RGBColor[
              0.2222018557461406, 0.35087861717352153`, 0.9359654390153307], 
             UndirectedEdge[244, 270] -> 
             RGBColor[
              0.2548116613836774, 0.3851535904796679, 0.9378225192045042], 
             UndirectedEdge[121, 265] -> 
             RGBColor[
              0.5725454192775208, 0.6638571901035208, 0.9594920191899539], 
             UndirectedEdge[156, 363] -> 
             RGBColor[
              0.5242360164158433, 0.390684407006331, 0.5704454430561892], 
             UndirectedEdge[133, 280] -> 
             RGBColor[
              0.26813571605602704`, 0.3991580167341666, 0.938581304406922], 
             UndirectedEdge[44, 362] -> 
             RGBColor[
              0.35130778497678417`, 0.477709319929344, 0.9436425248244668], 
             UndirectedEdge[116, 147] -> 
             RGBColor[
              0.35047958711339033`, 0.47576981650030403`, 0.9436345020558807],
              UndirectedEdge[83, 196] -> 
             RGBColor[
              0.32540289254677246`, 0.4552688060149441, 0.9419919977610904], 
             UndirectedEdge[109, 233] -> 
             RGBColor[
              0.9057773412404262, 0.5635119739368787, 0.4559259820875775], 
             UndirectedEdge[19, 125] -> 
             RGBColor[
              0.27618503388558474`, 0.4076183601292589, 0.9390397011494167], 
             UndirectedEdge[26, 160] -> 
             RGBColor[
              0.6422952177337565, 0.39805166532506286`, 0.5630541845557195], 
             UndirectedEdge[224, 302] -> 
             RGBColor[
              0.981469271203516, 0.9491536419267372, 0.38251204717050646`], 
             UndirectedEdge[58, 60] -> 
             RGBColor[
              0.3281696676840872, 0.4577472453898289, 0.942165291884663], 
             UndirectedEdge[165, 332] -> 
             RGBColor[
              0.5299851907540822, 0.6293048792717479, 0.9561415220973347], 
             UndirectedEdge[43, 252] -> 
             RGBColor[
              0.2258841865651551, 0.3547489803375645, 0.9361751423079533], 
             UndirectedEdge[292, 304] -> 
             RGBColor[
              0.21505855653612305`, 0.3433705567924642, 0.9355586386928844], 
             UndirectedEdge[63, 257] -> 
             RGBColor[
              0.8905841112547781, 0.5233265159050291, 0.23139995091138454`], 
             UndirectedEdge[94, 355] -> 
             RGBColor[
              0.2455225673247446, 0.37539016366114936`, 0.937293519039831], 
             UndirectedEdge[223, 290] -> 
             RGBColor[
              0.4296004547734099, 0.5464997120753861, 0.9486003596365518], 
             UndirectedEdge[141, 150] -> 
             RGBColor[
              0.3153323622893313, 0.4440199894984804, 0.9414428101102743], 
             UndirectedEdge[131, 306] -> 
             RGBColor[
              0.9464211476308863, 0.8210225463454206, 0.2979449525140816], 
             UndirectedEdge[151, 182] -> 
             RGBColor[
              0.301964914813191, 0.43405917516616493`, 0.9405318273574531], 
             UndirectedEdge[87, 201] -> 
             RGBColor[
              0.2832825017728496, 0.4150782488842294, 0.9394438914458336], 
             UndirectedEdge[72, 379] -> 
             RGBColor[
              0.22434193474233927`, 0.3531279758873717, 0.9360873133482011], 
             UndirectedEdge[23, 378] -> 
             RGBColor[
              0.21097218176330165`, 0.339075517815104, 0.9353259256948219], 
             UndirectedEdge[116, 322] -> 
             RGBColor[
              0.46231873384021377`, 0.5733629399471565, 0.9510928800267155], 
             UndirectedEdge[90, 175] -> 
             RGBColor[
              0.44236897151936794`, 0.5377497638065076, 0.9524065385174674], 
             UndirectedEdge[348, 369] -> 
             RGBColor[
              0.2602045857942335, 0.3908218959663191, 0.9381296382715687], 
             UndirectedEdge[134, 243] -> 
             RGBColor[
              0.2613494095308073, 0.3920251782994754, 0.9381948342897516], 
             UndirectedEdge[211, 372] -> 
             RGBColor[
              0.257077351430105, 0.3875349743715093, 0.9379515469008601], 
             UndirectedEdge[73, 188] -> 
             RGBColor[
              0.2551009475473486, 0.3854576485794885, 0.9378389936235647], 
             UndirectedEdge[55, 228] -> 
             RGBColor[
              0.38569491533937006`, 0.508491282902023, 0.9457971168421706], 
             UndirectedEdge[260, 384] -> 
             RGBColor[
              0.7786909364224193, 0.827038544894287, 0.9785762933282055], 
             UndirectedEdge[148, 282] -> 
             RGBColor[
              0.6353748988917614, 0.714796015346257, 0.9644853457536787], 
             UndirectedEdge[153, 203] -> 
             RGBColor[
              0.3044141682214503, 0.43648600467859244`, 0.9406767090877951], 
             UndirectedEdge[65, 148] -> 
             RGBColor[
              0.5696101053080527, 0.6614741699887192, 0.9592609405218679], 
             UndirectedEdge[42, 366] -> 
             RGBColor[
              0.9167531541973288, 0.7967074998480634, 0.6163680259642358], 
             UndirectedEdge[48, 313] -> 
             RGBColor[
              0.35412562406909687`, 0.4787494368539953, 0.9438733561702934], 
             UndirectedEdge[166, 213] -> 
             RGBColor[
              0.8678686088454421, 0.43805851659629047`, 0.20928664315190354`],
              UndirectedEdge[11, 78] -> 
             RGBColor[
              0.8826533057204708, 0.5284492493821207, 0.22248879223389445`], 
             UndirectedEdge[228, 348] -> 
             RGBColor[
              0.31540619999020275`, 0.44337706024281187`, 0.9414733974605265],
              UndirectedEdge[199, 336] -> 
             RGBColor[
              0.2184046627263886, 0.34688752655381927`, 0.9357491944902996], 
             UndirectedEdge[249, 309] -> 
             RGBColor[
              0.2701798653173872, 0.40130654721440506`, 0.9386977156833087], 
             UndirectedEdge[190, 273] -> 
             RGBColor[
              0.2582701914773965, 0.38878872489163985`, 0.9380194773769047], 
             UndirectedEdge[298, 314] -> 
             RGBColor[
              0.8746210569271528, 0.9028631061103101, 0.9879033312647884], 
             UndirectedEdge[7, 385] -> 
             RGBColor[
              0.4824130197414953, 0.5889482597885108, 0.9528759593947184], 
             UndirectedEdge[27, 194] -> 
             RGBColor[
              0.3427358884343137, 0.47023486345331306`, 0.943098158625497], 
             UndirectedEdge[39, 128] -> 
             RGBColor[
              0.2996526087721707, 0.4306693116276521, 0.9404352763322198], 
             UndirectedEdge[116, 265] -> 
             RGBColor[
              0.5040580192630065, 0.6072487721867599, 0.9543787494712381], 
             UndirectedEdge[231, 313] -> 
             RGBColor[
              0.295746238547153, 0.4281784264805763, 0.9401536828166841], 
             UndirectedEdge[96, 284] -> 
             RGBColor[
              0.2654547891651977, 0.3963401925913225, 0.9384286295865651], 
             UndirectedEdge[279, 300] -> 
             RGBColor[
              0.9178232089422185, 0.7078044246386144, 0.2525247911559355], 
             UndirectedEdge[22, 190] -> 
             RGBColor[
              0.26671069132338054`, 0.3976602253883686, 0.938500151356533], 
             UndirectedEdge[24, 207] -> 
             RGBColor[
              0.9210044213449331, 0.723918476562367, 0.2552656037171254], 
             UndirectedEdge[315, 329] -> 
             RGBColor[
              0.2392065257950246, 0.3687516035532512, 0.9369338298184597], 
             UndirectedEdge[239, 335] -> 
             RGBColor[
              0.3025165492814234, 0.4338365080010965, 0.9405926244808307], 
             UndirectedEdge[142, 300] -> 
             RGBColor[
              0.8557903757137784, 0.38014617017527513`, 0.1991125486638397], 
             UndirectedEdge[13, 88] -> 
             RGBColor[
              0.9770469480723544, 0.9813851840644524, 0.8781922259657269], 
             UndirectedEdge[18, 302] -> 
             RGBColor[
              0.9662417999648014, 0.9637001584466507, 0.6913546401282936], 
             UndirectedEdge[148, 251] -> 
             RGBColor[
              0.723101933884062, 0.7833478892534567, 0.9732241552199159], 
             UndirectedEdge[90, 257] -> 
             RGBColor[
              0.7642064856318851, 0.4724371566214084, 0.5702968707589827], 
             UndirectedEdge[134, 348] -> 
             RGBColor[
              0.24864104476606846`, 0.3786678811748705, 0.9374711117167406], 
             UndirectedEdge[158, 322] -> 
             RGBColor[
              0.5057660137173806, 0.6096426602918618, 0.9542348997632368], 
             UndirectedEdge[40, 385] -> 
             RGBColor[
              0.4573665882056296, 0.5672542996623962, 0.9512800229249427], 
             UndirectedEdge[228, 385] -> 
             RGBColor[
              0.4716391113259436, 0.5796164418313421, 0.9521894554774726], 
             UndirectedEdge[175, 214] -> 
             RGBColor[
              0.5813526175939636, 0.6464089921975442, 0.9229266959429565], 
             UndirectedEdge[7, 41] -> 
             RGBColor[
              0.36511265513899505`, 0.490663963610935, 0.9444856334223808], 
             UndirectedEdge[176, 379] -> 
             RGBColor[
              0.2183904240990045, 0.34687256085365753`, 0.9357483836215341], 
             UndirectedEdge[259, 336] -> 
             RGBColor[
              0.21101362554134806`, 0.339119077853518, 0.9353282858566712], 
             UndirectedEdge[213, 340] -> 
             RGBColor[
              0.9523731210086097, 0.8369128200592044, 0.40569345010895497`], 
             UndirectedEdge[55, 165] -> 
             RGBColor[
              0.4681407137086776, 0.5777449578588358, 0.9516464016172608], 
             UndirectedEdge[108, 231] -> 
             RGBColor[
              0.3381266013166869, 0.4672842792810106, 0.9427663154046388], 
             UndirectedEdge[38, 230] -> 
             RGBColor[
              0.9673242221990019, 0.9014390702190636, 0.3275612028563362], 
             UndirectedEdge[39, 316] -> 
             RGBColor[
              0.26368578568270973`, 0.3944808577699287, 0.9383278874552436], 
             UndirectedEdge[85, 167] -> 
             RGBColor[
              0.2624284668147709, 0.39315933592110447`, 0.9382562850057511], 
             UndirectedEdge[28, 328] -> 
             RGBColor[
              0.2988631492240676, 0.4313905924329009, 0.9403335261361829], 
             UndirectedEdge[79, 120] -> 
             RGBColor[
              0.5785921359057922, 0.6687661870638313, 0.9599680388727843], 
             UndirectedEdge[130, 347] -> 
             RGBColor[
              0.34522783768479254`, 0.47078760076913406`, 0.9433157346482299],
              UndirectedEdge[77, 160] -> 
             RGBColor[
              0.8294213428991457, 0.5471802126352212, 0.5797239248650322], 
             UndirectedEdge[108, 179] -> 
             RGBColor[
              0.3186061180992342, 0.4467670137493473, 0.9416546527633719], 
             UndirectedEdge[318, 373] -> 
             RGBColor[
              0.2370696348066011, 0.3665055956377041, 0.9368121370379159], 
             UndirectedEdge[48, 331] -> 
             RGBColor[
              0.43876768248625253`, 0.5544602462898143, 0.9491788666343646], 
             UndirectedEdge[222, 312] -> 
             RGBColor[
              0.5339420376563727, 0.632517225840949, 0.9564530195798908], 
             UndirectedEdge[292, 353] -> 
             RGBColor[
              0.2106991637542155, 0.3387885585772128, 0.9353103777230984], 
             UndirectedEdge[175, 204] -> 
             RGBColor[
              0.17892957074057536`, 0.30539670201133906`, 0.9335011463998728],
              UndirectedEdge[198, 340] -> 
             RGBColor[
              0.9101338786876096, 0.9267923912389714, 0.7737391772833939], 
             UndirectedEdge[14, 207] -> 
             RGBColor[
              0.9671064480201461, 0.8947970383510977, 0.44882285376347564`], 
             UndirectedEdge[45, 271] -> 
             RGBColor[
              0.30114348847212347`, 0.43385127835713033`, 0.9404610482153953],
              UndirectedEdge[112, 183] -> 
             RGBColor[
              0.2939274002864909, 0.42440137973285763`, 0.9401184016257302], 
             UndirectedEdge[85, 139] -> 
             RGBColor[
              0.2262390695271757, 0.3551219848315275, 0.9361953523676381], 
             UndirectedEdge[45, 97] -> 
             RGBColor[
              0.36889177075057233`, 0.4927124766331557, 0.9447712800460943], 
             UndirectedEdge[130, 181] -> 
             RGBColor[
              0.48885894126290724`, 0.5947515646860737, 0.9532258537292853], 
             UndirectedEdge[63, 90] -> 
             RGBColor[
              0.8321834271804781, 0.8209894828739578, 0.632414864387591], 
             UndirectedEdge[114, 361] -> 
             RGBColor[
              0.342252200873233, 0.470863387125772, 0.9430289854912723], 
             UndirectedEdge[75, 209] -> 
             RGBColor[
              0.24810555583118551`, 0.37810504835234904`, 0.9374406164140838],
              UndirectedEdge[42, 276] -> 
             RGBColor[
              0.8488960037945177, 0.8827904862944987, 0.9853329329150746], 
             UndirectedEdge[205, 358] -> 
             RGBColor[
              0.9819225924478814, 0.9489876509677333, 0.5302516309431803], 
             UndirectedEdge[76, 358] -> 
             RGBColor[
              0.9077605542707283, 0.6337524810989443, 0.26250704350549825`], 
             UndirectedEdge[90, 142] -> 
             RGBColor[
              0.763694887526314, 0.46850478939826945`, 0.5698069638353204], 
             UndirectedEdge[152, 381] -> 
             RGBColor[
              0.588381597564026, 0.6508783727536576, 0.8485015174600479], 
             UndirectedEdge[86, 309] -> 
             RGBColor[
              0.28566340206902835`, 0.417580726053311, 0.9395794801954747], 
             UndirectedEdge[104, 358] -> 
             RGBColor[
              0.9512253799690775, 0.8406018507565884, 0.299039239235954], 
             UndirectedEdge[16, 369] -> 
             RGBColor[
              0.24965722981087085`, 0.3797359560868109, 0.9375289819517311], 
             UndirectedEdge[278, 337] -> 
             RGBColor[
              0.26857947792754067`, 0.39962443859725516`, 0.9386065759890179],
              UndirectedEdge[100, 350] -> 
             RGBColor[
              0.4046784181179114, 0.524933838870203, 0.9470067288527668], 
             UndirectedEdge[90, 202] -> 
             RGBColor[
              0.7810727137045386, 0.6020783764160916, 0.5864479898090358], 
             UndirectedEdge[126, 367] -> 
             RGBColor[
              0.21567822148491766`, 0.34402186394267437`, 0.935593927695006], 
             UndirectedEdge[278, 327] -> 
             RGBColor[
              0.28550387867049365`, 0.4165027145117478, 0.9396037276662406], 
             UndirectedEdge[10, 200] -> 
             RGBColor[
              0.31629276558560215`, 0.4448572861787412, 0.9415038068416022], 
             UndirectedEdge[149, 299] -> 
             RGBColor[
              0.21717366869177715`, 0.345593673773913, 0.9356790912011209], 
             UndirectedEdge[57, 284] -> 
             RGBColor[
              0.2586027566797, 0.38913827200511253`, 0.9380384164731898], 
             UndirectedEdge[125, 313] -> 
             RGBColor[
              0.2803971559769777, 0.4120455675112783, 0.9392795752712453], 
             UndirectedEdge[125, 196] -> 
             RGBColor[
              0.2879550374250095, 0.4199893801105207, 0.9397099854388271], 
             UndirectedEdge[21, 210] -> 
             RGBColor[
              0.30642042589023155`, 0.43901202359644165`, 0.9407756825511414],
              UndirectedEdge[186, 374] -> 
             RGBColor[
              0.2622856992899031, 0.3930092782004845, 0.9382481546064155], 
             UndirectedEdge[6, 74] -> 
             RGBColor[
              0.909010509687477, 0.9256078266033538, 0.7502192883025007], 
             UndirectedEdge[7, 312] -> 
             RGBColor[
              0.42618108450073044`, 0.5432966415402436, 0.9484491754681994], 
             UndirectedEdge[238, 299] -> 
             RGBColor[
              0.22167590498284873`, 0.3503258095740973, 0.9359354868974357], 
             UndirectedEdge[155, 239] -> 
             RGBColor[
              0.3145302695292589, 0.4464636896954298, 0.9412767880762385], 
             UndirectedEdge[108, 331] -> 
             RGBColor[
              0.40983077437371584`, 0.5293965508940257, 0.9473350324373369], 
             UndirectedEdge[55, 87] -> 
             RGBColor[
              0.34683568506465234`, 0.47311300029375225`, 0.9433840322411374],
              UndirectedEdge[186, 288] -> 
             RGBColor[
              0.2467468316416792, 0.3766769430810886, 0.9373632390815438], 
             UndirectedEdge[178, 371] -> 
             RGBColor[
              0.25801702472850174`, 0.38852263058685255`, 0.9380050599050818],
              UndirectedEdge[212, 238] -> 
             RGBColor[
              0.22006014114382055`, 0.3486275393339343, 0.9358434715371114], 
             UndirectedEdge[292, 329] -> 
             RGBColor[
              0.22307875219905648`, 0.35180029094398246`, 0.9360153769710722],
              UndirectedEdge[268, 338] -> 
             RGBColor[
              0.9058036870049794, 0.5621593672391498, 0.39196047146640556`], 
             UndirectedEdge[68, 309] -> 
             RGBColor[
              0.27375753584035556`, 0.40506690577145743`, 0.9389014587269024],
              UndirectedEdge[129, 309] -> 
             RGBColor[
              0.25423745991444247`, 0.38455006832902616`, 0.9377898192802863],
              UndirectedEdge[137, 330] -> 
             RGBColor[
              0.22316402213431713`, 0.35188991505236755`, 0.9360202329677398],
              UndirectedEdge[111, 400] -> 
             RGBColor[
              0.631844529693345, 0.5164916201579837, 0.581343351224306], 
             UndirectedEdge[62, 370] -> 
             RGBColor[
              0.5051424414592518, 0.5868980307983699, 0.9586362110924191], 
             UndirectedEdge[163, 280] -> 
             RGBColor[
              0.24199322930997053`, 0.37168060563466715`, 0.9370925284610774],
              UndirectedEdge[316, 383] -> 
             RGBColor[
              0.2672579164630078, 0.3982353937061947, 0.9385313150186878], 
             UndirectedEdge[307, 314] -> 
             RGBColor[
              0.9555259778682477, 0.9659228619523936, 0.9435306567958934], 
             UndirectedEdge[126, 259] -> 
             RGBColor[
              0.2115312190038542, 0.33966310139993294`, 0.93535776203865], 
             UndirectedEdge[44, 372] -> 
             RGBColor[
              0.27471702429732014`, 0.4060753889748091, 0.9389561001750906], 
             UndirectedEdge[202, 279] -> 
             RGBColor[
              0.9009946329017078, 0.6281412966873632, 0.2383554119012628], 
             UndirectedEdge[148, 312] -> 
             RGBColor[
              0.5434225996528742, 0.6402139731641597, 0.9571993641486982], 
             UndirectedEdge[109, 358] -> 
             RGBColor[
              0.9813365611926588, 0.9487453119833825, 0.5399636854424916], 
             UndirectedEdge[142, 275] -> 
             RGBColor[
              0.906842307128124, 0.5789554407018784, 0.47443924955803846`], 
             UndirectedEdge[296, 375] -> 
             RGBColor[
              0.2781834406546093, 0.40971881234981117`, 0.9391535074585348], 
             UndirectedEdge[92, 195] -> 
             RGBColor[
              0.26667927398787117`, 0.3976272037767742, 0.9384983621857534], 
             UndirectedEdge[178, 248] -> 
             RGBColor[
              0.230098166399185, 0.35917814032488304`, 0.9364151222254768], 
             UndirectedEdge[41, 222] -> 
             RGBColor[
              0.4728736082946373, 0.5798845479116403, 0.9524894775340721], 
             UndirectedEdge[154, 356] -> 
             RGBColor[
              0.4742682171286211, 0.5834424825573183, 0.951929030274608], 
             UndirectedEdge[70, 133] -> 
             RGBColor[
              0.28753417910083867`, 0.4195470313278583, 0.9396860181798696], 
             UndirectedEdge[7, 80] -> 
             RGBColor[
              0.36191069619973304`, 0.48789058771288196`, 0.9442816074301521],
              UndirectedEdge[152, 261] -> 
             RGBColor[
              0.18153226782756765`, 0.3081323016702944, 0.9336493661486316], 
             UndirectedEdge[95, 229] -> 
             RGBColor[
              0.2643373458997902, 0.3951656888693841, 0.9383649928457094], 
             UndirectedEdge[30, 204] -> 
             RGBColor[
              0.17892701604158556`, 0.30539401686072354`, 0.9335010009135446],
              UndirectedEdge[133, 223] -> 
             RGBColor[
              0.3756627076897743, 0.49871942307299955`, 0.945202383630783], 
             UndirectedEdge[298, 306] -> 
             RGBColor[
              0.8969031243202032, 0.8868893383314866, 0.6612189641553454], 
             UndirectedEdge[40, 96] -> 
             RGBColor[
              0.313111809733841, 0.4436046951713676, 0.9412461018545393], 
             UndirectedEdge[122, 146] -> 
             RGBColor[
              0.49070941162852855`, 0.5972227097318854, 0.9531038334374095], 
             UndirectedEdge[223, 267] -> 
             RGBColor[
              0.5126330687833186, 0.6152176449516955, 0.954775499492879], 
             UndirectedEdge[54, 322] -> 
             RGBColor[
              0.48020380618298864`, 0.5888540906805946, 0.9522325010212487], 
             UndirectedEdge[41, 154] -> 
             RGBColor[
              0.3854891726816393, 0.5083130789528232, 0.945784007101951], 
             UndirectedEdge[245, 353] -> 
             RGBColor[
              0.220139248365585, 0.34871068603969635`, 0.9358479765763623], 
             UndirectedEdge[26, 62] -> 
             RGBColor[
              0.31709055637755623`, 0.43703130766003234`, 0.9418781709758536],
              UndirectedEdge[217, 269] -> 
             RGBColor[
              0.9079422992480835, 0.582007875379239, 0.32768831635612294`], 
             UndirectedEdge[172, 347] -> 
             RGBColor[
              0.29073737323035515`, 0.422913791452218, 0.9398684353468445], 
             UndirectedEdge[63, 261] -> 
             RGBColor[
              0.5690047111878296, 0.5889104173173967, 0.6135243178829187], 
             UndirectedEdge[195, 369] -> 
             RGBColor[
              0.2515743275380513, 0.381750947349094, 0.9376381578312021], 
             UndirectedEdge[65, 180] -> 
             RGBColor[
              0.4408011041078431, 0.5545376633487222, 0.9497736818591127], 
             UndirectedEdge[49, 211] -> 
             RGBColor[
              0.25920679804656954`, 0.3897731577801271, 0.9380728157354339], 
             UndirectedEdge[285, 387] -> 
             RGBColor[
              0.2661419288540897, 0.3970624199715206, 0.9384677611753156], 
             UndirectedEdge[329, 388] -> 
             RGBColor[
              0.22925196747727483`, 0.358288731605845, 0.9363669324487132], 
             UndirectedEdge[38, 102] -> 
             RGBColor[
              0.8925441235088332, 0.5227994562196083, 0.24385895757801979`], 
             UndirectedEdge[92, 188] -> 
             RGBColor[
              0.27737488016395806`, 0.40886896400844064`, 0.9391074611347503],
              UndirectedEdge[114, 153] -> 
             RGBColor[
              0.32315432075329853`, 0.4543217632532496, 0.9418120854576224], 
             UndirectedEdge[326, 337] -> 
             RGBColor[
              0.312066783946898, 0.44249908551128714`, 0.9411868535891006], 
             UndirectedEdge[38, 221] -> 
             RGBColor[
              0.9438250637656209, 0.9183985790902189, 0.6570073333224926], 
             UndirectedEdge[350, 394] -> 
             RGBColor[
              0.3958053510234857, 0.5172484341263308, 0.9464413448636552], 
             UndirectedEdge[286, 349] -> 
             RGBColor[
              0.5858145101958898, 0.6731289759492968, 0.9614748008949803], 
             UndirectedEdge[246, 320] -> 
             RGBColor[
              0.5768484382747107, 0.6660576659405324, 0.9606094815615308], 
             UndirectedEdge[322, 362] -> 
             RGBColor[
              0.45653757665465905`, 0.5683555921624378, 0.9507245098029286], 
             UndirectedEdge[80, 348] -> 
             RGBColor[
              0.2986858104115632, 0.42889469918101, 0.9404079890218355], 
             UndirectedEdge[78, 230] -> 
             RGBColor[
              0.9053505911840212, 0.6146233921482407, 0.26060988945584945`], 
             UndirectedEdge[248, 329] -> 
             RGBColor[
              0.22567335718883677`, 0.3545273852956994, 0.9361631358868661], 
             UndirectedEdge[43, 330] -> 
             RGBColor[
              0.2261035990920075, 0.35497959681484403`, 0.9361876375267658], 
             UndirectedEdge[63, 217] -> 
             RGBColor[
              0.8906933611547283, 0.5241662585096577, 0.23150456873895697`], 
             UndirectedEdge[79, 136] -> 
             RGBColor[
              0.6046940354323059, 0.6899568849766287, 0.9620228760179198], 
             UndirectedEdge[159, 243] -> 
             RGBColor[
              0.3099032733211534, 0.44096065205359114`, 0.9410367126469893], 
             UndirectedEdge[1, 327] -> 
             RGBColor[
              0.3392875835527789, 0.4682955846087937, 0.9428400826971212], 
             UndirectedEdge[304, 353] -> 
             RGBColor[
              0.21473904123945592`, 0.3430347259572272, 0.9355404427694197], 
             UndirectedEdge[240, 329] -> 
             RGBColor[
              0.23717266786335917`, 0.3666138899130299, 0.9368180046180745], 
             UndirectedEdge[10, 311] -> 
             RGBColor[
              0.4406499577202704, 0.5542970021663628, 0.9497943740304772], 
             UndirectedEdge[353, 378] -> 
             RGBColor[
              0.20945304207089746`, 0.33747880567936756`, 0.9352394129367053],
              UndirectedEdge[167, 243] -> 
             RGBColor[
              0.28596070978623506`, 0.41789321531449325`, 0.9395964114301423],
              UndirectedEdge[169, 292] -> 
             RGBColor[
              0.21585857380573317`, 0.34421142566684904`, 0.9356041984928691],
              UndirectedEdge[211, 347] -> 
             RGBColor[
              0.27136364126610246`, 0.4025507707922349, 0.9387651299723484], 
             UndirectedEdge[224, 340] -> 
             RGBColor[
              0.9847198182906963, 0.959331532205712, 0.46205791346696695`], 
             UndirectedEdge[144, 233] -> 
             RGBColor[
              0.8479481693127158, 0.33804742930989184`, 0.1923147220140613], 
             UndirectedEdge[273, 394] -> 
             RGBColor[
              0.3171526741702776, 0.4460438307034582, 0.9415424253765902], 
             UndirectedEdge[93, 94] -> 
             RGBColor[
              0.2526810398598759, 0.3829141721689455, 0.9377011834606958], 
             UndirectedEdge[358, 366] -> 
             RGBColor[
              0.934928559139148, 0.7751416322731404, 0.28588252947049914`], 
             UndirectedEdge[245, 329] -> 
             RGBColor[
              0.232518836810426, 0.36172241840646596`, 0.936552975824336], 
             UndirectedEdge[44, 93] -> 
             RGBColor[
              0.2715973273730923, 0.4027963897072362, 0.9387784380504338], 
             UndirectedEdge[218, 314] -> 
             RGBColor[
              0.9179378774680893, 0.9374027630058823, 0.9920349282773651], 
             UndirectedEdge[133, 346] -> 
             RGBColor[
              0.32114511749891506`, 0.4515193689112592, 0.9417229503460453], 
             UndirectedEdge[143, 272] -> 
             RGBColor[
              0.635830587523557, 0.7151635871324875, 0.9645228442451073], 
             UndirectedEdge[272, 346] -> 
             RGBColor[
              0.4960244700071036, 0.5987224642834593, 0.954329185667129], 
             UndirectedEdge[61, 269] -> 
             RGBColor[
              0.9932024163292561, 0.9878689808064407, 0.5015031511422814], 
             UndirectedEdge[158, 362] -> 
             RGBColor[
              0.4538874638081069, 0.5662041111673836, 0.9505158832119648], 
             UndirectedEdge[294, 393] -> 
             RGBColor[
              0.21778977524310467`, 0.34624124082276975`, 0.9357141775577711],
              UndirectedEdge[17, 298] -> 
             RGBColor[
              0.6794733687434446, 0.7479201915203444, 0.969798835244192], 
             UndirectedEdge[83, 179] -> 
             RGBColor[
              0.3112624132414147, 0.4404062657068423, 0.9411867183836149], 
             UndirectedEdge[223, 398] -> 
             RGBColor[
              0.696746297429305, 0.7610076864937902, 0.9687930758283795], 
             UndirectedEdge[52, 272] -> 
             RGBColor[
              0.5168312067307885, 0.6167442138565202, 0.9556549725324873], 
             UndirectedEdge[52, 174] -> 
             RGBColor[
              0.5576254346896334, 0.6486129747855855, 0.95972095993169], 
             UndirectedEdge[63, 317] -> 
             RGBColor[
              0.9745940579826633, 0.9311354530743134, 0.5492576472683819], 
             UndirectedEdge[145, 280] -> 
             RGBColor[
              0.23851863392834902`, 0.36802858558651175`, 0.9368946553942974],
              UndirectedEdge[152, 317] -> 
             RGBColor[
              0.5871216146224013, 0.6503573374272111, 0.8693826955340949], 
             UndirectedEdge[102, 391] -> 
             RGBColor[
              0.8198439128231849, 0.15353458638285297`, 0.16663585937096298`],
              UndirectedEdge[168, 251] -> 
             RGBColor[
              0.7462331666341901, 0.8017011358685895, 0.9753362046447762], 
             UndirectedEdge[89, 245] -> 
             RGBColor[
              0.22424083690782642`, 0.3530217156533258, 0.9360815559760864], 
             UndirectedEdge[293, 330] -> 
             RGBColor[
              0.21800150715905772`, 0.3464637844910152, 0.9357262353771553], 
             UndirectedEdge[166, 247] -> 
             RGBColor[
              0.8658883217742317, 0.43020733825048896`, 0.20769325769109587`],
              UndirectedEdge[8, 182] -> 
             RGBColor[
              0.29920713316336395`, 0.4316705233112208, 0.9403561039493367], 
             UndirectedEdge[2, 215] -> 
             RGBColor[
              0.8188696957350476, 0.14604632693877936`, 0.16570294798714186`],
              UndirectedEdge[61, 107] -> 
             RGBColor[
              0.9162817916828967, 0.6453128669663495, 0.3511545314597267], 
             UndirectedEdge[192, 361] -> 
             RGBColor[
              0.35005813253929685`, 0.4776244927973833, 0.9435263725545195], 
             UndirectedEdge[71, 321] -> 
             RGBColor[
              0.8444532383444727, 0.878825868324395, 0.985021184343525], 
             UndirectedEdge[26, 389] -> 
             RGBColor[
              0.31710049015279534`, 0.4370417486876464, 0.9418787366896577], 
             UndirectedEdge[134, 263] -> 
             RGBColor[
              0.24820523859568883`, 0.3782098212580943, 0.9374462932000549], 
             UndirectedEdge[105, 282] -> 
             RGBColor[
              0.5321029414738284, 0.6299784125013272, 0.956625284939209], 
             UndirectedEdge[323, 340] -> 
             RGBColor[
              0.9119941865056833, 0.9282757501963927, 0.7739166151037982], 
             UndirectedEdge[311, 323] -> 
             RGBColor[
              0.6747921418079339, 0.7440706990607763, 0.9694867808520644], 
             UndirectedEdge[29, 365] -> 
             RGBColor[
              0.24833496351636752`, 0.37834617037476265`, 0.9374536808423768],
              UndirectedEdge[321, 384] -> 
             RGBColor[
              0.7831071512596195, 0.8304885254895837, 0.9790164603513036], 
             UndirectedEdge[115, 195] -> 
             RGBColor[
              0.2421504028292495, 0.3718458049688061, 0.937101479260483], 
             UndirectedEdge[162, 359] -> 
             RGBColor[
              0.24582605828944576`, 0.3757091519074889, 0.9373108024012962], 
             UndirectedEdge[106, 295] -> 
             RGBColor[
              0.5954410834145789, 0.6666014753537031, 0.9545919964182874], 
             UndirectedEdge[24, 242] -> 
             RGBColor[
              0.9102499321760205, 0.681280510728698, 0.24661228929151274`], 
             UndirectedEdge[109, 286] -> 
             RGBColor[
              0.8601731647723879, 0.8889489686867593, 0.8604250468482817], 
             UndirectedEdge[287, 367] -> 
             RGBColor[
              0.23976404440825078`, 0.3693375909644736, 0.936965579678708], 
             UndirectedEdge[74, 140] -> 
             RGBColor[
              0.7482992359076605, 0.8033342207586809, 0.9755370742792053], 
             UndirectedEdge[168, 394] -> 
             RGBColor[
              0.5145092206731405, 0.613750519132451, 0.9559228612077943], 
             UndirectedEdge[68, 249] -> 
             RGBColor[
              0.2731469520224531, 0.4044251434655919, 0.9388666868817508], 
             UndirectedEdge[389, 400] -> 
             RGBColor[
              0.2843495171102985, 0.40872323643536973`, 0.9397784081644269], 
             UndirectedEdge[267, 346] -> 
             RGBColor[
              0.4581154785924594, 0.5680175907899552, 0.9512960662081413], 
             UndirectedEdge[16, 392] -> 
             RGBColor[
              0.24490486142793333`, 0.37474091559878486`, 0.9372583416028217],
              UndirectedEdge[13, 191] -> 
             RGBColor[
              0.8213167457883995, 0.8607762667176537, 0.9574101949991654], 
             UndirectedEdge[312, 327] -> 
             RGBColor[
              0.39077465425622554`, 0.5126293712413812, 0.9461931090416965], 
             UndirectedEdge[260, 291] -> 
             RGBColor[
              0.7527228069990448, 0.8067520448236535, 0.9759880328732503], 
             UndirectedEdge[83, 344] -> 
             RGBColor[
              0.33675515918736176`, 0.4661021259068189, 0.9426787188558917], 
             UndirectedEdge[200, 288] -> 
             RGBColor[
              0.25784282293400623`, 0.38833953345580596`, 0.9379951393705938],
              UndirectedEdge[297, 332] -> 
             RGBColor[
              0.736930313911651, 0.7933926635631983, 0.9655671808709663], 
             UndirectedEdge[189, 241] -> 
             RGBColor[
              0.2957543458619668, 0.428186947782479, 0.9401541445162689], 
             UndirectedEdge[276, 358] -> 
             RGBColor[
              0.8670714087363368, 0.8612246187195758, 0.654847436421338], 
             UndirectedEdge[11, 102] -> 
             RGBColor[
              0.8713798486298555, 0.4417965181232547, 0.21169331699237254`], 
             UndirectedEdge[96, 243] -> 
             RGBColor[
              0.2876417202462759, 0.4196600638902152, 0.9396921424890095], 
             UndirectedEdge[171, 397] -> 
             RGBColor[
              0.26128106780929927`, 0.39195334681705507`, 0.9381909423298143],
              UndirectedEdge[314, 385] -> 
             RGBColor[
              0.7506165131369036, 0.8049365561291917, 0.9762521831517132], 
             UndirectedEdge[11, 213] -> 
             RGBColor[
              0.9172153878071567, 0.709493629531714, 0.2522477617062842], 
             UndirectedEdge[68, 129] -> 
             RGBColor[
              0.25720454661950837`, 0.38766866458021304`, 0.9379587904787283],
              UndirectedEdge[137, 277] -> 
             RGBColor[
              0.23968446191505444`, 0.36925394471830275`, 0.9369610475734522],
              UndirectedEdge[35, 327] -> 
             RGBColor[
              0.29981659218631795`, 0.43154628389532945`, 0.9404188155272046],
              UndirectedEdge[155, 183] -> 
             RGBColor[
              0.2817396246657633, 0.4134565872206231, 0.9393560268770672], 
             UndirectedEdge[63, 256] -> 
             RGBColor[
              0.5919347091448884, 0.6130112990161062, 0.6148301473446811], 
             UndirectedEdge[144, 358] -> 
             RGBColor[
              0.9235073892649484, 0.7232807673563957, 0.2763524253689754], 
             UndirectedEdge[192, 332] -> 
             RGBColor[
              0.43585567576042195`, 0.5499313562155932, 0.9495477612304457], 
             UndirectedEdge[149, 259] -> 
             RGBColor[
              0.21561966255991427`, 0.3439603147996455, 0.9355905928508573], 
             UndirectedEdge[146, 165] -> 
             RGBColor[
              0.5340400056803238, 0.6325967606962016, 0.956460731981605], 
             UndirectedEdge[164, 280] -> 
             RGBColor[
              0.2407758584059484, 0.37040107162876656`, 0.9370232009890322], 
             UndirectedEdge[65, 105] -> 
             RGBColor[
              0.46633814789011974`, 0.5766565671437895, 0.9514008797073982], 
             UndirectedEdge[73, 369] -> 
             RGBColor[
              0.2502849628040927, 0.38039574326325765`, 0.9375647304170474], 
             UndirectedEdge[187, 281] -> 
             RGBColor[
              0.7379639441479849, 0.795257108792612, 0.9745741950769791], 
             UndirectedEdge[53, 253] -> 
             RGBColor[
              0.31547986955209806`, 0.4458714425532633, 0.9413890964198188], 
             UndirectedEdge[132, 191] -> 
             RGBColor[
              0.7390378619070974, 0.7960612617083893, 0.9746240454395679], 
             UndirectedEdge[29, 273] -> 
             RGBColor[
              0.25793330326133057`, 0.388434634016608, 0.9380002920913812], 
             UndirectedEdge[138, 366] -> 
             RGBColor[
              0.8603116610551809, 0.39715139303420033`, 0.20274719460083632`],
              UndirectedEdge[229, 309] -> 
             RGBColor[
              0.25884330525935606`, 0.3893911038139919, 0.9380521153589414], 
             UndirectedEdge[274, 287] -> 
             RGBColor[
              0.2454706833388167, 0.37533563030230443`, 0.937290564323588], 
             UndirectedEdge[251, 312] -> 
             RGBColor[
              0.6426365090387243, 0.7180224324379316, 0.9668896222215277], 
             UndirectedEdge[339, 360] -> 
             RGBColor[
              0.3380761124684098, 0.46724626924582036`, 0.942762888830887], 
             UndirectedEdge[150, 365] -> 
             RGBColor[
              0.26342074735738313`, 0.39420228568561005`, 0.9383127939147053],
              UndirectedEdge[61, 300] -> 
             RGBColor[
              0.9416713408004723, 0.7907793854302443, 0.3735219082012329], 
             UndirectedEdge[62, 389] -> 
             RGBColor[
              0.17907819285502502`, 0.305552913276812, 0.9335096102094239], 
             UndirectedEdge[374, 399] -> 
             RGBColor[
              0.255491371590293, 0.38586800900293716`, 0.9378612276952298], 
             UndirectedEdge[27, 51] -> 
             RGBColor[
              0.33517005330446453`, 0.4636817173337682, 0.9426160703012283], 
             UndirectedEdge[58, 159] -> 
             RGBColor[
              0.31512279365295653`, 0.44644669885901933`, 0.9413339566082971],
              UndirectedEdge[57, 153] -> 
             RGBColor[
              0.2953190920495516, 0.42692650296079127`, 0.9401587579547649], 
             UndirectedEdge[84, 264] -> 
             RGBColor[
              0.18447901438019912`, 0.31122951913163255`, 0.9338171790054831],
              UndirectedEdge[159, 201] -> 
             RGBColor[
              0.30393044061377905`, 0.43468282617867443`, 0.9406965686603185],
              UndirectedEdge[80, 87] -> 
             RGBColor[
              0.3122775575094636, 0.4431804871474425, 0.9411820189118731], 
             UndirectedEdge[39, 288] -> 
             RGBColor[
              0.2590590279232666, 0.38961784201136873`, 0.9380644004455181], 
             UndirectedEdge[91, 365] -> 
             RGBColor[
              0.259430965008946, 0.3900087714705911, 0.9380855817123159], 
             UndirectedEdge[5, 384] -> 
             RGBColor[
              0.7949354326614759, 0.8399023141409853, 0.9801493658443617], 
             UndirectedEdge[156, 381] -> 
             RGBColor[
              0.5895532840978516, 0.6521098895899253, 0.8485682432747944], 
             UndirectedEdge[2, 197] -> 
             RGBColor[
              0.9036013141673853, 0.5662229928500411, 0.5006917858198119], 
             UndirectedEdge[238, 293] -> 
             RGBColor[
              0.22022708573500543`, 0.3488030086841681, 0.935852978784607], 
             UndirectedEdge[85, 325] -> 
             RGBColor[
              0.22643759197523877`, 0.355330644511492, 0.9362066579273677], 
             UndirectedEdge[146, 332] -> 
             RGBColor[
              0.53127642233297, 0.6303531592368088, 0.9562431725771618], 
             UndirectedEdge[197, 204] -> 
             RGBColor[
              0.5838392169462935, 0.6475052215433456, 0.8847911904815791], 
             UndirectedEdge[20, 130] -> 
             RGBColor[
              0.4090322853711047, 0.5287049398531881, 0.9472841534241666], 
             UndirectedEdge[167, 348] -> 
             RGBColor[
              0.2732523450214962, 0.4045359181898883, 0.9388726888571313], 
             UndirectedEdge[83, 237] -> 
             RGBColor[
              0.4656503502316991, 0.5743478756221865, 0.9518303486289299], 
             UndirectedEdge[178, 334] -> 
             RGBColor[
              0.25269374017822266`, 0.3829275210087747, 0.9377019067250372], 
             UndirectedEdge[178, 388] -> 
             RGBColor[
              0.23367677668762307`, 0.36293948663502873`, 0.9366189187873238],
              UndirectedEdge[115, 184] -> 
             RGBColor[
              0.22818450918176583`, 0.35716676525650004`, 0.936306142277947], 
             UndirectedEdge[165, 385] -> 
             RGBColor[
              0.5540849096952511, 0.648870116788155, 0.9580387402525627], 
             UndirectedEdge[202, 257] -> 
             RGBColor[
              0.8394733977788387, 0.30441540944716294`, 0.18543307633282935`],
              UndirectedEdge[35, 57] -> 
             RGBColor[
              0.2771242370211076, 0.4086055221736117, 0.9390931873785582], 
             UndirectedEdge[115, 206] -> 
             RGBColor[
              0.23508408472910247`, 0.364418656615107, 0.9366990628983605], 
             UndirectedEdge[8, 82] -> 
             RGBColor[
              0.34476855469957235`, 0.4730429263345264, 0.9431893253319623], 
             UndirectedEdge[61, 98] -> 
             RGBColor[
              0.985458002900472, 0.9620883573989745, 0.44224268706809605`], 
             UndirectedEdge[33, 173] -> 
             RGBColor[
              0.20265449886636056`, 0.33033310571886365`, 0.9348522459587503],
              UndirectedEdge[6, 185] -> 
             RGBColor[
              0.9085190133388343, 0.5856402039031354, 0.34380931507742224`], 
             UndirectedEdge[300, 363] -> 
             RGBColor[
              0.8762546358068509, 0.5309830273105506, 0.21845617365184725`], 
             UndirectedEdge[34, 270] -> 
             RGBColor[
              0.28093807902462586`, 0.41228653639826196`, 0.9393223741835017],
              UndirectedEdge[162, 179] -> 
             RGBColor[
              0.25786357675267113`, 0.38836134703509095`, 0.9379963212698641],
              UndirectedEdge[11, 250] -> 
             RGBColor[
              0.9558449394073578, 0.8618308276345842, 0.5510217386219683], 
             UndirectedEdge[66, 314] -> 
             RGBColor[
              0.9492974340005453, 0.9317668939083206, 0.6707765260947278], 
             UndirectedEdge[153, 327] -> 
             RGBColor[
              0.31801144721476193`, 0.44986726468250904`, 0.9414843861034113],
              UndirectedEdge[153, 392] -> 
             RGBColor[
              0.28268998646480836`, 0.4136525122596839, 0.9394395490748012], 
             UndirectedEdge[110, 369] -> 
             RGBColor[
              0.2565159464057226, 0.38694490209574905`, 0.9379195757152459], 
             UndirectedEdge[321, 398] -> 
             RGBColor[
              0.8786059330927678, 0.9059622064053712, 0.9849470713031456], 
             UndirectedEdge[188, 278] -> 
             RGBColor[
              0.2597507710467335, 0.39034490789317966`, 0.9381037941930572], 
             UndirectedEdge[213, 289] -> 
             RGBColor[
              0.9043607109741805, 0.6566643735845665, 0.24180812561664938`], 
             UndirectedEdge[236, 263] -> 
             RGBColor[
              0.2563029052327246, 0.3867209823153376, 0.9379074433356098], 
             UndirectedEdge[93, 383] -> 
             RGBColor[
              0.2627372188358315, 0.39348385387124796`, 0.9382738679765928], 
             UndirectedEdge[56, 286] -> 
             RGBColor[
              0.5885924555434128, 0.6755350925857282, 0.9616518091160838], 
             UndirectedEdge[25, 144] -> 
             RGBColor[
              0.8635746104404736, 0.45815910336800225`, 0.20727861968554306`],
              UndirectedEdge[143, 331] -> 
             RGBColor[
              0.5383683584932644, 0.6360774364876114, 0.9568106700316372], 
             UndirectedEdge[76, 257] -> 
             RGBColor[
              0.8347758028344946, 0.2683076362057045, 0.1809346541089509], 
             UndirectedEdge[91, 189] -> 
             RGBColor[
              0.28158397795101814`, 0.4132929926548542, 0.9393471630269211], 
             UndirectedEdge[133, 145] -> 
             RGBColor[
              0.26764114093786784`, 0.3986381869271076, 0.9385531390856012], 
             UndirectedEdge[207, 230] -> 
             RGBColor[
              0.9543565255231943, 0.8529328333505086, 0.30199072149137773`], 
             UndirectedEdge[238, 336] -> 
             RGBColor[
              0.22011483416770328`, 0.34868502516977307`, 0.9358465862239105],
              UndirectedEdge[123, 306] -> 
             RGBColor[
              0.9723361250736168, 0.9460422517382365, 0.6339056761634236], 
             UndirectedEdge[272, 338] -> 
             RGBColor[
              0.8206526510459409, 0.8571827716487312, 0.7925776008366022], 
             UndirectedEdge[11, 289] -> 
             RGBColor[
              0.9106079850234978, 0.6814327334094423, 0.24683482895909917`], 
             UndirectedEdge[215, 300] -> 
             RGBColor[
              0.8546424874802127, 0.37132299820425807`, 0.1980133295950229], 
             UndirectedEdge[224, 289] -> 
             RGBColor[
              0.9367074082562672, 0.779083085731074, 0.29817258897466137`], 
             UndirectedEdge[65, 161] -> 
             RGBColor[
              0.4733844161827434, 0.5827596905831183, 0.9518498616922337], 
             UndirectedEdge[14, 247] -> 
             RGBColor[
              0.9506823086964485, 0.8296807989526216, 0.43560760573952945`], 
             UndirectedEdge[150, 226] -> 
             RGBColor[
              0.2546174021107136, 0.38494941166703367`, 0.9378114564262897], 
             UndirectedEdge[15, 180] -> 
             RGBColor[
              0.33506546922916314`, 0.4641869420312098, 0.9425875907675709], 
             UndirectedEdge[7, 114] -> 
             RGBColor[
              0.359141437487956, 0.48549199500373064`, 0.9441051527137969], 
             UndirectedEdge[108, 313] -> 
             RGBColor[
              0.3251887159565602, 0.4536857414582067, 0.9420295219732657], 
             UndirectedEdge[227, 315] -> 
             RGBColor[
              0.2390981188616284, 0.3686376609928552, 0.9369276562039764], 
             UndirectedEdge[174, 384] -> 
             RGBColor[
              0.7385166114389616, 0.7956540568810313, 0.9745720920642666], 
             UndirectedEdge[104, 138] -> 
             RGBColor[
              0.8766084818851104, 0.4626116115176483, 0.21590390436629117`], 
             UndirectedEdge[313, 344] -> 
             RGBColor[
              0.30171850127564737`, 0.43335702114888963`, 0.940534020647694], 
             UndirectedEdge[255, 374] -> 
             RGBColor[
              0.2682893522658295, 0.3993194981317673, 0.938590053761786], 
             UndirectedEdge[87, 167] -> 
             RGBColor[
              0.28684409211939654`, 0.41882170615632086`, 0.9396467187471687],
              UndirectedEdge[114, 312] -> 
             RGBColor[
              0.3959175277947622, 0.5170838698121216, 0.9465208083959076], 
             UndirectedEdge[50, 265] -> 
             RGBColor[
              0.5230211648142513, 0.6236511692879999, 0.9555932884652836], 
             UndirectedEdge[310, 345] -> 
             RGBColor[
              0.19226277251810686`, 0.3194107424533439, 0.9342604525163987], 
             UndirectedEdge[315, 334] -> 
             RGBColor[
              0.25233663141566864`, 0.38255217705732714`, 0.9376815699093048],
              UndirectedEdge[102, 302] -> 
             RGBColor[
              0.9032870347441282, 0.5590378183717704, 0.2855931390985828], 
             UndirectedEdge[172, 211] -> 
             RGBColor[
              0.2820509294380053, 0.413783788274112, 0.9393737552233123], 
             UndirectedEdge[264, 381] -> 
             RGBColor[
              0.5915890217554157, 0.6542495789412477, 0.8486841755227887], 
             UndirectedEdge[270, 397] -> 
             RGBColor[
              0.2494683482405557, 0.3795374295806264, 0.9375182254257268], 
             UndirectedEdge[48, 290] -> 
             RGBColor[
              0.4152883060919923, 0.5341235905648768, 0.9476827815325197], 
             UndirectedEdge[224, 323] -> 
             RGBColor[
              0.9029358765369997, 0.8985069119905342, 0.6718086867166897], 
             UndirectedEdge[10, 339] -> 
             RGBColor[
              0.3638431893323356, 0.48956441613441326`, 0.9444047441837249], 
             UndirectedEdge[254, 320] -> 
             RGBColor[
              0.5897027051719504, 0.6767516973442059, 0.9615500313265857], 
             UndirectedEdge[92, 392] -> 
             RGBColor[
              0.26780652703776464`, 0.39881201820418366`, 0.9385625575793235],
              UndirectedEdge[166, 224] -> 
             RGBColor[
              0.9002153061275288, 0.5604772287427979, 0.2656511065099155], 
             UndirectedEdge[108, 344] -> 
             RGBColor[
              0.3440988640451813, 0.47246287394932385`, 0.9431466532356487], 
             UndirectedEdge[180, 271] -> 
             RGBColor[
              0.3365289525569892, 0.46572515579895724`, 0.942670933978061], 
             UndirectedEdge[104, 207] -> 
             RGBColor[
              0.9368649528111581, 0.7873976069432023, 0.2680582629430743], 
             UndirectedEdge[45, 266] -> 
             RGBColor[
              0.2752485126978604, 0.4066340169820878, 0.9389863676532347], 
             UndirectedEdge[59, 373] -> 
             RGBColor[
              0.2921699969184407, 0.4220829828981863, 0.9400355750383738], 
             UndirectedEdge[107, 352] -> 
             RGBColor[
              0.9166859076311894, 0.6461772301173578, 0.39514005851685197`], 
             UndirectedEdge[99, 338] -> 
             RGBColor[
              0.9862079875593082, 0.9866999578573392, 0.7708056942036536], 
             UndirectedEdge[186, 341] -> 
             RGBColor[
              0.23502569235584353`, 0.3643572825285215, 0.9366957375390872], 
             UndirectedEdge[90, 156] -> 
             RGBColor[
              0.4458826703540418, 0.5414428840631231, 0.9526066384680504], 
             UndirectedEdge[34, 151] -> 
             RGBColor[
              0.31406226415390115`, 0.44644668080690353`, 0.9412327476508988],
              UndirectedEdge[174, 260] -> 
             RGBColor[
              0.7687797089830702, 0.819295818690549, 0.9775884348027377], 
             UndirectedEdge[13, 216] -> 
             RGBColor[
              0.8114408517281416, 0.8530611432182054, 0.956425858174716], 
             UndirectedEdge[9, 217] -> 
             RGBColor[
              0.8242465537218799, 0.18737521357976708`, 0.17085183326762515`],
              UndirectedEdge[87, 159] -> 
             RGBColor[
              0.3107866556543149, 0.4418891428954188, 0.9410870199640158], 
             UndirectedEdge[184, 305] -> 
             RGBColor[
              0.21033276310750965`, 0.33840344826638225`, 0.9352895117483098],
              UndirectedEdge[12, 259] -> 
             RGBColor[
              0.2147288372822968, 0.3430240009512847, 0.9355398616691548], 
             UndirectedEdge[27, 287] -> 
             RGBColor[
              0.27881505582512084`, 0.4103826799407336, 0.9391894770081045], 
             UndirectedEdge[188, 284] -> 
             RGBColor[
              0.25554200422115014`, 0.38592122710826227`, 0.9378641111486529],
              UndirectedEdge[118, 126] -> 
             RGBColor[
              0.20905168496127685`, 0.33705695390964574`, 0.935216556243067], 
             UndirectedEdge[209, 304] -> 
             RGBColor[
              0.23556571159456763`, 0.3649248769876179, 0.9367264908358456], 
             UndirectedEdge[48, 108] -> 
             RGBColor[
              0.3965059868386308, 0.5178552896544295, 0.9464859887582483], 
             UndirectedEdge[136, 376] -> 
             RGBColor[
              0.5284877060748537, 0.6276839131134415, 0.9561356038127271], 
             UndirectedEdge[48, 344] -> 
             RGBColor[
              0.373035772157718, 0.49752656934511247`, 0.9449904874326764], 
             UndirectedEdge[13, 198] -> 
             RGBColor[
              0.8951348791523555, 0.9184961361184019, 0.9647537428637106], 
             UndirectedEdge[286, 320] -> 
             RGBColor[
              0.7180719499645429, 0.7796825319520332, 0.9725343592747207], 
             UndirectedEdge[176, 368] -> 
             RGBColor[
              0.2143024966118115, 0.34257588987504495`, 0.9355155821986852], 
             UndirectedEdge[248, 388] -> 
             RGBColor[
              0.21978649931888122`, 0.34833992442602935`, 0.935827888039998], 
             UndirectedEdge[57, 188] -> 
             RGBColor[
              0.270146670915944, 0.40127165779384166`, 0.9386958253112532], 
             UndirectedEdge[39, 225] -> 
             RGBColor[
              0.26510008482719366`, 0.3959673758425263, 0.9384084296992539], 
             UndirectedEdge[355, 379] -> 
             RGBColor[
              0.2259392634266556, 0.3548068696110762, 0.9361782788537368], 
             UndirectedEdge[85, 348] -> 
             RGBColor[
              0.2521313444108594, 0.3823364073993248, 0.9376698791180758], 
             UndirectedEdge[118, 336] -> 
             RGBColor[
              0.20853409149877072`, 0.3365129303632308, 0.9351870800610882], 
             UndirectedEdge[195, 392] -> 
             RGBColor[
              0.24682195915511385`, 0.3767559068610679, 0.9373675174822926], 
             UndirectedEdge[193, 281] -> 
             RGBColor[
              0.7271668299156635, 0.7866477829836171, 0.9735443566828026], 
             UndirectedEdge[154, 312] -> 
             RGBColor[
              0.4465576020433747, 0.5609457568821319, 0.9497475491477698], 
             UndirectedEdge[53, 171] -> 
             RGBColor[
              0.28122827358250124`, 0.41291912481058346`, 0.9393269061893516],
              UndirectedEdge[115, 188] -> 
             RGBColor[
              0.25284600900533644`, 0.38308756520047255`, 0.9377105782094798],
              UndirectedEdge[319, 329] -> 
             RGBColor[
              0.2383612491721791, 0.3678631642290072, 0.9368856925652633], 
             UndirectedEdge[231, 359] -> 
             RGBColor[
              0.2771261222266016, 0.4086075036441148, 0.9390932947382222], 
             UndirectedEdge[288, 399] -> 
             RGBColor[
              0.23995250394206913`, 0.3695356738835413, 0.9369763121703581], 
             UndirectedEdge[140, 220] -> 
             RGBColor[
              0.5736797551483913, 0.6643251817234797, 0.9598909775899255], 
             UndirectedEdge[9, 215] -> 
             RGBColor[
              0.822477817482793, 0.1737799317809825, 0.1691580894475736], 
             UndirectedEdge[309, 329] -> 
             RGBColor[
              0.25296463724126, 0.3832122509978928, 0.9377173339120208], 
             UndirectedEdge[9, 61] -> 
             RGBColor[
              0.9095066708030527, 0.5932363190069687, 0.34466666805378354`], 
             UndirectedEdge[21, 82] -> 
             RGBColor[
              0.34606714839588365`, 0.4741677029250543, 0.94327207057399], 
             UndirectedEdge[154, 361] -> 
             RGBColor[
              0.39289227512184555`, 0.5147252741957822, 0.9462557262431346], 
             UndirectedEdge[160, 213] -> 
             RGBColor[
              0.8702228477750129, 0.45615422864304855`, 0.21154106500959308`],
              UndirectedEdge[331, 342] -> 
             RGBColor[
              0.5277253347918338, 0.6274369503840362, 0.9559728122191802], 
             UndirectedEdge[122, 159] -> 
             RGBColor[
              0.3887610902465449, 0.5111470494961861, 0.9459924907959437], 
             UndirectedEdge[258, 278] -> 
             RGBColor[
              0.25267444257649463`, 0.38290723800581994`, 0.937700807755167], 
             UndirectedEdge[37, 201] -> 
             RGBColor[
              0.26311290635419504`, 0.3938787252730125, 0.9382952628249838], 
             UndirectedEdge[61, 314] -> 
             RGBColor[
              0.9595789423265859, 0.965928622564677, 0.7549534149051582], 
             UndirectedEdge[297, 314] -> 
             RGBColor[
              0.9362255007006572, 0.9517027043636277, 0.9839981831745597], 
             UndirectedEdge[84, 175] -> 
             RGBColor[
              0.1789295778879611, 0.3053967095236947, 0.9335011468069058], 
             UndirectedEdge[72, 374] -> 
             RGBColor[
              0.25191511783451104`, 0.3821091395580259, 0.9376575653344313], 
             UndirectedEdge[168, 180] -> 
             RGBColor[
              0.5182102560481305, 0.6169561699548207, 0.9561586879091916], 
             UndirectedEdge[36, 60] -> 
             RGBColor[
              0.4386028192989782, 0.5525156396146701, 0.9496662072988238], 
             UndirectedEdge[347, 387] -> 
             RGBColor[
              0.2868094179961087, 0.41878526145427897`, 0.9396447441071433], 
             UndirectedEdge[140, 141] -> 
             RGBColor[
              0.5159944713875729, 0.6149616035084853, 0.9560493981699523], 
             UndirectedEdge[233, 382] -> 
             RGBColor[
              0.8581195774771997, 0.3842334181920808, 0.20080199431053547`], 
             UndirectedEdge[21, 122] -> 
             RGBColor[
              0.37950236392749337`, 0.5031276061157393, 0.9454025329420639], 
             UndirectedEdge[202, 268] -> 
             RGBColor[
              0.836829312925746, 0.2840918146209231, 0.18290109769144122`], 
             UndirectedEdge[196, 344] -> 
             RGBColor[
              0.3092763827236792, 0.441300833748132, 0.9409644308152758], 
             UndirectedEdge[109, 343] -> 
             RGBColor[
              0.8581485111146978, 0.8873672938614341, 0.8602232482931473], 
             UndirectedEdge[52, 117] -> 
             RGBColor[
              0.36808130040816744`, 0.4932352549346425, 0.9446747928738624], 
             UndirectedEdge[51, 194] -> 
             RGBColor[
              0.38048922371828053`, 0.5039823744655038, 0.945465414775287], 
             UndirectedEdge[223, 342] -> 
             RGBColor[
              0.5287126959381665, 0.6282718106549494, 0.9560413466441238], 
             UndirectedEdge[241, 374] -> 
             RGBColor[
              0.2835328374534444, 0.4153413675567334, 0.939458147692505], 
             UndirectedEdge[76, 109] -> 
             RGBColor[
              0.9205204428847344, 0.6768339136433675, 0.4700439928721189], 
             UndirectedEdge[90, 381] -> 
             RGBColor[
              0.849476415301395, 0.8807671291171392, 0.8672733890419332], 
             UndirectedEdge[75, 227] -> 
             RGBColor[
              0.2395500669875186, 0.36911268712833206`, 0.9369533939811485], 
             UndirectedEdge[209, 329] -> 
             RGBColor[
              0.24358590725750107`, 0.37335461113913604`, 0.9371832291140334],
              UndirectedEdge[24, 358] -> 
             RGBColor[
              0.9353648485028525, 0.777122720375753, 0.28624658001000514`], 
             UndirectedEdge[208, 369] -> 
             RGBColor[
              0.24527033350139205`, 0.37512504992025775`, 0.9372791546967377],
              UndirectedEdge[62, 400] -> 
             RGBColor[
              0.2843395833350594, 0.4087127954077557, 0.9397778424506229], 
             UndirectedEdge[127, 325] -> 
             RGBColor[
              0.21103171786447747`, 0.3391380940322466, 0.9353293161877081], 
             UndirectedEdge[43, 277] -> 
             RGBColor[
              0.2426240388727448, 0.37234362648077923`, 0.9371284521324783], 
             UndirectedEdge[70, 227] -> 
             RGBColor[
              0.25636607330828476`, 0.3867873759678386, 0.9379110406640643], 
             UndirectedEdge[25, 366] -> 
             RGBColor[
              0.8749957803146731, 0.510019968284747, 0.21680872378706678`], 
             UndirectedEdge[20, 387] -> 
             RGBColor[
              0.3506138656824209, 0.476702600538333, 0.94361316288308], 
             UndirectedEdge[328, 387] -> 
             RGBColor[
              0.30150296805800375`, 0.4341652094015489, 0.9404838599135137], 
             UndirectedEdge[249, 386] -> 
             RGBColor[
              0.3044662110801129, 0.4345129066433197, 0.9407539204836926], 
             UndirectedEdge[110, 243] -> 
             RGBColor[
              0.2719749479938126, 0.4031932929221435, 0.9387999429861442], 
             UndirectedEdge[47, 121] -> 
             RGBColor[
              0.4935440296663224, 0.5991928393789325, 0.9534184801906773], 
             UndirectedEdge[31, 156] -> 
             RGBColor[
              0.18458847622123073`, 0.3113445704668384, 0.9338234126953957], 
             UndirectedEdge[98, 283] -> 
             RGBColor[
              0.9432427006605664, 0.8062936865407971, 0.3064669136008217], 
             UndirectedEdge[38, 358] -> 
             RGBColor[
              0.9671839420965409, 0.9009658724941282, 0.3270162411479497], 
             UndirectedEdge[126, 199] -> 
             RGBColor[
              0.21892225618889471`, 0.3474315501002342, 0.9357786706722784], 
             UndirectedEdge[39, 200] -> 
             RGBColor[
              0.27187585958380484`, 0.4030891447206572, 0.9387943000477824], 
             UndirectedEdge[227, 304] -> 
             RGBColor[
              0.22701022275090071`, 0.35593251576360085`, 0.9362392684029103],
              UndirectedEdge[242, 333] -> 
             RGBColor[
              0.5569536477379948, 0.5184281382754727, 0.5938032026627618], 
             UndirectedEdge[30, 333] -> 
             RGBColor[
              0.1872437438170861, 0.31413542506377157`, 0.9339746262568631], 
             UndirectedEdge[85, 96] -> 
             RGBColor[
              0.2641094772748117, 0.3949261844968264, 0.9383520160646184], 
             UndirectedEdge[39, 94] -> 
             RGBColor[
              0.2666080163774077, 0.39755230751018356`, 0.9384943041702538], 
             UndirectedEdge[63, 138] -> 
             RGBColor[
              0.8889519646070447, 0.5107811215593289, 0.22983700543826907`], 
             UndirectedEdge[119, 324] -> 
             RGBColor[
              0.26022801088632164`, 0.3908465172233403, 0.9381309722959088], 
             UndirectedEdge[18, 224] -> 
             RGBColor[
              0.960434037083298, 0.9441092105197667, 0.6687925780376456], 
             UndirectedEdge[84, 204] -> 
             RGBColor[
              0.17892700714738574`, 0.30539400751235557`, 0.933501000407033], 
             UndirectedEdge[241, 288] -> 
             RGBColor[
              0.2679939698052205, 0.39900903243733754`, 0.9385732321676334], 
             UndirectedEdge[91, 266] -> 
             RGBColor[
              0.25880957199136756`, 0.38935564801052325`, 0.9380501942992334],
              UndirectedEdge[201, 263] -> 
             RGBColor[
              0.26925494850456955`, 0.4003344010010207, 0.9386450430391104], 
             UndirectedEdge[29, 266] -> 
             RGBColor[
              0.2477135704987891, 0.37769304691469485`, 0.9374182934292943], 
             UndirectedEdge[161, 326] -> 
             RGBColor[
              0.3854134409611904, 0.5082474839429573, 0.9457791815436909], 
             UndirectedEdge[174, 235] -> 
             RGBColor[
              0.7343495307888845, 0.7923987018062052, 0.9741567564086497], 
             UndirectedEdge[207, 233] -> 
             RGBColor[
              0.8786570254685007, 0.4672262975790694, 0.21740805642807715`], 
             UndirectedEdge[199, 212] -> 
             RGBColor[
              0.21834996970250586`, 0.3468300407179805, 0.9357460798035004], 
             UndirectedEdge[127, 184] -> 
             RGBColor[
              0.21412931839643223`, 0.34239386859054827`, 0.9355057199555137],
              UndirectedEdge[261, 381] -> 
             RGBColor[
              0.5862976993087463, 0.6486880635605781, 0.8483828425372609], 
             UndirectedEdge[221, 230] -> 
             RGBColor[
              0.9453580743501937, 0.9235697837599854, 0.6629627899588003], 
             UndirectedEdge[22, 273] -> 
             RGBColor[
              0.28387789683872655`, 0.4157040468486936, 0.9394777983140272], 
             UndirectedEdge[240, 292] -> 
             RGBColor[
              0.2251125947151853, 0.3539379883814973, 0.9361312012935654], 
             UndirectedEdge[50, 130] -> 
             RGBColor[
              0.4322766112650586, 0.5488154801889021, 0.9487714854439504], 
             UndirectedEdge[120, 343] -> 
             RGBColor[
              0.64428944346767, 0.7208791499127623, 0.9659761919445966], 
             UndirectedEdge[175, 310] -> 
             RGBColor[
              0.18075514602575382`, 0.30731549738422004`, 0.933605110211667], 
             UndirectedEdge[55, 201] -> 
             RGBColor[
              0.33997947002411655`, 0.46590668357700793`, 0.9429935809374401],
              UndirectedEdge[264, 333] -> 
             RGBColor[
              0.19279573500831393`, 0.31997091982232506`, 0.9342908039417687],
              UndirectedEdge[107, 197] -> 
             RGBColor[
              0.9139845567949747, 0.6460331456516251, 0.5106347906861869], 
             UndirectedEdge[131, 300] -> 
             RGBColor[
              0.9062314787117222, 0.661847076989811, 0.24319781291959908`], 
             UndirectedEdge[164, 227] -> 
             RGBColor[
              0.23873025962291325`, 0.36825101760934276`, 0.9369067071645306],
              UndirectedEdge[75, 315] -> 
             RGBColor[
              0.24372617436870905`, 0.3735020407664642, 0.9371912171185102], 
             UndirectedEdge[123, 193] -> 
             RGBColor[
              0.8983178729767032, 0.9207629901755221, 0.9556553997903747], 
             UndirectedEdge[157, 253] -> 
             RGBColor[
              0.40547981020843754`, 0.5251955404755204, 0.9471772728723662], 
             UndirectedEdge[87, 110] -> 
             RGBColor[
              0.27285833032697415`, 0.4041217837639711, 0.9388502503031707], 
             UndirectedEdge[112, 273] -> 
             RGBColor[
              0.30217928403804095`, 0.4330746327553852, 0.940588334197813], 
             UndirectedEdge[193, 384] -> 
             RGBColor[
              0.7853837252276628, 0.8322860419074539, 0.9792383154624147], 
             UndirectedEdge[95, 249] -> 
             RGBColor[
              0.2756739059578213, 0.4070811322697972, 0.9390105931700766], 
             UndirectedEdge[61, 66] -> 
             RGBColor[
              0.9830643953423903, 0.9540141570597834, 0.4329439736998075], 
             UndirectedEdge[113, 251] -> 
             RGBColor[
              0.8094157442625041, 0.8510598457172036, 0.9816336535080088], 
             UndirectedEdge[107, 131] -> 
             RGBColor[
              0.8808419295941465, 0.5163805585259162, 0.22083043617809295`], 
             UndirectedEdge[71, 343] -> 
             RGBColor[
              0.7966602927353739, 0.841489655974727, 0.98025763017568], 
             UndirectedEdge[113, 168] -> 
             RGBColor[
              0.7333330676267822, 0.7916046330585647, 0.9740554448600397], 
             UndirectedEdge[58, 201] -> 
             RGBColor[
              0.2876186397714912, 0.4196358048478299, 0.939690828090115], 
             UndirectedEdge[47, 130] -> 
             RGBColor[
              0.4221487542491271, 0.5400657659424366, 0.9481199232226362], 
             UndirectedEdge[17, 82] -> 
             RGBColor[
              0.4573668797759753, 0.5683380513272105, 0.9509806674680623], 
             UndirectedEdge[11, 25] -> 
             RGBColor[
              0.8860868883930885, 0.5548412704093811, 0.2257767948788701], 
             UndirectedEdge[73, 392] -> 
             RGBColor[
              0.24553259442115521`, 0.3754007027752315, 0.9372940900681379], 
             UndirectedEdge[155, 337] -> 
             RGBColor[
              0.29464447603044647`, 0.42702040421973947`, 0.9400909390712692],
              UndirectedEdge[159, 165] -> 
             RGBColor[
              0.43209168429834016`, 0.5465211004605023, 0.9493493893401392], 
             UndirectedEdge[226, 368] -> 
             RGBColor[
              0.2257077662103317, 0.35456355135894857`, 0.9361650954297367], 
             UndirectedEdge[188, 258] -> 
             RGBColor[
              0.2600095899871553, 0.39061694300963157`, 0.938118533548826], 
             UndirectedEdge[140, 350] -> 
             RGBColor[
              0.5523338730537959, 0.6464369667603329, 0.9583649127104528], 
             UndirectedEdge[14, 38] -> 
             RGBColor[
              0.9800741446959539, 0.9433032752196526, 0.4743933351284341], 
             UndirectedEdge[242, 268] -> 
             RGBColor[
              0.8678329199624942, 0.4240532300724246, 0.2086880773194431], 
             UndirectedEdge[20, 50] -> 
             RGBColor[
              0.4309033063250306, 0.5476259924741631, 0.9486839796675377], 
             UndirectedEdge[149, 212] -> 
             RGBColor[
              0.21555790485274898`, 0.34389540353375003`, 0.9355870758407967],
              UndirectedEdge[80, 361] -> 
             RGBColor[
              0.34502145958500996`, 0.47326197983492335`, 0.9432054402076274],
              UndirectedEdge[31, 204] -> 
             RGBColor[
              0.1810722066459815, 0.3076487481988837, 0.9336231663449399], 
             UndirectedEdge[209, 245] -> 
             RGBColor[
              0.2409659187206967, 0.37060083707008695`, 0.9370340246427882], 
             UndirectedEdge[113, 148] -> 
             RGBColor[
              0.7102018348766541, 0.7732513864434318, 0.9719433954351793], 
             UndirectedEdge[48, 231] -> 
             RGBColor[
              0.3670635094292236, 0.49234797467679914`, 0.9446101496016666], 
             UndirectedEdge[198, 224] -> 
             RGBColor[
              0.901075568718926, 0.8970235530331128, 0.6716312488962854], 
             UndirectedEdge[1, 188] -> 
             RGBColor[
              0.3135344759290187, 0.4421377779902256, 0.9413401492239378], 
             UndirectedEdge[256, 264] -> 
             RGBColor[
              0.2076696899760163, 0.3356043895565939, 0.9351378536731348], 
             UndirectedEdge[15, 170] -> 
             RGBColor[
              0.3744152758657625, 0.49826976676104406`, 0.9450949256507872], 
             UndirectedEdge[20, 322] -> 
             RGBColor[
              0.45803755349750475`, 0.5696547967126826, 0.9508200870009773], 
             UndirectedEdge[92, 153] -> 
             RGBColor[
              0.30254730129756563`, 0.4345238091753902, 0.940570393778262], 
             UndirectedEdge[189, 360] -> 
             RGBColor[
              0.30546923311788443`, 0.43824575192600135`, 0.9407129642351355],
              UndirectedEdge[272, 342] -> 
             RGBColor[
              0.6251875638221265, 0.7065231010289125, 0.9636849864326502], 
             UndirectedEdge[69, 219] -> 
             RGBColor[
              0.4677032328653056, 0.5785751319820428, 0.9512844483334466], 
             UndirectedEdge[86, 151] -> 
             RGBColor[
              0.30818593638346986`, 0.44059786327207706`, 0.9408861053327038],
              UndirectedEdge[72, 288] -> 
             RGBColor[
              0.2363762501862872, 0.36577680443863003`, 0.9367726498095597], 
             UndirectedEdge[266, 273] -> 
             RGBColor[
              0.265217664230201, 0.3960909592500517, 0.938415125672312], 
             UndirectedEdge[131, 297] -> 
             RGBColor[
              0.9345525999537521, 0.8450176590746574, 0.6158415354980056], 
             UndirectedEdge[219, 360] -> 
             RGBColor[
              0.37878978346753606`, 0.5025104047366595, 0.9453571279452656], 
             UndirectedEdge[58, 236] -> 
             RGBColor[
              0.27466659649964625`, 0.4060223861621468, 0.9389532283866143], 
             UndirectedEdge[272, 321] -> 
             RGBColor[
              0.7324016958614257, 0.7908770383567805, 0.9739626144266329], 
             UndirectedEdge[250, 391] -> 
             RGBColor[
              0.9043090036006871, 0.5735688958941825, 0.5059642810005588], 
             UndirectedEdge[122, 298] -> 
             RGBColor[
              0.634758859433705, 0.711422615804957, 0.9663329898214426], 
             UndirectedEdge[113, 282] -> 
             RGBColor[
              0.7216887092702036, 0.7825079718100041, 0.9728948440417715], 
             UndirectedEdge[237, 343] -> 
             RGBColor[
              0.6503098019378368, 0.7257667481329021, 0.9664501366166679], 
             UndirectedEdge[174, 398] -> 
             RGBColor[
              0.83401539327211, 0.8711277377968187, 0.9805027030161089], 
             UndirectedEdge[223, 384] -> 
             RGBColor[
              0.6012475155961567, 0.6855340055780029, 0.9628624648765374], 
             UndirectedEdge[143, 260] -> 
             RGBColor[
              0.7167991404658595, 0.7784168360748085, 0.9725930329082488], 
             UndirectedEdge[148, 161] -> 
             RGBColor[
              0.5276623353729026, 0.6268249505740837, 0.9561228183174523], 
             UndirectedEdge[137, 199] -> 
             RGBColor[
              0.22367942926895015`, 0.3524316406295666, 0.9360495846415806], 
             UndirectedEdge[147, 387] -> 
             RGBColor[
              0.28915329202202544`, 0.42124882166571403`, 0.9397782242654684],
              UndirectedEdge[138, 381] -> 
             RGBColor[
              0.9062449527279615, 0.5705587678025101, 0.4646955300926113], 
             UndirectedEdge[42, 207] -> 
             RGBColor[
              0.9360408404789141, 0.8740255032004962, 0.6319312562767279], 
             UndirectedEdge[185, 247] -> 
             RGBColor[
              0.8653490116625105, 0.42606196440460237`, 0.20717681371904806`],
              UndirectedEdge[49, 380] -> 
             RGBColor[
              0.2606135317686764, 0.39125172411413095`, 0.9381529271398318], 
             UndirectedEdge[63, 242] -> 
             RGBColor[
              0.9384539463641798, 0.7929291511512139, 0.2733380495894395], 
             UndirectedEdge[12, 238] -> 
             RGBColor[
              0.22383004590865202`, 0.3525899482675398, 0.9360581620363942], 
             UndirectedEdge[109, 382] -> 
             RGBColor[
              0.9464386860434384, 0.8125481887830079, 0.4923766470320703], 
             UndirectedEdge[4, 115] -> 
             RGBColor[
              0.23540129852856206`, 0.36475206843085556`, 0.936717127754964], 
             UndirectedEdge[187, 279] -> 
             RGBColor[
              0.8947917399967904, 0.8503099582405043, 0.6300514927715455], 
             UndirectedEdge[152, 156] -> 
             RGBColor[
              0.18478785261667285`, 0.31155412769964164`, 0.9338347668861651],
              UndirectedEdge[143, 290] -> 
             RGBColor[
              0.5148889820990041, 0.6157407807626738, 0.9553145849297924], 
             UndirectedEdge[48, 234] -> 
             RGBColor[
              0.38209114426819646`, 0.5053698775309731, 0.945567487736205], 
             UndirectedEdge[294, 341] -> 
             RGBColor[
              0.21717163219876068`, 0.3455915332906315, 0.9356789752258563], 
             UndirectedEdge[243, 351] -> 
             RGBColor[
              0.26705822161415743`, 0.39802550175866824`, 0.9385199426924677],
              UndirectedEdge[241, 399] -> 
             RGBColor[
              0.2629204824738216, 0.3936764755743613, 0.938284304569662], 
             UndirectedEdge[78, 207] -> 
             RGBColor[
              0.8908498839236407, 0.5609459506099194, 0.22908395145458324`], 
             UndirectedEdge[174, 267] -> 
             RGBColor[
              0.6499021646261236, 0.725337696254724, 0.9664851266806084], 
             UndirectedEdge[124, 293] -> 
             RGBColor[
              0.21725116581640602`, 0.3456751281654994, 0.9356835045477219], 
             UndirectedEdge[57, 392] -> 
             RGBColor[
              0.2605783177897506, 0.3912147119895847, 0.9381509217558264], 
             UndirectedEdge[272, 331] -> 
             RGBColor[
              0.5495546990516302, 0.6450876581742866, 0.9577400845269233], 
             UndirectedEdge[91, 255] -> 
             RGBColor[
              0.26154809523840944`, 0.39223400957556664`, 0.9382061491468703],
              UndirectedEdge[35, 337] -> 
             RGBColor[
              0.28289219144336497`, 0.41466800798083686`, 0.9394216638499819],
              UndirectedEdge[219, 339] -> 
             RGBColor[
              0.4064741730871376, 0.5264892315672777, 0.9471211527714821], 
             UndirectedEdge[166, 185] -> 
             RGBColor[
              0.8242297938213237, 0.1872463896398561, 0.17083578396792481`], 
             UndirectedEdge[137, 238] -> 
             RGBColor[
              0.22538960071026484`, 0.3542291392455204, 0.9361469763751915], 
             UndirectedEdge[218, 300] -> 
             RGBColor[
              0.9000302759419758, 0.7622535258714493, 0.6106034215734397], 
             UndirectedEdge[96, 110] -> 
             RGBColor[
              0.2712447160930261, 0.4024257728950402, 0.9387583573596757], 
             UndirectedEdge[225, 375] -> 
             RGBColor[
              0.2559767228165143, 0.3863781439147409, 0.9378888677295503], 
             UndirectedEdge[24, 25] -> 
             RGBColor[
              0.8754320696783777, 0.5120010563873596, 0.21717277432657275`], 
             UndirectedEdge[40, 361] -> 
             RGBColor[
              0.34746932604333547`, 0.4753821987277793, 0.9433614160937887], 
             UndirectedEdge[141, 394] -> 
             RGBColor[
              0.3594659493572627, 0.4857730708744833, 0.9441258303231546], 
             UndirectedEdge[200, 360] -> 
             RGBColor[
              0.29052568872167633`, 0.4225391392901483, 0.9398619514887643], 
             UndirectedEdge[68, 229] -> 
             RGBColor[
              0.2618103919644219, 0.39250970006517877`, 0.9382210865573835], 
             UndirectedEdge[96, 258] -> 
             RGBColor[
              0.26992237493120286`, 0.4010359084926919, 0.9386830519867384], 
             UndirectedEdge[106, 310] -> 
             RGBColor[
              0.5655364837016175, 0.6351698449942476, 0.952888973704525], 
             UndirectedEdge[15, 394] -> 
             RGBColor[
              0.33136443385417313`, 0.4609812912088401, 0.9423517640661736], 
             UndirectedEdge[115, 203] -> 
             RGBColor[
              0.265001837635785, 0.3958641118151241, 0.9384028346670469], 
             UndirectedEdge[218, 298] -> 
             RGBColor[
              0.8667469534105012, 0.8965845097029781, 0.9871522922420749], 
             UndirectedEdge[165, 262] -> 
             RGBColor[
              0.7356958172611161, 0.7926545035064209, 0.9725524468455675], 
             UndirectedEdge[141, 357] -> 
             RGBColor[
              0.5178770250869611, 0.6164322687663853, 0.9562370335292427], 
             UndirectedEdge[15, 239] -> 
             RGBColor[
              0.3141879177885835, 0.4461038563096259, 0.9412572916510711], 
             UndirectedEdge[80, 228] -> 
             RGBColor[
              0.35113678778418134`, 0.4785587697557132, 0.9435951035129062], 
             UndirectedEdge[260, 272] -> 
             RGBColor[
              0.7279854810242253, 0.7874270577614837, 0.9735224474035349], 
             UndirectedEdge[7, 361] -> 
             RGBColor[
              0.3725157575792012, 0.497076158853894, 0.9449573525635642], 
             UndirectedEdge[22, 255] -> 
             RGBColor[
              0.27639668732322686`, 0.40784082131182386`, 0.9390517544995772],
              UndirectedEdge[28, 380] -> 
             RGBColor[
              0.2768898890919296, 0.40835920764152867`, 0.9390798416106783], 
             UndirectedEdge[53, 397] -> 
             RGBColor[
              0.26929675474869136`, 0.4003783420142617, 0.9386474238428664], 
             UndirectedEdge[187, 306] -> 
             RGBColor[
              0.9071549779062498, 0.8950638881018478, 0.6621967951023203], 
             UndirectedEdge[208, 392] -> 
             RGBColor[
              0.24051796511845452`, 0.3701300094322317, 0.9370085143478284], 
             UndirectedEdge[33, 381] -> 
             RGBColor[
              0.5860442078575524, 0.648421627973087, 0.8483684065741224], 
             UndirectedEdge[290, 321] -> 
             RGBColor[
              0.6114600904368728, 0.6914542319869668, 0.964754355111318], 
             UndirectedEdge[20, 116] -> 
             RGBColor[
              0.4119401607737857, 0.531223595372923, 0.9474694406734923], 
             UndirectedEdge[33, 156] -> 
             RGBColor[
              0.18245046291019928`, 0.30909738291907096`, 0.9337016560002396],
              UndirectedEdge[9, 202] -> 
             RGBColor[
              0.8410035318945833, 0.31617669076982174`, 0.1868983344901058], 
             UndirectedEdge[76, 233] -> 
             RGBColor[
              0.8322013343184957, 0.24851914305244047`, 0.17846934015058413`],
              UndirectedEdge[115, 369] -> 
             RGBColor[
              0.24803002426208054`, 0.37802565988424164`, 0.9374363150029623],
              UndirectedEdge[183, 335] -> 
             RGBColor[
              0.2697259044179279, 0.4008294055262898, 0.9386718632816594], 
             UndirectedEdge[39, 296] -> 
             RGBColor[
              0.2873068026652887, 0.4193080442775966, 0.9396730694282384], 
             UndirectedEdge[10, 219] -> 
             RGBColor[
              0.4045568603314619, 0.5248285516252523, 0.9469989832981036], 
             UndirectedEdge[71, 143] -> 
             RGBColor[
              0.7478821300066041, 0.8031124171001021, 0.9755814141619994], 
             UndirectedEdge[232, 384] -> 
             RGBColor[
              0.6369922413654878, 0.7145531842390913, 0.965676420626344], 
             UndirectedEdge[1, 57] -> 
             RGBColor[
              0.31659522838756854`, 0.44535482288707584`, 0.9415144545484747],
              UndirectedEdge[288, 393] -> 
             RGBColor[
              0.23392299503197628`, 0.3631982777260886, 0.9366329405577875], 
             UndirectedEdge[328, 372] -> 
             RGBColor[
              0.2804573452843499, 0.4120449254968854, 0.9392853428307628], 
             UndirectedEdge[16, 115] -> 
             RGBColor[
              0.240233305102069, 0.36983081370652304`, 0.936992303381012], 
             UndirectedEdge[34, 244] -> 
             RGBColor[
              0.2861625929026812, 0.4177778317374103, 0.9396199025198813], 
             UndirectedEdge[233, 366] -> 
             RGBColor[
              0.8593693391869154, 0.3899082942266366, 0.20184482611558502`], 
             UndirectedEdge[100, 105] -> 
             RGBColor[
              0.3969790975995051, 0.5182650744162607, 0.9465161349575758], 
             UndirectedEdge[88, 282] -> 
             RGBColor[
              0.8185877701205739, 0.8571575543356513, 0.887813136638508], 
             UndirectedEdge[189, 219] -> 
             RGBColor[
              0.37386729373661226`, 0.4974887142474586, 0.9450712281757306], 
             UndirectedEdge[44, 328] -> 
             RGBColor[
              0.3036968641952127, 0.4364711333428047, 0.9406087990529493], 
             UndirectedEdge[153, 154] -> 
             RGBColor[
              0.3737943950019111, 0.49818365032325973`, 0.9450388262094847], 
             UndirectedEdge[73, 258] -> 
             RGBColor[
              0.2480246190771097, 0.3780199786921288, 0.9374360071856744], 
             UndirectedEdge[22, 141] -> 
             RGBColor[
              0.32619117202571163`, 0.45543328701971864`, 0.9420612032605917],
              UndirectedEdge[100, 273] -> 
             RGBColor[
              0.3260257412647034, 0.4537292354473304, 0.9421078093657018], 
             UndirectedEdge[230, 391] -> 
             RGBColor[
              0.8946240115133538, 0.5321742003823082, 0.2503381046492794], 
             UndirectedEdge[338, 384] -> 
             RGBColor[
              0.8713581064441347, 0.8967942587815345, 0.7976314467612728], 
             UndirectedEdge[76, 207] -> 
             RGBColor[
              0.8934001271128089, 0.5805482372855583, 0.23152606721261854`], 
             UndirectedEdge[144, 370] -> 
             RGBColor[
              0.8548273648949809, 0.7045756223106869, 0.6020207461756493], 
             UndirectedEdge[6, 340] -> 
             RGBColor[
              0.9935628356137232, 0.988639881211936, 0.5407325660065214], 
             UndirectedEdge[30, 370] -> 
             RGBColor[
              0.5050718279609444, 0.5868238115344944, 0.9586321897581539], 
             UndirectedEdge[164, 245] -> 
             RGBColor[
              0.23621867801950508`, 0.36561118610068966`, 0.9367636763077685],
              UndirectedEdge[56, 108] -> 
             RGBColor[
              0.40925205503740436`, 0.5288952932921922, 0.9472981569529686], 
             UndirectedEdge[50, 322] -> 
             RGBColor[
              0.4812818793914586, 0.5897653370483966, 0.952307419020761], 
             UndirectedEdge[379, 399] -> 
             RGBColor[
              0.22791818849812123`, 0.356886845332283, 0.9362909757089996], 
             UndirectedEdge[6, 13] -> 
             RGBColor[
              0.978563836078469, 0.9803436260913665, 0.7317471315868381], 
             UndirectedEdge[55, 60] -> 
             RGBColor[
              0.38053049793671245`, 0.5040181241190069, 0.9454680447319882], 
             UndirectedEdge[44, 47] -> 
             RGBColor[
              0.36592423069765223`, 0.4903693505688373, 0.9445738718209851], 
             UndirectedEdge[156, 264] -> 
             RGBColor[
              0.1879952768080626, 0.31492533388723165`, 0.9340174249489059], 
             UndirectedEdge[32, 43] -> 
             RGBColor[
              0.2218603287150994, 0.3505196506098328, 0.9359459895561568], 
             UndirectedEdge[144, 207] -> 
             RGBColor[
              0.9091469621070289, 0.6700765235430096, 0.2453714490760957], 
             UndirectedEdge[14, 213] -> 
             RGBColor[
              0.9526625957676589, 0.8375319772984231, 0.4372009912003371], 
             UndirectedEdge[127, 139] -> 
             RGBColor[
              0.2108331954164144, 0.3389294343522821, 0.9353180106279786], 
             UndirectedEdge[321, 342] -> 
             RGBColor[
              0.7105723316016292, 0.7732263305665302, 0.9721953421188899], 
             UndirectedEdge[82, 182] -> 
             RGBColor[
              0.3336557333984177, 0.4615081693978327, 0.9425511382946132], 
             UndirectedEdge[50, 172] -> 
             RGBColor[
              0.3777861468106212, 0.500941670871986, 0.945324186142565], 
             UndirectedEdge[80, 96] -> 
             RGBColor[
              0.31066394327551555`, 0.4414844762785116, 0.9410901259683782], 
             UndirectedEdge[78, 160] -> 
             RGBColor[
              0.835660765688327, 0.2751098484934552, 0.18178209553720334`], 
             UndirectedEdge[32, 293] -> 
             RGBColor[
              0.2137582367821496, 0.342003838286004, 0.9354845874065463], 
             UndirectedEdge[322, 328] -> 
             RGBColor[
              0.4089266558730876, 0.5271174055758985, 0.947690784031411], 
             UndirectedEdge[120, 254] -> 
             RGBColor[
              0.5179448523327678, 0.6195299901302602, 0.955193662551596], 
             UndirectedEdge[291, 321] -> 
             RGBColor[
              0.7571390218362452, 0.8102020254189503, 0.9764281998963484], 
             UndirectedEdge[65, 312] -> 
             RGBColor[
              0.4891446804627151, 0.5961487131731942, 0.9529264075234798], 
             UndirectedEdge[209, 334] -> 
             RGBColor[
              0.2567160128781451, 0.387155184643212, 0.9379309692048785], 
             UndirectedEdge[295, 310] -> 
             RGBColor[
              0.2124827502833183, 0.3406632211052174, 0.935411950337351], 
             UndirectedEdge[109, 205] -> 
             RGBColor[
              0.9946824810618875, 0.9920690835121566, 0.737788580309801], 
             UndirectedEdge[194, 376] -> 
             RGBColor[
              0.4132241787161002, 0.5323357471779375, 0.947551257161364], 
             UndirectedEdge[142, 338] -> 
             RGBColor[
              0.9079361737525008, 0.5785505948422507, 0.3940025431841314], 
             UndirectedEdge[232, 386] -> 
             RGBColor[
              0.4324598922567031, 0.5470353068857565, 0.9493188938960907], 
             UndirectedEdge[169, 378] -> 
             RGBColor[
              0.21461245212241514`, 0.34290167276900374`, 0.9355332337064761],
              UndirectedEdge[94, 324] -> 
             RGBColor[
              0.2700408112862358, 0.4011603926111301, 0.9386897967619465], 
             UndirectedEdge[196, 231] -> 
             RGBColor[
              0.3033041199951848, 0.43612223907981873`, 0.9405840929842658], 
             UndirectedEdge[207, 366] -> 
             RGBColor[
              0.9205681319812286, 0.7219373884597544, 0.2549015531776194], 
             UndirectedEdge[156, 310] -> 
             RGBColor[
              0.1842688448604277, 0.3110086176408356, 0.93380521016225], 
             UndirectedEdge[206, 369] -> 
             RGBColor[
              0.2445080094379043, 0.3743237989953949, 0.9372357414690795], 
             UndirectedEdge[119, 225] -> 
             RGBColor[
              0.24880323623162193`, 0.37883835468870003`, 0.9374803482807631],
              UndirectedEdge[69, 100] -> 
             RGBColor[
              0.4324163535905058, 0.5480114107243323, 0.9490359995890186], 
             UndirectedEdge[64, 182] -> 
             RGBColor[
              0.34352729206089855`, 0.4700584173523088, 0.9431801452835099], 
             UndirectedEdge[217, 268] -> 
             RGBColor[
              0.8200723347530428, 0.15529033743086842`, 0.16685459646896056`],
              UndirectedEdge[235, 275] -> 
             RGBColor[
              0.8660971591696807, 0.893943749566336, 0.8776528174795629], 
             UndirectedEdge[5, 99] -> 
             RGBColor[
              0.9097853137766493, 0.92980801321679, 0.9533236132867424], 
             UndirectedEdge[52, 267] -> 
             RGBColor[
              0.4789222153161444, 0.5860393403630161, 0.9526218530734996], 
             UndirectedEdge[290, 346] -> 
             RGBColor[
              0.3750828645825507, 0.4992996579136456, 0.9451209263518141], 
             UndirectedEdge[19, 108] -> 
             RGBColor[
              0.3209765938651673, 0.4492585340761873, 0.9417896478514372], 
             UndirectedEdge[92, 327] -> 
             RGBColor[
              0.3031279877877182, 0.4350267706270088, 0.9406073946079336], 
             UndirectedEdge[151, 244] -> 
             RGBColor[
              0.28793584651295273`, 0.41931373488830953`, 0.9397328926719012],
              UndirectedEdge[114, 327] -> 
             RGBColor[
              0.32373500724345117`, 0.4548247247048681, 0.941849086287294], 
             UndirectedEdge[99, 174] -> 
             RGBColor[
              0.8533664925541351, 0.885559755956836, 0.9477463395066474], 
             UndirectedEdge[180, 282] -> 
             RGBColor[
              0.5065658976915518, 0.60785950870626, 0.9549980870909234], 
             UndirectedEdge[199, 277] -> 
             RGBColor[
              0.24180779724081597`, 0.3714857047729135, 0.9370819683790612], 
             UndirectedEdge[237, 286] -> 
             RGBColor[
              0.652334455595527, 0.7273484229582274, 0.9666519351718024], 
             UndirectedEdge[290, 313] -> 
             RGBColor[
              0.34397103520992167`, 0.4699540423686539, 0.9432263147475373], 
             UndirectedEdge[56, 237] -> 
             RGBColor[
              0.5146770314008289, 0.6168123226982427, 0.9549542854004349], 
             UndirectedEdge[203, 361] -> 
             RGBColor[
              0.32351204834138475`, 0.4530276285511149, 0.941893609121445], 
             UndirectedEdge[169, 315] -> 
             RGBColor[
              0.23198634740170132`, 0.3611627382761178, 0.9365226513402567], 
             UndirectedEdge[23, 304] -> 
             RGBColor[
              0.2162581809318601, 0.34463143809296365`, 0.9356269555275363], 
             UndirectedEdge[129, 270] -> 
             RGBColor[
              0.24363580909960866`, 0.3734070611391507, 0.9371860709501183], 
             UndirectedEdge[85, 284] -> 
             RGBColor[
              0.24265277809452013`, 0.37237383322503703`, 0.9371300887886426],
              UndirectedEdge[203, 369] -> 
             RGBColor[
              0.2744257623445868, 0.405769254195412, 0.9389395132377659], 
             UndirectedEdge[1, 222] -> 
             RGBColor[
              0.48245496695292606`, 0.5881834392083616, 0.9530999932353155], 
             UndirectedEdge[25, 205] -> 
             RGBColor[
              0.9219898136234065, 0.68386598697934, 0.46117782525974793`], 
             UndirectedEdge[301, 380] -> 
             RGBColor[
              0.26115428543555863`, 0.39182009050378686`, 0.9381837222611874],
              UndirectedEdge[169, 329] -> 
             RGBColor[
              0.22791864695390707`, 0.3568873271983817, 0.9362910018173783], 
             UndirectedEdge[302, 340] -> 
             RGBColor[
              0.9905275811721996, 0.978922480132596, 0.484619975557615], 
             UndirectedEdge[205, 391] -> 
             RGBColor[
              0.9078296512801215, 0.575024774186147, 0.4476180378082022], 
             UndirectedEdge[96, 203] -> 
             RGBColor[
              0.28915453203189034`, 0.42125012499470316`, 0.9397782948821958],
              UndirectedEdge[4, 195] -> 
             RGBColor[
              0.2389456018045329, 0.3684773558957079, 0.9369189705832036], 
             UndirectedEdge[269, 298] -> 
             RGBColor[
              0.908244530929823, 0.9248034643520736, 0.7344530675019115], 
             UndirectedEdge[168, 220] -> 
             RGBColor[
              0.5727925024434088, 0.663632053166977, 0.9598025445321408], 
             UndirectedEdge[291, 338] -> 
             RGBColor[
              0.8453899770207604, 0.8765077587109009, 0.7950431863063177], 
             UndirectedEdge[10, 360] -> 
             RGBColor[
              0.336158799712734, 0.4655855893037951, 0.9426407193575084], 
             UndirectedEdge[87, 348] -> 
             RGBColor[
              0.27654696971548504`, 0.4079987776345412, 0.9390603128594934], 
             UndirectedEdge[259, 274] -> 
             RGBColor[
              0.22087433163626, 0.34948330516414705`, 0.9358898384811689], 
             UndirectedEdge[293, 336] -> 
             RGBColor[
              0.21111881242536762`, 0.33922963593785627`, 0.935334276094106], 
             UndirectedEdge[229, 245] -> 
             RGBColor[
              0.238397504828522, 0.36790127122256505`, 0.9368877572712566], 
             UndirectedEdge[173, 197] -> 
             RGBColor[
              0.607559522477704, 0.6724367666110929, 0.8861420267905455], 
             UndirectedEdge[19, 344] -> 
             RGBColor[
              0.2975063791842545, 0.4289298137668702, 0.9402941465258654], 
             UndirectedEdge[83, 125] -> 
             RGBColor[
              0.315433813888692, 0.4447906722692076, 0.9414242734794431], 
             UndirectedEdge[240, 315] -> 
             RGBColor[
              0.24124036831115342`, 0.3708893009907661, 0.9370496541409528], 
             UndirectedEdge[7, 154] -> 
             RGBColor[
              0.40978151173656857`, 0.5293538820737408, 0.9473318934656592], 
             UndirectedEdge[200, 225] -> 
             RGBColor[
              0.26388387983793327`, 0.3946890672869635, 0.9383391686243296], 
             UndirectedEdge[13, 140] -> 
             RGBColor[
              0.8178525622986523, 0.8580700202466935, 0.9570649175635426], 
             UndirectedEdge[104, 366] -> 
             RGBColor[
              0.9175772665295729, 0.7100796035907695, 0.25249503263058215`], 
             UndirectedEdge[116, 172] -> 
             RGBColor[
              0.3588230012593764, 0.484539273770746, 0.9441096471485195], 
             UndirectedEdge[143, 267] -> 
             RGBColor[
              0.5979215961089128, 0.6844587136389835, 0.9614897247861196], 
             UndirectedEdge[51, 395] -> 
             RGBColor[
              0.3229957435790246, 0.45088574591651165`, 0.9419227613726417], 
             UndirectedEdge[213, 224] -> 
             RGBColor[
              0.9433148110399261, 0.8071439818533458, 0.30358552172184644`], 
             UndirectedEdge[130, 362] -> 
             RGBColor[
              0.40753230852825906`, 0.5274057353029433, 0.9471885762261179], 
             UndirectedEdge[153, 278] -> 
             RGBColor[
              0.284923192180341, 0.41599975306012926`, 0.939566726836569], 
             UndirectedEdge[83, 303] -> 
             RGBColor[
              0.32124670467921895`, 0.4509003890486145, 0.9417553090105623], 
             UndirectedEdge[94, 296] -> 
             RGBColor[
              0.2808227544696311, 0.4124928985115602, 0.9393038124757853], 
             UndirectedEdge[147, 328] -> 
             RGBColor[
              0.29708750914626414`, 0.42952428212904603`, 0.9402324060605761],
              UndirectedEdge[78, 102] -> 
             RGBColor[
              0.8305704924938522, 0.23598377814878552`, 0.17690764417753302`],
              UndirectedEdge[22, 45] -> 
             RGBColor[
              0.2939087453063859, 0.4262471045807297, 0.94004904029495], 
             UndirectedEdge[199, 238] -> 
             RGBColor[
              0.22751293603602638`, 0.35646089930013114`, 0.9362678971808005],
              UndirectedEdge[21, 182] -> 
             RGBColor[
              0.30050572685967525`, 0.4327952999017487, 0.9404388491913643], 
             UndirectedEdge[126, 212] -> 
             RGBColor[
              0.21146946129668887`, 0.3395981901340374, 0.9353542450285892], 
             UndirectedEdge[273, 365] -> 
             RGBColor[
              0.26583905724777945`, 0.3967440827101195, 0.9384505130853945], 
             UndirectedEdge[149, 367] -> 
             RGBColor[
              0.21976666504097775`, 0.348319077342387, 0.9358267585072135], 
             UndirectedEdge[81, 89] -> 
             RGBColor[
              0.21914913629591037`, 0.3476700154777373, 0.9357915911587338], 
             UndirectedEdge[57, 337] -> 
             RGBColor[
              0.27897537779675124`, 0.41055118849791716`, 0.9391986071072138],
              UndirectedEdge[255, 288] -> 
             RGBColor[
              0.25275048461760563`, 0.38298716301237146`, 0.9377051382369141],
              UndirectedEdge[2, 283] -> 
             RGBColor[
              0.8636832468154017, 0.4097080433065882, 0.20543575312607748`], 
             UndirectedEdge[94, 128] -> 
             RGBColor[
              0.29316856057651314`, 0.42385416586161573`, 0.9400660193797667],
              UndirectedEdge[176, 393] -> 
             RGBColor[
              0.2193217433014607, 0.3478514363844869, 0.9358014208723507], 
             UndirectedEdge[65, 326] -> 
             RGBColor[
              0.4273612108963405, 0.5428967033575929, 0.9489173037481067], 
             UndirectedEdge[97, 282] -> 
             RGBColor[
              0.5445731104291971, 0.6407794460815519, 0.9574198730781076], 
             UndirectedEdge[12, 149] -> 
             RGBColor[
              0.21932780961758047`, 0.3478578124673555, 0.9358017663400795], 
             UndirectedEdge[78, 144] -> 
             RGBColor[
              0.8601410277678558, 0.4317670823407418, 0.2039906170405674], 
             UndirectedEdge[201, 348] -> 
             RGBColor[
              0.2696907546749492, 0.40079246091779686`, 0.9386698615557961], 
             UndirectedEdge[242, 381] -> 
             RGBColor[
              0.9557469344850966, 0.8527067973943953, 0.5081965742437817], 
             UndirectedEdge[43, 367] -> 
             RGBColor[
              0.22337497152266345`, 0.35211163623448327`, 0.9360322462233344],
              UndirectedEdge[111, 197] -> 
             RGBColor[
              0.931414792844472, 0.7553582824181725, 0.5263607215030722], 
             UndirectedEdge[69, 216] -> 
             RGBColor[
              0.5736600979558795, 0.6645056615859741, 0.959755124057878], 
             UndirectedEdge[197, 295] -> 
             RGBColor[
              0.6155693919444334, 0.6808556472756819, 0.8865981770071358], 
             UndirectedEdge[193, 275] -> 
             RGBColor[
              0.9072201261691099, 0.9260883634638468, 0.8817465180078601], 
             UndirectedEdge[149, 238] -> 
             RGBColor[
              0.2247208711862695, 0.3535262621159006, 0.9361088932180968], 
             UndirectedEdge[79, 349] -> 
             RGBColor[
              0.518092548976322, 0.6194343382750406, 0.9552648492680336], 
             UndirectedEdge[16, 110] -> 
             RGBColor[
              0.2487192272457111, 0.3787500559180304, 0.9374755640932957], 
             UndirectedEdge[49, 372] -> 
             RGBColor[
              0.25360695200292194`, 0.3838873645375076, 0.9377539127874779], 
             UndirectedEdge[320, 343] -> 
             RGBColor[
              0.7160472963068527, 0.7781008571267078, 0.9723325607195863], 
             UndirectedEdge[221, 358] -> 
             RGBColor[
              0.9452177942477327, 0.9230965860350502, 0.6624178282504138], 
             UndirectedEdge[240, 245] -> 
             RGBColor[
              0.2345526793265548, 0.3638601158439808, 0.9366688001468292], 
             UndirectedEdge[85, 115] -> 
             RGBColor[
              0.2399567828787064, 0.36954017131724737`, 0.9369765558494695], 
             UndirectedEdge[70, 280] -> 
             RGBColor[
              0.2584116720913199, 0.38893742998726233`, 0.9380275344885658], 
             UndirectedEdge[151, 171] -> 
             RGBColor[
              0.294524052203641, 0.4262383567855898, 0.940108081239609], 
             UndirectedEdge[23, 163] -> 
             RGBColor[
              0.22919558870789478`, 0.35822947394460614`, 0.9363637217612019],
              UndirectedEdge[255, 360] -> 
             RGBColor[
              0.28543335040527573`, 0.4171867688467138, 0.9395719503550848], 
             UndirectedEdge[165, 307] -> 
             RGBColor[
              0.7589943744265952, 0.8098564226113569, 0.9253172138967432], 
             UndirectedEdge[81, 169] -> 
             RGBColor[
              0.22020695780518662`, 0.3487818529537441, 0.9358518325287805], 
             UndirectedEdge[44, 316] -> 
             RGBColor[
              0.27611802500026855`, 0.4075479295421829, 0.9390358850925288], 
             UndirectedEdge[195, 337] -> 
             RGBColor[
              0.26521901916211443`, 0.39609238336940045`, 0.9384152028336801],
              UndirectedEdge[316, 390] -> 
             RGBColor[
              0.26028939055795897`, 0.3909110311499271, 0.9381344677774055], 
             UndirectedEdge[39, 177] -> 
             RGBColor[
              0.29750028265951367`, 0.4288050749279245, 0.9402981320155486], 
             UndirectedEdge[45, 190] -> 
             RGBColor[
              0.2683010399450559, 0.3993317826236759, 0.9385907193578275], 
             UndirectedEdge[287, 396] -> 
             RGBColor[
              0.2692564543945499, 0.400335983786869, 0.9386451287973171], 
             UndirectedEdge[136, 343] -> 
             RGBColor[
              0.6703913429941837, 0.7420698478255596, 0.9680310290897323], 
             UndirectedEdge[296, 360] -> 
             RGBColor[
              0.3059566318031602, 0.4387580388470877, 0.9407407208692202], 
             UndirectedEdge[167, 228] -> 
             RGBColor[
              0.32570332239411426`, 0.45419998876459156`, 0.9420598033482018],
              UndirectedEdge[123, 279] -> 
             RGBColor[
              0.9599728871641575, 0.901288321876893, 0.6017603738326488], 
             UndirectedEdge[33, 333] -> 
             RGBColor[
              0.1872509211104506, 0.3141429688541644, 0.9339750349931024], 
             UndirectedEdge[164, 209] -> 
             RGBColor[
              0.24728574846658016`, 0.37724337883335973`, 0.9373939295974659],
              UndirectedEdge[22, 29] -> 
             RGBColor[
              0.2663738031073146, 0.39730613451333674`, 0.9384809660710094], 
             UndirectedEdge[24, 366] -> 
             RGBColor[
              0.9017167350633479, 0.6466004732099342, 0.2397023734046333], 
             UndirectedEdge[178, 319] -> 
             RGBColor[
              0.24278605838252734`, 0.37251391925819094`, 0.9371376789038741],
              UndirectedEdge[294, 368] -> 
             RGBColor[
              0.21277052855345546`, 0.3409656943133277, 0.9354283388841056], 
             UndirectedEdge[13, 69] -> 
             RGBColor[
              0.7259993754166094, 0.7839523785382002, 0.9495242388978706], 
             UndirectedEdge[214, 295] -> 
             RGBColor[
              0.6130802218515281, 0.6797567159185416, 0.9247335360686406], 
             UndirectedEdge[80, 146] -> 
             RGBColor[
              0.4348738177323767, 0.548860724677587, 0.9495460387678236], 
             UndirectedEdge[56, 231] -> 
             RGBColor[
              0.37980957762799716`, 0.5033879783145618, 0.9454223177963867], 
             UndirectedEdge[134, 351] -> 
             RGBColor[
              0.24003567899790235`, 0.3696230961408251, 0.9369810488667414], 
             UndirectedEdge[143, 291] -> 
             RGBColor[
              0.6605679134983766, 0.7344885741946573, 0.9669884297148228], 
             UndirectedEdge[120, 320] -> 
             RGBColor[
              0.6381361673517921, 0.7160721638444079, 0.9653628908870006], 
             UndirectedEdge[132, 220] -> 
             RGBColor[
              0.6373284381573086, 0.7140480166379533, 0.9662348834814941], 
             UndirectedEdge[6, 247] -> 
             RGBColor[
              0.9501775412917424, 0.8286011525137683, 0.3806667888005933], 
             UndirectedEdge[166, 289] -> 
             RGBColor[
              0.8612612060617832, 0.40999762047401866`, 0.2038737104047185], 
             UndirectedEdge[114, 392] -> 
             RGBColor[
              0.2884135464934976, 0.418609972282043, 0.9398042492586839], 
             UndirectedEdge[305, 325] -> 
             RGBColor[
              0.20723516257555488`, 0.3351476737080805, 0.9351131079805042], 
             UndirectedEdge[44, 128] -> 
             RGBColor[
              0.3120848480897295, 0.44373638339990634`, 0.9411432739695049], 
             UndirectedEdge[90, 242] -> 
             RGBColor[
              0.8120763207412868, 0.7420397918675932, 0.6122349694370377], 
             UndirectedEdge[1, 337] -> 
             RGBColor[
              0.3223631828098259, 0.4514173086943011, 0.9418429310198984], 
             UndirectedEdge[74, 224] -> 
             RGBColor[
              0.9001674923644503, 0.8962994775971298, 0.6715446357629462], 
             UndirectedEdge[160, 370] -> 
             RGBColor[
              0.8303471028154521, 0.5479183884634005, 0.5798122246722852], 
             UndirectedEdge[30, 84] -> 
             RGBColor[
              0.1789270231889713, 0.3053940243730791, 0.9335010013205776], 
             UndirectedEdge[293, 299] -> 
             RGBColor[
              0.21267988324051307`, 0.34087042034218046`, 0.9354231767676313],
              UndirectedEdge[186, 399] -> 
             RGBColor[
              0.24167334431028037`, 0.3713443862181124, 0.9370743114835726], 
             UndirectedEdge[163, 371] -> 
             RGBColor[
              0.25850942763125473`, 0.3890401772577931, 0.9380331015219487], 
             UndirectedEdge[90, 138] -> 
             RGBColor[
              0.7625743389841517, 0.45989176227570816`, 0.5687339252858672], 
             UndirectedEdge[71, 286] -> 
             RGBColor[
              0.798684946393064, 0.8430713308000524, 0.9804594287308144], 
             UndirectedEdge[60, 201] -> 
             RGBColor[
              0.3169773146449097, 0.44598337270948407`, 0.9415279039366844], 
             UndirectedEdge[128, 380] -> 
             RGBColor[
              0.2958519089446212, 0.4266745351306104, 0.9402188320996724], 
             UndirectedEdge[54, 128] -> 
             RGBColor[
              0.3891023193866603, 0.5114426050266787, 0.9460142336150148], 
             UndirectedEdge[25, 138] -> 
             RGBColor[
              0.8340269956702107, 0.26255197621162585`, 0.18021759552277578`],
              UndirectedEdge[95, 129] -> 
             RGBColor[
              0.2597315005548766, 0.39032465338441835`, 0.9381026967670542], 
             UndirectedEdge[132, 302] -> 
             RGBColor[
              0.8932496977556434, 0.905911220002762, 0.6928483915783341], 
             UndirectedEdge[15, 100] -> 
             RGBColor[
              0.34023750094859895`, 0.4686666959527124, 0.9429171480552854], 
             UndirectedEdge[33, 63] -> 
             RGBColor[
              0.5687512197366357, 0.5886439817299056, 0.6135098819197802], 
             UndirectedEdge[275, 338] -> 
             RGBColor[
              0.9931945073855819, 0.9905965803379274, 0.7001396493067182], 
             UndirectedEdge[252, 277] -> 
             RGBColor[
              0.2410729775793306, 0.3707133627184349, 0.9370401214864079], 
             UndirectedEdge[146, 192] -> 
             RGBColor[
              0.43991049068666355`, 0.5532232376400468, 0.9498669711147159], 
             UndirectedEdge[237, 254] -> 
             RGBColor[
              0.5239652108029346, 0.6244175883504002, 0.9556676072236672], 
             UndirectedEdge[37, 236] -> 
             RGBColor[
              0.2501608630823501, 0.3802653065873294, 0.9375576631214831], 
             UndirectedEdge[265, 362] -> 
             RGBColor[
              0.4982768620774518, 0.6022414244020411, 0.9540103792474512], 
             UndirectedEdge[41, 92] -> 
             RGBColor[
              0.31424207897729384`, 0.44465323780495364`, 0.9413155746707285],
              UndirectedEdge[341, 379] -> 
             RGBColor[
              0.2212705365436844, 0.3498997416426921, 0.9359124017645142], 
             UndirectedEdge[324, 380] -> 
             RGBColor[
              0.27272415965434393`, 0.4039807618801248, 0.9388426094818522], 
             UndirectedEdge[63, 264] -> 
             RGBColor[
              0.5742960336344989, 0.5944719326980662, 0.6138256508684465], 
             UndirectedEdge[153, 337] -> 
             RGBColor[
              0.30108704647180895`, 0.43298898876801645`, 0.9404872344261885],
              UndirectedEdge[112, 155] -> 
             RGBColor[
              0.31673339546261187`, 0.44837192664657105`, 0.9414171693125639],
              UndirectedEdge[10, 177] -> 
             RGBColor[
              0.34191718866131093`, 0.47057321638600846`, 0.9430076388093683],
              UndirectedEdge[238, 367] -> 
             RGBColor[
              0.2242689013320493, 0.35305121314257126`, 0.9360831542035284], 
             UndirectedEdge[87, 228] -> 
             RGBColor[
              0.32899794708810315`, 0.4576628482092444, 0.9422474273505641], 
             UndirectedEdge[66, 352] -> 
             RGBColor[
              0.983468511290683, 0.9548785202107917, 0.47692950075693274`], 
             UndirectedEdge[86, 386] -> 
             RGBColor[
              0.31994974783175406`, 0.4507870854822257, 0.9416356849958585], 
             UndirectedEdge[52, 133] -> 
             RGBColor[
              0.34195185422260005`, 0.4695411184843201, 0.9430487372114036], 
             UndirectedEdge[105, 112] -> 
             RGBColor[
              0.37313264037284266`, 0.49761047172431544`, 0.944996659789687], 
             UndirectedEdge[4, 258] -> 
             RGBColor[
              0.24256487951038092`, 0.3722814462400146, 0.9371250830943101], 
             UndirectedEdge[141, 339] -> 
             RGBColor[
              0.36291222472736206`, 0.48875806138522676`, 0.9443454239423157],
              UndirectedEdge[251, 282] -> 
             RGBColor[
              0.7345888082776114, 0.7926044746200289, 0.9741756038265081], 
             UndirectedEdge[94, 390] -> 
             RGBColor[
              0.26321162125265696`, 0.393982480890182, 0.9383008844924156], 
             UndirectedEdge[239, 337] -> 
             RGBColor[
              0.304629125717821, 0.43605695978083275`, 0.9407129325836068], 
             UndirectedEdge[80, 243] -> 
             RGBColor[
              0.3113941751763021, 0.44225199630561496`, 0.9411317115948465], 
             UndirectedEdge[366, 382] -> 
             RGBColor[
              0.9000306839899277, 0.6389445090727658, 0.23829549106007777`], 
             UndirectedEdge[99, 306] -> 
             RGBColor[
              0.9742518584397497, 0.947471002545973, 0.6306628392778444], 
             UndirectedEdge[214, 261] -> 
             RGBColor[
              0.5816107316395323, 0.6466802864248125, 0.9229413951560062], 
             UndirectedEdge[21, 60] -> 
             RGBColor[
              0.33522274220732345`, 0.4647748233402267, 0.9425810746009868], 
             UndirectedEdge[60, 159] -> 
             RGBColor[
              0.344481468526375, 0.4727942667206735, 0.9431710324548666], 
             UndirectedEdge[9, 300] -> 
             RGBColor[
              0.8578321079350941, 0.3958398187210729, 0.2010677137447785], 
             UndirectedEdge[114, 369] -> 
             RGBColor[
              0.29316591487643506`, 0.4236050127700691, 0.9400748896075932], 
             UndirectedEdge[112, 350] -> 
             RGBColor[
              0.380831960891249, 0.5042792361782578, 0.945487253684878], 
             UndirectedEdge[18, 357] -> 
             RGBColor[
              0.8104483343258964, 0.8526146189392179, 0.9729726519131952], 
             UndirectedEdge[71, 320] -> 
             RGBColor[
              0.7905070166194959, 0.8366826699063725, 0.9796443291180839], 
             UndirectedEdge[226, 255] -> 
             RGBColor[
              0.24955450248561023`, 0.3796279831546734, 0.9375231317825289], 
             UndirectedEdge[208, 258] -> 
             RGBColor[
              0.24300998977440907`, 0.3727492853491289, 0.9371504314653649], 
             UndirectedEdge[11, 358] -> 
             RGBColor[
              0.9460196672175634, 0.8199629343977746, 0.2948506005623025], 
             UndirectedEdge[274, 299] -> 
             RGBColor[
              0.22242833776812287`, 0.35111666413841447`, 0.9359783368314325],
              UndirectedEdge[147, 372] -> 
             RGBColor[
              0.2681076692483716, 0.3991285377610505, 0.9385797071827175], 
             UndirectedEdge[335, 337] -> 
             RGBColor[
              0.282630755782611, 0.41439322252540617`, 0.9394067754758614], 
             UndirectedEdge[36, 218] -> 
             RGBColor[
              0.7148705349959443, 0.7760303162882036, 0.9733069680605333], 
             UndirectedEdge[262, 300] -> 
             RGBColor[
              0.9143198191766551, 0.7735717057130247, 0.6093343830407926], 
             UndirectedEdge[109, 136] -> 
             RGBColor[
              0.8063392816861509, 0.8465292984919313, 0.8553084156056971], 
             UndirectedEdge[219, 241] -> 
             RGBColor[
              0.36907489621161843`, 0.49245160059313714`, 0.9447983082263991],
              UndirectedEdge[37, 348] -> 
             RGBColor[
              0.2563773742968305, 0.38679925402332427`, 0.9379116842386436], 
             UndirectedEdge[291, 384] -> 
             RGBColor[
              0.7224597094549363, 0.7831102830141358, 0.9729716901347794], 
             UndirectedEdge[10, 241] -> 
             RGBColor[
              0.32644391245681637`, 0.4555267851602728, 0.9420818996386419], 
             UndirectedEdge[131, 314] -> 
             RGBColor[
              0.9241390802378358, 0.8369963141242439, 0.6246293196235244], 
             UndirectedEdge[1, 41] -> 
             RGBColor[
              0.3504016747423545, 0.4779220517867386, 0.943548262759916], 
             UndirectedEdge[78, 400] -> 
             RGBColor[
              0.6157274285874001, 0.4172598139869824, 0.5668748799123404], 
             UndirectedEdge[191, 357] -> 
             RGBColor[
              0.6772717325975683, 0.7478090920518159, 0.9684677749072899], 
             UndirectedEdge[215, 352] -> 
             RGBColor[
              0.906721166296464, 0.5695838616411621, 0.3855978109611532], 
             UndirectedEdge[96, 369] -> 
             RGBColor[
              0.27218271865818583`, 0.40341167306382075`, 0.9388117752181111],
              UndirectedEdge[212, 293] -> 
             RGBColor[
              0.2110641194014849, 0.3391721501020175, 0.935331161407307], 
             UndirectedEdge[66, 107] -> 
             RGBColor[
              0.906000283356856, 0.6111511383099929, 0.2669776426492963], 
             UndirectedEdge[146, 159] -> 
             RGBColor[
              0.433382915877228, 0.5475693804255631, 0.9494510398199664], 
             UndirectedEdge[11, 207] -> 
             RGBColor[
              0.931659240059644, 0.7667586905843885, 0.26386962426942273`], 
             UndirectedEdge[99, 218] -> 
             RGBColor[
              0.9440956875300477, 0.9571661739174645, 0.9565961673645738], 
             UndirectedEdge[131, 217] -> 
             RGBColor[
              0.8726459244985081, 0.4533824718485052, 0.21298193244244573`], 
             UndirectedEdge[81, 163] -> 
             RGBColor[
              0.23234434831161116`, 0.36153901993100174`, 0.9365430389624612],
              UndirectedEdge[50, 54] -> 
             RGBColor[
              0.4530695590105145, 0.5668252864420751, 0.9500963936878091], 
             UndirectedEdge[120, 286] -> 
             RGBColor[
              0.6463140971253603, 0.7224608247380875, 0.966177990499731], 
             UndirectedEdge[17, 253] -> 
             RGBColor[
              0.43861619159981363`, 0.5520971476660097, 0.9497858901980598], 
             UndirectedEdge[45, 365] -> 
             RGBColor[
              0.2758699057154388, 0.4072871404421556, 0.9390217550663172], 
             UndirectedEdge[35, 188] -> 
             RGBColor[
              0.27406348456255775`, 0.4053884772767613, 0.9389188820540213], 
             UndirectedEdge[99, 279] -> 
             RGBColor[
              0.9618886205302903, 0.9027170726846294, 0.5985175369470697], 
             UndirectedEdge[107, 363] -> 
             RGBColor[
              0.8508650866892753, 0.3855165088466559, 0.1960887969103411], 
             UndirectedEdge[105, 271] -> 
             RGBColor[
              0.36206599633926584`, 0.4878440595940245, 0.9442981318263466], 
             UndirectedEdge[191, 219] -> 
             RGBColor[
              0.5630206032370957, 0.6553990201614963, 0.9591704044347413], 
             UndirectedEdge[177, 339] -> 
             RGBColor[
              0.34383450141698674`, 0.4722338963280338, 0.9431298082827468], 
             UndirectedEdge[80, 167] -> 
             RGBColor[
              0.30898293281547473`, 0.43971762770278966`, 0.9409943949095109],
              UndirectedEdge[48, 56] -> 
             RGBColor[
              0.43818896314994105`, 0.5539589886879809, 0.9491419911499963], 
             UndirectedEdge[42, 136] -> 
             RGBColor[
              0.7754039881303256, 0.825013733522431, 0.9782569627328132], 
             UndirectedEdge[77, 102] -> 
             RGBColor[
              0.8243310697046711, 0.5080541422905515, 0.574849473505362], 
             UndirectedEdge[73, 203] -> 
             RGBColor[
              0.2672567761777972, 0.39823419519414005`, 0.9385312500811318], 
             UndirectedEdge[35, 284] -> 
             RGBColor[
              0.26251957032631373`, 0.3932550914880322, 0.9382614732159579], 
             UndirectedEdge[274, 367] -> 
             RGBColor[
              0.22502133411732347`, 0.3538420677068884, 0.9361260041375251], 
             UndirectedEdge[33, 310] -> 
             RGBColor[
              0.18075976862012855`, 0.3073203560239972, 0.9336053734615781], 
             UndirectedEdge[175, 295] -> 
             RGBColor[
              0.21065974573871524`, 0.33874712774367555`, 0.9353081329254295],
              UndirectedEdge[70, 75] -> 
             RGBColor[
              0.2609941288153654, 0.3916517557414475, 0.9381746015785979], 
             UndirectedEdge[57, 258] -> 
             RGBColor[
              0.26307034244570515`, 0.39383398790648194`, 0.9382928388733629],
              UndirectedEdge[70, 145] -> 
             RGBColor[
              0.2579170969731607, 0.3884176001802034, 0.937999369167245], 
             UndirectedEdge[12, 336] -> 
             RGBColor[
              0.21472177259901426`, 0.343016575521228, 0.9355394593458932], 
             UndirectedEdge[18, 216] -> 
             RGBColor[
              0.8021540700559975, 0.8461350766528297, 0.9721459571650781], 
             UndirectedEdge[158, 311] -> 
             RGBColor[
              0.5112449698673547, 0.6140907237185725, 0.9546662232614405], 
             UndirectedEdge[8, 36] -> 
             RGBColor[
              0.41499862525248465`, 0.5320708731128857, 0.9481621689265505], 
             UndirectedEdge[119, 200] -> 
             RGBColor[
              0.2555790109882331, 0.38596012356683096`, 0.9378662186292916], 
             UndirectedEdge[181, 362] -> 
             RGBColor[
              0.4859856594800335, 0.59226287242109, 0.9530427707548238], 
             UndirectedEdge[9, 306] -> 
             RGBColor[
              0.8980217768542582, 0.5550152880766823, 0.25581485333926096`], 
             UndirectedEdge[82, 253] -> 
             RGBColor[
              0.3604664667584644, 0.48663966875993736`, 0.9441895824072364], 
             UndirectedEdge[161, 356] -> 
             RGBColor[
              0.47490752561281135`, 0.5839962194337451, 0.9519697664459024], 
             UndirectedEdge[146, 314] -> 
             RGBColor[
              0.7305716091219763, 0.7886632000372383, 0.9746741748807553], 
             UndirectedEdge[27, 277] -> 
             RGBColor[
              0.277614773953709, 0.4091211075916136, 0.9391211227311855], 
             UndirectedEdge[6, 302] -> 
             RGBColor[
              0.9903122885265428, 0.9784619909329613, 0.461186699710061], 
             UndirectedEdge[93, 296] -> 
             RGBColor[
              0.27337982614775685`, 0.40466990893635857`, 0.9388799487186803],
              UndirectedEdge[153, 284] -> 
             RGBColor[
              0.2807144253547577, 0.4115760722752118, 0.9393270437921646], 
             UndirectedEdge[43, 199] -> 
             RGBColor[
              0.2266190062266405, 0.3555213223920431, 0.9362169892006067], 
             UndirectedEdge[213, 250] -> 
             RGBColor[
              0.9495976653580405, 0.8370624678097084, 0.5459950352795185], 
             UndirectedEdge[3, 232] -> 
             RGBColor[
              0.4478181508511241, 0.5603378585517222, 0.9502975085529524], 
             UndirectedEdge[5, 235] -> 
             RGBColor[
              0.7907683520113988, 0.8366469590661592, 0.9797340301887447], 
             UndirectedEdge[25, 391] -> 
             RGBColor[
              0.8345509525864179, 0.2665793386689794, 0.18071933725746053`], 
             UndirectedEdge[288, 341] -> 
             RGBColor[
              0.2333048519876323, 0.3625485701939505, 0.9365977382258728], 
             UndirectedEdge[181, 265] -> 
             RGBColor[
              0.5796034948121, 0.6695872537851715, 0.9600476567506184], 
             UndirectedEdge[295, 363] -> 
             RGBColor[
              0.5524499218387339, 0.42033901047071287`, 0.5720521832312901], 
             UndirectedEdge[278, 284] -> 
             RGBColor[
              0.24820685681048946`, 0.3782115221044505, 0.9374463853549939], 
             UndirectedEdge[167, 351] -> 
             RGBColor[
              0.2646469792533301, 0.39549113315584294`, 0.938382626007132], 
             UndirectedEdge[198, 311] -> 
             RGBColor[
              0.6729318339898602, 0.7425873401033549, 0.9693093430316602], 
             UndirectedEdge[54, 328] -> 
             RGBColor[
              0.38071433549214345`, 0.504177354969577, 0.9454797586984591], 
             UndirectedEdge[261, 310] -> 
             RGBColor[
              0.18101326007132248`, 0.3075867916114884, 0.9336198094247166], 
             UndirectedEdge[68, 319] -> 
             RGBColor[
              0.2591541477712746, 0.38971781900257185`, 0.9380698173801449], 
             UndirectedEdge[100, 141] -> 
             RGBColor[
              0.3683390164516885, 0.49345847561835543`, 0.9446912143122663], 
             UndirectedEdge[139, 325] -> 
             RGBColor[
              0.21136919529828035`, 0.33949280421247857`, 0.9353485350283102],
              UndirectedEdge[123, 338] -> 
             RGBColor[
              0.9842922541931751, 0.9852712070496027, 0.7740485310892328], 
             UndirectedEdge[317, 370] -> 
             RGBColor[
              0.9109218435003366, 0.9293228266692952, 0.8943803638429948], 
             UndirectedEdge[160, 400] -> 
             RGBColor[
              0.6095442446912597, 0.3697331530727862, 0.5609538560304888], 
             UndirectedEdge[150, 266] -> 
             RGBColor[
              0.2627993543398047, 0.39354916222554226`, 0.9382774065016228], 
             UndirectedEdge[134, 201] -> 
             RGBColor[
              0.255376576823433, 0.3857473524245587, 0.9378546903030808], 
             UndirectedEdge[161, 251] -> 
             RGBColor[
              0.6268762447587527, 0.7046334098478555, 0.9658130763902817], 
             UndirectedEdge[86, 371] -> 
             RGBColor[
              0.2862909803459218, 0.418240350613087, 0.9396152198499249], 
             UndirectedEdge[105, 350] -> 
             RGBColor[
              0.4250434301807523, 0.5425729887437677, 0.948304369413338], 
             UndirectedEdge[54, 362] -> 
             RGBColor[
              0.4283252562737149, 0.5454155415561164, 0.9485134844699766], 
             UndirectedEdge[4, 208] -> 
             RGBColor[
              0.23264160776787357`, 0.36185145846687167`, 0.9365599674487393],
              UndirectedEdge[176, 294] -> 
             RGBColor[
              0.21429151975408078`, 0.34256435250159695`, 0.9355149570828762],
              UndirectedEdge[113, 170] -> 
             RGBColor[
              0.6207426403130438, 0.7003977045332692, 0.9649634716556403], 
             UndirectedEdge[14, 205] -> 
             RGBColor[
              0.9948127950472943, 0.9913250536932577, 0.6776287249236647], 
             UndirectedEdge[262, 306] -> 
             RGBColor[
              0.9545094880958191, 0.9327471750686342, 0.664081522635275], 
             UndirectedEdge[47, 128] -> 
             RGBColor[
              0.3800525355791988, 0.5036041371480152, 0.945437589393213], 
             UndirectedEdge[257, 382] -> 
             RGBColor[
              0.8606940459931985, 0.4040219113453448, 0.20326730826890227`], 
             UndirectedEdge[165, 228] -> 
             RGBColor[
              0.4503029757321284, 0.5622948057743279, 0.9505097967266875], 
             UndirectedEdge[72, 341] -> 
             RGBColor[
              0.22465511090045148`, 0.353457143886063, 0.936105148267103], 
             UndirectedEdge[50, 116] -> 
             RGBColor[
              0.4351844866677396, 0.551334135708637, 0.9489567726932759], 
             UndirectedEdge[230, 247] -> 
             RGBColor[
              0.9379323861994966, 0.7878165939520326, 0.28877547346743154`], 
             UndirectedEdge[45, 100] -> 
             RGBColor[
              0.33605658973236274`, 0.46427229317936647`, 0.9426790513466246],
              UndirectedEdge[95, 386] -> 
             RGBColor[
              0.3105708355384495, 0.4409292540045774, 0.9411015698156122], 
             UndirectedEdge[182, 244] -> 
             RGBColor[
              0.27406524356197104`, 0.4053903260966717, 0.9389189822264357], 
             UndirectedEdge[104, 382] -> 
             RGBColor[
              0.9163275048198573, 0.7044047275562138, 0.25145220082553266`], 
             UndirectedEdge[58, 210] -> 
             RGBColor[
              0.2993673513669953, 0.4319844456460439, 0.9403598998348177], 
             UndirectedEdge[102, 370] -> 
             RGBColor[
              0.8252568296209774, 0.5087923181187306, 0.5749377733126149], 
             UndirectedEdge[1, 161] -> 
             RGBColor[
              0.3957098398241182, 0.5171657071259712, 0.9464352589744887], 
             UndirectedEdge[153, 356] -> 
             RGBColor[
              0.4179045828513193, 0.5346231354649491, 0.9483375893388631], 
             UndirectedEdge[1, 154] -> 
             RGBColor[
              0.39507053133992803`, 0.5166119702495444, 0.9463945228031945], 
             UndirectedEdge[341, 399] -> 
             RGBColor[
              0.22823136465623345`, 0.3572160133309742, 0.9363088106279014], 
             UndirectedEdge[373, 395] -> 
             RGBColor[
              0.2616949498810116, 0.3923883631160637, 0.9382145123015146], 
             UndirectedEdge[190, 266] -> 
             RGBColor[
              0.24805045871485498`, 0.3780471377897267, 0.9374374787148178], 
             UndirectedEdge[73, 85] -> 
             RGBColor[
              0.24221172142071856`, 0.3719102546962633, 0.9371049712635544], 
             UndirectedEdge[221, 250] -> 
             RGBColor[
              0.955043066437527, 0.9649644792718597, 0.9185889663100797], 
             UndirectedEdge[23, 353] -> 
             RGBColor[
              0.21189878814995255`, 0.34004943987771225`, 0.9353786945577505],
              UndirectedEdge[171, 270] -> 
             RGBColor[
              0.2613998670743656, 0.3920782123769482, 0.9381977077722119], 
             UndirectedEdge[277, 396] -> 
             RGBColor[
              0.26805617252313807`, 0.399074411437749, 0.9385767745203981], 
             UndirectedEdge[315, 371] -> 
             RGBColor[
              0.25765991596594773`, 0.388147286635405, 0.9379847230893494], 
             UndirectedEdge[207, 391] -> 
             RGBColor[
              0.8801233042529734, 0.4784967588439868, 0.2188121666480132], 
             UndirectedEdge[160, 247] -> 
             RGBColor[
              0.8682425607038025, 0.44830305029724704`, 0.2099476795487854], 
             UndirectedEdge[193, 232] -> 
             RGBColor[
              0.6739481277148399, 0.7434424430617759, 0.9693547854990241], 
             UndirectedEdge[22, 91] -> 
             RGBColor[
              0.2774698045998931, 0.40896873560916513`, 0.9391128669409485], 
             UndirectedEdge[78, 247] -> 
             RGBColor[
              0.874425744599943, 0.49582971121144337`, 0.21586870343063702`], 
             UndirectedEdge[87, 192] -> 
             RGBColor[
              0.3173142304637505, 0.44754300010990244`, 0.9415029512587653], 
             UndirectedEdge[226, 294] -> 
             RGBColor[
              0.22569678935260098`, 0.35455201398550057`, 0.9361644703139277],
              UndirectedEdge[177, 311] -> 
             RGBColor[
              0.42064126980492156`, 0.5369664823599833, 0.9485194381294991], 
             UndirectedEdge[189, 200] -> 
             RGBColor[
              0.28560319899075254`, 0.41751744880094743`, 0.9395760517192293],
              UndirectedEdge[67, 184] -> 
             RGBColor[
              0.2153543932680198, 0.3436814999548199, 0.9355754861571146], 
             UndirectedEdge[33, 256] -> 
             RGBColor[
              0.202124876078153, 0.3297764385884332, 0.9348220847244686], 
             UndirectedEdge[176, 226] -> 
             RGBColor[
              0.22722875741095702`, 0.3561622095472178, 0.9362517136285073], 
             UndirectedEdge[145, 162] -> 
             RGBColor[
              0.2420540274215789, 0.3717445083047905, 0.9370959908235907], 
             UndirectedEdge[286, 343] -> 
             RGBColor[
              0.7242252260804207, 0.7844895180203877, 0.9731476603323168], 
             UndirectedEdge[13, 18] -> 
             RGBColor[
              0.9544933475167275, 0.9655817936050558, 0.9619150720050708], 
             UndirectedEdge[86, 308] -> 
             RGBColor[
              0.28081236703944734`, 0.4124819806638359, 0.9393032209270034], 
             UndirectedEdge[364, 377] -> 
             RGBColor[
              0.3822045767059832, 0.5054681270073037, 0.9455747155508364], 
             UndirectedEdge[90, 152] -> 
             RGBColor[
              0.4447109838202162, 0.5402113672268555, 0.9525399126533038], 
             UndirectedEdge[1, 153] -> 
             RGBColor[
              0.33870689706262624`, 0.4677926231571751, 0.9428030818674495], 
             UndirectedEdge[92, 114] -> 
             RGBColor[
              0.3082708613262549, 0.43948126919774927`, 0.9409350939621447], 
             UndirectedEdge[132, 219] -> 
             RGBColor[
              0.6232051027562657, 0.7024156086050097, 0.9651690328906872], 
             UndirectedEdge[107, 215] -> 
             RGBColor[
              0.829252938362637, 0.22585647974036333`, 0.17564595285351675`], 
             UndirectedEdge[240, 319] -> 
             RGBColor[
              0.24039509168830792`, 0.37000086166652213`, 0.9370015168877566],
              UndirectedEdge[58, 110] -> 
             RGBColor[
              0.2771944683256158, 0.40867933972757164`, 0.939097186947452], 
             UndirectedEdge[67, 85] -> 
             RGBColor[
              0.22712666696496037`, 0.35605490601556716`, 0.9362458997286371],
              UndirectedEdge[125, 344] -> 
             RGBColor[
              0.2993073040655987, 0.4308227000023955, 0.9403967065336283], 
             UndirectedEdge[198, 219] -> 
             RGBColor[
              0.6368387366010516, 0.7131188895622445, 0.9665139522992866], 
             UndirectedEdge[16, 325] -> 
             RGBColor[
              0.22671411419860138`, 0.35562128690076766`, 0.9362224054589102],
              UndirectedEdge[119, 390] -> 
             RGBColor[
              0.2533988208527428, 0.3836686055023921, 0.9377420600263777], 
             UndirectedEdge[7, 153] -> 
             RGBColor[
              0.3534178774592668, 0.48053453498137155`, 0.9437404525299142], 
             UndirectedEdge[23, 164] -> 
             RGBColor[
              0.22797821780387265`, 0.3569499399387055, 0.9362943942891566], 
             UndirectedEdge[46, 373] -> 
             RGBColor[
              0.26731905714517273`, 0.3982996564396932, 0.9385347968900875], 
             UndirectedEdge[301, 316] -> 
             RGBColor[
              0.2555487063727525, 0.3859282714945373, 0.9378644928262717], 
             UndirectedEdge[22, 150] -> 
             RGBColor[
              0.28145958694833023`, 0.41316224982418415`, 0.9393400791433381],
              UndirectedEdge[161, 327] -> 
             RGBColor[
              0.3750143899762539, 0.4992403486513052, 0.9451165632104506], 
             UndirectedEdge[123, 281] -> 
             RGBColor[
              0.8031450913153519, 0.8462354724290008, 0.9462830761380823], 
             UndirectedEdge[111, 160] -> 
             RGBColor[
              0.8517778667942718, 0.37434165466445646`, 0.19625056684916897`],
              UndirectedEdge[277, 287] -> 
             RGBColor[
              0.25901311175833214`, 0.3895695812107696, 0.9380617855878519], 
             UndirectedEdge[48, 120] -> 
             RGBColor[
              0.49591060473188847`, 0.6008847208403402, 0.9536681725336434], 
             UndirectedEdge[6, 224] -> 
             RGBColor[
              0.9845045256450395, 0.9588710430060774, 0.43862463761941295`], 
             UndirectedEdge[103, 313] -> 
             RGBColor[
              0.31368725505562867`, 0.4437237541060531, 0.9412966590550009], 
             UndirectedEdge[8, 60] -> 
             RGBColor[
              0.33392414851101215`, 0.4636500467496988, 0.9424983293589592], 
             UndirectedEdge[284, 392] -> 
             RGBColor[
              0.24597365109495675`, 0.3758642813040053, 0.9373192075932261], 
             UndirectedEdge[218, 279] -> 
             RGBColor[
              0.9278567069516805, 0.8766750653657154, 0.6332052588371474], 
             UndirectedEdge[135, 221] -> 
             RGBColor[
              0.7125684826637311, 0.7740760557086418, 0.9732239792621271], 
             UndirectedEdge[95, 309] -> 
             RGBColor[
              0.2762844897757238, 0.4077228945756627, 0.9390453650152284], 
             UndirectedEdge[80, 385] -> 
             RGBColor[
              0.4549187217473041, 0.5651340807695402, 0.9511240470387816], 
             UndirectedEdge[272, 398] -> 
             RGBColor[
              0.7932211653132651, 0.8392589768677534, 0.976436715616906], 
             UndirectedEdge[33, 264] -> 
             RGBColor[
              0.18448620056776344`, 0.31123707227039327`, 0.9338175882482339],
              UndirectedEdge[76, 366] -> 
             RGBColor[
              0.8741124408312237, 0.5032302339331254, 0.2159628369001264], 
             UndirectedEdge[41, 258] -> 
             RGBColor[
              0.29687678880049106`, 0.4264012168061446, 0.9403266470848042], 
             UndirectedEdge[174, 232] -> 
             RGBColor[
              0.6270810139261389, 0.7068104580353534, 0.9646885621008761], 
             UndirectedEdge[61, 307] -> 
             RGBColor[
              0.9892929392100926, 0.9881701251038566, 0.7056981044009731], 
             UndirectedEdge[35, 392] -> 
             RGBColor[
              0.2644951314363644, 0.3953315314725043, 0.9383739784985945], 
             UndirectedEdge[212, 259] -> 
             RGBColor[
              0.2109589325174653, 0.33906159201767927`, 0.935325171169872], 
             UndirectedEdge[73, 110] -> 
             RGBColor[
              0.24934696023893294`, 0.3794098430944771, 0.9375113125586119], 
             UndirectedEdge[122, 228] -> 
             RGBColor[
              0.40697238168033323`, 0.5269207548100117, 0.9471528981824919], 
             UndirectedEdge[41, 203] -> 
             RGBColor[
              0.31610894590117855`, 0.4466154333081559, 0.9414218899802616], 
             UndirectedEdge[361, 385] -> 
             RGBColor[
              0.46552378312677223`, 0.5743196519105522, 0.9517997921721937], 
             UndirectedEdge[9, 269] -> 
             RGBColor[
              0.909363183463878, 0.5929294140972693, 0.329048956685827], 
             UndirectedEdge[192, 228] -> 
             RGBColor[
              0.35617346073846823`, 0.48292128271817314`, 0.9439160358597984],
              UndirectedEdge[47, 265] -> 
             RGBColor[
              0.5128933077983199, 0.6149014550415344, 0.9549417262439694], 
             UndirectedEdge[338, 398] -> 
             RGBColor[
              0.966856888277283, 0.9722679396973218, 0.803562057713115], 
             UndirectedEdge[71, 79] -> 
             RGBColor[
              0.730962985173496, 0.7893766931257962, 0.9742494771038676], 
             UndirectedEdge[77, 78] -> 
             RGBColor[
              0.8356045267952863, 0.5947068735494174, 0.5856449487468838], 
             UndirectedEdge[89, 164] -> 
             RGBColor[
              0.2305606666537099, 0.3596642574165986, 0.9364414609307642], 
             UndirectedEdge[123, 235] -> 
             RGBColor[
              0.8571949059772741, 0.8886183762780113, 0.9515616992620775], 
             UndirectedEdge[72, 393] -> 
             RGBColor[
              0.22527325394479547`, 0.3541068514182011, 0.9361403505990177], 
             UndirectedEdge[240, 371] -> 
             RGBColor[
              0.2556260580342823, 0.3860095729951837, 0.9378688978889642], 
             UndirectedEdge[196, 303] -> 
             RGBColor[
              0.29376792821553643`, 0.42609909688992764`, 0.9400410209699464],
              UndirectedEdge[105, 170] -> 
             RGBColor[
              0.4311568725166687, 0.5478681452245924, 0.9486939125530778], 
             UndirectedEdge[195, 208] -> 
             RGBColor[
              0.239390712068561, 0.3689451950048222, 0.9369443189542583], 
             UndirectedEdge[100, 180] -> 
             RGBColor[
              0.3714420538172285, 0.49614617062119337`, 0.9448889371092903], 
             UndirectedEdge[39, 355] -> 
             RGBColor[
              0.25200661552040216`, 0.3822053094271858, 0.9376627759922841], 
             UndirectedEdge[244, 397] -> 
             RGBColor[
              0.2546928621186111, 0.3850287249197748, 0.9378157537621064], 
             UndirectedEdge[225, 355] -> 
             RGBColor[
              0.24401463577453056`, 0.373805231993492, 0.9372076445688313], 
             UndirectedEdge[335, 354] -> 
             RGBColor[
              0.28014580760645524`, 0.41178138443745216`, 0.9392652613533807],
              UndirectedEdge[97, 100] -> 
             RGBColor[
              0.4094492665548738, 0.5290661079964851, 0.9473107230964745], 
             UndirectedEdge[2, 107] -> 
             RGBColor[
              0.828834437069773, 0.222639695414975, 0.17524519554284063`], 
             UndirectedEdge[128, 225] -> 
             RGBColor[
              0.2916606290262991, 0.42226923419395845`, 0.939980144908767], 
             UndirectedEdge[96, 228] -> 
             RGBColor[
              0.3273843328541551, 0.4559668373403135, 0.9421555344070691], 
             UndirectedEdge[262, 307] -> 
             RGBColor[
              0.9619414175862754, 0.970962445386637, 0.9415105792405329], 
             UndirectedEdge[86, 334] -> 
             RGBColor[
              0.28096769579564274`, 0.4126452410350092, 0.9393120666698803], 
             UndirectedEdge[255, 399] -> 
             RGBColor[
              0.24767699728620676`, 0.3776546061493952, 0.937416210638943], 
             UndirectedEdge[138, 242] -> 
             RGBColor[
              0.8688448581678534, 0.4318314305529642, 0.2096571104877158], 
             UndirectedEdge[27, 396] -> 
             RGBColor[
              0.28785811658992677`, 0.419887510167713, 0.9397044659406507], 
             UndirectedEdge[163, 209] -> 
             RGBColor[
              0.2485031193706023, 0.3785229128392603, 0.9374632570695112], 
             UndirectedEdge[63, 202] -> 
             RGBColor[
              0.9074503393274316, 0.6529677356997123, 0.2475510699614376], 
             UndirectedEdge[347, 372] -> 
             RGBColor[
              0.26576379522245486`, 0.3966649775496154, 0.9384462270243925], 
             UndirectedEdge[174, 275] -> 
             RGBColor[
              0.8603530123804088, 0.8894563784374243, 0.877080294609712], 
             UndirectedEdge[209, 315] -> 
             RGBColor[
              0.24765360770529532`, 0.37763002221687225`, 0.9374148786369118],
              UndirectedEdge[177, 374] -> 
             RGBColor[
              0.29900611365793894`, 0.43038779878246913`, 0.9403838868632315],
              UndirectedEdge[214, 215] -> 
             RGBColor[
              0.9015306453673441, 0.5683408458182889, 0.5392279021919928], 
             UndirectedEdge[160, 185] -> 
             RGBColor[
              0.8265840327508944, 0.20534210168661424`, 0.17309020582561438`],
              UndirectedEdge[63, 268] -> 
             RGBColor[
              0.8879400264016856, 0.5030029210787892, 0.2288679722699964], 
             UndirectedEdge[48, 196] -> 
             RGBColor[
              0.3616835055171287, 0.4866932494532377, 0.9443037663378753], 
             UndirectedEdge[34, 95] -> 
             RGBColor[
              0.29703377047989377`, 0.4292041286435296, 0.9402390000004376], 
             UndirectedEdge[84, 333] -> 
             RGBColor[
              0.18724373492288626`, 0.3141354157154036, 0.9339746257503516], 
             UndirectedEdge[102, 224] -> 
             RGBColor[
              0.8974792718626248, 0.5394468704448865, 0.26303107700793477`], 
             UndirectedEdge[105, 326] -> 
             RGBColor[
              0.37836717266856673`, 0.5021443605036287, 0.9453301995588554], 
             UndirectedEdge[134, 236] -> 
             RGBColor[
              0.24242453355158805`, 0.3721339337388756, 0.9371170905995801], 
             UndirectedEdge[92, 161] -> 
             RGBColor[
              0.35955024405905767`, 0.48389689314418627`, 0.9442025708853012],
              UndirectedEdge[77, 185] -> 
             RGBColor[
              0.8265277938578538, 0.5249391267425765, 0.5769530590352949], 
             UndirectedEdge[178, 329] -> 
             RGBColor[
              0.23956363455757862`, 0.36912694750469877`, 0.9369541666341921],
              UndirectedEdge[185, 400] -> 
             RGBColor[
              0.6066506956499677, 0.3474920671801415, 0.5581829902007515], 
             UndirectedEdge[317, 333] -> 
             RGBColor[
              0.5930937593564782, 0.6566344401985723, 0.8697228003417041], 
             UndirectedEdge[106, 215] -> 
             RGBColor[
              0.8838915069303948, 0.5551856052534505, 0.5690863625416396], 
             UndirectedEdge[14, 340] -> 
             RGBColor[
              0.9940676030184292, 0.9897195276507893, 0.5956733829454577], 
             UndirectedEdge[233, 358] -> 
             RGBColor[
              0.8930174526264201, 0.5204305413924555, 0.24838903272095686`], 
             UndirectedEdge[74, 191] -> 
             RGBColor[
              0.7517634193974077, 0.8060404672296411, 0.9758823517148281], 
             UndirectedEdge[53, 244] -> 
             RGBColor[
              0.27464006789181306`, 0.4059945029133032, 0.9389517176216438], 
             UndirectedEdge[4, 16] -> 
             RGBColor[
              0.23702850407735238`, 0.36646236463342485`, 0.9368097947037326],
              UndirectedEdge[149, 274] -> 
             RGBColor[
              0.22547330397154366`, 0.35431711668021776`, 0.9361517431520935],
              UndirectedEdge[326, 335] -> 
             RGBColor[
              0.3099542075105004, 0.4402786337315509, 0.9410665454863245], 
             UndirectedEdge[30, 77] -> 
             RGBColor[
              0.5041460680446381, 0.5860856357063153, 0.9585438899509009], 
             UndirectedEdge[129, 229] -> 
             RGBColor[
              0.24229031603850887`, 0.3719928626227475, 0.9371094471107673], 
             UndirectedEdge[216, 219] -> 
             RGBColor[
              0.5531447091768378, 0.647683896662048, 0.958186067610292], 
             UndirectedEdge[138, 233] -> 
             RGBColor[
              0.8184005545424529, 0.14244030215351539`, 0.165253697851294], 
             UndirectedEdge[28, 44] -> 
             RGBColor[
              0.29312282823703784`, 0.42542105591082463`, 0.9400042834805107],
              UndirectedEdge[163, 227] -> 
             RGBColor[
              0.23994763052693538`, 0.3695305516152434, 0.9369760346365759], 
             UndirectedEdge[15, 335] -> 
             RGBColor[
              0.2921895478533735, 0.4244401190541993, 0.9399511345433256], 
             UndirectedEdge[257, 268] -> 
             RGBColor[
              0.8199630848530925, 0.15445059482623982`, 0.16674997864138813`],
              UndirectedEdge[217, 279] -> 
             RGBColor[
              0.8842376547290044, 0.4993398194973086, 0.22230891067878217`], 
             UndirectedEdge[93, 119] -> 
             RGBColor[
              0.24286823945996167`, 0.3726002967811557, 0.9371423589946579], 
             UndirectedEdge[67, 305] -> 
             RGBColor[
              0.20792423756527648`, 0.33587193521215575`, 0.9351523497817738],
              UndirectedEdge[153, 195] -> 
             RGBColor[
              0.2815627334149148, 0.41246769783227444`, 0.9393753536812313], 
             UndirectedEdge[50, 135] -> 
             RGBColor[
              0.478712840814817, 0.5876796757980098, 0.9521051748933094], 
             UndirectedEdge[68, 334] -> 
             RGBColor[
              0.2690618295669699, 0.40013142075315566`, 0.938634045201308], 
             UndirectedEdge[95, 308] -> 
             RGBColor[
              0.2714334547461428, 0.4026241491861876, 0.9387691057467569], 
             UndirectedEdge[17, 36] -> 
             RGBColor[
              0.5275969503288876, 0.6273659981055699, 0.9559535110626505], 
             UndirectedEdge[41, 361] -> 
             RGBColor[
              0.34822341852427197`, 0.4760353557329764, 0.9434094661998561], 
             UndirectedEdge[117, 371] -> 
             RGBColor[
              0.31078136056287864`, 0.44021172480761495`, 0.9411479331302521],
              UndirectedEdge[89, 304] -> 
             RGBColor[
              0.21884062978169738`, 0.3473457555708567, 0.9357740221691438], 
             UndirectedEdge[267, 272] -> 
             RGBColor[
              0.6091079366672787, 0.6934689353256587, 0.9624191392814057], 
             UndirectedEdge[20, 158] -> 
             RGBColor[
              0.4553874406509526, 0.5675033157176284, 0.9506114604100135], 
             UndirectedEdge[30, 62] -> 
             RGBColor[
              0.17899764558147852`, 0.30546825298532254`, 0.9335050231613544],
              UndirectedEdge[197, 310] -> 
             RGBColor[
              0.5856647922314719, 0.6494240169162264, 0.8848951542933734], 
             UndirectedEdge[142, 268] -> 
             RGBColor[
              0.8194514867475214, 0.1505182276031009, 0.16626007171772583`], 
             UndirectedEdge[78, 213] -> 
             RGBColor[
              0.8764060316711535, 0.5036808895572449, 0.2174620888914447], 
             UndirectedEdge[48, 71] -> 
             RGBColor[
              0.6482814539995922, 0.7214952269023049, 0.9679496107647267], 
             UndirectedEdge[262, 269] -> 
             RGBColor[
              0.965850894705439, 0.9706613010892211, 0.7373156259818411], 
             UndirectedEdge[27, 376] -> 
             RGBColor[
              0.3679050083022842, 0.49203509004620194`, 0.9447019126873052], 
             UndirectedEdge[245, 292] -> 
             RGBColor[
              0.2204587636622521, 0.3490465168749334, 0.935866172499827], 
             UndirectedEdge[142, 217] -> 
             RGBColor[
              0.8222048215005642, 0.17168156503396934`, 0.16889666818668636`],
              UndirectedEdge[142, 363] -> 
             RGBColor[
              0.8420482335881154, 0.3177463123414773, 0.18764576842345915`], 
             UndirectedEdge[121, 130] -> 
             RGBColor[
              0.48180086572832803`, 0.5890215010044231, 0.9526702161686205], 
             UndirectedEdge[217, 300] -> 
             RGBColor[
              0.8564112237192996, 0.3849182800030426, 0.19970707341507446`], 
             UndirectedEdge[25, 109] -> 
             RGBColor[
              0.9214037823681839, 0.6836236479949891, 0.47088987975905927`], 
             UndirectedEdge[40, 146] -> 
             RGBColor[
              0.43732168419070216`, 0.5509809435704429, 0.9497020146539848], 
             UndirectedEdge[18, 140] -> 
             RGBColor[
              0.8085657806265083, 0.8511439536813179, 0.9727850165539047], 
             UndirectedEdge[170, 239] -> 
             RGBColor[
              0.38474227729381244`, 0.5076661557079413, 0.9457364155882924], 
             UndirectedEdge[152, 333] -> 
             RGBColor[
              0.18958831081692415`, 0.31659971363473505`, 0.9341081458790279],
              UndirectedEdge[14, 250] -> 
             RGBColor[
              0.99129214736786, 0.9898691754012934, 0.7359749681160213], 
             UndirectedEdge[55, 159] -> 
             RGBColor[
              0.36748362390558187`, 0.49271757758819734`, 0.9446367094556223],
              UndirectedEdge[234, 331] -> 
             RGBColor[
              0.3954159318032815, 0.5169111387705692, 0.9464165314152937], 
             UndirectedEdge[370, 389] -> 
             RGBColor[
              0.505152375234491, 0.5869084718259839, 0.9586367768062234], 
             UndirectedEdge[119, 316] -> 
             RGBColor[
              0.24738893708713797`, 0.3773518366161024, 0.9373998060367528], 
             UndirectedEdge[89, 227] -> 
             RGBColor[
              0.22675241851123462`, 0.35566154716197895`, 0.9362245868328485],
              UndirectedEdge[246, 254] -> 
             RGBColor[
              0.4566571232556863, 0.569515492226385, 0.9504402532261262], 
             UndirectedEdge[197, 345] -> 
             RGBColor[
              0.5953494141792219, 0.6596031686238084, 0.8854466791861835], 
             UndirectedEdge[231, 234] -> 
             RGBColor[
              0.3237117587462526, 0.454798867157554, 0.9418478143825956], 
             UndirectedEdge[89, 209] -> 
             RGBColor[
              0.23530790735490154`, 0.3646539083859959, 0.9367118092657838], 
             UndirectedEdge[233, 317] -> 
             RGBColor[
              0.9040426479180714, 0.5627946336685001, 0.48467433968140694`], 
             UndirectedEdge[48, 342] -> 
             RGBColor[
              0.5144005472567488, 0.6158956891444403, 0.9551237685400916], 
             UndirectedEdge[24, 104] -> 
             RGBColor[
              0.9180135558932775, 0.712060691693382, 0.25285908317008815`], 
             UndirectedEdge[118, 149] -> 
             RGBColor[
              0.21314012851733694`, 0.34135416730935836`, 0.9354493870552745],
              UndirectedEdge[34, 53] -> 
             RGBColor[
              0.30076648553276153`, 0.4331274488318972, 0.9404515726006413], 
             UndirectedEdge[29, 45] -> 
             RGBColor[
              0.26796415172899, 0.39897769174864406`, 0.938571534072304], 
             UndirectedEdge[35, 208] -> 
             RGBColor[
              0.25706388434981153`, 0.3875208196162586, 0.9379507799705602], 
             UndirectedEdge[69, 191] -> 
             RGBColor[
              0.5835359920161374, 0.6722207850854224, 0.9607394608823273], 
             UndirectedEdge[102, 166] -> 
             RGBColor[
              0.8220330696681408, 0.1703614051878311, 0.16873219843799186`], 
             UndirectedEdge[185, 213] -> 
             RGBColor[
              0.8673292987337209, 0.4339131427504039, 0.20877019917985573`], 
             UndirectedEdge[172, 364] -> 
             RGBColor[
              0.3254772137216906, 0.45565682861361634`, 0.9419848830531403], 
             UndirectedEdge[36, 55] -> 
             RGBColor[
              0.46160497467818506`, 0.5724389504821938, 0.9511318842995795], 
             UndirectedEdge[192, 203] -> 
             RGBColor[
              0.31794365991620344`, 0.4482045703725628, 0.9415387963349251], 
             UndirectedEdge[105, 394] -> 
             RGBColor[
              0.38810603050507936`, 0.5105796696723884, 0.9459507509684641], 
             UndirectedEdge[256, 261] -> 
             RGBColor[
              0.20237836752934693`, 0.3300428741759244, 0.934836520687607], 
             UndirectedEdge[215, 295] -> 
             RGBColor[
              0.5308377735120957, 0.2606789813644203, 0.5516093391744658], 
             UndirectedEdge[219, 357] -> 
             RGBColor[
              0.5614389734467367, 0.6541634389484363, 0.9590127623584092], 
             UndirectedEdge[204, 295] -> 
             RGBColor[
              0.21065717499813985`, 0.33874442573233643`, 0.9353079865255567],
              UndirectedEdge[24, 138] -> 
             RGBColor[
              0.8607479504188854, 0.399132481136813, 0.2031112451403423], 
             UndirectedEdge[135, 376] -> 
             RGBColor[
              0.47083567399736015`, 0.5808793962784845, 0.9515970246612349], 
             UndirectedEdge[127, 305] -> 
             RGBColor[
              0.20669916269368893`, 0.33458430384788407`, 0.9350825835801727],
              UndirectedEdge[54, 158] -> 
             RGBColor[
              0.4775536933364365, 0.5867026096855403, 0.9520238744302849], 
             UndirectedEdge[180, 350] -> 
             RGBColor[
              0.3995063863984757, 0.5204540849487005, 0.9466771715650524], 
             UndirectedEdge[46, 287] -> 
             RGBColor[
              0.27226485336384204`, 0.4034980018471065, 0.9388164526680909], 
             UndirectedEdge[41, 153] -> 
             RGBColor[
              0.32912553840433756`, 0.45949373186045395`, 0.9421925661662062],
              UndirectedEdge[163, 315] -> 
             RGBColor[
              0.24412373790812583`, 0.3739199052533755, 0.9372138577739373], 
             UndirectedEdge[17, 64] -> 
             RGBColor[
              0.46723843843845614`, 0.5768882992816866, 0.951609674456959], 
             UndirectedEdge[67, 127] -> 
             RGBColor[
              0.21172079285419906`, 0.33986235553632177`, 0.9353685579889777],
              UndirectedEdge[83, 246] -> 
             RGBColor[
              0.39834226268445083`, 0.5194457794981713, 0.946602994631389], 
             UndirectedEdge[44, 383] -> 
             RGBColor[
              0.28909643467092216`, 0.42118906098474024`, 0.9397749863234359],
              UndirectedEdge[5, 275] -> 
             RGBColor[
              0.916771833602923, 0.9337046356973782, 0.882657568389807], 
             UndirectedEdge[99, 123] -> 
             RGBColor[
              0.9762118677425246, 0.9817794304286422, 0.9251512823600752], 
             UndirectedEdge[278, 354] -> 
             RGBColor[
              0.2660945297513849, 0.3970126005093012, 0.9384650618665371], 
             UndirectedEdge[61, 215] -> 
             RGBColor[
              0.9063170503481712, 0.5687194984901538, 0.341612283904028], 
             UndirectedEdge[115, 208] -> 
             RGBColor[
              0.2358464087925902, 0.36521990753996986`, 0.9367424761260187], 
             UndirectedEdge[167, 203] -> 
             RGBColor[
              0.2874735215718495, 0.4194832764189812, 0.9396825638233285], 
             UndirectedEdge[242, 256] -> 
             RGBColor[
              0.5718276027056971, 0.5340616080097416, 0.5946502523941279], 
             UndirectedEdge[136, 254] -> 
             RGBColor[
              0.5440467518592814, 0.6407206880430576, 0.9572484996967315], 
             UndirectedEdge[65, 170] -> 
             RGBColor[
              0.4801509107444425, 0.5886204880785566, 0.952281016742329], 
             UndirectedEdge[247, 340] -> 
             RGBColor[
              0.9503928339373993, 0.8290616417134029, 0.4041000646481473], 
             UndirectedEdge[8, 17] -> 
             RGBColor[
              0.42291827954092154`, 0.5385004052405986, 0.9487856331227857], 
             UndirectedEdge[269, 300] -> 
             RGBColor[
              0.9415278534612976, 0.7904724805205449, 0.35790419683327634`], 
             UndirectedEdge[233, 242] -> 
             RGBColor[
              0.867902536299588, 0.4245883317454004, 0.20875474200246447`], 
             UndirectedEdge[242, 382] -> 
             RGBColor[
              0.9085638811026002, 0.6736245465915296, 0.24520540694695725`], 
             UndirectedEdge[144, 242] -> 
             RGBColor[
              0.8983924729381163, 0.6274385577093406, 0.23671813465048305`], 
             UndirectedEdge[81, 227] -> 
             RGBColor[
              0.2273187292651137, 0.35625677567048153`, 0.9362568373925002], 
             UndirectedEdge[224, 230] -> 
             RGBColor[
              0.9722593705527938, 0.9180864844443417, 0.3467333222862512], 
             UndirectedEdge[81, 248] -> 
             RGBColor[
              0.21796166804011632`, 0.3464219110510618, 0.9357239665982682], 
             UndirectedEdge[13, 323] -> 
             RGBColor[
              0.8969951869704291, 0.9199794950758233, 0.9649311806841149], 
             UndirectedEdge[10, 189] -> 
             RGBColor[
              0.3312363099818102, 0.46056389881459425`, 0.9423548195879734], 
             UndirectedEdge[135, 364] -> 
             RGBColor[
              0.42640390772588643`, 0.5423948335396401, 0.9487658718038847], 
             UndirectedEdge[39, 383] -> 
             RGBColor[
              0.27666419535336334`, 0.408121989212486, 0.9390669886861509], 
             UndirectedEdge[108, 196] -> 
             RGBColor[
              0.332746597404592, 0.4616295540574491, 0.9424599321408476], 
             UndirectedEdge[75, 89] -> 
             RGBColor[
              0.23138047401831524`, 0.3605259269355878, 0.9364881477473821], 
             UndirectedEdge[131, 269] -> 
             RGBColor[
              0.9577625542405059, 0.8589366723660075, 0.3711790558606476], 
             UndirectedEdge[36, 165] -> 
             RGBColor[
              0.5262130350709433, 0.6262424733544989, 0.9558445641840965], 
             UndirectedEdge[40, 41] -> 
             RGBColor[
              0.34006622360312927`, 0.4689700034848203, 0.942889696952605], 
             UndirectedEdge[86, 249] -> 
             RGBColor[
              0.2850528182511259, 0.41693896374744543`, 0.939544708350323], 
             UndirectedEdge[287, 395] -> 
             RGBColor[
              0.2666407460996809, 0.397586708523477, 0.938496168079518], 
             UndirectedEdge[177, 225] -> 
             RGBColor[
              0.2895083029136421, 0.42040499749423077`, 0.9398430005920957], 
             UndirectedEdge[74, 216] -> 
             RGBColor[
              0.7418875253371497, 0.7983253437301927, 0.9748980148903788], 
             UndirectedEdge[229, 371] -> 
             RGBColor[
              0.25947088353624953`, 0.3900507283737679, 0.9380878550133916], 
             UndirectedEdge[319, 371] -> 
             RGBColor[
              0.2568146393431022, 0.387258847311161, 0.937936585836153], 
             UndirectedEdge[169, 353] -> 
             RGBColor[
              0.21553905850906607`, 0.343875594831612, 0.9355860025694045], 
             UndirectedEdge[47, 362] -> 
             RGBColor[
              0.4192754724662534, 0.5375770736774529, 0.9479368402481747], 
             UndirectedEdge[83, 313] -> 
             RGBColor[
              0.31784501109874064`, 0.44732499341570175`, 0.9415615875935087],
              UndirectedEdge[87, 210] -> 
             RGBColor[
              0.2950312133683537, 0.42742688968244336`, 0.9401129631905363], 
             UndirectedEdge[91, 150] -> 
             RGBColor[
              0.2666109948635128, 0.3975554380879269, 0.9384944737906311], 
             UndirectedEdge[16, 258] -> 
             RGBColor[
              0.24739688608388788`, 0.37736019151568206`, 0.9374002587203583],
              UndirectedEdge[334, 388] -> 
             RGBColor[
              0.24238207309791887`, 0.372089305109921, 0.9371146725395583], 
             UndirectedEdge[67, 325] -> 
             RGBColor[
              0.21225679273606501`, 0.3404257253965182, 0.9353990823893092], 
             UndirectedEdge[279, 363] -> 
             RGBColor[
              0.9040810668165558, 0.6454045668048165, 0.24105801091555495`], 
             UndirectedEdge[192, 385] -> 
             RGBColor[
              0.45995539470159097`, 0.5694965937320001, 0.9514449793856737], 
             UndirectedEdge[216, 339] -> 
             RGBColor[
              0.5124310381777115, 0.6124197611712089, 0.9555918284959135], 
             UndirectedEdge[74, 323] -> 
             RGBColor[
              0.8274418605794372, 0.8652436955878107, 0.9834033373997775], 
             UndirectedEdge[60, 87] -> 
             RGBColor[
              0.32383352968544554`, 0.4531896894262284, 0.9419183552403817], 
             UndirectedEdge[74, 198] -> 
             RGBColor[
              0.8255815527613636, 0.8637603366303892, 0.9832258995793732], 
             UndirectedEdge[16, 348] -> 
             RGBColor[
              0.252407866634222, 0.38262704978860046`, 0.9376856266496183], 
             UndirectedEdge[88, 283] -> 
             RGBColor[
              0.9496145330722283, 0.8334245259791293, 0.5278793972462171], 
             UndirectedEdge[292, 388] -> 
             RGBColor[
              0.21719189432910094`, 0.3456128300743124, 0.9356801291242041], 
             UndirectedEdge[76, 382] -> 
             RGBColor[
              0.8728626791215081, 0.4975553578985697, 0.2149200050950769], 
             UndirectedEdge[131, 352] -> 
             RGBColor[
              0.9583101575279735, 0.8601079404267151, 0.43078229428572945`], 
             UndirectedEdge[123, 232] -> 
             RGBColor[
              0.7499263891145284, 0.8030301325071595, 0.9420935049543039], 
             UndirectedEdge[69, 357] -> 
             RGBColor[
              0.5819543622257783, 0.6709852038723623, 0.9605818188059951], 
             UndirectedEdge[241, 339] -> 
             RGBColor[
              0.32836122521249217`, 0.457187465102298, 0.9422040691120204], 
             UndirectedEdge[181, 322] -> 
             RGBColor[
              0.5378642093893072, 0.6357014215455682, 0.9567617873060958], 
             UndirectedEdge[140, 168] -> 
             RGBColor[
              0.6710377427034506, 0.7429390517664531, 0.9678464290545918], 
             UndirectedEdge[88, 357] -> 
             RGBColor[
              0.8330019348815232, 0.8684180093986145, 0.8892498058738514], 
             UndirectedEdge[125, 179] -> 
             RGBColor[
              0.2738145581196516, 0.4051268398024189, 0.9389047060613515], 
             UndirectedEdge[316, 324] -> 
             RGBColor[
              0.2671185805915378, 0.39808894287087526`, 0.9385233800469365], 
             UndirectedEdge[128, 390] -> 
             RGBColor[
              0.29625621364741994`, 0.42709948500765055`, 0.9402418566543815],
              UndirectedEdge[200, 339] -> 
             RGBColor[
              0.3182100783412779, 0.4465179661207665, 0.9416259763149808], 
             UndirectedEdge[85, 110] -> 
             RGBColor[
              0.2484427050223485, 0.37845941352875473`, 0.9374598165617531], 
             UndirectedEdge[178, 209] -> 
             RGBColor[
              0.24801071646784933`, 0.37800536616831976`, 0.9374352154526442],
              UndirectedEdge[380, 383] -> 
             RGBColor[
              0.2728634955258139, 0.4041272127154443, 0.9388505444536035], 
             UndirectedEdge[350, 357] -> 
             RGBColor[
              0.5542164267531839, 0.6479076320182329, 0.9585525480697432], 
             UndirectedEdge[98, 352] -> 
             RGBColor[
              0.9858621188487648, 0.9629527205499828, 0.4862282141252213], 
             UndirectedEdge[68, 151] -> 
             RGBColor[
              0.29628007015479707`, 0.4280840429902235, 0.9402080838641316], 
             UndirectedEdge[307, 385] -> 
             RGBColor[
              0.7803305100204103, 0.8271780586683711, 0.9269968726475282], 
             UndirectedEdge[94, 119] -> 
             RGBColor[
              0.25031116778183593`, 0.38042328635635736`, 0.9375662227517629],
              UndirectedEdge[116, 121] -> 
             RGBColor[
              0.48470874113100904`, 0.5915401565241579, 0.9528555034179461], 
             UndirectedEdge[1, 361] -> 
             RGBColor[
              0.35780477718256065`, 0.4843342470296975, 0.9440199819010995], 
             UndirectedEdge[180, 239] -> 
             RGBColor[
              0.3453924706572131, 0.47358333097810695`, 0.943229080705076], 
             UndirectedEdge[45, 394] -> 
             RGBColor[
              0.32718352263793704`, 0.4565868884354943, 0.9421136673575129], 
             UndirectedEdge[32, 124] -> 
             RGBColor[
              0.21977833860588586`, 0.34833134699925217`, 0.9358274232994656],
              UndirectedEdge[87, 243] -> 
             RGBColor[
              0.2892553344802239, 0.4213560747591461, 0.9397840354325044], 
             UndirectedEdge[188, 195] -> 
             RGBColor[
              0.25639031228130726`, 0.3868128526653249, 0.9379124210377194], 
             UndirectedEdge[122, 262] -> 
             RGBColor[
              0.6923652232093209, 0.7572804525421046, 0.9691955483013721], 
             UndirectedEdge[118, 212] -> 
             RGBColor[
              0.208479398474888, 0.33645544452739207`, 0.9351839653742893], 
             UndirectedEdge[35, 258] -> 
             RGBColor[
              0.2669871560923189, 0.3979508073894016, 0.938515895616131], 
             UndirectedEdge[183, 271] -> 
             RGBColor[
              0.28286075625291396`, 0.4146349676025667, 0.9394198736623899], 
             UndirectedEdge[130, 147] -> 
             RGBColor[
              0.34757171171070933`, 0.4732511609805692, 0.9434492148065551], 
             UndirectedEdge[124, 330] -> 
             RGBColor[
              0.22402160898279397`, 0.3527912932042634, 0.9360690712700745], 
             UndirectedEdge[46, 395] -> 
             RGBColor[
              0.27869220583377896`, 0.41025355681069386`, 0.939182480882838], 
             UndirectedEdge[206, 284] -> 
             RGBColor[
              0.23778007994491618`, 0.3672523185228967, 0.9368525958375336], 
             UndirectedEdge[179, 313] -> 
             RGBColor[
              0.2762257553297003, 0.407661160948913, 0.939042020175417], 
             UndirectedEdge[215, 363] -> 
             RGBColor[
              0.8409003453545498, 0.3089231403704602, 0.18654654935464235`], 
             UndirectedEdge[260, 338] -> 
             RGBColor[
              0.9016212039882432, 0.9204360205910522, 0.8006477894997438], 
             UndirectedEdge[88, 113] -> 
             RGBColor[
              0.8934147061054667, 0.915612925432826, 0.8952711863200087], 
             UndirectedEdge[95, 270] -> 
             RGBColor[
              0.26568283896088996`, 0.3965798873857872, 0.9384416166850604], 
             UndirectedEdge[16, 184] -> 
             RGBColor[
              0.22981171473055614`, 0.35887706145906934`, 0.9363988092267157],
              UndirectedEdge[38, 78] -> 
             RGBColor[
              0.9038175805994484, 0.6094521874784743, 0.2546544328195417], 
             UndirectedEdge[8, 210] -> 
             RGBColor[
              0.30512183219392025`, 0.43788724700591375`, 0.9406929373091137],
              UndirectedEdge[1, 96] -> 
             RGBColor[
              0.32344726087306624`, 0.45255674347328584`, 0.9419046676618501],
              UndirectedEdge[213, 247] -> 
             RGBColor[
              0.9089878266866289, 0.6768740913610367, 0.24562767290302676`], 
             UndirectedEdge[109, 366] -> 
             RGBColor[
              0.9476884477531541, 0.8182230648175637, 0.4934194788371198], 
             UndirectedEdge[223, 260] -> 
             RGBColor[
              0.6315106131402652, 0.7091757673875206, 0.9658788076150083], 
             UndirectedEdge[393, 399] -> 
             RGBColor[
              0.22884950770057744`, 0.3578657208631124, 0.9363440129598162], 
             UndirectedEdge[25, 358] -> 
             RGBColor[
              0.9086438937541778, 0.640542215450566, 0.2633529303924386], 
             UndirectedEdge[207, 358] -> 
             RGBColor[
              0.9542162454207332, 0.8524596356255733, 0.30144575978299126`], 
             UndirectedEdge[31, 33] -> 
             RGBColor[0.1810793999809316, 0.30765630885, 0.9336235759947237], 
             UndirectedEdge[355, 375] -> 
             RGBColor[
              0.24288325350972279`, 0.37261607749940034`, 0.9371432140225805],
              UndirectedEdge[25, 104] -> 
             RGBColor[
              0.8912926011446027, 0.575480186768195, 0.22996543355252164`], 
             UndirectedEdge[360, 375] -> 
             RGBColor[
              0.2826185317002574, 0.4142282159179257, 0.939411650593985], 
             UndirectedEdge[28, 347] -> 
             RGBColor[
              0.28416959916217255`, 0.4160106444856309, 0.9394944103298126], 
             UndirectedEdge[56, 143] -> 
             RGBColor[
              0.5377896391569529, 0.6355761788857779, 0.956773794547269], 
             UndirectedEdge[73, 115] -> 
             RGBColor[
              0.24086103809529086`, 0.3704906008829697, 0.9370280518463283], 
             UndirectedEdge[157, 218] -> 
             RGBColor[
              0.689653807893005, 0.7555582412254274, 0.971321814931075], 
             UndirectedEdge[267, 321] -> 
             RGBColor[
              0.6944927044467815, 0.7601721648632764, 0.9709294949676452], 
             UndirectedEdge[93, 324] -> 
             RGBColor[
              0.26259788296436154`, 0.3933374030359285, 0.9382659330048415], 
             UndirectedEdge[178, 245] -> 
             RGBColor[
              0.23694364602077422`, 0.3663731734356497, 0.9368049621629467], 
             UndirectedEdge[223, 331] -> 
             RGBColor[
              0.45307983116767014`, 0.5668363678003234, 0.9500964447383967], 
             UndirectedEdge[318, 367] -> 
             RGBColor[
              0.22156608180377718`, 0.3502103784497014, 0.9359292326298564], 
             UndirectedEdge[158, 265] -> 
             RGBColor[
              0.5475052991401734, 0.643528492531465, 0.9575207692077594], 
             UndirectedEdge[124, 199] -> 
             RGBColor[
              0.224537016117427, 0.35333301878146245`, 0.9360984229439153], 
             UndirectedEdge[38, 213] -> 
             RGBColor[
              0.9383796626861343, 0.7904965676280676, 0.28441340229193146`], 
             UndirectedEdge[128, 296] -> 
             RGBColor[
              0.3138673468643941, 0.4456099026290287, 0.9412447846377514], 
             UndirectedEdge[89, 315] -> 
             RGBColor[
              0.23092852589242507`, 0.36005090080011104`, 0.93646240997021], 
             UndirectedEdge[129, 178] -> 
             RGBColor[
              0.24083645723076108`, 0.3704647648358321, 0.9370266520024574], 
             UndirectedEdge[61, 279] -> 
             RGBColor[
              0.9694977718101772, 0.9052009249245101, 0.39612374546494056`], 
             UndirectedEdge[7, 332] -> 
             RGBColor[
              0.45831330080032634`, 0.5693830222721039, 0.9509787412394903], 
             UndirectedEdge[105, 180] -> 
             RGBColor[
              0.39180706588006936`, 0.513785320494758, 0.9461865776698615], 
             UndirectedEdge[75, 163] -> 
             RGBColor[
              0.24457568603401603`, 0.37439493138885227`, 0.9372395955511095],
              UndirectedEdge[15, 273] -> 
             RGBColor[
              0.28964915667663804`, 0.4217700068573468, 0.9398064630239824], 
             UndirectedEdge[149, 287] -> 
             RGBColor[
              0.24021601426247097`, 0.36981263993780294`, 0.9369913186932763],
              UndirectedEdge[123, 275] -> 
             RGBColor[
              0.9831983875687983, 0.9856760529092304, 0.8544852374631398], 
             UndirectedEdge[186, 226] -> 
             RGBColor[
              0.24355084950968384`, 0.37331776322339055`, 0.9371812326271585],
              UndirectedEdge[15, 183] -> 
             RGBColor[
              0.281397272925088, 0.41309675383481925`, 0.9393365304518997], 
             UndirectedEdge[35, 41] -> 
             RGBColor[
              0.3109306833758936, 0.44117275107327436`, 0.9411269955899995], 
             UndirectedEdge[47, 54] -> 
             RGBColor[
              0.44294170199458305`, 0.5580755721956097, 0.9494448314664949], 
             UndirectedEdge[19, 196] -> 
             RGBColor[
              0.2861541125436652, 0.4180964938749955, 0.9396074254310642], 
             UndirectedEdge[211, 328] -> 
             RGBColor[
              0.2860571913279975, 0.41793071873950494`, 0.9396042457787188], 
             UndirectedEdge[3, 86] -> 
             RGBColor[
              0.33530800642617503`, 0.4640896371481913, 0.9426142996527203], 
             UndirectedEdge[55, 58] -> 
             RGBColor[
              0.351171823063294, 0.4776705562573528, 0.9436309688854188], 
             UndirectedEdge[63, 214] -> 
             RGBColor[
              0.9711670732550739, 0.9296487112649943, 0.6029350218130802], 
             UndirectedEdge[26, 106] -> 
             RGBColor[
              0.7018038352541023, 0.7648141211568, 0.9611581586207743], 
             UndirectedEdge[89, 378] -> 
             RGBColor[
              0.2135546306131389, 0.341789835292997, 0.9354729923364294], 
             UndirectedEdge[191, 311] -> 
             RGBColor[
              0.5991137006259042, 0.6848674707026068, 0.961965795167115], 
             UndirectedEdge[147, 364] -> 
             RGBColor[
              0.31713379957570453`, 0.44688737134317436`, 0.9415097379605015],
              UndirectedEdge[137, 285] -> 
             RGBColor[
              0.23013560035880143`, 0.35921748578989005`, 0.9364172540340985],
              UndirectedEdge[104, 205] -> 
             RGBColor[
              0.9645712998383063, 0.8839256222853624, 0.49686413410326324`], 
             UndirectedEdge[191, 339] -> 
             RGBColor[
              0.5223069322379694, 0.6201348846706572, 0.9565761653203628], 
             UndirectedEdge[40, 167] -> 
             RGBColor[
              0.31143079927380024`, 0.4418378465956456, 0.9411503707956721], 
             UndirectedEdge[17, 262] -> 
             RGBColor[
              0.7370797325190604, 0.7937780282574919, 0.9726613937241215], 
             UndirectedEdge[96, 348] -> 
             RGBColor[
              0.27493335548153697`, 0.4063027667656103, 0.9389684199159984], 
             UndirectedEdge[60, 122] -> 
             RGBColor[
              0.4018079642776756, 0.5224475960269956, 0.9468238260723096], 
             UndirectedEdge[99, 187] -> 
             RGBColor[
              0.9110307205751575, 0.9308010667922535, 0.953442401298972], 
             UndirectedEdge[111, 166] -> 
             RGBColor[
              0.8494236278647009, 0.35624594261769826`, 0.19399614499147944`],
              UndirectedEdge[130, 172] -> 
             RGBColor[
              0.3559151258566954, 0.4820206182510111, 0.9439243598991939], 
             UndirectedEdge[205, 230] -> 
             RGBColor[
              0.9820628725503424, 0.9494608486926688, 0.5307965926515668], 
             UndirectedEdge[248, 319] -> 
             RGBColor[
              0.2288957810137855, 0.3579143570491916, 0.9363466481565481], 
             UndirectedEdge[77, 111] -> 
             RGBColor[
              0.8517216279012312, 0.6939386797204187, 0.6001134200588495], 
             UndirectedEdge[41, 188] -> 
             RGBColor[
              0.30395311727072993`, 0.43383888669350434`, 0.9407296335226945],
              UndirectedEdge[57, 278] -> 
             RGBColor[
              0.26281152350528336`, 0.39356195279003, 0.9382780995175941], 
             UndirectedEdge[56, 331] -> 
             RGBColor[
              0.4515137506850261, 0.565500249927577, 0.9499910348290849], 
             UndirectedEdge[40, 87] -> 
             RGBColor[
              0.31472542396778913`, 0.4453007060402985, 0.9413379947980343], 
             UndirectedEdge[142, 214] -> 
             RGBColor[
              0.9026785336009098, 0.577164017789306, 0.5403271212608096], 
             UndirectedEdge[341, 368] -> 
             RGBColor[
              0.2171826090564914, 0.3456030706640795, 0.9356796003416652], 
             UndirectedEdge[96, 188] -> 
             RGBColor[
              0.2769987034014417, 0.4084735783800516, 0.9390860384246287], 
             UndirectedEdge[142, 202] -> 
             RGBColor[
              0.8389617996732674, 0.300483042224024, 0.18494316940916705`], 
             UndirectedEdge[37, 351] -> 
             RGBColor[
              0.2477720085286644, 0.3777544689892789, 0.9374216213886444], 
             UndirectedEdge[83, 108] -> 
             RGBColor[
              0.3602253738682746, 0.48643084621613597`, 0.9441742201814636], 
             UndirectedEdge[72, 119] -> 
             RGBColor[
              0.2341124382405141, 0.36339739454965503`, 0.9366437290682574], 
             UndirectedEdge[170, 180] -> 
             RGBColor[
              0.40561982873439206`, 0.5257492414295251, 0.9470667147047922], 
             UndirectedEdge[196, 234] -> 
             RGBColor[
              0.3183317548341577, 0.44914414193399255`, 0.9415414311188043], 
             UndirectedEdge[218, 306] -> 
             RGBColor[
              0.9402199448611399, 0.9214289952270589, 0.6653505611679222], 
             UndirectedEdge[186, 189] -> 
             RGBColor[
              0.2745072076984255, 0.4058548584262301, 0.9389441514301794], 
             UndirectedEdge[20, 135] -> 
             RGBColor[
              0.45546851492086315`, 0.5675691354622958, 0.9506178428735257], 
             UndirectedEdge[79, 254] -> 
             RGBColor[
              0.5301586737259505, 0.6294457205636295, 0.9561551793123693], 
             UndirectedEdge[93, 355] -> 
             RGBColor[
              0.23807963900287032`, 0.36756717408594775`, 0.936869655282726], 
             UndirectedEdge[211, 301] -> 
             RGBColor[
              0.25974755171345176`, 0.39034152416978307`, 0.9381036108567895],
              UndirectedEdge[145, 227] -> 
             RGBColor[
              0.23647303514531387`, 0.36587853156708794`, 0.9367781615697957],
              UndirectedEdge[26, 345] -> 
             RGBColor[
              0.3285301240705917, 0.4490550186158963, 0.9425296374326482], 
             UndirectedEdge[132, 140] -> 
             RGBColor[
              0.7355736784173503, 0.7933550152374292, 0.9742787680039452], 
             UndirectedEdge[153, 258] -> 
             RGBColor[
              0.28518201112076286`, 0.41627178817658117`, 0.9395814661923377],
              UndirectedEdge[56, 344] -> 
             RGBColor[
              0.38578184035649155`, 0.5085665729828752, 0.9458026556273967], 
             UndirectedEdge[44, 390] -> 
             RGBColor[
              0.28212790876587335`, 0.4138646984284726, 0.9393781390821536], 
             UndirectedEdge[223, 346] -> 
             RGBColor[
              0.3995496021231435, 0.5204711739094963, 0.9466855458786024], 
             UndirectedEdge[114, 222] -> 
             RGBColor[
              0.4669023906435984, 0.574712579304436, 0.9521089968254883], 
             UndirectedEdge[85, 203] -> 
             RGBColor[
              0.2663525209612127, 0.3972837656284177, 0.9384797540842731], 
             UndirectedEdge[156, 261] -> 
             RGBColor[
              0.18270395436139325`, 0.3093638185065621, 0.9337160919633781], 
             UndirectedEdge[33, 295] -> 
             RGBColor[
              0.21066436833308994`, 0.3387519863834527, 0.9353083961753406], 
             UndirectedEdge[59, 395] -> 
             RGBColor[
              0.303543145607047, 0.434036883269187, 0.9406832590311243], 
             UndirectedEdge[334, 371] -> 
             RGBColor[
              0.26672232113879757`, 0.3976724490617448, 0.9385008136573162], 
             UndirectedEdge[40, 154] -> 
             RGBColor[
              0.3847350802007028, 0.5076599219476261, 0.9457359569958835], 
             UndirectedEdge[300, 306] -> 
             RGBColor[
              0.9301864468516778, 0.7525583544999579, 0.2846700934867103], 
             UndirectedEdge[61, 297] -> 
             RGBColor[
              0.9699924620425022, 0.9739499675150907, 0.7461656307796394], 
             UndirectedEdge[97, 350] -> 
             RGBColor[
              0.437513599136121, 0.5533740223239922, 0.9490989575522366], 
             UndirectedEdge[178, 229] -> 
             RGBColor[
              0.24544230257567465`, 0.37530580032079786`, 0.9372889480811126],
              UndirectedEdge[130, 265] -> 
             RGBColor[
              0.5011501438603255, 0.6047301166670249, 0.9541934622219126], 
             UndirectedEdge[110, 134] -> 
             RGBColor[
              0.24495240537755758`, 0.37479088730430044`, 0.9372610491604179],
              UndirectedEdge[147, 211] -> 
             RGBColor[
              0.2737075152920192, 0.40501433100367, 0.9388986101306735], 
             UndirectedEdge[78, 185] -> 
             RGBColor[
              0.832767216647035, 0.2528687626008105, 0.17901122970746597`], 
             UndirectedEdge[130, 135] -> 
             RGBColor[
              0.4568418198608912, 0.568758623177035, 0.9507053486499384], 
             UndirectedEdge[52, 384] -> 
             RGBColor[
              0.5675366621289825, 0.6563557009893235, 0.9607088184571579], 
             UndirectedEdge[77, 166] -> 
             RGBColor[
              0.827067103969575, 0.529084500588463, 0.5774695030073427], 
             UndirectedEdge[24, 76] -> 
             RGBColor[
              0.8745487301949283, 0.505211322035738, 0.2163268874396324], 
             UndirectedEdge[100, 220] -> 
             RGBColor[
              0.42602430021250687`, 0.5428220538333498, 0.9485327937322395], 
             UndirectedEdge[41, 369] -> 
             RGBColor[
              0.2991371325274741, 0.4287769813772735, 0.940455370316177], 
             UndirectedEdge[12, 318] -> 
             RGBColor[
              0.2211272263803799, 0.3497491135746699, 0.9359042404627222], 
             UndirectedEdge[118, 199] -> 
             RGBColor[
              0.21593219336709382`, 0.3442888044935889, 0.9356083910179783], 
             UndirectedEdge[11, 205] -> 
             RGBColor[
              0.9593655870867921, 0.8632867059265485, 0.49267549542961175`], 
             UndirectedEdge[120, 136] -> 
             RGBColor[
              0.5924802140391232, 0.6800411545432594, 0.9610613592571464], 
             UndirectedEdge[66, 215] -> 
             RGBColor[
              0.8960355420221306, 0.5345577698337973, 0.25743539509359753`], 
             UndirectedEdge[199, 287] -> 
             RGBColor[
              0.24300807911222783`, 0.3727472771220335, 0.9371503226559803], 
             UndirectedEdge[8, 64] -> 
             RGBColor[
              0.3546401133620532, 0.4815931742890025, 0.9438183323208591], 
             UndirectedEdge[312, 361] -> 
             RGBColor[
              0.40929184788600736`, 0.528668033662285, 0.9473730082456748], 
             UndirectedEdge[5, 193] -> 
             RGBColor[
              0.8318913190108279, 0.8687915729636699, 0.983827730717042], 
             UndirectedEdge[187, 232] -> 
             RGBColor[
              0.6847452419471614, 0.7520517688707707, 0.9703846238932006], 
             UndirectedEdge[115, 325] -> 
             RGBColor[
              0.22508690864981107`, 0.3539109906981984, 0.9361297385101415], 
             UndirectedEdge[137, 252] -> 
             RGBColor[
              0.22294460960746476`, 0.35165929857508804`, 0.9360077377489273],
              UndirectedEdge[296, 390] -> 
             RGBColor[
              0.283910407540538, 0.415738217657595, 0.9394796497504001], 
             UndirectedEdge[101, 171] -> 
             RGBColor[
              0.2670272094470698, 0.3979929060047742, 0.9385181765954305], 
             UndirectedEdge[234, 342] -> 
             RGBColor[
              0.47104879657377785`, 0.578346581625195, 0.9523614333210206], 
             UndirectedEdge[56, 343] -> 
             RGBColor[
              0.5865678018857227, 0.673953417760403, 0.9614500105609494], 
             UndirectedEdge[60, 146] -> 
             RGBColor[
              0.44642978990835863`, 0.5588699269563728, 0.9502823750963323], 
             UndirectedEdge[149, 336] -> 
             RGBColor[
              0.21561259787663173`, 0.3439528893695888, 0.9355901905275956], 
             UndirectedEdge[12, 199] -> 
             RGBColor[
              0.22211987446733733`, 0.350792449651586, 0.9359607703027832], 
             UndirectedEdge[42, 104] -> 
             RGBColor[
              0.9330499750272585, 0.8621677183315113, 0.6295247357296906], 
             UndirectedEdge[216, 323] -> 
             RGBColor[
              0.7446559095096992, 0.8005327781235971, 0.9751620658441222], 
             UndirectedEdge[110, 192] -> 
             RGBColor[
              0.30003384397733923`, 0.42938021827289985`, 0.940518858812405], 
             UndirectedEdge[93, 380] -> 
             RGBColor[
              0.25536438822798396`, 0.38573454143794017`, 0.9378539961806014],
              UndirectedEdge[34, 397] -> 
             RGBColor[
              0.28081927975955956`, 0.41216167083836874`, 0.939315608741104], 
             UndirectedEdge[249, 308] -> 
             RGBColor[
              0.2653288302878062, 0.39620780182492993`, 0.9384214564148372], 
             UndirectedEdge[116, 130] -> 
             RGBColor[
              0.4133134657138138, 0.5324130830876621, 0.947556946449905], 
             UndirectedEdge[81, 315] -> 
             RGBColor[
              0.23149483664630416`, 0.3606461293086136, 0.9364946605298619], 
             UndirectedEdge[99, 193] -> 
             RGBColor[
              0.9002336063428361, 0.9221917409832586, 0.9524125629047955], 
             UndirectedEdge[116, 135] -> 
             RGBColor[
              0.4597496952635722, 0.5712772786967698, 0.9508906358992639], 
             UndirectedEdge[304, 378] -> 
             RGBColor[
              0.21381243485280502`, 0.34206080389461896`, 0.9354876739064912],
              UndirectedEdge[56, 120] -> 
             RGBColor[
              0.5086566729306621, 0.6119247244781029, 0.9544803407283637], 
             UndirectedEdge[255, 393] -> 
             RGBColor[
              0.2416474883761139, 0.3713172099919425, 0.9370728390263723], 
             UndirectedEdge[106, 214] -> 
             RGBColor[
              0.9661339552698273, 0.9742633398075717, 0.9422105594358144], 
             UndirectedEdge[130, 328] -> 
             RGBColor[
              0.3599213877466876, 0.48616754871640405`, 0.9441548504546003], 
             UndirectedEdge[181, 250] -> 
             RGBColor[
              0.7777697545864616, 0.8245041838583995, 0.9019245302265969], 
             UndirectedEdge[102, 230] -> 
             RGBColor[
              0.8940771340934058, 0.5279706608893748, 0.24981441421432754`], 
             UndirectedEdge[45, 141] -> 
             RGBColor[
              0.32778152064738697`, 0.45710484425502595`, 0.9421517712618861],
              UndirectedEdge[225, 288] -> 
             RGBColor[
              0.25106704817739506`, 0.3812177645776751, 0.9376092690220652], 
             UndirectedEdge[208, 278] -> 
             RGBColor[
              0.24275117083398723`, 0.37247725023267697`, 0.9371356921095961],
              UndirectedEdge[342, 346] -> 
             RGBColor[
              0.4741951057473072, 0.5810717564932091, 0.9525619133593859], 
             UndirectedEdge[133, 164] -> 
             RGBColor[
              0.2698983654154672, 0.40101067296936244`, 0.9386816846803361], 
             UndirectedEdge[287, 373] -> 
             RGBColor[
              0.2552675974110747, 0.3856328081524763, 0.9378484840867676], 
             UndirectedEdge[122, 314] -> 
             RGBColor[
              0.6859497834912932, 0.7522408691078613, 0.9712156258567326], 
             UndirectedEdge[85, 351] -> 
             RGBColor[
              0.24352597864269326`, 0.37329162236527946`, 0.9371798162680766],
              UndirectedEdge[5, 338] -> 
             RGBColor[
              0.9178657002272999, 0.9332997898377504, 0.8022208620159], 
             UndirectedEdge[311, 339] -> 
             RGBColor[
              0.4425672704759462, 0.555957682108388, 0.9499165435038557], 
             UndirectedEdge[39, 324] -> 
             RGBColor[
              0.27652485948189337`, 0.40797553837716655`, 0.9390590537143996],
              UndirectedEdge[52, 346] -> 
             RGBColor[
              0.36583874865596927`, 0.4912928693208167, 0.944531899459223], 
             UndirectedEdge[272, 291] -> 
             RGBColor[
              0.6717542540567425, 0.7434987958813325, 0.9679178442101087], 
             UndirectedEdge[191, 323] -> 
             RGBColor[
              0.7545318035699571, 0.8082479016230455, 0.9761464026685716], 
             UndirectedEdge[60, 165] -> 
             RGBColor[
              0.4451385583294708, 0.557821646991312, 0.950180724616505], 
             UndirectedEdge[44, 301] -> 
             RGBColor[
              0.2773872245806669, 0.4088819387730828, 0.9391081641310199], 
             UndirectedEdge[11, 144] -> 
             RGBColor[
              0.9009503839038591, 0.6375798223152109, 0.23877628985540691`], 
             UndirectedEdge[333, 381] -> 
             RGBColor[
              0.5943537422981029, 0.6571554755250186, 0.8488416222676571], 
             UndirectedEdge[9, 363] -> 
             RGBColor[
              0.8440899658094313, 0.333439960887275, 0.18960093350439794`], 
             UndirectedEdge[153, 312] -> 
             RGBColor[
              0.39019396776607296`, 0.5121264097897626, 0.9461561082120249], 
             UndirectedEdge[55, 80] -> 
             RGBColor[
              0.36897452576073053`, 0.49400892184022105`, 0.9447317084034796],
              UndirectedEdge[7, 40] -> 
             RGBColor[
              0.36435856265805855`, 0.4900108066057379, 0.9444375833163132], 
             UndirectedEdge[51, 377] -> 
             RGBColor[
              0.39390138797963725`, 0.5155993170337143, 0.9463200260221095], 
             UndirectedEdge[112, 170] -> 
             RGBColor[
              0.3869454032271654, 0.5095743926590826, 0.9458767968246178], 
             UndirectedEdge[200, 375] -> 
             RGBColor[
              0.26275249757312547`, 0.3934999127928718, 0.9382747380780788], 
             UndirectedEdge[94, 200] -> 
             RGBColor[
              0.26539181138814727`, 0.3962739989546208, 0.9384250430953294], 
             UndirectedEdge[8, 253] -> 
             RGBColor[
              0.3260178665234107, 0.4568020226733255, 0.9419945480619598], 
             UndirectedEdge[31, 295] -> 
             RGBColor[
              0.21280238164412135`, 0.34099917393122015`, 0.9354301528704966],
              UndirectedEdge[301, 383] -> 
             RGBColor[
              0.2685271160434062, 0.39956940293709464`, 0.9386035940571789], 
             UndirectedEdge[327, 392] -> 
             RGBColor[
              0.28327067295496094`, 0.4141554737113025, 0.9394765499044728], 
             UndirectedEdge[119, 375] -> 
             RGBColor[
              0.24767185396681415`, 0.37764920019460835`, 0.9374159177345123],
              UndirectedEdge[160, 340] -> 
             RGBColor[
              0.9116278550257833, 0.6083417789954149, 0.37001345675471364`], 
             UndirectedEdge[151, 308] -> 
             RGBColor[
              0.28846194842015016`, 0.41986670134956156`, 0.9397628533972181],
              UndirectedEdge[221, 276] -> 
             RGBColor[
              0.8437125304054167, 0.8786573253156666, 0.9848385285958808], 
             UndirectedEdge[94, 316] -> 
             RGBColor[
              0.25720173748705216`, 0.38766571200389227`, 0.9379586305027907],
              UndirectedEdge[195, 206] -> 
             RGBColor[
              0.2386283880050733, 0.3681439440799593, 0.9369009057266002], 
             UndirectedEdge[159, 192] -> 
             RGBColor[
              0.3379621693046799, 0.46714757740434754`, 0.9427556284732501], 
             UndirectedEdge[220, 350] -> 
             RGBColor[
              0.454088632793754, 0.5671299681608568, 0.9503210281880017], 
             UndirectedEdge[229, 319] -> 
             RGBColor[
              0.24423991719027513`, 0.3740420170451063, 0.9372204740121839], 
             UndirectedEdge[69, 97] -> 
             RGBColor[
              0.46525153460871527`, 0.5764515941781216, 0.9511282282884884], 
             UndirectedEdge[90, 317] -> 
             RGBColor[
              0.8482164323597703, 0.8802460937906929, 0.8881545671159801], 
             UndirectedEdge[136, 237] -> 
             RGBColor[
              0.59850057250929, 0.6849287527633994, 0.9615353039292178], 
             UndirectedEdge[69, 141] -> 
             RGBColor[
              0.42414128450553, 0.540843961799992, 0.9485087195042803], 
             UndirectedEdge[48, 143] -> 
             RGBColor[
              0.5250435709581793, 0.6245361752480152, 0.9559616263525487], 
             UndirectedEdge[51, 246] -> 
             RGBColor[
              0.408363122473439, 0.5281253445843351, 0.9472415149560449], 
             UndirectedEdge[97, 132] -> 
             RGBColor[
              0.6207534044996754, 0.7002920708010887, 0.965012812845729], 
             UndirectedEdge[94, 383] -> 
             RGBColor[
              0.2701801471577058, 0.4013068434464496, 0.9386977317336979], 
             UndirectedEdge[246, 344] -> 
             RGBColor[
              0.3822157528613575, 0.505477807231359, 0.9455754276855741], 
             UndirectedEdge[155, 354] -> 
             RGBColor[
              0.29215952785429067`, 0.42440856613178546`, 0.9399494249487885],
              UndirectedEdge[107, 307] -> 
             RGBColor[
              0.9122288272245584, 0.6453071063540661, 0.539731773350462], 
             UndirectedEdge[310, 363] -> 
             RGBColor[
              0.5225453221257725, 0.38890738011125736`, 0.5703491605175277], 
             UndirectedEdge[99, 281] -> 
             RGBColor[
              0.8050608246814849, 0.8476642232367373, 0.943040239252503], 
             UndirectedEdge[123, 187] -> 
             RGBColor[
              0.9091149872090246, 0.929372315984517, 0.9566852381845512], 
             UndirectedEdge[23, 227] -> 
             RGBColor[
              0.22416996966139735`, 0.3529472296840859, 0.936077520191241], 
             UndirectedEdge[28, 211] -> 
             RGBColor[
              0.2754831553698227, 0.4068806413075249, 0.9389997302062802], 
             UndirectedEdge[327, 356] -> 
             RGBColor[
              0.4184852693414719, 0.5351260969165677, 0.9483745901685348], 
             UndirectedEdge[140, 219] -> 
             RGBColor[
              0.5595564197473485, 0.6526927736905361, 0.9588251269991186], 
             UndirectedEdge[104, 144] -> 
             RGBColor[
              0.9061560966553733, 0.6582187386740248, 0.24296492852905843`], 
             UndirectedEdge[49, 328] -> 
             RGBColor[
              0.2825867919008145, 0.4142831089055032, 0.9394066116653366], 
             UndirectedEdge[112, 271] -> 
             RGBColor[
              0.3178545270497625, 0.4495503070285146, 0.9414810160978866], 
             UndirectedEdge[106, 197] -> 
             RGBColor[
              0.9686231253627324, 0.9753622711647122, 0.9040752003743098], 
             UndirectedEdge[106, 204] -> 
             RGBColor[
              0.563710908416439, 0.6332510496213667, 0.9527850098927306], 
             UndirectedEdge[50, 158] -> 
             RGBColor[
              0.47863176654490647`, 0.5876138560533424, 0.9520987924297972], 
             UndirectedEdge[259, 299] -> 
             RGBColor[
              0.21257469635649348`, 0.34075986225784227`, 0.9354171865301963],
              UndirectedEdge[79, 286] -> 
             RGBColor[
              0.658527918518543, 0.7323765551714567, 0.9671395072605043], 
             UndirectedEdge[240, 388] -> 
             RGBColor[
              0.23128580999340365`, 0.36042642904335986`, 0.9364827567712063],
              UndirectedEdge[118, 299] -> 
             RGBColor[
              0.21009516231391617`, 0.33815371476755507`, 0.9352759807346135],
              UndirectedEdge[138, 257] -> 
             RGBColor[
              0.8209750230584517, 0.16222879530677942`, 0.1677190118096608], 
             UndirectedEdge[171, 244] -> 
             RGBColor[
              0.266624380952421, 0.39756950771609656`, 0.9384952361085915], 
             UndirectedEdge[161, 337] -> 
             RGBColor[
              0.35808998923330093`, 0.48236207273681253`, 0.9441194115332278],
              UndirectedEdge[119, 355] -> 
             RGBColor[
              0.2357097669248304, 0.3650762882733595, 0.9367346945737933], 
             UndirectedEdge[248, 292] -> 
             RGBColor[
              0.21361328404066288`, 0.34185148376416674`, 0.935476332562357], 
             UndirectedEdge[68, 386] -> 
             RGBColor[
              0.30804388160308127`, 0.43827326520037213`, 0.9409576635272863],
              UndirectedEdge[126, 299] -> 
             RGBColor[
              0.21308522513571704`, 0.34129646037420036`, 0.9354462603889135],
              UndirectedEdge[128, 383] -> 
             RGBColor[
              0.30322473955246876`, 0.43442384756391816`, 0.9406387038956638],
              UndirectedEdge[229, 248] -> 
             RGBColor[
              0.2315520252069328, 0.36070623811179847`, 0.9364979173337866], 
             UndirectedEdge[395, 396] -> 
             RGBColor[
              0.2756838068644868, 0.4070915387504564, 0.9390111570120642], 
             UndirectedEdge[81, 292] -> 
             RGBColor[
              0.21536706305033604`, 0.3436948166993449, 0.9355762076824743], 
             UndirectedEdge[34, 253] -> 
             RGBColor[
              0.3270023945629662, 0.4576547713773704, 0.9420572813180563], 
             UndirectedEdge[130, 322] -> 
             RGBColor[
              0.45941085843753277`, 0.5708442844274215, 0.95090759277739], 
             UndirectedEdge[74, 311] -> 
             RGBColor[
              0.6720237576353845, 0.741863264667372, 0.9692227298983209], 
             UndirectedEdge[232, 235] -> 
             RGBColor[
              0.6328251607154107, 0.7112978291642651, 0.965261084970727], 
             UndirectedEdge[207, 221] -> 
             RGBColor[
              0.9308573670898133, 0.869892342221664, 0.6314368519575342], 
             UndirectedEdge[140, 216] -> 
             RGBColor[
              0.6655132848379224, 0.7386233032944675, 0.96729580272355], 
             UndirectedEdge[31, 173] -> 
             RGBColor[
              0.20479251217739197`, 0.3325802932666311, 0.9349740026539064], 
             UndirectedEdge[37, 243] -> 
             RGBColor[
              0.2690857390615694, 0.4001565511479292, 0.9386354068116546], 
             UndirectedEdge[1, 35] -> 
             RGBColor[
              0.32051204203418227`, 0.44947164236999554`, 0.9417375112912428],
              UndirectedEdge[60, 210] -> 
             RGBColor[
              0.3287260262404138, 0.45833201350769803`, 0.942196975681387], 
             UndirectedEdge[35, 92] -> 
             RGBColor[
              0.28435244626912165`, 0.4162028283882106, 0.9395048232020553], 
             UndirectedEdge[52, 291] -> 
             RGBColor[
              0.5415685327056081, 0.6360692009186899, 0.9581205580022027], 
             UndirectedEdge[77, 400] -> 
             RGBColor[
              0.6094880057982189, 0.6893301781287484, 0.9648167092401694], 
             UndirectedEdge[77, 389] -> 
             RGBColor[
              0.5042266153181847, 0.5861702959978048, 0.9585484769989704], 
             UndirectedEdge[96, 361] -> 
             RGBColor[
              0.32126900465498376`, 0.45067004741952366`, 0.9417658711017902],
              UndirectedEdge[150, 374] -> 
             RGBColor[
              0.2733522518909328, 0.4046409266441276, 0.9388783784055468], 
             UndirectedEdge[80, 154] -> 
             RGBColor[
              0.38228721374237734`, 0.5055397030547701, 0.9455799811097223], 
             UndirectedEdge[200, 383] -> 
             RGBColor[
              0.27544799036410295`, 0.4068436806569232, 0.9389977276112265], 
             UndirectedEdge[144, 391] -> 
             RGBColor[
              0.8494144480971886, 0.3493178905748092, 0.19371883223399736`], 
             UndirectedEdge[196, 290] -> 
             RGBColor[
              0.3515289166579535, 0.47789785496789633`, 0.943656724915119], 
             UndirectedEdge[159, 228] -> 
             RGBColor[
              0.3496458859290326, 0.47726742550368945`, 0.9435001045650488], 
             UndirectedEdge[27, 377] -> 
             RGBColor[
              0.3561480526956704, 0.48185180602152367`, 0.9439527698723194], 
             UndirectedEdge[24, 233] -> 
             RGBColor[
              0.8598056285506199, 0.3918893823292492, 0.202208876655091], 
             UndirectedEdge[24, 109] -> 
             RGBColor[
              0.9481247371168586, 0.8202041529201762, 0.49378352937662584`], 
             UndirectedEdge[189, 255] -> 
             RGBColor[
              0.28051086067435194`, 0.4121650783575129, 0.9392860505855498], 
             UndirectedEdge[262, 298] -> 
             RGBColor[
              0.8810364966451805, 0.9079026895445534, 0.9858832537094278], 
             UndirectedEdge[249, 397] -> 
             RGBColor[
              0.25945941523748706`, 0.39003867446463636`, 0.938087201910743], 
             UndirectedEdge[128, 324] -> 
             RGBColor[
              0.3030854036809988, 0.43427739672859866`, 0.9406307689239126], 
             UndirectedEdge[7, 228] -> 
             RGBColor[
              0.37863108577837257`, 0.5023729487746839, 0.9453470158688431], 
             UndirectedEdge[115, 258] -> 
             RGBColor[
              0.24576968053509757`, 0.37564989531311277`, 0.9373075917715895],
              UndirectedEdge[375, 383] -> 
             RGBColor[
              0.26754083334268397`, 0.3985327572847006, 0.9385474267164473], 
             UndirectedEdge[257, 338] -> 
             RGBColor[
              0.9084477718580719, 0.5824829620653897, 0.3944924501077937], 
             UndirectedEdge[5, 321] -> 
             RGBColor[
              0.8296147450427847, 0.8669940565457998, 0.9836058756059307], 
             UndirectedEdge[65, 239] -> 
             RGBColor[
              0.4199235526672635, 0.5364545776271384, 0.9484433827426128], 
             UndirectedEdge[56, 71] -> 
             RGBColor[
              0.6610275221983658, 0.7325352305400676, 0.968761778959447], 
             UndirectedEdge[276, 322] -> 
             RGBColor[
              0.6369911357289768, 0.7142897496435541, 0.9658558315605028], 
             UndirectedEdge[239, 326] -> 
             RGBColor[
              0.3319525774457105, 0.4619423709869775, 0.94237270259407], 
             UndirectedEdge[379, 393] -> 
             RGBColor[
              0.22188867958802838`, 0.35054944917483033`, 0.9359476040964289],
              UndirectedEdge[131, 262] -> 
             RGBColor[
              0.9305545199558635, 0.8420358975584873, 0.6226092420681639], 
             UndirectedEdge[201, 210] -> 
             RGBColor[
              0.2881749983278178, 0.42022057296569904`, 0.9397225118868391], 
             UndirectedEdge[301, 372] -> 
             RGBColor[
              0.25414770566980416`, 0.3844557309271635, 0.9377847079088335], 
             UndirectedEdge[291, 398] -> 
             RGBColor[
              0.8179584912880846, 0.8585839639299231, 0.9789023010866215], 
             UndirectedEdge[28, 49] -> 
             RGBColor[
              0.27201275594263963`, 0.40323303147352313`, 0.938802096092898], 
             UndirectedEdge[6, 160] -> 
             RGBColor[
              0.9114125623801264, 0.6078812897957802, 0.3465801809071596], 
             UndirectedEdge[375, 379] -> 
             RGBColor[
              0.23790135046863936`, 0.36737978153232503`, 0.9368595020144559],
              UndirectedEdge[45, 112] -> 
             RGBColor[
              0.31221013250570034`, 0.4436176904874213, 0.9411595761787357], 
             UndirectedEdge[324, 390] -> 
             RGBColor[
              0.27312846435714266`, 0.404405711757165, 0.9388656340365613], 
             UndirectedEdge[169, 227] -> 
             RGBColor[
              0.22781024002051087`, 0.3567733846379857, 0.936284828202895], 
             UndirectedEdge[44, 380] -> 
             RGBColor[
              0.2817236040630746, 0.41343974855143245`, 0.9393551145274445], 
             UndirectedEdge[288, 360] -> 
             RGBColor[
              0.2777088570611381, 0.4090678365808599, 0.9391320518865], 
             UndirectedEdge[87, 134] -> 
             RGBColor[
              0.26223279186396886`, 0.39295366914130303`, 0.9382451416067781],
              UndirectedEdge[85, 258] -> 
             RGBColor[
              0.24712036386052527`, 0.3770695491264064, 0.9373845111888157], 
             UndirectedEdge[26, 77] -> 
             RGBColor[
              0.6422389788407158, 0.7176486903810251, 0.9669170377654001], 
             UndirectedEdge[90, 333] -> 
             RGBColor[
              0.4506831285542931, 0.5464884699982167, 0.9528800174609131], 
             UndirectedEdge[45, 91] -> 
             RGBColor[
              0.27906015322156846`, 0.41064029284447245`, 0.9392034349422431],
              UndirectedEdge[103, 133] -> 
             RGBColor[
              0.32091218999488846`, 0.4513176188145481, 0.9417081084114585], 
             UndirectedEdge[143, 342] -> 
             RGBColor[
              0.6140012232637606, 0.6975128793422373, 0.9627555719373643], 
             UndirectedEdge[75, 164] -> 
             RGBColor[
              0.2433583151299939, 0.3731153973829517, 0.9371702680790643], 
             UndirectedEdge[44, 211] -> 
             RGBColor[
              0.28031687034096775`, 0.4119611822174286, 0.9392750031230466], 
             UndirectedEdge[82, 171] -> 
             RGBColor[
              0.32621487078886763`, 0.45368735101725755`, 0.9421273921767691],
              UndirectedEdge[17, 122] -> 
             RGBColor[
              0.490802095307585, 0.5972979545178956, 0.9531111298361363], 
             UndirectedEdge[150, 186] -> 
             RGBColor[
              0.2595342246109202, 0.3901173038593028, 0.9380914621938894], 
             UndirectedEdge[180, 394] -> 
             RGBColor[
              0.36256898672280274`, 0.4884607658773212, 0.9443235531201786], 
             UndirectedEdge[156, 202] -> 
             RGBColor[
              0.5211495825009953, 0.37342113688887774`, 0.567742844041897], 
             UndirectedEdge[86, 178] -> 
             RGBColor[
              0.27226239938534696`, 0.40349542256011695`, 0.9388163129176459],
              UndirectedEdge[102, 250] -> 
             RGBColor[
              0.9037621261807391, 0.5693653564012491, 0.505440590565607], 
             UndirectedEdge[7, 222] -> 
             RGBColor[
              0.4971659473495666, 0.600925351032558, 0.9540373638977802], 
             UndirectedEdge[97, 220] -> 
             RGBColor[
              0.4588594812307164, 0.571262237287139, 0.9506250224317093], 
             UndirectedEdge[230, 289] -> 
             RGBColor[
              0.9333052704870481, 0.7676068761755623, 0.28495592618105414`], 
             UndirectedEdge[14, 289] -> 
             RGBColor[
              0.9460551929840001, 0.8094710811761514, 0.43178805845315205`], 
             UndirectedEdge[77, 370] -> 
             RGBColor[
              0.8302908639224114, 0.8675154135193626, 0.9836750778819656], 
             UndirectedEdge[151, 270] -> 
             RGBColor[
              0.28271133263489734`, 0.4138224395491612, 0.9394353643355215], 
             UndirectedEdge[173, 214] -> 
             RGBColor[
              0.6050703523847987, 0.6713378352539525, 0.9242773858520503], 
             UndirectedEdge[144, 317] -> 
             RGBColor[
              0.9345325845565998, 0.7656448596324403, 0.5126377323294256], 
             UndirectedEdge[31, 175] -> 
             RGBColor[
              0.18107477738655686`, 0.3076514502102228, 0.9336233127448126], 
             UndirectedEdge[163, 240] -> 
             RGBColor[
              0.2420898799764604, 0.3717821916131542, 0.9370980325735522], 
             UndirectedEdge[329, 371] -> 
             RGBColor[
              0.25359221551815353`, 0.38387187555766883`, 0.9377530735664711],
              UndirectedEdge[72, 375] -> 
             RGBColor[
              0.24128592482540645`, 0.37093718377569584`, 0.9370522485170447],
              UndirectedEdge[32, 238] -> 
             RGBColor[
              0.22275425852448527`, 0.3514592275179208, 0.9359968975363508], 
             UndirectedEdge[11, 14] -> 
             RGBColor[
              0.9589098698169762, 0.8623003371232989, 0.4422276945427869], 
             UndirectedEdge[79, 237] -> 
             RGBColor[
              0.5846124943759591, 0.6736537852839712, 0.9604419835448554], 
             UndirectedEdge[69, 74] -> 
             RGBColor[
              0.6564460490256175, 0.7292165790501876, 0.9679963956135333], 
             UndirectedEdge[16, 203] -> 
             RGBColor[
              0.2666290431845753, 0.3975744080176934, 0.9384955016158156], 
             UndirectedEdge[315, 319] -> 
             RGBColor[
              0.24242894961997336`, 0.37213857530674344`, 0.9371173420881417],
              UndirectedEdge[40, 80] -> 
             RGBColor[
              0.3368642646638673, 0.46619662758676733`, 0.9426856709603764], 
             UndirectedEdge[18, 198] -> 
             RGBColor[
              0.8858480974802114, 0.9115700695530261, 0.9804738418540726], 
             UndirectedEdge[300, 307] -> 
             RGBColor[
              0.9376183763421341, 0.7907736248179609, 0.5620991500919681], 
             UndirectedEdge[191, 198] -> 
             RGBColor[
              0.7526714957518834, 0.806764542665624, 0.9759689648481673], 
             UndirectedEdge[289, 391] -> 
             RGBColor[
              0.8590720492168273, 0.39317080166904056`, 0.2017773713376896], 
             UndirectedEdge[132, 357] -> 
             RGBColor[
              0.7374562321167385, 0.7948256804953293, 0.9744664033632358], 
             UndirectedEdge[157, 187] -> 
             RGBColor[
              0.656588840938115, 0.7291931341002164, 0.9681680488654731], 
             UndirectedEdge[38, 250] -> 
             RGBColor[
              0.9770092142863354, 0.9428337657309378, 0.5831873792076157], 
             UndirectedEdge[140, 191] -> 
             RGBColor[
              0.6753891788981803, 0.7463384267939157, 0.9682801395479993], 
             UndirectedEdge[204, 261] -> 
             RGBColor[
              0.17918768478614402`, 0.3056679962386074, 0.9335158456129223], 
             UndirectedEdge[337, 354] -> 
             RGBColor[
              0.28225838404285286`, 0.4140018362171884, 0.9393855694561568], 
             UndirectedEdge[300, 314] -> 
             RGBColor[
              0.9079043794586273, 0.7685321222787813, 0.6113544605961532], 
             UndirectedEdge[292, 378] -> 
             RGBColor[
              0.20977255736756456`, 0.3378146365146045, 0.93525760886017], 
             UndirectedEdge[153, 361] -> 
             RGBColor[
              0.3365286408445437, 0.46590592710341294`, 0.9426642853073897], 
             UndirectedEdge[240, 334] -> 
             RGBColor[
              0.2503027734840032, 0.3804144634171059, 0.9375657447089196], 
             UndirectedEdge[52, 260] -> 
             RGBColor[
              0.5977997596730911, 0.6799974627988412, 0.9637251611956289], 
             UndirectedEdge[128, 177] -> 
             RGBColor[
              0.32406082685861914`, 0.45510693327935664`, 0.9418698472250615],
              UndirectedEdge[16, 85] -> 
             RGBColor[
              0.2415839884274967, 0.3712504675198166, 0.9370692227982382], 
             UndirectedEdge[179, 303] -> 
             RGBColor[
              0.27962744891017854`, 0.4112365565818258, 0.9392357415924706], 
             UndirectedEdge[48, 320] -> 
             RGBColor[
              0.5676684575710711, 0.6581064280542859, 0.9600245413086331], 
             UndirectedEdge[136, 320] -> 
             RGBColor[
              0.6642380668783059, 0.7372628617572051, 0.9674177280321361], 
             UndirectedEdge[96, 192] -> 
             RGBColor[
              0.3157006162298024, 0.44584698924097155`, 0.9414110583152703], 
             UndirectedEdge[140, 357] -> 
             RGBColor[
              0.6738075491078213, 0.7451028455808557, 0.9681224974716671], 
             UndirectedEdge[202, 306] -> 
             RGBColor[
              0.913357870811167, 0.6728952265487068, 0.2705007142320376], 
             UndirectedEdge[114, 258] -> 
             RGBColor[
              0.29090557114945215`, 0.42122924819894025`, 0.9399461663762204],
              UndirectedEdge[87, 236] -> 
             RGBColor[
              0.2703304585010046, 0.4014648301985463, 0.938706291742333], 
             UndirectedEdge[116, 362] -> 
             RGBColor[
              0.41044018393094006`, 0.5299243908226783, 0.9473738634754435], 
             UndirectedEdge[36, 64] -> 
             RGBColor[
              0.45931878415001925`, 0.5704587671539738, 0.9509862102607236], 
             UndirectedEdge[245, 304] -> 
             RGBColor[
              0.22449864114749254`, 0.35329268425494775`, 0.9360962375461481],
              UndirectedEdge[187, 218] -> 
             RGBColor[
              0.8769988069965478, 0.9047590594733392, 0.9881301231890498], 
             UndirectedEdge[26, 370] -> 
             RGBColor[
              0.6431647387570222, 0.7183868662092043, 0.9670053375726531], 
             UndirectedEdge[91, 141] -> 
             RGBColor[
              0.3113425799408942, 0.43982647528346147`, 0.9412155979078848], 
             UndirectedEdge[55, 385] -> 
             RGBColor[
              0.4894768493024928, 0.5950665939158499, 0.9533260603680459], 
             UndirectedEdge[179, 231] -> 
             RGBColor[
              0.28916364068982703`, 0.4212596987717169, 0.9397788136067902], 
             UndirectedEdge[94, 177] -> 
             RGBColor[
              0.29101623446385616`, 0.4219899291618881, 0.9399288750630955], 
             UndirectedEdge[225, 383] -> 
             RGBColor[
              0.26867221560749177`, 0.39972191177879235`, 0.938611857262698], 
             UndirectedEdge[37, 134] -> 
             RGBColor[
              0.24206319644531432`, 0.3717541455300861, 0.9370965129859282], 
             UndirectedEdge[255, 341] -> 
             RGBColor[
              0.24102934533176992`, 0.3706675024598044, 0.9370376366944575], 
             UndirectedEdge[206, 278] -> 
             RGBColor[
              0.24198884677049953`, 0.37167599930781414`, 0.937092278881938], 
             UndirectedEdge[131, 279] -> 
             RGBColor[
              0.934057909721427, 0.776268616484077, 0.26579965018330676`], 
             UndirectedEdge[7, 203] -> 
             RGBColor[
              0.3404012849561078, 0.4676562364290735, 0.9429697763439697], 
             UndirectedEdge[101, 151] -> 
             RGBColor[
              0.2883386750076016, 0.41973713317698713`, 0.9397558331587401], 
             UndirectedEdge[200, 296] -> 
             RGBColor[
              0.2860905976760283, 0.41802973572203384`, 0.939603808353314], 
             UndirectedEdge[86, 229] -> 
             RGBColor[
              0.27371625819309475`, 0.4050235203470323, 0.9388991080259558], 
             UndirectedEdge[138, 382] -> 
             RGBColor[
              0.8590618993454652, 0.3914765169996446, 0.2017043627957868], 
             UndirectedEdge[195, 278] -> 
             RGBColor[
              0.24905516487064655`, 0.3791031476615132, 0.9374946952440605], 
             UndirectedEdge[65, 113] -> 
             RGBColor[
              0.6559239156864949, 0.7291861264524664, 0.9676704388099608], 
             UndirectedEdge[249, 270] -> 
             RGBColor[
              0.25957821450255336`, 0.3901635400245296, 0.9380939673531408], 
             UndirectedEdge[319, 388] -> 
             RGBColor[
              0.23247439130222355`, 0.3616757033593372, 0.9365504447183952], 
             UndirectedEdge[138, 256] -> 
             RGBColor[
              0.522325620948562, 0.25191357841785655`, 0.5511492082429574], 
             UndirectedEdge[246, 286] -> 
             RGBColor[
              0.5850263680482788, 0.6724463268342122, 0.9614245811742612], 
             UndirectedEdge[188, 208] -> 
             RGBColor[
              0.25008631824464794`, 0.38018695523648866`, 0.9375534179032552],
              UndirectedEdge[173, 345] -> 
             RGBColor[
              0.21415750276433887`, 0.34242349214821033`, 0.9355073250135709],
              UndirectedEdge[84, 156] -> 
             RGBColor[
              0.18244327672263497`, 0.3090898297803102, 0.9337012467574888], 
             UndirectedEdge[136, 349] -> 
             RGBColor[
              0.5319806271096528, 0.6307093057544687, 0.9563581696523957], 
             UndirectedEdge[117, 346] -> 
             RGBColor[
              0.3472745636844825, 0.4752135053615816, 0.9433490060085041], 
             UndirectedEdge[26, 197] -> 
             RGBColor[
              0.7219321437839568, 0.7790682930787789, 0.8931643392096228], 
             UndirectedEdge[328, 362] -> 
             RGBColor[
              0.35704810596381387`, 0.4836788564514203, 0.9439717674801389], 
             UndirectedEdge[187, 275] -> 
             RGBColor[
              0.9180172404014313, 0.9346976892728417, 0.8827763564020366], 
             UndirectedEdge[20, 121] -> 
             RGBColor[
              0.48042756078829996`, 0.5878320132896839, 0.9525827103922078], 
             UndirectedEdge[198, 302] -> 
             RGBColor[
              0.9068833316004294, 0.9166145009599966, 0.6941933109869335], 
             UndirectedEdge[1, 312] -> 
             RGBColor[
              0.4114701041040899, 0.5305547297160472, 0.9475118048057347], 
             UndirectedEdge[89, 292] -> 
             RGBColor[
              0.21480075229645693`, 0.3430995881908423, 0.9355439571228226], 
             UndirectedEdge[304, 315] -> 
             RGBColor[
              0.23118633013209117`, 0.360321869401733, 0.9364770915402718], 
             UndirectedEdge[21, 64] -> 
             RGBColor[
              0.3559387070583645, 0.4827179508795304, 0.9439010775628867], 
             UndirectedEdge[201, 351] -> 
             RGBColor[
              0.26108538890678307`, 0.3917476758837515, 0.9381797987057969], 
             UndirectedEdge[17, 218] -> 
             RGBColor[
              0.7227901892843811, 0.7824598484159166, 0.9739304322567687], 
             UndirectedEdge[266, 365] -> 
             RGBColor[
              0.25561932448523794`, 0.3860024956082064, 0.9378685144233075], 
             UndirectedEdge[112, 180] -> 
             RGBColor[
              0.34759559659056605`, 0.4754915679292482, 0.9433694619414015], 
             UndirectedEdge[247, 289] -> 
             RGBColor[
              0.9023804239029701, 0.648813195238765, 0.2402147401558417], 
             UndirectedEdge[15, 45] -> 
             RGBColor[
              0.29968000514429743`, 0.4323130645893829, 0.9403777050049051], 
             UndirectedEdge[57, 92] -> 
             RGBColor[
              0.2804356326225079, 0.4120860089052909, 0.9392817664592872], 
             UndirectedEdge[53, 86] -> 
             RGBColor[
              0.2948901577623302, 0.4272786312970708, 0.9401049302824465], 
             UndirectedEdge[114, 154] -> 
             RGBColor[
              0.3795179550306004, 0.5031411103456188, 0.9454035263933673], 
             UndirectedEdge[71, 237] -> 
             RGBColor[
              0.7247695222504801, 0.7843485609125668, 0.9737619050151656], 
             UndirectedEdge[241, 375] -> 
             RGBColor[
              0.2729036444443398, 0.40416941177440335`, 0.9388528308751185], 
             UndirectedEdge[100, 282] -> 
             RGBColor[
              0.5117379294109875, 0.6123392626277626, 0.9553276443786378], 
             UndirectedEdge[55, 146] -> 
             RGBColor[
              0.4694319452875655, 0.5787932378238967, 0.951748052097088], 
             UndirectedEdge[309, 319] -> 
             RGBColor[
              0.25618706106620875`, 0.38659922275138503`, 0.9379008461817029],
              UndirectedEdge[13, 302] -> 
             RGBColor[
              0.9755285816369456, 0.9706262250120263, 0.6756345411379316], 
             UndirectedEdge[110, 348] -> 
             RGBColor[
              0.25926658322907375`, 0.3898359957975386, 0.9380762204131332], 
             UndirectedEdge[217, 363] -> 
             RGBColor[
              0.8426690815936368, 0.3225184221692448, 0.1882402931746939], 
             UndirectedEdge[39, 380] -> 
             RGBColor[
              0.2692913647455158, 0.4003726767791782, 0.9386471168901593], 
             UndirectedEdge[248, 304] -> 
             RGBColor[
              0.2176531615259033, 0.3460976511441812, 0.9357063976086782], 
             UndirectedEdge[204, 400] -> 
             RGBColor[
              0.2842689537951664, 0.40863855928315673`, 0.939773820202813], 
             UndirectedEdge[69, 168] -> 
             RGBColor[
              0.5791845558214077, 0.6688214100579597, 0.9603057503889199], 
             UndirectedEdge[68, 86] -> 
             RGBColor[
              0.28863048877409425`, 0.42069932230449786`, 0.9397484513939167],
              UndirectedEdge[175, 264] -> 
             RGBColor[
              0.18448157797338877`, 0.31123221363061604`, 0.9338173249983228],
              UndirectedEdge[1, 92] -> 
             RGBColor[
              0.3238234376355826, 0.4529521291016748, 0.9419260903719718], 
             UndirectedEdge[368, 393] -> 
             RGBColor[
              0.21780075210083538`, 0.3462527781962177, 0.93571480267358], 
             UndirectedEdge[332, 361] -> 
             RGBColor[
              0.4414240641856033, 0.5547544143941453, 0.9499025740169657], 
             UndirectedEdge[80, 203] -> 
             RGBColor[
              0.31290698696191654`, 0.4438420574101029, 0.9412178639880329], 
             UndirectedEdge[20, 347] -> 
             RGBColor[
              0.3438545327447645, 0.469598113054395, 0.9432282288718172], 
             UndirectedEdge[18, 311] -> 
             RGBColor[
              0.7322903023542322, 0.7896729975900088, 0.9664706721730203], 
             UndirectedEdge[170, 282] -> 
             RGBColor[
              0.5459157043281511, 0.6419423334360943, 0.9575054219741398], 
             UndirectedEdge[198, 323] -> 
             RGBColor[
              0.828349936933913, 0.8659677710237936, 0.9834899505331167], 
             UndirectedEdge[168, 357] -> 
             RGBColor[
              0.6729202964028389, 0.7444097170243531, 0.9680340644138824], 
             UndirectedEdge[180, 326] -> 
             RGBColor[
              0.3528301288862901, 0.48002545670856134`, 0.9437030017105699], 
             UndirectedEdge[18, 340] -> 
             RGBColor[
              0.9694923470519816, 0.9738780487256253, 0.770900506424754], 
             UndirectedEdge[74, 340] -> 
             RGBColor[
              0.9092258023331339, 0.9260683158029884, 0.7736525641500547], 
             UndirectedEdge[173, 204] -> 
             RGBColor[
              0.20264730553141047`, 0.33032554506774736`, 0.9348518363089665],
              UndirectedEdge[26, 30] -> 
             RGBColor[
              0.31701994287924884`, 0.4369570883961569, 0.9418741496415883], 
             UndirectedEdge[169, 240] -> 
             RGBColor[
              0.22995248947003588`, 0.35902502463589653`, 0.9364068261398715],
              UndirectedEdge[95, 371] -> 
             RGBColor[
              0.27691206805261726`, 0.40838251913543877`, 0.9390811046696785],
              UndirectedEdge[65, 356] -> 
             RGBColor[
              0.5168552955479615, 0.6186454388483807, 0.9551078886503179], 
             UndirectedEdge[264, 310] -> 
             RGBColor[
              0.18630458251799184`, 0.3131483069921579, 0.9339211424102444], 
             UndirectedEdge[96, 114] -> 
             RGBColor[
              0.3078946845637386, 0.4390858835693603, 0.940913671252023], 
             UndirectedEdge[244, 308] -> 
             RGBColor[
              0.2605622771689302, 0.3911978522800683, 0.9381500082662007], 
             UndirectedEdge[187, 298] -> 
             RGBColor[
              0.8336819864556111, 0.8702194025777671, 0.983998526176473], 
             UndirectedEdge[58, 228] -> 
             RGBColor[
              0.3333340850867448, 0.46222040417284493`, 0.9424943639948453], 
             UndirectedEdge[36, 82] -> 
             RGBColor[
              0.4494472254875384, 0.5619085191994977, 0.950357203271827], 
             UndirectedEdge[72, 355] -> 
             RGBColor[
              0.2293238377834227, 0.358364271854447, 0.9363710253563257], 
             UndirectedEdge[22, 350] -> 
             RGBColor[
              0.36253057369193453`, 0.4869086502715662, 0.9443767178010922], 
             UndirectedEdge[58, 192] -> 
             RGBColor[
              0.32165036846239214`, 0.45210055607350297`, 0.9417498879030466],
              UndirectedEdge[3, 174] -> 
             RGBColor[
              0.5493425209245979, 0.6414387311936623, 0.9591931799908751], 
             UndirectedEdge[44, 54] -> 
             RGBColor[
              0.3749740145051137, 0.4982078184475008, 0.9451505160427869], 
             UndirectedEdge[21, 36] -> 
             RGBColor[
              0.416297218948796, 0.5331956497034136, 0.948244914168578], 
             UndirectedEdge[170, 271] -> 
             RGBColor[
              0.37587875919358854`, 0.49980798052879155`, 0.9451782688612774],
              UndirectedEdge[192, 201] -> 
             RGBColor[
              0.3104580154232146, 0.4403366833931581, 0.941112499955068], 
             UndirectedEdge[274, 395] -> 
             RGBColor[
              0.2518980358087536, 0.3820911852658918, 0.9376565925383351], 
             UndirectedEdge[208, 284] -> 
             RGBColor[
              0.23854240400840393`, 0.3680535694477596, 0.9368960090651918], 
             UndirectedEdge[237, 320] -> 
             RGBColor[
              0.644156525821959, 0.7209597620645476, 0.9658368355590718], 
             UndirectedEdge[119, 380] -> 
             RGBColor[
              0.25299451614994406`, 0.383243655625352, 0.9377190354716685], 
             UndirectedEdge[342, 398] -> 
             RGBColor[
              0.7713918010534688, 0.8216082690775031, 0.9746694433091629], 
             UndirectedEdge[90, 264] -> 
             RGBColor[
              0.44791840801160593`, 0.5435825734144455, 0.9527225707160447], 
             UndirectedEdge[212, 367] -> 
             RGBColor[
              0.21510593499852879`, 0.3434203545604207, 0.9355613368262283], 
             UndirectedEdge[92, 284] -> 
             RGBColor[
              0.26583096592771405`, 0.3967355782197115, 0.9384500522966869], 
             UndirectedEdge[267, 342] -> 
             RGBColor[
              0.5872785724074823, 0.6758182275354083, 0.9606518669736626], 
             UndirectedEdge[107, 297] -> 
             RGBColor[
              0.892928350056968, 0.6310869487653001, 0.5801992997291281], 
             UndirectedEdge[163, 245] -> 
             RGBColor[
              0.2374360489235272, 0.36689072010659024`, 0.9368330037798137], 
             UndirectedEdge[72, 200] -> 
             RGBColor[
              0.24919308184682543`, 0.37924810714791846`, 0.937502549411824], 
             UndirectedEdge[254, 286] -> 
             RGBColor[
              0.5978806349455185, 0.6831403582378857, 0.9623651309393161], 
             UndirectedEdge[269, 307] -> 
             RGBColor[
              0.9891494518709179, 0.9878632201941573, 0.6900803930330166], 
             UndirectedEdge[240, 304] -> 
             RGBColor[
              0.22915247220042573`, 0.35818415576151175`, 0.9363612663398866],
              UndirectedEdge[228, 332] -> 
             RGBColor[
              0.44753939238477464`, 0.5600512043149352, 0.9502922373222444], 
             UndirectedEdge[104, 109] -> 
             RGBColor[
              0.9639852685830836, 0.8836832833010115, 0.5065761886025747], 
             UndirectedEdge[28, 372] -> 
             RGBColor[
              0.2698833093261751, 0.4009948480649053, 0.9386808272583244], 
             UndirectedEdge[28, 362] -> 
             RGBColor[
              0.34647407000563907`, 0.4726287790194402, 0.9433672519077005], 
             UndirectedEdge[209, 227] -> 
             RGBColor[
              0.24347750032410487`, 0.3732406685787401, 0.9371770554995502], 
             UndirectedEdge[245, 371] -> 
             RGBColor[
              0.25097222698134913`, 0.38111810148861974`, 0.9376038690952258],
              UndirectedEdge[308, 397] -> 
             RGBColor[
              0.25521896402580857`, 0.3855816913810268, 0.9378457144874233], 
             UndirectedEdge[58, 87] -> 
             RGBColor[
              0.29447485481202706`, 0.42684212156457424`, 0.9400812793938123],
              UndirectedEdge[154, 332] -> 
             RGBColor[
              0.47868981834297064`, 0.5870321376139921, 0.9522771149190605], 
             UndirectedEdge[97, 180] -> 
             RGBColor[
              0.40427723483543804`, 0.5245863540749827, 0.9469811658087601], 
             UndirectedEdge[202, 300] -> 
             RGBColor[
              0.873168201892003, 0.5137197571930974, 0.21575357463755512`], 
             UndirectedEdge[25, 317] -> 
             RGBColor[
              0.9196690890458292, 0.6829063077266104, 0.4996382373528887], 
             UndirectedEdge[93, 128] -> 
             RGBColor[
              0.2857256322546389, 0.41603117628641406`, 0.9396421556226617], 
             UndirectedEdge[68, 178] -> 
             RGBColor[
              0.2603565331566741, 0.3909816022782634, 0.9381382914490737], 
             UndirectedEdge[271, 273] -> 
             RGBColor[
              0.2911126400044641, 0.42330822062509427`, 0.9398898062344726], 
             UndirectedEdge[149, 318] -> 
             RGBColor[
              0.22201805165799737`, 0.3506854274230307, 0.9359549716444248], 
             UndirectedEdge[42, 358] -> 
             RGBColor[
              0.9504012676368335, 0.9272297470138823, 0.6629122325696076], 
             UndirectedEdge[155, 170] -> 
             RGBColor[
              0.3747576276064379, 0.498629600146848, 0.9451144220759548], 
             UndirectedEdge[193, 338] -> 
             RGBColor[
              0.9083139927934867, 0.9256835176042191, 0.801309811633953], 
             UndirectedEdge[79, 109] -> 
             RGBColor[
              0.79245120355282, 0.8352543310125031, 0.854215095221335], 
             UndirectedEdge[173, 175] -> 
             RGBColor[
              0.20264987627198583`, 0.3303282470790865, 0.9348519827088393], 
             UndirectedEdge[95, 178] -> 
             RGBColor[
              0.2628834870920424, 0.39363759108246865`, 0.9382821977373995], 
             UndirectedEdge[243, 348] -> 
             RGBColor[
              0.27566358738232355`, 0.40707028679271356`, 0.9390100055424669],
              UndirectedEdge[56, 83] -> 
             RGBColor[
              0.4019083501795848, 0.5225345452496872, 0.9468302225732115], 
             UndirectedEdge[205, 207] -> 
             RGBColor[
              0.967562165289962, 0.8957834071543473, 0.4992706546503005], 
             UndirectedEdge[74, 302] -> 
             RGBColor[
              0.9059752552459537, 0.9158904255240137, 0.6941066978535942], 
             UndirectedEdge[179, 196] -> 
             RGBColor[
              0.2837836367777321, 0.41560497354815545`, 0.9394724303429989], 
             UndirectedEdge[174, 338] -> 
             RGBColor[
              0.8614468790047858, 0.8890515325777966, 0.796643588235805], 
             UndirectedEdge[159, 167] -> 
             RGBColor[
              0.30749203096032607`, 0.43842628345076595`, 0.9408993959616536],
              UndirectedEdge[251, 356] -> 
             RGBColor[
              0.6703471241239707, 0.7405191581131181, 0.9690711033483659], 
             UndirectedEdge[238, 277] -> 
             RGBColor[
              0.24351796868213066`, 0.3732832033888673, 0.9371793601126722], 
             UndirectedEdge[163, 164] -> 
             RGBColor[
              0.24375587866941067`, 0.373533261869863, 0.9371929087344915], 
             UndirectedEdge[213, 230] -> 
             RGBColor[
              0.939912673270707, 0.7956677722978341, 0.2903688589282392], 
             UndirectedEdge[246, 343] -> 
             RGBColor[
              0.5830017143905886, 0.6708646520088869, 0.9612227826191269], 
             UndirectedEdge[53, 95] -> 
             RGBColor[
              0.2855112454690256, 0.4174207998194225, 0.9395708151022], 
             UndirectedEdge[139, 184] -> 
             RGBColor[
              0.21446679583023515`, 0.34274857877078024`, 0.9355249387961155],
              UndirectedEdge[101, 308] -> 
             RGBColor[
              0.26096510566357906`, 0.39162125056874597`, 0.9381729487530396],
              UndirectedEdge[3, 52] -> 
             RGBColor[
              0.3783625716146186, 0.5021403753019544, 0.9453299063837663], 
             UndirectedEdge[136, 286] -> 
             RGBColor[
              0.6724159966518739, 0.7436515226508849, 0.9682328276448666], 
             UndirectedEdge[164, 169] -> 
             RGBColor[
              0.23161848816298614`, 0.3607760948926053, 0.9365017023008109], 
             UndirectedEdge[14, 102] -> 
             RGBColor[
              0.9068270565903578, 0.5698348658899638, 0.39664654648642544`], 
             UndirectedEdge[232, 281] -> 
             RGBColor[
              0.5787753460534887, 0.6689149253152545, 0.9599824618467317], 
             UndirectedEdge[56, 349] -> 
             RGBColor[
              0.44815708600119175`, 0.5625928756893122, 0.949777151123613], 
             UndirectedEdge[225, 324] -> 
             RGBColor[
              0.2685328797360218, 0.39957546094347285`, 0.9386039222909468], 
             UndirectedEdge[5, 272] -> 
             RGBColor[
              0.744229977263282, 0.800290827008182, 0.9750955199196911], 
             UndirectedEdge[68, 371] -> 
             RGBColor[
              0.27438511411724903`, 0.40572653033123346`, 0.9389371983813526],
              UndirectedEdge[151, 397] -> 
             RGBColor[
              0.28259253336983103`, 0.413697573989268, 0.9394285988931239], 
             UndirectedEdge[1, 356] -> 
             RGBColor[
              0.43918071918933627`, 0.5530514553912338, 0.949693285932573], 
             UndirectedEdge[96, 115] -> 
             RGBColor[
              0.262758793949384, 0.3935065306835328, 0.9382750966473921], 
             UndirectedEdge[328, 347] -> 
             RGBColor[
              0.29474363512034735`, 0.42706072191761096`, 0.940098925902251], 
             UndirectedEdge[80, 159] -> 
             RGBColor[
              0.3329254963503931, 0.4627850644418876, 0.9424346961263579], 
             UndirectedEdge[50, 121] -> 
             RGBColor[
              0.5036718866822538, 0.607942553625398, 0.9540700424119916], 
             UndirectedEdge[108, 342] -> 
             RGBColor[
              0.48546363914421214`, 0.5908319937486516, 0.9532799343430639], 
             UndirectedEdge[178, 315] -> 
             RGBColor[
              0.24363133500537287`, 0.37340235858243487`, 0.9371858161570703],
              UndirectedEdge[146, 228] -> 
             RGBColor[
              0.45159420731101624`, 0.5633430857393887, 0.9506114472065146], 
             UndirectedEdge[63, 152] -> 
             RGBColor[
              0.5710886094431091, 0.5911007265104762, 0.6136429928057057], 
             UndirectedEdge[43, 137] -> 
             RGBColor[
              0.22449567090087896`, 0.35328956233743236`, 0.9360960683949977],
              UndirectedEdge[97, 141] -> 
             RGBColor[
              0.401174197469898, 0.5218986590721447, 0.9467834430117361], 
             UndirectedEdge[25, 207] -> 
             RGBColor[
              0.8942834665962583, 0.5873379716371798, 0.2323719540995589], 
             UndirectedEdge[214, 310] -> 
             RGBColor[
              0.5831756221385668, 0.6483250855590861, 0.9230305133548782], 
             UndirectedEdge[37, 87] -> 
             RGBColor[
              0.2699691213947309, 0.4010850419897568, 0.9386857141286811], 
             UndirectedEdge[146, 262] -> 
             RGBColor[
              0.736987048840004, 0.7937027834714817, 0.9726540973253948], 
             UndirectedEdge[322, 364] -> 
             RGBColor[
              0.428972946302528, 0.5444804947900268, 0.9489681159313363], 
             UndirectedEdge[219, 311] -> 
             RGBColor[
              0.48328094147507245`, 0.5912218175992272, 0.9525107826182344], 
             UndirectedEdge[5, 260] -> 
             RGBColor[
              0.8251985302055844, 0.863544075950503, 0.9831657085828327], 
             UndirectedEdge[204, 389] -> 
             RGBColor[
              0.17900756331513207`, 0.305478677152213, 0.9335055879616141], 
             UndirectedEdge[275, 279] -> 
             RGBColor[
              0.9688751403565641, 0.9066136951652177, 0.5278514920501343], 
             UndirectedEdge[78, 289] -> 
             RGBColor[
              0.8697986288874946, 0.4756199934349731, 0.21204915614425965`], 
             UndirectedEdge[163, 329] -> 
             RGBColor[
              0.2400560374603316, 0.3696444941756393, 0.936982208251059], 
             UndirectedEdge[47, 181] -> 
             RGBColor[
              0.5006021052009016, 0.6049229030605833, 0.9539741177513421], 
             UndirectedEdge[267, 291] -> 
             RGBColor[
              0.6338452626420983, 0.7127939223878283, 0.964884724751121], 
             UndirectedEdge[28, 301] -> 
             RGBColor[
              0.27255350960952185`, 0.40380139786317903`, 0.9388328912142536],
              UndirectedEdge[174, 193] -> 
             RGBColor[
              0.7754724977883137, 0.8245433157037161, 0.9782504569369469], 
             UndirectedEdge[60, 263] -> 
             RGBColor[
              0.3098059764171655, 0.4384458415430197, 0.9411195068336586], 
             UndirectedEdge[122, 385] -> 
             RGBColor[
              0.510754315643456, 0.6134960658238386, 0.9546818417083673], 
             UndirectedEdge[282, 350] -> 
             RGBColor[
              0.5398022619922347, 0.6366471769552697, 0.9571158788344], 
             UndirectedEdge[142, 306] -> 
             RGBColor[
              0.8959800446329425, 0.5393216395308846, 0.25385968825832217`], 
             UndirectedEdge[6, 289] -> 
             RGBColor[
              0.9455504255792939, 0.808391434737298, 0.3768472415142159], 
             UndirectedEdge[3, 117] -> 
             RGBColor[
              0.35979838664313185`, 0.4860610113427193, 0.9441470129330474], 
             UndirectedEdge[6, 132] -> 
             RGBColor[
              0.896284952197167, 0.9156286210821021, 0.7489609820272407], 
             UndirectedEdge[22, 394] -> 
             RGBColor[
              0.32559317401626164`, 0.45491533120018696`, 0.9420230993562184],
              UndirectedEdge[11, 391] -> 
             RGBColor[
              0.8719267260498035, 0.4460000576161881, 0.2122170074273244], 
             UndirectedEdge[34, 249] -> 
             RGBColor[
              0.2909291460215572, 0.4227877812822719, 0.9398913506685179], 
             UndirectedEdge[269, 306] -> 
             RGBColor[
              0.9817175223804617, 0.9496479498761543, 0.4126513364277588], 
             UndirectedEdge[69, 394] -> 
             RGBColor[
              0.42354328649608, 0.5403260059804602, 0.948470615599907], 
             UndirectedEdge[361, 369] -> 
             RGBColor[
              0.30654023496768024`, 0.43518917662023243`, 0.9409270894573605],
              UndirectedEdge[85, 184] -> 
             RGBColor[
              0.22953519250719354`, 0.35858641906979366`, 0.9363830616951732],
              UndirectedEdge[73, 96] -> 
             RGBColor[
              0.26501373249139615`, 0.3958766140625488, 0.9384035120614771], 
             UndirectedEdge[71, 382] -> 
             RGBColor[
              0.8849504676641144, 0.7666705508963009, 0.612411028914603], 
             UndirectedEdge[122, 165] -> 
             RGBColor[
              0.48941818004964077`, 0.5961744297668246, 0.9530021829575823], 
             UndirectedEdge[321, 331] -> 
             RGBColor[
              0.634939466831133, 0.7117908877119044, 0.9662504402131629], 
             UndirectedEdge[296, 374] -> 
             RGBColor[
              0.2888126336637139, 0.4208907681321412, 0.9397588242759214], 
             UndirectedEdge[66, 297] -> 
             RGBColor[
              0.9597109537164616, 0.9397882388587341, 0.661988741969209], 
             UndirectedEdge[75, 145] -> 
             RGBColor[
              0.24110109065239455`, 0.37074291134069687`, 0.9370417224843294],
              UndirectedEdge[105, 239] -> 
             RGBColor[
              0.37092951443948974`, 0.4957022347731742, 0.9448562785533615], 
             UndirectedEdge[92, 354] -> 
             RGBColor[
              0.2837186388686095, 0.41553665662456213`, 0.9394687288082302], 
             UndirectedEdge[188, 369] -> 
             RGBColor[
              0.26226993371413826`, 0.39299270758076044`, 0.9382472567801988],
              UndirectedEdge[170, 251] -> 
             RGBColor[
              0.6336427393204518, 0.7104942073432939, 0.966244231440377], 
             UndirectedEdge[53, 68] -> 
             RGBColor[
              0.28298429153365734`, 0.4147648110152172, 0.9394269088138741], 
             UndirectedEdge[274, 318] -> 
             RGBColor[
              0.2272727207343431, 0.3562084177875322, 0.9362542172747363], 
             UndirectedEdge[179, 359] -> 
             RGBColor[
              0.2576056390091489, 0.3880902381124516, 0.9379816320969553], 
             UndirectedEdge[20, 328] -> 
             RGBColor[
              0.3585480828066595, 0.484978061001665, 0.9440673446781876], 
             UndirectedEdge[307, 352] -> 
             RGBColor[
              0.9896970551583855, 0.989034488254865, 0.7496836314580985], 
             UndirectedEdge[6, 216] -> 
             RGBColor[
              0.8262245586177389, 0.8608969091391403, 0.7419780167468455], 
             UndirectedEdge[297, 385] -> 
             RGBColor[
              0.76103003285282, 0.8129579010796052, 0.9674643990261943], 
             UndirectedEdge[40, 348] -> 
             RGBColor[
              0.3011336768698887, 0.43101491807386594`, 0.9405639649079968], 
             UndirectedEdge[229, 329] -> 
             RGBColor[
              0.2410174933653264, 0.37065504529161414`, 0.937036961742502], 
             UndirectedEdge[6, 213] -> 
             RGBColor[
              0.9521578283629528, 0.8364523308595698, 0.38226017426140096`], 
             UndirectedEdge[189, 374] -> 
             RGBColor[
              0.2883252349784382, 0.42037848121105487`, 0.9397310676418367], 
             UndirectedEdge[97, 140] -> 
             RGBColor[
              0.5571047214907582, 0.6505692358866151, 0.9586689069541604], 
             UndirectedEdge[34, 386] -> 
             RGBColor[
              0.32582607560218535`, 0.4566359030170521, 0.9419823273140535], 
             UndirectedEdge[162, 313] -> 
             RGBColor[
              0.26444617460999714`, 0.3952800747439503, 0.938371190479758], 
             UndirectedEdge[258, 392] -> 
             RGBColor[
              0.25044123686096187`, 0.3805599972053746, 0.9375736299933992], 
             UndirectedEdge[45, 273] -> 
             RGBColor[
              0.2854682454604019, 0.41737560408400093`, 0.9395683663153217], 
             UndirectedEdge[226, 393] -> 
             RGBColor[
              0.2307270128999809, 0.3598390978683905, 0.9364509341034022], 
             UndirectedEdge[88, 168] -> 
             RGBColor[
              0.8302321284771527, 0.8662542155842119, 0.8889737374567761], 
             UndirectedEdge[188, 327] -> 
             RGBColor[
              0.2928390260811543, 0.4242124195155595, 0.9400214534598996], 
             UndirectedEdge[59, 349] -> 
             RGBColor[
              0.38969866664907243`, 0.5119591310520951, 0.9460522323352465], 
             UndirectedEdge[260, 398] -> 
             RGBColor[
              0.8741897182555676, 0.9025122258100744, 0.9845069042800476], 
             UndirectedEdge[248, 353] -> 
             RGBColor[
              0.21329376874399575`, 0.34151565292892977`, 0.9354581366388923],
              UndirectedEdge[30, 389] -> 
             RGBColor[
              0.17900757935671766`, 0.3054786940129366, 0.9335055888751587], 
             UndirectedEdge[216, 311] -> 
             RGBColor[
              0.5892378065656463, 0.6771523472031584, 0.9609814583426657], 
             UndirectedEdge[66, 307] -> 
             RGBColor[
              0.9790114308840521, 0.9540083964475, 0.6215212155905427], 
             UndirectedEdge[94, 225] -> 
             RGBColor[
              0.2586160366315361, 0.3891522300764899, 0.9380391727468009], 
             UndirectedEdge[177, 324] -> 
             RGBColor[
              0.3009330775683418, 0.4324131600288711, 0.9404936246072413], 
             UndirectedEdge[79, 320] -> 
             RGBColor[
              0.6503499887449748, 0.725987894277777, 0.9663244076477739], 
             UndirectedEdge[133, 234] -> 
             RGBColor[
              0.31799880832538563`, 0.4487941940432452, 0.9415224703076799], 
             UndirectedEdge[35, 195] -> 
             RGBColor[
              0.2633678783864708, 0.39414671704509485`, 0.9383097831050244], 
             UndirectedEdge[34, 86] -> 
             RGBColor[
              0.30641268277319833`, 0.4390619601211778, 0.940773115180684], 
             UndirectedEdge[98, 131] -> 
             RGBColor[
              0.9500181408117219, 0.8331560489585412, 0.3119185917864623], 
             UndirectedEdge[173, 261] -> 
             RGBColor[
              0.2029079903175545, 0.3305995413063548, 0.9348666819218888], 
             UndirectedEdge[103, 331] -> 
             RGBColor[
              0.39832931347278433`, 0.519434563541872, 0.9466021695190721], 
             UndirectedEdge[135, 322] -> 
             RGBColor[
              0.5058470879872912, 0.6097084800365293, 0.954241282226749], 
             UndirectedEdge[50, 181] -> 
             RGBColor[
              0.5107299622168331, 0.6136726173070488, 0.9546256799726562], 
             UndirectedEdge[35, 153] -> 
             RGBColor[
              0.2992359056961653, 0.4310433224437109, 0.940381814697533], 
             UndirectedEdge[121, 362] -> 
             RGBColor[
              0.4789275839454543, 0.5865328087394392, 0.9524871331941591], 
             UndirectedEdge[84, 152] -> 
             RGBColor[
              0.18127159018880934`, 0.30785831294404253`, 0.9336345209427424],
              UndirectedEdge[295, 345] -> 
             RGBColor[
              0.22216737223106828`, 0.3508423728127994, 0.9359634752301611], 
             UndirectedEdge[22, 266] -> 
             RGBColor[
              0.27365816407618504`, 0.40496245974678047`, 0.9388957996519403],
              UndirectedEdge[271, 335] -> 
             RGBColor[
              0.2936530311811995, 0.4259783328219468, 0.9400344777538158], 
             UndirectedEdge[175, 261] -> 
             RGBColor[
              0.1791902555267194, 0.3056706982499465, 0.9335159920127951], 
             UndirectedEdge[59, 254] -> 
             RGBColor[
              0.401764791398701, 0.521970513340684, 0.9469425623795822], 
             UndirectedEdge[53, 270] -> 
             RGBColor[
              0.26941555401375766`, 0.4005032075741548, 0.9386541892852642], 
             UndirectedEdge[214, 300] -> 
             RGBColor[
              0.9368849358196452, 0.7904007327583793, 0.5711375264891978], 
             UndirectedEdge[3, 386] -> 
             RGBColor[
              0.35472139925516205`, 0.48166358004406556`, 0.9438235117860897],
              UndirectedEdge[299, 336] -> 
             RGBColor[
              0.2125676316732109, 0.34075243682778544`, 0.9354167842069347], 
             UndirectedEdge[110, 351] -> 
             RGBColor[
              0.25066121746090764`, 0.3807912107634932, 0.9375861575631339], 
             UndirectedEdge[172, 328] -> 
             RGBColor[
              0.3054309232922502, 0.438293739399488, 0.9407075511532149], 
             UndirectedEdge[185, 302] -> 
             RGBColor[
              0.905483758897311, 0.5759228028237954, 0.28769672462851575`], 
             UndirectedEdge[370, 391] -> 
             RGBColor[
              0.8258037070409253, 0.5129958576116641, 0.5754614637475668], 
             UndirectedEdge[50, 364] -> 
             RGBColor[
              0.4018386991300539, 0.5224516905515073, 0.9468320085978967], 
             UndirectedEdge[73, 195] -> 
             RGBColor[
              0.2444053413712617, 0.37421588834782205`, 0.937229894674568], 
             UndirectedEdge[80, 332] -> 
             RGBColor[
              0.4308190028061351, 0.5455688432531333, 0.9492268288835535], 
             UndirectedEdge[5, 267] -> 
             RGBColor[
              0.7063209858486378, 0.7695859535146778, 0.9720624004607035], 
             UndirectedEdge[136, 246] -> 
             RGBColor[
              0.5311924849620417, 0.6300266566393842, 0.9563079499316767], 
             UndirectedEdge[59, 246] -> 
             RGBColor[
              0.38891052450146135`, 0.5112764819370106, 0.9460020126145274], 
             UndirectedEdge[177, 200] -> 
             RGBColor[
              0.2962840776702533, 0.42752676637236176`, 0.9402288709406241], 
             UndirectedEdge[17, 157] -> 
             RGBColor[
              0.5023802232259484, 0.6068939230427937, 0.9539683579331921], 
             UndirectedEdge[151, 386] -> 
             RGBColor[
              0.3275993292124569, 0.45817180616795133`, 0.9420953174660733], 
             UndirectedEdge[4, 188] -> 
             RGBColor[
              0.24964120798061978`, 0.37971911612737436`, 0.9375280695322004],
              UndirectedEdge[241, 255] -> 
             RGBColor[
              0.2757184631493581, 0.40712796470319146`, 0.9390131306362182], 
             UndirectedEdge[62, 345] -> 
             RGBColor[
              0.19050782677282135`, 0.3175661832050619, 0.9341605109524143], 
             UndirectedEdge[57, 114] -> 
             RGBColor[
              0.3010426520782409, 0.43188396298315035`, 0.9405234581386476], 
             UndirectedEdge[32, 137] -> 
             RGBColor[
              0.21892075175740905`, 0.34742996884735633`, 0.9357785849971308],
              UndirectedEdge[152, 175] -> 
             RGBColor[
              0.181274153781999, 0.307861007443026, 0.9336346669355821], 
             UndirectedEdge[99, 235] -> 
             RGBColor[
              0.8591106393434069, 0.8900471270857477, 0.9483188623764983], 
             UndirectedEdge[156, 256] -> 
             RGBColor[
              0.20563395231845213`, 0.3334647002052716, 0.9350219214251405], 
             UndirectedEdge[48, 286] -> 
             RGBColor[
              0.5758463873446392, 0.6644950889479655, 0.9608396409213635], 
             UndirectedEdge[61, 262] -> 
             RGBColor[
              0.9659943820446136, 0.9709682059989204, 0.7529333373497976], 
             UndirectedEdge[146, 385] -> 
             RGBColor[
              0.5553761412741389, 0.6499183967532158, 0.95814039073239], 
             UndirectedEdge[29, 150] -> 
             RGBColor[
              0.2555149933709343, 0.38589283699209853`, 0.937862572920692], 
             UndirectedEdge[141, 220] -> 
             RGBColor[
              0.4177492311275311, 0.5356546049090093, 0.9480055136475012], 
             UndirectedEdge[152, 242] -> 
             RGBColor[
              0.5509815030039178, 0.5121510355041116, 0.5934630978551525], 
             UndirectedEdge[95, 151] -> 
             RGBColor[
              0.2988070240901653, 0.4307400317944288, 0.9403519901524575], 
             UndirectedEdge[252, 293] -> 
             RGBColor[
              0.21778209463220533`, 0.3462331680137357, 0.9357137401583427], 
             UndirectedEdge[93, 390] -> 
             RGBColor[
              0.2557686929307827, 0.3861594913149804, 0.9378770207353105], 
             UndirectedEdge[229, 249] -> 
             RGBColor[
              0.2582327214414536, 0.38874934150812634`, 0.9380173435137897], 
             UndirectedEdge[96, 153] -> 
             RGBColor[
              0.3021711245350493, 0.4341284235470012, 0.9405489710681403], 
             UndirectedEdge[202, 217] -> 
             RGBColor[
              0.8395826476787889, 0.30525515205179155`, 0.18553769416040178`],
              UndirectedEdge[163, 304] -> 
             RGBColor[
              0.23203584179739814`, 0.3612147600241211, 0.9365254699728711], 
             UndirectedEdge[18, 323] -> 
             RGBColor[
              0.8877084052982851, 0.9130534285104475, 0.9806512796744769], 
             UndirectedEdge[152, 264] -> 
             RGBColor[
              0.186823590274237, 0.31369381705096394`, 0.9339506991341594], 
             UndirectedEdge[23, 169] -> 
             RGBColor[
              0.21705819820147026`, 0.34547230696734843`, 0.9356725153275212],
              UndirectedEdge[290, 342] -> 
             RGBColor[
              0.5042459583975736, 0.6071002946590989, 0.9544767271173353], 
             UndirectedEdge[285, 330] -> 
             RGBColor[
              0.23174352854992997`, 0.3609075202673017, 0.9365088231658666], 
             UndirectedEdge[55, 192] -> 
             RGBColor[
              0.3740111987150174, 0.498371434802681, 0.9450526407503718], 
             UndirectedEdge[161, 170] -> 
             RGBColor[
              0.43820314080929235`, 0.5539712686639211, 0.9491428945379133], 
             UndirectedEdge[42, 205] -> 
             RGBColor[
              0.9637471875060623, 0.9705535185426564, 0.8607371274369169], 
             UndirectedEdge[267, 398] -> 
             RGBColor[
              0.7553121738986209, 0.8085541033742493, 0.9734035961579184], 
             UndirectedEdge[32, 199] -> 
             RGBColor[
              0.22104408708317058`, 0.349661728901967, 0.9358995058027398], 
             UndirectedEdge[154, 385] -> 
             RGBColor[
              0.5027895372841396, 0.606597375130399, 0.9541743330742887], 
             UndirectedEdge[91, 190] -> 
             RGBColor[
              0.25186209923856306`, 0.38205341365211143`, 0.9376545460038261],
              UndirectedEdge[94, 380] -> 
             RGBColor[
              0.2628073165498582, 0.39355753101314184`, 0.9382778599377064], 
             UndirectedEdge[119, 288] -> 
             RGBColor[
              0.2427621793276949, 0.37248882085754254`, 0.9371363190270272], 
             UndirectedEdge[65, 251] -> 
             RGBColor[
              0.6688240146939028, 0.7392826292624911, 0.9689511985946974], 
             UndirectedEdge[198, 216] -> 
             RGBColor[
              0.7427956016916255, 0.7990494191661757, 0.974984628023718], 
             UndirectedEdge[101, 182] -> 
             RGBColor[
              0.2744680720566198, 0.40581372438534935`, 0.9389419227132746], 
             UndirectedEdge[11, 230] -> 
             RGBColor[
              0.9461599473200244, 0.8204361321227099, 0.29539556227068897`], 
             UndirectedEdge[53, 101] -> 
             RGBColor[
              0.27504289638646184`, 0.40641790120198085`, 0.9389746581084827],
              UndirectedEdge[202, 264] -> 
             RGBColor[
              0.5231853201585595, 0.37556082624020004`, 0.5678587762898913], 
             UndirectedEdge[336, 367] -> 
             RGBColor[
              0.21516062802241154`, 0.34347784039625945`, 0.9355644515130273],
              UndirectedEdge[13, 132] -> 
             RGBColor[
              0.8815012453075697, 0.9077928551611671, 0.9634088234551113], 
             UndirectedEdge[146, 307] -> 
             RGBColor[
              0.760285606005483, 0.8109047025764178, 0.9254188643765703], 
             UndirectedEdge[75, 133] -> 
             RGBColor[
              0.27071817278007254`, 0.4018723424883518, 0.9387283714969541], 
             UndirectedEdge[153, 369] -> 
             RGBColor[
              0.28744235484774583`, 0.41864755274771004`, 0.9397101894237105],
              UndirectedEdge[20, 181] -> 
             RGBColor[
              0.4874856363228792, 0.5935620769713348, 0.9531383479528726], 
             UndirectedEdge[112, 394] -> 
             RGBColor[
              0.34389456121557604`, 0.47228591710687856`, 0.9431336352400042],
              UndirectedEdge[279, 306] -> 
             RGBColor[
              0.9580128778613826, 0.8669798939942239, 0.307271930750418], 
             UndirectedEdge[34, 68] -> 
             RGBColor[
              0.29450681654452554`, 0.42654813983932427`, 0.9400950937121118],
              UndirectedEdge[4, 284] -> 
             RGBColor[
              0.23809729374437577`, 0.3675857303386453, 0.936870660694137], 
             UndirectedEdge[193, 235] -> 
             RGBColor[
              0.7812166445775857, 0.8290306868326278, 0.9788229798067978], 
             UndirectedEdge[296, 316] -> 
             RGBColor[
              0.27790052377493313`, 0.40942144877130526`, 0.9391373957607753],
              UndirectedEdge[117, 223] -> 
             RGBColor[
              0.40179215387534173`, 0.5224135595233219, 0.9468284392932418], 
             UndirectedEdge[37, 110] -> 
             RGBColor[
              0.2526887349083196, 0.3829222601527542, 0.9377016216823209], 
             UndirectedEdge[83, 349] -> 
             RGBColor[
              0.3991304048320619, 0.5201284286132558, 0.946653214352108], 
             UndirectedEdge[192, 348] -> 
             RGBColor[
              0.30372248336585006`, 0.4332572121434699, 0.9407289213687278], 
             UndirectedEdge[97, 394] -> 
             RGBColor[
              0.40057619946044803`, 0.521380703252613, 0.9467453391073628], 
             UndirectedEdge[2, 352] -> 
             RGBColor[
              0.9063026650036, 0.5663670773157738, 0.3851970536504771], 
             UndirectedEdge[69, 350] -> 
             RGBColor[
              0.4604806861717529, 0.5723193250518395, 0.9508242340447808], 
             UndirectedEdge[164, 304] -> 
             RGBColor[
              0.230818470893376, 0.3599352260182205, 0.936456142500826], 
             UndirectedEdge[141, 350] -> 
             RGBColor[
              0.3964033490329356, 0.5177663899458625, 0.9464794487680284], 
             UndirectedEdge[114, 356] -> 
             RGBColor[
              0.4236281428800086, 0.5395805954873082, 0.9487022895227458], 
             UndirectedEdge[383, 390] -> 
             RGBColor[
              0.27326780022861263`, 0.40455216259248444`, 0.9388735690083126],
              UndirectedEdge[297, 307] -> 
             RGBColor[
              0.965939497584164, 0.9739442069028073, 0.9347428726703746], 
             UndirectedEdge[40, 58] -> 
             RGBColor[
              0.31906156196643076`, 0.449858262003899, 0.9415849314423156], 
             UndirectedEdge[173, 295] -> 
             RGBColor[
              0.23437748052955032`, 0.36367597080008385`, 0.9366588228345232],
              UndirectedEdge[161, 239] -> 
             RGBColor[
              0.3779757827321134, 0.5018053582125028, 0.9453052605381971], 
             UndirectedEdge[35, 369] -> 
             RGBColor[
              0.26924749981930185`, 0.40032657196053045`, 0.9386446188475038],
              UndirectedEdge[303, 313] -> 
             RGBColor[
              0.2862100467675046, 0.4181552842906852, 0.9396106108023645], 
             UndirectedEdge[237, 349] -> 
             RGBColor[
              0.5118990860533059, 0.6144062060618112, 0.9547772771793315], 
             UndirectedEdge[21, 263] -> 
             RGBColor[
              0.2875003760669833, 0.4191258516317633, 0.9396982137034129], 
             UndirectedEdge[126, 274] -> 
             RGBColor[
              0.22138486041548355`, 0.35001990328050514`, 0.9359189123398861],
              UndirectedEdge[331, 346] -> 
             RGBColor[
              0.3985622409768109, 0.5196363136385831, 0.946617011453659], 
             UndirectedEdge[106, 345] -> 
             RGBColor[
              0.5752211056493675, 0.6453489967018295, 0.953440498597335]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.23802405881018981`, 0.36750875577945274`, 0.9368664900729765],
              316 -> RGBColor[
              0.25427950679235417`, 0.38459426226363735`, 0.9377922137877805],
              308 -> RGBColor[
              0.2610883790761277, 0.39175081874132034`, 0.9381799689915176], 
             160 -> RGBColor[
              0.8294775817921864, 0.22758318757925894`, 0.17586107165535175`],
              245 -> RGBColor[
              0.22989884827362161`, 0.3589686443374169, 0.9364037713530907], 
             155 -> RGBColor[
              0.30454561984188433`, 0.43742713413433654`, 0.9406547945639009],
              213 -> RGBColor[
              0.9109681137578394, 0.6847252697068382, 0.24722105836383443`], 
             352 -> RGBColor[
              0.9941541355650164, 0.9899046120181566, 0.6050919166244885], 27 -> 
             RGBColor[
              0.2974167180204977, 0.42993420632157753`, 0.9402488141514381], 
             367 -> RGBColor[
              0.21931469518675756`, 0.34784402836905765`, 0.9358010194926452],
              19 -> RGBColor[
              0.2743841090042405, 0.40572547389373365`, 0.9389371411416538], 
             164 -> RGBColor[
              0.24253850776538854`, 0.3722537278639624, 0.9371235812624463], 
             190 -> RGBColor[
              0.2411029859620505, 0.37074490343131483`, 0.9370418304194105], 
             103 -> RGBColor[
              0.34456615692423104`, 0.4728676195543337, 0.943176428724691], 
             138 -> RGBColor[
              0.8193428764107183, 0.14968340096107918`, 0.16615606633654534`],
              291 -> RGBColor[
              0.696491580031562, 0.7628237829435023, 0.9703834296798242], 28 -> 
             RGBColor[
              0.2882891132658928, 0.42034051500092084`, 0.9397290105637445], 
             337 -> RGBColor[
              0.2847433322190086, 0.4166136743051424, 0.9395270835786375], 
             195 -> RGBColor[
              0.24569470610522032`, 0.37557109243365844`, 0.9373033220887227],
              114 -> RGBColor[
              0.3288778807819878, 0.45927922327560866`, 0.9421767856415051], 
             93 -> RGBColor[
              0.2452381115380016, 0.3750911825937439, 0.9372773197035907], 34 -> 
             RGBColor[
              0.3122890105436297, 0.4449107776560043, 0.9411197574988789], 
             161 -> RGBColor[
              0.4314366462475933, 0.5481104711684827, 0.9487117394878181], 22 -> 
             RGBColor[
              0.29231839668471055`, 0.42457554734542235`, 0.9399584722936555],
              124 -> RGBColor[
              0.22327126764014227`, 0.35200263687874755`, 0.936026340440641], 
             84 -> RGBColor[
              0.17892701429477148`, 0.30539401502471114`, 0.9335010008140661],
              46 -> RGBColor[
              0.2843163130979401, 0.41616485013432336`, 0.9395027654714108], 
             241 -> RGBColor[
              0.290961948336973, 0.42314983412815754`, 0.9398812245669373], 
             185 -> RGBColor[
              0.8236904837096025, 0.18310101579396953`, 0.170319339995877], 
             390 -> RGBColor[
              0.26629927432356376`, 0.3972278000362168, 0.9384767217670303], 
             121 -> RGBColor[
              0.5531961411455233, 0.6481485744409189, 0.9579687731366617], 
             322 -> RGBColor[
              0.5084161265639328, 0.611794141286916, 0.9544435263542006], 126 -> 
             RGBColor[
              0.21204174778307774`, 0.3401996995162911, 0.935386835897367], 
             236 -> RGBColor[
              0.2505222001886238, 0.3806450947961188, 0.9375782407351351], 78 -> 
             RGBColor[
              0.8418439495844675, 0.3226365094076515, 0.18770311941905493`], 
             376 -> RGBColor[
              0.43839329858407067`, 0.5541359737708264, 0.9491550112231723], 
             254 -> RGBColor[
              0.46951139015292603`, 0.5802095236300584, 0.951380802991181], 
             290 -> RGBColor[
              0.4051337172328171, 0.5253281960795354, 0.9470357401097634], 
             251 -> RGBColor[
              0.822315843269912, 0.8611563485272284, 0.9829144132927453], 165 -> 
             RGBColor[
              0.532748774101436, 0.6315484807311408, 0.9563590815017777], 100 -> 
             RGBColor[
              0.37661408553666426`, 0.5006259245426959, 0.9452184943970047], 
             235 -> RGBColor[
              0.7400936775781565, 0.7968860729351169, 0.9747292792785006], 70 -> 
             RGBColor[
              0.2778101351361315, 0.409326444580954, 0.9391322482615135], 234 -> 
             RGBColor[
              0.3387393935852255, 0.4678207700117279, 0.942805152517134], 257 -> 
             RGBColor[
              0.8226071697061851, 0.17477418965247965`, 0.16928195728277629`],
              135 -> RGBColor[
              0.5032780494106496, 0.6076228187861427, 0.9540390380992975], 
             265 -> RGBColor[
              0.5918946974095183, 0.6795658057661227, 0.9610152652432459], 
             111 -> RGBColor[
              0.8740781517963572, 0.5211001217496539, 0.21664006204298622`], 
             381 -> RGBColor[
              0.9931470290452047, 0.9914341346439413, 0.7632349938486772], 
             182 -> RGBColor[
              0.2880943118622093, 0.4201357663745271, 0.9397179169119876], 
             188 -> RGBColor[
              0.26708591845739416`, 0.39805461289699134`, 0.9385215199867163],
              154 -> RGBColor[
              0.4301580292792129, 0.547002997415629, 0.9486302671452295], 336 -> 
             RGBColor[
              0.2110065608580655, 0.33911165242346125`, 0.9353278835334095], 
             315 -> RGBColor[
              0.24327422624281886`, 0.37302701463098736`, 0.937165479341338], 
             368 -> RGBColor[
              0.21278150541118618`, 0.3409772316867757, 0.9354289639999145], 
             269 -> RGBColor[
              0.9930589289900814, 0.9875620758967413, 0.48588543977432486`], 
             208 -> RGBColor[
              0.2330867180319017, 0.36231929757598597`, 0.9365853158197941], 
             86 -> RGBColor[
              0.30053635500276704`, 0.4332131425863514, 0.940426472862489], 
             119 -> RGBColor[
              0.24049836738192176`, 0.3701094109685675, 0.9370073982857251], 
             377 -> RGBColor[
              0.41487938737084307`, 0.5337694057214698, 0.9476567255932007], 
             140 -> RGBColor[
              0.6719249954084331, 0.7436321803229556, 0.9679348621123766], 85 -> 
             RGBColor[
              0.2413074662041341, 0.37095982513054093`, 0.9370534752666957], 
             351 -> RGBColor[
              0.24574449108125243`, 0.37562341960001794`, 0.9373061572694574],
              242 -> RGBColor[
              0.9183468399249884, 0.7139794601448493, 0.25315815463888625`], 
             117 -> 
             RGBColor[
              0.3495171154366807, 0.47715589097540734`, 0.9434918994231435], 
             47 -> RGBColor[
              0.43389191818712153`, 0.5502371043169462, 0.948868187244693], 
             81 -> RGBColor[
              0.2197154470497895, 0.34826524398623987`, 0.9358238417183856], 
             275 -> RGBColor[
              0.992100640761205, 0.9910014261975552, 0.7805763556806252], 23 -> 
             RGBColor[
              0.21341792784235675`, 0.34164615201344867`, 0.935465207315867], 
             328 -> RGBColor[
              0.3094371851822424, 0.44244066986488095`, 0.9409380417086214], 
             110 -> RGBColor[
              0.25557794384056287`, 0.3859590019269685, 0.9378661578568105], 
             6 -> RGBColor[
              0.9933475429680663, 0.9881793920123014, 0.5172992901589675], 
             218 -> RGBColor[
              0.9100637739514378, 0.9311241665985504, 0.9912838892546516], 
             108 -> RGBColor[
              0.3675690787260941, 0.49279159425864094`, 0.9446421545612206], 
             297 -> RGBColor[
              0.9466390204165737, 0.9597240493140413, 0.9752103990490407], 
             157 -> RGBColor[
              0.46924384183457235`, 0.5799923158523045, 0.9513597406074984], 
             354 -> RGBColor[
              0.27977343586669706`, 0.4113899981292344, 0.939244055333676], 
             385 -> RGBColor[
              0.5754210452890663, 0.6661917528451691, 0.9597183990033479], 
             270 -> RGBColor[
              0.249587147505622, 0.3796622951405196, 0.9375249908681246], 392 -> 
             RGBColor[
              0.24794921220500737`, 0.3779407212884774, 0.9374317128758627], 
             33 -> RGBColor[
              0.17894138666990014`, 0.3054091213022326, 0.9335018192995677], 
             252 -> RGBColor[
              0.2243331252717409, 0.35311871657522015`, 0.9360868116618829], 
             394 -> RGBColor[
              0.35886795134781274`, 0.48525511505495156`, 0.9440877264187814],
              260 -> RGBColor[
              0.8089540339665278, 0.8506803067038047, 0.9815926360666765], 
             159 -> RGBColor[
              0.3314345944952444, 0.46149372018986384`, 0.9423396971785006], 
             183 -> RGBColor[
              0.2589336294896423, 0.3894860403069097, 0.9380572591902335], 99 -> 
             RGBColor[
              0.9781276011086575, 0.9832081812363787, 0.921908445474496], 329 -> 
             RGBColor[
              0.23513882534723038`, 0.36447619247551505`, 0.9367021802955814],
              309 -> 
             RGBColor[
              0.27079044913528966`, 0.40194830952027055`, 0.9387324875284604],
              17 -> RGBColor[
              0.5355166046173245, 0.6337955302332828, 0.9565769752588857], 
             349 -> RGBColor[
              0.4453791406536688, 0.5601867590528806, 0.9496001429025095], 
             347 -> RGBColor[
              0.2800500850584523, 0.411680773970341, 0.9392598100958807], 340 -> 
             RGBColor[
              0.99377812825938, 0.9891003704115706, 0.5641658418540755], 277 -> 
             RGBColor[
              0.2578128298869203, 0.3883080088616496, 0.9379934313109329], 
             104 -> RGBColor[
              0.9338740873595025, 0.7755398220742175, 0.265651742396037], 79 -> 
             RGBColor[
              0.590805957298975, 0.6786819174972005, 0.9609295556335575], 327 -> 
             RGBColor[
              0.3185921337049145, 0.45037022613412764`, 0.941521386933083], 
             191 -> RGBColor[
              0.6788533623879274, 0.7490446732648759, 0.968625416983622], 50 -> 
             RGBColor[
              0.45414763221898446`, 0.5677365328098771, 0.9501713116873214], 
             225 -> RGBColor[
              0.2571081050813221, 0.3875672984088326, 0.9379532982758011], 61 -> 
             RGBColor[
              0.9933459036684309, 0.98817588571614, 0.5171208625102379], 196 -> 
             RGBColor[
              0.29792411608308994`, 0.43046751385625726`, 0.9402777097204745],
              1 -> RGBColor[
              0.3599830334006432, 0.48622094308345976`, 0.9441587784611594], 
             263 -> RGBColor[
              0.26208361027682536`, 0.3927968698345563, 0.9382366459360847], 
             201 -> RGBColor[
              0.27642628673231373`, 0.407871932167485, 0.9390534401421363], 
             371 -> RGBColor[
              0.27204560568907665`, 0.4032675586398226, 0.9388039668373608], 
             293 -> RGBColor[
              0.21123106399266978`, 0.3393476194522512, 0.9353406686548026], 
             362 -> RGBColor[
              0.40465902674538534`, 0.5249170430379596, 0.9470054932516565], 
             184 -> RGBColor[
              0.21776291881025298`, 0.3462130130090464, 0.9357126481236506], 
             106 -> RGBColor[
              0.948494816832878, 0.9611080992427333, 0.9720690197854612], 206 -> 
             RGBColor[
              0.23156206990492625`, 0.36071679572626025`, 0.9364984893644777],
              358 -> RGBColor[
              0.9685766725786527, 0.9056638794389593, 0.332426736075871], 247 -> 
             RGBColor[
              0.9070075396154186, 0.6690229130152352, 0.24403428744221908`], 
             220 -> RGBColor[
              0.4754345148883495, 0.5850181831240037, 0.9518470930674744], 
             107 -> RGBColor[
              0.8392176796973624, 0.30244984821655896`, 0.1851882004092155], 
             375 -> RGBColor[
              0.25484534055170655`, 0.38518898942064916`, 0.9378244371832996],
              131 -> RGBColor[
              0.9224661794909306, 0.7303112688352736, 0.2564726719469704], 
             127 -> RGBColor[
              0.21049571798261152`, 0.33857472417205015`, 0.9352987917873766],
              210 -> RGBColor[
              0.2999237099233219, 0.432569213763913, 0.9403915836315417], 357 -> 
             RGBColor[
              0.6756901028072094, 0.7465735108387558, 0.9683101328309576], 
             181 -> RGBColor[
              0.5673122922146817, 0.6596087018042204, 0.9590800482579911], 
             194 -> RGBColor[
              0.3880550588481297, 0.5105355205850486, 0.9459475030995558], 
             118 -> RGBColor[
              0.20606162213947596`, 0.33391420830300045`, 0.935046276588767], 
             348 -> RGBColor[
              0.26295522261758464`, 0.39371298966810864`, 0.9382862829694559],
              276 -> RGBColor[
              0.765566144894021, 0.8167853580001923, 0.977268136766805], 305 -> 
             RGBColor[
              0.20290260740476634`, 0.33059388352371805`, 0.9348663753729688],
              343 -> RGBColor[
              0.7222005724227306, 0.7829078431950623, 0.9729458617771823], 
             280 -> RGBColor[
              0.23901320904650822`, 0.3685484153935707, 0.9369228207156182], 
             189 -> RGBColor[
              0.30054674338696064`, 0.4332240614368005, 0.9404270644656005], 
             168 -> RGBColor[
              0.6701504899984683, 0.7422459232099505, 0.9677579959968072], 
             363 -> RGBColor[
              0.8625124936811881, 0.46858316947675277`, 0.2069893934114667], 
             41 -> RGBColor[
              0.34082031608406577`, 0.4696231604900174, 0.9429377470586726], 
             14 -> RGBColor[
              0.9943570777774785, 0.9903386848900081, 0.6271809240368398], 77 -> 
             RGBColor[
              0.8293651040061051, 0.8667772376911834, 0.9835867780747127], 51 -> 
             RGBColor[
              0.3729233885884314, 0.4974292283459589, 0.9449833264510183], 
             179 -> RGBColor[
              0.2696431574723743, 0.40074243324005365`, 0.9386671509655232], 
             223 -> 
             RGBColor[
              0.4540671923140028, 0.5676712280712366, 0.9501649791633402], 
             323 -> RGBColor[
              0.8302102447519867, 0.867451129981215, 0.983667388353521], 292 -> 
             RGBColor[
              0.2110186790508826, 0.3391243894124498, 0.9353285736465631], 
             396 -> RGBColor[
              0.2782995151593558, 0.4098408140138484, 0.9391601177298633], 
             321 -> RGBColor[
              0.8177864636409283, 0.8575802678943982, 0.9824729701128726], 
             143 -> RGBColor[
              0.6246442469651912, 0.7061533654458123, 0.9635934297498213], 
             112 -> RGBColor[
              0.3289211710833394, 0.45931671915880556`, 0.9421795440612271], 
             197 -> RGBColor[
              0.988751433892587, 0.9896164430866911, 0.8360813809631582], 54 -> 
             RGBColor[
              0.4519914858020445, 0.5659140400742732, 0.9500214756882968], 71 -> 
             RGBColor[
              0.871120013048017, 0.9000714687543917, 0.9875693985741776], 177 -> 
             RGBColor[
              0.3219085007459621, 0.453242696579629, 0.9417327029083903], 158 -> 
             RGBColor[
              0.5031159008708285, 0.6074911792968075, 0.9540262731722731], 
             226 -> RGBColor[
              0.23863402700947722`, 0.3681498710311214, 0.9369012268595588], 
             350 -> RGBColor[
              0.4327427506991586, 0.5492417531977101, 0.948794963308529], 203 -> 
             RGBColor[
              0.29139757571829134`, 0.42360770612629445`, 0.9399060329018505],
              115 -> RGBColor[
              0.2386060995532787, 0.36812051750395375`, 0.9368996364322433], 
             173 -> RGBColor[
              0.22636761106282094`, 0.3552570901354948, 0.936202672617933], 
             212 -> RGBColor[
              0.21089717481030001`, 0.33899668075178374`, 0.9353216541598114],
              129 -> RGBColor[
              0.23768447069359533`, 0.36715182713778177`, 0.936847151032112], 
             279 -> RGBColor[
              0.9456496399519233, 0.8222259641328803, 0.2751266284196432], 26 -> 
             RGBColor[
              0.45511285367532656`, 0.5685201430708667, 0.9502472974560874], 
             40 -> RGBColor[
              0.3393121311221928, 0.4683168464796233, 0.9428416468465376], 
             146 -> RGBColor[
              0.5353312372592116, 0.6336450406612625, 0.9565623824614321], 
             386 -> RGBColor[
              0.3393631406607411, 0.4683610283780999, 0.942844897129228], 192 -> 
             RGBColor[
              0.34448974411411554`, 0.4728014346188312, 0.9431715597679996], 
             300 -> RGBColor[
              0.8899967779325137, 0.5933828851443484, 0.2299229538922278], 
             221 -> RGBColor[
              0.9218589159168126, 0.9405292926311409, 0.9924089204249567], 62 -> 
             RGBColor[
              0.1790682590797859, 0.30554247224919795`, 0.9335090444956198], 
             286 -> RGBColor[
              0.726249879738111, 0.7860711928457129, 0.9733494588874512], 152 -> 
             RGBColor[
              0.18361616608284723`, 0.3103226108633739, 0.9337680410714186], 
             64 -> RGBColor[
              0.3989602722595878, 0.5199810683300905, 0.9466423736550322], 
             307 -> RGBColor[
              0.9852399747517544, 0.9881643644915732, 0.8942753462917085], 37 -> 
             RGBColor[
              0.24979952597607638`, 0.3798855183785399, 0.9375370855078312], 
             148 -> RGBColor[
              0.6238880244982119, 0.7055394299796848, 0.9635338971470865], 
             261 -> RGBColor[
              0.17944836957228805`, 0.3059419924772149, 0.9335306912258446], 
             387 -> RGBColor[
              0.2935687509337651, 0.4258897489382169, 0.9400296781184059], 15 -> 
             RGBColor[
              0.3038609163605336, 0.43670746736272875`, 0.940615801713566], 
             136 -> RGBColor[
              0.6185821135656369, 0.7012318524560568, 0.9631161964022821], 
             198 -> RGBColor[
              0.8264896291158393, 0.8644844120663722, 0.9833125127127125], 63 -> 
             RGBColor[
              0.9585610528033711, 0.8718788421575785, 0.2935179445399928], 
             310 -> RGBColor[
              0.18257815057035692`, 0.3092315907457619, 0.9337089276235886], 
             171 -> RGBColor[
              0.2732125866431092, 0.40449412961337683`, 0.9388704246762993], 
             395 -> RGBColor[
              0.27306809856961783`, 0.40434226348706437`, 0.938862196294265], 
             311 -> RGBColor[
              0.519374038863881, 0.6206902681403376, 0.955306173350608], 353 -> 
             RGBColor[
              0.21037964845754836`, 0.3384527277419758, 0.9352921817996338], 
             59 -> RGBColor[
              0.3340181926444761, 0.4637315030513096, 0.9425043217679835], 
             397 -> RGBColor[
              0.2493495489754894, 0.37941256402073326`, 0.9375114599833291], 
             229 -> RGBColor[
              0.24689616138342244`, 0.3768338981077132, 0.9373717431894225], 
             102 -> 
             RGBColor[
              0.819297035403237, 0.14933104688991955`, 0.16611216893601113`], 
             299 -> RGBColor[
              0.21412870248835636`, 0.3423932212321097, 0.9355056848804599], 
             128 -> RGBColor[
              0.3262131529712761, 0.45697116997908427`, 0.9420069915417328], 
             12 -> RGBColor[
              0.218436984339963, 0.3469214986189947, 0.935751035158377], 222 -> 
             RGBColor[
              0.6049269005052089, 0.6901459353332633, 0.9620412080094716], 92 -> 
             RGBColor[
              0.28766384187052196`, 0.4196833151198899, 0.9396934022827843], 
             271 -> RGBColor[
              0.30678788301618565`, 0.43978389489822367`, 0.9407824881345462],
              361 -> RGBColor[
              0.35562652096447817`, 0.48244755097593534`, 0.9438811853410396],
              344 -> RGBColor[
              0.32062864936426844`, 0.45213415364000675`, 0.941651151910077], 
             132 -> RGBColor[
              0.7992223614262676, 0.8430778501519028, 0.9806226738955138], 80 -> 
             RGBColor[
              0.3344163982055418, 0.46407640869391137`, 0.9425296950742152], 
             324 -> RGBColor[
              0.2799576543907215, 0.4115836234781131, 0.9392545463060924], 
             244 -> RGBColor[
              0.2600361752617328, 0.3906448858188163, 0.9381200475408837], 
             150 -> RGBColor[
              0.2706007772119499, 0.40174895230294594`, 0.9387216859930206], 
             125 -> RGBColor[
              0.277985958766929, 0.4095112463647842, 0.9391422611571797], 258 -> 
             RGBColor[
              0.2529332615169164, 0.38317927312227185`, 0.9377155471109357], 
             133 -> RGBColor[
              0.29725822306554583`, 0.42976761807476255`, 0.9402397880982258],
              255 -> RGBColor[
              0.26047497796174324`, 0.3911060952782254, 0.938145036705499], 
             326 -> RGBColor[
              0.3393902356747875, 0.4683844967174319, 0.9428466235995638], 
             176 -> RGBColor[
              0.21582348781243682`, 0.34417454806331416`, 0.935602200397456], 
             230 -> RGBColor[
              0.9688572327835747, 0.9066102748888301, 0.333516659492644], 274 -> 
             RGBColor[
              0.2307279730478894, 0.35984010704471925`, 0.9364509887824051], 
             87 -> RGBColor[
              0.29013871681338543`, 0.4222845656009737, 0.9398343427495309], 
             130 -> RGBColor[
              0.4104055903111328, 0.5298944275679272, 0.9473716592005793], 35 -> 
             RGBColor[
              0.28104105066772134`, 0.4127223416565313, 0.9393162441213263], 
             379 -> RGBColor[
              0.22095736038557218`, 0.3495705736440009, 0.9358945668456122], 
             31 -> RGBColor[
              0.183217413291963, 0.30990349639776743`, 0.9337453326898797], 
             18 -> RGBColor[
              0.9452065658445834, 0.95865572703968, 0.9776351709954327], 24 -> 
             RGBColor[
              0.9021530244270525, 0.6485815613125467, 0.24006642394413927`], 
             151 -> RGBColor[
              0.3158355177641727, 0.44798258395780277`, 0.9413457378029186], 
             137 -> RGBColor[
              0.22155609394318862`, 0.3501998805749559, 0.9359286638359716], 
             330 -> RGBColor[
              0.22477195032544567`, 0.3535799495297792, 0.936111802099508], 
             296 -> RGBColor[
              0.30152154075751214`, 0.43424863527897317`, 0.94048257773377], 
             266 -> RGBColor[
              0.2549979314676595, 0.3853493721481386, 0.937833127010225], 302 -> 
             RGBColor[
              0.9872770340850194, 0.9687445898536212, 0.4050741092611545], 
             283 -> RGBColor[
              0.9089152991886196, 0.6765865439997854, 0.2455693155756892], 
             388 -> RGBColor[
              0.22336510960731928`, 0.352101270736175, 0.9360316846018449], 
             284 -> RGBColor[
              0.24399808998490613`, 0.37378784131953313`, 0.9372067023105894],
              318 -> RGBColor[
              0.2238174684207968, 0.35257672853034516`, 0.9360574457670676], 
             238 -> RGBColor[
              0.22922310747734106`, 0.35825839791608494`, 0.9363652889144115],
              72 -> RGBColor[
              0.22772650909910638`, 0.3566853781307425, 0.9362800598507899], 
             288 -> RGBColor[
              0.245025991273468, 0.37486823074651754`, 0.9372652397683294], 
             382 -> RGBColor[
              0.898780922280212, 0.63326963303821, 0.23725265925502825`], 389 -> 
             RGBColor[
              0.17908812663026416`, 0.30556335430442605`, 0.933510175923228], 
             172 -> RGBColor[
              0.301424661402258, 0.4341468089340951, 0.9404770605978084], 243 -> 
             RGBColor[
              0.2883719521470624, 0.4204275839173185, 0.939733728115478], 88 -> 
             RGBColor[
              0.9903137669558371, 0.9902625079584733, 0.8101894789167451], 
             273 -> RGBColor[
              0.2754373969927425, 0.40683254635196486`, 0.938997124334399], 
             202 -> 
             RGBColor[
              0.8563396258514921, 0.4340566292418462, 0.20158419538288244`], 
             393 -> RGBColor[
              0.22281999879048459`, 0.3515283247056597, 0.9360006413472455], 
             98 -> RGBColor[
              0.9775701021325132, 0.9360008290818089, 0.3673645116259542], 30 -> 
             RGBColor[
              0.17892703208317115`, 0.3053940337214471, 0.9335010018270892], 
             116 -> RGBColor[
              0.4162213411164948, 0.534931738607397, 0.9477422336992305], 373 -> 
             RGBColor[
              0.2503218011924054, 0.380434462745063, 0.9375668283087641], 240 -> 
             RGBColor[
              0.23920651037948798`, 0.3687515873505448, 0.9369338289405676], 
             317 -> RGBColor[
              0.9906270631619555, 0.9903920639910485, 0.8049973499967711], 
             391 -> RGBColor[
              0.8203907902431329, 0.1577381258757864, 0.16715954980591485`], 
             73 -> RGBColor[
              0.24311597663730303`, 0.3728606842619857, 0.9371564672604132], 
             303 -> RGBColor[
              0.28961174034798287`, 0.421730679923598, 0.9398043322194181], 
             29 -> RGBColor[
              0.2404292095299187, 0.3700367216812511, 0.9370034598483634], 
             360 -> RGBColor[
              0.3103917228488082, 0.4432674424152022, 0.9409988640046705], 
             320 -> RGBColor[
              0.7098940201909748, 0.7732938710583535, 0.9717192596619902], 75 -> 
             RGBColor[
              0.24417812249459925`, 0.373977066901941, 0.9372169548956822], 
             200 -> RGBColor[
              0.27065965459454444`, 0.40181083616509444`, 0.9387250389728581],
              301 -> RGBColor[
              0.2568179059531509, 0.3872622807254372, 0.9379367718647629], 
             156 -> RGBColor[
              0.18595953915049845`, 0.3127856445359093, 0.9339014927009116], 
             25 -> RGBColor[
              0.8487111149297029, 0.3754205514621725, 0.19427912470900624`], 
             38 -> RGBColor[
              0.9657912116144293, 0.896267865549297, 0.32160574622002847`], 
             365 -> RGBColor[
              0.25624071750281635`, 0.38665561906827417`, 0.93790390183639], 
             380 -> RGBColor[
              0.26549066491796636`, 0.3963779002821365, 0.9384306726576119], 
             370 -> RGBColor[
              0.8312166238387177, 0.8682535893475418, 0.9837633776892186], 3 -> 
             RGBColor[
              0.370079657849583, 0.49496613171003123`, 0.9448021264429514], 
             57 -> 
             RGBColor[
              0.2732074233744939, 0.404488702690692, 0.9388701306357901], 227 -> 
             RGBColor[
              0.23492201148043795`, 0.36424830735472313`, 0.9366898330666149],
              39 -> RGBColor[
              0.27309206457306523`, 0.40436745327622, 0.9388635611227067], 
             109 -> RGBColor[
              0.9940964498066649, 0.9918267445278057, 0.7475006348091123], 
             256 -> RGBColor[
              0.22530836548640581`, 0.35414375587463387`, 0.9361423501493695],
              339 -> RGBColor[
              0.36576050208801136`, 0.49122509607643855`, 0.9445269136571035],
              287 -> RGBColor[
              0.260213393629744, 0.3908311535598896, 0.9381301398647709], 239 -> 
             RGBColor[
              0.32451491921663345`, 0.4555002452565231, 0.9418987815885761], 
             285 -> RGBColor[
              0.23871510677441427`, 0.3682350910048242, 0.9369058442322252], 
             345 -> RGBColor[
              0.20194739446585683`, 0.3295898941609259, 0.9348119774092088], 
             366 -> RGBColor[
              0.9012804456996433, 0.6446193851073215, 0.2393383228651273], 
             216 -> RGBColor[
              0.6591015742674116, 0.7336144262659793, 0.9666567433347234], 21 -> 
             RGBColor[
              0.31291714185714126`, 0.44545483342897024`, 0.9411597814707411],
              355 -> RGBColor[
              0.23092116646773903`, 0.3600431655781515, 0.9364619908618614], 
             175 -> RGBColor[
              0.17893214148115075`, 0.3053994040226782, 0.9335012927997455], 
             7 -> RGBColor[
              0.38940499419392427`, 0.5117047667318526, 0.9460335197860889], 
             13 -> RGBColor[
              0.9637801291888717, 0.9725078601704316, 0.9461949730147088], 
             294 -> RGBColor[
              0.21275955169572475`, 0.34095415693987974`, 0.9354277137682966],
              193 -> RGBColor[
              0.8223396115770147, 0.8611753007301386, 0.9829166803350949], 60 -> 
             RGBColor[
              0.35752834255750565`, 0.4840948132514831, 0.9440023677312325], 
             65 -> RGBColor[
              0.5153321861178936, 0.6174089099977538, 0.9549879838966494], 69 -> 
             RGBColor[
              0.48821862164434726`, 0.5953968969059689, 0.9528535047810326], 
             217 -> RGBColor[
              0.8228256695060855, 0.17645367486173685`, 0.16949119293792111`],
              214 -> RGBColor[
              0.9837730937067766, 0.9874185803724101, 0.9123520990861677], 
             170 -> 
             RGBColor[
              0.44496963537099143`, 0.5598320661593594, 0.9495740495880086], 
             359 -> RGBColor[
              0.2455681205459235, 0.37543804298484945`, 0.9372961132283874], 
             74 -> RGBColor[
              0.8246734764068878, 0.8630362611944062, 0.983139286446034], 246 -> 
             RGBColor[
              0.4438028563584466, 0.5588214608227114, 0.9494997034610714], 
             264 -> RGBColor[
              0.19003101446562676`, 0.31706502323855396`, 0.9341333571969002],
              278 -> RGBColor[
              0.2524156236360728, 0.382635202889368, 0.9376860683993983], 45 -> 
             RGBColor[
              0.2954990939280613, 0.427918661816037, 0.9401396082962444], 306 -> 
             RGBColor[
              0.9703761157708419, 0.9117338238555674, 0.33941723308119276`], 
             237 -> RGBColor[
              0.5784190314529432, 0.6686256530707418, 0.9599544114561535], 
             228 -> RGBColor[
              0.36785717736282086`, 0.49304113081751505`, 0.9446605119515972],
              180 -> RGBColor[
              0.36627002209779275`, 0.4916664166996908, 0.9445593798215759], 
             383 -> RGBColor[
              0.28023632613366145`, 0.41187652514875206`, 0.939270416249595], 
             53 -> RGBColor[
              0.28924396052189333`, 0.4213441200077901, 0.9397833877024038], 
             304 -> RGBColor[
              0.21909843402136348`, 0.34761672417247863`, 0.9357887037392056],
              48 -> RGBColor[
              0.4254428949511675, 0.5429189850502182, 0.948329822955276], 5 -> 
             RGBColor[
              0.8414430264446411, 0.8764078451972013, 0.9847387810989889], 
             101 -> RGBColor[
              0.2608418322510304, 0.39149168239617155`, 0.9381659285145616], 
             333 -> RGBColor[
              0.19556045555100107`, 0.3228768164060961, 0.9344482506866372], 
             267 -> RGBColor[
              0.5711989452526345, 0.6627640618321545, 0.9593860198224179], 
             120 -> RGBColor[
              0.5663783145126094, 0.6588504566304622, 0.9590065221120109], 
             147 -> RGBColor[
              0.28473783311028583`, 0.41660789439321116`, 0.9395267704125309],
              89 -> RGBColor[
              0.21858282554203126`, 0.3470747869692347, 0.9357593405990821], 
             43 -> RGBColor[
              0.2274352478585693, 0.35637924409990884`, 0.9362634729540237], 
             199 -> RGBColor[
              0.22580276459471169`, 0.35466340068417734`, 0.9361705054471896],
              268 -> RGBColor[0.817319, 0.134127, 0.164218], 169 -> 
             RGBColor[
              0.22069846856058375`, 0.34929846192124825`, 0.9358798233391753],
              20 -> RGBColor[
              0.4076589804310767, 0.5275154521384491, 0.9471966476477539], 4 -> 
             RGBColor[
              0.23219649750384544`, 0.36138361935775737`, 0.9365346190776845],
              167 -> RGBColor[
              0.2835494674254077, 0.415358846711668, 0.9394590947448065], 142 -> 
             RGBColor[
              0.8215839734950429, 0.16690945520620182`, 0.16830214343545163`],
              16 -> RGBColor[
              0.2418605106508593, 0.3715411099090923, 0.9370849703297808], 
             281 -> RGBColor[
              0.6319940482543123, 0.7121202652370958, 0.9641720330305101], 
             289 -> RGBColor[
              0.8977533081905217, 0.6286034774622947, 0.23639519286946437`], 
             398 -> RGBColor[
              0.9394254025446074, 0.954344144916344, 0.9874211724934188], 178 -> 
             RGBColor[
              0.24398844376792686`, 0.3737777025338824, 0.9372061529728027], 
             58 -> RGBColor[
              0.2988109928106687, 0.43139967752817476`, 0.9403282160380936], 
             186 -> RGBColor[
              0.24846767200989045`, 0.3784856554156597, 0.9374612383947583], 
             122 -> RGBColor[
              0.44608758599784554`, 0.5608003788025082, 0.9496452844133868], 
             249 -> RGBColor[
              0.2695692814994847, 0.4006647849085395, 0.938662943838157], 113 -> 
             RGBColor[
              0.7965156452550962, 0.8409633429071789, 0.9803528937232722], 52 -> 
             RGBColor[
              0.38664548537965426`, 0.5093146188938776, 0.9458576863245813], 
             187 -> RGBColor[
              0.8439338400416576, 0.8783939523481282, 0.9849763571234479], 
             259 -> RGBColor[
              0.2110206902246306, 0.3391265032835748, 0.9353286881799328], 42 -> 
             RGBColor[
              0.9322258626950144, 0.9487956145888052, 0.9933977290633442], 
             134 -> RGBColor[
              0.2343268669145523, 0.36362277268163234`, 0.9366559404640252], 
             313 -> RGBColor[
              0.2828083531870263, 0.41457988865777246`, 0.939416889385311], 
             248 -> RGBColor[
              0.21620788903044316`, 0.3445785781158837, 0.9356240914781508], 
             174 -> RGBColor[
              0.7286053839996127, 0.7879113306772935, 0.9735842335387989], 
             215 -> RGBColor[
              0.8192881970279116, 0.1492631112641677, 0.166103705297818], 399 -> 
             RGBColor[
              0.2348790166106703, 0.36420311702056507`, 0.9366873845723869], 
             83 -> RGBColor[
              0.35288166901045503`, 0.480070098173631, 0.9437062858017065], 
             95 -> RGBColor[
              0.2817785304161579, 0.4134974796310549, 0.9393582425019963], 
             166 -> RGBColor[
              0.8247691039330448, 0.19139176348574266`, 0.17135222793997262`],
              384 -> RGBColor[
              0.7484278388783107, 0.8033967830847693, 0.9755599505897345], 
             233 -> RGBColor[
              0.8174582326741875, 0.1351972033459516, 0.16435132936604271`], 
             295 -> RGBColor[
              0.24238734999627973`, 0.3720948514646729, 0.9371149730511135], 
             141 -> RGBColor[
              0.3600639473667127, 0.48629102669401497`, 0.9441639342275279], 
             319 -> RGBColor[
              0.24158367299712782`, 0.37125013598249945`, 0.9370692048349454],
              205 -> RGBColor[
              0.9952685123171101, 0.9923114224965074, 0.7280765258104895], 
             224 -> RGBColor[
              0.9756615083220127, 0.9295626939998534, 0.3599499850798584], 
             231 -> RGBColor[
              0.30868412390727973`, 0.44177696430338015`, 0.9408904762480571],
              332 -> RGBColor[
              0.5272216074067284, 0.6270612778123552, 0.9559239626928917], 68 -> 
             RGBColor[
              0.2767246225454214, 0.4081855020226443, 0.9390704299253445], 10 -> 
             RGBColor[
              0.3619258765766598, 0.48790373619238797`, 0.9442825747103464], 
             250 -> RGBColor[
              0.9882272169582415, 0.9893996659125786, 0.8447690121952027], 
             282 -> RGBColor[
              0.6468617732853108, 0.7240526007128293, 0.965436794360271], 374 -> 
             RGBColor[
              0.2761037265699157, 0.40753290098530925`, 0.9390350708180728], 
             232 -> RGBColor[
              0.5255566438526651, 0.6257095853934133, 0.9557928906629534], 
             253 -> RGBColor[
              0.34171577858230273`, 0.47039876509873646`, 0.9429948051372339],
              55 -> RGBColor[
              0.4035326533159193, 0.5239414349865308, 0.9469337217327439], 
             325 -> RGBColor[
              0.21156771774634342`, 0.33970146389244305`, 0.9353598405880397],
              91 -> RGBColor[
              0.26262121251507564`, 0.39336192387290797`, 0.9382672615882417],
              105 -> 
             RGBColor[
              0.417344109662346, 0.5359042242898253, 0.9478137755181469], 36 -> 
             RGBColor[
              0.5196772960404508, 0.620936465977857, 0.9553300468664151], 123 -> 
             RGBColor[
              0.9742961343763916, 0.9803506796209057, 0.9283941192456544], 94 -> 
             RGBColor[
              0.26012396818175015`, 0.3907371617441472, 0.9381250472178008], 
             312 -> RGBColor[
              0.46295717480753656`, 0.5748885163486347, 0.9508648311503101], 
             96 -> RGBColor[
              0.2869114883454893, 0.4188925438631119, 0.939650556862541], 2 -> 
             RGBColor[
              0.8184511944421836, 0.14282954261339104`, 0.16530219067646573`],
              262 -> RGBColor[
              0.9386428604207964, 0.9537605262817009, 0.9887458121893573], 
             272 -> RGBColor[
              0.6470169280819229, 0.7241738088191627, 0.9654522587403933], 97 -> 
             RGBColor[
              0.44228444757308333`, 0.5575062914502744, 0.9494029517959442], 
             372 -> RGBColor[
              0.2514775053864574, 0.3816491811288898, 0.9376326439529042], 
             356 -> RGBColor[
              0.5183784049780293, 0.6198819676990077, 0.9552277934039866], 
             346 -> RGBColor[
              0.3450320119322843, 0.4732711197477559, 0.9432061125938647], 
             341 -> RGBColor[
              0.2215837127017966, 0.35022890964138337`, 0.935930236683416], 
             209 -> RGBColor[
              0.2520329891677718, 0.3822330298027571, 0.9376642779324855], 
             378 -> RGBColor[
              0.20852643568424656`, 0.3365048836167593, 0.9351866440737768], 
             66 -> RGBColor[
              0.9727828870163496, 0.9198524284034268, 0.3487670848893771], 
             139 -> RGBColor[
              0.2111706728502173, 0.3392841445325141, 0.9353372294685806], 56 -> 
             RGBColor[
              0.45093503134871465`, 0.5649989923257436, 0.9499541593447165], 
             335 -> RGBColor[
              0.28051817934621337`, 0.41217277074566994`, 0.9392864673730853],
              314 -> RGBColor[
              0.9258119809847409, 0.9436813594132142, 0.9927859673000785], 
             144 -> RGBColor[
              0.8784381059512442, 0.540897655273832, 0.22027811466207986`], 
             298 -> RGBColor[
              0.8234301328695646, 0.862044852807406, 0.9830206952294982], 204 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 207 -> 
             RGBColor[
              0.9398558182628138, 0.7992553918121872, 0.27046478349011155`], 
             334 -> 
             RGBColor[
              0.26139903658851843`, 0.39207733948366696`, 0.9381976604772716],
              149 -> RGBColor[
              0.22021863489519794`, 0.34879412631571627`, 0.9358524975217819],
              219 -> RGBColor[
              0.4471878440862639, 0.5617533670581167, 0.9497153918858607], 
             400 -> RGBColor[
              0.38961090759033284`, 0.5118831185663134, 0.9460466404056259], 
             9 -> RGBColor[
              0.8256674379376745, 0.1982967522977973, 0.17221247359732916`], 
             11 -> RGBColor[
              0.9234626618564741, 0.7342619893565898, 0.25727446504873397`], 
             44 -> RGBColor[
              0.29795654320818293`, 0.4305015968207284, 0.940279556397277], 
             153 -> RGBColor[
              0.3174307607246093, 0.4493643032308905, 0.9414473852737397], 32 -> 
             RGBColor[
              0.21628540957162948`, 0.3446600571197567, 0.9356285061582901], 
             162 -> RGBColor[
              0.246083996032968, 0.37598026083012825`, 0.9373254915742051], 
             90 -> RGBColor[
              0.7058058015575851, 0.7701001235903371, 0.9713117842351892], 
             331 -> RGBColor[
              0.45209247002133757`, 0.5660015075294104, 0.9500279103134532], 
             8 -> RGBColor[
              0.3103199544645186, 0.44320528024791445`, 0.9409942909866859], 
             364 -> RGBColor[
              0.34952976604112324`, 0.4771668482931376, 0.9434927055084721], 
             342 -> RGBColor[
              0.6033581995623302, 0.6888723932386622, 0.9619177141249072], 
             163 -> RGBColor[
              0.2449732495734328, 0.3748127958757636, 0.9372622362065367], 49 -> 
             RGBColor[
              0.2557363986193865, 0.3861255479461254, 0.9378751816220516], 
             338 -> RGBColor[
              0.9942883740099587, 0.9901917344782997, 0.6197029429328111], 76 -> 
             RGBColor[
              0.8469444359628041, 0.36184108275892934`, 0.19258735093512552`],
              369 -> RGBColor[
              0.25745394897088236`, 0.38793080226452953`, 0.9379729935736814],
              82 -> RGBColor[
              0.37921715493462604`, 0.5028805724211383, 0.9453843596772389], 
             67 -> RGBColor[
              0.2129458677257866, 0.3411499869005934, 0.9354383241905787], 
             211 -> RGBColor[
              0.2626771974737526, 0.39342076761412886`, 
               0.9382704498488161]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9l3k0VX/Yxa95Hq55dufJNVwqktwdKpWiSIU0EZFIxkiFhGRKk6SkQSmp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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 7}], {
             RGBColor[
             0.37469401379728373`, 0.4989628549076562, 0.945096149123624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 35}], {
             RGBColor[
             0.32051204203418227`, 0.44947164236999554`, 0.9417375112912428]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 41}], {
             RGBColor[
             0.3504016747423545, 0.4779220517867386, 0.943548262759916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 57}], {
             RGBColor[
             0.31659522838756854`, 0.44535482288707584`, 0.9415144545484747]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 92}], {
             RGBColor[
             0.3238234376355826, 0.4529521291016748, 0.9419260903719718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 96}], {
             RGBColor[
             0.32344726087306624`, 0.45255674347328584`, 0.9419046676618501]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 114}], {
             RGBColor[
             0.3444304570913155, 0.4727500831795342, 0.9431677820513322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 153}], {
             RGBColor[
             0.33870689706262624`, 0.4677926231571751, 0.9428030818674495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 154}], {
             RGBColor[
             0.39507053133992803`, 0.5166119702495444, 0.9463945228031945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 161}], {
             RGBColor[
             0.3957098398241182, 0.5171657071259712, 0.9464352589744887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 188}], {
             RGBColor[
             0.3135344759290187, 0.4421377779902256, 0.9413401492239378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 203}], {
             RGBColor[
             0.32569030455946724`, 0.45491432460487713`, 0.9420324056815049]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 222}], {
             RGBColor[
             0.48245496695292606`, 0.5881834392083616, 0.9530999932353155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 312}], {
             RGBColor[
             0.4114701041040899, 0.5305547297160472, 0.9475118048057347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 327}], {
             RGBColor[
             0.3392875835527789, 0.4682955846087937, 0.9428400826971212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 337}], {
             RGBColor[
             0.3223631828098259, 0.4514173086943011, 0.9418429310198984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 356}], {
             RGBColor[
             0.43918071918933627`, 0.5530514553912338, 0.949693285932573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 361}], {
             RGBColor[
             0.35780477718256065`, 0.4843342470296975, 0.9440199819010995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 66}], {
             RGBColor[
             0.8956170407292666, 0.531340985508409, 0.2570346377829214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 98}], {
             RGBColor[
             0.8980106482873484, 0.5394151858476, 0.26633335115120993`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 106}], {
             RGBColor[
             0.8834730056375308, 0.5519688209280622, 0.5686856052309635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 107}], {
             RGBColor[
             0.828834437069773, 0.222639695414975, 0.17524519554284063`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 197}], {
             RGBColor[
             0.9036013141673853, 0.5662229928500411, 0.5006917858198119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 215}], {
             RGBColor[
             0.8188696957350476, 0.14604632693877936`, 0.16570294798714186`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 283}], {
             RGBColor[
             0.8636832468154017, 0.4097080433065882, 0.20543575312607748`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 352}], {
             RGBColor[
             0.9063026650036, 0.5663670773157738, 0.3851970536504771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 52}], {
             RGBColor[
             0.3783625716146186, 0.5021403753019544, 0.9453299063837663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 86}], {
             RGBColor[
             0.33530800642617503`, 0.4640896371481913, 0.9426142996527203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 117}], {
             RGBColor[
             0.35979838664313185`, 0.4860610113427193, 0.9441470129330474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 174}], {
             RGBColor[
             0.5493425209245979, 0.6414387311936623, 0.9591931799908751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 232}], {
             RGBColor[
             0.4478181508511241, 0.5603378585517222, 0.9502975085529524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 309}], {
             RGBColor[
             0.32043505349243634`, 0.4484572206151509, 0.9417673069857059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 371}], {
             RGBColor[
             0.3210626317693298, 0.4491168451749269, 0.9418030466401561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 386}], {
             RGBColor[
             0.35472139925516205`, 0.48166358004406556`, 0.9438235117860897]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 16}], {
             RGBColor[
             0.23702850407735238`, 0.36646236463342485`, 0.9368097947037326]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 73}], {
             RGBColor[
             0.23765623707057423`, 0.3671221518098715, 0.9368455431690489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 115}], {
             RGBColor[
             0.23540129852856206`, 0.36475206843085556`, 0.936717127754964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 188}], {
             RGBColor[
             0.24964120798061978`, 0.37971911612737436`, 0.9375280695322004]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 195}], {
             RGBColor[
             0.2389456018045329, 0.3684773558957079, 0.9369189705832036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 206}], {
             RGBColor[
             0.23187928370438585`, 0.3610502075420088, 0.9365165542210812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 208}], {
             RGBColor[
             0.23264160776787357`, 0.36185145846687167`, 0.9365599674487393]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 258}], {
             RGBColor[
             0.24256487951038092`, 0.3722814462400146, 0.9371250830943101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 278}], {
             RGBColor[
             0.24230606056995913`, 0.37200941112356267`, 0.9371103437385414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 284}], {
             RGBColor[
             0.23809729374437577`, 0.3675857303386453, 0.936870660694137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 369}], {
             RGBColor[
             0.2448252232373639, 0.37465721081114345`, 0.937253806325683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 392}], {
             RGBColor[
             0.24007285485442642`, 0.3696621703231174, 0.9369831659767736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 99}], {
             RGBColor[
             0.9097853137766493, 0.92980801321679, 0.9533236132867424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 174}], {
             RGBColor[
             0.7850242052221269, 0.8321595879372474, 0.979161507318894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 193}], {
             RGBColor[
             0.8318913190108279, 0.8687915729636699, 0.983827730717042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 223}], {
             RGBColor[
             0.6477551093793219, 0.7220395366342189, 0.9674518801311646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 235}], {
             RGBColor[
             0.7907683520113988, 0.8366469590661592, 0.9797340301887447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 260}], {
             RGBColor[
             0.8251985302055844, 0.863544075950503, 0.9831657085828327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 267}], {
             RGBColor[
             0.7063209858486378, 0.7695859535146778, 0.9720624004607035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 272}], {
             RGBColor[
             0.744229977263282, 0.800290827008182, 0.9750955199196911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 275}], {
             RGBColor[
             0.916771833602923, 0.9337046356973782, 0.882657568389807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 291}], {
             RGBColor[
             0.7689673032381015, 0.8196158140703518, 0.9775611053894065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 321}], {
             RGBColor[
             0.8296147450427847, 0.8669940565457998, 0.9836058756059307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 338}], {
             RGBColor[
             0.9178657002272999, 0.9332997898377504, 0.8022208620159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 384}], {
             RGBColor[
             0.7949354326614759, 0.8399023141409853, 0.9801493658443617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 398}], {
             RGBColor[
             0.8904342144946242, 0.9153759950567726, 0.9860799767962038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 13}], {
             RGBColor[
             0.978563836078469, 0.9803436260913665, 0.7317471315868381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 18}], {
             RGBColor[
             0.9692770544063248, 0.9734175595259907, 0.7474672305772001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 74}], {
             RGBColor[
             0.909010509687477, 0.9256078266033538, 0.7502192883025007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 102}], {
             RGBColor[
             0.9063222891856516, 0.5687552194511105, 0.3417057295474893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 132}], {
             RGBColor[
             0.896284952197167, 0.9156286210821021, 0.7489609820272407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 160}], {
             RGBColor[
             0.9114125623801264, 0.6078812897957802, 0.3465801809071596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 166}], {
             RGBColor[
             0.9090583234505556, 0.5897855777490221, 0.34432575904947005`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 185}], {
             RGBColor[
             0.9085190133388343, 0.5856402039031354, 0.34380931507742224`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 198}], {
             RGBColor[
             0.9099185860419527, 0.9263319020393368, 0.75030590143584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 213}], {
             RGBColor[
             0.9521578283629528, 0.8364523308595698, 0.38226017426140096`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 216}], {
             RGBColor[
             0.8262245586177389, 0.8608969091391403, 0.7419780167468455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 224}], {
             RGBColor[
             0.9845045256450395, 0.9588710430060774, 0.43862463761941295`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 247}], {
             RGBColor[
             0.9501775412917424, 0.8286011525137683, 0.3806667888005933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 289}], {
             RGBColor[
             0.9455504255792939, 0.808391434737298, 0.3768472415142159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 302}], {
             RGBColor[
             0.9903122885265428, 0.9784619909329613, 0.461186699710061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 323}], {
             RGBColor[
             0.9117788938600264, 0.9278152609967583, 0.7504833392562442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 340}], {
             RGBColor[
             0.9935628356137232, 0.988639881211936, 0.5407325660065214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 40}], {
             RGBColor[
             0.36435856265805855`, 0.4900108066057379, 0.9444375833163132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 41}], {
             RGBColor[
             0.36511265513899505`, 0.490663963610935, 0.9444856334223808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 80}], {
             RGBColor[
             0.36191069619973304`, 0.48789058771288196`, 0.9442816074301521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 96}], {
             RGBColor[
             0.3381582412697068, 0.46529865529748227`, 0.9428420383243149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 114}], {
             RGBColor[
             0.359141437487956, 0.48549199500373064`, 0.9441051527137969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 153}], {
             RGBColor[
             0.3534178774592668, 0.48053453498137155`, 0.9437404525299142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 154}], {
             RGBColor[
             0.40978151173656857`, 0.5293538820737408, 0.9473318934656592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 192}], {
             RGBColor[
             0.36694736915401993`, 0.4922531006753419, 0.9446025397770442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 203}], {
             RGBColor[
             0.3404012849561078, 0.4676562364290735, 0.9429697763439697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 222}], {
             RGBColor[
             0.4971659473495666, 0.600925351032558, 0.9540373638977802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 228}], {
             RGBColor[
             0.37863108577837257`, 0.5023729487746839, 0.9453470158688431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 312}], {
             RGBColor[
             0.42618108450073044`, 0.5432966415402436, 0.9484491754681994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 332}], {
             RGBColor[
             0.45831330080032634`, 0.5693830222721039, 0.9509787412394903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 356}], {
             RGBColor[
             0.4538916995859768, 0.5657933672154302, 0.9506306565950378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 361}], {
             RGBColor[
             0.3725157575792012, 0.497076158853894, 0.9449573525635642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 385}], {
             RGBColor[
             0.4824130197414953, 0.5889482597885108, 0.9528759593947184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 17}], {
             RGBColor[
             0.42291827954092154`, 0.5385004052405986, 0.9487856331227857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 21}], {
             RGBColor[
             0.3116185481608299, 0.44433005683844234`, 0.9410770362287135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 36}], {
             RGBColor[
             0.41499862525248465`, 0.5320708731128857, 0.9481621689265505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 60}], {
             RGBColor[
             0.33392414851101215`, 0.4636500467496988, 0.9424983293589592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 64}], {
             RGBColor[
             0.3546401133620532, 0.4815931742890025, 0.9438183323208591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 82}], {
             RGBColor[
             0.34476855469957235`, 0.4730429263345264, 0.9431893253319623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 157}], {
             RGBColor[
             0.38978189814954545`, 0.5115987980501094, 0.9461770157970921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 171}], {
             RGBColor[
             0.2917662705538139, 0.42384970493064567`, 0.9399323578314926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 182}], {
             RGBColor[
             0.29920713316336395`, 0.4316705233112208, 0.9403561039493367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 210}], {
             RGBColor[
             0.30512183219392025`, 0.43788724700591375`, 0.9406929373091137]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 253}], {
             RGBColor[
             0.3260178665234107, 0.4568020226733255, 0.9419945480619598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 61}], {
             RGBColor[
             0.9095066708030527, 0.5932363190069687, 0.34466666805378354`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 131}], {
             RGBColor[
             0.8740668087143025, 0.4643040105665355, 0.21434257277214977`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 142}], {
             RGBColor[
             0.8236257057163587, 0.18260310375199956`, 0.1702573085163904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 202}], {
             RGBColor[
             0.8410035318945833, 0.31617669076982174`, 0.1868983344901058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 214}], {
             RGBColor[
             0.9047202658222255, 0.5928576663351037, 0.5422822863417485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 215}], {
             RGBColor[
             0.822477817482793, 0.1737799317809825, 0.1691580894475736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 217}], {
             RGBColor[
             0.8242465537218799, 0.18737521357976708`, 0.17085183326762515`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 269}], {
             RGBColor[
             0.909363183463878, 0.5929294140972693, 0.329048956685827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 279}], {
             RGBColor[
             0.8856585389447988, 0.5102613582153388, 0.22366955100848618`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 300}], {
             RGBColor[
             0.8578321079350941, 0.3958398187210729, 0.2010677137447785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 306}], {
             RGBColor[
             0.8980217768542582, 0.5550152880766823, 0.25581485333926096`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 363}], {
             RGBColor[
             0.8440899658094313, 0.333439960887275, 0.18960093350439794`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 39}], {
             RGBColor[
             0.3175089705748625, 0.446135594734304, 0.9415730679165266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 177}], {
             RGBColor[
             0.34191718866131093`, 0.47057321638600846`, 0.9430076388093683]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 189}], {
             RGBColor[
             0.3312363099818102, 0.46056389881459425`, 0.9423548195879734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 200}], {
             RGBColor[
             0.31629276558560215`, 0.4448572861787412, 0.9415038068416022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 216}], {
             RGBColor[
             0.5105137254220357, 0.6107590812291837, 0.9554696590225349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 219}], {
             RGBColor[
             0.4045568603314619, 0.5248285516252523, 0.9469989832981036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 241}], {
             RGBColor[
             0.32644391245681637`, 0.4555267851602728, 0.9420818996386419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 296}], {
             RGBColor[
             0.331723708667086, 0.46107618573568054`, 0.9423825762220581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 311}], {
             RGBColor[
             0.4406499577202704, 0.5542970021663628, 0.9497943740304772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 339}], {
             RGBColor[
             0.3638431893323356, 0.48956441613441326`, 0.9444047441837249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 360}], {
             RGBColor[
             0.336158799712734, 0.4655855893037951, 0.9426407193575084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 374}], {
             RGBColor[
             0.31901480157328777`, 0.4477183185888486, 0.9416588227642095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 14}], {
             RGBColor[
             0.9589098698169762, 0.8623003371232989, 0.4422276945427869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 25}], {
             RGBColor[
             0.8860868883930885, 0.5548412704093811, 0.2257767948788701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 38}], {
             RGBColor[
             0.9446269367354516, 0.8152649274529434, 0.2894401056343812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 78}], {
             RGBColor[
             0.8826533057204708, 0.5284492493821207, 0.22248879223389445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 102}], {
             RGBColor[
             0.8713798486298555, 0.4417965181232547, 0.21169331699237254`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 144}], {
             RGBColor[
             0.9009503839038591, 0.6375798223152109, 0.23877628985540691`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 205}], {
             RGBColor[
             0.9593655870867921, 0.8632867059265485, 0.49267549542961175`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 207}], {
             RGBColor[
             0.931659240059644, 0.7667586905843885, 0.26386962426942273`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 213}], {
             RGBColor[
             0.9172153878071567, 0.709493629531714, 0.2522477617062842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 221}], {
             RGBColor[
             0.9226607888866434, 0.8373956409938654, 0.6248416927368453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 230}], {
             RGBColor[
             0.9461599473200244, 0.8204361321227099, 0.29539556227068897`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 250}], {
             RGBColor[
             0.9558449394073578, 0.8618308276345842, 0.5510217386219683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 289}], {
             RGBColor[
             0.9106079850234978, 0.6814327334094423, 0.24683482895909917`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 358}], {
             RGBColor[
             0.9460196672175634, 0.8199629343977746, 0.2948506005623025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 391}], {
             RGBColor[
             0.8719267260498035, 0.4460000576161881, 0.2122170074273244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 118}], {
             RGBColor[
             0.21224930323971947`, 0.34041785346099757`, 0.9353986558735721]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 126}], {
             RGBColor[
             0.2152393660615204, 0.3435605990676429, 0.935568935527872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 149}], {
             RGBColor[
             0.21932780961758047`, 0.3478578124673555, 0.9358017663400795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 199}], {
             RGBColor[
             0.22211987446733733`, 0.350792449651586, 0.9359607703027832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 212}], {
             RGBColor[
             0.2146670795751315, 0.34295908968538924`, 0.9355363446590942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 238}], {
             RGBColor[
             0.22383004590865202`, 0.3525899482675398, 0.9360581620363942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 259}], {
             RGBColor[
             0.2147288372822968, 0.3430240009512847, 0.9355398616691548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 274}], {
             RGBColor[
             0.2245824786939262, 0.35338080283185697`, 0.936101011970391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 299}], {
             RGBColor[
             0.21628284341415968`, 0.3446573599255522, 0.9356283600194184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 318}], {
             RGBColor[
             0.2211272263803799, 0.3497491135746699, 0.9359042404627222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 336}], {
             RGBColor[
             0.21472177259901426`, 0.343016575521228, 0.9355394593458932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 367}], {
             RGBColor[
             0.21887583976336028`, 0.3473827634940262, 0.9357760273255111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 18}], {
             RGBColor[
             0.9544933475167275, 0.9655817936050558, 0.9619150720050708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 69}], {
             RGBColor[
             0.7259993754166094, 0.7839523785382002, 0.9495242388978706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 74}], {
             RGBColor[
             0.8942268027978797, 0.9177720606824189, 0.9646671297303714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 88}], {
             RGBColor[
             0.9770469480723544, 0.9813851840644524, 0.8781922259657269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 132}], {
             RGBColor[
             0.8815012453075697, 0.9077928551611671, 0.9634088234551113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 140}], {
             RGBColor[
             0.8178525622986523, 0.8580700202466935, 0.9570649175635426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 191}], {
             RGBColor[
             0.8213167457883995, 0.8607762667176537, 0.9574101949991654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 198}], {
             RGBColor[
             0.8951348791523555, 0.9184961361184019, 0.9647537428637106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 216}], {
             RGBColor[
             0.8114408517281416, 0.8530611432182054, 0.956425858174716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 224}], {
             RGBColor[
             0.9697208187554422, 0.9510352770851425, 0.6530724790472836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 302}], {
             RGBColor[
             0.9755285816369456, 0.9706262250120263, 0.6756345411379316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 323}], {
             RGBColor[
             0.8969951869704291, 0.9199794950758233, 0.9649311806841149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 340}], {
             RGBColor[
             0.9787791287241259, 0.9808041152910011, 0.7551804074343922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 357}], {
             RGBColor[
             0.8197351159980406, 0.8595406855045937, 0.9572525529228332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 38}], {
             RGBColor[
             0.9800741446959539, 0.9433032752196526, 0.4743933351284341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 102}], {
             RGBColor[
             0.9068270565903578, 0.5698348658899638, 0.39664654648642544`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 205}], {
             RGBColor[
             0.9948127950472943, 0.9913250536932577, 0.6776287249236647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 207}], {
             RGBColor[
             0.9671064480201461, 0.8947970383510977, 0.44882285376347564`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 213}], {
             RGBColor[
             0.9526625957676589, 0.8375319772984231, 0.4372009912003371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 224}], {
             RGBColor[
             0.9850092930497456, 0.9599506894449308, 0.4935654545583491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 230}], {
             RGBColor[
             0.9816071552805266, 0.9484744798894191, 0.4803487917647419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 247}], {
             RGBColor[
             0.9506823086964485, 0.8296807989526216, 0.43560760573952945`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 250}], {
             RGBColor[
             0.99129214736786, 0.9898691754012934, 0.7359749681160213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 289}], {
             RGBColor[
             0.9460551929840001, 0.8094710811761514, 0.43178805845315205`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 340}], {
             RGBColor[
             0.9940676030184292, 0.9897195276507893, 0.5956733829454577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 391}], {
             RGBColor[
             0.9073739340103057, 0.5740384053828973, 0.3971702369213773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 45}], {
             RGBColor[
             0.29968000514429743`, 0.4323130645893829, 0.9403777050049051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 100}], {
             RGBColor[
             0.34023750094859895`, 0.4686666959527124, 0.9429171480552854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 105}], {
             RGBColor[
             0.36060251301143975`, 0.486305845826277, 0.9442147886158565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.3163910437219365, 0.4480120932607672, 0.9413976728873965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 155}], {
             RGBColor[
             0.30420326810120896`, 0.4370673007485326, 0.9406352981387334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 170}], {
             RGBColor[
             0.3744152758657625, 0.49826976676104406`, 0.9450949256507872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 180}], {
             RGBColor[
             0.33506546922916314`, 0.4641869420312098, 0.9425875907675709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 183}], {
             RGBColor[
             0.281397272925088, 0.41309675383481925`, 0.9393365304518997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 239}], {
             RGBColor[
             0.3141879177885835, 0.4461038563096259, 0.9412572916510711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 271}], {
             RGBColor[
             0.3053243996883596, 0.43824568113047624`, 0.940699144924056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 273}], {
             RGBColor[
             0.28964915667663804`, 0.4217700068573468, 0.9398064630239824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 326}], {
             RGBColor[
             0.3216255760176605, 0.45254598204008034`, 0.9417312126565649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 335}], {
             RGBColor[
             0.2921895478533735, 0.4244401190541993, 0.9399511345433256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 394}], {
             RGBColor[
             0.33136443385417313`, 0.4609812912088401, 0.9423517640661736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 73}], {
             RGBColor[
             0.24248824364408117`, 0.372200897085539, 0.937120718795097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 85}], {
             RGBColor[
             0.2415839884274967, 0.3712504675198166, 0.9370692227982382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 96}], {
             RGBColor[
             0.2643859994981743, 0.3952168268861021, 0.9383677635961609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 110}], {
             RGBColor[
             0.2487192272457111, 0.3787500559180304, 0.9374755640932957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 115}], {
             RGBColor[
             0.240233305102069, 0.36983081370652304`, 0.936992303381012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 184}], {
             RGBColor[
             0.22981171473055614`, 0.35887706145906934`, 0.9363988092267157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 188}], {
             RGBColor[
             0.25447321455412675`, 0.38479786140304184`, 0.9378032451582485]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 203}], {
             RGBColor[
             0.2666290431845753, 0.3975744080176934, 0.9384955016158156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 206}], {
             RGBColor[
             0.23671129027789278`, 0.36612895281767627`, 0.9367917298471292]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 208}], {
             RGBColor[
             0.2374736143413805, 0.36693020374253915`, 0.9368351430747874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 258}], {
             RGBColor[
             0.24739688608388788`, 0.37736019151568206`, 0.9374002587203583]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 284}], {
             RGBColor[
             0.24292930031788273`, 0.3726644756143127, 0.9371458363201851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 325}], {
             RGBColor[
             0.22671411419860138`, 0.35562128690076766`, 0.9362224054589102]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 348}], {
             RGBColor[
             0.252407866634222, 0.38262704978860046`, 0.9376856266496183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 369}], {
             RGBColor[
             0.24965722981087085`, 0.3797359560868109, 0.9375289819517311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 392}], {
             RGBColor[
             0.24490486142793333`, 0.37474091559878486`, 0.9372583416028217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 36}], {
             RGBColor[
             0.5275969503288876, 0.6273659981055699, 0.9559535110626505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 64}], {
             RGBColor[
             0.46723843843845614`, 0.5768882992816866, 0.951609674456959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 82}], {
             RGBColor[
             0.4573668797759753, 0.5683380513272105, 0.9509806674680623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 122}], {
             RGBColor[
             0.490802095307585, 0.5972979545178956, 0.9531111298361363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 157}], {
             RGBColor[
             0.5023802232259484, 0.6068939230427937, 0.9539683579331921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 187}], {
             RGBColor[
             0.6897252223294911, 0.7560947412907055, 0.9707766661911668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 218}], {
             RGBColor[
             0.7227901892843811, 0.7824598484159166, 0.9739304322567687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 253}], {
             RGBColor[
             0.43861619159981363`, 0.5520971476660097, 0.9497858901980598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 262}], {
             RGBColor[
             0.7370797325190604, 0.7937780282574919, 0.9726613937241215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 298}], {
             RGBColor[
             0.6794733687434446, 0.7479201915203444, 0.969798835244192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 74}], {
             RGBColor[
             0.8849400211257357, 0.9108459941170431, 0.9803872287207334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 132}], {
             RGBColor[
             0.8722144636354254, 0.9008667885957915, 0.9791289224454733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 140}], {
             RGBColor[
             0.8085657806265083, 0.8511439536813179, 0.9727850165539047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 191}], {
             RGBColor[
             0.8120299641162554, 0.853850200152278, 0.9731302939895274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 198}], {
             RGBColor[
             0.8858480974802114, 0.9115700695530261, 0.9804738418540726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 216}], {
             RGBColor[
             0.8021540700559975, 0.8461350766528297, 0.9721459571650781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 224}], {
             RGBColor[
             0.960434037083298, 0.9441092105197667, 0.6687925780376456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 247}], {
             RGBColor[
             0.926107052730001, 0.8138393200274576, 0.6108347292188259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 302}], {
             RGBColor[
             0.9662417999648014, 0.9637001584466507, 0.6913546401282936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 311}], {
             RGBColor[
             0.7322903023542322, 0.7896729975900088, 0.9664706721730203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 323}], {
             RGBColor[
             0.8877084052982851, 0.9130534285104475, 0.9806512796744769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 340}], {
             RGBColor[
             0.9694923470519816, 0.9738780487256253, 0.770900506424754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 357}], {
             RGBColor[
             0.8104483343258964, 0.8526146189392179, 0.9729726519131952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 83}], {
             RGBColor[
             0.31363288900734776`, 0.44289778603368235`, 0.9413217134716801]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 108}], {
             RGBColor[
             0.3209765938651673, 0.4492585340761873, 0.9417896478514372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 125}], {
             RGBColor[
             0.27618503388558474`, 0.4076183601292589, 0.9390397011494167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 179}], {
             RGBColor[
             0.2720136332383074, 0.4032339535668936, 0.9388021460535885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 196}], {
             RGBColor[
             0.2861541125436652, 0.4180964938749955, 0.9396074254310642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 231}], {
             RGBColor[
             0.2915341164557601, 0.4237512190985569, 0.9399138086948555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 303}], {
             RGBColor[
             0.2819979246761117, 0.4137280769086658, 0.939370736680536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 313}], {
             RGBColor[
             0.27859623109563336`, 0.41015268127575305`, 0.9391770152634824]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 344}], {
             RGBColor[
             0.2975063791842545, 0.4289298137668702, 0.9402941465258654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 50}], {
             RGBColor[
             0.4309033063250306, 0.5476259924741631, 0.9486839796675377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 54}], {
             RGBColor[
             0.4298252331165606, 0.5467147461063611, 0.9486090616680254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 116}], {
             RGBColor[
             0.4119401607737857, 0.531223595372923, 0.9474694406734923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 121}], {
             RGBColor[
             0.48042756078829996`, 0.5878320132896839, 0.9525827103922078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 130}], {
             RGBColor[
             0.4090322853711047, 0.5287049398531881, 0.9472841534241666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 135}], {
             RGBColor[
             0.45546851492086315`, 0.5675691354622958, 0.9506178428735257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 147}], {
             RGBColor[
             0.34619840677068126`, 0.47206167326583015`, 0.9433617090301424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 158}], {
             RGBColor[
             0.4553874406509526, 0.5675033157176284, 0.9506114604100135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 172}], {
             RGBColor[
             0.3545418209166673, 0.4808311305362721, 0.9438368541227812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 181}], {
             RGBColor[
             0.4874856363228792, 0.5935620769713348, 0.9531383479528726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 265}], {
             RGBColor[
             0.49977683892029745`, 0.6035406289522859, 0.9541059564454999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 322}], {
             RGBColor[
             0.45803755349750475`, 0.5696547967126826, 0.9508200870009773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 328}], {
             RGBColor[
             0.3585480828066595, 0.484978061001665, 0.9440673446781876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 347}], {
             RGBColor[
             0.3438545327447645, 0.469598113054395, 0.9432282288718172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 362}], {
             RGBColor[
             0.406159003588231, 0.5262162475882044, 0.9471010704497052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 364}], {
             RGBColor[
             0.37859437323609996`, 0.5023411502157933, 0.945344676578113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 387}], {
             RGBColor[
             0.3506138656824209, 0.476702600538333, 0.94361316288308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 36}], {
             RGBColor[
             0.416297218948796, 0.5331956497034136, 0.948244914168578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 60}], {
             RGBColor[
             0.33522274220732345`, 0.4647748233402267, 0.9425810746009868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 64}], {
             RGBColor[
             0.3559387070583645, 0.4827179508795304, 0.9439010775628867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 82}], {
             RGBColor[
             0.34606714839588365`, 0.4741677029250543, 0.94327207057399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 122}], {
             RGBColor[
             0.37950236392749337`, 0.5031276061157393, 0.9454025329420639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 159}], {
             RGBColor[
             0.3221758681761928, 0.45347427680941704`, 0.9417497393246208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 182}], {
             RGBColor[
             0.30050572685967525`, 0.4327952999017487, 0.9404388491913643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 210}], {
             RGBColor[
             0.30642042589023155`, 0.43901202359644165`, 0.9407756825511414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 263}], {
             RGBColor[
             0.2875003760669833, 0.4191258516317633, 0.9396982137034129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 29}], {
             RGBColor[
             0.2663738031073146, 0.39730613451333674`, 0.9384809660710094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 45}], {
             RGBColor[
             0.2939087453063859, 0.4262471045807297, 0.94004904029495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 91}], {
             RGBColor[
             0.2774698045998931, 0.40896873560916513`, 0.9391128669409485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 97}], {
             RGBColor[
             0.36730142212889694`, 0.4910409193978484, 0.9446807120447999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 100}], {
             RGBColor[
             0.3344662411106874, 0.46260073594405915`, 0.9425884833453301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 141}], {
             RGBColor[
             0.32619117202571163`, 0.45543328701971864`, 0.9420612032605917]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 150}], {
             RGBColor[
             0.28145958694833023`, 0.41316224982418415`, 0.9393400791433381]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 189}], {
             RGBColor[
             0.29643257003583556`, 0.4288998043911114, 0.9401927683796281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 190}], {
             RGBColor[
             0.26671069132338054`, 0.3976602253883686, 0.938500151356533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 255}], {
             RGBColor[
             0.27639668732322686`, 0.40784082131182386`, 0.9390517544995772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 266}], {
             RGBColor[
             0.27365816407618504`, 0.40496245974678047`, 0.9388957996519403]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 273}], {
             RGBColor[
             0.28387789683872655`, 0.4157040468486936, 0.9394777983140272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 350}], {
             RGBColor[
             0.36253057369193453`, 0.4869086502715662, 0.9443767178010922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 365}], {
             RGBColor[
             0.27427955709376345`, 0.40561558320684826`, 0.9389311870650228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 394}], {
             RGBColor[
             0.32559317401626164`, 0.45491533120018696`, 0.9420230993562184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 81}], {
             RGBColor[
             0.2165666874460731, 0.34495569799984427`, 0.9356445245171263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 89}], {
             RGBColor[
             0.21600037669219402`, 0.3443604694913417, 0.9356122739574746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 163}], {
             RGBColor[
             0.22919558870789478`, 0.35822947394460614`, 0.9363637217612019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 164}], {
             RGBColor[
             0.22797821780387265`, 0.3569499399387055, 0.9362943942891566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 169}], {
             RGBColor[
             0.21705819820147026`, 0.34547230696734843`, 0.9356725153275212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 227}], {
             RGBColor[
             0.22416996966139735`, 0.3529472296840859, 0.936077520191241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 245}], {
             RGBColor[
             0.22165838805798918`, 0.35030739817543277`, 0.9359344893344789]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 292}], {
             RGBColor[
             0.21221830344661968`, 0.3403852707129492, 0.9353968904812151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 304}], {
             RGBColor[
             0.2162581809318601, 0.34463143809296365`, 0.9356269555275363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 353}], {
             RGBColor[
             0.21189878814995255`, 0.34004943987771225`, 0.9353786945577505]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 378}], {
             RGBColor[
             0.21097218176330165`, 0.339075517815104, 0.9353259256948219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 25}], {
             RGBColor[
             0.8754320696783777, 0.5120010563873596, 0.21717277432657275`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 76}], {
             RGBColor[
             0.8745487301949283, 0.505211322035738, 0.2163268874396324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 104}], {
             RGBColor[
             0.9180135558932775, 0.712060691693382, 0.25285908317008815`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 109}], {
             RGBColor[
             0.9481247371168586, 0.8202041529201762, 0.49378352937662584`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 138}], {
             RGBColor[
             0.8607479504188854, 0.399132481136813, 0.2031112451403423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 144}], {
             RGBColor[
             0.8902955651891483, 0.5947396082931894, 0.23017226930310958`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 207}], {
             RGBColor[
             0.9210044213449331, 0.723918476562367, 0.2552656037171254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 233}], {
             RGBColor[
             0.8598056285506199, 0.3918893823292492, 0.202208876655091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 242}], {
             RGBColor[
             0.9102499321760205, 0.681280510728698, 0.24661228929151274`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 317}], {
             RGBColor[
             0.946390043794504, 0.8194868126517976, 0.5225318869704552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 358}], {
             RGBColor[
             0.9353648485028525, 0.777122720375753, 0.28624658001000514`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 366}], {
             RGBColor[
             0.9017167350633479, 0.6466004732099342, 0.2397023734046333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 382}], {
             RGBColor[
             0.9004669733536322, 0.6409255971753784, 0.23865954159958375`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[
             0.8478277754462535, 0.3686308171105509, 0.1934332378220659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 104}], {
             RGBColor[
             0.8912926011446027, 0.575480186768195, 0.22996543355252164`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 109}], {
             RGBColor[
             0.9214037823681839, 0.6836236479949891, 0.47088987975905927`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 138}], {
             RGBColor[
             0.8340269956702107, 0.26255197621162585`, 0.18021759552277578`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 144}], {
             RGBColor[
             0.8635746104404736, 0.45815910336800225`, 0.20727861968554306`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 205}], {
             RGBColor[
             0.9219898136234065, 0.68386598697934, 0.46117782525974793`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 207}], {
             RGBColor[
             0.8942834665962583, 0.5873379716371798, 0.2323719540995589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 233}], {
             RGBColor[
             0.8330846738019452, 0.25530887740406205`, 0.17931522703752448`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 317}], {
             RGBColor[
             0.9196690890458292, 0.6829063077266104, 0.4996382373528887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 358}], {
             RGBColor[
             0.9086438937541778, 0.640542215450566, 0.2633529303924386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 366}], {
             RGBColor[
             0.8749957803146731, 0.510019968284747, 0.21680872378706678`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 382}], {
             RGBColor[
             0.8737460186049575, 0.5043450922501913, 0.21576589198201723`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 391}], {
             RGBColor[
             0.8345509525864179, 0.2665793386689794, 0.18071933725746053`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 30}], {
             RGBColor[
             0.31701994287924884`, 0.4369570883961569, 0.9418741496415883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 62}], {
             RGBColor[
             0.31709055637755623`, 0.43703130766003234`, 0.9418781709758536]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 77}], {
             RGBColor[
             0.6422389788407158, 0.7176486903810251, 0.9669170377654001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 106}], {
             RGBColor[
             0.7018038352541023, 0.7648141211568, 0.9611581586207743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 111}], {
             RGBColor[
             0.6645955027358419, 0.5448101324102603, 0.5834436797495368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 160}], {
             RGBColor[
             0.6422952177337565, 0.39805166532506286`, 0.5630541845557195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 166}], {
             RGBColor[
             0.6399409788041857, 0.37995595327830467`, 0.56079976269803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 173}], {
             RGBColor[
             0.34074023236907375`, 0.46188861660318076`, 0.9432249850370102]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 185}], {
             RGBColor[
             0.6394016686924645, 0.37581057943241813`, 0.5602833187259821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 197}], {
             RGBColor[
             0.7219321437839568, 0.7790682930787789, 0.8931643392096228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 204}], {
             RGBColor[
             0.3170199268376633, 0.4369570715354334, 0.9418741487280438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 345}], {
             RGBColor[
             0.3285301240705917, 0.4490550186158963, 0.9425296374326482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 370}], {
             RGBColor[
             0.6431647387570222, 0.7183868662092043, 0.9670053375726531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 389}], {
             RGBColor[
             0.31710049015279534`, 0.4370417486876464, 0.9418787366896577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 400}], {
             RGBColor[
             0.4223618806328297, 0.5402016308185901, 0.9481469689308566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 51}], {
             RGBColor[
             0.33517005330446453`, 0.4636817173337682, 0.9426160703012283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 194}], {
             RGBColor[
             0.3427358884343137, 0.47023486345331306`, 0.943098158625497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 277}], {
             RGBColor[
             0.277614773953709, 0.4091211075916136, 0.9391211227311855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 287}], {
             RGBColor[
             0.27881505582512084`, 0.4103826799407336, 0.9391894770081045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 376}], {
             RGBColor[
             0.3679050083022842, 0.49203509004620194`, 0.9447019126873052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 377}], {
             RGBColor[
             0.3561480526956704, 0.48185180602152367`, 0.9439527698723194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 395}], {
             RGBColor[
             0.28524240829505776`, 0.41713823490432095`, 0.9395555052228516]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 396}], {
             RGBColor[
             0.28785811658992677`, 0.419887510167713, 0.9397044659406507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 44}], {
             RGBColor[
             0.29312282823703784`, 0.42542105591082463`, 0.9400042834805107]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 47}], {
             RGBColor[
             0.3610905157265072, 0.4852888096589335, 0.9442985989042187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 49}], {
             RGBColor[
             0.27201275594263963`, 0.40323303147352313`, 0.938802096092898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 147}], {
             RGBColor[
             0.2865134731880893, 0.418474204697066, 0.9396278904881377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 211}], {
             RGBColor[
             0.2754831553698227, 0.4068806413075249, 0.9389997302062802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 301}], {
             RGBColor[
             0.27255350960952185`, 0.40380139786317903`, 0.9388328912142536]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 328}], {
             RGBColor[
             0.2988631492240676, 0.4313905924329009, 0.9403335261361829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 347}], {
             RGBColor[
             0.28416959916217255`, 0.4160106444856309, 0.9394944103298126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 362}], {
             RGBColor[
             0.34647407000563907`, 0.4726287790194402, 0.9433672519077005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 372}], {
             RGBColor[
             0.2698833093261751, 0.4009948480649053, 0.9386808272583244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 380}], {
             RGBColor[
             0.2768898890919296, 0.40835920764152867`, 0.9390798416106783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 390}], {
             RGBColor[
             0.2772941937947283, 0.40878415751856884`, 0.9391028661653874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 45}], {
             RGBColor[
             0.26796415172899, 0.39897769174864406`, 0.938571534072304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 91}], {
             RGBColor[
             0.25152521102249714`, 0.3816993227770795, 0.9376353607183026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 150}], {
             RGBColor[
             0.2555149933709343, 0.38589283699209853`, 0.937862572920692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 190}], {
             RGBColor[
             0.2407660977459846, 0.370390812556283, 0.937022645133887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 226}], {
             RGBColor[
             0.23953161826969796`, 0.36909329635618626`, 0.936952343353961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 266}], {
             RGBColor[
             0.2477135704987891, 0.37769304691469485`, 0.9374182934292943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 273}], {
             RGBColor[
             0.25793330326133057`, 0.388434634016608, 0.9380002920913812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 365}], {
             RGBColor[
             0.24833496351636752`, 0.37834617037476265`, 0.9374536808423768]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 62}], {
             RGBColor[
             0.17899764558147852`, 0.30546825298532254`, 0.9335050231613544]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 77}], {
             RGBColor[
             0.5041460680446381, 0.5860856357063153, 0.9585438899509009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 84}], {
             RGBColor[
             0.1789270231889713, 0.3053940243730791, 0.9335010013205776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 204}], {
             RGBColor[
             0.17892701604158556`, 0.30539401686072354`, 0.9335010009135446]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 333}], {
             RGBColor[
             0.1872437438170861, 0.31413542506377157`, 0.9339746262568631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 370}], {
             RGBColor[
             0.5050718279609444, 0.5868238115344944, 0.9586321897581539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 389}], {
             RGBColor[
             0.17900757935671766`, 0.3054786940129366, 0.9335055888751587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 400}], {
             RGBColor[
             0.284268969836752, 0.4086385761438802, 0.9397738211163575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 33}], {
             RGBColor[0.1810793999809316, 0.30765630885, 0.9336235759947237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 106}], {
             RGBColor[
             0.5658561150624204, 0.6355057978202503, 0.9529071762376704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 156}], {
             RGBColor[
             0.18458847622123073`, 0.3113445704668384, 0.9338234126953957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 173}], {
             RGBColor[
             0.20479251217739197`, 0.3325802932666311, 0.9349740026539064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 175}], {
             RGBColor[
             0.18107477738655686`, 0.3076514502102228, 0.9336233127448126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 197}], {
             RGBColor[
             0.5859844235922751, 0.6497599697422292, 0.884913356826519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 204}], {
             RGBColor[
             0.1810722066459815, 0.3076487481988837, 0.9336231663449399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 214}], {
             RGBColor[
             0.5834952534993698, 0.6486610383850888, 0.9230487158880236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 261}], {
             RGBColor[
             0.18133289143212553`, 0.3079227444374911, 0.9336380119578622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 295}], {
             RGBColor[
             0.21280238164412135`, 0.34099917393122015`, 0.9354301528704966]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 310}], {
             RGBColor[
             0.18289778193115996`, 0.30956754357176464`, 0.9337271301567341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 345}], {
             RGBColor[
             0.1925824038789099, 0.3197466952793466, 0.9342786550495443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 43}], {
             RGBColor[
             0.2218603287150994, 0.3505196506098328, 0.9359459895561568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 124}], {
             RGBColor[
             0.21977833860588586`, 0.34833134699925217`, 0.9358274232994656]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 137}], {
             RGBColor[
             0.21892075175740905`, 0.34742996884735633`, 0.9357785849971308]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 199}], {
             RGBColor[
             0.22104408708317058`, 0.349661728901967, 0.9358995058027398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 238}], {
             RGBColor[
             0.22275425852448527`, 0.3514592275179208, 0.9359968975363508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 252}], {
             RGBColor[
             0.2203092674216852, 0.34888938684748844`, 0.9358576589100864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 293}], {
             RGBColor[
             0.2137582367821496, 0.342003838286004, 0.9354845874065463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 330}], {
             RGBColor[
             0.2205286799485376, 0.349120003324768, 0.935870154128899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 63}], {
             RGBColor[
             0.5687512197366357, 0.5886439817299056, 0.6135098819197802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 84}], {
             RGBColor[
             0.17893420048233583`, 0.30540156816347186`, 0.9335014100568169]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 90}], {
             RGBColor[
             0.44237359411374266`, 0.5377546224462848, 0.9524068017673784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 152}], {
             RGBColor[
             0.18127877637637368`, 0.30786586608280325`, 0.9336349301854932]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 156}], {
             RGBColor[
             0.18245046291019928`, 0.30909738291907096`, 0.9337016560002396]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 173}], {
             RGBColor[
             0.20265449886636056`, 0.33033310571886365`, 0.9348522459587503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 175}], {
             RGBColor[
             0.17893676407552545`, 0.30540426266245535`, 0.9335015560496566]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 204}], {
             RGBColor[
             0.1789341933349501, 0.3054015606511163, 0.9335014096497838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 214}], {
             RGBColor[
             0.5813572401883383, 0.6464138508373214, 0.9229269591928677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 256}], {
             RGBColor[
             0.202124876078153, 0.3297764385884332, 0.9348220847244686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 261}], {
             RGBColor[
             0.17919487812109408`, 0.3056755568897237, 0.9335162552627061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 264}], {
             RGBColor[
             0.18448620056776344`, 0.31123707227039327`, 0.9338175882482339]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 295}], {
             RGBColor[
             0.21066436833308994`, 0.3387519863834527, 0.9353083961753406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 310}], {
             RGBColor[
             0.18075976862012855`, 0.3073203560239972, 0.9336053734615781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 333}], {
             RGBColor[
             0.1872509211104506, 0.3141429688541644, 0.9339750349931024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 381}], {
             RGBColor[
             0.5860442078575524, 0.648421627973087, 0.8483684065741224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 53}], {
             RGBColor[
             0.30076648553276153`, 0.4331274488318972, 0.9404515726006413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 68}], {
             RGBColor[
             0.29450681654452554`, 0.42654813983932427`, 0.9400950937121118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 86}], {
             RGBColor[
             0.30641268277319833`, 0.4390619601211778, 0.940773115180684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 95}], {
             RGBColor[
             0.29703377047989377`, 0.4292041286435296, 0.9402390000004376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 151}], {
             RGBColor[
             0.31406226415390115`, 0.44644668080690353`, 0.9412327476508988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 244}], {
             RGBColor[
             0.2861625929026812, 0.4177778317374103, 0.9396199025198813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 249}], {
             RGBColor[
             0.2909291460215572, 0.4227877812822719, 0.9398913506685179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 253}], {
             RGBColor[
             0.3270023945629662, 0.4576547713773704, 0.9420572813180563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 270}], {
             RGBColor[
             0.28093807902462586`, 0.41228653639826196`, 0.9393223741835017]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 308}], {
             RGBColor[
             0.2866886948098787, 0.4183307981986623, 0.9396498632451982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 386}], {
             RGBColor[
             0.32582607560218535`, 0.4566359030170521, 0.9419823273140535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 397}], {
             RGBColor[
             0.28081927975955956`, 0.41216167083836874`, 0.939315608741104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 41}], {
             RGBColor[
             0.3109306833758936, 0.44117275107327436`, 0.9411269955899995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 57}], {
             RGBColor[
             0.2771242370211076, 0.4086055221736117, 0.9390931873785582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 92}], {
             RGBColor[
             0.28435244626912165`, 0.4162028283882106, 0.9395048232020553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 114}], {
             RGBColor[
             0.30495946572485455`, 0.43600078246607, 0.9407465148814157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 153}], {
             RGBColor[
             0.2992359056961653, 0.4310433224437109, 0.940381814697533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 188}], {
             RGBColor[
             0.27406348456255775`, 0.4053884772767613, 0.9389188820540213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 195}], {
             RGBColor[
             0.2633678783864708, 0.39414671704509485`, 0.9383097831050244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 208}], {
             RGBColor[
             0.25706388434981153`, 0.3875208196162586, 0.9379507799705602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 258}], {
             RGBColor[
             0.2669871560923189, 0.3979508073894016, 0.938515895616131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 278}], {
             RGBColor[
             0.26672833715189703`, 0.3976787722729497, 0.9385011562603622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 284}], {
             RGBColor[
             0.26251957032631373`, 0.3932550914880322, 0.9382614732159579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 327}], {
             RGBColor[
             0.29981659218631795`, 0.43154628389532945`, 0.9404188155272046]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 337}], {
             RGBColor[
             0.28289219144336497`, 0.41466800798083686`, 0.9394216638499819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 354}], {
             RGBColor[
             0.2804072432672092, 0.41205616989288285`, 0.9392801497275012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 369}], {
             RGBColor[
             0.26924749981930185`, 0.40032657196053045`, 0.9386446188475038]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 392}], {
             RGBColor[
             0.2644951314363644, 0.3953315314725043, 0.9383739784985945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 55}], {
             RGBColor[
             0.46160497467818506`, 0.5724389504821938, 0.9511318842995795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 60}], {
             RGBColor[
             0.4386028192989782, 0.5525156396146701, 0.9496662072988238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 64}], {
             RGBColor[
             0.45931878415001925`, 0.5704587671539738, 0.9509862102607236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 82}], {
             RGBColor[
             0.4494472254875384, 0.5619085191994977, 0.950357203271827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 122}], {
             RGBColor[
             0.4828824410191481, 0.5908684223901826, 0.952487665639901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 157}], {
             RGBColor[
             0.49446056893751156`, 0.6004643909150807, 0.9533448937369567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 165}], {
             RGBColor[
             0.5262130350709433, 0.6262424733544989, 0.9558445641840965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 218}], {
             RGBColor[
             0.7148705349959443, 0.7760303162882036, 0.9733069680605333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 262}], {
             RGBColor[
             0.7291600782306236, 0.787348496129779, 0.9720379295278863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 298}], {
             RGBColor[
             0.6715537144550077, 0.7414906593926315, 0.9691753710479567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 314}], {
             RGBColor[
             0.7227446385125958, 0.7823089126955356, 0.9740580070832467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 58}], {
             RGBColor[
             0.2743052593933725, 0.40564259795335733`, 0.9389326507729624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 87}], {
             RGBColor[
             0.2699691213947309, 0.4010850419897568, 0.9386857141286811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 110}], {
             RGBColor[
             0.2526887349083196, 0.3829222601527542, 0.9377016216823209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 134}], {
             RGBColor[
             0.24206319644531432`, 0.3717541455300861, 0.9370965129859282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 159}], {
             RGBColor[
             0.29061706023566036`, 0.4206896192842019, 0.9399383913431659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 167}], {
             RGBColor[
             0.26667449670074206`, 0.39762218254510395`, 0.9384980901263189]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 201}], {
             RGBColor[
             0.26311290635419504`, 0.3938787252730125, 0.9382952628249838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 236}], {
             RGBColor[
             0.2501608630823501, 0.3802653065873294, 0.9375576631214831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 243}], {
             RGBColor[
             0.2690857390615694, 0.4001565511479292, 0.9386354068116546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 263}], {
             RGBColor[
             0.25594156812645086`, 0.3863411941065481, 0.9378868657219579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 348}], {
             RGBColor[
             0.2563773742968305, 0.38679925402332427`, 0.9379116842386436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 351}], {
             RGBColor[
             0.2477720085286644, 0.3777544689892789, 0.9374216213886444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 78}], {
             RGBColor[
             0.9038175805994484, 0.6094521874784743, 0.2546544328195417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 102}], {
             RGBColor[
             0.8925441235088332, 0.5227994562196083, 0.24385895757801979`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 205}], {
             RGBColor[
             0.9805298619657696, 0.9442896440229023, 0.524841136015259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 207}], {
             RGBColor[
             0.9528235149386215, 0.8477616286807421, 0.29603526485507003`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 213}], {
             RGBColor[
             0.9383796626861343, 0.7904965676280676, 0.28441340229193146`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 221}], {
             RGBColor[
             0.9438250637656209, 0.9183985790902189, 0.6570073333224926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 224}], {
             RGBColor[
             0.970726359968221, 0.9129152797745752, 0.34077786564994345`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 230}], {
             RGBColor[
             0.9673242221990019, 0.9014390702190636, 0.3275612028563362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 247}], {
             RGBColor[
             0.9363993756149239, 0.7826453892822661, 0.2828200168311238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 250}], {
             RGBColor[
             0.9770092142863354, 0.9428337657309378, 0.5831873792076157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 289}], {
             RGBColor[
             0.9317722599024755, 0.7624356715057958, 0.27900046954474644`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 358}], {
             RGBColor[
             0.9671839420965409, 0.9009658724941282, 0.3270162411479497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 391}], {
             RGBColor[
             0.8930910009287811, 0.5270029957125417, 0.24438264801297166`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 93}], {
             RGBColor[
             0.2591650880555334, 0.38972931793498194`, 0.9380704404131488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 94}], {
             RGBColor[
             0.2666080163774077, 0.39755230751018356`, 0.9384943041702538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 119}], {
             RGBColor[
             0.2567952159774935, 0.3872384321223937, 0.9379354797042159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 128}], {
             RGBColor[
             0.2996526087721707, 0.4306693116276521, 0.9404352763322198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 177}], {
             RGBColor[
             0.29750028265951367`, 0.4288050749279245, 0.9402981320155486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 200}], {
             RGBColor[
             0.27187585958380484`, 0.4030891447206572, 0.9387943000477824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 225}], {
             RGBColor[
             0.26510008482719366`, 0.3959673758425263, 0.9384084296992539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 288}], {
             RGBColor[
             0.2590590279232666, 0.38961784201136873`, 0.9380644004455181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 296}], {
             RGBColor[
             0.2873068026652887, 0.4193080442775966, 0.9396730694282384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 316}], {
             RGBColor[
             0.26368578568270973`, 0.3944808577699287, 0.9383278874552436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 324}], {
             RGBColor[
             0.27652485948189337`, 0.40797553837716655`, 0.9390590537143996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 355}], {
             RGBColor[
             0.25200661552040216`, 0.3822053094271858, 0.9376627759922841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 360}], {
             RGBColor[
             0.29174189371093673`, 0.42381744784571107`, 0.9399312125636886]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 374}], {
             RGBColor[
             0.2745978955714905, 0.40595017713076464`, 0.9389493159703898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 375}], {
             RGBColor[
             0.2639687025623859, 0.39477822134843454`, 0.9383439991530031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 380}], {
             RGBColor[
             0.2692913647455158, 0.4003726767791782, 0.9386471168901593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 383}], {
             RGBColor[
             0.27666419535336334`, 0.408121989212486, 0.9390669886861509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 390}], {
             RGBColor[
             0.26969566944831447`, 0.40079762665621843`, 0.9386701414448686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 41}], {
             RGBColor[
             0.34006622360312927`, 0.4689700034848203, 0.942889696952605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 55}], {
             RGBColor[
             0.37142239221905604`, 0.496129140733077, 0.9448876842896408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 58}], {
             RGBColor[
             0.31906156196643076`, 0.449858262003899, 0.9415849314423156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 80}], {
             RGBColor[
             0.3368642646638673, 0.46619662758676733`, 0.9426856709603764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 87}], {
             RGBColor[
             0.31472542396778913`, 0.4453007060402985, 0.9413379947980343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 96}], {
             RGBColor[
             0.313111809733841, 0.4436046951713676, 0.9412461018545393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 110}], {
             RGBColor[
             0.29744503748137785`, 0.4271379242032959, 0.940353902351674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 146}], {
             RGBColor[
             0.43732168419070216`, 0.5509809435704429, 0.9497020146539848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 154}], {
             RGBColor[
             0.3847350802007028, 0.5076599219476261, 0.9457359569958835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 159}], {
             RGBColor[
             0.33537336280871854`, 0.46490528333474357`, 0.9425906720125191]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 167}], {
             RGBColor[
             0.31143079927380024`, 0.4418378465956456, 0.9411503707956721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 192}], {
             RGBColor[
             0.34190093761815415`, 0.4705591405492272, 0.9430066033072686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 203}], {
             RGBColor[
             0.31535485342024205`, 0.44596227630295887`, 0.941373839874194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 228}], {
             RGBColor[
             0.35358465424250685`, 0.48067898864856917`, 0.9437510793990673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 243}], {
             RGBColor[
             0.3138420416346276, 0.4443722151984709, 0.9412876874810078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 332}], {
             RGBColor[
             0.43326686926446056`, 0.5476890621459892, 0.9493828047697146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 348}], {
             RGBColor[
             0.3011336768698887, 0.43101491807386594`, 0.9405639649079968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 361}], {
             RGBColor[
             0.34746932604333547`, 0.4753821987277793, 0.9433614160937887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 385}], {
             RGBColor[
             0.4573665882056296, 0.5672542996623962, 0.9512800229249427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 57}], {
             RGBColor[
             0.3070138697292798, 0.4370559315903547, 0.9409039388472313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 92}], {
             RGBColor[
             0.31424207897729384`, 0.44465323780495364`, 0.9413155746707285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 96}], {
             RGBColor[
             0.3138659022147775, 0.44425785217656466`, 0.9412941519606068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 114}], {
             RGBColor[
             0.3348490984330268, 0.46445119188281303`, 0.9425572663500889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 153}], {
             RGBColor[
             0.32912553840433756`, 0.45949373186045395`, 0.9421925661662062]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 154}], {
             RGBColor[
             0.3854891726816393, 0.5083130789528232, 0.945784007101951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 188}], {
             RGBColor[
             0.30395311727072993`, 0.43383888669350434`, 0.9407296335226945]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 203}], {
             RGBColor[
             0.31610894590117855`, 0.4466154333081559, 0.9414218899802616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 222}], {
             RGBColor[
             0.4728736082946373, 0.5798845479116403, 0.9524894775340721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 258}], {
             RGBColor[
             0.29687678880049106`, 0.4264012168061446, 0.9403266470848042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 312}], {
             RGBColor[
             0.40188874544580117`, 0.5222558384193261, 0.9469012891044913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 327}], {
             RGBColor[
             0.32970622489449014`, 0.4599966933120725, 0.9422295669958778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 356}], {
             RGBColor[
             0.4295993605310475, 0.5447525640945126, 0.9490827702313296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 361}], {
             RGBColor[
             0.34822341852427197`, 0.4760353557329764, 0.9434094661998561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 369}], {
             RGBColor[
             0.2991371325274741, 0.4287769813772735, 0.940455370316177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 104}], {
             RGBColor[
             0.9330499750272585, 0.8621677183315113, 0.6295247357296906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 109}], {
             RGBColor[
             0.9631611562508396, 0.9703111795583055, 0.8704491819362283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 136}], {
             RGBColor[
             0.7754039881303256, 0.825013733522431, 0.9782569627328132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 205}], {
             RGBColor[
             0.9637471875060623, 0.9705535185426564, 0.8607371274369169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 207}], {
             RGBColor[
             0.9360408404789141, 0.8740255032004962, 0.6319312562767279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 221}], {
             RGBColor[
             0.9270423893059134, 0.944662453609973, 0.9929033247441504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 276}], {
             RGBColor[
             0.8488960037945177, 0.8827904862944987, 0.9853329329150746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 358}], {
             RGBColor[
             0.9504012676368335, 0.9272297470138823, 0.6629122325696076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 366}], {
             RGBColor[
             0.9167531541973288, 0.7967074998480634, 0.6163680259642358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 376}], {
             RGBColor[
             0.6853095806395425, 0.7514657941798157, 0.9712763701432583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 124}], {
             RGBColor[
             0.22535325774935577`, 0.3541909404893282, 0.9361449066973324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 137}], {
             RGBColor[
             0.22449567090087896`, 0.35328956233743236`, 0.9360960683949977]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 199}], {
             RGBColor[
             0.2266190062266405, 0.3555213223920431, 0.9362169892006067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 238}], {
             RGBColor[
             0.22832917766795519`, 0.3573188210079969, 0.9363143809342176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 252}], {
             RGBColor[
             0.2258841865651551, 0.3547489803375645, 0.9361751423079533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 277}], {
             RGBColor[
             0.2426240388727448, 0.37234362648077923`, 0.9371284521324783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 293}], {
             RGBColor[
             0.21933315592561953`, 0.34786343177608003`, 0.9358020708044131]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 299}], {
             RGBColor[
             0.22078197517346282`, 0.34938623266600927`, 0.9358845789172419]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 330}], {
             RGBColor[
             0.2261035990920075, 0.35497959681484403`, 0.9361876375267658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 367}], {
             RGBColor[
             0.22337497152266345`, 0.35211163623448327`, 0.9360322462233344]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 47}], {
             RGBColor[
             0.36592423069765223`, 0.4903693505688373, 0.9445738718209851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 49}], {
             RGBColor[
             0.2768464709137847, 0.4083135723834269, 0.9390773690096643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 54}], {
             RGBColor[
             0.3749740145051137, 0.4982078184475008, 0.9451505160427869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 93}], {
             RGBColor[
             0.2715973273730923, 0.4027963897072362, 0.9387784380504338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 128}], {
             RGBColor[
             0.3120848480897295, 0.44373638339990634`, 0.9411432739695049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 211}], {
             RGBColor[
             0.28031687034096775`, 0.4119611822174286, 0.9392750031230466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 301}], {
             RGBColor[
             0.2773872245806669, 0.4088819387730828, 0.9391081641310199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 316}], {
             RGBColor[
             0.27611802500026855`, 0.4075479295421829, 0.9390358850925288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 324}], {
             RGBColor[
             0.2889570987994522, 0.4210426101494208, 0.9397670513516847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 328}], {
             RGBColor[
             0.3036968641952127, 0.4364711333428047, 0.9406087990529493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 362}], {
             RGBColor[
             0.35130778497678417`, 0.477709319929344, 0.9436425248244668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 372}], {
             RGBColor[
             0.27471702429732014`, 0.4060753889748091, 0.9389561001750906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 380}], {
             RGBColor[
             0.2817236040630746, 0.41343974855143245`, 0.9393551145274445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 383}], {
             RGBColor[
             0.28909643467092216`, 0.42118906098474024`, 0.9397749863234359]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 390}], {
             RGBColor[
             0.28212790876587335`, 0.4138646984284726, 0.9393781390821536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 91}], {
             RGBColor[
             0.27906015322156846`, 0.41064029284447245`, 0.9392034349422431]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 97}], {
             RGBColor[
             0.36889177075057233`, 0.4927124766331557, 0.9447712800460943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 100}], {
             RGBColor[
             0.33605658973236274`, 0.46427229317936647`, 0.9426790513466246]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 112}], {
             RGBColor[
             0.31221013250570034`, 0.4436176904874213, 0.9411595761787357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 141}], {
             RGBColor[
             0.32778152064738697`, 0.45710484425502595`, 0.9421517712618861]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 180}], {
             RGBColor[
             0.33088455801292704`, 0.4597925392578639, 0.9423494940589101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 190}], {
             RGBColor[
             0.2683010399450559, 0.3993317826236759, 0.9385907193578275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 266}], {
             RGBColor[
             0.2752485126978604, 0.4066340169820878, 0.9389863676532347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 271}], {
             RGBColor[
             0.30114348847212347`, 0.43385127835713033`, 0.9404610482153953]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 273}], {
             RGBColor[
             0.2854682454604019, 0.41737560408400093`, 0.9395683663153217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 350}], {
             RGBColor[
             0.36412092231360993`, 0.48858020750687353`, 0.9444672858023867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 365}], {
             RGBColor[
             0.2758699057154388, 0.4072871404421556, 0.9390217550663172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 394}], {
             RGBColor[
             0.32718352263793704`, 0.4565868884354943, 0.9421136673575129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 59}], {
             RGBColor[
             0.30916725287120805`, 0.4399481765928165, 0.9410035436196971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 287}], {
             RGBColor[
             0.27226485336384204`, 0.4034980018471065, 0.9388164526680909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 373}], {
             RGBColor[
             0.26731905714517273`, 0.3982996564396932, 0.9385347968900875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 395}], {
             RGBColor[
             0.27869220583377896`, 0.41025355681069386`, 0.939182480882838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 54}], {
             RGBColor[
             0.44294170199458305`, 0.5580755721956097, 0.9494448314664949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 121}], {
             RGBColor[
             0.4935440296663224, 0.5991928393789325, 0.9534184801906773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 128}], {
             RGBColor[
             0.3800525355791988, 0.5036041371480152, 0.945437589393213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 130}], {
             RGBColor[
             0.4221487542491271, 0.5400657659424366, 0.9481199232226362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 158}], {
             RGBColor[
             0.468503909528975, 0.5788641418068768, 0.9514472302084831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 181}], {
             RGBColor[
             0.5006021052009016, 0.6049229030605833, 0.9539741177513421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 265}], {
             RGBColor[
             0.5128933077983199, 0.6149014550415344, 0.9549417262439694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 311}], {
             RGBColor[
             0.47663297852550124`, 0.5854636862286419, 0.9520871802976505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 322}], {
             RGBColor[
             0.47115402237552717`, 0.5810156228019311, 0.9516558567994469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 362}], {
             RGBColor[
             0.4192754724662534, 0.5375770736774529, 0.9479368402481747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 56}], {
             RGBColor[
             0.43818896314994105`, 0.5539589886879809, 0.9491419911499963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 71}], {
             RGBColor[
             0.6482814539995922, 0.7214952269023049, 0.9679496107647267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 83}], {
             RGBColor[
             0.38916228198081126`, 0.5114945416119245, 0.9460180543784913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 103}], {
             RGBColor[
             0.3850045259376993, 0.5078933023022759, 0.9457531258399835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 108}], {
             RGBColor[
             0.3965059868386308, 0.5178552896544295, 0.9464859887582483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 120}], {
             RGBColor[
             0.49591060473188847`, 0.6008847208403402, 0.9536681725336434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 143}], {
             RGBColor[
             0.5250435709581793, 0.6245361752480152, 0.9559616263525487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 196}], {
             RGBColor[
             0.3616835055171287, 0.4866932494532377, 0.9443037663378753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 231}], {
             RGBColor[
             0.3670635094292236, 0.49234797467679914`, 0.9446101496016666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 234}], {
             RGBColor[
             0.38209114426819646`, 0.5053698775309731, 0.945567487736205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 286}], {
             RGBColor[
             0.5758463873446392, 0.6644950889479655, 0.9608396409213635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 290}], {
             RGBColor[
             0.4152883060919923, 0.5341235905648768, 0.9476827815325197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 313}], {
             RGBColor[
             0.35412562406909687`, 0.4787494368539953, 0.9438733561702934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 320}], {
             RGBColor[
             0.5676684575710711, 0.6581064280542859, 0.9600245413086331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 331}], {
             RGBColor[
             0.43876768248625253`, 0.5544602462898143, 0.9491788666343646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 342}], {
             RGBColor[
             0.5144005472567488, 0.6158956891444403, 0.9551237685400916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 343}], {
             RGBColor[
             0.5738217336869491, 0.6629134141226403, 0.9606378423662292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 344}], {
             RGBColor[
             0.373035772157718, 0.49752656934511247`, 0.9449904874326764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 349}], {
             RGBColor[
             0.43541101780241814`, 0.5515528720515495, 0.9489649829288928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 147}], {
             RGBColor[
             0.2702371158648362, 0.4013667211696683, 0.9387009760172913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 211}], {
             RGBColor[
             0.25920679804656954`, 0.3897731577801271, 0.9380728157354339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 301}], {
             RGBColor[
             0.2562771522862687, 0.3866939143357813, 0.9379059767434073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 328}], {
             RGBColor[
             0.2825867919008145, 0.4142831089055032, 0.9394066116653366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 347}], {
             RGBColor[
             0.2678932418389194, 0.3989031609582332, 0.9385674958589661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 372}], {
             RGBColor[
             0.25360695200292194`, 0.3838873645375076, 0.9377539127874779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 380}], {
             RGBColor[
             0.2606135317686764, 0.39125172411413095`, 0.9381529271398318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 54}], {
             RGBColor[
             0.4530695590105145, 0.5668252864420751, 0.9500963936878091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 116}], {
             RGBColor[
             0.4351844866677396, 0.551334135708637, 0.9489567726932759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 121}], {
             RGBColor[
             0.5036718866822538, 0.607942553625398, 0.9540700424119916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 130}], {
             RGBColor[
             0.4322766112650586, 0.5488154801889021, 0.9487714854439504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 135}], {
             RGBColor[
             0.478712840814817, 0.5876796757980098, 0.9521051748933094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 158}], {
             RGBColor[
             0.47863176654490647`, 0.5876138560533424, 0.9520987924297972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 172}], {
             RGBColor[
             0.3777861468106212, 0.500941670871986, 0.945324186142565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 181}], {
             RGBColor[
             0.5107299622168331, 0.6136726173070488, 0.9546256799726562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 265}], {
             RGBColor[
             0.5230211648142513, 0.6236511692879999, 0.9555932884652836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 276}], {
             RGBColor[
             0.6098568885565028, 0.6922609454050347, 0.9637197242270632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 322}], {
             RGBColor[
             0.4812818793914586, 0.5897653370483966, 0.952307419020761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 328}], {
             RGBColor[
             0.38179240870061343`, 0.505088601337379, 0.9455546766979714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 362}], {
             RGBColor[
             0.4294033294821849, 0.5463267879239184, 0.948588402469489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 364}], {
             RGBColor[
             0.4018386991300539, 0.5224516905515073, 0.9468320085978967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 59}], {
             RGBColor[
             0.3534707906164537, 0.48058036569863427`, 0.9437438241095009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 136}], {
             RGBColor[
             0.4957527510770341, 0.5993305404010079, 0.9540497614266502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 194}], {
             RGBColor[
             0.38048922371828053`, 0.5039823744655038, 0.945465414775287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 246}], {
             RGBColor[
             0.408363122473439, 0.5281253445843351, 0.9472415149560449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 376}], {
             RGBColor[
             0.405658343586251, 0.5257826010583926, 0.9470691688370954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 377}], {
             RGBColor[
             0.39390138797963725`, 0.5155993170337143, 0.9463200260221095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 395}], {
             RGBColor[
             0.3229957435790246, 0.45088574591651165`, 0.9419227613726417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 396}], {
             RGBColor[
             0.3256114518738936, 0.4536350211799036, 0.9420717220904409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 117}], {
             RGBColor[
             0.36808130040816744`, 0.4932352549346425, 0.9446747928738624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 133}], {
             RGBColor[
             0.34195185422260005`, 0.4695411184843201, 0.9430487372114036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 174}], {
             RGBColor[
             0.5576254346896334, 0.6486129747855855, 0.95972095993169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 223}], {
             RGBColor[
             0.42035633884682855`, 0.5384929234825571, 0.9480113327439608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 260}], {
             RGBColor[
             0.5977997596730911, 0.6799974627988412, 0.9637251611956289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 267}], {
             RGBColor[
             0.4789222153161444, 0.5860393403630161, 0.9526218530734996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 272}], {
             RGBColor[
             0.5168312067307885, 0.6167442138565202, 0.9556549725324873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 291}], {
             RGBColor[
             0.5415685327056081, 0.6360692009186899, 0.9581205580022027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 346}], {
             RGBColor[
             0.36583874865596927`, 0.4912928693208167, 0.944531899459223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 384}], {
             RGBColor[
             0.5675366621289825, 0.6563557009893235, 0.9607088184571579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 68}], {
             RGBColor[
             0.28298429153365734`, 0.4147648110152172, 0.9394269088138741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 86}], {
             RGBColor[
             0.2948901577623302, 0.4272786312970708, 0.9401049302824465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 95}], {
             RGBColor[
             0.2855112454690256, 0.4174207998194225, 0.9395708151022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 101}], {
             RGBColor[
             0.27504289638646184`, 0.40641790120198085`, 0.9389746581084827]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 129}], {
             RGBColor[
             0.26346421560774436`, 0.39424797357278596`, 0.9383152693672578]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 151}], {
             RGBColor[
             0.302539739143033, 0.43466335198279643`, 0.9405645627526612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 171}], {
             RGBColor[
             0.28122827358250124`, 0.41291912481058346`, 0.9393269061893516]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 244}], {
             RGBColor[
             0.27464006789181306`, 0.4059945029133032, 0.9389517176216438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 249}], {
             RGBColor[
             0.279406621010689, 0.4110044524581648, 0.9392231657702803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 253}], {
             RGBColor[
             0.31547986955209806`, 0.4458714425532633, 0.9413890964198188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 270}], {
             RGBColor[
             0.26941555401375766`, 0.4005032075741548, 0.9386541892852642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 308}], {
             RGBColor[
             0.27516616979901054`, 0.4065474693745552, 0.9389816783469607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 386}], {
             RGBColor[
             0.3143035505913172, 0.444852574192945, 0.9413141424158159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 397}], {
             RGBColor[
             0.26929675474869136`, 0.4003783420142617, 0.9386474238428664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 121}], {
             RGBColor[
             0.502593813473784, 0.607031307257596, 0.9539951244124792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 128}], {
             RGBColor[
             0.3891023193866603, 0.5114426050266787, 0.9460142336150148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 130}], {
             RGBColor[
             0.43119853805658864`, 0.5479042338211002, 0.9486965674444381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 158}], {
             RGBColor[
             0.4775536933364365, 0.5867026096855403, 0.9520238744302849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 181}], {
             RGBColor[
             0.5096518890083631, 0.6127613709392468, 0.9545507619731439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 265}], {
             RGBColor[
             0.5219430916057815, 0.622739922920198, 0.9555183704657713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 311}], {
             RGBColor[
             0.48568276233296276`, 0.5933021541073054, 0.9526638245194523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 322}], {
             RGBColor[
             0.48020380618298864`, 0.5888540906805946, 0.9522325010212487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 328}], {
             RGBColor[
             0.38071433549214345`, 0.504177354969577, 0.9454797586984591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 362}], {
             RGBColor[
             0.4283252562737149, 0.5454155415561164, 0.9485134844699766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 58}], {
             RGBColor[
             0.351171823063294, 0.4776705562573528, 0.9436309688854188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 60}], {
             RGBColor[
             0.38053049793671245`, 0.5040181241190069, 0.9454680447319882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 80}], {
             RGBColor[
             0.36897452576073053`, 0.49400892184022105`, 0.9447317084034796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 87}], {
             RGBColor[
             0.34683568506465234`, 0.47311300029375225`, 0.9433840322411374]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 122}], {
             RGBColor[
             0.4248101196568824, 0.5423709068945195, 0.9482895030730654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 146}], {
             RGBColor[
             0.4694319452875655, 0.5787932378238967, 0.951748052097088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 159}], {
             RGBColor[
             0.36748362390558187`, 0.49271757758819734`, 0.9446367094556223]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 165}], {
             RGBColor[
             0.4681407137086776, 0.5777449578588358, 0.9516464016172608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 192}], {
             RGBColor[
             0.3740111987150174, 0.498371434802681, 0.9450526407503718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 201}], {
             RGBColor[
             0.33997947002411655`, 0.46590668357700793`, 0.9429935809374401]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 210}], {
             RGBColor[
             0.3517281816196206, 0.4782553243752219, 0.9436626526821428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 228}], {
             RGBColor[
             0.38569491533937006`, 0.508491282902023, 0.9457971168421706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 385}], {
             RGBColor[
             0.4894768493024928, 0.5950665939158499, 0.9533260603680459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 71}], {
             RGBColor[
             0.6610275221983658, 0.7325352305400676, 0.968761778959447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 83}], {
             RGBColor[
             0.4019083501795848, 0.5225345452496872, 0.9468302225732115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 108}], {
             RGBColor[
             0.40925205503740436`, 0.5288952932921922, 0.9472981569529686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 120}], {
             RGBColor[
             0.5086566729306621, 0.6119247244781029, 0.9544803407283637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 143}], {
             RGBColor[
             0.5377896391569529, 0.6355761788857779, 0.956773794547269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 196}], {
             RGBColor[
             0.3744295737159023, 0.4977332530910004, 0.9451159345325955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 231}], {
             RGBColor[
             0.37980957762799716`, 0.5033879783145618, 0.9454223177963867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 237}], {
             RGBColor[
             0.5146770314008289, 0.6168123226982427, 0.9549542854004349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 254}], {
             RGBColor[
             0.46022321075082034`, 0.5726042579779009, 0.9506674811679487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 286}], {
             RGBColor[
             0.5885924555434128, 0.6755350925857282, 0.9616518091160838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 290}], {
             RGBColor[
             0.42803437429076585`, 0.5451635942026395, 0.9484949497272399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 320}], {
             RGBColor[
             0.5804145257698448, 0.6691464316920486, 0.9608367095033534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 331}], {
             RGBColor[
             0.4515137506850261, 0.565500249927577, 0.9499910348290849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 342}], {
             RGBColor[
             0.5271466154555224, 0.626935692782203, 0.9559359367348119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 343}], {
             RGBColor[
             0.5865678018857227, 0.673953417760403, 0.9614500105609494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 344}], {
             RGBColor[
             0.38578184035649155`, 0.5085665729828752, 0.9458026556273967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 349}], {
             RGBColor[
             0.44815708600119175`, 0.5625928756893122, 0.949777151123613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 92}], {
             RGBColor[
             0.2804356326225079, 0.4120860089052909, 0.9392817664592872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 114}], {
             RGBColor[
             0.3010426520782409, 0.43188396298315035`, 0.9405234581386476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 153}], {
             RGBColor[
             0.2953190920495516, 0.42692650296079127`, 0.9401587579547649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 188}], {
             RGBColor[
             0.270146670915944, 0.40127165779384166`, 0.9386958253112532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 195}], {
             RGBColor[
             0.25945106473985713`, 0.3900298975621752, 0.9380867263622563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 208}], {
             RGBColor[
             0.2531470707031978, 0.383404000133339, 0.9377277232277921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 258}], {
             RGBColor[
             0.26307034244570515`, 0.39383398790648194`, 0.9382928388733629]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 278}], {
             RGBColor[
             0.26281152350528336`, 0.39356195279003, 0.9382780995175941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 284}], {
             RGBColor[
             0.2586027566797, 0.38913827200511253`, 0.9380384164731898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 327}], {
             RGBColor[
             0.2958997785397042, 0.4274294644124098, 0.9401957587844365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 337}], {
             RGBColor[
             0.27897537779675124`, 0.41055118849791716`, 0.9391986071072138]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 354}], {
             RGBColor[
             0.27649042962059545`, 0.4079393504099632, 0.939057092984733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 392}], {
             RGBColor[
             0.2605783177897506, 0.3912147119895847, 0.9381509217558264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 60}], {
             RGBColor[
             0.3281696676840872, 0.4577472453898289, 0.942165291884663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 80}], {
             RGBColor[
             0.31661369550810525`, 0.44773804311104304`, 0.9414289555561544]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 87}], {
             RGBColor[
             0.29447485481202706`, 0.42684212156457424`, 0.9400812793938123]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 110}], {
             RGBColor[
             0.2771944683256158, 0.40867933972757164`, 0.939097186947452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 159}], {
             RGBColor[
             0.31512279365295653`, 0.44644669885901933`, 0.9413339566082971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 167}], {
             RGBColor[
             0.2911802301180382, 0.4233792621199214, 0.9398936553914501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 192}], {
             RGBColor[
             0.32165036846239214`, 0.45210055607350297`, 0.9417498879030466]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 201}], {
             RGBColor[
             0.2876186397714912, 0.4196358048478299, 0.939690828090115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 210}], {
             RGBColor[
             0.2993673513669953, 0.4319844456460439, 0.9403598998348177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 228}], {
             RGBColor[
             0.3333340850867448, 0.46222040417284493`, 0.9424943639948453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 236}], {
             RGBColor[
             0.27466659649964625`, 0.4060223861621468, 0.9389532283866143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 243}], {
             RGBColor[
             0.2935914724788655, 0.42591363072274663`, 0.9400309720767858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 263}], {
             RGBColor[
             0.28044730154374703`, 0.41209827368136553`, 0.9392824309870891]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 348}], {
             RGBColor[
             0.28088310771412667`, 0.4125563335981417, 0.9393072495037748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 351}], {
             RGBColor[
             0.27227774194596055`, 0.4035115485640963, 0.9388171866537756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 79}], {
             RGBColor[
             0.46241207497172554`, 0.5712067102742551, 0.9517169387007705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 194}], {
             RGBColor[
             0.3610366257463029, 0.4871335118181791, 0.9442259124337696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 237}], {
             RGBColor[
             0.4562186120487096, 0.5661785780610258, 0.9512293666120685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 246}], {
             RGBColor[
             0.38891052450146135`, 0.5112764819370106, 0.9460020126145274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 254}], {
             RGBColor[
             0.401764791398701, 0.521970513340684, 0.9469425623795822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 349}], {
             RGBColor[
             0.38969866664907243`, 0.5119591310520951, 0.9460522323352465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 373}], {
             RGBColor[
             0.2921699969184407, 0.4220829828981863, 0.9400355750383738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 395}], {
             RGBColor[
             0.303543145607047, 0.434036883269187, 0.9406832590311243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 87}], {
             RGBColor[
             0.32383352968544554`, 0.4531896894262284, 0.9419183552403817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 122}], {
             RGBColor[
             0.4018079642776756, 0.5224475960269956, 0.9468238260723096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 146}], {
             RGBColor[
             0.44642978990835863`, 0.5588699269563728, 0.9502823750963323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 159}], {
             RGBColor[
             0.344481468526375, 0.4727942667206735, 0.9431710324548666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 165}], {
             RGBColor[
             0.4451385583294708, 0.557821646991312, 0.950180724616505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 201}], {
             RGBColor[
             0.3169773146449097, 0.44598337270948407`, 0.9415279039366844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 210}], {
             RGBColor[
             0.3287260262404138, 0.45833201350769803`, 0.942196975681387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 263}], {
             RGBColor[
             0.3098059764171655, 0.4384458415430197, 0.9411195068336586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 66}], {
             RGBColor[
             0.9830643953423903, 0.9540141570597834, 0.4329439736998075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 98}], {
             RGBColor[
             0.985458002900472, 0.9620883573989745, 0.44224268706809605`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 107}], {
             RGBColor[
             0.9162817916828967, 0.6453128669663495, 0.3511545314597267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 131}], {
             RGBColor[
             0.9579060415796807, 0.8592435772757068, 0.3867967672286041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 215}], {
             RGBColor[
             0.9063170503481712, 0.5687194984901538, 0.341612283904028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 262}], {
             RGBColor[
             0.9659943820446136, 0.9709682059989204, 0.7529333373497976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 269}], {
             RGBColor[
             0.9932024163292561, 0.9878689808064407, 0.5015031511422814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 279}], {
             RGBColor[
             0.9694977718101772, 0.9052009249245101, 0.39612374546494056`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 297}], {
             RGBColor[
             0.9699924620425022, 0.9739499675150907, 0.7461656307796394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 298}], {
             RGBColor[
             0.9083880182689977, 0.925110369261773, 0.7500707788698681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 300}], {
             RGBColor[
             0.9416713408004723, 0.7907793854302443, 0.3735219082012329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 306}], {
             RGBColor[
             0.9818610097196364, 0.9499548547858537, 0.42826904779571534`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 307}], {
             RGBColor[
             0.9892929392100926, 0.9881701251038566, 0.7056981044009731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 314}], {
             RGBColor[
             0.9595789423265859, 0.965928622564677, 0.7549534149051582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 352}], {
             RGBColor[
             0.9937500196167237, 0.9890402488671484, 0.5611063895673631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 77}], {
             RGBColor[
             0.5042166815429454, 0.5861598549701907, 0.9585479112851663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 204}], {
             RGBColor[
             0.17899762953989296`, 0.30546823612459895`, 0.9335050222478098]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 345}], {
             RGBColor[
             0.19050782677282135`, 0.3175661832050619, 0.9341605109524143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 370}], {
             RGBColor[
             0.5051424414592518, 0.5868980307983699, 0.9586362110924191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 389}], {
             RGBColor[
             0.17907819285502502`, 0.305552913276812, 0.9335096102094239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 400}], {
             RGBColor[
             0.2843395833350594, 0.4087127954077557, 0.9397778424506229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 90}], {
             RGBColor[
             0.8321834271804781, 0.8209894828739578, 0.632414864387591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 138}], {
             RGBColor[
             0.8889519646070447, 0.5107811215593289, 0.22983700543826907`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 142}], {
             RGBColor[
             0.890072513149207, 0.5193941486818902, 0.23091004398772222`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 152}], {
             RGBColor[
             0.5710886094431091, 0.5911007265104762, 0.6136429928057057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 156}], {
             RGBColor[
             0.5722602959769347, 0.592332243346744, 0.6137097186204522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 202}], {
             RGBColor[
             0.9074503393274316, 0.6529677356997123, 0.2475510699614376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 214}], {
             RGBColor[
             0.9711670732550739, 0.9296487112649943, 0.6029350218130802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 217}], {
             RGBColor[
             0.8906933611547283, 0.5241662585096577, 0.23150456873895697`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 242}], {
             RGBColor[
             0.9384539463641798, 0.7929291511512139, 0.2733380495894395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 256}], {
             RGBColor[
             0.5919347091448884, 0.6130112990161062, 0.6148301473446811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 257}], {
             RGBColor[
             0.8905841112547781, 0.5233265159050291, 0.23139995091138454`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 261}], {
             RGBColor[
             0.5690047111878296, 0.5889104173173967, 0.6135243178829187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 264}], {
             RGBColor[
             0.5742960336344989, 0.5944719326980662, 0.6138256508684465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 268}], {
             RGBColor[
             0.8879400264016856, 0.5030029210787892, 0.2288679722699964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 317}], {
             RGBColor[
             0.9745940579826633, 0.9311354530743134, 0.5492576472683819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 381}], {
             RGBColor[
             0.975854040924288, 0.9316564884007599, 0.528376469194335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 82}], {
             RGBColor[
             0.38908871359710695`, 0.5114308203756144, 0.9460133666661356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 151}], {
             RGBColor[
             0.35739789501188024`, 0.48398182614394664`, 0.9439940557289754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 157}], {
             RGBColor[
             0.43410205704708005`, 0.5499866920911975, 0.9490010571312653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 171}], {
             RGBColor[
             0.3360864294513485, 0.46223759897173367`, 0.9427563991656658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 182}], {
             RGBColor[
             0.34352729206089855`, 0.4700584173523088, 0.9431801452835099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 253}], {
             RGBColor[
             0.3703380254209453, 0.4951899167144135, 0.9448185893961331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 105}], {
             RGBColor[
             0.46633814789011974`, 0.5766565671437895, 0.9514008797073982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 113}], {
             RGBColor[
             0.6559239156864949, 0.7291861264524664, 0.9676704388099608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 148}], {
             RGBColor[
             0.5696101053080527, 0.6614741699887192, 0.9592609405218679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 161}], {
             RGBColor[
             0.4733844161827434, 0.5827596905831183, 0.9518498616922337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 168}], {
             RGBColor[
             0.592741338058181, 0.6798274166038522, 0.9613729899467283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 170}], {
             RGBColor[
             0.4801509107444425, 0.5886204880785566, 0.952281016742329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 180}], {
             RGBColor[
             0.4408011041078431, 0.5545376633487222, 0.9497736818591127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 239}], {
             RGBColor[
             0.4199235526672635, 0.5364545776271384, 0.9484433827426128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 251}], {
             RGBColor[
             0.6688240146939028, 0.7392826292624911, 0.9689511985946974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 282}], {
             RGBColor[
             0.5810969797016021, 0.6707307553552915, 0.9602123891284602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 312}], {
             RGBColor[
             0.4891446804627151, 0.5961487131731942, 0.9529264075234798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 326}], {
             RGBColor[
             0.4273612108963405, 0.5428967033575929, 0.9489173037481067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 356}], {
             RGBColor[
             0.5168552955479615, 0.6186454388483807, 0.9551078886503179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 98}], {
             RGBColor[
             0.9751764945744315, 0.9279266287426179, 0.3580657982576656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 107}], {
             RGBColor[
             0.906000283356856, 0.6111511383099929, 0.2669776426492963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 131}], {
             RGBColor[
             0.9476245332536402, 0.8250818486193503, 0.3026198784181737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 215}], {
             RGBColor[
             0.8960355420221306, 0.5345577698337973, 0.25743539509359753`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 297}], {
             RGBColor[
             0.9597109537164616, 0.9397882388587341, 0.661988741969209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 307}], {
             RGBColor[
             0.9790114308840521, 0.9540083964475, 0.6215212155905427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 314}], {
             RGBColor[
             0.9492974340005453, 0.9317668939083206, 0.6707765260947278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 352}], {
             RGBColor[
             0.983468511290683, 0.9548785202107917, 0.47692950075693274`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 85}], {
             RGBColor[
             0.22712666696496037`, 0.35605490601556716`, 0.9362458997286371]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 127}], {
             RGBColor[
             0.21172079285419906`, 0.33986235553632177`, 0.9353685579889777]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 139}], {
             RGBColor[
             0.21205827028800195`, 0.34021706571655375`, 0.9353877768295796]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 184}], {
             RGBColor[
             0.2153543932680198, 0.3436814999548199, 0.9355754861571146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 305}], {
             RGBColor[
             0.20792423756527648`, 0.33587193521215575`, 0.9351523497817738]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 325}], {
             RGBColor[
             0.21225679273606501`, 0.3404257253965182, 0.9353990823893092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 86}], {
             RGBColor[
             0.28863048877409425`, 0.42069932230449786`, 0.9397484513939167]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 95}], {
             RGBColor[
             0.2792515764807897, 0.4108414908268496, 0.9392143362136705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 129}], {
             RGBColor[
             0.25720454661950837`, 0.38766866458021304`, 0.9379587904787283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 151}], {
             RGBColor[
             0.29628007015479707`, 0.4280840429902235, 0.9402080838641316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 178}], {
             RGBColor[
             0.2603565331566741, 0.3909816022782634, 0.9381382914490737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 229}], {
             RGBColor[
             0.2618103919644219, 0.39250970006517877`, 0.9382210865573835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 249}], {
             RGBColor[
             0.2731469520224531, 0.4044251434655919, 0.9388666868817508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 308}], {
             RGBColor[
             0.26890650081077455`, 0.39996816038198235`, 0.938625199458431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 309}], {
             RGBColor[
             0.27375753584035556`, 0.40506690577145743`, 0.9389014587269024]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 319}], {
             RGBColor[
             0.2591541477712746, 0.38971781900257185`, 0.9380698173801449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 334}], {
             RGBColor[
             0.2690618295669699, 0.40013142075315566`, 0.938634045201308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 371}], {
             RGBColor[
             0.27438511411724903`, 0.40572653033123346`, 0.9389371983813526]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 386}], {
             RGBColor[
             0.30804388160308127`, 0.43827326520037213`, 0.9409576635272863]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 74}], {
             RGBColor[
             0.6564460490256175, 0.7292165790501876, 0.9679963956135333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 97}], {
             RGBColor[
             0.46525153460871527`, 0.5764515941781216, 0.9511282282884884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 100}], {
             RGBColor[
             0.4324163535905058, 0.5480114107243323, 0.9490359995890186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 132}], {
             RGBColor[
             0.6437204915353074, 0.7192373735289359, 0.9667380893382732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 140}], {
             RGBColor[
             0.5800718085263902, 0.6695145386144623, 0.9603941834467046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 141}], {
             RGBColor[
             0.42414128450553, 0.540843961799992, 0.9485087195042803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 168}], {
             RGBColor[
             0.5791845558214077, 0.6688214100579597, 0.9603057503889199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 191}], {
             RGBColor[
             0.5835359920161374, 0.6722207850854224, 0.9607394608823273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 216}], {
             RGBColor[
             0.5736600979558795, 0.6645056615859741, 0.959755124057878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 219}], {
             RGBColor[
             0.4677032328653056, 0.5785751319820428, 0.9512844483334466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 220}], {
             RGBColor[
             0.4818265682663484, 0.5902075400149862, 0.9523502989242535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 350}], {
             RGBColor[
             0.4604806861717529, 0.5723193250518395, 0.9508242340447808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 357}], {
             RGBColor[
             0.5819543622257783, 0.6709852038723623, 0.9605818188059951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 394}], {
             RGBColor[
             0.42354328649608, 0.5403260059804602, 0.948470615599907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 75}], {
             RGBColor[
             0.2609941288153654, 0.3916517557414475, 0.9381746015785979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 103}], {
             RGBColor[
             0.3111881460301813, 0.44109703206764383`, 0.9411543384931023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 133}], {
             RGBColor[
             0.28753417910083867`, 0.4195470313278583, 0.9396860181798696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 145}], {
             RGBColor[
             0.2579170969731607, 0.3884176001802034, 0.937999369167245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 164}], {
             RGBColor[
             0.26017432145076, 0.3907900862224582, 0.9381279147619799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 227}], {
             RGBColor[
             0.25636607330828476`, 0.3867873759678386, 0.9379110406640643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 234}], {
             RGBColor[
             0.30827476436067847`, 0.438573607296341, 0.9409687003893238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 280}], {
             RGBColor[
             0.2584116720913199, 0.38893742998726233`, 0.9380275344885658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 346}], {
             RGBColor[
             0.3114210735342079, 0.4412987821643549, 0.9411691804276892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 79}], {
             RGBColor[
             0.730962985173496, 0.7893766931257962, 0.9742494771038676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 109}], {
             RGBColor[
             0.932608231427341, 0.9459491066410988, 0.8675350166916449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 120}], {
             RGBColor[
             0.7187491637803132, 0.7794609626924269, 0.9732879603430942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 143}], {
             RGBColor[
             0.7478821300066041, 0.8031124171001021, 0.9755814141619994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 237}], {
             RGBColor[
             0.7247695222504801, 0.7843485609125668, 0.9737619050151656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 286}], {
             RGBColor[
             0.798684946393064, 0.8430713308000524, 0.9804594287308144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 320}], {
             RGBColor[
             0.7905070166194959, 0.8366826699063725, 0.9796443291180839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 321}], {
             RGBColor[
             0.8444532383444727, 0.878825868324395, 0.985021184343525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 343}], {
             RGBColor[
             0.7966602927353739, 0.841489655974727, 0.98025763017568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 382}], {
             RGBColor[
             0.8849504676641144, 0.7666705508963009, 0.612411028914603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 119}], {
             RGBColor[
             0.2341124382405141, 0.36339739454965503`, 0.9366437290682574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 200}], {
             RGBColor[
             0.24919308184682543`, 0.37924810714791846`, 0.937502549411824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 288}], {
             RGBColor[
             0.2363762501862872, 0.36577680443863003`, 0.9367726498095597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 341}], {
             RGBColor[
             0.22465511090045148`, 0.353457143886063, 0.936105148267103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 355}], {
             RGBColor[
             0.2293238377834227, 0.358364271854447, 0.9363710253563257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 374}], {
             RGBColor[
             0.25191511783451104`, 0.3821091395580259, 0.9376575653344313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 375}], {
             RGBColor[
             0.24128592482540645`, 0.37093718377569584`, 0.9370522485170447]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 379}], {
             RGBColor[
             0.22434193474233927`, 0.3531279758873717, 0.9360873133482011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 393}], {
             RGBColor[
             0.22527325394479547`, 0.3541068514182011, 0.9361403505990177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 399}], {
             RGBColor[
             0.23130276285488832`, 0.3604442475756538, 0.9364837222115884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 85}], {
             RGBColor[
             0.24221172142071856`, 0.3719102546962633, 0.9371049712635544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 96}], {
             RGBColor[
             0.26501373249139615`, 0.3958766140625488, 0.9384035120614771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 110}], {
             RGBColor[
             0.24934696023893294`, 0.3794098430944771, 0.9375113125586119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 115}], {
             RGBColor[
             0.24086103809529086`, 0.3704906008829697, 0.9370280518463283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 184}], {
             RGBColor[
             0.230439447723778, 0.35953684863551605`, 0.9364345576920319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 188}], {
             RGBColor[
             0.2551009475473486, 0.3854576485794885, 0.9378389936235647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 195}], {
             RGBColor[
             0.2444053413712617, 0.37421588834782205`, 0.937229894674568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 203}], {
             RGBColor[
             0.2672567761777972, 0.39823419519414005`, 0.9385312500811318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 206}], {
             RGBColor[
             0.23733902327111464`, 0.366788739994123, 0.9368274783124455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 208}], {
             RGBColor[
             0.23810134733460236`, 0.3675899909189858, 0.9368708915401036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 258}], {
             RGBColor[
             0.2480246190771097, 0.3780199786921288, 0.9374360071856744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 284}], {
             RGBColor[
             0.24355703331110456`, 0.3733242627907594, 0.9371815847855014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 348}], {
             RGBColor[
             0.2530355996274438, 0.3832868369650472, 0.9377213751149346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 369}], {
             RGBColor[
             0.2502849628040927, 0.38039574326325765`, 0.9375647304170474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 392}], {
             RGBColor[
             0.24553259442115521`, 0.3754007027752315, 0.9372940900681379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 132}], {
             RGBColor[
             0.8119479189165777, 0.8530570556731545, 0.981880980170774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 140}], {
             RGBColor[
             0.7482992359076605, 0.8033342207586809, 0.9755370742792053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 191}], {
             RGBColor[
             0.7517634193974077, 0.8060404672296411, 0.9758823517148281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 198}], {
             RGBColor[
             0.8255815527613636, 0.8637603366303892, 0.9832258995793732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 216}], {
             RGBColor[
             0.7418875253371497, 0.7983253437301927, 0.9748980148903788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 219}], {
             RGBColor[
             0.6359306602465759, 0.7123948141262615, 0.9664273391659474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 220}], {
             RGBColor[
             0.6500539956476187, 0.724027222159205, 0.9674931897567542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 224}], {
             RGBColor[
             0.9001674923644503, 0.8962994775971298, 0.6715446357629462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 302}], {
             RGBColor[
             0.9059752552459537, 0.9158904255240137, 0.6941066978535942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 311}], {
             RGBColor[
             0.6720237576353845, 0.741863264667372, 0.9692227298983209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 323}], {
             RGBColor[
             0.8274418605794372, 0.8652436955878107, 0.9834033373997775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 340}], {
             RGBColor[
             0.9092258023331339, 0.9260683158029884, 0.7736525641500547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 357}], {
             RGBColor[
             0.7501817896070486, 0.8048048860165811, 0.9757247096384958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 89}], {
             RGBColor[
             0.23138047401831524`, 0.3605259269355878, 0.9364881477473821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 133}], {
             RGBColor[
             0.27071817278007254`, 0.4018723424883518, 0.9387283714969541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 145}], {
             RGBColor[
             0.24110109065239455`, 0.37074291134069687`, 0.9370417224843294]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.24457568603401603`, 0.37439493138885227`, 0.9372395955511095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 164}], {
             RGBColor[
             0.2433583151299939, 0.3731153973829517, 0.9371702680790643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 169}], {
             RGBColor[
             0.2324382955275915, 0.3616377644115946, 0.9365483891174288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 209}], {
             RGBColor[
             0.24810555583118551`, 0.37810504835234904`, 0.9374406164140838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 227}], {
             RGBColor[
             0.2395500669875186, 0.36911268712833206`, 0.9369533939811485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 280}], {
             RGBColor[
             0.24159566577055375`, 0.3712627411477558, 0.9370698878056503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 315}], {
             RGBColor[
             0.24372617436870905`, 0.3735020407664642, 0.9371912171185102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 104}], {
             RGBColor[
             0.8904092616611533, 0.5686904524165735, 0.22911954666558126`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 109}], {
             RGBColor[
             0.9205204428847344, 0.6768339136433675, 0.4700439928721189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 138}], {
             RGBColor[
             0.8331436561867612, 0.2557622418600043, 0.17937170863583543`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 144}], {
             RGBColor[
             0.8626912709570241, 0.4513693690163807, 0.2064327327986027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 207}], {
             RGBColor[
             0.8934001271128089, 0.5805482372855583, 0.23152606721261854`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 233}], {
             RGBColor[
             0.8322013343184957, 0.24851914305244047`, 0.17846934015058413`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 242}], {
             RGBColor[
             0.8826456379438963, 0.5379102714518893, 0.22287275278700588`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 257}], {
             RGBColor[
             0.8347758028344946, 0.2683076362057045, 0.1809346541089509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 317}], {
             RGBColor[
             0.9187857495623798, 0.676116573374989, 0.49879235046594833`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 358}], {
             RGBColor[
             0.9077605542707283, 0.6337524810989443, 0.26250704350549825`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 366}], {
             RGBColor[
             0.8741124408312237, 0.5032302339331254, 0.2159628369001264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 382}], {
             RGBColor[
             0.8728626791215081, 0.4975553578985697, 0.2149200050950769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 78}], {
             RGBColor[
             0.8356045267952863, 0.5947068735494174, 0.5856449487468838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 102}], {
             RGBColor[
             0.8243310697046711, 0.5080541422905515, 0.574849473505362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 111}], {
             RGBColor[
             0.8517216279012312, 0.6939386797204187, 0.6001134200588495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 160}], {
             RGBColor[
             0.8294213428991457, 0.5471802126352212, 0.5797239248650322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 166}], {
             RGBColor[
             0.827067103969575, 0.529084500588463, 0.5774695030073427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 185}], {
             RGBColor[
             0.8265277938578538, 0.5249391267425765, 0.5769530590352949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 370}], {
             RGBColor[
             0.8302908639224114, 0.8675154135193626, 0.9836750778819656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 389}], {
             RGBColor[
             0.5042266153181847, 0.5861702959978048, 0.9585484769989704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 400}], {
             RGBColor[
             0.6094880057982189, 0.6893301781287484, 0.9648167092401694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 102}], {
             RGBColor[
             0.8305704924938522, 0.23598377814878552`, 0.17690764417753302`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 144}], {
             RGBColor[
             0.8601410277678558, 0.4317670823407418, 0.2039906170405674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 160}], {
             RGBColor[
             0.835660765688327, 0.2751098484934552, 0.18178209553720334`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 185}], {
             RGBColor[
             0.832767216647035, 0.2528687626008105, 0.17901122970746597`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 207}], {
             RGBColor[
             0.8908498839236407, 0.5609459506099194, 0.22908395145458324`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 213}], {
             RGBColor[
             0.8764060316711535, 0.5036808895572449, 0.2174620888914447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 230}], {
             RGBColor[
             0.9053505911840212, 0.6146233921482407, 0.26060988945584945`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 247}], {
             RGBColor[
             0.874425744599943, 0.49582971121144337`, 0.21586870343063702`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 289}], {
             RGBColor[
             0.8697986288874946, 0.4756199934349731, 0.21204915614425965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 370}], {
             RGBColor[
             0.8365302867115927, 0.5954450493775967, 0.5857332485541368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 391}], {
             RGBColor[
             0.8311173699138001, 0.24018731764171894`, 0.1774313346124849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 400}], {
             RGBColor[
             0.6157274285874001, 0.4172598139869824, 0.5668748799123404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 109}], {
             RGBColor[
             0.79245120355282, 0.8352543310125031, 0.854215095221335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 120}], {
             RGBColor[
             0.5785921359057922, 0.6687661870638313, 0.9599680388727843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 136}], {
             RGBColor[
             0.6046940354323059, 0.6899568849766287, 0.9620228760179198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 237}], {
             RGBColor[
             0.5846124943759591, 0.6736537852839712, 0.9604419835448554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 246}], {
             RGBColor[
             0.5173044068287108, 0.618751689159956, 0.9552146295473145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 254}], {
             RGBColor[
             0.5301586737259505, 0.6294457205636295, 0.9561551793123693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 286}], {
             RGBColor[
             0.658527918518543, 0.7323765551714567, 0.9671395072605043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 320}], {
             RGBColor[
             0.6503499887449748, 0.725987894277777, 0.9663244076477739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 343}], {
             RGBColor[
             0.6565032648608529, 0.7307948803461315, 0.9669377087053699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 349}], {
             RGBColor[
             0.518092548976322, 0.6194343382750406, 0.9552648492680336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 87}], {
             RGBColor[
             0.3122775575094636, 0.4431804871474425, 0.9411820189118731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 96}], {
             RGBColor[
             0.31066394327551555`, 0.4414844762785116, 0.9410901259683782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 110}], {
             RGBColor[
             0.29499717102305234`, 0.4250177053104399, 0.9401979264655129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 146}], {
             RGBColor[
             0.4348738177323767, 0.548860724677587, 0.9495460387678236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 154}], {
             RGBColor[
             0.38228721374237734`, 0.5055397030547701, 0.9455799811097223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 159}], {
             RGBColor[
             0.3329254963503931, 0.4627850644418876, 0.9424346961263579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 167}], {
             RGBColor[
             0.30898293281547473`, 0.43971762770278966`, 0.9409943949095109]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 192}], {
             RGBColor[
             0.3394530711598287, 0.46843892165637124`, 0.9428506274211075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 201}], {
             RGBColor[
             0.30542134246892777`, 0.4359741704306982, 0.9407915676081757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 203}], {
             RGBColor[
             0.31290698696191654`, 0.4438420574101029, 0.9412178639880329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 228}], {
             RGBColor[
             0.35113678778418134`, 0.4785587697557132, 0.9435951035129062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 243}], {
             RGBColor[
             0.3113941751763021, 0.44225199630561496`, 0.9411317115948465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 332}], {
             RGBColor[
             0.4308190028061351, 0.5455688432531333, 0.9492268288835535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 348}], {
             RGBColor[
             0.2986858104115632, 0.42889469918101, 0.9404079890218355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 361}], {
             RGBColor[
             0.34502145958500996`, 0.47326197983492335`, 0.9432054402076274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 385}], {
             RGBColor[
             0.4549187217473041, 0.5651340807695402, 0.9511240470387816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 89}], {
             RGBColor[
             0.21914913629591037`, 0.3476700154777373, 0.9357915911587338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 163}], {
             RGBColor[
             0.23234434831161116`, 0.36153901993100174`, 0.9365430389624612]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 169}], {
             RGBColor[
             0.22020695780518662`, 0.3487818529537441, 0.9358518325287805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 209}], {
             RGBColor[
             0.23587421810878062`, 0.36524913689449845`, 0.9367440598254355]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 227}], {
             RGBColor[
             0.2273187292651137, 0.35625677567048153`, 0.9362568373925002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 240}], {
             RGBColor[
             0.22946097871463872`, 0.3585084156683923, 0.9363788353294766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 245}], {
             RGBColor[
             0.22480714766170556`, 0.3536169441618284, 0.9361138065357382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 248}], {
             RGBColor[
             0.21796166804011632`, 0.3464219110510618, 0.9357239665982682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 292}], {
             RGBColor[
             0.21536706305033604`, 0.3436948166993449, 0.9355762076824743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 304}], {
             RGBColor[
             0.21940694053557647`, 0.34794098407935925`, 0.9358062727287957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 315}], {
             RGBColor[
             0.23149483664630416`, 0.3606461293086136, 0.9364946605298619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 329}], {
             RGBColor[
             0.22742713619850993`, 0.35637071823087746`, 0.9362630110069835]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 353}], {
             RGBColor[
             0.2150475477536689, 0.34335898586410785`, 0.9355580117590097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 378}], {
             RGBColor[
             0.21412094136701804`, 0.3423850638014996, 0.9355052428960813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 151}], {
             RGBColor[
             0.34752633634939933`, 0.4754315781894705, 0.9433650487400788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 157}], {
             RGBColor[
             0.4242304983845992, 0.5414364441367214, 0.9483720501423687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 171}], {
             RGBColor[
             0.32621487078886763`, 0.45368735101725755`, 0.9421273921767691]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 182}], {
             RGBColor[
             0.3336557333984177, 0.4615081693978327, 0.9425511382946132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 253}], {
             RGBColor[
             0.3604664667584644, 0.48663966875993736`, 0.9441895824072364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 108}], {
             RGBColor[
             0.3602253738682746, 0.48643084621613597`, 0.9441742201814636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 120}], {
             RGBColor[
             0.45962999176153224`, 0.5694602774020465, 0.9513564039568587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 125}], {
             RGBColor[
             0.315433813888692, 0.4447906722692076, 0.9414242734794431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 179}], {
             RGBColor[
             0.3112624132414147, 0.4404062657068423, 0.9411867183836149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 196}], {
             RGBColor[
             0.32540289254677246`, 0.4552688060149441, 0.9419919977610904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 231}], {
             RGBColor[
             0.3307828964588674, 0.4609235312385056, 0.9422983810248817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 237}], {
             RGBColor[
             0.4656503502316991, 0.5743478756221865, 0.9518303486289299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 246}], {
             RGBColor[
             0.39834226268445083`, 0.5194457794981713, 0.946602994631389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 254}], {
             RGBColor[
             0.4111965295816905, 0.5301398109018447, 0.9475435443964437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 303}], {
             RGBColor[
             0.32124670467921895`, 0.4509003890486145, 0.9417553090105623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 313}], {
             RGBColor[
             0.31784501109874064`, 0.44732499341570175`, 0.9415615875935087]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 344}], {
             RGBColor[
             0.33675515918736176`, 0.4661021259068189, 0.9426787188558917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 349}], {
             RGBColor[
             0.3991304048320619, 0.5201284286132558, 0.946653214352108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 90}], {
             RGBColor[
             0.44236640792617826`, 0.5377470693075241, 0.9524063925246276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 152}], {
             RGBColor[
             0.18127159018880934`, 0.30785831294404253`, 0.9336345209427424]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 156}], {
             RGBColor[
             0.18244327672263497`, 0.3090898297803102, 0.9337012467574888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 175}], {
             RGBColor[
             0.1789295778879611, 0.3053967095236947, 0.9335011468069058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 204}], {
             RGBColor[
             0.17892700714738574`, 0.30539400751235557`, 0.933501000407033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 256}], {
             RGBColor[
             0.20211768989058865`, 0.32976888544967253`, 0.9348216754817178]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 261}], {
             RGBColor[
             0.17918769193352976`, 0.30566800375096304`, 0.9335158460199553]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 264}], {
             RGBColor[
             0.18447901438019912`, 0.31122951913163255`, 0.9338171790054831]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 317}], {
             RGBColor[
             0.5847770387283635, 0.6478930395078799, 0.8692491754054186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 333}], {
             RGBColor[
             0.18724373492288626`, 0.3141354157154036, 0.9339746257503516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 381}], {
             RGBColor[
             0.5860370216699882, 0.6484140748343261, 0.8483679973313716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 389}], {
             RGBColor[
             0.1790075704625178, 0.3054786846645686, 0.933505588368647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 96}], {
             RGBColor[
             0.2641094772748117, 0.3949261844968264, 0.9383520160646184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 110}], {
             RGBColor[
             0.2484427050223485, 0.37845941352875473`, 0.9374598165617531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 115}], {
             RGBColor[
             0.2399567828787064, 0.36954017131724737`, 0.9369765558494695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 139}], {
             RGBColor[
             0.2262390695271757, 0.3551219848315275, 0.9361953523676381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 167}], {
             RGBColor[
             0.2624284668147709, 0.39315933592110447`, 0.9382562850057511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 184}], {
             RGBColor[
             0.22953519250719354`, 0.35858641906979366`, 0.9363830616951732]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 188}], {
             RGBColor[
             0.25419669233076414`, 0.38450721901376617`, 0.937787497626706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 203}], {
             RGBColor[
             0.2663525209612127, 0.3972837656284177, 0.9384797540842731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 258}], {
             RGBColor[
             0.24712036386052527`, 0.3770695491264064, 0.9373845111888157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 284}], {
             RGBColor[
             0.24265277809452013`, 0.37237383322503703`, 0.9371300887886426]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 325}], {
             RGBColor[
             0.22643759197523877`, 0.355330644511492, 0.9362066579273677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 348}], {
             RGBColor[
             0.2521313444108594, 0.3823364073993248, 0.9376698791180758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 351}], {
             RGBColor[
             0.24352597864269326`, 0.37329162236527946`, 0.9371798162680766]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 369}], {
             RGBColor[
             0.24938070758750824`, 0.3794453136975352, 0.9375132344201885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 95}], {
             RGBColor[
             0.2911574427094625, 0.42335531110870317`, 0.9398923576822427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 151}], {
             RGBColor[
             0.30818593638346986`, 0.44059786327207706`, 0.9408861053327038]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[
             0.27226239938534696`, 0.40349542256011695`, 0.9388163129176459]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 229}], {
             RGBColor[
             0.27371625819309475`, 0.4050235203470323, 0.9388991080259558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 249}], {
             RGBColor[
             0.2850528182511259, 0.41693896374744543`, 0.939544708350323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 308}], {
             RGBColor[
             0.28081236703944734`, 0.4124819806638359, 0.9393032209270034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 309}], {
             RGBColor[
             0.28566340206902835`, 0.417580726053311, 0.9395794801954747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 334}], {
             RGBColor[
             0.28096769579564274`, 0.4126452410350092, 0.9393120666698803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 371}], {
             RGBColor[
             0.2862909803459218, 0.418240350613087, 0.9396152198499249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 386}], {
             RGBColor[
             0.31994974783175406`, 0.4507870854822257, 0.9416356849958585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 110}], {
             RGBColor[
             0.27285833032697415`, 0.4041217837639711, 0.9388502503031707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 134}], {
             RGBColor[
             0.26223279186396886`, 0.39295366914130303`, 0.9382451416067781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 159}], {
             RGBColor[
             0.3107866556543149, 0.4418891428954188, 0.9410870199640158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 167}], {
             RGBColor[
             0.28684409211939654`, 0.41882170615632086`, 0.9396467187471687]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 192}], {
             RGBColor[
             0.3173142304637505, 0.44754300010990244`, 0.9415029512587653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 201}], {
             RGBColor[
             0.2832825017728496, 0.4150782488842294, 0.9394438914458336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 210}], {
             RGBColor[
             0.2950312133683537, 0.42742688968244336`, 0.9401129631905363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 228}], {
             RGBColor[
             0.32899794708810315`, 0.4576628482092444, 0.9422474273505641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 236}], {
             RGBColor[
             0.2703304585010046, 0.4014648301985463, 0.938706291742333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 243}], {
             RGBColor[
             0.2892553344802239, 0.4213560747591461, 0.9397840354325044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 263}], {
             RGBColor[
             0.2761111635451054, 0.407540717717765, 0.9390354943428079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 348}], {
             RGBColor[
             0.27654696971548504`, 0.4079987776345412, 0.9390603128594934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 351}], {
             RGBColor[
             0.2679416039473189, 0.3989539926004958, 0.9385702500094941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 113}], {
             RGBColor[
             0.8934147061054667, 0.915612925432826, 0.8952711863200087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 132}], {
             RGBColor[
             0.8947680641910523, 0.9166701790551881, 0.8954060764061295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 140}], {
             RGBColor[
             0.8311193811821351, 0.8669473441407145, 0.8890621705145608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 168}], {
             RGBColor[
             0.8302321284771527, 0.8662542155842119, 0.8889737374567761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 282}], {
             RGBColor[
             0.8185877701205739, 0.8571575543356513, 0.887813136638508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 283}], {
             RGBColor[
             0.9496145330722283, 0.8334245259791293, 0.5278793972462171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 357}], {
             RGBColor[
             0.8330019348815232, 0.8684180093986145, 0.8892498058738514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 163}], {
             RGBColor[
             0.23177803755773202`, 0.36094379142249916`, 0.9365107884028094]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 164}], {
             RGBColor[
             0.2305606666537099, 0.3596642574165986, 0.9364414609307642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 169}], {
             RGBColor[
             0.2196406470513075, 0.3481866244452415, 0.9358195819691286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 209}], {
             RGBColor[
             0.23530790735490154`, 0.3646539083859959, 0.9367118092657838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 227}], {
             RGBColor[
             0.22675241851123462`, 0.35566154716197895`, 0.9362245868328485]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 245}], {
             RGBColor[
             0.22424083690782642`, 0.3530217156533258, 0.9360815559760864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.22879801729426974`, 0.3578116011814027, 0.9363410806573501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 292}], {
             RGBColor[
             0.21480075229645693`, 0.3430995881908423, 0.9355439571228226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 304}], {
             RGBColor[
             0.21884062978169738`, 0.3473457555708567, 0.9357740221691438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 315}], {
             RGBColor[
             0.23092852589242507`, 0.36005090080011104`, 0.93646240997021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 329}], {
             RGBColor[
             0.22686082544463082`, 0.3557754897223749, 0.9362307604473317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 353}], {
             RGBColor[
             0.21448123699978983`, 0.34276375735560527`, 0.9355257611993579]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 378}], {
             RGBColor[
             0.2135546306131389, 0.341789835292997, 0.9354729923364294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 138}], {
             RGBColor[
             0.7625743389841517, 0.45989176227570816`, 0.5687339252858672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 142}], {
             RGBColor[
             0.763694887526314, 0.46850478939826945`, 0.5698069638353204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 152}], {
             RGBColor[
             0.4447109838202162, 0.5402113672268555, 0.9525399126533038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 156}], {
             RGBColor[
             0.4458826703540418, 0.5414428840631231, 0.9526066384680504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 175}], {
             RGBColor[
             0.44236897151936794`, 0.5377497638065076, 0.9524065385174674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 202}], {
             RGBColor[
             0.7810727137045386, 0.6020783764160916, 0.5864479898090358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 242}], {
             RGBColor[
             0.8120763207412868, 0.7420397918675932, 0.6122349694370377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 256}], {
             RGBColor[
             0.46555708352199543`, 0.5621219397324855, 0.9537270671922793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[
             0.7642064856318851, 0.4724371566214084, 0.5702968707589827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 261}], {
             RGBColor[
             0.4426270855649366, 0.538021058033776, 0.9524212377305169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 264}], {
             RGBColor[
             0.44791840801160593`, 0.5435825734144455, 0.9527225707160447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 268}], {
             RGBColor[
             0.7615624007787926, 0.45211356179516854`, 0.5677648921175946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 317}], {
             RGBColor[
             0.8482164323597703, 0.8802460937906929, 0.8881545671159801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 333}], {
             RGBColor[
             0.4506831285542931, 0.5464884699982167, 0.9528800174609131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 381}], {
             RGBColor[
             0.849476415301395, 0.8807671291171392, 0.8672733890419332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 141}], {
             RGBColor[
             0.3113425799408942, 0.43982647528346147`, 0.9412155979078848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 150}], {
             RGBColor[
             0.2666109948635128, 0.3975554380879269, 0.9384944737906311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 186}], {
             RGBColor[
             0.2555444422624831, 0.38592378964428387`, 0.9378642499915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 189}], {
             RGBColor[
             0.28158397795101814`, 0.4132929926548542, 0.9393471630269211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 190}], {
             RGBColor[
             0.25186209923856306`, 0.38205341365211143`, 0.9376545460038261]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 226}], {
             RGBColor[
             0.25062761976227643`, 0.38075589745201466`, 0.9375842442239002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 241}], {
             RGBColor[
             0.2767915804260243, 0.40825587900053273`, 0.9390742430775896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 255}], {
             RGBColor[
             0.26154809523840944`, 0.39223400957556664`, 0.9382061491468703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 266}], {
             RGBColor[
             0.25880957199136756`, 0.38935564801052325`, 0.9380501942992334]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 273}], {
             RGBColor[
             0.26902930475390907`, 0.40009723511243644`, 0.9386321929613204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 365}], {
             RGBColor[
             0.259430965008946, 0.3900087714705911, 0.9380855817123159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 114}], {
             RGBColor[
             0.3082708613262549, 0.43948126919774927`, 0.9409350939621447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 153}], {
             RGBColor[
             0.30254730129756563`, 0.4345238091753902, 0.940570393778262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 161}], {
             RGBColor[
             0.35955024405905767`, 0.48389689314418627`, 0.9442025708853012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 188}], {
             RGBColor[
             0.27737488016395806`, 0.40886896400844064`, 0.9391074611347503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 195}], {
             RGBColor[
             0.26667927398787117`, 0.3976272037767742, 0.9384983621857534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 258}], {
             RGBColor[
             0.2702985516937192, 0.40143129412108086`, 0.93870447469686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 278}], {
             RGBColor[
             0.2700397327532974, 0.4011592590046289, 0.9386897353410912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 284}], {
             RGBColor[
             0.26583096592771405`, 0.3967355782197115, 0.9384500522966869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 327}], {
             RGBColor[
             0.3031279877877182, 0.4350267706270088, 0.9406073946079336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 337}], {
             RGBColor[
             0.2862035870447653, 0.41814849471251614`, 0.9396102429307109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 354}], {
             RGBColor[
             0.2837186388686095, 0.41553665662456213`, 0.9394687288082302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 392}], {
             RGBColor[
             0.26780652703776464`, 0.39881201820418366`, 0.9385625575793235]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 94}], {
             RGBColor[
             0.2526810398598759, 0.3829141721689455, 0.9377011834606958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 119}], {
             RGBColor[
             0.24286823945996167`, 0.3726002967811557, 0.9371423589946579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 128}], {
             RGBColor[
             0.2857256322546389, 0.41603117628641406`, 0.9396421556226617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 225}], {
             RGBColor[
             0.25117310830966183`, 0.38132924050128825`, 0.9376153089896959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 296}], {
             RGBColor[
             0.27337982614775685`, 0.40466990893635857`, 0.9388799487186803]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 301}], {
             RGBColor[
             0.25102800874557624`, 0.38117673165959054`, 0.9376070457841768]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 316}], {
             RGBColor[
             0.2497588091651779, 0.37984272242869066`, 0.9375347667456857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 324}], {
             RGBColor[
             0.26259788296436154`, 0.3933374030359285, 0.9382659330048415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 355}], {
             RGBColor[
             0.23807963900287032`, 0.36756717408594775`, 0.936869655282726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 380}], {
             RGBColor[
             0.25536438822798396`, 0.38573454143794017`, 0.9378539961806014]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 383}], {
             RGBColor[
             0.2627372188358315, 0.39348385387124796`, 0.9382738679765928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 390}], {
             RGBColor[
             0.2557686929307827, 0.3861594913149804, 0.9378770207353105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 119}], {
             RGBColor[
             0.25031116778183593`, 0.38042328635635736`, 0.9375662227517629]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 128}], {
             RGBColor[
             0.29316856057651314`, 0.42385416586161573`, 0.9400660193797667]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 177}], {
             RGBColor[
             0.29101623446385616`, 0.4219899291618881, 0.9399288750630955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 200}], {
             RGBColor[
             0.26539181138814727`, 0.3962739989546208, 0.9384250430953294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 225}], {
             RGBColor[
             0.2586160366315361, 0.3891522300764899, 0.9380391727468009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 288}], {
             RGBColor[
             0.25257497972760906`, 0.38280269624533236`, 0.9376951434930652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 296}], {
             RGBColor[
             0.2808227544696311, 0.4124928985115602, 0.9393038124757853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 316}], {
             RGBColor[
             0.25720173748705216`, 0.38766571200389227`, 0.9379586305027907]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 324}], {
             RGBColor[
             0.2700408112862358, 0.4011603926111301, 0.9386897967619465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 355}], {
             RGBColor[
             0.2455225673247446, 0.37539016366114936`, 0.937293519039831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 375}], {
             RGBColor[
             0.25748465436672835`, 0.3879630755823982, 0.9379747422005502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 380}], {
             RGBColor[
             0.2628073165498582, 0.39355753101314184`, 0.9382778599377064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 383}], {
             RGBColor[
             0.2701801471577058, 0.4013068434464496, 0.9386977317336979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 390}], {
             RGBColor[
             0.26321162125265696`, 0.393982480890182, 0.9383008844924156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 129}], {
             RGBColor[
             0.2597315005548766, 0.39032465338441835`, 0.9381026967670542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 151}], {
             RGBColor[
             0.2988070240901653, 0.4307400317944288, 0.9403519901524575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 178}], {
             RGBColor[
             0.2628834870920424, 0.39363759108246865`, 0.9382821977373995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 229}], {
             RGBColor[
             0.2643373458997902, 0.3951656888693841, 0.9383649928457094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 249}], {
             RGBColor[
             0.2756739059578213, 0.4070811322697972, 0.9390105931700766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 270}], {
             RGBColor[
             0.26568283896088996`, 0.3965798873857872, 0.9384416166850604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 308}], {
             RGBColor[
             0.2714334547461428, 0.4026241491861876, 0.9387691057467569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 309}], {
             RGBColor[
             0.2762844897757238, 0.4077228945756627, 0.9390453650152284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 334}], {
             RGBColor[
             0.27158878350233817`, 0.4027874095573609, 0.9387779514896339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 371}], {
             RGBColor[
             0.27691206805261726`, 0.40838251913543877`, 0.9390811046696785]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 386}], {
             RGBColor[
             0.3105708355384495, 0.4409292540045774, 0.9411015698156122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 110}], {
             RGBColor[
             0.2712447160930261, 0.4024257728950402, 0.9387583573596757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 114}], {
             RGBColor[
             0.3078946845637386, 0.4390858835693603, 0.940913671252023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 115}], {
             RGBColor[
             0.262758793949384, 0.3935065306835328, 0.9382750966473921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 153}], {
             RGBColor[
             0.3021711245350493, 0.4341284235470012, 0.9405489710681403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 154}], {
             RGBColor[
             0.3585347588123511, 0.48294777063937044`, 0.9441404120038852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 167}], {
             RGBColor[
             0.28523047788544853`, 0.41712569528738996`, 0.9395548258036737]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 188}], {
             RGBColor[
             0.2769987034014417, 0.4084735783800516, 0.9390860384246287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 192}], {
             RGBColor[
             0.3157006162298024, 0.44584698924097155`, 0.9414110583152703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 203}], {
             RGBColor[
             0.28915453203189034`, 0.42125012499470316`, 0.9397782948821958]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 228}], {
             RGBColor[
             0.3273843328541551, 0.4559668373403135, 0.9421555344070691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 243}], {
             RGBColor[
             0.2876417202462759, 0.4196600638902152, 0.9396921424890095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 258}], {
             RGBColor[
             0.26992237493120286`, 0.4010359084926919, 0.9386830519867384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 284}], {
             RGBColor[
             0.2654547891651977, 0.3963401925913225, 0.9384286295865651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 348}], {
             RGBColor[
             0.27493335548153697`, 0.4063027667656103, 0.9389684199159984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 361}], {
             RGBColor[
             0.32126900465498376`, 0.45067004741952366`, 0.9417658711017902]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 369}], {
             RGBColor[
             0.27218271865818583`, 0.40341167306382075`, 0.9388117752181111]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 100}], {
             RGBColor[
             0.4094492665548738, 0.5290661079964851, 0.9473107230964745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 105}], {
             RGBColor[
             0.42981427861771465`, 0.5467052578700499, 0.9486083636570456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 112}], {
             RGBColor[
             0.38560280932821134`, 0.5084115053045399, 0.9457912479285857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 132}], {
             RGBColor[
             0.6207534044996754, 0.7002920708010887, 0.965012812845729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 140}], {
             RGBColor[
             0.5571047214907582, 0.6505692358866151, 0.9586689069541604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 141}], {
             RGBColor[
             0.401174197469898, 0.5218986590721447, 0.9467834430117361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 168}], {
             RGBColor[
             0.5562174687857758, 0.6498761073301125, 0.9585804738963757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 180}], {
             RGBColor[
             0.40427723483543804`, 0.5245863540749827, 0.9469811658087601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 220}], {
             RGBColor[
             0.4588594812307164, 0.571262237287139, 0.9506250224317093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 282}], {
             RGBColor[
             0.5445731104291971, 0.6407794460815519, 0.9574198730781076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 350}], {
             RGBColor[
             0.437513599136121, 0.5533740223239922, 0.9490989575522366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 357}], {
             RGBColor[
             0.5589872751901463, 0.652039901144515, 0.958856542313451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 394}], {
             RGBColor[
             0.40057619946044803`, 0.521380703252613, 0.9467453391073628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 107}], {
             RGBColor[
             0.9083938909149378, 0.6192253386491839, 0.2762763560175848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 131}], {
             RGBColor[
             0.9500181408117219, 0.8331560489585412, 0.3119185917864623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 215}], {
             RGBColor[
             0.8984291495802124, 0.5426319701729883, 0.2667341084618861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 283}], {
             RGBColor[
             0.9432427006605664, 0.8062936865407971, 0.3064669136008217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 297}], {
             RGBColor[
             0.9621045612745434, 0.9478624391979251, 0.6712874553374975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 307}], {
             RGBColor[
             0.9814050384421338, 0.9620825967866911, 0.6308199289588313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 352}], {
             RGBColor[
             0.9858621188487648, 0.9629527205499828, 0.4862282141252213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 123}], {
             RGBColor[
             0.9762118677425246, 0.9817794304286422, 0.9251512823600752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 174}], {
             RGBColor[
             0.8533664925541351, 0.885559755956836, 0.9477463395066474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 187}], {
             RGBColor[
             0.9110307205751575, 0.9308010667922535, 0.953442401298972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 193}], {
             RGBColor[
             0.9002336063428361, 0.9221917409832586, 0.9524125629047955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 218}], {
             RGBColor[
             0.9440956875300477, 0.9571661739174645, 0.9565961673645738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 232}], {
             RGBColor[
             0.7518421224806613, 0.804458883314896, 0.9388506680687247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 235}], {
             RGBColor[
             0.8591106393434069, 0.8900471270857477, 0.9483188623764983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 275}], {
             RGBColor[
             0.9851141209349312, 0.987104803716967, 0.8512424005775606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 279}], {
             RGBColor[
             0.9618886205302903, 0.9027170726846294, 0.5985175369470697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 281}], {
             RGBColor[
             0.8050608246814849, 0.8476642232367373, 0.943040239252503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 306}], {
             RGBColor[
             0.9742518584397497, 0.947471002545973, 0.6306628392778444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 338}], {
             RGBColor[
             0.9862079875593082, 0.9866999578573392, 0.7708056942036536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 384}], {
             RGBColor[
             0.863277719993484, 0.893302482160574, 0.9487341980321153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 105}], {
             RGBColor[
             0.3969790975995051, 0.5182650744162607, 0.9465161349575758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 112}], {
             RGBColor[
             0.35276762831000186`, 0.47997132185075075`, 0.9436990192291159]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 141}], {
             RGBColor[
             0.3683390164516885, 0.49345847561835543`, 0.9446912143122663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 168}], {
             RGBColor[
             0.5233822877675662, 0.6214359238763232, 0.9564882451969059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 170}], {
             RGBColor[
             0.4107918604538279, 0.5302289953510277, 0.9473962719925066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 180}], {
             RGBColor[
             0.3714420538172285, 0.49614617062119337`, 0.9448889371092903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 220}], {
             RGBColor[
             0.42602430021250687`, 0.5428220538333498, 0.9485327937322395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 271}], {
             RGBColor[
             0.3417009842764249, 0.4702049097204598, 0.9430004912657755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 273}], {
             RGBColor[
             0.3260257412647034, 0.4537292354473304, 0.9421078093657018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 282}], {
             RGBColor[
             0.5117379294109875, 0.6123392626277626, 0.9553276443786378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 350}], {
             RGBColor[
             0.4046784181179114, 0.524933838870203, 0.9470067288527668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 394}], {
             RGBColor[
             0.3677410184422385, 0.49294051979882375`, 0.944653110407893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 151}], {
             RGBColor[
             0.2883386750076016, 0.41973713317698713`, 0.9397558331587401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 171}], {
             RGBColor[
             0.2670272094470698, 0.3979929060047742, 0.9385181765954305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 182}], {
             RGBColor[
             0.2744680720566198, 0.40581372438534935`, 0.9389419227132746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 244}], {
             RGBColor[
             0.2604390037563816, 0.39106828410749395`, 0.9381429880277227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 253}], {
             RGBColor[
             0.3012788054166666, 0.43094522374745403`, 0.9405803668258977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 270}], {
             RGBColor[
             0.2552144898783262, 0.38557698876834556`, 0.937845459691343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 308}], {
             RGBColor[
             0.26096510566357906`, 0.39162125056874597`, 0.9381729487530396]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 397}], {
             RGBColor[
             0.2550956906132599, 0.3854521232084524, 0.9378386942489454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 160}], {
             RGBColor[
             0.8243873085977117, 0.18845711723458924`, 0.17098662029568146`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 166}], {
             RGBColor[
             0.8220330696681408, 0.1703614051878311, 0.16873219843799186`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[
             0.8214937595564198, 0.16621603134194454`, 0.16821575446594406`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 213}], {
             RGBColor[
             0.8651325745805382, 0.41702815829837886`, 0.20666661364992278`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 224}], {
             RGBColor[
             0.8974792718626248, 0.5394468704448865, 0.26303107700793477`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 230}], {
             RGBColor[
             0.8940771340934058, 0.5279706608893748, 0.24981441421432754`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 247}], {
             RGBColor[
             0.8631522875093278, 0.40917697995257735`, 0.2050732281891151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 250}], {
             RGBColor[
             0.9037621261807391, 0.5693653564012491, 0.505440590565607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 289}], {
             RGBColor[
             0.8585251717968794, 0.3889672621761071, 0.20125368090273776`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 302}], {
             RGBColor[
             0.9032870347441282, 0.5590378183717704, 0.2855931390985828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 340}], {
             RGBColor[
             0.9065375818313084, 0.569215708650745, 0.3651390053950433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 370}], {
             RGBColor[
             0.8252568296209774, 0.5087923181187306, 0.5749377733126149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 391}], {
             RGBColor[
             0.8198439128231849, 0.15353458638285297`, 0.16663585937096298`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 400}], {
             RGBColor[
             0.6044539714967849, 0.33060708272811645`, 0.5560794046708185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 108}], {
             RGBColor[
             0.3560676178251626, 0.48282960690648735`, 0.9439092916429558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 133}], {
             RGBColor[
             0.32091218999488846`, 0.4513176188145481, 0.9417081084114585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 143}], {
             RGBColor[
             0.48460520194471113`, 0.589510492500073, 0.9533849292372562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 223}], {
             RGBColor[
             0.3993166746191169, 0.5202694238127852, 0.9466707039440156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 231}], {
             RGBColor[
             0.3266251404157554, 0.4573222919288569, 0.942033452486374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 234}], {
             RGBColor[
             0.34165277525472826`, 0.4703441947830308, 0.9429907906209125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 290}], {
             RGBColor[
             0.3748499370785241, 0.4990979078169345, 0.9451060844172272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 313}], {
             RGBColor[
             0.31368725505562867`, 0.4437237541060531, 0.9412966590550009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 331}], {
             RGBColor[
             0.39832931347278433`, 0.519434563541872, 0.9466021695190721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 342}], {
             RGBColor[
             0.4739621782432806, 0.580870006396498, 0.9525470714247991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 346}], {
             RGBColor[
             0.3447990844282577, 0.4730693696510448, 0.9431912706592778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 109}], {
             RGBColor[
             0.9639852685830836, 0.8836832833010115, 0.5065761886025747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 138}], {
             RGBColor[
             0.8766084818851104, 0.4626116115176483, 0.21590390436629117`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 144}], {
             RGBColor[
             0.9061560966553733, 0.6582187386740248, 0.24296492852905843`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 205}], {
             RGBColor[
             0.9645712998383063, 0.8839256222853624, 0.49686413410326324`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 207}], {
             RGBColor[
             0.9368649528111581, 0.7873976069432023, 0.2680582629430743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 233}], {
             RGBColor[
             0.8756661600168449, 0.4553685127100845, 0.21500153588103987`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 358}], {
             RGBColor[
             0.9512253799690775, 0.8406018507565884, 0.299039239235954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 366}], {
             RGBColor[
             0.9175772665295729, 0.7100796035907695, 0.25249503263058215`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 382}], {
             RGBColor[
             0.9163275048198573, 0.7044047275562138, 0.25145220082553266`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 112}], {
             RGBColor[
             0.37313264037284266`, 0.49761047172431544`, 0.944996659789687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 113}], {
             RGBColor[
             0.6069298774587211, 0.6884337835985022, 0.9640833346207096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 148}], {
             RGBColor[
             0.520616067080279, 0.620721827134755, 0.9556738363326167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 155}], {
             RGBColor[
             0.3609448647521152, 0.4866656792120809, 0.9442342850410239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 168}], {
             RGBColor[
             0.5437472998304071, 0.6390750737498879, 0.957785885757477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 170}], {
             RGBColor[
             0.4311568725166687, 0.5478681452245924, 0.9486939125530778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 180}], {
             RGBColor[
             0.39180706588006936`, 0.513785320494758, 0.9461865776698615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 239}], {
             RGBColor[
             0.37092951443948974`, 0.4957022347731742, 0.9448562785533615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 271}], {
             RGBColor[
             0.36206599633926584`, 0.4878440595940245, 0.9442981318263466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 282}], {
             RGBColor[
             0.5321029414738284, 0.6299784125013272, 0.956625284939209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 326}], {
             RGBColor[
             0.37836717266856673`, 0.5021443605036287, 0.9453301995588554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 350}], {
             RGBColor[
             0.4250434301807523, 0.5425729887437677, 0.948304369413338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 394}], {
             RGBColor[
             0.38810603050507936`, 0.5105796696723884, 0.9459507509684641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 107}], {
             RGBColor[
             0.8938562482651202, 0.6317789737296462, 0.5786286100973383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 173}], {
             RGBColor[
             0.5874312139478495, 0.658182594689114, 0.9541358462016971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 197}], {
             RGBColor[
             0.9686231253627324, 0.9753622711647122, 0.9040752003743098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 204}], {
             RGBColor[
             0.563710908416439, 0.6332510496213667, 0.9527850098927306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 214}], {
             RGBColor[
             0.9661339552698273, 0.9742633398075717, 0.9422105594358144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 215}], {
             RGBColor[
             0.8838915069303948, 0.5551856052534505, 0.5690863625416396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 295}], {
             RGBColor[
             0.5954410834145789, 0.6666014753537031, 0.9545919964182874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 310}], {
             RGBColor[
             0.5655364837016175, 0.6351698449942476, 0.952888973704525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 345}], {
             RGBColor[
             0.5752211056493675, 0.6453489967018295, 0.953440498597335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 363}], {
             RGBColor[
             0.905503655257033, 0.714845634359743, 0.589529206598464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 131}], {
             RGBColor[
             0.8808419295941465, 0.5163805585259162, 0.22083043617809295`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 197}], {
             RGBColor[
             0.9139845567949747, 0.6460331456516251, 0.5106347906861869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 215}], {
             RGBColor[
             0.829252938362637, 0.22585647974036333`, 0.17564595285351675`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 297}], {
             RGBColor[
             0.892928350056968, 0.6310869487653001, 0.5801992997291281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 307}], {
             RGBColor[
             0.9122288272245584, 0.6453071063540661, 0.539731773350462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 352}], {
             RGBColor[
             0.9166859076311894, 0.6461772301173578, 0.39514005851685197`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 363}], {
             RGBColor[
             0.8508650866892753, 0.3855165088466559, 0.1960887969103411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 143}], {
             RGBColor[
             0.49610666284564264`, 0.5994724798522266, 0.954117792155521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 179}], {
             RGBColor[
             0.3186061180992342, 0.4467670137493473, 0.9416546527633719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 196}], {
             RGBColor[
             0.332746597404592, 0.4616295540574491, 0.9424599321408476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 231}], {
             RGBColor[
             0.3381266013166869, 0.4672842792810106, 0.9427663154046388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 234}], {
             RGBColor[
             0.3531542361556598, 0.4803061821351844, 0.9437236535391773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 290}], {
             RGBColor[
             0.3863513979794556, 0.5090598951690881, 0.945838947335492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 313}], {
             RGBColor[
             0.3251887159565602, 0.4536857414582067, 0.9420295219732657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 331}], {
             RGBColor[
             0.40983077437371584`, 0.5293965508940257, 0.9473350324373369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 342}], {
             RGBColor[
             0.48546363914421214`, 0.5908319937486516, 0.9532799343430639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 344}], {
             RGBColor[
             0.3440988640451813, 0.47246287394932385`, 0.9431466532356487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 136}], {
             RGBColor[
             0.8063392816861509, 0.8465292984919313, 0.8553084156056971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 205}], {
             RGBColor[
             0.9946824810618875, 0.9920690835121566, 0.737788580309801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 207}], {
             RGBColor[
             0.9669761340347394, 0.8955410681699965, 0.508982709149612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 233}], {
             RGBColor[
             0.9057773412404262, 0.5635119739368787, 0.4559259820875775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 286}], {
             RGBColor[
             0.8601731647723879, 0.8889489686867593, 0.8604250468482817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 320}], {
             RGBColor[
             0.8519952349988198, 0.8825603077930796, 0.8596099472355513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 343}], {
             RGBColor[
             0.8581485111146978, 0.8873672938614341, 0.8602232482931473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 358}], {
             RGBColor[
             0.9813365611926588, 0.9487453119833825, 0.5399636854424916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 366}], {
             RGBColor[
             0.9476884477531541, 0.8182230648175637, 0.4934194788371198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 382}], {
             RGBColor[
             0.9464386860434384, 0.8125481887830079, 0.4923766470320703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 115}], {
             RGBColor[
             0.2470920216969208, 0.3770397597154611, 0.9373828971445268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 134}], {
             RGBColor[
             0.24495240537755758`, 0.37479088730430044`, 0.9372610491604179]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 167}], {
             RGBColor[
             0.26956370563298526`, 0.40065892431931827`, 0.9386626263008084]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 192}], {
             RGBColor[
             0.30003384397733923`, 0.42938021827289985`, 0.940518858812405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 203}], {
             RGBColor[
             0.2734877597794271, 0.40478335402663146`, 0.9388860953793305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 243}], {
             RGBColor[
             0.2719749479938126, 0.4031932929221435, 0.9387999429861442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 348}], {
             RGBColor[
             0.25926658322907375`, 0.3898359957975386, 0.9380762204131332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 351}], {
             RGBColor[
             0.25066121746090764`, 0.3807912107634932, 0.9375861575631339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 369}], {
             RGBColor[
             0.2565159464057226, 0.38694490209574905`, 0.9379195757152459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 160}], {
             RGBColor[
             0.8517778667942718, 0.37434165466445646`, 0.19625056684916897`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 166}], {
             RGBColor[
             0.8494236278647009, 0.35624594261769826`, 0.19399614499147944`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 185}], {
             RGBColor[
             0.8488843177529799, 0.35210056877181173`, 0.19347970101943163`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 197}], {
             RGBColor[
             0.931414792844472, 0.7553582824181725, 0.5263607215030722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[
             0.631844529693345, 0.5164916201579837, 0.581343351224306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 155}], {
             RGBColor[
             0.31673339546261187`, 0.44837192664657105`, 0.9414171693125639]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 170}], {
             RGBColor[
             0.3869454032271654, 0.5095743926590826, 0.9458767968246178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 180}], {
             RGBColor[
             0.34759559659056605`, 0.4754915679292482, 0.9433694619414015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 183}], {
             RGBColor[
             0.2939274002864909, 0.42440137973285763`, 0.9401184016257302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 271}], {
             RGBColor[
             0.3178545270497625, 0.4495503070285146, 0.9414810160978866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 273}], {
             RGBColor[
             0.30217928403804095`, 0.4330746327553852, 0.940588334197813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 326}], {
             RGBColor[
             0.3341557033790634, 0.4638506079381187, 0.9425130838303954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 350}], {
             RGBColor[
             0.380831960891249, 0.5042792361782578, 0.945487253684878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 394}], {
             RGBColor[
             0.34389456121557604`, 0.47228591710687856`, 0.9431336352400042]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 148}], {
             RGBColor[
             0.7102018348766541, 0.7732513864434318, 0.9719433954351793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 168}], {
             RGBColor[
             0.7333330676267822, 0.7916046330585647, 0.9740554448600397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 170}], {
             RGBColor[
             0.6207426403130438, 0.7003977045332692, 0.9649634716556403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 251}], {
             RGBColor[
             0.8094157442625041, 0.8510598457172036, 0.9816336535080088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 282}], {
             RGBColor[
             0.7216887092702036, 0.7825079718100041, 0.9728948440417715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 153}], {
             RGBColor[
             0.32315432075329853`, 0.4543217632532496, 0.9418120854576224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 154}], {
             RGBColor[
             0.3795179550306004, 0.5031411103456188, 0.9454035263933673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 188}], {
             RGBColor[
             0.297981899619691, 0.4286669180863, 0.9403491528141107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 203}], {
             RGBColor[
             0.3101377282501396, 0.4414434647009515, 0.9410414092716778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 222}], {
             RGBColor[
             0.4669023906435984, 0.574712579304436, 0.9521089968254883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 258}], {
             RGBColor[
             0.29090557114945215`, 0.42122924819894025`, 0.9399461663762204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 312}], {
             RGBColor[
             0.3959175277947622, 0.5170838698121216, 0.9465208083959076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 327}], {
             RGBColor[
             0.32373500724345117`, 0.4548247247048681, 0.941849086287294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 356}], {
             RGBColor[
             0.4236281428800086, 0.5395805954873082, 0.9487022895227458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 361}], {
             RGBColor[
             0.342252200873233, 0.470863387125772, 0.9430289854912723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 369}], {
             RGBColor[
             0.29316591487643506`, 0.4236050127700691, 0.9400748896075932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 392}], {
             RGBColor[
             0.2884135464934976, 0.418609972282043, 0.9398042492586839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 184}], {
             RGBColor[
             0.22818450918176583`, 0.35716676525650004`, 0.936306142277947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 188}], {
             RGBColor[
             0.25284600900533644`, 0.38308756520047255`, 0.9377105782094798]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 195}], {
             RGBColor[
             0.2421504028292495, 0.3718458049688061, 0.937101479260483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 203}], {
             RGBColor[
             0.265001837635785, 0.3958641118151241, 0.9384028346670469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 206}], {
             RGBColor[
             0.23508408472910247`, 0.364418656615107, 0.9366990628983605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 208}], {
             RGBColor[
             0.2358464087925902, 0.36521990753996986`, 0.9367424761260187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 258}], {
             RGBColor[
             0.24576968053509757`, 0.37564989531311277`, 0.9373075917715895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 284}], {
             RGBColor[
             0.24130209476909242`, 0.37095417941174347`, 0.9370531693714164]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 325}], {
             RGBColor[
             0.22508690864981107`, 0.3539109906981984, 0.9361297385101415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 369}], {
             RGBColor[
             0.24803002426208054`, 0.37802565988424164`, 0.9374363150029623]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 392}], {
             RGBColor[
             0.24327765587914302`, 0.37303061939621557`, 0.937165674654053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 121}], {
             RGBColor[
             0.48470874113100904`, 0.5915401565241579, 0.9528555034179461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 130}], {
             RGBColor[
             0.4133134657138138, 0.5324130830876621, 0.947556946449905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 135}], {
             RGBColor[
             0.4597496952635722, 0.5712772786967698, 0.9508906358992639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 147}], {
             RGBColor[
             0.35047958711339033`, 0.47576981650030403`, 0.9436345020558807]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 172}], {
             RGBColor[
             0.3588230012593764, 0.484539273770746, 0.9441096471485195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 265}], {
             RGBColor[
             0.5040580192630065, 0.6072487721867599, 0.9543787494712381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 276}], {
             RGBColor[
             0.5908937430052579, 0.6758585483037947, 0.9625051852330178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 322}], {
             RGBColor[
             0.46231873384021377`, 0.5733629399471565, 0.9510928800267155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 328}], {
             RGBColor[
             0.3628292631493686, 0.48868620423613895`, 0.944340137703926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 362}], {
             RGBColor[
             0.41044018393094006`, 0.5299243908226783, 0.9473738634754435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 364}], {
             RGBColor[
             0.382875553578809, 0.5060492934502673, 0.9456174696038513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 387}], {
             RGBColor[
             0.35489504602512995`, 0.4804107437728069, 0.9438859559088182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 223}], {
             RGBColor[
             0.40179215387534173`, 0.5224135595233219, 0.9468284392932418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 346}], {
             RGBColor[
             0.3472745636844825, 0.4752135053615816, 0.9433490060085041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 371}], {
             RGBColor[
             0.31078136056287864`, 0.44021172480761495`, 0.9411479331302521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 126}], {
             RGBColor[
             0.20905168496127685`, 0.33705695390964574`, 0.935216556243067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 149}], {
             RGBColor[
             0.21314012851733694`, 0.34135416730935836`, 0.9354493870552745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 199}], {
             RGBColor[
             0.21593219336709382`, 0.3442888044935889, 0.9356083910179783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 212}], {
             RGBColor[
             0.208479398474888, 0.33645544452739207`, 0.9351839653742893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 259}], {
             RGBColor[
             0.20854115618205327`, 0.33652035579328765`, 0.9351874823843499]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 293}], {
             RGBColor[
             0.20864634306607288`, 0.33663091387762584`, 0.9351934726217848]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 299}], {
             RGBColor[
             0.21009516231391617`, 0.33815371476755507`, 0.9352759807346135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 336}], {
             RGBColor[
             0.20853409149877072`, 0.3365129303632308, 0.9351870800610882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 367}], {
             RGBColor[
             0.21268815866311674`, 0.340879118336029, 0.9354236480407061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 200}], {
             RGBColor[
             0.2555790109882331, 0.38596012356683096`, 0.9378662186292916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 225}], {
             RGBColor[
             0.24880323623162193`, 0.37883835468870003`, 0.9374803482807631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 288}], {
             RGBColor[
             0.2427621793276949, 0.37248882085754254`, 0.9371363190270272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 296}], {
             RGBColor[
             0.27100995406971695`, 0.4021790231237703, 0.9387449880097476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 316}], {
             RGBColor[
             0.24738893708713797`, 0.3773518366161024, 0.9373998060367528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 324}], {
             RGBColor[
             0.26022801088632164`, 0.3908465172233403, 0.9381309722959088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 355}], {
             RGBColor[
             0.2357097669248304, 0.3650762882733595, 0.9367346945737933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 375}], {
             RGBColor[
             0.24767185396681415`, 0.37764920019460835`, 0.9374159177345123]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 380}], {
             RGBColor[
             0.25299451614994406`, 0.383243655625352, 0.9377190354716685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 383}], {
             RGBColor[
             0.2603673467577916, 0.3909929680586598, 0.93813890726766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 390}], {
             RGBColor[
             0.2533988208527428, 0.3836686055023921, 0.9377420600263777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 136}], {
             RGBColor[
             0.5924802140391232, 0.6800411545432594, 0.9610613592571464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 237}], {
             RGBColor[
             0.5723986729827764, 0.663738054850602, 0.9594804667840822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 246}], {
             RGBColor[
             0.505090585435528, 0.6088359587265868, 0.9542531127865411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 254}], {
             RGBColor[
             0.5179448523327678, 0.6195299901302602, 0.955193662551596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 286}], {
             RGBColor[
             0.6463140971253603, 0.7224608247380875, 0.966177990499731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 320}], {
             RGBColor[
             0.6381361673517921, 0.7160721638444079, 0.9653628908870006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 343}], {
             RGBColor[
             0.64428944346767, 0.7208791499127623, 0.9659761919445966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 349}], {
             RGBColor[
             0.5058787275831391, 0.6095186078416714, 0.9543033325072602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 130}], {
             RGBColor[
             0.48180086572832803`, 0.5890215010044231, 0.9526702161686205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 158}], {
             RGBColor[
             0.5281560210081759, 0.6278198768688632, 0.9559975231544674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 181}], {
             RGBColor[
             0.5602542166801026, 0.6538786381225696, 0.9585244106973264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 250}], {
             RGBColor[
             0.7707116790518824, 0.8187741201767487, 0.9013688926659322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 265}], {
             RGBColor[
             0.5725454192775208, 0.6638571901035208, 0.9594920191899539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 322}], {
             RGBColor[
             0.5308061338547281, 0.6299713578639174, 0.9562061497454312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 362}], {
             RGBColor[
             0.4789275839454543, 0.5865328087394392, 0.9524871331941591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 146}], {
             RGBColor[
             0.49070941162852855`, 0.5972227097318854, 0.9531038334374095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.3887610902465449, 0.5111470494961861, 0.9459924907959437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 165}], {
             RGBColor[
             0.48941818004964077`, 0.5961744297668246, 0.9530021829575823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 210}], {
             RGBColor[
             0.3730056479605837, 0.4966847962832106, 0.9450184340224643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 228}], {
             RGBColor[
             0.40697238168033323`, 0.5269207548100117, 0.9471528981824919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 262}], {
             RGBColor[
             0.6923652232093209, 0.7572804525421046, 0.9691955483013721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 298}], {
             RGBColor[
             0.634758859433705, 0.711422615804957, 0.9663329898214426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 314}], {
             RGBColor[
             0.6859497834912932, 0.7522408691078613, 0.9712156258567326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 385}], {
             RGBColor[
             0.510754315643456, 0.6134960658238386, 0.9546818417083673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 174}], {
             RGBColor[
             0.8514507591880022, 0.8841310051490996, 0.9509891763922267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 187}], {
             RGBColor[
             0.9091149872090246, 0.929372315984517, 0.9566852381845512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 193}], {
             RGBColor[
             0.8983178729767032, 0.9207629901755221, 0.9556553997903747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 218}], {
             RGBColor[
             0.9421799541639146, 0.955737423109728, 0.959839004250153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 232}], {
             RGBColor[
             0.7499263891145284, 0.8030301325071595, 0.9420935049543039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 235}], {
             RGBColor[
             0.8571949059772741, 0.8886183762780113, 0.9515616992620775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 275}], {
             RGBColor[
             0.9831983875687983, 0.9856760529092304, 0.8544852374631398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 279}], {
             RGBColor[
             0.9599728871641575, 0.901288321876893, 0.6017603738326488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 281}], {
             RGBColor[
             0.8031450913153519, 0.8462354724290008, 0.9462830761380823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 306}], {
             RGBColor[
             0.9723361250736168, 0.9460422517382365, 0.6339056761634236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 338}], {
             RGBColor[
             0.9842922541931751, 0.9852712070496027, 0.7740485310892328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 137}], {
             RGBColor[
             0.22241368079166546`, 0.3511012587268517, 0.9359775021383063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 199}], {
             RGBColor[
             0.224537016117427, 0.35333301878146245`, 0.9360984229439153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 238}], {
             RGBColor[
             0.22624718755874168`, 0.35513051739741625`, 0.9361958146775262]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 252}], {
             RGBColor[
             0.22380219645594157`, 0.3525606767269839, 0.936056576051262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 277}], {
             RGBColor[
             0.24054204876353127`, 0.3701553228701986, 0.9370098858757869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 293}], {
             RGBColor[
             0.21725116581640602`, 0.3456751281654994, 0.9356835045477219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 330}], {
             RGBColor[
             0.22402160898279397`, 0.3527912932042634, 0.9360690712700745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 179}], {
             RGBColor[
             0.2738145581196516, 0.4051268398024189, 0.9389047060613515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 196}], {
             RGBColor[
             0.2879550374250095, 0.4199893801105207, 0.9397099854388271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 303}], {
             RGBColor[
             0.28379884955745593`, 0.41562096314419106`, 0.9394732966882988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 313}], {
             RGBColor[
             0.2803971559769777, 0.4120455675112783, 0.9392795752712453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 344}], {
             RGBColor[
             0.2993073040655987, 0.4308227000023955, 0.9403967065336283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 149}], {
             RGBColor[
             0.21613019133913786`, 0.3444969129160037, 0.9356196667095744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 199}], {
             RGBColor[
             0.21892225618889471`, 0.3474315501002342, 0.9357786706722784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 212}], {
             RGBColor[
             0.21146946129668887`, 0.3395981901340374, 0.9353542450285892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 238}], {
             RGBColor[
             0.2206324276302094, 0.349229048716188, 0.9358760624058893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 259}], {
             RGBColor[
             0.2115312190038542, 0.33966310139993294`, 0.93535776203865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 274}], {
             RGBColor[
             0.22138486041548355`, 0.35001990328050514`, 0.9359189123398861]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 299}], {
             RGBColor[
             0.21308522513571704`, 0.34129646037420036`, 0.9354462603889135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 318}], {
             RGBColor[
             0.2179296081019373, 0.3463882140233181, 0.9357221408322174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 336}], {
             RGBColor[
             0.21152415432057162`, 0.33965567596987617`, 0.9353573597153882]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 367}], {
             RGBColor[
             0.21567822148491766`, 0.34402186394267437`, 0.935593927695006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 139}], {
             RGBColor[
             0.2108331954164144, 0.3389294343522821, 0.9353180106279786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 184}], {
             RGBColor[
             0.21412931839643223`, 0.34239386859054827`, 0.9355057199555137]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 305}], {
             RGBColor[
             0.20669916269368893`, 0.33458430384788407`, 0.9350825835801727]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 325}], {
             RGBColor[
             0.21103171786447747`, 0.3391380940322466, 0.9353293161877081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 177}], {
             RGBColor[
             0.32406082685861914`, 0.45510693327935664`, 0.9418698472250615]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 225}], {
             RGBColor[
             0.2916606290262991, 0.42226923419395845`, 0.939980144908767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 296}], {
             RGBColor[
             0.3138673468643941, 0.4456099026290287, 0.9412447846377514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 311}], {
             RGBColor[
             0.4227935959175786, 0.5388307190597109, 0.9486565824461703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 316}], {
             RGBColor[
             0.29024632988181515`, 0.4207827161213608, 0.9398996026647567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 324}], {
             RGBColor[
             0.3030854036809988, 0.43427739672859866`, 0.9406307689239126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 380}], {
             RGBColor[
             0.2958519089446212, 0.4266745351306104, 0.9402188320996724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 383}], {
             RGBColor[
             0.30322473955246876`, 0.43442384756391816`, 0.9406387038956638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 390}], {
             RGBColor[
             0.29625621364741994`, 0.42709948500765055`, 0.9402418566543815]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 178}], {
             RGBColor[
             0.24083645723076108`, 0.3704647648358321, 0.9370266520024574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 229}], {
             RGBColor[
             0.24229031603850887`, 0.3719928626227475, 0.9371094471107673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 249}], {
             RGBColor[
             0.25362687609654, 0.3839083060231606, 0.9377550474351345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 270}], {
             RGBColor[
             0.24363580909960866`, 0.3734070611391507, 0.9371860709501183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 308}], {
             RGBColor[
             0.2493864248848615, 0.3794513229395511, 0.9375135600118147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 309}], {
             RGBColor[
             0.25423745991444247`, 0.38455006832902616`, 0.9377898192802863]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 397}], {
             RGBColor[
             0.24351700983454236`, 0.3732821955792575, 0.9371793055077206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 135}], {
             RGBColor[
             0.4568418198608912, 0.568758623177035, 0.9507053486499384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 147}], {
             RGBColor[
             0.34757171171070933`, 0.4732511609805692, 0.9434492148065551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 158}], {
             RGBColor[
             0.4567607455909806, 0.5686928034323673, 0.9506989661864262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 172}], {
             RGBColor[
             0.3559151258566954, 0.4820206182510111, 0.9439243598991939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 181}], {
             RGBColor[
             0.48885894126290724`, 0.5947515646860737, 0.9532258537292853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 265}], {
             RGBColor[
             0.5011501438603255, 0.6047301166670249, 0.9541934622219126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 322}], {
             RGBColor[
             0.45941085843753277`, 0.5708442844274215, 0.95090759277739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 328}], {
             RGBColor[
             0.3599213877466876, 0.48616754871640405`, 0.9441548504546003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 347}], {
             RGBColor[
             0.34522783768479254`, 0.47078760076913406`, 0.9433157346482299]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 362}], {
             RGBColor[
             0.40753230852825906`, 0.5274057353029433, 0.9471885762261179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 364}], {
             RGBColor[
             0.379967678176128, 0.5035306379305324, 0.9454321823545258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 387}], {
             RGBColor[
             0.35198717062244894`, 0.47789208825307206`, 0.9437006686594926]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 215}], {
             RGBColor[
             0.8708771882594211, 0.43978719004972067`, 0.21128818862239418`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 217}], {
             RGBColor[
             0.8726459244985081, 0.4533824718485052, 0.21298193244244573`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 262}], {
             RGBColor[
             0.9305545199558635, 0.8420358975584873, 0.6226092420681639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 269}], {
             RGBColor[
             0.9577625542405059, 0.8589366723660075, 0.3711790558606476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 279}], {
             RGBColor[
             0.934057909721427, 0.776268616484077, 0.26579965018330676`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 297}], {
             RGBColor[
             0.9345525999537521, 0.8450176590746574, 0.6158415354980056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 300}], {
             RGBColor[
             0.9062314787117222, 0.661847076989811, 0.24319781291959908`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 306}], {
             RGBColor[
             0.9464211476308863, 0.8210225463454206, 0.2979449525140816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 307}], {
             RGBColor[
             0.9538530771213425, 0.8592378166634234, 0.5753740091193393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 314}], {
             RGBColor[
             0.9241390802378358, 0.8369963141242439, 0.6246293196235244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 352}], {
             RGBColor[
             0.9583101575279735, 0.8601079404267151, 0.43078229428572945`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 363}], {
             RGBColor[
             0.8924893365860593, 0.5994472191560132, 0.23173103267921852`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 140}], {
             RGBColor[
             0.7355736784173503, 0.7933550152374292, 0.9742787680039452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 191}], {
             RGBColor[
             0.7390378619070974, 0.7960612617083893, 0.9746240454395679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 198}], {
             RGBColor[
             0.8128559952710535, 0.8537811311091374, 0.9819675933041132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 216}], {
             RGBColor[
             0.7291619678468395, 0.7883461382089411, 0.9736397086151186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 219}], {
             RGBColor[
             0.6232051027562657, 0.7024156086050097, 0.9651690328906872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 220}], {
             RGBColor[
             0.6373284381573086, 0.7140480166379533, 0.9662348834814941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 302}], {
             RGBColor[
             0.8932496977556434, 0.905911220002762, 0.6928483915783341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 323}], {
             RGBColor[
             0.8147163030891271, 0.8552644900665589, 0.9821450311245175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 357}], {
             RGBColor[
             0.7374562321167385, 0.7948256804953293, 0.9744664033632358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 145}], {
             RGBColor[
             0.26764114093786784`, 0.3986381869271076, 0.9385531390856012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 164}], {
             RGBColor[
             0.2698983654154672, 0.40101067296936244`, 0.9386816846803361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 223}], {
             RGBColor[
             0.3756627076897743, 0.49871942307299955`, 0.945202383630783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 234}], {
             RGBColor[
             0.31799880832538563`, 0.4487941940432452, 0.9415224703076799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 280}], {
             RGBColor[
             0.26813571605602704`, 0.3991580167341666, 0.938581304406922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 346}], {
             RGBColor[
             0.32114511749891506`, 0.4515193689112592, 0.9417229503460453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 167}], {
             RGBColor[
             0.25893816716997997`, 0.3894908096966502, 0.9380575176044159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 201}], {
             RGBColor[
             0.255376576823433, 0.3857473524245587, 0.9378546903030808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 236}], {
             RGBColor[
             0.24242453355158805`, 0.3721339337388756, 0.9371170905995801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 243}], {
             RGBColor[
             0.2613494095308073, 0.3920251782994754, 0.9381948342897516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 263}], {
             RGBColor[
             0.24820523859568883`, 0.3782098212580943, 0.9374462932000549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 348}], {
             RGBColor[
             0.24864104476606846`, 0.3786678811748705, 0.9374711117167406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 351}], {
             RGBColor[
             0.24003567899790235`, 0.3696230961408251, 0.9369810488667414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 221}], {
             RGBColor[
             0.7125684826637311, 0.7740760557086418, 0.9732239792621271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 276}], {
             RGBColor[
             0.6344220971523353, 0.7122040883931675, 0.9656535874330512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 322}], {
             RGBColor[
             0.5058470879872912, 0.6097084800365293, 0.954241282226749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 364}], {
             RGBColor[
             0.42640390772588643`, 0.5423948335396401, 0.9487658718038847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 376}], {
             RGBColor[
             0.47083567399736015`, 0.5808793962784845, 0.9515970246612349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 377}], {
             RGBColor[
             0.4590787183907463, 0.5706961122538062, 0.9508478818462491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 194}], {
             RGBColor[
             0.5033185862068833, 0.6058836865205527, 0.954531849750919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 237}], {
             RGBColor[
             0.59850057250929, 0.6849287527633994, 0.9615353039292178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 246}], {
             RGBColor[
             0.5311924849620417, 0.6300266566393842, 0.9563079499316767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 254}], {
             RGBColor[
             0.5440467518592814, 0.6407206880430576, 0.9572484996967315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 286}], {
             RGBColor[
             0.6724159966518739, 0.7436515226508849, 0.9682328276448666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 320}], {
             RGBColor[
             0.6642380668783059, 0.7372628617572051, 0.9674177280321361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 343}], {
             RGBColor[
             0.6703913429941837, 0.7420698478255596, 0.9680310290897323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 349}], {
             RGBColor[
             0.5319806271096528, 0.6307093057544687, 0.9563581696523957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 376}], {
             RGBColor[
             0.5284877060748537, 0.6276839131134415, 0.9561356038127271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 199}], {
             RGBColor[
             0.22367942926895015`, 0.3524316406295666, 0.9360495846415806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 238}], {
             RGBColor[
             0.22538960071026484`, 0.3542291392455204, 0.9361469763751915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 252}], {
             RGBColor[
             0.22294460960746476`, 0.35165929857508804`, 0.9360077377489273]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 277}], {
             RGBColor[
             0.23968446191505444`, 0.36925394471830275`, 0.9369610475734522]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 285}], {
             RGBColor[
             0.23013560035880143`, 0.35921748578989005`, 0.9364172540340985]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 293}], {
             RGBColor[
             0.2163935789679292, 0.34477375001360355`, 0.9356346662453872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 330}], {
             RGBColor[
             0.22316402213431713`, 0.35188991505236755`, 0.9360202329677398]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 144}], {
             RGBColor[
             0.8488904911809813, 0.34529052811745564`, 0.1932170904993126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 233}], {
             RGBColor[
             0.8184005545424529, 0.14244030215351539`, 0.165253697851294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 242}], {
             RGBColor[
             0.8688448581678534, 0.4318314305529642, 0.2096571104877158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 256}], {
             RGBColor[
             0.522325620948562, 0.25191357841785655`, 0.5511492082429574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 257}], {
             RGBColor[
             0.8209750230584517, 0.16222879530677942`, 0.1677190118096608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 317}], {
             RGBColor[
             0.9049849697863369, 0.5700377324760639, 0.4855767081666582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 366}], {
             RGBColor[
             0.8603116610551809, 0.39715139303420033`, 0.20274719460083632`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 381}], {
             RGBColor[
             0.9062449527279615, 0.5705587678025101, 0.4646955300926113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 382}], {
             RGBColor[
             0.8590618993454652, 0.3914765169996446, 0.2017043627957868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 184}], {
             RGBColor[
             0.21446679583023515`, 0.34274857877078024`, 0.9355249387961155]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 305}], {
             RGBColor[
             0.20703664012749182`, 0.3349390140281161, 0.9351018024207747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 325}], {
             RGBColor[
             0.21136919529828035`, 0.33949280421247857`, 0.9353485350283102]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 141}], {
             RGBColor[
             0.5159944713875729, 0.6149616035084853, 0.9560493981699523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 168}], {
             RGBColor[
             0.6710377427034506, 0.7429390517664531, 0.9678464290545918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 191}], {
             RGBColor[
             0.6753891788981803, 0.7463384267939157, 0.9682801395479993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 216}], {
             RGBColor[
             0.6655132848379224, 0.7386233032944675, 0.96729580272355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 219}], {
             RGBColor[
             0.5595564197473485, 0.6526927736905361, 0.9588251269991186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 220}], {
             RGBColor[
             0.5736797551483913, 0.6643251817234797, 0.9598909775899255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 350}], {
             RGBColor[
             0.5523338730537959, 0.6464369667603329, 0.9583649127104528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 357}], {
             RGBColor[
             0.6738075491078213, 0.7451028455808557, 0.9681224974716671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 150}], {
             RGBColor[
             0.3153323622893313, 0.4440199894984804, 0.9414428101102743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 189}], {
             RGBColor[
             0.33030534537683665`, 0.4597575440654077, 0.9422954993465642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 219}], {
             RGBColor[
             0.4036258957264883, 0.5240221968760659, 0.9469396630566943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 220}], {
             RGBColor[
             0.4177492311275311, 0.5356546049090093, 0.9480055136475012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 273}], {
             RGBColor[
             0.31775067217972763`, 0.44656178652298995`, 0.9415805292809634]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 339}], {
             RGBColor[
             0.36291222472736206`, 0.48875806138522676`, 0.9443454239423157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 350}], {
             RGBColor[
             0.3964033490329356, 0.5177663899458625, 0.9464794487680284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 357}], {
             RGBColor[
             0.5178770250869611, 0.6164322687663853, 0.9562370335292427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 394}], {
             RGBColor[
             0.3594659493572627, 0.4857730708744833, 0.9441258303231546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 202}], {
             RGBColor[
             0.8389617996732674, 0.300483042224024, 0.18494316940916705`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 214}], {
             RGBColor[
             0.9026785336009098, 0.577164017789306, 0.5403271212608096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 217}], {
             RGBColor[
             0.8222048215005642, 0.17168156503396934`, 0.16889666818668636`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 257}], {
             RGBColor[
             0.822095571600614, 0.17084182242934073`, 0.16879205035911396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 268}], {
             RGBColor[
             0.8194514867475214, 0.1505182276031009, 0.16626007171772583`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 275}], {
             RGBColor[
             0.906842307128124, 0.5789554407018784, 0.47443924955803846`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 279}], {
             RGBColor[
             0.8836168067234831, 0.49456770966954106`, 0.2217143859275474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 300}], {
             RGBColor[
             0.8557903757137784, 0.38014617017527513`, 0.1991125486638397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 306}], {
             RGBColor[
             0.8959800446329425, 0.5393216395308846, 0.25385968825832217`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 338}], {
             RGBColor[
             0.9079361737525008, 0.5785505948422507, 0.3940025431841314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 363}], {
             RGBColor[
             0.8420482335881154, 0.3177463123414773, 0.18764576842345915`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 381}], {
             RGBColor[
             0.9073655012701238, 0.5791717949250715, 0.46576856864206445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 223}], {
             RGBColor[
             0.5393557196395969, 0.6369122967585245, 0.9568792044565808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 234}], {
             RGBColor[
             0.4816918202752083, 0.5869870677287701, 0.9531992911334777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 260}], {
             RGBColor[
             0.7167991404658595, 0.7784168360748085, 0.9725930329082488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 267}], {
             RGBColor[
             0.5979215961089128, 0.6844587136389835, 0.9614897247861196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 272}], {
             RGBColor[
             0.635830587523557, 0.7151635871324875, 0.9645228442451073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 290}], {
             RGBColor[
             0.5148889820990041, 0.6157407807626738, 0.9553145849297924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 291}], {
             RGBColor[
             0.6605679134983766, 0.7344885741946573, 0.9669884297148228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 321}], {
             RGBColor[
             0.7212153553030598, 0.7818668166701053, 0.973033199931347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 331}], {
             RGBColor[
             0.5383683584932644, 0.6360774364876114, 0.9568106700316372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 342}], {
             RGBColor[
             0.6140012232637606, 0.6975128793422373, 0.9627555719373643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 398}], {
             RGBColor[
             0.7820348247548993, 0.8302487551810782, 0.97550730112162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 207}], {
             RGBColor[
             0.9091469621070289, 0.6700765235430096, 0.2453714490760957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 233}], {
             RGBColor[
             0.8479481693127158, 0.33804742930989184`, 0.1923147220140613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 242}], {
             RGBColor[
             0.8983924729381163, 0.6274385577093406, 0.23671813465048305`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 317}], {
             RGBColor[
             0.9345325845565998, 0.7656448596324403, 0.5126377323294256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 358}], {
             RGBColor[
             0.9235073892649484, 0.7232807673563957, 0.2763524253689754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 366}], {
             RGBColor[
             0.8898592758254438, 0.5927585201905767, 0.22980821876360358`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 370}], {
             RGBColor[
             0.8548273648949809, 0.7045756223106869, 0.6020207461756493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 391}], {
             RGBColor[
             0.8494144480971886, 0.3493178905748092, 0.19371883223399736`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 162}], {
             RGBColor[
             0.2420540274215789, 0.3717445083047905, 0.9370959908235907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 164}], {
             RGBColor[
             0.2402812832877892, 0.36988124182170756`, 0.9369950356677115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 227}], {
             RGBColor[
             0.23647303514531387`, 0.36587853156708794`, 0.9367781615697957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 280}], {
             RGBColor[
             0.23851863392834902`, 0.36802858558651175`, 0.9368946553942974]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 359}], {
             RGBColor[
             0.24179608967805666`, 0.37147339938215107`, 0.9370813016506819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 154}], {
             RGBColor[
             0.48274463326921224`, 0.5903240190384458, 0.9525963248033308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 159}], {
             RGBColor[
             0.433382915877228, 0.5475693804255631, 0.9494510398199664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 165}], {
             RGBColor[
             0.5340400056803238, 0.6325967606962016, 0.956460731981605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 192}], {
             RGBColor[
             0.43991049068666355`, 0.5532232376400468, 0.9498669711147159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 228}], {
             RGBColor[
             0.45159420731101624`, 0.5633430857393887, 0.9506114472065146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 262}], {
             RGBColor[
             0.736987048840004, 0.7937027834714817, 0.9726540973253948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 297}], {
             RGBColor[
             0.7409851288378926, 0.7966845449876518, 0.9658863907552364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 307}], {
             RGBColor[
             0.760285606005483, 0.8109047025764178, 0.9254188643765703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 314}], {
             RGBColor[
             0.7305716091219763, 0.7886632000372383, 0.9746741748807553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 332}], {
             RGBColor[
             0.53127642233297, 0.6303531592368088, 0.9562431725771618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 385}], {
             RGBColor[
             0.5553761412741389, 0.6499183967532158, 0.95814039073239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 172}], {
             RGBColor[
             0.29308124725627194`, 0.4253773516636531, 0.9400019155051696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 211}], {
             RGBColor[
             0.2737075152920192, 0.40501433100367, 0.9388986101306735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 328}], {
             RGBColor[
             0.29708750914626414`, 0.42952428212904603`, 0.9402324060605761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 347}], {
             RGBColor[
             0.28239395908436904`, 0.4141443341817761, 0.9393932902542057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 364}], {
             RGBColor[
             0.31713379957570453`, 0.44688737134317436`, 0.9415097379605015]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 372}], {
             RGBColor[
             0.2681076692483716, 0.3991285377610505, 0.9385797071827175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 387}], {
             RGBColor[
             0.28915329202202544`, 0.42124882166571403`, 0.9397782242654684]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 161}], {
             RGBColor[
             0.5276623353729026, 0.6268249505740837, 0.9561228183174523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 168}], {
             RGBColor[
             0.6470192572483401, 0.7238926765948177, 0.9656459465719469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 170}], {
             RGBColor[
             0.5344288299346016, 0.632685748069522, 0.9565539733675475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 251}], {
             RGBColor[
             0.723101933884062, 0.7833478892534567, 0.9732241552199159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 282}], {
             RGBColor[
             0.6353748988917614, 0.714796015346257, 0.9644853457536787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 312}], {
             RGBColor[
             0.5434225996528742, 0.6402139731641597, 0.9571993641486982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 326}], {
             RGBColor[
             0.4816391300864997, 0.5869619633485583, 0.9531902603733251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 356}], {
             RGBColor[
             0.5711332147381206, 0.6627106988393463, 0.9593808452755366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 199}], {
             RGBColor[
             0.2230106997449548, 0.3517287634999468, 0.9360115014844858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 212}], {
             RGBColor[
             0.21555790485274898`, 0.34389540353375003`, 0.9355870758407967]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 238}], {
             RGBColor[
             0.2247208711862695, 0.3535262621159006, 0.9361088932180968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 259}], {
             RGBColor[
             0.21561966255991427`, 0.3439603147996455, 0.9355905928508573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 274}], {
             RGBColor[
             0.22547330397154366`, 0.35431711668021776`, 0.9361517431520935]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 287}], {
             RGBColor[
             0.24021601426247097`, 0.36981263993780294`, 0.9369913186932763]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 299}], {
             RGBColor[
             0.21717366869177715`, 0.345593673773913, 0.9356790912011209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 318}], {
             RGBColor[
             0.22201805165799737`, 0.3506854274230307, 0.9359549716444248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 336}], {
             RGBColor[
             0.21561259787663173`, 0.3439528893695888, 0.9355901905275956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 367}], {
             RGBColor[
             0.21976666504097775`, 0.348319077342387, 0.9358267585072135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 186}], {
             RGBColor[
             0.2595342246109202, 0.3901173038593028, 0.9380914621938894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 189}], {
             RGBColor[
             0.28557376029945525`, 0.4174865068698732, 0.9395743752293106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 226}], {
             RGBColor[
             0.2546174021107136, 0.38494941166703367`, 0.9378114564262897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 241}], {
             RGBColor[
             0.2807813627744614, 0.41244939321555174`, 0.939301455279979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 255}], {
             RGBColor[
             0.26553787758684655`, 0.39642752379058566`, 0.9384333613492598]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 266}], {
             RGBColor[
             0.2627993543398047, 0.39354916222554226`, 0.9382774065016228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 365}], {
             RGBColor[
             0.26342074735738313`, 0.39420228568561005`, 0.9383127939147053]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 374}], {
             RGBColor[
             0.2733522518909328, 0.4046409266441276, 0.9388783784055468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 399}], {
             RGBColor[
             0.2527398969113101, 0.3829760346617555, 0.9377045352827038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 171}], {
             RGBColor[
             0.294524052203641, 0.4262383567855898, 0.940108081239609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 182}], {
             RGBColor[
             0.301964914813191, 0.43405917516616493`, 0.9405318273574531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 244}], {
             RGBColor[
             0.28793584651295273`, 0.41931373488830953`, 0.9397328926719012]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 249}], {
             RGBColor[
             0.2927023996318287, 0.42432368443317114`, 0.9400043408205379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 253}], {
             RGBColor[
             0.3287756481732377, 0.4591906745282696, 0.9421702714700763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 270}], {
             RGBColor[
             0.28271133263489734`, 0.4138224395491612, 0.9394353643355215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 308}], {
             RGBColor[
             0.28846194842015016`, 0.41986670134956156`, 0.9397628533972181]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 386}], {
             RGBColor[
             0.3275993292124569, 0.45817180616795133`, 0.9420953174660733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 397}], {
             RGBColor[
             0.28259253336983103`, 0.413697573989268, 0.9394285988931239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 156}], {
             RGBColor[
             0.18478785261667285`, 0.31155412769964164`, 0.9338347668861651]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 175}], {
             RGBColor[
             0.181274153781999, 0.307861007443026, 0.9336346669355821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 242}], {
             RGBColor[
             0.5509815030039178, 0.5121510355041116, 0.5934630978551525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 256}], {
             RGBColor[
             0.2044622657846265, 0.33223318336900387`, 0.9349551956103941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 261}], {
             RGBColor[
             0.18153226782756765`, 0.3081323016702944, 0.9336493661486316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 264}], {
             RGBColor[
             0.186823590274237, 0.31369381705096394`, 0.9339506991341594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 317}], {
             RGBColor[
             0.5871216146224013, 0.6503573374272111, 0.8693826955340949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 333}], {
             RGBColor[
             0.18958831081692415`, 0.31659971363473505`, 0.9341081458790279]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 381}], {
             RGBColor[
             0.588381597564026, 0.6508783727536576, 0.8485015174600479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 154}], {
             RGBColor[
             0.3737943950019111, 0.49818365032325973`, 0.9450388262094847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 188}], {
             RGBColor[
             0.2922583395910017, 0.4237094580639409, 0.939984452630228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 195}], {
             RGBColor[
             0.2815627334149148, 0.41246769783227444`, 0.9393753536812313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 203}], {
             RGBColor[
             0.3044141682214503, 0.43648600467859244`, 0.9406767090877951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 258}], {
             RGBColor[
             0.28518201112076286`, 0.41627178817658117`, 0.9395814661923377]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 278}], {
             RGBColor[
             0.284923192180341, 0.41599975306012926`, 0.939566726836569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 284}], {
             RGBColor[
             0.2807144253547577, 0.4115760722752118, 0.9393270437921646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 312}], {
             RGBColor[
             0.39019396776607296`, 0.5121264097897626, 0.9461561082120249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 327}], {
             RGBColor[
             0.31801144721476193`, 0.44986726468250904`, 0.9414843861034113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 337}], {
             RGBColor[
             0.30108704647180895`, 0.43298898876801645`, 0.9404872344261885]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[
             0.4179045828513193, 0.5346231354649491, 0.9483375893388631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 361}], {
             RGBColor[
             0.3365286408445437, 0.46590592710341294`, 0.9426642853073897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 369}], {
             RGBColor[
             0.28744235484774583`, 0.41864755274771004`, 0.9397101894237105]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 392}], {
             RGBColor[
             0.28268998646480836`, 0.4136525122596839, 0.9394395490748012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 192}], {
             RGBColor[
             0.3873238866966642, 0.5099022160172301, 0.9459009134566145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 203}], {
             RGBColor[
             0.36077780249875213`, 0.4853053517709617, 0.9442681500235399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 222}], {
             RGBColor[
             0.5175424648922109, 0.6185744663744461, 0.9553357375773506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 228}], {
             RGBColor[
             0.39900760332101687`, 0.520022064116572, 0.9466453895484133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 312}], {
             RGBColor[
             0.4465576020433747, 0.5609457568821319, 0.9497475491477698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 332}], {
             RGBColor[
             0.47868981834297064`, 0.5870321376139921, 0.9522771149190605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 356}], {
             RGBColor[
             0.4742682171286211, 0.5834424825573183, 0.951929030274608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 361}], {
             RGBColor[
             0.39289227512184555`, 0.5147252741957822, 0.9462557262431346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 385}], {
             RGBColor[
             0.5027895372841396, 0.606597375130399, 0.9541743330742887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 170}], {
             RGBColor[
             0.3747576276064379, 0.498629600146848, 0.9451144220759548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 180}], {
             RGBColor[
             0.33540782096983857`, 0.46454677541701367`, 0.9426070871927383]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 183}], {
             RGBColor[
             0.2817396246657633, 0.4134565872206231, 0.9393560268770672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 239}], {
             RGBColor[
             0.3145302695292589, 0.4464636896954298, 0.9412767880762385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 271}], {
             RGBColor[
             0.305666751429035, 0.4386055145162801, 0.9407186413492236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 326}], {
             RGBColor[
             0.32196792775833594`, 0.4529058154258842, 0.9417507090817323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 335}], {
             RGBColor[
             0.29253189959404885`, 0.42479995244000324`, 0.9399706309684931]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 337}], {
             RGBColor[
             0.29464447603044647`, 0.42702040421973947`, 0.9400909390712692]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 354}], {
             RGBColor[
             0.29215952785429067`, 0.42440856613178546`, 0.9399494249487885]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 175}], {
             RGBColor[
             0.18244584031582461`, 0.30909252427929373`, 0.9337013927503286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 202}], {
             RGBColor[
             0.5211495825009953, 0.37342113688887774`, 0.567742844041897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 214}], {
             RGBColor[
             0.5848663164286375, 0.6501021124541597, 0.9231267958935396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 256}], {
             RGBColor[
             0.20563395231845213`, 0.3334647002052716, 0.9350219214251405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 261}], {
             RGBColor[
             0.18270395436139325`, 0.3093638185065621, 0.9337160919633781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 264}], {
             RGBColor[
             0.1879952768080626, 0.31492533388723165`, 0.9340174249489059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 295}], {
             RGBColor[
             0.2141734445733891, 0.3424402480002911, 0.9355082328760125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 310}], {
             RGBColor[
             0.1842688448604277, 0.3110086176408356, 0.93380521016225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 363}], {
             RGBColor[
             0.5242360164158433, 0.390684407006331, 0.5704454430561892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 381}], {
             RGBColor[
             0.5895532840978516, 0.6521098895899253, 0.8485682432747944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 187}], {
             RGBColor[
             0.656588840938115, 0.7291931341002164, 0.9681680488654731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 218}], {
             RGBColor[
             0.689653807893005, 0.7555582412254274, 0.971321814931075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 253}], {
             RGBColor[
             0.40547981020843754`, 0.5251955404755204, 0.9471772728723662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 298}], {
             RGBColor[
             0.6463369873520685, 0.7210185843298552, 0.9671902179184984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 181}], {
             RGBColor[
             0.5352140965427551, 0.633549940550514, 0.9565531607151321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 265}], {
             RGBColor[
             0.5475052991401734, 0.643528492531465, 0.9575207692077594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 311}], {
             RGBColor[
             0.5112449698673547, 0.6140907237185725, 0.9546662232614405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 322}], {
             RGBColor[
             0.5057660137173806, 0.6096426602918618, 0.9542348997632368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 362}], {
             RGBColor[
             0.4538874638081069, 0.5662041111673836, 0.9505158832119648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 165}], {
             RGBColor[
             0.43209168429834016`, 0.5465211004605023, 0.9493493893401392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 167}], {
             RGBColor[
             0.30749203096032607`, 0.43842628345076595`, 0.9408993959616536]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 192}], {
             RGBColor[
             0.3379621693046799, 0.46714757740434754`, 0.9427556284732501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 201}], {
             RGBColor[
             0.30393044061377905`, 0.43468282617867443`, 0.9406965686603185]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 210}], {
             RGBColor[
             0.3156791522092831, 0.44703146697688845`, 0.9413656404050212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 228}], {
             RGBColor[
             0.3496458859290326, 0.47726742550368945`, 0.9435001045650488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 236}], {
             RGBColor[
             0.2909783973419341, 0.4210694074929913, 0.9399589689568179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 243}], {
             RGBColor[
             0.3099032733211534, 0.44096065205359114`, 0.9410367126469893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 263}], {
             RGBColor[
             0.29675910238603487`, 0.4271452950122101, 0.9402881715572926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 166}], {
             RGBColor[
             0.8271233428626157, 0.2094874755325008, 0.1736066497976622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 185}], {
             RGBColor[
             0.8265840327508944, 0.20534210168661424`, 0.17309020582561438`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 213}], {
             RGBColor[
             0.8702228477750129, 0.45615422864304855`, 0.21154106500959308`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 224}], {
             RGBColor[
             0.9025695450570996, 0.5785729407895561, 0.26790552836760506`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 247}], {
             RGBColor[
             0.8682425607038025, 0.44830305029724704`, 0.2099476795487854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 289}], {
             RGBColor[
             0.863615444991354, 0.42809333252077686`, 0.20612813226240806`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 302}], {
             RGBColor[
             0.9083773079386029, 0.59816388871644, 0.2904675904582531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 340}], {
             RGBColor[
             0.9116278550257833, 0.6083417789954149, 0.37001345675471364`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 370}], {
             RGBColor[
             0.8303471028154521, 0.5479183884634005, 0.5798122246722852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 400}], {
             RGBColor[
             0.6095442446912597, 0.3697331530727862, 0.5609538560304888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 170}], {
             RGBColor[
             0.43820314080929235`, 0.5539712686639211, 0.9491428945379133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 222}], {
             RGBColor[
             0.5181817733764011, 0.6191282032508729, 0.9553764737486448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 239}], {
             RGBColor[
             0.3779757827321134, 0.5018053582125028, 0.9453052605381971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 251}], {
             RGBColor[
             0.6268762447587527, 0.7046334098478555, 0.9658130763902817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 312}], {
             RGBColor[
             0.44719691052756494`, 0.5614994937585587, 0.949788285319064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 326}], {
             RGBColor[
             0.3854134409611904, 0.5082474839429573, 0.9457791815436909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 327}], {
             RGBColor[
             0.3750143899762539, 0.4992403486513052, 0.9451165632104506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 337}], {
             RGBColor[
             0.35808998923330093`, 0.48236207273681253`, 0.9441194115332278]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 356}], {
             RGBColor[
             0.47490752561281135`, 0.5839962194337451, 0.9519697664459024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 179}], {
             RGBColor[
             0.25786357675267113`, 0.38836134703509095`, 0.9379963212698641]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 231}], {
             RGBColor[
             0.27738405997012383`, 0.4088786125667542, 0.9391079839111312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 313}], {
             RGBColor[
             0.26444617460999714`, 0.3952800747439503, 0.938371190479758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 359}], {
             RGBColor[
             0.24582605828944576`, 0.3757091519074889, 0.9373108024012962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 164}], {
             RGBColor[
             0.24375587866941067`, 0.373533261869863, 0.9371929087344915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 169}], {
             RGBColor[
             0.23283585906700827`, 0.36205562889850595`, 0.936571029772856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 209}], {
             RGBColor[
             0.2485031193706023, 0.3785229128392603, 0.9374632570695112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 227}], {
             RGBColor[
             0.23994763052693538`, 0.3695305516152434, 0.9369760346365759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 240}], {
             RGBColor[
             0.2420898799764604, 0.3717821916131542, 0.9370980325735522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 245}], {
             RGBColor[
             0.2374360489235272, 0.36689072010659024`, 0.9368330037798137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 280}], {
             RGBColor[
             0.24199322930997053`, 0.37168060563466715`, 0.9370925284610774]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 304}], {
             RGBColor[
             0.23203584179739814`, 0.3612147600241211, 0.9365254699728711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 315}], {
             RGBColor[
             0.24412373790812583`, 0.3739199052533755, 0.9372138577739373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 319}], {
             RGBColor[
             0.2432784612852803, 0.3730314659291315, 0.9371657205207411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 329}], {
             RGBColor[
             0.2400560374603316, 0.3696444941756393, 0.936982208251059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 371}], {
             RGBColor[
             0.25850942763125473`, 0.3890401772577931, 0.9380331015219487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 169}], {
             RGBColor[
             0.23161848816298614`, 0.3607760948926053, 0.9365017023008109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 209}], {
             RGBColor[
             0.24728574846658016`, 0.37724337883335973`, 0.9373939295974659]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 227}], {
             RGBColor[
             0.23873025962291325`, 0.36825101760934276`, 0.9369067071645306]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 245}], {
             RGBColor[
             0.23621867801950508`, 0.36561118610068966`, 0.9367636763077685]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 280}], {
             RGBColor[
             0.2407758584059484, 0.37040107162876656`, 0.9370232009890322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 304}], {
             RGBColor[
             0.230818470893376, 0.3599352260182205, 0.936456142500826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 315}], {
             RGBColor[
             0.2429063670041037, 0.37264037124747484`, 0.9371445303018922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 228}], {
             RGBColor[
             0.4503029757321284, 0.5622948057743279, 0.9505097967266875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 262}], {
             RGBColor[
             0.7356958172611161, 0.7926545035064209, 0.9725524468455675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 298}], {
             RGBColor[
             0.6780894534855002, 0.7467966667692734, 0.969689888365638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 307}], {
             RGBColor[
             0.7589943744265952, 0.8098564226113569, 0.9253172138967432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 314}], {
             RGBColor[
             0.7292803775430885, 0.7876149200721775, 0.9745725244009281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 332}], {
             RGBColor[
             0.5299851907540822, 0.6293048792717479, 0.9561415220973347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 385}], {
             RGBColor[
             0.5540849096952511, 0.648870116788155, 0.9580387402525627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 185}], {
             RGBColor[
             0.8242297938213237, 0.1872463896398561, 0.17083578396792481`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 213}], {
             RGBColor[
             0.8678686088454421, 0.43805851659629047`, 0.20928664315190354`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 224}], {
             RGBColor[
             0.9002153061275288, 0.5604772287427979, 0.2656511065099155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 247}], {
             RGBColor[
             0.8658883217742317, 0.43020733825048896`, 0.20769325769109587`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 289}], {
             RGBColor[
             0.8612612060617832, 0.40999762047401866`, 0.2038737104047185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 302}], {
             RGBColor[
             0.9060230690090321, 0.580068176669682, 0.28821316860056356`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 340}], {
             RGBColor[
             0.9092736160962124, 0.5902460669486567, 0.36775903489702405`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 400}], {
             RGBColor[
             0.6071900057616888, 0.351637441026028, 0.5586994341727993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 192}], {
             RGBColor[
             0.3140196057697616, 0.4440801406652496, 0.941315327256403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 201}], {
             RGBColor[
             0.27998787707886075`, 0.41161538943957654`, 0.9392562674434715]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 203}], {
             RGBColor[
             0.2874735215718495, 0.4194832764189812, 0.9396825638233285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 228}], {
             RGBColor[
             0.32570332239411426`, 0.45419998876459156`, 0.9420598033482018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 243}], {
             RGBColor[
             0.28596070978623506`, 0.41789321531449325`, 0.9395964114301423]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 348}], {
             RGBColor[
             0.2732523450214962, 0.4045359181898883, 0.9388726888571313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 351}], {
             RGBColor[
             0.2646469792533301, 0.39549113315584294`, 0.938382626007132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 170}], {
             RGBColor[
             0.5575600626847299, 0.651038994684655, 0.958666022792408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 180}], {
             RGBColor[
             0.5182102560481305, 0.6169561699548207, 0.9561586879091916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 220}], {
             RGBColor[
             0.5727925024434088, 0.663632053166977, 0.9598025445321408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 251}], {
             RGBColor[
             0.7462331666341901, 0.8017011358685895, 0.9753362046447762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 282}], {
             RGBColor[
             0.6585061316418895, 0.73314926196139, 0.9665973951785392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 350}], {
             RGBColor[
             0.5514466203488134, 0.6457438382038303, 0.9582764796526682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 357}], {
             RGBColor[
             0.6729202964028389, 0.7444097170243531, 0.9680340644138824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 394}], {
             RGBColor[
             0.5145092206731405, 0.613750519132451, 0.9559228612077943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 209}], {
             RGBColor[
             0.23636572886417778`, 0.36576574586200267`, 0.9367720506358304]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 227}], {
             RGBColor[
             0.22781024002051087`, 0.3567733846379857, 0.936284828202895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 240}], {
             RGBColor[
             0.22995248947003588`, 0.35902502463589653`, 0.9364068261398715]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 245}], {
             RGBColor[
             0.22529865841710267`, 0.3541335531293326, 0.936141797346133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 280}], {
             RGBColor[
             0.229855838803546, 0.3589234386574095, 0.9364013220273968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 292}], {
             RGBColor[
             0.21585857380573317`, 0.34421142566684904`, 0.9356041984928691]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 304}], {
             RGBColor[
             0.21989845129097363`, 0.3484575930468634, 0.9358342635391905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 315}], {
             RGBColor[
             0.23198634740170132`, 0.3611627382761178, 0.9365226513402567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 329}], {
             RGBColor[
             0.22791864695390707`, 0.3568873271983817, 0.9362910018173783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 353}], {
             RGBColor[
             0.21553905850906607`, 0.343875594831612, 0.9355860025694045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 378}], {
             RGBColor[
             0.21461245212241514`, 0.34290167276900374`, 0.9355332337064761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 180}], {
             RGBColor[
             0.40561982873439206`, 0.5257492414295251, 0.9470667147047922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 239}], {
             RGBColor[
             0.38474227729381244`, 0.5076661557079413, 0.9457364155882924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 251}], {
             RGBColor[
             0.6336427393204518, 0.7104942073432939, 0.966244231440377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 271}], {
             RGBColor[
             0.37587875919358854`, 0.49980798052879155`, 0.9451782688612774]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 282}], {
             RGBColor[
             0.5459157043281511, 0.6419423334360943, 0.9575054219741398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 326}], {
             RGBColor[
             0.39217993552288943`, 0.5141082814383957, 0.9462103365937862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 182}], {
             RGBColor[
             0.2806534492526592, 0.41231494799395196`, 0.9392941707941435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 244}], {
             RGBColor[
             0.266624380952421, 0.39756950771609656`, 0.9384952361085915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 253}], {
             RGBColor[
             0.30746418261270597`, 0.43744644735605664`, 0.9409326149067666]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 270}], {
             RGBColor[
             0.2613998670743656, 0.3920782123769482, 0.9381977077722119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 308}], {
             RGBColor[
             0.26715048285961845`, 0.3981224741773486, 0.9385251968339084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 397}], {
             RGBColor[
             0.26128106780929927`, 0.39195334681705507`, 0.9381909423298143]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 211}], {
             RGBColor[
             0.2820509294380053, 0.413783788274112, 0.9393737552233123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 328}], {
             RGBColor[
             0.3054309232922502, 0.438293739399488, 0.9407075511532149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 347}], {
             RGBColor[
             0.29073737323035515`, 0.422913791452218, 0.9398684353468445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 364}], {
             RGBColor[
             0.3254772137216906, 0.45565682861361634`, 0.9419848830531403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 387}], {
             RGBColor[
             0.29749670616801155`, 0.43001827893615596`, 0.9402533693581072]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 175}], {
             RGBColor[
             0.20264987627198583`, 0.3303282470790865, 0.9348519827088393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 197}], {
             RGBColor[
             0.607559522477704, 0.6724367666110929, 0.8861420267905455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 204}], {
             RGBColor[
             0.20264730553141047`, 0.33032554506774736`, 0.9348518363089665]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 214}], {
             RGBColor[
             0.6050703523847987, 0.6713378352539525, 0.9242773858520503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 261}], {
             RGBColor[
             0.2029079903175545, 0.3305995413063548, 0.9348666819218888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 295}], {
             RGBColor[
             0.23437748052955032`, 0.36367597080008385`, 0.9366588228345232]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 310}], {
             RGBColor[
             0.20447288081658893`, 0.33224434044062834`, 0.9349558001207607]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 345}], {
             RGBColor[
             0.21415750276433887`, 0.34242349214821033`, 0.9355073250135709]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 193}], {
             RGBColor[
             0.7754724977883137, 0.8245433157037161, 0.9782504569369469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 232}], {
             RGBColor[
             0.6270810139261389, 0.7068104580353534, 0.9646885621008761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 235}], {
             RGBColor[
             0.7343495307888845, 0.7923987018062052, 0.9741567564086497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 260}], {
             RGBColor[
             0.7687797089830702, 0.819295818690549, 0.9775884348027377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 267}], {
             RGBColor[
             0.6499021646261236, 0.725337696254724, 0.9664851266806084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 272}], {
             RGBColor[
             0.6878111560407678, 0.756042569748228, 0.9695182461395961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 275}], {
             RGBColor[
             0.8603530123804088, 0.8894563784374243, 0.877080294609712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 281}], {
             RGBColor[
             0.6802997161269625, 0.7500157979571946, 0.9688781332846546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 291}], {
             RGBColor[
             0.7125484820155874, 0.7753675568103979, 0.9719838316093115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 338}], {
             RGBColor[
             0.8614468790047858, 0.8890515325777966, 0.796643588235805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 384}], {
             RGBColor[
             0.7385166114389616, 0.7956540568810313, 0.9745720920642666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 398}], {
             RGBColor[
             0.83401539327211, 0.8711277377968187, 0.9805027030161089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 204}], {
             RGBColor[
             0.17892957074057536`, 0.30539670201133906`, 0.9335011463998728]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 214}], {
             RGBColor[
             0.5813526175939636, 0.6464089921975442, 0.9229266959429565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 256}], {
             RGBColor[
             0.20212025348377827`, 0.329771579948656, 0.9348218214745575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 261}], {
             RGBColor[
             0.1791902555267194, 0.3056706982499465, 0.9335159920127951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 264}], {
             RGBColor[
             0.18448157797338877`, 0.31123221363061604`, 0.9338173249983228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 295}], {
             RGBColor[
             0.21065974573871524`, 0.33874712774367555`, 0.9353081329254295]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 310}], {
             RGBColor[
             0.18075514602575382`, 0.30731549738422004`, 0.933605110211667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 345}], {
             RGBColor[
             0.1904397679735038, 0.31749464909180203`, 0.9341566351044772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 186}], {
             RGBColor[
             0.23214557991116364`, 0.36133010173948693`, 0.9365317193961071]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 226}], {
             RGBColor[
             0.22722875741095702`, 0.3561622095472178, 0.9362517136285073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 294}], {
             RGBColor[
             0.21429151975408078`, 0.34256435250159695`, 0.9355149570828762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 341}], {
             RGBColor[
             0.21870360025711671`, 0.3472017288523488, 0.9357662185404361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 368}], {
             RGBColor[
             0.2143024966118115, 0.34257588987504495`, 0.9355155821986852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 379}], {
             RGBColor[
             0.2183904240990045, 0.34687256085365753`, 0.9357483836215341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 393}], {
             RGBColor[
             0.2193217433014607, 0.3478514363844869, 0.9358014208723507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 399}], {
             RGBColor[
             0.22535125221155355`, 0.3541888325419396, 0.9361447924849214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 200}], {
             RGBColor[
             0.2962840776702533, 0.42752676637236176`, 0.9402288709406241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 225}], {
             RGBColor[
             0.2895083029136421, 0.42040499749423077`, 0.9398430005920957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 296}], {
             RGBColor[
             0.3117150207517371, 0.4437456659293011, 0.9411076403210801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 311}], {
             RGBColor[
             0.42064126980492156`, 0.5369664823599833, 0.9485194381294991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 324}], {
             RGBColor[
             0.3009330775683418, 0.4324131600288711, 0.9404936246072413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 339}], {
             RGBColor[
             0.34383450141698674`, 0.4722338963280338, 0.9431298082827468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 360}], {
             RGBColor[
             0.31615011179738517`, 0.4482550694974156, 0.9413657834565303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 374}], {
             RGBColor[
             0.29900611365793894`, 0.43038779878246913`, 0.9403838868632315]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 375}], {
             RGBColor[
             0.28837692064883436`, 0.4192158430001391, 0.939778570045845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 383}], {
             RGBColor[
             0.3010724134398118, 0.43255961086419054`, 0.9405015595789926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 390}], {
             RGBColor[
             0.2941038875347629, 0.4252352483079229, 0.9401047123377103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 209}], {
             RGBColor[
             0.24801071646784933`, 0.37800536616831976`, 0.9374352154526442]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 229}], {
             RGBColor[
             0.24544230257567465`, 0.37530580032079786`, 0.9372889480811126]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 240}], {
             RGBColor[
             0.24159747707370743`, 0.3712646449422136, 0.9370699909566852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 245}], {
             RGBColor[
             0.23694364602077422`, 0.3663731734356497, 0.9368049621629467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 248}], {
             RGBColor[
             0.230098166399185, 0.35917814032488304`, 0.9364151222254768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 309}], {
             RGBColor[
             0.2573894464516083, 0.38786300602707646`, 0.9379693202506316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 315}], {
             RGBColor[
             0.24363133500537287`, 0.37340235858243487`, 0.9371858161570703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 319}], {
             RGBColor[
             0.24278605838252734`, 0.37251391925819094`, 0.9371376789038741]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 329}], {
             RGBColor[
             0.23956363455757862`, 0.36912694750469877`, 0.9369541666341921]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 334}], {
             RGBColor[
             0.25269374017822266`, 0.3829275210087747, 0.9377019067250372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 371}], {
             RGBColor[
             0.25801702472850174`, 0.38852263058685255`, 0.9380050599050818]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 388}], {
             RGBColor[
             0.23367677668762307`, 0.36293948663502873`, 0.9366189187873238]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 196}], {
             RGBColor[
             0.2837836367777321, 0.41560497354815545`, 0.9394724303429989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 231}], {
             RGBColor[
             0.28916364068982703`, 0.4212596987717169, 0.9397788136067902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 303}], {
             RGBColor[
             0.27962744891017854`, 0.4112365565818258, 0.9392357415924706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 313}], {
             RGBColor[
             0.2762257553297003, 0.407661160948913, 0.939042020175417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 344}], {
             RGBColor[
             0.29513590341832135`, 0.4264382934400302, 0.9401591514378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 359}], {
             RGBColor[
             0.2576056390091489, 0.3880902381124516, 0.9379816320969553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 239}], {
             RGBColor[
             0.3453924706572131, 0.47358333097810695`, 0.943229080705076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 271}], {
             RGBColor[
             0.3365289525569892, 0.46572515579895724`, 0.942670933978061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 282}], {
             RGBColor[
             0.5065658976915518, 0.60785950870626, 0.9549980870909234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 326}], {
             RGBColor[
             0.3528301288862901, 0.48002545670856134`, 0.9437030017105699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 350}], {
             RGBColor[
             0.3995063863984757, 0.5204540849487005, 0.9466771715650524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 394}], {
             RGBColor[
             0.36256898672280274`, 0.4884607658773212, 0.9443235531201786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 250}], {
             RGBColor[
             0.7777697545864616, 0.8245041838583995, 0.9019245302265969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 265}], {
             RGBColor[
             0.5796034948121, 0.6695872537851715, 0.9600476567506184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 322}], {
             RGBColor[
             0.5378642093893072, 0.6357014215455682, 0.9567617873060958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 362}], {
             RGBColor[
             0.4859856594800335, 0.59226287242109, 0.9530427707548238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 244}], {
             RGBColor[
             0.27406524356197104`, 0.4053903260966717, 0.9389189822264357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 253}], {
             RGBColor[
             0.31490504522225604`, 0.4452672657366318, 0.9413563610246107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 271}], {
             RGBColor[
             0.28286075625291396`, 0.4146349676025667, 0.9394198736623899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 273}], {
             RGBColor[
             0.26718551324119244`, 0.3981592933294373, 0.9385271917623162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 335}], {
             RGBColor[
             0.2697259044179279, 0.4008294055262898, 0.9386718632816594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 305}], {
             RGBColor[
             0.21033276310750965`, 0.33840344826638225`, 0.9352895117483098]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 325}], {
             RGBColor[
             0.2146653182782982, 0.3429572384507447, 0.9355362443558451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 213}], {
             RGBColor[
             0.8673292987337209, 0.4339131427504039, 0.20877019917985573`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 224}], {
             RGBColor[
             0.8996759960158076, 0.5563318548969114, 0.2651346625378677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 247}], {
             RGBColor[
             0.8653490116625105, 0.42606196440460237`, 0.20717681371904806`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 289}], {
             RGBColor[
             0.8607218959500621, 0.40585224662813213`, 0.20335726643267069`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 302}], {
             RGBColor[
             0.905483758897311, 0.5759228028237954, 0.28769672462851575`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 340}], {
             RGBColor[
             0.9087343059844912, 0.5861006931027701, 0.36724259092497624`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 400}], {
             RGBColor[
             0.6066506956499677, 0.3474920671801415, 0.5581829902007515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 189}], {
             RGBColor[
             0.2745072076984255, 0.4058548584262301, 0.9389441514301794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 200}], {
             RGBColor[
             0.2595636633022175, 0.3901482457903771, 0.9380931386838082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 226}], {
             RGBColor[
             0.24355084950968384`, 0.37331776322339055`, 0.9371812326271585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 241}], {
             RGBColor[
             0.2697148101734317, 0.4008177447719086, 0.9386712314808479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 255}], {
             RGBColor[
             0.2544713249858168, 0.38479587534694254`, 0.9378031375501286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 288}], {
             RGBColor[
             0.2467468316416792, 0.3766769430810886, 0.9373632390815438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 341}], {
             RGBColor[
             0.23502569235584353`, 0.3643572825285215, 0.9366957375390872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 374}], {
             RGBColor[
             0.2622856992899031, 0.3930092782004845, 0.9382481546064155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 393}], {
             RGBColor[
             0.23564383540018752`, 0.36500699006065973`, 0.9367309398710019]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 399}], {
             RGBColor[
             0.24167334431028037`, 0.3713443862181124, 0.9370743114835726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 193}], {
             RGBColor[
             0.8331367258093362, 0.8697846265391334, 0.9839465187292714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 218}], {
             RGBColor[
             0.8769988069965478, 0.9047590594733392, 0.9881301231890498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 232}], {
             RGBColor[
             0.6847452419471614, 0.7520517688707707, 0.9703846238932006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 235}], {
             RGBColor[
             0.792013758809907, 0.8376400126416226, 0.9798528182009743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 275}], {
             RGBColor[
             0.9180172404014313, 0.9346976892728417, 0.8827763564020366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 279}], {
             RGBColor[
             0.8947917399967904, 0.8503099582405043, 0.6300514927715455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 281}], {
             RGBColor[
             0.7379639441479849, 0.795257108792612, 0.9745741950769791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 298}], {
             RGBColor[
             0.8336819864556111, 0.8702194025777671, 0.983998526176473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 306}], {
             RGBColor[
             0.9071549779062498, 0.8950638881018478, 0.6621967951023203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 195}], {
             RGBColor[
             0.25639031228130726`, 0.3868128526653249, 0.9379124210377194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 203}], {
             RGBColor[
             0.2792417470878428, 0.4108311595116429, 0.9392137764442834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 206}], {
             RGBColor[
             0.2493239941811602, 0.37938570431162577`, 0.937510004675597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 208}], {
             RGBColor[
             0.25008631824464794`, 0.38018695523648866`, 0.9375534179032552]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 258}], {
             RGBColor[
             0.2600095899871553, 0.39061694300963157`, 0.938118533548826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 278}], {
             RGBColor[
             0.2597507710467335, 0.39034490789317966`, 0.9381037941930572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 284}], {
             RGBColor[
             0.25554200422115014`, 0.38592122710826227`, 0.9378641111486529]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 327}], {
             RGBColor[
             0.2928390260811543, 0.4242124195155595, 0.9400214534598996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 361}], {
             RGBColor[
             0.3113562197109362, 0.44025108193646334`, 0.9412013526638779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 369}], {
             RGBColor[
             0.26226993371413826`, 0.39299270758076044`, 0.9382472567801988]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 392}], {
             RGBColor[
             0.25751756533120074`, 0.38799766709273437`, 0.9379766164312895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 200}], {
             RGBColor[
             0.28560319899075254`, 0.41751744880094743`, 0.9395760517192293]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 219}], {
             RGBColor[
             0.37386729373661226`, 0.4974887142474586, 0.9450712281757306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 241}], {
             RGBColor[
             0.2957543458619668, 0.428186947782479, 0.9401541445162689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 255}], {
             RGBColor[
             0.28051086067435194`, 0.4121650783575129, 0.9392860505855498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 339}], {
             RGBColor[
             0.333153622737486, 0.4622245787566195, 0.942476989061352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 360}], {
             RGBColor[
             0.30546923311788443`, 0.43824575192600135`, 0.9407129642351355]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 374}], {
             RGBColor[
             0.2883252349784382, 0.42037848121105487`, 0.9397310676418367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 266}], {
             RGBColor[
             0.24805045871485498`, 0.3780471377897267, 0.9374374787148178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 273}], {
             RGBColor[
             0.2582701914773965, 0.38878872489163985`, 0.9380194773769047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 365}], {
             RGBColor[
             0.24867185173243342`, 0.3787002612497945, 0.9374728661279003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 198}], {
             RGBColor[
             0.7526714957518834, 0.806764542665624, 0.9759689648481673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 216}], {
             RGBColor[
             0.6689774683276695, 0.7413295497654275, 0.9676410801591727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 219}], {
             RGBColor[
             0.5630206032370957, 0.6553990201614963, 0.9591704044347413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 220}], {
             RGBColor[
             0.5771439386381384, 0.6670314281944398, 0.9602362550255482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 311}], {
             RGBColor[
             0.5991137006259042, 0.6848674707026068, 0.961965795167115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 323}], {
             RGBColor[
             0.7545318035699571, 0.8082479016230455, 0.9761464026685716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 339}], {
             RGBColor[
             0.5223069322379694, 0.6201348846706572, 0.9565761653203628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 357}], {
             RGBColor[
             0.6772717325975683, 0.7478090920518159, 0.9684677749072899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 201}], {
             RGBColor[
             0.3104580154232146, 0.4403366833931581, 0.941112499955068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 203}], {
             RGBColor[
             0.31794365991620344`, 0.4482045703725628, 0.9415387963349251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 228}], {
             RGBColor[
             0.35617346073846823`, 0.48292128271817314`, 0.9439160358597984]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 243}], {
             RGBColor[
             0.31643084813058897`, 0.44661450926807483`, 0.9414526439417388]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 332}], {
             RGBColor[
             0.43585567576042195`, 0.5499313562155932, 0.9495477612304457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 348}], {
             RGBColor[
             0.30372248336585006`, 0.4332572121434699, 0.9407289213687278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 361}], {
             RGBColor[
             0.35005813253929685`, 0.4776244927973833, 0.9435263725545195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 385}], {
             RGBColor[
             0.45995539470159097`, 0.5694965937320001, 0.9514449793856737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 232}], {
             RGBColor[
             0.6739481277148399, 0.7434424430617759, 0.9693547854990241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 235}], {
             RGBColor[
             0.7812166445775857, 0.8290306868326278, 0.9788229798067978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 260}], {
             RGBColor[
             0.8156468227717713, 0.8559278037169716, 0.9822546582008858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 275}], {
             RGBColor[
             0.9072201261691099, 0.9260883634638468, 0.8817465180078601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 281}], {
             RGBColor[
             0.7271668299156635, 0.7866477829836171, 0.9735443566828026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 338}], {
             RGBColor[
             0.9083139927934867, 0.9256835176042191, 0.801309811633953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 384}], {
             RGBColor[
             0.7853837252276628, 0.8322860419074539, 0.9792383154624147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 376}], {
             RGBColor[
             0.4132241787161002, 0.5323357471779375, 0.947551257161364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 377}], {
             RGBColor[
             0.40146722310948635`, 0.5221524631532592, 0.9468021143463783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 396}], {
             RGBColor[
             0.3331772870037427, 0.4601881672994485, 0.9425538104147095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 206}], {
             RGBColor[
             0.2386283880050733, 0.3681439440799593, 0.9369009057266002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 208}], {
             RGBColor[
             0.239390712068561, 0.3689451950048222, 0.9369443189542583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 258}], {
             RGBColor[
             0.24931398381106837`, 0.3793751827779651, 0.9375094345998292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 278}], {
             RGBColor[
             0.24905516487064655`, 0.3791031476615132, 0.9374946952440605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 284}], {
             RGBColor[
             0.24484639804506322`, 0.3746794668765958, 0.9372550121996561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 327}], {
             RGBColor[
             0.2821434199050674, 0.41297065928389304`, 0.9394123545109028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 337}], {
             RGBColor[
             0.26521901916211443`, 0.39609238336940045`, 0.9384152028336801]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 369}], {
             RGBColor[
             0.2515743275380513, 0.381750947349094, 0.9376381578312021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 392}], {
             RGBColor[
             0.24682195915511385`, 0.3767559068610679, 0.9373675174822926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 231}], {
             RGBColor[
             0.3033041199951848, 0.43612223907981873`, 0.9405840929842658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 234}], {
             RGBColor[
             0.3183317548341577, 0.44914414193399255`, 0.9415414311188043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 290}], {
             RGBColor[
             0.3515289166579535, 0.47789785496789633`, 0.943656724915119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 303}], {
             RGBColor[
             0.29376792821553643`, 0.42609909688992764`, 0.9400410209699464]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 313}], {
             RGBColor[
             0.2903662346350581, 0.4225237012570149, 0.9398472995528928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 344}], {
             RGBColor[
             0.3092763827236792, 0.441300833748132, 0.9409644308152758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 204}], {
             RGBColor[
             0.5838392169462935, 0.6475052215433456, 0.8847911904815791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 215}], {
             RGBColor[
             0.9040198154602492, 0.5694397771754294, 0.5010925431304881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 295}], {
             RGBColor[
             0.6155693919444334, 0.6808556472756819, 0.8865981770071358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 310}], {
             RGBColor[
             0.5856647922314719, 0.6494240169162264, 0.8848951542933734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 345}], {
             RGBColor[
             0.5953494141792219, 0.6596031686238084, 0.8854466791861835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 216}], {
             RGBColor[
             0.7427956016916255, 0.7990494191661757, 0.974984628023718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 219}], {
             RGBColor[
             0.6368387366010516, 0.7131188895622445, 0.9665139522992866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 224}], {
             RGBColor[
             0.901075568718926, 0.8970235530331128, 0.6716312488962854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 247}], {
             RGBColor[
             0.866748584365629, 0.7667536625408037, 0.6136734000774657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 302}], {
             RGBColor[
             0.9068833316004294, 0.9166145009599966, 0.6941933109869335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 311}], {
             RGBColor[
             0.6729318339898602, 0.7425873401033549, 0.9693093430316602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 323}], {
             RGBColor[
             0.828349936933913, 0.8659677710237936, 0.9834899505331167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 340}], {
             RGBColor[
             0.9101338786876096, 0.9267923912389714, 0.7737391772833939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 212}], {
             RGBColor[
             0.21834996970250586`, 0.3468300407179805, 0.9357460798035004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 238}], {
             RGBColor[
             0.22751293603602638`, 0.35646089930013114`, 0.9362678971808005]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 252}], {
             RGBColor[
             0.2250679449332263, 0.3538910586296987, 0.9361286585545363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 277}], {
             RGBColor[
             0.24180779724081597`, 0.3714857047729135, 0.9370819683790612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 287}], {
             RGBColor[
             0.24300807911222783`, 0.3727472771220335, 0.9371503226559803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 293}], {
             RGBColor[
             0.21851691429369074`, 0.3470055100682143, 0.9357555870509962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 299}], {
             RGBColor[
             0.21996573354153404`, 0.3485283109581435, 0.9358380951638248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 336}], {
             RGBColor[
             0.2184046627263886, 0.34688752655381927`, 0.9357491944902996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 367}], {
             RGBColor[
             0.2225587298907346, 0.35125371452661747`, 0.9359857624699174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 225}], {
             RGBColor[
             0.26388387983793327`, 0.3946890672869635, 0.9383391686243296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 241}], {
             RGBColor[
             0.2808108014657587, 0.41248033514662596`, 0.9393031317698977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 255}], {
             RGBColor[
             0.26556731627814384`, 0.3964584657216599, 0.9384350378391786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 288}], {
             RGBColor[
             0.25784282293400623`, 0.38833953345580596`, 0.9379951393705938]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 296}], {
             RGBColor[
             0.2860905976760283, 0.41802973572203384`, 0.939603808353314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 339}], {
             RGBColor[
             0.3182100783412779, 0.4465179661207665, 0.9416259763149808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 355}], {
             RGBColor[
             0.2507904105311417, 0.380927000871623, 0.9375935149173598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 360}], {
             RGBColor[
             0.29052568872167633`, 0.4225391392901483, 0.9398619514887643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 374}], {
             RGBColor[
             0.27338169058223005`, 0.4046718685752019, 0.9388800548954654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 375}], {
             RGBColor[
             0.26275249757312547`, 0.3934999127928718, 0.9382747380780788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 383}], {
             RGBColor[
             0.27544799036410295`, 0.4068436806569232, 0.9389977276112265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 399}], {
             RGBColor[
             0.2527693356026074, 0.3830069765928298, 0.9377062117726225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 210}], {
             RGBColor[
             0.2881749983278178, 0.42022057296569904`, 0.9397225118868391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 228}], {
             RGBColor[
             0.3221417320475673, 0.45045653149250003`, 0.9418569760468667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 236}], {
             RGBColor[
             0.26347424346046877`, 0.3942585134818019, 0.9383158404386357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 243}], {
             RGBColor[
             0.2823991194396881, 0.4141497580424017, 0.9393935841288071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 263}], {
             RGBColor[
             0.26925494850456955`, 0.4003344010010207, 0.9386450430391104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 348}], {
             RGBColor[
             0.2696907546749492, 0.40079246091779686`, 0.9386698615557961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 351}], {
             RGBColor[
             0.26108538890678307`, 0.3917476758837515, 0.9381797987057969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 214}], {
             RGBColor[
             0.9200563597791344, 0.7107376048071281, 0.556968147234525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 217}], {
             RGBColor[
             0.8395826476787889, 0.30525515205179155`, 0.18553769416040178`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 257}], {
             RGBColor[
             0.8394733977788387, 0.30441540944716294`, 0.18543307633282935`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 264}], {
             RGBColor[
             0.5231853201585595, 0.37556082624020004`, 0.5678587762898913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 268}], {
             RGBColor[
             0.836829312925746, 0.2840918146209231, 0.18290109769144122`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 279}], {
             RGBColor[
             0.9009946329017078, 0.6281412966873632, 0.2383554119012628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 300}], {
             RGBColor[
             0.873168201892003, 0.5137197571930974, 0.21575357463755512`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 306}], {
             RGBColor[
             0.913357870811167, 0.6728952265487068, 0.2705007142320376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 363}], {
             RGBColor[
             0.8594260597663401, 0.4513198993592995, 0.20428679439717456`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 381}], {
             RGBColor[
             0.9247433274483484, 0.7127453819428937, 0.4824095946157798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 243}], {
             RGBColor[
             0.28988476393267687`, 0.4220176450218065, 0.9398198805086642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 258}], {
             RGBColor[
             0.2721654186176039, 0.4033934896242831, 0.9388107900063931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 284}], {
             RGBColor[
             0.26769783285159876`, 0.3986977737229138, 0.93855636760622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 348}], {
             RGBColor[
             0.277176399167938, 0.4086603478972015, 0.9390961579356532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 361}], {
             RGBColor[
             0.32351204834138475`, 0.4530276285511149, 0.941893609121445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 369}], {
             RGBColor[
             0.2744257623445868, 0.405769254195412, 0.9389395132377659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 392}], {
             RGBColor[
             0.26967339396164935`, 0.4007742137073859, 0.9386688728888566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 261}], {
             RGBColor[
             0.17918768478614402`, 0.3056679962386074, 0.9335158456129223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 295}], {
             RGBColor[
             0.21065717499813985`, 0.33874442573233643`, 0.9353079865255567]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 310}], {
             RGBColor[
             0.18075257528517846`, 0.3073127953728809, 0.9336049638117943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 345}], {
             RGBColor[
             0.1904371972329284, 0.3174919470804629, 0.9341564887046044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 389}], {
             RGBColor[
             0.17900756331513207`, 0.305478677152213, 0.9335055879616141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 400}], {
             RGBColor[
             0.2842689537951664, 0.40863855928315673`, 0.939773820202813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 207}], {
             RGBColor[
             0.967562165289962, 0.8957834071543473, 0.4992706546503005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 221}], {
             RGBColor[
             0.9585637141169614, 0.9664203575638242, 0.8602427231177231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 230}], {
             RGBColor[
             0.9820628725503424, 0.9494608486926688, 0.5307965926515668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 250}], {
             RGBColor[
             0.9917478646376758, 0.990855544204543, 0.7864227690028461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 276}], {
             RGBColor[
             0.8804173286055655, 0.9045483902483498, 0.8526723312886473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 358}], {
             RGBColor[
             0.9819225924478814, 0.9489876509677333, 0.5302516309431803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 391}], {
             RGBColor[
             0.9078296512801215, 0.575024774186147, 0.4476180378082022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 208}], {
             RGBColor[
             0.23232439396841398`, 0.3615180466511231, 0.9365419025921359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 258}], {
             RGBColor[
             0.24224766571092132`, 0.37194803442426605`, 0.9371070182377067]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 278}], {
             RGBColor[
             0.24198884677049953`, 0.37167599930781414`, 0.937092278881938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 284}], {
             RGBColor[
             0.23778007994491618`, 0.3672523185228967, 0.9368525958375336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 369}], {
             RGBColor[
             0.2445080094379043, 0.3743237989953949, 0.9372357414690795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 392}], {
             RGBColor[
             0.23975564105496683`, 0.3693287585073688, 0.9369651011201702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 221}], {
             RGBColor[
             0.9308573670898133, 0.869892342221664, 0.6314368519575342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 230}], {
             RGBColor[
             0.9543565255231943, 0.8529328333505086, 0.30199072149137773`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 233}], {
             RGBColor[
             0.8786570254685007, 0.4672262975790694, 0.21740805642807715`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 250}], {
             RGBColor[
             0.9640415176105277, 0.8943275288623829, 0.5576168978426572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 358}], {
             RGBColor[
             0.9542162454207332, 0.8524596356255733, 0.30144575978299126`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 366}], {
             RGBColor[
             0.9205681319812286, 0.7219373884597544, 0.2549015531776194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 391}], {
             RGBColor[
             0.8801233042529734, 0.4784967588439868, 0.2188121666480132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[
             0.24300998977440907`, 0.3727492853491289, 0.9371504314653649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 278}], {
             RGBColor[
             0.24275117083398723`, 0.37247725023267697`, 0.9371356921095961]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 284}], {
             RGBColor[
             0.23854240400840393`, 0.3680535694477596, 0.9368960090651918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 369}], {
             RGBColor[
             0.24527033350139205`, 0.37512504992025775`, 0.9372791546967377]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 392}], {
             RGBColor[
             0.24051796511845452`, 0.3701300094322317, 0.9370085143478284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 227}], {
             RGBColor[
             0.24347750032410487`, 0.3732406685787401, 0.9371770554995502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 229}], {
             RGBColor[
             0.24946457527559712`, 0.37953346395523513`, 0.937518010560954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 240}], {
             RGBColor[
             0.24561974977362988`, 0.37549230857665095`, 0.9372990534365266]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 245}], {
             RGBColor[
             0.2409659187206967, 0.37060083707008695`, 0.9370340246427882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 280}], {
             RGBColor[
             0.24552309910713999`, 0.37539072259816386`, 0.9372935493240518]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 304}], {
             RGBColor[
             0.23556571159456763`, 0.3649248769876179, 0.9367264908358456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 315}], {
             RGBColor[
             0.24765360770529532`, 0.37763002221687225`, 0.9374148786369118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 319}], {
             RGBColor[
             0.24680833108244982`, 0.37674158289262827`, 0.9373667413837155]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 329}], {
             RGBColor[
             0.24358590725750107`, 0.37335461113913604`, 0.9371832291140334]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 334}], {
             RGBColor[
             0.2567160128781451, 0.387155184643212, 0.9379309692048785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 371}], {
             RGBColor[
             0.26203929742842424`, 0.3927502942212898, 0.9382341223849231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 236}], {
             RGBColor[
             0.27522295505597283`, 0.4066071542800159, 0.9389849121833385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 263}], {
             RGBColor[
             0.2810036601000736, 0.41268304179923465`, 0.9393141147838132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 301}], {
             RGBColor[
             0.25974755171345176`, 0.39034152416978307`, 0.9381036108567895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 328}], {
             RGBColor[
             0.2860571913279975, 0.41793071873950494`, 0.9396042457787188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 347}], {
             RGBColor[
             0.27136364126610246`, 0.4025507707922349, 0.9387651299723484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 372}], {
             RGBColor[
             0.257077351430105, 0.3875349743715093, 0.9379515469008601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 387}], {
             RGBColor[
             0.27812297420375887`, 0.4096552582761729, 0.939150063983611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 238}], {
             RGBColor[
             0.22006014114382055`, 0.3486275393339343, 0.9358434715371114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 259}], {
             RGBColor[
             0.2109589325174653, 0.33906159201767927`, 0.935325171169872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 293}], {
             RGBColor[
             0.2110641194014849, 0.3391721501020175, 0.935331161407307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 299}], {
             RGBColor[
             0.2125129386493282, 0.3406949509919467, 0.9354136695201356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 336}], {
             RGBColor[
             0.21095186783418274`, 0.3390541665876225, 0.9353247688466104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 367}], {
             RGBColor[
             0.21510593499852879`, 0.3434203545604207, 0.9355613368262283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 224}], {
             RGBColor[
             0.9433148110399261, 0.8071439818533458, 0.30358552172184644`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 230}], {
             RGBColor[
             0.939912673270707, 0.7956677722978341, 0.2903688589282392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 247}], {
             RGBColor[
             0.9089878266866289, 0.6768740913610367, 0.24562767290302676`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 250}], {
             RGBColor[
             0.9495976653580405, 0.8370624678097084, 0.5459950352795185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 289}], {
             RGBColor[
             0.9043607109741805, 0.6566643735845665, 0.24180812561664938`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 302}], {
             RGBColor[
             0.9491225739214294, 0.8267349297802298, 0.3261475838124945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 340}], {
             RGBColor[
             0.9523731210086097, 0.8369128200592044, 0.40569345010895497`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 391}], {
             RGBColor[
             0.8656794520004861, 0.4212316977913123, 0.20719030408487465`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 215}], {
             RGBColor[
             0.9015306453673441, 0.5683408458182889, 0.5392279021919928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 217}], {
             RGBColor[
             0.903299381606431, 0.5819361276170735, 0.5409216460120444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 261}], {
             RGBColor[
             0.5816107316395323, 0.6466802864248125, 0.9229413951560062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 264}], {
             RGBColor[
             0.5869020540862017, 0.6522418018054821, 0.9232427281415339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 295}], {
             RGBColor[
             0.6130802218515281, 0.6797567159185416, 0.9247335360686406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 300}], {
             RGBColor[
             0.9368849358196452, 0.7904007327583793, 0.5711375264891978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 310}], {
             RGBColor[
             0.5831756221385668, 0.6483250855590861, 0.9230305133548782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 363}], {
             RGBColor[
             0.9231427936939823, 0.7280008749245814, 0.5596707462488172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 217}], {
             RGBColor[
             0.8210569332669986, 0.16285839306295227`, 0.16779744911786956`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 269}], {
             RGBColor[
             0.9061735630089964, 0.5684125935804545, 0.32599457253607145`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 295}], {
             RGBColor[
             0.5308377735120957, 0.2606789813644203, 0.5516093391744658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 300}], {
             RGBColor[
             0.8546424874802127, 0.37132299820425807`, 0.1980133295950229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 352}], {
             RGBColor[
             0.906721166296464, 0.5695838616411621, 0.3855978109611532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 363}], {
             RGBColor[
             0.8409003453545498, 0.3089231403704602, 0.18654654935464235`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 219}], {
             RGBColor[
             0.5531447091768378, 0.647683896662048, 0.958186067610292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 220}], {
             RGBColor[
             0.5672680445778805, 0.6593163046949915, 0.9592519182010989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 311}], {
             RGBColor[
             0.5892378065656463, 0.6771523472031584, 0.9609814583426657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 323}], {
             RGBColor[
             0.7446559095096992, 0.8005327781235971, 0.9751620658441222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 339}], {
             RGBColor[
             0.5124310381777115, 0.6124197611712089, 0.9555918284959135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 357}], {
             RGBColor[
             0.6673958385373104, 0.7400939685523675, 0.9674834380828405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 268}], {
             RGBColor[
             0.8200723347530428, 0.15529033743086842`, 0.16685459646896056`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 269}], {
             RGBColor[
             0.9079422992480835, 0.582007875379239, 0.32768831635612294`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 279}], {
             RGBColor[
             0.8842376547290044, 0.4993398194973086, 0.22230891067878217`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 300}], {
             RGBColor[
             0.8564112237192996, 0.3849182800030426, 0.19970707341507446`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 306}], {
             RGBColor[
             0.8966008926384637, 0.5440937493586522, 0.25445421300955695`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 363}], {
             RGBColor[
             0.8426690815936368, 0.3225184221692448, 0.1882402931746939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 262}], {
             RGBColor[
             0.9243533171861171, 0.9424423464401257, 0.9900148507220045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 269}], {
             RGBColor[
             0.9515613514707596, 0.9593431212476458, 0.7385846645144882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 279}], {
             RGBColor[
             0.9278567069516805, 0.8766750653657154, 0.6332052588371474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 298}], {
             RGBColor[
             0.8667469534105012, 0.8965845097029781, 0.9871522922420749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.9000302759419758, 0.7622535258714493, 0.6106034215734397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 306}], {
             RGBColor[
             0.9402199448611399, 0.9214289952270589, 0.6653505611679222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 314}], {
             RGBColor[
             0.9179378774680893, 0.9374027630058823, 0.9920349282773651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 220}], {
             RGBColor[
             0.4613111794873067, 0.5733857750910603, 0.9507812424766675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 241}], {
             RGBColor[
             0.36907489621161843`, 0.49245160059313714`, 0.9447983082263991]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 311}], {
             RGBColor[
             0.48328094147507245`, 0.5912218175992272, 0.9525107826182344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 323}], {
             RGBColor[
             0.6386990444191253, 0.7146022485196659, 0.9666913901196909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 339}], {
             RGBColor[
             0.4064741730871376, 0.5264892315672777, 0.9471211527714821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 357}], {
             RGBColor[
             0.5614389734467367, 0.6541634389484363, 0.9590127623584092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 360}], {
             RGBColor[
             0.37878978346753606`, 0.5025104047366595, 0.9453571279452656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 350}], {
             RGBColor[
             0.454088632793754, 0.5671299681608568, 0.9503210281880017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 357}], {
             RGBColor[
             0.5755623088477795, 0.6657958469813797, 0.960078612949216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 394}], {
             RGBColor[
             0.4171512331180811, 0.5351366490894776, 0.9479674097431279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 230}], {
             RGBColor[
             0.9453580743501937, 0.9235697837599854, 0.6629627899588003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 250}], {
             RGBColor[
             0.955043066437527, 0.9649644792718597, 0.9185889663100797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 276}], {
             RGBColor[
             0.8437125304054167, 0.8786573253156666, 0.9848385285958808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 358}], {
             RGBColor[
             0.9452177942477327, 0.9230965860350502, 0.6624178282504138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 251}], {
             RGBColor[
             0.7136213718875605, 0.7756511419302459, 0.9724778106511085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 297}], {
             RGBColor[
             0.7757829604608912, 0.8249349923236523, 0.9686258035292561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 312}], {
             RGBColor[
             0.5339420376563727, 0.632517225840949, 0.9564530195798908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 332}], {
             RGBColor[
             0.5660742539559687, 0.6586036065728093, 0.9589825853511816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 356}], {
             RGBColor[
             0.5616526527416191, 0.6550139515161355, 0.9586345007067291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 361}], {
             RGBColor[
             0.48027671073484357`, 0.5862967431545993, 0.9529611966752556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 260}], {
             RGBColor[
             0.6315106131402652, 0.7091757673875206, 0.9658788076150083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 267}], {
             RGBColor[
             0.5126330687833186, 0.6152176449516955, 0.954775499492879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 272}], {
             RGBColor[
             0.5505420601979628, 0.6459225184451997, 0.9578086189518668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 290}], {
             RGBColor[
             0.4296004547734099, 0.5464997120753861, 0.9486003596365518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 291}], {
             RGBColor[
             0.5752793861727824, 0.6652475055073694, 0.9602742044215822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 321}], {
             RGBColor[
             0.6359268279774656, 0.7126257479828174, 0.9663189746381065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 331}], {
             RGBColor[
             0.45307983116767014`, 0.5668363678003234, 0.9500964447383967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 342}], {
             RGBColor[
             0.5287126959381665, 0.6282718106549494, 0.9560413466441238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 346}], {
             RGBColor[
             0.3995496021231435, 0.5204711739094963, 0.9466855458786024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 384}], {
             RGBColor[
             0.6012475155961567, 0.6855340055780029, 0.9628624648765374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 398}], {
             RGBColor[
             0.696746297429305, 0.7610076864937902, 0.9687930758283795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 230}], {
             RGBColor[
             0.9722593705527938, 0.9180864844443417, 0.3467333222862512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 247}], {
             RGBColor[
             0.9413345239687156, 0.7992928035075443, 0.30199213626103877`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 289}], {
             RGBColor[
             0.9367074082562672, 0.779083085731074, 0.29817258897466137`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 302}], {
             RGBColor[
             0.981469271203516, 0.9491536419267372, 0.38251204717050646`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 323}], {
             RGBColor[
             0.9029358765369997, 0.8985069119905342, 0.6718086867166897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 340}], {
             RGBColor[
             0.9847198182906963, 0.959331532205712, 0.46205791346696695`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 288}], {
             RGBColor[
             0.25106704817739506`, 0.3812177645776751, 0.9376092690220652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 296}], {
             RGBColor[
             0.2793148229194171, 0.41090796684390285`, 0.9392179380047856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 316}], {
             RGBColor[
             0.2556938059368381, 0.38608078033623494`, 0.9378727560317908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 324}], {
             RGBColor[
             0.2685328797360218, 0.39957546094347285`, 0.9386039222909468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 355}], {
             RGBColor[
             0.24401463577453056`, 0.373805231993492, 0.9372076445688313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 375}], {
             RGBColor[
             0.2559767228165143, 0.3863781439147409, 0.9378888677295503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 380}], {
             RGBColor[
             0.2612993849996442, 0.39197259934548456`, 0.9381919854667065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 383}], {
             RGBColor[
             0.26867221560749177`, 0.39972191177879235`, 0.938611857262698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 390}], {
             RGBColor[
             0.26170368970244295`, 0.3923975492225247, 0.9382150100214157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 255}], {
             RGBColor[
             0.24955450248561023`, 0.3796279831546734, 0.9375231317825289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 266}], {
             RGBColor[
             0.24681597923856835`, 0.37674962158963, 0.9373671769348919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 294}], {
             RGBColor[
             0.22569678935260098`, 0.35455201398550057`, 0.9361644703139277]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 341}], {
             RGBColor[
             0.23010886985563692`, 0.3591893903362524, 0.9364157317714874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 368}], {
             RGBColor[
             0.2257077662103317, 0.35456355135894857`, 0.9361650954297367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 393}], {
             RGBColor[
             0.2307270128999809, 0.3598390978683905, 0.9364509341034022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 399}], {
             RGBColor[
             0.23675652181007376`, 0.36617649402584324`, 0.9367943057159729]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 280}], {
             RGBColor[
             0.23696761026347307`, 0.36639836137414694`, 0.9368063268911165]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 304}], {
             RGBColor[
             0.22701022275090071`, 0.35593251576360085`, 0.9362392684029103]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 315}], {
             RGBColor[
             0.2390981188616284, 0.3686376609928552, 0.9369276562039764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 243}], {
             RGBColor[
             0.3281145647549416, 0.45673435736741674`, 0.9421971200335375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 332}], {
             RGBColor[
             0.44753939238477464`, 0.5600512043149352, 0.9502922373222444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 348}], {
             RGBColor[
             0.31540619999020275`, 0.44337706024281187`, 0.9414733974605265]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 361}], {
             RGBColor[
             0.3617418491636495, 0.4877443408967252, 0.9442708486463184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 385}], {
             RGBColor[
             0.4716391113259436, 0.5796164418313421, 0.9521894554774726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 240}], {
             RGBColor[
             0.24305133588145522`, 0.372792742729129, 0.9371527860649951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 245}], {
             RGBColor[
             0.238397504828522, 0.36790127122256505`, 0.9368877572712566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 248}], {
             RGBColor[
             0.2315520252069328, 0.36070623811179847`, 0.9364979173337866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 249}], {
             RGBColor[
             0.2582327214414536, 0.38874934150812634`, 0.9380173435137897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 309}], {
             RGBColor[
             0.25884330525935606`, 0.3893911038139919, 0.9380521153589414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 315}], {
             RGBColor[
             0.24508519381312066`, 0.3749304563693503, 0.9372686112653803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 319}], {
             RGBColor[
             0.24423991719027513`, 0.3740420170451063, 0.9372204740121839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 329}], {
             RGBColor[
             0.2410174933653264, 0.37065504529161414`, 0.937036961742502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 334}], {
             RGBColor[
             0.25414759898597045`, 0.3844556187956901, 0.9377847018333471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 371}], {
             RGBColor[
             0.25947088353624953`, 0.3900507283737679, 0.9380878550133916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 388}], {
             RGBColor[
             0.23513063549537086`, 0.3644675844219441, 0.9367017138956337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 247}], {
             RGBColor[
             0.9379323861994966, 0.7878165939520326, 0.28877547346743154`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 250}], {
             RGBColor[
             0.9785422248709081, 0.9480049704007043, 0.5891428358439234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 289}], {
             RGBColor[
             0.9333052704870481, 0.7676068761755623, 0.28495592618105414`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 358}], {
             RGBColor[
             0.9687169526811137, 0.9061370771638947, 0.3329716977842575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 391}], {
             RGBColor[
             0.8946240115133538, 0.5321742003823082, 0.2503381046492794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 234}], {
             RGBColor[
             0.3237117587462526, 0.454798867157554, 0.9418478143825956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 290}], {
             RGBColor[
             0.3569089205700484, 0.48355258019145775`, 0.9439631081789103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 313}], {
             RGBColor[
             0.295746238547153, 0.4281784264805763, 0.9401536828166841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 331}], {
             RGBColor[
             0.38038829696430865`, 0.5038892359163952, 0.9454591932807552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 359}], {
             RGBColor[
             0.2771261222266016, 0.4086075036441148, 0.9390932947382222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 235}], {
             RGBColor[
             0.6328251607154107, 0.7112978291642651, 0.965261084970727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 281}], {
             RGBColor[
             0.5787753460534887, 0.6689149253152545, 0.9599824618467317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 384}], {
             RGBColor[
             0.6369922413654878, 0.7145531842390913, 0.965676420626344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 386}], {
             RGBColor[
             0.4324598922567031, 0.5470353068857565, 0.9493188938960907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 242}], {
             RGBColor[
             0.867902536299588, 0.4245883317454004, 0.20875474200246447`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 317}], {
             RGBColor[
             0.9040426479180714, 0.5627946336685001, 0.48467433968140694`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 358}], {
             RGBColor[
             0.8930174526264201, 0.5204305413924555, 0.24838903272095686`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 366}], {
             RGBColor[
             0.8593693391869154, 0.3899082942266366, 0.20184482611558502`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 382}], {
             RGBColor[
             0.8581195774771997, 0.3842334181920808, 0.20080199431053547`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 290}], {
             RGBColor[
             0.37193655540902126`, 0.4965744830456317, 0.9449204463134487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 313}], {
             RGBColor[
             0.3107738733861259, 0.4412003293347502, 0.9411110209512226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 331}], {
             RGBColor[
             0.3954159318032815, 0.5169111387705692, 0.9464165314152937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 342}], {
             RGBColor[
             0.47104879657377785`, 0.578346581625195, 0.9523614333210206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 346}], {
             RGBColor[
             0.34188570275875485`, 0.4705459448797419, 0.9430056325554994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 275}], {
             RGBColor[
             0.8660971591696807, 0.893943749566336, 0.8776528174795629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 281}], {
             RGBColor[
             0.6860438629162344, 0.7545031690861064, 0.9694506561545053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 384}], {
             RGBColor[
             0.7442607582282336, 0.800141428009943, 0.9751446149341176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 263}], {
             RGBColor[
             0.2563029052327246, 0.3867209823153376, 0.9379074433356098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 351}], {
             RGBColor[
             0.2481333456349381, 0.37813425719806837`, 0.9374421990022963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 246}], {
             RGBColor[
             0.5111109439056949, 0.6137235569467266, 0.9547270574586124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 254}], {
             RGBColor[
             0.5239652108029346, 0.6244175883504002, 0.9556676072236672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 286}], {
             RGBColor[
             0.652334455595527, 0.7273484229582274, 0.9666519351718024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 320}], {
             RGBColor[
             0.644156525821959, 0.7209597620645476, 0.9658368355590718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 343}], {
             RGBColor[
             0.6503098019378368, 0.7257667481329021, 0.9664501366166679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 349}], {
             RGBColor[
             0.5118990860533059, 0.6144062060618112, 0.9547772771793315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 252}], {
             RGBColor[
             0.22677811637454098`, 0.3556885572456525, 0.9362260502881472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 277}], {
             RGBColor[
             0.24351796868213066`, 0.3732832033888673, 0.9371793601126722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 287}], {
             RGBColor[
             0.24471825055354252`, 0.3745447757379873, 0.9372477143895912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 293}], {
             RGBColor[
             0.22022708573500543`, 0.3488030086841681, 0.935852978784607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 299}], {
             RGBColor[
             0.22167590498284873`, 0.3503258095740973, 0.9359354868974357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 336}], {
             RGBColor[
             0.22011483416770328`, 0.34868502516977307`, 0.9358465862239105]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 367}], {
             RGBColor[
             0.2242689013320493, 0.35305121314257126`, 0.9360831542035284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 396}], {
             RGBColor[
             0.25376131131834845`, 0.3840496059649667, 0.9377627033221374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 271}], {
             RGBColor[
             0.31565140111640955`, 0.4476420700773734, 0.9413406348615612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 326}], {
             RGBColor[
             0.3319525774457105, 0.4619423709869775, 0.94237270259407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 335}], {
             RGBColor[
             0.3025165492814234, 0.4338365080010965, 0.9405926244808307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 337}], {
             RGBColor[
             0.304629125717821, 0.43605695978083275`, 0.9407129325836068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 354}], {
             RGBColor[
             0.3021441775416652, 0.43344512169287874`, 0.940571418461126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 245}], {
             RGBColor[
             0.2345526793265548, 0.3638601158439808, 0.9366688001468292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 248}], {
             RGBColor[
             0.22770719970496556`, 0.3566650827332143, 0.9362789602093593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 292}], {
             RGBColor[
             0.2251125947151853, 0.3539379883814973, 0.9361312012935654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 304}], {
             RGBColor[
             0.22915247220042573`, 0.35818415576151175`, 0.9363612663398866]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 309}], {
             RGBColor[
             0.2549984797573888, 0.3853499484354077, 0.9378331582345141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 315}], {
             RGBColor[
             0.24124036831115342`, 0.3708893009907661, 0.9370496541409528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 319}], {
             RGBColor[
             0.24039509168830792`, 0.37000086166652213`, 0.9370015168877566]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 329}], {
             RGBColor[
             0.23717266786335917`, 0.3666138899130299, 0.9368180046180745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 334}], {
             RGBColor[
             0.2503027734840032, 0.3804144634171059, 0.9375657447089196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 371}], {
             RGBColor[
             0.2556260580342823, 0.3860095729951837, 0.9378688978889642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 388}], {
             RGBColor[
             0.23128580999340365`, 0.36042642904335986`, 0.9364827567712063]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 255}], {
             RGBColor[
             0.2757184631493581, 0.40712796470319146`, 0.9390131306362182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 288}], {
             RGBColor[
             0.2679939698052205, 0.39900903243733754`, 0.9385732321676334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 339}], {
             RGBColor[
             0.32836122521249217`, 0.457187465102298, 0.9422040691120204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 360}], {
             RGBColor[
             0.3006768355928906, 0.4332086382716799, 0.9404400442858039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 374}], {
             RGBColor[
             0.2835328374534444, 0.4153413675567334, 0.939458147692505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 375}], {
             RGBColor[
             0.2729036444443398, 0.40416941177440335`, 0.9388528308751185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 399}], {
             RGBColor[
             0.2629204824738216, 0.3936764755743613, 0.938284304569662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 256}], {
             RGBColor[
             0.5718276027056971, 0.5340616080097416, 0.5946502523941279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 257}], {
             RGBColor[
             0.8704770048155868, 0.4443768248986645, 0.21122005596083127`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 268}], {
             RGBColor[
             0.8678329199624942, 0.4240532300724246, 0.2086880773194431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 317}], {
             RGBColor[
             0.954486951543472, 0.8521857620679489, 0.5290777523178287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 333}], {
             RGBColor[
             0.5569536477379948, 0.5184281382754727, 0.5938032026627618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 381}], {
             RGBColor[
             0.9557469344850966, 0.8527067973943953, 0.5081965742437817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 382}], {
             RGBColor[
             0.9085638811026002, 0.6736245465915296, 0.24520540694695725`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 348}], {
             RGBColor[
             0.27566358738232355`, 0.40707028679271356`, 0.9390100055424669]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 351}], {
             RGBColor[
             0.26705822161415743`, 0.39802550175866824`, 0.9385199426924677]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 253}], {
             RGBColor[
             0.30087597692201773`, 0.4305218254587764, 0.9405574263390588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 270}], {
             RGBColor[
             0.2548116613836774, 0.3851535904796679, 0.9378225192045042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 308}], {
             RGBColor[
             0.2605622771689302, 0.3911978522800683, 0.9381500082662007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 397}], {
             RGBColor[
             0.2546928621186111, 0.3850287249197748, 0.9378157537621064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 248}], {
             RGBColor[
             0.2230533686520324, 0.3517736112266503, 0.9360139314156208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 292}], {
             RGBColor[
             0.2204587636622521, 0.3490465168749334, 0.935866172499827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 304}], {
             RGBColor[
             0.22449864114749254`, 0.35329268425494775`, 0.9360962375461481]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 315}], {
             RGBColor[
             0.23658653725822024`, 0.3659978294842021, 0.9367846253472143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 319}], {
             RGBColor[
             0.2357412606353747, 0.36510939015995814`, 0.9367364880940181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 329}], {
             RGBColor[
             0.232518836810426, 0.36172241840646596`, 0.936552975824336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 353}], {
             RGBColor[
             0.220139248365585, 0.34871068603969635`, 0.9358479765763623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 371}], {
             RGBColor[
             0.25097222698134913`, 0.38111810148861974`, 0.9376038690952258]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 378}], {
             RGBColor[
             0.2192126419789341, 0.3477367639770881, 0.9357952077134337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 388}], {
             RGBColor[
             0.22663197894047044`, 0.3555349575367959, 0.9362177279774678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 254}], {
             RGBColor[
             0.4566571232556863, 0.569515492226385, 0.9504402532261262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 286}], {
             RGBColor[
             0.5850263680482788, 0.6724463268342122, 0.9614245811742612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 320}], {
             RGBColor[
             0.5768484382747107, 0.6660576659405324, 0.9606094815615308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 343}], {
             RGBColor[
             0.5830017143905886, 0.6708646520088869, 0.9612227826191269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 344}], {
             RGBColor[
             0.3822157528613575, 0.505477807231359, 0.9455754276855741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 349}], {
             RGBColor[
             0.44459099850605766`, 0.559504109937796, 0.9495499231817904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 289}], {
             RGBColor[
             0.9023804239029701, 0.648813195238765, 0.2402147401558417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 302}], {
             RGBColor[
             0.9471422868502191, 0.8188837514344283, 0.3245541983516868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 340}], {
             RGBColor[
             0.9503928339373993, 0.8290616417134029, 0.4041000646481473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 391}], {
             RGBColor[
             0.8636991649292758, 0.4133805194455108, 0.20559691862406698`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 292}], {
             RGBColor[
             0.21361328404066288`, 0.34185148376416674`, 0.935476332562357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 304}], {
             RGBColor[
             0.2176531615259033, 0.3460976511441812, 0.9357063976086782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 315}], {
             RGBColor[
             0.229741057636631, 0.35880279637343554`, 0.9363947854097444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 319}], {
             RGBColor[
             0.2288957810137855, 0.3579143570491916, 0.9363466481565481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 329}], {
             RGBColor[
             0.22567335718883677`, 0.3545273852956994, 0.9361631358868661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 353}], {
             RGBColor[
             0.21329376874399575`, 0.34151565292892977`, 0.9354581366388923]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 388}], {
             RGBColor[
             0.21978649931888122`, 0.34833992442602935`, 0.935827888039998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 270}], {
             RGBColor[
             0.25957821450255336`, 0.3901635400245296, 0.9380939673531408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 308}], {
             RGBColor[
             0.2653288302878062, 0.39620780182492993`, 0.9384214564148372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 309}], {
             RGBColor[
             0.2701798653173872, 0.40130654721440506`, 0.9386977156833087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 334}], {
             RGBColor[
             0.2654841590440016, 0.39637106219610324`, 0.9384303021577143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 386}], {
             RGBColor[
             0.3044662110801129, 0.4345129066433197, 0.9407539204836926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 397}], {
             RGBColor[
             0.25945941523748706`, 0.39003867446463636`, 0.938087201910743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 265}], {
             RGBColor[
             0.7900609571838799, 0.8344827358393506, 0.9028921387192244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 276}], {
             RGBColor[
             0.8768966809261312, 0.9030925119563854, 0.9110185744810039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 289}], {
             RGBColor[
             0.9429902625743816, 0.8090015716874366, 0.5405821025323335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 391}], {
             RGBColor[
             0.9043090036006871, 0.5735688958941825, 0.5059642810005588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 282}], {
             RGBColor[
             0.7345888082776114, 0.7926044746200289, 0.9741756038265081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 312}], {
             RGBColor[
             0.6426365090387243, 0.7180224324379316, 0.9668896222215277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 356}], {
             RGBColor[
             0.6703471241239707, 0.7405191581131181, 0.9690711033483659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 277}], {
             RGBColor[
             0.2410729775793306, 0.3707133627184349, 0.9370401214864079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 293}], {
             RGBColor[
             0.21778209463220533`, 0.3462331680137357, 0.9357137401583427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 330}], {
             RGBColor[
             0.2245525377985933, 0.3533493330524997, 0.9360993068806954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 386}], {
             RGBColor[
             0.3405394596215219, 0.4693798967384182, 0.942919851133231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 286}], {
             RGBColor[
             0.5978806349455185, 0.6831403582378857, 0.9623651309393161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 320}], {
             RGBColor[
             0.5897027051719504, 0.6767516973442059, 0.9615500313265857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 343}], {
             RGBColor[
             0.5958559812878284, 0.6815586834125604, 0.9621633323841816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 344}], {
             RGBColor[
             0.39507001975859724`, 0.5161718386350326, 0.946515977450629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 349}], {
             RGBColor[
             0.45744526540329744`, 0.5701981413414695, 0.9504904729468453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 288}], {
             RGBColor[
             0.25275048461760563`, 0.38298716301237146`, 0.9377051382369141]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 341}], {
             RGBColor[
             0.24102934533176992`, 0.3706675024598044, 0.9370376366944575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 360}], {
             RGBColor[
             0.28543335040527573`, 0.4171867688467138, 0.9395719503550848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 374}], {
             RGBColor[
             0.2682893522658295, 0.3993194981317673, 0.938590053761786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 393}], {
             RGBColor[
             0.2416474883761139, 0.3713172099919425, 0.9370728390263723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 399}], {
             RGBColor[
             0.24767699728620676`, 0.3776546061493952, 0.937416210638943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 261}], {
             RGBColor[
             0.20237836752934693`, 0.3300428741759244, 0.934836520687607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 264}], {
             RGBColor[
             0.2076696899760163, 0.3356043895565939, 0.9351378536731348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 317}], {
             RGBColor[
             0.6079677143241806, 0.6722679099328412, 0.8705698500730703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 333}], {
             RGBColor[
             0.21043441051870343`, 0.338510286140365, 0.9352953004180034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 381}], {
             RGBColor[
             0.6092276972658053, 0.6727889452592876, 0.8496886719990233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 268}], {
             RGBColor[
             0.8199630848530925, 0.15445059482623982`, 0.16674997864138813`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 338}], {
             RGBColor[
             0.9084477718580719, 0.5824829620653897, 0.3944924501077937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 381}], {
             RGBColor[
             0.9078770993756948, 0.5831041621482105, 0.46625847556572675`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 382}], {
             RGBColor[
             0.8606940459931985, 0.4040219113453448, 0.20326730826890227`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 278}], {
             RGBColor[
             0.25267444257649463`, 0.38290723800581994`, 0.937700807755167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 284}], {
             RGBColor[
             0.24846567575091127`, 0.3784835572209025, 0.9374611247107626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 369}], {
             RGBColor[
             0.2551936052438994, 0.3855550376934007, 0.9378442703423086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 392}], {
             RGBColor[
             0.25044123686096187`, 0.3805599972053746, 0.9375736299933992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 274}], {
             RGBColor[
             0.22087433163626, 0.34948330516414705`, 0.9358898384811689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 299}], {
             RGBColor[
             0.21257469635649348`, 0.34075986225784227`, 0.9354171865301963]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 318}], {
             RGBColor[
             0.2174190793227137, 0.34585161590696, 0.9356930669735002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 336}], {
             RGBColor[
             0.21101362554134806`, 0.339119077853518, 0.9353282858566712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 367}], {
             RGBColor[
             0.21516769270569408`, 0.3434852658263162, 0.935564853836289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 267}], {
             RGBColor[
             0.6900764896095811, 0.7567221842679797, 0.9704893279445472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 272}], {
             RGBColor[
             0.7279854810242253, 0.7874270577614837, 0.9735224474035349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 291}], {
             RGBColor[
             0.7527228069990448, 0.8067520448236535, 0.9759880328732503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 321}], {
             RGBColor[
             0.813370248803728, 0.8541302872991015, 0.9820328030897745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 338}], {
             RGBColor[
             0.9016212039882432, 0.9204360205910522, 0.8006477894997438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 342}], {
             RGBColor[
             0.706156116764429, 0.7697763499712335, 0.9717551750957918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 384}], {
             RGBColor[
             0.7786909364224193, 0.827038544894287, 0.9785762933282055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 398}], {
             RGBColor[
             0.8741897182555676, 0.9025122258100744, 0.9845069042800476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 264}], {
             RGBColor[
             0.1847396920189574, 0.3115035078578844, 0.9338320242113725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 295}], {
             RGBColor[
             0.2109178597842839, 0.3390184219709439, 0.935322832138479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 310}], {
             RGBColor[
             0.18101326007132248`, 0.3075867916114884, 0.9336198094247166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 381}], {
             RGBColor[
             0.5862976993087463, 0.6486880635605781, 0.8483828425372609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 269}], {
             RGBColor[
             0.965850894705439, 0.9706613010892211, 0.7373156259818411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 298}], {
             RGBColor[
             0.8810364966451805, 0.9079026895445534, 0.9858832537094278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 300}], {
             RGBColor[
             0.9143198191766551, 0.7735717057130247, 0.6093343830407926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 306}], {
             RGBColor[
             0.9545094880958191, 0.9327471750686342, 0.664081522635275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 307}], {
             RGBColor[
             0.9619414175862754, 0.970962445386637, 0.9415105792405329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 314}], {
             RGBColor[
             0.9322274207027686, 0.9487209428474576, 0.9907658897447179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 310}], {
             RGBColor[
             0.18630458251799184`, 0.3131483069921579, 0.9339211424102444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 333}], {
             RGBColor[
             0.19279573500831393`, 0.31997091982232506`, 0.9342908039417687]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 381}], {
             RGBColor[
             0.5915890217554157, 0.6542495789412477, 0.8486841755227887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 322}], {
             RGBColor[
             0.5501554119867256, 0.6456799735265193, 0.9577293957987232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 362}], {
             RGBColor[
             0.4982768620774518, 0.6022414244020411, 0.9540103792474512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 273}], {
             RGBColor[
             0.265217664230201, 0.3960909592500517, 0.938415125672312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 365}], {
             RGBColor[
             0.25561932448523794`, 0.3860024956082064, 0.9378685144233075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 272}], {
             RGBColor[
             0.6091079366672787, 0.6934689353256587, 0.9624191392814057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 291}], {
             RGBColor[
             0.6338452626420983, 0.7127939223878283, 0.964884724751121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 321}], {
             RGBColor[
             0.6944927044467815, 0.7601721648632764, 0.9709294949676452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 331}], {
             RGBColor[
             0.511645707636986, 0.6143827846807824, 0.9547069650679356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 342}], {
             RGBColor[
             0.5872785724074823, 0.6758182275354083, 0.9606518669736626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 346}], {
             RGBColor[
             0.4581154785924594, 0.5680175907899552, 0.9512960662081413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 384}], {
             RGBColor[
             0.6598133920654725, 0.7330804224584619, 0.9674729852060762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 398}], {
             RGBColor[
             0.7553121738986209, 0.8085541033742493, 0.9734035961579184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 338}], {
             RGBColor[
             0.9058036870049794, 0.5621593672391498, 0.39196047146640556`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 381}], {
             RGBColor[
             0.9052330145226024, 0.5627805673219706, 0.46372649692433865`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 279}], {
             RGBColor[
             0.9693542844710024, 0.9048940200148108, 0.380506034096984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 298}], {
             RGBColor[
             0.908244530929823, 0.9248034643520736, 0.7344530675019115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 300}], {
             RGBColor[
             0.9415278534612976, 0.7904724805205449, 0.35790419683327634`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 306}], {
             RGBColor[
             0.9817175223804617, 0.9496479498761543, 0.4126513364277588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 307}], {
             RGBColor[
             0.9891494518709179, 0.9878632201941573, 0.6900803930330166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 314}], {
             RGBColor[
             0.9594354549874111, 0.9656217176549777, 0.7393357035372017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 308}], {
             RGBColor[
             0.2553377632908749, 0.38570655694091993`, 0.9378524799298211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 397}], {
             RGBColor[
             0.2494683482405557, 0.3795374295806264, 0.9375182254257268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 273}], {
             RGBColor[
             0.2911126400044641, 0.42330822062509427`, 0.9398898062344726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 326}], {
             RGBColor[
             0.3230890593454866, 0.4540841958078278, 0.941814555867055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 335}], {
             RGBColor[
             0.2936530311811995, 0.4259783328219468, 0.9400344777538158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 394}], {
             RGBColor[
             0.3328279171819992, 0.4625195049765876, 0.9424351072766638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 291}], {
             RGBColor[
             0.6717542540567425, 0.7434987958813325, 0.9679178442101087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 321}], {
             RGBColor[
             0.7324016958614257, 0.7908770383567805, 0.9739626144266329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 331}], {
             RGBColor[
             0.5495546990516302, 0.6450876581742866, 0.9577400845269233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 338}], {
             RGBColor[
             0.8206526510459409, 0.8571827716487312, 0.7925776008366022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 342}], {
             RGBColor[
             0.6251875638221265, 0.7065231010289125, 0.9636849864326502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 346}], {
             RGBColor[
             0.4960244700071036, 0.5987224642834593, 0.954329185667129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 384}], {
             RGBColor[
             0.6977223834801167, 0.763785295951966, 0.9705061046650639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 398}], {
             RGBColor[
             0.7932211653132651, 0.8392589768677534, 0.976436715616906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 365}], {
             RGBColor[
             0.26583905724777945`, 0.3967440827101195, 0.9384505130853945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 394}], {
             RGBColor[
             0.3171526741702776, 0.4460438307034582, 0.9415424253765902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 287}], {
             RGBColor[
             0.2454706833388167, 0.37533563030230443`, 0.937290564323588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 299}], {
             RGBColor[
             0.22242833776812287`, 0.35111666413841447`, 0.9359783368314325]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 318}], {
             RGBColor[
             0.2272727207343431, 0.3562084177875322, 0.9362542172747363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 367}], {
             RGBColor[
             0.22502133411732347`, 0.3538420677068884, 0.9361260041375251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 373}], {
             RGBColor[
             0.24052488712014738`, 0.3701372848948911, 0.9370089085455846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 395}], {
             RGBColor[
             0.2518980358087536, 0.3820911852658918, 0.9376565925383351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 279}], {
             RGBColor[
             0.9688751403565641, 0.9066136951652177, 0.5278514920501343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 281}], {
             RGBColor[
             0.8120473445077586, 0.8515608457173255, 0.8723741943555676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 306}], {
             RGBColor[
             0.9812383782660234, 0.9513676250265612, 0.559996794380909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 338}], {
             RGBColor[
             0.9931945073855819, 0.9905965803379274, 0.7001396493067182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 384}], {
             RGBColor[
             0.8702642398197578, 0.8971991046411623, 0.8780681531351799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 322}], {
             RGBColor[
             0.6369911357289768, 0.7142897496435541, 0.9658558315605028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 358}], {
             RGBColor[
             0.8670714087363368, 0.8612246187195758, 0.654847436421338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 376}], {
             RGBColor[
             0.6019797217390458, 0.6854606658855094, 0.9632115739949887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 377}], {
             RGBColor[
             0.590222766132432, 0.6752773818608311, 0.9624624311800029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 287}], {
             RGBColor[
             0.25901311175833214`, 0.3895695812107696, 0.9380617855878519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 330}], {
             RGBColor[
             0.24129239010618297`, 0.3709439791957144, 0.9370526167052204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 396}], {
             RGBColor[
             0.26805617252313807`, 0.399074411437749, 0.9385767745203981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 284}], {
             RGBColor[
             0.24820685681048946`, 0.3782115221044505, 0.9374463853549939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 327}], {
             RGBColor[
             0.28550387867049365`, 0.4165027145117478, 0.9396037276662406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 337}], {
             RGBColor[
             0.26857947792754067`, 0.39962443859725516`, 0.9386065759890179]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 354}], {
             RGBColor[
             0.2660945297513849, 0.3970126005093012, 0.9384650618665371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 392}], {
             RGBColor[
             0.2501824179205401, 0.3802879620889227, 0.9375588906376304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 300}], {
             RGBColor[
             0.9178232089422185, 0.7078044246386144, 0.2525247911559355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 306}], {
             RGBColor[
             0.9580128778613826, 0.8669798939942239, 0.307271930750418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 363}], {
             RGBColor[
             0.9040810668165558, 0.6454045668048165, 0.24105801091555495`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 384}], {
             RGBColor[
             0.6902109435663115, 0.7577585241609326, 0.9698659918101223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 386}], {
             RGBColor[
             0.4856785944575267, 0.5902406468075978, 0.9535084650798691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 350}], {
             RGBColor[
             0.5398022619922347, 0.6366471769552697, 0.9571158788344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 369}], {
             RGBColor[
             0.25072601947789425`, 0.3808593217920313, 0.9375898479421354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 392}], {
             RGBColor[
             0.24597365109495675`, 0.3758642813040053, 0.9373192075932261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 330}], {
             RGBColor[
             0.23174352854992997`, 0.3609075202673017, 0.9365088231658666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 387}], {
             RGBColor[
             0.2661419288540897, 0.3970624199715206, 0.9384677611753156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 320}], {
             RGBColor[
             0.7180719499645429, 0.7796825319520332, 0.9725343592747207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 343}], {
             RGBColor[
             0.7242252260804207, 0.7844895180203877, 0.9731476603323168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 349}], {
             RGBColor[
             0.5858145101958898, 0.6731289759492968, 0.9614748008949803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 367}], {
             RGBColor[
             0.23976404440825078`, 0.3693375909644736, 0.936965579678708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 373}], {
             RGBColor[
             0.2552675974110747, 0.3856328081524763, 0.9378484840867676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 395}], {
             RGBColor[
             0.2666407460996809, 0.397586708523477, 0.938496168079518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 396}], {
             RGBColor[
             0.2692564543945499, 0.400335983786869, 0.9386451287973171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 341}], {
             RGBColor[
             0.2333048519876323, 0.3625485701939505, 0.9365977382258728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 355}], {
             RGBColor[
             0.2379735788706035, 0.36745569816233453`, 0.9368636153150954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 360}], {
             RGBColor[
             0.2777088570611381, 0.4090678365808599, 0.9391320518865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 374}], {
             RGBColor[
             0.26056485892169184`, 0.3912005658659134, 0.9381501552932011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 375}], {
             RGBColor[
             0.24993566591258726`, 0.38002861008358335`, 0.9375448384758145]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 379}], {
             RGBColor[
             0.23299167582952007`, 0.3622194021952592, 0.9365799033069708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 393}], {
             RGBColor[
             0.23392299503197628`, 0.3631982777260886, 0.9366329405577875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 399}], {
             RGBColor[
             0.23995250394206913`, 0.3695356738835413, 0.9369763121703581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 302}], {
             RGBColor[
             0.9425151711377706, 0.798674033657958, 0.3207346510653094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 340}], {
             RGBColor[
             0.9457657182249508, 0.8088519239369327, 0.40028051736176995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 391}], {
             RGBColor[
             0.8590720492168273, 0.39317080166904056`, 0.2017773713376896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 313}], {
             RGBColor[
             0.34397103520992167`, 0.4699540423686539, 0.9432263147475373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 321}], {
             RGBColor[
             0.6114600904368728, 0.6914542319869668, 0.964754355111318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 331}], {
             RGBColor[
             0.42861309362707734`, 0.5456648518044729, 0.9485318252116084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 342}], {
             RGBColor[
             0.5042459583975736, 0.6071002946590989, 0.9544767271173353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 346}], {
             RGBColor[
             0.3750828645825507, 0.4992996579136456, 0.9451209263518141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 321}], {
             RGBColor[
             0.7571390218362452, 0.8102020254189503, 0.9764281998963484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 331}], {
             RGBColor[
             0.5742920250264498, 0.6644126452364563, 0.9602056699966387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 338}], {
             RGBColor[
             0.8453899770207604, 0.8765077587109009, 0.7950431863063177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 342}], {
             RGBColor[
             0.6499248897969461, 0.7258480880910823, 0.9661505719023658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 384}], {
             RGBColor[
             0.7224597094549363, 0.7831102830141358, 0.9729716901347794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 398}], {
             RGBColor[
             0.8179584912880846, 0.8585839639299231, 0.9789023010866215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 304}], {
             RGBColor[
             0.21505855653612305`, 0.3433705567924642, 0.9355586386928844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 329}], {
             RGBColor[
             0.22307875219905648`, 0.35180029094398246`, 0.9360153769710722]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 353}], {
             RGBColor[
             0.2106991637542155, 0.3387885585772128, 0.9353103777230984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 378}], {
             RGBColor[
             0.20977255736756456`, 0.3378146365146045, 0.93525760886017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 388}], {
             RGBColor[
             0.21719189432910094`, 0.3456128300743124, 0.9356801291242041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 299}], {
             RGBColor[
             0.21267988324051307`, 0.34087042034218046`, 0.9354231767676313]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 330}], {
             RGBColor[
             0.21800150715905772`, 0.3464637844910152, 0.9357262353771553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 336}], {
             RGBColor[
             0.21111881242536762`, 0.33922963593785627`, 0.935334276094106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 341}], {
             RGBColor[
             0.21717163219876068`, 0.3455915332906315, 0.9356789752258563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 368}], {
             RGBColor[
             0.21277052855345546`, 0.3409656943133277, 0.9354283388841056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 393}], {
             RGBColor[
             0.21778977524310467`, 0.34624124082276975`, 0.9357141775577711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 310}], {
             RGBColor[
             0.2124827502833183, 0.3406632211052174, 0.935411950337351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 345}], {
             RGBColor[
             0.22216737223106828`, 0.3508423728127994, 0.9359634752301611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 363}], {
             RGBColor[
             0.5524499218387339, 0.42033901047071287`, 0.5720521832312901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 316}], {
             RGBColor[
             0.27790052377493313`, 0.40942144877130526`, 0.9391373957607753]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 324}], {
             RGBColor[
             0.2907395975741168, 0.42291612937854317`, 0.9398685620199312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 360}], {
             RGBColor[
             0.3059566318031602, 0.4387580388470877, 0.9407407208692202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 374}], {
             RGBColor[
             0.2888126336637139, 0.4208907681321412, 0.9397588242759214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 375}], {
             RGBColor[
             0.2781834406546093, 0.40971881234981117`, 0.9391535074585348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 380}], {
             RGBColor[
             0.28350610283773925`, 0.41531326778055483`, 0.939456625195691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 383}], {
             RGBColor[
             0.2908789334455868, 0.4230625802138626, 0.9398764969916824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 390}], {
             RGBColor[
             0.283910407540538, 0.415738217657595, 0.9394796497504001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 307}], {
             RGBColor[
             0.965939497584164, 0.9739442069028073, 0.9347428726703746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 314}], {
             RGBColor[
             0.9362255007006572, 0.9517027043636277, 0.9839981831745597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 332}], {
             RGBColor[
             0.736930313911651, 0.7933926635631983, 0.9655671808709663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 352}], {
             RGBColor[
             0.970396577990795, 0.974814330666099, 0.7901511578367646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 385}], {
             RGBColor[
             0.76103003285282, 0.8129579010796052, 0.9674643990261943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 306}], {
             RGBColor[
             0.8969031243202032, 0.8868893383314866, 0.6612189641553454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 307}], {
             RGBColor[
             0.9043350538106595, 0.9251046086494896, 0.9386480207606034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 314}], {
             RGBColor[
             0.8746210569271528, 0.9028631061103101, 0.9879033312647884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 336}], {
             RGBColor[
             0.2125676316732109, 0.34075243682778544`, 0.9354167842069347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 367}], {
             RGBColor[
             0.21672169883755696`, 0.34511862480058364`, 0.9356533521865525]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 306}], {
             RGBColor[
             0.9301864468516778, 0.7525583544999579, 0.2846700934867103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 307}], {
             RGBColor[
             0.9376183763421341, 0.7907736248179609, 0.5620991500919681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 314}], {
             RGBColor[
             0.9079043794586273, 0.7685321222787813, 0.6113544605961532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 363}], {
             RGBColor[
             0.8762546358068509, 0.5309830273105506, 0.21845617365184725`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 316}], {
             RGBColor[
             0.2555487063727525, 0.3859282714945373, 0.9378644928262717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 324}], {
             RGBColor[
             0.2683877801719362, 0.39942295210177514`, 0.9385956590854276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 372}], {
             RGBColor[
             0.25414770566980416`, 0.3844557309271635, 0.9377847079088335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 380}], {
             RGBColor[
             0.26115428543555863`, 0.39182009050378686`, 0.9381837222611874]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 383}], {
             RGBColor[
             0.2685271160434062, 0.39956940293709464`, 0.9386035940571789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 390}], {
             RGBColor[
             0.26155859013835736`, 0.392245040380827, 0.9382067468158966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 323}], {
             RGBColor[
             0.9087436394185031, 0.9180978599174181, 0.6943707488073377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 340}], {
             RGBColor[
             0.9905275811721996, 0.978922480132596, 0.484619975557615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 313}], {
             RGBColor[
             0.2862100467675046, 0.4181552842906852, 0.9396106108023645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 344}], {
             RGBColor[
             0.3051201948561256, 0.4369324167818024, 0.9407277420647475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 315}], {
             RGBColor[
             0.23118633013209117`, 0.360321869401733, 0.9364770915402718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 329}], {
             RGBColor[
             0.2271186296842969, 0.35604645832399684`, 0.9362454420173936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 353}], {
             RGBColor[
             0.21473904123945592`, 0.3430347259572272, 0.9355404427694197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 378}], {
             RGBColor[
             0.21381243485280502`, 0.34206080389461896`, 0.9354876739064912]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 325}], {
             RGBColor[
             0.20723516257555488`, 0.3351476737080805, 0.9351131079805042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 314}], {
             RGBColor[
             0.9555259778682477, 0.9659228619523936, 0.9435306567958934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 352}], {
             RGBColor[
             0.9896970551583855, 0.989034488254865, 0.7496836314580985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 385}], {
             RGBColor[
             0.7803305100204103, 0.8271780586683711, 0.9269968726475282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 386}], {
             RGBColor[
             0.30022575986843436`, 0.4300559235597101, 0.9405124330603728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 397}], {
             RGBColor[
             0.25521896402580857`, 0.3855816913810268, 0.9378457144874233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 319}], {
             RGBColor[
             0.25618706106620875`, 0.38659922275138503`, 0.9379008461817029]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 329}], {
             RGBColor[
             0.25296463724126, 0.3832122509978928, 0.9377173339120208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 334}], {
             RGBColor[
             0.26609474286190404`, 0.39701282450196873`, 0.9384650740028659]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 371}], {
             RGBColor[
             0.2714180274121831, 0.4026079340800466, 0.9387682271829105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 386}], {
             RGBColor[
             0.30507679489801537`, 0.4351546689491852, 0.9407886923288442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 345}], {
             RGBColor[
             0.19226277251810686`, 0.3194107424533439, 0.9342604525163987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 363}], {
             RGBColor[
             0.5225453221257725, 0.38890738011125736`, 0.5703491605175277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 323}], {
             RGBColor[
             0.6747921418079339, 0.7440706990607763, 0.9694867808520644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 339}], {
             RGBColor[
             0.4425672704759462, 0.555957682108388, 0.9499165435038557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 327}], {
             RGBColor[
             0.39077465425622554`, 0.5126293712413812, 0.9461931090416965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 356}], {
             RGBColor[
             0.4906677898927829, 0.5973852420238213, 0.9530463122771483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 361}], {
             RGBColor[
             0.40929184788600736`, 0.528668033662285, 0.9473730082456748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 344}], {
             RGBColor[
             0.30171850127564737`, 0.43335702114888963`, 0.940534020647694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 359}], {
             RGBColor[
             0.2641882368664749, 0.39500896582131095`, 0.9383565013068491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 385}], {
             RGBColor[
             0.7506165131369036, 0.8049365561291917, 0.9762521831517132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 319}], {
             RGBColor[
             0.24242894961997336`, 0.37213857530674344`, 0.9371173420881417]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 329}], {
             RGBColor[
             0.2392065257950246, 0.3687516035532512, 0.9369338298184597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 334}], {
             RGBColor[
             0.25233663141566864`, 0.38255217705732714`, 0.9376815699093048]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 371}], {
             RGBColor[
             0.25765991596594773`, 0.388147286635405, 0.9379847230893494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 324}], {
             RGBColor[
             0.2671185805915378, 0.39808894287087526`, 0.9385233800469365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 355}], {
             RGBColor[
             0.2426003366300466, 0.37231871392089444`, 0.937127102324821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 380}], {
             RGBColor[
             0.25988508585516024`, 0.3904860812728869, 0.9381114432226962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 383}], {
             RGBColor[
             0.2672579164630078, 0.3982353937061947, 0.9385313150186878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 390}], {
             RGBColor[
             0.26028939055795897`, 0.3909110311499271, 0.9381344677774055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 333}], {
             RGBColor[
             0.5930937593564782, 0.6566344401985723, 0.8697228003417041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 370}], {
             RGBColor[
             0.9109218435003366, 0.9293228266692952, 0.8943803638429948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 381}], {
             RGBColor[
             0.99188704610358, 0.9909130993174948, 0.7841161719227241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 382}], {
             RGBColor[
             0.9447039927210837, 0.8118308485146293, 0.5211250046258997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 367}], {
             RGBColor[
             0.22156608180377718`, 0.3502103784497014, 0.9359292326298564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 373}], {
             RGBColor[
             0.2370696348066011, 0.3665055956377041, 0.9368121370379159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 329}], {
             RGBColor[
             0.2383612491721791, 0.3678631642290072, 0.9368856925652633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 334}], {
             RGBColor[
             0.25149135479282314`, 0.3816637377330832, 0.9376334326561084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 371}], {
             RGBColor[
             0.2568146393431022, 0.387258847311161, 0.937936585836153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 388}], {
             RGBColor[
             0.23247439130222355`, 0.3616757033593372, 0.9365504447183952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 343}], {
             RGBColor[
             0.7160472963068527, 0.7781008571267078, 0.9723325607195863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 349}], {
             RGBColor[
             0.5776365804223218, 0.666740315055617, 0.9606597012822499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 331}], {
             RGBColor[
             0.634939466831133, 0.7117908877119044, 0.9662504402131629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 338}], {
             RGBColor[
             0.9060374188254435, 0.923886001186349, 0.8010879565228419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 342}], {
             RGBColor[
             0.7105723316016292, 0.7732263305665302, 0.9721953421188899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 384}], {
             RGBColor[
             0.7831071512596195, 0.8304885254895837, 0.9790164603513036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 398}], {
             RGBColor[
             0.8786059330927678, 0.9059622064053712, 0.9849470713031456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 328}], {
             RGBColor[
             0.4089266558730876, 0.5271174055758985, 0.947690784031411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 362}], {
             RGBColor[
             0.45653757665465905`, 0.5683555921624378, 0.9507245098029286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 364}], {
             RGBColor[
             0.428972946302528, 0.5444804947900268, 0.9489681159313363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 340}], {
             RGBColor[
             0.9119941865056833, 0.9282757501963927, 0.7739166151037982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 375}], {
             RGBColor[
             0.267401497471214, 0.3983863064493811, 0.938539491744696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 380}], {
             RGBColor[
             0.27272415965434393`, 0.4039807618801248, 0.9388426094818522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 383}], {
             RGBColor[
             0.2800969902621915, 0.41173007431343256`, 0.9392624812778436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 390}], {
             RGBColor[
             0.27312846435714266`, 0.404405711757165, 0.9388656340365613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 335}], {
             RGBColor[
             0.3099542075105004, 0.4402786337315509, 0.9410665454863245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 337}], {
             RGBColor[
             0.312066783946898, 0.44249908551128714`, 0.9411868535891006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 354}], {
             RGBColor[
             0.3095818357707423, 0.4398872474233331, 0.94104533946662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 337}], {
             RGBColor[
             0.3016677329619616, 0.43349195021963505`, 0.9405242352558603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 354}], {
             RGBColor[
             0.2991827847858058, 0.430880112131681, 0.9403827211333795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 356}], {
             RGBColor[
             0.4184852693414719, 0.5351260969165677, 0.9483745901685348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 392}], {
             RGBColor[
             0.28327067295496094`, 0.4141554737113025, 0.9394765499044728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 347}], {
             RGBColor[
             0.29474363512034735`, 0.42706072191761096`, 0.940098925902251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 362}], {
             RGBColor[
             0.35704810596381387`, 0.4836788564514203, 0.9439717674801389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 372}], {
             RGBColor[
             0.2804573452843499, 0.4120449254968854, 0.9392853428307628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 387}], {
             RGBColor[
             0.30150296805800375`, 0.4341652094015489, 0.9404838599135137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 334}], {
             RGBColor[
             0.2482689309678744, 0.37827676597959103`, 0.9374499203864265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 353}], {
             RGBColor[
             0.22275923690238936`, 0.35146446010874544`, 0.9359971810476075]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 371}], {
             RGBColor[
             0.25359221551815353`, 0.38387187555766883`, 0.9377530735664711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 388}], {
             RGBColor[
             0.22925196747727483`, 0.358288731605845, 0.9363669324487132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 342}], {
             RGBColor[
             0.5277253347918338, 0.6274369503840362, 0.9559728122191802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 346}], {
             RGBColor[
             0.3985622409768109, 0.5196363136385831, 0.946617011453659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 361}], {
             RGBColor[
             0.4414240641856033, 0.5547544143941453, 0.9499025740169657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 385}], {
             RGBColor[
             0.5513213263478973, 0.6466265153287621, 0.9578211808481198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 381}], {
             RGBColor[
             0.5943537422981029, 0.6571554755250186, 0.8488416222676571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 371}], {
             RGBColor[
             0.26672232113879757`, 0.3976724490617448, 0.9385008136573162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 388}], {
             RGBColor[
             0.24238207309791887`, 0.372089305109921, 0.9371146725395583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 337}], {
             RGBColor[
             0.282630755782611, 0.41439322252540617`, 0.9394067754758614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 354}], {
             RGBColor[
             0.28014580760645524`, 0.41178138443745216`, 0.9392652613533807]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 367}], {
             RGBColor[
             0.21516062802241154`, 0.34347784039625945`, 0.9355644515130273]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 354}], {
             RGBColor[
             0.28225838404285286`, 0.4140018362171884, 0.9393855694561568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 384}], {
             RGBColor[
             0.8713581064441347, 0.8967942587815345, 0.7976314467612728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 398}], {
             RGBColor[
             0.966856888277283, 0.9722679396973218, 0.803562057713115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 360}], {
             RGBColor[
             0.3380761124684098, 0.46724626924582036`, 0.942762888830887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 374}], {
             RGBColor[
             0.3209321143289635, 0.44937899853087393`, 0.9417809922375882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 368}], {
             RGBColor[
             0.2171826090564914, 0.3456030706640795, 0.9356796003416652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 379}], {
             RGBColor[
             0.2212705365436844, 0.3498997416426921, 0.9359124017645142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 393}], {
             RGBColor[
             0.2222018557461406, 0.35087861717352153`, 0.9359654390153307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 399}], {
             RGBColor[
             0.22823136465623345`, 0.3572160133309742, 0.9363088106279014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 346}], {
             RGBColor[
             0.4741951057473072, 0.5810717564932091, 0.9525619133593859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 398}], {
             RGBColor[
             0.7713918010534688, 0.8216082690775031, 0.9746694433091629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 349}], {
             RGBColor[
             0.5837898565381997, 0.6715473011239714, 0.9612730023398459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 349}], {
             RGBColor[
             0.3830038950089686, 0.5061604563464437, 0.9456256474062932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 362}], {
             RGBColor[
             0.3423545559019188, 0.4682989085041503, 0.9431326516737686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 372}], {
             RGBColor[
             0.26576379522245486`, 0.3966649775496154, 0.9384462270243925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 387}], {
             RGBColor[
             0.2868094179961087, 0.41878526145427897`, 0.9396447441071433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 351}], {
             RGBColor[
             0.2543498568494185, 0.38466820463406326`, 0.9377962201194567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 369}], {
             RGBColor[
             0.2602045857942335, 0.3908218959663191, 0.9381296382715687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 357}], {
             RGBColor[
             0.5542164267531839, 0.6479076320182329, 0.9585525480697432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 394}], {
             RGBColor[
             0.3958053510234857, 0.5172484341263308, 0.9464413448636552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 378}], {
             RGBColor[
             0.20945304207089746`, 0.33747880567936756`, 0.9352394129367053]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 375}], {
             RGBColor[
             0.24288325350972279`, 0.37261607749940034`, 0.9371432140225805]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 379}], {
             RGBColor[
             0.2259392634266556, 0.3548068696110762, 0.9361782788537368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 366}], {
             RGBColor[
             0.934928559139148, 0.7751416322731404, 0.28588252947049914`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 391}], {
             RGBColor[
             0.8944837314108928, 0.5317010026573729, 0.24979314294089291`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 374}], {
             RGBColor[
             0.293247724709362, 0.42540017170025574`, 0.9400169674113716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 375}], {
             RGBColor[
             0.2826185317002574, 0.4142282159179257, 0.939411650593985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 369}], {
             RGBColor[
             0.30654023496768024`, 0.43518917662023243`, 0.9409270894573605]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 385}], {
             RGBColor[
             0.46552378312677223`, 0.5743196519105522, 0.9517997921721937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 377}], {
             RGBColor[
             0.3822045767059832, 0.5054681270073037, 0.9455747155508364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 387}], {
             RGBColor[
             0.3215492584874442, 0.4515282986156772, 0.941761191813439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 382}], {
             RGBColor[
             0.9000306839899277, 0.6389445090727658, 0.23829549106007777`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 393}], {
             RGBColor[
             0.21780075210083538`, 0.3462527781962177, 0.93571480267358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 399}], {
             RGBColor[
             0.22383026101092823`, 0.35259017435367035`, 0.9360581742861507]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 392}], {
             RGBColor[
             0.2527015805879449, 0.38293576177650346`, 0.937702353224772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 389}], {
             RGBColor[
             0.505152375234491, 0.5869084718259839, 0.9586367768062234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 391}], {
             RGBColor[
             0.8258037070409253, 0.5129958576116641, 0.5754614637475668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 400}], {
             RGBColor[
             0.6104137657145253, 0.6900683539569277, 0.9649050090474223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 395}], {
             RGBColor[
             0.2616949498810116, 0.3923883631160637, 0.9382145123015146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 375}], {
             RGBColor[
             0.26547453356081113`, 0.3963609452029792, 0.9384297540006862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 399}], {
             RGBColor[
             0.255491371590293, 0.38586800900293716`, 0.9378612276952298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 379}], {
             RGBColor[
             0.23790135046863936`, 0.36737978153232503`, 0.9368595020144559]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 383}], {
             RGBColor[
             0.26754083334268397`, 0.3985327572847006, 0.9385474267164473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 399}], {
             RGBColor[
             0.24486217858118842`, 0.3746960532206071, 0.9372559108778432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 377}], {
             RGBColor[
             0.4266363429774569, 0.5439526897461481, 0.9484058684081864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 393}], {
             RGBColor[
             0.22188867958802838`, 0.35054944917483033`, 0.9359476040964289]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 399}], {
             RGBColor[
             0.22791818849812123`, 0.356886845332283, 0.9362909757089996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 383}], {
             RGBColor[
             0.2728634955258139, 0.4041272127154443, 0.9388505444536035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 390}], {
             RGBColor[
             0.2658949696207651, 0.39680285015917666`, 0.9384536972123212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 390}], {
             RGBColor[
             0.27326780022861263`, 0.40455216259248444`, 0.9388735690083126]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 398}], {
             RGBColor[
             0.8439266207114591, 0.8788704640005567, 0.9814905615415767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 400}], {
             RGBColor[
             0.2843495171102985, 0.40872323643536973`, 0.9397784081644269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 399}], {
             RGBColor[
             0.22884950770057744`, 0.3578657208631124, 0.9363440129598162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 396}], {
             RGBColor[
             0.2756838068644868, 0.4070915387504564, 0.9390111570120642]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.03217915333176364], {
             RGBColor[
             0.3599830334006432, 0.48622094308345976`, 0.9441587784611594]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.03217915333176364], {
             RGBColor[
             0.8184511944421836, 0.14282954261339104`, 0.16530219067646573`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.03217915333176364], {
             RGBColor[
             0.370079657849583, 0.49496613171003123`, 0.9448021264429514]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.03217915333176364], {
             RGBColor[
             0.23219649750384544`, 0.36138361935775737`, 0.9365346190776845]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.03217915333176364], {
             RGBColor[
             0.8414430264446411, 0.8764078451972013, 0.9847387810989889]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.03217915333176364], {
             RGBColor[
             0.9933475429680663, 0.9881793920123014, 0.5172992901589675]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.03217915333176364], {
             RGBColor[
             0.38940499419392427`, 0.5117047667318526, 0.9460335197860889]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.03217915333176364], {
             RGBColor[
             0.3103199544645186, 0.44320528024791445`, 0.9409942909866859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.03217915333176364], {
             RGBColor[
             0.8256674379376745, 0.1982967522977973, 0.17221247359732916`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.03217915333176364], {
             RGBColor[
             0.3619258765766598, 0.48790373619238797`, 0.9442825747103464]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.03217915333176364], {
             RGBColor[
             0.9234626618564741, 0.7342619893565898, 0.25727446504873397`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.03217915333176364], {
             RGBColor[
             0.218436984339963, 0.3469214986189947, 0.935751035158377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.03217915333176364], {
             RGBColor[
             0.9637801291888717, 0.9725078601704316, 0.9461949730147088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.03217915333176364], {
             RGBColor[
             0.9943570777774785, 0.9903386848900081, 0.6271809240368398]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.03217915333176364], {
             RGBColor[
             0.3038609163605336, 0.43670746736272875`, 0.940615801713566]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.03217915333176364], {
             RGBColor[
             0.2418605106508593, 0.3715411099090923, 0.9370849703297808]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.03217915333176364], {
             RGBColor[
             0.5355166046173245, 0.6337955302332828, 0.9565769752588857]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.03217915333176364], {
             RGBColor[
             0.9452065658445834, 0.95865572703968, 0.9776351709954327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.03217915333176364], {
             RGBColor[
             0.2743841090042405, 0.40572547389373365`, 0.9389371411416538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.03217915333176364], {
             RGBColor[
             0.4076589804310767, 0.5275154521384491, 0.9471966476477539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.03217915333176364], {
             RGBColor[
             0.31291714185714126`, 0.44545483342897024`, 0.9411597814707411]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.03217915333176364], {
             RGBColor[
             0.29231839668471055`, 0.42457554734542235`, 0.9399584722936555]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.03217915333176364], {
             RGBColor[
             0.21341792784235675`, 0.34164615201344867`, 0.935465207315867]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.03217915333176364], {
             RGBColor[
             0.9021530244270525, 0.6485815613125467, 0.24006642394413927`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.03217915333176364], {
             RGBColor[
             0.8487111149297029, 0.3754205514621725, 0.19427912470900624`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.03217915333176364], {
             RGBColor[
             0.45511285367532656`, 0.5685201430708667, 0.9502472974560874]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.03217915333176364], {
             RGBColor[
             0.2974167180204977, 0.42993420632157753`, 0.9402488141514381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.03217915333176364], {
             RGBColor[
             0.2882891132658928, 0.42034051500092084`, 0.9397290105637445]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.03217915333176364], {
             RGBColor[
             0.2404292095299187, 0.3700367216812511, 0.9370034598483634]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.03217915333176364], {
             RGBColor[
             0.17892703208317115`, 0.3053940337214471, 0.9335010018270892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.03217915333176364], {
             RGBColor[
             0.183217413291963, 0.30990349639776743`, 0.9337453326898797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.03217915333176364], {
             RGBColor[
             0.21628540957162948`, 0.3446600571197567, 0.9356285061582901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.03217915333176364], {
             RGBColor[
             0.17894138666990014`, 0.3054091213022326, 0.9335018192995677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.03217915333176364], {
             RGBColor[
             0.3122890105436297, 0.4449107776560043, 0.9411197574988789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.03217915333176364], {
             RGBColor[
             0.28104105066772134`, 0.4127223416565313, 0.9393162441213263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.03217915333176364], {
             RGBColor[
             0.5196772960404508, 0.620936465977857, 0.9553300468664151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.03217915333176364], {
             RGBColor[
             0.24979952597607638`, 0.3798855183785399, 0.9375370855078312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.03217915333176364], {
             RGBColor[
             0.9657912116144293, 0.896267865549297, 0.32160574622002847`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.03217915333176364], {
             RGBColor[
             0.27309206457306523`, 0.40436745327622, 0.9388635611227067]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.03217915333176364], {
             RGBColor[
             0.3393121311221928, 0.4683168464796233, 0.9428416468465376]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.03217915333176364], {
             RGBColor[
             0.34082031608406577`, 0.4696231604900174, 0.9429377470586726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.03217915333176364], {
             RGBColor[
             0.9322258626950144, 0.9487956145888052, 0.9933977290633442]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.03217915333176364], {
             RGBColor[
             0.2274352478585693, 0.35637924409990884`, 0.9362634729540237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.03217915333176364], {
             RGBColor[
             0.29795654320818293`, 0.4305015968207284, 0.940279556397277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.03217915333176364], {
             RGBColor[
             0.2954990939280613, 0.427918661816037, 0.9401396082962444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.03217915333176364], {
             RGBColor[
             0.2843163130979401, 0.41616485013432336`, 0.9395027654714108]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.03217915333176364], {
             RGBColor[
             0.43389191818712153`, 0.5502371043169462, 0.948868187244693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.03217915333176364], {
             RGBColor[
             0.4254428949511675, 0.5429189850502182, 0.948329822955276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.03217915333176364], {
             RGBColor[
             0.2557363986193865, 0.3861255479461254, 0.9378751816220516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.03217915333176364], {
             RGBColor[
             0.45414763221898446`, 0.5677365328098771, 0.9501713116873214]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.03217915333176364], {
             RGBColor[
             0.3729233885884314, 0.4974292283459589, 0.9449833264510183]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.03217915333176364], {
             RGBColor[
             0.38664548537965426`, 0.5093146188938776, 0.9458576863245813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.03217915333176364], {
             RGBColor[
             0.28924396052189333`, 0.4213441200077901, 0.9397833877024038]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.03217915333176364], {
             RGBColor[
             0.4519914858020445, 0.5659140400742732, 0.9500214756882968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.03217915333176364], {
             RGBColor[
             0.4035326533159193, 0.5239414349865308, 0.9469337217327439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.03217915333176364], {
             RGBColor[
             0.45093503134871465`, 0.5649989923257436, 0.9499541593447165]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.03217915333176364], {
             RGBColor[
             0.2732074233744939, 0.404488702690692, 0.9388701306357901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.03217915333176364], {
             RGBColor[
             0.2988109928106687, 0.43139967752817476`, 0.9403282160380936]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.03217915333176364], {
             RGBColor[
             0.3340181926444761, 0.4637315030513096, 0.9425043217679835]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.03217915333176364], {
             RGBColor[
             0.35752834255750565`, 0.4840948132514831, 0.9440023677312325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.03217915333176364], {
             RGBColor[
             0.9933459036684309, 0.98817588571614, 0.5171208625102379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.03217915333176364], {
             RGBColor[
             0.1790682590797859, 0.30554247224919795`, 0.9335090444956198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.03217915333176364], {
             RGBColor[
             0.9585610528033711, 0.8718788421575785, 0.2935179445399928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.03217915333176364], {
             RGBColor[
             0.3989602722595878, 0.5199810683300905, 0.9466423736550322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.03217915333176364], {
             RGBColor[
             0.5153321861178936, 0.6174089099977538, 0.9549879838966494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.03217915333176364], {
             RGBColor[
             0.9727828870163496, 0.9198524284034268, 0.3487670848893771]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.03217915333176364], {
             RGBColor[
             0.2129458677257866, 0.3411499869005934, 0.9354383241905787]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.03217915333176364], {
             RGBColor[
             0.2767246225454214, 0.4081855020226443, 0.9390704299253445]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.03217915333176364], {
             RGBColor[
             0.48821862164434726`, 0.5953968969059689, 0.9528535047810326]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.03217915333176364], {
             RGBColor[
             0.2778101351361315, 0.409326444580954, 0.9391322482615135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.03217915333176364], {
             RGBColor[
             0.871120013048017, 0.9000714687543917, 0.9875693985741776]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.03217915333176364], {
             RGBColor[
             0.22772650909910638`, 0.3566853781307425, 0.9362800598507899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.03217915333176364], {
             RGBColor[
             0.24311597663730303`, 0.3728606842619857, 0.9371564672604132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.03217915333176364], {
             RGBColor[
             0.8246734764068878, 0.8630362611944062, 0.983139286446034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.03217915333176364], {
             RGBColor[
             0.24417812249459925`, 0.373977066901941, 0.9372169548956822]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.03217915333176364], {
             RGBColor[
             0.8469444359628041, 0.36184108275892934`, 0.19258735093512552`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.03217915333176364], {
             RGBColor[
             0.8293651040061051, 0.8667772376911834, 0.9835867780747127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.03217915333176364], {
             RGBColor[
             0.8418439495844675, 0.3226365094076515, 0.18770311941905493`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.03217915333176364], {
             RGBColor[
             0.590805957298975, 0.6786819174972005, 0.9609295556335575]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.03217915333176364], {
             RGBColor[
             0.3344163982055418, 0.46407640869391137`, 0.9425296950742152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.03217915333176364], {
             RGBColor[
             0.2197154470497895, 0.34826524398623987`, 0.9358238417183856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.03217915333176364], {
             RGBColor[
             0.37921715493462604`, 0.5028805724211383, 0.9453843596772389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.03217915333176364], {
             RGBColor[
             0.35288166901045503`, 0.480070098173631, 0.9437062858017065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.03217915333176364], {
             RGBColor[
             0.17892701429477148`, 0.30539401502471114`, 0.9335010008140661]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.03217915333176364], {
             RGBColor[
             0.2413074662041341, 0.37095982513054093`, 0.9370534752666957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.03217915333176364], {
             RGBColor[
             0.30053635500276704`, 0.4332131425863514, 0.940426472862489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.03217915333176364], {
             RGBColor[
             0.29013871681338543`, 0.4222845656009737, 0.9398343427495309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.03217915333176364], {
             RGBColor[
             0.9903137669558371, 0.9902625079584733, 0.8101894789167451]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.03217915333176364], {
             RGBColor[
             0.21858282554203126`, 0.3470747869692347, 0.9357593405990821]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.03217915333176364], {
             RGBColor[
             0.7058058015575851, 0.7701001235903371, 0.9713117842351892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.03217915333176364], {
             RGBColor[
             0.26262121251507564`, 0.39336192387290797`, 0.9382672615882417]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.03217915333176364], {
             RGBColor[
             0.28766384187052196`, 0.4196833151198899, 0.9396934022827843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.03217915333176364], {
             RGBColor[
             0.2452381115380016, 0.3750911825937439, 0.9372773197035907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.03217915333176364], {
             RGBColor[
             0.26012396818175015`, 0.3907371617441472, 0.9381250472178008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.03217915333176364], {
             RGBColor[
             0.2817785304161579, 0.4134974796310549, 0.9393582425019963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.03217915333176364], {
             RGBColor[
             0.2869114883454893, 0.4188925438631119, 0.939650556862541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.03217915333176364], {
             RGBColor[
             0.44228444757308333`, 0.5575062914502744, 0.9494029517959442]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.03217915333176364], {
             RGBColor[
             0.9775701021325132, 0.9360008290818089, 0.3673645116259542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.03217915333176364], {
             RGBColor[
             0.9781276011086575, 0.9832081812363787, 0.921908445474496]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.03217915333176364], {
             RGBColor[
             0.37661408553666426`, 0.5006259245426959, 0.9452184943970047]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.03217915333176364], {
             RGBColor[
             0.2608418322510304, 0.39149168239617155`, 0.9381659285145616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.03217915333176364], {
             RGBColor[
             0.819297035403237, 0.14933104688991955`, 0.16611216893601113`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.03217915333176364], {
             RGBColor[
             0.34456615692423104`, 0.4728676195543337, 0.943176428724691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.03217915333176364], {
             RGBColor[
             0.9338740873595025, 0.7755398220742175, 0.265651742396037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.03217915333176364], {
             RGBColor[
             0.417344109662346, 0.5359042242898253, 0.9478137755181469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.03217915333176364], {
             RGBColor[
             0.948494816832878, 0.9611080992427333, 0.9720690197854612]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.03217915333176364], {
             RGBColor[
             0.8392176796973624, 0.30244984821655896`, 0.1851882004092155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.03217915333176364], {
             RGBColor[
             0.3675690787260941, 0.49279159425864094`, 0.9446421545612206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.03217915333176364], {
             RGBColor[
             0.9940964498066649, 0.9918267445278057, 0.7475006348091123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.03217915333176364], {
             RGBColor[
             0.25557794384056287`, 0.3859590019269685, 0.9378661578568105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.03217915333176364], {
             RGBColor[
             0.8740781517963572, 0.5211001217496539, 0.21664006204298622`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.03217915333176364], {
             RGBColor[
             0.3289211710833394, 0.45931671915880556`, 0.9421795440612271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.03217915333176364], {
             RGBColor[
             0.7965156452550962, 0.8409633429071789, 0.9803528937232722]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.03217915333176364], {
             RGBColor[
             0.3288778807819878, 0.45927922327560866`, 0.9421767856415051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.03217915333176364], {
             RGBColor[
             0.2386060995532787, 0.36812051750395375`, 0.9368996364322433]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.03217915333176364], {
             RGBColor[
             0.4162213411164948, 0.534931738607397, 0.9477422336992305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.03217915333176364], {
             RGBColor[
             0.3495171154366807, 0.47715589097540734`, 0.9434918994231435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.03217915333176364], {
             RGBColor[
             0.20606162213947596`, 0.33391420830300045`, 0.935046276588767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.03217915333176364], {
             RGBColor[
             0.24049836738192176`, 0.3701094109685675, 0.9370073982857251]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.03217915333176364], {
             RGBColor[
             0.5663783145126094, 0.6588504566304622, 0.9590065221120109]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.03217915333176364], {
             RGBColor[
             0.5531961411455233, 0.6481485744409189, 0.9579687731366617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.03217915333176364], {
             RGBColor[
             0.44608758599784554`, 0.5608003788025082, 0.9496452844133868]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.03217915333176364], {
             RGBColor[
             0.9742961343763916, 0.9803506796209057, 0.9283941192456544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.03217915333176364], {
             RGBColor[
             0.22327126764014227`, 0.35200263687874755`, 0.936026340440641]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.03217915333176364], {
             RGBColor[
             0.277985958766929, 0.4095112463647842, 0.9391422611571797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.03217915333176364], {
             RGBColor[
             0.21204174778307774`, 0.3401996995162911, 0.935386835897367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.03217915333176364], {
             RGBColor[
             0.21049571798261152`, 0.33857472417205015`, 0.9352987917873766]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.03217915333176364], {
             RGBColor[
             0.3262131529712761, 0.45697116997908427`, 0.9420069915417328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.03217915333176364], {
             RGBColor[
             0.23768447069359533`, 0.36715182713778177`, 0.936847151032112]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.03217915333176364], {
             RGBColor[
             0.4104055903111328, 0.5298944275679272, 0.9473716592005793]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.03217915333176364], {
             RGBColor[
             0.9224661794909306, 0.7303112688352736, 0.2564726719469704]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.03217915333176364], {
             RGBColor[
             0.7992223614262676, 0.8430778501519028, 0.9806226738955138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.03217915333176364], {
             RGBColor[
             0.29725822306554583`, 0.42976761807476255`, 0.9402397880982258]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.03217915333176364], {
             RGBColor[
             0.2343268669145523, 0.36362277268163234`, 0.9366559404640252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.03217915333176364], {
             RGBColor[
             0.5032780494106496, 0.6076228187861427, 0.9540390380992975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.03217915333176364], {
             RGBColor[
             0.6185821135656369, 0.7012318524560568, 0.9631161964022821]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.03217915333176364], {
             RGBColor[
             0.22155609394318862`, 0.3501998805749559, 0.9359286638359716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.03217915333176364], {
             RGBColor[
             0.8193428764107183, 0.14968340096107918`, 0.16615606633654534`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.03217915333176364], {
             RGBColor[
             0.2111706728502173, 0.3392841445325141, 0.9353372294685806]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.03217915333176364], {
             RGBColor[
             0.6719249954084331, 0.7436321803229556, 0.9679348621123766]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.03217915333176364], {
             RGBColor[
             0.3600639473667127, 0.48629102669401497`, 0.9441639342275279]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.03217915333176364], {
             RGBColor[
             0.8215839734950429, 0.16690945520620182`, 0.16830214343545163`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.03217915333176364], {
             RGBColor[
             0.6246442469651912, 0.7061533654458123, 0.9635934297498213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.03217915333176364], {
             RGBColor[
             0.8784381059512442, 0.540897655273832, 0.22027811466207986`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.03217915333176364], {
             RGBColor[
             0.23802405881018981`, 0.36750875577945274`, 0.9368664900729765]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.03217915333176364], {
             RGBColor[
             0.5353312372592116, 0.6336450406612625, 0.9565623824614321]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.03217915333176364], {
             RGBColor[
             0.28473783311028583`, 0.41660789439321116`, 0.9395267704125309]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.03217915333176364], {
             RGBColor[
             0.6238880244982119, 0.7055394299796848, 0.9635338971470865]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.03217915333176364], {
             RGBColor[
             0.22021863489519794`, 0.34879412631571627`, 0.9358524975217819]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.03217915333176364], {
             RGBColor[
             0.2706007772119499, 0.40174895230294594`, 0.9387216859930206]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.03217915333176364], {
             RGBColor[
             0.3158355177641727, 0.44798258395780277`, 0.9413457378029186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.03217915333176364], {
             RGBColor[
             0.18361616608284723`, 0.3103226108633739, 0.9337680410714186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.03217915333176364], {
             RGBColor[
             0.3174307607246093, 0.4493643032308905, 0.9414473852737397]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.03217915333176364], {
             RGBColor[
             0.4301580292792129, 0.547002997415629, 0.9486302671452295]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.03217915333176364], {
             RGBColor[
             0.30454561984188433`, 0.43742713413433654`, 0.9406547945639009]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.03217915333176364], {
             RGBColor[
             0.18595953915049845`, 0.3127856445359093, 0.9339014927009116]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.03217915333176364], {
             RGBColor[
             0.46924384183457235`, 0.5799923158523045, 0.9513597406074984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.03217915333176364], {
             RGBColor[
             0.5031159008708285, 0.6074911792968075, 0.9540262731722731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.03217915333176364], {
             RGBColor[
             0.3314345944952444, 0.46149372018986384`, 0.9423396971785006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.03217915333176364], {
             RGBColor[
             0.8294775817921864, 0.22758318757925894`, 0.17586107165535175`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.03217915333176364], {
             RGBColor[
             0.4314366462475933, 0.5481104711684827, 0.9487117394878181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.03217915333176364], {
             RGBColor[
             0.246083996032968, 0.37598026083012825`, 0.9373254915742051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.03217915333176364], {
             RGBColor[
             0.2449732495734328, 0.3748127958757636, 0.9372622362065367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.03217915333176364], {
             RGBColor[
             0.24253850776538854`, 0.3722537278639624, 0.9371235812624463]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.03217915333176364], {
             RGBColor[
             0.532748774101436, 0.6315484807311408, 0.9563590815017777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.03217915333176364], {
             RGBColor[
             0.8247691039330448, 0.19139176348574266`, 0.17135222793997262`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.03217915333176364], {
             RGBColor[
             0.2835494674254077, 0.415358846711668, 0.9394590947448065]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.03217915333176364], {
             RGBColor[
             0.6701504899984683, 0.7422459232099505, 0.9677579959968072]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.03217915333176364], {
             RGBColor[
             0.22069846856058375`, 0.34929846192124825`, 0.9358798233391753]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.03217915333176364], {
             RGBColor[
             0.44496963537099143`, 0.5598320661593594, 0.9495740495880086]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.03217915333176364], {
             RGBColor[
             0.2732125866431092, 0.40449412961337683`, 0.9388704246762993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.03217915333176364], {
             RGBColor[
             0.301424661402258, 0.4341468089340951, 0.9404770605978084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.03217915333176364], {
             RGBColor[
             0.22636761106282094`, 0.3552570901354948, 0.936202672617933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.03217915333176364], {
             RGBColor[
             0.7286053839996127, 0.7879113306772935, 0.9735842335387989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.03217915333176364], {
             RGBColor[
             0.17893214148115075`, 0.3053994040226782, 0.9335012927997455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.03217915333176364], {
             RGBColor[
             0.21582348781243682`, 0.34417454806331416`, 0.935602200397456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.03217915333176364], {
             RGBColor[
             0.3219085007459621, 0.453242696579629, 0.9417327029083903]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.03217915333176364], {
             RGBColor[
             0.24398844376792686`, 0.3737777025338824, 0.9372061529728027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.03217915333176364], {
             RGBColor[
             0.2696431574723743, 0.40074243324005365`, 0.9386671509655232]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.03217915333176364], {
             RGBColor[
             0.36627002209779275`, 0.4916664166996908, 0.9445593798215759]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.03217915333176364], {
             RGBColor[
             0.5673122922146817, 0.6596087018042204, 0.9590800482579911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.03217915333176364], {
             RGBColor[
             0.2880943118622093, 0.4201357663745271, 0.9397179169119876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.03217915333176364], {
             RGBColor[
             0.2589336294896423, 0.3894860403069097, 0.9380572591902335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.03217915333176364], {
             RGBColor[
             0.21776291881025298`, 0.3462130130090464, 0.9357126481236506]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.03217915333176364], {
             RGBColor[
             0.8236904837096025, 0.18310101579396953`, 0.170319339995877]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.03217915333176364], {
             RGBColor[
             0.24846767200989045`, 0.3784856554156597, 0.9374612383947583]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.03217915333176364], {
             RGBColor[
             0.8439338400416576, 0.8783939523481282, 0.9849763571234479]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.03217915333176364], {
             RGBColor[
             0.26708591845739416`, 0.39805461289699134`, 0.9385215199867163]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.03217915333176364], {
             RGBColor[
             0.30054674338696064`, 0.4332240614368005, 0.9404270644656005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.03217915333176364], {
             RGBColor[
             0.2411029859620505, 0.37074490343131483`, 0.9370418304194105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.03217915333176364], {
             RGBColor[
             0.6788533623879274, 0.7490446732648759, 0.968625416983622]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.03217915333176364], {
             RGBColor[
             0.34448974411411554`, 0.4728014346188312, 0.9431715597679996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.03217915333176364], {
             RGBColor[
             0.8223396115770147, 0.8611753007301386, 0.9829166803350949]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.03217915333176364], {
             RGBColor[
             0.3880550588481297, 0.5105355205850486, 0.9459475030995558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.03217915333176364], {
             RGBColor[
             0.24569470610522032`, 0.37557109243365844`, 0.9373033220887227]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.03217915333176364], {
             RGBColor[
             0.29792411608308994`, 0.43046751385625726`, 0.9402777097204745]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.03217915333176364], {
             RGBColor[
             0.988751433892587, 0.9896164430866911, 0.8360813809631582]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.03217915333176364], {
             RGBColor[
             0.8264896291158393, 0.8644844120663722, 0.9833125127127125]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.03217915333176364], {
             RGBColor[
             0.22580276459471169`, 0.35466340068417734`, 0.9361705054471896]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.03217915333176364], {
             RGBColor[
             0.27065965459454444`, 0.40181083616509444`, 0.9387250389728581]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.03217915333176364], {
             RGBColor[
             0.27642628673231373`, 0.407871932167485, 0.9390534401421363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.03217915333176364], {
             RGBColor[
             0.8563396258514921, 0.4340566292418462, 0.20158419538288244`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.03217915333176364], {
             RGBColor[
             0.29139757571829134`, 0.42360770612629445`, 0.9399060329018505]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.03217915333176364], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.03217915333176364], {
             RGBColor[
             0.9952685123171101, 0.9923114224965074, 0.7280765258104895]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.03217915333176364], {
             RGBColor[
             0.23156206990492625`, 0.36071679572626025`, 0.9364984893644777]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.03217915333176364], {
             RGBColor[
             0.9398558182628138, 0.7992553918121872, 0.27046478349011155`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.03217915333176364], {
             RGBColor[
             0.2330867180319017, 0.36231929757598597`, 0.9365853158197941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.03217915333176364], {
             RGBColor[
             0.2520329891677718, 0.3822330298027571, 0.9376642779324855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.03217915333176364], {
             RGBColor[
             0.2999237099233219, 0.432569213763913, 0.9403915836315417]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.03217915333176364], {
             RGBColor[
             0.2626771974737526, 0.39342076761412886`, 0.9382704498488161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.03217915333176364], {
             RGBColor[
             0.21089717481030001`, 0.33899668075178374`, 0.9353216541598114]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.03217915333176364], {
             RGBColor[
             0.9109681137578394, 0.6847252697068382, 0.24722105836383443`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.03217915333176364], {
             RGBColor[
             0.9837730937067766, 0.9874185803724101, 0.9123520990861677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.03217915333176364], {
             RGBColor[
             0.8192881970279116, 0.1492631112641677, 0.166103705297818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.03217915333176364], {
             RGBColor[
             0.6591015742674116, 0.7336144262659793, 0.9666567433347234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.03217915333176364], {
             RGBColor[
             0.8228256695060855, 0.17645367486173685`, 0.16949119293792111`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.03217915333176364], {
             RGBColor[
             0.9100637739514378, 0.9311241665985504, 0.9912838892546516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.03217915333176364], {
             RGBColor[
             0.4471878440862639, 0.5617533670581167, 0.9497153918858607]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.03217915333176364], {
             RGBColor[
             0.4754345148883495, 0.5850181831240037, 0.9518470930674744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.03217915333176364], {
             RGBColor[
             0.9218589159168126, 0.9405292926311409, 0.9924089204249567]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.03217915333176364], {
             RGBColor[
             0.6049269005052089, 0.6901459353332633, 0.9620412080094716]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.03217915333176364], {
             RGBColor[
             0.4540671923140028, 0.5676712280712366, 0.9501649791633402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.03217915333176364], {
             RGBColor[
             0.9756615083220127, 0.9295626939998534, 0.3599499850798584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.03217915333176364], {
             RGBColor[
             0.2571081050813221, 0.3875672984088326, 0.9379532982758011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.03217915333176364], {
             RGBColor[
             0.23863402700947722`, 0.3681498710311214, 0.9369012268595588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.03217915333176364], {
             RGBColor[
             0.23492201148043795`, 0.36424830735472313`, 0.9366898330666149]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.03217915333176364], {
             RGBColor[
             0.36785717736282086`, 0.49304113081751505`, 0.9446605119515972]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.03217915333176364], {
             RGBColor[
             0.24689616138342244`, 0.3768338981077132, 0.9373717431894225]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.03217915333176364], {
             RGBColor[
             0.9688572327835747, 0.9066102748888301, 0.333516659492644]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.03217915333176364], {
             RGBColor[
             0.30868412390727973`, 0.44177696430338015`, 0.9408904762480571]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.03217915333176364], {
             RGBColor[
             0.5255566438526651, 0.6257095853934133, 0.9557928906629534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.03217915333176364], {
             RGBColor[
             0.8174582326741875, 0.1351972033459516, 0.16435132936604271`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.03217915333176364], {
             RGBColor[
             0.3387393935852255, 0.4678207700117279, 0.942805152517134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.03217915333176364], {
             RGBColor[
             0.7400936775781565, 0.7968860729351169, 0.9747292792785006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.03217915333176364], {
             RGBColor[
             0.2505222001886238, 0.3806450947961188, 0.9375782407351351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.03217915333176364], {
             RGBColor[
             0.5784190314529432, 0.6686256530707418, 0.9599544114561535]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.03217915333176364], {
             RGBColor[
             0.22922310747734106`, 0.35825839791608494`, 0.9363652889144115]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.03217915333176364], {
             RGBColor[
             0.32451491921663345`, 0.4555002452565231, 0.9418987815885761]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.03217915333176364], {
             RGBColor[
             0.23920651037948798`, 0.3687515873505448, 0.9369338289405676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.03217915333176364], {
             RGBColor[
             0.290961948336973, 0.42314983412815754`, 0.9398812245669373]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.03217915333176364], {
             RGBColor[
             0.9183468399249884, 0.7139794601448493, 0.25315815463888625`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.03217915333176364], {
             RGBColor[
             0.2883719521470624, 0.4204275839173185, 0.939733728115478]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.03217915333176364], {
             RGBColor[
             0.2600361752617328, 0.3906448858188163, 0.9381200475408837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.03217915333176364], {
             RGBColor[
             0.22989884827362161`, 0.3589686443374169, 0.9364037713530907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.03217915333176364], {
             RGBColor[
             0.4438028563584466, 0.5588214608227114, 0.9494997034610714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.03217915333176364], {
             RGBColor[
             0.9070075396154186, 0.6690229130152352, 0.24403428744221908`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.03217915333176364], {
             RGBColor[
             0.21620788903044316`, 0.3445785781158837, 0.9356240914781508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.03217915333176364], {
             RGBColor[
             0.2695692814994847, 0.4006647849085395, 0.938662943838157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.03217915333176364], {
             RGBColor[
             0.9882272169582415, 0.9893996659125786, 0.8447690121952027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.03217915333176364], {
             RGBColor[
             0.822315843269912, 0.8611563485272284, 0.9829144132927453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.03217915333176364], {
             RGBColor[
             0.2243331252717409, 0.35311871657522015`, 0.9360868116618829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.03217915333176364], {
             RGBColor[
             0.34171577858230273`, 0.47039876509873646`, 0.9429948051372339]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.03217915333176364], {
             RGBColor[
             0.46951139015292603`, 0.5802095236300584, 0.951380802991181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.03217915333176364], {
             RGBColor[
             0.26047497796174324`, 0.3911060952782254, 0.938145036705499]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.03217915333176364], {
             RGBColor[
             0.22530836548640581`, 0.35414375587463387`, 0.9361423501493695]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.03217915333176364], {
             RGBColor[
             0.8226071697061851, 0.17477418965247965`, 0.16928195728277629`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.03217915333176364], {
             RGBColor[
             0.2529332615169164, 0.38317927312227185`, 0.9377155471109357]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.03217915333176364], {
             RGBColor[
             0.2110206902246306, 0.3391265032835748, 0.9353286881799328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.03217915333176364], {
             RGBColor[
             0.8089540339665278, 0.8506803067038047, 0.9815926360666765]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.03217915333176364], {
             RGBColor[
             0.17944836957228805`, 0.3059419924772149, 0.9335306912258446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.03217915333176364], {
             RGBColor[
             0.9386428604207964, 0.9537605262817009, 0.9887458121893573]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.03217915333176364], {
             RGBColor[
             0.26208361027682536`, 0.3927968698345563, 0.9382366459360847]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.03217915333176364], {
             RGBColor[
             0.19003101446562676`, 0.31706502323855396`, 0.9341333571969002]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.03217915333176364], {
             RGBColor[
             0.5918946974095183, 0.6795658057661227, 0.9610152652432459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.03217915333176364], {
             RGBColor[
             0.2549979314676595, 0.3853493721481386, 0.937833127010225]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.03217915333176364], {
             RGBColor[
             0.5711989452526345, 0.6627640618321545, 0.9593860198224179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.03217915333176364], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.03217915333176364], {
             RGBColor[
             0.9930589289900814, 0.9875620758967413, 0.48588543977432486`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.03217915333176364], {
             RGBColor[
             0.249587147505622, 0.3796622951405196, 0.9375249908681246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.03217915333176364], {
             RGBColor[
             0.30678788301618565`, 0.43978389489822367`, 0.9407824881345462]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.03217915333176364], {
             RGBColor[
             0.6470169280819229, 0.7241738088191627, 0.9654522587403933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.03217915333176364], {
             RGBColor[
             0.2754373969927425, 0.40683254635196486`, 0.938997124334399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.03217915333176364], {
             RGBColor[
             0.2307279730478894, 0.35984010704471925`, 0.9364509887824051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.03217915333176364], {
             RGBColor[
             0.992100640761205, 0.9910014261975552, 0.7805763556806252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.03217915333176364], {
             RGBColor[
             0.765566144894021, 0.8167853580001923, 0.977268136766805]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.03217915333176364], {
             RGBColor[
             0.2578128298869203, 0.3883080088616496, 0.9379934313109329]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.03217915333176364], {
             RGBColor[
             0.2524156236360728, 0.382635202889368, 0.9376860683993983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.03217915333176364], {
             RGBColor[
             0.9456496399519233, 0.8222259641328803, 0.2751266284196432]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.03217915333176364], {
             RGBColor[
             0.23901320904650822`, 0.3685484153935707, 0.9369228207156182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.03217915333176364], {
             RGBColor[
             0.6319940482543123, 0.7121202652370958, 0.9641720330305101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.03217915333176364], {
             RGBColor[
             0.6468617732853108, 0.7240526007128293, 0.965436794360271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.03217915333176364], {
             RGBColor[
             0.9089152991886196, 0.6765865439997854, 0.2455693155756892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.03217915333176364], {
             RGBColor[
             0.24399808998490613`, 0.37378784131953313`, 0.9372067023105894]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.03217915333176364], {
             RGBColor[
             0.23871510677441427`, 0.3682350910048242, 0.9369058442322252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.03217915333176364], {
             RGBColor[
             0.726249879738111, 0.7860711928457129, 0.9733494588874512]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.03217915333176364], {
             RGBColor[
             0.260213393629744, 0.3908311535598896, 0.9381301398647709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.03217915333176364], {
             RGBColor[
             0.245025991273468, 0.37486823074651754`, 0.9372652397683294]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.03217915333176364], {
             RGBColor[
             0.8977533081905217, 0.6286034774622947, 0.23639519286946437`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.03217915333176364], {
             RGBColor[
             0.4051337172328171, 0.5253281960795354, 0.9470357401097634]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.03217915333176364], {
             RGBColor[
             0.696491580031562, 0.7628237829435023, 0.9703834296798242]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.03217915333176364], {
             RGBColor[
             0.2110186790508826, 0.3391243894124498, 0.9353285736465631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.03217915333176364], {
             RGBColor[
             0.21123106399266978`, 0.3393476194522512, 0.9353406686548026]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.03217915333176364], {
             RGBColor[
             0.21275955169572475`, 0.34095415693987974`, 0.9354277137682966]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.03217915333176364], {
             RGBColor[
             0.24238734999627973`, 0.3720948514646729, 0.9371149730511135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.03217915333176364], {
             RGBColor[
             0.30152154075751214`, 0.43424863527897317`, 0.94048257773377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.03217915333176364], {
             RGBColor[
             0.9466390204165737, 0.9597240493140413, 0.9752103990490407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.03217915333176364], {
             RGBColor[
             0.8234301328695646, 0.862044852807406, 0.9830206952294982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.03217915333176364], {
             RGBColor[
             0.21412870248835636`, 0.3423932212321097, 0.9355056848804599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.03217915333176364], {
             RGBColor[
             0.8899967779325137, 0.5933828851443484, 0.2299229538922278]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.03217915333176364], {
             RGBColor[
             0.2568179059531509, 0.3872622807254372, 0.9379367718647629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.03217915333176364], {
             RGBColor[
             0.9872770340850194, 0.9687445898536212, 0.4050741092611545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.03217915333176364], {
             RGBColor[
             0.28961174034798287`, 0.421730679923598, 0.9398043322194181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.03217915333176364], {
             RGBColor[
             0.21909843402136348`, 0.34761672417247863`, 0.9357887037392056]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.03217915333176364], {
             RGBColor[
             0.20290260740476634`, 0.33059388352371805`, 0.9348663753729688]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.03217915333176364], {
             RGBColor[
             0.9703761157708419, 0.9117338238555674, 0.33941723308119276`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.03217915333176364], {
             RGBColor[
             0.9852399747517544, 0.9881643644915732, 0.8942753462917085]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.03217915333176364], {
             RGBColor[
             0.2610883790761277, 0.39175081874132034`, 0.9381799689915176]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.03217915333176364], {
             RGBColor[
             0.27079044913528966`, 0.40194830952027055`, 0.9387324875284604]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.03217915333176364], {
             RGBColor[
             0.18257815057035692`, 0.3092315907457619, 0.9337089276235886]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.03217915333176364], {
             RGBColor[
             0.519374038863881, 0.6206902681403376, 0.955306173350608]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.03217915333176364], {
             RGBColor[
             0.46295717480753656`, 0.5748885163486347, 0.9508648311503101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.03217915333176364], {
             RGBColor[
             0.2828083531870263, 0.41457988865777246`, 0.939416889385311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.03217915333176364], {
             RGBColor[
             0.9258119809847409, 0.9436813594132142, 0.9927859673000785]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.03217915333176364], {
             RGBColor[
             0.24327422624281886`, 0.37302701463098736`, 0.937165479341338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.03217915333176364], {
             RGBColor[
             0.25427950679235417`, 0.38459426226363735`, 0.9377922137877805]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.03217915333176364], {
             RGBColor[
             0.9906270631619555, 0.9903920639910485, 0.8049973499967711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.03217915333176364], {
             RGBColor[
             0.2238174684207968, 0.35257672853034516`, 0.9360574457670676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.03217915333176364], {
             RGBColor[
             0.24158367299712782`, 0.37125013598249945`, 0.9370692048349454]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.03217915333176364], {
             RGBColor[
             0.7098940201909748, 0.7732938710583535, 0.9717192596619902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.03217915333176364], {
             RGBColor[
             0.8177864636409283, 0.8575802678943982, 0.9824729701128726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.03217915333176364], {
             RGBColor[
             0.5084161265639328, 0.611794141286916, 0.9544435263542006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.03217915333176364], {
             RGBColor[
             0.8302102447519867, 0.867451129981215, 0.983667388353521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.03217915333176364], {
             RGBColor[
             0.2799576543907215, 0.4115836234781131, 0.9392545463060924]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.03217915333176364], {
             RGBColor[
             0.21156771774634342`, 0.33970146389244305`, 0.9353598405880397]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.03217915333176364], {
             RGBColor[
             0.3393902356747875, 0.4683844967174319, 0.9428466235995638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.03217915333176364], {
             RGBColor[
             0.3185921337049145, 0.45037022613412764`, 0.941521386933083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.03217915333176364], {
             RGBColor[
             0.3094371851822424, 0.44244066986488095`, 0.9409380417086214]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.03217915333176364], {
             RGBColor[
             0.23513882534723038`, 0.36447619247551505`, 0.9367021802955814]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.03217915333176364], {
             RGBColor[
             0.22477195032544567`, 0.3535799495297792, 0.936111802099508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.03217915333176364], {
             RGBColor[
             0.45209247002133757`, 0.5660015075294104, 0.9500279103134532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.03217915333176364], {
             RGBColor[
             0.5272216074067284, 0.6270612778123552, 0.9559239626928917]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.03217915333176364], {
             RGBColor[
             0.19556045555100107`, 0.3228768164060961, 0.9344482506866372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.03217915333176364], {
             RGBColor[
             0.26139903658851843`, 0.39207733948366696`, 0.9381976604772716]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.03217915333176364], {
             RGBColor[
             0.28051817934621337`, 0.41217277074566994`, 0.9392864673730853]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.03217915333176364], {
             RGBColor[
             0.2110065608580655, 0.33911165242346125`, 0.9353278835334095]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.03217915333176364], {
             RGBColor[
             0.2847433322190086, 0.4166136743051424, 0.9395270835786375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.03217915333176364], {
             RGBColor[
             0.9942883740099587, 0.9901917344782997, 0.6197029429328111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.03217915333176364], {
             RGBColor[
             0.36576050208801136`, 0.49122509607643855`, 0.9445269136571035]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.03217915333176364], {
             RGBColor[
             0.99377812825938, 0.9891003704115706, 0.5641658418540755]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.03217915333176364], {
             RGBColor[
             0.2215837127017966, 0.35022890964138337`, 0.935930236683416]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.03217915333176364], {
             RGBColor[
             0.6033581995623302, 0.6888723932386622, 0.9619177141249072]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.03217915333176364], {
             RGBColor[
             0.7222005724227306, 0.7829078431950623, 0.9729458617771823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.03217915333176364], {
             RGBColor[
             0.32062864936426844`, 0.45213415364000675`, 0.941651151910077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.03217915333176364], {
             RGBColor[
             0.20194739446585683`, 0.3295898941609259, 0.9348119774092088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.03217915333176364], {
             RGBColor[
             0.3450320119322843, 0.4732711197477559, 0.9432061125938647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.03217915333176364], {
             RGBColor[
             0.2800500850584523, 0.411680773970341, 0.9392598100958807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.03217915333176364], {
             RGBColor[
             0.26295522261758464`, 0.39371298966810864`, 0.9382862829694559]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.03217915333176364], {
             RGBColor[
             0.4453791406536688, 0.5601867590528806, 0.9496001429025095]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.03217915333176364], {
             RGBColor[
             0.4327427506991586, 0.5492417531977101, 0.948794963308529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.03217915333176364], {
             RGBColor[
             0.24574449108125243`, 0.37562341960001794`, 0.9373061572694574]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.03217915333176364], {
             RGBColor[
             0.9941541355650164, 0.9899046120181566, 0.6050919166244885]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.03217915333176364], {
             RGBColor[
             0.21037964845754836`, 0.3384527277419758, 0.9352921817996338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.03217915333176364], {
             RGBColor[
             0.27977343586669706`, 0.4113899981292344, 0.939244055333676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.03217915333176364], {
             RGBColor[
             0.23092116646773903`, 0.3600431655781515, 0.9364619908618614]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.03217915333176364], {
             RGBColor[
             0.5183784049780293, 0.6198819676990077, 0.9552277934039866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.03217915333176364], {
             RGBColor[
             0.6756901028072094, 0.7465735108387558, 0.9683101328309576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.03217915333176364], {
             RGBColor[
             0.9685766725786527, 0.9056638794389593, 0.332426736075871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.03217915333176364], {
             RGBColor[
             0.2455681205459235, 0.37543804298484945`, 0.9372961132283874]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.03217915333176364], {
             RGBColor[
             0.3103917228488082, 0.4432674424152022, 0.9409988640046705]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.03217915333176364], {
             RGBColor[
             0.35562652096447817`, 0.48244755097593534`, 0.9438811853410396]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.03217915333176364], {
             RGBColor[
             0.40465902674538534`, 0.5249170430379596, 0.9470054932516565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.03217915333176364], {
             RGBColor[
             0.8625124936811881, 0.46858316947675277`, 0.2069893934114667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.03217915333176364], {
             RGBColor[
             0.34952976604112324`, 0.4771668482931376, 0.9434927055084721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.03217915333176364], {
             RGBColor[
             0.25624071750281635`, 0.38665561906827417`, 0.93790390183639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.03217915333176364], {
             RGBColor[
             0.9012804456996433, 0.6446193851073215, 0.2393383228651273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.03217915333176364], {
             RGBColor[
             0.21931469518675756`, 0.34784402836905765`, 0.9358010194926452]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.03217915333176364], {
             RGBColor[
             0.21278150541118618`, 0.3409772316867757, 0.9354289639999145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.03217915333176364], {
             RGBColor[
             0.25745394897088236`, 0.38793080226452953`, 0.9379729935736814]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.03217915333176364], {
             RGBColor[
             0.8312166238387177, 0.8682535893475418, 0.9837633776892186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.03217915333176364], {
             RGBColor[
             0.27204560568907665`, 0.4032675586398226, 0.9388039668373608]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.03217915333176364], {
             RGBColor[
             0.2514775053864574, 0.3816491811288898, 0.9376326439529042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.03217915333176364], {
             RGBColor[
             0.2503218011924054, 0.380434462745063, 0.9375668283087641]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.03217915333176364], {
             RGBColor[
             0.2761037265699157, 0.40753290098530925`, 0.9390350708180728]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.03217915333176364], {
             RGBColor[
             0.25484534055170655`, 0.38518898942064916`, 0.9378244371832996]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.03217915333176364], {
             RGBColor[
             0.43839329858407067`, 0.5541359737708264, 0.9491550112231723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.03217915333176364], {
             RGBColor[
             0.41487938737084307`, 0.5337694057214698, 0.9476567255932007]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.03217915333176364], {
             RGBColor[
             0.20852643568424656`, 0.3365048836167593, 0.9351866440737768]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.03217915333176364], {
             RGBColor[
             0.22095736038557218`, 0.3495705736440009, 0.9358945668456122]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.03217915333176364], {
             RGBColor[
             0.26549066491796636`, 0.3963779002821365, 0.9384306726576119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.03217915333176364], {
             RGBColor[
             0.9931470290452047, 0.9914341346439413, 0.7632349938486772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.03217915333176364], {
             RGBColor[
             0.898780922280212, 0.63326963303821, 0.23725265925502825`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.03217915333176364], {
             RGBColor[
             0.28023632613366145`, 0.41187652514875206`, 0.939270416249595]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.03217915333176364], {
             RGBColor[
             0.7484278388783107, 0.8033967830847693, 0.9755599505897345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.03217915333176364], {
             RGBColor[
             0.5754210452890663, 0.6661917528451691, 0.9597183990033479]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.03217915333176364], {
             RGBColor[
             0.3393631406607411, 0.4683610283780999, 0.942844897129228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.03217915333176364], {
             RGBColor[
             0.2935687509337651, 0.4258897489382169, 0.9400296781184059]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.03217915333176364], {
             RGBColor[
             0.22336510960731928`, 0.352101270736175, 0.9360316846018449]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.03217915333176364], {
             RGBColor[
             0.17908812663026416`, 0.30556335430442605`, 0.933510175923228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.03217915333176364], {
             RGBColor[
             0.26629927432356376`, 0.3972278000362168, 0.9384767217670303]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.03217915333176364], {
             RGBColor[
             0.8203907902431329, 0.1577381258757864, 0.16715954980591485`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.03217915333176364], {
             RGBColor[
             0.24794921220500737`, 0.3779407212884774, 0.9374317128758627]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.03217915333176364], {
             RGBColor[
             0.22281999879048459`, 0.3515283247056597, 0.9360006413472455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.03217915333176364], {
             RGBColor[
             0.35886795134781274`, 0.48525511505495156`, 0.9440877264187814]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.03217915333176364], {
             RGBColor[
             0.27306809856961783`, 0.40434226348706437`, 0.938862196294265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.03217915333176364], {
             RGBColor[
             0.2782995151593558, 0.4098408140138484, 0.9391601177298633]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.03217915333176364], {
             RGBColor[
             0.2493495489754894, 0.37941256402073326`, 0.9375114599833291]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.03217915333176364], {
             RGBColor[
             0.9394254025446074, 0.954344144916344, 0.9874211724934188]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.03217915333176364], {
             RGBColor[
             0.2348790166106703, 0.36420311702056507`, 0.9366873845723869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.03217915333176364], {
             RGBColor[
             0.38961090759033284`, 0.5118831185663134, 0.9460466404056259]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{{3.8349502435193233`*^9, 3.8349502581408367`*^9}, 
   3.834950528174912*^9, 3.8349578088972807`*^9, 3.835018923470682*^9, 
   3.835019026079196*^9, 3.8350205603927774`*^9, 3.835044649527498*^9, 
   3.835045037805329*^9, 3.8350457183729286`*^9},
 CellLabel->
  "Out[333]=",ExpressionUUID->"f75ba1e6-ccf0-435a-88ef-2f3e9c8d778e"]
}, Open  ]],

Cell["r = 3 :", "Text",
 CellChangeTimes->{{3.834793779215767*^9, 3.8347938725231647`*^9}, {
  3.8347953347101345`*^9, 3.8347953431477337`*^9}, {3.8348851911359825`*^9, 
  3.83488519180678*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"71a49330-cf07-48d0-901a-b9ea12f5d4c6"],

Cell["Cubic Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.834795179278664*^9}},ExpressionUUID->"c3869e81-af2b-491c-bdf7-\
463dfc8129f1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c\[Rho]3if4", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"CMDi3f400", ",", "krif4"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.834947911760502*^9, 
   3.834947914304406*^9}, {3.834947957535968*^9, 3.8349479704802837`*^9}, {
   3.8349480487781425`*^9, 3.834948105065866*^9}, {3.8349497992119355`*^9, 
   3.83494980454772*^9}, {3.8349578354451995`*^9, 3.83495784069214*^9}, {
   3.835018838991932*^9, 3.8350188405169106`*^9}, {3.8350443590646524`*^9, 
   3.8350443609005165`*^9}, {3.835044949683157*^9, 3.8350449510226583`*^9}, {
   3.8350456161573725`*^9, 3.8350456174929495`*^9}},
 CellLabel->
  "In[334]:=",ExpressionUUID->"3a84defb-4866-45aa-83a6-6f2b7cc7465f"],

Cell[BoxData[
 RowBox[{"-", "0.023232946343011682`"}]], "Output",
 CellChangeTimes->{
  3.834948013482303*^9, {3.834948049945756*^9, 3.834948058990469*^9}, 
   3.8349481059508953`*^9, 3.8349499476386404`*^9, 3.834957841643118*^9, 
   3.8350189236386824`*^9, 3.8350190270322647`*^9, 3.8350204164650445`*^9, 
   3.8350205609787445`*^9, 3.8350446521595054`*^9, 3.835045038186325*^9, 
   3.835045719133933*^9},
 CellLabel->
  "Out[334]=",ExpressionUUID->"d2f77a14-4f71-433b-a881-32e6553a4e87"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CP3if4", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"CMDi3f400", ",", "krif4"}], "}"}], "]"}], ",", "c\[Rho]3if4"}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.8349481210775223`*^9, 3.834948150679065*^9}, {
  3.8349481924167476`*^9, 3.8349481986802473`*^9}, {3.834949807949147*^9, 
  3.834949815491851*^9}, {3.8349578438231587`*^9, 3.8349578533989754`*^9}, {
  3.835018846742407*^9, 3.835018849961266*^9}, {3.835044361707146*^9, 
  3.835044363446494*^9}, {3.835044955607832*^9, 3.835044963462711*^9}, {
  3.835045618283763*^9, 3.835045620325021*^9}},
 CellLabel->
  "In[335]:=",ExpressionUUID->"536d270a-ad72-4a82-ac3a-4d4d94e37ee0"],

Cell[BoxData["0.464831615337423`"], "Output",
 CellChangeTimes->{3.8349481513130674`*^9, 3.8349482002632475`*^9, 
  3.8349499490044084`*^9, 3.8349578559445095`*^9, 3.83501892389968*^9, 
  3.8350190272812295`*^9, 3.8350205613687525`*^9, 3.8350446533657885`*^9, 
  3.835045038277321*^9, 3.8350457193059344`*^9},
 CellLabel->
  "Out[335]=",ExpressionUUID->"9995dcad-36c4-4e86-b65c-ade5bbd35b15"]
}, Open  ]],

Cell["Absolute Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.8347951985065947`*^9}},ExpressionUUID->"1f127eaf-fc42-4613-a3c1-\
fba593164f06"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a\[Rho]3if4", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"AMDi3f400", ",", "krif4"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.8348873709111376`*^9, 
   3.8348873755217657`*^9}, {3.8349481641806583`*^9, 
   3.8349481824982553`*^9}, {3.834949818653184*^9, 3.8349498238056817`*^9}, {
   3.834957866337153*^9, 3.834957872254816*^9}, {3.8350188531986103`*^9, 
   3.8350188546829796`*^9}, {3.8350443646261296`*^9, 3.835044365855239*^9}, {
   3.8350449644881577`*^9, 3.8350449665516605`*^9}, {3.83504562436516*^9, 
   3.835045625597438*^9}},
 CellLabel->
  "In[336]:=",ExpressionUUID->"0fc598f8-8cec-4937-b762-89f06098d1fb"],

Cell[BoxData[
 RowBox[{"-", "0.01678532163961404`"}]], "Output",
 CellChangeTimes->{3.834948182946122*^9, 3.83494995054953*^9, 
  3.834957874365346*^9, 3.835018924320698*^9, 3.8350190275072393`*^9, 
  3.8350205614078007`*^9, 3.835044655427159*^9, 3.8350450383643217`*^9, 
  3.8350457194749312`*^9},
 CellLabel->
  "Out[336]=",ExpressionUUID->"9a2be8dc-9fe6-4e94-9075-e8bab7739706"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"aP3if4", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"AMDi3f400", ",", "krif4"}], "}"}], "]"}], ",", "a\[Rho]3if4"}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8349482041094093`*^9, 
  3.8349482202691827`*^9}, {3.8349498269490285`*^9, 3.8349498405604887`*^9}, {
  3.8349578796796703`*^9, 3.834957886620027*^9}, {3.8350188593392305`*^9, 
  3.835018861313801*^9}, {3.8350443665470304`*^9, 3.835044368736087*^9}, {
  3.835044972843706*^9, 3.835044975243416*^9}, {3.835045628307909*^9, 
  3.835045630410689*^9}},
 CellLabel->
  "In[337]:=",ExpressionUUID->"90ee2376-6e9a-4655-8258-ca96f1e1978f"],

Cell[BoxData["0.8590843162773794`"], "Output",
 CellChangeTimes->{3.834887440036944*^9, 3.8349482220989213`*^9, 
  3.8349499520491343`*^9, 3.8349578874036503`*^9, 3.83501892439668*^9, 
  3.8350190277232385`*^9, 3.8350205614517555`*^9, 3.8350446570245705`*^9, 
  3.8350450384513245`*^9, 3.8350457196659327`*^9},
 CellLabel->
  "Out[337]=",ExpressionUUID->"491d505f-3112-4292-b15f-b33c6825644a"]
}, Open  ]],

Cell["Max-min Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 3.8347951985065947`*^9}, {
  3.8348543263190746`*^9, 
  3.834854330052075*^9}},ExpressionUUID->"2448f64e-8222-4229-aae8-\
f5eacec897fe"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mM\[Rho]3if4", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"mMDi3f400", ",", "krif4"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8348874651734295`*^9, 3.8348874872060013`*^9}, {
  3.8349482319487157`*^9, 3.834948245258479*^9}, {3.834949844516972*^9, 
  3.8349498489188633`*^9}, {3.834957895209076*^9, 3.834957899999796*^9}, {
  3.83501886583329*^9, 3.835018866821826*^9}, {3.835044369483486*^9, 
  3.835044370515362*^9}, {3.8350449764211473`*^9, 3.835044978468176*^9}, {
  3.835045634374282*^9, 3.8350456358208165`*^9}},
 CellLabel->
  "In[338]:=",ExpressionUUID->"e765810b-6559-4870-9ce9-1b2f4afe1c24"],

Cell[BoxData[
 RowBox[{"-", "0.008404638877767972`"}]], "Output",
 CellChangeTimes->{3.834948246413353*^9, 3.834949953689977*^9, 
  3.834957900696502*^9, 3.835018924463678*^9, 3.835019027994238*^9, 
  3.835020561490786*^9, 3.8350446585457473`*^9, 3.8350450385433226`*^9, 
  3.835045719831933*^9},
 CellLabel->
  "Out[338]=",ExpressionUUID->"4c8a94a3-b16c-42ba-a558-677f0fdaef7f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mMP3if4", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"mMDi3f400", ",", "krif4"}], "}"}], "]"}], ",", 
    "mM\[Rho]3if4"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8348875260806427`*^9, 
  3.8348875488478312`*^9}, {3.8349482525846663`*^9, 3.8349482707073736`*^9}, {
  3.8349498532537427`*^9, 3.834949860995207*^9}, {3.834957902898573*^9, 
  3.8349579090270967`*^9}, {3.8350188699780455`*^9, 3.835018871634328*^9}, {
  3.835044378315168*^9, 3.8350443808084726`*^9}, {3.8350449818572917`*^9, 
  3.835044984227113*^9}, {3.835045639089673*^9, 3.835045640972607*^9}},
 CellLabel->
  "In[339]:=",ExpressionUUID->"ab4626bd-0416-4936-bf89-cfb61bedfe6f"],

Cell[BoxData["0.7896717865871543`"], "Output",
 CellChangeTimes->{3.834887440036944*^9, 3.8348875533996215`*^9, 
  3.834948277702903*^9, 3.834949955989804*^9, 3.834957909480212*^9, 
  3.835018924542716*^9, 3.835019028341303*^9, 3.8350205615287514`*^9, 
  3.835044659514542*^9, 3.835045038636324*^9, 3.8350457200229316`*^9},
 CellLabel->
  "Out[339]=",ExpressionUUID->"a088fca4-86c3-4009-8afe-72b150502dda"]
}, Open  ]],

Cell["r = 6 :", "Text",
 CellChangeTimes->{{3.834793779215767*^9, 3.8347938725231647`*^9}, {
  3.8347953347101345`*^9, 3.8347953431477337`*^9}, {3.8348851911359825`*^9, 
  3.83488519180678*^9}, {3.834948305866973*^9, 3.8349483068980722`*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"c5d3bffd-6229-4603-b6ad-f76afb32a885"],

Cell["Cubic Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.834795179278664*^9}},ExpressionUUID->"aef04940-6bc9-4015-9228-\
bba48dacf7bc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c\[Rho]6if4", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"CMDi6f400", ",", "krif4"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.834947911760502*^9, 
   3.834947914304406*^9}, {3.834947957535968*^9, 3.8349479704802837`*^9}, {
   3.8349480487781425`*^9, 3.834948105065866*^9}, {3.8349483158342133`*^9, 
   3.8349483193845987`*^9}, {3.834949864783629*^9, 3.834949869574106*^9}, {
   3.834957963470776*^9, 3.834957967378231*^9}, {3.835018875109179*^9, 
   3.8350188762029247`*^9}, {3.83504438203627*^9, 3.8350443836235657`*^9}, {
   3.8350449852346697`*^9, 3.8350449865535607`*^9}, {3.835045642906684*^9, 
   3.835045644449538*^9}},
 CellLabel->
  "In[340]:=",ExpressionUUID->"9611d735-087e-4fde-9c76-27436b0d5504"],

Cell[BoxData[
 RowBox[{"-", "0.02767381288867006`"}]], "Output",
 CellChangeTimes->{
  3.834948013482303*^9, {3.834948049945756*^9, 3.834948058990469*^9}, 
   3.8349481059508953`*^9, 3.834948360850016*^9, 3.8349499580565577`*^9, 
   3.834957967763415*^9, 3.835018924610717*^9, 3.835019028526283*^9, 
   3.8350205615657897`*^9, 3.835044661527397*^9, 3.8350450387243443`*^9, 
   3.8350457201739283`*^9},
 CellLabel->
  "Out[340]=",ExpressionUUID->"2fc1e483-5125-415b-9f3b-06ce6a1ea652"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CP6if4", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"CMDi6f400", ",", "krif4"}], "}"}], "]"}], ",", "c\[Rho]6if4"}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.8349481210775223`*^9, 3.834948150679065*^9}, {
  3.8349481924167476`*^9, 3.8349481986802473`*^9}, {3.8349483230197706`*^9, 
  3.834948338654296*^9}, {3.8349498724373255`*^9, 3.8349498802583637`*^9}, {
  3.8349579696959915`*^9, 3.834957975592292*^9}, {3.8350188769841766`*^9, 
  3.835018878671647*^9}, {3.835044384544117*^9, 3.8350443867509155`*^9}, {
  3.8350449903821464`*^9, 3.83504499270442*^9}, {3.835045647655678*^9, 
  3.835045649855909*^9}},
 CellLabel->
  "In[341]:=",ExpressionUUID->"e9a3a4be-d580-4ac4-9e42-106e3dff0ebc"],

Cell[BoxData["0.5514339431156465`"], "Output",
 CellChangeTimes->{3.8350446625455046`*^9, 3.8350450388173184`*^9, 
  3.835045720313956*^9},
 CellLabel->
  "Out[341]=",ExpressionUUID->"95388b36-7116-4ab6-b06a-0fb86dadf6d0"]
}, Open  ]],

Cell["Absolute Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.8347951985065947`*^9}},ExpressionUUID->"2c0d36aa-9ee4-407b-8ef9-\
e86eaaa01b66"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a\[Rho]6if4", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"AMDi6f400", ",", "krif4"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.8348873709111376`*^9, 
   3.8348873755217657`*^9}, {3.8349481641806583`*^9, 
   3.8349481824982553`*^9}, {3.834948329127375*^9, 3.834948332212267*^9}, {
   3.834949883458797*^9, 3.8349498875077024`*^9}, {3.834957978394422*^9, 
   3.8349579827581863`*^9}, {3.8350188795779624`*^9, 3.83501888042175*^9}, {
   3.8350443900912123`*^9, 3.835044391591655*^9}, {3.8350449954828196`*^9, 
   3.835044996992873*^9}, {3.8350456507829885`*^9, 3.8350456521119957`*^9}},
 CellLabel->
  "In[342]:=",ExpressionUUID->"7cb1a6e1-152d-4ffe-b295-f62a8e98cc54"],

Cell[BoxData[
 RowBox[{"-", "0.03351086462479946`"}]], "Output",
 CellChangeTimes->{3.8350457204409323`*^9},
 CellLabel->
  "Out[342]=",ExpressionUUID->"cfaa5279-807f-4261-a51a-36f9ab3dedd9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"aP6if4", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"AMDi6f400", ",", "krif4"}], "}"}], "]"}], ",", "a\[Rho]6if4"}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8349482041094093`*^9, 
  3.8349482202691827`*^9}, {3.834948340881687*^9, 3.834948354997751*^9}, {
  3.8349498907390194`*^9, 3.8349498979971194`*^9}, {3.8349579853563895`*^9, 
  3.8349579919125147`*^9}, {3.8350188832810483`*^9, 3.83501888448921*^9}, {
  3.835044392264258*^9, 3.835044393785404*^9}, {3.835044997778226*^9, 
  3.835044999929602*^9}, {3.8350456632120996`*^9, 3.835045665307251*^9}},
 CellLabel->
  "In[343]:=",ExpressionUUID->"97e6a3b1-1d85-4b6b-837c-7c3667d62151"],

Cell[BoxData["0.5684183270539113`"], "Output",
 CellChangeTimes->{3.835044665314339*^9, 3.8350450390013194`*^9, 
  3.8350457205699325`*^9},
 CellLabel->
  "Out[343]=",ExpressionUUID->"448470f8-e07a-4815-8a35-f7cd4e52ae88"]
}, Open  ]],

Cell["Max-min Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 3.8347951985065947`*^9}, {
  3.8348543263190746`*^9, 
  3.834854330052075*^9}},ExpressionUUID->"ba0a319c-f2f8-4332-9f2e-\
af09c8eaae2d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mM\[Rho]6if4", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"mMDi6f400", ",", "krif4"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8348874651734295`*^9, 3.8348874872060013`*^9}, {
   3.8349482319487157`*^9, 3.834948245258479*^9}, 3.8349483527075925`*^9, {
   3.8349499042423377`*^9, 3.8349499090679235`*^9}, {3.834949978751977*^9, 
   3.8349499794842105`*^9}, {3.834957994342047*^9, 3.834957998175455*^9}, {
   3.835018886286111*^9, 3.8350188870361056`*^9}, {3.835044395189496*^9, 
   3.835044396222158*^9}, {3.8350450026406775`*^9, 3.8350450038650913`*^9}, {
   3.8350456680827856`*^9, 3.8350456693830676`*^9}},
 CellLabel->
  "In[344]:=",ExpressionUUID->"c6a495c9-e726-41e4-8b10-e3222985b615"],

Cell[BoxData[
 RowBox[{"-", "0.02003444906457847`"}]], "Output",
 CellChangeTimes->{3.835044666861985*^9, 3.835045039089321*^9, 
  3.8350457207069407`*^9},
 CellLabel->
  "Out[344]=",ExpressionUUID->"205a995a-36da-49dc-a87e-c76bd9e19f58"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mMP6if4", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"mMDi6f400", ",", "krif4"}], "}"}], "]"}], ",", 
    "mM\[Rho]6if4"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8348875260806427`*^9, 
  3.8348875488478312`*^9}, {3.8349482525846663`*^9, 3.8349482707073736`*^9}, {
  3.83494834565068*^9, 3.8349483504716325`*^9}, {3.8349499122654495`*^9, 
  3.83494991854418*^9}, {3.834958000997678*^9, 3.8349580074869604`*^9}, {
  3.8350188877705455`*^9, 3.8350189082569094`*^9}, {3.8350443974385123`*^9, 
  3.8350443985852137`*^9}, {3.8350450046283274`*^9, 3.835045006371921*^9}, {
  3.83504567018804*^9, 3.8350456724624395`*^9}},
 CellLabel->
  "In[345]:=",ExpressionUUID->"5074a7f5-bd5e-4aca-8db3-e7ba0d26c2ad"],

Cell[BoxData["0.8161535564034202`"], "Output",
 CellChangeTimes->{
  3.834887440036944*^9, 3.8348875533996215`*^9, 3.834948277702903*^9, 
   3.8349483617580156`*^9, {3.834949965578516*^9, 3.8349499927811513`*^9}, 
   3.834958007945059*^9, 3.8350189249776793`*^9, 3.835019029685795*^9, 
   3.835020561757756*^9, 3.835044668294428*^9, 3.835045039206321*^9, 
   3.8350457208449287`*^9},
 CellLabel->
  "Out[345]=",ExpressionUUID->"048bceda-502f-4bdf-a9d6-84b741389959"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5th imported file", "Subsubsection",
 CellChangeTimes->{{3.834947473073307*^9, 3.8349474798089457`*^9}, {
   3.8349497159535103`*^9, 3.8349497173354855`*^9}, {3.834956622993673*^9, 
   3.834956623710862*^9}, {3.8350187834860272`*^9, 3.835018783813758*^9}, {
   3.835044179773861*^9, 3.8350441837622757`*^9}, {3.8350447472475395`*^9, 
   3.8350447488425937`*^9}, {3.8350455598331027`*^9, 3.835045564155232*^9}, {
   3.8350524155909667`*^9, 3.8350524174964385`*^9}, 3.83520172539546*^9},
 Background->RGBColor[
  1, 1, 0],ExpressionUUID->"1f336b4f-15be-46ad-9ded-62df80fce74f"],

Cell["Dividing stuff", "Text",
 CellChangeTimes->{{3.83494752022309*^9, 
  3.834947523245259*^9}},ExpressionUUID->"a4881f29-7a39-4ca2-8266-\
d3b919208e3d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dataf5", "=", 
   RowBox[{"StringSplit", "[", 
    RowBox[{
     RowBox[{"Import", "[", "\"\<ariadnaComputationf5.txt\>\"", "]"}], ",", 
     "\"\<]\n{\>\""}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8349434033501863`*^9, 3.834943479535334*^9}, {
   3.834943567297134*^9, 3.8349435736474867`*^9}, {3.8349441109152327`*^9, 
   3.8349441401892223`*^9}, 3.834944204627252*^9, {3.834949720382628*^9, 
   3.8349497230261507`*^9}, {3.834956627593688*^9, 3.834956631231691*^9}, {
   3.8350187858989725`*^9, 3.8350187908769827`*^9}, {3.835044188339929*^9, 
   3.835044192375786*^9}, {3.835044770661966*^9, 3.8350447715129805`*^9}, {
   3.8350455738505306`*^9, 3.835045575197592*^9}, {3.8350524290406647`*^9, 
   3.8350524297236624`*^9}},
 CellLabel->
  "In[417]:=",ExpressionUUID->"cdcd88e1-c786-422d-bf3f-fa0e5af400bf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"graphif5", "=", 
   RowBox[{"ToExpression", "@", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
      "dataf5", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "<>", 
      "\"\<]\>\""}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834944474381714*^9, 3.83494454689666*^9}, 
   3.8349475108233376`*^9, {3.834949726505718*^9, 3.8349497324197383`*^9}, {
   3.8349566345564103`*^9, 3.834956636582815*^9}, {3.8350188037132354`*^9, 
   3.8350188065525265`*^9}, {3.835044199446479*^9, 3.8350442063533845`*^9}, {
   3.8350447722871337`*^9, 3.835044772707575*^9}, {3.835045575945426*^9, 
   3.8350455767503777`*^9}, {3.8350524305916667`*^9, 3.835052431239175*^9}},
 CellLabel->
  "In[418]:=",ExpressionUUID->"9dd4f0fb-c975-43e4-a9e7-08124afa9523"],

Cell[BoxData[
 RowBox[{
  RowBox[{"otherif5", "=", 
   RowBox[{"ToExpression", "@", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "<>", "\"\<}}\>\""}], "&"}], ",", 
      RowBox[{"StringSplit", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\"\<{\>\"", "<>", 
          RowBox[{
          "dataf5", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
         ")"}], ",", "\"\<}}\>\""}], "]"}]}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834944518155362*^9, 3.8349445533517303`*^9}, 
   3.8349446259294133`*^9, {3.8349447635371876`*^9, 3.8349447780382657`*^9}, {
   3.834944820013957*^9, 3.8349448816359477`*^9}, {3.834944915595456*^9, 
   3.834944918286141*^9}, {3.8349449615053425`*^9, 3.834944967406804*^9}, {
   3.834945029266304*^9, 3.834945031628281*^9}, {3.834945108799203*^9, 
   3.8349451822852197`*^9}, 3.834945584171259*^9, {3.834949734758335*^9, 
   3.8349497379503355`*^9}, {3.834956638769047*^9, 3.8349566423540664`*^9}, {
   3.8350188094708586`*^9, 3.8350188125204616`*^9}, {3.8350442096862793`*^9, 
   3.835044210497281*^9}, 3.8350442469097853`*^9, {3.835044779420373*^9, 
   3.835044781545072*^9}, {3.8350455774187374`*^9, 3.8350455783186817`*^9}, {
   3.835052432081176*^9, 3.8350524328097343`*^9}},
 CellLabel->
  "In[419]:=",ExpressionUUID->"3857c2e7-bf99-469c-b8a5-85c33e9098c8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "CMDi3f500", "}"}], ",", 
     RowBox[{"{", "AMDi3f500", "}"}], ",", 
     RowBox[{"{", "mMDi3f500", "}"}], ",", 
     RowBox[{"{", "CMDi6f500", "}"}], ",", 
     RowBox[{"{", "AMDi6f500", "}"}], ",", 
     RowBox[{"{", "mMDi6f500", "}"}]}], "}"}], "=", "otherif5"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.834945694541313*^9, 3.834945753140644*^9}, {
  3.8349459487260857`*^9, 3.8349459670133495`*^9}, {3.8349471029719105`*^9, 
  3.8349471182020655`*^9}, {3.83494974203613*^9, 3.8349497544188104`*^9}, {
  3.834956647753375*^9, 3.8349566844693546`*^9}, {3.8350188134722548`*^9, 
  3.835018816812196*^9}, {3.835044228572632*^9, 3.835044233700058*^9}, {
  3.8350447829709044`*^9, 3.835044786739727*^9}, {3.8350455804482784`*^9, 
  3.835045582889475*^9}, {3.835052433910961*^9, 3.835052437637211*^9}},
 CellLabel->
  "In[420]:=",ExpressionUUID->"5ad947c3-a0e8-46bc-bf11-62b8deb4184b"],

Cell["\[OpenCurlyDoubleQuote]Cleaning\[CloseCurlyDoubleQuote] the graph:", \
"Text",
 CellChangeTimes->{{3.8349477786156034`*^9, 
  3.8349478283202667`*^9}},ExpressionUUID->"712eb73b-1c06-4598-8b43-\
3a500ed8bc6c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"graphinf5", "=", 
   RowBox[{"IndexGraph", "@", "graphif5"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834946654863307*^9, 3.834946693639777*^9}, {
  3.834949757637121*^9, 3.834949759707878*^9}, {3.8349566892836237`*^9, 
  3.834956691608691*^9}, {3.83501881773997*^9, 3.8350188182388163`*^9}, {
  3.8350442520120163`*^9, 3.8350442531771507`*^9}, {3.835044787881835*^9, 
  3.8350447894788456`*^9}, {3.835045583706751*^9, 3.835045584330986*^9}, {
  3.8350524386127143`*^9, 3.8350524394958453`*^9}},
 CellLabel->
  "In[421]:=",ExpressionUUID->"511f4bf7-344d-4cd0-906e-56d1beeb988a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pointsif5", "=", 
   RowBox[{"VertexList", "@", "graphinf5"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834784420352569*^9, 3.8347844264642625`*^9}, {
  3.8348756828269844`*^9, 3.8348756865131674`*^9}, {3.834878831782991*^9, 
  3.8348788488376627`*^9}, {3.8349467020325813`*^9, 3.834946739879963*^9}, {
  3.8349497621629615`*^9, 3.8349497641865125`*^9}, {3.834956695197647*^9, 
  3.834956697830969*^9}, {3.835018818796376*^9, 3.8350188192932053`*^9}, {
  3.835044292816033*^9, 3.8350442934580317`*^9}, {3.835044790599271*^9, 
  3.835044791093337*^9}, {3.8350455847893662`*^9, 3.8350455852439384`*^9}, {
  3.835052440189391*^9, 3.8350524407077737`*^9}},
 CellLabel->
  "In[422]:=",ExpressionUUID->"9723012a-89ee-4f37-9d55-96d5107a8d73"],

Cell[BoxData[
 RowBox[{
  RowBox[{"coordpointsif5", "=", 
   RowBox[{"VertexList", "@", "graphif5"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834879134322084*^9, 3.834879146224797*^9}, {
  3.834946724882841*^9, 3.834946736706849*^9}, {3.834949767417904*^9, 
  3.8349497706963253`*^9}, {3.8349567000470257`*^9, 3.8349567019660654`*^9}, {
  3.835018819834511*^9, 3.835018820572505*^9}, {3.835044294376539*^9, 
  3.8350442977248926`*^9}, {3.835044791824248*^9, 3.8350447923863506`*^9}, {
  3.8350455858029118`*^9, 3.8350455862985897`*^9}, {3.8350524412464304`*^9, 
  3.8350524420217385`*^9}},
 CellLabel->
  "In[423]:=",ExpressionUUID->"e00008f3-c209-4f99-84b1-0f0d087fdde8"],

Cell["Kretchmann \[OpenCurlyDoubleQuote]real\[CloseCurlyDoubleQuote] \
values:", "Text",
 CellChangeTimes->{
  3.8347933561184683`*^9, {3.8347935444076195`*^9, 
   3.834793546974228*^9}},ExpressionUUID->"b4f4e3f3-5613-46c8-a4a2-\
a042eeeb3e0b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rvalif5", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1"}], "+", "r"}]]}], "\[Equal]", "#"}], ",", 
       RowBox[{"{", "r", "}"}]}], "]"}], "&"}], "/@", 
    RowBox[{"coordpointsif5", "\[LeftDoubleBracket]", 
     RowBox[{";;", ",", "3"}], "\[RightDoubleBracket]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834105426841242*^9, 3.8341054487325706`*^9}, {
   3.8341407674337025`*^9, 3.834140799285215*^9}, {3.8341408938375945`*^9, 
   3.834140946496229*^9}, {3.8341410168099756`*^9, 3.8341410671886864`*^9}, {
   3.8341411610986195`*^9, 3.834141210381962*^9}, {3.834141332672348*^9, 
   3.834141336755044*^9}, {3.834141461053176*^9, 3.834141468978607*^9}, {
   3.834141967115094*^9, 3.8341420256686225`*^9}, {3.8341640069512*^9, 
   3.834164012603241*^9}, {3.834164792400744*^9, 3.8341647947633886`*^9}, {
   3.83466546628111*^9, 3.834665483801684*^9}, {3.8347933895124626`*^9, 
   3.834793417249506*^9}, 3.8347960586942053`*^9, 3.834879156483405*^9, {
   3.8348862453609915`*^9, 3.8348862641404076`*^9}, 3.834886374221485*^9, {
   3.834946768449996*^9, 3.8349467823353415`*^9}, {3.8349468446168528`*^9, 
   3.834946857637892*^9}, 3.8349474594107084`*^9, {3.834949773350379*^9, 
   3.8349497766098785`*^9}, {3.8349567056279964`*^9, 
   3.8349567091770997`*^9}, {3.8350188215027976`*^9, 3.835018822410869*^9}, {
   3.835044298874358*^9, 3.8350443004592457`*^9}, 3.8350444868602533`*^9, {
   3.835044793477209*^9, 3.8350448005204644`*^9}, {3.835045587457754*^9, 
   3.8350455910161066`*^9}, {3.835052443171542*^9, 3.835052444349104*^9}},
 CellLabel->
  "In[424]:=",ExpressionUUID->"735f0c51-115c-4222-9876-f18d35a83a89"],

Cell[BoxData[
 RowBox[{
  RowBox[{"krif5", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"KHFlamm", "/.", "rvalif5"}], ")"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.834792366597866*^9, 3.834792376019791*^9}, {
   3.834793346399704*^9, 3.8347933590872536`*^9}, {3.834793445378667*^9, 
   3.8347934527754736`*^9}, {3.834793487784485*^9, 3.834793489659489*^9}, 
   3.8348550102643666`*^9, {3.8348863808528233`*^9, 3.83488645374378*^9}, {
   3.834886485165092*^9, 3.834886521271514*^9}, 3.8348865820814276`*^9, {
   3.83494679091998*^9, 3.8349467979310513`*^9}, {3.8349468742957215`*^9, 
   3.834946904080855*^9}, 3.8349474644429636`*^9, {3.834949779141443*^9, 
   3.834949781745859*^9}, {3.8349567110647635`*^9, 3.8349567138998594`*^9}, {
   3.8350188233356256`*^9, 3.8350188239955263`*^9}, {3.8350443047283278`*^9, 
   3.8350443056932993`*^9}, {3.835044525959175*^9, 3.835044526610751*^9}, {
   3.8350448048490252`*^9, 3.835044806579857*^9}, {3.8350455920142765`*^9, 
   3.835045592997998*^9}, {3.8350524456417847`*^9, 3.835052446349854*^9}},
 CellLabel->
  "In[425]:=",ExpressionUUID->"57067e2b-a72b-41b1-89d8-fe7ee445513f"],

Cell["Estimated with cubic Mean Deviation v Calculated: (r=3)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 
  3.8349503319477153`*^9}},ExpressionUUID->"7c97326e-f6a1-41b8-a8c3-\
70f58721f4d7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphinf5", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsif5", ",", "#"}], "}"}], "]"}], ",", "500", ",", "5"}],
      "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"CMDi3f500", ",", "krif5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349567344957485`*^9, 3.834956749729442*^9}, {
   3.8349587420893497`*^9, 3.834958755264699*^9}, {3.835018825281867*^9, 
   3.835018828052806*^9}, {3.835044306768691*^9, 3.8350443152608557`*^9}, {
   3.8350445713666224`*^9, 3.835044576386869*^9}, {3.8350448259670086`*^9, 
   3.8350448323754845`*^9}, {3.835045595956773*^9, 3.835045598251114*^9}, 
   3.8350457514276457`*^9, 3.8350458103509226`*^9, {3.83505205253205*^9, 
   3.8350520556646357`*^9}, {3.835052448602139*^9, 3.8350524539632254`*^9}, {
   3.8350526963427873`*^9, 3.8350526967144794`*^9}, {3.835129990453014*^9, 
   3.8351300253177066`*^9}},
 Background->RGBColor[1, 1, 0.85],
 CellLabel->
  "In[569]:=",ExpressionUUID->"cb0f9a62-8c5f-4add-a19b-12b903ae7dfb"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1dOWGAgQBNBMbNu2bds2J+bEtm3btm3btu01sjdnH271F1R1ssCg6p0C
ggUL9l38vMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEIS
kZgkJCUZyUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpR
mCIUpRjFKUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGY
JjSlGYE0pwUtaUVr2tCWdrSnAx3pRBCd6UJXutGdHvSkF73pQ1/60Z8BDGQQ
gxnCUIYxnBGMZBSjGcNYxjGeCUxkEpOZwlSmMZ0ZzGQWs5nDXOYxnwUsZBGL
WcJSlrGcFaxkFatZw1rWsZ4NbGQTm9nCVraxnR3sZBe72cNe9rGfAxzkEIc5
wlGOcZwTnOQUpznDWc5xngtc5BKXucJVrnGdG9zkFre5w13ucZ8HPOQRj3nC
U57xnBe85BWvecNb3vGeD3zkE5/5wle+8Z1f+JXf+J0/+JO/+Jt/+Jcf/Cx/
AMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEISkZgkJCUZ
yUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpRmCIUpRjF
KUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGYJjSlGYE0
pwUtaUVr2tCWdrSnAx35Od5BdKYLXelGd3rQk170pg996Ud/BjCQQQxmCEMZ
xnBGMJJRjGYMYxnHeCYwkUlMZgpTmcZ0ZjCTWcxmDnOZx3wWsJBFLGYJS1nG
clawklWsZg1rWcd6NrCRTWxmC1vZxnZ2sJNd7GYPe9nHfg5wkEMc5ghHOcZx
TnCSU5zmDGc5x3kucJFLXOYKV7nGdW5wk1vc5g53ucd9HvCQRzzmCU95xnNe
8JJXvOYNb3nHez7wkU985gtf+Rbw/z//Dz189+A=
          "], {Null, CompressedData["
1:eJw13A2c1mO6wPH7tsdpl2O9LLLYQ3Ioas/uCqvVrqQihdKSUmmVzEwspdpK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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[196, 330] -> 
             RGBColor[
              0.3909415698940796, 0.5042582028077578, 0.9470301129289374], 
             UndirectedEdge[136, 319] -> 
             RGBColor[
              0.3375453839844029, 0.4625381516880479, 0.9428846270131543], 
             UndirectedEdge[60, 188] -> 
             RGBColor[
              0.27423285988609647`, 0.40556650148081624`, 0.9389285277281285],
              UndirectedEdge[145, 408] -> 
             RGBColor[
              0.6274173384779865, 0.6986636982144436, 0.9475469243701514], 
             UndirectedEdge[398, 460] -> 
             RGBColor[
              0.30114093131004993`, 0.43163324278099846`, 0.9405420173252479],
              UndirectedEdge[413, 476] -> 
             RGBColor[
              0.3799723472444321, 0.5035346820428231, 0.9454324798634293], 
             UndirectedEdge[244, 274] -> 
             RGBColor[
              0.4089688614655975, 0.527234243282787, 0.9476712913599071], 
             UndirectedEdge[198, 223] -> 
             RGBColor[
              0.6532315303750404, 0.719950398091225, 0.901210896833158], 
             UndirectedEdge[36, 310] -> 
             RGBColor[
              0.33830838000131275`, 0.4621151620501824, 0.9429729298115033], 
             UndirectedEdge[252, 432] -> 
             RGBColor[
              0.4762258739503551, 0.5849080561958212, 0.9521173340211261], 
             UndirectedEdge[469, 475] -> 
             RGBColor[
              0.31083313846031596`, 0.43993348150912437`, 0.9411630623057134],
              UndirectedEdge[113, 347] -> 
             RGBColor[
              0.3011049930699146, 0.4316092984169466, 0.9405394643480239], 
             UndirectedEdge[35, 131] -> 
             RGBColor[
              0.6308385104586852, 0.7010497912626874, 0.940807683970279], 
             UndirectedEdge[156, 479] -> 
             RGBColor[
              0.6650458066174456, 0.7358594756463275, 0.9690633227300549], 
             UndirectedEdge[318, 354] -> 
             RGBColor[
              0.5642121864862469, 0.6548155869847447, 0.9599300968383652], 
             UndirectedEdge[6, 77] -> 
             RGBColor[
              0.27768823589739944`, 0.4090823797306565, 0.9391295514489508], 
             UndirectedEdge[23, 202] -> 
             RGBColor[
              0.3330981454257409, 0.462439996804462, 0.9424638071794962], 
             UndirectedEdge[342, 395] -> 
             RGBColor[
              0.3444200124410411, 0.47274103654842986`, 0.9431671165274526], 
             UndirectedEdge[53, 418] -> 
             RGBColor[
              0.48317835846400137`, 0.5888674607725203, 0.9531302117845911], 
             UndirectedEdge[75, 149] -> 
             RGBColor[
              0.6674308293843131, 0.7287429527975455, 0.6909284181541425], 
             UndirectedEdge[293, 418] -> 
             RGBColor[
              0.40680288029807765`, 0.5267739412320891, 0.9471420977042988], 
             UndirectedEdge[282, 432] -> 
             RGBColor[
              0.39754109167741425`, 0.5130093827320782, 0.9472407639184923], 
             UndirectedEdge[466, 468] -> 
             RGBColor[
              0.3082359598326471, 0.43823625754678297`, 0.9409773491797763], 
             UndirectedEdge[105, 190] -> 
             RGBColor[
              0.4202947794968303, 0.5374004988508216, 0.9482945180487792], 
             UndirectedEdge[64, 473] -> 
             RGBColor[
              0.29417794761130056`, 0.4253926671510052, 0.9401060162454646], 
             UndirectedEdge[214, 273] -> 
             RGBColor[
              0.4610460456189836, 0.5714871913584664, 0.9512254809511769], 
             UndirectedEdge[30, 64] -> 
             RGBColor[
              0.6265987736344348, 0.6933605351359373, 0.9110229405202315], 
             UndirectedEdge[296, 395] -> 
             RGBColor[
              0.30719888451376515`, 0.43564273994545805`, 0.9409733392505821],
              UndirectedEdge[114, 203] -> 
             RGBColor[
              0.3662855209441834, 0.4916798410214397, 0.9445603673943628], 
             UndirectedEdge[81, 237] -> 
             RGBColor[
              0.24449319730941957`, 0.37430823050921425`, 0.9372348979402749],
              UndirectedEdge[382, 427] -> 
             RGBColor[
              0.4929882839803501, 0.5974660386003674, 0.9537271878465681], 
             UndirectedEdge[39, 450] -> 
             RGBColor[
              0.5761713144406806, 0.6668008551416895, 0.9597774629392894], 
             UndirectedEdge[50, 57] -> 
             RGBColor[
              0.31120899929088863`, 0.4432062033142921, 0.9410791014930586], 
             UndirectedEdge[74, 153] -> 
             RGBColor[
              0.4785992212033241, 0.586923782208115, 0.9522795993857993], 
             UndirectedEdge[239, 332] -> 
             RGBColor[
              0.5701315332878578, 0.6593518765979136, 0.9605573062342767], 
             UndirectedEdge[14, 72] -> 
             RGBColor[
              0.41562257319156515`, 0.5335670569967614, 0.9479378493394439], 
             UndirectedEdge[331, 403] -> 
             RGBColor[
              0.3176334413448191, 0.4494195878866385, 0.9414647034716928], 
             UndirectedEdge[214, 302] -> 
             RGBColor[
              0.43476704118148507`, 0.5487256385358728, 0.9495510060260308], 
             UndirectedEdge[128, 197] -> 
             RGBColor[
              0.5367835507382848, 0.627330584985897, 0.9593118195568637], 
             UndirectedEdge[191, 212] -> 
             RGBColor[
              0.34106790105253404`, 0.46983760614572234`, 0.9429535229539326],
              UndirectedEdge[404, 407] -> 
             RGBColor[
              0.41345101152972163`, 0.5292876146225709, 0.9481872353003005], 
             UndirectedEdge[60, 116] -> 
             RGBColor[
              0.5719623755150469, 0.6528386290587519, 0.9630916233944142], 
             UndirectedEdge[272, 357] -> 
             RGBColor[
              0.4950421725258904, 0.5977061368550443, 0.9543366465221066], 
             UndirectedEdge[228, 490] -> 
             RGBColor[
              0.7277030103353785, 0.7865377538763565, 0.9742142252979955], 
             UndirectedEdge[111, 415] -> 
             RGBColor[
              0.541349972164373, 0.6384206275673067, 0.9570667841900226], 
             UndirectedEdge[227, 428] -> 
             RGBColor[
              0.3335224116678295, 0.45968177574687474`, 0.9426052882068576], 
             UndirectedEdge[367, 499] -> 
             RGBColor[
              0.32679550276233177`, 0.4554009949228739, 0.9421200587884286], 
             UndirectedEdge[434, 495] -> 
             RGBColor[
              0.4285641608172358, 0.5352032077005752, 0.9499553731267643], 
             UndirectedEdge[226, 283] -> 
             RGBColor[
              0.34291957564555403`, 0.467577356434953, 0.9432129928156685], 
             UndirectedEdge[9, 34] -> 
             RGBColor[
              0.27784526678685706`, 0.4093633701733419, 0.9391342489570497], 
             UndirectedEdge[127, 386] -> 
             RGBColor[
              0.3973121986454601, 0.5132742804466217, 0.9471817169742404], 
             UndirectedEdge[326, 469] -> 
             RGBColor[
              0.34871365307993185`, 0.47274367934261163`, 0.9435767752008515],
              UndirectedEdge[192, 483] -> 
             RGBColor[
              0.4136936564753471, 0.5317817946853001, 0.947846585894853], 
             UndirectedEdge[16, 39] -> 
             RGBColor[
              0.4607707551999842, 0.5674473709269019, 0.9519357710301706], 
             UndirectedEdge[209, 421] -> 
             RGBColor[
              0.6808777832483145, 0.7439160515707604, 0.9037024059899671], 
             UndirectedEdge[293, 317] -> 
             RGBColor[
              0.369510042211686, 0.49264342760046287`, 0.944832811831974], 
             UndirectedEdge[3, 381] -> 
             RGBColor[
              0.33952968804551115`, 0.46215914282477594`, 0.9430878726733483],
              UndirectedEdge[211, 497] -> 
             RGBColor[
              0.3361740404538647, 0.4655987900677405, 0.9426416904840564], 
             UndirectedEdge[196, 479] -> 
             RGBColor[
              0.5003117489026729, 0.6052146424034524, 0.9538055200573927], 
             UndirectedEdge[221, 439] -> 
             RGBColor[
              0.36427723848095306`, 0.4899403676910012, 0.9444324014116603], 
             UndirectedEdge[379, 390] -> 
             RGBColor[
              0.5272155709553981, 0.6261070160164126, 0.9561857987909503], 
             UndirectedEdge[119, 320] -> 
             RGBColor[
              0.6785213155738008, 0.7444179982324559, 0.95559355484343], 
             UndirectedEdge[179, 401] -> 
             RGBColor[
              0.4107014169132205, 0.5291899934948288, 0.9476559433928113], 
             UndirectedEdge[59, 342] -> 
             RGBColor[
              0.6344412907017315, 0.7071332322385013, 0.9658488038407635], 
             UndirectedEdge[86, 98] -> 
             RGBColor[
              0.40465622727848166`, 0.524914618280433, 0.9470053148721009], 
             UndirectedEdge[328, 431] -> 
             RGBColor[
              0.3012079728213124, 0.4275647605364449, 0.9406973823694628], 
             UndirectedEdge[270, 375] -> 
             RGBColor[
              0.6232119467538014, 0.6900280135694614, 0.9167576094197842], 
             UndirectedEdge[39, 45] -> 
             RGBColor[
              0.43637847701152616`, 0.5418095399910703, 0.9505466668724796], 
             UndirectedEdge[59, 463] -> 
             RGBColor[0.679848178667379, 0.7464623963777977, 0.9687420905902],
              UndirectedEdge[2, 55] -> 
             RGBColor[
              0.4592065728727362, 0.5566708935376079, 0.9531716785074327], 
             UndirectedEdge[193, 496] -> 
             RGBColor[
              0.3659185199820091, 0.49136196323400905`, 0.9445369824175793], 
             UndirectedEdge[201, 246] -> 
             RGBColor[
              0.6440466812479992, 0.7118569099767826, 0.9161252648810104], 
             UndirectedEdge[69, 487] -> 
             RGBColor[
              0.5330881413457693, 0.6168177605656924, 0.9601448064836962], 
             UndirectedEdge[15, 408] -> 
             RGBColor[
              0.46575616261137465`, 0.5717354208047798, 0.9523063331422184], 
             UndirectedEdge[118, 310] -> 
             RGBColor[
              0.3555584740205978, 0.4802461045835821, 0.9439552971466743], 
             UndirectedEdge[289, 297] -> 
             RGBColor[
              0.30368718046925003`, 0.43301401299308834`, 0.9407344570160809],
              UndirectedEdge[397, 419] -> 
             RGBColor[
              0.309795002088862, 0.4423386744659344, 0.9409759238366602], 
             UndirectedEdge[13, 380] -> 
             RGBColor[
              0.3423369995537029, 0.4682130345465898, 0.9431341204832734], 
             UndirectedEdge[155, 262] -> 
             RGBColor[
              0.6760796820582234, 0.6282343899010582, 0.6000925542959078], 
             UndirectedEdge[182, 324] -> 
             RGBColor[
              0.6480149761047262, 0.7183525219394613, 0.958868414073748], 
             UndirectedEdge[177, 245] -> 
             RGBColor[
              0.2876234146213934, 0.4196408235178201, 0.9396911000107532], 
             UndirectedEdge[113, 325] -> 
             RGBColor[
              0.5716148738305684, 0.6513915484974087, 0.9632357241323258], 
             UndirectedEdge[94, 368] -> 
             RGBColor[
              0.42427200226171174`, 0.5316292365091491, 0.9496256167467237], 
             UndirectedEdge[50, 140] -> 
             RGBColor[
              0.3526312313632107, 0.4790840587934183, 0.9437184894924654], 
             UndirectedEdge[389, 458] -> 
             RGBColor[
              0.6543771573972926, 0.7210496755997268, 0.9052164476279259], 
             UndirectedEdge[429, 499] -> 
             RGBColor[
              0.3828101309613807, 0.5059926276672873, 0.9456133009325197], 
             UndirectedEdge[97, 358] -> 
             RGBColor[
              0.9733012840964939, 0.9787777573231669, 0.8928658492642889], 
             UndirectedEdge[274, 363] -> 
             RGBColor[
              0.45189817497095836`, 0.5644174569510961, 0.9504067092555674], 
             UndirectedEdge[255, 274] -> 
             RGBColor[
              0.7265154044752805, 0.7849065811784965, 0.9639214585406182], 
             UndirectedEdge[289, 381] -> 
             RGBColor[
              0.3928355778667233, 0.5146761658830821, 0.9462521135441735], 
             UndirectedEdge[55, 230] -> 
             RGBColor[
              0.4831627345426124, 0.5818503383610256, 0.9545359464745669], 
             UndirectedEdge[289, 349] -> 
             RGBColor[
              0.32727845366621655`, 0.4578099368962125, 0.9420779451244871], 
             UndirectedEdge[29, 318] -> 
             RGBColor[
              0.8017805501766577, 0.8456153210863011, 0.9807346176907998], 
             UndirectedEdge[69, 402] -> 
             RGBColor[
              0.3783432047187423, 0.4939599125719259, 0.9460447289732175], 
             UndirectedEdge[6, 413] -> 
             RGBColor[
              0.3630044633097531, 0.488837953809248, 0.9443513013032222], 
             UndirectedEdge[29, 482] -> 
             RGBColor[
              0.6035258646925227, 0.6821954607359355, 0.9653439871061453], 
             UndirectedEdge[212, 456] -> 
             RGBColor[
              0.27400890388502325`, 0.3999380550076034, 0.9391132399095585], 
             UndirectedEdge[354, 482] -> 
             RGBColor[
              0.36595750100211194`, 0.49139572663437914`, 0.9445394662537107],
              UndirectedEdge[106, 247] -> 
             RGBColor[
              0.34039866126047386`, 0.4672521889577775, 0.9429843201137599], 
             UndirectedEdge[305, 382] -> 
             RGBColor[
              0.4413040155089769, 0.5555064211055456, 0.949658412906788], 
             UndirectedEdge[279, 285] -> 
             RGBColor[
              0.4248483362027642, 0.5349607219867032, 0.9494103259454554], 
             UndirectedEdge[27, 319] -> 
             RGBColor[
              0.3372521812636796, 0.4622299770384415, 0.9428679295519637], 
             UndirectedEdge[118, 483] -> 
             RGBColor[
              0.38713437680154295`, 0.5066349739903585, 0.9462326997762145], 
             UndirectedEdge[342, 447] -> 
             RGBColor[
              0.4048466503019128, 0.5243805499972741, 0.947210585107683], 
             UndirectedEdge[207, 458] -> 
             RGBColor[
              0.6255557522065843, 0.6998161278388395, 0.9674200669719166], 
             UndirectedEdge[462, 487] -> 
             RGBColor[
              0.8011745868159161, 0.8446588757972048, 0.9808024107562356], 
             UndirectedEdge[64, 384] -> 
             RGBColor[
              0.5846495622697845, 0.6614876560574878, 0.9645240382815183], 
             UndirectedEdge[203, 221] -> 
             RGBColor[
              0.37460370832173484`, 0.4988846368436209, 0.945090394938576], 
             UndirectedEdge[139, 370] -> 
             RGBColor[
              0.5024960384745965, 0.5968693416121483, 0.9564762587377575], 
             UndirectedEdge[46, 357] -> 
             RGBColor[
              0.5421857269386052, 0.6385395141833967, 0.9573405921218765], 
             UndirectedEdge[18, 326] -> 
             RGBColor[
              0.3652585356664778, 0.49013339994721516`, 0.9445189817881949], 
             UndirectedEdge[73, 93] -> 
             RGBColor[
              0.3159502163431185, 0.4472394994801647, 0.9413838918067577], 
             UndirectedEdge[104, 112] -> 
             RGBColor[
              0.45622342081603523`, 0.5640247192422079, 0.951553294945509], 
             UndirectedEdge[40, 314] -> 
             RGBColor[
              0.344555995127932, 0.47037147428744464`, 0.943266855058853], 
             UndirectedEdge[264, 398] -> 
             RGBColor[
              0.3649917516058699, 0.4905592430473303, 0.9444779295561607], 
             UndirectedEdge[345, 489] -> 
             RGBColor[
              0.42607772370000624`, 0.5416636804516175, 0.9488690451422275], 
             UndirectedEdge[80, 417] -> 
             RGBColor[
              0.3900518620734212, 0.5081399597407098, 0.9465409815267327], 
             UndirectedEdge[271, 442] -> 
             RGBColor[
              0.6418113017924578, 0.7115084163302816, 0.937007728568517], 
             UndirectedEdge[318, 482] -> 
             RGBColor[
              0.5186368692450607, 0.6153405378724783, 0.9570260779244274], 
             UndirectedEdge[235, 260] -> 
             RGBColor[
              0.30101538824273194`, 0.4337166368940162, 0.9404537530968389], 
             UndirectedEdge[79, 278] -> 
             RGBColor[
              0.34278001180732776`, 0.46863219980954407`, 0.9431610508226329],
              UndirectedEdge[137, 404] -> 
             RGBColor[
              0.4528525660176313, 0.5645624564053866, 0.9506558630578674], 
             UndirectedEdge[380, 478] -> 
             RGBColor[
              0.29585449851451273`, 0.42795222842487585`, 0.940172296619918], 
             UndirectedEdge[247, 370] -> 
             RGBColor[
              0.2780081891558688, 0.4095346119130481, 0.9391435271449429], 
             UndirectedEdge[251, 429] -> 
             RGBColor[
              0.3702334401100767, 0.49509933017474966`, 0.9448119253126057], 
             UndirectedEdge[286, 407] -> 
             RGBColor[
              0.3318804823528336, 0.4607327301760333, 0.9424101132114793], 
             UndirectedEdge[206, 410] -> 
             RGBColor[
              0.2780083817409559, 0.4095348143321852, 0.9391435381123787], 
             UndirectedEdge[86, 500] -> 
             RGBColor[
              0.38893420090354647`, 0.511296989246486, 0.9460035212539322], 
             UndirectedEdge[78, 407] -> 
             RGBColor[
              0.29418196446965694`, 0.426534275244423, 0.9400645997221067], 
             UndirectedEdge[363, 370] -> 
             RGBColor[
              0.33365063362045444`, 0.45973505595472874`, 0.9426155739759527],
              UndirectedEdge[447, 453] -> 
             RGBColor[
              0.7362223408363235, 0.7881090112704796, 0.7366419559295845], 
             UndirectedEdge[256, 492] -> 
             RGBColor[
              0.41953022022946707`, 0.5359932495597168, 0.9484516540450045], 
             UndirectedEdge[114, 349] -> 
             RGBColor[
              0.3169710092770939, 0.44888214663357295`, 0.9414211638825274], 
             UndirectedEdge[22, 160] -> 
             RGBColor[
              0.48291069172220835`, 0.589763125001314, 0.9528016236627901], 
             UndirectedEdge[149, 324] -> 
             RGBColor[
              0.969905355118667, 0.973383971169038, 0.7065583223863454], 
             UndirectedEdge[94, 315] -> 
             RGBColor[
              0.5207491703502783, 0.6213207552727182, 0.9555486861680158], 
             UndirectedEdge[246, 492] -> 
             RGBColor[
              0.652340185140871, 0.7195995007630781, 0.9166332454956572], 
             UndirectedEdge[193, 202] -> 
             RGBColor[
              0.387213855409118, 0.5098069124462908, 0.9458939023602688], 
             UndirectedEdge[321, 335] -> 
             RGBColor[
              0.4623200370379546, 0.5730114437670781, 0.9511903943881244], 
             UndirectedEdge[321, 496] -> 
             RGBColor[
              0.3617231335818693, 0.4877281304004597, 0.9442696561059969], 
             UndirectedEdge[18, 474] -> 
             RGBColor[
              0.26942010489881163`, 0.40050799084288935`, 0.9386544484514356],
              UndirectedEdge[184, 192] -> 
             RGBColor[
              0.3670552762132072, 0.49234656434644347`, 0.9446094155194371], 
             UndirectedEdge[170, 171] -> 
             RGBColor[
              0.3665002204510787, 0.48947991409634295`, 0.9446614069353397], 
             UndirectedEdge[80, 156] -> 
             RGBColor[
              0.5749219009080455, 0.6551320895722926, 0.9633839623936788], 
             UndirectedEdge[353, 418] -> 
             RGBColor[
              0.3741804792280217, 0.4985180570747593, 0.9450634271549715], 
             UndirectedEdge[201, 312] -> 
             RGBColor[
              0.3248098268615882, 0.45519650487817787`, 0.9419380469626857], 
             UndirectedEdge[152, 212] -> 
             RGBColor[
              0.37913919244695393`, 0.5028130452328253, 0.9453793919764639], 
             UndirectedEdge[192, 260] -> 
             RGBColor[
              0.31840759052099665`, 0.4492282780199688, 0.9415455877192771], 
             UndirectedEdge[90, 357] -> 
             RGBColor[
              0.4995394249831081, 0.6016014308950053, 0.9546232074719163], 
             UndirectedEdge[57, 369] -> 
             RGBColor[
              0.35468820655146405`, 0.48163483019243614`, 0.9438213967763611],
              UndirectedEdge[83, 448] -> 
             RGBColor[
              0.4751153735930713, 0.582865619736773, 0.9523451405277006], 
             UndirectedEdge[67, 180] -> 
             RGBColor[
              0.6435308081757964, 0.7206932794744353, 0.9656224597284939], 
             UndirectedEdge[373, 472] -> 
             RGBColor[
              0.517115082421003, 0.6188563455351812, 0.9551283400245945], 
             UndirectedEdge[353, 432] -> 
             RGBColor[
              0.4558330277747183, 0.567244797812736, 0.9508179198955004], 
             UndirectedEdge[1, 433] -> 
             RGBColor[
              0.3786903513261278, 0.5024242816133764, 0.9453507922171396], 
             UndirectedEdge[300, 301] -> 
             RGBColor[
              0.2438657876108875, 0.3736487831359845, 0.9371991678861129], 
             UndirectedEdge[212, 389] -> 
             RGBColor[
              0.676929974171858, 0.740583791952325, 0.9066534931701284], 
             UndirectedEdge[97, 174] -> 
             RGBColor[
              0.6426152699592951, 0.7130602862944986, 0.9495446730871335], 
             UndirectedEdge[200, 471] -> 
             RGBColor[
              0.3983537095954314, 0.5194556942371242, 0.9466037240184345], 
             UndirectedEdge[155, 387] -> 
             RGBColor[
              0.5023521890200746, 0.6064088355418074, 0.9540938936009871], 
             UndirectedEdge[156, 354] -> 
             RGBColor[
              0.6415117636763232, 0.7156189137390331, 0.96752412053154], 
             UndirectedEdge[314, 472] -> 
             RGBColor[
              0.4844828493391977, 0.5911136834578773, 0.9529048852036874], 
             UndirectedEdge[117, 269] -> 
             RGBColor[
              0.40069897103827934`, 0.5188904945413051, 0.9471873930872428], 
             UndirectedEdge[336, 409] -> 
             RGBColor[
              0.35141197557738457`, 0.4787971235908452, 0.9436126382357501], 
             UndirectedEdge[63, 252] -> 
             RGBColor[
              0.35313921834377116`, 0.47769806556345623`, 0.9438177162666903],
              UndirectedEdge[201, 444] -> 
             RGBColor[
              0.3470137524495589, 0.4744284292207288, 0.9433528614669906], 
             UndirectedEdge[201, 442] -> 
             RGBColor[
              0.6371619179154364, 0.7069221791429181, 0.9367319480589114], 
             UndirectedEdge[25, 333] -> 
             RGBColor[
              0.6215114791777864, 0.3386360525248429, 0.5562822288422777], 
             UndirectedEdge[203, 397] -> 
             RGBColor[
              0.3553789282373947, 0.481821180181048, 0.9438804913025616], 
             UndirectedEdge[7, 436] -> 
             RGBColor[
              0.31437972266567726`, 0.444509865090992, 0.9413339600120758], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.46587491466995506`, 0.5718602367476633, 0.9523130958962764], 
             UndirectedEdge[274, 369] -> 
             RGBColor[
              0.44642255838533196`, 0.5596747530771183, 0.9500578078086288], 
             UndirectedEdge[38, 364] -> 
             RGBColor[
              0.38824122235628583`, 0.5106967660589634, 0.9459593652736775], 
             UndirectedEdge[215, 356] -> 
             RGBColor[
              0.278551253504396, 0.4101054069756186, 0.9391744538561998], 
             UndirectedEdge[16, 283] -> 
             RGBColor[
              0.3565398550619287, 0.4818931336771555, 0.9439886475790333], 
             UndirectedEdge[236, 276] -> 
             RGBColor[
              0.6901244011102821, 0.7520844261194248, 0.9101510730654188], 
             UndirectedEdge[39, 454] -> 
             RGBColor[
              0.5064215346094953, 0.6083332829650174, 0.9547953329298114], 
             UndirectedEdge[179, 315] -> 
             RGBColor[
              0.46206047985198617`, 0.5736746324308273, 0.9509284974682333], 
             UndirectedEdge[149, 182] -> 
             RGBColor[
              0.6707362195691415, 0.7316059156419027, 0.6911390346938779], 
             UndirectedEdge[97, 407] -> 
             RGBColor[
              0.6268734797230271, 0.698278343132127, 0.9485836245861732], 
             UndirectedEdge[274, 379] -> 
             RGBColor[
              0.46190659237678294`, 0.5730862450703361, 0.9510444367625704], 
             UndirectedEdge[39, 325] -> 
             RGBColor[
              0.7504626700078774, 0.8051896361705033, 0.9758050276650219], 
             UndirectedEdge[127, 347] -> 
             RGBColor[
              0.42759110484982765`, 0.5428978118292347, 0.9489866642777871], 
             UndirectedEdge[327, 483] -> 
             RGBColor[
              0.3953482577377656, 0.5152682836444593, 0.9467004681441844], 
             UndirectedEdge[269, 360] -> 
             RGBColor[
              0.45626929023930063`, 0.5682042587117906, 0.9506850224743122], 
             UndirectedEdge[54, 147] -> 
             RGBColor[
              0.30634086270906946`, 0.43544163315460066`, 0.940898819074135], 
             UndirectedEdge[276, 422] -> 
             RGBColor[
              0.4823369028035926, 0.5890053858184805, 0.9528371089116425], 
             UndirectedEdge[181, 424] -> 
             RGBColor[
              0.31554582493427585`, 0.4465357661764743, 0.941371066604326], 
             UndirectedEdge[336, 456] -> 
             RGBColor[
              0.25547659542471446`, 0.3838863008801906, 0.9379323776019446], 
             UndirectedEdge[46, 298] -> 
             RGBColor[
              0.36361037596229234`, 0.48797750718158356`, 0.9444406305923888],
              UndirectedEdge[107, 132] -> 
             RGBColor[
              0.43222335478481533`, 0.5462914453434405, 0.949452745008568], 
             UndirectedEdge[78, 95] -> 
             RGBColor[
              0.6357864444562655, 0.7042674265931219, 0.9297237464694215], 
             UndirectedEdge[296, 332] -> 
             RGBColor[
              0.3328256570450433, 0.45783936227301236`, 0.9426062545354099], 
             UndirectedEdge[397, 472] -> 
             RGBColor[
              0.4329938504621051, 0.5461045821238103, 0.9496391340763272], 
             UndirectedEdge[19, 269] -> 
             RGBColor[
              0.46340875051639474`, 0.5743881003641021, 0.9511399425699918], 
             UndirectedEdge[185, 335] -> 
             RGBColor[
              0.40382753435356683`, 0.5202684572159431, 0.9475394526005261], 
             UndirectedEdge[112, 351] -> 
             RGBColor[
              0.4531633118073823, 0.5615403848926436, 0.9513123919547992], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.28168222466879256`, 0.4111811468464766, 0.9394338640359994], 
             UndirectedEdge[251, 305] -> 
             RGBColor[
              0.418913112949334, 0.536112546707868, 0.9482316843951852], 
             UndirectedEdge[131, 170] -> 
             RGBColor[
              0.7083076117958627, 0.7694092951659646, 0.9456978242065295], 
             UndirectedEdge[76, 333] -> 
             RGBColor[
              0.5778772586143013, 0.3008422837924454, 0.5535018948921986], 
             UndirectedEdge[114, 115] -> 
             RGBColor[
              0.30511184829014265`, 0.4364174165220521, 0.940745802208377], 
             UndirectedEdge[87, 421] -> 
             RGBColor[
              0.4524119539585507, 0.5641897028571343, 0.9506253333937351], 
             UndirectedEdge[60, 192] -> 
             RGBColor[
              0.3087839728862837, 0.43911324571328547`, 0.9409975369318467], 
             UndirectedEdge[84, 147] -> 
             RGBColor[
              0.3252422892905754, 0.45530823091142614`, 0.941975227355797], 
             UndirectedEdge[431, 433] -> 
             RGBColor[
              0.3781820028454647, 0.5019839757097635, 0.9453184007014666], 
             UndirectedEdge[201, 492] -> 
             RGBColor[
              0.3109915511086083, 0.4432278089476803, 0.9410575586507273], 
             UndirectedEdge[86, 124] -> 
             RGBColor[
              0.3557817306122228, 0.48258198577174793`, 0.9438910751625473], 
             UndirectedEdge[234, 239] -> 
             RGBColor[
              0.5292986786145881, 0.6239845101988771, 0.9579554728415716], 
             UndirectedEdge[100, 450] -> 
             RGBColor[
              0.4261968425141941, 0.5416258351475729, 0.9489155995432458], 
             UndirectedEdge[22, 275] -> 
             RGBColor[
              0.5778793241727047, 0.6681874943871083, 0.9599119237220402], 
             UndirectedEdge[160, 324] -> 
             RGBColor[
              0.675859878979082, 0.7424703772837167, 0.9606426666626212], 
             UndirectedEdge[191, 218] -> 
             RGBColor[
              0.3064504318221118, 0.4388455056266838, 0.9407846431488385], 
             UndirectedEdge[349, 397] -> 
             RGBColor[
              0.3060644165703052, 0.4390234857931813, 0.9407412877907261], 
             UndirectedEdge[401, 454] -> 
             RGBColor[
              0.3590995575892352, 0.4854557207404035, 0.9441024841636834], 
             UndirectedEdge[311, 349] -> 
             RGBColor[
              0.3381863307253634, 0.4672577917590036, 0.9427729854052389], 
             UndirectedEdge[63, 324] -> 
             RGBColor[
              0.6139308907687727, 0.686235491439511, 0.9567916259447211], 
             UndirectedEdge[22, 353] -> 
             RGBColor[
              0.4730504057967398, 0.5812226409250538, 0.9521733349627277], 
             UndirectedEdge[93, 437] -> 
             RGBColor[
              0.3559703939886576, 0.48274539650591874`, 0.9439030966260653], 
             UndirectedEdge[417, 461] -> 
             RGBColor[
              0.4273165975916754, 0.5432268326072317, 0.9488125684874142], 
             UndirectedEdge[151, 249] -> 
             RGBColor[
              0.41433471011109035`, 0.5321774118258205, 0.9479315398690497], 
             UndirectedEdge[148, 452] -> 
             RGBColor[
              0.374665832060994, 0.49857380602294066`, 0.945107704638622], 
             UndirectedEdge[262, 424] -> 
             RGBColor[
              0.6058399312613632, 0.5662003477008856, 0.5956607272580676], 
             UndirectedEdge[50, 139] -> 
             RGBColor[
              0.5182275046404602, 0.6134041099850349, 0.9573721424632848], 
             UndirectedEdge[237, 267] -> 
             RGBColor[
              0.25799062738744527`, 0.3884948853077141, 0.93800355661556], 
             UndirectedEdge[256, 442] -> 
             RGBColor[
              0.745700587036295, 0.7996876197549546, 0.9441260434531886], 
             UndirectedEdge[60, 133] -> 
             RGBColor[
              0.34854914222152356`, 0.47355583673594603`, 0.9435313383589297],
              UndirectedEdge[77, 156] -> 
             RGBColor[
              0.5584335896219583, 0.637801828991299, 0.9624449774582069], 
             UndirectedEdge[219, 498] -> 
             RGBColor[
              0.3360632251226524, 0.46034268154501906`, 0.9428235669141054], 
             UndirectedEdge[102, 185] -> 
             RGBColor[
              0.29041011393206395`, 0.4225698211802761, 0.9398497984139436], 
             UndirectedEdge[92, 169] -> 
             RGBColor[
              0.4509338874391724, 0.5573014013136256, 0.9513579895070066], 
             UndirectedEdge[53, 357] -> 
             RGBColor[
              0.6268623918700049, 0.7078231044703047, 0.9638576504824137], 
             UndirectedEdge[162, 289] -> 
             RGBColor[
              0.33167260255048114`, 0.4616998708046772, 0.9423548628413181], 
             UndirectedEdge[169, 204] -> 
             RGBColor[
              0.3636444243099394, 0.48637712670923217`, 0.9445024777005255], 
             UndirectedEdge[176, 448] -> 
             RGBColor[
              0.4673977005642639, 0.5761809592607451, 0.9518533772267752], 
             UndirectedEdge[377, 403] -> 
             RGBColor[
              0.34764552710264524`, 0.4755348152292307, 0.9433726434694794], 
             UndirectedEdge[86, 357] -> 
             RGBColor[
              0.5049797097541815, 0.606313532127046, 0.9549698576068743], 
             UndirectedEdge[12, 373] -> 
             RGBColor[
              0.5778410132358203, 0.6675315439183703, 0.9603361196831932], 
             UndirectedEdge[200, 469] -> 
             RGBColor[
              0.32882925034746896`, 0.455520809114893, 0.942309758641826], 
             UndirectedEdge[112, 153] -> 
             RGBColor[
              0.41238256994446704`, 0.5284327414968442, 0.9481019825705709], 
             UndirectedEdge[166, 243] -> 
             RGBColor[
              0.3205168560760495, 0.45199880671334813`, 0.941645438843954], 
             UndirectedEdge[394, 460] -> 
             RGBColor[
              0.3360923419013654, 0.461906397926221, 0.9427690903018078], 
             UndirectedEdge[18, 348] -> 
             RGBColor[
              0.46880513363883325`, 0.5748608449730328, 0.9524871802397561], 
             UndirectedEdge[315, 325] -> 
             RGBColor[
              0.6544997559263828, 0.726796712881888, 0.9683847329743158], 
             UndirectedEdge[195, 447] -> 
             RGBColor[
              0.7327135071811242, 0.7882963180770227, 0.9138795032863058], 
             UndirectedEdge[128, 204] -> 
             RGBColor[
              0.6142578812967956, 0.6955944205575073, 0.964205961720185], 
             UndirectedEdge[91, 435] -> 
             RGBColor[
              0.6268091408943142, 0.6893261104021484, 0.706785796809851], 
             UndirectedEdge[158, 206] -> 
             RGBColor[
              0.447495866268662, 0.5523621276494035, 0.9512828723311261], 
             UndirectedEdge[30, 290] -> 
             RGBColor[
              0.619412134560614, 0.6858069218101166, 0.9106136720566571], 
             UndirectedEdge[2, 250] -> 
             RGBColor[
              0.24968648292629247`, 0.37976670296587367`, 0.9375306478733781],
              UndirectedEdge[148, 195] -> 
             RGBColor[
              0.6455836894139857, 0.7131632130530201, 0.9081478829254572], 
             UndirectedEdge[5, 202] -> 
             RGBColor[
              0.3325060913088599, 0.46181771038922104`, 0.9424300905734053], 
             UndirectedEdge[220, 359] -> 
             RGBColor[
              0.36332965210996776`, 0.48781600515558976`, 0.9444197536250574],
              UndirectedEdge[175, 337] -> 
             RGBColor[
              0.3152816757053011, 0.44542185880904034`, 0.9413866436297151], 
             UndirectedEdge[263, 447] -> 
             RGBColor[
              0.5073391318501372, 0.6109197884601978, 0.9543587413851691], 
             UndirectedEdge[344, 387] -> 
             RGBColor[
              0.6674447397423183, 0.7389994208040271, 0.9682627792826257], 
             UndirectedEdge[82, 470] -> 
             RGBColor[
              0.37684902911561435`, 0.5008294208621749, 0.9452334647941029], 
             UndirectedEdge[273, 446] -> 
             RGBColor[
              0.4583328910980822, 0.5692845302921803, 0.9510118914886792], 
             UndirectedEdge[68, 306] -> 
             RGBColor[
              0.43906184297440454`, 0.5532483830178123, 0.9496028501288569], 
             UndirectedEdge[21, 33] -> 
             RGBColor[
              0.6480262427228414, 0.7124809692865914, 0.7934306583404654], 
             UndirectedEdge[77, 479] -> 
             RGBColor[
              0.3519886871300557, 0.47329425290620597`, 0.9439035442928301], 
             UndirectedEdge[253, 311] -> 
             RGBColor[
              0.32834625073164264`, 0.4569152437884969, 0.9422126074066903], 
             UndirectedEdge[308, 386] -> 
             RGBColor[
              0.35856145558691244`, 0.4815921791413188, 0.9441925946051304], 
             UndirectedEdge[151, 280] -> 
             RGBColor[
              0.4881134682640904, 0.5920743313896041, 0.95373967397135], 
             UndirectedEdge[305, 416] -> 
             RGBColor[
              0.36666168744596983`, 0.48427956045658016`, 0.9451430283853443],
              UndirectedEdge[38, 189] -> 
             RGBColor[
              0.3520104730929094, 0.47931551205743306`, 0.9436507739682087], 
             UndirectedEdge[277, 291] -> 
             RGBColor[
              0.34823030169727315`, 0.47505921150781233`, 0.9434458645042415],
              UndirectedEdge[27, 40] -> 
             RGBColor[
              0.27202622574763735`, 0.4032471890926106, 0.9388028631783659], 
             UndirectedEdge[88, 167] -> 
             RGBColor[
              0.36513515296865506`, 0.49068345010021275`, 0.9444870669641926],
              UndirectedEdge[89, 296] -> 
             RGBColor[
              0.37224664805517843`, 0.4910338914011055, 0.9453805997721259], 
             UndirectedEdge[169, 340] -> 
             RGBColor[
              0.31656728292503766`, 0.44560127300755564`, 0.9415027638801612],
              UndirectedEdge[169, 363] -> 
             RGBColor[
              0.3372358569763514, 0.46350335301806633`, 0.9428197471422084], 
             UndirectedEdge[43, 378] -> 
             RGBColor[
              0.3161162327714191, 0.44601394286504986`, 0.9414446089004782], 
             UndirectedEdge[350, 482] -> 
             RGBColor[
              0.4198827019235625, 0.5363091996961687, 0.9484711717349168], 
             UndirectedEdge[199, 429] -> 
             RGBColor[
              0.28863196181625994`, 0.41241757753986863`, 0.9400518272158606],
              UndirectedEdge[135, 216] -> 
             RGBColor[
              0.6374506935525226, 0.7141261223139587, 0.9662589660302847], 
             UndirectedEdge[153, 351] -> 
             RGBColor[
              0.5691029804520141, 0.6610624631848727, 0.959221017795541], 
             UndirectedEdge[207, 218] -> 
             RGBColor[
              0.6134910997507274, 0.6883581436723993, 0.9666882327090249], 
             UndirectedEdge[218, 389] -> 
             RGBColor[
              0.6423125049414357, 0.7095916914332865, 0.9044846133650343], 
             UndirectedEdge[421, 477] -> 
             RGBColor[
              0.3232559970276413, 0.4510054660374656, 0.941943214626094], 
             UndirectedEdge[171, 391] -> 
             RGBColor[
              0.34406463572305035`, 0.47004733825020095`, 0.9432318313154784],
              UndirectedEdge[25, 246] -> 
             RGBColor[
              0.7055496368179173, 0.7656868534209331, 0.9200237047052479], 
             UndirectedEdge[130, 254] -> 
             RGBColor[
              0.8358147815888839, 0.8304256620288168, 0.6424138244816251], 
             UndirectedEdge[65, 434] -> 
             RGBColor[
              0.49936133980555053`, 0.602582902494327, 0.9542446667375003], 
             UndirectedEdge[174, 430] -> 
             RGBColor[
              0.4140699775357322, 0.5317921677993519, 0.9479577596811245], 
             UndirectedEdge[213, 454] -> 
             RGBColor[
              0.3234224534037482, 0.4501719315203612, 0.9419896198560217], 
             UndirectedEdge[52, 495] -> 
             RGBColor[
              0.24418937466483973`, 0.37398889364629256`, 0.9372175956901314],
              UndirectedEdge[26, 224] -> 
             RGBColor[
              0.6446770138350606, 0.7175431879343095, 0.9681020585031037], 
             UndirectedEdge[8, 31] -> 
             RGBColor[
              0.26377361980797775`, 0.3945731770045906, 0.9383328894787387], 
             UndirectedEdge[29, 321] -> 
             RGBColor[
              0.6449532935971007, 0.7180778174499615, 0.967983706243108], 
             UndirectedEdge[319, 377] -> 
             RGBColor[
              0.3898822671383849, 0.5121181565679087, 0.9460639311960739], 
             UndirectedEdge[323, 447] -> 
             RGBColor[
              0.39279363475153894`, 0.5137355352529173, 0.9464500945977914], 
             UndirectedEdge[13, 340] -> 
             RGBColor[
              0.38119400979110823`, 0.504592824738209, 0.9455103231206298], 
             UndirectedEdge[176, 237] -> 
             RGBColor[
              0.3079362887176785, 0.4354988579657204, 0.94104898024426], 
             UndirectedEdge[22, 268] -> 
             RGBColor[
              0.4402853960709923, 0.5528432363178835, 0.9500855775159636], 
             UndirectedEdge[461, 493] -> 
             RGBColor[
              0.44762922341486727`, 0.5597175373238641, 0.950411652799816], 
             UndirectedEdge[401, 450] -> 
             RGBColor[
              0.42884933742042036`, 0.5439232929170756, 0.9490846141731614], 
             UndirectedEdge[100, 200] -> 
             RGBColor[
              0.35825335863102215`, 0.48472278573399563`, 0.9440485651143304],
              UndirectedEdge[197, 375] -> 
             RGBColor[
              0.278726362482399, 0.4102894576140501, 0.9391844260534465], 
             UndirectedEdge[94, 401] -> 
             RGBColor[
              0.4693901074115127, 0.5768361163367197, 0.9522761320925939], 
             UndirectedEdge[118, 327] -> 
             RGBColor[
              0.29378682286858115`, 0.4261189563682678, 0.9400420969924851], 
             UndirectedEdge[44, 255] -> 
             RGBColor[
              0.6107390079320196, 0.6828215100541717, 0.9562710513020449], 
             UndirectedEdge[148, 356] -> 
             RGBColor[
              0.28693616762291857`, 0.4189184833484466, 0.9396519623108808], 
             UndirectedEdge[26, 34] -> 
             RGBColor[
              0.3369006060204625, 0.4635430460133685, 0.9427862997490092], 
             UndirectedEdge[244, 313] -> 
             RGBColor[
              0.30074827235637036`, 0.4330908048374925, 0.9404511761768867], 
             UndirectedEdge[331, 488] -> 
             RGBColor[
              0.3606507413914649, 0.4866790110746765, 0.9442057277919602], 
             UndirectedEdge[382, 429] -> 
             RGBColor[
              0.39262434266971963`, 0.5144932045724273, 0.9462386538242085], 
             UndirectedEdge[409, 496] -> 
             RGBColor[
              0.3465106401032022, 0.47455183315139227`, 0.943300329473416], 
             UndirectedEdge[14, 324] -> 
             RGBColor[
              0.7158309061822735, 0.7762452131158672, 0.9634233537739373], 
             UndirectedEdge[259, 471] -> 
             RGBColor[
              0.3822998981840659, 0.5055506896806222, 0.9455807893511303], 
             UndirectedEdge[178, 439] -> 
             RGBColor[
              0.3256059828022444, 0.45243743220098087`, 0.9421150497590289], 
             UndirectedEdge[127, 454] -> 
             RGBColor[
              0.4540598502120995, 0.5658237087042108, 0.9506732293268785], 
             UndirectedEdge[190, 452] -> 
             RGBColor[
              0.46843309156351653`, 0.5790954852610706, 0.9513618487266304], 
             UndirectedEdge[218, 295] -> 
             RGBColor[
              0.30463226628515794`, 0.4372707020222313, 0.9406687912485645], 
             UndirectedEdge[35, 67] -> 
             RGBColor[
              0.4440272489506498, 0.5539652865708072, 0.9506075525774577], 
             UndirectedEdge[192, 249] -> 
             RGBColor[
              0.41663320555029204`, 0.5341682530495171, 0.9480779979659559], 
             UndirectedEdge[186, 202] -> 
             RGBColor[
              0.4058129112860275, 0.5259164798311405, 0.9470790177542462], 
             UndirectedEdge[243, 469] -> 
             RGBColor[
              0.28844025288627007`, 0.42049937232474277`, 0.939737617741534], 
             UndirectedEdge[48, 183] -> 
             RGBColor[
              0.4668142587044891, 0.5759630607795048, 0.9517367776649479], 
             UndirectedEdge[255, 390] -> 
             RGBColor[
              0.7918243830538957, 0.8379273521245729, 0.969062820568998], 
             UndirectedEdge[202, 497] -> 
             RGBColor[
              0.33761407993130804`, 0.46684607988461335`, 0.9427334485261822],
              UndirectedEdge[84, 365] -> 
             RGBColor[
              0.2685272141549316, 0.3995695060585285, 0.938603599644485], 
             UndirectedEdge[239, 262] -> 
             RGBColor[
              0.8233348002119456, 0.7468902372712403, 0.6124835713994008], 
             UndirectedEdge[299, 456] -> 
             RGBColor[
              0.31695680199215537`, 0.43713736572387757`, 0.9418498419996099],
              UndirectedEdge[136, 253] -> 
             RGBColor[
              0.27547676879410565`, 0.40687392861151395`, 0.9389993665002413],
              UndirectedEdge[338, 478] -> 
             RGBColor[
              0.38612998448542224`, 0.5086911192078316, 0.945873744337501], 
             UndirectedEdge[284, 444] -> 
             RGBColor[
              0.37153842008572996`, 0.49622963823945987`, 0.9448950774827058],
              UndirectedEdge[135, 147] -> 
             RGBColor[
              0.41246403320240754`, 0.5311076755704378, 0.9476602233686703], 
             UndirectedEdge[72, 73] -> 
             RGBColor[
              0.32320091771925485`, 0.45351969258132663`, 0.9418459000869017],
              UndirectedEdge[8, 291] -> 
             RGBColor[
              0.34301180857005975`, 0.46957424435953654`, 0.9431486790407155],
              UndirectedEdge[141, 240] -> 
             RGBColor[
              0.6876236721532911, 0.7499916648945408, 0.9126838485697075], 
             UndirectedEdge[9, 466] -> 
             RGBColor[
              0.3089663660576176, 0.4390039607996564, 0.9410189447337491], 
             UndirectedEdge[78, 346] -> 
             RGBColor[
              0.568362077374081, 0.6516357870516696, 0.962495542615234], 
             UndirectedEdge[255, 425] -> 
             RGBColor[
              0.6338555187710683, 0.7060650073740069, 0.9576260733085495], 
             UndirectedEdge[297, 349] -> 
             RGBColor[
              0.28424681119600387`, 0.4160917992287133, 0.9394988074409143], 
             UndirectedEdge[248, 478] -> 
             RGBColor[
              0.29767291174866123`, 0.4298634960280241, 0.9402758525635014], 
             UndirectedEdge[113, 130] -> 
             RGBColor[
              0.6166528755764088, 0.6449039400040834, 0.6259836021288571], 
             UndirectedEdge[51, 179] -> 
             RGBColor[
              0.38716289602185405`, 0.5066646249475397, 0.9462343534463251], 
             UndirectedEdge[440, 470] -> 
             RGBColor[
              0.37431673072139987`, 0.4986360712701243, 0.945072108979647], 
             UndirectedEdge[5, 414] -> 
             RGBColor[
              0.30765187210455036`, 0.4402902349238277, 0.9408464017034299], 
             UndirectedEdge[148, 463] -> 
             RGBColor[
              0.36312372050042185`, 0.4885766091125679, 0.9443722514962709], 
             UndirectedEdge[63, 441] -> 
             RGBColor[
              0.5152478362749404, 0.6084115975071163, 0.9574970296237788], 
             UndirectedEdge[163, 187] -> 
             RGBColor[
              0.6082220239976153, 0.6740790527346303, 0.9108540504114397], 
             UndirectedEdge[120, 177] -> 
             RGBColor[
              0.5458386134388508, 0.6308302167665994, 0.9607783796180016], 
             UndirectedEdge[450, 454] -> 
             RGBColor[
              0.4552445862877823, 0.5667855308222021, 0.9507664960905875], 
             UndirectedEdge[15, 190] -> 
             RGBColor[
              0.5638217801242545, 0.656774946843434, 0.9588052623600656], 
             UndirectedEdge[191, 287] -> 
             RGBColor[
              0.28021787938849874`, 0.41127342977906794`, 0.9392907380953279],
              UndirectedEdge[179, 292] -> 
             RGBColor[
              0.6359032928685773, 0.7131378700265187, 0.965953917764234], 
             UndirectedEdge[291, 297] -> 
             RGBColor[
              0.32949623081577867`, 0.4553685152026632, 0.9423789868821146], 
             UndirectedEdge[289, 397] -> 
             RGBColor[
              0.32550478584355136`, 0.45594569955755626`, 0.9419769373658927],
              UndirectedEdge[175, 370] -> 
             RGBColor[
              0.30664482916028357`, 0.4363439854825277, 0.9408947879960459], 
             UndirectedEdge[23, 186] -> 
             RGBColor[
              0.3761111602638936, 0.49969570836028415`, 0.9452045584500677], 
             UndirectedEdge[241, 461] -> 
             RGBColor[
              0.4794792349222017, 0.5855748114921854, 0.9529190023761098], 
             UndirectedEdge[157, 216] -> 
             RGBColor[
              0.490772053780571, 0.5758337103210316, 0.9571879877567727], 
             UndirectedEdge[51, 302] -> 
             RGBColor[
              0.3091305628069395, 0.4400376041430354, 0.9409967677924176], 
             UndirectedEdge[174, 390] -> 
             RGBColor[
              0.48194952909063554`, 0.586899845690572, 0.9533014866305167], 
             UndirectedEdge[79, 406] -> 
             RGBColor[
              0.4616525188591582, 0.5725415793681607, 0.9511179353674425], 
             UndirectedEdge[181, 235] -> 
             RGBColor[
              0.31959371799795877`, 0.4507903584376488, 0.9416015881259816], 
             UndirectedEdge[78, 404] -> 
             RGBColor[
              0.41129488175727036`, 0.5270213855252013, 0.9480644468994676], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.5652182131126833, 0.6579086340520297, 0.9589151946802172], 
             UndirectedEdge[43, 384] -> 
             RGBColor[
              0.6246999130863229, 0.7000084750271175, 0.9669357315587639], 
             UndirectedEdge[101, 363] -> 
             RGBColor[
              0.5462014555330743, 0.6401850233252737, 0.9583721618549175], 
             UndirectedEdge[120, 455] -> 
             RGBColor[
              0.555889255741948, 0.6413940790746825, 0.9613507488285702], 
             UndirectedEdge[295, 456] -> 
             RGBColor[
              0.24618212593796424`, 0.37583589856438704`, 0.9373401422250255],
              UndirectedEdge[58, 240] -> 
             RGBColor[
              0.3730533659029237, 0.49754180816292237`, 0.9449916084905634], 
             UndirectedEdge[39, 471] -> 
             RGBColor[
              0.5174741418003165, 0.6179064957935168, 0.9554995952865737], 
             UndirectedEdge[54, 365] -> 
             RGBColor[
              0.2496257875734256, 0.37970290830170295`, 0.9375271913628231], 
             UndirectedEdge[169, 334] -> 
             RGBColor[
              0.36959625604421514`, 0.4912678479286621, 0.9449547932140343], 
             UndirectedEdge[18, 65] -> 
             RGBColor[
              0.3432253938006836, 0.47104939988097405`, 0.9431150494716489], 
             UndirectedEdge[384, 435] -> 
             RGBColor[
              0.5813232872153056, 0.6579915300772112, 0.9643346118379487], 
             UndirectedEdge[9, 360] -> 
             RGBColor[
              0.3415464718523331, 0.46722321091530855`, 0.9430949202655321], 
             UndirectedEdge[135, 171] -> 
             RGBColor[
              0.37861956908019045`, 0.4994074129731425, 0.9455910431205361], 
             UndirectedEdge[149, 187] -> 
             RGBColor[
              0.9892052529813005, 0.9875133297415319, 0.6620449590018067], 
             UndirectedEdge[271, 464] -> 
             RGBColor[
              0.34470469194285375`, 0.4729876116244922, 0.9431852560535758], 
             UndirectedEdge[21, 348] -> 
             RGBColor[
              0.8152514291537309, 0.8530317900980647, 0.805431934685504], 
             UndirectedEdge[1, 70] -> 
             RGBColor[
              0.3905304054854526, 0.5126795414277583, 0.946105229998423], 
             UndirectedEdge[52, 276] -> 
             RGBColor[
              0.31947397874929506`, 0.44525537051377795`, 0.9417928240599194],
              UndirectedEdge[58, 429] -> 
             RGBColor[
              0.3776683495812062, 0.5015390750692266, 0.9452856711696738], 
             UndirectedEdge[243, 495] -> 
             RGBColor[
              0.2757724827697786, 0.40718474274929517`, 0.9390162069736863], 
             UndirectedEdge[131, 135] -> 
             RGBColor[
              0.7204269604249744, 0.7793367940427641, 0.9466274603917259], 
             UndirectedEdge[145, 430] -> 
             RGBColor[
              0.7294737800650596, 0.7869431550211035, 0.9543600258779894], 
             UndirectedEdge[291, 419] -> 
             RGBColor[
              0.3568180895313019, 0.4834796277785405, 0.9439571110364549], 
             UndirectedEdge[151, 260] -> 
             RGBColor[
              0.31610909508179497`, 0.44723743679627215`, 0.9413991296223709],
              UndirectedEdge[189, 437] -> 
             RGBColor[
              0.35618952688931305`, 0.48293519841052673`, 0.9439170595807235],
              UndirectedEdge[196, 354] -> 
             RGBColor[
              0.47677770596155067`, 0.5849740804961578, 0.9522663178588778], 
             UndirectedEdge[340, 355] -> 
             RGBColor[
              0.3070766357655428, 0.43562600110114164`, 0.9409622855645822], 
             UndirectedEdge[58, 310] -> 
             RGBColor[
              0.3912718908193648, 0.5133217787558564, 0.94615247678823], 
             UndirectedEdge[261, 500] -> 
             RGBColor[
              0.5461023869891515, 0.6409776929506601, 0.9579940358466219], 
             UndirectedEdge[237, 270] -> 
             RGBColor[
              0.6164507696724955, 0.6829215877736223, 0.916372570387269], 
             UndirectedEdge[23, 497] -> 
             RGBColor[
              0.3079123289091741, 0.440625308413757, 0.9408589892220036], 
             UndirectedEdge[431, 462] -> 
             RGBColor[
              0.5764591297640738, 0.66293644179462, 0.9617630063611268], 
             UndirectedEdge[108, 129] -> 
             RGBColor[
              0.4171037593906163, 0.5354707588504168, 0.9478607078360126], 
             UndirectedEdge[376, 485] -> 
             RGBColor[
              0.4290277116298691, 0.5445326413187079, 0.9489703037129593], 
             UndirectedEdge[124, 261] -> 
             RGBColor[
              0.5129499166978277, 0.612262689475922, 0.9558815897552373], 
             UndirectedEdge[63, 158] -> 
             RGBColor[
              0.4587471069702503, 0.5641878949966357, 0.9519236138443625], 
             UndirectedEdge[66, 427] -> 
             RGBColor[
              0.47940670577272715`, 0.5857023581868934, 0.9528617816928964], 
             UndirectedEdge[66, 208] -> 
             RGBColor[
              0.38917808776629237`, 0.5115082317888865, 0.9460190615091656], 
             UndirectedEdge[54, 230] -> 
             RGBColor[
              0.26582075407211336`, 0.3967248449120061, 0.9384494707466176], 
             UndirectedEdge[186, 295] -> 
             RGBColor[
              0.38012444184635064`, 0.5036664187425081, 0.9454421711969716], 
             UndirectedEdge[245, 394] -> 
             RGBColor[
              0.35413363171791556`, 0.4808689374072572, 0.9437965150671638], 
             UndirectedEdge[49, 459] -> 
             RGBColor[
              0.3497091690756735, 0.47540788235194764`, 0.9435742308559312], 
             UndirectedEdge[55, 365] -> 
             RGBColor[
              0.4669677680439246, 0.5648284017507225, 0.9536136670907724], 
             UndirectedEdge[197, 448] -> 
             RGBColor[
              0.43142659724767835`, 0.5438651331132356, 0.9496037840034466], 
             UndirectedEdge[185, 321] -> 
             RGBColor[
              0.3447445388856939, 0.47094240439902957`, 0.9432639438261], 
             UndirectedEdge[242, 339] -> 
             RGBColor[
              0.421062720856508, 0.5342146515923067, 0.948900466513644], 
             UndirectedEdge[186, 191] -> 
             RGBColor[
              0.38194260738330454`, 0.5052412223469606, 0.9455580230972457], 
             UndirectedEdge[218, 456] -> 
             RGBColor[
              0.239391434654601, 0.3689459544885648, 0.9369443601044645], 
             UndirectedEdge[63, 182] -> 
             RGBColor[
              0.3147617552192472, 0.44445743591237574`, 0.9413723382522537], 
             UndirectedEdge[133, 181] -> 
             RGBColor[
              0.37675108961146336`, 0.5007445905862619, 0.9452272241755029], 
             UndirectedEdge[11, 186] -> 
             RGBColor[
              0.407708849320648, 0.5275586460641124, 0.9471998252493001], 
             UndirectedEdge[105, 148] -> 
             RGBColor[
              0.3265275199943078, 0.45687881961269167`, 0.9420403739607708], 
             UndirectedEdge[235, 393] -> 
             RGBColor[
              0.31954173273243125`, 0.45074533141350426`, 0.941598275670831], 
             UndirectedEdge[110, 290] -> 
             RGBColor[
              0.5615148543448517, 0.6412174855285873, 0.9625936287739157], 
             UndirectedEdge[225, 296] -> 
             RGBColor[
              0.5565228786113532, 0.6376498357570682, 0.9620549508626433], 
             UndirectedEdge[38, 93] -> 
             RGBColor[
              0.3517913401922539, 0.479125710152825, 0.9436368110135507], 
             UndirectedEdge[80, 486] -> 
             RGBColor[
              0.4060086046522164, 0.521094362209237, 0.9477971547540095], 
             UndirectedEdge[471, 500] -> 
             RGBColor[
              0.41321147697602234`, 0.53232474556909, 0.9475504478177179], 
             UndirectedEdge[200, 213] -> 
             RGBColor[
              0.3252287493517614, 0.45173645428345616`, 0.9421047154365843], 
             UndirectedEdge[191, 295] -> 
             RGBColor[
              0.31324112310547503`, 0.445735449702506, 0.9411804252693996], 
             UndirectedEdge[295, 300] -> 
             RGBColor[
              0.277557276916298, 0.4088131715420843, 0.9391269106578652], 
             UndirectedEdge[191, 451] -> 
             RGBColor[
              0.3522396574071085, 0.47951401999125376`, 0.9436653773900499], 
             UndirectedEdge[137, 145] -> 
             RGBColor[
              0.6668852414956131, 0.7340082765087316, 0.9500193305783318], 
             UndirectedEdge[332, 344] -> 
             RGBColor[
              0.5879689658563793, 0.6732866144899512, 0.9623351748124223], 
             UndirectedEdge[76, 392] -> 
             RGBColor[
              0.30058496600847817`, 0.4305192371122264, 0.9405297490373172], 
             UndirectedEdge[157, 465] -> 
             RGBColor[
              0.28812924404519313`, 0.4121683839454104, 0.940012975498438], 
             UndirectedEdge[204, 337] -> 
             RGBColor[
              0.36869604749905993`, 0.49168670297240724`, 0.9447901601679392],
              UndirectedEdge[112, 395] -> 
             RGBColor[
              0.3273256871578789, 0.45679728563741406`, 0.942119530886228], 
             UndirectedEdge[51, 107] -> 
             RGBColor[
              0.3023334705061957, 0.43415030442392344`, 0.9405636630814469], 
             UndirectedEdge[5, 41] -> 
             RGBColor[
              0.35331803124291156`, 0.47984396672158053`, 0.9437562089827273],
              UndirectedEdge[88, 210] -> 
             RGBColor[
              0.32174012799400387`, 0.45309686056454335`, 0.9417219743455216],
              UndirectedEdge[248, 411] -> 
             RGBColor[
              0.30527389750401535`, 0.4364470878526595, 0.9407601806545448], 
             UndirectedEdge[101, 128] -> 
             RGBColor[
              0.735713845863762, 0.793464515111878, 0.9742927385850643], 
             UndirectedEdge[298, 418] -> 
             RGBColor[
              0.32865456643275887`, 0.45770054189717363`, 0.9422132773193757],
              UndirectedEdge[1, 391] -> 
             RGBColor[
              0.3918392789972914, 0.5138132218778174, 0.9461886302612059], 
             UndirectedEdge[116, 327] -> 
             RGBColor[
              0.5835245051711486, 0.6649911604086758, 0.9637500695736914], 
             UndirectedEdge[79, 81] -> 
             RGBColor[
              0.3235761319858936, 0.4484477045209111, 0.9420674182763966], 
             UndirectedEdge[254, 368] -> 
             RGBColor[
              0.4752222904274986, 0.5719877995839593, 0.9543238544865871], 
             UndirectedEdge[4, 318] -> 
             RGBColor[
              0.6760567758325431, 0.7467506288085379, 0.9684214287420858], 
             UndirectedEdge[352, 412] -> 
             RGBColor[
              0.5057961081074969, 0.6094397299146144, 0.9543000898010514], 
             UndirectedEdge[239, 424] -> 
             RGBColor[
              0.5133061795466541, 0.6089367109001507, 0.9569802327149375], 
             UndirectedEdge[58, 188] -> 
             RGBColor[
              0.31329452540474245`, 0.4421613973489137, 0.9413163851809911], 
             UndirectedEdge[407, 408] -> 
             RGBColor[
              0.2962717457123913, 0.4287307678303204, 0.9401836096723262], 
             UndirectedEdge[255, 466] -> 
             RGBColor[
              0.6447591837550684, 0.715509213949011, 0.9583208451995977], 
             UndirectedEdge[197, 489] -> 
             RGBColor[
              0.31428006901342037`, 0.445475868014124, 0.9412890796559565], 
             UndirectedEdge[50, 363] -> 
             RGBColor[
              0.3493820997863182, 0.4762698243276154, 0.94351145770148], 
             UndirectedEdge[57, 175] -> 
             RGBColor[
              0.3331580186769195, 0.46298646359421286`, 0.9424495122433928], 
             UndirectedEdge[278, 486] -> 
             RGBColor[
              0.406666648619943, 0.521786008141715, 0.9478346293844827], 
             UndirectedEdge[82, 263] -> 
             RGBColor[
              0.4274507849820442, 0.5424235208432349, 0.949075189916312], 
             UndirectedEdge[41, 186] -> 
             RGBColor[
              0.42662485122007915`, 0.5439427361635001, 0.9484051361635681], 
             UndirectedEdge[390, 425] -> 
             RGBColor[
              0.4781085191837997, 0.583572955964042, 0.9530567408757249], 
             UndirectedEdge[218, 458] -> 
             RGBColor[
              0.3099062274576516, 0.44183874211284935`, 0.9410048433908951], 
             UndirectedEdge[230, 374] -> 
             RGBColor[
              0.5678753930788263, 0.4429191519786202, 0.5743491526302444], 
             UndirectedEdge[104, 408] -> 
             RGBColor[
              0.4561046687574548, 0.5638999032993244, 0.9515465321914508], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.26449738135563605`, 0.395333896280312, 0.9383741066281686], 
             UndirectedEdge[143, 421] -> 
             RGBColor[
              0.6068914622213353, 0.6867431199061037, 0.9648068886015028], 
             UndirectedEdge[185, 482] -> 
             RGBColor[
              0.30331710998111594`, 0.4350600476850036, 0.9406242246891373], 
             UndirectedEdge[256, 333] -> 
             RGBColor[
              0.668547192728727, 0.377571549692729, 0.5597778844123176], 
             UndirectedEdge[351, 463] -> 
             RGBColor[
              0.515664525056192, 0.6168132999429556, 0.9552532643454603], 
             UndirectedEdge[42, 411] -> 
             RGBColor[
              0.34664548588055627`, 0.4746686297861905, 0.9433089217271096], 
             UndirectedEdge[52, 243] -> 
             RGBColor[
              0.27674629532528694`, 0.4082082814884166, 0.9390716641580958], 
             UndirectedEdge[385, 391] -> 
             RGBColor[
              0.41594177828000034`, 0.5346895953296622, 0.9477244202024968], 
             UndirectedEdge[366, 435] -> 
             RGBColor[
              0.2717041295248326, 0.4029086455403628, 0.9387845202749758], 
             UndirectedEdge[114, 419] -> 
             RGBColor[
              0.32070159479565064`, 0.4521973353063261, 0.9416557999284615], 
             UndirectedEdge[67, 391] -> 
             RGBColor[
              0.4990607655597989, 0.6028922146279425, 0.9540681171938468], 
             UndirectedEdge[310, 327] -> 
             RGBColor[
              0.3637723549568205, 0.48887941423768283`, 0.9444230655146444], 
             UndirectedEdge[309, 348] -> 
             RGBColor[
              0.5342813189878455, 0.6322299438380404, 0.9566352118842776], 
             UndirectedEdge[28, 194] -> 
             RGBColor[
              0.39198502847861205`, 0.5139394627529554, 0.9461979172892744], 
             UndirectedEdge[92, 337] -> 
             RGBColor[
              0.45598551062829296`, 0.5626109775768007, 0.9516456719744202], 
             UndirectedEdge[205, 432] -> 
             RGBColor[
              0.42729655802823563`, 0.5425279420030058, 0.9489996012770638], 
             UndirectedEdge[314, 398] -> 
             RGBColor[
              0.36998781739591546`, 0.49488658412509984`, 0.944796274450455], 
             UndirectedEdge[235, 453] -> 
             RGBColor[
              0.6486450148292093, 0.7125055467126014, 0.7308848506364984], 
             UndirectedEdge[92, 334] -> 
             RGBColor[
              0.5443953531632048, 0.6410036982858922, 0.957275942868345], 
             UndirectedEdge[35, 54] -> 
             RGBColor[
              0.27858695339168316`, 0.410142929820661, 0.9391764869119675], 
             UndirectedEdge[191, 456] -> 
             RGBColor[
              0.24800029147491814`, 0.37741070216883954`, 0.9374559941252996],
              UndirectedEdge[78, 137] -> 
             RGBColor[
              0.33358351895756655`, 0.46180911702723865`, 0.9425332274796736],
              UndirectedEdge[57, 169] -> 
             RGBColor[
              0.29906275648092184`, 0.43043973200474306`, 0.940387390933787], 
             UndirectedEdge[343, 392] -> 
             RGBColor[
              0.33721817471230664`, 0.4622490812528768, 0.9428639847024507], 
             UndirectedEdge[24, 197] -> 
             RGBColor[
              0.41668481033969174`, 0.5318970863914001, 0.9484432565371053], 
             UndirectedEdge[450, 471] -> 
             RGBColor[
              0.46629719347860343`, 0.5763587436507014, 0.9514707584473499], 
             UndirectedEdge[150, 267] -> 
             RGBColor[
              0.24693306498009032`, 0.37687268612763436`, 0.9373738447946587],
              UndirectedEdge[40, 371] -> 
             RGBColor[
              0.2975712278141692, 0.4296756303633329, 0.9402730272326185], 
             UndirectedEdge[217, 362] -> 
             RGBColor[
              0.5166118692324969, 0.6145533434948109, 0.9564878685479222], 
             UndirectedEdge[229, 478] -> 
             RGBColor[
              0.5759886709259834, 0.6599643543004001, 0.9628434621018613], 
             UndirectedEdge[100, 168] -> 
             RGBColor[
              0.29226233332903784`, 0.4227919944208597, 0.9400184266033118], 
             UndirectedEdge[221, 297] -> 
             RGBColor[
              0.3016979234576789, 0.43129101855262997`, 0.9406077033183345], 
             UndirectedEdge[50, 338] -> 
             RGBColor[
              0.3801320014685086, 0.5027268449084412, 0.9455197195196594], 
             UndirectedEdge[5, 186] -> 
             RGBColor[
              0.37551910614701256`, 0.4990734219450431, 0.9451708418439768], 
             UndirectedEdge[147, 391] -> 
             RGBColor[
              0.37790909984526744`, 0.5017476008474963, 0.9453010115636127], 
             UndirectedEdge[24, 426] -> 
             RGBColor[
              0.5407801161620216, 0.638068686023761, 0.9569913381685624], 
             UndirectedEdge[100, 127] -> 
             RGBColor[
              0.4250121064385113, 0.5406640130295817, 0.9488223327795368], 
             UndirectedEdge[418, 432] -> 
             RGBColor[
              0.4451984325497649, 0.5580336459391788, 0.9501402928915696], 
             UndirectedEdge[200, 259] -> 
             RGBColor[
              0.373053586941258, 0.4975419996152178, 0.9449916225749306], 
             UndirectedEdge[17, 293] -> 
             RGBColor[
              0.35585126900531266`, 0.47828719094432454`, 0.9440549649042153],
              UndirectedEdge[269, 468] -> 
             RGBColor[
              0.38997815940825975`, 0.5076222417794373, 0.9465768587249327], 
             UndirectedEdge[154, 390] -> 
             RGBColor[
              0.5882268974653132, 0.6765881205389125, 0.9607265225960442], 
             UndirectedEdge[162, 439] -> 
             RGBColor[
              0.3512202751035427, 0.4786310822755493, 0.9436004232510711], 
             UndirectedEdge[103, 304] -> 
             RGBColor[
              0.9132311965119942, 0.9320496710283179, 0.933049014145947], 
             UndirectedEdge[3, 480] -> 
             RGBColor[
              0.2913616934372136, 0.4204384468888711, 0.9400186506501927], 
             UndirectedEdge[358, 404] -> 
             RGBColor[
              0.7598788159031884, 0.8097870288136109, 0.8924694599784162], 
             UndirectedEdge[3, 439] -> 
             RGBColor[
              0.3129606056713121, 0.43914633907315337`, 0.9413949142385813], 
             UndirectedEdge[336, 458] -> 
             RGBColor[
              0.3259913882277651, 0.45677908850447513`, 0.9419928608883752], 
             UndirectedEdge[212, 287] -> 
             RGBColor[
              0.30622649179860384`, 0.43380078261783184`, 0.9409479838795869],
              UndirectedEdge[190, 195] -> 
             RGBColor[
              0.7393509489165082, 0.7936848922911501, 0.9144020270134654], 
             UndirectedEdge[253, 377] -> 
             RGBColor[
              0.32781365194808765`, 0.45645393349137475`, 0.9421786706831609],
              UndirectedEdge[192, 327] -> 
             RGBColor[
              0.3203461025423854, 0.45126577706320936`, 0.9416559831111238], 
             UndirectedEdge[151, 483] -> 
             RGBColor[
              0.41139516103614543`, 0.5297909534616033, 0.9477001277979469], 
             UndirectedEdge[38, 163] -> 
             RGBColor[
              0.3009883890398287, 0.4279031760686325, 0.940664035757951], 
             UndirectedEdge[88, 227] -> 
             RGBColor[
              0.3552735030476611, 0.4821417845995848, 0.9438586913515414], 
             UndirectedEdge[281, 343] -> 
             RGBColor[
              0.3874232199889084, 0.5099882535223356, 0.9459072428861592], 
             UndirectedEdge[76, 157] -> 
             RGBColor[
              0.25968840576800495`, 0.38753435930780566`, 0.9382007504326614],
              UndirectedEdge[364, 437] -> 
             RGBColor[
              0.3924202761526895, 0.5143164524120571, 0.9462256508861921], 
             UndirectedEdge[229, 244] -> 
             RGBColor[
              0.5760161982499107, 0.6599881970848224, 0.9628452161186005], 
             UndirectedEdge[154, 425] -> 
             RGBColor[
              0.4302580331824858, 0.5447257757883465, 0.9492897753355958], 
             UndirectedEdge[128, 355] -> 
             RGBColor[
              0.5172576001475442, 0.6068075728982566, 0.9581998455567764], 
             UndirectedEdge[58, 382] -> 
             RGBColor[
              0.3719557686184059, 0.49659112456191656`, 0.944921670562161], 
             UndirectedEdge[45, 179] -> 
             RGBColor[
              0.36705360818261323`, 0.485528488426008, 0.9450891592529057], 
             UndirectedEdge[181, 296] -> 
             RGBColor[
              0.29573481764204385`, 0.42571314142192784`, 0.9402428590467923],
              UndirectedEdge[350, 354] -> 
             RGBColor[
              0.4654580191647487, 0.5757842488084352, 0.9513751906488546], 
             UndirectedEdge[318, 335] -> 
             RGBColor[
              0.6191472936175115, 0.7005489474034178, 0.9639413058358162], 
             UndirectedEdge[354, 372] -> 
             RGBColor[
              0.7027728100250483, 0.7602365445735046, 0.7685760472104943], 
             UndirectedEdge[44, 57] -> 
             RGBColor[
              0.2979486779322681, 0.4292687648134481, 0.9403239458085727], 
             UndirectedEdge[257, 420] -> 
             RGBColor[
              0.49205543833816345`, 0.595793338866718, 0.9539066712782525], 
             UndirectedEdge[84, 171] -> 
             RGBColor[
              0.2913978251683583, 0.42360796831413083`, 0.9399060471076628], 
             UndirectedEdge[376, 497] -> 
             RGBColor[
              0.41033543351798085`, 0.5283423295194055, 0.9477792482806022], 
             UndirectedEdge[164, 443] -> 
             RGBColor[
              0.3422550208256281, 0.4708658296268017, 0.9430291651761453], 
             UndirectedEdge[2, 54] -> 
             RGBColor[
              0.2418645924022372, 0.3715454000885884, 0.9370852027794833], 
             UndirectedEdge[165, 324] -> 
             RGBColor[
              0.6343209347373799, 0.7064914315895977, 0.957995841866986], 
             UndirectedEdge[82, 395] -> 
             RGBColor[
              0.3387467640087014, 0.46782715390209445`, 0.9428056221540004], 
             UndirectedEdge[298, 420] -> 
             RGBColor[
              0.32348125155990815`, 0.4532196765726762, 0.9418836382702603], 
             UndirectedEdge[163, 437] -> 
             RGBColor[
              0.3051674428362324, 0.4315228624217262, 0.9409303213704656], 
             UndirectedEdge[156, 372] -> 
             RGBColor[
              0.9327517554580734, 0.9449846825658923, 0.7886566825743859], 
             UndirectedEdge[272, 317] -> 
             RGBColor[
              0.3140653010334952, 0.44461997952563354`, 0.9412999219519593], 
             UndirectedEdge[282, 441] -> 
             RGBColor[
              0.5090246024624772, 0.601870584194404, 0.9571426256646085], 
             UndirectedEdge[209, 423] -> 
             RGBColor[
              0.6763215025001792, 0.7399696301920545, 0.9034120838096568], 
             UndirectedEdge[222, 333] -> 
             RGBColor[
              0.7275097249962563, 0.4254399896193177, 0.5644196309392897], 
             UndirectedEdge[125, 455] -> 
             RGBColor[
              0.3224014738619655, 0.45190787947913225`, 0.9418286230541764], 
             UndirectedEdge[343, 433] -> 
             RGBColor[
              0.3952963932154813, 0.5168076004540008, 0.9464089145221828], 
             UndirectedEdge[29, 77] -> 
             RGBColor[
              0.5660230078793441, 0.6438534251004678, 0.96316886294675], 
             UndirectedEdge[298, 353] -> 
             RGBColor[
              0.3392891616577123, 0.4669116937707307, 0.9428909043233064], 
             UndirectedEdge[65, 337] -> 
             RGBColor[
              0.3355239783921925, 0.4629547239887102, 0.9426764652573585], 
             UndirectedEdge[93, 364] -> 
             RGBColor[
              0.3687159250845941, 0.49378493493219955`, 0.9447152305970679], 
             UndirectedEdge[170, 328] -> 
             RGBColor[
              0.33750133416974276`, 0.45900024597907413`, 0.9430099632616255],
              UndirectedEdge[13, 244] -> 
             RGBColor[
              0.3589332703370611, 0.4853116910804106, 0.9440918884870169], 
             UndirectedEdge[114, 291] -> 
             RGBColor[
              0.3622204288968687, 0.48815886260752284`, 0.9443013433237277], 
             UndirectedEdge[198, 373] -> 
             RGBColor[
              0.3958700355285574, 0.5167827225190543, 0.9465896242876051], 
             UndirectedEdge[54, 84] -> 
             RGBColor[
              0.28095365944614026`, 0.4126304879417261, 0.939311267320541], 
             UndirectedEdge[1, 385] -> 
             RGBColor[
              0.40259235014026146`, 0.5231269916367878, 0.9468738064458684], 
             UndirectedEdge[97, 294] -> 
             RGBColor[
              0.6485570333723533, 0.7182067431211772, 0.9499232769977184], 
             UndirectedEdge[83, 489] -> 
             RGBColor[
              0.35796884535881335`, 0.48447635463766126`, 0.9440304361802104],
              UndirectedEdge[349, 359] -> 
             RGBColor[
              0.30124220709062893`, 0.43395503788430145`, 0.9404666700946781],
              UndirectedEdge[47, 55] -> 
             RGBColor[
              0.5346642989897243, 0.6300787116823597, 0.9576850234557874], 
             UndirectedEdge[166, 309] -> 
             RGBColor[
              0.3826487734676519, 0.5058528679162828, 0.9456030193757021], 
             UndirectedEdge[196, 482] -> 
             RGBColor[
              0.4312023887203644, 0.5454990313838914, 0.9493622989449401], 
             UndirectedEdge[114, 311] -> 
             RGBColor[
              0.34731925560948695`, 0.4752522152607391, 0.9433518537384458], 
             UndirectedEdge[101, 169] -> 
             RGBColor[
              0.48510038887690565`, 0.5842472212636028, 0.9545892545654048], 
             UndirectedEdge[160, 353] -> 
             RGBColor[
              0.39467536037844364`, 0.5162696930245767, 0.9463693428589646], 
             UndirectedEdge[80, 329] -> 
             RGBColor[
              0.39886815639647094`, 0.5152974246416947, 0.9472350325109934], 
             UndirectedEdge[130, 386] -> 
             RGBColor[
              0.61782629203418, 0.6461372751001014, 0.6260504264602131], 
             UndirectedEdge[216, 238] -> 
             RGBColor[
              0.6035487233788674, 0.6853316114816681, 0.963941360461886], 
             UndirectedEdge[240, 382] -> 
             RGBColor[
              0.3880093589914371, 0.5104959376661231, 0.9459445911450981], 
             UndirectedEdge[424, 470] -> 
             RGBColor[
              0.3651121569129101, 0.48946763166008495`, 0.9445293894482181], 
             UndirectedEdge[184, 225] -> 
             RGBColor[
              0.6261377561787732, 0.7028059701411351, 0.9663128292219156], 
             UndirectedEdge[169, 274] -> 
             RGBColor[
              0.39079710831478975`, 0.5084796548894253, 0.9466238019660547], 
             UndirectedEdge[345, 375] -> 
             RGBColor[
              0.3905240171689849, 0.5064772700515436, 0.9467643915397175], 
             UndirectedEdge[326, 434] -> 
             RGBColor[
              0.5213944816713447, 0.6216669025605681, 0.9556485990540463], 
             UndirectedEdge[59, 105] -> 
             RGBColor[0.643251978161265, 0.7147646068779214, 0.9664102130547],
              UndirectedEdge[90, 306] -> 
             RGBColor[
              0.3594774903231769, 0.4857830670790923, 0.9441265657032973], 
             UndirectedEdge[44, 466] -> 
             RGBColor[
              0.30792680904592384`, 0.4379113204686448, 0.94095974349982], 
             UndirectedEdge[88, 434] -> 
             RGBColor[
              0.4635021087821979, 0.5715234389192554, 0.9519597482457651], 
             UndirectedEdge[174, 356] -> 
             RGBColor[
              0.298445948378546, 0.4292523162217663, 0.9403720041326156], 
             UndirectedEdge[65, 88] -> 
             RGBColor[
              0.34895068906260834`, 0.47666528091960325`, 0.9434558072354589],
              UndirectedEdge[82, 195] -> 
             RGBColor[
              0.6528251603130313, 0.7198000504600598, 0.9085959518174488], 
             UndirectedEdge[150, 413] -> 
             RGBColor[
              0.32080938688203875`, 0.4446041941828874, 0.9419441089539361], 
             UndirectedEdge[156, 307] -> 
             RGBColor[
              0.6602920163134958, 0.7318854246504086, 0.9687207816228554], 
             UndirectedEdge[245, 460] -> 
             RGBColor[
              0.28761626414664426`, 0.41963330791549247`, 0.9396906928017943],
              UndirectedEdge[101, 204] -> 
             RGBColor[
              0.5726100228666623, 0.6630587970164395, 0.9600548924132344], 
             UndirectedEdge[210, 428] -> 
             RGBColor[
              0.29998903661417226`, 0.4306368517118333, 0.9404685712008378], 
             UndirectedEdge[25, 76] -> 
             RGBColor[
              0.38206973779208764`, 0.5053513363172883, 0.9455661237344763], 
             UndirectedEdge[130, 421] -> 
             RGBColor[
              0.669120097225197, 0.6939628557454155, 0.6291944245444436], 
             UndirectedEdge[79, 493] -> 
             RGBColor[
              0.4741333630294715, 0.5826740909212436, 0.9521004731393681], 
             UndirectedEdge[194, 490] -> 
             RGBColor[
              0.4707448136715175, 0.5793228860818065, 0.9519995588558046], 
             UndirectedEdge[214, 347] -> 
             RGBColor[
              0.43472876971014235`, 0.5486924897109757, 0.9495485674017189], 
             UndirectedEdge[41, 202] -> 
             RGBColor[
              0.38361183638192653`, 0.5066870246076779, 0.9456643848929966], 
             UndirectedEdge[85, 97] -> 
             RGBColor[
              0.8148992827036392, 0.8558756965815397, 0.9624805202964128], 
             UndirectedEdge[31, 114] -> 
             RGBColor[
              0.28298224013478673`, 0.4131577952525769, 0.9394855537617509], 
             UndirectedEdge[247, 425] -> 
             RGBColor[
              0.30359584480216045`, 0.43537543910492593`, 0.940639277192489], 
             UndirectedEdge[35, 281] -> 
             RGBColor[
              0.3291330896301447, 0.45824061031745045`, 0.9422391697213552], 
             UndirectedEdge[157, 288] -> 
             RGBColor[
              0.5638297011996113, 0.6336470919017314, 0.9543461176625757], 
             UndirectedEdge[208, 427] -> 
             RGBColor[
              0.5088361882473461, 0.6111926967376105, 0.9547370022927095], 
             UndirectedEdge[154, 313] -> 
             RGBColor[
              0.41469732977747087`, 0.5294239111475415, 0.948365045384644], 
             UndirectedEdge[189, 364] -> 
             RGBColor[
              0.3689350579852496, 0.49397473683680754`, 0.9447291935517259], 
             UndirectedEdge[314, 373] -> 
             RGBColor[
              0.43990097958363056`, 0.5549201131999628, 0.9493952371077593], 
             UndirectedEdge[156, 232] -> 
             RGBColor[
              0.6252709455183157, 0.7015519333378222, 0.9664892699597034], 
             UndirectedEdge[321, 383] -> 
             RGBColor[
              0.35502584419688943`, 0.4817487081535031, 0.9438494489537443], 
             UndirectedEdge[15, 323] -> 
             RGBColor[
              0.47091622440274333`, 0.5771589729143222, 0.9526001910276094], 
             UndirectedEdge[225, 235] -> 
             RGBColor[
              0.5803817789672682, 0.6627270527727892, 0.9634136799418325], 
             UndirectedEdge[170, 265] -> 
             RGBColor[
              0.5847811758666781, 0.6725205231773401, 0.9612876679563881], 
             UndirectedEdge[102, 485] -> 
             RGBColor[
              0.3221905056506697, 0.4521761198025854, 0.9417986681113946], 
             UndirectedEdge[342, 463] -> 
             RGBColor[
              0.376038439831807, 0.5001273291659429, 0.9451818147617146], 
             UndirectedEdge[70, 147] -> 
             RGBColor[
              0.3766002263334287, 0.5006139203974371, 0.9452176113008297], 
             UndirectedEdge[162, 381] -> 
             RGBColor[
              0.37778935747774167`, 0.5016438860271719, 0.945293381685838], 
             UndirectedEdge[212, 299] -> 
             RGBColor[
              0.41002441156977126`, 0.5295642697007603, 0.9473473708282429], 
             UndirectedEdge[92, 361] -> 
             RGBColor[
              0.555070049627801, 0.6496698977654471, 0.9581162940767396], 
             UndirectedEdge[82, 184] -> 
             RGBColor[
              0.3573520530739639, 0.4839421201614063, 0.9439911347212279], 
             UndirectedEdge[232, 376] -> 
             RGBColor[
              0.44364689277425184`, 0.5571950412445632, 0.9499018250082449], 
             UndirectedEdge[293, 298] -> 
             RGBColor[
              0.3719115627277682, 0.49516757792806043`, 0.9449695748726337], 
             UndirectedEdge[225, 249] -> 
             RGBColor[
              0.675715685515858, 0.7446276588442088, 0.9697814116684343], 
             UndirectedEdge[19, 34] -> 
             RGBColor[
              0.35054545167002155`, 0.47536152550513333`, 0.9436557372481358],
              UndirectedEdge[338, 390] -> 
             RGBColor[
              0.547957055231764, 0.6438952484779984, 0.9575563331021266], 
             UndirectedEdge[82, 342] -> 
             RGBColor[
              0.3249583034338198, 0.4558842823803112, 0.9419270336388259], 
             UndirectedEdge[54, 374] -> 
             RGBColor[
              0.5641068718713471, 0.43895819725151475`, 0.574134540922506], 
             UndirectedEdge[196, 350] -> 
             RGBColor[
              0.5307029068830011, 0.6298875535579475, 0.956198023340084], 
             UndirectedEdge[19, 44] -> 
             RGBColor[
              0.34764637511773344`, 0.4723144122366086, 0.9434906391272825], 
             UndirectedEdge[85, 408] -> 
             RGBColor[
              0.48429754869300334`, 0.5863281212797331, 0.9540805053825658], 
             UndirectedEdge[57, 255] -> 
             RGBColor[
              0.6347810526414126, 0.7068666582938143, 0.9576850475083505], 
             UndirectedEdge[106, 269] -> 
             RGBColor[
              0.44958833591889846`, 0.5624175518739859, 0.9502593179727521], 
             UndirectedEdge[382, 416] -> 
             RGBColor[
              0.31226943364391224`, 0.43831839341615175`, 0.9413592686952521],
              UndirectedEdge[246, 392] -> 
             RGBColor[
              0.6240648650343078, 0.6908547542158712, 0.9149873300080887], 
             UndirectedEdge[350, 414] -> 
             RGBColor[
              0.4162373390627274, 0.5331517696073782, 0.9482388924368922], 
             UndirectedEdge[146, 211] -> 
             RGBColor[
              0.47248483382521245`, 0.5800875195258005, 0.9523155820967417], 
             UndirectedEdge[71, 487] -> 
             RGBColor[
              0.5799107817476705, 0.6637965044431702, 0.9628931142912018], 
             UndirectedEdge[415, 485] -> 
             RGBColor[
              0.4916357553325228, 0.5953606716567492, 0.9538990382540529], 
             UndirectedEdge[238, 433] -> 
             RGBColor[
              0.3926927426493517, 0.5145524491969017, 0.9462430122104268], 
             UndirectedEdge[141, 429] -> 
             RGBColor[
              0.6922386558315736, 0.753988931800845, 0.9129779112488179], 
             UndirectedEdge[406, 493] -> 
             RGBColor[
              0.5298950389161701, 0.6292316899484369, 0.9561344250144173], 
             UndirectedEdge[257, 357] -> 
             RGBColor[0.6409127866170177, 0.719229847889, 0.9649637490251903],
              UndirectedEdge[311, 488] -> 
             RGBColor[
              0.39119542593284606`, 0.5132555487143908, 0.9461476045132763], 
             UndirectedEdge[258, 381] -> 
             RGBColor[
              0.3546814592604417, 0.4780846150494491, 0.9439507436290018], 
             UndirectedEdge[168, 200] -> 
             RGBColor[
              0.3231163730506393, 0.4495162128585838, 0.9419844187312161], 
             UndirectedEdge[16, 254] -> 
             RGBColor[
              0.5010848650351504, 0.5991710052785408, 0.9557966898502425], 
             UndirectedEdge[325, 347] -> 
             RGBColor[
              0.6030671964927072, 0.6822484149760397, 0.9651074957672285], 
             UndirectedEdge[154, 478] -> 
             RGBColor[
              0.4263998267189715, 0.5413839912687457, 0.9490439338314187], 
             UndirectedEdge[302, 386] -> 
             RGBColor[
              0.30231668099902853`, 0.4328757823378617, 0.9406087273036918], 
             UndirectedEdge[330, 414] -> 
             RGBColor[
              0.27647600207380585`, 0.40752241885718854`, 0.9390709820257457],
              UndirectedEdge[50, 334] -> 
             RGBColor[
              0.38174249885418193`, 0.5040343192382112, 0.945646503773306], 
             UndirectedEdge[72, 187] -> 
             RGBColor[
              0.6662756765261768, 0.7315817799199846, 0.9142888339471833], 
             UndirectedEdge[14, 149] -> 
             RGBColor[
              0.7385521496466888, 0.7894986068183087, 0.6956939743940672], 
             UndirectedEdge[113, 214] -> 
             RGBColor[
              0.4032764470480036, 0.5178356232323448, 0.9476767957668162], 
             UndirectedEdge[63, 149] -> 
             RGBColor[
              0.636652134233188, 0.6994888851419525, 0.689062246564851], 
             UndirectedEdge[245, 445] -> 
             RGBColor[
              0.28388377496926664`, 0.4157102251365863, 0.9394781330648656], 
             UndirectedEdge[207, 336] -> 
             RGBColor[
              0.6295762605208408, 0.703298490064025, 0.967676250206505], 
             UndirectedEdge[264, 394] -> 
             RGBColor[
              0.3999431621971854, 0.5208323981925529, 0.9467050025327206], 
             UndirectedEdge[255, 370] -> 
             RGBColor[
              0.6082678631247767, 0.6802241801821292, 0.9561303232610034], 
             UndirectedEdge[330, 482] -> 
             RGBColor[
              0.28012136493464085`, 0.4106798489459791, 0.9393032613237702], 
             UndirectedEdge[383, 482] -> 
             RGBColor[
              0.3135984152923114, 0.44586635143947717`, 0.9412097298167816], 
             UndirectedEdge[358, 407] -> 
             RGBColor[
              0.642765898615575, 0.7092999185328326, 0.8844696128010554], 
             UndirectedEdge[28, 142] -> 
             RGBColor[
              0.40235768477549283`, 0.5229237362924494, 0.9468588537763318], 
             UndirectedEdge[348, 375] -> 
             RGBColor[
              0.44860836377219193`, 0.5536327592940222, 0.9513370040742943], 
             UndirectedEdge[41, 295] -> 
             RGBColor[
              0.3579233669422497, 0.48443696351904547`, 0.944027538335722], 
             UndirectedEdge[83, 345] -> 
             RGBColor[
              0.4516918282146532, 0.5638493303798789, 0.9505011532322376], 
             UndirectedEdge[140, 425] -> 
             RGBColor[
              0.3624874208436386, 0.48839011761240947`, 0.9443183558144841], 
             UndirectedEdge[160, 441] -> 
             RGBColor[
              0.5771768244852498, 0.6646464833513219, 0.9613480703416788], 
             UndirectedEdge[66, 394] -> 
             RGBColor[
              0.381179157382155, 0.5045799603280776, 0.9455093767382647], 
             UndirectedEdge[201, 271] -> 
             RGBColor[
              0.3073474310927581, 0.44007145534874836`, 0.940825358545686], 
             UndirectedEdge[192, 470] -> 
             RGBColor[
              0.3865522522548577, 0.509233865047212, 0.9458517455923121], 
             UndirectedEdge[255, 379] -> 
             RGBColor[
              0.6829625705426667, 0.7485990674263776, 0.960755131223775], 
             UndirectedEdge[82, 440] -> 
             RGBColor[
              0.3167527566072657, 0.44877705014192526`, 0.9414041834509181], 
             UndirectedEdge[43, 362] -> 
             RGBColor[
              0.5207687910550486, 0.6181538602445396, 0.9567527439306336], 
             UndirectedEdge[127, 302] -> 
             RGBColor[
              0.4276293763211704, 0.5429309606541317, 0.9489891029020989], 
             UndirectedEdge[137, 358] -> 
             RGBColor[
              0.6821674531034847, 0.7445747603156483, 0.8869382405586221], 
             UndirectedEdge[238, 328] -> 
             RGBColor[
              0.3157187126251994, 0.440133234023583, 0.941621993878423], 
             UndirectedEdge[185, 196] -> 
             RGBColor[
              0.4141373149405546, 0.5286384015467823, 0.9483510762943045], 
             UndirectedEdge[114, 208] -> 
             RGBColor[
              0.3723557522010644, 0.496937570237456, 0.9449471571623564], 
             UndirectedEdge[249, 424] -> 
             RGBColor[
              0.39519311020834447`, 0.51440201966239, 0.9467556418218619], 
             UndirectedEdge[21, 65] -> 
             RGBColor[
              0.6896716893155814, 0.749220345006006, 0.796059803917397], 
             UndirectedEdge[369, 466] -> 
             RGBColor[
              0.36466633766511986`, 0.4902773858476328, 0.9444571944676085], 
             UndirectedEdge[246, 459] -> 
             RGBColor[
              0.6983865274282197, 0.7594825280959233, 0.9195672777090252], 
             UndirectedEdge[46, 317] -> 
             RGBColor[
              0.3612088554462101, 0.485453356853986, 0.9443038675517291], 
             UndirectedEdge[66, 305] -> 
             RGBColor[
              0.42772243730135395`, 0.5437427406920717, 0.9487930067531163], 
             UndirectedEdge[56, 243] -> 
             RGBColor[
              0.38600365414151605`, 0.5084388840296612, 0.9458959225506228], 
             UndirectedEdge[281, 288] -> 
             RGBColor[
              0.6549313067166862, 0.7243711419756109, 0.9597183744509402], 
             UndirectedEdge[81, 329] -> 
             RGBColor[
              0.3803223205427634, 0.4958045752855397, 0.9461788745952302], 
             UndirectedEdge[57, 140] -> 
             RGBColor[
              0.36341295471398294`, 0.48919176853221685`, 0.944377330014285], 
             UndirectedEdge[184, 440] -> 
             RGBColor[
              0.3548197546797494, 0.4817487705693557, 0.943829778906772], 
             UndirectedEdge[422, 446] -> 
             RGBColor[
              0.5511814749876858, 0.6465129776943104, 0.9578101712367515], 
             UndirectedEdge[232, 307] -> 
             RGBColor[
              0.4140722527224633, 0.5330703062568103, 0.947605295687127], 
             UndirectedEdge[90, 261] -> 
             RGBColor[
              0.5107733700078192, 0.6103774741294541, 0.9557429021247945], 
             UndirectedEdge[118, 304] -> 
             RGBColor[
              0.5630108586052811, 0.64655035150974, 0.9621091385798354], 
             UndirectedEdge[427, 460] -> 
             RGBColor[
              0.4343198902919375, 0.5430287957850369, 0.9501214952564393], 
             UndirectedEdge[299, 300] -> 
             RGBColor[
              0.34833195297048913`, 0.4701146387015748, 0.9436366104324496], 
             UndirectedEdge[106, 425] -> 
             RGBColor[
              0.35694247135928564`, 0.4835873610663275, 0.9439650365365475], 
             UndirectedEdge[428, 495] -> 
             RGBColor[
              0.25640241869446195`, 0.3868255772731414, 0.9379131104800389], 
             UndirectedEdge[230, 365] -> 
             RGBColor[
              0.25339430878090474`, 0.38366386302880845`, 0.9377418030705615],
              UndirectedEdge[224, 463] -> 
             RGBColor[
              0.6583514648770511, 0.7293873101289882, 0.968973382431657], 
             UndirectedEdge[251, 382] -> 
             RGBColor[
              0.3645208591472764, 0.4901513796674397, 0.944447924705093], 
             UndirectedEdge[81, 278] -> 
             RGBColor[
              0.26046530082076175`, 0.39109592398948767`, 0.9381444856066361],
              UndirectedEdge[42, 294] -> 
             RGBColor[
              0.35268547990861054`, 0.4799001690343644, 0.9436937848056202], 
             UndirectedEdge[8, 419] -> 
             RGBColor[
              0.3014929744688417, 0.4336127170583398, 0.9405031356454493], 
             UndirectedEdge[159, 164] -> 
             RGBColor[
              0.42818104240711047`, 0.5440619324963929, 0.9488437882792019], 
             UndirectedEdge[346, 404] -> 
             RGBColor[
              0.6876311244341455, 0.7543891264298175, 0.9706181781934278], 
             UndirectedEdge[7, 194] -> 
             RGBColor[
              0.3638603414201825, 0.4895792724108172, 0.9444058370995955], 
             UndirectedEdge[268, 353] -> 
             RGBColor[
              0.35205006472722766`, 0.4793498043411461, 0.943653296712138], 
             UndirectedEdge[51, 423] -> 
             RGBColor[
              0.325550909574111, 0.45426008320213374`, 0.9420430577684791], 
             UndirectedEdge[14, 322] -> 
             RGBColor[
              0.6662866489532128, 0.737036136650177, 0.9689661575088726], 
             UndirectedEdge[109, 458] -> 
             RGBColor[
              0.3580336528134911, 0.48453248759758577`, 0.9440345656539155], 
             UndirectedEdge[217, 384] -> 
             RGBColor[
              0.6205429912637712, 0.696407958277389, 0.9666708561760524], 
             UndirectedEdge[202, 485] -> 
             RGBColor[
              0.35630635804319627`, 0.48303639168391577`, 0.9439245039585391],
              UndirectedEdge[125, 457] -> 
             RGBColor[
              0.3113886355235644, 0.4403326881311927, 0.9412014582028387], 
             UndirectedEdge[454, 475] -> 
             RGBColor[
              0.36930499051745735`, 0.49429515380285616`, 0.9447527653255597],
              UndirectedEdge[30, 378] -> 
             RGBColor[
              0.6353565674813205, 0.7025655317452153, 0.9115216839238166], 
             UndirectedEdge[445, 460] -> 
             RGBColor[
              0.2658424851527165, 0.39674768565555013`, 0.9384507082995095], 
             UndirectedEdge[173, 461] -> 
             RGBColor[
              0.3213491481487429, 0.45100798090621497`, 0.9417611460435369], 
             UndirectedEdge[23, 41] -> 
             RGBColor[
              0.3539100853597925, 0.48046625313682156`, 0.943789925588818], 
             UndirectedEdge[111, 444] -> 
             RGBColor[
              0.42028535549279966`, 0.5384517835968504, 0.9480011891016218], 
             UndirectedEdge[139, 360] -> 
             RGBColor[
              0.5715674648996037, 0.6603736254946824, 0.9607427562081345], 
             UndirectedEdge[53, 432] -> 
             RGBColor[
              0.5648309070106979, 0.6575942015104969, 0.95888470452512], 
             UndirectedEdge[184, 260] -> 
             RGBColor[
              0.346771365454237, 0.47379555426236214`, 0.9433529023769218], 
             UndirectedEdge[244, 379] -> 
             RGBColor[
              0.3654160275329837, 0.49092672953066807`, 0.9445049640430639], 
             UndirectedEdge[14, 187] -> 
             RGBColor[
              0.7351308040449069, 0.7903745716883612, 0.9189099903893985], 
             UndirectedEdge[133, 332] -> 
             RGBColor[
              0.4138419290144628, 0.5328708114373464, 0.9475906196641205], 
             UndirectedEdge[424, 440] -> 
             RGBColor[
              0.3050158844045614, 0.4374152609398353, 0.9407001081050334], 
             UndirectedEdge[381, 419] -> 
             RGBColor[
              0.37712579411203384`, 0.5010691407914603, 0.9452511000149411], 
             UndirectedEdge[39, 368] -> 
             RGBColor[
              0.43490818059233244`, 0.5402641652323203, 0.9504629356665152], 
             UndirectedEdge[40, 208] -> 
             RGBColor[
              0.35022540699747506`, 0.47528203389591683`, 0.9436281049699162],
              UndirectedEdge[436, 462] -> 
             RGBColor[
              0.5301343907168439, 0.6206004988581103, 0.9588922191379199], 
             UndirectedEdge[103, 188] -> 
             RGBColor[
              0.6278014465126885, 0.6945850426952171, 0.9100590811055471], 
             UndirectedEdge[313, 411] -> 
             RGBColor[
              0.3083217307877971, 0.43965055387770563`, 0.9409337502511909], 
             UndirectedEdge[181, 344] -> 
             RGBColor[
              0.5508781264533797, 0.6411603936388667, 0.9599717793238046], 
             UndirectedEdge[5, 485] -> 
             RGBColor[
              0.3260125529041813, 0.4561933337978184, 0.9420163280482698], 
             UndirectedEdge[371, 429] -> 
             RGBColor[
              0.35581806775340985`, 0.48261345917708637`, 0.9438933905330522],
              UndirectedEdge[426, 448] -> 
             RGBColor[
              0.5555219030700083, 0.6500367327455965, 0.9581518656349038], 
             UndirectedEdge[32, 403] -> 
             RGBColor[
              0.5383364759041063, 0.6310459834516572, 0.9588558200393184], 
             UndirectedEdge[115, 484] -> 
             RGBColor[
              0.36761692500090537`, 0.49055617237241333`, 0.9447285704253177],
              UndirectedEdge[36, 251] -> 
             RGBColor[
              0.2966013552407109, 0.4259906334585649, 0.9403153950738317], 
             UndirectedEdge[243, 454] -> 
             RGBColor[
              0.34691210494341146`, 0.47486104461847456`, 0.9433273207613802],
              UndirectedEdge[106, 139] -> 
             RGBColor[
              0.5648865105792015, 0.6545869186568778, 0.9603170517065744], 
             UndirectedEdge[220, 499] -> 
             RGBColor[
              0.39964815636094475`, 0.5205768789646257, 0.9466862050216986], 
             UndirectedEdge[359, 419] -> 
             RGBColor[
              0.30497279260918575`, 0.4372702265570546, 0.9407013061406122], 
             UndirectedEdge[115, 297] -> 
             RGBColor[
              0.27238765020905265`, 0.40362706911719254`, 0.9388234457667639],
              UndirectedEdge[155, 235] -> 
             RGBColor[
              0.37009895445661484`, 0.49453545579114305`, 0.9448197371331002],
              UndirectedEdge[98, 261] -> 
             RGBColor[
              0.5618244133640866, 0.654595321984607, 0.9589958294647908], 
             UndirectedEdge[386, 421] -> 
             RGBColor[
              0.3232933085143353, 0.4510446827756659, 0.9419453394600638], 
             UndirectedEdge[37, 58] -> 
             RGBColor[
              0.32742946730791833`, 0.4570181174962307, 0.9421213492116044], 
             UndirectedEdge[71, 194] -> 
             RGBColor[
              0.3583512044031033, 0.48480753482390093`, 0.9440547997604058], 
             UndirectedEdge[47, 339] -> 
             RGBColor[
              0.3292294822047813, 0.45746840222464147`, 0.9422766430846604], 
             UndirectedEdge[108, 410] -> 
             RGBColor[
              0.37972834480460527`, 0.5020898646827314, 0.9455160941916156], 
             UndirectedEdge[193, 196] -> 
             RGBColor[
              0.47682520402508216`, 0.5850152209314667, 0.9522693443934851], 
             UndirectedEdge[131, 171] -> 
             RGBColor[
              0.6247479556538544, 0.6946482319993318, 0.9404608358843123], 
             UndirectedEdge[203, 258] -> 
             RGBColor[
              0.3384388467270244, 0.4640160804504462, 0.9429157787211507], 
             UndirectedEdge[164, 428] -> 
             RGBColor[
              0.3136906733738075, 0.44250452080874203`, 0.9413416273792801], 
             UndirectedEdge[143, 325] -> 
             RGBColor[
              0.8563864439953396, 0.8883233207238646, 0.9861640976051209], 
             UndirectedEdge[101, 498] -> 
             RGBColor[
              0.4735003986969909, 0.5720548961026556, 0.9539286522853062], 
             UndirectedEdge[35, 391] -> 
             RGBColor[
              0.3501551905278812, 0.47644889751355657`, 0.9435786794014451], 
             UndirectedEdge[8, 221] -> 
             RGBColor[
              0.31521350121195996`, 0.4454967477095033, 0.9413773954769353], 
             UndirectedEdge[240, 251] -> 
             RGBColor[
              0.3656184564317942, 0.4911020632684455, 0.9445178626334954], 
             UndirectedEdge[464, 485] -> 
             RGBColor[
              0.36361269427722276`, 0.4893647729026928, 0.9443900572426319], 
             UndirectedEdge[104, 452] -> 
             RGBColor[
              0.5302667456254171, 0.6292948312028928, 0.9562296204785212], 
             UndirectedEdge[121, 475] -> 
             RGBColor[
              0.31037991846934515`, 0.4394571185628069, 0.9411372520977066], 
             UndirectedEdge[168, 315] -> 
             RGBColor[
              0.34627389117402974`, 0.46957409112636095`, 0.9434599953086493],
              UndirectedEdge[65, 320] -> 
             RGBColor[
              0.39436307251963587`, 0.5159992049773214, 0.9463494441527467], 
             UndirectedEdge[323, 452] -> 
             RGBColor[
              0.3755275358420053, 0.4994795113319588, 0.9451567773941743], 
             UndirectedEdge[72, 322] -> 
             RGBColor[
              0.5974315214344825, 0.6782433448818005, 0.9643450010666574], 
             UndirectedEdge[60, 327] -> 
             RGBColor[
              0.2904385741487021, 0.4225997346724447, 0.9398514191811781], 
             UndirectedEdge[1, 135] -> 
             RGBColor[
              0.42639421235443153`, 0.543173296600759, 0.9485478420662635], 
             UndirectedEdge[420, 439] -> 
             RGBColor[
              0.36950671115147626`, 0.4944698740772695, 0.9447656187859849], 
             UndirectedEdge[134, 367] -> 
             RGBColor[
              0.32935645235089234`, 0.4576191607394161, 0.942283240231653], 
             UndirectedEdge[119, 345] -> 
             RGBColor[
              0.7364635563750684, 0.7927994935993894, 0.9597843546514078], 
             UndirectedEdge[64, 366] -> 
             RGBColor[
              0.2750304045793114, 0.4064047715206393, 0.9389739467185454], 
             UndirectedEdge[86, 90] -> 
             RGBColor[
              0.3536051839222143, 0.4806967704252801, 0.9437523875321048], 
             UndirectedEdge[81, 426] -> 
             RGBColor[
              0.3928287149133309, 0.5059578296422123, 0.9471634237725134], 
             UndirectedEdge[70, 265] -> 
             RGBColor[
              0.561036717626811, 0.651954266881139, 0.9597746920737438], 
             UndirectedEdge[245, 438] -> 
             RGBColor[
              0.29216515973275825`, 0.42441448559313655`, 0.9399497456759356],
              UndirectedEdge[121, 259] -> 
             RGBColor[
              0.3123222189451326, 0.44113944161207364`, 0.9412610137665149], 
             UndirectedEdge[74, 105] -> 
             RGBColor[
              0.38856456530138783`, 0.510976829466322, 0.9459799684002185], 
             UndirectedEdge[358, 430] -> 
             RGBColor[
              0.7447559916729312, 0.7975096388280202, 0.8912789358582799], 
             UndirectedEdge[43, 316] -> 
             RGBColor[
              0.3434315172391845, 0.47188485168779515`, 0.9431041304872823], 
             UndirectedEdge[162, 203] -> 
             RGBColor[
              0.3615467449443245, 0.487575351428169, 0.9442584167779868], 
             UndirectedEdge[226, 236] -> 
             RGBColor[
              0.6267083603735737, 0.6932925618408008, 0.9062517418203191], 
             UndirectedEdge[110, 340] -> 
             RGBColor[
              0.6135473371296214, 0.6914455327406948, 0.9657201550814796], 
             UndirectedEdge[145, 407] -> 
             RGBColor[
              0.6274836870077034, 0.6987334347259159, 0.9475507028207649], 
             UndirectedEdge[258, 289] -> 
             RGBColor[
              0.3085647043331811, 0.4381405998269544, 0.9410122247844819], 
             UndirectedEdge[13, 334] -> 
             RGBColor[
              0.4342229829102857, 0.5502593996593155, 0.948962352454503], 
             UndirectedEdge[300, 389] -> 
             RGBColor[
              0.6152375155725758, 0.6811341609531395, 0.9029427327743351], 
             UndirectedEdge[57, 363] -> 
             RGBColor[
              0.36016382313709044`, 0.48637753406641393`, 0.9441702982232997],
              UndirectedEdge[305, 427] -> 
             RGBColor[
              0.5473805377824077, 0.6434272056407957, 0.9575109475366602], 
             UndirectedEdge[277, 419] -> 
             RGBColor[
              0.30671146759605517`, 0.4390976842066156, 0.9408003211089753], 
             UndirectedEdge[40, 349] -> 
             RGBColor[
              0.2948406640735045, 0.42722661029203385`, 0.9401021116900872], 
             UndirectedEdge[28, 241] -> 
             RGBColor[
              0.5031305248737998, 0.6060603700998624, 0.9544260416578111], 
             UndirectedEdge[164, 396] -> 
             RGBColor[
              0.3425956951887217, 0.47116090463732196`, 0.9430508726453152], 
             UndirectedEdge[111, 284] -> 
             RGBColor[
              0.4004943178951484, 0.5213097815562375, 0.9467401216864268], 
             UndirectedEdge[25, 343] -> 
             RGBColor[
              0.4187029464959161, 0.5370811804579387, 0.9479003593996098], 
             UndirectedEdge[84, 131] -> 
             RGBColor[
              0.6332052165131423, 0.7035373493837525, 0.9409424643788525], 
             UndirectedEdge[169, 244] -> 
             RGBColor[
              0.2943065434709905, 0.4263201393497572, 0.9400843292465482], 
             UndirectedEdge[219, 363] -> 
             RGBColor[
              0.4087642819587358, 0.5284728087676371, 0.9472670764837166], 
             UndirectedEdge[400, 415] -> 
             RGBColor[
              0.5151745426628249, 0.6157487861484058, 0.9553989089682073], 
             UndirectedEdge[248, 286] -> 
             RGBColor[
              0.3251727259934689, 0.45368245294602383`, 0.9420281164100497], 
             UndirectedEdge[136, 484] -> 
             RGBColor[
              0.3569548503827127, 0.4793496559341173, 0.9441213810489375], 
             UndirectedEdge[74, 263] -> 
             RGBColor[
              0.48224635939007876`, 0.5898846932898254, 0.952566715463768], 
             UndirectedEdge[69, 142] -> 
             RGBColor[
              0.32190122029808305`, 0.44681306448591707`, 0.9419674284399575],
              UndirectedEdge[109, 409] -> 
             RGBColor[
              0.3834542401631106, 0.5065505226839558, 0.9456543430012905], 
             UndirectedEdge[101, 219] -> 
             RGBColor[
              0.5566288138592901, 0.6492166770131738, 0.9590365839069129], 
             UndirectedEdge[380, 390] -> 
             RGBColor[
              0.45768156926085446`, 0.5631563576950427, 0.9518548853845434], 
             UndirectedEdge[53, 293] -> 
             RGBColor[
              0.5264353547590107, 0.626334496803407, 0.9558865093378492], 
             UndirectedEdge[221, 258] -> 
             RGBColor[
              0.30657544732160996`, 0.4364176053864961, 0.9408854710867356], 
             UndirectedEdge[235, 424] -> 
             RGBColor[
              0.2998592036597546, 0.43250141359097044`, 0.9403879100952601], 
             UndirectedEdge[367, 457] -> 
             RGBColor[
              0.2769862752217034, 0.4084605155751545, 0.9390853306581783], 
             UndirectedEdge[58, 220] -> 
             RGBColor[
              0.39450637498077024`, 0.516123326366565, 0.9463585752588528], 
             UndirectedEdge[334, 379] -> 
             RGBColor[
              0.44070574010620833`, 0.555874438109573, 0.9493754280105501], 
             UndirectedEdge[14, 163] -> 
             RGBColor[
              0.3575689206630036, 0.476064329811407, 0.9445030658037004], 
             UndirectedEdge[284, 442] -> 
             RGBColor[
              0.6616865855516074, 0.728723388161649, 0.9382741640746266], 
             UndirectedEdge[130, 302] -> 
             RGBColor[
              0.6481434697098902, 0.6757939553076113, 0.6278578123880716], 
             UndirectedEdge[65, 428] -> 
             RGBColor[
              0.32719959768277673`, 0.4542052720668932, 0.9422024040907749], 
             UndirectedEdge[388, 487] -> 
             RGBColor[
              0.6796393199826323, 0.7480297804811711, 0.9698408326011635], 
             UndirectedEdge[456, 458] -> 
             RGBColor[
              0.25145608711045797`, 0.3804039386550051, 0.937676194367356], 
             UndirectedEdge[281, 465] -> 
             RGBColor[
              0.3792308495622681, 0.5028924340192898, 0.9453852322868025], 
             UndirectedEdge[166, 428] -> 
             RGBColor[
              0.3011467920007328, 0.43163964123719434`, 0.9405423423503065], 
             UndirectedEdge[92, 128] -> 
             RGBColor[
              0.7015473444260286, 0.7665186951619007, 0.971061473526666], 
             UndirectedEdge[120, 457] -> 
             RGBColor[
              0.544876417403547, 0.629818887726743, 0.9607235839772326], 
             UndirectedEdge[79, 329] -> 
             RGBColor[
              0.4626370315293294, 0.5733408511055962, 0.951195439811227], 
             UndirectedEdge[105, 195] -> 
             RGBColor[
              0.6673090962049044, 0.7323453077458153, 0.9095188554048373], 
             UndirectedEdge[98, 377] -> 
             RGBColor[
              0.4088681826771611, 0.5285628023477353, 0.9472736969456188], 
             UndirectedEdge[21, 309] -> 
             RGBColor[
              0.7135633483793162, 0.7699140992573128, 0.7975821593063734], 
             UndirectedEdge[93, 322] -> 
             RGBColor[
              0.5901808200583463, 0.6719631517806386, 0.9638829927865135], 
             UndirectedEdge[8, 115] -> 
             RGBColor[
              0.2859032279633337, 0.41783279827406583`, 0.9395931379253648], 
             UndirectedEdge[54, 131] -> 
             RGBColor[
              0.6143037899316364, 0.6836707516269269, 0.9398660560971905], 
             UndirectedEdge[186, 212] -> 
             RGBColor[
              0.40795121979340965`, 0.5277685751857244, 0.9472152688815046], 
             UndirectedEdge[252, 467] -> 
             RGBColor[
              0.394642048437175, 0.5162408398953565, 0.9463672202515234], 
             UndirectedEdge[244, 378] -> 
             RGBColor[
              0.2986509862117823, 0.43088642412390854`, 0.9403317388336092], 
             UndirectedEdge[55, 339] -> 
             RGBColor[
              0.49130137702068916`, 0.5904045676252213, 0.9549994301236507], 
             UndirectedEdge[69, 490] -> 
             RGBColor[
              0.398488464361943, 0.510314741883881, 0.9476306376068477], 
             UndirectedEdge[299, 451] -> 
             RGBColor[
              0.4211961679243457, 0.5392406835462917, 0.9480592252643602], 
             UndirectedEdge[146, 464] -> 
             RGBColor[
              0.4812312095366823, 0.5876631905614503, 0.9528728934229602], 
             UndirectedEdge[199, 220] -> 
             RGBColor[
              0.30546998721582397`, 0.42700182883720705`, 0.9411247313050395],
              UndirectedEdge[345, 426] -> 
             RGBColor[
              0.5320983576915901, 0.6310204433887026, 0.9563078783394409], 
             UndirectedEdge[66, 472] -> 
             RGBColor[
              0.46072277873412176`, 0.5705339045156326, 0.9513909145149375], 
             UndirectedEdge[40, 114] -> 
             RGBColor[
              0.30397358895762805`, 0.4352210337937693, 0.940680980023294], 
             UndirectedEdge[248, 294] -> 
             RGBColor[
              0.3113138915320696, 0.4416786271008334, 0.9411450437330554], 
             UndirectedEdge[304, 483] -> 
             RGBColor[
              0.6645722934744656, 0.7356996787859316, 0.9687675097315347], 
             UndirectedEdge[9, 425] -> 
             RGBColor[
              0.29806270107361743`, 0.4295597542246523, 0.940324172842701], 
             UndirectedEdge[290, 384] -> 
             RGBColor[
              0.5774629231959636, 0.6539340427316671, 0.964114769817944], 
             UndirectedEdge[294, 358] -> 
             RGBColor[
              0.6644494522649012, 0.7292283185218826, 0.8858092652126006], 
             UndirectedEdge[148, 342] -> 
             RGBColor[
              0.31771683253477434`, 0.44924744497327157`, 0.9414789647468343],
              UndirectedEdge[178, 420] -> 
             RGBColor[
              0.3092985259081349, 0.43831273267591875`, 0.9410759530258542], 
             UndirectedEdge[193, 354] -> 
             RGBColor[
              0.4115803163068297, 0.5309119161819544, 0.9474465117022557], 
             UndirectedEdge[194, 228] -> 
             RGBColor[
              0.6407431099746377, 0.7140518029388985, 0.9678900796440478], 
             UndirectedEdge[326, 491] -> 
             RGBColor[
              0.5435337278949632, 0.6393980100987748, 0.9575573006380429], 
             UndirectedEdge[324, 481] -> 
             RGBColor[
              0.7049715237830463, 0.7674290772745724, 0.9625684634122417], 
             UndirectedEdge[94, 213] -> 
             RGBColor[
              0.4337130032260258, 0.5415523271166774, 0.9501632677849321], 
             UndirectedEdge[92, 175] -> 
             RGBColor[
              0.4850291496351701, 0.5898481329030953, 0.9534201108166123], 
             UndirectedEdge[254, 401] -> 
             RGBColor[
              0.5203403955772996, 0.61719467941153, 0.9569743698324572], 
             UndirectedEdge[161, 491] -> 
             RGBColor[
              0.6609582922076155, 0.7350649084324455, 0.9668418036269872], 
             UndirectedEdge[172, 303] -> 
             RGBColor[
              0.45029990678151016`, 0.5612511046311405, 0.9507972444509347], 
             UndirectedEdge[57, 274] -> 
             RGBColor[
              0.41372507447552886`, 0.5313538359377729, 0.947974353047146], 
             UndirectedEdge[44, 360] -> 
             RGBColor[
              0.34050691484063933`, 0.46613057058429697`, 0.9430357190316029],
              UndirectedEdge[170, 238] -> 
             RGBColor[
              0.42827725504854364`, 0.5453739653074847, 0.9485104258743545], 
             UndirectedEdge[5, 11] -> 
             RGBColor[
              0.3344020293434804, 0.4634598766221929, 0.9425508980684593], 
             UndirectedEdge[3, 223] -> 
             RGBColor[
              0.6136816228277203, 0.6793481154827916, 0.8989231749888876], 
             UndirectedEdge[65, 227] -> 
             RGBColor[
              0.39113273407101373`, 0.5132012481746563, 0.9461436098432766], 
             UndirectedEdge[78, 85] -> 
             RGBColor[
              0.48220776745026894`, 0.5841316286938357, 0.9539614954323463], 
             UndirectedEdge[181, 393] -> 
             RGBColor[
              0.33522835400695256`, 0.46477968399900815`, 0.9425814321798969],
              UndirectedEdge[45, 56] -> 
             RGBColor[
              0.35454329805673246`, 0.47537205508276936`, 0.9441043018130204],
              UndirectedEdge[141, 310] -> 
             RGBColor[
              0.7058421970697322, 0.765771635487475, 0.9138447168673742], 
             UndirectedEdge[39, 236] -> 
             RGBColor[
              0.8069061473523578, 0.8485095754406062, 0.9188979253320266], 
             UndirectedEdge[337, 375] -> 
             RGBColor[
              0.27374268224027376`, 0.4050512936959989, 0.9389006128363517], 
             UndirectedEdge[57, 334] -> 
             RGBColor[
              0.3925242222049542, 0.5141420289770098, 0.9463053442951256], 
             UndirectedEdge[123, 438] -> 
             RGBColor[
              0.3468656922493783, 0.47207888546842913`, 0.943424759929308], 
             UndirectedEdge[35, 385] -> 
             RGBColor[
              0.36090826167085127`, 0.4857626672725269, 0.9442638555861077], 
             UndirectedEdge[268, 285] -> 
             RGBColor[
              0.2928471950640109, 0.42415694032619017`, 0.9400242644161567], 
             UndirectedEdge[169, 361] -> 
             RGBColor[
              0.38027095250881143`, 0.49993404740821695`, 0.9457951444224288],
              UndirectedEdge[337, 361] -> 
             RGBColor[
              0.38532257569793205`, 0.505243623671392, 0.9460828268898425], 
             UndirectedEdge[119, 270] -> 
             RGBColor[
              0.9691514859598851, 0.9763502371173072, 0.9297775725314744], 
             UndirectedEdge[254, 386] -> 
             RGBColor[
              0.4899879928780221, 0.5875074890590672, 0.9551647393972452], 
             UndirectedEdge[253, 488] -> 
             RGBColor[
              0.35100709960673215`, 0.476542932116718, 0.9436565366588092], 
             UndirectedEdge[340, 380] -> 
             RGBColor[
              0.31814276529248714`, 0.4472572048670966, 0.9415924852702701], 
             UndirectedEdge[388, 490] -> 
             RGBColor[
              0.545039642998806, 0.6415267617993596, 0.957326663724315], 
             UndirectedEdge[27, 311] -> 
             RGBColor[
              0.31537189239949626`, 0.4432783705595804, 0.9414737368935178], 
             UndirectedEdge[222, 417] -> 
             RGBColor[
              0.5697255407163061, 0.6615678856534453, 0.9592700280200595], 
             UndirectedEdge[274, 361] -> 
             RGBColor[
              0.4949332705034184, 0.6008481513412467, 0.9533821065357878], 
             UndirectedEdge[65, 474] -> 
             RGBColor[
              0.31100463118408894`, 0.43718333545659005`, 0.9412801247069806],
              UndirectedEdge[243, 326] -> 
             RGBColor[
              0.36860280362388753`, 0.4936484376092881, 0.9447094329009684], 
             UndirectedEdge[47, 437] -> 
             RGBColor[
              0.37613357461528474`, 0.5002097301337781, 0.9451878766659934], 
             UndirectedEdge[232, 414] -> 
             RGBColor[
              0.34607131998326945`, 0.4741713161443778, 0.9432723363838493], 
             UndirectedEdge[102, 196] -> 
             RGBColor[
              0.41829539267131244`, 0.5330088048791639, 0.9485878726697463], 
             UndirectedEdge[90, 257] -> 
             RGBColor[
              0.4895382607850505, 0.5936130861872341, 0.9537462789504207], 
             UndirectedEdge[116, 310] -> 
             RGBColor[
              0.6452961563231654, 0.7191183086239901, 0.9676632697278805], 
             UndirectedEdge[333, 459] -> 
             RGBColor[
              0.6143483697880888, 0.3324317271998331, 0.5558258018460551], 
             UndirectedEdge[68, 257] -> 
             RGBColor[
              0.5691226134362781, 0.6610784021259541, 0.9592225633759803], 
             UndirectedEdge[220, 349] -> 
             RGBColor[
              0.36992552941230916`, 0.49474869040312575`, 0.9447953790796997],
              UndirectedEdge[92, 204] -> 
             RGBColor[
              0.5384435214289289, 0.6361129770664623, 0.9568236273548362], 
             UndirectedEdge[120, 123] -> 
             RGBColor[
              0.6185732852972717, 0.6974496405206005, 0.9652804114277712], 
             UndirectedEdge[190, 224] -> 
             RGBColor[
              0.6937971170825409, 0.7590291051744468, 0.971524676504785], 
             UndirectedEdge[450, 469] -> 
             RGBColor[
              0.39677273423064097`, 0.5124238585284703, 0.9471767930707413], 
             UndirectedEdge[405, 434] -> 
             RGBColor[
              0.5335820594084979, 0.632223169831022, 0.9564251807304058], 
             UndirectedEdge[312, 400] -> 
             RGBColor[
              0.371906000403281, 0.4965480178353986, 0.9449184993755017], 
             UndirectedEdge[100, 259] -> 
             RGBColor[
              0.3421995472196566, 0.4708177811774937, 0.9430256304470263], 
             UndirectedEdge[87, 423] -> 
             RGBColor[
              0.4478556732104154, 0.5602432814784285, 0.9503350112134248], 
             UndirectedEdge[403, 449] -> 
             RGBColor[
              0.35129237592778384`, 0.4786935323856142, 0.9436050174518353], 
             UndirectedEdge[268, 275] -> 
             RGBColor[
              0.45687898310319264`, 0.5663146578032007, 0.9513918854714505], 
             UndirectedEdge[166, 210] -> 
             RGBColor[
              0.3315465533353126, 0.46159069330991603`, 0.9423468310967884], 
             UndirectedEdge[102, 496] -> 
             RGBColor[
              0.3073887086282393, 0.43935554718170616`, 0.9408555106938405], 
             UndirectedEdge[11, 202] -> 
             RGBColor[
              0.3646958344824953, 0.4903029345082903, 0.9444590739787286], 
             UndirectedEdge[187, 494] -> 
             RGBColor[
              0.7213663188494067, 0.7791999425236625, 0.9178263996938381], 
             UndirectedEdge[158, 282] -> 
             RGBColor[
              0.45252387315778697`, 0.5576468816839234, 0.9515692098851922], 
             UndirectedEdge[232, 372] -> 
             RGBColor[
              0.686531991867041, 0.7461695641722939, 0.7675411966386577], 
             UndirectedEdge[143, 477] -> 
             RGBColor[
              0.5555603455436242, 0.6388783225225892, 0.9616607656833025], 
             UndirectedEdge[479, 482] -> 
             RGBColor[
              0.38949154394323426`, 0.5116362885416735, 0.9460786684522255], 
             UndirectedEdge[45, 283] -> 
             RGBColor[
              0.33214757687347063`, 0.4562553027413239, 0.9425995434213426], 
             UndirectedEdge[323, 463] -> 
             RGBColor[
              0.3639854242814331, 0.4894823144215861, 0.944421324251823], 
             UndirectedEdge[130, 347] -> 
             RGBColor[
              0.6481051982385475, 0.6757608064827143, 0.6278553737637598], 
             UndirectedEdge[338, 369] -> 
             RGBColor[
              0.423611208729084, 0.5411554717865852, 0.9482620148029619], 
             UndirectedEdge[143, 386] -> 
             RGBColor[
              0.5555976570303183, 0.6389175392607895, 0.9616628905172723], 
             UndirectedEdge[168, 254] -> 
             RGBColor[
              0.4825509150906905, 0.5796906487666152, 0.9547412088194274], 
             UndirectedEdge[86, 115] -> 
             RGBColor[
              0.3215826155561778, 0.4506835672830583, 0.9417953049340411], 
             UndirectedEdge[138, 457] -> 
             RGBColor[
              0.6011268241615624, 0.6746714351989684, 0.966088797989143], 
             UndirectedEdge[11, 497] -> 
             RGBColor[
              0.3395100179659285, 0.4684882461175852, 0.9428542560212361], 
             UndirectedEdge[154, 379] -> 
             RGBColor[
              0.4793650849540842, 0.5872598358407171, 0.9524188332508212], 
             UndirectedEdge[17, 467] -> 
             RGBColor[
              0.31266299574381984`, 0.4408796793509496, 0.9413030463218834], 
             UndirectedEdge[75, 93] -> 
             RGBColor[
              0.337250551553053, 0.46653120987483643`, 0.9427102848193754], 
             UndirectedEdge[100, 315] -> 
             RGBColor[
              0.3814108767544126, 0.5047806640017728, 0.9455241416917637], 
             UndirectedEdge[45, 52] -> 
             RGBColor[
              0.24528593924050335`, 0.37514145254152476`, 0.9372800434204935],
              UndirectedEdge[8, 203] -> 
             RGBColor[
              0.3470769006173744, 0.4730952227734534, 0.9434077031113506], 
             UndirectedEdge[244, 340] -> 
             RGBColor[
              0.3347390360758454, 0.46435586140091745`, 0.9425502532740135], 
             UndirectedEdge[104, 190] -> 
             RGBColor[
              0.5541702862703347, 0.6489394293379787, 0.9580454614092981], 
             UndirectedEdge[38, 437] -> 
             RGBColor[
              0.3754956912603493, 0.4996572276326826, 0.945147231302675], 
             UndirectedEdge[96, 465] -> 
             RGBColor[
              0.3175688677970441, 0.4431112950885601, 0.9416895185190854], 
             UndirectedEdge[48, 346] -> 
             RGBColor[
              0.7003797858894629, 0.7647390641198978, 0.971621799523076], 
             UndirectedEdge[153, 342] -> 
             RGBColor[
              0.4294768952276292, 0.5443764924078599, 0.9491495682117954], 
             UndirectedEdge[151, 327] -> 
             RGBColor[
              0.3180476071031837, 0.4492749358395127, 0.9415095250142176], 
             UndirectedEdge[375, 489] -> 
             RGBColor[
              0.296801034313145, 0.427104294309326, 0.9402936744876904], 
             UndirectedEdge[203, 289] -> 
             RGBColor[
              0.376592965333306, 0.5006076312840793, 0.9452171486363226], 
             UndirectedEdge[6, 79] -> 
             RGBColor[
              0.35794542231634496`, 0.48445606677555153`, 0.9440289436846565],
              UndirectedEdge[105, 463] -> 
             RGBColor[
              0.38484912729134046`, 0.507758703805363, 0.9457432239756511], 
             UndirectedEdge[10, 125] -> 
             RGBColor[
              0.38620202019520045`, 0.508930511640312, 0.9458294291151688], 
             UndirectedEdge[32, 331] -> 
             RGBColor[
              0.5281482425342815, 0.6221011806717597, 0.9582110383861508], 
             UndirectedEdge[26, 44] -> 
             RGBColor[
              0.3340015294681744, 0.46049593274484374`, 0.9426212016281559], 
             UndirectedEdge[86, 253] -> 
             RGBColor[
              0.3236016965494082, 0.45280574942407237`, 0.9419102886096429], 
             UndirectedEdge[370, 466] -> 
             RGBColor[
              0.30545566423868076`, 0.43531399059660214`, 0.9408190154587786],
              UndirectedEdge[301, 456] -> 
             RGBColor[
              0.21249063663255374`, 0.3406715101582872, 0.9354123994532731], 
             UndirectedEdge[21, 337] -> 
             RGBColor[
              0.6403857476218129, 0.7044503245000413, 0.7929955434475615], 
             UndirectedEdge[61, 172] -> 
             RGBColor[
              0.3708043892912313, 0.49559385765872555`, 0.9448483056895582], 
             UndirectedEdge[291, 359] -> 
             RGBColor[
              0.34649162671040373`, 0.47323175385825134`, 0.9433468495358784],
              UndirectedEdge[134, 499] -> 
             RGBColor[
              0.36984428787880214`, 0.4947622660713795, 0.9447871288765426], 
             UndirectedEdge[140, 244] -> 
             RGBColor[
              0.3586567417040516, 0.48507217587723106`, 0.9440742683270462], 
             UndirectedEdge[108, 364] -> 
             RGBColor[
              0.433390460928021, 0.5495774811286958, 0.9488984820562114], 
             UndirectedEdge[113, 421] -> 
             RGBColor[
              0.3221198920565641, 0.4498113476796478, 0.9418785151287077], 
             UndirectedEdge[54, 55] -> 
             RGBColor[
              0.4793942133351332, 0.5778893836339201, 0.9543213347668285], 
             UndirectedEdge[56, 210] -> 
             RGBColor[
              0.39703335140077917`, 0.518030770626229, 0.9465973148034572], 
             UndirectedEdge[36, 58] -> 
             RGBColor[
              0.3040362647118404, 0.43243037835304177`, 0.9407891409308997], 
             UndirectedEdge[25, 288] -> 
             RGBColor[
              0.6862110332236939, 0.751464068911214, 0.9617114909643907], 
             UndirectedEdge[262, 344] -> 
             RGBColor[
              0.8411722327804672, 0.7608249751632779, 0.6142614399775463], 
             UndirectedEdge[8, 439] -> 
             RGBColor[
              0.3367504307765926, 0.4641509536208337, 0.9427497095844347], 
             UndirectedEdge[102, 186] -> 
             RGBColor[
              0.3716970588935009, 0.4950562079498101, 0.9449531819071015], 
             UndirectedEdge[85, 145] -> 
             RGBColor[
              0.8155094899883155, 0.8563307881753286, 0.9614475985310045], 
             UndirectedEdge[421, 423] -> 
             RGBColor[
              0.370030832957217, 0.49492384204227424`, 0.9447990153639839], 
             UndirectedEdge[406, 476] -> 
             RGBColor[
              0.43067498213772254`, 0.5457103940363199, 0.9491440741199128], 
             UndirectedEdge[111, 400] -> 
             RGBColor[
              0.42306582380067004`, 0.5408600854947272, 0.9481783580835277], 
             UndirectedEdge[137, 183] -> 
             RGBColor[
              0.3763542344494681, 0.500400854591462, 0.9452019369155058], 
             UndirectedEdge[85, 358] -> 
             RGBColor[
              0.830791701596187, 0.8668972719822453, 0.898366508511295], 
             UndirectedEdge[399, 412] -> 
             RGBColor[
              0.33527713385355656`, 0.4571354294395099, 0.942865980997635], 
             UndirectedEdge[283, 292] -> 
             RGBColor[
              0.6009972615594347, 0.6838646843418348, 0.9634643019326707], 
             UndirectedEdge[240, 310] -> 
             RGBColor[
              0.40732548119239603`, 0.5272265918600629, 0.947175397371167], 
             UndirectedEdge[186, 300] -> 
             RGBColor[
              0.34625876119412746`, 0.46831894418653885`, 0.9435045084857113],
              UndirectedEdge[37, 240] -> 
             RGBColor[
              0.34348305768094956`, 0.4709229306004373, 0.9431442697945414], 
             UndirectedEdge[36, 429] -> 
             RGBColor[
              0.32470483876315415`, 0.45033245836355246`, 0.942106124192947], 
             UndirectedEdge[56, 276] -> 
             RGBColor[
              0.4287313375655242, 0.5454859730550226, 0.9486170824524462], 
             UndirectedEdge[95, 174] -> 
             RGBColor[
              0.6536843644649848, 0.7213155988528632, 0.9308075833712148], 
             UndirectedEdge[7, 28] -> 
             RGBColor[
              0.3720604565880178, 0.4966818000194241, 0.9449283411870129], 
             UndirectedEdge[251, 367] -> 
             RGBColor[
              0.31421881191102774`, 0.4445076974303363, 0.9413186831685146], 
             UndirectedEdge[31, 314] -> 
             RGBColor[
              0.32356464630509063`, 0.4483082357462522, 0.94207142879731], 
             UndirectedEdge[238, 436] -> 
             RGBColor[
              0.3456591546528833, 0.47160253692834586`, 0.943327057758985], 
             UndirectedEdge[291, 488] -> 
             RGBColor[
              0.4060965992202278, 0.5261621960611746, 0.9470970940985581], 
             UndirectedEdge[96, 171] -> 
             RGBColor[
              0.2613805530600898, 0.39205791212336505`, 0.9381966078676715], 
             UndirectedEdge[127, 179] -> 
             RGBColor[
              0.5056617095360849, 0.609557981458636, 0.9542266885560065], 
             UndirectedEdge[296, 453] -> 
             RGBColor[
              0.6247861144732942, 0.6874283296968804, 0.7295261215573091], 
             UndirectedEdge[14, 494] -> 
             RGBColor[
              0.47071321551479506`, 0.5811852196004392, 0.9514754150860987], 
             UndirectedEdge[317, 420] -> 
             RGBColor[
              0.3210797310438259, 0.45069552624507864`, 0.9417468752296007], 
             UndirectedEdge[7, 388] -> 
             RGBColor[
              0.43815517074747096`, 0.5517831481283704, 0.9497329419681059], 
             UndirectedEdge[146, 271] -> 
             RGBColor[
              0.4485233325636082, 0.5593332714730701, 0.950788776424676], 
             UndirectedEdge[331, 449] -> 
             RGBColor[
              0.34110414255795896`, 0.4697487296057168, 0.942960235798668], 
             UndirectedEdge[27, 359] -> 
             RGBColor[
              0.2784277687647617, 0.40997561668487825`, 0.9391674215829569], 
             UndirectedEdge[100, 471] -> 
             RGBColor[
              0.36749966987383, 0.4927314757994001, 0.9446377318905301], 
             UndirectedEdge[219, 337] -> 
             RGBColor[
              0.35271483849168783`, 0.4778445829691414, 0.9437718516616176], 
             UndirectedEdge[199, 419] -> 
             RGBColor[
              0.24711312771504196`, 0.3764560502386719, 0.9374062838205943], 
             UndirectedEdge[266, 437] -> 
             RGBColor[
              0.3246248596934236, 0.4519738412101163, 0.942038392475814], 
             UndirectedEdge[327, 399] -> 
             RGBColor[
              0.2638052763048027, 0.3946064499898915, 0.9383346922694014], 
             UndirectedEdge[311, 419] -> 
             RGBColor[
              0.34191691624392023`, 0.47057298043175677`, 0.9430076214511731],
              UndirectedEdge[267, 329] -> 
             RGBColor[
              0.3938197506207891, 0.5099912300840396, 0.9469475332705153], 
             UndirectedEdge[219, 244] -> 
             RGBColor[
              0.36583496845337493`, 0.4912895950993281, 0.9445316585880563], 
             UndirectedEdge[17, 205] -> 
             RGBColor[
              0.29469239818877413`, 0.4253144509772647, 0.9401579757364514], 
             UndirectedEdge[175, 361] -> 
             RGBColor[
              0.4143662147048091, 0.5324807789976868, 0.9478572657320347], 
             UndirectedEdge[189, 266] -> 
             RGBColor[
              0.30113964152598366`, 0.43163212563486675`, 0.9405419351413478],
              UndirectedEdge[225, 280] -> 
             RGBColor[
              0.7494944436688581, 0.8045245784079924, 0.9755895457707346], 
             UndirectedEdge[300, 458] -> 
             RGBColor[
              0.28283123808879174`, 0.41338121163270236`, 0.9394629628001958],
              UndirectedEdge[171, 343] -> 
             RGBColor[
              0.34732124947266496`, 0.4728680533979509, 0.9434393398638934], 
             UndirectedEdge[358, 408] -> 
             RGBColor[
              0.6426995500858581, 0.7092301820213602, 0.8844658343504419], 
             UndirectedEdge[380, 411] -> 
             RGBColor[
              0.3034554842698668, 0.4345358202495113, 0.9406566247109613], 
             UndirectedEdge[345, 498] -> 
             RGBColor[
              0.38636775825809966`, 0.502108778414168, 0.9465276987433766], 
             UndirectedEdge[161, 450] -> 
             RGBColor[
              0.5943598492809108, 0.6812398221466864, 0.9614331112191201], 
             UndirectedEdge[94, 214] -> 
             RGBColor[
              0.5714880648946918, 0.662998782182268, 0.9594087803797208], 
             UndirectedEdge[157, 343] -> 
             RGBColor[
              0.2963216144718334, 0.4192642034484561, 0.9405349860977947], 
             UndirectedEdge[155, 332] -> 
             RGBColor[
              0.42287641513413554`, 0.5406960292277314, 0.9481662891307836], 
             UndirectedEdge[127, 168] -> 
             RGBColor[
              0.3898751208581285, 0.5054574401541697, 0.9467581863964225], 
             UndirectedEdge[378, 380] -> 
             RGBColor[
              0.2820547154284241, 0.41378776759008773`, 0.9393739708298657], 
             UndirectedEdge[160, 481] -> 
             RGBColor[
              0.4336472911078765, 0.5497688770916926, 0.9489234283086474], 
             UndirectedEdge[23, 485] -> 
             RGBColor[
              0.3266046070210623, 0.45681562021305944`, 0.9420500446543607], 
             UndirectedEdge[352, 399] -> 
             RGBColor[
              0.396128823058742, 0.5067649344325187, 0.947593627981764], 
             UndirectedEdge[389, 456] -> 
             RGBColor[
              0.583862364594242, 0.6481568879754422, 0.9011559643414953], 
             UndirectedEdge[105, 263] -> 
             RGBColor[
              0.4419347208739173, 0.5549687781289904, 0.9499980935037006], 
             UndirectedEdge[143, 347] -> 
             RGBColor[
              0.5858765632346858, 0.6685410706434025, 0.963467837820819], 
             UndirectedEdge[98, 484] -> 
             RGBColor[
              0.45069053672320925`, 0.5647872233697879, 0.9499385803633774], 
             UndirectedEdge[100, 500] -> 
             RGBColor[
              0.373111126011613, 0.4975918370659615, 0.9449952889136138], 
             UndirectedEdge[89, 424] -> 
             RGBColor[
              0.39205765534741044`, 0.511856516155652, 0.9465088073296595], 
             UndirectedEdge[231, 442] -> 
             RGBColor[
              0.6918621705232362, 0.7548599631950741, 0.9401969256657967], 
             UndirectedEdge[15, 104] -> 
             RGBColor[
              0.6256554341861551, 0.706974292785256, 0.9636730341119564], 
             UndirectedEdge[75, 182] -> 
             RGBColor[
              0.3455404503703723, 0.4737115035679688, 0.9432385098415452], 
             UndirectedEdge[290, 316] -> 
             RGBColor[
              0.2961945273488252, 0.4258104193923448, 0.9402831687464623], 
             UndirectedEdge[344, 424] -> 
             RGBColor[
              0.5311436121151756, 0.6228714487921883, 0.958758101293083], 
             UndirectedEdge[369, 425] -> 
             RGBColor[
              0.3537626726811197, 0.4808331792726288, 0.9437624225765603], 
             UndirectedEdge[106, 255] -> 
             RGBColor[
              0.6706583352293816, 0.7379417572268585, 0.9599711162298206], 
             UndirectedEdge[84, 242] -> 
             RGBColor[
              0.42805698375245804`, 0.541566065357831, 0.9492987794384836], 
             UndirectedEdge[143, 446] -> 
             RGBColor[
              0.6853348626918734, 0.7525647343925146, 0.9703915797771134], 
             UndirectedEdge[376, 415] -> 
             RGBColor[
              0.5708506473238741, 0.662481297882944, 0.9593586005336086], 
             UndirectedEdge[93, 108] -> 
             RGBColor[
              0.396940578763989, 0.5180064252225574, 0.9465759277960845], 
             UndirectedEdge[78, 183] -> 
             RGBColor[
              0.33479655018910714`, 0.4628597837112766, 0.9426105207571059], 
             UndirectedEdge[17, 298] -> 
             RGBColor[
              0.2777029551399939, 0.4092137916094091, 0.939126144519292], 
             UndirectedEdge[204, 370] -> 
             RGBColor[
              0.3600592009540424, 0.4826088296458946, 0.9442983045342698], 
             UndirectedEdge[208, 314] -> 
             RGBColor[
              0.4129381583713683, 0.5320880107311312, 0.9475330321979155], 
             UndirectedEdge[313, 379] -> 
             RGBColor[
              0.3536860032675558, 0.47894280662504163`, 0.94382432157955], 
             UndirectedEdge[3, 221] -> 
             RGBColor[
              0.29142367610667946`, 0.42049213316182293`, 0.9400226001310821],
              UndirectedEdge[154, 229] -> 
             RGBColor[
              0.6899652556710112, 0.7563213033948714, 0.9707590853263577], 
             UndirectedEdge[25, 180] -> 
             RGBColor[
              0.5599163753622991, 0.6520615301566817, 0.959247193385842], 
             UndirectedEdge[371, 419] -> 
             RGBColor[
              0.31429923365219187`, 0.44665193187588964`, 0.941247847137786], 
             UndirectedEdge[31, 419] -> 
             RGBColor[
              0.27757990076921996`, 0.4084785604235946, 0.9391413214744782], 
             UndirectedEdge[321, 482] -> 
             RGBColor[
              0.3618096126655037, 0.4878030342361387, 0.9442751664767356], 
             UndirectedEdge[212, 300] -> 
             RGBColor[
              0.30538405486335696`, 0.43291532798530064`, 0.9409000083423983],
              UndirectedEdge[376, 414] -> 
             RGBColor[
              0.41066703083023803`, 0.5286295424447172, 0.9478003773681193], 
             UndirectedEdge[140, 274] -> 
             RGBColor[
              0.45514730654785085`, 0.5672316914168991, 0.9506137410465527], 
             UndirectedEdge[1, 131] -> 
             RGBColor[
              0.6725225989280954, 0.7384141156269481, 0.9434176348300398], 
             UndirectedEdge[360, 466] -> 
             RGBColor[
              0.37452709066368806`, 0.4988182744791362, 0.9450855129291558], 
             UndirectedEdge[165, 182] -> 
             RGBColor[
              0.33515179918785437`, 0.46471337606246244`, 0.9425765541745187],
              UndirectedEdge[268, 480] -> 
             RGBColor[
              0.33095069928943444`, 0.46107459448387145`, 0.9423088638038781],
              UndirectedEdge[54, 385] -> 
             RGBColor[
              0.34437354114380236`, 0.46838362763676655`, 0.9433222277130192],
              UndirectedEdge[149, 158] -> 
             RGBColor[
              0.8147215713201446, 0.8513363747261626, 0.7016903102859868], 
             UndirectedEdge[229, 379] -> 
             RGBColor[
              0.6289539291610962, 0.7058401988723715, 0.9662183615212638], 
             UndirectedEdge[98, 253] -> 
             RGBColor[
              0.3692124551346022, 0.49231149604718455`, 0.9448165658146812], 
             UndirectedEdge[121, 469] -> 
             RGBColor[
              0.2680978823513436, 0.3991182511117488, 0.9385791498334102], 
             UndirectedEdge[34, 269] -> 
             RGBColor[
              0.39256808517382463`, 0.5103444179698239, 0.9467243511658298], 
             UndirectedEdge[145, 286] -> 
             RGBColor[
              0.6630260751184288, 0.7306656605601565, 0.9497734279093044], 
             UndirectedEdge[34, 234] -> 
             RGBColor[
              0.30375054752969555`, 0.4348301315190519, 0.9406740073354232], 
             UndirectedEdge[85, 286] -> 
             RGBColor[
              0.5199062853334456, 0.6183300836254461, 0.9563070089217188], 
             UndirectedEdge[86, 261] -> 
             RGBColor[
              0.5162136547788927, 0.6150895753614948, 0.9560895522597525], 
             UndirectedEdge[140, 255] -> 
             RGBColor[
              0.6762032847137347, 0.7427445137729405, 0.9603244355077571], 
             UndirectedEdge[345, 448] -> 
             RGBColor[
              0.5432242519342643, 0.6400529455507291, 0.9571837494897176], 
             UndirectedEdge[146, 444] -> 
             RGBColor[
              0.48818965392040903`, 0.5936902453450505, 0.9533162793459806], 
             UndirectedEdge[215, 224] -> 
             RGBColor[
              0.5916449434614959, 0.6696943495634888, 0.9647930239620957], 
             UndirectedEdge[40, 359] -> 
             RGBColor[
              0.2882447867711631, 0.4202939250444978, 0.9397264862354449], 
             UndirectedEdge[88, 495] -> 
             RGBColor[
              0.27815351007429356`, 0.4092855861258514, 0.9391665136247227], 
             UndirectedEdge[341, 403] -> 
             RGBColor[
              0.371796649556267, 0.49645330362784856`, 0.9449115316362251], 
             UndirectedEdge[134, 416] -> 
             RGBColor[
              0.30501617152413396`, 0.432035982327554, 0.9408970972467876], 
             UndirectedEdge[113, 423] -> 
             RGBColor[
              0.3175636113084288, 0.44586492630094204`, 0.9415881929483974], 
             UndirectedEdge[204, 362] -> 
             RGBColor[
              0.5726414253343607, 0.6630833288628731, 0.960058022317742], 
             UndirectedEdge[231, 256] -> 
             RGBColor[
              0.4659369689443951, 0.5761884428255775, 0.951408651037243], 
             UndirectedEdge[183, 407] -> 
             RGBColor[
              0.3369526799615584, 0.4651260128086463, 0.9427333091579388], 
             UndirectedEdge[231, 271] -> 
             RGBColor[
              0.36204768370055795`, 0.48800923940090446`, 0.9442903361525714],
              UndirectedEdge[106, 140] -> 
             RGBColor[
              0.399290237301952, 0.5202668674652611, 0.9466633987357551], 
             UndirectedEdge[96, 147] -> 
             RGBColor[
              0.29522501718230687`, 0.42375817472066035`, 0.9402657881158056],
              UndirectedEdge[149, 275] -> 
             RGBColor[
              0.7935497548939937, 0.8341481403719525, 0.7000235873420012], 
             UndirectedEdge[207, 287] -> 
             RGBColor[
              0.5872585473171144, 0.6607860678247834, 0.9651943276555144], 
             UndirectedEdge[223, 480] -> 
             RGBColor[
              0.6649362729678954, 0.7300884578276876, 0.9019567126810772], 
             UndirectedEdge[11, 102] -> 
             RGBColor[
              0.33057998208996875`, 0.4594426626269599, 0.942333238131584], 
             UndirectedEdge[230, 339] -> 
             RGBColor[
              0.27772791775766925`, 0.40924002890330735`, 0.9391275661034398],
              UndirectedEdge[103, 449] -> 
             RGBColor[
              0.6803883474433542, 0.7437534799280077, 0.9132773147677744], 
             UndirectedEdge[226, 396] -> 
             RGBColor[
              0.29717600385712306`, 0.4279565736905826, 0.9402982528707621], 
             UndirectedEdge[144, 279] -> 
             RGBColor[
              0.4735911404737415, 0.5810936030970746, 0.9523728521241159], 
             UndirectedEdge[205, 228] -> 
             RGBColor[
              0.6127217207992544, 0.6897810840311523, 0.966104581504134], 
             UndirectedEdge[267, 406] -> 
             RGBColor[
              0.3928352379506179, 0.5091919583466042, 0.9468700288267308], 
             UndirectedEdge[209, 233] -> 
             RGBColor[
              0.6159550820654325, 0.6817656371160807, 0.8997822624411447], 
             UndirectedEdge[387, 405] -> 
             RGBColor[
              0.5108324625711065, 0.6137540222607692, 0.9546342491328474], 
             UndirectedEdge[75, 206] -> 
             RGBColor[
              0.3002051243328305, 0.42976870572078646`, 0.9405209801992818], 
             UndirectedEdge[183, 404] -> 
             RGBColor[
              0.45406559724917184`, 0.5656131230894246, 0.9507331563352998], 
             UndirectedEdge[319, 488] -> 
             RGBColor[
              0.4130757147970294, 0.5322071551932519, 0.9475417971717224], 
             UndirectedEdge[220, 371] -> 
             RGBColor[
              0.3726560931529739, 0.4971977104744248, 0.9449662946222311], 
             UndirectedEdge[66, 460] -> 
             RGBColor[
              0.3146617898108838, 0.44334433083631286`, 0.9414035544728954], 
             UndirectedEdge[87, 446] -> 
             RGBColor[
              0.5308553544290888, 0.6300113173435451, 0.9562100245693458], 
             UndirectedEdge[273, 308] -> 
             RGBColor[
              0.4151576377001212, 0.5340104121714224, 0.9476744554581351], 
             UndirectedEdge[326, 428] -> 
             RGBColor[
              0.3492327395485709, 0.4732892721331343, 0.943606336407321], 
             UndirectedEdge[130, 315] -> 
             RGBColor[
              0.6995377576722231, 0.7203091043885625, 0.631132610970847], 
             UndirectedEdge[95, 407] -> 
             RGBColor[
              0.6379425742287168, 0.7065336556904915, 0.9298465348702545], 
             UndirectedEdge[148, 153] -> 
             RGBColor[
              0.416562175896244, 0.5328257723544849, 0.9483400049463517], 
             UndirectedEdge[85, 137] -> 
             RGBColor[
              0.5237654517106299, 0.6216726995740212, 0.9565529115907461], 
             UndirectedEdge[289, 359] -> 
             RGBColor[
              0.3206825763638751, 0.4508772516486765, 0.9417023196698447], 
             UndirectedEdge[32, 449] -> 
             RGBColor[
              0.5618071771172461, 0.6513751251707354, 0.9603513523662934], 
             UndirectedEdge[329, 406] -> 
             RGBColor[
              0.518398707416028, 0.6198984501327894, 0.9552293916862762], 
             UndirectedEdge[168, 213] -> 
             RGBColor[
              0.2592377240497772, 0.38980566297032015`, 0.9380745769255656], 
             UndirectedEdge[111, 464] -> 
             RGBColor[
              0.41332691110907294`, 0.5324247288132502, 0.9475578031786016], 
             UndirectedEdge[50, 117] -> 
             RGBColor[
              0.2981969169982386, 0.4307542449146555, 0.9402932453290195], 
             UndirectedEdge[357, 420] -> 
             RGBColor[
              0.5020566025362211, 0.6037816835744894, 0.954783599799748], 
             UndirectedEdge[153, 190] -> 
             RGBColor[
              0.5103294353987665, 0.6133474515926148, 0.9545941490343599], 
             UndirectedEdge[165, 275] -> 
             RGBColor[
              0.45796533451270655`, 0.5672556007925122, 0.951461106822642], 
             UndirectedEdge[152, 301] -> 
             RGBColor[
              0.3176209251944845, 0.4435465003835092, 0.9416785515201785], 
             UndirectedEdge[208, 349] -> 
             RGBColor[
              0.3632228273169409, 0.4889431467357205, 0.9443682888291496], 
             UndirectedEdge[5, 23] -> 
             RGBColor[
              0.302804340286726, 0.43559693891836465`, 0.9405556312692269], 
             UndirectedEdge[56, 227] -> 
             RGBColor[
              0.4305667264544364, 0.5470756946612705, 0.948734031809477], 
             UndirectedEdge[56, 326] -> 
             RGBColor[
              0.44627705433517784`, 0.5606831910475301, 0.9497350800099404], 
             UndirectedEdge[155, 181] -> 
             RGBColor[
              0.38578557573113614`, 0.5085698083766469, 0.9458028936421661], 
             UndirectedEdge[148, 323] -> 
             RGBColor[
              0.3056638169844005, 0.43860243022891465`, 0.9407184742369428], 
             UndirectedEdge[177, 438] -> 
             RGBColor[
              0.27413102039095727`, 0.40545946171442804`, 0.9389227281195384],
              UndirectedEdge[53, 90] -> 
             RGBColor[
              0.47548786603803767`, 0.5822063427685389, 0.9526401804076441], 
             UndirectedEdge[30, 217] -> 
             RGBColor[
              0.6624922026284216, 0.7282808373558385, 0.9131697584147656], 
             UndirectedEdge[43, 290] -> 
             RGBColor[
              0.3001717998507125, 0.42925533292995127`, 0.9405365970333186], 
             UndirectedEdge[114, 397] -> 
             RGBColor[
              0.31519734145442874`, 0.4470179092949167, 0.941320156123933], 
             UndirectedEdge[227, 320] -> 
             RGBColor[
              0.4006858865046886, 0.521475708657303, 0.9467523282688293], 
             UndirectedEdge[298, 432] -> 
             RGBColor[
              0.41030711497945543`, 0.5264272826351502, 0.9479677700599045], 
             UndirectedEdge[42, 85] -> 
             RGBColor[
              0.5190277292398966, 0.6175691224947271, 0.9562510281043145], 
             UndirectedEdge[329, 413] -> 
             RGBColor[
              0.46769607252273754`, 0.5777227381392926, 0.9515177974297927], 
             UndirectedEdge[244, 380] -> 
             RGBColor[
              0.29588202583844003`, 0.42797607120929815`, 0.9401740506366572],
              UndirectedEdge[87, 113] -> 
             RGBColor[
              0.3999447323097625, 0.5151307871158021, 0.9474145109781487], 
             UndirectedEdge[334, 370] -> 
             RGBColor[
              0.36601103268831825`, 0.48749955086532454`, 0.9447506200477787],
              UndirectedEdge[24, 278] -> 
             RGBColor[
              0.4084167020694525, 0.5232067803710363, 0.9479724000026851], 
             UndirectedEdge[51, 325] -> 
             RGBColor[
              0.5796021720962505, 0.6597867053986004, 0.9636905889524076], 
             UndirectedEdge[112, 463] -> 
             RGBColor[
              0.35894411454864483`, 0.48418357825492714`, 0.9441342291204902],
              UndirectedEdge[308, 421] -> 
             RGBColor[
              0.40985526077792944`, 0.529417759786633, 0.9473365926893609], 
             UndirectedEdge[302, 421] -> 
             RGBColor[
              0.35361048619004554`, 0.48070136298317584`, 0.9437527253879223],
              UndirectedEdge[103, 488] -> 
             RGBColor[
              0.6999349462768601, 0.7606837613969674, 0.9145228067610667], 
             UndirectedEdge[225, 424] -> 
             RGBColor[
              0.5763338859035853, 0.6584724605116148, 0.9631831584201769], 
             UndirectedEdge[205, 388] -> 
             RGBColor[
              0.43005835346268173`, 0.5447700919541556, 0.9492170199304535], 
             UndirectedEdge[114, 297] -> 
             RGBColor[
              0.2933797360801274, 0.4240862227304488, 0.9400776757741212], 
             UndirectedEdge[203, 381] -> 
             RGBColor[
              0.4227097202605666, 0.5405516465065738, 0.9481556674808423], 
             UndirectedEdge[17, 252] -> 
             RGBColor[
              0.3436217141108935, 0.4676945651700801, 0.9432757084805137], 
             UndirectedEdge[361, 363] -> 
             RGBColor[
              0.44137201916498003`, 0.5558718494698878, 0.9495780517119415], 
             UndirectedEdge[318, 383] -> 
             RGBColor[
              0.5118531007764464, 0.6092862117898428, 0.9566003604014361], 
             UndirectedEdge[209, 273] -> 
             RGBColor[
              0.6861801601705063, 0.7485087039555498, 0.9040402687587413], 
             UndirectedEdge[47, 230] -> 
             RGBColor[
              0.3210908397267045, 0.4489141729604458, 0.9418131594355765], 
             UndirectedEdge[1, 170] -> 
             RGBColor[
              0.41427486372531974`, 0.5332457977239594, 0.9476182058810672], 
             UndirectedEdge[139, 247] -> 
             RGBColor[
              0.5115398840220763, 0.6063749966954761, 0.9569912923625159], 
             UndirectedEdge[246, 288] -> 
             RGBColor[
              0.9660567116860386, 0.9740058172824613, 0.9333887379850832], 
             UndirectedEdge[1, 147] -> 
             RGBColor[
              0.36455967170552855`, 0.4901849971546218, 0.9444503978069843], 
             UndirectedEdge[352, 457] -> 
             RGBColor[
              0.4171563402608336, 0.5288661882335108, 0.9487911139789992], 
             UndirectedEdge[157, 238] -> 
             RGBColor[
              0.2937179639057038, 0.4170090521913571, 0.9403690837860388], 
             UndirectedEdge[97, 145] -> 
             RGBColor[
              0.9580190724886224, 0.9682112735162502, 0.9559469392839984], 
             UndirectedEdge[83, 237] -> 
             RGBColor[
              0.31565396174648597`, 0.44218351844174825`, 0.9415407435451852],
              UndirectedEdge[73, 494] -> 
             RGBColor[
              0.3782915600424848, 0.5011378551850044, 0.9453834658335565], 
             UndirectedEdge[101, 197] -> 
             RGBColor[
              0.49513569230815146`, 0.5947949614448291, 0.9551607502499132], 
             UndirectedEdge[224, 356] -> 
             RGBColor[
              0.5821639119995478, 0.6597291843648669, 0.964253093246267], 
             UndirectedEdge[182, 441] -> 
             RGBColor[
              0.5493319216108941, 0.6405286280070666, 0.9595738177528057], 
             UndirectedEdge[160, 480] -> 
             RGBColor[
              0.3735759949406504, 0.497994483167302, 0.9450249099507047], 
             UndirectedEdge[263, 440] -> 
             RGBColor[
              0.4249184865878297, 0.5402301712511843, 0.9489138341018561], 
             UndirectedEdge[31, 223] -> 
             RGBColor[
              0.613558374233379, 0.6792185733957268, 0.8989161561637699], 
             UndirectedEdge[5, 102] -> 
             RGBColor[
              0.2983902389163333, 0.4309574385078906, 0.9403042547262608], 
             UndirectedEdge[171, 216] -> 
             RGBColor[
              0.5417716887814026, 0.6294375602705263, 0.9600923415228713], 
             UndirectedEdge[102, 414] -> 
             RGBColor[
              0.3038298248510387, 0.43627302092859466`, 0.9406287417665546], 
             UndirectedEdge[68, 205] -> 
             RGBColor[
              0.41753786970680307`, 0.5346053991997678, 0.9482313615851475], 
             UndirectedEdge[111, 376] -> 
             RGBColor[
              0.47874192846171926`, 0.5875925972292654, 0.9521380496489289], 
             UndirectedEdge[302, 325] -> 
             RGBColor[
              0.60310546796405, 0.6822815638009367, 0.9651099343915404], 
             UndirectedEdge[39, 315] -> 
             RGBColor[
              0.531385348680899, 0.6299556839958895, 0.9563860050878072], 
             UndirectedEdge[66, 314] -> 
             RGBColor[
              0.3835086758967493, 0.5065976721804142, 0.9456578115981024], 
             UndirectedEdge[274, 370] -> 
             RGBColor[
              0.38721188495889286`, 0.5047113578260877, 0.946419628799799], 
             UndirectedEdge[94, 477] -> 
             RGBColor[
              0.43900039322554124`, 0.5471097092460567, 0.950464376823412], 
             UndirectedEdge[99, 329] -> 
             RGBColor[
              0.4045994763202169, 0.5213214052682231, 0.9475614227019227], 
             UndirectedEdge[25, 465] -> 
             RGBColor[
              0.4105105760692759, 0.529985360954893, 0.947378348800253], 
             UndirectedEdge[223, 381] -> 
             RGBColor[
              0.7131042675761929, 0.7718091537635924, 0.9050259347042328], 
             UndirectedEdge[196, 318] -> 
             RGBColor[
              0.6294570742044994, 0.708918891734257, 0.9647529295295946], 
             UndirectedEdge[76, 462] -> 
             RGBColor[
              0.556940311430262, 0.6460302223982066, 0.9605192845167096], 
             UndirectedEdge[89, 440] -> 
             RGBColor[
              0.40126222915590026`, 0.5210249557656913, 0.9470515268610884], 
             UndirectedEdge[88, 326] -> 
             RGBColor[
              0.3709838309284025, 0.49574928098584436`, 0.9448597395520049], 
             UndirectedEdge[149, 282] -> 
             RGBColor[
              0.6304289004207247, 0.6929478718292402, 0.6887078426056807], 
             UndirectedEdge[238, 462] -> 
             RGBColor[
              0.5909698695679608, 0.675504915281758, 0.962687617870087], 
             UndirectedEdge[168, 261] -> 
             RGBColor[
              0.4652535943065763, 0.5661778503055583, 0.9530171735363199], 
             UndirectedEdge[155, 344] -> 
             RGBColor[
              0.6013833629120358, 0.6849054909923609, 0.9631899283309231], 
             UndirectedEdge[4, 496] -> 
             RGBColor[
              0.47771561126477374`, 0.5832558646224933, 0.9530252877866925], 
             UndirectedEdge[87, 226] -> 
             RGBColor[
              0.39859474150828733`, 0.5137118611890912, 0.947337630999137], 
             UndirectedEdge[128, 362] -> 
             RGBColor[
              0.7357452483314604, 0.7934890469583116, 0.9742958684895717], 
             UndirectedEdge[295, 389] -> 
             RGBColor[
              0.6491031962247988, 0.7164816355091087, 0.9048803954855953], 
             UndirectedEdge[89, 133] -> 
             RGBColor[
              0.45326292002459795`, 0.5660653405654396, 0.9503649649008364], 
             UndirectedEdge[33, 164] -> 
             RGBColor[
              0.3296555491842518, 0.45928461751710903`, 0.9422508034387677], 
             UndirectedEdge[276, 396] -> 
             RGBColor[
              0.36059204459383143`, 0.48674843796920675`, 0.9441975841158619],
              UndirectedEdge[50, 274] -> 
             RGBColor[
              0.40294335112475654`, 0.5212461261989743, 0.9473155125253263], 
             UndirectedEdge[21, 375] -> 
             RGBColor[
              0.6278903931636627, 0.6913169147132946, 0.7922839514963902], 
             UndirectedEdge[41, 485] -> 
             RGBColor[
              0.37711829797724794`, 0.5010626480162753, 0.9452506223678611], 
             UndirectedEdge[30, 316] -> 
             RGBColor[
              0.662671851949086, 0.7284364405679605, 0.9131812055106208], 
             UndirectedEdge[285, 324] -> 
             RGBColor[
              0.6067967233903968, 0.6787370291925006, 0.9563853456665775], 
             UndirectedEdge[95, 358] -> 
             RGBColor[
              0.9843703786021836, 0.9870330698815315, 0.8741287595483702], 
             UndirectedEdge[333, 492] -> 
             RGBColor[
              0.5683020275007401, 0.2925486998669879, 0.5528917696326869], 
             UndirectedEdge[332, 393] -> 
             RGBColor[
              0.372319193409952, 0.4969059048500927, 0.9449448276685145], 
             UndirectedEdge[418, 420] -> 
             RGBColor[
              0.35837256913021753`, 0.4848260398767048, 0.9440561611019255], 
             UndirectedEdge[107, 273] -> 
             RGBColor[
              0.3521157708114935, 0.47940671564885334`, 0.9436574834457259], 
             UndirectedEdge[310, 483] -> 
             RGBColor[
              0.45711990888978227`, 0.5693954318597735, 0.9506136682983737], 
             UndirectedEdge[155, 403] -> 
             RGBColor[
              0.38205624345221806`, 0.5053396481983385, 0.9455652638870724], 
             UndirectedEdge[140, 169] -> 
             RGBColor[
              0.3404849885532439, 0.46631758748386926`, 0.9430267789331938], 
             UndirectedEdge[147, 216] -> 
             RGBColor[
              0.5756161529036197, 0.6611378228678216, 0.9621615217710056], 
             UndirectedEdge[70, 171] -> 
             RGBColor[
              0.3427557622112116, 0.4689136578001418, 0.9431484310526954], 
             UndirectedEdge[7, 402] -> 
             RGBColor[
              0.43067498213772254`, 0.5457103940363199, 0.9491440741199128], 
             UndirectedEdge[185, 409] -> 
             RGBColor[
              0.32953204540702685`, 0.4577661071499622, 0.9422946171935191], 
             UndirectedEdge[126, 481] -> 
             RGBColor[
              0.502732764213554, 0.6071801316983223, 0.9539961112511366], 
             UndirectedEdge[115, 311] -> 
             RGBColor[
              0.32632716973841225`, 0.4547930616474828, 0.9420976237310885], 
             UndirectedEdge[383, 496] -> 
             RGBColor[
              0.313511936208677, 0.4457914476037982, 0.941204219446043], 
             UndirectedEdge[8, 297] -> 
             RGBColor[
              0.27417111575331843`, 0.40550160448246253`, 0.938925011491109], 
             UndirectedEdge[381, 439] -> 
             RGBColor[
              0.4123832504197848, 0.5316073773539542, 0.9474976739539265], 
             UndirectedEdge[16, 276] -> 
             RGBColor[
              0.3439890089579084, 0.4710222216057204, 0.9431889187635627], 
             UndirectedEdge[74, 342] -> 
             RGBColor[
              0.37975387784185444`, 0.5033454548269019, 0.945418559186282], 
             UndirectedEdge[26, 269] -> 
             RGBColor[
              0.4497639048668357, 0.5625696208723373, 0.9502705050708651], 
             UndirectedEdge[127, 315] -> 
             RGBColor[
              0.4790236642835032, 0.5874461097350829, 0.9522639014848744], 
             UndirectedEdge[175, 348] -> 
             RGBColor[
              0.49014735723721914`, 0.5940033244070637, 0.9538230348676577], 
             UndirectedEdge[180, 288] -> 
             RGBColor[
              0.8204234502304203, 0.8603804940182098, 0.9726122266656774], 
             UndirectedEdge[288, 343] -> 
             RGBColor[
              0.6792100213640373, 0.7454001443194669, 0.961265392679445], 
             UndirectedEdge[484, 500] -> 
             RGBColor[
              0.43496851034827405`, 0.5511695943358411, 0.9489367867452085], 
             UndirectedEdge[59, 323] -> 
             RGBColor[
              0.6223882751513576, 0.6964882174941445, 0.9650883133308719], 
             UndirectedEdge[108, 189] -> 
             RGBColor[
              0.3971597116646446, 0.5181962271271654, 0.9465898907507426], 
             UndirectedEdge[59, 74] -> 
             RGBColor[
              0.6835636166774264, 0.7496805220387566, 0.9689788350147674], 
             UndirectedEdge[40, 199] -> 
             RGBColor[
              0.23038512187701934`, 0.3594797487261151, 0.936431463915427], 
             UndirectedEdge[69, 241] -> 
             RGBColor[0.42267406039639, 0.52994969829333, 0.9495346163214369],
              UndirectedEdge[275, 353] -> 
             RGBColor[
              0.4896439928289401, 0.5946940624103709, 0.9534796429182146], 
             UndirectedEdge[196, 335] -> 
             RGBColor[
              0.5317128130928153, 0.6307074409148309, 0.9562775268563288], 
             UndirectedEdge[157, 281] -> 
             RGBColor[
              0.2720428998244823, 0.39823520110460003`, 0.93898796786929], 
             UndirectedEdge[120, 438] -> 
             RGBColor[
              0.5503803585502156, 0.6356038788419159, 0.9610370252831841], 
             UndirectedEdge[152, 389] -> 
             RGBColor[
              0.6889926531561728, 0.7510318782006642, 0.9074221164084006], 
             UndirectedEdge[126, 144] -> 
             RGBColor[
              0.45330076809188175`, 0.5646209647266218, 0.950775519684133], 
             UndirectedEdge[96, 157] -> 
             RGBColor[
              0.21038091805925824`, 0.3384540621738703, 0.9352922541015729], 
             UndirectedEdge[303, 366] -> 
             RGBColor[
              0.4269211542312609, 0.5385983479828317, 0.9493955659950237], 
             UndirectedEdge[119, 309] -> 
             RGBColor[
              0.6928598222038607, 0.7568372920011159, 0.956507191806854], 
             UndirectedEdge[325, 386] -> 
             RGBColor[
              0.5727882902883397, 0.6526248835934267, 0.9633025484636819], 
             UndirectedEdge[27, 220] -> 
             RGBColor[
              0.347111091086442, 0.47076926920370255`, 0.9434961305679785], 
             UndirectedEdge[95, 346] -> 
             RGBColor[
              0.9121226871331408, 0.9316351674977381, 0.9522774777633818], 
             UndirectedEdge[235, 239] -> 
             RGBColor[
              0.5173540726103371, 0.6131913031613252, 0.9572107542365932], 
             UndirectedEdge[64, 303] -> 
             RGBColor[
              0.4191988377599445, 0.5304817037483345, 0.9489557914961256], 
             UndirectedEdge[310, 429] -> 
             RGBColor[
              0.41194046487067854`, 0.5312238587663671, 0.9474694600502773], 
             UndirectedEdge[67, 238] -> 
             RGBColor[
              0.4997137287432839, 0.6034577785185934, 0.9541097234305057], 
             UndirectedEdge[38, 108] -> 
             RGBColor[
              0.41646587603568075`, 0.5349182563493213, 0.9478200624726942], 
             UndirectedEdge[20, 490] -> 
             RGBColor[
              0.4447808230032092, 0.5568341823530331, 0.9503451563294756], 
             UndirectedEdge[112, 148] -> 
             RGBColor[
              0.3006225072516122, 0.4333036940622558, 0.9404313791056098], 
             UndirectedEdge[76, 402] -> 
             RGBColor[
              0.4279248559872297, 0.5433283729901225, 0.9489688385134445], 
             UndirectedEdge[99, 406] -> 
             RGBColor[
              0.40361496365004573`, 0.5205221335307878, 0.9474839182581382], 
             UndirectedEdge[8, 258] -> 
             RGBColor[
              0.2790486396172495, 0.4106281913163286, 0.93920277925951], 
             UndirectedEdge[15, 153] -> 
             RGBColor[
              0.5818145833145869, 0.6713823150398923, 0.9602217217370184], 
             UndirectedEdge[195, 463] -> 
             RGBColor[
              0.7039052967110184, 0.7640430972456915, 0.9118507329403374], 
             UndirectedEdge[184, 249] -> 
             RGBColor[
              0.4449969804835324, 0.5587355292919105, 0.9498853126236007], 
             UndirectedEdge[109, 185] -> 
             RGBColor[
              0.34017423095738986`, 0.4669838333818882, 0.9429727278462732], 
             UndirectedEdge[77, 81] -> 
             RGBColor[
              0.24331894556694805`, 0.37307401747601604`, 0.9371680260406909],
              UndirectedEdge[355, 384] -> 
             RGBColor[
              0.5795722662163834, 0.6561510959862005, 0.9642348937824635], 
             UndirectedEdge[67, 343] -> 
             RGBColor[
              0.5023173793094136, 0.6057129297756925, 0.9542756257422618], 
             UndirectedEdge[247, 255] -> 
             RGBColor[
              0.6173117086722564, 0.6897298352654568, 0.956645356885762], 
             UndirectedEdge[95, 145] -> 
             RGBColor[
              0.9690881669943121, 0.9764665860746148, 0.9372098495680797], 
             UndirectedEdge[220, 416] -> 
             RGBColor[
              0.33482004000627663`, 0.4578505952208002, 0.9427961733919437], 
             UndirectedEdge[287, 451] -> 
             RGBColor[
              0.3173982481531783, 0.44347719646336325`, 0.941659838315704], 
             UndirectedEdge[387, 491] -> 
             RGBColor[
              0.6133024089113671, 0.6967030204619331, 0.9628663777342448], 
             UndirectedEdge[211, 464] -> 
             RGBColor[
              0.3686661932044579, 0.4937418596772226, 0.9447120617256417], 
             UndirectedEdge[335, 482] -> 
             RGBColor[
              0.4208926081333766, 0.5371290870530522, 0.9485506752511617], 
             UndirectedEdge[214, 423] -> 
             RGBColor[
              0.45118738794865654`, 0.5629481175949712, 0.9505972960020923], 
             UndirectedEdge[69, 194] -> 
             RGBColor[
              0.3115285640012022, 0.43782879094642313`, 0.9413064919529002], 
             UndirectedEdge[111, 312] -> 
             RGBColor[
              0.39808142990482903`, 0.5192198592542995, 0.9465863745973169], 
             UndirectedEdge[174, 294] -> 
             RGBColor[
              0.33376343812770215`, 0.4635108474932145, 0.9424880890354452], 
             UndirectedEdge[212, 295] -> 
             RGBColor[
              0.33924973551558013`, 0.46826280254126984`, 0.9428376710536586],
              UndirectedEdge[193, 414] -> 
             RGBColor[
              0.3623596362048085, 0.4882794369808975, 0.9443102134902934], 
             UndirectedEdge[320, 348] -> 
             RGBColor[
              0.5199428123577854, 0.6198106500693803, 0.9557215749208537], 
             UndirectedEdge[247, 468] -> 
             RGBColor[
              0.2807884847498352, 0.41245687886322885`, 0.9393018608659405], 
             UndirectedEdge[449, 488] -> 
             RGBColor[
              0.3943096759744297, 0.5159529555736522, 0.9463460417721028], 
             UndirectedEdge[290, 355] -> 
             RGBColor[
              0.2550441529807731, 0.3853979538890342, 0.9378357592570183], 
             UndirectedEdge[88, 469] -> 
             RGBColor[
              0.290821280190785, 0.422600215701299, 0.9398879243925704], 
             UndirectedEdge[6, 278] -> 
             RGBColor[
              0.29483459115121313`, 0.4271042862441281, 0.9401060110148961], 
             UndirectedEdge[24, 448] -> 
             RGBColor[
              0.5519060104046958, 0.6471011881857875, 0.9578672093188392], 
             UndirectedEdge[204, 274] -> 
             RGBColor[
              0.4783067423045464, 0.587291230642262, 0.9520894398138844], 
             UndirectedEdge[81, 99] -> 
             RGBColor[
              0.2655385767767811, 0.39642825868353804`, 0.9384334011670923], 
             UndirectedEdge[213, 368] -> 
             RGBColor[
              0.25190909938658523`, 0.38210281378766425`, 0.9376572225927254],
              UndirectedEdge[167, 474] -> 
             RGBColor[
              0.3271890950901357, 0.45120150463719955`, 0.9423113844357144], 
             UndirectedEdge[78, 430] -> 
             RGBColor[
              0.396172057527013, 0.5147439955396106, 0.9468739227793312], 
             UndirectedEdge[110, 316] -> 
             RGBColor[
              0.6047745717333237, 0.6838470042864312, 0.9651611622278794], 
             UndirectedEdge[153, 463] -> 
             RGBColor[
              0.47488378319327673`, 0.5837056565471562, 0.9520428549612319], 
             UndirectedEdge[471, 475] -> 
             RGBColor[
              0.3803575977082784, 0.5038683666313555, 0.945457027682322], 
             UndirectedEdge[79, 486] -> 
             RGBColor[
              0.46977747978507484`, 0.5791377886731384, 0.9517575620542431], 
             UndirectedEdge[49, 402] -> 
             RGBColor[
              0.4027273966605131, 0.5195892443497916, 0.9474333726311219], 
             UndirectedEdge[340, 498] -> 
             RGBColor[
              0.30496729274512285`, 0.4334089478466084, 0.9408421616000626], 
             UndirectedEdge[248, 313] -> 
             RGBColor[
              0.2859704148071607, 0.4179034159068199, 0.9395969641167267], 
             UndirectedEdge[37, 429] -> 
             RGBColor[
              0.34809804135923206`, 0.4749201975067414, 0.9434383324736517], 
             UndirectedEdge[18, 166] -> 
             RGBColor[
              0.3171725881186397, 0.44848376905127524`, 0.9414549877311806], 
             UndirectedEdge[147, 238] -> 
             RGBColor[
              0.37856206302875245`, 0.5023131647381471, 0.9453426178002715], 
             UndirectedEdge[165, 441] -> 
             RGBColor[
              0.5356378802435476, 0.628667537657203, 0.9587012455460437], 
             UndirectedEdge[13, 154] -> 
             RGBColor[
              0.47288232775816164`, 0.5816447973904596, 0.952005757694774], 
             UndirectedEdge[133, 249] -> 
             RGBColor[
              0.4563983748855319, 0.5686108440721775, 0.9506117993930387], 
             UndirectedEdge[84, 385] -> 
             RGBColor[
              0.3632749677253083, 0.48825022539359203`, 0.9443986359946812], 
             UndirectedEdge[125, 438] -> 
             RGBColor[
              0.316892576670233, 0.4461176792463657, 0.9415148995087902], 
             UndirectedEdge[21, 489] -> 
             RGBColor[
              0.6634440996946841, 0.7265033251133685, 0.7943886050989002], 
             UndirectedEdge[16, 200] -> 
             RGBColor[
              0.3416503229950991, 0.46899656937050926`, 0.9430398997620313], 
             UndirectedEdge[402, 436] -> 
             RGBColor[
              0.4011189352738116, 0.5178986494500262, 0.9473417731346547], 
             UndirectedEdge[127, 401] -> 
             RGBColor[
              0.42766460134473755`, 0.5429614707990844, 0.9489913474094523], 
             UndirectedEdge[195, 395] -> 
             RGBColor[
              0.6722868693202525, 0.7366568046281785, 0.9098360347060754], 
             UndirectedEdge[27, 297] -> 
             RGBColor[
              0.26143237287013665`, 0.3921123780292901, 0.9381995589291932], 
             UndirectedEdge[35, 70] -> 
             RGBColor[
              0.3488463170160424, 0.47531521706349744`, 0.9434952791386622], 
             UndirectedEdge[240, 367] -> 
             RGBColor[
              0.3377073117551884, 0.4648522554290197, 0.9428153496085196], 
             UndirectedEdge[121, 471] -> 
             RGBColor[
              0.33762234159930604`, 0.46305313623398003`, 0.9428731152100187],
              UndirectedEdge[184, 424] -> 
             RGBColor[
              0.34561518087125964`, 0.4725803309593164, 0.9432870593753431], 
             UndirectedEdge[122, 159] -> 
             RGBColor[
              0.4071163362001683, 0.5258167427228579, 0.9475015638264839], 
             UndirectedEdge[158, 324] -> 
             RGBColor[
              0.7920003278557293, 0.8380829810237211, 0.9694196896658569], 
             UndirectedEdge[180, 465] -> 
             RGBColor[
              0.5447229930760021, 0.6389017860618889, 0.9582790845015396], 
             UndirectedEdge[254, 454] -> 
             RGBColor[
              0.5467356444446615, 0.6400569173166564, 0.9586562517498833], 
             UndirectedEdge[297, 314] -> 
             RGBColor[
              0.3339621422504313, 0.4592366632241241, 0.9426635508096802], 
             UndirectedEdge[262, 393] -> 
             RGBColor[
              0.6255224603340399, 0.5844442655234194, 0.5968710928336387], 
             UndirectedEdge[201, 333] -> 
             RGBColor[
              0.5600085236078682, 0.28480610908069237`, 0.5523837890180403], 
             UndirectedEdge[219, 340] -> 
             RGBColor[
              0.3880957079074221, 0.5105707287571265, 0.9459500932216693], 
             UndirectedEdge[361, 370] -> 
             RGBColor[
              0.37668572915291454`, 0.49616575034487936`, 0.9455909712561732],
              UndirectedEdge[48, 358] -> 
             RGBColor[
              0.7726274773585057, 0.8201369665036911, 0.8934730813080645], 
             UndirectedEdge[287, 299] -> 
             RGBColor[
              0.34917438990573596`, 0.471000093334106, 0.9436845859696381], 
             UndirectedEdge[62, 233] -> 
             RGBColor[
              0.2881270786100112, 0.4180652928292059, 0.9397968541232865], 
             UndirectedEdge[61, 91] -> 
             RGBColor[
              0.7025306481104636, 0.7593585658722024, 0.7114479037685224], 
             UndirectedEdge[204, 340] -> 
             RGBColor[
              0.4040769169147942, 0.5244128487603923, 0.9469684017279908], 
             UndirectedEdge[258, 373] -> 
             RGBColor[
              0.3714718991961677, 0.4921059121352941, 0.9451647733989883], 
             UndirectedEdge[167, 210] -> 
             RGBColor[
              0.3737838229234033, 0.49817449332022434`, 0.9450381525659906], 
             UndirectedEdge[275, 481] -> 
             RGBColor[
              0.528615923558373, 0.6281932464774869, 0.9560337283678975], 
             UndirectedEdge[253, 277] -> 
             RGBColor[
              0.2931408020837776, 0.42543994756335574`, 0.9400053070644926], 
             UndirectedEdge[193, 485] -> 
             RGBColor[
              0.3807203170044394, 0.5041825358548883, 0.9454801398351333], 
             UndirectedEdge[89, 260] -> 
             RGBColor[
              0.39321383993038783`, 0.5130717394586977, 0.9465746503312382], 
             UndirectedEdge[359, 397] -> 
             RGBColor[
              0.2994685392679638, 0.43209080054564525`, 0.9403656623360838], 
             UndirectedEdge[1, 171] -> 
             RGBColor[
              0.33071520758331147`, 0.4584847345573265, 0.94238121755885], 
             UndirectedEdge[193, 330] -> 
             RGBColor[
              0.32574418023935864`, 0.4501960384935544, 0.9422103067723153], 
             UndirectedEdge[92, 320] -> 
             RGBColor[
              0.5148246047557363, 0.6156554585654119, 0.9553186508698083], 
             UndirectedEdge[126, 279] -> 
             RGBColor[
              0.5629969648971269, 0.6561053246845492, 0.9587403298839883], 
             UndirectedEdge[93, 163] -> 
             RGBColor[
              0.281463091768137, 0.4109913449418686, 0.9394199010813413], 
             UndirectedEdge[31, 297] -> 
             RGBColor[
              0.2502580420536967, 0.3803674478477173, 0.9375631973201379], 
             UndirectedEdge[127, 325] -> 
             RGBColor[
              0.6981009856104814, 0.7626800619096967, 0.971682924062089], 
             UndirectedEdge[334, 498] -> 
             RGBColor[
              0.35799626586430033`, 0.47907552276771487`, 0.9442941909339357],
              UndirectedEdge[41, 300] -> 
             RGBColor[
              0.3240576862900265, 0.44908948896307627`, 0.9420898756244618], 
             UndirectedEdge[330, 496] -> 
             RGBColor[
              0.2800348858510065, 0.4106049451103001, 0.9392977509530316], 
             UndirectedEdge[18, 227] -> 
             RGBColor[
              0.34954820778573636`, 0.4765259035609556, 0.9435179335877316], 
             UndirectedEdge[156, 350] -> 
             RGBColor[
              0.6954369645977737, 0.7605323868008227, 0.9714558260127462], 
             UndirectedEdge[315, 386] -> 
             RGBColor[
              0.3537109689613614, 0.47739093141881295`, 0.9438835258864673], 
             UndirectedEdge[29, 479] -> 
             RGBColor[
              0.6726352248748313, 0.7419110717554964, 0.9697872082185981], 
             UndirectedEdge[277, 488] -> 
             RGBColor[
              0.355989977284981, 0.4817802524892497, 0.9439403041710785], 
             UndirectedEdge[242, 374] -> 
             RGBColor[
              0.7112101961776649, 0.5678937746676196, 0.5841220530404486], 
             UndirectedEdge[244, 363] -> 
             RGBColor[
              0.3554076101271591, 0.4822579414114281, 0.9438672365360609], 
             UndirectedEdge[335, 409] -> 
             RGBColor[
              0.4471075435592875, 0.5598351465180107, 0.9502210677555436], 
             UndirectedEdge[235, 332] -> 
             RGBColor[
              0.3566845574009583, 0.4829165792887333, 0.9439649836145992], 
             UndirectedEdge[249, 440] -> 
             RGBColor[
              0.40439768401683424`, 0.5235704592724294, 0.9472983613532908], 
             UndirectedEdge[96, 265] -> 
             RGBColor[
              0.4796615084756891, 0.5750985212043622, 0.9548228688887198], 
             UndirectedEdge[39, 200] -> 
             RGBColor[
              0.5082278305575085, 0.6098978057281124, 0.954910428510374], 
             UndirectedEdge[146, 312] -> 
             RGBColor[
              0.4659857283324384, 0.5744583210024996, 0.9519014648416755], 
             UndirectedEdge[237, 448] -> 
             RGBColor[
              0.407186385466097, 0.5183871336125985, 0.9482233398026654], 
             UndirectedEdge[31, 162] -> 
             RGBColor[
              0.2782434641349278, 0.4090533056593062, 0.9391836031453751], 
             UndirectedEdge[41, 102] -> 
             RGBColor[
              0.34949598398939996`, 0.4758267527263475, 0.943538549045852], 
             UndirectedEdge[266, 374] -> 
             RGBColor[
              0.5678682426040771, 0.4429116363762926, 0.5743487454212857], 
             UndirectedEdge[44, 139] -> 
             RGBColor[
              0.5049671832818395, 0.599466671484191, 0.9566169867787988], 
             UndirectedEdge[47, 189] -> 
             RGBColor[
              0.35264835644784487`, 0.4798680145585285, 0.9436914193315271], 
             UndirectedEdge[208, 359] -> 
             RGBColor[
              0.35662695001459943`, 0.4820104614881845, 0.9439926633745073], 
             UndirectedEdge[122, 413] -> 
             RGBColor[
              0.3658357920067071, 0.4912903084198314, 0.9445317110641465], 
             UndirectedEdge[36, 141] -> 
             RGBColor[
              0.6186065709622078, 0.6848802350846603, 0.9084813810100438], 
             UndirectedEdge[179, 347] -> 
             RGBColor[
              0.4106279204183106, 0.529126334524979, 0.947651260261146], 
             UndirectedEdge[226, 422] -> 
             RGBColor[
              0.4189208620668843, 0.5302135215398563, 0.9489377776665427], 
             UndirectedEdge[18, 167] -> 
             RGBColor[
              0.3594098577067304, 0.48506756906158355`, 0.9441463092003828], 
             UndirectedEdge[112, 452] -> 
             RGBColor[
              0.37048622610921705`, 0.4941807751652999, 0.9448696822628413], 
             UndirectedEdge[323, 342] -> 
             RGBColor[
              0.3185785363157856, 0.45015315028228975`, 0.9415280375023865], 
             UndirectedEdge[74, 82] -> 
             RGBColor[
              0.37408062940951475`, 0.4984315721805664, 0.9450570648128299], 
             UndirectedEdge[291, 349] -> 
             RGBColor[
              0.35308750401274513`, 0.4801644391057873, 0.9437224749905208], 
             UndirectedEdge[86, 136] -> 
             RGBColor[
              0.31092054093798516`, 0.4394770508447623, 0.9411881155576609], 
             UndirectedEdge[11, 23] -> 
             RGBColor[
              0.33499408346036136`, 0.46408216303743394`, 0.94258461467455], 
             UndirectedEdge[249, 470] -> 
             RGBColor[
              0.4644939565251829, 0.575622829992679, 0.9511276426964757], 
             UndirectedEdge[35, 135] -> 
             RGBColor[
              0.38471012388502135`, 0.5058089722364981, 0.9459378912065028], 
             UndirectedEdge[161, 326] -> 
             RGBColor[
              0.5463007681302017, 0.6415596429608277, 0.9578330933492303], 
             UndirectedEdge[26, 139] -> 
             RGBColor[
              0.5650620795271388, 0.6547389876552292, 0.9603282388046875], 
             UndirectedEdge[109, 218] -> 
             RGBColor[
              0.3459690003576341, 0.4730745034311455, 0.9433027313910239], 
             UndirectedEdge[238, 465] -> 
             RGBColor[
              0.4009059136434896, 0.521666285106047, 0.9467663482035513], 
             UndirectedEdge[258, 314] -> 
             RGBColor[
              0.3388396661143624, 0.4643632500579902, 0.9429413185780813], 
             UndirectedEdge[28, 493] -> 
             RGBColor[
              0.47128051336646537`, 0.580203095931541, 0.9519186920815172], 
             UndirectedEdge[106, 466] -> 
             RGBColor[
              0.3678461363432858, 0.4930315676413316, 0.9446598084275957], 
             UndirectedEdge[45, 236] -> 
             RGBColor[
              0.6159363616014903, 0.6819705081471716, 0.9056382924259929], 
             UndirectedEdge[157, 246] -> 
             RGBColor[
              0.5831683047938345, 0.6478698764114506, 0.9126583314034329], 
             UndirectedEdge[371, 427] -> 
             RGBColor[
              0.4561820090640404, 0.5655862932050265, 0.9513819245554118], 
             UndirectedEdge[341, 450] -> 
             RGBColor[
              0.47038299525842886`, 0.5798976597940178, 0.9517311021238277], 
             UndirectedEdge[277, 484] -> 
             RGBColor[
              0.3746188836723846, 0.4979156748859591, 0.9451273216131888], 
             UndirectedEdge[84, 135] -> 
             RGBColor[
              0.38707682993947834`, 0.5082965303575633, 0.9460726716150762], 
             UndirectedEdge[35, 84] -> 
             RGBColor[
              0.29748837997318917`, 0.43000952757748645`, 0.9402528951936295],
              UndirectedEdge[68, 272] -> 
             RGBColor[
              0.42325199934515084`, 0.5395546910919984, 0.9485954608728966], 
             UndirectedEdge[164, 227] -> 
             RGBColor[
              0.37762380976204457`, 0.5015004969165051, 0.9452828331317817], 
             UndirectedEdge[355, 498] -> 
             RGBColor[
              0.2550441529807731, 0.3853979538890342, 0.9378357592570183], 
             UndirectedEdge[223, 373] -> 
             RGBColor[
              0.729894707511919, 0.7858304508494374, 0.9062399644742192], 
             UndirectedEdge[116, 192] -> 
             RGBColor[
              0.6018699039087302, 0.6815046714495165, 0.96489618732436], 
             UndirectedEdge[3, 31] -> 
             RGBColor[
              0.23998379470269726`, 0.3695685624569103, 0.9369780941328854], 
             UndirectedEdge[40, 419] -> 
             RGBColor[
              0.29857124959206127`, 0.43054179896478695`, 0.9403367477360213],
              UndirectedEdge[282, 324] -> 
             RGBColor[
              0.6077076569563093, 0.6796944781267988, 0.9564372219855508], 
             UndirectedEdge[250, 339] -> 
             RGBColor[
              0.28178128707424543`, 0.4135003770534871, 0.9393583994895962], 
             UndirectedEdge[259, 405] -> 
             RGBColor[
              0.40512556741087413`, 0.5253211371133903, 0.9470352208103158], 
             UndirectedEdge[22, 441] -> 
             RGBColor[
              0.6555518699035459, 0.729599431251799, 0.9671520624454419], 
             UndirectedEdge[142, 241] -> 
             RGBColor[
              0.5053030660028452, 0.6079421160307494, 0.9545644740574512], 
             UndirectedEdge[170, 266] -> 
             RGBColor[
              0.35981742546159057`, 0.48245587284871605`, 0.9442808316469976],
              UndirectedEdge[105, 153] -> 
             RGBColor[
              0.4382875826871626, 0.55200786704728, 0.9497109774257319], 
             UndirectedEdge[95, 404] -> 
             RGBColor[
              0.7550554915163303, 0.8070207659712698, 0.9378463820476153], 
             UndirectedEdge[200, 454] -> 
             RGBColor[
              0.38730110240461035`, 0.5098824814086248, 0.9458994616616723], 
             UndirectedEdge[96, 131] -> 
             RGBColor[
              0.6031879444048738, 0.6719872931929867, 0.9392330251388612], 
             UndirectedEdge[190, 395] -> 
             RGBColor[
              0.42527255261217844`, 0.5417119957331848, 0.9486116973500172], 
             UndirectedEdge[297, 381] -> 
             RGBColor[
              0.3498039353965106, 0.47295802821558297`, 0.9436729758606008], 
             UndirectedEdge[203, 419] -> 
             RGBColor[
              0.36088318157861665`, 0.4870006061924574, 0.94421613510709], 
             UndirectedEdge[107, 209] -> 
             RGBColor[
              0.653104063432264, 0.7198598514138442, 0.9019326891226245], 
             UndirectedEdge[205, 252] -> 
             RGBColor[
              0.3766714508821293, 0.5006756115216716, 0.9452221496660915], 
             UndirectedEdge[98, 488] -> 
             RGBColor[
              0.43206163033580564`, 0.5486518009730785, 0.9487515629212673], 
             UndirectedEdge[182, 275] -> 
             RGBColor[
              0.4716593758800529, 0.5791166911423757, 0.9523336790294039], 
             UndirectedEdge[88, 474] -> 
             RGBColor[
              0.2751454001607363, 0.4061238718815185, 0.9389952062152455], 
             UndirectedEdge[47, 242] -> 
             RGBColor[
              0.4644256428255432, 0.5738887956494452, 0.9515860598457807], 
             UndirectedEdge[133, 262] -> 
             RGBColor[
              0.6670451959385507, 0.6204091721106731, 0.5995168848292446], 
             UndirectedEdge[4, 321] -> 
             RGBColor[
              0.5192295192529861, 0.6192131251721983, 0.955670517294394], 
             UndirectedEdge[369, 370] -> 
             RGBColor[
              0.32817501703482804`, 0.45499235208075095`, 0.9422666725290143],
              UndirectedEdge[49, 436] -> 
             RGBColor[
              0.28643213718846783`, 0.4183887154044636, 0.9396232585232851], 
             UndirectedEdge[34, 393] -> 
             RGBColor[
              0.3074405775344382, 0.43802625004285933`, 0.9409091327843601], 
             UndirectedEdge[268, 324] -> 
             RGBColor[
              0.633234583327866, 0.7055504886002861, 0.9579266205157947], 
             UndirectedEdge[359, 371] -> 
             RGBColor[
              0.3039727708312937, 0.4364040579556005, 0.9406375856372096], 
             UndirectedEdge[296, 440] -> 
             RGBColor[
              0.28520487711232945`, 0.41659263618528886`, 0.9395719005474996],
              UndirectedEdge[113, 143] -> 
             RGBColor[
              0.554424240572547, 0.6376842041647715, 0.9615960661859162], 
             UndirectedEdge[270, 489] -> 
             RGBColor[
              0.6587656532848228, 0.7252144239695353, 0.9188622630222942], 
             UndirectedEdge[237, 426] -> 
             RGBColor[
              0.3960604912234229, 0.5093546314505719, 0.9473474686523886], 
             UndirectedEdge[131, 385] -> 
             RGBColor[
              0.6966250982108044, 0.7592904890787929, 0.9449534247713307], 
             UndirectedEdge[427, 499] -> 
             RGBColor[
              0.48317407227201126`, 0.5889654616952273, 0.9531018349548793], 
             UndirectedEdge[45, 243] -> 
             RGBColor[
              0.27686904734544227`, 0.4083373016445274, 0.9390786547040484], 
             UndirectedEdge[33, 443] -> 
             RGBColor[
              0.31411849854185725`, 0.4458272051655383, 0.9412607963107087], 
             UndirectedEdge[232, 330] -> 
             RGBColor[
              0.30945586401781966`, 0.43608791765703464`, 0.9411724296658713],
              UndirectedEdge[19, 360] -> 
             RGBColor[
              0.41424665673549754`, 0.5332213662470999, 0.9476164085566182], 
             UndirectedEdge[44, 370] -> 
             RGBColor[
              0.27143548841563203`, 0.4026262867017629, 0.9387692215612258], 
             UndirectedEdge[310, 412] -> 
             RGBColor[
              0.4352442125055743, 0.5514083936873013, 0.948954354242878], 
             UndirectedEdge[107, 214] -> 
             RGBColor[
              0.42796994888074125`, 0.5428383388167608, 0.9491179013150601], 
             UndirectedEdge[268, 481] -> 
             RGBColor[
              0.39102199545666044`, 0.5128489884082621, 0.9462073821618209], 
             UndirectedEdge[224, 351] -> 
             RGBColor[
              0.7525706621357885, 0.8067441167667047, 0.9761515452659661], 
             UndirectedEdge[78, 408] -> 
             RGBColor[
              0.29411561593993996`, 0.4264645387329507, 0.9400608212714932], 
             UndirectedEdge[124, 136] -> 
             RGBColor[
              0.30765680285692026`, 0.4366501649591895, 0.9409801530531458], 
             UndirectedEdge[51, 315] -> 
             RGBColor[
              0.3605248507692724, 0.48455275322398655`, 0.9442715663751929], 
             UndirectedEdge[24, 270] -> 
             RGBColor[
              0.7611703946110941, 0.8116356423468114, 0.926016439903443], 
             UndirectedEdge[43, 340] -> 
             RGBColor[
              0.3522042826354822, 0.4794833801420587, 0.9436631233408825], 
             UndirectedEdge[116, 483] -> 
             RGBColor[
              0.6768720591041104, 0.7455071780307665, 0.9699406723574207], 
             UndirectedEdge[50, 169] -> 
             RGBColor[
              0.2882810331301496, 0.4203320222659445, 0.9397285504119675], 
             UndirectedEdge[247, 369] -> 
             RGBColor[
              0.33721886258230793`, 0.46449800716407874`, 0.9427817061537727],
              UndirectedEdge[327, 412] -> 
             RGBColor[
              0.37347256135355766`, 0.49728124547198704`, 0.9450411540886887],
              UndirectedEdge[134, 305] -> 
             RGBColor[
              0.4340507533891986, 0.5492240100169479, 0.9491962414583235], 
             UndirectedEdge[7, 49] -> 
             RGBColor[
              0.31598818405237883`, 0.44620045999075747`, 0.9414255595085431],
              UndirectedEdge[81, 486] -> 
             RGBColor[
              0.3874627687985088, 0.501601512853082, 0.9467409968382463], 
             UndirectedEdge[110, 384] -> 
             RGBColor[
              0.886042967580462, 0.9119706276257535, 0.9889927632993609], 
             UndirectedEdge[18, 88] -> 
             RGBColor[
              0.307366162777331, 0.43998993630590255`, 0.9408301309799139], 
             UndirectedEdge[11, 41] -> 
             RGBColor[
              0.38550777441654693`, 0.5083291908406498, 0.9457851923880505], 
             UndirectedEdge[231, 288] -> 
             RGBColor[
              0.6794083302615758, 0.7455719095192197, 0.9612780287470386], 
             UndirectedEdge[236, 396] -> 
             RGBColor[
              0.6569316754258714, 0.7233345554464896, 0.9080360619359831], 
             UndirectedEdge[46, 418] -> 
             RGBColor[
              0.3985016935326018, 0.5195838704856122, 0.9466131534240539], 
             UndirectedEdge[74, 447] -> 
             RGBColor[
              0.45396897627760774`, 0.5669278397975293, 0.950340616281687], 
             UndirectedEdge[270, 426] -> 
             RGBColor[
              0.7647862872764067, 0.8145711869066203, 0.9263010962195075], 
             UndirectedEdge[383, 479] -> 
             RGBColor[
              0.38270777547462, 0.5055819624590381, 0.9456529509292344], 
             UndirectedEdge[408, 430] -> 
             RGBColor[
              0.3982618387697474, 0.516940488125508, 0.9469929327295508], 
             UndirectedEdge[13, 390] -> 
             RGBColor[
              0.5207328137594756, 0.6204919775661552, 0.9557727232349031], 
             UndirectedEdge[15, 97] -> 
             RGBColor[
              0.7963578966220105, 0.8412829961065864, 0.9607063480560654], 
             UndirectedEdge[289, 472] -> 
             RGBColor[
              0.45420788755801644`, 0.5648910332268415, 0.9509757914100881], 
             UndirectedEdge[254, 315] -> 
             RGBColor[
              0.5716994585160652, 0.6616793183475285, 0.9602469239078792], 
             UndirectedEdge[347, 386] -> 
             RGBColor[
              0.3022784095276858, 0.4328426335129647, 0.94060628867938], 
             UndirectedEdge[66, 445] -> 
             RGBColor[
              0.31092930063350616`, 0.4394212480574067, 0.9411909947359667], 
             UndirectedEdge[127, 213] -> 
             RGBColor[
              0.39198749715925063`, 0.5076776815790421, 0.9468784831017907], 
             UndirectedEdge[423, 446] -> 
             RGBColor[
              0.44847423342775505`, 0.5607454565286851, 0.9503837065395946], 
             UndirectedEdge[63, 410] -> 
             RGBColor[
              0.28925962244254416`, 0.42136058167941726`, 0.9397842796256151],
              UndirectedEdge[107, 421] -> 
             RGBColor[
              0.3468133938893017, 0.47481406326406395`, 0.9433196206769516], 
             UndirectedEdge[226, 308] -> 
             RGBColor[
              0.35603804832766595`, 0.4789399181185898, 0.9440488902947628], 
             UndirectedEdge[51, 386] -> 
             RGBColor[
              0.2788133851312293, 0.4103809239355254, 0.9391893818645589], 
             UndirectedEdge[89, 470] -> 
             RGBColor[
              0.46135850166424885`, 0.573077326485941, 0.9508808082042732], 
             UndirectedEdge[205, 490] -> 
             RGBColor[
              0.4427234244961341, 0.5550521671740603, 0.9502140607158908], 
             UndirectedEdge[270, 345] -> 
             RGBColor[
              0.7524886361406626, 0.804587399711753, 0.9253329800743213], 
             UndirectedEdge[152, 191] -> 
             RGBColor[
              0.35313058003684883`, 0.4802856923940615, 0.943722146192205], 
             UndirectedEdge[85, 404] -> 
             RGBColor[
              0.6014768145103337, 0.6868849680719837, 0.9620841310105401], 
             UndirectedEdge[26, 468] -> 
             RGBColor[
              0.33431068025489763`, 0.46082086982298187`, 0.9426388073081121],
              UndirectedEdge[191, 301] -> 
             RGBColor[
              0.2795496338000646, 0.4105710612964062, 0.9392526824976473], 
             UndirectedEdge[375, 426] -> 
             RGBColor[
              0.4028216683047289, 0.516461057246411, 0.9477325076849037], 
             UndirectedEdge[39, 213] -> 
             RGBColor[
              0.4443491815566465, 0.5501872558398487, 0.9510005867047235], 
             UndirectedEdge[360, 468] -> 
             RGBColor[
              0.34081606562736255`, 0.4664555076624351, 0.9430533247115591], 
             UndirectedEdge[80, 278] -> 
             RGBColor[
              0.2790111366744693, 0.4105887733456427, 0.9392006435223993], 
             UndirectedEdge[152, 299] -> 
             RGBColor[
              0.4220870905540861, 0.5400123559490995, 0.9481159940665153], 
             UndirectedEdge[227, 309] -> 
             RGBColor[
              0.4150243931347486, 0.5338950024259632, 0.9476659652322532], 
             UndirectedEdge[98, 115] -> 
             RGBColor[
              0.36719337414137176`, 0.4901893139061705, 0.9447015821390794], 
             UndirectedEdge[213, 261] -> 
             RGBColor[
              0.46736597060769847`, 0.5683980917304308, 0.953137470241688], 
             UndirectedEdge[199, 208] -> 
             RGBColor[
              0.2987672851204557, 0.4211962851698018, 0.9406976410544894], 
             UndirectedEdge[204, 219] -> 
             RGBColor[
              0.4351728492923238, 0.5513465824588031, 0.9489498070420337], 
             UndirectedEdge[52, 166] -> 
             RGBColor[
              0.2889337479711106, 0.4188029576103455, 0.9398468275603991], 
             UndirectedEdge[218, 300] -> 
             RGBColor[
              0.27076658563293476`, 0.4019232274662621, 0.9387311285373041], 
             UndirectedEdge[128, 345] -> 
             RGBColor[
              0.6485812054248707, 0.7235183974233905, 0.9668917850431347], 
             UndirectedEdge[325, 421] -> 
             RGBColor[
              0.6240820954793567, 0.7004504642387409, 0.9664465465479124], 
             UndirectedEdge[257, 272] -> 
             RGBColor[
              0.4850410083278328, 0.5897177921472729, 0.953459718000611], 
             UndirectedEdge[461, 486] -> 
             RGBColor[
              0.4432733401704706, 0.5561812350757589, 0.950068741714691], 
             UndirectedEdge[115, 203] -> 
             RGBColor[
              0.3452934350731086, 0.47122068740818346`, 0.9433061373870055], 
             UndirectedEdge[128, 169] -> 
             RGBColor[
              0.5267482473070391, 0.6167828448046706, 0.9587403238723553], 
             UndirectedEdge[190, 356] -> 
             RGBColor[
              0.3807034271254411, 0.4994401625865766, 0.9459061063988892], 
             UndirectedEdge[46, 272] -> 
             RGBColor[
              0.38631394864942037`, 0.5090274584416696, 0.9458365610972972], 
             UndirectedEdge[121, 450] -> 
             RGBColor[
              0.39631951423967016`, 0.5119474955821528, 0.9471509828627345], 
             UndirectedEdge[255, 269] -> 
             RGBColor[
              0.726501383330681, 0.7848951981816653, 0.9639203547447541], 
             UndirectedEdge[15, 356] -> 
             RGBColor[
              0.4521885750412614, 0.5574750260338541, 0.9515336791015474], 
             UndirectedEdge[85, 183] -> 
             RGBColor[
              0.5249784829421704, 0.6227233662580591, 0.9566302048681785], 
             UndirectedEdge[136, 261] -> 
             RGBColor[
              0.4680887270235901, 0.5691577545489364, 0.9531786301503509], 
             UndirectedEdge[295, 336] -> 
             RGBColor[
              0.3207174270552714, 0.45221104841385706`, 0.9416568087460446], 
             UndirectedEdge[259, 475] -> 
             RGBColor[
              0.355057475054105, 0.48195467200944914`, 0.9438449262388182], 
             UndirectedEdge[51, 143] -> 
             RGBColor[
              0.5624115388382291, 0.6460793610659632, 0.9620509310059979], 
             UndirectedEdge[53, 178] -> 
             RGBColor[
              0.4341043152419187, 0.5423541535717342, 0.9501500037085199], 
             UndirectedEdge[67, 385] -> 
             RGBColor[
              0.5098138367027689, 0.6122059843869128, 0.9547532933785093], 
             UndirectedEdge[69, 173] -> 
             RGBColor[
              0.2645439736229312, 0.3953828677073596, 0.9383767599888639], 
             UndirectedEdge[221, 381] -> 
             RGBColor[
              0.39084632085515214`, 0.5129531714426238, 0.9461253598464272], 
             UndirectedEdge[140, 334] -> 
             RGBColor[
              0.43394645427727624`, 0.5500198844561359, 0.9489447322945324], 
             UndirectedEdge[57, 370] -> 
             RGBColor[
              0.29547753312502495`, 0.42667143494140547`, 0.9401832177675313],
              UndirectedEdge[432, 467] -> 
             RGBColor[
              0.4452671555832814, 0.5580931703766907, 0.950144671862496], 
             UndirectedEdge[235, 440] -> 
             RGBColor[
              0.30906377746824437`, 0.4416698532010098, 0.940930629626689], 
             UndirectedEdge[229, 390] -> 
             RGBColor[
              0.7378157416723251, 0.7951684835705669, 0.9745260508664868], 
             UndirectedEdge[12, 198] -> 
             RGBColor[
              0.5011778360989418, 0.6016514911601579, 0.9553070520421321], 
             UndirectedEdge[232, 400] -> 
             RGBColor[
              0.3879707881132026, 0.5104625295100251, 0.9459421334428438], 
             UndirectedEdge[143, 273] -> 
             RGBColor[
              0.6121938391435271, 0.691335772290893, 0.965144751370277], 
             UndirectedEdge[115, 277] -> 
             RGBColor[
              0.2911217210905471, 0.4233177654223417, 0.9398903233888908], 
             UndirectedEdge[44, 468] -> 
             RGBColor[
              0.27421578400959845`, 0.4055485536519437, 0.9389275552822234], 
             UndirectedEdge[183, 346] -> 
             RGBColor[
              0.6111327928659824, 0.6902275246158929, 0.9651642520510662], 
             UndirectedEdge[434, 469] -> 
             RGBColor[
              0.44123193093372726`, 0.5485178372760227, 0.950676783894612], 
             UndirectedEdge[255, 334] -> 
             RGBColor[
              0.7053145522047058, 0.7676947742177334, 0.9622524497885978], 
             UndirectedEdge[65, 210] -> 
             RGBColor[
              0.3575993590173565, 0.48415632413961485`, 0.9440068928372568], 
             UndirectedEdge[49, 76] -> 
             RGBColor[
              0.31323805790188597`, 0.44381843894455997`, 0.9412503239020749],
              UndirectedEdge[74, 395] -> 
             RGBColor[
              0.393542338416736, 0.515288326348685, 0.9462971477014566], 
             UndirectedEdge[52, 88] -> 
             RGBColor[
              0.2791273226298019, 0.41030912486497284`, 0.9392219708091323], 
             UndirectedEdge[312, 354] -> 
             RGBColor[
              0.37922721237536905`, 0.5028892836708082, 0.9453850005284696], 
             UndirectedEdge[372, 417] -> 
             RGBColor[
              0.7478817166234492, 0.7979925527343095, 0.7718137017074398], 
             UndirectedEdge[354, 415] -> 
             RGBColor[
              0.522495754634913, 0.6220900519838154, 0.9558654101211753], 
             UndirectedEdge[301, 451] -> 
             RGBColor[
              0.31673000256474415`, 0.44277482798070145`, 0.9416217827180234],
              UndirectedEdge[243, 428] -> 
             RGBColor[
              0.28895933935490914`, 0.4210449651152654, 0.9397671789480033], 
             UndirectedEdge[102, 354] -> 
             RGBColor[
              0.35305050495305995`, 0.47890550012965155`, 0.9437650399785169],
              UndirectedEdge[255, 369] -> 
             RGBColor[
              0.6674785365512157, 0.7351875754331598, 0.9597685022698333], 
             UndirectedEdge[300, 409] -> 
             RGBColor[
              0.3082518254384112, 0.4353992467190725, 0.9410827401475708], 
             UndirectedEdge[93, 187] -> 
             RGBColor[
              0.6590249751500403, 0.7253015868188228, 0.9138268256670394], 
             UndirectedEdge[181, 332] -> 
             RGBColor[
              0.37237117867547953`, 0.4969509318742372, 0.9449481401236651], 
             UndirectedEdge[195, 351] -> 
             RGBColor[
              0.7981244939697558, 0.8413999038834079, 0.9190288957746465], 
             UndirectedEdge[480, 481] -> 
             RGBColor[
              0.40268763974461463`, 0.5229531831581578, 0.9469507067003251], 
             UndirectedEdge[47, 365] -> 
             RGBColor[
              0.30489587322801676`, 0.4318922363501426, 0.9408908800517821], 
             UndirectedEdge[50, 370] -> 
             RGBColor[
              0.2846958097742527, 0.4165637252026069, 0.9395243772457118], 
             UndirectedEdge[122, 150] -> 
             RGBColor[
              0.27063625392946994`, 0.40114674819435836`, 0.9387471212885579],
              UndirectedEdge[246, 256] -> 
             RGBColor[
              0.7525853503688579, 0.8046223505888193, 0.9235193602752877], 
             UndirectedEdge[63, 282] -> 
             RGBColor[
              0.2744544360708304, 0.40579939209971316`, 0.9389411461640564], 
             UndirectedEdge[230, 391] -> 
             RGBColor[
              0.33738899120831134`, 0.46303081260490175`, 0.942851663236095], 
             UndirectedEdge[312, 415] -> 
             RGBColor[
              0.4901901487669839, 0.5941085599079781, 0.9538069254819965], 
             UndirectedEdge[199, 397] -> 
             RGBColor[
              0.24160887437382003`, 0.3712766242272625, 0.9370706400160659], 
             UndirectedEdge[129, 328] -> 
             RGBColor[
              0.29876759796010754`, 0.42545103048847616`, 0.9405418838412456],
              UndirectedEdge[188, 304] -> 
             RGBColor[
              0.5550190252788982, 0.6381504279722123, 0.9616540154947558], 
             UndirectedEdge[323, 395] -> 
             RGBColor[
              0.3323669968906672, 0.46209602180407294`, 0.942406626017561], 
             UndirectedEdge[49, 238] -> 
             RGBColor[
              0.34726761603958484`, 0.47329313182811134`, 0.9434186572554522],
              UndirectedEdge[171, 385] -> 
             RGBColor[
              0.35481770686602043`, 0.4793611080091713, 0.943917007500141], 
             UndirectedEdge[117, 425] -> 
             RGBColor[
              0.30805310647866657`, 0.4400603037336467, 0.9408931116510382], 
             UndirectedEdge[32, 103] -> 
             RGBColor[
              0.8674324474196766, 0.8961059309940506, 0.9285281173552573], 
             UndirectedEdge[131, 216] -> 
             RGBColor[
              0.8835790801261865, 0.909366941340148, 0.9611287587940611], 
             UndirectedEdge[65, 175] -> 
             RGBColor[
              0.36456761739906957`, 0.4901918793150049, 0.9444509040995506], 
             UndirectedEdge[143, 226] -> 
             RGBColor[
              0.5530742497710718, 0.6362652782380606, 0.9615191862069047], 
             UndirectedEdge[234, 235] -> 
             RGBColor[
              0.3158517027276886, 0.44754921288969685`, 0.9413631502218942], 
             UndirectedEdge[179, 386] -> 
             RGBColor[
              0.38034901421394307`, 0.49950280314236606`, 0.9458463129575994],
              UndirectedEdge[267, 476] -> 
             RGBColor[
              0.30609602534248365`, 0.4358031739875701, 0.940862215704152], 
             UndirectedEdge[59, 195] -> 
             RGBColor[
              0.962308147580943, 0.9710490003182499, 0.9325177220193863], 
             UndirectedEdge[75, 108] -> 
             RGBColor[
              0.4019250873964799, 0.5223237560713326, 0.9468935362785189], 
             UndirectedEdge[334, 363] -> 
             RGBColor[
              0.43069732270038374`, 0.547205649990333, 0.948737700503547], 
             UndirectedEdge[77, 329] -> 
             RGBColor[
              0.3823798451103838, 0.4979671640607011, 0.9462960475755213], 
             UndirectedEdge[328, 462] -> 
             RGBColor[
              0.50019394868916, 0.5891311959533474, 0.957187155257358], 
             UndirectedEdge[285, 480] -> 
             RGBColor[
              0.30451283935196516`, 0.4342611350760858, 0.940767588954661], 
             UndirectedEdge[204, 334] -> 
             RGBColor[
              0.45710589003397173`, 0.5700794236814988, 0.950420431061864], 
             UndirectedEdge[70, 238] -> 
             RGBColor[
              0.4045327968086765, 0.5248077090112835, 0.9469974499917102], 
             UndirectedEdge[83, 270] -> 
             RGBColor[
              0.6843797577994698, 0.7474000738977967, 0.9204943711123043], 
             UndirectedEdge[112, 190] -> 
             RGBColor[
              0.39438976675413473`, 0.5138253733003857, 0.9466855231936182], 
             UndirectedEdge[263, 453] -> 
             RGBColor[
              0.7644997239487946, 0.8110658647627758, 0.7388680551116656], 
             UndirectedEdge[210, 474] -> 
             RGBColor[
              0.2837940701154845, 0.41361491510153015`, 0.9395462918170434], 
             UndirectedEdge[96, 392] -> 
             RGBColor[
              0.25127747829973146`, 0.38143893997829104`, 0.9376212527062288],
              UndirectedEdge[70, 84] -> 
             RGBColor[
              0.3512130230704995, 0.47780277518456254`, 0.9436300595472356], 
             UndirectedEdge[77, 278] -> 
             RGBColor[
              0.26252282538838223`, 0.39325851276464907`, 0.9382616585869272],
              UndirectedEdge[238, 265] -> 
             RGBColor[
              0.5629985543221347, 0.6536535112218491, 0.9598996985731857], 
             UndirectedEdge[157, 392] -> 
             RGBColor[
              0.22183785454788058`, 0.3504960288351413, 0.9359447096855813], 
             UndirectedEdge[145, 294] -> 
             RGBColor[
              0.6491672406570296, 0.718661834714966, 0.9488903552323102], 
             UndirectedEdge[29, 383] -> 
             RGBColor[
              0.5967420962239084, 0.6761411346533, 0.9649182695831542], 
             UndirectedEdge[210, 227] -> 
             RGBColor[
              0.36392217300240925`, 0.4896328278195964, 0.9444097769533395], 
             UndirectedEdge[45, 276] -> 
             RGBColor[
              0.3195967307694504, 0.4453843906698888, 0.9417998146058718], 
             UndirectedEdge[57, 219] -> 
             RGBColor[
              0.3705911814633063, 0.4954091877543139, 0.9448347202752951], 
             UndirectedEdge[291, 311] -> 
             RGBColor[
              0.3834357503451382, 0.5065345077329535, 0.9456531648464392], 
             UndirectedEdge[11, 485] -> 
             RGBColor[
              0.35820229607781673`, 0.4846785579168877, 0.944045311453593], 
             UndirectedEdge[13, 338] -> 
             RGBColor[
              0.4326124855246124, 0.5489519253295455, 0.9488355682008565], 
             UndirectedEdge[190, 351] -> 
             RGBColor[
              0.5511101772616818, 0.6464550949884142, 0.9578045584185884], 
             UndirectedEdge[314, 397] -> 
             RGBColor[
              0.35577974762473263`, 0.482168349788592, 0.943906031159492], 
             UndirectedEdge[339, 365] -> 
             RGBColor[
              0.2615329512589815, 0.3922180922930042, 0.9382052867196455], 
             UndirectedEdge[320, 337] -> 
             RGBColor[
              0.34507713082586733`, 0.4712291844713569, 0.9432851836829113], 
             UndirectedEdge[317, 357] -> 
             RGBColor[
              0.46993707932268014`, 0.5741320352673606, 0.9528039529765385], 
             UndirectedEdge[153, 452] -> 
             RGBColor[
              0.4864258947538489, 0.593702853457529, 0.9527783081035831], 
             UndirectedEdge[308, 423] -> 
             RGBColor[
              0.40529898002979414`, 0.5254713384079271, 0.9470462705090505], 
             UndirectedEdge[149, 441] -> 
             RGBColor[
              0.8712223006248347, 0.8955600772366432, 0.7072637260654031], 
             UndirectedEdge[486, 493] -> 
             RGBColor[
              0.5380199998420867, 0.6358278992534145, 0.9567740517012179], 
             UndirectedEdge[241, 402] -> 
             RGBColor[
              0.5617450504235045, 0.6550889641167582, 0.958641774590711], 
             UndirectedEdge[293, 432] -> 
             RGBColor[
              0.4884554288447742, 0.5955006819700657, 0.9528965904448277], 
             UndirectedEdge[23, 211] -> 
             RGBColor[
              0.3316581059482975, 0.46119270698758924`, 0.9423720491373704], 
             UndirectedEdge[8, 381] -> 
             RGBColor[
              0.3633195131507917, 0.4871637573724563, 0.9444426680192016], 
             UndirectedEdge[238, 343] -> 
             RGBColor[
              0.4090982840701299, 0.5287621046090927, 0.9472883588029082], 
             UndirectedEdge[355, 363] -> 
             RGBColor[
              0.3277452098168565, 0.4535280811116523, 0.9422792688266295], 
             UndirectedEdge[66, 398] -> 
             RGBColor[
              0.34622774679083956`, 0.47430680518285506`, 0.9432823037617051],
              UndirectedEdge[113, 477] -> 
             RGBColor[
              0.27078877537885304`, 0.40194655029613335`, 0.9387323922105074],
              UndirectedEdge[7, 241] -> 
             RGBColor[
              0.47500583781537026`, 0.5817001797577241, 0.9526339614681322], 
             UndirectedEdge[161, 259] -> 
             RGBColor[
              0.5103625539863732, 0.6104317681766072, 0.9555431421229006], 
             UndirectedEdge[346, 408] -> 
             RGBColor[
              0.5704518586168152, 0.6538322796375671, 0.9626145525654535], 
             UndirectedEdge[33, 270] -> 
             RGBColor[
              0.6433477963129801, 0.7111920681427581, 0.9179043162638596], 
             UndirectedEdge[197, 270] -> 
             RGBColor[
              0.6406909814540769, 0.7083995872742594, 0.9177530145880504], 
             UndirectedEdge[115, 381] -> 
             RGBColor[
              0.36153604760652586`, 0.4852892220071863, 0.9443411022948565], 
             UndirectedEdge[112, 224] -> 
             RGBColor[
              0.5958502516282413, 0.6741143950786761, 0.965032510040996], 
             UndirectedEdge[133, 296] -> 
             RGBColor[
              0.33720556798102713`, 0.46163302098503706`, 0.9428853385872477],
              UndirectedEdge[204, 244] -> 
             RGBColor[
              0.38181617746074714`, 0.5051317151025939, 0.9455499670943779], 
             UndirectedEdge[116, 280] -> 
             RGBColor[
              0.7535903663320555, 0.8077905559587671, 0.9759802185308237], 
             UndirectedEdge[81, 267] -> 
             RGBColor[
              0.2547588510773533, 0.3850980834993545, 0.9378195117356849], 
             UndirectedEdge[431, 459] -> 
             RGBColor[
              0.39442544673620195`, 0.5160532303886918, 0.9463534185826709], 
             UndirectedEdge[46, 293] -> 
             RGBColor[
              0.44175868982761113`, 0.557050906516499, 0.9493694509773121], 
             UndirectedEdge[145, 358] -> 
             RGBColor[
              0.9739114913811702, 0.9792328489169557, 0.8918329274988805], 
             UndirectedEdge[12, 480] -> 
             RGBColor[
              0.5128825786917967, 0.6117895508966205, 0.9560528678900513], 
             UndirectedEdge[318, 321] -> 
             RGBColor[
              0.5600642981496387, 0.6512228945865043, 0.9596657970613901], 
             UndirectedEdge[38, 47] -> 
             RGBColor[
              0.3719545208188811, 0.4965900437806844, 0.9449215910534787], 
             UndirectedEdge[271, 492] -> 
             RGBColor[
              0.31564093498562995`, 0.44781404613504383`, 0.9413333391603327],
              UndirectedEdge[246, 333] -> 
             RGBColor[
              0.9013571576401309, 0.5611778008960902, 0.5279594758629702], 
             UndirectedEdge[97, 137] -> 
             RGBColor[
              0.6662750342109368, 0.7335531849149426, 0.95105225234374], 
             UndirectedEdge[406, 486] -> 
             RGBColor[
              0.5255391556717735, 0.6256953877003317, 0.9557915139292923], 
             UndirectedEdge[272, 306] -> 
             RGBColor[
              0.35498023786595917`, 0.48188777303913116`, 0.9438400047534876],
              UndirectedEdge[50, 219] -> 
             RGBColor[
              0.359809458112534, 0.4853014780155154, 0.9441758797534756], 
             UndirectedEdge[326, 405] -> 
             RGBColor[
              0.44106378155470255`, 0.5564490118976109, 0.9493251720366456], 
             UndirectedEdge[180, 343] -> 
             RGBColor[
              0.5529153635026425, 0.6459976055649346, 0.9588010951008964], 
             UndirectedEdge[229, 380] -> 
             RGBColor[
              0.5594199274665524, 0.6428895405510016, 0.9618874481148569], 
             UndirectedEdge[184, 470] -> 
             RGBColor[
              0.41491602718809806`, 0.5338011412896053, 0.9476590602499568], 
             UndirectedEdge[188, 483] -> 
             RGBColor[
              0.3791425434751599, 0.4982350504528308, 0.9457775766911349], 
             UndirectedEdge[364, 374] -> 
             RGBColor[
              0.635663659063343, 0.5052542475782333, 0.5785360038316638], 
             UndirectedEdge[161, 469] -> 
             RGBColor[
              0.46613821739258415`, 0.5684105776762824, 0.9528612781897959], 
             UndirectedEdge[14, 182] -> 
             RGBColor[
              0.416661770632748, 0.534467157588732, 0.9480040660814699], 
             UndirectedEdge[374, 391] -> 
             RGBColor[
              0.6356751090075451, 0.5052641649444103, 0.5785367334119835], 
             UndirectedEdge[352, 367] -> 
             RGBColor[
              0.4264777322735521, 0.5386635622492668, 0.9493219534643598], 
             UndirectedEdge[8, 289] -> 
             RGBColor[
              0.3172027582235311, 0.44721974214996163`, 0.9415041491746818], 
             UndirectedEdge[160, 275] -> 
             RGBColor[
              0.4995042787544086, 0.6032345464866312, 0.954107931618277], 
             UndirectedEdge[118, 151] -> 
             RGBColor[
              0.30983372616696103`, 0.4406416261854119, 0.9410417566462475], 
             UndirectedEdge[43, 217] -> 
             RGBColor[
              0.34325186791852014`, 0.4717292484756731, 0.9430926833914272], 
             UndirectedEdge[117, 154] -> 
             RGBColor[
              0.41817148476018007`, 0.5330754683085172, 0.9485628933713575], 
             UndirectedEdge[139, 468] -> 
             RGBColor[
              0.5052763340685629, 0.5997916085623292, 0.9566345924587552], 
             UndirectedEdge[279, 324] -> 
             RGBColor[
              0.7652357244666192, 0.8163542702607993, 0.9673126820450935], 
             UndirectedEdge[4, 29] -> 
             RGBColor[
              0.7609457712800052, 0.8136055516719951, 0.9767393379238037], 
             UndirectedEdge[239, 393] -> 
             RGBColor[
              0.5329887086193308, 0.6271806287226845, 0.9581905982905085], 
             UndirectedEdge[94, 127] -> 
             RGBColor[
              0.5643504000343771, 0.657204104300527, 0.958846877255789], 
             UndirectedEdge[157, 459] -> 
             RGBColor[
              0.2961595169417925, 0.4191238027151934, 0.9405246573865178], 
             UndirectedEdge[48, 85] -> 
             RGBColor[
              0.6142254759656509, 0.6972349057620639, 0.9630877523401884], 
             UndirectedEdge[26, 215] -> 
             RGBColor[
              0.34106435533990886`, 0.4679194105450612, 0.9430234191130366], 
             UndirectedEdge[63, 165] -> 
             RGBColor[
              0.30106771385190084`, 0.43259634556251214`, 0.9404997660454918],
              UndirectedEdge[165, 282] -> 
             RGBColor[
              0.29484448003943753`, 0.42605533224979986`, 0.9401453620863214],
              UndirectedEdge[288, 465] -> 
             RGBColor[
              0.6710176509373971, 0.7383043248164212, 0.9607433820800882], 
             UndirectedEdge[200, 500] -> 
             RGBColor[
              0.4039651657332144, 0.5243160555036857, 0.9469612810415182], 
             UndirectedEdge[293, 353] -> 
             RGBColor[
              0.41743747552303107`, 0.5359850931056461, 0.9478197247082296], 
             UndirectedEdge[239, 296] -> 
             RGBColor[
              0.4934951722544221, 0.5881140861456042, 0.9558520251574039], 
             UndirectedEdge[139, 274] -> 
             RGBColor[
              0.6207435798251004, 0.7015517426085157, 0.964267394017372], 
             UndirectedEdge[140, 361] -> 
             RGBColor[
              0.44462115074187253`, 0.5586860839356907, 0.9497850835029269], 
             UndirectedEdge[83, 197] -> 
             RGBColor[
              0.33989417352806733`, 0.4676615179423854, 0.9429211877459666], 
             UndirectedEdge[256, 444] -> 
             RGBColor[
              0.4555524215704176, 0.5671938698327654, 0.9507469568612679], 
             UndirectedEdge[21, 166] -> 
             RGBColor[
              0.6636188836335375, 0.7266547141763071, 0.7943997421769285], 
             UndirectedEdge[92, 363] -> 
             RGBColor[
              0.5120349540953409, 0.6132392033752965, 0.9551408967965191], 
             UndirectedEdge[41, 212] -> 
             RGBColor[
              0.38575014488930864`, 0.5085391199622618, 0.9458006360202551], 
             UndirectedEdge[96, 433] -> 
             RGBColor[
              0.3093556968029062, 0.4359974591794149, 0.941166182525961], 
             UndirectedEdge[346, 407] -> 
             RGBColor[
              0.5705182071465322, 0.6539020161490393, 0.962618331016067], 
             UndirectedEdge[32, 155] -> 
             RGBColor[
              0.5925710446416804, 0.6780212409834598, 0.9623115988015305], 
             UndirectedEdge[302, 477] -> 
             RGBColor[
              0.30227936951233453`, 0.43283656559966144`, 0.9406066024697219],
              UndirectedEdge[24, 489] -> 
             RGBColor[
              0.43475948217043775`, 0.5487119230866759, 0.9495525049713491], 
             UndirectedEdge[359, 427] -> 
             RGBColor[
              0.4468555680210342, 0.5562045878861914, 0.950835383558238], 
             UndirectedEdge[217, 290] -> 
             RGBColor[
              0.29601487802816084`, 0.4256548161802228, 0.9402717216506072], 
             UndirectedEdge[40, 297] -> 
             RGBColor[
              0.27124939087653804`, 0.40243068638890966`, 0.9387586235816809],
              UndirectedEdge[41, 456] -> 
             RGBColor[
              0.29268253531169275`, 0.416112215985379, 0.9403031071916219], 
             UndirectedEdge[341, 469] -> 
             RGBColor[
              0.3421613633701023, 0.4670684153236137, 0.9431592690945034], 
             UndirectedEdge[169, 498] -> 
             RGBColor[
              0.264534800140268, 0.3953732257954482, 0.9383762375725972], 
             UndirectedEdge[6, 329] -> 
             RGBColor[
              0.4146916108732148, 0.5318129375401801, 0.9481404000034902], 
             UndirectedEdge[92, 219] -> 
             RGBColor[
              0.5224623124215568, 0.6222708570631965, 0.9558053188485147], 
             UndirectedEdge[341, 387] -> 
             RGBColor[
              0.4920925951241236, 0.5975224909713174, 0.9534401613501398], 
             UndirectedEdge[13, 478] -> 
             RGBColor[
              0.3589057430131338, 0.4852878482959883, 0.9440901344702777], 
             UndirectedEdge[33, 267] -> 
             RGBColor[
              0.28488765402793004`, 0.41676536567685, 0.9395353024921504], 
             UndirectedEdge[10, 123] -> 
             RGBColor[
              0.41617513577434573`, 0.5348917178623754, 0.9477392895356865], 
             UndirectedEdge[57, 337] -> 
             RGBColor[
              0.30411437967004246`, 0.43574930826791813`, 0.9406750734012006],
              UndirectedEdge[70, 135] -> 
             RGBColor[
              0.43843476698233164`, 0.5536022198435742, 0.9493150555601089], 
             UndirectedEdge[51, 130] -> 
             RGBColor[
              0.624640173842091, 0.653299096905275, 0.6264384669489388], 
             UndirectedEdge[219, 361] -> 
             RGBColor[
              0.45179937749119586`, 0.5649035031577878, 0.950242473763937], 
             UndirectedEdge[70, 131] -> 
             RGBColor[
              0.6845631535559955, 0.7488430388697634, 0.9441848483238853], 
             UndirectedEdge[61, 362] -> 
             RGBColor[
              0.5531136724001808, 0.6461693707646872, 0.9588137311684899], 
             UndirectedEdge[49, 487] -> 
             RGBColor[
              0.5574723332875402, 0.6424470923435581, 0.9615334501416007], 
             UndirectedEdge[83, 375] -> 
             RGBColor[
              0.32241513882779194`, 0.4492899442375874, 0.9419257825777004], 
             UndirectedEdge[147, 385] -> 
             RGBColor[
              0.3886621709882375, 0.5110613706064666, 0.9459861877482751], 
             UndirectedEdge[105, 395] -> 
             RGBColor[
              0.35323069990057454`, 0.48037241118784996`, 0.943728525741389], 
             UndirectedEdge[57, 204] -> 
             RGBColor[
              0.3865723904706785, 0.5092513077575798, 0.9458530287816167], 
             UndirectedEdge[362, 363] -> 
             RGBColor[
              0.5462328580007727, 0.6402095551717073, 0.9583752917594248], 
             UndirectedEdge[313, 390] -> 
             RGBColor[
              0.4625478157787848, 0.568271091323237, 0.9521320109247731], 
             UndirectedEdge[15, 430] -> 
             RGBColor[
              0.5678126041984477, 0.6600148776114396, 0.9591194346500563], 
             UndirectedEdge[104, 430] -> 
             RGBColor[
              0.5581611103445279, 0.6521793601059843, 0.9583596336992888], 
             UndirectedEdge[341, 405] -> 
             RGBColor[
              0.4345114918448729, 0.550773747878613, 0.9489076659302975], 
             UndirectedEdge[8, 311] -> 
             RGBColor[
              0.32811063528267803`, 0.4566675970127528, 0.9421991894554336], 
             UndirectedEdge[305, 460] -> 
             RGBColor[
              0.3826356218205643, 0.5010691782902151, 0.9460527203166592], 
             UndirectedEdge[451, 456] -> 
             RGBColor[
              0.2851806602395977, 0.4096144688531348, 0.9398250943456757], 
             UndirectedEdge[257, 306] -> 
             RGBColor[
              0.5008508519570865, 0.6034114840730869, 0.9544671072565714], 
             UndirectedEdge[65, 167] -> 
             RGBColor[
              0.4009943839920077, 0.5217429136752842, 0.9467719854559278], 
             UndirectedEdge[24, 329] -> 
             RGBColor[
              0.5282737217914542, 0.6279154316670883, 0.9560067889912792], 
             UndirectedEdge[14, 63] -> 
             RGBColor[
              0.3825776852967945, 0.5023501270887817, 0.945927277952443], 
             UndirectedEdge[64, 172] -> 
             RGBColor[
              0.2984091571295606, 0.42905752816894804`, 0.9403756251744564], 
             UndirectedEdge[50, 361] -> 
             RGBColor[
              0.3924171953187782, 0.512700518717766, 0.9464868549817005], 
             UndirectedEdge[253, 291] -> 
             RGBColor[
              0.3432474240190243, 0.4698218911352806, 0.9431620969919722], 
             UndirectedEdge[184, 280] -> 
             RGBColor[
              0.5187757386365325, 0.618632448855694, 0.9556934467259008], 
             UndirectedEdge[402, 487] -> 
             RGBColor[
              0.6721591313728839, 0.7419570263891206, 0.9692519647529704], 
             UndirectedEdge[356, 463] -> 
             RGBColor[
              0.34525777491995124`, 0.469798367541118, 0.9433548123257611], 
             UndirectedEdge[287, 301] -> 
             RGBColor[
              0.24470822454613433`, 0.3745342377685157, 0.9372471434233014], 
             UndirectedEdge[265, 328] -> 
             RGBColor[
              0.4722226334433338, 0.5672797918934385, 0.9543992359604566], 
             UndirectedEdge[196, 321] -> 
             RGBColor[
              0.4726298176249424, 0.5813813880979174, 0.9520020180819028], 
             UndirectedEdge[122, 267] -> 
             RGBColor[
              0.29195947010475864`, 0.4235588003645784, 0.9399614469048692], 
             UndirectedEdge[330, 354] -> 
             RGBColor[
              0.3256966821758271, 0.4501548980582455, 0.942207280237708], 
             UndirectedEdge[155, 393] -> 
             RGBColor[
              0.3857335904656086, 0.5085247813525025, 0.9457995811870155], 
             UndirectedEdge[291, 319] -> 
             RGBColor[
              0.4053160392093216, 0.5254861142118146, 0.9470473575048852], 
             UndirectedEdge[63, 206] -> 
             RGBColor[
              0.2694264291817054, 0.4005146380651934, 0.9386548086099904], 
             UndirectedEdge[174, 215] -> 
             RGBColor[
              0.30792697984049405`, 0.4392174814203882, 0.9409119348484445], 
             UndirectedEdge[254, 471] -> 
             RGBColor[
              0.5577882516354826, 0.6496301301451557, 0.9593605141066457], 
             UndirectedEdge[453, 463] -> 
             RGBColor[
              0.7074141303662178, 0.7638557904391485, 0.7346131855836162], 
             UndirectedEdge[154, 174] -> 
             RGBColor[
              0.4340990430893216, 0.5480526655148764, 0.9495345210903876], 
             UndirectedEdge[119, 197] -> 
             RGBColor[
              0.6246659016884826, 0.6966116811618959, 0.9522043891651367], 
             UndirectedEdge[50, 340] -> 
             RGBColor[
              0.32871352573500445`, 0.4583677443171047, 0.9421944744394328], 
             UndirectedEdge[443, 446] -> 
             RGBColor[
              0.42909594241483096`, 0.5439609548345163, 0.9491489389718009], 
             UndirectedEdge[275, 324] -> 
             RGBColor[
              0.7708285114295784, 0.8208947466695111, 0.9677529667218713], 
             UndirectedEdge[95, 286] -> 
             RGBColor[
              0.6734849623394422, 0.7384658815247321, 0.9320692599587941], 
             UndirectedEdge[306, 317] -> 
             RGBColor[
              0.3298751446627489, 0.4583136714514475, 0.9423073112079196], 
             UndirectedEdge[118, 188] -> 
             RGBColor[
              0.2775811086059755, 0.4090857231766393, 0.9391192055394355], 
             UndirectedEdge[7, 69] -> 
             RGBColor[
              0.291603992110608, 0.4205711282128918, 0.9400369158506385], 
             UndirectedEdge[88, 166] -> 
             RGBColor[
              0.32289788338056447`, 0.4540996500899044, 0.9417957454949905], 
             UndirectedEdge[9, 44] -> 
             RGBColor[
              0.2749461902345689, 0.40631625690481715`, 0.9389691508361964], 
             UndirectedEdge[76, 459] -> 
             RGBColor[
              0.3749066284023901, 0.49914701099227854`, 0.9451096967382537], 
             UndirectedEdge[254, 325] -> 
             RGBColor[
              0.7907767798430434, 0.8369132705221423, 0.9796659464850939], 
             UndirectedEdge[171, 433] -> 
             RGBColor[
              0.3309157080518868, 0.4586583979857599, 0.942393993271412], 
             UndirectedEdge[112, 447] -> 
             RGBColor[
              0.3877523250187507, 0.5084367990862584, 0.9461629994664584], 
             UndirectedEdge[199, 359] -> 
             RGBColor[
              0.23678666489414377`, 0.36620817631838276`, 0.9367960223200179],
              UndirectedEdge[74, 224] -> 
             RGBColor[
              0.6620669028870985, 0.732605435789947, 0.9692101268562243], 
             UndirectedEdge[292, 386] -> 
             RGBColor[
              0.5275537819779524, 0.6168541690145045, 0.9589089461824678], 
             UndirectedEdge[112, 195] -> 
             RGBColor[
              0.6414040834622088, 0.7087701821953794, 0.9079098605496764], 
             UndirectedEdge[97, 408] -> 
             RGBColor[
              0.6268071311933102, 0.6982086066206548, 0.9485798461355597], 
             UndirectedEdge[236, 422] -> 
             RGBColor[
              0.7786765336356325, 0.8255915032957633, 0.9166755867317637], 
             UndirectedEdge[27, 114] -> 
             RGBColor[
              0.2941565709512267, 0.42490272543414975`, 0.9401219153708061], 
             UndirectedEdge[110, 355] -> 
             RGBColor[
              0.5636241973652716, 0.6434345387831206, 0.9627137527384353], 
             UndirectedEdge[104, 215] -> 
             RGBColor[
              0.4520181126492897, 0.5596046737270206, 0.9513138088666088], 
             UndirectedEdge[80, 406] -> 
             RGBColor[
              0.39788364372629975`, 0.5144981529042594, 0.9471575280672089], 
             UndirectedEdge[276, 292] -> 
             RGBColor[
              0.5884464154554143, 0.6729937722703996, 0.9626645731172001], 
             UndirectedEdge[425, 466] -> 
             RGBColor[
              0.3310433198849724, 0.46115481778848, 0.9423147655063246], 
             UndirectedEdge[164, 309] -> 
             RGBColor[
              0.39519265484072663`, 0.5167177474878304, 0.9464023044046757], 
             UndirectedEdge[95, 137] -> 
             RGBColor[
              0.6773441287166265, 0.7418084974733072, 0.9323151626278213], 
             UndirectedEdge[119, 426] -> 
             RGBColor[
              0.7487612075108125, 0.8027832807942568, 0.960752470796594], 
             UndirectedEdge[238, 431] -> 
             RGBColor[
              0.3919838937001133, 0.5139384798648554, 0.9461978449821918], 
             UndirectedEdge[93, 266] -> 
             RGBColor[
              0.30092050862532815`, 0.4314423237302587, 0.9405279721866896], 
             UndirectedEdge[15, 148] -> 
             RGBColor[
              0.47005452062173203`, 0.576253267605304, 0.9525511182720573], 
             UndirectedEdge[225, 470] -> 
             RGBColor[
              0.6456347322204237, 0.7196932708419037, 0.9675551592947906], 
             UndirectedEdge[249, 296] -> 
             RGBColor[
              0.3753821029161124, 0.4935793949078435, 0.9456274342643283], 
             UndirectedEdge[273, 421] -> 
             RGBColor[
              0.37988949062754407`, 0.5034629158057694, 0.9454272003130685], 
             UndirectedEdge[150, 159] -> 
             RGBColor[
              0.3620899310755, 0.4791306284859139, 0.9449139617162735], 
             UndirectedEdge[85, 407] -> 
             RGBColor[
              0.4843638972227203, 0.5863978577912055, 0.9540842838331793], 
             UndirectedEdge[71, 388] -> 
             RGBColor[
              0.4326460337303918, 0.5470114105414541, 0.9493819046289163], 
             UndirectedEdge[61, 435] -> 
             RGBColor[
              0.33637704521518685`, 0.4613283307956431, 0.9428174262911797], 
             UndirectedEdge[10, 177] -> 
             RGBColor[
              0.3434404639159247, 0.46827229410837434`, 0.9432372577259169], 
             UndirectedEdge[16, 52] -> 
             RGBColor[
              0.26967821742896136`, 0.40077928347735636`, 0.9386691475781843],
              UndirectedEdge[25, 459] -> 
             RGBColor[
              0.4185408489658752, 0.536940779724676, 0.9478900306883328], 
             UndirectedEdge[105, 453] -> 
             RGBColor[
              0.6708179298601038, 0.7321580009392723, 0.7322813080481161], 
             UndirectedEdge[61, 384] -> 
             RGBColor[
              0.657044794431455, 0.7280239855472652, 0.9689967187966202], 
             UndirectedEdge[104, 323] -> 
             RGBColor[
              0.4612647305488235, 0.5693234554088668, 0.951840390076842], 
             UndirectedEdge[150, 406] -> 
             RGBColor[
              0.37151202177532927`, 0.4867799061763842, 0.9456557032104196], 
             UndirectedEdge[413, 493] -> 
             RGBColor[
              0.47919240402287966`, 0.58705597795494, 0.9524228307579338], 
             UndirectedEdge[94, 254] -> 
             RGBColor[
              0.6570261942669391, 0.7314373129129725, 0.9668298996787938], 
             UndirectedEdge[431, 487] -> 
             RGBColor[
              0.6021886109480686, 0.6830924403803023, 0.9643126378683404], 
             UndirectedEdge[234, 332] -> 
             RGBColor[
              0.3686291634052093, 0.49370978632628526`, 0.9447097022195776], 
             UndirectedEdge[82, 89] -> 
             RGBColor[
              0.4037945275501147, 0.5232183053577419, 0.9472128826755443], 
             UndirectedEdge[154, 255] -> 
             RGBColor[
              0.7439738970525818, 0.7990801719488774, 0.9652958550288688], 
             UndirectedEdge[22, 324] -> 
             RGBColor[
              0.754234924397378, 0.8074233251841938, 0.9664466587663844], 
             UndirectedEdge[105, 112] -> 
             RGBColor[
              0.3223479140425308, 0.4524857887550509, 0.94180235158499], 
             UndirectedEdge[6, 406] -> 
             RGBColor[
              0.41370709820304363`, 0.5310136658027448, 0.9480628955597057], 
             UndirectedEdge[396, 422] -> 
             RGBColor[
              0.44914417711918186`, 0.5602555151455453, 0.9507220977822067], 
             UndirectedEdge[409, 456] -> 
             RGBColor[
              0.2768766744600774, 0.4024219737413752, 0.939295971714731], 
             UndirectedEdge[91, 473] -> 
             RGBColor[
              0.6570052754520986, 0.719926776247288, 0.7085470672792378], 
             UndirectedEdge[369, 379] -> 
             RGBColor[
              0.4028697244527181, 0.5233672393249994, 0.9468914804917856], 
             UndirectedEdge[353, 441] -> 
             RGBColor[
              0.5673165385597811, 0.6561059992750617, 0.9607197816416164], 
             UndirectedEdge[165, 481] -> 
             RGBColor[
              0.39210834686617435`, 0.5137899313975736, 0.9462766035130123], 
             UndirectedEdge[185, 318] -> 
             RGBColor[
              0.5015717954652509, 0.5984799080353692, 0.9560148552737918], 
             UndirectedEdge[264, 445] -> 
             RGBColor[
              0.3296933054485365, 0.45567368592188195`, 0.9423866205304223], 
             UndirectedEdge[258, 297] -> 
             RGBColor[
              0.26553306186296843`, 0.3964224621594553, 0.9384330871009092], 
             UndirectedEdge[57, 139] -> 
             RGBColor[
              0.5290092279912324, 0.6235118197238335, 0.9580309829851044], 
             UndirectedEdge[447, 463] -> 
             RGBColor[
              0.4502535382675603, 0.5637097141365705, 0.9501038718571195], 
             UndirectedEdge[9, 26] -> 
             RGBColor[
              0.33504108647986813`, 0.4615885730758553, 0.942680402862085], 
             UndirectedEdge[181, 262] -> 
             RGBColor[
              0.6255744455995673, 0.5844892925475639, 0.5968744052887892], 
             UndirectedEdge[203, 291] -> 
             RGBColor[
              0.40240201567983463`, 0.5229621334936541, 0.9468616785023563], 
             UndirectedEdge[45, 254] -> 
             RGBColor[
              0.4766925868466923, 0.5735331743427092, 0.9544075856925516], 
             UndirectedEdge[240, 412] -> 
             RGBColor[
              0.4170256875891332, 0.5356284230943672, 0.9477934859452113], 
             UndirectedEdge[208, 258] -> 
             RGBColor[
              0.34450907798390545`, 0.4692738096664625, 0.9433025684891445], 
             UndirectedEdge[293, 420] -> 
             RGBColor[
              0.4016295654252269, 0.5222930759075917, 0.9468124586551836], 
             UndirectedEdge[85, 346] -> 
             RGBColor[
              0.7585440101271442, 0.811499369598452, 0.9765152267263065], 
             UndirectedEdge[65, 166] -> 
             RGBColor[
              0.3587571144039171, 0.48515911366497594`, 0.9440806639867256], 
             UndirectedEdge[254, 347] -> 
             RGBColor[
              0.5202668990823897, 0.6171310204416802, 0.956969686700792], 
             UndirectedEdge[236, 292] -> 
             RGBColor[
              0.8847860462874544, 0.9095798897476824, 0.9265030509373212], 
             UndirectedEdge[100, 401] -> 
             RGBColor[
              0.33005181381564697`, 0.46029602506577433`, 0.9422515876163416],
              UndirectedEdge[146, 400] -> 
             RGBColor[
              0.4909701222282794, 0.5960985472429272, 0.9534934483278865], 
             UndirectedEdge[104, 153] -> 
             RGBColor[
              0.5721630894606671, 0.6635467975344369, 0.9594619207862508], 
             UndirectedEdge[216, 281] -> 
             RGBColor[
              0.5818736592976459, 0.666557760394911, 0.9625602445451372], 
             UndirectedEdge[123, 125] -> 
             RGBColor[
              0.3850855034172892, 0.5079634409250503, 0.9457582856533773], 
             UndirectedEdge[78, 358] -> 
             RGBColor[
              0.6406097688431236, 0.7070336894354629, 0.8843468244002224], 
             UndirectedEdge[313, 478] -> 
             RGBColor[
              0.30072074503244306`, 0.43306696205307016`, 0.9404494221601475],
              UndirectedEdge[368, 401] -> 
             RGBColor[
              0.2875862035720722, 0.4173866030077065, 0.9397700869003871], 
             UndirectedEdge[106, 369] -> 
             RGBColor[
              0.3905654891394331, 0.5127099291254804, 0.9461074654978312], 
             UndirectedEdge[111, 146] -> 
             RGBColor[
              0.5171455517298275, 0.6187703886618281, 0.9551613235497016], 
             UndirectedEdge[129, 266] -> 
             RGBColor[
              0.32108368925195535`, 0.4489066573581181, 0.9418127522266178], 
             UndirectedEdge[99, 278] -> 
             RGBColor[
              0.2847424565982153, 0.4166127539721711, 0.9395270337133286], 
             UndirectedEdge[147, 171] -> 
             RGBColor[
              0.31678502843128753`, 0.4464191135270054, 0.9414935988612567], 
             UndirectedEdge[164, 166] -> 
             RGBColor[
              0.3452481900949479, 0.47345836240682476`, 0.9432198872752308], 
             UndirectedEdge[129, 433] -> 
             RGBColor[
              0.37574162798425986`, 0.49987024566179483`, 0.9451629021732493],
              UndirectedEdge[179, 283] -> 
             RGBColor[
              0.4537924937954252, 0.5665133184696963, 0.9504016687078023], 
             UndirectedEdge[136, 291] -> 
             RGBColor[
              0.3305662684076013, 0.45649319255597054`, 0.9424399239399902], 
             UndirectedEdge[321, 479] -> 
             RGBColor[
              0.4309189728478123, 0.5475186452556995, 0.9487183875891883], 
             UndirectedEdge[181, 239] -> 
             RGBColor[
              0.5330406938848583, 0.6272256557468291, 0.9581939107456591], 
             UndirectedEdge[102, 330] -> 
             RGBColor[
              0.26721436888558886`, 0.3981896224412515, 0.9385288350485765], 
             UndirectedEdge[406, 413] -> 
             RGBColor[
              0.46671155985256635`, 0.5769234664018572, 0.9514402929860082], 
             UndirectedEdge[37, 310] -> 
             RGBColor[
              0.3617015825973907, 0.48670290119337134`, 0.944305138092208], 
             UndirectedEdge[203, 439] -> 
             RGBColor[
              0.39614063788636755`, 0.5175388427549513, 0.9464627090460754], 
             UndirectedEdge[320, 375] -> 
             RGBColor[
              0.33258177636771713`, 0.45809577468461016`, 0.9425735917317399],
              UndirectedEdge[42, 407] -> 
             RGBColor[
              0.3310019262592845, 0.4599717690453142, 0.942354132394075], 
             UndirectedEdge[131, 374] -> 
             RGBColor[
              0.9163584289383491, 0.7298650586935411, 0.5757657379808175], 
             UndirectedEdge[387, 403] -> 
             RGBColor[
              0.4481176202825006, 0.5594335780100048, 0.950638114838775], 
             UndirectedEdge[65, 348] -> 
             RGBColor[
              0.5103896599241106, 0.6115361895867335, 0.9551128564953011], 
             UndirectedEdge[217, 498] -> 
             RGBColor[
              0.29601487802816084`, 0.4256548161802228, 0.9402717216506072], 
             UndirectedEdge[40, 397] -> 
             RGBColor[
              0.2930669962508394, 0.42536237295337764`, 0.9400011039314928], 
             UndirectedEdge[226, 292] -> 
             RGBColor[
              0.525030374718706, 0.6142019079917754, 0.9587652418721002], 
             UndirectedEdge[53, 257] -> 
             RGBColor[
              0.6168612276719473, 0.6998347597625335, 0.9629807219609181], 
             UndirectedEdge[220, 429] -> 
             RGBColor[
              0.41517494903208396`, 0.5340254063770756, 0.9476755585209], 
             UndirectedEdge[139, 425] -> 
             RGBColor[
              0.5280836941208881, 0.6227101688040262, 0.9579720087853035], 
             UndirectedEdge[317, 418] -> 
             RGBColor[
              0.32625304591667664`, 0.45517639156957607`, 0.942076514278716], 
             UndirectedEdge[482, 496] -> 
             RGBColor[
              0.3202957046772913, 0.45184577368643375`, 0.9416299369690342], 
             UndirectedEdge[117, 466] -> 
             RGBColor[
              0.3189567714626667, 0.44950451030865074`, 0.9415878835420863], 
             UndirectedEdge[82, 105] -> 
             RGBColor[
              0.3337689908933533, 0.4635156570197313, 0.9424884428527625], 
             UndirectedEdge[239, 453] -> 
             RGBColor[
              0.8620919907161089, 0.8889408440217816, 0.7474771732561759], 
             UndirectedEdge[274, 340] -> 
             RGBColor[
              0.43122960091964463`, 0.5465153769405855, 0.94908972599352], 
             UndirectedEdge[311, 484] -> 
             RGBColor[
              0.4098243323202497, 0.5293909711111002, 0.9473346219553864], 
             UndirectedEdge[44, 140] -> 
             RGBColor[
              0.3393709100045901, 0.4651466202925743, 0.9429633338079795], 
             UndirectedEdge[139, 466] -> 
             RGBColor[
              0.5389873591048883, 0.6321543753790302, 0.9586667806763517], 
             UndirectedEdge[22, 481] -> 
             RGBColor[
              0.5120223365261726, 0.6147218249921698, 0.9547274204124105], 
             UndirectedEdge[45, 386] -> 
             RGBColor[
              0.2587040972919885, 0.3892447874139937, 0.9380441876711396], 
             UndirectedEdge[40, 220] -> 
             RGBColor[
              0.35692810909284334`, 0.4810875775633221, 0.9440551952204664], 
             UndirectedEdge[237, 489] -> 
             RGBColor[
              0.290039857231839, 0.41999786851348686`, 0.9399086354551752], 
             UndirectedEdge[61, 64] -> 
             RGBColor[
              0.33970332026966565`, 0.4648244567759196, 0.9430068527347493], 
             UndirectedEdge[82, 296] -> 
             RGBColor[
              0.2877371755065439, 0.4187859857773394, 0.9397332563619555], 
             UndirectedEdge[27, 277] -> 
             RGBColor[
              0.28016644375163113`, 0.41180307433443925`, 0.9392664365513199],
              UndirectedEdge[416, 427] -> 
             RGBColor[
              0.418345955917343, 0.5262391779514018, 0.9492118033251243], 
             UndirectedEdge[59, 82] -> 
             RGBColor[
              0.6287680422693919, 0.702219349592166, 0.9654873094673114], 
             UndirectedEdge[271, 444] -> 
             RGBColor[
              0.3516631363265804, 0.4790146664080923, 0.9436286419765962], 
             UndirectedEdge[6, 486] -> 
             RGBColor[
              0.42183205912896027`, 0.5376098751077224, 0.9487025222465063], 
             UndirectedEdge[171, 265] -> 
             RGBColor[
              0.5012215197246698, 0.5977594600107073, 0.9560506796341709], 
             UndirectedEdge[219, 369] -> 
             RGBColor[
              0.40328866537310937`, 0.5237301048936593, 0.9469181750367781], 
             UndirectedEdge[244, 355] -> 
             RGBColor[
              0.2848158963114956, 0.4163448674433432, 0.9395438509309693], 
             UndirectedEdge[450, 500] -> 
             RGBColor[
              0.47190864961638646`, 0.5812191049172628, 0.9518283154704336], 
             UndirectedEdge[18, 243] -> 
             RGBColor[
              0.304985135472816, 0.4378890929293463, 0.9406798243288774], 
             UndirectedEdge[377, 449] -> 
             RGBColor[
              0.3711162283157851, 0.495863956948309, 0.9448681757964545], 
             UndirectedEdge[7, 173] -> 
             RGBColor[
              0.31687575104191146`, 0.4471333491717537, 0.9414761051355593], 
             UndirectedEdge[3, 8] -> 
             RGBColor[
              0.263896868402319, 0.39470271909165544`, 0.9383399083038565], 
             UndirectedEdge[405, 469] -> 
             RGBColor[
              0.3609012308170851, 0.4832999466130656, 0.9443533568772111], 
             UndirectedEdge[148, 190] -> 
             RGBColor[
              0.3985693727059117, 0.5182184041580264, 0.946923545569399], 
             UndirectedEdge[180, 216] -> 
             RGBColor[0.74736580281138, 0.80256711243751, 0.9754540967598744],
              UndirectedEdge[257, 317] -> 
             RGBColor[
              0.45993591512462256`, 0.5661436905595894, 0.951927024455043], 
             UndirectedEdge[49, 462] -> 
             RGBColor[
              0.5317428521035454, 0.6222910937578758, 0.9589838186343871], 
             UndirectedEdge[223, 258] -> 
             RGBColor[
              0.6288333940426508, 0.6952735877074647, 0.8997860459445411], 
             UndirectedEdge[260, 440] -> 
             RGBColor[
              0.3061720689875388, 0.4386304842428811, 0.9407659511066121], 
             UndirectedEdge[262, 332] -> 
             RGBColor[
              0.6626652850025668, 0.6166155133986484, 0.5992378007774068], 
             UndirectedEdge[283, 386] -> 
             RGBColor[
              0.34544298290480047`, 0.470229617457682, 0.9433566971260361], 
             UndirectedEdge[40, 289] -> 
             RGBColor[
              0.3142810333467507, 0.4441488240564089, 0.9413377612652538], 
             UndirectedEdge[95, 430] -> 
             RGBColor[
              0.739932667286073, 0.7947433759856792, 0.9366558579274791], 
             UndirectedEdge[274, 334] -> 
             RGBColor[
              0.4842585740388221, 0.592181951861692, 0.9525417553273933], 
             UndirectedEdge[75, 158] -> 
             RGBColor[
              0.48952580212137536`, 0.5934419626522287, 0.9537897854336539], 
             UndirectedEdge[233, 476] -> 
             RGBColor[
              0.2943387404345882, 0.4234455220944534, 0.9401926557219917], 
             UndirectedEdge[240, 416] -> 
             RGBColor[
              0.3133670309284301, 0.43926907701715756`, 0.9414292066236544], 
             UndirectedEdge[260, 280] -> 
             RGBColor[
              0.47012805294432186`, 0.5755141625292194, 0.9526296189257408], 
             UndirectedEdge[11, 193] -> 
             RGBColor[
              0.3891097934437385, 0.5114490786792627, 0.9460147098553228], 
             UndirectedEdge[3, 162] -> 
             RGBColor[
              0.27836671272926905`, 0.40918284774637104`, 0.9391906219704929],
              UndirectedEdge[117, 338] -> 
             RGBColor[
              0.37790164252663083`, 0.5003825962476031, 0.9453927038774399], 
             UndirectedEdge[40, 472] -> 
             RGBColor[
              0.4217700979653044, 0.5343077066226629, 0.9489999579756883], 
             UndirectedEdge[101, 355] -> 
             RGBColor[
              0.47560974171741077`, 0.5742719493571888, 0.9540487762498258], 
             UndirectedEdge[47, 364] -> 
             RGBColor[
              0.3888791057112213, 0.5112492685600589, 0.9460000106369959], 
             UndirectedEdge[377, 484] -> 
             RGBColor[
              0.4092917335366947, 0.5289296608139782, 0.9473006852318571], 
             UndirectedEdge[21, 227] -> 
             RGBColor[
              0.6959945033006342, 0.7546968486859875, 0.7964626880334795], 
             UndirectedEdge[158, 441] -> 
             RGBColor[
              0.6933172733618971, 0.7602590870913264, 0.9701250933449145], 
             UndirectedEdge[201, 222] -> 
             RGBColor[
              0.47019924860412454`, 0.5761190987000101, 0.95258541995733], 
             UndirectedEdge[107, 477] -> 
             RGBColor[
              0.2954822772115907, 0.4269492658805495, 0.9401734977587513], 
             UndirectedEdge[89, 239] -> 
             RGBColor[
              0.6095525242979929, 0.6925464057260067, 0.9633316514709926], 
             UndirectedEdge[63, 275] -> 
             RGBColor[
              0.4375752905440994, 0.5469996606424254, 0.950256890900377], 
             UndirectedEdge[133, 344] -> 
             RGBColor[
              0.592348876792363, 0.6770802732019758, 0.96261425886426], 
             UndirectedEdge[153, 356] -> 
             RGBColor[
              0.3986962303157734, 0.514047530783035, 0.9473225657758418], 
             UndirectedEdge[151, 188] -> 
             RGBColor[
              0.301841892840578, 0.4322417026478842, 0.9405866335611679], 
             UndirectedEdge[140, 204] -> 
             RGBColor[
              0.42799462254300047`, 0.5451291632367059, 0.9484924167810234], 
             UndirectedEdge[154, 369] -> 
             RGBColor[
              0.4638810509626332, 0.5738483438474993, 0.9514322042968796], 
             UndirectedEdge[16, 179] -> 
             RGBColor[
              0.39144588637107125`, 0.5111663193618396, 0.9464782634105966], 
             UndirectedEdge[161, 341] -> 
             RGBColor[
              0.539748478420372, 0.6358843789418298, 0.9574155872428822], 
             UndirectedEdge[48, 408] -> 
             RGBColor[
              0.426133324455322, 0.539567815801179, 0.9491870781793352], 
             UndirectedEdge[153, 263] -> 
             RGBColor[
              0.5319693767758535, 0.6309157308707836, 0.9562977244892814], 
             UndirectedEdge[62, 132] -> 
             RGBColor[
              0.4384597406884069, 0.5516930893632621, 0.9498501220037253], 
             UndirectedEdge[82, 225] -> 
             RGBColor[
              0.5880707581062895, 0.6698342497137046, 0.9638872337660616], 
             UndirectedEdge[216, 465] -> 
             RGBColor[
              0.5979600035183568, 0.6804909432357213, 0.9635852521742853], 
             UndirectedEdge[119, 489] -> 
             RGBColor[
              0.6427405735192286, 0.7134265178571717, 0.9533136375993806], 
             UndirectedEdge[287, 295] -> 
             RGBColor[
              0.2783997138515448, 0.4096986261746155, 0.9391748861950537], 
             UndirectedEdge[28, 417] -> 
             RGBColor[
              0.45096788754327355`, 0.5637123912149087, 0.9503196077691156], 
             UndirectedEdge[148, 351] -> 
             RGBColor[
              0.45734291775915925`, 0.5659334157502843, 0.95155041433058], 
             UndirectedEdge[218, 336] -> 
             RGBColor[
              0.3139267357719081, 0.44532110433803485`, 0.9412610266254835], 
             UndirectedEdge[127, 254] -> 
             RGBColor[
              0.6153006882001639, 0.6975626673753372, 0.9635451149956523], 
             UndirectedEdge[303, 473] -> 
             RGBColor[
              0.44606869726325016`, 0.5575862436131975, 0.9505276355219427], 
             UndirectedEdge[99, 267] -> 
             RGBColor[
              0.27903600685480684`, 0.41061491348203794`, 0.9392020598423774],
              UndirectedEdge[48, 145] -> 
             RGBColor[
              0.7573452657506341, 0.8095704826967745, 0.956554171327774], 
             UndirectedEdge[224, 342] -> 
             RGBColor[
              0.6129445769114036, 0.6900581459896918, 0.9660800956822204], 
             UndirectedEdge[193, 232] -> 
             RGBColor[
              0.39533949814882224`, 0.5168449357807436, 0.9464116611304191], 
             UndirectedEdge[216, 343] -> 
             RGBColor[
              0.606152373944997, 0.6875867627387671, 0.964107262773642], 
             UndirectedEdge[277, 449] -> 
             RGBColor[
              0.33644337845147504`, 0.46484997102028996`, 0.9426948121777863],
              UndirectedEdge[257, 418] -> 
             RGBColor[
              0.49722875321101423`, 0.6002742041912155, 0.9542363103273678], 
             UndirectedEdge[45, 422] -> 
             RGBColor[
              0.4081488632948009, 0.5188914678462273, 0.9483243282722167], 
             UndirectedEdge[133, 235] -> 
             RGBColor[
              0.36106446833694206`, 0.486710238000758, 0.944244067666437], 
             UndirectedEdge[145, 183] -> 
             RGBColor[
              0.6680982727271536, 0.7350589431927695, 0.9500966238557642], 
             UndirectedEdge[196, 496] -> 
             RGBColor[
              0.43111590963673, 0.5454241275482125, 0.9493567885742014], 
             UndirectedEdge[115, 136] -> 
             RGBColor[
              0.27345768780087526`, 0.4047517464704999, 0.9388843828246395], 
             UndirectedEdge[267, 413] -> 
             RGBColor[
              0.34213260305732746`, 0.4670162463531074, 0.9431584345702473], 
             UndirectedEdge[217, 340] -> 
             RGBColor[
              0.3480473608129305, 0.4758828633923302, 0.9433982479581711], 
             UndirectedEdge[335, 383] -> 
             RGBColor[
              0.4141088396647623, 0.5310747609704166, 0.9481249577281705], 
             UndirectedEdge[80, 493] -> 
             RGBColor[
              0.41036448789661306`, 0.5246306644573422, 0.9481400658391345], 
             UndirectedEdge[307, 372] -> 
             RGBColor[
              0.721553062662221, 0.7765030554848802, 0.7697727083018097], 
             UndirectedEdge[18, 434] -> 
             RGBColor[
              0.4577768135202732, 0.5659075578806263, 0.9516189904819553], 
             UndirectedEdge[130, 179] -> 
             RGBColor[
              0.7261758029248048, 0.7424209761121157, 0.6330953980419791], 
             UndirectedEdge[20, 228] -> 
             RGBColor[
              0.6147791193063294, 0.6915630992101252, 0.9662356771177187], 
             UndirectedEdge[297, 311] -> 
             RGBColor[
              0.314595057528397, 0.4424618678558795, 0.9414294972968328], 
             UndirectedEdge[127, 200] -> 
             RGBColor[
              0.45586614616011273`, 0.5673882314673058, 0.9507883249074411], 
             UndirectedEdge[54, 391] -> 
             RGBColor[
              0.3336204700008323, 0.4590698578777962, 0.9426370515283566], 
             UndirectedEdge[347, 368] -> 
             RGBColor[
              0.2875127070771623, 0.4173229440378568, 0.9397654037687219], 
             UndirectedEdge[22, 182] -> 
             RGBColor[
              0.4550657888478526, 0.5656452696570585, 0.951027371073917], 
             UndirectedEdge[96, 216] -> 
             RGBColor[
              0.5202116775324219, 0.6067766214641812, 0.9588645307774202], 
             UndirectedEdge[340, 363] -> 
             RGBColor[
              0.3776683495812062, 0.5015390750692266, 0.9452856711696738], 
             UndirectedEdge[71, 490] -> 
             RGBColor[
              0.44531110476384417`, 0.5572934857613588, 0.9503789454143534], 
             UndirectedEdge[111, 201] -> 
             RGBColor[
              0.37596965025897733`, 0.49950857253750647`, 0.9451979056707117],
              UndirectedEdge[261, 484] -> 
             RGBColor[
              0.5622479642236202, 0.6549621804508499, 0.9590228177510289], 
             UndirectedEdge[416, 499] -> 
             RGBColor[
              0.3024552219355734, 0.4298178165110118, 0.9407339158035634], 
             UndirectedEdge[42, 430] -> 
             RGBColor[
              0.4329920193166406, 0.5481814893405019, 0.9491634554512994], 
             UndirectedEdge[6, 81] -> 
             RGBColor[
              0.275630711329779, 0.4069197909554951, 0.9390123784686597], 
             UndirectedEdge[282, 353] -> 
             RGBColor[
              0.32652313835567115`, 0.45349379386765865`, 0.9421638981818942],
              UndirectedEdge[275, 441] -> 
             RGBColor[
              0.6721454569357461, 0.7430708527371164, 0.9684583704009289], 
             UndirectedEdge[50, 255] -> 
             RGBColor[
              0.6239993292906403, 0.6967589485550157, 0.9570262069865308], 
             UndirectedEdge[110, 217] -> 
             RGBColor[
              0.6045949224126593, 0.6836914010743091, 0.9651497151320243], 
             UndirectedEdge[30, 110] -> 
             RGBColor[
              0.9279921789451124, 0.943843506704203, 0.9354916655380741], 
             UndirectedEdge[77, 482] -> 
             RGBColor[
              0.2828793269477471, 0.41357864188664506`, 0.9394603231803775], 
             UndirectedEdge[52, 326] -> 
             RGBColor[
              0.33701969551894867`, 0.46045258850628545`, 0.9429108216174135],
              UndirectedEdge[44, 247] -> 
             RGBColor[
              0.2804793339631119, 0.4121319417850907, 0.9392842551859842], 
             UndirectedEdge[337, 348] -> 
             RGBColor[
              0.4611037182303421, 0.566766169080769, 0.9520485960254657], 
             UndirectedEdge[48, 78] -> 
             RGBColor[
              0.42404354321258764`, 0.5373713232152815, 0.9490680682291157], 
             UndirectedEdge[420, 432] -> 
             RGBColor[
              0.4400251176769141, 0.5535527806146814, 0.9498106538424543], 
             UndirectedEdge[469, 474] -> 
             RGBColor[
              0.25287522231226567`, 0.3831182702382858, 0.9377122418640922], 
             UndirectedEdge[172, 366] -> 
             RGBColor[
              0.306131473600877, 0.43717417240344525`, 0.9408153996733545], 
             UndirectedEdge[102, 415] -> 
             RGBColor[
              0.4640134413446748, 0.5701247763668214, 0.9521869649320438], 
             UndirectedEdge[414, 485] -> 
             RGBColor[
              0.3314521388388867, 0.4615089162185224, 0.9423408150885637], 
             UndirectedEdge[102, 193] -> 
             RGBColor[
              0.35309800301659144`, 0.47894664056496045`, 0.9437680665131243],
              UndirectedEdge[128, 498] -> 
             RGBColor[
              0.5151482571271242, 0.6045905196437233, 0.9580797215922567], 
             UndirectedEdge[150, 443] -> 
             RGBColor[
              0.2761639094940176, 0.4059345256163226, 0.9390993386132169], 
             UndirectedEdge[2, 230] -> 
             RGBColor[
              0.24563311360971632`, 0.37550635481569394`, 0.9372998144872218],
              UndirectedEdge[367, 416] -> 
             RGBColor[
              0.2619673864076636, 0.3926747111790484, 0.9382300271586737], 
             UndirectedEdge[61, 473] -> 
             RGBColor[
              0.3665731797729712, 0.4919289966407826, 0.9445786967605665], 
             UndirectedEdge[56, 164] -> 
             RGBColor[
              0.4107349881604144, 0.5298984397231378, 0.9474703709818996], 
             UndirectedEdge[20, 388] -> 
             RGBColor[
              0.4321157519697568, 0.5465521071331283, 0.9493481155440383], 
             UndirectedEdge[195, 296] -> 
             RGBColor[
              0.621277280818095, 0.6876156365034234, 0.9067636689140304], 
             UndirectedEdge[135, 391] -> 
             RGBColor[
              0.43974364049417036`, 0.5547359002936334, 0.9493984558228918], 
             UndirectedEdge[310, 399] -> 
             RGBColor[
              0.3255769274568194, 0.4487335982052057, 0.9422478924235905], 
             UndirectedEdge[150, 476] -> 
             RGBColor[
              0.28477280916719494`, 0.4133911218173501, 0.9396478900878407], 
             UndirectedEdge[142, 222] -> 
             RGBColor[
              0.5211153379485254, 0.620779230730986, 0.9558092740272757], 
             UndirectedEdge[48, 404] -> 
             RGBColor[
              0.5433125902726523, 0.6401246625934294, 0.9571907038073095], 
             UndirectedEdge[330, 415] -> 
             RGBColor[
              0.43665961856744195`, 0.5413741742954153, 0.9506292051912348], 
             UndirectedEdge[326, 495] -> 
             RGBColor[
              0.3360458829634404, 0.4594290497671641, 0.9428553644330038], 
             UndirectedEdge[36, 382] -> 
             RGBColor[
              0.31899225780035384`, 0.4453845078562425, 0.9417421235854344], 
             UndirectedEdge[31, 289] -> 
             RGBColor[
              0.29328968452390936`, 0.42208558551521647`, 0.9401423350037106],
              UndirectedEdge[436, 487] -> 
             RGBColor[
              0.5558638719008386, 0.6407564974437926, 0.9614418506451334], 
             UndirectedEdge[251, 427] -> 
             RGBColor[
              0.4705973814207072, 0.5780721642026898, 0.9523004593349653], 
             UndirectedEdge[108, 437] -> 
             RGBColor[
              0.42064492983208446`, 0.5385379427024151, 0.9480863480852089], 
             UndirectedEdge[258, 397] -> 
             RGBColor[
              0.28735066723726976`, 0.4193541487239232, 0.9396755674507209], 
             UndirectedEdge[308, 422] -> 
             RGBColor[
              0.5080062215897247, 0.6112388595735524, 0.9544727352062075], 
             UndirectedEdge[16, 292] -> 
             RGBColor[
              0.5386506541350807, 0.628517685233978, 0.959540896635465], 
             UndirectedEdge[68, 317] -> 
             RGBColor[
              0.3981469061419406, 0.5159805895043147, 0.9470627673273284], 
             UndirectedEdge[34, 468] -> 
             RGBColor[
              0.27711486056188656`, 0.40859566692046845`, 0.9390926534030768],
              UndirectedEdge[350, 383] -> 
             RGBColor[
              0.4130989334549482, 0.5302548736135332, 0.9480454542119257], 
             UndirectedEdge[190, 342] -> 
             RGBColor[
              0.41148409203729686`, 0.5297691242114015, 0.9477331088348426], 
             UndirectedEdge[61, 303] -> 
             RGBColor[
              0.4915940699216152, 0.597018033238112, 0.9534284720112275], 
             UndirectedEdge[214, 421] -> 
             RGBColor[
              0.45574366869679184`, 0.5668945389736769, 0.9508876181824026], 
             UndirectedEdge[219, 370] -> 
             RGBColor[
              0.3440779919466703, 0.46876670964262873`, 0.9432799960279483], 
             UndirectedEdge[91, 366] -> 
             RGBColor[
              0.6378577324201093, 0.7009388806169221, 0.7074149977523185], 
             UndirectedEdge[273, 477] -> 
             RGBColor[
              0.32855837394983306`, 0.455598118422255, 0.9422810773948682], 
             UndirectedEdge[153, 323] -> 
             RGBColor[
              0.4174238796772553, 0.533731477663503, 0.9483890777019037], 
             UndirectedEdge[170, 433] -> 
             RGBColor[
              0.4144753641938951, 0.5334194611523928, 0.9476309815936292], 
             UndirectedEdge[1, 54] -> 
             RGBColor[
              0.32027104186109334`, 0.44750725418492177`, 0.9417864377717282],
              UndirectedEdge[277, 377] -> 
             RGBColor[
              0.33279652962633643`, 0.46169125386390647`, 0.9424624381954302],
              UndirectedEdge[307, 417] -> 
             RGBColor[
              0.4754219774788715, 0.5848932948188258, 0.9518778007559092], 
             UndirectedEdge[58, 371] -> 
             RGBColor[
              0.3351494937020961, 0.4647113791665757, 0.9425764072710048], 
             UndirectedEdge[9, 269] -> 
             RGBColor[
              0.39070856563323025`, 0.5083899450323107, 0.9466184542789056], 
             UndirectedEdge[184, 453] -> 
             RGBColor[
              0.6944009920407144, 0.7525844640809473, 0.7337839999165815], 
             UndirectedEdge[42, 97] -> 
             RGBColor[
              0.6615373117402035, 0.7294496078356485, 0.9507503688573085], 
             UndirectedEdge[161, 405] -> 
             RGBColor[
              0.5584883458673549, 0.6521159102312817, 0.9586096750255899], 
             UndirectedEdge[304, 429] -> 
             RGBColor[
              0.6193928494553619, 0.6975281056925251, 0.9656233014834383], 
             UndirectedEdge[127, 130] -> 
             RGBColor[
              0.7431389873563219, 0.7561924534163713, 0.6344308020586201], 
             UndirectedEdge[318, 330] -> 
             RGBColor[
              0.47837605041877584`, 0.5740997092963447, 0.9546938919084247], 
             UndirectedEdge[393, 468] -> 
             RGBColor[
              0.3048506517688734, 0.4353040738524727, 0.940761640343463], 
             UndirectedEdge[334, 355] -> 
             RGBColor[
              0.36010560888472026`, 0.4812925760222481, 0.9444143148984554], 
             UndirectedEdge[290, 378] -> 
             RGBColor[
              0.2688792428810598, 0.39993951056959953`, 0.9386236471596583], 
             UndirectedEdge[92, 498] -> 
             RGBColor[
              0.4393338972592576, 0.5451090761526783, 0.950697387226908], 
             UndirectedEdge[340, 362] -> 
             RGBColor[
              0.525564283949459, 0.6223074751611966, 0.9570583084973776], 
             UndirectedEdge[58, 304] -> 
             RGBColor[
              0.5987242754040482, 0.6796260256820145, 0.9643063182213911], 
             UndirectedEdge[51, 308] -> 
             RGBColor[
              0.3653753373948234, 0.48875400094649246`, 0.9445806350938561], 
             UndirectedEdge[59, 447] -> 
             RGBColor[
              0.7086563891374849, 0.770715617209129, 0.9707708609361685], 
             UndirectedEdge[186, 485] -> 
             RGBColor[
              0.3993193728813489, 0.5202921032397378, 0.9466652552291106], 
             UndirectedEdge[340, 379] -> 
             RGBColor[
              0.3876767669870308, 0.5102078631884666, 0.9459233986766769], 
             UndirectedEdge[129, 410] -> 
             RGBColor[
              0.3352169895878056, 0.4637616521140945, 0.9426176227724002], 
             UndirectedEdge[192, 225] -> 
             RGBColor[
              0.5977739812455329, 0.6782386938987418, 0.9645055145642709], 
             UndirectedEdge[306, 420] -> 
             RGBColor[
              0.36199466787628987`, 0.48796331975857626`, 0.944286958031129], 
             UndirectedEdge[16, 45] -> 
             RGBColor[
              0.2698009694491167, 0.4009083036334672, 0.9386761381241369], 
             UndirectedEdge[334, 361] -> 
             RGBColor[
              0.4737324182328438, 0.5836363443804836, 0.9517130977837674], 
             UndirectedEdge[306, 357] -> 
             RGBColor[
              0.5108520161551441, 0.6113998287808582, 0.9553440357780669], 
             UndirectedEdge[335, 496] -> 
             RGBColor[
              0.42080612904974224`, 0.5370541832173732, 0.9485451648804231], 
             UndirectedEdge[176, 345] -> 
             RGBColor[
              0.4439741551858457, 0.557164669903851, 0.9500093899313122], 
             UndirectedEdge[15, 78] -> 
             RGBColor[
              0.46366638136864025`, 0.5695389282188823, 0.9521873231919988], 
             UndirectedEdge[52, 210] -> 
             RGBColor[
              0.28777599258455, 0.41780016808498444`, 0.9397730564109303], 
             UndirectedEdge[392, 465] -> 
             RGBColor[
              0.32902580428566636`, 0.45515326174983106`, 0.9423419741030938],
              UndirectedEdge[354, 414] -> 
             RGBColor[
              0.36231213814127694`, 0.4882382965455886, 0.944307186955686], 
             UndirectedEdge[56, 428] -> 
             RGBColor[
              0.3666335900661994, 0.4880797185535074, 0.9447928260569753], 
             UndirectedEdge[44, 425] -> 
             RGBColor[
              0.2970231440619237, 0.4284671138936408, 0.9402649716087719], 
             UndirectedEdge[106, 468] -> 
             RGBColor[
              0.3341351113069604, 0.46066880082463046`, 0.942627620209999], 
             UndirectedEdge[142, 461] -> 
             RGBColor[
              0.37870639482389473`, 0.5024381776847724, 0.9453518144946305], 
             UndirectedEdge[203, 297] -> 
             RGBColor[
              0.33356132286309337`, 0.4588894936165801, 0.9426380109527497], 
             UndirectedEdge[24, 176] -> 
             RGBColor[
              0.4526559136562772, 0.5642129125389095, 0.9506928497604339], 
             UndirectedEdge[351, 356] -> 
             RGBColor[
              0.43947697217868864`, 0.5471551741788344, 0.9505329751600702], 
             UndirectedEdge[315, 368] -> 
             RGBColor[
              0.3389452665108379, 0.461871241943705, 0.9430426409758091], 
             UndirectedEdge[278, 406] -> 
             RGBColor[
              0.39854168769402637`, 0.5151897988367374, 0.9471950026976821], 
             UndirectedEdge[247, 360] -> 
             RGBColor[
              0.3470796155808761, 0.4730388957955821, 0.94341002461532], 
             UndirectedEdge[78, 145] -> 
             RGBColor[
              0.6253275572352521, 0.6964672056285461, 0.947427914419932], 
             UndirectedEdge[19, 466] -> 
             RGBColor[
              0.3816665509407821, 0.5050021161314479, 0.9455404330248354], 
             UndirectedEdge[60, 151] -> 
             RGBColor[
              0.306485477447082, 0.43712240448958883`, 0.9408510788349405], 
             UndirectedEdge[109, 186] -> 
             RGBColor[
              0.42146117591882687`, 0.5394702201514223, 0.9480761113394311], 
             UndirectedEdge[474, 495] -> 
             RGBColor[
              0.2402074521957742, 0.3698036406628382, 0.9369908310962445], 
             UndirectedEdge[36, 412] -> 
             RGBColor[
              0.34800858639804993`, 0.4705169932844866, 0.9435910183855476], 
             UndirectedEdge[259, 469] -> 
             RGBColor[
              0.31277543893610343`, 0.44161580455839106`, 0.9412868239745218],
              UndirectedEdge[6, 80] -> 
             RGBColor[
              0.2941765471834865, 0.42641264031165005`, 0.9400685363844229], 
             UndirectedEdge[287, 389] -> 
             RGBColor[
              0.6160799525078225, 0.6820196155856706, 0.9029907083115236], 
             UndirectedEdge[158, 410] -> 
             RGBColor[
              0.46732905952950077`, 0.5732080712636274, 0.9524123433467508], 
             UndirectedEdge[414, 415] -> 
             RGBColor[
              0.47327507453289175`, 0.5794575727827584, 0.952729111909213], 
             UndirectedEdge[10, 245] -> 
             RGBColor[
              0.3614746032577256, 0.48722731798708285`, 0.9442642752823143], 
             UndirectedEdge[115, 178] -> 
             RGBColor[
              0.27475877998898546`, 0.406119276854213, 0.9389584780999589], 
             UndirectedEdge[88, 348] -> 
             RGBColor[
              0.4745304289007579, 0.580476726011662, 0.9528279380035659], 
             UndirectedEdge[135, 170] -> 
             RGBColor[
              0.4621792252221988, 0.5741684761397754, 0.9508280314427533], 
             UndirectedEdge[3, 203] -> 
             RGBColor[
              0.3232870755120939, 0.44809060822577307`, 0.9420529077654972], 
             UndirectedEdge[84, 374] -> 
             RGBColor[
              0.5830082984528531, 0.4588247950083402, 0.5752109492041679], 
             UndirectedEdge[29, 172] -> 
             RGBColor[
              0.6080898858876229, 0.6861485865007562, 0.9656348025008916], 
             UndirectedEdge[262, 387] -> 
             RGBColor[
              0.742141058888506, 0.6823283197127243, 0.6051654052476103], 
             UndirectedEdge[179, 276] -> 
             RGBColor[
              0.44124164769140495`, 0.5556424063982612, 0.9496019398923315], 
             UndirectedEdge[348, 428] -> 
             RGBColor[
              0.45277933752092636`, 0.558016717158952, 0.951574534858882], 
             UndirectedEdge[104, 351] -> 
             RGBColor[
              0.6129438313235823, 0.6966544409302364, 0.9626723301704792], 
             UndirectedEdge[111, 271] -> 
             RGBColor[
              0.38061903413599885`, 0.50409480972487, 0.9454736861803172], 
             UndirectedEdge[136, 277] -> 
             RGBColor[
              0.2804596464723545, 0.41211124898404566`, 0.9392831340125106], 
             UndirectedEdge[246, 442] -> 
             RGBColor[
              0.978510551947699, 0.9832938709583159, 0.9123076349038413], 
             UndirectedEdge[206, 266] -> 
             RGBColor[
              0.2638750814051056, 0.3946798195762088, 0.9383386675665961], 
             UndirectedEdge[31, 381] -> 
             RGBColor[
              0.33940643945116994`, 0.4620296007377111, 0.9430808538482305], 
             UndirectedEdge[31, 472] -> 
             RGBColor[
              0.40077874914246303`, 0.5122444680814705, 0.947804531714145], 
             UndirectedEdge[342, 453] -> 
             RGBColor[
              0.6620072424005703, 0.7245266262998522, 0.7317198988341795], 
             UndirectedEdge[200, 475] -> 
             RGBColor[
              0.37111128646547054`, 0.4958596765659511, 0.9448678609061223], 
             UndirectedEdge[92, 101] -> 
             RGBColor[
              0.6598994859958953, 0.733983071620833, 0.9669104042197154], 
             UndirectedEdge[193, 376] -> 
             RGBColor[
              0.4599352089957908, 0.571303162081083, 0.950939702114689], 
             UndirectedEdge[253, 319] -> 
             RGBColor[
              0.350226539595826, 0.475866850267358, 0.9436068000651363], 
             UndirectedEdge[249, 280] -> 
             RGBColor[
              0.5683536679736173, 0.6604541375587677, 0.9591620291724197], 
             UndirectedEdge[153, 195] -> 
             RGBColor[
              0.7573437521068406, 0.8082922604876085, 0.9158184863904182], 
             UndirectedEdge[313, 380] -> 
             RGBColor[
              0.2841520015730121, 0.4159921483036717, 0.9394934081731432], 
             UndirectedEdge[178, 357] -> 
             RGBColor[
              0.4581558741869891, 0.5617492416982007, 0.9521330307727921], 
             UndirectedEdge[163, 494] -> 
             RGBColor[
              0.3438044354675034, 0.4648897006467083, 0.94341947510814], 
             UndirectedEdge[24, 237] -> 
             RGBColor[
              0.3924445985581103, 0.5064190868907629, 0.9470628123363238], 
             UndirectedEdge[101, 345] -> 
             RGBColor[
              0.6069333469947373, 0.6909827738823227, 0.9627407157361842], 
             UndirectedEdge[320, 361] -> 
             RGBColor[
              0.4441616698253754, 0.5582881046600033, 0.9497558057852307], 
             UndirectedEdge[328, 487] -> 
             RGBColor[
              0.5259234298731548, 0.6092871945390297, 0.9597367867645716], 
             UndirectedEdge[322, 494] -> 
             RGBColor[
              0.6525221637577125, 0.7258615074854784, 0.9678825668133122], 
             UndirectedEdge[108, 266] -> 
             RGBColor[
              0.365595044468755, 0.487234869926755, 0.9447112236458332], 
             UndirectedEdge[405, 474] -> 
             RGBColor[
              0.34522535078703637`, 0.46682360279328505`, 0.9434606386998862],
              UndirectedEdge[338, 379] -> 
             RGBColor[
              0.439095242720535, 0.554566963779803, 0.9492486437569035], 
             UndirectedEdge[175, 309] -> 
             RGBColor[
              0.3884592764628044, 0.5108856335663118, 0.9459732594885273], 
             UndirectedEdge[294, 430] -> 
             RGBColor[
              0.42001174094879046`, 0.5369386246260304, 0.9483363635917095], 
             UndirectedEdge[197, 237] -> 
             RGBColor[
              0.27196518540109293`, 0.40318303181821097`, 0.9387993870209314],
              UndirectedEdge[94, 500] -> 
             RGBColor[
              0.5124494196074788, 0.6141319283369069, 0.9550198333898661], 
             UndirectedEdge[242, 365] -> 
             RGBColor[
              0.3967291118797434, 0.5086384857178079, 0.9475147034807658], 
             UndirectedEdge[401, 500] -> 
             RGBColor[
              0.3757636209178392, 0.4998892948354643, 0.9451643035435294], 
             UndirectedEdge[334, 340] -> 
             RGBColor[
              0.41002874864907, 0.5293035699798223, 0.9474207172414997], 
             UndirectedEdge[60, 310] -> 
             RGBColor[
              0.35221022530071877`, 0.476726882887759, 0.9437646193353673], 
             UndirectedEdge[50, 379] -> 
             RGBColor[
              0.35939051719214277`, 0.4849386124468554, 0.9441491852084831], 
             UndirectedEdge[123, 177] -> 
             RGBColor[
              0.3423239471380135, 0.46730522339311265`, 0.9431661142641254], 
             UndirectedEdge[231, 246] -> 
             RGBColor[
              0.698746933855799, 0.7597946940289387, 0.9195902424878957], 
             UndirectedEdge[182, 282] -> 
             RGBColor[
              0.30853852140678395`, 0.43791642259966346`, 0.9410179342930833],
              UndirectedEdge[185, 193] -> 
             RGBColor[
              0.3489399252858337, 0.4745762372325789, 0.9435312701376823], 
             UndirectedEdge[395, 447] -> 
             RGBColor[
              0.4186351108767944, 0.5363234215190573, 0.9480891736228575], 
             UndirectedEdge[22, 282] -> 
             RGBColor[
              0.41475846969943575`, 0.5269872258443961, 0.9485961789857197], 
             UndirectedEdge[195, 323] -> 
             RGBColor[
              0.6464453931949969, 0.7140689183620383, 0.9081969556810092], 
             UndirectedEdge[99, 486] -> 
             RGBColor[
              0.41173992457596237`, 0.5271183428357654, 0.9481235449449388], 
             UndirectedEdge[454, 469] -> 
             RGBColor[
              0.3270229543994557, 0.4539562863517981, 0.9421946630612634], 
             UndirectedEdge[31, 208] -> 
             RGBColor[
              0.3292340581746337, 0.4532187953547245, 0.9424326787083732], 
             UndirectedEdge[398, 472] -> 
             RGBColor[
              0.4472019202332879, 0.5588228164603182, 0.95052937736729], 
             UndirectedEdge[191, 389] -> 
             RGBColor[
              0.6509213617617529, 0.7180564391135611, 0.9049962473858695], 
             UndirectedEdge[133, 151] -> 
             RGBColor[
              0.3761581751760051, 0.5002310379030139, 0.945189444191969], 
             UndirectedEdge[165, 268] -> 
             RGBColor[
              0.3203714064109941, 0.4519113427232873, 0.9416347606165654], 
             UndirectedEdge[166, 495] -> 
             RGBColor[
              0.2879599354156023, 0.41777941887122416`, 0.9397913703759895], 
             UndirectedEdge[346, 430] -> 
             RGBColor[
              0.6725083002038883, 0.7421117364442269, 0.9694276540732915], 
             UndirectedEdge[169, 219] -> 
             RGBColor[
              0.3476632153025672, 0.4725350067059663, 0.943484169194204], 
             UndirectedEdge[197, 345] -> 
             RGBColor[
              0.4080030518692602, 0.5248488437563417, 0.9477597967079836], 
             UndirectedEdge[100, 213] -> 
             RGBColor[
              0.29437470963016, 0.42501223584573206`, 0.94013872330868], 
             UndirectedEdge[73, 187] -> 
             RGBColor[
              0.6427091485725966, 0.7103272072729265, 0.9128180411368563], 
             UndirectedEdge[97, 346] -> 
             RGBColor[
              0.9010535926274511, 0.9233798549393736, 0.9710145674793005], 
             UndirectedEdge[129, 170] -> 
             RGBColor[
              0.4113261403834518, 0.5306917617723779, 0.9474303158371771], 
             UndirectedEdge[36, 37] -> 
             RGBColor[
              0.27446595648986627`, 0.40581150079055667`, 0.9389418022348777],
              UndirectedEdge[143, 302] -> 
             RGBColor[
              0.5859148347060286, 0.6685742194682995, 0.9634702764451308], 
             UndirectedEdge[16, 236] -> 
             RGBColor[
              0.6403286397899484, 0.7076083390830032, 0.9070273965836839], 
             UndirectedEdge[187, 322] -> 
             RGBColor[
              0.9169397522878244, 0.9350508595734004, 0.935317142116612], 
             UndirectedEdge[108, 163] -> 
             RGBColor[
              0.3461376276115639, 0.4667838911383649, 0.9436031525404849], 
             UndirectedEdge[137, 346] -> 
             RGBColor[
              0.6099197616344418, 0.6891768579318549, 0.9650869587736337], 
             UndirectedEdge[243, 276] -> 
             RGBColor[
              0.351057086854234, 0.4784512196167806, 0.9435914353434742], 
             UndirectedEdge[131, 147] -> 
             RGBColor[
              0.6585924197760715, 0.7263484945966271, 0.9425300161324466], 
             UndirectedEdge[9, 468] -> 
             RGBColor[
              0.2752553410212922, 0.4066411939829553, 0.9389867565161526], 
             UndirectedEdge[331, 377] -> 
             RGBColor[
              0.3374572937328204, 0.4665900124493333, 0.9427278618163119], 
             UndirectedEdge[280, 470] -> 
             RGBColor[
              0.5382727146781829, 0.6355197495564626, 0.9569357767987758], 
             UndirectedEdge[234, 468] -> 
             RGBColor[
              0.3011606217641306, 0.4321079553286653, 0.9405265148945261], 
             UndirectedEdge[136, 488] -> 
             RGBColor[
              0.33832594399530913`, 0.4632142335374079, 0.9429343636068273], 
             UndirectedEdge[57, 361] -> 
             RGBColor[
              0.4031989186695505, 0.5228082284565645, 0.9471456955035201], 
             UndirectedEdge[196, 414] -> 
             RGBColor[
              0.42755702585952937`, 0.5423416012951009, 0.9491300196469155], 
             UndirectedEdge[103, 319] -> 
             RGBColor[
              0.6991543862659539, 0.7600076795476074, 0.9144730701673939], 
             UndirectedEdge[224, 263] -> 
             RGBColor[
              0.7154370584596279, 0.7765973844526155, 0.9732282519597064], 
             UndirectedEdge[89, 184] -> 
             RGBColor[
              0.4418615256225984, 0.5561900257851724, 0.9496384781313982], 
             UndirectedEdge[137, 407] -> 
             RGBColor[
              0.3357396487300179, 0.4640753461246083, 0.9426560158805065], 
             UndirectedEdge[53, 272] -> 
             RGBColor[
              0.47099061358081995`, 0.5783110487285777, 0.9523536194578344], 
             UndirectedEdge[236, 243] -> 
             RGBColor[
              0.6473967176862739, 0.7150373370940635, 0.9074299131635954], 
             UndirectedEdge[26, 351] -> 
             RGBColor[
              0.5019900740142015, 0.6049691777482771, 0.9543819404169069], 
             UndirectedEdge[67, 96] -> 
             RGBColor[
              0.4163766828968384, 0.5249027885011066, 0.9490328937460398], 
             UndirectedEdge[284, 464] -> 
             RGBColor[
              0.3645799757020033, 0.49020258345585965`, 0.9444516915596856], 
             UndirectedEdge[325, 401] -> 
             RGBColor[
              0.6031406929876171, 0.6823120739458894, 0.9651121788988939], 
             UndirectedEdge[227, 348] -> 
             RGBColor[
              0.5167124739091633, 0.617012693266715, 0.9555157406113837], 
             UndirectedEdge[106, 117] -> 
             RGBColor[
              0.34485592293698, 0.4719370535864983, 0.9432381545723092], 
             UndirectedEdge[395, 440] -> 
             RGBColor[
              0.336214465614487, 0.46563380431004386`, 0.9426442663395447], 
             UndirectedEdge[204, 361] -> 
             RGBColor[
              0.467780586498568, 0.5787456231610537, 0.9512607822702586], 
             UndirectedEdge[195, 263] -> 
             RGBColor[
              0.7609908902935952, 0.8112531715693189, 0.9161056024683869], 
             UndirectedEdge[360, 393] -> 
             RGBColor[
              0.37114178259991426`, 0.495886090784826, 0.9448698040928425], 
             UndirectedEdge[74, 440] -> 
             RGBColor[
              0.37154833101530027`, 0.4962382225885158, 0.944895708998374], 
             UndirectedEdge[166, 348] -> 
             RGBColor[
              0.4843368542420667, 0.5889705587570347, 0.9534527947548327], 
             UndirectedEdge[209, 477] -> 
             RGBColor[
              0.6295466665706035, 0.6960512541872459, 0.9005562830717668], 
             UndirectedEdge[292, 422] -> 
             RGBColor[
              0.6769985479807649, 0.746500849446738, 0.9691890867835449], 
             UndirectedEdge[36, 416] -> 
             RGBColor[
              0.2443499297373468, 0.37415764720727696`, 0.9372267390639907], 
             UndirectedEdge[306, 418] -> 
             RGBColor[
              0.3671679827491406, 0.4924441850830737, 0.9446165970802444], 
             UndirectedEdge[363, 498] -> 
             RGBColor[
              0.3256358667964366, 0.4513110278571191, 0.9421591448621098], 
             UndirectedEdge[57, 466] -> 
             RGBColor[
              0.33196885375531676`, 0.4619564687082873, 0.9423737397061256], 
             UndirectedEdge[263, 395] -> 
             RGBColor[
              0.44691249398926547`, 0.5592802750113535, 0.9503152728049387], 
             UndirectedEdge[171, 238] -> 
             RGBColor[
              0.34471759890653536`, 0.47061290214085183`, 0.9432734375521373],
              UndirectedEdge[42, 286] -> 
             RGBColor[
              0.36654431437000984`, 0.49190399487955483`, 0.9445768574826144],
              UndirectedEdge[246, 444] -> 
             RGBColor[
              0.6883623864818216, 0.7508001210361266, 0.9189285483119205], 
             UndirectedEdge[46, 306] -> 
             RGBColor[
              0.40212379227867406`, 0.5227211503674836, 0.9468439503532575], 
             UndirectedEdge[229, 411] -> 
             RGBColor[
              0.5835896566813374, 0.6665479461250355, 0.9633277901929047], 
             UndirectedEdge[239, 440] -> 
             RGBColor[
              0.5225107533551439, 0.6181051505101901, 0.9575229522463664], 
             UndirectedEdge[57, 106] -> 
             RGBColor[
              0.35786800522963, 0.4843890119861349, 0.9440240107363483], 
             UndirectedEdge[60, 280] -> 
             RGBColor[
              0.4605044353096089, 0.5653991302225361, 0.9520815681383105], 
             UndirectedEdge[438, 457] -> 
             RGBColor[
              0.2731688243556535, 0.4044481326745715, 0.9388679324787692], 
             UndirectedEdge[130, 368] -> 
             RGBColor[
              0.6030605895836565, 0.6306175856249935, 0.6252095415495549], 
             UndirectedEdge[152, 287] -> 
             RGBColor[
              0.31828917078291863`, 0.444248868866171, 0.9417166071178591], 
             UndirectedEdge[54, 242] -> 
             RGBColor[
              0.4091555571709521, 0.5216994676010055, 0.9482223711568216], 
             UndirectedEdge[89, 235] -> 
             RGBColor[
              0.39610554841109336`, 0.5161111084168264, 0.9467393288513152], 
             UndirectedEdge[60, 260] -> 
             RGBColor[
              0.2885000621273134, 0.42056223562920414`, 0.9397410237893316], 
             UndirectedEdge[88, 243] -> 
             RGBColor[
              0.31071043073474075`, 0.44350497396797545`, 0.9410205820926872],
              UndirectedEdge[36, 367] -> 
             RGBColor[
              0.26869021056410514`, 0.3997408256191391, 0.938612882048856], 
             UndirectedEdge[17, 282] -> 
             RGBColor[
              0.26493693183795275`, 0.3957958917063371, 0.9383991383778798], 
             UndirectedEdge[150, 233] -> 
             RGBColor[
              0.23517578007219486`, 0.36451503423451764`, 0.9367042848124985],
              UndirectedEdge[250, 365] -> 
             RGBColor[
              0.25744767809748087`, 0.38792421117898823`, 0.937972636456718], 
             UndirectedEdge[107, 423] -> 
             RGBColor[
              0.3422571131411664, 0.4708676418853581, 0.9430292984966413], 
             UndirectedEdge[315, 347] -> 
             RGBColor[
              0.3839898751657289, 0.5070144628014259, 0.9456884731900139], 
             UndirectedEdge[288, 492] -> 
             RGBColor[
              0.6330015815466477, 0.7053767162533591, 0.9583210317547999], 
             UndirectedEdge[24, 267] -> 
             RGBColor[
              0.40271025232604407`, 0.5172089398809032, 0.9476474261317338], 
             UndirectedEdge[198, 480] -> 
             RGBColor[
              0.33091160098453376`, 0.46104072949730446`, 0.9423063724944631],
              UndirectedEdge[4, 479] -> 
             RGBColor[
              0.5469114505307167, 0.6430463794777332, 0.9574740192698838], 
             UndirectedEdge[133, 239] -> 
             RGBColor[
              0.5745114442238416, 0.6631455353099382, 0.9608363902861145], 
             UndirectedEdge[115, 253] -> 
             RGBColor[
              0.28613884341229834`, 0.41808044504980996`, 0.9396065558766215],
              UndirectedEdge[199, 371] -> 
             RGBColor[
              0.2461131059371499, 0.37558988163721774`, 0.9373425633171917], 
             UndirectedEdge[93, 189] -> 
             RGBColor[
              0.33248517582121767`, 0.46240368093066914`, 0.9424066392915991],
              UndirectedEdge[357, 418] -> 
             RGBColor[
              0.5072299174090718, 0.6082625488989868, 0.9551132388488633], 
             UndirectedEdge[82, 463] -> 
             RGBColor[
              0.37036519139946733`, 0.4952134465196075, 0.9448203203882626], 
             UndirectedEdge[102, 350] -> 
             RGBColor[
              0.4069757058745105, 0.5238189731914411, 0.9476967454597232], 
             UndirectedEdge[235, 296] -> 
             RGBColor[
              0.28004819636752254`, 0.41167878883642395`, 0.9392597025377264],
              UndirectedEdge[26, 360] -> 
             RGBColor[
              0.4006018110859385, 0.5214028867553351, 0.9467469710574916], 
             UndirectedEdge[309, 320] -> 
             RGBColor[
              0.4182547315833707, 0.5366929592286284, 0.9478717995417232], 
             UndirectedEdge[13, 229] -> 
             RGBColor[
              0.6224711719651735, 0.700225160422114, 0.9658052859652166], 
             UndirectedEdge[353, 420] -> 
             RGBColor[
              0.369007164355171, 0.4940371917502619, 0.9447337881058562], 
             UndirectedEdge[171, 465] -> 
             RGBColor[
              0.3391288790460247, 0.4657722338949052, 0.9429173292645365], 
             UndirectedEdge[104, 224] -> 
             RGBColor[
              0.7556307711444414, 0.8092284511162688, 0.9763924482566759], 
             UndirectedEdge[22, 285] -> 
             RGBColor[
              0.4138475361335231, 0.5260297769100979, 0.9485443026667464], 
             UndirectedEdge[126, 285] -> 
             RGBColor[
              0.40455796382090436`, 0.5184880836162504, 0.9478129935054724], 
             UndirectedEdge[98, 319] -> 
             RGBColor[
              0.4312810703248995, 0.5479757191237185, 0.9487018263275944], 
             UndirectedEdge[286, 411] -> 
             RGBColor[
              0.34752404197410536`, 0.47542959091690956`, 0.9433649025445139],
              UndirectedEdge[259, 491] -> 
             RGBColor[
              0.5075955137511348, 0.6082701353145542, 0.9552673494117132], 
             UndirectedEdge[1, 266] -> 
             RGBColor[
              0.3240324125938233, 0.4514606933096996, 0.9420006422705078], 
             UndirectedEdge[67, 216] -> 
             RGBColor[
              0.6967678186181511, 0.7622824366482679, 0.9709286274012396], 
             UndirectedEdge[41, 451] -> 
             RGBColor[
              0.3969219012438831, 0.5182155338077932, 0.9465124904563722], 
             UndirectedEdge[300, 456] -> 
             RGBColor[
              0.21231644528574106`, 0.34048842400841783`, 0.9354024795137652],
              UndirectedEdge[117, 139] -> 
             RGBColor[
              0.5159971456985823, 0.6110598613241969, 0.9572451268210652], 
             UndirectedEdge[70, 96] -> 
             RGBColor[
              0.32119575096223096`, 0.44625271899379676`, 0.9419206203072443],
              UndirectedEdge[92, 274] -> 
             RGBColor[
              0.5655962054337793, 0.6582155052466554, 0.9589449516203654], 
             UndirectedEdge[241, 436] -> 
             RGBColor[
              0.4454497909514593, 0.5538884351714302, 0.9508316604828742], 
             UndirectedEdge[207, 295] -> 
             RGBColor[
              0.6202817910340906, 0.6952480877482214, 0.9670840148295861], 
             UndirectedEdge[83, 176] -> 
             RGBColor[
              0.3758652768446529, 0.4999773440898948, 0.9451707809692952], 
             UndirectedEdge[56, 495] -> 
             RGBColor[
              0.35344673348106886`, 0.47421949618753717`, 0.9440418540826583],
              UndirectedEdge[219, 334] -> 
             RGBColor[
              0.4411246810265996, 0.556237303678233, 0.9494021225555425], 
             UndirectedEdge[124, 357] -> 
             RGBColor[
              0.5017159716731165, 0.6034866462414732, 0.9547618951023591], 
             UndirectedEdge[40, 291] -> 
             RGBColor[
              0.3400900836932793, 0.4665033262659837, 0.9429822911312875], 
             UndirectedEdge[7, 487] -> 
             RGBColor[
              0.5854199187647496, 0.6685682420300865, 0.9632441516303916], 
             UndirectedEdge[423, 477] -> 
             RGBColor[
              0.318699716279506, 0.4470590446587598, 0.9416528924457837], 
             UndirectedEdge[22, 165] -> 
             RGBColor[
              0.4413717474805062, 0.5537841793071949, 0.950154798867155], 
             UndirectedEdge[302, 368] -> 
             RGBColor[
              0.28755097854850503`, 0.41735609286275377`, 0.9397678423930338],
              UndirectedEdge[297, 419] -> 
             RGBColor[
              0.2879773967145607, 0.41940698790146647`, 0.9397334434868485], 
             UndirectedEdge[263, 463] -> 
             RGBColor[
              0.4785309213800314, 0.5866665676288666, 0.9523299710392006], 
             UndirectedEdge[260, 424] -> 
             RGBColor[
              0.29696749517904897`, 0.4294620446328417, 0.9402232315751832], 
             UndirectedEdge[193, 415] -> 
             RGBColor[
              0.5225432526984446, 0.6221311924191243, 0.9558684366557826], 
             UndirectedEdge[434, 474] -> 
             RGBColor[
              0.42555605090367854`, 0.5320414934562422, 0.9497840657172869], 
             UndirectedEdge[102, 109] -> 
             RGBColor[
              0.3443323086881477, 0.47135423671426974`, 0.943209524221715], 
             UndirectedEdge[58, 118] -> 
             RGBColor[
              0.3212863587311255, 0.4505613208864414, 0.9417715082660707], 
             UndirectedEdge[39, 100] -> 
             RGBColor[
              0.47737379083590714`, 0.5831735872903883, 0.9529444363824697], 
             UndirectedEdge[35, 216] -> 
             RGBColor[
              0.5478622435862334, 0.635839119533882, 0.960439189608838], 
             UndirectedEdge[72, 163] -> 
             RGBColor[
              0.2887137931442734, 0.4172715380430305, 0.9398819093614852], 
             UndirectedEdge[202, 414] -> 
             RGBColor[
              0.3379456772435653, 0.46713329280992505`, 0.9427545776136992], 
             UndirectedEdge[324, 441] -> 
             RGBColor[
              0.8485010571604195, 0.8823066835342018, 0.9749931054452732], 
             UndirectedEdge[18, 52] -> 
             RGBColor[
              0.2734020273678771, 0.40469324382634364`, 0.9388812130453225], 
             UndirectedEdge[168, 368] -> 
             RGBColor[
              0.24979672308546313`, 0.3798825723627919, 0.9375369258873573], 
             UndirectedEdge[208, 397] -> 
             RGBColor[
              0.3614491594942757, 0.4870789093970643, 0.9442672810705552], 
             UndirectedEdge[193, 350] -> 
             RGBColor[
              0.4655055172282802, 0.575825389243744, 0.9513782171834619], 
             UndirectedEdge[2, 365] -> 
             RGBColor[
              0.22943814711102856`, 0.3584844182053908, 0.9363775351034274], 
             UndirectedEdge[42, 248] -> 
             RGBColor[
              0.32429416989991977`, 0.45292149181530483`, 0.9419721355926454],
              UndirectedEdge[46, 68] -> 
             RGBColor[
              0.47039555375786574`, 0.5803880684203508, 0.9515994064726665], 
             UndirectedEdge[260, 470] -> 
             RGBColor[
              0.36626834149588744`, 0.4906828549631307, 0.9445952324497968], 
             UndirectedEdge[32, 344] -> 
             RGBColor[
              0.7576635953639241, 0.8106118262456795, 0.9764804844831692], 
             UndirectedEdge[60, 483] -> 
             RGBColor[
              0.3837861280816639, 0.5031157522945354, 0.9460420219649075], 
             UndirectedEdge[337, 498] -> 
             RGBColor[
              0.2695864233293886, 0.4006828020586233, 0.9386639200400109], 
             UndirectedEdge[86, 168] -> 
             RGBColor[
              0.30808540822097136`, 0.4364971466013843, 0.94102665894363], 
             UndirectedEdge[151, 424] -> 
             RGBColor[
              0.3149529104988176, 0.44602221349322635`, 0.9413332866207922], 
             UndirectedEdge[234, 296] -> 
             RGBColor[
              0.2919928023717736, 0.4224719958739759, 0.9400044211427048], 
             UndirectedEdge[223, 268] -> 
             RGBColor[
              0.6532706286799411, 0.719984263077792, 0.901213388142573], 
             UndirectedEdge[50, 204] -> 
             RGBColor[
              0.37579066711990616`, 0.4991435980187812, 0.9451941882597972], 
             UndirectedEdge[26, 247] -> 
             RGBColor[
              0.34057423020841116`, 0.4674042579561289, 0.942995507211873], 
             UndirectedEdge[64, 435] -> 
             RGBColor[
              0.2639818130535162, 0.39479200130586567`, 0.9383447457760778], 
             UndirectedEdge[143, 214] -> 
             RGBColor[
              0.6880480172127748, 0.7547673954588006, 0.9706051692396112], 
             UndirectedEdge[38, 266] -> 
             RGBColor[
              0.3204458058970199, 0.4483541548570226, 0.9417721068632994], 
             UndirectedEdge[309, 375] -> 
             RGBColor[
              0.3469202829977771, 0.4705150684532703, 0.9434872286951638], 
             UndirectedEdge[70, 385] -> 
             RGBColor[
              0.4146329047681616, 0.533555914879603, 0.9476410199397138], 
             UndirectedEdge[232, 354] -> 
             RGBColor[
              0.39529200008529075`, 0.5168037953454347, 0.9464086345958118], 
             UndirectedEdge[86, 484] -> 
             RGBColor[
              0.4050797781380152, 0.5252814767466758, 0.9470323031583391], 
             UndirectedEdge[106, 360] -> 
             RGBColor[
              0.40042624213800126`, 0.5212508177569837, 0.9467357839593785], 
             UndirectedEdge[163, 322] -> 
             RGBColor[
              0.539377868905921, 0.6207406176964461, 0.9609102175309139], 
             UndirectedEdge[44, 117] -> 
             RGBColor[
              0.28493659563961804`, 0.41681680641381147`, 0.9395380896445336],
              UndirectedEdge[113, 273] -> 
             RGBColor[
              0.32742226897875587`, 0.45440400006443726`, 0.9422163778974819],
              UndirectedEdge[53, 298] -> 
             RGBColor[
              0.4482870408936919, 0.5572610974684917, 0.950957688952926], 
             UndirectedEdge[50, 369] -> 
             RGBColor[
              0.3439064832006917, 0.4715271204536376, 0.9431625562545416], 
             UndirectedEdge[135, 385] -> 
             RGBColor[
              0.45049671163714045`, 0.5640496700526036, 0.9500836320075545], 
             UndirectedEdge[376, 464] -> 
             RGBColor[
              0.4428275862685741, 0.5564853991288876, 0.9498496195221875], 
             UndirectedEdge[95, 408] -> 
             RGBColor[
              0.6378762256989999, 0.7064639191790193, 0.929842756419641], 
             UndirectedEdge[34, 332] -> 
             RGBColor[
              0.34458340220296524`, 0.4701974979180884, 0.9432758407281283], 
             UndirectedEdge[251, 416] -> 
             RGBColor[
              0.2898785310842693, 0.41892451901847416`, 0.9399325401836494], 
             UndirectedEdge[62, 209] -> 
             RGBColor[
              0.6593404493358554, 0.7252614954336658, 0.9023300661177818], 
             UndirectedEdge[109, 496] -> 
             RGBColor[
              0.35715282565356526`, 0.48376955938331834`, 0.9439784401261699],
              UndirectedEdge[179, 254] -> 
             RGBColor[
              0.5983375037686469, 0.6837911900710816, 0.9622097109790113], 
             UndirectedEdge[27, 199] -> 
             RGBColor[
              0.22056810387061798`, 0.34916144036649555`, 0.935872399262939], 
             UndirectedEdge[59, 453] -> 
             RGBColor[
              0.9658169812361423, 0.9708616935117069, 0.7552801746626651], 
             UndirectedEdge[450, 475] -> 
             RGBColor[
              0.43905477034864254`, 0.5527627259795284, 0.9497348953350377], 
             UndirectedEdge[311, 331] -> 
             RGBColor[
              0.3379898925163754, 0.4670513227464554, 0.9427617985398413], 
             UndirectedEdge[329, 486] -> 
             RGBColor[
              0.5265236683419446, 0.626494659437767, 0.9558690183730768], 
             UndirectedEdge[287, 456] -> 
             RGBColor[
              0.21315888222098792`, 0.34137387864094904`, 0.9354504550509537],
              UndirectedEdge[60, 118] -> 
             RGBColor[
              0.28222469321247945`, 0.41396642501834396`, 0.9393836508132081],
              UndirectedEdge[267, 493] -> 
             RGBColor[
              0.40531608212093123`, 0.5193244698996871, 0.9478525665986564], 
             UndirectedEdge[239, 263] -> 
             RGBColor[
              0.6332087817299223, 0.7117516212114997, 0.9651939587117604], 
             UndirectedEdge[64, 91] -> 
             RGBColor[
              0.6301354159487931, 0.692822236382425, 0.7069752232534205], 
             UndirectedEdge[469, 471] -> 
             RGBColor[
              0.33807556159027685`, 0.46352949918029746`, 0.9428989254180257],
              UndirectedEdge[275, 282] -> 
             RGBColor[
              0.4313520567316361, 0.5404586473297133, 0.9499024869412066], 
             UndirectedEdge[132, 423] -> 
             RGBColor[
              0.4554407938527306, 0.5664012241216508, 0.9509321396956003], 
             UndirectedEdge[116, 412] -> 
             RGBColor[
              0.6549963627199025, 0.7275201398582942, 0.968281358301925], 
             UndirectedEdge[89, 453] -> 
             RGBColor[
              0.7408434665168651, 0.7918606492772828, 0.7370057478708979], 
             UndirectedEdge[136, 311] -> 
             RGBColor[
              0.31566509512021956`, 0.44358654520918683`, 0.9414904343547084],
              UndirectedEdge[6, 24] -> 
             RGBColor[
              0.4235821125784698, 0.5390306473370438, 0.9488402928647087], 
             UndirectedEdge[51, 477] -> 
             RGBColor[
              0.27877607364453527`, 0.4103417071973251, 0.9391872570305891], 
             UndirectedEdge[114, 381] -> 
             RGBColor[
              0.3825281334776006, 0.5057483756204426, 0.9455953323022138], 
             UndirectedEdge[95, 294] -> 
             RGBColor[
              0.659626127878043, 0.7264620556795417, 0.9311861872817997], 
             UndirectedEdge[89, 192] -> 
             RGBColor[
              0.41349775068935807`, 0.531622749542779, 0.9478311634737535], 
             UndirectedEdge[108, 374] -> 
             RGBColor[
              0.663888312742738, 0.5294757378685913, 0.5803967010306805], 
             UndirectedEdge[208, 472] -> 
             RGBColor[
              0.4901522612087408, 0.5960242430663496, 0.9532661351147507], 
             UndirectedEdge[34, 360] -> 
             RGBColor[
              0.3434059913929275, 0.4691776838528217, 0.9432008171524562], 
             UndirectedEdge[395, 453] -> 
             RGBColor[
              0.6757957029754518, 0.7364694978216354, 0.7325984873493541], 
             UndirectedEdge[101, 361] -> 
             RGBColor[
              0.5892365510655343, 0.6766157177154244, 0.9613475591351379], 
             UndirectedEdge[11, 211] -> 
             RGBColor[
              0.3632557950050519, 0.4890556446914175, 0.9443673159366028], 
             UndirectedEdge[70, 433] -> 
             RGBColor[
              0.39073090595402793`, 0.5128532048561916, 0.9461180057109849], 
             UndirectedEdge[108, 206] -> 
             RGBColor[
              0.3598951515437665, 0.48124392106850744`, 0.944386623175991], 
             UndirectedEdge[251, 499] -> 
             RGBColor[
              0.35470664743893754`, 0.4816508027622997, 0.9438225718134043], 
             UndirectedEdge[116, 399] -> 
             RGBColor[
              0.5453290776711476, 0.6248453443761987, 0.9615748964826375], 
             UndirectedEdge[350, 479] -> 
             RGBColor[
              0.48899206210587104`, 0.5960248107157295, 0.9529143928473695], 
             UndirectedEdge[347, 421] -> 
             RGBColor[
              0.3535722147187028, 0.4806682141582789, 0.9437502867636105], 
             UndirectedEdge[153, 447] -> 
             RGBColor[
              0.5036919936633826, 0.6079588773784874, 0.9540716253072004], 
             UndirectedEdge[195, 453] -> 
             RGBColor[
              0.9898740992797816, 0.9884423943796008, 0.6983888170128024], 
             UndirectedEdge[338, 425] -> 
             RGBColor[
              0.38998819094893655`, 0.5120329037274324, 0.9461195858416782], 
             UndirectedEdge[164, 348] -> 
             RGBColor[
              0.4968807356151414, 0.5998354383285824, 0.9542520797838062], 
             UndirectedEdge[31, 258] -> 
             RGBColor[
              0.25513556591762776`, 0.3854940346815834, 0.9378409650885389], 
             UndirectedEdge[31, 203] -> 
             RGBColor[
              0.3231638269177527, 0.44796106613870823`, 0.9420458889403794], 
             UndirectedEdge[398, 445] -> 
             RGBColor[
              0.2974084421326723, 0.4277101600020923, 0.9403294575883192], 
             UndirectedEdge[44, 369] -> 
             RGBColor[
              0.3306461618420712, 0.4575896819527936, 0.9424074005700556], 
             UndirectedEdge[267, 278] -> 
             RGBColor[
              0.2739627308987875, 0.40528257878798757`, 0.9389131442819212], 
             UndirectedEdge[130, 477] -> 
             RGBColor[
              0.617788980547486, 0.6460980583619012, 0.6260483016262433], 
             UndirectedEdge[4, 482] -> 
             RGBColor[
              0.47780209034840815`, 0.5833307684581723, 0.9530307981574313], 
             UndirectedEdge[219, 274] -> 
             RGBColor[
              0.4623255332971742, 0.5734491106389961, 0.9510711313075628], 
             UndirectedEdge[44, 269] -> 
             RGBColor[
              0.38966900862153653`, 0.5072973047012992, 0.9465592530449765], 
             UndirectedEdge[130, 143] -> 
             RGBColor[
              0.90142444574118, 0.8818357122305391, 0.6489119756016521], 
             UndirectedEdge[315, 401] -> 
             RGBColor[
              0.38406337166063886`, 0.5070781217712756, 0.9456931563216793], 
             UndirectedEdge[75, 163] -> 
             RGBColor[
              0.2864476004006279, 0.4153086757906439, 0.9397375095637757], 
             UndirectedEdge[9, 139] -> 
             RGBColor[
              0.5060067402935333, 0.6005593118152026, 0.956676188012728], 
             UndirectedEdge[134, 438] -> 
             RGBColor[
              0.3255390014848424, 0.45360677783883313`, 0.9420658420522439], 
             UndirectedEdge[76, 431] -> 
             RGBColor[
              0.3579543355624144, 0.4844637869813041, 0.9440295116288144], 
             UndirectedEdge[90, 124] -> 
             RGBColor[
              0.3503414458411494, 0.47786988453970736`, 0.9435444250275895], 
             UndirectedEdge[37, 188] -> 
             RGBColor[
              0.28372421718276836`, 0.41554251978642864`, 0.9394690464849691],
              UndirectedEdge[26, 106] -> 
             RGBColor[
              0.39392085676553634`, 0.5156161799175305, 0.9463212665559315], 
             UndirectedEdge[107, 446] -> 
             RGBColor[
              0.42525679435983976`, 0.5406356777504748, 0.9489043118525622], 
             UndirectedEdge[19, 234] -> 
             RGBColor[
              0.3745912128722656, 0.4988738139133302, 0.9450895987395852], 
             UndirectedEdge[39, 243] -> 
             RGBColor[
              0.4678388330963097, 0.574876368937962, 0.9523382876100821], 
             UndirectedEdge[129, 265] -> 
             RGBColor[
              0.5460474396570428, 0.6389713076867423, 0.9588195885360082], 
             UndirectedEdge[396, 446] -> 
             RGBColor[
              0.42943661677792455`, 0.5442560298450366, 0.9491706464409708], 
             UndirectedEdge[325, 368] -> 
             RGBColor[
              0.5580225878378161, 0.6371051941183188, 0.9624616635530238], 
             UndirectedEdge[52, 56] -> 
             RGBColor[
              0.35442054603657713`, 0.47524303492665854`, 0.9440973112670679],
              UndirectedEdge[402, 431] -> 
             RGBColor[
              0.44744367432104154`, 0.5602345923865357, 0.9502125603578615], 
             UndirectedEdge[165, 353] -> 
             RGBColor[
              0.35313641613674157`, 0.4802907473304576, 0.9437225180633295], 
             UndirectedEdge[237, 329] -> 
             RGBColor[
              0.38355409685285535`, 0.4992013770938993, 0.9463629194751053], 
             UndirectedEdge[63, 75] -> 
             RGBColor[
              0.31145636503441876`, 0.4415944730680186, 0.9411617217125183], 
             UndirectedEdge[392, 492] -> 
             RGBColor[
              0.291009734894917, 0.42222565318676886`, 0.9399196237778056], 
             UndirectedEdge[125, 177] -> 
             RGBColor[
              0.3123508315588682, 0.4413440171710492, 0.9412562538436078], 
             UndirectedEdge[210, 348] -> 
             RGBColor[
              0.48317909885550614`, 0.5879677692316736, 0.9533790236053639], 
             UndirectedEdge[469, 491] -> 
             RGBColor[
              0.4633711771573457, 0.5662489448142294, 0.9525854854786084], 
             UndirectedEdge[35, 171] -> 
             RGBColor[
              0.2890311191139013, 0.42112041019306573`, 0.9397712666990893], 
             UndirectedEdge[8, 40] -> 
             RGBColor[
              0.2847649686308191, 0.416636415545783, 0.9395283157402818], 
             UndirectedEdge[405, 491] -> 
             RGBColor[
              0.5557213056321164, 0.6499542773692287, 0.9583338823144025], 
             UndirectedEdge[98, 136] -> 
             RGBColor[
              0.35653129952317913`, 0.4789827974678745, 0.9440943927626992], 
             UndirectedEdge[14, 75] -> 
             RGBColor[
              0.41335638044791956`, 0.5316041947443748, 0.9477934495417344], 
             UndirectedEdge[121, 500] -> 
             RGBColor[
              0.34323379773708906`, 0.46791349750054145`, 0.9432306722331025],
              UndirectedEdge[1, 265] -> 
             RGBColor[
              0.5489961629989109, 0.6415253436383237, 0.9590074785798983], 
             UndirectedEdge[227, 495] -> 
             RGBColor[
              0.32033555508269895`, 0.4458215533809045, 0.9418543162325406], 
             UndirectedEdge[127, 368] -> 
             RGBColor[
              0.3825464961949366, 0.4977545909715138, 0.9463408320635822], 
             UndirectedEdge[207, 389] -> 
             RGBColor[
              0.9579620296903684, 0.9675690771592766, 0.9308998369460559], 
             UndirectedEdge[249, 260] -> 
             RGBColor[
              0.3963492947913218, 0.5156172429654358, 0.9468214848234406], 
             UndirectedEdge[42, 95] -> 
             RGBColor[
              0.6726064062458932, 0.7377049203940131, 0.9320132791413898], 
             UndirectedEdge[190, 323] -> 
             RGBColor[
              0.399431076486923, 0.5191241094670447, 0.946972618324951], 
             UndirectedEdge[109, 295] -> 
             RGBColor[
              0.3527596916409974, 0.4799644475069677, 0.943698513511585], 
             UndirectedEdge[382, 499] -> 
             RGBColor[
              0.3770975499985805, 0.5010446771599772, 0.9452493003250071], 
             UndirectedEdge[213, 254] -> 
             RGBColor[
              0.48466329139181263`, 0.5819108901914877, 0.9548615055247955], 
             UndirectedEdge[47, 374] -> 
             RGBColor[
              0.6193769575259382, 0.49114752529995437`, 0.577498229611465], 
             UndirectedEdge[244, 390] -> 
             RGBColor[
              0.4742778400442127, 0.5802550142288635, 0.952812653388287], 
             UndirectedEdge[92, 370] -> 
             RGBColor[
              0.44734866408327545`, 0.553533104250288, 0.9511538163407508], 
             UndirectedEdge[295, 458] -> 
             RGBColor[
              0.3166969187410149, 0.44872868618867157`, 0.9414006255114561], 
             UndirectedEdge[278, 493] -> 
             RGBColor[
              0.4110225318643397, 0.5253223103898202, 0.9481775404696077], 
             UndirectedEdge[6, 156] -> 
             RGBColor[
              0.5907453553847892, 0.671647602470778, 0.9642893298861757], 
             UndirectedEdge[79, 413] -> 
             RGBColor[
              0.41094988396586773`, 0.530365867374664, 0.947406341110959], 
             UndirectedEdge[122, 476] -> 
             RGBColor[
              0.32979921429186326`, 0.4600772360542941, 0.9422354921980511], 
             UndirectedEdge[123, 455] -> 
             RGBColor[
              0.3523745894411108, 0.4778690857011957, 0.943738483474694], 
             UndirectedEdge[113, 302] -> 
             RGBColor[
              0.30114326454125734`, 0.43164244724184364`, 0.9405419029723359],
              UndirectedEdge[402, 462] -> 
             RGBColor[
              0.6464296501888891, 0.7218010278034384, 0.9667023332457567], 
             UndirectedEdge[140, 363] -> 
             RGBColor[
              0.4015860552094125, 0.5222553895455402, 0.9468096862227064], 
             UndirectedEdge[440, 453] -> 
             RGBColor[
              0.6538016955740161, 0.7174193940614662, 0.7311970486462718], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.33486551753193083`, 0.4614365040775039, 0.942669215763972], 
             UndirectedEdge[102, 202] -> 
             RGBColor[
              0.3286840440553483, 0.457800496393988, 0.94221243063653], 
             UndirectedEdge[363, 379] -> 
             RGBColor[
              0.4083453410383445, 0.5281099431989772, 0.9472403819387242], 
             UndirectedEdge[162, 297] -> 
             RGBColor[
              0.2886409600802685, 0.41998173313717807`, 0.9397757251577453], 
             UndirectedEdge[19, 393] -> 
             RGBColor[
              0.3782812428770084, 0.5020699324371376, 0.9453247241885221], 
             UndirectedEdge[96, 238] -> 
             RGBColor[
              0.32315758765755476`, 0.4479519633345068, 0.9420456268066862], 
             UndirectedEdge[117, 247] -> 
             RGBColor[
              0.2915092963798548, 0.4237251316250966, 0.9399123952282507], 
             UndirectedEdge[162, 223] -> 
             RGBColor[
              0.6519412922599508, 0.7188328586851875, 0.9011286840013772], 
             UndirectedEdge[355, 362] -> 
             RGBColor[
              0.47564114418510917`, 0.5742964812036224, 0.9540519061543333], 
             UndirectedEdge[59, 395] -> 
             RGBColor[
              0.6482297512766131, 0.7190761037602846, 0.9667273923559381], 
             UndirectedEdge[161, 403] -> 
             RGBColor[
              0.49577350357874894`, 0.5977954659805172, 0.9546135407315175], 
             UndirectedEdge[214, 477] -> 
             RGBColor[
              0.4044125520190808, 0.5190297415901626, 0.9477414952642024], 
             UndirectedEdge[65, 309] -> 
             RGBColor[
              0.40870157914969585`, 0.5284184987459817, 0.9472630811161705], 
             UndirectedEdge[361, 498] -> 
             RGBColor[
              0.3686709623288966, 0.4877417222472697, 0.9451345421423303], 
             UndirectedEdge[54, 70] -> 
             RGBColor[
              0.3323115964889935, 0.45793617742773707`, 0.9425536512655737], 
             UndirectedEdge[369, 390] -> 
             RGBColor[
              0.5117315369639471, 0.6126955240231948, 0.9551991698370087], 
             UndirectedEdge[56, 88] -> 
             RGBColor[
              0.388384681446031, 0.5105397274062174, 0.9460462292016593], 
             UndirectedEdge[289, 419] -> 
             RGBColor[
              0.3310090391847733, 0.4611251255689656, 0.9423125811704212], 
             UndirectedEdge[124, 178] -> 
             RGBColor[
              0.30895789504503046`, 0.4380176953429027, 0.9410542483284652], 
             UndirectedEdge[67, 465] -> 
             RGBColor[
              0.4941250088827732, 0.5986171102726467, 0.9537536151429049], 
             UndirectedEdge[7, 461] -> 
             RGBColor[
              0.3484091666364197, 0.47619624141174716`, 0.9434213019053115], 
             UndirectedEdge[273, 423] -> 
             RGBColor[
              0.37533320987940877`, 0.4995164944270637, 0.9451368781327582], 
             UndirectedEdge[63, 467] -> 
             RGBColor[
              0.3221804999766975, 0.4508831797443258, 0.9418450541080601], 
             UndirectedEdge[179, 368] -> 
             RGBColor[
              0.3655833117634195, 0.48398311366725816`, 0.9450054280469413], 
             UndirectedEdge[211, 485] -> 
             RGBColor[
              0.3548663185657529, 0.481789101867043, 0.9438327459164134], 
             UndirectedEdge[21, 320] -> 
             RGBColor[
              0.6992248417492563, 0.7574948054886527, 0.7966685223429496], 
             UndirectedEdge[318, 479] -> 
             RGBColor[
              0.5877462294273692, 0.6750561488920392, 0.96146929903688], 
             UndirectedEdge[343, 465] -> 
             RGBColor[
              0.4035095642096192, 0.5239214363631459, 0.9469322505153073], 
             UndirectedEdge[229, 313] -> 
             RGBColor[
              0.5642861739844828, 0.6480042741791959, 0.9621645736550866], 
             UndirectedEdge[168, 401] -> 
             RGBColor[
              0.2949148282352641, 0.4250894521903624, 0.9401874412332274], 
             UndirectedEdge[70, 216] -> 
             RGBColor[
              0.6015868866835437, 0.683632367140958, 0.9638163539624441], 
             UndirectedEdge[5, 193] -> 
             RGBColor[
              0.3569200502701031, 0.4829638545601935, 0.9439857264499996], 
             UndirectedEdge[213, 471] -> 
             RGBColor[
              0.33447506059456933`, 0.4597451443488606, 0.9426938822127839], 
             UndirectedEdge[145, 404] -> 
             RGBColor[
              0.7445966042953169, 0.7992205450066941, 0.9555505499981258], 
             UndirectedEdge[28, 173] -> 
             RGBColor[
              0.345000438100341, 0.4714935395138919, 0.9432681853252383], 
             UndirectedEdge[210, 243] -> 
             RGBColor[
              0.3193591006894889, 0.4509960171879871, 0.9415716676944852], 
             UndirectedEdge[133, 424] -> 
             RGBColor[
              0.35701657527325914`, 0.48245564573958355`, 0.9440135461447814],
              UndirectedEdge[201, 400] -> 
             RGBColor[
              0.3497942207574293, 0.4768367311186056, 0.9435300304488965], 
             UndirectedEdge[120, 125] -> 
             RGBColor[
              0.5886001697181265, 0.6714884342985371, 0.9633705510072534], 
             UndirectedEdge[96, 343] -> 
             RGBColor[
              0.3257612382236843, 0.45020711459160584`, 0.9422115291184423], 
             UndirectedEdge[22, 149] -> 
             RGBColor[
              0.7769561678617933, 0.8206767188866353, 0.6987172793865143], 
             UndirectedEdge[140, 369] -> 
             RGBColor[
              0.39611043862378603`, 0.5175126856715624, 0.9464607847757679], 
             UndirectedEdge[169, 370] -> 
             RGBColor[
              0.2725495669642859, 0.4037972538930579, 0.9388326666864402], 
             UndirectedEdge[154, 380] -> 
             RGBColor[
              0.40983108325954054`, 0.5243091775193471, 0.9480879198444143], 
             UndirectedEdge[33, 489] -> 
             RGBColor[
              0.31693688387232366`, 0.4482683488826228, 0.9414403813317658], 
             UndirectedEdge[271, 284] -> 
             RGBColor[
              0.3318720987289292, 0.4618726643674794, 0.9423675745614013], 
             UndirectedEdge[112, 356] -> 
             RGBColor[
              0.2827565616711416, 0.41452545249080586`, 0.9394139399351], 
             UndirectedEdge[133, 155] -> 
             RGBColor[
              0.42725632607011943`, 0.5444896879397562, 0.9484453731826215], 
             UndirectedEdge[82, 447] -> 
             RGBColor[
              0.3991734018695732, 0.5194666673509387, 0.9468490907342308], 
             UndirectedEdge[225, 260] -> 
             RGBColor[
              0.5774900704865626, 0.6596876838146605, 0.9632490014217556], 
             UndirectedEdge[133, 225] -> 
             RGBColor[
              0.6375391505807727, 0.7126812849214024, 0.9670393159913537], 
             UndirectedEdge[442, 444] -> 
             RGBColor[
              0.6814776231492587, 0.7458653902022621, 0.9395352314898215], 
             UndirectedEdge[49, 431] -> 
             RGBColor[
              0.33275687623569783`, 0.4607246583409732, 0.9424940457464919], 
             UndirectedEdge[220, 427] -> 
             RGBColor[
              0.5155388903427145, 0.6169982404050158, 0.9551640925432596], 
             UndirectedEdge[151, 192] -> 
             RGBColor[
              0.3363930058407652, 0.4657884468803535, 0.9426556427648862], 
             UndirectedEdge[167, 326] -> 
             RGBColor[
              0.4230275258578019, 0.5408269137415254, 0.9481759177724738], 
             UndirectedEdge[109, 196] -> 
             RGBColor[
              0.46805950969663834`, 0.577422817080776, 0.9517108021020759], 
             UndirectedEdge[212, 451] -> 
             RGBColor[
              0.3782482698172136, 0.5020413728300176, 0.9453226231743088], 
             UndirectedEdge[186, 414] -> 
             RGBColor[
              0.38095869208171795`, 0.5043890043657472, 0.9454953288842707], 
             UndirectedEdge[349, 419] -> 
             RGBColor[
              0.3115686699115271, 0.4442029118045906, 0.9410769315952545], 
             UndirectedEdge[162, 221] -> 
             RGBColor[
              0.32968334553891, 0.45997687636421886`, 0.9422281091435717], 
             UndirectedEdge[163, 364] -> 
             RGBColor[
              0.317912973932169, 0.442562400848007, 0.9417424553414682], 
             UndirectedEdge[191, 300] -> 
             RGBColor[
              0.27937544245325185`, 0.4103879751465368, 0.9392427625581393], 
             UndirectedEdge[438, 460] -> 
             RGBColor[
              0.27412386991620813`, 0.40545194611210045`, 0.9389223209105795],
              UndirectedEdge[172, 473] -> 
             RGBColor[
              0.3252790166328662, 0.4561620680338111, 0.9419474692002736], 
             UndirectedEdge[141, 188] -> 
             RGBColor[
              0.6278648316551099, 0.6946112540805323, 0.9090086252601354], 
             UndirectedEdge[79, 122] -> 
             RGBColor[
              0.3607767510132989, 0.48690842138613494`, 0.9442093534455809], 
             UndirectedEdge[326, 475] -> 
             RGBColor[
              0.3909956891979334, 0.5130825467936697, 0.9461348774651479], 
             UndirectedEdge[98, 124] -> 
             RGBColor[
              0.40139248919741677`, 0.5220877323948602, 0.9467973523675857], 
             UndirectedEdge[204, 498] -> 
             RGBColor[
              0.3520444341300246, 0.4741848015482849, 0.943841875420427], 
             UndirectedEdge[72, 144] -> 
             RGBColor[
              0.35533119467066565`, 0.48219175418376603`, 0.9438623674107447],
              UndirectedEdge[98, 331] -> 
             RGBColor[
              0.378856096919335, 0.502447575005143, 0.9453657569478322], 
             UndirectedEdge[311, 377] -> 
             RGBColor[
              0.36800197827420156`, 0.49316655008904764`, 0.9446697385376279],
              UndirectedEdge[299, 389] -> 
             RGBColor[
              0.71987787227899, 0.7777831026685993, 0.9093900952601797], 
             UndirectedEdge[131, 238] -> 
             RGBColor[
              0.6865249902513193, 0.7505422832104736, 0.9443098548233271], 
             UndirectedEdge[4, 185] -> 
             RGBColor[
              0.46073701656859833`, 0.5664701386210632, 0.9520195755067957], 
             UndirectedEdge[162, 258] -> 
             RGBColor[
              0.29351848394419955`, 0.42510831997104415`, 0.9400534929261464],
              UndirectedEdge[124, 253] -> 
             RGBColor[
              0.32033795846834334`, 0.4499788635384996, 0.9417023261051277], 
             UndirectedEdge[319, 449] -> 
             RGBColor[
              0.39352911596352347`, 0.5152768737242922, 0.94629630517843], 
             UndirectedEdge[256, 271] -> 
             RGBColor[
              0.4158861002136168, 0.532836895960785, 0.9482194539399633], 
             UndirectedEdge[379, 478] -> 
             RGBColor[
              0.36538850020905633`, 0.49090288674624577`, 0.9445032100263248],
              UndirectedEdge[349, 371] -> 
             RGBColor[
              0.31056864813363505`, 0.44333674320313654`, 0.9410132110918519],
              UndirectedEdge[130, 325] -> 
             RGBColor[
              0.9186150789992014, 0.8955430565631763, 0.6505516335480617], 
             UndirectedEdge[269, 369] -> 
             RGBColor[
              0.4464085372407325, 0.5596633700802871, 0.9500567040127649], 
             UndirectedEdge[43, 355] -> 
             RGBColor[
              0.30228114287113245`, 0.4314723861844845, 0.9406567209978383], 
             UndirectedEdge[11, 414] -> 
             RGBColor[
              0.33984161527818574`, 0.46877545904289697`, 0.942875385108753], 
             UndirectedEdge[117, 255] -> 
             RGBColor[
              0.6217689703487626, 0.6944146998941776, 0.9568991913443112], 
             UndirectedEdge[401, 475] -> 
             RGBColor[
              0.34290974165009536`, 0.4714329158977298, 0.9430708834081336], 
             UndirectedEdge[58, 141] -> 
             RGBColor[
              0.6715700817802599, 0.7360868517903343, 0.9116609279867707], 
             UndirectedEdge[96, 180] -> 
             RGBColor[
              0.4669746670900673, 0.5651874642903487, 0.9535583631046745], 
             UndirectedEdge[119, 375] -> 
             RGBColor[
              0.6071868669882072, 0.6782401074570978, 0.9512089839968706], 
             UndirectedEdge[220, 382] -> 
             RGBColor[
              0.40946236806928366`, 0.5290774558697657, 0.9473115579133874], 
             UndirectedEdge[104, 356] -> 
             RGBColor[
              0.4425370811873416, 0.5496395085283987, 0.95077387815078], 
             UndirectedEdge[225, 440] -> 
             RGBColor[
              0.585538459712075, 0.6676409001216541, 0.9637258779516058], 
             UndirectedEdge[259, 341] -> 
             RGBColor[
              0.38638569996389127`, 0.5090896058239385, 0.9458411330276082], 
             UndirectedEdge[290, 362] -> 
             RGBColor[
              0.4735318011646893, 0.5720794279490892, 0.9539317821898137], 
             UndirectedEdge[79, 267] -> 
             RGBColor[
              0.3370735620639193, 0.46263435931941094`, 0.9428360769516817], 
             UndirectedEdge[90, 317] -> 
             RGBColor[
              0.31856255349071294`, 0.4485152735655947, 0.941586482901769], 
             UndirectedEdge[41, 389] -> 
             RGBColor[
              0.6956036055985274, 0.7567579529301007, 0.9078433604521918], 
             UndirectedEdge[5, 300] -> 
             RGBColor[
              0.27295194121695987`, 0.40422017474461935`, 0.9388555813048705],
              UndirectedEdge[290, 340] -> 
             RGBColor[
              0.30496729274512285`, 0.4334089478466084, 0.9408421616000626], 
             UndirectedEdge[288, 392] -> 
             RGBColor[
              0.6047262614400846, 0.6766319697061521, 0.9566751162672316], 
             UndirectedEdge[45, 292] -> 
             RGBColor[
              0.5142583759466226, 0.6028798542981464, 0.9581517924777743], 
             UndirectedEdge[42, 145] -> 
             RGBColor[
              0.6621475190248798, 0.7299046994294375, 0.9497174470919001], 
             UndirectedEdge[100, 368] -> 
             RGBColor[
              0.284933708665846, 0.4150891452382037, 0.9396010722704715], 
             UndirectedEdge[302, 315] -> 
             RGBColor[
              0.38402814663707163`, 0.5070476116263228, 0.9456909118143257], 
             UndirectedEdge[255, 338] -> 
             RGBColor[
              0.7037040548190325, 0.7663872998879633, 0.9621256655349513], 
             UndirectedEdge[59, 263] -> 
             RGBColor[
              0.7369337722499558, 0.7936724707014251, 0.9729969601182495], 
             UndirectedEdge[413, 486] -> 
             RGBColor[
              0.474836520778483, 0.5835196757068348, 0.9520799196728088], 
             UndirectedEdge[140, 247] -> 
             RGBColor[
              0.3459436107448268, 0.47205494550385946`, 0.9433376393916966], 
             UndirectedEdge[82, 453] -> 
             RGBColor[
              0.6563339939682307, 0.7196127436535167, 0.7313584044607275], 
             UndirectedEdge[199, 349] -> 
             RGBColor[
              0.24338254219648517`, 0.37314086156591875`, 0.9371716477746602],
              UndirectedEdge[265, 462] -> 
             RGBColor[
              0.7474737903860953, 0.8026514731516134, 0.9754648599521206], 
             UndirectedEdge[113, 386] -> 
             RGBColor[
              0.2708260868655471, 0.4019857670343337, 0.9387345170444772], 
             UndirectedEdge[140, 219] -> 
             RGBColor[
              0.4120134135356283, 0.5312870432334401, 0.9474741082747019], 
             UndirectedEdge[13, 313] -> 
             RGBColor[
              0.3472032460716332, 0.47332776817478417`, 0.9434112460235029], 
             UndirectedEdge[74, 463] -> 
             RGBColor[
              0.42516076580750195`, 0.5426746189661982, 0.9483118459357185], 
             UndirectedEdge[146, 415] -> 
             RGBColor[
              0.6092542705919823, 0.6936590893155068, 0.9623818744343813], 
             UndirectedEdge[213, 475] -> 
             RGBColor[
              0.3072326374646084, 0.4361491266776875, 0.9409580191004718], 
             UndirectedEdge[49, 328] -> 
             RGBColor[
              0.25649169516078396`, 0.38691941249970074`, 0.9379181946427231],
              UndirectedEdge[259, 450] -> 
             RGBColor[
              0.44099707082443, 0.5544450490287951, 0.949858657003846], 
             UndirectedEdge[454, 500] -> 
             RGBColor[
              0.4021588697852012, 0.5227515327405907, 0.9468461854609556], 
             UndirectedEdge[469, 495] -> 
             RGBColor[
              0.25588333222582293`, 0.38627998448261874`, 0.9378835492735694],
              UndirectedEdge[158, 182] -> 
             RGBColor[
              0.4928311923062038, 0.5963049254965859, 0.9540004019733894], 
             UndirectedEdge[302, 347] -> 
             RGBColor[
              0.3325955872033961, 0.4624993137204747, 0.9424136746072385], 
             UndirectedEdge[87, 107] -> 
             RGBColor[
              0.4246382341425001, 0.5401335027002182, 0.9488556165263926], 
             UndirectedEdge[80, 307] -> 
             RGBColor[
              0.363723208112193, 0.48665046249128063`, 0.9444999881211025], 
             UndirectedEdge[159, 443] -> 
             RGBColor[
              0.4126439917647159, 0.5306045201448222, 0.9478537811511429], 
             UndirectedEdge[396, 443] -> 
             RGBColor[
              0.3270586445463271, 0.45770349228575125`, 0.9420608655172562], 
             UndirectedEdge[15, 452] -> 
             RGBColor[
              0.5399182394793369, 0.6371303487083482, 0.9569894214292887], 
             UndirectedEdge[55, 250] -> 
             RGBColor[
              0.4872161038591885, 0.5861106865112053, 0.9547667798607233], 
             UndirectedEdge[105, 447] -> 
             RGBColor[
              0.4136573377614463, 0.5320119246366942, 0.9477719943216194], 
             UndirectedEdge[55, 242] -> 
             RGBColor[
              0.626497537641451, 0.706824961050025, 0.964308846884771], 
             UndirectedEdge[133, 440] -> 
             RGBColor[
              0.36622114908174896`, 0.4916240853496229, 0.9445562656762103], 
             UndirectedEdge[177, 455] -> 
             RGBColor[
              0.2796399175826898, 0.4112496619471946, 0.9392364516649245], 
             UndirectedEdge[186, 456] -> 
             RGBColor[
              0.31488361021579375`, 0.4353416712088416, 0.9417177400528716], 
             UndirectedEdge[94, 302] -> 
             RGBColor[
              0.46935488238794554`, 0.576805606191767, 0.9522738875852403], 
             UndirectedEdge[146, 376] -> 
             RGBColor[
              0.5466462268893286, 0.6428310589774655, 0.9574531398932876], 
             UndirectedEdge[44, 106] -> 
             RGBColor[
              0.3338259605202371, 0.46034386374649233`, 0.9426100145300428], 
             UndirectedEdge[46, 205] -> 
             RGBColor[
              0.38059981901107254`, 0.5040781665494392, 0.9454724618095482], 
             UndirectedEdge[134, 457] -> 
             RGBColor[
              0.32003506033817375`, 0.44782178672366013`, 0.9417524007462923],
              UndirectedEdge[229, 248] -> 
             RGBColor[
              0.561238340700701, 0.6448008081541499, 0.9619910040584405], 
             UndirectedEdge[101, 362] -> 
             RGBColor[
              0.694097389901327, 0.7609534234172438, 0.9701447991826212], 
             UndirectedEdge[286, 346] -> 
             RGBColor[
              0.6060605952572575, 0.6858342419832799, 0.9648410561046065], 
             UndirectedEdge[134, 138] -> 
             RGBColor[
              0.6534970012907513, 0.72383008036323, 0.9692867075626176], 
             UndirectedEdge[144, 494] -> 
             RGBColor[
              0.4104218369938957, 0.5298099167874439, 0.9473999331573995], 
             UndirectedEdge[35, 147] -> 
             RGBColor[
              0.32287558323611837`, 0.45282067279036103`, 0.9418404469472235],
              UndirectedEdge[5, 211] -> 
             RGBColor[
              0.3310660518314165, 0.4605704205723482, 0.9423383325312796], 
             UndirectedEdge[243, 471] -> 
             RGBColor[
              0.35796471213423253`, 0.4844342574469739, 0.9440315831181425], 
             UndirectedEdge[154, 338] -> 
             RGBColor[
              0.50010656923045, 0.6050480683023028, 0.9537893675619975], 
             UndirectedEdge[185, 383] -> 
             RGBColor[
              0.29653334151250166`, 0.4290057216023681, 0.9401985071661461], 
             UndirectedEdge[416, 429] -> 
             RGBColor[
              0.3179820146067126, 0.44326634392346176`, 0.9417232693027647], 
             UndirectedEdge[159, 396] -> 
             RGBColor[
              0.4129846661278095, 0.5308995951553426, 0.9478754886203128], 
             UndirectedEdge[73, 322] -> 
             RGBColor[
              0.5738649934809026, 0.6569887722347423, 0.9628742082563303], 
             UndirectedEdge[287, 300] -> 
             RGBColor[
              0.24453403319932165`, 0.3743511516186463, 0.9372372234837936], 
             UndirectedEdge[392, 459] -> 
             RGBColor[
              0.3370560771822657, 0.46210868051961407`, 0.9428536559911737], 
             UndirectedEdge[200, 450] -> 
             RGBColor[
              0.45705088223579554`, 0.568350053585297, 0.9508815916711502], 
             UndirectedEdge[104, 148] -> 
             RGBColor[
              0.4604030267678122, 0.5684177500998486, 0.9517913173212897], 
             UndirectedEdge[94, 325] -> 
             RGBColor[
              0.7398264916772566, 0.796554707447332, 0.9749677087452304], 
             UndirectedEdge[355, 378] -> 
             RGBColor[
              0.2709885859014797, 0.4021565638241328, 0.9387437711241778], 
             UndirectedEdge[424, 453] -> 
             RGBColor[
              0.6445971217655264, 0.7082509544514268, 0.7306543291148428], 
             UndirectedEdge[212, 301] -> 
             RGBColor[
              0.3055582462101697, 0.43309841413517003`, 0.9409099282819062], 
             UndirectedEdge[46, 420] -> 
             RGBColor[
              0.393328378659751, 0.5151030051611147, 0.9462835143749386], 
             UndirectedEdge[146, 284] -> 
             RGBColor[
              0.46839861632275775`, 0.5765482433044375, 0.9520552119307857], 
             UndirectedEdge[76, 343] -> 
             RGBColor[
              0.375068725932431, 0.49928741172554125`, 0.9451200254495307], 
             UndirectedEdge[111, 256] -> 
             RGBColor[
              0.484508319379836, 0.592274013149543, 0.952592001064989], 
             UndirectedEdge[277, 319] -> 
             RGBColor[
              0.35520941727407485`, 0.4811041706398897, 0.9438905675774056], 
             UndirectedEdge[240, 429] -> 
             RGBColor[
              0.39372193995423743`, 0.5154438881734331, 0.9463085917526107], 
             UndirectedEdge[49, 71] -> 
             RGBColor[
              0.3104790470352997, 0.4414287224038411, 0.9410745221693535], 
             UndirectedEdge[19, 139] -> 
             RGBColor[
              0.5787069251766979, 0.666557467146994, 0.9611976763038141], 
             UndirectedEdge[9, 247] -> 
             RGBColor[
              0.28151889097480565`, 0.4132245821161023, 0.9393434564199135], 
             UndirectedEdge[333, 392] -> 
             RGBColor[
              0.5400267073941769, 0.263803953319781, 0.5512458541451186], 
             UndirectedEdge[169, 337] -> 
             RGBColor[
              0.2811864135093034, 0.41287512721957054`, 0.9393245223201094], 
             UndirectedEdge[21, 119] -> 
             RGBColor[
              0.9738299323697464, 0.9776391382611402, 0.8053039146080803], 
             UndirectedEdge[354, 479] -> 
             RGBColor[
              0.4350668611844205, 0.55111133765394, 0.9489826873661633], 
             UndirectedEdge[179, 236] -> 
             RGBColor[
              0.7375812785234449, 0.792228523875544, 0.9134404177124527], 
             UndirectedEdge[121, 341] -> 
             RGBColor[
              0.34170814337913147`, 0.4665920523772963, 0.9431334588864966], 
             UndirectedEdge[263, 323] -> 
             RGBColor[
              0.42107101786400997`, 0.5366923887452134, 0.9486761937798724], 
             UndirectedEdge[200, 401] -> 
             RGBColor[
              0.36090585353724836`, 0.48702024350349843`, 0.944217579744246], 
             UndirectedEdge[56, 236] -> 
             RGBColor[
              0.7250709683975642, 0.7820720905323054, 0.9124555602725675], 
             UndirectedEdge[374, 437] -> 
             RGBColor[
              0.6229181279674064, 0.4942147091519526, 0.5777238698606613], 
             UndirectedEdge[74, 195] -> 
             RGBColor[
              0.7076207347210658, 0.7672612229066504, 0.9120874773649048], 
             UndirectedEdge[240, 399] -> 
             RGBColor[
              0.3073584025403783, 0.43295362761227163`, 0.9410870241259239], 
             UndirectedEdge[138, 352] -> 
             RGBColor[
              0.7506182812134111, 0.8048744818730807, 0.9763254207953245], 
             UndirectedEdge[195, 342] -> 
             RGBColor[
              0.6584984087453709, 0.7247139331063952, 0.9089574461909009], 
             UndirectedEdge[13, 363] -> 
             RGBColor[
              0.40186258384242196`, 0.5224949047487197, 0.9468273063826771], 
             UndirectedEdge[368, 386] -> 
             RGBColor[
              0.2572338008727948, 0.3876994126552439, 0.9379604564651751], 
             UndirectedEdge[132, 233] -> 
             RGBColor[
              0.3950743734179838, 0.508197231045677, 0.9473023183270882], 
             UndirectedEdge[304, 310] -> 
             RGBColor[
              0.6329963906935205, 0.7093108093791551, 0.9664901071019947], 
             UndirectedEdge[213, 259] -> 
             RGBColor[
              0.30917493794039586`, 0.4378314497269542, 0.9410817807692802], 
             UndirectedEdge[226, 446] -> 
             RGBColor[
              0.39921330172562697`, 0.5142140362393477, 0.9473863263253068], 
             UndirectedEdge[60, 249] -> 
             RGBColor[
              0.3867256771566088, 0.5055022106587524, 0.9462734340360102], 
             UndirectedEdge[181, 387] -> 
             RGBColor[
              0.4518469525614186, 0.5626637381883132, 0.9508757445938686], 
             UndirectedEdge[94, 168] -> 
             RGBColor[
              0.43160062692490364`, 0.539332085691805, 0.9500429710795639], 
             UndirectedEdge[142, 402] -> 
             RGBColor[
              0.4609722103251976, 0.5719523303093452, 0.9510745867092317], 
             UndirectedEdge[188, 310] -> 
             RGBColor[
              0.34756664069421483`, 0.47184618104605436`, 0.9435001740615947],
              UndirectedEdge[74, 239] -> 
             RGBColor[
              0.5798386261573929, 0.6677596725488313, 0.9611758336082783], 
             UndirectedEdge[376, 400] -> 
             RGBColor[
              0.4525664989601712, 0.5649207558103645, 0.9504701744271138], 
             UndirectedEdge[292, 308] -> 
             RGBColor[
              0.6141157342415466, 0.6952272460254716, 0.964300199411765], 
             UndirectedEdge[7, 142] -> 
             RGBColor[
              0.3742329977170633, 0.49856354595031116`, 0.9450667735866529], 
             UndirectedEdge[20, 194] -> 
             RGBColor[
              0.35782092264246834`, 0.48434823141557515`, 0.9440210106755279],
              UndirectedEdge[168, 500] -> 
             RGBColor[
              0.3379741404312302, 0.4623852641905496, 0.9429311425304996], 
             UndirectedEdge[4, 383] -> 
             RGBColor[
              0.47101832187979387`, 0.5772764423755368, 0.95260508063444], 
             UndirectedEdge[91, 303] -> 
             RGBColor[
              0.7820261656007426, 0.8250158128446173, 0.7173968425298988], 
             UndirectedEdge[142, 417] -> 
             RGBColor[
              0.453140428672319, 0.5655941371457958, 0.9504580401687557], 
             UndirectedEdge[229, 338] -> 
             RGBColor[
              0.649695413437462, 0.7236284313339573, 0.9675888958324401], 
             UndirectedEdge[69, 388] -> 
             RGBColor[
              0.3858233933284907, 0.5000326666639763, 0.9466335968214106], 
             UndirectedEdge[170, 374] -> 
             RGBColor[
              0.6581106937355734, 0.5246967407905523, 0.579966309031845], 
             UndirectedEdge[96, 281] -> 
             RGBColor[
              0.3014825235763332, 0.42917811224774977`, 0.9406645108899374], 
             UndirectedEdge[131, 265] -> 
             RGBColor[
              0.8430289110694538, 0.877688841080329, 0.9570870969053606], 
             UndirectedEdge[117, 369] -> 
             RGBColor[
              0.341676124258814, 0.4691828717927995, 0.943035540612322], 
             UndirectedEdge[19, 247] -> 
             RGBColor[
              0.3542190758579702, 0.47922273744789373`, 0.9438649447109996], 
             UndirectedEdge[328, 436] -> 
             RGBColor[
              0.2548832337740824, 0.38522881759993527`, 0.9378265951462559], 
             UndirectedEdge[86, 178] -> 
             RGBColor[
              0.3122216331260953, 0.4408445812284755, 0.9412622108329805], 
             UndirectedEdge[42, 137] -> 
             RGBColor[
              0.37040348074719415`, 0.49524661082812993`, 0.9448227601516417],
              UndirectedEdge[54, 135] -> 
             RGBColor[
              0.3681754033579724, 0.48842993260073775`, 0.9449962633334144], 
             UndirectedEdge[42, 174] -> 
             RGBColor[
              0.34674371649555236`, 0.4747537122076859, 0.9433151808950352], 
             UndirectedEdge[1, 374] -> 
             RGBColor[
              0.6223256808678062, 0.4937015612515359, 0.5776861196553552], 
             UndirectedEdge[160, 285] -> 
             RGBColor[
              0.33547249071522695`, 0.4610768290096207, 0.9427403105629832], 
             UndirectedEdge[454, 471] -> 
             RGBColor[
              0.3965474136474182, 0.5178911714740293, 0.946488628437872], 
             UndirectedEdge[26, 425] -> 
             RGBColor[
              0.35711804030722294`, 0.4837394300646789, 0.9439762236346605], 
             UndirectedEdge[333, 442] -> 
             RGBColor[
              0.8944723943075681, 0.5562430700622256, 0.5485661590408711], 
             UndirectedEdge[75, 410] -> 
             RGBColor[
              0.32003831759366924`, 0.4506146493350104, 0.9416504512149065], 
             UndirectedEdge[31, 40] -> 
             RGBColor[
              0.26085189493119737`, 0.39150225891103785`, 0.9381665015693107],
              UndirectedEdge[3, 258] -> 
             RGBColor[
              0.255258814511969, 0.3856235767686482, 0.9378479839136566], 
             UndirectedEdge[132, 273] -> 
             RGBColor[
              0.4652994515230577, 0.5749402978851461, 0.9515603246446849], 
             UndirectedEdge[157, 180] -> 
             RGBColor[
              0.43753504333821636`, 0.534244553147199, 0.9518818200840271], 
             UndirectedEdge[213, 401] -> 
             RGBColor[
              0.2970272045363862, 0.42730969361523485`, 0.9403077379385956], 
             UndirectedEdge[84, 391] -> 
             RGBColor[
              0.35252189658233823`, 0.4789364556346217, 0.9437134598100185], 
             UndirectedEdge[43, 110] -> 
             RGBColor[
              0.6087518442352111, 0.6872919178240376, 0.9654145905147357], 
             UndirectedEdge[39, 127] -> 
             RGBColor[
              0.5749865783649978, 0.6658390330236983, 0.9596841961755804], 
             UndirectedEdge[52, 469] -> 
             RGBColor[
              0.2568571447813312, 0.3873035232217401, 0.9379390064579791], 
             UndirectedEdge[260, 483] -> 
             RGBColor[
              0.3934097457163769, 0.5132307846012187, 0.9465900727523379], 
             UndirectedEdge[98, 311] -> 
             RGBColor[
              0.4094007814607161, 0.5290241126448574, 0.9473076336691484], 
             UndirectedEdge[51, 127] -> 
             RGBColor[
              0.40412608045337106`, 0.5204361022517954, 0.947569757462966], 
             UndirectedEdge[243, 475] -> 
             RGBColor[
              0.3307222890042717, 0.46083823977580085`, 0.9422957200058304], 
             UndirectedEdge[76, 96] -> 
             RGBColor[
              0.28912802951985583`, 0.4184772704509554, 0.9398772934533088], 
             UndirectedEdge[99, 476] -> 
             RGBColor[
              0.31687575104191146`, 0.4471333491717537, 0.9414761051355593], 
             UndirectedEdge[107, 308] -> 
             RGBColor[
              0.38208154096187885`, 0.5053615596297168, 0.9455668758220184], 
             UndirectedEdge[190, 263] -> 
             RGBColor[
              0.5139765735855212, 0.6163083626743252, 0.9548812651123286], 
             UndirectedEdge[191, 299] -> 
             RGBColor[
              0.38401579915966616`, 0.5070369168619965, 0.945690125043984], 
             UndirectedEdge[39, 276] -> 
             RGBColor[
              0.5105665165203179, 0.6119234579633235, 0.9550594475119054], 
             UndirectedEdge[51, 214] -> 
             RGBColor[
              0.4112637453136858, 0.5262307801335364, 0.9481316605868979], 
             UndirectedEdge[295, 409] -> 
             RGBColor[
              0.34211750609063435`, 0.4707467212750417, 0.943020402858831], 
             UndirectedEdge[371, 382] -> 
             RGBColor[
              0.3501054867906096, 0.4776655086697764, 0.9435293899255395], 
             UndirectedEdge[53, 420] -> 
             RGBColor[
              0.4780050435911506, 0.5843865954480228, 0.9528005727354758], 
             UndirectedEdge[87, 308] -> 
             RGBColor[
              0.48768010103112786`, 0.5947371992227872, 0.9528725885388019], 
             UndirectedEdge[286, 358] -> 
             RGBColor[
              0.6783082867263004, 0.7412321443670732, 0.8866923378895949], 
             UndirectedEdge[215, 351] -> 
             RGBColor[
              0.44895800364063676`, 0.5571203393774563, 0.951072905875899], 
             UndirectedEdge[114, 258] -> 
             RGBColor[
              0.2982572599440585, 0.4292128095643149, 0.9403554435425222], 
             UndirectedEdge[87, 292] -> 
             RGBColor[
              0.6566724274221679, 0.729999189095973, 0.9675889401161393], 
             UndirectedEdge[196, 383] -> 
             RGBColor[
              0.42441862025175014`, 0.5394447053012559, 0.9489365814219488], 
             UndirectedEdge[65, 495] -> 
             RGBColor[
              0.3140127410976462, 0.440345049700923, 0.9414514321164578], 
             UndirectedEdge[14, 279] -> 
             RGBColor[
              0.533882518994641, 0.6324689059100699, 0.9564483340528152], 
             UndirectedEdge[26, 466] -> 
             RGBColor[
              0.3680217052912231, 0.493183636639683, 0.9446709955257087], 
             UndirectedEdge[27, 371] -> 
             RGBColor[
              0.2877542098077679, 0.4193573220037133, 0.9397139625801306], 
             UndirectedEdge[258, 472] -> 
             RGBColor[
              0.41605376895173485`, 0.5282994823932085, 0.9486744214949163], 
             UndirectedEdge[26, 117] -> 
             RGBColor[
              0.3450314918849172, 0.4720891225848497, 0.9432493416704222], 
             UndirectedEdge[97, 104] -> 
             RGBColor[
              0.7867064027680907, 0.833447478601131, 0.9599465471052978], 
             UndirectedEdge[21, 428] -> 
             RGBColor[
              0.6320613669123971, 0.6957008725782243, 0.7925214822809779], 
             UndirectedEdge[160, 268] -> 
             RGBColor[
              0.36191035065269617`, 0.48789028841740634`, 0.9442815854122004],
              UndirectedEdge[48, 137] -> 
             RGBColor[
              0.4656012274729486, 0.5749123940954668, 0.9516594843875156], 
             UndirectedEdge[27, 291] -> 
             RGBColor[
              0.330273065686878, 0.4561850179063641, 0.9424232264787995], 
             UndirectedEdge[117, 140] -> 
             RGBColor[
              0.3504008724213329, 0.47673981013258027`, 0.9435914738502458], 
             UndirectedEdge[31, 221] -> 
             RGBColor[
              0.2913004275123382, 0.4203625910747581, 0.9400155813059643], 
             UndirectedEdge[87, 386] -> 
             RGBColor[
              0.4011181487675337, 0.5163641222118202, 0.9474813353095046], 
             UndirectedEdge[207, 409] -> 
             RGBColor[
              0.6509763395562038, 0.7218341629252096, 0.9690398443192916], 
             UndirectedEdge[274, 498] -> 
             RGBColor[
              0.379197118134875, 0.496287329728478, 0.9459631996859561], 
             UndirectedEdge[28, 69] -> 
             RGBColor[
              0.3197286791690376, 0.44493131855503, 0.9418289960403174], 
             UndirectedEdge[442, 492] -> 
             RGBColor[
              0.6454554218083082, 0.7146647699292135, 0.9372399286735581], 
             UndirectedEdge[476, 493] -> 
             RGBColor[
              0.44315582630803585`, 0.5558429055894027, 0.9501266118918383], 
             UndirectedEdge[297, 359] -> 
             RGBColor[
              0.27765093389366247`, 0.4091591139811773, 0.939123181986272], 
             UndirectedEdge[112, 323] -> 
             RGBColor[
              0.30148421103262346`, 0.4342093993712739, 0.940480451861162], 
             UndirectedEdge[27, 349] -> 
             RGBColor[
              0.2850236460671032, 0.41690830193241424`, 0.9395430470375992], 
             UndirectedEdge[2, 242] -> 
             RGBColor[
              0.388967916708555, 0.5004809775046933, 0.9470727148974258], 
             UndirectedEdge[71, 462] -> 
             RGBColor[
              0.5541813005636756, 0.6436405058574879, 0.9603434827839883], 
             UndirectedEdge[165, 285] -> 
             RGBColor[
              0.2939335464735249, 0.4250978833155017, 0.9400934857673482], 
             UndirectedEdge[91, 172] -> 
             RGBColor[
              0.6612364849703587, 0.7235916372652309, 0.7088166762082295], 
             UndirectedEdge[19, 26] -> 
             RGBColor[
              0.4077412713630326, 0.5275867284076468, 0.9472018911531712], 
             UndirectedEdge[73, 163] -> 
             RGBColor[
              0.2651472651906933, 0.3960169653959722, 0.9384111165511582], 
             UndirectedEdge[67, 131] -> 
             RGBColor[
              0.7797440854906029, 0.8274931083770733, 0.9512971217626807], 
             UndirectedEdge[24, 81] -> 
             RGBColor[
              0.38921282224801834`, 0.5030222850824033, 0.9468787674564487], 
             UndirectedEdge[282, 467] -> 
             RGBColor[
              0.31595726616423425`, 0.4443421664316135, 0.9414906501488898], 
             UndirectedEdge[122, 406] -> 
             RGBColor[
              0.41653842689999754`, 0.5334660204133282, 0.9482433053206298], 
             UndirectedEdge[139, 255] -> 
             RGBColor[
              0.841799557990984, 0.8770645649645572, 0.9739780884785766], 
             UndirectedEdge[409, 458] -> 
             RGBColor[
              0.3473914672631281, 0.47531476136565975`, 0.9433564550011616], 
             UndirectedEdge[4, 196] -> 
             RGBColor[
              0.5886222953078468, 0.676909122319951, 0.9607576497625985], 
             UndirectedEdge[46, 90] -> 
             RGBColor[
              0.3908112011066381, 0.5129227524816308, 0.9461231220471069], 
             UndirectedEdge[115, 124] -> 
             RGBColor[
              0.3183188774751129, 0.4478566813974856, 0.9415873424295259], 
             UndirectedEdge[330, 350] -> 
             RGBColor[
              0.3796218830972776, 0.4950683711200351, 0.9461389857189142], 
             UndirectedEdge[213, 315] -> 
             RGBColor[
              0.3483862674751519, 0.4717943325512333, 0.9435802920140175], 
             UndirectedEdge[107, 143] -> 
             RGBColor[
              0.5791177424052847, 0.6626869197491876, 0.9630371717341601], 
             UndirectedEdge[403, 491] -> 
             RGBColor[
              0.4930064633435105, 0.5956338331184643, 0.9543377480203301], 
             UndirectedEdge[200, 254] -> 
             RGBColor[
              0.5485419403926748, 0.6416214400797513, 0.958771347330446], 
             UndirectedEdge[37, 304] -> 
             RGBColor[
              0.569153967182074, 0.6530071481195294, 0.9624589795253691], 
             UndirectedEdge[25, 392] -> 
             RGBColor[
              0.34421918657196326`, 0.4683130058446239, 0.9433100829873963], 
             UndirectedEdge[231, 492] -> 
             RGBColor[
              0.36569180371640825`, 0.4911655929998364, 0.9445225362576125], 
             UndirectedEdge[22, 63] -> 
             RGBColor[
              0.42098170351189906`, 0.5335282391571083, 0.9489505829448901], 
             UndirectedEdge[201, 256] -> 
             RGBColor[
              0.4112367163365952, 0.5282506587734214, 0.9479436734303578], 
             UndirectedEdge[57, 92] -> 
             RGBColor[
              0.47386185359991145`, 0.5801755823619732, 0.9527085405880977], 
             UndirectedEdge[433, 462] -> 
             RGBColor[
              0.5771679787133123, 0.6635504111266661, 0.9618081735893618], 
             UndirectedEdge[286, 294] -> 
             RGBColor[
              0.3535640360021597, 0.4806611301650834, 0.9437497656230245], 
             UndirectedEdge[319, 331] -> 
             RGBColor[
              0.35987018138055876`, 0.4860029292253165, 0.9441559911982873], 
             UndirectedEdge[222, 307] -> 
             RGBColor[
              0.5433968867550779, 0.640078388404016, 0.9572290346144292], 
             UndirectedEdge[276, 283] -> 
             RGBColor[
              0.40633561638226234`, 0.5263692207135771, 0.9471123240607684], 
             UndirectedEdge[464, 497] -> 
             RGBColor[
              0.34492041616533453`, 0.47317446110339034`, 0.9431990018102749],
              UndirectedEdge[143, 283] -> 
             RGBColor[
              0.6290411366118004, 0.7059280545881198, 0.9662182462674751], 
             UndirectedEdge[265, 433] -> 
             RGBColor[
              0.5491966634674861, 0.6416990070667572, 0.9590202542924604], 
             UndirectedEdge[74, 234] -> 
             RGBColor[
              0.37833625627474443`, 0.5021175822772028, 0.9453282295935792], 
             UndirectedEdge[17, 432] -> 
             RGBColor[
              0.3942468212569999, 0.5095468956514143, 0.947053160091486], 
             UndirectedEdge[103, 118] -> 
             RGBColor[
              0.6357932798390715, 0.7029849662327449, 0.9105142041906267], 
             UndirectedEdge[426, 489] -> 
             RGBColor[
              0.4383753748357503, 0.5516474676464849, 0.9498371612874137], 
             UndirectedEdge[277, 331] -> 
             RGBColor[
              0.30278444386851033`, 0.4355760265213142, 0.9405544981976436], 
             UndirectedEdge[74, 112] -> 
             RGBColor[
              0.36265955255869226`, 0.487401703915886, 0.9443709735450575], 
             UndirectedEdge[80, 372] -> 
             RGBColor[
              0.6361829472567706, 0.6997497204067642, 0.7644358890726333], 
             UndirectedEdge[180, 281] -> 
             RGBColor[
              0.5286366488552914, 0.6249686032210784, 0.9572540768723916], 
             UndirectedEdge[263, 296] -> 
             RGBColor[
              0.39590290548710794`, 0.5102391068865985, 0.9472429070128936], 
             UndirectedEdge[37, 141] -> 
             RGBColor[
              0.6419997735582859, 0.7094679742278492, 0.9098135892907486], 
             UndirectedEdge[18, 210] -> 
             RGBColor[
              0.31601483273207914`, 0.44748097952591415`, 0.9413812165817118],
              UndirectedEdge[279, 494] -> 
             RGBColor[
              0.5201180337991408, 0.6212942767453713, 0.9553647433572547], 
             UndirectedEdge[101, 337] -> 
             RGBColor[
              0.49015201206602627`, 0.5895567975267779, 0.9548769370328184], 
             UndirectedEdge[217, 378] -> 
             RGBColor[
              0.3119593109488674, 0.44241342611532136`, 0.9411797335177667], 
             UndirectedEdge[20, 62] -> 
             RGBColor[
              0.3316846889272972, 0.4617103394167963, 0.9423556329745613], 
             UndirectedEdge[18, 56] -> 
             RGBColor[
              0.3826593861841063, 0.5049238463675882, 0.9457054714378494], 
             UndirectedEdge[444, 492] -> 
             RGBColor[
              0.3553072563424307, 0.4821710200070243, 0.9438608420816373], 
             UndirectedEdge[199, 427] -> 
             RGBColor[
              0.3889959031268905, 0.4953904115678087, 0.9475403612382202], 
             UndirectedEdge[190, 463] -> 
             RGBColor[
              0.45689098000294437`, 0.5690982883506979, 0.9506263955842792], 
             UndirectedEdge[139, 369] -> 
             RGBColor[
              0.5617067119010355, 0.651832736863179, 0.9601144377465873], 
             UndirectedEdge[10, 455] -> 
             RGBColor[
              0.353491106219022, 0.4788361564164574, 0.9438096269364855], 
             UndirectedEdge[52, 236] -> 
             RGBColor[
              0.615813609581335, 0.6818414879910608, 0.9056313018800405], 
             UndirectedEdge[9, 19] -> 
             RGBColor[
              0.34868593212942717`, 0.47340705256762017`, 0.9435498403612117],
              UndirectedEdge[33, 309] -> 
             RGBColor[
              0.3670561325569558, 0.4916791230265671, 0.944633935539239], 
             UndirectedEdge[341, 491] -> 
             RGBColor[
              0.5369814381851336, 0.6337227460797769, 0.9571397945316948], 
             UndirectedEdge[87, 143] -> 
             RGBColor[
              0.6847163024745337, 0.752062559342258, 0.9703428844509436], 
             UndirectedEdge[110, 378] -> 
             RGBColor[
              0.5774592872655583, 0.657976095463686, 0.9635016406410752], 
             UndirectedEdge[401, 471] -> 
             RGBColor[
              0.37015216478005625`, 0.4950289335689029, 0.9448067465204457], 
             UndirectedEdge[160, 165] -> 
             RGBColor[
              0.36299670206221013`, 0.48883123140671786`, 0.9443508067633919],
              UndirectedEdge[13, 379] -> 
             RGBColor[
              0.41187100124824655`, 0.5311636928679597, 0.9474650338896802], 
             UndirectedEdge[210, 434] -> 
             RGBColor[
              0.4721507787369461, 0.5790144821392671, 0.9525108338475632], 
             UndirectedEdge[308, 446] -> 
             RGBColor[
              0.4882986612484675, 0.5952393742730437, 0.9529212838649715], 
             UndirectedEdge[153, 395] -> 
             RGBColor[
              0.4432653558025108, 0.5563193639296431, 0.9500281567269699], 
             UndirectedEdge[24, 83] -> 
             RGBColor[
              0.4603735866850847, 0.5708975730149373, 0.951184613061359], 
             UndirectedEdge[133, 260] -> 
             RGBColor[
              0.35817275985623653`, 0.4836708690426293, 0.9440793891463601], 
             UndirectedEdge[83, 119] -> 
             RGBColor[
              0.6683546780338756, 0.735612167785433, 0.9549457456893906], 
             UndirectedEdge[400, 464] -> 
             RGBColor[
              0.3871514816075249, 0.5097528873943493, 0.9458899279567864], 
             UndirectedEdge[175, 320] -> 
             RGBColor[
              0.37412076983274445`, 0.49846633979765165`, 0.9450596225251033],
              UndirectedEdge[39, 475] -> 
             RGBColor[
              0.4902317186703556, 0.5943104781223436, 0.9537637321742616], 
             UndirectedEdge[289, 291] -> 
             RGBColor[
              0.37252787328599135`, 0.49708665287016235`, 0.9449581245656874],
              UndirectedEdge[263, 342] -> 
             RGBColor[
              0.4331240334143839, 0.5473374034895703, 0.9494366842897641], 
             UndirectedEdge[311, 319] -> 
             RGBColor[
              0.3904148659219399, 0.5125794668650309, 0.9460978679196035], 
             UndirectedEdge[141, 304] -> 
             RGBColor[
              0.9132945816544156, 0.932075882413633, 0.9319985583005352], 
             UndirectedEdge[30, 43] -> 
             RGBColor[
              0.6666491244509732, 0.731881354105567, 0.913434633797477], 
             UndirectedEdge[85, 95] -> 
             RGBColor[
              0.8259683772093289, 0.8641310091399044, 0.9437434305804941], 
             UndirectedEdge[305, 438] -> 
             RGBColor[
              0.38718451740667825`, 0.5058503559678593, 0.9463117731908004], 
             UndirectedEdge[23, 212] -> 
             RGBColor[
              0.33523645393312307`, 0.46429209215904593`, 0.9426000583067546],
              UndirectedEdge[80, 461] -> 
             RGBColor[
              0.3156178282249969, 0.44498400027968654`, 0.9414347558526076], 
             UndirectedEdge[115, 439] -> 
             RGBColor[
              0.33496696523232683`, 0.46227641825556376`, 0.9426481438600895],
              UndirectedEdge[136, 377] -> 
             RGBColor[
              0.31513249633666457`, 0.4431252349120647, 0.9414564976311789], 
             UndirectedEdge[27, 488] -> 
             RGBColor[
              0.3380327412745858, 0.4629060588878015, 0.9429176661456367], 
             UndirectedEdge[70, 170] -> 
             RGBColor[
              0.42631541835321984`, 0.5436747209667747, 0.9483854193749126], 
             UndirectedEdge[268, 441] -> 
             RGBColor[
              0.5345515288340337, 0.6277265946678914, 0.9586320241948523], 
             UndirectedEdge[394, 445] -> 
             RGBColor[
              0.3323598527239878, 0.45798331514731483`, 0.942556530564879], 
             UndirectedEdge[234, 393] -> 
             RGBColor[
              0.3314863387366823, 0.4615385384510562, 0.9423429942758095], 
             UndirectedEdge[228, 388] -> 
             RGBColor[
              0.7150379393019262, 0.7762556786564517, 0.9732171845125582], 
             UndirectedEdge[8, 114] -> 
             RGBColor[
              0.3068953138344085, 0.4382919518873221, 0.9408473679327221], 
             UndirectedEdge[21, 164] -> 
             RGBColor[
              0.6761627650066122, 0.7375195937478547, 0.7951990272059021], 
             UndirectedEdge[100, 454] -> 
             RGBColor[
              0.3564470626830089, 0.4831582629709007, 0.9439334695337678], 
             UndirectedEdge[6, 267] -> 
             RGBColor[
              0.28912814140780474`, 0.4211064457539949, 0.9397810371439448], 
             UndirectedEdge[210, 495] -> 
             RGBColor[
              0.28680218002904173`, 0.41677662934586307`, 0.9397175992265208],
              UndirectedEdge[112, 342] -> 
             RGBColor[
              0.3135372265829973, 0.4448544141156308, 0.9412409423710535], 
             UndirectedEdge[93, 206] -> 
             RGBColor[
              0.29522061570033964`, 0.42545137487201123`, 0.9402033717168474],
              UndirectedEdge[485, 497] -> 
             RGBColor[
              0.33112054152662945`, 0.46122170329321077`, 0.9423196860010467],
              UndirectedEdge[36, 240] -> 
             RGBColor[
              0.32008985508487164`, 0.4463351914572483, 0.9418120615138367], 
             UndirectedEdge[275, 285] -> 
             RGBColor[
              0.43044112316572336`, 0.539501198395415, 0.9498506106222333], 
             UndirectedEdge[36, 399] -> 
             RGBColor[
              0.238341301349295, 0.367842197802391, 0.9368845565662602], 
             UndirectedEdge[72, 279] -> 
             RGBColor[
              0.46502739147591077`, 0.5736761141416934, 0.9518271776106], 
             UndirectedEdge[278, 413] -> 
             RGBColor[
              0.3478390528007359, 0.47301408684324053`, 0.9434834084411986], 
             UndirectedEdge[10, 120] -> 
             RGBColor[
              0.619689802075183, 0.6984167112358622, 0.9653515548895627], 
             UndirectedEdge[59, 153] -> 
             RGBColor[
              0.7332866340632012, 0.7907115596197147, 0.9727098440402808], 
             UndirectedEdge[377, 488] -> 
             RGBColor[
              0.39066282714929107`, 0.5127942384172688, 0.9461136677897468], 
             UndirectedEdge[53, 306] -> 
             RGBColor[
              0.48680045721007364`, 0.5920047406543918, 0.9533610087137947], 
             UndirectedEdge[172, 448] -> 
             RGBColor[
              0.4480790117319043, 0.5594480819796885, 0.950622407457223], 
             UndirectedEdge[138, 367] -> 
             RGBColor[
              0.6104482161742809, 0.6844688092147244, 0.9666196374745035], 
             UndirectedEdge[71, 431] -> 
             RGBColor[
              0.35519532469582815`, 0.48207407044058526`, 0.9438537098960931],
              UndirectedEdge[180, 392] -> 
             RGBColor[
              0.4784316035786896, 0.5772294309516197, 0.9542108186886828], 
             UndirectedEdge[33, 227] -> 
             RGBColor[
              0.34948728747827373`, 0.47646187245524174`, 0.9435144642663451],
              UndirectedEdge[30, 384] -> 
             RGBColor[
              0.9439402477962242, 0.9565600639072829, 0.9370128065821023], 
             UndirectedEdge[441, 467] -> 
             RGBColor[
              0.5567506663683444, 0.6469543718390166, 0.960046533608612], 
             UndirectedEdge[99, 122] -> 
             RGBColor[
              0.30273919580418646`, 0.43488897554876194`, 0.9405753363362765],
              UndirectedEdge[89, 225] -> 
             RGBColor[
              0.672580230654924, 0.7420821553374708, 0.969534577176232], 
             UndirectedEdge[146, 497] -> 
             RGBColor[
              0.44873905678608905`, 0.5595201209519682, 0.950802522181375], 
             UndirectedEdge[176, 197] -> 
             RGBColor[
              0.33217650049925984`, 0.4609768574663575, 0.9424294244450413], 
             UndirectedEdge[326, 474] -> 
             RGBColor[
              0.33303777304988313`, 0.45626733552283116`, 0.9426840570235266],
              UndirectedEdge[173, 241] -> 
             RGBColor[
              0.44794581932769345`, 0.5565119192521919, 0.9509738056063576], 
             UndirectedEdge[403, 405] -> 
             RGBColor[
              0.3905365170032499, 0.5126848349173004, 0.9461056194189327], 
             UndirectedEdge[79, 476] -> 
             RGBColor[
              0.3749133062510239, 0.4991527950091267, 0.9451101222448637], 
             UndirectedEdge[46, 257] -> 
             RGBColor[
              0.5321845627405477, 0.6305511694756254, 0.9564636636003809], 
             UndirectedEdge[450, 491] -> 
             RGBColor[
              0.5915928090456724, 0.6790781892846334, 0.9611573185079327], 
             UndirectedEdge[200, 243] -> 
             RGBColor[
              0.3487184008914247, 0.4764255673815695, 0.9434424163419428], 
             UndirectedEdge[296, 424] -> 
             RGBColor[
              0.2760003033038396, 0.4074241965752495, 0.9390291810160707], 
             UndirectedEdge[269, 466] -> 
             RGBColor[
              0.4236891844445852, 0.5399850085961384, 0.9486090469425292], 
             UndirectedEdge[74, 453] -> 
             RGBColor[
              0.7111295683762652, 0.7670739161001073, 0.7348499300081835], 
             UndirectedEdge[18, 469] -> 
             RGBColor[
              0.28509598492886035`, 0.4169843346626698, 0.9395471666287605], 
             UndirectedEdge[279, 481] -> 
             RGBColor[
              0.5230231365954137, 0.6236527700687751, 0.9555934436911195], 
             UndirectedEdge[19, 468] -> 
             RGBColor[
              0.34795552590445666`, 0.4726393493147467, 0.9435082448072387], 
             UndirectedEdge[415, 464] -> 
             RGBColor[
              0.5054356299712278, 0.6073134294669289, 0.9547783540632813], 
             UndirectedEdge[234, 262] -> 
             RGBColor[
              0.6218324303292972, 0.581248146999612, 0.5966359673847018], 
             UndirectedEdge[241, 417] -> 
             RGBColor[
              0.553913268770626, 0.6487307709532086, 0.9580252280502348], 
             UndirectedEdge[309, 489] -> 
             RGBColor[
              0.3824739895287985, 0.5057014788533442, 0.9455918822976738], 
             UndirectedEdge[83, 426] -> 
             RGBColor[
              0.46398947935039725`, 0.5738331175747463, 0.9514692693774238], 
             UndirectedEdge[6, 99] -> 
             RGBColor[
              0.2999078671072325, 0.4324366209381785, 0.9403949265753522], 
             UndirectedEdge[121, 491] -> 
             RGBColor[
              0.4629179571663749, 0.565772581867912, 0.9525596752706016], 
             UndirectedEdge[42, 358] -> 
             RGBColor[
              0.6774297306327512, 0.7404711832363542, 0.8866363570721906], 
             UndirectedEdge[69, 461] -> 
             RGBColor[
              0.2960773892174394, 0.42444575994735306`, 0.9403219567586162], 
             UndirectedEdge[161, 387] -> 
             RGBColor[
              0.6160694491466056, 0.6988646533239861, 0.9631421704454322], 
             UndirectedEdge[117, 390] -> 
             RGBColor[
              0.466021970761494, 0.5719226484842127, 0.9523298589114866], 
             UndirectedEdge[244, 334] -> 
             RGBColor[
              0.38776800919502286`, 0.5100224363220239, 0.9460022826078868], 
             UndirectedEdge[173, 493] -> 
             RGBColor[
              0.41609580782035904`, 0.5306546450838706, 0.9484664560300637], 
             UndirectedEdge[229, 255] -> 
             RGBColor[
              0.8935627412595937, 0.9176605349805318, 0.9790953832993115], 
             UndirectedEdge[39, 401] -> 
             RGBColor[
              0.4800262857421334, 0.585471045059891, 0.9531134510123853], 
             UndirectedEdge[379, 380] -> 
             RGBColor[
              0.34881975674962545`, 0.47382807299684726`, 0.9435471960393205],
              UndirectedEdge[92, 140] -> 
             RGBColor[
              0.5152840856722335, 0.6160534378410993, 0.9553479285875044], 
             UndirectedEdge[78, 97] -> 
             RGBColor[
              0.6247173499505758, 0.6960121140347573, 0.9484608361853402], 
             UndirectedEdge[395, 463] -> 
             RGBColor[
              0.3898269004066886, 0.5120702006877262, 0.9460604032768891], 
             UndirectedEdge[174, 338] -> 
             RGBColor[
              0.39382920085577244`, 0.5153597934539623, 0.94636433159647], 
             UndirectedEdge[143, 423] -> 
             RGBColor[
              0.6023351814732, 0.6827966985273979, 0.9645165664211924], 
             UndirectedEdge[94, 100] -> 
             RGBColor[
              0.46673761250528645`, 0.574538658567217, 0.9521071174626783], 
             UndirectedEdge[404, 408] -> 
             RGBColor[
              0.4133846630000047, 0.5292178781110987, 0.948183456849687], 
             UndirectedEdge[301, 389] -> 
             RGBColor[
              0.6154117069193885, 0.6813172471030089, 0.902952652713843], 
             UndirectedEdge[16, 422] -> 
             RGBColor[
              0.43254114148325895`, 0.5445292987820589, 0.9497134324299076], 
             UndirectedEdge[389, 451] -> 
             RGBColor[
              0.6881017305264323, 0.7502602057978565, 0.9073653476062455], 
             UndirectedEdge[74, 296] -> 
             RGBColor[
              0.3425327499145785, 0.46624715822393, 0.9432247819094115], 
             UndirectedEdge[225, 453] -> 
             RGBColor[
              0.92511969707304, 0.9384765936332455, 0.7536800989614152], 
             UndirectedEdge[340, 378] -> 
             RGBColor[
              0.3209117256658294, 0.450167557781707, 0.9417501734672221], 
             UndirectedEdge[52, 428] -> 
             RGBColor[
              0.2573762312499702, 0.3878491160122628, 0.9379685676644485], 
             UndirectedEdge[84, 230] -> 
             RGBColor[
              0.2847221806536193, 0.41659144266883164`, 0.9395258790282794], 
             UndirectedEdge[119, 237] -> 
             RGBColor[
              0.6004256899069011, 0.6711336816612586, 0.9508239449643554], 
             UndirectedEdge[67, 171] -> 
             RGBColor[
              0.437936694145819, 0.5475637273074516, 0.9502607044914909], 
             UndirectedEdge[25, 157] -> 
             RGBColor[
              0.30332262633149004`, 0.4253281280402032, 0.9409810843827404], 
             UndirectedEdge[124, 484] -> 
             RGBColor[
              0.4018160400569504, 0.522454590861103, 0.9468243406538239], 
             UndirectedEdge[368, 500] -> 
             RGBColor[
              0.33064551576803825`, 0.4546824150078937, 0.9425137881976593], 
             UndirectedEdge[283, 422] -> 
             RGBColor[
              0.4948877489076129, 0.5998762978899156, 0.9536368377271132], 
             UndirectedEdge[334, 369] -> 
             RGBColor[
              0.4252217061147573, 0.5424629461163553, 0.9483887990566084], 
             UndirectedEdge[42, 346] -> 
             RGBColor[
              0.6051820391637084, 0.6850732808525608, 0.9647850752872021], 
             UndirectedEdge[112, 263] -> 
             RGBColor[
              0.4160297081312217, 0.5313936525785545, 0.9483890986485396], 
             UndirectedEdge[146, 201] -> 
             RGBColor[
              0.4438739486865867, 0.5547470342857065, 0.9505129959150704], 
             UndirectedEdge[16, 243] -> 
             RGBColor[
              0.3012613255339003, 0.433975132580359, 0.9404677588617393], 
             UndirectedEdge[285, 481] -> 
             RGBColor[
              0.3645841355191912, 0.4860355290004764, 0.9446661073126037], 
             UndirectedEdge[231, 444] -> 
             RGBColor[
              0.40171400505735877`, 0.5223662132728849, 0.946817839073876], 
             UndirectedEdge[137, 408] -> 
             RGBColor[
              0.33567330020030095`, 0.4640056096131361, 0.942652237429893], 
             UndirectedEdge[431, 436] -> 
             RGBColor[
              0.33114841484899626`, 0.45903406344120773`, 0.9424024462500247],
              UndirectedEdge[98, 277] -> 
             RGBColor[
              0.374195332812851, 0.49754881641971627`, 0.9451003333269505], 
             UndirectedEdge[131, 391] -> 
             RGBColor[
              0.6858720270678342, 0.7499767193198226, 0.9442682485866682], 
             UndirectedEdge[52, 227] -> 
             RGBColor[
              0.3213093676382073, 0.4468450921200259, 0.9419097734169501], 
             UndirectedEdge[27, 419] -> 
             RGBColor[
              0.28875423158565994`, 0.4202234906051674, 0.9397776830835334], 
             UndirectedEdge[232, 312] -> 
             RGBColor[
              0.3629863942173616, 0.4888223032695974, 0.9443501499566329], 
             UndirectedEdge[247, 466] -> 
             RGBColor[
              0.3144995097861606, 0.44481964567992993`, 0.9413340490835371], 
             UndirectedEdge[253, 484] -> 
             RGBColor[
              0.36963600599413576`, 0.4926783545134274, 0.9448435541009195], 
             UndirectedEdge[121, 200] -> 
             RGBColor[
              0.32837603035649815`, 0.45504444616857553`, 0.942283948433819], 
             UndirectedEdge[79, 99] -> 
             RGBColor[
              0.3478532877633471, 0.4739645345035945, 0.9434499663830891], 
             UndirectedEdge[109, 300] -> 
             RGBColor[
              0.31889401098877423`, 0.4446169729509985, 0.9417608508003248], 
             UndirectedEdge[31, 397] -> 
             RGBColor[
              0.27207564742799806`, 0.40329913441218523`, 0.9388056776699496],
              UndirectedEdge[70, 374] -> 
             RGBColor[
              0.6343662354957064, 0.5041304844943512, 0.5784533331492006], 
             UndirectedEdge[240, 352] -> 
             RGBColor[
              0.47787737679431863`, 0.585257928087376, 0.9525211329293405], 
             UndirectedEdge[105, 323] -> 
             RGBColor[
              0.3273892237753191, 0.45778452492170985`, 0.942089446716323], 
             UndirectedEdge[46, 53] -> 
             RGBColor[
              0.5181341679935348, 0.6191444260569302, 0.9553575650576043], 
             UndirectedEdge[221, 223] -> 
             RGBColor[
              0.6649982556373613, 0.7301421441006394, 0.9019606621619665], 
             UndirectedEdge[33, 159] -> 
             RGBColor[
              0.4000445201233397, 0.5190233080351296, 0.9470754194137653], 
             UndirectedEdge[16, 454] -> 
             RGBColor[
              0.33984402704708594`, 0.46743204660741433`, 0.9429248041814686],
              UndirectedEdge[195, 224] -> 
             RGBColor[
              0.9408114337906149, 0.9539739140694404, 0.9327490138608432], 
             UndirectedEdge[259, 500] -> 
             RGBColor[
              0.38791135432184887`, 0.5104110509471836, 0.945938346374214], 
             UndirectedEdge[24, 77] -> 
             RGBColor[
              0.3912703468156388, 0.5051848738575647, 0.9469959404367398], 
             UndirectedEdge[226, 386] -> 
             RGBColor[
              0.26947609606407186`, 0.40056684110762275`, 0.9386576370654657],
              UndirectedEdge[289, 314] -> 
             RGBColor[
              0.376993784720644, 0.5009548008916233, 0.945242688493253], 
             UndirectedEdge[179, 325] -> 
             RGBColor[
              0.6811378011789644, 0.7489085846054411, 0.9703475200454479], 
             UndirectedEdge[81, 83] -> 
             RGBColor[
              0.31242218543639394`, 0.43878671663338864`, 0.9413566986653101],
              UndirectedEdge[312, 376] -> 
             RGBColor[
              0.4275821050643302, 0.5432805295699368, 0.9488781909409028], 
             UndirectedEdge[270, 309] -> 
             RGBColor[
              0.708884901969455, 0.7686251981134796, 0.9220558172297676], 
             UndirectedEdge[139, 269] -> 
             RGBColor[
              0.6207295586805008, 0.7015403596116845, 0.9642662902215081], 
             UndirectedEdge[269, 425] -> 
             RGBColor[
              0.41278551946058506`, 0.5305408020211343, 0.9479142750514811], 
             UndirectedEdge[25, 492] -> 
             RGBColor[
              0.37249450667852646`, 0.4970577523918308, 0.9449559984749647], 
             UndirectedEdge[142, 173] -> 
             RGBColor[
              0.3471729792293865, 0.47337528544477897`, 0.9434066177248783], 
             UndirectedEdge[132, 209] -> 
             RGBColor[
              0.766287744143828, 0.815393433650137, 0.9098355303215835], 
             UndirectedEdge[389, 409] -> 
             RGBColor[
              0.6797977447469121, 0.7430677106860969, 0.9068362249753008], 
             UndirectedEdge[337, 370] -> 
             RGBColor[
              0.27760119015340645`, 0.40910683015623295`, 0.9391203491538538],
              UndirectedEdge[230, 242] -> 
             RGBColor[
              0.41292407837843115`, 0.525660422328111, 0.9484369828645601], 
             UndirectedEdge[28, 461] -> 
             RGBColor[
              0.37653385369484926`, 0.5005564317538853, 0.9452133820949904], 
             UndirectedEdge[318, 350] -> 
             RGBColor[
              0.6181373874076974, 0.6997290600465343, 0.9638618023195713], 
             UndirectedEdge[390, 478] -> 
             RGBColor[
              0.4742503127202854, 0.5802311714444413, 0.9528108993715478], 
             UndirectedEdge[167, 434] -> 
             RGBColor[
              0.5155458037115973, 0.6166010716749364, 0.955275926466234], 
             UndirectedEdge[247, 269] -> 
             RGBColor[
              0.3962417093617733, 0.5142056299125843, 0.9469335586286936], 
             UndirectedEdge[394, 398] -> 
             RGBColor[
              0.3676582988813212, 0.4928688722727632, 0.9446478395906174], 
             UndirectedEdge[14, 158] -> 
             RGBColor[
              0.560647122383751, 0.6541976166729919, 0.9585553416735786], 
             UndirectedEdge[131, 433] -> 
             RGBColor[
              0.6727230993966707, 0.7385877790553816, 0.9434304105426019], 
             UndirectedEdge[87, 422] -> 
             RGBColor[
              0.5505629147703461, 0.6460108026440537, 0.9577614759105817], 
             UndirectedEdge[210, 469] -> 
             RGBColor[
              0.29946995014553324`, 0.4300912589213106, 0.9404390099943685], 
             UndirectedEdge[312, 414] -> 
             RGBColor[
              0.33000653227334786`, 0.4602568044697513, 0.9422487023165071], 
             UndirectedEdge[277, 311] -> 
             RGBColor[
              0.3333291284098915, 0.46215256416102857`, 0.9424963749189597], 
             UndirectedEdge[332, 424] -> 
             RGBColor[
              0.3526366643372753, 0.47866198702755886`, 0.9437344620929435], 
             UndirectedEdge[328, 433] -> 
             RGBColor[
              0.30191682177055085`, 0.4281787298684911, 0.9407425495976978], 
             UndirectedEdge[88, 428] -> 
             RGBColor[
              0.2913403666594241, 0.42314580849182165`, 0.9399174855990398], 
             UndirectedEdge[8, 162] -> 
             RGBColor[
              0.30215653783454954`, 0.43418746229405136`, 0.9405454173163461],
              UndirectedEdge[27, 289] -> 
             RGBColor[
              0.30446401534034934`, 0.43383051569678927`, 0.9407786966127658],
              UndirectedEdge[192, 280] -> 
             RGBColor[
              0.4904119637032921, 0.5940651726133007, 0.9538861320682561], 
             UndirectedEdge[347, 477] -> 
             RGBColor[
              0.3022410980409918, 0.4328034167747644, 0.9406041638454101], 
             UndirectedEdge[145, 346] -> 
             RGBColor[
              0.9016637999121274, 0.9238349465331626, 0.9699816457138921], 
             UndirectedEdge[232, 415] -> 
             RGBColor[
              0.5062549364769056, 0.6080230715826045, 0.9548305595493387], 
             UndirectedEdge[189, 374] -> 
             RGBColor[
              0.5994329097999666, 0.473872993576703, 0.576227412526195], 
             UndirectedEdge[139, 140] -> 
             RGBColor[
              0.5704314600635545, 0.6593896752029598, 0.9606703709845111], 
             UndirectedEdge[134, 251] -> 
             RGBColor[
              0.3572675970274981, 0.48386896857884193`, 0.9439857532566287], 
             UndirectedEdge[67, 281] -> 
             RGBColor[
              0.4780386646620624, 0.5846839274318363, 0.9527286075137569], 
             UndirectedEdge[167, 495] -> 
             RGBColor[
              0.330197205003693, 0.45436321888153247`, 0.9424826918451916], 
             UndirectedEdge[143, 179] -> 
             RGBColor[
              0.663947167920943, 0.7352012402728039, 0.9687078620990384], 
             UndirectedEdge[21, 175] -> 
             RGBColor[
              0.66942938662869, 0.7316874798263361, 0.7947699822897536], 
             UndirectedEdge[366, 473] -> 
             RGBColor[
              0.30190026408261694`, 0.4335093113855023, 0.9405457907443626], 
             UndirectedEdge[143, 292] -> 
             RGBColor[
              0.8111519356849524, 0.8525526061449422, 0.9817704953239068], 
             UndirectedEdge[267, 486] -> 
             RGBColor[
              0.40096019887653456`, 0.5157881676515819, 0.9475096555135314], 
             UndirectedEdge[248, 380] -> 
             RGBColor[
              0.28110416828923035`, 0.4127886822786256, 0.9393198385764971], 
             UndirectedEdge[48, 407] -> 
             RGBColor[
              0.4261996729850389, 0.5396375523126512, 0.9491908566299487], 
             UndirectedEdge[436, 459] -> 
             RGBColor[
              0.34810070768897194`, 0.47371728745218217`, 0.943482631359464], 
             UndirectedEdge[235, 262] -> 
             RGBColor[
              0.6098878243250461, 0.57045493996206, 0.5958912487797233], 
             UndirectedEdge[236, 283] -> 
             RGBColor[
              0.7026752472143023, 0.76295533819086, 0.9109508018808895], 
             UndirectedEdge[99, 493] -> 
             RGBColor[
              0.41609580782035904`, 0.5306546450838706, 0.9484664560300637], 
             UndirectedEdge[109, 456] -> 
             RGBColor[
              0.28751886001044047`, 0.41163969997330124`, 0.9399740823674849],
              UndirectedEdge[208, 289] -> 
             RGBColor[
              0.38266319659018705`, 0.5058653605000956, 0.9456039384043162], 
             UndirectedEdge[266, 410] -> 
             RGBColor[
              0.2837082746659444, 0.41552576319043266`, 0.9394681385822208], 
             UndirectedEdge[299, 301] -> 
             RGBColor[
              0.34850614431730176`, 0.4702977248514443, 0.9436465303719576], 
             UndirectedEdge[314, 359] -> 
             RGBColor[
              0.35095753814505637`, 0.47709990187971224`, 0.943631413463444], 
             UndirectedEdge[209, 214] -> 
             RGBColor[
              0.7620343382397541, 0.8119403271234573, 0.9095006866280755], 
             UndirectedEdge[210, 326] -> 
             RGBColor[
              0.3796325008831507, 0.503240324205856, 0.9454108251538028], 
             UndirectedEdge[53, 317] -> 
             RGBColor[
              0.4458855203776097, 0.554736947140894, 0.9508209259122663], 
             UndirectedEdge[402, 459] -> 
             RGBColor[
              0.4643959671610172, 0.5749178163975102, 0.9512927454673008], 
             UndirectedEdge[89, 249] -> 
             RGBColor[
              0.4914394549596832, 0.598011714488246, 0.953107060577917], 
             UndirectedEdge[67, 135] -> 
             RGBColor[
              0.533615698916939, 0.632252289350884, 0.9564273289989045], 
             UndirectedEdge[90, 178] -> 
             RGBColor[
              0.3067813483550219, 0.4361324799964348, 0.9409155606980226], 
             UndirectedEdge[174, 229] -> 
             RGBColor[
              0.5836878872963336, 0.6666330285465308, 0.9633340493608302], 
             UndirectedEdge[266, 364] -> 
             RGBColor[
              0.3373703907893601, 0.4630133796363971, 0.9428505264468166], 
             UndirectedEdge[407, 430] -> 
             RGBColor[
              0.39832818729946434`, 0.5170102246369803, 0.9469967111801643], 
             UndirectedEdge[217, 355] -> 
             RGBColor[
              0.2981242210485807, 0.427871869434756, 0.9403918456151268], 
             UndirectedEdge[176, 426] -> 
             RGBColor[
              0.4562718063215898, 0.5671484570987184, 0.9509775060764984], 
             UndirectedEdge[280, 483] -> 
             RGBColor[
              0.5654141188986723, 0.6580676791945506, 0.9589306171013168], 
             UndirectedEdge[51, 347] -> 
             RGBColor[
              0.3090922913355968, 0.44000445531813837`, 0.9409943291681057], 
             UndirectedEdge[152, 451] -> 
             RGBColor[
              0.3903109488015284, 0.5124894590783567, 0.9460912464125811], 
             UndirectedEdge[105, 342] -> 
             RGBColor[
              0.33944223932569295`, 0.4684295396660667, 0.9428499372262145], 
             UndirectedEdge[318, 496] -> 
             RGBColor[
              0.5185503901614263, 0.6152656340367993, 0.9570205675536887], 
             UndirectedEdge[114, 289] -> 
             RGBColor[
              0.3364113785503401, 0.4658043603979479, 0.942656813457694], 
             UndirectedEdge[103, 331] -> 
             RGBColor[
              0.6467294128603894, 0.7144795354290319, 0.9111370007876318], 
             UndirectedEdge[107, 113] -> 
             RGBColor[
              0.2943461722405135, 0.4257551475227317, 0.9401087982613652], 
             UndirectedEdge[16, 56] -> 
             RGBColor[
              0.37893557624519053`, 0.501009886018601, 0.9454934059707113], 
             UndirectedEdge[140, 370] -> 
             RGBColor[
              0.336899765197347, 0.46254929042053167`, 0.942822605766938], 
             UndirectedEdge[213, 500] -> 
             RGBColor[
              0.3400865167323523, 0.464605505615422, 0.9430514392358678], 
             UndirectedEdge[280, 327] -> 
             RGBColor[
              0.4720665649657106, 0.57755166157246, 0.9527400143175875], 
             UndirectedEdge[76, 238] -> 
             RGBColor[
              0.3724650753663014, 0.4970322604684422, 0.9449541231377747], 
             UndirectedEdge[253, 261] -> 
             RGBColor[
              0.4807698826350132, 0.5824864531282464, 0.9539008032023328], 
             UndirectedEdge[232, 350] -> 
             RGBColor[
              0.44921720100674123`, 0.5617172684072242, 0.9503403400770178], 
             UndirectedEdge[166, 320] -> 
             RGBColor[
              0.36831026683759194`, 0.4934335741476227, 0.9446893824122783], 
             UndirectedEdge[33, 119] -> 
             RGBColor[
              0.6273227165473858, 0.6994041620303946, 0.9523556908409458], 
             UndirectedEdge[71, 228] -> 
             RGBColor[
              0.6153094010669644, 0.6920224026184508, 0.9662694662025966], 
             UndirectedEdge[50, 244] -> 
             RGBColor[
              0.3064527862809573, 0.4390866106593063, 0.9407760398058198], 
             UndirectedEdge[235, 344] -> 
             RGBColor[
              0.5351915051788585, 0.6271260410533628, 0.9589886228147387], 
             UndirectedEdge[72, 494] -> 
             RGBColor[
              0.4018580879960649, 0.5223924278320627, 0.9468542586438835], 
             UndirectedEdge[185, 496] -> 
             RGBColor[
              0.30323063089748153`, 0.43498514384932463`, 0.9406187143183986],
              UndirectedEdge[106, 370] -> 
             RGBColor[
              0.33135481571299397`, 0.4577465338744497, 0.9424692864890014], 
             UndirectedEdge[51, 113] -> 
             RGBColor[
              0.2776399686734581, 0.4091475888395073, 0.939122557533203], 
             UndirectedEdge[422, 443] -> 
             RGBColor[
              0.44880350275608827`, 0.5599604401350249, 0.9507003903130369], 
             UndirectedEdge[4, 335] -> 
             RGBColor[
              0.578312514720859, 0.6685391779891118, 0.9599460260688201], 
             UndirectedEdge[1, 84] -> 
             RGBColor[
              0.33917246844259935`, 0.4673738519417473, 0.9428628460533902], 
             UndirectedEdge[90, 272] -> 
             RGBColor[
              0.3436676466939232, 0.4720893751532783, 0.9431191764473371], 
             UndirectedEdge[213, 450] -> 
             RGBColor[
              0.39317223323493344`, 0.5086395036970335, 0.9469717498654997], 
             UndirectedEdge[5, 212] -> 
             RGBColor[
              0.33464439981624206`, 0.4636698057438049, 0.9425663417006638], 
             UndirectedEdge[50, 106] -> 
             RGBColor[
              0.3470862818788577, 0.47428130224733633`, 0.9433651702145287], 
             UndirectedEdge[115, 291] -> 
             RGBColor[
              0.3412283430257939, 0.46769970899426655`, 0.9430471133163704], 
             UndirectedEdge[9, 117] -> 
             RGBColor[
              0.28597615265131177`, 0.4179094467448231, 0.9395972908784627], 
             UndirectedEdge[194, 388] -> 
             RGBColor[
              0.45807974263806517`, 0.5690408108619018, 0.9510025180703674], 
             UndirectedEdge[202, 211] -> 
             RGBColor[
              0.3613598569704315, 0.4874134784584456, 0.944246508441549], 
             UndirectedEdge[113, 308] -> 
             RGBColor[
              0.3573880391291412, 0.4803588440453007, 0.9441257702737744], 
             UndirectedEdge[51, 421] -> 
             RGBColor[
              0.3301071903222463, 0.45820650458083956`, 0.9423333799487894], 
             UndirectedEdge[109, 335] -> 
             RGBColor[
              0.45774972910965056`, 0.5690528727499368, 0.9508991784082975], 
             UndirectedEdge[278, 329] -> 
             RGBColor[
              0.39952620036419756`, 0.5159890705741728, 0.9472725071414666], 
             UndirectedEdge[129, 206] -> 
             RGBColor[
              0.31538379632696684`, 0.4429157084998706, 0.9414881517567755], 
             UndirectedEdge[166, 227] -> 
             RGBColor[
              0.36507992838896985`, 0.4906356173449575, 0.9444835481028082], 
             UndirectedEdge[294, 411] -> 
             RGBColor[
              0.3336652075127061, 0.46342576507171906`, 0.9424818298675196], 
             UndirectedEdge[362, 384] -> 
             RGBColor[
              0.7980599144002996, 0.8428325700462553, 0.980330916715259], 
             UndirectedEdge[143, 308] -> 
             RGBColor[
              0.6421596092939124, 0.7172906162717566, 0.9670541437465694], 
             UndirectedEdge[151, 310] -> 
             RGBColor[
              0.37981925825520035`, 0.5034020840548269, 0.9454227251684068], 
             UndirectedEdge[297, 397] -> 
             RGBColor[
              0.28247314337333873`, 0.4142275618900571, 0.93939779968232], 
             UndirectedEdge[114, 359] -> 
             RGBColor[
              0.31037513197475247`, 0.44194946138603697`, 0.9410455384278851],
              UndirectedEdge[141, 220] -> 
             RGBColor[
              0.7090766812311377, 0.7685731830981835, 0.9140508153379969], 
             UndirectedEdge[122, 493] -> 
             RGBColor[
              0.42901927107031085`, 0.5435985319664111, 0.9492258430925555], 
             UndirectedEdge[146, 442] -> 
             RGBColor[
              0.7783378193862864, 0.8261839952672397, 0.9466953659379014], 
             UndirectedEdge[294, 478] -> 
             RGBColor[
              0.326064221757352, 0.45684217324708365`, 0.9419975017764762], 
             UndirectedEdge[76, 487] -> 
             RGBColor[
              0.5826697926142568, 0.6661862209838889, 0.9630689160239232], 
             UndirectedEdge[67, 70] -> 
             RGBColor[
              0.4977518920479601, 0.6017585341778833, 0.9539847169310638], 
             UndirectedEdge[346, 358] -> 
             RGBColor[
              0.916946011519999, 0.9344014303400792, 0.9069005556941826], 
             UndirectedEdge[149, 165] -> 
             RGBColor[
              0.6570421782017952, 0.7197448252920391, 0.690266462487116], 
             UndirectedEdge[175, 375] -> 
             RGBColor[
              0.3027863212471509, 0.4322884490222936, 0.9406750516785438], 
             UndirectedEdge[18, 428] -> 
             RGBColor[
              0.28561507139749936`, 0.4175299274531925, 0.9395767278352299], 
             UndirectedEdge[2, 47] -> 
             RGBColor[
              0.29713467805682836`, 0.42373472813702806`, 0.9404488914684423],
              UndirectedEdge[140, 466] -> 
             RGBColor[
              0.3733910858276388, 0.4978343241874136, 0.9450131277055323], 
             UndirectedEdge[199, 382] -> 
             RGBColor[
              0.2829193808534597, 0.4074696270325586, 0.9396878266083479], 
             UndirectedEdge[305, 499] -> 
             RGBColor[
              0.431489803800638, 0.5470058442004057, 0.9490330600150992], 
             UndirectedEdge[252, 282] -> 
             RGBColor[
              0.3469159845313079, 0.471157052250744, 0.9434633123075199], 
             UndirectedEdge[235, 249] -> 
             RGBColor[
              0.3992410032720274, 0.5186566119235645, 0.9469861633435175], 
             UndirectedEdge[130, 214] -> 
             RGBColor[
              0.7502766522166365, 0.7619871312981125, 0.6349927051825519], 
             UndirectedEdge[100, 475] -> 
             RGBColor[
              0.34025724674386915`, 0.469135458128227, 0.942901868778218], 
             UndirectedEdge[10, 438] -> 
             RGBColor[
              0.3479822090272895, 0.47304595618369083`, 0.9434959033910995], 
             UndirectedEdge[39, 179] -> 
             RGBColor[
              0.5580233939334807, 0.6520675557194426, 0.9583487921589393], 
             UndirectedEdge[400, 414] -> 
             RGBColor[
              0.3549909261691888, 0.481897030710179, 0.9438406858027182], 
             UndirectedEdge[41, 191] -> 
             RGBColor[
              0.35974153247920354`, 0.4860117671234979, 0.9441433902359961], 
             UndirectedEdge[25, 96] -> 
             RGBColor[
              0.332762250083341, 0.45627103918335293`, 0.9426576274033879], 
             UndirectedEdge[106, 274] -> 
             RGBColor[
              0.44960235706349794`, 0.5624289348708171, 0.950260421768616], 
             UndirectedEdge[204, 363] -> 
             RGBColor[
              0.4247454909661079, 0.542314928770903, 0.9482853849900381], 
             UndirectedEdge[99, 413] -> 
             RGBColor[
              0.35291232875675527`, 0.47834642153729096`, 0.9437723240016547],
              UndirectedEdge[37, 118] -> 
             RGBColor[
              0.2917160505091514, 0.42394244332395636`, 0.9399241695700487], 
             UndirectedEdge[411, 478] -> 
             RGBColor[
              0.32002422772929773`, 0.45161063399890977`, 0.9416126386979656],
              UndirectedEdge[300, 451] -> 
             RGBColor[
              0.3165558112179314, 0.44259174183083205`, 0.9416118627785155], 
             UndirectedEdge[122, 233] -> 
             RGBColor[
              0.2802021851968632, 0.41120114847146166`, 0.9392918869227088], 
             UndirectedEdge[97, 404] -> 
             RGBColor[
              0.7439863970106406, 0.7987654534129052, 0.956583471763534], 
             UndirectedEdge[362, 498] -> 
             RGBColor[
              0.4735318011646893, 0.5720794279490892, 0.9539317821898137], 
             UndirectedEdge[121, 454] -> 
             RGBColor[
              0.3265697344084849, 0.4534799234054806, 0.9421688528532565], 
             UndirectedEdge[173, 417] -> 
             RGBColor[
              0.39578318199716717`, 0.5141639403672382, 0.9468673717176621], 
             UndirectedEdge[36, 352] -> 
             RGBColor[
              0.40886027560323535`, 0.5201464982774955, 0.9483186653696768], 
             UndirectedEdge[309, 337] -> 
             RGBColor[
              0.3594156374559273, 0.48364847824001705`, 0.9441988206463351], 
             UndirectedEdge[207, 456] -> 
             RGBColor[
              0.5550409594035337, 0.6269233402145551, 0.963359583685486], 
             UndirectedEdge[95, 97] -> 
             RGBColor[
              0.9684779597096358, 0.9760114944808258, 0.938242771333488], 
             UndirectedEdge[185, 350] -> 
             RGBColor[
              0.40281762814375266`, 0.5194485698590596, 0.9474599490842812], 
             UndirectedEdge[303, 435] -> 
             RGBColor[
              0.41587256270546574`, 0.5269855777680581, 0.948766365052556], 
             UndirectedEdge[14, 441] -> 
             RGBColor[
              0.6171478516884412, 0.6984213191834725, 0.9641287574529949], 
             UndirectedEdge[67, 147] -> 
             RGBColor[
              0.47178115826803607`, 0.5792639899047469, 0.9523298847396251], 
             UndirectedEdge[115, 419] -> 
             RGBColor[
              0.29970950892457593`, 0.4317381816930698, 0.9404015699211041], 
             UndirectedEdge[113, 209] -> 
             RGBColor[
              0.6284105615995264, 0.6948571358294282, 0.9004915835743805], 
             UndirectedEdge[100, 121] -> 
             RGBColor[
              0.2975219906348967, 0.42832022773085143`, 0.9403179563059147], 
             UndirectedEdge[39, 254] -> 
             RGBColor[
              0.6676623725975598, 0.7400722416361438, 0.9676672185985853], 
             UndirectedEdge[2, 339] -> 
             RGBColor[
              0.2537717560877931, 0.38406058407988963`, 0.9377632981363055], 
             UndirectedEdge[76, 436] -> 
             RGBColor[
              0.3116295965151844, 0.44212784404479444`, 0.9411587244056075], 
             UndirectedEdge[121, 161] -> 
             RGBColor[
              0.46568499740161334`, 0.567934214729965, 0.952835467981789], 
             UndirectedEdge[215, 430] -> 
             RGBColor[
              0.3941752826615823, 0.5126452585532042, 0.9467602094047087], 
             UndirectedEdge[100, 254] -> 
             RGBColor[
              0.5176879006710733, 0.6148972216420272, 0.9568053552025416], 
             UndirectedEdge[186, 389] -> 
             RGBColor[
              0.7178046805026284, 0.7759874081535633, 0.9092579933134415], 
             UndirectedEdge[197, 426] -> 
             RGBColor[
              0.4203007030050043, 0.534832630951209, 0.9487279128531698], 
             UndirectedEdge[316, 378] -> 
             RGBColor[
              0.3121389602695317, 0.4425690293274434, 0.941191180613622], 
             UndirectedEdge[185, 330] -> 
             RGBColor[
              0.2630562911548311, 0.39381921910886997`, 0.9382920386731346], 
             UndirectedEdge[56, 166] -> 
             RGBColor[
              0.3981911067873397, 0.5190335601515901, 0.946671085952926], 
             UndirectedEdge[38, 73] -> 
             RGBColor[
              0.3354755136148102, 0.46415133060692865`, 0.9426280264833675], 
             UndirectedEdge[97, 430] -> 
             RGBColor[
              0.7288635727803833, 0.7864880634273146, 0.9553929476433978], 
             UndirectedEdge[222, 372] -> 
             RGBColor[
              0.8158566258996556, 0.8531776463194997, 0.77716493556596], 
             UndirectedEdge[137, 430] -> 
             RGBColor[
              0.437729741787374, 0.552285066419796, 0.949465338937731], 
             UndirectedEdge[30, 355] -> 
             RGBColor[
              0.6215214775810338, 0.68802397506465, 0.9107337960211767], 
             UndirectedEdge[111, 442] -> 
             RGBColor[
              0.7104335209586772, 0.7709455335190396, 0.9413802756935425], 
             UndirectedEdge[183, 408] -> 
             RGBColor[
              0.3368863314318415, 0.46505627629717405`, 0.9427295307073253], 
             UndirectedEdge[39, 283] -> 
             RGBColor[
              0.5231173626243382, 0.6227943700347586, 0.9558591763273762], 
             UndirectedEdge[244, 498] -> 
             RGBColor[
              0.28270655329107575`, 0.41412781418880995`, 0.9394237269664496],
              UndirectedEdge[259, 454] -> 
             RGBColor[
              0.3712472909932448, 0.49597747685212284`, 0.944876526994368], 
             UndirectedEdge[17, 418] -> 
             RGBColor[
              0.3125942727103033, 0.44082015491343773`, 0.9412986673509571], 
             UndirectedEdge[70, 391] -> 
             RGBColor[
              0.40387983362519153`, 0.5242421451206327, 0.9469558437550513], 
             UndirectedEdge[18, 495] -> 
             RGBColor[
              0.27242821481236884`, 0.4036697050872223, 0.9388257558609128], 
             UndirectedEdge[48, 95] -> 
             RGBColor[
              0.7678041529716475, 0.81737070366135, 0.9388500033772635], 
             UndirectedEdge[50, 92] -> 
             RGBColor[
              0.4630801302491392, 0.5700678726231747, 0.9520497000662782], 
             UndirectedEdge[118, 141] -> 
             RGBColor[
              0.635856664981493, 0.7030111776180599, 0.9094637483452149], 
             UndirectedEdge[373, 398] -> 
             RGBColor[
              0.40262005047772076`, 0.5226292462024037, 0.947019729271362], 
             UndirectedEdge[218, 409] -> 
             RGBColor[
              0.3353268148072711, 0.46385677719921947`, 0.94262462073827]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {5}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.9586292797732987, 0.9686663651100391, 0.9549140175185902], 
             316 -> RGBColor[
              0.33945424473729713`, 0.4684399381501887, 0.942850702200426], 
             308 -> RGBColor[
              0.4451234078505065, 0.5599652561522859, 0.9495838478344276], 
             160 -> RGBColor[
              0.4045356463039122, 0.5248101771008369, 0.9469976315590269], 
             245 -> RGBColor[
              0.3056575539631944, 0.4385958473965286, 0.9407181175671504], 
             155 -> RGBColor[
              0.43629081218979215`, 0.5523149057301412, 0.9490210426492846], 
             425 -> RGBColor[
              0.32013965490097224`, 0.45171061121347594`, 0.9416199936152765],
              213 -> RGBColor[
              0.2613501003508993, 0.3920259043951926, 0.9381948736309338], 
             352 -> RGBColor[
              0.5666477973126823, 0.6590692349076231, 0.9590277367851806], 27 -> 
             RGBColor[
              0.26220920774123596`, 0.39292888073299104`, 0.938243798525878], 
             485 -> RGBColor[
              0.3498128196385177, 0.4774120150925132, 0.9435107414334036], 
             454 -> RGBColor[
              0.3854948064565971, 0.5083179586455299, 0.9457843660811096], 
             367 -> RGBColor[
              0.28630766723442197`, 0.4182578895909105, 0.9396161701435389], 
             19 -> RGBColor[
              0.42138611701259165`, 0.5394052078994116, 0.9480713286522978], 
             164 -> 
             RGBColor[
              0.3577920714680226, 0.4843232419783724, 0.9440191723042043], 
             190 -> RGBColor[
              0.4923366322084342, 0.5987400833961565, 0.9531776896574072], 
             103 -> RGBColor[
              0.9860136177457847, 0.9884842857513227, 0.8814540797567383], 
             138 -> RGBColor[
              0.9345887651141399, 0.9506797288385384, 0.9936231048054682], 
             416 -> RGBColor[
              0.23762710558090522`, 0.36709153276718626`, 0.9368438841738084],
              476 -> RGBColor[
              0.34393576952958826`, 0.47232160967728587`, 0.9431362609973339],
              291 -> RGBColor[
              0.39833692363251993`, 0.5194411550797372, 0.9466026544317211], 
             28 -> RGBColor[
              0.40018514364644736`, 0.5210419903615623, 0.9467204213766918], 
             337 -> RGBColor[
              0.28623803669842396`, 0.4181847034827456, 0.939612204787523], 
             195 -> RGBColor[
              0.9863652656245823, 0.9886297011861438, 0.8756263643695237], 
             114 -> RGBColor[
              0.3261039341612174, 0.4568765701353084, 0.9420000322157343], 
             479 -> RGBColor[
              0.4586009041255429, 0.5713518995612344, 0.9505218895646782], 93 -> 
             RGBColor[
              0.33226604292056217`, 0.46221387902606115`, 0.9423926763369409],
              34 -> RGBColor[
              0.27970478632745144`, 0.41131784311085506`, 0.9392401458439739],
              161 -> RGBColor[
              0.6637253324428539, 0.7372265412944985, 0.9671175963381747], 22 -> 
             RGBColor[
              0.5612857371405044, 0.6547160729017911, 0.9586056157665532], 
             124 -> RGBColor[
              0.3525179925311579, 0.4797550998861752, 0.9436831126580322], 84 -> 
             RGBColor[
              0.2998550860276462, 0.4324970856985516, 0.9403876756022029], 46 -> 
             RGBColor[
              0.43345750306213526`, 0.5498608357700221, 0.9488405066970671], 
             241 -> RGBColor[
              0.6060759061011523, 0.6910787498381623, 0.9621316619389304], 
             185 -> RGBColor[
              0.2862520362013061, 0.41819941784789455`, 0.9396130020385017], 
             426 -> RGBColor[
              0.5443960088273342, 0.6410042305835699, 0.9572759944846271], 
             390 -> RGBColor[
              0.6360773834666271, 0.715435300714608, 0.9644934881361733], 121 -> 
             RGBColor[
              0.26764466236037276`, 0.3986418881654314, 0.9385533396254033], 
             322 -> 
             RGBColor[
              0.8480955971961303, 0.8817124245352161, 0.985373309236086], 488 -> 
             RGBColor[
              0.41385627480793563`, 0.532883237042612, 0.9475915337653952], 
             126 -> RGBColor[
              0.5427065925152671, 0.6396326863140963, 0.9571429974440053], 
             433 -> RGBColor[
              0.37889085179470317`, 0.5025979450418098, 0.9453635679297016], 
             236 -> RGBColor[
              0.986464031942322, 0.9886705435967077, 0.87398955088554], 78 -> 
             RGBColor[
              0.2920258346972056, 0.42426804614705327`, 0.9399418113212737], 
             376 -> RGBColor[
              0.5082426036212204, 0.6116532675449027, 0.9544298659925149], 
             458 -> RGBColor[
              0.3219708799135086, 0.45329672627928963`, 0.9417366776537867], 
             254 -> RGBColor[
              0.7079764824327259, 0.7717958759877828, 0.9715281374186572], 
             290 -> RGBColor[
              0.2529348099603532, 0.38318090063450094`, 0.9377156352924987], 
             251 -> RGBColor[
              0.34212995658763345`, 0.4707575052697621, 0.9430211961934903], 
             165 -> RGBColor[
              0.321457757820508, 0.45285228571259883`, 0.9417039819677567], 
             460 -> RGBColor[
              0.26957497433009414`, 0.4006707684344563, 0.9386632680364383], 
             100 -> RGBColor[
              0.3273993189094207, 0.45799856729627153`, 0.9420825729864261], 
             235 -> RGBColor[
              0.3039070967234375, 0.4367560058521449, 0.9406184316169157], 70 -> 
             RGBColor[
              0.40257096011335275`, 0.5231084646705735, 0.9468724434922683], 
             234 -> RGBColor[
              0.3277963087319396, 0.4583424199272488, 0.9421078688268726], 
             435 -> RGBColor[
              0.2606555379990374, 0.3912958753255892, 0.9381553193325082], 
             257 -> RGBColor[
              0.6309116224189601, 0.7112415031812287, 0.9640868205036948], 
             135 -> RGBColor[
              0.4742985738513105, 0.5840959750165748, 0.9517576676279496], 
             265 -> RGBColor[
              0.7195024751402691, 0.7808000690917045, 0.9726769406552193], 
             111 -> RGBColor[
              0.4492412533022181, 0.5635319269136281, 0.9498462333053429], 
             497 -> RGBColor[
              0.3124282634147412, 0.4450313914939083, 0.9411286305686897], 
             481 -> RGBColor[
              0.4627589359118407, 0.5747275770825483, 0.9508492250582679], 
             381 -> 
             RGBColor[
              0.4389523327939838, 0.5546201811055768, 0.9491906323886934], 
             182 -> RGBColor[
              0.34884584055520074`, 0.476574466412326, 0.9434491263812806], 
             188 -> RGBColor[
              0.2695892752795925, 0.4006857996391116, 0.938664082454356], 154 -> 
             RGBColor[
              0.5403764114639993, 0.6377409403632169, 0.9569595570559151], 
             336 -> RGBColor[
              0.3300118965420216, 0.46026145072966057`, 0.9422490441229636], 
             463 -> RGBColor[
              0.4214453277974545, 0.5394564933052393, 0.9480751015111512], 
             315 -> RGBColor[
              0.4354224345994045, 0.5515627607072741, 0.9489657103971012], 
             368 -> RGBColor[
              0.24246809842227124`, 0.3721797231801359, 0.9371195715545171], 
             269 -> RGBColor[
              0.5054313840201978, 0.6093709928287927, 0.9542085564876857], 
             208 -> RGBColor[
              0.4186075702409114, 0.5369985703396035, 0.9478942821089787], 86 -> 
             RGBColor[
              0.3590454686932877, 0.4854088716573207, 0.9440990376670626], 
             119 -> RGBColor[
              0.9531264061942908, 0.9645623310049435, 0.9642289471085608], 
             436 -> RGBColor[
              0.2848236758017663, 0.4166981205046981, 0.9395316590268178], 
             377 -> RGBColor[
              0.3674693794906465, 0.4927052397919255, 0.9446358018140985], 
             140 -> RGBColor[
              0.404835186786305, 0.525069624011343, 0.9470167180136917], 85 -> 
             RGBColor[
              0.6723897002033323, 0.7439952112406182, 0.9679811795434189], 
             351 -> RGBColor[
              0.6098837223149294, 0.6941701065806721, 0.9624314271797694], 
             443 -> RGBColor[
              0.3267179701832335, 0.4574084172752309, 0.9420391580480864], 
             242 -> RGBColor[
              0.5562588814772699, 0.6506350450171104, 0.9582098832747643], 
             117 -> RGBColor[
              0.29596655805636085`, 0.4284099962538174, 0.9401662296867999], 
             47 -> RGBColor[
              0.37259240417381656`, 0.4971425462817799, 0.9449622364167971], 
             451 -> RGBColor[
              0.38942002617178806`, 0.511717786675549, 0.946034477610426], 81 -> 
             RGBColor[
              0.24126142099932757`, 0.37091142870085464`, 0.9370508530603997],
              275 -> RGBColor[
              0.5944729112049051, 0.6816589158724256, 0.9612182316775271], 23 -> 
             RGBColor[
              0.30339639440360694`, 0.4362192253336057, 0.9405893478753177], 
             328 -> RGBColor[
              0.22494279174639853`, 0.3537595146951724, 0.936121531265694], 
             418 -> RGBColor[
              0.3635458840030683, 0.48930690520120224`, 0.9443858001510408], 
             110 -> RGBColor[
              0.8700948987293502, 0.8992540704226737, 0.9874716222553328], 6 -> 
             RGBColor[
              0.3100000016602304, 0.4429281532101355, 0.9409739038769197], 
             218 -> RGBColor[
              0.29784157500179465`, 0.43038075794640906`, 0.9402730091280034],
              108 -> RGBColor[
              0.46161511460741594`, 0.5737989714190537, 0.950759179255228], 
             297 -> RGBColor[
              0.2606555379990374, 0.3912958753255892, 0.9381553193325082], 
             487 -> RGBColor[
              0.826904067999911, 0.8648148743828871, 0.9833520422634492], 464 -> 
             RGBColor[
              0.37741256891592784`, 0.5013175307128724, 0.9452693730518602], 
             157 -> RGBColor[
              0.18094129430740732`, 0.3075111510307206, 0.9336157110809254], 
             441 -> RGBColor[
              0.7498180026665873, 0.8044827896018071, 0.9756985091243308], 
             354 -> RGBColor[
              0.4115328182432982, 0.5308707757466455, 0.9474434851676484], 
             385 -> RGBColor[
              0.4266948494229704, 0.5440033650886325, 0.9484095963871594], 
             270 -> RGBColor[
              0.9851765657254793, 0.9881381432296708, 0.8953261979543881], 
             392 -> RGBColor[
              0.2627344147883538, 0.393480906639562, 0.9382737082902372], 33 -> 
             RGBColor[
              0.301519026900481, 0.43424599305584566`, 0.940482434573331], 
             252 -> RGBColor[
              0.4256007668042487, 0.543055725714487, 0.9483398824101537], 394 -> 
             RGBColor[
              0.4026097094726367, 0.5231420274179858, 0.9468749125671772], 
             260 -> RGBColor[
              0.29812367976202636`, 0.43067726793588745`, 0.9402890745767619],
              159 -> RGBColor[
              0.4985700133461983, 0.6038006230144135, 0.9536684042541995], 
             183 -> RGBColor[
              0.3775672656810086, 0.5014515212755, 0.9452792301929381], 99 -> 
             RGBColor[
              0.28981573255423465`, 0.4219450886662215, 0.9398159492737848], 
             329 -> RGBColor[
              0.5193832200861992, 0.6206977218702248, 0.9553068961300607], 
             309 -> 
             RGBColor[
              0.43259323821343065`, 0.5491122529972885, 0.9487854365051471], 
             17 -> RGBColor[
              0.26164266141753834`, 0.39233340462567323`, 0.9382115345508736],
              349 -> RGBColor[
              0.30783808439297033`, 0.4408877231318375, 0.9408422955493204], 
             495 -> RGBColor[
              0.24321556210933143`, 0.3729653549071712, 0.9371621385057217], 
             347 -> RGBColor[
              0.3325573157320534, 0.4624661648955777, 0.9424112359829266], 
             340 -> RGBColor[
              0.3569997755298925, 0.4836369950587158, 0.9439686879076264], 
             404 -> RGBColor[
              0.530563928817335, 0.6297747249033492, 0.9561870824776614], 277 -> 
             RGBColor[
              0.29812367976202636`, 0.43067726793588745`, 0.9402890745767619],
              104 -> RGBColor[
              0.6160039403322353, 0.6991387752798007, 0.9629132331611889], 79 -> 
             RGBColor[
              0.4058908429724596, 0.5259839803409675, 0.9470839834923934], 
             327 -> RGBColor[
              0.3020007038048038, 0.4347522660223686, 0.9405098653604551], 
             191 -> RGBColor[
              0.31505928864242894`, 0.44731025330695845`, 0.9412962771696737],
              50 -> RGBColor[
              0.30042727594011637`, 0.43309849357549357`, 0.9404202609712391],
              225 -> RGBColor[
              0.8568564612110988, 0.8886980996934335, 0.9862089282667493], 
             405 -> RGBColor[
              0.4532513592918558, 0.5670052791680649, 0.9501017537130051], 61 -> 
             RGBColor[
              0.4120985524313363, 0.531360786265697, 0.9474795332498511], 196 -> 
             RGBColor[
              0.5420225936798031, 0.6390773852456701, 0.9570891505501072], 1 -> 
             RGBColor[
              0.3784898508575525, 0.502250618184943, 0.9453380165045775], 263 -> 
             RGBColor[
              0.5356165149626082, 0.6338766419524939, 0.9565848405672501], 
             201 -> RGBColor[
              0.3026980472157365, 0.4354852181613848, 0.9405495780360805], 
             371 -> RGBColor[
              0.3132992118742998, 0.44578576327443553`, 0.9411841266343832], 
             293 -> RGBColor[
              0.450059876593087, 0.5642409772629758, 0.9498983952575569], 362 -> 
             RGBColor[
              0.6941287923690254, 0.7609779552636774, 0.9701479290871287], 
             184 -> RGBColor[
              0.3954190511464476, 0.5169138405888368, 0.9464167301770818], 
             106 -> 
             RGBColor[
              0.39374528781759904`, 0.5154641109191791, 0.9463100794578184], 
             206 -> RGBColor[
              0.2581751884801171, 0.38868887071796127`, 0.938014067096754], 
             358 -> RGBColor[
              0.9891937029890417, 0.9897993327238724, 0.828751837479171], 247 -> 
             RGBColor[
              0.28705203470334867`, 0.41904026699637587`, 0.9396585607697013],
              220 -> RGBColor[
              0.432012974431648, 0.548609657674414, 0.9487484626100791], 407 -> 
             RGBColor[
              0.2963380942421082, 0.4288005043417927, 0.9401873881229397], 
             107 -> RGBColor[
              0.3190396740732511, 0.4507578631071478, 0.941549903809609], 375 -> 
             RGBColor[
              0.2612473277821236, 0.39191788390925214`, 0.9381890208851804], 
             131 -> RGBColor[
              0.9665553469986383, 0.9745776130689534, 0.9414972531555021], 
             411 -> RGBColor[
              0.3276252134846518, 0.45819422582354524`, 0.942096966789009], 
             462 -> RGBColor[
              0.7754451056319214, 0.8245028772115225, 0.978252779249022], 127 -> 
             RGBColor[
              0.5226248939676019, 0.6233294587628917, 0.9555620925726475], 
             210 -> RGBColor[
              0.33038879794875203`, 0.46058790378455494`, 0.9422730599473197],
              357 -> RGBColor[
              0.6509139508150753, 0.7272181925967712, 0.9658406775466859], 
             181 -> RGBColor[
              0.3352803392724801, 0.46482471102315265`, 0.9425847446350475], 
             194 -> RGBColor[
              0.3837849133107767, 0.5068369351443486, 0.945675413201857], 440 -> 
             RGBColor[
              0.3142204582130512, 0.4465837005498747, 0.9412428276364623], 
             490 -> RGBColor[
              0.5577047140322583, 0.6518088370192644, 0.9583237045097522], 
             118 -> RGBColor[
              0.2855729419323585, 0.41748564671416705`, 0.9395743286245151], 
             348 -> RGBColor[
              0.6359693997622602, 0.7153476346787924, 0.9644849872634081], 
             276 -> RGBColor[
              0.3937847702782421, 0.515498308642142, 0.9463125952452976], 305 -> 
             RGBColor[
              0.49569626931103444`, 0.601467588145974, 0.9534421725968801], 
             343 -> RGBColor[
              0.4117019346362595, 0.5310172558661916, 0.9474542611146641], 
             280 -> RGBColor[
              0.6421324261266174, 0.7203510571225513, 0.9649701632747198], 
             474 -> 
             RGBColor[
              0.23719934228221695`, 0.3666419264185053, 0.9368195236867672], 
             189 -> RGBColor[
              0.3327043087218732, 0.4625934828352771, 0.9424206022462572], 
             168 -> RGBColor[
              0.25712534774865503`, 0.3875854215454478, 0.9379542802201974], 
             363 -> RGBColor[
              0.39833692363251993`, 0.5194411550797372, 0.9466026544317211], 
             41 -> RGBColor[
              0.40442377631597815`, 0.5247132809400374, 0.9469905033023185], 
             14 -> RGBColor[
              0.4844777007102953, 0.5923598487651379, 0.9525590057816591], 77 -> 
             RGBColor[
              0.2453764701345685, 0.37523660625117744`, 0.9372851990209821], 
             51 -> RGBColor[
              0.28562726693914026`, 0.41754274574069905`, 0.9395774223532847],
              438 -> RGBColor[
              0.2786727655023221, 0.4102331237897445, 0.9391813737847208], 
             179 -> RGBColor[
              0.4886985251045678, 0.5957865041543804, 0.9528912845393654], 
             467 -> RGBColor[
              0.36368333007010134`, 0.4894259540762261, 0.9443945580928933], 
             223 -> RGBColor[
              0.9872562023584021, 0.988998126421608, 0.8608612370197721], 456 -> 
             RGBColor[
              0.18094129430740732`, 0.3075111510307206, 0.9336157110809254], 
             323 -> RGBColor[
              0.30652552076541173`, 0.43950813553793283`, 0.9407675469924949],
              500 -> RGBColor[
              0.4188229331138053, 0.5371851068356515, 0.9479080048408016], 
             478 -> RGBColor[
              0.3124232419739436, 0.44502704217427436`, 0.9411283106069223], 
             292 -> RGBColor[
              0.7831080606325866, 0.8304892358986572, 0.9790165509891025], 
             491 -> RGBColor[
              0.658191251972377, 0.7329032755703926, 0.9665660109157999], 396 -> 
             RGBColor[
              0.3273993189094207, 0.45799856729627153`, 0.9420825729864261], 
             321 -> RGBColor[
              0.40323704157008167`, 0.5236853909501646, 0.9469148856136983], 
             143 -> RGBColor[
              0.8391958107373182, 0.8746159763912273, 0.9845244396587113], 
             112 -> RGBColor[
              0.2964429012998352, 0.428910663204615, 0.9401933567298291], 197 -> 
             RGBColor[
              0.29620539718267436`, 0.42866103131884814`, 0.9401798312217127],
              421 -> RGBColor[
              0.3745871137053523, 0.49887026342098, 0.9450893375442943], 54 -> 
             RGBColor[
              0.26205223286463425`, 0.3927638901849006, 0.938234859038879], 
             71 -> RGBColor[
              0.33291749549543, 0.46277813450345323`, 0.9424341863189546], 
             177 -> RGBColor[
              0.2695892752795925, 0.4006857996391116, 0.938664082454356], 158 -> 
             RGBColor[
              0.6368165440572069, 0.7160353845808458, 0.9645516775654982], 
             226 -> RGBColor[
              0.2669526888048254, 0.3979145800848937, 0.9385139327550981], 
             432 -> RGBColor[
              0.5268509810964614, 0.6267603866771554, 0.9558947856320985], 
             350 -> RGBColor[
              0.5193832200861992, 0.6206977218702248, 0.9553068961300607], 
             203 -> RGBColor[
              0.40646710772714933`, 0.526483111907571, 0.9471207025729913], 
             475 -> RGBColor[
              0.35311517457831754`, 0.48027234896018245`, 0.9437211645700099],
              115 -> RGBColor[
              0.2841197624190679, 0.4159582629087959, 0.9394915722010196], 
             173 -> RGBColor[
              0.28981573255423465`, 0.4219450886662215, 0.9398159492737848], 
             212 -> RGBColor[
              0.36707651346263914`, 0.4923649589844862, 0.9446107687381916], 
             129 -> RGBColor[
              0.37259240417381656`, 0.4971425462817799, 0.9449622364167971], 
             279 -> RGBColor[
              0.5832873372789866, 0.672577963055002, 0.9603376623239713], 26 -> 
             RGBColor[
              0.3940964257134736, 0.5157682489158819, 0.9463324536540445], 40 -> 
             RGBColor[
              0.2818432437540387, 0.4135654974522302, 0.9393619278308538], 
             146 -> RGBColor[
              0.5850498501574368, 0.6740088504100282, 0.9604764137940603], 
             386 -> RGBColor[
              0.2719995033233183, 0.4032191021303518, 0.9388013413758333], 
             192 -> RGBColor[
              0.3386915012799669, 0.4677792881040501, 0.9428021008617924], 
             300 -> RGBColor[
              0.24369159626407483`, 0.3734656969861151, 0.937189247946605], 
             221 -> RGBColor[
              0.3427403089163204, 0.47128616177967075`, 0.9430600873041609], 
             62 -> RGBColor[
              0.33151244588043427`, 0.4615611511467909, 0.9423446577999236], 
             286 -> RGBColor[
              0.3674228704635589, 0.4926649560102739, 0.9446328383000188], 
             472 -> RGBColor[
              0.5616969521765701, 0.6550499157930956, 0.9586379881205226], 
             152 -> 
             RGBColor[
              0.3912018714312688, 0.5132611314811645, 0.9461480152147362], 64 -> 
             RGBColor[
              0.26730808810799495`, 0.39828812728614216`, 0.9385341722196474],
              307 -> RGBColor[
              0.4490933235176433, 0.5634037975693966, 0.949836807350279], 37 -> 
             RGBColor[
              0.29785915908594424`, 0.4303992399337456, 0.9402740105155823], 
             148 -> RGBColor[
              0.3048021132033892, 0.43769672491989653`, 0.9406694014813907], 
             261 -> RGBColor[
              0.6733818408644976, 0.7447702790656688, 0.9680800668524423], 
             387 -> RGBColor[
              0.5684135658503572, 0.6605027653534736, 0.9591667445526897], 15 -> 
             RGBColor[
              0.6353069280400749, 0.7148098102907114, 0.9644328350627239], 
             136 -> RGBColor[
              0.26279561318268263`, 0.3935452300322039, 0.9382771934482593], 
             198 -> RGBColor[
              0.31920685839167895`, 0.45090266976084187`, 0.9415605566465439],
              63 -> RGBColor[
              0.2806776698832937, 0.41234040541242545`, 0.9392955501232269], 
             444 -> RGBColor[
              0.39132945768338123`, 0.5133716402800728, 0.9461561448979008], 
             310 -> RGBColor[
              0.42554400610883714`, 0.543006562452997, 0.9483362656688336], 
             171 -> RGBColor[
              0.28294056430907044`, 0.4147188509297101, 0.9394244186131225], 
             395 -> RGBColor[
              0.3582084730159227, 0.4846839080702131, 0.9440457050426271], 
             311 -> RGBColor[
              0.36853457705775655`, 0.49362786038616974`, 0.9447036752611574],
              353 -> RGBColor[
              0.38481507445297514`, 0.5077292089483164, 0.9457410541589022], 
             59 -> RGBColor[
              0.9382510295373035, 0.9534682994503562, 0.989409079669249], 397 -> 
             RGBColor[
              0.30429074874764006`, 0.43715924845452503`, 0.9406402800321317],
              229 -> RGBColor[
              0.8395540998780231, 0.8749016664265258, 0.9845586135968003], 
             102 -> RGBColor[
              0.2945681916628217, 0.42694022451265756`, 0.9400865947893855], 
             453 -> RGBColor[
              0.993382932934981, 0.9882550875730577, 0.5211512696560812], 299 -> 
             RGBColor[
              0.4529723096769034, 0.5667635804170346, 0.9500839729182943], 
             128 -> RGBColor[
              0.7773617042938953, 0.8260001386529457, 0.9784438078920148], 12 -> 
             RGBColor[
              0.6831488138062046, 0.7524003125594739, 0.9690535474377201], 
             222 -> RGBColor[
              0.6377004499925125, 0.7167529792386355, 0.9646212618785796], 
             483 -> RGBColor[
              0.48869581167072734`, 0.5957843012665499, 0.9528910709279138], 
             92 -> RGBColor[
              0.625732984558162, 0.7070372516708557, 0.9636791391613172], 271 -> 
             RGBColor[
              0.31199681496977966`, 0.4446576925361119, 0.9411011390552916], 
             361 -> RGBColor[
              0.4844071146974401, 0.5923025438600384, 0.952553448992162], 344 -> 
             RGBColor[
              0.7664759136342795, 0.8174960762545807, 0.9773588140125617], 
             132 -> RGBColor[
              0.5454070354963795, 0.6418250275797333, 0.957355586207527], 80 -> 
             RGBColor[
              0.2783530927067427, 0.40989712741316464`, 0.9391631688919261], 
             324 -> RGBColor[
              0.9471841116542518, 0.9601305774665966, 0.9742877017662155], 
             244 -> RGBColor[
              0.31247829662179827`, 0.445074727743119, 0.9411318186404006], 
             150 -> RGBColor[
              0.22560984880480164`, 0.35446063395741434`, 0.9361595191783475],
              125 -> RGBColor[
              0.3551123878381439, 0.48200223470298686`, 0.9438484252328596], 
             258 -> RGBColor[
              0.2704105857268995, 0.4015490489933214, 0.9387108548693102], 
             133 -> RGBColor[
              0.41822183995044665`, 0.5366644701493711, 0.9478697037159582], 
             469 -> RGBColor[
              0.2685511023423144, 0.3995946140580663, 0.9386049600414171], 
             255 -> RGBColor[
              0.9475713826411643, 0.9604194035345379, 0.9736321530018226], 
             408 -> RGBColor[
              0.29620539718267436`, 0.42866103131884814`, 0.9401798312217127],
              326 -> RGBColor[
              0.4288762038175493, 0.545892744627157, 0.9485485903602859], 176 -> 
             RGBColor[
              0.3681476038158454, 0.49329268361386697`, 0.9446790176683699], 
             230 -> RGBColor[
              0.2695892752795925, 0.4006857996391116, 0.938664082454356], 274 -> 
             RGBColor[
              0.5054594263093968, 0.6093937588224551, 0.9542107640794136], 87 -> 
             RGBColor[
              0.5302367942117492, 0.6295091422932886, 0.9561613292431761], 
             439 -> RGBColor[
              0.38581416804558577`, 0.5085945736023316, 0.9458047155191596], 
             130 -> 
             RGBColor[
              0.9636530807450417, 0.889055448069851, 0.31329951154459285`], 
             35 -> RGBColor[
              0.2951216739187321, 0.42752196945642135`, 0.940118114785056], 
             379 -> RGBColor[
              0.4183537584441691, 0.5367787313182172, 0.9478781094457273], 31 -> 
             RGBColor[
              0.23986054610835603`, 0.36943902036984544`, 0.9369710753077676],
              18 -> RGBColor[
              0.30164086751540625`, 0.43437405526727335`, 0.9404893732161039],
              24 -> RGBColor[
              0.5371642234967091, 0.635133141463952, 0.9567066818524977], 151 -> 
             RGBColor[
              0.3340945104015635, 0.4637976056566568, 0.94250918466798], 137 -> 
             RGBColor[
              0.37514120321792754`, 0.499350187907424, 0.9451246436380734], 
             330 -> RGBColor[
              0.23986054610835603`, 0.36943902036984544`, 0.9369710753077676],
              296 -> RGBColor[
              0.2561892960116076, 0.386601571820703, 0.9379009734585371], 266 -> 
             RGBColor[
              0.26957497433009414`, 0.4006707684344563, 0.9386632680364383], 
             302 -> RGBColor[
              0.3326338586747388, 0.46253246254537167`, 0.9424161132315504], 
             442 -> RGBColor[
              0.9716257886151362, 0.9783591401244512, 0.9329143180817423], 
             283 -> RGBColor[
              0.41888646248628264`, 0.5372401327850123, 0.947912052876239], 
             388 -> RGBColor[
              0.5323745719653536, 0.631244686579455, 0.9563296229388778], 284 -> 
             RGBColor[
              0.3517473824880787, 0.4790876361988469, 0.9436340100675109], 
             417 -> RGBColor[
              0.5017506314400997, 0.606382792068255, 0.9539187941615394], 318 -> 
             RGBColor[
              0.7168915547291956, 0.7787603982228439, 0.9724167085090819], 
             413 -> RGBColor[
              0.4160089249592759, 0.5347477544083604, 0.9477286987295247], 
             238 -> RGBColor[
              0.4064946335040003, 0.5265069533519936, 0.9471224564911521], 72 -> 
             RGBColor[
              0.34676744567283496`, 0.4747742652283849, 0.9433166928972287], 
             437 -> RGBColor[
              0.37967474505675297`, 0.5032769139857763, 0.9454135169151897], 
             288 -> RGBColor[
              0.9467181080918152, 0.9597830327727422, 0.975076524244226], 382 -> 
             RGBColor[
              0.3869117617069193, 0.5095452540651173, 0.9458746532166957], 
             461 -> 
             RGBColor[
              0.3528825637432511, 0.48007087314620844`, 0.9437063428132891], 
             389 -> RGBColor[
              0.9867834348810767, 0.9888026249201639, 0.8686962176020652], 
             172 -> RGBColor[
              0.32951022615112624`, 0.459826929051754, 0.9422170781292655], 
             447 -> RGBColor[
              0.47906174873766616`, 0.5879629349679016, 0.9521326422030879], 
             243 -> RGBColor[
              0.3083294034302258, 0.4414041305914192, 0.9408702754416508], 
             410 -> RGBColor[
              0.29784157500179465`, 0.43038075794640906`, 0.9402730091280034],
              88 -> RGBColor[
              0.3130914580392557, 0.4456058173445317, 0.9411708887437237], 
             273 -> RGBColor[
              0.3851918675497359, 0.5080555681905589, 0.9457650630818427], 
             477 -> RGBColor[
              0.27192488034993023`, 0.40314066865395115`, 0.9387970917078936],
              202 -> RGBColor[
              0.36279989644787486`, 0.4886607682753184, 0.9443382664836747], 
             393 -> RGBColor[
              0.33517636874142503`, 0.4647346569748636, 0.9425781197247463], 
             98 -> RGBColor[
              0.45026698586367564`, 0.5644203649035451, 0.9499115920771393], 
             30 -> RGBColor[
              0.9858894591608747, 0.9884329429857324, 0.8835117088208154], 
             116 -> RGBColor[
              0.8650483065374935, 0.895230054794983, 0.9869902737869275], 373 -> 
             RGBColor[
              0.47253321266543585`, 0.5826627752772667, 0.9516186919286663], 
             434 -> RGBColor[
              0.6139127595251401, 0.6974410604939791, 0.9627486077478067], 
             401 -> RGBColor[
              0.3327043087218732, 0.4625934828352771, 0.9424206022462572], 
             240 -> RGBColor[
              0.38910695627595493`, 0.5114466212671289, 0.9460145290735004], 
             480 -> RGBColor[
              0.3426163435773886, 0.4711787892337671, 0.9430521883423824], 
             403 -> RGBColor[
              0.32782167471464396`, 0.45836439066653595`, 0.9421094851248603],
              317 -> RGBColor[
              0.288960207830285, 0.4210458779379499, 0.9397672284063912], 429 -> 
             RGBColor[
              0.39833692363251993`, 0.5194411550797372, 0.9466026544317211], 
             391 -> RGBColor[
              0.40518870713703026`, 0.5253758255706918, 0.9470392440178342], 
             73 -> RGBColor[
              0.29963438976567475`, 0.43226511993426836`, 0.9403751072765746],
              303 -> 
             RGBColor[
              0.5710895874118941, 0.6626752802105269, 0.9593774107726039], 
             449 -> RGBColor[
              0.3747630771409237, 0.4990226741046925, 0.9451005497788105], 29 -> 
             RGBColor[
              0.8866695456241197, 0.9124702439497583, 0.9890525268725179], 
             360 -> RGBColor[
              0.4071071964584035, 0.5270375245947884, 0.9471614884609386], 
             320 -> RGBColor[
              0.4039162249533107, 0.5242736654599682, 0.9469581625782993], 
             482 -> RGBColor[
              0.3203821837609257, 0.4519206775221127, 0.9416354473397729], 75 -> 
             RGBColor[
              0.34223506018554384`, 0.47084854072361165`, 0.9430278933018097],
              200 -> RGBColor[
              0.38910739835262353`, 0.5114470041717197, 0.9460145572422348], 
             301 -> RGBColor[
              0.2440399789577002, 0.37383186928585393`, 0.9372090878256208], 
             156 -> RGBColor[
              0.8714907091093482, 0.9003670517314206, 0.9876047558954316], 25 -> 
             RGBColor[
              0.4257039583555728, 0.5431451050496858, 0.9483464576845554], 38 -> 
             RGBColor[
              0.3713166374639456, 0.49603754127958893`, 0.9448809456901603], 
             365 -> RGBColor[
              0.23719934228221695`, 0.3666419264185053, 0.9368195236867672], 
             380 -> RGBColor[
              0.2792857550550818, 0.41087741467547734`, 0.9392162826329137], 
             370 -> RGBColor[
              0.26896434360838894`, 0.4000289568297203, 0.9386284935201844], 
             3 -> RGBColor[
              0.2401070432970385, 0.3696981045439751, 0.9369851129580031], 57 -> 
             RGBColor[
              0.32199072264166095`, 0.45331391305309066`, 0.9417379420148783],
              227 -> RGBColor[
              0.3974555480560665, 0.5186777518546378, 0.9465464939593593], 
             494 -> RGBColor[
              0.4569487303192949, 0.5700105904357405, 0.9503918243905383], 39 -> 
             RGBColor[
              0.6273482627623936, 0.7083486072845049, 0.9638062997785133], 
             424 -> RGBColor[
              0.29581131059607163`, 0.42824682132979597`, 0.9401573885736044],
              109 -> RGBColor[
              0.3940964257134736, 0.5157682489158819, 0.9463324536540445], 
             465 -> RGBColor[
              0.3953171937829789, 0.5168256168601002, 0.9464102399159505], 
             256 -> RGBColor[
              0.5197753854574539, 0.621016099385458, 0.9553377688246351], 457 -> 
             RGBColor[
              0.26766488320898485`, 0.3986631415593985, 0.9385544911728178], 
             339 -> RGBColor[
              0.2858665602357461, 0.41779425816750304`, 0.9395910497525237], 
             420 -> RGBColor[
              0.3531992542573668, 0.4803451745522074, 0.9437265220528102], 
             287 -> RGBColor[
              0.2453764701345685, 0.37523660625117744`, 0.9372851990209821], 
             239 -> RGBColor[
              0.7308010484972366, 0.7896266004705055, 0.9738030768562707], 
             427 -> RGBColor[
              0.5990648062537809, 0.6853868231356175, 0.9615797224764403], 
             285 -> RGBColor[
              0.2664093351265417, 0.39734348091840455`, 0.9384829895669395], 
             345 -> RGBColor[
              0.5198007065558461, 0.6210366561938352, 0.9553397621942546], 
             366 -> RGBColor[
              0.28275272105062776`, 0.41452141575513646`, 0.9394137212174435],
              216 -> RGBColor[
              0.8006028132537346, 0.8441562696113425, 0.98076026443262], 21 -> 
             RGBColor[
              0.9945334585452018, 0.9907159455173371, 0.6463788821075999], 
             355 -> RGBColor[
              0.257153496001193, 0.38761500714356745`, 0.9379558832215379], 
             175 -> RGBColor[
              0.34432531471217814`, 0.47265901413533506`, 0.9431610824719073],
              7 -> RGBColor[
              0.34393576952958826`, 0.47232160967728587`, 0.9431362609973339],
              13 -> RGBColor[
              0.405388244052324, 0.5255486544177023, 0.9470519583336331], 294 -> 
             RGBColor[
              0.3397052015407604, 0.46865730431989294`, 0.9428666929460302], 
             412 -> RGBColor[
              0.4449444189023115, 0.5598102249216055, 0.9495724428169223], 
             193 -> RGBColor[
              0.4116278143703612, 0.5309530566172633, 0.9474495382368631], 60 -> 
             RGBColor[
              0.2788764444926004, 0.4104472033225209, 0.9391929730019011], 65 -> 
             RGBColor[
              0.384809920085961, 0.5077247444946748, 0.9457407257271939], 448 -> 
             RGBColor[
              0.5666477973126823, 0.6590692349076231, 0.9590277367851806], 69 -> 
             RGBColor[
              0.23927221469162774`, 0.3688206467484977, 0.9369375707039432], 
             217 -> RGBColor[
              0.33909494609596846`, 0.4681287317259446, 0.9428278080087158], 
             214 -> RGBColor[
              0.5369002236882313, 0.6349188145263739, 0.9566858988205111], 
             170 -> 
             RGBColor[
              0.450059876593087, 0.5642409772629758, 0.9498983952575569], 359 -> 
             RGBColor[
              0.29464632978828753`, 0.42702235263676547`, 0.9400910446400358],
              74 -> RGBColor[
              0.4288762038175493, 0.545892744627157, 0.9485485903602859], 246 -> 
             RGBColor[
              0.9853953152802618, 0.9882286017921804, 0.8917009517259403], 
             264 -> RGBColor[
              0.39727661492173405`, 0.5185227689671199, 0.946535092498264], 
             278 -> RGBColor[
              0.2796691806421959, 0.4112804192781207, 0.9392381181528725], 45 -> 
             RGBColor[
              0.24540869126065867`, 0.3752704726976356, 0.937287033966446], 
             492 -> RGBColor[
              0.3192850550014802, 0.4509703997339758, 0.9415655392653739], 
             306 -> RGBColor[
              0.37079008149521286`, 0.49558146496494515`, 0.944847394009448], 
             237 -> RGBColor[
              0.24772497361951157`, 0.3777050323175738, 0.93741894282015], 
             228 -> RGBColor[
              0.8977013066384987, 0.9212666707334485, 0.9901047460862387], 
             180 -> RGBColor[
              0.6941287923690254, 0.7609779552636774, 0.9701479290871287], 
             383 -> RGBColor[
              0.30681464682369713`, 0.43981202535684166`, 0.9407840122937905],
              53 -> RGBColor[
              0.6028108329249344, 0.6884280163438383, 0.9618746234181415], 
             304 -> RGBColor[
              0.8404487752782038, 0.8756150563053131, 0.9846439485351557], 48 -> 
             RGBColor[
              0.5560612517279696, 0.6504746002835097, 0.9581943251369578], 5 -> 
             RGBColor[
              0.30221228616984497`, 0.4349746525031236, 0.9405219146631361], 
             101 -> RGBColor[
              0.6940659874336286, 0.7609288915708102, 0.9701416692781137], 
             333 -> RGBColor[0.817319, 0.134127, 0.164218], 267 -> 
             RGBColor[
              0.26825628115537903`, 0.3992847382978544, 0.93858817041097], 
             120 -> RGBColor[
              0.822087951598109, 0.8609746338940873, 0.9828926767816474], 147 -> 
             RGBColor[
              0.3506294925535046, 0.4781193761243007, 0.943562779109391], 89 -> 
             RGBColor[
              0.48830400009874925`, 0.595466210981508, 0.9528602260857146], 
             43 -> RGBColor[
              0.34740878974107187`, 0.4753297652254016, 0.9433575587741385], 
             199 -> RGBColor[0.178927, 0.305394, 0.933501], 268 -> 
             RGBColor[
              0.3192850550014802, 0.4509703997339758, 0.9415655392653739], 
             169 -> RGBColor[
              0.2761347903201828, 0.40756555095639546`, 0.9390368398526958], 
             20 -> RGBColor[
              0.33185693197416005`, 0.4618595276868017, 0.9423666081491988], 
             4 -> RGBColor[
              0.6352219969358905, 0.7147408593942319, 0.9644261489750896], 
             167 -> RGBColor[
              0.4171788478980545, 0.5357610828558937, 0.9478032451846615], 
             431 -> RGBColor[
              0.37747315389622627`, 0.5013700063777173, 0.9452732334732316], 
             142 -> RGBColor[
              0.40453022590453835`, 0.5248054822233365, 0.9469972861759719], 
             16 -> RGBColor[
              0.29419324763757476`, 0.4265461345692988, 0.9400652422818278], 
             414 -> RGBColor[
              0.3130914580392557, 0.4456058173445317, 0.9411708887437237], 
             281 -> RGBColor[
              0.3631445053415573, 0.4889592511784795, 0.9443602246576545], 
             289 -> RGBColor[
              0.3467188229394627, 0.4747321506605875, 0.9433135946996537], 
             398 -> RGBColor[
              0.3327068882900057, 0.46259571712754066`, 0.9424207666140576], 
             178 -> RGBColor[
              0.26539779755890297`, 0.3962802907996302, 0.9384253839988983], 
             58 -> RGBColor[
              0.3569997755298925, 0.4836369950587158, 0.9439686879076264], 
             186 -> RGBColor[
              0.44882592612418015`, 0.5631721913869626, 0.9498197690248177], 
             122 -> RGBColor[
              0.31566265905413826`, 0.4478328624313024, 0.9413347233987682], 
             249 -> RGBColor[
              0.49457490982061725`, 0.6005572179949841, 0.9533538950701194], 
             113 -> RGBColor[
              0.26965267040777585`, 0.4007524319383156, 0.9386676927131212], 
             52 -> RGBColor[
              0.24516318722034802`, 0.37501243238541393`, 0.937273052874541], 
             409 -> RGBColor[
              0.3728120546127475, 0.4973327964520298, 0.9449762323485366], 
             187 -> RGBColor[
              0.9857839073795186, 0.9883892946115845, 0.885260974997138], 259 -> 
             RGBColor[
              0.3569997755298925, 0.4836369950587158, 0.9439686879076264], 42 -> 
             RGBColor[
              0.36566575827646075`, 0.49114303374883583`, 0.9445208766652101],
              134 -> RGBColor[
              0.3724052374673627, 0.49698043188792174`, 0.944950310319767], 
             470 -> 
             RGBColor[
              0.4344130032297485, 0.5506884419903739, 0.9489013903228318], 
             313 -> RGBColor[
              0.28901824809094245`, 0.421106881931866, 0.9397705337133727], 
             248 -> RGBColor[
              0.28292258152337885`, 0.41469994988177383`, 0.9394233945200806],
              174 -> RGBColor[
              0.32782167471464396`, 0.45836439066653595`, 0.9421094851248603],
              215 -> RGBColor[
              0.28803228496634414`, 0.4200705721742405, 0.9397143845720286], 
             399 -> RGBColor[
              0.22560984880480164`, 0.35446063395741434`, 0.9361595191783475],
              422 -> RGBColor[
              0.5708890353289431, 0.6625124629948189, 0.9593616225779874], 83 -> 
             RGBColor[
              0.3835829498734603, 0.5066620045659227, 0.9456625442702205], 95 -> 
             RGBColor[
              0.9795470542153255, 0.9842668070391905, 0.9195056816175693], 
             166 -> RGBColor[
              0.3327043087218732, 0.4625934828352771, 0.9424206022462572], 
             384 -> RGBColor[
              0.9019910364315739, 0.9246871848288334, 0.9905139043433892], 
             233 -> RGBColor[
              0.2447417113395881, 0.37456943451162095`, 0.9372490504466494], 
             295 -> RGBColor[
              0.3114229575685212, 0.4441606460980535, 0.9410645733691255], 
             499 -> RGBColor[
              0.36728333829024157`, 0.4925441002548373, 0.9446239474333183], 
             141 -> RGBColor[
              0.9861403880306273, 0.9885367085219529, 0.8793531680659148], 
             319 -> RGBColor[
              0.4122951547861233, 0.5315310733438919, 0.9474920605780495], 
             205 -> RGBColor[
              0.32774213496000987`, 0.45829549732885616`, 0.9421044169220293],
              468 -> RGBColor[
              0.2745249347963217, 0.40587349073008183`, 0.9389451609621797], 
             486 -> RGBColor[
              0.5336641165976901, 0.6322915970053093, 0.9564311406160929], 
             224 -> RGBColor[
              0.8952576019566476, 0.9193181269527371, 0.9898716633521628], 
             231 -> RGBColor[
              0.4120985524313363, 0.531360786265697, 0.9474795332498511], 332 -> 
             RGBColor[
              0.409462018078479, 0.5290771527253217, 0.9473115356122828], 68 -> 
             RGBColor[
              0.5073336044535962, 0.6109153010706795, 0.9543583062482658], 
             484 -> RGBColor[
              0.4511140875827428, 0.5651540818360308, 0.9499655686496156], 10 -> 
             RGBColor[
              0.4172916525522569, 0.5358587885776371, 0.947810432997478], 250 -> 
             RGBColor[
              0.2776960139127448, 0.4092064959394711, 0.9391257492266688], 
             282 -> RGBColor[
              0.2682312022583671, 0.39925837878700093`, 0.9385867422048861], 
             374 -> RGBColor[
              0.8661615108780599, 0.48515250431812884`, 0.2100342228061329], 
             232 -> RGBColor[
              0.37905118192728326`, 0.5027368149442238, 0.9453737840239751], 
             489 -> RGBColor[
              0.3323547408441664, 0.46229070470939987`, 0.9423983280902004], 
             253 -> RGBColor[
              0.28815792440552873`, 0.420202627190824, 0.9397215395522233], 
             459 -> RGBColor[
              0.4113777395761776, 0.5307364543996662, 0.9474336036921102], 
             415 -> RGBColor[
              0.6334586910265279, 0.7133093282209853, 0.9642873350747022], 55 -> 
             RGBColor[
              0.6967361938056322, 0.7630148770829396, 0.9704078104947778], 
             446 -> RGBColor[
              0.5314739146464285, 0.6305134923938017, 0.9562587198955155], 
             325 -> RGBColor[
              0.873577077253361, 0.9020306650565018, 0.9878037555515304], 91 -> 
             RGBColor[
              0.992962743789591, 0.9873563454787078, 0.4754162742871937], 450 -> 
             RGBColor[
              0.5249943661189675, 0.6252531029988743, 0.9557486261000655], 
             423 -> RGBColor[
              0.3654745522090817, 0.4909774206635685, 0.9445086931836736], 
             105 -> RGBColor[
              0.3482529267852264, 0.4760609143054868, 0.943411346440151], 36 -> 
             RGBColor[
              0.25107275389378836`, 0.3812237616473677, 0.937609593954173], 
             123 -> RGBColor[
              0.4150586189964345, 0.5339246471471137, 0.947668146073895], 94 -> 
             RGBColor[
              0.6060759061011523, 0.6910787498381623, 0.9621316619389304], 
             473 -> RGBColor[
              0.3210478071146062, 0.4524972070158682, 0.9416778602712818], 
             312 -> RGBColor[
              0.34692160650744, 0.47490779159497093`, 0.9433265158892907], 96 -> 
             RGBColor[
              0.23982054181110918`, 0.36939697331702004`, 0.9369687971222204],
              496 -> RGBColor[
              0.32020922559365694`, 0.45177086985075476`, 0.9416244265982955],
              2 -> RGBColor[
              0.22167695193984016`, 0.3503269099922762, 0.9359355465200875], 
             262 -> 
             RGBColor[
              0.9158685519266547, 0.7041538740719752, 0.251164065942531], 272 -> 
             RGBColor[
              0.3391703942367055, 0.4681940811133172, 0.9428326154975274], 97 -> 
             RGBColor[
              0.9574088652039461, 0.9677561819224613, 0.9569798610494067], 
             372 -> RGBColor[
              0.9940128018067986, 0.9896023134003639, 0.5897086092533403], 
             356 -> RGBColor[
              0.26907022204244796`, 0.4001402417769967, 0.938634523140371], 
             402 -> RGBColor[
              0.5174141947458568, 0.6190991783953541, 0.9551518872424916], 
             455 -> RGBColor[
              0.28969055988578707`, 0.42181352425527757`, 0.939808820875493], 
             428 -> RGBColor[
              0.2695892752795925, 0.4006857996391116, 0.938664082454356], 346 -> 
             RGBColor[
              0.8446983200509561, 0.8790035279562859, 0.9850492739091942], 
             341 -> RGBColor[
              0.4157716243978901, 0.5345422165891611, 0.9477135781475898], 
             209 -> RGBColor[
              0.9871684527912767, 0.9889618397205406, 0.8623154744356399], 
             498 -> RGBColor[
              0.2529348099603532, 0.38318090063450094`, 0.9377156352924987], 
             378 -> RGBColor[
              0.2848236758017663, 0.4166981205046981, 0.9395316590268178], 
             419 -> RGBColor[
              0.3152992554300839, 0.44751810047734375`, 0.9413115676411887], 
             66 -> RGBColor[
              0.3597486052916734, 0.48601789323816946`, 0.9441438409093524], 
             139 -> RGBColor[
              0.736027733340804, 0.7937097263945764, 0.9743240239553306], 56 -> 
             RGBColor[
              0.4636779048528063, 0.5754736374679031, 0.9509215696595948], 
             335 -> RGBColor[
              0.5214030325058275, 0.6223374965839916, 0.9554659031625505], 
             314 -> RGBColor[
              0.40726874650182526`, 0.527177451122659, 0.9471717822868523], 
             144 -> RGBColor[
              0.3638949436684964, 0.4896092431391472, 0.9444080419242605], 
             298 -> RGBColor[
              0.2937632488624494, 0.426094178593145, 0.9400407544877105], 204 -> 
             RGBColor[
              0.45115405829969596`, 0.5651887024620689, 0.9499681155483551], 
             452 -> RGBColor[
              0.4445295509185989, 0.5594508871259848, 0.9495460077958535], 
             466 -> RGBColor[
              0.34194698486897257`, 0.47059902436348405`, 0.9430095373973728],
              207 -> 
             RGBColor[
              0.9291406244996601, 0.9463355293983895, 0.9931034562900466], 
             334 -> RGBColor[
              0.4630577217682475, 0.5749701449009288, 0.9508727465753729], 
             149 -> RGBColor[
              0.9926265985830823, 0.9866373648714795, 0.43882894300647535`], 
             219 -> RGBColor[
              0.41919164028495165`, 0.5375044624555372, 0.9479314985357121], 
             400 -> RGBColor[
              0.396890394299122, 0.5181882440758263, 0.9465104828617126], 9 -> 
             RGBColor[
              0.2759857472462627, 0.40740889723582874`, 0.9390283520701255], 
             11 -> RGBColor[
              0.3665917725171158, 0.4919451007412622, 0.9445798814737825], 44 -> 
             RGBColor[
              0.2739066332228752, 0.40522361657380557`, 0.9389099496022671], 
             153 -> RGBColor[
              0.5283222385890989, 0.6279548197890732, 0.9560106084113127], 
             471 -> RGBColor[
              0.4076000208382393, 0.5274643843025286, 0.9471928907946342], 
             406 -> RGBColor[
              0.5174141947458568, 0.6190991783953541, 0.9551518872424916], 32 -> 
             RGBColor[
              0.7488512770935687, 0.8037275762367784, 0.9756021549537764], 
             162 -> RGBColor[
              0.3166263821614996, 0.44866759094876696`, 0.9413961309829825], 
             493 -> RGBColor[
              0.5423758830864834, 0.6393642015015197, 0.9571169627863428], 90 -> 
             RGBColor[
              0.3481648991511409, 0.47598466919323945`, 0.9434057373971468], 
             331 -> RGBColor[
              0.30744520797499425`, 0.44047478510674104`, 0.9408199218185253],
              8 -> RGBColor[
              0.2876866935075995, 0.4197073336393358, 0.9396947036497099], 
             364 -> RGBColor[
              0.40516580724862605`, 0.525355990838338, 0.9470377848571947], 
             342 -> RGBColor[
              0.3306315518661595, 0.4607981650266466, 0.942288528012278], 163 -> 
             RGBColor[
              0.23066014061571188`, 0.3597688108576761, 0.9364471258257416], 
             49 -> RGBColor[
              0.2880405985751694, 0.42007931030422907`, 0.9397148580197523], 
             338 -> RGBColor[
              0.45983672699690087`, 0.5723551962413888, 0.9506191780680798], 
             76 -> RGBColor[
              0.33843551722860254`, 0.4675575675848908, 0.9427857897843973], 
             369 -> RGBColor[
              0.38738569046126714`, 0.5099557473317816, 0.9459048515378441], 
             445 -> 
             RGBColor[
              0.2621099959753389, 0.39282460287664395`, 0.9382381485625808], 
             82 -> RGBColor[
              0.3192850550014802, 0.4509703997339758, 0.9415655392653739], 67 -> 
             RGBColor[
              0.5929328239825675, 0.6804086036851932, 0.9610969903698593], 
             430 -> RGBColor[
              0.5003182803568205, 0.6052199449321679, 0.9538060342373887], 
             211 -> RGBColor[
              0.35991981749298807`, 0.4861661886415728, 
               0.9441547503994232]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9V3c41W/cPkZ2skfWMY5xzsFxzjFCvnekUipFSBqEZKVlFlIpoUVlJUVG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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 54}], {
             RGBColor[
             0.32027104186109334`, 0.44750725418492177`, 0.9417864377717282]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 70}], {
             RGBColor[
             0.3905304054854526, 0.5126795414277583, 0.946105229998423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 84}], {
             RGBColor[
             0.33917246844259935`, 0.4673738519417473, 0.9428628460533902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 131}], {
             RGBColor[
             0.6725225989280954, 0.7384141156269481, 0.9434176348300398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 135}], {
             RGBColor[
             0.42639421235443153`, 0.543173296600759, 0.9485478420662635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 147}], {
             RGBColor[
             0.36455967170552855`, 0.4901849971546218, 0.9444503978069843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 170}], {
             RGBColor[
             0.41427486372531974`, 0.5332457977239594, 0.9476182058810672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 171}], {
             RGBColor[
             0.33071520758331147`, 0.4584847345573265, 0.94238121755885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 265}], {
             RGBColor[
             0.5489961629989109, 0.6415253436383237, 0.9590074785798983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 266}], {
             RGBColor[
             0.3240324125938233, 0.4514606933096996, 0.9420006422705078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 374}], {
             RGBColor[
             0.6223256808678062, 0.4937015612515359, 0.5776861196553552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 385}], {
             RGBColor[
             0.40259235014026146`, 0.5231269916367878, 0.9468738064458684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 391}], {
             RGBColor[
             0.3918392789972914, 0.5138132218778174, 0.9461886302612059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 433}], {
             RGBColor[
             0.3786903513261278, 0.5024242816133764, 0.9453507922171396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 47}], {
             RGBColor[
             0.29713467805682836`, 0.42373472813702806`, 0.9404488914684423]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 54}], {
             RGBColor[
             0.2418645924022372, 0.3715454000885884, 0.9370852027794833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 55}], {
             RGBColor[
             0.4592065728727362, 0.5566708935376079, 0.9531716785074327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 230}], {
             RGBColor[
             0.24563311360971632`, 0.37550635481569394`, 0.9372998144872218]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 242}], {
             RGBColor[
             0.388967916708555, 0.5004809775046933, 0.9470727148974258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 250}], {
             RGBColor[
             0.24968648292629247`, 0.37976670296587367`, 0.9375306478733781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 339}], {
             RGBColor[
             0.2537717560877931, 0.38406058407988963`, 0.9377632981363055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 365}], {
             RGBColor[
             0.22943814711102856`, 0.3584844182053908, 0.9363775351034274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 8}], {
             RGBColor[
             0.263896868402319, 0.39470271909165544`, 0.9383399083038565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 31}], {
             RGBColor[
             0.23998379470269726`, 0.3695685624569103, 0.9369780941328854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[
             0.27836671272926905`, 0.40918284774637104`, 0.9391906219704929]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 203}], {
             RGBColor[
             0.3232870755120939, 0.44809060822577307`, 0.9420529077654972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 221}], {
             RGBColor[
             0.29142367610667946`, 0.42049213316182293`, 0.9400226001310821]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 223}], {
             RGBColor[
             0.6136816228277203, 0.6793481154827916, 0.8989231749888876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 258}], {
             RGBColor[
             0.255258814511969, 0.3856235767686482, 0.9378479839136566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 381}], {
             RGBColor[
             0.33952968804551115`, 0.46215914282477594`, 0.9430878726733483]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 439}], {
             RGBColor[
             0.3129606056713121, 0.43914633907315337`, 0.9413949142385813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 480}], {
             RGBColor[
             0.2913616934372136, 0.4204384468888711, 0.9400186506501927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 29}], {
             RGBColor[
             0.7609457712800052, 0.8136055516719951, 0.9767393379238037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 185}], {
             RGBColor[
             0.46073701656859833`, 0.5664701386210632, 0.9520195755067957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 196}], {
             RGBColor[
             0.5886222953078468, 0.676909122319951, 0.9607576497625985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 318}], {
             RGBColor[
             0.6760567758325431, 0.7467506288085379, 0.9684214287420858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 321}], {
             RGBColor[
             0.5192295192529861, 0.6192131251721983, 0.955670517294394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 335}], {
             RGBColor[
             0.578312514720859, 0.6685391779891118, 0.9599460260688201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 383}], {
             RGBColor[
             0.47101832187979387`, 0.5772764423755368, 0.95260508063444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 479}], {
             RGBColor[
             0.5469114505307167, 0.6430463794777332, 0.9574740192698838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 482}], {
             RGBColor[
             0.47780209034840815`, 0.5833307684581723, 0.9530307981574313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 496}], {
             RGBColor[
             0.47771561126477374`, 0.5832558646224933, 0.9530252877866925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.3344020293434804, 0.4634598766221929, 0.9425508980684593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 23}], {
             RGBColor[
             0.302804340286726, 0.43559693891836465`, 0.9405556312692269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 41}], {
             RGBColor[
             0.35331803124291156`, 0.47984396672158053`, 0.9437562089827273]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 102}], {
             RGBColor[
             0.2983902389163333, 0.4309574385078906, 0.9403042547262608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 186}], {
             RGBColor[
             0.37551910614701256`, 0.4990734219450431, 0.9451708418439768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 193}], {
             RGBColor[
             0.3569200502701031, 0.4829638545601935, 0.9439857264499996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 202}], {
             RGBColor[
             0.3325060913088599, 0.46181771038922104`, 0.9424300905734053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 211}], {
             RGBColor[
             0.3310660518314165, 0.4605704205723482, 0.9423383325312796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 212}], {
             RGBColor[
             0.33464439981624206`, 0.4636698057438049, 0.9425663417006638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 300}], {
             RGBColor[
             0.27295194121695987`, 0.40422017474461935`, 0.9388555813048705]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 414}], {
             RGBColor[
             0.30765187210455036`, 0.4402902349238277, 0.9408464017034299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 485}], {
             RGBColor[
             0.3260125529041813, 0.4561933337978184, 0.9420163280482698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 24}], {
             RGBColor[
             0.4235821125784698, 0.5390306473370438, 0.9488402928647087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 77}], {
             RGBColor[
             0.27768823589739944`, 0.4090823797306565, 0.9391295514489508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 79}], {
             RGBColor[
             0.35794542231634496`, 0.48445606677555153`, 0.9440289436846565]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 80}], {
             RGBColor[
             0.2941765471834865, 0.42641264031165005`, 0.9400685363844229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 81}], {
             RGBColor[
             0.275630711329779, 0.4069197909554951, 0.9390123784686597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 99}], {
             RGBColor[
             0.2999078671072325, 0.4324366209381785, 0.9403949265753522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 156}], {
             RGBColor[
             0.5907453553847892, 0.671647602470778, 0.9642893298861757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 267}], {
             RGBColor[
             0.28912814140780474`, 0.4211064457539949, 0.9397810371439448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 278}], {
             RGBColor[
             0.29483459115121313`, 0.4271042862441281, 0.9401060110148961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 329}], {
             RGBColor[
             0.4146916108732148, 0.5318129375401801, 0.9481404000034902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 406}], {
             RGBColor[
             0.41370709820304363`, 0.5310136658027448, 0.9480628955597057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 413}], {
             RGBColor[
             0.3630044633097531, 0.488837953809248, 0.9443513013032222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 486}], {
             RGBColor[
             0.42183205912896027`, 0.5376098751077224, 0.9487025222465063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 28}], {
             RGBColor[
             0.3720604565880178, 0.4966818000194241, 0.9449283411870129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 49}], {
             RGBColor[
             0.31598818405237883`, 0.44620045999075747`, 0.9414255595085431]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 69}], {
             RGBColor[
             0.291603992110608, 0.4205711282128918, 0.9400369158506385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 142}], {
             RGBColor[
             0.3742329977170633, 0.49856354595031116`, 0.9450667735866529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 173}], {
             RGBColor[
             0.31687575104191146`, 0.4471333491717537, 0.9414761051355593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[
             0.3638603414201825, 0.4895792724108172, 0.9444058370995955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 241}], {
             RGBColor[
             0.47500583781537026`, 0.5817001797577241, 0.9526339614681322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 388}], {
             RGBColor[
             0.43815517074747096`, 0.5517831481283704, 0.9497329419681059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 402}], {
             RGBColor[
             0.43067498213772254`, 0.5457103940363199, 0.9491440741199128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 436}], {
             RGBColor[
             0.31437972266567726`, 0.444509865090992, 0.9413339600120758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 461}], {
             RGBColor[
             0.3484091666364197, 0.47619624141174716`, 0.9434213019053115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 487}], {
             RGBColor[
             0.5854199187647496, 0.6685682420300865, 0.9632441516303916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 31}], {
             RGBColor[
             0.26377361980797775`, 0.3945731770045906, 0.9383328894787387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 40}], {
             RGBColor[
             0.2847649686308191, 0.416636415545783, 0.9395283157402818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 114}], {
             RGBColor[
             0.3068953138344085, 0.4382919518873221, 0.9408473679327221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 115}], {
             RGBColor[
             0.2859032279633337, 0.41783279827406583`, 0.9395931379253648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 162}], {
             RGBColor[
             0.30215653783454954`, 0.43418746229405136`, 0.9405454173163461]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 203}], {
             RGBColor[
             0.3470769006173744, 0.4730952227734534, 0.9434077031113506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 221}], {
             RGBColor[
             0.31521350121195996`, 0.4454967477095033, 0.9413773954769353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 258}], {
             RGBColor[
             0.2790486396172495, 0.4106281913163286, 0.93920277925951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 289}], {
             RGBColor[
             0.3172027582235311, 0.44721974214996163`, 0.9415041491746818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 291}], {
             RGBColor[
             0.34301180857005975`, 0.46957424435953654`, 0.9431486790407155]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 297}], {
             RGBColor[
             0.27417111575331843`, 0.40550160448246253`, 0.938925011491109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 311}], {
             RGBColor[
             0.32811063528267803`, 0.4566675970127528, 0.9421991894554336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 381}], {
             RGBColor[
             0.3633195131507917, 0.4871637573724563, 0.9444426680192016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 419}], {
             RGBColor[
             0.3014929744688417, 0.4336127170583398, 0.9405031356454493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 439}], {
             RGBColor[
             0.3367504307765926, 0.4641509536208337, 0.9427497095844347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 19}], {
             RGBColor[
             0.34868593212942717`, 0.47340705256762017`, 0.9435498403612117]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 26}], {
             RGBColor[
             0.33504108647986813`, 0.4615885730758553, 0.942680402862085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 34}], {
             RGBColor[
             0.27784526678685706`, 0.4093633701733419, 0.9391342489570497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 44}], {
             RGBColor[
             0.2749461902345689, 0.40631625690481715`, 0.9389691508361964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.33486551753193083`, 0.4614365040775039, 0.942669215763972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 117}], {
             RGBColor[
             0.28597615265131177`, 0.4179094467448231, 0.9395972908784627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 139}], {
             RGBColor[
             0.5060067402935333, 0.6005593118152026, 0.956676188012728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 247}], {
             RGBColor[
             0.28151889097480565`, 0.4132245821161023, 0.9393434564199135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 269}], {
             RGBColor[
             0.39070856563323025`, 0.5083899450323107, 0.9466184542789056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 360}], {
             RGBColor[
             0.3415464718523331, 0.46722321091530855`, 0.9430949202655321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 425}], {
             RGBColor[
             0.29806270107361743`, 0.4295597542246523, 0.940324172842701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 466}], {
             RGBColor[
             0.3089663660576176, 0.4390039607996564, 0.9410189447337491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 468}], {
             RGBColor[
             0.2752553410212922, 0.4066411939829553, 0.9389867565161526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 120}], {
             RGBColor[
             0.619689802075183, 0.6984167112358622, 0.9653515548895627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 123}], {
             RGBColor[
             0.41617513577434573`, 0.5348917178623754, 0.9477392895356865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 125}], {
             RGBColor[
             0.38620202019520045`, 0.508930511640312, 0.9458294291151688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 177}], {
             RGBColor[
             0.3434404639159247, 0.46827229410837434`, 0.9432372577259169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 245}], {
             RGBColor[
             0.3614746032577256, 0.48722731798708285`, 0.9442642752823143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 438}], {
             RGBColor[
             0.3479822090272895, 0.47304595618369083`, 0.9434959033910995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 455}], {
             RGBColor[
             0.353491106219022, 0.4788361564164574, 0.9438096269364855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 23}], {
             RGBColor[
             0.33499408346036136`, 0.46408216303743394`, 0.94258461467455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 41}], {
             RGBColor[
             0.38550777441654693`, 0.5083291908406498, 0.9457851923880505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 102}], {
             RGBColor[
             0.33057998208996875`, 0.4594426626269599, 0.942333238131584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 186}], {
             RGBColor[
             0.407708849320648, 0.5275586460641124, 0.9471998252493001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 193}], {
             RGBColor[
             0.3891097934437385, 0.5114490786792627, 0.9460147098553228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 202}], {
             RGBColor[
             0.3646958344824953, 0.4903029345082903, 0.9444590739787286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 211}], {
             RGBColor[
             0.3632557950050519, 0.4890556446914175, 0.9443673159366028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 414}], {
             RGBColor[
             0.33984161527818574`, 0.46877545904289697`, 0.942875385108753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 485}], {
             RGBColor[
             0.35820229607781673`, 0.4846785579168877, 0.944045311453593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 497}], {
             RGBColor[
             0.3395100179659285, 0.4684882461175852, 0.9428542560212361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 198}], {
             RGBColor[
             0.5011778360989418, 0.6016514911601579, 0.9553070520421321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 373}], {
             RGBColor[
             0.5778410132358203, 0.6675315439183703, 0.9603361196831932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 480}], {
             RGBColor[
             0.5128825786917967, 0.6117895508966205, 0.9560528678900513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 154}], {
             RGBColor[
             0.47288232775816164`, 0.5816447973904596, 0.952005757694774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 229}], {
             RGBColor[
             0.6224711719651735, 0.700225160422114, 0.9658052859652166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 244}], {
             RGBColor[
             0.3589332703370611, 0.4853116910804106, 0.9440918884870169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 313}], {
             RGBColor[
             0.3472032460716332, 0.47332776817478417`, 0.9434112460235029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 334}], {
             RGBColor[
             0.4342229829102857, 0.5502593996593155, 0.948962352454503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 338}], {
             RGBColor[
             0.4326124855246124, 0.5489519253295455, 0.9488355682008565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 340}], {
             RGBColor[
             0.38119400979110823`, 0.504592824738209, 0.9455103231206298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 363}], {
             RGBColor[
             0.40186258384242196`, 0.5224949047487197, 0.9468273063826771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 379}], {
             RGBColor[
             0.41187100124824655`, 0.5311636928679597, 0.9474650338896802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 380}], {
             RGBColor[
             0.3423369995537029, 0.4682130345465898, 0.9431341204832734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 390}], {
             RGBColor[
             0.5207328137594756, 0.6204919775661552, 0.9557727232349031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 478}], {
             RGBColor[
             0.3589057430131338, 0.4852878482959883, 0.9440901344702777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 63}], {
             RGBColor[
             0.3825776852967945, 0.5023501270887817, 0.945927277952443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 72}], {
             RGBColor[
             0.41562257319156515`, 0.5335670569967614, 0.9479378493394439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 75}], {
             RGBColor[
             0.41335638044791956`, 0.5316041947443748, 0.9477934495417344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 149}], {
             RGBColor[
             0.7385521496466888, 0.7894986068183087, 0.6956939743940672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 158}], {
             RGBColor[
             0.560647122383751, 0.6541976166729919, 0.9585553416735786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 163}], {
             RGBColor[
             0.3575689206630036, 0.476064329811407, 0.9445030658037004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 182}], {
             RGBColor[
             0.416661770632748, 0.534467157588732, 0.9480040660814699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 187}], {
             RGBColor[
             0.7351308040449069, 0.7903745716883612, 0.9189099903893985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 279}], {
             RGBColor[
             0.533882518994641, 0.6324689059100699, 0.9564483340528152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 322}], {
             RGBColor[
             0.6662866489532128, 0.737036136650177, 0.9689661575088726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 324}], {
             RGBColor[
             0.7158309061822735, 0.7762452131158672, 0.9634233537739373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 441}], {
             RGBColor[
             0.6171478516884412, 0.6984213191834725, 0.9641287574529949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 494}], {
             RGBColor[
             0.47071321551479506`, 0.5811852196004392, 0.9514754150860987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 78}], {
             RGBColor[
             0.46366638136864025`, 0.5695389282188823, 0.9521873231919988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 97}], {
             RGBColor[
             0.7963578966220105, 0.8412829961065864, 0.9607063480560654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 104}], {
             RGBColor[
             0.6256554341861551, 0.706974292785256, 0.9636730341119564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.46587491466995506`, 0.5718602367476633, 0.9523130958962764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 148}], {
             RGBColor[
             0.47005452062173203`, 0.576253267605304, 0.9525511182720573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 153}], {
             RGBColor[
             0.5818145833145869, 0.6713823150398923, 0.9602217217370184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 190}], {
             RGBColor[
             0.5638217801242545, 0.656774946843434, 0.9588052623600656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 323}], {
             RGBColor[
             0.47091622440274333`, 0.5771589729143222, 0.9526001910276094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 356}], {
             RGBColor[
             0.4521885750412614, 0.5574750260338541, 0.9515336791015474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 408}], {
             RGBColor[
             0.46575616261137465`, 0.5717354208047798, 0.9523063331422184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 430}], {
             RGBColor[
             0.5678126041984477, 0.6600148776114396, 0.9591194346500563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 452}], {
             RGBColor[
             0.5399182394793369, 0.6371303487083482, 0.9569894214292887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 39}], {
             RGBColor[
             0.4607707551999842, 0.5674473709269019, 0.9519357710301706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 45}], {
             RGBColor[
             0.2698009694491167, 0.4009083036334672, 0.9386761381241369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 52}], {
             RGBColor[
             0.26967821742896136`, 0.40077928347735636`, 0.9386691475781843]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 56}], {
             RGBColor[
             0.37893557624519053`, 0.501009886018601, 0.9454934059707113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 179}], {
             RGBColor[
             0.39144588637107125`, 0.5111663193618396, 0.9464782634105966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 200}], {
             RGBColor[
             0.3416503229950991, 0.46899656937050926`, 0.9430398997620313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 236}], {
             RGBColor[
             0.6403286397899484, 0.7076083390830032, 0.9070273965836839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 243}], {
             RGBColor[
             0.3012613255339003, 0.433975132580359, 0.9404677588617393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 254}], {
             RGBColor[
             0.5010848650351504, 0.5991710052785408, 0.9557966898502425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 276}], {
             RGBColor[
             0.3439890089579084, 0.4710222216057204, 0.9431889187635627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 283}], {
             RGBColor[
             0.3565398550619287, 0.4818931336771555, 0.9439886475790333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 292}], {
             RGBColor[
             0.5386506541350807, 0.628517685233978, 0.959540896635465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 422}], {
             RGBColor[
             0.43254114148325895`, 0.5445292987820589, 0.9497134324299076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 454}], {
             RGBColor[
             0.33984402704708594`, 0.46743204660741433`, 0.9429248041814686]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 205}], {
             RGBColor[
             0.29469239818877413`, 0.4253144509772647, 0.9401579757364514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 252}], {
             RGBColor[
             0.3436217141108935, 0.4676945651700801, 0.9432757084805137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 282}], {
             RGBColor[
             0.26493693183795275`, 0.3957958917063371, 0.9383991383778798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 293}], {
             RGBColor[
             0.35585126900531266`, 0.47828719094432454`, 0.9440549649042153]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 298}], {
             RGBColor[
             0.2777029551399939, 0.4092137916094091, 0.939126144519292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 418}], {
             RGBColor[
             0.3125942727103033, 0.44082015491343773`, 0.9412986673509571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 432}], {
             RGBColor[
             0.3942468212569999, 0.5095468956514143, 0.947053160091486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 467}], {
             RGBColor[
             0.31266299574381984`, 0.4408796793509496, 0.9413030463218834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 52}], {
             RGBColor[
             0.2734020273678771, 0.40469324382634364`, 0.9388812130453225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 56}], {
             RGBColor[
             0.3826593861841063, 0.5049238463675882, 0.9457054714378494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 65}], {
             RGBColor[
             0.3432253938006836, 0.47104939988097405`, 0.9431150494716489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 88}], {
             RGBColor[
             0.307366162777331, 0.43998993630590255`, 0.9408301309799139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 166}], {
             RGBColor[
             0.3171725881186397, 0.44848376905127524`, 0.9414549877311806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 167}], {
             RGBColor[
             0.3594098577067304, 0.48506756906158355`, 0.9441463092003828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 210}], {
             RGBColor[
             0.31601483273207914`, 0.44748097952591415`, 0.9413812165817118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 227}], {
             RGBColor[
             0.34954820778573636`, 0.4765259035609556, 0.9435179335877316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 243}], {
             RGBColor[
             0.304985135472816, 0.4378890929293463, 0.9406798243288774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 326}], {
             RGBColor[
             0.3652585356664778, 0.49013339994721516`, 0.9445189817881949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 348}], {
             RGBColor[
             0.46880513363883325`, 0.5748608449730328, 0.9524871802397561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 428}], {
             RGBColor[
             0.28561507139749936`, 0.4175299274531925, 0.9395767278352299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 434}], {
             RGBColor[
             0.4577768135202732, 0.5659075578806263, 0.9516189904819553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 469}], {
             RGBColor[
             0.28509598492886035`, 0.4169843346626698, 0.9395471666287605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 474}], {
             RGBColor[
             0.26942010489881163`, 0.40050799084288935`, 0.9386544484514356]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 495}], {
             RGBColor[
             0.27242821481236884`, 0.4036697050872223, 0.9388257558609128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 26}], {
             RGBColor[
             0.4077412713630326, 0.5275867284076468, 0.9472018911531712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 34}], {
             RGBColor[
             0.35054545167002155`, 0.47536152550513333`, 0.9436557372481358]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 44}], {
             RGBColor[
             0.34764637511773344`, 0.4723144122366086, 0.9434906391272825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 139}], {
             RGBColor[
             0.5787069251766979, 0.666557467146994, 0.9611976763038141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 234}], {
             RGBColor[
             0.3745912128722656, 0.4988738139133302, 0.9450895987395852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 247}], {
             RGBColor[
             0.3542190758579702, 0.47922273744789373`, 0.9438649447109996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 269}], {
             RGBColor[
             0.46340875051639474`, 0.5743881003641021, 0.9511399425699918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 360}], {
             RGBColor[
             0.41424665673549754`, 0.5332213662470999, 0.9476164085566182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 393}], {
             RGBColor[
             0.3782812428770084, 0.5020699324371376, 0.9453247241885221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 466}], {
             RGBColor[
             0.3816665509407821, 0.5050021161314479, 0.9455404330248354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 468}], {
             RGBColor[
             0.34795552590445666`, 0.4726393493147467, 0.9435082448072387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 62}], {
             RGBColor[
             0.3316846889272972, 0.4617103394167963, 0.9423556329745613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 194}], {
             RGBColor[
             0.35782092264246834`, 0.48434823141557515`, 0.9440210106755279]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 228}], {
             RGBColor[
             0.6147791193063294, 0.6915630992101252, 0.9662356771177187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 388}], {
             RGBColor[
             0.4321157519697568, 0.5465521071331283, 0.9493481155440383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 490}], {
             RGBColor[
             0.4447808230032092, 0.5568341823530331, 0.9503451563294756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 33}], {
             RGBColor[
             0.6480262427228414, 0.7124809692865914, 0.7934306583404654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 65}], {
             RGBColor[
             0.6896716893155814, 0.749220345006006, 0.796059803917397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 119}], {
             RGBColor[
             0.9738299323697464, 0.9776391382611402, 0.8053039146080803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 164}], {
             RGBColor[
             0.6761627650066122, 0.7375195937478547, 0.7951990272059021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 166}], {
             RGBColor[
             0.6636188836335375, 0.7266547141763071, 0.7943997421769285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 175}], {
             RGBColor[
             0.66942938662869, 0.7316874798263361, 0.7947699822897536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 227}], {
             RGBColor[
             0.6959945033006342, 0.7546968486859875, 0.7964626880334795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 309}], {
             RGBColor[
             0.7135633483793162, 0.7699140992573128, 0.7975821593063734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 320}], {
             RGBColor[
             0.6992248417492563, 0.7574948054886527, 0.7966685223429496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 337}], {
             RGBColor[
             0.6403857476218129, 0.7044503245000413, 0.7929955434475615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 348}], {
             RGBColor[
             0.8152514291537309, 0.8530317900980647, 0.805431934685504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 375}], {
             RGBColor[
             0.6278903931636627, 0.6913169147132946, 0.7922839514963902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 428}], {
             RGBColor[
             0.6320613669123971, 0.6957008725782243, 0.7925214822809779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 489}], {
             RGBColor[
             0.6634440996946841, 0.7265033251133685, 0.7943886050989002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 63}], {
             RGBColor[
             0.42098170351189906`, 0.5335282391571083, 0.9489505829448901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 149}], {
             RGBColor[
             0.7769561678617933, 0.8206767188866353, 0.6987172793865143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 160}], {
             RGBColor[
             0.48291069172220835`, 0.589763125001314, 0.9528016236627901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 165}], {
             RGBColor[
             0.4413717474805062, 0.5537841793071949, 0.950154798867155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 182}], {
             RGBColor[
             0.4550657888478526, 0.5656452696570585, 0.951027371073917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 268}], {
             RGBColor[
             0.4402853960709923, 0.5528432363178835, 0.9500855775159636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 275}], {
             RGBColor[
             0.5778793241727047, 0.6681874943871083, 0.9599119237220402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 282}], {
             RGBColor[
             0.41475846969943575`, 0.5269872258443961, 0.9485961789857197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 285}], {
             RGBColor[
             0.4138475361335231, 0.5260297769100979, 0.9485443026667464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 324}], {
             RGBColor[
             0.754234924397378, 0.8074233251841938, 0.9664466587663844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 353}], {
             RGBColor[
             0.4730504057967398, 0.5812226409250538, 0.9521733349627277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 441}], {
             RGBColor[
             0.6555518699035459, 0.729599431251799, 0.9671520624454419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 481}], {
             RGBColor[
             0.5120223365261726, 0.6147218249921698, 0.9547274204124105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 41}], {
             RGBColor[
             0.3539100853597925, 0.48046625313682156`, 0.943789925588818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 186}], {
             RGBColor[
             0.3761111602638936, 0.49969570836028415`, 0.9452045584500677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 202}], {
             RGBColor[
             0.3330981454257409, 0.462439996804462, 0.9424638071794962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 211}], {
             RGBColor[
             0.3316581059482975, 0.46119270698758924`, 0.9423720491373704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 212}], {
             RGBColor[
             0.33523645393312307`, 0.46429209215904593`, 0.9426000583067546]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 485}], {
             RGBColor[
             0.3266046070210623, 0.45681562021305944`, 0.9420500446543607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 497}], {
             RGBColor[
             0.3079123289091741, 0.440625308413757, 0.9408589892220036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 77}], {
             RGBColor[
             0.3912703468156388, 0.5051848738575647, 0.9469959404367398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 81}], {
             RGBColor[
             0.38921282224801834`, 0.5030222850824033, 0.9468787674564487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 83}], {
             RGBColor[
             0.4603735866850847, 0.5708975730149373, 0.951184613061359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 176}], {
             RGBColor[
             0.4526559136562772, 0.5642129125389095, 0.9506928497604339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 197}], {
             RGBColor[
             0.41668481033969174`, 0.5318970863914001, 0.9484432565371053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 237}], {
             RGBColor[
             0.3924445985581103, 0.5064190868907629, 0.9470628123363238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 267}], {
             RGBColor[
             0.40271025232604407`, 0.5172089398809032, 0.9476474261317338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 270}], {
             RGBColor[
             0.7611703946110941, 0.8116356423468114, 0.926016439903443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 278}], {
             RGBColor[
             0.4084167020694525, 0.5232067803710363, 0.9479724000026851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 329}], {
             RGBColor[
             0.5282737217914542, 0.6279154316670883, 0.9560067889912792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 426}], {
             RGBColor[
             0.5407801161620216, 0.638068686023761, 0.9569913381685624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 448}], {
             RGBColor[
             0.5519060104046958, 0.6471011881857875, 0.9578672093188392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 489}], {
             RGBColor[
             0.43475948217043775`, 0.5487119230866759, 0.9495525049713491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[
             0.38206973779208764`, 0.5053513363172883, 0.9455661237344763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 96}], {
             RGBColor[
             0.332762250083341, 0.45627103918335293`, 0.9426576274033879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 157}], {
             RGBColor[
             0.30332262633149004`, 0.4253281280402032, 0.9409810843827404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.5599163753622991, 0.6520615301566817, 0.959247193385842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 246}], {
             RGBColor[
             0.7055496368179173, 0.7656868534209331, 0.9200237047052479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 288}], {
             RGBColor[
             0.6862110332236939, 0.751464068911214, 0.9617114909643907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 333}], {
             RGBColor[
             0.6215114791777864, 0.3386360525248429, 0.5562822288422777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 343}], {
             RGBColor[
             0.4187029464959161, 0.5370811804579387, 0.9479003593996098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 392}], {
             RGBColor[
             0.34421918657196326`, 0.4683130058446239, 0.9433100829873963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 459}], {
             RGBColor[
             0.4185408489658752, 0.536940779724676, 0.9478900306883328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 465}], {
             RGBColor[
             0.4105105760692759, 0.529985360954893, 0.947378348800253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 492}], {
             RGBColor[
             0.37249450667852646`, 0.4970577523918308, 0.9449559984749647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 34}], {
             RGBColor[
             0.3369006060204625, 0.4635430460133685, 0.9427862997490092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 44}], {
             RGBColor[
             0.3340015294681744, 0.46049593274484374`, 0.9426212016281559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 106}], {
             RGBColor[
             0.39392085676553634`, 0.5156161799175305, 0.9463212665559315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 117}], {
             RGBColor[
             0.3450314918849172, 0.4720891225848497, 0.9432493416704222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 139}], {
             RGBColor[
             0.5650620795271388, 0.6547389876552292, 0.9603282388046875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 215}], {
             RGBColor[
             0.34106435533990886`, 0.4679194105450612, 0.9430234191130366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 224}], {
             RGBColor[
             0.6446770138350606, 0.7175431879343095, 0.9681020585031037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 247}], {
             RGBColor[
             0.34057423020841116`, 0.4674042579561289, 0.942995507211873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 269}], {
             RGBColor[
             0.4497639048668357, 0.5625696208723373, 0.9502705050708651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 351}], {
             RGBColor[
             0.5019900740142015, 0.6049691777482771, 0.9543819404169069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 360}], {
             RGBColor[
             0.4006018110859385, 0.5214028867553351, 0.9467469710574916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 425}], {
             RGBColor[
             0.35711804030722294`, 0.4837394300646789, 0.9439762236346605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 466}], {
             RGBColor[
             0.3680217052912231, 0.493183636639683, 0.9446709955257087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 468}], {
             RGBColor[
             0.33431068025489763`, 0.46082086982298187`, 0.9426388073081121]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 40}], {
             RGBColor[
             0.27202622574763735`, 0.4032471890926106, 0.9388028631783659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 114}], {
             RGBColor[
             0.2941565709512267, 0.42490272543414975`, 0.9401219153708061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 199}], {
             RGBColor[
             0.22056810387061798`, 0.34916144036649555`, 0.935872399262939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 220}], {
             RGBColor[
             0.347111091086442, 0.47076926920370255`, 0.9434961305679785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 277}], {
             RGBColor[
             0.28016644375163113`, 0.41180307433443925`, 0.9392664365513199]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 289}], {
             RGBColor[
             0.30446401534034934`, 0.43383051569678927`, 0.9407786966127658]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 291}], {
             RGBColor[
             0.330273065686878, 0.4561850179063641, 0.9424232264787995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 297}], {
             RGBColor[
             0.26143237287013665`, 0.3921123780292901, 0.9381995589291932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 311}], {
             RGBColor[
             0.31537189239949626`, 0.4432783705595804, 0.9414737368935178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 319}], {
             RGBColor[
             0.3372521812636796, 0.4622299770384415, 0.9428679295519637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 349}], {
             RGBColor[
             0.2850236460671032, 0.41690830193241424`, 0.9395430470375992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 359}], {
             RGBColor[
             0.2784277687647617, 0.40997561668487825`, 0.9391674215829569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 371}], {
             RGBColor[
             0.2877542098077679, 0.4193573220037133, 0.9397139625801306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 419}], {
             RGBColor[
             0.28875423158565994`, 0.4202234906051674, 0.9397776830835334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 488}], {
             RGBColor[
             0.3380327412745858, 0.4629060588878015, 0.9429176661456367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 69}], {
             RGBColor[
             0.3197286791690376, 0.44493131855503, 0.9418289960403174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 142}], {
             RGBColor[
             0.40235768477549283`, 0.5229237362924494, 0.9468588537763318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 173}], {
             RGBColor[
             0.345000438100341, 0.4714935395138919, 0.9432681853252383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 194}], {
             RGBColor[
             0.39198502847861205`, 0.5139394627529554, 0.9461979172892744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 241}], {
             RGBColor[
             0.5031305248737998, 0.6060603700998624, 0.9544260416578111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 417}], {
             RGBColor[
             0.45096788754327355`, 0.5637123912149087, 0.9503196077691156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 461}], {
             RGBColor[
             0.37653385369484926`, 0.5005564317538853, 0.9452133820949904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 493}], {
             RGBColor[
             0.47128051336646537`, 0.580203095931541, 0.9519186920815172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 77}], {
             RGBColor[
             0.5660230078793441, 0.6438534251004678, 0.96316886294675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 172}], {
             RGBColor[
             0.6080898858876229, 0.6861485865007562, 0.9656348025008916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 318}], {
             RGBColor[
             0.8017805501766577, 0.8456153210863011, 0.9807346176907998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 321}], {
             RGBColor[
             0.6449532935971007, 0.7180778174499615, 0.967983706243108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 383}], {
             RGBColor[
             0.5967420962239084, 0.6761411346533, 0.9649182695831542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 479}], {
             RGBColor[
             0.6726352248748313, 0.7419110717554964, 0.9697872082185981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 482}], {
             RGBColor[
             0.6035258646925227, 0.6821954607359355, 0.9653439871061453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 43}], {
             RGBColor[
             0.6666491244509732, 0.731881354105567, 0.913434633797477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 64}], {
             RGBColor[
             0.6265987736344348, 0.6933605351359373, 0.9110229405202315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 110}], {
             RGBColor[
             0.9279921789451124, 0.943843506704203, 0.9354916655380741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 217}], {
             RGBColor[
             0.6624922026284216, 0.7282808373558385, 0.9131697584147656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 290}], {
             RGBColor[
             0.619412134560614, 0.6858069218101166, 0.9106136720566571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 316}], {
             RGBColor[
             0.662671851949086, 0.7284364405679605, 0.9131812055106208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 355}], {
             RGBColor[
             0.6215214775810338, 0.68802397506465, 0.9107337960211767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 378}], {
             RGBColor[
             0.6353565674813205, 0.7025655317452153, 0.9115216839238166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 384}], {
             RGBColor[
             0.9439402477962242, 0.9565600639072829, 0.9370128065821023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[
             0.26085189493119737`, 0.39150225891103785`, 0.9381665015693107]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 114}], {
             RGBColor[
             0.28298224013478673`, 0.4131577952525769, 0.9394855537617509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 162}], {
             RGBColor[
             0.2782434641349278, 0.4090533056593062, 0.9391836031453751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 203}], {
             RGBColor[
             0.3231638269177527, 0.44796106613870823`, 0.9420458889403794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 208}], {
             RGBColor[
             0.3292340581746337, 0.4532187953547245, 0.9424326787083732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 221}], {
             RGBColor[
             0.2913004275123382, 0.4203625910747581, 0.9400155813059643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 223}], {
             RGBColor[
             0.613558374233379, 0.6792185733957268, 0.8989161561637699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 258}], {
             RGBColor[
             0.25513556591762776`, 0.3854940346815834, 0.9378409650885389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 289}], {
             RGBColor[
             0.29328968452390936`, 0.42208558551521647`, 0.9401423350037106]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 297}], {
             RGBColor[
             0.2502580420536967, 0.3803674478477173, 0.9375631973201379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 314}], {
             RGBColor[
             0.32356464630509063`, 0.4483082357462522, 0.94207142879731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 381}], {
             RGBColor[
             0.33940643945116994`, 0.4620296007377111, 0.9430808538482305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 397}], {
             RGBColor[
             0.27207564742799806`, 0.40329913441218523`, 0.9388056776699496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 419}], {
             RGBColor[
             0.27757990076921996`, 0.4084785604235946, 0.9391413214744782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 472}], {
             RGBColor[
             0.40077874914246303`, 0.5122444680814705, 0.947804531714145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 103}], {
             RGBColor[
             0.8674324474196766, 0.8961059309940506, 0.9285281173552573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 155}], {
             RGBColor[
             0.5925710446416804, 0.6780212409834598, 0.9623115988015305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 331}], {
             RGBColor[
             0.5281482425342815, 0.6221011806717597, 0.9582110383861508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 344}], {
             RGBColor[
             0.7576635953639241, 0.8106118262456795, 0.9764804844831692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 403}], {
             RGBColor[
             0.5383364759041063, 0.6310459834516572, 0.9588558200393184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 449}], {
             RGBColor[
             0.5618071771172461, 0.6513751251707354, 0.9603513523662934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 119}], {
             RGBColor[
             0.6273227165473858, 0.6994041620303946, 0.9523556908409458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 159}], {
             RGBColor[
             0.4000445201233397, 0.5190233080351296, 0.9470754194137653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 164}], {
             RGBColor[
             0.3296555491842518, 0.45928461751710903`, 0.9422508034387677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 227}], {
             RGBColor[
             0.34948728747827373`, 0.47646187245524174`, 0.9435144642663451]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 267}], {
             RGBColor[
             0.28488765402793004`, 0.41676536567685, 0.9395353024921504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 270}], {
             RGBColor[
             0.6433477963129801, 0.7111920681427581, 0.9179043162638596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 309}], {
             RGBColor[
             0.3670561325569558, 0.4916791230265671, 0.944633935539239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 443}], {
             RGBColor[
             0.31411849854185725`, 0.4458272051655383, 0.9412607963107087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 489}], {
             RGBColor[
             0.31693688387232366`, 0.4482683488826228, 0.9414403813317658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 234}], {
             RGBColor[
             0.30375054752969555`, 0.4348301315190519, 0.9406740073354232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 269}], {
             RGBColor[
             0.39256808517382463`, 0.5103444179698239, 0.9467243511658298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 332}], {
             RGBColor[
             0.34458340220296524`, 0.4701974979180884, 0.9432758407281283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 360}], {
             RGBColor[
             0.3434059913929275, 0.4691776838528217, 0.9432008171524562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 393}], {
             RGBColor[
             0.3074405775344382, 0.43802625004285933`, 0.9409091327843601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 468}], {
             RGBColor[
             0.27711486056188656`, 0.40859566692046845`, 0.9390926534030768]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 54}], {
             RGBColor[
             0.27858695339168316`, 0.410142929820661, 0.9391764869119675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 67}], {
             RGBColor[
             0.4440272489506498, 0.5539652865708072, 0.9506075525774577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 70}], {
             RGBColor[
             0.3488463170160424, 0.47531521706349744`, 0.9434952791386622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 84}], {
             RGBColor[
             0.29748837997318917`, 0.43000952757748645`, 0.9402528951936295]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 131}], {
             RGBColor[
             0.6308385104586852, 0.7010497912626874, 0.940807683970279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 135}], {
             RGBColor[
             0.38471012388502135`, 0.5058089722364981, 0.9459378912065028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 147}], {
             RGBColor[
             0.32287558323611837`, 0.45282067279036103`, 0.9418404469472235]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 171}], {
             RGBColor[
             0.2890311191139013, 0.42112041019306573`, 0.9397712666990893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 216}], {
             RGBColor[
             0.5478622435862334, 0.635839119533882, 0.960439189608838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 281}], {
             RGBColor[
             0.3291330896301447, 0.45824061031745045`, 0.9422391697213552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 385}], {
             RGBColor[
             0.36090826167085127`, 0.4857626672725269, 0.9442638555861077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 391}], {
             RGBColor[
             0.3501551905278812, 0.47644889751355657`, 0.9435786794014451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 37}], {
             RGBColor[
             0.27446595648986627`, 0.40581150079055667`, 0.9389418022348777]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 58}], {
             RGBColor[
             0.3040362647118404, 0.43243037835304177`, 0.9407891409308997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 141}], {
             RGBColor[
             0.6186065709622078, 0.6848802350846603, 0.9084813810100438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 240}], {
             RGBColor[
             0.32008985508487164`, 0.4463351914572483, 0.9418120615138367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 251}], {
             RGBColor[
             0.2966013552407109, 0.4259906334585649, 0.9403153950738317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 310}], {
             RGBColor[
             0.33830838000131275`, 0.4621151620501824, 0.9429729298115033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 352}], {
             RGBColor[
             0.40886027560323535`, 0.5201464982774955, 0.9483186653696768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 367}], {
             RGBColor[
             0.26869021056410514`, 0.3997408256191391, 0.938612882048856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 382}], {
             RGBColor[
             0.31899225780035384`, 0.4453845078562425, 0.9417421235854344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 399}], {
             RGBColor[
             0.238341301349295, 0.367842197802391, 0.9368845565662602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 412}], {
             RGBColor[
             0.34800858639804993`, 0.4705169932844866, 0.9435910183855476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 416}], {
             RGBColor[
             0.2443499297373468, 0.37415764720727696`, 0.9372267390639907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 429}], {
             RGBColor[
             0.32470483876315415`, 0.45033245836355246`, 0.942106124192947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 58}], {
             RGBColor[
             0.32742946730791833`, 0.4570181174962307, 0.9421213492116044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 118}], {
             RGBColor[
             0.2917160505091514, 0.42394244332395636`, 0.9399241695700487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 141}], {
             RGBColor[
             0.6419997735582859, 0.7094679742278492, 0.9098135892907486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 188}], {
             RGBColor[
             0.28372421718276836`, 0.41554251978642864`, 0.9394690464849691]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 240}], {
             RGBColor[
             0.34348305768094956`, 0.4709229306004373, 0.9431442697945414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 304}], {
             RGBColor[
             0.569153967182074, 0.6530071481195294, 0.9624589795253691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 310}], {
             RGBColor[
             0.3617015825973907, 0.48670290119337134`, 0.944305138092208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 429}], {
             RGBColor[
             0.34809804135923206`, 0.4749201975067414, 0.9434383324736517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 47}], {
             RGBColor[
             0.3719545208188811, 0.4965900437806844, 0.9449215910534787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 73}], {
             RGBColor[
             0.3354755136148102, 0.46415133060692865`, 0.9426280264833675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 93}], {
             RGBColor[
             0.3517913401922539, 0.479125710152825, 0.9436368110135507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 108}], {
             RGBColor[
             0.41646587603568075`, 0.5349182563493213, 0.9478200624726942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 163}], {
             RGBColor[
             0.3009883890398287, 0.4279031760686325, 0.940664035757951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 189}], {
             RGBColor[
             0.3520104730929094, 0.47931551205743306`, 0.9436507739682087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 266}], {
             RGBColor[
             0.3204458058970199, 0.4483541548570226, 0.9417721068632994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 364}], {
             RGBColor[
             0.38824122235628583`, 0.5106967660589634, 0.9459593652736775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 437}], {
             RGBColor[
             0.3754956912603493, 0.4996572276326826, 0.945147231302675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 45}], {
             RGBColor[
             0.43637847701152616`, 0.5418095399910703, 0.9505466668724796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 100}], {
             RGBColor[
             0.47737379083590714`, 0.5831735872903883, 0.9529444363824697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 127}], {
             RGBColor[
             0.5749865783649978, 0.6658390330236983, 0.9596841961755804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 179}], {
             RGBColor[
             0.5580233939334807, 0.6520675557194426, 0.9583487921589393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 200}], {
             RGBColor[
             0.5082278305575085, 0.6098978057281124, 0.954910428510374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 213}], {
             RGBColor[
             0.4443491815566465, 0.5501872558398487, 0.9510005867047235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 236}], {
             RGBColor[
             0.8069061473523578, 0.8485095754406062, 0.9188979253320266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 243}], {
             RGBColor[
             0.4678388330963097, 0.574876368937962, 0.9523382876100821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 254}], {
             RGBColor[
             0.6676623725975598, 0.7400722416361438, 0.9676672185985853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 276}], {
             RGBColor[
             0.5105665165203179, 0.6119234579633235, 0.9550594475119054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 283}], {
             RGBColor[
             0.5231173626243382, 0.6227943700347586, 0.9558591763273762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 315}], {
             RGBColor[
             0.531385348680899, 0.6299556839958895, 0.9563860050878072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 325}], {
             RGBColor[
             0.7504626700078774, 0.8051896361705033, 0.9758050276650219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 368}], {
             RGBColor[
             0.43490818059233244`, 0.5402641652323203, 0.9504629356665152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 401}], {
             RGBColor[
             0.4800262857421334, 0.585471045059891, 0.9531134510123853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 450}], {
             RGBColor[
             0.5761713144406806, 0.6668008551416895, 0.9597774629392894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 454}], {
             RGBColor[
             0.5064215346094953, 0.6083332829650174, 0.9547953329298114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 471}], {
             RGBColor[
             0.5174741418003165, 0.6179064957935168, 0.9554995952865737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 475}], {
             RGBColor[
             0.4902317186703556, 0.5943104781223436, 0.9537637321742616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 114}], {
             RGBColor[
             0.30397358895762805`, 0.4352210337937693, 0.940680980023294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 199}], {
             RGBColor[
             0.23038512187701934`, 0.3594797487261151, 0.936431463915427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 208}], {
             RGBColor[
             0.35022540699747506`, 0.47528203389591683`, 0.9436281049699162]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 220}], {
             RGBColor[
             0.35692810909284334`, 0.4810875775633221, 0.9440551952204664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 289}], {
             RGBColor[
             0.3142810333467507, 0.4441488240564089, 0.9413377612652538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 291}], {
             RGBColor[
             0.3400900836932793, 0.4665033262659837, 0.9429822911312875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 297}], {
             RGBColor[
             0.27124939087653804`, 0.40243068638890966`, 0.9387586235816809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 314}], {
             RGBColor[
             0.344555995127932, 0.47037147428744464`, 0.943266855058853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 349}], {
             RGBColor[
             0.2948406640735045, 0.42722661029203385`, 0.9401021116900872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 359}], {
             RGBColor[
             0.2882447867711631, 0.4202939250444978, 0.9397264862354449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 371}], {
             RGBColor[
             0.2975712278141692, 0.4296756303633329, 0.9402730272326185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 397}], {
             RGBColor[
             0.2930669962508394, 0.42536237295337764`, 0.9400011039314928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 419}], {
             RGBColor[
             0.29857124959206127`, 0.43054179896478695`, 0.9403367477360213]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 472}], {
             RGBColor[
             0.4217700979653044, 0.5343077066226629, 0.9489999579756883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 102}], {
             RGBColor[
             0.34949598398939996`, 0.4758267527263475, 0.943538549045852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 186}], {
             RGBColor[
             0.42662485122007915`, 0.5439427361635001, 0.9484051361635681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 191}], {
             RGBColor[
             0.35974153247920354`, 0.4860117671234979, 0.9441433902359961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 202}], {
             RGBColor[
             0.38361183638192653`, 0.5066870246076779, 0.9456643848929966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 212}], {
             RGBColor[
             0.38575014488930864`, 0.5085391199622618, 0.9458006360202551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 295}], {
             RGBColor[
             0.3579233669422497, 0.48443696351904547`, 0.944027538335722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 300}], {
             RGBColor[
             0.3240576862900265, 0.44908948896307627`, 0.9420898756244618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 389}], {
             RGBColor[
             0.6956036055985274, 0.7567579529301007, 0.9078433604521918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 451}], {
             RGBColor[
             0.3969219012438831, 0.5182155338077932, 0.9465124904563722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 456}], {
             RGBColor[
             0.29268253531169275`, 0.416112215985379, 0.9403031071916219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 485}], {
             RGBColor[
             0.37711829797724794`, 0.5010626480162753, 0.9452506223678611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 85}], {
             RGBColor[
             0.5190277292398966, 0.6175691224947271, 0.9562510281043145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 95}], {
             RGBColor[
             0.6726064062458932, 0.7377049203940131, 0.9320132791413898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[
             0.6615373117402035, 0.7294496078356485, 0.9507503688573085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 137}], {
             RGBColor[
             0.37040348074719415`, 0.49524661082812993`, 0.9448227601516417]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 145}], {
             RGBColor[
             0.6621475190248798, 0.7299046994294375, 0.9497174470919001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 174}], {
             RGBColor[
             0.34674371649555236`, 0.4747537122076859, 0.9433151808950352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 248}], {
             RGBColor[
             0.32429416989991977`, 0.45292149181530483`, 0.9419721355926454]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 286}], {
             RGBColor[
             0.36654431437000984`, 0.49190399487955483`, 0.9445768574826144]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 294}], {
             RGBColor[
             0.35268547990861054`, 0.4799001690343644, 0.9436937848056202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 346}], {
             RGBColor[
             0.6051820391637084, 0.6850732808525608, 0.9647850752872021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 358}], {
             RGBColor[
             0.6774297306327512, 0.7404711832363542, 0.8866363570721906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 407}], {
             RGBColor[
             0.3310019262592845, 0.4599717690453142, 0.942354132394075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 411}], {
             RGBColor[
             0.34664548588055627`, 0.4746686297861905, 0.9433089217271096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 430}], {
             RGBColor[
             0.4329920193166406, 0.5481814893405019, 0.9491634554512994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 110}], {
             RGBColor[
             0.6087518442352111, 0.6872919178240376, 0.9654145905147357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 217}], {
             RGBColor[
             0.34325186791852014`, 0.4717292484756731, 0.9430926833914272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 290}], {
             RGBColor[
             0.3001717998507125, 0.42925533292995127`, 0.9405365970333186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 316}], {
             RGBColor[
             0.3434315172391845, 0.47188485168779515`, 0.9431041304872823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 340}], {
             RGBColor[
             0.3522042826354822, 0.4794833801420587, 0.9436631233408825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 355}], {
             RGBColor[
             0.30228114287113245`, 0.4314723861844845, 0.9406567209978383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 362}], {
             RGBColor[
             0.5207687910550486, 0.6181538602445396, 0.9567527439306336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 378}], {
             RGBColor[
             0.3161162327714191, 0.44601394286504986`, 0.9414446089004782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 384}], {
             RGBColor[
             0.6246999130863229, 0.7000084750271175, 0.9669357315587639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 57}], {
             RGBColor[
             0.2979486779322681, 0.4292687648134481, 0.9403239458085727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 106}], {
             RGBColor[
             0.3338259605202371, 0.46034386374649233`, 0.9426100145300428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 117}], {
             RGBColor[
             0.28493659563961804`, 0.41681680641381147`, 0.9395380896445336]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 139}], {
             RGBColor[
             0.5049671832818395, 0.599466671484191, 0.9566169867787988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 140}], {
             RGBColor[
             0.3393709100045901, 0.4651466202925743, 0.9429633338079795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 247}], {
             RGBColor[
             0.2804793339631119, 0.4121319417850907, 0.9392842551859842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 255}], {
             RGBColor[
             0.6107390079320196, 0.6828215100541717, 0.9562710513020449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 269}], {
             RGBColor[
             0.38966900862153653`, 0.5072973047012992, 0.9465592530449765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 360}], {
             RGBColor[
             0.34050691484063933`, 0.46613057058429697`, 0.9430357190316029]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 369}], {
             RGBColor[
             0.3306461618420712, 0.4575896819527936, 0.9424074005700556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 370}], {
             RGBColor[
             0.27143548841563203`, 0.4026262867017629, 0.9387692215612258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 425}], {
             RGBColor[
             0.2970231440619237, 0.4284671138936408, 0.9402649716087719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 466}], {
             RGBColor[
             0.30792680904592384`, 0.4379113204686448, 0.94095974349982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 468}], {
             RGBColor[
             0.27421578400959845`, 0.4055485536519437, 0.9389275552822234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 52}], {
             RGBColor[
             0.24528593924050335`, 0.37514145254152476`, 0.9372800434204935]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 56}], {
             RGBColor[
             0.35454329805673246`, 0.47537205508276936`, 0.9441043018130204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 179}], {
             RGBColor[
             0.36705360818261323`, 0.485528488426008, 0.9450891592529057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 236}], {
             RGBColor[
             0.6159363616014903, 0.6819705081471716, 0.9056382924259929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 243}], {
             RGBColor[
             0.27686904734544227`, 0.4083373016445274, 0.9390786547040484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 254}], {
             RGBColor[
             0.4766925868466923, 0.5735331743427092, 0.9544075856925516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 276}], {
             RGBColor[
             0.3195967307694504, 0.4453843906698888, 0.9417998146058718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 283}], {
             RGBColor[
             0.33214757687347063`, 0.4562553027413239, 0.9425995434213426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 292}], {
             RGBColor[
             0.5142583759466226, 0.6028798542981464, 0.9581517924777743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 386}], {
             RGBColor[
             0.2587040972919885, 0.3892447874139937, 0.9380441876711396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 422}], {
             RGBColor[
             0.4081488632948009, 0.5188914678462273, 0.9483243282722167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 53}], {
             RGBColor[
             0.5181341679935348, 0.6191444260569302, 0.9553575650576043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 68}], {
             RGBColor[
             0.47039555375786574`, 0.5803880684203508, 0.9515994064726665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 90}], {
             RGBColor[
             0.3908112011066381, 0.5129227524816308, 0.9461231220471069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 205}], {
             RGBColor[
             0.38059981901107254`, 0.5040781665494392, 0.9454724618095482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 257}], {
             RGBColor[
             0.5321845627405477, 0.6305511694756254, 0.9564636636003809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 272}], {
             RGBColor[
             0.38631394864942037`, 0.5090274584416696, 0.9458365610972972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 293}], {
             RGBColor[
             0.44175868982761113`, 0.557050906516499, 0.9493694509773121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 298}], {
             RGBColor[
             0.36361037596229234`, 0.48797750718158356`, 0.9444406305923888]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 306}], {
             RGBColor[
             0.40212379227867406`, 0.5227211503674836, 0.9468439503532575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 317}], {
             RGBColor[
             0.3612088554462101, 0.485453356853986, 0.9443038675517291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 357}], {
             RGBColor[
             0.5421857269386052, 0.6385395141833967, 0.9573405921218765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 418}], {
             RGBColor[
             0.3985016935326018, 0.5195838704856122, 0.9466131534240539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 420}], {
             RGBColor[
             0.393328378659751, 0.5151030051611147, 0.9462835143749386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 55}], {
             RGBColor[
             0.5346642989897243, 0.6300787116823597, 0.9576850234557874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 189}], {
             RGBColor[
             0.35264835644784487`, 0.4798680145585285, 0.9436914193315271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 230}], {
             RGBColor[
             0.3210908397267045, 0.4489141729604458, 0.9418131594355765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 242}], {
             RGBColor[
             0.4644256428255432, 0.5738887956494452, 0.9515860598457807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 339}], {
             RGBColor[
             0.3292294822047813, 0.45746840222464147`, 0.9422766430846604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 364}], {
             RGBColor[
             0.3888791057112213, 0.5112492685600589, 0.9460000106369959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 365}], {
             RGBColor[
             0.30489587322801676`, 0.4318922363501426, 0.9408908800517821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 374}], {
             RGBColor[
             0.6193769575259382, 0.49114752529995437`, 0.577498229611465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 437}], {
             RGBColor[
             0.37613357461528474`, 0.5002097301337781, 0.9451878766659934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 78}], {
             RGBColor[
             0.42404354321258764`, 0.5373713232152815, 0.9490680682291157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 85}], {
             RGBColor[
             0.6142254759656509, 0.6972349057620639, 0.9630877523401884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 95}], {
             RGBColor[
             0.7678041529716475, 0.81737070366135, 0.9388500033772635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 137}], {
             RGBColor[
             0.4656012274729486, 0.5749123940954668, 0.9516594843875156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 145}], {
             RGBColor[
             0.7573452657506341, 0.8095704826967745, 0.956554171327774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 183}], {
             RGBColor[
             0.4668142587044891, 0.5759630607795048, 0.9517367776649479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 346}], {
             RGBColor[
             0.7003797858894629, 0.7647390641198978, 0.971621799523076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 358}], {
             RGBColor[
             0.7726274773585057, 0.8201369665036911, 0.8934730813080645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 404}], {
             RGBColor[
             0.5433125902726523, 0.6401246625934294, 0.9571907038073095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 407}], {
             RGBColor[
             0.4261996729850389, 0.5396375523126512, 0.9491908566299487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 408}], {
             RGBColor[
             0.426133324455322, 0.539567815801179, 0.9491870781793352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 71}], {
             RGBColor[
             0.3104790470352997, 0.4414287224038411, 0.9410745221693535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 76}], {
             RGBColor[
             0.31323805790188597`, 0.44381843894455997`, 0.9412503239020749]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 238}], {
             RGBColor[
             0.34726761603958484`, 0.47329313182811134`, 0.9434186572554522]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 328}], {
             RGBColor[
             0.25649169516078396`, 0.38691941249970074`, 0.9379181946427231]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 402}], {
             RGBColor[
             0.4027273966605131, 0.5195892443497916, 0.9474333726311219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 431}], {
             RGBColor[
             0.33275687623569783`, 0.4607246583409732, 0.9424940457464919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 436}], {
             RGBColor[
             0.28643213718846783`, 0.4183887154044636, 0.9396232585232851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 459}], {
             RGBColor[
             0.3497091690756735, 0.47540788235194764`, 0.9435742308559312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 462}], {
             RGBColor[
             0.5317428521035454, 0.6222910937578758, 0.9589838186343871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 487}], {
             RGBColor[
             0.5574723332875402, 0.6424470923435581, 0.9615334501416007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 57}], {
             RGBColor[
             0.31120899929088863`, 0.4432062033142921, 0.9410791014930586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 92}], {
             RGBColor[
             0.4630801302491392, 0.5700678726231747, 0.9520497000662782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 106}], {
             RGBColor[
             0.3470862818788577, 0.47428130224733633`, 0.9433651702145287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 117}], {
             RGBColor[
             0.2981969169982386, 0.4307542449146555, 0.9402932453290195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 139}], {
             RGBColor[
             0.5182275046404602, 0.6134041099850349, 0.9573721424632848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 140}], {
             RGBColor[
             0.3526312313632107, 0.4790840587934183, 0.9437184894924654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 169}], {
             RGBColor[
             0.2882810331301496, 0.4203320222659445, 0.9397285504119675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 204}], {
             RGBColor[
             0.37579066711990616`, 0.4991435980187812, 0.9451941882597972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 219}], {
             RGBColor[
             0.359809458112534, 0.4853014780155154, 0.9441758797534756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 244}], {
             RGBColor[
             0.3064527862809573, 0.4390866106593063, 0.9407760398058198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 255}], {
             RGBColor[
             0.6239993292906403, 0.6967589485550157, 0.9570262069865308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 274}], {
             RGBColor[
             0.40294335112475654`, 0.5212461261989743, 0.9473155125253263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 334}], {
             RGBColor[
             0.38174249885418193`, 0.5040343192382112, 0.945646503773306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 338}], {
             RGBColor[
             0.3801320014685086, 0.5027268449084412, 0.9455197195196594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 340}], {
             RGBColor[
             0.32871352573500445`, 0.4583677443171047, 0.9421944744394328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 361}], {
             RGBColor[
             0.3924171953187782, 0.512700518717766, 0.9464868549817005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 363}], {
             RGBColor[
             0.3493820997863182, 0.4762698243276154, 0.94351145770148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 369}], {
             RGBColor[
             0.3439064832006917, 0.4715271204536376, 0.9431625562545416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 370}], {
             RGBColor[
             0.2846958097742527, 0.4165637252026069, 0.9395243772457118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 379}], {
             RGBColor[
             0.35939051719214277`, 0.4849386124468554, 0.9441491852084831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[
             0.3023334705061957, 0.43415030442392344`, 0.9405636630814469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 113}], {
             RGBColor[
             0.2776399686734581, 0.4091475888395073, 0.939122557533203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 127}], {
             RGBColor[
             0.40412608045337106`, 0.5204361022517954, 0.947569757462966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 130}], {
             RGBColor[
             0.624640173842091, 0.653299096905275, 0.6264384669489388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 143}], {
             RGBColor[
             0.5624115388382291, 0.6460793610659632, 0.9620509310059979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 179}], {
             RGBColor[
             0.38716289602185405`, 0.5066646249475397, 0.9462343534463251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 214}], {
             RGBColor[
             0.4112637453136858, 0.5262307801335364, 0.9481316605868979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 302}], {
             RGBColor[
             0.3091305628069395, 0.4400376041430354, 0.9409967677924176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 308}], {
             RGBColor[
             0.3653753373948234, 0.48875400094649246`, 0.9445806350938561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 315}], {
             RGBColor[
             0.3605248507692724, 0.48455275322398655`, 0.9442715663751929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 325}], {
             RGBColor[
             0.5796021720962505, 0.6597867053986004, 0.9636905889524076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 347}], {
             RGBColor[
             0.3090922913355968, 0.44000445531813837`, 0.9409943291681057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 386}], {
             RGBColor[
             0.2788133851312293, 0.4103809239355254, 0.9391893818645589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 421}], {
             RGBColor[
             0.3301071903222463, 0.45820650458083956`, 0.9423333799487894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 423}], {
             RGBColor[
             0.325550909574111, 0.45426008320213374`, 0.9420430577684791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 477}], {
             RGBColor[
             0.27877607364453527`, 0.4103417071973251, 0.9391872570305891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 56}], {
             RGBColor[
             0.35442054603657713`, 0.47524303492665854`, 0.9440973112670679]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 88}], {
             RGBColor[
             0.2791273226298019, 0.41030912486497284`, 0.9392219708091323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 166}], {
             RGBColor[
             0.2889337479711106, 0.4188029576103455, 0.9398468275603991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 210}], {
             RGBColor[
             0.28777599258455, 0.41780016808498444`, 0.9397730564109303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 227}], {
             RGBColor[
             0.3213093676382073, 0.4468450921200259, 0.9419097734169501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 236}], {
             RGBColor[
             0.615813609581335, 0.6818414879910608, 0.9056313018800405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 243}], {
             RGBColor[
             0.27674629532528694`, 0.4082082814884166, 0.9390716641580958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 276}], {
             RGBColor[
             0.31947397874929506`, 0.44525537051377795`, 0.9417928240599194]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 326}], {
             RGBColor[
             0.33701969551894867`, 0.46045258850628545`, 0.9429108216174135]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 428}], {
             RGBColor[
             0.2573762312499702, 0.3878491160122628, 0.9379685676644485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 469}], {
             RGBColor[
             0.2568571447813312, 0.3873035232217401, 0.9379390064579791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 495}], {
             RGBColor[
             0.24418937466483973`, 0.37398889364629256`, 0.9372175956901314]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 90}], {
             RGBColor[
             0.47548786603803767`, 0.5822063427685389, 0.9526401804076441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 178}], {
             RGBColor[
             0.4341043152419187, 0.5423541535717342, 0.9501500037085199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 257}], {
             RGBColor[
             0.6168612276719473, 0.6998347597625335, 0.9629807219609181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 272}], {
             RGBColor[
             0.47099061358081995`, 0.5783110487285777, 0.9523536194578344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[
             0.5264353547590107, 0.626334496803407, 0.9558865093378492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 298}], {
             RGBColor[
             0.4482870408936919, 0.5572610974684917, 0.950957688952926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 306}], {
             RGBColor[
             0.48680045721007364`, 0.5920047406543918, 0.9533610087137947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 317}], {
             RGBColor[
             0.4458855203776097, 0.554736947140894, 0.9508209259122663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 357}], {
             RGBColor[
             0.6268623918700049, 0.7078231044703047, 0.9638576504824137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 418}], {
             RGBColor[
             0.48317835846400137`, 0.5888674607725203, 0.9531302117845911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 420}], {
             RGBColor[
             0.4780050435911506, 0.5843865954480228, 0.9528005727354758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 432}], {
             RGBColor[
             0.5648309070106979, 0.6575942015104969, 0.95888470452512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 55}], {
             RGBColor[
             0.4793942133351332, 0.5778893836339201, 0.9543213347668285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 70}], {
             RGBColor[
             0.3323115964889935, 0.45793617742773707`, 0.9425536512655737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 84}], {
             RGBColor[
             0.28095365944614026`, 0.4126304879417261, 0.939311267320541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 131}], {
             RGBColor[
             0.6143037899316364, 0.6836707516269269, 0.9398660560971905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 135}], {
             RGBColor[
             0.3681754033579724, 0.48842993260073775`, 0.9449962633334144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 147}], {
             RGBColor[
             0.30634086270906946`, 0.43544163315460066`, 0.940898819074135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 230}], {
             RGBColor[
             0.26582075407211336`, 0.3967248449120061, 0.9384494707466176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 242}], {
             RGBColor[
             0.4091555571709521, 0.5216994676010055, 0.9482223711568216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 365}], {
             RGBColor[
             0.2496257875734256, 0.37970290830170295`, 0.9375271913628231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 374}], {
             RGBColor[
             0.5641068718713471, 0.43895819725151475`, 0.574134540922506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 385}], {
             RGBColor[
             0.34437354114380236`, 0.46838362763676655`, 0.9433222277130192]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 391}], {
             RGBColor[
             0.3336204700008323, 0.4590698578777962, 0.9426370515283566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 230}], {
             RGBColor[
             0.4831627345426124, 0.5818503383610256, 0.9545359464745669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 242}], {
             RGBColor[
             0.626497537641451, 0.706824961050025, 0.964308846884771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 250}], {
             RGBColor[
             0.4872161038591885, 0.5861106865112053, 0.9547667798607233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 339}], {
             RGBColor[
             0.49130137702068916`, 0.5904045676252213, 0.9549994301236507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 365}], {
             RGBColor[
             0.4669677680439246, 0.5648284017507225, 0.9536136670907724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 88}], {
             RGBColor[
             0.388384681446031, 0.5105397274062174, 0.9460462292016593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 164}], {
             RGBColor[
             0.4107349881604144, 0.5298984397231378, 0.9474703709818996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 166}], {
             RGBColor[
             0.3981911067873397, 0.5190335601515901, 0.946671085952926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 210}], {
             RGBColor[
             0.39703335140077917`, 0.518030770626229, 0.9465973148034572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 227}], {
             RGBColor[
             0.4305667264544364, 0.5470756946612705, 0.948734031809477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 236}], {
             RGBColor[
             0.7250709683975642, 0.7820720905323054, 0.9124555602725675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 243}], {
             RGBColor[
             0.38600365414151605`, 0.5084388840296612, 0.9458959225506228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 276}], {
             RGBColor[
             0.4287313375655242, 0.5454859730550226, 0.9486170824524462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 326}], {
             RGBColor[
             0.44627705433517784`, 0.5606831910475301, 0.9497350800099404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 428}], {
             RGBColor[
             0.3666335900661994, 0.4880797185535074, 0.9447928260569753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 495}], {
             RGBColor[
             0.35344673348106886`, 0.47421949618753717`, 0.9440418540826583]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 92}], {
             RGBColor[
             0.47386185359991145`, 0.5801755823619732, 0.9527085405880977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 106}], {
             RGBColor[
             0.35786800522963, 0.4843890119861349, 0.9440240107363483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 139}], {
             RGBColor[
             0.5290092279912324, 0.6235118197238335, 0.9580309829851044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 140}], {
             RGBColor[
             0.36341295471398294`, 0.48919176853221685`, 0.944377330014285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 169}], {
             RGBColor[
             0.29906275648092184`, 0.43043973200474306`, 0.940387390933787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 175}], {
             RGBColor[
             0.3331580186769195, 0.46298646359421286`, 0.9424495122433928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 204}], {
             RGBColor[
             0.3865723904706785, 0.5092513077575798, 0.9458530287816167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 219}], {
             RGBColor[
             0.3705911814633063, 0.4954091877543139, 0.9448347202752951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 255}], {
             RGBColor[
             0.6347810526414126, 0.7068666582938143, 0.9576850475083505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 274}], {
             RGBColor[
             0.41372507447552886`, 0.5313538359377729, 0.947974353047146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 334}], {
             RGBColor[
             0.3925242222049542, 0.5141420289770098, 0.9463053442951256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 337}], {
             RGBColor[
             0.30411437967004246`, 0.43574930826791813`, 0.9406750734012006]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 361}], {
             RGBColor[
             0.4031989186695505, 0.5228082284565645, 0.9471456955035201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 363}], {
             RGBColor[
             0.36016382313709044`, 0.48637753406641393`, 0.9441702982232997]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 369}], {
             RGBColor[
             0.35468820655146405`, 0.48163483019243614`, 0.9438213967763611]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 370}], {
             RGBColor[
             0.29547753312502495`, 0.42667143494140547`, 0.9401832177675313]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 466}], {
             RGBColor[
             0.33196885375531676`, 0.4619564687082873, 0.9423737397061256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 118}], {
             RGBColor[
             0.3212863587311255, 0.4505613208864414, 0.9417715082660707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 141}], {
             RGBColor[
             0.6715700817802599, 0.7360868517903343, 0.9116609279867707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 188}], {
             RGBColor[
             0.31329452540474245`, 0.4421613973489137, 0.9413163851809911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 220}], {
             RGBColor[
             0.39450637498077024`, 0.516123326366565, 0.9463585752588528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 240}], {
             RGBColor[
             0.3730533659029237, 0.49754180816292237`, 0.9449916084905634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 304}], {
             RGBColor[
             0.5987242754040482, 0.6796260256820145, 0.9643063182213911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 310}], {
             RGBColor[
             0.3912718908193648, 0.5133217787558564, 0.94615247678823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 371}], {
             RGBColor[
             0.3351494937020961, 0.4647113791665757, 0.9425764072710048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 382}], {
             RGBColor[
             0.3719557686184059, 0.49659112456191656`, 0.944921670562161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 429}], {
             RGBColor[
             0.3776683495812062, 0.5015390750692266, 0.9452856711696738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 74}], {
             RGBColor[
             0.6835636166774264, 0.7496805220387566, 0.9689788350147674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 82}], {
             RGBColor[
             0.6287680422693919, 0.702219349592166, 0.9654873094673114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 105}], {
             RGBColor[
             0.643251978161265, 0.7147646068779214, 0.9664102130547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 153}], {
             RGBColor[
             0.7332866340632012, 0.7907115596197147, 0.9727098440402808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 195}], {
             RGBColor[
             0.962308147580943, 0.9710490003182499, 0.9325177220193863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 263}], {
             RGBColor[
             0.7369337722499558, 0.7936724707014251, 0.9729969601182495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 323}], {
             RGBColor[
             0.6223882751513576, 0.6964882174941445, 0.9650883133308719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 342}], {
             RGBColor[
             0.6344412907017315, 0.7071332322385013, 0.9658488038407635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 395}], {
             RGBColor[
             0.6482297512766131, 0.7190761037602846, 0.9667273923559381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 447}], {
             RGBColor[
             0.7086563891374849, 0.770715617209129, 0.9707708609361685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 453}], {
             RGBColor[
             0.9658169812361423, 0.9708616935117069, 0.7552801746626651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 463}], {
             RGBColor[
             0.679848178667379, 0.7464623963777977, 0.9687420905902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 116}], {
             RGBColor[
             0.5719623755150469, 0.6528386290587519, 0.9630916233944142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 118}], {
             RGBColor[
             0.28222469321247945`, 0.41396642501834396`, 0.9393836508132081]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 133}], {
             RGBColor[
             0.34854914222152356`, 0.47355583673594603`, 0.9435313383589297]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 151}], {
             RGBColor[
             0.306485477447082, 0.43712240448958883`, 0.9408510788349405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 188}], {
             RGBColor[
             0.27423285988609647`, 0.40556650148081624`, 0.9389285277281285]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 192}], {
             RGBColor[
             0.3087839728862837, 0.43911324571328547`, 0.9409975369318467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 249}], {
             RGBColor[
             0.3867256771566088, 0.5055022106587524, 0.9462734340360102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 260}], {
             RGBColor[
             0.2885000621273134, 0.42056223562920414`, 0.9397410237893316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 280}], {
             RGBColor[
             0.4605044353096089, 0.5653991302225361, 0.9520815681383105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 310}], {
             RGBColor[
             0.35221022530071877`, 0.476726882887759, 0.9437646193353673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 327}], {
             RGBColor[
             0.2904385741487021, 0.4225997346724447, 0.9398514191811781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 483}], {
             RGBColor[
             0.3837861280816639, 0.5031157522945354, 0.9460420219649075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 64}], {
             RGBColor[
             0.33970332026966565`, 0.4648244567759196, 0.9430068527347493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 91}], {
             RGBColor[
             0.7025306481104636, 0.7593585658722024, 0.7114479037685224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 172}], {
             RGBColor[
             0.3708043892912313, 0.49559385765872555`, 0.9448483056895582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 303}], {
             RGBColor[
             0.4915940699216152, 0.597018033238112, 0.9534284720112275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 362}], {
             RGBColor[
             0.5531136724001808, 0.6461693707646872, 0.9588137311684899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 384}], {
             RGBColor[
             0.657044794431455, 0.7280239855472652, 0.9689967187966202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 435}], {
             RGBColor[
             0.33637704521518685`, 0.4613283307956431, 0.9428174262911797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 473}], {
             RGBColor[
             0.3665731797729712, 0.4919289966407826, 0.9445786967605665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 132}], {
             RGBColor[
             0.4384597406884069, 0.5516930893632621, 0.9498501220037253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 209}], {
             RGBColor[
             0.6593404493358554, 0.7252614954336658, 0.9023300661177818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 233}], {
             RGBColor[
             0.2881270786100112, 0.4180652928292059, 0.9397968541232865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 75}], {
             RGBColor[
             0.31145636503441876`, 0.4415944730680186, 0.9411617217125183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 149}], {
             RGBColor[
             0.636652134233188, 0.6994888851419525, 0.689062246564851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 158}], {
             RGBColor[
             0.4587471069702503, 0.5641878949966357, 0.9519236138443625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 165}], {
             RGBColor[
             0.30106771385190084`, 0.43259634556251214`, 0.9404997660454918]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 182}], {
             RGBColor[
             0.3147617552192472, 0.44445743591237574`, 0.9413723382522537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 206}], {
             RGBColor[
             0.2694264291817054, 0.4005146380651934, 0.9386548086099904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 252}], {
             RGBColor[
             0.35313921834377116`, 0.47769806556345623`, 0.9438177162666903]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 275}], {
             RGBColor[
             0.4375752905440994, 0.5469996606424254, 0.950256890900377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 282}], {
             RGBColor[
             0.2744544360708304, 0.40579939209971316`, 0.9389411461640564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 324}], {
             RGBColor[
             0.6139308907687727, 0.686235491439511, 0.9567916259447211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 410}], {
             RGBColor[
             0.28925962244254416`, 0.42136058167941726`, 0.9397842796256151]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 441}], {
             RGBColor[
             0.5152478362749404, 0.6084115975071163, 0.9574970296237788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 467}], {
             RGBColor[
             0.3221804999766975, 0.4508831797443258, 0.9418450541080601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 91}], {
             RGBColor[
             0.6301354159487931, 0.692822236382425, 0.7069752232534205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 172}], {
             RGBColor[
             0.2984091571295606, 0.42905752816894804`, 0.9403756251744564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 303}], {
             RGBColor[
             0.4191988377599445, 0.5304817037483345, 0.9489557914961256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 366}], {
             RGBColor[
             0.2750304045793114, 0.4064047715206393, 0.9389739467185454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 384}], {
             RGBColor[
             0.5846495622697845, 0.6614876560574878, 0.9645240382815183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 435}], {
             RGBColor[
             0.2639818130535162, 0.39479200130586567`, 0.9383447457760778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 473}], {
             RGBColor[
             0.29417794761130056`, 0.4253926671510052, 0.9401060162454646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 88}], {
             RGBColor[
             0.34895068906260834`, 0.47666528091960325`, 0.9434558072354589]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 166}], {
             RGBColor[
             0.3587571144039171, 0.48515911366497594`, 0.9440806639867256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 167}], {
             RGBColor[
             0.4009943839920077, 0.5217429136752842, 0.9467719854559278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 175}], {
             RGBColor[
             0.36456761739906957`, 0.4901918793150049, 0.9444509040995506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[
             0.3575993590173565, 0.48415632413961485`, 0.9440068928372568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 227}], {
             RGBColor[
             0.39113273407101373`, 0.5132012481746563, 0.9461436098432766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 309}], {
             RGBColor[
             0.40870157914969585`, 0.5284184987459817, 0.9472630811161705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 320}], {
             RGBColor[
             0.39436307251963587`, 0.5159992049773214, 0.9463494441527467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 337}], {
             RGBColor[
             0.3355239783921925, 0.4629547239887102, 0.9426764652573585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 348}], {
             RGBColor[
             0.5103896599241106, 0.6115361895867335, 0.9551128564953011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 428}], {
             RGBColor[
             0.32719959768277673`, 0.4542052720668932, 0.9422024040907749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 434}], {
             RGBColor[
             0.49936133980555053`, 0.602582902494327, 0.9542446667375003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 474}], {
             RGBColor[
             0.31100463118408894`, 0.43718333545659005`, 0.9412801247069806]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 495}], {
             RGBColor[
             0.3140127410976462, 0.440345049700923, 0.9414514321164578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 208}], {
             RGBColor[
             0.38917808776629237`, 0.5115082317888865, 0.9460190615091656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 305}], {
             RGBColor[
             0.42772243730135395`, 0.5437427406920717, 0.9487930067531163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 314}], {
             RGBColor[
             0.3835086758967493, 0.5065976721804142, 0.9456578115981024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 394}], {
             RGBColor[
             0.381179157382155, 0.5045799603280776, 0.9455093767382647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 398}], {
             RGBColor[
             0.34622774679083956`, 0.47430680518285506`, 0.9432823037617051]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 427}], {
             RGBColor[
             0.47940670577272715`, 0.5857023581868934, 0.9528617816928964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 445}], {
             RGBColor[
             0.31092930063350616`, 0.4394212480574067, 0.9411909947359667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 460}], {
             RGBColor[
             0.3146617898108838, 0.44334433083631286`, 0.9414035544728954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 472}], {
             RGBColor[
             0.46072277873412176`, 0.5705339045156326, 0.9513909145149375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 70}], {
             RGBColor[
             0.4977518920479601, 0.6017585341778833, 0.9539847169310638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 96}], {
             RGBColor[
             0.4163766828968384, 0.5249027885011066, 0.9490328937460398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 131}], {
             RGBColor[
             0.7797440854906029, 0.8274931083770733, 0.9512971217626807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 135}], {
             RGBColor[
             0.533615698916939, 0.632252289350884, 0.9564273289989045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 147}], {
             RGBColor[
             0.47178115826803607`, 0.5792639899047469, 0.9523298847396251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 171}], {
             RGBColor[
             0.437936694145819, 0.5475637273074516, 0.9502607044914909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 180}], {
             RGBColor[
             0.6435308081757964, 0.7206932794744353, 0.9656224597284939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 216}], {
             RGBColor[
             0.6967678186181511, 0.7622824366482679, 0.9709286274012396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 238}], {
             RGBColor[
             0.4997137287432839, 0.6034577785185934, 0.9541097234305057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 281}], {
             RGBColor[
             0.4780386646620624, 0.5846839274318363, 0.9527286075137569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 343}], {
             RGBColor[
             0.5023173793094136, 0.6057129297756925, 0.9542756257422618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 385}], {
             RGBColor[
             0.5098138367027689, 0.6122059843869128, 0.9547532933785093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 391}], {
             RGBColor[
             0.4990607655597989, 0.6028922146279425, 0.9540681171938468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 465}], {
             RGBColor[
             0.4941250088827732, 0.5986171102726467, 0.9537536151429049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 205}], {
             RGBColor[
             0.41753786970680307`, 0.5346053991997678, 0.9482313615851475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 257}], {
             RGBColor[
             0.5691226134362781, 0.6610784021259541, 0.9592225633759803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 272}], {
             RGBColor[
             0.42325199934515084`, 0.5395546910919984, 0.9485954608728966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 306}], {
             RGBColor[
             0.43906184297440454`, 0.5532483830178123, 0.9496028501288569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 317}], {
             RGBColor[
             0.3981469061419406, 0.5159805895043147, 0.9470627673273284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 142}], {
             RGBColor[
             0.32190122029808305`, 0.44681306448591707`, 0.9419674284399575]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 173}], {
             RGBColor[
             0.2645439736229312, 0.3953828677073596, 0.9383767599888639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 194}], {
             RGBColor[
             0.3115285640012022, 0.43782879094642313`, 0.9413064919529002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 241}], {
             RGBColor[
             0.42267406039639, 0.52994969829333, 0.9495346163214369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 388}], {
             RGBColor[
             0.3858233933284907, 0.5000326666639763, 0.9466335968214106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 402}], {
             RGBColor[
             0.3783432047187423, 0.4939599125719259, 0.9460447289732175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 461}], {
             RGBColor[
             0.2960773892174394, 0.42444575994735306`, 0.9403219567586162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 487}], {
             RGBColor[
             0.5330881413457693, 0.6168177605656924, 0.9601448064836962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 490}], {
             RGBColor[
             0.398488464361943, 0.510314741883881, 0.9476306376068477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 84}], {
             RGBColor[
             0.3512130230704995, 0.47780277518456254`, 0.9436300595472356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 96}], {
             RGBColor[
             0.32119575096223096`, 0.44625271899379676`, 0.9419206203072443]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 131}], {
             RGBColor[
             0.6845631535559955, 0.7488430388697634, 0.9441848483238853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 135}], {
             RGBColor[
             0.43843476698233164`, 0.5536022198435742, 0.9493150555601089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 147}], {
             RGBColor[
             0.3766002263334287, 0.5006139203974371, 0.9452176113008297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 170}], {
             RGBColor[
             0.42631541835321984`, 0.5436747209667747, 0.9483854193749126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 171}], {
             RGBColor[
             0.3427557622112116, 0.4689136578001418, 0.9431484310526954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 216}], {
             RGBColor[
             0.6015868866835437, 0.683632367140958, 0.9638163539624441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[
             0.4045327968086765, 0.5248077090112835, 0.9469974499917102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 265}], {
             RGBColor[
             0.561036717626811, 0.651954266881139, 0.9597746920737438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 374}], {
             RGBColor[
             0.6343662354957064, 0.5041304844943512, 0.5784533331492006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 385}], {
             RGBColor[
             0.4146329047681616, 0.533555914879603, 0.9476410199397138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 391}], {
             RGBColor[
             0.40387983362519153`, 0.5242421451206327, 0.9469558437550513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 433}], {
             RGBColor[
             0.39073090595402793`, 0.5128532048561916, 0.9461180057109849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 194}], {
             RGBColor[
             0.3583512044031033, 0.48480753482390093`, 0.9440547997604058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 228}], {
             RGBColor[
             0.6153094010669644, 0.6920224026184508, 0.9662694662025966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 388}], {
             RGBColor[
             0.4326460337303918, 0.5470114105414541, 0.9493819046289163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 431}], {
             RGBColor[
             0.35519532469582815`, 0.48207407044058526`, 0.9438537098960931]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 462}], {
             RGBColor[
             0.5541813005636756, 0.6436405058574879, 0.9603434827839883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 487}], {
             RGBColor[
             0.5799107817476705, 0.6637965044431702, 0.9628931142912018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 490}], {
             RGBColor[
             0.44531110476384417`, 0.5572934857613588, 0.9503789454143534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 73}], {
             RGBColor[
             0.32320091771925485`, 0.45351969258132663`, 0.9418459000869017]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 144}], {
             RGBColor[
             0.35533119467066565`, 0.48219175418376603`, 0.9438623674107447]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 163}], {
             RGBColor[
             0.2887137931442734, 0.4172715380430305, 0.9398819093614852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 187}], {
             RGBColor[
             0.6662756765261768, 0.7315817799199846, 0.9142888339471833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 279}], {
             RGBColor[
             0.46502739147591077`, 0.5736761141416934, 0.9518271776106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 322}], {
             RGBColor[
             0.5974315214344825, 0.6782433448818005, 0.9643450010666574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 494}], {
             RGBColor[
             0.4018580879960649, 0.5223924278320627, 0.9468542586438835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 93}], {
             RGBColor[
             0.3159502163431185, 0.4472394994801647, 0.9413838918067577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 163}], {
             RGBColor[
             0.2651472651906933, 0.3960169653959722, 0.9384111165511582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 187}], {
             RGBColor[
             0.6427091485725966, 0.7103272072729265, 0.9128180411368563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 322}], {
             RGBColor[
             0.5738649934809026, 0.6569887722347423, 0.9628742082563303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 494}], {
             RGBColor[
             0.3782915600424848, 0.5011378551850044, 0.9453834658335565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 82}], {
             RGBColor[
             0.37408062940951475`, 0.4984315721805664, 0.9450570648128299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 105}], {
             RGBColor[
             0.38856456530138783`, 0.510976829466322, 0.9459799684002185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 112}], {
             RGBColor[
             0.36265955255869226`, 0.487401703915886, 0.9443709735450575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 153}], {
             RGBColor[
             0.4785992212033241, 0.586923782208115, 0.9522795993857993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 195}], {
             RGBColor[
             0.7076207347210658, 0.7672612229066504, 0.9120874773649048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 224}], {
             RGBColor[
             0.6620669028870985, 0.732605435789947, 0.9692101268562243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 234}], {
             RGBColor[
             0.37833625627474443`, 0.5021175822772028, 0.9453282295935792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 239}], {
             RGBColor[
             0.5798386261573929, 0.6677596725488313, 0.9611758336082783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 263}], {
             RGBColor[
             0.48224635939007876`, 0.5898846932898254, 0.952566715463768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 296}], {
             RGBColor[
             0.3425327499145785, 0.46624715822393, 0.9432247819094115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 342}], {
             RGBColor[
             0.37975387784185444`, 0.5033454548269019, 0.945418559186282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 395}], {
             RGBColor[
             0.393542338416736, 0.515288326348685, 0.9462971477014566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 440}], {
             RGBColor[
             0.37154833101530027`, 0.4962382225885158, 0.944895708998374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 447}], {
             RGBColor[
             0.45396897627760774`, 0.5669278397975293, 0.950340616281687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 453}], {
             RGBColor[
             0.7111295683762652, 0.7670739161001073, 0.7348499300081835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 463}], {
             RGBColor[
             0.42516076580750195`, 0.5426746189661982, 0.9483118459357185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 93}], {
             RGBColor[
             0.337250551553053, 0.46653120987483643`, 0.9427102848193754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 108}], {
             RGBColor[
             0.4019250873964799, 0.5223237560713326, 0.9468935362785189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 149}], {
             RGBColor[
             0.6674308293843131, 0.7287429527975455, 0.6909284181541425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 158}], {
             RGBColor[
             0.48952580212137536`, 0.5934419626522287, 0.9537897854336539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.2864476004006279, 0.4153086757906439, 0.9397375095637757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 182}], {
             RGBColor[
             0.3455404503703723, 0.4737115035679688, 0.9432385098415452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 206}], {
             RGBColor[
             0.3002051243328305, 0.42976870572078646`, 0.9405209801992818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 410}], {
             RGBColor[
             0.32003831759366924`, 0.4506146493350104, 0.9416504512149065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.28912802951985583`, 0.4184772704509554, 0.9398772934533088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[
             0.25968840576800495`, 0.38753435930780566`, 0.9382007504326614]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 238}], {
             RGBColor[
             0.3724650753663014, 0.4970322604684422, 0.9449541231377747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 333}], {
             RGBColor[
             0.5778772586143013, 0.3008422837924454, 0.5535018948921986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 343}], {
             RGBColor[
             0.375068725932431, 0.49928741172554125`, 0.9451200254495307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 392}], {
             RGBColor[
             0.30058496600847817`, 0.4305192371122264, 0.9405297490373172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 402}], {
             RGBColor[
             0.4279248559872297, 0.5433283729901225, 0.9489688385134445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 431}], {
             RGBColor[
             0.3579543355624144, 0.4844637869813041, 0.9440295116288144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 436}], {
             RGBColor[
             0.3116295965151844, 0.44212784404479444`, 0.9411587244056075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 459}], {
             RGBColor[
             0.3749066284023901, 0.49914701099227854`, 0.9451096967382537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 462}], {
             RGBColor[
             0.556940311430262, 0.6460302223982066, 0.9605192845167096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 487}], {
             RGBColor[
             0.5826697926142568, 0.6661862209838889, 0.9630689160239232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 81}], {
             RGBColor[
             0.24331894556694805`, 0.37307401747601604`, 0.9371680260406909]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 156}], {
             RGBColor[
             0.5584335896219583, 0.637801828991299, 0.9624449774582069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 278}], {
             RGBColor[
             0.26252282538838223`, 0.39325851276464907`, 0.9382616585869272]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 329}], {
             RGBColor[
             0.3823798451103838, 0.4979671640607011, 0.9462960475755213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 479}], {
             RGBColor[
             0.3519886871300557, 0.47329425290620597`, 0.9439035442928301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 482}], {
             RGBColor[
             0.2828793269477471, 0.41357864188664506`, 0.9394603231803775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 85}], {
             RGBColor[
             0.48220776745026894`, 0.5841316286938357, 0.9539614954323463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 95}], {
             RGBColor[
             0.6357864444562655, 0.7042674265931219, 0.9297237464694215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 97}], {
             RGBColor[
             0.6247173499505758, 0.6960121140347573, 0.9484608361853402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 137}], {
             RGBColor[
             0.33358351895756655`, 0.46180911702723865`, 0.9425332274796736]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 145}], {
             RGBColor[
             0.6253275572352521, 0.6964672056285461, 0.947427914419932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 183}], {
             RGBColor[
             0.33479655018910714`, 0.4628597837112766, 0.9426105207571059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 346}], {
             RGBColor[
             0.568362077374081, 0.6516357870516696, 0.962495542615234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 358}], {
             RGBColor[
             0.6406097688431236, 0.7070336894354629, 0.8843468244002224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 404}], {
             RGBColor[
             0.41129488175727036`, 0.5270213855252013, 0.9480644468994676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 407}], {
             RGBColor[
             0.29418196446965694`, 0.426534275244423, 0.9400645997221067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 408}], {
             RGBColor[
             0.29411561593993996`, 0.4264645387329507, 0.9400608212714932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 430}], {
             RGBColor[
             0.396172057527013, 0.5147439955396106, 0.9468739227793312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 81}], {
             RGBColor[
             0.3235761319858936, 0.4484477045209111, 0.9420674182763966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 99}], {
             RGBColor[
             0.3478532877633471, 0.4739645345035945, 0.9434499663830891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 122}], {
             RGBColor[
             0.3607767510132989, 0.48690842138613494`, 0.9442093534455809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 267}], {
             RGBColor[
             0.3370735620639193, 0.46263435931941094`, 0.9428360769516817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 278}], {
             RGBColor[
             0.34278001180732776`, 0.46863219980954407`, 0.9431610508226329]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 329}], {
             RGBColor[
             0.4626370315293294, 0.5733408511055962, 0.951195439811227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 406}], {
             RGBColor[
             0.4616525188591582, 0.5725415793681607, 0.9511179353674425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 413}], {
             RGBColor[
             0.41094988396586773`, 0.530365867374664, 0.947406341110959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 476}], {
             RGBColor[
             0.3749133062510239, 0.4991527950091267, 0.9451101222448637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 486}], {
             RGBColor[
             0.46977747978507484`, 0.5791377886731384, 0.9517575620542431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 493}], {
             RGBColor[
             0.4741333630294715, 0.5826740909212436, 0.9521004731393681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 156}], {
             RGBColor[
             0.5749219009080455, 0.6551320895722926, 0.9633839623936788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 278}], {
             RGBColor[
             0.2790111366744693, 0.4105887733456427, 0.9392006435223993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 307}], {
             RGBColor[
             0.363723208112193, 0.48665046249128063`, 0.9444999881211025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 329}], {
             RGBColor[
             0.39886815639647094`, 0.5152974246416947, 0.9472350325109934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 372}], {
             RGBColor[
             0.6361829472567706, 0.6997497204067642, 0.7644358890726333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 406}], {
             RGBColor[
             0.39788364372629975`, 0.5144981529042594, 0.9471575280672089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 417}], {
             RGBColor[
             0.3900518620734212, 0.5081399597407098, 0.9465409815267327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 461}], {
             RGBColor[
             0.3156178282249969, 0.44498400027968654`, 0.9414347558526076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 486}], {
             RGBColor[
             0.4060086046522164, 0.521094362209237, 0.9477971547540095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 493}], {
             RGBColor[
             0.41036448789661306`, 0.5246306644573422, 0.9481400658391345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 83}], {
             RGBColor[
             0.31242218543639394`, 0.43878671663338864`, 0.9413566986653101]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 99}], {
             RGBColor[
             0.2655385767767811, 0.39642825868353804`, 0.9384334011670923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 237}], {
             RGBColor[
             0.24449319730941957`, 0.37430823050921425`, 0.9372348979402749]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[
             0.2547588510773533, 0.3850980834993545, 0.9378195117356849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 278}], {
             RGBColor[
             0.26046530082076175`, 0.39109592398948767`, 0.9381444856066361]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 329}], {
             RGBColor[
             0.3803223205427634, 0.4958045752855397, 0.9461788745952302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 426}], {
             RGBColor[
             0.3928287149133309, 0.5059578296422123, 0.9471634237725134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 486}], {
             RGBColor[
             0.3874627687985088, 0.501601512853082, 0.9467409968382463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 89}], {
             RGBColor[
             0.4037945275501147, 0.5232183053577419, 0.9472128826755443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 105}], {
             RGBColor[
             0.3337689908933533, 0.4635156570197313, 0.9424884428527625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 184}], {
             RGBColor[
             0.3573520530739639, 0.4839421201614063, 0.9439911347212279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 195}], {
             RGBColor[
             0.6528251603130313, 0.7198000504600598, 0.9085959518174488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 225}], {
             RGBColor[
             0.5880707581062895, 0.6698342497137046, 0.9638872337660616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 263}], {
             RGBColor[
             0.4274507849820442, 0.5424235208432349, 0.949075189916312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 296}], {
             RGBColor[
             0.2877371755065439, 0.4187859857773394, 0.9397332563619555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 342}], {
             RGBColor[
             0.3249583034338198, 0.4558842823803112, 0.9419270336388259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 395}], {
             RGBColor[
             0.3387467640087014, 0.46782715390209445`, 0.9428056221540004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 440}], {
             RGBColor[
             0.3167527566072657, 0.44877705014192526`, 0.9414041834509181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 447}], {
             RGBColor[
             0.3991734018695732, 0.5194666673509387, 0.9468490907342308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 453}], {
             RGBColor[
             0.6563339939682307, 0.7196127436535167, 0.7313584044607275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 463}], {
             RGBColor[
             0.37036519139946733`, 0.4952134465196075, 0.9448203203882626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 470}], {
             RGBColor[
             0.37684902911561435`, 0.5008294208621749, 0.9452334647941029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 119}], {
             RGBColor[
             0.6683546780338756, 0.735612167785433, 0.9549457456893906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 176}], {
             RGBColor[
             0.3758652768446529, 0.4999773440898948, 0.9451707809692952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[
             0.33989417352806733`, 0.4676615179423854, 0.9429211877459666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 237}], {
             RGBColor[
             0.31565396174648597`, 0.44218351844174825`, 0.9415407435451852]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 270}], {
             RGBColor[
             0.6843797577994698, 0.7474000738977967, 0.9204943711123043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 345}], {
             RGBColor[
             0.4516918282146532, 0.5638493303798789, 0.9505011532322376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 375}], {
             RGBColor[
             0.32241513882779194`, 0.4492899442375874, 0.9419257825777004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 426}], {
             RGBColor[
             0.46398947935039725`, 0.5738331175747463, 0.9514692693774238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 448}], {
             RGBColor[
             0.4751153735930713, 0.582865619736773, 0.9523451405277006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 489}], {
             RGBColor[
             0.35796884535881335`, 0.48447635463766126`, 0.9440304361802104]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 131}], {
             RGBColor[
             0.6332052165131423, 0.7035373493837525, 0.9409424643788525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 135}], {
             RGBColor[
             0.38707682993947834`, 0.5082965303575633, 0.9460726716150762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 147}], {
             RGBColor[
             0.3252422892905754, 0.45530823091142614`, 0.941975227355797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 171}], {
             RGBColor[
             0.2913978251683583, 0.42360796831413083`, 0.9399060471076628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 230}], {
             RGBColor[
             0.2847221806536193, 0.41659144266883164`, 0.9395258790282794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 242}], {
             RGBColor[
             0.42805698375245804`, 0.541566065357831, 0.9492987794384836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 365}], {
             RGBColor[
             0.2685272141549316, 0.3995695060585285, 0.938603599644485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 374}], {
             RGBColor[
             0.5830082984528531, 0.4588247950083402, 0.5752109492041679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 385}], {
             RGBColor[
             0.3632749677253083, 0.48825022539359203`, 0.9443986359946812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 391}], {
             RGBColor[
             0.35252189658233823`, 0.4789364556346217, 0.9437134598100185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 95}], {
             RGBColor[
             0.8259683772093289, 0.8641310091399044, 0.9437434305804941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 97}], {
             RGBColor[
             0.8148992827036392, 0.8558756965815397, 0.9624805202964128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 137}], {
             RGBColor[
             0.5237654517106299, 0.6216726995740212, 0.9565529115907461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 145}], {
             RGBColor[
             0.8155094899883155, 0.8563307881753286, 0.9614475985310045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 183}], {
             RGBColor[
             0.5249784829421704, 0.6227233662580591, 0.9566302048681785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 286}], {
             RGBColor[
             0.5199062853334456, 0.6183300836254461, 0.9563070089217188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 346}], {
             RGBColor[
             0.7585440101271442, 0.811499369598452, 0.9765152267263065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 358}], {
             RGBColor[
             0.830791701596187, 0.8668972719822453, 0.898366508511295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 404}], {
             RGBColor[
             0.6014768145103337, 0.6868849680719837, 0.9620841310105401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 407}], {
             RGBColor[
             0.4843638972227203, 0.5863978577912055, 0.9540842838331793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 408}], {
             RGBColor[
             0.48429754869300334`, 0.5863281212797331, 0.9540805053825658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 90}], {
             RGBColor[
             0.3536051839222143, 0.4806967704252801, 0.9437523875321048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 98}], {
             RGBColor[
             0.40465622727848166`, 0.524914618280433, 0.9470053148721009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 115}], {
             RGBColor[
             0.3215826155561778, 0.4506835672830583, 0.9417953049340411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 124}], {
             RGBColor[
             0.3557817306122228, 0.48258198577174793`, 0.9438910751625473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 136}], {
             RGBColor[
             0.31092054093798516`, 0.4394770508447623, 0.9411881155576609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 168}], {
             RGBColor[
             0.30808540822097136`, 0.4364971466013843, 0.94102665894363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[
             0.3122216331260953, 0.4408445812284755, 0.9412622108329805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 253}], {
             RGBColor[
             0.3236016965494082, 0.45280574942407237`, 0.9419102886096429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 261}], {
             RGBColor[
             0.5162136547788927, 0.6150895753614948, 0.9560895522597525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 357}], {
             RGBColor[
             0.5049797097541815, 0.606313532127046, 0.9549698576068743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 484}], {
             RGBColor[
             0.4050797781380152, 0.5252814767466758, 0.9470323031583391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 500}], {
             RGBColor[
             0.38893420090354647`, 0.511296989246486, 0.9460035212539322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 107}], {
             RGBColor[
             0.4246382341425001, 0.5401335027002182, 0.9488556165263926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 113}], {
             RGBColor[
             0.3999447323097625, 0.5151307871158021, 0.9474145109781487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 143}], {
             RGBColor[
             0.6847163024745337, 0.752062559342258, 0.9703428844509436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 226}], {
             RGBColor[
             0.39859474150828733`, 0.5137118611890912, 0.947337630999137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 292}], {
             RGBColor[
             0.6566724274221679, 0.729999189095973, 0.9675889401161393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 308}], {
             RGBColor[
             0.48768010103112786`, 0.5947371992227872, 0.9528725885388019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 386}], {
             RGBColor[
             0.4011181487675337, 0.5163641222118202, 0.9474813353095046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 421}], {
             RGBColor[
             0.4524119539585507, 0.5641897028571343, 0.9506253333937351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 422}], {
             RGBColor[
             0.5505629147703461, 0.6460108026440537, 0.9577614759105817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 423}], {
             RGBColor[
             0.4478556732104154, 0.5602432814784285, 0.9503350112134248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 446}], {
             RGBColor[
             0.5308553544290888, 0.6300113173435451, 0.9562100245693458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 166}], {
             RGBColor[
             0.32289788338056447`, 0.4540996500899044, 0.9417957454949905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 167}], {
             RGBColor[
             0.36513515296865506`, 0.49068345010021275`, 0.9444870669641926]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 210}], {
             RGBColor[
             0.32174012799400387`, 0.45309686056454335`, 0.9417219743455216]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 227}], {
             RGBColor[
             0.3552735030476611, 0.4821417845995848, 0.9438586913515414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 243}], {
             RGBColor[
             0.31071043073474075`, 0.44350497396797545`, 0.9410205820926872]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 326}], {
             RGBColor[
             0.3709838309284025, 0.49574928098584436`, 0.9448597395520049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 348}], {
             RGBColor[
             0.4745304289007579, 0.580476726011662, 0.9528279380035659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 428}], {
             RGBColor[
             0.2913403666594241, 0.42314580849182165`, 0.9399174855990398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 434}], {
             RGBColor[
             0.4635021087821979, 0.5715234389192554, 0.9519597482457651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 469}], {
             RGBColor[
             0.290821280190785, 0.422600215701299, 0.9398879243925704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 474}], {
             RGBColor[
             0.2751454001607363, 0.4061238718815185, 0.9389952062152455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 495}], {
             RGBColor[
             0.27815351007429356`, 0.4092855861258514, 0.9391665136247227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 133}], {
             RGBColor[
             0.45326292002459795`, 0.5660653405654396, 0.9503649649008364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 184}], {
             RGBColor[
             0.4418615256225984, 0.5561900257851724, 0.9496384781313982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 192}], {
             RGBColor[
             0.41349775068935807`, 0.531622749542779, 0.9478311634737535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 225}], {
             RGBColor[
             0.672580230654924, 0.7420821553374708, 0.969534577176232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 235}], {
             RGBColor[
             0.39610554841109336`, 0.5161111084168264, 0.9467393288513152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 239}], {
             RGBColor[
             0.6095525242979929, 0.6925464057260067, 0.9633316514709926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 249}], {
             RGBColor[
             0.4914394549596832, 0.598011714488246, 0.953107060577917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 260}], {
             RGBColor[
             0.39321383993038783`, 0.5130717394586977, 0.9465746503312382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.5652182131126833, 0.6579086340520297, 0.9589151946802172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 296}], {
             RGBColor[
             0.37224664805517843`, 0.4910338914011055, 0.9453805997721259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 424}], {
             RGBColor[
             0.39205765534741044`, 0.511856516155652, 0.9465088073296595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 440}], {
             RGBColor[
             0.40126222915590026`, 0.5210249557656913, 0.9470515268610884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 453}], {
             RGBColor[
             0.7408434665168651, 0.7918606492772828, 0.7370057478708979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 470}], {
             RGBColor[
             0.46135850166424885`, 0.573077326485941, 0.9508808082042732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 124}], {
             RGBColor[
             0.3503414458411494, 0.47786988453970736`, 0.9435444250275895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 178}], {
             RGBColor[
             0.3067813483550219, 0.4361324799964348, 0.9409155606980226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[
             0.4895382607850505, 0.5936130861872341, 0.9537462789504207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 261}], {
             RGBColor[
             0.5107733700078192, 0.6103774741294541, 0.9557429021247945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 272}], {
             RGBColor[
             0.3436676466939232, 0.4720893751532783, 0.9431191764473371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 306}], {
             RGBColor[
             0.3594774903231769, 0.4857830670790923, 0.9441265657032973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 317}], {
             RGBColor[
             0.31856255349071294`, 0.4485152735655947, 0.941586482901769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 357}], {
             RGBColor[
             0.4995394249831081, 0.6016014308950053, 0.9546232074719163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 172}], {
             RGBColor[
             0.6612364849703587, 0.7235916372652309, 0.7088166762082295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 303}], {
             RGBColor[
             0.7820261656007426, 0.8250158128446173, 0.7173968425298988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 366}], {
             RGBColor[
             0.6378577324201093, 0.7009388806169221, 0.7074149977523185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 435}], {
             RGBColor[
             0.6268091408943142, 0.6893261104021484, 0.706785796809851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 473}], {
             RGBColor[
             0.6570052754520986, 0.719926776247288, 0.7085470672792378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 101}], {
             RGBColor[
             0.6598994859958953, 0.733983071620833, 0.9669104042197154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 128}], {
             RGBColor[
             0.7015473444260286, 0.7665186951619007, 0.971061473526666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 140}], {
             RGBColor[
             0.5152840856722335, 0.6160534378410993, 0.9553479285875044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 169}], {
             RGBColor[
             0.4509338874391724, 0.5573014013136256, 0.9513579895070066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 175}], {
             RGBColor[
             0.4850291496351701, 0.5898481329030953, 0.9534201108166123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 204}], {
             RGBColor[
             0.5384435214289289, 0.6361129770664623, 0.9568236273548362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 219}], {
             RGBColor[
             0.5224623124215568, 0.6222708570631965, 0.9558053188485147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 274}], {
             RGBColor[
             0.5655962054337793, 0.6582155052466554, 0.9589449516203654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 320}], {
             RGBColor[
             0.5148246047557363, 0.6156554585654119, 0.9553186508698083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 334}], {
             RGBColor[
             0.5443953531632048, 0.6410036982858922, 0.957275942868345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 337}], {
             RGBColor[
             0.45598551062829296`, 0.5626109775768007, 0.9516456719744202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 361}], {
             RGBColor[
             0.555070049627801, 0.6496698977654471, 0.9581162940767396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 363}], {
             RGBColor[
             0.5120349540953409, 0.6132392033752965, 0.9551408967965191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 370}], {
             RGBColor[
             0.44734866408327545`, 0.553533104250288, 0.9511538163407508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 498}], {
             RGBColor[
             0.4393338972592576, 0.5451090761526783, 0.950697387226908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 108}], {
             RGBColor[
             0.396940578763989, 0.5180064252225574, 0.9465759277960845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 163}], {
             RGBColor[
             0.281463091768137, 0.4109913449418686, 0.9394199010813413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 187}], {
             RGBColor[
             0.6590249751500403, 0.7253015868188228, 0.9138268256670394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 189}], {
             RGBColor[
             0.33248517582121767`, 0.46240368093066914`, 0.9424066392915991]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 206}], {
             RGBColor[
             0.29522061570033964`, 0.42545137487201123`, 0.9402033717168474]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 266}], {
             RGBColor[
             0.30092050862532815`, 0.4314423237302587, 0.9405279721866896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 322}], {
             RGBColor[
             0.5901808200583463, 0.6719631517806386, 0.9638829927865135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 364}], {
             RGBColor[
             0.3687159250845941, 0.49378493493219955`, 0.9447152305970679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 437}], {
             RGBColor[
             0.3559703939886576, 0.48274539650591874`, 0.9439030966260653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 100}], {
             RGBColor[
             0.46673761250528645`, 0.574538658567217, 0.9521071174626783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 127}], {
             RGBColor[
             0.5643504000343771, 0.657204104300527, 0.958846877255789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 168}], {
             RGBColor[
             0.43160062692490364`, 0.539332085691805, 0.9500429710795639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 213}], {
             RGBColor[
             0.4337130032260258, 0.5415523271166774, 0.9501632677849321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 214}], {
             RGBColor[
             0.5714880648946918, 0.662998782182268, 0.9594087803797208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 254}], {
             RGBColor[
             0.6570261942669391, 0.7314373129129725, 0.9668298996787938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 302}], {
             RGBColor[
             0.46935488238794554`, 0.576805606191767, 0.9522738875852403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 315}], {
             RGBColor[
             0.5207491703502783, 0.6213207552727182, 0.9555486861680158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 325}], {
             RGBColor[
             0.7398264916772566, 0.796554707447332, 0.9749677087452304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 368}], {
             RGBColor[
             0.42427200226171174`, 0.5316292365091491, 0.9496256167467237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 401}], {
             RGBColor[
             0.4693901074115127, 0.5768361163367197, 0.9522761320925939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 477}], {
             RGBColor[
             0.43900039322554124`, 0.5471097092460567, 0.950464376823412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 500}], {
             RGBColor[
             0.5124494196074788, 0.6141319283369069, 0.9550198333898661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 97}], {
             RGBColor[
             0.9684779597096358, 0.9760114944808258, 0.938242771333488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 137}], {
             RGBColor[
             0.6773441287166265, 0.7418084974733072, 0.9323151626278213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 145}], {
             RGBColor[
             0.9690881669943121, 0.9764665860746148, 0.9372098495680797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 174}], {
             RGBColor[
             0.6536843644649848, 0.7213155988528632, 0.9308075833712148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 286}], {
             RGBColor[
             0.6734849623394422, 0.7384658815247321, 0.9320692599587941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 294}], {
             RGBColor[
             0.659626127878043, 0.7264620556795417, 0.9311861872817997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 346}], {
             RGBColor[
             0.9121226871331408, 0.9316351674977381, 0.9522774777633818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 358}], {
             RGBColor[
             0.9843703786021836, 0.9870330698815315, 0.8741287595483702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 404}], {
             RGBColor[
             0.7550554915163303, 0.8070207659712698, 0.9378463820476153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 407}], {
             RGBColor[
             0.6379425742287168, 0.7065336556904915, 0.9298465348702545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 408}], {
             RGBColor[
             0.6378762256989999, 0.7064639191790193, 0.929842756419641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 430}], {
             RGBColor[
             0.739932667286073, 0.7947433759856792, 0.9366558579274791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 131}], {
             RGBColor[
             0.6031879444048738, 0.6719872931929867, 0.9392330251388612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 147}], {
             RGBColor[
             0.29522501718230687`, 0.42375817472066035`, 0.9402657881158056]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.21038091805925824`, 0.3384540621738703, 0.9352922541015729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 171}], {
             RGBColor[
             0.2613805530600898, 0.39205791212336505`, 0.9381966078676715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 180}], {
             RGBColor[
             0.4669746670900673, 0.5651874642903487, 0.9535583631046745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 216}], {
             RGBColor[
             0.5202116775324219, 0.6067766214641812, 0.9588645307774202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 238}], {
             RGBColor[
             0.32315758765755476`, 0.4479519633345068, 0.9420456268066862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 265}], {
             RGBColor[
             0.4796615084756891, 0.5750985212043622, 0.9548228688887198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 281}], {
             RGBColor[
             0.3014825235763332, 0.42917811224774977`, 0.9406645108899374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 343}], {
             RGBColor[
             0.3257612382236843, 0.45020711459160584`, 0.9422115291184423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 392}], {
             RGBColor[
             0.25127747829973146`, 0.38143893997829104`, 0.9376212527062288]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 433}], {
             RGBColor[
             0.3093556968029062, 0.4359974591794149, 0.941166182525961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 465}], {
             RGBColor[
             0.3175688677970441, 0.4431112950885601, 0.9416895185190854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 104}], {
             RGBColor[
             0.7867064027680907, 0.833447478601131, 0.9599465471052978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 137}], {
             RGBColor[
             0.6662750342109368, 0.7335531849149426, 0.95105225234374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 145}], {
             RGBColor[
             0.9580190724886224, 0.9682112735162502, 0.9559469392839984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 174}], {
             RGBColor[
             0.6426152699592951, 0.7130602862944986, 0.9495446730871335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 294}], {
             RGBColor[
             0.6485570333723533, 0.7182067431211772, 0.9499232769977184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 346}], {
             RGBColor[
             0.9010535926274511, 0.9233798549393736, 0.9710145674793005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 358}], {
             RGBColor[
             0.9733012840964939, 0.9787777573231669, 0.8928658492642889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 404}], {
             RGBColor[
             0.7439863970106406, 0.7987654534129052, 0.956583471763534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 407}], {
             RGBColor[
             0.6268734797230271, 0.698278343132127, 0.9485836245861732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 408}], {
             RGBColor[
             0.6268071311933102, 0.6982086066206548, 0.9485798461355597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 430}], {
             RGBColor[
             0.7288635727803833, 0.7864880634273146, 0.9553929476433978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 115}], {
             RGBColor[
             0.36719337414137176`, 0.4901893139061705, 0.9447015821390794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 124}], {
             RGBColor[
             0.40139248919741677`, 0.5220877323948602, 0.9467973523675857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 136}], {
             RGBColor[
             0.35653129952317913`, 0.4789827974678745, 0.9440943927626992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 253}], {
             RGBColor[
             0.3692124551346022, 0.49231149604718455`, 0.9448165658146812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 261}], {
             RGBColor[
             0.5618244133640866, 0.654595321984607, 0.9589958294647908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 277}], {
             RGBColor[
             0.374195332812851, 0.49754881641971627`, 0.9451003333269505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 311}], {
             RGBColor[
             0.4094007814607161, 0.5290241126448574, 0.9473076336691484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 319}], {
             RGBColor[
             0.4312810703248995, 0.5479757191237185, 0.9487018263275944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 331}], {
             RGBColor[
             0.378856096919335, 0.502447575005143, 0.9453657569478322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 377}], {
             RGBColor[
             0.4088681826771611, 0.5285628023477353, 0.9472736969456188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 484}], {
             RGBColor[
             0.45069053672320925`, 0.5647872233697879, 0.9499385803633774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 488}], {
             RGBColor[
             0.43206163033580564`, 0.5486518009730785, 0.9487515629212673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 122}], {
             RGBColor[
             0.30273919580418646`, 0.43488897554876194`, 0.9405753363362765]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 267}], {
             RGBColor[
             0.27903600685480684`, 0.41061491348203794`, 0.9392020598423774]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 278}], {
             RGBColor[
             0.2847424565982153, 0.4166127539721711, 0.9395270337133286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 329}], {
             RGBColor[
             0.4045994763202169, 0.5213214052682231, 0.9475614227019227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 406}], {
             RGBColor[
             0.40361496365004573`, 0.5205221335307878, 0.9474839182581382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 413}], {
             RGBColor[
             0.35291232875675527`, 0.47834642153729096`, 0.9437723240016547]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 476}], {
             RGBColor[
             0.31687575104191146`, 0.4471333491717537, 0.9414761051355593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 486}], {
             RGBColor[
             0.41173992457596237`, 0.5271183428357654, 0.9481235449449388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 493}], {
             RGBColor[
             0.41609580782035904`, 0.5306546450838706, 0.9484664560300637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 121}], {
             RGBColor[
             0.2975219906348967, 0.42832022773085143`, 0.9403179563059147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 127}], {
             RGBColor[
             0.4250121064385113, 0.5406640130295817, 0.9488223327795368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 168}], {
             RGBColor[
             0.29226233332903784`, 0.4227919944208597, 0.9400184266033118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 200}], {
             RGBColor[
             0.35825335863102215`, 0.48472278573399563`, 0.9440485651143304]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 213}], {
             RGBColor[
             0.29437470963016, 0.42501223584573206`, 0.94013872330868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 254}], {
             RGBColor[
             0.5176879006710733, 0.6148972216420272, 0.9568053552025416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 259}], {
             RGBColor[
             0.3421995472196566, 0.4708177811774937, 0.9430256304470263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 315}], {
             RGBColor[
             0.3814108767544126, 0.5047806640017728, 0.9455241416917637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 368}], {
             RGBColor[
             0.284933708665846, 0.4150891452382037, 0.9396010722704715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 401}], {
             RGBColor[
             0.33005181381564697`, 0.46029602506577433`, 0.9422515876163416]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 450}], {
             RGBColor[
             0.4261968425141941, 0.5416258351475729, 0.9489155995432458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 454}], {
             RGBColor[
             0.3564470626830089, 0.4831582629709007, 0.9439334695337678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 471}], {
             RGBColor[
             0.36749966987383, 0.4927314757994001, 0.9446377318905301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 475}], {
             RGBColor[
             0.34025724674386915`, 0.469135458128227, 0.942901868778218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 500}], {
             RGBColor[
             0.373111126011613, 0.4975918370659615, 0.9449952889136138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 128}], {
             RGBColor[
             0.735713845863762, 0.793464515111878, 0.9742927385850643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 169}], {
             RGBColor[
             0.48510038887690565`, 0.5842472212636028, 0.9545892545654048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 197}], {
             RGBColor[
             0.49513569230815146`, 0.5947949614448291, 0.9551607502499132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[
             0.5726100228666623, 0.6630587970164395, 0.9600548924132344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 219}], {
             RGBColor[
             0.5566288138592901, 0.6492166770131738, 0.9590365839069129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 337}], {
             RGBColor[
             0.49015201206602627`, 0.5895567975267779, 0.9548769370328184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 345}], {
             RGBColor[
             0.6069333469947373, 0.6909827738823227, 0.9627407157361842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 355}], {
             RGBColor[
             0.47560974171741077`, 0.5742719493571888, 0.9540487762498258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 361}], {
             RGBColor[
             0.5892365510655343, 0.6766157177154244, 0.9613475591351379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 362}], {
             RGBColor[
             0.694097389901327, 0.7609534234172438, 0.9701447991826212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 363}], {
             RGBColor[
             0.5462014555330743, 0.6401850233252737, 0.9583721618549175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 498}], {
             RGBColor[
             0.4735003986969909, 0.5720548961026556, 0.9539286522853062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 109}], {
             RGBColor[
             0.3443323086881477, 0.47135423671426974`, 0.943209524221715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[
             0.29041011393206395`, 0.4225698211802761, 0.9398497984139436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 186}], {
             RGBColor[
             0.3716970588935009, 0.4950562079498101, 0.9449531819071015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 193}], {
             RGBColor[
             0.35309800301659144`, 0.47894664056496045`, 0.9437680665131243]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 196}], {
             RGBColor[
             0.41829539267131244`, 0.5330088048791639, 0.9485878726697463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 202}], {
             RGBColor[
             0.3286840440553483, 0.457800496393988, 0.94221243063653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 330}], {
             RGBColor[
             0.26721436888558886`, 0.3981896224412515, 0.9385288350485765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 350}], {
             RGBColor[
             0.4069757058745105, 0.5238189731914411, 0.9476967454597232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 354}], {
             RGBColor[
             0.35305050495305995`, 0.47890550012965155`, 0.9437650399785169]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 414}], {
             RGBColor[
             0.3038298248510387, 0.43627302092859466`, 0.9406287417665546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 415}], {
             RGBColor[
             0.4640134413446748, 0.5701247763668214, 0.9521869649320438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 485}], {
             RGBColor[
             0.3221905056506697, 0.4521761198025854, 0.9417986681113946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 496}], {
             RGBColor[
             0.3073887086282393, 0.43935554718170616`, 0.9408555106938405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 118}], {
             RGBColor[
             0.6357932798390715, 0.7029849662327449, 0.9105142041906267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 188}], {
             RGBColor[
             0.6278014465126885, 0.6945850426952171, 0.9100590811055471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 304}], {
             RGBColor[
             0.9132311965119942, 0.9320496710283179, 0.933049014145947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 319}], {
             RGBColor[
             0.6991543862659539, 0.7600076795476074, 0.9144730701673939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 331}], {
             RGBColor[
             0.6467294128603894, 0.7144795354290319, 0.9111370007876318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 449}], {
             RGBColor[
             0.6803883474433542, 0.7437534799280077, 0.9132773147677744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 488}], {
             RGBColor[
             0.6999349462768601, 0.7606837613969674, 0.9145228067610667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 112}], {
             RGBColor[
             0.45622342081603523`, 0.5640247192422079, 0.951553294945509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 148}], {
             RGBColor[
             0.4604030267678122, 0.5684177500998486, 0.9517913173212897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 153}], {
             RGBColor[
             0.5721630894606671, 0.6635467975344369, 0.9594619207862508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 190}], {
             RGBColor[
             0.5541702862703347, 0.6489394293379787, 0.9580454614092981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 215}], {
             RGBColor[
             0.4520181126492897, 0.5596046737270206, 0.9513138088666088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 224}], {
             RGBColor[
             0.7556307711444414, 0.8092284511162688, 0.9763924482566759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 323}], {
             RGBColor[
             0.4612647305488235, 0.5693234554088668, 0.951840390076842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 351}], {
             RGBColor[
             0.6129438313235823, 0.6966544409302364, 0.9626723301704792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 356}], {
             RGBColor[
             0.4425370811873416, 0.5496395085283987, 0.95077387815078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 408}], {
             RGBColor[
             0.4561046687574548, 0.5638999032993244, 0.9515465321914508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 430}], {
             RGBColor[
             0.5581611103445279, 0.6521793601059843, 0.9583596336992888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 452}], {
             RGBColor[
             0.5302667456254171, 0.6292948312028928, 0.9562296204785212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 112}], {
             RGBColor[
             0.3223479140425308, 0.4524857887550509, 0.94180235158499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 148}], {
             RGBColor[
             0.3265275199943078, 0.45687881961269167`, 0.9420403739607708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 153}], {
             RGBColor[
             0.4382875826871626, 0.55200786704728, 0.9497109774257319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 190}], {
             RGBColor[
             0.4202947794968303, 0.5374004988508216, 0.9482945180487792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 195}], {
             RGBColor[
             0.6673090962049044, 0.7323453077458153, 0.9095188554048373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 263}], {
             RGBColor[
             0.4419347208739173, 0.5549687781289904, 0.9499980935037006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 323}], {
             RGBColor[
             0.3273892237753191, 0.45778452492170985`, 0.942089446716323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 342}], {
             RGBColor[
             0.33944223932569295`, 0.4684295396660667, 0.9428499372262145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 395}], {
             RGBColor[
             0.35323069990057454`, 0.48037241118784996`, 0.943728525741389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 447}], {
             RGBColor[
             0.4136573377614463, 0.5320119246366942, 0.9477719943216194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 453}], {
             RGBColor[
             0.6708179298601038, 0.7321580009392723, 0.7322813080481161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 463}], {
             RGBColor[
             0.38484912729134046`, 0.507758703805363, 0.9457432239756511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 117}], {
             RGBColor[
             0.34485592293698, 0.4719370535864983, 0.9432381545723092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 139}], {
             RGBColor[
             0.5648865105792015, 0.6545869186568778, 0.9603170517065744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 140}], {
             RGBColor[
             0.399290237301952, 0.5202668674652611, 0.9466633987357551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 247}], {
             RGBColor[
             0.34039866126047386`, 0.4672521889577775, 0.9429843201137599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 255}], {
             RGBColor[
             0.6706583352293816, 0.7379417572268585, 0.9599711162298206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 269}], {
             RGBColor[
             0.44958833591889846`, 0.5624175518739859, 0.9502593179727521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 274}], {
             RGBColor[
             0.44960235706349794`, 0.5624289348708171, 0.950260421768616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 360}], {
             RGBColor[
             0.40042624213800126`, 0.5212508177569837, 0.9467357839593785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 369}], {
             RGBColor[
             0.3905654891394331, 0.5127099291254804, 0.9461074654978312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 370}], {
             RGBColor[
             0.33135481571299397`, 0.4577465338744497, 0.9424692864890014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 425}], {
             RGBColor[
             0.35694247135928564`, 0.4835873610663275, 0.9439650365365475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 466}], {
             RGBColor[
             0.3678461363432858, 0.4930315676413316, 0.9446598084275957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 468}], {
             RGBColor[
             0.3341351113069604, 0.46066880082463046`, 0.942627620209999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 113}], {
             RGBColor[
             0.2943461722405135, 0.4257551475227317, 0.9401087982613652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 132}], {
             RGBColor[
             0.43222335478481533`, 0.5462914453434405, 0.949452745008568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 143}], {
             RGBColor[
             0.5791177424052847, 0.6626869197491876, 0.9630371717341601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 209}], {
             RGBColor[
             0.653104063432264, 0.7198598514138442, 0.9019326891226245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 214}], {
             RGBColor[
             0.42796994888074125`, 0.5428383388167608, 0.9491179013150601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 273}], {
             RGBColor[
             0.3521157708114935, 0.47940671564885334`, 0.9436574834457259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 308}], {
             RGBColor[
             0.38208154096187885`, 0.5053615596297168, 0.9455668758220184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 421}], {
             RGBColor[
             0.3468133938893017, 0.47481406326406395`, 0.9433196206769516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 423}], {
             RGBColor[
             0.3422571131411664, 0.4708676418853581, 0.9430292984966413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 446}], {
             RGBColor[
             0.42525679435983976`, 0.5406356777504748, 0.9489043118525622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 477}], {
             RGBColor[
             0.2954822772115907, 0.4269492658805495, 0.9401734977587513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 129}], {
             RGBColor[
             0.4171037593906163, 0.5354707588504168, 0.9478607078360126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 163}], {
             RGBColor[
             0.3461376276115639, 0.4667838911383649, 0.9436031525404849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 189}], {
             RGBColor[
             0.3971597116646446, 0.5181962271271654, 0.9465898907507426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 206}], {
             RGBColor[
             0.3598951515437665, 0.48124392106850744`, 0.944386623175991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 266}], {
             RGBColor[
             0.365595044468755, 0.487234869926755, 0.9447112236458332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 364}], {
             RGBColor[
             0.433390460928021, 0.5495774811286958, 0.9488984820562114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 374}], {
             RGBColor[
             0.663888312742738, 0.5294757378685913, 0.5803967010306805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 410}], {
             RGBColor[
             0.37972834480460527`, 0.5020898646827314, 0.9455160941916156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 437}], {
             RGBColor[
             0.42064492983208446`, 0.5385379427024151, 0.9480863480852089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 185}], {
             RGBColor[
             0.34017423095738986`, 0.4669838333818882, 0.9429727278462732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 186}], {
             RGBColor[
             0.42146117591882687`, 0.5394702201514223, 0.9480761113394311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 196}], {
             RGBColor[
             0.46805950969663834`, 0.577422817080776, 0.9517108021020759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 218}], {
             RGBColor[
             0.3459690003576341, 0.4730745034311455, 0.9433027313910239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 295}], {
             RGBColor[
             0.3527596916409974, 0.4799644475069677, 0.943698513511585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 300}], {
             RGBColor[
             0.31889401098877423`, 0.4446169729509985, 0.9417608508003248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 335}], {
             RGBColor[
             0.45774972910965056`, 0.5690528727499368, 0.9508991784082975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 409}], {
             RGBColor[
             0.3834542401631106, 0.5065505226839558, 0.9456543430012905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 456}], {
             RGBColor[
             0.28751886001044047`, 0.41163969997330124`, 0.9399740823674849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 458}], {
             RGBColor[
             0.3580336528134911, 0.48453248759758577`, 0.9440345656539155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 496}], {
             RGBColor[
             0.35715282565356526`, 0.48376955938331834`, 0.9439784401261699]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 217}], {
             RGBColor[
             0.6045949224126593, 0.6836914010743091, 0.9651497151320243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 290}], {
             RGBColor[
             0.5615148543448517, 0.6412174855285873, 0.9625936287739157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 316}], {
             RGBColor[
             0.6047745717333237, 0.6838470042864312, 0.9651611622278794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 340}], {
             RGBColor[
             0.6135473371296214, 0.6914455327406948, 0.9657201550814796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 355}], {
             RGBColor[
             0.5636241973652716, 0.6434345387831206, 0.9627137527384353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 378}], {
             RGBColor[
             0.5774592872655583, 0.657976095463686, 0.9635016406410752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 384}], {
             RGBColor[
             0.886042967580462, 0.9119706276257535, 0.9889927632993609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 146}], {
             RGBColor[
             0.5171455517298275, 0.6187703886618281, 0.9551613235497016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 201}], {
             RGBColor[
             0.37596965025897733`, 0.49950857253750647`, 0.9451979056707117]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 256}], {
             RGBColor[
             0.484508319379836, 0.592274013149543, 0.952592001064989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 271}], {
             RGBColor[
             0.38061903413599885`, 0.50409480972487, 0.9454736861803172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 284}], {
             RGBColor[
             0.4004943178951484, 0.5213097815562375, 0.9467401216864268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 312}], {
             RGBColor[
             0.39808142990482903`, 0.5192198592542995, 0.9465863745973169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 376}], {
             RGBColor[
             0.47874192846171926`, 0.5875925972292654, 0.9521380496489289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[
             0.42306582380067004`, 0.5408600854947272, 0.9481783580835277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 415}], {
             RGBColor[
             0.541349972164373, 0.6384206275673067, 0.9570667841900226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 442}], {
             RGBColor[
             0.7104335209586772, 0.7709455335190396, 0.9413802756935425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 444}], {
             RGBColor[
             0.42028535549279966`, 0.5384517835968504, 0.9480011891016218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 464}], {
             RGBColor[
             0.41332691110907294`, 0.5324247288132502, 0.9475578031786016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 148}], {
             RGBColor[
             0.3006225072516122, 0.4333036940622558, 0.9404313791056098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 153}], {
             RGBColor[
             0.41238256994446704`, 0.5284327414968442, 0.9481019825705709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 190}], {
             RGBColor[
             0.39438976675413473`, 0.5138253733003857, 0.9466855231936182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 195}], {
             RGBColor[
             0.6414040834622088, 0.7087701821953794, 0.9079098605496764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 224}], {
             RGBColor[
             0.5958502516282413, 0.6741143950786761, 0.965032510040996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 263}], {
             RGBColor[
             0.4160297081312217, 0.5313936525785545, 0.9483890986485396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 323}], {
             RGBColor[
             0.30148421103262346`, 0.4342093993712739, 0.940480451861162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 342}], {
             RGBColor[
             0.3135372265829973, 0.4448544141156308, 0.9412409423710535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 351}], {
             RGBColor[
             0.4531633118073823, 0.5615403848926436, 0.9513123919547992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 356}], {
             RGBColor[
             0.2827565616711416, 0.41452545249080586`, 0.9394139399351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 395}], {
             RGBColor[
             0.3273256871578789, 0.45679728563741406`, 0.942119530886228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 447}], {
             RGBColor[
             0.3877523250187507, 0.5084367990862584, 0.9461629994664584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 452}], {
             RGBColor[
             0.37048622610921705`, 0.4941807751652999, 0.9448696822628413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 463}], {
             RGBColor[
             0.35894411454864483`, 0.48418357825492714`, 0.9441342291204902]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 130}], {
             RGBColor[
             0.6166528755764088, 0.6449039400040834, 0.6259836021288571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 143}], {
             RGBColor[
             0.554424240572547, 0.6376842041647715, 0.9615960661859162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 209}], {
             RGBColor[
             0.6284105615995264, 0.6948571358294282, 0.9004915835743805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 214}], {
             RGBColor[
             0.4032764470480036, 0.5178356232323448, 0.9476767957668162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 273}], {
             RGBColor[
             0.32742226897875587`, 0.45440400006443726`, 0.9422163778974819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 302}], {
             RGBColor[
             0.30114326454125734`, 0.43164244724184364`, 0.9405419029723359]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 308}], {
             RGBColor[
             0.3573880391291412, 0.4803588440453007, 0.9441257702737744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 325}], {
             RGBColor[
             0.5716148738305684, 0.6513915484974087, 0.9632357241323258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 347}], {
             RGBColor[
             0.3011049930699146, 0.4316092984169466, 0.9405394643480239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 386}], {
             RGBColor[
             0.2708260868655471, 0.4019857670343337, 0.9387345170444772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 421}], {
             RGBColor[
             0.3221198920565641, 0.4498113476796478, 0.9418785151287077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 423}], {
             RGBColor[
             0.3175636113084288, 0.44586492630094204`, 0.9415881929483974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 477}], {
             RGBColor[
             0.27078877537885304`, 0.40194655029613335`, 0.9387323922105074]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 115}], {
             RGBColor[
             0.30511184829014265`, 0.4364174165220521, 0.940745802208377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 203}], {
             RGBColor[
             0.3662855209441834, 0.4916798410214397, 0.9445603673943628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 208}], {
             RGBColor[
             0.3723557522010644, 0.496937570237456, 0.9449471571623564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 258}], {
             RGBColor[
             0.2982572599440585, 0.4292128095643149, 0.9403554435425222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 289}], {
             RGBColor[
             0.3364113785503401, 0.4658043603979479, 0.942656813457694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 291}], {
             RGBColor[
             0.3622204288968687, 0.48815886260752284`, 0.9443013433237277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 297}], {
             RGBColor[
             0.2933797360801274, 0.4240862227304488, 0.9400776757741212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 311}], {
             RGBColor[
             0.34731925560948695`, 0.4752522152607391, 0.9433518537384458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 349}], {
             RGBColor[
             0.3169710092770939, 0.44888214663357295`, 0.9414211638825274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 359}], {
             RGBColor[
             0.31037513197475247`, 0.44194946138603697`, 0.9410455384278851]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 381}], {
             RGBColor[
             0.3825281334776006, 0.5057483756204426, 0.9455953323022138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 397}], {
             RGBColor[
             0.31519734145442874`, 0.4470179092949167, 0.941320156123933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 419}], {
             RGBColor[
             0.32070159479565064`, 0.4521973353063261, 0.9416557999284615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 124}], {
             RGBColor[
             0.3183188774751129, 0.4478566813974856, 0.9415873424295259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 136}], {
             RGBColor[
             0.27345768780087526`, 0.4047517464704999, 0.9388843828246395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 178}], {
             RGBColor[
             0.27475877998898546`, 0.406119276854213, 0.9389584780999589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 203}], {
             RGBColor[
             0.3452934350731086, 0.47122068740818346`, 0.9433061373870055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 253}], {
             RGBColor[
             0.28613884341229834`, 0.41808044504980996`, 0.9396065558766215]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 277}], {
             RGBColor[
             0.2911217210905471, 0.4233177654223417, 0.9398903233888908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 291}], {
             RGBColor[
             0.3412283430257939, 0.46769970899426655`, 0.9430471133163704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 297}], {
             RGBColor[
             0.27238765020905265`, 0.40362706911719254`, 0.9388234457667639]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 311}], {
             RGBColor[
             0.32632716973841225`, 0.4547930616474828, 0.9420976237310885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 381}], {
             RGBColor[
             0.36153604760652586`, 0.4852892220071863, 0.9443411022948565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 419}], {
             RGBColor[
             0.29970950892457593`, 0.4317381816930698, 0.9404015699211041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 439}], {
             RGBColor[
             0.33496696523232683`, 0.46227641825556376`, 0.9426481438600895]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 484}], {
             RGBColor[
             0.36761692500090537`, 0.49055617237241333`, 0.9447285704253177]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 192}], {
             RGBColor[
             0.6018699039087302, 0.6815046714495165, 0.96489618732436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 280}], {
             RGBColor[
             0.7535903663320555, 0.8077905559587671, 0.9759802185308237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 310}], {
             RGBColor[
             0.6452961563231654, 0.7191183086239901, 0.9676632697278805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 327}], {
             RGBColor[
             0.5835245051711486, 0.6649911604086758, 0.9637500695736914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 399}], {
             RGBColor[
             0.5453290776711476, 0.6248453443761987, 0.9615748964826375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 412}], {
             RGBColor[
             0.6549963627199025, 0.7275201398582942, 0.968281358301925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 483}], {
             RGBColor[
             0.6768720591041104, 0.7455071780307665, 0.9699406723574207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 139}], {
             RGBColor[
             0.5159971456985823, 0.6110598613241969, 0.9572451268210652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 140}], {
             RGBColor[
             0.3504008724213329, 0.47673981013258027`, 0.9435914738502458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 154}], {
             RGBColor[
             0.41817148476018007`, 0.5330754683085172, 0.9485628933713575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 247}], {
             RGBColor[
             0.2915092963798548, 0.4237251316250966, 0.9399123952282507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 255}], {
             RGBColor[
             0.6217689703487626, 0.6944146998941776, 0.9568991913443112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 269}], {
             RGBColor[
             0.40069897103827934`, 0.5188904945413051, 0.9471873930872428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 338}], {
             RGBColor[
             0.37790164252663083`, 0.5003825962476031, 0.9453927038774399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 369}], {
             RGBColor[
             0.341676124258814, 0.4691828717927995, 0.943035540612322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 390}], {
             RGBColor[
             0.466021970761494, 0.5719226484842127, 0.9523298589114866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 425}], {
             RGBColor[
             0.30805310647866657`, 0.4400603037336467, 0.9408931116510382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 466}], {
             RGBColor[
             0.3189567714626667, 0.44950451030865074`, 0.9415878835420863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[
             0.635856664981493, 0.7030111776180599, 0.9094637483452149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 151}], {
             RGBColor[
             0.30983372616696103`, 0.4406416261854119, 0.9410417566462475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 188}], {
             RGBColor[
             0.2775811086059755, 0.4090857231766393, 0.9391192055394355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 304}], {
             RGBColor[
             0.5630108586052811, 0.64655035150974, 0.9621091385798354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 310}], {
             RGBColor[
             0.3555584740205978, 0.4802461045835821, 0.9439552971466743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 327}], {
             RGBColor[
             0.29378682286858115`, 0.4261189563682678, 0.9400420969924851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 483}], {
             RGBColor[
             0.38713437680154295`, 0.5066349739903585, 0.9462326997762145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 197}], {
             RGBColor[
             0.6246659016884826, 0.6966116811618959, 0.9522043891651367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 237}], {
             RGBColor[
             0.6004256899069011, 0.6711336816612586, 0.9508239449643554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 270}], {
             RGBColor[
             0.9691514859598851, 0.9763502371173072, 0.9297775725314744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 309}], {
             RGBColor[
             0.6928598222038607, 0.7568372920011159, 0.956507191806854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 320}], {
             RGBColor[
             0.6785213155738008, 0.7444179982324559, 0.95559355484343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 345}], {
             RGBColor[
             0.7364635563750684, 0.7927994935993894, 0.9597843546514078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 375}], {
             RGBColor[
             0.6071868669882072, 0.6782401074570978, 0.9512089839968706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 426}], {
             RGBColor[
             0.7487612075108125, 0.8027832807942568, 0.960752470796594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 489}], {
             RGBColor[
             0.6427405735192286, 0.7134265178571717, 0.9533136375993806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 123}], {
             RGBColor[
             0.6185732852972717, 0.6974496405206005, 0.9652804114277712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 125}], {
             RGBColor[
             0.5886001697181265, 0.6714884342985371, 0.9633705510072534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 177}], {
             RGBColor[
             0.5458386134388508, 0.6308302167665994, 0.9607783796180016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 438}], {
             RGBColor[
             0.5503803585502156, 0.6356038788419159, 0.9610370252831841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 455}], {
             RGBColor[
             0.555889255741948, 0.6413940790746825, 0.9613507488285702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 457}], {
             RGBColor[
             0.544876417403547, 0.629818887726743, 0.9607235839772326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 161}], {
             RGBColor[
             0.46568499740161334`, 0.567934214729965, 0.952835467981789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[
             0.32837603035649815`, 0.45504444616857553`, 0.942283948433819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.26449738135563605`, 0.395333896280312, 0.9383741066281686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 259}], {
             RGBColor[
             0.3123222189451326, 0.44113944161207364`, 0.9412610137665149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 341}], {
             RGBColor[
             0.34170814337913147`, 0.4665920523772963, 0.9431334588864966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 450}], {
             RGBColor[
             0.39631951423967016`, 0.5119474955821528, 0.9471509828627345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 454}], {
             RGBColor[
             0.3265697344084849, 0.4534799234054806, 0.9421688528532565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 469}], {
             RGBColor[
             0.2680978823513436, 0.3991182511117488, 0.9385791498334102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 471}], {
             RGBColor[
             0.33762234159930604`, 0.46305313623398003`, 0.9428731152100187]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 475}], {
             RGBColor[
             0.31037991846934515`, 0.4394571185628069, 0.9411372520977066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 491}], {
             RGBColor[
             0.4629179571663749, 0.565772581867912, 0.9525596752706016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 500}], {
             RGBColor[
             0.34323379773708906`, 0.46791349750054145`, 0.9432306722331025]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 150}], {
             RGBColor[
             0.27063625392946994`, 0.40114674819435836`, 0.9387471212885579]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.4071163362001683, 0.5258167427228579, 0.9475015638264839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 233}], {
             RGBColor[
             0.2802021851968632, 0.41120114847146166`, 0.9392918869227088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 267}], {
             RGBColor[
             0.29195947010475864`, 0.4235588003645784, 0.9399614469048692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 406}], {
             RGBColor[
             0.41653842689999754`, 0.5334660204133282, 0.9482433053206298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 413}], {
             RGBColor[
             0.3658357920067071, 0.4912903084198314, 0.9445317110641465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 476}], {
             RGBColor[
             0.32979921429186326`, 0.4600772360542941, 0.9422354921980511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 493}], {
             RGBColor[
             0.42901927107031085`, 0.5435985319664111, 0.9492258430925555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 125}], {
             RGBColor[
             0.3850855034172892, 0.5079634409250503, 0.9457582856533773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 177}], {
             RGBColor[
             0.3423239471380135, 0.46730522339311265`, 0.9431661142641254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 438}], {
             RGBColor[
             0.3468656922493783, 0.47207888546842913`, 0.943424759929308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 455}], {
             RGBColor[
             0.3523745894411108, 0.4778690857011957, 0.943738483474694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 136}], {
             RGBColor[
             0.30765680285692026`, 0.4366501649591895, 0.9409801530531458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 178}], {
             RGBColor[
             0.30895789504503046`, 0.4380176953429027, 0.9410542483284652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 253}], {
             RGBColor[
             0.32033795846834334`, 0.4499788635384996, 0.9417023261051277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 261}], {
             RGBColor[
             0.5129499166978277, 0.612262689475922, 0.9558815897552373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 357}], {
             RGBColor[
             0.5017159716731165, 0.6034866462414732, 0.9547618951023591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 484}], {
             RGBColor[
             0.4018160400569504, 0.522454590861103, 0.9468243406538239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 177}], {
             RGBColor[
             0.3123508315588682, 0.4413440171710492, 0.9412562538436078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 438}], {
             RGBColor[
             0.316892576670233, 0.4461176792463657, 0.9415148995087902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 455}], {
             RGBColor[
             0.3224014738619655, 0.45190787947913225`, 0.9418286230541764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 457}], {
             RGBColor[
             0.3113886355235644, 0.4403326881311927, 0.9412014582028387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 144}], {
             RGBColor[
             0.45330076809188175`, 0.5646209647266218, 0.950775519684133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 279}], {
             RGBColor[
             0.5629969648971269, 0.6561053246845492, 0.9587403298839883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 285}], {
             RGBColor[
             0.40455796382090436`, 0.5184880836162504, 0.9478129935054724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 481}], {
             RGBColor[
             0.502732764213554, 0.6071801316983223, 0.9539961112511366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 130}], {
             RGBColor[
             0.7431389873563219, 0.7561924534163713, 0.6344308020586201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 168}], {
             RGBColor[
             0.3898751208581285, 0.5054574401541697, 0.9467581863964225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 179}], {
             RGBColor[
             0.5056617095360849, 0.609557981458636, 0.9542266885560065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 200}], {
             RGBColor[
             0.45586614616011273`, 0.5673882314673058, 0.9507883249074411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 213}], {
             RGBColor[
             0.39198749715925063`, 0.5076776815790421, 0.9468784831017907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 254}], {
             RGBColor[
             0.6153006882001639, 0.6975626673753372, 0.9635451149956523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 302}], {
             RGBColor[
             0.4276293763211704, 0.5429309606541317, 0.9489891029020989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 315}], {
             RGBColor[
             0.4790236642835032, 0.5874461097350829, 0.9522639014848744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 325}], {
             RGBColor[
             0.6981009856104814, 0.7626800619096967, 0.971682924062089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 347}], {
             RGBColor[
             0.42759110484982765`, 0.5428978118292347, 0.9489866642777871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 368}], {
             RGBColor[
             0.3825464961949366, 0.4977545909715138, 0.9463408320635822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 386}], {
             RGBColor[
             0.3973121986454601, 0.5132742804466217, 0.9471817169742404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 401}], {
             RGBColor[
             0.42766460134473755`, 0.5429614707990844, 0.9489913474094523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 454}], {
             RGBColor[
             0.4540598502120995, 0.5658237087042108, 0.9506732293268785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 169}], {
             RGBColor[
             0.5267482473070391, 0.6167828448046706, 0.9587403238723553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 197}], {
             RGBColor[
             0.5367835507382848, 0.627330584985897, 0.9593118195568637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 204}], {
             RGBColor[
             0.6142578812967956, 0.6955944205575073, 0.964205961720185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 345}], {
             RGBColor[
             0.6485812054248707, 0.7235183974233905, 0.9668917850431347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 355}], {
             RGBColor[
             0.5172576001475442, 0.6068075728982566, 0.9581998455567764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 362}], {
             RGBColor[
             0.7357452483314604, 0.7934890469583116, 0.9742958684895717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 498}], {
             RGBColor[
             0.5151482571271242, 0.6045905196437233, 0.9580797215922567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 170}], {
             RGBColor[
             0.4113261403834518, 0.5306917617723779, 0.9474303158371771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 206}], {
             RGBColor[
             0.31538379632696684`, 0.4429157084998706, 0.9414881517567755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 265}], {
             RGBColor[
             0.5460474396570428, 0.6389713076867423, 0.9588195885360082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 266}], {
             RGBColor[
             0.32108368925195535`, 0.4489066573581181, 0.9418127522266178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 328}], {
             RGBColor[
             0.29876759796010754`, 0.42545103048847616`, 0.9405418838412456]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 410}], {
             RGBColor[
             0.3352169895878056, 0.4637616521140945, 0.9426176227724002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 433}], {
             RGBColor[
             0.37574162798425986`, 0.49987024566179483`, 0.9451629021732493]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 143}], {
             RGBColor[
             0.90142444574118, 0.8818357122305391, 0.6489119756016521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 179}], {
             RGBColor[
             0.7261758029248048, 0.7424209761121157, 0.6330953980419791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 214}], {
             RGBColor[
             0.7502766522166365, 0.7619871312981125, 0.6349927051825519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 254}], {
             RGBColor[
             0.8358147815888839, 0.8304256620288168, 0.6424138244816251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 302}], {
             RGBColor[
             0.6481434697098902, 0.6757939553076113, 0.6278578123880716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 315}], {
             RGBColor[
             0.6995377576722231, 0.7203091043885625, 0.631132610970847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 325}], {
             RGBColor[
             0.9186150789992014, 0.8955430565631763, 0.6505516335480617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 347}], {
             RGBColor[
             0.6481051982385475, 0.6757608064827143, 0.6278553737637598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 368}], {
             RGBColor[
             0.6030605895836565, 0.6306175856249935, 0.6252095415495549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 386}], {
             RGBColor[
             0.61782629203418, 0.6461372751001014, 0.6260504264602131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 421}], {
             RGBColor[
             0.669120097225197, 0.6939628557454155, 0.6291944245444436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 477}], {
             RGBColor[
             0.617788980547486, 0.6460980583619012, 0.6260483016262433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 135}], {
             RGBColor[
             0.7204269604249744, 0.7793367940427641, 0.9466274603917259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 147}], {
             RGBColor[
             0.6585924197760715, 0.7263484945966271, 0.9425300161324466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 170}], {
             RGBColor[
             0.7083076117958627, 0.7694092951659646, 0.9456978242065295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 171}], {
             RGBColor[
             0.6247479556538544, 0.6946482319993318, 0.9404608358843123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 216}], {
             RGBColor[
             0.8835790801261865, 0.909366941340148, 0.9611287587940611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 238}], {
             RGBColor[
             0.6865249902513193, 0.7505422832104736, 0.9443098548233271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 265}], {
             RGBColor[
             0.8430289110694538, 0.877688841080329, 0.9570870969053606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 374}], {
             RGBColor[
             0.9163584289383491, 0.7298650586935411, 0.5757657379808175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 385}], {
             RGBColor[
             0.6966250982108044, 0.7592904890787929, 0.9449534247713307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 391}], {
             RGBColor[
             0.6858720270678342, 0.7499767193198226, 0.9442682485866682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 433}], {
             RGBColor[
             0.6727230993966707, 0.7385877790553816, 0.9434304105426019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 209}], {
             RGBColor[
             0.766287744143828, 0.815393433650137, 0.9098355303215835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 233}], {
             RGBColor[
             0.3950743734179838, 0.508197231045677, 0.9473023183270882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 273}], {
             RGBColor[
             0.4652994515230577, 0.5749402978851461, 0.9515603246446849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 423}], {
             RGBColor[
             0.4554407938527306, 0.5664012241216508, 0.9509321396956003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 151}], {
             RGBColor[
             0.3761581751760051, 0.5002310379030139, 0.945189444191969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 155}], {
             RGBColor[
             0.42725632607011943`, 0.5444896879397562, 0.9484453731826215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 181}], {
             RGBColor[
             0.37675108961146336`, 0.5007445905862619, 0.9452272241755029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 225}], {
             RGBColor[
             0.6375391505807727, 0.7126812849214024, 0.9670393159913537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 235}], {
             RGBColor[
             0.36106446833694206`, 0.486710238000758, 0.944244067666437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 239}], {
             RGBColor[
             0.5745114442238416, 0.6631455353099382, 0.9608363902861145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 249}], {
             RGBColor[
             0.4563983748855319, 0.5686108440721775, 0.9506117993930387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 260}], {
             RGBColor[
             0.35817275985623653`, 0.4836708690426293, 0.9440793891463601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 262}], {
             RGBColor[
             0.6670451959385507, 0.6204091721106731, 0.5995168848292446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 296}], {
             RGBColor[
             0.33720556798102713`, 0.46163302098503706`, 0.9428853385872477]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 332}], {
             RGBColor[
             0.4138419290144628, 0.5328708114373464, 0.9475906196641205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 344}], {
             RGBColor[
             0.592348876792363, 0.6770802732019758, 0.96261425886426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 424}], {
             RGBColor[
             0.35701657527325914`, 0.48245564573958355`, 0.9440135461447814]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 440}], {
             RGBColor[
             0.36622114908174896`, 0.4916240853496229, 0.9445562656762103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 138}], {
             RGBColor[
             0.6534970012907513, 0.72383008036323, 0.9692867075626176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 251}], {
             RGBColor[
             0.3572675970274981, 0.48386896857884193`, 0.9439857532566287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 305}], {
             RGBColor[
             0.4340507533891986, 0.5492240100169479, 0.9491962414583235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 367}], {
             RGBColor[
             0.32935645235089234`, 0.4576191607394161, 0.942283240231653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 416}], {
             RGBColor[
             0.30501617152413396`, 0.432035982327554, 0.9408970972467876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 438}], {
             RGBColor[
             0.3255390014848424, 0.45360677783883313`, 0.9420658420522439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 457}], {
             RGBColor[
             0.32003506033817375`, 0.44782178672366013`, 0.9417524007462923]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 499}], {
             RGBColor[
             0.36984428787880214`, 0.4947622660713795, 0.9447871288765426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 147}], {
             RGBColor[
             0.41246403320240754`, 0.5311076755704378, 0.9476602233686703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 170}], {
             RGBColor[
             0.4621792252221988, 0.5741684761397754, 0.9508280314427533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 171}], {
             RGBColor[
             0.37861956908019045`, 0.4994074129731425, 0.9455910431205361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 216}], {
             RGBColor[
             0.6374506935525226, 0.7141261223139587, 0.9662589660302847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 385}], {
             RGBColor[
             0.45049671163714045`, 0.5640496700526036, 0.9500836320075545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 391}], {
             RGBColor[
             0.43974364049417036`, 0.5547359002936334, 0.9493984558228918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 253}], {
             RGBColor[
             0.27547676879410565`, 0.40687392861151395`, 0.9389993665002413]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 261}], {
             RGBColor[
             0.4680887270235901, 0.5691577545489364, 0.9531786301503509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 277}], {
             RGBColor[
             0.2804596464723545, 0.41211124898404566`, 0.9392831340125106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 291}], {
             RGBColor[
             0.3305662684076013, 0.45649319255597054`, 0.9424399239399902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 311}], {
             RGBColor[
             0.31566509512021956`, 0.44358654520918683`, 0.9414904343547084]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 319}], {
             RGBColor[
             0.3375453839844029, 0.4625381516880479, 0.9428846270131543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 377}], {
             RGBColor[
             0.31513249633666457`, 0.4431252349120647, 0.9414564976311789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 484}], {
             RGBColor[
             0.3569548503827127, 0.4793496559341173, 0.9441213810489375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 488}], {
             RGBColor[
             0.33832594399530913`, 0.4632142335374079, 0.9429343636068273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 145}], {
             RGBColor[
             0.6668852414956131, 0.7340082765087316, 0.9500193305783318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 183}], {
             RGBColor[
             0.3763542344494681, 0.500400854591462, 0.9452019369155058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 346}], {
             RGBColor[
             0.6099197616344418, 0.6891768579318549, 0.9650869587736337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 358}], {
             RGBColor[
             0.6821674531034847, 0.7445747603156483, 0.8869382405586221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 404}], {
             RGBColor[
             0.4528525660176313, 0.5645624564053866, 0.9506558630578674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 407}], {
             RGBColor[
             0.3357396487300179, 0.4640753461246083, 0.9426560158805065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 408}], {
             RGBColor[
             0.33567330020030095`, 0.4640056096131361, 0.942652237429893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 430}], {
             RGBColor[
             0.437729741787374, 0.552285066419796, 0.949465338937731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 352}], {
             RGBColor[
             0.7506182812134111, 0.8048744818730807, 0.9763254207953245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 367}], {
             RGBColor[
             0.6104482161742809, 0.6844688092147244, 0.9666196374745035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 457}], {
             RGBColor[
             0.6011268241615624, 0.6746714351989684, 0.966088797989143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 140}], {
             RGBColor[
             0.5704314600635545, 0.6593896752029598, 0.9606703709845111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 247}], {
             RGBColor[
             0.5115398840220763, 0.6063749966954761, 0.9569912923625159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 255}], {
             RGBColor[
             0.841799557990984, 0.8770645649645572, 0.9739780884785766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 269}], {
             RGBColor[
             0.6207295586805008, 0.7015403596116845, 0.9642662902215081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 274}], {
             RGBColor[
             0.6207435798251004, 0.7015517426085157, 0.964267394017372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 360}], {
             RGBColor[
             0.5715674648996037, 0.6603736254946824, 0.9607427562081345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 369}], {
             RGBColor[
             0.5617067119010355, 0.651832736863179, 0.9601144377465873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 370}], {
             RGBColor[
             0.5024960384745965, 0.5968693416121483, 0.9564762587377575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 425}], {
             RGBColor[
             0.5280836941208881, 0.6227101688040262, 0.9579720087853035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 466}], {
             RGBColor[
             0.5389873591048883, 0.6321543753790302, 0.9586667806763517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 468}], {
             RGBColor[
             0.5052763340685629, 0.5997916085623292, 0.9566345924587552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 169}], {
             RGBColor[
             0.3404849885532439, 0.46631758748386926`, 0.9430267789331938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 204}], {
             RGBColor[
             0.42799462254300047`, 0.5451291632367059, 0.9484924167810234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 219}], {
             RGBColor[
             0.4120134135356283, 0.5312870432334401, 0.9474741082747019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 244}], {
             RGBColor[
             0.3586567417040516, 0.48507217587723106`, 0.9440742683270462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 247}], {
             RGBColor[
             0.3459436107448268, 0.47205494550385946`, 0.9433376393916966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 255}], {
             RGBColor[
             0.6762032847137347, 0.7427445137729405, 0.9603244355077571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 274}], {
             RGBColor[
             0.45514730654785085`, 0.5672316914168991, 0.9506137410465527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 334}], {
             RGBColor[
             0.43394645427727624`, 0.5500198844561359, 0.9489447322945324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 361}], {
             RGBColor[
             0.44462115074187253`, 0.5586860839356907, 0.9497850835029269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 363}], {
             RGBColor[
             0.4015860552094125, 0.5222553895455402, 0.9468096862227064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 369}], {
             RGBColor[
             0.39611043862378603`, 0.5175126856715624, 0.9464607847757679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 370}], {
             RGBColor[
             0.336899765197347, 0.46254929042053167`, 0.942822605766938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 425}], {
             RGBColor[
             0.3624874208436386, 0.48839011761240947`, 0.9443183558144841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 466}], {
             RGBColor[
             0.3733910858276388, 0.4978343241874136, 0.9450131277055323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 188}], {
             RGBColor[
             0.6278648316551099, 0.6946112540805323, 0.9090086252601354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 220}], {
             RGBColor[
             0.7090766812311377, 0.7685731830981835, 0.9140508153379969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[
             0.6876236721532911, 0.7499916648945408, 0.9126838485697075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 304}], {
             RGBColor[
             0.9132945816544156, 0.932075882413633, 0.9319985583005352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 310}], {
             RGBColor[
             0.7058421970697322, 0.765771635487475, 0.9138447168673742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 429}], {
             RGBColor[
             0.6922386558315736, 0.753988931800845, 0.9129779112488179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 173}], {
             RGBColor[
             0.3471729792293865, 0.47337528544477897`, 0.9434066177248783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 222}], {
             RGBColor[
             0.5211153379485254, 0.620779230730986, 0.9558092740272757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 241}], {
             RGBColor[
             0.5053030660028452, 0.6079421160307494, 0.9545644740574512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 402}], {
             RGBColor[
             0.4609722103251976, 0.5719523303093452, 0.9510745867092317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 417}], {
             RGBColor[
             0.453140428672319, 0.5655941371457958, 0.9504580401687557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 461}], {
             RGBColor[
             0.37870639482389473`, 0.5024381776847724, 0.9453518144946305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 179}], {
             RGBColor[
             0.663947167920943, 0.7352012402728039, 0.9687078620990384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 214}], {
             RGBColor[
             0.6880480172127748, 0.7547673954588006, 0.9706051692396112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 226}], {
             RGBColor[
             0.5530742497710718, 0.6362652782380606, 0.9615191862069047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 273}], {
             RGBColor[
             0.6121938391435271, 0.691335772290893, 0.965144751370277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 283}], {
             RGBColor[
             0.6290411366118004, 0.7059280545881198, 0.9662182462674751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 292}], {
             RGBColor[
             0.8111519356849524, 0.8525526061449422, 0.9817704953239068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 302}], {
             RGBColor[
             0.5859148347060286, 0.6685742194682995, 0.9634702764451308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 308}], {
             RGBColor[
             0.6421596092939124, 0.7172906162717566, 0.9670541437465694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 325}], {
             RGBColor[
             0.8563864439953396, 0.8883233207238646, 0.9861640976051209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 347}], {
             RGBColor[
             0.5858765632346858, 0.6685410706434025, 0.963467837820819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 386}], {
             RGBColor[
             0.5555976570303183, 0.6389175392607895, 0.9616628905172723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 421}], {
             RGBColor[
             0.6068914622213353, 0.6867431199061037, 0.9648068886015028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 423}], {
             RGBColor[
             0.6023351814732, 0.6827966985273979, 0.9645165664211924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 446}], {
             RGBColor[
             0.6853348626918734, 0.7525647343925146, 0.9703915797771134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 477}], {
             RGBColor[
             0.5555603455436242, 0.6388783225225892, 0.9616607656833025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 279}], {
             RGBColor[
             0.4735911404737415, 0.5810936030970746, 0.9523728521241159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 494}], {
             RGBColor[
             0.4104218369938957, 0.5298099167874439, 0.9473999331573995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 183}], {
             RGBColor[
             0.6680982727271536, 0.7350589431927695, 0.9500966238557642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 286}], {
             RGBColor[
             0.6630260751184288, 0.7306656605601565, 0.9497734279093044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 294}], {
             RGBColor[
             0.6491672406570296, 0.718661834714966, 0.9488903552323102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 346}], {
             RGBColor[
             0.9016637999121274, 0.9238349465331626, 0.9699816457138921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 358}], {
             RGBColor[
             0.9739114913811702, 0.9792328489169557, 0.8918329274988805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 404}], {
             RGBColor[
             0.7445966042953169, 0.7992205450066941, 0.9555505499981258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 407}], {
             RGBColor[
             0.6274836870077034, 0.6987334347259159, 0.9475507028207649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 408}], {
             RGBColor[
             0.6274173384779865, 0.6986636982144436, 0.9475469243701514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 430}], {
             RGBColor[
             0.7294737800650596, 0.7869431550211035, 0.9543600258779894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 201}], {
             RGBColor[
             0.4438739486865867, 0.5547470342857065, 0.9505129959150704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 211}], {
             RGBColor[
             0.47248483382521245`, 0.5800875195258005, 0.9523155820967417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 271}], {
             RGBColor[
             0.4485233325636082, 0.5593332714730701, 0.950788776424676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 284}], {
             RGBColor[
             0.46839861632275775`, 0.5765482433044375, 0.9520552119307857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 312}], {
             RGBColor[
             0.4659857283324384, 0.5744583210024996, 0.9519014648416755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 376}], {
             RGBColor[
             0.5466462268893286, 0.6428310589774655, 0.9574531398932876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 400}], {
             RGBColor[
             0.4909701222282794, 0.5960985472429272, 0.9534934483278865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 415}], {
             RGBColor[
             0.6092542705919823, 0.6936590893155068, 0.9623818744343813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 442}], {
             RGBColor[
             0.7783378193862864, 0.8261839952672397, 0.9466953659379014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 444}], {
             RGBColor[
             0.48818965392040903`, 0.5936902453450505, 0.9533162793459806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 464}], {
             RGBColor[
             0.4812312095366823, 0.5876631905614503, 0.9528728934229602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 497}], {
             RGBColor[
             0.44873905678608905`, 0.5595201209519682, 0.950802522181375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 171}], {
             RGBColor[
             0.31678502843128753`, 0.4464191135270054, 0.9414935988612567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 216}], {
             RGBColor[
             0.5756161529036197, 0.6611378228678216, 0.9621615217710056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 238}], {
             RGBColor[
             0.37856206302875245`, 0.5023131647381471, 0.9453426178002715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 385}], {
             RGBColor[
             0.3886621709882375, 0.5110613706064666, 0.9459861877482751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 391}], {
             RGBColor[
             0.37790909984526744`, 0.5017476008474963, 0.9453010115636127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 153}], {
             RGBColor[
             0.416562175896244, 0.5328257723544849, 0.9483400049463517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 190}], {
             RGBColor[
             0.3985693727059117, 0.5182184041580264, 0.946923545569399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 195}], {
             RGBColor[
             0.6455836894139857, 0.7131632130530201, 0.9081478829254572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 323}], {
             RGBColor[
             0.3056638169844005, 0.43860243022891465`, 0.9407184742369428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 342}], {
             RGBColor[
             0.31771683253477434`, 0.44924744497327157`, 0.9414789647468343]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 351}], {
             RGBColor[
             0.45734291775915925`, 0.5659334157502843, 0.95155041433058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 356}], {
             RGBColor[
             0.28693616762291857`, 0.4189184833484466, 0.9396519623108808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 452}], {
             RGBColor[
             0.374665832060994, 0.49857380602294066`, 0.945107704638622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 463}], {
             RGBColor[
             0.36312372050042185`, 0.4885766091125679, 0.9443722514962709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 158}], {
             RGBColor[
             0.8147215713201446, 0.8513363747261626, 0.7016903102859868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 165}], {
             RGBColor[
             0.6570421782017952, 0.7197448252920391, 0.690266462487116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 182}], {
             RGBColor[
             0.6707362195691415, 0.7316059156419027, 0.6911390346938779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 187}], {
             RGBColor[
             0.9892052529813005, 0.9875133297415319, 0.6620449590018067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 275}], {
             RGBColor[
             0.7935497548939937, 0.8341481403719525, 0.7000235873420012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 282}], {
             RGBColor[
             0.6304289004207247, 0.6929478718292402, 0.6887078426056807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 324}], {
             RGBColor[
             0.969905355118667, 0.973383971169038, 0.7065583223863454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 441}], {
             RGBColor[
             0.8712223006248347, 0.8955600772366432, 0.7072637260654031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 159}], {
             RGBColor[
             0.3620899310755, 0.4791306284859139, 0.9449139617162735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 233}], {
             RGBColor[
             0.23517578007219486`, 0.36451503423451764`, 0.9367042848124985]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 267}], {
             RGBColor[
             0.24693306498009032`, 0.37687268612763436`, 0.9373738447946587]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 406}], {
             RGBColor[
             0.37151202177532927`, 0.4867799061763842, 0.9456557032104196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 413}], {
             RGBColor[
             0.32080938688203875`, 0.4446041941828874, 0.9419441089539361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 443}], {
             RGBColor[
             0.2761639094940176, 0.4059345256163226, 0.9390993386132169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 476}], {
             RGBColor[
             0.28477280916719494`, 0.4133911218173501, 0.9396478900878407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 188}], {
             RGBColor[
             0.301841892840578, 0.4322417026478842, 0.9405866335611679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 192}], {
             RGBColor[
             0.3363930058407652, 0.4657884468803535, 0.9426556427648862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 249}], {
             RGBColor[
             0.41433471011109035`, 0.5321774118258205, 0.9479315398690497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 260}], {
             RGBColor[
             0.31610909508179497`, 0.44723743679627215`, 0.9413991296223709]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 280}], {
             RGBColor[
             0.4881134682640904, 0.5920743313896041, 0.95373967397135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 310}], {
             RGBColor[
             0.37981925825520035`, 0.5034020840548269, 0.9454227251684068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 327}], {
             RGBColor[
             0.3180476071031837, 0.4492749358395127, 0.9415095250142176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 424}], {
             RGBColor[
             0.3149529104988176, 0.44602221349322635`, 0.9413332866207922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 483}], {
             RGBColor[
             0.41139516103614543`, 0.5297909534616033, 0.9477001277979469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 191}], {
             RGBColor[
             0.35313058003684883`, 0.4802856923940615, 0.943722146192205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 212}], {
             RGBColor[
             0.37913919244695393`, 0.5028130452328253, 0.9453793919764639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 287}], {
             RGBColor[
             0.31828917078291863`, 0.444248868866171, 0.9417166071178591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 299}], {
             RGBColor[
             0.4220870905540861, 0.5400123559490995, 0.9481159940665153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 301}], {
             RGBColor[
             0.3176209251944845, 0.4435465003835092, 0.9416785515201785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 389}], {
             RGBColor[
             0.6889926531561728, 0.7510318782006642, 0.9074221164084006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 451}], {
             RGBColor[
             0.3903109488015284, 0.5124894590783567, 0.9460912464125811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 190}], {
             RGBColor[
             0.5103294353987665, 0.6133474515926148, 0.9545941490343599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 195}], {
             RGBColor[
             0.7573437521068406, 0.8082922604876085, 0.9158184863904182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 263}], {
             RGBColor[
             0.5319693767758535, 0.6309157308707836, 0.9562977244892814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 323}], {
             RGBColor[
             0.4174238796772553, 0.533731477663503, 0.9483890777019037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 342}], {
             RGBColor[
             0.4294768952276292, 0.5443764924078599, 0.9491495682117954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 351}], {
             RGBColor[
             0.5691029804520141, 0.6610624631848727, 0.959221017795541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[
             0.3986962303157734, 0.514047530783035, 0.9473225657758418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 395}], {
             RGBColor[
             0.4432653558025108, 0.5563193639296431, 0.9500281567269699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 447}], {
             RGBColor[
             0.5036919936633826, 0.6079588773784874, 0.9540716253072004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 452}], {
             RGBColor[
             0.4864258947538489, 0.593702853457529, 0.9527783081035831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 463}], {
             RGBColor[
             0.47488378319327673`, 0.5837056565471562, 0.9520428549612319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 174}], {
             RGBColor[
             0.4340990430893216, 0.5480526655148764, 0.9495345210903876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 229}], {
             RGBColor[
             0.6899652556710112, 0.7563213033948714, 0.9707590853263577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 255}], {
             RGBColor[
             0.7439738970525818, 0.7990801719488774, 0.9652958550288688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 313}], {
             RGBColor[
             0.41469732977747087`, 0.5294239111475415, 0.948365045384644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 338}], {
             RGBColor[
             0.50010656923045, 0.6050480683023028, 0.9537893675619975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 369}], {
             RGBColor[
             0.4638810509626332, 0.5738483438474993, 0.9514322042968796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 379}], {
             RGBColor[
             0.4793650849540842, 0.5872598358407171, 0.9524188332508212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 380}], {
             RGBColor[
             0.40983108325954054`, 0.5243091775193471, 0.9480879198444143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 390}], {
             RGBColor[
             0.5882268974653132, 0.6765881205389125, 0.9607265225960442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 425}], {
             RGBColor[
             0.4302580331824858, 0.5447257757883465, 0.9492897753355958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 478}], {
             RGBColor[
             0.4263998267189715, 0.5413839912687457, 0.9490439338314187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 181}], {
             RGBColor[
             0.38578557573113614`, 0.5085698083766469, 0.9458028936421661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 235}], {
             RGBColor[
             0.37009895445661484`, 0.49453545579114305`, 0.9448197371331002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 262}], {
             RGBColor[
             0.6760796820582234, 0.6282343899010582, 0.6000925542959078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 332}], {
             RGBColor[
             0.42287641513413554`, 0.5406960292277314, 0.9481662891307836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 344}], {
             RGBColor[
             0.6013833629120358, 0.6849054909923609, 0.9631899283309231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 387}], {
             RGBColor[
             0.5023521890200746, 0.6064088355418074, 0.9540938936009871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 393}], {
             RGBColor[
             0.3857335904656086, 0.5085247813525025, 0.9457995811870155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 403}], {
             RGBColor[
             0.38205624345221806`, 0.5053396481983385, 0.9455652638870724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 232}], {
             RGBColor[
             0.6252709455183157, 0.7015519333378222, 0.9664892699597034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 307}], {
             RGBColor[
             0.6602920163134958, 0.7318854246504086, 0.9687207816228554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 350}], {
             RGBColor[
             0.6954369645977737, 0.7605323868008227, 0.9714558260127462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 354}], {
             RGBColor[
             0.6415117636763232, 0.7156189137390331, 0.96752412053154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 372}], {
             RGBColor[
             0.9327517554580734, 0.9449846825658923, 0.7886566825743859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 479}], {
             RGBColor[
             0.6650458066174456, 0.7358594756463275, 0.9690633227300549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 180}], {
             RGBColor[
             0.43753504333821636`, 0.534244553147199, 0.9518818200840271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 216}], {
             RGBColor[
             0.490772053780571, 0.5758337103210316, 0.9571879877567727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 238}], {
             RGBColor[
             0.2937179639057038, 0.4170090521913571, 0.9403690837860388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 246}], {
             RGBColor[
             0.5831683047938345, 0.6478698764114506, 0.9126583314034329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 281}], {
             RGBColor[
             0.2720428998244823, 0.39823520110460003`, 0.93898796786929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 288}], {
             RGBColor[
             0.5638297011996113, 0.6336470919017314, 0.9543461176625757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 343}], {
             RGBColor[
             0.2963216144718334, 0.4192642034484561, 0.9405349860977947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 392}], {
             RGBColor[
             0.22183785454788058`, 0.3504960288351413, 0.9359447096855813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 459}], {
             RGBColor[
             0.2961595169417925, 0.4191238027151934, 0.9405246573865178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 465}], {
             RGBColor[
             0.28812924404519313`, 0.4121683839454104, 0.940012975498438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 182}], {
             RGBColor[
             0.4928311923062038, 0.5963049254965859, 0.9540004019733894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 206}], {
             RGBColor[
             0.447495866268662, 0.5523621276494035, 0.9512828723311261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 282}], {
             RGBColor[
             0.45252387315778697`, 0.5576468816839234, 0.9515692098851922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 324}], {
             RGBColor[
             0.7920003278557293, 0.8380829810237211, 0.9694196896658569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 410}], {
             RGBColor[
             0.46732905952950077`, 0.5732080712636274, 0.9524123433467508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 441}], {
             RGBColor[
             0.6933172733618971, 0.7602590870913264, 0.9701250933449145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 164}], {
             RGBColor[
             0.42818104240711047`, 0.5440619324963929, 0.9488437882792019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 396}], {
             RGBColor[
             0.4129846661278095, 0.5308995951553426, 0.9478754886203128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 443}], {
             RGBColor[
             0.4126439917647159, 0.5306045201448222, 0.9478537811511429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 165}], {
             RGBColor[
             0.36299670206221013`, 0.48883123140671786`, 0.9443508067633919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 268}], {
             RGBColor[
             0.36191035065269617`, 0.48789028841740634`, 0.9442815854122004]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 275}], {
             RGBColor[
             0.4995042787544086, 0.6032345464866312, 0.954107931618277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 285}], {
             RGBColor[
             0.33547249071522695`, 0.4610768290096207, 0.9427403105629832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 324}], {
             RGBColor[
             0.675859878979082, 0.7424703772837167, 0.9606426666626212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 353}], {
             RGBColor[
             0.39467536037844364`, 0.5162696930245767, 0.9463693428589646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 441}], {
             RGBColor[
             0.5771768244852498, 0.6646464833513219, 0.9613480703416788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 480}], {
             RGBColor[
             0.3735759949406504, 0.497994483167302, 0.9450249099507047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 481}], {
             RGBColor[
             0.4336472911078765, 0.5497688770916926, 0.9489234283086474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 259}], {
             RGBColor[
             0.5103625539863732, 0.6104317681766072, 0.9555431421229006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 326}], {
             RGBColor[
             0.5463007681302017, 0.6415596429608277, 0.9578330933492303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 341}], {
             RGBColor[
             0.539748478420372, 0.6358843789418298, 0.9574155872428822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 387}], {
             RGBColor[
             0.6160694491466056, 0.6988646533239861, 0.9631421704454322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 403}], {
             RGBColor[
             0.49577350357874894`, 0.5977954659805172, 0.9546135407315175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 405}], {
             RGBColor[
             0.5584883458673549, 0.6521159102312817, 0.9586096750255899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 450}], {
             RGBColor[
             0.5943598492809108, 0.6812398221466864, 0.9614331112191201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 469}], {
             RGBColor[
             0.46613821739258415`, 0.5684105776762824, 0.9528612781897959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 491}], {
             RGBColor[
             0.6609582922076155, 0.7350649084324455, 0.9668418036269872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 203}], {
             RGBColor[
             0.3615467449443245, 0.487575351428169, 0.9442584167779868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 221}], {
             RGBColor[
             0.32968334553891, 0.45997687636421886`, 0.9422281091435717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 223}], {
             RGBColor[
             0.6519412922599508, 0.7188328586851875, 0.9011286840013772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 258}], {
             RGBColor[
             0.29351848394419955`, 0.42510831997104415`, 0.9400534929261464]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 289}], {
             RGBColor[
             0.33167260255048114`, 0.4616998708046772, 0.9423548628413181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 297}], {
             RGBColor[
             0.2886409600802685, 0.41998173313717807`, 0.9397757251577453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 381}], {
             RGBColor[
             0.37778935747774167`, 0.5016438860271719, 0.945293381685838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 439}], {
             RGBColor[
             0.3512202751035427, 0.4786310822755493, 0.9436004232510711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 187}], {
             RGBColor[
             0.6082220239976153, 0.6740790527346303, 0.9108540504114397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.28168222466879256`, 0.4111811468464766, 0.9394338640359994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 322}], {
             RGBColor[
             0.539377868905921, 0.6207406176964461, 0.9609102175309139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 364}], {
             RGBColor[
             0.317912973932169, 0.442562400848007, 0.9417424553414682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 437}], {
             RGBColor[
             0.3051674428362324, 0.4315228624217262, 0.9409303213704656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 494}], {
             RGBColor[
             0.3438044354675034, 0.4648897006467083, 0.94341947510814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 166}], {
             RGBColor[
             0.3452481900949479, 0.47345836240682476`, 0.9432198872752308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 227}], {
             RGBColor[
             0.37762380976204457`, 0.5015004969165051, 0.9452828331317817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 309}], {
             RGBColor[
             0.39519265484072663`, 0.5167177474878304, 0.9464023044046757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 348}], {
             RGBColor[
             0.4968807356151414, 0.5998354383285824, 0.9542520797838062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 396}], {
             RGBColor[
             0.3425956951887217, 0.47116090463732196`, 0.9430508726453152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 428}], {
             RGBColor[
             0.3136906733738075, 0.44250452080874203`, 0.9413416273792801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 443}], {
             RGBColor[
             0.3422550208256281, 0.4708658296268017, 0.9430291651761453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 182}], {
             RGBColor[
             0.33515179918785437`, 0.46471337606246244`, 0.9425765541745187]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 268}], {
             RGBColor[
             0.3203714064109941, 0.4519113427232873, 0.9416347606165654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 275}], {
             RGBColor[
             0.45796533451270655`, 0.5672556007925122, 0.951461106822642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 282}], {
             RGBColor[
             0.29484448003943753`, 0.42605533224979986`, 0.9401453620863214]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 285}], {
             RGBColor[
             0.2939335464735249, 0.4250978833155017, 0.9400934857673482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 324}], {
             RGBColor[
             0.6343209347373799, 0.7064914315895977, 0.957995841866986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 353}], {
             RGBColor[
             0.35313641613674157`, 0.4802907473304576, 0.9437225180633295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 441}], {
             RGBColor[
             0.5356378802435476, 0.628667537657203, 0.9587012455460437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 481}], {
             RGBColor[
             0.39210834686617435`, 0.5137899313975736, 0.9462766035130123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 210}], {
             RGBColor[
             0.3315465533353126, 0.46159069330991603`, 0.9423468310967884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 227}], {
             RGBColor[
             0.36507992838896985`, 0.4906356173449575, 0.9444835481028082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 243}], {
             RGBColor[
             0.3205168560760495, 0.45199880671334813`, 0.941645438843954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 309}], {
             RGBColor[
             0.3826487734676519, 0.5058528679162828, 0.9456030193757021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 320}], {
             RGBColor[
             0.36831026683759194`, 0.4934335741476227, 0.9446893824122783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 348}], {
             RGBColor[
             0.4843368542420667, 0.5889705587570347, 0.9534527947548327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 428}], {
             RGBColor[
             0.3011467920007328, 0.43163964123719434`, 0.9405423423503065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 495}], {
             RGBColor[
             0.2879599354156023, 0.41777941887122416`, 0.9397913703759895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 210}], {
             RGBColor[
             0.3737838229234033, 0.49817449332022434`, 0.9450381525659906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 326}], {
             RGBColor[
             0.4230275258578019, 0.5408269137415254, 0.9481759177724738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 434}], {
             RGBColor[
             0.5155458037115973, 0.6166010716749364, 0.955275926466234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 474}], {
             RGBColor[
             0.3271890950901357, 0.45120150463719955`, 0.9423113844357144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 495}], {
             RGBColor[
             0.330197205003693, 0.45436321888153247`, 0.9424826918451916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 200}], {
             RGBColor[
             0.3231163730506393, 0.4495162128585838, 0.9419844187312161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 213}], {
             RGBColor[
             0.2592377240497772, 0.38980566297032015`, 0.9380745769255656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 254}], {
             RGBColor[
             0.4825509150906905, 0.5796906487666152, 0.9547412088194274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 261}], {
             RGBColor[
             0.4652535943065763, 0.5661778503055583, 0.9530171735363199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 315}], {
             RGBColor[
             0.34627389117402974`, 0.46957409112636095`, 0.9434599953086493]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 368}], {
             RGBColor[
             0.24979672308546313`, 0.3798825723627919, 0.9375369258873573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 401}], {
             RGBColor[
             0.2949148282352641, 0.4250894521903624, 0.9401874412332274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 500}], {
             RGBColor[
             0.3379741404312302, 0.4623852641905496, 0.9429311425304996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 204}], {
             RGBColor[
             0.3636444243099394, 0.48637712670923217`, 0.9445024777005255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 219}], {
             RGBColor[
             0.3476632153025672, 0.4725350067059663, 0.943484169194204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 244}], {
             RGBColor[
             0.2943065434709905, 0.4263201393497572, 0.9400843292465482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 274}], {
             RGBColor[
             0.39079710831478975`, 0.5084796548894253, 0.9466238019660547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 334}], {
             RGBColor[
             0.36959625604421514`, 0.4912678479286621, 0.9449547932140343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 337}], {
             RGBColor[
             0.2811864135093034, 0.41287512721957054`, 0.9393245223201094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 340}], {
             RGBColor[
             0.31656728292503766`, 0.44560127300755564`, 0.9415027638801612]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 361}], {
             RGBColor[
             0.38027095250881143`, 0.49993404740821695`, 0.9457951444224288]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 363}], {
             RGBColor[
             0.3372358569763514, 0.46350335301806633`, 0.9428197471422084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 370}], {
             RGBColor[
             0.2725495669642859, 0.4037972538930579, 0.9388326666864402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 498}], {
             RGBColor[
             0.264534800140268, 0.3953732257954482, 0.9383762375725972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 171}], {
             RGBColor[
             0.3665002204510787, 0.48947991409634295`, 0.9446614069353397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 238}], {
             RGBColor[
             0.42827725504854364`, 0.5453739653074847, 0.9485104258743545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 265}], {
             RGBColor[
             0.5847811758666781, 0.6725205231773401, 0.9612876679563881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 266}], {
             RGBColor[
             0.35981742546159057`, 0.48245587284871605`, 0.9442808316469976]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 328}], {
             RGBColor[
             0.33750133416974276`, 0.45900024597907413`, 0.9430099632616255]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 374}], {
             RGBColor[
             0.6581106937355734, 0.5246967407905523, 0.579966309031845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 433}], {
             RGBColor[
             0.4144753641938951, 0.5334194611523928, 0.9476309815936292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 216}], {
             RGBColor[
             0.5417716887814026, 0.6294375602705263, 0.9600923415228713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 238}], {
             RGBColor[
             0.34471759890653536`, 0.47061290214085183`, 0.9432734375521373]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 265}], {
             RGBColor[
             0.5012215197246698, 0.5977594600107073, 0.9560506796341709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 343}], {
             RGBColor[
             0.34732124947266496`, 0.4728680533979509, 0.9434393398638934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 385}], {
             RGBColor[
             0.35481770686602043`, 0.4793611080091713, 0.943917007500141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 391}], {
             RGBColor[
             0.34406463572305035`, 0.47004733825020095`, 0.9432318313154784]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 433}], {
             RGBColor[
             0.3309157080518868, 0.4586583979857599, 0.942393993271412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 465}], {
             RGBColor[
             0.3391288790460247, 0.4657722338949052, 0.9429173292645365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 303}], {
             RGBColor[
             0.45029990678151016`, 0.5612511046311405, 0.9507972444509347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 366}], {
             RGBColor[
             0.306131473600877, 0.43717417240344525`, 0.9408153996733545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 448}], {
             RGBColor[
             0.4480790117319043, 0.5594480819796885, 0.950622407457223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 473}], {
             RGBColor[
             0.3252790166328662, 0.4561620680338111, 0.9419474692002736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 241}], {
             RGBColor[
             0.44794581932769345`, 0.5565119192521919, 0.9509738056063576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 417}], {
             RGBColor[
             0.39578318199716717`, 0.5141639403672382, 0.9468673717176621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 461}], {
             RGBColor[
             0.3213491481487429, 0.45100798090621497`, 0.9417611460435369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 493}], {
             RGBColor[
             0.41609580782035904`, 0.5306546450838706, 0.9484664560300637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 215}], {
             RGBColor[
             0.30792697984049405`, 0.4392174814203882, 0.9409119348484445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 229}], {
             RGBColor[
             0.5836878872963336, 0.6666330285465308, 0.9633340493608302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 294}], {
             RGBColor[
             0.33376343812770215`, 0.4635108474932145, 0.9424880890354452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 338}], {
             RGBColor[
             0.39382920085577244`, 0.5153597934539623, 0.94636433159647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 356}], {
             RGBColor[
             0.298445948378546, 0.4292523162217663, 0.9403720041326156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 390}], {
             RGBColor[
             0.48194952909063554`, 0.586899845690572, 0.9533014866305167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 430}], {
             RGBColor[
             0.4140699775357322, 0.5317921677993519, 0.9479577596811245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 309}], {
             RGBColor[
             0.3884592764628044, 0.5108856335663118, 0.9459732594885273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 320}], {
             RGBColor[
             0.37412076983274445`, 0.49846633979765165`, 0.9450596225251033]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 337}], {
             RGBColor[
             0.3152816757053011, 0.44542185880904034`, 0.9413866436297151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 348}], {
             RGBColor[
             0.49014735723721914`, 0.5940033244070637, 0.9538230348676577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 361}], {
             RGBColor[
             0.4143662147048091, 0.5324807789976868, 0.9478572657320347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 370}], {
             RGBColor[
             0.30664482916028357`, 0.4363439854825277, 0.9408947879960459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 375}], {
             RGBColor[
             0.3027863212471509, 0.4322884490222936, 0.9406750516785438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 197}], {
             RGBColor[
             0.33217650049925984`, 0.4609768574663575, 0.9424294244450413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 237}], {
             RGBColor[
             0.3079362887176785, 0.4354988579657204, 0.94104898024426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 345}], {
             RGBColor[
             0.4439741551858457, 0.557164669903851, 0.9500093899313122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 426}], {
             RGBColor[
             0.4562718063215898, 0.5671484570987184, 0.9509775060764984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 448}], {
             RGBColor[
             0.4673977005642639, 0.5761809592607451, 0.9518533772267752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 245}], {
             RGBColor[
             0.2876234146213934, 0.4196408235178201, 0.9396911000107532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 438}], {
             RGBColor[
             0.27413102039095727`, 0.40545946171442804`, 0.9389227281195384]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 455}], {
             RGBColor[
             0.2796399175826898, 0.4112496619471946, 0.9392364516649245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 357}], {
             RGBColor[
             0.4581558741869891, 0.5617492416982007, 0.9521330307727921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 420}], {
             RGBColor[
             0.3092985259081349, 0.43831273267591875`, 0.9410759530258542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 439}], {
             RGBColor[
             0.3256059828022444, 0.45243743220098087`, 0.9421150497590289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 236}], {
             RGBColor[
             0.7375812785234449, 0.792228523875544, 0.9134404177124527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 254}], {
             RGBColor[
             0.5983375037686469, 0.6837911900710816, 0.9622097109790113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 276}], {
             RGBColor[
             0.44124164769140495`, 0.5556424063982612, 0.9496019398923315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 283}], {
             RGBColor[
             0.4537924937954252, 0.5665133184696963, 0.9504016687078023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 292}], {
             RGBColor[
             0.6359032928685773, 0.7131378700265187, 0.965953917764234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 315}], {
             RGBColor[
             0.46206047985198617`, 0.5736746324308273, 0.9509284974682333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 325}], {
             RGBColor[
             0.6811378011789644, 0.7489085846054411, 0.9703475200454479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 347}], {
             RGBColor[
             0.4106279204183106, 0.529126334524979, 0.947651260261146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 368}], {
             RGBColor[
             0.3655833117634195, 0.48398311366725816`, 0.9450054280469413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 386}], {
             RGBColor[
             0.38034901421394307`, 0.49950280314236606`, 0.9458463129575994]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 401}], {
             RGBColor[
             0.4107014169132205, 0.5291899934948288, 0.9476559433928113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 216}], {
             RGBColor[
             0.74736580281138, 0.80256711243751, 0.9754540967598744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 281}], {
             RGBColor[
             0.5286366488552914, 0.6249686032210784, 0.9572540768723916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 288}], {
             RGBColor[
             0.8204234502304203, 0.8603804940182098, 0.9726122266656774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 343}], {
             RGBColor[
             0.5529153635026425, 0.6459976055649346, 0.9588010951008964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 392}], {
             RGBColor[
             0.4784316035786896, 0.5772294309516197, 0.9542108186886828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 465}], {
             RGBColor[
             0.5447229930760021, 0.6389017860618889, 0.9582790845015396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 235}], {
             RGBColor[
             0.31959371799795877`, 0.4507903584376488, 0.9416015881259816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 239}], {
             RGBColor[
             0.5330406938848583, 0.6272256557468291, 0.9581939107456591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 262}], {
             RGBColor[
             0.6255744455995673, 0.5844892925475639, 0.5968744052887892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 296}], {
             RGBColor[
             0.29573481764204385`, 0.42571314142192784`, 0.9402428590467923]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 332}], {
             RGBColor[
             0.37237117867547953`, 0.4969509318742372, 0.9449481401236651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 344}], {
             RGBColor[
             0.5508781264533797, 0.6411603936388667, 0.9599717793238046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 387}], {
             RGBColor[
             0.4518469525614186, 0.5626637381883132, 0.9508757445938686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 393}], {
             RGBColor[
             0.33522835400695256`, 0.46477968399900815`, 0.9425814321798969]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 424}], {
             RGBColor[
             0.31554582493427585`, 0.4465357661764743, 0.941371066604326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 275}], {
             RGBColor[
             0.4716593758800529, 0.5791166911423757, 0.9523336790294039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 282}], {
             RGBColor[
             0.30853852140678395`, 0.43791642259966346`, 0.9410179342930833]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 324}], {
             RGBColor[
             0.6480149761047262, 0.7183525219394613, 0.958868414073748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 441}], {
             RGBColor[
             0.5493319216108941, 0.6405286280070666, 0.9595738177528057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 346}], {
             RGBColor[
             0.6111327928659824, 0.6902275246158929, 0.9651642520510662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 404}], {
             RGBColor[
             0.45406559724917184`, 0.5656131230894246, 0.9507331563352998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 407}], {
             RGBColor[
             0.3369526799615584, 0.4651260128086463, 0.9427333091579388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 408}], {
             RGBColor[
             0.3368863314318415, 0.46505627629717405`, 0.9427295307073253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 192}], {
             RGBColor[
             0.3670552762132072, 0.49234656434644347`, 0.9446094155194371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 225}], {
             RGBColor[
             0.6261377561787732, 0.7028059701411351, 0.9663128292219156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 249}], {
             RGBColor[
             0.4449969804835324, 0.5587355292919105, 0.9498853126236007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 260}], {
             RGBColor[
             0.346771365454237, 0.47379555426236214`, 0.9433529023769218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 280}], {
             RGBColor[
             0.5187757386365325, 0.618632448855694, 0.9556934467259008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 424}], {
             RGBColor[
             0.34561518087125964`, 0.4725803309593164, 0.9432870593753431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 440}], {
             RGBColor[
             0.3548197546797494, 0.4817487705693557, 0.943829778906772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 453}], {
             RGBColor[
             0.6944009920407144, 0.7525844640809473, 0.7337839999165815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 470}], {
             RGBColor[
             0.41491602718809806`, 0.5338011412896053, 0.9476590602499568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 193}], {
             RGBColor[
             0.3489399252858337, 0.4745762372325789, 0.9435312701376823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 196}], {
             RGBColor[
             0.4141373149405546, 0.5286384015467823, 0.9483510762943045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 318}], {
             RGBColor[
             0.5015717954652509, 0.5984799080353692, 0.9560148552737918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 321}], {
             RGBColor[
             0.3447445388856939, 0.47094240439902957`, 0.9432639438261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 330}], {
             RGBColor[
             0.2630562911548311, 0.39381921910886997`, 0.9382920386731346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 335}], {
             RGBColor[
             0.40382753435356683`, 0.5202684572159431, 0.9475394526005261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 350}], {
             RGBColor[
             0.40281762814375266`, 0.5194485698590596, 0.9474599490842812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 383}], {
             RGBColor[
             0.29653334151250166`, 0.4290057216023681, 0.9401985071661461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 409}], {
             RGBColor[
             0.32953204540702685`, 0.4577661071499622, 0.9422946171935191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 482}], {
             RGBColor[
             0.30331710998111594`, 0.4350600476850036, 0.9406242246891373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 496}], {
             RGBColor[
             0.30323063089748153`, 0.43498514384932463`, 0.9406187143183986]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 191}], {
             RGBColor[
             0.38194260738330454`, 0.5052412223469606, 0.9455580230972457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 202}], {
             RGBColor[
             0.4058129112860275, 0.5259164798311405, 0.9470790177542462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 212}], {
             RGBColor[
             0.40795121979340965`, 0.5277685751857244, 0.9472152688815046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 295}], {
             RGBColor[
             0.38012444184635064`, 0.5036664187425081, 0.9454421711969716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 300}], {
             RGBColor[
             0.34625876119412746`, 0.46831894418653885`, 0.9435045084857113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 389}], {
             RGBColor[
             0.7178046805026284, 0.7759874081535633, 0.9092579933134415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 414}], {
             RGBColor[
             0.38095869208171795`, 0.5043890043657472, 0.9454953288842707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 456}], {
             RGBColor[
             0.31488361021579375`, 0.4353416712088416, 0.9417177400528716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 485}], {
             RGBColor[
             0.3993193728813489, 0.5202921032397378, 0.9466652552291106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 322}], {
             RGBColor[
             0.9169397522878244, 0.9350508595734004, 0.935317142116612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 494}], {
             RGBColor[
             0.7213663188494067, 0.7791999425236625, 0.9178263996938381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 304}], {
             RGBColor[
             0.5550190252788982, 0.6381504279722123, 0.9616540154947558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 310}], {
             RGBColor[
             0.34756664069421483`, 0.47184618104605436`, 0.9435001740615947]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 483}], {
             RGBColor[
             0.3791425434751599, 0.4982350504528308, 0.9457775766911349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 266}], {
             RGBColor[
             0.30113964152598366`, 0.43163212563486675`, 0.9405419351413478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 364}], {
             RGBColor[
             0.3689350579852496, 0.49397473683680754`, 0.9447291935517259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 374}], {
             RGBColor[
             0.5994329097999666, 0.473872993576703, 0.576227412526195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 437}], {
             RGBColor[
             0.35618952688931305`, 0.48293519841052673`, 0.9439170595807235]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 195}], {
             RGBColor[
             0.7393509489165082, 0.7936848922911501, 0.9144020270134654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 224}], {
             RGBColor[
             0.6937971170825409, 0.7590291051744468, 0.971524676504785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 263}], {
             RGBColor[
             0.5139765735855212, 0.6163083626743252, 0.9548812651123286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 323}], {
             RGBColor[
             0.399431076486923, 0.5191241094670447, 0.946972618324951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 342}], {
             RGBColor[
             0.41148409203729686`, 0.5297691242114015, 0.9477331088348426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 351}], {
             RGBColor[
             0.5511101772616818, 0.6464550949884142, 0.9578045584185884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 356}], {
             RGBColor[
             0.3807034271254411, 0.4994401625865766, 0.9459061063988892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 395}], {
             RGBColor[
             0.42527255261217844`, 0.5417119957331848, 0.9486116973500172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 452}], {
             RGBColor[
             0.46843309156351653`, 0.5790954852610706, 0.9513618487266304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 463}], {
             RGBColor[
             0.45689098000294437`, 0.5690982883506979, 0.9506263955842792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 212}], {
             RGBColor[
             0.34106790105253404`, 0.46983760614572234`, 0.9429535229539326]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 218}], {
             RGBColor[
             0.3064504318221118, 0.4388455056266838, 0.9407846431488385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 287}], {
             RGBColor[
             0.28021787938849874`, 0.41127342977906794`, 0.9392907380953279]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 295}], {
             RGBColor[
             0.31324112310547503`, 0.445735449702506, 0.9411804252693996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 299}], {
             RGBColor[
             0.38401579915966616`, 0.5070369168619965, 0.945690125043984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 300}], {
             RGBColor[
             0.27937544245325185`, 0.4103879751465368, 0.9392427625581393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 301}], {
             RGBColor[
             0.2795496338000646, 0.4105710612964062, 0.9392526824976473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 389}], {
             RGBColor[
             0.6509213617617529, 0.7180564391135611, 0.9049962473858695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 451}], {
             RGBColor[
             0.3522396574071085, 0.47951401999125376`, 0.9436653773900499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 456}], {
             RGBColor[
             0.24800029147491814`, 0.37741070216883954`, 0.9374559941252996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[
             0.5977739812455329, 0.6782386938987418, 0.9645055145642709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 249}], {
             RGBColor[
             0.41663320555029204`, 0.5341682530495171, 0.9480779979659559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 260}], {
             RGBColor[
             0.31840759052099665`, 0.4492282780199688, 0.9415455877192771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 280}], {
             RGBColor[
             0.4904119637032921, 0.5940651726133007, 0.9538861320682561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 327}], {
             RGBColor[
             0.3203461025423854, 0.45126577706320936`, 0.9416559831111238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 470}], {
             RGBColor[
             0.3865522522548577, 0.509233865047212, 0.9458517455923121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 483}], {
             RGBColor[
             0.4136936564753471, 0.5317817946853001, 0.947846585894853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 196}], {
             RGBColor[
             0.47682520402508216`, 0.5850152209314667, 0.9522693443934851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 202}], {
             RGBColor[
             0.387213855409118, 0.5098069124462908, 0.9458939023602688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 232}], {
             RGBColor[
             0.39533949814882224`, 0.5168449357807436, 0.9464116611304191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 330}], {
             RGBColor[
             0.32574418023935864`, 0.4501960384935544, 0.9422103067723153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 350}], {
             RGBColor[
             0.4655055172282802, 0.575825389243744, 0.9513782171834619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 354}], {
             RGBColor[
             0.4115803163068297, 0.5309119161819544, 0.9474465117022557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 376}], {
             RGBColor[
             0.4599352089957908, 0.571303162081083, 0.950939702114689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 414}], {
             RGBColor[
             0.3623596362048085, 0.4882794369808975, 0.9443102134902934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 415}], {
             RGBColor[
             0.5225432526984446, 0.6221311924191243, 0.9558684366557826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 485}], {
             RGBColor[
             0.3807203170044394, 0.5041825358548883, 0.9454801398351333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 496}], {
             RGBColor[
             0.3659185199820091, 0.49136196323400905`, 0.9445369824175793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 228}], {
             RGBColor[
             0.6407431099746377, 0.7140518029388985, 0.9678900796440478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 388}], {
             RGBColor[
             0.45807974263806517`, 0.5690408108619018, 0.9510025180703674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 490}], {
             RGBColor[
             0.4707448136715175, 0.5793228860818065, 0.9519995588558046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 224}], {
             RGBColor[
             0.9408114337906149, 0.9539739140694404, 0.9327490138608432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 263}], {
             RGBColor[
             0.7609908902935952, 0.8112531715693189, 0.9161056024683869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 296}], {
             RGBColor[
             0.621277280818095, 0.6876156365034234, 0.9067636689140304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 323}], {
             RGBColor[
             0.6464453931949969, 0.7140689183620383, 0.9081969556810092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 342}], {
             RGBColor[
             0.6584984087453709, 0.7247139331063952, 0.9089574461909009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 351}], {
             RGBColor[
             0.7981244939697558, 0.8413999038834079, 0.9190288957746465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 395}], {
             RGBColor[
             0.6722868693202525, 0.7366568046281785, 0.9098360347060754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 447}], {
             RGBColor[
             0.7327135071811242, 0.7882963180770227, 0.9138795032863058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 453}], {
             RGBColor[
             0.9898740992797816, 0.9884423943796008, 0.6983888170128024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 463}], {
             RGBColor[
             0.7039052967110184, 0.7640430972456915, 0.9118507329403374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 318}], {
             RGBColor[
             0.6294570742044994, 0.708918891734257, 0.9647529295295946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 321}], {
             RGBColor[
             0.4726298176249424, 0.5813813880979174, 0.9520020180819028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 330}], {
             RGBColor[
             0.3909415698940796, 0.5042582028077578, 0.9470301129289374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 335}], {
             RGBColor[
             0.5317128130928153, 0.6307074409148309, 0.9562775268563288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 350}], {
             RGBColor[
             0.5307029068830011, 0.6298875535579475, 0.956198023340084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 354}], {
             RGBColor[
             0.47677770596155067`, 0.5849740804961578, 0.9522663178588778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 383}], {
             RGBColor[
             0.42441862025175014`, 0.5394447053012559, 0.9489365814219488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 414}], {
             RGBColor[
             0.42755702585952937`, 0.5423416012951009, 0.9491300196469155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 479}], {
             RGBColor[
             0.5003117489026729, 0.6052146424034524, 0.9538055200573927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 482}], {
             RGBColor[
             0.4312023887203644, 0.5454990313838914, 0.9493622989449401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 496}], {
             RGBColor[
             0.43111590963673, 0.5454241275482125, 0.9493567885742014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 237}], {
             RGBColor[
             0.27196518540109293`, 0.40318303181821097`, 0.9387993870209314]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 270}], {
             RGBColor[
             0.6406909814540769, 0.7083995872742594, 0.9177530145880504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 345}], {
             RGBColor[
             0.4080030518692602, 0.5248488437563417, 0.9477597967079836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 375}], {
             RGBColor[
             0.278726362482399, 0.4102894576140501, 0.9391844260534465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 426}], {
             RGBColor[
             0.4203007030050043, 0.534832630951209, 0.9487279128531698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 448}], {
             RGBColor[
             0.43142659724767835`, 0.5438651331132356, 0.9496037840034466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 489}], {
             RGBColor[
             0.31428006901342037`, 0.445475868014124, 0.9412890796559565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 223}], {
             RGBColor[
             0.6532315303750404, 0.719950398091225, 0.901210896833158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 373}], {
             RGBColor[
             0.3958700355285574, 0.5167827225190543, 0.9465896242876051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 480}], {
             RGBColor[
             0.33091160098453376`, 0.46104072949730446`, 0.9423063724944631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 208}], {
             RGBColor[
             0.2987672851204557, 0.4211962851698018, 0.9406976410544894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 220}], {
             RGBColor[
             0.30546998721582397`, 0.42700182883720705`, 0.9411247313050395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 349}], {
             RGBColor[
             0.24338254219648517`, 0.37314086156591875`, 0.9371716477746602]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 359}], {
             RGBColor[
             0.23678666489414377`, 0.36620817631838276`, 0.9367960223200179]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 371}], {
             RGBColor[
             0.2461131059371499, 0.37558988163721774`, 0.9373425633171917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 382}], {
             RGBColor[
             0.2829193808534597, 0.4074696270325586, 0.9396878266083479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 397}], {
             RGBColor[
             0.24160887437382003`, 0.3712766242272625, 0.9370706400160659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 419}], {
             RGBColor[
             0.24711312771504196`, 0.3764560502386719, 0.9374062838205943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 427}], {
             RGBColor[
             0.3889959031268905, 0.4953904115678087, 0.9475403612382202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 429}], {
             RGBColor[
             0.28863196181625994`, 0.41241757753986863`, 0.9400518272158606]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 213}], {
             RGBColor[
             0.3252287493517614, 0.45173645428345616`, 0.9421047154365843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 243}], {
             RGBColor[
             0.3487184008914247, 0.4764255673815695, 0.9434424163419428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 254}], {
             RGBColor[
             0.5485419403926748, 0.6416214400797513, 0.958771347330446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 259}], {
             RGBColor[
             0.373053586941258, 0.4975419996152178, 0.9449916225749306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 401}], {
             RGBColor[
             0.36090585353724836`, 0.48702024350349843`, 0.944217579744246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 450}], {
             RGBColor[
             0.45705088223579554`, 0.568350053585297, 0.9508815916711502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 454}], {
             RGBColor[
             0.38730110240461035`, 0.5098824814086248, 0.9458994616616723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 469}], {
             RGBColor[
             0.32882925034746896`, 0.455520809114893, 0.942309758641826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 471}], {
             RGBColor[
             0.3983537095954314, 0.5194556942371242, 0.9466037240184345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 475}], {
             RGBColor[
             0.37111128646547054`, 0.4958596765659511, 0.9448678609061223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 500}], {
             RGBColor[
             0.4039651657332144, 0.5243160555036857, 0.9469612810415182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 222}], {
             RGBColor[
             0.47019924860412454`, 0.5761190987000101, 0.95258541995733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 246}], {
             RGBColor[
             0.6440466812479992, 0.7118569099767826, 0.9161252648810104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 256}], {
             RGBColor[
             0.4112367163365952, 0.5282506587734214, 0.9479436734303578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 271}], {
             RGBColor[
             0.3073474310927581, 0.44007145534874836`, 0.940825358545686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 312}], {
             RGBColor[
             0.3248098268615882, 0.45519650487817787`, 0.9419380469626857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 333}], {
             RGBColor[
             0.5600085236078682, 0.28480610908069237`, 0.5523837890180403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 400}], {
             RGBColor[
             0.3497942207574293, 0.4768367311186056, 0.9435300304488965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 442}], {
             RGBColor[
             0.6371619179154364, 0.7069221791429181, 0.9367319480589114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 444}], {
             RGBColor[
             0.3470137524495589, 0.4744284292207288, 0.9433528614669906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 492}], {
             RGBColor[
             0.3109915511086083, 0.4432278089476803, 0.9410575586507273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 211}], {
             RGBColor[
             0.3613598569704315, 0.4874134784584456, 0.944246508441549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 414}], {
             RGBColor[
             0.3379456772435653, 0.46713329280992505`, 0.9427545776136992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 485}], {
             RGBColor[
             0.35630635804319627`, 0.48303639168391577`, 0.9439245039585391]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 497}], {
             RGBColor[
             0.33761407993130804`, 0.46684607988461335`, 0.9427334485261822]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 221}], {
             RGBColor[
             0.37460370832173484`, 0.4988846368436209, 0.945090394938576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 258}], {
             RGBColor[
             0.3384388467270244, 0.4640160804504462, 0.9429157787211507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 289}], {
             RGBColor[
             0.376592965333306, 0.5006076312840793, 0.9452171486363226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 291}], {
             RGBColor[
             0.40240201567983463`, 0.5229621334936541, 0.9468616785023563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 297}], {
             RGBColor[
             0.33356132286309337`, 0.4588894936165801, 0.9426380109527497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 381}], {
             RGBColor[
             0.4227097202605666, 0.5405516465065738, 0.9481556674808423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 397}], {
             RGBColor[
             0.3553789282373947, 0.481821180181048, 0.9438804913025616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 419}], {
             RGBColor[
             0.36088318157861665`, 0.4870006061924574, 0.94421613510709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 439}], {
             RGBColor[
             0.39614063788636755`, 0.5175388427549513, 0.9464627090460754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 219}], {
             RGBColor[
             0.4351728492923238, 0.5513465824588031, 0.9489498070420337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 244}], {
             RGBColor[
             0.38181617746074714`, 0.5051317151025939, 0.9455499670943779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 274}], {
             RGBColor[
             0.4783067423045464, 0.587291230642262, 0.9520894398138844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 334}], {
             RGBColor[
             0.45710589003397173`, 0.5700794236814988, 0.950420431061864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 337}], {
             RGBColor[
             0.36869604749905993`, 0.49168670297240724`, 0.9447901601679392]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 340}], {
             RGBColor[
             0.4040769169147942, 0.5244128487603923, 0.9469684017279908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 361}], {
             RGBColor[
             0.467780586498568, 0.5787456231610537, 0.9512607822702586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 362}], {
             RGBColor[
             0.5726414253343607, 0.6630833288628731, 0.960058022317742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 363}], {
             RGBColor[
             0.4247454909661079, 0.542314928770903, 0.9482853849900381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 370}], {
             RGBColor[
             0.3600592009540424, 0.4826088296458946, 0.9442983045342698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 498}], {
             RGBColor[
             0.3520444341300246, 0.4741848015482849, 0.943841875420427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 228}], {
             RGBColor[
             0.6127217207992544, 0.6897810840311523, 0.966104581504134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 252}], {
             RGBColor[
             0.3766714508821293, 0.5006756115216716, 0.9452221496660915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 388}], {
             RGBColor[
             0.43005835346268173`, 0.5447700919541556, 0.9492170199304535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 432}], {
             RGBColor[
             0.42729655802823563`, 0.5425279420030058, 0.9489996012770638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 490}], {
             RGBColor[
             0.4427234244961341, 0.5550521671740603, 0.9502140607158908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 266}], {
             RGBColor[
             0.2638750814051056, 0.3946798195762088, 0.9383386675665961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 410}], {
             RGBColor[
             0.2780083817409559, 0.4095348143321852, 0.9391435381123787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 218}], {
             RGBColor[
             0.6134910997507274, 0.6883581436723993, 0.9666882327090249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 287}], {
             RGBColor[
             0.5872585473171144, 0.6607860678247834, 0.9651943276555144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 295}], {
             RGBColor[
             0.6202817910340906, 0.6952480877482214, 0.9670840148295861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 336}], {
             RGBColor[
             0.6295762605208408, 0.703298490064025, 0.967676250206505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 389}], {
             RGBColor[
             0.9579620296903684, 0.9675690771592766, 0.9308998369460559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 409}], {
             RGBColor[
             0.6509763395562038, 0.7218341629252096, 0.9690398443192916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 456}], {
             RGBColor[
             0.5550409594035337, 0.6269233402145551, 0.963359583685486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 458}], {
             RGBColor[
             0.6255557522065843, 0.6998161278388395, 0.9674200669719166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[
             0.34450907798390545`, 0.4692738096664625, 0.9433025684891445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 289}], {
             RGBColor[
             0.38266319659018705`, 0.5058653605000956, 0.9456039384043162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 314}], {
             RGBColor[
             0.4129381583713683, 0.5320880107311312, 0.9475330321979155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 349}], {
             RGBColor[
             0.3632228273169409, 0.4889431467357205, 0.9443682888291496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 359}], {
             RGBColor[
             0.35662695001459943`, 0.4820104614881845, 0.9439926633745073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 397}], {
             RGBColor[
             0.3614491594942757, 0.4870789093970643, 0.9442672810705552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 427}], {
             RGBColor[
             0.5088361882473461, 0.6111926967376105, 0.9547370022927095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 472}], {
             RGBColor[
             0.4901522612087408, 0.5960242430663496, 0.9532661351147507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 214}], {
             RGBColor[
             0.7620343382397541, 0.8119403271234573, 0.9095006866280755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 233}], {
             RGBColor[
             0.6159550820654325, 0.6817656371160807, 0.8997822624411447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 273}], {
             RGBColor[
             0.6861801601705063, 0.7485087039555498, 0.9040402687587413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 421}], {
             RGBColor[
             0.6808777832483145, 0.7439160515707604, 0.9037024059899671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 423}], {
             RGBColor[
             0.6763215025001792, 0.7399696301920545, 0.9034120838096568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 477}], {
             RGBColor[
             0.6295466665706035, 0.6960512541872459, 0.9005562830717668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 227}], {
             RGBColor[
             0.36392217300240925`, 0.4896328278195964, 0.9444097769533395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 243}], {
             RGBColor[
             0.3193591006894889, 0.4509960171879871, 0.9415716676944852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 326}], {
             RGBColor[
             0.3796325008831507, 0.503240324205856, 0.9454108251538028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 348}], {
             RGBColor[
             0.48317909885550614`, 0.5879677692316736, 0.9533790236053639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 428}], {
             RGBColor[
             0.29998903661417226`, 0.4306368517118333, 0.9404685712008378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 434}], {
             RGBColor[
             0.4721507787369461, 0.5790144821392671, 0.9525108338475632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 469}], {
             RGBColor[
             0.29946995014553324`, 0.4300912589213106, 0.9404390099943685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 474}], {
             RGBColor[
             0.2837940701154845, 0.41361491510153015`, 0.9395462918170434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 495}], {
             RGBColor[
             0.28680218002904173`, 0.41677662934586307`, 0.9397175992265208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 464}], {
             RGBColor[
             0.3686661932044579, 0.4937418596772226, 0.9447120617256417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 485}], {
             RGBColor[
             0.3548663185657529, 0.481789101867043, 0.9438327459164134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 497}], {
             RGBColor[
             0.3361740404538647, 0.4655987900677405, 0.9426416904840564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 287}], {
             RGBColor[
             0.30622649179860384`, 0.43380078261783184`, 0.9409479838795869]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 295}], {
             RGBColor[
             0.33924973551558013`, 0.46826280254126984`, 0.9428376710536586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 299}], {
             RGBColor[
             0.41002441156977126`, 0.5295642697007603, 0.9473473708282429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 300}], {
             RGBColor[
             0.30538405486335696`, 0.43291532798530064`, 0.9409000083423983]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 301}], {
             RGBColor[
             0.3055582462101697, 0.43309841413517003`, 0.9409099282819062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 389}], {
             RGBColor[
             0.676929974171858, 0.740583791952325, 0.9066534931701284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 451}], {
             RGBColor[
             0.3782482698172136, 0.5020413728300176, 0.9453226231743088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 456}], {
             RGBColor[
             0.27400890388502325`, 0.3999380550076034, 0.9391132399095585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 254}], {
             RGBColor[
             0.48466329139181263`, 0.5819108901914877, 0.9548615055247955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 259}], {
             RGBColor[
             0.30917493794039586`, 0.4378314497269542, 0.9410817807692802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 261}], {
             RGBColor[
             0.46736597060769847`, 0.5683980917304308, 0.953137470241688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 315}], {
             RGBColor[
             0.3483862674751519, 0.4717943325512333, 0.9435802920140175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 368}], {
             RGBColor[
             0.25190909938658523`, 0.38210281378766425`, 0.9376572225927254]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 401}], {
             RGBColor[
             0.2970272045363862, 0.42730969361523485`, 0.9403077379385956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 450}], {
             RGBColor[
             0.39317223323493344`, 0.5086395036970335, 0.9469717498654997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 454}], {
             RGBColor[
             0.3234224534037482, 0.4501719315203612, 0.9419896198560217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 471}], {
             RGBColor[
             0.33447506059456933`, 0.4597451443488606, 0.9426938822127839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 475}], {
             RGBColor[
             0.3072326374646084, 0.4361491266776875, 0.9409580191004718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 500}], {
             RGBColor[
             0.3400865167323523, 0.464605505615422, 0.9430514392358678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 273}], {
             RGBColor[
             0.4610460456189836, 0.5714871913584664, 0.9512254809511769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 302}], {
             RGBColor[
             0.43476704118148507`, 0.5487256385358728, 0.9495510060260308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 347}], {
             RGBColor[
             0.43472876971014235`, 0.5486924897109757, 0.9495485674017189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 421}], {
             RGBColor[
             0.45574366869679184`, 0.5668945389736769, 0.9508876181824026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 423}], {
             RGBColor[
             0.45118738794865654`, 0.5629481175949712, 0.9505972960020923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 477}], {
             RGBColor[
             0.4044125520190808, 0.5190297415901626, 0.9477414952642024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 224}], {
             RGBColor[
             0.5916449434614959, 0.6696943495634888, 0.9647930239620957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 351}], {
             RGBColor[
             0.44895800364063676`, 0.5571203393774563, 0.951072905875899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 356}], {
             RGBColor[
             0.278551253504396, 0.4101054069756186, 0.9391744538561998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 430}], {
             RGBColor[
             0.3941752826615823, 0.5126452585532042, 0.9467602094047087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 238}], {
             RGBColor[
             0.6035487233788674, 0.6853316114816681, 0.963941360461886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 281}], {
             RGBColor[
             0.5818736592976459, 0.666557760394911, 0.9625602445451372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 343}], {
             RGBColor[
             0.606152373944997, 0.6875867627387671, 0.964107262773642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 465}], {
             RGBColor[
             0.5979600035183568, 0.6804909432357213, 0.9635852521742853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 290}], {
             RGBColor[
             0.29601487802816084`, 0.4256548161802228, 0.9402717216506072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 340}], {
             RGBColor[
             0.3480473608129305, 0.4758828633923302, 0.9433982479581711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 355}], {
             RGBColor[
             0.2981242210485807, 0.427871869434756, 0.9403918456151268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 362}], {
             RGBColor[
             0.5166118692324969, 0.6145533434948109, 0.9564878685479222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 378}], {
             RGBColor[
             0.3119593109488674, 0.44241342611532136`, 0.9411797335177667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 384}], {
             RGBColor[
             0.6205429912637712, 0.696407958277389, 0.9666708561760524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 498}], {
             RGBColor[
             0.29601487802816084`, 0.4256548161802228, 0.9402717216506072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 295}], {
             RGBColor[
             0.30463226628515794`, 0.4372707020222313, 0.9406687912485645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.27076658563293476`, 0.4019232274662621, 0.9387311285373041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 336}], {
             RGBColor[
             0.3139267357719081, 0.44532110433803485`, 0.9412610266254835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 389}], {
             RGBColor[
             0.6423125049414357, 0.7095916914332865, 0.9044846133650343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 409}], {
             RGBColor[
             0.3353268148072711, 0.46385677719921947`, 0.94262462073827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 456}], {
             RGBColor[
             0.239391434654601, 0.3689459544885648, 0.9369443601044645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 458}], {
             RGBColor[
             0.3099062274576516, 0.44183874211284935`, 0.9410048433908951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 244}], {
             RGBColor[
             0.36583496845337493`, 0.4912895950993281, 0.9445316585880563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 274}], {
             RGBColor[
             0.4623255332971742, 0.5734491106389961, 0.9510711313075628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 334}], {
             RGBColor[
             0.4411246810265996, 0.556237303678233, 0.9494021225555425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 337}], {
             RGBColor[
             0.35271483849168783`, 0.4778445829691414, 0.9437718516616176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 340}], {
             RGBColor[
             0.3880957079074221, 0.5105707287571265, 0.9459500932216693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 361}], {
             RGBColor[
             0.45179937749119586`, 0.5649035031577878, 0.950242473763937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 363}], {
             RGBColor[
             0.4087642819587358, 0.5284728087676371, 0.9472670764837166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 369}], {
             RGBColor[
             0.40328866537310937`, 0.5237301048936593, 0.9469181750367781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 370}], {
             RGBColor[
             0.3440779919466703, 0.46876670964262873`, 0.9432799960279483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 498}], {
             RGBColor[
             0.3360632251226524, 0.46034268154501906`, 0.9428235669141054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 349}], {
             RGBColor[
             0.36992552941230916`, 0.49474869040312575`, 0.9447953790796997]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 359}], {
             RGBColor[
             0.36332965210996776`, 0.48781600515558976`, 0.9444197536250574]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 371}], {
             RGBColor[
             0.3726560931529739, 0.4971977104744248, 0.9449662946222311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 382}], {
             RGBColor[
             0.40946236806928366`, 0.5290774558697657, 0.9473115579133874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 416}], {
             RGBColor[
             0.33482004000627663`, 0.4578505952208002, 0.9427961733919437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 427}], {
             RGBColor[
             0.5155388903427145, 0.6169982404050158, 0.9551640925432596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 429}], {
             RGBColor[
             0.41517494903208396`, 0.5340254063770756, 0.9476755585209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 499}], {
             RGBColor[
             0.39964815636094475`, 0.5205768789646257, 0.9466862050216986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 223}], {
             RGBColor[
             0.6649982556373613, 0.7301421441006394, 0.9019606621619665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 258}], {
             RGBColor[
             0.30657544732160996`, 0.4364176053864961, 0.9408854710867356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 297}], {
             RGBColor[
             0.3016979234576789, 0.43129101855262997`, 0.9406077033183345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 381}], {
             RGBColor[
             0.39084632085515214`, 0.5129531714426238, 0.9461253598464272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 439}], {
             RGBColor[
             0.36427723848095306`, 0.4899403676910012, 0.9444324014116603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 307}], {
             RGBColor[
             0.5433968867550779, 0.640078388404016, 0.9572290346144292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 333}], {
             RGBColor[
             0.7275097249962563, 0.4254399896193177, 0.5644196309392897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 372}], {
             RGBColor[
             0.8158566258996556, 0.8531776463194997, 0.77716493556596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 417}], {
             RGBColor[
             0.5697255407163061, 0.6615678856534453, 0.9592700280200595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 258}], {
             RGBColor[
             0.6288333940426508, 0.6952735877074647, 0.8997860459445411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 268}], {
             RGBColor[
             0.6532706286799411, 0.719984263077792, 0.901213388142573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 373}], {
             RGBColor[
             0.729894707511919, 0.7858304508494374, 0.9062399644742192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 381}], {
             RGBColor[
             0.7131042675761929, 0.7718091537635924, 0.9050259347042328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 480}], {
             RGBColor[
             0.6649362729678954, 0.7300884578276876, 0.9019567126810772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 263}], {
             RGBColor[
             0.7154370584596279, 0.7765973844526155, 0.9732282519597064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 342}], {
             RGBColor[
             0.6129445769114036, 0.6900581459896918, 0.9660800956822204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 351}], {
             RGBColor[
             0.7525706621357885, 0.8067441167667047, 0.9761515452659661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 356}], {
             RGBColor[
             0.5821639119995478, 0.6597291843648669, 0.964253093246267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 463}], {
             RGBColor[
             0.6583514648770511, 0.7293873101289882, 0.968973382431657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 235}], {
             RGBColor[
             0.5803817789672682, 0.6627270527727892, 0.9634136799418325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 249}], {
             RGBColor[
             0.675715685515858, 0.7446276588442088, 0.9697814116684343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 260}], {
             RGBColor[
             0.5774900704865626, 0.6596876838146605, 0.9632490014217556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 280}], {
             RGBColor[
             0.7494944436688581, 0.8045245784079924, 0.9755895457707346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 296}], {
             RGBColor[
             0.5565228786113532, 0.6376498357570682, 0.9620549508626433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 424}], {
             RGBColor[
             0.5763338859035853, 0.6584724605116148, 0.9631831584201769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 440}], {
             RGBColor[
             0.585538459712075, 0.6676409001216541, 0.9637258779516058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 453}], {
             RGBColor[
             0.92511969707304, 0.9384765936332455, 0.7536800989614152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 470}], {
             RGBColor[
             0.6456347322204237, 0.7196932708419037, 0.9675551592947906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 236}], {
             RGBColor[
             0.6267083603735737, 0.6932925618408008, 0.9062517418203191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 283}], {
             RGBColor[
             0.34291957564555403`, 0.467577356434953, 0.9432129928156685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 292}], {
             RGBColor[
             0.525030374718706, 0.6142019079917754, 0.9587652418721002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 308}], {
             RGBColor[
             0.35603804832766595`, 0.4789399181185898, 0.9440488902947628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 386}], {
             RGBColor[
             0.26947609606407186`, 0.40056684110762275`, 0.9386576370654657]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 396}], {
             RGBColor[
             0.29717600385712306`, 0.4279565736905826, 0.9402982528707621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 422}], {
             RGBColor[
             0.4189208620668843, 0.5302135215398563, 0.9489377776665427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 446}], {
             RGBColor[
             0.39921330172562697`, 0.5142140362393477, 0.9473863263253068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 309}], {
             RGBColor[
             0.4150243931347486, 0.5338950024259632, 0.9476659652322532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 320}], {
             RGBColor[
             0.4006858865046886, 0.521475708657303, 0.9467523282688293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 348}], {
             RGBColor[
             0.5167124739091633, 0.617012693266715, 0.9555157406113837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 428}], {
             RGBColor[
             0.3335224116678295, 0.45968177574687474`, 0.9426052882068576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 495}], {
             RGBColor[
             0.32033555508269895`, 0.4458215533809045, 0.9418543162325406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 388}], {
             RGBColor[
             0.7150379393019262, 0.7762556786564517, 0.9732171845125582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 490}], {
             RGBColor[
             0.7277030103353785, 0.7865377538763565, 0.9742142252979955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 244}], {
             RGBColor[
             0.5760161982499107, 0.6599881970848224, 0.9628452161186005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 248}], {
             RGBColor[
             0.561238340700701, 0.6448008081541499, 0.9619910040584405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 255}], {
             RGBColor[
             0.8935627412595937, 0.9176605349805318, 0.9790953832993115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 313}], {
             RGBColor[
             0.5642861739844828, 0.6480042741791959, 0.9621645736550866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 338}], {
             RGBColor[
             0.649695413437462, 0.7236284313339573, 0.9675888958324401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 379}], {
             RGBColor[
             0.6289539291610962, 0.7058401988723715, 0.9662183615212638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 380}], {
             RGBColor[
             0.5594199274665524, 0.6428895405510016, 0.9618874481148569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 390}], {
             RGBColor[
             0.7378157416723251, 0.7951684835705669, 0.9745260508664868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 411}], {
             RGBColor[
             0.5835896566813374, 0.6665479461250355, 0.9633277901929047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 478}], {
             RGBColor[
             0.5759886709259834, 0.6599643543004001, 0.9628434621018613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 242}], {
             RGBColor[
             0.41292407837843115`, 0.525660422328111, 0.9484369828645601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 339}], {
             RGBColor[
             0.27772791775766925`, 0.40924002890330735`, 0.9391275661034398]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 365}], {
             RGBColor[
             0.25339430878090474`, 0.38366386302880845`, 0.9377418030705615]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 374}], {
             RGBColor[
             0.5678753930788263, 0.4429191519786202, 0.5743491526302444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 391}], {
             RGBColor[
             0.33738899120831134`, 0.46303081260490175`, 0.942851663236095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 246}], {
             RGBColor[
             0.698746933855799, 0.7597946940289387, 0.9195902424878957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 256}], {
             RGBColor[
             0.4659369689443951, 0.5761884428255775, 0.951408651037243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 271}], {
             RGBColor[
             0.36204768370055795`, 0.48800923940090446`, 0.9442903361525714]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 288}], {
             RGBColor[
             0.6794083302615758, 0.7455719095192197, 0.9612780287470386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 442}], {
             RGBColor[
             0.6918621705232362, 0.7548599631950741, 0.9401969256657967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 444}], {
             RGBColor[
             0.40171400505735877`, 0.5223662132728849, 0.946817839073876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 492}], {
             RGBColor[
             0.36569180371640825`, 0.4911655929998364, 0.9445225362576125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 307}], {
             RGBColor[
             0.4140722527224633, 0.5330703062568103, 0.947605295687127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 312}], {
             RGBColor[
             0.3629863942173616, 0.4888223032695974, 0.9443501499566329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 330}], {
             RGBColor[
             0.30945586401781966`, 0.43608791765703464`, 0.9411724296658713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 350}], {
             RGBColor[
             0.44921720100674123`, 0.5617172684072242, 0.9503403400770178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 354}], {
             RGBColor[
             0.39529200008529075`, 0.5168037953454347, 0.9464086345958118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 372}], {
             RGBColor[
             0.686531991867041, 0.7461695641722939, 0.7675411966386577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 376}], {
             RGBColor[
             0.44364689277425184`, 0.5571950412445632, 0.9499018250082449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 400}], {
             RGBColor[
             0.3879707881132026, 0.5104625295100251, 0.9459421334428438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 414}], {
             RGBColor[
             0.34607131998326945`, 0.4741713161443778, 0.9432723363838493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 415}], {
             RGBColor[
             0.5062549364769056, 0.6080230715826045, 0.9548305595493387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 476}], {
             RGBColor[
             0.2943387404345882, 0.4234455220944534, 0.9401926557219917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 235}], {
             RGBColor[
             0.3158517027276886, 0.44754921288969685`, 0.9413631502218942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[
             0.5292986786145881, 0.6239845101988771, 0.9579554728415716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 262}], {
             RGBColor[
             0.6218324303292972, 0.581248146999612, 0.5966359673847018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 296}], {
             RGBColor[
             0.2919928023717736, 0.4224719958739759, 0.9400044211427048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 332}], {
             RGBColor[
             0.3686291634052093, 0.49370978632628526`, 0.9447097022195776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 393}], {
             RGBColor[
             0.3314863387366823, 0.4615385384510562, 0.9423429942758095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 468}], {
             RGBColor[
             0.3011606217641306, 0.4321079553286653, 0.9405265148945261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 239}], {
             RGBColor[
             0.5173540726103371, 0.6131913031613252, 0.9572107542365932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 249}], {
             RGBColor[
             0.3992410032720274, 0.5186566119235645, 0.9469861633435175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 260}], {
             RGBColor[
             0.30101538824273194`, 0.4337166368940162, 0.9404537530968389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 262}], {
             RGBColor[
             0.6098878243250461, 0.57045493996206, 0.5958912487797233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 296}], {
             RGBColor[
             0.28004819636752254`, 0.41167878883642395`, 0.9392597025377264]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 332}], {
             RGBColor[
             0.3566845574009583, 0.4829165792887333, 0.9439649836145992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 344}], {
             RGBColor[
             0.5351915051788585, 0.6271260410533628, 0.9589886228147387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 393}], {
             RGBColor[
             0.31954173273243125`, 0.45074533141350426`, 0.941598275670831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 424}], {
             RGBColor[
             0.2998592036597546, 0.43250141359097044`, 0.9403879100952601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 440}], {
             RGBColor[
             0.30906377746824437`, 0.4416698532010098, 0.940930629626689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 453}], {
             RGBColor[
             0.6486450148292093, 0.7125055467126014, 0.7308848506364984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 243}], {
             RGBColor[
             0.6473967176862739, 0.7150373370940635, 0.9074299131635954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 276}], {
             RGBColor[
             0.6901244011102821, 0.7520844261194248, 0.9101510730654188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 283}], {
             RGBColor[
             0.7026752472143023, 0.76295533819086, 0.9109508018808895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 292}], {
             RGBColor[
             0.8847860462874544, 0.9095798897476824, 0.9265030509373212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 396}], {
             RGBColor[
             0.6569316754258714, 0.7233345554464896, 0.9080360619359831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 422}], {
             RGBColor[
             0.7786765336356325, 0.8255915032957633, 0.9166755867317637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 267}], {
             RGBColor[
             0.25799062738744527`, 0.3884948853077141, 0.93800355661556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 270}], {
             RGBColor[
             0.6164507696724955, 0.6829215877736223, 0.916372570387269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 329}], {
             RGBColor[
             0.38355409685285535`, 0.4992013770938993, 0.9463629194751053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 426}], {
             RGBColor[
             0.3960604912234229, 0.5093546314505719, 0.9473474686523886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 448}], {
             RGBColor[
             0.407186385466097, 0.5183871336125985, 0.9482233398026654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 489}], {
             RGBColor[
             0.290039857231839, 0.41999786851348686`, 0.9399086354551752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 265}], {
             RGBColor[
             0.5629985543221347, 0.6536535112218491, 0.9598996985731857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 328}], {
             RGBColor[
             0.3157187126251994, 0.440133234023583, 0.941621993878423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 343}], {
             RGBColor[
             0.4090982840701299, 0.5287621046090927, 0.9472883588029082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 431}], {
             RGBColor[
             0.3919838937001133, 0.5139384798648554, 0.9461978449821918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 433}], {
             RGBColor[
             0.3926927426493517, 0.5145524491969017, 0.9462430122104268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 436}], {
             RGBColor[
             0.3456591546528833, 0.47160253692834586`, 0.943327057758985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 462}], {
             RGBColor[
             0.5909698695679608, 0.675504915281758, 0.962687617870087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 465}], {
             RGBColor[
             0.4009059136434896, 0.521666285106047, 0.9467663482035513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 262}], {
             RGBColor[
             0.8233348002119456, 0.7468902372712403, 0.6124835713994008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 263}], {
             RGBColor[
             0.6332087817299223, 0.7117516212114997, 0.9651939587117604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 296}], {
             RGBColor[
             0.4934951722544221, 0.5881140861456042, 0.9558520251574039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 332}], {
             RGBColor[
             0.5701315332878578, 0.6593518765979136, 0.9605573062342767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 393}], {
             RGBColor[
             0.5329887086193308, 0.6271806287226845, 0.9581905982905085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 424}], {
             RGBColor[
             0.5133061795466541, 0.6089367109001507, 0.9569802327149375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 440}], {
             RGBColor[
             0.5225107533551439, 0.6181051505101901, 0.9575229522463664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 453}], {
             RGBColor[
             0.8620919907161089, 0.8889408440217816, 0.7474771732561759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 251}], {
             RGBColor[
             0.3656184564317942, 0.4911020632684455, 0.9445178626334954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 310}], {
             RGBColor[
             0.40732548119239603`, 0.5272265918600629, 0.947175397371167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 352}], {
             RGBColor[
             0.47787737679431863`, 0.585257928087376, 0.9525211329293405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 367}], {
             RGBColor[
             0.3377073117551884, 0.4648522554290197, 0.9428153496085196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 382}], {
             RGBColor[
             0.3880093589914371, 0.5104959376661231, 0.9459445911450981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 399}], {
             RGBColor[
             0.3073584025403783, 0.43295362761227163`, 0.9410870241259239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 412}], {
             RGBColor[
             0.4170256875891332, 0.5356284230943672, 0.9477934859452113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 416}], {
             RGBColor[
             0.3133670309284301, 0.43926907701715756`, 0.9414292066236544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 429}], {
             RGBColor[
             0.39372193995423743`, 0.5154438881734331, 0.9463085917526107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 402}], {
             RGBColor[
             0.5617450504235045, 0.6550889641167582, 0.958641774590711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 417}], {
             RGBColor[
             0.553913268770626, 0.6487307709532086, 0.9580252280502348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 436}], {
             RGBColor[
             0.4454497909514593, 0.5538884351714302, 0.9508316604828742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 461}], {
             RGBColor[
             0.4794792349222017, 0.5855748114921854, 0.9529190023761098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 339}], {
             RGBColor[
             0.421062720856508, 0.5342146515923067, 0.948900466513644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 365}], {
             RGBColor[
             0.3967291118797434, 0.5086384857178079, 0.9475147034807658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 374}], {
             RGBColor[
             0.7112101961776649, 0.5678937746676196, 0.5841220530404486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 276}], {
             RGBColor[
             0.351057086854234, 0.4784512196167806, 0.9435914353434742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 326}], {
             RGBColor[
             0.36860280362388753`, 0.4936484376092881, 0.9447094329009684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 428}], {
             RGBColor[
             0.28895933935490914`, 0.4210449651152654, 0.9397671789480033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 454}], {
             RGBColor[
             0.34691210494341146`, 0.47486104461847456`, 0.9433273207613802]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 469}], {
             RGBColor[
             0.28844025288627007`, 0.42049937232474277`, 0.939737617741534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 471}], {
             RGBColor[
             0.35796471213423253`, 0.4844342574469739, 0.9440315831181425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 475}], {
             RGBColor[
             0.3307222890042717, 0.46083823977580085`, 0.9422957200058304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 495}], {
             RGBColor[
             0.2757724827697786, 0.40718474274929517`, 0.9390162069736863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 274}], {
             RGBColor[
             0.4089688614655975, 0.527234243282787, 0.9476712913599071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 313}], {
             RGBColor[
             0.30074827235637036`, 0.4330908048374925, 0.9404511761768867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 334}], {
             RGBColor[
             0.38776800919502286`, 0.5100224363220239, 0.9460022826078868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 340}], {
             RGBColor[
             0.3347390360758454, 0.46435586140091745`, 0.9425502532740135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 355}], {
             RGBColor[
             0.2848158963114956, 0.4163448674433432, 0.9395438509309693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 363}], {
             RGBColor[
             0.3554076101271591, 0.4822579414114281, 0.9438672365360609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 378}], {
             RGBColor[
             0.2986509862117823, 0.43088642412390854`, 0.9403317388336092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 379}], {
             RGBColor[
             0.3654160275329837, 0.49092672953066807`, 0.9445049640430639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 380}], {
             RGBColor[
             0.29588202583844003`, 0.42797607120929815`, 0.9401740506366572]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 390}], {
             RGBColor[
             0.4742778400442127, 0.5802550142288635, 0.952812653388287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 498}], {
             RGBColor[
             0.28270655329107575`, 0.41412781418880995`, 0.9394237269664496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 394}], {
             RGBColor[
             0.35413363171791556`, 0.4808689374072572, 0.9437965150671638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 438}], {
             RGBColor[
             0.29216515973275825`, 0.42441448559313655`, 0.9399497456759356]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 445}], {
             RGBColor[
             0.28388377496926664`, 0.4157102251365863, 0.9394781330648656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 460}], {
             RGBColor[
             0.28761626414664426`, 0.41963330791549247`, 0.9396906928017943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 256}], {
             RGBColor[
             0.7525853503688579, 0.8046223505888193, 0.9235193602752877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 288}], {
             RGBColor[
             0.9660567116860386, 0.9740058172824613, 0.9333887379850832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 333}], {
             RGBColor[
             0.9013571576401309, 0.5611778008960902, 0.5279594758629702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 392}], {
             RGBColor[
             0.6240648650343078, 0.6908547542158712, 0.9149873300080887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 442}], {
             RGBColor[
             0.978510551947699, 0.9832938709583159, 0.9123076349038413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 444}], {
             RGBColor[
             0.6883623864818216, 0.7508001210361266, 0.9189285483119205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 459}], {
             RGBColor[
             0.6983865274282197, 0.7594825280959233, 0.9195672777090252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 492}], {
             RGBColor[
             0.652340185140871, 0.7195995007630781, 0.9166332454956572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 255}], {
             RGBColor[
             0.6173117086722564, 0.6897298352654568, 0.956645356885762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 269}], {
             RGBColor[
             0.3962417093617733, 0.5142056299125843, 0.9469335586286936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 360}], {
             RGBColor[
             0.3470796155808761, 0.4730388957955821, 0.94341002461532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 369}], {
             RGBColor[
             0.33721886258230793`, 0.46449800716407874`, 0.9427817061537727]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 370}], {
             RGBColor[
             0.2780081891558688, 0.4095346119130481, 0.9391435271449429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 425}], {
             RGBColor[
             0.30359584480216045`, 0.43537543910492593`, 0.940639277192489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 466}], {
             RGBColor[
             0.3144995097861606, 0.44481964567992993`, 0.9413340490835371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 468}], {
             RGBColor[
             0.2807884847498352, 0.41245687886322885`, 0.9393018608659405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 286}], {
             RGBColor[
             0.3251727259934689, 0.45368245294602383`, 0.9420281164100497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 294}], {
             RGBColor[
             0.3113138915320696, 0.4416786271008334, 0.9411450437330554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 313}], {
             RGBColor[
             0.2859704148071607, 0.4179034159068199, 0.9395969641167267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 380}], {
             RGBColor[
             0.28110416828923035`, 0.4127886822786256, 0.9393198385764971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 411}], {
             RGBColor[
             0.30527389750401535`, 0.4364470878526595, 0.9407601806545448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 478}], {
             RGBColor[
             0.29767291174866123`, 0.4298634960280241, 0.9402758525635014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 260}], {
             RGBColor[
             0.3963492947913218, 0.5156172429654358, 0.9468214848234406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 280}], {
             RGBColor[
             0.5683536679736173, 0.6604541375587677, 0.9591620291724197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 296}], {
             RGBColor[
             0.3753821029161124, 0.4935793949078435, 0.9456274342643283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 424}], {
             RGBColor[
             0.39519311020834447`, 0.51440201966239, 0.9467556418218619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 440}], {
             RGBColor[
             0.40439768401683424`, 0.5235704592724294, 0.9472983613532908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 470}], {
             RGBColor[
             0.4644939565251829, 0.575622829992679, 0.9511276426964757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 339}], {
             RGBColor[
             0.28178128707424543`, 0.4135003770534871, 0.9393583994895962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 365}], {
             RGBColor[
             0.25744767809748087`, 0.38792421117898823`, 0.937972636456718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 305}], {
             RGBColor[
             0.418913112949334, 0.536112546707868, 0.9482316843951852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 367}], {
             RGBColor[
             0.31421881191102774`, 0.4445076974303363, 0.9413186831685146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 382}], {
             RGBColor[
             0.3645208591472764, 0.4901513796674397, 0.944447924705093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 416}], {
             RGBColor[
             0.2898785310842693, 0.41892451901847416`, 0.9399325401836494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 427}], {
             RGBColor[
             0.4705973814207072, 0.5780721642026898, 0.9523004593349653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 429}], {
             RGBColor[
             0.3702334401100767, 0.49509933017474966`, 0.9448119253126057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 499}], {
             RGBColor[
             0.35470664743893754`, 0.4816508027622997, 0.9438225718134043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 282}], {
             RGBColor[
             0.3469159845313079, 0.471157052250744, 0.9434633123075199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 432}], {
             RGBColor[
             0.4762258739503551, 0.5849080561958212, 0.9521173340211261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 467}], {
             RGBColor[
             0.394642048437175, 0.5162408398953565, 0.9463672202515234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 261}], {
             RGBColor[
             0.4807698826350132, 0.5824864531282464, 0.9539008032023328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 277}], {
             RGBColor[
             0.2931408020837776, 0.42543994756335574`, 0.9400053070644926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 291}], {
             RGBColor[
             0.3432474240190243, 0.4698218911352806, 0.9431620969919722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 311}], {
             RGBColor[
             0.32834625073164264`, 0.4569152437884969, 0.9422126074066903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 319}], {
             RGBColor[
             0.350226539595826, 0.475866850267358, 0.9436068000651363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 377}], {
             RGBColor[
             0.32781365194808765`, 0.45645393349137475`, 0.9421786706831609]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 484}], {
             RGBColor[
             0.36963600599413576`, 0.4926783545134274, 0.9448435541009195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 488}], {
             RGBColor[
             0.35100709960673215`, 0.476542932116718, 0.9436565366588092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 315}], {
             RGBColor[
             0.5716994585160652, 0.6616793183475285, 0.9602469239078792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 325}], {
             RGBColor[
             0.7907767798430434, 0.8369132705221423, 0.9796659464850939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 347}], {
             RGBColor[
             0.5202668990823897, 0.6171310204416802, 0.956969686700792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 368}], {
             RGBColor[
             0.4752222904274986, 0.5719877995839593, 0.9543238544865871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 386}], {
             RGBColor[
             0.4899879928780221, 0.5875074890590672, 0.9551647393972452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 401}], {
             RGBColor[
             0.5203403955772996, 0.61719467941153, 0.9569743698324572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 454}], {
             RGBColor[
             0.5467356444446615, 0.6400569173166564, 0.9586562517498833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 471}], {
             RGBColor[
             0.5577882516354826, 0.6496301301451557, 0.9593605141066457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 269}], {
             RGBColor[
             0.726501383330681, 0.7848951981816653, 0.9639203547447541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 274}], {
             RGBColor[
             0.7265154044752805, 0.7849065811784965, 0.9639214585406182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 334}], {
             RGBColor[
             0.7053145522047058, 0.7676947742177334, 0.9622524497885978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 338}], {
             RGBColor[
             0.7037040548190325, 0.7663872998879633, 0.9621256655349513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 369}], {
             RGBColor[
             0.6674785365512157, 0.7351875754331598, 0.9597685022698333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 370}], {
             RGBColor[
             0.6082678631247767, 0.6802241801821292, 0.9561303232610034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 379}], {
             RGBColor[
             0.6829625705426667, 0.7485990674263776, 0.960755131223775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 390}], {
             RGBColor[
             0.7918243830538957, 0.8379273521245729, 0.969062820568998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 425}], {
             RGBColor[
             0.6338555187710683, 0.7060650073740069, 0.9576260733085495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 466}], {
             RGBColor[
             0.6447591837550684, 0.715509213949011, 0.9583208451995977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 271}], {
             RGBColor[
             0.4158861002136168, 0.532836895960785, 0.9482194539399633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 333}], {
             RGBColor[
             0.668547192728727, 0.377571549692729, 0.5597778844123176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 442}], {
             RGBColor[
             0.745700587036295, 0.7996876197549546, 0.9441260434531886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 444}], {
             RGBColor[
             0.4555524215704176, 0.5671938698327654, 0.9507469568612679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 492}], {
             RGBColor[
             0.41953022022946707`, 0.5359932495597168, 0.9484516540450045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 272}], {
             RGBColor[
             0.4850410083278328, 0.5897177921472729, 0.953459718000611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 306}], {
             RGBColor[
             0.5008508519570865, 0.6034114840730869, 0.9544671072565714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 317}], {
             RGBColor[
             0.45993591512462256`, 0.5661436905595894, 0.951927024455043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 357}], {
             RGBColor[
             0.6409127866170177, 0.719229847889, 0.9649637490251903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 418}], {
             RGBColor[
             0.49722875321101423`, 0.6002742041912155, 0.9542363103273678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 420}], {
             RGBColor[
             0.49205543833816345`, 0.595793338866718, 0.9539066712782525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 289}], {
             RGBColor[
             0.3085647043331811, 0.4381405998269544, 0.9410122247844819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 297}], {
             RGBColor[
             0.26553306186296843`, 0.3964224621594553, 0.9384330871009092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 314}], {
             RGBColor[
             0.3388396661143624, 0.4643632500579902, 0.9429413185780813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 373}], {
             RGBColor[
             0.3714718991961677, 0.4921059121352941, 0.9451647733989883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 381}], {
             RGBColor[
             0.3546814592604417, 0.4780846150494491, 0.9439507436290018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 397}], {
             RGBColor[
             0.28735066723726976`, 0.4193541487239232, 0.9396755674507209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 472}], {
             RGBColor[
             0.41605376895173485`, 0.5282994823932085, 0.9486744214949163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 341}], {
             RGBColor[
             0.38638569996389127`, 0.5090896058239385, 0.9458411330276082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 405}], {
             RGBColor[
             0.40512556741087413`, 0.5253211371133903, 0.9470352208103158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 450}], {
             RGBColor[
             0.44099707082443, 0.5544450490287951, 0.949858657003846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 454}], {
             RGBColor[
             0.3712472909932448, 0.49597747685212284`, 0.944876526994368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 469}], {
             RGBColor[
             0.31277543893610343`, 0.44161580455839106`, 0.9412868239745218]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 471}], {
             RGBColor[
             0.3822998981840659, 0.5055506896806222, 0.9455807893511303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 475}], {
             RGBColor[
             0.355057475054105, 0.48195467200944914`, 0.9438449262388182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 491}], {
             RGBColor[
             0.5075955137511348, 0.6082701353145542, 0.9552673494117132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 500}], {
             RGBColor[
             0.38791135432184887`, 0.5104110509471836, 0.945938346374214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 280}], {
             RGBColor[
             0.47012805294432186`, 0.5755141625292194, 0.9526296189257408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 424}], {
             RGBColor[
             0.29696749517904897`, 0.4294620446328417, 0.9402232315751832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 440}], {
             RGBColor[
             0.3061720689875388, 0.4386304842428811, 0.9407659511066121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 470}], {
             RGBColor[
             0.36626834149588744`, 0.4906828549631307, 0.9445952324497968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 483}], {
             RGBColor[
             0.3934097457163769, 0.5132307846012187, 0.9465900727523379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 484}], {
             RGBColor[
             0.5622479642236202, 0.6549621804508499, 0.9590228177510289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 500}], {
             RGBColor[
             0.5461023869891515, 0.6409776929506601, 0.9579940358466219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 332}], {
             RGBColor[
             0.6626652850025668, 0.6166155133986484, 0.5992378007774068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 344}], {
             RGBColor[
             0.8411722327804672, 0.7608249751632779, 0.6142614399775463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 387}], {
             RGBColor[
             0.742141058888506, 0.6823283197127243, 0.6051654052476103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 393}], {
             RGBColor[
             0.6255224603340399, 0.5844442655234194, 0.5968710928336387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 424}], {
             RGBColor[
             0.6058399312613632, 0.5662003477008856, 0.5956607272580676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 296}], {
             RGBColor[
             0.39590290548710794`, 0.5102391068865985, 0.9472429070128936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 323}], {
             RGBColor[
             0.42107101786400997`, 0.5366923887452134, 0.9486761937798724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 342}], {
             RGBColor[
             0.4331240334143839, 0.5473374034895703, 0.9494366842897641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 395}], {
             RGBColor[
             0.44691249398926547`, 0.5592802750113535, 0.9503152728049387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 440}], {
             RGBColor[
             0.4249184865878297, 0.5402301712511843, 0.9489138341018561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 447}], {
             RGBColor[
             0.5073391318501372, 0.6109197884601978, 0.9543587413851691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 453}], {
             RGBColor[
             0.7644997239487946, 0.8110658647627758, 0.7388680551116656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 463}], {
             RGBColor[
             0.4785309213800314, 0.5866665676288666, 0.9523299710392006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 394}], {
             RGBColor[
             0.3999431621971854, 0.5208323981925529, 0.9467050025327206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 398}], {
             RGBColor[
             0.3649917516058699, 0.4905592430473303, 0.9444779295561607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 445}], {
             RGBColor[
             0.3296933054485365, 0.45567368592188195`, 0.9423866205304223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 328}], {
             RGBColor[
             0.4722226334433338, 0.5672797918934385, 0.9543992359604566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 433}], {
             RGBColor[
             0.5491966634674861, 0.6416990070667572, 0.9590202542924604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 462}], {
             RGBColor[
             0.7474737903860953, 0.8026514731516134, 0.9754648599521206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 364}], {
             RGBColor[
             0.3373703907893601, 0.4630133796363971, 0.9428505264468166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 374}], {
             RGBColor[
             0.5678682426040771, 0.4429116363762926, 0.5743487454212857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 410}], {
             RGBColor[
             0.2837082746659444, 0.41552576319043266`, 0.9394681385822208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 437}], {
             RGBColor[
             0.3246248596934236, 0.4519738412101163, 0.942038392475814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 278}], {
             RGBColor[
             0.2739627308987875, 0.40528257878798757`, 0.9389131442819212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 329}], {
             RGBColor[
             0.3938197506207891, 0.5099912300840396, 0.9469475332705153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 406}], {
             RGBColor[
             0.3928352379506179, 0.5091919583466042, 0.9468700288267308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 413}], {
             RGBColor[
             0.34213260305732746`, 0.4670162463531074, 0.9431584345702473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 476}], {
             RGBColor[
             0.30609602534248365`, 0.4358031739875701, 0.940862215704152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 486}], {
             RGBColor[
             0.40096019887653456`, 0.5157881676515819, 0.9475096555135314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 493}], {
             RGBColor[
             0.40531608212093123`, 0.5193244698996871, 0.9478525665986564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 275}], {
             RGBColor[
             0.45687898310319264`, 0.5663146578032007, 0.9513918854714505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 285}], {
             RGBColor[
             0.2928471950640109, 0.42415694032619017`, 0.9400242644161567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 324}], {
             RGBColor[
             0.633234583327866, 0.7055504886002861, 0.9579266205157947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 353}], {
             RGBColor[
             0.35205006472722766`, 0.4793498043411461, 0.943653296712138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 441}], {
             RGBColor[
             0.5345515288340337, 0.6277265946678914, 0.9586320241948523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 480}], {
             RGBColor[
             0.33095069928943444`, 0.46107459448387145`, 0.9423088638038781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 481}], {
             RGBColor[
             0.39102199545666044`, 0.5128489884082621, 0.9462073821618209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 360}], {
             RGBColor[
             0.45626929023930063`, 0.5682042587117906, 0.9506850224743122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 369}], {
             RGBColor[
             0.4464085372407325, 0.5596633700802871, 0.9500567040127649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 425}], {
             RGBColor[
             0.41278551946058506`, 0.5305408020211343, 0.9479142750514811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 466}], {
             RGBColor[
             0.4236891844445852, 0.5399850085961384, 0.9486090469425292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 468}], {
             RGBColor[
             0.38997815940825975`, 0.5076222417794373, 0.9465768587249327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 309}], {
             RGBColor[
             0.708884901969455, 0.7686251981134796, 0.9220558172297676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 345}], {
             RGBColor[
             0.7524886361406626, 0.804587399711753, 0.9253329800743213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 375}], {
             RGBColor[
             0.6232119467538014, 0.6900280135694614, 0.9167576094197842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 426}], {
             RGBColor[
             0.7647862872764067, 0.8145711869066203, 0.9263010962195075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 489}], {
             RGBColor[
             0.6587656532848228, 0.7252144239695353, 0.9188622630222942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 284}], {
             RGBColor[
             0.3318720987289292, 0.4618726643674794, 0.9423675745614013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 442}], {
             RGBColor[
             0.6418113017924578, 0.7115084163302816, 0.937007728568517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 444}], {
             RGBColor[
             0.3516631363265804, 0.4790146664080923, 0.9436286419765962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 464}], {
             RGBColor[
             0.34470469194285375`, 0.4729876116244922, 0.9431852560535758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 492}], {
             RGBColor[
             0.31564093498562995`, 0.44781404613504383`, 0.9413333391603327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 306}], {
             RGBColor[
             0.35498023786595917`, 0.48188777303913116`, 0.9438400047534876]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 317}], {
             RGBColor[
             0.3140653010334952, 0.44461997952563354`, 0.9412999219519593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 357}], {
             RGBColor[
             0.4950421725258904, 0.5977061368550443, 0.9543366465221066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 308}], {
             RGBColor[
             0.4151576377001212, 0.5340104121714224, 0.9476744554581351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 421}], {
             RGBColor[
             0.37988949062754407`, 0.5034629158057694, 0.9454272003130685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 423}], {
             RGBColor[
             0.37533320987940877`, 0.4995164944270637, 0.9451368781327582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 446}], {
             RGBColor[
             0.4583328910980822, 0.5692845302921803, 0.9510118914886792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 477}], {
             RGBColor[
             0.32855837394983306`, 0.455598118422255, 0.9422810773948682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 334}], {
             RGBColor[
             0.4842585740388221, 0.592181951861692, 0.9525417553273933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 340}], {
             RGBColor[
             0.43122960091964463`, 0.5465153769405855, 0.94908972599352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 361}], {
             RGBColor[
             0.4949332705034184, 0.6008481513412467, 0.9533821065357878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 363}], {
             RGBColor[
             0.45189817497095836`, 0.5644174569510961, 0.9504067092555674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 369}], {
             RGBColor[
             0.44642255838533196`, 0.5596747530771183, 0.9500578078086288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 370}], {
             RGBColor[
             0.38721188495889286`, 0.5047113578260877, 0.946419628799799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 379}], {
             RGBColor[
             0.46190659237678294`, 0.5730862450703361, 0.9510444367625704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 498}], {
             RGBColor[
             0.379197118134875, 0.496287329728478, 0.9459631996859561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 282}], {
             RGBColor[
             0.4313520567316361, 0.5404586473297133, 0.9499024869412066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 285}], {
             RGBColor[
             0.43044112316572336`, 0.539501198395415, 0.9498506106222333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 324}], {
             RGBColor[
             0.7708285114295784, 0.8208947466695111, 0.9677529667218713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 353}], {
             RGBColor[
             0.4896439928289401, 0.5946940624103709, 0.9534796429182146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 441}], {
             RGBColor[
             0.6721454569357461, 0.7430708527371164, 0.9684583704009289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 481}], {
             RGBColor[
             0.528615923558373, 0.6281932464774869, 0.9560337283678975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 283}], {
             RGBColor[
             0.40633561638226234`, 0.5263692207135771, 0.9471123240607684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 292}], {
             RGBColor[
             0.5884464154554143, 0.6729937722703996, 0.9626645731172001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 396}], {
             RGBColor[
             0.36059204459383143`, 0.48674843796920675`, 0.9441975841158619]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 422}], {
             RGBColor[
             0.4823369028035926, 0.5890053858184805, 0.9528371089116425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 291}], {
             RGBColor[
             0.34823030169727315`, 0.47505921150781233`, 0.9434458645042415]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 311}], {
             RGBColor[
             0.3333291284098915, 0.46215256416102857`, 0.9424963749189597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 319}], {
             RGBColor[
             0.35520941727407485`, 0.4811041706398897, 0.9438905675774056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 331}], {
             RGBColor[
             0.30278444386851033`, 0.4355760265213142, 0.9405544981976436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 377}], {
             RGBColor[
             0.33279652962633643`, 0.46169125386390647`, 0.9424624381954302]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 419}], {
             RGBColor[
             0.30671146759605517`, 0.4390976842066156, 0.9408003211089753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 449}], {
             RGBColor[
             0.33644337845147504`, 0.46484997102028996`, 0.9426948121777863]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 484}], {
             RGBColor[
             0.3746188836723846, 0.4979156748859591, 0.9451273216131888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 488}], {
             RGBColor[
             0.355989977284981, 0.4817802524892497, 0.9439403041710785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 329}], {
             RGBColor[
             0.39952620036419756`, 0.5159890705741728, 0.9472725071414666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 406}], {
             RGBColor[
             0.39854168769402637`, 0.5151897988367374, 0.9471950026976821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 413}], {
             RGBColor[
             0.3478390528007359, 0.47301408684324053`, 0.9434834084411986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 486}], {
             RGBColor[
             0.406666648619943, 0.521786008141715, 0.9478346293844827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 493}], {
             RGBColor[
             0.4110225318643397, 0.5253223103898202, 0.9481775404696077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.4248483362027642, 0.5349607219867032, 0.9494103259454554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 324}], {
             RGBColor[
             0.7652357244666192, 0.8163542702607993, 0.9673126820450935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 481}], {
             RGBColor[
             0.5230231365954137, 0.6236527700687751, 0.9555934436911195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 494}], {
             RGBColor[
             0.5201180337991408, 0.6212942767453713, 0.9553647433572547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 327}], {
             RGBColor[
             0.4720665649657106, 0.57755166157246, 0.9527400143175875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 470}], {
             RGBColor[
             0.5382727146781829, 0.6355197495564626, 0.9569357767987758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 483}], {
             RGBColor[
             0.5654141188986723, 0.6580676791945506, 0.9589306171013168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 288}], {
             RGBColor[
             0.6549313067166862, 0.7243711419756109, 0.9597183744509402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 343}], {
             RGBColor[
             0.3874232199889084, 0.5099882535223356, 0.9459072428861592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 465}], {
             RGBColor[
             0.3792308495622681, 0.5028924340192898, 0.9453852322868025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 324}], {
             RGBColor[
             0.6077076569563093, 0.6796944781267988, 0.9564372219855508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 353}], {
             RGBColor[
             0.32652313835567115`, 0.45349379386765865`, 0.9421638981818942]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 432}], {
             RGBColor[
             0.39754109167741425`, 0.5130093827320782, 0.9472407639184923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 441}], {
             RGBColor[
             0.5090246024624772, 0.601870584194404, 0.9571426256646085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 467}], {
             RGBColor[
             0.31595726616423425`, 0.4443421664316135, 0.9414906501488898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 292}], {
             RGBColor[
             0.6009972615594347, 0.6838646843418348, 0.9634643019326707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 386}], {
             RGBColor[
             0.34544298290480047`, 0.470229617457682, 0.9433566971260361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 422}], {
             RGBColor[
             0.4948877489076129, 0.5998762978899156, 0.9536368377271132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 442}], {
             RGBColor[
             0.6616865855516074, 0.728723388161649, 0.9382741640746266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 444}], {
             RGBColor[
             0.37153842008572996`, 0.49622963823945987`, 0.9448950774827058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 464}], {
             RGBColor[
             0.3645799757020033, 0.49020258345585965`, 0.9444516915596856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 324}], {
             RGBColor[
             0.6067967233903968, 0.6787370291925006, 0.9563853456665775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 480}], {
             RGBColor[
             0.30451283935196516`, 0.4342611350760858, 0.940767588954661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 481}], {
             RGBColor[
             0.3645841355191912, 0.4860355290004764, 0.9446661073126037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 294}], {
             RGBColor[
             0.3535640360021597, 0.4806611301650834, 0.9437497656230245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 346}], {
             RGBColor[
             0.6060605952572575, 0.6858342419832799, 0.9648410561046065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 358}], {
             RGBColor[
             0.6783082867263004, 0.7412321443670732, 0.8866923378895949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 407}], {
             RGBColor[
             0.3318804823528336, 0.4607327301760333, 0.9424101132114793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 411}], {
             RGBColor[
             0.34752404197410536`, 0.47542959091690956`, 0.9433649025445139]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 295}], {
             RGBColor[
             0.2783997138515448, 0.4096986261746155, 0.9391748861950537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 299}], {
             RGBColor[
             0.34917438990573596`, 0.471000093334106, 0.9436845859696381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 300}], {
             RGBColor[
             0.24453403319932165`, 0.3743511516186463, 0.9372372234837936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 301}], {
             RGBColor[
             0.24470822454613433`, 0.3745342377685157, 0.9372471434233014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 389}], {
             RGBColor[
             0.6160799525078225, 0.6820196155856706, 0.9029907083115236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 451}], {
             RGBColor[
             0.3173982481531783, 0.44347719646336325`, 0.941659838315704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 456}], {
             RGBColor[
             0.21315888222098792`, 0.34137387864094904`, 0.9354504550509537]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 343}], {
             RGBColor[
             0.6792100213640373, 0.7454001443194669, 0.961265392679445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 392}], {
             RGBColor[
             0.6047262614400846, 0.6766319697061521, 0.9566751162672316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 465}], {
             RGBColor[
             0.6710176509373971, 0.7383043248164212, 0.9607433820800882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 492}], {
             RGBColor[
             0.6330015815466477, 0.7053767162533591, 0.9583210317547999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 291}], {
             RGBColor[
             0.37252787328599135`, 0.49708665287016235`, 0.9449581245656874]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 297}], {
             RGBColor[
             0.30368718046925003`, 0.43301401299308834`, 0.9407344570160809]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 314}], {
             RGBColor[
             0.376993784720644, 0.5009548008916233, 0.945242688493253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 349}], {
             RGBColor[
             0.32727845366621655`, 0.4578099368962125, 0.9420779451244871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 359}], {
             RGBColor[
             0.3206825763638751, 0.4508772516486765, 0.9417023196698447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 381}], {
             RGBColor[
             0.3928355778667233, 0.5146761658830821, 0.9462521135441735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 397}], {
             RGBColor[
             0.32550478584355136`, 0.45594569955755626`, 0.9419769373658927]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 419}], {
             RGBColor[
             0.3310090391847733, 0.4611251255689656, 0.9423125811704212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 472}], {
             RGBColor[
             0.45420788755801644`, 0.5648910332268415, 0.9509757914100881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 316}], {
             RGBColor[
             0.2961945273488252, 0.4258104193923448, 0.9402831687464623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 340}], {
             RGBColor[
             0.30496729274512285`, 0.4334089478466084, 0.9408421616000626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 355}], {
             RGBColor[
             0.2550441529807731, 0.3853979538890342, 0.9378357592570183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 362}], {
             RGBColor[
             0.4735318011646893, 0.5720794279490892, 0.9539317821898137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 378}], {
             RGBColor[
             0.2688792428810598, 0.39993951056959953`, 0.9386236471596583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 384}], {
             RGBColor[
             0.5774629231959636, 0.6539340427316671, 0.964114769817944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 297}], {
             RGBColor[
             0.32949623081577867`, 0.4553685152026632, 0.9423789868821146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 311}], {
             RGBColor[
             0.3834357503451382, 0.5065345077329535, 0.9456531648464392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 319}], {
             RGBColor[
             0.4053160392093216, 0.5254861142118146, 0.9470473575048852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 349}], {
             RGBColor[
             0.35308750401274513`, 0.4801644391057873, 0.9437224749905208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 359}], {
             RGBColor[
             0.34649162671040373`, 0.47323175385825134`, 0.9433468495358784]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 419}], {
             RGBColor[
             0.3568180895313019, 0.4834796277785405, 0.9439571110364549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 488}], {
             RGBColor[
             0.4060965992202278, 0.5261621960611746, 0.9470970940985581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 308}], {
             RGBColor[
             0.6141157342415466, 0.6952272460254716, 0.964300199411765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 386}], {
             RGBColor[
             0.5275537819779524, 0.6168541690145045, 0.9589089461824678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 422}], {
             RGBColor[
             0.6769985479807649, 0.746500849446738, 0.9691890867835449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 298}], {
             RGBColor[
             0.3719115627277682, 0.49516757792806043`, 0.9449695748726337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 317}], {
             RGBColor[
             0.369510042211686, 0.49264342760046287`, 0.944832811831974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 353}], {
             RGBColor[
             0.41743747552303107`, 0.5359850931056461, 0.9478197247082296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 418}], {
             RGBColor[
             0.40680288029807765`, 0.5267739412320891, 0.9471420977042988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 420}], {
             RGBColor[
             0.4016295654252269, 0.5222930759075917, 0.9468124586551836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 432}], {
             RGBColor[
             0.4884554288447742, 0.5955006819700657, 0.9528965904448277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 358}], {
             RGBColor[
             0.6644494522649012, 0.7292283185218826, 0.8858092652126006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 411}], {
             RGBColor[
             0.3336652075127061, 0.46342576507171906`, 0.9424818298675196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 430}], {
             RGBColor[
             0.42001174094879046`, 0.5369386246260304, 0.9483363635917095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 478}], {
             RGBColor[
             0.326064221757352, 0.45684217324708365`, 0.9419975017764762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 300}], {
             RGBColor[
             0.277557276916298, 0.4088131715420843, 0.9391269106578652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 336}], {
             RGBColor[
             0.3207174270552714, 0.45221104841385706`, 0.9416568087460446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 389}], {
             RGBColor[
             0.6491031962247988, 0.7164816355091087, 0.9048803954855953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 409}], {
             RGBColor[
             0.34211750609063435`, 0.4707467212750417, 0.943020402858831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 456}], {
             RGBColor[
             0.24618212593796424`, 0.37583589856438704`, 0.9373401422250255]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 458}], {
             RGBColor[
             0.3166969187410149, 0.44872868618867157`, 0.9414006255114561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 332}], {
             RGBColor[
             0.3328256570450433, 0.45783936227301236`, 0.9426062545354099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 395}], {
             RGBColor[
             0.30719888451376515`, 0.43564273994545805`, 0.9409733392505821]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 424}], {
             RGBColor[
             0.2760003033038396, 0.4074241965752495, 0.9390291810160707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 440}], {
             RGBColor[
             0.28520487711232945`, 0.41659263618528886`, 0.9395719005474996]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 453}], {
             RGBColor[
             0.6247861144732942, 0.6874283296968804, 0.7295261215573091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 311}], {
             RGBColor[
             0.314595057528397, 0.4424618678558795, 0.9414294972968328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 314}], {
             RGBColor[
             0.3339621422504313, 0.4592366632241241, 0.9426635508096802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 349}], {
             RGBColor[
             0.28424681119600387`, 0.4160917992287133, 0.9394988074409143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 359}], {
             RGBColor[
             0.27765093389366247`, 0.4091591139811773, 0.939123181986272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 381}], {
             RGBColor[
             0.3498039353965106, 0.47295802821558297`, 0.9436729758606008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 397}], {
             RGBColor[
             0.28247314337333873`, 0.4142275618900571, 0.93939779968232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 419}], {
             RGBColor[
             0.2879773967145607, 0.41940698790146647`, 0.9397334434868485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 353}], {
             RGBColor[
             0.3392891616577123, 0.4669116937707307, 0.9428909043233064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 418}], {
             RGBColor[
             0.32865456643275887`, 0.45770054189717363`, 0.9422132773193757]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 420}], {
             RGBColor[
             0.32348125155990815`, 0.4532196765726762, 0.9418836382702603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 432}], {
             RGBColor[
             0.41030711497945543`, 0.5264272826351502, 0.9479677700599045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 300}], {
             RGBColor[
             0.34833195297048913`, 0.4701146387015748, 0.9436366104324496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 301}], {
             RGBColor[
             0.34850614431730176`, 0.4702977248514443, 0.9436465303719576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 389}], {
             RGBColor[
             0.71987787227899, 0.7777831026685993, 0.9093900952601797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 451}], {
             RGBColor[
             0.4211961679243457, 0.5392406835462917, 0.9480592252643602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 456}], {
             RGBColor[
             0.31695680199215537`, 0.43713736572387757`, 0.9418498419996099]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 301}], {
             RGBColor[
             0.2438657876108875, 0.3736487831359845, 0.9371991678861129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 389}], {
             RGBColor[
             0.6152375155725758, 0.6811341609531395, 0.9029427327743351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 409}], {
             RGBColor[
             0.3082518254384112, 0.4353992467190725, 0.9410827401475708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 451}], {
             RGBColor[
             0.3165558112179314, 0.44259174183083205`, 0.9416118627785155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 456}], {
             RGBColor[
             0.21231644528574106`, 0.34048842400841783`, 0.9354024795137652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 458}], {
             RGBColor[
             0.28283123808879174`, 0.41338121163270236`, 0.9394629628001958]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 389}], {
             RGBColor[
             0.6154117069193885, 0.6813172471030089, 0.902952652713843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 451}], {
             RGBColor[
             0.31673000256474415`, 0.44277482798070145`, 0.9416217827180234]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 456}], {
             RGBColor[
             0.21249063663255374`, 0.3406715101582872, 0.9354123994532731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 315}], {
             RGBColor[
             0.38402814663707163`, 0.5070476116263228, 0.9456909118143257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 325}], {
             RGBColor[
             0.60310546796405, 0.6822815638009367, 0.9651099343915404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 347}], {
             RGBColor[
             0.3325955872033961, 0.4624993137204747, 0.9424136746072385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 368}], {
             RGBColor[
             0.28755097854850503`, 0.41735609286275377`, 0.9397678423930338]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 386}], {
             RGBColor[
             0.30231668099902853`, 0.4328757823378617, 0.9406087273036918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 421}], {
             RGBColor[
             0.35361048619004554`, 0.48070136298317584`, 0.9437527253879223]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 477}], {
             RGBColor[
             0.30227936951233453`, 0.43283656559966144`, 0.9406066024697219]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 366}], {
             RGBColor[
             0.4269211542312609, 0.5385983479828317, 0.9493955659950237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 435}], {
             RGBColor[
             0.41587256270546574`, 0.5269855777680581, 0.948766365052556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 473}], {
             RGBColor[
             0.44606869726325016`, 0.5575862436131975, 0.9505276355219427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 310}], {
             RGBColor[
             0.6329963906935205, 0.7093108093791551, 0.9664901071019947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 429}], {
             RGBColor[
             0.6193928494553619, 0.6975281056925251, 0.9656233014834383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 483}], {
             RGBColor[
             0.6645722934744656, 0.7356996787859316, 0.9687675097315347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 382}], {
             RGBColor[
             0.4413040155089769, 0.5555064211055456, 0.949658412906788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 416}], {
             RGBColor[
             0.36666168744596983`, 0.48427956045658016`, 0.9451430283853443]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 427}], {
             RGBColor[
             0.5473805377824077, 0.6434272056407957, 0.9575109475366602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 438}], {
             RGBColor[
             0.38718451740667825`, 0.5058503559678593, 0.9463117731908004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 460}], {
             RGBColor[
             0.3826356218205643, 0.5010691782902151, 0.9460527203166592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 499}], {
             RGBColor[
             0.431489803800638, 0.5470058442004057, 0.9490330600150992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 317}], {
             RGBColor[
             0.3298751446627489, 0.4583136714514475, 0.9423073112079196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 357}], {
             RGBColor[
             0.5108520161551441, 0.6113998287808582, 0.9553440357780669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 418}], {
             RGBColor[
             0.3671679827491406, 0.4924441850830737, 0.9446165970802444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 420}], {
             RGBColor[
             0.36199466787628987`, 0.48796331975857626`, 0.944286958031129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 372}], {
             RGBColor[
             0.721553062662221, 0.7765030554848802, 0.7697727083018097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 417}], {
             RGBColor[
             0.4754219774788715, 0.5848932948188258, 0.9518778007559092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 386}], {
             RGBColor[
             0.35856145558691244`, 0.4815921791413188, 0.9441925946051304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 421}], {
             RGBColor[
             0.40985526077792944`, 0.529417759786633, 0.9473365926893609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 422}], {
             RGBColor[
             0.5080062215897247, 0.6112388595735524, 0.9544727352062075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 423}], {
             RGBColor[
             0.40529898002979414`, 0.5254713384079271, 0.9470462705090505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 446}], {
             RGBColor[
             0.4882986612484675, 0.5952393742730437, 0.9529212838649715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 320}], {
             RGBColor[
             0.4182547315833707, 0.5366929592286284, 0.9478717995417232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 337}], {
             RGBColor[
             0.3594156374559273, 0.48364847824001705`, 0.9441988206463351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 348}], {
             RGBColor[
             0.5342813189878455, 0.6322299438380404, 0.9566352118842776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 375}], {
             RGBColor[
             0.3469202829977771, 0.4705150684532703, 0.9434872286951638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 489}], {
             RGBColor[
             0.3824739895287985, 0.5057014788533442, 0.9455918822976738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 327}], {
             RGBColor[
             0.3637723549568205, 0.48887941423768283`, 0.9444230655146444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 399}], {
             RGBColor[
             0.3255769274568194, 0.4487335982052057, 0.9422478924235905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 412}], {
             RGBColor[
             0.4352442125055743, 0.5514083936873013, 0.948954354242878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 429}], {
             RGBColor[
             0.41194046487067854`, 0.5312238587663671, 0.9474694600502773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 483}], {
             RGBColor[
             0.45711990888978227`, 0.5693954318597735, 0.9506136682983737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 319}], {
             RGBColor[
             0.3904148659219399, 0.5125794668650309, 0.9460978679196035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 331}], {
             RGBColor[
             0.3379898925163754, 0.4670513227464554, 0.9427617985398413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 349}], {
             RGBColor[
             0.3381863307253634, 0.4672577917590036, 0.9427729854052389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 377}], {
             RGBColor[
             0.36800197827420156`, 0.49316655008904764`, 0.9446697385376279]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 419}], {
             RGBColor[
             0.34191691624392023`, 0.47057298043175677`, 0.9430076214511731]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 484}], {
             RGBColor[
             0.4098243323202497, 0.5293909711111002, 0.9473346219553864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 488}], {
             RGBColor[
             0.39119542593284606`, 0.5132555487143908, 0.9461476045132763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 354}], {
             RGBColor[
             0.37922721237536905`, 0.5028892836708082, 0.9453850005284696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 376}], {
             RGBColor[
             0.4275821050643302, 0.5432805295699368, 0.9488781909409028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 400}], {
             RGBColor[
             0.371906000403281, 0.4965480178353986, 0.9449184993755017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 414}], {
             RGBColor[
             0.33000653227334786`, 0.4602568044697513, 0.9422487023165071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 415}], {
             RGBColor[
             0.4901901487669839, 0.5941085599079781, 0.9538069254819965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 379}], {
             RGBColor[
             0.3536860032675558, 0.47894280662504163`, 0.94382432157955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 380}], {
             RGBColor[
             0.2841520015730121, 0.4159921483036717, 0.9394934081731432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 390}], {
             RGBColor[
             0.4625478157787848, 0.568271091323237, 0.9521320109247731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 411}], {
             RGBColor[
             0.3083217307877971, 0.43965055387770563`, 0.9409337502511909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 478}], {
             RGBColor[
             0.30072074503244306`, 0.43306696205307016`, 0.9404494221601475]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 359}], {
             RGBColor[
             0.35095753814505637`, 0.47709990187971224`, 0.943631413463444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 373}], {
             RGBColor[
             0.43990097958363056`, 0.5549201131999628, 0.9493952371077593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 397}], {
             RGBColor[
             0.35577974762473263`, 0.482168349788592, 0.943906031159492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 398}], {
             RGBColor[
             0.36998781739591546`, 0.49488658412509984`, 0.944796274450455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 472}], {
             RGBColor[
             0.4844828493391977, 0.5911136834578773, 0.9529048852036874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 325}], {
             RGBColor[
             0.6544997559263828, 0.726796712881888, 0.9683847329743158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 347}], {
             RGBColor[
             0.3839898751657289, 0.5070144628014259, 0.9456884731900139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 368}], {
             RGBColor[
             0.3389452665108379, 0.461871241943705, 0.9430426409758091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 386}], {
             RGBColor[
             0.3537109689613614, 0.47739093141881295`, 0.9438835258864673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 401}], {
             RGBColor[
             0.38406337166063886`, 0.5070781217712756, 0.9456931563216793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 378}], {
             RGBColor[
             0.3121389602695317, 0.4425690293274434, 0.941191180613622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 357}], {
             RGBColor[
             0.46993707932268014`, 0.5741320352673606, 0.9528039529765385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 418}], {
             RGBColor[
             0.32625304591667664`, 0.45517639156957607`, 0.942076514278716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 420}], {
             RGBColor[
             0.3210797310438259, 0.45069552624507864`, 0.9417468752296007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 321}], {
             RGBColor[
             0.5600642981496387, 0.6512228945865043, 0.9596657970613901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 330}], {
             RGBColor[
             0.47837605041877584`, 0.5740997092963447, 0.9546938919084247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 335}], {
             RGBColor[
             0.6191472936175115, 0.7005489474034178, 0.9639413058358162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 350}], {
             RGBColor[
             0.6181373874076974, 0.6997290600465343, 0.9638618023195713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 354}], {
             RGBColor[
             0.5642121864862469, 0.6548155869847447, 0.9599300968383652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 383}], {
             RGBColor[
             0.5118531007764464, 0.6092862117898428, 0.9566003604014361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 479}], {
             RGBColor[
             0.5877462294273692, 0.6750561488920392, 0.96146929903688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 482}], {
             RGBColor[
             0.5186368692450607, 0.6153405378724783, 0.9570260779244274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 496}], {
             RGBColor[
             0.5185503901614263, 0.6152656340367993, 0.9570205675536887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 331}], {
             RGBColor[
             0.35987018138055876`, 0.4860029292253165, 0.9441559911982873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 377}], {
             RGBColor[
             0.3898822671383849, 0.5121181565679087, 0.9460639311960739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 449}], {
             RGBColor[
             0.39352911596352347`, 0.5152768737242922, 0.94629630517843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 488}], {
             RGBColor[
             0.4130757147970294, 0.5322071551932519, 0.9475417971717224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 337}], {
             RGBColor[
             0.34507713082586733`, 0.4712291844713569, 0.9432851836829113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 348}], {
             RGBColor[
             0.5199428123577854, 0.6198106500693803, 0.9557215749208537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 361}], {
             RGBColor[
             0.4441616698253754, 0.5582881046600033, 0.9497558057852307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 375}], {
             RGBColor[
             0.33258177636771713`, 0.45809577468461016`, 0.9425735917317399]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 335}], {
             RGBColor[
             0.4623200370379546, 0.5730114437670781, 0.9511903943881244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 383}], {
             RGBColor[
             0.35502584419688943`, 0.4817487081535031, 0.9438494489537443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 479}], {
             RGBColor[
             0.4309189728478123, 0.5475186452556995, 0.9487183875891883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 482}], {
             RGBColor[
             0.3618096126655037, 0.4878030342361387, 0.9442751664767356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 496}], {
             RGBColor[
             0.3617231335818693, 0.4877281304004597, 0.9442696561059969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 494}], {
             RGBColor[
             0.6525221637577125, 0.7258615074854784, 0.9678825668133122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 342}], {
             RGBColor[
             0.3185785363157856, 0.45015315028228975`, 0.9415280375023865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 395}], {
             RGBColor[
             0.3323669968906672, 0.46209602180407294`, 0.942406626017561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 447}], {
             RGBColor[
             0.39279363475153894`, 0.5137355352529173, 0.9464500945977914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 452}], {
             RGBColor[
             0.3755275358420053, 0.4994795113319588, 0.9451567773941743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 463}], {
             RGBColor[
             0.3639854242814331, 0.4894823144215861, 0.944421324251823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 441}], {
             RGBColor[
             0.8485010571604195, 0.8823066835342018, 0.9749931054452732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 481}], {
             RGBColor[
             0.7049715237830463, 0.7674290772745724, 0.9625684634122417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 347}], {
             RGBColor[
             0.6030671964927072, 0.6822484149760397, 0.9651074957672285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 368}], {
             RGBColor[
             0.5580225878378161, 0.6371051941183188, 0.9624616635530238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 386}], {
             RGBColor[
             0.5727882902883397, 0.6526248835934267, 0.9633025484636819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 401}], {
             RGBColor[
             0.6031406929876171, 0.6823120739458894, 0.9651121788988939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 421}], {
             RGBColor[
             0.6240820954793567, 0.7004504642387409, 0.9664465465479124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 405}], {
             RGBColor[
             0.44106378155470255`, 0.5564490118976109, 0.9493251720366456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 428}], {
             RGBColor[
             0.3492327395485709, 0.4732892721331343, 0.943606336407321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 434}], {
             RGBColor[
             0.5213944816713447, 0.6216669025605681, 0.9556485990540463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 469}], {
             RGBColor[
             0.34871365307993185`, 0.47274367934261163`, 0.9435767752008515]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 474}], {
             RGBColor[
             0.33303777304988313`, 0.45626733552283116`, 0.9426840570235266]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 475}], {
             RGBColor[
             0.3909956891979334, 0.5130825467936697, 0.9461348774651479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 491}], {
             RGBColor[
             0.5435337278949632, 0.6393980100987748, 0.9575573006380429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 495}], {
             RGBColor[
             0.3360458829634404, 0.4594290497671641, 0.9428553644330038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 399}], {
             RGBColor[
             0.2638052763048027, 0.3946064499898915, 0.9383346922694014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 412}], {
             RGBColor[
             0.37347256135355766`, 0.49728124547198704`, 0.9450411540886887]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 483}], {
             RGBColor[
             0.3953482577377656, 0.5152682836444593, 0.9467004681441844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 431}], {
             RGBColor[
             0.3012079728213124, 0.4275647605364449, 0.9406973823694628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 433}], {
             RGBColor[
             0.30191682177055085`, 0.4281787298684911, 0.9407425495976978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 436}], {
             RGBColor[
             0.2548832337740824, 0.38522881759993527`, 0.9378265951462559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 462}], {
             RGBColor[
             0.50019394868916, 0.5891311959533474, 0.957187155257358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 487}], {
             RGBColor[
             0.5259234298731548, 0.6092871945390297, 0.9597367867645716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 406}], {
             RGBColor[
             0.518398707416028, 0.6198984501327894, 0.9552293916862762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 413}], {
             RGBColor[
             0.46769607252273754`, 0.5777227381392926, 0.9515177974297927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 486}], {
             RGBColor[
             0.5265236683419446, 0.626494659437767, 0.9558690183730768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 350}], {
             RGBColor[
             0.3796218830972776, 0.4950683711200351, 0.9461389857189142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 354}], {
             RGBColor[
             0.3256966821758271, 0.4501548980582455, 0.942207280237708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 414}], {
             RGBColor[
             0.27647600207380585`, 0.40752241885718854`, 0.9390709820257457]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 415}], {
             RGBColor[
             0.43665961856744195`, 0.5413741742954153, 0.9506292051912348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 482}], {
             RGBColor[
             0.28012136493464085`, 0.4106798489459791, 0.9393032613237702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 496}], {
             RGBColor[
             0.2800348858510065, 0.4106049451103001, 0.9392977509530316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 377}], {
             RGBColor[
             0.3374572937328204, 0.4665900124493333, 0.9427278618163119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 403}], {
             RGBColor[
             0.3176334413448191, 0.4494195878866385, 0.9414647034716928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 449}], {
             RGBColor[
             0.34110414255795896`, 0.4697487296057168, 0.942960235798668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 488}], {
             RGBColor[
             0.3606507413914649, 0.4866790110746765, 0.9442057277919602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 344}], {
             RGBColor[
             0.5879689658563793, 0.6732866144899512, 0.9623351748124223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 393}], {
             RGBColor[
             0.372319193409952, 0.4969059048500927, 0.9449448276685145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 424}], {
             RGBColor[
             0.3526366643372753, 0.47866198702755886`, 0.9437344620929435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 392}], {
             RGBColor[
             0.5400267073941769, 0.263803953319781, 0.5512458541451186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 442}], {
             RGBColor[
             0.8944723943075681, 0.5562430700622256, 0.5485661590408711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 459}], {
             RGBColor[
             0.6143483697880888, 0.3324317271998331, 0.5558258018460551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 492}], {
             RGBColor[
             0.5683020275007401, 0.2925486998669879, 0.5528917696326869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 340}], {
             RGBColor[
             0.41002874864907, 0.5293035699798223, 0.9474207172414997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 355}], {
             RGBColor[
             0.36010560888472026`, 0.4812925760222481, 0.9444143148984554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 361}], {
             RGBColor[
             0.4737324182328438, 0.5836363443804836, 0.9517130977837674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 363}], {
             RGBColor[
             0.43069732270038374`, 0.547205649990333, 0.948737700503547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 369}], {
             RGBColor[
             0.4252217061147573, 0.5424629461163553, 0.9483887990566084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 370}], {
             RGBColor[
             0.36601103268831825`, 0.48749955086532454`, 0.9447506200477787]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 379}], {
             RGBColor[
             0.44070574010620833`, 0.555874438109573, 0.9493754280105501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 498}], {
             RGBColor[
             0.35799626586430033`, 0.47907552276771487`, 0.9442941909339357]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 383}], {
             RGBColor[
             0.4141088396647623, 0.5310747609704166, 0.9481249577281705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 409}], {
             RGBColor[
             0.4471075435592875, 0.5598351465180107, 0.9502210677555436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 482}], {
             RGBColor[
             0.4208926081333766, 0.5371290870530522, 0.9485506752511617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 496}], {
             RGBColor[
             0.42080612904974224`, 0.5370541832173732, 0.9485451648804231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 409}], {
             RGBColor[
             0.35141197557738457`, 0.4787971235908452, 0.9436126382357501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 456}], {
             RGBColor[
             0.25547659542471446`, 0.3838863008801906, 0.9379323776019446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 458}], {
             RGBColor[
             0.3259913882277651, 0.45677908850447513`, 0.9419928608883752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 348}], {
             RGBColor[
             0.4611037182303421, 0.566766169080769, 0.9520485960254657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 361}], {
             RGBColor[
             0.38532257569793205`, 0.505243623671392, 0.9460828268898425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 370}], {
             RGBColor[
             0.27760119015340645`, 0.40910683015623295`, 0.9391203491538538]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 375}], {
             RGBColor[
             0.27374268224027376`, 0.4050512936959989, 0.9389006128363517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 498}], {
             RGBColor[
             0.2695864233293886, 0.4006828020586233, 0.9386639200400109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 369}], {
             RGBColor[
             0.423611208729084, 0.5411554717865852, 0.9482620148029619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 379}], {
             RGBColor[
             0.439095242720535, 0.554566963779803, 0.9492486437569035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 390}], {
             RGBColor[
             0.547957055231764, 0.6438952484779984, 0.9575563331021266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 425}], {
             RGBColor[
             0.38998819094893655`, 0.5120329037274324, 0.9461195858416782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 478}], {
             RGBColor[
             0.38612998448542224`, 0.5086911192078316, 0.945873744337501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 365}], {
             RGBColor[
             0.2615329512589815, 0.3922180922930042, 0.9382052867196455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 355}], {
             RGBColor[
             0.3070766357655428, 0.43562600110114164`, 0.9409622855645822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 362}], {
             RGBColor[
             0.525564283949459, 0.6223074751611966, 0.9570583084973776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 363}], {
             RGBColor[
             0.3776683495812062, 0.5015390750692266, 0.9452856711696738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 378}], {
             RGBColor[
             0.3209117256658294, 0.450167557781707, 0.9417501734672221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 379}], {
             RGBColor[
             0.3876767669870308, 0.5102078631884666, 0.9459233986766769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 380}], {
             RGBColor[
             0.31814276529248714`, 0.4472572048670966, 0.9415924852702701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 498}], {
             RGBColor[
             0.30496729274512285`, 0.4334089478466084, 0.9408421616000626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 387}], {
             RGBColor[
             0.4920925951241236, 0.5975224909713174, 0.9534401613501398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 403}], {
             RGBColor[
             0.371796649556267, 0.49645330362784856`, 0.9449115316362251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 405}], {
             RGBColor[
             0.4345114918448729, 0.550773747878613, 0.9489076659302975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 450}], {
             RGBColor[
             0.47038299525842886`, 0.5798976597940178, 0.9517311021238277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 469}], {
             RGBColor[
             0.3421613633701023, 0.4670684153236137, 0.9431592690945034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 491}], {
             RGBColor[
             0.5369814381851336, 0.6337227460797769, 0.9571397945316948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 395}], {
             RGBColor[
             0.3444200124410411, 0.47274103654842986`, 0.9431671165274526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 447}], {
             RGBColor[
             0.4048466503019128, 0.5243805499972741, 0.947210585107683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 453}], {
             RGBColor[
             0.6620072424005703, 0.7245266262998522, 0.7317198988341795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 463}], {
             RGBColor[
             0.376038439831807, 0.5001273291659429, 0.9451818147617146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 392}], {
             RGBColor[
             0.33721817471230664`, 0.4622490812528768, 0.9428639847024507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 433}], {
             RGBColor[
             0.3952963932154813, 0.5168076004540008, 0.9464089145221828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 465}], {
             RGBColor[
             0.4035095642096192, 0.5239214363631459, 0.9469322505153073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 387}], {
             RGBColor[
             0.6674447397423183, 0.7389994208040271, 0.9682627792826257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 424}], {
             RGBColor[
             0.5311436121151756, 0.6228714487921883, 0.958758101293083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 375}], {
             RGBColor[
             0.3905240171689849, 0.5064772700515436, 0.9467643915397175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 426}], {
             RGBColor[
             0.5320983576915901, 0.6310204433887026, 0.9563078783394409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 448}], {
             RGBColor[
             0.5432242519342643, 0.6400529455507291, 0.9571837494897176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 489}], {
             RGBColor[
             0.42607772370000624`, 0.5416636804516175, 0.9488690451422275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 498}], {
             RGBColor[
             0.38636775825809966`, 0.502108778414168, 0.9465276987433766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 358}], {
             RGBColor[
             0.916946011519999, 0.9344014303400792, 0.9069005556941826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 404}], {
             RGBColor[
             0.6876311244341455, 0.7543891264298175, 0.9706181781934278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 407}], {
             RGBColor[
             0.5705182071465322, 0.6539020161490393, 0.962618331016067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 408}], {
             RGBColor[
             0.5704518586168152, 0.6538322796375671, 0.9626145525654535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 430}], {
             RGBColor[
             0.6725083002038883, 0.7421117364442269, 0.9694276540732915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 368}], {
             RGBColor[
             0.2875127070771623, 0.4173229440378568, 0.9397654037687219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 386}], {
             RGBColor[
             0.3022784095276858, 0.4328426335129647, 0.94060628867938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 421}], {
             RGBColor[
             0.3535722147187028, 0.4806682141582789, 0.9437502867636105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 477}], {
             RGBColor[
             0.3022410980409918, 0.4328034167747644, 0.9406041638454101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 375}], {
             RGBColor[
             0.44860836377219193`, 0.5536327592940222, 0.9513370040742943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 428}], {
             RGBColor[
             0.45277933752092636`, 0.558016717158952, 0.951574534858882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 359}], {
             RGBColor[
             0.30124220709062893`, 0.43395503788430145`, 0.9404666700946781]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 371}], {
             RGBColor[
             0.31056864813363505`, 0.44333674320313654`, 0.9410132110918519]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 397}], {
             RGBColor[
             0.3060644165703052, 0.4390234857931813, 0.9407412877907261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 419}], {
             RGBColor[
             0.3115686699115271, 0.4442029118045906, 0.9410769315952545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 354}], {
             RGBColor[
             0.4654580191647487, 0.5757842488084352, 0.9513751906488546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 383}], {
             RGBColor[
             0.4130989334549482, 0.5302548736135332, 0.9480454542119257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 414}], {
             RGBColor[
             0.4162373390627274, 0.5331517696073782, 0.9482388924368922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 479}], {
             RGBColor[
             0.48899206210587104`, 0.5960248107157295, 0.9529143928473695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 482}], {
             RGBColor[
             0.4198827019235625, 0.5363091996961687, 0.9484711717349168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 356}], {
             RGBColor[
             0.43947697217868864`, 0.5471551741788344, 0.9505329751600702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 463}], {
             RGBColor[
             0.515664525056192, 0.6168132999429556, 0.9552532643454603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 367}], {
             RGBColor[
             0.4264777322735521, 0.5386635622492668, 0.9493219534643598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 399}], {
             RGBColor[
             0.396128823058742, 0.5067649344325187, 0.947593627981764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 412}], {
             RGBColor[
             0.5057961081074969, 0.6094397299146144, 0.9543000898010514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 457}], {
             RGBColor[
             0.4171563402608336, 0.5288661882335108, 0.9487911139789992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 418}], {
             RGBColor[
             0.3741804792280217, 0.4985180570747593, 0.9450634271549715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 420}], {
             RGBColor[
             0.369007164355171, 0.4940371917502619, 0.9447337881058562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 432}], {
             RGBColor[
             0.4558330277747183, 0.567244797812736, 0.9508179198955004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 441}], {
             RGBColor[
             0.5673165385597811, 0.6561059992750617, 0.9607197816416164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 372}], {
             RGBColor[
             0.7027728100250483, 0.7602365445735046, 0.7685760472104943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 414}], {
             RGBColor[
             0.36231213814127694`, 0.4882382965455886, 0.944307186955686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 415}], {
             RGBColor[
             0.522495754634913, 0.6220900519838154, 0.9558654101211753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 479}], {
             RGBColor[
             0.4350668611844205, 0.55111133765394, 0.9489826873661633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 482}], {
             RGBColor[
             0.36595750100211194`, 0.49139572663437914`, 0.9445394662537107]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 362}], {
             RGBColor[
             0.47564114418510917`, 0.5742964812036224, 0.9540519061543333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 363}], {
             RGBColor[
             0.3277452098168565, 0.4535280811116523, 0.9422792688266295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 378}], {
             RGBColor[
             0.2709885859014797, 0.4021565638241328, 0.9387437711241778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 384}], {
             RGBColor[
             0.5795722662163834, 0.6561510959862005, 0.9642348937824635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 498}], {
             RGBColor[
             0.2550441529807731, 0.3853979538890342, 0.9378357592570183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 463}], {
             RGBColor[
             0.34525777491995124`, 0.469798367541118, 0.9433548123257611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 418}], {
             RGBColor[
             0.5072299174090718, 0.6082625488989868, 0.9551132388488633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 420}], {
             RGBColor[
             0.5020566025362211, 0.6037816835744894, 0.954783599799748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 404}], {
             RGBColor[
             0.7598788159031884, 0.8097870288136109, 0.8924694599784162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 407}], {
             RGBColor[
             0.642765898615575, 0.7092999185328326, 0.8844696128010554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 408}], {
             RGBColor[
             0.6426995500858581, 0.7092301820213602, 0.8844658343504419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 430}], {
             RGBColor[
             0.7447559916729312, 0.7975096388280202, 0.8912789358582799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 371}], {
             RGBColor[
             0.3039727708312937, 0.4364040579556005, 0.9406375856372096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 397}], {
             RGBColor[
             0.2994685392679638, 0.43209080054564525`, 0.9403656623360838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 419}], {
             RGBColor[
             0.30497279260918575`, 0.4372702265570546, 0.9407013061406122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 427}], {
             RGBColor[
             0.4468555680210342, 0.5562045878861914, 0.950835383558238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 393}], {
             RGBColor[
             0.37114178259991426`, 0.495886090784826, 0.9448698040928425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 466}], {
             RGBColor[
             0.37452709066368806`, 0.4988182744791362, 0.9450855129291558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 468}], {
             RGBColor[
             0.34081606562736255`, 0.4664555076624351, 0.9430533247115591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 363}], {
             RGBColor[
             0.44137201916498003`, 0.5558718494698878, 0.9495780517119415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 370}], {
             RGBColor[
             0.37668572915291454`, 0.49616575034487936`, 0.9455909712561732]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 498}], {
             RGBColor[
             0.3686709623288966, 0.4877417222472697, 0.9451345421423303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 363}], {
             RGBColor[
             0.5462328580007727, 0.6402095551717073, 0.9583752917594248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 384}], {
             RGBColor[
             0.7980599144002996, 0.8428325700462553, 0.980330916715259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 498}], {
             RGBColor[
             0.4735318011646893, 0.5720794279490892, 0.9539317821898137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 370}], {
             RGBColor[
             0.33365063362045444`, 0.45973505595472874`, 0.9426155739759527]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 379}], {
             RGBColor[
             0.4083453410383445, 0.5281099431989772, 0.9472403819387242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 498}], {
             RGBColor[
             0.3256358667964366, 0.4513110278571191, 0.9421591448621098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 374}], {
             RGBColor[
             0.635663659063343, 0.5052542475782333, 0.5785360038316638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 437}], {
             RGBColor[
             0.3924202761526895, 0.5143164524120571, 0.9462256508861921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 435}], {
             RGBColor[
             0.2717041295248326, 0.4029086455403628, 0.9387845202749758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 473}], {
             RGBColor[
             0.30190026408261694`, 0.4335093113855023, 0.9405457907443626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 416}], {
             RGBColor[
             0.2619673864076636, 0.3926747111790484, 0.9382300271586737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 457}], {
             RGBColor[
             0.2769862752217034, 0.4084605155751545, 0.9390853306581783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 499}], {
             RGBColor[
             0.32679550276233177`, 0.4554009949228739, 0.9421200587884286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 386}], {
             RGBColor[
             0.2572338008727948, 0.3876994126552439, 0.9379604564651751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 401}], {
             RGBColor[
             0.2875862035720722, 0.4173866030077065, 0.9397700869003871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 500}], {
             RGBColor[
             0.33064551576803825`, 0.4546824150078937, 0.9425137881976593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 370}], {
             RGBColor[
             0.32817501703482804`, 0.45499235208075095`, 0.9422666725290143]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 379}], {
             RGBColor[
             0.4028697244527181, 0.5233672393249994, 0.9468914804917856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 390}], {
             RGBColor[
             0.5117315369639471, 0.6126955240231948, 0.9551991698370087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 425}], {
             RGBColor[
             0.3537626726811197, 0.4808331792726288, 0.9437624225765603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 466}], {
             RGBColor[
             0.36466633766511986`, 0.4902773858476328, 0.9444571944676085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 466}], {
             RGBColor[
             0.30545566423868076`, 0.43531399059660214`, 0.9408190154587786]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 382}], {
             RGBColor[
             0.3501054867906096, 0.4776655086697764, 0.9435293899255395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 419}], {
             RGBColor[
             0.31429923365219187`, 0.44665193187588964`, 0.941247847137786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 427}], {
             RGBColor[
             0.4561820090640404, 0.5655862932050265, 0.9513819245554118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 429}], {
             RGBColor[
             0.35581806775340985`, 0.48261345917708637`, 0.9438933905330522]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 417}], {
             RGBColor[
             0.7478817166234492, 0.7979925527343095, 0.7718137017074398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 398}], {
             RGBColor[
             0.40262005047772076`, 0.5226292462024037, 0.947019729271362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 472}], {
             RGBColor[
             0.517115082421003, 0.6188563455351812, 0.9551283400245945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 391}], {
             RGBColor[
             0.6356751090075451, 0.5052641649444103, 0.5785367334119835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 437}], {
             RGBColor[
             0.6229181279674064, 0.4942147091519526, 0.5777238698606613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 426}], {
             RGBColor[
             0.4028216683047289, 0.516461057246411, 0.9477325076849037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 489}], {
             RGBColor[
             0.296801034313145, 0.427104294309326, 0.9402936744876904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 400}], {
             RGBColor[
             0.4525664989601712, 0.5649207558103645, 0.9504701744271138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 414}], {
             RGBColor[
             0.41066703083023803`, 0.5286295424447172, 0.9478003773681193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 415}], {
             RGBColor[
             0.5708506473238741, 0.662481297882944, 0.9593586005336086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 464}], {
             RGBColor[
             0.4428275862685741, 0.5564853991288876, 0.9498496195221875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 485}], {
             RGBColor[
             0.4290277116298691, 0.5445326413187079, 0.9489703037129593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 497}], {
             RGBColor[
             0.41033543351798085`, 0.5283423295194055, 0.9477792482806022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 403}], {
             RGBColor[
             0.34764552710264524`, 0.4755348152292307, 0.9433726434694794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 449}], {
             RGBColor[
             0.3711162283157851, 0.495863956948309, 0.9448681757964545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 484}], {
             RGBColor[
             0.4092917335366947, 0.5289296608139782, 0.9473006852318571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 488}], {
             RGBColor[
             0.39066282714929107`, 0.5127942384172688, 0.9461136677897468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 380}], {
             RGBColor[
             0.2820547154284241, 0.41378776759008773`, 0.9393739708298657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 380}], {
             RGBColor[
             0.34881975674962545`, 0.47382807299684726`, 0.9435471960393205]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 390}], {
             RGBColor[
             0.5272155709553981, 0.6261070160164126, 0.9561857987909503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 478}], {
             RGBColor[
             0.36538850020905633`, 0.49090288674624577`, 0.9445032100263248]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 390}], {
             RGBColor[
             0.45768156926085446`, 0.5631563576950427, 0.9518548853845434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 411}], {
             RGBColor[
             0.3034554842698668, 0.4345358202495113, 0.9406566247109613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 478}], {
             RGBColor[
             0.29585449851451273`, 0.42795222842487585`, 0.940172296619918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 419}], {
             RGBColor[
             0.37712579411203384`, 0.5010691407914603, 0.9452511000149411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 439}], {
             RGBColor[
             0.4123832504197848, 0.5316073773539542, 0.9474976739539265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 416}], {
             RGBColor[
             0.31226943364391224`, 0.43831839341615175`, 0.9413592686952521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 427}], {
             RGBColor[
             0.4929882839803501, 0.5974660386003674, 0.9537271878465681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 429}], {
             RGBColor[
             0.39262434266971963`, 0.5144932045724273, 0.9462386538242085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 499}], {
             RGBColor[
             0.3770975499985805, 0.5010446771599772, 0.9452493003250071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 479}], {
             RGBColor[
             0.38270777547462, 0.5055819624590381, 0.9456529509292344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 482}], {
             RGBColor[
             0.3135984152923114, 0.44586635143947717`, 0.9412097298167816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 496}], {
             RGBColor[
             0.313511936208677, 0.4457914476037982, 0.941204219446043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 435}], {
             RGBColor[
             0.5813232872153056, 0.6579915300772112, 0.9643346118379487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 391}], {
             RGBColor[
             0.41594177828000034`, 0.5346895953296622, 0.9477244202024968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 421}], {
             RGBColor[
             0.3232933085143353, 0.4510446827756659, 0.9419453394600638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 403}], {
             RGBColor[
             0.4481176202825006, 0.5594335780100048, 0.950638114838775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 405}], {
             RGBColor[
             0.5108324625711065, 0.6137540222607692, 0.9546342491328474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 491}], {
             RGBColor[
             0.6133024089113671, 0.6967030204619331, 0.9628663777342448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 487}], {
             RGBColor[
             0.6796393199826323, 0.7480297804811711, 0.9698408326011635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 490}], {
             RGBColor[
             0.545039642998806, 0.6415267617993596, 0.957326663724315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 409}], {
             RGBColor[
             0.6797977447469121, 0.7430677106860969, 0.9068362249753008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 451}], {
             RGBColor[
             0.6881017305264323, 0.7502602057978565, 0.9073653476062455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 456}], {
             RGBColor[
             0.583862364594242, 0.6481568879754422, 0.9011559643414953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 458}], {
             RGBColor[
             0.6543771573972926, 0.7210496755997268, 0.9052164476279259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 425}], {
             RGBColor[
             0.4781085191837997, 0.583572955964042, 0.9530567408757249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 478}], {
             RGBColor[
             0.4742503127202854, 0.5802311714444413, 0.9528108993715478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 459}], {
             RGBColor[
             0.3370560771822657, 0.46210868051961407`, 0.9428536559911737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 465}], {
             RGBColor[
             0.32902580428566636`, 0.45515326174983106`, 0.9423419741030938]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 492}], {
             RGBColor[
             0.291009734894917, 0.42222565318676886`, 0.9399196237778056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 468}], {
             RGBColor[
             0.3048506517688734, 0.4353040738524727, 0.940761640343463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 398}], {
             RGBColor[
             0.3676582988813212, 0.4928688722727632, 0.9446478395906174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 445}], {
             RGBColor[
             0.3323598527239878, 0.45798331514731483`, 0.942556530564879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 460}], {
             RGBColor[
             0.3360923419013654, 0.461906397926221, 0.9427690903018078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 440}], {
             RGBColor[
             0.336214465614487, 0.46563380431004386`, 0.9426442663395447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 447}], {
             RGBColor[
             0.4186351108767944, 0.5363234215190573, 0.9480891736228575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 453}], {
             RGBColor[
             0.6757957029754518, 0.7364694978216354, 0.7325984873493541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 463}], {
             RGBColor[
             0.3898269004066886, 0.5120702006877262, 0.9460604032768891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 422}], {
             RGBColor[
             0.44914417711918186`, 0.5602555151455453, 0.9507220977822067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 443}], {
             RGBColor[
             0.3270586445463271, 0.45770349228575125`, 0.9420608655172562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 446}], {
             RGBColor[
             0.42943661677792455`, 0.5442560298450366, 0.9491706464409708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 419}], {
             RGBColor[
             0.309795002088862, 0.4423386744659344, 0.9409759238366602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 472}], {
             RGBColor[
             0.4329938504621051, 0.5461045821238103, 0.9496391340763272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 445}], {
             RGBColor[
             0.2974084421326723, 0.4277101600020923, 0.9403294575883192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 460}], {
             RGBColor[
             0.30114093131004993`, 0.43163324278099846`, 0.9405420173252479]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 472}], {
             RGBColor[
             0.4472019202332879, 0.5588228164603182, 0.95052937736729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 412}], {
             RGBColor[
             0.33527713385355656`, 0.4571354294395099, 0.942865980997635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 414}], {
             RGBColor[
             0.3549909261691888, 0.481897030710179, 0.9438406858027182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 415}], {
             RGBColor[
             0.5151745426628249, 0.6157487861484058, 0.9553989089682073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 464}], {
             RGBColor[
             0.3871514816075249, 0.5097528873943493, 0.9458899279567864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 450}], {
             RGBColor[
             0.42884933742042036`, 0.5439232929170756, 0.9490846141731614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 454}], {
             RGBColor[
             0.3590995575892352, 0.4854557207404035, 0.9441024841636834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 471}], {
             RGBColor[
             0.37015216478005625`, 0.4950289335689029, 0.9448067465204457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 475}], {
             RGBColor[
             0.34290974165009536`, 0.4714329158977298, 0.9430708834081336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 500}], {
             RGBColor[
             0.3757636209178392, 0.4998892948354643, 0.9451643035435294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 431}], {
             RGBColor[
             0.44744367432104154`, 0.5602345923865357, 0.9502125603578615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 436}], {
             RGBColor[
             0.4011189352738116, 0.5178986494500262, 0.9473417731346547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 459}], {
             RGBColor[
             0.4643959671610172, 0.5749178163975102, 0.9512927454673008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 462}], {
             RGBColor[
             0.6464296501888891, 0.7218010278034384, 0.9667023332457567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 487}], {
             RGBColor[
             0.6721591313728839, 0.7419570263891206, 0.9692519647529704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 405}], {
             RGBColor[
             0.3905365170032499, 0.5126848349173004, 0.9461056194189327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 449}], {
             RGBColor[
             0.35129237592778384`, 0.4786935323856142, 0.9436050174518353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 491}], {
             RGBColor[
             0.4930064633435105, 0.5956338331184643, 0.9543377480203301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 407}], {
             RGBColor[
             0.41345101152972163`, 0.5292876146225709, 0.9481872353003005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 408}], {
             RGBColor[
             0.4133846630000047, 0.5292178781110987, 0.948183456849687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 434}], {
             RGBColor[
             0.5335820594084979, 0.632223169831022, 0.9564251807304058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 469}], {
             RGBColor[
             0.3609012308170851, 0.4832999466130656, 0.9443533568772111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 474}], {
             RGBColor[
             0.34522535078703637`, 0.46682360279328505`, 0.9434606386998862]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 491}], {
             RGBColor[
             0.5557213056321164, 0.6499542773692287, 0.9583338823144025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 413}], {
             RGBColor[
             0.46671155985256635`, 0.5769234664018572, 0.9514402929860082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 476}], {
             RGBColor[
             0.43067498213772254`, 0.5457103940363199, 0.9491440741199128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 486}], {
             RGBColor[
             0.5255391556717735, 0.6256953877003317, 0.9557915139292923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 493}], {
             RGBColor[
             0.5298950389161701, 0.6292316899484369, 0.9561344250144173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 408}], {
             RGBColor[
             0.2962717457123913, 0.4287307678303204, 0.9401836096723262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 430}], {
             RGBColor[
             0.39832818729946434`, 0.5170102246369803, 0.9469967111801643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{408, 430}], {
             RGBColor[
             0.3982618387697474, 0.516940488125508, 0.9469929327295508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 456}], {
             RGBColor[
             0.2768766744600774, 0.4024219737413752, 0.939295971714731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 458}], {
             RGBColor[
             0.3473914672631281, 0.47531476136565975`, 0.9433564550011616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 496}], {
             RGBColor[
             0.3465106401032022, 0.47455183315139227`, 0.943300329473416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{411, 478}], {
             RGBColor[
             0.32002422772929773`, 0.45161063399890977`, 0.9416126386979656]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 476}], {
             RGBColor[
             0.3799723472444321, 0.5035346820428231, 0.9454324798634293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 486}], {
             RGBColor[
             0.474836520778483, 0.5835196757068348, 0.9520799196728088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 493}], {
             RGBColor[
             0.47919240402287966`, 0.58705597795494, 0.9524228307579338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 415}], {
             RGBColor[
             0.47327507453289175`, 0.5794575727827584, 0.952729111909213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 485}], {
             RGBColor[
             0.3314521388388867, 0.4615089162185224, 0.9423408150885637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{415, 464}], {
             RGBColor[
             0.5054356299712278, 0.6073134294669289, 0.9547783540632813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{415, 485}], {
             RGBColor[
             0.4916357553325228, 0.5953606716567492, 0.9538990382540529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 427}], {
             RGBColor[
             0.418345955917343, 0.5262391779514018, 0.9492118033251243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 429}], {
             RGBColor[
             0.3179820146067126, 0.44326634392346176`, 0.9417232693027647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 499}], {
             RGBColor[
             0.3024552219355734, 0.4298178165110118, 0.9407339158035634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{417, 461}], {
             RGBColor[
             0.4273165975916754, 0.5432268326072317, 0.9488125684874142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 420}], {
             RGBColor[
             0.35837256913021753`, 0.4848260398767048, 0.9440561611019255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 432}], {
             RGBColor[
             0.4451984325497649, 0.5580336459391788, 0.9501402928915696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 432}], {
             RGBColor[
             0.4400251176769141, 0.5535527806146814, 0.9498106538424543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 439}], {
             RGBColor[
             0.36950671115147626`, 0.4944698740772695, 0.9447656187859849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 423}], {
             RGBColor[
             0.370030832957217, 0.49492384204227424`, 0.9447990153639839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 477}], {
             RGBColor[
             0.3232559970276413, 0.4510054660374656, 0.941943214626094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 443}], {
             RGBColor[
             0.44880350275608827`, 0.5599604401350249, 0.9507003903130369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 446}], {
             RGBColor[
             0.5511814749876858, 0.6465129776943104, 0.9578101712367515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 446}], {
             RGBColor[
             0.44847423342775505`, 0.5607454565286851, 0.9503837065395946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 477}], {
             RGBColor[
             0.318699716279506, 0.4470590446587598, 0.9416528924457837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 440}], {
             RGBColor[
             0.3050158844045614, 0.4374152609398353, 0.9407001081050334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 453}], {
             RGBColor[
             0.6445971217655264, 0.7082509544514268, 0.7306543291148428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 470}], {
             RGBColor[
             0.3651121569129101, 0.48946763166008495`, 0.9445293894482181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{425, 466}], {
             RGBColor[
             0.3310433198849724, 0.46115481778848, 0.9423147655063246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 448}], {
             RGBColor[
             0.5555219030700083, 0.6500367327455965, 0.9581518656349038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 489}], {
             RGBColor[
             0.4383753748357503, 0.5516474676464849, 0.9498371612874137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 460}], {
             RGBColor[
             0.4343198902919375, 0.5430287957850369, 0.9501214952564393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 499}], {
             RGBColor[
             0.48317407227201126`, 0.5889654616952273, 0.9531018349548793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 495}], {
             RGBColor[
             0.25640241869446195`, 0.3868255772731414, 0.9379131104800389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{429, 499}], {
             RGBColor[
             0.3828101309613807, 0.5059926276672873, 0.9456133009325197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 433}], {
             RGBColor[
             0.3781820028454647, 0.5019839757097635, 0.9453184007014666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 436}], {
             RGBColor[
             0.33114841484899626`, 0.45903406344120773`, 0.9424024462500247]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 459}], {
             RGBColor[
             0.39442544673620195`, 0.5160532303886918, 0.9463534185826709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 462}], {
             RGBColor[
             0.5764591297640738, 0.66293644179462, 0.9617630063611268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 487}], {
             RGBColor[
             0.6021886109480686, 0.6830924403803023, 0.9643126378683404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{432, 467}], {
             RGBColor[
             0.4452671555832814, 0.5580931703766907, 0.950144671862496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 462}], {
             RGBColor[
             0.5771679787133123, 0.6635504111266661, 0.9618081735893618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 469}], {
             RGBColor[
             0.44123193093372726`, 0.5485178372760227, 0.950676783894612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 474}], {
             RGBColor[
             0.42555605090367854`, 0.5320414934562422, 0.9497840657172869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 495}], {
             RGBColor[
             0.4285641608172358, 0.5352032077005752, 0.9499553731267643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 459}], {
             RGBColor[
             0.34810070768897194`, 0.47371728745218217`, 0.943482631359464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 462}], {
             RGBColor[
             0.5301343907168439, 0.6206004988581103, 0.9588922191379199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 487}], {
             RGBColor[
             0.5558638719008386, 0.6407564974437926, 0.9614418506451334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 457}], {
             RGBColor[
             0.2731688243556535, 0.4044481326745715, 0.9388679324787692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 460}], {
             RGBColor[
             0.27412386991620813`, 0.40545194611210045`, 0.9389223209105795]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 453}], {
             RGBColor[
             0.6538016955740161, 0.7174193940614662, 0.7311970486462718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 470}], {
             RGBColor[
             0.37431673072139987`, 0.4986360712701243, 0.945072108979647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 467}], {
             RGBColor[
             0.5567506663683444, 0.6469543718390166, 0.960046533608612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 444}], {
             RGBColor[
             0.6814776231492587, 0.7458653902022621, 0.9395352314898215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 492}], {
             RGBColor[
             0.6454554218083082, 0.7146647699292135, 0.9372399286735581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{443, 446}], {
             RGBColor[
             0.42909594241483096`, 0.5439609548345163, 0.9491489389718009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{444, 492}], {
             RGBColor[
             0.3553072563424307, 0.4821710200070243, 0.9438608420816373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{445, 460}], {
             RGBColor[
             0.2658424851527165, 0.39674768565555013`, 0.9384507082995095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 453}], {
             RGBColor[
             0.7362223408363235, 0.7881090112704796, 0.7366419559295845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 463}], {
             RGBColor[
             0.4502535382675603, 0.5637097141365705, 0.9501038718571195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{449, 488}], {
             RGBColor[
             0.3943096759744297, 0.5159529555736522, 0.9463460417721028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 454}], {
             RGBColor[
             0.4552445862877823, 0.5667855308222021, 0.9507664960905875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 469}], {
             RGBColor[
             0.39677273423064097`, 0.5124238585284703, 0.9471767930707413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 471}], {
             RGBColor[
             0.46629719347860343`, 0.5763587436507014, 0.9514707584473499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 475}], {
             RGBColor[
             0.43905477034864254`, 0.5527627259795284, 0.9497348953350377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 491}], {
             RGBColor[
             0.5915928090456724, 0.6790781892846334, 0.9611573185079327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 500}], {
             RGBColor[
             0.47190864961638646`, 0.5812191049172628, 0.9518283154704336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{451, 456}], {
             RGBColor[
             0.2851806602395977, 0.4096144688531348, 0.9398250943456757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{453, 463}], {
             RGBColor[
             0.7074141303662178, 0.7638557904391485, 0.7346131855836162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 469}], {
             RGBColor[
             0.3270229543994557, 0.4539562863517981, 0.9421946630612634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 471}], {
             RGBColor[
             0.3965474136474182, 0.5178911714740293, 0.946488628437872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 475}], {
             RGBColor[
             0.36930499051745735`, 0.49429515380285616`, 0.9447527653255597]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 500}], {
             RGBColor[
             0.4021588697852012, 0.5227515327405907, 0.9468461854609556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{456, 458}], {
             RGBColor[
             0.25145608711045797`, 0.3804039386550051, 0.937676194367356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{461, 486}], {
             RGBColor[
             0.4432733401704706, 0.5561812350757589, 0.950068741714691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{461, 493}], {
             RGBColor[
             0.44762922341486727`, 0.5597175373238641, 0.950411652799816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{462, 487}], {
             RGBColor[
             0.8011745868159161, 0.8446588757972048, 0.9808024107562356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 485}], {
             RGBColor[
             0.36361269427722276`, 0.4893647729026928, 0.9443900572426319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 497}], {
             RGBColor[
             0.34492041616533453`, 0.47317446110339034`, 0.9431990018102749]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 468}], {
             RGBColor[
             0.3082359598326471, 0.43823625754678297`, 0.9409773491797763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 471}], {
             RGBColor[
             0.33807556159027685`, 0.46352949918029746`, 0.9428989254180257]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 474}], {
             RGBColor[
             0.25287522231226567`, 0.3831182702382858, 0.9377122418640922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 475}], {
             RGBColor[
             0.31083313846031596`, 0.43993348150912437`, 0.9411630623057134]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 491}], {
             RGBColor[
             0.4633711771573457, 0.5662489448142294, 0.9525854854786084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 495}], {
             RGBColor[
             0.25588333222582293`, 0.38627998448261874`, 0.9378835492735694]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 475}], {
             RGBColor[
             0.3803575977082784, 0.5038683666313555, 0.945457027682322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 500}], {
             RGBColor[
             0.41321147697602234`, 0.53232474556909, 0.9475504478177179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{474, 495}], {
             RGBColor[
             0.2402074521957742, 0.3698036406628382, 0.9369908310962445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{476, 493}], {
             RGBColor[
             0.44315582630803585`, 0.5558429055894027, 0.9501266118918383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{479, 482}], {
             RGBColor[
             0.38949154394323426`, 0.5116362885416735, 0.9460786684522255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{480, 481}], {
             RGBColor[
             0.40268763974461463`, 0.5229531831581578, 0.9469507067003251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{482, 496}], {
             RGBColor[
             0.3202957046772913, 0.45184577368643375`, 0.9416299369690342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{484, 500}], {
             RGBColor[
             0.43496851034827405`, 0.5511695943358411, 0.9489367867452085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{485, 497}], {
             RGBColor[
             0.33112054152662945`, 0.46122170329321077`, 0.9423196860010467]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{486, 493}], {
             RGBColor[
             0.5380199998420867, 0.6358278992534145, 0.9567740517012179]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.15793718311639351`], {
             RGBColor[
             0.3784898508575525, 0.502250618184943, 0.9453380165045775]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.15793718311639351`], {
             RGBColor[
             0.22167695193984016`, 0.3503269099922762, 0.9359355465200875]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.15793718311639351`], {
             RGBColor[
             0.2401070432970385, 0.3696981045439751, 0.9369851129580031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.15793718311639351`], {
             RGBColor[
             0.6352219969358905, 0.7147408593942319, 0.9644261489750896]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.15793718311639351`], {
             RGBColor[
             0.30221228616984497`, 0.4349746525031236, 0.9405219146631361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.15793718311639351`], {
             RGBColor[
             0.3100000016602304, 0.4429281532101355, 0.9409739038769197]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.15793718311639351`], {
             RGBColor[
             0.34393576952958826`, 0.47232160967728587`, 0.9431362609973339]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.15793718311639351`], {
             RGBColor[
             0.2876866935075995, 0.4197073336393358, 0.9396947036497099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.15793718311639351`], {
             RGBColor[
             0.2759857472462627, 0.40740889723582874`, 0.9390283520701255]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.15793718311639351`], {
             RGBColor[
             0.4172916525522569, 0.5358587885776371, 0.947810432997478]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.15793718311639351`], {
             RGBColor[
             0.3665917725171158, 0.4919451007412622, 0.9445798814737825]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.15793718311639351`], {
             RGBColor[
             0.6831488138062046, 0.7524003125594739, 0.9690535474377201]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.15793718311639351`], {
             RGBColor[
             0.405388244052324, 0.5255486544177023, 0.9470519583336331]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.15793718311639351`], {
             RGBColor[
             0.4844777007102953, 0.5923598487651379, 0.9525590057816591]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.15793718311639351`], {
             RGBColor[
             0.6353069280400749, 0.7148098102907114, 0.9644328350627239]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.15793718311639351`], {
             RGBColor[
             0.29419324763757476`, 0.4265461345692988, 0.9400652422818278]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.15793718311639351`], {
             RGBColor[
             0.26164266141753834`, 0.39233340462567323`, 0.9382115345508736]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.15793718311639351`], {
             RGBColor[
             0.30164086751540625`, 0.43437405526727335`, 0.9404893732161039]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.15793718311639351`], {
             RGBColor[
             0.42138611701259165`, 0.5394052078994116, 0.9480713286522978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.15793718311639351`], {
             RGBColor[
             0.33185693197416005`, 0.4618595276868017, 0.9423666081491988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.15793718311639351`], {
             RGBColor[
             0.9945334585452018, 0.9907159455173371, 0.6463788821075999]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.15793718311639351`], {
             RGBColor[
             0.5612857371405044, 0.6547160729017911, 0.9586056157665532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.15793718311639351`], {
             RGBColor[
             0.30339639440360694`, 0.4362192253336057, 0.9405893478753177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.15793718311639351`], {
             RGBColor[
             0.5371642234967091, 0.635133141463952, 0.9567066818524977]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.15793718311639351`], {
             RGBColor[
             0.4257039583555728, 0.5431451050496858, 0.9483464576845554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.15793718311639351`], {
             RGBColor[
             0.3940964257134736, 0.5157682489158819, 0.9463324536540445]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.15793718311639351`], {
             RGBColor[
             0.26220920774123596`, 0.39292888073299104`, 0.938243798525878]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.15793718311639351`], {
             RGBColor[
             0.40018514364644736`, 0.5210419903615623, 0.9467204213766918]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.15793718311639351`], {
             RGBColor[
             0.8866695456241197, 0.9124702439497583, 0.9890525268725179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.15793718311639351`], {
             RGBColor[
             0.9858894591608747, 0.9884329429857324, 0.8835117088208154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.15793718311639351`], {
             RGBColor[
             0.23986054610835603`, 0.36943902036984544`, 0.9369710753077676]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.15793718311639351`], {
             RGBColor[
             0.7488512770935687, 0.8037275762367784, 0.9756021549537764]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.15793718311639351`], {
             RGBColor[
             0.301519026900481, 0.43424599305584566`, 0.940482434573331]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.15793718311639351`], {
             RGBColor[
             0.27970478632745144`, 0.41131784311085506`, 0.9392401458439739]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.15793718311639351`], {
             RGBColor[
             0.2951216739187321, 0.42752196945642135`, 0.940118114785056]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.15793718311639351`], {
             RGBColor[
             0.25107275389378836`, 0.3812237616473677, 0.937609593954173]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.15793718311639351`], {
             RGBColor[
             0.29785915908594424`, 0.4303992399337456, 0.9402740105155823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.15793718311639351`], {
             RGBColor[
             0.3713166374639456, 0.49603754127958893`, 0.9448809456901603]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.15793718311639351`], {
             RGBColor[
             0.6273482627623936, 0.7083486072845049, 0.9638062997785133]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.15793718311639351`], {
             RGBColor[
             0.2818432437540387, 0.4135654974522302, 0.9393619278308538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.15793718311639351`], {
             RGBColor[
             0.40442377631597815`, 0.5247132809400374, 0.9469905033023185]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.15793718311639351`], {
             RGBColor[
             0.36566575827646075`, 0.49114303374883583`, 0.9445208766652101]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.15793718311639351`], {
             RGBColor[
             0.34740878974107187`, 0.4753297652254016, 0.9433575587741385]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.15793718311639351`], {
             RGBColor[
             0.2739066332228752, 0.40522361657380557`, 0.9389099496022671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.15793718311639351`], {
             RGBColor[
             0.24540869126065867`, 0.3752704726976356, 0.937287033966446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.15793718311639351`], {
             RGBColor[
             0.43345750306213526`, 0.5498608357700221, 0.9488405066970671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.15793718311639351`], {
             RGBColor[
             0.37259240417381656`, 0.4971425462817799, 0.9449622364167971]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.15793718311639351`], {
             RGBColor[
             0.5560612517279696, 0.6504746002835097, 0.9581943251369578]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.15793718311639351`], {
             RGBColor[
             0.2880405985751694, 0.42007931030422907`, 0.9397148580197523]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.15793718311639351`], {
             RGBColor[
             0.30042727594011637`, 0.43309849357549357`, 0.9404202609712391]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.15793718311639351`], {
             RGBColor[
             0.28562726693914026`, 0.41754274574069905`, 0.9395774223532847]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.15793718311639351`], {
             RGBColor[
             0.24516318722034802`, 0.37501243238541393`, 0.937273052874541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.15793718311639351`], {
             RGBColor[
             0.6028108329249344, 0.6884280163438383, 0.9618746234181415]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.15793718311639351`], {
             RGBColor[
             0.26205223286463425`, 0.3927638901849006, 0.938234859038879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.15793718311639351`], {
             RGBColor[
             0.6967361938056322, 0.7630148770829396, 0.9704078104947778]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.15793718311639351`], {
             RGBColor[
             0.4636779048528063, 0.5754736374679031, 0.9509215696595948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.15793718311639351`], {
             RGBColor[
             0.32199072264166095`, 0.45331391305309066`, 0.9417379420148783]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.15793718311639351`], {
             RGBColor[
             0.3569997755298925, 0.4836369950587158, 0.9439686879076264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.15793718311639351`], {
             RGBColor[
             0.9382510295373035, 0.9534682994503562, 0.989409079669249]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.15793718311639351`], {
             RGBColor[
             0.2788764444926004, 0.4104472033225209, 0.9391929730019011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.15793718311639351`], {
             RGBColor[
             0.4120985524313363, 0.531360786265697, 0.9474795332498511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.15793718311639351`], {
             RGBColor[
             0.33151244588043427`, 0.4615611511467909, 0.9423446577999236]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.15793718311639351`], {
             RGBColor[
             0.2806776698832937, 0.41234040541242545`, 0.9392955501232269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.15793718311639351`], {
             RGBColor[
             0.26730808810799495`, 0.39828812728614216`, 0.9385341722196474]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.15793718311639351`], {
             RGBColor[
             0.384809920085961, 0.5077247444946748, 0.9457407257271939]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.15793718311639351`], {
             RGBColor[
             0.3597486052916734, 0.48601789323816946`, 0.9441438409093524]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.15793718311639351`], {
             RGBColor[
             0.5929328239825675, 0.6804086036851932, 0.9610969903698593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.15793718311639351`], {
             RGBColor[
             0.5073336044535962, 0.6109153010706795, 0.9543583062482658]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.15793718311639351`], {
             RGBColor[
             0.23927221469162774`, 0.3688206467484977, 0.9369375707039432]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.15793718311639351`], {
             RGBColor[
             0.40257096011335275`, 0.5231084646705735, 0.9468724434922683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.15793718311639351`], {
             RGBColor[
             0.33291749549543, 0.46277813450345323`, 0.9424341863189546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.15793718311639351`], {
             RGBColor[
             0.34676744567283496`, 0.4747742652283849, 0.9433166928972287]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.15793718311639351`], {
             RGBColor[
             0.29963438976567475`, 0.43226511993426836`, 0.9403751072765746]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.15793718311639351`], {
             RGBColor[
             0.4288762038175493, 0.545892744627157, 0.9485485903602859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.15793718311639351`], {
             RGBColor[
             0.34223506018554384`, 0.47084854072361165`, 0.9430278933018097]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.15793718311639351`], {
             RGBColor[
             0.33843551722860254`, 0.4675575675848908, 0.9427857897843973]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.15793718311639351`], {
             RGBColor[
             0.2453764701345685, 0.37523660625117744`, 0.9372851990209821]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.15793718311639351`], {
             RGBColor[
             0.2920258346972056, 0.42426804614705327`, 0.9399418113212737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.15793718311639351`], {
             RGBColor[
             0.4058908429724596, 0.5259839803409675, 0.9470839834923934]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.15793718311639351`], {
             RGBColor[
             0.2783530927067427, 0.40989712741316464`, 0.9391631688919261]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.15793718311639351`], {
             RGBColor[
             0.24126142099932757`, 0.37091142870085464`, 0.9370508530603997]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.15793718311639351`], {
             RGBColor[
             0.3192850550014802, 0.4509703997339758, 0.9415655392653739]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.15793718311639351`], {
             RGBColor[
             0.3835829498734603, 0.5066620045659227, 0.9456625442702205]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.15793718311639351`], {
             RGBColor[
             0.2998550860276462, 0.4324970856985516, 0.9403876756022029]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.15793718311639351`], {
             RGBColor[
             0.6723897002033323, 0.7439952112406182, 0.9679811795434189]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.15793718311639351`], {
             RGBColor[
             0.3590454686932877, 0.4854088716573207, 0.9440990376670626]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.15793718311639351`], {
             RGBColor[
             0.5302367942117492, 0.6295091422932886, 0.9561613292431761]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.15793718311639351`], {
             RGBColor[
             0.3130914580392557, 0.4456058173445317, 0.9411708887437237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.15793718311639351`], {
             RGBColor[
             0.48830400009874925`, 0.595466210981508, 0.9528602260857146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.15793718311639351`], {
             RGBColor[
             0.3481648991511409, 0.47598466919323945`, 0.9434057373971468]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.15793718311639351`], {
             RGBColor[
             0.992962743789591, 0.9873563454787078, 0.4754162742871937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.15793718311639351`], {
             RGBColor[
             0.625732984558162, 0.7070372516708557, 0.9636791391613172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.15793718311639351`], {
             RGBColor[
             0.33226604292056217`, 0.46221387902606115`, 0.9423926763369409]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.15793718311639351`], {
             RGBColor[
             0.6060759061011523, 0.6910787498381623, 0.9621316619389304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.15793718311639351`], {
             RGBColor[
             0.9795470542153255, 0.9842668070391905, 0.9195056816175693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.15793718311639351`], {
             RGBColor[
             0.23982054181110918`, 0.36939697331702004`, 0.9369687971222204]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.15793718311639351`], {
             RGBColor[
             0.9574088652039461, 0.9677561819224613, 0.9569798610494067]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.15793718311639351`], {
             RGBColor[
             0.45026698586367564`, 0.5644203649035451, 0.9499115920771393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.15793718311639351`], {
             RGBColor[
             0.28981573255423465`, 0.4219450886662215, 0.9398159492737848]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.15793718311639351`], {
             RGBColor[
             0.3273993189094207, 0.45799856729627153`, 0.9420825729864261]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.15793718311639351`], {
             RGBColor[
             0.6940659874336286, 0.7609288915708102, 0.9701416692781137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.15793718311639351`], {
             RGBColor[
             0.2945681916628217, 0.42694022451265756`, 0.9400865947893855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.15793718311639351`], {
             RGBColor[
             0.9860136177457847, 0.9884842857513227, 0.8814540797567383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.15793718311639351`], {
             RGBColor[
             0.6160039403322353, 0.6991387752798007, 0.9629132331611889]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.15793718311639351`], {
             RGBColor[
             0.3482529267852264, 0.4760609143054868, 0.943411346440151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.15793718311639351`], {
             RGBColor[
             0.39374528781759904`, 0.5154641109191791, 0.9463100794578184]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.15793718311639351`], {
             RGBColor[
             0.3190396740732511, 0.4507578631071478, 0.941549903809609]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.15793718311639351`], {
             RGBColor[
             0.46161511460741594`, 0.5737989714190537, 0.950759179255228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.15793718311639351`], {
             RGBColor[
             0.3940964257134736, 0.5157682489158819, 0.9463324536540445]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.15793718311639351`], {
             RGBColor[
             0.8700948987293502, 0.8992540704226737, 0.9874716222553328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.15793718311639351`], {
             RGBColor[
             0.4492412533022181, 0.5635319269136281, 0.9498462333053429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.15793718311639351`], {
             RGBColor[
             0.2964429012998352, 0.428910663204615, 0.9401933567298291]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.15793718311639351`], {
             RGBColor[
             0.26965267040777585`, 0.4007524319383156, 0.9386676927131212]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.15793718311639351`], {
             RGBColor[
             0.3261039341612174, 0.4568765701353084, 0.9420000322157343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.15793718311639351`], {
             RGBColor[
             0.2841197624190679, 0.4159582629087959, 0.9394915722010196]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.15793718311639351`], {
             RGBColor[
             0.8650483065374935, 0.895230054794983, 0.9869902737869275]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.15793718311639351`], {
             RGBColor[
             0.29596655805636085`, 0.4284099962538174, 0.9401662296867999]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.15793718311639351`], {
             RGBColor[
             0.2855729419323585, 0.41748564671416705`, 0.9395743286245151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.15793718311639351`], {
             RGBColor[
             0.9531264061942908, 0.9645623310049435, 0.9642289471085608]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.15793718311639351`], {
             RGBColor[
             0.822087951598109, 0.8609746338940873, 0.9828926767816474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.15793718311639351`], {
             RGBColor[
             0.26764466236037276`, 0.3986418881654314, 0.9385533396254033]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.15793718311639351`], {
             RGBColor[
             0.31566265905413826`, 0.4478328624313024, 0.9413347233987682]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.15793718311639351`], {
             RGBColor[
             0.4150586189964345, 0.5339246471471137, 0.947668146073895]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.15793718311639351`], {
             RGBColor[
             0.3525179925311579, 0.4797550998861752, 0.9436831126580322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.15793718311639351`], {
             RGBColor[
             0.3551123878381439, 0.48200223470298686`, 0.9438484252328596]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.15793718311639351`], {
             RGBColor[
             0.5427065925152671, 0.6396326863140963, 0.9571429974440053]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.15793718311639351`], {
             RGBColor[
             0.5226248939676019, 0.6233294587628917, 0.9555620925726475]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.15793718311639351`], {
             RGBColor[
             0.7773617042938953, 0.8260001386529457, 0.9784438078920148]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.15793718311639351`], {
             RGBColor[
             0.37259240417381656`, 0.4971425462817799, 0.9449622364167971]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.15793718311639351`], {
             RGBColor[
             0.9636530807450417, 0.889055448069851, 0.31329951154459285`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.15793718311639351`], {
             RGBColor[
             0.9665553469986383, 0.9745776130689534, 0.9414972531555021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.15793718311639351`], {
             RGBColor[
             0.5454070354963795, 0.6418250275797333, 0.957355586207527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.15793718311639351`], {
             RGBColor[
             0.41822183995044665`, 0.5366644701493711, 0.9478697037159582]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.15793718311639351`], {
             RGBColor[
             0.3724052374673627, 0.49698043188792174`, 0.944950310319767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.15793718311639351`], {
             RGBColor[
             0.4742985738513105, 0.5840959750165748, 0.9517576676279496]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.15793718311639351`], {
             RGBColor[
             0.26279561318268263`, 0.3935452300322039, 0.9382771934482593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.15793718311639351`], {
             RGBColor[
             0.37514120321792754`, 0.499350187907424, 0.9451246436380734]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.15793718311639351`], {
             RGBColor[
             0.9345887651141399, 0.9506797288385384, 0.9936231048054682]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.15793718311639351`], {
             RGBColor[
             0.736027733340804, 0.7937097263945764, 0.9743240239553306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.15793718311639351`], {
             RGBColor[
             0.404835186786305, 0.525069624011343, 0.9470167180136917]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.15793718311639351`], {
             RGBColor[
             0.9861403880306273, 0.9885367085219529, 0.8793531680659148]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.15793718311639351`], {
             RGBColor[
             0.40453022590453835`, 0.5248054822233365, 0.9469972861759719]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.15793718311639351`], {
             RGBColor[
             0.8391958107373182, 0.8746159763912273, 0.9845244396587113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.15793718311639351`], {
             RGBColor[
             0.3638949436684964, 0.4896092431391472, 0.9444080419242605]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.15793718311639351`], {
             RGBColor[
             0.9586292797732987, 0.9686663651100391, 0.9549140175185902]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.15793718311639351`], {
             RGBColor[
             0.5850498501574368, 0.6740088504100282, 0.9604764137940603]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.15793718311639351`], {
             RGBColor[
             0.3506294925535046, 0.4781193761243007, 0.943562779109391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.15793718311639351`], {
             RGBColor[
             0.3048021132033892, 0.43769672491989653`, 0.9406694014813907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.15793718311639351`], {
             RGBColor[
             0.9926265985830823, 0.9866373648714795, 0.43882894300647535`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.15793718311639351`], {
             RGBColor[
             0.22560984880480164`, 0.35446063395741434`, 0.9361595191783475]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.15793718311639351`], {
             RGBColor[
             0.3340945104015635, 0.4637976056566568, 0.94250918466798]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.15793718311639351`], {
             RGBColor[
             0.3912018714312688, 0.5132611314811645, 0.9461480152147362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.15793718311639351`], {
             RGBColor[
             0.5283222385890989, 0.6279548197890732, 0.9560106084113127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.15793718311639351`], {
             RGBColor[
             0.5403764114639993, 0.6377409403632169, 0.9569595570559151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.15793718311639351`], {
             RGBColor[
             0.43629081218979215`, 0.5523149057301412, 0.9490210426492846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.15793718311639351`], {
             RGBColor[
             0.8714907091093482, 0.9003670517314206, 0.9876047558954316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.15793718311639351`], {
             RGBColor[
             0.18094129430740732`, 0.3075111510307206, 0.9336157110809254]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.15793718311639351`], {
             RGBColor[
             0.6368165440572069, 0.7160353845808458, 0.9645516775654982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.15793718311639351`], {
             RGBColor[
             0.4985700133461983, 0.6038006230144135, 0.9536684042541995]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.15793718311639351`], {
             RGBColor[
             0.4045356463039122, 0.5248101771008369, 0.9469976315590269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.15793718311639351`], {
             RGBColor[
             0.6637253324428539, 0.7372265412944985, 0.9671175963381747]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.15793718311639351`], {
             RGBColor[
             0.3166263821614996, 0.44866759094876696`, 0.9413961309829825]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.15793718311639351`], {
             RGBColor[
             0.23066014061571188`, 0.3597688108576761, 0.9364471258257416]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.15793718311639351`], {
             RGBColor[
             0.3577920714680226, 0.4843232419783724, 0.9440191723042043]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.15793718311639351`], {
             RGBColor[
             0.321457757820508, 0.45285228571259883`, 0.9417039819677567]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.15793718311639351`], {
             RGBColor[
             0.3327043087218732, 0.4625934828352771, 0.9424206022462572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.15793718311639351`], {
             RGBColor[
             0.4171788478980545, 0.5357610828558937, 0.9478032451846615]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.15793718311639351`], {
             RGBColor[
             0.25712534774865503`, 0.3875854215454478, 0.9379542802201974]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.15793718311639351`], {
             RGBColor[
             0.2761347903201828, 0.40756555095639546`, 0.9390368398526958]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.15793718311639351`], {
             RGBColor[
             0.450059876593087, 0.5642409772629758, 0.9498983952575569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.15793718311639351`], {
             RGBColor[
             0.28294056430907044`, 0.4147188509297101, 0.9394244186131225]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.15793718311639351`], {
             RGBColor[
             0.32951022615112624`, 0.459826929051754, 0.9422170781292655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.15793718311639351`], {
             RGBColor[
             0.28981573255423465`, 0.4219450886662215, 0.9398159492737848]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.15793718311639351`], {
             RGBColor[
             0.32782167471464396`, 0.45836439066653595`, 0.9421094851248603]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.15793718311639351`], {
             RGBColor[
             0.34432531471217814`, 0.47265901413533506`, 0.9431610824719073]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.15793718311639351`], {
             RGBColor[
             0.3681476038158454, 0.49329268361386697`, 0.9446790176683699]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.15793718311639351`], {
             RGBColor[
             0.2695892752795925, 0.4006857996391116, 0.938664082454356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.15793718311639351`], {
             RGBColor[
             0.26539779755890297`, 0.3962802907996302, 0.9384253839988983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.15793718311639351`], {
             RGBColor[
             0.4886985251045678, 0.5957865041543804, 0.9528912845393654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.15793718311639351`], {
             RGBColor[
             0.6941287923690254, 0.7609779552636774, 0.9701479290871287]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.15793718311639351`], {
             RGBColor[
             0.3352803392724801, 0.46482471102315265`, 0.9425847446350475]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.15793718311639351`], {
             RGBColor[
             0.34884584055520074`, 0.476574466412326, 0.9434491263812806]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.15793718311639351`], {
             RGBColor[
             0.3775672656810086, 0.5014515212755, 0.9452792301929381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.15793718311639351`], {
             RGBColor[
             0.3954190511464476, 0.5169138405888368, 0.9464167301770818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.15793718311639351`], {
             RGBColor[
             0.2862520362013061, 0.41819941784789455`, 0.9396130020385017]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.15793718311639351`], {
             RGBColor[
             0.44882592612418015`, 0.5631721913869626, 0.9498197690248177]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.15793718311639351`], {
             RGBColor[
             0.9857839073795186, 0.9883892946115845, 0.885260974997138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.15793718311639351`], {
             RGBColor[
             0.2695892752795925, 0.4006857996391116, 0.938664082454356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.15793718311639351`], {
             RGBColor[
             0.3327043087218732, 0.4625934828352771, 0.9424206022462572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.15793718311639351`], {
             RGBColor[
             0.4923366322084342, 0.5987400833961565, 0.9531776896574072]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.15793718311639351`], {
             RGBColor[
             0.31505928864242894`, 0.44731025330695845`, 0.9412962771696737]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.15793718311639351`], {
             RGBColor[
             0.3386915012799669, 0.4677792881040501, 0.9428021008617924]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.15793718311639351`], {
             RGBColor[
             0.4116278143703612, 0.5309530566172633, 0.9474495382368631]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.15793718311639351`], {
             RGBColor[
             0.3837849133107767, 0.5068369351443486, 0.945675413201857]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.15793718311639351`], {
             RGBColor[
             0.9863652656245823, 0.9886297011861438, 0.8756263643695237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.15793718311639351`], {
             RGBColor[
             0.5420225936798031, 0.6390773852456701, 0.9570891505501072]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.15793718311639351`], {
             RGBColor[
             0.29620539718267436`, 0.42866103131884814`, 0.9401798312217127]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.15793718311639351`], {
             RGBColor[
             0.31920685839167895`, 0.45090266976084187`, 0.9415605566465439]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.15793718311639351`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.15793718311639351`], {
             RGBColor[
             0.38910739835262353`, 0.5114470041717197, 0.9460145572422348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.15793718311639351`], {
             RGBColor[
             0.3026980472157365, 0.4354852181613848, 0.9405495780360805]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.15793718311639351`], {
             RGBColor[
             0.36279989644787486`, 0.4886607682753184, 0.9443382664836747]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.15793718311639351`], {
             RGBColor[
             0.40646710772714933`, 0.526483111907571, 0.9471207025729913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.15793718311639351`], {
             RGBColor[
             0.45115405829969596`, 0.5651887024620689, 0.9499681155483551]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.15793718311639351`], {
             RGBColor[
             0.32774213496000987`, 0.45829549732885616`, 0.9421044169220293]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.15793718311639351`], {
             RGBColor[
             0.2581751884801171, 0.38868887071796127`, 0.938014067096754]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.15793718311639351`], {
             RGBColor[
             0.9291406244996601, 0.9463355293983895, 0.9931034562900466]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.15793718311639351`], {
             RGBColor[
             0.4186075702409114, 0.5369985703396035, 0.9478942821089787]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.15793718311639351`], {
             RGBColor[
             0.9871684527912767, 0.9889618397205406, 0.8623154744356399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.15793718311639351`], {
             RGBColor[
             0.33038879794875203`, 0.46058790378455494`, 0.9422730599473197]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.15793718311639351`], {
             RGBColor[
             0.35991981749298807`, 0.4861661886415728, 0.9441547503994232]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.15793718311639351`], {
             RGBColor[
             0.36707651346263914`, 0.4923649589844862, 0.9446107687381916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.15793718311639351`], {
             RGBColor[
             0.2613501003508993, 0.3920259043951926, 0.9381948736309338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.15793718311639351`], {
             RGBColor[
             0.5369002236882313, 0.6349188145263739, 0.9566858988205111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.15793718311639351`], {
             RGBColor[
             0.28803228496634414`, 0.4200705721742405, 0.9397143845720286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.15793718311639351`], {
             RGBColor[
             0.8006028132537346, 0.8441562696113425, 0.98076026443262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.15793718311639351`], {
             RGBColor[
             0.33909494609596846`, 0.4681287317259446, 0.9428278080087158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.15793718311639351`], {
             RGBColor[
             0.29784157500179465`, 0.43038075794640906`, 0.9402730091280034]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.15793718311639351`], {
             RGBColor[
             0.41919164028495165`, 0.5375044624555372, 0.9479314985357121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.15793718311639351`], {
             RGBColor[
             0.432012974431648, 0.548609657674414, 0.9487484626100791]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.15793718311639351`], {
             RGBColor[
             0.3427403089163204, 0.47128616177967075`, 0.9430600873041609]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.15793718311639351`], {
             RGBColor[
             0.6377004499925125, 0.7167529792386355, 0.9646212618785796]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.15793718311639351`], {
             RGBColor[
             0.9872562023584021, 0.988998126421608, 0.8608612370197721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.15793718311639351`], {
             RGBColor[
             0.8952576019566476, 0.9193181269527371, 0.9898716633521628]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.15793718311639351`], {
             RGBColor[
             0.8568564612110988, 0.8886980996934335, 0.9862089282667493]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.15793718311639351`], {
             RGBColor[
             0.2669526888048254, 0.3979145800848937, 0.9385139327550981]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.15793718311639351`], {
             RGBColor[
             0.3974555480560665, 0.5186777518546378, 0.9465464939593593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.15793718311639351`], {
             RGBColor[
             0.8977013066384987, 0.9212666707334485, 0.9901047460862387]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.15793718311639351`], {
             RGBColor[
             0.8395540998780231, 0.8749016664265258, 0.9845586135968003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.15793718311639351`], {
             RGBColor[
             0.2695892752795925, 0.4006857996391116, 0.938664082454356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.15793718311639351`], {
             RGBColor[
             0.4120985524313363, 0.531360786265697, 0.9474795332498511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.15793718311639351`], {
             RGBColor[
             0.37905118192728326`, 0.5027368149442238, 0.9453737840239751]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.15793718311639351`], {
             RGBColor[
             0.2447417113395881, 0.37456943451162095`, 0.9372490504466494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.15793718311639351`], {
             RGBColor[
             0.3277963087319396, 0.4583424199272488, 0.9421078688268726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.15793718311639351`], {
             RGBColor[
             0.3039070967234375, 0.4367560058521449, 0.9406184316169157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.15793718311639351`], {
             RGBColor[
             0.986464031942322, 0.9886705435967077, 0.87398955088554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.15793718311639351`], {
             RGBColor[
             0.24772497361951157`, 0.3777050323175738, 0.93741894282015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.15793718311639351`], {
             RGBColor[
             0.4064946335040003, 0.5265069533519936, 0.9471224564911521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.15793718311639351`], {
             RGBColor[
             0.7308010484972366, 0.7896266004705055, 0.9738030768562707]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.15793718311639351`], {
             RGBColor[
             0.38910695627595493`, 0.5114466212671289, 0.9460145290735004]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.15793718311639351`], {
             RGBColor[
             0.6060759061011523, 0.6910787498381623, 0.9621316619389304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.15793718311639351`], {
             RGBColor[
             0.5562588814772699, 0.6506350450171104, 0.9582098832747643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.15793718311639351`], {
             RGBColor[
             0.3083294034302258, 0.4414041305914192, 0.9408702754416508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.15793718311639351`], {
             RGBColor[
             0.31247829662179827`, 0.445074727743119, 0.9411318186404006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.15793718311639351`], {
             RGBColor[
             0.3056575539631944, 0.4385958473965286, 0.9407181175671504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.15793718311639351`], {
             RGBColor[
             0.9853953152802618, 0.9882286017921804, 0.8917009517259403]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.15793718311639351`], {
             RGBColor[
             0.28705203470334867`, 0.41904026699637587`, 0.9396585607697013]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.15793718311639351`], {
             RGBColor[
             0.28292258152337885`, 0.41469994988177383`, 0.9394233945200806]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.15793718311639351`], {
             RGBColor[
             0.49457490982061725`, 0.6005572179949841, 0.9533538950701194]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.15793718311639351`], {
             RGBColor[
             0.2776960139127448, 0.4092064959394711, 0.9391257492266688]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.15793718311639351`], {
             RGBColor[
             0.34212995658763345`, 0.4707575052697621, 0.9430211961934903]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.15793718311639351`], {
             RGBColor[
             0.4256007668042487, 0.543055725714487, 0.9483398824101537]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.15793718311639351`], {
             RGBColor[
             0.28815792440552873`, 0.420202627190824, 0.9397215395522233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.15793718311639351`], {
             RGBColor[
             0.7079764824327259, 0.7717958759877828, 0.9715281374186572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.15793718311639351`], {
             RGBColor[
             0.9475713826411643, 0.9604194035345379, 0.9736321530018226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.15793718311639351`], {
             RGBColor[
             0.5197753854574539, 0.621016099385458, 0.9553377688246351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.15793718311639351`], {
             RGBColor[
             0.6309116224189601, 0.7112415031812287, 0.9640868205036948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.15793718311639351`], {
             RGBColor[
             0.2704105857268995, 0.4015490489933214, 0.9387108548693102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.15793718311639351`], {
             RGBColor[
             0.3569997755298925, 0.4836369950587158, 0.9439686879076264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.15793718311639351`], {
             RGBColor[
             0.29812367976202636`, 0.43067726793588745`, 0.9402890745767619]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.15793718311639351`], {
             RGBColor[
             0.6733818408644976, 0.7447702790656688, 0.9680800668524423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.15793718311639351`], {
             RGBColor[
             0.9158685519266547, 0.7041538740719752, 0.251164065942531]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.15793718311639351`], {
             RGBColor[
             0.5356165149626082, 0.6338766419524939, 0.9565848405672501]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.15793718311639351`], {
             RGBColor[
             0.39727661492173405`, 0.5185227689671199, 0.946535092498264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.15793718311639351`], {
             RGBColor[
             0.7195024751402691, 0.7808000690917045, 0.9726769406552193]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.15793718311639351`], {
             RGBColor[
             0.26957497433009414`, 0.4006707684344563, 0.9386632680364383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.15793718311639351`], {
             RGBColor[
             0.26825628115537903`, 0.3992847382978544, 0.93858817041097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.15793718311639351`], {
             RGBColor[
             0.3192850550014802, 0.4509703997339758, 0.9415655392653739]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.15793718311639351`], {
             RGBColor[
             0.5054313840201978, 0.6093709928287927, 0.9542085564876857]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.15793718311639351`], {
             RGBColor[
             0.9851765657254793, 0.9881381432296708, 0.8953261979543881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.15793718311639351`], {
             RGBColor[
             0.31199681496977966`, 0.4446576925361119, 0.9411011390552916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.15793718311639351`], {
             RGBColor[
             0.3391703942367055, 0.4681940811133172, 0.9428326154975274]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.15793718311639351`], {
             RGBColor[
             0.3851918675497359, 0.5080555681905589, 0.9457650630818427]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.15793718311639351`], {
             RGBColor[
             0.5054594263093968, 0.6093937588224551, 0.9542107640794136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.15793718311639351`], {
             RGBColor[
             0.5944729112049051, 0.6816589158724256, 0.9612182316775271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.15793718311639351`], {
             RGBColor[
             0.3937847702782421, 0.515498308642142, 0.9463125952452976]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.15793718311639351`], {
             RGBColor[
             0.29812367976202636`, 0.43067726793588745`, 0.9402890745767619]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.15793718311639351`], {
             RGBColor[
             0.2796691806421959, 0.4112804192781207, 0.9392381181528725]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.15793718311639351`], {
             RGBColor[
             0.5832873372789866, 0.672577963055002, 0.9603376623239713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.15793718311639351`], {
             RGBColor[
             0.6421324261266174, 0.7203510571225513, 0.9649701632747198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.15793718311639351`], {
             RGBColor[
             0.3631445053415573, 0.4889592511784795, 0.9443602246576545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.15793718311639351`], {
             RGBColor[
             0.2682312022583671, 0.39925837878700093`, 0.9385867422048861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.15793718311639351`], {
             RGBColor[
             0.41888646248628264`, 0.5372401327850123, 0.947912052876239]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.15793718311639351`], {
             RGBColor[
             0.3517473824880787, 0.4790876361988469, 0.9436340100675109]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.15793718311639351`], {
             RGBColor[
             0.2664093351265417, 0.39734348091840455`, 0.9384829895669395]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.15793718311639351`], {
             RGBColor[
             0.3674228704635589, 0.4926649560102739, 0.9446328383000188]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.15793718311639351`], {
             RGBColor[
             0.2453764701345685, 0.37523660625117744`, 0.9372851990209821]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.15793718311639351`], {
             RGBColor[
             0.9467181080918152, 0.9597830327727422, 0.975076524244226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.15793718311639351`], {
             RGBColor[
             0.3467188229394627, 0.4747321506605875, 0.9433135946996537]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.15793718311639351`], {
             RGBColor[
             0.2529348099603532, 0.38318090063450094`, 0.9377156352924987]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.15793718311639351`], {
             RGBColor[
             0.39833692363251993`, 0.5194411550797372, 0.9466026544317211]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.15793718311639351`], {
             RGBColor[
             0.7831080606325866, 0.8304892358986572, 0.9790165509891025]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.15793718311639351`], {
             RGBColor[
             0.450059876593087, 0.5642409772629758, 0.9498983952575569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.15793718311639351`], {
             RGBColor[
             0.3397052015407604, 0.46865730431989294`, 0.9428666929460302]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.15793718311639351`], {
             RGBColor[
             0.3114229575685212, 0.4441606460980535, 0.9410645733691255]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.15793718311639351`], {
             RGBColor[
             0.2561892960116076, 0.386601571820703, 0.9379009734585371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.15793718311639351`], {
             RGBColor[
             0.2606555379990374, 0.3912958753255892, 0.9381553193325082]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.15793718311639351`], {
             RGBColor[
             0.2937632488624494, 0.426094178593145, 0.9400407544877105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.15793718311639351`], {
             RGBColor[
             0.4529723096769034, 0.5667635804170346, 0.9500839729182943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.15793718311639351`], {
             RGBColor[
             0.24369159626407483`, 0.3734656969861151, 0.937189247946605]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.15793718311639351`], {
             RGBColor[
             0.2440399789577002, 0.37383186928585393`, 0.9372090878256208]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.15793718311639351`], {
             RGBColor[
             0.3326338586747388, 0.46253246254537167`, 0.9424161132315504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.15793718311639351`], {
             RGBColor[
             0.5710895874118941, 0.6626752802105269, 0.9593774107726039]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.15793718311639351`], {
             RGBColor[
             0.8404487752782038, 0.8756150563053131, 0.9846439485351557]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.15793718311639351`], {
             RGBColor[
             0.49569626931103444`, 0.601467588145974, 0.9534421725968801]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.15793718311639351`], {
             RGBColor[
             0.37079008149521286`, 0.49558146496494515`, 0.944847394009448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.15793718311639351`], {
             RGBColor[
             0.4490933235176433, 0.5634037975693966, 0.949836807350279]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.15793718311639351`], {
             RGBColor[
             0.4451234078505065, 0.5599652561522859, 0.9495838478344276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.15793718311639351`], {
             RGBColor[
             0.43259323821343065`, 0.5491122529972885, 0.9487854365051471]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.15793718311639351`], {
             RGBColor[
             0.42554400610883714`, 0.543006562452997, 0.9483362656688336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.15793718311639351`], {
             RGBColor[
             0.36853457705775655`, 0.49362786038616974`, 0.9447036752611574]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.15793718311639351`], {
             RGBColor[
             0.34692160650744, 0.47490779159497093`, 0.9433265158892907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.15793718311639351`], {
             RGBColor[
             0.28901824809094245`, 0.421106881931866, 0.9397705337133727]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.15793718311639351`], {
             RGBColor[
             0.40726874650182526`, 0.527177451122659, 0.9471717822868523]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.15793718311639351`], {
             RGBColor[
             0.4354224345994045, 0.5515627607072741, 0.9489657103971012]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.15793718311639351`], {
             RGBColor[
             0.33945424473729713`, 0.4684399381501887, 0.942850702200426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.15793718311639351`], {
             RGBColor[
             0.288960207830285, 0.4210458779379499, 0.9397672284063912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.15793718311639351`], {
             RGBColor[
             0.7168915547291956, 0.7787603982228439, 0.9724167085090819]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.15793718311639351`], {
             RGBColor[
             0.4122951547861233, 0.5315310733438919, 0.9474920605780495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.15793718311639351`], {
             RGBColor[
             0.4039162249533107, 0.5242736654599682, 0.9469581625782993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.15793718311639351`], {
             RGBColor[
             0.40323704157008167`, 0.5236853909501646, 0.9469148856136983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.15793718311639351`], {
             RGBColor[
             0.8480955971961303, 0.8817124245352161, 0.985373309236086]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.15793718311639351`], {
             RGBColor[
             0.30652552076541173`, 0.43950813553793283`, 0.9407675469924949]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.15793718311639351`], {
             RGBColor[
             0.9471841116542518, 0.9601305774665966, 0.9742877017662155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.15793718311639351`], {
             RGBColor[
             0.873577077253361, 0.9020306650565018, 0.9878037555515304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.15793718311639351`], {
             RGBColor[
             0.4288762038175493, 0.545892744627157, 0.9485485903602859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.15793718311639351`], {
             RGBColor[
             0.3020007038048038, 0.4347522660223686, 0.9405098653604551]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.15793718311639351`], {
             RGBColor[
             0.22494279174639853`, 0.3537595146951724, 0.936121531265694]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.15793718311639351`], {
             RGBColor[
             0.5193832200861992, 0.6206977218702248, 0.9553068961300607]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.15793718311639351`], {
             RGBColor[
             0.23986054610835603`, 0.36943902036984544`, 0.9369710753077676]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.15793718311639351`], {
             RGBColor[
             0.30744520797499425`, 0.44047478510674104`, 0.9408199218185253]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.15793718311639351`], {
             RGBColor[
             0.409462018078479, 0.5290771527253217, 0.9473115356122828]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.15793718311639351`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.15793718311639351`], {
             RGBColor[
             0.4630577217682475, 0.5749701449009288, 0.9508727465753729]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.15793718311639351`], {
             RGBColor[
             0.5214030325058275, 0.6223374965839916, 0.9554659031625505]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.15793718311639351`], {
             RGBColor[
             0.3300118965420216, 0.46026145072966057`, 0.9422490441229636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.15793718311639351`], {
             RGBColor[
             0.28623803669842396`, 0.4181847034827456, 0.939612204787523]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.15793718311639351`], {
             RGBColor[
             0.45983672699690087`, 0.5723551962413888, 0.9506191780680798]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.15793718311639351`], {
             RGBColor[
             0.2858665602357461, 0.41779425816750304`, 0.9395910497525237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.15793718311639351`], {
             RGBColor[
             0.3569997755298925, 0.4836369950587158, 0.9439686879076264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.15793718311639351`], {
             RGBColor[
             0.4157716243978901, 0.5345422165891611, 0.9477135781475898]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.15793718311639351`], {
             RGBColor[
             0.3306315518661595, 0.4607981650266466, 0.942288528012278]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.15793718311639351`], {
             RGBColor[
             0.4117019346362595, 0.5310172558661916, 0.9474542611146641]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.15793718311639351`], {
             RGBColor[
             0.7664759136342795, 0.8174960762545807, 0.9773588140125617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.15793718311639351`], {
             RGBColor[
             0.5198007065558461, 0.6210366561938352, 0.9553397621942546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.15793718311639351`], {
             RGBColor[
             0.8446983200509561, 0.8790035279562859, 0.9850492739091942]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.15793718311639351`], {
             RGBColor[
             0.3325573157320534, 0.4624661648955777, 0.9424112359829266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.15793718311639351`], {
             RGBColor[
             0.6359693997622602, 0.7153476346787924, 0.9644849872634081]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.15793718311639351`], {
             RGBColor[
             0.30783808439297033`, 0.4408877231318375, 0.9408422955493204]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.15793718311639351`], {
             RGBColor[
             0.5193832200861992, 0.6206977218702248, 0.9553068961300607]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.15793718311639351`], {
             RGBColor[
             0.6098837223149294, 0.6941701065806721, 0.9624314271797694]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.15793718311639351`], {
             RGBColor[
             0.5666477973126823, 0.6590692349076231, 0.9590277367851806]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.15793718311639351`], {
             RGBColor[
             0.38481507445297514`, 0.5077292089483164, 0.9457410541589022]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.15793718311639351`], {
             RGBColor[
             0.4115328182432982, 0.5308707757466455, 0.9474434851676484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.15793718311639351`], {
             RGBColor[
             0.257153496001193, 0.38761500714356745`, 0.9379558832215379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.15793718311639351`], {
             RGBColor[
             0.26907022204244796`, 0.4001402417769967, 0.938634523140371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.15793718311639351`], {
             RGBColor[
             0.6509139508150753, 0.7272181925967712, 0.9658406775466859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.15793718311639351`], {
             RGBColor[
             0.9891937029890417, 0.9897993327238724, 0.828751837479171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.15793718311639351`], {
             RGBColor[
             0.29464632978828753`, 0.42702235263676547`, 0.9400910446400358]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.15793718311639351`], {
             RGBColor[
             0.4071071964584035, 0.5270375245947884, 0.9471614884609386]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.15793718311639351`], {
             RGBColor[
             0.4844071146974401, 0.5923025438600384, 0.952553448992162]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.15793718311639351`], {
             RGBColor[
             0.6941287923690254, 0.7609779552636774, 0.9701479290871287]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.15793718311639351`], {
             RGBColor[
             0.39833692363251993`, 0.5194411550797372, 0.9466026544317211]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.15793718311639351`], {
             RGBColor[
             0.40516580724862605`, 0.525355990838338, 0.9470377848571947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.15793718311639351`], {
             RGBColor[
             0.23719934228221695`, 0.3666419264185053, 0.9368195236867672]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.15793718311639351`], {
             RGBColor[
             0.28275272105062776`, 0.41452141575513646`, 0.9394137212174435]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.15793718311639351`], {
             RGBColor[
             0.28630766723442197`, 0.4182578895909105, 0.9396161701435389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.15793718311639351`], {
             RGBColor[
             0.24246809842227124`, 0.3721797231801359, 0.9371195715545171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.15793718311639351`], {
             RGBColor[
             0.38738569046126714`, 0.5099557473317816, 0.9459048515378441]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.15793718311639351`], {
             RGBColor[
             0.26896434360838894`, 0.4000289568297203, 0.9386284935201844]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.15793718311639351`], {
             RGBColor[
             0.3132992118742998, 0.44578576327443553`, 0.9411841266343832]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.15793718311639351`], {
             RGBColor[
             0.9940128018067986, 0.9896023134003639, 0.5897086092533403]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.15793718311639351`], {
             RGBColor[
             0.47253321266543585`, 0.5826627752772667, 0.9516186919286663]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.15793718311639351`], {
             RGBColor[
             0.8661615108780599, 0.48515250431812884`, 0.2100342228061329]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.15793718311639351`], {
             RGBColor[
             0.2612473277821236, 0.39191788390925214`, 0.9381890208851804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.15793718311639351`], {
             RGBColor[
             0.5082426036212204, 0.6116532675449027, 0.9544298659925149]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.15793718311639351`], {
             RGBColor[
             0.3674693794906465, 0.4927052397919255, 0.9446358018140985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.15793718311639351`], {
             RGBColor[
             0.2848236758017663, 0.4166981205046981, 0.9395316590268178]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.15793718311639351`], {
             RGBColor[
             0.4183537584441691, 0.5367787313182172, 0.9478781094457273]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.15793718311639351`], {
             RGBColor[
             0.2792857550550818, 0.41087741467547734`, 0.9392162826329137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.15793718311639351`], {
             RGBColor[
             0.4389523327939838, 0.5546201811055768, 0.9491906323886934]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.15793718311639351`], {
             RGBColor[
             0.3869117617069193, 0.5095452540651173, 0.9458746532166957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.15793718311639351`], {
             RGBColor[
             0.30681464682369713`, 0.43981202535684166`, 0.9407840122937905]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.15793718311639351`], {
             RGBColor[
             0.9019910364315739, 0.9246871848288334, 0.9905139043433892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.15793718311639351`], {
             RGBColor[
             0.4266948494229704, 0.5440033650886325, 0.9484095963871594]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.15793718311639351`], {
             RGBColor[
             0.2719995033233183, 0.4032191021303518, 0.9388013413758333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.15793718311639351`], {
             RGBColor[
             0.5684135658503572, 0.6605027653534736, 0.9591667445526897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.15793718311639351`], {
             RGBColor[
             0.5323745719653536, 0.631244686579455, 0.9563296229388778]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.15793718311639351`], {
             RGBColor[
             0.9867834348810767, 0.9888026249201639, 0.8686962176020652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.15793718311639351`], {
             RGBColor[
             0.6360773834666271, 0.715435300714608, 0.9644934881361733]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.15793718311639351`], {
             RGBColor[
             0.40518870713703026`, 0.5253758255706918, 0.9470392440178342]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.15793718311639351`], {
             RGBColor[
             0.2627344147883538, 0.393480906639562, 0.9382737082902372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.15793718311639351`], {
             RGBColor[
             0.33517636874142503`, 0.4647346569748636, 0.9425781197247463]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.15793718311639351`], {
             RGBColor[
             0.4026097094726367, 0.5231420274179858, 0.9468749125671772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.15793718311639351`], {
             RGBColor[
             0.3582084730159227, 0.4846839080702131, 0.9440457050426271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.15793718311639351`], {
             RGBColor[
             0.3273993189094207, 0.45799856729627153`, 0.9420825729864261]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.15793718311639351`], {
             RGBColor[
             0.30429074874764006`, 0.43715924845452503`, 0.9406402800321317]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.15793718311639351`], {
             RGBColor[
             0.3327068882900057, 0.46259571712754066`, 0.9424207666140576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.15793718311639351`], {
             RGBColor[
             0.22560984880480164`, 0.35446063395741434`, 0.9361595191783475]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.15793718311639351`], {
             RGBColor[
             0.396890394299122, 0.5181882440758263, 0.9465104828617126]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[401, 0.15793718311639351`], {
             RGBColor[
             0.3327043087218732, 0.4625934828352771, 0.9424206022462572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[402, 0.15793718311639351`], {
             RGBColor[
             0.5174141947458568, 0.6190991783953541, 0.9551518872424916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[403, 0.15793718311639351`], {
             RGBColor[
             0.32782167471464396`, 0.45836439066653595`, 0.9421094851248603]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[404, 0.15793718311639351`], {
             RGBColor[
             0.530563928817335, 0.6297747249033492, 0.9561870824776614]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[405, 0.15793718311639351`], {
             RGBColor[
             0.4532513592918558, 0.5670052791680649, 0.9501017537130051]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[406, 0.15793718311639351`], {
             RGBColor[
             0.5174141947458568, 0.6190991783953541, 0.9551518872424916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[407, 0.15793718311639351`], {
             RGBColor[
             0.2963380942421082, 0.4288005043417927, 0.9401873881229397]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[408, 0.15793718311639351`], {
             RGBColor[
             0.29620539718267436`, 0.42866103131884814`, 0.9401798312217127]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[409, 0.15793718311639351`], {
             RGBColor[
             0.3728120546127475, 0.4973327964520298, 0.9449762323485366]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[410, 0.15793718311639351`], {
             RGBColor[
             0.29784157500179465`, 0.43038075794640906`, 0.9402730091280034]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[411, 0.15793718311639351`], {
             RGBColor[
             0.3276252134846518, 0.45819422582354524`, 0.942096966789009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[412, 0.15793718311639351`], {
             RGBColor[
             0.4449444189023115, 0.5598102249216055, 0.9495724428169223]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[413, 0.15793718311639351`], {
             RGBColor[
             0.4160089249592759, 0.5347477544083604, 0.9477286987295247]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[414, 0.15793718311639351`], {
             RGBColor[
             0.3130914580392557, 0.4456058173445317, 0.9411708887437237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[415, 0.15793718311639351`], {
             RGBColor[
             0.6334586910265279, 0.7133093282209853, 0.9642873350747022]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[416, 0.15793718311639351`], {
             RGBColor[
             0.23762710558090522`, 0.36709153276718626`, 0.9368438841738084]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[417, 0.15793718311639351`], {
             RGBColor[
             0.5017506314400997, 0.606382792068255, 0.9539187941615394]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[418, 0.15793718311639351`], {
             RGBColor[
             0.3635458840030683, 0.48930690520120224`, 0.9443858001510408]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[419, 0.15793718311639351`], {
             RGBColor[
             0.3152992554300839, 0.44751810047734375`, 0.9413115676411887]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[420, 0.15793718311639351`], {
             RGBColor[
             0.3531992542573668, 0.4803451745522074, 0.9437265220528102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[421, 0.15793718311639351`], {
             RGBColor[
             0.3745871137053523, 0.49887026342098, 0.9450893375442943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[422, 0.15793718311639351`], {
             RGBColor[
             0.5708890353289431, 0.6625124629948189, 0.9593616225779874]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[423, 0.15793718311639351`], {
             RGBColor[
             0.3654745522090817, 0.4909774206635685, 0.9445086931836736]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[424, 0.15793718311639351`], {
             RGBColor[
             0.29581131059607163`, 0.42824682132979597`, 0.9401573885736044]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[425, 0.15793718311639351`], {
             RGBColor[
             0.32013965490097224`, 0.45171061121347594`, 0.9416199936152765]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[426, 0.15793718311639351`], {
             RGBColor[
             0.5443960088273342, 0.6410042305835699, 0.9572759944846271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[427, 0.15793718311639351`], {
             RGBColor[
             0.5990648062537809, 0.6853868231356175, 0.9615797224764403]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[428, 0.15793718311639351`], {
             RGBColor[
             0.2695892752795925, 0.4006857996391116, 0.938664082454356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[429, 0.15793718311639351`], {
             RGBColor[
             0.39833692363251993`, 0.5194411550797372, 0.9466026544317211]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[430, 0.15793718311639351`], {
             RGBColor[
             0.5003182803568205, 0.6052199449321679, 0.9538060342373887]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[431, 0.15793718311639351`], {
             RGBColor[
             0.37747315389622627`, 0.5013700063777173, 0.9452732334732316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[432, 0.15793718311639351`], {
             RGBColor[
             0.5268509810964614, 0.6267603866771554, 0.9558947856320985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[433, 0.15793718311639351`], {
             RGBColor[
             0.37889085179470317`, 0.5025979450418098, 0.9453635679297016]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[434, 0.15793718311639351`], {
             RGBColor[
             0.6139127595251401, 0.6974410604939791, 0.9627486077478067]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[435, 0.15793718311639351`], {
             RGBColor[
             0.2606555379990374, 0.3912958753255892, 0.9381553193325082]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[436, 0.15793718311639351`], {
             RGBColor[
             0.2848236758017663, 0.4166981205046981, 0.9395316590268178]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[437, 0.15793718311639351`], {
             RGBColor[
             0.37967474505675297`, 0.5032769139857763, 0.9454135169151897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[438, 0.15793718311639351`], {
             RGBColor[
             0.2786727655023221, 0.4102331237897445, 0.9391813737847208]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[439, 0.15793718311639351`], {
             RGBColor[
             0.38581416804558577`, 0.5085945736023316, 0.9458047155191596]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[440, 0.15793718311639351`], {
             RGBColor[
             0.3142204582130512, 0.4465837005498747, 0.9412428276364623]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[441, 0.15793718311639351`], {
             RGBColor[
             0.7498180026665873, 0.8044827896018071, 0.9756985091243308]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[442, 0.15793718311639351`], {
             RGBColor[
             0.9716257886151362, 0.9783591401244512, 0.9329143180817423]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[443, 0.15793718311639351`], {
             RGBColor[
             0.3267179701832335, 0.4574084172752309, 0.9420391580480864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[444, 0.15793718311639351`], {
             RGBColor[
             0.39132945768338123`, 0.5133716402800728, 0.9461561448979008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[445, 0.15793718311639351`], {
             RGBColor[
             0.2621099959753389, 0.39282460287664395`, 0.9382381485625808]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[446, 0.15793718311639351`], {
             RGBColor[
             0.5314739146464285, 0.6305134923938017, 0.9562587198955155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[447, 0.15793718311639351`], {
             RGBColor[
             0.47906174873766616`, 0.5879629349679016, 0.9521326422030879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[448, 0.15793718311639351`], {
             RGBColor[
             0.5666477973126823, 0.6590692349076231, 0.9590277367851806]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[449, 0.15793718311639351`], {
             RGBColor[
             0.3747630771409237, 0.4990226741046925, 0.9451005497788105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[450, 0.15793718311639351`], {
             RGBColor[
             0.5249943661189675, 0.6252531029988743, 0.9557486261000655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[451, 0.15793718311639351`], {
             RGBColor[
             0.38942002617178806`, 0.511717786675549, 0.946034477610426]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[452, 0.15793718311639351`], {
             RGBColor[
             0.4445295509185989, 0.5594508871259848, 0.9495460077958535]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[453, 0.15793718311639351`], {
             RGBColor[
             0.993382932934981, 0.9882550875730577, 0.5211512696560812]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[454, 0.15793718311639351`], {
             RGBColor[
             0.3854948064565971, 0.5083179586455299, 0.9457843660811096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[455, 0.15793718311639351`], {
             RGBColor[
             0.28969055988578707`, 0.42181352425527757`, 0.939808820875493]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[456, 0.15793718311639351`], {
             RGBColor[
             0.18094129430740732`, 0.3075111510307206, 0.9336157110809254]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[457, 0.15793718311639351`], {
             RGBColor[
             0.26766488320898485`, 0.3986631415593985, 0.9385544911728178]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[458, 0.15793718311639351`], {
             RGBColor[
             0.3219708799135086, 0.45329672627928963`, 0.9417366776537867]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[459, 0.15793718311639351`], {
             RGBColor[
             0.4113777395761776, 0.5307364543996662, 0.9474336036921102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[460, 0.15793718311639351`], {
             RGBColor[
             0.26957497433009414`, 0.4006707684344563, 0.9386632680364383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[461, 0.15793718311639351`], {
             RGBColor[
             0.3528825637432511, 0.48007087314620844`, 0.9437063428132891]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[462, 0.15793718311639351`], {
             RGBColor[
             0.7754451056319214, 0.8245028772115225, 0.978252779249022]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[463, 0.15793718311639351`], {
             RGBColor[
             0.4214453277974545, 0.5394564933052393, 0.9480751015111512]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[464, 0.15793718311639351`], {
             RGBColor[
             0.37741256891592784`, 0.5013175307128724, 0.9452693730518602]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[465, 0.15793718311639351`], {
             RGBColor[
             0.3953171937829789, 0.5168256168601002, 0.9464102399159505]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[466, 0.15793718311639351`], {
             RGBColor[
             0.34194698486897257`, 0.47059902436348405`, 0.9430095373973728]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[467, 0.15793718311639351`], {
             RGBColor[
             0.36368333007010134`, 0.4894259540762261, 0.9443945580928933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[468, 0.15793718311639351`], {
             RGBColor[
             0.2745249347963217, 0.40587349073008183`, 0.9389451609621797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[469, 0.15793718311639351`], {
             RGBColor[
             0.2685511023423144, 0.3995946140580663, 0.9386049600414171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[470, 0.15793718311639351`], {
             RGBColor[
             0.4344130032297485, 0.5506884419903739, 0.9489013903228318]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[471, 0.15793718311639351`], {
             RGBColor[
             0.4076000208382393, 0.5274643843025286, 0.9471928907946342]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[472, 0.15793718311639351`], {
             RGBColor[
             0.5616969521765701, 0.6550499157930956, 0.9586379881205226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[473, 0.15793718311639351`], {
             RGBColor[
             0.3210478071146062, 0.4524972070158682, 0.9416778602712818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[474, 0.15793718311639351`], {
             RGBColor[
             0.23719934228221695`, 0.3666419264185053, 0.9368195236867672]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[475, 0.15793718311639351`], {
             RGBColor[
             0.35311517457831754`, 0.48027234896018245`, 0.9437211645700099]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[476, 0.15793718311639351`], {
             RGBColor[
             0.34393576952958826`, 0.47232160967728587`, 0.9431362609973339]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[477, 0.15793718311639351`], {
             RGBColor[
             0.27192488034993023`, 0.40314066865395115`, 0.9387970917078936]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[478, 0.15793718311639351`], {
             RGBColor[
             0.3124232419739436, 0.44502704217427436`, 0.9411283106069223]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[479, 0.15793718311639351`], {
             RGBColor[
             0.4586009041255429, 0.5713518995612344, 0.9505218895646782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[480, 0.15793718311639351`], {
             RGBColor[
             0.3426163435773886, 0.4711787892337671, 0.9430521883423824]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[481, 0.15793718311639351`], {
             RGBColor[
             0.4627589359118407, 0.5747275770825483, 0.9508492250582679]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[482, 0.15793718311639351`], {
             RGBColor[
             0.3203821837609257, 0.4519206775221127, 0.9416354473397729]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[483, 0.15793718311639351`], {
             RGBColor[
             0.48869581167072734`, 0.5957843012665499, 0.9528910709279138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[484, 0.15793718311639351`], {
             RGBColor[
             0.4511140875827428, 0.5651540818360308, 0.9499655686496156]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[485, 0.15793718311639351`], {
             RGBColor[
             0.3498128196385177, 0.4774120150925132, 0.9435107414334036]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[486, 0.15793718311639351`], {
             RGBColor[
             0.5336641165976901, 0.6322915970053093, 0.9564311406160929]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[487, 0.15793718311639351`], {
             RGBColor[
             0.826904067999911, 0.8648148743828871, 0.9833520422634492]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[488, 0.15793718311639351`], {
             RGBColor[
             0.41385627480793563`, 0.532883237042612, 0.9475915337653952]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[489, 0.15793718311639351`], {
             RGBColor[
             0.3323547408441664, 0.46229070470939987`, 0.9423983280902004]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[490, 0.15793718311639351`], {
             RGBColor[
             0.5577047140322583, 0.6518088370192644, 0.9583237045097522]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[491, 0.15793718311639351`], {
             RGBColor[
             0.658191251972377, 0.7329032755703926, 0.9665660109157999]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[492, 0.15793718311639351`], {
             RGBColor[
             0.3192850550014802, 0.4509703997339758, 0.9415655392653739]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[493, 0.15793718311639351`], {
             RGBColor[
             0.5423758830864834, 0.6393642015015197, 0.9571169627863428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[494, 0.15793718311639351`], {
             RGBColor[
             0.4569487303192949, 0.5700105904357405, 0.9503918243905383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[495, 0.15793718311639351`], {
             RGBColor[
             0.24321556210933143`, 0.3729653549071712, 0.9371621385057217]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[496, 0.15793718311639351`], {
             RGBColor[
             0.32020922559365694`, 0.45177086985075476`, 0.9416244265982955]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[497, 0.15793718311639351`], {
             RGBColor[
             0.3124282634147412, 0.4450313914939083, 0.9411286305686897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[498, 0.15793718311639351`], {
             RGBColor[
             0.2529348099603532, 0.38318090063450094`, 0.9377156352924987]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[499, 0.15793718311639351`], {
             RGBColor[
             0.36728333829024157`, 0.4925441002548373, 0.9446239474333183]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[500, 0.15793718311639351`], {
             RGBColor[
             0.4188229331138053, 0.5371851068356515, 0.9479080048408016]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1dOWGAgQBNBMbNu2bds2J+bEtm3btm3btu01sjdnH271F1R1ssCg6p0C
ggUL9l38vMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEIS
kZgkJCUZyUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpR
mCIUpRjFKUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGY
JjSlGYE0pwUtaUVr2tCWdrSnAx3pRBCd6UJXutGdHvSkF73pQ1/60Z8BDGQQ
gxnCUIYxnBGMZBSjGcNYxjGeCUxkEpOZwlSmMZ0ZzGQWs5nDXOYxnwUsZBGL
WcJSlrGcFaxkFatZw1rWsZ4NbGQTm9nCVraxnR3sZBe72cNe9rGfAxzkEIc5
wlGOcZwTnOQUpznDWc5xngtc5BKXucJVrnGdG9zkFre5w13ucZ8HPOQRj3nC
U57xnBe85BWvecNb3vGeD3zkE5/5wle+8Z1f+JXf+J0/+JO/+Jt/+Jcf/Cx/
AMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEISkZgkJCUZ
yUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpRmCIUpRjF
KUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGYJjSlGYE0
pwUtaUVr2tCWdrSnAx35Od5BdKYLXelGd3rQk170pg996Ud/BjCQQQxmCEMZ
xnBGMJJRjGYMYxnHeCYwkUlMZgpTmcZ0ZjCTWcxmDnOZx3wWsJBFLGYJS1nG
clawklWsZg1rWcd6NrCRTWxmC1vZxnZ2sJNd7GYPe9nHfg5wkEMc5ghHOcZx
TnCSU5zmDGc5x3kucJFLXOYKV7nGdW5wk1vc5g53ucd9HvCQRzzmCU95xnNe
8JJXvOYNb3nHez7wkU985gtf+Rbw/z//Dz189+A=
          "], {Null, CompressedData["
1:eJw13A2c1mO6wPH7tsdpl2O9LLLYQ3Ioas/uCqvVrqQihdKSUmmVzEwspdpK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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[196, 330] -> 
             RGBColor[
              0.3010744440099954, 0.433778708249762, 0.9404571162354194], 
             UndirectedEdge[136, 319] -> 
             RGBColor[
              0.8419251732908781, 0.8767840075536342, 0.9548214315268342], 
             UndirectedEdge[60, 188] -> 
             RGBColor[
              0.31499337168742486`, 0.44577048443841216`, 0.9413463649912971],
              UndirectedEdge[145, 408] -> 
             RGBColor[
              0.2215813501340996, 0.35022642643293833`, 0.9359301021386808], 
             UndirectedEdge[398, 460] -> 
             RGBColor[
              0.2547486544855675, 0.3850873662348864, 0.9378189310548671], 
             UndirectedEdge[413, 476] -> 
             RGBColor[
              0.9111642263834832, 0.6485722673362936, 0.273464018883213], 
             UndirectedEdge[244, 274] -> 
             RGBColor[
              0.40258764491589, 0.5228672426461249, 0.9469441500000384], 
             UndirectedEdge[198, 223] -> 
             RGBColor[
              0.335871613441881, 0.4628528461466326, 0.9427133713948876], 
             UndirectedEdge[36, 310] -> 
             RGBColor[
              0.2755731801551128, 0.4069752630647657, 0.9390048569846228], 
             UndirectedEdge[252, 432] -> 
             RGBColor[
              0.8172102397534445, 0.8577657390481622, 0.982246863062763], 
             UndirectedEdge[469, 475] -> 
             RGBColor[
              0.8497170345102683, 0.3799664311487149, 0.19511763635494941`], 
             UndirectedEdge[113, 347] -> 
             RGBColor[
              0.17905963034776856`, 0.3055334029047545, 0.9335085531020964], 
             UndirectedEdge[35, 131] -> 
             RGBColor[
              0.2509907389862678, 0.38113755877951816`, 0.9376049233265198], 
             UndirectedEdge[156, 479] -> 
             RGBColor[
              0.4393999195807523, 0.5546279653397757, 0.9493241177753168], 
             UndirectedEdge[318, 354] -> 
             RGBColor[
              0.35185308329442466`, 0.47917918892462685`, 0.9436407452294238],
              UndirectedEdge[6, 77] -> 
             RGBColor[
              0.7172538475630181, 0.7785612627115652, 0.9728085302210365], 
             UndirectedEdge[23, 202] -> 
             RGBColor[
              0.23077928410080303`, 0.35989403821464017`, 0.9364539108709606],
              UndirectedEdge[342, 395] -> 
             RGBColor[
              0.2624873580585535, 0.3932212343522405, 0.9382596387749628], 
             UndirectedEdge[53, 418] -> 
             RGBColor[
              0.9774928986004763, 0.9579493905915291, 0.642289060004833], 
             UndirectedEdge[75, 149] -> 
             RGBColor[
              0.3494116417234011, 0.4770645349462275, 0.9434851787314], 
             UndirectedEdge[293, 418] -> 
             RGBColor[
              0.9663729017016692, 0.9744415456652006, 0.9418060854539165], 
             UndirectedEdge[282, 432] -> 
             RGBColor[
              0.7531414292760994, 0.8071831282683875, 0.9762245194841053], 
             UndirectedEdge[466, 468] -> 
             RGBColor[
              0.49094259840512156`, 0.5976083439541202, 0.9530679462098963], 
             UndirectedEdge[105, 190] -> 
             RGBColor[
              0.24700744449895456`, 0.37695086371789455`, 0.9373780805982235],
              UndirectedEdge[64, 473] -> 
             RGBColor[
              0.3073328542986736, 0.43868458843205593`, 0.9408747474285853], 
             UndirectedEdge[214, 273] -> 
             RGBColor[
              0.24667426527178135`, 0.3766006712253524, 0.9373591065341305], 
             UndirectedEdge[30, 64] -> 
             RGBColor[
              0.27788283656739987`, 0.4094028583947541, 0.9391363885004721], 
             UndirectedEdge[296, 395] -> 
             RGBColor[
              0.289203696626415, 0.4208696734674796, 0.9397969170059906], 
             UndirectedEdge[114, 203] -> 
             RGBColor[
              0.5176225598035007, 0.6192683385358883, 0.9551682905030956], 
             UndirectedEdge[81, 237] -> 
             RGBColor[
              0.8648552697662895, 0.8950761325134684, 0.9869718617673642], 
             UndirectedEdge[382, 427] -> 
             RGBColor[
              0.2808624118228371, 0.41253458090420103`, 0.9393060709033827], 
             UndirectedEdge[39, 450] -> 
             RGBColor[
              0.7206850354992045, 0.4212381693670362, 0.5640535204963621], 
             UndirectedEdge[50, 57] -> 
             RGBColor[
              0.5210905073010532, 0.6217476292469348, 0.9555341779806428], 
             UndirectedEdge[74, 153] -> 
             RGBColor[
              0.2633334885240648, 0.39411057111926295`, 0.9383078246532357], 
             UndirectedEdge[239, 332] -> 
             RGBColor[
              0.37656128496655794`, 0.5005801913427036, 0.9452151299913671], 
             UndirectedEdge[14, 72] -> 
             RGBColor[
              0.2803635687690008, 0.4120102652261427, 0.9392776625294388], 
             UndirectedEdge[331, 403] -> 
             RGBColor[
              0.8828018353475209, 0.9093862367613971, 0.9886836212135901], 
             UndirectedEdge[214, 302] -> 
             RGBColor[
              0.19497823659732902`, 0.32226486737097304`, 0.9344150941785414],
              UndirectedEdge[128, 197] -> 
             RGBColor[
              0.5961844176461558, 0.6822017797294064, 0.9619318024689351], 
             UndirectedEdge[191, 212] -> 
             RGBColor[
              0.21845881642544385`, 0.3469444455250692, 0.9357522784633475], 
             UndirectedEdge[404, 407] -> 
             RGBColor[
              0.2139033248740353, 0.3421563350696921, 0.9354928499587406], 
             UndirectedEdge[60, 116] -> 
             RGBColor[
              0.27071777339856856`, 0.4018719227130688, 0.9387283487527682], 
             UndirectedEdge[272, 357] -> 
             RGBColor[
              0.8638626077841431, 0.41438606964025426`, 0.20574312527482636`],
              UndirectedEdge[228, 490] -> 
             RGBColor[
              0.9918174311383581, 0.9889858002878001, 0.6472681311594083], 
             UndirectedEdge[111, 415] -> 
             RGBColor[
              0.2800519643946353, 0.41168274927182613`, 0.9392599171212961], 
             UndirectedEdge[227, 428] -> 
             RGBColor[
              0.8379823315719487, 0.29295442119162834`, 0.18400522964919308`],
              UndirectedEdge[367, 499] -> 
             RGBColor[
              0.24528184927831587`, 0.3751371537319471, 0.9372798105031974], 
             UndirectedEdge[434, 495] -> 
             RGBColor[
              0.9167025248852594, 0.6580111596730529, 0.4917530067660364], 
             UndirectedEdge[226, 283] -> 
             RGBColor[
              0.18031957576389654`, 0.30685768542225833`, 0.9335803051296228],
              UndirectedEdge[9, 34] -> 
             RGBColor[
              0.559448373541096, 0.6532244183595045, 0.9584609717735231], 
             UndirectedEdge[127, 386] -> 
             RGBColor[
              0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993],
              UndirectedEdge[326, 469] -> 
             RGBColor[
              0.8678030946468546, 0.4926065528105953, 0.21140400054171546`], 
             UndirectedEdge[192, 483] -> 
             RGBColor[
              0.275631905541692, 0.4070369871694651, 0.9390082013085121], 
             UndirectedEdge[16, 39] -> 
             RGBColor[
              0.5137718344766236, 0.6147998451486828, 0.9552360290912556], 
             UndirectedEdge[209, 421] -> 
             RGBColor[
              0.37249008899703795`, 0.4820057501195733, 0.9462395519949527], 
             UndirectedEdge[293, 317] -> 
             RGBColor[
              0.9188363181868828, 0.7644234365766909, 0.5933539685152149], 
             UndirectedEdge[3, 381] -> 
             RGBColor[
              0.5154854178683257, 0.6175333104357662, 0.9550000468613498], 
             UndirectedEdge[211, 497] -> 
             RGBColor[
              0.23351702426712523`, 0.36277157671219695`, 0.936609821123309], 
             UndirectedEdge[196, 479] -> 
             RGBColor[
              0.35359500425427093`, 0.4794816999667437, 0.9437959057364866], 
             UndirectedEdge[221, 439] -> 
             RGBColor[
              0.6987612824501502, 0.7633077628527738, 0.9716294265306357], 
             UndirectedEdge[379, 390] -> 
             RGBColor[
              0.30502633329137085`, 0.4378812473959014, 0.9406840432278518], 
             UndirectedEdge[119, 320] -> 
             RGBColor[
              0.9896249360090673, 0.9899776586598361, 0.8216051903420669], 
             UndirectedEdge[179, 401] -> 
             RGBColor[
              0.47619075737058414`, 0.5641711945885997, 0.9557776422261561], 
             UndirectedEdge[59, 342] -> 
             RGBColor[
              0.25108912406320616`, 0.3812409677333546, 0.9376105262111039], 
             UndirectedEdge[86, 98] -> 
             RGBColor[
              0.9552139147274563, 0.8468459050338089, 0.4866646892725739], 
             UndirectedEdge[328, 431] -> 
             RGBColor[
              0.4169264678183623, 0.535542483915856, 0.9477871637491544], 
             UndirectedEdge[270, 375] -> 
             RGBColor[
              0.9741122632489756, 0.9792447932430604, 0.8853225104060825], 
             UndirectedEdge[39, 45] -> 
             RGBColor[
              0.45322202962692537`, 0.5599541419213354, 0.9514657433370749], 
             UndirectedEdge[59, 463] -> 
             RGBColor[
              0.2546442329532448, 0.38497761258370766`, 0.9378129844030793], 
             UndirectedEdge[2, 55] -> 
             RGBColor[
              0.21196267506411343`, 0.3401165890751596, 0.9353823328229998], 
             UndirectedEdge[193, 496] -> 
             RGBColor[
              0.28235063055336573`, 0.41409879314850406`, 0.939390822758464], 
             UndirectedEdge[201, 246] -> 
             RGBColor[
              0.2993400916080083, 0.43195579391098005`, 0.9403583474318706], 
             UndirectedEdge[69, 487] -> 
             RGBColor[
              0.7444469428218465, 0.8000461273805028, 0.9756303235156909], 
             UndirectedEdge[15, 408] -> 
             RGBColor[
              0.22837166352845595`, 0.3573634763411423, 0.9363168004411209], 
             UndirectedEdge[118, 310] -> 
             RGBColor[
              0.3109325878407584, 0.44262745407148385`, 0.9410739135361832], 
             UndirectedEdge[289, 297] -> 
             RGBColor[
              0.47936763079523015`, 0.5878325714725148, 0.9522613561781106], 
             UndirectedEdge[397, 419] -> 
             RGBColor[
              0.43561929438142943`, 0.5501211672171827, 0.9494236831393772], 
             UndirectedEdge[13, 380] -> 
             RGBColor[
              0.28473366122711574`, 0.4166035094794867, 0.939526532829956], 
             UndirectedEdge[155, 262] -> 
             RGBColor[
              0.520987467347936, 0.6220001220678183, 0.9554331883510561], 
             UndirectedEdge[182, 324] -> 
             RGBColor[
              0.37413205522389265`, 0.49847611463624397`, 0.9450603416202481],
              UndirectedEdge[177, 245] -> 
             RGBColor[
              0.21512971428686242`, 0.34344534810015337`, 0.9355626910215206],
              UndirectedEdge[113, 325] -> 
             RGBColor[
              0.1791045905323438, 0.30558065890938335`, 0.9335111135180953], 
             UndirectedEdge[94, 368] -> 
             RGBColor[
              0.6817603644893816, 0.7470855364406719, 0.9537864521193352], 
             UndirectedEdge[50, 140] -> 
             RGBColor[
              0.47028604559026116`, 0.5805022785151959, 0.9515346646518938], 
             UndirectedEdge[389, 458] -> 
             RGBColor[
              0.2244995192065336, 0.35329360715067204`, 0.9360962875503116], 
             UndirectedEdge[429, 499] -> 
             RGBColor[
              0.2771583025105514, 0.4086413271628938, 0.9390951273577867], 
             UndirectedEdge[97, 358] -> 
             RGBColor[
              0.2286803601297014, 0.35768793604154625`, 0.9363343802558861], 
             UndirectedEdge[274, 363] -> 
             RGBColor[
              0.4337728092244554, 0.5498782645582716, 0.9489312410938221], 
             UndirectedEdge[255, 274] -> 
             RGBColor[
              0.43015989340709154`, 0.5467489384677, 0.9487010292927157], 
             UndirectedEdge[289, 381] -> 
             RGBColor[
              0.5043379271734174, 0.6081045829713598, 0.9542271093782111], 
             UndirectedEdge[55, 230] -> 
             RGBColor[
              0.21767784356668446`, 0.34612359353397393`, 0.935707803214387], 
             UndirectedEdge[289, 349] -> 
             RGBColor[
              0.42648626116779464`, 0.5438226964259498, 0.9483963053279869], 
             UndirectedEdge[29, 318] -> 
             RGBColor[
              0.37578131668551923`, 0.4999046220200136, 0.9451654311021982], 
             UndirectedEdge[69, 402] -> 
             RGBColor[
              0.7308868707375382, 0.7890374499881754, 0.9745628249690335], 
             UndirectedEdge[6, 413] -> 
             RGBColor[
              0.9007629224656561, 0.8944231613369187, 0.6681426582115271], 
             UndirectedEdge[29, 482] -> 
             RGBColor[
              0.38405087443932273`, 0.5070672973063002, 0.9456923600097877], 
             UndirectedEdge[212, 456] -> 
             RGBColor[
              0.22108739015867407`, 0.34970724317989477`, 0.9359019718488286],
              UndirectedEdge[354, 482] -> 
             RGBColor[
              0.3601226410482282, 0.48634186421091347`, 0.9441676741370133], 
             UndirectedEdge[106, 247] -> 
             RGBColor[
              0.5064333598698463, 0.6101844419620349, 0.9542874356969284], 
             UndirectedEdge[305, 382] -> 
             RGBColor[
              0.2666682843502908, 0.39761565297089385`, 0.938497736342151], 
             UndirectedEdge[279, 285] -> 
             RGBColor[
              0.2964892825686648, 0.42843496613236076`, 0.9402152006381983], 
             UndirectedEdge[27, 319] -> 
             RGBColor[
              0.6135043005796454, 0.695998377538924, 0.9634761021745089], 
             UndirectedEdge[118, 483] -> 
             RGBColor[
              0.31087863822406303`, 0.44257074960373377`, 0.9410708411853237],
              UndirectedEdge[342, 447] -> 
             RGBColor[
              0.2532435452217043, 0.38350540096912705`, 0.9377332173088998], 
             UndirectedEdge[207, 458] -> 
             RGBColor[
              0.22378112515977486`, 0.35253852945871533`, 0.9360553760721175],
              UndirectedEdge[462, 487] -> 
             RGBColor[
              0.5216548713893666, 0.6225419507348611, 0.9554857288419789], 
             UndirectedEdge[64, 384] -> 
             RGBColor[
              0.28582762436265047`, 0.41775333409620263`, 0.9395888324121513],
              UndirectedEdge[203, 221] -> 
             RGBColor[
              0.5355883582024223, 0.6338537830261275, 0.9565826239639467], 
             UndirectedEdge[139, 370] -> 
             RGBColor[
              0.5777392587332322, 0.6680737829534684, 0.9599008972575682], 
             UndirectedEdge[46, 357] -> 
             RGBColor[
              0.9123985653292456, 0.6903965335177349, 0.2483720332752017], 
             UndirectedEdge[18, 326] -> 
             RGBColor[
              0.8797797158009789, 0.5469895922605361, 0.22139758680656518`], 
             UndirectedEdge[73, 93] -> 
             RGBColor[
              0.2585978739086303, 0.3891331399031328, 0.9380381384066008], 
             UndirectedEdge[104, 112] -> 
             RGBColor[
              0.24741859649764936`, 0.37738301053706513`, 0.9374014950963042],
              UndirectedEdge[40, 314] -> 
             RGBColor[
              0.35813781501059505`, 0.484622707657373, 0.944041202777008], 
             UndirectedEdge[264, 398] -> 
             RGBColor[0.2479686232623, 0.377961123540424, 0.9374328183068594],
              UndirectedEdge[345, 489] -> 
             RGBColor[
              0.8249113944148371, 0.8621373590775923, 0.8902454594075883], 
             UndirectedEdge[80, 417] -> 
             RGBColor[
              0.7452877880838611, 0.8009437515388753, 0.9752469796719869], 
             UndirectedEdge[271, 442] -> 
             RGBColor[
              0.26987532258207286`, 0.400986453490465, 0.9386803724250632], 
             UndirectedEdge[318, 482] -> 
             RGBColor[
              0.35021188070592757`, 0.4777576617317112, 0.9435361692517431], 
             UndirectedEdge[235, 260] -> 
             RGBColor[
              0.32130907660212404`, 0.45058132040043347`, 0.941772944022762], 
             UndirectedEdge[79, 278] -> 
             RGBColor[
              0.9710962278680113, 0.9751094566161655, 0.770981396643022], 
             UndirectedEdge[137, 404] -> 
             RGBColor[
              0.2167644246749318, 0.34516353236463915`, 0.9356557853597838], 
             UndirectedEdge[380, 478] -> 
             RGBColor[
              0.26944650218814237`, 0.40053573606766074`, 0.9386559517380118],
              UndirectedEdge[247, 370] -> 
             RGBColor[
              0.5432273595581627, 0.6400554684598069, 0.9571839941332545], 
             UndirectedEdge[251, 429] -> 
             RGBColor[
              0.2760715850682322, 0.4074991182291509, 0.9390332404071009], 
             UndirectedEdge[286, 407] -> 
             RGBColor[
              0.21872930348009942`, 0.347228744569382, 0.9357676823009604], 
             UndirectedEdge[206, 410] -> 
             RGBColor[
              0.35319958507105037`, 0.4803454610863929, 0.9437265431319655], 
             UndirectedEdge[86, 500] -> 
             RGBColor[
              0.8673428769617186, 0.42615530998421236`, 0.20846003809980468`],
              UndirectedEdge[78, 407] -> 
             RGBColor[
              0.21689372054729342`, 0.34529943052432305`, 0.9356631485684387],
              UndirectedEdge[363, 370] -> 
             RGBColor[
              0.4981273475389003, 0.6021241779008506, 0.9539974660883765], 
             UndirectedEdge[447, 453] -> 
             RGBColor[
              0.26540338983624123`, 0.39628616863768357`, 0.9384257024708196],
              UndirectedEdge[256, 492] -> 
             RGBColor[
              0.28300272562501616`, 0.4147841864140242, 0.9394279586081062], 
             UndirectedEdge[114, 349] -> 
             RGBColor[
              0.45713997699902986`, 0.5690874562014547, 0.9507048443075143], 
             UndirectedEdge[22, 160] -> 
             RGBColor[
              0.4369491379476227, 0.5528851144131592, 0.949062990584439], 
             UndirectedEdge[149, 324] -> 
             RGBColor[
              0.361776111320833, 0.4877740170552114, 0.9442730318006773], 
             UndirectedEdge[94, 315] -> 
             RGBColor[
              0.5704593476328262, 0.6392872195268108, 0.9471116754258844], 
             UndirectedEdge[246, 492] -> 
             RGBColor[
              0.2854203608730804, 0.4173252743466679, 0.9395656393589127], 
             UndirectedEdge[193, 202] -> 
             RGBColor[
              0.2634343891958272, 0.39421662412275726`, 0.9383135707972234], 
             UndirectedEdge[321, 335] -> 
             RGBColor[
              0.3049738126003747, 0.4356185220197354, 0.94076188047572], 
             UndirectedEdge[321, 496] -> 
             RGBColor[
              0.3050324981109774, 0.4356802042122551, 0.9407652225287313], 
             UndirectedEdge[18, 474] -> 
             RGBColor[
              0.9387405372806834, 0.7796548598202627, 0.49465049788910304`], 
             UndirectedEdge[184, 192] -> 
             RGBColor[
              0.25582325613433854`, 0.3862168407014245, 0.9378801280290341], 
             UndirectedEdge[170, 171] -> 
             RGBColor[
              0.2792113970027737, 0.4107992596479288, 0.9392120480518376], 
             UndirectedEdge[80, 156] -> 
             RGBColor[
              0.6284260394446897, 0.7069689251123001, 0.9654326763878454], 
             UndirectedEdge[353, 418] -> 
             RGBColor[
              0.809068015481273, 0.8509060188194038, 0.9430493347226458], 
             UndirectedEdge[201, 312] -> 
             RGBColor[
              0.30443515610797417`, 0.4373110297461917, 0.9406485038176712], 
             UndirectedEdge[152, 212] -> 
             RGBColor[
              0.21125959360220817`, 0.3393776058807578, 0.93534229337386], 
             UndirectedEdge[192, 260] -> 
             RGBColor[
              0.27009553441077905`, 0.4012179100846716, 0.9386929131629338], 
             UndirectedEdge[90, 357] -> 
             RGBColor[
              0.8859560304571115, 0.5741950476247133, 0.2265078159100875], 
             UndirectedEdge[57, 369] -> 
             RGBColor[
              0.5105952058083258, 0.6126571266031253, 0.9548654266501568], 
             UndirectedEdge[83, 448] -> 
             RGBColor[
              0.7443425082604527, 0.7998796964136958, 0.9757160754212024], 
             UndirectedEdge[67, 180] -> 
             RGBColor[
              0.26337700695553745`, 0.3941563117499686, 0.9383103029635284], 
             UndirectedEdge[373, 472] -> 
             RGBColor[
              0.31103110428016545`, 0.44242232361832246`, 0.9410908260962028],
              UndirectedEdge[353, 432] -> 
             RGBColor[
              0.7691435045990516, 0.820174333900838, 0.9774842614710615], 
             UndirectedEdge[1, 433] -> 
             RGBColor[
              0.2958358704615542, 0.4267230355457211, 0.940215525659722], 
             UndirectedEdge[300, 301] -> 
             RGBColor[
              0.2173551636481656, 0.3457844364805221, 0.9356894270703895], 
             UndirectedEdge[212, 389] -> 
             RGBColor[
              0.21850801717300872`, 0.34699615863026745`, 0.9357550803731354],
              UndirectedEdge[97, 174] -> 
             RGBColor[
              0.24919580773922206`, 0.37925097223365895`, 0.9375027046473634],
              UndirectedEdge[200, 471] -> 
             RGBColor[
              0.8788202951923778, 0.5401284768128874, 0.22049894846562806`], 
             UndirectedEdge[155, 387] -> 
             RGBColor[
              0.6705014636086952, 0.7413486854414358, 0.9685938847155504], 
             UndirectedEdge[156, 354] -> 
             RGBColor[
              0.4145365045344412, 0.533092524898237, 0.9477398429544205], 
             UndirectedEdge[314, 472] -> 
             RGBColor[
              0.3292610947634469, 0.4596111439654538, 0.9422012036975409], 
             UndirectedEdge[117, 269] -> 
             RGBColor[
              0.41500730712434825`, 0.5338802033825223, 0.947664876526779], 
             UndirectedEdge[336, 409] -> 
             RGBColor[
              0.23189710424361965`, 0.36106893805863094`, 0.9365175690744273],
              UndirectedEdge[63, 252] -> 
             RGBColor[
              0.5775658026497799, 0.6655789256820774, 0.9611207995905398], 
             UndirectedEdge[201, 444] -> 
             RGBColor[
              0.2878759109078417, 0.4199062131240665, 0.9397054793007316], 
             UndirectedEdge[201, 442] -> 
             RGBColor[
              0.2942020501296223, 0.426555386546551, 0.9400657435707277], 
             UndirectedEdge[25, 333] -> 
             RGBColor[
              0.34601220845973285`, 0.4741201167137219, 0.94326856984984], 
             UndirectedEdge[203, 397] -> 
             RGBColor[
              0.44655734447149653`, 0.5590011690338403, 0.950284766509865], 
             UndirectedEdge[7, 436] -> 
             RGBColor[
              0.6558009604167452, 0.7285914992480711, 0.9680622843636464], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.24125115959042637`, 0.3709006433094886, 0.9370502686883432], 
             UndirectedEdge[274, 369] -> 
             RGBColor[
              0.4413408424038283, 0.5564333145178368, 0.9494134694758627], 
             UndirectedEdge[38, 364] -> 
             RGBColor[
              0.2592676752099878, 0.3898371435387148, 0.9380762825998308], 
             UndirectedEdge[215, 356] -> 
             RGBColor[
              0.2767305167100354, 0.40819169716336523`, 0.9390707655892996], 
             UndirectedEdge[16, 283] -> 
             RGBColor[
              0.29254812031783006`, 0.4160210207001029, 0.9402936186581154], 
             UndirectedEdge[236, 276] -> 
             RGBColor[
              0.45343165662521556`, 0.5606674341824253, 0.9514328089086481], 
             UndirectedEdge[39, 454] -> 
             RGBColor[
              0.761772006870989, 0.6718134516549312, 0.6008439261608904], 
             UndirectedEdge[179, 315] -> 
             RGBColor[
              0.18221437666537932`, 0.3088492413070327, 0.9336882112378554], 
             UndirectedEdge[149, 182] -> 
             RGBColor[
              0.36623071660169665`, 0.4916323722545241, 0.9445568753101211], 
             UndirectedEdge[97, 407] -> 
             RGBColor[
              0.2230464248259349, 0.3517663128251578, 0.936013535974997], 
             UndirectedEdge[274, 379] -> 
             RGBColor[
              0.386016730119334, 0.5085143491277428, 0.9458882659622865], 
             UndirectedEdge[39, 325] -> 
             RGBColor[
              0.40133925395865816`, 0.5054220551360133, 0.9485110960164554], 
             UndirectedEdge[127, 347] -> 
             RGBColor[
              0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993],
              UndirectedEdge[327, 483] -> 
             RGBColor[
              0.27685916583525294`, 0.4083269155507945, 0.9390780919666615], 
             UndirectedEdge[269, 360] -> 
             RGBColor[
              0.5141528316673345, 0.616332566062272, 0.9549279906939228], 
             UndirectedEdge[54, 147] -> 
             RGBColor[
              0.2401069833110282, 0.36969804149487495`, 0.9369851095418886], 
             UndirectedEdge[276, 422] -> 
             RGBColor[
              0.4267760803352025, 0.5326507334404715, 0.9499148132723232], 
             UndirectedEdge[181, 424] -> 
             RGBColor[
              0.3706458143967508, 0.4954565080553325, 0.9448382014375043], 
             UndirectedEdge[336, 456] -> 
             RGBColor[
              0.22294853768143919`, 0.3516634272298894, 0.936007961446929], 
             UndirectedEdge[46, 298] -> 
             RGBColor[
              0.9096473304128414, 0.8178215341712867, 0.6215408826637097], 
             UndirectedEdge[107, 132] -> 
             RGBColor[
              0.5874023021726906, 0.6508098778838103, 0.8735074338464627], 
             UndirectedEdge[78, 95] -> 
             RGBColor[
              0.22325600943798377`, 0.3519865995408531, 0.9360254715086005], 
             UndirectedEdge[296, 332] -> 
             RGBColor[
              0.3578059368755654, 0.48433525149749035`, 0.9440200557957121], 
             UndirectedEdge[397, 472] -> 
             RGBColor[
              0.3434973849835166, 0.4719419030173265, 0.9431083275217065], 
             UndirectedEdge[19, 269] -> 
             RGBColor[
              0.5043319337096805, 0.6083595186738375, 0.9541548536315616], 
             UndirectedEdge[185, 335] -> 
             RGBColor[
              0.28035846079175497`, 0.4120048964181928, 0.9392773716376912], 
             UndirectedEdge[112, 351] -> 
             RGBColor[
              0.26915448795361524`, 0.4002288105924009, 0.9386393219593516], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.2633838374698597, 0.39416349105360093`, 0.9383106919512142], 
             UndirectedEdge[251, 305] -> 
             RGBColor[
              0.25482853774731307`, 0.38517132860787223`, 0.9378234802884469],
              UndirectedEdge[131, 170] -> 
             RGBColor[
              0.28014480934839103`, 0.4117803352049335, 0.9392652045040607], 
             UndirectedEdge[76, 333] -> 
             RGBColor[
              0.3949872182942583, 0.5165398086768207, 0.9463892141695951], 
             UndirectedEdge[114, 115] -> 
             RGBColor[
              0.7109234320173796, 0.7727455262693818, 0.9730887236423327], 
             UndirectedEdge[87, 421] -> 
             RGBColor[
              0.17915493384170816`, 0.30563357291947557`, 0.9335139804950874],
              UndirectedEdge[60, 192] -> 
             RGBColor[
              0.2736621188386635, 0.4049666164528918, 0.9388960248698129], 
             UndirectedEdge[84, 147] -> 
             RGBColor[
              0.24240373141068797`, 0.37211206936985763`, 0.93711590594843], 
             UndirectedEdge[431, 433] -> 
             RGBColor[
              0.3870230907643596, 0.509641681699111, 0.9458817470057914], 
             UndirectedEdge[201, 492] -> 
             RGBColor[
              0.29053904388296076`, 0.4227053347332997, 0.9398571407839125], 
             UndirectedEdge[86, 124] -> 
             RGBColor[
              0.9389228207101663, 0.7935781606519255, 0.2800166062249653], 
             UndirectedEdge[234, 239] -> 
             RGBColor[
              0.36975457999068184`, 0.4946845656075394, 0.9447814127692372], 
             UndirectedEdge[100, 450] -> 
             RGBColor[
              0.8744616680202064, 0.45105879141128646`, 0.21405151473609035`],
              UndirectedEdge[22, 275] -> 
             RGBColor[
              0.43256024452096153`, 0.549083675519183, 0.9487833341762382], 
             UndirectedEdge[160, 324] -> 
             RGBColor[
              0.3960795993510239, 0.5174859742435227, 0.9464588197245776], 
             UndirectedEdge[191, 218] -> 
             RGBColor[
              0.2251871593264507, 0.3540163605156067, 0.9361354476378685], 
             UndirectedEdge[349, 397] -> 
             RGBColor[
              0.38607476166702576`, 0.5088202866994067, 0.9458213203142838], 
             UndirectedEdge[401, 454] -> 
             RGBColor[
              0.8366674019364873, 0.7306087240183134, 0.6081129719353302], 
             UndirectedEdge[311, 349] -> 
             RGBColor[
              0.5802291691633081, 0.667416033439714, 0.9614893343765445], 
             UndirectedEdge[63, 324] -> 
             RGBColor[
              0.3945065223315428, 0.5161234539943981, 0.9463585846479137], 
             UndirectedEdge[22, 353] -> 
             RGBColor[
              0.5455395337034719, 0.641880966146923, 0.9573802823215901], 
             UndirectedEdge[93, 437] -> 
             RGBColor[
              0.26255787085876586`, 0.3932953477760335, 0.9382636543746206], 
             UndirectedEdge[417, 461] -> 
             RGBColor[
              0.8227440842305245, 0.8622334494485463, 0.9748712810946092], 
             UndirectedEdge[151, 249] -> 
             RGBColor[
              0.29817109629594896`, 0.43072710571942197`, 0.9402917748782225],
              UndirectedEdge[148, 452] -> 
             RGBColor[
              0.23180463347080354`, 0.3609717454134156, 0.9365123030007138], 
             UndirectedEdge[262, 424] -> 
             RGBColor[
              0.39834012297090404`, 0.5188257266580119, 0.9467736686621999], 
             UndirectedEdge[50, 139] -> 
             RGBColor[
              0.50248660335272, 0.6066441419253559, 0.9540696105134843], 
             UndirectedEdge[237, 267] -> 
             RGBColor[
              0.9475774996267206, 0.9513626199375382, 0.7014579081154306], 
             UndirectedEdge[256, 442] -> 
             RGBColor[
              0.28666573187167776`, 0.4186342382272755, 0.9396365613949216], 
             UndirectedEdge[60, 133] -> 
             RGBColor[
              0.31894163191943015`, 0.44919026900604586`, 0.9415979446419711],
              UndirectedEdge[77, 156] -> 
             RGBColor[
              0.5370635204917655, 0.6350513862279201, 0.9566987541430614], 
             UndirectedEdge[219, 498] -> 
             RGBColor[
              0.49407920545967077`, 0.6001547828635406, 0.9533148714070008], 
             UndirectedEdge[102, 185] -> 
             RGBColor[
              0.28024115314486164`, 0.4118815986435736, 0.9392706911407418], 
             UndirectedEdge[92, 169] -> 
             RGBColor[
              0.5509398864490034, 0.6463168452351683, 0.9577911525020184], 
             UndirectedEdge[53, 357] -> 
             RGBColor[
              0.9418272950686917, 0.8009948820936315, 0.3036989405074137], 
             UndirectedEdge[162, 289] -> 
             RGBColor[
              0.45070123455015054`, 0.5645598995943251, 0.9500046324572284], 
             UndirectedEdge[169, 204] -> 
             RGBColor[
              0.4973176178268257, 0.6027838719120118, 0.9535698110912385], 
             UndirectedEdge[176, 448] -> 
             RGBColor[
              0.587441960125221, 0.6759508730452015, 0.9606647294533119], 
             UndirectedEdge[377, 403] -> 
             RGBColor[
              0.9550085431684978, 0.9657910070072111, 0.9549749729457403], 
             UndirectedEdge[86, 357] -> 
             RGBColor[
              0.911167687629582, 0.6855165136042474, 0.2473816401856394], 
             UndirectedEdge[12, 373] -> 
             RGBColor[
              0.28300945147034123`, 0.414791255703904, 0.9394283416350475], 
             UndirectedEdge[200, 469] -> 
             RGBColor[
              0.8806293426662699, 0.5508475494204266, 0.22210653628922422`], 
             UndirectedEdge[112, 153] -> 
             RGBColor[
              0.24659824483285725`, 0.37652076892406894`, 0.9373547772825959],
              UndirectedEdge[166, 243] -> 
             RGBColor[
              0.838713260625803, 0.29857266219470613`, 0.18470516813663024`], 
             UndirectedEdge[394, 460] -> 
             RGBColor[
              0.23849436642390026`, 0.3680030789006874, 0.9368932733958195], 
             UndirectedEdge[18, 348] -> 
             RGBColor[
              0.9221477650002106, 0.7221653986171828, 0.2620020254952798], 
             UndirectedEdge[315, 325] -> 
             RGBColor[
              0.1822582683189515, 0.30889537421782864`, 0.9336907108025945], 
             UndirectedEdge[195, 447] -> 
             RGBColor[
              0.25832593618087096`, 0.38884731610940987`, 0.9380226519553008],
              UndirectedEdge[128, 204] -> 
             RGBColor[
              0.4983181319181479, 0.6035961343239933, 0.9536485752255113], 
             UndirectedEdge[91, 435] -> 
             RGBColor[
              0.29287326479962417`, 0.4234129007814571, 0.9400539952643586], 
             UndirectedEdge[158, 206] -> 
             RGBColor[
              0.3501277440364893, 0.4776847867774757, 0.9435308081375656], 
             UndirectedEdge[30, 290] -> 
             RGBColor[
              0.2772082322816696, 0.40869380651806936`, 0.9390979707843874], 
             UndirectedEdge[2, 250] -> 
             RGBColor[
              0.20844651025640323`, 0.33642087692453115`, 0.9351820924389003],
              UndirectedEdge[148, 195] -> 
             RGBColor[
              0.2549038837878154, 0.3852505220736551, 0.9378277711339891], 
             UndirectedEdge[5, 202] -> 
             RGBColor[
              0.23883220085490312`, 0.3683581643076115, 0.9369125125668838], 
             UndirectedEdge[220, 359] -> 
             RGBColor[
              0.3621822341604067, 0.48812578024652276`, 0.9442989095888945], 
             UndirectedEdge[175, 337] -> 
             RGBColor[
              0.9079704822927377, 0.9289384814961321, 0.9731750764283525], 
             UndirectedEdge[263, 447] -> 
             RGBColor[
              0.2599502995006695, 0.3905546249491011, 0.938115157043333], 
             UndirectedEdge[344, 387] -> 
             RGBColor[
              0.6194283934274943, 0.6998852662527452, 0.9645732255440658], 
             UndirectedEdge[82, 470] -> 
             RGBColor[
              0.25688036525862096`, 0.38732792941563493`, 0.937940328829809], 
             UndirectedEdge[273, 446] -> 
             RGBColor[
              0.26084634450324296`, 0.39149642505934035`, 0.9381661854806498],
              UndirectedEdge[68, 306] -> 
             RGBColor[
              0.8387829864974263, 0.2991086057980758, 0.18477193771004097`], 
             UndirectedEdge[21, 33] -> 
             RGBColor[
              0.9296510090196749, 0.7439907144053559, 0.3002556094938443], 
             UndirectedEdge[77, 479] -> 
             RGBColor[
              0.5091542746403608, 0.6112576931750507, 0.9548154361242309], 
             UndirectedEdge[253, 311] -> 
             RGBColor[
              0.8659443575362178, 0.8951239135712197, 0.9365639679939195], 
             UndirectedEdge[308, 386] -> 
             RGBColor[
              0.17893664238380538`, 0.3054041347567419, 0.9335015491194931], 
             UndirectedEdge[151, 280] -> 
             RGBColor[
              0.2818433506476452, 0.4135656098041881, 0.9393619339182866], 
             UndirectedEdge[305, 416] -> 
             RGBColor[
              0.2563227786802443, 0.3867418705687301, 0.9379085750990459], 
             UndirectedEdge[38, 189] -> 
             RGBColor[
              0.2598720197723208, 0.3904723479913851, 0.9381106991286081], 
             UndirectedEdge[277, 291] -> 
             RGBColor[
              0.7131143362098424, 0.7758096064076011, 0.9720402306671867], 
             UndirectedEdge[27, 40] -> 
             RGBColor[
              0.44915953688308596`, 0.5618645655130168, 0.9502821669769903], 
             UndirectedEdge[88, 167] -> 
             RGBColor[
              0.9266401906833595, 0.7379726928092079, 0.5404902319838795], 
             UndirectedEdge[89, 296] -> 
             RGBColor[
              0.2994607686458766, 0.4316505064958615, 0.9403810420835206], 
             UndirectedEdge[169, 340] -> 
             RGBColor[
              0.41508837309382146`, 0.5328799596159772, 0.9479658129994224], 
             UndirectedEdge[169, 363] -> 
             RGBColor[
              0.44877677089386697`, 0.5620591565622703, 0.9501124079177607], 
             UndirectedEdge[43, 378] -> 
             RGBColor[
              0.2881161193118442, 0.42015868738676554`, 0.939719158813983], 
             UndirectedEdge[350, 482] -> 
             RGBColor[
              0.36032571563534044`, 0.4865177572114446, 0.9441806138701323], 
             UndirectedEdge[199, 429] -> 
             RGBColor[
              0.318220922727511, 0.44864816272084596`, 0.9415490142958283], 
             UndirectedEdge[135, 216] -> 
             RGBColor[
              0.25825637493020664`, 0.38877420282452363`, 0.938018690544982], 
             UndirectedEdge[153, 351] -> 
             RGBColor[
              0.267489207183899, 0.39847849491853005`, 0.9385444866830785], 
             UndirectedEdge[207, 218] -> 
             RGBColor[
              0.22451796602725682`, 0.35331299592884813`, 0.9360973380694622],
              UndirectedEdge[218, 389] -> 
             RGBColor[
              0.22523636007401557`, 0.35406807362080495`, 0.9361382495476563],
              UndirectedEdge[421, 477] -> 
             RGBColor[
              0.21186411660990806`, 0.34001299789082284`, 0.9353767200648369],
              UndirectedEdge[171, 391] -> 
             RGBColor[
              0.25143472628896596`, 0.3816042175850748, 0.9376302077465881], 
             UndirectedEdge[25, 246] -> 
             RGBColor[
              0.3037983452782409, 0.43621369244109887`, 0.940627909879872], 
             UndirectedEdge[130, 254] -> 
             RGBColor[
              0.20771262472504887`, 0.3356495167000475, 0.935140298743576], 
             UndirectedEdge[65, 434] -> 
             RGBColor[
              0.9883337030612244, 0.9766308233101144, 0.5967468015081936], 
             UndirectedEdge[174, 430] -> 
             RGBColor[
              0.2531980668507343, 0.38345760031774234`, 0.9377306273829522], 
             UndirectedEdge[213, 454] -> 
             RGBColor[
              0.902044161930851, 0.6480872421427781, 0.23997558640884487`], 
             UndirectedEdge[52, 495] -> 
             RGBColor[
              0.8389987580384334, 0.3007671204139477, 0.18497856078138836`], 
             UndirectedEdge[26, 224] -> 
             RGBColor[
              0.34279791451999597`, 0.4704318560417961, 0.9430968651035153], 
             UndirectedEdge[8, 31] -> 
             RGBColor[
              0.5366659458722182, 0.6347210217205881, 0.9566695542776334], 
             UndirectedEdge[29, 321] -> 
             RGBColor[
              0.3713978817482214, 0.49610791099517215`, 0.944886122504113], 
             UndirectedEdge[319, 377] -> 
             RGBColor[
              0.8479973976544979, 0.8813126625416667, 0.9445427395689829], 
             UndirectedEdge[323, 447] -> 
             RGBColor[
              0.24292230663621342`, 0.3726571248114532, 0.9371454380403603], 
             UndirectedEdge[13, 340] -> 
             RGBColor[
              0.3170254114231826, 0.44789173278801986`, 0.9414626195505558], 
             UndirectedEdge[176, 237] -> 
             RGBColor[
              0.7565184993634433, 0.8098707472801487, 0.9765525722729846], 
             UndirectedEdge[22, 268] -> 
             RGBColor[
              0.4305356531895016, 0.5473300762667914, 0.9486543290068734], 
             UndirectedEdge[461, 493] -> 
             RGBColor[
              0.9690163833229786, 0.9733831615410689, 0.7606045943611018], 
             UndirectedEdge[401, 450] -> 
             RGBColor[
              0.7955804305647025, 0.4800334417304184, 0.5713225662708019], 
             UndirectedEdge[100, 200] -> 
             RGBColor[
              0.9160214299715226, 0.703780905297789, 0.25123642844933736`], 
             UndirectedEdge[197, 375] -> 
             RGBColor[
              0.8279135305907634, 0.8660284937370616, 0.9630673509377192], 
             UndirectedEdge[94, 401] -> 
             RGBColor[
              0.8644357283380311, 0.8946091728083778, 0.9692011064141851], 
             UndirectedEdge[118, 327] -> 
             RGBColor[
              0.2910886324434072, 0.42177019876942656`, 0.9399438296328053], 
             UndirectedEdge[44, 255] -> 
             RGBColor[
              0.44713138767076954`, 0.5605271620680575, 0.9500370874897843], 
             UndirectedEdge[148, 356] -> 
             RGBColor[
              0.2544968866209464, 0.384822742246165, 0.9378045932474341], 
             UndirectedEdge[26, 34] -> 
             RGBColor[
              0.46519130263863967`, 0.5748915338435057, 0.9515410249790447], 
             UndirectedEdge[244, 313] -> 
             RGBColor[
              0.3046994618698019, 0.43447349621750786`, 0.9407776233385161], 
             UndirectedEdge[331, 488] -> 
             RGBColor[
              0.8030279977952235, 0.8461858842867422, 0.9809661481473407], 
             UndirectedEdge[382, 429] -> 
             RGBColor[
              0.2879113316712099, 0.41994344259217253`, 0.9397074964608051], 
             UndirectedEdge[409, 496] -> 
             RGBColor[
              0.25922260246551676`, 0.38978976922649866`, 0.9380737157737123],
              UndirectedEdge[14, 324] -> 
             RGBColor[
              0.33821006500838097`, 0.4671770715883025, 0.9427782060023248], 
             UndirectedEdge[259, 471] -> 
             RGBColor[
              0.8593266411159032, 0.451612346510198, 0.20423296567103144`], 
             UndirectedEdge[178, 439] -> 
             RGBColor[
              0.9262985601874452, 0.9413808299607197, 0.8870332114673454], 
             UndirectedEdge[127, 454] -> 
             RGBColor[
              0.562931118749189, 0.49656039652436856`, 0.5871761845581333], 
             UndirectedEdge[190, 452] -> 
             RGBColor[
              0.2360315215156537, 0.3654144727487341, 0.9367530180217474], 
             UndirectedEdge[218, 295] -> 
             RGBColor[
              0.2307804101674582, 0.3598952217820915, 0.9364539749987908], 
             UndirectedEdge[35, 67] -> 
             RGBColor[
              0.24749774961125026`, 0.377466205478057, 0.9374060027490273], 
             UndirectedEdge[192, 249] -> 
             RGBColor[
              0.27208125411189216`, 0.40330502739244223`, 0.938805996962303], 
             UndirectedEdge[186, 202] -> 
             RGBColor[
              0.2373837352876954, 0.3668357351584549, 0.9368300245956442], 
             UndirectedEdge[243, 469] -> 
             RGBColor[
              0.8498683936659192, 0.3811298439450528, 0.19526257805333647`], 
             UndirectedEdge[48, 183] -> 
             RGBColor[
              0.20623910902756293`, 0.3341007582756985, 0.9350563842044752], 
             UndirectedEdge[255, 390] -> 
             RGBColor[
              0.3491694965791283, 0.4761158367358585, 0.9434968065582812], 
             UndirectedEdge[202, 497] -> 
             RGBColor[
              0.23752535161991525`, 0.36698458290261204`, 0.9368380894362616],
              UndirectedEdge[84, 365] -> 
             RGBColor[
              0.22514447908377305`, 0.3539715008744688, 0.9361330170611878], 
             UndirectedEdge[239, 262] -> 
             RGBColor[
              0.41350816527111056`, 0.531963522530478, 0.947740162904996], 
             UndirectedEdge[299, 456] -> 
             RGBColor[
              0.21641245264037934`, 0.34479358744000865`, 0.935635741073112], 
             UndirectedEdge[136, 253] -> 
             RGBColor[
              0.9769962544035893, 0.9822248956493935, 0.9175751236598007], 
             UndirectedEdge[338, 478] -> 
             RGBColor[
              0.29307363534810826`, 0.42431910359583813`, 0.9400399367228911],
              UndirectedEdge[284, 444] -> 
             RGBColor[
              0.25819284063858217`, 0.3887074242557196, 0.9380150723610645], 
             UndirectedEdge[135, 147] -> 
             RGBColor[
              0.2510599689447852, 0.3812103238553528, 0.9376088658702408], 
             UndirectedEdge[72, 73] -> 
             RGBColor[
              0.2509474629421924, 0.38109207291333524`, 0.9376024588198308], 
             UndirectedEdge[8, 291] -> 
             RGBColor[
              0.637610384777719, 0.7164873323549865, 0.9647458039813404], 
             UndirectedEdge[141, 240] -> 
             RGBColor[
              0.2831042170303842, 0.4148134850118461, 0.939436571482416], 
             UndirectedEdge[9, 466] -> 
             RGBColor[
              0.5393259259475076, 0.6368881088970959, 0.9568768589880016], 
             UndirectedEdge[78, 346] -> 
             RGBColor[
              0.21865587786091514`, 0.34715156958816623`, 0.9357635008205714],
              UndirectedEdge[255, 425] -> 
             RGBColor[
              0.38646418769848023`, 0.5091575879547311, 0.9458461341966522], 
             UndirectedEdge[297, 349] -> 
             RGBColor[
              0.4664828396818328, 0.5766724130185215, 0.9514403486819383], 
             UndirectedEdge[248, 478] -> 
             RGBColor[
              0.25429079969208646`, 0.3846061318172672, 0.9377928569017139], 
             UndirectedEdge[113, 130] -> 
             RGBColor[
              0.17905963034776856`, 0.3055334029047545, 0.9335085531020964], 
             UndirectedEdge[51, 179] -> 
             RGBColor[
              0.1789280689363169, 0.30539512351984355`, 0.9335010608743419], 
             UndirectedEdge[440, 470] -> 
             RGBColor[
              0.2685779731534025, 0.3996228569842277, 0.9386064902943567], 
             UndirectedEdge[5, 414] -> 
             RGBColor[
              0.2566326545868817, 0.38706756979387325`, 0.9379262220735086], 
             UndirectedEdge[148, 463] -> 
             RGBColor[
              0.25337660171868737`, 0.3836452517837254, 0.9377407946795635], 
             UndirectedEdge[63, 441] -> 
             RGBColor[
              0.4347339982883702, 0.5509664717764713, 0.9489218438441225], 
             UndirectedEdge[163, 187] -> 
             RGBColor[
              0.2658102034815037, 0.3967137555723293, 0.9384488699060904], 
             UndirectedEdge[120, 177] -> 
             RGBColor[
              0.20805903153131503`, 0.3360136122168933, 0.9351600260987298], 
             UndirectedEdge[450, 454] -> 
             RGBColor[
              0.8587954548220276, 0.3876960227591984, 0.20138137545633958`], 
             UndirectedEdge[15, 190] -> 
             RGBColor[
              0.24117420601353035`, 0.37081976022103225`, 0.9370458862959816],
              UndirectedEdge[191, 287] -> 
             RGBColor[
              0.21410654860741013`, 0.342369936098598, 0.9355044232497137], 
             UndirectedEdge[179, 292] -> 
             RGBColor[
              0.17894988462017136`, 0.30541805318676885`, 0.9335023032452641],
              UndirectedEdge[291, 297] -> 
             RGBColor[
              0.5871456749634538, 0.6755178075184964, 0.9607730371664382], 
             UndirectedEdge[289, 397] -> 
             RGBColor[
              0.39895955278042317`, 0.5199804451534001, 0.9466423278104561], 
             UndirectedEdge[175, 370] -> 
             RGBColor[
              0.7735868010178651, 0.822851827878325, 0.9604005134157099], 
             UndirectedEdge[23, 186] -> 
             RGBColor[
              0.22910595895914918`, 0.35813526739582024`, 0.9363586174796061],
              UndirectedEdge[241, 461] -> 
             RGBColor[
              0.8249688230204753, 0.8639714322998968, 0.9750930222658254], 
             UndirectedEdge[157, 216] -> 
             RGBColor[
              0.28421479544229167`, 0.41605814864164575`, 0.9394969841911034],
              UndirectedEdge[51, 302] -> 
             RGBColor[
              0.18453817957609825`, 0.31129170550381263`, 0.9338205483758626],
              UndirectedEdge[174, 390] -> 
             RGBColor[
              0.28370528761633407`, 0.41552262361190234`, 0.9394679684741645],
              UndirectedEdge[79, 406] -> 
             RGBColor[
              0.9922235479450122, 0.984612153776488, 0.4938632532617516], 
             UndirectedEdge[181, 235] -> 
             RGBColor[
              0.38886946031407776`, 0.511240914201845, 0.9459993960408191], 
             UndirectedEdge[78, 404] -> 
             RGBColor[
              0.2164387033219317, 0.3448211785707095, 0.935637236010592], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.2711970471587578, 0.4023756698227392, 0.938755642684389], 
             UndirectedEdge[43, 384] -> 
             RGBColor[
              0.28848430619933074`, 0.4205456751499109, 0.9397401265125418], 
             UndirectedEdge[101, 363] -> 
             RGBColor[
              0.4628220425559936, 0.5734617408298626, 0.9512181031525286], 
             UndirectedEdge[120, 455] -> 
             RGBColor[
              0.2056810719300792, 0.33351422590464763`, 0.9350246048173154], 
             UndirectedEdge[295, 456] -> 
             RGBColor[
              0.22662320577002346`, 0.355525736378405, 0.9362172283583896], 
             UndirectedEdge[58, 240] -> 
             RGBColor[
              0.2858686487739417, 0.41720789684373627`, 0.9396127186286245], 
             UndirectedEdge[39, 471] -> 
             RGBColor[
              0.7402370852900231, 0.5715237918221177, 0.5827765854569318], 
             UndirectedEdge[54, 365] -> 
             RGBColor[
              0.22284773098411328`, 0.35155747299948614`, 0.9360022206546466],
              UndirectedEdge[169, 334] -> 
             RGBColor[
              0.44777313143376407`, 0.5611898545063152, 0.9500484568988465], 
             UndirectedEdge[18, 65] -> 
             RGBColor[
              0.9349243740088637, 0.7652639008938271, 0.3116367388337401], 
             UndirectedEdge[384, 435] -> 
             RGBColor[
              0.2709692417504848, 0.4021362318949472, 0.9387426695033958], 
             UndirectedEdge[9, 360] -> 
             RGBColor[
              0.5772550006439877, 0.6676806404210414, 0.9598627746868871], 
             UndirectedEdge[135, 171] -> 
             RGBColor[
              0.25618449679905386`, 0.3865965275440213, 0.9379007001504819], 
             UndirectedEdge[149, 187] -> 
             RGBColor[
              0.30925143443909986`, 0.4382007802607746, 0.9410755580672832], 
             UndirectedEdge[271, 464] -> 
             RGBColor[
              0.24983604138275278`, 0.37992389838616725`, 0.9375391650062217],
              UndirectedEdge[21, 348] -> 
             RGBColor[
              0.9703996877499586, 0.911813337676092, 0.3395088057688662], 
             UndirectedEdge[1, 70] -> 
             RGBColor[
              0.26220782647507634`, 0.3929274289346799, 0.9382437198648137], 
             UndirectedEdge[52, 276] -> 
             RGBColor[
              0.7276676005214341, 0.4890758052767825, 0.5725511491543327], 
             UndirectedEdge[58, 429] -> 
             RGBColor[
              0.3043548555603097, 0.4366380722694161, 0.9406654807572159], 
             UndirectedEdge[243, 495] -> 
             RGBColor[
              0.8407542903650291, 0.31426091115533294`, 0.1866596605199266], 
             UndirectedEdge[131, 135] -> 
             RGBColor[
              0.25711790914467114`, 0.38757760310102596`, 0.937953856602705], 
             UndirectedEdge[145, 430] -> 
             RGBColor[
              0.23019859628253192`, 0.35928369849990305`, 0.9364208415587607],
              UndirectedEdge[291, 419] -> 
             RGBColor[
              0.583808838050422, 0.6728088129897074, 0.960510349141408], 
             UndirectedEdge[151, 260] -> 
             RGBColor[
              0.2961853765948359, 0.4286399884116514, 0.940178691078853], 
             UndirectedEdge[189, 437] -> 
             RGBColor[
              0.25780291323833093`, 0.38829758583523044`, 0.9379928665724662],
              UndirectedEdge[196, 354] -> 
             RGBColor[
              0.32873158920795986`, 0.45794625952520507`, 0.9422116309155903],
              UndirectedEdge[340, 355] -> 
             RGBColor[
              0.3330706823231735, 0.4629108172342508, 0.9424439472481606], 
             UndirectedEdge[58, 310] -> 
             RGBColor[
              0.3059344073310527, 0.43829828132983367`, 0.9407554338938223], 
             UndirectedEdge[261, 500] -> 
             RGBColor[
              0.8497397394109806, 0.34938235459205963`, 0.19393494909850834`],
              UndirectedEdge[237, 270] -> 
             RGBColor[
              0.9480577404464491, 0.9590498999175098, 0.9029559373872008], 
             UndirectedEdge[23, 497] -> 
             RGBColor[
              0.22924757529136902`, 0.3582841151399774, 0.9363666823202235], 
             UndirectedEdge[431, 462] -> 
             RGBColor[
              0.4562091477173884, 0.5692804281616477, 0.9503694481270373], 
             UndirectedEdge[108, 129] -> 
             RGBColor[
              0.3203552344901264, 0.4497120899906687, 0.9417137426958612], 
             UndirectedEdge[376, 485] -> 
             RGBColor[
              0.26372814560153673`, 0.3945253807303899, 0.938330299789955], 
             UndirectedEdge[124, 261] -> 
             RGBColor[
              0.9213196831594281, 0.7168052052597729, 0.265491517223669], 
             UndirectedEdge[63, 158] -> 
             RGBColor[
              0.38842846253649266`, 0.5108589440920934, 0.9459712960523903], 
             UndirectedEdge[66, 427] -> 
             RGBColor[
              0.271390600085227, 0.40257910622042264`, 0.9387666652372155], 
             UndirectedEdge[66, 208] -> 
             RGBColor[
              0.2926997987840062, 0.4237400438284219, 0.9400254625551399], 
             UndirectedEdge[54, 230] -> 
             RGBColor[
              0.22629940994459397`, 0.3551854064360376, 0.9361987886651444], 
             UndirectedEdge[186, 295] -> 
             RGBColor[
              0.23264914651192115`, 0.36185938216484964`, 0.9365603967690603],
              UndirectedEdge[245, 394] -> 
             RGBColor[
              0.22510267482771082`, 0.3539275619508045, 0.936130636370649], 
             UndirectedEdge[49, 459] -> 
             RGBColor[
              0.44038041665413563`, 0.554855283237734, 0.9495584378871766], 
             UndirectedEdge[55, 365] -> 
             RGBColor[
              0.21422616460620378`, 0.3424956600974225, 0.935511235203889], 
             UndirectedEdge[197, 448] -> 
             RGBColor[
              0.6327824685500147, 0.7119137261765637, 0.9648129350991647], 
             UndirectedEdge[185, 321] -> 
             RGBColor[
              0.30856010126890854`, 0.43938793879419913`, 0.9409661143099544],
              UndirectedEdge[242, 339] -> 
             RGBColor[
              0.21834915626655288`, 0.34682918574521915`, 0.9357460334795263],
              UndirectedEdge[186, 191] -> 
             RGBColor[
              0.22705589567091367`, 0.35598052089836485`, 0.936241869408138], 
             UndirectedEdge[218, 456] -> 
             RGBColor[
              0.2278157330596809, 0.3567791581704322, 0.9362851410233497], 
             UndirectedEdge[63, 182] -> 
             RGBColor[
              0.3989611276124065, 0.5199818091937107, 0.9466424281573576], 
             UndirectedEdge[133, 181] -> 
             RGBColor[
              0.3829354312034995, 0.5061011564392373, 0.9456212849531489], 
             UndirectedEdge[11, 186] -> 
             RGBColor[
              0.23731427099118235`, 0.3667627237785289, 0.936826068706721], 
             UndirectedEdge[105, 148] -> 
             RGBColor[
              0.24278055645410443`, 0.37250813638257607`, 0.9371373655771897],
              UndirectedEdge[235, 393] -> 
             RGBColor[
              0.40912660425444114`, 0.5285723075143651, 0.947349382422311], 
             UndirectedEdge[110, 290] -> 
             RGBColor[
              0.2791002706073135, 0.4106824587604797, 0.9392057195680129], 
             UndirectedEdge[225, 296] -> 
             RGBColor[
              0.29383455667092717`, 0.42573700098774714`, 0.940060637634782], 
             UndirectedEdge[38, 93] -> 
             RGBColor[
              0.2646269773927557, 0.3954701099321881, 0.9383814869307624], 
             UndirectedEdge[80, 486] -> 
             RGBColor[
              0.8622352558727102, 0.8932330485230531, 0.9866566699988166], 
             UndirectedEdge[471, 500] -> 
             RGBColor[
              0.8381526226622067, 0.29426335313338325`, 0.18416830058954048`],
              UndirectedEdge[200, 213] -> 
             RGBColor[
              0.9025169525103827, 0.6502340737413859, 0.24037009445756363`], 
             UndirectedEdge[191, 295] -> 
             RGBColor[
              0.22399463203679326`, 0.35276293872357944`, 0.9360675349729086],
              UndirectedEdge[295, 300] -> 
             RGBColor[
              0.22777276498654234`, 0.3567339960012304, 0.9362826940551499], 
             UndirectedEdge[191, 451] -> 
             RGBColor[
              0.21492359957141377`, 0.343228708465789, 0.9355509530933952], 
             UndirectedEdge[137, 145] -> 
             RGBColor[
              0.2203693542453783, 0.34895254190891456`, 0.9358610807658054], 
             UndirectedEdge[332, 344] -> 
             RGBColor[
              0.4329675168621825, 0.5491533716913533, 0.9488874962659426], 
             UndirectedEdge[76, 392] -> 
             RGBColor[
              0.35866334703698777`, 0.48482413936361163`, 0.9440839805262493],
              UndirectedEdge[157, 465] -> 
             RGBColor[
              0.2925845958094424, 0.42485533950351484`, 0.9399736319400027], 
             UndirectedEdge[204, 337] -> 
             RGBColor[
              0.6810518757467315, 0.7489355468683991, 0.970229432274497], 
             UndirectedEdge[112, 395] -> 
             RGBColor[
              0.2566255492107321, 0.38706010159303317`, 0.9379258174328484], 
             UndirectedEdge[51, 107] -> 
             RGBColor[
              0.18179934664985797`, 0.3084130184462969, 0.9336645758924533], 
             UndirectedEdge[5, 41] -> 
             RGBColor[
              0.23556700835298144`, 0.36492623996293, 0.9367265646843188], 
             UndirectedEdge[88, 210] -> 
             RGBColor[
              0.8513369203215293, 0.3826983248089265, 0.19628825904818903`], 
             UndirectedEdge[248, 411] -> 
             RGBColor[
              0.2410648104835609, 0.37070477858295714`, 0.937039656382386], 
             UndirectedEdge[101, 128] -> 
             RGBColor[
              0.5077879700548952, 0.6112841755347511, 0.9543940755727961], 
             UndirectedEdge[298, 418] -> 
             RGBColor[
              0.9400566522436402, 0.9539366372768199, 0.955901674523727], 
             UndirectedEdge[1, 391] -> 
             RGBColor[
              0.25364635844324135`, 0.38392878320479584`, 0.9377561569259576],
              UndirectedEdge[116, 327] -> 
             RGBColor[
              0.25289755432094124`, 0.38314174259533496`, 0.937713513638949], 
             UndirectedEdge[79, 81] -> 
             RGBColor[
              0.9087234308797807, 0.9257016701540246, 0.7763552620147077], 
             UndirectedEdge[254, 368] -> 
             RGBColor[
              0.32229994971598047`, 0.44690195182710835`, 0.9420022258236223],
              UndirectedEdge[4, 318] -> 
             RGBColor[
              0.33312298494508064`, 0.46295611913654056`, 0.9424472799249791],
              UndirectedEdge[352, 412] -> 
             RGBColor[
              0.23510619043035305`, 0.36444189110870373`, 0.9367003217853442],
              UndirectedEdge[239, 424] -> 
             RGBColor[
              0.3357624743157177, 0.4652423121647933, 0.9426154658536674], 
             UndirectedEdge[58, 188] -> 
             RGBColor[
              0.32619444448890195`, 0.45695496563196736`, 0.9420057994537792],
              UndirectedEdge[407, 408] -> 
             RGBColor[
              0.2184314377890148, 0.3469156688422765, 0.9357507192905059], 
             UndirectedEdge[255, 466] -> 
             RGBColor[
              0.45054684949746193`, 0.5632999878437683, 0.9503059651560305], 
             UndirectedEdge[197, 489] -> 
             RGBColor[
              0.843861608566709, 0.8769414103999965, 0.8921342396544271], 
             UndirectedEdge[50, 363] -> 
             RGBColor[
              0.422874692158388, 0.5406945368727382, 0.9481661793442926], 
             UndirectedEdge[57, 175] -> 
             RGBColor[
              0.7784866261079177, 0.8268297266210345, 0.9607862455954495], 
             UndirectedEdge[278, 486] -> 
             RGBColor[
              0.9416456695144926, 0.9559801240610102, 0.9829731602176706], 
             UndirectedEdge[82, 263] -> 
             RGBColor[
              0.26583963752085393`, 0.39674469261391226`, 0.9384505461310877],
              UndirectedEdge[41, 186] -> 
             RGBColor[
              0.23411854278577374`, 0.36340381081377343`, 0.9366440767130793],
              UndirectedEdge[390, 425] -> 
             RGBColor[
              0.3380481584260487, 0.4664830926023694, 0.94278816472538], 
             UndirectedEdge[218, 458] -> 
             RGBColor[
              0.23123609658963368`, 0.36037417710398584`, 0.936479925666406], 
             UndirectedEdge[230, 374] -> 
             RGBColor[
              0.23780417240741958`, 0.3672776412285381, 0.9368539678676315], 
             UndirectedEdge[104, 408] -> 
             RGBColor[
              0.23453910043567894`, 0.36384584356871885`, 0.9366680268490819],
              UndirectedEdge[121, 213] -> 
             RGBColor[
              0.86583591956703, 0.4350120088827739, 0.20785705715207875`], 
             UndirectedEdge[143, 421] -> 
             RGBColor[
              0.1789918035644768, 0.3054621126550484, 0.9335046904671287], 
             UndirectedEdge[185, 482] -> 
             RGBColor[
              0.32121309396000997`, 0.4503473251053272, 0.9417723518156291], 
             UndirectedEdge[256, 333] -> 
             RGBColor[
              0.3340176365315557, 0.4619410698643276, 0.9425698252260324], 
             UndirectedEdge[351, 463] -> 
             RGBColor[
              0.27857140569147526`, 0.4101265882019613, 0.9391756014934415], 
             UndirectedEdge[42, 411] -> 
             RGBColor[
              0.23603211668449622`, 0.3654150983089235, 0.9367530519157325], 
             UndirectedEdge[52, 243] -> 
             RGBColor[
              0.837550577025578, 0.2896357665521757, 0.18359178100799164`], 
             UndirectedEdge[385, 391] -> 
             RGBColor[
              0.23729940724147955`, 0.36674710103517516`, 0.9368252222381643],
              UndirectedEdge[366, 435] -> 
             RGBColor[
              0.2615619901606841, 0.3922486140198663, 0.9382069404421383], 
             UndirectedEdge[114, 419] -> 
             RGBColor[
              0.5066845097134336, 0.6103883367192307, 0.9543072071326079], 
             UndirectedEdge[67, 391] -> 
             RGBColor[
              0.24887514925956578`, 0.37891393984061833`, 0.9374844436213188],
              UndirectedEdge[310, 327] -> 
             RGBColor[
              0.2769131154519483, 0.40838362001854456`, 0.939081164317521], 
             UndirectedEdge[309, 348] -> 
             RGBColor[
              0.976471187338104, 0.9319682118150352, 0.39079228120582354`], 
             UndirectedEdge[28, 194] -> 
             RGBColor[
              0.9756860818103763, 0.9810011844305191, 0.9087502503850045], 
             UndirectedEdge[92, 337] -> 
             RGBColor[
              0.7346741443689091, 0.7924685201915558, 0.974450773685277], 
             UndirectedEdge[205, 432] -> 
             RGBColor[
              0.9462255159241673, 0.9556033712696023, 0.7798152269955922], 
             UndirectedEdge[314, 398] -> 
             RGBColor[
              0.29561326424229706`, 0.426066606556162, 0.9402183167389095], 
             UndirectedEdge[235, 453] -> 
             RGBColor[
              0.32067427818872773`, 0.4499141070194098, 0.9417367931922191], 
             UndirectedEdge[92, 334] -> 
             RGBColor[
              0.505970833581321, 0.6084373708863062, 0.9546299931971096], 
             UndirectedEdge[35, 54] -> 
             RGBColor[
              0.23354661261843296`, 0.36280267594543125`, 0.936611506136144], 
             UndirectedEdge[191, 456] -> 
             RGBColor[
              0.22102995492901595`, 0.34964687511192016`, 0.9358987009974674],
              UndirectedEdge[78, 137] -> 
             RGBColor[
              0.21975482034818994`, 0.34830662781927, 0.9358260839694819], 
             UndirectedEdge[57, 169] -> 
             RGBColor[
              0.5469925860365322, 0.6431122489364671, 0.9574804065541109], 
             UndirectedEdge[343, 392] -> 
             RGBColor[
              0.29944445035868683`, 0.4320654815746701, 0.9403642905083368], 
             UndirectedEdge[24, 197] -> 
             RGBColor[
              0.7672988184851579, 0.8182762435725834, 0.9774043962108645], 
             UndirectedEdge[450, 471] -> 
             RGBColor[
              0.8372605332410615, 0.2874063629263848, 0.183314034752381], 
             UndirectedEdge[150, 267] -> 
             RGBColor[
              0.9052536312416688, 0.5703031723537458, 0.2900897268509228], 
             UndirectedEdge[40, 371] -> 
             RGBColor[
              0.37457203795785354`, 0.49885720556622565`, 0.9450883769309946],
              UndirectedEdge[217, 362] -> 
             RGBColor[
              0.35409065029754605`, 0.481117256999343, 0.9437833210202597], 
             UndirectedEdge[229, 478] -> 
             RGBColor[
              0.27850887095594073`, 0.41006086022998334`, 0.9391720402327646],
              UndirectedEdge[100, 168] -> 
             RGBColor[
              0.9210035362936968, 0.7245123759551941, 0.25529579489782767`], 
             UndirectedEdge[221, 297] -> 
             RGBColor[
              0.5279871450253872, 0.627682775738259, 0.9559842286184892], 
             UndirectedEdge[50, 338] -> 
             RGBColor[
              0.3805216773222415, 0.5040104841460892, 0.9454674826902338], 
             UndirectedEdge[5, 186] -> 
             RGBColor[
              0.23715887571324926`, 0.36659939348879156`, 0.9368172191755294],
              UndirectedEdge[147, 391] -> 
             RGBColor[
              0.24631019843469731`, 0.37621801389640636`, 0.9373383734663472],
              UndirectedEdge[24, 426] -> 
             RGBColor[
              0.8535732035252862, 0.8860801191364223, 0.9858957682176778], 
             UndirectedEdge[100, 127] -> 
             RGBColor[
              0.5785973319473678, 0.5599231651764567, 0.5998463238378839], 
             UndirectedEdge[418, 432] -> 
             RGBColor[
              0.9385489798096075, 0.9527344602026001, 0.9557578713810538], 
             UndirectedEdge[200, 259] -> 
             RGBColor[
              0.8813343532764009, 0.5540488379416193, 0.22269481442370878`], 
             UndirectedEdge[17, 293] -> 
             RGBColor[
              0.9171217844286204, 0.9362730779745756, 0.9753514321588153], 
             UndirectedEdge[269, 468] -> 
             RGBColor[
              0.4636581822326119, 0.5753387348931303, 0.9509528669224259], 
             UndirectedEdge[154, 390] -> 
             RGBColor[
              0.30514733542854805`, 0.43798605336538, 0.9406917533770347], 
             UndirectedEdge[162, 439] -> 
             RGBColor[
              0.6614719504889517, 0.7330346033014116, 0.9686938737233264], 
             UndirectedEdge[103, 304] -> 
             RGBColor[
              0.4094598762170423, 0.5283411604549934, 0.947514243402197], 
             UndirectedEdge[3, 480] -> 
             RGBColor[
              0.4076066344287682, 0.5272434439758863, 0.9472559414401728], 
             UndirectedEdge[358, 404] -> 
             RGBColor[
              0.21953726017780179`, 0.34807795828608057`, 0.9358136942396298],
              UndirectedEdge[3, 439] -> 
             RGBColor[
              0.6612892589149015, 0.732886286051436, 0.9686794915733958], 
             UndirectedEdge[336, 458] -> 
             RGBColor[
              0.22636890121139194`, 0.35525844616344304`, 0.9362027460899854],
              UndirectedEdge[212, 287] -> 
             RGBColor[
              0.21416398383706822`, 0.3424303041665726, 0.9355076941010749], 
             UndirectedEdge[190, 195] -> 
             RGBColor[
              0.25913077183266553`, 0.38969324940897365`, 0.9380684861550228],
              UndirectedEdge[253, 377] -> 
             RGBColor[
              0.9830684787672088, 0.9867535506374262, 0.9072964317019494], 
             UndirectedEdge[192, 327] -> 
             RGBColor[
              0.25584189976103616`, 0.38623643633515786`, 0.9378811897559938],
              UndirectedEdge[151, 483] -> 
             RGBColor[
              0.3017217477257488, 0.43445906549644486`, 0.9404939792244313], 
             UndirectedEdge[38, 163] -> 
             RGBColor[
              0.2634804930859057, 0.3942650822343853, 0.9383161963455589], 
             UndirectedEdge[88, 227] -> 
             RGBColor[
              0.8561206468687188, 0.41946814329296433`, 0.20086916099222407`],
              UndirectedEdge[281, 343] -> 
             RGBColor[
              0.26889808498261325`, 0.3999593148129905, 0.9386247201894673], 
             UndirectedEdge[76, 157] -> 
             RGBColor[
              0.35693445553108405`, 0.4830069647728541, 0.9439855227126539], 
             UndirectedEdge[364, 437] -> 
             RGBColor[
              0.25719856867599794`, 0.38766238138256004`, 0.9379584500436889],
              UndirectedEdge[229, 244] -> 
             RGBColor[
              0.3167084139494082, 0.447095666264713, 0.9414615153937971], 
             UndirectedEdge[154, 425] -> 
             RGBColor[
              0.3424420265478999, 0.47102780458425264`, 0.9430410810154058], 
             UndirectedEdge[128, 355] -> 
             RGBColor[
              0.4117250076221206, 0.5299124488854325, 0.9477665145867664], 
             UndirectedEdge[58, 382] -> 
             RGBColor[
              0.2986682199237062, 0.43066105766182183`, 0.9403416352703349], 
             UndirectedEdge[45, 179] -> 
             RGBColor[
              0.2308558043838454, 0.3599744658837838, 0.9364582685878783], 
             UndirectedEdge[181, 296] -> 
             RGBColor[
              0.3670585086059648, 0.49234936408258523`, 0.9446096214846453], 
             UndirectedEdge[350, 354] -> 
             RGBColor[
              0.36196691822383753`, 0.4879392844043602, 0.9442851898478128], 
             UndirectedEdge[318, 335] -> 
             RGBColor[
              0.3093572475376726, 0.43941523304457686`, 0.9410411890738053], 
             UndirectedEdge[354, 372] -> 
             RGBColor[
              0.416108457877265, 0.5343687074376324, 0.9478635928798225], 
             UndirectedEdge[44, 57] -> 
             RGBColor[
              0.5489601186307986, 0.6447095805328258, 0.9576352979272409], 
             UndirectedEdge[257, 420] -> 
             RGBColor[
              0.9137481314322007, 0.7140513423503487, 0.5709499365964574], 
             UndirectedEdge[84, 171] -> 
             RGBColor[
              0.2475282592649566, 0.3774982730585261, 0.9374077402286709], 
             UndirectedEdge[376, 497] -> 
             RGBColor[
              0.25772437162935435`, 0.38821503362437043`, 0.9379883937440268],
              UndirectedEdge[164, 443] -> 
             RGBColor[
              0.8760183447320038, 0.45688851313920237`, 0.21528999668843654`],
              UndirectedEdge[2, 54] -> 
             RGBColor[
              0.22058424144202293`, 0.3491784019772233, 0.9358733182737572], 
             UndirectedEdge[165, 324] -> 
             RGBColor[
              0.3968553526992069, 0.5181578928032218, 0.9465082500419522], 
             UndirectedEdge[82, 395] -> 
             RGBColor[
              0.26163309800222595`, 0.39232335286982434`, 0.9382109899285194],
              UndirectedEdge[298, 420] -> 
             RGBColor[
              0.9351413217232607, 0.9502707918228358, 0.9642220469712115], 
             UndirectedEdge[163, 437] -> 
             RGBColor[
              0.26141138655191587`, 0.3920903200782306, 0.9381983637894169], 
             UndirectedEdge[156, 372] -> 
             RGBColor[
              0.46888111877498084`, 0.5796978409320405, 0.951331185719549], 
             UndirectedEdge[272, 317] -> 
             RGBColor[
              0.8519916278011412, 0.36132246904964216`, 0.1958811278335439], 
             UndirectedEdge[282, 441] -> 
             RGBColor[
              0.5288953957407483, 0.628333638126909, 0.9560796286709814], 
             UndirectedEdge[209, 423] -> 
             RGBColor[
              0.37687473184245884`, 0.48661428775252374`, 0.9464892509185017],
              UndirectedEdge[222, 333] -> 
             RGBColor[
              0.41068141899913524`, 0.5301333365139219, 0.9473892347606732], 
             UndirectedEdge[125, 455] -> 
             RGBColor[
              0.20630711262003382`, 0.3341722343630622, 0.9350602569084642], 
             UndirectedEdge[343, 433] -> 
             RGBColor[
              0.3091968798489231, 0.4407663035487692, 0.9409764153784905], 
             UndirectedEdge[29, 77] -> 
             RGBColor[
              0.5082190929851442, 0.6104476858288989, 0.9547558471761093], 
             UndirectedEdge[298, 353] -> 
             RGBColor[
              0.7706511770330843, 0.8213765109750578, 0.9776280646137345], 
             UndirectedEdge[65, 337] -> 
             RGBColor[
              0.9228377639355362, 0.92700213552959, 0.6922814441739551], 
             UndirectedEdge[93, 364] -> 
             RGBColor[
              0.2639259772143767, 0.39473331429873343`, 0.9383415660076406], 
             UndirectedEdge[170, 328] -> 
             RGBColor[
              0.3409967871765409, 0.4686604793300483, 0.9429898367152708], 
             UndirectedEdge[13, 244] -> 
             RGBColor[
              0.3195286449146627, 0.4500599078221664, 0.9416221233751105], 
             UndirectedEdge[114, 291] -> 
             RGBColor[
              0.577802812280651, 0.6679328507014297, 0.9600375327920143], 
             UndirectedEdge[198, 373] -> 
             RGBColor[
              0.28774746699468884`, 0.4197712104275283, 0.9396981646098933], 
             UndirectedEdge[54, 84] -> 
             RGBColor[
              0.23101754524273913`, 0.3601444657814439, 0.9364674794905181], 
             UndirectedEdge[1, 385] -> 
             RGBColor[
              0.2498185382943033, 0.379905501530447, 0.937538168231228], 
             UndirectedEdge[97, 294] -> 
             RGBColor[
              0.23502362506905988`, 0.3643551096790384, 0.936695619810163], 
             UndirectedEdge[83, 489] -> 
             RGBColor[
              0.9554216482771469, 0.9649073806371287, 0.9030373799764648], 
             UndirectedEdge[349, 359] -> 
             RGBColor[
              0.3995263663781553, 0.520471390602876, 0.94667844467169], 
             UndirectedEdge[47, 55] -> 
             RGBColor[
              0.22170565849658444`, 0.35035708240351526`, 0.9359371813160265],
              UndirectedEdge[166, 309] -> 
             RGBColor[
              0.9155755884315661, 0.6407588014939913, 0.33347870741883034`], 
             UndirectedEdge[196, 482] -> 
             RGBColor[
              0.3270903866194627, 0.45652473233228946`, 0.9421070549379097], 
             UndirectedEdge[114, 311] -> 
             RGBColor[
              0.6237676761079407, 0.7038409516692123, 0.9646188808522442], 
             UndirectedEdge[101, 169] -> 
             RGBColor[
              0.506787455963573, 0.6104719131227696, 0.9543153114385234], 
             UndirectedEdge[160, 353] -> 
             RGBColor[
              0.531072144514868, 0.6293500407838779, 0.9564584330755022], 
             UndirectedEdge[80, 329] -> 
             RGBColor[
              0.8360503988309712, 0.8723539542869803, 0.9841591349586778], 
             UndirectedEdge[130, 386] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[216, 238] -> 
             RGBColor[
              0.29301995095784455`, 0.42425818517520597`, 0.9400370439768699],
              UndirectedEdge[240, 382] -> 
             RGBColor[
              0.26942512488484194`, 0.40051326716649266`, 0.9386547343322136],
              UndirectedEdge[424, 470] -> 
             RGBColor[
              0.28803826967359597`, 0.4189813939860375, 0.9397548358601392], 
             UndirectedEdge[184, 225] -> 
             RGBColor[
              0.2656405828545585, 0.396535473538841, 0.9384392102623171], 
             UndirectedEdge[169, 274] -> 
             RGBColor[
              0.4777382226320348, 0.5868884368511786, 0.9520284493798168], 
             UndirectedEdge[345, 375] -> 
             RGBColor[
              0.8089633164388916, 0.8512244424146573, 0.9611785706908804], 
             UndirectedEdge[326, 434] -> 
             RGBColor[
              0.9331890448533395, 0.7583565146768234, 0.5065076494810187], 
             UndirectedEdge[59, 105] -> 
             RGBColor[
              0.2440481876886619, 0.3738404971825583, 0.9372095553007055], 
             UndirectedEdge[90, 306] -> 
             RGBColor[
              0.8611746456929213, 0.4612099603827511, 0.20582221997608346`], 
             UndirectedEdge[44, 466] -> 
             RGBColor[
              0.5000927113166715, 0.6050368178236056, 0.9537882766162615], 
             UndirectedEdge[88, 434] -> 
             RGBColor[
              0.9289063525023188, 0.7389098089590498, 0.5029340660049313], 
             UndirectedEdge[174, 356] -> 
             RGBColor[
              0.2679975194043914, 0.3990127632911238, 0.938573434312055], 
             UndirectedEdge[65, 88] -> 
             RGBColor[
              0.9260374771709088, 0.7249105779401631, 0.30422129427437533`], 
             UndirectedEdge[82, 195] -> 
             RGBColor[
              0.2642152742010554, 0.39503738377422104`, 0.9383580410430554], 
             UndirectedEdge[150, 413] -> 
             RGBColor[
              0.8976403406773998, 0.5446217555948332, 0.26051353065802335`], 
             UndirectedEdge[156, 307] -> 
             RGBColor[
              0.4685593666518582, 0.5794366280637215, 0.9513058562137999], 
             UndirectedEdge[245, 460] -> 
             RGBColor[
              0.23495456172986623`, 0.36428251973067727`, 0.936691686755166], 
             UndirectedEdge[101, 204] -> 
             RGBColor[
              0.5113628894889524, 0.6141864561796039, 0.9546755063260064], 
             UndirectedEdge[210, 428] -> 
             RGBColor[
              0.8331986050247592, 0.2561846027075905, 0.17942432770515804`], 
             UndirectedEdge[25, 76] -> 
             RGBColor[
              0.36235029179287925`, 0.48827134332094824`, 0.9443096180726283],
              UndirectedEdge[130, 421] -> 
             RGBColor[
              0.17899180289058533`, 0.3054621119467458, 0.9335046904287516], 
             UndirectedEdge[79, 493] -> 
             RGBColor[
              0.9937029879453217, 0.9889396528776512, 0.5559872823811043], 
             UndirectedEdge[194, 490] -> 
             RGBColor[
              0.9885348242076832, 0.9895268694153684, 0.8396711640099095], 
             UndirectedEdge[214, 347] -> 
             RGBColor[
              0.1893670574265447, 0.316367162293171, 0.9340955458257609], 
             UndirectedEdge[41, 202] -> 
             RGBColor[
              0.2357918679274276, 0.3651625816325934, 0.9367393701044336], 
             UndirectedEdge[85, 97] -> 
             RGBColor[
              0.22297503114412753`, 0.3516912735389574, 0.9360094702104356], 
             UndirectedEdge[31, 114] -> 
             RGBColor[
              0.47685837337515014`, 0.5861665400670314, 0.9519612830883075], 
             UndirectedEdge[247, 425] -> 
             RGBColor[
              0.4351771155351065, 0.550218204604259, 0.9492628740426365], 
             UndirectedEdge[35, 281] -> 
             RGBColor[
              0.2416405448941051, 0.37130991195210916`, 0.9370724436053437], 
             UndirectedEdge[157, 288] -> 
             RGBColor[
              0.2793047597177943, 0.4108973897809534, 0.9392173649203402], 
             UndirectedEdge[208, 427] -> 
             RGBColor[
              0.3008093263098471, 0.4322636714318231, 0.9404872881507658], 
             UndirectedEdge[154, 313] -> 
             RGBColor[
              0.2882495492104231, 0.42022540866860447`, 0.9397294494499471], 
             UndirectedEdge[189, 364] -> 
             RGBColor[
              0.25917101959394173`, 0.3897355523579304, 0.9380707782054862], 
             UndirectedEdge[314, 373] -> 
             RGBColor[
              0.3118454823562334, 0.44312769697598026`, 0.9411427175470836], 
             UndirectedEdge[156, 232] -> 
             RGBColor[
              0.4117533959329014, 0.5306819361106889, 0.9475625057353367], 
             UndirectedEdge[321, 383] -> 
             RGBColor[
              0.3310589867507921, 0.46116838764021345`, 0.942315763785161], 
             UndirectedEdge[15, 323] -> 
             RGBColor[
              0.2367917298527569, 0.36621349991102203`, 0.936796310761918], 
             UndirectedEdge[225, 235] -> 
             RGBColor[
              0.31564550837904015`, 0.44462855110700683`, 0.9414504121909557],
              UndirectedEdge[170, 265] -> 
             RGBColor[
              0.3088475371272851, 0.4408144148056739, 0.9409413149305978], 
             UndirectedEdge[102, 485] -> 
             RGBColor[
              0.2622693737921402, 0.3929921190672394, 0.9382472248934693], 
             UndirectedEdge[342, 463] -> 
             RGBColor[
              0.2635422521882549, 0.3943299949667075, 0.9383197134350733], 
             UndirectedEdge[70, 147] -> 
             RGBColor[
              0.2548716664665323, 0.3852166596262904, 0.9378259364052033], 
             UndirectedEdge[162, 381] -> 
             RGBColor[
              0.515668109442376, 0.6176816276857418, 0.9550144290112803], 
             UndirectedEdge[212, 299] -> 
             RGBColor[
              0.21384131413680724`, 0.3420911578531577, 0.9354893185389921], 
             UndirectedEdge[92, 361] -> 
             RGBColor[
              0.6266695180780231, 0.7077693478258749, 0.9637721633771799], 
             UndirectedEdge[82, 184] -> 
             RGBColor[
              0.2576552479933815, 0.38814238030027126`, 0.9379844572552174], 
             UndirectedEdge[232, 376] -> 
             RGBColor[
              0.3178263634409366, 0.4469988106247622, 0.9415717511395277], 
             UndirectedEdge[293, 298] -> 
             RGBColor[
              0.9279560632534805, 0.9449120378208546, 0.9763848153450053], 
             UndirectedEdge[225, 249] -> 
             RGBColor[
              0.28189858083211217`, 0.41362366022985875`, 0.9393650791955862],
              UndirectedEdge[19, 34] -> 
             RGBColor[
              0.5517387974757788, 0.6469654371972362, 0.9578540457045537], 
             UndirectedEdge[338, 390] -> 
             RGBColor[
              0.3104293975603457, 0.44256111009978116`, 0.9410283217053288], 
             UndirectedEdge[82, 342] -> 
             RGBColor[
              0.2591328832418887, 0.3896954686339382, 0.9380686063966545], 
             UndirectedEdge[54, 374] -> 
             RGBColor[
              0.24022555960590497`, 0.3698226726989618, 0.9369918622864639], 
             UndirectedEdge[196, 350] -> 
             RGBColor[
              0.3289346637950721, 0.4581221525257362, 0.9422245706487093], 
             UndirectedEdge[19, 44] -> 
             RGBColor[
              0.5282008880554978, 0.6278563019591167, 0.956001055252786], 
             UndirectedEdge[85, 408] -> 
             RGBColor[
              0.21836004410720744`, 0.3468406295560761, 0.9357466535259444], 
             UndirectedEdge[57, 255] -> 
             RGBColor[
              0.499414256811589, 0.6029727505529885, 0.9541529864670097], 
             UndirectedEdge[106, 269] -> 
             RGBColor[
              0.48339733950661234`, 0.5913638720070653, 0.9525068056899508], 
             UndirectedEdge[382, 416] -> 
             RGBColor[
              0.2718791903645599, 0.40309264558241453`, 0.938794489730819], 
             UndirectedEdge[246, 392] -> 
             RGBColor[
              0.3001114005223494, 0.4327664884837622, 0.940402272333493], 
             UndirectedEdge[350, 414] -> 
             RGBColor[
              0.31841398035212815`, 0.44706424717734483`, 0.94162543329059], 
             UndirectedEdge[146, 211] -> 
             RGBColor[
              0.2444868180291041, 0.37430152548113294`, 0.9372345346496982], 
             UndirectedEdge[71, 487] -> 
             RGBColor[
              0.6676064579243342, 0.7392945350984725, 0.9681635028375868], 
             UndirectedEdge[415, 485] -> 
             RGBColor[
              0.2675069384795197, 0.39849713163445644`, 0.9385454964541331], 
             UndirectedEdge[238, 433] -> 
             RGBColor[
              0.32283008594645624`, 0.45404092736007795`, 0.94179142550244], 
             UndirectedEdge[141, 429] -> 
             RGBColor[
              0.30159042381675216`, 0.434243660437526, 0.9404893336110074], 
             UndirectedEdge[406, 493] -> 
             RGBColor[
              0.9920978208950986, 0.9843432363296774, 0.4801786397760631], 
             UndirectedEdge[257, 357] -> 
             RGBColor[
              0.8829978584207956, 0.5607626793064351, 0.22403944465155362`], 
             UndirectedEdge[311, 488] -> 
             RGBColor[
              0.7581105843852092, 0.8109610174663499, 0.9765250361714609], 
             UndirectedEdge[258, 381] -> 
             RGBColor[
              0.4713636222770108, 0.5795438974068458, 0.952126015828245], 
             UndirectedEdge[168, 200] -> 
             RGBColor[
              0.9058101136750496, 0.6632964389017137, 0.24302016366679569`], 
             UndirectedEdge[16, 254] -> 
             RGBColor[
              0.3201901654275895, 0.4450745627173458, 0.941867792234375], 
             UndirectedEdge[325, 347] -> 
             RGBColor[
              0.1789719601845752, 0.3054412560046289, 0.9335035604159989], 
             UndirectedEdge[154, 478] -> 
             RGBColor[
              0.28779157321631055`, 0.419744046861437, 0.9397033683945971], 
             UndirectedEdge[302, 386] -> 
             RGBColor[
              0.18453817917078433`, 0.311291705077802, 0.9338205483527805], 
             UndirectedEdge[330, 414] -> 
             RGBColor[
              0.2905537605670515, 0.4227208029013707, 0.9398579788773], 
             UndirectedEdge[50, 334] -> 
             RGBColor[
              0.42187105269828507`, 0.539825234816783, 0.9481022283253784], 
             UndirectedEdge[72, 187] -> 
             RGBColor[
              0.2593062768219157, 0.38987771628033463`, 0.9380784809045242], 
             UndirectedEdge[14, 149] -> 
             RGBColor[
              0.33030872638618497`, 0.46033332920658265`, 0.9422747396921978],
              UndirectedEdge[113, 214] -> 
             RGBColor[
              0.18949968777431325`, 0.3165065651979255, 0.9341030989278573], 
             UndirectedEdge[63, 149] -> 
             RGBColor[
              0.3866051837093468, 0.5092797116126782, 0.9458551183377868], 
             UndirectedEdge[245, 445] -> 
             RGBColor[
              0.22560109399094413`, 0.3544514320929628, 0.93615902060465], 
             UndirectedEdge[207, 336] -> 
             RGBColor[
              0.2196507706490151, 0.34819726498830533`, 0.9358201584930417], 
             UndirectedEdge[264, 394] -> 
             RGBColor[
              0.23171433520063273`, 0.36087683620622507`, 0.9365071606478118],
              UndirectedEdge[255, 370] -> 
             RGBColor[
              0.4945144317215364, 0.598994851810279, 0.9537672542872702], 
             UndirectedEdge[330, 482] -> 
             RGBColor[
              0.33246549585026375`, 0.4621743129354704, 0.9424131594568423], 
             UndirectedEdge[383, 482] -> 
             RGBColor[
              0.34371197944189347`, 0.47212777395134153`, 0.9431220012908359],
              UndirectedEdge[358, 407] -> 
             RGBColor[
              0.21999227740316346`, 0.34855621023969413`, 0.9358396067974764],
              UndirectedEdge[28, 142] -> 
             RGBColor[
              0.8321901895218196, 0.869251634409216, 0.9575296911592543], 
             UndirectedEdge[348, 375] -> 
             RGBColor[
              0.959056524042907, 0.9223909347161948, 0.6272014222552931], 
             UndirectedEdge[41, 295] -> 
             RGBColor[
              0.23105727915165333`, 0.3601862286389881, 0.9364697422778497], 
             UndirectedEdge[83, 345] -> 
             RGBColor[
              0.7902354483667869, 0.8368716246944006, 0.9795108205407682], 
             UndirectedEdge[140, 425] -> 
             RGBColor[
              0.4374884569477172, 0.5520946556877604, 0.9494448313053598], 
             UndirectedEdge[160, 441] -> 
             RGBColor[
              0.4363070753078513, 0.5523289920255958, 0.9490220789207864], 
             UndirectedEdge[66, 394] -> 
             RGBColor[
              0.24596177604056546`, 0.3758517998689181, 0.937318531326446], 
             UndirectedEdge[201, 271] -> 
             RGBColor[
              0.2801320470703391, 0.4117669212415258, 0.9392644777112058], 
             UndirectedEdge[192, 470] -> 
             RGBColor[
              0.255048373399578, 0.3854023898167881, 0.9378359996036256], 
             UndirectedEdge[255, 379] -> 
             RGBColor[
              0.35344236256380235`, 0.4805557427482631, 0.943742012699124], 
             UndirectedEdge[82, 440] -> 
             RGBColor[
              0.26997623108034263`, 0.40109251472011487`, 0.9386861190147588],
              UndirectedEdge[43, 362] -> 
             RGBColor[
              0.34080467652755875`, 0.4681674552795022, 0.9429895550260083], 
             UndirectedEdge[127, 302] -> 
             RGBColor[
              0.2080645848230672, 0.3360194490786239, 0.9351603423504797], 
             UndirectedEdge[137, 358] -> 
             RGBColor[
              0.22285337720406, 0.3515634075346411, 0.9360025421985196], 
             UndirectedEdge[238, 328] -> 
             RGBColor[
              0.35273346300045894`, 0.47994172957682313`, 0.943696842245803], 
             UndirectedEdge[185, 196] -> 
             RGBColor[
              0.2898220421197416, 0.4219517204196188, 0.9398163085942062], 
             UndirectedEdge[114, 208] -> 
             RGBColor[
              0.41139850447614446`, 0.5294684917353877, 0.9477902381259522], 
             UndirectedEdge[249, 424] -> 
             RGBColor[
              0.30507115038591015`, 0.4368840315616916, 0.9407248332188166], 
             UndirectedEdge[21, 65] -> 
             RGBColor[
              0.9831762967586118, 0.9549118399527363, 0.38914351910732653`], 
             UndirectedEdge[369, 466] -> 
             RGBColor[
              0.46172779849419876`, 0.5729843638939052, 0.9510184053391775], 
             UndirectedEdge[246, 459] -> 
             RGBColor[
              0.3423837632254584, 0.4696344421074833, 0.9430865385917233], 
             UndirectedEdge[46, 317] -> 
             RGBColor[
              0.9005275853462438, 0.6373329329271229, 0.23851003583391922`], 
             UndirectedEdge[66, 305] -> 
             RGBColor[
              0.25719647261268064`, 0.38766017828711546`, 0.9379583306759838],
              UndirectedEdge[56, 243] -> 
             RGBColor[
              0.8379898589381207, 0.2930122798265395, 0.18401243786354038`], 
             UndirectedEdge[281, 288] -> 
             RGBColor[
              0.2504872858476244, 0.38060839761003135`, 0.9375762524150663], 
             UndirectedEdge[81, 329] -> 
             RGBColor[
              0.8530880154845231, 0.8856932433627962, 0.9858494905492173], 
             UndirectedEdge[57, 140] -> 
             RGBColor[
              0.550438526060826, 0.6459098182860178, 0.9577516835757175], 
             UndirectedEdge[184, 440] -> 
             RGBColor[
              0.26935285588816305`, 0.4004373078688641, 0.9386506187197652], 
             UndirectedEdge[422, 446] -> 
             RGBColor[
              0.2310816388212659, 0.36021183219624314`, 0.9364711295249972], 
             UndirectedEdge[232, 307] -> 
             RGBColor[
              0.4130035971526026, 0.5316969057817654, 0.9476609261549895], 
             UndirectedEdge[90, 261] -> 
             RGBColor[
              0.8723782969076955, 0.5133814777114375, 0.21522166145663085`], 
             UndirectedEdge[118, 304] -> 
             RGBColor[
              0.3318360758338559, 0.46184146314633034`, 0.9423652792143808], 
             UndirectedEdge[427, 460] -> 
             RGBColor[
              0.2639231904685617, 0.39473038525219195`, 0.938341407306589], 
             UndirectedEdge[299, 300] -> 
             RGBColor[
              0.21756201185689822`, 0.346001847062834, 0.9357012067698722], 
             UndirectedEdge[106, 425] -> 
             RGBColor[
              0.4465990938801403, 0.559491081179018, 0.9501620540180429], 
             UndirectedEdge[428, 495] -> 
             RGBColor[
              0.8362679836981737, 0.2797771922017657, 0.1823635681891872], 
             UndirectedEdge[230, 365] -> 
             RGBColor[
              0.22042634378562792`, 0.3490124415290624, 0.9358643262358141], 
             UndirectedEdge[224, 463] -> 
             RGBColor[
              0.2830318265857735, 0.4148147733688876, 0.9394296158647704], 
             UndirectedEdge[251, 382] -> 
             RGBColor[
              0.27038494943162866`, 0.40152210362155666`, 0.9387093949202199],
              UndirectedEdge[81, 278] -> 
             RGBColor[
              0.8859909437525565, 0.9116025564457284, 0.9776647627909368], 
             UndirectedEdge[42, 294] -> 
             RGBColor[
              0.23539350574473433`, 0.36474387772096156`, 0.9367166839674533],
              UndirectedEdge[8, 419] -> 
             RGBColor[
              0.5664920822105015, 0.6589428183727875, 0.9590154783219338], 
             UndirectedEdge[159, 164] -> 
             RGBColor[
              0.819137437150352, 0.14810430478184575`, 0.1659593374688081], 
             UndirectedEdge[346, 404] -> 
             RGBColor[
              0.21566548218765702`, 0.3440084741335353, 0.9355932022108733], 
             UndirectedEdge[7, 194] -> 
             RGBColor[
              0.9125990982944516, 0.9314492168831301, 0.9288011319761822], 
             UndirectedEdge[268, 353] -> 
             RGBColor[
              0.5246586597567469, 0.6237950026375101, 0.9560497714979366], 
             UndirectedEdge[51, 423] -> 
             RGBColor[
              0.18337644614132015`, 0.31007065000570677`, 0.9337543893753826],
              UndirectedEdge[14, 322] -> 
             RGBColor[
              0.2829806146027809, 0.4147609463277351, 0.9394266994181002], 
             UndirectedEdge[109, 458] -> 
             RGBColor[
              0.24222963005763265`, 0.3719290778091332, 0.9371059911339332], 
             UndirectedEdge[217, 384] -> 
             RGBColor[
              0.30177027996931804`, 0.4334954768697517, 0.9405338925067932], 
             UndirectedEdge[202, 485] -> 
             RGBColor[
              0.2435291255920976, 0.37329493000863156`, 0.9371799954821897], 
             UndirectedEdge[125, 457] -> 
             RGBColor[
              0.21513132866869134`, 0.3434470449178132, 0.9355627829581774], 
             UndirectedEdge[454, 475] -> 
             RGBColor[
              0.8694429086173421, 0.4695370183739893, 0.21157738923531183`], 
             UndirectedEdge[30, 378] -> 
             RGBColor[
              0.2755078252460146, 0.406906570911563, 0.9390011351192336], 
             UndirectedEdge[445, 460] -> 
             RGBColor[
              0.23899278558713355`, 0.3685269490428458, 0.9369216576298206], 
             UndirectedEdge[173, 461] -> 
             RGBColor[
              0.9645092309315171, 0.9729899937684735, 0.9422009085196323], 
             UndirectedEdge[23, 41] -> 
             RGBColor[
              0.22751409159888136`, 0.35646211386995863`, 0.9362679629883957],
              UndirectedEdge[111, 444] -> 
             RGBColor[
              0.272192144891436, 0.40342158063262434`, 0.9388123120281499], 
             UndirectedEdge[139, 360] -> 
             RGBColor[
              0.5717007512056378, 0.6631714505109032, 0.9594255238252141], 
             UndirectedEdge[53, 432] -> 
             RGBColor[
              0.9375683877182548, 0.9272177056729635, 0.6767239867532486], 
             UndirectedEdge[184, 260] -> 
             RGBColor[
              0.2713041510776424, 0.40248824283226764`, 0.9387617420941234], 
             UndirectedEdge[244, 379] -> 
             RGBColor[
              0.3258701140726008, 0.45667404692668806`, 0.9419851334064466], 
             UndirectedEdge[14, 187] -> 
             RGBColor[
              0.28568538812664784`, 0.41760383479386565`, 0.9395807322689307],
              UndirectedEdge[133, 332] -> 
             RGBColor[
              0.3736828594731001, 0.4980870438541423, 0.9450317192642157], 
             UndirectedEdge[424, 440] -> 
             RGBColor[
              0.30113413549531765`, 0.4327459792905174, 0.940500626045089], 
             UndirectedEdge[381, 419] -> 
             RGBColor[
              0.5409976687744238, 0.6382453050351424, 0.9570084647071322], 
             UndirectedEdge[39, 368] -> 
             RGBColor[
              0.5158816187650146, 0.6166272342584453, 0.9553704626805029], 
             UndirectedEdge[40, 208] -> 
             RGBColor[
              0.3541593410951509, 0.4811767535157284, 0.9437876979371422], 
             UndirectedEdge[436, 462] -> 
             RGBColor[
              0.46839908955768095`, 0.5793065078982675, 0.951293238613832], 
             UndirectedEdge[103, 188] -> 
             RGBColor[
              0.408816425381794, 0.5277838356822806, 0.9474732432839563], 
             UndirectedEdge[313, 411] -> 
             RGBColor[
              0.2532739296678089, 0.38353733694846814`, 0.9377349476581557], 
             UndirectedEdge[181, 344] -> 
             RGBColor[
              0.4422200885925819, 0.5571674842764482, 0.9494770619548758], 
             UndirectedEdge[5, 485] -> 
             RGBColor[
              0.24330426601765148`, 0.37305858833896816`, 0.9371671900620748],
              UndirectedEdge[371, 429] -> 
             RGBColor[
              0.3282709430209225, 0.4573529851702918, 0.9421893927020404], 
             UndirectedEdge[426, 448] -> 
             RGBColor[
              0.7190568535901429, 0.7797176017404024, 0.9733043071059779], 
             UndirectedEdge[32, 403] -> 
             RGBColor[
              0.73231135392298, 0.7900531713799142, 0.9748369526254256], 
             UndirectedEdge[115, 484] -> 
             RGBColor[
              0.9570300393594782, 0.9635915325846716, 0.7300132516870645], 
             UndirectedEdge[36, 251] -> 
             RGBColor[
              0.25646724614478844`, 0.3868937150337323, 0.9379168023074314], 
             UndirectedEdge[243, 454] -> 
             RGBColor[
              0.869594267772993, 0.47070043117032717`, 0.21172233093369885`], 
             UndirectedEdge[106, 139] -> 
             RGBColor[
              0.5409452590449157, 0.6382027564556965, 0.9570043388212421], 
             UndirectedEdge[220, 499] -> 
             RGBColor[
              0.2998159216660946, 0.42966675719263536`, 0.9404875702170554], 
             UndirectedEdge[359, 419] -> 
             RGBColor[
              0.44907089909255904`, 0.561772271120652, 0.9502808074967835], 
             UndirectedEdge[115, 297] -> 
             RGBColor[
              0.7202662947001824, 0.7803304830864486, 0.9738242280167566], 
             UndirectedEdge[155, 235] -> 
             RGBColor[
              0.4614654223098702, 0.5710633178486462, 0.9514696859030422], 
             UndirectedEdge[98, 261] -> 
             RGBColor[
              0.9376107771767181, 0.7700729496416561, 0.47213960027127755`], 
             UndirectedEdge[386, 421] -> 
             RGBColor[
              0.17899180289058533`, 0.3054621119467458, 0.9335046904287516], 
             UndirectedEdge[37, 58] -> 
             RGBColor[
              0.31037597127891847`, 0.44296664665046, 0.9410083743899482], 
             UndirectedEdge[71, 194] -> 
             RGBColor[
              0.8711488139703549, 0.898916809896938, 0.9247098602219754], 
             UndirectedEdge[47, 339] -> 
             RGBColor[
              0.22181216919966315`, 0.3504690319056196, 0.9359432469429985], 
             UndirectedEdge[108, 410] -> 
             RGBColor[
              0.32438785376155105`, 0.4532049421182389, 0.9419706976299311], 
             UndirectedEdge[193, 196] -> 
             RGBColor[
              0.29175552637074975`, 0.4239839349574104, 0.9399264176619675], 
             UndirectedEdge[131, 171] -> 
             RGBColor[
              0.26267563753313167`, 0.39341912801763035`, 0.9382703610125054],
              UndirectedEdge[203, 258] -> 
             RGBColor[
              0.45399453907585874`, 0.5654428931958693, 0.950758657973602], 
             UndirectedEdge[164, 428] -> 
             RGBColor[
              0.8239291026561835, 0.1849351455808791, 0.17054784176860438`], 
             UndirectedEdge[143, 325] -> 
             RGBColor[
              0.17897196085846667`, 0.30544125671293154`, 0.9335035604543761],
              UndirectedEdge[101, 498] -> 
             RGBColor[
              0.491361119566665, 0.5979481182872246, 0.9531008937288266], 
             UndirectedEdge[35, 391] -> 
             RGBColor[
              0.23974982774210207`, 0.3693226483469626, 0.9369647700606025], 
             UndirectedEdge[8, 221] -> 
             RGBColor[
              0.5784518548396522, 0.6686523005747489, 0.9599569954333912], 
             UndirectedEdge[240, 251] -> 
             RGBColor[
              0.25758537828186423`, 0.38806894280347104`, 0.9379804782785095],
              UndirectedEdge[464, 485] -> 
             RGBColor[
              0.24593397699878092`, 0.3758225813134415, 0.9373169482121415], 
             UndirectedEdge[104, 452] -> 
             RGBColor[
              0.2352635459876256, 0.36460728177631574`, 0.9367092829515442], 
             UndirectedEdge[121, 475] -> 
             RGBColor[
              0.8332346662535209, 0.256461785113985, 0.17945885997854572`], 
             UndirectedEdge[168, 315] -> 
             RGBColor[
              0.5481459181329882, 0.49816507299275914`, 0.5904774154442385], 
             UndirectedEdge[65, 320] -> 
             RGBColor[
              0.9870336626851595, 0.9760932232050978, 0.618291834936235], 
             UndirectedEdge[323, 452] -> 
             RGBColor[
              0.23164904535488023`, 0.3608082124387239, 0.9365034424876839], 
             UndirectedEdge[72, 322] -> 
             RGBColor[
              0.25660150329804876`, 0.38703482781420406`, 0.9379244480536938],
              UndirectedEdge[60, 327] -> 
             RGBColor[
              0.27488937913222444`, 0.40625654483422113`, 0.9389659155279624],
              UndirectedEdge[1, 135] -> 
             RGBColor[
              0.2583961289533292, 0.38892109316374235`, 0.9380266493298512], 
             UndirectedEdge[420, 439] -> 
             RGBColor[
              0.9147776569049322, 0.9340333582536569, 0.9622797424419812], 
             UndirectedEdge[134, 367] -> 
             RGBColor[
              0.23152572380893705`, 0.3606785936749, 0.9364964195080803], 
             UndirectedEdge[119, 345] -> 
             RGBColor[
              0.8251862844410536, 0.8622510331677843, 0.8856898202805965], 
             UndirectedEdge[64, 366] -> 
             RGBColor[
              0.27642037277284975`, 0.4078657162211217, 0.9390531033508938], 
             UndirectedEdge[86, 90] -> 
             RGBColor[
              0.8899814344584336, 0.5901544331035902, 0.2297467504579272], 
             UndirectedEdge[81, 426] -> 
             RGBColor[
              0.8468962698264015, 0.8807561134454687, 0.9852589163209091], 
             UndirectedEdge[70, 265] -> 
             RGBColor[
              0.28963233444531233`, 0.42061801847270397`, 0.9398470375642044],
              UndirectedEdge[245, 438] -> 
             RGBColor[
              0.22151371355788788`, 0.3501553361029332, 0.9359262503357249], 
             UndirectedEdge[121, 259] -> 
             RGBColor[
              0.8446533203330481, 0.33882677308300735`, 0.1901817771182239], 
             UndirectedEdge[74, 105] -> 
             RGBColor[
              0.2638196417670582, 0.3946215490015449, 0.938335510361225], 
             UndirectedEdge[358, 430] -> 
             RGBColor[
              0.23268261924121364`, 0.3618945641256297, 0.936562302991475], 
             UndirectedEdge[43, 316] -> 
             RGBColor[
              0.2718214258604257, 0.4030319314260883, 0.9387912001277635], 
             UndirectedEdge[162, 203] -> 
             RGBColor[
              0.4982990262412239, 0.6035806234747654, 0.9536470711566374], 
             UndirectedEdge[226, 236] -> 
             RGBColor[
              0.23337407460187973`, 0.3626213275504917, 0.9366016803513484], 
             UndirectedEdge[110, 340] -> 
             RGBColor[
              0.3045749314378675, 0.43480548891742876`, 0.9407535831342266], 
             UndirectedEdge[145, 407] -> 
             RGBColor[
              0.2175082544444818, 0.34594534461396753`, 0.9356981453647621], 
             UndirectedEdge[258, 289] -> 
             RGBColor[
              0.4063967473847854, 0.5264221693154291, 0.9471162192741931], 
             UndirectedEdge[13, 334] -> 
             RGBColor[
              0.3497101697631252, 0.47620162767835794`, 0.94354526344998], 
             UndirectedEdge[300, 389] -> 
             RGBColor[
              0.2222287148930997, 0.35090684783994386`, 0.9359669686040155], 
             UndirectedEdge[57, 363] -> 
             RGBColor[
              0.5030271726289528, 0.6061020766435601, 0.9543831982681161], 
             UndirectedEdge[305, 427] -> 
             RGBColor[
              0.26530600013852146`, 0.3961838058905166, 0.9384201562716097], 
             UndirectedEdge[277, 419] -> 
             RGBColor[
              0.6419960336426249, 0.718265092425402, 0.9663099050077802], 
             UndirectedEdge[40, 349] -> 
             RGBColor[
              0.3999008136180363, 0.5207957179817955, 0.9467023041187045], 
             UndirectedEdge[28, 241] -> 
             RGBColor[
              0.8351691071867402, 0.8715787875296648, 0.9578266018325254], 
             UndirectedEdge[164, 396] -> 
             RGBColor[
              0.9055353853140414, 0.5621560872497313, 0.3516608883245811], 
             UndirectedEdge[111, 284] -> 
             RGBColor[
              0.2590919383322233, 0.3896524329378227, 0.9380662746446216], 
             UndirectedEdge[25, 343] -> 
             RGBColor[
              0.3031313951145783, 0.4355126855320067, 0.9405899280547156], 
             UndirectedEdge[84, 131] -> 
             RGBColor[
              0.24846167161057395`, 0.3784793486155308, 0.9374608966808939], 
             UndirectedEdge[169, 244] -> 
             RGBColor[
              0.4175916065853016, 0.5350481346501237, 0.9481253168239769], 
             UndirectedEdge[219, 363] -> 
             RGBColor[
              0.4655401284489993, 0.5756684054061787, 0.9514320808307029], 
             UndirectedEdge[400, 415] -> 
             RGBColor[
              0.2914672574254832, 0.4236809460186285, 0.9399100011719903], 
             UndirectedEdge[248, 286] -> 
             RGBColor[
              0.23281996068137648`, 0.36203891868719107`, 0.9365701243833138],
              UndirectedEdge[136, 484] -> 
             RGBColor[
              0.980926180317411, 0.981787940062676, 0.7025545645628573], 
             UndirectedEdge[74, 263] -> 
             RGBColor[
              0.27756733242056764`, 0.40907124353231517`, 0.9391184210060566],
              UndirectedEdge[69, 142] -> 
             RGBColor[
              0.8044934065793106, 0.8479188521576653, 0.9809561216743297], 
             UndirectedEdge[109, 409] -> 
             RGBColor[
              0.24775783308986035`, 0.3777395697043211, 0.9374208141183751], 
             UndirectedEdge[101, 219] -> 
             RGBColor[
              0.5235508135187052, 0.6240811619666777, 0.9556349843514654], 
             UndirectedEdge[380, 390] -> 
             RGBColor[
              0.2868022644003798, 0.4187777425716037, 0.9396443367204493], 
             UndirectedEdge[53, 293] -> 
             RGBColor[
              0.9653923096103165, 0.9489247911355639, 0.6627722008261114], 
             UndirectedEdge[221, 258] -> 
             RGBColor[
              0.45501626161494246`, 0.5662723735811732, 0.9508390917145717], 
             UndirectedEdge[235, 424] -> 
             RGBColor[
              0.3388180779328382, 0.46788892243883967`, 0.9428101662141861], 
             UndirectedEdge[367, 457] -> 
             RGBColor[
              0.22571706608911693`, 0.3545733261211982, 0.9361656250440755], 
             UndirectedEdge[58, 220] -> 
             RGBColor[
              0.32701247471585293`, 0.45766350229915764`, 0.9420579236164848],
              UndirectedEdge[334, 379] -> 
             RGBColor[
              0.3560516389210633, 0.4828157667828796, 0.9439082734813162], 
             UndirectedEdge[14, 163] -> 
             RGBColor[
              0.2868674954285888, 0.4188463045181374, 0.9396480515310051], 
             UndirectedEdge[284, 442] -> 
             RGBColor[
              0.26451897986036277`, 0.3953565976782041, 0.9383753366310607], 
             UndirectedEdge[130, 302] -> 
             RGBColor[
              0.18453817917078433`, 0.311291705077802, 0.9338205483527805], 
             UndirectedEdge[65, 428] -> 
             RGBColor[
              0.9078991618741388, 0.5983968558388272, 0.2873573629313444], 
             UndirectedEdge[388, 487] -> 
             RGBColor[
              0.7628017392959624, 0.8144116714200249, 0.9680174393113103], 
             UndirectedEdge[456, 458] -> 
             RGBColor[
              0.22707889219219896`, 0.35600469170029936`, 0.9362431790260048],
              UndirectedEdge[281, 465] -> 
             RGBColor[
              0.26376712193927254`, 0.39456634733259277`, 0.9383325194347287],
              UndirectedEdge[166, 428] -> 
             RGBColor[
              0.8342269539589475, 0.26408894324113896`, 0.18040907580589088`],
              UndirectedEdge[92, 128] -> 
             RGBColor[
              0.5519404005403256, 0.6471291076471498, 0.9578699166362912], 
             UndirectedEdge[120, 457] -> 
             RGBColor[
              0.21450528797873675`, 0.3427890364593986, 0.9355271308670288], 
             UndirectedEdge[79, 329] -> 
             RGBColor[
              0.9381932995999778, 0.9492001435332333, 0.7791661244013025], 
             UndirectedEdge[105, 195] -> 
             RGBColor[
              0.2580285978828387, 0.38853479470584096`, 0.9380057189791005], 
             UndirectedEdge[98, 377] -> 
             RGBColor[
              0.9881699242791049, 0.9888223570121889, 0.8197885510745015], 
             UndirectedEdge[21, 309] -> 
             RGBColor[
              0.9869592653755547, 0.967346961753188, 0.4315364838739727], 
             UndirectedEdge[93, 322] -> 
             RGBColor[
              0.26425191426448674`, 0.3950758948040016, 0.9383601276404636], 
             UndirectedEdge[8, 115] -> 
             RGBColor[
              0.7707310045144475, 0.8213000079229384, 0.9777969948316587], 
             UndirectedEdge[54, 131] -> 
             RGBColor[
              0.24616492351091418`, 0.3760653207405481, 0.9373301002743527], 
             UndirectedEdge[186, 212] -> 
             RGBColor[
              0.22711333090057176`, 0.3560408889663394, 0.9362451402594992], 
             UndirectedEdge[252, 467] -> 
             RGBColor[
              0.7213175895970523, 0.7822180503007243, 0.9728578543010624], 
             UndirectedEdge[244, 378] -> 
             RGBColor[
              0.3127627275114677, 0.4429484996474682, 0.9412368143882763], 
             UndirectedEdge[55, 339] -> 
             RGBColor[
              0.21158417509033906`, 0.33971876160443837`, 0.9353607778094337],
              UndirectedEdge[69, 490] -> 
             RGBColor[
              0.9500080335378767, 0.9605032008441318, 0.8987210231001681], 
             UndirectedEdge[299, 451] -> 
             RGBColor[
              0.21030609728277713`, 0.3383754207938774, 0.9352879931690398], 
             UndirectedEdge[146, 464] -> 
             RGBColor[
              0.25089999678857744`, 0.38104218297635795`, 0.9375997556926023],
              UndirectedEdge[199, 220] -> 
             RGBColor[
              0.3408785418830542, 0.4696735927505875, 0.9429414571550971], 
             UndirectedEdge[345, 426] -> 
             RGBColor[
              0.7649497936964772, 0.8167095300211071, 0.9770990522255436], 
             UndirectedEdge[66, 472] -> 
             RGBColor[
              0.29586389462338253`, 0.42648062461240877`, 0.9402270759441249],
              UndirectedEdge[40, 114] -> 
             RGBColor[
              0.443439320562669, 0.5572206362112937, 0.9498318505944043], 
             UndirectedEdge[248, 294] -> 
             RGBColor[
              0.240426199543799, 0.37003355799499527`, 0.9370032884341067], 
             UndirectedEdge[304, 483] -> 
             RGBColor[
              0.3176066092257016, 0.44839817992769826`, 0.941499541548237], 
             UndirectedEdge[9, 425] -> 
             RGBColor[
              0.47524326414852586`, 0.5827457090080587, 0.9524170280286233], 
             UndirectedEdge[290, 384] -> 
             RGBColor[
              0.2851530200769201, 0.4170442822195179, 0.9395504146960666], 
             UndirectedEdge[294, 358] -> 
             RGBColor[
              0.23196947764628847`, 0.36114500709357467`, 0.9365216906326425],
              UndirectedEdge[148, 342] -> 
             RGBColor[
              0.2498214928286487, 0.3799086069333723, 0.9375383364875882], 
             UndirectedEdge[178, 420] -> 
             RGBColor[
              0.9801637329335828, 0.9834819259202605, 0.8627171585529716], 
             UndirectedEdge[193, 354] -> 
             RGBColor[
              0.3247877807995152, 0.4538010668360344, 0.941987036861071], 
             UndirectedEdge[194, 228] -> 
             RGBColor[
              0.9897986964683487, 0.9881510016226367, 0.6807237889593197], 
             UndirectedEdge[326, 491] -> 
             RGBColor[
              0.9346684716417725, 0.7580015966571071, 0.4117209054738351], 
             UndirectedEdge[324, 481] -> 
             RGBColor[
              0.3439470735768655, 0.47233140067487944`, 0.9431369812812307], 
             UndirectedEdge[94, 213] -> 
             RGBColor[
              0.9298124883323949, 0.8120876909328425, 0.6010637208876998], 
             UndirectedEdge[92, 175] -> 
             RGBColor[
              0.7824339265203888, 0.8300343229197356, 0.9610969915433571], 
             UndirectedEdge[254, 401] -> 
             RGBColor[
              0.50497531356463, 0.5944255881948143, 0.9574168801184721], 
             UndirectedEdge[161, 491] -> 
             RGBColor[
              0.992246695040947, 0.9844848921088973, 0.5114139987289448], 
             UndirectedEdge[172, 303] -> 
             RGBColor[
              0.32845548787730483`, 0.4585909264869045, 0.9421616772940785], 
             UndirectedEdge[57, 274] -> 
             RGBColor[
              0.5319886243671207, 0.6309313569324684, 0.9562992397301722], 
             UndirectedEdge[44, 360] -> 
             RGBColor[
              0.5380217860131518, 0.6358293493475512, 0.9567741923151472], 
             UndirectedEdge[170, 238] -> 
             RGBColor[
              0.3084172446419511, 0.44044171708200675`, 0.940913897073925], 
             UndirectedEdge[5, 11] -> 
             RGBColor[
              0.23876273655839006`, 0.3682851529276855, 0.9369085566779607], 
             UndirectedEdge[3, 223] -> 
             RGBColor[
              0.4257649092191724, 0.5429712289379067, 0.9484129706530855], 
             UndirectedEdge[65, 227] -> 
             RGBColor[
              0.9155479974276244, 0.657189157644029, 0.2946818964954864], 
             UndirectedEdge[78, 85] -> 
             RGBColor[
              0.21682232686548605`, 0.34522439123812265`, 0.9356590828038773],
              UndirectedEdge[181, 393] -> 
             RGBColor[
              0.4409543407183537, 0.5561398931308579, 0.9493774176456293], 
             UndirectedEdge[45, 56] -> 
             RGBColor[
              0.5597280401148761, 0.3487238439697099, 0.5610837052268939], 
             UndirectedEdge[141, 310] -> 
             RGBColor[
              0.3031699755874952, 0.4359038694979436, 0.9405792867476138], 
             UndirectedEdge[39, 236] -> 
             RGBColor[
              0.4554923722273556, 0.5623404159424226, 0.9515950359894985], 
             UndirectedEdge[337, 375] -> 
             RGBColor[
              0.9092060692572821, 0.9298599802312014, 0.9710835499900707], 
             UndirectedEdge[57, 334] -> 
             RGBColor[
              0.5020235331688498, 0.6052327745876049, 0.9543192472492019], 
             UndirectedEdge[123, 438] -> 
             RGBColor[
              0.21421403684205725`, 0.34248291304835987`, 0.9355105445456623],
              UndirectedEdge[35, 385] -> 
             RGBColor[
              0.235922007593164, 0.36529936667261376`, 0.936746781365873], 
             UndirectedEdge[268, 285] -> 
             RGBColor[
              0.3620365603618595, 0.4879996049239992, 0.9442896273832655], 
             UndirectedEdge[169, 361] -> 
             RGBColor[
              0.5684718159304661, 0.6605218314458838, 0.9591906270789168], 
             UndirectedEdge[337, 361] -> 
             RGBColor[
              0.752206073850372, 0.8066735064022713, 0.9758502482621753], 
             UndirectedEdge[119, 270] -> 
             RGBColor[
              0.9903352312511376, 0.9902713839961873, 0.8098337599957988], 
             UndirectedEdge[254, 386] -> 
             RGBColor[
              0.20771262472504887`, 0.3356495167000475, 0.935140298743576], 
             UndirectedEdge[253, 488] -> 
             RGBColor[
              0.877198073649208, 0.9039154021300979, 0.937685633244106], 
             UndirectedEdge[340, 380] -> 
             RGBColor[
              0.3051428116901297, 0.43540236706824387`, 0.9407859230744895], 
             UndirectedEdge[388, 490] -> 
             RGBColor[
              0.9683628300119925, 0.9748687448836537, 0.8911081388957877], 
             UndirectedEdge[27, 311] -> 
             RGBColor[
              0.6294878924283578, 0.7084848809709354, 0.9650691972348303], 
             UndirectedEdge[222, 417] -> 
             RGBColor[
              0.5718731828738293, 0.6621247011020224, 0.9601331729684849], 
             UndirectedEdge[274, 361] -> 
             RGBColor[
              0.5534678542610545, 0.6483409394418851, 0.9580094602549781], 
             UndirectedEdge[65, 474] -> 
             RGBColor[
              0.989280991001634, 0.9770225512176633, 0.5810477888330006], 
             UndirectedEdge[243, 326] -> 
             RGBColor[
              0.8572408103331092, 0.41460626615910345`, 0.2014143032349089], 
             UndirectedEdge[47, 437] -> 
             RGBColor[
              0.2438820574631478, 0.37366588378227833`, 0.93720009443013], 
             UndirectedEdge[232, 414] -> 
             RGBColor[
              0.31542779716347613`, 0.44447776538926564`, 0.9414351563383871],
              UndirectedEdge[102, 196] -> 
             RGBColor[
              0.28611844580431445`, 0.41805900587053585`, 0.9396053942630224],
              UndirectedEdge[90, 257] -> 
             RGBColor[
              0.8618116052496472, 0.4654005988057779, 0.20640455492384144`], 
             UndirectedEdge[116, 310] -> 
             RGBColor[
              0.2727415097182925, 0.40399899789739224`, 0.9388435975423268], 
             UndirectedEdge[333, 459] -> 
             RGBColor[
              0.3845976264069504, 0.5075408663801063, 0.9457271985616913], 
             UndirectedEdge[68, 257] -> 
             RGBColor[
              0.8394199460541523, 0.30329924422110266`, 0.18535427265779897`],
              UndirectedEdge[220, 349] -> 
             RGBColor[
              0.3762573378366486, 0.5003169276156031, 0.9451957627490192], 
             UndirectedEdge[92, 204] -> 
             RGBColor[
              0.5555153199743827, 0.6500313882920026, 0.9581513473895016], 
             UndirectedEdge[120, 123] -> 
             RGBColor[
              0.20719251066229882`, 0.33510284384296096`, 0.9351106790171422],
              UndirectedEdge[190, 224] -> 
             RGBColor[
              0.2735379552710175, 0.40483611267087094`, 0.938888953938319], 
             UndirectedEdge[450, 469] -> 
             RGBColor[
              0.8390695807149537, 0.298125435533924, 0.18492162257597716`], 
             UndirectedEdge[405, 434] -> 
             RGBColor[
              0.9926076308918226, 0.9901160572249841, 0.6925776468321798], 
             UndirectedEdge[312, 400] -> 
             RGBColor[
              0.30016668312241634`, 0.43282459400155193`, 0.9404054205957836],
              UndirectedEdge[100, 259] -> 
             RGBColor[
              0.8965277758950481, 0.6152647749950997, 0.2349704456547408], 
             UndirectedEdge[87, 423] -> 
             RGBColor[
              0.18353957668712906`, 0.310242110552426, 0.9337636794186364], 
             UndirectedEdge[403, 449] -> 
             RGBColor[
              0.8286073759188407, 0.8669140710830616, 0.9833178599894938], 
             UndirectedEdge[268, 275] -> 
             RGBColor[
              0.4116793705742366, 0.5309977120097701, 0.9474528233525847], 
             UndirectedEdge[166, 210] -> 
             RGBColor[
              0.8370920629652436, 0.28611142656230293`, 0.18315270742599782`],
              UndirectedEdge[102, 496] -> 
             RGBColor[
              0.27671354998693043`, 0.4081738640616296, 0.9390697993595188], 
             UndirectedEdge[11, 202] -> 
             RGBColor[
              0.2389875961328362, 0.3685214945973489, 0.9369213620980754], 
             UndirectedEdge[187, 494] -> 
             RGBColor[
              0.26156581469201307`, 0.3922526338447824, 0.9382071582435395], 
             UndirectedEdge[158, 282] -> 
             RGBColor[
              0.4825898599888707, 0.5882261104425313, 0.9531290808792493], 
             UndirectedEdge[232, 372] -> 
             RGBColor[
              0.41332534927572523`, 0.5319581186500844, 0.9476862556607386], 
             UndirectedEdge[143, 477] -> 
             RGBColor[
              0.21179931439321417`, 0.33994488665237976`, 0.9353730296744625],
              UndirectedEdge[479, 482] -> 
             RGBColor[
              0.3849860560945393, 0.5078773046524521, 0.9457519489579096], 
             UndirectedEdge[45, 283] -> 
             RGBColor[
              0.23199831546813182`, 0.3611753174727555, 0.9365233329039347], 
             UndirectedEdge[323, 463] -> 
             RGBColor[
              0.25322101360276406`, 0.3834817188090337, 0.9377319341665338], 
             UndirectedEdge[130, 347] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[338, 369] -> 
             RGBColor[
              0.37002637582951403`, 0.49491998150227967`, 0.9447987313597479],
              UndirectedEdge[143, 386] -> 
             RGBColor[
              0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772],
              UndirectedEdge[168, 254] -> 
             RGBColor[
              0.5736452347236608, 0.5249664714796068, 0.591929563801219], 
             UndirectedEdge[86, 115] -> 
             RGBColor[
              0.9181807358610004, 0.8207272885954675, 0.6214818156174652], 
             UndirectedEdge[138, 457] -> 
             RGBColor[
              0.22077773189024535`, 0.349381772706308, 0.9358843372685399], 
             UndirectedEdge[11, 497] -> 
             RGBColor[
              0.2374558873234022, 0.36691157152268605`, 0.9368341335473384], 
             UndirectedEdge[154, 379] -> 
             RGBColor[
              0.3094202014132221, 0.4424259593777846, 0.9409369595178776], 
             UndirectedEdge[17, 467] -> 
             RGBColor[
              0.7934052123801664, 0.8390183037645371, 0.979914209324252], 
             UndirectedEdge[75, 93] -> 
             RGBColor[
              0.30711689507265494`, 0.43678253795558514`, 0.940923781155411], 
             UndirectedEdge[100, 315] -> 
             RGBColor[
              0.5583572344294613, 0.5386495393888345, 0.5986936802267802], 
             UndirectedEdge[45, 52] -> 
             RGBColor[
              0.5592887582023336, 0.3453473306953461, 0.5606630483713451], 
             UndirectedEdge[8, 203] -> 
             RGBColor[
              0.5774301323005686, 0.6678228201894449, 0.9598765616924215], 
             UndirectedEdge[244, 340] -> 
             RGBColor[
              0.33993779537767665`, 0.4688587654109236, 0.9428815136196439], 
             UndirectedEdge[104, 190] -> 
             RGBColor[
              0.24734164292075334`, 0.3773021274486088, 0.9373971127039427], 
             UndirectedEdge[38, 437] -> 
             RGBColor[
              0.2578995688543769, 0.3883991770160148, 0.9379983709668107], 
             UndirectedEdge[96, 465] -> 
             RGBColor[
              0.2893936582907169, 0.42150146185421045`, 0.9397919127688803], 
             UndirectedEdge[48, 346] -> 
             RGBColor[
              0.21269676667826953`, 0.34088816590573434`, 0.9354241382544346],
              UndirectedEdge[153, 342] -> 
             RGBColor[
              0.25246005368067864`, 0.38268190168327626`, 0.9376885986247103],
              UndirectedEdge[151, 327] -> 
             RGBColor[
              0.28193174194509296`, 0.41365851466213766`, 0.939366967671913], 
             UndirectedEdge[375, 489] -> 
             RGBColor[
              0.9741495163492516, 0.9792601983573855, 0.8847051301265769], 
             UndirectedEdge[203, 289] -> 
             RGBColor[
              0.48696884397226536`, 0.5940035787603833, 0.9528597515235682], 
             UndirectedEdge[6, 79] -> 
             RGBColor[
              0.9107592672849488, 0.9273249908421985, 0.7765494419084453], 
             UndirectedEdge[105, 463] -> 
             RGBColor[
              0.2565013158137106, 0.3869295244159112, 0.9379187425246749], 
             UndirectedEdge[10, 125] -> 
             RGBColor[
              0.21381800062875955`, 0.3420666538780378, 0.935487990869198], 
             UndirectedEdge[32, 331] -> 
             RGBColor[
              0.6862012136677067, 0.7532861971667737, 0.9704389262848694], 
             UndirectedEdge[26, 44] -> 
             RGBColor[
              0.4416533932183588, 0.5557823986053863, 0.949688034527277], 
             UndirectedEdge[86, 253] -> 
             RGBColor[
              0.9501124692155603, 0.8447770986590462, 0.5741725699000219], 
             UndirectedEdge[370, 466] -> 
             RGBColor[
              0.5474757553674385, 0.6435045075658272, 0.9575184434137474], 
             UndirectedEdge[301, 456] -> 
             RGBColor[
              0.21620560443164671`, 0.3445761768576967, 0.9356239613736292], 
             UndirectedEdge[21, 337] -> 
             RGBColor[
              0.9205492329643337, 0.9192823831910986, 0.6833909335036439], 
             UndirectedEdge[61, 172] -> 
             RGBColor[
              0.3377395733706075, 0.4669547759942509, 0.9427414448571648], 
             UndirectedEdge[291, 359] -> 
             RGBColor[
              0.5201892016597764, 0.619316785102851, 0.95601113315619], 
             UndirectedEdge[134, 499] -> 
             RGBColor[
              0.2469625122439105, 0.37690363706897373`, 0.93737552177277], 
             UndirectedEdge[140, 244] -> 
             RGBColor[
              0.42103754660959536`, 0.5378457039996745, 0.9483965938455836], 
             UndirectedEdge[108, 364] -> 
             RGBColor[
              0.27183868506633, 0.4030500719457907, 0.938792183014007], 
             UndirectedEdge[113, 421] -> 
             RGBColor[
              0.17912443323835392`, 0.3056015148515002, 0.9335122435308479], 
             UndirectedEdge[54, 55] -> 
             RGBColor[
              0.22009923076516985`, 0.34866862500439766`, 0.9358456976332195],
              UndirectedEdge[56, 210] -> 
             RGBColor[
              0.8363686612775614, 0.28055104419413623`, 0.18245997715290796`],
              UndirectedEdge[36, 58] -> 
             RGBColor[
              0.28475051663686596`, 0.4160326690739975, 0.9395490426575464], 
             UndirectedEdge[25, 288] -> 
             RGBColor[
              0.2847205959795895, 0.4161617683290476, 0.9395414602803146], 
             UndirectedEdge[262, 344] -> 
             RGBColor[
              0.4699143971667351, 0.5805367028791276, 0.9514125291795714], 
             UndirectedEdge[8, 439] -> 
             RGBColor[
              0.7406030565482964, 0.7972768000160912, 0.9749233642591105], 
             UndirectedEdge[102, 186] -> 
             RGBColor[
              0.256123983487738, 0.3865329242170628, 0.9378972540069239], 
             UndirectedEdge[85, 145] -> 
             RGBColor[
              0.21743686076267443`, 0.3458703053277671, 0.9356940796002007], 
             UndirectedEdge[421, 423] -> 
             RGBColor[
              0.18344124862659156`, 0.31013876152644193`, 0.9337580797810521],
              UndirectedEdge[406, 476] -> 
             RGBColor[
              0.9195554041525527, 0.6768776802935997, 0.3060621599750899], 
             UndirectedEdge[111, 400] -> 
             RGBColor[
              0.2845065356159251, 0.4163647860615299, 0.939513598362401], 
             UndirectedEdge[137, 183] -> 
             RGBColor[
              0.2125239415632086, 0.34070651575206007`, 0.9354142961198038], 
             UndirectedEdge[85, 358] -> 
             RGBColor[
              0.2199208837213561, 0.34848117095349374`, 0.935835541032915], 
             UndirectedEdge[399, 412] -> 
             RGBColor[
              0.24194122045751632`, 0.37162594103318614`, 0.9370895666338703],
              UndirectedEdge[283, 292] -> 
             RGBColor[
              0.18009239570445779`, 0.3066189047757405, 0.9335673675613205], 
             UndirectedEdge[240, 310] -> 
             RGBColor[
              0.2766913122921885, 0.4081504908345045, 0.939068532955701], 
             UndirectedEdge[186, 300] -> 
             RGBColor[
              0.23083402862066274`, 0.35995157817601575`, 0.9364570284903794],
              UndirectedEdge[37, 240] -> 
             RGBColor[
              0.28113287624005423`, 0.4128188561551308, 0.9393214734518269], 
             UndirectedEdge[36, 429] -> 
             RGBColor[
              0.2739936283843697, 0.4053150540043482, 0.9389149038480165], 
             UndirectedEdge[56, 276] -> 
             RGBColor[
              0.7281068824339767, 0.4924523185511463, 0.5729718060098814], 
             UndirectedEdge[95, 174] -> 
             RGBColor[
              0.24687001390337449`, 0.3768064154483368, 0.9373702541291156], 
             UndirectedEdge[7, 28] -> 
             RGBColor[
              0.901769090567154, 0.9237583305634441, 0.9644245605513657], 
             UndirectedEdge[251, 367] -> 
             RGBColor[
              0.24419513183599667`, 0.3739949447982042, 0.9372179235525118], 
             UndirectedEdge[31, 314] -> 
             RGBColor[
              0.3915568678230763, 0.5135686115131106, 0.9461706352709112], 
             UndirectedEdge[238, 436] -> 
             RGBColor[
              0.3965368671240651, 0.5173498014044343, 0.9466350145946033], 
             UndirectedEdge[291, 488] -> 
             RGBColor[
              0.7121457205579194, 0.7750529164985673, 0.971943688111231], 
             UndirectedEdge[96, 171] -> 
             RGBColor[
              0.2789519797924134, 0.41052659571183897`, 0.939197274625481], 
             UndirectedEdge[127, 179] -> 
             RGBColor[
              0.20245447418328588`, 0.33012286709465477`, 0.9348408548489592],
              UndirectedEdge[296, 453] -> 
             RGBColor[
              0.2988633264806147, 0.4310225569001501, 0.9403470186360454], 
             UndirectedEdge[14, 494] -> 
             RGBColor[
              0.2826231066390982, 0.4143851827905905, 0.9394063398684542], 
             UndirectedEdge[317, 420] -> 
             RGBColor[
              0.9260215766566631, 0.7697821905786719, 0.5811912001414211], 
             UndirectedEdge[7, 388] -> 
             RGBColor[
              0.8924271040987608, 0.9167910923514154, 0.9802381068620604], 
             UndirectedEdge[146, 271] -> 
             RGBColor[
              0.25686927492861433`, 0.3873162727756304, 0.9379396972519218], 
             UndirectedEdge[331, 449] -> 
             RGBColor[
              0.7824972356635673, 0.8301470968699212, 0.9789198336489376], 
             UndirectedEdge[27, 359] -> 
             RGBColor[
              0.44878508964320496`, 0.5615402381340974, 0.9502583075299758], 
             UndirectedEdge[100, 471] -> 
             RGBColor[
              0.894013717811025, 0.6013444138663678, 0.23277457969666004`], 
             UndirectedEdge[219, 337] -> 
             RGBColor[
              0.6932397997764845, 0.7588302526554731, 0.971188910299956], 
             UndirectedEdge[199, 419] -> 
             RGBColor[
              0.4277672068152066, 0.5433200836247167, 0.948923355062986], 
             UndirectedEdge[266, 437] -> 
             RGBColor[
              0.2726756027922651, 0.40392972553939704`, 0.9388398442403902], 
             UndirectedEdge[327, 399] -> 
             RGBColor[
              0.24928505714751653`, 0.3793447790205158, 0.9375077872691331], 
             UndirectedEdge[311, 419] -> 
             RGBColor[
              0.6297737018777119, 0.70871691395749, 0.9650916972016379], 
             UndirectedEdge[267, 329] -> 
             RGBColor[
              0.9358102453449542, 0.941979730786866, 0.7003355368972839], 
             UndirectedEdge[219, 244] -> 
             RGBColor[
              0.43435496414043395`, 0.548657383494032, 0.949444989736919], 
             UndirectedEdge[17, 205] -> 
             RGBColor[
              0.9368989095333399, 0.9481665884975428, 0.7789256469520753], 
             UndirectedEdge[175, 361] -> 
             RGBColor[
              0.7999658560018515, 0.8442393091304512, 0.9624964661202554], 
             UndirectedEdge[189, 266] -> 
             RGBColor[
              0.2746480537102089, 0.4060028965147674, 0.9389521724021874], 
             UndirectedEdge[225, 280] -> 
             RGBColor[
              0.26557083518380836`, 0.39646216431462483`, 0.9384352382356503],
              UndirectedEdge[300, 458] -> 
             RGBColor[
              0.22822845140871784`, 0.35721295132312475`, 0.9363086447227651],
              UndirectedEdge[171, 343] -> 
             RGBColor[
              0.2773148667291586, 0.40880588608339485`, 0.9391040434584204], 
             UndirectedEdge[358, 408] -> 
             RGBColor[
              0.2240653730927813, 0.35283729205866493`, 0.936071563571395], 
             UndirectedEdge[380, 411] -> 
             RGBColor[
              0.2562205129796168, 0.38663438283335066`, 0.9379027512186837], 
             UndirectedEdge[345, 498] -> 
             RGBColor[
              0.5608073530060538, 0.6540616711594758, 0.9587498403781267], 
             UndirectedEdge[161, 450] -> 
             RGBColor[
              0.9040202207813182, 0.5580851531997648, 0.2907664410126593], 
             UndirectedEdge[94, 214] -> 
             RGBColor[
              0.5776130969249946, 0.6468062636067821, 0.9475190708650497], 
             UndirectedEdge[157, 343] -> 
             RGBColor[
              0.2977155588527831, 0.4302483069839126, 0.9402658326947413], 
             UndirectedEdge[155, 332] -> 
             RGBColor[
              0.4840405870433834, 0.5906167908800439, 0.9529081554374272], 
             UndirectedEdge[127, 168] -> 
             RGBColor[
              0.5683860156508949, 0.5194386987803812, 0.5916300590553423], 
             UndirectedEdge[378, 380] -> 
             RGBColor[
              0.27796774382392075`, 0.40949210130478847`, 0.939141223843122], 
             UndirectedEdge[160, 481] -> 
             RGBColor[
              0.3703492229848604, 0.49519961548147085`, 0.9448193028950042], 
             UndirectedEdge[23, 485] -> 
             RGBColor[
              0.2352513492635514, 0.3645944622459968, 0.9367085883661517], 
             UndirectedEdge[352, 399] -> 
             RGBColor[
              0.23466592421327268`, 0.3639791434000619, 0.936675249275597], 
             UndirectedEdge[389, 456] -> 
             RGBColor[
              0.22107915567658082`, 0.3496985882171184, 0.9359015029072553], 
             UndirectedEdge[105, 263] -> 
             RGBColor[
              0.2596529612026372, 0.3902421035455322, 0.9380982240671327], 
             UndirectedEdge[143, 347] -> 
             RGBColor[
              0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772],
              UndirectedEdge[98, 484] -> 
             RGBColor[
              0.9940632182259341, 0.9897101490230129, 0.5951961253421731], 
             UndirectedEdge[100, 500] -> 
             RGBColor[
              0.8753537574413516, 0.45791578161828494`, 0.21490578057324983`],
              UndirectedEdge[89, 424] -> 
             RGBColor[
              0.3030480744366626, 0.4347576504686087, 0.9406096220363795], 
             UndirectedEdge[231, 442] -> 
             RGBColor[
              0.2711958428958343, 0.40237440406605196`, 0.938755574103397], 
             UndirectedEdge[15, 104] -> 
             RGBColor[
              0.24040623048550225`, 0.3700125692486139, 0.9370021512257783], 
             UndirectedEdge[75, 182] -> 
             RGBColor[
              0.3617675856264607, 0.48776663252726005`, 0.9442724885509708], 
             UndirectedEdge[290, 316] -> 
             RGBColor[
              0.268490139738015, 0.3995305384956953, 0.9386014883112883], 
             UndirectedEdge[344, 424] -> 
             RGBColor[
              0.39216870621134226`, 0.5138154925134429, 0.9462878321282429], 
             UndirectedEdge[369, 425] -> 
             RGBColor[
              0.397645136695217, 0.5188419640048679, 0.9465585743797993], 
             UndirectedEdge[106, 255] -> 
             RGBColor[
              0.45772043203322, 0.569123825312507, 0.9508706958509441], 
             UndirectedEdge[84, 242] -> 
             RGBColor[
              0.22916096004104347`, 0.3581930770201611, 0.9363617497098533], 
             UndirectedEdge[143, 446] -> 
             RGBColor[
              0.20353913733189777`, 0.3312629168354616, 0.9349026248106573], 
             UndirectedEdge[376, 415] -> 
             RGBColor[
              0.28323389332621046`, 0.41502715832485815`, 0.9394411232667073],
              UndirectedEdge[93, 108] -> 
             RGBColor[
              0.27719798724909794`, 0.408683038339264, 0.9390973873449386], 
             UndirectedEdge[78, 183] -> 
             RGBColor[
              0.21219822021020854`, 0.34036416195813046`, 0.935395746770612], 
             UndirectedEdge[17, 298] -> 
             RGBColor[
              0.8908055349705915, 0.9157681695861948, 0.9894470212286257], 
             UndirectedEdge[204, 370] -> 
             RGBColor[
              0.546668194471859, 0.642848893250592, 0.9574548692618543], 
             UndirectedEdge[208, 314] -> 
             RGBColor[
              0.32609699892407057`, 0.4568705631814669, 0.9419995903085558], 
             UndirectedEdge[313, 379] -> 
             RGBColor[
              0.288128547073246, 0.4201206026991259, 0.9397217393007642], 
             UndirectedEdge[3, 221] -> 
             RGBColor[
              0.4991380572062573, 0.6042617866100937, 0.9537131227476765], 
             UndirectedEdge[154, 229] -> 
             RGBColor[
              0.3002585012900294, 0.4328475787158096, 0.940413341505228], 
             UndirectedEdge[25, 180] -> 
             RGBColor[
              0.2917531123703574, 0.42355338894303707`, 0.9399419516850931], 
             UndirectedEdge[371, 419] -> 
             RGBColor[
              0.43781722710861815`, 0.5520249060741627, 0.9495637334691982], 
             UndirectedEdge[31, 419] -> 
             RGBColor[
              0.4828643991449212, 0.5910425023553091, 0.9524340994377012], 
             UndirectedEdge[321, 482] -> 
             RGBColor[
              0.3458284457686297, 0.47396095070686983`, 0.9432568606536578], 
             UndirectedEdge[212, 300] -> 
             RGBColor[
              0.22223694937519295`, 0.35091550280272016`, 0.9359674375455889],
              UndirectedEdge[376, 414] -> 
             RGBColor[
              0.27705653417076703`, 0.40853436218529504`, 0.9390893318013886],
              UndirectedEdge[140, 274] -> 
             RGBColor[
              0.4811841626563286, 0.5896860062007292, 0.9522997264014235], 
             UndirectedEdge[1, 131] -> 
             RGBColor[
              0.26488726968740706`, 0.3957436936373514, 0.9383963101918749], 
             UndirectedEdge[360, 466] -> 
             RGBColor[
              0.5414372478398441, 0.638602175123262, 0.9570430699813932], 
             UndirectedEdge[165, 182] -> 
             RGBColor[
              0.4013099579800705, 0.5220162480025345, 0.9467920935513959], 
             UndirectedEdge[268, 480] -> 
             RGBColor[
              0.3816010072146523, 0.5049453454501976, 0.9455362566365644], 
             UndirectedEdge[54, 385] -> 
             RGBColor[
              0.23109619211781043`, 0.36022712863364376`, 0.9364719583137058],
              UndirectedEdge[149, 158] -> 
             RGBColor[
              0.3556980515257828, 0.48250950715290686`, 0.943885743205154], 
             UndirectedEdge[229, 379] -> 
             RGBColor[
              0.30013749915285226`, 0.43274277274633094`, 0.9404056313560452],
              UndirectedEdge[98, 253] -> 
             RGBColor[
              0.9901332923121124, 0.9901471046097305, 0.8102166844391167], 
             UndirectedEdge[121, 469] -> 
             RGBColor[
              0.8439483097229172, 0.3356254845618147, 0.18959349898373934`], 
             UndirectedEdge[34, 269] -> 
             RGBColor[
              0.4963462045644428, 0.6018763440007352, 0.9535261877805588], 
             UndirectedEdge[145, 286] -> 
             RGBColor[
              0.22187921582518422`, 0.3505395021600439, 0.9359470651491353], 
             UndirectedEdge[34, 234] -> 
             RGBColor[
              0.4661658558479902, 0.5757356428509766, 0.951603122647781], 
             UndirectedEdge[85, 286] -> 
             RGBColor[
              0.21865790979829205`, 0.3471537052831816, 0.935763616536399], 
             UndirectedEdge[86, 261] -> 
             RGBColor[
              0.897589954080166, 0.6247029436909717, 0.23609548573218275`], 
             UndirectedEdge[140, 255] -> 
             RGBColor[
              0.4486097951007969, 0.5617273998212495, 0.950153473138261], 
             UndirectedEdge[345, 448] -> 
             RGBColor[
              0.6138322543981429, 0.6971096748541594, 0.9629241548523259], 
             UndirectedEdge[146, 444] -> 
             RGBColor[
              0.2646131387661169, 0.39545556465817117`, 0.9383806988414477], 
             UndirectedEdge[215, 224] -> 
             RGBColor[
              0.2915446973152564, 0.4237623402527527, 0.9399144112591507], 
             UndirectedEdge[40, 359] -> 
             RGBColor[
              0.38582570994179444`, 0.508604570612715, 0.9458054509585798], 
             UndirectedEdge[88, 495] -> 
             RGBColor[
              0.8544062989949438, 0.4062909143031017, 0.1992274995322182], 
             UndirectedEdge[341, 403] -> 
             RGBColor[
              0.9612426733705868, 0.9674078133042042, 0.7674804702008887], 
             UndirectedEdge[134, 416] -> 
             RGBColor[
              0.24737003573452257`, 0.37733197009608865`, 0.9373987296326833],
              UndirectedEdge[113, 423] -> 
             RGBColor[
              0.1835090760837748, 0.31021005248445066`, 0.9337619424543968], 
             UndirectedEdge[204, 362] -> 
             RGBColor[
              0.4451772959687064, 0.5586930048020928, 0.9499517048675632], 
             UndirectedEdge[231, 256] -> 
             RGBColor[
              0.27391624912615603`, 0.40523372349783726`, 0.9389104972137335],
              UndirectedEdge[183, 407] -> 
             RGBColor[
              0.2096628417623121, 0.3376993184571131, 0.9352513607187605], 
             UndirectedEdge[231, 271] -> 
             RGBColor[
              0.25712583983655113`, 0.38758593876102676`, 0.9379543082438752],
              UndirectedEdge[106, 140] -> 
             RGBColor[
              0.508744701282457, 0.6120608930455363, 0.9544693929596517], 
             UndirectedEdge[96, 147] -> 
             RGBColor[
              0.27382745193814473`, 0.40514039202317054`, 0.9389054403452399],
              UndirectedEdge[149, 275] -> 
             RGBColor[
              0.38378936730216673`, 0.5068407929678266, 0.9456756970062499], 
             UndirectedEdge[207, 287] -> 
             RGBColor[
              0.21343735530821623`, 0.3416665715118395, 0.9354663136813074], 
             UndirectedEdge[223, 480] -> 
             RGBColor[
              0.3717055099769321, 0.496374363105037, 0.9449057243028214], 
             UndirectedEdge[11, 102] -> 
             RGBColor[
              0.2577278443328788, 0.3882186836559568, 0.9379885915093551], 
             UndirectedEdge[230, 339] -> 
             RGBColor[
              0.21778435426976317`, 0.3462355430360783, 0.9357138688413589], 
             UndirectedEdge[103, 449] -> 
             RGBColor[
              0.6043292409167387, 0.6883441793156388, 0.9628942898259707], 
             UndirectedEdge[226, 396] -> 
             RGBColor[
              0.5864855268156967, 0.6472607121015193, 0.7362180745608087], 
             UndirectedEdge[144, 279] -> 
             RGBColor[
              0.2623939933592224, 0.3931231021335797, 0.9382543217934566], 
             UndirectedEdge[205, 228] -> 
             RGBColor[
              0.9934539331599859, 0.9884069498751192, 0.5288792059852668], 
             UndirectedEdge[267, 406] -> 
             RGBColor[
              0.9898404936899885, 0.9773917410301207, 0.415032665757733], 
             UndirectedEdge[209, 233] -> 
             RGBColor[
              0.7045416845554648, 0.49561598240663746`, 0.5739669497124782], 
             UndirectedEdge[387, 405] -> 
             RGBColor[
              0.8845632449194131, 0.9069230619459494, 0.7839577394340637], 
             UndirectedEdge[75, 206] -> 
             RGBColor[
              0.34384133423410757`, 0.4722398145707964, 0.9431302436638118], 
             UndirectedEdge[183, 404] -> 
             RGBColor[
              0.20920782453695042`, 0.33722106650349953`, 0.9352254481609139],
              UndirectedEdge[319, 488] -> 
             RGBColor[
              0.7421269925364968, 0.7984745140343386, 0.9749319411111395], 
             UndirectedEdge[220, 371] -> 
             RGBColor[
              0.3509285621764658, 0.4783784152000333, 0.9435818355613093], 
             UndirectedEdge[66, 460] -> 
             RGBColor[
              0.2558136629427209, 0.38620675764879087`, 0.9378795817109632], 
             UndirectedEdge[87, 446] -> 
             RGBColor[
              0.20370226760912918`, 0.33143437709988877`, 0.934911914838616], 
             UndirectedEdge[273, 308] -> 
             RGBColor[
              0.23624385022904204`, 0.36563764368892326`, 0.9367651098278627],
              UndirectedEdge[326, 428] -> 
             RGBColor[
              0.8527545036662538, 0.3801225472055363, 0.19711821090416948`], 
             UndirectedEdge[130, 315] -> 
             RGBColor[
              0.1822133081343763, 0.30884811821319974`, 0.9336881503865955], 
             UndirectedEdge[95, 407] -> 
             RGBColor[
              0.22072063099008732`, 0.34932175603983573`, 0.9358810854567492],
              UndirectedEdge[148, 153] -> 
             RGBColor[
              0.2422944032111111, 0.37199715850029413`, 0.9371096798692006], 
             UndirectedEdge[85, 137] -> 
             RGBColor[
              0.21714804821848613`, 0.34556674503205226`, 0.9356776321530691],
              UndirectedEdge[289, 359] -> 
             RGBColor[
              0.4124111574915527, 0.5316315490568694, 0.9474994521678624], 
             UndirectedEdge[32, 449] -> 
             RGBColor[
              0.6320067542390264, 0.7108140314884382, 0.9650731650607731], 
             UndirectedEdge[329, 406] -> 
             RGBColor[
              0.9365881325497546, 0.9446037269852596, 0.7033574817962612], 
             UndirectedEdge[168, 213] -> 
             RGBColor[
              0.9074990588325569, 0.6709655443987909, 0.2444294609060539], 
             UndirectedEdge[111, 464] -> 
             RGBColor[
              0.2584790029138965, 0.3890081989508112, 0.9380313688793045], 
             UndirectedEdge[50, 117] -> 
             RGBColor[
              0.41100665014042015`, 0.5304150353819104, 0.9474099582014052], 
             UndirectedEdge[357, 420] -> 
             RGBColor[
              0.937892556639665, 0.822845791169284, 0.5910531975827036], 
             UndirectedEdge[153, 190] -> 
             RGBColor[
              0.24652129125596123`, 0.3764398858356126, 0.9373503948902342], 
             UndirectedEdge[165, 275] -> 
             RGBColor[
              0.41886860868054065`, 0.537224668715837, 0.9479109152475247], 
             UndirectedEdge[152, 301] -> 
             RGBColor[
              0.2063778078751808, 0.33424653955855976`, 0.9350642828986606], 
             UndirectedEdge[208, 349] -> 
             RGBColor[
              0.3678599975315118, 0.49304357350588934`, 0.9446606916502523], 
             UndirectedEdge[5, 23] -> 
             RGBColor[
              0.23055442452635688`, 0.3596576965449768, 0.9364411054508459], 
             UndirectedEdge[56, 227] -> 
             RGBColor[
              0.8411523878247509, 0.31732086267817405`, 0.187040879096943], 
             UndirectedEdge[56, 326] -> 
             RGBColor[
              0.8559245599190561, 0.404488988692082, 0.2001538603519194], 
             UndirectedEdge[155, 181] -> 
             RGBColor[
              0.49329315877378277`, 0.5986309034651389, 0.9534977211263604], 
             UndirectedEdge[148, 323] -> 
             RGBColor[
              0.23950025424315785`, 0.36906033077569844`, 0.9369505572190486],
              UndirectedEdge[177, 438] -> 
             RGBColor[
              0.21508055771107348`, 0.3433936814222922, 0.9355598916272501], 
             UndirectedEdge[53, 90] -> 
             RGBColor[
              0.9206410418975434, 0.7056328015929743, 0.28606405077970154`], 
             UndirectedEdge[30, 217] -> 
             RGBColor[
              0.2938254921740675, 0.42514500116830317`, 0.9400814485951139], 
             UndirectedEdge[43, 290] -> 
             RGBColor[
              0.2898165263474991, 0.4219459229932718, 0.9398159944791369], 
             UndirectedEdge[114, 397] -> 
             RGBColor[
              0.4296132686116584, 0.545245204928905, 0.9489508667899835], 
             UndirectedEdge[227, 320] -> 
             RGBColor[
              0.9171168323829694, 0.670650788557899, 0.5149397016540836], 
             UndirectedEdge[298, 432] -> 
             RGBColor[
              0.9001321413614187, 0.9232049523582542, 0.9903366012721426], 
             UndirectedEdge[42, 85] -> 
             RGBColor[
              0.22334491181980198`, 0.3520800415808806, 0.9360305343677259], 
             UndirectedEdge[329, 413] -> 
             RGBColor[
              0.9281969547806851, 0.9162983140279535, 0.6707593407043844], 
             UndirectedEdge[244, 380] -> 
             RGBColor[
              0.3076460451816098, 0.43757054210239044`, 0.9409454268990441], 
             UndirectedEdge[87, 113] -> 
             RGBColor[
              0.17922276129889142`, 0.3057048638774843, 0.9335178431684322], 
             UndirectedEdge[334, 370] -> 
             RGBColor[
              0.49712370807879736`, 0.6012548758448955, 0.9539335150694623], 
             UndirectedEdge[24, 278] -> 
             RGBColor[
              0.8926678774514412, 0.9169265621366819, 0.9783016146877055], 
             UndirectedEdge[51, 325] -> 
             RGBColor[
              0.17897196058988912`, 0.30544125643063946`, 0.933503560439081], 
             UndirectedEdge[112, 463] -> 
             RGBColor[
              0.2576804433404335, 0.3881688622075002, 0.9379858920929589], 
             UndirectedEdge[308, 421] -> 
             RGBColor[
              0.1790014452743907, 0.3054722467034876, 0.9335052395482446], 
             UndirectedEdge[302, 421] -> 
             RGBColor[
              0.18460298206136966`, 0.31135981702454774`, 0.9338242387815321],
              UndirectedEdge[103, 488] -> 
             RGBColor[
              0.6248600030483947, 0.70438296673246, 0.9649406043243738], 
             UndirectedEdge[225, 424] -> 
             RGBColor[
              0.2974218624617132, 0.42884414496049433`, 0.940289217587641], 
             UndirectedEdge[205, 388] -> 
             RGBColor[
              0.9699993320336204, 0.9742898944709728, 0.7727192137216462], 
             UndirectedEdge[114, 297] -> 
             RGBColor[
              0.5100213466264654, 0.6130973312480197, 0.954569895157638], 
             UndirectedEdge[203, 381] -> 
             RGBColor[
              0.5519357188644908, 0.6471253068518, 0.9578695480776199], 
             UndirectedEdge[17, 252] -> 
             RGBColor[
              0.8078836333626171, 0.8503289562761027, 0.9813572830192461], 
             UndirectedEdge[361, 363] -> 
             RGBColor[
              0.5245064025228867, 0.6235116591529769, 0.9560934187929221], 
             UndirectedEdge[318, 383] -> 
             RGBColor[
              0.3354424216880899, 0.46496509866505487`, 0.9425950723832464], 
             UndirectedEdge[209, 273] -> 
             RGBColor[
              0.4297324939516893, 0.5421711471050089, 0.9494994222745707], 
             UndirectedEdge[47, 230] -> 
             RGBColor[
              0.22790583767600858`, 0.3568738638351552, 0.9362902723479516], 
             UndirectedEdge[1, 170] -> 
             RGBColor[
              0.2814230291570491, 0.41312382526764985`, 0.939337997231207], 
             UndirectedEdge[139, 247] -> 
             RGBColor[
              0.529523280699882, 0.6289298798809373, 0.9561051588458358], 
             UndirectedEdge[246, 288] -> 
             RGBColor[
              0.2751436592994766, 0.40652380941229693`, 0.9389803964073136], 
             UndirectedEdge[1, 147] -> 
             RGBColor[
              0.2588293294875211, 0.38937641439167825`, 0.9380513194594108], 
             UndirectedEdge[352, 457] -> 
             RGBColor[
              0.22470998276050042`, 0.3535148176900512, 0.9361082731383572], 
             UndirectedEdge[157, 238] -> 
             RGBColor[
              0.31134876495031627`, 0.4435229307952213, 0.9410808428186908], 
             UndirectedEdge[97, 145] -> 
             RGBColor[
              0.2261963371710197, 0.3550770704158197, 0.9361929188231719], 
             UndirectedEdge[83, 237] -> 
             RGBColor[
              0.913419047498675, 0.933799570648643, 0.9916039182408752], 
             UndirectedEdge[73, 494] -> 
             RGBColor[
              0.25320700081228975`, 0.383466990477783, 0.9377311361588463], 
             UndirectedEdge[101, 197] -> 
             RGBColor[
              0.6092291752169602, 0.6927921015850171, 0.9629587335694303], 
             UndirectedEdge[224, 356] -> 
             RGBColor[
              0.28415211148803254`, 0.41599226383132715`, 0.939493414432641], 
             UndirectedEdge[182, 441] -> 
             RGBColor[
              0.41435953118072005`, 0.5333191324183171, 0.9476236008164568], 
             UndirectedEdge[160, 480] -> 
             RGBColor[
              0.3880144919727734, 0.5105003835965654, 0.94594491821413], 
             UndirectedEdge[263, 440] -> 
             RGBColor[
              0.2775372454156354, 0.40903962018250506`, 0.9391167075956355], 
             UndirectedEdge[31, 223] -> 
             RGBColor[
              0.42145102378698707`, 0.5394614268850837, 0.9480754644545675], 
             UndirectedEdge[5, 102] -> 
             RGBColor[
              0.2575724490549457, 0.3880553533662194, 0.9379797419781635], 
             UndirectedEdge[171, 216] -> 
             RGBColor[
              0.26381410331866717`, 0.39461572774112796`, 0.9383351949547825],
              UndirectedEdge[102, 414] -> 
             RGBColor[
              0.27559776236137046`, 0.40700110052214455`, 0.9390062569049031],
              UndirectedEdge[68, 205] -> 
             RGBColor[
              0.9069065109079608, 0.5719171126049378, 0.3681050087560027], 
             UndirectedEdge[111, 376] -> 
             RGBColor[
              0.2762731715166523, 0.4077109983677596, 0.9390447204571181], 
             UndirectedEdge[302, 325] -> 
             RGBColor[
              0.18458313935535953`, 0.31133896108243087`, 0.9338231087687794],
              UndirectedEdge[39, 315] -> 
             RGBColor[
              0.40458060190845924`, 0.5088289173445842, 0.948695685987052], 
             UndirectedEdge[66, 314] -> 
             RGBColor[
              0.29667827269945046`, 0.4271859979700665, 0.9402789673950056], 
             UndirectedEdge[274, 370] -> 
             RGBColor[
              0.5270887992770681, 0.6269534581897589, 0.9559135075504326], 
             UndirectedEdge[94, 477] -> 
             RGBColor[
              0.6000453532177727, 0.6703839872576882, 0.948796554675374], 
             UndirectedEdge[99, 329] -> 
             RGBColor[
              0.9380897089070905, 0.9489785735157732, 0.7678909167681753], 
             UndirectedEdge[25, 465] -> 
             RGBColor[
              0.2980004320712376, 0.430119718051609, 0.9402977272999771], 
             UndirectedEdge[223, 381] -> 
             RGBColor[
              0.47958429341648956`, 0.5866642295649169, 0.9526498297239985], 
             UndirectedEdge[196, 318] -> 
             RGBColor[
              0.3188208288656592, 0.44936205704600285`, 0.9415801260303202], 
             UndirectedEdge[76, 462] -> 
             RGBColor[
              0.4376018334802528, 0.5531637078002476, 0.949183806517649], 
             UndirectedEdge[89, 440] -> 
             RGBColor[
              0.2835877779164691, 0.415399113466799, 0.9394612764705972], 
             UndirectedEdge[88, 326] -> 
             RGBColor[
              0.8708928189630238, 0.5066362693068722, 0.21398214224720047`], 
             UndirectedEdge[149, 282] -> 
             RGBColor[
              0.48076658116172494`, 0.586646877963116, 0.9530129031646457], 
             UndirectedEdge[238, 462] -> 
             RGBColor[
              0.392016142899485, 0.5136796738226148, 0.9462791266236859], 
             UndirectedEdge[168, 261] -> 
             RGBColor[
              0.8953895182633258, 0.6159789489289689, 0.23432496342308617`], 
             UndirectedEdge[155, 344] -> 
             RGBColor[
              0.5148160505883743, 0.6169898879232494, 0.9549473518170989], 
             UndirectedEdge[4, 496] -> 
             RGBColor[
              0.3005965950412318, 0.4318380479282125, 0.9404825707076422], 
             UndirectedEdge[87, 226] -> 
             RGBColor[
              0.17933912709972993`, 0.30582717171218354`, 0.9335244700286423],
              UndirectedEdge[128, 362] -> 
             RGBColor[
              0.4416023765346493, 0.55579072415724, 0.9496702741143528], 
             UndirectedEdge[295, 389] -> 
             RGBColor[
              0.22404383278435813`, 0.3528146518287777, 0.9360703368826964], 
             UndirectedEdge[89, 133] -> 
             RGBColor[
              0.3153376912434113, 0.4454022988525135, 0.9413927055520241], 
             UndirectedEdge[33, 164] -> 
             RGBColor[
              0.8479694807729221, 0.33824875648589925`, 0.19233659900141542`],
              UndirectedEdge[276, 396] -> 
             RGBColor[
              0.8065431088390325, 0.8453068187334528, 0.7510492031181083], 
             UndirectedEdge[50, 274] -> 
             RGBColor[
              0.4518361438965558, 0.5655238171616463, 0.9500822208063486], 
             UndirectedEdge[21, 375] -> 
             RGBColor[
              0.9695446020803578, 0.9577696846543478, 0.6679456249234423], 
             UndirectedEdge[41, 485] -> 
             RGBColor[
              0.24026393309017596`, 0.36986300566395003`, 0.9369940475996247],
              UndirectedEdge[30, 316] -> 
             RGBColor[
              0.25921313179459604`, 0.3897798149508858, 0.938073176433014], 
             UndirectedEdge[285, 324] -> 
             RGBColor[
              0.3420478957119857, 0.4706864282637755, 0.9430159673470576], 
             UndirectedEdge[95, 358] -> 
             RGBColor[
              0.2263545662938538, 0.3552433792562242, 0.9362019297376383], 
             UndirectedEdge[333, 492] -> 
             RGBColor[
              0.32763422405457243`, 0.45523169861929097`, 0.9422062993288807],
              UndirectedEdge[332, 393] -> 
             RGBColor[
              0.4317017689879543, 0.548125780545763, 0.9487878519566961], 
             UndirectedEdge[418, 420] -> 
             RGBColor[
              0.9735581601714495, 0.9798002996671817, 0.9296433170801228], 
             UndirectedEdge[107, 273] -> 
             RGBColor[
              0.2391065540897807, 0.3686465269524677, 0.9369281365777409], 
             UndirectedEdge[310, 483] -> 
             RGBColor[
              0.2967031212326041, 0.4291841708528518, 0.9402081758700394], 
             UndirectedEdge[155, 403] -> 
             RGBColor[
              0.7474005481861847, 0.8023032590432388, 0.9760248292713649], 
             UndirectedEdge[140, 169] -> 
             RGBColor[
              0.4961881243257401, 0.601866898204728, 0.953480893225362], 
             UndirectedEdge[147, 216] -> 
             RGBColor[
              0.2586895754643985, 0.38922952405245953`, 0.9380433606745415], 
             UndirectedEdge[70, 171] -> 
             RGBColor[
              0.25999619432080096`, 0.39060286331495886`, 0.9381177706854442],
              UndirectedEdge[7, 402] -> 
             RGBColor[
              0.6954966701641224, 0.7608182646923372, 0.971187276045136], 
             UndirectedEdge[185, 409] -> 
             RGBColor[
              0.262750205623448, 0.39349750380844273`, 0.9382746075549353], 
             UndirectedEdge[126, 481] -> 
             RGBColor[
              0.28467725623571494`, 0.41566859359098884`, 0.9395553817772139],
              UndirectedEdge[115, 311] -> 
             RGBColor[
              0.8340126241816578, 0.871074103507641, 0.9838732137113628], 
             UndirectedEdge[383, 496] -> 
             RGBColor[
              0.30291603178424115`, 0.4338470274567268, 0.9406303631659094], 
             UndirectedEdge[8, 297] -> 
             RGBColor[
              0.5698289191235334, 0.6616518129015765, 0.9592781663469641], 
             UndirectedEdge[381, 439] -> 
             RGBColor[
              0.7151086431122187, 0.7765792866784462, 0.9729163506443089], 
             UndirectedEdge[16, 276] -> 
             RGBColor[
              0.5117111188744836, 0.6131268633886855, 0.9550738020104051], 
             UndirectedEdge[74, 342] -> 
             RGBColor[
              0.27086057814160247`, 0.4020220195523411, 0.9387364812716233], 
             UndirectedEdge[26, 269] -> 
             RGBColor[
              0.4177844388725415, 0.5362856153201071, 0.9478418329060527], 
             UndirectedEdge[127, 315] -> 
             RGBColor[
              0.20573971378665917`, 0.3335758622140216, 0.9350279443842948], 
             UndirectedEdge[175, 348] -> 
             RGBColor[
              0.9578209370783626, 0.9214694359811255, 0.6292929486935749], 
             UndirectedEdge[180, 288] -> 
             RGBColor[
              0.2630984263915931, 0.39386350591423513`, 0.9382944382125347], 
             UndirectedEdge[288, 343] -> 
             RGBColor[
              0.274476709135814, 0.40582280250320485`, 0.9389424145821572], 
             UndirectedEdge[484, 500] -> 
             RGBColor[
              0.9061921804601966, 0.5690195539734165, 0.316991474169404], 
             UndirectedEdge[59, 323] -> 
             RGBColor[
              0.24076788547771533`, 0.3703926915756808, 0.9370227469425643], 
             UndirectedEdge[108, 189] -> 
             RGBColor[
              0.27244302962866296`, 0.40368527639846097`, 0.9388265995427842],
              UndirectedEdge[59, 74] -> 
             RGBColor[
              0.26196255890659237`, 0.3926696371693413, 0.9382297522396293], 
             UndirectedEdge[40, 199] -> 
             RGBColor[
              0.3645220176644419, 0.4901523831167798, 0.9444479985247825], 
             UndirectedEdge[69, 241] -> 
             RGBColor[
              0.8074723242442312, 0.8502460052781141, 0.9812530323476005], 
             UndirectedEdge[275, 353] -> 
             RGBColor[
              0.5266832510882068, 0.6255486018899017, 0.9561787766673014], 
             UndirectedEdge[196, 335] -> 
             RGBColor[
              0.2862357534512077, 0.4181823036451551, 0.9396120747599719], 
             UndirectedEdge[157, 281] -> 
             RGBColor[
              0.2737261355645935, 0.4050339020907391, 0.9388996705276503], 
             UndirectedEdge[120, 438] -> 
             RGBColor[
              0.21444303080234048`, 0.3427236002196732, 0.9355235854129342], 
             UndirectedEdge[152, 389] -> 
             RGBColor[
              0.21125135912011495`, 0.33936895091798147`, 0.9353418244322866],
              UndirectedEdge[126, 144] -> 
             RGBColor[
              0.24868278916139275`, 0.37871175718110384`, 0.937473488998299], 
             UndirectedEdge[96, 157] -> 
             RGBColor[
              0.29935267191603787`, 0.43196901661235676`, 0.940359063861802], 
             UndirectedEdge[303, 366] -> 
             RGBColor[
              0.2851324087513453, 0.4170226184095053, 0.9395492409115669], 
             UndirectedEdge[119, 309] -> 
             RGBColor[
              0.9918390696706652, 0.9889511495464178, 0.6437403499501158], 
             UndirectedEdge[325, 386] -> 
             RGBColor[
              0.1789719601845752, 0.3054412560046289, 0.9335035604159989], 
             UndirectedEdge[27, 220] -> 
             RGBColor[
              0.4255160611016982, 0.5413857751468245, 0.948775625607305], 
             UndirectedEdge[95, 346] -> 
             RGBColor[
              0.22248278830370904`, 0.3511738951036789, 0.9359814377088818], 
             UndirectedEdge[235, 239] -> 
             RGBColor[
              0.35398612023304477`, 0.4810267183113057, 0.943776660456982], 
             UndirectedEdge[64, 303] -> 
             RGBColor[
              0.29654648477504475`, 0.4290195360046319, 0.9401992556555043], 
             UndirectedEdge[310, 429] -> 
             RGBColor[
              0.2951775190785565, 0.4275806662601843, 0.9401212950842925], 
             UndirectedEdge[67, 238] -> 
             RGBColor[
              0.28838849579729153`, 0.41939023215024707`, 0.9397732894571003],
              UndirectedEdge[38, 108] -> 
             RGBColor[
              0.272539685244709, 0.40378686757924537`, 0.9388321039371288], 
             UndirectedEdge[20, 490] -> 
             RGBColor[
              0.9375437932423437, 0.7794697399272263, 0.5157901036631747], 
             UndirectedEdge[112, 148] -> 
             RGBColor[
              0.2439596839808273, 0.373747474174165, 0.9372045151454738], 
             UndirectedEdge[76, 402] -> 
             RGBColor[
              0.4818182674522101, 0.589060600826333, 0.952664686170056], 
             UndirectedEdge[99, 406] -> 
             RGBColor[
              0.992119957252125, 0.9843905837590278, 0.48258804562862445`], 
             UndirectedEdge[8, 258] -> 
             RGBColor[
              0.4968580357130886, 0.6002414107444907, 0.9541330294430466], 
             UndirectedEdge[15, 153] -> 
             RGBColor[
              0.23958587882071014`, 0.3691503276356177, 0.93695543341207], 
             UndirectedEdge[195, 463] -> 
             RGBColor[
              0.2686246431474216, 0.3996719101069903, 0.9386091480814742], 
             UndirectedEdge[184, 249] -> 
             RGBColor[
              0.2732898707787555, 0.40457536014003825`, 0.9388748258934928], 
             UndirectedEdge[109, 185] -> 
             RGBColor[
              0.26895237692670115`, 0.40001637908853493`, 0.9386278120353654],
              UndirectedEdge[77, 81] -> 
             RGBColor[
              0.7152180111578499, 0.7769379420233913, 0.972614350327299], 
             UndirectedEdge[355, 384] -> 
             RGBColor[
              0.3062638013444511, 0.43738753923394075`, 0.9408202157153518], 
             UndirectedEdge[67, 343] -> 
             RGBColor[
              0.2747552896997584, 0.40611560833893834`, 0.9389582793331509], 
             UndirectedEdge[247, 255] -> 
             RGBColor[
              0.4462984536881862, 0.5598509487377481, 0.9499715158755377], 
             UndirectedEdge[95, 145] -> 
             RGBColor[
              0.22387054333517215`, 0.3526325136304976, 0.9360604683049241], 
             UndirectedEdge[220, 416] -> 
             RGBColor[
              0.3002234451567067, 0.4300950902197503, 0.9405107780769688], 
             UndirectedEdge[287, 451] -> 
             RGBColor[
              0.21062876698303812`, 0.3387145671072923, 0.9353063687311225], 
             UndirectedEdge[387, 491] -> 
             RGBColor[
              0.8846376192086578, 0.9070821410302499, 0.7920529218334498], 
             UndirectedEdge[211, 464] -> 
             RGBColor[
              0.23745358448324252`, 0.36690915109166977`, 0.936834002403998], 
             UndirectedEdge[335, 482] -> 
             RGBColor[
              0.3176268052914761, 0.44657790833086347`, 0.9415681179813948], 
             UndirectedEdge[214, 423] -> 
             RGBColor[
              0.19381650316255092`, 0.32104381187286724`, 0.9343489351780614],
              UndirectedEdge[69, 194] -> 
             RGBColor[
              0.9479892988678673, 0.9596684021789683, 0.9321766809000795], 
             UndirectedEdge[111, 312] -> 
             RGBColor[
              0.28875139009156847`, 0.4208263972547496, 0.9397553365450895], 
             UndirectedEdge[174, 294] -> 
             RGBColor[
              0.2524849252558091, 0.3827080432856873, 0.9376900150241196], 
             UndirectedEdge[212, 295] -> 
             RGBColor[
              0.22405206726645135`, 0.35282330679155405`, 0.9360708058242697],
              UndirectedEdge[193, 414] -> 
             RGBColor[
              0.28123484292780576`, 0.41292602960901903`, 0.9393272803038482],
              UndirectedEdge[320, 348] -> 
             RGBColor[
              0.9742570536765062, 0.9329947209284535, 0.5686571215977747], 
             UndirectedEdge[247, 468] -> 
             RGBColor[
              0.48669420259584584`, 0.5941593048480999, 0.9527334969294036], 
             UndirectedEdge[449, 488] -> 
             RGBColor[
              0.7488335383665432, 0.8037137186084069, 0.9756003869232444], 
             UndirectedEdge[290, 355] -> 
             RGBColor[
              0.30759602149261944`, 0.4387877870773017, 0.9408960836819469], 
             UndirectedEdge[88, 469] -> 
             RGBColor[
              0.8635204022958338, 0.47315984709282155`, 0.20783041706562805`],
              UndirectedEdge[6, 278] -> 
             RGBColor[
              0.8880267801577246, 0.9132258771339024, 0.9778589426846744], 
             UndirectedEdge[24, 448] -> 
             RGBColor[
              0.7024556642269519, 0.7664802639694746, 0.97172087084446], 
             UndirectedEdge[204, 274] -> 
             RGBColor[
              0.4823136561574142, 0.5906029799080129, 0.9523886442672999], 
             UndirectedEdge[81, 99] -> 
             RGBColor[
              0.9086198401868935, 0.9254801001365643, 0.7650800543815806], 
             UndirectedEdge[213, 368] -> 
             RGBColor[
              0.6561537738248766, 0.5929010247462924, 0.5945021229284573], 
             UndirectedEdge[167, 474] -> 
             RGBColor[
              0.9898837045140847, 0.9900846660867081, 0.8173167265425048], 
             UndirectedEdge[78, 430] -> 
             RGBColor[
              0.22958406238534357`, 0.3586377844102586, 0.9363858447624374], 
             UndirectedEdge[110, 316] -> 
             RGBColor[
              0.26110517012024004`, 0.39176846719329617`, 0.9381809252166395],
              UndirectedEdge[153, 463] -> 
             RGBColor[
              0.25601516257071727`, 0.38641854653362934`, 0.9378910568166856],
              UndirectedEdge[471, 475] -> 
             RGBColor[
              0.847907987036376, 0.36924735854117574`, 0.19351004853135326`], 
             UndirectedEdge[79, 486] -> 
             RGBColor[
              0.9643781566417168, 0.9700792377693064, 0.7816636594414414], 
             UndirectedEdge[49, 402] -> 
             RGBColor[
              0.521262974366249, 0.6222237910767345, 0.9554548772727531], 
             UndirectedEdge[340, 498] -> 
             RGBColor[
              0.39966203669691347`, 0.5203561647804322, 0.9467513952897255], 
             UndirectedEdge[248, 313] -> 
             RGBColor[
              0.254748775686199, 0.38508749362443473`, 0.9378189379570638], 
             UndirectedEdge[37, 429] -> 
             RGBColor[
              0.29961908302642226`, 0.4322490315808106, 0.9403742355804184], 
             UndirectedEdge[18, 166] -> 
             RGBColor[
              0.8612521660936727, 0.43095598829613885`, 0.2046884517082866], 
             UndirectedEdge[147, 238] -> 
             RGBColor[
              0.2858235449724231, 0.4166943062060351, 0.9396272193021288], 
             UndirectedEdge[165, 441] -> 
             RGBColor[
              0.4370828286560343, 0.553000910585295, 0.9490715092381609], 
             UndirectedEdge[13, 154] -> 
             RGBColor[
              0.3030787322552839, 0.435811820273263, 0.9405739494865415], 
             UndirectedEdge[133, 249] -> 
             RGBColor[
              0.3173607671926588, 0.44752867994559636`, 0.9415079167344612], 
             UndirectedEdge[84, 385] -> 
             RGBColor[
              0.2333929402174702, 0.3626411565086264, 0.9366027547202471], 
             UndirectedEdge[125, 438] -> 
             RGBColor[
              0.2150690714922951, 0.34338160867808776`, 0.9355592375040829], 
             UndirectedEdge[21, 489] -> 
             RGBColor[
              0.9854926800563032, 0.9686826013172827, 0.5970125136401502], 
             UndirectedEdge[16, 200] -> 
             RGBColor[
              0.6523550443789783, 0.5834045301394526, 0.5929583920999518], 
             UndirectedEdge[402, 436] -> 
             RGBColor[
              0.5126155235296384, 0.6152034009243532, 0.954774118266239], 
             UndirectedEdge[127, 401] -> 
             RGBColor[
              0.499716094491864, 0.5888978154955886, 0.9571173753725956], 
             UndirectedEdge[195, 395] -> 
             RGBColor[
              0.26756974901772024`, 0.3985631494925233, 0.9385490734213637], 
             UndirectedEdge[27, 297] -> 
             RGBColor[
              0.5157415629468824, 0.6177412605497428, 0.9550202115402241], 
             UndirectedEdge[35, 70] -> 
             RGBColor[
              0.24831129577393707`, 0.37832129407684667`, 0.9374523329994586],
              UndirectedEdge[240, 367] -> 
             RGBColor[
              0.24323530728920995`, 0.3729861083431402, 0.9371632629645055], 
             UndirectedEdge[121, 471] -> 
             RGBColor[
              0.842139262249025, 0.3249064119542755, 0.18798591116014318`], 
             UndirectedEdge[184, 424] -> 
             RGBColor[
              0.28881315240835653`, 0.41979584487067384`, 0.9397989642855475],
              UndirectedEdge[122, 159] -> 
             RGBColor[
              0.8441272348319537, 0.3258751275198433, 0.1893291851678579], 
             UndirectedEdge[158, 324] -> 
             RGBColor[
              0.3635993901479788, 0.48935324953462667`, 0.9443892095152808], 
             UndirectedEdge[180, 465] -> 
             RGBColor[
              0.27637826248324115`, 0.40782145563679656`, 0.9390507052321971],
              UndirectedEdge[254, 454] -> 
             RGBColor[
              0.568190337821955, 0.5020881692235942, 0.5874756893040098], 
             UndirectedEdge[297, 314] -> 
             RGBColor[
              0.42471984107439154`, 0.540499402694099, 0.9487792473402418], 
             UndirectedEdge[262, 393] -> 
             RGBColor[
              0.46864864929250694`, 0.5795091117335374, 0.951312884870325], 
             UndirectedEdge[201, 333] -> 
             RGBColor[
              0.34155395478950024`, 0.4698622181836031, 0.9429990074018386], 
             UndirectedEdge[219, 340] -> 
             RGBColor[
              0.43185173064895377`, 0.5464892084598855, 0.9492854859123644], 
             UndirectedEdge[361, 370] -> 
             RGBColor[
              0.6178223925754994, 0.7005868527844641, 0.9630756852495326], 
             UndirectedEdge[48, 358] -> 
             RGBColor[
              0.2165685446684143, 0.3449576500582796, 0.9356446302831911], 
             UndirectedEdge[287, 299] -> 
             RGBColor[
              0.2094890463187735, 0.33751664842668644`, 0.9352414633253583], 
             UndirectedEdge[62, 233] -> 
             RGBColor[
              0.8302393984490122, 0.2334388442338099, 0.17659058814627704`], 
             UndirectedEdge[61, 91] -> 
             RGBColor[
              0.32572776888358806`, 0.4565507546784424, 0.9419760632968737], 
             UndirectedEdge[204, 340] -> 
             RGBColor[
              0.4196638066192008, 0.5365945026728116, 0.9483260078869054], 
             UndirectedEdge[258, 373] -> 
             RGBColor[
              0.3335189671806654, 0.461900180189882, 0.9425237328349862], 
             UndirectedEdge[167, 210] -> 
             RGBColor[
              0.9113669843928855, 0.6334814540290358, 0.5263699322609554], 
             UndirectedEdge[275, 481] -> 
             RGBColor[
              0.36596032955819924`, 0.49139817658749463`, 0.9445396464868034],
              UndirectedEdge[253, 277] -> 
             RGBColor[
              0.8781666893011308, 0.9046720920391318, 0.9377821758000617], 
             UndirectedEdge[193, 485] -> 
             RGBColor[
              0.2679064543585755, 0.3989170481541139, 0.9385682482924145], 
             UndirectedEdge[89, 260] -> 
             RGBColor[
              0.2855390731059485, 0.4174500484302025, 0.9395723998449554], 
             UndirectedEdge[359, 397] -> 
             RGBColor[
              0.3719996579907838, 0.4966291393303264, 0.9449244671541592], 
             UndirectedEdge[1, 171] -> 
             RGBColor[
              0.2639538573417897, 0.3947626180803467, 0.9383431537396518], 
             UndirectedEdge[193, 330] -> 
             RGBColor[
              0.2971306356015508, 0.42963351556059126`, 0.9402325221809], 
             UndirectedEdge[92, 320] -> 
             RGBColor[
              0.7988700431185324, 0.8415596078670635, 0.9004611644475569], 
             UndirectedEdge[126, 279] -> 
             RGBColor[
              0.26484901945855754`, 0.3957034902216259, 0.9383941318979281], 
             UndirectedEdge[93, 163] -> 
             RGBColor[
              0.26813879509029465`, 0.39916125299440397`, 0.9385814797533685],
              UndirectedEdge[31, 297] -> 
             RGBColor[
              0.48620123605795307`, 0.5937514968840982, 0.9526967874627315], 
             UndirectedEdge[127, 325] -> 
             RGBColor[
              0.20249836583685807`, 0.33016900000545074`, 0.9348433544136983],
              UndirectedEdge[334, 498] -> 
             RGBColor[
              0.4323467950368561, 0.5486660596707702, 0.9488340391891498], 
             UndirectedEdge[41, 300] -> 
             RGBColor[
              0.22924216126039493`, 0.3582784246501542, 0.9363663739991688], 
             UndirectedEdge[330, 496] -> 
             RGBColor[
              0.2916695481926115, 0.42389356644085574`, 0.9399215213319159], 
             UndirectedEdge[18, 227] -> 
             RGBColor[
              0.8650075437066738, 0.45982146624662823`, 0.2082846055515888], 
             UndirectedEdge[156, 350] -> 
             RGBColor[
              0.41473957912155346`, 0.5332684178987681, 0.9477527826875395], 
             UndirectedEdge[315, 386] -> 
             RGBColor[
              0.1822133081343763, 0.30884811821319974`, 0.9336881503865955], 
             UndirectedEdge[29, 479] -> 
             RGBColor[
              0.410555492074131, 0.5300242649407545, 0.9473812108083647], 
             UndirectedEdge[277, 488] -> 
             RGBColor[
              0.7703329161501223, 0.8205091959342619, 0.9777432439776033], 
             UndirectedEdge[242, 374] -> 
             RGBColor[
              0.2383689744042093, 0.367871283937679, 0.936886132505799], 
             UndirectedEdge[244, 363] -> 
             RGBColor[
              0.37362619317772217`, 0.49803796235721676`, 0.9450281085379824],
              UndirectedEdge[335, 409] -> 
             RGBColor[
              0.25916391695491414`, 0.389728087033979, 0.938070373720701], 
             UndirectedEdge[235, 332] -> 
             RGBColor[
              0.37961688858367837`, 0.50322680161675, 0.9454098303518859], 
             UndirectedEdge[249, 440] -> 
             RGBColor[
              0.2856108538657166, 0.41752549455988186`, 0.9395764876530341], 
             UndirectedEdge[96, 265] -> 
             RGBColor[
              0.3085881199169248, 0.4405417508695841, 0.9409265415042412], 
             UndirectedEdge[39, 200] -> 
             RGBColor[
              0.7622447974505207, 0.6739602832535388, 0.6012384342096092], 
             UndirectedEdge[146, 312] -> 
             RGBColor[
              0.28117238396624933`, 0.41286038128029634`, 0.9393237233583873],
              UndirectedEdge[237, 448] -> 
             RGBColor[
              0.7370158535300309, 0.7940376208084021, 0.9750172525524329], 
             UndirectedEdge[31, 162] -> 
             RGBColor[
              0.4575348398128734, 0.5704788250059085, 0.9504400637418493], 
             UndirectedEdge[41, 102] -> 
             RGBColor[
              0.2545321161274702, 0.38485977069120125`, 0.9378065995157133], 
             UndirectedEdge[266, 374] -> 
             RGBColor[
              0.27062553266643685`, 0.40177497185519817`, 0.9387230957795312],
              UndirectedEdge[44, 139] -> 
             RGBColor[
              0.5303562146824653, 0.6296060932112468, 0.9561707304600824], 
             UndirectedEdge[47, 189] -> 
             RGBColor[
              0.24585450838109163`, 0.3757390547576487, 0.9373124225919274], 
             UndirectedEdge[208, 359] -> 
             RGBColor[
              0.3537848938552699, 0.480852426136809, 0.9437638384901277], 
             UndirectedEdge[122, 413] -> 
             RGBColor[
              0.9206701650068785, 0.7073273642826143, 0.2820065056616069], 
             UndirectedEdge[36, 141] -> 
             RGBColor[
              0.28198608489330845`, 0.4136382572421074, 0.9393728955113378], 
             UndirectedEdge[179, 347] -> 
             RGBColor[
              0.17892806853100302`, 0.30539512309383293`, 0.93350106085126], 
             UndirectedEdge[226, 422] -> 
             RGBColor[
              0.20671849831186667`, 0.3346046268085379, 0.9350836847150235], 
             UndirectedEdge[18, 167] -> 
             RGBColor[
              0.9355270875213144, 0.7783260157628717, 0.5479056765432442], 
             UndirectedEdge[112, 452] -> 
             RGBColor[
              0.2361084750925497, 0.3654953558371904, 0.936757400414109], 
             UndirectedEdge[323, 342] -> 
             RGBColor[
              0.2496659047127254, 0.3797450739586806, 0.9375294759745583], 
             UndirectedEdge[74, 82] -> 
             RGBColor[
              0.27000631808527487`, 0.401124138069925, 0.93868783242518], 
             UndirectedEdge[291, 349] -> 
             RGBColor[
              0.5342643053360183, 0.6315079324719315, 0.9569079863163146], 
             UndirectedEdge[86, 136] -> 
             RGBColor[
              0.942076876818933, 0.8389236960734718, 0.594023128493258], 
             UndirectedEdge[11, 23] -> 
             RGBColor[
              0.23070981980428998`, 0.3598210268347142, 0.9364499549820375], 
             UndirectedEdge[249, 470] -> 
             RGBColor[
              0.27251498804399493`, 0.40376090925540187`, 0.9388306974680845],
              UndirectedEdge[35, 135] -> 
             RGBColor[
              0.24449959825218992`, 0.3743149583059091, 0.9372352624644963], 
             UndirectedEdge[161, 326] -> 
             RGBColor[
              0.9327537347132191, 0.7525662704764362, 0.31724881897839763`], 
             UndirectedEdge[26, 139] -> 
             RGBColor[
              0.4753323584108449, 0.5831244997687381, 0.952339366037344], 
             UndirectedEdge[109, 218] -> 
             RGBColor[
              0.24296647092511459`, 0.372703544279266, 0.937147953131278], 
             UndirectedEdge[238, 465] -> 
             RGBColor[
              0.30138975132499524`, 0.433055376037075, 0.940513691725769], 
             UndirectedEdge[258, 314] -> 
             RGBColor[
              0.35174895766394676`, 0.47908900053701325`, 0.9436341104363243],
              UndirectedEdge[28, 493] -> 
             RGBColor[
              0.9792166674892435, 0.9809905167708368, 0.7433381739278018], 
             UndirectedEdge[106, 466] -> 
             RGBColor[
              0.5106817556791221, 0.6136334810680553, 0.9546218849774213], 
             UndirectedEdge[45, 236] -> 
             RGBColor[
              0.285052814306115, 0.4169389596009889, 0.9395447081256605], 
             UndirectedEdge[157, 246] -> 
             RGBColor[
              0.2983825090164457, 0.4309493138930047, 0.9403038145198976], 
             UndirectedEdge[371, 427] -> 
             RGBColor[
              0.3212220231725497, 0.4499441234823203, 0.9417879671446181], 
             UndirectedEdge[341, 450] -> 
             RGBColor[
              0.9056409272943111, 0.562891578052587, 0.35323513131972123`], 
             UndirectedEdge[277, 484] -> 
             RGBColor[
              0.8820966152149525, 0.9042351364524142, 0.7227616167031183], 
             UndirectedEdge[84, 135] -> 
             RGBColor[
              0.24197053087649611`, 0.37165674814192173`, 0.9370912358188704],
              UndirectedEdge[35, 84] -> 
             RGBColor[
              0.2358433607180927, 0.36521670382041393`, 0.9367423025426853], 
             UndirectedEdge[68, 272] -> 
             RGBColor[
              0.8202846954174998, 0.15692263455492186`, 0.1670579532810717], 
             UndirectedEdge[164, 227] -> 
             RGBColor[
              0.8315779382096691, 0.24372744738608088`, 0.17787237533274636`],
              UndirectedEdge[355, 498] -> 
             RGBColor[
              0.3952981571338905, 0.516576391637906, 0.946473332742797], 
             UndirectedEdge[223, 373] -> 
             RGBColor[
              0.3417396383201442, 0.4690205123479532, 0.9430475467307398], 
             UndirectedEdge[116, 192] -> 
             RGBColor[
              0.2516702940273803, 0.3818518142140055, 0.9376436229807996], 
             UndirectedEdge[3, 31] -> 
             RGBColor[
              0.4573521482388232, 0.5703305077559329, 0.9504256815919188], 
             UndirectedEdge[40, 419] -> 
             RGBColor[
              0.44944534633244004`, 0.5620965984995714, 0.950304666943798], 
             UndirectedEdge[282, 324] -> 
             RGBColor[
              0.48866791978392093`, 0.5934906203448358, 0.9535163694747727], 
             UndirectedEdge[250, 339] -> 
             RGBColor[
              0.20806801028262886`, 0.33602304945380984`, 0.9351605374253343],
              UndirectedEdge[259, 405] -> 
             RGBColor[
              0.9279266912954685, 0.7275673838799486, 0.39806227602736116`], 
             UndirectedEdge[22, 441] -> 
             RGBColor[
              0.45077446449645514`, 0.564859917388641, 0.9499439281668742], 
             UndirectedEdge[142, 241] -> 
             RGBColor[
              0.7025032226254809, 0.7675201238280478, 0.9709826140315919], 
             UndirectedEdge[170, 266] -> 
             RGBColor[
              0.29310065604108804`, 0.425397751527083, 0.9400030208067522], 
             UndirectedEdge[105, 153] -> 
             RGBColor[
              0.24541911730613436`, 0.37528143113248, 0.9372876277143118], 
             UndirectedEdge[95, 404] -> 
             RGBColor[
              0.22026561376472564`, 0.3488435040862222, 0.9358551728989024], 
             UndirectedEdge[200, 454] -> 
             RGBColor[
              0.9003552167733437, 0.640418136645701, 0.2385662891695866], 
             UndirectedEdge[96, 131] -> 
             RGBColor[
              0.2798853921380307, 0.4115076712688437, 0.9392504310777041], 
             UndirectedEdge[190, 395] -> 
             RGBColor[
              0.2565485956338361, 0.38697921850457684`, 0.9379214350404868], 
             UndirectedEdge[297, 381] -> 
             RGBColor[
              0.5443345056874556, 0.6409542995639315, 0.9572711527321625], 
             UndirectedEdge[203, 419] -> 
             RGBColor[
              0.5236285855732716, 0.6241443008241659, 0.9556411068524893], 
             UndirectedEdge[107, 209] -> 
             RGBColor[
              0.37529763235099667`, 0.4849566561931139, 0.9463994374355724], 
             UndirectedEdge[205, 252] -> 
             RGBColor[
              0.8648112867502258, 0.89136633503373, 0.7718692919288858], 
             UndirectedEdge[98, 488] -> 
             RGBColor[
              0.8822995191611039, 0.9059842085048606, 0.8501777526166581], 
             UndirectedEdge[182, 275] -> 
             RGBColor[
              0.39614531120522645`, 0.517542890548859, 0.9464630068258206], 
             UndirectedEdge[88, 474] -> 
             RGBColor[
              0.9298536404427284, 0.7393015368665987, 0.48723505332973827`], 
             UndirectedEdge[47, 242] -> 
             RGBColor[
              0.2284706396727983, 0.35746750654429615`, 0.9363224369861192], 
             UndirectedEdge[133, 262] -> 
             RGBColor[
              0.4106297397776527, 0.5294703750419166, 0.9475567521778445], 
             UndirectedEdge[4, 321] -> 
             RGBColor[
              0.32873955000778277`, 0.45915940811169914`, 0.9421679713268938],
              UndirectedEdge[369, 370] -> 
             RGBColor[
              0.5056953807182732, 0.6086792278604158, 0.9544796944704173], 
             UndirectedEdge[49, 436] -> 
             RGBColor[
              0.4815672646188717, 0.5899970256324685, 0.9523298855912635], 
             UndirectedEdge[34, 393] -> 
             RGBColor[
              0.5024822764946291, 0.606976774483756, 0.9539763919403361], 
             UndirectedEdge[268, 324] -> 
             RGBColor[
              0.3896661145929028, 0.5119309360971549, 0.946050158147012], 
             UndirectedEdge[359, 371] -> 
             RGBColor[
              0.37419759071797254`, 0.49853287818730624`, 0.94506451748398], 
             UndirectedEdge[296, 440] -> 
             RGBColor[
              0.29754682970453167`, 0.4296388353177702, 0.94027204609223], 
             UndirectedEdge[113, 143] -> 
             RGBColor[
              0.17905963102166003`, 0.30553340361305714`, 0.9335085531404735],
              UndirectedEdge[270, 489] -> 
             RGBColor[
              0.9900603412249211, 0.9901577099059953, 0.8143893991227904], 
             UndirectedEdge[237, 426] -> 
             RGBColor[
              0.8881333928283652, 0.9136374759753497, 0.9891921499256506], 
             UndirectedEdge[131, 385] -> 
             RGBColor[
              0.24854031848564526`, 0.3785620114677306, 0.9374653755040816], 
             UndirectedEdge[427, 499] -> 
             RGBColor[
              0.27010938266217854`, 0.4012324654749223, 0.9386937018003643], 
             UndirectedEdge[45, 243] -> 
             RGBColor[
              0.5610442905289292, 0.35884112143673136`, 0.5623441481098833], 
             UndirectedEdge[33, 443] -> 
             RGBColor[
              0.9064631162110222, 0.6594290978497701, 0.24321160823769428`], 
             UndirectedEdge[232, 330] -> 
             RGBColor[
              0.3313235898372211, 0.4611852513408379, 0.942340398215439], 
             UndirectedEdge[19, 360] -> 
             RGBColor[
              0.5695454245786704, 0.661421659258773, 0.9592558486179177], 
             UndirectedEdge[44, 370] -> 
             RGBColor[
              0.5440602935407461, 0.6407316817901163, 0.9572495657475013], 
             UndirectedEdge[310, 412] -> 
             RGBColor[
              0.26956927876194814`, 0.4006647820312149, 0.9386629436822582], 
             UndirectedEdge[107, 214] -> 
             RGBColor[
              0.19223940367108877`, 0.31938618031345734`, 0.9342591216951321],
              UndirectedEdge[268, 481] -> 
             RGBColor[
              0.3639357382267393, 0.48964457733510314`, 0.9444106413174386], 
             UndirectedEdge[224, 351] -> 
             RGBColor[
              0.29450587119895527`, 0.4268747217537883, 0.9400830457311632], 
             UndirectedEdge[78, 408] -> 
             RGBColor[
              0.22096681623691122`, 0.34958051234329385`, 0.9358951053423573],
              UndirectedEdge[124, 136] -> 
             RGBColor[
              0.9658066058981951, 0.931025957642273, 0.6234191599847442], 
             UndirectedEdge[51, 315] -> 
             RGBColor[
              0.1822133085396902, 0.30884811863921036`, 0.9336881504096776], 
             UndirectedEdge[24, 270] -> 
             RGBColor[
              0.9134975511433701, 0.9314925430785823, 0.899659555679228], 
             UndirectedEdge[43, 340] -> 
             RGBColor[
              0.31529118717805316`, 0.446068953150221, 0.9413638580453506], 
             UndirectedEdge[116, 483] -> 
             RGBColor[
              0.27268756010159706`, 0.40394229342964216`, 0.9388405251914673],
              UndirectedEdge[50, 169] -> 
             RGBColor[
              0.46684010556596744`, 0.5777047091656451, 0.9512633876302873], 
             UndirectedEdge[247, 369] -> 
             RGBColor[
              0.457479402684923, 0.5695353247878849, 0.9506839560586847], 
             UndirectedEdge[327, 412] -> 
             RGBColor[
              0.2497253233645969, 0.37980752672915763`, 0.9375328597788803], 
             UndirectedEdge[134, 305] -> 
             RGBColor[
              0.2421591297202534, 0.37185497748456803`, 0.9371019762440154], 
             UndirectedEdge[7, 49] -> 
             RGBColor[
              0.6644484112533559, 0.7356118894004525, 0.9687430433701605], 
             UndirectedEdge[81, 486] -> 
             RGBColor[
              0.879272872526262, 0.9065723375988691, 0.9883470255893563], 
             UndirectedEdge[110, 384] -> 
             RGBColor[
              0.27776805045914515`, 0.4092822109171187, 0.9391298516014178], 
             UndirectedEdge[18, 88] -> 
             RGBColor[
              0.8754970234499582, 0.5275428865427625, 0.2178240033304778], 
             UndirectedEdge[11, 41] -> 
             RGBColor[
              0.23572240363091454`, 0.3650895702526674, 0.9367354142155104], 
             UndirectedEdge[231, 288] -> 
             RGBColor[
              0.2572561350755689, 0.3877228873184297, 0.9379617283649826], 
             UndirectedEdge[236, 396] -> 
             RGBColor[
              0.6404346091203621, 0.7039646181731036, 0.7392903949875442], 
             UndirectedEdge[46, 418] -> 
             RGBColor[
              0.9480641688610301, 0.8473510420156326, 0.586962152772621], 
             UndirectedEdge[74, 447] -> 
             RGBColor[
              0.26411698006509043`, 0.39493407040511375`, 0.9383524433374253],
              UndirectedEdge[270, 426] -> 
             RGBColor[
              0.9300987405065613, 0.9447298808495102, 0.9012429919407459], 
             UndirectedEdge[383, 479] -> 
             RGBColor[
              0.37021659707670174`, 0.49508474158579574`, 0.9448108520894127],
              UndirectedEdge[408, 430] -> 
             RGBColor[
              0.23112177962706493`, 0.36025402272821205`, 0.9364734154845045],
              UndirectedEdge[13, 390] -> 
             RGBColor[
              0.29868486413343276`, 0.4312671082913797, 0.9403210331965157], 
             UndirectedEdge[15, 97] -> 
             RGBColor[
              0.23298665056537604`, 0.36221412032402367`, 0.936579617125612], 
             UndirectedEdge[289, 472] -> 
             RGBColor[
              0.3839088844842855, 0.5069443127438695, 0.9456833125354096], 
             UndirectedEdge[254, 315] -> 
             RGBColor[
              0.21099893285942517`, 0.33910363491324724`, 0.9353274491301715],
              UndirectedEdge[347, 386] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[66, 445] -> 
             RGBColor[
              0.24646019520379875`, 0.3763756700110764, 0.9373469155604471], 
             UndirectedEdge[127, 213] -> 
             RGBColor[
              0.5650928544862279, 0.5063763336200533, 0.5889799898461102], 
             UndirectedEdge[423, 446] -> 
             RGBColor[
              0.20798858239401255`, 0.3359395657068551, 0.9351560141245807], 
             UndirectedEdge[63, 410] -> 
             RGBColor[
              0.39150030357105375`, 0.5135196184010107, 0.9461670310467902], 
             UndirectedEdge[107, 421] -> 
             RGBColor[
              0.18186414913512938`, 0.30848112996703203`, 0.9336682662981228],
              UndirectedEdge[226, 308] -> 
             RGBColor[
              0.17918563853241248`, 0.3056658454961956, 0.9335157290817995], 
             UndirectedEdge[51, 386] -> 
             RGBColor[
              0.1789270004053139, 0.3053940004260106, 0.9335010000230821], 
             UndirectedEdge[89, 470] -> 
             RGBColor[
              0.27049191209474743`, 0.40163452816231904`, 0.9387154862856475],
              UndirectedEdge[205, 490] -> 
             RGBColor[
              0.9921900608993205, 0.9897828176678509, 0.6878265810358566], 
             UndirectedEdge[270, 345] -> 
             RGBColor[
              0.824874141314561, 0.8621219539632672, 0.8908628396870938], 
             UndirectedEdge[152, 191] -> 
             RGBColor[
              0.21120215837255008`, 0.3393172378127832, 0.9353390225224988], 
             UndirectedEdge[85, 404] -> 
             RGBColor[
              0.21383193119222793`, 0.3420812957834917, 0.9354887841941792], 
             UndirectedEdge[26, 468] -> 
             RGBColor[
              0.43250328030680874`, 0.5483539247359007, 0.9489677041209118], 
             UndirectedEdge[191, 301] -> 
             RGBColor[
              0.2135770306984165, 0.34181337920287114`, 0.935474267988148], 
             UndirectedEdge[375, 426] -> 
             RGBColor[
              0.9141879156308917, 0.9338323693009003, 0.9715587229445324], 
             UndirectedEdge[39, 213] -> 
             RGBColor[
              0.7639337426080279, 0.681629388750616, 0.6026477314488674], 
             UndirectedEdge[360, 468] -> 
             RGBColor[
              0.5288716731016017, 0.6284008754780657, 0.9560538619087819], 
             UndirectedEdge[80, 278] -> 
             RGBColor[
              0.8689533270990046, 0.8982632673699124, 0.9759744072003973], 
             UndirectedEdge[152, 299] -> 
             RGBColor[
              0.20658465608391344`, 0.3344639501408717, 0.9350760625981434], 
             UndirectedEdge[227, 309] -> 
             RGBColor[
              0.9193309660445672, 0.6696242794444807, 0.3370748612621325], 
             UndirectedEdge[98, 115] -> 
             RGBColor[
              0.9582015589575525, 0.9660972945461519, 0.85752593015656], 
             UndirectedEdge[213, 261] -> 
             RGBColor[
              0.8920963570986589, 0.602916583768641, 0.23167489421385412`], 
             UndirectedEdge[199, 208] -> 
             RGBColor[
              0.33248120157791744`, 0.46240023864087376`, 0.9424063860563303],
              UndirectedEdge[204, 219] -> 
             RGBColor[
              0.5140809753819581, 0.6163931207559199, 0.9548894840041806], 
             UndirectedEdge[52, 166] -> 
             RGBColor[
              0.8369577282992072, 0.2850788714533209, 0.18302406839809204`], 
             UndirectedEdge[218, 300] -> 
             RGBColor[
              0.22896529227619977`, 0.3579874177932576, 0.93635060672011], 
             UndirectedEdge[128, 345] -> 
             RGBColor[
              0.5772342034942839, 0.6673977284070023, 0.9600430222220963], 
             UndirectedEdge[325, 421] -> 
             RGBColor[
              0.17903676307516053`, 0.3055093679513746, 0.9335072508447505], 
             UndirectedEdge[257, 272] -> 
             RGBColor[
              0.8397181825766789, 0.3055916208213189, 0.18563986428858031`], 
             UndirectedEdge[461, 486] -> 
             RGBColor[
              0.9396915520193736, 0.9545227464327241, 0.9862809714214389], 
             UndirectedEdge[115, 203] -> 
             RGBColor[
              0.7278675078772177, 0.786501490374317, 0.9744226233622142], 
             UndirectedEdge[128, 169] -> 
             RGBColor[
              0.4937426983927686, 0.5998815912671589, 0.9532883803380281], 
             UndirectedEdge[190, 356] -> 
             RGBColor[
              0.2587237746657965, 0.38926546958148345`, 0.9380453082684679], 
             UndirectedEdge[46, 272] -> 
             RGBColor[
              0.8691188894851287, 0.4352254750326188, 0.20997245291222838`], 
             UndirectedEdge[121, 450] -> 
             RGBColor[
              0.8225872124582064, 0.17462078949919407`, 0.16926284619957344`],
              UndirectedEdge[255, 269] -> 
             RGBColor[
              0.4232624333249523, 0.5410303787827784, 0.94819088586856], 
             UndirectedEdge[15, 356] -> 
             RGBColor[
              0.2517883622305454, 0.38197591138148856`, 0.9376503467903037], 
             UndirectedEdge[85, 183] -> 
             RGBColor[
              0.20959144808050473`, 0.33762427917091264`, 0.9352472949541991],
              UndirectedEdge[136, 261] -> 
             RGBColor[
              0.924473739268195, 0.762150740681319, 0.5794980394919615], 
             UndirectedEdge[295, 336] -> 
             RGBColor[
              0.22591321478921644`, 0.3547794908415487, 0.9361767954223702], 
             UndirectedEdge[259, 475] -> 
             RGBColor[
              0.8504220451203991, 0.38316771966990754`, 0.19570591448943397`],
              UndirectedEdge[51, 143] -> 
             RGBColor[
              0.17892700107920537`, 0.30539400113431325`, 0.9335010000614592],
              UndirectedEdge[53, 178] -> 
             RGBColor[
              0.9840984713626098, 0.9616310168446078, 0.5753629014776818], 
             UndirectedEdge[67, 385] -> 
             RGBColor[
              0.24504732911062774`, 0.37489065816626943`, 0.9372664549265891],
              UndirectedEdge[69, 173] -> 
             RGBColor[
              0.9470127321552729, 0.9592645667466908, 0.9483609186014075], 
             UndirectedEdge[221, 381] -> 
             RGBColor[
              0.5529574414035745, 0.647954787237104, 0.9579499818185896], 
             UndirectedEdge[140, 334] -> 
             RGBColor[
              0.4512190714580578, 0.563987423855866, 0.9503197339204532], 
             UndirectedEdge[57, 370] -> 
             RGBColor[
              0.5963431626815656, 0.6831772702750474, 0.9613654647247267], 
             UndirectedEdge[432, 467] -> 
             RGBColor[
              0.8027318187709938, 0.8464550865365966, 0.9808037893677689], 
             UndirectedEdge[235, 440] -> 
             RGBColor[
              0.3193577814126447, 0.44853038543702994`, 0.9416618206484036], 
             UndirectedEdge[229, 390] -> 
             RGBColor[
              0.29586463316817824`, 0.4283028667339263, 0.9401604252152023], 
             UndirectedEdge[12, 198] -> 
             RGBColor[
              0.2771414265920781, 0.4086235895025834, 0.9390941662991953], 
             UndirectedEdge[232, 400] -> 
             RGBColor[
              0.3260597275402094, 0.45565259831853255`, 0.9420406290448107], 
             UndirectedEdge[143, 273] -> 
             RGBColor[
              0.23623420851912813`, 0.365627509640484, 0.9367645607467467], 
             UndirectedEdge[115, 277] -> 
             RGBColor[
              0.8462349559465709, 0.8806222819755531, 0.9850914215175051], 
             UndirectedEdge[44, 468] -> 
             RGBColor[
              0.48752713657842917`, 0.5948355181784093, 0.9527990685436503], 
             UndirectedEdge[183, 346] -> 
             RGBColor[
              0.21142499907593382`, 0.3395514575209563, 0.9353517129708931], 
             UndirectedEdge[434, 469] -> 
             RGBColor[
              0.9258166281861495, 0.7248800924627727, 0.5003559242994462], 
             UndirectedEdge[255, 334] -> 
             RGBColor[
              0.40019480220882075`, 0.5210503561228367, 0.9467210368117455], 
             UndirectedEdge[65, 210] -> 
             RGBColor[
              0.9107642708804349, 0.6204193391599911, 0.29010099455145133`], 
             UndirectedEdge[49, 76] -> 
             RGBColor[
              0.45077000854144356`, 0.5638542255344485, 0.9502204534950804], 
             UndirectedEdge[74, 395] -> 
             RGBColor[
              0.2733607929019397, 0.4046499037882272, 0.9388788648034883], 
             UndirectedEdge[52, 88] -> 
             RGBColor[
              0.8512025856554928, 0.3816657696999445, 0.19615962002028325`], 
             UndirectedEdge[312, 354] -> 
             RGBColor[
              0.3330876906173925, 0.4625247982993003, 0.942459704446583], 
             UndirectedEdge[372, 417] -> 
             RGBColor[
              0.5857428674141524, 0.6736726673586156, 0.9611454890036907], 
             UndirectedEdge[354, 415] -> 
             RGBColor[
              0.32438826492045936`, 0.4533811503163769, 0.9419642850227896], 
             UndirectedEdge[301, 451] -> 
             RGBColor[
              0.2100992490740445, 0.3381580102115655, 0.9352762134695569], 
             UndirectedEdge[243, 428] -> 
             RGBColor[
              0.8348198026853184, 0.2686458383399938, 0.18097678841579048`], 
             UndirectedEdge[102, 354] -> 
             RGBColor[
              0.3191507002330799, 0.44787613774915985`, 0.941666013462126], 
             UndirectedEdge[255, 369] -> 
             RGBColor[
              0.40876647484829665`, 0.5284747081383571, 0.9472672162127003], 
             UndirectedEdge[300, 409] -> 
             RGBColor[
              0.23375665444094554`, 0.3630234432183127, 0.936623467707207], 
             UndirectedEdge[93, 187] -> 
             RGBColor[
              0.2669566877883537, 0.3979187832701322, 0.9385141604912941], 
             UndirectedEdge[181, 332] -> 
             RGBColor[
              0.41144462504759094`, 0.5307943872332428, 0.947437865575204], 
             UndirectedEdge[195, 351] -> 
             RGBColor[
              0.2800986877606033, 0.41173185849189103`, 0.9392625779478669], 
             UndirectedEdge[480, 481] -> 
             RGBColor[
              0.33588196619861493`, 0.46534581002792214`, 0.9426230797707831],
              UndirectedEdge[47, 365] -> 
             RGBColor[
              0.22445415871552787`, 0.3532459303986038, 0.9360937043374536], 
             UndirectedEdge[50, 370] -> 
             RGBColor[
              0.5161906822110007, 0.6177697305042253, 0.9551484458009031], 
             UndirectedEdge[122, 150] -> 
             RGBColor[
              0.8444744803276283, 0.32854420856354566`, 0.1896617078466737], 
             UndirectedEdge[246, 256] -> 
             RGBColor[
              0.2918037733500637, 0.42403464559170456`, 0.9399291652560644], 
             UndirectedEdge[63, 282] -> 
             RGBColor[
              0.5134969921724348, 0.6149963149023026, 0.9550984560118821], 
             UndirectedEdge[230, 391] -> 
             RGBColor[
              0.23250262506826308`, 0.3617053788375689, 0.936552052589603], 
             UndirectedEdge[312, 415] -> 
             RGBColor[
              0.29571211190112656`, 0.42814255721184813`, 0.9401517393546788],
              UndirectedEdge[199, 397] -> 
             RGBColor[
              0.3506959657134314, 0.47817695183439113`, 0.9435670147203616], 
             UndirectedEdge[129, 328] -> 
             RGBColor[
              0.3704563897071251, 0.49529243790994043`, 0.944826131463783], 
             UndirectedEdge[188, 304] -> 
             RGBColor[
              0.33792059600024626`, 0.4671115686975821, 0.9427529794590535], 
             UndirectedEdge[323, 395] -> 
             RGBColor[
              0.25216611947306267`, 0.3823729581945666, 0.9376718595064233], 
             UndirectedEdge[49, 238] -> 
             RGBColor[
              0.4051843179606758, 0.5243701915568157, 0.9473157736011174], 
             UndirectedEdge[171, 385] -> 
             RGBColor[
              0.24760690614002792`, 0.37758093591072595`, 0.9374122190518586],
              UndirectedEdge[117, 425] -> 
             RGBColor[
              0.3782090614978762, 0.502007412554475, 0.9453201248548712], 
             UndirectedEdge[32, 103] -> 
             RGBColor[
              0.5080332189208779, 0.6114832796124914, 0.9544133824619024], 
             UndirectedEdge[131, 216] -> 
             RGBColor[
              0.26474751566428445`, 0.3955968032981327, 0.9383883514070055], 
             UndirectedEdge[65, 175] -> 
             RGBColor[
              0.9705975460870158, 0.9645679382577699, 0.6789276620320353], 
             UndirectedEdge[143, 226] -> 
             RGBColor[
              0.17917599682249857`, 0.3056557114477564, 0.9335151800006836], 
             UndirectedEdge[234, 235] -> 
             RGBColor[
              0.3728101836078023, 0.49733117588158576`, 0.9449761131297559], 
             UndirectedEdge[179, 386] -> 
             RGBColor[
              0.17892806853100302`, 0.30539512309383293`, 0.93350106085126], 
             UndirectedEdge[267, 476] -> 
             RGBColor[
              0.9187775169477521, 0.6742536840952063, 0.3030402150761125], 
             UndirectedEdge[59, 195] -> 
             RGBColor[
              0.2561715150223729, 0.3865828828736374, 0.9378999608575047], 
             UndirectedEdge[75, 108] -> 
             RGBColor[
              0.31502960292460824`, 0.4450992956026424, 0.9413743981617775], 
             UndirectedEdge[334, 363] -> 
             RGBColor[
              0.40380771802618465`, 0.5241796822134083, 0.9469512486128518], 
             UndirectedEdge[77, 329] -> 
             RGBColor[
              0.7446878798780471, 0.8004364154026, 0.9754252127138938], 
             UndirectedEdge[328, 462] -> 
             RGBColor[
              0.4245956854340748, 0.5418984360706564, 0.9483550662650316], 
             UndirectedEdge[285, 480] -> 
             RGBColor[
              0.3339827883337351, 0.46370083761681824`, 0.9425020658366099], 
             UndirectedEdge[204, 334] -> 
             RGBColor[
              0.4523485649591434, 0.5649043975631496, 0.9504086517863296], 
             UndirectedEdge[70, 238] -> 
             RGBColor[
              0.28920204195997834`, 0.42024532074903687`, 0.9398196197075317],
              UndirectedEdge[83, 270] -> 
             RGBColor[
              0.955384395176871, 0.9648919755228036, 0.9036547602559704], 
             UndirectedEdge[112, 190] -> 
             RGBColor[
              0.24818657202567745`, 0.37819020150948346`, 0.9374452301665075],
              UndirectedEdge[263, 453] -> 
             RGBColor[
              0.27885374219171843`, 0.41042334176488493`, 0.9391916801394509],
              UndirectedEdge[210, 474] -> 
             RGBColor[
              0.9145804341522545, 0.6348102980864267, 0.4731147536068143], 
             UndirectedEdge[96, 392] -> 
             RGBColor[
              0.3010815634219416, 0.43378619120311424`, 0.9404575216753974], 
             UndirectedEdge[70, 84] -> 
             RGBColor[
              0.24578222839824324`, 0.37566308391285935`, 0.9373083063538328],
              UndirectedEdge[77, 278] -> 
             RGBColor[
              0.7775908081460805, 0.8263457284855322, 0.9672404849556133], 
             UndirectedEdge[238, 265] -> 
             RGBColor[
              0.32058421295120315`, 0.4520956650524487, 0.9416483204611299], 
             UndirectedEdge[157, 392] -> 
             RGBColor[
              0.3042725009406671, 0.4371400688524187, 0.9406392408465198], 
             UndirectedEdge[145, 294] -> 
             RGBColor[
              0.22948545468760678`, 0.35853414146784807`, 0.9363802291999281],
              UndirectedEdge[29, 383] -> 
             RGBColor[
              0.3692814154214852, 0.49427473423964385`, 0.944751263141291], 
             UndirectedEdge[210, 227] -> 
             RGBColor[
              0.8408474405782448, 0.3149769045127923, 0.18674886126930004`], 
             UndirectedEdge[45, 276] -> 
             RGBColor[
              0.4511613140247853, 0.5582811601613382, 0.9513035162562244], 
             UndirectedEdge[57, 219] -> 
             RGBColor[
              0.5637559435916646, 0.6567214977803754, 0.9588000794670529], 
             UndirectedEdge[291, 311] -> 
             RGBColor[
              0.7008920044449292, 0.7662614279396891, 0.9708220228610445], 
             UndirectedEdge[11, 485] -> 
             RGBColor[
              0.24345966129558455`, 0.3732219186287056, 0.9371760395932665], 
             UndirectedEdge[13, 338] -> 
             RGBColor[
              0.30836079438708164`, 0.4403868770076641, 0.9409105178148355], 
             UndirectedEdge[190, 351] -> 
             RGBColor[
              0.2690775343767192, 0.40014792750394457`, 0.9386349395669901], 
             UndirectedEdge[314, 397] -> 
             RGBColor[
              0.34431176305958455`, 0.4726472763749843, 0.9431602189725873], 
             UndirectedEdge[339, 365] -> 
             RGBColor[
              0.2143326753092825, 0.34260760959952685`, 0.9355173008308608], 
             UndirectedEdge[320, 337] -> 
             RGBColor[
              0.9244065988908812, 0.9404637664434601, 0.9125392493325524], 
             UndirectedEdge[317, 357] -> 
             RGBColor[
              0.895271303645258, 0.6164935275347583, 0.23428070819651722`], 
             UndirectedEdge[153, 452] -> 
             RGBColor[
              0.2344431943228335, 0.36374504016331954`, 0.9366625651378359], 
             UndirectedEdge[308, 423] -> 
             RGBColor[
              0.1833860881198116, 0.31008078433643804`, 0.9337549384717936], 
             UndirectedEdge[149, 441] -> 
             RGBColor[
              0.4020035872776604, 0.5226170348372846, 0.946836290996886], 
             UndirectedEdge[486, 493] -> 
             RGBColor[
              0.9642524295918031, 0.9698103203224957, 0.7679790459557528], 
             UndirectedEdge[241, 402] -> 
             RGBColor[
              0.6288966867837086, 0.7086387216585579, 0.9645893173262957], 
             UndirectedEdge[293, 432] -> 
             RGBColor[
              0.9264483908194477, 0.943709860746635, 0.9762410122023322], 
             UndirectedEdge[23, 211] -> 
             RGBColor[
              0.226770956748013, 0.3556810320242251, 0.9362256425580082], 
             UndirectedEdge[8, 381] -> 
             RGBColor[
              0.5947992155017207, 0.6819238244004215, 0.9612439195470645], 
             UndirectedEdge[238, 343] -> 
             RGBColor[
              0.306520714368336, 0.43844834351747275`, 0.9408058924805078], 
             UndirectedEdge[355, 363] -> 
             RGBColor[
              0.366759080123219, 0.492090014180544, 0.9445905421664991], 
             UndirectedEdge[66, 398] -> 
             RGBColor[
              0.26221606410223275`, 0.392936087203117, 0.9382441889854937], 
             UndirectedEdge[113, 477] -> 
             RGBColor[
              0.2119319440670913, 0.3400842888488316, 0.9353805827381816], 
             UndirectedEdge[7, 241] -> 
             RGBColor[
              0.7720821236708154, 0.8220268199822758, 0.9778774834237032], 
             UndirectedEdge[161, 259] -> 
             RGBColor[
              0.9260863286561598, 0.722291136783578, 0.31168537193130974`], 
             UndirectedEdge[346, 408] -> 
             RGBColor[
              0.22019359510263653`, 0.34876780790611966`, 0.9358510715426385],
              UndirectedEdge[33, 270] -> 
             RGBColor[
              0.9342186701882929, 0.7654658229940685, 0.5176324949764846], 
             UndirectedEdge[197, 270] -> 
             RGBColor[
              0.843824355466433, 0.8769260052856713, 0.8927516199339326], 
             UndirectedEdge[115, 381] -> 
             RGBColor[
              0.7452365910783697, 0.8006024945852935, 0.9757899812168571], 
             UndirectedEdge[112, 224] -> 
             RGBColor[
              0.2736149088479135, 0.4049169957593272, 0.9388933363306806], 
             UndirectedEdge[133, 296] -> 
             RGBColor[
              0.3292967430314739, 0.4596420207034847, 0.942203475173657], 
             UndirectedEdge[204, 244] -> 
             RGBColor[
              0.42216704011068096`, 0.5387626777069581, 0.9484855117114601], 
             UndirectedEdge[116, 280] -> 
             RGBColor[
              0.25280916302349343`, 0.3830488377373854, 0.9377084798853226], 
             UndirectedEdge[81, 267] -> 
             RGBColor[
              0.906340376624757, 0.9184812574076573, 0.6975246745106891], 
             UndirectedEdge[431, 459] -> 
             RGBColor[
              0.41954302397723237`, 0.5378088133487329, 0.9479538883938678], 
             UndirectedEdge[46, 293] -> 
             RGBColor[
              0.9359635798708703, 0.8383264425596675, 0.6074452935938994], 
             UndirectedEdge[145, 358] -> 
             RGBColor[
              0.2231421897482483, 0.351866967830356, 0.9360189896456512], 
             UndirectedEdge[12, 480] -> 
             RGBColor[
              0.31297532312712917`, 0.4421451064609878, 0.9412865192071291], 
             UndirectedEdge[318, 321] -> 
             RGBColor[
              0.33755888801482614`, 0.46679827542058316`, 0.9427299317460682],
              UndirectedEdge[38, 47] -> 
             RGBColor[
              0.24595116399713765`, 0.375840645938433, 0.9373179269862719], 
             UndirectedEdge[271, 492] -> 
             RGBColor[
              0.2662123163354113, 0.39713640167721365`, 0.9384717696382479], 
             UndirectedEdge[246, 333] -> 
             RGBColor[
              0.33643527177961996`, 0.46448215779697133`, 0.9427075059768388],
              UndirectedEdge[97, 137] -> 
             RGBColor[
              0.2259075246268314, 0.35477351012010483`, 0.9361764713760403], 
             UndirectedEdge[406, 486] -> 
             RGBColor[
              0.9627729895914936, 0.9654828212213326, 0.7058550168364002], 
             UndirectedEdge[272, 306] -> 
             RGBColor[
              0.8390812230199529, 0.30140098239829205`, 0.18505752934082234`],
              UndirectedEdge[50, 219] -> 
             RGBColor[
              0.48360346312109975`, 0.5913139580095534, 0.9525830605432293], 
             UndirectedEdge[326, 405] -> 
             RGBColor[
              0.9345940973525277, 0.7578425175728066, 0.403625723074449], 
             UndirectedEdge[180, 343] -> 
             RGBColor[
              0.28150922552658186`, 0.4132144231171943, 0.9393429059869358], 
             UndirectedEdge[229, 380] -> 
             RGBColor[
              0.2819134302618612, 0.4136392679220333, 0.9393659248486427], 
             UndirectedEdge[184, 470] -> 
             RGBColor[
              0.2562569900664413, 0.3866727225643841, 0.9379048285348154], 
             UndirectedEdge[188, 483] -> 
             RGBColor[
              0.31696315839045336`, 0.4478408551549855, 0.9414585414299963], 
             UndirectedEdge[364, 374] -> 
             RGBColor[
              0.2551484985501697, 0.3855076276983612, 0.93784170158283], 
             UndirectedEdge[161, 469] -> 
             RGBColor[
              0.9253813180460291, 0.7190898482623855, 0.3110970937968252], 
             UndirectedEdge[14, 182] -> 
             RGBColor[
              0.34266467028924463`, 0.47103542678761523`, 0.9430620495117685],
              UndirectedEdge[374, 391] -> 
             RGBColor[
              0.24642877472957408`, 0.3763426451004932, 0.9373451262109225], 
             UndirectedEdge[352, 367] -> 
             RGBColor[
              0.2288379775147259, 0.35785360190672644`, 0.9363433563327893], 
             UndirectedEdge[8, 289] -> 
             RGBColor[
              0.5298323406094952, 0.6288020963090049, 0.9562341229930127], 
             UndirectedEdge[160, 275] -> 
             RGBColor[
              0.4180928553323577, 0.5365527501561378, 0.9478614849301503], 
             UndirectedEdge[118, 151] -> 
             RGBColor[
              0.31595121433390305`, 0.44790234871507695`, 0.9413597168905753],
              UndirectedEdge[43, 217] -> 
             RGBColor[
              0.30643378623989703`, 0.43839711764350564`, 0.9407994722898634],
              UndirectedEdge[117, 154] -> 
             RGBColor[
              0.34530823850037556`, 0.4735103733174856, 0.9432237135065259], 
             UndirectedEdge[139, 468] -> 
             RGBColor[
              0.5212061017709153, 0.6221776193417614, 0.9554504000537172], 
             UndirectedEdge[279, 324] -> 
             RGBColor[
              0.3241188367997081, 0.45236629730551653`, 0.9419757314019449], 
             UndirectedEdge[4, 29] -> 
             RGBColor[
              0.36696197867847585`, 0.49226575471112954`, 0.9446034706830237],
              UndirectedEdge[239, 393] -> 
             RGBColor[
              0.4060710006373207, 0.5259256972403187, 0.9471546820617923], 
             UndirectedEdge[94, 127] -> 
             RGBColor[
              0.5906994451507328, 0.6605608453144329, 0.9482643190369882], 
             UndirectedEdge[157, 459] -> 
             RGBColor[
              0.3465448636437761, 0.4740080224761397, 0.94332350710475], 
             UndirectedEdge[48, 85] -> 
             RGBColor[
              0.21086321568284044`, 0.3389609875556907, 0.9353197202377406], 
             UndirectedEdge[26, 215] -> 
             RGBColor[
              0.33537631974199883`, 0.4626312893738342, 0.942674216260174], 
             UndirectedEdge[63, 165] -> 
             RGBColor[
              0.42168442508772075`, 0.5396635873606885, 0.9480903365790616], 
             UndirectedEdge[165, 282] -> 
             RGBColor[
              0.5158458225400988, 0.6170307537111264, 0.9552481214059205], 
             UndirectedEdge[288, 465] -> 
             RGBColor[
              0.2693457460924733, 0.4004298350228071, 0.9386502138274186], 
             UndirectedEdge[200, 500] -> 
             RGBColor[
              0.8601603348227043, 0.3966998445648045, 0.2026301493422178], 
             UndirectedEdge[293, 353] -> 
             RGBColor[
              0.7969674264911133, 0.8418814193634385, 0.9635324755439242], 
             UndirectedEdge[239, 296] -> 
             RGBColor[
              0.33217516852493173`, 0.46213516819204603`, 0.9423868859008084],
              UndirectedEdge[139, 274] -> 
             RGBColor[
              0.5133847204187874, 0.6158278696108893, 0.9548346722630138], 
             UndirectedEdge[140, 361] -> 
             RGBColor[
              0.5719177559547599, 0.6633194007954346, 0.9594619041005235], 
             UndirectedEdge[83, 197] -> 
             RGBColor[
              0.8091856625186589, 0.8516756760168047, 0.981399600787607], 
             UndirectedEdge[256, 444] -> 
             RGBColor[
              0.28033959264989716`, 0.411985064804791, 0.9392762971249253], 
             UndirectedEdge[21, 166] -> 
             RGBColor[
              0.9095040888434207, 0.6206039273550481, 0.282195231981873], 
             UndirectedEdge[92, 363] -> 
             RGBColor[
              0.506974473041424, 0.6093066729422614, 0.9546939442160238], 
             UndirectedEdge[41, 212] -> 
             RGBColor[
              0.22552146354030395`, 0.35436773544047784`, 0.9361544857682886],
              UndirectedEdge[96, 433] -> 
             RGBColor[
              0.31083399291217784`, 0.4424870131772134, 0.9410696465455513], 
             UndirectedEdge[346, 407] -> 
             RGBColor[
              0.2161204994130187, 0.34448672608714886`, 0.9356191147687198], 
             UndirectedEdge[32, 155] -> 
             RGBColor[
              0.5507999265063706, 0.6462032194486154, 0.9577801343426442], 
             UndirectedEdge[302, 477] -> 
             RGBColor[
              0.21741049289010705`, 0.3458425910218791, 0.9356925779888657], 
             UndirectedEdge[24, 489] -> 
             RGBColor[
              0.9135348042436461, 0.9315079481929074, 0.8990421753997224], 
             UndirectedEdge[359, 427] -> 
             RGBColor[
              0.3324756951564906, 0.4596914885288097, 0.9425050411722034], 
             UndirectedEdge[217, 290] -> 
             RGBColor[
              0.3031025001174864, 0.43489572471311266`, 0.9406097604733883], 
             UndirectedEdge[40, 297] -> 
             RGBColor[
              0.4527821832454718, 0.5648055930283604, 0.9505673549688282], 
             UndirectedEdge[41, 456] -> 
             RGBColor[
              0.22809260204387605`, 0.3570701650273288, 0.9363009083024085], 
             UndirectedEdge[341, 469] -> 
             RGBColor[
              0.927002024559022, 0.7238962731152077, 0.3735657841038871], 
             UndirectedEdge[169, 498] -> 
             RGBColor[
              0.4773158479045384, 0.5865455340196324, 0.9519951984940587], 
             UndirectedEdge[6, 329] -> 
             RGBColor[
              0.8551238518896912, 0.8873165640509703, 0.9860436704429549], 
             UndirectedEdge[92, 219] -> 
             RGBColor[
              0.5677032440041356, 0.6599260940790765, 0.9591108254149605], 
             UndirectedEdge[341, 387] -> 
             RGBColor[
              0.8843435887930974, 0.9064532397024012, 0.7600495256450741], 
             UndirectedEdge[13, 478] -> 
             RGBColor[
              0.28132910192119526`, 0.41302510178743673`, 0.939332648214078], 
             UndirectedEdge[33, 267] -> 
             RGBColor[
              0.9337384293685642, 0.7577785430140971, 0.3161344657047144], 
             UndirectedEdge[10, 123] -> 
             RGBColor[
              0.21296296597852177`, 0.34116795824830987`, 0.9354392979107774],
              UndirectedEdge[57, 337] -> 
             RGBColor[
              0.730726843956438, 0.7892639238928545, 0.9741400277373693], 
             UndirectedEdge[70, 135] -> 
             RGBColor[
              0.25443846593234043`, 0.3847613383983545, 0.9378012662756438], 
             UndirectedEdge[51, 130] -> 
             RGBColor[
              0.1789270004053139, 0.3053940004260106, 0.9335010000230821], 
             UndirectedEdge[219, 361] -> 
             RGBColor[
              0.5852351734855985, 0.6741310802897922, 0.9605102999918589], 
             UndirectedEdge[70, 131] -> 
             RGBColor[
              0.2609296066664183, 0.3915839388719636, 0.9381709271376673], 
             UndirectedEdge[61, 362] -> 
             RGBColor[
              0.3561441161626767, 0.48289586592152384`, 0.9439141660493773], 
             UndirectedEdge[49, 487] -> 
             RGBColor[
              0.5348230464505574, 0.633232468469062, 0.9565223758194106], 
             UndirectedEdge[83, 375] -> 
             RGBColor[
              0.9394735703012015, 0.9539944639741937, 0.9739704912597569], 
             UndirectedEdge[147, 385] -> 
             RGBColor[
              0.24248237828575928`, 0.37219473222205746`, 0.9371203847716176],
              UndirectedEdge[105, 395] -> 
             RGBColor[
              0.2554464216840092, 0.38582076380144426`, 0.9378586678645644], 
             UndirectedEdge[57, 204] -> 
             RGBColor[
              0.5515680195619116, 0.6468267919933015, 0.9578406014415939], 
             UndirectedEdge[362, 363] -> 
             RGBColor[
              0.3966364490357477, 0.5179682894523514, 0.9464943016940854], 
             UndirectedEdge[313, 390] -> 
             RGBColor[
              0.28385568108857195`, 0.41568069668672125`, 0.9394765331599213],
              UndirectedEdge[15, 430] -> 
             RGBColor[
              0.23698890967688827`, 0.36642074840810707`, 0.9368075398612009],
              UndirectedEdge[104, 430] -> 
             RGBColor[
              0.24315634658411125`, 0.3729031156356836, 0.937158766269162], 
             UndirectedEdge[341, 405] -> 
             RGBColor[
              0.9937930272646951, 0.989132237877419, 0.5657875066366207], 
             UndirectedEdge[8, 311] -> 
             RGBColor[
              0.6835752486050087, 0.752395433322769, 0.9693271520415703], 
             UndirectedEdge[305, 460] -> 
             RGBColor[
              0.24972906299601538`, 0.37981145731888477`, 0.9375330727453572],
              UndirectedEdge[451, 456] -> 
             RGBColor[
              0.21755217330464396`, 0.3459915061206145, 0.9357006464788762], 
             UndirectedEdge[257, 306] -> 
             RGBColor[
              0.8582164736566054, 0.4477775920644729, 0.2033538487175496], 
             UndirectedEdge[65, 167] -> 
             RGBColor[
              0.986067541242265, 0.9756937071602725, 0.6343029674871418], 
             UndirectedEdge[24, 329] -> 
             RGBColor[
              0.8597649491834076, 0.8910172490537498, 0.986486342445986], 
             UndirectedEdge[14, 63] -> 
             RGBColor[
              0.3630391373968948, 0.48868276614576933`, 0.9443602925394342], 
             UndirectedEdge[64, 172] -> 
             RGBColor[
              0.31974345189880926`, 0.449434024298521, 0.9416655397334055], 
             UndirectedEdge[50, 361] -> 
             RGBColor[
              0.5425697371949871, 0.6391572117563517, 0.9572443985054486], 
             UndirectedEdge[253, 291] -> 
             RGBColor[
              0.819979493708928, 0.8592158126034372, 0.9319826199336896], 
             UndirectedEdge[184, 280] -> 
             RGBColor[
              0.2569621251304517, 0.38741386422480434`, 0.9379449849335569], 
             UndirectedEdge[402, 487] -> 
             RGBColor[
              0.565871305361324, 0.6584388437609466, 0.958966608494386], 
             UndirectedEdge[356, 463] -> 
             RGBColor[
              0.26821764598055253`, 0.3992441302795001, 0.9385859701949193], 
             UndirectedEdge[287, 301] -> 
             RGBColor[
              0.20928219811004087`, 0.33729923784437454`, 0.9352296836258756],
              UndirectedEdge[265, 328] -> 
             RGBColor[
              0.35316375548579293`, 0.48031442730049023`, 0.9437242601024758],
              UndirectedEdge[196, 321] -> 
             RGBColor[
              0.31443739392836134`, 0.4455653460211614, 0.9413008174322348], 
             UndirectedEdge[122, 267] -> 
             RGBColor[
              0.9282834555711476, 0.7330087810415269, 0.3115827018545064], 
             UndirectedEdge[330, 354] -> 
             RGBColor[
              0.3341066984387609, 0.463595840128386, 0.9425177354345229], 
             UndirectedEdge[155, 393] -> 
             RGBColor[
              0.5135503027141461, 0.615962296777659, 0.9548477075078524], 
             UndirectedEdge[291, 319] -> 
             RGBColor[
              0.6849084125962169, 0.7537749245076777, 0.969228927800723], 
             UndirectedEdge[63, 206] -> 
             RGBColor[
              0.3810348762200533, 0.5044549912372471, 0.9455001832701985], 
             UndirectedEdge[174, 215] -> 
             RGBColor[
              0.2753901052316153, 0.40678283971254936`, 0.9389944311385647], 
             UndirectedEdge[254, 471] -> 
             RGBColor[
              0.5466554162409889, 0.4017985093907806, 0.5694083486000513], 
             UndirectedEdge[453, 463] -> 
             RGBColor[
              0.2757020968027919, 0.407110762635264, 0.939012198596993], 
             UndirectedEdge[154, 174] -> 
             RGBColor[
              0.2880991557381853, 0.4200673355937856, 0.9397208847641902], 
             UndirectedEdge[119, 197] -> 
             RGBColor[
              0.8441364985929255, 0.8770550844901885, 0.8875786005274353], 
             UndirectedEdge[50, 340] -> 
             RGBColor[
              0.3891862943583425, 0.5115153399264449, 0.9460195844259542], 
             UndirectedEdge[443, 446] -> 
             RGBColor[
              0.5813316267430582, 0.5676003433786956, 0.6012346277346379], 
             UndirectedEdge[275, 324] -> 
             RGBColor[
              0.3916907059243627, 0.5136845353495464, 0.9461791633163769], 
             UndirectedEdge[95, 286] -> 
             RGBColor[
              0.22509159237078977`, 0.3539159135859121, 0.9361300052411223], 
             UndirectedEdge[306, 317] -> 
             RGBColor[
              0.8704899188810679, 0.5035084402927961, 0.2135951122625132], 
             UndirectedEdge[118, 188] -> 
             RGBColor[
              0.3311926249986076, 0.4612841383736176, 0.9423242790961401], 
             UndirectedEdge[7, 69] -> 
             RGBColor[
              0.874072307624645, 0.9024255483118935, 0.9878509910664408], 
             UndirectedEdge[88, 166] -> 
             RGBColor[
              0.8523652692557177, 0.3906026653424749, 0.19727300714892185`], 
             UndirectedEdge[9, 44] -> 
             RGBColor[
              0.5359104641208152, 0.634115283121385, 0.9566079813217554], 
             UndirectedEdge[76, 459] -> 
             RGBColor[
              0.40093570974009674`, 0.5216920929873327, 0.9467682467844796], 
             UndirectedEdge[254, 325] -> 
             RGBColor[
              0.20775758490962407`, 0.33569677270467635`, 0.935142859159575], 
             UndirectedEdge[171, 433] -> 
             RGBColor[
              0.2936242383072788, 0.42439846992600005`, 0.9400895764803525], 
             UndirectedEdge[112, 447] -> 
             RGBColor[
              0.2473817363738829, 0.37734426820991973`, 0.9373993959667855], 
             UndirectedEdge[199, 359] -> 
             RGBColor[
              0.364147570424561, 0.48982805573786037`, 0.9444241390777679], 
             UndirectedEdge[74, 224] -> 
             RGBColor[
              0.2903501525391211, 0.42250679795452123`, 0.9398463837013205], 
             UndirectedEdge[292, 386] -> 
             RGBColor[
              0.17894881608916835`, 0.3054169300929359, 0.9335022423940041], 
             UndirectedEdge[112, 195] -> 
             RGBColor[
              0.25920772540956155`, 0.3897741324974299, 0.9380728685473844], 
             UndirectedEdge[97, 408] -> 
             RGBColor[
              0.2271195205155527, 0.3560473946441286, 0.9362454927489157], 
             UndirectedEdge[236, 422] -> 
             RGBColor[
              0.26066758061653217`, 0.39130853288012224`, 0.9381560051417591],
              UndirectedEdge[27, 114] -> 
             RGBColor[
              0.5063987002640795, 0.610156303732676, 0.9542847071658003], 
             UndirectedEdge[110, 355] -> 
             RGBColor[
              0.30021105187484454`, 0.43102571577490256`, 0.9404755205872981],
              UndirectedEdge[104, 215] -> 
             RGBColor[
              0.26534838496499225`, 0.39622835503049064`, 0.9384225700247744],
              UndirectedEdge[80, 406] -> 
             RGBColor[
              0.8900806471760057, 0.9077659645302347, 0.6988562638191269], 
             UndirectedEdge[276, 292] -> 
             RGBColor[
              0.39925539426111123`, 0.5037247474643232, 0.9483475509136101], 
             UndirectedEdge[425, 466] -> 
             RGBColor[
              0.4394255113443823, 0.5536672437102792, 0.9495973233231294], 
             UndirectedEdge[164, 309] -> 
             RGBColor[
              0.9052777371288019, 0.5616050038337315, 0.3236174733815438], 
             UndirectedEdge[95, 137] -> 
             RGBColor[
              0.22358173079098384`, 0.35232895333478276`, 0.9360440208577924],
              UndirectedEdge[119, 426] -> 
             RGBColor[
              0.9304108836330538, 0.9448589600540273, 0.8960699725342486], 
             UndirectedEdge[238, 431] -> 
             RGBColor[
              0.38434692528377257`, 0.5073237216678145, 0.9457112241078087], 
             UndirectedEdge[93, 266] -> 
             RGBColor[
              0.2794030113306438, 0.41100065845557043`, 0.9392229602043418], 
             UndirectedEdge[15, 148] -> 
             RGBColor[
              0.2369473179686802, 0.36637703288571377`, 0.9368051712749479], 
             UndirectedEdge[225, 470] -> 
             RGBColor[
              0.26486570011979793`, 0.3957210226542046, 0.9383950818369088], 
             UndirectedEdge[249, 296] -> 
             RGBColor[
              0.3014838445951241, 0.4337768875889444, 0.9404962532659576], 
             UndirectedEdge[273, 421] -> 
             RGBColor[
              0.236299010735822, 0.36569562087892715`, 0.9367682511371211], 
             UndirectedEdge[150, 159] -> 
             RGBColor[
              0.821097410502475, 0.1631695188320622, 0.16783621016427433`], 
             UndirectedEdge[85, 407] -> 
             RGBColor[
              0.2142869484175896, 0.3425595477371053, 0.9355146967520258], 
             UndirectedEdge[71, 388] -> 
             RGBColor[
              0.8509768197746642, 0.8842586853652235, 0.9761468351078537], 
             UndirectedEdge[61, 435] -> 
             RGBColor[
              0.2909721876561818, 0.42176628331072286`, 0.9399328603098349], 
             UndirectedEdge[10, 177] -> 
             RGBColor[
              0.21382948684753797`, 0.34207872662224226`, 0.9354886449923652],
              UndirectedEdge[16, 52] -> 
             RGBColor[
              0.6198385630520318, 0.4001930339226935, 0.5644333341255259], 
             UndirectedEdge[25, 459] -> 
             RGBColor[
              0.35196069990557133`, 0.47927240102423385`, 0.9436476024647243],
              UndirectedEdge[105, 453] -> 
             RGBColor[
              0.265106051538209, 0.39597364723411466`, 0.9384087694946193], 
             UndirectedEdge[61, 384] -> 
             RGBColor[
              0.3038237458344487, 0.43527408579193255`, 0.9406647375359107], 
             UndirectedEdge[104, 323] -> 
             RGBColor[
              0.2429591667599799, 0.3726958671385986, 0.9371475371698791], 
             UndirectedEdge[150, 406] -> 
             RGBColor[
              0.9060315184464693, 0.5729271685521393, 0.29311167174990027`], 
             UndirectedEdge[413, 493] -> 
             RGBColor[
              0.9837066431260291, 0.9560378233723712, 0.44758049868418615`], 
             UndirectedEdge[94, 254] -> 
             RGBColor[
              0.5959586642234989, 0.6660886180136586, 0.9485638237828649], 
             UndirectedEdge[431, 487] -> 
             RGBColor[
              0.5139856537736541, 0.6161859985800608, 0.9549178263261018], 
             UndirectedEdge[234, 332] -> 
             RGBColor[
              0.3953853483413155, 0.5168846489129837, 0.946414582664141], 
             UndirectedEdge[82, 89] -> 
             RGBColor[
              0.2718901700216876, 0.4031041858982062, 0.9387951150060494], 
             UndirectedEdge[154, 255] -> 
             RGBColor[
              0.3535633647009796, 0.4806605487177418, 0.9437497228483069], 
             UndirectedEdge[22, 324] -> 
             RGBColor[
              0.41054698853962773`, 0.5300168996065678, 0.9473806689706655], 
             UndirectedEdge[105, 112] -> 
             RGBColor[
              0.2470843980758506, 0.3770317468063509, 0.9373824629905851], 
             UndirectedEdge[6, 406] -> 
             RGBColor[
              0.9091541002347256, 0.9227285742942248, 0.700740799303404], 
             UndirectedEdge[396, 422] -> 
             RGBColor[
              0.6137790328303492, 0.6759479174311498, 0.7377723993512193], 
             UndirectedEdge[409, 456] -> 
             RGBColor[
              0.23260709522442666`, 0.3618151835954873, 0.9365580020104467], 
             UndirectedEdge[91, 473] -> 
             RGBColor[
              0.32723005291391416`, 0.4578519575985201, 0.9420717875068684], 
             UndirectedEdge[369, 379] -> 
             RGBColor[
              0.3646233115605392, 0.49024011879839996`, 0.944454452882271], 
             UndirectedEdge[353, 441] -> 
             RGBColor[
              0.5448974710637005, 0.6413248437593597, 0.9573393706579376], 
             UndirectedEdge[165, 481] -> 
             RGBColor[
              0.3711249763330434, 0.49587153404117, 0.9448687332123786], 
             UndirectedEdge[185, 318] -> 
             RGBColor[
              0.3129435362062064, 0.4431846498190406, 0.9412454229080396], 
             UndirectedEdge[264, 445] -> 
             RGBColor[
              0.23221275436386601`, 0.3614007063483834, 0.9365355448818129], 
             UndirectedEdge[258, 297] -> 
             RGBColor[
              0.4463933258988235, 0.5592718859080008, 0.9501602626281445], 
             UndirectedEdge[57, 139] -> 
             RGBColor[
              0.5826390838232848, 0.6720516816961779, 0.9602866294373078], 
             UndirectedEdge[447, 463] -> 
             RGBColor[
              0.2567986541117429, 0.38724204581948013`, 0.9379356755008752], 
             UndirectedEdge[9, 26] -> 
             RGBColor[
              0.4808866078491948, 0.5876336896788764, 0.952776616899017], 
             UndirectedEdge[181, 262] -> 
             RGBColor[
              0.4483915053521436, 0.5621777184210172, 0.9499628984888329], 
             UndirectedEdge[203, 291] -> 
             RGBColor[
              0.5947468881404891, 0.681688814806365, 0.9613714325118958], 
             UndirectedEdge[45, 254] -> 
             RGBColor[
              0.25964036057789125`, 0.3902288594899984, 0.9380975064801944], 
             UndirectedEdge[240, 412] -> 
             RGBColor[
              0.2495035202048371, 0.3795743975451175, 0.9375202284170604], 
             UndirectedEdge[208, 258] -> 
             RGBColor[
              0.3477704837485026, 0.4756430463953687, 0.9433806055964585], 
             UndirectedEdge[293, 420] -> 
             RGBColor[
              0.9614575711812897, 0.9707757002112165, 0.9501264579014013], 
             UndirectedEdge[85, 346] -> 
             RGBColor[
              0.21604910573121133`, 0.34441168680094847`, 0.9356150490041585],
              UndirectedEdge[65, 166] -> 
             RGBColor[
              0.9117926198146232, 0.6283236796935395, 0.2910857426521841], 
             UndirectedEdge[254, 347] -> 
             RGBColor[
              0.20771262472504887`, 0.3356495167000475, 0.935140298743576], 
             UndirectedEdge[236, 292] -> 
             RGBColor[
              0.23314689454244097`, 0.36238254690397387`, 0.9365887427830462],
              UndirectedEdge[100, 401] -> 
             RGBColor[
              0.8523336151346661, 0.7939714926704016, 0.620783111215081], 
             UndirectedEdge[146, 400] -> 
             RGBColor[
              0.276927529490606, 0.4083987700870767, 0.9390819851756989], 
             UndirectedEdge[104, 153] -> 
             RGBColor[
              0.24575331572793313`, 0.3756326948631943, 0.937306659820031], 
             UndirectedEdge[216, 281] -> 
             RGBColor[
              0.2553973215721218, 0.3857691564707237, 0.9378558716858294], 
             UndirectedEdge[123, 125] -> 
             RGBColor[
              0.2078185513522534, 0.33576085230137553`, 0.9351463311082908], 
             UndirectedEdge[78, 358] -> 
             RGBColor[
              0.22252765585105994`, 0.3512210537407115, 0.9359839928493279], 
             UndirectedEdge[313, 478] -> 
             RGBColor[
              0.26649991887633445`, 0.3974386901827782, 0.9384881481774836], 
             UndirectedEdge[368, 401] -> 
             RGBColor[
              0.5907770138305127, 0.6754225066218276, 0.9626395084549426], 
             UndirectedEdge[106, 369] -> 
             RGBColor[
              0.46890138102995677`, 0.5788082013626439, 0.9515831360340911], 
             UndirectedEdge[111, 146] -> 
             RGBColor[
              0.2655122364597581, 0.39640057334027434`, 0.9384319011250047], 
             UndirectedEdge[129, 266] -> 
             RGBColor[
              0.32256025857167225`, 0.4520297101069751, 0.9418393155552645], 
             UndirectedEdge[99, 278] -> 
             RGBColor[
              0.9709926371751241, 0.9748878865987054, 0.7597061890098948], 
             UndirectedEdge[147, 171] -> 
             RGBColor[
              0.2566176973332457, 0.3870518487719572, 0.9379253702800414], 
             UndirectedEdge[164, 166] -> 
             RGBColor[
              0.8278225605966679, 0.21486196943559147`, 0.17427622148944416`],
              UndirectedEdge[129, 433] -> 
             RGBColor[
              0.3405530126531223, 0.4693916356931953, 0.94292071472042], 
             UndirectedEdge[179, 283] -> 
             RGBColor[
              0.18007164814629245`, 0.3065970977766376, 0.9335661860185762], 
             UndirectedEdge[136, 291] -> 
             RGBColor[
              0.8119439013123007, 0.853362410017863, 0.9518331785269256], 
             UndirectedEdge[321, 479] -> 
             RGBColor[
              0.37233306340343797`, 0.49691791834132404`, 0.9449457114522347],
              UndirectedEdge[181, 239] -> 
             RGBColor[
              0.38581385669695734`, 0.5085943039277986, 0.9458046956803003], 
             UndirectedEdge[102, 330] -> 
             RGBColor[
              0.2914935550351155, 0.4237085864737168, 0.939911498781955], 
             UndirectedEdge[406, 413] -> 
             RGBColor[
              0.9822272031257195, 0.951710324271208, 0.3854564695648335], 
             UndirectedEdge[37, 310] -> 
             RGBColor[
              0.30119863479716524`, 0.4339092406412282, 0.9404641887170249], 
             UndirectedEdge[203, 439] -> 
             RGBColor[
              0.6977395599110665, 0.7624782824674698, 0.971548992789666], 
             UndirectedEdge[320, 375] -> 
             RGBColor[
              0.9734019680069053, 0.9789510679067093, 0.8970939407523506], 
             UndirectedEdge[42, 407] -> 
             RGBColor[
              0.22341630550160935`, 0.352155080867081, 0.9360346001322872], 
             UndirectedEdge[131, 374] -> 
             RGBColor[
              0.2576696859737398, 0.38815755553304865`, 0.9379852794768397], 
             UndirectedEdge[387, 403] -> 
             RGBColor[
              0.8520128910253049, 0.8851986373727346, 0.9856507029983317], 
             UndirectedEdge[65, 348] -> 
             RGBColor[
              0.9726882187211612, 0.9195330900145834, 0.3483993164391773], 
             UndirectedEdge[217, 498] -> 
             RGBColor[
              0.3908046357587574, 0.5126843292737169, 0.9461870095342384], 
             UndirectedEdge[40, 397] -> 
             RGBColor[
              0.37237410523066483`, 0.4969534667092458, 0.9449483266011737], 
             UndirectedEdge[226, 292] -> 
             RGBColor[
              0.17919781223777545`, 0.3056786408323896, 0.9335164223563106], 
             UndirectedEdge[53, 257] -> 
             RGBColor[
              0.9176828698612274, 0.692200433274696, 0.28359567952116765`], 
             UndirectedEdge[220, 429] -> 
             RGBColor[
              0.3162555864633567, 0.44694588722950834`, 0.9414237848069549], 
             UndirectedEdge[139, 425] -> 
             RGBColor[
              0.469689014710176, 0.5782365190979204, 0.9519797771669503], 
             UndirectedEdge[317, 418] -> 
             RGBColor[
              0.9309369071770426, 0.7734480360326559, 0.5728708276939365], 
             UndirectedEdge[482, 496] -> 
             RGBColor[
              0.31768549080207875`, 0.4466395905233832, 0.9415714600344062], 
             UndirectedEdge[117, 466] -> 
             RGBColor[
              0.44229172329685795`, 0.5561498124435122, 0.9497799558142495], 
             UndirectedEdge[82, 105] -> 
             RGBColor[
              0.25209194686734443`, 0.382294998083142, 0.9376676354862561], 
             UndirectedEdge[239, 453] -> 
             RGBColor[
              0.31761867457160725`, 0.44726749674536337`, 0.9415420928317004],
              UndirectedEdge[274, 340] -> 
             RGBColor[
              0.40008441142440987`, 0.5206990676119785, 0.9467846461754836], 
             UndirectedEdge[311, 484] -> 
             RGBColor[
              0.8698742834500395, 0.8946869579845022, 0.7215434088969761], 
             UndirectedEdge[44, 140] -> 
             RGBColor[
              0.4981556569200065, 0.6034642298010868, 0.9536357845984921], 
             UndirectedEdge[139, 466] -> 
             RGBColor[
              0.5337716765091578, 0.6323789189869576, 0.9564396081263286], 
             UndirectedEdge[22, 481] -> 
             RGBColor[
              0.38481661217346425`, 0.507730540844516, 0.9457411521410921], 
             UndirectedEdge[45, 386] -> 
             RGBColor[
              0.23085473585284239`, 0.35997334278995086`, 0.9364582077366184],
              UndirectedEdge[40, 220] -> 
             RGBColor[
              0.36255668140028763`, 0.48845010762544216`, 0.9443227690359091],
              UndirectedEdge[237, 489] -> 
             RGBColor[
              0.9480949935467251, 0.959065305031835, 0.9023385571076953], 
             UndirectedEdge[61, 64] -> 
             RGBColor[
              0.3058305702683475, 0.43738338551197825`, 0.9407790232185906], 
             UndirectedEdge[82, 296] -> 
             RGBColor[
              0.28584922180975014`, 0.4173439077491774, 0.9396058846276822], 
             UndirectedEdge[27, 277] -> 
             RGBColor[
              0.6417102241932708, 0.7180330594388474, 0.9662874050409727], 
             UndirectedEdge[416, 427] -> 
             RGBColor[
              0.2705169061527906, 0.4016607985020373, 0.9387169096602777], 
             UndirectedEdge[59, 82] -> 
             RGBColor[
              0.25023486400687867`, 0.3803430862509384, 0.9375618773646605], 
             UndirectedEdge[271, 444] -> 
             RGBColor[
              0.26354918336029226`, 0.3943372800679805, 0.938320108155067], 
             UndirectedEdge[6, 486] -> 
             RGBColor[
              0.8813087089314302, 0.9081956582870432, 0.9885412054830938], 
             UndirectedEdge[171, 265] -> 
             RGBColor[
              0.29137836531202577`, 0.42245320761837074`, 0.9399464714390425],
              UndirectedEdge[219, 369] -> 
             RGBColor[
              0.47310816162837227`, 0.5822234553657439, 0.9519143092127434], 
             UndirectedEdge[244, 355] -> 
             RGBColor[
              0.3355739158146536, 0.46507899226839733`, 0.9426034510727153], 
             UndirectedEdge[450, 500] -> 
             RGBColor[
              0.8186005728713881, 0.14397773067830186`, 0.16544523562897076`],
              UndirectedEdge[18, 243] -> 
             RGBColor[
              0.8618450148200435, 0.43551288339499367`, 0.2052561643181862], 
             UndirectedEdge[377, 449] -> 
             RGBColor[
              0.8547039434845443, 0.8865518671157351, 0.9452111853810878], 
             UndirectedEdge[7, 173] -> 
             RGBColor[
              0.9116225315818571, 0.9310453814508525, 0.9449853696775101], 
             UndirectedEdge[3, 8] -> 
             RGBColor[
              0.5409798313044035, 0.6382308237734111, 0.9570070604761514], 
             UndirectedEdge[405, 469] -> 
             RGBColor[
              0.9272216806853377, 0.724366095358756, 0.3974739978928766], 
             UndirectedEdge[148, 190] -> 
             RGBColor[
              0.2438827304039313, 0.37366659108570865`, 0.9372001327531121], 
             UndirectedEdge[180, 216] -> 
             RGBColor[
              0.2680084621160904, 0.3990242647749275, 0.9385740574832979], 
             UndirectedEdge[257, 317] -> 
             RGBColor[
              0.8711268784377937, 0.5076990787158229, 0.21417744721027115`], 
             UndirectedEdge[49, 462] -> 
             RGBColor[
              0.4770465403942916, 0.586326898050649, 0.9519739976203461], 
             UndirectedEdge[223, 258] -> 
             RGBColor[
              0.3816431136278576, 0.5049818159089863, 0.9455389396199805], 
             UndirectedEdge[260, 440] -> 
             RGBColor[
              0.28362513416460355`, 0.4154383772521112, 0.9394634038536649], 
             UndirectedEdge[262, 332] -> 
             RGBColor[
              0.43913893362174417`, 0.5541636058359223, 0.9493733327998998], 
             UndirectedEdge[283, 386] -> 
             RGBColor[
              0.18007057961528944`, 0.30659597468280464`, 0.9335661251673164],
              UndirectedEdge[40, 289] -> 
             RGBColor[
              0.41278560473143366`, 0.5319558764357888, 0.9475233116148768], 
             UndirectedEdge[95, 430] -> 
             RGBColor[
              0.23341097282813747`, 0.36266010992577125`, 0.9366037816507478],
              UndirectedEdge[274, 334] -> 
             RGBColor[
              0.4327691697643524, 0.5490089625023165, 0.9488672900749079], 
             UndirectedEdge[75, 158] -> 
             RGBColor[
              0.3512349205505469, 0.4786437674256428, 0.9436013564460036], 
             UndirectedEdge[233, 476] -> 
             RGBColor[
              0.8458261121541704, 0.35324515591315253`, 0.19151644279301172`],
              UndirectedEdge[240, 416] -> 
             RGBColor[
              0.2590796192147955, 0.38963948476432886`, 0.9380655730891085], 
             UndirectedEdge[260, 280] -> 
             RGBColor[
              0.27123440340689225`, 0.4024149336080515, 0.9387577700674566], 
             UndirectedEdge[11, 193] -> 
             RGBColor[
              0.2633649248993141, 0.3941436127428313, 0.9383096149083003], 
             UndirectedEdge[3, 162] -> 
             RGBColor[
              0.4618487252450588, 0.5739886270587315, 0.9507775699403673], 
             UndirectedEdge[117, 338] -> 
             RGBColor[
              0.3505903006321732, 0.47808543005188675`, 0.9435602818348199], 
             UndirectedEdge[40, 472] -> 
             RGBColor[
              0.35732343693452717`, 0.4839173342997152, 0.9439893113261273], 
             UndirectedEdge[101, 355] -> 
             RGBColor[
              0.424769765192925, 0.5405027707410431, 0.9487934456872616], 
             UndirectedEdge[47, 364] -> 
             RGBColor[
              0.24525016381875867`, 0.3751038503049783, 0.93727800606315], 
             UndirectedEdge[377, 484] -> 
             RGBColor[
              0.9869984046810305, 0.9863165950507087, 0.692275872605006], 
             UndirectedEdge[21, 227] -> 
             RGBColor[
              0.9132594664564218, 0.6494694053055374, 0.28579138582517527`], 
             UndirectedEdge[158, 441] -> 
             RGBColor[
              0.4038268661048062, 0.5241962673166999, 0.9469524687114896], 
             UndirectedEdge[201, 222] -> 
             RGBColor[
              0.3735862388275236, 0.49760697262793063`, 0.9450400762157048], 
             UndirectedEdge[107, 477] -> 
             RGBColor[
              0.21467165996386678`, 0.3429639039643634, 0.9355366055054566], 
             UndirectedEdge[89, 239] -> 
             RGBColor[
              0.31821611673686917`, 0.4478954463410748, 0.9415761162791756], 
             UndirectedEdge[63, 275] -> 
             RGBColor[
              0.41651977831287657`, 0.5351902299070133, 0.9477612498534863], 
             UndirectedEdge[133, 344] -> 
             RGBColor[
              0.404458323018091, 0.5244601408973477, 0.9470709156438875], 
             UndirectedEdge[153, 356] -> 
             RGBColor[
              0.2571354474729763, 0.3875960369960689, 0.9379548553845563], 
             UndirectedEdge[151, 188] -> 
             RGBColor[
              0.32203573450029344`, 0.4531724542663287, 0.9417474171352478], 
             UndirectedEdge[140, 204] -> 
             RGBColor[
              0.5007635578511195, 0.6055814412615623, 0.9538410881128452], 
             UndirectedEdge[154, 369] -> 
             RGBColor[
              0.36474431369771637`, 0.4903449247678786, 0.944462163031454], 
             UndirectedEdge[16, 179] -> 
             RGBColor[
              0.29140560923354364`, 0.4148201691111312, 0.940228554342059], 
             UndirectedEdge[161, 341] -> 
             RGBColor[
              0.9919526646253864, 0.9838559907810486, 0.4794106025405692], 
             UndirectedEdge[48, 408] -> 
             RGBColor[
              0.21500770505426564`, 0.34331710866086196`, 0.9355557427762207],
              UndirectedEdge[153, 263] -> 
             RGBColor[
              0.25916680795964386`, 0.3897311256632503, 0.9380705383591434], 
             UndirectedEdge[62, 132] -> 
             RGBColor[
              0.9037259559281465, 0.5621573598635239, 0.4887023579770914], 
             UndirectedEdge[82, 225] -> 
             RGBColor[
              0.2662639580467382, 0.39719068039009175`, 0.9384747105573108], 
             UndirectedEdge[216, 465] -> 
             RGBColor[
              0.27425578181697063`, 0.40559059388349944`, 0.9389298330981818],
              UndirectedEdge[119, 489] -> 
             RGBColor[
              0.9903724843514137, 0.9902867891105125, 0.8092163797162932], 
             UndirectedEdge[287, 295] -> 
             RGBColor[
              0.2196997994484176, 0.34824879736508285`, 0.9358229506106359], 
             UndirectedEdge[28, 417] -> 
             RGBColor[
              0.8329443683967894, 0.8698408046783143, 0.9576048606613091], 
             UndirectedEdge[148, 351] -> 
             RGBColor[
              0.26485064633186906`, 0.3957052001686261, 0.9383942245459564], 
             UndirectedEdge[218, 336] -> 
             RGBColor[
              0.2271057420788739, 0.35603291263357584`, 0.9362447080873302], 
             UndirectedEdge[127, 254] -> 
             RGBColor[
              0.23123903037733173`, 0.3603772607008694, 0.9364800927412753], 
             UndirectedEdge[303, 473] -> 
             RGBColor[
              0.31604489027716914`, 0.44784149062043943`, 0.9413708849892584],
              UndirectedEdge[99, 267] -> 
             RGBColor[
              0.9913420700473246, 0.9817665875606343, 0.479566100729647], 
             UndirectedEdge[48, 145] -> 
             RGBColor[
              0.21408452170973263`, 0.34234678443255295`, 0.9355031688504769],
              UndirectedEdge[224, 342] -> 
             RGBColor[
              0.2794767176957349, 0.41107812851853454`, 0.939227157672795], 
             UndirectedEdge[193, 232] -> 
             RGBColor[
              0.32200467219797546`, 0.4513904780484862, 0.9418096996419872], 
             UndirectedEdge[216, 343] -> 
             RGBColor[
              0.2793867448603114, 0.4109835613638972, 0.9392220338529205], 
             UndirectedEdge[277, 449] -> 
             RGBColor[
              0.7498021540184663, 0.8044704085174408, 0.9756969294792002], 
             UndirectedEdge[257, 418] -> 
             RGBColor[
              0.9186634619525802, 0.7177171878043327, 0.5626295641489729], 
             UndirectedEdge[45, 422] -> 
             RGBColor[
              0.2583972380161019, 0.3889222588590351, 0.9380267124893356], 
             UndirectedEdge[133, 235] -> 
             RGBColor[
              0.3511076947395869, 0.47853357082274445`, 0.9435932497298307], 
             UndirectedEdge[145, 183] -> 
             RGBColor[
              0.21281275410739692`, 0.3410100760477749, 0.9354307435669353], 
             UndirectedEdge[196, 496] -> 
             RGBColor[
              0.2862944389618104, 0.41824398583767475`, 0.9396154168129832], 
             UndirectedEdge[115, 136] -> 
             RGBColor[
              0.9450645210490293, 0.9581750855858149, 0.964884369377244], 
             UndirectedEdge[267, 413] -> 
             RGBColor[
              0.981449315920919, 0.9490863280728146, 0.38243452466585603`], 
             UndirectedEdge[217, 340] -> 
             RGBColor[
              0.32857716094804046`, 0.4590187548700618, 0.9421576240396021], 
             UndirectedEdge[335, 383] -> 
             RGBColor[
              0.3028573462736385, 0.4337853452642071, 0.940627021112898], 
             UndirectedEdge[80, 493] -> 
             RGBColor[
              0.8915600871763152, 0.912093463631398, 0.7609802929384797], 
             UndirectedEdge[307, 372] -> 
             RGBColor[
              0.47013131999468205`, 0.580712810603117, 0.9514296061392018], 
             UndirectedEdge[18, 434] -> 
             RGBColor[
              0.9377932493402739, 0.7792631319127137, 0.510349510564296], 
             UndirectedEdge[130, 179] -> 
             RGBColor[
              0.17892806853100302`, 0.30539512309383293`, 0.93350106085126], 
             UndirectedEdge[20, 228] -> 
             RGBColor[
              0.9388076655030091, 0.7780938721344945, 0.3568427286125849], 
             UndirectedEdge[297, 311] -> 
             RGBColor[
              0.6331105387907436, 0.7114259084862791, 0.9653543852266682], 
             UndirectedEdge[127, 200] -> 
             RGBColor[
              0.5634039093287206, 0.4987072281229762, 0.587570692606852], 
             UndirectedEdge[54, 391] -> 
             RGBColor[
              0.23492401226674847`, 0.36425041030799266`, 0.9366899470084354],
              UndirectedEdge[347, 368] -> 
             RGBColor[
              0.2935143249909316, 0.4166464351270609, 0.9403629270800464], 
             UndirectedEdge[22, 182] -> 
             RGBColor[
              0.4150015938204914, 0.5338752548058805, 0.9476645124801093], 
             UndirectedEdge[96, 216] -> 
             RGBColor[
              0.2810238579235662, 0.4127042709923413, 0.9393152650199811], 
             UndirectedEdge[340, 363] -> 
             RGBColor[
              0.37112295968624204`, 0.49586978732307024`, 0.9448686047134276],
              UndirectedEdge[71, 490] -> 
             RGBColor[
              0.8731675486403643, 0.8997516085621015, 0.891254202422064], 
             UndirectedEdge[111, 201] -> 
             RGBColor[
              0.28877500860148286`, 0.42085122180616963`, 0.9397566815842886],
              UndirectedEdge[261, 484] -> 
             RGBColor[
              0.9364392575786439, 0.7675671876801757, 0.34462692180178206`], 
             UndirectedEdge[416, 499] -> 
             RGBColor[
              0.26112616120390136`, 0.3917905301531358, 0.9381821206278006], 
             UndirectedEdge[42, 430] -> 
             RGBColor[
              0.2361066473396595, 0.36549343475301654`, 0.9367572963262859], 
             UndirectedEdge[6, 81] -> 
             RGBColor[
              0.825653983169494, 0.8638180906717614, 0.9832328080563602], 
             UndirectedEdge[282, 353] -> 
             RGBColor[
              0.6236604649477651, 0.705354686885191, 0.9635159828256973], 
             UndirectedEdge[275, 441] -> 
             RGBColor[
              0.43191818188119013`, 0.5485275531316196, 0.9487424225125856], 
             UndirectedEdge[50, 255] -> 
             RGBColor[
              0.41926177634102413`, 0.5375652107821666, 0.9479359675431862], 
             UndirectedEdge[110, 217] -> 
             RGBColor[
              0.29571753049971145`, 0.4271336534107135, 0.9401891973787395], 
             UndirectedEdge[30, 110] -> 
             RGBColor[
              0.26982326266389456`, 0.40093173521567016`, 0.9386774076897386],
              UndirectedEdge[77, 482] -> 
             RGBColor[
              0.4826496570055525, 0.5883007255405965, 0.9531265853256541], 
             UndirectedEdge[52, 326] -> 
             RGBColor[
              0.8554852780065134, 0.4011124754177182, 0.19973320349637064`], 
             UndirectedEdge[44, 247] -> 
             RGBColor[
              0.4958443155073958, 0.6015877787175854, 0.9534538273357688], 
             UndirectedEdge[337, 348] -> 
             RGBColor[
              0.9100611549268829, 0.8839036332529456, 0.6426467308354947], 
             UndirectedEdge[48, 78] -> 
             RGBColor[
              0.21346998781254425`, 0.3417008703429085, 0.9354681720541533], 
             UndirectedEdge[420, 432] -> 
             RGBColor[
              0.933633649289228, 0.949068614748616, 0.9640782438285385], 
             UndirectedEdge[469, 474] -> 
             RGBColor[
              0.9267639161265591, 0.7252718203703219, 0.4846569116242533], 
             UndirectedEdge[172, 366] -> 
             RGBColor[
              0.3083293758751098, 0.43743710670339436`, 0.941015524989468], 
             UndirectedEdge[102, 415] -> 
             RGBColor[
              0.28177512151681394`, 0.41349389666170766`, 0.9393580483702217],
              UndirectedEdge[414, 485] -> 
             RGBColor[
              0.26132957932407624`, 0.39200433549489333`, 0.9381937049888145],
              UndirectedEdge[102, 193] -> 
             RGBColor[
              0.2821746373958698, 0.4139138131813651, 0.9393808002085031], 
             UndirectedEdge[128, 498] -> 
             RGBColor[
              0.4783163619958606, 0.5873577964316139, 0.9520739626283314], 
             UndirectedEdge[150, 443] -> 
             RGBColor[
              0.8779783180841267, 0.47195372718941886`, 0.21716686938390278`],
              UndirectedEdge[2, 230] -> 
             RGBColor[
              0.21816285424353754`, 0.34663337050679954`, 0.9357354238549247],
              UndirectedEdge[367, 416] -> 
             RGBColor[
              0.24568937276892794`, 0.3755654867590621, 0.9373030183631108], 
             UndirectedEdge[61, 473] -> 
             RGBColor[
              0.3253289757704718, 0.4562053401277858, 0.9419506525523447], 
             UndirectedEdge[56, 164] -> 
             RGBColor[
              0.8270991589089857, 0.20930158706742483`, 0.17358349121635427`],
              UndirectedEdge[20, 388] -> 
             RGBColor[
              0.9153530643766437, 0.7639768167303482, 0.6006827363489642], 
             UndirectedEdge[195, 296] -> 
             RGBColor[
              0.29178587282524443`, 0.4235837043718764, 0.9399439681205266], 
             UndirectedEdge[135, 391] -> 
             RGBColor[
              0.24587699790050546`, 0.37576269266847045`, 0.9373137033367878],
              UndirectedEdge[310, 399] -> 
             RGBColor[
              0.26912901254486776`, 0.40020203432257306`, 0.938637871172511], 
             UndirectedEdge[150, 476] -> 
             RGBColor[
              0.834968541704233, 0.26978911161722496`, 0.18111922106827977`], 
             UndirectedEdge[142, 222] -> 
             RGBColor[
              0.5711190039988594, 0.6615355308329243, 0.9600580034664301], 
             UndirectedEdge[48, 404] -> 
             RGBColor[
              0.21047959213928613`, 0.3385577748882776, 0.9352978734444553], 
             UndirectedEdge[330, 415] -> 
             RGBColor[
              0.29673111972249494`, 0.4292135990409338, 0.9402097703426187], 
             UndirectedEdge[326, 495] -> 
             RGBColor[
              0.8586889913459645, 0.42573762002087545`, 0.2028010830083056], 
             UndirectedEdge[36, 382] -> 
             RGBColor[
              0.26830699274776615`, 0.39933803939675394`, 0.9385910583611354],
              UndirectedEdge[31, 289] -> 
             RGBColor[
              0.4462046575439149, 0.5609017802915265, 0.9496527441087801], 
             UndirectedEdge[436, 487] -> 
             RGBColor[
              0.5261755956139467, 0.6262120783166807, 0.9558416168128965], 
             UndirectedEdge[251, 427] -> 
             RGBColor[
              0.2690226652198594, 0.4000902565411794, 0.9386318148496786], 
             UndirectedEdge[108, 437] -> 
             RGBColor[
              0.27047057871071917`, 0.40161210542309067`, 0.938714271380987], 
             UndirectedEdge[258, 397] -> 
             RGBColor[
              0.36598524788401654`, 0.49141975958888606`, 0.94454123426049], 
             UndirectedEdge[308, 422] -> 
             RGBColor[
              0.20647914454706495`, 0.3343530508258261, 0.9350700538722102], 
             UndirectedEdge[16, 292] -> 
             RGBColor[
              0.29142635679170903`, 0.41484197611023416`, 0.9402297358848033],
              UndirectedEdge[68, 317] -> 
             RGBColor[
              0.8516933912786147, 0.35903009244942585`, 0.19559553620276254`],
              UndirectedEdge[34, 468] -> 
             RGBColor[
              0.51106504599871, 0.6139446534165288, 0.9546520589954179], 
             UndirectedEdge[350, 383] -> 
             RGBColor[
              0.34555625661750283`, 0.4737251941447882, 0.9432395170016354], 
             UndirectedEdge[190, 342] -> 
             RGBColor[
              0.25404838087349885`, 0.38435133426869084`, 0.9377790515086218],
              UndirectedEdge[61, 303] -> 
             RGBColor[
              0.31454260624684305`, 0.4465402877003618, 0.9412751607792637], 
             UndirectedEdge[214, 421] -> 
             RGBColor[
              0.18943186031713002`, 0.3164352742399168, 0.9340992362545124], 
             UndirectedEdge[219, 370] -> 
             RGBColor[
              0.5588561185016121, 0.6527435990376659, 0.9584143472873132], 
             UndirectedEdge[91, 366] -> 
             RGBColor[
              0.29631757138809034`, 0.4270330853875859, 0.9402501434291768], 
             UndirectedEdge[273, 477] -> 
             RGBColor[
              0.2691065215645594, 0.4001783948762585, 0.9386365903444549], 
             UndirectedEdge[153, 323] -> 
             RGBColor[
              0.24213881509518778`, 0.3718336255256024, 0.9371008193561707], 
             UndirectedEdge[170, 433] -> 
             RGBColor[
              0.31109341012253816`, 0.4427596771133032, 0.9410844199719078], 
             UndirectedEdge[1, 54] -> 
             RGBColor[
              0.24744314331957223`, 0.3774088108032645, 0.937402893001499], 
             UndirectedEdge[277, 377] -> 
             RGBColor[
              0.8762033212681233, 0.9033473444415901, 0.9473540424354466], 
             UndirectedEdge[307, 417] -> 
             RGBColor[
              0.5854211152910297, 0.6734114544902967, 0.9611201594979415], 
             UndirectedEdge[58, 371] -> 
             RGBColor[
              0.3390278312734188, 0.4680706002399412, 0.9428235315115703], 
             UndirectedEdge[9, 269] -> 
             RGBColor[
              0.512041509774998, 0.614618499836106, 0.9547617797005311], 
             UndirectedEdge[184, 453] -> 
             RGBColor[
              0.2706693526642461, 0.401821029451244, 0.9387255912635806], 
             UndirectedEdge[42, 97] -> 
             RGBColor[
              0.23210438822814727`, 0.3612868066689332, 0.936529373590697], 
             UndirectedEdge[161, 405] -> 
             RGBColor[
              0.9921723207517021, 0.9843258130245969, 0.5033188163295588], 
             UndirectedEdge[304, 429] -> 
             RGBColor[
              0.316081007071654, 0.4467946753350308, 0.9414126607624902], 
             UndirectedEdge[127, 130] -> 
             RGBColor[
              0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993],
              UndirectedEdge[318, 330] -> 
             RGBColor[
              0.32419593809646025`, 0.45501163764918373`, 0.9418862305492528],
              UndirectedEdge[393, 468] -> 
             RGBColor[
              0.4697942541627981, 0.5804391653761509, 0.9514030710822032], 
             UndirectedEdge[334, 355] -> 
             RGBColor[
              0.36575544066311605`, 0.49122071212458884`, 0.9445265911475849],
              UndirectedEdge[290, 378] -> 
             RGBColor[
              0.28478483318943354`, 0.41665729445637256`, 0.939529446997508], 
             UndirectedEdge[92, 498] -> 
             RGBColor[
              0.5355135500520953, 0.6337930503996233, 0.9565767347923217], 
             UndirectedEdge[340, 362] -> 
             RGBColor[
              0.3629480512357022, 0.4887890925060583, 0.944347706775747], 
             UndirectedEdge[58, 304] -> 
             RGBColor[
              0.3268378953241502, 0.4575122904046801, 0.94204679957202], 
             UndirectedEdge[51, 308] -> 
             RGBColor[
              0.1789366427891193, 0.3054041351827525, 0.9335015491425751], 
             UndirectedEdge[59, 447] -> 
             RGBColor[
              0.2443455259866942, 0.3741530185861272, 0.9372264882769058], 
             UndirectedEdge[186, 485] -> 
             RGBColor[
              0.24185580045044375`, 0.3715361591898116, 0.9370847020908353], 
             UndirectedEdge[340, 379] -> 
             RGBColor[
              0.32336688058112073`, 0.45450587189254155`, 0.941825629581892], 
             UndirectedEdge[129, 410] -> 
             RGBColor[
              0.3596323931506261, 0.48591723612258636`, 0.9441364359744873], 
             UndirectedEdge[192, 225] -> 
             RGBColor[
              0.26443196618769516`, 0.395265140791245, 0.9383703813311275], 
             UndirectedEdge[306, 420] -> 
             RGBColor[
              0.9131111718754747, 0.7098607039273219, 0.5703676016486996], 
             UndirectedEdge[16, 45] -> 
             RGBColor[
              0.343332276555383, 0.46939838880724916`, 0.9431857012274175], 
             UndirectedEdge[334, 361] -> 
             RGBColor[
              0.5235027630627838, 0.6226423570970218, 0.9560294677740079], 
             UndirectedEdge[306, 357] -> 
             RGBColor[
              0.8823608988640697, 0.5565720408834082, 0.22345710970379568`], 
             UndirectedEdge[335, 496] -> 
             RGBColor[
              0.27683085763382376`, 0.40829716183624876`, 0.9390764798564684],
              UndirectedEdge[176, 345] -> 
             RGBColor[
              0.6333349002315553, 0.7129428013259062, 0.9644594745728776], 
             UndirectedEdge[15, 78] -> 
             RGBColor[
              0.22683394628673456`, 0.35574723802318886`, 0.9362292297190538],
              UndirectedEdge[52, 210] -> 
             RGBColor[
              0.8359293793650189, 0.2771745309197725, 0.1820393202973592], 
             UndirectedEdge[392, 465] -> 
             RGBColor[
              0.2943134873153461, 0.42667251409427237`, 0.9400720897535981], 
             UndirectedEdge[354, 414] -> 
             RGBColor[
              0.3182109057650159, 0.4468883541768137, 0.941612493557471], 
             UndirectedEdge[56, 428] -> 
             RGBColor[
              0.8335035522712653, 0.25852856087297227`, 0.179716345532801], 
             UndirectedEdge[44, 425] -> 
             RGBColor[
              0.43601004951768985`, 0.5508944179345684, 0.9493284456568833], 
             UndirectedEdge[106, 468] -> 
             RGBColor[
              0.4981161809408796, 0.6034321814228589, 0.9536326769048099], 
             UndirectedEdge[142, 461] -> 
             RGBColor[
              0.8219899053555546, 0.8616442791794481, 0.9747961115925544], 
             UndirectedEdge[203, 297] -> 
             RGBColor[
              0.5269654224863035, 0.6268532953529551, 0.9559037948775195], 
             UndirectedEdge[24, 176] -> 
             RGBColor[
              0.7219583100603643, 0.7823133904412213, 0.9732561905650118], 
             UndirectedEdge[351, 356] -> 
             RGBColor[
              0.2796916905937343, 0.4113040786644009, 0.9392394000613121], 
             UndirectedEdge[315, 368] -> 
             RGBColor[
              0.2968006331253079, 0.42010055334026064`, 0.9405500774666419], 
             UndirectedEdge[278, 406] -> 
             RGBColor[
              0.969491060817788, 0.9705130400681918, 0.6951727540379807], 
             UndirectedEdge[247, 360] -> 
             RGBColor[
              0.5371888520305683, 0.6351531360172418, 0.9567086207009003], 
             UndirectedEdge[78, 145] -> 
             RGBColor[
              0.22004363289237822`, 0.3486101881149849, 0.9358425314166136], 
             UndirectedEdge[19, 466] -> 
             RGBColor[
              0.5316163498821903, 0.6306291277348275, 0.9562699329190321], 
             UndirectedEdge[60, 151] -> 
             RGBColor[
              0.2997519610227203, 0.4323886947798715, 0.9403818027857322], 
             UndirectedEdge[109, 186] -> 
             RGBColor[
              0.24483520726957755`, 0.37466770466202415`, 0.9372543749015474],
              UndirectedEdge[474, 495] -> 
             RGBColor[
              0.917649812825669, 0.658402887580602, 0.4760539940908434], 
             UndirectedEdge[36, 412] -> 
             RGBColor[
              0.24838538806776134`, 0.3783991697753788, 0.9374565524459821], 
             UndirectedEdge[259, 469] -> 
             RGBColor[
              0.8611356885897954, 0.46233141911773723`, 0.2058405534946276], 
             UndirectedEdge[6, 80] -> 
             RGBColor[
              0.8086163665159423, 0.8504788015959455, 0.9815424524658205], 
             UndirectedEdge[287, 389] -> 
             RGBColor[
              0.214155749354975, 0.34242164920379625`, 0.9355072251595016], 
             UndirectedEdge[158, 410] -> 
             RGBColor[
              0.3605931713874897, 0.48674941394123933`, 0.9441976559141574], 
             UndirectedEdge[414, 415] -> 
             RGBColor[
              0.2808353270487499, 0.4125061130893616, 0.9393045284655668], 
             UndirectedEdge[10, 245] -> 
             RGBColor[
              0.22026264269435236`, 0.3488403813028832, 0.93585500370084], 
             UndirectedEdge[115, 178] -> 
             RGBColor[
              0.9564265081535962, 0.965404037867567, 0.8899068420398936], 
             UndirectedEdge[88, 348] -> 
             RGBColor[
              0.9132608681622556, 0.6818120756635188, 0.2545865809359151], 
             UndirectedEdge[135, 170] -> 
             RGBColor[
              0.2736536686143132, 0.40495773473132446`, 0.9388955436420372], 
             UndirectedEdge[3, 203] -> 
             RGBColor[
              0.49811633466717364`, 0.6034323062247897, 0.9536326890067068], 
             UndirectedEdge[84, 374] -> 
             RGBColor[
              0.24252230770556474`, 0.3722367005739444, 0.9371226586930053], 
             UndirectedEdge[29, 172] -> 
             RGBColor[
              0.3806363827099919, 0.5041098361876981, 0.9454747916161113], 
             UndirectedEdge[262, 387] -> 
             RGBColor[
              0.6255998101870561, 0.7048955003973141, 0.9650590620780228], 
             UndirectedEdge[179, 276] -> 
             RGBColor[
              0.39923464670294595`, 0.5037029404652202, 0.9483463693708659], 
             UndirectedEdge[348, 428] -> 
             RGBColor[
              0.8951225528654855, 0.5552983535621828, 0.23772264959288408`], 
             UndirectedEdge[104, 351] -> 
             RGBColor[
              0.2683095588486911, 0.39934073653152624`, 0.9385912044967868], 
             UndirectedEdge[111, 271] -> 
             RGBColor[
              0.2644482810539334, 0.39528228875008364`, 0.938371310438624], 
             UndirectedEdge[136, 277] -> 
             RGBColor[
              0.8701310969045036, 0.8988186894535575, 0.9576327343932979], 
             UndirectedEdge[246, 442] -> 
             RGBColor[
              0.28908336711974203`, 0.42117532615991926`, 0.939774242145728], 
             UndirectedEdge[206, 266] -> 
             RGBColor[
              0.31612745049209645`, 0.4464579350707817, 0.9414294227127427], 
             UndirectedEdge[31, 381] -> 
             RGBColor[
              0.5111715324361403, 0.6140235083829432, 0.9546625406628318], 
             UndirectedEdge[31, 472] -> 
             RGBColor[
              0.39074248974700837`, 0.5128632381554529, 0.9461187438200305], 
             UndirectedEdge[342, 453] -> 
             RGBColor[
              0.27214698791275327`, 0.40337411778491095`, 0.9388097404050177],
              UndirectedEdge[200, 475] -> 
             RGBColor[
              0.8699156991968737, 0.47168384997259694`, 0.2119718972840306], 
             UndirectedEdge[92, 101] -> 
             RGBColor[
              0.5649851581111299, 0.6577194295027604, 0.9588968477367864], 
             UndirectedEdge[193, 376] -> 
             RGBColor[
              0.2836334092052663, 0.4154470748445156, 0.9394638751049887], 
             UndirectedEdge[253, 319] -> 
             RGBColor[
              0.8499607656875054, 0.8826374101392084, 0.934970872933598], 
             UndirectedEdge[249, 280] -> 
             RGBColor[
              0.27322012310800536`, 0.4045020509158221, 0.938870853866826], 
             UndirectedEdge[153, 195] -> 
             RGBColor[
              0.2575424446398453, 0.3880238168235591, 0.9379780332711112], 
             UndirectedEdge[313, 380] -> 
             RGBColor[
              0.26990447818225494`, 0.4010170978748282, 0.9386820327933616], 
             UndirectedEdge[178, 357] -> 
             RGBColor[
              0.9494134599221778, 0.8301932628763469, 0.5158066666080678], 
             UndirectedEdge[163, 494] -> 
             RGBColor[
              0.262747921993954, 0.39349510356905415`, 0.938274477505614], 
             UndirectedEdge[24, 237] -> 
             RGBColor[
              0.871532203465174, 0.9004001382044219, 0.9876087136641327], 
             UndirectedEdge[101, 345] -> 
             RGBColor[
              0.5902789610650883, 0.677988050262613, 0.9610699533225915], 
             UndirectedEdge[320, 361] -> 
             RGBColor[
              0.8164019725999951, 0.8557645940777792, 0.9018606390244552], 
             UndirectedEdge[328, 487] -> 
             RGBColor[
              0.4823721914903405, 0.5888040064890694, 0.952903444464096], 
             UndirectedEdge[322, 494] -> 
             RGBColor[
              0.2588610411681461, 0.3894097453786518, 0.9380531253927091], 
             UndirectedEdge[108, 266] -> 
             RGBColor[
              0.28731571918259713`, 0.4193174161026276, 0.9396735772107083], 
             UndirectedEdge[405, 474] -> 
             RGBColor[
              0.9935549188322322, 0.9905077851325332, 0.6768786341569868], 
             UndirectedEdge[338, 379] -> 
             RGBColor[
              0.31470226354501973`, 0.4470010161121858, 0.9412735278461717], 
             UndirectedEdge[175, 309] -> 
             RGBColor[
              0.9743805147039586, 0.9770030600582216, 0.7213206267986814], 
             UndirectedEdge[294, 430] -> 
             RGBColor[
              0.23902588418057213`, 0.36856173776312173`, 0.9369235425457519],
              UndirectedEdge[197, 237] -> 
             RGBColor[
              0.8018590077882369, 0.845833600411511, 0.9807007779188375], 
             UndirectedEdge[94, 500] -> 
             RGBColor[
              0.8874558706447166, 0.5585534617562613, 0.5633237757723539], 
             UndirectedEdge[242, 365] -> 
             RGBColor[
              0.22099114578241763`, 0.3496060842382034, 0.9358964908739815], 
             UndirectedEdge[401, 500] -> 
             RGBColor[
              0.7964725199858478, 0.48689043193741693`, 0.5721768321079614], 
             UndirectedEdge[334, 340] -> 
             RGBColor[
              0.37011932022613914`, 0.4950004852671151, 0.9448046536945134], 
             UndirectedEdge[60, 310] -> 
             RGBColor[
              0.2947333345295756, 0.4271138001362785, 0.9400959994313403], 
             UndirectedEdge[50, 379] -> 
             RGBColor[
              0.37511861305326666`, 0.49933062144220947`, 0.9451232042127569],
              UndirectedEdge[123, 177] -> 
             RGBColor[
              0.2078300375710318, 0.33577292504558, 0.935146985231458], 
             UndirectedEdge[231, 246] -> 
             RGBColor[
              0.27633388437422024`, 0.407774811430481, 0.93904817796454], 
             UndirectedEdge[182, 282] -> 
             RGBColor[
              0.4931225250647846, 0.5973489755441486, 0.9538002129842165], 
             UndirectedEdge[185, 193] -> 
             RGBColor[
              0.28587823371129695`, 0.41780652773044813`, 0.9395917145396869],
              UndirectedEdge[395, 447] -> 
             RGBColor[
              0.2557437599820415, 0.3861332852050131, 0.9378756008407647], 
             UndirectedEdge[22, 282] -> 
             RGBColor[
              0.5295374583805197, 0.6288897605144723, 0.956120540334634], 
             UndirectedEdge[195, 323] -> 
             RGBColor[
              0.2547482956718921, 0.38508698909896344`, 0.9378189106209592], 
             UndirectedEdge[99, 486] -> 
             RGBColor[
              0.9642745659488295, 0.9698576677518461, 0.7703884518083142], 
             UndirectedEdge[454, 469] -> 
             RGBColor[
              0.8801565520867384, 0.5487007178218191, 0.22171202824050545`], 
             UndirectedEdge[31, 208] -> 
             RGBColor[
              0.38757839390763205`, 0.5101226573714661, 0.9459171304310454], 
             UndirectedEdge[398, 472] -> 
             RGBColor[
              0.2947988861662292, 0.4253612331985043, 0.9401664252880289], 
             UndirectedEdge[191, 389] -> 
             RGBColor[
              0.21845058194335062`, 0.3469357905622929, 0.9357518095217741], 
             UndirectedEdge[133, 151] -> 
             RGBColor[
              0.3259839947322987, 0.4565922388339624, 0.9419989967859217], 
             UndirectedEdge[165, 268] -> 
             RGBColor[
              0.4168440173490807, 0.5354710694634455, 0.9477819100781599], 
             UndirectedEdge[166, 495] -> 
             RGBColor[
              0.8401614416386582, 0.3097040160564781, 0.18609194791002698`], 
             UndirectedEdge[346, 430] -> 
             RGBColor[
              0.22881084125106885`, 0.35782507997308444`, 0.9363418109627185],
              UndirectedEdge[169, 219] -> 
             RGBColor[
              0.5095055418565787, 0.6126785776990856, 0.9545292891166974], 
             UndirectedEdge[197, 345] -> 
             RGBColor[
              0.6786754086563489, 0.7489056544572683, 0.9686076802187304], 
             UndirectedEdge[100, 213] -> 
             RGBColor[
              0.9177103751290299, 0.7114500107948662, 0.2526457256885956], 
             UndirectedEdge[73, 187] -> 
             RGBColor[
              0.25626928229983936`, 0.38668564248105813`, 0.9379055285593227],
              UndirectedEdge[97, 346] -> 
             RGBColor[
              0.22480858213955662`, 0.353618451889001, 0.9361138882271296], 
             UndirectedEdge[129, 170] -> 
             RGBColor[
              0.3261401713486173, 0.4557924254151241, 0.9420431862919051], 
             UndirectedEdge[36, 37] -> 
             RGBColor[
              0.2800147441029785, 0.41164362838539204`, 0.9392577974807488], 
             UndirectedEdge[143, 302] -> 
             RGBColor[
              0.1845381798446758, 0.31129170578610466`, 0.9338205483911577], 
             UndirectedEdge[16, 236] -> 
             RGBColor[
              0.34560261915581325`, 0.4717846628283363, 0.9433149938798411], 
             UndirectedEdge[187, 322] -> 
             RGBColor[
              0.2619233226556958, 0.392628397381927, 0.9382275177931856], 
             UndirectedEdge[108, 163] -> 
             RGBColor[
              0.27605150294224795`, 0.40747801064146116`, 0.939032096759735], 
             UndirectedEdge[137, 346] -> 
             RGBColor[
              0.21898159921391522`, 0.34749392338209584`, 0.9357820501697631],
              UndirectedEdge[243, 276] -> 
             RGBColor[
              0.7294231328480298, 0.5025695960181678, 0.5742322488928711], 
             UndirectedEdge[131, 147] -> 
             RGBColor[
              0.257551109678863, 0.38803292432896186`, 0.9379785267322645], 
             UndirectedEdge[9, 468] -> 
             RGBColor[
              0.5267603512092651, 0.6266868092518996, 0.9558876509153902], 
             UndirectedEdge[331, 377] -> 
             RGBColor[
              0.9088984029132244, 0.9290240327940705, 0.9505769466051841], 
             UndirectedEdge[280, 470] -> 
             RGBColor[
              0.25618724239569113`, 0.386599413340168, 0.9379008565081486], 
             UndirectedEdge[234, 468] -> 
             RGBColor[
              0.4334778335161593, 0.5491980337433716, 0.9490298017896481], 
             UndirectedEdge[136, 488] -> 
             RGBColor[
              0.8691624812525807, 0.8980619995445237, 0.9575361918373422], 
             UndirectedEdge[57, 361] -> 
             RGBColor[
              0.622722217665552, 0.7045647515271736, 0.9634614174292722], 
             UndirectedEdge[196, 414] -> 
             RGBColor[
              0.2851786513362504, 0.4170712222981897, 0.9395518743583675], 
             UndirectedEdge[103, 319] -> 
             RGBColor[
              0.5976226950866923, 0.6831049747415705, 0.9622258440138658], 
             UndirectedEdge[224, 263] -> 
             RGBColor[
              0.2861834719747001, 0.4181273524985085, 0.9396090974072282], 
             UndirectedEdge[89, 184] -> 
             RGBColor[
              0.271266794829508, 0.4024489790469554, 0.9387596147110557], 
             UndirectedEdge[137, 407] -> 
             RGBColor[
              0.2172194419002935, 0.34564178431825265`, 0.9356816979176306], 
             UndirectedEdge[53, 272] -> 
             RGBColor[
              0.8985476192245749, 0.5458238236085153, 0.2652993601444404], 
             UndirectedEdge[236, 243] -> 
             RGBColor[
              0.5633146331293595, 0.36122739545781846`, 0.562473440762307], 
             UndirectedEdge[26, 351] -> 
             RGBColor[
              0.3383374936256977, 0.4657436708748698, 0.9428428507321864], 
             UndirectedEdge[67, 96] -> 
             RGBColor[
              0.2763924027630132, 0.4078363179673825, 0.9390515105002115], 
             UndirectedEdge[284, 464] -> 
             RGBColor[
              0.24447969866104266`, 0.37429404257390636`, 0.9372341292122193],
              UndirectedEdge[325, 401] -> 
             RGBColor[
              0.4762346490241563, 0.5642173274993956, 0.9557801417908952], 
             UndirectedEdge[227, 348] -> 
             RGBColor[
              0.9027713884189711, 0.6140906553673846, 0.24504718315702606`], 
             UndirectedEdge[106, 117] -> 
             RGBColor[
              0.44946530583261596`, 0.561973649912251, 0.9503446865091629], 
             UndirectedEdge[395, 440] -> 
             RGBColor[
              0.2733307058970075, 0.4046182804384171, 0.9388771513930672], 
             UndirectedEdge[204, 361] -> 
             RGBColor[
              0.5730472494558454, 0.6642363745027182, 0.9595508219663998], 
             UndirectedEdge[195, 263] -> 
             RGBColor[
              0.27177628853634817`, 0.40298448923661123`, 0.9387886296239321],
              UndirectedEdge[360, 393] -> 
             RGBColor[
              0.5202889035975207, 0.6214329965452928, 0.9553781948537], 
             UndirectedEdge[74, 440] -> 
             RGBColor[
              0.2817039259800564, 0.4134190656385177, 0.9393539938897277], 
             UndirectedEdge[166, 348] -> 
             RGBColor[
              0.8990160108059699, 0.5852251774168952, 0.24145102931372386`], 
             UndirectedEdge[209, 477] -> 
             RGBColor[
              0.40529759982577535`, 0.5164885241169046, 0.9481078912022864], 
             UndirectedEdge[292, 422] -> 
             RGBColor[
              0.20649131825242792`, 0.3343658461620201, 0.9350707471467212], 
             UndirectedEdge[36, 416] -> 
             RGBColor[
              0.2579614870777197, 0.3884642569945902, 0.9380018971180304], 
             UndirectedEdge[306, 418] -> 
             RGBColor[
              0.9180265023958543, 0.7135265493813059, 0.5620472292012149], 
             UndirectedEdge[363, 498] -> 
             RGBColor[
              0.433350434496959, 0.5495353617267253, 0.948897990208064], 
             UndirectedEdge[57, 466] -> 
             RGBColor[
              0.552375580457491, 0.6474824063085367, 0.957904175593487], 
             UndirectedEdge[263, 395] -> 
             RGBColor[
              0.2691941123375187, 0.40027045833221453`, 0.938641578509396], 
             UndirectedEdge[171, 238] -> 
             RGBColor[
              0.2909480728266918, 0.4220805098947036, 0.9399190535823698], 
             UndirectedEdge[42, 286] -> 
             RGBColor[
              0.2277872668823118, 0.3567492384131574, 0.9362835199166604], 
             UndirectedEdge[246, 444] -> 
             RGBColor[
              0.2827572278979614, 0.41452615273743476`, 0.9394139778757318], 
             UndirectedEdge[46, 306] -> 
             RGBColor[
              0.8876171805650555, 0.5774114462757728, 0.22768643734119767`], 
             UndirectedEdge[229, 411] -> 
             RGBColor[
              0.26528288174741516`, 0.39615950699567326`, 0.9384188397134368],
              UndirectedEdge[239, 440] -> 
             RGBColor[
              0.3163021777955242, 0.4458837751629835, 0.9414671202878849], 
             UndirectedEdge[57, 106] -> 
             RGBColor[
              0.5595491629932491, 0.6533062437772754, 0.9584689062884005], 
             UndirectedEdge[60, 280] -> 
             RGBColor[
              0.2748009878347767, 0.4061636399762716, 0.9389608817743358], 
             UndirectedEdge[438, 457] -> 
             RGBColor[
              0.22152681415849518`, 0.35016910566479753`, 0.9359269963955489],
              UndirectedEdge[130, 368] -> 
             RGBColor[
              0.2935143249909316, 0.4166464351270609, 0.9403629270800464], 
             UndirectedEdge[152, 287] -> 
             RGBColor[
              0.20690732578417442`, 0.33480309645428663`, 0.9350944381602262],
              UndirectedEdge[54, 242] -> 
             RGBColor[
              0.22686421194138368`, 0.35577904914517844`, 0.936230953303312], 
             UndirectedEdge[89, 235] -> 
             RGBColor[
              0.32127172035398965`, 0.45054205661512126`, 0.9417708166396943],
              UndirectedEdge[60, 260] -> 
             RGBColor[
              0.2891430137819674, 0.4212380185837349, 0.9397776389349024], 
             UndirectedEdge[88, 243] -> 
             RGBColor[
              0.8529581179820884, 0.3951595604413297, 0.19784071975882145`], 
             UndirectedEdge[36, 367] -> 
             RGBColor[
              0.2421171751521342, 0.3718108805734015, 0.9370995869934273], 
             UndirectedEdge[17, 282] -> 
             RGBColor[
              0.7438148228852721, 0.7997463454963281, 0.9753349394405884], 
             UndirectedEdge[150, 233] -> 
             RGBColor[
              0.832302226448087, 0.24929464417169217`, 0.1785659545678221], 
             UndirectedEdge[250, 365] -> 
             RGBColor[
              0.21070999979849359`, 0.338799947946794, 0.9353109948197895], 
             UndirectedEdge[107, 423] -> 
             RGBColor[
              0.18624879198055028`, 0.31308966759998247`, 0.9339179652216718],
              UndirectedEdge[315, 347] -> 
             RGBColor[
              0.1822133081343763, 0.30884811821319974`, 0.9336881503865955], 
             UndirectedEdge[288, 492] -> 
             RGBColor[
              0.26634261157442907`, 0.39727335023461663`, 0.9384791897593554],
              UndirectedEdge[24, 267] -> 
             RGBColor[
              0.9130173103236416, 0.9238052630986108, 0.6981615264074577], 
             UndirectedEdge[198, 480] -> 
             RGBColor[
              0.3177133386514768, 0.44712506118461215`, 0.9415563421819749], 
             UndirectedEdge[4, 479] -> 
             RGBColor[
              0.3678971603336924, 0.49307576205728143`, 0.9446630596311456], 
             UndirectedEdge[133, 239] -> 
             RGBColor[
              0.34805209112246643`, 0.47588696054869806`, 0.943398549369312], 
             UndirectedEdge[115, 253] -> 
             RGBColor[
              0.9531001134456565, 0.9640284881713892, 0.9450338107840079], 
             UndirectedEdge[199, 371] -> 
             RGBColor[
              0.3528938984406201, 0.480080690691371, 0.9437070650501826], 
             UndirectedEdge[93, 189] -> 
             RGBColor[
              0.26453032177670965`, 0.3953685187514038, 0.9383759825364177], 
             UndirectedEdge[357, 418] -> 
             RGBColor[
              0.9428078871600445, 0.8265116366232681, 0.582732825135219], 
             UndirectedEdge[82, 463] -> 
             RGBColor[
              0.26268799213192734`, 0.3934321134842913, 0.9382710645886299], 
             UndirectedEdge[102, 350] -> 
             RGBColor[
              0.3193537748201921, 0.44805203074969097`, 0.941678953195245], 
             UndirectedEdge[235, 296] -> 
             RGBColor[
              0.3352307721420522, 0.4647817784660925, 0.9425815862613272], 
             UndirectedEdge[26, 360] -> 
             RGBColor[
              0.48299792974153133`, 0.5893477559050426, 0.9529428278924086], 
             UndirectedEdge[309, 320] -> 
             RGBColor[
              0.9908166313021023, 0.9885283450055495, 0.6606847997028811], 
             UndirectedEdge[13, 229] -> 
             RGBColor[
              0.2937960299949141, 0.4261286336418093, 0.9400426213247091], 
             UndirectedEdge[353, 420] -> 
             RGBColor[
              0.8041526849608935, 0.8472401733654197, 0.9513697071701304], 
             UndirectedEdge[171, 465] -> 
             RGBColor[
              0.27218390368581785`, 0.4034129186029971, 0.9388118427036817], 
             UndirectedEdge[104, 224] -> 
             RGBColor[
              0.2727699797429894, 0.40402892169845256`, 0.9388452188681158], 
             UndirectedEdge[22, 285] -> 
             RGBColor[
              0.38291743430858444`, 0.506085568433412, 0.9456201382069189], 
             UndirectedEdge[126, 285] -> 
             RGBColor[
              0.28277807837083513`, 0.4140236211798849, 0.9394343678430408], 
             UndirectedEdge[98, 319] -> 
             RGBColor[
              0.8550622111994015, 0.8847062165139711, 0.8474629923061501], 
             UndirectedEdge[286, 411] -> 
             RGBColor[
              0.2313451146629863, 0.3604887620112245, 0.9364861340844057], 
             UndirectedEdge[259, 491] -> 
             RGBColor[
              0.9280010655847133, 0.727726462964249, 0.4061574584267472], 
             UndirectedEdge[1, 266] -> 
             RGBColor[
              0.27784311638010406`, 0.40936110995950087`, 0.9391341264945663],
              UndirectedEdge[67, 216] -> 
             RGBColor[
              0.26125452628926693`, 0.3919254499966715, 0.938189430829513], 
             UndirectedEdge[41, 451] -> 
             RGBColor[
              0.22198624668627384`, 0.3506519983811976, 0.9359531603983363], 
             UndirectedEdge[300, 456] -> 
             RGBColor[
              0.22480808787876505`, 0.3536179323895711, 0.9361138600797088], 
             UndirectedEdge[117, 139] -> 
             RGBColor[
              0.47255522666265165`, 0.5807190878311534, 0.9521624096580703], 
             UndirectedEdge[70, 96] -> 
             RGBColor[
              0.2772059489257, 0.4086914065661722, 0.9390978407506428], 
             UndirectedEdge[92, 274] -> 
             RGBColor[
              0.5359359247795917, 0.6341359532311694, 0.9566099856780799], 
             UndirectedEdge[241, 436] -> 
             RGBColor[
              0.5892009770363313, 0.6764119562142918, 0.9614643256448061], 
             UndirectedEdge[207, 295] -> 
             RGBColor[
              0.22332543873759936`, 0.352059574136821, 0.9360294254045023], 
             UndirectedEdge[83, 176] -> 
             RGBColor[
              0.7638451540938651, 0.8157128228854424, 0.9772513951417543], 
             UndirectedEdge[56, 495] -> 
             RGBColor[
              0.839438039950976, 0.30414363368831143`, 0.18539921763693712`], 
             UndirectedEdge[219, 334] -> 
             RGBColor[
              0.4645364889888964, 0.5747991033502236, 0.9513681298117886], 
             UndirectedEdge[124, 357] -> 
             RGBColor[
              0.9348974167088442, 0.7776187751730486, 0.27677767167712564`], 
             UndirectedEdge[40, 291] -> 
             RGBColor[
              0.5205636488996574, 0.6196411124817705, 0.9560349926032045], 
             UndirectedEdge[7, 487] -> 
             RGBColor[
              0.7090567422484308, 0.7718269420846646, 0.9722547745917934], 
             UndirectedEdge[423, 477] -> 
             RGBColor[
              0.21624875945532895`, 0.3446215355237733, 0.9356264189883857], 
             UndirectedEdge[22, 165] -> 
             RGBColor[
              0.4377248912958056, 0.5535570329728583, 0.9491124209018134], 
             UndirectedEdge[302, 368] -> 
             RGBColor[
              0.2991255041617159, 0.42254414020486286`, 0.9406824754328269], 
             UndirectedEdge[297, 419] -> 
             RGBColor[
              0.5160273723962365, 0.6179732935362974, 0.9550427115070317], 
             UndirectedEdge[263, 463] -> 
             RGBColor[
              0.2702490064672201, 0.4013792189466815, 0.9387016531695065], 
             UndirectedEdge[260, 424] -> 
             RGBColor[
              0.3030854306847971, 0.434796914253921, 0.9406117494194473], 
             UndirectedEdge[193, 415] -> 
             RGBColor[
              0.28741220208324925`, 0.41941882574858214`, 0.9396790717691668],
              UndirectedEdge[434, 474] -> 
             RGBColor[
              0.992149866333044, 0.99102178223655, 0.7797605605635565], 
             UndirectedEdge[102, 109] -> 
             RGBColor[
              0.265248780611274, 0.396123664539452, 0.9384168977041816], 
             UndirectedEdge[58, 118] -> 
             RGBColor[
              0.3201099243225116, 0.4516848600807156, 0.9416180992091068], 
             UndirectedEdge[39, 100] -> 
             RGBColor[
              0.7774382200691679, 0.7351762203070193, 0.6135140654406412], 
             UndirectedEdge[35, 216] -> 
             RGBColor[
              0.25212920477180323`, 0.3823341585030158, 0.9376697572687969], 
             UndirectedEdge[72, 163] -> 
             RGBColor[
              0.26048838412385666`, 0.3911201860046064, 0.9381458001665987], 
             UndirectedEdge[202, 414] -> 
             RGBColor[
              0.25685751416132785`, 0.38730391146353665`, 0.9379390274936235],
              UndirectedEdge[324, 441] -> 
             RGBColor[
              0.4099049258998564, 0.5294607772190044, 0.947339757307013], 
             UndirectedEdge[18, 52] -> 
             RGBColor[
              0.8600894824934477, 0.42201909265360843`, 0.20357506457964797`],
              UndirectedEdge[168, 368] -> 
             RGBColor[
              0.6594469349895435, 0.6059633899066202, 0.5971521921376893], 
             UndirectedEdge[208, 397] -> 
             RGBColor[
              0.3403332891441403, 0.46920132223333977`, 0.9429067141327215], 
             UndirectedEdge[193, 350] -> 
             RGBColor[
              0.3249908553866274, 0.4539769598365655, 0.94199997659419], 
             UndirectedEdge[2, 365] -> 
             RGBColor[
              0.21471117528305686`, 0.3430054370702481, 0.9355388558444269], 
             UndirectedEdge[42, 248] -> 
             RGBColor[
              0.2375069627028864, 0.3669652549848901, 0.9368370422146407], 
             UndirectedEdge[46, 68] -> 
             RGBColor[
              0.8688206529626022, 0.4329330984324026, 0.20968686128144703`], 
             UndirectedEdge[260, 470] -> 
             RGBColor[
              0.2705292683428818, 0.4016737919476313, 0.9387176136687151], 
             UndirectedEdge[32, 344] -> 
             RGBColor[
              0.49972685632516956`, 0.6047398002599247, 0.9537594751711596], 
             UndirectedEdge[60, 483] -> 
             RGBColor[
              0.29467938491288026`, 0.4270570956685284, 0.9400929270804808], 
             UndirectedEdge[337, 498] -> 
             RGBColor[
              0.6610501058244442, 0.7326972089760198, 0.9686548196773171], 
             UndirectedEdge[86, 168] -> 
             RGBColor[
              0.912992655814064, 0.6927519043211215, 0.24885005242438252`], 
             UndirectedEdge[151, 424] -> 
             RGBColor[
              0.31369437792555, 0.4459475904500576, 0.9412159132702771], 
             UndirectedEdge[234, 296] -> 
             RGBColor[
              0.3509992318996893, 0.478439625762326, 0.9435863385735823], 
             UndirectedEdge[223, 268] -> 
             RGBColor[
              0.3997592820050565, 0.5206731304122181, 0.946693285849477], 
             UndirectedEdge[50, 204] -> 
             RGBColor[
              0.47141553909134676`, 0.5814192522224795, 0.9516235825177704], 
             UndirectedEdge[26, 247] -> 
             RGBColor[
              0.44082045923577545`, 0.5551061852750767, 0.9496224629130303], 
             UndirectedEdge[64, 435] -> 
             RGBColor[
              0.2729760661843835, 0.4042455316149929, 0.9388569551860756], 
             UndirectedEdge[143, 214] -> 
             RGBColor[
              0.18936705810043614`, 0.31636716300147366`, 0.934095545864138], 
             UndirectedEdge[38, 266] -> 
             RGBColor[
              0.27474470932625494`, 0.40610448769555174`, 0.9389576767965321],
              UndirectedEdge[309, 375] -> 
             RGBColor[
              0.9756161016685031, 0.977924558793291, 0.7192291003603996], 
             UndirectedEdge[70, 385] -> 
             RGBColor[
              0.24586087527331454`, 0.37574574676505923`, 0.9373127851770204],
              UndirectedEdge[232, 354] -> 
             RGBColor[
              0.35898073503518557`, 0.48535280261628094`, 0.94409491289561], 
             UndirectedEdge[86, 484] -> 
             RGBColor[
              0.9540423951293819, 0.8443401430723285, 0.3591520108030784], 
             UndirectedEdge[106, 360] -> 
             RGBColor[
              0.5486108303756021, 0.6444260125920007, 0.9576078006763067], 
             UndirectedEdge[163, 322] -> 
             RGBColor[
              0.26310542995763675`, 0.3938708671061988, 0.9382948370552601], 
             UndirectedEdge[44, 117] -> 
             RGBColor[
              0.4388762614701655, 0.5533769866678013, 0.9495110781480034], 
             UndirectedEdge[113, 273] -> 
             RGBColor[
              0.23636683819300525`, 0.3657669118369359, 0.936772113810466], 
             UndirectedEdge[53, 298] -> 
             RGBColor[
              0.9390760601522875, 0.9284198827471832, 0.6768677898959217], 
             UndirectedEdge[50, 369] -> 
             RGBColor[
              0.43044272533776096`, 0.5472495868323034, 0.9486484077263333], 
             UndirectedEdge[135, 385] -> 
             RGBColor[
              0.24204917775156742`, 0.37173941099412156`, 0.9370957146420581],
              UndirectedEdge[376, 464] -> 
             RGBColor[
              0.2616609318454717, 0.3923526080038432, 0.9382125750247157], 
             UndirectedEdge[95, 408] -> 
             RGBColor[
              0.22479372667970515`, 0.35360283785880653`, 0.9361130422306678],
              UndirectedEdge[34, 332] -> 
             RGBColor[
              0.47297256082386624`, 0.5816312685861409, 0.9520368398699108], 
             UndirectedEdge[251, 416] -> 
             RGBColor[
              0.26003944376158217`, 0.39064832121939286`, 0.9381202336771148],
              UndirectedEdge[62, 209] -> 
             RGBColor[
              0.6916212861064526, 0.39630413817282756`, 0.5615943615662011], 
             UndirectedEdge[109, 496] -> 
             RGBColor[
              0.26542477376877, 0.3963086445065909, 0.9384269202541424], 
             UndirectedEdge[179, 254] -> 
             RGBColor[
              0.20771369325605188`, 0.33565063979388043`, 0.9351403595948358],
              UndirectedEdge[27, 199] -> 
             RGBColor[
              0.4274813973658525, 0.5430880506381621, 0.9489008550961784], 
             UndirectedEdge[59, 453] -> 
             RGBColor[
              0.26324896867774317`, 0.3940217354019111, 0.9383030113730237], 
             UndirectedEdge[450, 475] -> 
             RGBColor[
              0.8283559372455574, 0.2189617360860943, 0.17478698357078354`], 
             UndirectedEdge[311, 331] -> 
             RGBColor[
              0.7917742816822333, 0.837394395727864, 0.9798444828971542], 
             UndirectedEdge[329, 486] -> 
             RGBColor[
              0.9087427412464592, 0.930070810978078, 0.9911578879759511], 
             UndirectedEdge[287, 456] -> 
             RGBColor[
              0.21673512234064032`, 0.34513273375342357`, 0.9356541166351948],
              UndirectedEdge[60, 118] -> 
             RGBColor[
              0.30890885152103453`, 0.4405003788871604, 0.9409586647466246], 
             UndirectedEdge[267, 493] -> 
             RGBColor[
              0.991319933690298, 0.9817192401312839, 0.4771566948770857], 
             UndirectedEdge[239, 263] -> 
             RGBColor[
              0.31216558423603546`, 0.4415359530567809, 0.9412315474042139], 
             UndirectedEdge[64, 91] -> 
             RGBColor[
              0.3077316474117898, 0.43903000298271255`, 0.9409001581731142], 
             UndirectedEdge[469, 471] -> 
             RGBColor[
              0.8586216305057723, 0.4484110579890054, 0.20364468753654688`], 
             UndirectedEdge[275, 282] -> 
             RGBColor[
              0.5106811757652547, 0.612557396257451, 0.9549190346803453], 
             UndirectedEdge[132, 423] -> 
             RGBColor[
              0.5889794016641527, 0.6524675094432201, 0.8735972473293918], 
             UndirectedEdge[116, 412] -> 
             RGBColor[
              0.24555371763094103`, 0.3754229046080053, 0.9372952930036862], 
             UndirectedEdge[89, 453] -> 
             RGBColor[
              0.28490427469255214`, 0.4167828350491789, 0.9395362490144127], 
             UndirectedEdge[136, 311] -> 
             RGBColor[
              0.8579087651395905, 0.8892705109856455, 0.9564145265871555], 
             UndirectedEdge[6, 24] -> 
             RGBColor[
              0.8323309168683787, 0.869142096362715, 0.9838696599531287], 
             UndirectedEdge[51, 477] -> 
             RGBColor[
              0.21179931412463662`, 0.3399448863700877, 0.9353730296591674], 
             UndirectedEdge[114, 381] -> 
             RGBColor[
              0.5349916430046526, 0.6333693427468647, 0.9565356483577385], 
             UndirectedEdge[95, 294] -> 
             RGBColor[
              0.2326978312332123, 0.36191055289371626`, 0.9365631692919152], 
             UndirectedEdge[89, 192] -> 
             RGBColor[
              0.27005817816264466`, 0.4011786462993594, 0.9386907857798661], 
             UndirectedEdge[108, 374] -> 
             RGBColor[
              0.2684205085848909, 0.3994573517388918, 0.938597522920128], 
             UndirectedEdge[208, 472] -> 
             RGBColor[
              0.32528262084800263`, 0.45616518982380916`, 0.9419476988576752],
              UndirectedEdge[34, 360] -> 
             RGBColor[
              0.5615596954334325, 0.6549384845856707, 0.9586271827669148], 
             UndirectedEdge[395, 453] -> 
             RGBColor[
              0.2746472026730905, 0.406002002020797, 0.9389521239368825], 
             UndirectedEdge[101, 361] -> 
             RGBColor[
              0.5825170875925927, 0.671924415713476, 0.9602963223136847], 
             UndirectedEdge[11, 211] -> 
             RGBColor[
              0.23497926878004616`, 0.3643084884069338, 0.936693093785123], 
             UndirectedEdge[70, 433] -> 
             RGBColor[
              0.2918782074405654, 0.4225632807803333, 0.9399901426055144], 
             UndirectedEdge[108, 206] -> 
             RGBColor[
              0.31392242641055057`, 0.44414031495447526`, 0.9413038498533395],
              UndirectedEdge[251, 499] -> 
             RGBColor[
              0.25963192027097015`, 0.39021998819227793`, 0.9380970258172014],
              UndirectedEdge[116, 399] -> 
             RGBColor[
              0.24511345141386065`, 0.3749601568993634, 0.937270220493939], 
             UndirectedEdge[350, 479] -> 
             RGBColor[
              0.3868303332701487, 0.5094747248458988, 0.9458694646687091], 
             UndirectedEdge[347, 421] -> 
             RGBColor[
              0.17899180289058533`, 0.3054621119467458, 0.9335046904287516], 
             UndirectedEdge[153, 447] -> 
             RGBColor[
              0.24571645560416666`, 0.3755939525360489, 0.9373045606905122], 
             UndirectedEdge[195, 453] -> 
             RGBColor[
              0.27722937887191995`, 0.40871603292519376`, 0.9390991750514186],
              UndirectedEdge[338, 425] -> 
             RGBColor[
              0.3477240886796976, 0.47560286131865376`, 0.9433776493436998], 
             UndirectedEdge[164, 348] -> 
             RGBColor[
              0.8887181595032059, 0.5060713797566354, 0.23158979527643736`], 
             UndirectedEdge[31, 258] -> 
             RGBColor[
              0.4132303526475083, 0.5323410947270124, 0.947551650558814], 
             UndirectedEdge[31, 203] -> 
             RGBColor[
              0.4938024492349883, 0.5999225041719667, 0.9532951828081889], 
             UndirectedEdge[398, 445] -> 
             RGBColor[
              0.2453951867466454, 0.3752562785971719, 0.9372862649043511], 
             UndirectedEdge[44, 369] -> 
             RGBColor[
              0.4583123366675063, 0.5702115381181944, 0.9507495276729314], 
             UndirectedEdge[267, 278] -> 
             RGBColor[
              0.9687131736129876, 0.9678890438697982, 0.6921508091390034], 
             UndirectedEdge[130, 477] -> 
             RGBColor[
              0.2117993137193227, 0.3399448859440771, 0.9353730296360853], 
             UndirectedEdge[4, 482] -> 
             RGBColor[
              0.3413925426988842, 0.4701187944228272, 0.9429742088325687], 
             UndirectedEdge[219, 274] -> 
             RGBColor[
              0.49450158018716717`, 0.6004976856950868, 0.9533481222927589], 
             UndirectedEdge[44, 269] -> 
             RGBColor[
              0.4728082951441619, 0.5827672087626157, 0.9516731973287911], 
             UndirectedEdge[130, 143] -> 
             RGBColor[
              0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772],
              UndirectedEdge[315, 401] -> 
             RGBColor[
              0.47947599697395743`, 0.5676241897079666, 0.9559647317614918], 
             UndirectedEdge[75, 163] -> 
             RGBColor[
              0.3059704107658049, 0.43557751025778224`, 0.9408584905702073], 
             UndirectedEdge[9, 139] -> 
             RGBColor[
              0.5695894293133013, 0.6614573842847371, 0.9592593128318224], 
             UndirectedEdge[134, 438] -> 
             RGBColor[
              0.22733547187831532`, 0.35627437321849936`, 0.9362577908595535],
              UndirectedEdge[76, 431] -> 
             RGBColor[
              0.42993261586454035`, 0.5468077556454473, 0.9486159040017718], 
             UndirectedEdge[90, 124] -> 
             RGBColor[
              0.9137111635376958, 0.6822566946723914, 0.2591427819494134], 
             UndirectedEdge[37, 188] -> 
             RGBColor[
              0.3214586719550145, 0.4525659249433619, 0.9417145542769817], 
             UndirectedEdge[26, 106] -> 
             RGBColor[
              0.45224243758080923`, 0.5643790618498358, 0.9505216428884367], 
             UndirectedEdge[107, 446] -> 
             RGBColor[
              0.2064114829025504, 0.3342819341474452, 0.9350662006416515], 
             UndirectedEdge[19, 234] -> 
             RGBColor[
              0.474151584993228, 0.582218817524079, 0.9522317884987839], 
             UndirectedEdge[39, 243] -> 
             RGBColor[
              0.7314838484501698, 0.504242577778165, 0.5743944759737214], 
             UndirectedEdge[129, 265] -> 
             RGBColor[
              0.3383071396578693, 0.46744637338556605`, 0.9427776096791101], 
             UndirectedEdge[396, 446] -> 
             RGBColor[
              0.6108486673250959, 0.6728679174892245, 0.7376055193707824], 
             UndirectedEdge[325, 368] -> 
             RGBColor[
              0.2935592851755068, 0.41669369113168975`, 0.9403654874960453], 
             UndirectedEdge[52, 56] -> 
             RGBColor[
              0.836234326611525, 0.27951848908515425`, 0.18233133812500216`], 
             UndirectedEdge[402, 431] -> 
             RGBColor[
              0.5004255816893457, 0.6051773211877334, 0.9538503277794443], 
             UndirectedEdge[165, 353] -> 
             RGBColor[
              0.531847897863051, 0.630021959343577, 0.9565078633928767], 
             UndirectedEdge[237, 329] -> 
             RGBColor[
              0.8943251384864865, 0.9185746058926771, 0.989782724153959], 
             UndirectedEdge[63, 75] -> 
             RGBColor[
              0.38214205273411095`, 0.5054139718854141, 0.9455707315786365], 
             UndirectedEdge[392, 492] -> 
             RGBColor[
              0.2913103527973019, 0.4235160293060819, 0.9399010656855349], 
             UndirectedEdge[125, 177] -> 
             RGBColor[
              0.20868507222126964`, 0.3366716206753079, 0.9351956781898786], 
             UndirectedEdge[210, 348] -> 
             RGBColor[
              0.8979876618717816, 0.5773208368833467, 0.24046628121299102`], 
             UndirectedEdge[469, 491] -> 
             RGBColor[
              0.9272960549745825, 0.7245251744430564, 0.40556918029226263`], 
             UndirectedEdge[35, 171] -> 
             RGBColor[
              0.25005732664065045`, 0.38015648322251344`, 0.9375517668742968],
              UndirectedEdge[8, 40] -> 
             RGBColor[
              0.5032468930597369, 0.6057751178648505, 0.9545401217837302], 
             UndirectedEdge[405, 491] -> 
             RGBColor[
              0.9940870576802556, 0.9897611392052678, 0.5977909028249961], 
             UndirectedEdge[98, 136] -> 
             RGBColor[
              0.9820976999154852, 0.9842937020241562, 0.8300672430323528], 
             UndirectedEdge[14, 75] -> 
             RGBColor[
              0.32584559541094904`, 0.45646758947931865`, 0.9419903529330476],
              UndirectedEdge[121, 500] -> 
             RGBColor[
              0.8234793018793516, 0.18147777970619255`, 0.1701171120367329], 
             UndirectedEdge[1, 265] -> 
             RGBColor[
              0.2935899974663011, 0.4247777732380918, 0.9400724206184119], 
             UndirectedEdge[227, 495] -> 
             RGBColor[
              0.8439168192516593, 0.3385694940069675, 0.1896881017533292], 
             UndirectedEdge[127, 368] -> 
             RGBColor[
              0.3170407306432145, 0.44137417912788274`, 0.9417027210777457], 
             UndirectedEdge[207, 389] -> 
             RGBColor[
              0.21778138864415675`, 0.3462324259755344, 0.9357136999533677], 
             UndirectedEdge[249, 260] -> 
             RGBColor[
              0.28756214905519606`, 0.4195764295232854, 0.9396876110273925], 
             UndirectedEdge[42, 95] -> 
             RGBColor[
              0.2297785943922997, 0.3588422498836111, 0.9363969230724491], 
             UndirectedEdge[190, 323] -> 
             RGBColor[
              0.243727142288008, 0.373503058111017, 0.9371912722400824], 
             UndirectedEdge[109, 295] -> 
             RGBColor[
              0.24177394363545715`, 0.37145012248723885`, 0.937080040466318], 
             UndirectedEdge[382, 499] -> 
             RGBColor[
              0.27147166687394786`, 0.40266431255529955`, 0.9387712818709056],
              UndirectedEdge[213, 254] -> 
             RGBColor[
              0.5703520735589939, 0.511904106319279, 0.5892794945919869], 
             UndirectedEdge[47, 374] -> 
             RGBColor[
              0.24183198733731956`, 0.37151113009807946`, 0.9370833459692711],
              UndirectedEdge[244, 390] -> 
             RGBColor[
              0.3215972480879268, 0.45223414091428343`, 0.9417399272656037], 
             UndirectedEdge[92, 370] -> 
             RGBColor[
              0.6002904630940367, 0.6863818665737486, 0.9616762106726342], 
             UndirectedEdge[295, 458] -> 
             RGBColor[
              0.2300435692999762, 0.35912075531195864`, 0.936412013001446], 
             UndirectedEdge[278, 493] -> 
             RGBColor[
              0.9709705008180975, 0.974840539169355, 0.7572967831573334], 
             UndirectedEdge[6, 156] -> 
             RGBColor[
              0.6474994925034097, 0.7219315348762902, 0.9673172118721224], 
             UndirectedEdge[79, 413] -> 
             RGBColor[
              0.9838323701759427, 0.9563067408191819, 0.46126511216987476`], 
             UndirectedEdge[122, 476] -> 
             RGBColor[
              0.8579983660337116, 0.432494720305006, 0.20261219607186334`], 
             UndirectedEdge[123, 455] -> 
             RGBColor[
              0.20545207796979598`, 0.3332735387333343, 0.9350115639500436], 
             UndirectedEdge[113, 302] -> 
             RGBColor[
              0.18467080951855291`, 0.3114311079825565, 0.9338281014548768], 
             UndirectedEdge[402, 462] -> 
             RGBColor[
              0.5080947993050582, 0.6115332733425336, 0.9544182302953215], 
             UndirectedEdge[140, 363] -> 
             RGBColor[
              0.4522227109181607, 0.5648567259118211, 0.9503836849393674], 
             UndirectedEdge[440, 453] -> 
             RGBColor[
              0.2829903357512072, 0.4147711638710876, 0.939427253023122], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.5464995084832656, 0.6427119463658346, 0.9574415896829152], 
             UndirectedEdge[102, 202] -> 
             RGBColor[
              0.2577973086293919, 0.3882916950358828, 0.9379925473982783], 
             UndirectedEdge[363, 379] -> 
             RGBColor[
              0.35705527838116624`, 0.4836850688388347, 0.9439722245002304], 
             UndirectedEdge[162, 297] -> 
             RGBColor[
              0.4906978130641887, 0.5974096161868968, 0.9530486758111798], 
             UndirectedEdge[19, 393] -> 
             RGBColor[
              0.5104680056398668, 0.6134599491568583, 0.954605057791339], 
             UndirectedEdge[96, 238] -> 
             RGBColor[
              0.3081578274315908, 0.4401690531459169, 0.9408991236475683], 
             UndirectedEdge[117, 247] -> 
             RGBColor[
              0.4380433274875822, 0.5527007733374919, 0.9494455065337566], 
             UndirectedEdge[162, 223] -> 
             RGBColor[
              0.4259476007932227, 0.5431195461878823, 0.9484273528030159], 
             UndirectedEdge[355, 362] -> 
             RGBColor[
              0.3585841716726791, 0.48500931936353203`, 0.9440696442288183], 
             UndirectedEdge[59, 395] -> 
             RGBColor[
              0.2535893388235434, 0.38386885196924064`, 0.9377529097429688], 
             UndirectedEdge[161, 403] -> 
             RGBColor[
              0.9596219668575938, 0.962601388451382, 0.7050117798938269], 
             UndirectedEdge[214, 477] -> 
             RGBColor[
              0.2222393711458674, 0.35091804823724815`, 0.9359675754618462], 
             UndirectedEdge[65, 309] -> 
             RGBColor[
              0.9892477963467572, 0.9750667140916796, 0.4404269945442838], 
             UndirectedEdge[361, 498] -> 
             RGBColor[
              0.5530454795335582, 0.6479980366103388, 0.95797620936922], 
             UndirectedEdge[54, 70] -> 
             RGBColor[
              0.24348548029858347`, 0.3732490560378767, 0.9371775099472914], 
             UndirectedEdge[369, 390] -> 
             RGBColor[
              0.36035044557586515`, 0.48580021278599533`, 0.9442092467414281],
              UndirectedEdge[56, 88] -> 
             RGBColor[
              0.8516418675680354, 0.38504228297430826`, 0.19658027687583196`],
              UndirectedEdge[289, 419] -> 
             RGBColor[
              0.4760307938821983, 0.5851235769437257, 0.9519986681530803], 
             UndirectedEdge[124, 178] -> 
             RGBColor[
              0.977168593002762, 0.938254909924025, 0.5484416326473938], 
             UndirectedEdge[67, 465] -> 
             RGBColor[
              0.26962432665641767`, 0.4007226408585406, 0.9386660785784122], 
             UndirectedEdge[7, 461] -> 
             RGBColor[
              0.8915688064008891, 0.9161509753336762, 0.9816909809846657], 
             UndirectedEdge[273, 423] -> 
             RGBColor[
              0.24068365358124288`, 0.3703041585118776, 0.9370179500606701], 
             UndirectedEdge[63, 467] -> 
             RGBColor[
              0.563087381667329, 0.6542682731705118, 0.9596777258955458], 
             UndirectedEdge[179, 368] -> 
             RGBColor[
              0.2935153935219346, 0.41664755822089383`, 0.9403629879313062], 
             UndirectedEdge[211, 485] -> 
             RGBColor[
              0.23952079823930758`, 0.3690819238182165, 0.9369517271692371], 
             UndirectedEdge[21, 320] -> 
             RGBColor[
              0.9847451317139568, 0.9683734708666063, 0.6094013242659239], 
             UndirectedEdge[318, 479] -> 
             RGBColor[
              0.3767164983407358, 0.5007146293661655, 0.94522502005032], 
             UndirectedEdge[343, 465] -> 
             RGBColor[
              0.2877565452274621, 0.4197807522257663, 0.9396986816018197], 
             UndirectedEdge[229, 313] -> 
             RGBColor[
              0.2789668469500533, 0.41054222203715074`, 0.9391981212881146], 
             UndirectedEdge[168, 401] -> 
             RGBColor[
              0.842122298838193, 0.7534870262743261, 0.6125668464325392], 
             UndirectedEdge[70, 216] -> 
             RGBColor[
              0.26206807245195374`, 0.39278053859546125`, 0.9382357610799443],
              UndirectedEdge[5, 193] -> 
             RGBColor[
              0.263209529621381, 0.3939802824530939, 0.9383007653771087], 
             UndirectedEdge[213, 471] -> 
             RGBColor[
              0.8805092403498851, 0.5477975823099646, 0.2219082457048863], 
             UndirectedEdge[145, 404] -> 
             RGBColor[
              0.2170532372191201, 0.345467092660354, 0.9356722328069155], 
             UndirectedEdge[28, 173] -> 
             RGBColor[
              0.9747095150977819, 0.9805973489982415, 0.9249344880863324], 
             UndirectedEdge[210, 243] -> 
             RGBColor[
              0.8376849116916145, 0.29066832166115775`, 0.18372042003589745`],
              UndirectedEdge[133, 424] -> 
             RGBColor[
              0.33288404882225986`, 0.46274916467623195`, 0.942432055126516], 
             UndirectedEdge[201, 400] -> 
             RGBColor[
              0.30019030163233085`, 0.432849418552972, 0.9404067656349827], 
             UndirectedEdge[120, 125] -> 
             RGBColor[
              0.2080475453125366, 0.33600153947268885`, 0.9351593719755629], 
             UndirectedEdge[96, 343] -> 
             RGBColor[
              0.29452462133405766`, 0.4268944293346082, 0.940084113523619], 
             UndirectedEdge[22, 149] -> 
             RGBColor[
              0.40264564991743174`, 0.5231731572248479, 0.9468772026605385], 
             UndirectedEdge[140, 369] -> 
             RGBColor[
              0.4597907440975337, 0.5714117758713864, 0.950865913321408], 
             UndirectedEdge[169, 370] -> 
             RGBColor[
              0.5420927609464797, 0.6391343501937576, 0.9570946743743712], 
             UndirectedEdge[154, 380] -> 
             RGBColor[
              0.2911961325222311, 0.423322454553487, 0.9398972530104752], 
             UndirectedEdge[33, 489] -> 
             RGBColor[
              0.9342559232885688, 0.7654812281083937, 0.517015114696979], 
             UndirectedEdge[271, 284] -> 
             RGBColor[
              0.2504489768010796, 0.3805681323731789, 0.9375740707715388], 
             UndirectedEdge[112, 356] -> 
             RGBColor[
              0.2588007282426925, 0.3893463526699398, 0.9380496906608295], 
             UndirectedEdge[133, 155] -> 
             RGBColor[
              0.4555313931992919, 0.5659235600860384, 0.9510915748153721], 
             UndirectedEdge[82, 447] -> 
             RGBColor[
              0.25238928516537673`, 0.3826075194867109, 0.9376845684624564], 
             UndirectedEdge[225, 260] -> 
             RGBColor[
              0.27991286113099906`, 0.41153654292208813`, 0.9392519953962168],
              UndirectedEdge[133, 225] -> 
             RGBColor[
              0.3097114792684619, 0.4394887933443991, 0.9410723011032855], 
             UndirectedEdge[442, 444] -> 
             RGBColor[
              0.27761918641957545`, 0.4091257453730057, 0.939121374014589], 
             UndirectedEdge[49, 431] -> 
             RGBColor[
              0.4693773227785792, 0.5799709458958486, 0.9514060951044689], 
             UndirectedEdge[220, 427] -> 
             RGBColor[
              0.30920666661498386`, 0.43953702554153684`, 0.9410223592495326],
              UndirectedEdge[151, 192] -> 
             RGBColor[
              0.28070448165153206`, 0.4123685862808082, 0.9392970770137636], 
             UndirectedEdge[167, 326] -> 
             RGBColor[
              0.9309228830343801, 0.7574193985269815, 0.5440638154599668], 
             UndirectedEdge[109, 196] -> 
             RGBColor[
              0.27482966958615396`, 0.4061937863154972, 0.938962515157646], 
             UndirectedEdge[212, 451] -> 
             RGBColor[
              0.21498103480107186`, 0.34328907653376356`, 0.9355542239447563],
              UndirectedEdge[186, 414] -> 
             RGBColor[
              0.255184189019674, 0.3855451406447167, 0.937843734102269], 
             UndirectedEdge[349, 419] -> 
             RGBColor[
              0.4631460027688009, 0.5739634184897324, 0.951177660656908], 
             UndirectedEdge[162, 221] -> 
             RGBColor[
              0.4993207487803075, 0.6044101038600693, 0.953727504897607], 
             UndirectedEdge[163, 364] -> 
             RGBColor[
              0.2627794929075267, 0.39352828660093053`, 0.938276275422437], 
             UndirectedEdge[191, 300] -> 
             RGBColor[
              0.22217951414553483`, 0.3508551347347456, 0.9359641666942277], 
             UndirectedEdge[438, 460] -> 
             RGBColor[
              0.23490540515407732`, 0.3642308530528161, 0.9366888873608955], 
             UndirectedEdge[172, 473] -> 
             RGBColor[
              0.3392418574009336, 0.4682559789143286, 0.9428371690671595], 
             UndirectedEdge[141, 188] -> 
             RGBColor[
              0.32343001274534444`, 0.45456055380007726`, 0.9418296523075707],
              UndirectedEdge[79, 122] -> 
             RGBColor[
              0.9306665098261713, 0.7402291937878942, 0.3904132893585251], 
             UndirectedEdge[326, 475] -> 
             RGBColor[
              0.8570894511774583, 0.4134428533627656, 0.20126936153652183`], 
             UndirectedEdge[98, 124] -> 
             RGBColor[
              0.9789436438067185, 0.93894816660261, 0.5160607207640602], 
             UndirectedEdge[204, 498] -> 
             RGBColor[
              0.4818912814299178, 0.5902600770764668, 0.9523553933815417], 
             UndirectedEdge[72, 144] -> 
             RGBColor[
              0.2501061102631632, 0.3802077579028347, 0.93755454502943], 
             UndirectedEdge[98, 331] -> 
             RGBColor[
              0.9159632164581281, 0.9324175867663749, 0.8534971993423514], 
             UndirectedEdge[311, 377] -> 
             RGBColor[
              0.8639809895032101, 0.8937991659736781, 0.9461358346293043], 
             UndirectedEdge[299, 389] -> 
             RGBColor[
              0.213833079654714, 0.34208250289038133`, 0.9354888495974187], 
             UndirectedEdge[131, 238] -> 
             RGBColor[
              0.29188148517230905`, 0.42306158545170824`, 0.9399722100345929],
              UndirectedEdge[4, 185] -> 
             RGBColor[
              0.30412419819916303`, 0.4355457825101565, 0.9406834624888651], 
             UndirectedEdge[162, 258] -> 
             RGBColor[
              0.4177269296537439, 0.5359992140298111, 0.9479035389072623], 
             UndirectedEdge[124, 253] -> 
             RGBColor[
              0.9738421982948224, 0.9368793602278473, 0.603568601391508], 
             UndirectedEdge[319, 449] -> 
             RGBColor[
              0.7215962304048408, 0.7824357266175173, 0.9728856266127364], 
             UndirectedEdge[256, 271] -> 
             RGBColor[
              0.2725957288123946, 0.4038457729222503, 0.9388352955353996], 
             UndirectedEdge[379, 478] -> 
             RGBColor[
              0.2876705710791334, 0.41963924089195836`, 0.9396956582454141], 
             UndirectedEdge[349, 371] -> 
             RGBColor[
              0.3882726943942144, 0.5107240255563866, 0.9459613706441047], 
             UndirectedEdge[130, 325] -> 
             RGBColor[
              0.1789719601845752, 0.3054412560046289, 0.9335035604159989], 
             UndirectedEdge[269, 369] -> 
             RGBColor[
              0.43444338232168905`, 0.5507147548329152, 0.948903326051707], 
             UndirectedEdge[43, 355] -> 
             RGBColor[
              0.3109273076150301, 0.4422891800076947, 0.941085795498422], 
             UndirectedEdge[11, 414] -> 
             RGBColor[
              0.25678804986481485`, 0.38723090008361066`, 0.9379350716047002],
              UndirectedEdge[117, 255] -> 
             RGBColor[
              0.38933039965095584`, 0.511640156687964, 0.9460287666877722], 
             UndirectedEdge[401, 475] -> 
             RGBColor[
              0.806227884360017, 0.5618744373452094, 0.5815185800497742], 
             UndirectedEdge[58, 141] -> 
             RGBColor[
              0.3123473120692484, 0.44496127550717535`, 0.9411234724205373], 
             UndirectedEdge[96, 180] -> 
             RGBColor[
              0.2831463385898367, 0.4149351327456384, 0.9394361371539964], 
             UndirectedEdge[119, 375] -> 
             RGBColor[
              0.9744244063754681, 0.9793738724475776, 0.8801494909995853], 
             UndirectedEdge[220, 382] -> 
             RGBColor[
              0.3105689508267532, 0.4409688726219141, 0.9410999393200739], 
             UndirectedEdge[104, 356] -> 
             RGBColor[
              0.2579557991377684, 0.3884582786090651, 0.9380015731982647], 
             UndirectedEdge[225, 440] -> 
             RGBColor[
              0.27796156594151966`, 0.4094856079586846, 0.9391408720218586], 
             UndirectedEdge[259, 341] -> 
             RGBColor[
              0.9277070351691528, 0.7270975616364004, 0.37415406223837167`], 
             UndirectedEdge[290, 362] -> 
             RGBColor[
              0.3374733904051481, 0.4646660623491092, 0.9427998432095333], 
             UndirectedEdge[79, 267] -> 
             RGBColor[
              0.9914456607402118, 0.9819881575780944, 0.49084130836277423`], 
             UndirectedEdge[90, 317] -> 
             RGBColor[
              0.8740850504741097, 0.5211314470341011, 0.21664581846880504`], 
             UndirectedEdge[41, 389] -> 
             RGBColor[
              0.2255132290582107, 0.3543590804777015, 0.9361540168267153], 
             UndirectedEdge[5, 300] -> 
             RGBColor[
              0.23228249418787045`, 0.3614740073251723, 0.936539516461619], 
             UndirectedEdge[290, 340] -> 
             RGBColor[
              0.31195990105564253`, 0.44256756021982796`, 0.9411741462288754],
              UndirectedEdge[288, 392] -> 
             RGBColor[
              0.281033651223698, 0.41271456437171095`, 0.9393158227339358], 
             UndirectedEdge[45, 292] -> 
             RGBColor[
              0.23087655194201073`, 0.35999627288288677`, 0.9364594501306225],
              UndirectedEdge[42, 145] -> 
             RGBColor[
              0.22656621784669417`, 0.3554658384577429, 0.9362139829804621], 
             UndirectedEdge[100, 368] -> 
             RGBColor[
              0.6696582512860165, 0.6464478563026956, 0.6053684569202311], 
             UndirectedEdge[302, 315] -> 
             RGBColor[
              0.18782448730516063`, 0.31474582329100176`, 0.934007698739376], 
             UndirectedEdge[255, 338] -> 
             RGBColor[
              0.35884542683277726`, 0.48523560545214284`, 0.9440862911766009],
              UndirectedEdge[59, 263] -> 
             RGBColor[
              0.25779587834217144`, 0.38829019171332857`, 0.9379924659455371],
              UndirectedEdge[413, 486] -> 
             RGBColor[
              0.9543818118224241, 0.9371774082640264, 0.6732568757445232], 
             UndirectedEdge[140, 247] -> 
             RGBColor[
              0.4973227229374232, 0.6027880164707773, 0.9535702129842454], 
             UndirectedEdge[82, 453] -> 
             RGBColor[
              0.27129272785642566`, 0.40247623630249474`, 0.9387610915585742],
              UndirectedEdge[199, 349] -> 
             RGBColor[
              0.3782226741008029, 0.5020192031069408, 0.9453209922378925], 
             UndirectedEdge[265, 462] -> 
             RGBColor[
              0.392446435384819, 0.5140523715462819, 0.9463065444803587], 
             UndirectedEdge[113, 386] -> 
             RGBColor[
              0.17905963034776856`, 0.3055334029047545, 0.9335085531020964], 
             UndirectedEdge[140, 219] -> 
             RGBColor[
              0.5129514818808725, 0.6154761470486363, 0.9548005661383041], 
             UndirectedEdge[13, 313] -> 
             RGBColor[
              0.2817870779153078, 0.4135064635946042, 0.939358729269428], 
             UndirectedEdge[74, 463] -> 
             RGBColor[
              0.2744156870316411, 0.4057586644026942, 0.9389389394635987], 
             UndirectedEdge[146, 415] -> 
             RGBColor[
              0.27247295826931617`, 0.4037167332973729, 0.9388283039345939], 
             UndirectedEdge[213, 475] -> 
             RGBColor[
              0.871604644354381, 0.4793529554696741, 0.21338119452328883`], 
             UndirectedEdge[49, 328] -> 
             RGBColor[
              0.4377638604952656, 0.5525889538048573, 0.9493917132424632], 
             UndirectedEdge[259, 450] -> 
             RGBColor[
              0.8397745913250846, 0.3013267240551166, 0.18550990071046175`], 
             UndirectedEdge[454, 500] -> 
             RGBColor[
              0.8596875442431727, 0.3945530129661969, 0.20223564129349905`], 
             UndirectedEdge[469, 495] -> 
             RGBColor[
              0.8513165746787745, 0.3922611978068248, 0.19664935782673318`], 
             UndirectedEdge[158, 182] -> 
             RGBColor[
              0.36805399542884243`, 0.4932116047339394, 0.9446730530247247], 
             UndirectedEdge[302, 347] -> 
             RGBColor[
              0.18453817917078433`, 0.311291705077802, 0.9338205483527805], 
             UndirectedEdge[87, 107] -> 
             RGBColor[
              0.1819624771956669, 0.3085844789930161, 0.9336738659357071], 
             UndirectedEdge[80, 307] -> 
             RGBColor[
              0.6296762406643908, 0.7079838947833768, 0.9655310968074982], 
             UndirectedEdge[159, 443] -> 
             RGBColor[
              0.877631072588452, 0.4692846461457165, 0.21683434670508697`], 
             UndirectedEdge[396, 443] -> 
             RGBColor[
              0.9640290207521414, 0.8833364286136021, 0.40253589756085995`], 
             UndirectedEdge[15, 452] -> 
             RGBColor[
              0.22909610908040262`, 0.3581249145487392, 0.9363580565435832], 
             UndirectedEdge[55, 250] -> 
             RGBColor[
              0.20796149957955015`, 0.33591109995170554`, 0.9351544717983624],
              UndirectedEdge[105, 447] -> 
             RGBColor[
              0.24620260884716, 0.3761049304183308, 0.9373322463985014], 
             UndirectedEdge[55, 242] -> 
             RGBColor[
              0.21824264556347417`, 0.34671723624311485`, 0.9357399678525544],
              UndirectedEdge[133, 440] -> 
             RGBColor[
              0.31342375230206637`, 0.44339062767442217`, 0.9412837095607336],
              UndirectedEdge[177, 455] -> 
             RGBColor[
              0.2063185988388122, 0.33418430710726665`, 0.9350609110316312], 
             UndirectedEdge[186, 456] -> 
             RGBColor[
              0.22968446940414386`, 0.35874331855319036`, 0.9363915627936191],
              UndirectedEdge[94, 302] -> 
             RGBColor[
              0.5727842186692342, 0.6417308063914131, 0.9472440733920693], 
             UndirectedEdge[146, 376] -> 
             RGBColor[
              0.2686941653913333, 0.39974498239330636`, 0.9386131072704159], 
             UndirectedEdge[44, 106] -> 
             RGBColor[
              0.5072662938524296, 0.6108606552923443, 0.9543530073111751], 
             UndirectedEdge[46, 205] -> 
             RGBColor[
              0.9557407049755898, 0.8502199530826348, 0.4110195083871594], 
             UndirectedEdge[134, 457] -> 
             RGBColor[
              0.22739772905471156`, 0.3563398094582248, 0.936261336313648], 
             UndirectedEdge[229, 248] -> 
             RGBColor[
              0.2667577277658053, 0.3977096636716398, 0.9385028300123448], 
             UndirectedEdge[101, 362] -> 
             RGBColor[
              0.45464713410545365`, 0.5663810460128507, 0.950697205214848], 
             UndirectedEdge[286, 346] -> 
             RGBColor[
              0.22049146079372114`, 0.3490808836332252, 0.935868034553093], 
             UndirectedEdge[134, 138] -> 
             RGBColor[
              0.2265863896100655, 0.3554870402600099, 0.9362151317325447], 
             UndirectedEdge[144, 494] -> 
             RGBColor[
              0.25236564813326057`, 0.3825826754672824, 0.9376832223684453], 
             UndirectedEdge[35, 147] -> 
             RGBColor[
              0.2449327987863818, 0.374770279533845, 0.9372599325940558], 
             UndirectedEdge[5, 211] -> 
             RGBColor[
              0.2348238735021131, 0.3641451581171964, 0.9366842442539314], 
             UndirectedEdge[243, 471] -> 
             RGBColor[
              0.8480593461920269, 0.37041077133751354`, 0.1936549902297403], 
             UndirectedEdge[154, 338] -> 
             RGBColor[
              0.314823265682197, 0.4471058220816644, 0.9412812379953546], 
             UndirectedEdge[185, 383] -> 
             RGBColor[
              0.3064436349421723, 0.43755476203867083`, 0.9408312549471323], 
             UndirectedEdge[416, 429] -> 
             RGBColor[
              0.2775658260011634, 0.4090696601900088, 0.9391183352177], 
             UndirectedEdge[159, 396] -> 
             RGBColor[
              0.9071481131704897, 0.5745522202562454, 0.3532052383412315], 
             UndirectedEdge[73, 322] -> 
             RGBColor[
              0.2535645087759725, 0.3838427540149276, 0.9377514957084923], 
             UndirectedEdge[287, 300] -> 
             RGBColor[
              0.2178846815571592, 0.3463409933762489, 0.9357195823319551], 
             UndirectedEdge[392, 459] -> 
             RGBColor[
              0.34827375514967984`, 0.47582519706689724`, 0.9434219649183455],
              UndirectedEdge[200, 450] -> 
             RGBColor[
              0.8592682454015592, 0.38984285435780597`, 0.20177588350505832`],
              UndirectedEdge[104, 148] -> 
             RGBColor[
              0.2431147548759032, 0.37285940011329033`, 0.9371563976829089], 
             UndirectedEdge[94, 325] -> 
             RGBColor[
              0.5672179996830251, 0.6358803573182399, 0.9469270854552878], 
             UndirectedEdge[355, 378] -> 
             RGBColor[
              0.30589561445696456`, 0.4370005514707954, 0.940799248016793], 
             UndirectedEdge[424, 453] -> 
             RGBColor[
              0.3024506322714007, 0.4341297008728973, 0.9405755985889044], 
             UndirectedEdge[212, 301] -> 
             RGBColor[
              0.2136344659280746, 0.34187374727084574`, 0.9354775388395093], 
             UndirectedEdge[46, 420] -> 
             RGBColor[
              0.9431488383406506, 0.8436851965616485, 0.5952825252201055], 
             UndirectedEdge[146, 284] -> 
             RGBColor[
              0.25151293220690424`, 0.3816864169633695, 0.9376346614579194], 
             UndirectedEdge[76, 343] -> 
             RGBColor[
              0.3521064049491038, 0.47793237749510553`, 0.9437105723744709], 
             UndirectedEdge[111, 256] -> 
             RGBColor[
              0.2812386903435383, 0.41293007348689414`, 0.9393274994084824], 
             UndirectedEdge[277, 319] -> 
             RGBColor[
              0.7430956081884199, 0.7992312039433723, 0.9750284836670953], 
             UndirectedEdge[240, 429] -> 
             RGBColor[
              0.2751117605214455, 0.4064902817740869, 0.9389785798190946], 
             UndirectedEdge[49, 71] -> 
             RGBColor[
              0.6229981269292593, 0.7030794824142605, 0.9646517716159538], 
             UndirectedEdge[19, 139] -> 
             RGBColor[
              0.5618798532479841, 0.6551984031224687, 0.9586523867628529], 
             UndirectedEdge[9, 247] -> 
             RGBColor[
              0.5350775301382318, 0.6334390697910756, 0.9565424097075088], 
             UndirectedEdge[333, 392] -> 
             RGBColor[
              0.34232526370384136`, 0.4706729127563853, 0.943042932303461], 
             UndirectedEdge[169, 337] -> 
             RGBColor[
              0.6764764422213522, 0.7452210038115648, 0.9698692373870139], 
             UndirectedEdge[21, 119] -> 
             RGBColor[
              0.9857675700825197, 0.9687962754074746, 0.5924568745131584], 
             UndirectedEdge[354, 479] -> 
             RGBColor[
              0.38662725868303643`, 0.5092988318453677, 0.9458565249355901], 
             UndirectedEdge[179, 236] -> 
             RGBColor[
              0.23312614698427564`, 0.36236073990487094`, 0.9365875612403018],
              UndirectedEdge[121, 341] -> 
             RGBColor[
              0.9105196563022746, 0.6003916270804778, 0.3579070077274834], 
             UndirectedEdge[263, 323] -> 
             RGBColor[
              0.2563726589916906, 0.3867942979386546, 0.9379114157089916], 
             UndirectedEdge[200, 401] -> 
             RGBColor[
              0.8371401925160188, 0.7327555556169211, 0.6085074799840489], 
             UndirectedEdge[56, 236] -> 
             RGBColor[
              0.5619983827153064, 0.35111011799079705`, 0.5612129978793174], 
             UndirectedEdge[374, 437] -> 
             RGBColor[
              0.25378039219455883`, 0.3840696611756612, 0.9377637899498099], 
             UndirectedEdge[74, 195] -> 
             RGBColor[
              0.27594296910076915`, 0.40736393469262394`, 0.9390259159180243],
              UndirectedEdge[240, 399] -> 
             RGBColor[
              0.24906325398775672`, 0.3791116498364756, 0.9374951559073132], 
             UndirectedEdge[138, 352] -> 
             RGBColor[
              0.22389864331585435`, 0.3526620484918363, 0.9360620685572537], 
             UndirectedEdge[195, 342] -> 
             RGBColor[
              0.265069534257383, 0.39593526525663725`, 0.9384066898894987], 
             UndirectedEdge[13, 363] -> 
             RGBColor[
              0.3507138092232281, 0.4770709297343131, 0.9436092144688942], 
             UndirectedEdge[368, 386] -> 
             RGBColor[
              0.2935143249909316, 0.4166464351270609, 0.9403629270800464], 
             UndirectedEdge[132, 233] -> 
             RGBColor[
              0.9166463543771588, 0.6614692040973338, 0.5010749461233683], 
             UndirectedEdge[304, 310] -> 
             RGBColor[
              0.317660558842397, 0.44845488439544834`, 0.9415026138990965], 
             UndirectedEdge[213, 259] -> 
             RGBColor[
              0.8830232984339081, 0.5617179434386964, 0.224104111662967], 
             UndirectedEdge[226, 446] -> 
             RGBColor[
              0.20378813280661343`, 0.33152462686661266`, 0.9349168047345866],
              UndirectedEdge[60, 249] -> 
             RGBColor[
              0.29112873348308044`, 0.42332513589150556`, 0.9398907227342717],
              UndirectedEdge[181, 387] -> 
             RGBColor[
              0.5979055016129029, 0.6815262817946347, 0.9631235948533272], 
             UndirectedEdge[94, 168] -> 
             RGBColor[
              0.9331056494970619, 0.8251500560931704, 0.6037137900969318], 
             UndirectedEdge[142, 402] -> 
             RGBColor[
              0.6259177691187879, 0.7063115685381091, 0.9642924066530247], 
             UndirectedEdge[188, 310] -> 
             RGBColor[
              0.3170171080071488, 0.4478975596227356, 0.9414616137808558], 
             UndirectedEdge[74, 239] -> 
             RGBColor[
              0.31633226480045645`, 0.4459153985127936, 0.9414688336983061], 
             UndirectedEdge[376, 400] -> 
             RGBColor[
              0.2876884645475003, 0.41970919511456195`, 0.9396948045078122], 
             UndirectedEdge[292, 308] -> 
             RGBColor[
              0.17895845847297373`, 0.30542706484967774`, 0.9335027915134972],
              UndirectedEdge[7, 142] -> 
             RGBColor[
              0.7691032060058948, 0.819699666861827, 0.9775805727504322], 
             UndirectedEdge[20, 194] -> 
             RGBColor[
              0.9355250585723344, 0.7786349412620628, 0.5492457614630861], 
             UndirectedEdge[168, 500] -> 
             RGBColor[
              0.8651424411448785, 0.41743131522220955`, 0.2066895157907081], 
             UndirectedEdge[4, 383] -> 
             RGBColor[
              0.32662308368104653`, 0.45732623135617084`, 0.9420331119640719],
              UndirectedEdge[91, 303] -> 
             RGBColor[
              0.3164436833902854, 0.44818690517109605`, 0.9413962957337874], 
             UndirectedEdge[142, 417] -> 
             RGBColor[
              0.7002784838355302, 0.7657821409766972, 0.9707608728603756], 
             UndirectedEdge[229, 338] -> 
             RGBColor[
              0.3055405634218271, 0.43742263545021065`, 0.9407499098335221], 
             UndirectedEdge[69, 388] -> 
             RGBColor[
              0.9278173046721767, 0.9450102776472538, 0.9836136557859578], 
             UndirectedEdge[170, 374] -> 
             RGBColor[
              0.2742054454433818, 0.40553768716334715`, 0.9389269665161719], 
             UndirectedEdge[96, 281] -> 
             RGBColor[
              0.27053519804586806`, 0.4016800244414347, 0.938717951356528], 
             UndirectedEdge[131, 265] -> 
             RGBColor[
              0.29231177765764305`, 0.42343428317537546`, 0.9399996278912657],
              UndirectedEdge[117, 369] -> 
             RGBColor[
              0.40051134864769267`, 0.5213245327381009, 0.9467412068709193], 
             UndirectedEdge[19, 247] -> 
             RGBColor[
              0.5273679540729146, 0.6271800886288073, 0.9559354836385393], 
             UndirectedEdge[328, 436] -> 
             RGBColor[
              0.42911640965865483`, 0.5455685636524759, 0.9487109542359491], 
             UndirectedEdge[86, 178] -> 
             RGBColor[
              0.9534388639235, 0.8461526483552239, 0.5190456011559075], 
             UndirectedEdge[42, 137] -> 
             RGBColor[
              0.22627740530250587`, 0.35516227816202806`, 0.9361975355333305],
              UndirectedEdge[54, 135] -> 
             RGBColor[
              0.23967378277683635`, 0.36924272026693905`, 0.9369604394123292],
              UndirectedEdge[42, 174] -> 
             RGBColor[
              0.2495656884148965, 0.3796397402755821, 0.9375237688046536], 
             UndirectedEdge[1, 374] -> 
             RGBColor[
              0.25894790578239785`, 0.38950104559576504`, 0.9380580722039861],
              UndirectedEdge[160, 285] -> 
             RGBColor[
              0.3684500451199806, 0.49355464307036695`, 0.9446982889608311], 
             UndirectedEdge[454, 471] -> 
             RGBColor[
              0.8783475046128462, 0.5379816452142798, 0.2201044404169093], 
             UndirectedEdge[26, 425] -> 
             RGBColor[
              0.38098619324606947`, 0.5044128244920598, 0.9454970812341448], 
             UndirectedEdge[333, 442] -> 
             RGBColor[
              0.331297230301234, 0.4590817504325423, 0.942414902115696], 
             UndirectedEdge[75, 410] -> 
             RGBColor[
              0.354306761585108, 0.48130444173456, 0.9437970914404035], 
             UndirectedEdge[31, 40] -> 
             RGBColor[
              0.4196192099941566, 0.5378748018473721, 0.9479587428994976], 
             UndirectedEdge[3, 258] -> 
             RGBColor[
              0.41754423807969365`, 0.5358508967798354, 0.9478891567573319], 
             UndirectedEdge[132, 273] -> 
             RGBColor[
              0.6418371637733833, 0.7080243687957053, 0.8766074186854609], 
             UndirectedEdge[157, 180] -> 
             RGBColor[
              0.2863372761085622, 0.4182890103949429, 0.9396178563251187], 
             UndirectedEdge[213, 401] -> 
             RGBColor[
              0.8388291376735261, 0.7404246611139982, 0.6099167772233072], 
             UndirectedEdge[84, 391] -> 
             RGBColor[
              0.23722076036640824`, 0.3666644381829753, 0.9368207434149767], 
             UndirectedEdge[43, 110] -> 
             RGBColor[
              0.2824315567297242, 0.4141838516908727, 0.9393954313844881], 
             UndirectedEdge[39, 127] -> 
             RGBColor[
              0.4248206994263658, 0.5301025431322064, 0.9498483295981558], 
             UndirectedEdge[52, 469] -> 
             RGBColor[
              0.8481128613393234, 0.36763605320366755`, 0.19358147831479822`],
              UndirectedEdge[260, 483] -> 
             RGBColor[
              0.2911128004849959, 0.42330838930030823`, 0.9398898153736015], 
             UndirectedEdge[98, 311] -> 
             RGBColor[
              0.8710458030481137, 0.8971927199459824, 0.8490560873664715], 
             UndirectedEdge[51, 127] -> 
             RGBColor[
              0.20245340605759676`, 0.3301217444268325, 0.9348407940207814], 
             UndirectedEdge[243, 475] -> 
             RGBColor[
              0.8391547501965229, 0.3019661444972231, 0.18512793904814284`], 
             UndirectedEdge[76, 96] -> 
             RGBColor[
              0.3537435180123586, 0.4796530871235497, 0.9438038035415315], 
             UndirectedEdge[99, 476] -> 
             RGBColor[
              0.9210569805098886, 0.6812525268241133, 0.37059559494700395`], 
             UndirectedEdge[107, 308] -> 
             RGBColor[
              0.18180898862834943`, 0.3084231527770282, 0.9336651249888644], 
             UndirectedEdge[190, 263] -> 
             RGBColor[
              0.26075513515246407`, 0.3914005582486648, 0.9381609912430551], 
             UndirectedEdge[191, 299] -> 
             RGBColor[
              0.21378387890714912`, 0.3420307897851831, 0.935486047687631], 
             UndirectedEdge[39, 276] -> 
             RGBColor[
              0.6216008719460259, 0.7036826165027719, 0.9633538441200625], 
             UndirectedEdge[51, 214] -> 
             RGBColor[
              0.1893670578318586, 0.31636716271918164`, 0.9340955458488429], 
             UndirectedEdge[295, 409] -> 
             RGBColor[
              0.23557177233220394`, 0.3649312472071466, 0.9367268359858879], 
             UndirectedEdge[371, 382] -> 
             RGBColor[
              0.322584307384319, 0.45137597056269757`, 0.9418655472151594], 
             UndirectedEdge[53, 420] -> 
             RGBColor[
              0.9725775680800968, 0.9542835451375451, 0.6506094324523175], 
             UndirectedEdge[87, 308] -> 
             RGBColor[
              0.17909977333492821`, 0.3055755957294717, 0.9335108391858289], 
             UndirectedEdge[286, 358] -> 
             RGBColor[
              0.22436323878386594`, 0.35315036778577047`, 0.9360885265818495],
              UndirectedEdge[215, 351] -> 
             RGBColor[
              0.28708427642095813`, 0.4190741550858264, 0.9396603968878219], 
             UndirectedEdge[114, 258] -> 
             RGBColor[
              0.4370504632160207, 0.551686929090934, 0.9494247582537205], 
             UndirectedEdge[87, 292] -> 
             RGBColor[
              0.1791119470402912, 0.3055883910656657, 0.93351153246034], 
             UndirectedEdge[196, 383] -> 
             RGBColor[
              0.3123209276016251, 0.4437321692656331, 0.941165958069413], 
             UndirectedEdge[65, 495] -> 
             RGBColor[
              0.9138336495538494, 0.6440119286541663, 0.2930402350354805], 
             UndirectedEdge[14, 279] -> 
             RGBColor[
              0.2926514518650601, 0.4249256094568878, 0.9399774392934654], 
             UndirectedEdge[26, 466] -> 
             RGBColor[
              0.4450688550450512, 0.558555224381097, 0.9499569121935232], 
             UndirectedEdge[27, 371] -> 
             RGBColor[
              0.43753141765926407`, 0.551792873087608, 0.9495412335023905], 
             UndirectedEdge[258, 472] -> 
             RGBColor[
              0.3509345795878789, 0.47838362717935545`, 0.9435822189854435], 
             UndirectedEdge[26, 117] -> 
             RGBColor[
              0.38385240519854513`, 0.5068953932252928, 0.9456797137252648], 
             UndirectedEdge[97, 104] -> 
             RGBColor[
              0.23915408747259903`, 0.3686964875516002, 0.936930843533573], 
             UndirectedEdge[21, 428] -> 
             RGBColor[
              0.9056106309029361, 0.5906771035003356, 0.2784668522610333], 
             UndirectedEdge[160, 268] -> 
             RGBColor[
              0.41606826400089775`, 0.5347991509037464, 0.9477324797607855], 
             UndirectedEdge[48, 137] -> 
             RGBColor[
              0.21379570916554433`, 0.34204322413683813`, 0.9354867214033452],
              UndirectedEdge[27, 291] -> 
             RGBColor[
              0.583523028601068, 0.6725767800031528, 0.9604878491746004], 
             UndirectedEdge[117, 140] -> 
             RGBColor[
              0.44035466890019287`, 0.5545772244209933, 0.9496274637964799], 
             UndirectedEdge[31, 221] -> 
             RGBColor[
              0.4948241717740719, 0.6007519845572706, 0.9533756165491586], 
             UndirectedEdge[87, 386] -> 
             RGBColor[
              0.17909013095112286`, 0.3055654609727298, 0.9335102900663359], 
             UndirectedEdge[207, 409] -> 
             RGBColor[
              0.22930932819200256`, 0.35834902135390323`, 0.9363701990565594],
              UndirectedEdge[274, 498] -> 
             RGBColor[
              0.46231188623512687`, 0.5743646420156336, 0.95081403167012], 
             UndirectedEdge[28, 69] -> 
             RGBColor[
              0.9371592911405698, 0.9519775158592825, 0.9678001094752631], 
             UndirectedEdge[442, 492] -> 
             RGBColor[
              0.2802823193946945, 0.4119248669822389, 0.9392730354977699], 
             UndirectedEdge[476, 493] -> 
             RGBColor[
              0.9210348441528622, 0.6812051793947629, 0.36818618909444256`], 
             UndirectedEdge[297, 359] -> 
             RGBColor[
              0.45240773600559087`, 0.5644812656494411, 0.9505434955218137], 
             UndirectedEdge[112, 323] -> 
             RGBColor[
              0.24380409586490398`, 0.37358394119947325`, 0.9371956546324439],
              UndirectedEdge[27, 349] -> 
             RGBColor[
              0.46286019331944683`, 0.5737313855031778, 0.9511551606901004], 
             UndirectedEdge[2, 242] -> 
             RGBColor[
              0.21872765624032725`, 0.34722701321594046`, 0.9357675884930923],
              UndirectedEdge[71, 462] -> 
             RGBColor[
              0.6098299518680684, 0.6923889646800596, 0.9636151246385223], 
             UndirectedEdge[165, 285] -> 
             RGBColor[
              0.3692257984681636, 0.49422656163006606`, 0.9447477192782054], 
             UndirectedEdge[91, 172] -> 
             RGBColor[
              0.33964065051404985`, 0.4686013934649852, 0.9428625798116885], 
             UndirectedEdge[19, 26] -> 
             RGBColor[
              0.4731770317838775, 0.5813747085166081, 0.9521696908300475], 
             UndirectedEdge[73, 163] -> 
             RGBColor[
              0.2574513896017804, 0.3879281122053299, 0.9379728478213971], 
             UndirectedEdge[67, 131] -> 
             RGBColor[
              0.2601160605037315, 0.39072885027317383`, 0.938124596887236], 
             UndirectedEdge[24, 81] -> 
             RGBColor[
              0.8302950804632105, 0.8675187756745408, 0.9836754800593912], 
             UndirectedEdge[282, 467] -> 
             RGBColor[
              0.6572487791197071, 0.7316354395209496, 0.9668355107224047], 
             UndirectedEdge[122, 406] -> 
             RGBColor[
              0.929061342775948, 0.7356327772399205, 0.3146046467534838], 
             UndirectedEdge[139, 255] -> 
             RGBColor[
              0.4808103528632557, 0.5878692632314095, 0.9526884189998513], 
             UndirectedEdge[409, 458] -> 
             RGBColor[
              0.23602745875437942`, 0.36541020252904094`, 0.9367527866535031],
              UndirectedEdge[4, 196] -> 
             RGBColor[
              0.31000149085861584`, 0.44172318973711877`, 0.9410181656111457],
              UndirectedEdge[46, 90] -> 
             RGBColor[
              0.8912123121580973, 0.5950344530170778, 0.2307371435474895], 
             UndirectedEdge[115, 124] -> 
             RGBColor[
              0.9419104649402625, 0.9128295501642687, 0.6508778471089514], 
             UndirectedEdge[330, 350] -> 
             RGBColor[
              0.33430977302587317`, 0.4637717331289171, 0.9425306751676419], 
             UndirectedEdge[213, 315] -> 
             RGBColor[
              0.5448527569683213, 0.48510270783243126`, 0.5878273462350064], 
             UndirectedEdge[107, 143] -> 
             RGBColor[
              0.18179934691843552`, 0.30841301872858895`, 0.9336645759077484],
              UndirectedEdge[403, 491] -> 
             RGBColor[
              0.9615367037861473, 0.968036714632053, 0.7994838663892643], 
             UndirectedEdge[200, 254] -> 
             RGBColor[
              0.5686631284014866, 0.5042350008222019, 0.5878701973527287], 
             UndirectedEdge[37, 304] -> 
             RGBColor[
              0.32210212279026273`, 0.45312324971607465`, 0.9417555543952225],
              UndirectedEdge[25, 392] -> 
             RGBColor[
              0.3096883372024623, 0.4424044474005129, 0.9409633362064942], 
             UndirectedEdge[231, 492] -> 
             RGBColor[
              0.2675328366491727, 0.39852435225280064`, 0.9385469713165818], 
             UndirectedEdge[22, 63] -> 
             RGBColor[
              0.4353760609281416, 0.5515225941640346, 0.948962755507775], 
             UndirectedEdge[201, 256] -> 
             RGBColor[
              0.2969224563599441, 0.4294147059783363, 0.9402206666810642], 
             UndirectedEdge[57, 92] -> 
             RGBColor[
              0.6051902881840892, 0.690359765316458, 0.9620619428523739], 
             UndirectedEdge[433, 462] -> 
             RGBColor[
              0.3946923083800721, 0.5159976338539112, 0.9464496495216687], 
             UndirectedEdge[286, 294] -> 
             RGBColor[
              0.23070650372322443`, 0.3598175414232626, 0.9364497661361264], 
             UndirectedEdge[319, 331] -> 
             RGBColor[
              0.775790689833521, 0.8249078922958527, 0.9782513878368327], 
             UndirectedEdge[222, 307] -> 
             RGBColor[
              0.456261635454359, 0.5691648443465238, 0.950417290103996], 
             UndirectedEdge[276, 283] -> 
             RGBColor[
              0.4003771577872324, 0.5049037920541919, 0.9484114336869224], 
             UndirectedEdge[464, 497] -> 
             RGBColor[
              0.23993020302659857`, 0.369512234207422, 0.9369750421662133], 
             UndirectedEdge[143, 283] -> 
             RGBColor[
              0.18007058028918088`, 0.3065959753911073, 0.9335661252056935], 
             UndirectedEdge[265, 433] -> 
             RGBColor[
              0.32326037843179023`, 0.45441362508374517`, 0.9418188433591128],
              UndirectedEdge[74, 234] -> 
             RGBColor[
              0.335156328175214, 0.4622198560830736, 0.94266828637108], 
             UndirectedEdge[17, 432] -> 
             RGBColor[
              0.8892978625365586, 0.9145659925119751, 0.9893032180859526], 
             UndirectedEdge[103, 118] -> 
             RGBColor[
              0.4027319052154037, 0.522513730131029, 0.9470855430392838], 
             UndirectedEdge[426, 489] -> 
             RGBColor[
              0.9301359936068372, 0.9447452859638352, 0.9006256116612403], 
             UndirectedEdge[277, 331] -> 
             RGBColor[
              0.8039966134471465, 0.8469425741957761, 0.9810626907032964], 
             UndirectedEdge[74, 112] -> 
             RGBColor[
              0.264998769293781, 0.3958608867931338, 0.938402659929509], 
             UndirectedEdge[80, 372] -> 
             RGBColor[
              0.6299979927875134, 0.7082451076516956, 0.9655564263132472], 
             UndirectedEdge[180, 281] -> 
             RGBColor[
              0.2575198022383923, 0.3880000182240208, 0.9379767438198447], 
             UndirectedEdge[263, 296] -> 
             RGBColor[
              0.2934102361450429, 0.4252910132115676, 0.9400364732085589], 
             UndirectedEdge[37, 141] -> 
             RGBColor[
              0.3076115395353609, 0.4405722348185699, 0.9408322272437397], 
             UndirectedEdge[18, 210] -> 
             RGBColor[
              0.8602238171594843, 0.4230516477625904, 0.20370370360755374`], 
             UndirectedEdge[279, 494] -> 
             RGBColor[
              0.2685318784304253, 0.3995744085078045, 0.9386038652680744], 
             UndirectedEdge[101, 337] -> 
             RGBColor[
              0.6905217138834787, 0.756623588079157, 0.9709749326217818], 
             UndirectedEdge[217, 378] -> 
             RGBColor[
              0.30140209308183147`, 0.4331084891066064, 0.9405129248082346], 
             UndirectedEdge[20, 62] -> 
             RGBColor[
              0.8509265138034974, 0.3513524058869604, 0.19479135055817565`], 
             UndirectedEdge[18, 56] -> 
             RGBColor[
              0.8605287644059905, 0.4253956059279722, 0.2039957214351967], 
             UndirectedEdge[444, 492] -> 
             RGBColor[
              0.2739561801729139, 0.4052756935597544, 0.9389127712277736], 
             UndirectedEdge[199, 427] -> 
             RGBColor[
              0.31117200287913815`, 0.44123930103287445`, 0.9411475887384059],
              UndirectedEdge[190, 463] -> 
             RGBColor[
              0.2576034897635375, 0.3880879791190439, 0.9379815097005972], 
             UndirectedEdge[139, 369] -> 
             RGBColor[
              0.49199130185999246`, 0.5975536392815464, 0.9534008591829983], 
             UndirectedEdge[10, 455] -> 
             RGBColor[
              0.21145152724630215`, 0.3395793403099965, 0.9353532237109508], 
             UndirectedEdge[52, 236] -> 
             RGBColor[
              0.5615591008027638, 0.3477336047164332, 0.5607923410237687], 
             UndirectedEdge[9, 19] -> 
             RGBColor[
              0.5674341026863339, 0.6597075930326068, 0.9590896376245259], 
             UndirectedEdge[33, 309] -> 
             RGBColor[
              0.9357225086078202, 0.7641455885442991, 0.35153908493080155`], 
             UndirectedEdge[341, 491] -> 
             RGBColor[
              0.9938674015539399, 0.9892913169617195, 0.5738826890360067], 
             UndirectedEdge[87, 143] -> 
             RGBColor[
              0.1790901316250143, 0.30556546168103244`, 0.933510290104713], 
             UndirectedEdge[110, 378] -> 
             RGBColor[
              0.2773998635716586, 0.40889522315397336`, 0.9391088839028592], 
             UndirectedEdge[401, 471] -> 
             RGBColor[
              0.8151324803555211, 0.6303190641854999, 0.5900456312313715], 
             UndirectedEdge[160, 165] -> 
             RGBColor[
              0.4232575021072018, 0.5410261076098133, 0.9481905716557255], 
             UndirectedEdge[13, 379] -> 
             RGBColor[
              0.3029577301181068, 0.43570701430378433`, 0.9405662393373586], 
             UndirectedEdge[210, 434] -> 
             RGBColor[
              0.9136331462118448, 0.6344185701788778, 0.48881376628200723`], 
             UndirectedEdge[308, 446] -> 
             RGBColor[
              0.2035487790418117, 0.3312730508839008, 0.9349031738917732], 
             UndirectedEdge[153, 395] -> 
             RGBColor[
              0.2549602684410159, 0.3853097859191623, 0.9378309821565751], 
             UndirectedEdge[24, 83] -> 
             RGBColor[
              0.878858858195596, 0.9062422138097157, 0.9883075365329024], 
             UndirectedEdge[133, 260] -> 
             RGBColor[
              0.31537504749154577`, 0.44544156263782575`, 0.9413948329350919],
              UndirectedEdge[83, 119] -> 
             RGBColor[
              0.9556965383033635, 0.9650210547273206, 0.8984817408494732], 
             UndirectedEdge[400, 464] -> 
             RGBColor[
              0.26989429594474446`, 0.40100639569761354`, 0.9386814529299987],
              UndirectedEdge[175, 320] -> 
             RGBColor[
              0.9721663810423609, 0.9780295691716399, 0.8991854671906325], 
             UndirectedEdge[39, 475] -> 
             RGBColor[
              0.731332489294519, 0.5030791649818271, 0.5742495342753344], 
             UndirectedEdge[289, 291] -> 
             RGBColor[
              0.5471490964494157, 0.6426680909259248, 0.9577289938124869], 
             UndirectedEdge[263, 342] -> 
             RGBColor[
              0.2666938975771815, 0.3976425740963284, 0.9384991949775311], 
             UndirectedEdge[311, 319] -> 
             RGBColor[
              0.7308732764235066, 0.7896830254754603, 0.9738102758609529], 
             UndirectedEdge[141, 304] -> 
             RGBColor[
              0.3240734635805927, 0.45511787857278996`, 0.9418706524258115], 
             UndirectedEdge[30, 43] -> 
             RGBColor[
              0.2805395184040802, 0.4121951994484624, 0.9392876826008625], 
             UndirectedEdge[85, 95] -> 
             RGBColor[
              0.22064923730827996`, 0.3492467167536353, 0.9358770196921877], 
             UndirectedEdge[305, 438] -> 
             RGBColor[
              0.23628821482403703`, 0.36568427369114076`, 0.9367676363259161],
              UndirectedEdge[23, 212] -> 
             RGBColor[
              0.22050887971367938`, 0.3490991920225246, 0.9358690265348157], 
             UndirectedEdge[80, 461] -> 
             RGBColor[
              0.8669992096038857, 0.8968058897416262, 0.9792822184041656], 
             UndirectedEdge[115, 439] -> 
             RGBColor[
              0.8910404321249454, 0.9159554702009634, 0.9894694259289032], 
             UndirectedEdge[136, 377] -> 
             RGBColor[
              0.9750328863705816, 0.980900148051852, 0.9271469902951855], 
             UndirectedEdge[27, 488] -> 
             RGBColor[
              0.640741608541348, 0.7172763695298137, 0.9661908624850168], 
             UndirectedEdge[70, 170] -> 
             RGBColor[
              0.2774653661360603, 0.408964070502262, 0.9391126141769994], 
             UndirectedEdge[268, 441] -> 
             RGBColor[
              0.4298935905497302, 0.5467739538792281, 0.9486134173432208], 
             UndirectedEdge[394, 445] -> 
             RGBColor[
              0.2291408986849781, 0.35817199126297306`, 0.9363606072453035], 
             UndirectedEdge[234, 393] -> 
             RGBColor[
              0.42489506401207827`, 0.5422301548105988, 0.9483541347345662], 
             UndirectedEdge[228, 388] -> 
             RGBColor[
              0.9696267022726579, 0.9734928770909221, 0.7321607638451979], 
             UndirectedEdge[8, 114] -> 
             RGBColor[
              0.5604860564407306, 0.6540668560845098, 0.9585426619725401], 
             UndirectedEdge[21, 164] -> 
             RGBColor[
              0.8992062375406565, 0.5414501296947882, 0.27233399794458657`], 
             UndirectedEdge[100, 454] -> 
             RGBColor[
              0.915548639391991, 0.7016340736991815, 0.25084192040061865`], 
             UndirectedEdge[6, 267] -> 
             RGBColor[
              0.9083762130299251, 0.9201045780958312, 0.6977188544044266], 
             UndirectedEdge[210, 495] -> 
             RGBColor[
              0.8391330927044698, 0.3017996755229297, 0.18510719980929416`], 
             UndirectedEdge[112, 342] -> 
             RGBColor[
              0.25412533445039487`, 0.3844322173571471, 0.9377834339009834], 
             UndirectedEdge[93, 206] -> 
             RGBColor[
              0.30600971855859727`, 0.43582355730741806`, 0.940853232846973], 
             UndirectedEdge[485, 497] -> 
             RGBColor[
              0.24199741678266362`, 0.3716850069339687, 0.9370927669314526], 
             UndirectedEdge[36, 240] -> 
             RGBColor[
              0.25550742159800177`, 0.3858848785786683, 0.9378621417194251], 
             UndirectedEdge[275, 285] -> 
             RGBColor[
              0.36406115169331943`, 0.4897532041763907, 0.9444186325526303], 
             UndirectedEdge[36, 399] -> 
             RGBColor[
              0.24794512185068096`, 0.37793642206673694`, 0.937431479936235], 
             UndirectedEdge[72, 279] -> 
             RGBColor[
              0.26627234056032795`, 0.3971994909433567, 0.9384751879290589], 
             UndirectedEdge[278, 413] -> 
             RGBColor[
              0.9610998830487185, 0.9422076271108857, 0.6625746129461039], 
             UndirectedEdge[10, 120] -> 
             RGBColor[
              0.21319195993880496`, 0.3414086454196232, 0.9354523387780493], 
             UndirectedEdge[59, 153] -> 
             RGBColor[
              0.24356203444566857`, 0.3733295193002764, 0.9371818695927163], 
             UndirectedEdge[377, 488] -> 
             RGBColor[
              0.8752347056162003, 0.9025906545325564, 0.9472574998794909], 
             UndirectedEdge[53, 306] -> 
             RGBColor[
              0.9170459103045016, 0.6880097948516692, 0.28301334457340965`], 
             UndirectedEdge[172, 448] -> 
             RGBColor[
              0.45979588464643895`, 0.5695615806771241, 0.9513786855523698], 
             UndirectedEdge[138, 367] -> 
             RGBColor[
              0.22490572664447084`, 0.3537205569229832, 0.9361194204629721], 
             UndirectedEdge[71, 431] -> 
             RGBColor[
              0.602160734252356, 0.6860330125252593, 0.9630472221226452], 
             UndirectedEdge[180, 392] -> 
             RGBColor[
              0.2880661676144659, 0.4201061849857004, 0.9397163141387143], 
             UndirectedEdge[33, 227] -> 
             RGBColor[
              0.8620227096886874, 0.44626803209664856`, 0.20579398688200412`],
              UndirectedEdge[30, 384] -> 
             RGBColor[
              0.2758760121335012, 0.4072935586747084, 0.9390221028177923], 
             UndirectedEdge[441, 467] -> 
             RGBColor[
              0.5784857852356426, 0.6676055963951182, 0.960658898554645], 
             UndirectedEdge[99, 122] -> 
             RGBColor[
              0.930562919133284, 0.740007623770434, 0.37913808172539787`], 
             UndirectedEdge[89, 225] -> 
             RGBColor[
              0.2798755048828646, 0.4114972791367759, 0.9392498680131491], 
             UndirectedEdge[146, 497] -> 
             RGBColor[
              0.24696343657246012`, 0.3769046085968852, 0.9373755744119134], 
             UndirectedEdge[176, 197] -> 
             RGBColor[
              0.6522851143834272, 0.7277468526483104, 0.9663482548197164], 
             UndirectedEdge[326, 474] -> 
             RGBColor[
              0.9341363327937491, 0.7587482425843726, 0.49080863680582576`], 
             UndirectedEdge[173, 241] -> 
             RGBColor[
              0.8450225482014433, 0.8788658384170731, 0.9383874109586698], 
             UndirectedEdge[403, 405] -> 
             RGBColor[
              0.9614623294969025, 0.9678776355477525, 0.7913886839898783], 
             UndirectedEdge[79, 476] -> 
             RGBColor[
              0.9211605712027758, 0.6814740968415736, 0.3818708025801312], 
             UndirectedEdge[46, 257] -> 
             RGBColor[
              0.8882541401217813, 0.5816020846987996, 0.22826877228895565`], 
             UndirectedEdge[450, 491] -> 
             RGBColor[
              0.9059349577098716, 0.5635204793804358, 0.38523852750809673`], 
             UndirectedEdge[200, 243] -> 
             RGBColor[
              0.8700670583525245, 0.4728472627689348, 0.21211683898241762`], 
             UndirectedEdge[296, 424] -> 
             RGBColor[
              0.31700712622472516`, 0.4489973723195799, 0.9414203916580124], 
             UndirectedEdge[269, 466] -> 
             RGBColor[
              0.47622375697085434`, 0.5855400345383266, 0.9519420749950372], 
             UndirectedEdge[74, 453] -> 
             RGBColor[
              0.2830204227561394, 0.41480278722089764`, 0.9394289664335431], 
             UndirectedEdge[18, 469] -> 
             RGBColor[
              0.8724072991337889, 0.5135131700464854, 0.21524586162499276`], 
             UndirectedEdge[279, 481] -> 
             RGBColor[
              0.2983884604335446, 0.4300799385434647, 0.9403362145723715], 
             UndirectedEdge[19, 468] -> 
             RGBColor[
              0.5190507751439478, 0.6204278280896312, 0.9552807248464208], 
             UndirectedEdge[415, 464] -> 
             RGBColor[
              0.2654397247234546, 0.39632435890790974`, 0.9384277716888938], 
             UndirectedEdge[234, 262] -> 
             RGBColor[
              0.4323322286458682, 0.548267980100758, 0.9489396155777698], 
             UndirectedEdge[241, 417] -> 
             RGBColor[
              0.7032574015004508, 0.7681092940971459, 0.9710577835336467], 
             UndirectedEdge[309, 489] -> 
             RGBColor[
              0.9915641796444485, 0.9888374754562259, 0.6482959890771074], 
             UndirectedEdge[83, 426] -> 
             RGBColor[
              0.895460047558787, 0.9194795515806435, 0.9898909727944203], 
             UndirectedEdge[6, 99] -> 
             RGBColor[
              0.9106556765920616, 0.9271034208247384, 0.765274234275318], 
             UndirectedEdge[121, 491] -> 
             RGBColor[
              0.9108136867178351, 0.6010205284083265, 0.38991040391585896`], 
             UndirectedEdge[42, 358] -> 
             RGBColor[
              0.22905024080537584`, 0.3580767040834695, 0.9363554444131764], 
             UndirectedEdge[69, 461] -> 
             RGBColor[
              0.926959006974305, 0.9443701606295145, 0.985066529908563], 
             UndirectedEdge[161, 387] -> 
             RGBColor[
              0.8827228822801044, 0.901646814849579, 0.6975808353380122], 
             UndirectedEdge[117, 390] -> 
             RGBColor[
              0.34091437037852435`, 0.46896566133560236`, 0.9429707972165], 
             UndirectedEdge[244, 334] -> 
             RGBColor[
              0.3726225537176192, 0.4971686603012616, 0.9449641575190681], 
             UndirectedEdge[173, 493] -> 
             RGBColor[
              0.9890701085039466, 0.9882775676582451, 0.7238989830539463], 
             UndirectedEdge[229, 255] -> 
             RGBColor[
              0.34428066244060973`, 0.47097736208628804`, 0.9432183946864745],
              UndirectedEdge[39, 401] -> 
             RGBColor[
              0.6985569826136641, 0.7641508706261513, 0.9707851169753527], 
             UndirectedEdge[379, 380] -> 
             RGBColor[
              0.29107513038505384`, 0.42321764858400834`, 0.9398895428612922],
              UndirectedEdge[92, 140] -> 
             RGBColor[
              0.554385826473297, 0.649114414584719, 0.9580624295236251], 
             UndirectedEdge[78, 97] -> 
             RGBColor[
              0.22558180327383132`, 0.35443115632617517`, 0.9361579220268484],
              UndirectedEdge[395, 463] -> 
             RGBColor[
              0.2660424669485921, 0.39695787920259357`, 0.9384620969669382], 
             UndirectedEdge[174, 338] -> 
             RGBColor[
              0.29338121786998295`, 0.4246423923281867, 0.9400574530924843], 
             UndirectedEdge[143, 423] -> 
             RGBColor[
              0.1833764464098977, 0.31007065028799885`, 0.9337543893906777], 
             UndirectedEdge[94, 100] -> 
             RGBColor[
              0.943316965793535, 0.8656345224892459, 0.6119300548794735], 
             UndirectedEdge[404, 408] -> 
             RGBColor[
              0.2179764205636531, 0.3464374168886629, 0.9357248067326592], 
             UndirectedEdge[301, 389] -> 
             RGBColor[
              0.21362623144598136`, 0.3418650923080694, 0.9354770698979359], 
             UndirectedEdge[16, 422] -> 
             RGBColor[
              0.3189470428658002, 0.4437679620863825, 0.9417969982435161], 
             UndirectedEdge[389, 451] -> 
             RGBColor[
              0.21497280031897864`, 0.34328042157098726`, 0.9355537550031829],
              UndirectedEdge[74, 296] -> 
             RGBColor[
              0.2975769167094639, 0.42967045866758025`, 0.9402737595026511], 
             UndirectedEdge[225, 453] -> 
             RGBColor[
              0.2792780627176027, 0.4108693295410645, 0.939215844565674], 
             UndirectedEdge[340, 378] -> 
             RGBColor[
              0.31025949401998754`, 0.4407803246133216, 0.9410773105637218], 
             UndirectedEdge[52, 428] -> 
             RGBColor[
              0.8330642703587228, 0.25515204759860854`, 0.17929568867725226`],
              UndirectedEdge[84, 230] -> 
             RGBColor[
              0.22859615804425376`, 0.3575994343110202, 0.9363295850716857], 
             UndirectedEdge[119, 237] -> 
             RGBColor[
              0.9483698835729416, 0.9591789791220269, 0.8977829179807035], 
             UndirectedEdge[67, 171] -> 
             RGBColor[
              0.25918264815811415`, 0.38974777471616917`, 0.9380714404350129],
              UndirectedEdge[25, 157] -> 
             RGBColor[
              0.3079594456965586, 0.4405872728097553, 0.9408648783928987], 
             UndirectedEdge[124, 484] -> 
             RGBColor[
              0.9777721242086441, 0.9364424046411297, 0.38854804229456463`], 
             UndirectedEdge[368, 500] -> 
             RGBColor[
              0.6137971561371982, 0.33936679556971105`, 0.5567621778131115], 
             UndirectedEdge[283, 422] -> 
             RGBColor[
              0.207613081778549, 0.3355448907518888, 0.9351346299200334], 
             UndirectedEdge[334, 369] -> 
             RGBColor[
              0.4113757512055576, 0.5307347321729735, 0.9474334769948924], 
             UndirectedEdge[42, 346] -> 
             RGBColor[
              0.22517846281523107`, 0.3540072199309242, 0.9361349523844199], 
             UndirectedEdge[112, 263] -> 
             RGBColor[
              0.2608320887293601, 0.39148144133712115`, 0.9381653736354167], 
             UndirectedEdge[146, 201] -> 
             RGBColor[
              0.28119600247616383`, 0.41288520583171645`, 0.9393250683975864],
              UndirectedEdge[16, 243] -> 
             RGBColor[
              0.6215940953786275, 0.41368682466407874`, 0.566114433864064], 
             UndirectedEdge[285, 481] -> 
             RGBColor[
              0.3163175193458222, 0.44840006950172373`, 0.9413764505174842], 
             UndirectedEdge[231, 444] -> 
             RGBColor[
              0.2648697036740537, 0.39572523064356746`, 0.938395309833401], 
             UndirectedEdge[137, 408] -> 
             RGBColor[
              0.2212925375899113, 0.34992286613722345`, 0.9359136546915492], 
             UndirectedEdge[431, 436] -> 
             RGBColor[
              0.46072987194196846`, 0.5729505557434673, 0.9507253360979548], 
             UndirectedEdge[98, 277] -> 
             RGBColor[
              0.8832681348130269, 0.9067408984138945, 0.8502742951726139], 
             UndirectedEdge[131, 391] -> 
             RGBColor[
              0.2523681386345833, 0.3825852931420795, 0.9376833641988113], 
             UndirectedEdge[52, 227] -> 
             RGBColor[
              0.8407131059122084, 0.31394434940381033`, 0.18662022224139424`],
              UndirectedEdge[27, 419] -> 
             RGBColor[
              0.5124047260338506, 0.6150322660209537, 0.9547575235151939], 
             UndirectedEdge[232, 312] -> 
             RGBColor[
              0.3303045820158528, 0.4601142095117522, 0.9422823672274991], 
             UndirectedEdge[247, 466] -> 
             RGBColor[
              0.4992597773340883, 0.6043606044932961, 0.953722705002015], 
             UndirectedEdge[253, 484] -> 
             RGBColor[
              0.9889617727140382, 0.9876413426482502, 0.6827040059696212], 
             UndirectedEdge[121, 200] -> 
             RGBColor[
              0.8641469744095227, 0.4273429033856967, 0.2064477599128205], 
             UndirectedEdge[79, 99] -> 
             RGBColor[
              0.9937251243023482, 0.9889870003070016, 0.5583966882336657], 
             UndirectedEdge[109, 300] -> 
             RGBColor[
              0.23995882574419874`, 0.3695423184984049, 0.9369766721876371], 
             UndirectedEdge[31, 397] -> 
             RGBColor[
              0.40579315804314603`, 0.5258993705649835, 0.947077759095077], 
             UndirectedEdge[70, 374] -> 
             RGBColor[
              0.2549902427614091, 0.38534129083037727`, 0.9378326891497786], 
             UndirectedEdge[240, 352] -> 
             RGBColor[
              0.24222822396059346`, 0.3719275999119933, 0.937105911058787], 
             UndirectedEdge[105, 323] -> 
             RGBColor[
              0.24262496833818112`, 0.37234460340788433`, 0.93712850506416], 
             UndirectedEdge[46, 53] -> 
             RGBColor[
              0.9470835767696775, 0.821834287485996, 0.3079282681448157], 
             UndirectedEdge[221, 223] -> 
             RGBColor[
              0.46323693275442124`, 0.5733927057392445, 0.9513629056103252], 
             UndirectedEdge[33, 159] -> 
             RGBColor[
              0.8495822086293704, 0.3506448894924134, 0.19388094901806585`], 
             UndirectedEdge[16, 454] -> 
             RGBColor[
              0.6518822537994468, 0.581257698540845, 0.5925638840512331], 
             UndirectedEdge[195, 224] -> 
             RGBColor[
              0.28455910865490164`, 0.41642004365881735`, 0.9395165923191959],
              UndirectedEdge[259, 500] -> 
             RGBColor[
              0.8406666807462297, 0.3081837142621151, 0.18636416654762122`], 
             UndirectedEdge[24, 77] -> 
             RGBColor[
              0.7218949448567346, 0.7822619477143448, 0.9732512022240677], 
             UndirectedEdge[226, 386] -> 
             RGBColor[
              0.1791759961486071, 0.30565571073945375`, 0.9335151799623065], 
             UndirectedEdge[289, 314] -> 
             RGBColor[
              0.3847232625603534, 0.5076496861015274, 0.9457352039862904], 
             UndirectedEdge[179, 325] -> 
             RGBColor[
              0.1789730287155782, 0.30544237909846184`, 0.9335036212672588], 
             UndirectedEdge[81, 83] -> 
             RGBColor[
              0.8721819244967113, 0.9009182081187621, 0.9876706846361336], 
             UndirectedEdge[312, 376] -> 
             RGBColor[
              0.2919333190231436, 0.4241708063077816, 0.9399365426905006], 
             UndirectedEdge[270, 309] -> 
             RGBColor[
              0.9915269265441726, 0.9888220703419007, 0.6489133693566129], 
             UndirectedEdge[139, 269] -> 
             RGBColor[
              0.506487260336648, 0.6101093099259678, 0.9543245288388581], 
             UndirectedEdge[269, 425] -> 
             RGBColor[
              0.4121410951718726, 0.5313976346492894, 0.947482244035659], 
             UndirectedEdge[25, 492] -> 
             RGBColor[
              0.29499729755319337`, 0.42696323326341856`, 0.9401267032319138],
              UndirectedEdge[142, 173] -> 
             RGBColor[
              0.8420436305365226, 0.8765386852966244, 0.9380905002853989], 
             UndirectedEdge[132, 209] -> 
             RGBColor[
              0.7780282420345992, 0.8243344980363514, 0.8860787195432924], 
             UndirectedEdge[389, 409] -> 
             RGBColor[
              0.23002772223876133`, 0.35910409904586005`, 0.9364111105347535],
              UndirectedEdge[337, 370] -> 
             RGBColor[
              0.7258270188663856, 0.785286025150145, 0.9737542955576297], 
             UndirectedEdge[230, 242] -> 
             RGBColor[
              0.2244428247428983, 0.35323401767475476`, 0.9360930588844796], 
             UndirectedEdge[28, 461] -> 
             RGBColor[
              0.954655789916814, 0.9657029428810652, 0.9616400993934879], 
             UndirectedEdge[318, 350] -> 
             RGBColor[
              0.3520561578815369, 0.47935508192515797`, 0.9436536849625428], 
             UndirectedEdge[390, 478] -> 
             RGBColor[
              0.2833977050944594, 0.41519933487955374`, 0.9394504521045712], 
             UndirectedEdge[167, 434] -> 
             RGBColor[
              0.988936416573675, 0.989692938179159, 0.8330157392176978], 
             UndirectedEdge[247, 269] -> 
             RGBColor[
              0.47197536116157857`, 0.5820909954323062, 0.9516076257145445], 
             UndirectedEdge[394, 398] -> 
             RGBColor[
              0.24489676758341208`, 0.3747324084550136, 0.93725788067035], 
             UndirectedEdge[14, 158] -> 
             RGBColor[
              0.33213200521333075`, 0.4619125616859979, 0.9423909174068014], 
             UndirectedEdge[131, 433] -> 
             RGBColor[
              0.29455765065289613`, 0.4253795454830047, 0.9401427329325757], 
             UndirectedEdge[87, 422] -> 
             RGBColor[
              0.2066326331143824, 0.33451437704181397`, 0.9350787948190529], 
             UndirectedEdge[210, 469] -> 
             RGBColor[
              0.8482471960053599, 0.3686686083126496, 0.19371011734270402`], 
             UndirectedEdge[312, 414] -> 
             RGBColor[
              0.2895347527456831, 0.421649761072285, 0.9397999478893602], 
             UndirectedEdge[277, 311] -> 
             RGBColor[
              0.7590792000371321, 0.8117177073753836, 0.9766215787274166], 
             UndirectedEdge[332, 424] -> 
             RGBColor[
              0.36139324266635137`, 0.48744239547023754`, 0.9442486357485711],
              UndirectedEdge[328, 433] -> 
             RGBColor[
              0.35540962848104596`, 0.48225968960811955`, 0.9438673651437858],
              UndirectedEdge[88, 428] -> 
             RGBColor[
              0.8484718113152332, 0.36067584148776255`, 0.1935446274280821], 
             UndirectedEdge[8, 162] -> 
             RGBColor[
              0.5411625228784538, 0.6383791410233868, 0.9570214426260819], 
             UndirectedEdge[27, 289] -> 
             RGBColor[
              0.47574498443284424`, 0.5848915439571711, 0.9519761681862727], 
             UndirectedEdge[192, 280] -> 
             RGBColor[
              0.25575350846358835`, 0.3861435314772083, 0.9378761560023672], 
             UndirectedEdge[347, 477] -> 
             RGBColor[
              0.2117993137193227, 0.3399448859440771, 0.9353730296360853], 
             UndirectedEdge[145, 346] -> 
             RGBColor[
              0.21927041175810352`, 0.3477974836778107, 0.9357984976168947], 
             UndirectedEdge[232, 415] -> 
             RGBColor[
              0.3216051563189196, 0.45097056152882875`, 0.9417869478037058], 
             UndirectedEdge[189, 374] -> 
             RGBColor[
              0.2557528431125027, 0.3861428321510315, 0.9378761181116072], 
             UndirectedEdge[139, 140] -> 
             RGBColor[
              0.5318346221124927, 0.6308063309644387, 0.9562871161085591], 
             UndirectedEdge[134, 251] -> 
             RGBColor[
              0.24587579480159133`, 0.37576142813523083`, 0.9373136348220843],
              UndirectedEdge[67, 281] -> 
             RGBColor[
              0.25076586641156884`, 0.38090120344576484`, 0.93759211716606], 
             UndirectedEdge[167, 495] -> 
             RGBColor[0.9144363630663, 0.657074043523211, 0.5293091727449846],
              UndirectedEdge[143, 179] -> 
             RGBColor[
              0.17892806920489446`, 0.30539512380213557`, 0.933501060889637], 
             UndirectedEdge[21, 175] -> 
             RGBColor[
              0.9683090151158134, 0.9568481859192783, 0.670037151361724], 
             UndirectedEdge[366, 473] -> 
             RGBColor[
              0.29591877827497415`, 0.42668767083692927`, 0.940224732684648], 
             UndirectedEdge[143, 292] -> 
             RGBColor[
              0.1789488167630598, 0.30541693080123855`, 0.9335022424323813], 
             UndirectedEdge[267, 486] -> 
             RGBColor[
              0.9619951023866931, 0.9628588250229391, 0.7028330719374227], 
             UndirectedEdge[248, 380] -> 
             RGBColor[
              0.257695358998007, 0.3881845395093172, 0.937986741517592], 
             UndirectedEdge[48, 407] -> 
             RGBColor[
              0.2109346093646478, 0.33903602684189116`, 0.935323786002302], 
             UndirectedEdge[436, 459] -> 
             RGBColor[
              0.4317329658175249, 0.5478348930853527, 0.9488776788806625], 
             UndirectedEdge[235, 262] -> 
             RGBColor[
              0.416563768888231, 0.5346101328045243, 0.9479348632655147], 
             UndirectedEdge[236, 283] -> 
             RGBColor[
              0.23426865806856206`, 0.3635615914938426, 0.9366526255563583], 
             UndirectedEdge[99, 493] -> 
             RGBColor[
              0.9935993972524345, 0.9887180828601909, 0.5447120747479771], 
             UndirectedEdge[109, 456] -> 
             RGBColor[
              0.23880926652767986`, 0.3683340588755796, 0.9369112064908769], 
             UndirectedEdge[208, 289] -> 
             RGBColor[
              0.3807447886449092, 0.5042037319598828, 0.9454816991464247], 
             UndirectedEdge[266, 410] -> 
             RGBColor[
              0.326592877843097, 0.45552256223454524`, 0.9420962704893343], 
             UndirectedEdge[299, 301] -> 
             RGBColor[
              0.20895952840977988`, 0.3369600915309596, 0.9352113080637927], 
             UndirectedEdge[314, 359] -> 
             RGBColor[
              0.3577633677707141, 0.48429838027845357`, 0.9440173433299934], 
             UndirectedEdge[209, 214] -> 
             RGBColor[
              0.3828653435329973, 0.49291080046599856`, 0.946830407391962], 
             UndirectedEdge[210, 326] -> 
             RGBColor[
              0.8556196126725499, 0.40214503052670025`, 0.19986184252427644`],
              UndirectedEdge[53, 317] -> 
             RGBColor[
              0.9299563150856899, 0.7479312815030192, 0.29383694306613123`], 
             UndirectedEdge[402, 459] -> 
             RGBColor[
              0.4714286755649022, 0.5800616585296188, 0.952002670562152], 
             UndirectedEdge[89, 249] -> 
             RGBColor[
              0.28752479280706156`, 0.41953716573797317`, 0.9396854836443249],
              UndirectedEdge[67, 135] -> 
             RGBColor[
              0.2536249197696536, 0.3839062497995648, 0.9377549360252124], 
             UndirectedEdge[90, 178] -> 
             RGBColor[
              0.9282272067510295, 0.7348311823756897, 0.4981717768803556], 
             UndirectedEdge[174, 229] -> 
             RGBColor[
              0.2788164534778155, 0.4103841489623319, 0.9391895566023578], 
             UndirectedEdge[266, 364] -> 
             RGBColor[
              0.2740437091478759, 0.405367692062097, 0.9389177558734103], 
             UndirectedEdge[407, 430] -> 
             RGBColor[
              0.22704868393744712`, 0.35597294090924125`, 0.9362414587105858],
              UndirectedEdge[217, 355] -> 
             RGBColor[
              0.32421328138501737`, 0.4552389817275355, 0.9418795614926734], 
             UndirectedEdge[176, 426] -> 
             RGBColor[
              0.7385594994235554, 0.7955507282121491, 0.9748396268265297], 
             UndirectedEdge[280, 483] -> 
             RGBColor[
              0.2767707745378052, 0.40823401069284493`, 0.939073058213035], 
             UndirectedEdge[51, 347] -> 
             RGBColor[
              0.1789270004053139, 0.3053940004260106, 0.9335010000230821], 
             UndirectedEdge[152, 451] -> 
             RGBColor[
              0.20772437674817806`, 0.3356618688214776, 0.9351409680039076], 
             UndirectedEdge[105, 342] -> 
             RGBColor[
              0.252946206923672, 0.38319287956555814`, 0.9377162843326995], 
             UndirectedEdge[318, 496] -> 
             RGBColor[
              0.3094159330482752, 0.43947691523709653`, 0.9410445311268166], 
             UndirectedEdge[114, 289] -> 
             RGBColor[
              0.47002476811242727`, 0.580247614655448, 0.9515258518036867], 
             UndirectedEdge[103, 331] -> 
             RGBColor[
              0.6585237003454188, 0.7308163449939742, 0.968260051050067], 
             UndirectedEdge[107, 113] -> 
             RGBColor[
              0.18193197659231264`, 0.3085524209250408, 0.9336721289714678], 
             UndirectedEdge[16, 56] -> 
             RGBColor[
              0.6202778449645745, 0.4035695471970573, 0.5648539909810746], 
             UndirectedEdge[140, 370] -> 
             RGBColor[
              0.5455387009707735, 0.6419319195433083, 0.9573659513959778], 
             UndirectedEdge[213, 500] -> 
             RGBColor[
              0.8618492799802115, 0.40436895006188167`, 0.20403944658147605`],
              UndirectedEdge[280, 327] -> 
             RGBColor[
              0.25698076875714937`, 0.3874334598585377, 0.9379460466605166], 
             UndirectedEdge[76, 238] -> 
             RGBColor[
              0.36573961104663694`, 0.49120700130641426`, 0.9445255824984202],
              UndirectedEdge[253, 261] -> 
             RGBColor[
              0.9325093316648222, 0.7680041432668934, 0.5596474808987255], 
             UndirectedEdge[232, 350] -> 
             RGBColor[
              0.3591838096222978, 0.48552869561681206`, 0.944107852628729], 
             UndirectedEdge[166, 320] -> 
             RGBColor[
              0.9133614547699682, 0.6417853106074096, 0.5113435478107814], 
             UndirectedEdge[33, 119] -> 
             RGBColor[
              0.9345308133147854, 0.7655949021985857, 0.5124594755699873], 
             UndirectedEdge[71, 228] -> 
             RGBColor[
              0.8744314209010298, 0.8983757407693698, 0.7323068273714743], 
             UndirectedEdge[50, 244] -> 
             RGBColor[
              0.3916895278498226, 0.5136835149605915, 0.9461790882505088], 
             UndirectedEdge[235, 344] -> 
             RGBColor[
              0.4103923521286693, 0.5295998986599555, 0.9474490267315575], 
             UndirectedEdge[72, 494] -> 
             RGBColor[
              0.25624399533436604`, 0.3866590642770594, 0.9379040885040477], 
             UndirectedEdge[185, 496] -> 
             RGBColor[
              0.2804171463023576, 0.4120665786107125, 0.9392807136907027], 
             UndirectedEdge[106, 370] -> 
             RGBColor[
              0.5546493379031965, 0.6493283450345659, 0.9580831741086608], 
             UndirectedEdge[51, 113] -> 
             RGBColor[
              0.17905963075308248`, 0.3055334033307651, 0.9335085531251784], 
             UndirectedEdge[422, 443] -> 
             RGBColor[
              0.5842619922483114, 0.5706803433206208, 0.6014015077150748], 
             UndirectedEdge[4, 335] -> 
             RGBColor[
              0.3005379095306292, 0.4317763657356928, 0.9404792286546308], 
             UndirectedEdge[1, 84] -> 
             RGBColor[
              0.249739891419232, 0.3798228386782472, 0.9375336894080404], 
             UndirectedEdge[90, 272] -> 
             RGBColor[
              0.8426763546129947, 0.3190239891395971, 0.18810823554711417`], 
             UndirectedEdge[213, 450] -> 
             RGBColor[
              0.8609571905590665, 0.3975119598548832, 0.20318518074431657`], 
             UndirectedEdge[5, 212] -> 
             RGBColor[
              0.22856179646777947`, 0.35756331811549596`, 0.9363276282307389],
              UndirectedEdge[50, 106] -> 
             RGBColor[
              0.47939668252268425`, 0.5878987040064534, 0.9522518873645769], 
             UndirectedEdge[115, 291] -> 
             RGBColor[
              0.7880477603543681, 0.8351660025398585, 0.9792918656511329], 
             UndirectedEdge[9, 117] -> 
             RGBColor[
              0.4781094761010015, 0.5852282777412916, 0.9525996605197433], 
             UndirectedEdge[194, 388] -> 
             RGBColor[
              0.9663440953419832, 0.9740339462184904, 0.9245637966956991], 
             UndirectedEdge[202, 211] -> 
             RGBColor[
              0.2350487330765592, 0.3643814997868598, 0.9366970496740461], 
             UndirectedEdge[113, 308] -> 
             RGBColor[
              0.17906927273157397`, 0.3055435376614964, 0.9335091022215896], 
             UndirectedEdge[51, 421] -> 
             RGBColor[
              0.17899180329589925`, 0.30546211237275633`, 0.9335046904518336],
              UndirectedEdge[109, 335] -> 
             RGBColor[
              0.2653660882581673, 0.3962469623140712, 0.938423578201131], 
             UndirectedEdge[278, 329] -> 
             RGBColor[
              0.9154608124727537, 0.9351010298249371, 0.9804756251775316], 
             UndirectedEdge[129, 206] -> 
             RGBColor[
              0.3491669657996257, 0.47685260895882275`, 0.9434695881978956], 
             UndirectedEdge[166, 227] -> 
             RGBColor[
              0.8418757895124331, 0.32288124504634075`, 0.18773360937003286`],
              UndirectedEdge[294, 411] -> 
             RGBColor[
              0.23895135352540886`, 0.3684834013190287, 0.9369192981351986], 
             UndirectedEdge[362, 384] -> 
             RGBColor[
              0.33614117025697976`, 0.4632658145057482, 0.9427239752429382], 
             UndirectedEdge[143, 308] -> 
             RGBColor[
              0.17893664305769685`, 0.3054041354650445, 0.9335015491578702], 
             UndirectedEdge[151, 310] -> 
             RGBColor[
              0.3017756973424442, 0.43451576996419494`, 0.9404970515752908], 
             UndirectedEdge[297, 397] -> 
             RGBColor[
              0.4389561312944613, 0.5528301617459719, 0.9496863711644075], 
             UndirectedEdge[114, 359] -> 
             RGBColor[
              0.443064873322788, 0.5568963088323743, 0.9498079911473898], 
             UndirectedEdge[141, 220] -> 
             RGBColor[
              0.32424804297229537`, 0.4552690904672675, 0.9418817764702763], 
             UndirectedEdge[122, 493] -> 
             RGBColor[
              0.9305407827762575, 0.7399602763410837, 0.37672867587283654`], 
             UndirectedEdge[146, 442] -> 
             RGBColor[
              0.2709392779878975, 0.40210473808065567`, 0.9387409631114438], 
             UndirectedEdge[294, 478] -> 
             RGBColor[
              0.25217734273393444`, 0.38238475455333876`, 0.9376724986545265],
              UndirectedEdge[76, 487] -> 
             RGBColor[
              0.49537833953651855`, 0.6000692782186605, 0.9537321847167134], 
             UndirectedEdge[67, 70] -> 
             RGBColor[
              0.25743661729140077`, 0.3879125855705024, 0.9379720065601748], 
             UndirectedEdge[346, 358] -> 
             RGBColor[
              0.2217544347167852, 0.3504083493035373, 0.935939959049609], 
             UndirectedEdge[149, 165] -> 
             RGBColor[
              0.3889540140770109, 0.511314150421502, 0.9460047837318252], 
             UndirectedEdge[175, 375] -> 
             RGBColor[
              0.9569658514087618, 0.9674257829593813, 0.9577297678481509], 
             UndirectedEdge[18, 428] -> 
             RGBColor[
              0.8573587081531882, 0.40102916444142644`, 0.2009600719874468], 
             UndirectedEdge[2, 47] -> 
             RGBColor[
              0.22219066917343752`, 0.3508668593763409, 0.9359648019565643], 
             UndirectedEdge[140, 466] -> 
             RGBColor[
              0.5015711187466989, 0.6062370555767975, 0.9539046622647382], 
             UndirectedEdge[199, 382] -> 
             RGBColor[
              0.31253428709090747`, 0.4426711481132517, 0.9412251688089472], 
             UndirectedEdge[305, 499] -> 
             RGBColor[
              0.2559152551896322, 0.3863135375416151, 0.9378853672391325], 
             UndirectedEdge[252, 282] -> 
             RGBColor[
              0.6717272001021579, 0.7429460920325152, 0.9682785844173988], 
             UndirectedEdge[235, 249] -> 
             RGBColor[
              0.32329479630323715`, 0.4526684377082041, 0.9418860278221313], 
             UndirectedEdge[130, 214] -> 
             RGBColor[
              0.1893670574265447, 0.316367162293171, 0.9340955458257609], 
             UndirectedEdge[100, 475] -> 
             RGBColor[
              0.8851091218155209, 0.5328997870260774, 0.22424752851506258`], 
             UndirectedEdge[10, 438] -> 
             RGBColor[
              0.22021348611856342`, 0.3487887146250221, 0.9358522043065695], 
             UndirectedEdge[39, 179] -> 
             RGBColor[
              0.40129536230508595`, 0.5053759222252174, 0.9485085964517164], 
             UndirectedEdge[400, 414] -> 
             RGBColor[
              0.28528989827003975`, 0.41718814987906533`, 0.9395582097066717],
              UndirectedEdge[41, 191] -> 
             RGBColor[
              0.22546402831064583`, 0.35430736737250323`, 0.9361512149169275],
              UndirectedEdge[25, 96] -> 
             RGBColor[
              0.3047685081778331, 0.4372333951604509, 0.9406831592217764], 
             UndirectedEdge[106, 274] -> 
             RGBColor[
              0.49029479958875166`, 0.5970824316919869, 0.9530169491141065], 
             UndirectedEdge[204, 363] -> 
             RGBColor[
              0.4533522044192463, 0.5657736996191047, 0.9504726028052438], 
             UndirectedEdge[99, 413] -> 
             RGBColor[
              0.9837287794830555, 0.9560851708017216, 0.4499899045367475], 
             UndirectedEdge[37, 118] -> 
             RGBColor[
              0.31537415178862416`, 0.44729581939211016`, 0.9413268540323092],
              UndirectedEdge[411, 478] -> 
             RGBColor[
              0.2528159536736963, 0.3830559751413007, 0.9377088666028057], 
             UndirectedEdge[300, 451] -> 
             RGBColor[
              0.21870173252116284`, 0.3471997657434399, 0.9357661121756364], 
             UndirectedEdge[122, 233] -> 
             RGBColor[
              0.8553320507775657, 0.4120002528594733, 0.20005892957140564`], 
             UndirectedEdge[97, 404] -> 
             RGBColor[
              0.2225914076005732, 0.3512880608715443, 0.9359876234171504], 
             UndirectedEdge[362, 498] -> 
             RGBColor[
              0.4251755260464191, 0.5424546669097134, 0.9483770922703834], 
             UndirectedEdge[121, 454] -> 
             RGBColor[
              0.8636741838299911, 0.42519607178708907`, 0.20605325186410173`],
              UndirectedEdge[173, 417] -> 
             RGBColor[
              0.8427978094114925, 0.8771278555657226, 0.9381656697874536], 
             UndirectedEdge[36, 352] -> 
             RGBColor[
              0.2411100918235177, 0.37075237214225454`, 0.9370422350877088], 
             UndirectedEdge[309, 337] -> 
             RGBColor[
              0.926620732552479, 0.9394372573300418, 0.7346744089406012], 
             UndirectedEdge[207, 456] -> 
             RGBColor[
              0.2203607616298221, 0.3489435105251617, 0.9358605914290611], 
             UndirectedEdge[95, 97] -> 
             RGBColor[
              0.22940871371662525`, 0.3584534818416879, 0.936375858915159], 
             UndirectedEdge[185, 350] -> 
             RGBColor[
              0.3230573711356193, 0.45194474529877393`, 0.9418898675264287], 
             UndirectedEdge[303, 435] -> 
             RGBColor[
              0.2816881021628791, 0.4134024338033765, 0.9393530927467486], 
             UndirectedEdge[14, 441] -> 
             RGBColor[
              0.3784375409652084, 0.5020200893703757, 0.9453414651985335], 
             UndirectedEdge[67, 147] -> 
             RGBColor[
              0.2540581203038455, 0.3843615710275007, 0.9377796061547718], 
             UndirectedEdge[115, 419] -> 
             RGBColor[
              0.7169294577871506, 0.7776214885576594, 0.9735615399917263], 
             UndirectedEdge[113, 209] -> 
             RGBColor[
              0.3725579164542212, 0.4820770410775821, 0.9462434146682975], 
             UndirectedEdge[100, 121] -> 
             RGBColor[
              0.8793403970281699, 0.48855884043917713`, 0.2187233911438525], 
             UndirectedEdge[39, 254] -> 
             RGBColor[
              0.43007991849913185`, 0.5356303158314321, 0.9501478343440324], 
             UndirectedEdge[2, 339] -> 
             RGBColor[
              0.21206918576719214`, 0.340228538577264, 0.9353883984499716], 
             UndirectedEdge[76, 436] -> 
             RGBColor[
              0.4421225577048329, 0.5568338353820671, 0.9495396944885663], 
             UndirectedEdge[121, 161] -> 
             RGBColor[
              0.9088989497892817, 0.5955852022276555, 0.2954383174204215], 
             UndirectedEdge[215, 430] -> 
             RGBColor[
              0.26193106415637823`, 0.3926365341899838, 0.9382279586601969], 
             UndirectedEdge[100, 254] -> 
             RGBColor[
              0.5838565510201338, 0.5654509378756822, 0.6001458285837606], 
             UndirectedEdge[186, 389] -> 
             RGBColor[
              0.22710509641847854`, 0.3560322340035631, 0.9362446713179258], 
             UndirectedEdge[197, 426] -> 
             RGBColor[
              0.7839000078483491, 0.8315135813435113, 0.9789878324723824], 
             UndirectedEdge[316, 378] -> 
             RGBColor[
              0.26678973270236006`, 0.397743302889189, 0.9385046526461347], 
             UndirectedEdge[185, 330] -> 
             RGBColor[
              0.29519715135054264`, 0.42760130102279975`, 0.9401224131131387],
              UndirectedEdge[56, 166] -> 
             RGBColor[
              0.8373970102117498, 0.28845538472768467`, 0.18344472525364075`],
              UndirectedEdge[38, 73] -> 
             RGBColor[
              0.25393957190424143`, 0.3842369691431141, 0.937772854998791], 
             UndirectedEdge[97, 430] -> 
             RGBColor[
              0.23573676666398502`, 0.3651046667110934, 0.9367362321689956], 
             UndirectedEdge[222, 372] -> 
             RGBColor[
              0.4565833875774816, 0.5694260572148426, 0.9504426196097452], 
             UndirectedEdge[137, 430] -> 
             RGBColor[
              0.22990978373834364`, 0.3589801382041882, 0.9364043941116291], 
             UndirectedEdge[30, 355] -> 
             RGBColor[
              0.29831901354920054`, 0.4290370635324922, 0.9403677718036725], 
             UndirectedEdge[111, 442] -> 
             RGBColor[
              0.2785182841132166, 0.41007075405510884`, 0.939172576298146], 
             UndirectedEdge[183, 408] -> 
             RGBColor[
              0.21373593745192992`, 0.3419804002760839, 0.9354833174926791], 
             UndirectedEdge[39, 283] -> 
             RGBColor[
              0.4024378733893724, 0.5065767738141891, 0.9485736607677728], 
             UndirectedEdge[244, 498] -> 
             RGBColor[
              0.40216527018839365`, 0.5225243398145787, 0.9469108991142803], 
             UndirectedEdge[259, 454] -> 
             RGBColor[
              0.8808615626968692, 0.5519020063430116, 0.22230030637499004`], 
             UndirectedEdge[17, 418] -> 
             RGBColor[
              0.9292223734187801, 0.9452976774305406, 0.9548682913375369], 
             UndirectedEdge[70, 391] -> 
             RGBColor[
              0.24968869542225258`, 0.3797690284394081, 0.93753077387175], 
             UndirectedEdge[18, 495] -> 
             RGBColor[
              0.8632931958328989, 0.4466442372567656, 0.2066429440915829], 
             UndirectedEdge[48, 95] -> 
             RGBColor[
              0.21729689825533816`, 0.34572319585842115`, 0.9356861089424638],
              UndirectedEdge[50, 92] -> 
             RGBColor[
              0.5250378077135244, 0.6249522255456361, 0.9558449239285502], 
             UndirectedEdge[118, 141] -> 
             RGBColor[
              0.31734549257895406`, 0.4492904482488255, 0.9414419520628983], 
             UndirectedEdge[373, 398] -> 
             RGBColor[
              0.27738327375901567`, 0.40887778620903076`, 0.9391079391375716],
              UndirectedEdge[218, 409] -> 
             RGBColor[
              0.2367642996218614, 0.3661846689991738, 0.9367947486508479]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {5}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.2206581667895666, 0.3492561022046294, 0.935877528212937], 316 -> 
             RGBColor[
              0.2504950392509415, 0.38061654692851177`, 0.937576693959915], 
             308 -> RGBColor[
              0.17894628476761076`, 0.30541426951348377`, 0.9335020982389862],
              160 -> RGBColor[
              0.42248174875901884`, 0.5403541890501141, 0.948141141338351], 
             245 -> RGBColor[
              0.22156287013367681`, 0.3502070027807943, 0.9359290497299955], 
             155 -> RGBColor[
              0.5658891207695752, 0.6584533071119401, 0.9589680109885835], 
             425 -> RGBColor[
              0.37534284954540054`, 0.499524843821242, 0.9451374923637511], 
             213 -> RGBColor[
              0.90420589766789, 0.657903179238463, 0.24177939169682186`], 352 -> 
             RGBColor[
              0.2278308941861094, 0.35679509347557953`, 0.9362860044270709], 
             27 -> RGBColor[
              0.5121189165844965, 0.6148002330343991, 0.9547350235483862], 
             485 -> RGBColor[
              0.24800119075484597`, 0.3779953540399882, 0.9374346729773807], 
             454 -> RGBColor[
              0.8998824261938122, 0.6382713050470934, 0.23817178112086787`], 
             367 -> RGBColor[
              0.2298450608433424, 0.3589121103378734, 0.9364007082385077], 19 -> 
             RGBColor[
              0.5597245266210166, 0.6534486118703385, 0.9584827115555565], 
             164 -> RGBColor[
              0.8175247092939038, 0.13570817177533162`, 0.16441498745215766`],
              190 -> RGBColor[
              0.24810961844878143`, 0.3781093184210272, 0.9374408477741458], 
             103 -> RGBColor[
              0.4803557055985901, 0.589013427439692, 0.9522345072271], 138 -> 
             RGBColor[
              0.2199663924455993, 0.34852900350809307`, 0.9358381326874365], 
             416 -> RGBColor[
              0.26153368469451344`, 0.39221886318025073`, 0.938205328487714], 
             476 -> RGBColor[
              0.8484924274103163, 0.3737396233586853, 0.19406970929346942`], 
             291 -> RGBColor[
              0.6549271406176395, 0.7303533269719065, 0.9662406748008145], 28 -> 
             RGBColor[
              0.9648560740830788, 0.9733102981108331, 0.9443736789601879], 
             337 -> RGBColor[
              0.860210700141258, 0.8913726787679522, 0.9865288585702724], 195 -> 
             RGBColor[
              0.2701519252165497, 0.40127718039692006`, 0.9386961245358997], 
             114 -> RGBColor[
              0.5006784839436625, 0.605512374430953, 0.9538343907832142], 479 -> 
             RGBColor[
              0.41149067372934756`, 0.5308342722869064, 0.9474407997564864], 
             93 -> RGBColor[
              0.26928527939714464`, 0.4003662806922068, 0.9386467703385721], 
             34 -> RGBColor[
              0.5437530683305409, 0.6404822625241338, 0.9572253798535508], 
             161 -> RGBColor[
              0.9903319581123935, 0.9790495659282263, 0.41694191223350735`], 
             22 -> RGBColor[
              0.4514165271362265, 0.5654160397762044, 0.9499848398305268], 
             124 -> RGBColor[
              0.9626525497894284, 0.8856804222207267, 0.30941263771645156`], 
             84 -> RGBColor[
              0.2333142933423989, 0.36255849365642656`, 0.9365982758970595], 
             46 -> RGBColor[
              0.9176548470302313, 0.7112359389100995, 0.2526013609126037], 
             241 -> RGBColor[
              0.7054821402904016, 0.7698472769484965, 0.9712795247048629], 
             185 -> RGBColor[
              0.2839447494602888, 0.41577431319265656`, 0.9394816054719256], 
             426 -> RGBColor[
              0.8701743928884773, 0.8993174569073501, 0.9874792044791957], 
             390 -> RGBColor[
              0.30075346730669683`, 0.43344134138349677`, 0.9404388370870089],
              121 -> RGBColor[
              0.8274659414661699, 0.21212083852708477`, 0.1739347226073356], 
             322 -> RGBColor[
              0.25921854913182885`, 0.38978550891579644`, 0.9380734849423552],
              488 -> RGBColor[
              0.7693643004981994, 0.8197525060252281, 0.9776467014216474], 
             126 -> RGBColor[
              0.2511378152607278, 0.38129214526915, 0.9376132991027705], 433 -> 
             RGBColor[
              0.32550625142704326`, 0.4563588873913744, 0.9419619484004228], 
             236 -> RGBColor[
              0.28732315690654525`, 0.419325233622076, 0.939674000778084], 78 -> 
             RGBColor[
              0.21942909899518986`, 0.3479642740253404, 0.9358075346202901], 
             376 -> RGBColor[
              0.2794551004482275, 0.4110554074207916, 0.9392259266025292], 
             458 -> RGBColor[
              0.2304992557221517, 0.359599710633853, 0.9364379636690613], 254 -> 
             RGBColor[
              0.23649824945009773`, 0.365905033400095, 0.9367795974871519], 
             290 -> RGBColor[
              0.2864852402250885, 0.41844453006287885`, 0.9396262826626617], 
             251 -> RGBColor[
              0.25854520282865096`, 0.38907777925853504`, 0.9380351388665158],
              165 -> 
             RGBColor[
              0.4240332554553848, 0.5416980261695123, 0.9482400019731], 460 -> 
             RGBColor[
              0.24834625332605567`, 0.3783580366805602, 0.9374543237803367], 
             100 -> RGBColor[
              0.9312148525901699, 0.7649968423512695, 0.2635120596803694], 
             235 -> RGBColor[
              0.3570417238501652, 0.48367332858535217`, 0.9439713608175008], 
             70 -> RGBColor[
              0.2582501634540876, 0.38876767416929214`, 0.9380183368106061], 
             234 -> RGBColor[
              0.38857864336543946`, 0.5109890231778194, 0.9459808654420111], 
             435 -> RGBColor[
              0.25811768357221787`, 0.3886284294137375, 0.93801079227732], 
             257 -> RGBColor[
              0.8588534332133313, 0.4519682304874997, 0.20393618366530758`], 
             135 -> RGBColor[
              0.25062676841059334`, 0.3807550026274169, 0.9375841957406814], 
             265 -> RGBColor[
              0.32101450543653715`, 0.45246836277611585`, 0.9416757383178027],
              111 -> RGBColor[
              0.27309124258507717`, 0.4043665893147275, 0.9388635143117069], 
             497 -> RGBColor[
              0.23599364281048124`, 0.36537465982794926`, 0.9367508608855244],
              481 -> RGBColor[
              0.318216697210702, 0.4500450419128276, 0.9414974644516573], 381 -> 
             RGBColor[
              0.5693048020656428, 0.6612263110627765, 0.9592369059322629], 
             182 -> RGBColor[
              0.3785866605047563, 0.5023344698355566, 0.9453441851296919], 
             188 -> RGBColor[
              0.33727714516499796`, 0.4665542439248693, 0.9427119793408126], 
             154 -> RGBColor[
              0.30954120355039927`, 0.44253076534726327`, 0.9409446696670606],
              336 -> RGBColor[
              0.22223854670063217`, 0.35091718169303304`, 0.9359675285109096],
              463 -> RGBColor[
              0.2670973610782935, 0.3980666398170606, 0.9385221716270487], 
             315 -> RGBColor[
              0.1854996162687526, 0.3123022364263995, 0.933875300773191], 368 -> 
             RGBColor[
              0.4081016499818632, 0.5278988702541217, 0.9472248541600927], 
             269 -> RGBColor[
              0.44893934079834463`, 0.5632704254773366, 0.9498269957075668], 
             208 -> RGBColor[
              0.32211852500862637`, 0.45342460903982235`, 0.9417460854686901],
              86 -> RGBColor[
              0.9151930916309041, 0.7014758990831244, 0.2506205747334791], 
             119 -> 
             RGBColor[
              0.9906473743776302, 0.9904004632007044, 0.8046607405893015], 
             436 -> RGBColor[
              0.472919813782261, 0.5829766354800872, 0.9516491265847494], 377 -> 
             RGBColor[
              0.9811051107342013, 0.9854288030398846, 0.9168682983373343], 
             140 -> RGBColor[
              0.4996340643500339, 0.6046644675542787, 0.9537521702469687], 85 -> 
             RGBColor[
              0.21421555473578224`, 0.34248450845090483`, 0.9355106309874645],
              351 -> RGBColor[
              0.290045450304657, 0.422186536586862, 0.9398290313598343], 443 -> 
             RGBColor[
              0.9345119801701037, 0.7780688545030732, 0.2661650059247154], 
             242 -> RGBColor[
              0.22500762673968802`, 0.3538276603838957, 0.936125223522647], 
             117 -> RGBColor[
              0.38107527345035186`, 0.504489981287708, 0.9455027573459912], 
             47 -> RGBColor[
              0.23193365260590854`, 0.36110735270469657`, 0.9365196504495912],
              451 -> RGBColor[
              0.21144581794704176`, 0.3395733394744833, 0.935352898574804], 
             81 -> RGBColor[
              0.8236181467643259, 0.8621947699835874, 0.9830386281626226], 
             275 -> RGBColor[
              0.4137039619056965, 0.5327513112621616, 0.9475818285219495], 23 -> 
             RGBColor[
              0.2225015077722568, 0.35119357045200544`, 0.9359825037549226], 
             328 -> RGBColor[
              0.3853130055350487, 0.5081604918248647, 0.9457727818871488], 
             418 -> RGBColor[
              0.978473490691829, 0.9834661451211657, 0.9213229446326382], 110 -> 
             RGBColor[
              0.27171530098953856`, 0.4029203874580805, 0.9387851564733641], 
             6 -> RGBColor[
              0.8276898195746623, 0.8654414113599355, 0.9834269879500976], 
             218 -> RGBColor[
              0.23197293745711564`, 0.3611486435741187, 0.9365218876637508], 
             108 -> RGBColor[
              0.28511069510105125`, 0.41699979598632125`, 0.939548004351305], 
             297 -> RGBColor[
              0.5193642093092683, 0.6206822880650865, 0.955305399532062], 487 -> 
             RGBColor[
              0.5794313774456323, 0.6694475211532741, 0.9600341070410434], 
             464 -> RGBColor[
              0.24386676324271586`, 0.3736498085868948, 0.9371992234469022], 
             157 -> RGBColor[
              0.3025436094347634, 0.43532289426166115`, 0.9405407830329243], 
             441 -> 
             RGBColor[
              0.4501324018566838, 0.5643037950010776, 0.9499030165032217], 
             354 -> RGBColor[
              0.3617638436367253, 0.48776339140382907`, 0.9442722501146938], 
             385 -> RGBColor[
              0.2334715870925415, 0.36272381936082626`, 0.9366072335434348], 
             270 -> RGBColor[
              0.9900230881246451, 0.9901423047916702, 0.8150067794022959], 
             392 -> RGBColor[
              0.3060013924465708, 0.4389572434431762, 0.9407376986601153], 33 -> 
             RGBColor[
              0.8784142522519405, 0.5407893411964669, 0.22025821055067316`], 
             252 -> RGBColor[
              0.7357960105795031, 0.7935287028122899, 0.9743009279960564], 
             394 -> RGBColor[
              0.22864247952174482`, 0.3576481211208147, 0.9363322230113024], 
             260 -> RGBColor[
              0.28557642935408295`, 0.4174893122155148, 0.9395745272280231], 
             159 -> RGBColor[
              0.8207501650068003, 0.16050043778835987`, 0.16750368748545852`],
              183 -> RGBColor[
              0.2049673414252272, 0.33276404989092045`, 0.9349839589209338], 
             99 -> RGBColor[
              0.9936215336094609, 0.9887654302895413, 0.5471214806005384], 
             329 -> RGBColor[
              0.8825578842047201, 0.909191716742005, 0.9886603529358121], 309 -> 
             RGBColor[
              0.9930307649637, 0.9875018358921313, 0.48281995931092997`], 17 -> 
             RGBColor[
              0.8799712561457314, 0.9071292097399156, 0.9884136380424356], 
             349 -> RGBColor[
              0.41360147005439724`, 0.5326625379719564, 0.9475752978318146], 
             495 -> RGBColor[
              0.8422024713778844, 0.3253922650171049, 0.18804644029332332`], 
             347 -> RGBColor[0.178927, 0.305394, 0.933501], 340 -> 
             RGBColor[
              0.3374345618861965, 0.46669059037677707`, 0.9427220097950892], 
             404 -> RGBColor[
              0.2134483076486736, 0.3416780831160786, 0.9354669374008939], 
             277 -> RGBColor[
              0.7713015318020453, 0.8212658858432957, 0.977839786533559], 104 -> 
             RGBColor[
              0.24657366739272524`, 0.3764949364761905, 0.9373533776337394], 
             79 -> RGBColor[
              0.9938287149952354, 0.9892085703244617, 0.5696718958667929], 
             327 -> RGBColor[
              0.2570691600545971, 0.38752636471648727`, 0.9379510804141431], 
             191 -> RGBColor[
              0.21840138119578575`, 0.34688407745709465`, 0.9357490076119863],
              50 -> RGBColor[
              0.44093802683048844`, 0.5563400894761129, 0.9493171590568191], 
             225 -> RGBColor[
              0.27424929290791517`, 0.4055837736286615, 0.9389294635644105], 
             405 -> RGBColor[
              0.9940126833910108, 0.9896020601209673, 0.5896957204256101], 61 -> 
             RGBColor[
              0.3238266917401457, 0.45490413720770817`, 0.94185492834235], 
             196 -> RGBColor[
              0.29569933477919436`, 0.42812912764658106`, 0.9401510117164867],
              1 -> RGBColor[
              0.2661654894960651, 0.39708718370006774`, 0.9384691029190212], 
             263 -> RGBColor[
              0.2734006518561467, 0.40469179807630246`, 0.9388811347119643], 
             201 -> RGBColor[
              0.3044587746178886, 0.4373358542976118, 0.9406498488568703], 
             371 -> RGBColor[
              0.36294391873403165`, 0.48878551314081686`, 0.9443474434563948],
              293 -> RGBColor[
              0.9542723127115095, 0.9654169462092355, 0.962289226275195], 362 -> 
             RGBColor[
              0.38846154058520777`, 0.5108875946353395, 0.9459734037564047], 
             184 -> RGBColor[
              0.2570318728012019, 0.3874871734490205, 0.9379489569602237], 
             106 -> RGBColor[
              0.5178553382148801, 0.619457318536794, 0.9551866156723348], 206 -> 
             RGBColor[
              0.3427341577200499, 0.4712808339226293, 0.9430596953553738], 
             358 -> RGBColor[
              0.22562621270692998`, 0.3544778334560826, 0.9361604510783655], 
             247 -> RGBColor[
              0.4950113815248125, 0.6009115653872759, 0.9533882557215221], 
             220 -> RGBColor[
              0.3389132056188999, 0.46797131725924984`, 0.9428162276662237], 
             407 -> RGBColor[
              0.21435834209939697`, 0.3426345870233057, 0.9355187625165873], 
             107 -> RGBColor[
              0.18467169248908813`, 0.3114320360405726, 0.9338281517387427], 
             375 -> RGBColor[
              0.9582014383733062, 0.9683472816944506, 0.9556382414098691], 
             131 -> RGBColor[
              0.263609049878749, 0.394400203574635, 0.9383235174647285], 411 -> 
             RGBColor[
              0.23958996446517072`, 0.3691546219069906, 0.9369556660834778], 
             462 -> RGBColor[
              0.46387836533310084`, 0.575636380316448, 0.9509373506429145], 
             127 -> 
             RGBColor[
              0.22597981130456574`, 0.35484948800164373`, 0.9361805879953986],
              210 -> RGBColor[
              0.8360637140310553, 0.2782070860287545, 0.182167959325265], 357 -> 
             RGBColor[
              0.9071422836282599, 0.6695571281253704, 0.2441427056377997], 
             181 -> RGBColor[
              0.4206971967779904, 0.5388084998183378, 0.9480274312641372], 
             194 -> RGBColor[
              0.9865160895376739, 0.9886920707502049, 0.8731268218098209], 
             440 -> RGBColor[
              0.28167383897512416`, 0.41338744228870766`, 0.9393522804793065],
              490 -> RGBColor[
              0.9905535588776926, 0.9903616680805318, 0.806215506209998], 118 -> 
             RGBColor[
              0.32510810483221725`, 0.45601403282236586`, 0.9419365788514676],
              348 -> RGBColor[
              0.9599116097125079, 0.876434587737939, 0.29876460310071706`], 
             276 -> RGBColor[
              0.6195401563438858, 0.7020096347427746, 0.9631916170392121], 
             305 -> RGBColor[
              0.2511118726659751, 0.3812648779572094, 0.9376118217103779], 
             343 -> RGBColor[
              0.29288750827080284`, 0.425173719706164, 0.9399908823565584], 
             280 -> RGBColor[
              0.25689237745970156`, 0.38734055500058817`, 0.9379410129068901],
              474 -> RGBColor[
              0.9930971542734537, 0.9914135101440991, 0.7640615478883636], 
             189 -> RGBColor[
              0.2597753641562747, 0.39037075681060074`, 0.9381051947342635], 
             168 -> RGBColor[
              0.9107922199972238, 0.6840279095591187, 0.24707953011528597`], 
             363 -> RGBColor[
              0.40481135748628755`, 0.5250489842693634, 0.9470151996317661], 
             41 -> RGBColor[
              0.23252667542550592`, 0.36173065728791187`, 0.9365534222218687],
              14 -> RGBColor[
              0.30674268007373295`, 0.4397363837396738, 0.9407799138938453], 
             77 -> RGBColor[
              0.606817875551374, 0.6916811140631951, 0.9621900724919755], 51 -> 
             RGBColor[
              0.17892700081062782`, 0.30539400085202123`, 0.9335010000461641],
              438 -> RGBColor[
              0.22146455698209894`, 0.3501036694250721, 0.9359234509414543], 
             179 -> RGBColor[
              0.178929137062006, 0.30539624618766587`, 0.9335011217025198], 
             467 -> RGBColor[
              0.7068391686146014, 0.7709073977891587, 0.9714147806060683], 
             223 -> 
             RGBColor[
              0.38986378476733635`, 0.5121021480670574, 0.9460627535157341], 
             456 -> RGBColor[
              0.22365852866224617`, 0.35240967276674573`, 0.9360483943829485],
              323 -> RGBColor[
              0.23934466612723454`, 0.36889679780100676`, 0.9369416967060188],
              500 -> RGBColor[
              0.8194926622925333, 0.15083472088530037`, 0.16629950146613023`],
              478 -> RGBColor[
              0.2660419428822219, 0.39695732837561076`, 0.9384620671221336], 
             292 -> RGBColor[
              0.1789706321783367, 0.30543986018587177`, 0.9335034847880083], 
             491 -> RGBColor[
              0.9941614319695004, 0.9899202182895682, 0.6058860852243823], 
             396 -> RGBColor[
              0.9935460613341791, 0.9886040027241311, 0.5389067891970045], 
             321 -> RGBColor[
              0.3331754530775283, 0.46300156439574175`, 0.942450623147983], 
             143 -> RGBColor[
              0.17892700134778292`, 0.3053940014166053, 0.9335010000767543], 
             112 -> RGBColor[
              0.24826352560257345`, 0.3782710845979398, 0.937449612558869], 
             197 -> RGBColor[
              0.6976256228082208, 0.7637097057796726, 0.9704964604655693], 
             421 -> RGBColor[
              0.17905660578117066`, 0.3055302238934915, 0.9335083808575031], 
             54 -> RGBColor[
              0.22872079714307936`, 0.35773043790646125`, 0.9363366830839769],
              71 -> RGBColor[
              0.755781538403036, 0.8091415490436711, 0.97629289863413], 177 -> 
             RGBColor[
              0.20869655844004803`, 0.3366836934195124, 0.9351963323130457], 
             158 -> RGBColor[
              0.3575213303529286, 0.48408873963232213`, 0.9440019209197574], 
             226 -> RGBColor[
              0.1794249922972142, 0.30591742147890744`, 0.9335293599246128], 
             432 -> RGBColor[
              0.898624468927386, 0.9220027752840345, 0.9901927981294695], 350 -> 
             RGBColor[
              0.3621699928109498, 0.4881151774048913, 0.9442981295809318], 
             203 -> RGBColor[
              0.5345666356633387, 0.6330243026408235, 0.956502190222977], 475 -> 
             RGBColor[
              0.839003391040872, 0.30080273170088523`, 0.1849829973497558], 
             115 -> RGBColor[
              0.9211683800910966, 0.9399786781078106, 0.9923430565014513], 
             173 -> RGBColor[
              0.984562956112485, 0.9878843998856498, 0.9054952972124768], 212 -> 
             RGBColor[
              0.21851625165510197`, 0.3470048135930438, 0.9357555493147087], 
             129 -> RGBColor[
              0.35559977387920144`, 0.4824243839950162, 0.9438794810404173], 
             279 -> RGBColor[
              0.2785602236563872, 0.4101148351741018, 0.9391749646930856], 26 -> 
             RGBColor[
              0.3866295369467384, 0.5093008051628776, 0.9458566701045386], 40 -> 
             RGBColor[
              0.3862001571816754, 0.5089288979916344, 0.9458293104055944], 
             146 -> RGBColor[
              0.257933230334439, 0.3884345573658211, 0.9380002879383026], 386 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 192 -> 
             RGBColor[
              0.2546146394674752, 0.38494650795382845`, 0.9378112990978443], 
             300 -> RGBColor[
              0.22595764709528393`, 0.3548261920123965, 0.936179325776469], 
             221 -> RGBColor[
              0.5366100807415061, 0.6346832634114314, 0.9566630577049163], 62 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 286 -> 
             RGBColor[
              0.22310026486080187`, 0.3518229021154584, 0.9360166020853335], 
             472 -> RGBColor[
              0.32844671668737896`, 0.45890577060779597`, 0.9421493122466601],
              152 -> RGBColor[
              0.20400293554931437`, 0.33175039816847185`, 0.9349290374330113],
              64 -> RGBColor[
              0.2878344487965492, 0.41986263381624833`, 0.9397031180948312], 
             307 -> RGBColor[
              0.46980956787155936`, 0.580451597734798, 0.9514042766334527], 
             37 -> RGBColor[
              0.305640198745031, 0.4385776059618545, 0.9407171292131508], 148 -> 
             RGBColor[
              0.23965584235908116`, 0.3692238637503902, 0.9369594177320785], 
             261 -> RGBColor[
              0.8799868165294279, 0.5479299882988189, 0.2215703967308864], 
             387 -> RGBColor[
              0.7751138064478154, 0.8242440637709316, 0.9782197584425172], 15 -> 
             RGBColor[
              0.23423879357827926`, 0.36353020202103736`, 0.9366509248178173],
              136 -> RGBColor[
              0.968960662006962, 0.9763714930638193, 0.9374256822530368], 198 -> 
             RGBColor[
              0.2818794421164257, 0.41360354422620765`, 0.9393639892740411], 
             63 -> RGBColor[
              0.41933559472005666`, 0.5376291485518648, 0.9479406711850231], 
             444 -> RGBColor[
              0.27129304719779485`, 0.4024765719505212, 0.9387611097445928], 
             310 -> 
             RGBColor[
              0.29675707084929953`, 0.4292408753206019, 0.9402112482208989], 
             171 -> RGBColor[
              0.26174222518751433`, 0.39243805246062563`, 0.9382172045602823],
              395 -> RGBColor[
              0.26498757281889074`, 0.39584911858812655`, 0.9384020223068277],
              311 -> RGBColor[
              0.746856868272219, 0.8021695289074716, 0.9754033709212744], 353 -> 
             RGBColor[
              0.6396625402707171, 0.7183458925176417, 0.9647757248126534], 59 -> 
             RGBColor[
              0.2421911048281961, 0.37188858535035474`, 0.9371037971791099], 
             397 -> RGBColor[
              0.3585480532796543, 0.48497803542685713`, 0.944067342796753], 
             229 -> RGBColor[
              0.2909757990296596, 0.42316439208435586`, 0.9398820133433956], 
             102 -> RGBColor[
              0.2765375568294345, 0.40798888409449063`, 0.939059776809558], 
             453 -> RGBColor[
              0.2843068325272902, 0.41615488545346746`, 0.9395022255669375], 
             299 -> RGBColor[
              0.2091663766185125, 0.3371775021132715, 0.9352230877632756], 
             128 -> RGBColor[
              0.49474321248409076`, 0.6006938536791404, 0.9533671444723009], 
             12 -> RGBColor[
              0.27240341106773047`, 0.40364363477895904`, 0.9388243433243495],
              222 -> RGBColor[
              0.4427137030371586, 0.5578780909582495, 0.9494303035745394], 
             483 -> RGBColor[
              0.29664917161590876`, 0.42912746638510174`, 0.9402051035191799],
              92 -> RGBColor[
              0.6091375885965603, 0.6935643616151592, 0.9623726888002815], 
             271 -> RGBColor[
              0.2558053195227897, 0.38619798818543977`, 0.9378791065655412], 
             361 -> RGBColor[
              0.6442014475594858, 0.7219743340365904, 0.9651716379540781], 
             344 -> RGBColor[
              0.4637429804071734, 0.5755264687345587, 0.9509266926456142], 
             132 -> RGBColor[
              0.9901329118562932, 0.9901877197270478, 0.8131867159541827], 80 -> 
             RGBColor[
              0.7895429134572223, 0.8355161918319554, 0.9796579169815435], 
             324 -> RGBColor[
              0.369677449943029, 0.49461775943693126`, 0.9447764981108042], 
             244 -> RGBColor[
              0.3424410288691568, 0.4710269404450701, 0.9430410174441985], 
             150 -> RGBColor[
              0.8214446559981496, 0.16583859987576455`, 0.16816873284309014`],
              125 -> 
             RGBColor[
              0.20867358600249122`, 0.3366595479311035, 0.9351950240667115], 
             258 -> RGBColor[
              0.3734224424883788, 0.497861483750915, 0.945015125724227], 133 -> 
             RGBColor[
              0.3451736656290086, 0.4733938130601367, 0.9432151386421606], 
             469 -> RGBColor[
              0.8604306779796645, 0.4591301305965446, 0.20525227536014304`], 
             255 -> RGBColor[
              0.3975855258515599, 0.5187903320882202, 0.9465547760295533], 
             408 -> RGBColor[
              0.2225045334786326, 0.3511967506612473, 0.9359826760644245], 
             326 -> RGBColor[
              0.8751755113140446, 0.526082975024646, 0.21755572572328788`], 
             176 -> RGBColor[
              0.6069446059586334, 0.6917839995169481, 0.9622000491738637], 
             230 -> RGBColor[
              0.2238780227461086, 0.35264037496561385`, 0.936060894246312], 
             274 -> RGBColor[
              0.4627342609626232, 0.5747075448471798, 0.9508472825558781], 87 -> 
             RGBColor[
              0.1792532619022457, 0.3057369219454596, 0.9335195801326717], 
             439 -> RGBColor[
              0.8609124841587944, 0.891932262294116, 0.986595795356355], 130 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 35 -> 
             RGBColor[
              0.23837242809378653`, 0.36787491398440125`, 0.9368863291883112],
              379 -> RGBColor[
              0.3092991992760449, 0.442321153408306, 0.9409292493686947], 31 -> 
             RGBColor[
              0.4530382628066378, 0.5668207057031098, 0.9500881753934008], 18 -> 
             RGBColor[
              0.8843839202879132, 0.5678962094964264, 0.22523944788984251`], 
             24 -> RGBColor[
              0.8369720141620951, 0.8728427813654944, 0.9843123319561599], 
             151 -> RGBColor[
              0.30679432383558886`, 0.439790664607788, 0.9407828549296829], 
             137 -> RGBColor[
              0.22008054170119, 0.3486489816131997, 0.9358446333186737], 330 -> 
             RGBColor[
              0.3064495532407965, 0.43942828885294294`, 0.9407632207543519], 
             296 -> RGBColor[
              0.3134198204339392, 0.44589022834683273`, 0.9411918117051534], 
             266 -> RGBColor[
              0.28952074326414307`, 0.421635036218934, 0.9397991500701115], 
             302 -> RGBColor[
              0.19014935834156865`, 0.31718941015560403`, 0.934140096705561], 
             442 -> RGBColor[
              0.28394532564135605`, 0.4157749187954902, 0.9394816382845851], 
             283 -> 
             RGBColor[
              0.18121415923057888`, 0.3077979493656092, 0.9336312503346327], 
             388 -> RGBColor[
              0.9461721011462925, 0.9593758216867757, 0.9760007715815773], 
             284 -> RGBColor[
              0.24509263407936946`, 0.37493827656091794`, 0.9372690349775362],
              417 -> RGBColor[
              0.7010326627105, 0.7663713112457954, 0.9708360423624304], 318 -> 
             RGBColor[
              0.341942322952124, 0.4705949864454246, 0.9430092403441536], 413 -> 
             RGBColor[
              0.97383602535665, 0.9234049113139019, 0.35285832847295656`], 
             238 -> RGBColor[
              0.32015392046586916`, 0.45172296732878153`, 0.9416209026044572],
              72 -> RGBColor[
              0.2539844574642687, 0.3842841467126117, 0.9377754111650324], 
             437 -> RGBColor[
              0.2558304623203871, 0.3862244148598601, 0.9378805384106689], 
             288 -> RGBColor[
              0.2560659100008252, 0.3864718853002457, 0.9378939468077562], 
             382 -> RGBColor[
              0.28222469603460637`, 0.4139664279845783, 0.9393836509739241], 
             461 -> RGBColor[
              0.944455505750549, 0.9580955876512972, 0.9789065198267879], 389 -> 
             RGBColor[
              0.2184997826909155, 0.34698750366749115`, 0.9357546114315619], 
             172 -> RGBColor[
              0.3516524550010693, 0.4790054147807936, 0.9436279613719797], 
             447 -> RGBColor[
              0.2464999471451923, 0.3764174518218997, 0.9373491793747017], 
             243 -> RGBColor[
              0.8393061093521738, 0.30312955729356095`, 0.18527288074652987`],
              410 -> RGBColor[
              0.36366501242205085`, 0.4894100882501565, 0.9443933909085572], 
             88 -> RGBColor[
              0.8666101266120032, 0.4871895635890985, 0.21040855877111306`], 
             273 -> RGBColor[
              0.2935414156904733, 0.42586101786436276`, 0.9400281214167392], 
             477 -> RGBColor[
              0.24467162743864543`, 0.3744957718881542, 0.9372450592721705], 
             202 -> RGBColor[
              0.23905706042934927`, 0.3685945059772749, 0.9369253179869986], 
             393 -> RGBColor[
              0.4612114846587171, 0.5734712864433781, 0.9507274040271213], 98 -> 
             RGBColor[
              0.9952347378240085, 0.9922159109844932, 0.7227088038116687], 30 -> 
             RGBColor[
              0.2679312243382506, 0.39894308297325987`, 0.938569658906113], 
             116 -> 
             RGBColor[
              0.24872594858728536`, 0.3787571204741826, 0.9374759468637549], 
             373 -> RGBColor[
              0.293615491872952, 0.425938876628849, 0.9400323399457455], 434 -> 
             RGBColor[
              0.9912025783926344, 0.990630054329001, 0.7954595732387495], 401 -> 
             RGBColor[
              0.7734523776791622, 0.8229461429895335, 0.9780541627497925], 
             240 -> RGBColor[
              0.2566255537350775, 0.38706010634840704`, 0.9379258176905032], 
             480 -> RGBColor[
              0.35354723518652786`, 0.48064657814301665`, 0.9437486950899088],
              403 -> RGBColor[
              0.9289119756027943, 0.9461532109745376, 0.9930816475541463], 
             317 -> RGBColor[
              0.8834003236622562, 0.5634299269441462, 0.22441871075523476`], 
             429 -> RGBColor[
              0.29359796730781346`, 0.4259204571997668, 0.9400313419476861], 
             391 -> RGBColor[
              0.2411272273904176, 0.370770382709524, 0.937043210932894], 73 -> 
             RGBColor[
              0.24791046842011605`, 0.37789999911405875`, 0.9374295064746294],
              303 -> RGBColor[
              0.3052585207535403, 0.43817643819301544`, 0.9406953932161773], 
             449 -> RGBColor[
              0.7283027762348872, 0.7876749311915857, 0.9735540724248413], 29 -> 
             RGBColor[
              0.40962031041891445`, 0.5292142575946026, 0.9473216218602429], 
             360 -> RGBColor[
              0.5793663225363243, 0.6693947066472076, 0.9600289856802787], 
             320 -> RGBColor[
              0.9886024976405045, 0.9895548541189678, 0.8385496400948322], 
             482 -> RGBColor[
              0.35848143845973107`, 0.48492033701799786`, 0.9440630981593326],
              75 -> RGBColor[
              0.3449485107481652, 0.47319879521896346`, 0.9432007919722498], 
             200 -> RGBColor[
              0.9008280073528754, 0.6425649682443086, 0.23896079721830538`], 
             301 -> RGBColor[
              0.20875268020104726`, 0.3367426809486477, 0.9351995283643099], 
             156 -> RGBColor[
              0.46730916543215706`, 0.578421658392645, 0.9512074357941471], 
             25 -> RGBColor[
              0.3133752819583538, 0.4458516513578495, 0.941188973752873], 38 -> 
             RGBColor[
              0.25996867538836677`, 0.3905739391721695, 0.9381162035229527], 
             365 -> RGBColor[
              0.2169746648251472, 0.34538450809251103`, 0.9356677582253161], 
             380 -> 
             RGBColor[
              0.27285106149406285`, 0.4041141437597107, 0.9388498363538897], 
             370 -> RGBColor[
              0.591443337591513, 0.6791993715323379, 0.960979732544987], 3 -> 
             RGBColor[
              0.46166603367100856`, 0.5738403098087559, 0.9507631877904368], 
             57 -> RGBColor[
              0.6012429877716181, 0.6871551690177569, 0.9617511969044663], 
             227 -> RGBColor[
              0.8456311671254343, 0.35174672299683013`, 0.19132976321333509`],
              494 -> RGBColor[
              0.2585035332044634, 0.3890339818415072, 0.938032765843063], 39 -> 
             RGBColor[
              0.6236615875481659, 0.7053555982627691, 0.963516071200913], 424 -> 
             RGBColor[
              0.3205944320155112, 0.4521045162923272, 0.9416489716108714], 
             109 -> RGBColor[
              0.25396000439311356`, 0.38425844498441336`, 0.9377740185988052],
              465 -> RGBColor[
              0.28262558218412137`, 0.4143877847453685, 0.939406480847081], 
             256 -> RGBColor[
              0.2893861381019995, 0.4214935576590608, 0.939791484505258], 457 -> 
             RGBColor[
              0.22158907133489145`, 0.35023454190452297`, 0.9359305418496434],
              339 -> RGBColor[
              0.21169068579341777`, 0.33983071110654267`, 0.9353668434364056],
              420 -> RGBColor[
              0.96864282965107, 0.9761344542131977, 0.9379636895276074], 287 -> 
             RGBColor[
              0.20981171601903448`, 0.33785579474010136`, 0.9352598388874411],
              239 -> RGBColor[
              0.3509305166159243, 0.47838010803725933`, 0.9435819600964633], 
             427 -> RGBColor[
              0.2795001276110678, 0.4111027338238238, 0.9392284908328413], 
             285 -> RGBColor[
              0.3144183414809424, 0.4467550970906198, 0.941255436583311], 345 -> 
             RGBColor[
              0.6597251945044771, 0.7341016031348642, 0.9667188999718916], 
             366 -> RGBColor[
              0.2650062967491503, 0.3958687986259951, 0.9384030886069564], 
             216 -> RGBColor[
              0.26588598144981995`, 0.39679340302163035`, 0.9384531853492826],
              21 -> RGBColor[
              0.9808877657874093, 0.9471920876142448, 0.3802530084370154], 
             355 -> RGBColor[
              0.32870680276015046`, 0.45913104409172456`, 0.942165884701232], 
             175 -> RGBColor[
              0.9557302644442173, 0.966504284224312, 0.9598212942864327], 7 -> 
             RGBColor[
              0.8386821070512293, 0.8742063630160551, 0.9844754421425435], 13 -> 
             RGBColor[
              0.29661626096016863`, 0.4290928751992627, 0.9402032293060224], 
             294 -> RGBColor[
              0.23831274258564697`, 0.36781218073106675`, 0.9368829301869194],
              412 -> RGBColor[
              0.2423814866745967, 0.372088688741828, 0.9371146391436176], 193 -> 
             RGBColor[
              0.2878117179623051, 0.41983874226823964`, 0.9397018236074483], 
             60 -> RGBColor[
              0.29270959820985176`, 0.42498672495195505`, 0.9399807506417815],
              65 -> RGBColor[
              0.9854648277298144, 0.9626315922912277, 0.39803402977763763`], 
             448 -> RGBColor[
              0.5679393142918087, 0.6601177465734548, 0.9591294097327601], 69 -> 
             RGBColor[
              0.9094625081980608, 0.9306447336077317, 0.9912265399903383], 
             217 -> RGBColor[
              0.31971976000988434`, 0.4513469193633465, 0.9415932382841149], 
             214 -> RGBColor[
              0.19980711485308938`, 0.32734032458634205`, 0.9346900916515217],
              170 -> RGBColor[
              0.29668056881803306`, 0.42916046683523196`, 0.9402068915433929],
              359 -> RGBColor[
              0.38545126270191343`, 0.5082802432337956, 0.9457815915115654], 
             74 -> RGBColor[
              0.2817340129849886, 0.4134506889883278, 0.9393557073001488], 
             246 -> RGBColor[
              0.29422140859812795`, 0.42657573352434824`, 0.9400668460068708],
              264 -> RGBColor[
              0.23478619087952063`, 0.36410555129163547`, 0.9366820982843213],
              278 -> RGBColor[
              0.9483637407407871, 0.9610103429078694, 0.9722908974192511], 45 -> 
             RGBColor[
              0.28278247170568477`, 0.41455268557990177`, 0.9394154154732368],
              492 -> RGBColor[
              0.2766193131480329, 0.4080748151689876, 0.9390644327109545], 
             306 -> RGBColor[
              0.8575795140998795, 0.443586953641446, 0.20277151376979163`], 
             237 -> RGBColor[
              0.906092392768253, 0.9279574950433493, 0.9909050953721057], 228 -> 
             RGBColor[
              0.9930813033990235, 0.9876099324950685, 0.48832075610881853`], 
             180 -> RGBColor[
              0.27013094278236094`, 0.4012551265282246, 0.9386949296173133], 
             383 -> RGBColor[
              0.32894252042405586`, 0.45933521088468515`, 0.942180904422339], 
             53 -> 
             RGBColor[
              0.9765123065091236, 0.9324326360618924, 0.36325517537702773`], 
             304 -> RGBColor[
              0.3385640468354945, 0.4676688934702948, 0.9427939795772942], 48 -> 
             RGBColor[
              0.20751087662989864`, 0.3354374666604766, 0.9351288094880167], 
             5 -> RGBColor[
              0.23860734128045696`, 0.3681218226379481, 0.9368997071467691], 
             101 -> RGBColor[
              0.5208327276256995, 0.6218744973903617, 0.9554210066732913], 
             333 -> RGBColor[
              0.3786491349611119, 0.5023885820695944, 0.9453481659468069], 
             267 -> RGBColor[
              0.9890626064851881, 0.9747677448317271, 0.41201072085875556`], 
             120 -> RGBColor[
              0.20742150462258202`, 0.3353435310142743, 0.9351237198844141], 
             147 -> RGBColor[
              0.25149316947897704`, 0.3816656450832887, 0.9376335359998004], 
             89 -> RGBColor[
              0.28550171685781406`, 0.4174107846448903, 0.9395702724618878], 
             43 -> RGBColor[
              0.2931478124699098, 0.42544731592366486`, 0.940005706295612], 
             199 -> RGBColor[
              0.3428438781472085, 0.4713758682419251, 0.9430666866439704], 
             268 -> RGBColor[
              0.40965477924277666`, 0.5292441127573786, 0.9473238181832199], 
             169 -> RGBColor[
              0.4927421843014464, 0.5990693288551774, 0.9532096162037554], 20 -> 
             RGBColor[
              0.8845340276069948, 0.5685778117739207, 0.22536470111635126`], 
             4 -> RGBColor[
              0.32430364693803726`, 0.45531725182765653`, 0.9418853195058047],
              167 -> RGBColor[
              0.9866702547547157, 0.9887558220293171, 0.870571905196646], 431 -> 
             RGBColor[
              0.4485399301016759, 0.5629244760068475, 0.9498015456111601], 
             142 -> RGBColor[
              0.6995243049605603, 0.765192970707599, 0.9706857033583209], 16 -> 
             RGBColor[
              0.4038820814050813, 0.5242440920345965, 0.9469559869815982], 
             414 -> RGBColor[
              0.2746579678933065, 0.4060133169497984, 0.9389527370002482], 
             281 -> RGBColor[
              0.24490866169442368`, 0.374744909919817, 0.9372585580223763], 
             289 -> RGBColor[
              0.439371052281192, 0.5549828548799431, 0.9492173128241592], 398 -> 
             RGBColor[
              0.26115105564507934`, 0.3918166957892125, 0.9381835383293976], 
             178 -> 
             RGBColor[
              0.9916846362160958, 0.9908293976273234, 0.7874706275783359], 58 -> 
             RGBColor[
              0.31511174381280593`, 0.44735568733906544`, 0.9412996195667458],
              186 -> RGBColor[
              0.23571041014604155`, 0.365076964339635, 0.9367347312042897], 
             122 -> RGBColor[
              0.867504304657107, 0.49124981725132677`, 0.21115468285025726`], 
             249 -> RGBColor[
              0.2895478687563091, 0.421663546831056, 0.9398006948267619], 113 -> 
             RGBColor[
              0.17919226069553715`, 0.305672805809509, 0.9335161062041928], 
             52 -> RGBColor[
              0.8357950446989824, 0.2761419758107905, 0.18191068126945342`], 
             409 -> RGBColor[
              0.24155566178660715`, 0.3712206944242289, 0.937067609637945], 
             187 -> RGBColor[
              0.26462809617956273`, 0.3954712858480575, 0.938381550644016], 
             259 -> RGBColor[
              0.8618406991999262, 0.46553270763892984`, 0.20642883162911219`],
              42 -> RGBColor[
              0.23247426890382172`, 0.3616755747108564, 0.9365504377479873], 
             134 -> RGBColor[
              0.2332063867745317, 0.36244507701192663`, 0.9365921307776528], 
             470 -> RGBColor[
              0.25548210733168075`, 0.3858582716797478, 0.937860700109407], 
             313 -> RGBColor[
              0.266957894870447, 0.3979200519899457, 0.9385142292328336], 248 -> 
             RGBColor[
              0.24253965650195108`, 0.3722549352589237, 0.9371236466812941], 
             174 -> RGBColor[
              0.2666571079259713, 0.3976039058403079, 0.93849709986132], 215 -> 
             RGBColor[
              0.28412310253725925`, 0.4159617735847908, 0.9394917624158093], 
             399 -> RGBColor[
              0.24150095424043594`, 0.3711631933245442, 0.9370644941241232], 
             422 -> RGBColor[
              0.23401200432651914`, 0.3632918321381684, 0.9366380095054342], 
             83 -> RGBColor[
              0.9207457022290968, 0.9396416462539369, 0.9923027411096448], 95 -> 
             RGBColor[
              0.22708291988077767`, 0.3560089250563658, 0.936243408396911], 
             166 -> RGBColor[
              0.8381204118994321, 0.2940157670958513, 0.18413745552673064`], 
             384 -> RGBColor[
              0.28382079992875175`, 0.41564403437615693`, 0.9394745467294715],
              233 -> RGBColor[
              0.8431597968980244, 0.3327506884676198, 0.18896317629255405`], 
             295 -> 
             RGBColor[
              0.22958788287780074`, 0.3586417999900643, 0.9363860623338308], 
             499 -> RGBColor[
              0.2607186377132893, 0.3913621971260208, 0.9381589127678872], 
             141 -> RGBColor[
              0.30958288032569087`, 0.4425668636752852, 0.9409473252743288], 
             319 -> RGBColor[
              0.7148896845747944, 0.7771965220434489, 0.9722171808006315], 
             205 -> RGBColor[
              0.9938265629209484, 0.98920396725517, 0.5694376558617151], 468 -> 
             RGBColor[
              0.4783770236668791, 0.5874070443089239, 0.952078738137285], 486 -> 
             RGBColor[
              0.9349275982881982, 0.9509499052141509, 0.9936554230160899], 
             224 -> RGBColor[
              0.29896629209325354`, 0.43156290692071464`, 0.9403370601024921],
              231 -> RGBColor[
              0.2584463601503126, 0.3889738893366137, 0.9380295099222091], 
             332 -> RGBColor[
              0.40219205331719154`, 0.5227802746481479, 0.946848299886271], 
             68 -> RGBColor[
              0.8199864588949732, 0.15463025795470559`, 0.16677236165029033`],
              484 -> RGBColor[
              0.9928916986278599, 0.9872043870615327, 0.4676834468726777], 10 -> 
             RGBColor[
              0.2189624152550279, 0.3474737598249721, 0.9357809576716846], 
             250 -> RGBColor[
              0.20444533477183996`, 0.332215387801077, 0.934954231414263], 
             282 -> RGBColor[
              0.6076583896248129, 0.6923634812527404, 0.9622562408387412], 
             374 -> RGBColor[
              0.2517303220687306, 0.38191490749146234`, 0.937647041488951], 
             232 -> RGBColor[
              0.3561976264336458, 0.4829422138287328, 0.9439175756765262], 
             489 -> RGBColor[
              0.9900975943251971, 0.9901731150203205, 0.8137720188432849], 
             253 -> RGBColor[
              0.9850318468002165, 0.9880782982349678, 0.8977245650665646], 
             459 -> RGBColor[
              0.3905461178527888, 0.5126931506906183, 0.9461062311765757], 
             415 -> RGBColor[
              0.2870126862041934, 0.4189989092289247, 0.9396563199308854], 55 -> 
             RGBColor[
              0.21147766438726034`, 0.339606812102334, 0.9353547121824619], 
             446 -> RGBColor[
              0.22815127331601265`, 0.3571318322543179, 0.9363042495445604], 
             325 -> RGBColor[
              0.1790169203691504, 0.30548851200925775`, 0.9335061208319979], 
             91 -> 
             RGBColor[
              0.3276288460270304, 0.4581973721491767, 0.9420971982513973], 
             450 -> RGBColor[
              0.8177084834502429, 0.13712074047130335`, 0.1645909697918113], 
             423 -> RGBColor[
              0.18782589147201245`, 0.31474729915939237`, 0.9340077787046009],
              105 -> RGBColor[
              0.2459052705491277, 0.3757924090147619, 0.9373153134223011], 36 -> 
             RGBColor[
              0.254389289460926, 0.3847096508089296, 0.9377984657483468], 123 -> 
             RGBColor[
              0.2069635167020156, 0.33486215667164765`, 0.9350976381498702], 
             94 -> RGBColor[
              0.9554190789968999, 0.9662722026272221, 0.9603480500785777], 
             473 -> RGBColor[
              0.32683125980079797`, 0.4575065430478635, 0.9420463767623395], 
             312 -> RGBColor[
              0.3044115375980597, 0.43728620519477157`, 0.940647158778472], 
             96 -> RGBColor[
              0.2961617343973124, 0.4286151389630523, 0.9401773446906796], 
             496 -> RGBColor[
              0.27688954314442643`, 0.4083588440287685, 0.9390798219094797], 
             2 -> RGBColor[
              0.2124476857409665, 0.34062636604798524`, 0.9354099534635375], 
             262 -> RGBColor[
              0.47608581392629684`, 0.5855469370236965, 0.9518983657135286], 
             272 -> RGBColor[
              0.8205829319400263, 0.15921501115513814`, 0.16734354491185305`],
              97 -> RGBColor[
              0.2317345075524728, 0.36089803862701, 0.9365083094334068], 372 -> 
             RGBColor[
              0.4704530721178047, 0.5809740234714359, 0.951454935644951], 356 -> 
             RGBColor[
              0.26933793088281155`, 0.4004216207419397, 0.9386497687627899], 
             402 -> RGBColor[
              0.5523112332770156, 0.6474301663686192, 0.9578991099477285], 
             455 -> RGBColor[
              0.20394063923757638`, 0.33168492079502093`, 0.9349254897502168],
              428 -> RGBColor[
              0.8303334960184631, 0.23416211938642656`, 0.1766806960850511], 
             346 -> RGBColor[
              0.21788265672664042`, 0.34633886515099205`, 0.9357194670208525],
              341 -> RGBColor[
              0.9935733711383794, 0.9886624156338708, 0.5418792928476311], 
             209 -> RGBColor[
              0.5659235722129052, 0.6584812763456551, 0.9589707231324023], 
             498 -> RGBColor[
              0.46188951150763047`, 0.5740217391840874, 0.9507807807843619], 
             378 -> 
             RGBColor[
              0.2830844261537786, 0.4148700588498662, 0.9394326113323542], 
             419 -> RGBColor[
              0.5126905354832046, 0.6152642990075083, 0.9547800234820015], 66 -> 
             RGBColor[
              0.2632810725593861, 0.3940554786170215, 0.9383048396415897], 
             139 -> RGBColor[
              0.5640351798749514, 0.6569481943745988, 0.9588220619701494], 56 -> 
             RGBColor[
              0.8366736085240676, 0.28289500235951803`, 0.1827519949805509], 
             335 -> RGBColor[
              0.2767721721232211, 0.4082354796437291, 0.9390731378034569], 
             314 -> RGBColor[
              0.33007547283951477`, 0.4603165173231115, 0.9422530951484216], 
             144 -> RGBColor[
              0.24622776306205768`, 0.3761313690930576, 0.9373336788938276], 
             298 -> RGBColor[
              0.9016398137954514, 0.9244071294324739, 0.9904804044148157], 
             204 -> RGBColor[
              0.5018930513522051, 0.606498414968846, 0.9539300059787216], 452 -> 
             RGBColor[
              0.22395342458252596`, 0.35271962707644106`, 0.936065188269349], 
             466 -> RGBColor[
              0.503508173143364, 0.6078096435993164, 0.9540571542825077], 207 -> 
             RGBColor[
              0.217062994597398, 0.3454773482835776, 0.9356727884751737], 334 -> 
             RGBColor[
              0.4028040785660817, 0.5233103801574531, 0.9468872975939376], 
             149 -> RGBColor[
              0.353874772698637, 0.4809302746734916, 0.9437695654905504], 219 -> 
             RGBColor[
              0.5262688994117111, 0.6262878265429939, 0.9558489620296395], 
             400 -> RGBColor[
              0.295921828646773, 0.42836298280833224`, 0.9401636824130951], 9 -> 
             RGBColor[
              0.5751436787516512, 0.6659665741948753, 0.9596965636934954], 11 -> 
             RGBColor[
              0.23891813183632316`, 0.3684484832174229, 0.9369174062091523], 
             44 -> RGBColor[
              0.49667724948997916`, 0.6022639920478948, 0.9535193989500155], 
             153 -> RGBColor[
              0.24493296406314102`, 0.3747704532501981, 0.9372599420063227], 
             471 -> RGBColor[
              0.8568125830318801, 0.4376919853814662, 0.20203709971295072`], 
             406 -> RGBColor[
              0.990618380894789, 0.9800157372285142, 0.4180546106567104], 32 -> 
             RGBColor[
              0.5357107322431658, 0.6339531317852908, 0.9565922576967049], 
             162 -> 
             RGBColor[
              0.46203141681910903`, 0.5741369443087071, 0.9507919520902978], 
             493 -> RGBColor[
              0.9935772608954081, 0.9886707354308406, 0.5423026688954158], 90 -> 
             RGBColor[
              0.8647697772859632, 0.4788329671240561, 0.2088729261823753], 
             331 -> RGBColor[
              0.8366916950922476, 0.8726192625482565, 0.984285594873034], 8 -> 
             RGBColor[
              0.6202936289377985, 0.7026213377380665, 0.963250933161866], 364 -> 
             RGBColor[
              0.2585666750316088, 0.38910034790526005`, 0.938036361676709], 
             342 -> RGBColor[
              0.25998714329821626`, 0.39059335011635443`, 0.9381172552430979],
              163 -> RGBColor[
              0.26699231078344465`, 0.3979562252966011, 0.9385161891681649], 
             49 -> RGBColor[
              0.49021471545548245`, 0.5970174157848499, 0.9530106445977776], 
             338 -> RGBColor[
              0.32010532781399464`, 0.4516808788160655, 0.9416178063236486], 
             76 -> RGBColor[
              0.4113253016274047, 0.530691035284047, 0.9474302623923834], 369 -> 
             RGBColor[
              0.4199474238450335, 0.5381590841884939, 0.9479796563958474], 
             445 -> RGBColor[
              0.22963931784821143`, 0.3586958614051314, 0.9363889914793045], 
             82 -> RGBColor[
              0.25827862318556116`, 0.3887975871515221, 0.9380199575502111], 
             67 -> RGBColor[
              0.25662307112871396`, 0.38705749697171266`, 0.9379256763097434],
              430 -> RGBColor[
              0.23973902577549727`, 0.36931129479517677`, 0.9369641549045845],
              211 -> RGBColor[
              0.2310404057237692, 0.3601684935964447, 
               0.9364687813610937]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9V3c41W/cPkZ2skfWMY5xzsFxzjFCvnekUipFSBqEZKVlFlIpoUVlJUVG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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 54}], {
             RGBColor[
             0.24744314331957223`, 0.3774088108032645, 0.937402893001499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 70}], {
             RGBColor[
             0.26220782647507634`, 0.3929274289346799, 0.9382437198648137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 84}], {
             RGBColor[
             0.249739891419232, 0.3798228386782472, 0.9375336894080404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 131}], {
             RGBColor[
             0.26488726968740706`, 0.3957436936373514, 0.9383963101918749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 135}], {
             RGBColor[
             0.2583961289533292, 0.38892109316374235`, 0.9380266493298512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 147}], {
             RGBColor[
             0.2588293294875211, 0.38937641439167825`, 0.9380513194594108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 170}], {
             RGBColor[
             0.2814230291570491, 0.41312382526764985`, 0.939337997231207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 171}], {
             RGBColor[
             0.2639538573417897, 0.3947626180803467, 0.9383431537396518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 265}], {
             RGBColor[
             0.2935899974663011, 0.4247777732380918, 0.9400724206184119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 266}], {
             RGBColor[
             0.27784311638010406`, 0.40936110995950087`, 0.9391341264945663]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 374}], {
             RGBColor[
             0.25894790578239785`, 0.38950104559576504`, 0.9380580722039861]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 385}], {
             RGBColor[
             0.2498185382943033, 0.379905501530447, 0.937538168231228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 391}], {
             RGBColor[
             0.25364635844324135`, 0.38392878320479584`, 0.9377561569259576]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 433}], {
             RGBColor[
             0.2958358704615542, 0.4267230355457211, 0.940215525659722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 47}], {
             RGBColor[
             0.22219066917343752`, 0.3508668593763409, 0.9359648019565643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 54}], {
             RGBColor[
             0.22058424144202293`, 0.3491784019772233, 0.9358733182737572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 55}], {
             RGBColor[
             0.21196267506411343`, 0.3401165890751596, 0.9353823328229998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 230}], {
             RGBColor[
             0.21816285424353754`, 0.34663337050679954`, 0.9357354238549247]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 242}], {
             RGBColor[
             0.21872765624032725`, 0.34722701321594046`, 0.9357675884930923]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 250}], {
             RGBColor[
             0.20844651025640323`, 0.33642087692453115`, 0.9351820924389003]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 339}], {
             RGBColor[
             0.21206918576719214`, 0.340228538577264, 0.9353883984499716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 365}], {
             RGBColor[
             0.21471117528305686`, 0.3430054370702481, 0.9355388558444269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 8}], {
             RGBColor[
             0.5409798313044035, 0.6382308237734111, 0.9570070604761514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 31}], {
             RGBColor[
             0.4573521482388232, 0.5703305077559329, 0.9504256815919188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[
             0.4618487252450588, 0.5739886270587315, 0.9507775699403673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 203}], {
             RGBColor[
             0.49811633466717364`, 0.6034323062247897, 0.9536326890067068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 221}], {
             RGBColor[
             0.4991380572062573, 0.6042617866100937, 0.9537131227476765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 223}], {
             RGBColor[
             0.4257649092191724, 0.5429712289379067, 0.9484129706530855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 258}], {
             RGBColor[
             0.41754423807969365`, 0.5358508967798354, 0.9478891567573319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 381}], {
             RGBColor[
             0.5154854178683257, 0.6175333104357662, 0.9550000468613498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 439}], {
             RGBColor[
             0.6612892589149015, 0.732886286051436, 0.9686794915733958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 480}], {
             RGBColor[
             0.4076066344287682, 0.5272434439758863, 0.9472559414401728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 29}], {
             RGBColor[
             0.36696197867847585`, 0.49226575471112954`, 0.9446034706830237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 185}], {
             RGBColor[
             0.30412419819916303`, 0.4355457825101565, 0.9406834624888651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 196}], {
             RGBColor[
             0.31000149085861584`, 0.44172318973711877`, 0.9410181656111457]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 318}], {
             RGBColor[
             0.33312298494508064`, 0.46295611913654056`, 0.9424472799249791]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 321}], {
             RGBColor[
             0.32873955000778277`, 0.45915940811169914`, 0.9421679713268938]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 335}], {
             RGBColor[
             0.3005379095306292, 0.4317763657356928, 0.9404792286546308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 383}], {
             RGBColor[
             0.32662308368104653`, 0.45732623135617084`, 0.9420331119640719]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 479}], {
             RGBColor[
             0.3678971603336924, 0.49307576205728143`, 0.9446630596311456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 482}], {
             RGBColor[
             0.3413925426988842, 0.4701187944228272, 0.9429742088325687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 496}], {
             RGBColor[
             0.3005965950412318, 0.4318380479282125, 0.9404825707076422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.23876273655839006`, 0.3682851529276855, 0.9369085566779607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 23}], {
             RGBColor[
             0.23055442452635688`, 0.3596576965449768, 0.9364411054508459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 41}], {
             RGBColor[
             0.23556700835298144`, 0.36492623996293, 0.9367265646843188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 102}], {
             RGBColor[
             0.2575724490549457, 0.3880553533662194, 0.9379797419781635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 186}], {
             RGBColor[
             0.23715887571324926`, 0.36659939348879156`, 0.9368172191755294]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 193}], {
             RGBColor[
             0.263209529621381, 0.3939802824530939, 0.9383007653771087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 202}], {
             RGBColor[
             0.23883220085490312`, 0.3683581643076115, 0.9369125125668838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 211}], {
             RGBColor[
             0.2348238735021131, 0.3641451581171964, 0.9366842442539314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 212}], {
             RGBColor[
             0.22856179646777947`, 0.35756331811549596`, 0.9363276282307389]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 300}], {
             RGBColor[
             0.23228249418787045`, 0.3614740073251723, 0.936539516461619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 414}], {
             RGBColor[
             0.2566326545868817, 0.38706756979387325`, 0.9379262220735086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 485}], {
             RGBColor[
             0.24330426601765148`, 0.37305858833896816`, 0.9371671900620748]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 24}], {
             RGBColor[
             0.8323309168683787, 0.869142096362715, 0.9838696599531287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 77}], {
             RGBColor[
             0.7172538475630181, 0.7785612627115652, 0.9728085302210365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 79}], {
             RGBColor[
             0.9107592672849488, 0.9273249908421985, 0.7765494419084453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 80}], {
             RGBColor[
             0.8086163665159423, 0.8504788015959455, 0.9815424524658205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 81}], {
             RGBColor[
             0.825653983169494, 0.8638180906717614, 0.9832328080563602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 99}], {
             RGBColor[
             0.9106556765920616, 0.9271034208247384, 0.765274234275318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 156}], {
             RGBColor[
             0.6474994925034097, 0.7219315348762902, 0.9673172118721224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 267}], {
             RGBColor[
             0.9083762130299251, 0.9201045780958312, 0.6977188544044266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 278}], {
             RGBColor[
             0.8880267801577246, 0.9132258771339024, 0.9778589426846744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 329}], {
             RGBColor[
             0.8551238518896912, 0.8873165640509703, 0.9860436704429549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 406}], {
             RGBColor[
             0.9091541002347256, 0.9227285742942248, 0.700740799303404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 413}], {
             RGBColor[
             0.9007629224656561, 0.8944231613369187, 0.6681426582115271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 486}], {
             RGBColor[
             0.8813087089314302, 0.9081956582870432, 0.9885412054830938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 28}], {
             RGBColor[
             0.901769090567154, 0.9237583305634441, 0.9644245605513657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 49}], {
             RGBColor[
             0.6644484112533559, 0.7356118894004525, 0.9687430433701605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 69}], {
             RGBColor[
             0.874072307624645, 0.9024255483118935, 0.9878509910664408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 142}], {
             RGBColor[
             0.7691032060058948, 0.819699666861827, 0.9775805727504322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 173}], {
             RGBColor[
             0.9116225315818571, 0.9310453814508525, 0.9449853696775101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[
             0.9125990982944516, 0.9314492168831301, 0.9288011319761822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 241}], {
             RGBColor[
             0.7720821236708154, 0.8220268199822758, 0.9778774834237032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 388}], {
             RGBColor[
             0.8924271040987608, 0.9167910923514154, 0.9802381068620604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 402}], {
             RGBColor[
             0.6954966701641224, 0.7608182646923372, 0.971187276045136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 436}], {
             RGBColor[
             0.6558009604167452, 0.7285914992480711, 0.9680622843636464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 461}], {
             RGBColor[
             0.8915688064008891, 0.9161509753336762, 0.9816909809846657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 487}], {
             RGBColor[
             0.7090567422484308, 0.7718269420846646, 0.9722547745917934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 31}], {
             RGBColor[
             0.5366659458722182, 0.6347210217205881, 0.9566695542776334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 40}], {
             RGBColor[
             0.5032468930597369, 0.6057751178648505, 0.9545401217837302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 114}], {
             RGBColor[
             0.5604860564407306, 0.6540668560845098, 0.9585426619725401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 115}], {
             RGBColor[
             0.7707310045144475, 0.8213000079229384, 0.9777969948316587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 162}], {
             RGBColor[
             0.5411625228784538, 0.6383791410233868, 0.9570214426260819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 203}], {
             RGBColor[
             0.5774301323005686, 0.6678228201894449, 0.9598765616924215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 221}], {
             RGBColor[
             0.5784518548396522, 0.6686523005747489, 0.9599569954333912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 258}], {
             RGBColor[
             0.4968580357130886, 0.6002414107444907, 0.9541330294430466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 289}], {
             RGBColor[
             0.5298323406094952, 0.6288020963090049, 0.9562341229930127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 291}], {
             RGBColor[
             0.637610384777719, 0.7164873323549865, 0.9647458039813404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 297}], {
             RGBColor[
             0.5698289191235334, 0.6616518129015765, 0.9592781663469641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 311}], {
             RGBColor[
             0.6835752486050087, 0.752395433322769, 0.9693271520415703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 381}], {
             RGBColor[
             0.5947992155017207, 0.6819238244004215, 0.9612439195470645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 419}], {
             RGBColor[
             0.5664920822105015, 0.6589428183727875, 0.9590154783219338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 439}], {
             RGBColor[
             0.7406030565482964, 0.7972768000160912, 0.9749233642591105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 19}], {
             RGBColor[
             0.5674341026863339, 0.6597075930326068, 0.9590896376245259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 26}], {
             RGBColor[
             0.4808866078491948, 0.5876336896788764, 0.952776616899017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 34}], {
             RGBColor[
             0.559448373541096, 0.6532244183595045, 0.9584609717735231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 44}], {
             RGBColor[
             0.5359104641208152, 0.634115283121385, 0.9566079813217554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.5464995084832656, 0.6427119463658346, 0.9574415896829152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 117}], {
             RGBColor[
             0.4781094761010015, 0.5852282777412916, 0.9525996605197433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 139}], {
             RGBColor[
             0.5695894293133013, 0.6614573842847371, 0.9592593128318224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 247}], {
             RGBColor[
             0.5350775301382318, 0.6334390697910756, 0.9565424097075088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 269}], {
             RGBColor[
             0.512041509774998, 0.614618499836106, 0.9547617797005311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 360}], {
             RGBColor[
             0.5772550006439877, 0.6676806404210414, 0.9598627746868871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 425}], {
             RGBColor[
             0.47524326414852586`, 0.5827457090080587, 0.9524170280286233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 466}], {
             RGBColor[
             0.5393259259475076, 0.6368881088970959, 0.9568768589880016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 468}], {
             RGBColor[
             0.5267603512092651, 0.6266868092518996, 0.9558876509153902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 120}], {
             RGBColor[
             0.21319195993880496`, 0.3414086454196232, 0.9354523387780493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 123}], {
             RGBColor[
             0.21296296597852177`, 0.34116795824830987`, 0.9354392979107774]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 125}], {
             RGBColor[
             0.21381800062875955`, 0.3420666538780378, 0.935487990869198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 177}], {
             RGBColor[
             0.21382948684753797`, 0.34207872662224226`, 0.9354886449923652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 245}], {
             RGBColor[
             0.22026264269435236`, 0.3488403813028832, 0.93585500370084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 438}], {
             RGBColor[
             0.22021348611856342`, 0.3487887146250221, 0.9358522043065695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 455}], {
             RGBColor[
             0.21145152724630215`, 0.3395793403099965, 0.9353532237109508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 23}], {
             RGBColor[
             0.23070981980428998`, 0.3598210268347142, 0.9364499549820375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 41}], {
             RGBColor[
             0.23572240363091454`, 0.3650895702526674, 0.9367354142155104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 102}], {
             RGBColor[
             0.2577278443328788, 0.3882186836559568, 0.9379885915093551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 186}], {
             RGBColor[
             0.23731427099118235`, 0.3667627237785289, 0.936826068706721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 193}], {
             RGBColor[
             0.2633649248993141, 0.3941436127428313, 0.9383096149083003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 202}], {
             RGBColor[
             0.2389875961328362, 0.3685214945973489, 0.9369213620980754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 211}], {
             RGBColor[
             0.23497926878004616`, 0.3643084884069338, 0.936693093785123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 414}], {
             RGBColor[
             0.25678804986481485`, 0.38723090008361066`, 0.9379350716047002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 485}], {
             RGBColor[
             0.24345966129558455`, 0.3732219186287056, 0.9371760395932665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 497}], {
             RGBColor[
             0.2374558873234022, 0.36691157152268605`, 0.9368341335473384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 198}], {
             RGBColor[
             0.2771414265920781, 0.4086235895025834, 0.9390941662991953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 373}], {
             RGBColor[
             0.28300945147034123`, 0.414791255703904, 0.9394283416350475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 480}], {
             RGBColor[
             0.31297532312712917`, 0.4421451064609878, 0.9412865192071291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 154}], {
             RGBColor[
             0.3030787322552839, 0.435811820273263, 0.9405739494865415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 229}], {
             RGBColor[
             0.2937960299949141, 0.4261286336418093, 0.9400426213247091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 244}], {
             RGBColor[
             0.3195286449146627, 0.4500599078221664, 0.9416221233751105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 313}], {
             RGBColor[
             0.2817870779153078, 0.4135064635946042, 0.939358729269428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 334}], {
             RGBColor[
             0.3497101697631252, 0.47620162767835794`, 0.94354526344998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 338}], {
             RGBColor[
             0.30836079438708164`, 0.4403868770076641, 0.9409105178148355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 340}], {
             RGBColor[
             0.3170254114231826, 0.44789173278801986`, 0.9414626195505558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 363}], {
             RGBColor[
             0.3507138092232281, 0.4770709297343131, 0.9436092144688942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 379}], {
             RGBColor[
             0.3029577301181068, 0.43570701430378433`, 0.9405662393373586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 380}], {
             RGBColor[
             0.28473366122711574`, 0.4166035094794867, 0.939526532829956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 390}], {
             RGBColor[
             0.29868486413343276`, 0.4312671082913797, 0.9403210331965157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 478}], {
             RGBColor[
             0.28132910192119526`, 0.41302510178743673`, 0.939332648214078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 63}], {
             RGBColor[
             0.3630391373968948, 0.48868276614576933`, 0.9443602925394342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 72}], {
             RGBColor[
             0.2803635687690008, 0.4120102652261427, 0.9392776625294388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 75}], {
             RGBColor[
             0.32584559541094904`, 0.45646758947931865`, 0.9419903529330476]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 149}], {
             RGBColor[
             0.33030872638618497`, 0.46033332920658265`, 0.9422747396921978]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 158}], {
             RGBColor[
             0.33213200521333075`, 0.4619125616859979, 0.9423909174068014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 163}], {
             RGBColor[
             0.2868674954285888, 0.4188463045181374, 0.9396480515310051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 182}], {
             RGBColor[
             0.34266467028924463`, 0.47103542678761523`, 0.9430620495117685]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 187}], {
             RGBColor[
             0.28568538812664784`, 0.41760383479386565`, 0.9395807322689307]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 279}], {
             RGBColor[
             0.2926514518650601, 0.4249256094568878, 0.9399774392934654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 322}], {
             RGBColor[
             0.2829806146027809, 0.4147609463277351, 0.9394266994181002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 324}], {
             RGBColor[
             0.33821006500838097`, 0.4671770715883025, 0.9427782060023248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 441}], {
             RGBColor[
             0.3784375409652084, 0.5020200893703757, 0.9453414651985335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 494}], {
             RGBColor[
             0.2826231066390982, 0.4143851827905905, 0.9394063398684542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 78}], {
             RGBColor[
             0.22683394628673456`, 0.35574723802318886`, 0.9362292297190538]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 97}], {
             RGBColor[
             0.23298665056537604`, 0.36221412032402367`, 0.936579617125612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 104}], {
             RGBColor[
             0.24040623048550225`, 0.3700125692486139, 0.9370021512257783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.24125115959042637`, 0.3709006433094886, 0.9370502686883432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 148}], {
             RGBColor[
             0.2369473179686802, 0.36637703288571377`, 0.9368051712749479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 153}], {
             RGBColor[
             0.23958587882071014`, 0.3691503276356177, 0.93695543341207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 190}], {
             RGBColor[
             0.24117420601353035`, 0.37081976022103225`, 0.9370458862959816]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 323}], {
             RGBColor[
             0.2367917298527569, 0.36621349991102203`, 0.936796310761918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 356}], {
             RGBColor[
             0.2517883622305454, 0.38197591138148856`, 0.9376503467903037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 408}], {
             RGBColor[
             0.22837166352845595`, 0.3573634763411423, 0.9363168004411209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 430}], {
             RGBColor[
             0.23698890967688827`, 0.36642074840810707`, 0.9368075398612009]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 452}], {
             RGBColor[
             0.22909610908040262`, 0.3581249145487392, 0.9363580565435832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 39}], {
             RGBColor[
             0.5137718344766236, 0.6147998451486828, 0.9552360290912556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 45}], {
             RGBColor[
             0.343332276555383, 0.46939838880724916`, 0.9431857012274175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 52}], {
             RGBColor[
             0.6198385630520318, 0.4001930339226935, 0.5644333341255259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 56}], {
             RGBColor[
             0.6202778449645745, 0.4035695471970573, 0.5648539909810746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 179}], {
             RGBColor[
             0.29140560923354364`, 0.4148201691111312, 0.940228554342059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 200}], {
             RGBColor[
             0.6523550443789783, 0.5834045301394526, 0.5929583920999518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 236}], {
             RGBColor[
             0.34560261915581325`, 0.4717846628283363, 0.9433149938798411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 243}], {
             RGBColor[
             0.6215940953786275, 0.41368682466407874`, 0.566114433864064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 254}], {
             RGBColor[
             0.3201901654275895, 0.4450745627173458, 0.941867792234375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 276}], {
             RGBColor[
             0.5117111188744836, 0.6131268633886855, 0.9550738020104051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 283}], {
             RGBColor[
             0.29254812031783006`, 0.4160210207001029, 0.9402936186581154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 292}], {
             RGBColor[
             0.29142635679170903`, 0.41484197611023416`, 0.9402297358848033]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 422}], {
             RGBColor[
             0.3189470428658002, 0.4437679620863825, 0.9417969982435161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 454}], {
             RGBColor[
             0.6518822537994468, 0.581257698540845, 0.5925638840512331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 205}], {
             RGBColor[
             0.9368989095333399, 0.9481665884975428, 0.7789256469520753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 252}], {
             RGBColor[
             0.8078836333626171, 0.8503289562761027, 0.9813572830192461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 282}], {
             RGBColor[
             0.7438148228852721, 0.7997463454963281, 0.9753349394405884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 293}], {
             RGBColor[
             0.9171217844286204, 0.9362730779745756, 0.9753514321588153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 298}], {
             RGBColor[
             0.8908055349705915, 0.9157681695861948, 0.9894470212286257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 418}], {
             RGBColor[
             0.9292223734187801, 0.9452976774305406, 0.9548682913375369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 432}], {
             RGBColor[
             0.8892978625365586, 0.9145659925119751, 0.9893032180859526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 467}], {
             RGBColor[
             0.7934052123801664, 0.8390183037645371, 0.979914209324252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 52}], {
             RGBColor[
             0.8600894824934477, 0.42201909265360843`, 0.20357506457964797`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 56}], {
             RGBColor[
             0.8605287644059905, 0.4253956059279722, 0.2039957214351967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 65}], {
             RGBColor[
             0.9349243740088637, 0.7652639008938271, 0.3116367388337401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 88}], {
             RGBColor[
             0.8754970234499582, 0.5275428865427625, 0.2178240033304778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 166}], {
             RGBColor[
             0.8612521660936727, 0.43095598829613885`, 0.2046884517082866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 167}], {
             RGBColor[
             0.9355270875213144, 0.7783260157628717, 0.5479056765432442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 210}], {
             RGBColor[
             0.8602238171594843, 0.4230516477625904, 0.20370370360755374`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 227}], {
             RGBColor[
             0.8650075437066738, 0.45982146624662823`, 0.2082846055515888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 243}], {
             RGBColor[
             0.8618450148200435, 0.43551288339499367`, 0.2052561643181862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 326}], {
             RGBColor[
             0.8797797158009789, 0.5469895922605361, 0.22139758680656518`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 348}], {
             RGBColor[
             0.9221477650002106, 0.7221653986171828, 0.2620020254952798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 428}], {
             RGBColor[
             0.8573587081531882, 0.40102916444142644`, 0.2009600719874468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 434}], {
             RGBColor[
             0.9377932493402739, 0.7792631319127137, 0.510349510564296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 469}], {
             RGBColor[
             0.8724072991337889, 0.5135131700464854, 0.21524586162499276`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 474}], {
             RGBColor[
             0.9387405372806834, 0.7796548598202627, 0.49465049788910304`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 495}], {
             RGBColor[
             0.8632931958328989, 0.4466442372567656, 0.2066429440915829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 26}], {
             RGBColor[
             0.4731770317838775, 0.5813747085166081, 0.9521696908300475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 34}], {
             RGBColor[
             0.5517387974757788, 0.6469654371972362, 0.9578540457045537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 44}], {
             RGBColor[
             0.5282008880554978, 0.6278563019591167, 0.956001055252786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 139}], {
             RGBColor[
             0.5618798532479841, 0.6551984031224687, 0.9586523867628529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 234}], {
             RGBColor[
             0.474151584993228, 0.582218817524079, 0.9522317884987839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 247}], {
             RGBColor[
             0.5273679540729146, 0.6271800886288073, 0.9559354836385393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 269}], {
             RGBColor[
             0.5043319337096805, 0.6083595186738375, 0.9541548536315616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 360}], {
             RGBColor[
             0.5695454245786704, 0.661421659258773, 0.9592558486179177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 393}], {
             RGBColor[
             0.5104680056398668, 0.6134599491568583, 0.954605057791339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 466}], {
             RGBColor[
             0.5316163498821903, 0.6306291277348275, 0.9562699329190321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 468}], {
             RGBColor[
             0.5190507751439478, 0.6204278280896312, 0.9552807248464208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 62}], {
             RGBColor[
             0.8509265138034974, 0.3513524058869604, 0.19479135055817565`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 194}], {
             RGBColor[
             0.9355250585723344, 0.7786349412620628, 0.5492457614630861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 228}], {
             RGBColor[
             0.9388076655030091, 0.7780938721344945, 0.3568427286125849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 388}], {
             RGBColor[
             0.9153530643766437, 0.7639768167303482, 0.6006827363489642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 490}], {
             RGBColor[
             0.9375437932423437, 0.7794697399272263, 0.5157901036631747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 33}], {
             RGBColor[
             0.9296510090196749, 0.7439907144053559, 0.3002556094938443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 65}], {
             RGBColor[
             0.9831762967586118, 0.9549118399527363, 0.38914351910732653`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 119}], {
             RGBColor[
             0.9857675700825197, 0.9687962754074746, 0.5924568745131584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 164}], {
             RGBColor[
             0.8992062375406565, 0.5414501296947882, 0.27233399794458657`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 166}], {
             RGBColor[
             0.9095040888434207, 0.6206039273550481, 0.282195231981873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 175}], {
             RGBColor[
             0.9683090151158134, 0.9568481859192783, 0.670037151361724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 227}], {
             RGBColor[
             0.9132594664564218, 0.6494694053055374, 0.28579138582517527`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 309}], {
             RGBColor[
             0.9869592653755547, 0.967346961753188, 0.4315364838739727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 320}], {
             RGBColor[
             0.9847451317139568, 0.9683734708666063, 0.6094013242659239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 337}], {
             RGBColor[
             0.9205492329643337, 0.9192823831910986, 0.6833909335036439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 348}], {
             RGBColor[
             0.9703996877499586, 0.911813337676092, 0.3395088057688662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 375}], {
             RGBColor[
             0.9695446020803578, 0.9577696846543478, 0.6679456249234423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 428}], {
             RGBColor[
             0.9056106309029361, 0.5906771035003356, 0.2784668522610333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 489}], {
             RGBColor[
             0.9854926800563032, 0.9686826013172827, 0.5970125136401502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 63}], {
             RGBColor[
             0.4353760609281416, 0.5515225941640346, 0.948962755507775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 149}], {
             RGBColor[
             0.40264564991743174`, 0.5231731572248479, 0.9468772026605385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 160}], {
             RGBColor[
             0.4369491379476227, 0.5528851144131592, 0.949062990584439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 165}], {
             RGBColor[
             0.4377248912958056, 0.5535570329728583, 0.9491124209018134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 182}], {
             RGBColor[
             0.4150015938204914, 0.5338752548058805, 0.9476645124801093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 268}], {
             RGBColor[
             0.4305356531895016, 0.5473300762667914, 0.9486543290068734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 275}], {
             RGBColor[
             0.43256024452096153`, 0.549083675519183, 0.9487833341762382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 282}], {
             RGBColor[
             0.5295374583805197, 0.6288897605144723, 0.956120540334634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 285}], {
             RGBColor[
             0.38291743430858444`, 0.506085568433412, 0.9456201382069189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 324}], {
             RGBColor[
             0.41054698853962773`, 0.5300168996065678, 0.9473806689706655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 353}], {
             RGBColor[
             0.5455395337034719, 0.641880966146923, 0.9573802823215901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 441}], {
             RGBColor[
             0.45077446449645514`, 0.564859917388641, 0.9499439281668742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 481}], {
             RGBColor[
             0.38481661217346425`, 0.507730540844516, 0.9457411521410921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 41}], {
             RGBColor[
             0.22751409159888136`, 0.35646211386995863`, 0.9362679629883957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 186}], {
             RGBColor[
             0.22910595895914918`, 0.35813526739582024`, 0.9363586174796061]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 202}], {
             RGBColor[
             0.23077928410080303`, 0.35989403821464017`, 0.9364539108709606]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 211}], {
             RGBColor[
             0.226770956748013, 0.3556810320242251, 0.9362256425580082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 212}], {
             RGBColor[
             0.22050887971367938`, 0.3490991920225246, 0.9358690265348157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 485}], {
             RGBColor[
             0.2352513492635514, 0.3645944622459968, 0.9367085883661517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 497}], {
             RGBColor[
             0.22924757529136902`, 0.3582841151399774, 0.9363666823202235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 77}], {
             RGBColor[
             0.7218949448567346, 0.7822619477143448, 0.9732512022240677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 81}], {
             RGBColor[
             0.8302950804632105, 0.8675187756745408, 0.9836754800593912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 83}], {
             RGBColor[
             0.878858858195596, 0.9062422138097157, 0.9883075365329024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 176}], {
             RGBColor[
             0.7219583100603643, 0.7823133904412213, 0.9732561905650118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 197}], {
             RGBColor[
             0.7672988184851579, 0.8182762435725834, 0.9774043962108645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 237}], {
             RGBColor[
             0.871532203465174, 0.9004001382044219, 0.9876087136641327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 267}], {
             RGBColor[
             0.9130173103236416, 0.9238052630986108, 0.6981615264074577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 270}], {
             RGBColor[
             0.9134975511433701, 0.9314925430785823, 0.899659555679228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 278}], {
             RGBColor[
             0.8926678774514412, 0.9169265621366819, 0.9783016146877055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 329}], {
             RGBColor[
             0.8597649491834076, 0.8910172490537498, 0.986486342445986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 426}], {
             RGBColor[
             0.8535732035252862, 0.8860801191364223, 0.9858957682176778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 448}], {
             RGBColor[
             0.7024556642269519, 0.7664802639694746, 0.97172087084446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 489}], {
             RGBColor[
             0.9135348042436461, 0.9315079481929074, 0.8990421753997224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[
             0.36235029179287925`, 0.48827134332094824`, 0.9443096180726283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 96}], {
             RGBColor[
             0.3047685081778331, 0.4372333951604509, 0.9406831592217764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 157}], {
             RGBColor[
             0.3079594456965586, 0.4405872728097553, 0.9408648783928987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.2917531123703574, 0.42355338894303707`, 0.9399419516850931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 246}], {
             RGBColor[
             0.3037983452782409, 0.43621369244109887`, 0.940627909879872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 288}], {
             RGBColor[
             0.2847205959795895, 0.4161617683290476, 0.9395414602803146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 333}], {
             RGBColor[
             0.34601220845973285`, 0.4741201167137219, 0.94326856984984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 343}], {
             RGBColor[
             0.3031313951145783, 0.4355126855320067, 0.9405899280547156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 392}], {
             RGBColor[
             0.3096883372024623, 0.4424044474005129, 0.9409633362064942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 459}], {
             RGBColor[
             0.35196069990557133`, 0.47927240102423385`, 0.9436476024647243]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 465}], {
             RGBColor[
             0.2980004320712376, 0.430119718051609, 0.9402977272999771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 492}], {
             RGBColor[
             0.29499729755319337`, 0.42696323326341856`, 0.9401267032319138]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 34}], {
             RGBColor[
             0.46519130263863967`, 0.5748915338435057, 0.9515410249790447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 44}], {
             RGBColor[
             0.4416533932183588, 0.5557823986053863, 0.949688034527277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 106}], {
             RGBColor[
             0.45224243758080923`, 0.5643790618498358, 0.9505216428884367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 117}], {
             RGBColor[
             0.38385240519854513`, 0.5068953932252928, 0.9456797137252648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 139}], {
             RGBColor[
             0.4753323584108449, 0.5831244997687381, 0.952339366037344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 215}], {
             RGBColor[
             0.33537631974199883`, 0.4626312893738342, 0.942674216260174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 224}], {
             RGBColor[
             0.34279791451999597`, 0.4704318560417961, 0.9430968651035153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 247}], {
             RGBColor[
             0.44082045923577545`, 0.5551061852750767, 0.9496224629130303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 269}], {
             RGBColor[
             0.4177844388725415, 0.5362856153201071, 0.9478418329060527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 351}], {
             RGBColor[
             0.3383374936256977, 0.4657436708748698, 0.9428428507321864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 360}], {
             RGBColor[
             0.48299792974153133`, 0.5893477559050426, 0.9529428278924086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 425}], {
             RGBColor[
             0.38098619324606947`, 0.5044128244920598, 0.9454970812341448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 466}], {
             RGBColor[
             0.4450688550450512, 0.558555224381097, 0.9499569121935232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 468}], {
             RGBColor[
             0.43250328030680874`, 0.5483539247359007, 0.9489677041209118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 40}], {
             RGBColor[
             0.44915953688308596`, 0.5618645655130168, 0.9502821669769903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 114}], {
             RGBColor[
             0.5063987002640795, 0.610156303732676, 0.9542847071658003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 199}], {
             RGBColor[
             0.4274813973658525, 0.5430880506381621, 0.9489008550961784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 220}], {
             RGBColor[
             0.4255160611016982, 0.5413857751468245, 0.948775625607305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 277}], {
             RGBColor[
             0.6417102241932708, 0.7180330594388474, 0.9662874050409727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 289}], {
             RGBColor[
             0.47574498443284424`, 0.5848915439571711, 0.9519761681862727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 291}], {
             RGBColor[
             0.583523028601068, 0.6725767800031528, 0.9604878491746004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 297}], {
             RGBColor[
             0.5157415629468824, 0.6177412605497428, 0.9550202115402241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 311}], {
             RGBColor[
             0.6294878924283578, 0.7084848809709354, 0.9650691972348303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 319}], {
             RGBColor[
             0.6135043005796454, 0.695998377538924, 0.9634761021745089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 349}], {
             RGBColor[
             0.46286019331944683`, 0.5737313855031778, 0.9511551606901004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 359}], {
             RGBColor[
             0.44878508964320496`, 0.5615402381340974, 0.9502583075299758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 371}], {
             RGBColor[
             0.43753141765926407`, 0.551792873087608, 0.9495412335023905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 419}], {
             RGBColor[
             0.5124047260338506, 0.6150322660209537, 0.9547575235151939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 488}], {
             RGBColor[
             0.640741608541348, 0.7172763695298137, 0.9661908624850168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 69}], {
             RGBColor[
             0.9371592911405698, 0.9519775158592825, 0.9678001094752631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 142}], {
             RGBColor[
             0.8321901895218196, 0.869251634409216, 0.9575296911592543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 173}], {
             RGBColor[
             0.9747095150977819, 0.9805973489982415, 0.9249344880863324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 194}], {
             RGBColor[
             0.9756860818103763, 0.9810011844305191, 0.9087502503850045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 241}], {
             RGBColor[
             0.8351691071867402, 0.8715787875296648, 0.9578266018325254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 417}], {
             RGBColor[
             0.8329443683967894, 0.8698408046783143, 0.9576048606613091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 461}], {
             RGBColor[
             0.954655789916814, 0.9657029428810652, 0.9616400993934879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 493}], {
             RGBColor[
             0.9792166674892435, 0.9809905167708368, 0.7433381739278018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 77}], {
             RGBColor[
             0.5082190929851442, 0.6104476858288989, 0.9547558471761093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 172}], {
             RGBColor[
             0.3806363827099919, 0.5041098361876981, 0.9454747916161113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 318}], {
             RGBColor[
             0.37578131668551923`, 0.4999046220200136, 0.9451654311021982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 321}], {
             RGBColor[
             0.3713978817482214, 0.49610791099517215`, 0.944886122504113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 383}], {
             RGBColor[
             0.3692814154214852, 0.49427473423964385`, 0.944751263141291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 479}], {
             RGBColor[
             0.410555492074131, 0.5300242649407545, 0.9473812108083647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 482}], {
             RGBColor[
             0.38405087443932273`, 0.5070672973063002, 0.9456923600097877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 43}], {
             RGBColor[
             0.2805395184040802, 0.4121951994484624, 0.9392876826008625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 64}], {
             RGBColor[
             0.27788283656739987`, 0.4094028583947541, 0.9391363885004721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 110}], {
             RGBColor[
             0.26982326266389456`, 0.40093173521567016`, 0.9386774076897386]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 217}], {
             RGBColor[
             0.2938254921740675, 0.42514500116830317`, 0.9400814485951139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 290}], {
             RGBColor[
             0.2772082322816696, 0.40869380651806936`, 0.9390979707843874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 316}], {
             RGBColor[
             0.25921313179459604`, 0.3897798149508858, 0.938073176433014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 355}], {
             RGBColor[
             0.29831901354920054`, 0.4290370635324922, 0.9403677718036725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 378}], {
             RGBColor[
             0.2755078252460146, 0.406906570911563, 0.9390011351192336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 384}], {
             RGBColor[
             0.2758760121335012, 0.4072935586747084, 0.9390221028177923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[
             0.4196192099941566, 0.5378748018473721, 0.9479587428994976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 114}], {
             RGBColor[
             0.47685837337515014`, 0.5861665400670314, 0.9519612830883075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 162}], {
             RGBColor[
             0.4575348398128734, 0.5704788250059085, 0.9504400637418493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 203}], {
             RGBColor[
             0.4938024492349883, 0.5999225041719667, 0.9532951828081889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 208}], {
             RGBColor[
             0.38757839390763205`, 0.5101226573714661, 0.9459171304310454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 221}], {
             RGBColor[
             0.4948241717740719, 0.6007519845572706, 0.9533756165491586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 223}], {
             RGBColor[
             0.42145102378698707`, 0.5394614268850837, 0.9480754644545675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 258}], {
             RGBColor[
             0.4132303526475083, 0.5323410947270124, 0.947551650558814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 289}], {
             RGBColor[
             0.4462046575439149, 0.5609017802915265, 0.9496527441087801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 297}], {
             RGBColor[
             0.48620123605795307`, 0.5937514968840982, 0.9526967874627315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 314}], {
             RGBColor[
             0.3915568678230763, 0.5135686115131106, 0.9461706352709112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 381}], {
             RGBColor[
             0.5111715324361403, 0.6140235083829432, 0.9546625406628318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 397}], {
             RGBColor[
             0.40579315804314603`, 0.5258993705649835, 0.947077759095077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 419}], {
             RGBColor[
             0.4828643991449212, 0.5910425023553091, 0.9524340994377012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 472}], {
             RGBColor[
             0.39074248974700837`, 0.5128632381554529, 0.9461187438200305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 103}], {
             RGBColor[
             0.5080332189208779, 0.6114832796124914, 0.9544133824619024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 155}], {
             RGBColor[
             0.5507999265063706, 0.6462032194486154, 0.9577801343426442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 331}], {
             RGBColor[
             0.6862012136677067, 0.7532861971667737, 0.9704389262848694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 344}], {
             RGBColor[
             0.49972685632516956`, 0.6047398002599247, 0.9537594751711596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 403}], {
             RGBColor[
             0.73231135392298, 0.7900531713799142, 0.9748369526254256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 449}], {
             RGBColor[
             0.6320067542390264, 0.7108140314884382, 0.9650731650607731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 119}], {
             RGBColor[
             0.9345308133147854, 0.7655949021985857, 0.5124594755699873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 159}], {
             RGBColor[
             0.8495822086293704, 0.3506448894924134, 0.19388094901806585`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 164}], {
             RGBColor[
             0.8479694807729221, 0.33824875648589925`, 0.19233659900141542`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 227}], {
             RGBColor[
             0.8620227096886874, 0.44626803209664856`, 0.20579398688200412`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 267}], {
             RGBColor[
             0.9337384293685642, 0.7577785430140971, 0.3161344657047144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 270}], {
             RGBColor[
             0.9342186701882929, 0.7654658229940685, 0.5176324949764846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 309}], {
             RGBColor[
             0.9357225086078202, 0.7641455885442991, 0.35153908493080155`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 443}], {
             RGBColor[
             0.9064631162110222, 0.6594290978497701, 0.24321160823769428`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 489}], {
             RGBColor[
             0.9342559232885688, 0.7654812281083937, 0.517015114696979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 234}], {
             RGBColor[
             0.4661658558479902, 0.5757356428509766, 0.951603122647781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 269}], {
             RGBColor[
             0.4963462045644428, 0.6018763440007352, 0.9535261877805588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 332}], {
             RGBColor[
             0.47297256082386624`, 0.5816312685861409, 0.9520368398699108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 360}], {
             RGBColor[
             0.5615596954334325, 0.6549384845856707, 0.9586271827669148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 393}], {
             RGBColor[
             0.5024822764946291, 0.606976774483756, 0.9539763919403361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 468}], {
             RGBColor[
             0.51106504599871, 0.6139446534165288, 0.9546520589954179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 54}], {
             RGBColor[
             0.23354661261843296`, 0.36280267594543125`, 0.936611506136144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 67}], {
             RGBColor[
             0.24749774961125026`, 0.377466205478057, 0.9374060027490273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 70}], {
             RGBColor[
             0.24831129577393707`, 0.37832129407684667`, 0.9374523329994586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 84}], {
             RGBColor[
             0.2358433607180927, 0.36521670382041393`, 0.9367423025426853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 131}], {
             RGBColor[
             0.2509907389862678, 0.38113755877951816`, 0.9376049233265198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 135}], {
             RGBColor[
             0.24449959825218992`, 0.3743149583059091, 0.9372352624644963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 147}], {
             RGBColor[
             0.2449327987863818, 0.374770279533845, 0.9372599325940558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 171}], {
             RGBColor[
             0.25005732664065045`, 0.38015648322251344`, 0.9375517668742968]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 216}], {
             RGBColor[
             0.25212920477180323`, 0.3823341585030158, 0.9376697572687969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 281}], {
             RGBColor[
             0.2416405448941051, 0.37130991195210916`, 0.9370724436053437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 385}], {
             RGBColor[
             0.235922007593164, 0.36529936667261376`, 0.936746781365873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 391}], {
             RGBColor[
             0.23974982774210207`, 0.3693226483469626, 0.9369647700606025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 37}], {
             RGBColor[
             0.2800147441029785, 0.41164362838539204`, 0.9392577974807488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 58}], {
             RGBColor[
             0.28475051663686596`, 0.4160326690739975, 0.9395490426575464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 141}], {
             RGBColor[
             0.28198608489330845`, 0.4136382572421074, 0.9393728955113378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 240}], {
             RGBColor[
             0.25550742159800177`, 0.3858848785786683, 0.9378621417194251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 251}], {
             RGBColor[
             0.25646724614478844`, 0.3868937150337323, 0.9379168023074314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 310}], {
             RGBColor[
             0.2755731801551128, 0.4069752630647657, 0.9390048569846228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 352}], {
             RGBColor[
             0.2411100918235177, 0.37075237214225454`, 0.9370422350877088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 367}], {
             RGBColor[
             0.2421171751521342, 0.3718108805734015, 0.9370995869934273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 382}], {
             RGBColor[
             0.26830699274776615`, 0.39933803939675394`, 0.9385910583611354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 399}], {
             RGBColor[
             0.24794512185068096`, 0.37793642206673694`, 0.937431479936235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 412}], {
             RGBColor[
             0.24838538806776134`, 0.3783991697753788, 0.9374565524459821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 416}], {
             RGBColor[
             0.2579614870777197, 0.3884642569945902, 0.9380018971180304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 429}], {
             RGBColor[
             0.2739936283843697, 0.4053150540043482, 0.9389149038480165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 58}], {
             RGBColor[
             0.31037597127891847`, 0.44296664665046, 0.9410083743899482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 118}], {
             RGBColor[
             0.31537415178862416`, 0.44729581939211016`, 0.9413268540323092]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 141}], {
             RGBColor[
             0.3076115395353609, 0.4405722348185699, 0.9408322272437397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 188}], {
             RGBColor[
             0.3214586719550145, 0.4525659249433619, 0.9417145542769817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 240}], {
             RGBColor[
             0.28113287624005423`, 0.4128188561551308, 0.9393214734518269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 304}], {
             RGBColor[
             0.32210212279026273`, 0.45312324971607465`, 0.9417555543952225]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 310}], {
             RGBColor[
             0.30119863479716524`, 0.4339092406412282, 0.9404641887170249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 429}], {
             RGBColor[
             0.29961908302642226`, 0.4322490315808106, 0.9403742355804184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 47}], {
             RGBColor[
             0.24595116399713765`, 0.375840645938433, 0.9373179269862719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 73}], {
             RGBColor[
             0.25393957190424143`, 0.3842369691431141, 0.937772854998791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 93}], {
             RGBColor[
             0.2646269773927557, 0.3954701099321881, 0.9383814869307624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 108}], {
             RGBColor[
             0.272539685244709, 0.40378686757924537`, 0.9388321039371288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 163}], {
             RGBColor[
             0.2634804930859057, 0.3942650822343853, 0.9383161963455589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 189}], {
             RGBColor[
             0.2598720197723208, 0.3904723479913851, 0.9381106991286081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 266}], {
             RGBColor[
             0.27474470932625494`, 0.40610448769555174`, 0.9389576767965321]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 364}], {
             RGBColor[
             0.2592676752099878, 0.3898371435387148, 0.9380762825998308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 437}], {
             RGBColor[
             0.2578995688543769, 0.3883991770160148, 0.9379983709668107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 45}], {
             RGBColor[
             0.45322202962692537`, 0.5599541419213354, 0.9514657433370749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 100}], {
             RGBColor[
             0.7774382200691679, 0.7351762203070193, 0.6135140654406412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 127}], {
             RGBColor[
             0.4248206994263658, 0.5301025431322064, 0.9498483295981558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 179}], {
             RGBColor[
             0.40129536230508595`, 0.5053759222252174, 0.9485085964517164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 200}], {
             RGBColor[
             0.7622447974505207, 0.6739602832535388, 0.6012384342096092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 213}], {
             RGBColor[
             0.7639337426080279, 0.681629388750616, 0.6026477314488674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 236}], {
             RGBColor[
             0.4554923722273556, 0.5623404159424226, 0.9515950359894985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 243}], {
             RGBColor[
             0.7314838484501698, 0.504242577778165, 0.5743944759737214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 254}], {
             RGBColor[
             0.43007991849913185`, 0.5356303158314321, 0.9501478343440324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 276}], {
             RGBColor[
             0.6216008719460259, 0.7036826165027719, 0.9633538441200625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 283}], {
             RGBColor[
             0.4024378733893724, 0.5065767738141891, 0.9485736607677728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 315}], {
             RGBColor[
             0.40458060190845924`, 0.5088289173445842, 0.948695685987052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 325}], {
             RGBColor[
             0.40133925395865816`, 0.5054220551360133, 0.9485110960164554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 368}], {
             RGBColor[
             0.5158816187650146, 0.6166272342584453, 0.9553704626805029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 401}], {
             RGBColor[
             0.6985569826136641, 0.7641508706261513, 0.9707851169753527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 450}], {
             RGBColor[
             0.7206850354992045, 0.4212381693670362, 0.5640535204963621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 454}], {
             RGBColor[
             0.761772006870989, 0.6718134516549312, 0.6008439261608904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 471}], {
             RGBColor[
             0.7402370852900231, 0.5715237918221177, 0.5827765854569318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 475}], {
             RGBColor[
             0.731332489294519, 0.5030791649818271, 0.5742495342753344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 114}], {
             RGBColor[
             0.443439320562669, 0.5572206362112937, 0.9498318505944043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 199}], {
             RGBColor[
             0.3645220176644419, 0.4901523831167798, 0.9444479985247825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 208}], {
             RGBColor[
             0.3541593410951509, 0.4811767535157284, 0.9437876979371422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 220}], {
             RGBColor[
             0.36255668140028763`, 0.48845010762544216`, 0.9443227690359091]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 289}], {
             RGBColor[
             0.41278560473143366`, 0.5319558764357888, 0.9475233116148768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 291}], {
             RGBColor[
             0.5205636488996574, 0.6196411124817705, 0.9560349926032045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 297}], {
             RGBColor[
             0.4527821832454718, 0.5648055930283604, 0.9505673549688282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 314}], {
             RGBColor[
             0.35813781501059505`, 0.484622707657373, 0.944041202777008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 349}], {
             RGBColor[
             0.3999008136180363, 0.5207957179817955, 0.9467023041187045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 359}], {
             RGBColor[
             0.38582570994179444`, 0.508604570612715, 0.9458054509585798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 371}], {
             RGBColor[
             0.37457203795785354`, 0.49885720556622565`, 0.9450883769309946]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 397}], {
             RGBColor[
             0.37237410523066483`, 0.4969534667092458, 0.9449483266011737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 419}], {
             RGBColor[
             0.44944534633244004`, 0.5620965984995714, 0.950304666943798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 472}], {
             RGBColor[
             0.35732343693452717`, 0.4839173342997152, 0.9439893113261273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 102}], {
             RGBColor[
             0.2545321161274702, 0.38485977069120125`, 0.9378065995157133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 186}], {
             RGBColor[
             0.23411854278577374`, 0.36340381081377343`, 0.9366440767130793]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 191}], {
             RGBColor[
             0.22546402831064583`, 0.35430736737250323`, 0.9361512149169275]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 202}], {
             RGBColor[
             0.2357918679274276, 0.3651625816325934, 0.9367393701044336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 212}], {
             RGBColor[
             0.22552146354030395`, 0.35436773544047784`, 0.9361544857682886]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 295}], {
             RGBColor[
             0.23105727915165333`, 0.3601862286389881, 0.9364697422778497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 300}], {
             RGBColor[
             0.22924216126039493`, 0.3582784246501542, 0.9363663739991688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 389}], {
             RGBColor[
             0.2255132290582107, 0.3543590804777015, 0.9361540168267153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 451}], {
             RGBColor[
             0.22198624668627384`, 0.3506519983811976, 0.9359531603983363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 456}], {
             RGBColor[
             0.22809260204387605`, 0.3570701650273288, 0.9363009083024085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 485}], {
             RGBColor[
             0.24026393309017596`, 0.36986300566395003`, 0.9369940475996247]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 85}], {
             RGBColor[
             0.22334491181980198`, 0.3520800415808806, 0.9360305343677259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 95}], {
             RGBColor[
             0.2297785943922997, 0.3588422498836111, 0.9363969230724491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[
             0.23210438822814727`, 0.3612868066689332, 0.936529373590697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 137}], {
             RGBColor[
             0.22627740530250587`, 0.35516227816202806`, 0.9361975355333305]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 145}], {
             RGBColor[
             0.22656621784669417`, 0.3554658384577429, 0.9362139829804621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 174}], {
             RGBColor[
             0.2495656884148965, 0.3796397402755821, 0.9375237688046536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 248}], {
             RGBColor[
             0.2375069627028864, 0.3669652549848901, 0.9368370422146407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 286}], {
             RGBColor[
             0.2277872668823118, 0.3567492384131574, 0.9362835199166604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 294}], {
             RGBColor[
             0.23539350574473433`, 0.36474387772096156`, 0.9367166839674533]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 346}], {
             RGBColor[
             0.22517846281523107`, 0.3540072199309242, 0.9361349523844199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 358}], {
             RGBColor[
             0.22905024080537584`, 0.3580767040834695, 0.9363554444131764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 407}], {
             RGBColor[
             0.22341630550160935`, 0.352155080867081, 0.9360346001322872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 411}], {
             RGBColor[
             0.23603211668449622`, 0.3654150983089235, 0.9367530519157325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 430}], {
             RGBColor[
             0.2361066473396595, 0.36549343475301654`, 0.9367572963262859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 110}], {
             RGBColor[
             0.2824315567297242, 0.4141838516908727, 0.9393954313844881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 217}], {
             RGBColor[
             0.30643378623989703`, 0.43839711764350564`, 0.9407994722898634]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 290}], {
             RGBColor[
             0.2898165263474991, 0.4219459229932718, 0.9398159944791369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 316}], {
             RGBColor[
             0.2718214258604257, 0.4030319314260883, 0.9387912001277635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 340}], {
             RGBColor[
             0.31529118717805316`, 0.446068953150221, 0.9413638580453506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 355}], {
             RGBColor[
             0.3109273076150301, 0.4422891800076947, 0.941085795498422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 362}], {
             RGBColor[
             0.34080467652755875`, 0.4681674552795022, 0.9429895550260083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 378}], {
             RGBColor[
             0.2881161193118442, 0.42015868738676554`, 0.939719158813983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 384}], {
             RGBColor[
             0.28848430619933074`, 0.4205456751499109, 0.9397401265125418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 57}], {
             RGBColor[
             0.5489601186307986, 0.6447095805328258, 0.9576352979272409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 106}], {
             RGBColor[
             0.5072662938524296, 0.6108606552923443, 0.9543530073111751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 117}], {
             RGBColor[
             0.4388762614701655, 0.5533769866678013, 0.9495110781480034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 139}], {
             RGBColor[
             0.5303562146824653, 0.6296060932112468, 0.9561707304600824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 140}], {
             RGBColor[
             0.4981556569200065, 0.6034642298010868, 0.9536357845984921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 247}], {
             RGBColor[
             0.4958443155073958, 0.6015877787175854, 0.9534538273357688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 255}], {
             RGBColor[
             0.44713138767076954`, 0.5605271620680575, 0.9500370874897843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 269}], {
             RGBColor[
             0.4728082951441619, 0.5827672087626157, 0.9516731973287911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 360}], {
             RGBColor[
             0.5380217860131518, 0.6358293493475512, 0.9567741923151472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 369}], {
             RGBColor[
             0.4583123366675063, 0.5702115381181944, 0.9507495276729314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 370}], {
             RGBColor[
             0.5440602935407461, 0.6407316817901163, 0.9572495657475013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 425}], {
             RGBColor[
             0.43601004951768985`, 0.5508944179345684, 0.9493284456568833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 466}], {
             RGBColor[
             0.5000927113166715, 0.6050368178236056, 0.9537882766162615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 468}], {
             RGBColor[
             0.48752713657842917`, 0.5948355181784093, 0.9527990685436503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 52}], {
             RGBColor[
             0.5592887582023336, 0.3453473306953461, 0.5606630483713451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 56}], {
             RGBColor[
             0.5597280401148761, 0.3487238439697099, 0.5610837052268939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 179}], {
             RGBColor[
             0.2308558043838454, 0.3599744658837838, 0.9364582685878783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 236}], {
             RGBColor[
             0.285052814306115, 0.4169389596009889, 0.9395447081256605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 243}], {
             RGBColor[
             0.5610442905289292, 0.35884112143673136`, 0.5623441481098833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 254}], {
             RGBColor[
             0.25964036057789125`, 0.3902288594899984, 0.9380975064801944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 276}], {
             RGBColor[
             0.4511613140247853, 0.5582811601613382, 0.9513035162562244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 283}], {
             RGBColor[
             0.23199831546813182`, 0.3611753174727555, 0.9365233329039347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 292}], {
             RGBColor[
             0.23087655194201073`, 0.35999627288288677`, 0.9364594501306225]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 386}], {
             RGBColor[
             0.23085473585284239`, 0.35997334278995086`, 0.9364582077366184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 422}], {
             RGBColor[
             0.2583972380161019, 0.3889222588590351, 0.9380267124893356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 53}], {
             RGBColor[
             0.9470835767696775, 0.821834287485996, 0.3079282681448157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 68}], {
             RGBColor[
             0.8688206529626022, 0.4329330984324026, 0.20968686128144703`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 90}], {
             RGBColor[
             0.8912123121580973, 0.5950344530170778, 0.2307371435474895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 205}], {
             RGBColor[
             0.9557407049755898, 0.8502199530826348, 0.4110195083871594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 257}], {
             RGBColor[
             0.8882541401217813, 0.5816020846987996, 0.22826877228895565`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 272}], {
             RGBColor[
             0.8691188894851287, 0.4352254750326188, 0.20997245291222838`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 293}], {
             RGBColor[
             0.9359635798708703, 0.8383264425596675, 0.6074452935938994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 298}], {
             RGBColor[
             0.9096473304128414, 0.8178215341712867, 0.6215408826637097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 306}], {
             RGBColor[
             0.8876171805650555, 0.5774114462757728, 0.22768643734119767`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 317}], {
             RGBColor[
             0.9005275853462438, 0.6373329329271229, 0.23851003583391922`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 357}], {
             RGBColor[
             0.9123985653292456, 0.6903965335177349, 0.2483720332752017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 418}], {
             RGBColor[
             0.9480641688610301, 0.8473510420156326, 0.586962152772621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 420}], {
             RGBColor[
             0.9431488383406506, 0.8436851965616485, 0.5952825252201055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 55}], {
             RGBColor[
             0.22170565849658444`, 0.35035708240351526`, 0.9359371813160265]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 189}], {
             RGBColor[
             0.24585450838109163`, 0.3757390547576487, 0.9373124225919274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 230}], {
             RGBColor[
             0.22790583767600858`, 0.3568738638351552, 0.9362902723479516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 242}], {
             RGBColor[
             0.2284706396727983, 0.35746750654429615`, 0.9363224369861192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 339}], {
             RGBColor[
             0.22181216919966315`, 0.3504690319056196, 0.9359432469429985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 364}], {
             RGBColor[
             0.24525016381875867`, 0.3751038503049783, 0.93727800606315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 365}], {
             RGBColor[
             0.22445415871552787`, 0.3532459303986038, 0.9360937043374536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 374}], {
             RGBColor[
             0.24183198733731956`, 0.37151113009807946`, 0.9370833459692711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 437}], {
             RGBColor[
             0.2438820574631478, 0.37366588378227833`, 0.93720009443013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 78}], {
             RGBColor[
             0.21346998781254425`, 0.3417008703429085, 0.9354681720541533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 85}], {
             RGBColor[
             0.21086321568284044`, 0.3389609875556907, 0.9353197202377406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 95}], {
             RGBColor[
             0.21729689825533816`, 0.34572319585842115`, 0.9356861089424638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 137}], {
             RGBColor[
             0.21379570916554433`, 0.34204322413683813`, 0.9354867214033452]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 145}], {
             RGBColor[
             0.21408452170973263`, 0.34234678443255295`, 0.9355031688504769]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 183}], {
             RGBColor[
             0.20623910902756293`, 0.3341007582756985, 0.9350563842044752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 346}], {
             RGBColor[
             0.21269676667826953`, 0.34088816590573434`, 0.9354241382544346]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 358}], {
             RGBColor[
             0.2165685446684143, 0.3449576500582796, 0.9356446302831911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 404}], {
             RGBColor[
             0.21047959213928613`, 0.3385577748882776, 0.9352978734444553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 407}], {
             RGBColor[
             0.2109346093646478, 0.33903602684189116`, 0.935323786002302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 408}], {
             RGBColor[
             0.21500770505426564`, 0.34331710866086196`, 0.9355557427762207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 71}], {
             RGBColor[
             0.6229981269292593, 0.7030794824142605, 0.9646517716159538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 76}], {
             RGBColor[
             0.45077000854144356`, 0.5638542255344485, 0.9502204534950804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 238}], {
             RGBColor[
             0.4051843179606758, 0.5243701915568157, 0.9473157736011174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 328}], {
             RGBColor[
             0.4377638604952656, 0.5525889538048573, 0.9493917132424632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 402}], {
             RGBColor[
             0.521262974366249, 0.6222237910767345, 0.9554548772727531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 431}], {
             RGBColor[
             0.4693773227785792, 0.5799709458958486, 0.9514060951044689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 436}], {
             RGBColor[
             0.4815672646188717, 0.5899970256324685, 0.9523298855912635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 459}], {
             RGBColor[
             0.44038041665413563`, 0.554855283237734, 0.9495584378871766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 462}], {
             RGBColor[
             0.4770465403942916, 0.586326898050649, 0.9519739976203461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 487}], {
             RGBColor[
             0.5348230464505574, 0.633232468469062, 0.9565223758194106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 57}], {
             RGBColor[
             0.5210905073010532, 0.6217476292469348, 0.9555341779806428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 92}], {
             RGBColor[
             0.5250378077135244, 0.6249522255456361, 0.9558449239285502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 106}], {
             RGBColor[
             0.47939668252268425`, 0.5878987040064534, 0.9522518873645769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 117}], {
             RGBColor[
             0.41100665014042015`, 0.5304150353819104, 0.9474099582014052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 139}], {
             RGBColor[
             0.50248660335272, 0.6066441419253559, 0.9540696105134843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 140}], {
             RGBColor[
             0.47028604559026116`, 0.5805022785151959, 0.9515346646518938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 169}], {
             RGBColor[
             0.46684010556596744`, 0.5777047091656451, 0.9512633876302873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 204}], {
             RGBColor[
             0.47141553909134676`, 0.5814192522224795, 0.9516235825177704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 219}], {
             RGBColor[
             0.48360346312109975`, 0.5913139580095534, 0.9525830605432293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 244}], {
             RGBColor[
             0.3916895278498226, 0.5136835149605915, 0.9461790882505088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 255}], {
             RGBColor[
             0.41926177634102413`, 0.5375652107821666, 0.9479359675431862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 274}], {
             RGBColor[
             0.4518361438965558, 0.5655238171616463, 0.9500822208063486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 334}], {
             RGBColor[
             0.42187105269828507`, 0.539825234816783, 0.9481022283253784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 338}], {
             RGBColor[
             0.3805216773222415, 0.5040104841460892, 0.9454674826902338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 340}], {
             RGBColor[
             0.3891862943583425, 0.5115153399264449, 0.9460195844259542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 361}], {
             RGBColor[
             0.5425697371949871, 0.6391572117563517, 0.9572443985054486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 363}], {
             RGBColor[
             0.422874692158388, 0.5406945368727382, 0.9481661793442926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 369}], {
             RGBColor[
             0.43044272533776096`, 0.5472495868323034, 0.9486484077263333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 370}], {
             RGBColor[
             0.5161906822110007, 0.6177697305042253, 0.9551484458009031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 379}], {
             RGBColor[
             0.37511861305326666`, 0.49933062144220947`, 0.9451232042127569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[
             0.18179934664985797`, 0.3084130184462969, 0.9336645758924533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 113}], {
             RGBColor[
             0.17905963075308248`, 0.3055334033307651, 0.9335085531251784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 127}], {
             RGBColor[
             0.20245340605759676`, 0.3301217444268325, 0.9348407940207814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 130}], {
             RGBColor[
             0.1789270004053139, 0.3053940004260106, 0.9335010000230821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 143}], {
             RGBColor[
             0.17892700107920537`, 0.30539400113431325`, 0.9335010000614592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 179}], {
             RGBColor[
             0.1789280689363169, 0.30539512351984355`, 0.9335010608743419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 214}], {
             RGBColor[
             0.1893670578318586, 0.31636716271918164`, 0.9340955458488429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 302}], {
             RGBColor[
             0.18453817957609825`, 0.31129170550381263`, 0.9338205483758626]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 308}], {
             RGBColor[
             0.1789366427891193, 0.3054041351827525, 0.9335015491425751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 315}], {
             RGBColor[
             0.1822133085396902, 0.30884811863921036`, 0.9336881504096776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 325}], {
             RGBColor[
             0.17897196058988912`, 0.30544125643063946`, 0.933503560439081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 347}], {
             RGBColor[
             0.1789270004053139, 0.3053940004260106, 0.9335010000230821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 386}], {
             RGBColor[
             0.1789270004053139, 0.3053940004260106, 0.9335010000230821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 421}], {
             RGBColor[
             0.17899180329589925`, 0.30546211237275633`, 0.9335046904518336]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 423}], {
             RGBColor[
             0.18337644614132015`, 0.31007065000570677`, 0.9337543893753826]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 477}], {
             RGBColor[
             0.21179931412463662`, 0.3399448863700877, 0.9353730296591674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 56}], {
             RGBColor[
             0.836234326611525, 0.27951848908515425`, 0.18233133812500216`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 88}], {
             RGBColor[
             0.8512025856554928, 0.3816657696999445, 0.19615962002028325`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 166}], {
             RGBColor[
             0.8369577282992072, 0.2850788714533209, 0.18302406839809204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 210}], {
             RGBColor[
             0.8359293793650189, 0.2771745309197725, 0.1820393202973592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 227}], {
             RGBColor[
             0.8407131059122084, 0.31394434940381033`, 0.18662022224139424`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 236}], {
             RGBColor[
             0.5615591008027638, 0.3477336047164332, 0.5607923410237687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 243}], {
             RGBColor[
             0.837550577025578, 0.2896357665521757, 0.18359178100799164`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 276}], {
             RGBColor[
             0.7276676005214341, 0.4890758052767825, 0.5725511491543327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 326}], {
             RGBColor[
             0.8554852780065134, 0.4011124754177182, 0.19973320349637064`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 428}], {
             RGBColor[
             0.8330642703587228, 0.25515204759860854`, 0.17929568867725226`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 469}], {
             RGBColor[
             0.8481128613393234, 0.36763605320366755`, 0.19358147831479822`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 495}], {
             RGBColor[
             0.8389987580384334, 0.3007671204139477, 0.18497856078138836`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 90}], {
             RGBColor[
             0.9206410418975434, 0.7056328015929743, 0.28606405077970154`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 178}], {
             RGBColor[
             0.9840984713626098, 0.9616310168446078, 0.5753629014776818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 257}], {
             RGBColor[
             0.9176828698612274, 0.692200433274696, 0.28359567952116765`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 272}], {
             RGBColor[
             0.8985476192245749, 0.5458238236085153, 0.2652993601444404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[
             0.9653923096103165, 0.9489247911355639, 0.6627722008261114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 298}], {
             RGBColor[
             0.9390760601522875, 0.9284198827471832, 0.6768677898959217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 306}], {
             RGBColor[
             0.9170459103045016, 0.6880097948516692, 0.28301334457340965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 317}], {
             RGBColor[
             0.9299563150856899, 0.7479312815030192, 0.29383694306613123`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 357}], {
             RGBColor[
             0.9418272950686917, 0.8009948820936315, 0.3036989405074137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 418}], {
             RGBColor[
             0.9774928986004763, 0.9579493905915291, 0.642289060004833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 420}], {
             RGBColor[
             0.9725775680800968, 0.9542835451375451, 0.6506094324523175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 432}], {
             RGBColor[
             0.9375683877182548, 0.9272177056729635, 0.6767239867532486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 55}], {
             RGBColor[
             0.22009923076516985`, 0.34866862500439766`, 0.9358456976332195]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 70}], {
             RGBColor[
             0.24348548029858347`, 0.3732490560378767, 0.9371775099472914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 84}], {
             RGBColor[
             0.23101754524273913`, 0.3601444657814439, 0.9364674794905181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 131}], {
             RGBColor[
             0.24616492351091418`, 0.3760653207405481, 0.9373301002743527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 135}], {
             RGBColor[
             0.23967378277683635`, 0.36924272026693905`, 0.9369604394123292]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 147}], {
             RGBColor[
             0.2401069833110282, 0.36969804149487495`, 0.9369851095418886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 230}], {
             RGBColor[
             0.22629940994459397`, 0.3551854064360376, 0.9361987886651444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 242}], {
             RGBColor[
             0.22686421194138368`, 0.35577904914517844`, 0.936230953303312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 365}], {
             RGBColor[
             0.22284773098411328`, 0.35155747299948614`, 0.9360022206546466]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 374}], {
             RGBColor[
             0.24022555960590497`, 0.3698226726989618, 0.9369918622864639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 385}], {
             RGBColor[
             0.23109619211781043`, 0.36022712863364376`, 0.9364719583137058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 391}], {
             RGBColor[
             0.23492401226674847`, 0.36425041030799266`, 0.9366899470084354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 230}], {
             RGBColor[
             0.21767784356668446`, 0.34612359353397393`, 0.935707803214387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 242}], {
             RGBColor[
             0.21824264556347417`, 0.34671723624311485`, 0.9357399678525544]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 250}], {
             RGBColor[
             0.20796149957955015`, 0.33591109995170554`, 0.9351544717983624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 339}], {
             RGBColor[
             0.21158417509033906`, 0.33971876160443837`, 0.9353607778094337]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 365}], {
             RGBColor[
             0.21422616460620378`, 0.3424956600974225, 0.935511235203889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 88}], {
             RGBColor[
             0.8516418675680354, 0.38504228297430826`, 0.19658027687583196`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 164}], {
             RGBColor[
             0.8270991589089857, 0.20930158706742483`, 0.17358349121635427`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 166}], {
             RGBColor[
             0.8373970102117498, 0.28845538472768467`, 0.18344472525364075`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 210}], {
             RGBColor[
             0.8363686612775614, 0.28055104419413623`, 0.18245997715290796`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 227}], {
             RGBColor[
             0.8411523878247509, 0.31732086267817405`, 0.187040879096943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 236}], {
             RGBColor[
             0.5619983827153064, 0.35111011799079705`, 0.5612129978793174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 243}], {
             RGBColor[
             0.8379898589381207, 0.2930122798265395, 0.18401243786354038`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 276}], {
             RGBColor[
             0.7281068824339767, 0.4924523185511463, 0.5729718060098814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 326}], {
             RGBColor[
             0.8559245599190561, 0.404488988692082, 0.2001538603519194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 428}], {
             RGBColor[
             0.8335035522712653, 0.25852856087297227`, 0.179716345532801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 495}], {
             RGBColor[
             0.839438039950976, 0.30414363368831143`, 0.18539921763693712`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 92}], {
             RGBColor[
             0.6051902881840892, 0.690359765316458, 0.9620619428523739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 106}], {
             RGBColor[
             0.5595491629932491, 0.6533062437772754, 0.9584689062884005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 139}], {
             RGBColor[
             0.5826390838232848, 0.6720516816961779, 0.9602866294373078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 140}], {
             RGBColor[
             0.550438526060826, 0.6459098182860178, 0.9577516835757175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 169}], {
             RGBColor[
             0.5469925860365322, 0.6431122489364671, 0.9574804065541109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 175}], {
             RGBColor[
             0.7784866261079177, 0.8268297266210345, 0.9607862455954495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 204}], {
             RGBColor[
             0.5515680195619116, 0.6468267919933015, 0.9578406014415939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 219}], {
             RGBColor[
             0.5637559435916646, 0.6567214977803754, 0.9588000794670529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 255}], {
             RGBColor[
             0.499414256811589, 0.6029727505529885, 0.9541529864670097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 274}], {
             RGBColor[
             0.5319886243671207, 0.6309313569324684, 0.9562992397301722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 334}], {
             RGBColor[
             0.5020235331688498, 0.6052327745876049, 0.9543192472492019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 337}], {
             RGBColor[
             0.730726843956438, 0.7892639238928545, 0.9741400277373693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 361}], {
             RGBColor[
             0.622722217665552, 0.7045647515271736, 0.9634614174292722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 363}], {
             RGBColor[
             0.5030271726289528, 0.6061020766435601, 0.9543831982681161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 369}], {
             RGBColor[
             0.5105952058083258, 0.6126571266031253, 0.9548654266501568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 370}], {
             RGBColor[
             0.5963431626815656, 0.6831772702750474, 0.9613654647247267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 466}], {
             RGBColor[
             0.552375580457491, 0.6474824063085367, 0.957904175593487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 118}], {
             RGBColor[
             0.3201099243225116, 0.4516848600807156, 0.9416180992091068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 141}], {
             RGBColor[
             0.3123473120692484, 0.44496127550717535`, 0.9411234724205373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 188}], {
             RGBColor[
             0.32619444448890195`, 0.45695496563196736`, 0.9420057994537792]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 220}], {
             RGBColor[
             0.32701247471585293`, 0.45766350229915764`, 0.9420579236164848]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 240}], {
             RGBColor[
             0.2858686487739417, 0.41720789684373627`, 0.9396127186286245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 304}], {
             RGBColor[
             0.3268378953241502, 0.4575122904046801, 0.94204679957202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 310}], {
             RGBColor[
             0.3059344073310527, 0.43829828132983367`, 0.9407554338938223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 371}], {
             RGBColor[
             0.3390278312734188, 0.4680706002399412, 0.9428235315115703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 382}], {
             RGBColor[
             0.2986682199237062, 0.43066105766182183`, 0.9403416352703349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 429}], {
             RGBColor[
             0.3043548555603097, 0.4366380722694161, 0.9406654807572159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 74}], {
             RGBColor[
             0.26196255890659237`, 0.3926696371693413, 0.9382297522396293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 82}], {
             RGBColor[
             0.25023486400687867`, 0.3803430862509384, 0.9375618773646605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 105}], {
             RGBColor[
             0.2440481876886619, 0.3738404971825583, 0.9372095553007055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 153}], {
             RGBColor[
             0.24356203444566857`, 0.3733295193002764, 0.9371818695927163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 195}], {
             RGBColor[
             0.2561715150223729, 0.3865828828736374, 0.9378999608575047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 263}], {
             RGBColor[
             0.25779587834217144`, 0.38829019171332857`, 0.9379924659455371]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 323}], {
             RGBColor[
             0.24076788547771533`, 0.3703926915756808, 0.9370227469425643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 342}], {
             RGBColor[
             0.25108912406320616`, 0.3812409677333546, 0.9376105262111039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 395}], {
             RGBColor[
             0.2535893388235434, 0.38386885196924064`, 0.9377529097429688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 447}], {
             RGBColor[
             0.2443455259866942, 0.3741530185861272, 0.9372264882769058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 453}], {
             RGBColor[
             0.26324896867774317`, 0.3940217354019111, 0.9383030113730237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 463}], {
             RGBColor[
             0.2546442329532448, 0.38497761258370766`, 0.9378129844030793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 116}], {
             RGBColor[
             0.27071777339856856`, 0.4018719227130688, 0.9387283487527682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 118}], {
             RGBColor[
             0.30890885152103453`, 0.4405003788871604, 0.9409586647466246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 133}], {
             RGBColor[
             0.31894163191943015`, 0.44919026900604586`, 0.9415979446419711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 151}], {
             RGBColor[
             0.2997519610227203, 0.4323886947798715, 0.9403818027857322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 188}], {
             RGBColor[
             0.31499337168742486`, 0.44577048443841216`, 0.9413463649912971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 192}], {
             RGBColor[
             0.2736621188386635, 0.4049666164528918, 0.9388960248698129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 249}], {
             RGBColor[
             0.29112873348308044`, 0.42332513589150556`, 0.9398907227342717]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 260}], {
             RGBColor[
             0.2891430137819674, 0.4212380185837349, 0.9397776389349024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 280}], {
             RGBColor[
             0.2748009878347767, 0.4061636399762716, 0.9389608817743358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 310}], {
             RGBColor[
             0.2947333345295756, 0.4271138001362785, 0.9400959994313403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 327}], {
             RGBColor[
             0.27488937913222444`, 0.40625654483422113`, 0.9389659155279624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 483}], {
             RGBColor[
             0.29467938491288026`, 0.4270570956685284, 0.9400929270804808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 64}], {
             RGBColor[
             0.3058305702683475, 0.43738338551197825`, 0.9407790232185906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 91}], {
             RGBColor[
             0.32572776888358806`, 0.4565507546784424, 0.9419760632968737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 172}], {
             RGBColor[
             0.3377395733706075, 0.4669547759942509, 0.9427414448571648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 303}], {
             RGBColor[
             0.31454260624684305`, 0.4465402877003618, 0.9412751607792637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 362}], {
             RGBColor[
             0.3561441161626767, 0.48289586592152384`, 0.9439141660493773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 384}], {
             RGBColor[
             0.3038237458344487, 0.43527408579193255`, 0.9406647375359107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 435}], {
             RGBColor[
             0.2909721876561818, 0.42176628331072286`, 0.9399328603098349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 473}], {
             RGBColor[
             0.3253289757704718, 0.4562053401277858, 0.9419506525523447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 132}], {
             RGBColor[
             0.9037259559281465, 0.5621573598635239, 0.4887023579770914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 209}], {
             RGBColor[
             0.6916212861064526, 0.39630413817282756`, 0.5615943615662011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 233}], {
             RGBColor[
             0.8302393984490122, 0.2334388442338099, 0.17659058814627704`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 75}], {
             RGBColor[
             0.38214205273411095`, 0.5054139718854141, 0.9455707315786365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 149}], {
             RGBColor[
             0.3866051837093468, 0.5092797116126782, 0.9458551183377868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 158}], {
             RGBColor[
             0.38842846253649266`, 0.5108589440920934, 0.9459712960523903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 165}], {
             RGBColor[
             0.42168442508772075`, 0.5396635873606885, 0.9480903365790616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 182}], {
             RGBColor[
             0.3989611276124065, 0.5199818091937107, 0.9466424281573576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 206}], {
             RGBColor[
             0.3810348762200533, 0.5044549912372471, 0.9455001832701985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 252}], {
             RGBColor[
             0.5775658026497799, 0.6655789256820774, 0.9611207995905398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 275}], {
             RGBColor[
             0.41651977831287657`, 0.5351902299070133, 0.9477612498534863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 282}], {
             RGBColor[
             0.5134969921724348, 0.6149963149023026, 0.9550984560118821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 324}], {
             RGBColor[
             0.3945065223315428, 0.5161234539943981, 0.9463585846479137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 410}], {
             RGBColor[
             0.39150030357105375`, 0.5135196184010107, 0.9461670310467902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 441}], {
             RGBColor[
             0.4347339982883702, 0.5509664717764713, 0.9489218438441225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 467}], {
             RGBColor[
             0.563087381667329, 0.6542682731705118, 0.9596777258955458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 91}], {
             RGBColor[
             0.3077316474117898, 0.43903000298271255`, 0.9409001581731142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 172}], {
             RGBColor[
             0.31974345189880926`, 0.449434024298521, 0.9416655397334055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 303}], {
             RGBColor[
             0.29654648477504475`, 0.4290195360046319, 0.9401992556555043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 366}], {
             RGBColor[
             0.27642037277284975`, 0.4078657162211217, 0.9390531033508938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 384}], {
             RGBColor[
             0.28582762436265047`, 0.41775333409620263`, 0.9395888324121513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 435}], {
             RGBColor[
             0.2729760661843835, 0.4042455316149929, 0.9388569551860756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 473}], {
             RGBColor[
             0.3073328542986736, 0.43868458843205593`, 0.9408747474285853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 88}], {
             RGBColor[
             0.9260374771709088, 0.7249105779401631, 0.30422129427437533`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 166}], {
             RGBColor[
             0.9117926198146232, 0.6283236796935395, 0.2910857426521841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 167}], {
             RGBColor[
             0.986067541242265, 0.9756937071602725, 0.6343029674871418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 175}], {
             RGBColor[
             0.9705975460870158, 0.9645679382577699, 0.6789276620320353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[
             0.9107642708804349, 0.6204193391599911, 0.29010099455145133`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 227}], {
             RGBColor[
             0.9155479974276244, 0.657189157644029, 0.2946818964954864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 309}], {
             RGBColor[
             0.9892477963467572, 0.9750667140916796, 0.4404269945442838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 320}], {
             RGBColor[
             0.9870336626851595, 0.9760932232050978, 0.618291834936235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 337}], {
             RGBColor[
             0.9228377639355362, 0.92700213552959, 0.6922814441739551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 348}], {
             RGBColor[
             0.9726882187211612, 0.9195330900145834, 0.3483993164391773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 428}], {
             RGBColor[
             0.9078991618741388, 0.5983968558388272, 0.2873573629313444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 434}], {
             RGBColor[
             0.9883337030612244, 0.9766308233101144, 0.5967468015081936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 474}], {
             RGBColor[
             0.989280991001634, 0.9770225512176633, 0.5810477888330006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 495}], {
             RGBColor[
             0.9138336495538494, 0.6440119286541663, 0.2930402350354805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 208}], {
             RGBColor[
             0.2926997987840062, 0.4237400438284219, 0.9400254625551399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 305}], {
             RGBColor[
             0.25719647261268064`, 0.38766017828711546`, 0.9379583306759838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 314}], {
             RGBColor[
             0.29667827269945046`, 0.4271859979700665, 0.9402789673950056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 394}], {
             RGBColor[
             0.24596177604056546`, 0.3758517998689181, 0.937318531326446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 398}], {
             RGBColor[
             0.26221606410223275`, 0.392936087203117, 0.9382441889854937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 427}], {
             RGBColor[
             0.271390600085227, 0.40257910622042264`, 0.9387666652372155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 445}], {
             RGBColor[
             0.24646019520379875`, 0.3763756700110764, 0.9373469155604471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 460}], {
             RGBColor[
             0.2558136629427209, 0.38620675764879087`, 0.9378795817109632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 472}], {
             RGBColor[
             0.29586389462338253`, 0.42648062461240877`, 0.9402270759441249]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 70}], {
             RGBColor[
             0.25743661729140077`, 0.3879125855705024, 0.9379720065601748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 96}], {
             RGBColor[
             0.2763924027630132, 0.4078363179673825, 0.9390515105002115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 131}], {
             RGBColor[
             0.2601160605037315, 0.39072885027317383`, 0.938124596887236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 135}], {
             RGBColor[
             0.2536249197696536, 0.3839062497995648, 0.9377549360252124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 147}], {
             RGBColor[
             0.2540581203038455, 0.3843615710275007, 0.9377796061547718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 171}], {
             RGBColor[
             0.25918264815811415`, 0.38974777471616917`, 0.9380714404350129]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 180}], {
             RGBColor[
             0.26337700695553745`, 0.3941563117499686, 0.9383103029635284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 216}], {
             RGBColor[
             0.26125452628926693`, 0.3919254499966715, 0.938189430829513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 238}], {
             RGBColor[
             0.28838849579729153`, 0.41939023215024707`, 0.9397732894571003]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 281}], {
             RGBColor[
             0.25076586641156884`, 0.38090120344576484`, 0.93759211716606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 343}], {
             RGBColor[
             0.2747552896997584, 0.40611560833893834`, 0.9389582793331509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 385}], {
             RGBColor[
             0.24504732911062774`, 0.37489065816626943`, 0.9372664549265891]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 391}], {
             RGBColor[
             0.24887514925956578`, 0.37891393984061833`, 0.9374844436213188]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 465}], {
             RGBColor[
             0.26962432665641767`, 0.4007226408585406, 0.9386660785784122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 205}], {
             RGBColor[
             0.9069065109079608, 0.5719171126049378, 0.3681050087560027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 257}], {
             RGBColor[
             0.8394199460541523, 0.30329924422110266`, 0.18535427265779897`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 272}], {
             RGBColor[
             0.8202846954174998, 0.15692263455492186`, 0.1670579532810717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 306}], {
             RGBColor[
             0.8387829864974263, 0.2991086057980758, 0.18477193771004097`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 317}], {
             RGBColor[
             0.8516933912786147, 0.35903009244942585`, 0.19559553620276254`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 142}], {
             RGBColor[
             0.8044934065793106, 0.8479188521576653, 0.9809561216743297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 173}], {
             RGBColor[
             0.9470127321552729, 0.9592645667466908, 0.9483609186014075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 194}], {
             RGBColor[
             0.9479892988678673, 0.9596684021789683, 0.9321766809000795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 241}], {
             RGBColor[
             0.8074723242442312, 0.8502460052781141, 0.9812530323476005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 388}], {
             RGBColor[
             0.9278173046721767, 0.9450102776472538, 0.9836136557859578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 402}], {
             RGBColor[
             0.7308868707375382, 0.7890374499881754, 0.9745628249690335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 461}], {
             RGBColor[
             0.926959006974305, 0.9443701606295145, 0.985066529908563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 487}], {
             RGBColor[
             0.7444469428218465, 0.8000461273805028, 0.9756303235156909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 490}], {
             RGBColor[
             0.9500080335378767, 0.9605032008441318, 0.8987210231001681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 84}], {
             RGBColor[
             0.24578222839824324`, 0.37566308391285935`, 0.9373083063538328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 96}], {
             RGBColor[
             0.2772059489257, 0.4086914065661722, 0.9390978407506428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 131}], {
             RGBColor[
             0.2609296066664183, 0.3915839388719636, 0.9381709271376673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 135}], {
             RGBColor[
             0.25443846593234043`, 0.3847613383983545, 0.9378012662756438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 147}], {
             RGBColor[
             0.2548716664665323, 0.3852166596262904, 0.9378259364052033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 170}], {
             RGBColor[
             0.2774653661360603, 0.408964070502262, 0.9391126141769994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 171}], {
             RGBColor[
             0.25999619432080096`, 0.39060286331495886`, 0.9381177706854442]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 216}], {
             RGBColor[
             0.26206807245195374`, 0.39278053859546125`, 0.9382357610799443]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[
             0.28920204195997834`, 0.42024532074903687`, 0.9398196197075317]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 265}], {
             RGBColor[
             0.28963233444531233`, 0.42061801847270397`, 0.9398470375642044]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 374}], {
             RGBColor[
             0.2549902427614091, 0.38534129083037727`, 0.9378326891497786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 385}], {
             RGBColor[
             0.24586087527331454`, 0.37574574676505923`, 0.9373127851770204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 391}], {
             RGBColor[
             0.24968869542225258`, 0.3797690284394081, 0.93753077387175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 433}], {
             RGBColor[
             0.2918782074405654, 0.4225632807803333, 0.9399901426055144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 194}], {
             RGBColor[
             0.8711488139703549, 0.898916809896938, 0.9247098602219754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 228}], {
             RGBColor[
             0.8744314209010298, 0.8983757407693698, 0.7323068273714743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 388}], {
             RGBColor[
             0.8509768197746642, 0.8842586853652235, 0.9761468351078537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 431}], {
             RGBColor[
             0.602160734252356, 0.6860330125252593, 0.9630472221226452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 462}], {
             RGBColor[
             0.6098299518680684, 0.6923889646800596, 0.9636151246385223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 487}], {
             RGBColor[
             0.6676064579243342, 0.7392945350984725, 0.9681635028375868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 490}], {
             RGBColor[
             0.8731675486403643, 0.8997516085621015, 0.891254202422064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 73}], {
             RGBColor[
             0.2509474629421924, 0.38109207291333524`, 0.9376024588198308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 144}], {
             RGBColor[
             0.2501061102631632, 0.3802077579028347, 0.93755454502943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 163}], {
             RGBColor[
             0.26048838412385666`, 0.3911201860046064, 0.9381458001665987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 187}], {
             RGBColor[
             0.2593062768219157, 0.38987771628033463`, 0.9380784809045242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 279}], {
             RGBColor[
             0.26627234056032795`, 0.3971994909433567, 0.9384751879290589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 322}], {
             RGBColor[
             0.25660150329804876`, 0.38703482781420406`, 0.9379244480536938]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 494}], {
             RGBColor[
             0.25624399533436604`, 0.3866590642770594, 0.9379040885040477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 93}], {
             RGBColor[
             0.2585978739086303, 0.3891331399031328, 0.9380381384066008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 163}], {
             RGBColor[
             0.2574513896017804, 0.3879281122053299, 0.9379728478213971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 187}], {
             RGBColor[
             0.25626928229983936`, 0.38668564248105813`, 0.9379055285593227]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 322}], {
             RGBColor[
             0.2535645087759725, 0.3838427540149276, 0.9377514957084923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 494}], {
             RGBColor[
             0.25320700081228975`, 0.383466990477783, 0.9377311361588463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 82}], {
             RGBColor[
             0.27000631808527487`, 0.401124138069925, 0.93868783242518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 105}], {
             RGBColor[
             0.2638196417670582, 0.3946215490015449, 0.938335510361225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 112}], {
             RGBColor[
             0.264998769293781, 0.3958608867931338, 0.938402659929509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 153}], {
             RGBColor[
             0.2633334885240648, 0.39411057111926295`, 0.9383078246532357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 195}], {
             RGBColor[
             0.27594296910076915`, 0.40736393469262394`, 0.9390259159180243]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 224}], {
             RGBColor[
             0.2903501525391211, 0.42250679795452123`, 0.9398463837013205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 234}], {
             RGBColor[
             0.335156328175214, 0.4622198560830736, 0.94266828637108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 239}], {
             RGBColor[
             0.31633226480045645`, 0.4459153985127936, 0.9414688336983061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 263}], {
             RGBColor[
             0.27756733242056764`, 0.40907124353231517`, 0.9391184210060566]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 296}], {
             RGBColor[
             0.2975769167094639, 0.42967045866758025`, 0.9402737595026511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 342}], {
             RGBColor[
             0.27086057814160247`, 0.4020220195523411, 0.9387364812716233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 395}], {
             RGBColor[
             0.2733607929019397, 0.4046499037882272, 0.9388788648034883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 440}], {
             RGBColor[
             0.2817039259800564, 0.4134190656385177, 0.9393539938897277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 447}], {
             RGBColor[
             0.26411698006509043`, 0.39493407040511375`, 0.9383524433374253]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 453}], {
             RGBColor[
             0.2830204227561394, 0.41480278722089764`, 0.9394289664335431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 463}], {
             RGBColor[
             0.2744156870316411, 0.4057586644026942, 0.9389389394635987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 93}], {
             RGBColor[
             0.30711689507265494`, 0.43678253795558514`, 0.940923781155411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 108}], {
             RGBColor[
             0.31502960292460824`, 0.4450992956026424, 0.9413743981617775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 149}], {
             RGBColor[
             0.3494116417234011, 0.4770645349462275, 0.9434851787314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 158}], {
             RGBColor[
             0.3512349205505469, 0.4786437674256428, 0.9436013564460036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.3059704107658049, 0.43557751025778224`, 0.9408584905702073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 182}], {
             RGBColor[
             0.3617675856264607, 0.48776663252726005`, 0.9442724885509708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 206}], {
             RGBColor[
             0.34384133423410757`, 0.4722398145707964, 0.9431302436638118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 410}], {
             RGBColor[
             0.354306761585108, 0.48130444173456, 0.9437970914404035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.3537435180123586, 0.4796530871235497, 0.9438038035415315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[
             0.35693445553108405`, 0.4830069647728541, 0.9439855227126539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 238}], {
             RGBColor[
             0.36573961104663694`, 0.49120700130641426`, 0.9445255824984202]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 333}], {
             RGBColor[
             0.3949872182942583, 0.5165398086768207, 0.9463892141695951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 343}], {
             RGBColor[
             0.3521064049491038, 0.47793237749510553`, 0.9437105723744709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 392}], {
             RGBColor[
             0.35866334703698777`, 0.48482413936361163`, 0.9440839805262493]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 402}], {
             RGBColor[
             0.4818182674522101, 0.589060600826333, 0.952664686170056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 431}], {
             RGBColor[
             0.42993261586454035`, 0.5468077556454473, 0.9486159040017718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 436}], {
             RGBColor[
             0.4421225577048329, 0.5568338353820671, 0.9495396944885663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 459}], {
             RGBColor[
             0.40093570974009674`, 0.5216920929873327, 0.9467682467844796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 462}], {
             RGBColor[
             0.4376018334802528, 0.5531637078002476, 0.949183806517649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 487}], {
             RGBColor[
             0.49537833953651855`, 0.6000692782186605, 0.9537321847167134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 81}], {
             RGBColor[
             0.7152180111578499, 0.7769379420233913, 0.972614350327299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 156}], {
             RGBColor[
             0.5370635204917655, 0.6350513862279201, 0.9566987541430614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 278}], {
             RGBColor[
             0.7775908081460805, 0.8263457284855322, 0.9672404849556133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 329}], {
             RGBColor[
             0.7446878798780471, 0.8004364154026, 0.9754252127138938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 479}], {
             RGBColor[
             0.5091542746403608, 0.6112576931750507, 0.9548154361242309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 482}], {
             RGBColor[
             0.4826496570055525, 0.5883007255405965, 0.9531265853256541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 85}], {
             RGBColor[
             0.21682232686548605`, 0.34522439123812265`, 0.9356590828038773]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 95}], {
             RGBColor[
             0.22325600943798377`, 0.3519865995408531, 0.9360254715086005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 97}], {
             RGBColor[
             0.22558180327383132`, 0.35443115632617517`, 0.9361579220268484]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 137}], {
             RGBColor[
             0.21975482034818994`, 0.34830662781927, 0.9358260839694819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 145}], {
             RGBColor[
             0.22004363289237822`, 0.3486101881149849, 0.9358425314166136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 183}], {
             RGBColor[
             0.21219822021020854`, 0.34036416195813046`, 0.935395746770612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 346}], {
             RGBColor[
             0.21865587786091514`, 0.34715156958816623`, 0.9357635008205714]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 358}], {
             RGBColor[
             0.22252765585105994`, 0.3512210537407115, 0.9359839928493279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 404}], {
             RGBColor[
             0.2164387033219317, 0.3448211785707095, 0.935637236010592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 407}], {
             RGBColor[
             0.21689372054729342`, 0.34529943052432305`, 0.9356631485684387]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 408}], {
             RGBColor[
             0.22096681623691122`, 0.34958051234329385`, 0.9358951053423573]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 430}], {
             RGBColor[
             0.22958406238534357`, 0.3586377844102586, 0.9363858447624374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 81}], {
             RGBColor[
             0.9087234308797807, 0.9257016701540246, 0.7763552620147077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 99}], {
             RGBColor[
             0.9937251243023482, 0.9889870003070016, 0.5583966882336657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 122}], {
             RGBColor[
             0.9306665098261713, 0.7402291937878942, 0.3904132893585251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 267}], {
             RGBColor[
             0.9914456607402118, 0.9819881575780944, 0.49084130836277423`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 278}], {
             RGBColor[
             0.9710962278680113, 0.9751094566161655, 0.770981396643022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 329}], {
             RGBColor[
             0.9381932995999778, 0.9492001435332333, 0.7791661244013025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 406}], {
             RGBColor[
             0.9922235479450122, 0.984612153776488, 0.4938632532617516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 413}], {
             RGBColor[
             0.9838323701759427, 0.9563067408191819, 0.46126511216987476`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 476}], {
             RGBColor[
             0.9211605712027758, 0.6814740968415736, 0.3818708025801312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 486}], {
             RGBColor[
             0.9643781566417168, 0.9700792377693064, 0.7816636594414414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 493}], {
             RGBColor[
             0.9937029879453217, 0.9889396528776512, 0.5559872823811043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 156}], {
             RGBColor[
             0.6284260394446897, 0.7069689251123001, 0.9654326763878454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 278}], {
             RGBColor[
             0.8689533270990046, 0.8982632673699124, 0.9759744072003973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 307}], {
             RGBColor[
             0.6296762406643908, 0.7079838947833768, 0.9655310968074982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 329}], {
             RGBColor[
             0.8360503988309712, 0.8723539542869803, 0.9841591349586778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 372}], {
             RGBColor[
             0.6299979927875134, 0.7082451076516956, 0.9655564263132472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 406}], {
             RGBColor[
             0.8900806471760057, 0.9077659645302347, 0.6988562638191269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 417}], {
             RGBColor[
             0.7452877880838611, 0.8009437515388753, 0.9752469796719869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 461}], {
             RGBColor[
             0.8669992096038857, 0.8968058897416262, 0.9792822184041656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 486}], {
             RGBColor[
             0.8622352558727102, 0.8932330485230531, 0.9866566699988166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 493}], {
             RGBColor[
             0.8915600871763152, 0.912093463631398, 0.7609802929384797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 83}], {
             RGBColor[
             0.8721819244967113, 0.9009182081187621, 0.9876706846361336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 99}], {
             RGBColor[
             0.9086198401868935, 0.9254801001365643, 0.7650800543815806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 237}], {
             RGBColor[
             0.8648552697662895, 0.8950761325134684, 0.9869718617673642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[
             0.906340376624757, 0.9184812574076573, 0.6975246745106891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 278}], {
             RGBColor[
             0.8859909437525565, 0.9116025564457284, 0.9776647627909368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 329}], {
             RGBColor[
             0.8530880154845231, 0.8856932433627962, 0.9858494905492173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 426}], {
             RGBColor[
             0.8468962698264015, 0.8807561134454687, 0.9852589163209091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 486}], {
             RGBColor[
             0.879272872526262, 0.9065723375988691, 0.9883470255893563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 89}], {
             RGBColor[
             0.2718901700216876, 0.4031041858982062, 0.9387951150060494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 105}], {
             RGBColor[
             0.25209194686734443`, 0.382294998083142, 0.9376676354862561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 184}], {
             RGBColor[
             0.2576552479933815, 0.38814238030027126`, 0.9379844572552174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 195}], {
             RGBColor[
             0.2642152742010554, 0.39503738377422104`, 0.9383580410430554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 225}], {
             RGBColor[
             0.2662639580467382, 0.39719068039009175`, 0.9384747105573108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 263}], {
             RGBColor[
             0.26583963752085393`, 0.39674469261391226`, 0.9384505461310877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 296}], {
             RGBColor[
             0.28584922180975014`, 0.4173439077491774, 0.9396058846276822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 342}], {
             RGBColor[
             0.2591328832418887, 0.3896954686339382, 0.9380686063966545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 395}], {
             RGBColor[
             0.26163309800222595`, 0.39232335286982434`, 0.9382109899285194]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 440}], {
             RGBColor[
             0.26997623108034263`, 0.40109251472011487`, 0.9386861190147588]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 447}], {
             RGBColor[
             0.25238928516537673`, 0.3826075194867109, 0.9376845684624564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 453}], {
             RGBColor[
             0.27129272785642566`, 0.40247623630249474`, 0.9387610915585742]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 463}], {
             RGBColor[
             0.26268799213192734`, 0.3934321134842913, 0.9382710645886299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 470}], {
             RGBColor[
             0.25688036525862096`, 0.38732792941563493`, 0.937940328829809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 119}], {
             RGBColor[
             0.9556965383033635, 0.9650210547273206, 0.8984817408494732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 176}], {
             RGBColor[
             0.7638451540938651, 0.8157128228854424, 0.9772513951417543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[
             0.8091856625186589, 0.8516756760168047, 0.981399600787607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 237}], {
             RGBColor[
             0.913419047498675, 0.933799570648643, 0.9916039182408752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 270}], {
             RGBColor[
             0.955384395176871, 0.9648919755228036, 0.9036547602559704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 345}], {
             RGBColor[
             0.7902354483667869, 0.8368716246944006, 0.9795108205407682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 375}], {
             RGBColor[
             0.9394735703012015, 0.9539944639741937, 0.9739704912597569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 426}], {
             RGBColor[
             0.895460047558787, 0.9194795515806435, 0.9898909727944203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 448}], {
             RGBColor[
             0.7443425082604527, 0.7998796964136958, 0.9757160754212024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 489}], {
             RGBColor[
             0.9554216482771469, 0.9649073806371287, 0.9030373799764648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 131}], {
             RGBColor[
             0.24846167161057395`, 0.3784793486155308, 0.9374608966808939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 135}], {
             RGBColor[
             0.24197053087649611`, 0.37165674814192173`, 0.9370912358188704]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 147}], {
             RGBColor[
             0.24240373141068797`, 0.37211206936985763`, 0.93711590594843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 171}], {
             RGBColor[
             0.2475282592649566, 0.3774982730585261, 0.9374077402286709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 230}], {
             RGBColor[
             0.22859615804425376`, 0.3575994343110202, 0.9363295850716857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 242}], {
             RGBColor[
             0.22916096004104347`, 0.3581930770201611, 0.9363617497098533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 365}], {
             RGBColor[
             0.22514447908377305`, 0.3539715008744688, 0.9361330170611878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 374}], {
             RGBColor[
             0.24252230770556474`, 0.3722367005739444, 0.9371226586930053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 385}], {
             RGBColor[
             0.2333929402174702, 0.3626411565086264, 0.9366027547202471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 391}], {
             RGBColor[
             0.23722076036640824`, 0.3666644381829753, 0.9368207434149767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 95}], {
             RGBColor[
             0.22064923730827996`, 0.3492467167536353, 0.9358770196921877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 97}], {
             RGBColor[
             0.22297503114412753`, 0.3516912735389574, 0.9360094702104356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 137}], {
             RGBColor[
             0.21714804821848613`, 0.34556674503205226`, 0.9356776321530691]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 145}], {
             RGBColor[
             0.21743686076267443`, 0.3458703053277671, 0.9356940796002007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 183}], {
             RGBColor[
             0.20959144808050473`, 0.33762427917091264`, 0.9352472949541991]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 286}], {
             RGBColor[
             0.21865790979829205`, 0.3471537052831816, 0.935763616536399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 346}], {
             RGBColor[
             0.21604910573121133`, 0.34441168680094847`, 0.9356150490041585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 358}], {
             RGBColor[
             0.2199208837213561, 0.34848117095349374`, 0.935835541032915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 404}], {
             RGBColor[
             0.21383193119222793`, 0.3420812957834917, 0.9354887841941792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 407}], {
             RGBColor[
             0.2142869484175896, 0.3425595477371053, 0.9355146967520258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 408}], {
             RGBColor[
             0.21836004410720744`, 0.3468406295560761, 0.9357466535259444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 90}], {
             RGBColor[
             0.8899814344584336, 0.5901544331035902, 0.2297467504579272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 98}], {
             RGBColor[
             0.9552139147274563, 0.8468459050338089, 0.4866646892725739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 115}], {
             RGBColor[
             0.9181807358610004, 0.8207272885954675, 0.6214818156174652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 124}], {
             RGBColor[
             0.9389228207101663, 0.7935781606519255, 0.2800166062249653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 136}], {
             RGBColor[
             0.942076876818933, 0.8389236960734718, 0.594023128493258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 168}], {
             RGBColor[
             0.912992655814064, 0.6927519043211215, 0.24885005242438252`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[
             0.9534388639235, 0.8461526483552239, 0.5190456011559075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 253}], {
             RGBColor[
             0.9501124692155603, 0.8447770986590462, 0.5741725699000219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 261}], {
             RGBColor[
             0.897589954080166, 0.6247029436909717, 0.23609548573218275`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 357}], {
             RGBColor[
             0.911167687629582, 0.6855165136042474, 0.2473816401856394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 484}], {
             RGBColor[
             0.9540423951293819, 0.8443401430723285, 0.3591520108030784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 500}], {
             RGBColor[
             0.8673428769617186, 0.42615530998421236`, 0.20846003809980468`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 107}], {
             RGBColor[
             0.1819624771956669, 0.3085844789930161, 0.9336738659357071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 113}], {
             RGBColor[
             0.17922276129889142`, 0.3057048638774843, 0.9335178431684322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 143}], {
             RGBColor[
             0.1790901316250143, 0.30556546168103244`, 0.933510290104713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 226}], {
             RGBColor[
             0.17933912709972993`, 0.30582717171218354`, 0.9335244700286423]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 292}], {
             RGBColor[
             0.1791119470402912, 0.3055883910656657, 0.93351153246034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 308}], {
             RGBColor[
             0.17909977333492821`, 0.3055755957294717, 0.9335108391858289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 386}], {
             RGBColor[
             0.17909013095112286`, 0.3055654609727298, 0.9335102900663359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 421}], {
             RGBColor[
             0.17915493384170816`, 0.30563357291947557`, 0.9335139804950874]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 422}], {
             RGBColor[
             0.2066326331143824, 0.33451437704181397`, 0.9350787948190529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 423}], {
             RGBColor[
             0.18353957668712906`, 0.310242110552426, 0.9337636794186364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 446}], {
             RGBColor[
             0.20370226760912918`, 0.33143437709988877`, 0.934911914838616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 166}], {
             RGBColor[
             0.8523652692557177, 0.3906026653424749, 0.19727300714892185`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 167}], {
             RGBColor[
             0.9266401906833595, 0.7379726928092079, 0.5404902319838795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 210}], {
             RGBColor[
             0.8513369203215293, 0.3826983248089265, 0.19628825904818903`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 227}], {
             RGBColor[
             0.8561206468687188, 0.41946814329296433`, 0.20086916099222407`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 243}], {
             RGBColor[
             0.8529581179820884, 0.3951595604413297, 0.19784071975882145`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 326}], {
             RGBColor[
             0.8708928189630238, 0.5066362693068722, 0.21398214224720047`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 348}], {
             RGBColor[
             0.9132608681622556, 0.6818120756635188, 0.2545865809359151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 428}], {
             RGBColor[
             0.8484718113152332, 0.36067584148776255`, 0.1935446274280821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 434}], {
             RGBColor[
             0.9289063525023188, 0.7389098089590498, 0.5029340660049313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 469}], {
             RGBColor[
             0.8635204022958338, 0.47315984709282155`, 0.20783041706562805`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 474}], {
             RGBColor[
             0.9298536404427284, 0.7393015368665987, 0.48723505332973827`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 495}], {
             RGBColor[
             0.8544062989949438, 0.4062909143031017, 0.1992274995322182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 133}], {
             RGBColor[
             0.3153376912434113, 0.4454022988525135, 0.9413927055520241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 184}], {
             RGBColor[
             0.271266794829508, 0.4024489790469554, 0.9387596147110557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 192}], {
             RGBColor[
             0.27005817816264466`, 0.4011786462993594, 0.9386907857798661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 225}], {
             RGBColor[
             0.2798755048828646, 0.4114972791367759, 0.9392498680131491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 235}], {
             RGBColor[
             0.32127172035398965`, 0.45054205661512126`, 0.9417708166396943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 239}], {
             RGBColor[
             0.31821611673686917`, 0.4478954463410748, 0.9415761162791756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 249}], {
             RGBColor[
             0.28752479280706156`, 0.41953716573797317`, 0.9396854836443249]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 260}], {
             RGBColor[
             0.2855390731059485, 0.4174500484302025, 0.9395723998449554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.2711970471587578, 0.4023756698227392, 0.938755642684389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 296}], {
             RGBColor[
             0.2994607686458766, 0.4316505064958615, 0.9403810420835206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 424}], {
             RGBColor[
             0.3030480744366626, 0.4347576504686087, 0.9406096220363795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 440}], {
             RGBColor[
             0.2835877779164691, 0.415399113466799, 0.9394612764705972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 453}], {
             RGBColor[
             0.28490427469255214`, 0.4167828350491789, 0.9395362490144127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 470}], {
             RGBColor[
             0.27049191209474743`, 0.40163452816231904`, 0.9387154862856475]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 124}], {
             RGBColor[
             0.9137111635376958, 0.6822566946723914, 0.2591427819494134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 178}], {
             RGBColor[
             0.9282272067510295, 0.7348311823756897, 0.4981717768803556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[
             0.8618116052496472, 0.4654005988057779, 0.20640455492384144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 261}], {
             RGBColor[
             0.8723782969076955, 0.5133814777114375, 0.21522166145663085`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 272}], {
             RGBColor[
             0.8426763546129947, 0.3190239891395971, 0.18810823554711417`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 306}], {
             RGBColor[
             0.8611746456929213, 0.4612099603827511, 0.20582221997608346`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 317}], {
             RGBColor[
             0.8740850504741097, 0.5211314470341011, 0.21664581846880504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 357}], {
             RGBColor[
             0.8859560304571115, 0.5741950476247133, 0.2265078159100875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 172}], {
             RGBColor[
             0.33964065051404985`, 0.4686013934649852, 0.9428625798116885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 303}], {
             RGBColor[
             0.3164436833902854, 0.44818690517109605`, 0.9413962957337874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 366}], {
             RGBColor[
             0.29631757138809034`, 0.4270330853875859, 0.9402501434291768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 435}], {
             RGBColor[
             0.29287326479962417`, 0.4234129007814571, 0.9400539952643586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 473}], {
             RGBColor[
             0.32723005291391416`, 0.4578519575985201, 0.9420717875068684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 101}], {
             RGBColor[
             0.5649851581111299, 0.6577194295027604, 0.9588968477367864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 128}], {
             RGBColor[
             0.5519404005403256, 0.6471291076471498, 0.9578699166362912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 140}], {
             RGBColor[
             0.554385826473297, 0.649114414584719, 0.9580624295236251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 169}], {
             RGBColor[
             0.5509398864490034, 0.6463168452351683, 0.9577911525020184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 175}], {
             RGBColor[
             0.7824339265203888, 0.8300343229197356, 0.9610969915433571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 204}], {
             RGBColor[
             0.5555153199743827, 0.6500313882920026, 0.9581513473895016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 219}], {
             RGBColor[
             0.5677032440041356, 0.6599260940790765, 0.9591108254149605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 274}], {
             RGBColor[
             0.5359359247795917, 0.6341359532311694, 0.9566099856780799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 320}], {
             RGBColor[
             0.7988700431185324, 0.8415596078670635, 0.9004611644475569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 334}], {
             RGBColor[
             0.505970833581321, 0.6084373708863062, 0.9546299931971096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 337}], {
             RGBColor[
             0.7346741443689091, 0.7924685201915558, 0.974450773685277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 361}], {
             RGBColor[
             0.6266695180780231, 0.7077693478258749, 0.9637721633771799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 363}], {
             RGBColor[
             0.506974473041424, 0.6093066729422614, 0.9546939442160238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 370}], {
             RGBColor[
             0.6002904630940367, 0.6863818665737486, 0.9616762106726342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 498}], {
             RGBColor[
             0.5355135500520953, 0.6337930503996233, 0.9565767347923217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 108}], {
             RGBColor[
             0.27719798724909794`, 0.408683038339264, 0.9390973873449386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 163}], {
             RGBColor[
             0.26813879509029465`, 0.39916125299440397`, 0.9385814797533685]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 187}], {
             RGBColor[
             0.2669566877883537, 0.3979187832701322, 0.9385141604912941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 189}], {
             RGBColor[
             0.26453032177670965`, 0.3953685187514038, 0.9383759825364177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 206}], {
             RGBColor[
             0.30600971855859727`, 0.43582355730741806`, 0.940853232846973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 266}], {
             RGBColor[
             0.2794030113306438, 0.41100065845557043`, 0.9392229602043418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 322}], {
             RGBColor[
             0.26425191426448674`, 0.3950758948040016, 0.9383601276404636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 364}], {
             RGBColor[
             0.2639259772143767, 0.39473331429873343`, 0.9383415660076406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 437}], {
             RGBColor[
             0.26255787085876586`, 0.3932953477760335, 0.9382636543746206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 100}], {
             RGBColor[
             0.943316965793535, 0.8656345224892459, 0.6119300548794735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 127}], {
             RGBColor[
             0.5906994451507328, 0.6605608453144329, 0.9482643190369882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 168}], {
             RGBColor[
             0.9331056494970619, 0.8251500560931704, 0.6037137900969318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 213}], {
             RGBColor[
             0.9298124883323949, 0.8120876909328425, 0.6010637208876998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 214}], {
             RGBColor[
             0.5776130969249946, 0.6468062636067821, 0.9475190708650497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 254}], {
             RGBColor[
             0.5959586642234989, 0.6660886180136586, 0.9485638237828649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 302}], {
             RGBColor[
             0.5727842186692342, 0.6417308063914131, 0.9472440733920693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 315}], {
             RGBColor[
             0.5704593476328262, 0.6392872195268108, 0.9471116754258844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 325}], {
             RGBColor[
             0.5672179996830251, 0.6358803573182399, 0.9469270854552878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 368}], {
             RGBColor[
             0.6817603644893816, 0.7470855364406719, 0.9537864521193352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 401}], {
             RGBColor[
             0.8644357283380311, 0.8946091728083778, 0.9692011064141851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 477}], {
             RGBColor[
             0.6000453532177727, 0.6703839872576882, 0.948796554675374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 500}], {
             RGBColor[
             0.8874558706447166, 0.5585534617562613, 0.5633237757723539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 97}], {
             RGBColor[
             0.22940871371662525`, 0.3584534818416879, 0.936375858915159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 137}], {
             RGBColor[
             0.22358173079098384`, 0.35232895333478276`, 0.9360440208577924]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 145}], {
             RGBColor[
             0.22387054333517215`, 0.3526325136304976, 0.9360604683049241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 174}], {
             RGBColor[
             0.24687001390337449`, 0.3768064154483368, 0.9373702541291156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 286}], {
             RGBColor[
             0.22509159237078977`, 0.3539159135859121, 0.9361300052411223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 294}], {
             RGBColor[
             0.2326978312332123, 0.36191055289371626`, 0.9365631692919152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 346}], {
             RGBColor[
             0.22248278830370904`, 0.3511738951036789, 0.9359814377088818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 358}], {
             RGBColor[
             0.2263545662938538, 0.3552433792562242, 0.9362019297376383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 404}], {
             RGBColor[
             0.22026561376472564`, 0.3488435040862222, 0.9358551728989024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 407}], {
             RGBColor[
             0.22072063099008732`, 0.34932175603983573`, 0.9358810854567492]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 408}], {
             RGBColor[
             0.22479372667970515`, 0.35360283785880653`, 0.9361130422306678]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 430}], {
             RGBColor[
             0.23341097282813747`, 0.36266010992577125`, 0.9366037816507478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 131}], {
             RGBColor[
             0.2798853921380307, 0.4115076712688437, 0.9392504310777041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 147}], {
             RGBColor[
             0.27382745193814473`, 0.40514039202317054`, 0.9389054403452399]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.29935267191603787`, 0.43196901661235676`, 0.940359063861802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 171}], {
             RGBColor[
             0.2789519797924134, 0.41052659571183897`, 0.939197274625481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 180}], {
             RGBColor[
             0.2831463385898367, 0.4149351327456384, 0.9394361371539964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 216}], {
             RGBColor[
             0.2810238579235662, 0.4127042709923413, 0.9393152650199811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 238}], {
             RGBColor[
             0.3081578274315908, 0.4401690531459169, 0.9408991236475683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 265}], {
             RGBColor[
             0.3085881199169248, 0.4405417508695841, 0.9409265415042412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 281}], {
             RGBColor[
             0.27053519804586806`, 0.4016800244414347, 0.938717951356528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 343}], {
             RGBColor[
             0.29452462133405766`, 0.4268944293346082, 0.940084113523619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 392}], {
             RGBColor[
             0.3010815634219416, 0.43378619120311424`, 0.9404575216753974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 433}], {
             RGBColor[
             0.31083399291217784`, 0.4424870131772134, 0.9410696465455513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 465}], {
             RGBColor[
             0.2893936582907169, 0.42150146185421045`, 0.9397919127688803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 104}], {
             RGBColor[
             0.23915408747259903`, 0.3686964875516002, 0.936930843533573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 137}], {
             RGBColor[
             0.2259075246268314, 0.35477351012010483`, 0.9361764713760403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 145}], {
             RGBColor[
             0.2261963371710197, 0.3550770704158197, 0.9361929188231719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 174}], {
             RGBColor[
             0.24919580773922206`, 0.37925097223365895`, 0.9375027046473634]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 294}], {
             RGBColor[
             0.23502362506905988`, 0.3643551096790384, 0.936695619810163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 346}], {
             RGBColor[
             0.22480858213955662`, 0.353618451889001, 0.9361138882271296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 358}], {
             RGBColor[
             0.2286803601297014, 0.35768793604154625`, 0.9363343802558861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 404}], {
             RGBColor[
             0.2225914076005732, 0.3512880608715443, 0.9359876234171504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 407}], {
             RGBColor[
             0.2230464248259349, 0.3517663128251578, 0.936013535974997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 408}], {
             RGBColor[
             0.2271195205155527, 0.3560473946441286, 0.9362454927489157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 430}], {
             RGBColor[
             0.23573676666398502`, 0.3651046667110934, 0.9367362321689956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 115}], {
             RGBColor[
             0.9582015589575525, 0.9660972945461519, 0.85752593015656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 124}], {
             RGBColor[
             0.9789436438067185, 0.93894816660261, 0.5160607207640602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 136}], {
             RGBColor[
             0.9820976999154852, 0.9842937020241562, 0.8300672430323528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 253}], {
             RGBColor[
             0.9901332923121124, 0.9901471046097305, 0.8102166844391167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 261}], {
             RGBColor[
             0.9376107771767181, 0.7700729496416561, 0.47213960027127755`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 277}], {
             RGBColor[
             0.8832681348130269, 0.9067408984138945, 0.8502742951726139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 311}], {
             RGBColor[
             0.8710458030481137, 0.8971927199459824, 0.8490560873664715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 319}], {
             RGBColor[
             0.8550622111994015, 0.8847062165139711, 0.8474629923061501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 331}], {
             RGBColor[
             0.9159632164581281, 0.9324175867663749, 0.8534971993423514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 377}], {
             RGBColor[
             0.9881699242791049, 0.9888223570121889, 0.8197885510745015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 484}], {
             RGBColor[
             0.9940632182259341, 0.9897101490230129, 0.5951961253421731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 488}], {
             RGBColor[
             0.8822995191611039, 0.9059842085048606, 0.8501777526166581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 122}], {
             RGBColor[
             0.930562919133284, 0.740007623770434, 0.37913808172539787`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 267}], {
             RGBColor[
             0.9913420700473246, 0.9817665875606343, 0.479566100729647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 278}], {
             RGBColor[
             0.9709926371751241, 0.9748878865987054, 0.7597061890098948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 329}], {
             RGBColor[
             0.9380897089070905, 0.9489785735157732, 0.7678909167681753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 406}], {
             RGBColor[
             0.992119957252125, 0.9843905837590278, 0.48258804562862445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 413}], {
             RGBColor[
             0.9837287794830555, 0.9560851708017216, 0.4499899045367475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 476}], {
             RGBColor[
             0.9210569805098886, 0.6812525268241133, 0.37059559494700395`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 486}], {
             RGBColor[
             0.9642745659488295, 0.9698576677518461, 0.7703884518083142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 493}], {
             RGBColor[
             0.9935993972524345, 0.9887180828601909, 0.5447120747479771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 121}], {
             RGBColor[
             0.8793403970281699, 0.48855884043917713`, 0.2187233911438525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 127}], {
             RGBColor[
             0.5785973319473678, 0.5599231651764567, 0.5998463238378839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 168}], {
             RGBColor[
             0.9210035362936968, 0.7245123759551941, 0.25529579489782767`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 200}], {
             RGBColor[
             0.9160214299715226, 0.703780905297789, 0.25123642844933736`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 213}], {
             RGBColor[
             0.9177103751290299, 0.7114500107948662, 0.2526457256885956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 254}], {
             RGBColor[
             0.5838565510201338, 0.5654509378756822, 0.6001458285837606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 259}], {
             RGBColor[
             0.8965277758950481, 0.6152647749950997, 0.2349704456547408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 315}], {
             RGBColor[
             0.5583572344294613, 0.5386495393888345, 0.5986936802267802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 368}], {
             RGBColor[
             0.6696582512860165, 0.6464478563026956, 0.6053684569202311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 401}], {
             RGBColor[
             0.8523336151346661, 0.7939714926704016, 0.620783111215081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 450}], {
             RGBColor[
             0.8744616680202064, 0.45105879141128646`, 0.21405151473609035`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 454}], {
             RGBColor[
             0.915548639391991, 0.7016340736991815, 0.25084192040061865`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 471}], {
             RGBColor[
             0.894013717811025, 0.6013444138663678, 0.23277457969666004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 475}], {
             RGBColor[
             0.8851091218155209, 0.5328997870260774, 0.22424752851506258`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 500}], {
             RGBColor[
             0.8753537574413516, 0.45791578161828494`, 0.21490578057324983`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 128}], {
             RGBColor[
             0.5077879700548952, 0.6112841755347511, 0.9543940755727961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 169}], {
             RGBColor[
             0.506787455963573, 0.6104719131227696, 0.9543153114385234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 197}], {
             RGBColor[
             0.6092291752169602, 0.6927921015850171, 0.9629587335694303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[
             0.5113628894889524, 0.6141864561796039, 0.9546755063260064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 219}], {
             RGBColor[
             0.5235508135187052, 0.6240811619666777, 0.9556349843514654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 337}], {
             RGBColor[
             0.6905217138834787, 0.756623588079157, 0.9709749326217818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 345}], {
             RGBColor[
             0.5902789610650883, 0.677988050262613, 0.9610699533225915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 355}], {
             RGBColor[
             0.424769765192925, 0.5405027707410431, 0.9487934456872616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 361}], {
             RGBColor[
             0.5825170875925927, 0.671924415713476, 0.9602963223136847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 362}], {
             RGBColor[
             0.45464713410545365`, 0.5663810460128507, 0.950697205214848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 363}], {
             RGBColor[
             0.4628220425559936, 0.5734617408298626, 0.9512181031525286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 498}], {
             RGBColor[
             0.491361119566665, 0.5979481182872246, 0.9531008937288266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 109}], {
             RGBColor[
             0.265248780611274, 0.396123664539452, 0.9384168977041816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[
             0.28024115314486164`, 0.4118815986435736, 0.9392706911407418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 186}], {
             RGBColor[
             0.256123983487738, 0.3865329242170628, 0.9378972540069239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 193}], {
             RGBColor[
             0.2821746373958698, 0.4139138131813651, 0.9393808002085031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 196}], {
             RGBColor[
             0.28611844580431445`, 0.41805900587053585`, 0.9396053942630224]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 202}], {
             RGBColor[
             0.2577973086293919, 0.3882916950358828, 0.9379925473982783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 330}], {
             RGBColor[
             0.2914935550351155, 0.4237085864737168, 0.939911498781955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 350}], {
             RGBColor[
             0.3193537748201921, 0.44805203074969097`, 0.941678953195245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 354}], {
             RGBColor[
             0.3191507002330799, 0.44787613774915985`, 0.941666013462126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 414}], {
             RGBColor[
             0.27559776236137046`, 0.40700110052214455`, 0.9390062569049031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 415}], {
             RGBColor[
             0.28177512151681394`, 0.41349389666170766`, 0.9393580483702217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 485}], {
             RGBColor[
             0.2622693737921402, 0.3929921190672394, 0.9382472248934693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 496}], {
             RGBColor[
             0.27671354998693043`, 0.4081738640616296, 0.9390697993595188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 118}], {
             RGBColor[
             0.4027319052154037, 0.522513730131029, 0.9470855430392838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 188}], {
             RGBColor[
             0.408816425381794, 0.5277838356822806, 0.9474732432839563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 304}], {
             RGBColor[
             0.4094598762170423, 0.5283411604549934, 0.947514243402197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 319}], {
             RGBColor[
             0.5976226950866923, 0.6831049747415705, 0.9622258440138658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 331}], {
             RGBColor[
             0.6585237003454188, 0.7308163449939742, 0.968260051050067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 449}], {
             RGBColor[
             0.6043292409167387, 0.6883441793156388, 0.9628942898259707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 488}], {
             RGBColor[
             0.6248600030483947, 0.70438296673246, 0.9649406043243738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 112}], {
             RGBColor[
             0.24741859649764936`, 0.37738301053706513`, 0.9374014950963042]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 148}], {
             RGBColor[
             0.2431147548759032, 0.37285940011329033`, 0.9371563976829089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 153}], {
             RGBColor[
             0.24575331572793313`, 0.3756326948631943, 0.937306659820031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 190}], {
             RGBColor[
             0.24734164292075334`, 0.3773021274486088, 0.9373971127039427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 215}], {
             RGBColor[
             0.26534838496499225`, 0.39622835503049064`, 0.9384225700247744]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 224}], {
             RGBColor[
             0.2727699797429894, 0.40402892169845256`, 0.9388452188681158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 323}], {
             RGBColor[
             0.2429591667599799, 0.3726958671385986, 0.9371475371698791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 351}], {
             RGBColor[
             0.2683095588486911, 0.39934073653152624`, 0.9385912044967868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 356}], {
             RGBColor[
             0.2579557991377684, 0.3884582786090651, 0.9380015731982647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 408}], {
             RGBColor[
             0.23453910043567894`, 0.36384584356871885`, 0.9366680268490819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 430}], {
             RGBColor[
             0.24315634658411125`, 0.3729031156356836, 0.937158766269162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 452}], {
             RGBColor[
             0.2352635459876256, 0.36460728177631574`, 0.9367092829515442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 112}], {
             RGBColor[
             0.2470843980758506, 0.3770317468063509, 0.9373824629905851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 148}], {
             RGBColor[
             0.24278055645410443`, 0.37250813638257607`, 0.9371373655771897]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 153}], {
             RGBColor[
             0.24541911730613436`, 0.37528143113248, 0.9372876277143118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 190}], {
             RGBColor[
             0.24700744449895456`, 0.37695086371789455`, 0.9373780805982235]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 195}], {
             RGBColor[
             0.2580285978828387, 0.38853479470584096`, 0.9380057189791005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 263}], {
             RGBColor[
             0.2596529612026372, 0.3902421035455322, 0.9380982240671327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 323}], {
             RGBColor[
             0.24262496833818112`, 0.37234460340788433`, 0.93712850506416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 342}], {
             RGBColor[
             0.252946206923672, 0.38319287956555814`, 0.9377162843326995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 395}], {
             RGBColor[
             0.2554464216840092, 0.38582076380144426`, 0.9378586678645644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 447}], {
             RGBColor[
             0.24620260884716, 0.3761049304183308, 0.9373322463985014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 453}], {
             RGBColor[
             0.265106051538209, 0.39597364723411466`, 0.9384087694946193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 463}], {
             RGBColor[
             0.2565013158137106, 0.3869295244159112, 0.9379187425246749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 117}], {
             RGBColor[
             0.44946530583261596`, 0.561973649912251, 0.9503446865091629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 139}], {
             RGBColor[
             0.5409452590449157, 0.6382027564556965, 0.9570043388212421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 140}], {
             RGBColor[
             0.508744701282457, 0.6120608930455363, 0.9544693929596517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 247}], {
             RGBColor[
             0.5064333598698463, 0.6101844419620349, 0.9542874356969284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 255}], {
             RGBColor[
             0.45772043203322, 0.569123825312507, 0.9508706958509441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 269}], {
             RGBColor[
             0.48339733950661234`, 0.5913638720070653, 0.9525068056899508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 274}], {
             RGBColor[
             0.49029479958875166`, 0.5970824316919869, 0.9530169491141065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 360}], {
             RGBColor[
             0.5486108303756021, 0.6444260125920007, 0.9576078006763067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 369}], {
             RGBColor[
             0.46890138102995677`, 0.5788082013626439, 0.9515831360340911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 370}], {
             RGBColor[
             0.5546493379031965, 0.6493283450345659, 0.9580831741086608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 425}], {
             RGBColor[
             0.4465990938801403, 0.559491081179018, 0.9501620540180429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 466}], {
             RGBColor[
             0.5106817556791221, 0.6136334810680553, 0.9546218849774213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 468}], {
             RGBColor[
             0.4981161809408796, 0.6034321814228589, 0.9536326769048099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 113}], {
             RGBColor[
             0.18193197659231264`, 0.3085524209250408, 0.9336721289714678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 132}], {
             RGBColor[
             0.5874023021726906, 0.6508098778838103, 0.8735074338464627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 143}], {
             RGBColor[
             0.18179934691843552`, 0.30841301872858895`, 0.9336645759077484]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 209}], {
             RGBColor[
             0.37529763235099667`, 0.4849566561931139, 0.9463994374355724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 214}], {
             RGBColor[
             0.19223940367108877`, 0.31938618031345734`, 0.9342591216951321]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 273}], {
             RGBColor[
             0.2391065540897807, 0.3686465269524677, 0.9369281365777409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 308}], {
             RGBColor[
             0.18180898862834943`, 0.3084231527770282, 0.9336651249888644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 421}], {
             RGBColor[
             0.18186414913512938`, 0.30848112996703203`, 0.9336682662981228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 423}], {
             RGBColor[
             0.18624879198055028`, 0.31308966759998247`, 0.9339179652216718]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 446}], {
             RGBColor[
             0.2064114829025504, 0.3342819341474452, 0.9350662006416515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 477}], {
             RGBColor[
             0.21467165996386678`, 0.3429639039643634, 0.9355366055054566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 129}], {
             RGBColor[
             0.3203552344901264, 0.4497120899906687, 0.9417137426958612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 163}], {
             RGBColor[
             0.27605150294224795`, 0.40747801064146116`, 0.939032096759735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 189}], {
             RGBColor[
             0.27244302962866296`, 0.40368527639846097`, 0.9388265995427842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 206}], {
             RGBColor[
             0.31392242641055057`, 0.44414031495447526`, 0.9413038498533395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 266}], {
             RGBColor[
             0.28731571918259713`, 0.4193174161026276, 0.9396735772107083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 364}], {
             RGBColor[
             0.27183868506633, 0.4030500719457907, 0.938792183014007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 374}], {
             RGBColor[
             0.2684205085848909, 0.3994573517388918, 0.938597522920128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 410}], {
             RGBColor[
             0.32438785376155105`, 0.4532049421182389, 0.9419706976299311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 437}], {
             RGBColor[
             0.27047057871071917`, 0.40161210542309067`, 0.938714271380987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 185}], {
             RGBColor[
             0.26895237692670115`, 0.40001637908853493`, 0.9386278120353654]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 186}], {
             RGBColor[
             0.24483520726957755`, 0.37466770466202415`, 0.9372543749015474]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 196}], {
             RGBColor[
             0.27482966958615396`, 0.4061937863154972, 0.938962515157646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 218}], {
             RGBColor[
             0.24296647092511459`, 0.372703544279266, 0.937147953131278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 295}], {
             RGBColor[
             0.24177394363545715`, 0.37145012248723885`, 0.937080040466318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 300}], {
             RGBColor[
             0.23995882574419874`, 0.3695423184984049, 0.9369766721876371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 335}], {
             RGBColor[
             0.2653660882581673, 0.3962469623140712, 0.938423578201131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 409}], {
             RGBColor[
             0.24775783308986035`, 0.3777395697043211, 0.9374208141183751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 456}], {
             RGBColor[
             0.23880926652767986`, 0.3683340588755796, 0.9369112064908769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 458}], {
             RGBColor[
             0.24222963005763265`, 0.3719290778091332, 0.9371059911339332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 496}], {
             RGBColor[
             0.26542477376877, 0.3963086445065909, 0.9384269202541424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 217}], {
             RGBColor[
             0.29571753049971145`, 0.4271336534107135, 0.9401891973787395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 290}], {
             RGBColor[
             0.2791002706073135, 0.4106824587604797, 0.9392057195680129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 316}], {
             RGBColor[
             0.26110517012024004`, 0.39176846719329617`, 0.9381809252166395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 340}], {
             RGBColor[
             0.3045749314378675, 0.43480548891742876`, 0.9407535831342266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 355}], {
             RGBColor[
             0.30021105187484454`, 0.43102571577490256`, 0.9404755205872981]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 378}], {
             RGBColor[
             0.2773998635716586, 0.40889522315397336`, 0.9391088839028592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 384}], {
             RGBColor[
             0.27776805045914515`, 0.4092822109171187, 0.9391298516014178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 146}], {
             RGBColor[
             0.2655122364597581, 0.39640057334027434`, 0.9384319011250047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 201}], {
             RGBColor[
             0.28877500860148286`, 0.42085122180616963`, 0.9397566815842886]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 256}], {
             RGBColor[
             0.2812386903435383, 0.41293007348689414`, 0.9393274994084824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 271}], {
             RGBColor[
             0.2644482810539334, 0.39528228875008364`, 0.938371310438624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 284}], {
             RGBColor[
             0.2590919383322233, 0.3896524329378227, 0.9380662746446216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 312}], {
             RGBColor[
             0.28875139009156847`, 0.4208263972547496, 0.9397553365450895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 376}], {
             RGBColor[
             0.2762731715166523, 0.4077109983677596, 0.9390447204571181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[
             0.2845065356159251, 0.4163647860615299, 0.939513598362401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 415}], {
             RGBColor[
             0.2800519643946353, 0.41168274927182613`, 0.9392599171212961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 442}], {
             RGBColor[
             0.2785182841132166, 0.41007075405510884`, 0.939172576298146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 444}], {
             RGBColor[
             0.272192144891436, 0.40342158063262434`, 0.9388123120281499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 464}], {
             RGBColor[
             0.2584790029138965, 0.3890081989508112, 0.9380313688793045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 148}], {
             RGBColor[
             0.2439596839808273, 0.373747474174165, 0.9372045151454738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 153}], {
             RGBColor[
             0.24659824483285725`, 0.37652076892406894`, 0.9373547772825959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 190}], {
             RGBColor[
             0.24818657202567745`, 0.37819020150948346`, 0.9374452301665075]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 195}], {
             RGBColor[
             0.25920772540956155`, 0.3897741324974299, 0.9380728685473844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 224}], {
             RGBColor[
             0.2736149088479135, 0.4049169957593272, 0.9388933363306806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 263}], {
             RGBColor[
             0.2608320887293601, 0.39148144133712115`, 0.9381653736354167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 323}], {
             RGBColor[
             0.24380409586490398`, 0.37358394119947325`, 0.9371956546324439]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 342}], {
             RGBColor[
             0.25412533445039487`, 0.3844322173571471, 0.9377834339009834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 351}], {
             RGBColor[
             0.26915448795361524`, 0.4002288105924009, 0.9386393219593516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 356}], {
             RGBColor[
             0.2588007282426925, 0.3893463526699398, 0.9380496906608295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 395}], {
             RGBColor[
             0.2566255492107321, 0.38706010159303317`, 0.9379258174328484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 447}], {
             RGBColor[
             0.2473817363738829, 0.37734426820991973`, 0.9373993959667855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 452}], {
             RGBColor[
             0.2361084750925497, 0.3654953558371904, 0.936757400414109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 463}], {
             RGBColor[
             0.2576804433404335, 0.3881688622075002, 0.9379858920929589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 130}], {
             RGBColor[
             0.17905963034776856`, 0.3055334029047545, 0.9335085531020964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 143}], {
             RGBColor[
             0.17905963102166003`, 0.30553340361305714`, 0.9335085531404735]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 209}], {
             RGBColor[
             0.3725579164542212, 0.4820770410775821, 0.9462434146682975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 214}], {
             RGBColor[
             0.18949968777431325`, 0.3165065651979255, 0.9341030989278573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 273}], {
             RGBColor[
             0.23636683819300525`, 0.3657669118369359, 0.936772113810466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 302}], {
             RGBColor[
             0.18467080951855291`, 0.3114311079825565, 0.9338281014548768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 308}], {
             RGBColor[
             0.17906927273157397`, 0.3055435376614964, 0.9335091022215896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 325}], {
             RGBColor[
             0.1791045905323438, 0.30558065890938335`, 0.9335111135180953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 347}], {
             RGBColor[
             0.17905963034776856`, 0.3055334029047545, 0.9335085531020964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 386}], {
             RGBColor[
             0.17905963034776856`, 0.3055334029047545, 0.9335085531020964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 421}], {
             RGBColor[
             0.17912443323835392`, 0.3056015148515002, 0.9335122435308479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 423}], {
             RGBColor[
             0.1835090760837748, 0.31021005248445066`, 0.9337619424543968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 477}], {
             RGBColor[
             0.2119319440670913, 0.3400842888488316, 0.9353805827381816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 115}], {
             RGBColor[
             0.7109234320173796, 0.7727455262693818, 0.9730887236423327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 203}], {
             RGBColor[
             0.5176225598035007, 0.6192683385358883, 0.9551682905030956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 208}], {
             RGBColor[
             0.41139850447614446`, 0.5294684917353877, 0.9477902381259522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 258}], {
             RGBColor[
             0.4370504632160207, 0.551686929090934, 0.9494247582537205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 289}], {
             RGBColor[
             0.47002476811242727`, 0.580247614655448, 0.9515258518036867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 291}], {
             RGBColor[
             0.577802812280651, 0.6679328507014297, 0.9600375327920143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 297}], {
             RGBColor[
             0.5100213466264654, 0.6130973312480197, 0.954569895157638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 311}], {
             RGBColor[
             0.6237676761079407, 0.7038409516692123, 0.9646188808522442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 349}], {
             RGBColor[
             0.45713997699902986`, 0.5690874562014547, 0.9507048443075143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 359}], {
             RGBColor[
             0.443064873322788, 0.5568963088323743, 0.9498079911473898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 381}], {
             RGBColor[
             0.5349916430046526, 0.6333693427468647, 0.9565356483577385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 397}], {
             RGBColor[
             0.4296132686116584, 0.545245204928905, 0.9489508667899835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 419}], {
             RGBColor[
             0.5066845097134336, 0.6103883367192307, 0.9543072071326079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 124}], {
             RGBColor[
             0.9419104649402625, 0.9128295501642687, 0.6508778471089514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 136}], {
             RGBColor[
             0.9450645210490293, 0.9581750855858149, 0.964884369377244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 178}], {
             RGBColor[
             0.9564265081535962, 0.965404037867567, 0.8899068420398936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 203}], {
             RGBColor[
             0.7278675078772177, 0.786501490374317, 0.9744226233622142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 253}], {
             RGBColor[
             0.9531001134456565, 0.9640284881713892, 0.9450338107840079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 277}], {
             RGBColor[
             0.8462349559465709, 0.8806222819755531, 0.9850914215175051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 291}], {
             RGBColor[
             0.7880477603543681, 0.8351660025398585, 0.9792918656511329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 297}], {
             RGBColor[
             0.7202662947001824, 0.7803304830864486, 0.9738242280167566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 311}], {
             RGBColor[
             0.8340126241816578, 0.871074103507641, 0.9838732137113628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 381}], {
             RGBColor[
             0.7452365910783697, 0.8006024945852935, 0.9757899812168571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 419}], {
             RGBColor[
             0.7169294577871506, 0.7776214885576594, 0.9735615399917263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 439}], {
             RGBColor[
             0.8910404321249454, 0.9159554702009634, 0.9894694259289032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 484}], {
             RGBColor[
             0.9570300393594782, 0.9635915325846716, 0.7300132516870645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 192}], {
             RGBColor[
             0.2516702940273803, 0.3818518142140055, 0.9376436229807996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 280}], {
             RGBColor[
             0.25280916302349343`, 0.3830488377373854, 0.9377084798853226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 310}], {
             RGBColor[
             0.2727415097182925, 0.40399899789739224`, 0.9388435975423268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 327}], {
             RGBColor[
             0.25289755432094124`, 0.38314174259533496`, 0.937713513638949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 399}], {
             RGBColor[
             0.24511345141386065`, 0.3749601568993634, 0.937270220493939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 412}], {
             RGBColor[
             0.24555371763094103`, 0.3754229046080053, 0.9372952930036862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 483}], {
             RGBColor[
             0.27268756010159706`, 0.40394229342964216`, 0.9388405251914673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 139}], {
             RGBColor[
             0.47255522666265165`, 0.5807190878311534, 0.9521624096580703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 140}], {
             RGBColor[
             0.44035466890019287`, 0.5545772244209933, 0.9496274637964799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 154}], {
             RGBColor[
             0.34530823850037556`, 0.4735103733174856, 0.9432237135065259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 247}], {
             RGBColor[
             0.4380433274875822, 0.5527007733374919, 0.9494455065337566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 255}], {
             RGBColor[
             0.38933039965095584`, 0.511640156687964, 0.9460287666877722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 269}], {
             RGBColor[
             0.41500730712434825`, 0.5338802033825223, 0.947664876526779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 338}], {
             RGBColor[
             0.3505903006321732, 0.47808543005188675`, 0.9435602818348199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 369}], {
             RGBColor[
             0.40051134864769267`, 0.5213245327381009, 0.9467412068709193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 390}], {
             RGBColor[
             0.34091437037852435`, 0.46896566133560236`, 0.9429707972165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 425}], {
             RGBColor[
             0.3782090614978762, 0.502007412554475, 0.9453201248548712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 466}], {
             RGBColor[
             0.44229172329685795`, 0.5561498124435122, 0.9497799558142495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[
             0.31734549257895406`, 0.4492904482488255, 0.9414419520628983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 151}], {
             RGBColor[
             0.31595121433390305`, 0.44790234871507695`, 0.9413597168905753]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 188}], {
             RGBColor[
             0.3311926249986076, 0.4612841383736176, 0.9423242790961401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 304}], {
             RGBColor[
             0.3318360758338559, 0.46184146314633034`, 0.9423652792143808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 310}], {
             RGBColor[
             0.3109325878407584, 0.44262745407148385`, 0.9410739135361832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 327}], {
             RGBColor[
             0.2910886324434072, 0.42177019876942656`, 0.9399438296328053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 483}], {
             RGBColor[
             0.31087863822406303`, 0.44257074960373377`, 0.9410708411853237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 197}], {
             RGBColor[
             0.8441364985929255, 0.8770550844901885, 0.8875786005274353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 237}], {
             RGBColor[
             0.9483698835729416, 0.9591789791220269, 0.8977829179807035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 270}], {
             RGBColor[
             0.9903352312511376, 0.9902713839961873, 0.8098337599957988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 309}], {
             RGBColor[
             0.9918390696706652, 0.9889511495464178, 0.6437403499501158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 320}], {
             RGBColor[
             0.9896249360090673, 0.9899776586598361, 0.8216051903420669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 345}], {
             RGBColor[
             0.8251862844410536, 0.8622510331677843, 0.8856898202805965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 375}], {
             RGBColor[
             0.9744244063754681, 0.9793738724475776, 0.8801494909995853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 426}], {
             RGBColor[
             0.9304108836330538, 0.9448589600540273, 0.8960699725342486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 489}], {
             RGBColor[
             0.9903724843514137, 0.9902867891105125, 0.8092163797162932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 123}], {
             RGBColor[
             0.20719251066229882`, 0.33510284384296096`, 0.9351106790171422]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 125}], {
             RGBColor[
             0.2080475453125366, 0.33600153947268885`, 0.9351593719755629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 177}], {
             RGBColor[
             0.20805903153131503`, 0.3360136122168933, 0.9351600260987298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 438}], {
             RGBColor[
             0.21444303080234048`, 0.3427236002196732, 0.9355235854129342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 455}], {
             RGBColor[
             0.2056810719300792, 0.33351422590464763`, 0.9350246048173154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 457}], {
             RGBColor[
             0.21450528797873675`, 0.3427890364593986, 0.9355271308670288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 161}], {
             RGBColor[
             0.9088989497892817, 0.5955852022276555, 0.2954383174204215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[
             0.8641469744095227, 0.4273429033856967, 0.2064477599128205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.86583591956703, 0.4350120088827739, 0.20785705715207875`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 259}], {
             RGBColor[
             0.8446533203330481, 0.33882677308300735`, 0.1901817771182239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 341}], {
             RGBColor[
             0.9105196563022746, 0.6003916270804778, 0.3579070077274834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 450}], {
             RGBColor[
             0.8225872124582064, 0.17462078949919407`, 0.16926284619957344`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 454}], {
             RGBColor[
             0.8636741838299911, 0.42519607178708907`, 0.20605325186410173`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 469}], {
             RGBColor[
             0.8439483097229172, 0.3356254845618147, 0.18959349898373934`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 471}], {
             RGBColor[
             0.842139262249025, 0.3249064119542755, 0.18798591116014318`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 475}], {
             RGBColor[
             0.8332346662535209, 0.256461785113985, 0.17945885997854572`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 491}], {
             RGBColor[
             0.9108136867178351, 0.6010205284083265, 0.38991040391585896`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 500}], {
             RGBColor[
             0.8234793018793516, 0.18147777970619255`, 0.1701171120367329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 150}], {
             RGBColor[
             0.8444744803276283, 0.32854420856354566`, 0.1896617078466737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.8441272348319537, 0.3258751275198433, 0.1893291851678579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 233}], {
             RGBColor[
             0.8553320507775657, 0.4120002528594733, 0.20005892957140564`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 267}], {
             RGBColor[
             0.9282834555711476, 0.7330087810415269, 0.3115827018545064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 406}], {
             RGBColor[
             0.929061342775948, 0.7356327772399205, 0.3146046467534838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 413}], {
             RGBColor[
             0.9206701650068785, 0.7073273642826143, 0.2820065056616069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 476}], {
             RGBColor[
             0.8579983660337116, 0.432494720305006, 0.20261219607186334`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 493}], {
             RGBColor[
             0.9305407827762575, 0.7399602763410837, 0.37672867587283654`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 125}], {
             RGBColor[
             0.2078185513522534, 0.33576085230137553`, 0.9351463311082908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 177}], {
             RGBColor[
             0.2078300375710318, 0.33577292504558, 0.935146985231458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 438}], {
             RGBColor[
             0.21421403684205725`, 0.34248291304835987`, 0.9355105445456623]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 455}], {
             RGBColor[
             0.20545207796979598`, 0.3332735387333343, 0.9350115639500436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 136}], {
             RGBColor[
             0.9658066058981951, 0.931025957642273, 0.6234191599847442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 178}], {
             RGBColor[
             0.977168593002762, 0.938254909924025, 0.5484416326473938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 253}], {
             RGBColor[
             0.9738421982948224, 0.9368793602278473, 0.603568601391508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 261}], {
             RGBColor[
             0.9213196831594281, 0.7168052052597729, 0.265491517223669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 357}], {
             RGBColor[
             0.9348974167088442, 0.7776187751730486, 0.27677767167712564`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 484}], {
             RGBColor[
             0.9777721242086441, 0.9364424046411297, 0.38854804229456463`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 177}], {
             RGBColor[
             0.20868507222126964`, 0.3366716206753079, 0.9351956781898786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 438}], {
             RGBColor[
             0.2150690714922951, 0.34338160867808776`, 0.9355592375040829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 455}], {
             RGBColor[
             0.20630711262003382`, 0.3341722343630622, 0.9350602569084642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 457}], {
             RGBColor[
             0.21513132866869134`, 0.3434470449178132, 0.9355627829581774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 144}], {
             RGBColor[
             0.24868278916139275`, 0.37871175718110384`, 0.937473488998299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 279}], {
             RGBColor[
             0.26484901945855754`, 0.3957034902216259, 0.9383941318979281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 285}], {
             RGBColor[
             0.28277807837083513`, 0.4140236211798849, 0.9394343678430408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 481}], {
             RGBColor[
             0.28467725623571494`, 0.41566859359098884`, 0.9395553817772139]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 130}], {
             RGBColor[
             0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 168}], {
             RGBColor[
             0.5683860156508949, 0.5194386987803812, 0.5916300590553423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 179}], {
             RGBColor[
             0.20245447418328588`, 0.33012286709465477`, 0.9348408548489592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 200}], {
             RGBColor[
             0.5634039093287206, 0.4987072281229762, 0.587570692606852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 213}], {
             RGBColor[
             0.5650928544862279, 0.5063763336200533, 0.5889799898461102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 254}], {
             RGBColor[
             0.23123903037733173`, 0.3603772607008694, 0.9364800927412753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 302}], {
             RGBColor[
             0.2080645848230672, 0.3360194490786239, 0.9351603423504797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 315}], {
             RGBColor[
             0.20573971378665917`, 0.3335758622140216, 0.9350279443842948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 325}], {
             RGBColor[
             0.20249836583685807`, 0.33016900000545074`, 0.9348433544136983]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 347}], {
             RGBColor[
             0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 368}], {
             RGBColor[
             0.3170407306432145, 0.44137417912788274`, 0.9417027210777457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 386}], {
             RGBColor[
             0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 401}], {
             RGBColor[
             0.499716094491864, 0.5888978154955886, 0.9571173753725956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 454}], {
             RGBColor[
             0.562931118749189, 0.49656039652436856`, 0.5871761845581333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 169}], {
             RGBColor[
             0.4937426983927686, 0.5998815912671589, 0.9532883803380281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 197}], {
             RGBColor[
             0.5961844176461558, 0.6822017797294064, 0.9619318024689351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 204}], {
             RGBColor[
             0.4983181319181479, 0.6035961343239933, 0.9536485752255113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 345}], {
             RGBColor[
             0.5772342034942839, 0.6673977284070023, 0.9600430222220963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 355}], {
             RGBColor[
             0.4117250076221206, 0.5299124488854325, 0.9477665145867664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 362}], {
             RGBColor[
             0.4416023765346493, 0.55579072415724, 0.9496702741143528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 498}], {
             RGBColor[
             0.4783163619958606, 0.5873577964316139, 0.9520739626283314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 170}], {
             RGBColor[
             0.3261401713486173, 0.4557924254151241, 0.9420431862919051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 206}], {
             RGBColor[
             0.3491669657996257, 0.47685260895882275`, 0.9434695881978956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 265}], {
             RGBColor[
             0.3383071396578693, 0.46744637338556605`, 0.9427776096791101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 266}], {
             RGBColor[
             0.32256025857167225`, 0.4520297101069751, 0.9418393155552645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 328}], {
             RGBColor[
             0.3704563897071251, 0.49529243790994043`, 0.944826131463783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 410}], {
             RGBColor[
             0.3596323931506261, 0.48591723612258636`, 0.9441364359744873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 433}], {
             RGBColor[
             0.3405530126531223, 0.4693916356931953, 0.94292071472042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 143}], {
             RGBColor[
             0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 179}], {
             RGBColor[
             0.17892806853100302`, 0.30539512309383293`, 0.93350106085126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 214}], {
             RGBColor[
             0.1893670574265447, 0.316367162293171, 0.9340955458257609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 254}], {
             RGBColor[
             0.20771262472504887`, 0.3356495167000475, 0.935140298743576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 302}], {
             RGBColor[
             0.18453817917078433`, 0.311291705077802, 0.9338205483527805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 315}], {
             RGBColor[
             0.1822133081343763, 0.30884811821319974`, 0.9336881503865955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 325}], {
             RGBColor[
             0.1789719601845752, 0.3054412560046289, 0.9335035604159989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 347}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 368}], {
             RGBColor[
             0.2935143249909316, 0.4166464351270609, 0.9403629270800464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 386}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 421}], {
             RGBColor[
             0.17899180289058533`, 0.3054621119467458, 0.9335046904287516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 477}], {
             RGBColor[
             0.2117993137193227, 0.3399448859440771, 0.9353730296360853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 135}], {
             RGBColor[
             0.25711790914467114`, 0.38757760310102596`, 0.937953856602705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 147}], {
             RGBColor[
             0.257551109678863, 0.38803292432896186`, 0.9379785267322645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 170}], {
             RGBColor[
             0.28014480934839103`, 0.4117803352049335, 0.9392652045040607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 171}], {
             RGBColor[
             0.26267563753313167`, 0.39341912801763035`, 0.9382703610125054]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 216}], {
             RGBColor[
             0.26474751566428445`, 0.3955968032981327, 0.9383883514070055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 238}], {
             RGBColor[
             0.29188148517230905`, 0.42306158545170824`, 0.9399722100345929]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 265}], {
             RGBColor[
             0.29231177765764305`, 0.42343428317537546`, 0.9399996278912657]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 374}], {
             RGBColor[
             0.2576696859737398, 0.38815755553304865`, 0.9379852794768397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 385}], {
             RGBColor[
             0.24854031848564526`, 0.3785620114677306, 0.9374653755040816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 391}], {
             RGBColor[
             0.2523681386345833, 0.3825852931420795, 0.9376833641988113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 433}], {
             RGBColor[
             0.29455765065289613`, 0.4253795454830047, 0.9401427329325757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 209}], {
             RGBColor[
             0.7780282420345992, 0.8243344980363514, 0.8860787195432924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 233}], {
             RGBColor[
             0.9166463543771588, 0.6614692040973338, 0.5010749461233683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 273}], {
             RGBColor[
             0.6418371637733833, 0.7080243687957053, 0.8766074186854609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 423}], {
             RGBColor[
             0.5889794016641527, 0.6524675094432201, 0.8735972473293918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 151}], {
             RGBColor[
             0.3259839947322987, 0.4565922388339624, 0.9419989967859217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 155}], {
             RGBColor[
             0.4555313931992919, 0.5659235600860384, 0.9510915748153721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 181}], {
             RGBColor[
             0.3829354312034995, 0.5061011564392373, 0.9456212849531489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 225}], {
             RGBColor[
             0.3097114792684619, 0.4394887933443991, 0.9410723011032855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 235}], {
             RGBColor[
             0.3511076947395869, 0.47853357082274445`, 0.9435932497298307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 239}], {
             RGBColor[
             0.34805209112246643`, 0.47588696054869806`, 0.943398549369312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 249}], {
             RGBColor[
             0.3173607671926588, 0.44752867994559636`, 0.9415079167344612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 260}], {
             RGBColor[
             0.31537504749154577`, 0.44544156263782575`, 0.9413948329350919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 262}], {
             RGBColor[
             0.4106297397776527, 0.5294703750419166, 0.9475567521778445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 296}], {
             RGBColor[
             0.3292967430314739, 0.4596420207034847, 0.942203475173657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 332}], {
             RGBColor[
             0.3736828594731001, 0.4980870438541423, 0.9450317192642157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 344}], {
             RGBColor[
             0.404458323018091, 0.5244601408973477, 0.9470709156438875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 424}], {
             RGBColor[
             0.33288404882225986`, 0.46274916467623195`, 0.942432055126516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 440}], {
             RGBColor[
             0.31342375230206637`, 0.44339062767442217`, 0.9412837095607336]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 138}], {
             RGBColor[
             0.2265863896100655, 0.3554870402600099, 0.9362151317325447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 251}], {
             RGBColor[
             0.24587579480159133`, 0.37576142813523083`, 0.9373136348220843]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 305}], {
             RGBColor[
             0.2421591297202534, 0.37185497748456803`, 0.9371019762440154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 367}], {
             RGBColor[
             0.23152572380893705`, 0.3606785936749, 0.9364964195080803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 416}], {
             RGBColor[
             0.24737003573452257`, 0.37733197009608865`, 0.9373987296326833]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 438}], {
             RGBColor[
             0.22733547187831532`, 0.35627437321849936`, 0.9362577908595535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 457}], {
             RGBColor[
             0.22739772905471156`, 0.3563398094582248, 0.936261336313648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 499}], {
             RGBColor[
             0.2469625122439105, 0.37690363706897373`, 0.93737552177277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 147}], {
             RGBColor[
             0.2510599689447852, 0.3812103238553528, 0.9376088658702408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 170}], {
             RGBColor[
             0.2736536686143132, 0.40495773473132446`, 0.9388955436420372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 171}], {
             RGBColor[
             0.25618449679905386`, 0.3865965275440213, 0.9379007001504819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 216}], {
             RGBColor[
             0.25825637493020664`, 0.38877420282452363`, 0.938018690544982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 385}], {
             RGBColor[
             0.24204917775156742`, 0.37173941099412156`, 0.9370957146420581]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 391}], {
             RGBColor[
             0.24587699790050546`, 0.37576269266847045`, 0.9373137033367878]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 253}], {
             RGBColor[
             0.9769962544035893, 0.9822248956493935, 0.9175751236598007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 261}], {
             RGBColor[
             0.924473739268195, 0.762150740681319, 0.5794980394919615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 277}], {
             RGBColor[
             0.8701310969045036, 0.8988186894535575, 0.9576327343932979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 291}], {
             RGBColor[
             0.8119439013123007, 0.853362410017863, 0.9518331785269256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 311}], {
             RGBColor[
             0.8579087651395905, 0.8892705109856455, 0.9564145265871555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 319}], {
             RGBColor[
             0.8419251732908781, 0.8767840075536342, 0.9548214315268342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 377}], {
             RGBColor[
             0.9750328863705816, 0.980900148051852, 0.9271469902951855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 484}], {
             RGBColor[
             0.980926180317411, 0.981787940062676, 0.7025545645628573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 488}], {
             RGBColor[
             0.8691624812525807, 0.8980619995445237, 0.9575361918373422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 145}], {
             RGBColor[
             0.2203693542453783, 0.34895254190891456`, 0.9358610807658054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 183}], {
             RGBColor[
             0.2125239415632086, 0.34070651575206007`, 0.9354142961198038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 346}], {
             RGBColor[
             0.21898159921391522`, 0.34749392338209584`, 0.9357820501697631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 358}], {
             RGBColor[
             0.22285337720406, 0.3515634075346411, 0.9360025421985196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 404}], {
             RGBColor[
             0.2167644246749318, 0.34516353236463915`, 0.9356557853597838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 407}], {
             RGBColor[
             0.2172194419002935, 0.34564178431825265`, 0.9356816979176306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 408}], {
             RGBColor[
             0.2212925375899113, 0.34992286613722345`, 0.9359136546915492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 430}], {
             RGBColor[
             0.22990978373834364`, 0.3589801382041882, 0.9364043941116291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 352}], {
             RGBColor[
             0.22389864331585435`, 0.3526620484918363, 0.9360620685572537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 367}], {
             RGBColor[
             0.22490572664447084`, 0.3537205569229832, 0.9361194204629721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 457}], {
             RGBColor[
             0.22077773189024535`, 0.349381772706308, 0.9358843372685399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 140}], {
             RGBColor[
             0.5318346221124927, 0.6308063309644387, 0.9562871161085591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 247}], {
             RGBColor[
             0.529523280699882, 0.6289298798809373, 0.9561051588458358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 255}], {
             RGBColor[
             0.4808103528632557, 0.5878692632314095, 0.9526884189998513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 269}], {
             RGBColor[
             0.506487260336648, 0.6101093099259678, 0.9543245288388581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 274}], {
             RGBColor[
             0.5133847204187874, 0.6158278696108893, 0.9548346722630138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 360}], {
             RGBColor[
             0.5717007512056378, 0.6631714505109032, 0.9594255238252141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 369}], {
             RGBColor[
             0.49199130185999246`, 0.5975536392815464, 0.9534008591829983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 370}], {
             RGBColor[
             0.5777392587332322, 0.6680737829534684, 0.9599008972575682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 425}], {
             RGBColor[
             0.469689014710176, 0.5782365190979204, 0.9519797771669503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 466}], {
             RGBColor[
             0.5337716765091578, 0.6323789189869576, 0.9564396081263286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 468}], {
             RGBColor[
             0.5212061017709153, 0.6221776193417614, 0.9554504000537172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 169}], {
             RGBColor[
             0.4961881243257401, 0.601866898204728, 0.953480893225362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 204}], {
             RGBColor[
             0.5007635578511195, 0.6055814412615623, 0.9538410881128452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 219}], {
             RGBColor[
             0.5129514818808725, 0.6154761470486363, 0.9548005661383041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 244}], {
             RGBColor[
             0.42103754660959536`, 0.5378457039996745, 0.9483965938455836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 247}], {
             RGBColor[
             0.4973227229374232, 0.6027880164707773, 0.9535702129842454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 255}], {
             RGBColor[
             0.4486097951007969, 0.5617273998212495, 0.950153473138261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 274}], {
             RGBColor[
             0.4811841626563286, 0.5896860062007292, 0.9522997264014235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 334}], {
             RGBColor[
             0.4512190714580578, 0.563987423855866, 0.9503197339204532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 361}], {
             RGBColor[
             0.5719177559547599, 0.6633194007954346, 0.9594619041005235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 363}], {
             RGBColor[
             0.4522227109181607, 0.5648567259118211, 0.9503836849393674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 369}], {
             RGBColor[
             0.4597907440975337, 0.5714117758713864, 0.950865913321408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 370}], {
             RGBColor[
             0.5455387009707735, 0.6419319195433083, 0.9573659513959778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 425}], {
             RGBColor[
             0.4374884569477172, 0.5520946556877604, 0.9494448313053598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 466}], {
             RGBColor[
             0.5015711187466989, 0.6062370555767975, 0.9539046622647382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 188}], {
             RGBColor[
             0.32343001274534444`, 0.45456055380007726`, 0.9418296523075707]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 220}], {
             RGBColor[
             0.32424804297229537`, 0.4552690904672675, 0.9418817764702763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[
             0.2831042170303842, 0.4148134850118461, 0.939436571482416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 304}], {
             RGBColor[
             0.3240734635805927, 0.45511787857278996`, 0.9418706524258115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 310}], {
             RGBColor[
             0.3031699755874952, 0.4359038694979436, 0.9405792867476138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 429}], {
             RGBColor[
             0.30159042381675216`, 0.434243660437526, 0.9404893336110074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 173}], {
             RGBColor[
             0.8420436305365226, 0.8765386852966244, 0.9380905002853989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 222}], {
             RGBColor[
             0.5711190039988594, 0.6615355308329243, 0.9600580034664301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 241}], {
             RGBColor[
             0.7025032226254809, 0.7675201238280478, 0.9709826140315919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 402}], {
             RGBColor[
             0.6259177691187879, 0.7063115685381091, 0.9642924066530247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 417}], {
             RGBColor[
             0.7002784838355302, 0.7657821409766972, 0.9707608728603756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 461}], {
             RGBColor[
             0.8219899053555546, 0.8616442791794481, 0.9747961115925544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 179}], {
             RGBColor[
             0.17892806920489446`, 0.30539512380213557`, 0.933501060889637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 214}], {
             RGBColor[
             0.18936705810043614`, 0.31636716300147366`, 0.934095545864138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 226}], {
             RGBColor[
             0.17917599682249857`, 0.3056557114477564, 0.9335151800006836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 273}], {
             RGBColor[
             0.23623420851912813`, 0.365627509640484, 0.9367645607467467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 283}], {
             RGBColor[
             0.18007058028918088`, 0.3065959753911073, 0.9335661252056935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 292}], {
             RGBColor[
             0.1789488167630598, 0.30541693080123855`, 0.9335022424323813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 302}], {
             RGBColor[
             0.1845381798446758, 0.31129170578610466`, 0.9338205483911577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 308}], {
             RGBColor[
             0.17893664305769685`, 0.3054041354650445, 0.9335015491578702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 325}], {
             RGBColor[
             0.17897196085846667`, 0.30544125671293154`, 0.9335035604543761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 347}], {
             RGBColor[
             0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 386}], {
             RGBColor[
             0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 421}], {
             RGBColor[
             0.1789918035644768, 0.3054621126550484, 0.9335046904671287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 423}], {
             RGBColor[
             0.1833764464098977, 0.31007065028799885`, 0.9337543893906777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 446}], {
             RGBColor[
             0.20353913733189777`, 0.3312629168354616, 0.9349026248106573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 477}], {
             RGBColor[
             0.21179931439321417`, 0.33994488665237976`, 0.9353730296744625]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 279}], {
             RGBColor[
             0.2623939933592224, 0.3931231021335797, 0.9382543217934566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 494}], {
             RGBColor[
             0.25236564813326057`, 0.3825826754672824, 0.9376832223684453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 183}], {
             RGBColor[
             0.21281275410739692`, 0.3410100760477749, 0.9354307435669353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 286}], {
             RGBColor[
             0.22187921582518422`, 0.3505395021600439, 0.9359470651491353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 294}], {
             RGBColor[
             0.22948545468760678`, 0.35853414146784807`, 0.9363802291999281]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 346}], {
             RGBColor[
             0.21927041175810352`, 0.3477974836778107, 0.9357984976168947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 358}], {
             RGBColor[
             0.2231421897482483, 0.351866967830356, 0.9360189896456512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 404}], {
             RGBColor[
             0.2170532372191201, 0.345467092660354, 0.9356722328069155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 407}], {
             RGBColor[
             0.2175082544444818, 0.34594534461396753`, 0.9356981453647621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 408}], {
             RGBColor[
             0.2215813501340996, 0.35022642643293833`, 0.9359301021386808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 430}], {
             RGBColor[
             0.23019859628253192`, 0.35928369849990305`, 0.9364208415587607]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 201}], {
             RGBColor[
             0.28119600247616383`, 0.41288520583171645`, 0.9393250683975864]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 211}], {
             RGBColor[
             0.2444868180291041, 0.37430152548113294`, 0.9372345346496982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 271}], {
             RGBColor[
             0.25686927492861433`, 0.3873162727756304, 0.9379396972519218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 284}], {
             RGBColor[
             0.25151293220690424`, 0.3816864169633695, 0.9376346614579194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 312}], {
             RGBColor[
             0.28117238396624933`, 0.41286038128029634`, 0.9393237233583873]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 376}], {
             RGBColor[
             0.2686941653913333, 0.39974498239330636`, 0.9386131072704159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 400}], {
             RGBColor[
             0.276927529490606, 0.4083987700870767, 0.9390819851756989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 415}], {
             RGBColor[
             0.27247295826931617`, 0.4037167332973729, 0.9388283039345939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 442}], {
             RGBColor[
             0.2709392779878975, 0.40210473808065567`, 0.9387409631114438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 444}], {
             RGBColor[
             0.2646131387661169, 0.39545556465817117`, 0.9383806988414477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 464}], {
             RGBColor[
             0.25089999678857744`, 0.38104218297635795`, 0.9375997556926023]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 497}], {
             RGBColor[
             0.24696343657246012`, 0.3769046085968852, 0.9373755744119134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 171}], {
             RGBColor[
             0.2566176973332457, 0.3870518487719572, 0.9379253702800414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 216}], {
             RGBColor[
             0.2586895754643985, 0.38922952405245953`, 0.9380433606745415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 238}], {
             RGBColor[
             0.2858235449724231, 0.4166943062060351, 0.9396272193021288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 385}], {
             RGBColor[
             0.24248237828575928`, 0.37219473222205746`, 0.9371203847716176]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 391}], {
             RGBColor[
             0.24631019843469731`, 0.37621801389640636`, 0.9373383734663472]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 153}], {
             RGBColor[
             0.2422944032111111, 0.37199715850029413`, 0.9371096798692006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 190}], {
             RGBColor[
             0.2438827304039313, 0.37366659108570865`, 0.9372001327531121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 195}], {
             RGBColor[
             0.2549038837878154, 0.3852505220736551, 0.9378277711339891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 323}], {
             RGBColor[
             0.23950025424315785`, 0.36906033077569844`, 0.9369505572190486]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 342}], {
             RGBColor[
             0.2498214928286487, 0.3799086069333723, 0.9375383364875882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 351}], {
             RGBColor[
             0.26485064633186906`, 0.3957052001686261, 0.9383942245459564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 356}], {
             RGBColor[
             0.2544968866209464, 0.384822742246165, 0.9378045932474341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 452}], {
             RGBColor[
             0.23180463347080354`, 0.3609717454134156, 0.9365123030007138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 463}], {
             RGBColor[
             0.25337660171868737`, 0.3836452517837254, 0.9377407946795635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 158}], {
             RGBColor[
             0.3556980515257828, 0.48250950715290686`, 0.943885743205154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 165}], {
             RGBColor[
             0.3889540140770109, 0.511314150421502, 0.9460047837318252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 182}], {
             RGBColor[
             0.36623071660169665`, 0.4916323722545241, 0.9445568753101211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 187}], {
             RGBColor[
             0.30925143443909986`, 0.4382007802607746, 0.9410755580672832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 275}], {
             RGBColor[
             0.38378936730216673`, 0.5068407929678266, 0.9456756970062499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 282}], {
             RGBColor[
             0.48076658116172494`, 0.586646877963116, 0.9530129031646457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 324}], {
             RGBColor[
             0.361776111320833, 0.4877740170552114, 0.9442730318006773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 441}], {
             RGBColor[
             0.4020035872776604, 0.5226170348372846, 0.946836290996886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 159}], {
             RGBColor[
             0.821097410502475, 0.1631695188320622, 0.16783621016427433`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 233}], {
             RGBColor[
             0.832302226448087, 0.24929464417169217`, 0.1785659545678221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 267}], {
             RGBColor[
             0.9052536312416688, 0.5703031723537458, 0.2900897268509228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 406}], {
             RGBColor[
             0.9060315184464693, 0.5729271685521393, 0.29311167174990027`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 413}], {
             RGBColor[
             0.8976403406773998, 0.5446217555948332, 0.26051353065802335`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 443}], {
             RGBColor[
             0.8779783180841267, 0.47195372718941886`, 0.21716686938390278`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 476}], {
             RGBColor[
             0.834968541704233, 0.26978911161722496`, 0.18111922106827977`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 188}], {
             RGBColor[
             0.32203573450029344`, 0.4531724542663287, 0.9417474171352478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 192}], {
             RGBColor[
             0.28070448165153206`, 0.4123685862808082, 0.9392970770137636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 249}], {
             RGBColor[
             0.29817109629594896`, 0.43072710571942197`, 0.9402917748782225]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 260}], {
             RGBColor[
             0.2961853765948359, 0.4286399884116514, 0.940178691078853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 280}], {
             RGBColor[
             0.2818433506476452, 0.4135656098041881, 0.9393619339182866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 310}], {
             RGBColor[
             0.3017756973424442, 0.43451576996419494`, 0.9404970515752908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 327}], {
             RGBColor[
             0.28193174194509296`, 0.41365851466213766`, 0.939366967671913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 424}], {
             RGBColor[
             0.31369437792555, 0.4459475904500576, 0.9412159132702771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 483}], {
             RGBColor[
             0.3017217477257488, 0.43445906549644486`, 0.9404939792244313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 191}], {
             RGBColor[
             0.21120215837255008`, 0.3393172378127832, 0.9353390225224988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 212}], {
             RGBColor[
             0.21125959360220817`, 0.3393776058807578, 0.93534229337386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 287}], {
             RGBColor[
             0.20690732578417442`, 0.33480309645428663`, 0.9350944381602262]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 299}], {
             RGBColor[
             0.20658465608391344`, 0.3344639501408717, 0.9350760625981434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 301}], {
             RGBColor[
             0.2063778078751808, 0.33424653955855976`, 0.9350642828986606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 389}], {
             RGBColor[
             0.21125135912011495`, 0.33936895091798147`, 0.9353418244322866]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 451}], {
             RGBColor[
             0.20772437674817806`, 0.3356618688214776, 0.9351409680039076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 190}], {
             RGBColor[
             0.24652129125596123`, 0.3764398858356126, 0.9373503948902342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 195}], {
             RGBColor[
             0.2575424446398453, 0.3880238168235591, 0.9379780332711112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 263}], {
             RGBColor[
             0.25916680795964386`, 0.3897311256632503, 0.9380705383591434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 323}], {
             RGBColor[
             0.24213881509518778`, 0.3718336255256024, 0.9371008193561707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 342}], {
             RGBColor[
             0.25246005368067864`, 0.38268190168327626`, 0.9376885986247103]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 351}], {
             RGBColor[
             0.267489207183899, 0.39847849491853005`, 0.9385444866830785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[
             0.2571354474729763, 0.3875960369960689, 0.9379548553845563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 395}], {
             RGBColor[
             0.2549602684410159, 0.3853097859191623, 0.9378309821565751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 447}], {
             RGBColor[
             0.24571645560416666`, 0.3755939525360489, 0.9373045606905122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 452}], {
             RGBColor[
             0.2344431943228335, 0.36374504016331954`, 0.9366625651378359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 463}], {
             RGBColor[
             0.25601516257071727`, 0.38641854653362934`, 0.9378910568166856]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 174}], {
             RGBColor[
             0.2880991557381853, 0.4200673355937856, 0.9397208847641902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 229}], {
             RGBColor[
             0.3002585012900294, 0.4328475787158096, 0.940413341505228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 255}], {
             RGBColor[
             0.3535633647009796, 0.4806605487177418, 0.9437497228483069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 313}], {
             RGBColor[
             0.2882495492104231, 0.42022540866860447`, 0.9397294494499471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 338}], {
             RGBColor[
             0.314823265682197, 0.4471058220816644, 0.9412812379953546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 369}], {
             RGBColor[
             0.36474431369771637`, 0.4903449247678786, 0.944462163031454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 379}], {
             RGBColor[
             0.3094202014132221, 0.4424259593777846, 0.9409369595178776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 380}], {
             RGBColor[
             0.2911961325222311, 0.423322454553487, 0.9398972530104752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 390}], {
             RGBColor[
             0.30514733542854805`, 0.43798605336538, 0.9406917533770347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 425}], {
             RGBColor[
             0.3424420265478999, 0.47102780458425264`, 0.9430410810154058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 478}], {
             RGBColor[
             0.28779157321631055`, 0.419744046861437, 0.9397033683945971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 181}], {
             RGBColor[
             0.49329315877378277`, 0.5986309034651389, 0.9534977211263604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 235}], {
             RGBColor[
             0.4614654223098702, 0.5710633178486462, 0.9514696859030422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 262}], {
             RGBColor[
             0.520987467347936, 0.6220001220678183, 0.9554331883510561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 332}], {
             RGBColor[
             0.4840405870433834, 0.5906167908800439, 0.9529081554374272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 344}], {
             RGBColor[
             0.5148160505883743, 0.6169898879232494, 0.9549473518170989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 387}], {
             RGBColor[
             0.6705014636086952, 0.7413486854414358, 0.9685938847155504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 393}], {
             RGBColor[
             0.5135503027141461, 0.615962296777659, 0.9548477075078524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 403}], {
             RGBColor[
             0.7474005481861847, 0.8023032590432388, 0.9760248292713649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 232}], {
             RGBColor[
             0.4117533959329014, 0.5306819361106889, 0.9475625057353367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 307}], {
             RGBColor[
             0.4685593666518582, 0.5794366280637215, 0.9513058562137999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 350}], {
             RGBColor[
             0.41473957912155346`, 0.5332684178987681, 0.9477527826875395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 354}], {
             RGBColor[
             0.4145365045344412, 0.533092524898237, 0.9477398429544205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 372}], {
             RGBColor[
             0.46888111877498084`, 0.5796978409320405, 0.951331185719549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 479}], {
             RGBColor[
             0.4393999195807523, 0.5546279653397757, 0.9493241177753168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 180}], {
             RGBColor[
             0.2863372761085622, 0.4182890103949429, 0.9396178563251187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 216}], {
             RGBColor[
             0.28421479544229167`, 0.41605814864164575`, 0.9394969841911034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 238}], {
             RGBColor[
             0.31134876495031627`, 0.4435229307952213, 0.9410808428186908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 246}], {
             RGBColor[
             0.2983825090164457, 0.4309493138930047, 0.9403038145198976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 281}], {
             RGBColor[
             0.2737261355645935, 0.4050339020907391, 0.9388996705276503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 288}], {
             RGBColor[
             0.2793047597177943, 0.4108973897809534, 0.9392173649203402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 343}], {
             RGBColor[
             0.2977155588527831, 0.4302483069839126, 0.9402658326947413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 392}], {
             RGBColor[
             0.3042725009406671, 0.4371400688524187, 0.9406392408465198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 459}], {
             RGBColor[
             0.3465448636437761, 0.4740080224761397, 0.94332350710475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 465}], {
             RGBColor[
             0.2925845958094424, 0.42485533950351484`, 0.9399736319400027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 182}], {
             RGBColor[
             0.36805399542884243`, 0.4932116047339394, 0.9446730530247247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 206}], {
             RGBColor[
             0.3501277440364893, 0.4776847867774757, 0.9435308081375656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 282}], {
             RGBColor[
             0.4825898599888707, 0.5882261104425313, 0.9531290808792493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 324}], {
             RGBColor[
             0.3635993901479788, 0.48935324953462667`, 0.9443892095152808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 410}], {
             RGBColor[
             0.3605931713874897, 0.48674941394123933`, 0.9441976559141574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 441}], {
             RGBColor[
             0.4038268661048062, 0.5241962673166999, 0.9469524687114896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 164}], {
             RGBColor[
             0.819137437150352, 0.14810430478184575`, 0.1659593374688081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 396}], {
             RGBColor[
             0.9071481131704897, 0.5745522202562454, 0.3532052383412315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 443}], {
             RGBColor[
             0.877631072588452, 0.4692846461457165, 0.21683434670508697`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 165}], {
             RGBColor[
             0.4232575021072018, 0.5410261076098133, 0.9481905716557255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 268}], {
             RGBColor[
             0.41606826400089775`, 0.5347991509037464, 0.9477324797607855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 275}], {
             RGBColor[
             0.4180928553323577, 0.5365527501561378, 0.9478614849301503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 285}], {
             RGBColor[
             0.3684500451199806, 0.49355464307036695`, 0.9446982889608311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 324}], {
             RGBColor[
             0.3960795993510239, 0.5174859742435227, 0.9464588197245776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 353}], {
             RGBColor[
             0.531072144514868, 0.6293500407838779, 0.9564584330755022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 441}], {
             RGBColor[
             0.4363070753078513, 0.5523289920255958, 0.9490220789207864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 480}], {
             RGBColor[
             0.3880144919727734, 0.5105003835965654, 0.94594491821413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 481}], {
             RGBColor[
             0.3703492229848604, 0.49519961548147085`, 0.9448193028950042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 259}], {
             RGBColor[
             0.9260863286561598, 0.722291136783578, 0.31168537193130974`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 326}], {
             RGBColor[
             0.9327537347132191, 0.7525662704764362, 0.31724881897839763`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 341}], {
             RGBColor[
             0.9919526646253864, 0.9838559907810486, 0.4794106025405692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 387}], {
             RGBColor[
             0.8827228822801044, 0.901646814849579, 0.6975808353380122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 403}], {
             RGBColor[
             0.9596219668575938, 0.962601388451382, 0.7050117798938269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 405}], {
             RGBColor[
             0.9921723207517021, 0.9843258130245969, 0.5033188163295588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 450}], {
             RGBColor[
             0.9040202207813182, 0.5580851531997648, 0.2907664410126593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 469}], {
             RGBColor[
             0.9253813180460291, 0.7190898482623855, 0.3110970937968252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 491}], {
             RGBColor[
             0.992246695040947, 0.9844848921088973, 0.5114139987289448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 203}], {
             RGBColor[
             0.4982990262412239, 0.6035806234747654, 0.9536470711566374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 221}], {
             RGBColor[
             0.4993207487803075, 0.6044101038600693, 0.953727504897607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 223}], {
             RGBColor[
             0.4259476007932227, 0.5431195461878823, 0.9484273528030159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 258}], {
             RGBColor[
             0.4177269296537439, 0.5359992140298111, 0.9479035389072623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 289}], {
             RGBColor[
             0.45070123455015054`, 0.5645598995943251, 0.9500046324572284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 297}], {
             RGBColor[
             0.4906978130641887, 0.5974096161868968, 0.9530486758111798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 381}], {
             RGBColor[
             0.515668109442376, 0.6176816276857418, 0.9550144290112803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 439}], {
             RGBColor[
             0.6614719504889517, 0.7330346033014116, 0.9686938737233264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 187}], {
             RGBColor[
             0.2658102034815037, 0.3967137555723293, 0.9384488699060904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.2633838374698597, 0.39416349105360093`, 0.9383106919512142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 322}], {
             RGBColor[
             0.26310542995763675`, 0.3938708671061988, 0.9382948370552601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 364}], {
             RGBColor[
             0.2627794929075267, 0.39352828660093053`, 0.938276275422437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 437}], {
             RGBColor[
             0.26141138655191587`, 0.3920903200782306, 0.9381983637894169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 494}], {
             RGBColor[
             0.262747921993954, 0.39349510356905415`, 0.938274477505614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 166}], {
             RGBColor[
             0.8278225605966679, 0.21486196943559147`, 0.17427622148944416`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 227}], {
             RGBColor[
             0.8315779382096691, 0.24372744738608088`, 0.17787237533274636`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 309}], {
             RGBColor[
             0.9052777371288019, 0.5616050038337315, 0.3236174733815438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 348}], {
             RGBColor[
             0.8887181595032059, 0.5060713797566354, 0.23158979527643736`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 396}], {
             RGBColor[
             0.9055353853140414, 0.5621560872497313, 0.3516608883245811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 428}], {
             RGBColor[
             0.8239291026561835, 0.1849351455808791, 0.17054784176860438`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 443}], {
             RGBColor[
             0.8760183447320038, 0.45688851313920237`, 0.21528999668843654`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 182}], {
             RGBColor[
             0.4013099579800705, 0.5220162480025345, 0.9467920935513959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 268}], {
             RGBColor[
             0.4168440173490807, 0.5354710694634455, 0.9477819100781599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 275}], {
             RGBColor[
             0.41886860868054065`, 0.537224668715837, 0.9479109152475247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 282}], {
             RGBColor[
             0.5158458225400988, 0.6170307537111264, 0.9552481214059205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 285}], {
             RGBColor[
             0.3692257984681636, 0.49422656163006606`, 0.9447477192782054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 324}], {
             RGBColor[
             0.3968553526992069, 0.5181578928032218, 0.9465082500419522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 353}], {
             RGBColor[
             0.531847897863051, 0.630021959343577, 0.9565078633928767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 441}], {
             RGBColor[
             0.4370828286560343, 0.553000910585295, 0.9490715092381609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 481}], {
             RGBColor[
             0.3711249763330434, 0.49587153404117, 0.9448687332123786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 210}], {
             RGBColor[
             0.8370920629652436, 0.28611142656230293`, 0.18315270742599782`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 227}], {
             RGBColor[
             0.8418757895124331, 0.32288124504634075`, 0.18773360937003286`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 243}], {
             RGBColor[
             0.838713260625803, 0.29857266219470613`, 0.18470516813663024`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 309}], {
             RGBColor[
             0.9155755884315661, 0.6407588014939913, 0.33347870741883034`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 320}], {
             RGBColor[
             0.9133614547699682, 0.6417853106074096, 0.5113435478107814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 348}], {
             RGBColor[
             0.8990160108059699, 0.5852251774168952, 0.24145102931372386`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 428}], {
             RGBColor[
             0.8342269539589475, 0.26408894324113896`, 0.18040907580589088`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 495}], {
             RGBColor[
             0.8401614416386582, 0.3097040160564781, 0.18609194791002698`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 210}], {
             RGBColor[
             0.9113669843928855, 0.6334814540290358, 0.5263699322609554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 326}], {
             RGBColor[
             0.9309228830343801, 0.7574193985269815, 0.5440638154599668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 434}], {
             RGBColor[
             0.988936416573675, 0.989692938179159, 0.8330157392176978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 474}], {
             RGBColor[
             0.9898837045140847, 0.9900846660867081, 0.8173167265425048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 495}], {
             RGBColor[
             0.9144363630663, 0.657074043523211, 0.5293091727449846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 200}], {
             RGBColor[
             0.9058101136750496, 0.6632964389017137, 0.24302016366679569`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 213}], {
             RGBColor[
             0.9074990588325569, 0.6709655443987909, 0.2444294609060539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 254}], {
             RGBColor[
             0.5736452347236608, 0.5249664714796068, 0.591929563801219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 261}], {
             RGBColor[
             0.8953895182633258, 0.6159789489289689, 0.23432496342308617`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 315}], {
             RGBColor[
             0.5481459181329882, 0.49816507299275914`, 0.5904774154442385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 368}], {
             RGBColor[
             0.6594469349895435, 0.6059633899066202, 0.5971521921376893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 401}], {
             RGBColor[
             0.842122298838193, 0.7534870262743261, 0.6125668464325392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 500}], {
             RGBColor[
             0.8651424411448785, 0.41743131522220955`, 0.2066895157907081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 204}], {
             RGBColor[
             0.4973176178268257, 0.6027838719120118, 0.9535698110912385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 219}], {
             RGBColor[
             0.5095055418565787, 0.6126785776990856, 0.9545292891166974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 244}], {
             RGBColor[
             0.4175916065853016, 0.5350481346501237, 0.9481253168239769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 274}], {
             RGBColor[
             0.4777382226320348, 0.5868884368511786, 0.9520284493798168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 334}], {
             RGBColor[
             0.44777313143376407`, 0.5611898545063152, 0.9500484568988465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 337}], {
             RGBColor[
             0.6764764422213522, 0.7452210038115648, 0.9698692373870139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 340}], {
             RGBColor[
             0.41508837309382146`, 0.5328799596159772, 0.9479658129994224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 361}], {
             RGBColor[
             0.5684718159304661, 0.6605218314458838, 0.9591906270789168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 363}], {
             RGBColor[
             0.44877677089386697`, 0.5620591565622703, 0.9501124079177607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 370}], {
             RGBColor[
             0.5420927609464797, 0.6391343501937576, 0.9570946743743712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 498}], {
             RGBColor[
             0.4773158479045384, 0.5865455340196324, 0.9519951984940587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 171}], {
             RGBColor[
             0.2792113970027737, 0.4107992596479288, 0.9392120480518376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 238}], {
             RGBColor[
             0.3084172446419511, 0.44044171708200675`, 0.940913897073925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 265}], {
             RGBColor[
             0.3088475371272851, 0.4408144148056739, 0.9409413149305978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 266}], {
             RGBColor[
             0.29310065604108804`, 0.425397751527083, 0.9400030208067522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 328}], {
             RGBColor[
             0.3409967871765409, 0.4686604793300483, 0.9429898367152708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 374}], {
             RGBColor[
             0.2742054454433818, 0.40553768716334715`, 0.9389269665161719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 433}], {
             RGBColor[
             0.31109341012253816`, 0.4427596771133032, 0.9410844199719078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 216}], {
             RGBColor[
             0.26381410331866717`, 0.39461572774112796`, 0.9383351949547825]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 238}], {
             RGBColor[
             0.2909480728266918, 0.4220805098947036, 0.9399190535823698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 265}], {
             RGBColor[
             0.29137836531202577`, 0.42245320761837074`, 0.9399464714390425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 343}], {
             RGBColor[
             0.2773148667291586, 0.40880588608339485`, 0.9391040434584204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 385}], {
             RGBColor[
             0.24760690614002792`, 0.37758093591072595`, 0.9374122190518586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 391}], {
             RGBColor[
             0.25143472628896596`, 0.3816042175850748, 0.9376302077465881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 433}], {
             RGBColor[
             0.2936242383072788, 0.42439846992600005`, 0.9400895764803525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 465}], {
             RGBColor[
             0.27218390368581785`, 0.4034129186029971, 0.9388118427036817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 303}], {
             RGBColor[
             0.32845548787730483`, 0.4585909264869045, 0.9421616772940785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 366}], {
             RGBColor[
             0.3083293758751098, 0.43743710670339436`, 0.941015524989468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 448}], {
             RGBColor[
             0.45979588464643895`, 0.5695615806771241, 0.9513786855523698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 473}], {
             RGBColor[
             0.3392418574009336, 0.4682559789143286, 0.9428371690671595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 241}], {
             RGBColor[
             0.8450225482014433, 0.8788658384170731, 0.9383874109586698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 417}], {
             RGBColor[
             0.8427978094114925, 0.8771278555657226, 0.9381656697874536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 461}], {
             RGBColor[
             0.9645092309315171, 0.9729899937684735, 0.9422009085196323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 493}], {
             RGBColor[
             0.9890701085039466, 0.9882775676582451, 0.7238989830539463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 215}], {
             RGBColor[
             0.2753901052316153, 0.40678283971254936`, 0.9389944311385647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 229}], {
             RGBColor[
             0.2788164534778155, 0.4103841489623319, 0.9391895566023578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 294}], {
             RGBColor[
             0.2524849252558091, 0.3827080432856873, 0.9376900150241196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 338}], {
             RGBColor[
             0.29338121786998295`, 0.4246423923281867, 0.9400574530924843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 356}], {
             RGBColor[
             0.2679975194043914, 0.3990127632911238, 0.938573434312055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 390}], {
             RGBColor[
             0.28370528761633407`, 0.41552262361190234`, 0.9394679684741645]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 430}], {
             RGBColor[
             0.2531980668507343, 0.38345760031774234`, 0.9377306273829522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 309}], {
             RGBColor[
             0.9743805147039586, 0.9770030600582216, 0.7213206267986814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 320}], {
             RGBColor[
             0.9721663810423609, 0.9780295691716399, 0.8991854671906325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 337}], {
             RGBColor[
             0.9079704822927377, 0.9289384814961321, 0.9731750764283525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 348}], {
             RGBColor[
             0.9578209370783626, 0.9214694359811255, 0.6292929486935749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 361}], {
             RGBColor[
             0.7999658560018515, 0.8442393091304512, 0.9624964661202554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 370}], {
             RGBColor[
             0.7735868010178651, 0.822851827878325, 0.9604005134157099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 375}], {
             RGBColor[
             0.9569658514087618, 0.9674257829593813, 0.9577297678481509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 197}], {
             RGBColor[
             0.6522851143834272, 0.7277468526483104, 0.9663482548197164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 237}], {
             RGBColor[
             0.7565184993634433, 0.8098707472801487, 0.9765525722729846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 345}], {
             RGBColor[
             0.6333349002315553, 0.7129428013259062, 0.9644594745728776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 426}], {
             RGBColor[
             0.7385594994235554, 0.7955507282121491, 0.9748396268265297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 448}], {
             RGBColor[
             0.587441960125221, 0.6759508730452015, 0.9606647294533119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 245}], {
             RGBColor[
             0.21512971428686242`, 0.34344534810015337`, 0.9355626910215206]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 438}], {
             RGBColor[
             0.21508055771107348`, 0.3433936814222922, 0.9355598916272501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 455}], {
             RGBColor[
             0.2063185988388122, 0.33418430710726665`, 0.9350609110316312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 357}], {
             RGBColor[
             0.9494134599221778, 0.8301932628763469, 0.5158066666080678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 420}], {
             RGBColor[
             0.9801637329335828, 0.9834819259202605, 0.8627171585529716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 439}], {
             RGBColor[
             0.9262985601874452, 0.9413808299607197, 0.8870332114673454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 236}], {
             RGBColor[
             0.23312614698427564`, 0.36236073990487094`, 0.9365875612403018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 254}], {
             RGBColor[
             0.20771369325605188`, 0.33565063979388043`, 0.9351403595948358]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 276}], {
             RGBColor[
             0.39923464670294595`, 0.5037029404652202, 0.9483463693708659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 283}], {
             RGBColor[
             0.18007164814629245`, 0.3065970977766376, 0.9335661860185762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 292}], {
             RGBColor[
             0.17894988462017136`, 0.30541805318676885`, 0.9335023032452641]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 315}], {
             RGBColor[
             0.18221437666537932`, 0.3088492413070327, 0.9336882112378554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 325}], {
             RGBColor[
             0.1789730287155782, 0.30544237909846184`, 0.9335036212672588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 347}], {
             RGBColor[
             0.17892806853100302`, 0.30539512309383293`, 0.93350106085126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 368}], {
             RGBColor[
             0.2935153935219346, 0.41664755822089383`, 0.9403629879313062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 386}], {
             RGBColor[
             0.17892806853100302`, 0.30539512309383293`, 0.93350106085126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 401}], {
             RGBColor[
             0.47619075737058414`, 0.5641711945885997, 0.9557776422261561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 216}], {
             RGBColor[
             0.2680084621160904, 0.3990242647749275, 0.9385740574832979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 281}], {
             RGBColor[
             0.2575198022383923, 0.3880000182240208, 0.9379767438198447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 288}], {
             RGBColor[
             0.2630984263915931, 0.39386350591423513`, 0.9382944382125347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 343}], {
             RGBColor[
             0.28150922552658186`, 0.4132144231171943, 0.9393429059869358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 392}], {
             RGBColor[
             0.2880661676144659, 0.4201061849857004, 0.9397163141387143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 465}], {
             RGBColor[
             0.27637826248324115`, 0.40782145563679656`, 0.9390507052321971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 235}], {
             RGBColor[
             0.38886946031407776`, 0.511240914201845, 0.9459993960408191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 239}], {
             RGBColor[
             0.38581385669695734`, 0.5085943039277986, 0.9458046956803003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 262}], {
             RGBColor[
             0.4483915053521436, 0.5621777184210172, 0.9499628984888329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 296}], {
             RGBColor[
             0.3670585086059648, 0.49234936408258523`, 0.9446096214846453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 332}], {
             RGBColor[
             0.41144462504759094`, 0.5307943872332428, 0.947437865575204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 344}], {
             RGBColor[
             0.4422200885925819, 0.5571674842764482, 0.9494770619548758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 387}], {
             RGBColor[
             0.5979055016129029, 0.6815262817946347, 0.9631235948533272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 393}], {
             RGBColor[
             0.4409543407183537, 0.5561398931308579, 0.9493774176456293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 424}], {
             RGBColor[
             0.3706458143967508, 0.4954565080553325, 0.9448382014375043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 275}], {
             RGBColor[
             0.39614531120522645`, 0.517542890548859, 0.9464630068258206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 282}], {
             RGBColor[
             0.4931225250647846, 0.5973489755441486, 0.9538002129842165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 324}], {
             RGBColor[
             0.37413205522389265`, 0.49847611463624397`, 0.9450603416202481]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 441}], {
             RGBColor[
             0.41435953118072005`, 0.5333191324183171, 0.9476236008164568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 346}], {
             RGBColor[
             0.21142499907593382`, 0.3395514575209563, 0.9353517129708931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 404}], {
             RGBColor[
             0.20920782453695042`, 0.33722106650349953`, 0.9352254481609139]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 407}], {
             RGBColor[
             0.2096628417623121, 0.3376993184571131, 0.9352513607187605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 408}], {
             RGBColor[
             0.21373593745192992`, 0.3419804002760839, 0.9354833174926791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 192}], {
             RGBColor[
             0.25582325613433854`, 0.3862168407014245, 0.9378801280290341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 225}], {
             RGBColor[
             0.2656405828545585, 0.396535473538841, 0.9384392102623171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 249}], {
             RGBColor[
             0.2732898707787555, 0.40457536014003825`, 0.9388748258934928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 260}], {
             RGBColor[
             0.2713041510776424, 0.40248824283226764`, 0.9387617420941234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 280}], {
             RGBColor[
             0.2569621251304517, 0.38741386422480434`, 0.9379449849335569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 424}], {
             RGBColor[
             0.28881315240835653`, 0.41979584487067384`, 0.9397989642855475]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 440}], {
             RGBColor[
             0.26935285588816305`, 0.4004373078688641, 0.9386506187197652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 453}], {
             RGBColor[
             0.2706693526642461, 0.401821029451244, 0.9387255912635806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 470}], {
             RGBColor[
             0.2562569900664413, 0.3866727225643841, 0.9379048285348154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 193}], {
             RGBColor[
             0.28587823371129695`, 0.41780652773044813`, 0.9395917145396869]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 196}], {
             RGBColor[
             0.2898220421197416, 0.4219517204196188, 0.9398163085942062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 318}], {
             RGBColor[
             0.3129435362062064, 0.4431846498190406, 0.9412454229080396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 321}], {
             RGBColor[
             0.30856010126890854`, 0.43938793879419913`, 0.9409661143099544]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 330}], {
             RGBColor[
             0.29519715135054264`, 0.42760130102279975`, 0.9401224131131387]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 335}], {
             RGBColor[
             0.28035846079175497`, 0.4120048964181928, 0.9392773716376912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 350}], {
             RGBColor[
             0.3230573711356193, 0.45194474529877393`, 0.9418898675264287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 383}], {
             RGBColor[
             0.3064436349421723, 0.43755476203867083`, 0.9408312549471323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 409}], {
             RGBColor[
             0.262750205623448, 0.39349750380844273`, 0.9382746075549353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 482}], {
             RGBColor[
             0.32121309396000997`, 0.4503473251053272, 0.9417723518156291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 496}], {
             RGBColor[
             0.2804171463023576, 0.4120665786107125, 0.9392807136907027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 191}], {
             RGBColor[
             0.22705589567091367`, 0.35598052089836485`, 0.936241869408138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 202}], {
             RGBColor[
             0.2373837352876954, 0.3668357351584549, 0.9368300245956442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 212}], {
             RGBColor[
             0.22711333090057176`, 0.3560408889663394, 0.9362451402594992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 295}], {
             RGBColor[
             0.23264914651192115`, 0.36185938216484964`, 0.9365603967690603]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 300}], {
             RGBColor[
             0.23083402862066274`, 0.35995157817601575`, 0.9364570284903794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 389}], {
             RGBColor[
             0.22710509641847854`, 0.3560322340035631, 0.9362446713179258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 414}], {
             RGBColor[
             0.255184189019674, 0.3855451406447167, 0.937843734102269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 456}], {
             RGBColor[
             0.22968446940414386`, 0.35874331855319036`, 0.9363915627936191]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 485}], {
             RGBColor[
             0.24185580045044375`, 0.3715361591898116, 0.9370847020908353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 322}], {
             RGBColor[
             0.2619233226556958, 0.392628397381927, 0.9382275177931856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 494}], {
             RGBColor[
             0.26156581469201307`, 0.3922526338447824, 0.9382071582435395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 304}], {
             RGBColor[
             0.33792059600024626`, 0.4671115686975821, 0.9427529794590535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 310}], {
             RGBColor[
             0.3170171080071488, 0.4478975596227356, 0.9414616137808558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 483}], {
             RGBColor[
             0.31696315839045336`, 0.4478408551549855, 0.9414585414299963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 266}], {
             RGBColor[
             0.2746480537102089, 0.4060028965147674, 0.9389521724021874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 364}], {
             RGBColor[
             0.25917101959394173`, 0.3897355523579304, 0.9380707782054862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 374}], {
             RGBColor[
             0.2557528431125027, 0.3861428321510315, 0.9378761181116072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 437}], {
             RGBColor[
             0.25780291323833093`, 0.38829758583523044`, 0.9379928665724662]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 195}], {
             RGBColor[
             0.25913077183266553`, 0.38969324940897365`, 0.9380684861550228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 224}], {
             RGBColor[
             0.2735379552710175, 0.40483611267087094`, 0.938888953938319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 263}], {
             RGBColor[
             0.26075513515246407`, 0.3914005582486648, 0.9381609912430551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 323}], {
             RGBColor[
             0.243727142288008, 0.373503058111017, 0.9371912722400824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 342}], {
             RGBColor[
             0.25404838087349885`, 0.38435133426869084`, 0.9377790515086218]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 351}], {
             RGBColor[
             0.2690775343767192, 0.40014792750394457`, 0.9386349395669901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 356}], {
             RGBColor[
             0.2587237746657965, 0.38926546958148345`, 0.9380453082684679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 395}], {
             RGBColor[
             0.2565485956338361, 0.38697921850457684`, 0.9379214350404868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 452}], {
             RGBColor[
             0.2360315215156537, 0.3654144727487341, 0.9367530180217474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 463}], {
             RGBColor[
             0.2576034897635375, 0.3880879791190439, 0.9379815097005972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 212}], {
             RGBColor[
             0.21845881642544385`, 0.3469444455250692, 0.9357522784633475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 218}], {
             RGBColor[
             0.2251871593264507, 0.3540163605156067, 0.9361354476378685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 287}], {
             RGBColor[
             0.21410654860741013`, 0.342369936098598, 0.9355044232497137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 295}], {
             RGBColor[
             0.22399463203679326`, 0.35276293872357944`, 0.9360675349729086]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 299}], {
             RGBColor[
             0.21378387890714912`, 0.3420307897851831, 0.935486047687631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 300}], {
             RGBColor[
             0.22217951414553483`, 0.3508551347347456, 0.9359641666942277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 301}], {
             RGBColor[
             0.2135770306984165, 0.34181337920287114`, 0.935474267988148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 389}], {
             RGBColor[
             0.21845058194335062`, 0.3469357905622929, 0.9357518095217741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 451}], {
             RGBColor[
             0.21492359957141377`, 0.343228708465789, 0.9355509530933952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 456}], {
             RGBColor[
             0.22102995492901595`, 0.34964687511192016`, 0.9358987009974674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[
             0.26443196618769516`, 0.395265140791245, 0.9383703813311275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 249}], {
             RGBColor[
             0.27208125411189216`, 0.40330502739244223`, 0.938805996962303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 260}], {
             RGBColor[
             0.27009553441077905`, 0.4012179100846716, 0.9386929131629338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 280}], {
             RGBColor[
             0.25575350846358835`, 0.3861435314772083, 0.9378761560023672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 327}], {
             RGBColor[
             0.25584189976103616`, 0.38623643633515786`, 0.9378811897559938]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 470}], {
             RGBColor[
             0.255048373399578, 0.3854023898167881, 0.9378359996036256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 483}], {
             RGBColor[
             0.275631905541692, 0.4070369871694651, 0.9390082013085121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 196}], {
             RGBColor[
             0.29175552637074975`, 0.4239839349574104, 0.9399264176619675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 202}], {
             RGBColor[
             0.2634343891958272, 0.39421662412275726`, 0.9383135707972234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 232}], {
             RGBColor[
             0.32200467219797546`, 0.4513904780484862, 0.9418096996419872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 330}], {
             RGBColor[
             0.2971306356015508, 0.42963351556059126`, 0.9402325221809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 350}], {
             RGBColor[
             0.3249908553866274, 0.4539769598365655, 0.94199997659419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 354}], {
             RGBColor[
             0.3247877807995152, 0.4538010668360344, 0.941987036861071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 376}], {
             RGBColor[
             0.2836334092052663, 0.4154470748445156, 0.9394638751049887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 414}], {
             RGBColor[
             0.28123484292780576`, 0.41292602960901903`, 0.9393272803038482]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 415}], {
             RGBColor[
             0.28741220208324925`, 0.41941882574858214`, 0.9396790717691668]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 485}], {
             RGBColor[
             0.2679064543585755, 0.3989170481541139, 0.9385682482924145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 496}], {
             RGBColor[
             0.28235063055336573`, 0.41409879314850406`, 0.939390822758464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 228}], {
             RGBColor[
             0.9897986964683487, 0.9881510016226367, 0.6807237889593197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 388}], {
             RGBColor[
             0.9663440953419832, 0.9740339462184904, 0.9245637966956991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 490}], {
             RGBColor[
             0.9885348242076832, 0.9895268694153684, 0.8396711640099095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 224}], {
             RGBColor[
             0.28455910865490164`, 0.41642004365881735`, 0.9395165923191959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 263}], {
             RGBColor[
             0.27177628853634817`, 0.40298448923661123`, 0.9387886296239321]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 296}], {
             RGBColor[
             0.29178587282524443`, 0.4235837043718764, 0.9399439681205266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 323}], {
             RGBColor[
             0.2547482956718921, 0.38508698909896344`, 0.9378189106209592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 342}], {
             RGBColor[
             0.265069534257383, 0.39593526525663725`, 0.9384066898894987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 351}], {
             RGBColor[
             0.2800986877606033, 0.41173185849189103`, 0.9392625779478669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 395}], {
             RGBColor[
             0.26756974901772024`, 0.3985631494925233, 0.9385490734213637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 447}], {
             RGBColor[
             0.25832593618087096`, 0.38884731610940987`, 0.9380226519553008]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 453}], {
             RGBColor[
             0.27722937887191995`, 0.40871603292519376`, 0.9390991750514186]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 463}], {
             RGBColor[
             0.2686246431474216, 0.3996719101069903, 0.9386091480814742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 318}], {
             RGBColor[
             0.3188208288656592, 0.44936205704600285`, 0.9415801260303202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 321}], {
             RGBColor[
             0.31443739392836134`, 0.4455653460211614, 0.9413008174322348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 330}], {
             RGBColor[
             0.3010744440099954, 0.433778708249762, 0.9404571162354194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 335}], {
             RGBColor[
             0.2862357534512077, 0.4181823036451551, 0.9396120747599719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 350}], {
             RGBColor[
             0.3289346637950721, 0.4581221525257362, 0.9422245706487093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 354}], {
             RGBColor[
             0.32873158920795986`, 0.45794625952520507`, 0.9422116309155903]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 383}], {
             RGBColor[
             0.3123209276016251, 0.4437321692656331, 0.941165958069413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 414}], {
             RGBColor[
             0.2851786513362504, 0.4170712222981897, 0.9395518743583675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 479}], {
             RGBColor[
             0.35359500425427093`, 0.4794816999667437, 0.9437959057364866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 482}], {
             RGBColor[
             0.3270903866194627, 0.45652473233228946`, 0.9421070549379097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 496}], {
             RGBColor[
             0.2862944389618104, 0.41824398583767475`, 0.9396154168129832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 237}], {
             RGBColor[
             0.8018590077882369, 0.845833600411511, 0.9807007779188375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 270}], {
             RGBColor[
             0.843824355466433, 0.8769260052856713, 0.8927516199339326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 345}], {
             RGBColor[
             0.6786754086563489, 0.7489056544572683, 0.9686076802187304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 375}], {
             RGBColor[
             0.8279135305907634, 0.8660284937370616, 0.9630673509377192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 426}], {
             RGBColor[
             0.7839000078483491, 0.8315135813435113, 0.9789878324723824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 448}], {
             RGBColor[
             0.6327824685500147, 0.7119137261765637, 0.9648129350991647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 489}], {
             RGBColor[
             0.843861608566709, 0.8769414103999965, 0.8921342396544271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 223}], {
             RGBColor[
             0.335871613441881, 0.4628528461466326, 0.9427133713948876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 373}], {
             RGBColor[
             0.28774746699468884`, 0.4197712104275283, 0.9396981646098933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 480}], {
             RGBColor[
             0.3177133386514768, 0.44712506118461215`, 0.9415563421819749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 208}], {
             RGBColor[
             0.33248120157791744`, 0.46240023864087376`, 0.9424063860563303]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 220}], {
             RGBColor[
             0.3408785418830542, 0.4696735927505875, 0.9429414571550971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 349}], {
             RGBColor[
             0.3782226741008029, 0.5020192031069408, 0.9453209922378925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 359}], {
             RGBColor[
             0.364147570424561, 0.48982805573786037`, 0.9444241390777679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 371}], {
             RGBColor[
             0.3528938984406201, 0.480080690691371, 0.9437070650501826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 382}], {
             RGBColor[
             0.31253428709090747`, 0.4426711481132517, 0.9412251688089472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 397}], {
             RGBColor[
             0.3506959657134314, 0.47817695183439113`, 0.9435670147203616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 419}], {
             RGBColor[
             0.4277672068152066, 0.5433200836247167, 0.948923355062986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 427}], {
             RGBColor[
             0.31117200287913815`, 0.44123930103287445`, 0.9411475887384059]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 429}], {
             RGBColor[
             0.318220922727511, 0.44864816272084596`, 0.9415490142958283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 213}], {
             RGBColor[
             0.9025169525103827, 0.6502340737413859, 0.24037009445756363`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 243}], {
             RGBColor[
             0.8700670583525245, 0.4728472627689348, 0.21211683898241762`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 254}], {
             RGBColor[
             0.5686631284014866, 0.5042350008222019, 0.5878701973527287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 259}], {
             RGBColor[
             0.8813343532764009, 0.5540488379416193, 0.22269481442370878`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 401}], {
             RGBColor[
             0.8371401925160188, 0.7327555556169211, 0.6085074799840489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 450}], {
             RGBColor[
             0.8592682454015592, 0.38984285435780597`, 0.20177588350505832`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 454}], {
             RGBColor[
             0.9003552167733437, 0.640418136645701, 0.2385662891695866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 469}], {
             RGBColor[
             0.8806293426662699, 0.5508475494204266, 0.22210653628922422`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 471}], {
             RGBColor[
             0.8788202951923778, 0.5401284768128874, 0.22049894846562806`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 475}], {
             RGBColor[
             0.8699156991968737, 0.47168384997259694`, 0.2119718972840306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 500}], {
             RGBColor[
             0.8601603348227043, 0.3966998445648045, 0.2026301493422178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 222}], {
             RGBColor[
             0.3735862388275236, 0.49760697262793063`, 0.9450400762157048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 246}], {
             RGBColor[
             0.2993400916080083, 0.43195579391098005`, 0.9403583474318706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 256}], {
             RGBColor[
             0.2969224563599441, 0.4294147059783363, 0.9402206666810642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 271}], {
             RGBColor[
             0.2801320470703391, 0.4117669212415258, 0.9392644777112058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 312}], {
             RGBColor[
             0.30443515610797417`, 0.4373110297461917, 0.9406485038176712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 333}], {
             RGBColor[
             0.34155395478950024`, 0.4698622181836031, 0.9429990074018386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 400}], {
             RGBColor[
             0.30019030163233085`, 0.432849418552972, 0.9404067656349827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 442}], {
             RGBColor[
             0.2942020501296223, 0.426555386546551, 0.9400657435707277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 444}], {
             RGBColor[
             0.2878759109078417, 0.4199062131240665, 0.9397054793007316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 492}], {
             RGBColor[
             0.29053904388296076`, 0.4227053347332997, 0.9398571407839125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 211}], {
             RGBColor[
             0.2350487330765592, 0.3643814997868598, 0.9366970496740461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 414}], {
             RGBColor[
             0.25685751416132785`, 0.38730391146353665`, 0.9379390274936235]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 485}], {
             RGBColor[
             0.2435291255920976, 0.37329493000863156`, 0.9371799954821897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 497}], {
             RGBColor[
             0.23752535161991525`, 0.36698458290261204`, 0.9368380894362616]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 221}], {
             RGBColor[
             0.5355883582024223, 0.6338537830261275, 0.9565826239639467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 258}], {
             RGBColor[
             0.45399453907585874`, 0.5654428931958693, 0.950758657973602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 289}], {
             RGBColor[
             0.48696884397226536`, 0.5940035787603833, 0.9528597515235682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 291}], {
             RGBColor[
             0.5947468881404891, 0.681688814806365, 0.9613714325118958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 297}], {
             RGBColor[
             0.5269654224863035, 0.6268532953529551, 0.9559037948775195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 381}], {
             RGBColor[
             0.5519357188644908, 0.6471253068518, 0.9578695480776199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 397}], {
             RGBColor[
             0.44655734447149653`, 0.5590011690338403, 0.950284766509865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 419}], {
             RGBColor[
             0.5236285855732716, 0.6241443008241659, 0.9556411068524893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 439}], {
             RGBColor[
             0.6977395599110665, 0.7624782824674698, 0.971548992789666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 219}], {
             RGBColor[
             0.5140809753819581, 0.6163931207559199, 0.9548894840041806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 244}], {
             RGBColor[
             0.42216704011068096`, 0.5387626777069581, 0.9484855117114601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 274}], {
             RGBColor[
             0.4823136561574142, 0.5906029799080129, 0.9523886442672999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 334}], {
             RGBColor[
             0.4523485649591434, 0.5649043975631496, 0.9504086517863296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 337}], {
             RGBColor[
             0.6810518757467315, 0.7489355468683991, 0.970229432274497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 340}], {
             RGBColor[
             0.4196638066192008, 0.5365945026728116, 0.9483260078869054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 361}], {
             RGBColor[
             0.5730472494558454, 0.6642363745027182, 0.9595508219663998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 362}], {
             RGBColor[
             0.4451772959687064, 0.5586930048020928, 0.9499517048675632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 363}], {
             RGBColor[
             0.4533522044192463, 0.5657736996191047, 0.9504726028052438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 370}], {
             RGBColor[
             0.546668194471859, 0.642848893250592, 0.9574548692618543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 498}], {
             RGBColor[
             0.4818912814299178, 0.5902600770764668, 0.9523553933815417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 228}], {
             RGBColor[
             0.9934539331599859, 0.9884069498751192, 0.5288792059852668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 252}], {
             RGBColor[
             0.8648112867502258, 0.89136633503373, 0.7718692919288858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 388}], {
             RGBColor[
             0.9699993320336204, 0.9742898944709728, 0.7727192137216462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 432}], {
             RGBColor[
             0.9462255159241673, 0.9556033712696023, 0.7798152269955922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 490}], {
             RGBColor[
             0.9921900608993205, 0.9897828176678509, 0.6878265810358566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 266}], {
             RGBColor[
             0.31612745049209645`, 0.4464579350707817, 0.9414294227127427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 410}], {
             RGBColor[
             0.35319958507105037`, 0.4803454610863929, 0.9437265431319655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 218}], {
             RGBColor[
             0.22451796602725682`, 0.35331299592884813`, 0.9360973380694622]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 287}], {
             RGBColor[
             0.21343735530821623`, 0.3416665715118395, 0.9354663136813074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 295}], {
             RGBColor[
             0.22332543873759936`, 0.352059574136821, 0.9360294254045023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 336}], {
             RGBColor[
             0.2196507706490151, 0.34819726498830533`, 0.9358201584930417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 389}], {
             RGBColor[
             0.21778138864415675`, 0.3462324259755344, 0.9357136999533677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 409}], {
             RGBColor[
             0.22930932819200256`, 0.35834902135390323`, 0.9363701990565594]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 456}], {
             RGBColor[
             0.2203607616298221, 0.3489435105251617, 0.9358605914290611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 458}], {
             RGBColor[
             0.22378112515977486`, 0.35253852945871533`, 0.9360553760721175]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[
             0.3477704837485026, 0.4756430463953687, 0.9433806055964585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 289}], {
             RGBColor[
             0.3807447886449092, 0.5042037319598828, 0.9454816991464247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 314}], {
             RGBColor[
             0.32609699892407057`, 0.4568705631814669, 0.9419995903085558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 349}], {
             RGBColor[
             0.3678599975315118, 0.49304357350588934`, 0.9446606916502523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 359}], {
             RGBColor[
             0.3537848938552699, 0.480852426136809, 0.9437638384901277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 397}], {
             RGBColor[
             0.3403332891441403, 0.46920132223333977`, 0.9429067141327215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 427}], {
             RGBColor[
             0.3008093263098471, 0.4322636714318231, 0.9404872881507658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 472}], {
             RGBColor[
             0.32528262084800263`, 0.45616518982380916`, 0.9419476988576752]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 214}], {
             RGBColor[
             0.3828653435329973, 0.49291080046599856`, 0.946830407391962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 233}], {
             RGBColor[
             0.7045416845554648, 0.49561598240663746`, 0.5739669497124782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 273}], {
             RGBColor[
             0.4297324939516893, 0.5421711471050089, 0.9494994222745707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 421}], {
             RGBColor[
             0.37249008899703795`, 0.4820057501195733, 0.9462395519949527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 423}], {
             RGBColor[
             0.37687473184245884`, 0.48661428775252374`, 0.9464892509185017]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 477}], {
             RGBColor[
             0.40529759982577535`, 0.5164885241169046, 0.9481078912022864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 227}], {
             RGBColor[
             0.8408474405782448, 0.3149769045127923, 0.18674886126930004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 243}], {
             RGBColor[
             0.8376849116916145, 0.29066832166115775`, 0.18372042003589745`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 326}], {
             RGBColor[
             0.8556196126725499, 0.40214503052670025`, 0.19986184252427644`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 348}], {
             RGBColor[
             0.8979876618717816, 0.5773208368833467, 0.24046628121299102`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 428}], {
             RGBColor[
             0.8331986050247592, 0.2561846027075905, 0.17942432770515804`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 434}], {
             RGBColor[
             0.9136331462118448, 0.6344185701788778, 0.48881376628200723`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 469}], {
             RGBColor[
             0.8482471960053599, 0.3686686083126496, 0.19371011734270402`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 474}], {
             RGBColor[
             0.9145804341522545, 0.6348102980864267, 0.4731147536068143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 495}], {
             RGBColor[
             0.8391330927044698, 0.3017996755229297, 0.18510719980929416`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 464}], {
             RGBColor[
             0.23745358448324252`, 0.36690915109166977`, 0.936834002403998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 485}], {
             RGBColor[
             0.23952079823930758`, 0.3690819238182165, 0.9369517271692371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 497}], {
             RGBColor[
             0.23351702426712523`, 0.36277157671219695`, 0.936609821123309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 287}], {
             RGBColor[
             0.21416398383706822`, 0.3424303041665726, 0.9355076941010749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 295}], {
             RGBColor[
             0.22405206726645135`, 0.35282330679155405`, 0.9360708058242697]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 299}], {
             RGBColor[
             0.21384131413680724`, 0.3420911578531577, 0.9354893185389921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 300}], {
             RGBColor[
             0.22223694937519295`, 0.35091550280272016`, 0.9359674375455889]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 301}], {
             RGBColor[
             0.2136344659280746, 0.34187374727084574`, 0.9354775388395093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 389}], {
             RGBColor[
             0.21850801717300872`, 0.34699615863026745`, 0.9357550803731354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 451}], {
             RGBColor[
             0.21498103480107186`, 0.34328907653376356`, 0.9355542239447563]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 456}], {
             RGBColor[
             0.22108739015867407`, 0.34970724317989477`, 0.9359019718488286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 254}], {
             RGBColor[
             0.5703520735589939, 0.511904106319279, 0.5892794945919869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 259}], {
             RGBColor[
             0.8830232984339081, 0.5617179434386964, 0.224104111662967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 261}], {
             RGBColor[
             0.8920963570986589, 0.602916583768641, 0.23167489421385412`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 315}], {
             RGBColor[
             0.5448527569683213, 0.48510270783243126`, 0.5878273462350064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 368}], {
             RGBColor[
             0.6561537738248766, 0.5929010247462924, 0.5945021229284573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 401}], {
             RGBColor[
             0.8388291376735261, 0.7404246611139982, 0.6099167772233072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 450}], {
             RGBColor[
             0.8609571905590665, 0.3975119598548832, 0.20318518074431657`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 454}], {
             RGBColor[
             0.902044161930851, 0.6480872421427781, 0.23997558640884487`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 471}], {
             RGBColor[
             0.8805092403498851, 0.5477975823099646, 0.2219082457048863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 475}], {
             RGBColor[
             0.871604644354381, 0.4793529554696741, 0.21338119452328883`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 500}], {
             RGBColor[
             0.8618492799802115, 0.40436895006188167`, 0.20403944658147605`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 273}], {
             RGBColor[
             0.24667426527178135`, 0.3766006712253524, 0.9373591065341305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 302}], {
             RGBColor[
             0.19497823659732902`, 0.32226486737097304`, 0.9344150941785414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 347}], {
             RGBColor[
             0.1893670574265447, 0.316367162293171, 0.9340955458257609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 421}], {
             RGBColor[
             0.18943186031713002`, 0.3164352742399168, 0.9340992362545124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 423}], {
             RGBColor[
             0.19381650316255092`, 0.32104381187286724`, 0.9343489351780614]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 477}], {
             RGBColor[
             0.2222393711458674, 0.35091804823724815`, 0.9359675754618462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 224}], {
             RGBColor[
             0.2915446973152564, 0.4237623402527527, 0.9399144112591507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 351}], {
             RGBColor[
             0.28708427642095813`, 0.4190741550858264, 0.9396603968878219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 356}], {
             RGBColor[
             0.2767305167100354, 0.40819169716336523`, 0.9390707655892996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 430}], {
             RGBColor[
             0.26193106415637823`, 0.3926365341899838, 0.9382279586601969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 238}], {
             RGBColor[
             0.29301995095784455`, 0.42425818517520597`, 0.9400370439768699]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 281}], {
             RGBColor[
             0.2553973215721218, 0.3857691564707237, 0.9378558716858294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 343}], {
             RGBColor[
             0.2793867448603114, 0.4109835613638972, 0.9392220338529205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 465}], {
             RGBColor[
             0.27425578181697063`, 0.40559059388349944`, 0.9389298330981818]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 290}], {
             RGBColor[
             0.3031025001174864, 0.43489572471311266`, 0.9406097604733883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 340}], {
             RGBColor[
             0.32857716094804046`, 0.4590187548700618, 0.9421576240396021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 355}], {
             RGBColor[
             0.32421328138501737`, 0.4552389817275355, 0.9418795614926734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 362}], {
             RGBColor[
             0.35409065029754605`, 0.481117256999343, 0.9437833210202597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 378}], {
             RGBColor[
             0.30140209308183147`, 0.4331084891066064, 0.9405129248082346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 384}], {
             RGBColor[
             0.30177027996931804`, 0.4334954768697517, 0.9405338925067932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 498}], {
             RGBColor[
             0.3908046357587574, 0.5126843292737169, 0.9461870095342384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 295}], {
             RGBColor[
             0.2307804101674582, 0.3598952217820915, 0.9364539749987908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.22896529227619977`, 0.3579874177932576, 0.93635060672011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 336}], {
             RGBColor[
             0.2271057420788739, 0.35603291263357584`, 0.9362447080873302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 389}], {
             RGBColor[
             0.22523636007401557`, 0.35406807362080495`, 0.9361382495476563]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 409}], {
             RGBColor[
             0.2367642996218614, 0.3661846689991738, 0.9367947486508479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 456}], {
             RGBColor[
             0.2278157330596809, 0.3567791581704322, 0.9362851410233497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 458}], {
             RGBColor[
             0.23123609658963368`, 0.36037417710398584`, 0.936479925666406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 244}], {
             RGBColor[
             0.43435496414043395`, 0.548657383494032, 0.949444989736919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 274}], {
             RGBColor[
             0.49450158018716717`, 0.6004976856950868, 0.9533481222927589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 334}], {
             RGBColor[
             0.4645364889888964, 0.5747991033502236, 0.9513681298117886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 337}], {
             RGBColor[
             0.6932397997764845, 0.7588302526554731, 0.971188910299956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 340}], {
             RGBColor[
             0.43185173064895377`, 0.5464892084598855, 0.9492854859123644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 361}], {
             RGBColor[
             0.5852351734855985, 0.6741310802897922, 0.9605102999918589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 363}], {
             RGBColor[
             0.4655401284489993, 0.5756684054061787, 0.9514320808307029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 369}], {
             RGBColor[
             0.47310816162837227`, 0.5822234553657439, 0.9519143092127434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 370}], {
             RGBColor[
             0.5588561185016121, 0.6527435990376659, 0.9584143472873132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 498}], {
             RGBColor[
             0.49407920545967077`, 0.6001547828635406, 0.9533148714070008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 349}], {
             RGBColor[
             0.3762573378366486, 0.5003169276156031, 0.9451957627490192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 359}], {
             RGBColor[
             0.3621822341604067, 0.48812578024652276`, 0.9442989095888945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 371}], {
             RGBColor[
             0.3509285621764658, 0.4783784152000333, 0.9435818355613093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 382}], {
             RGBColor[
             0.3105689508267532, 0.4409688726219141, 0.9410999393200739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 416}], {
             RGBColor[
             0.3002234451567067, 0.4300950902197503, 0.9405107780769688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 427}], {
             RGBColor[
             0.30920666661498386`, 0.43953702554153684`, 0.9410223592495326]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 429}], {
             RGBColor[
             0.3162555864633567, 0.44694588722950834`, 0.9414237848069549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 499}], {
             RGBColor[
             0.2998159216660946, 0.42966675719263536`, 0.9404875702170554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 223}], {
             RGBColor[
             0.46323693275442124`, 0.5733927057392445, 0.9513629056103252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 258}], {
             RGBColor[
             0.45501626161494246`, 0.5662723735811732, 0.9508390917145717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 297}], {
             RGBColor[
             0.5279871450253872, 0.627682775738259, 0.9559842286184892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 381}], {
             RGBColor[
             0.5529574414035745, 0.647954787237104, 0.9579499818185896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 439}], {
             RGBColor[
             0.6987612824501502, 0.7633077628527738, 0.9716294265306357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 307}], {
             RGBColor[
             0.456261635454359, 0.5691648443465238, 0.950417290103996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 333}], {
             RGBColor[
             0.41068141899913524`, 0.5301333365139219, 0.9473892347606732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 372}], {
             RGBColor[
             0.4565833875774816, 0.5694260572148426, 0.9504426196097452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 417}], {
             RGBColor[
             0.5718731828738293, 0.6621247011020224, 0.9601331729684849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 258}], {
             RGBColor[
             0.3816431136278576, 0.5049818159089863, 0.9455389396199805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 268}], {
             RGBColor[
             0.3997592820050565, 0.5206731304122181, 0.946693285849477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 373}], {
             RGBColor[
             0.3417396383201442, 0.4690205123479532, 0.9430475467307398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 381}], {
             RGBColor[
             0.47958429341648956`, 0.5866642295649169, 0.9526498297239985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 480}], {
             RGBColor[
             0.3717055099769321, 0.496374363105037, 0.9449057243028214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 263}], {
             RGBColor[
             0.2861834719747001, 0.4181273524985085, 0.9396090974072282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 342}], {
             RGBColor[
             0.2794767176957349, 0.41107812851853454`, 0.939227157672795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 351}], {
             RGBColor[
             0.29450587119895527`, 0.4268747217537883, 0.9400830457311632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 356}], {
             RGBColor[
             0.28415211148803254`, 0.41599226383132715`, 0.939493414432641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 463}], {
             RGBColor[
             0.2830318265857735, 0.4148147733688876, 0.9394296158647704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 235}], {
             RGBColor[
             0.31564550837904015`, 0.44462855110700683`, 0.9414504121909557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 249}], {
             RGBColor[
             0.28189858083211217`, 0.41362366022985875`, 0.9393650791955862]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 260}], {
             RGBColor[
             0.27991286113099906`, 0.41153654292208813`, 0.9392519953962168]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 280}], {
             RGBColor[
             0.26557083518380836`, 0.39646216431462483`, 0.9384352382356503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 296}], {
             RGBColor[
             0.29383455667092717`, 0.42573700098774714`, 0.940060637634782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 424}], {
             RGBColor[
             0.2974218624617132, 0.42884414496049433`, 0.940289217587641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 440}], {
             RGBColor[
             0.27796156594151966`, 0.4094856079586846, 0.9391408720218586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 453}], {
             RGBColor[
             0.2792780627176027, 0.4108693295410645, 0.939215844565674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 470}], {
             RGBColor[
             0.26486570011979793`, 0.3957210226542046, 0.9383950818369088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 236}], {
             RGBColor[
             0.23337407460187973`, 0.3626213275504917, 0.9366016803513484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 283}], {
             RGBColor[
             0.18031957576389654`, 0.30685768542225833`, 0.9335803051296228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 292}], {
             RGBColor[
             0.17919781223777545`, 0.3056786408323896, 0.9335164223563106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 308}], {
             RGBColor[
             0.17918563853241248`, 0.3056658454961956, 0.9335157290817995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 386}], {
             RGBColor[
             0.1791759961486071, 0.30565571073945375`, 0.9335151799623065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 396}], {
             RGBColor[
             0.5864855268156967, 0.6472607121015193, 0.7362180745608087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 422}], {
             RGBColor[
             0.20671849831186667`, 0.3346046268085379, 0.9350836847150235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 446}], {
             RGBColor[
             0.20378813280661343`, 0.33152462686661266`, 0.9349168047345866]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 309}], {
             RGBColor[
             0.9193309660445672, 0.6696242794444807, 0.3370748612621325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 320}], {
             RGBColor[
             0.9171168323829694, 0.670650788557899, 0.5149397016540836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 348}], {
             RGBColor[
             0.9027713884189711, 0.6140906553673846, 0.24504718315702606`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 428}], {
             RGBColor[
             0.8379823315719487, 0.29295442119162834`, 0.18400522964919308`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 495}], {
             RGBColor[
             0.8439168192516593, 0.3385694940069675, 0.1896881017533292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 388}], {
             RGBColor[
             0.9696267022726579, 0.9734928770909221, 0.7321607638451979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 490}], {
             RGBColor[
             0.9918174311383581, 0.9889858002878001, 0.6472681311594083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 244}], {
             RGBColor[
             0.3167084139494082, 0.447095666264713, 0.9414615153937971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 248}], {
             RGBColor[
             0.2667577277658053, 0.3977096636716398, 0.9385028300123448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 255}], {
             RGBColor[
             0.34428066244060973`, 0.47097736208628804`, 0.9432183946864745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 313}], {
             RGBColor[
             0.2789668469500533, 0.41054222203715074`, 0.9391981212881146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 338}], {
             RGBColor[
             0.3055405634218271, 0.43742263545021065`, 0.9407499098335221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 379}], {
             RGBColor[
             0.30013749915285226`, 0.43274277274633094`, 0.9404056313560452]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 380}], {
             RGBColor[
             0.2819134302618612, 0.4136392679220333, 0.9393659248486427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 390}], {
             RGBColor[
             0.29586463316817824`, 0.4283028667339263, 0.9401604252152023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 411}], {
             RGBColor[
             0.26528288174741516`, 0.39615950699567326`, 0.9384188397134368]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 478}], {
             RGBColor[
             0.27850887095594073`, 0.41006086022998334`, 0.9391720402327646]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 242}], {
             RGBColor[
             0.2244428247428983, 0.35323401767475476`, 0.9360930588844796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 339}], {
             RGBColor[
             0.21778435426976317`, 0.3462355430360783, 0.9357138688413589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 365}], {
             RGBColor[
             0.22042634378562792`, 0.3490124415290624, 0.9358643262358141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 374}], {
             RGBColor[
             0.23780417240741958`, 0.3672776412285381, 0.9368539678676315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 391}], {
             RGBColor[
             0.23250262506826308`, 0.3617053788375689, 0.936552052589603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 246}], {
             RGBColor[
             0.27633388437422024`, 0.407774811430481, 0.93904817796454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 256}], {
             RGBColor[
             0.27391624912615603`, 0.40523372349783726`, 0.9389104972137335]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 271}], {
             RGBColor[
             0.25712583983655113`, 0.38758593876102676`, 0.9379543082438752]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 288}], {
             RGBColor[
             0.2572561350755689, 0.3877228873184297, 0.9379617283649826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 442}], {
             RGBColor[
             0.2711958428958343, 0.40237440406605196`, 0.938755574103397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 444}], {
             RGBColor[
             0.2648697036740537, 0.39572523064356746`, 0.938395309833401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 492}], {
             RGBColor[
             0.2675328366491727, 0.39852435225280064`, 0.9385469713165818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 307}], {
             RGBColor[
             0.4130035971526026, 0.5316969057817654, 0.9476609261549895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 312}], {
             RGBColor[
             0.3303045820158528, 0.4601142095117522, 0.9422823672274991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 330}], {
             RGBColor[
             0.3313235898372211, 0.4611852513408379, 0.942340398215439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 350}], {
             RGBColor[
             0.3591838096222978, 0.48552869561681206`, 0.944107852628729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 354}], {
             RGBColor[
             0.35898073503518557`, 0.48535280261628094`, 0.94409491289561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 372}], {
             RGBColor[
             0.41332534927572523`, 0.5319581186500844, 0.9476862556607386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 376}], {
             RGBColor[
             0.3178263634409366, 0.4469988106247622, 0.9415717511395277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 400}], {
             RGBColor[
             0.3260597275402094, 0.45565259831853255`, 0.9420406290448107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 414}], {
             RGBColor[
             0.31542779716347613`, 0.44447776538926564`, 0.9414351563383871]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 415}], {
             RGBColor[
             0.3216051563189196, 0.45097056152882875`, 0.9417869478037058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 476}], {
             RGBColor[
             0.8458261121541704, 0.35324515591315253`, 0.19151644279301172`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 235}], {
             RGBColor[
             0.3728101836078023, 0.49733117588158576`, 0.9449761131297559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[
             0.36975457999068184`, 0.4946845656075394, 0.9447814127692372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 262}], {
             RGBColor[
             0.4323322286458682, 0.548267980100758, 0.9489396155777698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 296}], {
             RGBColor[
             0.3509992318996893, 0.478439625762326, 0.9435863385735823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 332}], {
             RGBColor[
             0.3953853483413155, 0.5168846489129837, 0.946414582664141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 393}], {
             RGBColor[
             0.42489506401207827`, 0.5422301548105988, 0.9483541347345662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 468}], {
             RGBColor[
             0.4334778335161593, 0.5491980337433716, 0.9490298017896481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 239}], {
             RGBColor[
             0.35398612023304477`, 0.4810267183113057, 0.943776660456982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 249}], {
             RGBColor[
             0.32329479630323715`, 0.4526684377082041, 0.9418860278221313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 260}], {
             RGBColor[
             0.32130907660212404`, 0.45058132040043347`, 0.941772944022762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 262}], {
             RGBColor[
             0.416563768888231, 0.5346101328045243, 0.9479348632655147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 296}], {
             RGBColor[
             0.3352307721420522, 0.4647817784660925, 0.9425815862613272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 332}], {
             RGBColor[
             0.37961688858367837`, 0.50322680161675, 0.9454098303518859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 344}], {
             RGBColor[
             0.4103923521286693, 0.5295998986599555, 0.9474490267315575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 393}], {
             RGBColor[
             0.40912660425444114`, 0.5285723075143651, 0.947349382422311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 424}], {
             RGBColor[
             0.3388180779328382, 0.46788892243883967`, 0.9428101662141861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 440}], {
             RGBColor[
             0.3193577814126447, 0.44853038543702994`, 0.9416618206484036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 453}], {
             RGBColor[
             0.32067427818872773`, 0.4499141070194098, 0.9417367931922191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 243}], {
             RGBColor[
             0.5633146331293595, 0.36122739545781846`, 0.562473440762307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 276}], {
             RGBColor[
             0.45343165662521556`, 0.5606674341824253, 0.9514328089086481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 283}], {
             RGBColor[
             0.23426865806856206`, 0.3635615914938426, 0.9366526255563583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 292}], {
             RGBColor[
             0.23314689454244097`, 0.36238254690397387`, 0.9365887427830462]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 396}], {
             RGBColor[
             0.6404346091203621, 0.7039646181731036, 0.7392903949875442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 422}], {
             RGBColor[
             0.26066758061653217`, 0.39130853288012224`, 0.9381560051417591]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 267}], {
             RGBColor[
             0.9475774996267206, 0.9513626199375382, 0.7014579081154306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 270}], {
             RGBColor[
             0.9480577404464491, 0.9590498999175098, 0.9029559373872008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 329}], {
             RGBColor[
             0.8943251384864865, 0.9185746058926771, 0.989782724153959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 426}], {
             RGBColor[
             0.8881333928283652, 0.9136374759753497, 0.9891921499256506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 448}], {
             RGBColor[
             0.7370158535300309, 0.7940376208084021, 0.9750172525524329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 489}], {
             RGBColor[
             0.9480949935467251, 0.959065305031835, 0.9023385571076953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 265}], {
             RGBColor[
             0.32058421295120315`, 0.4520956650524487, 0.9416483204611299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 328}], {
             RGBColor[
             0.35273346300045894`, 0.47994172957682313`, 0.943696842245803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 343}], {
             RGBColor[
             0.306520714368336, 0.43844834351747275`, 0.9408058924805078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 431}], {
             RGBColor[
             0.38434692528377257`, 0.5073237216678145, 0.9457112241078087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 433}], {
             RGBColor[
             0.32283008594645624`, 0.45404092736007795`, 0.94179142550244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 436}], {
             RGBColor[
             0.3965368671240651, 0.5173498014044343, 0.9466350145946033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 462}], {
             RGBColor[
             0.392016142899485, 0.5136796738226148, 0.9462791266236859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 465}], {
             RGBColor[
             0.30138975132499524`, 0.433055376037075, 0.940513691725769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 262}], {
             RGBColor[
             0.41350816527111056`, 0.531963522530478, 0.947740162904996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 263}], {
             RGBColor[
             0.31216558423603546`, 0.4415359530567809, 0.9412315474042139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 296}], {
             RGBColor[
             0.33217516852493173`, 0.46213516819204603`, 0.9423868859008084]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 332}], {
             RGBColor[
             0.37656128496655794`, 0.5005801913427036, 0.9452151299913671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 393}], {
             RGBColor[
             0.4060710006373207, 0.5259256972403187, 0.9471546820617923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 424}], {
             RGBColor[
             0.3357624743157177, 0.4652423121647933, 0.9426154658536674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 440}], {
             RGBColor[
             0.3163021777955242, 0.4458837751629835, 0.9414671202878849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 453}], {
             RGBColor[
             0.31761867457160725`, 0.44726749674536337`, 0.9415420928317004]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 251}], {
             RGBColor[
             0.25758537828186423`, 0.38806894280347104`, 0.9379804782785095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 310}], {
             RGBColor[
             0.2766913122921885, 0.4081504908345045, 0.939068532955701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 352}], {
             RGBColor[
             0.24222822396059346`, 0.3719275999119933, 0.937105911058787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 367}], {
             RGBColor[
             0.24323530728920995`, 0.3729861083431402, 0.9371632629645055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 382}], {
             RGBColor[
             0.26942512488484194`, 0.40051326716649266`, 0.9386547343322136]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 399}], {
             RGBColor[
             0.24906325398775672`, 0.3791116498364756, 0.9374951559073132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 412}], {
             RGBColor[
             0.2495035202048371, 0.3795743975451175, 0.9375202284170604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 416}], {
             RGBColor[
             0.2590796192147955, 0.38963948476432886`, 0.9380655730891085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 429}], {
             RGBColor[
             0.2751117605214455, 0.4064902817740869, 0.9389785798190946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 402}], {
             RGBColor[
             0.6288966867837086, 0.7086387216585579, 0.9645893173262957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 417}], {
             RGBColor[
             0.7032574015004508, 0.7681092940971459, 0.9710577835336467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 436}], {
             RGBColor[
             0.5892009770363313, 0.6764119562142918, 0.9614643256448061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 461}], {
             RGBColor[
             0.8249688230204753, 0.8639714322998968, 0.9750930222658254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 339}], {
             RGBColor[
             0.21834915626655288`, 0.34682918574521915`, 0.9357460334795263]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 365}], {
             RGBColor[
             0.22099114578241763`, 0.3496060842382034, 0.9358964908739815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 374}], {
             RGBColor[
             0.2383689744042093, 0.367871283937679, 0.936886132505799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 276}], {
             RGBColor[
             0.7294231328480298, 0.5025695960181678, 0.5742322488928711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 326}], {
             RGBColor[
             0.8572408103331092, 0.41460626615910345`, 0.2014143032349089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 428}], {
             RGBColor[
             0.8348198026853184, 0.2686458383399938, 0.18097678841579048`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 454}], {
             RGBColor[
             0.869594267772993, 0.47070043117032717`, 0.21172233093369885`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 469}], {
             RGBColor[
             0.8498683936659192, 0.3811298439450528, 0.19526257805333647`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 471}], {
             RGBColor[
             0.8480593461920269, 0.37041077133751354`, 0.1936549902297403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 475}], {
             RGBColor[
             0.8391547501965229, 0.3019661444972231, 0.18512793904814284`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 495}], {
             RGBColor[
             0.8407542903650291, 0.31426091115533294`, 0.1866596605199266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 274}], {
             RGBColor[
             0.40258764491589, 0.5228672426461249, 0.9469441500000384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 313}], {
             RGBColor[
             0.3046994618698019, 0.43447349621750786`, 0.9407776233385161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 334}], {
             RGBColor[
             0.3726225537176192, 0.4971686603012616, 0.9449641575190681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 340}], {
             RGBColor[
             0.33993779537767665`, 0.4688587654109236, 0.9428815136196439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 355}], {
             RGBColor[
             0.3355739158146536, 0.46507899226839733`, 0.9426034510727153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 363}], {
             RGBColor[
             0.37362619317772217`, 0.49803796235721676`, 0.9450281085379824]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 378}], {
             RGBColor[
             0.3127627275114677, 0.4429484996474682, 0.9412368143882763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 379}], {
             RGBColor[
             0.3258701140726008, 0.45667404692668806`, 0.9419851334064466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 380}], {
             RGBColor[
             0.3076460451816098, 0.43757054210239044`, 0.9409454268990441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 390}], {
             RGBColor[
             0.3215972480879268, 0.45223414091428343`, 0.9417399272656037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 498}], {
             RGBColor[
             0.40216527018839365`, 0.5225243398145787, 0.9469108991142803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 394}], {
             RGBColor[
             0.22510267482771082`, 0.3539275619508045, 0.936130636370649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 438}], {
             RGBColor[
             0.22151371355788788`, 0.3501553361029332, 0.9359262503357249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 445}], {
             RGBColor[
             0.22560109399094413`, 0.3544514320929628, 0.93615902060465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 460}], {
             RGBColor[
             0.23495456172986623`, 0.36428251973067727`, 0.936691686755166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 256}], {
             RGBColor[
             0.2918037733500637, 0.42403464559170456`, 0.9399291652560644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 288}], {
             RGBColor[
             0.2751436592994766, 0.40652380941229693`, 0.9389803964073136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 333}], {
             RGBColor[
             0.33643527177961996`, 0.46448215779697133`, 0.9427075059768388]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 392}], {
             RGBColor[
             0.3001114005223494, 0.4327664884837622, 0.940402272333493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 442}], {
             RGBColor[
             0.28908336711974203`, 0.42117532615991926`, 0.939774242145728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 444}], {
             RGBColor[
             0.2827572278979614, 0.41452615273743476`, 0.9394139778757318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 459}], {
             RGBColor[
             0.3423837632254584, 0.4696344421074833, 0.9430865385917233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 492}], {
             RGBColor[
             0.2854203608730804, 0.4173252743466679, 0.9395656393589127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 255}], {
             RGBColor[
             0.4462984536881862, 0.5598509487377481, 0.9499715158755377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 269}], {
             RGBColor[
             0.47197536116157857`, 0.5820909954323062, 0.9516076257145445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 360}], {
             RGBColor[
             0.5371888520305683, 0.6351531360172418, 0.9567086207009003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 369}], {
             RGBColor[
             0.457479402684923, 0.5695353247878849, 0.9506839560586847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 370}], {
             RGBColor[
             0.5432273595581627, 0.6400554684598069, 0.9571839941332545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 425}], {
             RGBColor[
             0.4351771155351065, 0.550218204604259, 0.9492628740426365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 466}], {
             RGBColor[
             0.4992597773340883, 0.6043606044932961, 0.953722705002015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 468}], {
             RGBColor[
             0.48669420259584584`, 0.5941593048480999, 0.9527334969294036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 286}], {
             RGBColor[
             0.23281996068137648`, 0.36203891868719107`, 0.9365701243833138]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 294}], {
             RGBColor[
             0.240426199543799, 0.37003355799499527`, 0.9370032884341067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 313}], {
             RGBColor[
             0.254748775686199, 0.38508749362443473`, 0.9378189379570638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 380}], {
             RGBColor[
             0.257695358998007, 0.3881845395093172, 0.937986741517592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 411}], {
             RGBColor[
             0.2410648104835609, 0.37070477858295714`, 0.937039656382386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 478}], {
             RGBColor[
             0.25429079969208646`, 0.3846061318172672, 0.9377928569017139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 260}], {
             RGBColor[
             0.28756214905519606`, 0.4195764295232854, 0.9396876110273925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 280}], {
             RGBColor[
             0.27322012310800536`, 0.4045020509158221, 0.938870853866826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 296}], {
             RGBColor[
             0.3014838445951241, 0.4337768875889444, 0.9404962532659576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 424}], {
             RGBColor[
             0.30507115038591015`, 0.4368840315616916, 0.9407248332188166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 440}], {
             RGBColor[
             0.2856108538657166, 0.41752549455988186`, 0.9395764876530341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 470}], {
             RGBColor[
             0.27251498804399493`, 0.40376090925540187`, 0.9388306974680845]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 339}], {
             RGBColor[
             0.20806801028262886`, 0.33602304945380984`, 0.9351605374253343]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 365}], {
             RGBColor[
             0.21070999979849359`, 0.338799947946794, 0.9353109948197895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 305}], {
             RGBColor[
             0.25482853774731307`, 0.38517132860787223`, 0.9378234802884469]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 367}], {
             RGBColor[
             0.24419513183599667`, 0.3739949447982042, 0.9372179235525118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 382}], {
             RGBColor[
             0.27038494943162866`, 0.40152210362155666`, 0.9387093949202199]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 416}], {
             RGBColor[
             0.26003944376158217`, 0.39064832121939286`, 0.9381202336771148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 427}], {
             RGBColor[
             0.2690226652198594, 0.4000902565411794, 0.9386318148496786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 429}], {
             RGBColor[
             0.2760715850682322, 0.4074991182291509, 0.9390332404071009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 499}], {
             RGBColor[
             0.25963192027097015`, 0.39021998819227793`, 0.9380970258172014]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 282}], {
             RGBColor[
             0.6717272001021579, 0.7429460920325152, 0.9682785844173988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 432}], {
             RGBColor[
             0.8172102397534445, 0.8577657390481622, 0.982246863062763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 467}], {
             RGBColor[
             0.7213175895970523, 0.7822180503007243, 0.9728578543010624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 261}], {
             RGBColor[
             0.9325093316648222, 0.7680041432668934, 0.5596474808987255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 277}], {
             RGBColor[
             0.8781666893011308, 0.9046720920391318, 0.9377821758000617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 291}], {
             RGBColor[
             0.819979493708928, 0.8592158126034372, 0.9319826199336896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 311}], {
             RGBColor[
             0.8659443575362178, 0.8951239135712197, 0.9365639679939195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 319}], {
             RGBColor[
             0.8499607656875054, 0.8826374101392084, 0.934970872933598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 377}], {
             RGBColor[
             0.9830684787672088, 0.9867535506374262, 0.9072964317019494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 484}], {
             RGBColor[
             0.9889617727140382, 0.9876413426482502, 0.6827040059696212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 488}], {
             RGBColor[
             0.877198073649208, 0.9039154021300979, 0.937685633244106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 315}], {
             RGBColor[
             0.21099893285942517`, 0.33910363491324724`, 0.9353274491301715]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 325}], {
             RGBColor[
             0.20775758490962407`, 0.33569677270467635`, 0.935142859159575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 347}], {
             RGBColor[
             0.20771262472504887`, 0.3356495167000475, 0.935140298743576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 368}], {
             RGBColor[
             0.32229994971598047`, 0.44690195182710835`, 0.9420022258236223]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 386}], {
             RGBColor[
             0.20771262472504887`, 0.3356495167000475, 0.935140298743576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 401}], {
             RGBColor[
             0.50497531356463, 0.5944255881948143, 0.9574168801184721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 454}], {
             RGBColor[
             0.568190337821955, 0.5020881692235942, 0.5874756893040098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 471}], {
             RGBColor[
             0.5466554162409889, 0.4017985093907806, 0.5694083486000513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 269}], {
             RGBColor[
             0.4232624333249523, 0.5410303787827784, 0.94819088586856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 274}], {
             RGBColor[
             0.43015989340709154`, 0.5467489384677, 0.9487010292927157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 334}], {
             RGBColor[
             0.40019480220882075`, 0.5210503561228367, 0.9467210368117455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 338}], {
             RGBColor[
             0.35884542683277726`, 0.48523560545214284`, 0.9440862911766009]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 369}], {
             RGBColor[
             0.40876647484829665`, 0.5284747081383571, 0.9472672162127003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 370}], {
             RGBColor[
             0.4945144317215364, 0.598994851810279, 0.9537672542872702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 379}], {
             RGBColor[
             0.35344236256380235`, 0.4805557427482631, 0.943742012699124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 390}], {
             RGBColor[
             0.3491694965791283, 0.4761158367358585, 0.9434968065582812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 425}], {
             RGBColor[
             0.38646418769848023`, 0.5091575879547311, 0.9458461341966522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 466}], {
             RGBColor[
             0.45054684949746193`, 0.5632999878437683, 0.9503059651560305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 271}], {
             RGBColor[
             0.2725957288123946, 0.4038457729222503, 0.9388352955353996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 333}], {
             RGBColor[
             0.3340176365315557, 0.4619410698643276, 0.9425698252260324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 442}], {
             RGBColor[
             0.28666573187167776`, 0.4186342382272755, 0.9396365613949216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 444}], {
             RGBColor[
             0.28033959264989716`, 0.411985064804791, 0.9392762971249253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 492}], {
             RGBColor[
             0.28300272562501616`, 0.4147841864140242, 0.9394279586081062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 272}], {
             RGBColor[
             0.8397181825766789, 0.3055916208213189, 0.18563986428858031`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 306}], {
             RGBColor[
             0.8582164736566054, 0.4477775920644729, 0.2033538487175496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 317}], {
             RGBColor[
             0.8711268784377937, 0.5076990787158229, 0.21417744721027115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 357}], {
             RGBColor[
             0.8829978584207956, 0.5607626793064351, 0.22403944465155362`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 418}], {
             RGBColor[
             0.9186634619525802, 0.7177171878043327, 0.5626295641489729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 420}], {
             RGBColor[
             0.9137481314322007, 0.7140513423503487, 0.5709499365964574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 289}], {
             RGBColor[
             0.4063967473847854, 0.5264221693154291, 0.9471162192741931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 297}], {
             RGBColor[
             0.4463933258988235, 0.5592718859080008, 0.9501602626281445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 314}], {
             RGBColor[
             0.35174895766394676`, 0.47908900053701325`, 0.9436341104363243]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 373}], {
             RGBColor[
             0.3335189671806654, 0.461900180189882, 0.9425237328349862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 381}], {
             RGBColor[
             0.4713636222770108, 0.5795438974068458, 0.952126015828245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 397}], {
             RGBColor[
             0.36598524788401654`, 0.49141975958888606`, 0.94454123426049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 472}], {
             RGBColor[
             0.3509345795878789, 0.47838362717935545`, 0.9435822189854435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 341}], {
             RGBColor[
             0.9277070351691528, 0.7270975616364004, 0.37415406223837167`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 405}], {
             RGBColor[
             0.9279266912954685, 0.7275673838799486, 0.39806227602736116`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 450}], {
             RGBColor[
             0.8397745913250846, 0.3013267240551166, 0.18550990071046175`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 454}], {
             RGBColor[
             0.8808615626968692, 0.5519020063430116, 0.22230030637499004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 469}], {
             RGBColor[
             0.8611356885897954, 0.46233141911773723`, 0.2058405534946276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 471}], {
             RGBColor[
             0.8593266411159032, 0.451612346510198, 0.20423296567103144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 475}], {
             RGBColor[
             0.8504220451203991, 0.38316771966990754`, 0.19570591448943397`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 491}], {
             RGBColor[
             0.9280010655847133, 0.727726462964249, 0.4061574584267472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 500}], {
             RGBColor[
             0.8406666807462297, 0.3081837142621151, 0.18636416654762122`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 280}], {
             RGBColor[
             0.27123440340689225`, 0.4024149336080515, 0.9387577700674566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 424}], {
             RGBColor[
             0.3030854306847971, 0.434796914253921, 0.9406117494194473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 440}], {
             RGBColor[
             0.28362513416460355`, 0.4154383772521112, 0.9394634038536649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 470}], {
             RGBColor[
             0.2705292683428818, 0.4016737919476313, 0.9387176136687151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 483}], {
             RGBColor[
             0.2911128004849959, 0.42330838930030823`, 0.9398898153736015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 484}], {
             RGBColor[
             0.9364392575786439, 0.7675671876801757, 0.34462692180178206`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 500}], {
             RGBColor[
             0.8497397394109806, 0.34938235459205963`, 0.19393494909850834`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 332}], {
             RGBColor[
             0.43913893362174417`, 0.5541636058359223, 0.9493733327998998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 344}], {
             RGBColor[
             0.4699143971667351, 0.5805367028791276, 0.9514125291795714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 387}], {
             RGBColor[
             0.6255998101870561, 0.7048955003973141, 0.9650590620780228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 393}], {
             RGBColor[
             0.46864864929250694`, 0.5795091117335374, 0.951312884870325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 424}], {
             RGBColor[
             0.39834012297090404`, 0.5188257266580119, 0.9467736686621999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 296}], {
             RGBColor[
             0.2934102361450429, 0.4252910132115676, 0.9400364732085589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 323}], {
             RGBColor[
             0.2563726589916906, 0.3867942979386546, 0.9379114157089916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 342}], {
             RGBColor[
             0.2666938975771815, 0.3976425740963284, 0.9384991949775311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 395}], {
             RGBColor[
             0.2691941123375187, 0.40027045833221453`, 0.938641578509396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 440}], {
             RGBColor[
             0.2775372454156354, 0.40903962018250506`, 0.9391167075956355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 447}], {
             RGBColor[
             0.2599502995006695, 0.3905546249491011, 0.938115157043333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 453}], {
             RGBColor[
             0.27885374219171843`, 0.41042334176488493`, 0.9391916801394509]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 463}], {
             RGBColor[
             0.2702490064672201, 0.4013792189466815, 0.9387016531695065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 394}], {
             RGBColor[
             0.23171433520063273`, 0.36087683620622507`, 0.9365071606478118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 398}], {
             RGBColor[
             0.2479686232623, 0.377961123540424, 0.9374328183068594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 445}], {
             RGBColor[
             0.23221275436386601`, 0.3614007063483834, 0.9365355448818129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 328}], {
             RGBColor[
             0.35316375548579293`, 0.48031442730049023`, 0.9437242601024758]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 433}], {
             RGBColor[
             0.32326037843179023`, 0.45441362508374517`, 0.9418188433591128]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 462}], {
             RGBColor[
             0.392446435384819, 0.5140523715462819, 0.9463065444803587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 364}], {
             RGBColor[
             0.2740437091478759, 0.405367692062097, 0.9389177558734103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 374}], {
             RGBColor[
             0.27062553266643685`, 0.40177497185519817`, 0.9387230957795312]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 410}], {
             RGBColor[
             0.326592877843097, 0.45552256223454524`, 0.9420962704893343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 437}], {
             RGBColor[
             0.2726756027922651, 0.40392972553939704`, 0.9388398442403902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 278}], {
             RGBColor[
             0.9687131736129876, 0.9678890438697982, 0.6921508091390034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 329}], {
             RGBColor[
             0.9358102453449542, 0.941979730786866, 0.7003355368972839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 406}], {
             RGBColor[
             0.9898404936899885, 0.9773917410301207, 0.415032665757733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 413}], {
             RGBColor[
             0.981449315920919, 0.9490863280728146, 0.38243452466585603`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 476}], {
             RGBColor[
             0.9187775169477521, 0.6742536840952063, 0.3030402150761125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 486}], {
             RGBColor[
             0.9619951023866931, 0.9628588250229391, 0.7028330719374227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 493}], {
             RGBColor[
             0.991319933690298, 0.9817192401312839, 0.4771566948770857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 275}], {
             RGBColor[
             0.4116793705742366, 0.5309977120097701, 0.9474528233525847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 285}], {
             RGBColor[
             0.3620365603618595, 0.4879996049239992, 0.9442896273832655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 324}], {
             RGBColor[
             0.3896661145929028, 0.5119309360971549, 0.946050158147012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 353}], {
             RGBColor[
             0.5246586597567469, 0.6237950026375101, 0.9560497714979366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 441}], {
             RGBColor[
             0.4298935905497302, 0.5467739538792281, 0.9486134173432208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 480}], {
             RGBColor[
             0.3816010072146523, 0.5049453454501976, 0.9455362566365644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 481}], {
             RGBColor[
             0.3639357382267393, 0.48964457733510314`, 0.9444106413174386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 360}], {
             RGBColor[
             0.5141528316673345, 0.616332566062272, 0.9549279906939228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 369}], {
             RGBColor[
             0.43444338232168905`, 0.5507147548329152, 0.948903326051707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 425}], {
             RGBColor[
             0.4121410951718726, 0.5313976346492894, 0.947482244035659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 466}], {
             RGBColor[
             0.47622375697085434`, 0.5855400345383266, 0.9519420749950372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 468}], {
             RGBColor[
             0.4636581822326119, 0.5753387348931303, 0.9509528669224259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 309}], {
             RGBColor[
             0.9915269265441726, 0.9888220703419007, 0.6489133693566129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 345}], {
             RGBColor[
             0.824874141314561, 0.8621219539632672, 0.8908628396870938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 375}], {
             RGBColor[
             0.9741122632489756, 0.9792447932430604, 0.8853225104060825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 426}], {
             RGBColor[
             0.9300987405065613, 0.9447298808495102, 0.9012429919407459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 489}], {
             RGBColor[
             0.9900603412249211, 0.9901577099059953, 0.8143893991227904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 284}], {
             RGBColor[
             0.2504489768010796, 0.3805681323731789, 0.9375740707715388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 442}], {
             RGBColor[
             0.26987532258207286`, 0.400986453490465, 0.9386803724250632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 444}], {
             RGBColor[
             0.26354918336029226`, 0.3943372800679805, 0.938320108155067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 464}], {
             RGBColor[
             0.24983604138275278`, 0.37992389838616725`, 0.9375391650062217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 492}], {
             RGBColor[
             0.2662123163354113, 0.39713640167721365`, 0.9384717696382479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 306}], {
             RGBColor[
             0.8390812230199529, 0.30140098239829205`, 0.18505752934082234`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 317}], {
             RGBColor[
             0.8519916278011412, 0.36132246904964216`, 0.1958811278335439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 357}], {
             RGBColor[
             0.8638626077841431, 0.41438606964025426`, 0.20574312527482636`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 308}], {
             RGBColor[
             0.23624385022904204`, 0.36563764368892326`, 0.9367651098278627]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 421}], {
             RGBColor[
             0.236299010735822, 0.36569562087892715`, 0.9367682511371211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 423}], {
             RGBColor[
             0.24068365358124288`, 0.3703041585118776, 0.9370179500606701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 446}], {
             RGBColor[
             0.26084634450324296`, 0.39149642505934035`, 0.9381661854806498]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 477}], {
             RGBColor[
             0.2691065215645594, 0.4001783948762585, 0.9386365903444549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 334}], {
             RGBColor[
             0.4327691697643524, 0.5490089625023165, 0.9488672900749079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 340}], {
             RGBColor[
             0.40008441142440987`, 0.5206990676119785, 0.9467846461754836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 361}], {
             RGBColor[
             0.5534678542610545, 0.6483409394418851, 0.9580094602549781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 363}], {
             RGBColor[
             0.4337728092244554, 0.5498782645582716, 0.9489312410938221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 369}], {
             RGBColor[
             0.4413408424038283, 0.5564333145178368, 0.9494134694758627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 370}], {
             RGBColor[
             0.5270887992770681, 0.6269534581897589, 0.9559135075504326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 379}], {
             RGBColor[
             0.386016730119334, 0.5085143491277428, 0.9458882659622865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 498}], {
             RGBColor[
             0.46231188623512687`, 0.5743646420156336, 0.95081403167012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 282}], {
             RGBColor[
             0.5106811757652547, 0.612557396257451, 0.9549190346803453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 285}], {
             RGBColor[
             0.36406115169331943`, 0.4897532041763907, 0.9444186325526303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 324}], {
             RGBColor[
             0.3916907059243627, 0.5136845353495464, 0.9461791633163769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 353}], {
             RGBColor[
             0.5266832510882068, 0.6255486018899017, 0.9561787766673014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 441}], {
             RGBColor[
             0.43191818188119013`, 0.5485275531316196, 0.9487424225125856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 481}], {
             RGBColor[
             0.36596032955819924`, 0.49139817658749463`, 0.9445396464868034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 283}], {
             RGBColor[
             0.4003771577872324, 0.5049037920541919, 0.9484114336869224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 292}], {
             RGBColor[
             0.39925539426111123`, 0.5037247474643232, 0.9483475509136101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 396}], {
             RGBColor[
             0.8065431088390325, 0.8453068187334528, 0.7510492031181083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 422}], {
             RGBColor[
             0.4267760803352025, 0.5326507334404715, 0.9499148132723232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 291}], {
             RGBColor[
             0.7131143362098424, 0.7758096064076011, 0.9720402306671867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 311}], {
             RGBColor[
             0.7590792000371321, 0.8117177073753836, 0.9766215787274166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 319}], {
             RGBColor[
             0.7430956081884199, 0.7992312039433723, 0.9750284836670953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 331}], {
             RGBColor[
             0.8039966134471465, 0.8469425741957761, 0.9810626907032964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 377}], {
             RGBColor[
             0.8762033212681233, 0.9033473444415901, 0.9473540424354466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 419}], {
             RGBColor[
             0.6419960336426249, 0.718265092425402, 0.9663099050077802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 449}], {
             RGBColor[
             0.7498021540184663, 0.8044704085174408, 0.9756969294792002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 484}], {
             RGBColor[
             0.8820966152149525, 0.9042351364524142, 0.7227616167031183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 488}], {
             RGBColor[
             0.7703329161501223, 0.8205091959342619, 0.9777432439776033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 329}], {
             RGBColor[
             0.9154608124727537, 0.9351010298249371, 0.9804756251775316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 406}], {
             RGBColor[
             0.969491060817788, 0.9705130400681918, 0.6951727540379807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 413}], {
             RGBColor[
             0.9610998830487185, 0.9422076271108857, 0.6625746129461039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 486}], {
             RGBColor[
             0.9416456695144926, 0.9559801240610102, 0.9829731602176706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 493}], {
             RGBColor[
             0.9709705008180975, 0.974840539169355, 0.7572967831573334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.2964892825686648, 0.42843496613236076`, 0.9402152006381983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 324}], {
             RGBColor[
             0.3241188367997081, 0.45236629730551653`, 0.9419757314019449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 481}], {
             RGBColor[
             0.2983884604335446, 0.4300799385434647, 0.9403362145723715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 494}], {
             RGBColor[
             0.2685318784304253, 0.3995744085078045, 0.9386038652680744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 327}], {
             RGBColor[
             0.25698076875714937`, 0.3874334598585377, 0.9379460466605166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 470}], {
             RGBColor[
             0.25618724239569113`, 0.386599413340168, 0.9379008565081486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 483}], {
             RGBColor[
             0.2767707745378052, 0.40823401069284493`, 0.939073058213035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 288}], {
             RGBColor[
             0.2504872858476244, 0.38060839761003135`, 0.9375762524150663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 343}], {
             RGBColor[
             0.26889808498261325`, 0.3999593148129905, 0.9386247201894673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 465}], {
             RGBColor[
             0.26376712193927254`, 0.39456634733259277`, 0.9383325194347287]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 324}], {
             RGBColor[
             0.48866791978392093`, 0.5934906203448358, 0.9535163694747727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 353}], {
             RGBColor[
             0.6236604649477651, 0.705354686885191, 0.9635159828256973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 432}], {
             RGBColor[
             0.7531414292760994, 0.8071831282683875, 0.9762245194841053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 441}], {
             RGBColor[
             0.5288953957407483, 0.628333638126909, 0.9560796286709814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 467}], {
             RGBColor[
             0.6572487791197071, 0.7316354395209496, 0.9668355107224047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 292}], {
             RGBColor[
             0.18009239570445779`, 0.3066189047757405, 0.9335673675613205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 386}], {
             RGBColor[
             0.18007057961528944`, 0.30659597468280464`, 0.9335661251673164]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 422}], {
             RGBColor[
             0.207613081778549, 0.3355448907518888, 0.9351346299200334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 442}], {
             RGBColor[
             0.26451897986036277`, 0.3953565976782041, 0.9383753366310607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 444}], {
             RGBColor[
             0.25819284063858217`, 0.3887074242557196, 0.9380150723610645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 464}], {
             RGBColor[
             0.24447969866104266`, 0.37429404257390636`, 0.9372341292122193]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 324}], {
             RGBColor[
             0.3420478957119857, 0.4706864282637755, 0.9430159673470576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 480}], {
             RGBColor[
             0.3339827883337351, 0.46370083761681824`, 0.9425020658366099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 481}], {
             RGBColor[
             0.3163175193458222, 0.44840006950172373`, 0.9413764505174842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 294}], {
             RGBColor[
             0.23070650372322443`, 0.3598175414232626, 0.9364497661361264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 346}], {
             RGBColor[
             0.22049146079372114`, 0.3490808836332252, 0.935868034553093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 358}], {
             RGBColor[
             0.22436323878386594`, 0.35315036778577047`, 0.9360885265818495]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 407}], {
             RGBColor[
             0.21872930348009942`, 0.347228744569382, 0.9357676823009604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 411}], {
             RGBColor[
             0.2313451146629863, 0.3604887620112245, 0.9364861340844057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 295}], {
             RGBColor[
             0.2196997994484176, 0.34824879736508285`, 0.9358229506106359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 299}], {
             RGBColor[
             0.2094890463187735, 0.33751664842668644`, 0.9352414633253583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 300}], {
             RGBColor[
             0.2178846815571592, 0.3463409933762489, 0.9357195823319551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 301}], {
             RGBColor[
             0.20928219811004087`, 0.33729923784437454`, 0.9352296836258756]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 389}], {
             RGBColor[
             0.214155749354975, 0.34242164920379625`, 0.9355072251595016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 451}], {
             RGBColor[
             0.21062876698303812`, 0.3387145671072923, 0.9353063687311225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 456}], {
             RGBColor[
             0.21673512234064032`, 0.34513273375342357`, 0.9356541166351948]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 343}], {
             RGBColor[
             0.274476709135814, 0.40582280250320485`, 0.9389424145821572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 392}], {
             RGBColor[
             0.281033651223698, 0.41271456437171095`, 0.9393158227339358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 465}], {
             RGBColor[
             0.2693457460924733, 0.4004298350228071, 0.9386502138274186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 492}], {
             RGBColor[
             0.26634261157442907`, 0.39727335023461663`, 0.9384791897593554]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 291}], {
             RGBColor[
             0.5471490964494157, 0.6426680909259248, 0.9577289938124869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 297}], {
             RGBColor[
             0.47936763079523015`, 0.5878325714725148, 0.9522613561781106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 314}], {
             RGBColor[
             0.3847232625603534, 0.5076496861015274, 0.9457352039862904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 349}], {
             RGBColor[
             0.42648626116779464`, 0.5438226964259498, 0.9483963053279869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 359}], {
             RGBColor[
             0.4124111574915527, 0.5316315490568694, 0.9474994521678624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 381}], {
             RGBColor[
             0.5043379271734174, 0.6081045829713598, 0.9542271093782111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 397}], {
             RGBColor[
             0.39895955278042317`, 0.5199804451534001, 0.9466423278104561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 419}], {
             RGBColor[
             0.4760307938821983, 0.5851235769437257, 0.9519986681530803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 472}], {
             RGBColor[
             0.3839088844842855, 0.5069443127438695, 0.9456833125354096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 316}], {
             RGBColor[
             0.268490139738015, 0.3995305384956953, 0.9386014883112883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 340}], {
             RGBColor[
             0.31195990105564253`, 0.44256756021982796`, 0.9411741462288754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 355}], {
             RGBColor[
             0.30759602149261944`, 0.4387877870773017, 0.9408960836819469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 362}], {
             RGBColor[
             0.3374733904051481, 0.4646660623491092, 0.9427998432095333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 378}], {
             RGBColor[
             0.28478483318943354`, 0.41665729445637256`, 0.939529446997508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 384}], {
             RGBColor[
             0.2851530200769201, 0.4170442822195179, 0.9395504146960666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 297}], {
             RGBColor[
             0.5871456749634538, 0.6755178075184964, 0.9607730371664382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 311}], {
             RGBColor[
             0.7008920044449292, 0.7662614279396891, 0.9708220228610445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 319}], {
             RGBColor[
             0.6849084125962169, 0.7537749245076777, 0.969228927800723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 349}], {
             RGBColor[
             0.5342643053360183, 0.6315079324719315, 0.9569079863163146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 359}], {
             RGBColor[
             0.5201892016597764, 0.619316785102851, 0.95601113315619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 419}], {
             RGBColor[
             0.583808838050422, 0.6728088129897074, 0.960510349141408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 488}], {
             RGBColor[
             0.7121457205579194, 0.7750529164985673, 0.971943688111231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 308}], {
             RGBColor[
             0.17895845847297373`, 0.30542706484967774`, 0.9335027915134972]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 386}], {
             RGBColor[
             0.17894881608916835`, 0.3054169300929359, 0.9335022423940041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 422}], {
             RGBColor[
             0.20649131825242792`, 0.3343658461620201, 0.9350707471467212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 298}], {
             RGBColor[
             0.9279560632534805, 0.9449120378208546, 0.9763848153450053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 317}], {
             RGBColor[
             0.9188363181868828, 0.7644234365766909, 0.5933539685152149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 353}], {
             RGBColor[
             0.7969674264911133, 0.8418814193634385, 0.9635324755439242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 418}], {
             RGBColor[
             0.9663729017016692, 0.9744415456652006, 0.9418060854539165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 420}], {
             RGBColor[
             0.9614575711812897, 0.9707757002112165, 0.9501264579014013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 432}], {
             RGBColor[
             0.9264483908194477, 0.943709860746635, 0.9762410122023322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 358}], {
             RGBColor[
             0.23196947764628847`, 0.36114500709357467`, 0.9365216906326425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 411}], {
             RGBColor[
             0.23895135352540886`, 0.3684834013190287, 0.9369192981351986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 430}], {
             RGBColor[
             0.23902588418057213`, 0.36856173776312173`, 0.9369235425457519]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 478}], {
             RGBColor[
             0.25217734273393444`, 0.38238475455333876`, 0.9376724986545265]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 300}], {
             RGBColor[
             0.22777276498654234`, 0.3567339960012304, 0.9362826940551499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 336}], {
             RGBColor[
             0.22591321478921644`, 0.3547794908415487, 0.9361767954223702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 389}], {
             RGBColor[
             0.22404383278435813`, 0.3528146518287777, 0.9360703368826964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 409}], {
             RGBColor[
             0.23557177233220394`, 0.3649312472071466, 0.9367268359858879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 456}], {
             RGBColor[
             0.22662320577002346`, 0.355525736378405, 0.9362172283583896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 458}], {
             RGBColor[
             0.2300435692999762, 0.35912075531195864`, 0.936412013001446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 332}], {
             RGBColor[
             0.3578059368755654, 0.48433525149749035`, 0.9440200557957121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 395}], {
             RGBColor[
             0.289203696626415, 0.4208696734674796, 0.9397969170059906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 424}], {
             RGBColor[
             0.31700712622472516`, 0.4489973723195799, 0.9414203916580124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 440}], {
             RGBColor[
             0.29754682970453167`, 0.4296388353177702, 0.94027204609223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 453}], {
             RGBColor[
             0.2988633264806147, 0.4310225569001501, 0.9403470186360454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 311}], {
             RGBColor[
             0.6331105387907436, 0.7114259084862791, 0.9653543852266682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 314}], {
             RGBColor[
             0.42471984107439154`, 0.540499402694099, 0.9487792473402418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 349}], {
             RGBColor[
             0.4664828396818328, 0.5766724130185215, 0.9514403486819383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 359}], {
             RGBColor[
             0.45240773600559087`, 0.5644812656494411, 0.9505434955218137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 381}], {
             RGBColor[
             0.5443345056874556, 0.6409542995639315, 0.9572711527321625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 397}], {
             RGBColor[
             0.4389561312944613, 0.5528301617459719, 0.9496863711644075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 419}], {
             RGBColor[
             0.5160273723962365, 0.6179732935362974, 0.9550427115070317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 353}], {
             RGBColor[
             0.7706511770330843, 0.8213765109750578, 0.9776280646137345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 418}], {
             RGBColor[
             0.9400566522436402, 0.9539366372768199, 0.955901674523727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 420}], {
             RGBColor[
             0.9351413217232607, 0.9502707918228358, 0.9642220469712115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 432}], {
             RGBColor[
             0.9001321413614187, 0.9232049523582542, 0.9903366012721426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 300}], {
             RGBColor[
             0.21756201185689822`, 0.346001847062834, 0.9357012067698722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 301}], {
             RGBColor[
             0.20895952840977988`, 0.3369600915309596, 0.9352113080637927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 389}], {
             RGBColor[
             0.213833079654714, 0.34208250289038133`, 0.9354888495974187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 451}], {
             RGBColor[
             0.21030609728277713`, 0.3383754207938774, 0.9352879931690398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 456}], {
             RGBColor[
             0.21641245264037934`, 0.34479358744000865`, 0.935635741073112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 301}], {
             RGBColor[
             0.2173551636481656, 0.3457844364805221, 0.9356894270703895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 389}], {
             RGBColor[
             0.2222287148930997, 0.35090684783994386`, 0.9359669686040155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 409}], {
             RGBColor[
             0.23375665444094554`, 0.3630234432183127, 0.936623467707207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 451}], {
             RGBColor[
             0.21870173252116284`, 0.3471997657434399, 0.9357661121756364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 456}], {
             RGBColor[
             0.22480808787876505`, 0.3536179323895711, 0.9361138600797088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 458}], {
             RGBColor[
             0.22822845140871784`, 0.35721295132312475`, 0.9363086447227651]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 389}], {
             RGBColor[
             0.21362623144598136`, 0.3418650923080694, 0.9354770698979359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 451}], {
             RGBColor[
             0.2100992490740445, 0.3381580102115655, 0.9352762134695569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 456}], {
             RGBColor[
             0.21620560443164671`, 0.3445761768576967, 0.9356239613736292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 315}], {
             RGBColor[
             0.18782448730516063`, 0.31474582329100176`, 0.934007698739376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 325}], {
             RGBColor[
             0.18458313935535953`, 0.31133896108243087`, 0.9338231087687794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 347}], {
             RGBColor[
             0.18453817917078433`, 0.311291705077802, 0.9338205483527805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 368}], {
             RGBColor[
             0.2991255041617159, 0.42254414020486286`, 0.9406824754328269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 386}], {
             RGBColor[
             0.18453817917078433`, 0.311291705077802, 0.9338205483527805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 421}], {
             RGBColor[
             0.18460298206136966`, 0.31135981702454774`, 0.9338242387815321]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 477}], {
             RGBColor[
             0.21741049289010705`, 0.3458425910218791, 0.9356925779888657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 366}], {
             RGBColor[
             0.2851324087513453, 0.4170226184095053, 0.9395492409115669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 435}], {
             RGBColor[
             0.2816881021628791, 0.4134024338033765, 0.9393530927467486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 473}], {
             RGBColor[
             0.31604489027716914`, 0.44784149062043943`, 0.9413708849892584]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 310}], {
             RGBColor[
             0.317660558842397, 0.44845488439544834`, 0.9415026138990965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 429}], {
             RGBColor[
             0.316081007071654, 0.4467946753350308, 0.9414126607624902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 483}], {
             RGBColor[
             0.3176066092257016, 0.44839817992769826`, 0.941499541548237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 382}], {
             RGBColor[
             0.2666682843502908, 0.39761565297089385`, 0.938497736342151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 416}], {
             RGBColor[
             0.2563227786802443, 0.3867418705687301, 0.9379085750990459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 427}], {
             RGBColor[
             0.26530600013852146`, 0.3961838058905166, 0.9384201562716097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 438}], {
             RGBColor[
             0.23628821482403703`, 0.36568427369114076`, 0.9367676363259161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 460}], {
             RGBColor[
             0.24972906299601538`, 0.37981145731888477`, 0.9375330727453572]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 499}], {
             RGBColor[
             0.2559152551896322, 0.3863135375416151, 0.9378853672391325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 317}], {
             RGBColor[
             0.8704899188810679, 0.5035084402927961, 0.2135951122625132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 357}], {
             RGBColor[
             0.8823608988640697, 0.5565720408834082, 0.22345710970379568`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 418}], {
             RGBColor[
             0.9180265023958543, 0.7135265493813059, 0.5620472292012149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 420}], {
             RGBColor[
             0.9131111718754747, 0.7098607039273219, 0.5703676016486996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 372}], {
             RGBColor[
             0.47013131999468205`, 0.580712810603117, 0.9514296061392018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 417}], {
             RGBColor[
             0.5854211152910297, 0.6734114544902967, 0.9611201594979415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 386}], {
             RGBColor[
             0.17893664238380538`, 0.3054041347567419, 0.9335015491194931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 421}], {
             RGBColor[
             0.1790014452743907, 0.3054722467034876, 0.9335052395482446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 422}], {
             RGBColor[
             0.20647914454706495`, 0.3343530508258261, 0.9350700538722102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 423}], {
             RGBColor[
             0.1833860881198116, 0.31008078433643804`, 0.9337549384717936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 446}], {
             RGBColor[
             0.2035487790418117, 0.3312730508839008, 0.9349031738917732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 320}], {
             RGBColor[
             0.9908166313021023, 0.9885283450055495, 0.6606847997028811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 337}], {
             RGBColor[
             0.926620732552479, 0.9394372573300418, 0.7346744089406012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 348}], {
             RGBColor[
             0.976471187338104, 0.9319682118150352, 0.39079228120582354`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 375}], {
             RGBColor[
             0.9756161016685031, 0.977924558793291, 0.7192291003603996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 489}], {
             RGBColor[
             0.9915641796444485, 0.9888374754562259, 0.6482959890771074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 327}], {
             RGBColor[
             0.2769131154519483, 0.40838362001854456`, 0.939081164317521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 399}], {
             RGBColor[
             0.26912901254486776`, 0.40020203432257306`, 0.938637871172511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 412}], {
             RGBColor[
             0.26956927876194814`, 0.4006647820312149, 0.9386629436822582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 429}], {
             RGBColor[
             0.2951775190785565, 0.4275806662601843, 0.9401212950842925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 483}], {
             RGBColor[
             0.2967031212326041, 0.4291841708528518, 0.9402081758700394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 319}], {
             RGBColor[
             0.7308732764235066, 0.7896830254754603, 0.9738102758609529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 331}], {
             RGBColor[
             0.7917742816822333, 0.837394395727864, 0.9798444828971542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 349}], {
             RGBColor[
             0.5802291691633081, 0.667416033439714, 0.9614893343765445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 377}], {
             RGBColor[
             0.8639809895032101, 0.8937991659736781, 0.9461358346293043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 419}], {
             RGBColor[
             0.6297737018777119, 0.70871691395749, 0.9650916972016379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 484}], {
             RGBColor[
             0.8698742834500395, 0.8946869579845022, 0.7215434088969761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 488}], {
             RGBColor[
             0.7581105843852092, 0.8109610174663499, 0.9765250361714609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 354}], {
             RGBColor[
             0.3330876906173925, 0.4625247982993003, 0.942459704446583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 376}], {
             RGBColor[
             0.2919333190231436, 0.4241708063077816, 0.9399365426905006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 400}], {
             RGBColor[
             0.30016668312241634`, 0.43282459400155193`, 0.9404054205957836]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 414}], {
             RGBColor[
             0.2895347527456831, 0.421649761072285, 0.9397999478893602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 415}], {
             RGBColor[
             0.29571211190112656`, 0.42814255721184813`, 0.9401517393546788]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 379}], {
             RGBColor[
             0.288128547073246, 0.4201206026991259, 0.9397217393007642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 380}], {
             RGBColor[
             0.26990447818225494`, 0.4010170978748282, 0.9386820327933616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 390}], {
             RGBColor[
             0.28385568108857195`, 0.41568069668672125`, 0.9394765331599213]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 411}], {
             RGBColor[
             0.2532739296678089, 0.38353733694846814`, 0.9377349476581557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 478}], {
             RGBColor[
             0.26649991887633445`, 0.3974386901827782, 0.9384881481774836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 359}], {
             RGBColor[
             0.3577633677707141, 0.48429838027845357`, 0.9440173433299934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 373}], {
             RGBColor[
             0.3118454823562334, 0.44312769697598026`, 0.9411427175470836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 397}], {
             RGBColor[
             0.34431176305958455`, 0.4726472763749843, 0.9431602189725873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 398}], {
             RGBColor[
             0.29561326424229706`, 0.426066606556162, 0.9402183167389095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 472}], {
             RGBColor[
             0.3292610947634469, 0.4596111439654538, 0.9422012036975409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 325}], {
             RGBColor[
             0.1822582683189515, 0.30889537421782864`, 0.9336907108025945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 347}], {
             RGBColor[
             0.1822133081343763, 0.30884811821319974`, 0.9336881503865955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 368}], {
             RGBColor[
             0.2968006331253079, 0.42010055334026064`, 0.9405500774666419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 386}], {
             RGBColor[
             0.1822133081343763, 0.30884811821319974`, 0.9336881503865955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 401}], {
             RGBColor[
             0.47947599697395743`, 0.5676241897079666, 0.9559647317614918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 378}], {
             RGBColor[
             0.26678973270236006`, 0.397743302889189, 0.9385046526461347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 357}], {
             RGBColor[
             0.895271303645258, 0.6164935275347583, 0.23428070819651722`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 418}], {
             RGBColor[
             0.9309369071770426, 0.7734480360326559, 0.5728708276939365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 420}], {
             RGBColor[
             0.9260215766566631, 0.7697821905786719, 0.5811912001414211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 321}], {
             RGBColor[
             0.33755888801482614`, 0.46679827542058316`, 0.9427299317460682]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 330}], {
             RGBColor[
             0.32419593809646025`, 0.45501163764918373`, 0.9418862305492528]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 335}], {
             RGBColor[
             0.3093572475376726, 0.43941523304457686`, 0.9410411890738053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 350}], {
             RGBColor[
             0.3520561578815369, 0.47935508192515797`, 0.9436536849625428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 354}], {
             RGBColor[
             0.35185308329442466`, 0.47917918892462685`, 0.9436407452294238]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 383}], {
             RGBColor[
             0.3354424216880899, 0.46496509866505487`, 0.9425950723832464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 479}], {
             RGBColor[
             0.3767164983407358, 0.5007146293661655, 0.94522502005032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 482}], {
             RGBColor[
             0.35021188070592757`, 0.4777576617317112, 0.9435361692517431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 496}], {
             RGBColor[
             0.3094159330482752, 0.43947691523709653`, 0.9410445311268166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 331}], {
             RGBColor[
             0.775790689833521, 0.8249078922958527, 0.9782513878368327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 377}], {
             RGBColor[
             0.8479973976544979, 0.8813126625416667, 0.9445427395689829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 449}], {
             RGBColor[
             0.7215962304048408, 0.7824357266175173, 0.9728856266127364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 488}], {
             RGBColor[
             0.7421269925364968, 0.7984745140343386, 0.9749319411111395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 337}], {
             RGBColor[
             0.9244065988908812, 0.9404637664434601, 0.9125392493325524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 348}], {
             RGBColor[
             0.9742570536765062, 0.9329947209284535, 0.5686571215977747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 361}], {
             RGBColor[
             0.8164019725999951, 0.8557645940777792, 0.9018606390244552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 375}], {
             RGBColor[
             0.9734019680069053, 0.9789510679067093, 0.8970939407523506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 335}], {
             RGBColor[
             0.3049738126003747, 0.4356185220197354, 0.94076188047572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 383}], {
             RGBColor[
             0.3310589867507921, 0.46116838764021345`, 0.942315763785161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 479}], {
             RGBColor[
             0.37233306340343797`, 0.49691791834132404`, 0.9449457114522347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 482}], {
             RGBColor[
             0.3458284457686297, 0.47396095070686983`, 0.9432568606536578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 496}], {
             RGBColor[
             0.3050324981109774, 0.4356802042122551, 0.9407652225287313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 494}], {
             RGBColor[
             0.2588610411681461, 0.3894097453786518, 0.9380531253927091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 342}], {
             RGBColor[
             0.2496659047127254, 0.3797450739586806, 0.9375294759745583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 395}], {
             RGBColor[
             0.25216611947306267`, 0.3823729581945666, 0.9376718595064233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 447}], {
             RGBColor[
             0.24292230663621342`, 0.3726571248114532, 0.9371454380403603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 452}], {
             RGBColor[
             0.23164904535488023`, 0.3608082124387239, 0.9365034424876839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 463}], {
             RGBColor[
             0.25322101360276406`, 0.3834817188090337, 0.9377319341665338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 441}], {
             RGBColor[
             0.4099049258998564, 0.5294607772190044, 0.947339757307013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 481}], {
             RGBColor[
             0.3439470735768655, 0.47233140067487944`, 0.9431369812812307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 347}], {
             RGBColor[
             0.1789719601845752, 0.3054412560046289, 0.9335035604159989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 368}], {
             RGBColor[
             0.2935592851755068, 0.41669369113168975`, 0.9403654874960453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 386}], {
             RGBColor[
             0.1789719601845752, 0.3054412560046289, 0.9335035604159989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 401}], {
             RGBColor[
             0.4762346490241563, 0.5642173274993956, 0.9557801417908952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 421}], {
             RGBColor[
             0.17903676307516053`, 0.3055093679513746, 0.9335072508447505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 405}], {
             RGBColor[
             0.9345940973525277, 0.7578425175728066, 0.403625723074449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 428}], {
             RGBColor[
             0.8527545036662538, 0.3801225472055363, 0.19711821090416948`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 434}], {
             RGBColor[
             0.9331890448533395, 0.7583565146768234, 0.5065076494810187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 469}], {
             RGBColor[
             0.8678030946468546, 0.4926065528105953, 0.21140400054171546`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 474}], {
             RGBColor[
             0.9341363327937491, 0.7587482425843726, 0.49080863680582576`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 475}], {
             RGBColor[
             0.8570894511774583, 0.4134428533627656, 0.20126936153652183`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 491}], {
             RGBColor[
             0.9346684716417725, 0.7580015966571071, 0.4117209054738351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 495}], {
             RGBColor[
             0.8586889913459645, 0.42573762002087545`, 0.2028010830083056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 399}], {
             RGBColor[
             0.24928505714751653`, 0.3793447790205158, 0.9375077872691331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 412}], {
             RGBColor[
             0.2497253233645969, 0.37980752672915763`, 0.9375328597788803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 483}], {
             RGBColor[
             0.27685916583525294`, 0.4083269155507945, 0.9390780919666615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 431}], {
             RGBColor[
             0.4169264678183623, 0.535542483915856, 0.9477871637491544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 433}], {
             RGBColor[
             0.35540962848104596`, 0.48225968960811955`, 0.9438673651437858]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 436}], {
             RGBColor[
             0.42911640965865483`, 0.5455685636524759, 0.9487109542359491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 462}], {
             RGBColor[
             0.4245956854340748, 0.5418984360706564, 0.9483550662650316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 487}], {
             RGBColor[
             0.4823721914903405, 0.5888040064890694, 0.952903444464096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 406}], {
             RGBColor[
             0.9365881325497546, 0.9446037269852596, 0.7033574817962612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 413}], {
             RGBColor[
             0.9281969547806851, 0.9162983140279535, 0.6707593407043844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 486}], {
             RGBColor[
             0.9087427412464592, 0.930070810978078, 0.9911578879759511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 350}], {
             RGBColor[
             0.33430977302587317`, 0.4637717331289171, 0.9425306751676419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 354}], {
             RGBColor[
             0.3341066984387609, 0.463595840128386, 0.9425177354345229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 414}], {
             RGBColor[
             0.2905537605670515, 0.4227208029013707, 0.9398579788773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 415}], {
             RGBColor[
             0.29673111972249494`, 0.4292135990409338, 0.9402097703426187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 482}], {
             RGBColor[
             0.33246549585026375`, 0.4621743129354704, 0.9424131594568423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 496}], {
             RGBColor[
             0.2916695481926115, 0.42389356644085574`, 0.9399215213319159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 377}], {
             RGBColor[
             0.9088984029132244, 0.9290240327940705, 0.9505769466051841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 403}], {
             RGBColor[
             0.8828018353475209, 0.9093862367613971, 0.9886836212135901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 449}], {
             RGBColor[
             0.7824972356635673, 0.8301470968699212, 0.9789198336489376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 488}], {
             RGBColor[
             0.8030279977952235, 0.8461858842867422, 0.9809661481473407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 344}], {
             RGBColor[
             0.4329675168621825, 0.5491533716913533, 0.9488874962659426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 393}], {
             RGBColor[
             0.4317017689879543, 0.548125780545763, 0.9487878519566961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 424}], {
             RGBColor[
             0.36139324266635137`, 0.48744239547023754`, 0.9442486357485711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 392}], {
             RGBColor[
             0.34232526370384136`, 0.4706729127563853, 0.943042932303461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 442}], {
             RGBColor[
             0.331297230301234, 0.4590817504325423, 0.942414902115696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 459}], {
             RGBColor[
             0.3845976264069504, 0.5075408663801063, 0.9457271985616913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 492}], {
             RGBColor[
             0.32763422405457243`, 0.45523169861929097`, 0.9422062993288807]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 340}], {
             RGBColor[
             0.37011932022613914`, 0.4950004852671151, 0.9448046536945134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 355}], {
             RGBColor[
             0.36575544066311605`, 0.49122071212458884`, 0.9445265911475849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 361}], {
             RGBColor[
             0.5235027630627838, 0.6226423570970218, 0.9560294677740079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 363}], {
             RGBColor[
             0.40380771802618465`, 0.5241796822134083, 0.9469512486128518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 369}], {
             RGBColor[
             0.4113757512055576, 0.5307347321729735, 0.9474334769948924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 370}], {
             RGBColor[
             0.49712370807879736`, 0.6012548758448955, 0.9539335150694623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 379}], {
             RGBColor[
             0.3560516389210633, 0.4828157667828796, 0.9439082734813162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 498}], {
             RGBColor[
             0.4323467950368561, 0.5486660596707702, 0.9488340391891498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 383}], {
             RGBColor[
             0.3028573462736385, 0.4337853452642071, 0.940627021112898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 409}], {
             RGBColor[
             0.25916391695491414`, 0.389728087033979, 0.938070373720701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 482}], {
             RGBColor[
             0.3176268052914761, 0.44657790833086347`, 0.9415681179813948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 496}], {
             RGBColor[
             0.27683085763382376`, 0.40829716183624876`, 0.9390764798564684]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 409}], {
             RGBColor[
             0.23189710424361965`, 0.36106893805863094`, 0.9365175690744273]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 456}], {
             RGBColor[
             0.22294853768143919`, 0.3516634272298894, 0.936007961446929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 458}], {
             RGBColor[
             0.22636890121139194`, 0.35525844616344304`, 0.9362027460899854]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 348}], {
             RGBColor[
             0.9100611549268829, 0.8839036332529456, 0.6426467308354947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 361}], {
             RGBColor[
             0.752206073850372, 0.8066735064022713, 0.9758502482621753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 370}], {
             RGBColor[
             0.7258270188663856, 0.785286025150145, 0.9737542955576297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 375}], {
             RGBColor[
             0.9092060692572821, 0.9298599802312014, 0.9710835499900707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 498}], {
             RGBColor[
             0.6610501058244442, 0.7326972089760198, 0.9686548196773171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 369}], {
             RGBColor[
             0.37002637582951403`, 0.49491998150227967`, 0.9447987313597479]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 379}], {
             RGBColor[
             0.31470226354501973`, 0.4470010161121858, 0.9412735278461717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 390}], {
             RGBColor[
             0.3104293975603457, 0.44256111009978116`, 0.9410283217053288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 425}], {
             RGBColor[
             0.3477240886796976, 0.47560286131865376`, 0.9433776493436998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 478}], {
             RGBColor[
             0.29307363534810826`, 0.42431910359583813`, 0.9400399367228911]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 365}], {
             RGBColor[
             0.2143326753092825, 0.34260760959952685`, 0.9355173008308608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 355}], {
             RGBColor[
             0.3330706823231735, 0.4629108172342508, 0.9424439472481606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 362}], {
             RGBColor[
             0.3629480512357022, 0.4887890925060583, 0.944347706775747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 363}], {
             RGBColor[
             0.37112295968624204`, 0.49586978732307024`, 0.9448686047134276]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 378}], {
             RGBColor[
             0.31025949401998754`, 0.4407803246133216, 0.9410773105637218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 379}], {
             RGBColor[
             0.32336688058112073`, 0.45450587189254155`, 0.941825629581892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 380}], {
             RGBColor[
             0.3051428116901297, 0.43540236706824387`, 0.9407859230744895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 498}], {
             RGBColor[
             0.39966203669691347`, 0.5203561647804322, 0.9467513952897255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 387}], {
             RGBColor[
             0.8843435887930974, 0.9064532397024012, 0.7600495256450741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 403}], {
             RGBColor[
             0.9612426733705868, 0.9674078133042042, 0.7674804702008887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 405}], {
             RGBColor[
             0.9937930272646951, 0.989132237877419, 0.5657875066366207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 450}], {
             RGBColor[
             0.9056409272943111, 0.562891578052587, 0.35323513131972123`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 469}], {
             RGBColor[
             0.927002024559022, 0.7238962731152077, 0.3735657841038871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 491}], {
             RGBColor[
             0.9938674015539399, 0.9892913169617195, 0.5738826890360067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 395}], {
             RGBColor[
             0.2624873580585535, 0.3932212343522405, 0.9382596387749628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 447}], {
             RGBColor[
             0.2532435452217043, 0.38350540096912705`, 0.9377332173088998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 453}], {
             RGBColor[
             0.27214698791275327`, 0.40337411778491095`, 0.9388097404050177]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 463}], {
             RGBColor[
             0.2635422521882549, 0.3943299949667075, 0.9383197134350733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 392}], {
             RGBColor[
             0.29944445035868683`, 0.4320654815746701, 0.9403642905083368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 433}], {
             RGBColor[
             0.3091968798489231, 0.4407663035487692, 0.9409764153784905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 465}], {
             RGBColor[
             0.2877565452274621, 0.4197807522257663, 0.9396986816018197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 387}], {
             RGBColor[
             0.6194283934274943, 0.6998852662527452, 0.9645732255440658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 424}], {
             RGBColor[
             0.39216870621134226`, 0.5138154925134429, 0.9462878321282429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 375}], {
             RGBColor[
             0.8089633164388916, 0.8512244424146573, 0.9611785706908804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 426}], {
             RGBColor[
             0.7649497936964772, 0.8167095300211071, 0.9770990522255436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 448}], {
             RGBColor[
             0.6138322543981429, 0.6971096748541594, 0.9629241548523259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 489}], {
             RGBColor[
             0.8249113944148371, 0.8621373590775923, 0.8902454594075883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 498}], {
             RGBColor[
             0.5608073530060538, 0.6540616711594758, 0.9587498403781267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 358}], {
             RGBColor[
             0.2217544347167852, 0.3504083493035373, 0.935939959049609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 404}], {
             RGBColor[
             0.21566548218765702`, 0.3440084741335353, 0.9355932022108733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 407}], {
             RGBColor[
             0.2161204994130187, 0.34448672608714886`, 0.9356191147687198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 408}], {
             RGBColor[
             0.22019359510263653`, 0.34876780790611966`, 0.9358510715426385]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 430}], {
             RGBColor[
             0.22881084125106885`, 0.35782507997308444`, 0.9363418109627185]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 368}], {
             RGBColor[
             0.2935143249909316, 0.4166464351270609, 0.9403629270800464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 386}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 421}], {
             RGBColor[
             0.17899180289058533`, 0.3054621119467458, 0.9335046904287516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 477}], {
             RGBColor[
             0.2117993137193227, 0.3399448859440771, 0.9353730296360853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 375}], {
             RGBColor[
             0.959056524042907, 0.9223909347161948, 0.6272014222552931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 428}], {
             RGBColor[
             0.8951225528654855, 0.5552983535621828, 0.23772264959288408`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 359}], {
             RGBColor[
             0.3995263663781553, 0.520471390602876, 0.94667844467169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 371}], {
             RGBColor[
             0.3882726943942144, 0.5107240255563866, 0.9459613706441047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 397}], {
             RGBColor[
             0.38607476166702576`, 0.5088202866994067, 0.9458213203142838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 419}], {
             RGBColor[
             0.4631460027688009, 0.5739634184897324, 0.951177660656908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 354}], {
             RGBColor[
             0.36196691822383753`, 0.4879392844043602, 0.9442851898478128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 383}], {
             RGBColor[
             0.34555625661750283`, 0.4737251941447882, 0.9432395170016354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 414}], {
             RGBColor[
             0.31841398035212815`, 0.44706424717734483`, 0.94162543329059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 479}], {
             RGBColor[
             0.3868303332701487, 0.5094747248458988, 0.9458694646687091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 482}], {
             RGBColor[
             0.36032571563534044`, 0.4865177572114446, 0.9441806138701323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 356}], {
             RGBColor[
             0.2796916905937343, 0.4113040786644009, 0.9392394000613121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 463}], {
             RGBColor[
             0.27857140569147526`, 0.4101265882019613, 0.9391756014934415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 367}], {
             RGBColor[
             0.2288379775147259, 0.35785360190672644`, 0.9363433563327893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 399}], {
             RGBColor[
             0.23466592421327268`, 0.3639791434000619, 0.936675249275597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 412}], {
             RGBColor[
             0.23510619043035305`, 0.36444189110870373`, 0.9367003217853442]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 457}], {
             RGBColor[
             0.22470998276050042`, 0.3535148176900512, 0.9361082731383572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 418}], {
             RGBColor[
             0.809068015481273, 0.8509060188194038, 0.9430493347226458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 420}], {
             RGBColor[
             0.8041526849608935, 0.8472401733654197, 0.9513697071701304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 432}], {
             RGBColor[
             0.7691435045990516, 0.820174333900838, 0.9774842614710615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 441}], {
             RGBColor[
             0.5448974710637005, 0.6413248437593597, 0.9573393706579376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 372}], {
             RGBColor[
             0.416108457877265, 0.5343687074376324, 0.9478635928798225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 414}], {
             RGBColor[
             0.3182109057650159, 0.4468883541768137, 0.941612493557471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 415}], {
             RGBColor[
             0.32438826492045936`, 0.4533811503163769, 0.9419642850227896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 479}], {
             RGBColor[
             0.38662725868303643`, 0.5092988318453677, 0.9458565249355901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 482}], {
             RGBColor[
             0.3601226410482282, 0.48634186421091347`, 0.9441676741370133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 362}], {
             RGBColor[
             0.3585841716726791, 0.48500931936353203`, 0.9440696442288183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 363}], {
             RGBColor[
             0.366759080123219, 0.492090014180544, 0.9445905421664991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 378}], {
             RGBColor[
             0.30589561445696456`, 0.4370005514707954, 0.940799248016793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 384}], {
             RGBColor[
             0.3062638013444511, 0.43738753923394075`, 0.9408202157153518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 498}], {
             RGBColor[
             0.3952981571338905, 0.516576391637906, 0.946473332742797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 463}], {
             RGBColor[
             0.26821764598055253`, 0.3992441302795001, 0.9385859701949193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 418}], {
             RGBColor[
             0.9428078871600445, 0.8265116366232681, 0.582732825135219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 420}], {
             RGBColor[
             0.937892556639665, 0.822845791169284, 0.5910531975827036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 404}], {
             RGBColor[
             0.21953726017780179`, 0.34807795828608057`, 0.9358136942396298]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 407}], {
             RGBColor[
             0.21999227740316346`, 0.34855621023969413`, 0.9358396067974764]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 408}], {
             RGBColor[
             0.2240653730927813, 0.35283729205866493`, 0.936071563571395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 430}], {
             RGBColor[
             0.23268261924121364`, 0.3618945641256297, 0.936562302991475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 371}], {
             RGBColor[
             0.37419759071797254`, 0.49853287818730624`, 0.94506451748398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 397}], {
             RGBColor[
             0.3719996579907838, 0.4966291393303264, 0.9449244671541592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 419}], {
             RGBColor[
             0.44907089909255904`, 0.561772271120652, 0.9502808074967835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 427}], {
             RGBColor[
             0.3324756951564906, 0.4596914885288097, 0.9425050411722034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 393}], {
             RGBColor[
             0.5202889035975207, 0.6214329965452928, 0.9553781948537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 466}], {
             RGBColor[
             0.5414372478398441, 0.638602175123262, 0.9570430699813932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 468}], {
             RGBColor[
             0.5288716731016017, 0.6284008754780657, 0.9560538619087819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 363}], {
             RGBColor[
             0.5245064025228867, 0.6235116591529769, 0.9560934187929221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 370}], {
             RGBColor[
             0.6178223925754994, 0.7005868527844641, 0.9630756852495326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 498}], {
             RGBColor[
             0.5530454795335582, 0.6479980366103388, 0.95797620936922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 363}], {
             RGBColor[
             0.3966364490357477, 0.5179682894523514, 0.9464943016940854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 384}], {
             RGBColor[
             0.33614117025697976`, 0.4632658145057482, 0.9427239752429382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 498}], {
             RGBColor[
             0.4251755260464191, 0.5424546669097134, 0.9483770922703834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 370}], {
             RGBColor[
             0.4981273475389003, 0.6021241779008506, 0.9539974660883765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 379}], {
             RGBColor[
             0.35705527838116624`, 0.4836850688388347, 0.9439722245002304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 498}], {
             RGBColor[
             0.433350434496959, 0.5495353617267253, 0.948897990208064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 374}], {
             RGBColor[
             0.2551484985501697, 0.3855076276983612, 0.93784170158283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 437}], {
             RGBColor[
             0.25719856867599794`, 0.38766238138256004`, 0.9379584500436889]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 435}], {
             RGBColor[
             0.2615619901606841, 0.3922486140198663, 0.9382069404421383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 473}], {
             RGBColor[
             0.29591877827497415`, 0.42668767083692927`, 0.940224732684648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 416}], {
             RGBColor[
             0.24568937276892794`, 0.3755654867590621, 0.9373030183631108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 457}], {
             RGBColor[
             0.22571706608911693`, 0.3545733261211982, 0.9361656250440755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 499}], {
             RGBColor[
             0.24528184927831587`, 0.3751371537319471, 0.9372798105031974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 386}], {
             RGBColor[
             0.2935143249909316, 0.4166464351270609, 0.9403629270800464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 401}], {
             RGBColor[
             0.5907770138305127, 0.6754225066218276, 0.9626395084549426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 500}], {
             RGBColor[
             0.6137971561371982, 0.33936679556971105`, 0.5567621778131115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 370}], {
             RGBColor[
             0.5056953807182732, 0.6086792278604158, 0.9544796944704173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 379}], {
             RGBColor[
             0.3646233115605392, 0.49024011879839996`, 0.944454452882271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 390}], {
             RGBColor[
             0.36035044557586515`, 0.48580021278599533`, 0.9442092467414281]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 425}], {
             RGBColor[
             0.397645136695217, 0.5188419640048679, 0.9465585743797993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 466}], {
             RGBColor[
             0.46172779849419876`, 0.5729843638939052, 0.9510184053391775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 466}], {
             RGBColor[
             0.5474757553674385, 0.6435045075658272, 0.9575184434137474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 382}], {
             RGBColor[
             0.322584307384319, 0.45137597056269757`, 0.9418655472151594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 419}], {
             RGBColor[
             0.43781722710861815`, 0.5520249060741627, 0.9495637334691982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 427}], {
             RGBColor[
             0.3212220231725497, 0.4499441234823203, 0.9417879671446181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 429}], {
             RGBColor[
             0.3282709430209225, 0.4573529851702918, 0.9421893927020404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 417}], {
             RGBColor[
             0.5857428674141524, 0.6736726673586156, 0.9611454890036907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 398}], {
             RGBColor[
             0.27738327375901567`, 0.40887778620903076`, 0.9391079391375716]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 472}], {
             RGBColor[
             0.31103110428016545`, 0.44242232361832246`, 0.9410908260962028]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 391}], {
             RGBColor[
             0.24642877472957408`, 0.3763426451004932, 0.9373451262109225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 437}], {
             RGBColor[
             0.25378039219455883`, 0.3840696611756612, 0.9377637899498099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 426}], {
             RGBColor[
             0.9141879156308917, 0.9338323693009003, 0.9715587229445324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 489}], {
             RGBColor[
             0.9741495163492516, 0.9792601983573855, 0.8847051301265769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 400}], {
             RGBColor[
             0.2876884645475003, 0.41970919511456195`, 0.9396948045078122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 414}], {
             RGBColor[
             0.27705653417076703`, 0.40853436218529504`, 0.9390893318013886]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 415}], {
             RGBColor[
             0.28323389332621046`, 0.41502715832485815`, 0.9394411232667073]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 464}], {
             RGBColor[
             0.2616609318454717, 0.3923526080038432, 0.9382125750247157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 485}], {
             RGBColor[
             0.26372814560153673`, 0.3945253807303899, 0.938330299789955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 497}], {
             RGBColor[
             0.25772437162935435`, 0.38821503362437043`, 0.9379883937440268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 403}], {
             RGBColor[
             0.9550085431684978, 0.9657910070072111, 0.9549749729457403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 449}], {
             RGBColor[
             0.8547039434845443, 0.8865518671157351, 0.9452111853810878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 484}], {
             RGBColor[
             0.9869984046810305, 0.9863165950507087, 0.692275872605006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 488}], {
             RGBColor[
             0.8752347056162003, 0.9025906545325564, 0.9472574998794909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 380}], {
             RGBColor[
             0.27796774382392075`, 0.40949210130478847`, 0.939141223843122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 380}], {
             RGBColor[
             0.29107513038505384`, 0.42321764858400834`, 0.9398895428612922]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 390}], {
             RGBColor[
             0.30502633329137085`, 0.4378812473959014, 0.9406840432278518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 478}], {
             RGBColor[
             0.2876705710791334, 0.41963924089195836`, 0.9396956582454141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 390}], {
             RGBColor[
             0.2868022644003798, 0.4187777425716037, 0.9396443367204493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 411}], {
             RGBColor[
             0.2562205129796168, 0.38663438283335066`, 0.9379027512186837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 478}], {
             RGBColor[
             0.26944650218814237`, 0.40053573606766074`, 0.9386559517380118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 419}], {
             RGBColor[
             0.5409976687744238, 0.6382453050351424, 0.9570084647071322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 439}], {
             RGBColor[
             0.7151086431122187, 0.7765792866784462, 0.9729163506443089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 416}], {
             RGBColor[
             0.2718791903645599, 0.40309264558241453`, 0.938794489730819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 427}], {
             RGBColor[
             0.2808624118228371, 0.41253458090420103`, 0.9393060709033827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 429}], {
             RGBColor[
             0.2879113316712099, 0.41994344259217253`, 0.9397074964608051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 499}], {
             RGBColor[
             0.27147166687394786`, 0.40266431255529955`, 0.9387712818709056]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 479}], {
             RGBColor[
             0.37021659707670174`, 0.49508474158579574`, 0.9448108520894127]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 482}], {
             RGBColor[
             0.34371197944189347`, 0.47212777395134153`, 0.9431220012908359]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 496}], {
             RGBColor[
             0.30291603178424115`, 0.4338470274567268, 0.9406303631659094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 435}], {
             RGBColor[
             0.2709692417504848, 0.4021362318949472, 0.9387426695033958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 391}], {
             RGBColor[
             0.23729940724147955`, 0.36674710103517516`, 0.9368252222381643]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 421}], {
             RGBColor[
             0.17899180289058533`, 0.3054621119467458, 0.9335046904287516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 403}], {
             RGBColor[
             0.8520128910253049, 0.8851986373727346, 0.9856507029983317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 405}], {
             RGBColor[
             0.8845632449194131, 0.9069230619459494, 0.7839577394340637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 491}], {
             RGBColor[
             0.8846376192086578, 0.9070821410302499, 0.7920529218334498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 487}], {
             RGBColor[
             0.7628017392959624, 0.8144116714200249, 0.9680174393113103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 490}], {
             RGBColor[
             0.9683628300119925, 0.9748687448836537, 0.8911081388957877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 409}], {
             RGBColor[
             0.23002772223876133`, 0.35910409904586005`, 0.9364111105347535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 451}], {
             RGBColor[
             0.21497280031897864`, 0.34328042157098726`, 0.9355537550031829]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 456}], {
             RGBColor[
             0.22107915567658082`, 0.3496985882171184, 0.9359015029072553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 458}], {
             RGBColor[
             0.2244995192065336, 0.35329360715067204`, 0.9360962875503116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 425}], {
             RGBColor[
             0.3380481584260487, 0.4664830926023694, 0.94278816472538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 478}], {
             RGBColor[
             0.2833977050944594, 0.41519933487955374`, 0.9394504521045712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 459}], {
             RGBColor[
             0.34827375514967984`, 0.47582519706689724`, 0.9434219649183455]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 465}], {
             RGBColor[
             0.2943134873153461, 0.42667251409427237`, 0.9400720897535981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 492}], {
             RGBColor[
             0.2913103527973019, 0.4235160293060819, 0.9399010656855349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 468}], {
             RGBColor[
             0.4697942541627981, 0.5804391653761509, 0.9514030710822032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 398}], {
             RGBColor[
             0.24489676758341208`, 0.3747324084550136, 0.93725788067035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 445}], {
             RGBColor[
             0.2291408986849781, 0.35817199126297306`, 0.9363606072453035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 460}], {
             RGBColor[
             0.23849436642390026`, 0.3680030789006874, 0.9368932733958195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 440}], {
             RGBColor[
             0.2733307058970075, 0.4046182804384171, 0.9388771513930672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 447}], {
             RGBColor[
             0.2557437599820415, 0.3861332852050131, 0.9378756008407647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 453}], {
             RGBColor[
             0.2746472026730905, 0.406002002020797, 0.9389521239368825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 463}], {
             RGBColor[
             0.2660424669485921, 0.39695787920259357`, 0.9384620969669382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 422}], {
             RGBColor[
             0.6137790328303492, 0.6759479174311498, 0.7377723993512193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 443}], {
             RGBColor[
             0.9640290207521414, 0.8833364286136021, 0.40253589756085995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 446}], {
             RGBColor[
             0.6108486673250959, 0.6728679174892245, 0.7376055193707824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 419}], {
             RGBColor[
             0.43561929438142943`, 0.5501211672171827, 0.9494236831393772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 472}], {
             RGBColor[
             0.3434973849835166, 0.4719419030173265, 0.9431083275217065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 445}], {
             RGBColor[
             0.2453951867466454, 0.3752562785971719, 0.9372862649043511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 460}], {
             RGBColor[
             0.2547486544855675, 0.3850873662348864, 0.9378189310548671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 472}], {
             RGBColor[
             0.2947988861662292, 0.4253612331985043, 0.9401664252880289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 412}], {
             RGBColor[
             0.24194122045751632`, 0.37162594103318614`, 0.9370895666338703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 414}], {
             RGBColor[
             0.28528989827003975`, 0.41718814987906533`, 0.9395582097066717]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 415}], {
             RGBColor[
             0.2914672574254832, 0.4236809460186285, 0.9399100011719903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 464}], {
             RGBColor[
             0.26989429594474446`, 0.40100639569761354`, 0.9386814529299987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 450}], {
             RGBColor[
             0.7955804305647025, 0.4800334417304184, 0.5713225662708019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 454}], {
             RGBColor[
             0.8366674019364873, 0.7306087240183134, 0.6081129719353302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 471}], {
             RGBColor[
             0.8151324803555211, 0.6303190641854999, 0.5900456312313715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 475}], {
             RGBColor[
             0.806227884360017, 0.5618744373452094, 0.5815185800497742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 500}], {
             RGBColor[
             0.7964725199858478, 0.48689043193741693`, 0.5721768321079614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 431}], {
             RGBColor[
             0.5004255816893457, 0.6051773211877334, 0.9538503277794443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 436}], {
             RGBColor[
             0.5126155235296384, 0.6152034009243532, 0.954774118266239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 459}], {
             RGBColor[
             0.4714286755649022, 0.5800616585296188, 0.952002670562152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 462}], {
             RGBColor[
             0.5080947993050582, 0.6115332733425336, 0.9544182302953215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 487}], {
             RGBColor[
             0.565871305361324, 0.6584388437609466, 0.958966608494386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 405}], {
             RGBColor[
             0.9614623294969025, 0.9678776355477525, 0.7913886839898783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 449}], {
             RGBColor[
             0.8286073759188407, 0.8669140710830616, 0.9833178599894938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 491}], {
             RGBColor[
             0.9615367037861473, 0.968036714632053, 0.7994838663892643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 407}], {
             RGBColor[
             0.2139033248740353, 0.3421563350696921, 0.9354928499587406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 408}], {
             RGBColor[
             0.2179764205636531, 0.3464374168886629, 0.9357248067326592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 434}], {
             RGBColor[
             0.9926076308918226, 0.9901160572249841, 0.6925776468321798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 469}], {
             RGBColor[
             0.9272216806853377, 0.724366095358756, 0.3974739978928766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 474}], {
             RGBColor[
             0.9935549188322322, 0.9905077851325332, 0.6768786341569868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 491}], {
             RGBColor[
             0.9940870576802556, 0.9897611392052678, 0.5977909028249961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 413}], {
             RGBColor[
             0.9822272031257195, 0.951710324271208, 0.3854564695648335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 476}], {
             RGBColor[
             0.9195554041525527, 0.6768776802935997, 0.3060621599750899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 486}], {
             RGBColor[
             0.9627729895914936, 0.9654828212213326, 0.7058550168364002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 493}], {
             RGBColor[
             0.9920978208950986, 0.9843432363296774, 0.4801786397760631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 408}], {
             RGBColor[
             0.2184314377890148, 0.3469156688422765, 0.9357507192905059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 430}], {
             RGBColor[
             0.22704868393744712`, 0.35597294090924125`, 0.9362414587105858]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{408, 430}], {
             RGBColor[
             0.23112177962706493`, 0.36025402272821205`, 0.9364734154845045]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 456}], {
             RGBColor[
             0.23260709522442666`, 0.3618151835954873, 0.9365580020104467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 458}], {
             RGBColor[
             0.23602745875437942`, 0.36541020252904094`, 0.9367527866535031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 496}], {
             RGBColor[
             0.25922260246551676`, 0.38978976922649866`, 0.9380737157737123]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{411, 478}], {
             RGBColor[
             0.2528159536736963, 0.3830559751413007, 0.9377088666028057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 476}], {
             RGBColor[
             0.9111642263834832, 0.6485722673362936, 0.273464018883213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 486}], {
             RGBColor[
             0.9543818118224241, 0.9371774082640264, 0.6732568757445232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 493}], {
             RGBColor[
             0.9837066431260291, 0.9560378233723712, 0.44758049868418615`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 415}], {
             RGBColor[
             0.2808353270487499, 0.4125061130893616, 0.9393045284655668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 485}], {
             RGBColor[
             0.26132957932407624`, 0.39200433549489333`, 0.9381937049888145]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{415, 464}], {
             RGBColor[
             0.2654397247234546, 0.39632435890790974`, 0.9384277716888938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{415, 485}], {
             RGBColor[
             0.2675069384795197, 0.39849713163445644`, 0.9385454964541331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 427}], {
             RGBColor[
             0.2705169061527906, 0.4016607985020373, 0.9387169096602777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 429}], {
             RGBColor[
             0.2775658260011634, 0.4090696601900088, 0.9391183352177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 499}], {
             RGBColor[
             0.26112616120390136`, 0.3917905301531358, 0.9381821206278006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{417, 461}], {
             RGBColor[
             0.8227440842305245, 0.8622334494485463, 0.9748712810946092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 420}], {
             RGBColor[
             0.9735581601714495, 0.9798002996671817, 0.9296433170801228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 432}], {
             RGBColor[
             0.9385489798096075, 0.9527344602026001, 0.9557578713810538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 432}], {
             RGBColor[
             0.933633649289228, 0.949068614748616, 0.9640782438285385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 439}], {
             RGBColor[
             0.9147776569049322, 0.9340333582536569, 0.9622797424419812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 423}], {
             RGBColor[
             0.18344124862659156`, 0.31013876152644193`, 0.9337580797810521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 477}], {
             RGBColor[
             0.21186411660990806`, 0.34001299789082284`, 0.9353767200648369]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 443}], {
             RGBColor[
             0.5842619922483114, 0.5706803433206208, 0.6014015077150748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 446}], {
             RGBColor[
             0.2310816388212659, 0.36021183219624314`, 0.9364711295249972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 446}], {
             RGBColor[
             0.20798858239401255`, 0.3359395657068551, 0.9351560141245807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 477}], {
             RGBColor[
             0.21624875945532895`, 0.3446215355237733, 0.9356264189883857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 440}], {
             RGBColor[
             0.30113413549531765`, 0.4327459792905174, 0.940500626045089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 453}], {
             RGBColor[
             0.3024506322714007, 0.4341297008728973, 0.9405755985889044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 470}], {
             RGBColor[
             0.28803826967359597`, 0.4189813939860375, 0.9397548358601392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{425, 466}], {
             RGBColor[
             0.4394255113443823, 0.5536672437102792, 0.9495973233231294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 448}], {
             RGBColor[
             0.7190568535901429, 0.7797176017404024, 0.9733043071059779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 489}], {
             RGBColor[
             0.9301359936068372, 0.9447452859638352, 0.9006256116612403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 460}], {
             RGBColor[
             0.2639231904685617, 0.39473038525219195`, 0.938341407306589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 499}], {
             RGBColor[
             0.27010938266217854`, 0.4012324654749223, 0.9386937018003643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 495}], {
             RGBColor[
             0.8362679836981737, 0.2797771922017657, 0.1823635681891872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{429, 499}], {
             RGBColor[
             0.2771583025105514, 0.4086413271628938, 0.9390951273577867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 433}], {
             RGBColor[
             0.3870230907643596, 0.509641681699111, 0.9458817470057914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 436}], {
             RGBColor[
             0.46072987194196846`, 0.5729505557434673, 0.9507253360979548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 459}], {
             RGBColor[
             0.41954302397723237`, 0.5378088133487329, 0.9479538883938678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 462}], {
             RGBColor[
             0.4562091477173884, 0.5692804281616477, 0.9503694481270373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 487}], {
             RGBColor[
             0.5139856537736541, 0.6161859985800608, 0.9549178263261018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{432, 467}], {
             RGBColor[
             0.8027318187709938, 0.8464550865365966, 0.9808037893677689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 462}], {
             RGBColor[
             0.3946923083800721, 0.5159976338539112, 0.9464496495216687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 469}], {
             RGBColor[
             0.9258166281861495, 0.7248800924627727, 0.5003559242994462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 474}], {
             RGBColor[
             0.992149866333044, 0.99102178223655, 0.7797605605635565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 495}], {
             RGBColor[
             0.9167025248852594, 0.6580111596730529, 0.4917530067660364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 459}], {
             RGBColor[
             0.4317329658175249, 0.5478348930853527, 0.9488776788806625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 462}], {
             RGBColor[
             0.46839908955768095`, 0.5793065078982675, 0.951293238613832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 487}], {
             RGBColor[
             0.5261755956139467, 0.6262120783166807, 0.9558416168128965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 457}], {
             RGBColor[
             0.22152681415849518`, 0.35016910566479753`, 0.9359269963955489]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 460}], {
             RGBColor[
             0.23490540515407732`, 0.3642308530528161, 0.9366888873608955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 453}], {
             RGBColor[
             0.2829903357512072, 0.4147711638710876, 0.939427253023122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 470}], {
             RGBColor[
             0.2685779731534025, 0.3996228569842277, 0.9386064902943567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 467}], {
             RGBColor[
             0.5784857852356426, 0.6676055963951182, 0.960658898554645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 444}], {
             RGBColor[
             0.27761918641957545`, 0.4091257453730057, 0.939121374014589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 492}], {
             RGBColor[
             0.2802823193946945, 0.4119248669822389, 0.9392730354977699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{443, 446}], {
             RGBColor[
             0.5813316267430582, 0.5676003433786956, 0.6012346277346379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{444, 492}], {
             RGBColor[
             0.2739561801729139, 0.4052756935597544, 0.9389127712277736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{445, 460}], {
             RGBColor[
             0.23899278558713355`, 0.3685269490428458, 0.9369216576298206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 453}], {
             RGBColor[
             0.26540338983624123`, 0.39628616863768357`, 0.9384257024708196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 463}], {
             RGBColor[
             0.2567986541117429, 0.38724204581948013`, 0.9379356755008752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{449, 488}], {
             RGBColor[
             0.7488335383665432, 0.8037137186084069, 0.9756003869232444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 454}], {
             RGBColor[
             0.8587954548220276, 0.3876960227591984, 0.20138137545633958`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 469}], {
             RGBColor[
             0.8390695807149537, 0.298125435533924, 0.18492162257597716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 471}], {
             RGBColor[
             0.8372605332410615, 0.2874063629263848, 0.183314034752381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 475}], {
             RGBColor[
             0.8283559372455574, 0.2189617360860943, 0.17478698357078354`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 491}], {
             RGBColor[
             0.9059349577098716, 0.5635204793804358, 0.38523852750809673`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 500}], {
             RGBColor[
             0.8186005728713881, 0.14397773067830186`, 0.16544523562897076`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{451, 456}], {
             RGBColor[
             0.21755217330464396`, 0.3459915061206145, 0.9357006464788762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{453, 463}], {
             RGBColor[
             0.2757020968027919, 0.407110762635264, 0.939012198596993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 469}], {
             RGBColor[
             0.8801565520867384, 0.5487007178218191, 0.22171202824050545`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 471}], {
             RGBColor[
             0.8783475046128462, 0.5379816452142798, 0.2201044404169093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 475}], {
             RGBColor[
             0.8694429086173421, 0.4695370183739893, 0.21157738923531183`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 500}], {
             RGBColor[
             0.8596875442431727, 0.3945530129661969, 0.20223564129349905`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{456, 458}], {
             RGBColor[
             0.22707889219219896`, 0.35600469170029936`, 0.9362431790260048]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{461, 486}], {
             RGBColor[
             0.9396915520193736, 0.9545227464327241, 0.9862809714214389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{461, 493}], {
             RGBColor[
             0.9690163833229786, 0.9733831615410689, 0.7606045943611018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{462, 487}], {
             RGBColor[
             0.5216548713893666, 0.6225419507348611, 0.9554857288419789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 485}], {
             RGBColor[
             0.24593397699878092`, 0.3758225813134415, 0.9373169482121415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 497}], {
             RGBColor[
             0.23993020302659857`, 0.369512234207422, 0.9369750421662133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 468}], {
             RGBColor[
             0.49094259840512156`, 0.5976083439541202, 0.9530679462098963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 471}], {
             RGBColor[
             0.8586216305057723, 0.4484110579890054, 0.20364468753654688`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 474}], {
             RGBColor[
             0.9267639161265591, 0.7252718203703219, 0.4846569116242533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 475}], {
             RGBColor[
             0.8497170345102683, 0.3799664311487149, 0.19511763635494941`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 491}], {
             RGBColor[
             0.9272960549745825, 0.7245251744430564, 0.40556918029226263`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 495}], {
             RGBColor[
             0.8513165746787745, 0.3922611978068248, 0.19664935782673318`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 475}], {
             RGBColor[
             0.847907987036376, 0.36924735854117574`, 0.19351004853135326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 500}], {
             RGBColor[
             0.8381526226622067, 0.29426335313338325`, 0.18416830058954048`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{474, 495}], {
             RGBColor[
             0.917649812825669, 0.658402887580602, 0.4760539940908434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{476, 493}], {
             RGBColor[
             0.9210348441528622, 0.6812051793947629, 0.36818618909444256`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{479, 482}], {
             RGBColor[
             0.3849860560945393, 0.5078773046524521, 0.9457519489579096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{480, 481}], {
             RGBColor[
             0.33588196619861493`, 0.46534581002792214`, 0.9426230797707831]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{482, 496}], {
             RGBColor[
             0.31768549080207875`, 0.4466395905233832, 0.9415714600344062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{484, 500}], {
             RGBColor[
             0.9061921804601966, 0.5690195539734165, 0.316991474169404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{485, 497}], {
             RGBColor[
             0.24199741678266362`, 0.3716850069339687, 0.9370927669314526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{486, 493}], {
             RGBColor[
             0.9642524295918031, 0.9698103203224957, 0.7679790459557528]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.15793718311639351`], {
             RGBColor[
             0.2661654894960651, 0.39708718370006774`, 0.9384691029190212]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.15793718311639351`], {
             RGBColor[
             0.2124476857409665, 0.34062636604798524`, 0.9354099534635375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.15793718311639351`], {
             RGBColor[
             0.46166603367100856`, 0.5738403098087559, 0.9507631877904368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.15793718311639351`], {
             RGBColor[
             0.32430364693803726`, 0.45531725182765653`, 0.9418853195058047]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.15793718311639351`], {
             RGBColor[
             0.23860734128045696`, 0.3681218226379481, 0.9368997071467691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.15793718311639351`], {
             RGBColor[
             0.8276898195746623, 0.8654414113599355, 0.9834269879500976]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.15793718311639351`], {
             RGBColor[
             0.8386821070512293, 0.8742063630160551, 0.9844754421425435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.15793718311639351`], {
             RGBColor[
             0.6202936289377985, 0.7026213377380665, 0.963250933161866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.15793718311639351`], {
             RGBColor[
             0.5751436787516512, 0.6659665741948753, 0.9596965636934954]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.15793718311639351`], {
             RGBColor[
             0.2189624152550279, 0.3474737598249721, 0.9357809576716846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.15793718311639351`], {
             RGBColor[
             0.23891813183632316`, 0.3684484832174229, 0.9369174062091523]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.15793718311639351`], {
             RGBColor[
             0.27240341106773047`, 0.40364363477895904`, 0.9388243433243495]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.15793718311639351`], {
             RGBColor[
             0.29661626096016863`, 0.4290928751992627, 0.9402032293060224]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.15793718311639351`], {
             RGBColor[
             0.30674268007373295`, 0.4397363837396738, 0.9407799138938453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.15793718311639351`], {
             RGBColor[
             0.23423879357827926`, 0.36353020202103736`, 0.9366509248178173]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.15793718311639351`], {
             RGBColor[
             0.4038820814050813, 0.5242440920345965, 0.9469559869815982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.15793718311639351`], {
             RGBColor[
             0.8799712561457314, 0.9071292097399156, 0.9884136380424356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.15793718311639351`], {
             RGBColor[
             0.8843839202879132, 0.5678962094964264, 0.22523944788984251`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.15793718311639351`], {
             RGBColor[
             0.5597245266210166, 0.6534486118703385, 0.9584827115555565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.15793718311639351`], {
             RGBColor[
             0.8845340276069948, 0.5685778117739207, 0.22536470111635126`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.15793718311639351`], {
             RGBColor[
             0.9808877657874093, 0.9471920876142448, 0.3802530084370154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.15793718311639351`], {
             RGBColor[
             0.4514165271362265, 0.5654160397762044, 0.9499848398305268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.15793718311639351`], {
             RGBColor[
             0.2225015077722568, 0.35119357045200544`, 0.9359825037549226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.15793718311639351`], {
             RGBColor[
             0.8369720141620951, 0.8728427813654944, 0.9843123319561599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.15793718311639351`], {
             RGBColor[
             0.3133752819583538, 0.4458516513578495, 0.941188973752873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.15793718311639351`], {
             RGBColor[
             0.3866295369467384, 0.5093008051628776, 0.9458566701045386]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.15793718311639351`], {
             RGBColor[
             0.5121189165844965, 0.6148002330343991, 0.9547350235483862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.15793718311639351`], {
             RGBColor[
             0.9648560740830788, 0.9733102981108331, 0.9443736789601879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.15793718311639351`], {
             RGBColor[
             0.40962031041891445`, 0.5292142575946026, 0.9473216218602429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.15793718311639351`], {
             RGBColor[
             0.2679312243382506, 0.39894308297325987`, 0.938569658906113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.15793718311639351`], {
             RGBColor[
             0.4530382628066378, 0.5668207057031098, 0.9500881753934008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.15793718311639351`], {
             RGBColor[
             0.5357107322431658, 0.6339531317852908, 0.9565922576967049]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.15793718311639351`], {
             RGBColor[
             0.8784142522519405, 0.5407893411964669, 0.22025821055067316`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.15793718311639351`], {
             RGBColor[
             0.5437530683305409, 0.6404822625241338, 0.9572253798535508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.15793718311639351`], {
             RGBColor[
             0.23837242809378653`, 0.36787491398440125`, 0.9368863291883112]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.15793718311639351`], {
             RGBColor[
             0.254389289460926, 0.3847096508089296, 0.9377984657483468]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.15793718311639351`], {
             RGBColor[
             0.305640198745031, 0.4385776059618545, 0.9407171292131508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.15793718311639351`], {
             RGBColor[
             0.25996867538836677`, 0.3905739391721695, 0.9381162035229527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.15793718311639351`], {
             RGBColor[
             0.6236615875481659, 0.7053555982627691, 0.963516071200913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.15793718311639351`], {
             RGBColor[
             0.3862001571816754, 0.5089288979916344, 0.9458293104055944]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.15793718311639351`], {
             RGBColor[
             0.23252667542550592`, 0.36173065728791187`, 0.9365534222218687]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.15793718311639351`], {
             RGBColor[
             0.23247426890382172`, 0.3616755747108564, 0.9365504377479873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.15793718311639351`], {
             RGBColor[
             0.2931478124699098, 0.42544731592366486`, 0.940005706295612]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.15793718311639351`], {
             RGBColor[
             0.49667724948997916`, 0.6022639920478948, 0.9535193989500155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.15793718311639351`], {
             RGBColor[
             0.28278247170568477`, 0.41455268557990177`, 0.9394154154732368]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.15793718311639351`], {
             RGBColor[
             0.9176548470302313, 0.7112359389100995, 0.2526013609126037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.15793718311639351`], {
             RGBColor[
             0.23193365260590854`, 0.36110735270469657`, 0.9365196504495912]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.15793718311639351`], {
             RGBColor[
             0.20751087662989864`, 0.3354374666604766, 0.9351288094880167]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.15793718311639351`], {
             RGBColor[
             0.49021471545548245`, 0.5970174157848499, 0.9530106445977776]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.15793718311639351`], {
             RGBColor[
             0.44093802683048844`, 0.5563400894761129, 0.9493171590568191]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.15793718311639351`], {
             RGBColor[
             0.17892700081062782`, 0.30539400085202123`, 0.9335010000461641]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.15793718311639351`], {
             RGBColor[
             0.8357950446989824, 0.2761419758107905, 0.18191068126945342`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.15793718311639351`], {
             RGBColor[
             0.9765123065091236, 0.9324326360618924, 0.36325517537702773`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.15793718311639351`], {
             RGBColor[
             0.22872079714307936`, 0.35773043790646125`, 0.9363366830839769]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.15793718311639351`], {
             RGBColor[
             0.21147766438726034`, 0.339606812102334, 0.9353547121824619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.15793718311639351`], {
             RGBColor[
             0.8366736085240676, 0.28289500235951803`, 0.1827519949805509]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.15793718311639351`], {
             RGBColor[
             0.6012429877716181, 0.6871551690177569, 0.9617511969044663]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.15793718311639351`], {
             RGBColor[
             0.31511174381280593`, 0.44735568733906544`, 0.9412996195667458]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.15793718311639351`], {
             RGBColor[
             0.2421911048281961, 0.37188858535035474`, 0.9371037971791099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.15793718311639351`], {
             RGBColor[
             0.29270959820985176`, 0.42498672495195505`, 0.9399807506417815]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.15793718311639351`], {
             RGBColor[
             0.3238266917401457, 0.45490413720770817`, 0.94185492834235]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.15793718311639351`], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.15793718311639351`], {
             RGBColor[
             0.41933559472005666`, 0.5376291485518648, 0.9479406711850231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.15793718311639351`], {
             RGBColor[
             0.2878344487965492, 0.41986263381624833`, 0.9397031180948312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.15793718311639351`], {
             RGBColor[
             0.9854648277298144, 0.9626315922912277, 0.39803402977763763`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.15793718311639351`], {
             RGBColor[
             0.2632810725593861, 0.3940554786170215, 0.9383048396415897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.15793718311639351`], {
             RGBColor[
             0.25662307112871396`, 0.38705749697171266`, 0.9379256763097434]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.15793718311639351`], {
             RGBColor[
             0.8199864588949732, 0.15463025795470559`, 0.16677236165029033`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.15793718311639351`], {
             RGBColor[
             0.9094625081980608, 0.9306447336077317, 0.9912265399903383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.15793718311639351`], {
             RGBColor[
             0.2582501634540876, 0.38876767416929214`, 0.9380183368106061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.15793718311639351`], {
             RGBColor[
             0.755781538403036, 0.8091415490436711, 0.97629289863413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.15793718311639351`], {
             RGBColor[
             0.2539844574642687, 0.3842841467126117, 0.9377754111650324]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.15793718311639351`], {
             RGBColor[
             0.24791046842011605`, 0.37789999911405875`, 0.9374295064746294]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.15793718311639351`], {
             RGBColor[
             0.2817340129849886, 0.4134506889883278, 0.9393557073001488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.15793718311639351`], {
             RGBColor[
             0.3449485107481652, 0.47319879521896346`, 0.9432007919722498]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.15793718311639351`], {
             RGBColor[
             0.4113253016274047, 0.530691035284047, 0.9474302623923834]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.15793718311639351`], {
             RGBColor[
             0.606817875551374, 0.6916811140631951, 0.9621900724919755]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.15793718311639351`], {
             RGBColor[
             0.21942909899518986`, 0.3479642740253404, 0.9358075346202901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.15793718311639351`], {
             RGBColor[
             0.9938287149952354, 0.9892085703244617, 0.5696718958667929]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.15793718311639351`], {
             RGBColor[
             0.7895429134572223, 0.8355161918319554, 0.9796579169815435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.15793718311639351`], {
             RGBColor[
             0.8236181467643259, 0.8621947699835874, 0.9830386281626226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.15793718311639351`], {
             RGBColor[
             0.25827862318556116`, 0.3887975871515221, 0.9380199575502111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.15793718311639351`], {
             RGBColor[
             0.9207457022290968, 0.9396416462539369, 0.9923027411096448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.15793718311639351`], {
             RGBColor[
             0.2333142933423989, 0.36255849365642656`, 0.9365982758970595]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.15793718311639351`], {
             RGBColor[
             0.21421555473578224`, 0.34248450845090483`, 0.9355106309874645]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.15793718311639351`], {
             RGBColor[
             0.9151930916309041, 0.7014758990831244, 0.2506205747334791]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.15793718311639351`], {
             RGBColor[
             0.1792532619022457, 0.3057369219454596, 0.9335195801326717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.15793718311639351`], {
             RGBColor[
             0.8666101266120032, 0.4871895635890985, 0.21040855877111306`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.15793718311639351`], {
             RGBColor[
             0.28550171685781406`, 0.4174107846448903, 0.9395702724618878]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.15793718311639351`], {
             RGBColor[
             0.8647697772859632, 0.4788329671240561, 0.2088729261823753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.15793718311639351`], {
             RGBColor[
             0.3276288460270304, 0.4581973721491767, 0.9420971982513973]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.15793718311639351`], {
             RGBColor[
             0.6091375885965603, 0.6935643616151592, 0.9623726888002815]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.15793718311639351`], {
             RGBColor[
             0.26928527939714464`, 0.4003662806922068, 0.9386467703385721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.15793718311639351`], {
             RGBColor[
             0.9554190789968999, 0.9662722026272221, 0.9603480500785777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.15793718311639351`], {
             RGBColor[
             0.22708291988077767`, 0.3560089250563658, 0.936243408396911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.15793718311639351`], {
             RGBColor[
             0.2961617343973124, 0.4286151389630523, 0.9401773446906796]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.15793718311639351`], {
             RGBColor[
             0.2317345075524728, 0.36089803862701, 0.9365083094334068]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.15793718311639351`], {
             RGBColor[
             0.9952347378240085, 0.9922159109844932, 0.7227088038116687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.15793718311639351`], {
             RGBColor[
             0.9936215336094609, 0.9887654302895413, 0.5471214806005384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.15793718311639351`], {
             RGBColor[
             0.9312148525901699, 0.7649968423512695, 0.2635120596803694]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.15793718311639351`], {
             RGBColor[
             0.5208327276256995, 0.6218744973903617, 0.9554210066732913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.15793718311639351`], {
             RGBColor[
             0.2765375568294345, 0.40798888409449063`, 0.939059776809558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.15793718311639351`], {
             RGBColor[
             0.4803557055985901, 0.589013427439692, 0.9522345072271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.15793718311639351`], {
             RGBColor[
             0.24657366739272524`, 0.3764949364761905, 0.9373533776337394]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.15793718311639351`], {
             RGBColor[
             0.2459052705491277, 0.3757924090147619, 0.9373153134223011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.15793718311639351`], {
             RGBColor[
             0.5178553382148801, 0.619457318536794, 0.9551866156723348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.15793718311639351`], {
             RGBColor[
             0.18467169248908813`, 0.3114320360405726, 0.9338281517387427]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.15793718311639351`], {
             RGBColor[
             0.28511069510105125`, 0.41699979598632125`, 0.939548004351305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.15793718311639351`], {
             RGBColor[
             0.25396000439311356`, 0.38425844498441336`, 0.9377740185988052]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.15793718311639351`], {
             RGBColor[
             0.27171530098953856`, 0.4029203874580805, 0.9387851564733641]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.15793718311639351`], {
             RGBColor[
             0.27309124258507717`, 0.4043665893147275, 0.9388635143117069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.15793718311639351`], {
             RGBColor[
             0.24826352560257345`, 0.3782710845979398, 0.937449612558869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.15793718311639351`], {
             RGBColor[
             0.17919226069553715`, 0.305672805809509, 0.9335161062041928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.15793718311639351`], {
             RGBColor[
             0.5006784839436625, 0.605512374430953, 0.9538343907832142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.15793718311639351`], {
             RGBColor[
             0.9211683800910966, 0.9399786781078106, 0.9923430565014513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.15793718311639351`], {
             RGBColor[
             0.24872594858728536`, 0.3787571204741826, 0.9374759468637549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.15793718311639351`], {
             RGBColor[
             0.38107527345035186`, 0.504489981287708, 0.9455027573459912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.15793718311639351`], {
             RGBColor[
             0.32510810483221725`, 0.45601403282236586`, 0.9419365788514676]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.15793718311639351`], {
             RGBColor[
             0.9906473743776302, 0.9904004632007044, 0.8046607405893015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.15793718311639351`], {
             RGBColor[
             0.20742150462258202`, 0.3353435310142743, 0.9351237198844141]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.15793718311639351`], {
             RGBColor[
             0.8274659414661699, 0.21212083852708477`, 0.1739347226073356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.15793718311639351`], {
             RGBColor[
             0.867504304657107, 0.49124981725132677`, 0.21115468285025726`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.15793718311639351`], {
             RGBColor[
             0.2069635167020156, 0.33486215667164765`, 0.9350976381498702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.15793718311639351`], {
             RGBColor[
             0.9626525497894284, 0.8856804222207267, 0.30941263771645156`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.15793718311639351`], {
             RGBColor[
             0.20867358600249122`, 0.3366595479311035, 0.9351950240667115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.15793718311639351`], {
             RGBColor[
             0.2511378152607278, 0.38129214526915, 0.9376132991027705]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.15793718311639351`], {
             RGBColor[
             0.22597981130456574`, 0.35484948800164373`, 0.9361805879953986]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.15793718311639351`], {
             RGBColor[
             0.49474321248409076`, 0.6006938536791404, 0.9533671444723009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.15793718311639351`], {
             RGBColor[
             0.35559977387920144`, 0.4824243839950162, 0.9438794810404173]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.15793718311639351`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.15793718311639351`], {
             RGBColor[
             0.263609049878749, 0.394400203574635, 0.9383235174647285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.15793718311639351`], {
             RGBColor[
             0.9901329118562932, 0.9901877197270478, 0.8131867159541827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.15793718311639351`], {
             RGBColor[
             0.3451736656290086, 0.4733938130601367, 0.9432151386421606]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.15793718311639351`], {
             RGBColor[
             0.2332063867745317, 0.36244507701192663`, 0.9365921307776528]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.15793718311639351`], {
             RGBColor[
             0.25062676841059334`, 0.3807550026274169, 0.9375841957406814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.15793718311639351`], {
             RGBColor[
             0.968960662006962, 0.9763714930638193, 0.9374256822530368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.15793718311639351`], {
             RGBColor[
             0.22008054170119, 0.3486489816131997, 0.9358446333186737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.15793718311639351`], {
             RGBColor[
             0.2199663924455993, 0.34852900350809307`, 0.9358381326874365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.15793718311639351`], {
             RGBColor[
             0.5640351798749514, 0.6569481943745988, 0.9588220619701494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.15793718311639351`], {
             RGBColor[
             0.4996340643500339, 0.6046644675542787, 0.9537521702469687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.15793718311639351`], {
             RGBColor[
             0.30958288032569087`, 0.4425668636752852, 0.9409473252743288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.15793718311639351`], {
             RGBColor[
             0.6995243049605603, 0.765192970707599, 0.9706857033583209]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.15793718311639351`], {
             RGBColor[
             0.17892700134778292`, 0.3053940014166053, 0.9335010000767543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.15793718311639351`], {
             RGBColor[
             0.24622776306205768`, 0.3761313690930576, 0.9373336788938276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.15793718311639351`], {
             RGBColor[
             0.2206581667895666, 0.3492561022046294, 0.935877528212937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.15793718311639351`], {
             RGBColor[
             0.257933230334439, 0.3884345573658211, 0.9380002879383026]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.15793718311639351`], {
             RGBColor[
             0.25149316947897704`, 0.3816656450832887, 0.9376335359998004]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.15793718311639351`], {
             RGBColor[
             0.23965584235908116`, 0.3692238637503902, 0.9369594177320785]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.15793718311639351`], {
             RGBColor[
             0.353874772698637, 0.4809302746734916, 0.9437695654905504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.15793718311639351`], {
             RGBColor[
             0.8214446559981496, 0.16583859987576455`, 0.16816873284309014`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.15793718311639351`], {
             RGBColor[
             0.30679432383558886`, 0.439790664607788, 0.9407828549296829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.15793718311639351`], {
             RGBColor[
             0.20400293554931437`, 0.33175039816847185`, 0.9349290374330113]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.15793718311639351`], {
             RGBColor[
             0.24493296406314102`, 0.3747704532501981, 0.9372599420063227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.15793718311639351`], {
             RGBColor[
             0.30954120355039927`, 0.44253076534726327`, 0.9409446696670606]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.15793718311639351`], {
             RGBColor[
             0.5658891207695752, 0.6584533071119401, 0.9589680109885835]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.15793718311639351`], {
             RGBColor[
             0.46730916543215706`, 0.578421658392645, 0.9512074357941471]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.15793718311639351`], {
             RGBColor[
             0.3025436094347634, 0.43532289426166115`, 0.9405407830329243]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.15793718311639351`], {
             RGBColor[
             0.3575213303529286, 0.48408873963232213`, 0.9440019209197574]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.15793718311639351`], {
             RGBColor[
             0.8207501650068003, 0.16050043778835987`, 0.16750368748545852`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.15793718311639351`], {
             RGBColor[
             0.42248174875901884`, 0.5403541890501141, 0.948141141338351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.15793718311639351`], {
             RGBColor[
             0.9903319581123935, 0.9790495659282263, 0.41694191223350735`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.15793718311639351`], {
             RGBColor[
             0.46203141681910903`, 0.5741369443087071, 0.9507919520902978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.15793718311639351`], {
             RGBColor[
             0.26699231078344465`, 0.3979562252966011, 0.9385161891681649]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.15793718311639351`], {
             RGBColor[
             0.8175247092939038, 0.13570817177533162`, 0.16441498745215766`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.15793718311639351`], {
             RGBColor[
             0.4240332554553848, 0.5416980261695123, 0.9482400019731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.15793718311639351`], {
             RGBColor[
             0.8381204118994321, 0.2940157670958513, 0.18413745552673064`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.15793718311639351`], {
             RGBColor[
             0.9866702547547157, 0.9887558220293171, 0.870571905196646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.15793718311639351`], {
             RGBColor[
             0.9107922199972238, 0.6840279095591187, 0.24707953011528597`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.15793718311639351`], {
             RGBColor[
             0.4927421843014464, 0.5990693288551774, 0.9532096162037554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.15793718311639351`], {
             RGBColor[
             0.29668056881803306`, 0.42916046683523196`, 0.9402068915433929]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.15793718311639351`], {
             RGBColor[
             0.26174222518751433`, 0.39243805246062563`, 0.9382172045602823]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.15793718311639351`], {
             RGBColor[
             0.3516524550010693, 0.4790054147807936, 0.9436279613719797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.15793718311639351`], {
             RGBColor[
             0.984562956112485, 0.9878843998856498, 0.9054952972124768]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.15793718311639351`], {
             RGBColor[
             0.2666571079259713, 0.3976039058403079, 0.93849709986132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.15793718311639351`], {
             RGBColor[
             0.9557302644442173, 0.966504284224312, 0.9598212942864327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.15793718311639351`], {
             RGBColor[
             0.6069446059586334, 0.6917839995169481, 0.9622000491738637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.15793718311639351`], {
             RGBColor[
             0.20869655844004803`, 0.3366836934195124, 0.9351963323130457]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.15793718311639351`], {
             RGBColor[
             0.9916846362160958, 0.9908293976273234, 0.7874706275783359]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.15793718311639351`], {
             RGBColor[
             0.178929137062006, 0.30539624618766587`, 0.9335011217025198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.15793718311639351`], {
             RGBColor[
             0.27013094278236094`, 0.4012551265282246, 0.9386949296173133]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.15793718311639351`], {
             RGBColor[
             0.4206971967779904, 0.5388084998183378, 0.9480274312641372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.15793718311639351`], {
             RGBColor[
             0.3785866605047563, 0.5023344698355566, 0.9453441851296919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.15793718311639351`], {
             RGBColor[
             0.2049673414252272, 0.33276404989092045`, 0.9349839589209338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.15793718311639351`], {
             RGBColor[
             0.2570318728012019, 0.3874871734490205, 0.9379489569602237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.15793718311639351`], {
             RGBColor[
             0.2839447494602888, 0.41577431319265656`, 0.9394816054719256]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.15793718311639351`], {
             RGBColor[
             0.23571041014604155`, 0.365076964339635, 0.9367347312042897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.15793718311639351`], {
             RGBColor[
             0.26462809617956273`, 0.3954712858480575, 0.938381550644016]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.15793718311639351`], {
             RGBColor[
             0.33727714516499796`, 0.4665542439248693, 0.9427119793408126]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.15793718311639351`], {
             RGBColor[
             0.2597753641562747, 0.39037075681060074`, 0.9381051947342635]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.15793718311639351`], {
             RGBColor[
             0.24810961844878143`, 0.3781093184210272, 0.9374408477741458]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.15793718311639351`], {
             RGBColor[
             0.21840138119578575`, 0.34688407745709465`, 0.9357490076119863]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.15793718311639351`], {
             RGBColor[
             0.2546146394674752, 0.38494650795382845`, 0.9378112990978443]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.15793718311639351`], {
             RGBColor[
             0.2878117179623051, 0.41983874226823964`, 0.9397018236074483]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.15793718311639351`], {
             RGBColor[
             0.9865160895376739, 0.9886920707502049, 0.8731268218098209]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.15793718311639351`], {
             RGBColor[
             0.2701519252165497, 0.40127718039692006`, 0.9386961245358997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.15793718311639351`], {
             RGBColor[
             0.29569933477919436`, 0.42812912764658106`, 0.9401510117164867]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.15793718311639351`], {
             RGBColor[
             0.6976256228082208, 0.7637097057796726, 0.9704964604655693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.15793718311639351`], {
             RGBColor[
             0.2818794421164257, 0.41360354422620765`, 0.9393639892740411]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.15793718311639351`], {
             RGBColor[
             0.3428438781472085, 0.4713758682419251, 0.9430666866439704]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.15793718311639351`], {
             RGBColor[
             0.9008280073528754, 0.6425649682443086, 0.23896079721830538`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.15793718311639351`], {
             RGBColor[
             0.3044587746178886, 0.4373358542976118, 0.9406498488568703]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.15793718311639351`], {
             RGBColor[
             0.23905706042934927`, 0.3685945059772749, 0.9369253179869986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.15793718311639351`], {
             RGBColor[
             0.5345666356633387, 0.6330243026408235, 0.956502190222977]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.15793718311639351`], {
             RGBColor[
             0.5018930513522051, 0.606498414968846, 0.9539300059787216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.15793718311639351`], {
             RGBColor[
             0.9938265629209484, 0.98920396725517, 0.5694376558617151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.15793718311639351`], {
             RGBColor[
             0.3427341577200499, 0.4712808339226293, 0.9430596953553738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.15793718311639351`], {
             RGBColor[
             0.217062994597398, 0.3454773482835776, 0.9356727884751737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.15793718311639351`], {
             RGBColor[
             0.32211852500862637`, 0.45342460903982235`, 0.9417460854686901]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.15793718311639351`], {
             RGBColor[
             0.5659235722129052, 0.6584812763456551, 0.9589707231324023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.15793718311639351`], {
             RGBColor[
             0.8360637140310553, 0.2782070860287545, 0.182167959325265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.15793718311639351`], {
             RGBColor[
             0.2310404057237692, 0.3601684935964447, 0.9364687813610937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.15793718311639351`], {
             RGBColor[
             0.21851625165510197`, 0.3470048135930438, 0.9357555493147087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.15793718311639351`], {
             RGBColor[
             0.90420589766789, 0.657903179238463, 0.24177939169682186`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.15793718311639351`], {
             RGBColor[
             0.19980711485308938`, 0.32734032458634205`, 0.9346900916515217]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.15793718311639351`], {
             RGBColor[
             0.28412310253725925`, 0.4159617735847908, 0.9394917624158093]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.15793718311639351`], {
             RGBColor[
             0.26588598144981995`, 0.39679340302163035`, 0.9384531853492826]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.15793718311639351`], {
             RGBColor[
             0.31971976000988434`, 0.4513469193633465, 0.9415932382841149]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.15793718311639351`], {
             RGBColor[
             0.23197293745711564`, 0.3611486435741187, 0.9365218876637508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.15793718311639351`], {
             RGBColor[
             0.5262688994117111, 0.6262878265429939, 0.9558489620296395]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.15793718311639351`], {
             RGBColor[
             0.3389132056188999, 0.46797131725924984`, 0.9428162276662237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.15793718311639351`], {
             RGBColor[
             0.5366100807415061, 0.6346832634114314, 0.9566630577049163]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.15793718311639351`], {
             RGBColor[
             0.4427137030371586, 0.5578780909582495, 0.9494303035745394]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.15793718311639351`], {
             RGBColor[
             0.38986378476733635`, 0.5121021480670574, 0.9460627535157341]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.15793718311639351`], {
             RGBColor[
             0.29896629209325354`, 0.43156290692071464`, 0.9403370601024921]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.15793718311639351`], {
             RGBColor[
             0.27424929290791517`, 0.4055837736286615, 0.9389294635644105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.15793718311639351`], {
             RGBColor[
             0.1794249922972142, 0.30591742147890744`, 0.9335293599246128]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.15793718311639351`], {
             RGBColor[
             0.8456311671254343, 0.35174672299683013`, 0.19132976321333509`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.15793718311639351`], {
             RGBColor[
             0.9930813033990235, 0.9876099324950685, 0.48832075610881853`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.15793718311639351`], {
             RGBColor[
             0.2909757990296596, 0.42316439208435586`, 0.9398820133433956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.15793718311639351`], {
             RGBColor[
             0.2238780227461086, 0.35264037496561385`, 0.936060894246312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.15793718311639351`], {
             RGBColor[
             0.2584463601503126, 0.3889738893366137, 0.9380295099222091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.15793718311639351`], {
             RGBColor[
             0.3561976264336458, 0.4829422138287328, 0.9439175756765262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.15793718311639351`], {
             RGBColor[
             0.8431597968980244, 0.3327506884676198, 0.18896317629255405`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.15793718311639351`], {
             RGBColor[
             0.38857864336543946`, 0.5109890231778194, 0.9459808654420111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.15793718311639351`], {
             RGBColor[
             0.3570417238501652, 0.48367332858535217`, 0.9439713608175008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.15793718311639351`], {
             RGBColor[
             0.28732315690654525`, 0.419325233622076, 0.939674000778084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.15793718311639351`], {
             RGBColor[
             0.906092392768253, 0.9279574950433493, 0.9909050953721057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.15793718311639351`], {
             RGBColor[
             0.32015392046586916`, 0.45172296732878153`, 0.9416209026044572]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.15793718311639351`], {
             RGBColor[
             0.3509305166159243, 0.47838010803725933`, 0.9435819600964633]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.15793718311639351`], {
             RGBColor[
             0.2566255537350775, 0.38706010634840704`, 0.9379258176905032]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.15793718311639351`], {
             RGBColor[
             0.7054821402904016, 0.7698472769484965, 0.9712795247048629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.15793718311639351`], {
             RGBColor[
             0.22500762673968802`, 0.3538276603838957, 0.936125223522647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.15793718311639351`], {
             RGBColor[
             0.8393061093521738, 0.30312955729356095`, 0.18527288074652987`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.15793718311639351`], {
             RGBColor[
             0.3424410288691568, 0.4710269404450701, 0.9430410174441985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.15793718311639351`], {
             RGBColor[
             0.22156287013367681`, 0.3502070027807943, 0.9359290497299955]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.15793718311639351`], {
             RGBColor[
             0.29422140859812795`, 0.42657573352434824`, 0.9400668460068708]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.15793718311639351`], {
             RGBColor[
             0.4950113815248125, 0.6009115653872759, 0.9533882557215221]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.15793718311639351`], {
             RGBColor[
             0.24253965650195108`, 0.3722549352589237, 0.9371236466812941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.15793718311639351`], {
             RGBColor[
             0.2895478687563091, 0.421663546831056, 0.9398006948267619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.15793718311639351`], {
             RGBColor[
             0.20444533477183996`, 0.332215387801077, 0.934954231414263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.15793718311639351`], {
             RGBColor[
             0.25854520282865096`, 0.38907777925853504`, 0.9380351388665158]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.15793718311639351`], {
             RGBColor[
             0.7357960105795031, 0.7935287028122899, 0.9743009279960564]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.15793718311639351`], {
             RGBColor[
             0.9850318468002165, 0.9880782982349678, 0.8977245650665646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.15793718311639351`], {
             RGBColor[
             0.23649824945009773`, 0.365905033400095, 0.9367795974871519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.15793718311639351`], {
             RGBColor[
             0.3975855258515599, 0.5187903320882202, 0.9465547760295533]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.15793718311639351`], {
             RGBColor[
             0.2893861381019995, 0.4214935576590608, 0.939791484505258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.15793718311639351`], {
             RGBColor[
             0.8588534332133313, 0.4519682304874997, 0.20393618366530758`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.15793718311639351`], {
             RGBColor[
             0.3734224424883788, 0.497861483750915, 0.945015125724227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.15793718311639351`], {
             RGBColor[
             0.8618406991999262, 0.46553270763892984`, 0.20642883162911219`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.15793718311639351`], {
             RGBColor[
             0.28557642935408295`, 0.4174893122155148, 0.9395745272280231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.15793718311639351`], {
             RGBColor[
             0.8799868165294279, 0.5479299882988189, 0.2215703967308864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.15793718311639351`], {
             RGBColor[
             0.47608581392629684`, 0.5855469370236965, 0.9518983657135286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.15793718311639351`], {
             RGBColor[
             0.2734006518561467, 0.40469179807630246`, 0.9388811347119643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.15793718311639351`], {
             RGBColor[
             0.23478619087952063`, 0.36410555129163547`, 0.9366820982843213]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.15793718311639351`], {
             RGBColor[
             0.32101450543653715`, 0.45246836277611585`, 0.9416757383178027]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.15793718311639351`], {
             RGBColor[
             0.28952074326414307`, 0.421635036218934, 0.9397991500701115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.15793718311639351`], {
             RGBColor[
             0.9890626064851881, 0.9747677448317271, 0.41201072085875556`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.15793718311639351`], {
             RGBColor[
             0.40965477924277666`, 0.5292441127573786, 0.9473238181832199]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.15793718311639351`], {
             RGBColor[
             0.44893934079834463`, 0.5632704254773366, 0.9498269957075668]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.15793718311639351`], {
             RGBColor[
             0.9900230881246451, 0.9901423047916702, 0.8150067794022959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.15793718311639351`], {
             RGBColor[
             0.2558053195227897, 0.38619798818543977`, 0.9378791065655412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.15793718311639351`], {
             RGBColor[
             0.8205829319400263, 0.15921501115513814`, 0.16734354491185305`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.15793718311639351`], {
             RGBColor[
             0.2935414156904733, 0.42586101786436276`, 0.9400281214167392]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.15793718311639351`], {
             RGBColor[
             0.4627342609626232, 0.5747075448471798, 0.9508472825558781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.15793718311639351`], {
             RGBColor[
             0.4137039619056965, 0.5327513112621616, 0.9475818285219495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.15793718311639351`], {
             RGBColor[
             0.6195401563438858, 0.7020096347427746, 0.9631916170392121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.15793718311639351`], {
             RGBColor[
             0.7713015318020453, 0.8212658858432957, 0.977839786533559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.15793718311639351`], {
             RGBColor[
             0.9483637407407871, 0.9610103429078694, 0.9722908974192511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.15793718311639351`], {
             RGBColor[
             0.2785602236563872, 0.4101148351741018, 0.9391749646930856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.15793718311639351`], {
             RGBColor[
             0.25689237745970156`, 0.38734055500058817`, 0.9379410129068901]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.15793718311639351`], {
             RGBColor[
             0.24490866169442368`, 0.374744909919817, 0.9372585580223763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.15793718311639351`], {
             RGBColor[
             0.6076583896248129, 0.6923634812527404, 0.9622562408387412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.15793718311639351`], {
             RGBColor[
             0.18121415923057888`, 0.3077979493656092, 0.9336312503346327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.15793718311639351`], {
             RGBColor[
             0.24509263407936946`, 0.37493827656091794`, 0.9372690349775362]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.15793718311639351`], {
             RGBColor[
             0.3144183414809424, 0.4467550970906198, 0.941255436583311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.15793718311639351`], {
             RGBColor[
             0.22310026486080187`, 0.3518229021154584, 0.9360166020853335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.15793718311639351`], {
             RGBColor[
             0.20981171601903448`, 0.33785579474010136`, 0.9352598388874411]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.15793718311639351`], {
             RGBColor[
             0.2560659100008252, 0.3864718853002457, 0.9378939468077562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.15793718311639351`], {
             RGBColor[
             0.439371052281192, 0.5549828548799431, 0.9492173128241592]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.15793718311639351`], {
             RGBColor[
             0.2864852402250885, 0.41844453006287885`, 0.9396262826626617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.15793718311639351`], {
             RGBColor[
             0.6549271406176395, 0.7303533269719065, 0.9662406748008145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.15793718311639351`], {
             RGBColor[
             0.1789706321783367, 0.30543986018587177`, 0.9335034847880083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.15793718311639351`], {
             RGBColor[
             0.9542723127115095, 0.9654169462092355, 0.962289226275195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.15793718311639351`], {
             RGBColor[
             0.23831274258564697`, 0.36781218073106675`, 0.9368829301869194]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.15793718311639351`], {
             RGBColor[
             0.22958788287780074`, 0.3586417999900643, 0.9363860623338308]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.15793718311639351`], {
             RGBColor[
             0.3134198204339392, 0.44589022834683273`, 0.9411918117051534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.15793718311639351`], {
             RGBColor[
             0.5193642093092683, 0.6206822880650865, 0.955305399532062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.15793718311639351`], {
             RGBColor[
             0.9016398137954514, 0.9244071294324739, 0.9904804044148157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.15793718311639351`], {
             RGBColor[
             0.2091663766185125, 0.3371775021132715, 0.9352230877632756]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.15793718311639351`], {
             RGBColor[
             0.22595764709528393`, 0.3548261920123965, 0.936179325776469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.15793718311639351`], {
             RGBColor[
             0.20875268020104726`, 0.3367426809486477, 0.9351995283643099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.15793718311639351`], {
             RGBColor[
             0.19014935834156865`, 0.31718941015560403`, 0.934140096705561]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.15793718311639351`], {
             RGBColor[
             0.3052585207535403, 0.43817643819301544`, 0.9406953932161773]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.15793718311639351`], {
             RGBColor[
             0.3385640468354945, 0.4676688934702948, 0.9427939795772942]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.15793718311639351`], {
             RGBColor[
             0.2511118726659751, 0.3812648779572094, 0.9376118217103779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.15793718311639351`], {
             RGBColor[
             0.8575795140998795, 0.443586953641446, 0.20277151376979163`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.15793718311639351`], {
             RGBColor[
             0.46980956787155936`, 0.580451597734798, 0.9514042766334527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.15793718311639351`], {
             RGBColor[
             0.17894628476761076`, 0.30541426951348377`, 0.9335020982389862]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.15793718311639351`], {
             RGBColor[
             0.9930307649637, 0.9875018358921313, 0.48281995931092997`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.15793718311639351`], {
             RGBColor[
             0.29675707084929953`, 0.4292408753206019, 0.9402112482208989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.15793718311639351`], {
             RGBColor[
             0.746856868272219, 0.8021695289074716, 0.9754033709212744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.15793718311639351`], {
             RGBColor[
             0.3044115375980597, 0.43728620519477157`, 0.940647158778472]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.15793718311639351`], {
             RGBColor[
             0.266957894870447, 0.3979200519899457, 0.9385142292328336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.15793718311639351`], {
             RGBColor[
             0.33007547283951477`, 0.4603165173231115, 0.9422530951484216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.15793718311639351`], {
             RGBColor[
             0.1854996162687526, 0.3123022364263995, 0.933875300773191]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.15793718311639351`], {
             RGBColor[
             0.2504950392509415, 0.38061654692851177`, 0.937576693959915]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.15793718311639351`], {
             RGBColor[
             0.8834003236622562, 0.5634299269441462, 0.22441871075523476`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.15793718311639351`], {
             RGBColor[
             0.341942322952124, 0.4705949864454246, 0.9430092403441536]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.15793718311639351`], {
             RGBColor[
             0.7148896845747944, 0.7771965220434489, 0.9722171808006315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.15793718311639351`], {
             RGBColor[
             0.9886024976405045, 0.9895548541189678, 0.8385496400948322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.15793718311639351`], {
             RGBColor[
             0.3331754530775283, 0.46300156439574175`, 0.942450623147983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.15793718311639351`], {
             RGBColor[
             0.25921854913182885`, 0.38978550891579644`, 0.9380734849423552]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.15793718311639351`], {
             RGBColor[
             0.23934466612723454`, 0.36889679780100676`, 0.9369416967060188]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.15793718311639351`], {
             RGBColor[
             0.369677449943029, 0.49461775943693126`, 0.9447764981108042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.15793718311639351`], {
             RGBColor[
             0.1790169203691504, 0.30548851200925775`, 0.9335061208319979]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.15793718311639351`], {
             RGBColor[
             0.8751755113140446, 0.526082975024646, 0.21755572572328788`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.15793718311639351`], {
             RGBColor[
             0.2570691600545971, 0.38752636471648727`, 0.9379510804141431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.15793718311639351`], {
             RGBColor[
             0.3853130055350487, 0.5081604918248647, 0.9457727818871488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.15793718311639351`], {
             RGBColor[
             0.8825578842047201, 0.909191716742005, 0.9886603529358121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.15793718311639351`], {
             RGBColor[
             0.3064495532407965, 0.43942828885294294`, 0.9407632207543519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.15793718311639351`], {
             RGBColor[
             0.8366916950922476, 0.8726192625482565, 0.984285594873034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.15793718311639351`], {
             RGBColor[
             0.40219205331719154`, 0.5227802746481479, 0.946848299886271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.15793718311639351`], {
             RGBColor[
             0.3786491349611119, 0.5023885820695944, 0.9453481659468069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.15793718311639351`], {
             RGBColor[
             0.4028040785660817, 0.5233103801574531, 0.9468872975939376]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.15793718311639351`], {
             RGBColor[
             0.2767721721232211, 0.4082354796437291, 0.9390731378034569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.15793718311639351`], {
             RGBColor[
             0.22223854670063217`, 0.35091718169303304`, 0.9359675285109096]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.15793718311639351`], {
             RGBColor[
             0.860210700141258, 0.8913726787679522, 0.9865288585702724]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.15793718311639351`], {
             RGBColor[
             0.32010532781399464`, 0.4516808788160655, 0.9416178063236486]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.15793718311639351`], {
             RGBColor[
             0.21169068579341777`, 0.33983071110654267`, 0.9353668434364056]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.15793718311639351`], {
             RGBColor[
             0.3374345618861965, 0.46669059037677707`, 0.9427220097950892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.15793718311639351`], {
             RGBColor[
             0.9935733711383794, 0.9886624156338708, 0.5418792928476311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.15793718311639351`], {
             RGBColor[
             0.25998714329821626`, 0.39059335011635443`, 0.9381172552430979]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.15793718311639351`], {
             RGBColor[
             0.29288750827080284`, 0.425173719706164, 0.9399908823565584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.15793718311639351`], {
             RGBColor[
             0.4637429804071734, 0.5755264687345587, 0.9509266926456142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.15793718311639351`], {
             RGBColor[
             0.6597251945044771, 0.7341016031348642, 0.9667188999718916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.15793718311639351`], {
             RGBColor[
             0.21788265672664042`, 0.34633886515099205`, 0.9357194670208525]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.15793718311639351`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.15793718311639351`], {
             RGBColor[
             0.9599116097125079, 0.876434587737939, 0.29876460310071706`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.15793718311639351`], {
             RGBColor[
             0.41360147005439724`, 0.5326625379719564, 0.9475752978318146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.15793718311639351`], {
             RGBColor[
             0.3621699928109498, 0.4881151774048913, 0.9442981295809318]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.15793718311639351`], {
             RGBColor[
             0.290045450304657, 0.422186536586862, 0.9398290313598343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.15793718311639351`], {
             RGBColor[
             0.2278308941861094, 0.35679509347557953`, 0.9362860044270709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.15793718311639351`], {
             RGBColor[
             0.6396625402707171, 0.7183458925176417, 0.9647757248126534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.15793718311639351`], {
             RGBColor[
             0.3617638436367253, 0.48776339140382907`, 0.9442722501146938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.15793718311639351`], {
             RGBColor[
             0.32870680276015046`, 0.45913104409172456`, 0.942165884701232]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.15793718311639351`], {
             RGBColor[
             0.26933793088281155`, 0.4004216207419397, 0.9386497687627899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.15793718311639351`], {
             RGBColor[
             0.9071422836282599, 0.6695571281253704, 0.2441427056377997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.15793718311639351`], {
             RGBColor[
             0.22562621270692998`, 0.3544778334560826, 0.9361604510783655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.15793718311639351`], {
             RGBColor[
             0.38545126270191343`, 0.5082802432337956, 0.9457815915115654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.15793718311639351`], {
             RGBColor[
             0.5793663225363243, 0.6693947066472076, 0.9600289856802787]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.15793718311639351`], {
             RGBColor[
             0.6442014475594858, 0.7219743340365904, 0.9651716379540781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.15793718311639351`], {
             RGBColor[
             0.38846154058520777`, 0.5108875946353395, 0.9459734037564047]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.15793718311639351`], {
             RGBColor[
             0.40481135748628755`, 0.5250489842693634, 0.9470151996317661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.15793718311639351`], {
             RGBColor[
             0.2585666750316088, 0.38910034790526005`, 0.938036361676709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.15793718311639351`], {
             RGBColor[
             0.2169746648251472, 0.34538450809251103`, 0.9356677582253161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.15793718311639351`], {
             RGBColor[
             0.2650062967491503, 0.3958687986259951, 0.9384030886069564]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.15793718311639351`], {
             RGBColor[
             0.2298450608433424, 0.3589121103378734, 0.9364007082385077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.15793718311639351`], {
             RGBColor[
             0.4081016499818632, 0.5278988702541217, 0.9472248541600927]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.15793718311639351`], {
             RGBColor[
             0.4199474238450335, 0.5381590841884939, 0.9479796563958474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.15793718311639351`], {
             RGBColor[
             0.591443337591513, 0.6791993715323379, 0.960979732544987]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.15793718311639351`], {
             RGBColor[
             0.36294391873403165`, 0.48878551314081686`, 0.9443474434563948]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.15793718311639351`], {
             RGBColor[
             0.4704530721178047, 0.5809740234714359, 0.951454935644951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.15793718311639351`], {
             RGBColor[
             0.293615491872952, 0.425938876628849, 0.9400323399457455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.15793718311639351`], {
             RGBColor[
             0.2517303220687306, 0.38191490749146234`, 0.937647041488951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.15793718311639351`], {
             RGBColor[
             0.9582014383733062, 0.9683472816944506, 0.9556382414098691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.15793718311639351`], {
             RGBColor[
             0.2794551004482275, 0.4110554074207916, 0.9392259266025292]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.15793718311639351`], {
             RGBColor[
             0.9811051107342013, 0.9854288030398846, 0.9168682983373343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.15793718311639351`], {
             RGBColor[
             0.2830844261537786, 0.4148700588498662, 0.9394326113323542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.15793718311639351`], {
             RGBColor[
             0.3092991992760449, 0.442321153408306, 0.9409292493686947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.15793718311639351`], {
             RGBColor[
             0.27285106149406285`, 0.4041141437597107, 0.9388498363538897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.15793718311639351`], {
             RGBColor[
             0.5693048020656428, 0.6612263110627765, 0.9592369059322629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.15793718311639351`], {
             RGBColor[
             0.28222469603460637`, 0.4139664279845783, 0.9393836509739241]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.15793718311639351`], {
             RGBColor[
             0.32894252042405586`, 0.45933521088468515`, 0.942180904422339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.15793718311639351`], {
             RGBColor[
             0.28382079992875175`, 0.41564403437615693`, 0.9394745467294715]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.15793718311639351`], {
             RGBColor[
             0.2334715870925415, 0.36272381936082626`, 0.9366072335434348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.15793718311639351`], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.15793718311639351`], {
             RGBColor[
             0.7751138064478154, 0.8242440637709316, 0.9782197584425172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.15793718311639351`], {
             RGBColor[
             0.9461721011462925, 0.9593758216867757, 0.9760007715815773]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.15793718311639351`], {
             RGBColor[
             0.2184997826909155, 0.34698750366749115`, 0.9357546114315619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.15793718311639351`], {
             RGBColor[
             0.30075346730669683`, 0.43344134138349677`, 0.9404388370870089]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.15793718311639351`], {
             RGBColor[
             0.2411272273904176, 0.370770382709524, 0.937043210932894]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.15793718311639351`], {
             RGBColor[
             0.3060013924465708, 0.4389572434431762, 0.9407376986601153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.15793718311639351`], {
             RGBColor[
             0.4612114846587171, 0.5734712864433781, 0.9507274040271213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.15793718311639351`], {
             RGBColor[
             0.22864247952174482`, 0.3576481211208147, 0.9363322230113024]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.15793718311639351`], {
             RGBColor[
             0.26498757281889074`, 0.39584911858812655`, 0.9384020223068277]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.15793718311639351`], {
             RGBColor[
             0.9935460613341791, 0.9886040027241311, 0.5389067891970045]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.15793718311639351`], {
             RGBColor[
             0.3585480532796543, 0.48497803542685713`, 0.944067342796753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.15793718311639351`], {
             RGBColor[
             0.26115105564507934`, 0.3918166957892125, 0.9381835383293976]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.15793718311639351`], {
             RGBColor[
             0.24150095424043594`, 0.3711631933245442, 0.9370644941241232]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.15793718311639351`], {
             RGBColor[
             0.295921828646773, 0.42836298280833224`, 0.9401636824130951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[401, 0.15793718311639351`], {
             RGBColor[
             0.7734523776791622, 0.8229461429895335, 0.9780541627497925]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[402, 0.15793718311639351`], {
             RGBColor[
             0.5523112332770156, 0.6474301663686192, 0.9578991099477285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[403, 0.15793718311639351`], {
             RGBColor[
             0.9289119756027943, 0.9461532109745376, 0.9930816475541463]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[404, 0.15793718311639351`], {
             RGBColor[
             0.2134483076486736, 0.3416780831160786, 0.9354669374008939]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[405, 0.15793718311639351`], {
             RGBColor[
             0.9940126833910108, 0.9896020601209673, 0.5896957204256101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[406, 0.15793718311639351`], {
             RGBColor[
             0.990618380894789, 0.9800157372285142, 0.4180546106567104]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[407, 0.15793718311639351`], {
             RGBColor[
             0.21435834209939697`, 0.3426345870233057, 0.9355187625165873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[408, 0.15793718311639351`], {
             RGBColor[
             0.2225045334786326, 0.3511967506612473, 0.9359826760644245]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[409, 0.15793718311639351`], {
             RGBColor[
             0.24155566178660715`, 0.3712206944242289, 0.937067609637945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[410, 0.15793718311639351`], {
             RGBColor[
             0.36366501242205085`, 0.4894100882501565, 0.9443933909085572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[411, 0.15793718311639351`], {
             RGBColor[
             0.23958996446517072`, 0.3691546219069906, 0.9369556660834778]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[412, 0.15793718311639351`], {
             RGBColor[
             0.2423814866745967, 0.372088688741828, 0.9371146391436176]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[413, 0.15793718311639351`], {
             RGBColor[
             0.97383602535665, 0.9234049113139019, 0.35285832847295656`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[414, 0.15793718311639351`], {
             RGBColor[
             0.2746579678933065, 0.4060133169497984, 0.9389527370002482]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[415, 0.15793718311639351`], {
             RGBColor[
             0.2870126862041934, 0.4189989092289247, 0.9396563199308854]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[416, 0.15793718311639351`], {
             RGBColor[
             0.26153368469451344`, 0.39221886318025073`, 0.938205328487714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[417, 0.15793718311639351`], {
             RGBColor[
             0.7010326627105, 0.7663713112457954, 0.9708360423624304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[418, 0.15793718311639351`], {
             RGBColor[
             0.978473490691829, 0.9834661451211657, 0.9213229446326382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[419, 0.15793718311639351`], {
             RGBColor[
             0.5126905354832046, 0.6152642990075083, 0.9547800234820015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[420, 0.15793718311639351`], {
             RGBColor[
             0.96864282965107, 0.9761344542131977, 0.9379636895276074]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[421, 0.15793718311639351`], {
             RGBColor[
             0.17905660578117066`, 0.3055302238934915, 0.9335083808575031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[422, 0.15793718311639351`], {
             RGBColor[
             0.23401200432651914`, 0.3632918321381684, 0.9366380095054342]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[423, 0.15793718311639351`], {
             RGBColor[
             0.18782589147201245`, 0.31474729915939237`, 0.9340077787046009]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[424, 0.15793718311639351`], {
             RGBColor[
             0.3205944320155112, 0.4521045162923272, 0.9416489716108714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[425, 0.15793718311639351`], {
             RGBColor[
             0.37534284954540054`, 0.499524843821242, 0.9451374923637511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[426, 0.15793718311639351`], {
             RGBColor[
             0.8701743928884773, 0.8993174569073501, 0.9874792044791957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[427, 0.15793718311639351`], {
             RGBColor[
             0.2795001276110678, 0.4111027338238238, 0.9392284908328413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[428, 0.15793718311639351`], {
             RGBColor[
             0.8303334960184631, 0.23416211938642656`, 0.1766806960850511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[429, 0.15793718311639351`], {
             RGBColor[
             0.29359796730781346`, 0.4259204571997668, 0.9400313419476861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[430, 0.15793718311639351`], {
             RGBColor[
             0.23973902577549727`, 0.36931129479517677`, 0.9369641549045845]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[431, 0.15793718311639351`], {
             RGBColor[
             0.4485399301016759, 0.5629244760068475, 0.9498015456111601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[432, 0.15793718311639351`], {
             RGBColor[
             0.898624468927386, 0.9220027752840345, 0.9901927981294695]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[433, 0.15793718311639351`], {
             RGBColor[
             0.32550625142704326`, 0.4563588873913744, 0.9419619484004228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[434, 0.15793718311639351`], {
             RGBColor[
             0.9912025783926344, 0.990630054329001, 0.7954595732387495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[435, 0.15793718311639351`], {
             RGBColor[
             0.25811768357221787`, 0.3886284294137375, 0.93801079227732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[436, 0.15793718311639351`], {
             RGBColor[
             0.472919813782261, 0.5829766354800872, 0.9516491265847494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[437, 0.15793718311639351`], {
             RGBColor[
             0.2558304623203871, 0.3862244148598601, 0.9378805384106689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[438, 0.15793718311639351`], {
             RGBColor[
             0.22146455698209894`, 0.3501036694250721, 0.9359234509414543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[439, 0.15793718311639351`], {
             RGBColor[
             0.8609124841587944, 0.891932262294116, 0.986595795356355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[440, 0.15793718311639351`], {
             RGBColor[
             0.28167383897512416`, 0.41338744228870766`, 0.9393522804793065]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[441, 0.15793718311639351`], {
             RGBColor[
             0.4501324018566838, 0.5643037950010776, 0.9499030165032217]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[442, 0.15793718311639351`], {
             RGBColor[
             0.28394532564135605`, 0.4157749187954902, 0.9394816382845851]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[443, 0.15793718311639351`], {
             RGBColor[
             0.9345119801701037, 0.7780688545030732, 0.2661650059247154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[444, 0.15793718311639351`], {
             RGBColor[
             0.27129304719779485`, 0.4024765719505212, 0.9387611097445928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[445, 0.15793718311639351`], {
             RGBColor[
             0.22963931784821143`, 0.3586958614051314, 0.9363889914793045]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[446, 0.15793718311639351`], {
             RGBColor[
             0.22815127331601265`, 0.3571318322543179, 0.9363042495445604]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[447, 0.15793718311639351`], {
             RGBColor[
             0.2464999471451923, 0.3764174518218997, 0.9373491793747017]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[448, 0.15793718311639351`], {
             RGBColor[
             0.5679393142918087, 0.6601177465734548, 0.9591294097327601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[449, 0.15793718311639351`], {
             RGBColor[
             0.7283027762348872, 0.7876749311915857, 0.9735540724248413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[450, 0.15793718311639351`], {
             RGBColor[
             0.8177084834502429, 0.13712074047130335`, 0.1645909697918113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[451, 0.15793718311639351`], {
             RGBColor[
             0.21144581794704176`, 0.3395733394744833, 0.935352898574804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[452, 0.15793718311639351`], {
             RGBColor[
             0.22395342458252596`, 0.35271962707644106`, 0.936065188269349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[453, 0.15793718311639351`], {
             RGBColor[
             0.2843068325272902, 0.41615488545346746`, 0.9395022255669375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[454, 0.15793718311639351`], {
             RGBColor[
             0.8998824261938122, 0.6382713050470934, 0.23817178112086787`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[455, 0.15793718311639351`], {
             RGBColor[
             0.20394063923757638`, 0.33168492079502093`, 0.9349254897502168]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[456, 0.15793718311639351`], {
             RGBColor[
             0.22365852866224617`, 0.35240967276674573`, 0.9360483943829485]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[457, 0.15793718311639351`], {
             RGBColor[
             0.22158907133489145`, 0.35023454190452297`, 0.9359305418496434]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[458, 0.15793718311639351`], {
             RGBColor[
             0.2304992557221517, 0.359599710633853, 0.9364379636690613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[459, 0.15793718311639351`], {
             RGBColor[
             0.3905461178527888, 0.5126931506906183, 0.9461062311765757]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[460, 0.15793718311639351`], {
             RGBColor[
             0.24834625332605567`, 0.3783580366805602, 0.9374543237803367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[461, 0.15793718311639351`], {
             RGBColor[
             0.944455505750549, 0.9580955876512972, 0.9789065198267879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[462, 0.15793718311639351`], {
             RGBColor[
             0.46387836533310084`, 0.575636380316448, 0.9509373506429145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[463, 0.15793718311639351`], {
             RGBColor[
             0.2670973610782935, 0.3980666398170606, 0.9385221716270487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[464, 0.15793718311639351`], {
             RGBColor[
             0.24386676324271586`, 0.3736498085868948, 0.9371992234469022]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[465, 0.15793718311639351`], {
             RGBColor[
             0.28262558218412137`, 0.4143877847453685, 0.939406480847081]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[466, 0.15793718311639351`], {
             RGBColor[
             0.503508173143364, 0.6078096435993164, 0.9540571542825077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[467, 0.15793718311639351`], {
             RGBColor[
             0.7068391686146014, 0.7709073977891587, 0.9714147806060683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[468, 0.15793718311639351`], {
             RGBColor[
             0.4783770236668791, 0.5874070443089239, 0.952078738137285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[469, 0.15793718311639351`], {
             RGBColor[
             0.8604306779796645, 0.4591301305965446, 0.20525227536014304`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[470, 0.15793718311639351`], {
             RGBColor[
             0.25548210733168075`, 0.3858582716797478, 0.937860700109407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[471, 0.15793718311639351`], {
             RGBColor[
             0.8568125830318801, 0.4376919853814662, 0.20203709971295072`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[472, 0.15793718311639351`], {
             RGBColor[
             0.32844671668737896`, 0.45890577060779597`, 0.9421493122466601]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[473, 0.15793718311639351`], {
             RGBColor[
             0.32683125980079797`, 0.4575065430478635, 0.9420463767623395]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[474, 0.15793718311639351`], {
             RGBColor[
             0.9930971542734537, 0.9914135101440991, 0.7640615478883636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[475, 0.15793718311639351`], {
             RGBColor[
             0.839003391040872, 0.30080273170088523`, 0.1849829973497558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[476, 0.15793718311639351`], {
             RGBColor[
             0.8484924274103163, 0.3737396233586853, 0.19406970929346942`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[477, 0.15793718311639351`], {
             RGBColor[
             0.24467162743864543`, 0.3744957718881542, 0.9372450592721705]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[478, 0.15793718311639351`], {
             RGBColor[
             0.2660419428822219, 0.39695732837561076`, 0.9384620671221336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[479, 0.15793718311639351`], {
             RGBColor[
             0.41149067372934756`, 0.5308342722869064, 0.9474407997564864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[480, 0.15793718311639351`], {
             RGBColor[
             0.35354723518652786`, 0.48064657814301665`, 0.9437486950899088]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[481, 0.15793718311639351`], {
             RGBColor[
             0.318216697210702, 0.4500450419128276, 0.9414974644516573]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[482, 0.15793718311639351`], {
             RGBColor[
             0.35848143845973107`, 0.48492033701799786`, 0.9440630981593326]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[483, 0.15793718311639351`], {
             RGBColor[
             0.29664917161590876`, 0.42912746638510174`, 0.9402051035191799]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[484, 0.15793718311639351`], {
             RGBColor[
             0.9928916986278599, 0.9872043870615327, 0.4676834468726777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[485, 0.15793718311639351`], {
             RGBColor[
             0.24800119075484597`, 0.3779953540399882, 0.9374346729773807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[486, 0.15793718311639351`], {
             RGBColor[
             0.9349275982881982, 0.9509499052141509, 0.9936554230160899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[487, 0.15793718311639351`], {
             RGBColor[
             0.5794313774456323, 0.6694475211532741, 0.9600341070410434]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[488, 0.15793718311639351`], {
             RGBColor[
             0.7693643004981994, 0.8197525060252281, 0.9776467014216474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[489, 0.15793718311639351`], {
             RGBColor[
             0.9900975943251971, 0.9901731150203205, 0.8137720188432849]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[490, 0.15793718311639351`], {
             RGBColor[
             0.9905535588776926, 0.9903616680805318, 0.806215506209998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[491, 0.15793718311639351`], {
             RGBColor[
             0.9941614319695004, 0.9899202182895682, 0.6058860852243823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[492, 0.15793718311639351`], {
             RGBColor[
             0.2766193131480329, 0.4080748151689876, 0.9390644327109545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[493, 0.15793718311639351`], {
             RGBColor[
             0.9935772608954081, 0.9886707354308406, 0.5423026688954158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[494, 0.15793718311639351`], {
             RGBColor[
             0.2585035332044634, 0.3890339818415072, 0.938032765843063]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[495, 0.15793718311639351`], {
             RGBColor[
             0.8422024713778844, 0.3253922650171049, 0.18804644029332332`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[496, 0.15793718311639351`], {
             RGBColor[
             0.27688954314442643`, 0.4083588440287685, 0.9390798219094797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[497, 0.15793718311639351`], {
             RGBColor[
             0.23599364281048124`, 0.36537465982794926`, 0.9367508608855244]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[498, 0.15793718311639351`], {
             RGBColor[
             0.46188951150763047`, 0.5740217391840874, 0.9507807807843619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[499, 0.15793718311639351`], {
             RGBColor[
             0.2607186377132893, 0.3913621971260208, 0.9381589127678872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[500, 0.15793718311639351`], {
             RGBColor[
             0.8194926622925333, 0.15083472088530037`, 0.16629950146613023`]},
             StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{{3.834946926643799*^9, 3.8349469478612347`*^9}, 
   3.834947050298876*^9, {3.8349471234738255`*^9, 3.8349471300172663`*^9}, {
   3.8349471617829676`*^9, 3.834947218900016*^9}, {3.8349472753220577`*^9, 
   3.834947307624898*^9}, 3.83494993428115*^9, 3.8349573375769677`*^9, {
   3.8349587473655295`*^9, 3.83495875945916*^9}, 3.835018920680505*^9, 
   3.835019004300144*^9, 3.8350204747493663`*^9, 3.8350205388580465`*^9, {
   3.8350445644807453`*^9, 3.8350445774530525`*^9}, 3.8350450259183207`*^9, 
   3.835045692651933*^9, 3.8350457593931894`*^9, 3.835045816585536*^9, 
   3.835052059319915*^9, 3.83505250969635*^9, 3.835052701023122*^9, {
   3.8351300041710176`*^9, 3.835130031892748*^9}},
 Background->RGBColor[1, 1, 0.85],
 CellLabel->
  "Out[569]=",ExpressionUUID->"bb0d9b6f-4a1d-4151-a0f9-0f3a3370674e"]
}, Open  ]],

Cell["Estimated with cubic Mean Deviation v Calculated: (r=6)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 
  3.834950339812094*^9}},ExpressionUUID->"e850b377-d136-40c5-a3d5-\
833bda59fb0f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphinf5", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsif5", ",", "#"}], "}"}], "]"}], ",", "500", ",", "4"}],
      "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"CMDi6f500", ",", "krif5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.834950273560528*^9, 3.834950273964845*^9}, {
   3.834957360267254*^9, 3.8349573712318316`*^9}, {3.8349587856645794`*^9, 
   3.83495878977224*^9}, {3.8350188291975336`*^9, 3.8350188308736053`*^9}, {
   3.8350443206807604`*^9, 3.835044327012074*^9}, {3.8350446304641314`*^9, 
   3.835044631224497*^9}, {3.8350448339393716`*^9, 3.8350448366448307`*^9}, {
   3.835045599457345*^9, 3.8350456034768167`*^9}, {3.83505207591029*^9, 
   3.835052078308282*^9}, {3.8350524550749288`*^9, 3.8350524569490147`*^9}, {
   3.8350527247540455`*^9, 3.835052732510481*^9}},
 CellLabel->
  "In[446]:=",ExpressionUUID->"1f7c7df0-46de-4766-b9e2-e85b3f0cb99d"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1dOWGAgQBNBMbNu2bds2J+bEtm3btm3btu01sjdnH271F1R1ssCg6p0C
ggUL9l38vMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEIS
kZgkJCUZyUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpR
mCIUpRjFKUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGY
JjSlGYE0pwUtaUVr2tCWdrSnAx3pRBCd6UJXutGdHvSkF73pQ1/60Z8BDGQQ
gxnCUIYxnBGMZBSjGcNYxjGeCUxkEpOZwlSmMZ0ZzGQWs5nDXOYxnwUsZBGL
WcJSlrGcFaxkFatZw1rWsZ4NbGQTm9nCVraxnR3sZBe72cNe9rGfAxzkEIc5
wlGOcZwTnOQUpznDWc5xngtc5BKXucJVrnGdG9zkFre5w13ucZ8HPOQRj3nC
U57xnBe85BWvecNb3vGeD3zkE5/5wle+8Z1f+JXf+J0/+JO/+Jt/+Jcf/Cx/
AMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEISkZgkJCUZ
yUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpRmCIUpRjF
KUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGYJjSlGYE0
pwUtaUVr2tCWdrSnAx35Od5BdKYLXelGd3rQk170pg996Ud/BjCQQQxmCEMZ
xnBGMJJRjGYMYxnHeCYwkUlMZgpTmcZ0ZjCTWcxmDnOZx3wWsJBFLGYJS1nG
clawklWsZg1rWcd6NrCRTWxmC1vZxnZ2sJNd7GYPe9nHfg5wkEMc5ghHOcZx
TnCSU5zmDGc5x3kucJFLXOYKV7nGdW5wk1vc5g53ucd9HvCQRzzmCU95xnNe
8JJXvOYNb3nHez7wkU985gtf+Rbw/z//Dz189+A=
          "], {Null, CompressedData["
1:eJw13A2c1mO6wPH7tsdpl2O9LLLYQ3Ioas/uCqvVrqQihdKSUmmVzEwspdpK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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[196, 330] -> 
             RGBColor[
              0.32537808411842595`, 0.4518298639703964, 0.9421155467301773], 
             UndirectedEdge[136, 319] -> 
             RGBColor[
              0.30297342583997355`, 0.43186680688930945`, 0.9407083460339274],
              UndirectedEdge[60, 188] -> 
             RGBColor[
              0.23327762773917593`, 0.36251995578270574`, 0.9365961878451978],
              UndirectedEdge[145, 408] -> 
             RGBColor[
              0.3282200639524777, 0.4538677258215365, 0.9423121495725059], 
             UndirectedEdge[398, 460] -> 
             RGBColor[
              0.2193374437779616, 0.34786793858075715`, 0.9358023149912607], 
             UndirectedEdge[413, 476] -> 
             RGBColor[
              0.25217149266044675`, 0.3823786057551871, 0.9376721655014958], 
             UndirectedEdge[244, 274] -> 
             RGBColor[
              0.40465733387738523`, 0.5173434113671104, 0.9479323548343548], 
             UndirectedEdge[198, 223] -> 
             RGBColor[
              0.356289985116648, 0.48160412579690254`, 0.9439753837096442], 
             UndirectedEdge[36, 310] -> 
             RGBColor[
              0.33619748196766147`, 0.4651984333541015, 0.942658586600883], 
             UndirectedEdge[252, 432] -> 
             RGBColor[
              0.30267104773324927`, 0.4350653950488076, 0.9405623731724579], 
             UndirectedEdge[469, 475] -> 
             RGBColor[
              0.4219730326165199, 0.5399135646962983, 0.948108726395591], 
             UndirectedEdge[113, 347] -> 
             RGBColor[
              0.3043126213644256, 0.43668652407036707`, 0.9406596761591715], 
             UndirectedEdge[35, 131] -> 
             RGBColor[
              0.5456531296625032, 0.6416992531480954, 0.957495315324815], 
             UndirectedEdge[156, 479] -> 
             RGBColor[
              0.3429908237858506, 0.4715031451684143, 0.9430760498901257], 
             UndirectedEdge[318, 354] -> 
             RGBColor[
              0.7687489837239145, 0.8198677496201479, 0.9774272299059115], 
             UndirectedEdge[6, 77] -> 
             RGBColor[
              0.42085783786685993`, 0.5280465354573923, 0.9494306569831121], 
             UndirectedEdge[23, 202] -> 
             RGBColor[
              0.2748267491756965, 0.40619071677894175`, 0.9389623488445908], 
             UndirectedEdge[342, 395] -> 
             RGBColor[
              0.3021956228242944, 0.4346219160266674, 0.9405332398387292], 
             UndirectedEdge[53, 418] -> 
             RGBColor[
              0.6106897886972149, 0.6902579143193588, 0.964945392323808], 
             UndirectedEdge[75, 149] -> 
             RGBColor[
              0.4227172608618136, 0.5331891199846208, 0.9492463373886431], 
             UndirectedEdge[293, 418] -> 
             RGBColor[
              0.5377450994183253, 0.6209828434083888, 0.9605205541518484], 
             UndirectedEdge[282, 432] -> 
             RGBColor[
              0.3435992579405138, 0.4720301402523938, 0.9431148187764437], 
             UndirectedEdge[466, 468] -> 
             RGBColor[
              0.3121119132519271, 0.4436783432022194, 0.9411479820178059], 
             UndirectedEdge[105, 190] -> 
             RGBColor[
              0.6743858732507966, 0.7170739346374994, 0.6578025290491971], 
             UndirectedEdge[64, 473] -> 
             RGBColor[
              0.28141977761397885`, 0.41312040768972325`, 0.9393378120606395],
              UndirectedEdge[214, 273] -> 
             RGBColor[
              0.33317936838238926`, 0.45150650891891486`, 0.9430160684502362],
              UndirectedEdge[30, 64] -> 
             RGBColor[
              0.2703042423382894, 0.4014372753493318, 0.9387047987706497], 
             UndirectedEdge[296, 395] -> 
             RGBColor[
              0.30657865317353783`, 0.4384182766176713, 0.9408125226568214], 
             UndirectedEdge[114, 203] -> 
             RGBColor[
              0.28668559060106974`, 0.4157598784247698, 0.9397437009678107], 
             UndirectedEdge[81, 237] -> 
             RGBColor[
              0.27208430199858474`, 0.4033082309146033, 0.9388061705349413], 
             UndirectedEdge[382, 427] -> 
             RGBColor[
              0.43562540811075146`, 0.5495684934498513, 0.9495782412456037], 
             UndirectedEdge[39, 450] -> 
             RGBColor[
              0.30422808684035463`, 0.4345689304966003, 0.9407291442414556], 
             UndirectedEdge[50, 57] -> 
             RGBColor[
              0.2993334213170487, 0.4317736477352392, 0.9403643801290813], 
             UndirectedEdge[74, 153] -> 
             RGBColor[
              0.4619393954013594, 0.5728886555364794, 0.9511089719309671], 
             UndirectedEdge[239, 332] -> 
             RGBColor[
              0.4191520677319591, 0.5359630304263426, 0.9483454087763685], 
             UndirectedEdge[14, 72] -> 
             RGBColor[
              0.29133270710872516`, 0.4166373303627908, 0.9401550618912393], 
             UndirectedEdge[331, 403] -> 
             RGBColor[
              0.325923721436505, 0.45203913277119784`, 0.9421599562353198], 
             UndirectedEdge[214, 302] -> 
             RGBColor[
              0.25397805788520417`, 0.383507852009367, 0.9378032243852191], 
             UndirectedEdge[128, 197] -> 
             RGBColor[
              0.2801432432545966, 0.4117786891410595, 0.9392651153173359], 
             UndirectedEdge[191, 212] -> 
             RGBColor[
              0.29726013407882657`, 0.42834494826516234`, 0.9402920613829984],
              UndirectedEdge[404, 407] -> 
             RGBColor[
              0.41370052381917727`, 0.5204053501718319, 0.949033835533031], 
             UndirectedEdge[60, 116] -> 
             RGBColor[
              0.290226202075678, 0.4159792072535978, 0.9400735617960273], 
             UndirectedEdge[272, 357] -> 
             RGBColor[
              0.43649972624530353`, 0.5455861354473004, 0.9502214030678764], 
             UndirectedEdge[228, 490] -> 
             RGBColor[
              0.5164201264206575, 0.6136678622136623, 0.9567801364359081], 
             UndirectedEdge[111, 415] -> 
             RGBColor[
              0.2972159418156486, 0.4297231778003345, 0.9402373802435937], 
             UndirectedEdge[227, 428] -> 
             RGBColor[
              0.2693911155887458, 0.4004775212399817, 0.9386527975531131], 
             UndirectedEdge[367, 499] -> 
             RGBColor[
              0.28003994836037044`, 0.4116701196579532, 0.9392592328259208], 
             UndirectedEdge[434, 495] -> 
             RGBColor[
              0.5284977666640296, 0.6178100163577864, 0.9589684579346547], 
             UndirectedEdge[226, 283] -> 
             RGBColor[
              0.29614919240833165`, 0.4286019565374255, 0.9401766304429613], 
             UndirectedEdge[9, 34] -> 
             RGBColor[
              0.35352648411393695`, 0.47905679972095017`, 0.9438049243264646],
              UndirectedEdge[127, 386] -> 
             RGBColor[
              0.5574573432912244, 0.6405366362373883, 0.9618196305953318], 
             UndirectedEdge[326, 469] -> 
             RGBColor[
              0.4583627302208659, 0.5697907279255549, 0.950881069988387], 
             UndirectedEdge[192, 483] -> 
             RGBColor[
              0.2832583738671508, 0.4150528889255424, 0.9394425173972981], 
             UndirectedEdge[16, 39] -> 
             RGBColor[
              0.30133019008659706`, 0.4315230572711347, 0.9405641133083831], 
             UndirectedEdge[209, 421] -> 
             RGBColor[
              0.26665880370651635`, 0.3972269923496162, 0.9385110623441659], 
             UndirectedEdge[293, 317] -> 
             RGBColor[
              0.2764554854428187, 0.4077795318947397, 0.9390596098922326], 
             UndirectedEdge[3, 381] -> 
             RGBColor[
              0.3426874089179265, 0.4712403424598931, 0.9430567165630408], 
             UndirectedEdge[211, 497] -> 
             RGBColor[
              0.5714275109554221, 0.6418846441256053, 0.9562218858271847], 
             UndirectedEdge[196, 479] -> 
             RGBColor[
              0.28630630254854605`, 0.41798785057940824`, 0.9396259273583644],
              UndirectedEdge[221, 439] -> 
             RGBColor[
              0.6566220840703149, 0.6675220957961796, 0.6122769090191604], 
             UndirectedEdge[379, 390] -> 
             RGBColor[
              0.5103083676634432, 0.6084143542476915, 0.9563736901394801], 
             UndirectedEdge[119, 320] -> 
             RGBColor[
              0.2581002454855258, 0.3886101008789855, 0.9380097992040802], 
             UndirectedEdge[179, 401] -> 
             RGBColor[
              0.22728391389660996`, 0.35622018251076215`, 0.9362548547087687],
              UndirectedEdge[59, 342] -> 
             RGBColor[
              0.42121594857204914`, 0.537174086414851, 0.948636226514319], 
             UndirectedEdge[86, 98] -> 
             RGBColor[
              0.43920615091719817`, 0.5541093448638095, 0.9494086947213694], 
             UndirectedEdge[328, 431] -> 
             RGBColor[
              0.3885770347923928, 0.5109876299126955, 0.945980762945159], 
             UndirectedEdge[270, 375] -> 
             RGBColor[
              0.45891226832269894`, 0.5699350043422362, 0.951007737389541], 
             UndirectedEdge[39, 45] -> 
             RGBColor[
              0.3166100783983864, 0.44758318868769953`, 0.9414342803431706], 
             UndirectedEdge[59, 463] -> 
             RGBColor[
              0.7599659793679686, 0.8097227468658681, 0.8868309036641199], 
             UndirectedEdge[2, 55] -> 
             RGBColor[
              0.2617305958237108, 0.391253530468996, 0.9382594658866745], 
             UndirectedEdge[193, 496] -> 
             RGBColor[
              0.2789675459718982, 0.4103735360100222, 0.9392043644197188], 
             UndirectedEdge[201, 246] -> 
             RGBColor[
              0.3239483179760788, 0.4550094837401611, 0.9418626782585537], 
             UndirectedEdge[69, 487] -> 
             RGBColor[
              0.45297918778833307`, 0.5649385556885385, 0.950590317023552], 
             UndirectedEdge[15, 408] -> 
             RGBColor[
              0.6060105040333921, 0.6766196423782695, 0.9489408297081157], 
             UndirectedEdge[118, 310] -> 
             RGBColor[
              0.4937887853434399, 0.5948209290466644, 0.9548558111879343], 
             UndirectedEdge[289, 297] -> 
             RGBColor[
              0.3613847306174177, 0.48611908420951366`, 0.9442962763250045], 
             UndirectedEdge[397, 419] -> 
             RGBColor[
              0.3039639837740025, 0.4289585217559195, 0.9409093646142179], 
             UndirectedEdge[13, 380] -> 
             RGBColor[
              0.39162977978154834`, 0.5066345474573899, 0.9469188398122959], 
             UndirectedEdge[155, 262] -> 
             RGBColor[
              0.5559109061299013, 0.6453083158428536, 0.9603818613153942], 
             UndirectedEdge[182, 324] -> 
             RGBColor[
              0.3738531580875366, 0.49823454795450994`, 0.9450425705413386], 
             UndirectedEdge[177, 245] -> 
             RGBColor[
              0.3139375488098808, 0.4422053999451028, 0.9413761397477046], 
             UndirectedEdge[113, 325] -> 
             RGBColor[
              0.2904914434484028, 0.4221595897673338, 0.9398725805234543], 
             UndirectedEdge[94, 368] -> 
             RGBColor[
              0.6417992528163612, 0.7061678474450253, 0.8162606870273654], 
             UndirectedEdge[50, 140] -> 
             RGBColor[
              0.3206764398726418, 0.4502598976767903, 0.9417243383985535], 
             UndirectedEdge[389, 458] -> 
             RGBColor[
              0.3595621037775764, 0.48229577988243943`, 0.9442623272947714], 
             UndirectedEdge[429, 499] -> 
             RGBColor[
              0.29370734948565225`, 0.42603542480390605`, 0.9400375711008977],
              UndirectedEdge[97, 358] -> 
             RGBColor[
              0.4605753326394801, 0.5691599865320909, 0.9517258502495949], 
             UndirectedEdge[274, 363] -> 
             RGBColor[
              0.2701994955891793, 0.4013271798746896, 0.9386988335982468], 
             UndirectedEdge[255, 274] -> 
             RGBColor[
              0.30673099448910324`, 0.43523520849506736`, 0.9409436087775287],
              UndirectedEdge[289, 381] -> 
             RGBColor[
              0.39713122948062607`, 0.518396843405317, 0.9465258286665159], 
             UndirectedEdge[55, 230] -> 
             RGBColor[
              0.29273333860863454`, 0.4238393788233762, 0.9400250262238281], 
             UndirectedEdge[289, 349] -> 
             RGBColor[
              0.42746810855504785`, 0.544673123283704, 0.9484588677752892], 
             UndirectedEdge[29, 318] -> 
             RGBColor[
              0.6230440165510414, 0.6988588482777491, 0.9666991895765319], 
             UndirectedEdge[69, 402] -> 
             RGBColor[
              0.35431734238865575`, 0.4813136062947864, 0.9437977656398493], 
             UndirectedEdge[6, 413] -> 
             RGBColor[
              0.42625015382701964`, 0.5337142014240989, 0.9497377413998266], 
             UndirectedEdge[29, 482] -> 
             RGBColor[
              0.3230826023916115, 0.45287698658561354`, 0.9418581415032121], 
             UndirectedEdge[212, 456] -> 
             RGBColor[
              0.33355493909917167`, 0.4633302561141671, 0.9424748036617158], 
             UndirectedEdge[354, 482] -> 
             RGBColor[
              0.46878756956448486`, 0.5738858879280124, 0.9525861818325918], 
             UndirectedEdge[106, 247] -> 
             RGBColor[
              0.35681919692371133`, 0.48247232109304766`, 0.9439940991505158],
              UndirectedEdge[305, 382] -> 
             RGBColor[
              0.28885221437341774`, 0.41822664807856974`, 0.9398601480714484],
              UndirectedEdge[279, 285] -> 
             RGBColor[
              0.28052767151646363`, 0.41218274761844126`, 0.9392870079381386],
              UndirectedEdge[27, 319] -> 
             RGBColor[
              0.2581083457040704, 0.3886186147222594, 0.9380102604995432], 
             UndirectedEdge[118, 483] -> 
             RGBColor[
              0.4758960543567841, 0.576014534315021, 0.9538368466281677], 
             UndirectedEdge[342, 447] -> 
             RGBColor[
              0.621193456688631, 0.6026115106331071, 0.6018359080702526], 
             UndirectedEdge[207, 458] -> 
             RGBColor[
              0.32123352481114653`, 0.4490974912321108, 0.9418200641356621], 
             UndirectedEdge[462, 487] -> 
             RGBColor[
              0.4614802764978421, 0.572301771451573, 0.9511319988789044], 
             UndirectedEdge[64, 384] -> 
             RGBColor[
              0.3520213518157216, 0.4754370424528974, 0.9437938219298323], 
             UndirectedEdge[203, 221] -> 
             RGBColor[
              0.6460831237211158, 0.6583937780452522, 0.6116053757849462], 
             UndirectedEdge[139, 370] -> 
             RGBColor[
              0.4000407011690553, 0.5209168815475353, 0.9467112176297577], 
             UndirectedEdge[46, 357] -> 
             RGBColor[
              0.4983370067488957, 0.6021592617973868, 0.9540513071931429], 
             UndirectedEdge[18, 326] -> 
             RGBColor[
              0.46912150107516254`, 0.5791094344880003, 0.9515666093536151], 
             UndirectedEdge[73, 93] -> 
             RGBColor[
              0.3752774524960066, 0.4994682001840082, 0.9451333253215921], 
             UndirectedEdge[104, 112] -> 
             RGBColor[
              0.29400882313177046`, 0.4226538167418803, 0.9401901589020638], 
             UndirectedEdge[40, 314] -> 
             RGBColor[
              0.3562376275353101, 0.4761804066745331, 0.9442893140155857], 
             UndirectedEdge[264, 398] -> 
             RGBColor[
              0.2767497473180145, 0.40524570271933913`, 0.9391804681137519], 
             UndirectedEdge[345, 489] -> 
             RGBColor[
              0.29747258482185285`, 0.4237827885105943, 0.9404793792330371], 
             UndirectedEdge[80, 417] -> 
             RGBColor[
              0.3774558445942924, 0.4991776586809089, 0.9454343458387047], 
             UndirectedEdge[271, 442] -> 
             RGBColor[
              0.3129440775581589, 0.4440168797477819, 0.9412150025564647], 
             UndirectedEdge[318, 482] -> 
             RGBColor[
              0.5937527830185738, 0.6721055961847174, 0.9648834039532422], 
             UndirectedEdge[235, 260] -> 
             RGBColor[
              0.29267686459117404`, 0.4217987494260689, 0.940094354171744], 
             UndirectedEdge[79, 278] -> 
             RGBColor[
              0.3014981472428113, 0.4342240472117881, 0.9404812455077154], 
             UndirectedEdge[137, 404] -> 
             RGBColor[
              0.49482122852027455`, 0.598837715801958, 0.9539036427895162], 
             UndirectedEdge[380, 478] -> 
             RGBColor[
              0.30677785112338873`, 0.4351733653767857, 0.9409503448309287], 
             UndirectedEdge[247, 370] -> 
             RGBColor[
              0.3274864972676159, 0.4570658109552898, 0.9421250454663173], 
             UndirectedEdge[251, 429] -> 
             RGBColor[
              0.2981513032441211, 0.4303991257752138, 0.9403018949183231], 
             UndirectedEdge[286, 407] -> 
             RGBColor[
              0.22911463617680608`, 0.35814438770174506`, 0.9363591116343148],
              UndirectedEdge[206, 410] -> 
             RGBColor[
              0.25389879102272206`, 0.38419410585098, 0.9377705325879184], 
             UndirectedEdge[86, 500] -> 
             RGBColor[
              0.3750890828079514, 0.4993050438279506, 0.945121322571638], 
             UndirectedEdge[78, 407] -> 
             RGBColor[
              0.20657777419938345`, 0.334456716843894, 0.9350756706850003], 
             UndirectedEdge[363, 370] -> 
             RGBColor[
              0.32068324372868695`, 0.4499151601346874, 0.9417376102417869], 
             UndirectedEdge[447, 453] -> 
             RGBColor[
              0.7036709547120156, 0.6733974811524364, 0.6072714212432673], 
             UndirectedEdge[256, 492] -> 
             RGBColor[
              0.3067542364616502, 0.4387983131415774, 0.9408153641156247], 
             UndirectedEdge[114, 349] -> 
             RGBColor[
              0.32999525338267066`, 0.4532725315192477, 0.9425033543830232], 
             UndirectedEdge[22, 160] -> 
             RGBColor[
              0.3345495269083127, 0.45715139705410063`, 0.9427959585582413], 
             UndirectedEdge[149, 324] -> 
             RGBColor[
              0.30087017440870145`, 0.4310739634009525, 0.9405366561124442], 
             UndirectedEdge[94, 315] -> 
             RGBColor[0.6155454257518824, 0.67857341061148, 0.8147655704151], 
             UndirectedEdge[246, 492] -> 
             RGBColor[
              0.3245806333599376, 0.45555716354456427`, 0.9419029688356788], 
             UndirectedEdge[193, 202] -> 
             RGBColor[
              0.28552193284714245`, 0.41726261218803407`, 0.9395776270559175],
              UndirectedEdge[321, 335] -> 
             RGBColor[
              0.2636060496983948, 0.3943970501948603, 0.9383233466088958], 
             UndirectedEdge[321, 496] -> 
             RGBColor[
              0.2663979836312177, 0.3973315497770926, 0.9384823431160738], 
             UndirectedEdge[18, 474] -> 
             RGBColor[
              0.32164429816353246`, 0.44470036993690787`, 0.9420202656607733],
              UndirectedEdge[184, 192] -> 
             RGBColor[
              0.28265894328951674`, 0.41442284938235524`, 0.9394083807126798],
              UndirectedEdge[170, 171] -> 
             RGBColor[
              0.2609020040150326, 0.39155492673524805`, 0.9381693552075053], 
             UndirectedEdge[80, 156] -> 
             RGBColor[
              0.331624452594818, 0.45982497301720227`, 0.9424189169341686], 
             UndirectedEdge[353, 418] -> 
             RGBColor[
              0.5914482487402649, 0.6735918595165667, 0.963719338412377], 
             UndirectedEdge[201, 312] -> 
             RGBColor[
              0.31142901594140404`, 0.44382872652808014`, 0.9410773047398393],
              UndirectedEdge[152, 212] -> 
             RGBColor[
              0.3042393577712771, 0.43568055487426804`, 0.9406895178474471], 
             UndirectedEdge[192, 260] -> 
             RGBColor[
              0.32048029282660306`, 0.45102191534067165`, 0.9416777182782656],
              UndirectedEdge[90, 357] -> 
             RGBColor[
              0.410562757736043, 0.5183247370452823, 0.9487443310815804], 
             UndirectedEdge[57, 369] -> 
             RGBColor[
              0.38761374574356555`, 0.5098472907109118, 0.9460039280401971], 
             UndirectedEdge[83, 448] -> 
             RGBColor[
              0.41616829005972333`, 0.5320938376108015, 0.9483465142206449], 
             UndirectedEdge[67, 180] -> 
             RGBColor[
              0.3712768261018824, 0.49600305867874694`, 0.9448784089453734], 
             UndirectedEdge[373, 472] -> 
             RGBColor[
              0.2635109407289557, 0.39429708463772284`, 0.9383179302937873], 
             UndirectedEdge[353, 432] -> 
             RGBColor[
              0.3316098794612853, 0.46164554321736995`, 0.9423508661815383], 
             UndirectedEdge[1, 433] -> 
             RGBColor[
              0.48476042924766133`, 0.5854937257925473, 0.9543159855467488], 
             UndirectedEdge[300, 301] -> 
             RGBColor[
              0.25291995824008207`, 0.3831652905348425, 0.9377147895090004], 
             UndirectedEdge[212, 389] -> 
             RGBColor[
              0.3865220016328993, 0.5092076634789121, 0.9458498180494306], 
             UndirectedEdge[97, 174] -> 
             RGBColor[
              0.5006640201560811, 0.6038827927429498, 0.9542802659691182], 
             UndirectedEdge[200, 471] -> 
             RGBColor[
              0.32075858426609694`, 0.4493309728181985, 0.9417661901822418], 
             UndirectedEdge[155, 387] -> 
             RGBColor[
              0.2699526545615311, 0.3981436331377874, 0.9387918420346497], 
             UndirectedEdge[156, 354] -> 
             RGBColor[
              0.5090571140574185, 0.6101480011890471, 0.9551014957225431], 
             UndirectedEdge[314, 472] -> 
             RGBColor[
              0.2503270722813453, 0.3804400029937452, 0.9375671284894814], 
             UndirectedEdge[117, 269] -> 
             RGBColor[
              0.7430126029301558, 0.799162127325086, 0.9751946007697969], 
             UndirectedEdge[336, 409] -> 
             RGBColor[
              0.23836618775359522`, 0.36786835499119974`, 0.936885973810169], 
             UndirectedEdge[63, 252] -> 
             RGBColor[
              0.2921206520638884, 0.4243677052112051, 0.9399472110300366], 
             UndirectedEdge[201, 444] -> 
             RGBColor[
              0.2874750183445739, 0.418651556282644, 0.9397131600134636], 
             UndirectedEdge[201, 442] -> 
             RGBColor[
              0.305349870829171, 0.43743915957506113`, 0.9407311064189869], 
             UndirectedEdge[25, 333] -> 
             RGBColor[
              0.551242302093989, 0.6366896730443384, 0.9610588676420718], 
             UndirectedEdge[203, 397] -> 
             RGBColor[
              0.36689480459078944`, 0.4922075718926434, 0.9445991904095561], 
             UndirectedEdge[7, 436] -> 
             RGBColor[
              0.24542015519463006`, 0.3752825220190949, 0.9372876868205262], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.5974559616383552, 0.667628275931771, 0.9484536611740297], 
             UndirectedEdge[274, 369] -> 
             RGBColor[
              0.36037600600067105`, 0.48139383454570617`, 0.9444463664960511],
              UndirectedEdge[38, 364] -> 
             RGBColor[
              0.6298883178421724, 0.7039917853978015, 0.9675014008812328], 
             UndirectedEdge[215, 356] -> 
             RGBColor[
              0.4203716919905961, 0.5376390193035466, 0.9482519216121562], 
             UndirectedEdge[16, 283] -> 
             RGBColor[
              0.2845128366061411, 0.4163714088017527, 0.9395139571944724], 
             UndirectedEdge[236, 276] -> 
             RGBColor[
              0.3772299493802354, 0.49746865671648904`, 0.9455554330560079], 
             UndirectedEdge[39, 454] -> 
             RGBColor[
              0.43856554678376164`, 0.5519021971453393, 0.9498244082599898], 
             UndirectedEdge[179, 315] -> 
             RGBColor[
              0.22043467394470245`, 0.34902119705441237`, 0.93586480062605], 
             UndirectedEdge[149, 182] -> 
             RGBColor[
              0.3390453635176709, 0.46413939346634736`, 0.9429691454054734], 
             UndirectedEdge[97, 407] -> 
             RGBColor[
              0.4139888139644822, 0.5206393970991134, 0.9490565307893111], 
             UndirectedEdge[274, 379] -> 
             RGBColor[
              0.28333016638386443`, 0.4149665873501284, 0.9394525287032027], 
             UndirectedEdge[39, 325] -> 
             RGBColor[
              0.30146273877054985`, 0.431662374342041, 0.9405716617598461], 
             UndirectedEdge[127, 347] -> 
             RGBColor[
              0.5681794202655019, 0.6518062189562985, 0.9624302370171255], 
             UndirectedEdge[327, 483] -> 
             RGBColor[
              0.42071200808766995`, 0.5318420500190769, 0.949062908683979], 
             UndirectedEdge[269, 360] -> 
             RGBColor[
              0.5453780902592326, 0.6241794856482414, 0.9616863649108902], 
             UndirectedEdge[54, 147] -> 
             RGBColor[
              0.2370504067857524, 0.3664853857686652, 0.9368110420305739], 
             UndirectedEdge[276, 422] -> 
             RGBColor[
              0.4028654800237479, 0.5226853406305615, 0.9470786049058217], 
             UndirectedEdge[181, 424] -> 
             RGBColor[
              0.3084378000193689, 0.43842999098529245`, 0.9409895178844105], 
             UndirectedEdge[336, 456] -> 
             RGBColor[
              0.2905064388191045, 0.41950823129297765`, 0.9399710907999219], 
             UndirectedEdge[46, 298] -> 
             RGBColor[
              0.3260329385927924, 0.4515898923470144, 0.9421868280597712], 
             UndirectedEdge[107, 132] -> 
             RGBColor[
              0.3421969437423345, 0.47081552617629185`, 0.9430254645557534], 
             UndirectedEdge[78, 95] -> 
             RGBColor[
              0.24377004958662993`, 0.3735481564023485, 0.9371937157472632], 
             UndirectedEdge[296, 332] -> 
             RGBColor[
              0.41498159262231915`, 0.5323507745005462, 0.9480796697901885], 
             UndirectedEdge[397, 472] -> 
             RGBColor[
              0.32685829634267305`, 0.4530218958488485, 0.9422131618459035], 
             UndirectedEdge[19, 269] -> 
             RGBColor[
              0.5927201568770827, 0.6733851364522525, 0.9644027052013643], 
             UndirectedEdge[185, 335] -> 
             RGBColor[
              0.2836702000010342, 0.4139304718314949, 0.9395229164302727], 
             UndirectedEdge[112, 351] -> 
             RGBColor[
              0.35500886298222833`, 0.47501571256362596`, 0.944207794170836], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.24387252055979958`, 0.37365585989218475`, 0.937199551317593], 
             UndirectedEdge[251, 305] -> 
             RGBColor[
              0.2758810491777799, 0.40699167673582726`, 0.9390336368951333], 
             UndirectedEdge[131, 170] -> 
             RGBColor[
              0.34345480814381835`, 0.4658109777344726, 0.9433287474895654], 
             UndirectedEdge[76, 333] -> 
             RGBColor[
              0.5664666283245456, 0.652366227962671, 0.9619377768297674], 
             UndirectedEdge[114, 115] -> 
             RGBColor[
              0.2757769877021288, 0.40631139487603085`, 0.9390486144371889], 
             UndirectedEdge[87, 421] -> 
             RGBColor[
              0.29485256312401126`, 0.42164700969749913`, 0.9403075437634862],
              UndirectedEdge[60, 192] -> 
             RGBColor[
              0.2503100053844817, 0.38042206460303774`, 0.9375661565549532], 
             UndirectedEdge[84, 147] -> 
             RGBColor[
              0.3344882832704137, 0.4589478199143692, 0.9427243380470751], 
             UndirectedEdge[431, 433] -> 
             RGBColor[
              0.5651305091776502, 0.6570852515451886, 0.9593646350125357], 
             UndirectedEdge[201, 492] -> 
             RGBColor[
              0.31839109806614657`, 0.4501960991681718, 0.9415085771199495], 
             UndirectedEdge[86, 124] -> 
             RGBColor[
              0.39930648634218946`, 0.5202809415672143, 0.9466644341102306], 
             UndirectedEdge[234, 239] -> 
             RGBColor[
              0.3236937091535074, 0.4547889543750613, 0.9418464548095213], 
             UndirectedEdge[100, 450] -> 
             RGBColor[
              0.32330119395404244`, 0.45108909723623936`, 0.9419444657610534],
              UndirectedEdge[22, 275] -> 
             RGBColor[
              0.3594471123692681, 0.4833203379716584, 0.9442138392175657], 
             UndirectedEdge[160, 324] -> 
             RGBColor[
              0.28413842715533555`, 0.41348783618361706`, 0.9395838078587668],
              UndirectedEdge[191, 218] -> 
             RGBColor[
              0.25836499873393515`, 0.3888883733293892, 0.9380248765099098], 
             UndirectedEdge[349, 397] -> 
             RGBColor[
              0.41020446737239036`, 0.5297202249871213, 0.9473588438247686], 
             UndirectedEdge[401, 454] -> 
             RGBColor[0.395455282412895, 0.5091150322633, 0.947276909767746], 
             UndirectedEdge[311, 349] -> 
             RGBColor[
              0.3649387717865599, 0.49000038490876596`, 0.9444933360618217], 
             UndirectedEdge[63, 324] -> 
             RGBColor[
              0.31377849534684576`, 0.44464142714176014`, 0.941271765893722], 
             UndirectedEdge[22, 353] -> 
             RGBColor[
              0.39337005717662293`, 0.5151391049976061, 0.9462861700931788], 
             UndirectedEdge[93, 437] -> 
             RGBColor[
              0.33633501871539867`, 0.46194197552757454`, 0.9427909470323483],
              UndirectedEdge[417, 461] -> 
             RGBColor[
              0.35354192324240735`, 0.4740426111098907, 0.9440724833951911], 
             UndirectedEdge[151, 249] -> 
             RGBColor[
              0.33675793788664043`, 0.46359329013663864`, 0.9427708448031616],
              UndirectedEdge[148, 452] -> 
             RGBColor[
              0.27415444941778877`, 0.4054840871071141, 0.9389240623679562], 
             UndirectedEdge[262, 424] -> 
             RGBColor[
              0.5230893034417832, 0.6137348315740565, 0.9584056539297569], 
             UndirectedEdge[50, 139] -> 
             RGBColor[
              0.3654878757496205, 0.48907331114517383`, 0.9445796834674377], 
             UndirectedEdge[237, 267] -> 
             RGBColor[
              0.2674003823141685, 0.3983851343486213, 0.938539428238152], 
             UndirectedEdge[256, 442] -> 
             RGBColor[
              0.2937130092246746, 0.4260413735484667, 0.9400378934146622], 
             UndirectedEdge[60, 133] -> 
             RGBColor[
              0.2534659406617682, 0.3837391526773195, 0.937745882400207], 
             UndirectedEdge[77, 156] -> 
             RGBColor[
              0.30500936855727045`, 0.4318508321999468, 0.9409032272717186], 
             UndirectedEdge[219, 498] -> 
             RGBColor[
              0.6059910606070265, 0.6773339960836999, 0.9531513182624579], 
             UndirectedEdge[102, 185] -> 
             RGBColor[
              0.2939705672291499, 0.42475681086924694`, 0.940109507105886], 
             UndirectedEdge[92, 169] -> 
             RGBColor[
              0.3685450888703953, 0.49361902709753686`, 0.9447050018659984], 
             UndirectedEdge[53, 357] -> 
             RGBColor[
              0.4927811507932633, 0.5973470586140577, 0.9536972929645005], 
             UndirectedEdge[162, 289] -> 
             RGBColor[
              0.3696805149995165, 0.4946204142348065, 0.9447766934134932], 
             UndirectedEdge[169, 204] -> 
             RGBColor[
              0.2650023562972814, 0.39586465696124185`, 0.9384028642040518], 
             UndirectedEdge[176, 448] -> 
             RGBColor[
              0.6604165975244745, 0.7329355537214444, 0.9679543362640093], 
             UndirectedEdge[377, 403] -> 
             RGBColor[
              0.3963697923563595, 0.5177373248392199, 0.94647731056627], 
             UndirectedEdge[86, 357] -> 
             RGBColor[
              0.49751158346613467`, 0.6014443216368397, 0.9539987119514586], 
             UndirectedEdge[12, 373] -> 
             RGBColor[
              0.4901124702137567, 0.5869348105159453, 0.95528320448933], 
             UndirectedEdge[200, 469] -> 
             RGBColor[
              0.38362489204656713`, 0.5066983327681929, 0.9456652167884028], 
             UndirectedEdge[112, 153] -> 
             RGBColor[
              0.3246826717434447, 0.449221962696854, 0.9421446694117803], 
             UndirectedEdge[166, 243] -> 
             RGBColor[
              0.2545941639165943, 0.3849249868516277, 0.9378101330455124], 
             UndirectedEdge[394, 460] -> 
             RGBColor[
              0.2559377723129188, 0.3863372044658575, 0.9378866495559927], 
             UndirectedEdge[18, 348] -> 
             RGBColor[
              0.4338166942114427, 0.55017194909008, 0.9488633940394807], 
             UndirectedEdge[315, 325] -> 
             RGBColor[
              0.2515032344477757, 0.381676224003652, 0.9376341091848837], 
             UndirectedEdge[195, 447] -> 
             RGBColor[
              0.7609016251366696, 0.7198599176154921, 0.6117768292619494], 
             UndirectedEdge[128, 204] -> 
             RGBColor[
              0.2626803380161941, 0.39342406852335676`, 0.9382706286980621], 
             UndirectedEdge[91, 435] -> 
             RGBColor[
              0.47526917290894954`, 0.5790467332359228, 0.9532167927737226], 
             UndirectedEdge[158, 206] -> 
             RGBColor[
              0.3034287688560122, 0.43286204682747875`, 0.9407153602203457], 
             UndirectedEdge[30, 290] -> 
             RGBColor[
              0.26753356975743603`, 0.3985251227960671, 0.938547013066013], 
             UndirectedEdge[2, 250] -> 
             RGBColor[
              0.22320027563435835`, 0.3519280197795155, 0.9360222975509349], 
             UndirectedEdge[148, 195] -> 
             RGBColor[
              0.44115226311345346`, 0.5510804192644326, 0.9504313626135641], 
             UndirectedEdge[5, 202] -> 
             RGBColor[
              0.27931549559896207`, 0.410908673872755, 0.9392179763128905], 
             UndirectedEdge[220, 359] -> 
             RGBColor[
              0.30104851128528043`, 0.4275596115263786, 0.9406823529911341], 
             UndirectedEdge[175, 337] -> 
             RGBColor[
              0.25935756388011755`, 0.389931622230292, 0.9380814016266164], 
             UndirectedEdge[263, 447] -> 
             RGBColor[
              0.6708888743648083, 0.6456551836598937, 0.6050024561406462], 
             UndirectedEdge[344, 387] -> 
             RGBColor[
              0.2657089848875702, 0.3944679797592421, 0.9385214391555547], 
             UndirectedEdge[82, 470] -> 
             RGBColor[
              0.33520888894329015`, 0.4647628243392063, 0.9425801918832526], 
             UndirectedEdge[273, 446] -> 
             RGBColor[
              0.5197045826867778, 0.6209586185065946, 0.9553321949711683], 
             UndirectedEdge[68, 306] -> 
             RGBColor[
              0.20271872726201295`, 0.33040061383500985`, 0.9348559036708652],
              UndirectedEdge[21, 33] -> 
             RGBColor[
              0.3010625668005851, 0.43256593617291467`, 0.940500388283143], 
             UndirectedEdge[77, 479] -> 
             RGBColor[
              0.2736697344981096, 0.40470601635370973`, 0.9389062935020192], 
             UndirectedEdge[253, 311] -> 
             RGBColor[
              0.2943915089823741, 0.42675451981317825`, 0.9400765329721127], 
             UndirectedEdge[308, 386] -> 
             RGBColor[
              0.337209324970382, 0.4631973367463982, 0.9428284198653771], 
             UndirectedEdge[151, 280] -> 
             RGBColor[
              0.36360848331118134`, 0.4893611255755571, 0.9443897889235994], 
             UndirectedEdge[305, 416] -> 
             RGBColor[
              0.23311831341429884`, 0.36235250632614835`, 0.9365871151300804],
              UndirectedEdge[38, 189] -> 
             RGBColor[
              0.2963832457941988, 0.4256867830081446, 0.9403057056665185], 
             UndirectedEdge[277, 291] -> 
             RGBColor[
              0.31354440155050856`, 0.44373185384859004`, 0.9412827295308237],
              UndirectedEdge[27, 40] -> 
             RGBColor[
              0.3665455645136251, 0.48701470199969454`, 0.9448763357772745], 
             UndirectedEdge[88, 167] -> 
             RGBColor[
              0.5922470145919307, 0.6798518327265133, 0.9610430009424258], 
             UndirectedEdge[89, 296] -> 
             RGBColor[
              0.3065670557715655, 0.43840608701288064`, 0.9408118622019359], 
             UndirectedEdge[169, 340] -> 
             RGBColor[
              0.3237421275861684, 0.4548129538954495, 0.9418501967906705], 
             UndirectedEdge[169, 363] -> 
             RGBColor[
              0.29639310822933107`, 0.42885832753045205`, 0.9401905210881261],
              UndirectedEdge[43, 378] -> 
             RGBColor[
              0.25283917405769907`, 0.383080381237145, 0.9377101889693232], 
             UndirectedEdge[350, 482] -> 
             RGBColor[
              0.3314542678836259, 0.4601281024626543, 0.9423915766255901], 
             UndirectedEdge[199, 429] -> 
             RGBColor[
              0.313594495380501, 0.4437752426063404, 0.9412859214653746], 
             UndirectedEdge[135, 216] -> 
             RGBColor[
              0.39116095008933266`, 0.5132256874715458, 0.9461454077430134], 
             UndirectedEdge[153, 351] -> 
             RGBColor[
              0.44042208057876364`, 0.55541993001951, 0.9494150500876111], 
             UndirectedEdge[207, 218] -> 
             RGBColor[
              0.30929828732157805`, 0.4365527998928104, 0.9411403700172327], 
             UndirectedEdge[218, 389] -> 
             RGBColor[
              0.3476268662880079, 0.469751088543139, 0.9435826331763421], 
             UndirectedEdge[421, 477] -> 
             RGBColor[
              0.29367489183371065`, 0.42062697001732086`, 0.9402325035902421],
              UndirectedEdge[171, 391] -> 
             RGBColor[
              0.2819150849753827, 0.4136410071308593, 0.9393660190821298], 
             UndirectedEdge[25, 246] -> 
             RGBColor[
              0.30597613581494587`, 0.43695287412601824`, 0.9408086781207955],
              UndirectedEdge[130, 254] -> 
             RGBColor[
              0.29626746415445354`, 0.4287262676414614, 0.9401833658439356], 
             UndirectedEdge[65, 434] -> 
             RGBColor[
              0.5254823198709788, 0.6146405905879208, 0.9587967327007443], 
             UndirectedEdge[174, 430] -> 
             RGBColor[
              0.34760797929969633`, 0.4748306626467687, 0.9433948426416437], 
             UndirectedEdge[213, 454] -> 
             RGBColor[
              0.4320309689558699, 0.5462422742682508, 0.9494080307390969], 
             UndirectedEdge[52, 495] -> 
             RGBColor[
              0.4138693342696695, 0.5269097129100396, 0.9484675323126454], 
             UndirectedEdge[26, 224] -> 
             RGBColor[
              0.6857883634014559, 0.7526270616702886, 0.9707793030322531], 
             UndirectedEdge[8, 31] -> 
             RGBColor[
              0.30362067814478433`, 0.42896145079288417`, 0.9408764946471762],
              UndirectedEdge[29, 321] -> 
             RGBColor[
              0.3189065709983838, 0.44848771281564814`, 0.9416203226932527], 
             UndirectedEdge[319, 377] -> 
             RGBColor[
              0.3269697234553643, 0.45265119379477414`, 0.9422373688988873], 
             UndirectedEdge[323, 447] -> 
             RGBColor[
              0.6699287042510715, 0.644823532566928, 0.6049412749500439], 
             UndirectedEdge[13, 340] -> 
             RGBColor[
              0.4335674591313914, 0.5479227804495039, 0.9494093181194534], 
             UndirectedEdge[176, 237] -> 
             RGBColor[
              0.5359360856480928, 0.624754443427604, 0.9595303815462835], 
             UndirectedEdge[22, 268] -> 
             RGBColor[
              0.37776179096726337`, 0.5016200093013287, 0.9452916251721664], 
             UndirectedEdge[461, 493] -> 
             RGBColor[
              0.3289501227291953, 0.45308659205867646`, 0.9424104224787264], 
             UndirectedEdge[401, 450] -> 
             RGBColor[
              0.261117822469488, 0.3917817656145611, 0.9381816457492118], 
             UndirectedEdge[100, 200] -> 
             RGBColor[
              0.3692518005955957, 0.49424908336594287`, 0.9447493761107726], 
             UndirectedEdge[197, 375] -> 
             RGBColor[
              0.3911889563822097, 0.5064347458328288, 0.946869747275759], 
             UndirectedEdge[94, 401] -> 
             RGBColor[
              0.62239466570379, 0.6857723960678298, 0.8151556244978186], 
             UndirectedEdge[118, 327] -> 
             RGBColor[
              0.6281973295866186, 0.7084095075041583, 0.9643027891052125], 
             UndirectedEdge[44, 255] -> 
             RGBColor[
              0.36937154351278584`, 0.4943527986623589, 0.9447570060235715], 
             UndirectedEdge[148, 356] -> 
             RGBColor[
              0.3226271349318635, 0.4521796970702844, 0.9418402060162183], 
             UndirectedEdge[26, 34] -> 
             RGBColor[
              0.45271086433835783`, 0.5655380226630424, 0.9503433700775266], 
             UndirectedEdge[244, 313] -> 
             RGBColor[
              0.5869282178765687, 0.6755337939439208, 0.9606242857815981], 
             UndirectedEdge[331, 488] -> 
             RGBColor[
              0.28949992128048707`, 0.4204906677894813, 0.9398390638976801], 
             UndirectedEdge[382, 429] -> 
             RGBColor[
              0.3111224684397589, 0.4416340971179562, 0.9411284060946381], 
             UndirectedEdge[409, 496] -> 
             RGBColor[
              0.24301545874772648`, 0.3727550335868385, 0.9371507429153048], 
             UndirectedEdge[14, 324] -> 
             RGBColor[
              0.3595385646386442, 0.48583596658146566`, 0.944130457304673], 
             UndirectedEdge[259, 471] -> 
             RGBColor[
              0.30807110722800224`, 0.4383417178989385, 0.9409577553644699], 
             UndirectedEdge[178, 439] -> 
             RGBColor[
              0.3999356131951194, 0.5208258596263872, 0.9467045215169843], 
             UndirectedEdge[127, 454] -> 
             RGBColor[
              0.6914610503626909, 0.7575191074565635, 0.9708958878815522], 
             UndirectedEdge[190, 452] -> 
             RGBColor[
              0.6181218354009574, 0.6636298468858447, 0.6543899273197225], 
             UndirectedEdge[218, 295] -> 
             RGBColor[
              0.24593395186322134`, 0.37582255489437466`, 0.9373169467807085],
              UndirectedEdge[35, 67] -> 
             RGBColor[
              0.5247056392963427, 0.6235555898444061, 0.9561605597618217], 
             UndirectedEdge[192, 249] -> 
             RGBColor[
              0.28984538570236706`, 0.4219762560050268, 0.9398176379767029], 
             UndirectedEdge[186, 202] -> 
             RGBColor[
              0.6256901261285276, 0.6908035613432937, 0.8691865061056626], 
             UndirectedEdge[243, 469] -> 
             RGBColor[
              0.3311506268521201, 0.456681567875556, 0.9424887937349842], 
             UndirectedEdge[48, 183] -> 
             RGBColor[
              0.31086872679060046`, 0.44300647537394755`, 0.941053941251594], 
             UndirectedEdge[255, 390] -> 
             RGBColor[
              0.533709195768682, 0.6286829753926305, 0.9578647702138061], 
             UndirectedEdge[202, 497] -> 
             RGBColor[
              0.22912594108308554`, 0.35815626987501725`, 0.9363597554320034],
              UndirectedEdge[84, 365] -> 
             RGBColor[
              0.3176012909907563, 0.44119852033129825`, 0.9417626488188149], 
             UndirectedEdge[239, 262] -> 
             RGBColor[
              0.5504639377961893, 0.640590425644781, 0.9600347853097351], 
             UndirectedEdge[299, 456] -> 
             RGBColor[
              0.34216910141691437`, 0.4707914105534089, 0.9430236904673976], 
             UndirectedEdge[136, 253] -> 
             RGBColor[
              0.31829899762109515`, 0.4479749545286417, 0.9415811146747106], 
             UndirectedEdge[338, 478] -> 
             RGBColor[
              0.3232381328412462, 0.4524741651043927, 0.941887733523956], 
             UndirectedEdge[284, 444] -> 
             RGBColor[
              0.2690908095868497, 0.4001618805914887, 0.9386356955705681], 
             UndirectedEdge[135, 147] -> 
             RGBColor[
              0.34724449570088645`, 0.4699966099757658, 0.9435371526232691], 
             UndirectedEdge[72, 73] -> 
             RGBColor[
              0.27241873231020286`, 0.4002549960363254, 0.9389498801420488], 
             UndirectedEdge[8, 291] -> 
             RGBColor[
              0.25084041787369815`, 0.38097956175929837`, 0.9375963627615391],
              UndirectedEdge[141, 240] -> 
             RGBColor[
              0.597398358538158, 0.31775047938747947`, 0.5547457621175159], 
             UndirectedEdge[9, 466] -> 
             RGBColor[
              0.30944708475070337`, 0.4408774394875476, 0.9409962239769217], 
             UndirectedEdge[78, 346] -> 
             RGBColor[
              0.37663819934672765`, 0.4870138290309683, 0.9464167819228801], 
             UndirectedEdge[255, 425] -> 
             RGBColor[
              0.337602960612635, 0.46683644888965203`, 0.9427327400130288], 
             UndirectedEdge[297, 349] -> 
             RGBColor[
              0.36059637302815317`, 0.48543624848969724`, 0.9442460428765338],
              UndirectedEdge[248, 478] -> 
             RGBColor[
              0.28165702130215503`, 0.40876978048206536`, 0.9395197507355468],
              UndirectedEdge[113, 130] -> 
             RGBColor[
              0.3058405935919328, 0.4382925197605118, 0.9407466919170957], 
             UndirectedEdge[51, 179] -> 
             RGBColor[
              0.3415955415348642, 0.4599959184214032, 0.94352780991942], 
             UndirectedEdge[440, 470] -> 
             RGBColor[
              0.3154953360729083, 0.44499284745550627`, 0.9414227421082886], 
             UndirectedEdge[5, 414] -> 
             RGBColor[
              0.42607137907778203`, 0.539751978767008, 0.949160860240723], 
             UndirectedEdge[148, 463] -> 
             RGBColor[
              0.6401941254613344, 0.7063806727330647, 0.8786851185716682], 
             UndirectedEdge[63, 441] -> 
             RGBColor[
              0.5904615797902606, 0.6692387078703843, 0.9646062340697246], 
             UndirectedEdge[163, 187] -> 
             RGBColor[
              0.3267392292423903, 0.4508780586200475, 0.9422802952861364], 
             UndirectedEdge[120, 177] -> 
             RGBColor[
              0.30500497164595075`, 0.434468450570089, 0.9408069638295868], 
             UndirectedEdge[450, 454] -> 
             RGBColor[
              0.4067434717744418, 0.5209796349948288, 0.9479197554525065], 
             UndirectedEdge[15, 190] -> 
             RGBColor[
              0.9670468570694324, 0.9527059687645865, 0.6653787470822691], 
             UndirectedEdge[191, 287] -> 
             RGBColor[
              0.253026713832782, 0.38327749743146566`, 0.937720869082074], 
             UndirectedEdge[179, 292] -> 
             RGBColor[
              0.27200391906775356`, 0.4004016239660762, 0.9389049244613683], 
             UndirectedEdge[291, 297] -> 
             RGBColor[
              0.2893736137074001, 0.42148039372624446`, 0.9397907712595137], 
             UndirectedEdge[289, 397] -> 
             RGBColor[
              0.410992824961655, 0.5304030607069377, 0.9474090772732394], 
             UndirectedEdge[175, 370] -> 
             RGBColor[
              0.298908798745927, 0.42702883787825635`, 0.9404975878124233], 
             UndirectedEdge[23, 186] -> 
             RGBColor[
              0.640051440363989, 0.7058982131646776, 0.8700043617057116], 
             UndirectedEdge[241, 461] -> 
             RGBColor[
              0.6180251514702465, 0.6811797595651721, 0.8149067871263354], 
             UndirectedEdge[157, 216] -> 
             RGBColor[
              0.34169507370620533`, 0.4703808315757182, 0.9429934858408375], 
             UndirectedEdge[51, 302] -> 
             RGBColor[
              0.397761215251045, 0.5182600342666117, 0.9467545396146353], 
             UndirectedEdge[174, 390] -> 
             RGBColor[
              0.551927690505199, 0.6444629198452312, 0.9590256365884346], 
             UndirectedEdge[79, 406] -> 
             RGBColor[
              0.31066449890845993`, 0.44250101482797904`, 0.9410529585382197],
              UndirectedEdge[181, 235] -> 
             RGBColor[
              0.29232264997364404`, 0.4214919465277087, 0.9400717839295347], 
             UndirectedEdge[78, 404] -> 
             RGBColor[
              0.3998944908045995, 0.5058943341204596, 0.9482476023770464], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.31364109096694537`, 0.44453326074777155`, 0.9412626134692619],
              UndirectedEdge[43, 384] -> 
             RGBColor[
              0.3550278533481285, 0.4785970661866641, 0.9439650377443825], 
             UndirectedEdge[101, 363] -> 
             RGBColor[
              0.28206980135397597`, 0.41380362385434577`, 0.9393748299510083],
              UndirectedEdge[120, 455] -> 
             RGBColor[
              0.31497028938814114`, 0.4449426313547692, 0.9413744739326382], 
             UndirectedEdge[295, 456] -> 
             RGBColor[
              0.2942289065456659, 0.42342078089167934`, 0.940183079830052], 
             UndirectedEdge[58, 240] -> 
             RGBColor[
              0.578125635518976, 0.3010574153834884, 0.5535177212489335], 
             UndirectedEdge[39, 471] -> 
             RGBColor[
              0.3066300526338635, 0.4370935488390054, 0.940865932640006], 
             UndirectedEdge[54, 365] -> 
             RGBColor[
              0.22016341450609503`, 0.34873608618559426`, 0.9358493528023137],
              UndirectedEdge[169, 334] -> 
             RGBColor[
              0.27109908904060476`, 0.4022727096296569, 0.9387500641144763], 
             UndirectedEdge[18, 65] -> 
             RGBColor[
              0.34602367385307303`, 0.4703246395283116, 0.9434086350402384], 
             UndirectedEdge[384, 435] -> 
             RGBColor[
              0.3659302949647987, 0.49005622358050793`, 0.9445859156657348], 
             UndirectedEdge[9, 360] -> 
             RGBColor[
              0.2558989750896009, 0.3862964261242643, 0.9378844401115201], 
             UndirectedEdge[135, 171] -> 
             RGBColor[
              0.36042843600409985`, 0.4838537671445382, 0.9442879585196453], 
             UndirectedEdge[149, 187] -> 
             RGBColor[
              0.3408127151559792, 0.4656701846257738, 0.9430817594890587], 
             UndirectedEdge[271, 464] -> 
             RGBColor[
              0.5310343439458123, 0.6255591888423668, 0.9580358765769861], 
             UndirectedEdge[21, 348] -> 
             RGBColor[
              0.3824507183693485, 0.505681322544671, 0.9455903994799715], 
             UndirectedEdge[1, 70] -> 
             RGBColor[
              0.2818632580853818, 0.4135865337834537, 0.9393630676174152], 
             UndirectedEdge[52, 276] -> 
             RGBColor[
              0.5162084687714787, 0.6181203157320179, 0.9550569680770686], 
             UndirectedEdge[58, 429] -> 
             RGBColor[
              0.31158325168111456`, 0.44203320440197946`, 0.9411577667953226],
              UndirectedEdge[243, 495] -> 
             RGBColor[
              0.26648841766495435`, 0.3974266016803988, 0.9384874932005101], 
             UndirectedEdge[131, 135] -> 
             RGBColor[
              0.44298124013288553`, 0.5581098181437627, 0.9494473508017054], 
             UndirectedEdge[145, 430] -> 
             RGBColor[
              0.350771663985103, 0.4775708873098522, 0.9435964298322613], 
             UndirectedEdge[291, 419] -> 
             RGBColor[
              0.24921650804664236`, 0.37927272956923297`, 0.9375038834992476],
              UndirectedEdge[151, 260] -> 
             RGBColor[
              0.3673928450108765, 0.4926389494722835, 0.9446309251047242], 
             UndirectedEdge[189, 437] -> 
             RGBColor[
              0.25875798812420103`, 0.3893014300955252, 0.9380472566743098], 
             UndirectedEdge[196, 354] -> 
             RGBColor[
              0.452372592820114, 0.556632706600041, 0.9516513731907817], 
             UndirectedEdge[340, 355] -> 
             RGBColor[
              0.349023564109878, 0.4767284016227419, 0.94346045076903], 
             UndirectedEdge[58, 310] -> 
             RGBColor[
              0.3215642329345495, 0.4525238485301015, 0.9417261689121672], 
             UndirectedEdge[261, 500] -> 
             RGBColor[
              0.5672092311416879, 0.6546282354402944, 0.9612990653716444], 
             UndirectedEdge[237, 270] -> 
             RGBColor[
              0.33692224970456935`, 0.4637757886708876, 0.9427798434240822], 
             UndirectedEdge[23, 497] -> 
             RGBColor[
              0.24348725531854698`, 0.37325092169640106`, 0.9371776110320524],
              UndirectedEdge[431, 462] -> 
             RGBColor[
              0.42514521932552046`, 0.5426611533848946, 0.948310855327634], 
             UndirectedEdge[108, 129] -> 
             RGBColor[
              0.4972652073320985, 0.5978948704920503, 0.9551456105486111], 
             UndirectedEdge[376, 485] -> 
             RGBColor[
              0.35544406144865526`, 0.4759445406278544, 0.9441896676931467], 
             UndirectedEdge[124, 261] -> 
             RGBColor[
              0.591426634675926, 0.6756041331795579, 0.9628421769102369], 
             UndirectedEdge[63, 158] -> 
             RGBColor[
              0.3186519132267702, 0.448862536764246, 0.9415822957716364], 
             UndirectedEdge[66, 427] -> 
             RGBColor[
              0.7347939368756264, 0.7919981082007538, 0.9745142882045359], 
             UndirectedEdge[66, 208] -> 
             RGBColor[
              0.9291557773080821, 0.946330882048684, 0.9925248693322104], 
             UndirectedEdge[54, 230] -> 
             RGBColor[
              0.242769796479283, 0.37249682696681696`, 0.9371367528125416], 
             UndirectedEdge[186, 295] -> 
             RGBColor[
              0.6182089359857136, 0.6829403561683447, 0.8687604633944583], 
             UndirectedEdge[245, 394] -> 
             RGBColor[
              0.32485295739266246`, 0.4536781864424829, 0.9419977561185942], 
             UndirectedEdge[49, 459] -> 
             RGBColor[
              0.6249058717409084, 0.6884404345537158, 0.8181588936971622], 
             UndirectedEdge[55, 365] -> 
             RGBColor[
              0.27012695663544656`, 0.4000786380421535, 0.9387376262136001], 
             UndirectedEdge[197, 448] -> 
             RGBColor[
              0.39367944964046186`, 0.5084566404553206, 0.947065808028026], 
             UndirectedEdge[185, 321] -> 
             RGBColor[
              0.30550345637532805`, 0.43687860858928573`, 0.9407662880813804],
              UndirectedEdge[242, 339] -> 
             RGBColor[
              0.2801555830106085, 0.41130467001282967`, 0.9392836491008374], 
             UndirectedEdge[186, 191] -> 
             RGBColor[
              0.6306399828564273, 0.6960061746033593, 0.8694683931236598], 
             UndirectedEdge[218, 456] -> 
             RGBColor[
              0.29465980375428025`, 0.42387368117839397`, 0.9402076187886272],
              UndirectedEdge[63, 182] -> 
             RGBColor[
              0.3519536844558152, 0.477706857207155, 0.9437042551867512], 
             UndirectedEdge[133, 181] -> 
             RGBColor[
              0.32328201348635954`, 0.4540322005165932, 0.9418348738813098], 
             UndirectedEdge[11, 186] -> 
             RGBColor[
              0.6164356802257485, 0.6810765519337125, 0.8686594791022251], 
             UndirectedEdge[105, 148] -> 
             RGBColor[
              0.3304184872676279, 0.4589281748587687, 0.9423366640974309], 
             UndirectedEdge[235, 393] -> 
             RGBColor[
              0.2396127369823878, 0.36917855726644677`, 0.9369569629446444], 
             UndirectedEdge[110, 290] -> 
             RGBColor[
              0.3778250871122646, 0.49615651542005734`, 0.9457657039343039], 
             UndirectedEdge[225, 296] -> 
             RGBColor[
              0.4039327011105678, 0.5233807866244162, 0.9472098605769603], 
             UndirectedEdge[38, 93] -> 
             RGBColor[
              0.3739602763853964, 0.498327328440194, 0.9450493960245572], 
             UndirectedEdge[80, 486] -> 
             RGBColor[
              0.42893421146214905`, 0.5409701159782344, 0.9494869114500135], 
             UndirectedEdge[471, 500] -> 
             RGBColor[
              0.31460210895279395`, 0.4439985433352619, 0.9413739050192356], 
             UndirectedEdge[200, 213] -> 
             RGBColor[
              0.3436441156540162, 0.4720689937492153, 0.9431176770702818], 
             UndirectedEdge[191, 295] -> 
             RGBColor[
              0.2579341015253208, 0.38843547304267456`, 0.9380003375513346], 
             UndirectedEdge[295, 300] -> 
             RGBColor[
              0.23940165119627274`, 0.36895669272162795`, 0.9369449419213987],
              UndirectedEdge[191, 451] -> 
             RGBColor[
              0.3177707337120979, 0.4461101987747899, 0.9415989786548193], 
             UndirectedEdge[137, 145] -> 
             RGBColor[
              0.3913434027920641, 0.5133837188323123, 0.9461570334678948], 
             UndirectedEdge[332, 344] -> 
             RGBColor[
              0.42035536639171034`, 0.5370052672458699, 0.9484220819029325], 
             UndirectedEdge[76, 392] -> 
             RGBColor[
              0.2981302709474612, 0.43035901846166735`, 0.9403013562662594], 
             UndirectedEdge[157, 465] -> 
             RGBColor[
              0.35947465813381674`, 0.4857806139790185, 0.9441263852386957], 
             UndirectedEdge[204, 337] -> 
             RGBColor[
              0.24974125693082783`, 0.37982427391751283`, 0.9375337671719056],
              UndirectedEdge[112, 395] -> 
             RGBColor[
              0.26564449175369753`, 0.39653958203967454`, 0.9384394328683404],
              UndirectedEdge[51, 107] -> 
             RGBColor[
              0.3960066496902922, 0.5167403177649168, 0.9466427402486055], 
             UndirectedEdge[5, 41] -> 
             RGBColor[
              0.2813209844676747, 0.41301656982911034`, 0.9393321859371088], 
             UndirectedEdge[88, 210] -> 
             RGBColor[
              0.413955876696398, 0.5270178175969552, 0.9484709003033828], 
             UndirectedEdge[248, 411] -> 
             RGBColor[
              0.25538853775186104`, 0.3857599241187032, 0.9378553714602602], 
             UndirectedEdge[101, 128] -> 
             RGBColor[
              0.29190665897794255`, 0.42414278490993074`, 0.9399350244403664],
              UndirectedEdge[298, 418] -> 
             RGBColor[
              0.5424438455517504, 0.6259215235123304, 0.960788140792975], 
             UndirectedEdge[1, 391] -> 
             RGBColor[
              0.2861006017784636, 0.41804025066799, 0.9396043780721479], 
             UndirectedEdge[116, 327] -> 
             RGBColor[
              0.4754758457881816, 0.5830050047652398, 0.9524158651154171], 
             UndirectedEdge[79, 81] -> 
             RGBColor[
              0.2800251437031319, 0.4116545590245261, 0.9392583897225926], 
             UndirectedEdge[254, 368] -> 
             RGBColor[
              0.2918000598317529, 0.42403074244850925`, 0.9399289537766902], 
             UndirectedEdge[4, 318] -> 
             RGBColor[
              0.5887883613230269, 0.6668876742201824, 0.9646006874818847], 
             UndirectedEdge[352, 412] -> 
             RGBColor[
              0.47158577433811405`, 0.5807769128018796, 0.9518526507102099], 
             UndirectedEdge[239, 424] -> 
             RGBColor[
              0.3021040928514639, 0.4329440521778316, 0.940585939664349], 
             UndirectedEdge[58, 188] -> 
             RGBColor[
              0.30148676531190327`, 0.431421157073729, 0.940582786833009], 
             UndirectedEdge[407, 408] -> 
             RGBColor[
              0.23838117307547213`, 0.3678841055146167, 0.9368868272020812], 
             UndirectedEdge[255, 466] -> 
             RGBColor[
              0.34222290927494, 0.4708380162155691, 0.9430271190565307], 
             UndirectedEdge[197, 489] -> 
             RGBColor[
              0.2377048714234121, 0.3671732695983002, 0.9368483128234949], 
             UndirectedEdge[50, 363] -> 
             RGBColor[
              0.2861304183092521, 0.41807158973232594`, 0.9396060760794669], 
             UndirectedEdge[57, 175] -> 
             RGBColor[
              0.2756627903493139, 0.4068943137834642, 0.9390163727130293], 
             UndirectedEdge[278, 486] -> 
             RGBColor[
              0.4370226250325123, 0.5494715514757265, 0.9499475346371101], 
             UndirectedEdge[82, 263] -> 
             RGBColor[
              0.3653929825452315, 0.4909067691205519, 0.9445034956368223], 
             UndirectedEdge[41, 186] -> 
             RGBColor[
              0.6276956149972401, 0.6929114572996491, 0.8693007157298809], 
             UndirectedEdge[390, 425] -> 
             RGBColor[
              0.5140149262571918, 0.611624789004545, 0.9566098687754927], 
             UndirectedEdge[218, 458] -> 
             RGBColor[
              0.25830008656140413`, 0.38882014652038976`, 0.9380211798577132],
              UndirectedEdge[230, 374] -> 
             RGBColor[
              0.45019031439810053`, 0.5552512379620819, 0.9514311218908778], 
             UndirectedEdge[104, 408] -> 
             RGBColor[
              0.3025633655268073, 0.4316451831883788, 0.9406773274361497], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.30569467230967756`, 0.43731873754793793`, 0.9407684211336786],
              UndirectedEdge[143, 421] -> 
             RGBColor[
              0.30476377319650144`, 0.43023160171038743`, 0.9409390773051663],
              UndirectedEdge[185, 482] -> 
             RGBColor[
              0.3096794877685558, 0.44126788235925113`, 0.94100410689134], 
             UndirectedEdge[256, 333] -> 
             RGBColor[
              0.5575776226506255, 0.6433484966318868, 0.9614196547755054], 
             UndirectedEdge[351, 463] -> 
             RGBColor[
              0.7303100248487446, 0.7856467070016357, 0.8844962782910257], 
             UndirectedEdge[42, 411] -> 
             RGBColor[
              0.29709507707423144`, 0.4295961412938377, 0.9402304971753734], 
             UndirectedEdge[52, 243] -> 
             RGBColor[
              0.40673961132996245`, 0.519415922049864, 0.9480615051387089], 
             UndirectedEdge[385, 391] -> 
             RGBColor[
              0.2822037141411573, 0.4139443746842344, 0.939382456086132], 
             UndirectedEdge[366, 435] -> 
             RGBColor[
              0.4464252698818928, 0.5558393044186494, 0.9508029606035121], 
             UndirectedEdge[114, 419] -> 
             RGBColor[
              0.22375476978428283`, 0.35251082828804586`, 0.9360538751724725],
              UndirectedEdge[67, 391] -> 
             RGBColor[
              0.3435203987380079, 0.46975339482639433`, 0.9431906558011964], 
             UndirectedEdge[310, 327] -> 
             RGBColor[
              0.43860473907432573`, 0.5506484447507203, 0.9500818732437456], 
             UndirectedEdge[309, 348] -> 
             RGBColor[
              0.34923946197641575`, 0.4719744747371215, 0.943655119122816], 
             UndirectedEdge[28, 194] -> 
             RGBColor[
              0.5533009052402318, 0.6431364193834057, 0.9601779889896214], 
             UndirectedEdge[92, 337] -> 
             RGBColor[
              0.3532839895039417, 0.4775786440538078, 0.943835904833852], 
             UndirectedEdge[205, 432] -> 
             RGBColor[
              0.2730062886244281, 0.40388585237107605`, 0.9388730090262889], 
             UndirectedEdge[314, 398] -> 
             RGBColor[
              0.2266690776689228, 0.35557395065259456`, 0.9362198406951706], 
             UndirectedEdge[235, 453] -> 
             RGBColor[
              0.35991293537024016`, 0.47938336172277696`, 0.9445586970782156],
              UndirectedEdge[92, 334] -> 
             RGBColor[
              0.33109219377661514`, 0.4542536597032717, 0.9425721148970005], 
             UndirectedEdge[35, 54] -> 
             RGBColor[
              0.43436431181746316`, 0.5372398297645861, 0.950699449572737], 
             UndirectedEdge[191, 456] -> 
             RGBColor[
              0.3066599534163797, 0.4364865993266939, 0.9408910095592533], 
             UndirectedEdge[78, 137] -> 
             RGBColor[
              0.2876984789004807, 0.4128890824740201, 0.9399454779414855], 
             UndirectedEdge[57, 169] -> 
             RGBColor[
              0.30959611123712766`, 0.4425603855333653, 0.9409488251377407], 
             UndirectedEdge[343, 392] -> 
             RGBColor[
              0.36028925760485436`, 0.4841980085027917, 0.9442620719310348], 
             UndirectedEdge[24, 197] -> 
             RGBColor[
              0.28790215944673525`, 0.41894638337546414`, 0.9397431283491231],
              UndirectedEdge[450, 471] -> 
             RGBColor[
              0.2748079776245437, 0.406170986688495, 0.9389612798325226], 
             UndirectedEdge[150, 267] -> 
             RGBColor[
              0.28315153659406656`, 0.41449905515355884`, 0.9394526001524819],
              UndirectedEdge[40, 371] -> 
             RGBColor[
              0.5173034667923286, 0.6190092844544425, 0.9551431703323799], 
             UndirectedEdge[217, 362] -> 
             RGBColor[
              0.2755929363376306, 0.4040719268989873, 0.9391130477377494], 
             UndirectedEdge[229, 478] -> 
             RGBColor[
              0.3078682418379389, 0.4363194351525423, 0.9410124409690339], 
             UndirectedEdge[100, 168] -> 
             RGBColor[
              0.3080353498661728, 0.4350437271894693, 0.9410750985240417], 
             UndirectedEdge[221, 297] -> 
             RGBColor[
              0.6233094085650865, 0.6373523920655397, 0.6102024377498741], 
             UndirectedEdge[50, 338] -> 
             RGBColor[
              0.28800204003410385`, 0.4200387828328165, 0.9397126621678809], 
             UndirectedEdge[5, 186] -> 
             RGBColor[
              0.6445401867872546, 0.7106161702584908, 0.8702599891740114], 
             UndirectedEdge[147, 391] -> 
             RGBColor[
              0.2687311446721693, 0.3997838499620869, 0.9386152131857536], 
             UndirectedEdge[24, 426] -> 
             RGBColor[
              0.3608954742733297, 0.48701125350676905`, 0.944216918386727], 
             UndirectedEdge[100, 127] -> 
             RGBColor[
              0.6080187725422915, 0.687628569697974, 0.964920598190099], 
             UndirectedEdge[418, 432] -> 
             RGBColor[
              0.5728181823328258, 0.657455432368807, 0.9625322470548158], 
             UndirectedEdge[200, 259] -> 
             RGBColor[
              0.3516197480760467, 0.47897708568623687`, 0.9436258773156389], 
             UndirectedEdge[17, 293] -> 
             RGBColor[
              0.29381970299129867`, 0.4228195443842826, 0.940166042479847], 
             UndirectedEdge[269, 468] -> 
             RGBColor[
              0.5838895247465075, 0.6646574450603435, 0.9638795341323788], 
             UndirectedEdge[154, 390] -> 
             RGBColor[
              0.8432333509905447, 0.8776752194552123, 0.9483334540552624], 
             UndirectedEdge[162, 439] -> 
             RGBColor[
              0.33612145497785006`, 0.4655532431714396, 0.9426383397840242], 
             UndirectedEdge[103, 304] -> 
             RGBColor[
              0.37341541610331475`, 0.49785539784932886`, 0.9450146780091839],
              UndirectedEdge[3, 480] -> 
             RGBColor[
              0.2828536240833065, 0.4136453184859975, 0.9394554289194039], 
             UndirectedEdge[358, 404] -> 
             RGBColor[
              0.4602870424941751, 0.5689259396048092, 0.9517031549933148], 
             UndirectedEdge[3, 439] -> 
             RGBColor[
              0.34025358555994645`, 0.46913228699472964`, 0.9429016354908158],
              UndirectedEdge[336, 458] -> 
             RGBColor[
              0.2541467216262284, 0.38445469663497345`, 0.9377846518690077], 
             UndirectedEdge[212, 287] -> 
             RGBColor[
              0.279921699515574, 0.41012115421893885`, 0.9393046631845363], 
             UndirectedEdge[190, 195] -> 
             RGBColor[
              0.785119649096622, 0.8092261790431632, 0.6658972275653303], 
             UndirectedEdge[253, 377] -> 
             RGBColor[
              0.34229529523648583`, 0.4687593414341064, 0.9431101375396704], 
             UndirectedEdge[192, 327] -> 
             RGBColor[
              0.4355596490969853, 0.5474478621146798, 0.949908459874343], 
             UndirectedEdge[151, 483] -> 
             RGBColor[
              0.33017092605142423`, 0.45666992305715426`, 0.9423957242237568],
              UndirectedEdge[38, 163] -> 
             RGBColor[
              0.2904261332460571, 0.41942548001729707`, 0.9399664569196602], 
             UndirectedEdge[88, 227] -> 
             RGBColor[
              0.41435908674475597`, 0.5274416169227731, 0.9484938625191409], 
             UndirectedEdge[281, 343] -> 
             RGBColor[
              0.36487207778639486`, 0.48901484308117266`, 0.9445230567606986],
              UndirectedEdge[76, 157] -> 
             RGBColor[
              0.32760891462893016`, 0.45818010857392344`, 0.942095928240335], 
             UndirectedEdge[364, 437] -> 
             RGBColor[
              0.5922630601721746, 0.667606432485182, 0.965242951889024], 
             UndirectedEdge[229, 244] -> 
             RGBColor[
              0.40519380133402766`, 0.5179072726780429, 0.9479629058623781], 
             UndirectedEdge[154, 425] -> 
             RGBColor[
              0.6471271158344978, 0.7158286929522338, 0.933201423854485], 
             UndirectedEdge[128, 355] -> 
             RGBColor[
              0.33151140237700716`, 0.4611129363133294, 0.9423609695558437], 
             UndirectedEdge[58, 382] -> 
             RGBColor[
              0.33847148779659625`, 0.46758872348295366`, 0.9427880817971823],
              UndirectedEdge[45, 179] -> 
             RGBColor[
              0.2509540948161885, 0.38109904343339024`, 0.937602836495244], 
             UndirectedEdge[181, 296] -> 
             RGBColor[
              0.331641959264135, 0.4616733291302206, 0.9423529102782089], 
             UndirectedEdge[350, 354] -> 
             RGBColor[
              0.5064504685889667, 0.6078902558980848, 0.9549354025782595], 
             UndirectedEdge[318, 335] -> 
             RGBColor[
              0.5677434952510523, 0.6447681856569613, 0.963402213492175], 
             UndirectedEdge[354, 372] -> 
             RGBColor[
              0.5956005815968521, 0.682552583834195, 0.9613219283468313], 
             UndirectedEdge[44, 57] -> 
             RGBColor[
              0.34604304762065846`, 0.4741468280448944, 0.9432705348939041], 
             UndirectedEdge[257, 420] -> 
             RGBColor[
              0.4868432674033458, 0.5910727608261654, 0.9536314906697281], 
             UndirectedEdge[84, 171] -> 
             RGBColor[
              0.3476722235736271, 0.4728049770831416, 0.9434751439434512], 
             UndirectedEdge[376, 497] -> 
             RGBColor[
              0.3322967461695083, 0.4516152446449163, 0.9428714623313836], 
             UndirectedEdge[164, 443] -> 
             RGBColor[
              0.6358898906422468, 0.7082117904169005, 0.9633703549076986], 
             UndirectedEdge[2, 54] -> 
             RGBColor[
              0.21176705369435922`, 0.3399109786124368, 0.935371192475388], 
             UndirectedEdge[165, 324] -> 
             RGBColor[
              0.37670034575962935`, 0.5007006388122635, 0.945223990822135], 
             UndirectedEdge[82, 395] -> 
             RGBColor[
              0.3055214714052455, 0.43750259890547705`, 0.940745159969375], 
             UndirectedEdge[298, 420] -> 
             RGBColor[
              0.29370855530118867`, 0.4235921362105709, 0.9401271469397601], 
             UndirectedEdge[163, 437] -> 
             RGBColor[
              0.25280087557605935`, 0.3830401271046776, 0.9377080079274513], 
             UndirectedEdge[156, 372] -> 
             RGBColor[
              0.46087392538444516`, 0.5710525436597993, 0.9512934162841133], 
             UndirectedEdge[272, 317] -> 
             RGBColor[
              0.2931187501737488, 0.42529367963895226`, 0.9400085581675679], 
             UndirectedEdge[282, 441] -> 
             RGBColor[
              0.631631420346289, 0.7064574218907704, 0.9671724401646122], 
             UndirectedEdge[209, 423] -> 
             RGBColor[
              0.45767446703157283`, 0.5667855212927282, 0.9515028470364686], 
             UndirectedEdge[222, 333] -> 
             RGBColor[
              0.6274246212835168, 0.7051649776259206, 0.9658219662380764], 
             UndirectedEdge[125, 455] -> 
             RGBColor[
              0.2506235022952221, 0.3807515697330781, 0.9375840097402428], 
             UndirectedEdge[343, 433] -> 
             RGBColor[
              0.5593802541099313, 0.6521046696217538, 0.9589982338443714], 
             UndirectedEdge[29, 77] -> 
             RGBColor[
              0.2940310575968042, 0.4223419710319437, 0.9402036990050568], 
             UndirectedEdge[298, 353] -> 
             RGBColor[
              0.3012355426802099, 0.4301116343608934, 0.9406067599196977], 
             UndirectedEdge[65, 337] -> 
             RGBColor[
              0.2728085162100188, 0.4040694259686536, 0.9388474134629035], 
             UndirectedEdge[93, 364] -> 
             RGBColor[
              0.6609117357471124, 0.7308627107047385, 0.9694781856372042], 
             UndirectedEdge[170, 328] -> 
             RGBColor[
              0.2859530812691356, 0.4160058720364491, 0.9396647882998912], 
             UndirectedEdge[13, 244] -> 
             RGBColor[
              0.5406762780627601, 0.6379843855769273, 0.956983163653017], 
             UndirectedEdge[114, 291] -> 
             RGBColor[
              0.25877249406191766`, 0.3893166767557949, 0.9380480827660032], 
             UndirectedEdge[198, 373] -> 
             RGBColor[
              0.2802213358728946, 0.41186076943424865`, 0.9392695625764204], 
             UndirectedEdge[54, 84] -> 
             RGBColor[
              0.3189362098573727, 0.44260160469885673`, 0.9418386704734333], 
             UndirectedEdge[1, 385] -> 
             RGBColor[
              0.2834445067740757, 0.41524852641222837`, 0.9394531173909886], 
             UndirectedEdge[97, 294] -> 
             RGBColor[
              0.4909400813266977, 0.5954604056683142, 0.9536606651854513], 
             UndirectedEdge[83, 489] -> 
             RGBColor[
              0.2601937118426736, 0.3908104667537812, 0.9381290190161138], 
             UndirectedEdge[349, 359] -> 
             RGBColor[
              0.32653035589527857`, 0.44963070457280935`, 0.9423060335969726],
              UndirectedEdge[47, 55] -> 
             RGBColor[
              0.3141379378385081, 0.44633696974394854`, 0.9412439864847024], 
             UndirectedEdge[166, 309] -> 
             RGBColor[
              0.2525676346627368, 0.3827949761164476, 0.9376947252024866], 
             UndirectedEdge[196, 482] -> 
             RGBColor[
              0.2773763921147733, 0.4088705531646106, 0.9391075472381125], 
             UndirectedEdge[114, 311] -> 
             RGBColor[
              0.2682542742034474, 0.39928262886412613`, 0.9385880561180265], 
             UndirectedEdge[101, 169] -> 
             RGBColor[
              0.29422867725902985`, 0.4265833733478158, 0.9400672599463562], 
             UndirectedEdge[160, 353] -> 
             RGBColor[
              0.2914194156004142, 0.4197942624216243, 0.940047746004162], 
             UndirectedEdge[80, 329] -> 
             RGBColor[
              0.32901780712636614`, 0.4575672277262399, 0.9422528237898848], 
             UndirectedEdge[130, 386] -> 
             RGBColor[
              0.28532356677670045`, 0.41722353761427233`, 0.9395601270783178],
              UndirectedEdge[216, 238] -> 
             RGBColor[
              0.26518550496924587`, 0.39312725729726483`, 0.9385205722608705],
              UndirectedEdge[240, 382] -> 
             RGBColor[
              0.5776648522776203, 0.30065830809946525`, 0.5534883605482489], 
             UndirectedEdge[424, 470] -> 
             RGBColor[
              0.3130619114668164, 0.44243516390647236`, 0.9412841621769008], 
             UndirectedEdge[184, 225] -> 
             RGBColor[
              0.3769697484685564, 0.49618671829771716`, 0.9456324104598255], 
             UndirectedEdge[169, 274] -> 
             RGBColor[
              0.28235837149423315`, 0.4141069293681596, 0.9393912635935946], 
             UndirectedEdge[345, 375] -> 
             RGBColor[
              0.4509566697806504, 0.5630442647451228, 0.9505008136853013], 
             UndirectedEdge[326, 434] -> 
             RGBColor[
              0.6485801470930683, 0.7234253855476096, 0.9669547070141209], 
             UndirectedEdge[59, 105] -> 
             RGBColor[
              0.4501903411742621, 0.5622702489915721, 0.9504824491898827], 
             UndirectedEdge[90, 306] -> 
             RGBColor[
              0.22539834709610493`, 0.35423833225159124`, 0.936147474468926], 
             UndirectedEdge[44, 466] -> 
             RGBColor[
              0.35429722266360064`, 0.48129617960019044`, 0.94379648362876], 
             UndirectedEdge[88, 434] -> 
             RGBColor[
              0.6686772973106363, 0.7397411574605313, 0.9685368282975348], 
             UndirectedEdge[174, 356] -> 
             RGBColor[
              0.37423600820907965`, 0.498566153487184, 0.9450669654125421], 
             UndirectedEdge[65, 88] -> 
             RGBColor[
              0.41078222445821744`, 0.5236821078734536, 0.9482901655034162], 
             UndirectedEdge[82, 195] -> 
             RGBColor[
              0.4554057333170928, 0.5651115030761502, 0.9512778687581256], 
             UndirectedEdge[150, 413] -> 
             RGBColor[
              0.27999727817041103`, 0.4111837295587618, 0.9392729698015619], 
             UndirectedEdge[156, 307] -> 
             RGBColor[
              0.2935447565942925, 0.4198007981284748, 0.9402503345808005], 
             UndirectedEdge[245, 460] -> 
             RGBColor[
              0.2949186529541634, 0.4222153345330989, 0.9402930417646566], 
             UndirectedEdge[101, 204] -> 
             RGBColor[
              0.25067904942192637`, 0.38080995328513556`, 0.9375871730669341],
              UndirectedEdge[210, 428] -> 
             RGBColor[
              0.26898790554038776`, 0.4000537219141638, 0.938629835337355], 
             UndirectedEdge[25, 76] -> 
             RGBColor[
              0.2970387445905787, 0.4292117550538156, 0.9402391954550036], 
             UndirectedEdge[130, 421] -> 
             RGBColor[
              0.2590246512959126, 0.3895817099964156, 0.938062442747446], 
             UndirectedEdge[79, 493] -> 
             RGBColor[
              0.3573553304089039, 0.4829422663242376, 0.9440280570343467], 
             UndirectedEdge[194, 490] -> 
             RGBColor[
              0.3295076170788376, 0.4598246692044733, 0.9422169118814865], 
             UndirectedEdge[214, 347] -> 
             RGBColor[
              0.2427021225881194, 0.37242569741643144`, 0.9371328988845544], 
             UndirectedEdge[41, 202] -> 
             RGBColor[
              0.2624709238089477, 0.39320396091391324`, 0.93825870286876], 
             UndirectedEdge[85, 97] -> 
             RGBColor[
              0.45711058853021413`, 0.5659631162461181, 0.9515122520578807], 
             UndirectedEdge[31, 114] -> 
             RGBColor[
              0.31155275433300383`, 0.43729856578938064`, 0.94132821465164], 
             UndirectedEdge[247, 425] -> 
             RGBColor[
              0.30787471525164, 0.44007907108987665`, 0.9408754000582771], 
             UndirectedEdge[35, 281] -> 
             RGBColor[
              0.4701967008495414, 0.5749019425419839, 0.9527400511188446], 
             UndirectedEdge[157, 288] -> 
             RGBColor[
              0.38719543505653287`, 0.5097909576627154, 0.9458927286316907], 
             UndirectedEdge[208, 427] -> 
             RGBColor[
              0.727601952098718, 0.7862801445487022, 0.9744083425223843], 
             UndirectedEdge[154, 313] -> 
             RGBColor[
              0.7985260337101494, 0.8424178351344596, 0.9441042235662285], 
             UndirectedEdge[189, 364] -> 
             RGBColor[
              0.5833347051559148, 0.6582221652726892, 0.9647344952791657], 
             UndirectedEdge[314, 373] -> 
             RGBColor[
              0.25385060410395244`, 0.3841434583441261, 0.9377677884141807], 
             UndirectedEdge[156, 232] -> 
             RGBColor[
              0.3433552466001377, 0.4718187898937266, 0.9430992705896056], 
             UndirectedEdge[321, 383] -> 
             RGBColor[
              0.3026271505183238, 0.43438729702328455`, 0.9405830124155895], 
             UndirectedEdge[15, 323] -> 
             RGBColor[
              0.6827423402713926, 0.7479226318525847, 0.9536528350242099], 
             UndirectedEdge[225, 235] -> 
             RGBColor[
              0.36461339182007685`, 0.48319940402190437`, 0.9449287342282862],
              UndirectedEdge[170, 265] -> 
             RGBColor[
              0.33731588147693903`, 0.46049374800704757`, 0.9429375805107916],
              UndirectedEdge[102, 485] -> 
             RGBColor[
              0.2532273027822811, 0.38348832913546316`, 0.9377322923260032], 
             UndirectedEdge[342, 463] -> 
             RGBColor[
              0.6511217470840227, 0.7175310736659726, 0.8793197045855838], 
             UndirectedEdge[70, 147] -> 
             RGBColor[
              0.26449380097908753`, 0.3953301330775506, 0.9383739027310208], 
             UndirectedEdge[162, 381] -> 
             RGBColor[
              0.3385552783358301, 0.4676612986366031, 0.9427934208562492], 
             UndirectedEdge[212, 299] -> 
             RGBColor[
              0.3327692820793612, 0.46264975949187737`, 0.9424247422911427], 
             UndirectedEdge[92, 361] -> 
             RGBColor[
              0.36637545570685137`, 0.49133860507996435`, 0.9445814444670191],
              UndirectedEdge[82, 184] -> 
             RGBColor[
              0.2931176425762863, 0.42446538835807013`, 0.9400387802673861], 
             UndirectedEdge[232, 376] -> 
             RGBColor[
              0.38959354023417225`, 0.5115018166350789, 0.946146732281344], 
             UndirectedEdge[293, 298] -> 
             RGBColor[
              0.24753239335827026`, 0.37750261825271536`, 0.9374079756591692],
              UndirectedEdge[225, 249] -> 
             RGBColor[
              0.38415619088140673`, 0.5037401249203888, 0.9460416677238485], 
             UndirectedEdge[19, 34] -> 
             RGBColor[
              0.36502194474573596`, 0.49058539482753094`, 0.9444798534363343],
              UndirectedEdge[338, 390] -> 
             RGBColor[
              0.4990493185936098, 0.5967421398727433, 0.9557265811229383], 
             UndirectedEdge[82, 342] -> 
             RGBColor[
              0.31569756486905426`, 0.4478630960937653, 0.9413369475664287], 
             UndirectedEdge[54, 374] -> 
             RGBColor[
              0.4289188512915289, 0.5328935815484176, 0.9502197435352682], 
             UndirectedEdge[196, 350] -> 
             RGBColor[
              0.3150392911392551, 0.44287492113468296`, 0.9414567679837802], 
             UndirectedEdge[19, 44] -> 
             RGBColor[
              0.34809117962034825`, 0.4759208170409182, 0.9434010400538324], 
             UndirectedEdge[85, 408] -> 
             RGBColor[
              0.28150294764120404`, 0.4132078246616212, 0.9393425484706508], 
             UndirectedEdge[57, 255] -> 
             RGBColor[
              0.3339687342319978, 0.46368866466027303`, 0.9425011703216748], 
             UndirectedEdge[106, 269] -> 
             RGBColor[
              0.6432507329301015, 0.7171521816887787, 0.9676224688250287], 
             UndirectedEdge[382, 416] -> 
             RGBColor[
              0.28227680359612173`, 0.41131547444650907`, 0.9394856881551299],
              UndirectedEdge[246, 392] -> 
             RGBColor[
              0.30706766217182835`, 0.43810013753387, 0.9408708389320514], 
             UndirectedEdge[350, 414] -> 
             RGBColor[
              0.46154718440299136`, 0.5714575725893953, 0.9513855292357323], 
             UndirectedEdge[146, 211] -> 
             RGBColor[
              0.6515561947182096, 0.7215470514081394, 0.9609519835992624], 
             UndirectedEdge[71, 487] -> 
             RGBColor[
              0.43397550730676615`, 0.5484785228081585, 0.9493794193075614], 
             UndirectedEdge[415, 485] -> 
             RGBColor[
              0.2686049791759216, 0.3996512420261761, 0.9386080282473874], 
             UndirectedEdge[238, 433] -> 
             RGBColor[
              0.43605754252337336`, 0.5343039039039512, 0.9515424281972649], 
             UndirectedEdge[141, 429] -> 
             RGBColor[
              0.3308559747002966, 0.45872626840597047`, 0.9423858076639051], 
             UndirectedEdge[406, 493] -> 
             RGBColor[
              0.37011880931709223`, 0.4950000427433777, 0.9448046211398408], 
             UndirectedEdge[257, 357] -> 
             RGBColor[
              0.6176699197499559, 0.7004912924226239, 0.9630443851636357], 
             UndirectedEdge[311, 488] -> 
             RGBColor[
              0.3120422059462299, 0.44418403823657515`, 0.9411228136610725], 
             UndirectedEdge[258, 381] -> 
             RGBColor[
              0.3078594194548105, 0.4356160700661915, 0.9410373526629876], 
             UndirectedEdge[168, 200] -> 
             RGBColor[
              0.30309077438471843`, 0.43076098442902333`, 0.9407600345466798],
              UndirectedEdge[16, 254] -> 
             RGBColor[
              0.28078576532697075`, 0.412454020577377, 0.9393017059988313], 
             UndirectedEdge[325, 347] -> 
             RGBColor[
              0.28069649360744797`, 0.4123601903400046, 0.9392966221064702], 
             UndirectedEdge[154, 478] -> 
             RGBColor[
              0.6674221652381811, 0.7334072446868618, 0.9344946064562802], 
             UndirectedEdge[302, 386] -> 
             RGBColor[
              0.29507152984627805`, 0.4266996965170632, 0.9401434368210584], 
             UndirectedEdge[330, 414] -> 
             RGBColor[
              0.4718859773821623, 0.5804125154251087, 0.9520443079821295], 
             UndirectedEdge[50, 334] -> 
             RGBColor[
              0.2608363991205258, 0.39148597183153083`, 0.938165619105817], 
             UndirectedEdge[72, 187] -> 
             RGBColor[
              0.3074146521959259, 0.43056670289526167`, 0.9411797892114901], 
             UndirectedEdge[14, 149] -> 
             RGBColor[
              0.3247307700687785, 0.4517408120933031, 0.942057032168808], 
             UndirectedEdge[113, 214] -> 
             RGBColor[
              0.25249707242907415`, 0.3822250968437606, 0.9377088573015385], 
             UndirectedEdge[63, 149] -> 
             RGBColor[
              0.27897070077698005`, 0.41054627265359755`, 0.9391983407578568],
              UndirectedEdge[245, 445] -> 
             RGBColor[
              0.32390286655207123`, 0.452679580729783, 0.9419436498507558], 
             UndirectedEdge[207, 336] -> 
             RGBColor[
              0.30514492238640234`, 0.43218735000739406`, 0.9409038420285273],
              UndirectedEdge[264, 394] -> 
             RGBColor[
              0.3133500758529717, 0.4437149686044395, 0.9412648026784838], 
             UndirectedEdge[255, 370] -> 
             RGBColor[
              0.3572147426286109, 0.4838231887550652, 0.9439823854210688], 
             UndirectedEdge[330, 482] -> 
             RGBColor[
              0.3417930608627968, 0.4690830452983677, 0.9430503553719873], 
             UndirectedEdge[383, 482] -> 
             RGBColor[
              0.30680318191155154`, 0.43877657079324994`, 0.940820831225549], 
             UndirectedEdge[358, 407] -> 
             RGBColor[
              0.2669703258889591, 0.3974883223282437, 0.9385312233012687], 
             UndirectedEdge[28, 142] -> 
             RGBColor[
              0.8174128034860786, 0.8576559777320825, 0.9823381731799472], 
             UndirectedEdge[348, 375] -> 
             RGBColor[
              0.48458633078136776`, 0.5921725868280354, 0.9526436659467254], 
             UndirectedEdge[41, 295] -> 
             RGBColor[
              0.25498973366613364`, 0.3853407557389643, 0.9378326601575557], 
             UndirectedEdge[83, 345] -> 
             RGBColor[
              0.3386350927546853, 0.4670471942017421, 0.9428235231653386], 
             UndirectedEdge[140, 425] -> 
             RGBColor[
              0.33561748327610075`, 0.4651167282137386, 0.9426062271528335], 
             UndirectedEdge[160, 441] -> 
             RGBColor[
              0.5608215115987503, 0.6380851169122411, 0.9629182760347694], 
             UndirectedEdge[66, 394] -> 
             RGBColor[
              0.6111099194182043, 0.6849244510379885, 0.9661110894621461], 
             UndirectedEdge[201, 271] -> 
             RGBColor[
              0.32535298941127566`, 0.45622613953648944`, 0.9419521826803023],
              UndirectedEdge[192, 470] -> 
             RGBColor[
              0.3247501896565206, 0.4547202853634914, 0.9419497923285464], 
             UndirectedEdge[255, 379] -> 
             RGBColor[
              0.3338964020188863, 0.4636260141327986, 0.9424965613770162], 
             UndirectedEdge[82, 440] -> 
             RGBColor[
              0.2993098605796235, 0.43097380208887504`, 0.9403914179221106], 
             UndirectedEdge[43, 362] -> 
             RGBColor[
              0.30654038786523846`, 0.4365996606362603, 0.9408754593195949], 
             UndirectedEdge[127, 302] -> 
             RGBColor[
              0.5794553555625866, 0.6628883735492341, 0.9631005625177902], 
             UndirectedEdge[137, 358] -> 
             RGBColor[
              0.34809103059005636`, 0.47592068795836984`, 0.9434010305577539],
              UndirectedEdge[238, 328] -> 
             RGBColor[
              0.25950406813811605`, 0.38820628227145826`, 0.9381585561298882],
              UndirectedEdge[185, 196] -> 
             RGBColor[
              0.29326451102418494`, 0.4240147010312798, 0.9400692982495299], 
             UndirectedEdge[114, 208] -> 
             RGBColor[
              0.5776372741653659, 0.6515838469356201, 0.9645084990446434], 
             UndirectedEdge[249, 424] -> 
             RGBColor[
              0.27815710751266287`, 0.40969113454800776`, 0.9391520078250573],
              UndirectedEdge[21, 65] -> 
             RGBColor[
              0.29465769801097885`, 0.4258340129829025, 0.9401356404807292], 
             UndirectedEdge[369, 466] -> 
             RGBColor[
              0.3958679207865078, 0.5169966422662079, 0.946529876775053], 
             UndirectedEdge[246, 459] -> 
             RGBColor[
              0.29246865690359136`, 0.422755657366557, 0.9400394471793181], 
             UndirectedEdge[46, 317] -> 
             RGBColor[
              0.35495603067734094`, 0.48186680598903875`, 0.9438384622928344],
              UndirectedEdge[66, 305] -> 
             RGBColor[
              0.5880207431382927, 0.6606562628294723, 0.9647961950303805], 
             UndirectedEdge[56, 243] -> 
             RGBColor[
              0.31942767533965444`, 0.44652773648813343`, 0.941741817630809], 
             UndirectedEdge[281, 288] -> 
             RGBColor[
              0.36229961155660445`, 0.4867867021288403, 0.944359141487279], 
             UndirectedEdge[81, 329] -> 
             RGBColor[
              0.31563321715705006`, 0.44349917503646996`, 0.9414905911918587],
              UndirectedEdge[57, 140] -> 
             RGBColor[
              0.33198325689546354`, 0.4619689439843596, 0.9423746574614795], 
             UndirectedEdge[184, 440] -> 
             RGBColor[
              0.27340408970590446`, 0.40469541147437016`, 0.9388813304924222],
              UndirectedEdge[422, 446] -> 
             RGBColor[
              0.4456857763503804, 0.5574487862208881, 0.950449575488568], 
             UndirectedEdge[232, 307] -> 
             RGBColor[
              0.26256954534941873`, 0.39297162700755006`, 0.938276621510581], 
             UndirectedEdge[90, 261] -> 
             RGBColor[
              0.5033552137320122, 0.5915122130370639, 0.957516265266006], 
             UndirectedEdge[118, 304] -> 
             RGBColor[
              0.5175224870751732, 0.615798529170843, 0.956352699231096], 
             UndirectedEdge[427, 460] -> 
             RGBColor[
              0.3796217897703411, 0.49341086162862274`, 0.9462898482983824], 
             UndirectedEdge[299, 300] -> 
             RGBColor[
              0.2873418460675212, 0.4163273223833575, 0.9397855525587443], 
             UndirectedEdge[106, 425] -> 
             RGBColor[
              0.3668531727732162, 0.49217151250473745`, 0.944596537666954], 
             UndirectedEdge[428, 495] -> 
             RGBColor[
              0.268829700095258, 0.39988743796052784`, 0.9386208257712988], 
             UndirectedEdge[230, 365] -> 
             RGBColor[
              0.24143487761266663`, 0.3710937425992585, 0.9370607311579233], 
             UndirectedEdge[224, 463] -> 
             RGBColor[
              0.9356670815791801, 0.9491989648758439, 0.9030351225028213], 
             UndirectedEdge[251, 382] -> 
             RGBColor[
              0.3250395393596027, 0.455954644856188, 0.9419322099201828], 
             UndirectedEdge[81, 278] -> 
             RGBColor[
              0.28362227094567166`, 0.41543536782747525`, 0.9394632407975825],
              UndirectedEdge[42, 294] -> 
             RGBColor[
              0.33125733663946566`, 0.4594431896886225, 0.94239786087814], 
             UndirectedEdge[8, 419] -> 
             RGBColor[
              0.2158226935960633, 0.34417371329154933`, 0.9356021551680085], 
             UndirectedEdge[159, 164] -> 
             RGBColor[
              0.29350188273879596`, 0.42379877114882075`, 0.9400998576190059],
              UndirectedEdge[346, 404] -> 
             RGBColor[
              0.5837609489665214, 0.6729624623589062, 0.9603749467709108], 
             UndirectedEdge[7, 194] -> 
             RGBColor[
              0.2975562573811955, 0.42744618039691995`, 0.9403532296422834], 
             UndirectedEdge[268, 353] -> 
             RGBColor[
              0.3346316796593649, 0.4642628746688524, 0.9425434126180869], 
             UndirectedEdge[51, 423] -> 
             RGBColor[
              0.5404799508239514, 0.637824998280021, 0.9569677080536076], 
             UndirectedEdge[14, 322] -> 
             RGBColor[
              0.3133751104580029, 0.4398052938519739, 0.9414103441531672], 
             UndirectedEdge[109, 458] -> 
             RGBColor[
              0.38017483278773323`, 0.4991503827827847, 0.9458518083851954], 
             UndirectedEdge[217, 384] -> 
             RGBColor[
              0.3240804018205206, 0.4460693324493911, 0.9422026261625369], 
             UndirectedEdge[202, 485] -> 
             RGBColor[
              0.2522732563622325, 0.38248556585795535`, 0.9376779607937666], 
             UndirectedEdge[125, 457] -> 
             RGBColor[
              0.283399551025744, 0.41143107104270515`, 0.939588602865881], 
             UndirectedEdge[454, 475] -> 
             RGBColor[
              0.49104221898594785`, 0.5973548530526378, 0.953168175409414], 
             UndirectedEdge[30, 378] -> 
             RGBColor[
              0.25344180607121264`, 0.38371378569242426`, 0.9377445079709786],
              UndirectedEdge[445, 460] -> 
             RGBColor[
              0.25498768147232764`, 0.38533859875315757`, 0.9378325432881545],
              UndirectedEdge[173, 461] -> 
             RGBColor[
              0.31607264180802686`, 0.44193276532577086`, 0.9415898807815388],
              UndirectedEdge[23, 41] -> 
             RGBColor[
              0.27683223804440915`, 0.4082986127352971, 0.939076558468809], 
             UndirectedEdge[111, 444] -> 
             RGBColor[
              0.279247128535272, 0.41083681575409453`, 0.9392140829097533], 
             UndirectedEdge[139, 360] -> 
             RGBColor[
              0.33150075815428187`, 0.4533506956447559, 0.9426441673998178], 
             UndirectedEdge[53, 432] -> 
             RGBColor[
              0.3508514194182354, 0.478311598020162, 0.9435769200929695], 
             UndirectedEdge[184, 260] -> 
             RGBColor[
              0.3050332212396536, 0.43478606370188166`, 0.9407980304032834], 
             UndirectedEdge[244, 379] -> 
             RGBColor[
              0.4318227414071683, 0.5457342170048416, 0.9494853074338421], 
             UndirectedEdge[14, 187] -> 
             RGBColor[
              0.39948110538592196`, 0.520432187806287, 0.9466755606812876], 
             UndirectedEdge[133, 332] -> 
             RGBColor[
              0.40662164684454366`, 0.5247096458869189, 0.9475616333932896], 
             UndirectedEdge[424, 440] -> 
             RGBColor[
              0.27716288310314974`, 0.4086461416561411, 0.9390953882157588], 
             UndirectedEdge[381, 419] -> 
             RGBColor[
              0.29010238829297363`, 0.4169523044542987, 0.9400261160074944], 
             UndirectedEdge[39, 368] -> 
             RGBColor[
              0.3123444845913792, 0.44309977914226695`, 0.9411913610862419], 
             UndirectedEdge[40, 208] -> 
             RGBColor[
              0.6968861559727259, 0.7613436775227751, 0.9719902825356777], 
             UndirectedEdge[436, 462] -> 
             RGBColor[
              0.3175895603189484, 0.4424958603574968, 0.9417140273508959], 
             UndirectedEdge[103, 188] -> 
             RGBColor[
              0.32960424674893524`, 0.4557751062687777, 0.9423744078868641], 
             UndirectedEdge[313, 411] -> 
             RGBColor[
              0.4633341748301859, 0.5709361000550581, 0.9520094416129672], 
             UndirectedEdge[181, 344] -> 
             RGBColor[
              0.33701573303352617`, 0.4663278218755442, 0.9426953223909529], 
             UndirectedEdge[5, 485] -> 
             RGBColor[
              0.2711233170209595, 0.40229817477315244`, 0.9387514438621154], 
             UndirectedEdge[371, 429] -> 
             RGBColor[
              0.42351632324732824`, 0.5360113551484746, 0.9491113951681209], 
             UndirectedEdge[426, 448] -> 
             RGBColor[
              0.4666727644670563, 0.5765215105866255, 0.95153959806563], 
             UndirectedEdge[32, 403] -> 
             RGBColor[
              0.4727208771720134, 0.5811972904442376, 0.952080479394307], 
             UndirectedEdge[115, 484] -> 
             RGBColor[
              0.32848714770128296`, 0.4589407899199178, 0.9421518884751142], 
             UndirectedEdge[36, 251] -> 
             RGBColor[
              0.34013357163407043`, 0.4690283369642111, 0.9428939883095832], 
             UndirectedEdge[243, 454] -> 
             RGBColor[
              0.40021981322154804`, 0.5141228562318955, 0.9475482427488072], 
             UndirectedEdge[106, 139] -> 
             RGBColor[
              0.42937340082515074`, 0.5463233916852932, 0.9485802713139563], 
             UndirectedEdge[220, 499] -> 
             RGBColor[
              0.33944826419640717`, 0.4679201865209281, 0.942869162112079], 
             UndirectedEdge[359, 419] -> 
             RGBColor[
              0.22028987229689073`, 0.34886900134160753`, 0.9358565543864219],
              UndirectedEdge[115, 297] -> 
             RGBColor[
              0.3063781073476113, 0.4384751118464804, 0.9407913029306996], 
             UndirectedEdge[155, 235] -> 
             RGBColor[
              0.29143591113945116`, 0.42072389791832054`, 0.9400152817151323],
              UndirectedEdge[98, 261] -> 
             RGBColor[
              0.6313262992509348, 0.7094325364761531, 0.9655864375213759], 
             UndirectedEdge[386, 421] -> 
             RGBColor[
              0.24677460209412794`, 0.3767061315873606, 0.9373648205677281], 
             UndirectedEdge[37, 58] -> 
             RGBColor[
              0.35369345679149744`, 0.48077322794792976`, 0.9437580122012788],
              UndirectedEdge[71, 194] -> 
             RGBColor[
              0.3422208933144379, 0.4708362700919073, 0.9430269906013101], 
             UndirectedEdge[47, 339] -> 
             RGBColor[
              0.31043183100056115`, 0.4431269262752648, 0.9410078366341701], 
             UndirectedEdge[108, 410] -> 
             RGBColor[
              0.4670224028452155, 0.5661077654717819, 0.9534233275733031], 
             UndirectedEdge[193, 196] -> 
             RGBColor[
              0.28576992306222604`, 0.41752326562757475`, 0.9395917497317978],
              UndirectedEdge[131, 171] -> 
             RGBColor[
              0.36152316493400594`, 0.48480196632094696`, 0.9443577136790281],
              UndirectedEdge[203, 258] -> 
             RGBColor[
              0.2948866357476313, 0.4243796968501007, 0.9402107383565483], 
             UndirectedEdge[164, 428] -> 
             RGBColor[
              0.29732140560358056`, 0.42781333185144615`, 0.9403173737956777],
              UndirectedEdge[143, 325] -> 
             RGBColor[
              0.327963587735544, 0.45461607774412116`, 0.9422602724221149], 
             UndirectedEdge[101, 498] -> 
             RGBColor[
              0.2705295670071685, 0.4016741058627329, 0.9387176306772045], 
             UndirectedEdge[35, 391] -> 
             RGBColor[
              0.46604504970388005`, 0.5705382939580077, 0.9525036207279167], 
             UndirectedEdge[8, 221] -> 
             RGBColor[
              0.5847762127313846, 0.5968515600985937, 0.6080080292518997], 
             UndirectedEdge[240, 251] -> 
             RGBColor[
              0.5646936870819825, 0.28942333675672277`, 0.5526618493719339], 
             UndirectedEdge[464, 485] -> 
             RGBColor[
              0.48660128476779546`, 0.5810947923669382, 0.9554235513395917], 
             UndirectedEdge[104, 452] -> 
             RGBColor[
              0.3032703089547413, 0.4323882255539395, 0.9407175868185416], 
             UndirectedEdge[121, 475] -> 
             RGBColor[
              0.3647059223397555, 0.48843131633232484`, 0.9445285658039957], 
             UndirectedEdge[168, 315] -> 
             RGBColor[
              0.2390027384297109, 0.36853741011144125`, 0.9369222244294815], 
             UndirectedEdge[65, 320] -> 
             RGBColor[
              0.27588176019991395`, 0.40729960025695666`, 0.939022430161671], 
             UndirectedEdge[323, 452] -> 
             RGBColor[
              0.33381731860291747`, 0.4588465099738429, 0.9426640152616632], 
             UndirectedEdge[72, 322] -> 
             RGBColor[
              0.22130865726800683`, 0.34993980894094856`, 0.9359145726833697],
              UndirectedEdge[60, 327] -> 
             RGBColor[
              0.3877636396050008, 0.4972112256965723, 0.9471865478416341], 
             UndirectedEdge[1, 135] -> 
             RGBColor[
              0.36461395280718073`, 0.48825301068166893`, 0.9445263175096634],
              UndirectedEdge[420, 439] -> 
             RGBColor[
              0.3481621586058308, 0.47598229547063564`, 0.943405562772023], 
             UndirectedEdge[134, 367] -> 
             RGBColor[
              0.2401457444836934, 0.3697387819449464, 0.9369873169333298], 
             UndirectedEdge[119, 345] -> 
             RGBColor[
              0.30396909166182406`, 0.43061102910172805`, 0.940849345686853], 
             UndirectedEdge[64, 366] -> 
             RGBColor[
              0.4325163267328157, 0.5412201232910389, 0.9500108668676096], 
             UndirectedEdge[86, 90] -> 
             RGBColor[
              0.3112350653982756, 0.43618902142472016`, 0.9413385224659996], 
             UndirectedEdge[81, 426] -> 
             RGBColor[
              0.33225721799808206`, 0.45789804901839504`, 0.9425498578254226],
              UndirectedEdge[70, 265] -> 
             RGBColor[
              0.35409161874420736`, 0.47812611151812245`, 0.9438929339306832],
              UndirectedEdge[245, 438] -> 
             RGBColor[
              0.4043999708199356, 0.5246926618158645, 0.946988986437161], 
             UndirectedEdge[121, 259] -> 
             RGBColor[
              0.31367030473170804`, 0.44422682948495945`, 0.9412766213790356],
              UndirectedEdge[74, 105] -> 
             RGBColor[
              0.442051701477634, 0.5556629346443093, 0.9498417456601446], 
             UndirectedEdge[358, 430] -> 
             RGBColor[
              0.3075192917830953, 0.4401078564359097, 0.9408404269221204], 
             UndirectedEdge[43, 316] -> 
             RGBColor[
              0.3135710615386804, 0.44268927680026215`, 0.9413234476290862], 
             UndirectedEdge[162, 203] -> 
             RGBColor[
              0.3255824946286509, 0.4564249254205123, 0.9419668065498099], 
             UndirectedEdge[226, 236] -> 
             RGBColor[
              0.2830232095400458, 0.41480571630747554`, 0.9394291251367639], 
             UndirectedEdge[110, 340] -> 
             RGBColor[
              0.41671434081590947`, 0.5342406597766676, 0.9480825789106522], 
             UndirectedEdge[145, 407] -> 
             RGBColor[
              0.3102226980909668, 0.43495135320218614`, 0.9412872262114096], 
             UndirectedEdge[258, 289] -> 
             RGBColor[
              0.3389846561184968, 0.462575185664395, 0.9430206252202316], 
             UndirectedEdge[13, 334] -> 
             RGBColor[
              0.38092442058582776`, 0.4953825361837113, 0.9463091854432593], 
             UndirectedEdge[300, 389] -> 
             RGBColor[
              0.34109456562105933`, 0.4628852263703923, 0.9432106283170322], 
             UndirectedEdge[57, 363] -> 
             RGBColor[
              0.2974372353320738, 0.42978063603989525`, 0.9402563951423928], 
             UndirectedEdge[305, 427] -> 
             RGBColor[
              0.3864669179289286, 0.5006055253294905, 0.9466796682205543], 
             UndirectedEdge[277, 419] -> 
             RGBColor[
              0.2785266772728737, 0.406926005380841, 0.9392885219372931], 
             UndirectedEdge[40, 349] -> 
             RGBColor[
              0.4492441351900306, 0.5630323621064026, 0.9499851378740574], 
             UndirectedEdge[28, 241] -> 
             RGBColor[
              0.8821595340743779, 0.9056881417086591, 0.8352093294559062], 
             UndirectedEdge[164, 396] -> 
             RGBColor[
              0.3523989638491783, 0.47965200322439994`, 0.9436755282556694], 
             UndirectedEdge[111, 284] -> 
             RGBColor[
              0.2911466841152617, 0.42334400314406384`, 0.9398917449962187], 
             UndirectedEdge[25, 343] -> 
             RGBColor[
              0.3591977312479719, 0.48305074509493995`, 0.944199911119779], 
             UndirectedEdge[84, 131] -> 
             RGBColor[
              0.4302250277024128, 0.5470610280823661, 0.9486345362255113], 
             UndirectedEdge[169, 244] -> 
             RGBColor[
              0.430850946517537, 0.5448745590228729, 0.949424042324234], 
             UndirectedEdge[219, 363] -> 
             RGBColor[
              0.617531294953834, 0.6894635140753127, 0.9538085175362618], 
             UndirectedEdge[400, 415] -> 
             RGBColor[
              0.29719778530953317`, 0.4297040941612182, 0.9402363462574306], 
             UndirectedEdge[248, 286] -> 
             RGBColor[
              0.22133035891772468`, 0.34996261875076606`, 0.9359158085602164],
              UndirectedEdge[136, 484] -> 
             RGBColor[
              0.3448719228413225, 0.4731324586234765, 0.9431959118585498], 
             UndirectedEdge[74, 263] -> 
             RGBColor[
              0.4627727265515983, 0.5736104450943749, 0.9511620710549745], 
             UndirectedEdge[69, 142] -> 
             RGBColor[
              0.6253364720418517, 0.701815861320964, 0.9663980725076264], 
             UndirectedEdge[109, 409] -> 
             RGBColor[0.3643942989151, 0.482564041139011, 0.9449531303263567],
              UndirectedEdge[101, 219] -> 
             RGBColor[
              0.6153668639835328, 0.6871885598926764, 0.9536852563944918], 
             UndirectedEdge[380, 390] -> 
             RGBColor[
              0.48258903687575233`, 0.5794413401451362, 0.9547891924299109], 
             UndirectedEdge[53, 293] -> 
             RGBColor[
              0.31577833650373477`, 0.44183900905974377`, 0.9415652271900021],
              UndirectedEdge[221, 258] -> 
             RGBColor[
              0.6009093340661656, 0.6138084935204211, 0.6089267866451011], 
             UndirectedEdge[235, 424] -> 
             RGBColor[
              0.258614308451333, 0.3891504136495234, 0.938039074329495], 
             UndirectedEdge[367, 457] -> 
             RGBColor[
              0.30321171130249636`, 0.432254907657086, 0.9407168760841775], 
             UndirectedEdge[58, 220] -> 
             RGBColor[
              0.3573241663918694, 0.4839179661190015, 0.9439893578065041], 
             UndirectedEdge[334, 379] -> 
             RGBColor[
              0.27207088393023604`, 0.4031323676116257, 0.9388113292240843], 
             UndirectedEdge[14, 163] -> 
             RGBColor[
              0.31065728415518956`, 0.4369486860875767, 0.9412555679658857], 
             UndirectedEdge[284, 442] -> 
             RGBColor[
              0.2869656620714468, 0.41894948388390585`, 0.9396536419760915], 
             UndirectedEdge[130, 302] -> 
             RGBColor[
              0.3073215790480628, 0.43957527492611825`, 0.9408410590007763], 
             UndirectedEdge[65, 428] -> 
             RGBColor[
              0.2658142533022072, 0.39671801219066216`, 0.9384491005373883], 
             UndirectedEdge[388, 487] -> 
             RGBColor[
              0.41353723706232354`, 0.5305518794924018, 0.9480853140348157], 
             UndirectedEdge[456, 458] -> 
             RGBColor[
              0.30659504124384873`, 0.43641837251769444`, 0.9408873129070567],
              UndirectedEdge[281, 465] -> 
             RGBColor[
              0.33457883463388827`, 0.4627763584451433, 0.9425927980942841], 
             UndirectedEdge[166, 428] -> 
             RGBColor[
              0.2569354463468979, 0.38738582313175673`, 0.9379434656163013], 
             UndirectedEdge[92, 128] -> 
             RGBColor[
              0.366223070589308, 0.4911784386596518, 0.9445727663600085], 
             UndirectedEdge[120, 457] -> 
             RGBColor[
              0.347746338118663, 0.47562213266439624`, 0.9433790670582763], 
             UndirectedEdge[79, 329] -> 
             RGBColor[
              0.33350909345418966`, 0.4622878544207828, 0.9425085959019917], 
             UndirectedEdge[105, 195] -> 
             RGBColor[
              0.48105427733835465`, 0.5873269827740616, 0.9529121713030434], 
             UndirectedEdge[98, 377] -> 
             RGBColor[
              0.43961688791079445`, 0.554465104603421, 0.9494348665194009], 
             UndirectedEdge[21, 309] -> 
             RGBColor[
              0.2885168926104651, 0.4193796371574124, 0.9397859306976775], 
             UndirectedEdge[93, 322] -> 
             RGBColor[
              0.3241673774538106, 0.4491530130886313, 0.942098017862913], 
             UndirectedEdge[8, 115] -> 
             RGBColor[
              0.26784491151390927`, 0.3979742798795344, 0.938596894432725], 
             UndirectedEdge[54, 131] -> 
             RGBColor[
              0.3327871512177515, 0.4545985939366621, 0.9427212402090102], 
             UndirectedEdge[186, 212] -> 
             RGBColor[
              0.6575349685392193, 0.7228498313908325, 0.8710521872261221], 
             UndirectedEdge[252, 467] -> 
             RGBColor[
              0.29450281951597845`, 0.42687151424149183`, 0.9400828719423322],
              UndirectedEdge[244, 378] -> 
             RGBColor[
              0.3930600725794523, 0.5051539544341471, 0.947271907960048], 
             UndirectedEdge[55, 339] -> 
             RGBColor[
              0.3177193107934676, 0.44961423079758744`, 0.9414657714289726], 
             UndirectedEdge[69, 490] -> 
             RGBColor[
              0.35348975024349605`, 0.48059678757463975`, 0.9437450322001708],
              UndirectedEdge[299, 451] -> 
             RGBColor[
              0.3532798817126326, 0.4804150100015049, 0.9437316595629637], 
             UndirectedEdge[146, 464] -> 
             RGBColor[
              0.543582653251436, 0.636427903666534, 0.9588354437499061], 
             UndirectedEdge[199, 220] -> 
             RGBColor[
              0.35933541009125586`, 0.4856600043233624, 0.944117512476556], 
             UndirectedEdge[345, 426] -> 
             RGBColor[
              0.3891395671620182, 0.511474867177566, 0.9460166070103236], 
             UndirectedEdge[66, 472] -> 
             RGBColor[
              0.5981675854956696, 0.6713212374940387, 0.965374042691725], 
             UndirectedEdge[40, 114] -> 
             RGBColor[
              0.35255963760691805`, 0.4723146060617628, 0.9440798579302622], 
             UndirectedEdge[248, 294] -> 
             RGBColor[
              0.28955079731709527`, 0.415606972513488, 0.9400227351630268], 
             UndirectedEdge[304, 483] -> 
             RGBColor[
              0.31003716557622457`, 0.4392310716857616, 0.9411128188098624], 
             UndirectedEdge[9, 425] -> 
             RGBColor[
              0.3048271360883984, 0.4368758721616305, 0.9407018449334199], 
             UndirectedEdge[290, 384] -> 
             RGBColor[
              0.34925067923486824`, 0.47252488989963265`, 0.9436360362251955],
              UndirectedEdge[294, 358] -> 
             RGBColor[
              0.34392159325117455`, 0.4723093308974443, 0.9431353576974091], 
             UndirectedEdge[148, 342] -> 
             RGBColor[
              0.30144409466541494`, 0.4338320122820477, 0.9404904414218673], 
             UndirectedEdge[178, 420] -> 
             RGBColor[
              0.38695942569997055`, 0.5095865382202364, 0.9458776903241854], 
             UndirectedEdge[193, 354] -> 
             RGBColor[
              0.47718110051193763`, 0.5825386003909765, 0.9530703843262771], 
             UndirectedEdge[194, 228] -> 
             RGBColor[
              0.5241549499731664, 0.6203673776113099, 0.957272992553038], 
             UndirectedEdge[326, 491] -> 
             RGBColor[
              0.5749425131613002, 0.6658032589062217, 0.9596807272013292], 
             UndirectedEdge[324, 481] -> 
             RGBColor[
              0.5946777022256553, 0.6756661743755695, 0.9642578956010922], 
             UndirectedEdge[94, 213] -> 
             RGBColor[
              0.6589703522467648, 0.7228996380727806, 0.8172867454691695], 
             UndirectedEdge[92, 175] -> 
             RGBColor[
              0.3346117679825815, 0.45795295534763575`, 0.942772549441287], 
             UndirectedEdge[254, 401] -> 
             RGBColor[
              0.2723954727191816, 0.4036352910713138, 0.9388238912471434], 
             UndirectedEdge[161, 491] -> 
             RGBColor[
              0.464668096963314, 0.5704966819840841, 0.9522530271752385], 
             UndirectedEdge[172, 303] -> 
             RGBColor[
              0.278101947991656, 0.40963315839411396`, 0.9391488665719372], 
             UndirectedEdge[57, 274] -> 
             RGBColor[
              0.28340249859697586`, 0.4150292378776028, 0.9394571376478613], 
             UndirectedEdge[44, 360] -> 
             RGBColor[
              0.3007491130024982, 0.42671516623690714`, 0.9406846997633583], 
             UndirectedEdge[170, 238] -> 
             RGBColor[
              0.21638463409382552`, 0.34476434838378284`, 0.9356341568480395],
              UndirectedEdge[5, 11] -> 
             RGBColor[
              0.27006104969618294`, 0.4011816644631739, 0.9386909493094531], 
             UndirectedEdge[3, 223] -> 
             RGBColor[
              0.3692702980289915, 0.4942651049130422, 0.9447505547508721], 
             UndirectedEdge[65, 227] -> 
             RGBColor[
              0.2711641093050984, 0.40234105005016263`, 0.9387537669223502], 
             UndirectedEdge[78, 85] -> 
             RGBColor[
              0.24969954876511535`, 0.3797804359908985, 0.9375313919535699], 
             UndirectedEdge[181, 393] -> 
             RGBColor[
              0.2894362285504237, 0.4184581346022158, 0.9399074064995601], 
             UndirectedEdge[45, 56] -> 
             RGBColor[
              0.33833332545058, 0.46639877344216607`, 0.9428184664362231], 
             UndirectedEdge[141, 310] -> 
             RGBColor[
              0.34083695595373154`, 0.4692169125340926, 0.9429542097807496], 
             UndirectedEdge[39, 236] -> 
             RGBColor[
              0.30610682550093266`, 0.4365436039477788, 0.9408361356288307], 
             UndirectedEdge[337, 375] -> 
             RGBColor[
              0.40201457961445697`, 0.5178131622340773, 0.9474862505037611], 
             UndirectedEdge[57, 334] -> 
             RGBColor[
              0.27214321614334747`, 0.4031950181391001, 0.9388159381687429], 
             UndirectedEdge[123, 438] -> 
             RGBColor[
              0.3843119302605872, 0.5072934107376323, 0.9457089942558762], 
             UndirectedEdge[35, 385] -> 
             RGBColor[
              0.46338895469949215`, 0.5677465697022461, 0.9523523600467572], 
             UndirectedEdge[268, 285] -> 
             RGBColor[
              0.2979106494482142, 0.4295031424746541, 0.9403117349181241], 
             UndirectedEdge[169, 361] -> 
             RGBColor[
              0.30638235097084093`, 0.4393576550063496, 0.9407593936844948], 
             UndirectedEdge[337, 361] -> 
             RGBColor[
              0.2911212516043873, 0.4233172719626206, 0.9398902966523486], 
             UndirectedEdge[119, 270] -> 
             RGBColor[
              0.3119246902038726, 0.43750176869884133`, 0.9413562693910926], 
             UndirectedEdge[254, 386] -> 
             RGBColor[
              0.28401741495266886`, 0.4158506892324063, 0.9394857436642177], 
             UndirectedEdge[253, 488] -> 
             RGBColor[
              0.3032359223212674, 0.4349280757961089, 0.9406213088363601], 
             UndirectedEdge[340, 380] -> 
             RGBColor[
              0.2969945916881088, 0.4266995977748629, 0.9403269641907093], 
             UndirectedEdge[388, 490] -> 
             RGBColor[
              0.3140477995174865, 0.44621011137850314`, 0.9412400292114345], 
             UndirectedEdge[27, 311] -> 
             RGBColor[
              0.28224020111015435`, 0.41398272480205783`, 0.9393845339650388],
              UndirectedEdge[222, 417] -> 
             RGBColor[
              0.450086149291519, 0.5639195708203562, 0.9499951624641072], 
             UndirectedEdge[274, 361] -> 
             RGBColor[
              0.28018873833068914`, 0.4118265073505871, 0.9392677061946155], 
             UndirectedEdge[65, 474] -> 
             RGBColor[
              0.24320787132901925`, 0.37295727140943946`, 0.9371617005271604],
              UndirectedEdge[243, 326] -> 
             RGBColor[
              0.3865707980939931, 0.503041970870222, 0.9464737422799763], 
             UndirectedEdge[47, 437] -> 
             RGBColor[
              0.2872684005930312, 0.41926768126482195`, 0.9396708824870341], 
             UndirectedEdge[232, 414] -> 
             RGBColor[
              0.4331786186265695, 0.5468861467594329, 0.9495779093097965], 
             UndirectedEdge[102, 196] -> 
             RGBColor[
              0.26166747157536735`, 0.3923594816746064, 0.9382129474526586], 
             UndirectedEdge[90, 257] -> 
             RGBColor[
              0.43139340168209683`, 0.5352359922105044, 0.9503841956781767], 
             UndirectedEdge[116, 310] -> 
             RGBColor[
              0.34106730154500287`, 0.46941642630774577`, 0.9429688871981388],
              UndirectedEdge[333, 459] -> 
             RGBColor[
              0.5377348231826343, 0.6224924562848771, 0.9602896367005944], 
             UndirectedEdge[68, 257] -> 
             RGBColor[
              0.4087137818480049, 0.511398273793923, 0.9490926248801159], 
             UndirectedEdge[220, 349] -> 
             RGBColor[
              0.4011979063557851, 0.5219191945174568, 0.9467849537209798], 
             UndirectedEdge[92, 204] -> 
             RGBColor[
              0.32499546103329185`, 0.4478456070348566, 0.9422249149865762], 
             UndirectedEdge[120, 123] -> 
             RGBColor[
              0.33481322031062843`, 0.4644201160564785, 0.9425549802278554], 
             UndirectedEdge[190, 224] -> 
             RGBColor[
              0.929956815143741, 0.9236456632706495, 0.679671724290871], 
             UndirectedEdge[450, 469] -> 
             RGBColor[
              0.3376742854050139, 0.46353834663848936`, 0.9428603064386836], 
             UndirectedEdge[405, 434] -> 
             RGBColor[
              0.5409964579459694, 0.630946933357903, 0.9596802399130044], 
             UndirectedEdge[312, 400] -> 
             RGBColor[
              0.30318296962598673`, 0.4359949023604144, 0.9405771936499658], 
             UndirectedEdge[100, 259] -> 
             RGBColor[
              0.356564323557501, 0.4832598284466828, 0.9439409412930007], 
             UndirectedEdge[87, 423] -> 
             RGBColor[
              0.4858682264490677, 0.5912055386406111, 0.9532993284557889], 
             UndirectedEdge[403, 449] -> 
             RGBColor[
              0.5940673136056046, 0.6773827136842656, 0.9632257204019158], 
             UndirectedEdge[268, 275] -> 
             RGBColor[
              0.30070873485201, 0.43244410764290475`, 0.940471081742474], 
             UndirectedEdge[166, 210] -> 
             RGBColor[
              0.2618820923014311, 0.3925850616654393, 0.9382251697855051], 
             UndirectedEdge[102, 496] -> 
             RGBColor[
              0.25486509448503947`, 0.3852097520570538, 0.9378255621405795], 
             UndirectedEdge[11, 202] -> 
             RGBColor[
              0.251210989037456, 0.3813690555479768, 0.9376174662411043], 
             UndirectedEdge[187, 494] -> 
             RGBColor[
              0.36410430017427065`, 0.4897905772218849, 0.9444213819356817], 
             UndirectedEdge[158, 282] -> 
             RGBColor[
              0.3598217537827987, 0.48608125078463216`, 0.9441485018665242], 
             UndirectedEdge[232, 372] -> 
             RGBColor[
              0.42989871413957137`, 0.5442233725388745, 0.9493197032138938], 
             UndirectedEdge[143, 477] -> 
             RGBColor[
              0.377962978416872, 0.5017942677582043, 0.9453044446585523], 
             UndirectedEdge[479, 482] -> 
             RGBColor[
              0.3027212792929169, 0.43524103190737956`, 0.9405607360001744], 
             UndirectedEdge[45, 283] -> 
             RGBColor[
              0.2997927249179304, 0.4324315402183176, 0.9403841242292597], 
             UndirectedEdge[323, 463] -> 
             RGBColor[
              0.6998569946464631, 0.7597430955997935, 0.8824250714653752], 
             UndirectedEdge[130, 347] -> 
             RGBColor[
              0.29604564375097797`, 0.42849312033318265`, 0.9401707335001115],
              UndirectedEdge[338, 369] -> 
             RGBColor[
              0.3762823644606207, 0.4981124258084891, 0.9453522100789966], 
             UndirectedEdge[143, 386] -> 
             RGBColor[
              0.3310626886772893, 0.45787342932824415`, 0.9424367616360383], 
             UndirectedEdge[168, 254] -> 
             RGBColor[
              0.2684178179928587, 0.3994545237560726, 0.9385973696948922], 
             UndirectedEdge[86, 115] -> 
             RGBColor[
              0.35821355536653343`, 0.48468831014686575`, 0.9440460288855138],
              UndirectedEdge[138, 457] -> 
             RGBColor[
              0.34218325610872913`, 0.47080367063602335`, 0.9430245923918437],
              UndirectedEdge[11, 497] -> 
             RGBColor[
              0.21987149518030644`, 0.3484292604654361, 0.9358327284285659], 
             UndirectedEdge[154, 379] -> 
             RGBColor[
              0.643420557240749, 0.7126182581953804, 0.9329652452184725], 
             UndirectedEdge[17, 467] -> 
             RGBColor[
              0.32072455768852837`, 0.451098252537385, 0.9416982341526885], 
             UndirectedEdge[75, 93] -> 
             RGBColor[
              0.492177918087564, 0.5972988424017914, 0.9535278122906179], 
             UndirectedEdge[100, 315] -> 
             RGBColor[
              0.30516376464058814`, 0.43202550904836073`, 0.9409115659935743],
              UndirectedEdge[45, 52] -> 
             RGBColor[
              0.425645261440888, 0.5392869590038966, 0.9491381539441233], 
             UndirectedEdge[8, 203] -> 
             RGBColor[
              0.27875351441285023`, 0.4074227634282733, 0.9392919809633467], 
             UndirectedEdge[244, 340] -> 
             RGBColor[
              0.44604108996932057`, 0.5580494358944003, 0.9503912880314305], 
             UndirectedEdge[104, 190] -> 
             RGBColor[
              0.6635997185628477, 0.7077315095746958, 0.657115244810303], 
             UndirectedEdge[38, 437] -> 
             RGBColor[
              0.30531160081045855`, 0.4350710502206375, 0.9408141622763769], 
             UndirectedEdge[96, 465] -> 
             RGBColor[
              0.30615140408124764`, 0.4328973265311191, 0.9409738979789259], 
             UndirectedEdge[48, 346] -> 
             RGBColor[
              0.43097971456853806`, 0.5441302069801559, 0.9495114508236946], 
             UndirectedEdge[153, 342] -> 
             RGBColor[
              0.3612338028140416, 0.4873042966838468, 0.9442384763821692], 
             UndirectedEdge[151, 327] -> 
             RGBColor[
              0.48247220128125873`, 0.5890648962462917, 0.9528616667008016], 
             UndirectedEdge[375, 489] -> 
             RGBColor[
              0.3725152888686387, 0.486807537297162, 0.9458063095360766], 
             UndirectedEdge[203, 289] -> 
             RGBColor[
              0.38415844577344693`, 0.507160470189226, 0.9456992143600766], 
             UndirectedEdge[6, 79] -> 
             RGBColor[
              0.45196420823223105`, 0.5607413029691908, 0.9512021187576689], 
             UndirectedEdge[105, 463] -> 
             RGBColor[
              0.6800961396862357, 0.7426272362426937, 0.8811659272611474], 
             UndirectedEdge[10, 125] -> 
             RGBColor[
              0.24430466531632083`, 0.3741100714308487, 0.9372241613221759], 
             UndirectedEdge[32, 331] -> 
             RGBColor[
              0.40491037901135934`, 0.5177818990324965, 0.9479310614290275], 
             UndirectedEdge[26, 44] -> 
             RGBColor[
              0.4357800992129701, 0.5508734448764298, 0.9492645566950246], 
             UndirectedEdge[86, 253] -> 
             RGBColor[
              0.3418845582428895, 0.4684035816944948, 0.943083965741639], 
             UndirectedEdge[370, 466] -> 
             RGBColor[
              0.3421404217794257, 0.4707665696928967, 0.9430218630262572], 
             UndirectedEdge[301, 456] -> 
             RGBColor[
              0.3077472135894752, 0.43762937870489393`, 0.9409529274176538], 
             UndirectedEdge[21, 337] -> 
             RGBColor[
              0.29987896720243773`, 0.43132189795071296`, 0.9404329840370071],
              UndirectedEdge[61, 172] -> 
             RGBColor[
              0.27187887403181193`, 0.40309231309663973`, 0.938794471716137], 
             UndirectedEdge[291, 359] -> 
             RGBColor[
              0.25530759657452556`, 0.38567484980935657`, 0.9378507619799525],
              UndirectedEdge[134, 499] -> 
             RGBColor[
              0.26328626277035033`, 0.3940609338578233, 0.938305135216426], 
             UndirectedEdge[140, 244] -> 
             RGBColor[
              0.4532380921758729, 0.5642831174738672, 0.9508498746479729], 
             UndirectedEdge[108, 364] -> 
             RGBColor[
              0.8022598669112418, 0.8462336217124102, 0.980717679950601], 
             UndirectedEdge[113, 421] -> 
             RGBColor[
              0.2672916289093602, 0.3977751137336001, 0.9385513854065058], 
             UndirectedEdge[54, 55] -> 
             RGBColor[
              0.2714618755020629, 0.4014817224097119, 0.9388136478682185], 
             UndirectedEdge[56, 210] -> 
             RGBColor[
              0.32671560372449127`, 0.4541878113019451, 0.9421568543708015], 
             UndirectedEdge[36, 58] -> 
             RGBColor[
              0.3535655200710639, 0.4806624155909768, 0.9437498601865828], 
             UndirectedEdge[25, 288] -> 
             RGBColor[
              0.3566252650181815, 0.4808226041426076, 0.9440359958463592], 
             UndirectedEdge[262, 344] -> 
             RGBColor[
              0.5516672364559404, 0.6416326624643083, 0.9601114584362991], 
             UndirectedEdge[8, 439] -> 
             RGBColor[
              0.28929247476204933`, 0.41655108117920064`, 0.939963514197561], 
             UndirectedEdge[102, 186] -> 
             RGBColor[
              0.6266441725485762, 0.6918063246208015, 0.8692408376378992], 
             UndirectedEdge[85, 145] -> 
             RGBColor[
              0.3533444726566987, 0.48027507234919076`, 0.9437429474799794], 
             UndirectedEdge[421, 423] -> 
             RGBColor[
              0.41149134993839653`, 0.5186228329126159, 0.9488589209291588], 
             UndirectedEdge[406, 476] -> 
             RGBColor[
              0.29064902597384645`, 0.4214634837194191, 0.9399131069648321], 
             UndirectedEdge[111, 400] -> 
             RGBColor[
              0.3012848465575686, 0.4339998546675534, 0.9404690983492409], 
             UndirectedEdge[137, 183] -> 
             RGBColor[
              0.3514539492844651, 0.4788334791062585, 0.9436153127632494], 
             UndirectedEdge[85, 358] -> 
             RGBColor[
              0.310092100454691, 0.4428120414752482, 0.9409869445698384], 
             UndirectedEdge[399, 412] -> 
             RGBColor[
              0.3628564167416303, 0.48870972331297685`, 0.9443418679068138], 
             UndirectedEdge[283, 292] -> 
             RGBColor[
              0.3208425491694955, 0.45173412075100355`, 0.941686212195384], 
             UndirectedEdge[240, 310] -> 
             RGBColor[
              0.5607575974155735, 0.2855934331466131, 0.5524264476632337], 
             UndirectedEdge[186, 300] -> 
             RGBColor[
              0.6121075325273793, 0.6765273942823127, 0.8684129974937238], 
             UndirectedEdge[37, 240] -> 
             RGBColor[
              0.5928868212725215, 0.3138428125644413, 0.5544582909523453], 
             UndirectedEdge[36, 429] -> 
             RGBColor[
              0.3262165007142266, 0.4547077892259793, 0.9420901844840384], 
             UndirectedEdge[56, 276] -> 
             RGBColor[
              0.4288965327811708, 0.5452321301702874, 0.9487372805691687], 
             UndirectedEdge[95, 174] -> 
             RGBColor[
              0.34425128879280664`, 0.4713025680975572, 0.943203684083055], 
             UndirectedEdge[7, 28] -> 
             RGBColor[
              0.5136147219900808, 0.6040584151782049, 0.9578214506332885], 
             UndirectedEdge[251, 367] -> 
             RGBColor[
              0.2844839021188392, 0.4160338206292609, 0.9395235566433462], 
             UndirectedEdge[31, 314] -> 
             RGBColor[
              0.31523074426139586`, 0.44116436640215095`, 0.9415376707369635],
              UndirectedEdge[238, 436] -> 
             RGBColor[
              0.21145292861051068`, 0.33958081323263134`, 0.9353533035165693],
              UndirectedEdge[291, 488] -> 
             RGBColor[
              0.3025604258047002, 0.434218086128244, 0.940582840309049], 
             UndirectedEdge[96, 171] -> 
             RGBColor[
              0.2576393055684034, 0.38812562380081117`, 0.9379835493576996], 
             UndirectedEdge[127, 179] -> 
             RGBColor[
              0.5232896818464059, 0.6046242577040257, 0.9598738328225749], 
             UndirectedEdge[296, 453] -> 
             RGBColor[
              0.3992322446607311, 0.5195647443252889, 0.9468398234268898], 
             UndirectedEdge[14, 494] -> 
             RGBColor[
              0.3480223550870699, 0.47586120468941406`, 0.943396654615431], 
             UndirectedEdge[317, 420] -> 
             RGBColor[
              0.3226316473857372, 0.45386904985259524`, 0.9417787811728233], 
             UndirectedEdge[7, 388] -> 
             RGBColor[
              0.28209643981984445`, 0.4138316225709498, 0.9393763469722314], 
             UndirectedEdge[146, 271] -> 
             RGBColor[
              0.34549550544588725`, 0.4736725745333774, 0.9432356459907003], 
             UndirectedEdge[331, 449] -> 
             RGBColor[
              0.5262568154449505, 0.6139673222725244, 0.9590763024366363], 
             UndirectedEdge[27, 359] -> 
             RGBColor[
              0.24383178521887305`, 0.3736130444661012, 0.9371972315001897], 
             UndirectedEdge[100, 471] -> 
             RGBColor[
              0.32570315974755126`, 0.4536137155786445, 0.9420812541596038], 
             UndirectedEdge[219, 337] -> 
             RGBColor[
              0.6144290714924342, 0.6862028805250537, 0.9536318504994634], 
             UndirectedEdge[199, 419] -> 
             RGBColor[
              0.27857677110286616`, 0.40696939413859134`, 0.939291713871844], 
             UndirectedEdge[266, 437] -> 
             RGBColor[
              0.2468449055074403, 0.37678002493224577`, 0.9373688242431116], 
             UndirectedEdge[327, 399] -> 
             RGBColor[
              0.44326746423423885`, 0.5551077235035414, 0.9503635755235533], 
             UndirectedEdge[311, 419] -> 
             RGBColor[
              0.2586982881881721, 0.38923868167756415`, 0.938043856851271], 
             UndirectedEdge[267, 329] -> 
             RGBColor[
              0.31094929747263383`, 0.4385760784704879, 0.9412238488950695], 
             UndirectedEdge[219, 244] -> 
             RGBColor[
              0.7519891332420399, 0.8054797455677335, 0.9630420387723697], 
             UndirectedEdge[17, 205] -> 
             RGBColor[
              0.28891926147638114`, 0.4176688696461667, 0.939886969585126], 
             UndirectedEdge[175, 361] -> 
             RGBColor[
              0.2724490300830272, 0.4036915832564485, 0.9388269412597834], 
             UndirectedEdge[189, 266] -> 
             RGBColor[
              0.23791655049118052`, 0.36739575771975286`, 0.9368603676332532],
              UndirectedEdge[225, 280] -> 
             RGBColor[
              0.41100673630594764`, 0.5295079603593071, 0.9476606118442862], 
             UndirectedEdge[300, 458] -> 
             RGBColor[
              0.2517677858944556, 0.381954284347643, 0.9376491749984033], 
             UndirectedEdge[171, 343] -> 
             RGBColor[
              0.357775702470571, 0.4815561026880597, 0.944118928684609], 
             UndirectedEdge[358, 408] -> 
             RGBColor[0.28496769175047, 0.416404694947594, 0.939556146662365],
              UndirectedEdge[380, 411] -> 
             RGBColor[
              0.28050936757309475`, 0.4121635090134235, 0.939285965555642], 
             UndirectedEdge[345, 498] -> 
             RGBColor[
              0.3185338646822634, 0.4459195290061558, 0.9416787879637162], 
             UndirectedEdge[161, 450] -> 
             RGBColor[
              0.28282004044890063`, 0.4145921727110176, 0.9394175549575849], 
             UndirectedEdge[94, 214] -> 
             RGBColor[
              0.5929231359762033, 0.6547959497212261, 0.8134772644790538], 
             UndirectedEdge[157, 343] -> 
             RGBColor[
              0.3897679012863233, 0.5120190986150478, 0.9460566439051104], 
             UndirectedEdge[155, 332] -> 
             RGBColor[
              0.4245990360656712, 0.5406809206244153, 0.9486924847820276], 
             UndirectedEdge[127, 168] -> 
             RGBColor[
              0.5418577463314143, 0.6241404707610545, 0.9609312566260062], 
             UndirectedEdge[378, 380] -> 
             RGBColor[
              0.2440135742982406, 0.37380411631460986`, 0.9372075841193268], 
             UndirectedEdge[160, 481] -> 
             RGBColor[
              0.5431381604024237, 0.6239848926700714, 0.9612316222115498], 
             UndirectedEdge[23, 485] -> 
             RGBColor[
              0.26663457059769397`, 0.39758021767933927`, 0.9384958163938157],
              UndirectedEdge[352, 399] -> 
             RGBColor[
              0.42225100274745697`, 0.5380456132877713, 0.9487090826894787], 
             UndirectedEdge[389, 456] -> 
             RGBColor[
              0.3959218209704525, 0.5173493145404437, 0.9464487662256855], 
             UndirectedEdge[105, 263] -> 
             RGBColor[
              0.3910415265664934, 0.5131222488184632, 0.9461377981817402], 
             UndirectedEdge[143, 347] -> 
             RGBColor[
              0.3417847656515668, 0.4691430120471545, 0.943047368057832], 
             UndirectedEdge[98, 484] -> 
             RGBColor[
              0.4094797432519477, 0.5283618246368615, 0.9475145543109698], 
             UndirectedEdge[100, 500] -> 
             RGBColor[
              0.3630953252822927, 0.4889166538830062, 0.9443570909477663], 
             UndirectedEdge[89, 424] -> 
             RGBColor[
              0.2833628965267994, 0.41516274886795246`, 0.9394484698081377], 
             UndirectedEdge[231, 442] -> 
             RGBColor[
              0.2912355008362285, 0.4234373551491053, 0.9398968029770853], 
             UndirectedEdge[15, 104] -> 
             RGBColor[
              0.6521953306232163, 0.7214643474326813, 0.9517064065810881], 
             UndirectedEdge[75, 182] -> 
             RGBColor[
              0.49570024454064876`, 0.6003497045381783, 0.9537522518175374], 
             UndirectedEdge[290, 316] -> 
             RGBColor[
              0.30779388742542013`, 0.4366171005132307, 0.9409944461098991], 
             UndirectedEdge[344, 424] -> 
             RGBColor[
              0.3033073915112151, 0.4339862889973589, 0.9406626127909132], 
             UndirectedEdge[369, 425] -> 
             RGBColor[
              0.3912479721242028, 0.5129950749402908, 0.946235497731551], 
             UndirectedEdge[106, 255] -> 
             RGBColor[
              0.3865474422847064, 0.5092296988928231, 0.9458514391052674], 
             UndirectedEdge[84, 242] -> 
             RGBColor[
              0.3313360242038651, 0.45563459577065824`, 0.9425448215565846], 
             UndirectedEdge[143, 446] -> 
             RGBColor[
              0.47649443102060396`, 0.5841336944082278, 0.9524126757211311], 
             UndirectedEdge[376, 415] -> 
             RGBColor[
              0.37996796284034684`, 0.5017207158956776, 0.9455862675975427], 
             UndirectedEdge[93, 108] -> 
             RGBColor[
              0.546331825454466, 0.6405691647548029, 0.9582656750939254], 
             UndirectedEdge[78, 183] -> 
             RGBColor[
              0.25652721156879005`, 0.38589009742476, 0.9379592723507795], 
             UndirectedEdge[17, 298] -> 
             RGBColor[
              0.2985184491247238, 0.4277582244882242, 0.9404336291209736], 
             UndirectedEdge[204, 370] -> 
             RGBColor[
              0.2892924917966373, 0.4169214895654772, 0.9399499533577126], 
             UndirectedEdge[208, 314] -> 
             RGBColor[
              0.5813152640937579, 0.6554496475483904, 0.9647179551299669], 
             UndirectedEdge[313, 379] -> 
             RGBColor[
              0.4656010503830478, 0.5731569699269389, 0.9521444596504461], 
             UndirectedEdge[3, 221] -> 
             RGBColor[
              0.6357373235292816, 0.6494327659141227, 0.6109461505451546], 
             UndirectedEdge[154, 229] -> 
             RGBColor[
              0.6167916171676084, 0.6847913138685817, 0.9314428436470084], 
             UndirectedEdge[25, 180] -> 
             RGBColor[
              0.31109354111665805`, 0.4413853133900922, 0.9411347546614768], 
             UndirectedEdge[371, 419] -> 
             RGBColor[
              0.3884985989696934, 0.49920550668072555`, 0.9471171875745903], 
             UndirectedEdge[31, 419] -> 
             RGBColor[
              0.30199676831772854`, 0.4272546186028187, 0.9407840153848845], 
             UndirectedEdge[321, 482] -> 
             RGBColor[
              0.2896153374659164, 0.42173446072261656`, 0.939804537069963], 
             UndirectedEdge[212, 300] -> 
             RGBColor[
              0.27872768374977847`, 0.4088661679441157, 0.9392366657530624], 
             UndirectedEdge[376, 414] -> 
             RGBColor[
              0.5103921235054778, 0.61339834462171, 0.9545990840717544], 
             UndirectedEdge[140, 274] -> 
             RGBColor[
              0.30474551715256903`, 0.43351548781915394`, 0.9408170959173334],
              UndirectedEdge[1, 131] -> 
             RGBColor[
              0.3657086817370868, 0.4892012098580777, 0.9445960726690463], 
             UndirectedEdge[360, 466] -> 
             RGBColor[
              0.2736004787646523, 0.4032003837901173, 0.9389548127963174], 
             UndirectedEdge[165, 182] -> 
             RGBColor[
              0.41487553486859885`, 0.5337660688776582, 0.9476564801151643], 
             UndirectedEdge[268, 480] -> 
             RGBColor[
              0.28268091829885256`, 0.4134957294159486, 0.9394444242595361], 
             UndirectedEdge[54, 385] -> 
             RGBColor[
              0.2505229762547404, 0.38064591049081276`, 0.9375782849309523], 
             UndirectedEdge[149, 158] -> 
             RGBColor[
              0.3057435922886259, 0.4352950730234383, 0.9408471859903587], 
             UndirectedEdge[229, 379] -> 
             RGBColor[
              0.2838666338405068, 0.4155304486610609, 0.9394830797312261], 
             UndirectedEdge[98, 253] -> 
             RGBColor[
              0.38290681803172033`, 0.5032043205420267, 0.9458997571271306], 
             UndirectedEdge[121, 469] -> 
             RGBColor[
              0.34567544870222855`, 0.4719480765669155, 0.9433159608517996], 
             UndirectedEdge[34, 269] -> 
             RGBColor[
              0.6430055992835686, 0.7169398592449272, 0.9676068491258347], 
             UndirectedEdge[145, 286] -> 
             RGBColor[
              0.3189535270538117, 0.44412800800866487`, 0.9417844340047397], 
             UndirectedEdge[34, 234] -> 
             RGBColor[
              0.3666080391266834, 0.49195919006088606`, 0.94458091796776], 
             UndirectedEdge[85, 286] -> 
             RGBColor[
              0.272236410742538, 0.40346810684874956`, 0.9388148329028847], 
             UndirectedEdge[86, 261] -> 
             RGBColor[
              0.5903040394621039, 0.6746317976286214, 0.9627706461358841], 
             UndirectedEdge[140, 255] -> 
             RGBColor[
              0.3553117527875909, 0.48217491460182416`, 0.9438611285911469], 
             UndirectedEdge[345, 448] -> 
             RGBColor[
              0.45344716303890265`, 0.5650661593676147, 0.9506968744375682], 
             UndirectedEdge[146, 444] -> 
             RGBColor[
              0.3076175343791855, 0.43609799127953197`, 0.9409966233238616], 
             UndirectedEdge[215, 224] -> 
             RGBColor[
              0.683733986219305, 0.7509592257251811, 0.9706175749350426], 
             UndirectedEdge[40, 359] -> 
             RGBColor[
              0.34909474011952596`, 0.46867277911532446`, 0.9438825371442117],
              UndirectedEdge[88, 495] -> 
             RGBColor[
              0.4137976712512682, 0.5268515336433193, 0.9484618907373266], 
             UndirectedEdge[341, 403] -> 
             RGBColor[
              0.3503546787669288, 0.4777176179376347, 0.9435512631129249], 
             UndirectedEdge[134, 416] -> 
             RGBColor[
              0.22496748076533807`, 0.3537854644194521, 0.9361229372687985], 
             UndirectedEdge[113, 423] -> 
             RGBColor[
              0.4583072922344167, 0.567333642676712, 0.9515431700988085], 
             UndirectedEdge[204, 362] -> 
             RGBColor[
              0.2809126961667361, 0.4096633317716315, 0.9394160001901376], 
             UndirectedEdge[231, 256] -> 
             RGBColor[
              0.2920075510848489, 0.4242488289112184, 0.9399407700965983], 
             UndirectedEdge[183, 407] -> 
             RGBColor[
              0.2703332445833678, 0.40040111347613233`, 0.9387455055067642], 
             UndirectedEdge[231, 271] -> 
             RGBColor[
              0.3112386194183332, 0.4422243351105336, 0.9411178792384007], 
             UndirectedEdge[106, 140] -> 
             RGBColor[
              0.38456196494817213`, 0.5075099782169097, 0.9457249262450721], 
             UndirectedEdge[96, 147] -> 
             RGBColor[
              0.24445536526519, 0.37426846663203883`, 0.9372327434613235], 
             UndirectedEdge[149, 275] -> 
             RGBColor[
              0.2742282180464253, 0.4055616226130122, 0.9389282633822262], 
             UndirectedEdge[207, 287] -> 
             RGBColor[
              0.303960002420425, 0.4309419239948868, 0.9408363625893968], 
             UndirectedEdge[223, 480] -> 
             RGBColor[
              0.33275509709338474`, 0.4568674662863669, 0.9426351066534661], 
             UndirectedEdge[11, 102] -> 
             RGBColor[
              0.25216503545750457`, 0.3823718188254846, 0.9376717977733409], 
             UndirectedEdge[230, 339] -> 
             RGBColor[
              0.2890272317706877, 0.42062933535469244`, 0.9397888763732958], 
             UndirectedEdge[103, 449] -> 
             RGBColor[
              0.594783820763033, 0.6780033161713332, 0.9632713756044047], 
             UndirectedEdge[226, 396] -> 
             RGBColor[
              0.3320396530024754, 0.46027377174644646`, 0.94244210807647], 
             UndirectedEdge[144, 279] -> 
             RGBColor[
              0.28480399851246496`, 0.4166774384260302, 0.939530538434302], 
             UndirectedEdge[205, 228] -> 
             RGBColor[
              0.4720501117549981, 0.5682365796465204, 0.9542092301680302], 
             UndirectedEdge[267, 406] -> 
             RGBColor[
              0.2881047029269041, 0.41878923887768416`, 0.9397682115312973], 
             UndirectedEdge[209, 233] -> 
             RGBColor[
              0.3058018975757784, 0.4383688658217048, 0.9407402036330024], 
             UndirectedEdge[387, 405] -> 
             RGBColor[
              0.2490740842091546, 0.3791230330858405, 0.9374957726723999], 
             UndirectedEdge[75, 206] -> 
             RGBColor[
              0.4204024374291999, 0.5307560937886613, 0.9491145116186301], 
             UndirectedEdge[183, 404] -> 
             RGBColor[
              0.46364996118858387`, 0.5718387307526979, 0.9519174371988104], 
             UndirectedEdge[319, 488] -> 
             RGBColor[
              0.2879103505401459, 0.4188199281567767, 0.939748540195577], 
             UndirectedEdge[220, 371] -> 
             RGBColor[
              0.46925723795808316`, 0.5778961168654966, 0.9519429861793023], 
             UndirectedEdge[66, 460] -> 
             RGBColor[
              0.5811756149797052, 0.6534615991286046, 0.9644063751082086], 
             UndirectedEdge[87, 446] -> 
             RGBColor[
              0.4665832209481138, 0.5755491023953394, 0.951781142179451], 
             UndirectedEdge[273, 308] -> 
             RGBColor[
              0.43840864773892935`, 0.5535477309677919, 0.9493221958528526], 
             UndirectedEdge[326, 428] -> 
             RGBColor[
              0.3889120805242967, 0.505502807150351, 0.9466070748507651], 
             UndirectedEdge[130, 315] -> 
             RGBColor[
              0.2668523845913057, 0.39780915399683003`, 0.9385082205785249], 
             UndirectedEdge[95, 407] -> 
             RGBColor[
              0.2575760826012077, 0.38805917245372085`, 0.9379799489032479], 
             UndirectedEdge[148, 153] -> 
             RGBColor[
              0.35030618119135337`, 0.47615389575093886`, 0.9436038903682535],
              UndirectedEdge[85, 137] -> 
             RGBColor[
              0.3446262864807904, 0.472723817672397, 0.9431874323660399], 
             UndirectedEdge[289, 359] -> 
             RGBColor[
              0.3273187134845432, 0.45031354029262577`, 0.9423562670454434], 
             UndirectedEdge[32, 449] -> 
             RGBColor[
              0.673053971180459, 0.7431254799455642, 0.9689968255956235], 
             UndirectedEdge[329, 406] -> 
             RGBColor[
              0.346272572362378, 0.4743456308399229, 0.9432851600074857], 
             UndirectedEdge[168, 213] -> 
             RGBColor[
              0.28242766492459326`, 0.4128636375727418, 0.9394433994835509], 
             UndirectedEdge[111, 464] -> 
             RGBColor[
              0.5152122474075225, 0.6111667281410966, 0.957052903335798], 
             UndirectedEdge[50, 117] -> 
             RGBColor[
              0.45167399936981156`, 0.5593246276040965, 0.9512867808574422], 
             UndirectedEdge[357, 420] -> 
             RGBColor[
              0.466012623457292, 0.5741615056609433, 0.9519916260731318], 
             UndirectedEdge[153, 190] -> 
             RGBColor[
              0.6942735671745219, 0.7342996555296695, 0.6590697553200197], 
             UndirectedEdge[165, 275] -> 
             RGBColor[
              0.3500583893973531, 0.4751882980243231, 0.9436155980919171], 
             UndirectedEdge[152, 301] -> 
             RGBColor[
              0.27843163226158063`, 0.4099796774649948, 0.9391676416033852], 
             UndirectedEdge[208, 349] -> 
             RGBColor[
              0.6743217717484784, 0.74230160298026, 0.9704137789884386], 
             UndirectedEdge[5, 23] -> 
             RGBColor[
              0.29367680983442346`, 0.42600332569413885`, 0.9400358319129396],
              UndirectedEdge[56, 227] -> 
             RGBColor[
              0.3271188137728493, 0.45461161062776295`, 0.9421798165865597], 
             UndirectedEdge[56, 326] -> 
             RGBColor[
              0.4466397787084002, 0.5596368965381322, 0.9501340938842116], 
             UndirectedEdge[155, 181] -> 
             RGBColor[
              0.34125940270748706`, 0.4700034752540896, 0.9429657252700478], 
             UndirectedEdge[148, 323] -> 
             RGBColor[
              0.3501793422278554, 0.47604403421586855`, 0.9435958083016587], 
             UndirectedEdge[177, 438] -> 
             RGBColor[
              0.3545036815959094, 0.47734174525124284`, 0.9439609778576077], 
             UndirectedEdge[53, 90] -> 
             RGBColor[
              0.30650463272540424`, 0.43209175840193825`, 0.9410371034790416],
              UndirectedEdge[30, 217] -> 
             RGBColor[
              0.2423632923430884, 0.3720695653458256, 0.9371136030033543], 
             UndirectedEdge[43, 290] -> 
             RGBColor[
              0.2669309377439225, 0.39789171834078785`, 0.9385126940643576], 
             UndirectedEdge[114, 397] -> 
             RGBColor[
              0.3135199697892778, 0.4390024689424814, 0.9414535638809735], 
             UndirectedEdge[227, 320] -> 
             RGBColor[
              0.2794586224864525, 0.41105910930627615`, 0.9392261271773958], 
             UndirectedEdge[298, 432] -> 
             RGBColor[
              0.28260547627277083`, 0.4139752072131336, 0.9394196685621365], 
             UndirectedEdge[42, 85] -> 
             RGBColor[
              0.29742784384298204`, 0.42994590026642643`, 0.9402494477505694],
              UndirectedEdge[329, 413] -> 
             RGBColor[
              0.3077950390489783, 0.4352607528756909, 0.9410442185441494], 
             UndirectedEdge[244, 380] -> 
             RGBColor[
              0.40410341061947747`, 0.5167612029022863, 0.9479008097242729], 
             UndirectedEdge[87, 113] -> 
             RGBColor[
              0.34166850542003135`, 0.4703578194615953, 0.942991792933136], 
             UndirectedEdge[334, 370] -> 
             RGBColor[
              0.29538922453996064`, 0.4233295422338923, 0.940297153268137], 
             UndirectedEdge[24, 278] -> 
             RGBColor[
              0.31226052722091924`, 0.44454857231584927`, 0.941130301358887], 
             UndirectedEdge[51, 325] -> 
             RGBColor[
              0.3726641020379375, 0.4926509453706428, 0.9452971184782535], 
             UndirectedEdge[112, 463] -> 
             RGBColor[
              0.6145706160134258, 0.6794487396789799, 0.877225897615195], 
             UndirectedEdge[308, 421] -> 
             RGBColor[
              0.31091040948959414`, 0.43555550912854146`, 0.9413307355345051],
              UndirectedEdge[302, 421] -> 
             RGBColor[
              0.2687726143654902, 0.39905786889920647`, 0.9386457524901864], 
             UndirectedEdge[103, 488] -> 
             RGBColor[
              0.3580269265985695, 0.48452666168829006`, 0.9440341370654486], 
             UndirectedEdge[225, 424] -> 
             RGBColor[
              0.3807285418658017, 0.500137448479488, 0.945846468183162], 
             UndirectedEdge[205, 388] -> 
             RGBColor[
              0.26967778485182714`, 0.40077882881136123`, 0.9386691229435565],
              UndirectedEdge[114, 297] -> 
             RGBColor[
              0.2639118754450406, 0.3947184924450573, 0.9383407629327385], 
             UndirectedEdge[203, 381] -> 
             RGBColor[
              0.35303320910976055`, 0.48020135459102264`, 0.9437159418028326],
              UndirectedEdge[17, 252] -> 
             RGBColor[
              0.3185840205852023, 0.4488484123238982, 0.941576333731295], 
             UndirectedEdge[361, 363] -> 
             RGBColor[
              0.29422347506578705`, 0.42657790551287955`, 0.940066963689147], 
             UndirectedEdge[318, 383] -> 
             RGBColor[
              0.6067645960709813, 0.6847584324853855, 0.9656618792988687], 
             UndirectedEdge[209, 273] -> 
             RGBColor[
              0.39415704195585155`, 0.5152192141888666, 0.9465025226625134], 
             UndirectedEdge[47, 230] -> 
             RGBColor[
              0.28544585881572815`, 0.41735207430105353`, 0.9395670914290256],
              UndirectedEdge[1, 170] -> 
             RGBColor[
              0.2650875208181135, 0.3959541702723789, 0.9384077141975236], 
             UndirectedEdge[139, 247] -> 
             RGBColor[
              0.37039494330357453`, 0.4942309502704323, 0.9448591337052794], 
             UndirectedEdge[246, 288] -> 
             RGBColor[
              0.38078698247310544`, 0.5042402781331429, 0.9454843876998468], 
             UndirectedEdge[1, 147] -> 
             RGBColor[
              0.2699719373050877, 0.40108800169008085`, 0.9386858744906101], 
             UndirectedEdge[352, 457] -> 
             RGBColor[
              0.44025217643760994`, 0.553637325172885, 0.9498561015592024], 
             UndirectedEdge[157, 238] -> 
             RGBColor[
              0.2664451896997654, 0.3942183328972453, 0.9386008382580037], 
             UndirectedEdge[97, 145] -> 
             RGBColor[
              0.5038277048414879, 0.6066230174060333, 0.9544818531597358], 
             UndirectedEdge[83, 237] -> 
             RGBColor[
              0.2916877781833416, 0.4239127273169612, 0.939922559502919], 
             UndirectedEdge[73, 494] -> 
             RGBColor[
              0.3291083802885476, 0.45947887036294865`, 0.9421914728662404], 
             UndirectedEdge[101, 197] -> 
             RGBColor[
              0.2681419546603289, 0.3991645739028382, 0.9385816596862078], 
             UndirectedEdge[224, 356] -> 
             RGBColor[
              0.6181000910497092, 0.6949979892130635, 0.9661902099473715], 
             UndirectedEdge[182, 441] -> 
             RGBColor[
              0.6505362425309513, 0.7228318286831341, 0.9683770387173412], 
             UndirectedEdge[160, 480] -> 
             RGBColor[
              0.23946865423990188`, 0.36902711716872055`, 0.9369487576456111],
              UndirectedEdge[263, 440] -> 
             RGBColor[
              0.34567942967484966`, 0.4711367922368519, 0.9433460458618583], 
             UndirectedEdge[31, 223] -> 
             RGBColor[
              0.40448326195275963`, 0.5247648044087825, 0.9469942936744932], 
             UndirectedEdge[5, 102] -> 
             RGBColor[
              0.28026954201901066`, 0.4119114371502628, 0.939272307845127], 
             UndirectedEdge[171, 216] -> 
             RGBColor[
              0.309702874890453, 0.43991783564873005`, 0.9410557706203362], 
             UndirectedEdge[102, 414] -> 
             RGBColor[
              0.40817536483910366`, 0.5209421331293187, 0.9481417087046108], 
             UndirectedEdge[68, 205] -> 
             RGBColor[
              0.205979882097505, 0.333828294336271, 0.9350416216143004], 
             UndirectedEdge[111, 376] -> 
             RGBColor[
              0.38405502408838227`, 0.5060164764020129, 0.945819019689353], 
             UndirectedEdge[302, 325] -> 
             RGBColor[
              0.2919724289045328, 0.4234423449329402, 0.939966947607135], 
             UndirectedEdge[39, 315] -> 
             RGBColor[
              0.2860906575269004, 0.4155053423087217, 0.9396962444739765], 
             UndirectedEdge[66, 314] -> 
             RGBColor[
              0.5885072488706664, 0.661167611200442, 0.9648239008121184], 
             UndirectedEdge[274, 370] -> 
             RGBColor[
              0.30664850699358903`, 0.43516376197239504`, 0.9409383527472555],
              UndirectedEdge[94, 477] -> 
             RGBColor[
              0.6809168976768599, 0.7419086326588826, 0.818685159937407], 
             UndirectedEdge[99, 329] -> 
             RGBColor[
              0.38008592294165355`, 0.5036330556032759, 0.9454397168064252], 
             UndirectedEdge[25, 465] -> 
             RGBColor[
              0.3289044880954653, 0.45681226045891066`, 0.9422696524533642], 
             UndirectedEdge[223, 381] -> 
             RGBColor[
              0.3925888819280047, 0.5144624902602626, 0.946236394297103], 
             UndirectedEdge[196, 318] -> 
             RGBColor[
              0.577337806274203, 0.6548524148567461, 0.9639485953114322], 
             UndirectedEdge[76, 462] -> 
             RGBColor[
              0.3572359776004085, 0.4838415814203355, 0.9439837384946945], 
             UndirectedEdge[89, 440] -> 
             RGBColor[
              0.28579632113289133`, 0.4177204324169864, 0.9395870497395256], 
             UndirectedEdge[88, 326] -> 
             RGBColor[
              0.5338800516803069, 0.6324669028331424, 0.9564481398167928], 
             UndirectedEdge[149, 282] -> 
             RGBColor[
              0.3201405413330086, 0.4477649866739837, 0.9417645468527446], 
             UndirectedEdge[238, 462] -> 
             RGBColor[
              0.29607225267124365`, 0.41987980574365735`, 0.9404886485123631],
              UndirectedEdge[168, 261] -> 
             RGBColor[
              0.512149255725568, 0.6007553087467574, 0.9580170729479197], 
             UndirectedEdge[155, 344] -> 
             RGBColor[
              0.3361289941993333, 0.46555977326615605`, 0.9426388201765505], 
             UndirectedEdge[4, 496] -> 
             RGBColor[
              0.26560959332889844`, 0.3965029015825229, 0.9384374454546758], 
             UndirectedEdge[87, 226] -> 
             RGBColor[
              0.32955618478129156`, 0.4581227163959992, 0.9422838636774609], 
             UndirectedEdge[128, 362] -> 
             RGBColor[
              0.3221403057227522, 0.4529961633964267, 0.94176385156357], 
             UndirectedEdge[295, 389] -> 
             RGBColor[
              0.3471959690793936, 0.4692981882564244, 0.9435580942177668], 
             UndirectedEdge[89, 133] -> 
             RGBColor[
              0.2982071099937901, 0.4307649583992533, 0.940293825805037], 
             UndirectedEdge[33, 164] -> 
             RGBColor[
              0.3054992681095394, 0.4364087838516393, 0.9407830909673287], 
             UndirectedEdge[276, 396] -> 
             RGBColor[
              0.4262463928426651, 0.54293671215546, 0.9485684159957137], 
             UndirectedEdge[50, 274] -> 
             RGBColor[
              0.2720956815741542, 0.40332019157003357`, 0.9388068185849354], 
             UndirectedEdge[21, 375] -> 
             RGBColor[
              0.42386376141541704`, 0.5395777492483262, 0.9487744775215867], 
             UndirectedEdge[41, 485] -> 
             RGBColor[
              0.2542787452309451, 0.38459346181431076`, 0.9377921704179849], 
             UndirectedEdge[30, 316] -> 
             RGBColor[
              0.31417369355219393`, 0.4433226812555414, 0.9413577666307416], 
             UndirectedEdge[285, 324] -> 
             RGBColor[
              0.3062379272124951, 0.4367158119329242, 0.9408423416937415], 
             UndirectedEdge[95, 358] -> 
             RGBColor[
              0.30416260127620554`, 0.4365797618866982, 0.9406492683635317], 
             UndirectedEdge[333, 492] -> 
             RGBColor[
              0.5698467996389806, 0.6552939624628844, 0.9621531583569551], 
             UndirectedEdge[332, 393] -> 
             RGBColor[
              0.37277586190860784`, 0.48913557997254153`, 0.9456341660115397],
              UndirectedEdge[418, 420] -> 
             RGBColor[
              0.5839212613612437, 0.6670723613662444, 0.9632397254324393], 
             UndirectedEdge[107, 273] -> 
             RGBColor[
              0.39451628705407255`, 0.515530374236762, 0.9465254134425041], 
             UndirectedEdge[310, 483] -> 
             RGBColor[
              0.28630346384449123`, 0.4182534715615829, 0.9396159307667007], 
             UndirectedEdge[155, 403] -> 
             RGBColor[
              0.3670534417352266, 0.49234497541382016`, 0.9446092986281224], 
             UndirectedEdge[140, 169] -> 
             RGBColor[
              0.3309391297927208, 0.4610466354749164, 0.9423087834072128], 
             UndirectedEdge[147, 216] -> 
             RGBColor[
              0.2965189345872396, 0.42606067847995766`, 0.9403049647239601], 
             UndirectedEdge[70, 171] -> 
             RGBColor[
              0.27767774128230094`, 0.40918729024632294`, 0.939124708627397], 
             UndirectedEdge[7, 402] -> 
             RGBColor[
              0.29064902597384645`, 0.4214634837194191, 0.9399131069648321], 
             UndirectedEdge[185, 409] -> 
             RGBColor[
              0.28212093149183687`, 0.4123020923990316, 0.9394346878806112], 
             UndirectedEdge[126, 481] -> 
             RGBColor[
              0.5807635378157233, 0.6635315499181622, 0.9633743317934794], 
             UndirectedEdge[115, 311] -> 
             RGBColor[
              0.31072050610601804`, 0.4430392482655492, 0.9410385961159875], 
             UndirectedEdge[383, 496] -> 
             RGBColor[
              0.28358582807685284`, 0.414373659847726, 0.9394986372716598], 
             UndirectedEdge[8, 297] -> 
             RGBColor[
              0.255979799256821, 0.3863813774485608, 0.9378890429282747], 
             UndirectedEdge[381, 439] -> 
             RGBColor[
              0.3635721694589597, 0.48932967234195, 0.9443874750370469], 
             UndirectedEdge[16, 276] -> 
             RGBColor[
              0.3724533139658998, 0.4924481100398449, 0.9452834107355602], 
             UndirectedEdge[74, 342] -> 
             RGBColor[
              0.41307730887542105`, 0.5305667720675882, 0.9479955229845809], 
             UndirectedEdge[26, 269] -> 
             RGBColor[
              0.6804090764697046, 0.748337764287764, 0.9702662218425566], 
             UndirectedEdge[127, 315] -> 
             RGBColor[
              0.5389861611058296, 0.621122252619946, 0.9607677240955388], 
             UndirectedEdge[175, 348] -> 
             RGBColor[
              0.3419293150470283, 0.46429104682425004`, 0.9432388170695807], 
             UndirectedEdge[180, 288] -> 
             RGBColor[
              0.3859043877748176, 0.5086727173972168, 0.9458104642405281], 
             UndirectedEdge[288, 343] -> 
             RGBColor[
              0.43400857790613145`, 0.5503381491020646, 0.9488756206988302], 
             UndirectedEdge[484, 500] -> 
             RGBColor[
              0.3453626751427009, 0.4735575236010027, 0.9432271821612384], 
             UndirectedEdge[59, 323] -> 
             RGBColor[
              0.46995119613448955`, 0.5793861083486719, 0.9517415933941104], 
             UndirectedEdge[108, 189] -> 
             RGBColor[
              0.4687547948632683, 0.5679286193227534, 0.9535219847358868], 
             UndirectedEdge[59, 74] -> 
             RGBColor[
              0.521921541159367, 0.6227584452674836, 0.955506722063117], 
             UndirectedEdge[40, 199] -> 
             RGBColor[
              0.4073816389255014, 0.5267731719123082, 0.9473176966296336], 
             UndirectedEdge[69, 241] -> 
             RGBColor[
              0.6900832026301509, 0.7498480252975406, 0.8192692287835854], 
             UndirectedEdge[275, 353] -> 
             RGBColor[
              0.31631700106136956`, 0.44596320333918216`, 0.9414656266634864],
              UndirectedEdge[196, 335] -> 
             RGBColor[
              0.2513671043472517, 0.38153314263685434`, 0.9376263567770453], 
             UndirectedEdge[157, 281] -> 
             RGBColor[
              0.3180589349367964, 0.44846765164182356`, 0.9415401646935591], 
             UndirectedEdge[120, 438] -> 
             RGBColor[
              0.39546739365600553`, 0.5169557124408507, 0.9464198105190433], 
             UndirectedEdge[152, 389] -> 
             RGBColor[
              0.3666062396425579, 0.4896996133005446, 0.9446634804114169], 
             UndirectedEdge[126, 144] -> 
             RGBColor[
              0.29660008979856445`, 0.4290758782831059, 0.9402023083822921], 
             UndirectedEdge[96, 157] -> 
             RGBColor[
              0.2896315043841557, 0.4185886197277993, 0.939921264578201], 
             UndirectedEdge[303, 366] -> 
             RGBColor[
              0.4501568676446767, 0.5597614502642987, 0.9510154695756985], 
             UndirectedEdge[119, 309] -> 
             RGBColor[
              0.24366492690365796`, 0.3734376657973819, 0.9371877291659829], 
             UndirectedEdge[325, 386] -> 
             RGBColor[
              0.26997441663317046`, 0.40109060762109433`, 0.9386860156846766],
              UndirectedEdge[27, 220] -> 
             RGBColor[
              0.31849933567937955`, 0.44590153441074865`, 0.9416761516241968],
              UndirectedEdge[95, 346] -> 
             RGBColor[
              0.4276365077485519, 0.5406162846407951, 0.9493210601411277], 
             UndirectedEdge[235, 239] -> 
             RGBColor[
              0.28598894280573905`, 0.4160060077202479, 0.9396682057094732], 
             UndirectedEdge[64, 303] -> 
             RGBColor[
              0.28433564970423, 0.41618517413354567`, 0.939503866662533], 
             UndirectedEdge[310, 429] -> 
             RGBColor[
              0.2942152135777121, 0.4265692221651041, 0.9400664932096228], 
             UndirectedEdge[67, 238] -> 
             RGBColor[
              0.29605830464663824`, 0.41986772466579225`, 0.9404877597565691],
              UndirectedEdge[38, 108] -> 
             RGBColor[
              0.5153084075495258, 0.6136982394478657, 0.956288890337954], 
             UndirectedEdge[20, 490] -> 
             RGBColor[
              0.4195516853272835, 0.5360782238266332, 0.9484346801608439], 
             UndirectedEdge[112, 148] -> 
             RGBColor[
              0.26489296359481806`, 0.39574967829505486`, 0.9383966344514785],
              UndirectedEdge[76, 402] -> 
             RGBColor[
              0.3178455243188919, 0.4497235506096337, 0.9414738136432064], 
             UndirectedEdge[99, 406] -> 
             RGBColor[
              0.3572413283959238, 0.4838462160104721, 0.9439840794426532], 
             UndirectedEdge[8, 258] -> 
             RGBColor[
              0.23357972475790012`, 0.3628374789034422, 0.9366133918235017], 
             UndirectedEdge[15, 153] -> 
             RGBColor[
              0.6828691792348905, 0.748032493387655, 0.9536609170908047], 
             UndirectedEdge[195, 463] -> 
             RGBColor[
              0.7908299155320612, 0.8347794806483576, 0.8892606257772806], 
             UndirectedEdge[184, 249] -> 
             RGBColor[
              0.2743983141154176, 0.4057404043662368, 0.9389379501017208], 
             UndirectedEdge[109, 185] -> 
             RGBColor[
              0.40784097410123066`, 0.5266739789658998, 0.947484300348503], 
             UndirectedEdge[77, 81] -> 
             RGBColor[
              0.24891877333776088`, 0.3789597915127277, 0.9374869279480358], 
             UndirectedEdge[355, 384] -> 
             RGBColor[
              0.39823122601043914`, 0.5193496051120079, 0.9465959194727067], 
             UndirectedEdge[67, 343] -> 
             RGBColor[
              0.41938101623319624`, 0.5376684903835948, 0.9479435654036756], 
             UndirectedEdge[247, 255] -> 
             RGBColor[
              0.3275689847631301, 0.4571372574779622, 0.9421303014965905], 
             UndirectedEdge[95, 145] -> 
             RGBColor[
              0.34741497347821326`, 0.47404279276064065`, 0.9434052712736726],
              UndirectedEdge[220, 416] -> 
             RGBColor[
              0.3011294821913949, 0.42764471708255686`, 0.9406869641644515], 
             UndirectedEdge[287, 451] -> 
             RGBColor[
              0.30043229914884534`, 0.4278864047285664, 0.9406115804563573], 
             UndirectedEdge[387, 491] -> 
             RGBColor[
              0.4178173850548148, 0.5212536132615481, 0.9495849484414667], 
             UndirectedEdge[211, 464] -> 
             RGBColor[
              0.8370950332181346, 0.8734336657171288, 0.9757522141855481], 
             UndirectedEdge[335, 482] -> 
             RGBColor[
              0.2677820810916225, 0.3987863239648257, 0.9385611654188553], 
             UndirectedEdge[214, 423] -> 
             RGBColor[
              0.3966967934581105, 0.5030728160227764, 0.9480163928241915], 
             UndirectedEdge[69, 194] -> 
             RGBColor[
              0.3612245737960048, 0.48729630297228727`, 0.9442378883173007], 
             UndirectedEdge[111, 312] -> 
             RGBColor[
              0.30320112613210215`, 0.4360139859995307, 0.940578227636129], 
             UndirectedEdge[174, 294] -> 
             RGBColor[
              0.3840102807677756, 0.5070321371083033, 0.9456897734169324], 
             UndirectedEdge[212, 295] -> 
             RGBColor[
              0.28482908720811273`, 0.4152791298301478, 0.939584131653797], 
             UndirectedEdge[193, 414] -> 
             RGBColor[
              0.4322778163259624, 0.5461059170822871, 0.9495205109837499], 
             UndirectedEdge[320, 348] -> 
             RGBColor[
              0.3636747805582836, 0.48714690981872516`, 0.9444771891609133], 
             UndirectedEdge[247, 468] -> 
             RGBColor[
              0.2974579887401173, 0.4299775844646125, 0.9402511644578659], 
             UndirectedEdge[449, 488] -> 
             RGBColor[
              0.5576435134495867, 0.645834248702549, 0.9609048280642761], 
             UndirectedEdge[290, 355] -> 
             RGBColor[
              0.3101343104062332, 0.4386442572661316, 0.9411435757926818], 
             UndirectedEdge[88, 469] -> 
             RGBColor[
              0.47845988043843396`, 0.5861064998384764, 0.9524631912718008], 
             UndirectedEdge[6, 278] -> 
             RGBColor[
              0.45556133547477073`, 0.56452211177214, 0.9514069698326586], 
             UndirectedEdge[24, 448] -> 
             RGBColor[
              0.4252030701502141, 0.5406025456968178, 0.9488971858139716], 
             UndirectedEdge[204, 274] -> 
             RGBColor[
              0.23880874365712967`, 0.36833350930547937`, 0.9369111767141725],
              UndirectedEdge[81, 99] -> 
             RGBColor[
              0.3266019731905958, 0.45299976020701915`, 0.9421895106270262], 
             UndirectedEdge[213, 368] -> 
             RGBColor[
              0.3058099067634874, 0.43743985626517845`, 0.9407749835653489], 
             UndirectedEdge[167, 474] -> 
             RGBColor[
              0.4246726614627325, 0.5291269962624991, 0.94991453596617], 
             UndirectedEdge[78, 430] -> 
             RGBColor[
              0.24712674009351965`, 0.37707625095156, 0.9373848743058519], 
             UndirectedEdge[110, 316] -> 
             RGBColor[
              0.42446521090702255`, 0.5409540738795318, 0.9485764574990325], 
             UndirectedEdge[153, 463] -> 
             RGBColor[
              0.6999838336099611, 0.7598529571348638, 0.88243315353197], 
             UndirectedEdge[471, 475] -> 
             RGBColor[
              0.3591067248360497, 0.48254620474630394`, 0.94420969978943], 
             UndirectedEdge[79, 486] -> 
             RGBColor[
              0.43342549778997264`, 0.5456907426727773, 0.9497426835621203], 
             UndirectedEdge[49, 402] -> 
             RGBColor[
              0.6592201303805761, 0.7231494468689952, 0.8201627428268425], 
             UndirectedEdge[340, 498] -> 
             RGBColor[
              0.30004301733430705`, 0.4299036864103666, 0.9405005675215188], 
             UndirectedEdge[248, 313] -> 
             RGBColor[
              0.41276088977412323`, 0.5177803709296632, 0.9491293678454951], 
             UndirectedEdge[37, 429] -> 
             RGBColor[
              0.32634443743466, 0.4548186015829323, 0.9420983364987345], 
             UndirectedEdge[18, 166] -> 
             RGBColor[
              0.33714486689776374`, 0.4609924504694062, 0.9429030001191514], 
             UndirectedEdge[147, 238] -> 
             RGBColor[
              0.22126905058079965`, 0.3498981798014848, 0.9359123171411261], 
             UndirectedEdge[165, 441] -> 
             RGBColor[
              0.6533834302030441, 0.7252979195408875, 0.9685584589981376], 
             UndirectedEdge[13, 154] -> 
             RGBColor[
              0.7522740938963408, 0.8048684267674661, 0.9404631014376473], 
             UndirectedEdge[133, 249] -> 
             RGBColor[
              0.2930013209796535, 0.4252933440793085, 0.9399973638219565], 
             UndirectedEdge[84, 385] -> 
             RGBColor[
              0.3479608527394017, 0.47310834463651674`, 0.9434915809474536], 
             UndirectedEdge[125, 438] -> 
             RGBColor[
              0.3311206065630865, 0.4527646508191596, 0.942629346326648], 
             UndirectedEdge[21, 489] -> 
             RGBColor[
              0.2703796764566195, 0.4003162730137977, 0.9387530430693227], 
             UndirectedEdge[16, 200] -> 
             RGBColor[
              0.3154587217188305, 0.44376048125032774`, 0.9414643708506191], 
             UndirectedEdge[402, 436] -> 
             RGBColor[
              0.2781991070374319, 0.4083778295467949, 0.9392041024994078], 
             UndirectedEdge[127, 401] -> 
             RGBColor[
              0.5458354010577371, 0.6283212380762958, 0.9611577781782574], 
             UndirectedEdge[195, 395] -> 
             RGBColor[
              0.4419037912723329, 0.5518703230090524, 0.950474161030426], 
             UndirectedEdge[27, 297] -> 
             RGBColor[
              0.2778978023517476, 0.40941858838298906`, 0.9391372407797508], 
             UndirectedEdge[35, 70] -> 
             RGBColor[
              0.4618077060107983, 0.5660845770734715, 0.952262310273184], 
             UndirectedEdge[240, 367] -> 
             RGBColor[
              0.5371092150368568, 0.26073748387253814`, 0.5510797072714124], 
             UndirectedEdge[121, 471] -> 
             RGBColor[
              0.28280914092175835`, 0.4145807166169211, 0.9394169342456387], 
             UndirectedEdge[184, 424] -> 
             RGBColor[
              0.27097066509981255`, 0.4021377279253362, 0.9387427505610343], 
             UndirectedEdge[122, 159] -> 
             RGBColor[
              0.28331094426839853`, 0.4149718924572232, 0.9394505000311653], 
             UndirectedEdge[158, 324] -> 
             RGBColor[
              0.34055138685849157`, 0.469390227511601, 0.9429206111262238], 
             UndirectedEdge[180, 465] -> 
             RGBColor[
              0.35818361085210143`, 0.48466237371351983`, 0.9440441208475331],
              UndirectedEdge[254, 454] -> 
             RGBColor[
              0.4180211220241353, 0.5328331604515816, 0.9485620009504381], 
             UndirectedEdge[297, 314] -> 
             RGBColor[
              0.26758986537343254`, 0.3985842930578276, 0.938550219018062], 
             UndirectedEdge[262, 393] -> 
             RGBColor[
              0.504087731972838, 0.5937629751909799, 0.9573235425449063], 
             UndirectedEdge[201, 333] -> 
             RGBColor[
              0.5692144842551219, 0.6547462826584812, 0.9621128677798301], 
             UndirectedEdge[219, 340] -> 
             RGBColor[
              0.6448803143106713, 0.7154181404403102, 0.955468193238806], 
             UndirectedEdge[361, 370] -> 
             RGBColor[
              0.3306724864701968, 0.46041448761058495`, 0.9423064828381555], 
             UndirectedEdge[48, 358] -> 
             RGBColor[
              0.3075058080961917, 0.44009368422605893`, 0.9408396590460986], 
             UndirectedEdge[287, 299] -> 
             RGBColor[
              0.2885358618333167, 0.4175823086581807, 0.9398535499902183], 
             UndirectedEdge[62, 233] -> 
             RGBColor[
              0.2779593309045732, 0.40948325879314434`, 0.9391407447398109], 
             UndirectedEdge[61, 91] -> 
             RGBColor[
              0.4727776967118894, 0.5764280337840979, 0.9530749068901088], 
             UndirectedEdge[204, 340] -> 
             RGBColor[
              0.28019249974906496`, 0.40903953383276925`, 0.9393701099112484],
              UndirectedEdge[258, 373] -> 
             RGBColor[
              0.25837365932212203`, 0.3888974761566867, 0.9380253697175949], 
             UndirectedEdge[167, 210] -> 
             RGBColor[
              0.4522256893904537, 0.5580869755774045, 0.9514836401456018], 
             UndirectedEdge[275, 481] -> 
             RGBColor[
              0.5680357458633791, 0.6501538335876291, 0.9626495028708743], 
             UndirectedEdge[253, 277] -> 
             RGBColor[
              0.31421989806707584`, 0.44444184351645505`, 0.9413211980581346],
              UndirectedEdge[193, 485] -> 
             RGBColor[
              0.27732975426913986`, 0.4086521130884315, 0.9391110946051424], 
             UndirectedEdge[89, 260] -> 
             RGBColor[
              0.31742545266664046`, 0.4478110846444979, 0.9415037496503867], 
             UndirectedEdge[359, 397] -> 
             RGBColor[
              0.3100550723018857, 0.4353606419960431, 0.941256243094923], 
             UndirectedEdge[1, 171] -> 
             RGBColor[
              0.2831558776083011, 0.4149451588588532, 0.9394366803869862], 
             UndirectedEdge[193, 330] -> 
             RGBColor[
              0.35018659181024964`, 0.47773575776133187`, 0.9435345578656726],
              UndirectedEdge[92, 320] -> 
             RGBColor[
              0.35635723349383686`, 0.48080881834211087`, 0.9440109215326196],
              UndirectedEdge[126, 279] -> 
             RGBColor[
              0.2960535488726037, 0.428501429117225, 0.9401711836850936], 
             UndirectedEdge[93, 163] -> 
             RGBColor[
              0.3214495511509972, 0.4462964053242341, 0.9419432416756316], 
             UndirectedEdge[31, 297] -> 
             RGBColor[
              0.3421538739784863, 0.46946228275983015`, 0.9430709031451506], 
             UndirectedEdge[127, 325] -> 
             RGBColor[
              0.5543582423494791, 0.6372792846532653, 0.9616431413814084], 
             UndirectedEdge[334, 498] -> 
             RGBColor[
              0.2473999787887434, 0.37736344214457407`, 0.9374004348453245], 
             UndirectedEdge[41, 300] -> 
             RGBColor[
              0.24888833020779938`, 0.37892779385293224`, 0.9374851942568212],
              UndirectedEdge[330, 496] -> 
             RGBColor[
              0.3185757070280981, 0.4446801343528438, 0.9417281614180981], 
             UndirectedEdge[18, 227] -> 
             RGBColor[
              0.3496005361396116, 0.4740841485776311, 0.9436123320559633], 
             UndirectedEdge[156, 350] -> 
             RGBColor[
              0.3717238123765596, 0.496390215723689, 0.9449068905155416], 
             UndirectedEdge[315, 386] -> 
             RGBColor[
              0.25460233538952104`, 0.38493357558777497`, 0.937810598398807], 
             UndirectedEdge[29, 479] -> 
             RGBColor[
              0.33201251282538435`, 0.4619942840004112, 0.9423765216234641], 
             UndirectedEdge[277, 488] -> 
             RGBColor[
              0.3318705950309316, 0.461871361939852, 0.9423674787470945], 
             UndirectedEdge[242, 374] -> 
             RGBColor[
              0.44131866563802136`, 0.5459265726202192, 0.9509258946184195], 
             UndirectedEdge[244, 363] -> 
             RGBColor[
              0.41869207061248315`, 0.5320948095294028, 0.9487316123288863], 
             UndirectedEdge[335, 409] -> 
             RGBColor[
              0.2402235248149036, 0.3698205340046061, 0.9369917464081265], 
             UndirectedEdge[235, 332] -> 
             RGBColor[
              0.37566228333182816`, 0.49216939189803444`, 0.9457985434415144],
              UndirectedEdge[249, 440] -> 
             RGBColor[
              0.2805905321187548, 0.4122488180970417, 0.9392905877564452], 
             UndirectedEdge[96, 265] -> 
             RGBColor[
              0.3340531830303098, 0.4570644450726107, 0.9427517746609859], 
             UndirectedEdge[39, 200] -> 
             RGBColor[
              0.35017869348190794`, 0.4777289166263038, 0.9435340545911748], 
             UndirectedEdge[146, 312] -> 
             RGBColor[
              0.33157153197601563`, 0.46127516152496817`, 0.9423607680502372],
              UndirectedEdge[237, 448] -> 
             RGBColor[
              0.40649984846755893`, 0.5219316924828338, 0.9477959107751488], 
             UndirectedEdge[31, 162] -> 
             RGBColor[
              0.350449658360585, 0.4779636127851231, 0.9435513202336394], 
             UndirectedEdge[41, 102] -> 
             RGBColor[
              0.2634249702289963, 0.39420672419142105`, 0.9383130344009966], 
             UndirectedEdge[266, 374] -> 
             RGBColor[
              0.43117141854238306`, 0.535261172550078, 0.9503480239078297], 
             UndirectedEdge[44, 139] -> 
             RGBColor[
              0.41219750205323025`, 0.531446491454829, 0.9474858382322604], 
             UndirectedEdge[47, 189] -> 
             RGBColor[
              0.27834004557677144`, 0.4098834140523291, 0.9391624258771757], 
             UndirectedEdge[208, 359] -> 
             RGBColor[
              0.5741723766779738, 0.6479420199891819, 0.9643111782585929], 
             UndirectedEdge[122, 413] -> 
             RGBColor[
              0.27834629293518026`, 0.4097537291289356, 0.939167770482282], 
             UndirectedEdge[36, 141] -> 
             RGBColor[
              0.372838243090246, 0.49735547959496784`, 0.9449779010551652], 
             UndirectedEdge[179, 347] -> 
             RGBColor[
              0.24962793310437476`, 0.379705163390765, 0.9375273135476367], 
             UndirectedEdge[226, 422] -> 
             RGBColor[
              0.30865874018355827`, 0.44002240022154804`, 0.940952296986578], 
             UndirectedEdge[18, 167] -> 
             RGBColor[
              0.5274884639867863, 0.6264943643813713, 0.956161470479248], 
             UndirectedEdge[112, 452] -> 
             RGBColor[
              0.24853093996988013`, 0.3785521540530292, 0.9374648414114831], 
             UndirectedEdge[323, 342] -> 
             RGBColor[
              0.36110696385054364`, 0.4871944351487765, 0.9442303943155743], 
             UndirectedEdge[74, 82] -> 
             RGBColor[
              0.41640315745637213`, 0.5334474549463979, 0.9482074431152268], 
             UndirectedEdge[291, 349] -> 
             RGBColor[
              0.3554569916450302, 0.4800344328004348, 0.9439533627097983], 
             UndirectedEdge[86, 136] -> 
             RGBColor[
              0.374598330506573, 0.4988799788504245, 0.9450900522689494], 
             UndirectedEdge[11, 23] -> 
             RGBColor[
              0.2655723032729174, 0.39646370736936065`, 0.9384353218411533], 
             UndirectedEdge[249, 470] -> 
             RGBColor[
              0.3164895604824214, 0.446037840347373, 0.9414793617175872], 
             UndirectedEdge[35, 135] -> 
             RGBColor[
              0.5445584007325972, 0.6407510539716867, 0.9574255601654322], 
             UndirectedEdge[161, 326] -> 
             RGBColor[
              0.4035084852647527, 0.520844553998083, 0.9474383185072883], 
             UndirectedEdge[26, 139] -> 
             RGBColor[
              0.46653174436475386`, 0.5775089742842785, 0.9512240243314842], 
             UndirectedEdge[109, 218] -> 
             RGBColor[
              0.36823959529816475`, 0.48660569144348426`, 0.9451721142667662],
              UndirectedEdge[238, 465] -> 
             RGBColor[
              0.2829650893968573, 0.4085270397005651, 0.9396534716587286], 
             UndirectedEdge[258, 314] -> 
             RGBColor[
              0.24518979087451165`, 0.375040394512709, 0.937274567913289], 
             UndirectedEdge[28, 493] -> 
             RGBColor[
              0.5930845053333267, 0.6775949742021634, 0.9627129648082972], 
             UndirectedEdge[106, 466] -> 
             RGBColor[
              0.3714731214355212, 0.49617307983065456`, 0.9448909167104558], 
             UndirectedEdge[45, 236] -> 
             RGBColor[
              0.2866667420496446, 0.4186352999883677, 0.9396366189230623], 
             UndirectedEdge[157, 246] -> 
             RGBColor[
              0.33654630585329737`, 0.4659212276461261, 0.942665410906127], 
             UndirectedEdge[371, 427] -> 
             RGBColor[
              0.5480192629183209, 0.6439457514803696, 0.9575612303190866], 
             UndirectedEdge[341, 450] -> 
             RGBColor[
              0.2896905748838666, 0.4218135400192101, 0.9398088217296114], 
             UndirectedEdge[277, 484] -> 
             RGBColor[
              0.3407928232873032, 0.46959934761128985`, 0.9429359952419738], 
             UndirectedEdge[84, 135] -> 
             RGBColor[
              0.42913029877250675`, 0.5461128289059574, 0.9485647810661285], 
             UndirectedEdge[35, 84] -> 
             RGBColor[
              0.5318021883021244, 0.62970226391029, 0.9566127455892381], 
             UndirectedEdge[68, 272] -> 
             RGBColor[
              0.22754358834335253`, 0.3564931168185995, 0.9362696427843568], 
             UndirectedEdge[164, 227] -> 
             RGBColor[
              0.30267126160647173`, 0.4334363697109467, 0.9406220401806397], 
             UndirectedEdge[355, 498] -> 
             RGBColor[
              0.3101343104062332, 0.4386442572661316, 0.9411435757926818], 
             UndirectedEdge[223, 373] -> 
             RGBColor[
              0.3431031217953162, 0.46774389635075764`, 0.9432244113517104], 
             UndirectedEdge[116, 192] -> 
             RGBColor[
              0.33802221156766243`, 0.46621584367170527`, 0.9427954738287362],
              UndirectedEdge[3, 31] -> 
             RGBColor[
              0.3545817889426814, 0.4815426566084131, 0.943814615940431], 
             UndirectedEdge[40, 419] -> 
             RGBColor[
              0.34300365159164276`, 0.46227065887520086`, 0.9435356586635066],
              UndirectedEdge[282, 324] -> 
             RGBColor[
              0.3549483359028742, 0.4818601411621463, 0.9438379719886096], 
             UndirectedEdge[250, 339] -> 
             RGBColor[
              0.2791889906041152, 0.4102887201081069, 0.939228603093233], 
             UndirectedEdge[259, 405] -> 
             RGBColor[
              0.31877389710324655`, 0.4495910286538922, 0.9415672634145065], 
             UndirectedEdge[22, 441] -> 
             RGBColor[
              0.6627721531749591, 0.7334299594882228, 0.9691567001237863], 
             UndirectedEdge[142, 241] -> 
             RGBColor[
              0.9302129677113393, 0.9435954652760508, 0.839901292655227], 
             UndirectedEdge[170, 266] -> 
             RGBColor[
              0.23441855754963242`, 0.3637191453526236, 0.9366611621100489], 
             UndirectedEdge[105, 153] -> 
             RGBColor[
              0.3902081954162546, 0.5124004592605679, 0.9460846990577327], 
             UndirectedEdge[95, 404] -> 
             RGBColor[
              0.4508927992064238, 0.5594967897302864, 0.951151880595294], 
             UndirectedEdge[200, 454] -> 
             RGBColor[
              0.45269407841599507`, 0.5641396211245323, 0.9507246658022258], 
             UndirectedEdge[96, 131] -> 
             RGBColor[
              0.3401921096971891, 0.46238167480003567`, 0.9431429416397596], 
             UndirectedEdge[190, 395] -> 
             RGBColor[
              0.6352353871847748, 0.68161727487249, 0.6553645187765798], 
             UndirectedEdge[297, 381] -> 
             RGBColor[
              0.3302594939537314, 0.45915996861131014`, 0.9423130037677605], 
             UndirectedEdge[203, 419] -> 
             RGBColor[
              0.27712960458579444`, 0.40571593123820787`, 0.9391995017010552],
              UndirectedEdge[107, 209] -> 
             RGBColor[
              0.3132011658979136, 0.44570084077762384`, 0.9411778792314665], 
             UndirectedEdge[205, 252] -> 
             RGBColor[
              0.26269752330383117`, 0.3934421313502735, 0.9382716073747697], 
             UndirectedEdge[98, 488] -> 
             RGBColor[
              0.40055751499557607`, 0.5206338389654236, 0.9469460378160905], 
             UndirectedEdge[182, 275] -> 
             RGBColor[
              0.3472112017252604, 0.47272220716656965`, 0.9434341778111206], 
             UndirectedEdge[88, 474] -> 
             RGBColor[
              0.3864028487686768, 0.49805783828204986`, 0.946901796123951], 
             UndirectedEdge[47, 242] -> 
             RGBColor[
              0.276574210055649, 0.40802740895919076`, 0.9390618641565673], 
             UndirectedEdge[133, 262] -> 
             RGBColor[
              0.5379335169087738, 0.6293370411053574, 0.9592510099266561], 
             UndirectedEdge[4, 321] -> 
             RGBColor[
              0.28465091577036944`, 0.41651653875808137`, 0.9395218205986053],
              UndirectedEdge[369, 370] -> 
             RGBColor[
              0.4108597541401787, 0.529981814805704, 0.9474851431395912], 
             UndirectedEdge[49, 436] -> 
             RGBColor[
              0.6139912596013597, 0.676968485168671, 0.8175373226825366], 
             UndirectedEdge[34, 393] -> 
             RGBColor[
              0.3260168513556947, 0.45014243148057975`, 0.9422382914377373], 
             UndirectedEdge[268, 324] -> 
             RGBColor[
              0.3273506912142862, 0.45795644843084504`, 0.9420794744726919], 
             UndirectedEdge[359, 371] -> 
             RGBColor[
              0.3945896874975766, 0.5056076269208492, 0.9474640660552952], 
             UndirectedEdge[296, 440] -> 
             RGBColor[
              0.3003670423479159, 0.4318894798010692, 0.940458780609557], 
             UndirectedEdge[113, 143] -> 
             RGBColor[
              0.3515797154925216, 0.47894241147448363`, 0.9436233264748161], 
             UndirectedEdge[270, 489] -> 
             RGBColor[
              0.3054281833639013, 0.4306735281077076, 0.9409863029372769], 
             UndirectedEdge[237, 426] -> 
             RGBColor[
              0.34219225259067454`, 0.4683404002927851, 0.9431156433479042], 
             UndirectedEdge[131, 385] -> 
             RGBColor[
              0.3618117940997805, 0.4851053338743221, 0.9443741506830303], 
             UndirectedEdge[427, 499] -> 
             RGBColor[
              0.4182102891566449, 0.533969821135801, 0.9484874062518633], 
             UndirectedEdge[45, 243] -> 
             RGBColor[
              0.2782643448361728, 0.40980384777425577`, 0.9391581148319879], 
             UndirectedEdge[33, 443] -> 
             RGBColor[
              0.6107876071304796, 0.6838483939461286, 0.9618668294518231], 
             UndirectedEdge[232, 330] -> 
             RGBColor[
              0.35108739411085677`, 0.4785159874384777, 0.9435919561917191], 
             UndirectedEdge[19, 360] -> 
             RGBColor[
              0.26739443572139987`, 0.39782502123084507`, 0.9385593692213898],
              UndirectedEdge[44, 370] -> 
             RGBColor[
              0.3692890560172716, 0.49428135213968655`, 0.9447517499932983], 
             UndirectedEdge[310, 412] -> 
             RGBColor[
              0.3581936915817172, 0.4842504445601557, 0.9440601656270062], 
             UndirectedEdge[107, 214] -> 
             RGBColor[
              0.2522234923244513, 0.3819881355076721, 0.9376914250191893], 
             UndirectedEdge[268, 481] -> 
             RGBColor[
              0.5863504244613744, 0.6684535049172995, 0.9637272888254749], 
             UndirectedEdge[224, 351] -> 
             RGBColor[
              0.6761053285479827, 0.7447659377604899, 0.9700170190584623], 
             UndirectedEdge[78, 408] -> 
             RGBColor[
              0.22457514006089435`, 0.3533730894632443, 0.9361005940460965], 
             UndirectedEdge[124, 136] -> 
             RGBColor[
              0.37572092572039506`, 0.4998523144013612, 0.9451615830433022], 
             UndirectedEdge[51, 315] -> 
             RGBColor[
              0.357292020794288, 0.4764939133373235, 0.9444217011923839], 
             UndirectedEdge[24, 270] -> 
             RGBColor[
              0.35562547138722456`, 0.4824466418848715, 0.943881118462905], 
             UndirectedEdge[43, 340] -> 
             RGBColor[
              0.30582019144756734`, 0.4359758626973981, 0.9408295690407057], 
             UndirectedEdge[116, 483] -> 
             RGBColor[
              0.3231745705583471, 0.45061003157610247`, 0.9419499226383722], 
             UndirectedEdge[50, 169] -> 
             RGBColor[
              0.29828929421430594`, 0.430851339225796, 0.9402985060748147], 
             UndirectedEdge[247, 369] -> 
             RGBColor[
              0.38121399627469793`, 0.503295883528601, 0.9456330592151129], 
             UndirectedEdge[327, 412] -> 
             RGBColor[
              0.49260223582489593`, 0.5978390230176498, 0.9535071435442843], 
             UndirectedEdge[134, 305] -> 
             RGBColor[
              0.23154289154263408`, 0.36069663805151275`, 0.9364973971851169],
              UndirectedEdge[7, 49] -> 
             RGBColor[
              0.6264411785377744, 0.6900541393412951, 0.818246327147961], 
             UndirectedEdge[81, 486] -> 
             RGBColor[
              0.415549621492833, 0.5269020632884645, 0.9487246788519874], 
             UndirectedEdge[110, 384] -> 
             RGBColor[
              0.46592200271647066`, 0.5768618632659337, 0.951218047614329], 
             UndirectedEdge[18, 88] -> 
             RGBColor[
              0.4892186512927306, 0.595425206400922, 0.953148730637029], 
             UndirectedEdge[11, 41] -> 
             RGBColor[
              0.2532164779061686, 0.38347695150433214`, 0.9377316758653225], 
             UndirectedEdge[231, 288] -> 
             RGBColor[
              0.3604830771863719, 0.4848774093307946, 0.944255692542216], 
             UndirectedEdge[236, 396] -> 
             RGBColor[
              0.3251799326146204, 0.4530637706874179, 0.9420514571484285], 
             UndirectedEdge[46, 418] -> 
             RGBColor[
              0.6162456446528474, 0.6950701175026879, 0.9652994065524505], 
             UndirectedEdge[74, 447] -> 
             RGBColor[
              0.721899049275949, 0.6881958694857397, 0.6087064036190506], 
             UndirectedEdge[270, 426] -> 
             RGBColor[
              0.39709516570406667`, 0.5183656067746794, 0.9465235307145634], 
             UndirectedEdge[383, 479] -> 
             RGBColor[
              0.3157330923453243, 0.44789386820804755`, 0.9413392113458009], 
             UndirectedEdge[408, 430] -> 
             RGBColor[
              0.27893013896960833`, 0.4105036396222827, 0.9391960308229328], 
             UndirectedEdge[13, 390] -> 
             RGBColor[
              0.6191619043190348, 0.7006645228197772, 0.963871546358655], 
             UndirectedEdge[15, 97] -> 
             RGBColor[
              0.7816181449224021, 0.8293749339627663, 0.9611105332953456], 
             UndirectedEdge[289, 472] -> 
             RGBColor[
              0.3441219375253305, 0.4679747941454312, 0.9433131857964239], 
             UndirectedEdge[254, 315] -> 
             RGBColor[
              0.26554623276727407`, 0.396436305614964, 0.9384338371644247], 
             UndirectedEdge[347, 386] -> 
             RGBColor[
              0.2837955945491933, 0.4156175419241276, 0.9394731113203937], 
             UndirectedEdge[66, 445] -> 
             RGBColor[
              0.6101598285776131, 0.6839258453252886, 0.9660569831943079], 
             UndirectedEdge[127, 213] -> 
             RGBColor[
              0.582411087600712, 0.6654484800812466, 0.9632888991496082], 
             UndirectedEdge[423, 446] -> 
             RGBColor[
              0.583222007762499, 0.6725249256104562, 0.9603325193451235], 
             UndirectedEdge[63, 410] -> 
             RGBColor[
              0.26912193539348, 0.40019459578774724`, 0.9386374681392091], 
             UndirectedEdge[107, 421] -> 
             RGBColor[
              0.26701804880473734`, 0.39753815239751156`, 0.9385339531241567],
              UndirectedEdge[226, 308] -> 
             RGBColor[
              0.3456140311468745, 0.47203121582704155`, 0.9433070554484797], 
             UndirectedEdge[51, 386] -> 
             RGBColor[
              0.3757632029796828, 0.4959082969547658, 0.9454736076921769], 
             UndirectedEdge[89, 470] -> 
             RGBColor[
              0.321695349496558, 0.45150945466731773`, 0.9417758237006675], 
             UndirectedEdge[205, 490] -> 
             RGBColor[
              0.2774027788606694, 0.40769387123968387`, 0.9391531494964787], 
             UndirectedEdge[270, 345] -> 
             RGBColor[
              0.383869564275913, 0.5069102555556685, 0.9456808070865016], 
             UndirectedEdge[152, 191] -> 
             RGBColor[
              0.2773443720884851, 0.4088368980867948, 0.9391057237449847], 
             UndirectedEdge[85, 404] -> 
             RGBColor[
              0.4568222983849092, 0.5657290693188365, 0.9514895568016009], 
             UndirectedEdge[26, 468] -> 
             RGBColor[
              0.39359478980129664`, 0.5132556084784587, 0.9466160550840707], 
             UndirectedEdge[191, 301] -> 
             RGBColor[
              0.2714524085691301, 0.40264407085588916`, 0.9387701851389364], 
             UndirectedEdge[375, 426] -> 
             RGBColor[
              0.46418227120880406`, 0.5744996159641337, 0.9513435373133631], 
             UndirectedEdge[39, 213] -> 
             RGBColor[
              0.3295155840217827, 0.45983156977002226`, 0.9422174195280459], 
             UndirectedEdge[360, 468] -> 
             RGBColor[
              0.25856380359082465`, 0.3890973298389361, 0.9380361981524044], 
             UndirectedEdge[80, 278] -> 
             RGBColor[
              0.29700686091498774`, 0.4295034205172452, 0.9402254733956086], 
             UndirectedEdge[152, 299] -> 
             RGBColor[
              0.3128535200890198, 0.4431417093135098, 0.941238404653129], 
             UndirectedEdge[227, 309] -> 
             RGBColor[
              0.2650233039045846, 0.3958866742246725, 0.9384040571392985], 
             UndirectedEdge[98, 115] -> 
             RGBColor[
              0.3992358151553642, 0.5194890489943976, 0.9468618202710055], 
             UndirectedEdge[213, 261] -> 
             RGBColor[
              0.5527025969948657, 0.6420633180669494, 0.9603747154715218], 
             UndirectedEdge[199, 208] -> 
             RGBColor[
              0.6324592754839493, 0.7060424127861656, 0.9677463377440149], 
             UndirectedEdge[204, 219] -> 
             RGBColor[
              0.5861405430217843, 0.6564698435061025, 0.9520208606521875], 
             UndirectedEdge[52, 166] -> 
             RGBColor[
              0.4019750805213094, 0.5144080980812685, 0.9477901721576478], 
             UndirectedEdge[218, 300] -> 
             RGBColor[
              0.23983254840488705`, 0.3694095930083426, 0.9369694808799739], 
             UndirectedEdge[128, 345] -> 
             RGBColor[
              0.3399109566530374, 0.46838820805335357`, 0.9428961817268782], 
             UndirectedEdge[325, 421] -> 
             RGBColor[
              0.24367550115238262`, 0.3734487800032376, 0.9371883313538046], 
             UndirectedEdge[257, 272] -> 
             RGBColor[
              0.45733037019135736`, 0.5624973906125226, 0.9518612676644727], 
             UndirectedEdge[461, 486] -> 
             RGBColor[0.405020290110264, 0.5158350684072162, 0.9481250490065],
              UndirectedEdge[115, 203] -> 
             RGBColor[
              0.3291518225036404, 0.45951649782619286`, 0.9421942409657715], 
             UndirectedEdge[128, 169] -> 
             RGBColor[
              0.30622996585329754`, 0.439197488586037, 0.9407507155774842], 
             UndirectedEdge[190, 356] -> 
             RGBColor[
              0.6665945209150321, 0.7103254568490149, 0.6573060709679845], 
             UndirectedEdge[46, 272] -> 
             RGBColor[
              0.3379974571902972, 0.4641653599872854, 0.94286818969398], 
             UndirectedEdge[121, 450] -> 
             RGBColor[
              0.2804071751282495, 0.41205609827451595`, 0.9392801458470883], 
             UndirectedEdge[255, 269] -> 
             RGBColor[
              0.6140005207695203, 0.6918171180736932, 0.9657586711711035], 
             UndirectedEdge[15, 356] -> 
             RGBColor[
              0.6551901329754006, 0.7240582947070004, 0.9518972327387696], 
             UndirectedEdge[85, 183] -> 
             RGBColor[
              0.31345501914909973`, 0.4457248326231369, 0.9412012267753339], 
             UndirectedEdge[136, 261] -> 
             RGBColor[
              0.5667184788403095, 0.6542031704627682, 0.9612677950689558], 
             UndirectedEdge[295, 336] -> 
             RGBColor[
              0.2417805869280456, 0.37145710500895834`, 0.937080418792003], 
             UndirectedEdge[259, 475] -> 
             RGBColor[
              0.3899678886459994, 0.5121923176143423, 0.946069386922827], 
             UndirectedEdge[51, 143] -> 
             RGBColor[
              0.4337523740820563, 0.5494337670777927, 0.9490478644296152], 
             UndirectedEdge[53, 178] -> 
             RGBColor[
              0.41372795303594184`, 0.5327720911733509, 0.9475833572155541], 
             UndirectedEdge[67, 385] -> 
             RGBColor[
              0.34086430373362, 0.46696167057063265`, 0.9430393951200371], 
             UndirectedEdge[69, 173] -> 
             RGBColor[
              0.38813069296793135`, 0.5106010310581394, 0.9459523224387889], 
             UndirectedEdge[221, 381] -> 
             RGBColor[
              0.6590559074282949, 0.6696301512613431, 0.6124319900913855], 
             UndirectedEdge[140, 334] -> 
             RGBColor[
              0.29348623469894064`, 0.4216812680806512, 0.9401758964382151], 
             UndirectedEdge[57, 370] -> 
             RGBColor[
              0.33388624673648354`, 0.46361721813760065`, 0.9424959142914013],
              UndirectedEdge[432, 467] -> 
             RGBColor[
              0.3048115848365754, 0.4373152352622944, 0.9406842735938514], 
             UndirectedEdge[235, 440] -> 
             RGBColor[
              0.2610477330574249, 0.39170809719855737`, 0.9381776542608828], 
             UndirectedEdge[229, 390] -> 
             RGBColor[
              0.4836794275903025, 0.5805874099208927, 0.954851288568016], 
             UndirectedEdge[12, 198] -> 
             RGBColor[
              0.5032993335350885, 0.6007950399620902, 0.9560341768472638], 
             UndirectedEdge[232, 400] -> 
             RGBColor[
              0.3068233627033585, 0.43948519490061944`, 0.9407968109412319], 
             UndirectedEdge[143, 273] -> 
             RGBColor[
              0.43226201144583665`, 0.548223823549638, 0.9489305376235138], 
             UndirectedEdge[115, 277] -> 
             RGBColor[
              0.3305488951907197, 0.46072657196882605`, 0.9422832612020094], 
             UndirectedEdge[44, 468] -> 
             RGBColor[
              0.33926054748977297`, 0.4671931256490092, 0.9428778689848469], 
             UndirectedEdge[183, 346] -> 
             RGBColor[
              0.44039366973071203`, 0.5529582256632066, 0.950086616744644], 
             UndirectedEdge[434, 469] -> 
             RGBColor[
              0.5931599758511953, 0.6770649825529437, 0.9629697584691289], 
             UndirectedEdge[255, 334] -> 
             RGBColor[
              0.29547171203547484`, 0.4234009887565646, 0.9403024092984104], 
             UndirectedEdge[65, 210] -> 
             RGBColor[
              0.2707608992567404, 0.40191725072434475`, 0.9387308047065921], 
             UndirectedEdge[49, 76] -> 
             RGBColor[
              0.6536376768828197, 0.7183142062315098, 0.8198070338263352], 
             UndirectedEdge[74, 395] -> 
             RGBColor[
              0.4029012154116123, 0.5202062748792999, 0.9474037353875272], 
             UndirectedEdge[52, 88] -> 
             RGBColor[
              0.5540488649162763, 0.6488408540127844, 0.9580359026755255], 
             UndirectedEdge[312, 354] -> 
             RGBColor[
              0.47444150973517296`, 0.5798285375279173, 0.9529081653610575], 
             UndirectedEdge[372, 417] -> 
             RGBColor[
              0.5067053173839196, 0.610405229323506, 0.9543088451886494], 
             UndirectedEdge[354, 415] -> 
             RGBColor[
              0.4684563254187194, 0.573537729328721, 0.9525673179685222], 
             UndirectedEdge[301, 451] -> 
             RGBColor[
              0.3188579938851934, 0.4472529781529899, 0.9416608965132198], 
             UndirectedEdge[243, 428] -> 
             RGBColor[
              0.26169997715555093`, 0.3923936471003522, 0.9382147985973623], 
             UndirectedEdge[102, 354] -> 
             RGBColor[
              0.45307864902507894`, 0.5573748164380081, 0.9516915820471379], 
             UndirectedEdge[255, 369] -> 
             RGBColor[
              0.41094224163569293`, 0.5300532613283764, 0.9474903991698644], 
             UndirectedEdge[300, 409] -> 
             RGBColor[
              0.23598725202182236`, 0.36536794270386935`, 0.9367504969395646],
              UndirectedEdge[93, 187] -> 
             RGBColor[
              0.4102733723817296, 0.5297799070429444, 0.9473632343910334], 
             UndirectedEdge[181, 332] -> 
             RGBColor[
              0.42548577489986406`, 0.5414489692338035, 0.9487489869964301], 
             UndirectedEdge[195, 351] -> 
             RGBColor[
              0.5312681625008637, 0.6303464535330037, 0.9562425223329216], 
             UndirectedEdge[480, 481] -> 
             RGBColor[
              0.5500079293102216, 0.631205455360673, 0.9616228453879365], 
             UndirectedEdge[47, 365] -> 
             RGBColor[
              0.26283947684254017`, 0.39359133351983083`, 0.9382796914187976],
              UndirectedEdge[50, 370] -> 
             RGBColor[
              0.3225794297136618, 0.4519081718300314, 0.9418455952284754], 
             UndirectedEdge[122, 150] -> 
             RGBColor[
              0.3118706599157425, 0.4445484233690423, 0.9410931005668028], 
             UndirectedEdge[246, 256] -> 
             RGBColor[
              0.3123114563715824, 0.4436116977135667, 0.9411694652542291], 
             UndirectedEdge[63, 282] -> 
             RGBColor[
              0.3330488622711529, 0.4613324504147913, 0.9424996566340224], 
             UndirectedEdge[230, 391] -> 
             RGBColor[
              0.2744505343656999, 0.4057952911602386, 0.9389409239677213], 
             UndirectedEdge[312, 415] -> 
             RGBColor[
              0.2991140648840668, 0.43171822549319544`, 0.9403454755443187], 
             UndirectedEdge[199, 397] -> 
             RGBColor[
              0.36834197110786115`, 0.49346103479302683`, 0.9446914025803449],
              UndirectedEdge[129, 328] -> 
             RGBColor[
              0.31796148667951385`, 0.4496487355728752, 0.94148761963582], 
             UndirectedEdge[188, 304] -> 
             RGBColor[
              0.3078524289402341, 0.4369347749610324, 0.940988401290471], 
             UndirectedEdge[323, 395] -> 
             RGBColor[
              0.35093087038673487`, 0.47683393796048823`, 0.9436386067185205],
              UndirectedEdge[49, 238] -> 
             RGBColor[
              0.5924739519536549, 0.6543524305548316, 0.8163119438440039], 
             UndirectedEdge[171, 385] -> 
             RGBColor[
              0.2792589899709948, 0.4108492828750976, 0.9392147584009702], 
             UndirectedEdge[117, 425] -> 
             RGBColor[
              0.4666150427732705, 0.5741814581410447, 0.9521686696117222], 
             UndirectedEdge[32, 103] -> 
             RGBColor[
              0.4734373843294418, 0.5818178929313051, 0.952126134596796], 
             UndirectedEdge[131, 216] -> 
             RGBColor[
              0.39225567901923875`, 0.5141738866479546, 0.9462151629023963], 
             UndirectedEdge[65, 175] -> 
             RGBColor[
              0.2541362946886586, 0.3844437372624815, 0.9377840580703384], 
             UndirectedEdge[143, 226] -> 
             RGBColor[
              0.3394673948537818, 0.46670730840888763`, 0.942915397219141], 
             UndirectedEdge[234, 235] -> 
             RGBColor[
              0.2802039247533765, 0.4109953158467531, 0.9392995894746672], 
             UndirectedEdge[179, 386] -> 
             RGBColor[
              0.23890585613009724`, 0.36843558067185467`, 0.9369167071258431],
              UndirectedEdge[267, 476] -> 
             RGBColor[
              0.25532575108410227`, 0.3856939313499841, 0.9378517958524157], 
             UndirectedEdge[59, 195] -> 
             RGBColor[
              0.5609241170200876, 0.654422493397236, 0.9585771477060159], 
             UndirectedEdge[75, 108] -> 
             RGBColor[
              0.6335260492516934, 0.7126697534094633, 0.9647673066040147], 
             UndirectedEdge[334, 363] -> 
             RGBColor[
              0.2589402131355509, 0.38949296013618684`, 0.9380576341191285], 
             UndirectedEdge[77, 329] -> 
             RGBColor[
              0.3024027230888186, 0.42959308690898446`, 0.9407371341274349], 
             UndirectedEdge[328, 462] -> 
             RGBColor[
              0.3656406998465538, 0.4911213293963237, 0.9445192799642148], 
             UndirectedEdge[285, 480] -> 
             RGBColor[
              0.26156815429706143`, 0.3922550929180277, 0.9382072914805859], 
             UndirectedEdge[204, 334] -> 
             RGBColor[
              0.22754946120350128`, 0.35649928956697663`, 0.9362699772350541],
              UndirectedEdge[70, 238] -> 
             RGBColor[
              0.2331603713610938, 0.36239671189485767`, 0.9365895102679312], 
             UndirectedEdge[83, 270] -> 
             RGBColor[
              0.34659069129673375`, 0.4739379337988554, 0.9433304468695782], 
             UndirectedEdge[112, 190] -> 
             RGBColor[
              0.6088603495779866, 0.6538954380737855, 0.6538624994032447], 
             UndirectedEdge[263, 453] -> 
             RGBColor[
              0.4445446319876649, 0.5588120567610715, 0.9497270886791912], 
             UndirectedEdge[210, 474] -> 
             RGBColor[
              0.24638152356719978`, 0.3762929811329411, 0.9373424353271271], 
             UndirectedEdge[96, 392] -> 
             RGBColor[
              0.26015286070268673`, 0.3907675296155432, 0.9381266926041254], 
             UndirectedEdge[70, 84] -> 
             RGBColor[
              0.34637960405070783`, 0.4714463520077421, 0.9434015311738803], 
             UndirectedEdge[77, 278] -> 
             RGBColor[
              0.2703917768774402, 0.40152927969998975`, 0.9387097837331586], 
             UndirectedEdge[238, 265] -> 
             RGBColor[
              0.3108668683459195, 0.43269415824205665`, 0.9414313483407886], 
             UndirectedEdge[157, 392] -> 
             RGBColor[
              0.31347611475525583`, 0.44365081706344256`, 0.9412791798638953],
              UndirectedEdge[145, 294] -> 
             RGBColor[
              0.3871739654531823, 0.5097723617713869, 0.94589136060755], 
             UndirectedEdge[29, 383] -> 
             RGBColor[
              0.33609441544401897`, 0.46552982288628153`, 0.9426366168488387],
              UndirectedEdge[210, 227] -> 
             RGBColor[
              0.27433776154327894`, 0.40567675977366424`, 0.938934501722317], 
             UndirectedEdge[45, 276] -> 
             RGBColor[
              0.38773320227768915`, 0.5085082414564097, 0.9461535777703476], 
             UndirectedEdge[57, 219] -> 
             RGBColor[
              0.6307342979616306, 0.7031655720782259, 0.9545668215858762], 
             UndirectedEdge[291, 311] -> 
             RGBColor[
              0.2937160124658069, 0.4260445301453132, 0.9400380644448016], 
             UndirectedEdge[11, 485] -> 
             RGBColor[
              0.24301881045945342`, 0.3727585564483743, 0.9371509337903292], 
             UndirectedEdge[13, 338] -> 
             RGBColor[
              0.4080900614994058, 0.523935347184997, 0.9478562285053231], 
             UndirectedEdge[190, 351] -> 
             RGBColor[
              0.7245997584133056, 0.7600934053964414, 0.6611328800790754], 
             UndirectedEdge[314, 397] -> 
             RGBColor[
              0.31719795971766984`, 0.4428682695552517, 0.941663019966297], 
             UndirectedEdge[339, 365] -> 
             RGBColor[
              0.2664208497974997, 0.39686859457346974`, 0.9385014763630678], 
             UndirectedEdge[320, 337] -> 
             RGBColor[
              0.2811030293913728, 0.41278748522476705`, 0.9393197737179491], 
             UndirectedEdge[317, 357] -> 
             RGBColor[
              0.45345829973234725`, 0.5632875814490537, 0.9511916756667309], 
             UndirectedEdge[153, 452] -> 
             RGBColor[
              0.3339441575664155, 0.4589563715089132, 0.9426720973282581], 
             UndirectedEdge[308, 423] -> 
             RGBColor[
              0.5019260728146506, 0.6051140380716534, 0.9543225202268077], 
             UndirectedEdge[149, 441] -> 
             RGBColor[
              0.5775532588521162, 0.6556712441295767, 0.9638711242884468], 
             UndirectedEdge[486, 493] -> 
             RGBColor[
              0.4928798081986049, 0.598189770588176, 0.9534943461637415], 
             UndirectedEdge[241, 402] -> 
             RGBColor[
              0.6591938380581435, 0.7230932102498733, 0.8173009857874498], 
             UndirectedEdge[293, 432] -> 
             RGBColor[
              0.27790673013934564`, 0.4090365271091919, 0.93915208192101], 
             UndirectedEdge[23, 211] -> 
             RGBColor[
              0.617128319048033, 0.6899190910295299, 0.9588244792397721], 
             UndirectedEdge[8, 381] -> 
             RGBColor[
              0.29172629812002937`, 0.41865913664436416`, 0.9401185952697859],
              UndirectedEdge[238, 343] -> 
             RGBColor[
              0.3132583325493639, 0.43476552433659443`, 0.9415837303251432], 
             UndirectedEdge[355, 363] -> 
             RGBColor[
              0.32167454475304064`, 0.4507737752577444, 0.9418007750664856], 
             UndirectedEdge[66, 398] -> 
             RGBColor[
              0.574509590883247, 0.6464551851528881, 0.9640267548974142], 
             UndirectedEdge[113, 477] -> 
             RGBColor[
              0.3404908341297308, 0.469337779781417, 0.9429167527598918], 
             UndirectedEdge[7, 241] -> 
             RGBColor[
              0.6264148862153416, 0.6899979027221732, 0.8153845701085682], 
             UndirectedEdge[161, 259] -> 
             RGBColor[
              0.3160831700523592, 0.4467629039214611, 0.9414140304895323], 
             UndirectedEdge[346, 408] -> 
             RGBColor[
              0.40844159822281634`, 0.520441217701691, 0.948227938439961], 
             UndirectedEdge[33, 270] -> 
             RGBColor[
              0.3361110737078669, 0.4629231912668246, 0.9427336481510973], 
             UndirectedEdge[197, 270] -> 
             RGBColor[
              0.3241018508774723, 0.4503007366433744, 0.9420497406769593], 
             UndirectedEdge[115, 381] -> 
             RGBColor[
              0.34212460621081964`, 0.4707528710422837, 0.9430208552722108], 
             UndirectedEdge[112, 224] -> 
             RGBColor[
              0.5603659197126637, 0.638567970437834, 0.9627466383826316], 
             UndirectedEdge[133, 296] -> 
             RGBColor[
              0.3127778312088145, 0.4449340057833361, 0.9411655566750684], 
             UndirectedEdge[204, 244] -> 
             RGBColor[
              0.3873013186804336, 0.4991011389601926, 0.9469439554448119], 
             UndirectedEdge[116, 280] -> 
             RGBColor[
              0.35661212781810425`, 0.4833012340945053, 0.9439439873382147], 
             UndirectedEdge[81, 267] -> 
             RGBColor[
              0.25746534772157614`, 0.38794278307423113`, 0.9379736427156704],
              UndirectedEdge[431, 459] -> 
             RGBColor[
              0.3514405074043362, 0.47383411025891353`, 0.9437970813464658], 
             UndirectedEdge[46, 293] -> 
             RGBColor[
              0.32133419245936723`, 0.4466512122430728, 0.9419192414186446], 
             UndirectedEdge[145, 358] -> 
             RGBColor[
              0.35680921676596467`, 0.4834719426351635, 0.9439565456716934], 
             UndirectedEdge[12, 480] -> 
             RGBColor[
              0.4797644455118252, 0.5760583804515544, 0.9546938997910857], 
             UndirectedEdge[318, 321] -> 
             RGBColor[
              0.5895767516253461, 0.6677163224147521, 0.9646455851432827], 
             UndirectedEdge[38, 47] -> 
             RGBColor[
              0.32489365826302896`, 0.4556530341774414, 0.9419293314792428], 
             UndirectedEdge[271, 492] -> 
             RGBColor[
              0.32598530479513443`, 0.4567738193408926, 0.9419924732574273], 
             UndirectedEdge[246, 333] -> 
             RGBColor[
              0.5754040195489128, 0.6601073470348737, 0.9625072594955594], 
             UndirectedEdge[97, 137] -> 
             RGBColor[
              0.4951095186655795, 0.5990717627292397, 0.9539263380457963], 
             UndirectedEdge[406, 486] -> 
             RGBColor[
              0.44618897669816093`, 0.5577485190919175, 0.9505192476676143], 
             UndirectedEdge[272, 306] -> 
             RGBColor[
              0.2513353156053655, 0.3814997306536093, 0.937624546455222], 
             UndirectedEdge[50, 219] -> 
             RGBColor[
              0.6194274809388088, 0.6914565257706566, 0.9539165025229503], 
             UndirectedEdge[326, 405] -> 
             RGBColor[
              0.40619921231564, 0.5236726787305142, 0.9475915514322624], 
             UndirectedEdge[180, 343] -> 
             RGBColor[
              0.388476854004608, 0.5109008583495491, 0.9459743795139477], 
             UndirectedEdge[229, 380] -> 
             RGBColor[
              0.25614730305281597`, 0.38655743455850555`, 0.9378985820216569],
              UndirectedEdge[184, 470] -> 
             RGBColor[
              0.3093031180695711, 0.4384844337247014, 0.9410701044535641], 
             UndirectedEdge[188, 483] -> 
             RGBColor[
              0.26622599622184506`, 0.3971507801052104, 0.9384725486875427], 
             UndirectedEdge[364, 374] -> 
             RGBColor[
              0.7765895732071173, 0.8260875801030143, 0.9782221515537421], 
             UndirectedEdge[161, 469] -> 
             RGBColor[
              0.34808831402287965`, 0.4744841510034171, 0.9434533699622962], 
             UndirectedEdge[14, 182] -> 
             RGBColor[
              0.39771375374761364`, 0.5189013966468605, 0.9465629465977023], 
             UndirectedEdge[374, 391] -> 
             RGBColor[
              0.4605995891779458, 0.5661920457418392, 0.9520239146904479], 
             UndirectedEdge[352, 367] -> 
             RGBColor[
              0.3939398952088271, 0.5087303852608752, 0.9470806400178498], 
             UndirectedEdge[8, 289] -> 
             RGBColor[
              0.32285153478371575`, 0.44561825224256757`, 0.94210186782703], 
             UndirectedEdge[160, 275] -> 
             RGBColor[
              0.2574964707930593, 0.3879754953956767, 0.9379754151285489], 
             UndirectedEdge[118, 151] -> 
             RGBColor[
              0.5376562475503729, 0.6332373805422357, 0.9576356046449903], 
             UndirectedEdge[43, 217] -> 
             RGBColor[
              0.24176066032957486`, 0.3714361608905463, 0.9370792840016989], 
             UndirectedEdge[117, 154] -> 
             RGBColor[
              0.7958334675066234, 0.8402318885917122, 0.9438922548914919], 
             UndirectedEdge[139, 468] -> 
             RGBColor[
              0.3700121926415567, 0.49382865505685797`, 0.9448373366213064], 
             UndirectedEdge[279, 324] -> 
             RGBColor[
              0.3099677132825357, 0.4406360535746322, 0.9410547474927063], 
             UndirectedEdge[4, 29] -> 
             RGBColor[
              0.31811818069606457`, 0.4476590646210784, 0.9415754250318544], 
             UndirectedEdge[239, 393] -> 
             RGBColor[
              0.28310252138251873`, 0.41297219579475497`, 0.9395038282794985],
              UndirectedEdge[94, 127] -> 
             RGBColor[
              0.9184004336535858, 0.9341764712610934, 0.8387746026116247], 
             UndirectedEdge[157, 459] -> 
             RGBColor[
              0.29887710948701884`, 0.4283063368961296, 0.940447788111162], 
             UndirectedEdge[48, 85] -> 
             RGBColor[
              0.30404106398692576`, 0.43689681394008617`, 0.9406260608543845],
              UndirectedEdge[26, 215] -> 
             RGBColor[
              0.4880599643423429, 0.5952680917607718, 0.9528410146970379], 
             UndirectedEdge[63, 165] -> 
             RGBColor[
              0.354800872127908, 0.48017294806490846`, 0.9438856754675478], 
             UndirectedEdge[165, 282] -> 
             RGBColor[
              0.39597071268393647`, 0.5173916620852946, 0.9464518815624354], 
             UndirectedEdge[288, 465] -> 
             RGBColor[
              0.40371533475362487`, 0.5240996644660352, 0.9469453620324155], 
             UndirectedEdge[200, 500] -> 
             RGBColor[
              0.3581507498008384, 0.48463391112256027`, 0.9440420269704045], 
             UndirectedEdge[293, 353] -> 
             RGBColor[
              0.2965367965467848, 0.4251729542569518, 0.9403391732785711], 
             UndirectedEdge[239, 296] -> 
             RGBColor[
              0.32530825209623004`, 0.45618739032275973`, 0.9419493320581473],
              UndirectedEdge[139, 274] -> 
             RGBColor[
              0.34955695302954765`, 0.47232890128753746`, 0.9436724409862176],
              UndirectedEdge[140, 361] -> 
             RGBColor[
              0.3287694966291768, 0.4587662134573439, 0.9421852260082336], 
             UndirectedEdge[83, 197] -> 
             RGBColor[
              0.2788673793562445, 0.410437675289448, 0.9391924567557963], 
             UndirectedEdge[256, 444] -> 
             RGBColor[
              0.2758381567400775, 0.4072537702560496, 0.9390199470091389], 
             UndirectedEdge[21, 166] -> 
             RGBColor[
              0.28577889105566956`, 0.4165018239239971, 0.939630005559642], 
             UndirectedEdge[92, 363] -> 
             RGBColor[
              0.35638621296534145`, 0.4808392776040668, 0.9440125718706505], 
             UndirectedEdge[41, 212] -> 
             RGBColor[
              0.2943157662196394, 0.4252502309614521, 0.9401243839892195], 
             UndirectedEdge[96, 433] -> 
             RGBColor[
              0.4592438572077636, 0.5586741907345053, 0.9528628545174622], 
             UndirectedEdge[346, 407] -> 
             RGBColor[
              0.39044423236130543`, 0.5015248450823406, 0.9472030150788647], 
             UndirectedEdge[32, 155] -> 
             RGBColor[
              0.44604009931008093`, 0.5580877416751188, 0.9503804038218301], 
             UndirectedEdge[302, 477] -> 
             RGBColor[
              0.34197181958586076`, 0.4706205349470234, 0.9430111198435724], 
             UndirectedEdge[24, 489] -> 
             RGBColor[
              0.26922849193316434`, 0.39931917483979734`, 0.9386796906094406],
              UndirectedEdge[359, 427] -> 
             RGBColor[
              0.3798105362455182, 0.49360924614125157`, 0.9463005971309183], 
             UndirectedEdge[217, 290] -> 
             RGBColor[
              0.2359834862163146, 0.3653639846035148, 0.936750282482512], 
             UndirectedEdge[40, 297] -> 
             RGBColor[
              0.3831607572524005, 0.5044783230322123, 0.9458225464237728], 
             UndirectedEdge[41, 456] -> 
             RGBColor[
              0.3037155855571926, 0.4333918820229836, 0.9407233321654745], 
             UndirectedEdge[341, 469] -> 
             RGBColor[
              0.3549588484578457, 0.4817055183116096, 0.9438446367343227], 
             UndirectedEdge[169, 498] -> 
             RGBColor[
              0.28485287388252356`, 0.41672880953883923`, 0.9395333218143223],
              UndirectedEdge[6, 329] -> 
             RGBColor[
              0.4875722816861491, 0.5925859189811347, 0.953434320226935], 
             UndirectedEdge[92, 219] -> 
             RGBColor[
              0.6896832755948983, 0.7542242136423976, 0.9583229983141339], 
             UndirectedEdge[341, 387] -> 
             RGBColor[
              0.2532538915932333, 0.38351627566160185`, 0.9377338065194523], 
             UndirectedEdge[13, 478] -> 
             RGBColor[
              0.4433507185666713, 0.5563965480514267, 0.9500326987596728], 
             UndirectedEdge[33, 267] -> 
             RGBColor[
              0.2665892063174661, 0.39753253694455826`, 0.9384932329651671], 
             UndirectedEdge[10, 123] -> 
             RGBColor[
              0.29749598901382146`, 0.42863883134932146`, 0.9403038092514042],
              UndirectedEdge[57, 337] -> 
             RGBColor[
              0.294335011870674, 0.4265200024896363, 0.9400797281055944], 
             UndirectedEdge[70, 135] -> 
             RGBColor[
              0.3591358164811806, 0.4824951420691387, 0.9442143457500742], 
             UndirectedEdge[51, 130] -> 
             RGBColor[
              0.3880132521814675, 0.5087838753638209, 0.9461712298718947], 
             UndirectedEdge[219, 361] -> 
             RGBColor[
              0.6275205376953439, 0.6999628415512102, 0.9543773901326305], 
             UndirectedEdge[70, 131] -> 
             RGBColor[
              0.3602305454110867, 0.48344334124554744`, 0.9442841009094571], 
             UndirectedEdge[61, 362] -> 
             RGBColor[
              0.31495135328484847`, 0.4454401185782792, 0.9413544513573335], 
             UndirectedEdge[49, 487] -> 
             RGBColor[
              0.7578819757802534, 0.8067743962627472, 0.8269552942105451], 
             UndirectedEdge[83, 375] -> 
             RGBColor[
              0.41367779680147115`, 0.5300719429883098, 0.948150453468378], 
             UndirectedEdge[147, 385] -> 
             RGBColor[
              0.2660750496677814, 0.39699212570632525`, 0.9384639525045941], 
             UndirectedEdge[105, 395] -> 
             RGBColor[
              0.33117001542650737`, 0.4597180786033884, 0.9423794625142928], 
             UndirectedEdge[57, 204] -> 
             RGBColor[
              0.2660464834000242, 0.39678696547068504`, 0.9384687382583186], 
             UndirectedEdge[362, 363] -> 
             RGBColor[
              0.3123034480987857, 0.4426570023408417, 0.9412036570742119], 
             UndirectedEdge[313, 390] -> 
             RGBColor[
              0.6654138441328434, 0.7382139311867708, 0.9675126684872362], 
             UndirectedEdge[15, 430] -> 
             RGBColor[
              0.6285621040660173, 0.7003228038665852, 0.9502251099678711], 
             UndirectedEdge[104, 430] -> 
             RGBColor[
              0.32511496555943264`, 0.4553483446766945, 0.9419616076959052], 
             UndirectedEdge[341, 405] -> 
             RGBColor[
              0.3027953305526198, 0.4355874691165689, 0.9405551181781983], 
             UndirectedEdge[8, 311] -> 
             RGBColor[
              0.2603221980152278, 0.3909455138676296, 0.9381363361135626], 
             UndirectedEdge[305, 460] -> 
             RGBColor[
              0.23284859603300734`, 0.3620690162573412, 0.936571755124227], 
             UndirectedEdge[451, 456] -> 
             RGBColor[
              0.354065538732443, 0.4810955066237947, 0.9437817209335367], 
             UndirectedEdge[257, 306] -> 
             RGBColor[
              0.43250550911001784`, 0.5364048876289329, 0.9504475285509812], 
             UndirectedEdge[65, 167] -> 
             RGBColor[
              0.44905203715227315`, 0.5547512658539029, 0.9513029053456352], 
             UndirectedEdge[24, 329] -> 
             RGBColor[
              0.34427147343229764`, 0.472612379524844, 0.9431576517531632], 
             UndirectedEdge[14, 63] -> 
             RGBColor[
              0.3376390910069228, 0.4653082758341107, 0.9427921419500858], 
             UndirectedEdge[64, 172] -> 
             RGBColor[
              0.26046140707979504`, 0.39109183142085413`, 0.9381442638638484],
              UndirectedEdge[50, 361] -> 
             RGBColor[
              0.296119661050762, 0.4285709172082235, 0.9401749486758355], 
             UndirectedEdge[253, 291] -> 
             RGBColor[
              0.2849097288408444, 0.416788567704847, 0.9395365596200893], 
             UndirectedEdge[184, 280] -> 
             RGBColor[
              0.3012488595399585, 0.4315082398051553, 0.9405568942221585], 
             UndirectedEdge[402, 487] -> 
             RGBColor[
              0.4220898232163256, 0.5381837406408712, 0.9486220740274163], 
             UndirectedEdge[356, 463] -> 
             RGBColor[
              0.6723047873504713, 0.7358787584542094, 0.8806694691799348], 
             UndirectedEdge[287, 301] -> 
             RGBColor[
              0.25411397400587754`, 0.3844202768096656, 0.9377827869404745], 
             UndirectedEdge[265, 328] -> 
             RGBColor[
              0.38043531552122956`, 0.5039356818947229, 0.9454619797926401], 
             UndirectedEdge[196, 321] -> 
             RGBColor[
              0.2732003607215455, 0.4044812793946452, 0.938869728428153], 
             UndirectedEdge[122, 267] -> 
             RGBColor[
              0.2815005513588358, 0.4130690547237326, 0.9393474008332019], 
             UndirectedEdge[330, 354] -> 
             RGBColor[
              0.5167892615681375, 0.6168451987337982, 0.9555941813246566], 
             UndirectedEdge[155, 393] -> 
             RGBColor[
              0.28854948971623084`, 0.4176900859928276, 0.9398509042851577], 
             UndirectedEdge[291, 319] -> 
             RGBColor[
              0.2695841570597229, 0.40068042006551474`, 0.9386637909793061], 
             UndirectedEdge[63, 206] -> 
             RGBColor[
              0.27665587734436636`, 0.40811324645763797`, 0.9390665149878439],
              UndirectedEdge[174, 215] -> 
             RGBColor[
              0.4398699033786755, 0.5545273899993016, 0.9494943304002132], 
             UndirectedEdge[254, 471] -> 
             RGBColor[
              0.2860856278742372, 0.4180245121452477, 0.9396035253304542], 
             UndirectedEdge[453, 463] -> 
             RGBColor[
              0.7335992451074071, 0.788317044185302, 0.8847552177585984], 
             UndirectedEdge[154, 174] -> 
             RGBColor[
              0.6850398800825048, 0.7486668237929202, 0.935617191667427], 
             UndirectedEdge[119, 197] -> 
             RGBColor[
              0.2442013782633833, 0.37400151018943395`, 0.9372182792773107], 
             UndirectedEdge[50, 340] -> 
             RGBColor[
              0.31347943766608943`, 0.4440262160973234, 0.9412657517820111], 
             UndirectedEdge[443, 446] -> 
             RGBColor[
              0.7525576159623661, 0.8062599449382872, 0.9716342132304894], 
             UndirectedEdge[275, 324] -> 
             RGBColor[
              0.3090360126162909, 0.4396567771011748, 0.9410016885180913], 
             UndirectedEdge[95, 286] -> 
             RGBColor[
              0.26630691156405256`, 0.39723582726019957`, 0.9384771566965778],
              UndirectedEdge[306, 317] -> 
             RGBColor[
              0.2682938890924092, 0.39920117665536264`, 0.9385948190540765], 
             UndirectedEdge[118, 188] -> 
             RGBColor[
              0.47371131772079367`, 0.5737182375902918, 0.9537124291087762], 
             UndirectedEdge[7, 69] -> 
             RGBColor[
              0.321538390545854, 0.4482182987670864, 0.9418813499609677], 
             UndirectedEdge[88, 166] -> 
             RGBColor[
              0.40190341750290814`, 0.5143499188145482, 0.947784530582329], 
             UndirectedEdge[9, 44] -> 
             RGBColor[
              0.33659571898854923`, 0.46439222193433743`, 0.9427261109439626],
              UndirectedEdge[76, 459] -> 
             RGBColor[
              0.28353126567922415`, 0.41501453829435436`, 0.9394699645135263],
              UndirectedEdge[254, 325] -> 
             RGBColor[
              0.28091831401092354`, 0.4125933376482833, 0.9393092544502943], 
             UndirectedEdge[171, 433] -> 
             RGBColor[
              0.48057491244458045`, 0.5810944822554165, 0.9540776265567306], 
             UndirectedEdge[112, 447] -> 
             RGBColor[
              0.5846423256180342, 0.5645291766461142, 0.5997421010998638], 
             UndirectedEdge[199, 359] -> 
             RGBColor[
              0.28466785963074936`, 0.4133715143787149, 0.9396385923525489], 
             UndirectedEdge[74, 224] -> 
             RGBColor[
              0.6976226433705784, 0.7622346632774594, 0.9717109409018184], 
             UndirectedEdge[292, 386] -> 
             RGBColor[
              0.3061715805125721, 0.43631400249943886`, 0.9408507222341252], 
             UndirectedEdge[112, 195] -> 
             RGBColor[
              0.41552875366554476`, 0.5241484862103478, 0.948972141657091], 
             UndirectedEdge[97, 408] -> 
             RGBColor[
              0.43198617982599313`, 0.5395557697184639, 0.9500814541504072], 
             UndirectedEdge[236, 422] -> 
             RGBColor[
              0.3017990197957033, 0.4328123991625194, 0.9405616460585365], 
             UndirectedEdge[27, 114] -> 
             RGBColor[
              0.24729668270626515`, 0.37725487141253955`, 0.9373945522862401],
              UndirectedEdge[110, 355] -> 
             RGBColor[
              0.42680563388783554`, 0.5429812306324326, 0.9487255871818152], 
             UndirectedEdge[104, 215] -> 
             RGBColor[
              0.4173768896384118, 0.5350450720292275, 0.9480610954544748], 
             UndirectedEdge[80, 406] -> 
             RGBColor[
              0.3061732125806364, 0.4377803881334361, 0.9407971864261129], 
             UndirectedEdge[276, 292] -> 
             RGBColor[
              0.40878302652925425`, 0.5278108219890958, 0.9474556657364718], 
             UndirectedEdge[425, 466] -> 
             RGBColor[
              0.3225286397634498, 0.45377982982748355`, 0.9417722176182173], 
             UndirectedEdge[164, 309] -> 
             RGBColor[
              0.29295359391941944`, 0.423222484836137, 0.9400686333818631], 
             UndirectedEdge[95, 137] -> 
             RGBColor[
              0.338696787302305, 0.466491538083847, 0.9428497561597331], 
             UndirectedEdge[119, 426] -> 
             RGBColor[
              0.3171946930899777, 0.44206638032073886`, 0.9416920693149147], 
             UndirectedEdge[238, 431] -> 
             RGBColor[
              0.31900858761708273`, 0.43974610626002925`, 0.9419501314933074],
              UndirectedEdge[93, 266] -> 
             RGBColor[
              0.3154935810823781, 0.44003630315180225`, 0.9416040579912919], 
             UndirectedEdge[15, 148] -> 
             RGBColor[
              0.6230794710862638, 0.6945602089858558, 0.949912882130503], 
             UndirectedEdge[225, 470] -> 
             RGBColor[
              0.41906099483556025`, 0.5364841542788533, 0.9481738220756919], 
             UndirectedEdge[249, 296] -> 
             RGBColor[
              0.3013612667574289, 0.4329344726929359, 0.9405154002188556], 
             UndirectedEdge[273, 421] -> 
             RGBColor[
              0.3479739248626753, 0.46705652580875434`, 0.9438585965552035], 
             UndirectedEdge[150, 159] -> 
             RGBColor[
              0.2849619295036293, 0.41640189288704943`, 0.9395556993504453], 
             UndirectedEdge[85, 407] -> 
             RGBColor[
              0.26350558177969313`, 0.3942914520422709, 0.9383176251095546], 
             UndirectedEdge[71, 388] -> 
             RGBColor[
              0.3267610757530868, 0.4572217122659371, 0.9420501079312581], 
             UndirectedEdge[61, 435] -> 
             RGBColor[
              0.29202151889346295`, 0.42426350996368195`, 0.9399415655426353],
              UndirectedEdge[10, 177] -> 
             RGBColor[
              0.2676877403491438, 0.39868716586293196`, 0.9385557928531356], 
             UndirectedEdge[16, 52] -> 
             RGBColor[
              0.4103653731290986, 0.5232268275873317, 0.9482679869093358], 
             UndirectedEdge[25, 459] -> 
             RGBColor[
              0.26830693944866735`, 0.3993379833760218, 0.9385910553258305], 
             UndirectedEdge[105, 453] -> 
             RGBColor[
              0.4238236069137007, 0.540864546311006, 0.9484067632843612], 
             UndirectedEdge[61, 384] -> 
             RGBColor[
              0.36343881876773854`, 0.487437524128683, 0.944444029782121], 
             UndirectedEdge[104, 323] -> 
             RGBColor[
              0.3792952017648078, 0.502948172662694, 0.9453893327522439], 
             UndirectedEdge[150, 406] -> 
             RGBColor[
              0.31847481148381074`, 0.45026860752299386`, 0.9415139112648983],
              UndirectedEdge[413, 493] -> 
             RGBColor[
              0.33164127600369253`, 0.45591516477914573`, 0.9425636796765045],
              UndirectedEdge[94, 254] -> 
             RGBColor[
              0.6449605053150302, 0.7094905242561114, 0.8164407156805107], 
             UndirectedEdge[431, 487] -> 
             RGBColor[
              0.4844166114436812, 0.5921680719679449, 0.9525934818598486], 
             UndirectedEdge[234, 332] -> 
             RGBColor[
              0.41336704967959653`, 0.5309523385528478, 0.9479767925415625], 
             UndirectedEdge[82, 89] -> 
             RGBColor[
              0.3055098740032732, 0.4374904093006864, 0.9407444995144895], 
             UndirectedEdge[154, 255] -> 
             RGBColor[
              0.6668213853459879, 0.7328868793403194, 0.9344563252927984], 
             UndirectedEdge[22, 324] -> 
             RGBColor[
              0.38608906873154425`, 0.5088326787595987, 0.9458222319477837], 
             UndirectedEdge[105, 112] -> 
             RGBColor[
              0.30479497781971926`, 0.4319962418046839, 0.9408774431409578], 
             UndirectedEdge[6, 406] -> 
             RGBColor[
              0.46472768714041934`, 0.5727990793883309, 0.9519786828631629], 
             UndirectedEdge[396, 422] -> 
             RGBColor[
              0.35081546325813295`, 0.4782804546014903, 0.9435746289982425], 
             UndirectedEdge[409, 456] -> 
             RGBColor[
              0.2908145073712155, 0.41983203087392074`, 0.939988634848218], 
             UndirectedEdge[91, 473] -> 
             RGBColor[
              0.4760848985814824, 0.5799041126377497, 0.9532632471440154], 
             UndirectedEdge[369, 379] -> 
             RGBColor[
              0.3875414135304541, 0.5097846401834374, 0.9459993190955385], 
             UndirectedEdge[353, 441] -> 
             RGBColor[
              0.6196420418670605, 0.6960728248557465, 0.966408487569707], 
             UndirectedEdge[165, 481] -> 
             RGBColor[
              0.6357000790067175, 0.7111976952987178, 0.966871805174918], 
             UndirectedEdge[185, 318] -> 
             RGBColor[
              0.6096409019279856, 0.6872497440513867, 0.9658451549646596], 
             UndirectedEdge[264, 445] -> 
             RGBColor[
              0.31239998501238053`, 0.44271636289173955`, 0.9412106964106456],
              UndirectedEdge[258, 297] -> 
             RGBColor[
              0.27211292059160214`, 0.4033383108703882, 0.9388078003214761], 
             UndirectedEdge[57, 139] -> 
             RGBColor[
              0.37679469277244215`, 0.5007823574527431, 0.9452300025303637], 
             UndirectedEdge[447, 463] -> 
             RGBColor[
              0.9599434874845505, 0.8751601710841241, 0.5400305852200534], 
             UndirectedEdge[9, 26] -> 
             RGBColor[
              0.3909299613000729, 0.5104547047637868, 0.9464642970431865], 
             UndirectedEdge[181, 262] -> 
             RGBColor[
              0.5567976449640942, 0.6460763644522418, 0.9604383635297966], 
             UndirectedEdge[203, 291] -> 
             RGBColor[
              0.3121473288634293, 0.4425217797059569, 0.9411937092945858], 
             UndirectedEdge[45, 254] -> 
             RGBColor[
              0.29606565363876014`, 0.4285141519939419, 0.9401718730336188], 
             UndirectedEdge[240, 412] -> 
             RGBColor[
              0.6147550941661437, 0.3327840114135426, 0.5558517179637725], 
             UndirectedEdge[208, 258] -> 
             RGBColor[
              0.5858383193119274, 0.6602036653609511, 0.9649755364333811], 
             UndirectedEdge[293, 420] -> 
             RGBColor[
              0.28900980916776353`, 0.4186534561066293, 0.9398595602986335], 
             UndirectedEdge[85, 346] -> 
             RGBColor[
              0.43356600692703734`, 0.5468485642293452, 0.9496587363474345], 
             UndirectedEdge[65, 166] -> 
             RGBColor[
              0.25870844006325056`, 0.3892493519419377, 0.9380444349855384], 
             UndirectedEdge[254, 347] -> 
             RGBColor[
              0.2947394919269464, 0.42712027195131663`, 0.9400963500860113], 
             UndirectedEdge[236, 292] -> 
             RGBColor[
              0.30771656630120964`, 0.43793788052105365`, 0.9409387068891866],
              UndirectedEdge[100, 401] -> 
             RGBColor[
              0.3120130045924957, 0.43922449450471057`, 0.9413016200762929], 
             UndirectedEdge[146, 400] -> 
             RGBColor[
              0.32965525240148197`, 0.4592610301929909, 0.942251638763349], 
             UndirectedEdge[104, 153] -> 
             RGBColor[
              0.3794220407283058, 0.5030580341977643, 0.9453974148188387], 
             UndirectedEdge[216, 281] -> 
             RGBColor[
              0.31679925020627686`, 0.447376576041843, 0.9414598986964259], 
             UndirectedEdge[123, 125] -> 
             RGBColor[
              0.27046643321770947`, 0.4002290544347874, 0.9387645160354601], 
             UndirectedEdge[78, 358] -> 
             RGBColor[
              0.2531642928743813, 0.3829773062768713, 0.9377449901452841], 
             UndirectedEdge[313, 478] -> 
             RGBColor[
              0.4896026583804799, 0.5939459564184202, 0.9536738208882539], 
             UndirectedEdge[368, 401] -> 
             RGBColor[
              0.2692342202205126, 0.4003126142602277, 0.9386438625939981], 
             UndirectedEdge[106, 369] -> 
             RGBColor[
              0.44019245379627414`, 0.5553883249434619, 0.9493541968237897], 
             UndirectedEdge[111, 146] -> 
             RGBColor[
              0.32967340890759744`, 0.4592801138321072, 0.9422526727495122], 
             UndirectedEdge[129, 266] -> 
             RGBColor[
              0.26642696296001067`, 0.3973620088890497, 0.9384839934459775], 
             UndirectedEdge[99, 278] -> 
             RGBColor[
              0.3480749767302752, 0.47556924839428116`, 0.943412366412149], 
             UndirectedEdge[147, 171] -> 
             RGBColor[
              0.2657864205020068, 0.39668875815295, 0.9384475155005918], 
             UndirectedEdge[164, 166] -> 
             RGBColor[
              0.2902155923646239, 0.4203446716027217, 0.9399127082438278], 
             UndirectedEdge[129, 433] -> 
             RGBColor[
              0.49451496106477116`, 0.5957463572053683, 0.9548714917031966], 
             UndirectedEdge[179, 283] -> 
             RGBColor[
              0.2535768247870206, 0.3838556989234194, 0.9377521970871017], 
             UndirectedEdge[136, 291] -> 
             RGBColor[
              0.31762350110452786`, 0.4472649648607767, 0.9415426461473997], 
             UndirectedEdge[321, 479] -> 
             RGBColor[
              0.29854524789968917`, 0.43085175813741416`, 0.9403229171902149],
              UndirectedEdge[181, 239] -> 
             RGBColor[
              0.33581243437377495`, 0.4652855850560169, 0.9426186492643888], 
             UndirectedEdge[102, 330] -> 
             RGBColor[
              0.32608414032339095`, 0.4525719738083635, 0.9421557555865334], 
             UndirectedEdge[406, 413] -> 
             RGBColor[
              0.2849504445032486, 0.4154739132828872, 0.9395885811803774], 
             UndirectedEdge[37, 310] -> 
             RGBColor[
              0.33632541868809496`, 0.4653092457110544, 0.942666738615579], 
             UndirectedEdge[203, 439] -> 
             RGBColor[
              0.3505993857517805, 0.4780932991258592, 0.9435608607306076], 
             UndirectedEdge[320, 375] -> 
             RGBColor[
              0.40508782360435214`, 0.5210433365223803, 0.9476612672025286], 
             UndirectedEdge[42, 407] -> 
             RGBColor[
              0.25430606927725014`, 0.38462218111942187`, 0.9377937264819997],
              UndirectedEdge[131, 374] -> 
             RGBColor[
              0.540207669136569, 0.6373530049319269, 0.9570156092873463], 
             UndirectedEdge[387, 403] -> 
             RGBColor[
              0.29663343242346357`, 0.4212531819069062, 0.9404919176071266], 
             UndirectedEdge[65, 348] -> 
             RGBColor[
              0.3553802673769295, 0.47842885056261164`, 0.9440048289058678], 
             UndirectedEdge[217, 498] -> 
             RGBColor[
              0.2359834862163146, 0.3653639846035148, 0.936750282482512], 
             UndirectedEdge[40, 397] -> 
             RGBColor[
              0.43276885159663775`, 0.5487622995296364, 0.9489353473720077], 
             UndirectedEdge[226, 292] -> 
             RGBColor[
              0.3145762866890646, 0.4451478815800822, 0.9413293578172279], 
             UndirectedEdge[53, 257] -> 
             RGBColor[
              0.5136117947393171, 0.6142583137792799, 0.9553371575610968], 
             UndirectedEdge[220, 429] -> 
             RGBColor[
              0.32997514703503206`, 0.45796333975400405`, 0.9423296821039597],
              UndirectedEdge[139, 425] -> 
             RGBColor[
              0.3804289191530794, 0.5039301416821221, 0.9454615722217177], 
             UndirectedEdge[317, 418] -> 
             RGBColor[
              0.5713669376362989, 0.6561984371543547, 0.9624397750260384], 
             UndirectedEdge[482, 496] -> 
             RGBColor[
              0.2705740150244454, 0.401720823547058, 0.9387201619260334], 
             UndirectedEdge[117, 466] -> 
             RGBColor[
              0.47123499143557546`, 0.5781830254669618, 0.9524630486552241], 
             UndirectedEdge[82, 105] -> 
             RGBColor[
              0.3446719574712672, 0.4729592586704864, 0.9431831702419924], 
             UndirectedEdge[239, 453] -> 
             RGBColor[
              0.4034027197703711, 0.5231770002510852, 0.9471055624130698], 
             UndirectedEdge[274, 340] -> 
             RGBColor[
              0.29754851494601664`, 0.42728180623968703`, 0.9403585093007911],
              UndirectedEdge[311, 484] -> 
             RGBColor[
              0.32096443420260157`, 0.451912023908013, 0.9416913301559519], 
             UndirectedEdge[44, 140] -> 
             RGBColor[
              0.3673860661762516, 0.4926330779864455, 0.9446304931633762], 
             UndirectedEdge[139, 466] -> 
             RGBColor[
              0.3850488678153844, 0.5079317090080392, 0.9457559512652196], 
             UndirectedEdge[22, 481] -> 
             RGBColor[
              0.6450888019786325, 0.719329735246053, 0.9674700463005667], 
             UndirectedEdge[45, 386] -> 
             RGBColor[
              0.28512175626100705`, 0.4170114219667529, 0.9395486342680011], 
             UndirectedEdge[40, 220] -> 
             RGBColor[
              0.42376229058003245`, 0.5409612690599719, 0.9483614572682189], 
             UndirectedEdge[237, 489] -> 
             RGBColor[
              0.2505252702505092, 0.3806483216258134, 0.9375784155706177], 
             UndirectedEdge[61, 64] -> 
             RGBColor[
              0.27811257574438586`, 0.4096443288360715, 0.9391494718067328], 
             UndirectedEdge[82, 296] -> 
             RGBColor[
              0.3200805952182977, 0.4516594566847692, 0.9416162303845209], 
             UndirectedEdge[27, 277] -> 
             RGBColor[
              0.3020685901948561, 0.43167004850533464`, 0.9406291990510607], 
             UndirectedEdge[416, 427] -> 
             RGBColor[
              0.3798915071516326, 0.4936943516974298, 0.9463052083042358], 
             UndirectedEdge[59, 82] -> 
             RGBColor[
              0.4245417971530002, 0.5400547692936607, 0.9488481466449648], 
             UndirectedEdge[271, 444] -> 
             RGBColor[
              0.2950692250735618, 0.4252292764553648, 0.9401970561509414], 
             UndirectedEdge[6, 486] -> 
             RGBColor[
              0.587488686021932, 0.6759888072331292, 0.9606684078870635], 
             UndirectedEdge[171, 265] -> 
             RGBColor[
              0.3553842382671266, 0.47948473659352187`, 0.9439665467002543], 
             UndirectedEdge[219, 369] -> 
             RGBColor[
              0.7077078053653257, 0.7695301687463293, 0.9595560504340661], 
             UndirectedEdge[244, 355] -> 
             RGBColor[
              0.4561323830412466, 0.5667900067501652, 0.9510342963025935], 
             UndirectedEdge[450, 500] -> 
             RGBColor[
              0.3122001431592851, 0.44147392499285676`, 0.9412371166206852], 
             UndirectedEdge[18, 243] -> 
             RGBColor[
              0.34190939770641676`, 0.46600027443800157`, 0.9431743331002125],
              UndirectedEdge[377, 449] -> 
             RGBColor[
              0.5967028863648051, 0.6796655143405466, 0.9633936567675865], 
             UndirectedEdge[7, 173] -> 
             RGBColor[
              0.32446237655312204`, 0.4507509084827721, 0.9420676637637716], 
             UndirectedEdge[3, 8] -> 
             RGBColor[
              0.26840771422101617`, 0.3984617512971438, 0.938632755723555], 
             UndirectedEdge[405, 469] -> 
             RGBColor[
              0.350779041073767, 0.4773122757358482, 0.9436066028872704], 
             UndirectedEdge[148, 190] -> 
             RGBColor[
              0.6344838590258952, 0.6808273711278703, 0.6553217203597179], 
             UndirectedEdge[180, 216] -> 
             RGBColor[
              0.34040402642448997`, 0.4692625913102195, 0.9429112214496749], 
             UndirectedEdge[257, 317] -> 
             RGBColor[
              0.4742889436784011, 0.5801988366142758, 0.9528315402633272], 
             UndirectedEdge[49, 462] -> 
             RGBColor[
              0.6986105836620926, 0.757267477679697, 0.8226726676783305], 
             UndirectedEdge[223, 258] -> 
             RGBColor[
              0.3344423085658754, 0.45864083251934057`, 0.9427311908508187], 
             UndirectedEdge[260, 440] -> 
             RGBColor[
              0.31122543924299084`, 0.44129447743268657`, 0.9411506680580078],
              UndirectedEdge[262, 332] -> 
             RGBColor[
              0.6401372783222783, 0.7167538098225676, 0.9661651230417763], 
             UndirectedEdge[283, 386] -> 
             RGBColor[
              0.2877444862318391, 0.419768077456782, 0.9396979948598587], 
             UndirectedEdge[40, 289] -> 
             RGBColor[
              0.45003249277929525`, 0.5637151978262191, 0.9500353713225281], 
             UndirectedEdge[95, 430] -> 
             RGBColor[
              0.29812504849534394`, 0.43067870656138685`, 0.9402891525240995],
              UndirectedEdge[274, 334] -> 
             RGBColor[
              0.24490547640045296`, 0.37474156197389447`, 0.937258376624597], 
             UndirectedEdge[75, 158] -> 
             RGBColor[
              0.4623984733116038, 0.5715053840952693, 0.9516302924024227], 
             UndirectedEdge[233, 476] -> 
             RGBColor[
              0.27831597424145443`, 0.4098581135527001, 0.9391610550502397], 
             UndirectedEdge[240, 416] -> 
             RGBColor[
              0.5219309513185014, 0.2447841663470438, 0.550215327606881], 
             UndirectedEdge[260, 280] -> 
             RGBColor[
              0.3390702090770449, 0.4681073057634717, 0.942826231787744], 
             UndirectedEdge[11, 193] -> 
             RGBColor[
              0.2762674869443633, 0.40753560277845297`, 0.93905060005248], 
             UndirectedEdge[3, 162] -> 
             RGBColor[
              0.31523669443681684`, 0.44746391328938273`, 0.9413075813100182],
              UndirectedEdge[117, 338] -> 
             RGBColor[
              0.4516494351096884, 0.559298809009243, 0.9512853819591678], 
             UndirectedEdge[40, 472] -> 
             RGBColor[
              0.3658979641603133, 0.4863340329681299, 0.9448394558951922], 
             UndirectedEdge[101, 355] -> 
             RGBColor[
              0.3195101137827394, 0.4484988210751082, 0.9416775139247157], 
             UndirectedEdge[47, 364] -> 
             RGBColor[
              0.611845117624745, 0.6881884164419859, 0.9663581210918899], 
             UndirectedEdge[377, 484] -> 
             RGBColor[
              0.36886822045671325`, 0.4939168455289412, 0.9447249347235096], 
             UndirectedEdge[21, 227] -> 
             RGBColor[
              0.2982345602975174, 0.429593522032222, 0.9403393374964539], 
             UndirectedEdge[158, 441] -> 
             RGBColor[
              0.6172344713019065, 0.693987508240225, 0.9662550793022264], 
             UndirectedEdge[201, 222] -> 
             RGBColor[
              0.3759689197106828, 0.5000671143312081, 0.9451773850010707], 
             UndirectedEdge[107, 477] -> 
             RGBColor[
              0.3402172540251079, 0.46910081844532847`, 0.9428993204775427], 
             UndirectedEdge[89, 239] -> 
             RGBColor[
              0.3107375308812055, 0.4420183429386769, 0.9410776011881159], 
             UndirectedEdge[63, 275] -> 
             RGBColor[
              0.28713653898456953`, 0.41912908635381985`, 0.939663373163504], 
             UndirectedEdge[133, 344] -> 
             RGBColor[
              0.3181516049782057, 0.4495884985286597, 0.9415079687878125], 
             UndirectedEdge[153, 356] -> 
             RGBColor[
              0.3824168430804902, 0.5056519814720835, 0.9455882409765202], 
             UndirectedEdge[151, 188] -> 
             RGBColor[
              0.3279861894154338, 0.45437362633242506`, 0.9422713067043653], 
             UndirectedEdge[140, 204] -> 
             RGBColor[
              0.2873895019556173, 0.41527321541223616`, 0.9398286965277907], 
             UndirectedEdge[154, 369] -> 
             RGBColor[
              0.7204663968575556, 0.7790455053909582, 0.9379590830113207], 
             UndirectedEdge[16, 179] -> 
             RGBColor[
              0.23567420650439913`, 0.36503891201682537`, 0.9367326694604567],
              UndirectedEdge[161, 341] -> 
             RGBColor[
              0.3001046035017325, 0.4327593443841379, 0.9404018852532241], 
             UndirectedEdge[48, 408] -> 
             RGBColor[
              0.27891665528270476`, 0.4104894674124319, 0.9391952629469109], 
             UndirectedEdge[153, 263] -> 
             RGBColor[
              0.41092922049021885`, 0.5303479697106335, 0.9474050244525627], 
             UndirectedEdge[62, 132] -> 
             RGBColor[
              0.3139951319729083, 0.44161875909983606`, 0.9414031148825712], 
             UndirectedEdge[82, 225] -> 
             RGBColor[
              0.40287551934227545`, 0.5224651089122221, 0.9471424978895138], 
             UndirectedEdge[216, 465] -> 
             RGBColor[
              0.3582149734032972, 0.48468953837903794`, 0.9440461192415626], 
             UndirectedEdge[119, 489] -> 
             RGBColor[
              0.22552771074981237`, 0.35437430165376715`, 0.9361548415376282],
              UndirectedEdge[287, 295] -> 
             RGBColor[
              0.24059566696206824`, 0.37021167899645113`, 0.9370129393528726],
              UndirectedEdge[28, 417] -> 
             RGBColor[
              0.6176763058465387, 0.6985509932533778, 0.9643750257247619], 
             UndirectedEdge[148, 351] -> 
             RGBColor[
              0.380632372430137, 0.5019476456177108, 0.9456670151273092], 
             UndirectedEdge[218, 336] -> 
             RGBColor[
              0.2422114841366599, 0.371910005295673, 0.9371049577505783], 
             UndirectedEdge[127, 254] -> 
             RGBColor[
              0.5684012406689775, 0.6520393662645774, 0.9624428693609495], 
             UndirectedEdge[303, 473] -> 
             RGBColor[
              0.2990603185258398, 0.431661734662983, 0.9403424147687283], 
             UndirectedEdge[99, 267] -> 
             RGBColor[
              0.32191805350617964`, 0.4480766636410371, 0.9419227683302369], 
             UndirectedEdge[48, 145] -> 
             RGBColor[
              0.35075818029819944`, 0.4775567151000014, 0.9435956619562396], 
             UndirectedEdge[224, 342] -> 
             RGBColor[
              0.5969170507832606, 0.6766503044248268, 0.9648404453530204], 
             UndirectedEdge[193, 232] -> 
             RGBColor[
              0.31147923305465686`, 0.444209389095656, 0.9410681591933396], 
             UndirectedEdge[216, 343] -> 
             RGBColor[
              0.3885082165558038, 0.5109280230150673, 0.9459763779079771], 
             UndirectedEdge[277, 449] -> 
             RGBColor[
              0.5686274891953951, 0.6553480164228951, 0.9616047172860507], 
             UndirectedEdge[257, 418] -> 
             RGBColor[
              0.7355785576539076, 0.793402148127925, 0.9742924845229431], 
             UndirectedEdge[45, 422] -> 
             RGBColor[
              0.312302272693157, 0.44385198390244013`, 0.9411597907728764], 
             UndirectedEdge[133, 235] -> 
             RGBColor[
              0.27345852191832365`, 0.40475262318082417`, 0.9388844303263942],
              UndirectedEdge[145, 183] -> 
             RGBColor[
              0.3601721354603734, 0.48638473378305214`, 0.944170827877189], 
             UndirectedEdge[196, 496] -> 
             RGBColor[
              0.2541590382800746, 0.3844676422190867, 0.9377853532842233], 
             UndirectedEdge[115, 136] -> 
             RGBColor[
              0.33462799474473903`, 0.4642596829810127, 0.9425431778185854], 
             UndirectedEdge[267, 413] -> 
             RGBColor[
              0.24962716961350437`, 0.37970436091345217`, 0.9375272700679611],
              UndirectedEdge[217, 340] -> 
             RGBColor[
              0.2748727399199594, 0.40344812896012505`, 0.9390671574588602], 
             UndirectedEdge[335, 383] -> 
             RGBColor[
              0.28079389414403, 0.4114391602654937, 0.9393396407644818], 
             UndirectedEdge[80, 493] -> 
             RGBColor[
              0.35286404408108035`, 0.47822163962969466`, 0.9437722849222399],
              UndirectedEdge[307, 372] -> 
             RGBColor[
              0.3800882241337261, 0.49220538077362275`, 0.9464707672050887], 
             UndirectedEdge[18, 434] -> 
             RGBColor[
              0.603918746705492, 0.6863836891153892, 0.9636552978343571], 
             UndirectedEdge[130, 179] -> 
             RGBColor[
              0.2511559053318819, 0.38131115908090973`, 0.9376143293055609], 
             UndirectedEdge[20, 228] -> 
             RGBColor[
              0.6141990182216122, 0.6966209322334698, 0.9634907608323954], 
             UndirectedEdge[297, 311] -> 
             RGBColor[
              0.2988553938489298, 0.43144634583457564`, 0.9403307446115372], 
             UndirectedEdge[127, 200] -> 
             RGBColor[
              0.6030741970608372, 0.6833458269375281, 0.9646055342127372], 
             UndirectedEdge[54, 391] -> 
             RGBColor[
              0.2531790712591283, 0.3834376347465744, 0.9377295456121117], 
             UndirectedEdge[347, 368] -> 
             RGBColor[
              0.2915782394282773, 0.4237975951402305, 0.9399163214328662], 
             UndirectedEdge[22, 182] -> 
             RGBColor[
              0.42426425784051375`, 0.5418981088249936, 0.948254721240813], 
             UndirectedEdge[96, 216] -> 
             RGBColor[
              0.28837181965363623`, 0.4174975441278188, 0.9398409985810678], 
             UndirectedEdge[340, 363] -> 
             RGBColor[
              0.31158325168111456`, 0.44203320440197946`, 0.9411577667953226],
              UndirectedEdge[71, 490] -> 
             RGBColor[
              0.3344860697619291, 0.46413675469425975`, 0.9425341344841802], 
             UndirectedEdge[111, 201] -> 
             RGBColor[
              0.3095308928729859, 0.4418336788352192, 0.9409692094391142], 
             UndirectedEdge[261, 484] -> 
             RGBColor[
              0.5605776317968535, 0.6488842774016733, 0.9608765057254846], 
             UndirectedEdge[416, 499] -> 
             RGBColor[
              0.2648616846420151, 0.39571680213245886`, 0.9383948531613895], 
             UndirectedEdge[42, 430] -> 
             RGBColor[
              0.29485503517138634`, 0.42724171522708787`, 0.9401029301028514],
              UndirectedEdge[6, 81] -> 
             RGBColor[
              0.4340883319350914, 0.5419526235848778, 0.9501841140475359], 
             UndirectedEdge[282, 353] -> 
             RGBColor[
              0.3622293243479529, 0.48816656740015363`, 0.9443019101340049], 
             UndirectedEdge[275, 441] -> 
             RGBColor[
              0.5857190970597057, 0.6642540578297988, 0.9643361566940939], 
             UndirectedEdge[50, 255] -> 
             RGBColor[
              0.3226619172091761, 0.4519796183527037, 0.9418508512587488], 
             UndirectedEdge[110, 217] -> 
             RGBColor[
              0.35265480969791696`, 0.4697009579698158, 0.9443322938716454], 
             UndirectedEdge[30, 110] -> 
             RGBColor[
              0.3842048932390384, 0.5028620961623681, 0.9461290244551464], 
             UndirectedEdge[77, 482] -> 
             RGBColor[
              0.26473982406433677`, 0.395588718938912, 0.9383879133817672], 
             UndirectedEdge[52, 326] -> 
             RGBColor[
              0.5339517146987083, 0.6325250820998627, 0.9564537813921117], 
             UndirectedEdge[44, 247] -> 
             RGBColor[
              0.33964329815179084`, 0.46759542086258354`, 0.9428996660688199],
              UndirectedEdge[337, 348] -> 
             RGBColor[
              0.36060153656838845`, 0.48391673553042214`, 0.9443021724621459],
              UndirectedEdge[48, 78] -> 
             RGBColor[
              0.24711325640661608`, 0.3770620787417092, 0.93738410642983], 
             UndirectedEdge[420, 432] -> 
             RGBColor[
              0.32408289208226404`, 0.45512604506704746`, 0.9418712532016007],
              UndirectedEdge[469, 474] -> 
             RGBColor[
              0.3108855273092358, 0.4353816633744624, 0.9413347262955452], 
             UndirectedEdge[172, 366] -> 
             RGBColor[
              0.4262826250202418, 0.5346681075516071, 0.9496558667770139], 
             UndirectedEdge[102, 415] -> 
             RGBColor[
              0.27775120417397275`, 0.4092645044032864, 0.9391288922303991], 
             UndirectedEdge[414, 485] -> 
             RGBColor[
              0.3990291398410525, 0.5113288707522085, 0.9476208447215991], 
             UndirectedEdge[102, 193] -> 
             RGBColor[
              0.28647597926719104`, 0.4182653754655419, 0.9396319585881541], 
             UndirectedEdge[128, 498] -> 
             RGBColor[
              0.2825308556014362, 0.41428822110095415`, 0.9394010863083325], 
             UndirectedEdge[150, 443] -> 
             RGBColor[
              0.6273499374070801, 0.7008149121551293, 0.9628261966391379], 
             UndirectedEdge[2, 230] -> 
             RGBColor[
              0.23303851680093085`, 0.362268635026101, 0.9365825708309976], 
             UndirectedEdge[367, 416] -> 
             RGBColor[
              0.24172116635535817`, 0.37139465021958196`, 0.9370770348782933],
              UndirectedEdge[61, 473] -> 
             RGBColor[
              0.2928372445659958, 0.42512088936550885`, 0.939988019912928], 
             UndirectedEdge[56, 164] -> 
             RGBColor[
              0.35504910378768406`, 0.4819474212392274, 0.9438443928291242], 
             UndirectedEdge[20, 388] -> 
             RGBColor[
              0.4118266913184412, 0.5291631813983105, 0.9479506536079217], 
             UndirectedEdge[195, 296] -> 
             RGBColor[
              0.45646291508538506`, 0.5660271807883445, 0.9513452314455719], 
             UndirectedEdge[135, 391] -> 
             RGBColor[
              0.36337316017426236`, 0.486948858953675, 0.944455656204807], 
             UndirectedEdge[310, 399] -> 
             RGBColor[
              0.30885891999106013`, 0.4415191450460474, 0.9409165976062751], 
             UndirectedEdge[150, 476] -> 
             RGBColor[
              0.28569585964100896`, 0.41717329999529384`, 0.9395974955860167],
              UndirectedEdge[142, 222] -> 
             RGBColor[
              0.649822646931059, 0.7230245552990608, 0.9679583099192925], 
             UndirectedEdge[48, 404] -> 
             RGBColor[
              0.4542360060264099, 0.5630107120696471, 0.951342271277861], 
             UndirectedEdge[330, 415] -> 
             RGBColor[
              0.34146181671703135`, 0.46873488669907637`, 0.9430314915079178],
              UndirectedEdge[326, 495] -> 
             RGBColor[
              0.3937005210337001, 0.5105357617303976, 0.9468797694539126], 
             UndirectedEdge[36, 382] -> 
             RGBColor[
              0.3531047368297082, 0.4802633083069536, 0.9437204994858982], 
             UndirectedEdge[31, 289] -> 
             RGBColor[
              0.409025609505381, 0.5286991575538369, 0.9472837280439059], 
             UndirectedEdge[436, 487] -> 
             RGBColor[
              0.37686095243710915`, 0.4920027789405469, 0.9459966538831105], 
             UndirectedEdge[251, 427] -> 
             RGBColor[
              0.42265424291511366`, 0.5383335221071088, 0.9487517300692887], 
             UndirectedEdge[108, 437] -> 
             RGBColor[
              0.4776831498795281, 0.5773128865352464, 0.9540304413457452], 
             UndirectedEdge[258, 397] -> 
             RGBColor[
              0.3217210149358394, 0.4476222873678123, 0.9419206012697111], 
             UndirectedEdge[308, 422] -> 
             RGBColor[
              0.36438984140253194`, 0.4900378986820854, 0.9444395763702523], 
             UndirectedEdge[16, 292] -> 
             RGBColor[
              0.30293993088687404`, 0.4329173338444095, 0.9406666845687389], 
             UndirectedEdge[68, 317] -> 
             RGBColor[
              0.24450216183039622`, 0.3741945628203528, 0.9372399153832112], 
             UndirectedEdge[34, 468] -> 
             RGBColor[
              0.3561913126151607, 0.48185770343562195`, 0.9439566823673489], 
             UndirectedEdge[350, 383] -> 
             RGBColor[
              0.34446608093603337`, 0.4727809387633223, 0.9431700519712167], 
             UndirectedEdge[190, 342] -> 
             RGBColor[
              0.6454114806485836, 0.6919777720607783, 0.6559563063736336], 
             UndirectedEdge[61, 303] -> 
             RGBColor[
              0.2957531166562469, 0.4281856558093312, 0.9401540745148216], 
             UndirectedEdge[214, 421] -> 
             RGBColor[
              0.20568113013305406`, 0.33351428707966446`, 0.9350246081318888],
              UndirectedEdge[219, 370] -> 
             RGBColor[
              0.6539803063582437, 0.723300096173018, 0.9560480366852704], 
             UndirectedEdge[91, 366] -> 
             RGBColor[
              0.6271814477003193, 0.7080038282390653, 0.9639363019509856], 
             UndirectedEdge[273, 477] -> 
             RGBColor[
              0.42117313008304585`, 0.5386191918565713, 0.9482239639085894], 
             UndirectedEdge[153, 323] -> 
             RGBColor[
              0.409969050376482, 0.5295163186176677, 0.9473438432619605], 
             UndirectedEdge[170, 433] -> 
             RGBColor[
              0.4625065556543929, 0.5621034936689422, 0.9530486603672679], 
             UndirectedEdge[1, 54] -> 
             RGBColor[
              0.2544198638920467, 0.38474178647456836`, 0.9378002069169682], 
             UndirectedEdge[277, 377] -> 
             RGBColor[
              0.37092996794614996`, 0.49570262757784944`, 0.9448563074504048],
              UndirectedEdge[307, 417] -> 
             RGBColor[
              0.33937614859376686`, 0.4591534837921815, 0.9432657634853366], 
             UndirectedEdge[58, 371] -> 
             RGBColor[
              0.45086534260416566`, 0.561965981513472, 0.9507710708706651], 
             UndirectedEdge[9, 269] -> 
             RGBColor[
              0.5812246962452836, 0.6618565413456716, 0.9637277760914946], 
             UndirectedEdge[184, 453] -> 
             RGBColor[
              0.3722692920187197, 0.49237067599858975`, 0.9452623733097549], 
             UndirectedEdge[42, 97] -> 
             RGBColor[
              0.44791107602777114`, 0.556293845323269, 0.9509883534303258], 
             UndirectedEdge[161, 405] -> 
             RGBColor[
              0.29592479611765377`, 0.4283661018083764, 0.9401638514061719], 
             UndirectedEdge[304, 429] -> 
             RGBColor[
              0.31794891530944547`, 0.4475468222892828, 0.9415633812527845], 
             UndirectedEdge[127, 130] -> 
             RGBColor[
              0.5697073924930092, 0.6534122146464434, 0.9625172527750496], 
             UndirectedEdge[318, 330] -> 
             RGBColor[
              0.6417544750222266, 0.7150649069905033, 0.967891403445307], 
             UndirectedEdge[393, 468] -> 
             RGBColor[
              0.26690077681863345`, 0.39786001729599596`, 0.9385109764442814],
              UndirectedEdge[334, 355] -> 
             RGBColor[
              0.2963805255643143, 0.42418815735694926`, 0.9403603180928357], 
             UndirectedEdge[290, 378] -> 
             RGBColor[
              0.24706199994443884`, 0.37700820495011356`, 0.9373811874501363],
              UndirectedEdge[92, 498] -> 
             RGBColor[
              0.34484597861853394`, 0.468709759612454, 0.9433553725968467], 
             UndirectedEdge[340, 362] -> 
             RGBColor[
              0.33965246745562305`, 0.4686116287058391, 0.9428633327767562], 
             UndirectedEdge[58, 304] -> 
             RGBColor[
              0.3452979346662828, 0.47350144865428023`, 0.9432230569553288], 
             UndirectedEdge[51, 308] -> 
             RGBColor[
              0.439899010375149, 0.5547576744959466, 0.949439522658954], 
             UndirectedEdge[59, 447] -> 
             RGBColor[
              0.730037688972577, 0.6948031838330024, 0.6093471071487886], 
             UndirectedEdge[186, 485] -> 
             RGBColor[
              0.617497947550525, 0.6821930622436911, 0.8687199736548875], 
             UndirectedEdge[340, 379] -> 
             RGBColor[
              0.32471392247579967`, 0.45567261187741825`, 0.9419114619002785],
              UndirectedEdge[129, 410] -> 
             RGBColor[
              0.27660765355871864`, 0.40806256020135756`, 0.939063768714592], 
             UndirectedEdge[192, 225] -> 
             RGBColor[
              0.3924168200555059, 0.5124225699365071, 0.9465120983348076], 
             UndirectedEdge[306, 420] -> 
             RGBColor[
              0.28084821281735395`, 0.4100751008672523, 0.9393947694604774], 
             UndirectedEdge[16, 45] -> 
             RGBColor[
              0.281890106635309, 0.41361475331172354`, 0.9393645966026147], 
             UndirectedEdge[334, 361] -> 
             RGBColor[
              0.26892945587706074`, 0.3999922876120844, 0.9386265067154971], 
             UndirectedEdge[306, 357] -> 
             RGBColor[
              0.411674865163964, 0.5194936324637107, 0.948807663954385], 
             UndirectedEdge[335, 496] -> 
             RGBColor[
              0.24456472725692383`, 0.3743834130193018, 0.9372389714649662], 
             UndirectedEdge[176, 345] -> 
             RGBColor[
              0.5828834002194364, 0.6678889103123848, 0.962431345208703], 
             UndirectedEdge[15, 78] -> 
             RGBColor[
              0.5742071051573033, 0.6431922537075467, 0.9471296731910348], 
             UndirectedEdge[52, 210] -> 
             RGBColor[
              0.4140275397147992, 0.5270759968636756, 0.9484765418787016], 
             UndirectedEdge[392, 465] -> 
             RGBColor[
              0.3299960144523478, 0.4579595238667623, 0.9423318132646201], 
             UndirectedEdge[354, 414] -> 
             RGBColor[
              0.5988804860838504, 0.6852153580547534, 0.9615801344427339], 
             UndirectedEdge[56, 428] -> 
             RGBColor[
              0.3217689577699581, 0.44898857276826243`, 0.9418751502015977], 
             UndirectedEdge[44, 425] -> 
             RGBColor[
              0.34967727400129567`, 0.4772946122742734, 0.9435021045852581], 
             UndirectedEdge[106, 468] -> 
             RGBColor[
              0.3564364462616936, 0.48207002587947334`, 0.9439723020665427], 
             UndirectedEdge[142, 461] -> 
             RGBColor[
              0.5532784208819472, 0.6331475955885955, 0.9620356308503764], 
             UndirectedEdge[203, 297] -> 
             RGBColor[
              0.3172867102465522, 0.4479235953952193, 0.9414863894613212], 
             UndirectedEdge[24, 176] -> 
             RGBColor[
              0.554639307330748, 0.6434252966415879, 0.9606316565851064], 
             UndirectedEdge[351, 356] -> 
             RGBColor[
              0.4127430343192738, 0.5314457313388554, 0.9476513657355758], 
             UndirectedEdge[315, 368] -> 
             RGBColor[
              0.2623849802686051, 0.3931136288038779, 0.9382538085112795], 
             UndirectedEdge[278, 406] -> 
             RGBColor[
              0.3142616261509996, 0.4462818236309282, 0.9412578096132094], 
             UndirectedEdge[247, 360] -> 
             RGBColor[
              0.25894655425284246`, 0.3894996250525104, 0.9380579952363773], 
             UndirectedEdge[78, 145] -> 
             RGBColor[
              0.29641666507638903`, 0.4204403371508138, 0.940500993055425], 
             UndirectedEdge[19, 466] -> 
             RGBColor[
              0.3209425453825024, 0.45240603459412837`, 0.9416711530867914], 
             UndirectedEdge[60, 151] -> 
             RGBColor[
              0.29722255756875515`, 0.4220390987346496, 0.940519363381412], 
             UndirectedEdge[109, 186] -> 
             RGBColor[
              0.7405145794206569, 0.7937234927174543, 0.876615630880516], 
             UndirectedEdge[474, 495] -> 
             RGBColor[
              0.24622331812207002`, 0.37612669717930514`, 0.9373334257610708],
              UndirectedEdge[36, 412] -> 
             RGBColor[
              0.39019497871823167`, 0.5123890116210309, 0.9460838569014218], 
             UndirectedEdge[259, 469] -> 
             RGBColor[
              0.37093741500847244`, 0.4957090778489329, 0.9448567819706308], 
             UndirectedEdge[6, 80] -> 
             RGBColor[
              0.44747292190440746`, 0.5560206762746478, 0.9509463466455621], 
             UndirectedEdge[287, 389] -> 
             RGBColor[
              0.3422885813868548, 0.46414021264521543`, 0.9432786257485062], 
             UndirectedEdge[158, 410] -> 
             RGBColor[
              0.2958948269051258, 0.424943396157588, 0.940286313371711], 
             UndirectedEdge[414, 415] -> 
             RGBColor[
              0.4235530412327441, 0.5371050460200316, 0.9490174446259951], 
             UndirectedEdge[10, 245] -> 
             RGBColor[
              0.31758402957316995`, 0.4460380824275535, 0.9415838014326892], 
             UndirectedEdge[115, 178] -> 
             RGBColor[
              0.3784880499469793, 0.502249058326721, 0.9453379017521482], 
             UndirectedEdge[88, 348] -> 
             RGBColor[
              0.4985752448165871, 0.6035294174352221, 0.9537449245026584], 
             UndirectedEdge[135, 170] -> 
             RGBColor[
              0.3423600792139123, 0.46486277855806385`, 0.9432589923301826], 
             UndirectedEdge[3, 203] -> 
             RGBColor[
              0.3297146252107473, 0.46000396924380227`, 0.9422301022566015], 
             UndirectedEdge[84, 374] -> 
             RGBColor[
              0.5263567277761902, 0.6253560156941216, 0.9561330395517694], 
             UndirectedEdge[29, 172] -> 
             RGBColor[
              0.30330077064565, 0.43208502718003383`, 0.9407315954498772], 
             UndirectedEdge[262, 387] -> 
             RGBColor[
              0.4854908968181383, 0.5742165223359397, 0.9562644802943984], 
             UndirectedEdge[179, 276] -> 
             RGBColor[
              0.34151730214677933`, 0.4599324001615116, 0.9435216506281896], 
             UndirectedEdge[348, 428] -> 
             RGBColor[
              0.35360727366057687`, 0.4765653217524307, 0.9439038595366307], 
             UndirectedEdge[104, 351] -> 
             RGBColor[
              0.4097482319670894, 0.5288517840645363, 0.9474605395778944], 
             UndirectedEdge[111, 271] -> 
             RGBColor[
              0.31712509960197377`, 0.44841139900793997`, 0.941453105576592], 
             UndirectedEdge[136, 277] -> 
             RGBColor[
              0.3469336703307593, 0.47491824067238475`, 0.943327284585445], 
             UndirectedEdge[246, 442] -> 
             RGBColor[
              0.31153940612296205`, 0.4428002239514536, 0.9411254981347161], 
             UndirectedEdge[206, 266] -> 
             RGBColor[
              0.2437181004240141, 0.3734935545386721, 0.9371907573193041], 
             UndirectedEdge[31, 381] -> 
             RGBColor[
              0.37790037284169464`, 0.5017400419556335, 0.945300455486662], 
             UndirectedEdge[31, 472] -> 
             RGBColor[
              0.32489108088639906`, 0.45131799269574774`, 0.94208781261657], 
             UndirectedEdge[342, 453] -> 
             RGBColor[
              0.3948492143114877, 0.5157683837342849, 0.9465605406087976], 
             UndirectedEdge[200, 475] -> 
             RGBColor[
              0.40265536568409416`, 0.5231815725336023, 0.946877821740599], 
             UndirectedEdge[92, 101] -> 
             RGBColor[
              0.3542217819950403, 0.4785643234214305, 0.9438893107288805], 
             UndirectedEdge[193, 376] -> 
             RGBColor[
              0.3886927379335651, 0.5107215869579331, 0.9460893339552976], 
             UndirectedEdge[253, 319] -> 
             RGBColor[
              0.2702596535762901, 0.4013904097333798, 0.938702259506617], 
             UndirectedEdge[249, 280] -> 
             RGBColor[
              0.30843530195280877`, 0.43906164642782686`, 0.9409661514861815],
              UndirectedEdge[153, 195] -> 
             RGBColor[
              0.5009419712620801, 0.6045527036662317, 0.9541793975738659], 
             UndirectedEdge[313, 380] -> 
             RGBColor[
              0.43788171959535693`, 0.5441839558243835, 0.9505599619408769], 
             UndirectedEdge[178, 357] -> 
             RGBColor[
              0.5177860780465806, 0.6190050698166948, 0.9552905848180929], 
             UndirectedEdge[163, 494] -> 
             RGBColor[
              0.2752804789435382, 0.4063070755031746, 0.9390013892202799], 
             UndirectedEdge[24, 237] -> 
             RGBColor[
              0.3007225582738323, 0.43242143540297734`, 0.9404732310962458], 
             UndirectedEdge[101, 345] -> 
             RGBColor[
              0.32790966805876964`, 0.45577409281513237`, 0.94221272609575], 
             UndirectedEdge[320, 361] -> 
             RGBColor[
              0.29419449559428246`, 0.4265474462509236, 0.9400653133511161], 
             UndirectedEdge[328, 487] -> 
             RGBColor[
              0.42491209196471447`, 0.5406282479793738, 0.9488019064964294], 
             UndirectedEdge[322, 494] -> 
             RGBColor[
              0.2779983052463516, 0.4091636832675718, 0.9391561654075613], 
             UndirectedEdge[108, 266] -> 
             RGBColor[
              0.4568417122465076, 0.555407214159474, 0.9528435523046886], 
             UndirectedEdge[405, 474] -> 
             RGBColor[
              0.2587220094040099, 0.3892636141794217, 0.9380452077394206], 
             UndirectedEdge[338, 379] -> 
             RGBColor[
              0.2992365248438141, 0.43168517861291134`, 0.9403583722861483], 
             UndirectedEdge[175, 309] -> 
             RGBColor[
              0.24799548928814485`, 0.37798936143699136`, 0.9374343482872867],
              UndirectedEdge[294, 430] -> 
             RGBColor[
              0.3378840404703129, 0.46640827557213305`, 0.9427752418579769], 
             UndirectedEdge[197, 237] -> 
             RGBColor[
              0.2691989377640801, 0.4002755301614802, 0.9386418533103], 
             UndirectedEdge[94, 500] -> 
             RGBColor[
              0.673476986393587, 0.7354645554461255, 0.818211095369292], 
             UndirectedEdge[242, 365] -> 
             RGBColor[
              0.23256322885258746`, 0.3617690772573957, 0.9365555038854649], 
             UndirectedEdge[401, 500] -> 
             RGBColor[
              0.30091195379773833`, 0.429609322261328, 0.9405942709359247], 
             UndirectedEdge[334, 340] -> 
             RGBColor[
              0.28628923249238825`, 0.4154475865011843, 0.9397173098216727], 
             UndirectedEdge[60, 310] -> 
             RGBColor[
              0.25335509536182216`, 0.38362264723907824`, 0.9377395699243558],
              UndirectedEdge[50, 379] -> 
             RGBColor[
              0.29926108910393723`, 0.4317109972077648, 0.9403597711844227], 
             UndirectedEdge[123, 177] -> 
             RGBColor[
              0.29384950825053235`, 0.4248061488668706, 0.9400961475664198], 
             UndirectedEdge[231, 246] -> 
             RGBColor[
              0.30983394798313635`, 0.44100767931420526`, 0.9410283748166522],
              UndirectedEdge[182, 282] -> 
             RGBColor[
              0.3931235250118437, 0.5149255712275411, 0.9462704612816389], 
             UndirectedEdge[185, 193] -> 
             RGBColor[
              0.31807301871600857`, 0.4499205948222153, 0.9414883093850253], 
             UndirectedEdge[395, 447] -> 
             RGBColor[
              0.6110173632248224, 0.5922510134448189, 0.6012441204731989], 
             UndirectedEdge[22, 282] -> 
             RGBColor[
              0.4053594356558514, 0.5255237020326299, 0.9470501226880841], 
             UndirectedEdge[195, 323] -> 
             RGBColor[
              0.5008151322985821, 0.6044428421311614, 0.9541713155072711], 
             UndirectedEdge[99, 486] -> 
             RGBColor[
              0.4800023272774365, 0.5870359438552704, 0.9526738044665539], 
             UndirectedEdge[454, 469] -> 
             RGBColor[
              0.47201174534842083`, 0.5808716132872284, 0.9519555704572178], 
             UndirectedEdge[31, 208] -> 
             RGBColor[
              0.6558792726988116, 0.7263276372503931, 0.9692386392570556], 
             UndirectedEdge[398, 472] -> 
             RGBColor[
              0.236329414293926, 0.3657275769461914, 0.9367699825747772], 
             UndirectedEdge[191, 389] -> 
             RGBColor[
              0.3596270159501074, 0.482364006691439, 0.9442660239469681], 
             UndirectedEdge[133, 151] -> 
             RGBColor[
              0.34817450233802605`, 0.4755928232270388, 0.9434210012593744], 
             UndirectedEdge[165, 268] -> 
             RGBColor[
              0.36837306799534847`, 0.49348796935399336`, 0.9446933840465177],
              UndirectedEdge[166, 495] -> 
             RGBColor[
              0.2617238868563013, 0.3924187777118034, 0.9382161602194489], 
             UndirectedEdge[346, 430] -> 
             RGBColor[
              0.43099319825544163`, 0.5441443791900067, 0.9495122186997165], 
             UndirectedEdge[169, 219] -> 
             RGBColor[
              0.6296901708588878, 0.7022432635687827, 0.9545009475316096], 
             UndirectedEdge[197, 345] -> 
             RGBColor[
              0.3161462523354238, 0.4434099970462611, 0.9415428169727196], 
             UndirectedEdge[100, 213] -> 
             RGBColor[
              0.34858869113547053`, 0.4763517365096613, 0.9434327410476437], 
             UndirectedEdge[73, 187] -> 
             RGBColor[
              0.38056713058739966`, 0.5040498534798217, 0.9454703789320971], 
             UndirectedEdge[97, 346] -> 
             RGBColor[
              0.5840492391118264, 0.6731965092861878, 0.9603976420271909], 
             UndirectedEdge[129, 170] -> 
             RGBColor[
              0.2748420526352233, 0.40620680168519985`, 0.9389632203539713], 
             UndirectedEdge[36, 37] -> 
             RGBColor[
              0.3683267058246094, 0.4934478127719296, 0.9446904298899946], 
             UndirectedEdge[143, 302] -> 
             RGBColor[
              0.3530607009486516, 0.4802251666400901, 0.9437176935584967], 
             UndirectedEdge[16, 236] -> 
             RGBColor[
              0.2713868537378552, 0.4025751685718028, 0.938766451888275], 
             UndirectedEdge[187, 322] -> 
             RGBColor[
              0.32945705554520366`, 0.4537346663844447, 0.942435071473418], 
             UndirectedEdge[108, 163] -> 
             RGBColor[
              0.46279768231512664`, 0.5616673163319059, 0.9531827359890284], 
             UndirectedEdge[137, 346] -> 
             RGBColor[
              0.4715649370624027, 0.5799572107124669, 0.95207282233535], 
             UndirectedEdge[243, 276] -> 
             RGBColor[
              0.36882755216676366`, 0.48863720450237713`, 0.9450769289649333],
              UndirectedEdge[131, 147] -> 
             RGBColor[
              0.3483392246307925, 0.47094480915217457`, 0.9436069077826519], 
             UndirectedEdge[9, 468] -> 
             RGBColor[
              0.29441040957687575`, 0.4267743855363664, 0.9400776093330085], 
             UndirectedEdge[331, 377] -> 
             RGBColor[
              0.3285592941957055, 0.45432193342747873`, 0.9423278926009906], 
             UndirectedEdge[280, 470] -> 
             RGBColor[
              0.3433401059069623, 0.47180567578629146`, 0.9430983058380249], 
             UndirectedEdge[234, 468] -> 
             RGBColor[
              0.30749196458962214`, 0.4396767758763023, 0.9408536029743041], 
             UndirectedEdge[136, 488] -> 
             RGBColor[
              0.3359496945849509, 0.4654044729520387, 0.9426273953636705], 
             UndirectedEdge[57, 361] -> 
             RGBColor[
              0.3074264780735837, 0.4402799635157928, 0.9408252677387614], 
             UndirectedEdge[196, 414] -> 
             RGBColor[
              0.4074693086341387, 0.5202000232913516, 0.9481014998482546], 
             UndirectedEdge[103, 319] -> 
             RGBColor[
              0.3250506578535922, 0.45098899562556083`, 0.9421150877357055], 
             UndirectedEdge[224, 263] -> 
             RGBColor[
              0.6466124684594379, 0.7196939774516133, 0.968006993423414], 
             UndirectedEdge[89, 184] -> 
             RGBColor[
              0.27960410312955414`, 0.4112120186861815, 0.9392344120848011], 
             UndirectedEdge[137, 407] -> 
             RGBColor[
              0.3015045119150585, 0.4274000985253925, 0.9407317110974701], 
             UndirectedEdge[53, 272] -> 
             RGBColor[
              0.3324416012346648, 0.4593531568039564, 0.9425141754653377], 
             UndirectedEdge[236, 243] -> 
             RGBColor[
              0.26776109193871905`, 0.39876426303433504`, 0.9385599701176481],
              UndirectedEdge[26, 351] -> 
             RGBColor[
              0.4804313066710205, 0.5890748037960806, 0.9522404588204576], 
             UndirectedEdge[67, 96] -> 
             RGBColor[
              0.31924461933102855`, 0.44423801149634623`, 0.9418081860767664],
              UndirectedEdge[284, 464] -> 
             RGBColor[
              0.5050559284591002, 0.6004917929784908, 0.9564745159966128], 
             UndirectedEdge[325, 401] -> 
             RGBColor[
              0.25835247439968323`, 0.3888752094600018, 0.9380241632676023], 
             UndirectedEdge[227, 348] -> 
             RGBColor[
              0.35895712966346804`, 0.4821883596119312, 0.9442085259215927], 
             UndirectedEdge[106, 117] -> 
             RGBColor[
              0.5155595244453419, 0.6165747081442158, 0.9552873687039608], 
             UndirectedEdge[395, 440] -> 
             RGBColor[
              0.28580791853486365`, 0.4177326220217771, 0.939587710194411], 
             UndirectedEdge[204, 361] -> 
             RGBColor[
              0.26283272313373746`, 0.39358423494366934`, 0.9382793068050727],
              UndirectedEdge[195, 263] -> 
             RGBColor[
              0.5017753024123189, 0.6052744932241272, 0.9542324966978734], 
             UndirectedEdge[360, 393] -> 
             RGBColor[
              0.22838934233135863`, 0.3573820578838939, 0.9363178072227928], 
             UndirectedEdge[74, 440] -> 
             RGBColor[
              0.3966896045859903, 0.5136774780626979, 0.9470499933402627], 
             UndirectedEdge[166, 348] -> 
             RGBColor[
              0.3465014604216202, 0.4690966615037062, 0.9434991939847808], 
             UndirectedEdge[209, 477] -> 
             RGBColor[
              0.3398580089268869, 0.46878965839743314`, 0.9428764296975519], 
             UndirectedEdge[292, 422] -> 
             RGBColor[
              0.3333520969447221, 0.4631545644351261, 0.9424618787390004], 
             UndirectedEdge[36, 416] -> 
             RGBColor[
              0.2973708358705894, 0.4243891665545322, 0.9404474665445303], 
             UndirectedEdge[306, 418] -> 
             RGBColor[
              0.5295835030679157, 0.6124044881690118, 0.9600557633136925], 
             UndirectedEdge[363, 498] -> 
             RGBColor[
              0.27269399797746974`, 0.4039490600453692, 0.9388408918189743], 
             UndirectedEdge[57, 466] -> 
             RGBColor[
              0.3188944133828126, 0.45063204559810455`, 0.9415406479268632], 
             UndirectedEdge[263, 395] -> 
             RGBColor[
              0.35189104050047165`, 0.477665589053454, 0.9436997879091228], 
             UndirectedEdge[171, 238] -> 
             RGBColor[
              0.23445299088401306`, 0.3637553369702572, 0.9366631230375022], 
             UndirectedEdge[42, 286] -> 
             RGBColor[
              0.263036898240095, 0.3937988359259006, 0.9382909342753296], 
             UndirectedEdge[246, 444] -> 
             RGBColor[
              0.29366455363836497`, 0.42401262065903644`, 0.9401075517291928],
              UndirectedEdge[46, 306] -> 
             RGBColor[
              0.31317259610895765`, 0.4380728570036958, 0.9414544505804885], 
             UndirectedEdge[229, 411] -> 
             RGBColor[
              0.28159975828764494`, 0.4133095787891801, 0.9393480616937472], 
             UndirectedEdge[239, 440] -> 
             RGBColor[
              0.30453751745755586`, 0.43550173572686557`, 0.940724519595737], 
             UndirectedEdge[57, 106] -> 
             RGBColor[
              0.363218946392579, 0.4890237282753585, 0.9443649679755999], 
             UndirectedEdge[60, 280] -> 
             RGBColor[
              0.2688999216349235, 0.39750745502583784`, 0.9387146700644318], 
             UndirectedEdge[438, 457] -> 
             RGBColor[
              0.3972450480686217, 0.5184954273455502, 0.9465330810862971], 
             UndirectedEdge[130, 368] -> 
             RGBColor[
              0.29310621165578454`, 0.42540359083037527`, 0.9400033371907903],
              UndirectedEdge[152, 287] -> 
             RGBColor[
              0.26000593752523254`, 0.39061310404057137`, 0.9381183255465229],
              UndirectedEdge[54, 242] -> 
             RGBColor[
              0.23389814771920384`, 0.3631721616249542, 0.9366315255400833], 
             UndirectedEdge[89, 235] -> 
             RGBColor[
              0.2672477464810746, 0.3982247044103687, 0.9385307358532617], 
             UndirectedEdge[60, 260] -> 
             RGBColor[
              0.27268428333461864`, 0.4007852789225642, 0.9389558062455567], 
             UndirectedEdge[88, 243] -> 
             RGBColor[
              0.40666794831156117`, 0.5193577427831435, 0.9480558635633902], 
             UndirectedEdge[36, 367] -> 
             RGBColor[
              0.3125490995889447, 0.4403424840800265, 0.9413118462090617], 
             UndirectedEdge[17, 282] -> 
             RGBColor[
              0.3595122307924668, 0.48581315752748444`, 0.9441287793352807], 
             UndirectedEdge[150, 233] -> 
             RGBColor[
              0.3061417597514187, 0.4386632373562748, 0.9407618593503059], 
             UndirectedEdge[250, 365] -> 
             RGBColor[
              0.23159663644609413`, 0.36075312735267295`, 0.9365004578778605],
              UndirectedEdge[107, 423] -> 
             RGBColor[
              0.4580337121297938, 0.5670966813406235, 0.9515257378164593], 
             UndirectedEdge[315, 347] -> 
             RGBColor[
              0.26532441236379856`, 0.3962031583066853, 0.9384212048206007], 
             UndirectedEdge[288, 492] -> 
             RGBColor[
              0.3752297625631732, 0.4994268935611536, 0.9451302865612425], 
             UndirectedEdge[24, 267] -> 
             RGBColor[
              0.2861036039968237, 0.4170559875626052, 0.9396407032769749], 
             UndirectedEdge[198, 480] -> 
             RGBColor[
              0.26987331117096314`, 0.40098433936985783`, 0.938680257878176], 
             UndirectedEdge[4, 479] -> 
             RGBColor[
              0.29775685759737, 0.43002310994284443`, 0.9402780195288167], 
             UndirectedEdge[133, 239] -> 
             RGBColor[
              0.31694830631845455`, 0.44854626170913237`, 0.9414312956612483],
              UndirectedEdge[115, 253] -> 
             RGBColor[
              0.3019142224810556, 0.43378328582508296`, 0.940537091291275], 
             UndirectedEdge[199, 371] -> 
             RGBColor[
              0.4528765863035521, 0.5637080197178329, 0.9508992255407172], 
             UndirectedEdge[93, 189] -> 
             RGBColor[
              0.3274066636991389, 0.4525577083150817, 0.94228249042249], 
             UndirectedEdge[357, 418] -> 
             RGBColor[
              0.7147479137078537, 0.7764908929627028, 0.9726526199263468], 
             UndirectedEdge[82, 463] -> 
             RGBColor[
              0.6544475956649738, 0.7204117565447823, 0.8795316247162296], 
             UndirectedEdge[102, 350] -> 
             RGBColor[
              0.31574534734422, 0.4436170309726501, 0.9414969768401363], 
             UndirectedEdge[235, 296] -> 
             RGBColor[
              0.2818184676960991, 0.41239375179445154`, 0.9394024667232932], 
             UndirectedEdge[26, 360] -> 
             RGBColor[
              0.3550833553140218, 0.4727776490663566, 0.944422885862582], 
             UndirectedEdge[309, 320] -> 
             RGBColor[
              0.2697409547994002, 0.40084522443146653`, 0.9386727203786192], 
             UndirectedEdge[13, 229] -> 
             RGBColor[
              0.39272017049609853`, 0.5077806172331465, 0.946980935950401], 
             UndirectedEdge[353, 420] -> 
             RGBColor[
              0.3427129584897032, 0.4712624722148073, 0.9430583445591618], 
             UndirectedEdge[171, 465] -> 
             RGBColor[
              0.3274824593180644, 0.4553176180520303, 0.9421886700181943], 
             UndirectedEdge[104, 224] -> 
             RGBColor[
              0.6151052886975248, 0.6924040419387443, 0.9659993837896901], 
             UndirectedEdge[22, 285] -> 
             RGBColor[
              0.35664902696547224`, 0.48037937280340776`, 0.9440544923932159],
              UndirectedEdge[126, 285] -> 
             RGBColor[
              0.2923237628025631, 0.42458118747551693`, 0.9399587778861287], 
             UndirectedEdge[98, 319] -> 
             RGBColor[
              0.36758124625059874`, 0.48709617290269447`, 0.9450269884863475],
              UndirectedEdge[286, 411] -> 
             RGBColor[
              0.27190364397378736`, 0.4031183478761609, 0.9387958823276886], 
             UndirectedEdge[259, 491] -> 
             RGBColor[
              0.4875171979489068, 0.5917216088295998, 0.9536564391835731], 
             UndirectedEdge[1, 266] -> 
             RGBColor[
              0.25667243114290084`, 0.38710937747622876`, 0.9379284872895297],
              UndirectedEdge[67, 216] -> 
             RGBColor[
              0.3713081886530782, 0.49603022334426516`, 0.9448804073394029], 
             UndirectedEdge[41, 451] -> 
             RGBColor[
              0.3148263658529108, 0.4430154814710796, 0.9414313012610405], 
             UndirectedEdge[300, 456] -> 
             RGBColor[
              0.2881275030873316, 0.4170078190056473, 0.9398356139293174], 
             UndirectedEdge[117, 139] -> 
             RGBColor[
              0.5291352708252051, 0.6283333373216005, 0.9561524032587245], 
             UndirectedEdge[70, 96] -> 
             RGBColor[
              0.25634668604548416`, 0.3867669987254117, 0.9379099365881286], 
             UndirectedEdge[92, 274] -> 
             RGBColor[
              0.34235147623024353`, 0.46608787944177443`, 0.943213314376119], 
             UndirectedEdge[241, 436] -> 
             RGBColor[
              0.613964967278927, 0.676912248549549, 0.8146755656431439], 
             UndirectedEdge[207, 295] -> 
             RGBColor[
              0.3088673901129637, 0.43609989960609574`, 0.9411158310586574], 
             UndirectedEdge[83, 176] -> 
             RGBColor[
              0.5456045272402572, 0.6349165885555719, 0.9600809849917796], 
             UndirectedEdge[56, 495] -> 
             RGBColor[
              0.3265573982793615, 0.45402152734830914`, 0.9421478448047453], 
             UndirectedEdge[219, 334] -> 
             RGBColor[
              0.5922372757651077, 0.6628778961745175, 0.9523680605626119], 
             UndirectedEdge[124, 357] -> 
             RGBColor[
              0.49863417867995685`, 0.6024166571877763, 0.9540702427258113], 
             UndirectedEdge[40, 291] -> 
             RGBColor[
              0.3780213758692776, 0.4990765073429499, 0.9455298662570373], 
             UndirectedEdge[7, 487] -> 
             RGBColor[
              0.38931087137352377`, 0.5050884331131711, 0.9467056583485347], 
             UndirectedEdge[423, 477] -> 
             RGBColor[
              0.48469055515876713`, 0.5901854989604328, 0.9532242882825448], 
             UndirectedEdge[22, 165] -> 
             RGBColor[
              0.4271114455126065, 0.5443641996827471, 0.9484361415216095], 
             UndirectedEdge[302, 368] -> 
             RGBColor[
              0.30285417472536214`, 0.4348797497331661, 0.9405866469335309], 
             UndirectedEdge[297, 419] -> 
             RGBColor[
              0.2543558894297653, 0.3846745452584954, 0.9377965636659831], 
             UndirectedEdge[263, 463] -> 
             RGBColor[
              0.7008171647602, 0.7605747466927593, 0.8824862526559774], 
             UndirectedEdge[260, 424] -> 
             RGBColor[
              0.30879201463689887`, 0.4387367938836526, 0.94101208812662], 
             UndirectedEdge[193, 415] -> 
             RGBColor[
              0.30185365566083144`, 0.43442828835625474`, 0.9405076945095383],
              UndirectedEdge[434, 474] -> 
             RGBColor[
              0.5011029441814382, 0.5890163209965171, 0.9574083633212791], 
             UndirectedEdge[102, 109] -> 
             RGBColor[
              0.376243934652413, 0.49501875960922637`, 0.9456279495516317], 
             UndirectedEdge[58, 118] -> 
             RGBColor[
              0.5111568234468423, 0.6102849112835397, 0.955947084773634], 
             UndirectedEdge[39, 100] -> 
             RGBColor[
              0.3551232689633623, 0.4820116593867497, 0.9438491185685367], 
             UndirectedEdge[35, 216] -> 
             RGBColor[
              0.49383283961895036`, 0.5968151224758785, 0.9541933722661231], 
             UndirectedEdge[72, 163] -> 
             RGBColor[
              0.21859083096519344`, 0.34708320117655134`, 0.9357597964960882],
              UndirectedEdge[202, 414] -> 
             RGBColor[
              0.40722131841905507`, 0.5199393698518109, 0.9480873771723742], 
             UndirectedEdge[324, 441] -> 
             RGBColor[
              0.6123610534219819, 0.6897663986177393, 0.9659445494243118], 
             UndirectedEdge[18, 52] -> 
             RGBColor[
              0.4892903143111319, 0.5954833856676424, 0.9531543722123479], 
             UndirectedEdge[168, 368] -> 
             RGBColor[
              0.26525656549418974`, 0.3961318469449865, 0.9384173410417469], 
             UndirectedEdge[208, 397] -> 
             RGBColor[
              0.6578464881550856, 0.7280315404034938, 0.9693639884863889], 
             UndirectedEdge[193, 350] -> 
             RGBColor[
              0.33984779883107874`, 0.46878081492561846`, 0.9428757791192754],
              UndirectedEdge[2, 365] -> 
             RGBColor[
              0.21043213482774287`, 0.3385078942448783, 0.9352951708207697], 
             UndirectedEdge[42, 248] -> 
             RGBColor[
              0.24652179201816873`, 0.3764404121684429, 0.9373504234079012], 
             UndirectedEdge[46, 68] -> 
             RGBColor[
              0.2893808688469447, 0.4130662431686859, 0.9400995469096233], 
             UndirectedEdge[260, 470] -> 
             RGBColor[
              0.34712446760665744`, 0.47508349968301783`, 0.9433394420191499],
              UndirectedEdge[32, 344] -> 
             RGBColor[
              0.4417964296361201, 0.5544120882965735, 0.950110000942735], 
             UndirectedEdge[60, 483] -> 
             RGBColor[
              0.23546236437516638`, 0.36481625250743493`, 0.9367206053645892],
              UndirectedEdge[337, 498] -> 
             RGBColor[
              0.26959177451606997`, 0.40068842649511016`, 0.938664224782176], 
             UndirectedEdge[86, 168] -> 
             RGBColor[
              0.32002910739183144`, 0.4454321171344137, 0.9418393301479133], 
             UndirectedEdge[151, 424] -> 
             RGBColor[
              0.33333028887103544`, 0.459990613695738, 0.9425756452624752], 
             UndirectedEdge[234, 296] -> 
             RGBColor[
              0.3195232340438674, 0.4511766984492649, 0.9415807158233414], 
             UndirectedEdge[223, 268] -> 
             RGBColor[
              0.36909759224453753`, 0.4941155158429933, 0.9447395500910043], 
             UndirectedEdge[50, 204] -> 
             RGBColor[
              0.25473966637720247`, 0.38507791916311573`, 0.9378184191953925],
              UndirectedEdge[26, 247] -> 
             RGBColor[
              0.39397754046331446`, 0.513657903692033, 0.9466378521680436], 
             UndirectedEdge[64, 435] -> 
             RGBColor[
              0.280604051941446, 0.4122630282878964, 0.9392913576903467], 
             UndirectedEdge[143, 214] -> 
             RGBColor[
              0.28996921671621545`, 0.414681584820548, 0.940096549200199], 
             UndirectedEdge[38, 266] -> 
             RGBColor[
              0.284470163177438, 0.4131653778448652, 0.9396272732353204], 
             UndirectedEdge[309, 375] -> 
             RGBColor[
              0.39065250502248433`, 0.5058709014407767, 0.9468391971644313], 
             UndirectedEdge[70, 385] -> 
             RGBColor[
              0.27796637044807554`, 0.4094906577996981, 0.9391411456313993], 
             UndirectedEdge[232, 354] -> 
             RGBColor[
              0.47808190281254476`, 0.5833188300681224, 0.9531277826523236], 
             UndirectedEdge[86, 484] -> 
             RGBColor[
              0.3684574834631169, 0.4935610857893296, 0.9446987629254782], 
             UndirectedEdge[106, 360] -> 
             RGBColor[
              0.3179250117744187, 0.44159206646737126`, 0.9417791328450542], 
             UndirectedEdge[163, 322] -> 
             RGBColor[
              0.24063323431447126`, 0.3702511646657344, 0.937015078758016], 
             UndirectedEdge[44, 117] -> 
             RGBColor[
              0.4983836256734213, 0.6016978079137516, 0.9541929356222649], 
             UndirectedEdge[113, 273] -> 
             RGBColor[
              0.39478986715869546`, 0.5157673355728505, 0.9465428457248533], 
             UndirectedEdge[53, 298] -> 
             RGBColor[
              0.32047708263716, 0.44677768916368543`, 0.9418328138311287], 
             UndirectedEdge[50, 369] -> 
             RGBColor[
              0.3763069287207439, 0.49813824440334253`, 0.9453536089772712], 
             UndirectedEdge[135, 385] -> 
             RGBColor[
              0.36071706516987445`, 0.4841571346979133, 0.9443043955236475], 
             UndirectedEdge[376, 464] -> 
             RGBColor[
              0.5979642684322207, 0.6831642662364397, 0.962401790689747], 
             UndirectedEdge[95, 408] -> 
             RGBColor[
              0.2755734484627186, 0.4069755450730712, 0.939004872264344], 
             UndirectedEdge[34, 332] -> 
             RGBColor[
              0.4620663977051351, 0.5731332661121675, 0.9510798719346072], 
             UndirectedEdge[251, 416] -> 
             RGBColor[
              0.2693056384004839, 0.4000805031037666, 0.9386591769788148], 
             UndirectedEdge[62, 209] -> 
             RGBColor[
              0.2849993541284874, 0.41650407370116804`, 0.9395555295582844], 
             UndirectedEdge[109, 496] -> 
             RGBColor[
              0.36873550135712024`, 0.4871269201537067, 0.9452003553831964], 
             UndirectedEdge[179, 254] -> 
             RGBColor[
              0.24984975350785027`, 0.3799383106990437, 0.9375399458914607], 
             UndirectedEdge[27, 199] -> 
             RGBColor[
              0.3021186840248485, 0.431713437263085, 0.9406323909856116], 
             UndirectedEdge[59, 453] -> 
             RGBColor[
              0.5036934465954336, 0.6079600569341803, 0.9540717396873337], 
             UndirectedEdge[450, 475] -> 
             RGBColor[
              0.35670475904254084`, 0.4800215864038988, 0.9440729113908797], 
             UndirectedEdge[311, 331] -> 
             RGBColor[
              0.2806555079415938, 0.4123171118065505, 0.9392942880334327], 
             UndirectedEdge[329, 486] -> 
             RGBColor[
              0.46903357124389067`, 0.5775353586847212, 0.9519748850313865], 
             UndirectedEdge[287, 456] -> 
             RGBColor[
              0.2893215188531271, 0.41826280528047044`, 0.9399036113607915], 
             UndirectedEdge[60, 118] -> 
             RGBColor[
              0.44294768587411504`, 0.5413837099925164, 0.9519604857858228], 
             UndirectedEdge[267, 493] -> 
             RGBColor[
              0.33479553442734805`, 0.4592304903739427, 0.9427433100274245], 
             UndirectedEdge[239, 263] -> 
             RGBColor[
              0.3706206394231638, 0.49543470275854246`, 0.9448365973104487], 
             UndirectedEdge[64, 91] -> 
             RGBColor[
              0.46136022975987245`, 0.5644275521083123, 0.9524246990378201], 
             UndirectedEdge[469, 471] -> 
             RGBColor[
              0.3400762511985227, 0.4660629649808945, 0.9429970948372339], 
             UndirectedEdge[275, 282] -> 
             RGBColor[
              0.32830637954059805`, 0.45634780037420597`, 0.9422295792583917],
              UndirectedEdge[132, 423] -> 
             RGBColor[
              0.48667024487599375`, 0.5919002066913962, 0.9533504323607556], 
             UndirectedEdge[116, 412] -> 
             RGBColor[
              0.39506479829557306`, 0.5166070045746752, 0.9463941574986776], 
             UndirectedEdge[89, 453] -> 
             RGBColor[
              0.3846615234457066, 0.505395696941206, 0.9459680925568583], 
             UndirectedEdge[136, 311] -> 
             RGBColor[
              0.3271052812460576, 0.4572309169691079, 0.9420826194994231], 
             UndirectedEdge[6, 24] -> 
             RGBColor[
              0.46272658821033896`, 0.5710658280732519, 0.9518511746088405], 
             UndirectedEdge[51, 477] -> 
             RGBColor[
              0.4226634927192655, 0.539829135384726, 0.9483412907146909], 
             UndirectedEdge[114, 381] -> 
             RGBColor[
              0.29965837430824893`, 0.42699625164086064`, 0.94057031527425], 
             UndirectedEdge[95, 294] -> 
             RGBColor[
              0.33452734996342315`, 0.4628801810229215, 0.9425840832993881], 
             UndirectedEdge[89, 192] -> 
             RGBColor[
              0.2950511747165036, 0.42744787032497156`, 0.9401140999597832], 
             UndirectedEdge[108, 374] -> 
             RGBColor[
              0.6620096629144709, 0.7357940341530785, 0.9670096410104633], 
             UndirectedEdge[208, 472] -> 
             RGBColor[
              0.5909756007187611, 0.6656032738419873, 0.9652680970095735], 
             UndirectedEdge[34, 360] -> 
             RGBColor[
              0.3176798781278859, 0.44137974402351987`, 0.9417635131458603], 
             UndirectedEdge[395, 453] -> 
             RGBColor[
              0.3846731208476789, 0.5054078865459967, 0.9459687530117439], 
             UndirectedEdge[101, 361] -> 
             RGBColor[
              0.2920590440954859, 0.4243029513302433, 0.9399437025473769], 
             UndirectedEdge[11, 211] -> 
             RGBColor[
              0.5935125589097926, 0.6650974297985649, 0.9574795966362856], 
             UndirectedEdge[70, 433] -> 
             RGBColor[
              0.4792822929216612, 0.5797358571800171, 0.9540040137871595], 
             UndirectedEdge[108, 206] -> 
             RGBColor[
              0.47455634479610187`, 0.5740264161416726, 0.9538523744219376], 
             UndirectedEdge[251, 499] -> 
             RGBColor[
              0.30762442040549615`, 0.4403559725421378, 0.9408413749264424], 
             UndirectedEdge[116, 399] -> 
             RGBColor[
              0.345730026704916, 0.4738757050605669, 0.9432505894779466], 
             UndirectedEdge[350, 479] -> 
             RGBColor[
              0.34038417831739876`, 0.46924539987745195`, 0.9429099567458421],
              UndirectedEdge[347, 421] -> 
             RGBColor[
              0.25749667906840545`, 0.38797571430627087`, 0.9379754269895217],
              UndirectedEdge[153, 447] -> 
             RGBColor[
              0.6700555432145694, 0.6449333941019983, 0.6049493570166387], 
             UndirectedEdge[195, 453] -> 
             RGBColor[
              0.5345573827595261, 0.6330167907166699, 0.9565014618004944], 
             UndirectedEdge[338, 425] -> 
             RGBColor[
              0.30294308343756277`, 0.4348956133697647, 0.9405945509221609], 
             UndirectedEdge[164, 348] -> 
             RGBColor[
              0.38688741967830287`, 0.5095241702233957, 0.9458731021641571], 
             UndirectedEdge[31, 258] -> 
             RGBColor[
              0.3197537994795654, 0.4459183842147115, 0.9417952520403776], 
             UndirectedEdge[31, 203] -> 
             RGBColor[
              0.36492758913451545`, 0.49050366873954265`, 0.9444738411802227],
              UndirectedEdge[398, 445] -> 
             RGBColor[
              0.24832165737586948`, 0.3783321847774412, 0.9374529230773601], 
             UndirectedEdge[44, 369] -> 
             RGBColor[
              0.42301655502435365`, 0.5405114247129977, 0.9482597637420939], 
             UndirectedEdge[267, 278] -> 
             RGBColor[
              0.27893835126125543`, 0.4105122712614932, 0.9391964985007931], 
             UndirectedEdge[130, 477] -> 
             RGBColor[
              0.33222385651628317`, 0.4611443760442326, 0.9424278101008319], 
             UndirectedEdge[4, 482] -> 
             RGBColor[
              0.28882694716359714`, 0.42090581252804676`, 0.9397596394085648],
              UndirectedEdge[219, 274] -> 
             RGBColor[
              0.603496558218736, 0.6747121159130203, 0.9530092600417304], 
             UndirectedEdge[44, 269] -> 
             RGBColor[
              0.626074834158181, 0.7022752814583145, 0.9665280357433328], 
             UndirectedEdge[130, 143] -> 
             RGBColor[
              0.343312737879074, 0.4707490077372992, 0.9431343838157562], 
             UndirectedEdge[315, 401] -> 
             RGBColor[
              0.24298039315603376`, 0.37271817742668245`, 0.9371487459817327],
              UndirectedEdge[75, 163] -> 
             RGBColor[
              0.4086437749482247, 0.5183969939788945, 0.9484448731857209], 
             UndirectedEdge[9, 139] -> 
             RGBColor[
              0.367347364140333, 0.4910277513421862, 0.9446855785804222], 
             UndirectedEdge[134, 438] -> 
             RGBColor[
              0.33417908124981877`, 0.45597930163341055`, 0.9428035219354496],
              UndirectedEdge[76, 431] -> 
             RGBColor[
              0.3801723125462475, 0.5037078819367073, 0.9454452214756387], 
             UndirectedEdge[90, 124] -> 
             RGBColor[
              0.31235766061209774`, 0.43716135697565683`, 0.9414100532403524],
              UndirectedEdge[37, 188] -> 
             RGBColor[
              0.3162479510654488, 0.4442065542546819, 0.9415233565364209], 
             UndirectedEdge[26, 106] -> 
             RGBColor[
              0.4529559979848907, 0.5657503451068939, 0.9503589897767205], 
             UndirectedEdge[107, 446] -> 
             RGBColor[
              0.4387487066288398, 0.5514402450953518, 0.9500075515401214], 
             UndirectedEdge[19, 234] -> 
             RGBColor[
              0.3163225967201974, 0.44840446726821126`, 0.9413767740432896], 
             UndirectedEdge[39, 243] -> 
             RGBColor[
              0.2977044282874609, 0.42771215173366695`, 0.9403576315377562], 
             UndirectedEdge[129, 265] -> 
             RGBColor[
              0.36932428688731733`, 0.49413661154347366`, 0.9447604118467203],
              UndirectedEdge[396, 446] -> 
             RGBColor[
              0.4690666891692976, 0.5777001577457866, 0.95193938657846], 
             UndirectedEdge[325, 368] -> 
             RGBColor[
              0.27775706151225454`, 0.4092706608371972, 0.9391292257971491], 
             UndirectedEdge[52, 56] -> 
             RGBColor[
              0.46680859194436963`, 0.5760108477177742, 0.9517218567429443], 
             UndirectedEdge[402, 431] -> 
             RGBColor[
              0.38575476604400394`, 0.5085431225741929, 0.9458009304761459], 
             UndirectedEdge[165, 353] -> 
             RGBColor[
              0.38398133420470804`, 0.5070070650502707, 0.9456879289675302], 
             UndirectedEdge[237, 329] -> 
             RGBColor[
              0.32556825174964243`, 0.45394152631086004`, 0.9420563767143404],
              UndirectedEdge[63, 75] -> 
             RGBColor[
              0.4356255817999579, 0.5467565837254285, 0.9499814471699208], 
             UndirectedEdge[392, 492] -> 
             RGBColor[
              0.3015104422618961, 0.4332867529618807, 0.9405167377934471], 
             UndirectedEdge[125, 177] -> 
             RGBColor[
              0.2406581845530317, 0.3702773889483979, 0.9370164996371915], 
             UndirectedEdge[210, 348] -> 
             RGBColor[
              0.3585539196151101, 0.48176456028611325`, 0.9441855637058345], 
             UndirectedEdge[469, 491] -> 
             RGBColor[
              0.5195223419194273, 0.6194428559115559, 0.9556957786563371], 
             UndirectedEdge[35, 171] -> 
             RGBColor[
              0.46310032553371755`, 0.5674432021488709, 0.9523359230427549], 
             UndirectedEdge[8, 40] -> 
             RGBColor[
              0.34462756141869855`, 0.4639774910652663, 0.9436281379257982], 
             UndirectedEdge[405, 491] -> 
             RGBColor[
              0.46735882401420137`, 0.5733248067165151, 0.9524062601002127], 
             UndirectedEdge[98, 136] -> 
             RGBColor[
              0.41562059029540377`, 0.5336807176979563, 0.947905843654441], 
             UndirectedEdge[14, 75] -> 
             RGBColor[
              0.48138565109175635`, 0.587951123165134, 0.952840138580872], 
             UndirectedEdge[121, 500] -> 
             RGBColor[
              0.3202013064564998, 0.44988365492128285`, 0.9416927710338012], 
             UndirectedEdge[1, 265] -> 
             RGBColor[
              0.3595697550702075, 0.4838839801306527, 0.9442049056902725], 
             UndirectedEdge[227, 495] -> 
             RGBColor[
              0.27417955609814915`, 0.4055104758200283, 0.9389254921562608], 
             UndirectedEdge[127, 368] -> 
             RGBColor[
              0.5652399881703085, 0.6487166894534913, 0.9622628407078043], 
             UndirectedEdge[207, 389] -> 
             RGBColor[
              0.4105603045377503, 0.53002843325486, 0.947381517454291], 
             UndirectedEdge[249, 260] -> 
             RGBColor[
              0.3122196636525039, 0.44233947032455323`, 0.9412072876673063], 
             UndirectedEdge[42, 95] -> 
             RGBColor[
              0.29149834466449664`, 0.4237136206778764, 0.9399117715442626], 
             UndirectedEdge[190, 323] -> 
             RGBColor[
              0.694146728211024, 0.7341897939945992, 0.6590616732534249], 
             UndirectedEdge[109, 295] -> 
             RGBColor[
              0.3678086980895504, 0.4861527911567696, 0.9451475753081908], 
             UndirectedEdge[382, 499] -> 
             RGBColor[
              0.320595585601134, 0.4515909438848803, 0.9416678861027574], 
             UndirectedEdge[213, 254] -> 
             RGBColor[
              0.30897115926215646`, 0.44076253307626456`, 0.9409550122184942],
              UndirectedEdge[47, 374] -> 
             RGBColor[
              0.471594913627974, 0.5777488288826542, 0.9526500821517522], 
             UndirectedEdge[244, 390] -> 
             RGBColor[
              0.631635535156964, 0.7107911782646735, 0.9648535162706321], 
             UndirectedEdge[92, 370] -> 
             RGBColor[
              0.39283522436975116`, 0.5146758597017722, 0.946252091019659], 
             UndirectedEdge[295, 458] -> 
             RGBColor[
              0.25786918935278985`, 0.38836724623367513`, 0.9379966408991378],
              UndirectedEdge[278, 493] -> 
             RGBColor[
              0.36095245765144357`, 0.48672307512718677`, 0.9442329081093366],
              UndirectedEdge[6, 156] -> 
             RGBColor[
              0.490178927154601, 0.594843664272097, 0.9536004133712186], 
             UndirectedEdge[79, 413] -> 
             RGBColor[
              0.27218696559506017`, 0.403416136863747, 0.9388120170748833], 
             UndirectedEdge[122, 476] -> 
             RGBColor[
              0.2840448744057782, 0.41574329956546763`, 0.9394922962667367], 
             UndirectedEdge[123, 455] -> 
             RGBColor[
              0.3038148259927228, 0.43528032965155083`, 0.940663657669471], 
             UndirectedEdge[113, 302] -> 
             RGBColor[
              0.3155885566615103, 0.4477686786633026, 0.9413300016598362], 
             UndirectedEdge[402, 462] -> 
             RGBColor[
              0.3628184310981648, 0.488676822057821, 0.9443394474952017], 
             UndirectedEdge[140, 363] -> 
             RGBColor[
              0.31878025388766695`, 0.4482668859814464, 0.9416163534118649], 
             UndirectedEdge[440, 453] -> 
             RGBColor[
              0.37846151002205697`, 0.49887908972939465`, 0.9456150109644794],
              UndirectedEdge[9, 106] -> 
             RGBColor[
              0.35377161776046984`, 0.47926912216480155`, 0.9438205440256584],
              UndirectedEdge[102, 202] -> 
             RGBColor[
              0.2614194813602837, 0.3920988282350657, 0.9381988247767783], 
             UndirectedEdge[363, 379] -> 
             RGBColor[
              0.29736490311896235`, 0.4297179855124208, 0.9402517861977342], 
             UndirectedEdge[162, 297] -> 
             RGBColor[
              0.30280877947262175`, 0.43538353944079977`, 0.9405638685147379],
              UndirectedEdge[19, 393] -> 
             RGBColor[
              0.2757314089492087, 0.40658770868790495`, 0.9390341475132669], 
             UndirectedEdge[96, 238] -> 
             RGBColor[
              0.21312193564719628`, 0.3413350454493459, 0.9354483509982339], 
             UndirectedEdge[117, 247] -> 
             RGBColor[
              0.45658106692376565`, 0.564482266729355, 0.9515662310952839], 
             UndirectedEdge[162, 223] -> 
             RGBColor[
              0.3651381674468951, 0.4906860610897521, 0.9444872590440805], 
             UndirectedEdge[355, 362] -> 
             RGBColor[
              0.34974376052754913`, 0.47735219956160413`, 0.9435063410479192],
              UndirectedEdge[59, 395] -> 
             RGBColor[
              0.41103985510824037`, 0.5268135892265627, 0.9480444389172653], 
             UndirectedEdge[161, 403] -> 
             RGBColor[
              0.3434841443319627, 0.4704962506294422, 0.9431599963408985], 
             UndirectedEdge[214, 477] -> 
             RGBColor[
              0.2788803353534246, 0.4050769531274814, 0.9393899754852748], 
             UndirectedEdge[65, 309] -> 
             RGBColor[
              0.2614464416180461, 0.392127165175353, 0.9382003601235738], 
             UndirectedEdge[361, 498] -> 
             RGBColor[
              0.2826832407189796, 0.4144483875212667, 0.9394097644153431], 
             UndirectedEdge[54, 70] -> 
             RGBColor[
              0.24894172756604654`, 0.3789839178620381, 0.937488235157379], 
             UndirectedEdge[369, 390] -> 
             RGBColor[
              0.5873542072802498, 0.6748416014432693, 0.9613675279323284], 
             UndirectedEdge[56, 88] -> 
             RGBColor[
              0.4667369289259683, 0.5759526684510539, 0.9517162151676255], 
             UndirectedEdge[289, 419] -> 
             RGBColor[
              0.32122762495666, 0.44391142005250217`, 0.9420093885647385], 
             UndirectedEdge[124, 178] -> 
             RGBColor[
              0.4195809809226354, 0.5378416897470695, 0.947956306976865], 
             UndirectedEdge[67, 465] -> 
             RGBColor[
              0.38908777308068965`, 0.5114300057475654, 0.9460133067372611], 
             UndirectedEdge[7, 461] -> 
             RGBColor[
              0.24948033938594955`, 0.3795500330347179, 0.9375189083037176], 
             UndirectedEdge[273, 423] -> 
             RGBColor[
              0.5389895881877318, 0.6366150547518663, 0.9568503812475062], 
             UndirectedEdge[63, 467] -> 
             RGBColor[
              0.29426118916721444`, 0.4266175454246919, 0.9400691114514301], 
             UndirectedEdge[179, 368] -> 
             RGBColor[
              0.24668850100918127`, 0.3766156338879576, 0.9373599172383156], 
             UndirectedEdge[211, 485] -> 
             RGBColor[
              0.5945748262345691, 0.6662139401085435, 0.957540091188948], 
             UndirectedEdge[21, 320] -> 
             RGBColor[
              0.3029522111923329, 0.43455207223901604`, 0.9406080007357747], 
             UndirectedEdge[318, 479] -> 
             RGBColor[
              0.6026826934523466, 0.681222893599515, 0.9654017840734941], 
             UndirectedEdge[343, 465] -> 
             RGBColor[
              0.40628780098341527`, 0.5263278054183675, 0.9471092773058353], 
             UndirectedEdge[229, 313] -> 
             RGBColor[
              0.4389721103099071, 0.5453300256001401, 0.9506220580789821], 
             UndirectedEdge[168, 401] -> 
             RGBColor[
              0.2458519783816184, 0.37573639556779104`, 0.9373122785122001], 
             UndirectedEdge[70, 216] -> 
             RGBColor[
              0.30841025536753375`, 0.4385592105733306, 0.9409821578507651], 
             UndirectedEdge[5, 193] -> 
             RGBColor[
              0.3043719935058694, 0.43707522110323116`, 0.9406511101242663], 
             UndirectedEdge[213, 471] -> 
             RGBColor[
              0.30009547480597176`, 0.4314336259619169, 0.940449555119113], 
             UndirectedEdge[145, 404] -> 
             RGBColor[
              0.5035394146961829, 0.6063889704787517, 0.9544591579034558], 
             UndirectedEdge[28, 173] -> 
             RGBColor[
              0.5802070244121582, 0.6664411474692579, 0.9618924231111096], 
             UndirectedEdge[210, 243] -> 
             RGBColor[
              0.26664662311008414`, 0.3975928856340347, 0.9384965027665662], 
             UndirectedEdge[133, 424] -> 
             RGBColor[
              0.2895736719640485, 0.4216906676384079, 0.9398021642812702], 
             UndirectedEdge[201, 400] -> 
             RGBColor[
              0.3095127363668705, 0.4418145951961029, 0.9409681754529511], 
             UndirectedEdge[120, 125] -> 
             RGBColor[
              0.2816218966131278, 0.4098913561380057, 0.9394753322986271], 
             UndirectedEdge[96, 343] -> 
             RGBColor[
              0.3364446472337542, 0.4591358111671484, 0.9429041566453406], 
             UndirectedEdge[22, 149] -> 
             RGBColor[
              0.35128127416167865`, 0.4747375242714361, 0.9437488068119186], 
             UndirectedEdge[140, 369] -> 
             RGBColor[
              0.4089567642991587, 0.528333540652463, 0.9473638863096692], 
             UndirectedEdge[169, 370] -> 
             RGBColor[
              0.3328421196337408, 0.46269490962815746`, 0.9424300402371347], 
             UndirectedEdge[154, 380] -> 
             RGBColor[
              0.6157012264530581, 0.6836452440928251, 0.9313807475089032], 
             UndirectedEdge[33, 489] -> 
             RGBColor[
              0.24971409425380672`, 0.37979572422175045`, 0.9375322202976328],
              UndirectedEdge[271, 284] -> 
             RGBColor[
              0.3069687806535515, 0.43773646384533416`, 0.9408747182374069], 
             UndirectedEdge[112, 356] -> 
             RGBColor[
              0.29700362548395487`, 0.4252477640161995, 0.9403809850597452], 
             UndirectedEdge[133, 155] -> 
             RGBColor[
              0.32239527465216666`, 0.45326415190720504`, 0.9417783716669075],
              UndirectedEdge[82, 447] -> 
             RGBColor[
              0.6245193052695821, 0.6054921935119169, 0.6020478282008983], 
             UndirectedEdge[225, 260] -> 
             RGBColor[
              0.41479109800564273`, 0.5327857842560335, 0.947901748025411], 
             UndirectedEdge[133, 225] -> 
             RGBColor[
              0.39557275533279235`, 0.5157396580107889, 0.9466918241800613], 
             UndirectedEdge[442, 444] -> 
             RGBColor[
              0.27506610649145713`, 0.4064422964939365, 0.938975979889626], 
             UndirectedEdge[49, 431] -> 
             RGBColor[
              0.7215469186079317, 0.777133778196069, 0.8241341506592748], 
             UndirectedEdge[220, 427] -> 
             RGBColor[
              0.45447808670602463`, 0.565897736085899, 0.9507795172549254], 
             UndirectedEdge[151, 192] -> 
             RGBColor[
              0.34501856706073963`, 0.47227573515275706`, 0.9432412754141208],
              UndirectedEdge[167, 326] -> 
             RGBColor[
              0.5721498643743627, 0.6635360608135916, 0.9594608796590118], 
             UndirectedEdge[109, 196] -> 
             RGBColor[
              0.3755378784474481, 0.49427664977125924`, 0.9455877406952755], 
             UndirectedEdge[212, 451] -> 
             RGBColor[
              0.3446657193948899, 0.4729538555622631, 0.9431827727572817], 
             UndirectedEdge[186, 414] -> 
             RGBColor[
              0.7724460096073476, 0.8196468662375467, 0.8791293900334951], 
             UndirectedEdge[349, 419] -> 
             RGBColor[
              0.32043926736739536`, 0.44322858433268575`, 0.9419591551162677],
              UndirectedEdge[162, 221] -> 
             RGBColor[
              0.6316051929471853, 0.6458537220908327, 0.6106828548383629], 
             UndirectedEdge[163, 364] -> 
             RGBColor[
              0.5773775926077731, 0.6519608622818416, 0.9643952465323072], 
             UndirectedEdge[191, 300] -> 
             RGBColor[
              0.2518326980669865, 0.38202251115664254`, 0.9376528716506], 
             UndirectedEdge[438, 460] -> 
             RGBColor[
              0.335484785740192, 0.457351679839239, 0.9428778798745596], 
             UndirectedEdge[172, 473] -> 
             RGBColor[
              0.27518607590140487`, 0.4065683919502915, 0.9389828119700436], 
             UndirectedEdge[141, 188] -> 
             RGBColor[
              0.32075948833108536`, 0.44811422107772003`, 0.9418108277015915],
              UndirectedEdge[79, 122] -> 
             RGBColor[
              0.30406034734039167`, 0.4367808306740275, 0.9406321478401243], 
             UndirectedEdge[326, 475] -> 
             RGBColor[
              0.4773932038583929, 0.5862739676909643, 0.9520936749405831], 
             UndirectedEdge[98, 124] -> 
             RGBColor[
              0.44032874613102024`, 0.5550816804147461, 0.9494802254957222], 
             UndirectedEdge[204, 498] -> 
             RGBColor[
              0.24130324604542008`, 0.37095538947615897`, 0.9370532349349001],
              UndirectedEdge[72, 144] -> 
             RGBColor[
              0.24230839667857737`, 0.37201186652183826`, 0.9371104767764713],
              UndirectedEdge[98, 331] -> 
             RGBColor[
              0.36917081699093995`, 0.488766912535399, 0.9451175121884507], 
             UndirectedEdge[311, 377] -> 
             RGBColor[
              0.3511015788614483, 0.4780153038745726, 0.943611642364383], 
             UndirectedEdge[299, 389] -> 
             RGBColor[
              0.39513616395064205`, 0.516668817918154, 0.9463987048551125], 
             UndirectedEdge[131, 238] -> 
             RGBColor[
              0.3170057950127988, 0.4380113879694817, 0.9418225153195623], 
             UndirectedEdge[4, 185] -> 
             RGBColor[
              0.30471506607300886`, 0.436049960394716, 0.9407213904199823], 
             UndirectedEdge[162, 258] -> 
             RGBColor[
              0.28040870497370085`, 0.41183964089568115`, 0.9392882174099649],
              UndirectedEdge[124, 253] -> 
             RGBColor[
              0.3430071534567116, 0.4693759172454315, 0.9431554965159918], 
             UndirectedEdge[319, 449] -> 
             RGBColor[
              0.5246672447046095, 0.6122965826398199, 0.9589857787345331], 
             UndirectedEdge[256, 271] -> 
             RGBColor[
              0.31371612780677927`, 0.444828353509895, 0.9412589696759777], 
             UndirectedEdge[379, 478] -> 
             RGBColor[
              0.3344971819110796, 0.464146379479341, 0.9425348425404979], 
             UndirectedEdge[349, 371] -> 
             RGBColor[
              0.4947390825680813, 0.5999672099119273, 0.953566666785141], 
             UndirectedEdge[130, 325] -> 
             RGBColor[
              0.2822244658349552, 0.41396618603014934`, 0.9393836378643945], 
             UndirectedEdge[269, 369] -> 
             RGBColor[
              0.667645532281088, 0.737975744124332, 0.9692614288896257], 
             UndirectedEdge[43, 355] -> 
             RGBColor[
              0.3159114845194934, 0.44471643355316304`, 0.9414725773118687], 
             UndirectedEdge[11, 414] -> 
             RGBColor[
              0.39796687251627594`, 0.5102123604422298, 0.9475603501689367], 
             UndirectedEdge[117, 255] -> 
             RGBColor[
              0.48630931228476065`, 0.5912396445291304, 0.9534235710500356], 
             UndirectedEdge[401, 475] -> 
             RGBColor[
              0.3454165696809941, 0.46815698367237, 0.9434300657061192], 
             UndirectedEdge[58, 141] -> 
             RGBColor[
              0.358204994057134, 0.4846808947709679, 0.9440454833664493], 
             UndirectedEdge[96, 180] -> 
             RGBColor[
              0.2883404571024404, 0.41747037946230064`, 0.9398390001870384], 
             UndirectedEdge[119, 375] -> 
             RGBColor[
              0.37901179570861, 0.4936357778882957, 0.9461762759898924], 
             UndirectedEdge[220, 382] -> 
             RGBColor[
              0.35686338315051375`, 0.48351885883497825`, 0.9439599971058195],
              UndirectedEdge[104, 356] -> 
             RGBColor[
              0.35174299446881596`, 0.4790838355171098, 0.9436337304668037], 
             UndirectedEdge[225, 440] -> 
             RGBColor[
              0.3831619664718936, 0.502695132028522, 0.94598504811455], 
             UndirectedEdge[259, 341] -> 
             RGBColor[
              0.3229537044873252, 0.45398427122965357`, 0.9418052972615587], 
             UndirectedEdge[290, 362] -> 
             RGBColor[
              0.30076321375197823`, 0.43052748434922883`, 0.940546457800408], 
             UndirectedEdge[79, 267] -> 
             RGBColor[
              0.27534122401871575`, 0.406731462458544, 0.9389916474258033], 
             UndirectedEdge[90, 317] -> 
             RGBColor[
              0.2671817816644882, 0.3980322812369342, 0.9385314861812719], 
             UndirectedEdge[41, 389] -> 
             RGBColor[
              0.3566826480909202, 0.47926928938772867`, 0.9440983465531894], 
             UndirectedEdge[5, 300] -> 
             RGBColor[
              0.26573290199781374`, 0.396632506811774, 0.9384444677009516], 
             UndirectedEdge[290, 340] -> 
             RGBColor[
              0.30004301733430705`, 0.4299036864103666, 0.9405005675215188], 
             UndirectedEdge[288, 392] -> 
             RGBColor[
              0.35771679137506396`, 0.48196986755045934`, 0.9440981566576151],
              UndirectedEdge[45, 292] -> 
             RGBColor[
              0.3182198191986634, 0.4489774652609744, 0.9415368516035263], 
             UndirectedEdge[42, 145] -> 
             RGBColor[
              0.3441449601542558, 0.4706058014263417, 0.9432190488524244], 
             UndirectedEdge[100, 368] -> 
             RGBColor[
              0.331417591705067, 0.45961994588190597`, 0.9424066826058397], 
             UndirectedEdge[302, 315] -> 
             RGBColor[
              0.27660034766088326`, 0.4072853128996209, 0.9390915303212655], 
             UndirectedEdge[255, 338] -> 
             RGBColor[
              0.32263735294905294`, 0.45195379975785027`, 0.9418494523604743],
              UndirectedEdge[59, 263] -> 
             RGBColor[
              0.4709113662482264, 0.5802177594416376, 0.9518027745847126], 
             UndirectedEdge[413, 486] -> 
             RGBColor[
              0.40771144338476123`, 0.5186636411276855, 0.9482783062042781], 
             UndirectedEdge[140, 247] -> 
             RGBColor[
              0.3255835074265959, 0.4554175368020488, 0.9420037886363952], 
             UndirectedEdge[82, 453] -> 
             RGBColor[
              0.39817506289243876`, 0.5186490666130946, 0.9467724607394434], 
             UndirectedEdge[199, 349] -> 
             RGBColor[
              0.38481725470125405`, 0.5077310973697932, 0.9457411930823947], 
             UndirectedEdge[265, 462] -> 
             RGBColor[
              0.41700350005435716`, 0.5356092053669221, 0.9477920721751152], 
             UndirectedEdge[113, 386] -> 
             RGBColor[
              0.2935905443901481, 0.4254169413514568, 0.9400490697373778], 
             UndirectedEdge[140, 219] -> 
             RGBColor[
              0.6520773165172237, 0.7216518220197771, 0.9559267798553485], 
             UndirectedEdge[13, 313] -> 
             RGBColor[
              0.5744545870386395, 0.6654071384990246, 0.959642315869621], 
             UndirectedEdge[74, 463] -> 
             RGBColor[
              0.7518273396713405, 0.8031154325186052, 0.8861902001343818], 
             UndirectedEdge[146, 415] -> 
             RGBColor[
              0.32558634765956207`, 0.4549843533257719, 0.9420199206577019], 
             UndirectedEdge[213, 475] -> 
             RGBColor[
              0.38199225622396893`, 0.5052842256773207, 0.94556118667747], 
             UndirectedEdge[49, 328] -> 
             RGBColor[
              0.662042399128965, 0.725593954207498, 0.8203425752958555], 
             UndirectedEdge[259, 450] -> 
             RGBColor[
              0.30566914143449336`, 0.43581709955653336`, 0.9408209669659195],
              UndirectedEdge[454, 500] -> 
             RGBColor[
              0.4465376031026921, 0.5588071916415958, 0.9503323806392195], 
             UndirectedEdge[469, 495] -> 
             RGBColor[
              0.33828034979182714`, 0.4641753587357317, 0.9428948209089206], 
             UndirectedEdge[158, 182] -> 
             RGBColor[
              0.37872657596746107`, 0.5024556575769958, 0.945353100419253], 
             UndirectedEdge[302, 347] -> 
             RGBColor[
              0.30579360682055556`, 0.4379692792359735, 0.9407540432428521], 
             UndirectedEdge[87, 107] -> 
             RGBColor[
              0.3413949253154085, 0.47012085812550675`, 0.9429743606507868], 
             UndirectedEdge[80, 307] -> 
             RGBColor[
              0.250838751344099, 0.3809778101310257, 0.9375962678551439], 
             UndirectedEdge[159, 443] -> 
             RGBColor[
              0.5987902217597363, 0.67123838124331, 0.9611835961035003], 
             UndirectedEdge[396, 443] -> 
             RGBColor[
              0.6576873028701187, 0.7270916133188894, 0.9647592667401638], 
             UndirectedEdge[15, 452] -> 
             RGBColor[
              0.6067174474613259, 0.6773626847438302, 0.9489810890905075], 
             UndirectedEdge[55, 250] -> 
             RGBColor[
              0.28289509744206204`, 0.41349876357679066`, 0.9394647529437653],
              UndirectedEdge[105, 447] -> 
             RGBColor[
              0.650167849290844, 0.6277076732098281, 0.6036821307458162], 
             UndirectedEdge[55, 242] -> 
             RGBColor[
              0.28386168984855537`, 0.4145147134815134, 0.9395197989513697], 
             UndirectedEdge[133, 440] -> 
             RGBColor[
              0.2920070965701404, 0.42424835118744186`, 0.939940744212658], 
             UndirectedEdge[177, 455] -> 
             RGBColor[
              0.274006577328045, 0.4053286641651614, 0.9389156412712025], 
             UndirectedEdge[186, 456] -> 
             RGBColor[
              0.6669347878767724, 0.7309914824523641, 0.8716511354023772], 
             UndirectedEdge[94, 302] -> 
             RGBColor[
              0.6560146202086394, 0.7203395315407682, 0.8170984088373514], 
             UndirectedEdge[146, 376] -> 
             RGBColor[
              0.4124254299322957, 0.5312776519274504, 0.9476015601034612], 
             UndirectedEdge[44, 106] -> 
             RGBColor[
              0.39862175567336705`, 0.5196878622774443, 0.9466208036774968], 
             UndirectedEdge[46, 205] -> 
             RGBColor[
              0.3164337509444497, 0.4415005375049569, 0.9416401685239236], 
             UndirectedEdge[134, 457] -> 
             RGBColor[
              0.28645802571247625`, 0.41464572185695614`, 0.9397627784746826],
              UndirectedEdge[229, 248] -> 
             RGBColor[
              0.23102647323158226`, 0.3601538496637853, 0.936467987926275], 
             UndirectedEdge[101, 362] -> 
             RGBColor[
              0.31013901712848446`, 0.4403820481582054, 0.9410803959324419], 
             UndirectedEdge[286, 346] -> 
             RGBColor[
              0.39917506132415026`, 0.5107014998888193, 0.9477002228721947], 
             UndirectedEdge[134, 138] -> 
             RGBColor[
              0.2791172892899262, 0.40828754492388375`, 0.939295033240996], 
             UndirectedEdge[144, 494] -> 
             RGBColor[
              0.29899804465692215`, 0.4312357408484615, 0.9403520695006629], 
             UndirectedEdge[35, 147] -> 
             RGBColor[
              0.44991638523050415`, 0.5535860449800986, 0.9515851171463787], 
             UndirectedEdge[5, 211] -> 
             RGBColor[
              0.6216170654712987, 0.694637048123343, 0.9590801067080719], 
             UndirectedEdge[243, 471] -> 
             RGBColor[
              0.2682843190716499, 0.3993142079255616, 0.9385897671288232], 
             UndirectedEdge[154, 338] -> 
             RGBColor[
              0.6321615081709157, 0.700946043820432, 0.9323181362019306], 
             UndirectedEdge[185, 383] -> 
             RGBColor[
              0.3226913008209632, 0.4539207186599191, 0.9417825822369664], 
             UndirectedEdge[416, 429] -> 
             RGBColor[
              0.25538856748064, 0.3857599553655348, 0.9378553731532702], 
             UndirectedEdge[159, 396] -> 
             RGBColor[
              0.31529929496666775`, 0.44267859405080956`, 0.9414887694514711],
              UndirectedEdge[73, 322] -> 
             RGBColor[
              0.2944611356594806, 0.4234229595255085, 0.9402051624039767], 
             UndirectedEdge[287, 300] -> 
             RGBColor[
              0.23449426350373395`, 0.363798717110419, 0.936665473452138], 
             UndirectedEdge[392, 459] -> 
             RGBColor[
              0.2693984658055498, 0.4004852467838734, 0.9386532161370864], 
             UndirectedEdge[200, 450] -> 
             RGBColor[
              0.3183566184725881, 0.44680635447579337`, 0.9416294017836915], 
             UndirectedEdge[104, 148] -> 
             RGBColor[
              0.31963233257967916`, 0.44958574979596516`, 0.9416493798585369],
              UndirectedEdge[94, 325] -> 
             RGBColor[
              0.630917506995532, 0.6947304426447993, 0.8156409877009696], 
             UndirectedEdge[355, 378] -> 
             RGBColor[
              0.29604254672000974`, 0.42383292016248875`, 0.9403410706976475],
              UndirectedEdge[424, 453] -> 
             RGBColor[
              0.376028085415965, 0.4963214061803607, 0.9454764310330916], 
             UndirectedEdge[212, 301] -> 
             RGBColor[
              0.2983473942519221, 0.4294877276433623, 0.9403539792413989], 
             UndirectedEdge[46, 420] -> 
             RGBColor[
              0.36751035440228563`, 0.49274073020092835`, 0.9446384126992353],
              UndirectedEdge[146, 284] -> 
             RGBColor[
              0.31951708995917516`, 0.44860517866950134`, 0.941674285410327], 
             UndirectedEdge[76, 343] -> 
             RGBColor[
              0.3744220574785287, 0.4987273000132726, 0.9450788203074745], 
             UndirectedEdge[111, 256] -> 
             RGBColor[
              0.2978940312684895, 0.43043589280862476`, 0.9402759964347895], 
             UndirectedEdge[277, 319] -> 
             RGBColor[
              0.29889432628595425`, 0.4283336958771228, 0.9404484294173514], 
             UndirectedEdge[240, 429] -> 
             RGBColor[
              0.5507766161621386, 0.275102789018491, 0.5518580455463892], 
             UndirectedEdge[49, 71] -> 
             RGBColor[
              0.6711058144710167, 0.7334442290362826, 0.8209200881069876], 
             UndirectedEdge[19, 139] -> 
             RGBColor[
              0.37884282477213194`, 0.502556346448767, 0.9453605076902919], 
             UndirectedEdge[9, 247] -> 
             RGBColor[
              0.29479316023889357`, 0.4271766807499407, 0.9400994064169816], 
             UndirectedEdge[333, 392] -> 
             RGBColor[
              0.5523338284508713, 0.6378369364521901, 0.9611210284533277], 
             UndirectedEdge[169, 337] -> 
             RGBColor[
              0.2932908847679313, 0.4255976939801931, 0.9400138540513278], 
             UndirectedEdge[21, 119] -> 
             RGBColor[
              0.2768761832965907, 0.4071445136049314, 0.9391230095231384], 
             UndirectedEdge[354, 479] -> 
             RGBColor[
              0.47771747999825764`, 0.58300318534281, 0.9531045619528437], 
             UndirectedEdge[179, 236] -> 
             RGBColor[
              0.24045084191873473`, 0.3700594586934695, 0.9370046917809043], 
             UndirectedEdge[121, 341] -> 
             RGBColor[
              0.2976917381810813, 0.43022326994763616`, 0.9402644761427275], 
             UndirectedEdge[263, 323] -> 
             RGBColor[
              0.4108023815267209, 0.5302381081755632, 0.9473969423859678], 
             UndirectedEdge[200, 401] -> 
             RGBColor[
              0.3070684291110413, 0.4349417517442646, 0.940986556098931], 
             UndirectedEdge[56, 236] -> 
             RGBColor[
              0.32783007255312624`, 0.45535918870224534`, 0.9422203217218834],
              UndirectedEdge[374, 437] -> 
             RGBColor[
              0.4520128561754036, 0.5571668449258502, 0.9515349129488863], 
             UndirectedEdge[74, 195] -> 
             RGBColor[
              0.5527854773234595, 0.6478151790499731, 0.9579364441762778], 
             UndirectedEdge[240, 399] -> 
             RGBColor[
              0.5654203225754866, 0.29005271189943427`, 0.5527081499430414], 
             UndirectedEdge[138, 352] -> 
             RGBColor[
              0.4329114400150599, 0.5472791482398126, 0.9493883563255159], 
             UndirectedEdge[195, 342] -> 
             RGBColor[
              0.4520798847361417, 0.5622308201973406, 0.9510659486274797], 
             UndirectedEdge[13, 363] -> 
             RGBColor[
              0.4062184397745541, 0.5219681540845065, 0.9477496424169092], 
             UndirectedEdge[368, 386] -> 
             RGBColor[
              0.2808561624539998, 0.4125280124213202, 0.9393057150110725], 
             UndirectedEdge[132, 233] -> 
             RGBColor[
              0.33479767542019934`, 0.46348355122037277`, 0.9425877889572893],
              UndirectedEdge[304, 310] -> 
             RGBColor[
              0.32792989656288035`, 0.4580374664174049, 0.942131783369629], 
             UndirectedEdge[213, 259] -> 
             RGBColor[
              0.33095663861592145`, 0.46107973882995534`, 0.9423092422525099],
              UndirectedEdge[226, 446] -> 
             RGBColor[
              0.4269099660947229, 0.5394421033658443, 0.9493170545667955], 
             UndirectedEdge[60, 249] -> 
             RGBColor[
              0.24204937621038258`, 0.37173961958691937`, 0.937095725943994], 
             UndirectedEdge[181, 387] -> 
             RGBColor[
              0.270839393395724, 0.3989116817471756, 0.9388483442490521], 
             UndirectedEdge[94, 168] -> 
             RGBColor[
              0.618417010977467, 0.6815916287525886, 0.8149291029455674], 
             UndirectedEdge[142, 402] -> 
             RGBColor[
              0.5944471074698442, 0.6750610462732967, 0.9644298295114908], 
             UndirectedEdge[188, 310] -> 
             RGBColor[
              0.28411872720850084`, 0.4159571748368537, 0.9394915132473093], 
             UndirectedEdge[74, 239] -> 
             RGBColor[
              0.42163081433430444`, 0.5379753885843884, 0.9485405447888531], 
             UndirectedEdge[376, 400] -> 
             RGBColor[
              0.38403686758226685`, 0.5059973927628966, 0.9458179857031899], 
             UndirectedEdge[292, 308] -> 
             RGBColor[
              0.3703073879080383, 0.49516338004061966`, 0.9448166372009024], 
             UndirectedEdge[7, 142] -> 
             RGBColor[
              0.5616681556270424, 0.6419657387455966, 0.9625134138326092], 
             UndirectedEdge[20, 194] -> 
             RGBColor[
              0.42728650887979225`, 0.5427777392242807, 0.9489275362779738], 
             UndirectedEdge[168, 500] -> 
             RGBColor[
              0.29693429907141544`, 0.4254285549460868, 0.9403677493836735], 
             UndirectedEdge[4, 383] -> 
             RGBColor[
              0.30183876021600464`, 0.43355864882871475`, 0.9405381147541914],
              UndirectedEdge[91, 303] -> 
             RGBColor[
              0.47900077067173347`, 0.5829688790815721, 0.953429301745909], 
             UndirectedEdge[142, 417] -> 
             RGBColor[
              0.6657297394835002, 0.7364583168207695, 0.9690669889240826], 
             UndirectedEdge[229, 338] -> 
             RGBColor[
              0.27260758477067343`, 0.40385823428611256`, 0.9388359707146843],
              UndirectedEdge[69, 388] -> 
             RGBColor[
              0.34576475623465375`, 0.4736817451463171, 0.9432610056472487], 
             UndirectedEdge[170, 374] -> 
             RGBColor[
              0.4395865082175957, 0.5441059653462281, 0.9508272508158235], 
             UndirectedEdge[96, 281] -> 
             RGBColor[
              0.2647356808842273, 0.3955843641939242, 0.9383876774337894], 
             UndirectedEdge[131, 265] -> 
             RGBColor[
              0.4379370423959123, 0.5537407875927465, 0.9491259389823143], 
             UndirectedEdge[117, 369] -> 
             RGBColor[
              0.5399543237963285, 0.6373982705797692, 0.9569263287685579], 
             UndirectedEdge[19, 247] -> 
             RGBColor[
              0.30628862087069253`, 0.43870527585652147`, 0.9407743355268514],
              UndirectedEdge[328, 436] -> 
             RGBColor[
              0.28102137578582076`, 0.4108223368852976, 0.9393839349684209], 
             UndirectedEdge[86, 178] -> 
             RGBColor[
              0.4184583857088132, 0.5368693541961327, 0.9478847762025122], 
             UndirectedEdge[42, 137] -> 
             RGBColor[
              0.3354267739783474, 0.46305454674954805`, 0.9426635337384849], 
             UndirectedEdge[54, 135] -> 
             RGBColor[
              0.33169242228784546`, 0.4536503947602533, 0.9426514850496273], 
             UndirectedEdge[42, 174] -> 
             RGBColor[
              0.34098127546884904`, 0.46786557676325824`, 0.9430174616618068],
              UndirectedEdge[1, 374] -> 
             RGBColor[
              0.4618403818108642, 0.5674961974698333, 0.9520945759953043], 
             UndirectedEdge[160, 285] -> 
             RGBColor[
              0.2546983853892635, 0.38503453022742606`, 0.9378160683041992], 
             UndirectedEdge[454, 471] -> 
             RGBColor[
              0.40914543756795063`, 0.5235042533372339, 0.9480565438510569], 
             UndirectedEdge[26, 425] -> 
             RGBColor[
              0.4040115163128193, 0.5233570951037229, 0.9472402906844819], 
             UndirectedEdge[333, 442] -> 
             RGBColor[
              0.556805572402005, 0.6425370228697738, 0.9613756876559925], 
             UndirectedEdge[75, 410] -> 
             RGBColor[
              0.41286849547831356`, 0.5228374431187706, 0.9486854647699954], 
             UndirectedEdge[31, 40] -> 
             RGBColor[
              0.43080163614036376`, 0.5470583963765356, 0.9488099981426743], 
             UndirectedEdge[3, 258] -> 
             RGBColor[
              0.28454083555579723`, 0.41541868471897114`, 0.9395515131167566],
              UndirectedEdge[132, 273] -> 
             RGBColor[
              0.4231528198002725, 0.5403338995875346, 0.9483501079868003], 
             UndirectedEdge[157, 180] -> 
             RGBColor[
              0.3416637111550095, 0.47035366691020003`, 0.9429914874468082], 
             UndirectedEdge[213, 401] -> 
             RGBColor[
              0.2864053196509161, 0.417044404887983, 0.9396699210358022], 
             UndirectedEdge[84, 391] -> 
             RGBColor[
              0.3506169477437896, 0.4759000688922784, 0.943642841628613], 
             UndirectedEdge[43, 110] -> 
             RGBColor[
              0.3836022612255249, 0.5022286917070888, 0.946094705453491], 
             UndirectedEdge[39, 127] -> 
             RGBColor[
              0.5889456654286038, 0.671108402958335, 0.9637052766705012], 
             UndirectedEdge[52, 469] -> 
             RGBColor[
              0.47853154345683524`, 0.5861646791051969, 0.9524688328471196], 
             UndirectedEdge[260, 483] -> 
             RGBColor[
              0.3056326518172877, 0.43541610324506885`, 0.9408321670879016], 
             UndirectedEdge[98, 311] -> 
             RGBColor[
              0.39171310165668277`, 0.5124602829824929, 0.9464012619518432], 
             UndirectedEdge[51, 127] -> 
             RGBColor[
              0.6601470286959914, 0.7320969739869367, 0.9684307333889087], 
             UndirectedEdge[243, 475] -> 
             RGBColor[
              0.3501811004896471, 0.4731648076409654, 0.9437013986871804], 
             UndirectedEdge[76, 96] -> 
             RGBColor[
              0.27428566057636106`, 0.40529682112602405`, 0.9389434409805653],
              UndirectedEdge[99, 476] -> 
             RGBColor[
              0.32446237655312204`, 0.4507509084827721, 0.9420676637637716], 
             UndirectedEdge[107, 308] -> 
             RGBColor[
              0.3574527716809914, 0.4840293575565491, 0.9439975524218056], 
             UndirectedEdge[190, 263] -> 
             RGBColor[
              0.6951068983247608, 0.735021445087565, 0.6591228544440271], 
             UndirectedEdge[191, 299] -> 
             RGBColor[
              0.30587429639656927`, 0.4358061027044041, 0.9408409481886802], 
             UndirectedEdge[39, 276] -> 
             RGBColor[
              0.40717328572897726`, 0.526416545415821, 0.9473530944761159], 
             UndirectedEdge[51, 214] -> 
             RGBColor[
              0.33466973101860886`, 0.45271645244706965`, 0.9431333952563377],
              UndirectedEdge[295, 409] -> 
             RGBColor[
              0.24208865548015665`, 0.37178090458990143`, 0.9370979628402991],
              UndirectedEdge[371, 382] -> 
             RGBColor[
              0.45040455936281, 0.5615668742294488, 0.9507417101699807], 
             UndirectedEdge[53, 420] -> 
             RGBColor[
              0.36195449844665323`, 0.4879285270175993, 0.944284398470593], 
             UndirectedEdge[87, 308] -> 
             RGBColor[
              0.3852872860002653, 0.5081382148565367, 0.9457711430611353], 
             UndirectedEdge[286, 358] -> 
             RGBColor[
              0.27570115485180396`, 0.4066649771347224, 0.9390284310945987], 
             UndirectedEdge[215, 351] -> 
             RGBColor[
              0.47837692948886956`, 0.587406967850973, 0.952078730723247], 
             UndirectedEdge[114, 258] -> 
             RGBColor[
              0.24151180094611968`, 0.3711745938999387, 0.9370651118279656], 
             UndirectedEdge[87, 292] -> 
             RGBColor[
              0.35424954154245547`, 0.48125488060957733`, 0.9437934454298834],
              UndirectedEdge[196, 383] -> 
             RGBColor[
              0.29038820516718067`, 0.42152338946527856`, 0.939886022583739], 
             UndirectedEdge[65, 495] -> 
             RGBColor[
              0.2706026938116106, 0.4017509667707088, 0.938721795140536], 
             UndirectedEdge[14, 279] -> 
             RGBColor[
              0.33382830894261273`, 0.4613029022669828, 0.9425751235490701], 
             UndirectedEdge[26, 466] -> 
             RGBColor[
              0.40863146497512426`, 0.5273586624296399, 0.9475346697279838], 
             UndirectedEdge[27, 371] -> 
             RGBColor[
              0.4120405118916758, 0.5239495498052192, 0.9484578646883579], 
             UndirectedEdge[258, 472] -> 
             RGBColor[
              0.2548501274995149, 0.38519402080630577`, 0.9378247097928956], 
             UndirectedEdge[26, 117] -> 
             RGBColor[
              0.5527178679849449, 0.6477602907432012, 0.9579311217214888], 
             UndirectedEdge[97, 104] -> 
             RGBColor[
              0.47817100641581745`, 0.5844004747728756, 0.9528470310233796], 
             UndirectedEdge[21, 428] -> 
             RGBColor[
              0.2928847042946262, 0.42397048417272154`, 0.940034671111492], 
             UndirectedEdge[160, 268] -> 
             RGBColor[
              0.27581114939105467`, 0.40627516672534697`, 0.9390532010831494],
              UndirectedEdge[48, 137] -> 
             RGBColor[
              0.34203999412229114`, 0.47000546042320773`, 0.9430401468423], 
             UndirectedEdge[27, 291] -> 
             RGBColor[
              0.2727584209686247, 0.4040167726937266, 0.9388445606130154], 
             UndirectedEdge[117, 140] -> 
             RGBColor[
              0.4843238349482264, 0.5895199238532169, 0.9532970581898403], 
             UndirectedEdge[31, 221] -> 
             RGBColor[
              0.6709502874530497, 0.6799324654098631, 0.6131898894687756], 
             UndirectedEdge[87, 386] -> 
             RGBColor[
              0.3211514786047991, 0.44928883731535585`, 0.9418052280943582], 
             UndirectedEdge[207, 409] -> 
             RGBColor[
              0.30545299093851336`, 0.43251114958833714`, 0.9409213860768234],
              UndirectedEdge[274, 498] -> 
             RGBColor[
              0.2586592612423718, 0.3891976618830768, 0.9380416343244429], 
             UndirectedEdge[28, 69] -> 
             RGBColor[
              0.5772830384048901, 0.6639085377535722, 0.9617061093083057], 
             UndirectedEdge[442, 492] -> 
             RGBColor[
              0.30598218621302975`, 0.4379868393794643, 0.9407713969961118], 
             UndirectedEdge[476, 493] -> 
             RGBColor[
              0.3373398574742904, 0.46190473521567765`, 0.9428882054609592], 
             UndirectedEdge[297, 359] -> 
             RGBColor[
              0.2604469779576485, 0.39107666549861897`, 0.9381434421466881], 
             UndirectedEdge[112, 323] -> 
             RGBColor[
              0.3245558327799467, 0.4491121011617837, 0.9421365873451855], 
             UndirectedEdge[27, 349] -> 
             RGBColor[
              0.34398118028937774`, 0.4679726274571794, 0.9432998322300354], 
             UndirectedEdge[2, 242] -> 
             RGBColor[
              0.22416686804085167`, 0.35294396968423825`, 0.9360773435585393],
              UndirectedEdge[71, 462] -> 
             RGBColor[
              0.3747041151886054, 0.4989716042251083, 0.9450967927753469], 
             UndirectedEdge[165, 285] -> 
             RGBColor[
              0.34726030399355734`, 0.47224733285607245`, 0.9434562512675673],
              UndirectedEdge[91, 172] -> 
             RGBColor[
              0.45512652804729853`, 0.5578755363688805, 0.9520696989472244], 
             UndirectedEdge[19, 26] -> 
             RGBColor[
              0.4024254219318719, 0.5219832998703677, 0.9471392261530561], 
             UndirectedEdge[73, 163] -> 
             RGBColor[
              0.29174330935666726`, 0.4205663517611113, 0.9400503862166951], 
             UndirectedEdge[67, 131] -> 
             RGBColor[
              0.42312847869663106`, 0.540914354016482, 0.9481823503980948], 
             UndirectedEdge[24, 81] -> 
             RGBColor[
              0.29078752368123995`, 0.4219790841285872, 0.9399074455737642], 
             UndirectedEdge[282, 467] -> 
             RGBColor[
              0.335431029723243, 0.46383625944507806`, 0.942635317546318], 
             UndirectedEdge[122, 406] -> 
             RGBColor[
              0.31682382624857997`, 0.44883860709316764`, 0.9414087119456183],
              UndirectedEdge[139, 255] -> 
             RGBColor[
              0.40012318866456953`, 0.5209883280702077, 0.9467164736600311], 
             UndirectedEdge[409, 458] -> 
             RGBColor[
              0.2544547901783395, 0.38477849621591653`, 0.9378021959173038], 
             UndirectedEdge[4, 196] -> 
             RGBColor[
              0.2724119704192263, 0.40365263120007544`, 0.9388248307667548], 
             UndirectedEdge[46, 90] -> 
             RGBColor[
              0.31206048868103664`, 0.43690396158526734`, 0.9413911177076839],
              UndirectedEdge[115, 124] -> 
             RGBColor[
              0.3593361505803555, 0.48566064569780243`, 0.9441175596598665], 
             UndirectedEdge[330, 350] -> 
             RGBColor[
              0.37945595988727865`, 0.5030874132684401, 0.945399576117655], 
             UndirectedEdge[213, 315] -> 
             RGBColor[
              0.27955607969900864`, 0.4098454194316332, 0.9392798669530835], 
             UndirectedEdge[107, 143] -> 
             RGBColor[
              0.3513061353878987, 0.47870545013839516`, 0.9436058941924669], 
             UndirectedEdge[403, 491] -> 
             RGBColor[
              0.5149181722285103, 0.6154549555375809, 0.9554024050349393], 
             UndirectedEdge[200, 254] -> 
             RGBColor[
              0.32963426872228163`, 0.4586598799325461, 0.942271647281623], 
             UndirectedEdge[37, 304] -> 
             RGBColor[
              0.3600591204198283, 0.4862868458352331, 0.9441636266587408], 
             UndirectedEdge[25, 392] -> 
             RGBColor[
              0.2829059447169044, 0.4146824635433347, 0.9394224470785638], 
             UndirectedEdge[231, 492] -> 
             RGBColor[
              0.30427672807320405`, 0.43619429474221605`, 0.940674273678048], 
             UndirectedEdge[22, 63] -> 
             RGBColor[
              0.3641895950998229, 0.48830498801224376`, 0.9444839165931964], 
             UndirectedEdge[201, 256] -> 
             RGBColor[
              0.3061219210777914, 0.43825063333717423`, 0.9407750735384999], 
             UndirectedEdge[57, 92] -> 
             RGBColor[
              0.3695892159731381, 0.49454133560698005`, 0.944770875920265], 
             UndirectedEdge[433, 462] -> 
             RGBColor[
              0.542194174231811, 0.6372189510288166, 0.9579031520315915], 
             UndirectedEdge[286, 294] -> 
             RGBColor[
              0.3060659035390216, 0.43296539627094566`, 0.9409632460304552], 
             UndirectedEdge[319, 331] -> 
             RGBColor[
              0.2565236525355098, 0.38695300172675207`, 0.9379200145679372], 
             UndirectedEdge[222, 307] -> 
             RGBColor[
              0.32346905604132564`, 0.44571972227047285`, 0.9421570844805465],
              UndirectedEdge[276, 283] -> 
             RGBColor[
              0.3903559322485213, 0.511264896946439, 0.9463029383622052], 
             UndirectedEdge[464, 497] -> 
             RGBColor[0.4634539694886485, 0.556765496384, 0.9541053459778286],
              UndirectedEdge[143, 283] -> 
             RGBColor[
              0.3457336573342127, 0.4732935475798089, 0.9432722515972969], 
             UndirectedEdge[265, 433] -> 
             RGBColor[
              0.5569887899064868, 0.650033303527216, 0.9588458518600168], 
             UndirectedEdge[74, 234] -> 
             RGBColor[
              0.41584579628194185`, 0.5329646967108936, 0.9481719285540471], 
             UndirectedEdge[17, 432] -> 
             RGBColor[
              0.3288927859057992, 0.45929213334470076`, 0.9421777353828142], 
             UndirectedEdge[103, 118] -> 
             RGBColor[
              0.5392743048838743, 0.6346388604785883, 0.9577387058274891], 
             UndirectedEdge[426, 489] -> 
             RGBColor[
              0.3106981862500065, 0.4352381397296051, 0.941322102861099], 
             UndirectedEdge[277, 331] -> 
             RGBColor[
              0.30048389702629547`, 0.43000443550982737`, 0.9405389531194547],
              UndirectedEdge[74, 112] -> 
             RGBColor[
              0.3765261778048241, 0.4924844380805954, 0.9459017160141922], 
             UndirectedEdge[80, 372] -> 
             RGBColor[
              0.41816792013425164`, 0.5322295556623502, 0.9486393495584569], 
             UndirectedEdge[180, 281] -> 
             RGBColor[
              0.316767887655081, 0.4473494113763249, 0.9414579003023964], 
             UndirectedEdge[263, 296] -> 
             RGBColor[
              0.36645016431352384`, 0.4918224468327461, 0.9445708583242687], 
             UndirectedEdge[37, 141] -> 
             RGBColor[
              0.3729661798106795, 0.49746629195192077`, 0.9449860530698613], 
             UndirectedEdge[18, 210] -> 
             RGBColor[
              0.34919732609125353`, 0.4736603492518132, 0.9435893698402051], 
             UndirectedEdge[279, 494] -> 
             RGBColor[
              0.2984515037309614, 0.4306612916825806, 0.9403209448034643], 
             UndirectedEdge[101, 337] -> 
             RGBColor[
              0.2789675778925762, 0.41054299030408675`, 0.9391981629142099], 
             UndirectedEdge[217, 378] -> 
             RGBColor[
              0.2218917225300912, 0.350552647499872, 0.9359477773874777], 
             UndirectedEdge[20, 62] -> 
             RGBColor[
              0.3872436822927602, 0.503324880259524, 0.946550687611212], 
             UndirectedEdge[18, 56] -> 
             RGBColor[
              0.40197837832082395`, 0.5225952001059119, 0.9468346847044478], 
             UndirectedEdge[444, 492] -> 
             RGBColor[
              0.28810733372843267`, 0.4191992360870472, 0.9397534505905886], 
             UndirectedEdge[199, 427] -> 
             RGBColor[
              0.43809743505149357`, 0.5517096389382353, 0.9497357566163402], 
             UndirectedEdge[190, 463] -> 
             RGBColor[
              0.984161511444503, 0.9645264325117953, 0.5941509835234344], 
             UndirectedEdge[139, 369] -> 
             RGBColor[
              0.45376820017613734`, 0.5671469541208465, 0.9502192313785534], 
             UndirectedEdge[10, 455] -> 
             RGBColor[
              0.27765305809133417`, 0.40916134664761217`, 0.939123302956187], 
             UndirectedEdge[52, 236] -> 
             RGBColor[
              0.4151420085434342, 0.5282473742639758, 0.9485400092297834], 
             UndirectedEdge[9, 19] -> 
             RGBColor[
              0.30324104170745103`, 0.43550207692827536`, 0.940600780401994], 
             UndirectedEdge[33, 309] -> 
             RGBColor[
              0.2678513104076523, 0.39885908836536516`, 0.9385651079259876], 
             UndirectedEdge[341, 491] -> 
             RGBColor[
              0.47153863139828006`, 0.5777180492922765, 0.952644293947265], 
             UndirectedEdge[87, 143] -> 
             RGBColor[
              0.37914064970717265`, 0.5028143074383826, 0.9453794848317965], 
             UndirectedEdge[110, 378] -> 
             RGBColor[
              0.36373332342604126`, 0.48134517831641455`, 0.9449631988392697],
              UndirectedEdge[401, 471] -> 
             RGBColor[
              0.2635197882629969, 0.3943063839569662, 0.9383184341477622], 
             UndirectedEdge[160, 165] -> 
             RGBColor[
              0.3251608039363978, 0.4490193571067653, 0.9421977174325926], 
             UndirectedEdge[13, 379] -> 
             RGBColor[
              0.4193491105692392, 0.5356075615599453, 0.948503337521865], 
             UndirectedEdge[210, 434] -> 
             RGBColor[
              0.5286559721091593, 0.6179763003114224, 0.9589774675007109], 
             UndirectedEdge[308, 446] -> 
             RGBColor[
              0.4826410673136966, 0.5894576018263817, 0.9528043339504699], 
             UndirectedEdge[153, 395] -> 
             RGBColor[
              0.35105770935023284`, 0.47694379949555854`, 0.9436466887851154],
              UndirectedEdge[24, 83] -> 
             RGBColor[
              0.3103909998659967, 0.44258358053094515`, 0.941023834541742], 
             UndirectedEdge[133, 260] -> 
             RGBColor[
              0.32363622810388953`, 0.45433900341495337`, 0.9418574441235192],
              UndirectedEdge[83, 119] -> 
             RGBColor[
              0.26669021868264475`, 0.39763870734491497`, 0.9384989854699296],
              UndirectedEdge[400, 464] -> 
             RGBColor[
              0.515194090901407, 0.6111476445019803, 0.9570518693496348], 
             UndirectedEdge[175, 320] -> 
             RGBColor[
              0.2624308078700127, 0.393161796518595, 0.9382564183253839], 
             UndirectedEdge[39, 475] -> 
             RGBColor[
              0.3885268340518607, 0.5109441485544092, 0.945977564198363], 
             UndirectedEdge[289, 291] -> 
             RGBColor[
              0.35624534923429485`, 0.4807172685202512, 0.9440035961582691], 
             UndirectedEdge[263, 342] -> 
             RGBColor[
              0.3620671339642804, 0.48802608624174226`, 0.9442915755061765], 
             UndirectedEdge[311, 319] -> 
             RGBColor[
              0.2790659372012526, 0.410646372173846, 0.9392037643313296], 
             UndirectedEdge[141, 304] -> 
             RGBColor[
              0.36457065768546487`, 0.49019451265827124`, 0.9444510978239113],
              UndirectedEdge[30, 43] -> 
             RGBColor[
              0.2733107438706963, 0.40459729908309855`, 0.9388760145851999], 
             UndirectedEdge[85, 95] -> 
             RGBColor[
              0.30069785716693964`, 0.4333828916007254, 0.9404356701718175], 
             UndirectedEdge[305, 438] -> 
             RGBColor[
              0.34232991389877954`, 0.4645463435401068, 0.9432676997967315], 
             UndirectedEdge[23, 212] -> 
             RGBColor[
              0.30667159158638824`, 0.4382369868264806, 0.9408280299650502], 
             UndirectedEdge[80, 461] -> 
             RGBColor[
              0.2650045259927395, 0.3958669374487349, 0.9384029877649984], 
             UndirectedEdge[115, 439] -> 
             RGBColor[
              0.3396907828528396, 0.46864481557712023`, 0.9428657741999859], 
             UndirectedEdge[136, 377] -> 
             RGBColor[
              0.37500906750016927`, 0.4992357385900361, 0.9451162240669808], 
             UndirectedEdge[27, 488] -> 
             RGBColor[
              0.29108461444904765`, 0.42215628078498857`, 0.9399293098292862],
              UndirectedEdge[70, 170] -> 
             RGBColor[
              0.25960938449211335`, 0.39019630165984864`, 0.9380957424379344],
              UndirectedEdge[268, 441] -> 
             RGBColor[
              0.604033775657701, 0.6825537291594692, 0.9654139426486945], 
             UndirectedEdge[394, 445] -> 
             RGBColor[
              0.2849219859108267, 0.41680145066254154`, 0.939537257642092], 
             UndirectedEdge[234, 393] -> 
             RGBColor[
              0.27731750333015615`, 0.4079615039212601, 0.9391352120446925], 
             UndirectedEdge[228, 388] -> 
             RGBColor[
              0.5086951324118152, 0.6067528197853397, 0.956296109882986], 
             UndirectedEdge[8, 114] -> 
             RGBColor[
              0.2253786796113386, 0.3542176604781113, 0.936146354434764], 
             UndirectedEdge[21, 164] -> 
             RGBColor[
              0.32616485031235215`, 0.4569293326436865, 0.9420039137390186], 
             UndirectedEdge[100, 454] -> 
             RGBColor[
              0.4576386538974494, 0.5684223638849784, 0.9510397297795876], 
             UndirectedEdge[6, 267] -> 
             RGBColor[
              0.42940441225067516`, 0.5370295270188958, 0.9499173717507465], 
             UndirectedEdge[210, 495] -> 
             RGBColor[
              0.2737763460497912, 0.40508667649421043`, 0.9389025299405026], 
             UndirectedEdge[112, 342] -> 
             RGBColor[
              0.2758205852175063, 0.4069000792279628, 0.9390312204653941], 
             UndirectedEdge[93, 206] -> 
             RGBColor[
              0.3332082136319725, 0.4586555051340009, 0.9426128801085408], 
             UndirectedEdge[485, 497] -> 
             RGBColor[
              0.22093376250508298`, 0.3495457707754147, 0.9358932229812283], 
             UndirectedEdge[36, 240] -> 
             RGBColor[
              0.5927588845520879, 0.31373200020748837`, 0.5544501389376493], 
             UndirectedEdge[275, 285] -> 
             RGBColor[
              0.27959597085021887`, 0.41120347114498385`, 0.9392339489635235],
              UndirectedEdge[36, 399] -> 
             RGBColor[
              0.3408602071275746, 0.46965771210692264`, 0.9429402888806907], 
             UndirectedEdge[72, 279] -> 
             RGBColor[
              0.24176185575261663`, 0.37143741735595737`, 0.9370793520792726],
              UndirectedEdge[278, 413] -> 
             RGBColor[
              0.2757840928375999, 0.4071969456666962, 0.9390168681498732], 
             UndirectedEdge[10, 120] -> 
             RGBColor[
              0.30865145240923986`, 0.43830113305253976`, 0.9410146255145713],
              UndirectedEdge[59, 153] -> 
             RGBColor[
              0.4700780350979875, 0.5794959698837422, 0.9517496754607051], 
             UndirectedEdge[377, 488] -> 
             RGBColor[
              0.3599459922003416, 0.4861888598575034, 0.9441564182286304], 
             UndirectedEdge[53, 306] -> 
             RGBColor[
              0.30761674015332524`, 0.4332606538203667, 0.9411004363518461], 
             UndirectedEdge[172, 448] -> 
             RGBColor[
              0.3926040328555809, 0.5073263092290483, 0.9470045646330636], 
             UndirectedEdge[138, 367] -> 
             RGBColor[
              0.2958709748799463, 0.4258967307240137, 0.9402491308504909], 
             UndirectedEdge[71, 431] -> 
             RGBColor[
              0.3976404501344445, 0.5188379047414802, 0.946558275756291], 
             UndirectedEdge[180, 392] -> 
             RGBColor[
              0.3121850674735405, 0.4425325767979439, 0.9411969154727327], 
             UndirectedEdge[33, 227] -> 
             RGBColor[
              0.2775689780947046, 0.4090729732401748, 0.939118514724764], 
             UndirectedEdge[30, 384] -> 
             RGBColor[
              0.35563048536164205`, 0.47923047064194335`, 0.9439993567460379],
              UndirectedEdge[441, 467] -> 
             RGBColor[
              0.5928437472423507, 0.671742516900671, 0.9647418949820201], 
             UndirectedEdge[99, 122] -> 
             RGBColor[
              0.35063717682785556`, 0.4781260318565206, 0.9435632687445578], 
             UndirectedEdge[89, 225] -> 
             RGBColor[
              0.3893619798955433, 0.5092117392403335, 0.9463381297069289], 
             UndirectedEdge[146, 497] -> 
             RGBColor[
              0.27791513098872345`, 0.4048788820750106, 0.9393051153915428], 
             UndirectedEdge[176, 197] -> 
             RGBColor[
              0.5231156868209956, 0.6112793914000908, 0.9588002787991607], 
             UndirectedEdge[326, 474] -> 
             RGBColor[
              0.3663056985511087, 0.4817420663691283, 0.9453196748405371], 
             UndirectedEdge[173, 241] -> 
             RGBColor[
              0.693007188637419, 0.7523806350132263, 0.8194555425863893], 
             UndirectedEdge[403, 405] -> 
             RGBColor[
              0.3461748713828501, 0.4733243753618733, 0.9433132292658726], 
             UndirectedEdge[79, 476] -> 
             RGBColor[
              0.27788554706565816`, 0.40940570730027903`, 0.9391365428593381],
              UndirectedEdge[46, 257] -> 
             RGBColor[
              0.5191676506949495, 0.619070516962609, 0.9556911717897392], 
             UndirectedEdge[450, 491] -> 
             RGBColor[
              0.45425406834544824`, 0.5595508776191563, 0.9516599636516259], 
             UndirectedEdge[200, 243] -> 
             RGBColor[
              0.31183295991969434`, 0.43994957571286, 0.9412578890799922], 
             UndirectedEdge[296, 424] -> 
             RGBColor[
              0.2979336177418239, 0.42933179625203527`, 0.9403202006781691], 
             UndirectedEdge[269, 466] -> 
             RGBColor[
              0.598926199920335, 0.6787604990115247, 0.964798148776292], 
             UndirectedEdge[74, 453] -> 
             RGBColor[
              0.4955548068988055, 0.6013527425869175, 0.9534310361575956], 
             UndirectedEdge[18, 469] -> 
             RGBColor[
              0.41370132983328956`, 0.5327490314933345, 0.9475816608086232], 
             UndirectedEdge[279, 481] -> 
             RGBColor[
              0.5689674465296238, 0.6511331100610867, 0.9627025618454893], 
             UndirectedEdge[19, 468] -> 
             RGBColor[
              0.30590587020867477`, 0.43830298064294715`, 0.9407525384428783],
              UndirectedEdge[415, 464] -> 
             RGBColor[
              0.5111251861594871, 0.6068709676347613, 0.9568201512439877], 
             UndirectedEdge[234, 262] -> 
             RGBColor[
              0.5446789197438267, 0.6355797337712862, 0.9596661690749291], 
             UndirectedEdge[241, 417] -> 
             RGBColor[
              0.7304764700717994, 0.7844904807973461, 0.8219381452000416], 
             UndirectedEdge[309, 489] -> 
             RGBColor[
              0.23716842006368674`, 0.3666094252062482, 0.9368177627121672], 
             UndirectedEdge[83, 426] -> 
             RGBColor[
              0.35186069418283894`, 0.47850254542075293`, 0.9436662467934003],
              UndirectedEdge[6, 99] -> 
             RGBColor[
              0.49854103771969493`, 0.6020865041516839, 0.9541332396621024], 
             UndirectedEdge[121, 491] -> 
             RGBColor[
              0.4622552316426629, 0.5679606075475824, 0.9521156180647419], 
             UndirectedEdge[42, 358] -> 
             RGBColor[
              0.30089258795224805`, 0.43314277055239925`, 0.9404630459422835],
              UndirectedEdge[69, 461] -> 
             RGBColor[
              0.31314865580075885`, 0.43940015561008516`, 0.941403566978735], 
             UndirectedEdge[161, 387] -> 
             RGBColor[
              0.24638335715826726`, 0.3762949083534094, 0.9373425397474258], 
             UndirectedEdge[117, 390] -> 
             RGBColor[
              0.6627212779293175, 0.7360279846440232, 0.9673006998124996], 
             UndirectedEdge[244, 334] -> 
             RGBColor[
              0.39339805142375683`, 0.5055091916286076, 0.9472911553552363], 
             UndirectedEdge[173, 493] -> 
             RGBColor[
              0.40393215989636777`, 0.5242874675067306, 0.9469591779387803], 
             UndirectedEdge[229, 255] -> 
             RGBColor[
              0.30726746194574567`, 0.43579906980599986`, 0.9409741598055521],
              UndirectedEdge[39, 401] -> 
             RGBColor[
              0.2929398974788079, 0.4227043277650715, 0.9400862985566951], 
             UndirectedEdge[379, 380] -> 
             RGBColor[
              0.2827762431259566, 0.4143843788853043, 0.9394209835931209], 
             UndirectedEdge[92, 140] -> 
             RGBColor[
              0.39093223452873116`, 0.5130275855485311, 0.9461308341897372], 
             UndirectedEdge[78, 97] -> 
             RGBColor[
              0.40018278094990445`, 0.506128381047741, 0.9482702976333264], 
             UndirectedEdge[395, 463] -> 
             RGBColor[
              0.6409456536202138, 0.7071705764776843, 0.87872791698853], 
             UndirectedEdge[174, 338] -> 
             RGBColor[
              0.34085584768556987`, 0.467733744210451, 0.9430103187351029], 
             UndirectedEdge[143, 423] -> 
             RGBColor[
              0.4957794365215579, 0.5997901306534994, 0.953930861997469], 
             UndirectedEdge[94, 100] -> 
             RGBColor[
              0.6845780371883443, 0.745079727689508, 0.8189184445096602], 
             UndirectedEdge[404, 408] -> 
             RGBColor[
              0.4316978896806882, 0.5393217227911822, 0.9500587588941273], 
             UndirectedEdge[301, 389] -> 
             RGBColor[
              0.36071427612320295`, 0.4835067860696389, 0.9443279418053686], 
             UndirectedEdge[16, 422] -> 
             RGBColor[
              0.2970223843813677, 0.42779185248587526`, 0.9402896237380889], 
             UndirectedEdge[389, 451] -> 
             RGBColor[
              0.4070326012661707, 0.5269729139885397, 0.9471567353212516], 
             UndirectedEdge[74, 296] -> 
             RGBColor[
              0.4174603392246644, 0.534363132658592, 0.9482748058026731], 
             UndirectedEdge[225, 453] -> 
             RGBColor[
              0.48202716878470886`, 0.5903703965527416, 0.9523660909318827], 
             UndirectedEdge[340, 378] -> 
             RGBColor[
              0.2859512536480837, 0.4150923493067238, 0.9396980624264845], 
             UndirectedEdge[52, 428] -> 
             RGBColor[
              0.40908089376026613`, 0.5218767583299929, 0.9481948377094978], 
             UndirectedEdge[84, 230] -> 
             RGBColor[
              0.3402076729639443, 0.46495926111252095`, 0.9430500488290429], 
             UndirectedEdge[119, 237] -> 
             RGBColor[
              0.25702177709048035`, 0.38747656221694715`, 0.9379483820244334],
              UndirectedEdge[67, 171] -> 
             RGBColor[
              0.3405756745678454, 0.4666583030172575, 0.9430229581160348], 
             UndirectedEdge[25, 157] -> 
             RGBColor[
              0.31238458839837335`, 0.44250355365559085`, 0.9412170190526394],
              UndirectedEdge[124, 484] -> 
             RGBColor[
              0.36958007867693904`, 0.4945334213402663, 0.944770293699831], 
             UndirectedEdge[368, 500] -> 
             RGBColor[
              0.32031654091030964`, 0.4500047736385234, 0.9416993334654716], 
             UndirectedEdge[283, 422] -> 
             RGBColor[
              0.31492500266398915`, 0.4466086393924693, 0.9413091513647339], 
             UndirectedEdge[334, 369] -> 
             RGBColor[
              0.34911672354704265`, 0.46955961480720343`, 0.9438051670169327],
              UndirectedEdge[42, 346] -> 
             RGBColor[
              0.4243664944245944, 0.5371792933064962, 0.9491348377198795], 
             UndirectedEdge[112, 263] -> 
             RGBColor[
              0.32551600289368354`, 0.4499437522547494, 0.9421977685357877], 
             UndirectedEdge[146, 201] -> 
             RGBColor[
              0.33790129871689933`, 0.4670948543606567, 0.9427517498532225], 
             UndirectedEdge[16, 243] -> 
             RGBColor[
              0.26298445652438346`, 0.3937437163576909, 0.9382879477972005], 
             UndirectedEdge[285, 481] -> 
             RGBColor[
              0.5652376604595832, 0.6472128684193785, 0.9624901560465244], 
             UndirectedEdge[231, 444] -> 
             RGBColor[
              0.27336064835163143`, 0.40464975185668817`, 0.938878856571562], 
             UndirectedEdge[137, 408] -> 
             RGBColor[
              0.3195018777765694, 0.4463164711447428, 0.9417566344585664], 
             UndirectedEdge[431, 436] -> 
             RGBColor[
              0.3405258952647875, 0.4623621608738686, 0.9431755103318401], 
             UndirectedEdge[98, 277] -> 
             RGBColor[
              0.41154149074138446`, 0.5301476066857698, 0.947645927037865], 
             UndirectedEdge[131, 391] -> 
             RGBColor[
              0.3644678891041684, 0.48789705813008377`, 0.9445254113641899], 
             UndirectedEdge[52, 227] -> 
             RGBColor[
              0.4144307497631573, 0.5274997961894934, 0.9484995040944597], 
             UndirectedEdge[27, 419] -> 
             RGBColor[
              0.23774069669098985`, 0.36721092422597756`, 0.9368503530194847],
              UndirectedEdge[232, 312] -> 
             RGBColor[
              0.30873964227789213`, 0.4414993262325967, 0.94090594022812], 
             UndirectedEdge[247, 466] -> 
             RGBColor[
              0.312494663913945, 0.4440806384157937, 0.941169779101779], 
             UndirectedEdge[253, 484] -> 
             RGBColor[
              0.31215815057763907`, 0.4426560614675468, 0.9411898253312394], 
             UndirectedEdge[121, 200] -> 
             RGBColor[
              0.3263577817698028, 0.45521608440421946`, 0.9420850561968075], 
             UndirectedEdge[79, 99] -> 
             RGBColor[
              0.34447784948773547`, 0.471788439591332, 0.9432075153371591], 
             UndirectedEdge[109, 300] -> 
             RGBColor[
              0.3617072946312161, 0.47973982927073755`, 0.9448001094074563], 
             UndirectedEdge[31, 397] -> 
             RGBColor[
              0.39176196832272353`, 0.5137462592572543, 0.9461837040933856], 
             UndirectedEdge[70, 374] -> 
             RGBColor[
              0.45636224548486404`, 0.561738328857303, 0.9517826042357151], 
             UndirectedEdge[240, 352] -> 
             RGBColor[
              0.6741496801719704, 0.38211990138833707`, 0.5602189327464373], 
             UndirectedEdge[105, 323] -> 
             RGBColor[
              0.3900813564527566, 0.5122905977254976, 0.9460766169911379], 
             UndirectedEdge[46, 53] -> 
             RGBColor[
              0.394278881738257, 0.5159262831540428, 0.9463440795906042], 
             UndirectedEdge[221, 223] -> 
             RGBColor[
              0.6856387965393599, 0.6926549137144922, 0.6141258282792167], 
             UndirectedEdge[33, 159] -> 
             RGBColor[
              0.26839959922702883`, 0.3994353746780489, 0.9385963321631303], 
             UndirectedEdge[16, 454] -> 
             RGBColor[
              0.4038455750206842, 0.5179337617693632, 0.9477547245194341], 
             UndirectedEdge[195, 224] -> 
             RGBColor[
              0.7366252192312991, 0.7938987114072118, 0.9747813665447173], 
             UndirectedEdge[259, 500] -> 
             RGBColor[
              0.3454632727627437, 0.47364465620330026`, 0.9432335921526326], 
             UndirectedEdge[24, 77] -> 
             RGBColor[
              0.2775570296130085, 0.4080729960011017, 0.9391539885093404], 
             UndirectedEdge[226, 386] -> 
             RGBColor[
              0.2814782237514083, 0.41318183828586075`, 0.9393411404817027], 
             UndirectedEdge[289, 314] -> 
             RGBColor[
              0.3344616009003273, 0.4578211678518344, 0.9427630439168173], 
             UndirectedEdge[179, 325] -> 
             RGBColor[
              0.23580675518835192`, 0.3651782290877317, 0.9367402179119195], 
             UndirectedEdge[81, 83] -> 
             RGBColor[
              0.28175274359074914`, 0.4134703760425711, 0.9393567739804374], 
             UndirectedEdge[312, 376] -> 
             RGBColor[
              0.3859531471568004, 0.5080115240948738, 0.945927114990078], 
             UndirectedEdge[270, 309] -> 
             RGBColor[
              0.32356539951774693`, 0.4497368922513223, 0.9420191905656317], 
             UndirectedEdge[139, 269] -> 
             RGBColor[
              0.6568264793099646, 0.7289108108661633, 0.9684875033797924], 
             UndirectedEdge[269, 425] -> 
             RGBColor[
              0.5943062512580302, 0.6747589316856076, 0.9645037697327901], 
             UndirectedEdge[25, 492] -> 
             RGBColor[
              0.30041891590501363`, 0.43213948955402903`, 0.9404545769821913],
              UndirectedEdge[142, 173] -> 
             RGBColor[
              0.6282604580491197, 0.7043484710366497, 0.9665843863104303], 
             UndirectedEdge[132, 209] -> 
             RGBColor[
              0.3418376986441135, 0.4705043661283965, 0.9430025737757628], 
             UndirectedEdge[389, 409] -> 
             RGBColor[
              0.34378156990494324`, 0.4657094382386658, 0.9433636492359327], 
             UndirectedEdge[337, 370] -> 
             RGBColor[
              0.3175810202672872, 0.4466545265844284, 0.9415609432049885], 
             UndirectedEdge[230, 242] -> 
             RGBColor[
              0.25516961082577544`, 0.3855298180386184, 0.9378429038956929], 
             UndirectedEdge[28, 461] -> 
             RGBColor[
              0.5052249872449858, 0.5952402720212037, 0.9573436676510556], 
             UndirectedEdge[318, 350] -> 
             RGBColor[
              0.6314156820430556, 0.7061099641547899, 0.9672326246989099], 
             UndirectedEdge[390, 478] -> 
             RGBColor[
              0.5343099756608753, 0.629203340739173, 0.9579030513772879], 
             UndirectedEdge[167, 434] -> 
             RGBColor[
              0.706947110004692, 0.7708103154409804, 0.9715495681397539], 
             UndirectedEdge[247, 269] -> 
             RGBColor[
              0.5842722754085252, 0.6650597402739178, 0.9639013312163518], 
             UndirectedEdge[394, 398] -> 
             RGBColor[
              0.2492717482164607, 0.3793307904901411, 0.9375070293451984], 
             UndirectedEdge[14, 158] -> 
             RGBColor[
              0.36441198251856866`, 0.4900570762039515, 0.9444409871825876], 
             UndirectedEdge[131, 433] -> 
             RGBColor[
              0.5631277165733661, 0.655350533254641, 0.9592370188387906], 
             UndirectedEdge[87, 422] -> 
             RGBColor[
              0.3483319950369491, 0.4761293992510431, 0.9434163845992334], 
             UndirectedEdge[210, 469] -> 
             RGBColor[
              0.3384385552369569, 0.4643416426893676, 0.9429038304749768], 
             UndirectedEdge[312, 414] -> 
             RGBColor[
              0.4295382255491977, 0.5433958542192279, 0.9493582920185304], 
             UndirectedEdge[277, 311] -> 
             RGBColor[
              0.3230261816920383, 0.4536978059569212, 0.9418227028828471], 
             UndirectedEdge[332, 424] -> 
             RGBColor[
              0.391777433377553, 0.5091074363556182, 0.9467162773963903], 
             UndirectedEdge[328, 433] -> 
             RGBColor[
              0.5056259896986834, 0.6055454275566176, 0.9555730596491164], 
             UndirectedEdge[88, 428] -> 
             RGBColor[
              0.4090092307418648, 0.5218185790632726, 0.948189196134179], 
             UndirectedEdge[8, 162] -> 
             RGBColor[
              0.2642755836389198, 0.39488270747385373`, 0.9383694600167634], 
             UndirectedEdge[27, 289] -> 
             RGBColor[
              0.3447695378786423, 0.4686554631769958, 0.9433500656785061], 
             UndirectedEdge[192, 280] -> 
             RGBColor[
              0.31669593112690797`, 0.4477440914439453, 0.9414365820971407], 
             UndirectedEdge[347, 477] -> 
             RGBColor[
              0.330695884288776, 0.45953838035408784`, 0.9423407943429076], 
             UndirectedEdge[145, 346] -> 
             RGBColor[
              0.480283123238311, 0.5875084653892605, 0.9526283374492894], 
             UndirectedEdge[232, 415] -> 
             RGBColor[
              0.30275445796143857`, 0.43520851803340055`, 0.9405650928355848],
              UndirectedEdge[189, 374] -> 
             RGBColor[
              0.44308450115914383`, 0.5477825777133574, 0.9510264563390278], 
             UndirectedEdge[139, 140] -> 
             RGBColor[
              0.3981377113280353, 0.5192686073942943, 0.9465899607998358], 
             UndirectedEdge[134, 251] -> 
             RGBColor[
              0.2677302165288191, 0.39842463482913104`, 0.9385694590338514], 
             UndirectedEdge[67, 281] -> 
             RGBColor[
              0.34767204988366923`, 0.4741170434103705, 0.9434270861921245], 
             UndirectedEdge[167, 495] -> 
             RGBColor[
              0.4520674839453239, 0.5579206916237686, 0.9514746305795456], 
             UndirectedEdge[143, 179] -> 
             RGBColor[
              0.29689502723247074`, 0.42196105079488155`, 0.9404909638632812],
              UndirectedEdge[21, 175] -> 
             RGBColor[
              0.2812067456810776, 0.41169620924454087`, 0.9393696286444421], 
             UndirectedEdge[366, 473] -> 
             RGBColor[
              0.44724099555442565`, 0.5566966838204762, 0.9508494149738049], 
             UndirectedEdge[143, 292] -> 
             RGBColor[
              0.36416075161494565`, 0.4898394726224657, 0.9444249789715635], 
             UndirectedEdge[267, 486] -> 
             RGBColor[
              0.41086570180841675`, 0.5219789667224825, 0.9484579365551981], 
             UndirectedEdge[248, 380] -> 
             RGBColor[
              0.22993608251703207`, 0.3590077798880287, 0.9364058917881699], 
             UndirectedEdge[48, 407] -> 
             RGBColor[
              0.26091928942119386`, 0.39157309479308156`, 0.9381703395858147],
              UndirectedEdge[436, 459] -> 
             RGBColor[
              0.24388484839776414`, 0.37366881723151557`, 0.9372002533697277],
              UndirectedEdge[235, 262] -> 
             RGBColor[
              0.5069741533960583, 0.5967967871164728, 0.9574879199748809], 
             UndirectedEdge[236, 283] -> 
             RGBColor[
              0.28928947202047667`, 0.42139195547839686`, 0.9397859795149199],
              UndirectedEdge[99, 493] -> 
             RGBColor[
              0.40393215989636777`, 0.5242874675067306, 0.9469591779387803], 
             UndirectedEdge[109, 456] -> 
             RGBColor[
              0.4165345499806093, 0.534203917440789, 0.9480382473161096], 
             UndirectedEdge[208, 289] -> 
             RGBColor[
              0.6751101293377431, 0.7429844387000765, 0.9704640124369094], 
             UndirectedEdge[266, 410] -> 
             RGBColor[
              0.2361841584731277, 0.3655749038687814, 0.9367617104706694], 
             UndirectedEdge[299, 301] -> 
             RGBColor[
              0.30696155656966484`, 0.43694888208260413`, 0.9409028660470807],
              UndirectedEdge[314, 359] -> 
             RGBColor[
              0.23352384824055802`, 0.36277874914093977`, 0.936610209738501], 
             UndirectedEdge[209, 214] -> 
             RGBColor[
              0.25186424722623035`, 0.38167697545977675`, 0.9376685342391986],
              UndirectedEdge[210, 326] -> 
             RGBColor[
              0.3938587264788299, 0.5107020456840335, 0.9468887790199689], 
             UndirectedEdge[53, 317] -> 
             RGBColor[
              0.3494001747217085, 0.47705460280570966`, 0.9434844480641921], 
             UndirectedEdge[402, 459] -> 
             RGBColor[
              0.2891137191769806, 0.41984977893183983`, 0.9398256735140335], 
             UndirectedEdge[89, 249] -> 
             RGBColor[
              0.28679054554240446`, 0.4187654253088531, 0.9396436693488242], 
             UndirectedEdge[67, 135] -> 
             RGBColor[
              0.42203374976672503`, 0.5399661548400733, 0.9481125952387119], 
             UndirectedEdge[90, 178] -> 
             RGBColor[
              0.33150955997872156`, 0.45374976960457536`, 0.942630395332634], 
             UndirectedEdge[174, 229] -> 
             RGBColor[
              0.3254859566822626, 0.4515790142586006, 0.9421350261801806], 
             UndirectedEdge[266, 364] -> 
             RGBColor[
              0.571421622539154, 0.6457007601094098, 0.9640560628479675], 
             UndirectedEdge[407, 430] -> 
             RGBColor[
              0.2609327731080974, 0.39158726700293234`, 0.9381711074618366], 
             UndirectedEdge[217, 355] -> 
             RGBColor[
              0.28496403299188555`, 0.41218869981589007`, 0.9397101657300232],
              UndirectedEdge[176, 426] -> 
             RGBColor[
              0.5961090016475901, 0.6793442615313957, 0.9632740688367647], 
             UndirectedEdge[280, 483] -> 
             RGBColor[
              0.3018482901175926, 0.4321382793483425, 0.9405910309067766], 
             UndirectedEdge[51, 347] -> 
             RGBColor[
              0.3864852799539603, 0.5071778796736761, 0.9460842141139706], 
             UndirectedEdge[152, 451] -> 
             RGBColor[
              0.32474995740454843`, 0.45344580538389556`, 0.9419964351192681],
              UndirectedEdge[105, 342] -> 
             RGBColor[
              0.34134610889031614`, 0.47007857579167667`, 0.9429712501113465],
              UndirectedEdge[318, 496] -> 
             RGBColor[
              0.5705354291838751, 0.6477026852391936, 0.9635612099993531], 
             UndirectedEdge[114, 289] -> 
             RGBColor[
              0.3307836109719353, 0.4539553672390641, 0.9425535878314939], 
             UndirectedEdge[103, 331] -> 
             RGBColor[
              0.3266402285939334, 0.4526597352582654, 0.9422056114378088], 
             UndirectedEdge[107, 113] -> 
             RGBColor[
              0.3138339911007575, 0.4462489621616077, 0.9412182022938064], 
             UndirectedEdge[16, 56] -> 
             RGBColor[
              0.32305343713879064`, 0.4503386420256012, 0.9419482994014359], 
             UndirectedEdge[140, 370] -> 
             RGBColor[
              0.35522926529207666`, 0.4821034680791518, 0.9438558725608736], 
             UndirectedEdge[213, 500] -> 
             RGBColor[
              0.3374876403407132, 0.46673656426627874`, 0.9427253919072756], 
             UndirectedEdge[280, 327] -> 
             RGBColor[
              0.4541495653474271, 0.5645332525374798, 0.9510569733838214], 
             UndirectedEdge[76, 238] -> 
             RGBColor[
              0.25109934589197075`, 0.3809265342954701, 0.9376230146603679], 
             UndirectedEdge[253, 261] -> 
             RGBColor[
              0.534004706576626, 0.6237267733068386, 0.9592617085416454], 
             UndirectedEdge[232, 350] -> 
             RGBColor[
              0.3407486011316858, 0.46956104460276427`, 0.942933177445322], 
             UndirectedEdge[166, 320] -> 
             RGBColor[
              0.26700295324460466`, 0.39796741119805124`, 0.938516795240584], 
             UndirectedEdge[33, 119] -> 
             RGBColor[
              0.2562106010937779, 0.3866239648128842, 0.9379021867514485], 
             UndirectedEdge[71, 228] -> 
             RGBColor[
              0.5291334026562579, 0.6246794631010963, 0.9575902151557317], 
             UndirectedEdge[50, 244] -> 
             RGBColor[
              0.4205882565974581, 0.5340878212247467, 0.9488395973155748], 
             UndirectedEdge[235, 344] -> 
             RGBColor[
              0.28719224146549027`, 0.4170482445397752, 0.9397448788360372], 
             UndirectedEdge[72, 494] -> 
             RGBColor[
              0.2559559018970738, 0.3859957197783887, 0.9379008831456335], 
             UndirectedEdge[185, 496] -> 
             RGBColor[
              0.2864621339338571, 0.41686497141372725`, 0.9396819129374507], 
             UndirectedEdge[106, 370] -> 
             RGBColor[
              0.3864649547891921, 0.5091582523701507, 0.945846183074994], 
             UndirectedEdge[51, 113] -> 
             RGBColor[
              0.39628022979491506`, 0.5169772791010052, 0.9466601725309547], 
             UndirectedEdge[422, 443] -> 
             RGBColor[
              0.6343063900512014, 0.7068402417939909, 0.9632694556502718], 
             UndirectedEdge[4, 335] -> 
             RGBColor[
              0.2628176593960756, 0.39356840200029053`, 0.9382784489474976], 
             UndirectedEdge[1, 84] -> 
             RGBColor[
              0.351857740376708, 0.47720422062027235`, 0.9437135029334696], 
             UndirectedEdge[90, 272] -> 
             RGBColor[
              0.2502232081774445, 0.38033083523518085`, 0.9375612135824174], 
             UndirectedEdge[213, 450] -> 
             RGBColor[
              0.2976935090124629, 0.4289090076195118, 0.9403127667205626], 
             UndirectedEdge[5, 212] -> 
             RGBColor[
              0.31116033800965376`, 0.4429549439202938, 0.94108365743335], 
             UndirectedEdge[50, 106] -> 
             RGBColor[
              0.3519121293697573, 0.47731468196778926`, 0.943714648912674], 
             UndirectedEdge[115, 291] -> 
             RGBColor[
              0.3012387259644883, 0.433073296157218, 0.940498622763964], 
             UndirectedEdge[9, 117] -> 
             RGBColor[
              0.45353348776052405`, 0.5612790678011088, 0.9513926759704268], 
             UndirectedEdge[194, 388] -> 
             RGBColor[
              0.3217826230699953, 0.45290962677615065`, 0.9417328853285644], 
             UndirectedEdge[202, 211] -> 
             RGBColor[
              0.6027670048125717, 0.6748244392081459, 0.9580066236397231], 
             UndirectedEdge[113, 308] -> 
             RGBColor[
              0.3577263517856143, 0.4842663188926376, 0.9440149847041548], 
             UndirectedEdge[51, 421] -> 
             RGBColor[
              0.3494642874988949, 0.4682664693369091, 0.943975923361305], 
             UndirectedEdge[109, 335] -> 
             RGBColor[
              0.36594356742429734`, 0.4841924205714744, 0.9450413588760183], 
             UndirectedEdge[278, 329] -> 
             RGBColor[
              0.33710622069672935`, 0.46606866322373197`, 0.9427134469769816],
              UndirectedEdge[129, 206] -> 
             RGBColor[
              0.28414159550960505`, 0.4159812108712483, 0.9394928155632265], 
             UndirectedEdge[166, 227] -> 
             RGBColor[
              0.2622853023497891, 0.3930088609912572, 0.9382481320012632], 
             UndirectedEdge[294, 411] -> 
             RGBColor[
              0.34012408237315794`, 0.4687627016388829, 0.9429028089304989], 
             UndirectedEdge[362, 384] -> 
             RGBColor[
              0.3888601293561842, 0.5112328321951052, 0.945998801480433], 
             UndirectedEdge[143, 308] -> 
             RGBColor[
              0.3951984960727555, 0.516722806869425, 0.9464026766028153], 
             UndirectedEdge[151, 310] -> 
             RGBColor[
              0.34806365703808, 0.47547631778879756`, 0.9434146887835235], 
             UndirectedEdge[297, 397] -> 
             RGBColor[
              0.3441210894347603, 0.4711661859129309, 0.9431962523744841], 
             UndirectedEdge[114, 359] -> 
             RGBColor[
              0.22984585831216603`, 0.35891294852816946`, 0.9364007536531774],
              UndirectedEdge[141, 220] -> 
             RGBColor[
              0.3765968894110515, 0.5006110301229925, 0.9452173986750865], 
             UndirectedEdge[122, 493] -> 
             RGBColor[
              0.3635146577490239, 0.4892798585894262, 0.9443838104417454], 
             UndirectedEdge[146, 442] -> 
             RGBColor[
              0.32549238686378257`, 0.4548855945719491, 0.9420145697293848], 
             UndirectedEdge[294, 478] -> 
             RGBColor[
              0.36639256592345193`, 0.49177255800224506`, 0.9445671882057856],
              UndirectedEdge[76, 487] -> 
             RGBColor[
              0.41650736971856916`, 0.5333485000033857, 0.9482663650269091], 
             UndirectedEdge[67, 70] -> 
             RGBColor[
              0.3392830550449261, 0.465299677941858, 0.9429493453464637], 
             UndirectedEdge[346, 358] -> 
             RGBColor[
              0.4370307510363033, 0.5500454345153181, 0.9498723345391485], 
             UndirectedEdge[149, 165] -> 
             RGBColor[
              0.3418925511897637, 0.46660548432410076`, 0.94315056568627], 
             UndirectedEdge[175, 375] -> 
             RGBColor[
              0.38334235809309686`, 0.4981874735279052, 0.9464228951111959], 
             UndirectedEdge[18, 428] -> 
             RGBColor[
              0.34425068013672044`, 0.46846111071813057`, 0.9433076656710013],
              UndirectedEdge[2, 47] -> 
             RGBColor[
              0.25444311603080433`, 0.38476622594667337`, 0.937801531091872], 
             UndirectedEdge[140, 466] -> 
             RGBColor[
              0.3402374319384057, 0.46911829553965567`, 0.9429006061963354], 
             UndirectedEdge[199, 382] -> 
             RGBColor[
              0.3404827314959827, 0.4693307616873146, 0.9429162364672343], 
             UndirectedEdge[305, 499] -> 
             RGBColor[
              0.2714370954193111, 0.4026279757645196, 0.938769313077708], 
             UndirectedEdge[252, 282] -> 
             RGBColor[
              0.33329049261991683`, 0.46158641923159127`, 0.9425134171249244],
              UndirectedEdge[235, 249] -> 
             RGBColor[
              0.26204195746693804`, 0.39275309009042403`, 0.9382342738701814],
              UndirectedEdge[130, 214] -> 
             RGBColor[
              0.2442300948156266, 0.3740316931065762, 0.9372199146424787], 
             UndirectedEdge[100, 475] -> 
             RGBColor[
              0.40759994116554854`, 0.5274643152940482, 0.9471928857179608], 
             UndirectedEdge[10, 438] -> 
             RGBColor[
              0.35815016235919855`, 0.4811744277336937, 0.9441686395425921], 
             UndirectedEdge[39, 179] -> 
             RGBColor[
              0.2703941782674766, 0.3990073473928014, 0.9388023532010125], 
             UndirectedEdge[400, 414] -> 
             RGBColor[
              0.4276219459746641, 0.5413817228872506, 0.9492491627316422], 
             UndirectedEdge[41, 191] -> 
             RGBColor[
              0.2674207805368475, 0.39840657417397884`, 0.9385405898867571], 
             UndirectedEdge[25, 96] -> 
             RGBColor[
              0.25906133434580425`, 0.38962026620769147`, 0.9380645317928695],
              UndirectedEdge[106, 274] -> 
             RGBColor[
              0.33598120664968445`, 0.4605702721101529, 0.942807406431454], 
             UndirectedEdge[204, 363] -> 
             RGBColor[
              0.2528434803922276, 0.3830849074677718, 0.9377104342087039], 
             UndirectedEdge[99, 413] -> 
             RGBColor[
              0.31876379508252406`, 0.4447613380462401, 0.9417431379793169], 
             UndirectedEdge[37, 118] -> 
             RGBColor[
              0.5259180092003879, 0.6230703084644925, 0.9568876544770459], 
             UndirectedEdge[411, 478] -> 
             RGBColor[
              0.3322303063582177, 0.46192550960746026`, 0.942399824503019], 
             UndirectedEdge[300, 451] -> 
             RGBColor[
              0.2992382833830498, 0.4266314184537433, 0.9405435830248834], 
             UndirectedEdge[122, 233] -> 
             RGBColor[
              0.30449077451618795`, 0.4372332369264486, 0.9406566600310259], 
             UndirectedEdge[97, 404] -> 
             RGBColor[
              0.6073055305696983, 0.692077014375679, 0.9622284624813572], 
             UndirectedEdge[362, 498] -> 
             RGBColor[
              0.30076321375197823`, 0.43052748434922883`, 0.940546457800408], 
             UndirectedEdge[121, 454] -> 
             RGBColor[
              0.4147446350716565, 0.529389364923255, 0.9483754098656225], 
             UndirectedEdge[173, 417] -> 
             RGBColor[
              0.42852396040957985`, 0.545243486557945, 0.9486212388552451], 
             UndirectedEdge[36, 352] -> 
             RGBColor[
              0.4495895647240583, 0.5617249015958254, 0.9504510716840866], 
             UndirectedEdge[309, 337] -> 
             RGBColor[
              0.266667710809505, 0.39761505014316345`, 0.9384977036798517], 
             UndirectedEdge[207, 456] -> 
             RGBColor[
              0.35759324200402265`, 0.48415102589011505`, 0.9440065030665763],
              UndirectedEdge[95, 97] -> 
             RGBColor[
              0.45118108935172874`, 0.559730836657568, 0.951174575851574], 
             UndirectedEdge[185, 350] -> 
             RGBColor[
              0.34734238679303764`, 0.4752722503293235, 0.9433533276370076], 
             UndirectedEdge[303, 435] -> 
             RGBColor[
              0.29824459285330696`, 0.4308043552611561, 0.9402959603984355], 
             UndirectedEdge[14, 441] -> 
             RGBColor[
              0.6362216490820589, 0.7104332473100898, 0.9674649254806756], 
             UndirectedEdge[67, 147] -> 
             RGBColor[
              0.327391734264632, 0.45280114584848513`, 0.9422721522196587], 
             UndirectedEdge[115, 419] -> 
             RGBColor[
              0.2662210016868535, 0.396267447689469, 0.9385044151704334], 
             UndirectedEdge[113, 209] -> 
             RGBColor[
              0.3134747460025365, 0.44593780211371237`, 0.9411953115138156], 
             UndirectedEdge[100, 121] -> 
             RGBColor[
              0.3313023572512571, 0.4594988271646654, 0.9424001201741694], 
             UndirectedEdge[39, 254] -> 
             RGBColor[
              0.3155057370900482, 0.44642245595335306`, 0.9413713897393872], 
             UndirectedEdge[2, 339] -> 
             RGBColor[
              0.2580244889857639, 0.38804348700031227`, 0.9380233160361422], 
             UndirectedEdge[76, 436] -> 
             RGBColor[
              0.27261665353967546`, 0.4035425889093095, 0.9388483934989006], 
             UndirectedEdge[121, 161] -> 
             RGBColor[
              0.2908212037461153, 0.4230019026394437, 0.939873209370701], 
             UndirectedEdge[215, 430] -> 
             RGBColor[
              0.3937436630812128, 0.5139035284631313, 0.9465797988412579], 
             UndirectedEdge[100, 254] -> 
             RGBColor[
              0.33457884420373596`, 0.4629426226929921, 0.942586711258985], 
             UndirectedEdge[186, 389] -> 
             RGBColor[
              0.7199018504105001, 0.7768688898171091, 0.875026149790092], 
             UndirectedEdge[197, 426] -> 
             RGBColor[
              0.32937185376357747`, 0.4548653482652719, 0.9423855406007814], 
             UndirectedEdge[316, 378] -> 
             RGBColor[
              0.2937021237391968, 0.42180576340958786`, 0.9401919410148649], 
             UndirectedEdge[185, 330] -> 
             RGBColor[
              0.3576811797722085, 0.48422719316503693`, 0.9440121063834047], 
             UndirectedEdge[56, 166] -> 
             RGBColor[
              0.3146631445310014, 0.44151991251953804`, 0.9414704846497478], 
             UndirectedEdge[38, 73] -> 
             RGBColor[
              0.34425403459106646`, 0.47259727487707115`, 0.9431565405656206],
              UndirectedEdge[97, 430] -> 
             RGBColor[
              0.45453777985861843`, 0.5632589312067795, 0.9513657344101627], 
             UndirectedEdge[222, 372] -> 
             RGBColor[
              0.4907982248314783, 0.5969714678017973, 0.9532001661838594], 
             UndirectedEdge[137, 430] -> 
             RGBColor[
              0.3420534778091947, 0.4700196326330585, 0.9430409147183219], 
             UndirectedEdge[30, 355] -> 
             RGBColor[
              0.316514116533007, 0.4453498380084423, 0.9415068963135241], 
             UndirectedEdge[111, 442] -> 
             RGBColor[
              0.2971219810198691, 0.42962441904651166`, 0.9402320293152766], 
             UndirectedEdge[183, 408] -> 
             RGBColor[
              0.28833061044487873`, 0.4193174860954827, 0.9397704288678603], 
             UndirectedEdge[39, 283] -> 
             RGBColor[
              0.3192328083692185, 0.45033984417772877`, 0.9415836409350281], 
             UndirectedEdge[244, 498] -> 
             RGBColor[
              0.4071518362656757, 0.5199652915377899, 0.9480744130550823], 
             UndirectedEdge[259, 454] -> 
             RGBColor[
              0.4400066013779004, 0.5531503662052724, 0.9499162309844539], 
             UndirectedEdge[17, 418] -> 
             RGBColor[
              0.5887311551847788, 0.6712384496438977, 0.9635462076136528], 
             UndirectedEdge[70, 391] -> 
             RGBColor[
              0.28062246545246344`, 0.41228238205545975`, 0.9392924063125587],
              UndirectedEdge[18, 495] -> 
             RGBColor[
              0.3490391206461238, 0.4734940652981773, 0.9435803602741488], 
             UndirectedEdge[48, 95] -> 
             RGBColor[
              0.29811156480844037`, 0.43066453435153607`, 0.9402883846480776],
              UndirectedEdge[50, 92] -> 
             RGBColor[
              0.3582823989503163, 0.4828322892994108, 0.944120556857339], 
             UndirectedEdge[118, 141] -> 
             RGBColor[
              0.5304295464660245, 0.6269779752875306, 0.9571751256422165], 
             UndirectedEdge[373, 398] -> 
             RGBColor[
              0.23985294611653313`, 0.36943103229657226`, 0.9369706424994765],
              UndirectedEdge[218, 409] -> 
             RGBColor[
              0.24251955268877096`, 0.37223380487661606`, 
               0.9371225017988745]}, GraphLayout -> {"Dimension" -> 2}, 
           ImageSize -> 500, VertexSize -> {4}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.4000615889679724, 0.520934973509106, 0.9467125485818344], 316 -> 
             RGBColor[
              0.3544340112201781, 0.4814146589727051, 0.9438051996746277], 
             308 -> RGBColor[
              0.4013451323658482, 0.522046714287579, 0.9467943348321541], 160 -> 
             RGBColor[
              0.23259888533210393`, 0.36180655447811894`, 0.9365575344692244],
              245 -> RGBColor[
              0.363833838033907, 0.4895563165097243, 0.944404148327258], 155 -> 
             RGBColor[
              0.3403726638732942, 0.46923542664470136`, 0.9429092230556455], 
             425 -> RGBColor[
              0.31790869110114484`, 0.44977826250156644`, 0.9414778385747153],
              213 -> RGBColor[
              0.322981006193891, 0.45417164689293377`, 0.941801042007153], 
             352 -> RGBColor[
              0.5309803603439407, 0.6301128027766741, 0.9562198654928746], 27 -> 
             RGBColor[
              0.26128260961297217`, 0.39195496735047125`, 0.9381910301332524],
              485 -> RGBColor[
              0.24408107778422997`, 0.37387506675835286`, 0.9372114283429915],
              454 -> RGBColor[
              0.5410809317178488, 0.6383129016435678, 0.9570150194710408], 
             367 -> RGBColor[
              0.2568994300737135, 0.3873479677450763, 0.9379414145428248], 19 -> 
             RGBColor[
              0.31473650233925, 0.44703067203485614`, 0.9412757095118638], 
             164 -> 
             RGBColor[
              0.3306015516213065, 0.46077218032241113`, 0.9422866164232042], 
             190 -> RGBColor[
              0.9784512450090639, 0.938973130906601, 0.37078758531148404`], 
             103 -> RGBColor[
              0.39516723391201586`, 0.5166957291570742, 0.9464006846055771], 
             138 -> RGBColor[
              0.3348425196861791, 0.464445493702951, 0.942556847158157], 416 -> 
             RGBColor[
              0.22654290263700283`, 0.3554413326940876, 0.936212655213762], 
             476 -> RGBColor[
              0.2578700741310447, 0.3883681761917191, 0.9379966912859505], 
             291 -> RGBColor[
              0.2842342323242772, 0.416078578036982, 0.9394980910927783], 28 -> 
             RGBColor[
              0.7693593698491171, 0.8197486541646907, 0.9776462099806265], 
             337 -> RGBColor[
              0.27802978540147766`, 0.409557310936464, 0.9391447570191815], 
             195 -> RGBColor[
              0.5917880531841802, 0.6794792271797255, 0.9610068698191766], 
             114 -> RGBColor[
              0.23331075579955812`, 0.3625547754746078, 0.9365980744392279], 
             479 -> RGBColor[
              0.3116511897266897, 0.4443583293221772, 0.9410791161204263], 93 -> 
             RGBColor[
              0.40498369429033654`, 0.525198253747131, 0.9470261807805286], 
             34 -> RGBColor[
              0.41530738715222193`, 0.5341401176202057, 0.9476839973608048], 
             161 -> RGBColor[
              0.29323406906676647`, 0.4255379770759454, 0.9400106184811977], 
             22 -> RGBColor[
              0.43650016848452144`, 0.5524962396300823, 0.9490343826472581], 
             124 -> RGBColor[
              0.4004290815560116, 0.521253277118151, 0.9467359648845833], 84 -> 
             RGBColor[
              0.416374086342034, 0.5350640388445608, 0.9477519664899345], 46 -> 
             RGBColor[
              0.3998347376938894, 0.5207384863373719, 0.9466980938192465], 
             241 -> RGBColor[
              0.9949596982996386, 0.9916276292526274, 0.692772448931186], 185 -> 
             RGBColor[
              0.32556760667796747`, 0.45641203022592036`, 0.9419658579027573],
              426 -> RGBColor[
              0.40236516859017185`, 0.5229302183965768, 0.9468593306383855], 
             390 -> RGBColor[
              0.7101211614132389, 0.7734713155075235, 0.9717418989762701], 
             121 -> RGBColor[
              0.28840833842546415`, 0.42046582820294204`, 0.9397358002602043],
              322 -> 
             RGBColor[
              0.24335106061728462`, 0.3731077724301316, 0.9371698549452976], 
             488 -> RGBColor[
              0.3208866192851232, 0.4523575942195059, 0.9416675895253199], 
             126 -> RGBColor[
              0.3078496401587032, 0.44089986897430067`, 0.9408429536330837], 
             433 -> RGBColor[
              0.6821794640839407, 0.7516430491891106, 0.9689569317164931], 
             236 -> RGBColor[
              0.2761634891521908, 0.40759571524844695`, 0.9390384742087226], 
             78 -> RGBColor[
              0.19277174118480567`, 0.3199457007925216, 0.9342894375290156], 
             376 -> RGBColor[
              0.4668070451130805, 0.578014014497356, 0.951167907043302], 458 -> 
             RGBColor[
              0.27023532405097267`, 0.4013648378596902, 0.9387008739761425], 
             254 -> RGBColor[
              0.2949613123304219, 0.42735341925959536`, 0.9401089824298354], 
             290 -> RGBColor[
              0.26115376363066223`, 0.39181954205375635`, 0.9381836925451705],
              251 -> RGBColor[
              0.31206837416396493`, 0.44471967351344555`, 0.9411056987438677],
              165 -> RGBColor[
              0.4177227225406916, 0.5362321597354117, 0.9478379003959608], 
             460 -> RGBColor[
              0.22600346787441977`, 0.3548743525564735, 0.9361819352020551], 
             100 -> RGBColor[
              0.3741963760770501, 0.4985318261263888, 0.9450644400881345], 
             235 -> RGBColor[
              0.24249915840560815`, 0.3722123691919397, 0.937121340374619], 
             70 -> RGBColor[
              0.2763851217593817, 0.4078286651709235, 0.939051095857826], 234 -> 
             RGBColor[
              0.31790869110114484`, 0.44977826250156644`, 0.9414778385747153],
              435 -> RGBColor[
              0.29451299509052303`, 0.42688220941550686`, 0.9400834514262492],
              257 -> RGBColor[
              0.6385005636960097, 0.717402547587846, 0.9646842497602319], 135 -> 
             RGBColor[
              0.4418865112029795, 0.5571616189673539, 0.9493775956423225], 
             265 -> RGBColor[
              0.431798115729033, 0.5484235578653214, 0.9487347720035405], 111 -> 
             RGBColor[
              0.301303003063684, 0.4340189383066697, 0.940470132335404], 497 -> 
             RGBColor[
              0.197786447225936, 0.32521647479247656`, 0.9345750176194652], 
             481 -> RGBColor[
              0.8536774354727434, 0.8861632308620239, 0.9859057099538752], 
             381 -> 
             RGBColor[
              0.36600599281693974`, 0.4914377278071135, 0.9445425561092718], 
             182 -> RGBColor[
              0.41202834719650605`, 0.5312999780199048, 0.9474750598343677], 
             188 -> RGBColor[
              0.2640412595858546, 0.3948544833804812, 0.9383481311681512], 
             154 -> RGBColor[
              0.9763455405678506, 0.9818791234029012, 0.9249250091342547], 
             336 -> RGBColor[
              0.23805811920148418`, 0.36754455541025666`, 0.9368684297618729],
              463 -> RGBColor[
              0.9898717778799422, 0.9900797341169897, 0.8175143817353847], 
             315 -> RGBColor[
              0.23613115320412625`, 0.36551919197033267`, 0.9367586918990141],
              368 -> RGBColor[
              0.2886388073330839, 0.42070806563742313`, 0.939748925123545], 
             269 -> RGBColor[
              0.8707038114149154, 0.8997396008696488, 0.9875297008908648], 
             208 -> RGBColor[
              0.9219637925311737, 0.9406129183966325, 0.9924189236500589], 86 -> 
             RGBColor[
              0.39818389112836733`, 0.5193086060162776, 0.9465929033358778], 
             119 -> RGBColor[
              0.2320242175897836, 0.3612025422449009, 0.936524807991444], 436 -> 
             RGBColor[
              0.23297023625821545`, 0.3621968678464707, 0.936578682355102], 
             377 -> RGBColor[
              0.39900536511556, 0.5200201254955008, 0.9466452469319407], 140 -> 
             RGBColor[
              0.35332627545105666`, 0.48045519392591074`, 0.9437346157309516],
              85 -> RGBColor[
              0.30662735634542504`, 0.43961517118927546`, 0.9407733463781244],
              351 -> RGBColor[
              0.47074827181754725`, 0.5812136798862819, 0.9514781748466667], 
             443 -> RGBColor[
              0.9411782296631871, 0.9556514005113899, 0.984454093392193], 242 -> 
             RGBColor[
              0.24629796206569626`, 0.3762051526967557, 0.9373376766232346], 
             117 -> RGBColor[
              0.6153213944453961, 0.698584653780523, 0.962859500648729], 47 -> 
             RGBColor[
              0.3068504580456016, 0.4398496652216259, 0.9407860516899], 451 -> 
             RGBColor[
              0.3651763190281612, 0.4907191060718907, 0.9444896900291027], 81 -> 
             RGBColor[
              0.2621492674059923, 0.3928658796402132, 0.9382403850124597], 
             275 -> RGBColor[
              0.2823940562540147, 0.4141444363132345, 0.9393932957878733], 23 -> 
             RGBColor[
              0.28918806341115794`, 0.4212853686003256, 0.9397802044446398], 
             328 -> RGBColor[
              0.32907251531342613`, 0.45944780592412454`, 0.9421891875817398],
              418 -> RGBColor[
              0.8326565516118054, 0.8694017486680038, 0.9839007192856544], 
             110 -> RGBColor[
              0.494496410593867, 0.6004934887863583, 0.9533477153234374], 6 -> 
             RGBColor[
              0.6060273964641905, 0.6910393675295425, 0.9621278430826121], 
             218 -> RGBColor[
              0.24636484907183565`, 0.3762754551810893, 0.9373414857392838], 
             108 -> RGBColor[
              0.6876799566185954, 0.7559400757624746, 0.9695051694073222], 
             297 -> RGBColor[
              0.29451299509052303`, 0.42688220941550686`, 0.9400834514262492],
              487 -> RGBColor[
              0.5207516686160029, 0.6218086900346231, 0.955414625411119], 464 -> 
             RGBColor[
              0.729121491751361, 0.7883145179755234, 0.9736356743361919], 157 -> 
             RGBColor[
              0.3429547584367248, 0.4714719071756987, 0.9430737518379708], 
             441 -> RGBColor[
              0.8890441378653967, 0.9143636793463633, 0.9892790176003144], 
             354 -> RGBColor[
              0.6437837702698256, 0.7216480413634428, 0.965130007785261], 385 -> 
             RGBColor[
              0.2795476191367694, 0.41115265042847277`, 0.9392311954049726], 
             270 -> RGBColor[
              0.39182516281796154`, 0.5138009951527818, 0.9461877307907414], 
             392 -> RGBColor[
              0.28399747107378687`, 0.4158297269511864, 0.9394846078898197], 
             33 -> RGBColor[
              0.2803969845977723, 0.41204538738086743`, 0.9392795655114531], 
             252 -> RGBColor[
              0.29236228241265233`, 0.424621674028005, 0.9399609715209387], 
             394 -> RGBColor[
              0.2858720767514179, 0.4178000563752415, 0.9395913639099303], 
             260 -> RGBColor[
              0.34285457077674, 0.4713851296601981, 0.943067367968869], 159 -> 
             RGBColor[
              0.2564022138562854, 0.3868253619752304, 0.9379130988148077], 
             183 -> RGBColor[
              0.32028268195277443`, 0.4518344940569983, 0.9416291071725434], 
             99 -> RGBColor[
              0.39105467897519935`, 0.5131336407738251, 0.9461386362415927], 
             329 -> RGBColor[
              0.36911716690810775`, 0.4941324704327267, 0.9447407973712578], 
             309 -> 
             RGBColor[
              0.25530563621753233`, 0.3856727893498629, 0.937850650340522], 
             17 -> RGBColor[
              0.3448057587577522, 0.47307515061979144`, 0.9431916959416513], 
             349 -> RGBColor[
              0.42667975096578326`, 0.5439902875638876, 0.9484086343268184], 
             495 -> RGBColor[
              0.2736181406046614, 0.4049203925405745, 0.9388935203744464], 
             347 -> RGBColor[
              0.2945176715234708, 0.4268871246430379, 0.9400837177421874], 
             340 -> RGBColor[
              0.3389322710379519, 0.46798783076697686`, 0.9428174424978669], 
             404 -> RGBColor[
              0.6070172404243933, 0.6918429674483975, 0.9622057672250772], 
             277 -> RGBColor[
              0.34285457077674, 0.4713851296601981, 0.943067367968869], 104 -> 
             RGBColor[
              0.3487481921166316, 0.4764898882427906, 0.9434429043091221], 79 -> 
             RGBColor[
              0.2979010200002716, 0.4304432384088389, 0.9402763944327256], 
             327 -> RGBColor[
              0.5730132833175045, 0.6642370232082143, 0.9595288511610238], 
             191 -> RGBColor[
              0.2703651483960346, 0.40150129147768915`, 0.9387082672805359], 
             50 -> RGBColor[
              0.288026604294227, 0.42006460142766994`, 0.9397140610661554], 
             225 -> RGBColor[
              0.48672762523454555`, 0.5941864388518691, 0.9527361280819532], 
             405 -> RGBColor[
              0.2986155231685411, 0.4311942265408075, 0.9403170843311459], 61 -> 
             RGBColor[
              0.2895300426964028, 0.42164481051185704`, 0.9397996796590214], 
             196 -> RGBColor[
              0.2609614153704024, 0.39161737183663925`, 0.9381727385963025], 
             1 -> RGBColor[
              0.28734139441138196`, 0.419344402395984, 0.9396750393770045], 
             263 -> RGBColor[
              0.41176255164045766`, 0.5310697592685288, 0.9474581235765701], 
             201 -> RGBColor[
              0.3177587826822878, 0.44964841936376865`, 0.9414682865428246], 
             371 -> RGBColor[
              0.5627984141703793, 0.6559441322599672, 0.9587246992434635], 
             293 -> RGBColor[
              0.24283364722484507`, 0.37256393814877375`, 0.9371403890180426],
              362 -> RGBColor[
              0.3403726638732942, 0.46923542664470136`, 0.9429092230556455], 
             184 -> RGBColor[
              0.26721187170256727`, 0.39818699774356525`, 0.9385286928376977],
              106 -> 
             RGBColor[
              0.4157976544452876, 0.5345647625079085, 0.9477152367591926], 
             206 -> RGBColor[
              0.2614327329736084, 0.39211275652087074`, 0.9381995794365531], 
             358 -> RGBColor[
              0.31355684456395694`, 0.44600891176122104`, 0.9412005427615525],
              247 -> RGBColor[
              0.2978407394021351, 0.4303798796781868, 0.9402729615418389], 
             220 -> RGBColor[
              0.3757160617457869, 0.4998481014710261, 0.9451612731151412], 
             407 -> RGBColor[
              0.2203838072139612, 0.34896773289526634`, 0.9358619038409849], 
             107 -> RGBColor[
              0.3135604109961346, 0.44601200082551923`, 0.9412007700114572], 
             375 -> RGBColor[
              0.5259993738274363, 0.6260690135316905, 0.9558277439883407], 
             131 -> RGBColor[
              0.4440759690627916, 0.5590580173201715, 0.9495171059610882], 
             411 -> RGBColor[
              0.3059618228079237, 0.4389156532440981, 0.9407354452277323], 
             462 -> RGBColor[
              0.4022088843796814, 0.5227948528685228, 0.9468493723466898], 
             127 -> RGBColor[
              0.841841169007533, 0.8767253132695593, 0.9847767562920636], 210 -> 
             RGBColor[
              0.2739345514949209, 0.40525296044784637`, 0.9389115395065588], 
             357 -> RGBColor[
              0.5968392758039021, 0.6835800372574017, 0.9614045205670393], 
             181 -> RGBColor[
              0.34214614154167994`, 0.47077152386347776`, 0.9430222274844503],
              194 -> RGBColor[
              0.33724244063134634`, 0.46652418460212086`, 0.9427097679986164],
              440 -> RGBColor[
              0.2795963077092417, 0.411203825205175, 0.9392339681471467], 490 -> 
             RGBColor[
              0.32177279352632876`, 0.4531251538068258, 0.9417240557643565], 
             118 -> RGBColor[
              0.6833813758557328, 0.7525819918001024, 0.9690767270494012], 
             348 -> RGBColor[
              0.4431732877352992, 0.5582761601243802, 0.9494595879051101], 
             276 -> RGBColor[
              0.47829640960828, 0.5873415981845311, 0.9520723919032931], 305 -> 
             RGBColor[
              0.23969372419159488`, 0.369263679958209, 0.936961575046399], 
             343 -> RGBColor[
              0.43658104413592186`, 0.552566290054397, 0.9490395359722499], 
             280 -> RGBColor[
              0.33528584737734973`, 0.46482948186674533`, 0.9425850956066192],
              474 -> 
             RGBColor[
              0.21882849563947865`, 0.3473330018180358, 0.9357733311476953], 
             189 -> RGBColor[
              0.24982963310794126`, 0.3799171628830323, 0.9375388000644513], 
             168 -> RGBColor[
              0.24187432365529554`, 0.37155562825254984`, 0.9370857569599489],
              363 -> RGBColor[
              0.2842342323242772, 0.416078578036982, 0.9394980910927783], 41 -> 
             RGBColor[
              0.2644764126776603, 0.3953118568702686, 0.9383729124929783], 14 -> 
             RGBColor[
              0.38339916029872123`, 0.5065028152738162, 0.9456508333610368], 
             77 -> RGBColor[
              0.23568827926952945`, 0.3650537033852422, 0.936733470883612], 
             51 -> RGBColor[
              0.47845288838444977`, 0.5874686347043143, 0.9520847104857538], 
             438 -> RGBColor[
              0.4449661036059642, 0.5598290071220046, 0.9495738245470641], 
             179 -> RGBColor[
              0.20473819468527868`, 0.33252320213849207`, 0.934970909353086], 
             467 -> RGBColor[
              0.2966433566193046, 0.4291213544549786, 0.9402047723637258], 
             223 -> RGBColor[
              0.41917177103906966`, 0.5374872527134116, 0.9479302324849342], 
             456 -> RGBColor[
              0.3429547584367248, 0.4714719071756987, 0.9430737518379708], 
             323 -> RGBColor[
              0.40984221141298405`, 0.5294064570825974, 0.9473357611953657], 
             500 -> RGBColor[
              0.3519942744875354, 0.47930148163962366`, 0.9436497418073982], 
             478 -> RGBColor[
              0.3584987899085117, 0.48493536597082243`, 0.9440642037783057], 
             292 -> RGBColor[
              0.3392696434502285, 0.46828004579366034`, 0.9428389395696505], 
             491 -> RGBColor[
              0.6361021248598616, 0.7154553868922228, 0.9644954358692794], 
             396 -> RGBColor[
              0.3741963760770501, 0.4985318261263888, 0.9450644400881345], 
             321 -> RGBColor[
              0.28543930607268864`, 0.41734518695265116`, 0.9395667182600035],
              143 -> RGBColor[
              0.38905185977966283`, 0.511398899451271, 0.9460110183734766], 
             112 -> RGBColor[
              0.23926945414690937`, 0.36881774524097, 0.9369374134950054], 
             197 -> RGBColor[
              0.25637853893698304`, 0.386800478133967, 0.9379117505631773], 
             421 -> RGBColor[
              0.22047568661334008`, 0.3490643039695039, 0.9358671362368561], 
             54 -> 
             RGBColor[
              0.2214983333727114, 0.3501391705531527, 0.935925374456932], 71 -> 
             RGBColor[
              0.34719934599752944`, 0.47514835558169377`, 0.9433442132040039],
              177 -> RGBColor[
              0.2640412595858546, 0.3948544833804812, 0.9383481311681512], 
             158 -> RGBColor[
              0.345424804738416, 0.47361133713408676`, 0.9432311410041383], 
             226 -> RGBColor[
              0.28988292992790077`, 0.4220157173665042, 0.9398197760648054], 
             432 -> RGBColor[
              0.3129798130538462, 0.44550911606961013`, 0.9411637748239772], 
             350 -> RGBColor[
              0.36911716690810775`, 0.4941324704327267, 0.9447407973712578], 
             203 -> RGBColor[
              0.34006042540258136`, 0.4689649813749318, 0.9428893274963933], 
             475 -> RGBColor[
              0.44100350625404694`, 0.5563968044617077, 0.9493213313477872], 
             115 -> RGBColor[
              0.3182432196046995, 0.45006801427745396`, 0.9414991544351499], 
             173 -> RGBColor[
              0.39105467897519935`, 0.5131336407738251, 0.9461386362415927], 
             212 -> RGBColor[
              0.3241551197616185, 0.45518860505263553`, 0.9418758554854607], 
             129 -> RGBColor[
              0.3068504580456016, 0.4398496652216259, 0.9407860516899], 279 -> 
             RGBColor[
              0.2842574575865042, 0.4161029892601493, 0.9394994137371034], 26 -> 
             RGBColor[
              0.4901143415244938, 0.5969359277058792, 0.9530027427942485], 40 -> 
             RGBColor[
              0.471808519414278, 0.5820744366489178, 0.9515616414212964], 146 -> 
             RGBColor[
              0.35804381475151087`, 0.48454128935754465`, 0.9440352131636204],
              386 -> RGBColor[
              0.27307351757491577`, 0.4043479592052173, 0.9388625048986], 192 -> 
             RGBColor[
              0.2981060148764662, 0.43065870102114523`, 0.9402880685876621], 
             300 -> RGBColor[
              0.23330024773793845`, 0.3625437308355959, 0.936597476020664], 
             221 -> RGBColor[
              0.9521058220396501, 0.8478225747155727, 0.28032142407349914`], 
             62 -> RGBColor[
              0.2571567874572822, 0.3876184666726076, 0.9379560706650929], 
             286 -> RGBColor[
              0.23784546513965096`, 0.3673210425082237, 0.9368563194276449], 
             472 -> RGBColor[
              0.2599874089063486, 0.390593629287342, 0.938117270369088], 152 -> 
             RGBColor[
              0.28432359578093563`, 0.4161725046959005, 0.9395031802094336], 
             64 -> RGBColor[
              0.26669510879236896`, 0.3976438471602859, 0.9384992639544442], 
             307 -> RGBColor[
              0.2127590553435735, 0.34095363524229827`, 0.9354276855017759], 
             37 -> RGBColor[
              0.3684546425450429, 0.4935586251288826, 0.9446985819046907], 
             148 -> RGBColor[
              0.2905164730427267, 0.42268161134913973`, 0.9398558554079517], 
             261 -> RGBColor[
              0.7824241877958404, 0.829954989240965, 0.9789483889358905], 387 -> 
             RGBColor[
              0.19953264524976808`, 0.3270518396308734, 0.9346744610136539], 
             15 -> RGBColor[
              0.955642469129801, 0.966438806622572, 0.9599699088530541], 136 -> 
             RGBColor[
              0.3510127698847786, 0.4784513516845714, 0.943587201202021], 198 -> 
             RGBColor[
              0.2934081991942264, 0.4257209988803935, 0.9400205349343541], 63 -> 
             RGBColor[
              0.29187902171512436`, 0.4241137363944052, 0.9399334505391346], 
             444 -> RGBColor[
              0.25719125400686005`, 0.38765469320151935`, 0.9379580334841027],
              310 -> RGBColor[
              0.304196194831147, 0.43705986629322624`, 0.9406348953264674], 
             171 -> RGBColor[
              0.2789703608052202, 0.4105459153217224, 0.939198321396968], 395 -> 
             RGBColor[
              0.29201952936048564`, 0.42426141883837915`, 0.9399414522416755],
              311 -> RGBColor[
              0.3031977926073366, 0.4360104822536444, 0.9405780377968251], 
             353 -> RGBColor[
              0.3502399458687244, 0.47778197036512976`, 0.9435379575390995], 
             59 -> RGBColor[
              0.530060180855995, 0.6293657596147464, 0.956147425592855], 397 -> 
             RGBColor[
              0.3937291837789975, 0.515450162410355, 0.946309053322719], 229 -> 
             RGBColor[
              0.25723769376736616`, 0.38770350433426215`, 0.937960678159762], 
             102 -> RGBColor[
              0.2623735277803323, 0.3931015915125735, 0.9382531563090148], 
             453 -> RGBColor[
              0.47732671233487217`, 0.5865543542536142, 0.9519960537818123], 
             299 -> RGBColor[
              0.34138344439710394`, 0.47011091393111915`, 0.9429736290968246],
              128 -> RGBColor[
              0.30390794757221024`, 0.43675690014815194`, 0.9406184800714945],
              12 -> 
             RGBColor[
              0.7131904678759505, 0.7758690810437868, 0.9720478187601735], 
             222 -> RGBColor[
              0.4341790567390778, 0.5504858092986474, 0.948886483459317], 483 -> 
             RGBColor[
              0.26841073285783545`, 0.3994470768299396, 0.9385969662069341], 
             92 -> RGBColor[
              0.4285381936064057, 0.5455999771711516, 0.9485270526485227], 
             271 -> RGBColor[
              0.3329471961402636, 0.46280385970921023`, 0.9424360788177801], 
             361 -> RGBColor[
              0.304212717807297, 0.4370772329887771, 0.9406358362855156], 344 -> 
             RGBColor[
              0.3318853245253724, 0.4618841198876107, 0.9423684172974555], 
             132 -> RGBColor[
              0.37083347648853443`, 0.4956190515270645, 0.9448501591000497], 
             80 -> RGBColor[
              0.2889184473446245, 0.4210019850197531, 0.939764850208512], 324 -> 
             RGBColor[
              0.3356779689785671, 0.46516911788911514`, 0.9426100812483093], 
             244 -> RGBColor[
              0.5531499089006892, 0.6481110410218236, 0.9579651335649941], 
             150 -> RGBColor[
              0.31352164515097325`, 0.44597842379886854`, 0.9411982998860828],
              125 -> RGBColor[
              0.2172751095202088, 0.3457002945163146, 0.9356848681062317], 
             258 -> RGBColor[
              0.2497128460926812, 0.37979441232526956`, 0.9375321492167032], 
             133 -> RGBColor[
              0.3044178854310391, 0.4372928771697087, 0.9406475202781694], 
             469 -> RGBColor[
              0.4029425589789929, 0.5234303249308889, 0.9468961214433949], 
             255 -> RGBColor[
              0.3572972301241252, 0.4838946352777376, 0.9439876414513422], 
             408 -> RGBColor[
              0.25637853893698304`, 0.386800478133967, 0.9379117505631773], 
             326 -> RGBColor[
              0.5137829014627389, 0.6161511309202208, 0.9548660185333789], 
             176 -> RGBColor[
              0.7898528347050083, 0.8357583046662146, 0.979688807035144], 230 -> 
             RGBColor[
              0.2640412595858546, 0.3948544833804812, 0.9383481311681512], 
             274 -> RGBColor[
              0.25616475885408135`, 0.3865757817123972, 0.9378995761037153], 
             87 -> RGBColor[
              0.3692294396346824, 0.4942297154254943, 0.9447479512901164], 
             439 -> RGBColor[
              0.36113834610097967`, 0.4872216168767865, 0.9442323939648218], 
             130 -> 
             RGBColor[
              0.2975736159784852, 0.4300991160233274, 0.9402577492580357], 35 -> 
             RGBColor[
              0.6472302902622149, 0.7243404889760194, 0.9654735246885419], 
             379 -> RGBColor[
              0.31049557391364746`, 0.44335739298785964`, 0.9410054813026901],
              31 -> RGBColor[
              0.38979475286644955`, 0.5120423561041535, 0.9460583548640521], 
             18 -> RGBColor[
              0.4244601006875862, 0.54206773805578, 0.9482672001738514], 24 -> 
             RGBColor[
              0.3194257799564875, 0.45109228861696127`, 0.9415745061350688], 
             151 -> RGBColor[
              0.391931119245013, 0.5138927692843689, 0.9461944822405796], 137 -> 
             RGBColor[
              0.3826252166161558, 0.5058324641555186, 0.9456015183539553], 
             330 -> RGBColor[
              0.38979475286644955`, 0.5120423561041535, 0.9460583548640521], 
             296 -> RGBColor[
              0.32113777698659, 0.4525751343969634, 0.9416835930719674], 266 -> 
             RGBColor[
              0.22600346787441977`, 0.3548743525564735, 0.9361819352020551], 
             302 -> RGBColor[
              0.3170695421176403, 0.44905143382890905`, 0.9414243687435168], 
             442 -> RGBColor[
              0.2929409589760542, 0.4252298997863536, 0.9399939262951492], 
             283 -> RGBColor[
              0.30241545488876254`, 0.43518819570834677`, 0.9405334848211173],
              388 -> RGBColor[
              0.3063228055086442, 0.4392950689501805, 0.9407560026585123], 
             284 -> RGBColor[
              0.2809903651668394, 0.412669067981458, 0.9393133576570336], 417 -> 
             RGBColor[
              0.4659932418439603, 0.5773533323420648, 0.9511038414688974], 
             318 -> RGBColor[
              0.8937141971780036, 0.918087457876853, 0.989724452026562], 413 -> 
             RGBColor[
              0.24647291118984882`, 0.37638903531865514`, 0.937347639717041], 
             238 -> RGBColor[
              0.18993562096280595`, 0.3169647586187919, 0.9341279246780365], 
             72 -> RGBColor[
              0.19926625391872904`, 0.32677184545176546`, 0.9346592904214419],
              437 -> RGBColor[
              0.2676863431404608, 0.39868569730801806`, 0.9385557132841682], 
             288 -> RGBColor[
              0.431436111676341, 0.5481100081497322, 0.9487117054254105], 382 -> 
             RGBColor[
              0.33801070455524057`, 0.46718961619893046`, 0.9427587210964978],
              461 -> 
             RGBColor[
              0.2410906046408544, 0.37073188987771666`, 0.9370411253214849], 
             389 -> RGBColor[
              0.44888888350418016`, 0.5632267219051887, 0.9498237806134003], 
             172 -> RGBColor[
              0.25422770536722106`, 0.3845398156814224, 0.9377892637732526], 
             447 -> RGBColor[
              0.9300151970891589, 0.7602406080512586, 0.26254678870472214`], 
             243 -> RGBColor[
              0.2593586947252473, 0.38993281082022313`, 0.9380814660265736], 
             410 -> RGBColor[
              0.24636484907183565`, 0.3762754551810893, 0.9373414857392838], 
             88 -> RGBColor[
              0.553977201897875, 0.648782674746064, 0.9580302611002067], 273 -> 
             RGBColor[
              0.4754721631120105, 0.5850487476480047, 0.951850056873551], 477 -> 
             RGBColor[
              0.3668740970540812, 0.49218963606513777`, 0.944597870943628], 
             202 -> RGBColor[
              0.2604654349402351, 0.3910960649575579, 0.9381444932445417], 
             393 -> RGBColor[
              0.23672631555916746`, 0.3661447453409538, 0.9367925855146698], 
             98 -> RGBColor[
              0.48022841070602895`, 0.5889100837113413, 0.9522244861068611], 
             30 -> RGBColor[
              0.27391337588420983`, 0.4052307035383778, 0.9389103335868553], 
             116 -> RGBColor[
              0.3779384082588587, 0.5017729863222653, 0.9453028790698103], 
             373 -> RGBColor[
              0.2670344725515628, 0.39800053998810375`, 0.9385185902184866], 
             434 -> RGBColor[
              0.7833773927233977, 0.8306996401749984, 0.979043395494863], 401 -> 
             RGBColor[
              0.24982963310794126`, 0.3799171628830323, 0.9375388000644513], 
             240 -> RGBColor[0.817319, 0.134127, 0.164218], 480 -> 
             RGBColor[
              0.24633842314769983`, 0.37624767985932217`, 0.9373399808219979],
              403 -> RGBColor[
              0.39373421959715904`, 0.515454524182939, 0.9463093742005992], 
             317 -> RGBColor[
              0.31007732366079244`, 0.4429951256407056, 0.9409788307664224], 
             429 -> RGBColor[
              0.2842342323242772, 0.416078578036982, 0.9394980910927783], 391 -> 
             RGBColor[
              0.2848598091455452, 0.4167360989399961, 0.9395337167672915], 73 -> 
             RGBColor[
              0.3455712107016766, 0.4737381466208854, 0.9432404698626556], 
             303 -> RGBColor[
              0.30197619061609093`, 0.43472650110680544`, 0.9405084693706218],
              449 -> RGBColor[
              0.7944004076140502, 0.8393109031855922, 0.9801420666032323], 29 -> 
             RGBColor[
              0.35237383592407895`, 0.4796302386786452, 0.9436739271265018], 
             360 -> RGBColor[
              0.2200523691035498, 0.348619370426834, 0.9358430289309158], 320 -> 
             RGBColor[
              0.284176273381268, 0.4160176595130701, 0.9394947904167165], 482 -> 
             RGBColor[
              0.2937913688591441, 0.4261237344925819, 0.9400423558799225], 75 -> 
             RGBColor[
              0.5793721418847915, 0.6693994310564518, 0.9600294438007071], 
             200 -> RGBColor[
              0.3643072251141414, 0.4899663406054969, 0.9444343121334108], 
             301 -> RGBColor[
              0.2725396687422257, 0.4037868502340891, 0.9388321029973369], 
             156 -> RGBColor[
              0.3743304578450115, 0.4986479610146514, 0.9450729836598252], 25 -> 
             RGBColor[
              0.2818144183600219, 0.413535200135483, 0.9393602862673079], 38 -> 
             RGBColor[
              0.3429368584804563, 0.47145640313325693`, 0.9430726112685857], 
             365 -> RGBColor[
              0.21882849563947865`, 0.3473330018180358, 0.9357733311476953], 
             380 -> RGBColor[
              0.2550569123382658, 0.38541136478274896`, 0.9378364858835517], 
             370 -> RGBColor[
              0.35713225513309665`, 0.4837517422323928, 0.9439771293907955], 
             3 -> RGBColor[
              0.3193688250189132, 0.4510429571126728, 0.9415708770168099], 57 -> 
             RGBColor[
              0.3106402383398704, 0.4434826940428085, 0.9410146991920073], 
             227 -> RGBColor[
              0.27474097159163696`, 0.4061005590994822, 0.9389574639380751], 
             494 -> RGBColor[
              0.31264554987541854`, 0.44521959410501194`, 0.9411424758698251],
              39 -> RGBColor[
              0.3360501618496745, 0.4654914926471107, 0.9426337970489389], 
             424 -> RGBColor[
              0.2747294584970578, 0.40608845810710714`, 0.9389568082843709], 
             109 -> RGBColor[
              0.4901143415244938, 0.5969359277058792, 0.9530027427942485], 
             465 -> RGBColor[
              0.3759945578309087, 0.5000893207823383, 0.9451790186394207], 
             256 -> RGBColor[
              0.294485059473295, 0.4268528473105798, 0.9400818605341751], 457 -> 
             RGBColor[
              0.3495239925312792, 0.47716184756909574`, 0.9434923376255302], 
             339 -> RGBColor[
              0.31401320395552074`, 0.4464041873289037, 0.9412296215784403], 
             420 -> RGBColor[
              0.33518597111068194`, 0.46474297406448484`, 0.9425787315792242],
              287 -> RGBColor[
              0.23568827926952945`, 0.3650537033852422, 0.936733470883612], 
             239 -> RGBColor[
              0.32947872720587, 0.45979964624855607`, 0.9422150710443272], 
             427 -> RGBColor[
              0.5332401116662624, 0.631947370700772, 0.9563977613947097], 285 -> 
             RGBColor[
              0.27679788544642303`, 0.4082625059767332, 0.9390746021391738], 
             345 -> RGBColor[
              0.37591396573386454`, 0.5000195159585552, 0.9451738833822618], 
             366 -> RGBColor[
              0.5983375446732625, 0.6847963994217918, 0.961522469780775], 216 -> 
             RGBColor[
              0.3404353889756858, 0.4692897559757377, 0.9429132198437044], 21 -> 
             RGBColor[
              0.3217281490033978, 0.4530864849649619, 0.9417212110548329], 
             355 -> RGBColor[
              0.3591148571818041, 0.48546897247850684`, 0.944103459040193], 
             175 -> RGBColor[
              0.24068534235875738`, 0.3703059335241199, 0.9370180462340513], 
             7 -> RGBColor[
              0.2578700741310447, 0.3883681761917191, 0.9379966912859505], 13 -> 
             RGBColor[
              0.5282026472248309, 0.627857730132031, 0.95600119374104], 294 -> 
             RGBColor[
              0.37428634193839216`, 0.49860975003366764`, 0.9450701726332655],
              412 -> RGBColor[
              0.4121911883322874, 0.5314410228270852, 0.947485435927545], 193 -> 
             RGBColor[
              0.31057843075404973`, 0.44342915941851024`, 0.9410107608672932],
              60 -> RGBColor[
              0.20251399589249727`, 0.3301854281849303, 0.9348442445222443], 
             65 -> RGBColor[
              0.26758724701855985`, 0.39858154100084314`, 0.9385500699066255],
              448 -> RGBColor[
              0.5309803603439407, 0.6301128027766741, 0.9562198654928746], 69 -> 
             RGBColor[
              0.3852067069606633, 0.5080684213424537, 0.945766008635985], 217 -> 
             RGBColor[
              0.21081320880196697`, 0.3389084271532733, 0.9353168724198534], 
             214 -> RGBColor[
              0.190886573652768, 0.317964270189825, 0.9341820800269215], 170 -> 
             RGBColor[
              0.24283364722484507`, 0.37256393814877375`, 0.9371403890180426],
              359 -> RGBColor[
              0.22638096082477394`, 0.35527112158173113`, 0.9362034328671269],
              74 -> RGBColor[
              0.5137829014627389, 0.6161511309202208, 0.9548660185333789], 
             246 -> RGBColor[
              0.3301378532698699, 0.46037054811655354`, 0.942257069974283], 
             264 -> RGBColor[
              0.34082807495452555`, 0.46962988083363755`, 0.9429382414470374],
              278 -> RGBColor[
              0.305095274485351, 0.43800485601473726`, 0.9406860965827052], 
             45 -> RGBColor[
              0.29716999494709834`, 0.4296748847282884, 0.9402347636374021], 
             492 -> RGBColor[
              0.31902341345000534`, 0.450743778972575, 0.9415488676970745], 
             306 -> RGBColor[
              0.22651045452402593`, 0.3554072276700197, 0.9362108073417306], 
             237 -> RGBColor[
              0.28201933659117717`, 0.4137505821889934, 0.9393719560574229], 
             228 -> RGBColor[
              0.7110674593149863, 0.7742105706204989, 0.9718362171074596], 
             180 -> RGBColor[
              0.3403726638732942, 0.46923542664470136`, 0.9429092230556455], 
             383 -> RGBColor[
              0.319814994963959, 0.45142940709391793`, 0.9415993065711755], 
             53 -> RGBColor[
              0.3887230257826245, 0.5111140799707138, 0.9459900653619617], 
             304 -> RGBColor[
              0.3516635982946137, 0.47901506654158355`, 0.9436286714127907], 
             48 -> RGBColor[
              0.3014547716284265, 0.43417845669089683`, 0.9404787753306446], 
             5 -> RGBColor[
              0.29816555625768904`, 0.4307212827879521, 0.9402914593812393], 
             101 -> RGBColor[
              0.2799053703836748, 0.4115286696717095, 0.9392515688092383], 
             333 -> RGBColor[
              0.8206701858279558, 0.8598441459531938, 0.9827574490168357], 
             267 -> RGBColor[
              0.2527814280371599, 0.38301968650824914`, 0.937706900418881], 
             120 -> RGBColor[
              0.34596868370604683`, 0.4740824177596968, 0.9432657964910225], 
             147 -> RGBColor[
              0.2526024801987934, 0.3828316009841777, 0.9376967096042157], 89 -> 
             RGBColor[
              0.291996334556541, 0.42423703962879783`, 0.9399401313319045], 
             43 -> RGBColor[
              0.27270811185718274`, 0.4039638946278193, 0.9388416955835445], 
             199 -> 
             RGBColor[
              0.3429547584367248, 0.4714719071756987, 0.9430737518379708], 
             268 -> RGBColor[
              0.31902341345000534`, 0.450743778972575, 0.9415488676970745], 
             169 -> RGBColor[
              0.3085519841343849, 0.4416380770239221, 0.940882951083474], 20 -> 
             RGBColor[
              0.5173305771282382, 0.6190312938464405, 0.9551453045573312], 4 -> 
             RGBColor[
              0.28386252546805024`, 0.41568789056351163`, 0.9394769229372072],
              167 -> RGBColor[
              0.6305168272859865, 0.7109209907069626, 0.9640557407846448], 
             431 -> RGBColor[
              0.44808155427135954`, 0.5625274539012666, 0.9497723383085782], 
             142 -> RGBColor[
              0.86546623712304, 0.8955633012994741, 0.987030136379268], 16 -> 
             RGBColor[
              0.2666102183235196, 0.39755462189515867`, 0.9384944295678274], 
             414 -> RGBColor[
              0.553977201897875, 0.648782674746064, 0.9580302611002067], 281 -> 
             RGBColor[
              0.2931631114368679, 0.42546339610794837`, 0.9400065775491474], 
             289 -> RGBColor[
              0.42825646614431245`, 0.5453559590035204, 0.9485091012237599], 
             398 -> RGBColor[
              0.21267141968150347`, 0.34086152460504077`, 0.9354226947804664],
              178 -> RGBColor[
              0.43873288028925916`, 0.5544301023759879, 0.9491766490691466], 
             58 -> RGBColor[
              0.3389322710379519, 0.46798783076697686`, 0.9428174424978669], 
             186 -> RGBColor[
              0.9909148173168201, 0.9905110577290295, 0.8002285189667835], 
             122 -> RGBColor[
              0.3102196746805117, 0.4431184229392161, 0.9409879012475229], 
             249 -> RGBColor[
              0.28158475652826787`, 0.4132938109889084, 0.9393472073657437], 
             113 -> RGBColor[
              0.31410757120538035`, 0.4464859234976962, 0.9412356345761556], 
             52 -> RGBColor[
              0.5541205279346776, 0.6488990332795047, 0.9580415442508443], 
             409 -> RGBColor[
              0.23867425630570627`, 0.3681921545721428, 0.9369035178584652], 
             187 -> RGBColor[
              0.4155630504731227, 0.5343615603387578, 0.9477002880015384], 
             259 -> RGBColor[
              0.3389322710379519, 0.46798783076697686`, 0.9428174424978669], 
             42 -> RGBColor[
              0.2882283313405391, 0.4202766293435774, 0.9397255491230144], 
             134 -> 
             RGBColor[
              0.2233920588936733, 0.35212959614481654`, 0.936033219323835], 
             470 -> RGBColor[
              0.3513943644365749, 0.4787818697058376, 0.9436115160694306], 
             313 -> RGBColor[
              0.6207065268524481, 0.702956546866018, 0.9632834379982022], 248 -> 
             RGBColor[
              0.20481525269579837`, 0.33260419499330834`, 0.934975297692788], 
             174 -> RGBColor[
              0.39373421959715904`, 0.515454524182939, 0.9463093742005992], 
             215 -> RGBColor[
              0.48600558716019193`, 0.5936002558156642, 0.9526792865998274], 
             399 -> RGBColor[
              0.31352164515097325`, 0.44597842379886854`, 0.9411982998860828],
              422 -> RGBColor[
              0.32743455043921577`, 0.45802908307659185`, 0.9420848179083505],
              83 -> RGBColor[
              0.301356219775506, 0.43407487244492904`, 0.9404731629484152], 
             95 -> RGBColor[
              0.2947683579884542, 0.42715061201217536`, 0.9400979939655107], 
             166 -> RGBColor[
              0.24982963310794126`, 0.3799171628830323, 0.9375388000644513], 
             384 -> RGBColor[
              0.43734759483907426`, 0.553230237745509, 0.9490883799052205], 
             233 -> RGBColor[
              0.2987618743518642, 0.4313480509136811, 0.9403254188145289], 
             295 -> RGBColor[
              0.24550305465460703`, 0.37536965460766003`, 0.9372924078221332],
              499 -> RGBColor[
              0.30318046664702736`, 0.4359922715708301, 0.940577051109017], 
             141 -> RGBColor[
              0.37747771707631605`, 0.5013739587749589, 0.9452735242350319], 
             319 -> RGBColor[
              0.2549340817951686, 0.38528226209404753`, 0.9378294908658339], 
             205 -> RGBColor[
              0.23303276419501, 0.36226258867254196`, 0.9365822432286007], 
             468 -> RGBColor[
              0.2970752380780995, 0.42957528925103816`, 0.9402293673738928], 
             486 -> RGBColor[
              0.5689499755796736, 0.6609382469367158, 0.9592089726915151], 
             224 -> RGBColor[
              0.881462385278418, 0.908318195634698, 0.9885558632702579], 231 -> 
             RGBColor[
              0.2895300426964028, 0.42164481051185704`, 0.9397996796590214], 
             332 -> RGBColor[
              0.5088254082580482, 0.6121264146041292, 0.9544757465084097], 68 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 484 -> 
             RGBColor[
              0.3387310757978665, 0.46781356556238163`, 0.9428046225150786], 
             10 -> RGBColor[
              0.2713342211124329, 0.40251984834538274`, 0.9387634545381202], 
             250 -> RGBColor[
              0.2443647772527096, 0.3741732528873102, 0.9372275846080257], 
             282 -> RGBColor[
              0.3742187028271814, 0.4985511644351775, 0.9450658627289101], 
             374 -> RGBColor[
              0.6363393692103464, 0.7156479925436825, 0.9645141126136043], 
             232 -> RGBColor[
              0.31238003535526393`, 0.4449896187728018, 0.9411255575193861], 
             489 -> RGBColor[
              0.21903120390984115`, 0.3475460610626334, 0.9357848750838125], 
             253 -> RGBColor[
              0.28558522535741165`, 0.417498557372712, 0.9395750281474002], 
             459 -> RGBColor[
              0.25479946053731284`, 0.3851407666165605, 0.9378218243843532], 
             415 -> RGBColor[
              0.2931288805676132, 0.42542741729399924`, 0.9400046281517834], 
             55 -> RGBColor[
              0.32142541763141447`, 0.45282427426627114`, 0.9417019212795049],
              446 -> RGBColor[
              0.5639370022615451, 0.6568684893651845, 0.9588143330687856], 
             325 -> RGBColor[
              0.2668753156914252, 0.39783325603697134`, 0.9385095264707531], 
             91 -> RGBColor[
              0.656025350727376, 0.7312112570563387, 0.9663501341211961], 450 -> 
             RGBColor[
              0.2724060118310348, 0.40364636834608986`, 0.9388244914339723], 
             423 -> RGBColor[
              0.602507013263453, 0.6881813618557279, 0.9618507056214615], 105 -> 
             RGBColor[
              0.37032050149252915`, 0.4951747383683977, 0.9448174727869102], 
             36 -> RGBColor[
              0.3681987691041759, 0.4933370004149767, 0.9446822778752986], 
             123 -> RGBColor[
              0.3236577569152101, 0.4547578143532601, 0.9418441639646883], 94 -> 
             RGBColor[
              0.9949596982996386, 0.9916276292526274, 0.692772448931186], 473 -> 
             RGBColor[
              0.29614444643558874`, 0.4285969682191606, 0.9401763601668347], 
             312 -> RGBColor[
              0.30509924920052034`, 0.43800903369239164`, 0.940686322936854], 
             96 -> RGBColor[
              0.2363082503315866, 0.36570533227989993`, 0.9367687773184312], 
             496 -> RGBColor[
              0.2473566611897467, 0.37731791260153413`, 0.9373979679721443], 
             2 -> 
             RGBColor[
              0.20203577401600706`, 0.32968278667172085`, 0.934817010493844], 
             262 -> RGBColor[
              0.7714491483865085, 0.821381205041006, 0.9778544995751428], 272 -> 
             RGBColor[
              0.27616017668670506`, 0.407592233637199, 0.9390382855687135], 
             97 -> RGBColor[
              0.6075938207150032, 0.6923110613029606, 0.9622511577376371], 
             372 -> RGBColor[
              0.5474173929238788, 0.6434571263049472, 0.9575138489084016], 
             356 -> RGBColor[
              0.3547377968210003, 0.48167778279142903`, 0.9438245566244851], 
             402 -> RGBColor[
              0.3234279778166483, 0.4545587912471192, 0.9418295226437137], 
             455 -> RGBColor[
              0.28397189507023546`, 0.4158028449498416, 0.9394831513742538], 
             428 -> RGBColor[
              0.2640412595858546, 0.3948544833804812, 0.9383481311681512], 
             346 -> RGBColor[
              0.5605046575086496, 0.654081957269415, 0.9585441263167446], 341 -> 
             RGBColor[
              0.3069751379366985, 0.43998071169233033`, 0.9407931520252506], 
             209 -> RGBColor[
              0.31284192079969264`, 0.4453896807297285, 0.9411549884514758], 
             498 -> RGBColor[
              0.26115376363066223`, 0.39181954205375635`, 0.9381836925451705],
              378 -> RGBColor[
              0.23297023625821545`, 0.3621968678464707, 0.936578682355102], 
             419 -> RGBColor[
              0.21419878376900753`, 0.34246688110148393`, 0.935509675905717], 
             66 -> RGBColor[
              0.9363477620849906, 0.9520488457007356, 0.992630815014362], 139 -> 
             RGBColor[
              0.44294914720501394`, 0.5580820208626778, 0.94944530586872], 56 -> 
             RGBColor[
              0.3794966559540616, 0.5031226621560437, 0.9454021692350443], 
             335 -> RGBColor[
              0.24177279332410095`, 0.3714489134370695, 0.937079974957788], 
             314 -> RGBColor[
              0.2406667356563421, 0.3702863767001484, 0.9370169866098749], 
             144 -> RGBColor[
              0.2853505394384257, 0.4172518875919111, 0.9395616631315007], 
             298 -> RGBColor[
              0.25223113949169546`, 0.382441298356657, 0.9376755623002958], 
             204 -> RGBColor[
              0.22145272846017797`, 0.3500912368985616, 0.9359227773246297], 
             452 -> RGBColor[
              0.2577924257928509, 0.38828656286508845`, 0.9379922693279609], 
             466 -> 
             RGBColor[
              0.3271485884257548, 0.4577813971534006, 0.9420665966617191], 
             207 -> RGBColor[
              0.37223172557132045`, 0.4968301446045314, 0.9449392542951817], 
             334 -> RGBColor[
              0.23364619394682457`, 0.36290734223539173`, 0.9366171771454785],
              149 -> RGBColor[
              0.2660623798388358, 0.39697880891278986`, 0.938463230976579], 
             219 -> RGBColor[
              0.9508283575833907, 0.9628484501136434, 0.9681189439797453], 
             400 -> RGBColor[
              0.3012666900514531, 0.43398077102843713`, 0.9404680643630777], 
             9 -> RGBColor[
              0.291745581075652, 0.4239734818216946, 0.9399258512921244], 11 -> 
             RGBColor[
              0.24195654313467688`, 0.3716420461383957, 0.9370904392376668], 
             44 -> RGBColor[
              0.3814458569014465, 0.5048109620469803, 0.9455263705958009], 
             153 -> RGBColor[
              0.41009588933998004`, 0.529626180152738, 0.9473519253285553], 
             471 -> RGBColor[
              0.2772099434180525, 0.40869560503090013`, 0.939098068231073], 
             406 -> RGBColor[
              0.3234279778166483, 0.4545587912471192, 0.9418295226437137], 32 -> 
             RGBColor[
              0.5517075347468677, 0.6469400567055362, 0.9578515845880147], 
             162 -> RGBColor[
              0.31110456385472046`, 0.4438848694660927, 0.9410442856032266], 
             493 -> RGBColor[
              0.4168096408175362, 0.5354412942396363, 0.9477797196359679], 90 -> 
             RGBColor[
              0.22428623966818392`, 0.3530694368331628, 0.9360841415961214], 
             331 -> RGBColor[
              0.25811322327585096`, 0.38862374135945665`, 0.9380105382700403],
              8 -> RGBColor[
              0.21744660342311906`, 0.3458805454816148, 0.9356946344303001], 
             364 -> RGBColor[
              0.9168397772038883, 0.936527167662346, 0.9919301904938799], 342 -> 
             RGBColor[
              0.3123717162881032, 0.44498241321495563`, 0.941125027435783], 
             163 -> RGBColor[
              0.23791540801165786`, 0.36739455690133715`, 0.9368603025707346],
              49 -> RGBColor[
              0.995012282944504, 0.9917401024908713, 0.6984959630099713], 338 -> 
             RGBColor[
              0.2879774757739807, 0.42001296423796297`, 0.9397112632696064], 
             76 -> RGBColor[
              0.3122630708211355, 0.44488830997214823`, 0.9411181046426992], 
             369 -> 
             RGBColor[
              0.46458725314726074`, 0.5762118873790152, 0.9509931568883868], 
             445 -> RGBColor[
              0.28397189507023546`, 0.4158028449498416, 0.9394831513742538], 
             82 -> RGBColor[
              0.31902341345000534`, 0.450743778972575, 0.9415488676970745], 
             67 -> RGBColor[
              0.40218098833047056`, 0.5227706907127926, 0.9468475948351015], 
             430 -> RGBColor[
              0.30148173900223363`, 0.4342068011105984, 0.9404803110826883], 
             211 -> RGBColor[
              0.9450685746849082, 0.9585528134587341, 
               0.9778687540349044]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9V3c41W/cPkZ2skfWMY5xzsFxzjFCvnekUipFSBqEZKVlFlIpoUVlJUVG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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 54}], {
             RGBColor[
             0.2544198638920467, 0.38474178647456836`, 0.9378002069169682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 70}], {
             RGBColor[
             0.2818632580853818, 0.4135865337834537, 0.9393630676174152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 84}], {
             RGBColor[
             0.351857740376708, 0.47720422062027235`, 0.9437135029334696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 131}], {
             RGBColor[
             0.3657086817370868, 0.4892012098580777, 0.9445960726690463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 135}], {
             RGBColor[
             0.36461395280718073`, 0.48825301068166893`, 0.9445263175096634]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 147}], {
             RGBColor[
             0.2699719373050877, 0.40108800169008085`, 0.9386858744906101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 170}], {
             RGBColor[
             0.2650875208181135, 0.3959541702723789, 0.9384077141975236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 171}], {
             RGBColor[
             0.2831558776083011, 0.4149451588588532, 0.9394366803869862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 265}], {
             RGBColor[
             0.3595697550702075, 0.4838839801306527, 0.9442049056902725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 266}], {
             RGBColor[
             0.25667243114290084`, 0.38710937747622876`, 0.9379284872895297]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 374}], {
             RGBColor[
             0.4618403818108642, 0.5674961974698333, 0.9520945759953043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 385}], {
             RGBColor[
             0.2834445067740757, 0.41524852641222837`, 0.9394531173909886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 391}], {
             RGBColor[
             0.2861006017784636, 0.41804025066799, 0.9396043780721479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 433}], {
             RGBColor[
             0.48476042924766133`, 0.5854937257925473, 0.9543159855467488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 47}], {
             RGBColor[
             0.25444311603080433`, 0.38476622594667337`, 0.937801531091872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 54}], {
             RGBColor[
             0.21176705369435922`, 0.3399109786124368, 0.935371192475388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 55}], {
             RGBColor[
             0.2617305958237108, 0.391253530468996, 0.9382594658866745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 230}], {
             RGBColor[
             0.23303851680093085`, 0.362268635026101, 0.9365825708309976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 242}], {
             RGBColor[
             0.22416686804085167`, 0.35294396968423825`, 0.9360773435585393]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 250}], {
             RGBColor[
             0.22320027563435835`, 0.3519280197795155, 0.9360222975509349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 339}], {
             RGBColor[
             0.2580244889857639, 0.38804348700031227`, 0.9380233160361422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 365}], {
             RGBColor[
             0.21043213482774287`, 0.3385078942448783, 0.9352951708207697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 8}], {
             RGBColor[
             0.26840771422101617`, 0.3984617512971438, 0.938632755723555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 31}], {
             RGBColor[
             0.3545817889426814, 0.4815426566084131, 0.943814615940431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[
             0.31523669443681684`, 0.44746391328938273`, 0.9413075813100182]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 203}], {
             RGBColor[
             0.3297146252107473, 0.46000396924380227`, 0.9422301022566015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 221}], {
             RGBColor[
             0.6357373235292816, 0.6494327659141227, 0.6109461505451546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 223}], {
             RGBColor[
             0.3692702980289915, 0.4942651049130422, 0.9447505547508721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 258}], {
             RGBColor[
             0.28454083555579723`, 0.41541868471897114`, 0.9395515131167566]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 381}], {
             RGBColor[
             0.3426874089179265, 0.4712403424598931, 0.9430567165630408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 439}], {
             RGBColor[
             0.34025358555994645`, 0.46913228699472964`, 0.9429016354908158]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 480}], {
             RGBColor[
             0.2828536240833065, 0.4136453184859975, 0.9394554289194039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 29}], {
             RGBColor[
             0.31811818069606457`, 0.4476590646210784, 0.9415754250318544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 185}], {
             RGBColor[
             0.30471506607300886`, 0.436049960394716, 0.9407213904199823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 196}], {
             RGBColor[
             0.2724119704192263, 0.40365263120007544`, 0.9388248307667548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 318}], {
             RGBColor[
             0.5887883613230269, 0.6668876742201824, 0.9646006874818847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 321}], {
             RGBColor[
             0.28465091577036944`, 0.41651653875808137`, 0.9395218205986053]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 335}], {
             RGBColor[
             0.2628176593960756, 0.39356840200029053`, 0.9382784489474976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 383}], {
             RGBColor[
             0.30183876021600464`, 0.43355864882871475`, 0.9405381147541914]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 479}], {
             RGBColor[
             0.29775685759737, 0.43002310994284443`, 0.9402780195288167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 482}], {
             RGBColor[
             0.28882694716359714`, 0.42090581252804676`, 0.9397596394085648]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 496}], {
             RGBColor[
             0.26560959332889844`, 0.3965029015825229, 0.9384374454546758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.27006104969618294`, 0.4011816644631739, 0.9386909493094531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 23}], {
             RGBColor[
             0.29367680983442346`, 0.42600332569413885`, 0.9400358319129396]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 41}], {
             RGBColor[
             0.2813209844676747, 0.41301656982911034`, 0.9393321859371088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 102}], {
             RGBColor[
             0.28026954201901066`, 0.4119114371502628, 0.939272307845127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 186}], {
             RGBColor[
             0.6445401867872546, 0.7106161702584908, 0.8702599891740114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 193}], {
             RGBColor[
             0.3043719935058694, 0.43707522110323116`, 0.9406511101242663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 202}], {
             RGBColor[
             0.27931549559896207`, 0.410908673872755, 0.9392179763128905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 211}], {
             RGBColor[
             0.6216170654712987, 0.694637048123343, 0.9590801067080719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 212}], {
             RGBColor[
             0.31116033800965376`, 0.4429549439202938, 0.94108365743335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 300}], {
             RGBColor[
             0.26573290199781374`, 0.396632506811774, 0.9384444677009516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 414}], {
             RGBColor[
             0.42607137907778203`, 0.539751978767008, 0.949160860240723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 485}], {
             RGBColor[
             0.2711233170209595, 0.40229817477315244`, 0.9387514438621154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 24}], {
             RGBColor[
             0.46272658821033896`, 0.5710658280732519, 0.9518511746088405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 77}], {
             RGBColor[
             0.42085783786685993`, 0.5280465354573923, 0.9494306569831121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 79}], {
             RGBColor[
             0.45196420823223105`, 0.5607413029691908, 0.9512021187576689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 80}], {
             RGBColor[
             0.44747292190440746`, 0.5560206762746478, 0.9509463466455621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 81}], {
             RGBColor[
             0.4340883319350914, 0.5419526235848778, 0.9501841140475359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 99}], {
             RGBColor[
             0.49854103771969493`, 0.6020865041516839, 0.9541332396621024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 156}], {
             RGBColor[
             0.490178927154601, 0.594843664272097, 0.9536004133712186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 267}], {
             RGBColor[
             0.42940441225067516`, 0.5370295270188958, 0.9499173717507465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 278}], {
             RGBColor[
             0.45556133547477073`, 0.56452211177214, 0.9514069698326586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 329}], {
             RGBColor[
             0.4875722816861491, 0.5925859189811347, 0.953434320226935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 406}], {
             RGBColor[
             0.46472768714041934`, 0.5727990793883309, 0.9519786828631629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 413}], {
             RGBColor[
             0.42625015382701964`, 0.5337142014240989, 0.9497377413998266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 486}], {
             RGBColor[
             0.587488686021932, 0.6759888072331292, 0.9606684078870635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 28}], {
             RGBColor[
             0.5136147219900808, 0.6040584151782049, 0.9578214506332885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 49}], {
             RGBColor[
             0.6264411785377744, 0.6900541393412951, 0.818246327147961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 69}], {
             RGBColor[
             0.321538390545854, 0.4482182987670864, 0.9418813499609677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 142}], {
             RGBColor[
             0.5616681556270424, 0.6419657387455966, 0.9625134138326092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 173}], {
             RGBColor[
             0.32446237655312204`, 0.4507509084827721, 0.9420676637637716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[
             0.2975562573811955, 0.42744618039691995`, 0.9403532296422834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 241}], {
             RGBColor[
             0.6264148862153416, 0.6899979027221732, 0.8153845701085682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 388}], {
             RGBColor[
             0.28209643981984445`, 0.4138316225709498, 0.9393763469722314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 402}], {
             RGBColor[
             0.29064902597384645`, 0.4214634837194191, 0.9399131069648321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 436}], {
             RGBColor[
             0.24542015519463006`, 0.3752825220190949, 0.9372876868205262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 461}], {
             RGBColor[
             0.24948033938594955`, 0.3795500330347179, 0.9375189083037176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 487}], {
             RGBColor[
             0.38931087137352377`, 0.5050884331131711, 0.9467056583485347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 31}], {
             RGBColor[
             0.30362067814478433`, 0.42896145079288417`, 0.9408764946471762]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 40}], {
             RGBColor[
             0.34462756141869855`, 0.4639774910652663, 0.9436281379257982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 114}], {
             RGBColor[
             0.2253786796113386, 0.3542176604781113, 0.936146354434764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 115}], {
             RGBColor[
             0.26784491151390927`, 0.3979742798795344, 0.938596894432725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 162}], {
             RGBColor[
             0.2642755836389198, 0.39488270747385373`, 0.9383694600167634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 203}], {
             RGBColor[
             0.27875351441285023`, 0.4074227634282733, 0.9392919809633467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 221}], {
             RGBColor[
             0.5847762127313846, 0.5968515600985937, 0.6080080292518997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 258}], {
             RGBColor[
             0.23357972475790012`, 0.3628374789034422, 0.9366133918235017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 289}], {
             RGBColor[
             0.32285153478371575`, 0.44561825224256757`, 0.94210186782703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 291}], {
             RGBColor[
             0.25084041787369815`, 0.38097956175929837`, 0.9375963627615391]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 297}], {
             RGBColor[
             0.255979799256821, 0.3863813774485608, 0.9378890429282747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 311}], {
             RGBColor[
             0.2603221980152278, 0.3909455138676296, 0.9381363361135626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 381}], {
             RGBColor[
             0.29172629812002937`, 0.41865913664436416`, 0.9401185952697859]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 419}], {
             RGBColor[
             0.2158226935960633, 0.34417371329154933`, 0.9356021551680085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 439}], {
             RGBColor[
             0.28929247476204933`, 0.41655108117920064`, 0.939963514197561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 19}], {
             RGBColor[
             0.30324104170745103`, 0.43550207692827536`, 0.940600780401994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 26}], {
             RGBColor[
             0.3909299613000729, 0.5104547047637868, 0.9464642970431865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 34}], {
             RGBColor[
             0.35352648411393695`, 0.47905679972095017`, 0.9438049243264646]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 44}], {
             RGBColor[
             0.33659571898854923`, 0.46439222193433743`, 0.9427261109439626]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.35377161776046984`, 0.47926912216480155`, 0.9438205440256584]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 117}], {
             RGBColor[
             0.45353348776052405`, 0.5612790678011088, 0.9513926759704268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 139}], {
             RGBColor[
             0.367347364140333, 0.4910277513421862, 0.9446855785804222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 247}], {
             RGBColor[
             0.29479316023889357`, 0.4271766807499407, 0.9400994064169816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 269}], {
             RGBColor[
             0.5812246962452836, 0.6618565413456716, 0.9637277760914946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 360}], {
             RGBColor[
             0.2558989750896009, 0.3862964261242643, 0.9378844401115201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 425}], {
             RGBColor[
             0.3048271360883984, 0.4368758721616305, 0.9407018449334199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 466}], {
             RGBColor[
             0.30944708475070337`, 0.4408774394875476, 0.9409962239769217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 468}], {
             RGBColor[
             0.29441040957687575`, 0.4267743855363664, 0.9400776093330085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 120}], {
             RGBColor[
             0.30865145240923986`, 0.43830113305253976`, 0.9410146255145713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 123}], {
             RGBColor[
             0.29749598901382146`, 0.42863883134932146`, 0.9403038092514042]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 125}], {
             RGBColor[
             0.24430466531632083`, 0.3741100714308487, 0.9372241613221759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 177}], {
             RGBColor[
             0.2676877403491438, 0.39868716586293196`, 0.9385557928531356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 245}], {
             RGBColor[
             0.31758402957316995`, 0.4460380824275535, 0.9415838014326892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 438}], {
             RGBColor[
             0.35815016235919855`, 0.4811744277336937, 0.9441686395425921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 455}], {
             RGBColor[
             0.27765305809133417`, 0.40916134664761217`, 0.939123302956187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 23}], {
             RGBColor[
             0.2655723032729174, 0.39646370736936065`, 0.9384353218411533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 41}], {
             RGBColor[
             0.2532164779061686, 0.38347695150433214`, 0.9377316758653225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 102}], {
             RGBColor[
             0.25216503545750457`, 0.3823718188254846, 0.9376717977733409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 186}], {
             RGBColor[
             0.6164356802257485, 0.6810765519337125, 0.8686594791022251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 193}], {
             RGBColor[
             0.2762674869443633, 0.40753560277845297`, 0.93905060005248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 202}], {
             RGBColor[
             0.251210989037456, 0.3813690555479768, 0.9376174662411043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 211}], {
             RGBColor[
             0.5935125589097926, 0.6650974297985649, 0.9574795966362856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 414}], {
             RGBColor[
             0.39796687251627594`, 0.5102123604422298, 0.9475603501689367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 485}], {
             RGBColor[
             0.24301881045945342`, 0.3727585564483743, 0.9371509337903292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 497}], {
             RGBColor[
             0.21987149518030644`, 0.3484292604654361, 0.9358327284285659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 198}], {
             RGBColor[
             0.5032993335350885, 0.6007950399620902, 0.9560341768472638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 373}], {
             RGBColor[
             0.4901124702137567, 0.5869348105159453, 0.95528320448933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 480}], {
             RGBColor[
             0.4797644455118252, 0.5760583804515544, 0.9546938997910857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 154}], {
             RGBColor[
             0.7522740938963408, 0.8048684267674661, 0.9404631014376473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 229}], {
             RGBColor[
             0.39272017049609853`, 0.5077806172331465, 0.946980935950401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 244}], {
             RGBColor[
             0.5406762780627601, 0.6379843855769273, 0.956983163653017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 313}], {
             RGBColor[
             0.5744545870386395, 0.6654071384990246, 0.959642315869621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 334}], {
             RGBColor[
             0.38092442058582776`, 0.4953825361837113, 0.9463091854432593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 338}], {
             RGBColor[
             0.4080900614994058, 0.523935347184997, 0.9478562285053231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 340}], {
             RGBColor[
             0.4335674591313914, 0.5479227804495039, 0.9494093181194534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 363}], {
             RGBColor[
             0.4062184397745541, 0.5219681540845065, 0.9477496424169092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 379}], {
             RGBColor[
             0.4193491105692392, 0.5356075615599453, 0.948503337521865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 380}], {
             RGBColor[
             0.39162977978154834`, 0.5066345474573899, 0.9469188398122959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 390}], {
             RGBColor[
             0.6191619043190348, 0.7006645228197772, 0.963871546358655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 478}], {
             RGBColor[
             0.4433507185666713, 0.5563965480514267, 0.9500326987596728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 63}], {
             RGBColor[
             0.3376390910069228, 0.4653082758341107, 0.9427921419500858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 72}], {
             RGBColor[
             0.29133270710872516`, 0.4166373303627908, 0.9401550618912393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 75}], {
             RGBColor[
             0.48138565109175635`, 0.587951123165134, 0.952840138580872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 149}], {
             RGBColor[
             0.3247307700687785, 0.4517408120933031, 0.942057032168808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 158}], {
             RGBColor[
             0.36441198251856866`, 0.4900570762039515, 0.9444409871825876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 163}], {
             RGBColor[
             0.31065728415518956`, 0.4369486860875767, 0.9412555679658857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 182}], {
             RGBColor[
             0.39771375374761364`, 0.5189013966468605, 0.9465629465977023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 187}], {
             RGBColor[
             0.39948110538592196`, 0.520432187806287, 0.9466755606812876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 279}], {
             RGBColor[
             0.33382830894261273`, 0.4613029022669828, 0.9425751235490701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 322}], {
             RGBColor[
             0.3133751104580029, 0.4398052938519739, 0.9414103441531672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 324}], {
             RGBColor[
             0.3595385646386442, 0.48583596658146566`, 0.944130457304673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 441}], {
             RGBColor[
             0.6362216490820589, 0.7104332473100898, 0.9674649254806756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 494}], {
             RGBColor[
             0.3480223550870699, 0.47586120468941406`, 0.943396654615431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 78}], {
             RGBColor[
             0.5742071051573033, 0.6431922537075467, 0.9471296731910348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 97}], {
             RGBColor[
             0.7816181449224021, 0.8293749339627663, 0.9611105332953456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 104}], {
             RGBColor[
             0.6521953306232163, 0.7214643474326813, 0.9517064065810881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.5974559616383552, 0.667628275931771, 0.9484536611740297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 148}], {
             RGBColor[
             0.6230794710862638, 0.6945602089858558, 0.949912882130503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 153}], {
             RGBColor[
             0.6828691792348905, 0.748032493387655, 0.9536609170908047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 190}], {
             RGBColor[
             0.9670468570694324, 0.9527059687645865, 0.6653787470822691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 323}], {
             RGBColor[
             0.6827423402713926, 0.7479226318525847, 0.9536528350242099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 356}], {
             RGBColor[
             0.6551901329754006, 0.7240582947070004, 0.9518972327387696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 408}], {
             RGBColor[
             0.6060105040333921, 0.6766196423782695, 0.9489408297081157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 430}], {
             RGBColor[
             0.6285621040660173, 0.7003228038665852, 0.9502251099678711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 452}], {
             RGBColor[
             0.6067174474613259, 0.6773626847438302, 0.9489810890905075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 39}], {
             RGBColor[
             0.30133019008659706`, 0.4315230572711347, 0.9405641133083831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 45}], {
             RGBColor[
             0.281890106635309, 0.41361475331172354`, 0.9393645966026147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 52}], {
             RGBColor[
             0.4103653731290986, 0.5232268275873317, 0.9482679869093358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 56}], {
             RGBColor[
             0.32305343713879064`, 0.4503386420256012, 0.9419482994014359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 179}], {
             RGBColor[
             0.23567420650439913`, 0.36503891201682537`, 0.9367326694604567]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 200}], {
             RGBColor[
             0.3154587217188305, 0.44376048125032774`, 0.9414643708506191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 236}], {
             RGBColor[
             0.2713868537378552, 0.4025751685718028, 0.938766451888275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 243}], {
             RGBColor[
             0.26298445652438346`, 0.3937437163576909, 0.9382879477972005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 254}], {
             RGBColor[
             0.28078576532697075`, 0.412454020577377, 0.9393017059988313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 276}], {
             RGBColor[
             0.3724533139658998, 0.4924481100398449, 0.9452834107355602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 283}], {
             RGBColor[
             0.2845128366061411, 0.4163714088017527, 0.9395139571944724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 292}], {
             RGBColor[
             0.30293993088687404`, 0.4329173338444095, 0.9406666845687389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 422}], {
             RGBColor[
             0.2970223843813677, 0.42779185248587526`, 0.9402896237380889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 454}], {
             RGBColor[
             0.4038455750206842, 0.5179337617693632, 0.9477547245194341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 205}], {
             RGBColor[
             0.28891926147638114`, 0.4176688696461667, 0.939886969585126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 252}], {
             RGBColor[
             0.3185840205852023, 0.4488484123238982, 0.941576333731295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 282}], {
             RGBColor[
             0.3595122307924668, 0.48581315752748444`, 0.9441287793352807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 293}], {
             RGBColor[
             0.29381970299129867`, 0.4228195443842826, 0.940166042479847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 298}], {
             RGBColor[
             0.2985184491247238, 0.4277582244882242, 0.9404336291209736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 418}], {
             RGBColor[
             0.5887311551847788, 0.6712384496438977, 0.9635462076136528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 432}], {
             RGBColor[
             0.3288927859057992, 0.45929213334470076`, 0.9421777353828142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 467}], {
             RGBColor[
             0.32072455768852837`, 0.451098252537385, 0.9416982341526885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 52}], {
             RGBColor[
             0.4892903143111319, 0.5954833856676424, 0.9531543722123479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 56}], {
             RGBColor[
             0.40197837832082395`, 0.5225952001059119, 0.9468346847044478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 65}], {
             RGBColor[
             0.34602367385307303`, 0.4703246395283116, 0.9434086350402384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 88}], {
             RGBColor[
             0.4892186512927306, 0.595425206400922, 0.953148730637029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 166}], {
             RGBColor[
             0.33714486689776374`, 0.4609924504694062, 0.9429030001191514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 167}], {
             RGBColor[
             0.5274884639867863, 0.6264943643813713, 0.956161470479248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 210}], {
             RGBColor[
             0.34919732609125353`, 0.4736603492518132, 0.9435893698402051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 227}], {
             RGBColor[
             0.3496005361396116, 0.4740841485776311, 0.9436123320559633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 243}], {
             RGBColor[
             0.34190939770641676`, 0.46600027443800157`, 0.9431743331002125]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 326}], {
             RGBColor[
             0.46912150107516254`, 0.5791094344880003, 0.9515666093536151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 348}], {
             RGBColor[
             0.4338166942114427, 0.55017194909008, 0.9488633940394807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 428}], {
             RGBColor[
             0.34425068013672044`, 0.46846111071813057`, 0.9433076656710013]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 434}], {
             RGBColor[
             0.603918746705492, 0.6863836891153892, 0.9636552978343571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 469}], {
             RGBColor[
             0.41370132983328956`, 0.5327490314933345, 0.9475816608086232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 474}], {
             RGBColor[
             0.32164429816353246`, 0.44470036993690787`, 0.9420202656607733]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 495}], {
             RGBColor[
             0.3490391206461238, 0.4734940652981773, 0.9435803602741488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 26}], {
             RGBColor[
             0.4024254219318719, 0.5219832998703677, 0.9471392261530561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 34}], {
             RGBColor[
             0.36502194474573596`, 0.49058539482753094`, 0.9444798534363343]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 44}], {
             RGBColor[
             0.34809117962034825`, 0.4759208170409182, 0.9434010400538324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 139}], {
             RGBColor[
             0.37884282477213194`, 0.502556346448767, 0.9453605076902919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 234}], {
             RGBColor[
             0.3163225967201974, 0.44840446726821126`, 0.9413767740432896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 247}], {
             RGBColor[
             0.30628862087069253`, 0.43870527585652147`, 0.9407743355268514]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 269}], {
             RGBColor[
             0.5927201568770827, 0.6733851364522525, 0.9644027052013643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 360}], {
             RGBColor[
             0.26739443572139987`, 0.39782502123084507`, 0.9385593692213898]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 393}], {
             RGBColor[
             0.2757314089492087, 0.40658770868790495`, 0.9390341475132669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 466}], {
             RGBColor[
             0.3209425453825024, 0.45240603459412837`, 0.9416711530867914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 468}], {
             RGBColor[
             0.30590587020867477`, 0.43830298064294715`, 0.9407525384428783]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 62}], {
             RGBColor[
             0.3872436822927602, 0.503324880259524, 0.946550687611212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 194}], {
             RGBColor[
             0.42728650887979225`, 0.5427777392242807, 0.9489275362779738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 228}], {
             RGBColor[
             0.6141990182216122, 0.6966209322334698, 0.9634907608323954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 388}], {
             RGBColor[
             0.4118266913184412, 0.5291631813983105, 0.9479506536079217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 490}], {
             RGBColor[
             0.4195516853272835, 0.5360782238266332, 0.9484346801608439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 33}], {
             RGBColor[
             0.3010625668005851, 0.43256593617291467`, 0.940500388283143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 65}], {
             RGBColor[
             0.29465769801097885`, 0.4258340129829025, 0.9401356404807292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 119}], {
             RGBColor[
             0.2768761832965907, 0.4071445136049314, 0.9391230095231384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 164}], {
             RGBColor[
             0.32616485031235215`, 0.4569293326436865, 0.9420039137390186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 166}], {
             RGBColor[
             0.28577889105566956`, 0.4165018239239971, 0.939630005559642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 175}], {
             RGBColor[
             0.2812067456810776, 0.41169620924454087`, 0.9393696286444421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 227}], {
             RGBColor[
             0.2982345602975174, 0.429593522032222, 0.9403393374964539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 309}], {
             RGBColor[
             0.2885168926104651, 0.4193796371574124, 0.9397859306976775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 320}], {
             RGBColor[
             0.3029522111923329, 0.43455207223901604`, 0.9406080007357747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 337}], {
             RGBColor[
             0.29987896720243773`, 0.43132189795071296`, 0.9404329840370071]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 348}], {
             RGBColor[
             0.3824507183693485, 0.505681322544671, 0.9455903994799715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 375}], {
             RGBColor[
             0.42386376141541704`, 0.5395777492483262, 0.9487744775215867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 428}], {
             RGBColor[
             0.2928847042946262, 0.42397048417272154`, 0.940034671111492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 489}], {
             RGBColor[
             0.2703796764566195, 0.4003162730137977, 0.9387530430693227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 63}], {
             RGBColor[
             0.3641895950998229, 0.48830498801224376`, 0.9444839165931964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 149}], {
             RGBColor[
             0.35128127416167865`, 0.4747375242714361, 0.9437488068119186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 160}], {
             RGBColor[
             0.3345495269083127, 0.45715139705410063`, 0.9427959585582413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 165}], {
             RGBColor[
             0.4271114455126065, 0.5443641996827471, 0.9484361415216095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 182}], {
             RGBColor[
             0.42426425784051375`, 0.5418981088249936, 0.948254721240813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 268}], {
             RGBColor[
             0.37776179096726337`, 0.5016200093013287, 0.9452916251721664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 275}], {
             RGBColor[
             0.3594471123692681, 0.4833203379716584, 0.9442138392175657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 282}], {
             RGBColor[
             0.4053594356558514, 0.5255237020326299, 0.9470501226880841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 285}], {
             RGBColor[
             0.35664902696547224`, 0.48037937280340776`, 0.9440544923932159]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 324}], {
             RGBColor[
             0.38608906873154425`, 0.5088326787595987, 0.9458222319477837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 353}], {
             RGBColor[
             0.39337005717662293`, 0.5151391049976061, 0.9462861700931788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 441}], {
             RGBColor[
             0.6627721531749591, 0.7334299594882228, 0.9691567001237863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 481}], {
             RGBColor[
             0.6450888019786325, 0.719329735246053, 0.9674700463005667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 41}], {
             RGBColor[
             0.27683223804440915`, 0.4082986127352971, 0.939076558468809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 186}], {
             RGBColor[
             0.640051440363989, 0.7058982131646776, 0.8700043617057116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 202}], {
             RGBColor[
             0.2748267491756965, 0.40619071677894175`, 0.9389623488445908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 211}], {
             RGBColor[
             0.617128319048033, 0.6899190910295299, 0.9588244792397721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 212}], {
             RGBColor[
             0.30667159158638824`, 0.4382369868264806, 0.9408280299650502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 485}], {
             RGBColor[
             0.26663457059769397`, 0.39758021767933927`, 0.9384958163938157]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 497}], {
             RGBColor[
             0.24348725531854698`, 0.37325092169640106`, 0.9371776110320524]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 77}], {
             RGBColor[
             0.2775570296130085, 0.4080729960011017, 0.9391539885093404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 81}], {
             RGBColor[
             0.29078752368123995`, 0.4219790841285872, 0.9399074455737642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 83}], {
             RGBColor[
             0.3103909998659967, 0.44258358053094515`, 0.941023834541742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 176}], {
             RGBColor[
             0.554639307330748, 0.6434252966415879, 0.9606316565851064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 197}], {
             RGBColor[
             0.28790215944673525`, 0.41894638337546414`, 0.9397431283491231]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 237}], {
             RGBColor[
             0.3007225582738323, 0.43242143540297734`, 0.9404732310962458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 267}], {
             RGBColor[
             0.2861036039968237, 0.4170559875626052, 0.9396407032769749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 270}], {
             RGBColor[
             0.35562547138722456`, 0.4824466418848715, 0.943881118462905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 278}], {
             RGBColor[
             0.31226052722091924`, 0.44454857231584927`, 0.941130301358887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 329}], {
             RGBColor[
             0.34427147343229764`, 0.472612379524844, 0.9431576517531632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 426}], {
             RGBColor[
             0.3608954742733297, 0.48701125350676905`, 0.944216918386727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 448}], {
             RGBColor[
             0.4252030701502141, 0.5406025456968178, 0.9488971858139716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 489}], {
             RGBColor[
             0.26922849193316434`, 0.39931917483979734`, 0.9386796906094406]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[
             0.2970387445905787, 0.4292117550538156, 0.9402391954550036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 96}], {
             RGBColor[
             0.25906133434580425`, 0.38962026620769147`, 0.9380645317928695]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 157}], {
             RGBColor[
             0.31238458839837335`, 0.44250355365559085`, 0.9412170190526394]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.31109354111665805`, 0.4413853133900922, 0.9411347546614768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 246}], {
             RGBColor[
             0.30597613581494587`, 0.43695287412601824`, 0.9408086781207955]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 288}], {
             RGBColor[
             0.3566252650181815, 0.4808226041426076, 0.9440359958463592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 333}], {
             RGBColor[
             0.551242302093989, 0.6366896730443384, 0.9610588676420718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 343}], {
             RGBColor[
             0.3591977312479719, 0.48305074509493995`, 0.944199911119779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 392}], {
             RGBColor[
             0.2829059447169044, 0.4146824635433347, 0.9394224470785638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 459}], {
             RGBColor[
             0.26830693944866735`, 0.3993379833760218, 0.9385910553258305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 465}], {
             RGBColor[
             0.3289044880954653, 0.45681226045891066`, 0.9422696524533642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 492}], {
             RGBColor[
             0.30041891590501363`, 0.43213948955402903`, 0.9404545769821913]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 34}], {
             RGBColor[
             0.45271086433835783`, 0.5655380226630424, 0.9503433700775266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 44}], {
             RGBColor[
             0.4357800992129701, 0.5508734448764298, 0.9492645566950246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 106}], {
             RGBColor[
             0.4529559979848907, 0.5657503451068939, 0.9503589897767205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 117}], {
             RGBColor[
             0.5527178679849449, 0.6477602907432012, 0.9579311217214888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 139}], {
             RGBColor[
             0.46653174436475386`, 0.5775089742842785, 0.9512240243314842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 215}], {
             RGBColor[
             0.4880599643423429, 0.5952680917607718, 0.9528410146970379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 224}], {
             RGBColor[
             0.6857883634014559, 0.7526270616702886, 0.9707793030322531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 247}], {
             RGBColor[
             0.39397754046331446`, 0.513657903692033, 0.9466378521680436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 269}], {
             RGBColor[
             0.6804090764697046, 0.748337764287764, 0.9702662218425566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 351}], {
             RGBColor[
             0.4804313066710205, 0.5890748037960806, 0.9522404588204576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 360}], {
             RGBColor[
             0.3550833553140218, 0.4727776490663566, 0.944422885862582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 425}], {
             RGBColor[
             0.4040115163128193, 0.5233570951037229, 0.9472402906844819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 466}], {
             RGBColor[
             0.40863146497512426`, 0.5273586624296399, 0.9475346697279838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 468}], {
             RGBColor[
             0.39359478980129664`, 0.5132556084784587, 0.9466160550840707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 40}], {
             RGBColor[
             0.3665455645136251, 0.48701470199969454`, 0.9448763357772745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 114}], {
             RGBColor[
             0.24729668270626515`, 0.37725487141253955`, 0.9373945522862401]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 199}], {
             RGBColor[
             0.3021186840248485, 0.431713437263085, 0.9406323909856116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 220}], {
             RGBColor[
             0.31849933567937955`, 0.44590153441074865`, 0.9416761516241968]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 277}], {
             RGBColor[
             0.3020685901948561, 0.43167004850533464`, 0.9406291990510607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 289}], {
             RGBColor[
             0.3447695378786423, 0.4686554631769958, 0.9433500656785061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 291}], {
             RGBColor[
             0.2727584209686247, 0.4040167726937266, 0.9388445606130154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 297}], {
             RGBColor[
             0.2778978023517476, 0.40941858838298906`, 0.9391372407797508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 311}], {
             RGBColor[
             0.28224020111015435`, 0.41398272480205783`, 0.9393845339650388]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 319}], {
             RGBColor[
             0.2581083457040704, 0.3886186147222594, 0.9380102604995432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 349}], {
             RGBColor[
             0.34398118028937774`, 0.4679726274571794, 0.9432998322300354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 359}], {
             RGBColor[
             0.24383178521887305`, 0.3736130444661012, 0.9371972315001897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 371}], {
             RGBColor[
             0.4120405118916758, 0.5239495498052192, 0.9484578646883579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 419}], {
             RGBColor[
             0.23774069669098985`, 0.36721092422597756`, 0.9368503530194847]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 488}], {
             RGBColor[
             0.29108461444904765`, 0.42215628078498857`, 0.9399293098292862]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 69}], {
             RGBColor[
             0.5772830384048901, 0.6639085377535722, 0.9617061093083057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 142}], {
             RGBColor[
             0.8174128034860786, 0.8576559777320825, 0.9823381731799472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 173}], {
             RGBColor[
             0.5802070244121582, 0.6664411474692579, 0.9618924231111096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 194}], {
             RGBColor[
             0.5533009052402318, 0.6431364193834057, 0.9601779889896214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 241}], {
             RGBColor[
             0.8821595340743779, 0.9056881417086591, 0.8352093294559062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 417}], {
             RGBColor[
             0.6176763058465387, 0.6985509932533778, 0.9643750257247619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 461}], {
             RGBColor[
             0.5052249872449858, 0.5952402720212037, 0.9573436676510556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 493}], {
             RGBColor[
             0.5930845053333267, 0.6775949742021634, 0.9627129648082972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 77}], {
             RGBColor[
             0.2940310575968042, 0.4223419710319437, 0.9402036990050568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 172}], {
             RGBColor[
             0.30330077064565, 0.43208502718003383`, 0.9407315954498772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 318}], {
             RGBColor[
             0.6230440165510414, 0.6988588482777491, 0.9666991895765319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 321}], {
             RGBColor[
             0.3189065709983838, 0.44848771281564814`, 0.9416203226932527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 383}], {
             RGBColor[
             0.33609441544401897`, 0.46552982288628153`, 0.9426366168488387]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 479}], {
             RGBColor[
             0.33201251282538435`, 0.4619942840004112, 0.9423765216234641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 482}], {
             RGBColor[
             0.3230826023916115, 0.45287698658561354`, 0.9418581415032121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 43}], {
             RGBColor[
             0.2733107438706963, 0.40459729908309855`, 0.9388760145851999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 64}], {
             RGBColor[
             0.2703042423382894, 0.4014372753493318, 0.9387047987706497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 110}], {
             RGBColor[
             0.3842048932390384, 0.5028620961623681, 0.9461290244551464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 217}], {
             RGBColor[
             0.2423632923430884, 0.3720695653458256, 0.9371136030033543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 290}], {
             RGBColor[
             0.26753356975743603`, 0.3985251227960671, 0.938547013066013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 316}], {
             RGBColor[
             0.31417369355219393`, 0.4433226812555414, 0.9413577666307416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 355}], {
             RGBColor[
             0.316514116533007, 0.4453498380084423, 0.9415068963135241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 378}], {
             RGBColor[
             0.25344180607121264`, 0.38371378569242426`, 0.9377445079709786]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 384}], {
             RGBColor[
             0.35563048536164205`, 0.47923047064194335`, 0.9439993567460379]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[
             0.43080163614036376`, 0.5470583963765356, 0.9488099981426743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 114}], {
             RGBColor[
             0.31155275433300383`, 0.43729856578938064`, 0.94132821465164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 162}], {
             RGBColor[
             0.350449658360585, 0.4779636127851231, 0.9435513202336394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 203}], {
             RGBColor[
             0.36492758913451545`, 0.49050366873954265`, 0.9444738411802227]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 208}], {
             RGBColor[
             0.6558792726988116, 0.7263276372503931, 0.9692386392570556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 221}], {
             RGBColor[
             0.6709502874530497, 0.6799324654098631, 0.6131898894687756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 223}], {
             RGBColor[
             0.40448326195275963`, 0.5247648044087825, 0.9469942936744932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 258}], {
             RGBColor[
             0.3197537994795654, 0.4459183842147115, 0.9417952520403776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 289}], {
             RGBColor[
             0.409025609505381, 0.5286991575538369, 0.9472837280439059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 297}], {
             RGBColor[
             0.3421538739784863, 0.46946228275983015`, 0.9430709031451506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 314}], {
             RGBColor[
             0.31523074426139586`, 0.44116436640215095`, 0.9415376707369635]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 381}], {
             RGBColor[
             0.37790037284169464`, 0.5017400419556335, 0.945300455486662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 397}], {
             RGBColor[
             0.39176196832272353`, 0.5137462592572543, 0.9461837040933856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 419}], {
             RGBColor[
             0.30199676831772854`, 0.4272546186028187, 0.9407840153848845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 472}], {
             RGBColor[
             0.32489108088639906`, 0.45131799269574774`, 0.94208781261657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 103}], {
             RGBColor[
             0.4734373843294418, 0.5818178929313051, 0.952126134596796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 155}], {
             RGBColor[
             0.44604009931008093`, 0.5580877416751188, 0.9503804038218301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 331}], {
             RGBColor[
             0.40491037901135934`, 0.5177818990324965, 0.9479310614290275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 344}], {
             RGBColor[
             0.4417964296361201, 0.5544120882965735, 0.950110000942735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 403}], {
             RGBColor[
             0.4727208771720134, 0.5811972904442376, 0.952080479394307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 449}], {
             RGBColor[
             0.673053971180459, 0.7431254799455642, 0.9689968255956235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 119}], {
             RGBColor[
             0.2562106010937779, 0.3866239648128842, 0.9379021867514485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 159}], {
             RGBColor[
             0.26839959922702883`, 0.3994353746780489, 0.9385963321631303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 164}], {
             RGBColor[
             0.3054992681095394, 0.4364087838516393, 0.9407830909673287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 227}], {
             RGBColor[
             0.2775689780947046, 0.4090729732401748, 0.939118514724764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 267}], {
             RGBColor[
             0.2665892063174661, 0.39753253694455826`, 0.9384932329651671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 270}], {
             RGBColor[
             0.3361110737078669, 0.4629231912668246, 0.9427336481510973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 309}], {
             RGBColor[
             0.2678513104076523, 0.39885908836536516`, 0.9385651079259876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 443}], {
             RGBColor[
             0.6107876071304796, 0.6838483939461286, 0.9618668294518231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 489}], {
             RGBColor[
             0.24971409425380672`, 0.37979572422175045`, 0.9375322202976328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 234}], {
             RGBColor[
             0.3666080391266834, 0.49195919006088606`, 0.94458091796776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 269}], {
             RGBColor[
             0.6430055992835686, 0.7169398592449272, 0.9676068491258347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 332}], {
             RGBColor[
             0.4620663977051351, 0.5731332661121675, 0.9510798719346072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 360}], {
             RGBColor[
             0.3176798781278859, 0.44137974402351987`, 0.9417635131458603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 393}], {
             RGBColor[
             0.3260168513556947, 0.45014243148057975`, 0.9422382914377373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 468}], {
             RGBColor[
             0.3561913126151607, 0.48185770343562195`, 0.9439566823673489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 54}], {
             RGBColor[
             0.43436431181746316`, 0.5372398297645861, 0.950699449572737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 67}], {
             RGBColor[
             0.5247056392963427, 0.6235555898444061, 0.9561605597618217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 70}], {
             RGBColor[
             0.4618077060107983, 0.5660845770734715, 0.952262310273184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 84}], {
             RGBColor[
             0.5318021883021244, 0.62970226391029, 0.9566127455892381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 131}], {
             RGBColor[
             0.5456531296625032, 0.6416992531480954, 0.957495315324815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 135}], {
             RGBColor[
             0.5445584007325972, 0.6407510539716867, 0.9574255601654322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 147}], {
             RGBColor[
             0.44991638523050415`, 0.5535860449800986, 0.9515851171463787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 171}], {
             RGBColor[
             0.46310032553371755`, 0.5674432021488709, 0.9523359230427549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 216}], {
             RGBColor[
             0.49383283961895036`, 0.5968151224758785, 0.9541933722661231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 281}], {
             RGBColor[
             0.4701967008495414, 0.5749019425419839, 0.9527400511188446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 385}], {
             RGBColor[
             0.46338895469949215`, 0.5677465697022461, 0.9523523600467572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 391}], {
             RGBColor[
             0.46604504970388005`, 0.5705382939580077, 0.9525036207279167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 37}], {
             RGBColor[
             0.3683267058246094, 0.4934478127719296, 0.9446904298899946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 58}], {
             RGBColor[
             0.3535655200710639, 0.4806624155909768, 0.9437498601865828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 141}], {
             RGBColor[
             0.372838243090246, 0.49735547959496784`, 0.9449779010551652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 240}], {
             RGBColor[
             0.5927588845520879, 0.31373200020748837`, 0.5544501389376493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 251}], {
             RGBColor[
             0.34013357163407043`, 0.4690283369642111, 0.9428939883095832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 310}], {
             RGBColor[
             0.33619748196766147`, 0.4651984333541015, 0.942658586600883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 352}], {
             RGBColor[
             0.4495895647240583, 0.5617249015958254, 0.9504510716840866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 367}], {
             RGBColor[
             0.3125490995889447, 0.4403424840800265, 0.9413118462090617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 382}], {
             RGBColor[
             0.3531047368297082, 0.4802633083069536, 0.9437204994858982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 399}], {
             RGBColor[
             0.3408602071275746, 0.46965771210692264`, 0.9429402888806907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 412}], {
             RGBColor[
             0.39019497871823167`, 0.5123890116210309, 0.9460838569014218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 416}], {
             RGBColor[
             0.2973708358705894, 0.4243891665545322, 0.9404474665445303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 429}], {
             RGBColor[
             0.3262165007142266, 0.4547077892259793, 0.9420901844840384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 58}], {
             RGBColor[
             0.35369345679149744`, 0.48077322794792976`, 0.9437580122012788]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 118}], {
             RGBColor[
             0.5259180092003879, 0.6230703084644925, 0.9568876544770459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 141}], {
             RGBColor[
             0.3729661798106795, 0.49746629195192077`, 0.9449860530698613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 188}], {
             RGBColor[
             0.3162479510654488, 0.4442065542546819, 0.9415233565364209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 240}], {
             RGBColor[
             0.5928868212725215, 0.3138428125644413, 0.5544582909523453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 304}], {
             RGBColor[
             0.3600591204198283, 0.4862868458352331, 0.9441636266587408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 310}], {
             RGBColor[
             0.33632541868809496`, 0.4653092457110544, 0.942666738615579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 429}], {
             RGBColor[
             0.32634443743466, 0.4548186015829323, 0.9420983364987345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 47}], {
             RGBColor[
             0.32489365826302896`, 0.4556530341774414, 0.9419293314792428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 73}], {
             RGBColor[
             0.34425403459106646`, 0.47259727487707115`, 0.9431565405656206]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 93}], {
             RGBColor[
             0.3739602763853964, 0.498327328440194, 0.9450493960245572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 108}], {
             RGBColor[
             0.5153084075495258, 0.6136982394478657, 0.956288890337954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 163}], {
             RGBColor[
             0.2904261332460571, 0.41942548001729707`, 0.9399664569196602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 189}], {
             RGBColor[
             0.2963832457941988, 0.4256867830081446, 0.9403057056665185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 266}], {
             RGBColor[
             0.284470163177438, 0.4131653778448652, 0.9396272732353204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 364}], {
             RGBColor[
             0.6298883178421724, 0.7039917853978015, 0.9675014008812328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 437}], {
             RGBColor[
             0.30531160081045855`, 0.4350710502206375, 0.9408141622763769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 45}], {
             RGBColor[
             0.3166100783983864, 0.44758318868769953`, 0.9414342803431706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 100}], {
             RGBColor[
             0.3551232689633623, 0.4820116593867497, 0.9438491185685367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 127}], {
             RGBColor[
             0.5889456654286038, 0.671108402958335, 0.9637052766705012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 179}], {
             RGBColor[
             0.2703941782674766, 0.3990073473928014, 0.9388023532010125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 200}], {
             RGBColor[
             0.35017869348190794`, 0.4777289166263038, 0.9435340545911748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 213}], {
             RGBColor[
             0.3295155840217827, 0.45983156977002226`, 0.9422174195280459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 236}], {
             RGBColor[
             0.30610682550093266`, 0.4365436039477788, 0.9408361356288307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 243}], {
             RGBColor[
             0.2977044282874609, 0.42771215173366695`, 0.9403576315377562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 254}], {
             RGBColor[
             0.3155057370900482, 0.44642245595335306`, 0.9413713897393872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 276}], {
             RGBColor[
             0.40717328572897726`, 0.526416545415821, 0.9473530944761159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 283}], {
             RGBColor[
             0.3192328083692185, 0.45033984417772877`, 0.9415836409350281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 315}], {
             RGBColor[
             0.2860906575269004, 0.4155053423087217, 0.9396962444739765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 325}], {
             RGBColor[
             0.30146273877054985`, 0.431662374342041, 0.9405716617598461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 368}], {
             RGBColor[
             0.3123444845913792, 0.44309977914226695`, 0.9411913610862419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 401}], {
             RGBColor[
             0.2929398974788079, 0.4227043277650715, 0.9400862985566951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 450}], {
             RGBColor[
             0.30422808684035463`, 0.4345689304966003, 0.9407291442414556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 454}], {
             RGBColor[
             0.43856554678376164`, 0.5519021971453393, 0.9498244082599898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 471}], {
             RGBColor[
             0.3066300526338635, 0.4370935488390054, 0.940865932640006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 475}], {
             RGBColor[
             0.3885268340518607, 0.5109441485544092, 0.945977564198363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 114}], {
             RGBColor[
             0.35255963760691805`, 0.4723146060617628, 0.9440798579302622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 199}], {
             RGBColor[
             0.4073816389255014, 0.5267731719123082, 0.9473176966296336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 208}], {
             RGBColor[
             0.6968861559727259, 0.7613436775227751, 0.9719902825356777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 220}], {
             RGBColor[
             0.42376229058003245`, 0.5409612690599719, 0.9483614572682189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 289}], {
             RGBColor[
             0.45003249277929525`, 0.5637151978262191, 0.9500353713225281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 291}], {
             RGBColor[
             0.3780213758692776, 0.4990765073429499, 0.9455298662570373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 297}], {
             RGBColor[
             0.3831607572524005, 0.5044783230322123, 0.9458225464237728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 314}], {
             RGBColor[
             0.3562376275353101, 0.4761804066745331, 0.9442893140155857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 349}], {
             RGBColor[
             0.4492441351900306, 0.5630323621064026, 0.9499851378740574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 359}], {
             RGBColor[
             0.34909474011952596`, 0.46867277911532446`, 0.9438825371442117]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 371}], {
             RGBColor[
             0.5173034667923286, 0.6190092844544425, 0.9551431703323799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 397}], {
             RGBColor[
             0.43276885159663775`, 0.5487622995296364, 0.9489353473720077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 419}], {
             RGBColor[
             0.34300365159164276`, 0.46227065887520086`, 0.9435356586635066]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 472}], {
             RGBColor[
             0.3658979641603133, 0.4863340329681299, 0.9448394558951922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 102}], {
             RGBColor[
             0.2634249702289963, 0.39420672419142105`, 0.9383130344009966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 186}], {
             RGBColor[
             0.6276956149972401, 0.6929114572996491, 0.8693007157298809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 191}], {
             RGBColor[
             0.2674207805368475, 0.39840657417397884`, 0.9385405898867571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 202}], {
             RGBColor[
             0.2624709238089477, 0.39320396091391324`, 0.93825870286876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 212}], {
             RGBColor[
             0.2943157662196394, 0.4252502309614521, 0.9401243839892195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 295}], {
             RGBColor[
             0.25498973366613364`, 0.3853407557389643, 0.9378326601575557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 300}], {
             RGBColor[
             0.24888833020779938`, 0.37892779385293224`, 0.9374851942568212]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 389}], {
             RGBColor[
             0.3566826480909202, 0.47926928938772867`, 0.9440983465531894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 451}], {
             RGBColor[
             0.3148263658529108, 0.4430154814710796, 0.9414313012610405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 456}], {
             RGBColor[
             0.3037155855571926, 0.4333918820229836, 0.9407233321654745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 485}], {
             RGBColor[
             0.2542787452309451, 0.38459346181431076`, 0.9377921704179849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 85}], {
             RGBColor[
             0.29742784384298204`, 0.42994590026642643`, 0.9402494477505694]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 95}], {
             RGBColor[
             0.29149834466449664`, 0.4237136206778764, 0.9399117715442626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[
             0.44791107602777114`, 0.556293845323269, 0.9509883534303258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 137}], {
             RGBColor[
             0.3354267739783474, 0.46305454674954805`, 0.9426635337384849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 145}], {
             RGBColor[
             0.3441449601542558, 0.4706058014263417, 0.9432190488524244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 174}], {
             RGBColor[
             0.34098127546884904`, 0.46786557676325824`, 0.9430174616618068]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 248}], {
             RGBColor[
             0.24652179201816873`, 0.3764404121684429, 0.9373504234079012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 286}], {
             RGBColor[
             0.263036898240095, 0.3937988359259006, 0.9382909342753296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 294}], {
             RGBColor[
             0.33125733663946566`, 0.4594431896886225, 0.94239786087814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 346}], {
             RGBColor[
             0.4243664944245944, 0.5371792933064962, 0.9491348377198795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 358}], {
             RGBColor[
             0.30089258795224805`, 0.43314277055239925`, 0.9404630459422835]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 407}], {
             RGBColor[
             0.25430606927725014`, 0.38462218111942187`, 0.9377937264819997]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 411}], {
             RGBColor[
             0.29709507707423144`, 0.4295961412938377, 0.9402304971753734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 430}], {
             RGBColor[
             0.29485503517138634`, 0.42724171522708787`, 0.9401029301028514]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 110}], {
             RGBColor[
             0.3836022612255249, 0.5022286917070888, 0.946094705453491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 217}], {
             RGBColor[
             0.24176066032957486`, 0.3714361608905463, 0.9370792840016989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 290}], {
             RGBColor[
             0.2669309377439225, 0.39789171834078785`, 0.9385126940643576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 316}], {
             RGBColor[
             0.3135710615386804, 0.44268927680026215`, 0.9413234476290862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 340}], {
             RGBColor[
             0.30582019144756734`, 0.4359758626973981, 0.9408295690407057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 355}], {
             RGBColor[
             0.3159114845194934, 0.44471643355316304`, 0.9414725773118687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 362}], {
             RGBColor[
             0.30654038786523846`, 0.4365996606362603, 0.9408754593195949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 378}], {
             RGBColor[
             0.25283917405769907`, 0.383080381237145, 0.9377101889693232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 384}], {
             RGBColor[
             0.3550278533481285, 0.4785970661866641, 0.9439650377443825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 57}], {
             RGBColor[
             0.34604304762065846`, 0.4741468280448944, 0.9432705348939041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 106}], {
             RGBColor[
             0.39862175567336705`, 0.5196878622774443, 0.9466208036774968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 117}], {
             RGBColor[
             0.4983836256734213, 0.6016978079137516, 0.9541929356222649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 139}], {
             RGBColor[
             0.41219750205323025`, 0.531446491454829, 0.9474858382322604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 140}], {
             RGBColor[
             0.3673860661762516, 0.4926330779864455, 0.9446304931633762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 247}], {
             RGBColor[
             0.33964329815179084`, 0.46759542086258354`, 0.9428996660688199]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 255}], {
             RGBColor[
             0.36937154351278584`, 0.4943527986623589, 0.9447570060235715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 269}], {
             RGBColor[
             0.626074834158181, 0.7022752814583145, 0.9665280357433328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 360}], {
             RGBColor[
             0.3007491130024982, 0.42671516623690714`, 0.9406846997633583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 369}], {
             RGBColor[
             0.42301655502435365`, 0.5405114247129977, 0.9482597637420939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 370}], {
             RGBColor[
             0.3692890560172716, 0.49428135213968655`, 0.9447517499932983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 425}], {
             RGBColor[
             0.34967727400129567`, 0.4772946122742734, 0.9435021045852581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 466}], {
             RGBColor[
             0.35429722266360064`, 0.48129617960019044`, 0.94379648362876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 468}], {
             RGBColor[
             0.33926054748977297`, 0.4671931256490092, 0.9428778689848469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 52}], {
             RGBColor[
             0.425645261440888, 0.5392869590038966, 0.9491381539441233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 56}], {
             RGBColor[
             0.33833332545058, 0.46639877344216607`, 0.9428184664362231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 179}], {
             RGBColor[
             0.2509540948161885, 0.38109904343339024`, 0.937602836495244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 236}], {
             RGBColor[
             0.2866667420496446, 0.4186352999883677, 0.9396366189230623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 243}], {
             RGBColor[
             0.2782643448361728, 0.40980384777425577`, 0.9391581148319879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 254}], {
             RGBColor[
             0.29606565363876014`, 0.4285141519939419, 0.9401718730336188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 276}], {
             RGBColor[
             0.38773320227768915`, 0.5085082414564097, 0.9461535777703476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 283}], {
             RGBColor[
             0.2997927249179304, 0.4324315402183176, 0.9403841242292597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 292}], {
             RGBColor[
             0.3182198191986634, 0.4489774652609744, 0.9415368516035263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 386}], {
             RGBColor[
             0.28512175626100705`, 0.4170114219667529, 0.9395486342680011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 422}], {
             RGBColor[
             0.312302272693157, 0.44385198390244013`, 0.9411597907728764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 53}], {
             RGBColor[
             0.394278881738257, 0.5159262831540428, 0.9463440795906042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 68}], {
             RGBColor[
             0.2893808688469447, 0.4130662431686859, 0.9400995469096233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 90}], {
             RGBColor[
             0.31206048868103664`, 0.43690396158526734`, 0.9413911177076839]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 205}], {
             RGBColor[
             0.3164337509444497, 0.4415005375049569, 0.9416401685239236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 257}], {
             RGBColor[
             0.5191676506949495, 0.619070516962609, 0.9556911717897392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 272}], {
             RGBColor[
             0.3379974571902972, 0.4641653599872854, 0.94286818969398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 293}], {
             RGBColor[
             0.32133419245936723`, 0.4466512122430728, 0.9419192414186446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 298}], {
             RGBColor[
             0.3260329385927924, 0.4515898923470144, 0.9421868280597712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 306}], {
             RGBColor[
             0.31317259610895765`, 0.4380728570036958, 0.9414544505804885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 317}], {
             RGBColor[
             0.35495603067734094`, 0.48186680598903875`, 0.9438384622928344]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 357}], {
             RGBColor[
             0.4983370067488957, 0.6021592617973868, 0.9540513071931429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 418}], {
             RGBColor[
             0.6162456446528474, 0.6950701175026879, 0.9652994065524505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 420}], {
             RGBColor[
             0.36751035440228563`, 0.49274073020092835`, 0.9446384126992353]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 55}], {
             RGBColor[
             0.3141379378385081, 0.44633696974394854`, 0.9412439864847024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 189}], {
             RGBColor[
             0.27834004557677144`, 0.4098834140523291, 0.9391624258771757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 230}], {
             RGBColor[
             0.28544585881572815`, 0.41735207430105353`, 0.9395670914290256]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 242}], {
             RGBColor[
             0.276574210055649, 0.40802740895919076`, 0.9390618641565673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 339}], {
             RGBColor[
             0.31043183100056115`, 0.4431269262752648, 0.9410078366341701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 364}], {
             RGBColor[
             0.611845117624745, 0.6881884164419859, 0.9663581210918899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 365}], {
             RGBColor[
             0.26283947684254017`, 0.39359133351983083`, 0.9382796914187976]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 374}], {
             RGBColor[
             0.471594913627974, 0.5777488288826542, 0.9526500821517522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 437}], {
             RGBColor[
             0.2872684005930312, 0.41926768126482195`, 0.9396708824870341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 78}], {
             RGBColor[
             0.24711325640661608`, 0.3770620787417092, 0.93738410642983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 85}], {
             RGBColor[
             0.30404106398692576`, 0.43689681394008617`, 0.9406260608543845]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 95}], {
             RGBColor[
             0.29811156480844037`, 0.43066453435153607`, 0.9402883846480776]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 137}], {
             RGBColor[
             0.34203999412229114`, 0.47000546042320773`, 0.9430401468423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 145}], {
             RGBColor[
             0.35075818029819944`, 0.4775567151000014, 0.9435956619562396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 183}], {
             RGBColor[
             0.31086872679060046`, 0.44300647537394755`, 0.941053941251594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 346}], {
             RGBColor[
             0.43097971456853806`, 0.5441302069801559, 0.9495114508236946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 358}], {
             RGBColor[
             0.3075058080961917, 0.44009368422605893`, 0.9408396590460986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 404}], {
             RGBColor[
             0.4542360060264099, 0.5630107120696471, 0.951342271277861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 407}], {
             RGBColor[
             0.26091928942119386`, 0.39157309479308156`, 0.9381703395858147]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 408}], {
             RGBColor[
             0.27891665528270476`, 0.4104894674124319, 0.9391952629469109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 71}], {
             RGBColor[
             0.6711058144710167, 0.7334442290362826, 0.8209200881069876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 76}], {
             RGBColor[
             0.6536376768828197, 0.7183142062315098, 0.8198070338263352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 238}], {
             RGBColor[
             0.5924739519536549, 0.6543524305548316, 0.8163119438440039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 328}], {
             RGBColor[
             0.662042399128965, 0.725593954207498, 0.8203425752958555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 402}], {
             RGBColor[
             0.6592201303805761, 0.7231494468689952, 0.8201627428268425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 431}], {
             RGBColor[
             0.7215469186079317, 0.777133778196069, 0.8241341506592748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 436}], {
             RGBColor[
             0.6139912596013597, 0.676968485168671, 0.8175373226825366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 459}], {
             RGBColor[
             0.6249058717409084, 0.6884404345537158, 0.8181588936971622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 462}], {
             RGBColor[
             0.6986105836620926, 0.757267477679697, 0.8226726676783305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 487}], {
             RGBColor[
             0.7578819757802534, 0.8067743962627472, 0.8269552942105451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 57}], {
             RGBColor[
             0.2993334213170487, 0.4317736477352392, 0.9403643801290813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 92}], {
             RGBColor[
             0.3582823989503163, 0.4828322892994108, 0.944120556857339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 106}], {
             RGBColor[
             0.3519121293697573, 0.47731468196778926`, 0.943714648912674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 117}], {
             RGBColor[
             0.45167399936981156`, 0.5593246276040965, 0.9512867808574422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 139}], {
             RGBColor[
             0.3654878757496205, 0.48907331114517383`, 0.9445796834674377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 140}], {
             RGBColor[
             0.3206764398726418, 0.4502598976767903, 0.9417243383985535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 169}], {
             RGBColor[
             0.29828929421430594`, 0.430851339225796, 0.9402985060748147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 204}], {
             RGBColor[
             0.25473966637720247`, 0.38507791916311573`, 0.9378184191953925]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 219}], {
             RGBColor[
             0.6194274809388088, 0.6914565257706566, 0.9539165025229503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 244}], {
             RGBColor[
             0.4205882565974581, 0.5340878212247467, 0.9488395973155748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 255}], {
             RGBColor[
             0.3226619172091761, 0.4519796183527037, 0.9418508512587488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 274}], {
             RGBColor[
             0.2720956815741542, 0.40332019157003357`, 0.9388068185849354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 334}], {
             RGBColor[
             0.2608363991205258, 0.39148597183153083`, 0.938165619105817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 338}], {
             RGBColor[
             0.28800204003410385`, 0.4200387828328165, 0.9397126621678809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 340}], {
             RGBColor[
             0.31347943766608943`, 0.4440262160973234, 0.9412657517820111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 361}], {
             RGBColor[
             0.296119661050762, 0.4285709172082235, 0.9401749486758355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 363}], {
             RGBColor[
             0.2861304183092521, 0.41807158973232594`, 0.9396060760794669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 369}], {
             RGBColor[
             0.3763069287207439, 0.49813824440334253`, 0.9453536089772712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 370}], {
             RGBColor[
             0.3225794297136618, 0.4519081718300314, 0.9418455952284754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 379}], {
             RGBColor[
             0.29926108910393723`, 0.4317109972077648, 0.9403597711844227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[
             0.3960066496902922, 0.5167403177649168, 0.9466427402486055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 113}], {
             RGBColor[
             0.39628022979491506`, 0.5169772791010052, 0.9466601725309547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 127}], {
             RGBColor[
             0.6601470286959914, 0.7320969739869367, 0.9684307333889087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 130}], {
             RGBColor[
             0.3880132521814675, 0.5087838753638209, 0.9461712298718947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 143}], {
             RGBColor[
             0.4337523740820563, 0.5494337670777927, 0.9490478644296152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 179}], {
             RGBColor[
             0.3415955415348642, 0.4599959184214032, 0.94352780991942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 214}], {
             RGBColor[
             0.33466973101860886`, 0.45271645244706965`, 0.9431333952563377]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 302}], {
             RGBColor[
             0.397761215251045, 0.5182600342666117, 0.9467545396146353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 308}], {
             RGBColor[
             0.439899010375149, 0.5547576744959466, 0.949439522658954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 315}], {
             RGBColor[
             0.357292020794288, 0.4764939133373235, 0.9444217011923839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 325}], {
             RGBColor[
             0.3726641020379375, 0.4926509453706428, 0.9452971184782535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 347}], {
             RGBColor[
             0.3864852799539603, 0.5071778796736761, 0.9460842141139706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 386}], {
             RGBColor[
             0.3757632029796828, 0.4959082969547658, 0.9454736076921769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 421}], {
             RGBColor[
             0.3494642874988949, 0.4682664693369091, 0.943975923361305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 423}], {
             RGBColor[
             0.5404799508239514, 0.637824998280021, 0.9569677080536076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 477}], {
             RGBColor[
             0.4226634927192655, 0.539829135384726, 0.9483412907146909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 56}], {
             RGBColor[
             0.46680859194436963`, 0.5760108477177742, 0.9517218567429443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 88}], {
             RGBColor[
             0.5540488649162763, 0.6488408540127844, 0.9580359026755255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 166}], {
             RGBColor[
             0.4019750805213094, 0.5144080980812685, 0.9477901721576478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 210}], {
             RGBColor[
             0.4140275397147992, 0.5270759968636756, 0.9484765418787016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 227}], {
             RGBColor[
             0.4144307497631573, 0.5274997961894934, 0.9484995040944597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 236}], {
             RGBColor[
             0.4151420085434342, 0.5282473742639758, 0.9485400092297834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 243}], {
             RGBColor[
             0.40673961132996245`, 0.519415922049864, 0.9480615051387089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 276}], {
             RGBColor[
             0.5162084687714787, 0.6181203157320179, 0.9550569680770686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 326}], {
             RGBColor[
             0.5339517146987083, 0.6325250820998627, 0.9564537813921117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 428}], {
             RGBColor[
             0.40908089376026613`, 0.5218767583299929, 0.9481948377094978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 469}], {
             RGBColor[
             0.47853154345683524`, 0.5861646791051969, 0.9524688328471196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 495}], {
             RGBColor[
             0.4138693342696695, 0.5269097129100396, 0.9484675323126454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 90}], {
             RGBColor[
             0.30650463272540424`, 0.43209175840193825`, 0.9410371034790416]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 178}], {
             RGBColor[
             0.41372795303594184`, 0.5327720911733509, 0.9475833572155541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 257}], {
             RGBColor[
             0.5136117947393171, 0.6142583137792799, 0.9553371575610968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 272}], {
             RGBColor[
             0.3324416012346648, 0.4593531568039564, 0.9425141754653377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[
             0.31577833650373477`, 0.44183900905974377`, 0.9415652271900021]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 298}], {
             RGBColor[
             0.32047708263716, 0.44677768916368543`, 0.9418328138311287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 306}], {
             RGBColor[
             0.30761674015332524`, 0.4332606538203667, 0.9411004363518461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 317}], {
             RGBColor[
             0.3494001747217085, 0.47705460280570966`, 0.9434844480641921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 357}], {
             RGBColor[
             0.4927811507932633, 0.5973470586140577, 0.9536972929645005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 418}], {
             RGBColor[
             0.6106897886972149, 0.6902579143193588, 0.964945392323808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 420}], {
             RGBColor[
             0.36195449844665323`, 0.4879285270175993, 0.944284398470593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 432}], {
             RGBColor[
             0.3508514194182354, 0.478311598020162, 0.9435769200929695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 55}], {
             RGBColor[
             0.2714618755020629, 0.4014817224097119, 0.9388136478682185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 70}], {
             RGBColor[
             0.24894172756604654`, 0.3789839178620381, 0.937488235157379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 84}], {
             RGBColor[
             0.3189362098573727, 0.44260160469885673`, 0.9418386704734333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 131}], {
             RGBColor[
             0.3327871512177515, 0.4545985939366621, 0.9427212402090102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 135}], {
             RGBColor[
             0.33169242228784546`, 0.4536503947602533, 0.9426514850496273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 147}], {
             RGBColor[
             0.2370504067857524, 0.3664853857686652, 0.9368110420305739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 230}], {
             RGBColor[
             0.242769796479283, 0.37249682696681696`, 0.9371367528125416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 242}], {
             RGBColor[
             0.23389814771920384`, 0.3631721616249542, 0.9366315255400833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 365}], {
             RGBColor[
             0.22016341450609503`, 0.34873608618559426`, 0.9358493528023137]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 374}], {
             RGBColor[
             0.4289188512915289, 0.5328935815484176, 0.9502197435352682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 385}], {
             RGBColor[
             0.2505229762547404, 0.38064591049081276`, 0.9375782849309523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 391}], {
             RGBColor[
             0.2531790712591283, 0.3834376347465744, 0.9377295456121117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 230}], {
             RGBColor[
             0.29273333860863454`, 0.4238393788233762, 0.9400250262238281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 242}], {
             RGBColor[
             0.28386168984855537`, 0.4145147134815134, 0.9395197989513697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 250}], {
             RGBColor[
             0.28289509744206204`, 0.41349876357679066`, 0.9394647529437653]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 339}], {
             RGBColor[
             0.3177193107934676, 0.44961423079758744`, 0.9414657714289726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 365}], {
             RGBColor[
             0.27012695663544656`, 0.4000786380421535, 0.9387376262136001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 88}], {
             RGBColor[
             0.4667369289259683, 0.5759526684510539, 0.9517162151676255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 164}], {
             RGBColor[
             0.35504910378768406`, 0.4819474212392274, 0.9438443928291242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 166}], {
             RGBColor[
             0.3146631445310014, 0.44151991251953804`, 0.9414704846497478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 210}], {
             RGBColor[
             0.32671560372449127`, 0.4541878113019451, 0.9421568543708015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 227}], {
             RGBColor[
             0.3271188137728493, 0.45461161062776295`, 0.9421798165865597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 236}], {
             RGBColor[
             0.32783007255312624`, 0.45535918870224534`, 0.9422203217218834]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 243}], {
             RGBColor[
             0.31942767533965444`, 0.44652773648813343`, 0.941741817630809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 276}], {
             RGBColor[
             0.4288965327811708, 0.5452321301702874, 0.9487372805691687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 326}], {
             RGBColor[
             0.4466397787084002, 0.5596368965381322, 0.9501340938842116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 428}], {
             RGBColor[
             0.3217689577699581, 0.44898857276826243`, 0.9418751502015977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 495}], {
             RGBColor[
             0.3265573982793615, 0.45402152734830914`, 0.9421478448047453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 92}], {
             RGBColor[
             0.3695892159731381, 0.49454133560698005`, 0.944770875920265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 106}], {
             RGBColor[
             0.363218946392579, 0.4890237282753585, 0.9443649679755999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 139}], {
             RGBColor[
             0.37679469277244215`, 0.5007823574527431, 0.9452300025303637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 140}], {
             RGBColor[
             0.33198325689546354`, 0.4619689439843596, 0.9423746574614795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 169}], {
             RGBColor[
             0.30959611123712766`, 0.4425603855333653, 0.9409488251377407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 175}], {
             RGBColor[
             0.2756627903493139, 0.4068943137834642, 0.9390163727130293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 204}], {
             RGBColor[
             0.2660464834000242, 0.39678696547068504`, 0.9384687382583186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 219}], {
             RGBColor[
             0.6307342979616306, 0.7031655720782259, 0.9545668215858762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 255}], {
             RGBColor[
             0.3339687342319978, 0.46368866466027303`, 0.9425011703216748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 274}], {
             RGBColor[
             0.28340249859697586`, 0.4150292378776028, 0.9394571376478613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 334}], {
             RGBColor[
             0.27214321614334747`, 0.4031950181391001, 0.9388159381687429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 337}], {
             RGBColor[
             0.294335011870674, 0.4265200024896363, 0.9400797281055944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 361}], {
             RGBColor[
             0.3074264780735837, 0.4402799635157928, 0.9408252677387614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 363}], {
             RGBColor[
             0.2974372353320738, 0.42978063603989525`, 0.9402563951423928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 369}], {
             RGBColor[
             0.38761374574356555`, 0.5098472907109118, 0.9460039280401971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 370}], {
             RGBColor[
             0.33388624673648354`, 0.46361721813760065`, 0.9424959142914013]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 466}], {
             RGBColor[
             0.3188944133828126, 0.45063204559810455`, 0.9415406479268632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 118}], {
             RGBColor[
             0.5111568234468423, 0.6102849112835397, 0.955947084773634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 141}], {
             RGBColor[
             0.358204994057134, 0.4846808947709679, 0.9440454833664493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 188}], {
             RGBColor[
             0.30148676531190327`, 0.431421157073729, 0.940582786833009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 220}], {
             RGBColor[
             0.3573241663918694, 0.4839179661190015, 0.9439893578065041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 240}], {
             RGBColor[
             0.578125635518976, 0.3010574153834884, 0.5535177212489335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 304}], {
             RGBColor[
             0.3452979346662828, 0.47350144865428023`, 0.9432230569553288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 310}], {
             RGBColor[
             0.3215642329345495, 0.4525238485301015, 0.9417261689121672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 371}], {
             RGBColor[
             0.45086534260416566`, 0.561965981513472, 0.9507710708706651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 382}], {
             RGBColor[
             0.33847148779659625`, 0.46758872348295366`, 0.9427880817971823]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 429}], {
             RGBColor[
             0.31158325168111456`, 0.44203320440197946`, 0.9411577667953226]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 74}], {
             RGBColor[
             0.521921541159367, 0.6227584452674836, 0.955506722063117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 82}], {
             RGBColor[
             0.4245417971530002, 0.5400547692936607, 0.9488481466449648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 105}], {
             RGBColor[
             0.4501903411742621, 0.5622702489915721, 0.9504824491898827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 153}], {
             RGBColor[
             0.4700780350979875, 0.5794959698837422, 0.9517496754607051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 195}], {
             RGBColor[
             0.5609241170200876, 0.654422493397236, 0.9585771477060159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 263}], {
             RGBColor[
             0.4709113662482264, 0.5802177594416376, 0.9518027745847126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 323}], {
             RGBColor[
             0.46995119613448955`, 0.5793861083486719, 0.9517415933941104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 342}], {
             RGBColor[
             0.42121594857204914`, 0.537174086414851, 0.948636226514319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 395}], {
             RGBColor[
             0.41103985510824037`, 0.5268135892265627, 0.9480444389172653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 447}], {
             RGBColor[
             0.730037688972577, 0.6948031838330024, 0.6093471071487886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 453}], {
             RGBColor[
             0.5036934465954336, 0.6079600569341803, 0.9540717396873337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 463}], {
             RGBColor[
             0.7599659793679686, 0.8097227468658681, 0.8868309036641199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 116}], {
             RGBColor[
             0.290226202075678, 0.4159792072535978, 0.9400735617960273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 118}], {
             RGBColor[
             0.44294768587411504`, 0.5413837099925164, 0.9519604857858228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 133}], {
             RGBColor[
             0.2534659406617682, 0.3837391526773195, 0.937745882400207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 151}], {
             RGBColor[
             0.29722255756875515`, 0.4220390987346496, 0.940519363381412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 188}], {
             RGBColor[
             0.23327762773917593`, 0.36251995578270574`, 0.9365961878451978]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 192}], {
             RGBColor[
             0.2503100053844817, 0.38042206460303774`, 0.9375661565549532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 249}], {
             RGBColor[
             0.24204937621038258`, 0.37173961958691937`, 0.937095725943994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 260}], {
             RGBColor[
             0.27268428333461864`, 0.4007852789225642, 0.9389558062455567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 280}], {
             RGBColor[
             0.2688999216349235, 0.39750745502583784`, 0.9387146700644318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 310}], {
             RGBColor[
             0.25335509536182216`, 0.38362264723907824`, 0.9377395699243558]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 327}], {
             RGBColor[
             0.3877636396050008, 0.4972112256965723, 0.9471865478416341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 483}], {
             RGBColor[
             0.23546236437516638`, 0.36481625250743493`, 0.9367206053645892]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 64}], {
             RGBColor[
             0.27811257574438586`, 0.4096443288360715, 0.9391494718067328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 91}], {
             RGBColor[
             0.4727776967118894, 0.5764280337840979, 0.9530749068901088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 172}], {
             RGBColor[
             0.27187887403181193`, 0.40309231309663973`, 0.938794471716137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 303}], {
             RGBColor[
             0.2957531166562469, 0.4281856558093312, 0.9401540745148216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 362}], {
             RGBColor[
             0.31495135328484847`, 0.4454401185782792, 0.9413544513573335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 384}], {
             RGBColor[
             0.36343881876773854`, 0.487437524128683, 0.944444029782121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 435}], {
             RGBColor[
             0.29202151889346295`, 0.42426350996368195`, 0.9399415655426353]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 473}], {
             RGBColor[
             0.2928372445659958, 0.42512088936550885`, 0.939988019912928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 132}], {
             RGBColor[
             0.3139951319729083, 0.44161875909983606`, 0.9414031148825712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 209}], {
             RGBColor[
             0.2849993541284874, 0.41650407370116804`, 0.9395555295582844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 233}], {
             RGBColor[
             0.2779593309045732, 0.40948325879314434`, 0.9391407447398109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 75}], {
             RGBColor[
             0.4356255817999579, 0.5467565837254285, 0.9499814471699208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 149}], {
             RGBColor[
             0.27897070077698005`, 0.41054627265359755`, 0.9391983407578568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 158}], {
             RGBColor[
             0.3186519132267702, 0.448862536764246, 0.9415822957716364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 165}], {
             RGBColor[
             0.354800872127908, 0.48017294806490846`, 0.9438856754675478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 182}], {
             RGBColor[
             0.3519536844558152, 0.477706857207155, 0.9437042551867512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 206}], {
             RGBColor[
             0.27665587734436636`, 0.40811324645763797`, 0.9390665149878439]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 252}], {
             RGBColor[
             0.2921206520638884, 0.4243677052112051, 0.9399472110300366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 275}], {
             RGBColor[
             0.28713653898456953`, 0.41912908635381985`, 0.939663373163504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 282}], {
             RGBColor[
             0.3330488622711529, 0.4613324504147913, 0.9424996566340224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 324}], {
             RGBColor[
             0.31377849534684576`, 0.44464142714176014`, 0.941271765893722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 410}], {
             RGBColor[
             0.26912193539348, 0.40019459578774724`, 0.9386374681392091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 441}], {
             RGBColor[
             0.5904615797902606, 0.6692387078703843, 0.9646062340697246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 467}], {
             RGBColor[
             0.29426118916721444`, 0.4266175454246919, 0.9400691114514301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 91}], {
             RGBColor[
             0.46136022975987245`, 0.5644275521083123, 0.9524246990378201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 172}], {
             RGBColor[
             0.26046140707979504`, 0.39109183142085413`, 0.9381442638638484]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 303}], {
             RGBColor[
             0.28433564970423, 0.41618517413354567`, 0.939503866662533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 366}], {
             RGBColor[
             0.4325163267328157, 0.5412201232910389, 0.9500108668676096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 384}], {
             RGBColor[
             0.3520213518157216, 0.4754370424528974, 0.9437938219298323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 435}], {
             RGBColor[
             0.280604051941446, 0.4122630282878964, 0.9392913576903467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 473}], {
             RGBColor[
             0.28141977761397885`, 0.41312040768972325`, 0.9393378120606395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 88}], {
             RGBColor[
             0.41078222445821744`, 0.5236821078734536, 0.9482901655034162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 166}], {
             RGBColor[
             0.25870844006325056`, 0.3892493519419377, 0.9380444349855384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 167}], {
             RGBColor[
             0.44905203715227315`, 0.5547512658539029, 0.9513029053456352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 175}], {
             RGBColor[
             0.2541362946886586, 0.3844437372624815, 0.9377840580703384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[
             0.2707608992567404, 0.40191725072434475`, 0.9387308047065921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 227}], {
             RGBColor[
             0.2711641093050984, 0.40234105005016263`, 0.9387537669223502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 309}], {
             RGBColor[
             0.2614464416180461, 0.392127165175353, 0.9382003601235738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 320}], {
             RGBColor[
             0.27588176019991395`, 0.40729960025695666`, 0.939022430161671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 337}], {
             RGBColor[
             0.2728085162100188, 0.4040694259686536, 0.9388474134629035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 348}], {
             RGBColor[
             0.3553802673769295, 0.47842885056261164`, 0.9440048289058678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 428}], {
             RGBColor[
             0.2658142533022072, 0.39671801219066216`, 0.9384491005373883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 434}], {
             RGBColor[
             0.5254823198709788, 0.6146405905879208, 0.9587967327007443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 474}], {
             RGBColor[
             0.24320787132901925`, 0.37295727140943946`, 0.9371617005271604]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 495}], {
             RGBColor[
             0.2706026938116106, 0.4017509667707088, 0.938721795140536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 208}], {
             RGBColor[
             0.9291557773080821, 0.946330882048684, 0.9925248693322104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 305}], {
             RGBColor[
             0.5880207431382927, 0.6606562628294723, 0.9647961950303805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 314}], {
             RGBColor[
             0.5885072488706664, 0.661167611200442, 0.9648239008121184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 394}], {
             RGBColor[
             0.6111099194182043, 0.6849244510379885, 0.9661110894621461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 398}], {
             RGBColor[
             0.574509590883247, 0.6464551851528881, 0.9640267548974142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 427}], {
             RGBColor[
             0.7347939368756264, 0.7919981082007538, 0.9745142882045359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 445}], {
             RGBColor[
             0.6101598285776131, 0.6839258453252886, 0.9660569831943079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 460}], {
             RGBColor[
             0.5811756149797052, 0.6534615991286046, 0.9644063751082086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 472}], {
             RGBColor[
             0.5981675854956696, 0.6713212374940387, 0.965374042691725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 70}], {
             RGBColor[
             0.3392830550449261, 0.465299677941858, 0.9429493453464637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 96}], {
             RGBColor[
             0.31924461933102855`, 0.44423801149634623`, 0.9418081860767664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 131}], {
             RGBColor[
             0.42312847869663106`, 0.540914354016482, 0.9481823503980948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 135}], {
             RGBColor[
             0.42203374976672503`, 0.5399661548400733, 0.9481125952387119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 147}], {
             RGBColor[
             0.327391734264632, 0.45280114584848513`, 0.9422721522196587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 171}], {
             RGBColor[
             0.3405756745678454, 0.4666583030172575, 0.9430229581160348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 180}], {
             RGBColor[
             0.3712768261018824, 0.49600305867874694`, 0.9448784089453734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 216}], {
             RGBColor[
             0.3713081886530782, 0.49603022334426516`, 0.9448804073394029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 238}], {
             RGBColor[
             0.29605830464663824`, 0.41986772466579225`, 0.9404877597565691]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 281}], {
             RGBColor[
             0.34767204988366923`, 0.4741170434103705, 0.9434270861921245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 343}], {
             RGBColor[
             0.41938101623319624`, 0.5376684903835948, 0.9479435654036756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 385}], {
             RGBColor[
             0.34086430373362, 0.46696167057063265`, 0.9430393951200371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 391}], {
             RGBColor[
             0.3435203987380079, 0.46975339482639433`, 0.9431906558011964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 465}], {
             RGBColor[
             0.38908777308068965`, 0.5114300057475654, 0.9460133067372611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 205}], {
             RGBColor[
             0.205979882097505, 0.333828294336271, 0.9350416216143004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 257}], {
             RGBColor[
             0.4087137818480049, 0.511398273793923, 0.9490926248801159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 272}], {
             RGBColor[
             0.22754358834335253`, 0.3564931168185995, 0.9362696427843568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 306}], {
             RGBColor[
             0.20271872726201295`, 0.33040061383500985`, 0.9348559036708652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 317}], {
             RGBColor[
             0.24450216183039622`, 0.3741945628203528, 0.9372399153832112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 142}], {
             RGBColor[
             0.6253364720418517, 0.701815861320964, 0.9663980725076264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 173}], {
             RGBColor[
             0.38813069296793135`, 0.5106010310581394, 0.9459523224387889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 194}], {
             RGBColor[
             0.3612245737960048, 0.48729630297228727`, 0.9442378883173007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 241}], {
             RGBColor[
             0.6900832026301509, 0.7498480252975406, 0.8192692287835854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 388}], {
             RGBColor[
             0.34576475623465375`, 0.4736817451463171, 0.9432610056472487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 402}], {
             RGBColor[
             0.35431734238865575`, 0.4813136062947864, 0.9437977656398493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 461}], {
             RGBColor[
             0.31314865580075885`, 0.43940015561008516`, 0.941403566978735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 487}], {
             RGBColor[
             0.45297918778833307`, 0.5649385556885385, 0.950590317023552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 490}], {
             RGBColor[
             0.35348975024349605`, 0.48059678757463975`, 0.9437450322001708]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 84}], {
             RGBColor[
             0.34637960405070783`, 0.4714463520077421, 0.9434015311738803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 96}], {
             RGBColor[
             0.25634668604548416`, 0.3867669987254117, 0.9379099365881286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 131}], {
             RGBColor[
             0.3602305454110867, 0.48344334124554744`, 0.9442841009094571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 135}], {
             RGBColor[
             0.3591358164811806, 0.4824951420691387, 0.9442143457500742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 147}], {
             RGBColor[
             0.26449380097908753`, 0.3953301330775506, 0.9383739027310208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 170}], {
             RGBColor[
             0.25960938449211335`, 0.39019630165984864`, 0.9380957424379344]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 171}], {
             RGBColor[
             0.27767774128230094`, 0.40918729024632294`, 0.939124708627397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 216}], {
             RGBColor[
             0.30841025536753375`, 0.4385592105733306, 0.9409821578507651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[
             0.2331603713610938, 0.36239671189485767`, 0.9365895102679312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 265}], {
             RGBColor[
             0.35409161874420736`, 0.47812611151812245`, 0.9438929339306832]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 374}], {
             RGBColor[
             0.45636224548486404`, 0.561738328857303, 0.9517826042357151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 385}], {
             RGBColor[
             0.27796637044807554`, 0.4094906577996981, 0.9391411456313993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 391}], {
             RGBColor[
             0.28062246545246344`, 0.41228238205545975`, 0.9392924063125587]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 433}], {
             RGBColor[
             0.4792822929216612, 0.5797358571800171, 0.9540040137871595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 194}], {
             RGBColor[
             0.3422208933144379, 0.4708362700919073, 0.9430269906013101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 228}], {
             RGBColor[
             0.5291334026562579, 0.6246794631010963, 0.9575902151557317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 388}], {
             RGBColor[
             0.3267610757530868, 0.4572217122659371, 0.9420501079312581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 431}], {
             RGBColor[
             0.3976404501344445, 0.5188379047414802, 0.946558275756291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 462}], {
             RGBColor[
             0.3747041151886054, 0.4989716042251083, 0.9450967927753469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 487}], {
             RGBColor[
             0.43397550730676615`, 0.5484785228081585, 0.9493794193075614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 490}], {
             RGBColor[
             0.3344860697619291, 0.46413675469425975`, 0.9425341344841802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 73}], {
             RGBColor[
             0.27241873231020286`, 0.4002549960363254, 0.9389498801420488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 144}], {
             RGBColor[
             0.24230839667857737`, 0.37201186652183826`, 0.9371104767764713]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 163}], {
             RGBColor[
             0.21859083096519344`, 0.34708320117655134`, 0.9357597964960882]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 187}], {
             RGBColor[
             0.3074146521959259, 0.43056670289526167`, 0.9411797892114901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 279}], {
             RGBColor[
             0.24176185575261663`, 0.37143741735595737`, 0.9370793520792726]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 322}], {
             RGBColor[
             0.22130865726800683`, 0.34993980894094856`, 0.9359145726833697]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 494}], {
             RGBColor[
             0.2559559018970738, 0.3859957197783887, 0.9379008831456335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 93}], {
             RGBColor[
             0.3752774524960066, 0.4994682001840082, 0.9451333253215921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 163}], {
             RGBColor[
             0.29174330935666726`, 0.4205663517611113, 0.9400503862166951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 187}], {
             RGBColor[
             0.38056713058739966`, 0.5040498534798217, 0.9454703789320971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 322}], {
             RGBColor[
             0.2944611356594806, 0.4234229595255085, 0.9402051624039767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 494}], {
             RGBColor[
             0.3291083802885476, 0.45947887036294865`, 0.9421914728662404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 82}], {
             RGBColor[
             0.41640315745637213`, 0.5334474549463979, 0.9482074431152268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 105}], {
             RGBColor[
             0.442051701477634, 0.5556629346443093, 0.9498417456601446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 112}], {
             RGBColor[
             0.3765261778048241, 0.4924844380805954, 0.9459017160141922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 153}], {
             RGBColor[
             0.4619393954013594, 0.5728886555364794, 0.9511089719309671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 195}], {
             RGBColor[
             0.5527854773234595, 0.6478151790499731, 0.9579364441762778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 224}], {
             RGBColor[
             0.6976226433705784, 0.7622346632774594, 0.9717109409018184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 234}], {
             RGBColor[
             0.41584579628194185`, 0.5329646967108936, 0.9481719285540471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 239}], {
             RGBColor[
             0.42163081433430444`, 0.5379753885843884, 0.9485405447888531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 263}], {
             RGBColor[
             0.4627727265515983, 0.5736104450943749, 0.9511620710549745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 296}], {
             RGBColor[
             0.4174603392246644, 0.534363132658592, 0.9482748058026731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 342}], {
             RGBColor[
             0.41307730887542105`, 0.5305667720675882, 0.9479955229845809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 395}], {
             RGBColor[
             0.4029012154116123, 0.5202062748792999, 0.9474037353875272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 440}], {
             RGBColor[
             0.3966896045859903, 0.5136774780626979, 0.9470499933402627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 447}], {
             RGBColor[
             0.721899049275949, 0.6881958694857397, 0.6087064036190506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 453}], {
             RGBColor[
             0.4955548068988055, 0.6013527425869175, 0.9534310361575956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 463}], {
             RGBColor[
             0.7518273396713405, 0.8031154325186052, 0.8861902001343818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 93}], {
             RGBColor[
             0.492177918087564, 0.5972988424017914, 0.9535278122906179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 108}], {
             RGBColor[
             0.6335260492516934, 0.7126697534094633, 0.9647673066040147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 149}], {
             RGBColor[
             0.4227172608618136, 0.5331891199846208, 0.9492463373886431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 158}], {
             RGBColor[
             0.4623984733116038, 0.5715053840952693, 0.9516302924024227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.4086437749482247, 0.5183969939788945, 0.9484448731857209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 182}], {
             RGBColor[
             0.49570024454064876`, 0.6003497045381783, 0.9537522518175374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 206}], {
             RGBColor[
             0.4204024374291999, 0.5307560937886613, 0.9491145116186301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 410}], {
             RGBColor[
             0.41286849547831356`, 0.5228374431187706, 0.9486854647699954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.27428566057636106`, 0.40529682112602405`, 0.9389434409805653]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[
             0.32760891462893016`, 0.45818010857392344`, 0.942095928240335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 238}], {
             RGBColor[
             0.25109934589197075`, 0.3809265342954701, 0.9376230146603679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 333}], {
             RGBColor[
             0.5664666283245456, 0.652366227962671, 0.9619377768297674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 343}], {
             RGBColor[
             0.3744220574785287, 0.4987273000132726, 0.9450788203074745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 392}], {
             RGBColor[
             0.2981302709474612, 0.43035901846166735`, 0.9403013562662594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 402}], {
             RGBColor[
             0.3178455243188919, 0.4497235506096337, 0.9414738136432064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 431}], {
             RGBColor[
             0.3801723125462475, 0.5037078819367073, 0.9454452214756387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 436}], {
             RGBColor[
             0.27261665353967546`, 0.4035425889093095, 0.9388483934989006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 459}], {
             RGBColor[
             0.28353126567922415`, 0.41501453829435436`, 0.9394699645135263]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 462}], {
             RGBColor[
             0.3572359776004085, 0.4838415814203355, 0.9439837384946945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 487}], {
             RGBColor[
             0.41650736971856916`, 0.5333485000033857, 0.9482663650269091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 81}], {
             RGBColor[
             0.24891877333776088`, 0.3789597915127277, 0.9374869279480358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 156}], {
             RGBColor[
             0.30500936855727045`, 0.4318508321999468, 0.9409032272717186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 278}], {
             RGBColor[
             0.2703917768774402, 0.40152927969998975`, 0.9387097837331586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 329}], {
             RGBColor[
             0.3024027230888186, 0.42959308690898446`, 0.9407371341274349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 479}], {
             RGBColor[
             0.2736697344981096, 0.40470601635370973`, 0.9389062935020192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 482}], {
             RGBColor[
             0.26473982406433677`, 0.395588718938912, 0.9383879133817672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 85}], {
             RGBColor[
             0.24969954876511535`, 0.3797804359908985, 0.9375313919535699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 95}], {
             RGBColor[
             0.24377004958662993`, 0.3735481564023485, 0.9371937157472632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 97}], {
             RGBColor[
             0.40018278094990445`, 0.506128381047741, 0.9482702976333264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 137}], {
             RGBColor[
             0.2876984789004807, 0.4128890824740201, 0.9399454779414855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 145}], {
             RGBColor[
             0.29641666507638903`, 0.4204403371508138, 0.940500993055425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 183}], {
             RGBColor[
             0.25652721156879005`, 0.38589009742476, 0.9379592723507795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 346}], {
             RGBColor[
             0.37663819934672765`, 0.4870138290309683, 0.9464167819228801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 358}], {
             RGBColor[
             0.2531642928743813, 0.3829773062768713, 0.9377449901452841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 404}], {
             RGBColor[
             0.3998944908045995, 0.5058943341204596, 0.9482476023770464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 407}], {
             RGBColor[
             0.20657777419938345`, 0.334456716843894, 0.9350756706850003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 408}], {
             RGBColor[
             0.22457514006089435`, 0.3533730894632443, 0.9361005940460965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 430}], {
             RGBColor[
             0.24712674009351965`, 0.37707625095156, 0.9373848743058519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 81}], {
             RGBColor[
             0.2800251437031319, 0.4116545590245261, 0.9392583897225926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 99}], {
             RGBColor[
             0.34447784948773547`, 0.471788439591332, 0.9432075153371591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 122}], {
             RGBColor[
             0.30406034734039167`, 0.4367808306740275, 0.9406321478401243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 267}], {
             RGBColor[
             0.27534122401871575`, 0.406731462458544, 0.9389916474258033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 278}], {
             RGBColor[
             0.3014981472428113, 0.4342240472117881, 0.9404812455077154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 329}], {
             RGBColor[
             0.33350909345418966`, 0.4622878544207828, 0.9425085959019917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 406}], {
             RGBColor[
             0.31066449890845993`, 0.44250101482797904`, 0.9410529585382197]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 413}], {
             RGBColor[
             0.27218696559506017`, 0.403416136863747, 0.9388120170748833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 476}], {
             RGBColor[
             0.27788554706565816`, 0.40940570730027903`, 0.9391365428593381]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 486}], {
             RGBColor[
             0.43342549778997264`, 0.5456907426727773, 0.9497426835621203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 493}], {
             RGBColor[
             0.3573553304089039, 0.4829422663242376, 0.9440280570343467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 156}], {
             RGBColor[
             0.331624452594818, 0.45982497301720227`, 0.9424189169341686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 278}], {
             RGBColor[
             0.29700686091498774`, 0.4295034205172452, 0.9402254733956086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 307}], {
             RGBColor[
             0.250838751344099, 0.3809778101310257, 0.9375962678551439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 329}], {
             RGBColor[
             0.32901780712636614`, 0.4575672277262399, 0.9422528237898848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 372}], {
             RGBColor[
             0.41816792013425164`, 0.5322295556623502, 0.9486393495584569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 406}], {
             RGBColor[
             0.3061732125806364, 0.4377803881334361, 0.9407971864261129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 417}], {
             RGBColor[
             0.3774558445942924, 0.4991776586809089, 0.9454343458387047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 461}], {
             RGBColor[
             0.2650045259927395, 0.3958669374487349, 0.9384029877649984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 486}], {
             RGBColor[
             0.42893421146214905`, 0.5409701159782344, 0.9494869114500135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 493}], {
             RGBColor[
             0.35286404408108035`, 0.47822163962969466`, 0.9437722849222399]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 83}], {
             RGBColor[
             0.28175274359074914`, 0.4134703760425711, 0.9393567739804374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 99}], {
             RGBColor[
             0.3266019731905958, 0.45299976020701915`, 0.9421895106270262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 237}], {
             RGBColor[
             0.27208430199858474`, 0.4033082309146033, 0.9388061705349413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[
             0.25746534772157614`, 0.38794278307423113`, 0.9379736427156704]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 278}], {
             RGBColor[
             0.28362227094567166`, 0.41543536782747525`, 0.9394632407975825]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 329}], {
             RGBColor[
             0.31563321715705006`, 0.44349917503646996`, 0.9414905911918587]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 426}], {
             RGBColor[
             0.33225721799808206`, 0.45789804901839504`, 0.9425498578254226]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 486}], {
             RGBColor[
             0.415549621492833, 0.5269020632884645, 0.9487246788519874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 89}], {
             RGBColor[
             0.3055098740032732, 0.4374904093006864, 0.9407444995144895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 105}], {
             RGBColor[
             0.3446719574712672, 0.4729592586704864, 0.9431831702419924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 184}], {
             RGBColor[
             0.2931176425762863, 0.42446538835807013`, 0.9400387802673861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 195}], {
             RGBColor[
             0.4554057333170928, 0.5651115030761502, 0.9512778687581256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 225}], {
             RGBColor[
             0.40287551934227545`, 0.5224651089122221, 0.9471424978895138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 263}], {
             RGBColor[
             0.3653929825452315, 0.4909067691205519, 0.9445034956368223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 296}], {
             RGBColor[
             0.3200805952182977, 0.4516594566847692, 0.9416162303845209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 342}], {
             RGBColor[
             0.31569756486905426`, 0.4478630960937653, 0.9413369475664287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 395}], {
             RGBColor[
             0.3055214714052455, 0.43750259890547705`, 0.940745159969375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 440}], {
             RGBColor[
             0.2993098605796235, 0.43097380208887504`, 0.9403914179221106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 447}], {
             RGBColor[
             0.6245193052695821, 0.6054921935119169, 0.6020478282008983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 453}], {
             RGBColor[
             0.39817506289243876`, 0.5186490666130946, 0.9467724607394434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 463}], {
             RGBColor[
             0.6544475956649738, 0.7204117565447823, 0.8795316247162296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 470}], {
             RGBColor[
             0.33520888894329015`, 0.4647628243392063, 0.9425801918832526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 119}], {
             RGBColor[
             0.26669021868264475`, 0.39763870734491497`, 0.9384989854699296]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 176}], {
             RGBColor[
             0.5456045272402572, 0.6349165885555719, 0.9600809849917796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[
             0.2788673793562445, 0.410437675289448, 0.9391924567557963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 237}], {
             RGBColor[
             0.2916877781833416, 0.4239127273169612, 0.939922559502919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 270}], {
             RGBColor[
             0.34659069129673375`, 0.4739379337988554, 0.9433304468695782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 345}], {
             RGBColor[
             0.3386350927546853, 0.4670471942017421, 0.9428235231653386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 375}], {
             RGBColor[
             0.41367779680147115`, 0.5300719429883098, 0.948150453468378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 426}], {
             RGBColor[
             0.35186069418283894`, 0.47850254542075293`, 0.9436662467934003]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 448}], {
             RGBColor[
             0.41616829005972333`, 0.5320938376108015, 0.9483465142206449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 489}], {
             RGBColor[
             0.2601937118426736, 0.3908104667537812, 0.9381290190161138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 131}], {
             RGBColor[
             0.4302250277024128, 0.5470610280823661, 0.9486345362255113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 135}], {
             RGBColor[
             0.42913029877250675`, 0.5461128289059574, 0.9485647810661285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 147}], {
             RGBColor[
             0.3344882832704137, 0.4589478199143692, 0.9427243380470751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 171}], {
             RGBColor[
             0.3476722235736271, 0.4728049770831416, 0.9434751439434512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 230}], {
             RGBColor[
             0.3402076729639443, 0.46495926111252095`, 0.9430500488290429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 242}], {
             RGBColor[
             0.3313360242038651, 0.45563459577065824`, 0.9425448215565846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 365}], {
             RGBColor[
             0.3176012909907563, 0.44119852033129825`, 0.9417626488188149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 374}], {
             RGBColor[
             0.5263567277761902, 0.6253560156941216, 0.9561330395517694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 385}], {
             RGBColor[
             0.3479608527394017, 0.47310834463651674`, 0.9434915809474536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 391}], {
             RGBColor[
             0.3506169477437896, 0.4759000688922784, 0.943642841628613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 95}], {
             RGBColor[
             0.30069785716693964`, 0.4333828916007254, 0.9404356701718175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 97}], {
             RGBColor[
             0.45711058853021413`, 0.5659631162461181, 0.9515122520578807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 137}], {
             RGBColor[
             0.3446262864807904, 0.472723817672397, 0.9431874323660399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 145}], {
             RGBColor[
             0.3533444726566987, 0.48027507234919076`, 0.9437429474799794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 183}], {
             RGBColor[
             0.31345501914909973`, 0.4457248326231369, 0.9412012267753339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 286}], {
             RGBColor[
             0.272236410742538, 0.40346810684874956`, 0.9388148329028847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 346}], {
             RGBColor[
             0.43356600692703734`, 0.5468485642293452, 0.9496587363474345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 358}], {
             RGBColor[
             0.310092100454691, 0.4428120414752482, 0.9409869445698384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 404}], {
             RGBColor[
             0.4568222983849092, 0.5657290693188365, 0.9514895568016009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 407}], {
             RGBColor[
             0.26350558177969313`, 0.3942914520422709, 0.9383176251095546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 408}], {
             RGBColor[
             0.28150294764120404`, 0.4132078246616212, 0.9393425484706508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 90}], {
             RGBColor[
             0.3112350653982756, 0.43618902142472016`, 0.9413385224659996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 98}], {
             RGBColor[
             0.43920615091719817`, 0.5541093448638095, 0.9494086947213694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 115}], {
             RGBColor[
             0.35821355536653343`, 0.48468831014686575`, 0.9440460288855138]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 124}], {
             RGBColor[
             0.39930648634218946`, 0.5202809415672143, 0.9466644341102306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 136}], {
             RGBColor[
             0.374598330506573, 0.4988799788504245, 0.9450900522689494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 168}], {
             RGBColor[
             0.32002910739183144`, 0.4454321171344137, 0.9418393301479133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[
             0.4184583857088132, 0.5368693541961327, 0.9478847762025122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 253}], {
             RGBColor[
             0.3418845582428895, 0.4684035816944948, 0.943083965741639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 261}], {
             RGBColor[
             0.5903040394621039, 0.6746317976286214, 0.9627706461358841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 357}], {
             RGBColor[
             0.49751158346613467`, 0.6014443216368397, 0.9539987119514586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 484}], {
             RGBColor[
             0.3684574834631169, 0.4935610857893296, 0.9446987629254782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 500}], {
             RGBColor[
             0.3750890828079514, 0.4993050438279506, 0.945121322571638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 107}], {
             RGBColor[
             0.3413949253154085, 0.47012085812550675`, 0.9429743606507868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 113}], {
             RGBColor[
             0.34166850542003135`, 0.4703578194615953, 0.942991792933136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 143}], {
             RGBColor[
             0.37914064970717265`, 0.5028143074383826, 0.9453794848317965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 226}], {
             RGBColor[
             0.32955618478129156`, 0.4581227163959992, 0.9422838636774609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 292}], {
             RGBColor[
             0.35424954154245547`, 0.48125488060957733`, 0.9437934454298834]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 308}], {
             RGBColor[
             0.3852872860002653, 0.5081382148565367, 0.9457711430611353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 386}], {
             RGBColor[
             0.3211514786047991, 0.44928883731535585`, 0.9418052280943582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 421}], {
             RGBColor[
             0.29485256312401126`, 0.42164700969749913`, 0.9403075437634862]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 422}], {
             RGBColor[
             0.3483319950369491, 0.4761293992510431, 0.9434163845992334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 423}], {
             RGBColor[
             0.4858682264490677, 0.5912055386406111, 0.9532993284557889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 446}], {
             RGBColor[
             0.4665832209481138, 0.5755491023953394, 0.951781142179451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 166}], {
             RGBColor[
             0.40190341750290814`, 0.5143499188145482, 0.947784530582329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 167}], {
             RGBColor[
             0.5922470145919307, 0.6798518327265133, 0.9610430009424258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 210}], {
             RGBColor[
             0.413955876696398, 0.5270178175969552, 0.9484709003033828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 227}], {
             RGBColor[
             0.41435908674475597`, 0.5274416169227731, 0.9484938625191409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 243}], {
             RGBColor[
             0.40666794831156117`, 0.5193577427831435, 0.9480558635633902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 326}], {
             RGBColor[
             0.5338800516803069, 0.6324669028331424, 0.9564481398167928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 348}], {
             RGBColor[
             0.4985752448165871, 0.6035294174352221, 0.9537449245026584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 428}], {
             RGBColor[
             0.4090092307418648, 0.5218185790632726, 0.948189196134179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 434}], {
             RGBColor[
             0.6686772973106363, 0.7397411574605313, 0.9685368282975348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 469}], {
             RGBColor[
             0.47845988043843396`, 0.5861064998384764, 0.9524631912718008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 474}], {
             RGBColor[
             0.3864028487686768, 0.49805783828204986`, 0.946901796123951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 495}], {
             RGBColor[
             0.4137976712512682, 0.5268515336433193, 0.9484618907373266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 133}], {
             RGBColor[
             0.2982071099937901, 0.4307649583992533, 0.940293825805037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 184}], {
             RGBColor[
             0.27960410312955414`, 0.4112120186861815, 0.9392344120848011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 192}], {
             RGBColor[
             0.2950511747165036, 0.42744787032497156`, 0.9401140999597832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 225}], {
             RGBColor[
             0.3893619798955433, 0.5092117392403335, 0.9463381297069289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 235}], {
             RGBColor[
             0.2672477464810746, 0.3982247044103687, 0.9385307358532617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 239}], {
             RGBColor[
             0.3107375308812055, 0.4420183429386769, 0.9410776011881159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 249}], {
             RGBColor[
             0.28679054554240446`, 0.4187654253088531, 0.9396436693488242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 260}], {
             RGBColor[
             0.31742545266664046`, 0.4478110846444979, 0.9415037496503867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.31364109096694537`, 0.44453326074777155`, 0.9412626134692619]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 296}], {
             RGBColor[
             0.3065670557715655, 0.43840608701288064`, 0.9408118622019359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 424}], {
             RGBColor[
             0.2833628965267994, 0.41516274886795246`, 0.9394484698081377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 440}], {
             RGBColor[
             0.28579632113289133`, 0.4177204324169864, 0.9395870497395256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 453}], {
             RGBColor[
             0.3846615234457066, 0.505395696941206, 0.9459680925568583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 470}], {
             RGBColor[
             0.321695349496558, 0.45150945466731773`, 0.9417758237006675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 124}], {
             RGBColor[
             0.31235766061209774`, 0.43716135697565683`, 0.9414100532403524]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 178}], {
             RGBColor[
             0.33150955997872156`, 0.45374976960457536`, 0.942630395332634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[
             0.43139340168209683`, 0.5352359922105044, 0.9503841956781767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 261}], {
             RGBColor[
             0.5033552137320122, 0.5915122130370639, 0.957516265266006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 272}], {
             RGBColor[
             0.2502232081774445, 0.38033083523518085`, 0.9375612135824174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 306}], {
             RGBColor[
             0.22539834709610493`, 0.35423833225159124`, 0.936147474468926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 317}], {
             RGBColor[
             0.2671817816644882, 0.3980322812369342, 0.9385314861812719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 357}], {
             RGBColor[
             0.410562757736043, 0.5183247370452823, 0.9487443310815804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 172}], {
             RGBColor[
             0.45512652804729853`, 0.5578755363688805, 0.9520696989472244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 303}], {
             RGBColor[
             0.47900077067173347`, 0.5829688790815721, 0.953429301745909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 366}], {
             RGBColor[
             0.6271814477003193, 0.7080038282390653, 0.9639363019509856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 435}], {
             RGBColor[
             0.47526917290894954`, 0.5790467332359228, 0.9532167927737226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 473}], {
             RGBColor[
             0.4760848985814824, 0.5799041126377497, 0.9532632471440154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 101}], {
             RGBColor[
             0.3542217819950403, 0.4785643234214305, 0.9438893107288805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 128}], {
             RGBColor[
             0.366223070589308, 0.4911784386596518, 0.9445727663600085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 140}], {
             RGBColor[
             0.39093223452873116`, 0.5130275855485311, 0.9461308341897372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 169}], {
             RGBColor[
             0.3685450888703953, 0.49361902709753686`, 0.9447050018659984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 175}], {
             RGBColor[
             0.3346117679825815, 0.45795295534763575`, 0.942772549441287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 204}], {
             RGBColor[
             0.32499546103329185`, 0.4478456070348566, 0.9422249149865762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 219}], {
             RGBColor[
             0.6896832755948983, 0.7542242136423976, 0.9583229983141339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 274}], {
             RGBColor[
             0.34235147623024353`, 0.46608787944177443`, 0.943213314376119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 320}], {
             RGBColor[
             0.35635723349383686`, 0.48080881834211087`, 0.9440109215326196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 334}], {
             RGBColor[
             0.33109219377661514`, 0.4542536597032717, 0.9425721148970005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 337}], {
             RGBColor[
             0.3532839895039417, 0.4775786440538078, 0.943835904833852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 361}], {
             RGBColor[
             0.36637545570685137`, 0.49133860507996435`, 0.9445814444670191]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 363}], {
             RGBColor[
             0.35638621296534145`, 0.4808392776040668, 0.9440125718706505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 370}], {
             RGBColor[
             0.39283522436975116`, 0.5146758597017722, 0.946252091019659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 498}], {
             RGBColor[
             0.34484597861853394`, 0.468709759612454, 0.9433553725968467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 108}], {
             RGBColor[
             0.546331825454466, 0.6405691647548029, 0.9582656750939254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 163}], {
             RGBColor[
             0.3214495511509972, 0.4462964053242341, 0.9419432416756316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 187}], {
             RGBColor[
             0.4102733723817296, 0.5297799070429444, 0.9473632343910334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 189}], {
             RGBColor[
             0.3274066636991389, 0.4525577083150817, 0.94228249042249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 206}], {
             RGBColor[
             0.3332082136319725, 0.4586555051340009, 0.9426128801085408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 266}], {
             RGBColor[
             0.3154935810823781, 0.44003630315180225`, 0.9416040579912919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 322}], {
             RGBColor[
             0.3241673774538106, 0.4491530130886313, 0.942098017862913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 364}], {
             RGBColor[
             0.6609117357471124, 0.7308627107047385, 0.9694781856372042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 437}], {
             RGBColor[
             0.33633501871539867`, 0.46194197552757454`, 0.9427909470323483]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 100}], {
             RGBColor[
             0.6845780371883443, 0.745079727689508, 0.8189184445096602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 127}], {
             RGBColor[
             0.9184004336535858, 0.9341764712610934, 0.8387746026116247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 168}], {
             RGBColor[
             0.618417010977467, 0.6815916287525886, 0.8149291029455674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 213}], {
             RGBColor[
             0.6589703522467648, 0.7228996380727806, 0.8172867454691695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 214}], {
             RGBColor[
             0.5929231359762033, 0.6547959497212261, 0.8134772644790538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 254}], {
             RGBColor[
             0.6449605053150302, 0.7094905242561114, 0.8164407156805107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 302}], {
             RGBColor[
             0.6560146202086394, 0.7203395315407682, 0.8170984088373514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 315}], {
             RGBColor[0.6155454257518824, 0.67857341061148, 0.8147655704151]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 325}], {
             RGBColor[
             0.630917506995532, 0.6947304426447993, 0.8156409877009696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 368}], {
             RGBColor[
             0.6417992528163612, 0.7061678474450253, 0.8162606870273654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 401}], {
             RGBColor[
             0.62239466570379, 0.6857723960678298, 0.8151556244978186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 477}], {
             RGBColor[
             0.6809168976768599, 0.7419086326588826, 0.818685159937407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 500}], {
             RGBColor[
             0.673476986393587, 0.7354645554461255, 0.818211095369292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 97}], {
             RGBColor[
             0.45118108935172874`, 0.559730836657568, 0.951174575851574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 137}], {
             RGBColor[
             0.338696787302305, 0.466491538083847, 0.9428497561597331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 145}], {
             RGBColor[
             0.34741497347821326`, 0.47404279276064065`, 0.9434052712736726]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 174}], {
             RGBColor[
             0.34425128879280664`, 0.4713025680975572, 0.943203684083055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 286}], {
             RGBColor[
             0.26630691156405256`, 0.39723582726019957`, 0.9384771566965778]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 294}], {
             RGBColor[
             0.33452734996342315`, 0.4628801810229215, 0.9425840832993881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 346}], {
             RGBColor[
             0.4276365077485519, 0.5406162846407951, 0.9493210601411277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 358}], {
             RGBColor[
             0.30416260127620554`, 0.4365797618866982, 0.9406492683635317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 404}], {
             RGBColor[
             0.4508927992064238, 0.5594967897302864, 0.951151880595294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 407}], {
             RGBColor[
             0.2575760826012077, 0.38805917245372085`, 0.9379799489032479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 408}], {
             RGBColor[
             0.2755734484627186, 0.4069755450730712, 0.939004872264344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 430}], {
             RGBColor[
             0.29812504849534394`, 0.43067870656138685`, 0.9402891525240995]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 131}], {
             RGBColor[
             0.3401921096971891, 0.46238167480003567`, 0.9431429416397596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 147}], {
             RGBColor[
             0.24445536526519, 0.37426846663203883`, 0.9372327434613235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.2896315043841557, 0.4185886197277993, 0.939921264578201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 171}], {
             RGBColor[
             0.2576393055684034, 0.38812562380081117`, 0.9379835493576996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 180}], {
             RGBColor[
             0.2883404571024404, 0.41747037946230064`, 0.9398390001870384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 216}], {
             RGBColor[
             0.28837181965363623`, 0.4174975441278188, 0.9398409985810678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 238}], {
             RGBColor[
             0.21312193564719628`, 0.3413350454493459, 0.9354483509982339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 265}], {
             RGBColor[
             0.3340531830303098, 0.4570644450726107, 0.9427517746609859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 281}], {
             RGBColor[
             0.2647356808842273, 0.3955843641939242, 0.9383876774337894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 343}], {
             RGBColor[
             0.3364446472337542, 0.4591358111671484, 0.9429041566453406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 392}], {
             RGBColor[
             0.26015286070268673`, 0.3907675296155432, 0.9381266926041254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 433}], {
             RGBColor[
             0.4592438572077636, 0.5586741907345053, 0.9528628545174622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 465}], {
             RGBColor[
             0.30615140408124764`, 0.4328973265311191, 0.9409738979789259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 104}], {
             RGBColor[
             0.47817100641581745`, 0.5844004747728756, 0.9528470310233796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 137}], {
             RGBColor[
             0.4951095186655795, 0.5990717627292397, 0.9539263380457963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 145}], {
             RGBColor[
             0.5038277048414879, 0.6066230174060333, 0.9544818531597358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 174}], {
             RGBColor[
             0.5006640201560811, 0.6038827927429498, 0.9542802659691182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 294}], {
             RGBColor[
             0.4909400813266977, 0.5954604056683142, 0.9536606651854513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 346}], {
             RGBColor[
             0.5840492391118264, 0.6731965092861878, 0.9603976420271909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 358}], {
             RGBColor[
             0.4605753326394801, 0.5691599865320909, 0.9517258502495949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 404}], {
             RGBColor[
             0.6073055305696983, 0.692077014375679, 0.9622284624813572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 407}], {
             RGBColor[
             0.4139888139644822, 0.5206393970991134, 0.9490565307893111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 408}], {
             RGBColor[
             0.43198617982599313`, 0.5395557697184639, 0.9500814541504072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 430}], {
             RGBColor[
             0.45453777985861843`, 0.5632589312067795, 0.9513657344101627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 115}], {
             RGBColor[
             0.3992358151553642, 0.5194890489943976, 0.9468618202710055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 124}], {
             RGBColor[
             0.44032874613102024`, 0.5550816804147461, 0.9494802254957222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 136}], {
             RGBColor[
             0.41562059029540377`, 0.5336807176979563, 0.947905843654441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 253}], {
             RGBColor[
             0.38290681803172033`, 0.5032043205420267, 0.9458997571271306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 261}], {
             RGBColor[
             0.6313262992509348, 0.7094325364761531, 0.9655864375213759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 277}], {
             RGBColor[
             0.41154149074138446`, 0.5301476066857698, 0.947645927037865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 311}], {
             RGBColor[
             0.39171310165668277`, 0.5124602829824929, 0.9464012619518432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 319}], {
             RGBColor[
             0.36758124625059874`, 0.48709617290269447`, 0.9450269884863475]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 331}], {
             RGBColor[
             0.36917081699093995`, 0.488766912535399, 0.9451175121884507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 377}], {
             RGBColor[
             0.43961688791079445`, 0.554465104603421, 0.9494348665194009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 484}], {
             RGBColor[
             0.4094797432519477, 0.5283618246368615, 0.9475145543109698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 488}], {
             RGBColor[
             0.40055751499557607`, 0.5206338389654236, 0.9469460378160905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 122}], {
             RGBColor[
             0.35063717682785556`, 0.4781260318565206, 0.9435632687445578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 267}], {
             RGBColor[
             0.32191805350617964`, 0.4480766636410371, 0.9419227683302369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 278}], {
             RGBColor[
             0.3480749767302752, 0.47556924839428116`, 0.943412366412149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 329}], {
             RGBColor[
             0.38008592294165355`, 0.5036330556032759, 0.9454397168064252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 406}], {
             RGBColor[
             0.3572413283959238, 0.4838462160104721, 0.9439840794426532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 413}], {
             RGBColor[
             0.31876379508252406`, 0.4447613380462401, 0.9417431379793169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 476}], {
             RGBColor[
             0.32446237655312204`, 0.4507509084827721, 0.9420676637637716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 486}], {
             RGBColor[
             0.4800023272774365, 0.5870359438552704, 0.9526738044665539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 493}], {
             RGBColor[
             0.40393215989636777`, 0.5242874675067306, 0.9469591779387803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 121}], {
             RGBColor[
             0.3313023572512571, 0.4594988271646654, 0.9424001201741694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 127}], {
             RGBColor[
             0.6080187725422915, 0.687628569697974, 0.964920598190099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 168}], {
             RGBColor[
             0.3080353498661728, 0.4350437271894693, 0.9410750985240417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 200}], {
             RGBColor[
             0.3692518005955957, 0.49424908336594287`, 0.9447493761107726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 213}], {
             RGBColor[
             0.34858869113547053`, 0.4763517365096613, 0.9434327410476437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 254}], {
             RGBColor[
             0.33457884420373596`, 0.4629426226929921, 0.942586711258985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 259}], {
             RGBColor[
             0.356564323557501, 0.4832598284466828, 0.9439409412930007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 315}], {
             RGBColor[
             0.30516376464058814`, 0.43202550904836073`, 0.9409115659935743]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 368}], {
             RGBColor[
             0.331417591705067, 0.45961994588190597`, 0.9424066826058397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 401}], {
             RGBColor[
             0.3120130045924957, 0.43922449450471057`, 0.9413016200762929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 450}], {
             RGBColor[
             0.32330119395404244`, 0.45108909723623936`, 0.9419444657610534]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 454}], {
             RGBColor[
             0.4576386538974494, 0.5684223638849784, 0.9510397297795876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 471}], {
             RGBColor[
             0.32570315974755126`, 0.4536137155786445, 0.9420812541596038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 475}], {
             RGBColor[
             0.40759994116554854`, 0.5274643152940482, 0.9471928857179608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 500}], {
             RGBColor[
             0.3630953252822927, 0.4889166538830062, 0.9443570909477663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 128}], {
             RGBColor[
             0.29190665897794255`, 0.42414278490993074`, 0.9399350244403664]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 169}], {
             RGBColor[
             0.29422867725902985`, 0.4265833733478158, 0.9400672599463562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 197}], {
             RGBColor[
             0.2681419546603289, 0.3991645739028382, 0.9385816596862078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[
             0.25067904942192637`, 0.38080995328513556`, 0.9375871730669341]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 219}], {
             RGBColor[
             0.6153668639835328, 0.6871885598926764, 0.9536852563944918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 337}], {
             RGBColor[
             0.2789675778925762, 0.41054299030408675`, 0.9391981629142099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 345}], {
             RGBColor[
             0.32790966805876964`, 0.45577409281513237`, 0.94221272609575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 355}], {
             RGBColor[
             0.3195101137827394, 0.4484988210751082, 0.9416775139247157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 361}], {
             RGBColor[
             0.2920590440954859, 0.4243029513302433, 0.9399437025473769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 362}], {
             RGBColor[
             0.31013901712848446`, 0.4403820481582054, 0.9410803959324419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 363}], {
             RGBColor[
             0.28206980135397597`, 0.41380362385434577`, 0.9393748299510083]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 498}], {
             RGBColor[
             0.2705295670071685, 0.4016741058627329, 0.9387176306772045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 109}], {
             RGBColor[
             0.376243934652413, 0.49501875960922637`, 0.9456279495516317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[
             0.2939705672291499, 0.42475681086924694`, 0.940109507105886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 186}], {
             RGBColor[
             0.6266441725485762, 0.6918063246208015, 0.8692408376378992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 193}], {
             RGBColor[
             0.28647597926719104`, 0.4182653754655419, 0.9396319585881541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 196}], {
             RGBColor[
             0.26166747157536735`, 0.3923594816746064, 0.9382129474526586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 202}], {
             RGBColor[
             0.2614194813602837, 0.3920988282350657, 0.9381988247767783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 330}], {
             RGBColor[
             0.32608414032339095`, 0.4525719738083635, 0.9421557555865334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 350}], {
             RGBColor[
             0.31574534734422, 0.4436170309726501, 0.9414969768401363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 354}], {
             RGBColor[
             0.45307864902507894`, 0.5573748164380081, 0.9516915820471379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 414}], {
             RGBColor[
             0.40817536483910366`, 0.5209421331293187, 0.9481417087046108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 415}], {
             RGBColor[
             0.27775120417397275`, 0.4092645044032864, 0.9391288922303991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 485}], {
             RGBColor[
             0.2532273027822811, 0.38348832913546316`, 0.9377322923260032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 496}], {
             RGBColor[
             0.25486509448503947`, 0.3852097520570538, 0.9378255621405795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 118}], {
             RGBColor[
             0.5392743048838743, 0.6346388604785883, 0.9577387058274891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 188}], {
             RGBColor[
             0.32960424674893524`, 0.4557751062687777, 0.9423744078868641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 304}], {
             RGBColor[
             0.37341541610331475`, 0.49785539784932886`, 0.9450146780091839]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 319}], {
             RGBColor[
             0.3250506578535922, 0.45098899562556083`, 0.9421150877357055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 331}], {
             RGBColor[
             0.3266402285939334, 0.4526597352582654, 0.9422056114378088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 449}], {
             RGBColor[
             0.594783820763033, 0.6780033161713332, 0.9632713756044047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 488}], {
             RGBColor[
             0.3580269265985695, 0.48452666168829006`, 0.9440341370654486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 112}], {
             RGBColor[
             0.29400882313177046`, 0.4226538167418803, 0.9401901589020638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 148}], {
             RGBColor[
             0.31963233257967916`, 0.44958574979596516`, 0.9416493798585369]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 153}], {
             RGBColor[
             0.3794220407283058, 0.5030580341977643, 0.9453974148188387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 190}], {
             RGBColor[
             0.6635997185628477, 0.7077315095746958, 0.657115244810303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 215}], {
             RGBColor[
             0.4173768896384118, 0.5350450720292275, 0.9480610954544748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 224}], {
             RGBColor[
             0.6151052886975248, 0.6924040419387443, 0.9659993837896901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 323}], {
             RGBColor[
             0.3792952017648078, 0.502948172662694, 0.9453893327522439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 351}], {
             RGBColor[
             0.4097482319670894, 0.5288517840645363, 0.9474605395778944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 356}], {
             RGBColor[
             0.35174299446881596`, 0.4790838355171098, 0.9436337304668037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 408}], {
             RGBColor[
             0.3025633655268073, 0.4316451831883788, 0.9406773274361497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 430}], {
             RGBColor[
             0.32511496555943264`, 0.4553483446766945, 0.9419616076959052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 452}], {
             RGBColor[
             0.3032703089547413, 0.4323882255539395, 0.9407175868185416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 112}], {
             RGBColor[
             0.30479497781971926`, 0.4319962418046839, 0.9408774431409578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 148}], {
             RGBColor[
             0.3304184872676279, 0.4589281748587687, 0.9423366640974309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 153}], {
             RGBColor[
             0.3902081954162546, 0.5124004592605679, 0.9460846990577327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 190}], {
             RGBColor[
             0.6743858732507966, 0.7170739346374994, 0.6578025290491971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 195}], {
             RGBColor[
             0.48105427733835465`, 0.5873269827740616, 0.9529121713030434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 263}], {
             RGBColor[
             0.3910415265664934, 0.5131222488184632, 0.9461377981817402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 323}], {
             RGBColor[
             0.3900813564527566, 0.5122905977254976, 0.9460766169911379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 342}], {
             RGBColor[
             0.34134610889031614`, 0.47007857579167667`, 0.9429712501113465]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 395}], {
             RGBColor[
             0.33117001542650737`, 0.4597180786033884, 0.9423794625142928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 447}], {
             RGBColor[
             0.650167849290844, 0.6277076732098281, 0.6036821307458162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 453}], {
             RGBColor[
             0.4238236069137007, 0.540864546311006, 0.9484067632843612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 463}], {
             RGBColor[
             0.6800961396862357, 0.7426272362426937, 0.8811659272611474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 117}], {
             RGBColor[
             0.5155595244453419, 0.6165747081442158, 0.9552873687039608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 139}], {
             RGBColor[
             0.42937340082515074`, 0.5463233916852932, 0.9485802713139563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 140}], {
             RGBColor[
             0.38456196494817213`, 0.5075099782169097, 0.9457249262450721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 247}], {
             RGBColor[
             0.35681919692371133`, 0.48247232109304766`, 0.9439940991505158]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 255}], {
             RGBColor[
             0.3865474422847064, 0.5092296988928231, 0.9458514391052674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 269}], {
             RGBColor[
             0.6432507329301015, 0.7171521816887787, 0.9676224688250287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 274}], {
             RGBColor[
             0.33598120664968445`, 0.4605702721101529, 0.942807406431454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 360}], {
             RGBColor[
             0.3179250117744187, 0.44159206646737126`, 0.9417791328450542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 369}], {
             RGBColor[
             0.44019245379627414`, 0.5553883249434619, 0.9493541968237897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 370}], {
             RGBColor[
             0.3864649547891921, 0.5091582523701507, 0.945846183074994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 425}], {
             RGBColor[
             0.3668531727732162, 0.49217151250473745`, 0.944596537666954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 466}], {
             RGBColor[
             0.3714731214355212, 0.49617307983065456`, 0.9448909167104558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 468}], {
             RGBColor[
             0.3564364462616936, 0.48207002587947334`, 0.9439723020665427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 113}], {
             RGBColor[
             0.3138339911007575, 0.4462489621616077, 0.9412182022938064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 132}], {
             RGBColor[
             0.3421969437423345, 0.47081552617629185`, 0.9430254645557534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 143}], {
             RGBColor[
             0.3513061353878987, 0.47870545013839516`, 0.9436058941924669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 209}], {
             RGBColor[
             0.3132011658979136, 0.44570084077762384`, 0.9411778792314665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 214}], {
             RGBColor[
             0.2522234923244513, 0.3819881355076721, 0.9376914250191893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 273}], {
             RGBColor[
             0.39451628705407255`, 0.515530374236762, 0.9465254134425041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 308}], {
             RGBColor[
             0.3574527716809914, 0.4840293575565491, 0.9439975524218056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 421}], {
             RGBColor[
             0.26701804880473734`, 0.39753815239751156`, 0.9385339531241567]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 423}], {
             RGBColor[
             0.4580337121297938, 0.5670966813406235, 0.9515257378164593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 446}], {
             RGBColor[
             0.4387487066288398, 0.5514402450953518, 0.9500075515401214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 477}], {
             RGBColor[
             0.3402172540251079, 0.46910081844532847`, 0.9428993204775427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 129}], {
             RGBColor[
             0.4972652073320985, 0.5978948704920503, 0.9551456105486111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 163}], {
             RGBColor[
             0.46279768231512664`, 0.5616673163319059, 0.9531827359890284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 189}], {
             RGBColor[
             0.4687547948632683, 0.5679286193227534, 0.9535219847358868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 206}], {
             RGBColor[
             0.47455634479610187`, 0.5740264161416726, 0.9538523744219376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 266}], {
             RGBColor[
             0.4568417122465076, 0.555407214159474, 0.9528435523046886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 364}], {
             RGBColor[
             0.8022598669112418, 0.8462336217124102, 0.980717679950601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 374}], {
             RGBColor[
             0.6620096629144709, 0.7357940341530785, 0.9670096410104633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 410}], {
             RGBColor[
             0.4670224028452155, 0.5661077654717819, 0.9534233275733031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 437}], {
             RGBColor[
             0.4776831498795281, 0.5773128865352464, 0.9540304413457452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 185}], {
             RGBColor[
             0.40784097410123066`, 0.5266739789658998, 0.947484300348503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 186}], {
             RGBColor[
             0.7405145794206569, 0.7937234927174543, 0.876615630880516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 196}], {
             RGBColor[
             0.3755378784474481, 0.49427664977125924`, 0.9455877406952755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 218}], {
             RGBColor[
             0.36823959529816475`, 0.48660569144348426`, 0.9451721142667662]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 295}], {
             RGBColor[
             0.3678086980895504, 0.4861527911567696, 0.9451475753081908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 300}], {
             RGBColor[
             0.3617072946312161, 0.47973982927073755`, 0.9448001094074563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 335}], {
             RGBColor[
             0.36594356742429734`, 0.4841924205714744, 0.9450413588760183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 409}], {
             RGBColor[
             0.3643942989151, 0.482564041139011, 0.9449531303263567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 456}], {
             RGBColor[
             0.4165345499806093, 0.534203917440789, 0.9480382473161096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 458}], {
             RGBColor[
             0.38017483278773323`, 0.4991503827827847, 0.9458518083851954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 496}], {
             RGBColor[
             0.36873550135712024`, 0.4871269201537067, 0.9452003553831964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 217}], {
             RGBColor[
             0.35265480969791696`, 0.4697009579698158, 0.9443322938716454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 290}], {
             RGBColor[
             0.3778250871122646, 0.49615651542005734`, 0.9457657039343039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 316}], {
             RGBColor[
             0.42446521090702255`, 0.5409540738795318, 0.9485764574990325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 340}], {
             RGBColor[
             0.41671434081590947`, 0.5342406597766676, 0.9480825789106522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 355}], {
             RGBColor[
             0.42680563388783554`, 0.5429812306324326, 0.9487255871818152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 378}], {
             RGBColor[
             0.36373332342604126`, 0.48134517831641455`, 0.9449631988392697]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 384}], {
             RGBColor[
             0.46592200271647066`, 0.5768618632659337, 0.951218047614329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 146}], {
             RGBColor[
             0.32967340890759744`, 0.4592801138321072, 0.9422526727495122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 201}], {
             RGBColor[
             0.3095308928729859, 0.4418336788352192, 0.9409692094391142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 256}], {
             RGBColor[
             0.2978940312684895, 0.43043589280862476`, 0.9402759964347895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 271}], {
             RGBColor[
             0.31712509960197377`, 0.44841139900793997`, 0.941453105576592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 284}], {
             RGBColor[
             0.2911466841152617, 0.42334400314406384`, 0.9398917449962187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 312}], {
             RGBColor[
             0.30320112613210215`, 0.4360139859995307, 0.940578227636129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 376}], {
             RGBColor[
             0.38405502408838227`, 0.5060164764020129, 0.945819019689353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[
             0.3012848465575686, 0.4339998546675534, 0.9404690983492409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 415}], {
             RGBColor[
             0.2972159418156486, 0.4297231778003345, 0.9402373802435937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 442}], {
             RGBColor[
             0.2971219810198691, 0.42962441904651166`, 0.9402320293152766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 444}], {
             RGBColor[
             0.279247128535272, 0.41083681575409453`, 0.9392140829097533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 464}], {
             RGBColor[
             0.5152122474075225, 0.6111667281410966, 0.957052903335798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 148}], {
             RGBColor[
             0.26489296359481806`, 0.39574967829505486`, 0.9383966344514785]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 153}], {
             RGBColor[
             0.3246826717434447, 0.449221962696854, 0.9421446694117803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 190}], {
             RGBColor[
             0.6088603495779866, 0.6538954380737855, 0.6538624994032447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 195}], {
             RGBColor[
             0.41552875366554476`, 0.5241484862103478, 0.948972141657091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 224}], {
             RGBColor[
             0.5603659197126637, 0.638567970437834, 0.9627466383826316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 263}], {
             RGBColor[
             0.32551600289368354`, 0.4499437522547494, 0.9421977685357877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 323}], {
             RGBColor[
             0.3245558327799467, 0.4491121011617837, 0.9421365873451855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 342}], {
             RGBColor[
             0.2758205852175063, 0.4069000792279628, 0.9390312204653941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 351}], {
             RGBColor[
             0.35500886298222833`, 0.47501571256362596`, 0.944207794170836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 356}], {
             RGBColor[
             0.29700362548395487`, 0.4252477640161995, 0.9403809850597452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 395}], {
             RGBColor[
             0.26564449175369753`, 0.39653958203967454`, 0.9384394328683404]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 447}], {
             RGBColor[
             0.5846423256180342, 0.5645291766461142, 0.5997421010998638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 452}], {
             RGBColor[
             0.24853093996988013`, 0.3785521540530292, 0.9374648414114831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 463}], {
             RGBColor[
             0.6145706160134258, 0.6794487396789799, 0.877225897615195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 130}], {
             RGBColor[
             0.3058405935919328, 0.4382925197605118, 0.9407466919170957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 143}], {
             RGBColor[
             0.3515797154925216, 0.47894241147448363`, 0.9436233264748161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 209}], {
             RGBColor[
             0.3134747460025365, 0.44593780211371237`, 0.9411953115138156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 214}], {
             RGBColor[
             0.25249707242907415`, 0.3822250968437606, 0.9377088573015385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 273}], {
             RGBColor[
             0.39478986715869546`, 0.5157673355728505, 0.9465428457248533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 302}], {
             RGBColor[
             0.3155885566615103, 0.4477686786633026, 0.9413300016598362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 308}], {
             RGBColor[
             0.3577263517856143, 0.4842663188926376, 0.9440149847041548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 325}], {
             RGBColor[
             0.2904914434484028, 0.4221595897673338, 0.9398725805234543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 347}], {
             RGBColor[
             0.3043126213644256, 0.43668652407036707`, 0.9406596761591715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 386}], {
             RGBColor[
             0.2935905443901481, 0.4254169413514568, 0.9400490697373778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 421}], {
             RGBColor[
             0.2672916289093602, 0.3977751137336001, 0.9385513854065058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 423}], {
             RGBColor[
             0.4583072922344167, 0.567333642676712, 0.9515431700988085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 477}], {
             RGBColor[
             0.3404908341297308, 0.469337779781417, 0.9429167527598918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 115}], {
             RGBColor[
             0.2757769877021288, 0.40631139487603085`, 0.9390486144371889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 203}], {
             RGBColor[
             0.28668559060106974`, 0.4157598784247698, 0.9397437009678107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 208}], {
             RGBColor[
             0.5776372741653659, 0.6515838469356201, 0.9645084990446434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 258}], {
             RGBColor[
             0.24151180094611968`, 0.3711745938999387, 0.9370651118279656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 289}], {
             RGBColor[
             0.3307836109719353, 0.4539553672390641, 0.9425535878314939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 291}], {
             RGBColor[
             0.25877249406191766`, 0.3893166767557949, 0.9380480827660032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 297}], {
             RGBColor[
             0.2639118754450406, 0.3947184924450573, 0.9383407629327385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 311}], {
             RGBColor[
             0.2682542742034474, 0.39928262886412613`, 0.9385880561180265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 349}], {
             RGBColor[
             0.32999525338267066`, 0.4532725315192477, 0.9425033543830232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 359}], {
             RGBColor[
             0.22984585831216603`, 0.35891294852816946`, 0.9364007536531774]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 381}], {
             RGBColor[
             0.29965837430824893`, 0.42699625164086064`, 0.94057031527425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 397}], {
             RGBColor[
             0.3135199697892778, 0.4390024689424814, 0.9414535638809735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 419}], {
             RGBColor[
             0.22375476978428283`, 0.35251082828804586`, 0.9360538751724725]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 124}], {
             RGBColor[
             0.3593361505803555, 0.48566064569780243`, 0.9441175596598665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 136}], {
             RGBColor[
             0.33462799474473903`, 0.4642596829810127, 0.9425431778185854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 178}], {
             RGBColor[
             0.3784880499469793, 0.502249058326721, 0.9453379017521482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 203}], {
             RGBColor[
             0.3291518225036404, 0.45951649782619286`, 0.9421942409657715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 253}], {
             RGBColor[
             0.3019142224810556, 0.43378328582508296`, 0.940537091291275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 277}], {
             RGBColor[
             0.3305488951907197, 0.46072657196882605`, 0.9422832612020094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 291}], {
             RGBColor[
             0.3012387259644883, 0.433073296157218, 0.940498622763964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 297}], {
             RGBColor[
             0.3063781073476113, 0.4384751118464804, 0.9407913029306996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 311}], {
             RGBColor[
             0.31072050610601804`, 0.4430392482655492, 0.9410385961159875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 381}], {
             RGBColor[
             0.34212460621081964`, 0.4707528710422837, 0.9430208552722108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 419}], {
             RGBColor[
             0.2662210016868535, 0.396267447689469, 0.9385044151704334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 439}], {
             RGBColor[
             0.3396907828528396, 0.46864481557712023`, 0.9428657741999859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 484}], {
             RGBColor[
             0.32848714770128296`, 0.4589407899199178, 0.9421518884751142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 192}], {
             RGBColor[
             0.33802221156766243`, 0.46621584367170527`, 0.9427954738287362]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 280}], {
             RGBColor[
             0.35661212781810425`, 0.4833012340945053, 0.9439439873382147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 310}], {
             RGBColor[
             0.34106730154500287`, 0.46941642630774577`, 0.9429688871981388]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 327}], {
             RGBColor[
             0.4754758457881816, 0.5830050047652398, 0.9524158651154171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 399}], {
             RGBColor[
             0.345730026704916, 0.4738757050605669, 0.9432505894779466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 412}], {
             RGBColor[
             0.39506479829557306`, 0.5166070045746752, 0.9463941574986776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 483}], {
             RGBColor[
             0.3231745705583471, 0.45061003157610247`, 0.9419499226383722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 139}], {
             RGBColor[
             0.5291352708252051, 0.6283333373216005, 0.9561524032587245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 140}], {
             RGBColor[
             0.4843238349482264, 0.5895199238532169, 0.9532970581898403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 154}], {
             RGBColor[
             0.7958334675066234, 0.8402318885917122, 0.9438922548914919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 247}], {
             RGBColor[
             0.45658106692376565`, 0.564482266729355, 0.9515662310952839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 255}], {
             RGBColor[
             0.48630931228476065`, 0.5912396445291304, 0.9534235710500356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 269}], {
             RGBColor[
             0.7430126029301558, 0.799162127325086, 0.9751946007697969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 338}], {
             RGBColor[
             0.4516494351096884, 0.559298809009243, 0.9512853819591678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 369}], {
             RGBColor[
             0.5399543237963285, 0.6373982705797692, 0.9569263287685579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 390}], {
             RGBColor[
             0.6627212779293175, 0.7360279846440232, 0.9673006998124996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 425}], {
             RGBColor[
             0.4666150427732705, 0.5741814581410447, 0.9521686696117222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 466}], {
             RGBColor[
             0.47123499143557546`, 0.5781830254669618, 0.9524630486552241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[
             0.5304295464660245, 0.6269779752875306, 0.9571751256422165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 151}], {
             RGBColor[
             0.5376562475503729, 0.6332373805422357, 0.9576356046449903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 188}], {
             RGBColor[
             0.47371131772079367`, 0.5737182375902918, 0.9537124291087762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 304}], {
             RGBColor[
             0.5175224870751732, 0.615798529170843, 0.956352699231096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 310}], {
             RGBColor[
             0.4937887853434399, 0.5948209290466644, 0.9548558111879343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 327}], {
             RGBColor[
             0.6281973295866186, 0.7084095075041583, 0.9643027891052125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 483}], {
             RGBColor[
             0.4758960543567841, 0.576014534315021, 0.9538368466281677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 197}], {
             RGBColor[
             0.2442013782633833, 0.37400151018943395`, 0.9372182792773107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 237}], {
             RGBColor[
             0.25702177709048035`, 0.38747656221694715`, 0.9379483820244334]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 270}], {
             RGBColor[
             0.3119246902038726, 0.43750176869884133`, 0.9413562693910926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 309}], {
             RGBColor[
             0.24366492690365796`, 0.3734376657973819, 0.9371877291659829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 320}], {
             RGBColor[
             0.2581002454855258, 0.3886101008789855, 0.9380097992040802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 345}], {
             RGBColor[
             0.30396909166182406`, 0.43061102910172805`, 0.940849345686853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 375}], {
             RGBColor[
             0.37901179570861, 0.4936357778882957, 0.9461762759898924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 426}], {
             RGBColor[
             0.3171946930899777, 0.44206638032073886`, 0.9416920693149147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 489}], {
             RGBColor[
             0.22552771074981237`, 0.35437430165376715`, 0.9361548415376282]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 123}], {
             RGBColor[
             0.33481322031062843`, 0.4644201160564785, 0.9425549802278554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 125}], {
             RGBColor[
             0.2816218966131278, 0.4098913561380057, 0.9394753322986271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 177}], {
             RGBColor[
             0.30500497164595075`, 0.434468450570089, 0.9408069638295868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 438}], {
             RGBColor[
             0.39546739365600553`, 0.5169557124408507, 0.9464198105190433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 455}], {
             RGBColor[
             0.31497028938814114`, 0.4449426313547692, 0.9413744739326382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 457}], {
             RGBColor[
             0.347746338118663, 0.47562213266439624`, 0.9433790670582763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 161}], {
             RGBColor[
             0.2908212037461153, 0.4230019026394437, 0.939873209370701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[
             0.3263577817698028, 0.45521608440421946`, 0.9420850561968075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.30569467230967756`, 0.43731873754793793`, 0.9407684211336786]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 259}], {
             RGBColor[
             0.31367030473170804`, 0.44422682948495945`, 0.9412766213790356]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 341}], {
             RGBColor[
             0.2976917381810813, 0.43022326994763616`, 0.9402644761427275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 450}], {
             RGBColor[
             0.2804071751282495, 0.41205609827451595`, 0.9392801458470883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 454}], {
             RGBColor[
             0.4147446350716565, 0.529389364923255, 0.9483754098656225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 469}], {
             RGBColor[
             0.34567544870222855`, 0.4719480765669155, 0.9433159608517996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 471}], {
             RGBColor[
             0.28280914092175835`, 0.4145807166169211, 0.9394169342456387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 475}], {
             RGBColor[
             0.3647059223397555, 0.48843131633232484`, 0.9445285658039957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 491}], {
             RGBColor[
             0.4622552316426629, 0.5679606075475824, 0.9521156180647419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 500}], {
             RGBColor[
             0.3202013064564998, 0.44988365492128285`, 0.9416927710338012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 150}], {
             RGBColor[
             0.3118706599157425, 0.4445484233690423, 0.9410931005668028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.28331094426839853`, 0.4149718924572232, 0.9394505000311653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 233}], {
             RGBColor[
             0.30449077451618795`, 0.4372332369264486, 0.9406566600310259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 267}], {
             RGBColor[
             0.2815005513588358, 0.4130690547237326, 0.9393474008332019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 406}], {
             RGBColor[
             0.31682382624857997`, 0.44883860709316764`, 0.9414087119456183]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 413}], {
             RGBColor[
             0.27834629293518026`, 0.4097537291289356, 0.939167770482282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 476}], {
             RGBColor[
             0.2840448744057782, 0.41574329956546763`, 0.9394922962667367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 493}], {
             RGBColor[
             0.3635146577490239, 0.4892798585894262, 0.9443838104417454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 125}], {
             RGBColor[
             0.27046643321770947`, 0.4002290544347874, 0.9387645160354601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 177}], {
             RGBColor[
             0.29384950825053235`, 0.4248061488668706, 0.9400961475664198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 438}], {
             RGBColor[
             0.3843119302605872, 0.5072934107376323, 0.9457089942558762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 455}], {
             RGBColor[
             0.3038148259927228, 0.43528032965155083`, 0.940663657669471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 136}], {
             RGBColor[
             0.37572092572039506`, 0.4998523144013612, 0.9451615830433022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 178}], {
             RGBColor[
             0.4195809809226354, 0.5378416897470695, 0.947956306976865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 253}], {
             RGBColor[
             0.3430071534567116, 0.4693759172454315, 0.9431554965159918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 261}], {
             RGBColor[
             0.591426634675926, 0.6756041331795579, 0.9628421769102369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 357}], {
             RGBColor[
             0.49863417867995685`, 0.6024166571877763, 0.9540702427258113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 484}], {
             RGBColor[
             0.36958007867693904`, 0.4945334213402663, 0.944770293699831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 177}], {
             RGBColor[
             0.2406581845530317, 0.3702773889483979, 0.9370164996371915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 438}], {
             RGBColor[
             0.3311206065630865, 0.4527646508191596, 0.942629346326648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 455}], {
             RGBColor[
             0.2506235022952221, 0.3807515697330781, 0.9375840097402428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 457}], {
             RGBColor[
             0.283399551025744, 0.41143107104270515`, 0.939588602865881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 144}], {
             RGBColor[
             0.29660008979856445`, 0.4290758782831059, 0.9402023083822921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 279}], {
             RGBColor[
             0.2960535488726037, 0.428501429117225, 0.9401711836850936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 285}], {
             RGBColor[
             0.2923237628025631, 0.42458118747551693`, 0.9399587778861287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 481}], {
             RGBColor[
             0.5807635378157233, 0.6635315499181622, 0.9633743317934794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 130}], {
             RGBColor[
             0.5697073924930092, 0.6534122146464434, 0.9625172527750496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 168}], {
             RGBColor[
             0.5418577463314143, 0.6241404707610545, 0.9609312566260062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 179}], {
             RGBColor[
             0.5232896818464059, 0.6046242577040257, 0.9598738328225749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 200}], {
             RGBColor[
             0.6030741970608372, 0.6833458269375281, 0.9646055342127372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 213}], {
             RGBColor[
             0.582411087600712, 0.6654484800812466, 0.9632888991496082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 254}], {
             RGBColor[
             0.5684012406689775, 0.6520393662645774, 0.9624428693609495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 302}], {
             RGBColor[
             0.5794553555625866, 0.6628883735492341, 0.9631005625177902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 315}], {
             RGBColor[
             0.5389861611058296, 0.621122252619946, 0.9607677240955388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 325}], {
             RGBColor[
             0.5543582423494791, 0.6372792846532653, 0.9616431413814084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 347}], {
             RGBColor[
             0.5681794202655019, 0.6518062189562985, 0.9624302370171255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 368}], {
             RGBColor[
             0.5652399881703085, 0.6487166894534913, 0.9622628407078043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 386}], {
             RGBColor[
             0.5574573432912244, 0.6405366362373883, 0.9618196305953318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 401}], {
             RGBColor[
             0.5458354010577371, 0.6283212380762958, 0.9611577781782574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 454}], {
             RGBColor[
             0.6914610503626909, 0.7575191074565635, 0.9708958878815522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 169}], {
             RGBColor[
             0.30622996585329754`, 0.439197488586037, 0.9407507155774842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 197}], {
             RGBColor[
             0.2801432432545966, 0.4117786891410595, 0.9392651153173359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 204}], {
             RGBColor[
             0.2626803380161941, 0.39342406852335676`, 0.9382706286980621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 345}], {
             RGBColor[
             0.3399109566530374, 0.46838820805335357`, 0.9428961817268782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 355}], {
             RGBColor[
             0.33151140237700716`, 0.4611129363133294, 0.9423609695558437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 362}], {
             RGBColor[
             0.3221403057227522, 0.4529961633964267, 0.94176385156357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 498}], {
             RGBColor[
             0.2825308556014362, 0.41428822110095415`, 0.9394010863083325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 170}], {
             RGBColor[
             0.2748420526352233, 0.40620680168519985`, 0.9389632203539713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 206}], {
             RGBColor[
             0.28414159550960505`, 0.4159812108712483, 0.9394928155632265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 265}], {
             RGBColor[
             0.36932428688731733`, 0.49413661154347366`, 0.9447604118467203]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 266}], {
             RGBColor[
             0.26642696296001067`, 0.3973620088890497, 0.9384839934459775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 328}], {
             RGBColor[
             0.31796148667951385`, 0.4496487355728752, 0.94148761963582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 410}], {
             RGBColor[
             0.27660765355871864`, 0.40806256020135756`, 0.939063768714592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 433}], {
             RGBColor[
             0.49451496106477116`, 0.5957463572053683, 0.9548714917031966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 143}], {
             RGBColor[
             0.343312737879074, 0.4707490077372992, 0.9431343838157562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 179}], {
             RGBColor[
             0.2511559053318819, 0.38131115908090973`, 0.9376143293055609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 214}], {
             RGBColor[
             0.2442300948156266, 0.3740316931065762, 0.9372199146424787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 254}], {
             RGBColor[
             0.29626746415445354`, 0.4287262676414614, 0.9401833658439356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 302}], {
             RGBColor[
             0.3073215790480628, 0.43957527492611825`, 0.9408410590007763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 315}], {
             RGBColor[
             0.2668523845913057, 0.39780915399683003`, 0.9385082205785249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 325}], {
             RGBColor[
             0.2822244658349552, 0.41396618603014934`, 0.9393836378643945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 347}], {
             RGBColor[
             0.29604564375097797`, 0.42849312033318265`, 0.9401707335001115]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 368}], {
             RGBColor[
             0.29310621165578454`, 0.42540359083037527`, 0.9400033371907903]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 386}], {
             RGBColor[
             0.28532356677670045`, 0.41722353761427233`, 0.9395601270783178]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 421}], {
             RGBColor[
             0.2590246512959126, 0.3895817099964156, 0.938062442747446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 477}], {
             RGBColor[
             0.33222385651628317`, 0.4611443760442326, 0.9424278101008319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 135}], {
             RGBColor[
             0.44298124013288553`, 0.5581098181437627, 0.9494473508017054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 147}], {
             RGBColor[
             0.3483392246307925, 0.47094480915217457`, 0.9436069077826519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 170}], {
             RGBColor[
             0.34345480814381835`, 0.4658109777344726, 0.9433287474895654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 171}], {
             RGBColor[
             0.36152316493400594`, 0.48480196632094696`, 0.9443577136790281]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 216}], {
             RGBColor[
             0.39225567901923875`, 0.5141738866479546, 0.9462151629023963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 238}], {
             RGBColor[
             0.3170057950127988, 0.4380113879694817, 0.9418225153195623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 265}], {
             RGBColor[
             0.4379370423959123, 0.5537407875927465, 0.9491259389823143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 374}], {
             RGBColor[
             0.540207669136569, 0.6373530049319269, 0.9570156092873463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 385}], {
             RGBColor[
             0.3618117940997805, 0.4851053338743221, 0.9443741506830303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 391}], {
             RGBColor[
             0.3644678891041684, 0.48789705813008377`, 0.9445254113641899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 433}], {
             RGBColor[
             0.5631277165733661, 0.655350533254641, 0.9592370188387906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 209}], {
             RGBColor[
             0.3418376986441135, 0.4705043661283965, 0.9430025737757628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 233}], {
             RGBColor[
             0.33479767542019934`, 0.46348355122037277`, 0.9425877889572893]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 273}], {
             RGBColor[
             0.4231528198002725, 0.5403338995875346, 0.9483501079868003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 423}], {
             RGBColor[
             0.48667024487599375`, 0.5919002066913962, 0.9533504323607556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 151}], {
             RGBColor[
             0.34817450233802605`, 0.4755928232270388, 0.9434210012593744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 155}], {
             RGBColor[
             0.32239527465216666`, 0.45326415190720504`, 0.9417783716669075]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 181}], {
             RGBColor[
             0.32328201348635954`, 0.4540322005165932, 0.9418348738813098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 225}], {
             RGBColor[
             0.39557275533279235`, 0.5157396580107889, 0.9466918241800613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 235}], {
             RGBColor[
             0.27345852191832365`, 0.40475262318082417`, 0.9388844303263942]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 239}], {
             RGBColor[
             0.31694830631845455`, 0.44854626170913237`, 0.9414312956612483]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 249}], {
             RGBColor[
             0.2930013209796535, 0.4252933440793085, 0.9399973638219565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 260}], {
             RGBColor[
             0.32363622810388953`, 0.45433900341495337`, 0.9418574441235192]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 262}], {
             RGBColor[
             0.5379335169087738, 0.6293370411053574, 0.9592510099266561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 296}], {
             RGBColor[
             0.3127778312088145, 0.4449340057833361, 0.9411655566750684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 332}], {
             RGBColor[
             0.40662164684454366`, 0.5247096458869189, 0.9475616333932896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 344}], {
             RGBColor[
             0.3181516049782057, 0.4495884985286597, 0.9415079687878125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 424}], {
             RGBColor[
             0.2895736719640485, 0.4216906676384079, 0.9398021642812702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 440}], {
             RGBColor[
             0.2920070965701404, 0.42424835118744186`, 0.939940744212658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 138}], {
             RGBColor[
             0.2791172892899262, 0.40828754492388375`, 0.939295033240996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 251}], {
             RGBColor[
             0.2677302165288191, 0.39842463482913104`, 0.9385694590338514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 305}], {
             RGBColor[
             0.23154289154263408`, 0.36069663805151275`, 0.9364973971851169]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 367}], {
             RGBColor[
             0.2401457444836934, 0.3697387819449464, 0.9369873169333298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 416}], {
             RGBColor[
             0.22496748076533807`, 0.3537854644194521, 0.9361229372687985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 438}], {
             RGBColor[
             0.33417908124981877`, 0.45597930163341055`, 0.9428035219354496]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 457}], {
             RGBColor[
             0.28645802571247625`, 0.41464572185695614`, 0.9397627784746826]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 499}], {
             RGBColor[
             0.26328626277035033`, 0.3940609338578233, 0.938305135216426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 147}], {
             RGBColor[
             0.34724449570088645`, 0.4699966099757658, 0.9435371526232691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 170}], {
             RGBColor[
             0.3423600792139123, 0.46486277855806385`, 0.9432589923301826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 171}], {
             RGBColor[
             0.36042843600409985`, 0.4838537671445382, 0.9442879585196453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 216}], {
             RGBColor[
             0.39116095008933266`, 0.5132256874715458, 0.9461454077430134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 385}], {
             RGBColor[
             0.36071706516987445`, 0.4841571346979133, 0.9443043955236475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 391}], {
             RGBColor[
             0.36337316017426236`, 0.486948858953675, 0.944455656204807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 253}], {
             RGBColor[
             0.31829899762109515`, 0.4479749545286417, 0.9415811146747106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 261}], {
             RGBColor[
             0.5667184788403095, 0.6542031704627682, 0.9612677950689558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 277}], {
             RGBColor[
             0.3469336703307593, 0.47491824067238475`, 0.943327284585445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 291}], {
             RGBColor[
             0.31762350110452786`, 0.4472649648607767, 0.9415426461473997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 311}], {
             RGBColor[
             0.3271052812460576, 0.4572309169691079, 0.9420826194994231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 319}], {
             RGBColor[
             0.30297342583997355`, 0.43186680688930945`, 0.9407083460339274]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 377}], {
             RGBColor[
             0.37500906750016927`, 0.4992357385900361, 0.9451162240669808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 484}], {
             RGBColor[
             0.3448719228413225, 0.4731324586234765, 0.9431959118585498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 488}], {
             RGBColor[
             0.3359496945849509, 0.4654044729520387, 0.9426273953636705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 145}], {
             RGBColor[
             0.3913434027920641, 0.5133837188323123, 0.9461570334678948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 183}], {
             RGBColor[
             0.3514539492844651, 0.4788334791062585, 0.9436153127632494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 346}], {
             RGBColor[
             0.4715649370624027, 0.5799572107124669, 0.95207282233535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 358}], {
             RGBColor[
             0.34809103059005636`, 0.47592068795836984`, 0.9434010305577539]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 404}], {
             RGBColor[
             0.49482122852027455`, 0.598837715801958, 0.9539036427895162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 407}], {
             RGBColor[
             0.3015045119150585, 0.4274000985253925, 0.9407317110974701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 408}], {
             RGBColor[
             0.3195018777765694, 0.4463164711447428, 0.9417566344585664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 430}], {
             RGBColor[
             0.3420534778091947, 0.4700196326330585, 0.9430409147183219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 352}], {
             RGBColor[
             0.4329114400150599, 0.5472791482398126, 0.9493883563255159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 367}], {
             RGBColor[
             0.2958709748799463, 0.4258967307240137, 0.9402491308504909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 457}], {
             RGBColor[
             0.34218325610872913`, 0.47080367063602335`, 0.9430245923918437]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 140}], {
             RGBColor[
             0.3981377113280353, 0.5192686073942943, 0.9465899607998358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 247}], {
             RGBColor[
             0.37039494330357453`, 0.4942309502704323, 0.9448591337052794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 255}], {
             RGBColor[
             0.40012318866456953`, 0.5209883280702077, 0.9467164736600311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 269}], {
             RGBColor[
             0.6568264793099646, 0.7289108108661633, 0.9684875033797924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 274}], {
             RGBColor[
             0.34955695302954765`, 0.47232890128753746`, 0.9436724409862176]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 360}], {
             RGBColor[
             0.33150075815428187`, 0.4533506956447559, 0.9426441673998178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 369}], {
             RGBColor[
             0.45376820017613734`, 0.5671469541208465, 0.9502192313785534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 370}], {
             RGBColor[
             0.4000407011690553, 0.5209168815475353, 0.9467112176297577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 425}], {
             RGBColor[
             0.3804289191530794, 0.5039301416821221, 0.9454615722217177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 466}], {
             RGBColor[
             0.3850488678153844, 0.5079317090080392, 0.9457559512652196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 468}], {
             RGBColor[
             0.3700121926415567, 0.49382865505685797`, 0.9448373366213064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 169}], {
             RGBColor[
             0.3309391297927208, 0.4610466354749164, 0.9423087834072128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 204}], {
             RGBColor[
             0.2873895019556173, 0.41527321541223616`, 0.9398286965277907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 219}], {
             RGBColor[
             0.6520773165172237, 0.7216518220197771, 0.9559267798553485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 244}], {
             RGBColor[
             0.4532380921758729, 0.5642831174738672, 0.9508498746479729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 247}], {
             RGBColor[
             0.3255835074265959, 0.4554175368020488, 0.9420037886363952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 255}], {
             RGBColor[
             0.3553117527875909, 0.48217491460182416`, 0.9438611285911469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 274}], {
             RGBColor[
             0.30474551715256903`, 0.43351548781915394`, 0.9408170959173334]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 334}], {
             RGBColor[
             0.29348623469894064`, 0.4216812680806512, 0.9401758964382151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 361}], {
             RGBColor[
             0.3287694966291768, 0.4587662134573439, 0.9421852260082336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 363}], {
             RGBColor[
             0.31878025388766695`, 0.4482668859814464, 0.9416163534118649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 369}], {
             RGBColor[
             0.4089567642991587, 0.528333540652463, 0.9473638863096692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 370}], {
             RGBColor[
             0.35522926529207666`, 0.4821034680791518, 0.9438558725608736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 425}], {
             RGBColor[
             0.33561748327610075`, 0.4651167282137386, 0.9426062271528335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 466}], {
             RGBColor[
             0.3402374319384057, 0.46911829553965567`, 0.9429006061963354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 188}], {
             RGBColor[
             0.32075948833108536`, 0.44811422107772003`, 0.9418108277015915]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 220}], {
             RGBColor[
             0.3765968894110515, 0.5006110301229925, 0.9452173986750865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[
             0.597398358538158, 0.31775047938747947`, 0.5547457621175159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 304}], {
             RGBColor[
             0.36457065768546487`, 0.49019451265827124`, 0.9444510978239113]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 310}], {
             RGBColor[
             0.34083695595373154`, 0.4692169125340926, 0.9429542097807496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 429}], {
             RGBColor[
             0.3308559747002966, 0.45872626840597047`, 0.9423858076639051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 173}], {
             RGBColor[
             0.6282604580491197, 0.7043484710366497, 0.9665843863104303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 222}], {
             RGBColor[
             0.649822646931059, 0.7230245552990608, 0.9679583099192925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 241}], {
             RGBColor[
             0.9302129677113393, 0.9435954652760508, 0.839901292655227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 402}], {
             RGBColor[
             0.5944471074698442, 0.6750610462732967, 0.9644298295114908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 417}], {
             RGBColor[
             0.6657297394835002, 0.7364583168207695, 0.9690669889240826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 461}], {
             RGBColor[
             0.5532784208819472, 0.6331475955885955, 0.9620356308503764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 179}], {
             RGBColor[
             0.29689502723247074`, 0.42196105079488155`, 0.9404909638632812]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 214}], {
             RGBColor[
             0.28996921671621545`, 0.414681584820548, 0.940096549200199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 226}], {
             RGBColor[
             0.3394673948537818, 0.46670730840888763`, 0.942915397219141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 273}], {
             RGBColor[
             0.43226201144583665`, 0.548223823549638, 0.9489305376235138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 283}], {
             RGBColor[
             0.3457336573342127, 0.4732935475798089, 0.9432722515972969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 292}], {
             RGBColor[
             0.36416075161494565`, 0.4898394726224657, 0.9444249789715635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 302}], {
             RGBColor[
             0.3530607009486516, 0.4802251666400901, 0.9437176935584967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 308}], {
             RGBColor[
             0.3951984960727555, 0.516722806869425, 0.9464026766028153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 325}], {
             RGBColor[
             0.327963587735544, 0.45461607774412116`, 0.9422602724221149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 347}], {
             RGBColor[
             0.3417847656515668, 0.4691430120471545, 0.943047368057832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 386}], {
             RGBColor[
             0.3310626886772893, 0.45787342932824415`, 0.9424367616360383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 421}], {
             RGBColor[
             0.30476377319650144`, 0.43023160171038743`, 0.9409390773051663]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 423}], {
             RGBColor[
             0.4957794365215579, 0.5997901306534994, 0.953930861997469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 446}], {
             RGBColor[
             0.47649443102060396`, 0.5841336944082278, 0.9524126757211311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 477}], {
             RGBColor[
             0.377962978416872, 0.5017942677582043, 0.9453044446585523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 279}], {
             RGBColor[
             0.28480399851246496`, 0.4166774384260302, 0.939530538434302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 494}], {
             RGBColor[
             0.29899804465692215`, 0.4312357408484615, 0.9403520695006629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 183}], {
             RGBColor[
             0.3601721354603734, 0.48638473378305214`, 0.944170827877189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 286}], {
             RGBColor[
             0.3189535270538117, 0.44412800800866487`, 0.9417844340047397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 294}], {
             RGBColor[
             0.3871739654531823, 0.5097723617713869, 0.94589136060755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 346}], {
             RGBColor[
             0.480283123238311, 0.5875084653892605, 0.9526283374492894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 358}], {
             RGBColor[
             0.35680921676596467`, 0.4834719426351635, 0.9439565456716934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 404}], {
             RGBColor[
             0.5035394146961829, 0.6063889704787517, 0.9544591579034558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 407}], {
             RGBColor[
             0.3102226980909668, 0.43495135320218614`, 0.9412872262114096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 408}], {
             RGBColor[
             0.3282200639524777, 0.4538677258215365, 0.9423121495725059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 430}], {
             RGBColor[
             0.350771663985103, 0.4775708873098522, 0.9435964298322613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 201}], {
             RGBColor[
             0.33790129871689933`, 0.4670948543606567, 0.9427517498532225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 211}], {
             RGBColor[
             0.6515561947182096, 0.7215470514081394, 0.9609519835992624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 271}], {
             RGBColor[
             0.34549550544588725`, 0.4736725745333774, 0.9432356459907003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 284}], {
             RGBColor[
             0.31951708995917516`, 0.44860517866950134`, 0.941674285410327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 312}], {
             RGBColor[
             0.33157153197601563`, 0.46127516152496817`, 0.9423607680502372]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 376}], {
             RGBColor[
             0.4124254299322957, 0.5312776519274504, 0.9476015601034612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 400}], {
             RGBColor[
             0.32965525240148197`, 0.4592610301929909, 0.942251638763349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 415}], {
             RGBColor[
             0.32558634765956207`, 0.4549843533257719, 0.9420199206577019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 442}], {
             RGBColor[
             0.32549238686378257`, 0.4548855945719491, 0.9420145697293848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 444}], {
             RGBColor[
             0.3076175343791855, 0.43609799127953197`, 0.9409966233238616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 464}], {
             RGBColor[
             0.543582653251436, 0.636427903666534, 0.9588354437499061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 497}], {
             RGBColor[
             0.27791513098872345`, 0.4048788820750106, 0.9393051153915428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 171}], {
             RGBColor[
             0.2657864205020068, 0.39668875815295, 0.9384475155005918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 216}], {
             RGBColor[
             0.2965189345872396, 0.42606067847995766`, 0.9403049647239601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 238}], {
             RGBColor[
             0.22126905058079965`, 0.3498981798014848, 0.9359123171411261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 385}], {
             RGBColor[
             0.2660750496677814, 0.39699212570632525`, 0.9384639525045941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 391}], {
             RGBColor[
             0.2687311446721693, 0.3997838499620869, 0.9386152131857536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 153}], {
             RGBColor[
             0.35030618119135337`, 0.47615389575093886`, 0.9436038903682535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 190}], {
             RGBColor[
             0.6344838590258952, 0.6808273711278703, 0.6553217203597179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 195}], {
             RGBColor[
             0.44115226311345346`, 0.5510804192644326, 0.9504313626135641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 323}], {
             RGBColor[
             0.3501793422278554, 0.47604403421586855`, 0.9435958083016587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 342}], {
             RGBColor[
             0.30144409466541494`, 0.4338320122820477, 0.9404904414218673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 351}], {
             RGBColor[
             0.380632372430137, 0.5019476456177108, 0.9456670151273092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 356}], {
             RGBColor[
             0.3226271349318635, 0.4521796970702844, 0.9418402060162183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 452}], {
             RGBColor[
             0.27415444941778877`, 0.4054840871071141, 0.9389240623679562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 463}], {
             RGBColor[
             0.6401941254613344, 0.7063806727330647, 0.8786851185716682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 158}], {
             RGBColor[
             0.3057435922886259, 0.4352950730234383, 0.9408471859903587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 165}], {
             RGBColor[
             0.3418925511897637, 0.46660548432410076`, 0.94315056568627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 182}], {
             RGBColor[
             0.3390453635176709, 0.46413939346634736`, 0.9429691454054734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 187}], {
             RGBColor[
             0.3408127151559792, 0.4656701846257738, 0.9430817594890587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 275}], {
             RGBColor[
             0.2742282180464253, 0.4055616226130122, 0.9389282633822262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 282}], {
             RGBColor[
             0.3201405413330086, 0.4477649866739837, 0.9417645468527446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 324}], {
             RGBColor[
             0.30087017440870145`, 0.4310739634009525, 0.9405366561124442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 441}], {
             RGBColor[
             0.5775532588521162, 0.6556712441295767, 0.9638711242884468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 159}], {
             RGBColor[
             0.2849619295036293, 0.41640189288704943`, 0.9395556993504453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 233}], {
             RGBColor[
             0.3061417597514187, 0.4386632373562748, 0.9407618593503059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 267}], {
             RGBColor[
             0.28315153659406656`, 0.41449905515355884`, 0.9394526001524819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 406}], {
             RGBColor[
             0.31847481148381074`, 0.45026860752299386`, 0.9415139112648983]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 413}], {
             RGBColor[
             0.27999727817041103`, 0.4111837295587618, 0.9392729698015619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 443}], {
             RGBColor[
             0.6273499374070801, 0.7008149121551293, 0.9628261966391379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 476}], {
             RGBColor[
             0.28569585964100896`, 0.41717329999529384`, 0.9395974955860167]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 188}], {
             RGBColor[
             0.3279861894154338, 0.45437362633242506`, 0.9422713067043653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 192}], {
             RGBColor[
             0.34501856706073963`, 0.47227573515275706`, 0.9432412754141208]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 249}], {
             RGBColor[
             0.33675793788664043`, 0.46359329013663864`, 0.9427708448031616]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 260}], {
             RGBColor[
             0.3673928450108765, 0.4926389494722835, 0.9446309251047242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 280}], {
             RGBColor[
             0.36360848331118134`, 0.4893611255755571, 0.9443897889235994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 310}], {
             RGBColor[
             0.34806365703808, 0.47547631778879756`, 0.9434146887835235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 327}], {
             RGBColor[
             0.48247220128125873`, 0.5890648962462917, 0.9528616667008016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 424}], {
             RGBColor[
             0.33333028887103544`, 0.459990613695738, 0.9425756452624752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 483}], {
             RGBColor[
             0.33017092605142423`, 0.45666992305715426`, 0.9423957242237568]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 191}], {
             RGBColor[
             0.2773443720884851, 0.4088368980867948, 0.9391057237449847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 212}], {
             RGBColor[
             0.3042393577712771, 0.43568055487426804`, 0.9406895178474471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 287}], {
             RGBColor[
             0.26000593752523254`, 0.39061310404057137`, 0.9381183255465229]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 299}], {
             RGBColor[
             0.3128535200890198, 0.4431417093135098, 0.941238404653129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 301}], {
             RGBColor[
             0.27843163226158063`, 0.4099796774649948, 0.9391676416033852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 389}], {
             RGBColor[
             0.3666062396425579, 0.4896996133005446, 0.9446634804114169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 451}], {
             RGBColor[
             0.32474995740454843`, 0.45344580538389556`, 0.9419964351192681]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 190}], {
             RGBColor[
             0.6942735671745219, 0.7342996555296695, 0.6590697553200197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 195}], {
             RGBColor[
             0.5009419712620801, 0.6045527036662317, 0.9541793975738659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 263}], {
             RGBColor[
             0.41092922049021885`, 0.5303479697106335, 0.9474050244525627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 323}], {
             RGBColor[
             0.409969050376482, 0.5295163186176677, 0.9473438432619605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 342}], {
             RGBColor[
             0.3612338028140416, 0.4873042966838468, 0.9442384763821692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 351}], {
             RGBColor[
             0.44042208057876364`, 0.55541993001951, 0.9494150500876111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[
             0.3824168430804902, 0.5056519814720835, 0.9455882409765202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 395}], {
             RGBColor[
             0.35105770935023284`, 0.47694379949555854`, 0.9436466887851154]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 447}], {
             RGBColor[
             0.6700555432145694, 0.6449333941019983, 0.6049493570166387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 452}], {
             RGBColor[
             0.3339441575664155, 0.4589563715089132, 0.9426720973282581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 463}], {
             RGBColor[
             0.6999838336099611, 0.7598529571348638, 0.88243315353197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 174}], {
             RGBColor[
             0.6850398800825048, 0.7486668237929202, 0.935617191667427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 229}], {
             RGBColor[
             0.6167916171676084, 0.6847913138685817, 0.9314428436470084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 255}], {
             RGBColor[
             0.6668213853459879, 0.7328868793403194, 0.9344563252927984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 313}], {
             RGBColor[
             0.7985260337101494, 0.8424178351344596, 0.9441042235662285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 338}], {
             RGBColor[
             0.6321615081709157, 0.700946043820432, 0.9323181362019306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 369}], {
             RGBColor[
             0.7204663968575556, 0.7790455053909582, 0.9379590830113207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 379}], {
             RGBColor[
             0.643420557240749, 0.7126182581953804, 0.9329652452184725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 380}], {
             RGBColor[
             0.6157012264530581, 0.6836452440928251, 0.9313807475089032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 390}], {
             RGBColor[
             0.8432333509905447, 0.8776752194552123, 0.9483334540552624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 425}], {
             RGBColor[
             0.6471271158344978, 0.7158286929522338, 0.933201423854485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 478}], {
             RGBColor[
             0.6674221652381811, 0.7334072446868618, 0.9344946064562802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 181}], {
             RGBColor[
             0.34125940270748706`, 0.4700034752540896, 0.9429657252700478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 235}], {
             RGBColor[
             0.29143591113945116`, 0.42072389791832054`, 0.9400152817151323]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 262}], {
             RGBColor[
             0.5559109061299013, 0.6453083158428536, 0.9603818613153942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 332}], {
             RGBColor[
             0.4245990360656712, 0.5406809206244153, 0.9486924847820276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 344}], {
             RGBColor[
             0.3361289941993333, 0.46555977326615605`, 0.9426388201765505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 387}], {
             RGBColor[
             0.2699526545615311, 0.3981436331377874, 0.9387918420346497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 393}], {
             RGBColor[
             0.28854948971623084`, 0.4176900859928276, 0.9398509042851577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 403}], {
             RGBColor[
             0.3670534417352266, 0.49234497541382016`, 0.9446092986281224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 232}], {
             RGBColor[
             0.3433552466001377, 0.4718187898937266, 0.9430992705896056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 307}], {
             RGBColor[
             0.2935447565942925, 0.4198007981284748, 0.9402503345808005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 350}], {
             RGBColor[
             0.3717238123765596, 0.496390215723689, 0.9449068905155416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 354}], {
             RGBColor[
             0.5090571140574185, 0.6101480011890471, 0.9551014957225431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 372}], {
             RGBColor[
             0.46087392538444516`, 0.5710525436597993, 0.9512934162841133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 479}], {
             RGBColor[
             0.3429908237858506, 0.4715031451684143, 0.9430760498901257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 180}], {
             RGBColor[
             0.3416637111550095, 0.47035366691020003`, 0.9429914874468082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 216}], {
             RGBColor[
             0.34169507370620533`, 0.4703808315757182, 0.9429934858408375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 238}], {
             RGBColor[
             0.2664451896997654, 0.3942183328972453, 0.9386008382580037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 246}], {
             RGBColor[
             0.33654630585329737`, 0.4659212276461261, 0.942665410906127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 281}], {
             RGBColor[
             0.3180589349367964, 0.44846765164182356`, 0.9415401646935591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 288}], {
             RGBColor[
             0.38719543505653287`, 0.5097909576627154, 0.9458927286316907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 343}], {
             RGBColor[
             0.3897679012863233, 0.5120190986150478, 0.9460566439051104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 392}], {
             RGBColor[
             0.31347611475525583`, 0.44365081706344256`, 0.9412791798638953]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 459}], {
             RGBColor[
             0.29887710948701884`, 0.4283063368961296, 0.940447788111162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 465}], {
             RGBColor[
             0.35947465813381674`, 0.4857806139790185, 0.9441263852386957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 182}], {
             RGBColor[
             0.37872657596746107`, 0.5024556575769958, 0.945353100419253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 206}], {
             RGBColor[
             0.3034287688560122, 0.43286204682747875`, 0.9407153602203457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 282}], {
             RGBColor[
             0.3598217537827987, 0.48608125078463216`, 0.9441485018665242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 324}], {
             RGBColor[
             0.34055138685849157`, 0.469390227511601, 0.9429206111262238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 410}], {
             RGBColor[
             0.2958948269051258, 0.424943396157588, 0.940286313371711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 441}], {
             RGBColor[
             0.6172344713019065, 0.693987508240225, 0.9662550793022264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 164}], {
             RGBColor[
             0.29350188273879596`, 0.42379877114882075`, 0.9400998576190059]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 396}], {
             RGBColor[
             0.31529929496666775`, 0.44267859405080956`, 0.9414887694514711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 443}], {
             RGBColor[
             0.5987902217597363, 0.67123838124331, 0.9611835961035003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 165}], {
             RGBColor[
             0.3251608039363978, 0.4490193571067653, 0.9421977174325926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 268}], {
             RGBColor[
             0.27581114939105467`, 0.40627516672534697`, 0.9390532010831494]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 275}], {
             RGBColor[
             0.2574964707930593, 0.3879754953956767, 0.9379754151285489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 285}], {
             RGBColor[
             0.2546983853892635, 0.38503453022742606`, 0.9378160683041992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 324}], {
             RGBColor[
             0.28413842715533555`, 0.41348783618361706`, 0.9395838078587668]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 353}], {
             RGBColor[
             0.2914194156004142, 0.4197942624216243, 0.940047746004162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 441}], {
             RGBColor[
             0.5608215115987503, 0.6380851169122411, 0.9629182760347694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 480}], {
             RGBColor[
             0.23946865423990188`, 0.36902711716872055`, 0.9369487576456111]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 481}], {
             RGBColor[
             0.5431381604024237, 0.6239848926700714, 0.9612316222115498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 259}], {
             RGBColor[
             0.3160831700523592, 0.4467629039214611, 0.9414140304895323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 326}], {
             RGBColor[
             0.4035084852647527, 0.520844553998083, 0.9474383185072883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 341}], {
             RGBColor[
             0.3001046035017325, 0.4327593443841379, 0.9404018852532241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 387}], {
             RGBColor[
             0.24638335715826726`, 0.3762949083534094, 0.9373425397474258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 403}], {
             RGBColor[
             0.3434841443319627, 0.4704962506294422, 0.9431599963408985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 405}], {
             RGBColor[
             0.29592479611765377`, 0.4283661018083764, 0.9401638514061719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 450}], {
             RGBColor[
             0.28282004044890063`, 0.4145921727110176, 0.9394175549575849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 469}], {
             RGBColor[
             0.34808831402287965`, 0.4744841510034171, 0.9434533699622962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 491}], {
             RGBColor[
             0.464668096963314, 0.5704966819840841, 0.9522530271752385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 203}], {
             RGBColor[
             0.3255824946286509, 0.4564249254205123, 0.9419668065498099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 221}], {
             RGBColor[
             0.6316051929471853, 0.6458537220908327, 0.6106828548383629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 223}], {
             RGBColor[
             0.3651381674468951, 0.4906860610897521, 0.9444872590440805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 258}], {
             RGBColor[
             0.28040870497370085`, 0.41183964089568115`, 0.9392882174099649]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 289}], {
             RGBColor[
             0.3696805149995165, 0.4946204142348065, 0.9447766934134932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 297}], {
             RGBColor[
             0.30280877947262175`, 0.43538353944079977`, 0.9405638685147379]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 381}], {
             RGBColor[
             0.3385552783358301, 0.4676612986366031, 0.9427934208562492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 439}], {
             RGBColor[
             0.33612145497785006`, 0.4655532431714396, 0.9426383397840242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 187}], {
             RGBColor[
             0.3267392292423903, 0.4508780586200475, 0.9422802952861364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.24387252055979958`, 0.37365585989218475`, 0.937199551317593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 322}], {
             RGBColor[
             0.24063323431447126`, 0.3702511646657344, 0.937015078758016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 364}], {
             RGBColor[
             0.5773775926077731, 0.6519608622818416, 0.9643952465323072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 437}], {
             RGBColor[
             0.25280087557605935`, 0.3830401271046776, 0.9377080079274513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 494}], {
             RGBColor[
             0.2752804789435382, 0.4063070755031746, 0.9390013892202799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 166}], {
             RGBColor[
             0.2902155923646239, 0.4203446716027217, 0.9399127082438278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 227}], {
             RGBColor[
             0.30267126160647173`, 0.4334363697109467, 0.9406220401806397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 309}], {
             RGBColor[
             0.29295359391941944`, 0.423222484836137, 0.9400686333818631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 348}], {
             RGBColor[
             0.38688741967830287`, 0.5095241702233957, 0.9458731021641571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 396}], {
             RGBColor[
             0.3523989638491783, 0.47965200322439994`, 0.9436755282556694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 428}], {
             RGBColor[
             0.29732140560358056`, 0.42781333185144615`, 0.9403173737956777]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 443}], {
             RGBColor[
             0.6358898906422468, 0.7082117904169005, 0.9633703549076986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 182}], {
             RGBColor[
             0.41487553486859885`, 0.5337660688776582, 0.9476564801151643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 268}], {
             RGBColor[
             0.36837306799534847`, 0.49348796935399336`, 0.9446933840465177]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 275}], {
             RGBColor[
             0.3500583893973531, 0.4751882980243231, 0.9436155980919171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 282}], {
             RGBColor[
             0.39597071268393647`, 0.5173916620852946, 0.9464518815624354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 285}], {
             RGBColor[
             0.34726030399355734`, 0.47224733285607245`, 0.9434562512675673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 324}], {
             RGBColor[
             0.37670034575962935`, 0.5007006388122635, 0.945223990822135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 353}], {
             RGBColor[
             0.38398133420470804`, 0.5070070650502707, 0.9456879289675302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 441}], {
             RGBColor[
             0.6533834302030441, 0.7252979195408875, 0.9685584589981376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 481}], {
             RGBColor[
             0.6357000790067175, 0.7111976952987178, 0.966871805174918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 210}], {
             RGBColor[
             0.2618820923014311, 0.3925850616654393, 0.9382251697855051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 227}], {
             RGBColor[
             0.2622853023497891, 0.3930088609912572, 0.9382481320012632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 243}], {
             RGBColor[
             0.2545941639165943, 0.3849249868516277, 0.9378101330455124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 309}], {
             RGBColor[
             0.2525676346627368, 0.3827949761164476, 0.9376947252024866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 320}], {
             RGBColor[
             0.26700295324460466`, 0.39796741119805124`, 0.938516795240584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 348}], {
             RGBColor[
             0.3465014604216202, 0.4690966615037062, 0.9434991939847808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 428}], {
             RGBColor[
             0.2569354463468979, 0.38738582313175673`, 0.9379434656163013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 495}], {
             RGBColor[
             0.2617238868563013, 0.3924187777118034, 0.9382161602194489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 210}], {
             RGBColor[
             0.4522256893904537, 0.5580869755774045, 0.9514836401456018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 326}], {
             RGBColor[
             0.5721498643743627, 0.6635360608135916, 0.9594608796590118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 434}], {
             RGBColor[
             0.706947110004692, 0.7708103154409804, 0.9715495681397539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 474}], {
             RGBColor[
             0.4246726614627325, 0.5291269962624991, 0.94991453596617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 495}], {
             RGBColor[
             0.4520674839453239, 0.5579206916237686, 0.9514746305795456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 200}], {
             RGBColor[
             0.30309077438471843`, 0.43076098442902333`, 0.9407600345466798]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 213}], {
             RGBColor[
             0.28242766492459326`, 0.4128636375727418, 0.9394433994835509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 254}], {
             RGBColor[
             0.2684178179928587, 0.3994545237560726, 0.9385973696948922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 261}], {
             RGBColor[
             0.512149255725568, 0.6007553087467574, 0.9580170729479197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 315}], {
             RGBColor[
             0.2390027384297109, 0.36853741011144125`, 0.9369222244294815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 368}], {
             RGBColor[
             0.26525656549418974`, 0.3961318469449865, 0.9384173410417469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 401}], {
             RGBColor[
             0.2458519783816184, 0.37573639556779104`, 0.9373122785122001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 500}], {
             RGBColor[
             0.29693429907141544`, 0.4254285549460868, 0.9403677493836735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 204}], {
             RGBColor[
             0.2650023562972814, 0.39586465696124185`, 0.9384028642040518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 219}], {
             RGBColor[
             0.6296901708588878, 0.7022432635687827, 0.9545009475316096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 244}], {
             RGBColor[
             0.430850946517537, 0.5448745590228729, 0.949424042324234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 274}], {
             RGBColor[
             0.28235837149423315`, 0.4141069293681596, 0.9393912635935946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 334}], {
             RGBColor[
             0.27109908904060476`, 0.4022727096296569, 0.9387500641144763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 337}], {
             RGBColor[
             0.2932908847679313, 0.4255976939801931, 0.9400138540513278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 340}], {
             RGBColor[
             0.3237421275861684, 0.4548129538954495, 0.9418501967906705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 361}], {
             RGBColor[
             0.30638235097084093`, 0.4393576550063496, 0.9407593936844948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 363}], {
             RGBColor[
             0.29639310822933107`, 0.42885832753045205`, 0.9401905210881261]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 370}], {
             RGBColor[
             0.3328421196337408, 0.46269490962815746`, 0.9424300402371347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 498}], {
             RGBColor[
             0.28485287388252356`, 0.41672880953883923`, 0.9395333218143223]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 171}], {
             RGBColor[
             0.2609020040150326, 0.39155492673524805`, 0.9381693552075053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 238}], {
             RGBColor[
             0.21638463409382552`, 0.34476434838378284`, 0.9356341568480395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 265}], {
             RGBColor[
             0.33731588147693903`, 0.46049374800704757`, 0.9429375805107916]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 266}], {
             RGBColor[
             0.23441855754963242`, 0.3637191453526236, 0.9366611621100489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 328}], {
             RGBColor[
             0.2859530812691356, 0.4160058720364491, 0.9396647882998912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 374}], {
             RGBColor[
             0.4395865082175957, 0.5441059653462281, 0.9508272508158235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 433}], {
             RGBColor[
             0.4625065556543929, 0.5621034936689422, 0.9530486603672679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 216}], {
             RGBColor[
             0.309702874890453, 0.43991783564873005`, 0.9410557706203362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 238}], {
             RGBColor[
             0.23445299088401306`, 0.3637553369702572, 0.9366631230375022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 265}], {
             RGBColor[
             0.3553842382671266, 0.47948473659352187`, 0.9439665467002543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 343}], {
             RGBColor[
             0.357775702470571, 0.4815561026880597, 0.944118928684609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 385}], {
             RGBColor[
             0.2792589899709948, 0.4108492828750976, 0.9392147584009702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 391}], {
             RGBColor[
             0.2819150849753827, 0.4136410071308593, 0.9393660190821298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 433}], {
             RGBColor[
             0.48057491244458045`, 0.5810944822554165, 0.9540776265567306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 465}], {
             RGBColor[
             0.3274824593180644, 0.4553176180520303, 0.9421886700181943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 303}], {
             RGBColor[
             0.278101947991656, 0.40963315839411396`, 0.9391488665719372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 366}], {
             RGBColor[
             0.4262826250202418, 0.5346681075516071, 0.9496558667770139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 448}], {
             RGBColor[
             0.3926040328555809, 0.5073263092290483, 0.9470045646330636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 473}], {
             RGBColor[
             0.27518607590140487`, 0.4065683919502915, 0.9389828119700436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 241}], {
             RGBColor[
             0.693007188637419, 0.7523806350132263, 0.8194555425863893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 417}], {
             RGBColor[
             0.42852396040957985`, 0.545243486557945, 0.9486212388552451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 461}], {
             RGBColor[
             0.31607264180802686`, 0.44193276532577086`, 0.9415898807815388]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 493}], {
             RGBColor[
             0.40393215989636777`, 0.5242874675067306, 0.9469591779387803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 215}], {
             RGBColor[
             0.4398699033786755, 0.5545273899993016, 0.9494943304002132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 229}], {
             RGBColor[
             0.3254859566822626, 0.4515790142586006, 0.9421350261801806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 294}], {
             RGBColor[
             0.3840102807677756, 0.5070321371083033, 0.9456897734169324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 338}], {
             RGBColor[
             0.34085584768556987`, 0.467733744210451, 0.9430103187351029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 356}], {
             RGBColor[
             0.37423600820907965`, 0.498566153487184, 0.9450669654125421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 390}], {
             RGBColor[
             0.551927690505199, 0.6444629198452312, 0.9590256365884346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 430}], {
             RGBColor[
             0.34760797929969633`, 0.4748306626467687, 0.9433948426416437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 309}], {
             RGBColor[
             0.24799548928814485`, 0.37798936143699136`, 0.9374343482872867]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 320}], {
             RGBColor[
             0.2624308078700127, 0.393161796518595, 0.9382564183253839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 337}], {
             RGBColor[
             0.25935756388011755`, 0.389931622230292, 0.9380814016266164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 348}], {
             RGBColor[
             0.3419293150470283, 0.46429104682425004`, 0.9432388170695807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 361}], {
             RGBColor[
             0.2724490300830272, 0.4036915832564485, 0.9388269412597834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 370}], {
             RGBColor[
             0.298908798745927, 0.42702883787825635`, 0.9404975878124233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 375}], {
             RGBColor[
             0.38334235809309686`, 0.4981874735279052, 0.9464228951111959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 197}], {
             RGBColor[
             0.5231156868209956, 0.6112793914000908, 0.9588002787991607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 237}], {
             RGBColor[
             0.5359360856480928, 0.624754443427604, 0.9595303815462835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 345}], {
             RGBColor[
             0.5828834002194364, 0.6678889103123848, 0.962431345208703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 426}], {
             RGBColor[
             0.5961090016475901, 0.6793442615313957, 0.9632740688367647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 448}], {
             RGBColor[
             0.6604165975244745, 0.7329355537214444, 0.9679543362640093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 245}], {
             RGBColor[
             0.3139375488098808, 0.4422053999451028, 0.9413761397477046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 438}], {
             RGBColor[
             0.3545036815959094, 0.47734174525124284`, 0.9439609778576077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 455}], {
             RGBColor[
             0.274006577328045, 0.4053286641651614, 0.9389156412712025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 357}], {
             RGBColor[
             0.5177860780465806, 0.6190050698166948, 0.9552905848180929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 420}], {
             RGBColor[
             0.38695942569997055`, 0.5095865382202364, 0.9458776903241854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 439}], {
             RGBColor[
             0.3999356131951194, 0.5208258596263872, 0.9467045215169843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 236}], {
             RGBColor[
             0.24045084191873473`, 0.3700594586934695, 0.9370046917809043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 254}], {
             RGBColor[
             0.24984975350785027`, 0.3799383106990437, 0.9375399458914607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 276}], {
             RGBColor[
             0.34151730214677933`, 0.4599324001615116, 0.9435216506281896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 283}], {
             RGBColor[
             0.2535768247870206, 0.3838556989234194, 0.9377521970871017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 292}], {
             RGBColor[
             0.27200391906775356`, 0.4004016239660762, 0.9389049244613683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 315}], {
             RGBColor[
             0.22043467394470245`, 0.34902119705441237`, 0.93586480062605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 325}], {
             RGBColor[
             0.23580675518835192`, 0.3651782290877317, 0.9367402179119195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 347}], {
             RGBColor[
             0.24962793310437476`, 0.379705163390765, 0.9375273135476367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 368}], {
             RGBColor[
             0.24668850100918127`, 0.3766156338879576, 0.9373599172383156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 386}], {
             RGBColor[
             0.23890585613009724`, 0.36843558067185467`, 0.9369167071258431]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 401}], {
             RGBColor[
             0.22728391389660996`, 0.35622018251076215`, 0.9362548547087687]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 216}], {
             RGBColor[
             0.34040402642448997`, 0.4692625913102195, 0.9429112214496749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 281}], {
             RGBColor[
             0.316767887655081, 0.4473494113763249, 0.9414579003023964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 288}], {
             RGBColor[
             0.3859043877748176, 0.5086727173972168, 0.9458104642405281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 343}], {
             RGBColor[
             0.388476854004608, 0.5109008583495491, 0.9459743795139477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 392}], {
             RGBColor[
             0.3121850674735405, 0.4425325767979439, 0.9411969154727327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 465}], {
             RGBColor[
             0.35818361085210143`, 0.48466237371351983`, 0.9440441208475331]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 235}], {
             RGBColor[
             0.29232264997364404`, 0.4214919465277087, 0.9400717839295347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 239}], {
             RGBColor[
             0.33581243437377495`, 0.4652855850560169, 0.9426186492643888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 262}], {
             RGBColor[
             0.5567976449640942, 0.6460763644522418, 0.9604383635297966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 296}], {
             RGBColor[
             0.331641959264135, 0.4616733291302206, 0.9423529102782089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 332}], {
             RGBColor[
             0.42548577489986406`, 0.5414489692338035, 0.9487489869964301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 344}], {
             RGBColor[
             0.33701573303352617`, 0.4663278218755442, 0.9426953223909529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 387}], {
             RGBColor[
             0.270839393395724, 0.3989116817471756, 0.9388483442490521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 393}], {
             RGBColor[
             0.2894362285504237, 0.4184581346022158, 0.9399074064995601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 424}], {
             RGBColor[
             0.3084378000193689, 0.43842999098529245`, 0.9409895178844105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 275}], {
             RGBColor[
             0.3472112017252604, 0.47272220716656965`, 0.9434341778111206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 282}], {
             RGBColor[
             0.3931235250118437, 0.5149255712275411, 0.9462704612816389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 324}], {
             RGBColor[
             0.3738531580875366, 0.49823454795450994`, 0.9450425705413386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 441}], {
             RGBColor[
             0.6505362425309513, 0.7228318286831341, 0.9683770387173412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 346}], {
             RGBColor[
             0.44039366973071203`, 0.5529582256632066, 0.950086616744644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 404}], {
             RGBColor[
             0.46364996118858387`, 0.5718387307526979, 0.9519174371988104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 407}], {
             RGBColor[
             0.2703332445833678, 0.40040111347613233`, 0.9387455055067642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 408}], {
             RGBColor[
             0.28833061044487873`, 0.4193174860954827, 0.9397704288678603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 192}], {
             RGBColor[
             0.28265894328951674`, 0.41442284938235524`, 0.9394083807126798]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 225}], {
             RGBColor[
             0.3769697484685564, 0.49618671829771716`, 0.9456324104598255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 249}], {
             RGBColor[
             0.2743983141154176, 0.4057404043662368, 0.9389379501017208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 260}], {
             RGBColor[
             0.3050332212396536, 0.43478606370188166`, 0.9407980304032834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 280}], {
             RGBColor[
             0.3012488595399585, 0.4315082398051553, 0.9405568942221585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 424}], {
             RGBColor[
             0.27097066509981255`, 0.4021377279253362, 0.9387427505610343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 440}], {
             RGBColor[
             0.27340408970590446`, 0.40469541147437016`, 0.9388813304924222]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 453}], {
             RGBColor[
             0.3722692920187197, 0.49237067599858975`, 0.9452623733097549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 470}], {
             RGBColor[
             0.3093031180695711, 0.4384844337247014, 0.9410701044535641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 193}], {
             RGBColor[
             0.31807301871600857`, 0.4499205948222153, 0.9414883093850253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 196}], {
             RGBColor[
             0.29326451102418494`, 0.4240147010312798, 0.9400692982495299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 318}], {
             RGBColor[
             0.6096409019279856, 0.6872497440513867, 0.9658451549646596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 321}], {
             RGBColor[
             0.30550345637532805`, 0.43687860858928573`, 0.9407662880813804]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 330}], {
             RGBColor[
             0.3576811797722085, 0.48422719316503693`, 0.9440121063834047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 335}], {
             RGBColor[
             0.2836702000010342, 0.4139304718314949, 0.9395229164302727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 350}], {
             RGBColor[
             0.34734238679303764`, 0.4752722503293235, 0.9433533276370076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 383}], {
             RGBColor[
             0.3226913008209632, 0.4539207186599191, 0.9417825822369664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 409}], {
             RGBColor[
             0.28212093149183687`, 0.4123020923990316, 0.9394346878806112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 482}], {
             RGBColor[
             0.3096794877685558, 0.44126788235925113`, 0.94100410689134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 496}], {
             RGBColor[
             0.2864621339338571, 0.41686497141372725`, 0.9396819129374507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 191}], {
             RGBColor[
             0.6306399828564273, 0.6960061746033593, 0.8694683931236598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 202}], {
             RGBColor[
             0.6256901261285276, 0.6908035613432937, 0.8691865061056626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 212}], {
             RGBColor[
             0.6575349685392193, 0.7228498313908325, 0.8710521872261221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 295}], {
             RGBColor[
             0.6182089359857136, 0.6829403561683447, 0.8687604633944583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 300}], {
             RGBColor[
             0.6121075325273793, 0.6765273942823127, 0.8684129974937238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 389}], {
             RGBColor[
             0.7199018504105001, 0.7768688898171091, 0.875026149790092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 414}], {
             RGBColor[
             0.7724460096073476, 0.8196468662375467, 0.8791293900334951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 456}], {
             RGBColor[
             0.6669347878767724, 0.7309914824523641, 0.8716511354023772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 485}], {
             RGBColor[
             0.617497947550525, 0.6821930622436911, 0.8687199736548875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 322}], {
             RGBColor[
             0.32945705554520366`, 0.4537346663844447, 0.942435071473418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 494}], {
             RGBColor[
             0.36410430017427065`, 0.4897905772218849, 0.9444213819356817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 304}], {
             RGBColor[
             0.3078524289402341, 0.4369347749610324, 0.940988401290471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 310}], {
             RGBColor[
             0.28411872720850084`, 0.4159571748368537, 0.9394915132473093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 483}], {
             RGBColor[
             0.26622599622184506`, 0.3971507801052104, 0.9384725486875427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 266}], {
             RGBColor[
             0.23791655049118052`, 0.36739575771975286`, 0.9368603676332532]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 364}], {
             RGBColor[
             0.5833347051559148, 0.6582221652726892, 0.9647344952791657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 374}], {
             RGBColor[
             0.44308450115914383`, 0.5477825777133574, 0.9510264563390278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 437}], {
             RGBColor[
             0.25875798812420103`, 0.3893014300955252, 0.9380472566743098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 195}], {
             RGBColor[
             0.785119649096622, 0.8092261790431632, 0.6658972275653303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 224}], {
             RGBColor[
             0.929956815143741, 0.9236456632706495, 0.679671724290871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 263}], {
             RGBColor[
             0.6951068983247608, 0.735021445087565, 0.6591228544440271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 323}], {
             RGBColor[
             0.694146728211024, 0.7341897939945992, 0.6590616732534249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 342}], {
             RGBColor[
             0.6454114806485836, 0.6919777720607783, 0.6559563063736336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 351}], {
             RGBColor[
             0.7245997584133056, 0.7600934053964414, 0.6611328800790754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 356}], {
             RGBColor[
             0.6665945209150321, 0.7103254568490149, 0.6573060709679845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 395}], {
             RGBColor[
             0.6352353871847748, 0.68161727487249, 0.6553645187765798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 452}], {
             RGBColor[
             0.6181218354009574, 0.6636298468858447, 0.6543899273197225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 463}], {
             RGBColor[
             0.984161511444503, 0.9645264325117953, 0.5941509835234344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 212}], {
             RGBColor[
             0.29726013407882657`, 0.42834494826516234`, 0.9402920613829984]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 218}], {
             RGBColor[
             0.25836499873393515`, 0.3888883733293892, 0.9380248765099098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 287}], {
             RGBColor[
             0.253026713832782, 0.38327749743146566`, 0.937720869082074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 295}], {
             RGBColor[
             0.2579341015253208, 0.38843547304267456`, 0.9380003375513346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 299}], {
             RGBColor[
             0.30587429639656927`, 0.4358061027044041, 0.9408409481886802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 300}], {
             RGBColor[
             0.2518326980669865, 0.38202251115664254`, 0.9376528716506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 301}], {
             RGBColor[
             0.2714524085691301, 0.40264407085588916`, 0.9387701851389364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 389}], {
             RGBColor[
             0.3596270159501074, 0.482364006691439, 0.9442660239469681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 451}], {
             RGBColor[
             0.3177707337120979, 0.4461101987747899, 0.9415989786548193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 456}], {
             RGBColor[
             0.3066599534163797, 0.4364865993266939, 0.9408910095592533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[
             0.3924168200555059, 0.5124225699365071, 0.9465120983348076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 249}], {
             RGBColor[
             0.28984538570236706`, 0.4219762560050268, 0.9398176379767029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 260}], {
             RGBColor[
             0.32048029282660306`, 0.45102191534067165`, 0.9416777182782656]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 280}], {
             RGBColor[
             0.31669593112690797`, 0.4477440914439453, 0.9414365820971407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 327}], {
             RGBColor[
             0.4355596490969853, 0.5474478621146798, 0.949908459874343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 470}], {
             RGBColor[
             0.3247501896565206, 0.4547202853634914, 0.9419497923285464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 483}], {
             RGBColor[
             0.2832583738671508, 0.4150528889255424, 0.9394425173972981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 196}], {
             RGBColor[
             0.28576992306222604`, 0.41752326562757475`, 0.9395917497317978]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 202}], {
             RGBColor[
             0.28552193284714245`, 0.41726261218803407`, 0.9395776270559175]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 232}], {
             RGBColor[
             0.31147923305465686`, 0.444209389095656, 0.9410681591933396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 330}], {
             RGBColor[
             0.35018659181024964`, 0.47773575776133187`, 0.9435345578656726]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 350}], {
             RGBColor[
             0.33984779883107874`, 0.46878081492561846`, 0.9428757791192754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 354}], {
             RGBColor[
             0.47718110051193763`, 0.5825386003909765, 0.9530703843262771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 376}], {
             RGBColor[
             0.3886927379335651, 0.5107215869579331, 0.9460893339552976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 414}], {
             RGBColor[
             0.4322778163259624, 0.5461059170822871, 0.9495205109837499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 415}], {
             RGBColor[
             0.30185365566083144`, 0.43442828835625474`, 0.9405076945095383]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 485}], {
             RGBColor[
             0.27732975426913986`, 0.4086521130884315, 0.9391110946051424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 496}], {
             RGBColor[
             0.2789675459718982, 0.4103735360100222, 0.9392043644197188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 228}], {
             RGBColor[
             0.5241549499731664, 0.6203673776113099, 0.957272992553038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 388}], {
             RGBColor[
             0.3217826230699953, 0.45290962677615065`, 0.9417328853285644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 490}], {
             RGBColor[
             0.3295076170788376, 0.4598246692044733, 0.9422169118814865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 224}], {
             RGBColor[
             0.7366252192312991, 0.7938987114072118, 0.9747813665447173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 263}], {
             RGBColor[
             0.5017753024123189, 0.6052744932241272, 0.9542324966978734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 296}], {
             RGBColor[
             0.45646291508538506`, 0.5660271807883445, 0.9513452314455719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 323}], {
             RGBColor[
             0.5008151322985821, 0.6044428421311614, 0.9541713155072711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 342}], {
             RGBColor[
             0.4520798847361417, 0.5622308201973406, 0.9510659486274797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 351}], {
             RGBColor[
             0.5312681625008637, 0.6303464535330037, 0.9562425223329216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 395}], {
             RGBColor[
             0.4419037912723329, 0.5518703230090524, 0.950474161030426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 447}], {
             RGBColor[
             0.7609016251366696, 0.7198599176154921, 0.6117768292619494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 453}], {
             RGBColor[
             0.5345573827595261, 0.6330167907166699, 0.9565014618004944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 463}], {
             RGBColor[
             0.7908299155320612, 0.8347794806483576, 0.8892606257772806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 318}], {
             RGBColor[
             0.577337806274203, 0.6548524148567461, 0.9639485953114322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 321}], {
             RGBColor[
             0.2732003607215455, 0.4044812793946452, 0.938869728428153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 330}], {
             RGBColor[
             0.32537808411842595`, 0.4518298639703964, 0.9421155467301773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 335}], {
             RGBColor[
             0.2513671043472517, 0.38153314263685434`, 0.9376263567770453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 350}], {
             RGBColor[
             0.3150392911392551, 0.44287492113468296`, 0.9414567679837802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 354}], {
             RGBColor[
             0.452372592820114, 0.556632706600041, 0.9516513731907817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 383}], {
             RGBColor[
             0.29038820516718067`, 0.42152338946527856`, 0.939886022583739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 414}], {
             RGBColor[
             0.4074693086341387, 0.5202000232913516, 0.9481014998482546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 479}], {
             RGBColor[
             0.28630630254854605`, 0.41798785057940824`, 0.9396259273583644]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 482}], {
             RGBColor[
             0.2773763921147733, 0.4088705531646106, 0.9391075472381125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 496}], {
             RGBColor[
             0.2541590382800746, 0.3844676422190867, 0.9377853532842233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 237}], {
             RGBColor[
             0.2691989377640801, 0.4002755301614802, 0.9386418533103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 270}], {
             RGBColor[
             0.3241018508774723, 0.4503007366433744, 0.9420497406769593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 345}], {
             RGBColor[
             0.3161462523354238, 0.4434099970462611, 0.9415428169727196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 375}], {
             RGBColor[
             0.3911889563822097, 0.5064347458328288, 0.946869747275759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 426}], {
             RGBColor[
             0.32937185376357747`, 0.4548653482652719, 0.9423855406007814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 448}], {
             RGBColor[
             0.39367944964046186`, 0.5084566404553206, 0.947065808028026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 489}], {
             RGBColor[
             0.2377048714234121, 0.3671732695983002, 0.9368483128234949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 223}], {
             RGBColor[
             0.356289985116648, 0.48160412579690254`, 0.9439753837096442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 373}], {
             RGBColor[
             0.2802213358728946, 0.41186076943424865`, 0.9392695625764204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 480}], {
             RGBColor[
             0.26987331117096314`, 0.40098433936985783`, 0.938680257878176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 208}], {
             RGBColor[
             0.6324592754839493, 0.7060424127861656, 0.9677463377440149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 220}], {
             RGBColor[
             0.35933541009125586`, 0.4856600043233624, 0.944117512476556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 349}], {
             RGBColor[
             0.38481725470125405`, 0.5077310973697932, 0.9457411930823947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 359}], {
             RGBColor[
             0.28466785963074936`, 0.4133715143787149, 0.9396385923525489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 371}], {
             RGBColor[
             0.4528765863035521, 0.5637080197178329, 0.9508992255407172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 382}], {
             RGBColor[
             0.3404827314959827, 0.4693307616873146, 0.9429162364672343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 397}], {
             RGBColor[
             0.36834197110786115`, 0.49346103479302683`, 0.9446914025803449]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 419}], {
             RGBColor[
             0.27857677110286616`, 0.40696939413859134`, 0.939291713871844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 427}], {
             RGBColor[
             0.43809743505149357`, 0.5517096389382353, 0.9497357566163402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 429}], {
             RGBColor[
             0.313594495380501, 0.4437752426063404, 0.9412859214653746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 213}], {
             RGBColor[
             0.3436441156540162, 0.4720689937492153, 0.9431176770702818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 243}], {
             RGBColor[
             0.31183295991969434`, 0.43994957571286, 0.9412578890799922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 254}], {
             RGBColor[
             0.32963426872228163`, 0.4586598799325461, 0.942271647281623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 259}], {
             RGBColor[
             0.3516197480760467, 0.47897708568623687`, 0.9436258773156389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 401}], {
             RGBColor[
             0.3070684291110413, 0.4349417517442646, 0.940986556098931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 450}], {
             RGBColor[
             0.3183566184725881, 0.44680635447579337`, 0.9416294017836915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 454}], {
             RGBColor[
             0.45269407841599507`, 0.5641396211245323, 0.9507246658022258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 469}], {
             RGBColor[
             0.38362489204656713`, 0.5066983327681929, 0.9456652167884028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 471}], {
             RGBColor[
             0.32075858426609694`, 0.4493309728181985, 0.9417661901822418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 475}], {
             RGBColor[
             0.40265536568409416`, 0.5231815725336023, 0.946877821740599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 500}], {
             RGBColor[
             0.3581507498008384, 0.48463391112256027`, 0.9440420269704045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 222}], {
             RGBColor[
             0.3759689197106828, 0.5000671143312081, 0.9451773850010707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 246}], {
             RGBColor[
             0.3239483179760788, 0.4550094837401611, 0.9418626782585537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 256}], {
             RGBColor[
             0.3061219210777914, 0.43825063333717423`, 0.9407750735384999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 271}], {
             RGBColor[
             0.32535298941127566`, 0.45622613953648944`, 0.9419521826803023]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 312}], {
             RGBColor[
             0.31142901594140404`, 0.44382872652808014`, 0.9410773047398393]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 333}], {
             RGBColor[
             0.5692144842551219, 0.6547462826584812, 0.9621128677798301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 400}], {
             RGBColor[
             0.3095127363668705, 0.4418145951961029, 0.9409681754529511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 442}], {
             RGBColor[
             0.305349870829171, 0.43743915957506113`, 0.9407311064189869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 444}], {
             RGBColor[
             0.2874750183445739, 0.418651556282644, 0.9397131600134636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 492}], {
             RGBColor[
             0.31839109806614657`, 0.4501960991681718, 0.9415085771199495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 211}], {
             RGBColor[
             0.6027670048125717, 0.6748244392081459, 0.9580066236397231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 414}], {
             RGBColor[
             0.40722131841905507`, 0.5199393698518109, 0.9480873771723742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 485}], {
             RGBColor[
             0.2522732563622325, 0.38248556585795535`, 0.9376779607937666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 497}], {
             RGBColor[
             0.22912594108308554`, 0.35815626987501725`, 0.9363597554320034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 221}], {
             RGBColor[
             0.6460831237211158, 0.6583937780452522, 0.6116053757849462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 258}], {
             RGBColor[
             0.2948866357476313, 0.4243796968501007, 0.9402107383565483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 289}], {
             RGBColor[
             0.38415844577344693`, 0.507160470189226, 0.9456992143600766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 291}], {
             RGBColor[
             0.3121473288634293, 0.4425217797059569, 0.9411937092945858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 297}], {
             RGBColor[
             0.3172867102465522, 0.4479235953952193, 0.9414863894613212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 381}], {
             RGBColor[
             0.35303320910976055`, 0.48020135459102264`, 0.9437159418028326]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 397}], {
             RGBColor[
             0.36689480459078944`, 0.4922075718926434, 0.9445991904095561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 419}], {
             RGBColor[
             0.27712960458579444`, 0.40571593123820787`, 0.9391995017010552]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 439}], {
             RGBColor[
             0.3505993857517805, 0.4780932991258592, 0.9435608607306076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 219}], {
             RGBColor[
             0.5861405430217843, 0.6564698435061025, 0.9520208606521875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 244}], {
             RGBColor[
             0.3873013186804336, 0.4991011389601926, 0.9469439554448119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 274}], {
             RGBColor[
             0.23880874365712967`, 0.36833350930547937`, 0.9369111767141725]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 334}], {
             RGBColor[
             0.22754946120350128`, 0.35649928956697663`, 0.9362699772350541]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 337}], {
             RGBColor[
             0.24974125693082783`, 0.37982427391751283`, 0.9375337671719056]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 340}], {
             RGBColor[
             0.28019249974906496`, 0.40903953383276925`, 0.9393701099112484]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 361}], {
             RGBColor[
             0.26283272313373746`, 0.39358423494366934`, 0.9382793068050727]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 362}], {
             RGBColor[
             0.2809126961667361, 0.4096633317716315, 0.9394160001901376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 363}], {
             RGBColor[
             0.2528434803922276, 0.3830849074677718, 0.9377104342087039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 370}], {
             RGBColor[
             0.2892924917966373, 0.4169214895654772, 0.9399499533577126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 498}], {
             RGBColor[
             0.24130324604542008`, 0.37095538947615897`, 0.9370532349349001]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 228}], {
             RGBColor[
             0.4720501117549981, 0.5682365796465204, 0.9542092301680302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 252}], {
             RGBColor[
             0.26269752330383117`, 0.3934421313502735, 0.9382716073747697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 388}], {
             RGBColor[
             0.26967778485182714`, 0.40077882881136123`, 0.9386691229435565]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 432}], {
             RGBColor[
             0.2730062886244281, 0.40388585237107605`, 0.9388730090262889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 490}], {
             RGBColor[
             0.2774027788606694, 0.40769387123968387`, 0.9391531494964787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 266}], {
             RGBColor[
             0.2437181004240141, 0.3734935545386721, 0.9371907573193041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 410}], {
             RGBColor[
             0.25389879102272206`, 0.38419410585098, 0.9377705325879184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 218}], {
             RGBColor[
             0.30929828732157805`, 0.4365527998928104, 0.9411403700172327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 287}], {
             RGBColor[
             0.303960002420425, 0.4309419239948868, 0.9408363625893968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 295}], {
             RGBColor[
             0.3088673901129637, 0.43609989960609574`, 0.9411158310586574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 336}], {
             RGBColor[
             0.30514492238640234`, 0.43218735000739406`, 0.9409038420285273]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 389}], {
             RGBColor[
             0.4105603045377503, 0.53002843325486, 0.947381517454291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 409}], {
             RGBColor[
             0.30545299093851336`, 0.43251114958833714`, 0.9409213860768234]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 456}], {
             RGBColor[
             0.35759324200402265`, 0.48415102589011505`, 0.9440065030665763]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 458}], {
             RGBColor[
             0.32123352481114653`, 0.4490974912321108, 0.9418200641356621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[
             0.5858383193119274, 0.6602036653609511, 0.9649755364333811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 289}], {
             RGBColor[
             0.6751101293377431, 0.7429844387000765, 0.9704640124369094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 314}], {
             RGBColor[
             0.5813152640937579, 0.6554496475483904, 0.9647179551299669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 349}], {
             RGBColor[
             0.6743217717484784, 0.74230160298026, 0.9704137789884386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 359}], {
             RGBColor[
             0.5741723766779738, 0.6479420199891819, 0.9643111782585929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 397}], {
             RGBColor[
             0.6578464881550856, 0.7280315404034938, 0.9693639884863889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 427}], {
             RGBColor[
             0.727601952098718, 0.7862801445487022, 0.9744083425223843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 472}], {
             RGBColor[
             0.5909756007187611, 0.6656032738419873, 0.9652680970095735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 214}], {
             RGBColor[
             0.25186424722623035`, 0.38167697545977675`, 0.9376685342391986]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 233}], {
             RGBColor[
             0.3058018975757784, 0.4383688658217048, 0.9407402036330024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 273}], {
             RGBColor[
             0.39415704195585155`, 0.5152192141888666, 0.9465025226625134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 421}], {
             RGBColor[
             0.26665880370651635`, 0.3972269923496162, 0.9385110623441659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 423}], {
             RGBColor[
             0.45767446703157283`, 0.5667855212927282, 0.9515028470364686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 477}], {
             RGBColor[
             0.3398580089268869, 0.46878965839743314`, 0.9428764296975519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 227}], {
             RGBColor[
             0.27433776154327894`, 0.40567675977366424`, 0.938934501722317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 243}], {
             RGBColor[
             0.26664662311008414`, 0.3975928856340347, 0.9384965027665662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 326}], {
             RGBColor[
             0.3938587264788299, 0.5107020456840335, 0.9468887790199689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 348}], {
             RGBColor[
             0.3585539196151101, 0.48176456028611325`, 0.9441855637058345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 428}], {
             RGBColor[
             0.26898790554038776`, 0.4000537219141638, 0.938629835337355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 434}], {
             RGBColor[
             0.5286559721091593, 0.6179763003114224, 0.9589774675007109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 469}], {
             RGBColor[
             0.3384385552369569, 0.4643416426893676, 0.9429038304749768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 474}], {
             RGBColor[
             0.24638152356719978`, 0.3762929811329411, 0.9373424353271271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 495}], {
             RGBColor[
             0.2737763460497912, 0.40508667649421043`, 0.9389025299405026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 464}], {
             RGBColor[
             0.8370950332181346, 0.8734336657171288, 0.9757522141855481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 485}], {
             RGBColor[
             0.5945748262345691, 0.6662139401085435, 0.957540091188948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 497}], {
             RGBColor[
             0.5714275109554221, 0.6418846441256053, 0.9562218858271847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 287}], {
             RGBColor[
             0.279921699515574, 0.41012115421893885`, 0.9393046631845363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 295}], {
             RGBColor[
             0.28482908720811273`, 0.4152791298301478, 0.939584131653797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 299}], {
             RGBColor[
             0.3327692820793612, 0.46264975949187737`, 0.9424247422911427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 300}], {
             RGBColor[
             0.27872768374977847`, 0.4088661679441157, 0.9392366657530624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 301}], {
             RGBColor[
             0.2983473942519221, 0.4294877276433623, 0.9403539792413989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 389}], {
             RGBColor[
             0.3865220016328993, 0.5092076634789121, 0.9458498180494306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 451}], {
             RGBColor[
             0.3446657193948899, 0.4729538555622631, 0.9431827727572817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 456}], {
             RGBColor[
             0.33355493909917167`, 0.4633302561141671, 0.9424748036617158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 254}], {
             RGBColor[
             0.30897115926215646`, 0.44076253307626456`, 0.9409550122184942]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 259}], {
             RGBColor[
             0.33095663861592145`, 0.46107973882995534`, 0.9423092422525099]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 261}], {
             RGBColor[
             0.5527025969948657, 0.6420633180669494, 0.9603747154715218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 315}], {
             RGBColor[
             0.27955607969900864`, 0.4098454194316332, 0.9392798669530835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 368}], {
             RGBColor[
             0.3058099067634874, 0.43743985626517845`, 0.9407749835653489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 401}], {
             RGBColor[
             0.2864053196509161, 0.417044404887983, 0.9396699210358022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 450}], {
             RGBColor[
             0.2976935090124629, 0.4289090076195118, 0.9403127667205626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 454}], {
             RGBColor[
             0.4320309689558699, 0.5462422742682508, 0.9494080307390969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 471}], {
             RGBColor[
             0.30009547480597176`, 0.4314336259619169, 0.940449555119113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 475}], {
             RGBColor[
             0.38199225622396893`, 0.5052842256773207, 0.94556118667747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 500}], {
             RGBColor[
             0.3374876403407132, 0.46673656426627874`, 0.9427253919072756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 273}], {
             RGBColor[
             0.33317936838238926`, 0.45150650891891486`, 0.9430160684502362]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 302}], {
             RGBColor[
             0.25397805788520417`, 0.383507852009367, 0.9378032243852191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 347}], {
             RGBColor[
             0.2427021225881194, 0.37242569741643144`, 0.9371328988845544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 421}], {
             RGBColor[
             0.20568113013305406`, 0.33351428707966446`, 0.9350246081318888]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 423}], {
             RGBColor[
             0.3966967934581105, 0.5030728160227764, 0.9480163928241915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 477}], {
             RGBColor[
             0.2788803353534246, 0.4050769531274814, 0.9393899754852748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 224}], {
             RGBColor[
             0.683733986219305, 0.7509592257251811, 0.9706175749350426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 351}], {
             RGBColor[
             0.47837692948886956`, 0.587406967850973, 0.952078730723247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 356}], {
             RGBColor[
             0.4203716919905961, 0.5376390193035466, 0.9482519216121562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 430}], {
             RGBColor[
             0.3937436630812128, 0.5139035284631313, 0.9465797988412579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 238}], {
             RGBColor[
             0.26518550496924587`, 0.39312725729726483`, 0.9385205722608705]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 281}], {
             RGBColor[
             0.31679925020627686`, 0.447376576041843, 0.9414598986964259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 343}], {
             RGBColor[
             0.3885082165558038, 0.5109280230150673, 0.9459763779079771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 465}], {
             RGBColor[
             0.3582149734032972, 0.48468953837903794`, 0.9440461192415626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 290}], {
             RGBColor[
             0.2359834862163146, 0.3653639846035148, 0.936750282482512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 340}], {
             RGBColor[
             0.2748727399199594, 0.40344812896012505`, 0.9390671574588602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 355}], {
             RGBColor[
             0.28496403299188555`, 0.41218869981589007`, 0.9397101657300232]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 362}], {
             RGBColor[
             0.2755929363376306, 0.4040719268989873, 0.9391130477377494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 378}], {
             RGBColor[
             0.2218917225300912, 0.350552647499872, 0.9359477773874777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 384}], {
             RGBColor[
             0.3240804018205206, 0.4460693324493911, 0.9422026261625369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 498}], {
             RGBColor[
             0.2359834862163146, 0.3653639846035148, 0.936750282482512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 295}], {
             RGBColor[
             0.24593395186322134`, 0.37582255489437466`, 0.9373169467807085]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.23983254840488705`, 0.3694095930083426, 0.9369694808799739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 336}], {
             RGBColor[
             0.2422114841366599, 0.371910005295673, 0.9371049577505783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 389}], {
             RGBColor[
             0.3476268662880079, 0.469751088543139, 0.9435826331763421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 409}], {
             RGBColor[
             0.24251955268877096`, 0.37223380487661606`, 0.9371225017988745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 456}], {
             RGBColor[
             0.29465980375428025`, 0.42387368117839397`, 0.9402076187886272]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 458}], {
             RGBColor[
             0.25830008656140413`, 0.38882014652038976`, 0.9380211798577132]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 244}], {
             RGBColor[
             0.7519891332420399, 0.8054797455677335, 0.9630420387723697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 274}], {
             RGBColor[
             0.603496558218736, 0.6747121159130203, 0.9530092600417304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 334}], {
             RGBColor[
             0.5922372757651077, 0.6628778961745175, 0.9523680605626119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 337}], {
             RGBColor[
             0.6144290714924342, 0.6862028805250537, 0.9536318504994634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 340}], {
             RGBColor[
             0.6448803143106713, 0.7154181404403102, 0.955468193238806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 361}], {
             RGBColor[
             0.6275205376953439, 0.6999628415512102, 0.9543773901326305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 363}], {
             RGBColor[
             0.617531294953834, 0.6894635140753127, 0.9538085175362618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 369}], {
             RGBColor[
             0.7077078053653257, 0.7695301687463293, 0.9595560504340661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 370}], {
             RGBColor[
             0.6539803063582437, 0.723300096173018, 0.9560480366852704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 498}], {
             RGBColor[
             0.6059910606070265, 0.6773339960836999, 0.9531513182624579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 349}], {
             RGBColor[
             0.4011979063557851, 0.5219191945174568, 0.9467849537209798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 359}], {
             RGBColor[
             0.30104851128528043`, 0.4275596115263786, 0.9406823529911341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 371}], {
             RGBColor[
             0.46925723795808316`, 0.5778961168654966, 0.9519429861793023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 382}], {
             RGBColor[
             0.35686338315051375`, 0.48351885883497825`, 0.9439599971058195]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 416}], {
             RGBColor[
             0.3011294821913949, 0.42764471708255686`, 0.9406869641644515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 427}], {
             RGBColor[
             0.45447808670602463`, 0.565897736085899, 0.9507795172549254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 429}], {
             RGBColor[
             0.32997514703503206`, 0.45796333975400405`, 0.9423296821039597]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 499}], {
             RGBColor[
             0.33944826419640717`, 0.4679201865209281, 0.942869162112079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 223}], {
             RGBColor[
             0.6856387965393599, 0.6926549137144922, 0.6141258282792167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 258}], {
             RGBColor[
             0.6009093340661656, 0.6138084935204211, 0.6089267866451011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 297}], {
             RGBColor[
             0.6233094085650865, 0.6373523920655397, 0.6102024377498741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 381}], {
             RGBColor[
             0.6590559074282949, 0.6696301512613431, 0.6124319900913855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 439}], {
             RGBColor[
             0.6566220840703149, 0.6675220957961796, 0.6122769090191604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 307}], {
             RGBColor[
             0.32346905604132564`, 0.44571972227047285`, 0.9421570844805465]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 333}], {
             RGBColor[
             0.6274246212835168, 0.7051649776259206, 0.9658219662380764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 372}], {
             RGBColor[
             0.4907982248314783, 0.5969714678017973, 0.9532001661838594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 417}], {
             RGBColor[
             0.450086149291519, 0.5639195708203562, 0.9499951624641072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 258}], {
             RGBColor[
             0.3344423085658754, 0.45864083251934057`, 0.9427311908508187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 268}], {
             RGBColor[
             0.36909759224453753`, 0.4941155158429933, 0.9447395500910043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 373}], {
             RGBColor[
             0.3431031217953162, 0.46774389635075764`, 0.9432244113517104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 381}], {
             RGBColor[
             0.3925888819280047, 0.5144624902602626, 0.946236394297103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 480}], {
             RGBColor[
             0.33275509709338474`, 0.4568674662863669, 0.9426351066534661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 263}], {
             RGBColor[
             0.6466124684594379, 0.7196939774516133, 0.968006993423414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 342}], {
             RGBColor[
             0.5969170507832606, 0.6766503044248268, 0.9648404453530204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 351}], {
             RGBColor[
             0.6761053285479827, 0.7447659377604899, 0.9700170190584623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 356}], {
             RGBColor[
             0.6181000910497092, 0.6949979892130635, 0.9661902099473715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 463}], {
             RGBColor[
             0.9356670815791801, 0.9491989648758439, 0.9030351225028213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 235}], {
             RGBColor[
             0.36461339182007685`, 0.48319940402190437`, 0.9449287342282862]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 249}], {
             RGBColor[
             0.38415619088140673`, 0.5037401249203888, 0.9460416677238485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 260}], {
             RGBColor[
             0.41479109800564273`, 0.5327857842560335, 0.947901748025411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 280}], {
             RGBColor[
             0.41100673630594764`, 0.5295079603593071, 0.9476606118442862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 296}], {
             RGBColor[
             0.4039327011105678, 0.5233807866244162, 0.9472098605769603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 424}], {
             RGBColor[
             0.3807285418658017, 0.500137448479488, 0.945846468183162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 440}], {
             RGBColor[
             0.3831619664718936, 0.502695132028522, 0.94598504811455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 453}], {
             RGBColor[
             0.48202716878470886`, 0.5903703965527416, 0.9523660909318827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 470}], {
             RGBColor[
             0.41906099483556025`, 0.5364841542788533, 0.9481738220756919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 236}], {
             RGBColor[
             0.2830232095400458, 0.41480571630747554`, 0.9394291251367639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 283}], {
             RGBColor[
             0.29614919240833165`, 0.4286019565374255, 0.9401766304429613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 292}], {
             RGBColor[
             0.3145762866890646, 0.4451478815800822, 0.9413293578172279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 308}], {
             RGBColor[
             0.3456140311468745, 0.47203121582704155`, 0.9433070554484797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 386}], {
             RGBColor[
             0.2814782237514083, 0.41318183828586075`, 0.9393411404817027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 396}], {
             RGBColor[
             0.3320396530024754, 0.46027377174644646`, 0.94244210807647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 422}], {
             RGBColor[
             0.30865874018355827`, 0.44002240022154804`, 0.940952296986578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 446}], {
             RGBColor[
             0.4269099660947229, 0.5394421033658443, 0.9493170545667955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 309}], {
             RGBColor[
             0.2650233039045846, 0.3958866742246725, 0.9384040571392985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 320}], {
             RGBColor[
             0.2794586224864525, 0.41105910930627615`, 0.9392261271773958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 348}], {
             RGBColor[
             0.35895712966346804`, 0.4821883596119312, 0.9442085259215927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 428}], {
             RGBColor[
             0.2693911155887458, 0.4004775212399817, 0.9386527975531131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 495}], {
             RGBColor[
             0.27417955609814915`, 0.4055104758200283, 0.9389254921562608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 388}], {
             RGBColor[
             0.5086951324118152, 0.6067528197853397, 0.956296109882986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 490}], {
             RGBColor[
             0.5164201264206575, 0.6136678622136623, 0.9567801364359081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 244}], {
             RGBColor[
             0.40519380133402766`, 0.5179072726780429, 0.9479629058623781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 248}], {
             RGBColor[
             0.23102647323158226`, 0.3601538496637853, 0.936467987926275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 255}], {
             RGBColor[
             0.30726746194574567`, 0.43579906980599986`, 0.9409741598055521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 313}], {
             RGBColor[
             0.4389721103099071, 0.5453300256001401, 0.9506220580789821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 338}], {
             RGBColor[
             0.27260758477067343`, 0.40385823428611256`, 0.9388359707146843]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 379}], {
             RGBColor[
             0.2838666338405068, 0.4155304486610609, 0.9394830797312261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 380}], {
             RGBColor[
             0.25614730305281597`, 0.38655743455850555`, 0.9378985820216569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 390}], {
             RGBColor[
             0.4836794275903025, 0.5805874099208927, 0.954851288568016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 411}], {
             RGBColor[
             0.28159975828764494`, 0.4133095787891801, 0.9393480616937472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 478}], {
             RGBColor[
             0.3078682418379389, 0.4363194351525423, 0.9410124409690339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 242}], {
             RGBColor[
             0.25516961082577544`, 0.3855298180386184, 0.9378429038956929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 339}], {
             RGBColor[
             0.2890272317706877, 0.42062933535469244`, 0.9397888763732958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 365}], {
             RGBColor[
             0.24143487761266663`, 0.3710937425992585, 0.9370607311579233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 374}], {
             RGBColor[
             0.45019031439810053`, 0.5552512379620819, 0.9514311218908778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 391}], {
             RGBColor[
             0.2744505343656999, 0.4057952911602386, 0.9389409239677213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 246}], {
             RGBColor[
             0.30983394798313635`, 0.44100767931420526`, 0.9410283748166522]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 256}], {
             RGBColor[
             0.2920075510848489, 0.4242488289112184, 0.9399407700965983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 271}], {
             RGBColor[
             0.3112386194183332, 0.4422243351105336, 0.9411178792384007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 288}], {
             RGBColor[
             0.3604830771863719, 0.4848774093307946, 0.944255692542216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 442}], {
             RGBColor[
             0.2912355008362285, 0.4234373551491053, 0.9398968029770853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 444}], {
             RGBColor[
             0.27336064835163143`, 0.40464975185668817`, 0.938878856571562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 492}], {
             RGBColor[
             0.30427672807320405`, 0.43619429474221605`, 0.940674273678048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 307}], {
             RGBColor[
             0.26256954534941873`, 0.39297162700755006`, 0.938276621510581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 312}], {
             RGBColor[
             0.30873964227789213`, 0.4414993262325967, 0.94090594022812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 330}], {
             RGBColor[
             0.35108739411085677`, 0.4785159874384777, 0.9435919561917191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 350}], {
             RGBColor[
             0.3407486011316858, 0.46956104460276427`, 0.942933177445322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 354}], {
             RGBColor[
             0.47808190281254476`, 0.5833188300681224, 0.9531277826523236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 372}], {
             RGBColor[
             0.42989871413957137`, 0.5442233725388745, 0.9493197032138938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 376}], {
             RGBColor[
             0.38959354023417225`, 0.5115018166350789, 0.946146732281344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 400}], {
             RGBColor[
             0.3068233627033585, 0.43948519490061944`, 0.9407968109412319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 414}], {
             RGBColor[
             0.4331786186265695, 0.5468861467594329, 0.9495779093097965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 415}], {
             RGBColor[
             0.30275445796143857`, 0.43520851803340055`, 0.9405650928355848]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 476}], {
             RGBColor[
             0.27831597424145443`, 0.4098581135527001, 0.9391610550502397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 235}], {
             RGBColor[
             0.2802039247533765, 0.4109953158467531, 0.9392995894746672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[
             0.3236937091535074, 0.4547889543750613, 0.9418464548095213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 262}], {
             RGBColor[
             0.5446789197438267, 0.6355797337712862, 0.9596661690749291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 296}], {
             RGBColor[
             0.3195232340438674, 0.4511766984492649, 0.9415807158233414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 332}], {
             RGBColor[
             0.41336704967959653`, 0.5309523385528478, 0.9479767925415625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 393}], {
             RGBColor[
             0.27731750333015615`, 0.4079615039212601, 0.9391352120446925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 468}], {
             RGBColor[
             0.30749196458962214`, 0.4396767758763023, 0.9408536029743041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 239}], {
             RGBColor[
             0.28598894280573905`, 0.4160060077202479, 0.9396682057094732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 249}], {
             RGBColor[
             0.26204195746693804`, 0.39275309009042403`, 0.9382342738701814]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 260}], {
             RGBColor[
             0.29267686459117404`, 0.4217987494260689, 0.940094354171744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 262}], {
             RGBColor[
             0.5069741533960583, 0.5967967871164728, 0.9574879199748809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 296}], {
             RGBColor[
             0.2818184676960991, 0.41239375179445154`, 0.9394024667232932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 332}], {
             RGBColor[
             0.37566228333182816`, 0.49216939189803444`, 0.9457985434415144]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 344}], {
             RGBColor[
             0.28719224146549027`, 0.4170482445397752, 0.9397448788360372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 393}], {
             RGBColor[
             0.2396127369823878, 0.36917855726644677`, 0.9369569629446444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 424}], {
             RGBColor[
             0.258614308451333, 0.3891504136495234, 0.938039074329495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 440}], {
             RGBColor[
             0.2610477330574249, 0.39170809719855737`, 0.9381776542608828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 453}], {
             RGBColor[
             0.35991293537024016`, 0.47938336172277696`, 0.9445586970782156]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 243}], {
             RGBColor[
             0.26776109193871905`, 0.39876426303433504`, 0.9385599701176481]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 276}], {
             RGBColor[
             0.3772299493802354, 0.49746865671648904`, 0.9455554330560079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 283}], {
             RGBColor[
             0.28928947202047667`, 0.42139195547839686`, 0.9397859795149199]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 292}], {
             RGBColor[
             0.30771656630120964`, 0.43793788052105365`, 0.9409387068891866]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 396}], {
             RGBColor[
             0.3251799326146204, 0.4530637706874179, 0.9420514571484285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 422}], {
             RGBColor[
             0.3017990197957033, 0.4328123991625194, 0.9405616460585365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 267}], {
             RGBColor[
             0.2674003823141685, 0.3983851343486213, 0.938539428238152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 270}], {
             RGBColor[
             0.33692224970456935`, 0.4637757886708876, 0.9427798434240822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 329}], {
             RGBColor[
             0.32556825174964243`, 0.45394152631086004`, 0.9420563767143404]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 426}], {
             RGBColor[
             0.34219225259067454`, 0.4683404002927851, 0.9431156433479042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 448}], {
             RGBColor[
             0.40649984846755893`, 0.5219316924828338, 0.9477959107751488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 489}], {
             RGBColor[
             0.2505252702505092, 0.3806483216258134, 0.9375784155706177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 265}], {
             RGBColor[
             0.3108668683459195, 0.43269415824205665`, 0.9414313483407886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 328}], {
             RGBColor[
             0.25950406813811605`, 0.38820628227145826`, 0.9381585561298882]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 343}], {
             RGBColor[
             0.3132583325493639, 0.43476552433659443`, 0.9415837303251432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 431}], {
             RGBColor[
             0.31900858761708273`, 0.43974610626002925`, 0.9419501314933074]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 433}], {
             RGBColor[
             0.43605754252337336`, 0.5343039039039512, 0.9515424281972649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 436}], {
             RGBColor[
             0.21145292861051068`, 0.33958081323263134`, 0.9353533035165693]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 462}], {
             RGBColor[
             0.29607225267124365`, 0.41987980574365735`, 0.9404886485123631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 465}], {
             RGBColor[
             0.2829650893968573, 0.4085270397005651, 0.9396534716587286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 262}], {
             RGBColor[
             0.5504639377961893, 0.640590425644781, 0.9600347853097351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 263}], {
             RGBColor[
             0.3706206394231638, 0.49543470275854246`, 0.9448365973104487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 296}], {
             RGBColor[
             0.32530825209623004`, 0.45618739032275973`, 0.9419493320581473]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 332}], {
             RGBColor[
             0.4191520677319591, 0.5359630304263426, 0.9483454087763685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 393}], {
             RGBColor[
             0.28310252138251873`, 0.41297219579475497`, 0.9395038282794985]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 424}], {
             RGBColor[
             0.3021040928514639, 0.4329440521778316, 0.940585939664349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 440}], {
             RGBColor[
             0.30453751745755586`, 0.43550173572686557`, 0.940724519595737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 453}], {
             RGBColor[
             0.4034027197703711, 0.5231770002510852, 0.9471055624130698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 251}], {
             RGBColor[
             0.5646936870819825, 0.28942333675672277`, 0.5526618493719339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 310}], {
             RGBColor[
             0.5607575974155735, 0.2855934331466131, 0.5524264476632337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 352}], {
             RGBColor[
             0.6741496801719704, 0.38211990138833707`, 0.5602189327464373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 367}], {
             RGBColor[
             0.5371092150368568, 0.26073748387253814`, 0.5510797072714124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 382}], {
             RGBColor[
             0.5776648522776203, 0.30065830809946525`, 0.5534883605482489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 399}], {
             RGBColor[
             0.5654203225754866, 0.29005271189943427`, 0.5527081499430414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 412}], {
             RGBColor[
             0.6147550941661437, 0.3327840114135426, 0.5558517179637725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 416}], {
             RGBColor[
             0.5219309513185014, 0.2447841663470438, 0.550215327606881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 429}], {
             RGBColor[
             0.5507766161621386, 0.275102789018491, 0.5518580455463892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 402}], {
             RGBColor[
             0.6591938380581435, 0.7230932102498733, 0.8173009857874498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 417}], {
             RGBColor[
             0.7304764700717994, 0.7844904807973461, 0.8219381452000416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 436}], {
             RGBColor[
             0.613964967278927, 0.676912248549549, 0.8146755656431439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 461}], {
             RGBColor[
             0.6180251514702465, 0.6811797595651721, 0.8149067871263354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 339}], {
             RGBColor[
             0.2801555830106085, 0.41130467001282967`, 0.9392836491008374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 365}], {
             RGBColor[
             0.23256322885258746`, 0.3617690772573957, 0.9365555038854649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 374}], {
             RGBColor[
             0.44131866563802136`, 0.5459265726202192, 0.9509258946184195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 276}], {
             RGBColor[
             0.36882755216676366`, 0.48863720450237713`, 0.9450769289649333]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 326}], {
             RGBColor[
             0.3865707980939931, 0.503041970870222, 0.9464737422799763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 428}], {
             RGBColor[
             0.26169997715555093`, 0.3923936471003522, 0.9382147985973623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 454}], {
             RGBColor[
             0.40021981322154804`, 0.5141228562318955, 0.9475482427488072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 469}], {
             RGBColor[
             0.3311506268521201, 0.456681567875556, 0.9424887937349842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 471}], {
             RGBColor[
             0.2682843190716499, 0.3993142079255616, 0.9385897671288232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 475}], {
             RGBColor[
             0.3501811004896471, 0.4731648076409654, 0.9437013986871804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 495}], {
             RGBColor[
             0.26648841766495435`, 0.3974266016803988, 0.9384874932005101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 274}], {
             RGBColor[
             0.40465733387738523`, 0.5173434113671104, 0.9479323548343548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 313}], {
             RGBColor[
             0.5869282178765687, 0.6755337939439208, 0.9606242857815981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 334}], {
             RGBColor[
             0.39339805142375683`, 0.5055091916286076, 0.9472911553552363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 340}], {
             RGBColor[
             0.44604108996932057`, 0.5580494358944003, 0.9503912880314305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 355}], {
             RGBColor[
             0.4561323830412466, 0.5667900067501652, 0.9510342963025935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 363}], {
             RGBColor[
             0.41869207061248315`, 0.5320948095294028, 0.9487316123288863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 378}], {
             RGBColor[
             0.3930600725794523, 0.5051539544341471, 0.947271907960048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 379}], {
             RGBColor[
             0.4318227414071683, 0.5457342170048416, 0.9494853074338421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 380}], {
             RGBColor[
             0.40410341061947747`, 0.5167612029022863, 0.9479008097242729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 390}], {
             RGBColor[
             0.631635535156964, 0.7107911782646735, 0.9648535162706321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 498}], {
             RGBColor[
             0.4071518362656757, 0.5199652915377899, 0.9480744130550823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 394}], {
             RGBColor[
             0.32485295739266246`, 0.4536781864424829, 0.9419977561185942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 438}], {
             RGBColor[
             0.4043999708199356, 0.5246926618158645, 0.946988986437161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 445}], {
             RGBColor[
             0.32390286655207123`, 0.452679580729783, 0.9419436498507558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 460}], {
             RGBColor[
             0.2949186529541634, 0.4222153345330989, 0.9402930417646566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 256}], {
             RGBColor[
             0.3123114563715824, 0.4436116977135667, 0.9411694652542291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 288}], {
             RGBColor[
             0.38078698247310544`, 0.5042402781331429, 0.9454843876998468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 333}], {
             RGBColor[
             0.5754040195489128, 0.6601073470348737, 0.9625072594955594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 392}], {
             RGBColor[
             0.30706766217182835`, 0.43810013753387, 0.9408708389320514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 442}], {
             RGBColor[
             0.31153940612296205`, 0.4428002239514536, 0.9411254981347161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 444}], {
             RGBColor[
             0.29366455363836497`, 0.42401262065903644`, 0.9401075517291928]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 459}], {
             RGBColor[
             0.29246865690359136`, 0.422755657366557, 0.9400394471793181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 492}], {
             RGBColor[
             0.3245806333599376, 0.45555716354456427`, 0.9419029688356788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 255}], {
             RGBColor[
             0.3275689847631301, 0.4571372574779622, 0.9421303014965905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 269}], {
             RGBColor[
             0.5842722754085252, 0.6650597402739178, 0.9639013312163518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 360}], {
             RGBColor[
             0.25894655425284246`, 0.3894996250525104, 0.9380579952363773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 369}], {
             RGBColor[
             0.38121399627469793`, 0.503295883528601, 0.9456330592151129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 370}], {
             RGBColor[
             0.3274864972676159, 0.4570658109552898, 0.9421250454663173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 425}], {
             RGBColor[
             0.30787471525164, 0.44007907108987665`, 0.9408754000582771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 466}], {
             RGBColor[
             0.312494663913945, 0.4440806384157937, 0.941169779101779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 468}], {
             RGBColor[
             0.2974579887401173, 0.4299775844646125, 0.9402511644578659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 286}], {
             RGBColor[
             0.22133035891772468`, 0.34996261875076606`, 0.9359158085602164]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 294}], {
             RGBColor[
             0.28955079731709527`, 0.415606972513488, 0.9400227351630268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 313}], {
             RGBColor[
             0.41276088977412323`, 0.5177803709296632, 0.9491293678454951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 380}], {
             RGBColor[
             0.22993608251703207`, 0.3590077798880287, 0.9364058917881699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 411}], {
             RGBColor[
             0.25538853775186104`, 0.3857599241187032, 0.9378553714602602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 478}], {
             RGBColor[
             0.28165702130215503`, 0.40876978048206536`, 0.9395197507355468]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 260}], {
             RGBColor[
             0.3122196636525039, 0.44233947032455323`, 0.9412072876673063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 280}], {
             RGBColor[
             0.30843530195280877`, 0.43906164642782686`, 0.9409661514861815]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 296}], {
             RGBColor[
             0.3013612667574289, 0.4329344726929359, 0.9405154002188556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 424}], {
             RGBColor[
             0.27815710751266287`, 0.40969113454800776`, 0.9391520078250573]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 440}], {
             RGBColor[
             0.2805905321187548, 0.4122488180970417, 0.9392905877564452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 470}], {
             RGBColor[
             0.3164895604824214, 0.446037840347373, 0.9414793617175872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 339}], {
             RGBColor[
             0.2791889906041152, 0.4102887201081069, 0.939228603093233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 365}], {
             RGBColor[
             0.23159663644609413`, 0.36075312735267295`, 0.9365004578778605]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 305}], {
             RGBColor[
             0.2758810491777799, 0.40699167673582726`, 0.9390336368951333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 367}], {
             RGBColor[
             0.2844839021188392, 0.4160338206292609, 0.9395235566433462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 382}], {
             RGBColor[
             0.3250395393596027, 0.455954644856188, 0.9419322099201828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 416}], {
             RGBColor[
             0.2693056384004839, 0.4000805031037666, 0.9386591769788148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 427}], {
             RGBColor[
             0.42265424291511366`, 0.5383335221071088, 0.9487517300692887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 429}], {
             RGBColor[
             0.2981513032441211, 0.4303991257752138, 0.9403018949183231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 499}], {
             RGBColor[
             0.30762442040549615`, 0.4403559725421378, 0.9408413749264424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 282}], {
             RGBColor[
             0.33329049261991683`, 0.46158641923159127`, 0.9425134171249244]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 432}], {
             RGBColor[
             0.30267104773324927`, 0.4350653950488076, 0.9405623731724579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 467}], {
             RGBColor[
             0.29450281951597845`, 0.42687151424149183`, 0.9400828719423322]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 261}], {
             RGBColor[
             0.534004706576626, 0.6237267733068386, 0.9592617085416454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 277}], {
             RGBColor[
             0.31421989806707584`, 0.44444184351645505`, 0.9413211980581346]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 291}], {
             RGBColor[
             0.2849097288408444, 0.416788567704847, 0.9395365596200893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 311}], {
             RGBColor[
             0.2943915089823741, 0.42675451981317825`, 0.9400765329721127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 319}], {
             RGBColor[
             0.2702596535762901, 0.4013904097333798, 0.938702259506617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 377}], {
             RGBColor[
             0.34229529523648583`, 0.4687593414341064, 0.9431101375396704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 484}], {
             RGBColor[
             0.31215815057763907`, 0.4426560614675468, 0.9411898253312394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 488}], {
             RGBColor[
             0.3032359223212674, 0.4349280757961089, 0.9406213088363601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 315}], {
             RGBColor[
             0.26554623276727407`, 0.396436305614964, 0.9384338371644247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 325}], {
             RGBColor[
             0.28091831401092354`, 0.4125933376482833, 0.9393092544502943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 347}], {
             RGBColor[
             0.2947394919269464, 0.42712027195131663`, 0.9400963500860113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 368}], {
             RGBColor[
             0.2918000598317529, 0.42403074244850925`, 0.9399289537766902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 386}], {
             RGBColor[
             0.28401741495266886`, 0.4158506892324063, 0.9394857436642177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 401}], {
             RGBColor[
             0.2723954727191816, 0.4036352910713138, 0.9388238912471434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 454}], {
             RGBColor[
             0.4180211220241353, 0.5328331604515816, 0.9485620009504381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 471}], {
             RGBColor[
             0.2860856278742372, 0.4180245121452477, 0.9396035253304542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 269}], {
             RGBColor[
             0.6140005207695203, 0.6918171180736932, 0.9657586711711035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 274}], {
             RGBColor[
             0.30673099448910324`, 0.43523520849506736`, 0.9409436087775287]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 334}], {
             RGBColor[
             0.29547171203547484`, 0.4234009887565646, 0.9403024092984104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 338}], {
             RGBColor[
             0.32263735294905294`, 0.45195379975785027`, 0.9418494523604743]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 369}], {
             RGBColor[
             0.41094224163569293`, 0.5300532613283764, 0.9474903991698644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 370}], {
             RGBColor[
             0.3572147426286109, 0.4838231887550652, 0.9439823854210688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 379}], {
             RGBColor[
             0.3338964020188863, 0.4636260141327986, 0.9424965613770162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 390}], {
             RGBColor[
             0.533709195768682, 0.6286829753926305, 0.9578647702138061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 425}], {
             RGBColor[
             0.337602960612635, 0.46683644888965203`, 0.9427327400130288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 466}], {
             RGBColor[
             0.34222290927494, 0.4708380162155691, 0.9430271190565307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 271}], {
             RGBColor[
             0.31371612780677927`, 0.444828353509895, 0.9412589696759777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 333}], {
             RGBColor[
             0.5575776226506255, 0.6433484966318868, 0.9614196547755054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 442}], {
             RGBColor[
             0.2937130092246746, 0.4260413735484667, 0.9400378934146622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 444}], {
             RGBColor[
             0.2758381567400775, 0.4072537702560496, 0.9390199470091389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 492}], {
             RGBColor[
             0.3067542364616502, 0.4387983131415774, 0.9408153641156247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 272}], {
             RGBColor[
             0.45733037019135736`, 0.5624973906125226, 0.9518612676644727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 306}], {
             RGBColor[
             0.43250550911001784`, 0.5364048876289329, 0.9504475285509812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 317}], {
             RGBColor[
             0.4742889436784011, 0.5801988366142758, 0.9528315402633272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 357}], {
             RGBColor[
             0.6176699197499559, 0.7004912924226239, 0.9630443851636357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 418}], {
             RGBColor[
             0.7355785576539076, 0.793402148127925, 0.9742924845229431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 420}], {
             RGBColor[
             0.4868432674033458, 0.5910727608261654, 0.9536314906697281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 289}], {
             RGBColor[
             0.3389846561184968, 0.462575185664395, 0.9430206252202316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 297}], {
             RGBColor[
             0.27211292059160214`, 0.4033383108703882, 0.9388078003214761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 314}], {
             RGBColor[
             0.24518979087451165`, 0.375040394512709, 0.937274567913289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 373}], {
             RGBColor[
             0.25837365932212203`, 0.3888974761566867, 0.9380253697175949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 381}], {
             RGBColor[
             0.3078594194548105, 0.4356160700661915, 0.9410373526629876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 397}], {
             RGBColor[
             0.3217210149358394, 0.4476222873678123, 0.9419206012697111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 472}], {
             RGBColor[
             0.2548501274995149, 0.38519402080630577`, 0.9378247097928956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 341}], {
             RGBColor[
             0.3229537044873252, 0.45398427122965357`, 0.9418052972615587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 405}], {
             RGBColor[
             0.31877389710324655`, 0.4495910286538922, 0.9415672634145065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 450}], {
             RGBColor[
             0.30566914143449336`, 0.43581709955653336`, 0.9408209669659195]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 454}], {
             RGBColor[
             0.4400066013779004, 0.5531503662052724, 0.9499162309844539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 469}], {
             RGBColor[
             0.37093741500847244`, 0.4957090778489329, 0.9448567819706308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 471}], {
             RGBColor[
             0.30807110722800224`, 0.4383417178989385, 0.9409577553644699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 475}], {
             RGBColor[
             0.3899678886459994, 0.5121923176143423, 0.946069386922827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 491}], {
             RGBColor[
             0.4875171979489068, 0.5917216088295998, 0.9536564391835731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 500}], {
             RGBColor[
             0.3454632727627437, 0.47364465620330026`, 0.9432335921526326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 280}], {
             RGBColor[
             0.3390702090770449, 0.4681073057634717, 0.942826231787744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 424}], {
             RGBColor[
             0.30879201463689887`, 0.4387367938836526, 0.94101208812662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 440}], {
             RGBColor[
             0.31122543924299084`, 0.44129447743268657`, 0.9411506680580078]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 470}], {
             RGBColor[
             0.34712446760665744`, 0.47508349968301783`, 0.9433394420191499]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 483}], {
             RGBColor[
             0.3056326518172877, 0.43541610324506885`, 0.9408321670879016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 484}], {
             RGBColor[
             0.5605776317968535, 0.6488842774016733, 0.9608765057254846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 500}], {
             RGBColor[
             0.5672092311416879, 0.6546282354402944, 0.9612990653716444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 332}], {
             RGBColor[
             0.6401372783222783, 0.7167538098225676, 0.9661651230417763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 344}], {
             RGBColor[
             0.5516672364559404, 0.6416326624643083, 0.9601114584362991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 387}], {
             RGBColor[
             0.4854908968181383, 0.5742165223359397, 0.9562644802943984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 393}], {
             RGBColor[
             0.504087731972838, 0.5937629751909799, 0.9573235425449063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 424}], {
             RGBColor[
             0.5230893034417832, 0.6137348315740565, 0.9584056539297569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 296}], {
             RGBColor[
             0.36645016431352384`, 0.4918224468327461, 0.9445708583242687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 323}], {
             RGBColor[
             0.4108023815267209, 0.5302381081755632, 0.9473969423859678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 342}], {
             RGBColor[
             0.3620671339642804, 0.48802608624174226`, 0.9442915755061765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 395}], {
             RGBColor[
             0.35189104050047165`, 0.477665589053454, 0.9436997879091228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 440}], {
             RGBColor[
             0.34567942967484966`, 0.4711367922368519, 0.9433460458618583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 447}], {
             RGBColor[
             0.6708888743648083, 0.6456551836598937, 0.6050024561406462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 453}], {
             RGBColor[
             0.4445446319876649, 0.5588120567610715, 0.9497270886791912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 463}], {
             RGBColor[
             0.7008171647602, 0.7605747466927593, 0.8824862526559774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 394}], {
             RGBColor[
             0.3133500758529717, 0.4437149686044395, 0.9412648026784838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 398}], {
             RGBColor[
             0.2767497473180145, 0.40524570271933913`, 0.9391804681137519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 445}], {
             RGBColor[
             0.31239998501238053`, 0.44271636289173955`, 0.9412106964106456]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 328}], {
             RGBColor[
             0.38043531552122956`, 0.5039356818947229, 0.9454619797926401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 433}], {
             RGBColor[
             0.5569887899064868, 0.650033303527216, 0.9588458518600168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 462}], {
             RGBColor[
             0.41700350005435716`, 0.5356092053669221, 0.9477920721751152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 364}], {
             RGBColor[
             0.571421622539154, 0.6457007601094098, 0.9640560628479675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 374}], {
             RGBColor[
             0.43117141854238306`, 0.535261172550078, 0.9503480239078297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 410}], {
             RGBColor[
             0.2361841584731277, 0.3655749038687814, 0.9367617104706694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 437}], {
             RGBColor[
             0.2468449055074403, 0.37678002493224577`, 0.9373688242431116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 278}], {
             RGBColor[
             0.27893835126125543`, 0.4105122712614932, 0.9391964985007931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 329}], {
             RGBColor[
             0.31094929747263383`, 0.4385760784704879, 0.9412238488950695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 406}], {
             RGBColor[
             0.2881047029269041, 0.41878923887768416`, 0.9397682115312973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 413}], {
             RGBColor[
             0.24962716961350437`, 0.37970436091345217`, 0.9375272700679611]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 476}], {
             RGBColor[
             0.25532575108410227`, 0.3856939313499841, 0.9378517958524157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 486}], {
             RGBColor[
             0.41086570180841675`, 0.5219789667224825, 0.9484579365551981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 493}], {
             RGBColor[
             0.33479553442734805`, 0.4592304903739427, 0.9427433100274245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 275}], {
             RGBColor[
             0.30070873485201, 0.43244410764290475`, 0.940471081742474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 285}], {
             RGBColor[
             0.2979106494482142, 0.4295031424746541, 0.9403117349181241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 324}], {
             RGBColor[
             0.3273506912142862, 0.45795644843084504`, 0.9420794744726919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 353}], {
             RGBColor[
             0.3346316796593649, 0.4642628746688524, 0.9425434126180869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 441}], {
             RGBColor[
             0.604033775657701, 0.6825537291594692, 0.9654139426486945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 480}], {
             RGBColor[
             0.28268091829885256`, 0.4134957294159486, 0.9394444242595361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 481}], {
             RGBColor[
             0.5863504244613744, 0.6684535049172995, 0.9637272888254749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 360}], {
             RGBColor[
             0.5453780902592326, 0.6241794856482414, 0.9616863649108902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 369}], {
             RGBColor[
             0.667645532281088, 0.737975744124332, 0.9692614288896257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 425}], {
             RGBColor[
             0.5943062512580302, 0.6747589316856076, 0.9645037697327901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 466}], {
             RGBColor[
             0.598926199920335, 0.6787604990115247, 0.964798148776292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 468}], {
             RGBColor[
             0.5838895247465075, 0.6646574450603435, 0.9638795341323788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 309}], {
             RGBColor[
             0.32356539951774693`, 0.4497368922513223, 0.9420191905656317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 345}], {
             RGBColor[
             0.383869564275913, 0.5069102555556685, 0.9456808070865016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 375}], {
             RGBColor[
             0.45891226832269894`, 0.5699350043422362, 0.951007737389541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 426}], {
             RGBColor[
             0.39709516570406667`, 0.5183656067746794, 0.9465235307145634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 489}], {
             RGBColor[
             0.3054281833639013, 0.4306735281077076, 0.9409863029372769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 284}], {
             RGBColor[
             0.3069687806535515, 0.43773646384533416`, 0.9408747182374069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 442}], {
             RGBColor[
             0.3129440775581589, 0.4440168797477819, 0.9412150025564647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 444}], {
             RGBColor[
             0.2950692250735618, 0.4252292764553648, 0.9401970561509414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 464}], {
             RGBColor[
             0.5310343439458123, 0.6255591888423668, 0.9580358765769861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 492}], {
             RGBColor[
             0.32598530479513443`, 0.4567738193408926, 0.9419924732574273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 306}], {
             RGBColor[
             0.2513353156053655, 0.3814997306536093, 0.937624546455222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 317}], {
             RGBColor[
             0.2931187501737488, 0.42529367963895226`, 0.9400085581675679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 357}], {
             RGBColor[
             0.43649972624530353`, 0.5455861354473004, 0.9502214030678764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 308}], {
             RGBColor[
             0.43840864773892935`, 0.5535477309677919, 0.9493221958528526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 421}], {
             RGBColor[
             0.3479739248626753, 0.46705652580875434`, 0.9438585965552035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 423}], {
             RGBColor[
             0.5389895881877318, 0.6366150547518663, 0.9568503812475062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 446}], {
             RGBColor[
             0.5197045826867778, 0.6209586185065946, 0.9553321949711683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 477}], {
             RGBColor[
             0.42117313008304585`, 0.5386191918565713, 0.9482239639085894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 334}], {
             RGBColor[
             0.24490547640045296`, 0.37474156197389447`, 0.937258376624597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 340}], {
             RGBColor[
             0.29754851494601664`, 0.42728180623968703`, 0.9403585093007911]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 361}], {
             RGBColor[
             0.28018873833068914`, 0.4118265073505871, 0.9392677061946155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 363}], {
             RGBColor[
             0.2701994955891793, 0.4013271798746896, 0.9386988335982468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 369}], {
             RGBColor[
             0.36037600600067105`, 0.48139383454570617`, 0.9444463664960511]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 370}], {
             RGBColor[
             0.30664850699358903`, 0.43516376197239504`, 0.9409383527472555]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 379}], {
             RGBColor[
             0.28333016638386443`, 0.4149665873501284, 0.9394525287032027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 498}], {
             RGBColor[
             0.2586592612423718, 0.3891976618830768, 0.9380416343244429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 282}], {
             RGBColor[
             0.32830637954059805`, 0.45634780037420597`, 0.9422295792583917]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 285}], {
             RGBColor[
             0.27959597085021887`, 0.41120347114498385`, 0.9392339489635235]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 324}], {
             RGBColor[
             0.3090360126162909, 0.4396567771011748, 0.9410016885180913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 353}], {
             RGBColor[
             0.31631700106136956`, 0.44596320333918216`, 0.9414656266634864]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 441}], {
             RGBColor[
             0.5857190970597057, 0.6642540578297988, 0.9643361566940939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 481}], {
             RGBColor[
             0.5680357458633791, 0.6501538335876291, 0.9626495028708743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 283}], {
             RGBColor[
             0.3903559322485213, 0.511264896946439, 0.9463029383622052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 292}], {
             RGBColor[
             0.40878302652925425`, 0.5278108219890958, 0.9474556657364718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 396}], {
             RGBColor[
             0.4262463928426651, 0.54293671215546, 0.9485684159957137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 422}], {
             RGBColor[
             0.4028654800237479, 0.5226853406305615, 0.9470786049058217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 291}], {
             RGBColor[
             0.31354440155050856`, 0.44373185384859004`, 0.9412827295308237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 311}], {
             RGBColor[
             0.3230261816920383, 0.4536978059569212, 0.9418227028828471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 319}], {
             RGBColor[
             0.29889432628595425`, 0.4283336958771228, 0.9404484294173514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 331}], {
             RGBColor[
             0.30048389702629547`, 0.43000443550982737`, 0.9405389531194547]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 377}], {
             RGBColor[
             0.37092996794614996`, 0.49570262757784944`, 0.9448563074504048]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 419}], {
             RGBColor[
             0.2785266772728737, 0.406926005380841, 0.9392885219372931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 449}], {
             RGBColor[
             0.5686274891953951, 0.6553480164228951, 0.9616047172860507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 484}], {
             RGBColor[
             0.3407928232873032, 0.46959934761128985`, 0.9429359952419738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 488}], {
             RGBColor[
             0.3318705950309316, 0.461871361939852, 0.9423674787470945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 329}], {
             RGBColor[
             0.33710622069672935`, 0.46606866322373197`, 0.9427134469769816]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 406}], {
             RGBColor[
             0.3142616261509996, 0.4462818236309282, 0.9412578096132094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 413}], {
             RGBColor[
             0.2757840928375999, 0.4071969456666962, 0.9390168681498732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 486}], {
             RGBColor[
             0.4370226250325123, 0.5494715514757265, 0.9499475346371101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 493}], {
             RGBColor[
             0.36095245765144357`, 0.48672307512718677`, 0.9442329081093366]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.28052767151646363`, 0.41218274761844126`, 0.9392870079381386]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 324}], {
             RGBColor[
             0.3099677132825357, 0.4406360535746322, 0.9410547474927063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 481}], {
             RGBColor[
             0.5689674465296238, 0.6511331100610867, 0.9627025618454893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 494}], {
             RGBColor[
             0.2984515037309614, 0.4306612916825806, 0.9403209448034643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 327}], {
             RGBColor[
             0.4541495653474271, 0.5645332525374798, 0.9510569733838214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 470}], {
             RGBColor[
             0.3433401059069623, 0.47180567578629146`, 0.9430983058380249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 483}], {
             RGBColor[
             0.3018482901175926, 0.4321382793483425, 0.9405910309067766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 288}], {
             RGBColor[
             0.36229961155660445`, 0.4867867021288403, 0.944359141487279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 343}], {
             RGBColor[
             0.36487207778639486`, 0.48901484308117266`, 0.9445230567606986]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 465}], {
             RGBColor[
             0.33457883463388827`, 0.4627763584451433, 0.9425927980942841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 324}], {
             RGBColor[
             0.3549483359028742, 0.4818601411621463, 0.9438379719886096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 353}], {
             RGBColor[
             0.3622293243479529, 0.48816656740015363`, 0.9443019101340049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 432}], {
             RGBColor[
             0.3435992579405138, 0.4720301402523938, 0.9431148187764437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 441}], {
             RGBColor[
             0.631631420346289, 0.7064574218907704, 0.9671724401646122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 467}], {
             RGBColor[
             0.335431029723243, 0.46383625944507806`, 0.942635317546318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 292}], {
             RGBColor[
             0.3208425491694955, 0.45173412075100355`, 0.941686212195384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 386}], {
             RGBColor[
             0.2877444862318391, 0.419768077456782, 0.9396979948598587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 422}], {
             RGBColor[
             0.31492500266398915`, 0.4466086393924693, 0.9413091513647339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 442}], {
             RGBColor[
             0.2869656620714468, 0.41894948388390585`, 0.9396536419760915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 444}], {
             RGBColor[
             0.2690908095868497, 0.4001618805914887, 0.9386356955705681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 464}], {
             RGBColor[
             0.5050559284591002, 0.6004917929784908, 0.9564745159966128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 324}], {
             RGBColor[
             0.3062379272124951, 0.4367158119329242, 0.9408423416937415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 480}], {
             RGBColor[
             0.26156815429706143`, 0.3922550929180277, 0.9382072914805859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 481}], {
             RGBColor[
             0.5652376604595832, 0.6472128684193785, 0.9624901560465244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 294}], {
             RGBColor[
             0.3060659035390216, 0.43296539627094566`, 0.9409632460304552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 346}], {
             RGBColor[
             0.39917506132415026`, 0.5107014998888193, 0.9477002228721947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 358}], {
             RGBColor[
             0.27570115485180396`, 0.4066649771347224, 0.9390284310945987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 407}], {
             RGBColor[
             0.22911463617680608`, 0.35814438770174506`, 0.9363591116343148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 411}], {
             RGBColor[
             0.27190364397378736`, 0.4031183478761609, 0.9387958823276886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 295}], {
             RGBColor[
             0.24059566696206824`, 0.37021167899645113`, 0.9370129393528726]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 299}], {
             RGBColor[
             0.2885358618333167, 0.4175823086581807, 0.9398535499902183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 300}], {
             RGBColor[
             0.23449426350373395`, 0.363798717110419, 0.936665473452138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 301}], {
             RGBColor[
             0.25411397400587754`, 0.3844202768096656, 0.9377827869404745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 389}], {
             RGBColor[
             0.3422885813868548, 0.46414021264521543`, 0.9432786257485062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 451}], {
             RGBColor[
             0.30043229914884534`, 0.4278864047285664, 0.9406115804563573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 456}], {
             RGBColor[
             0.2893215188531271, 0.41826280528047044`, 0.9399036113607915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 343}], {
             RGBColor[
             0.43400857790613145`, 0.5503381491020646, 0.9488756206988302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 392}], {
             RGBColor[
             0.35771679137506396`, 0.48196986755045934`, 0.9440981566576151]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 465}], {
             RGBColor[
             0.40371533475362487`, 0.5240996644660352, 0.9469453620324155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 492}], {
             RGBColor[
             0.3752297625631732, 0.4994268935611536, 0.9451302865612425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 291}], {
             RGBColor[
             0.35624534923429485`, 0.4807172685202512, 0.9440035961582691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 297}], {
             RGBColor[
             0.3613847306174177, 0.48611908420951366`, 0.9442962763250045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 314}], {
             RGBColor[
             0.3344616009003273, 0.4578211678518344, 0.9427630439168173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 349}], {
             RGBColor[
             0.42746810855504785`, 0.544673123283704, 0.9484588677752892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 359}], {
             RGBColor[
             0.3273187134845432, 0.45031354029262577`, 0.9423562670454434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 381}], {
             RGBColor[
             0.39713122948062607`, 0.518396843405317, 0.9465258286665159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 397}], {
             RGBColor[
             0.410992824961655, 0.5304030607069377, 0.9474090772732394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 419}], {
             RGBColor[
             0.32122762495666, 0.44391142005250217`, 0.9420093885647385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 472}], {
             RGBColor[
             0.3441219375253305, 0.4679747941454312, 0.9433131857964239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 316}], {
             RGBColor[
             0.30779388742542013`, 0.4366171005132307, 0.9409944461098991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 340}], {
             RGBColor[
             0.30004301733430705`, 0.4299036864103666, 0.9405005675215188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 355}], {
             RGBColor[
             0.3101343104062332, 0.4386442572661316, 0.9411435757926818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 362}], {
             RGBColor[
             0.30076321375197823`, 0.43052748434922883`, 0.940546457800408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 378}], {
             RGBColor[
             0.24706199994443884`, 0.37700820495011356`, 0.9373811874501363]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 384}], {
             RGBColor[
             0.34925067923486824`, 0.47252488989963265`, 0.9436360362251955]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 297}], {
             RGBColor[
             0.2893736137074001, 0.42148039372624446`, 0.9397907712595137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 311}], {
             RGBColor[
             0.2937160124658069, 0.4260445301453132, 0.9400380644448016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 319}], {
             RGBColor[
             0.2695841570597229, 0.40068042006551474`, 0.9386637909793061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 349}], {
             RGBColor[
             0.3554569916450302, 0.4800344328004348, 0.9439533627097983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 359}], {
             RGBColor[
             0.25530759657452556`, 0.38567484980935657`, 0.9378507619799525]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 419}], {
             RGBColor[
             0.24921650804664236`, 0.37927272956923297`, 0.9375038834992476]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 488}], {
             RGBColor[
             0.3025604258047002, 0.434218086128244, 0.940582840309049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 308}], {
             RGBColor[
             0.3703073879080383, 0.49516338004061966`, 0.9448166372009024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 386}], {
             RGBColor[
             0.3061715805125721, 0.43631400249943886`, 0.9408507222341252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 422}], {
             RGBColor[
             0.3333520969447221, 0.4631545644351261, 0.9424618787390004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 298}], {
             RGBColor[
             0.24753239335827026`, 0.37750261825271536`, 0.9374079756591692]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 317}], {
             RGBColor[
             0.2764554854428187, 0.4077795318947397, 0.9390596098922326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 353}], {
             RGBColor[
             0.2965367965467848, 0.4251729542569518, 0.9403391732785711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 418}], {
             RGBColor[
             0.5377450994183253, 0.6209828434083888, 0.9605205541518484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 420}], {
             RGBColor[
             0.28900980916776353`, 0.4186534561066293, 0.9398595602986335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 432}], {
             RGBColor[
             0.27790673013934564`, 0.4090365271091919, 0.93915208192101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 358}], {
             RGBColor[
             0.34392159325117455`, 0.4723093308974443, 0.9431353576974091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 411}], {
             RGBColor[
             0.34012408237315794`, 0.4687627016388829, 0.9429028089304989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 430}], {
             RGBColor[
             0.3378840404703129, 0.46640827557213305`, 0.9427752418579769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 478}], {
             RGBColor[
             0.36639256592345193`, 0.49177255800224506`, 0.9445671882057856]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 300}], {
             RGBColor[
             0.23940165119627274`, 0.36895669272162795`, 0.9369449419213987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 336}], {
             RGBColor[
             0.2417805869280456, 0.37145710500895834`, 0.937080418792003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 389}], {
             RGBColor[
             0.3471959690793936, 0.4692981882564244, 0.9435580942177668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 409}], {
             RGBColor[
             0.24208865548015665`, 0.37178090458990143`, 0.9370979628402991]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 456}], {
             RGBColor[
             0.2942289065456659, 0.42342078089167934`, 0.940183079830052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 458}], {
             RGBColor[
             0.25786918935278985`, 0.38836724623367513`, 0.9379966408991378]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 332}], {
             RGBColor[
             0.41498159262231915`, 0.5323507745005462, 0.9480796697901885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 395}], {
             RGBColor[
             0.30657865317353783`, 0.4384182766176713, 0.9408125226568214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 424}], {
             RGBColor[
             0.2979336177418239, 0.42933179625203527`, 0.9403202006781691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 440}], {
             RGBColor[
             0.3003670423479159, 0.4318894798010692, 0.940458780609557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 453}], {
             RGBColor[
             0.3992322446607311, 0.5195647443252889, 0.9468398234268898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 311}], {
             RGBColor[
             0.2988553938489298, 0.43144634583457564`, 0.9403307446115372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 314}], {
             RGBColor[
             0.26758986537343254`, 0.3985842930578276, 0.938550219018062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 349}], {
             RGBColor[
             0.36059637302815317`, 0.48543624848969724`, 0.9442460428765338]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 359}], {
             RGBColor[
             0.2604469779576485, 0.39107666549861897`, 0.9381434421466881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 381}], {
             RGBColor[
             0.3302594939537314, 0.45915996861131014`, 0.9423130037677605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 397}], {
             RGBColor[
             0.3441210894347603, 0.4711661859129309, 0.9431962523744841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 419}], {
             RGBColor[
             0.2543558894297653, 0.3846745452584954, 0.9377965636659831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 353}], {
             RGBColor[
             0.3012355426802099, 0.4301116343608934, 0.9406067599196977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 418}], {
             RGBColor[
             0.5424438455517504, 0.6259215235123304, 0.960788140792975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 420}], {
             RGBColor[
             0.29370855530118867`, 0.4235921362105709, 0.9401271469397601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 432}], {
             RGBColor[
             0.28260547627277083`, 0.4139752072131336, 0.9394196685621365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 300}], {
             RGBColor[
             0.2873418460675212, 0.4163273223833575, 0.9397855525587443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 301}], {
             RGBColor[
             0.30696155656966484`, 0.43694888208260413`, 0.9409028660470807]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 389}], {
             RGBColor[
             0.39513616395064205`, 0.516668817918154, 0.9463987048551125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 451}], {
             RGBColor[
             0.3532798817126326, 0.4804150100015049, 0.9437316595629637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 456}], {
             RGBColor[
             0.34216910141691437`, 0.4707914105534089, 0.9430236904673976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 301}], {
             RGBColor[
             0.25291995824008207`, 0.3831652905348425, 0.9377147895090004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 389}], {
             RGBColor[
             0.34109456562105933`, 0.4628852263703923, 0.9432106283170322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 409}], {
             RGBColor[
             0.23598725202182236`, 0.36536794270386935`, 0.9367504969395646]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 451}], {
             RGBColor[
             0.2992382833830498, 0.4266314184537433, 0.9405435830248834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 456}], {
             RGBColor[
             0.2881275030873316, 0.4170078190056473, 0.9398356139293174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 458}], {
             RGBColor[
             0.2517677858944556, 0.381954284347643, 0.9376491749984033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 389}], {
             RGBColor[
             0.36071427612320295`, 0.4835067860696389, 0.9443279418053686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 451}], {
             RGBColor[
             0.3188579938851934, 0.4472529781529899, 0.9416608965132198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 456}], {
             RGBColor[
             0.3077472135894752, 0.43762937870489393`, 0.9409529274176538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 315}], {
             RGBColor[
             0.27660034766088326`, 0.4072853128996209, 0.9390915303212655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 325}], {
             RGBColor[
             0.2919724289045328, 0.4234423449329402, 0.939966947607135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 347}], {
             RGBColor[
             0.30579360682055556`, 0.4379692792359735, 0.9407540432428521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 368}], {
             RGBColor[
             0.30285417472536214`, 0.4348797497331661, 0.9405866469335309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 386}], {
             RGBColor[
             0.29507152984627805`, 0.4266996965170632, 0.9401434368210584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 421}], {
             RGBColor[
             0.2687726143654902, 0.39905786889920647`, 0.9386457524901864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 477}], {
             RGBColor[
             0.34197181958586076`, 0.4706205349470234, 0.9430111198435724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 366}], {
             RGBColor[
             0.4501568676446767, 0.5597614502642987, 0.9510154695756985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 435}], {
             RGBColor[
             0.29824459285330696`, 0.4308043552611561, 0.9402959603984355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 473}], {
             RGBColor[
             0.2990603185258398, 0.431661734662983, 0.9403424147687283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 310}], {
             RGBColor[
             0.32792989656288035`, 0.4580374664174049, 0.942131783369629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 429}], {
             RGBColor[
             0.31794891530944547`, 0.4475468222892828, 0.9415633812527845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 483}], {
             RGBColor[
             0.31003716557622457`, 0.4392310716857616, 0.9411128188098624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 382}], {
             RGBColor[
             0.28885221437341774`, 0.41822664807856974`, 0.9398601480714484]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 416}], {
             RGBColor[
             0.23311831341429884`, 0.36235250632614835`, 0.9365871151300804]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 427}], {
             RGBColor[
             0.3864669179289286, 0.5006055253294905, 0.9466796682205543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 438}], {
             RGBColor[
             0.34232991389877954`, 0.4645463435401068, 0.9432676997967315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 460}], {
             RGBColor[
             0.23284859603300734`, 0.3620690162573412, 0.936571755124227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 499}], {
             RGBColor[
             0.2714370954193111, 0.4026279757645196, 0.938769313077708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 317}], {
             RGBColor[
             0.2682938890924092, 0.39920117665536264`, 0.9385948190540765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 357}], {
             RGBColor[
             0.411674865163964, 0.5194936324637107, 0.948807663954385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 418}], {
             RGBColor[
             0.5295835030679157, 0.6124044881690118, 0.9600557633136925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 420}], {
             RGBColor[
             0.28084821281735395`, 0.4100751008672523, 0.9393947694604774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 372}], {
             RGBColor[
             0.3800882241337261, 0.49220538077362275`, 0.9464707672050887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 417}], {
             RGBColor[
             0.33937614859376686`, 0.4591534837921815, 0.9432657634853366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 386}], {
             RGBColor[
             0.337209324970382, 0.4631973367463982, 0.9428284198653771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 421}], {
             RGBColor[
             0.31091040948959414`, 0.43555550912854146`, 0.9413307355345051]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 422}], {
             RGBColor[
             0.36438984140253194`, 0.4900378986820854, 0.9444395763702523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 423}], {
             RGBColor[
             0.5019260728146506, 0.6051140380716534, 0.9543225202268077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 446}], {
             RGBColor[
             0.4826410673136966, 0.5894576018263817, 0.9528043339504699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 320}], {
             RGBColor[
             0.2697409547994002, 0.40084522443146653`, 0.9386727203786192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 337}], {
             RGBColor[
             0.266667710809505, 0.39761505014316345`, 0.9384977036798517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 348}], {
             RGBColor[
             0.34923946197641575`, 0.4719744747371215, 0.943655119122816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 375}], {
             RGBColor[
             0.39065250502248433`, 0.5058709014407767, 0.9468391971644313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 489}], {
             RGBColor[
             0.23716842006368674`, 0.3666094252062482, 0.9368177627121672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 327}], {
             RGBColor[
             0.43860473907432573`, 0.5506484447507203, 0.9500818732437456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 399}], {
             RGBColor[
             0.30885891999106013`, 0.4415191450460474, 0.9409165976062751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 412}], {
             RGBColor[
             0.3581936915817172, 0.4842504445601557, 0.9440601656270062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 429}], {
             RGBColor[
             0.2942152135777121, 0.4265692221651041, 0.9400664932096228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 483}], {
             RGBColor[
             0.28630346384449123`, 0.4182534715615829, 0.9396159307667007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 319}], {
             RGBColor[
             0.2790659372012526, 0.410646372173846, 0.9392037643313296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 331}], {
             RGBColor[
             0.2806555079415938, 0.4123171118065505, 0.9392942880334327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 349}], {
             RGBColor[
             0.3649387717865599, 0.49000038490876596`, 0.9444933360618217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 377}], {
             RGBColor[
             0.3511015788614483, 0.4780153038745726, 0.943611642364383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 419}], {
             RGBColor[
             0.2586982881881721, 0.38923868167756415`, 0.938043856851271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 484}], {
             RGBColor[
             0.32096443420260157`, 0.451912023908013, 0.9416913301559519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 488}], {
             RGBColor[
             0.3120422059462299, 0.44418403823657515`, 0.9411228136610725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 354}], {
             RGBColor[
             0.47444150973517296`, 0.5798285375279173, 0.9529081653610575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 376}], {
             RGBColor[
             0.3859531471568004, 0.5080115240948738, 0.945927114990078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 400}], {
             RGBColor[
             0.30318296962598673`, 0.4359949023604144, 0.9405771936499658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 414}], {
             RGBColor[
             0.4295382255491977, 0.5433958542192279, 0.9493582920185304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 415}], {
             RGBColor[
             0.2991140648840668, 0.43171822549319544`, 0.9403454755443187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 379}], {
             RGBColor[
             0.4656010503830478, 0.5731569699269389, 0.9521444596504461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 380}], {
             RGBColor[
             0.43788171959535693`, 0.5441839558243835, 0.9505599619408769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 390}], {
             RGBColor[
             0.6654138441328434, 0.7382139311867708, 0.9675126684872362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 411}], {
             RGBColor[
             0.4633341748301859, 0.5709361000550581, 0.9520094416129672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 478}], {
             RGBColor[
             0.4896026583804799, 0.5939459564184202, 0.9536738208882539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 359}], {
             RGBColor[
             0.23352384824055802`, 0.36277874914093977`, 0.936610209738501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 373}], {
             RGBColor[
             0.25385060410395244`, 0.3841434583441261, 0.9377677884141807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 397}], {
             RGBColor[
             0.31719795971766984`, 0.4428682695552517, 0.941663019966297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 398}], {
             RGBColor[
             0.2266690776689228, 0.35557395065259456`, 0.9362198406951706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 472}], {
             RGBColor[
             0.2503270722813453, 0.3804400029937452, 0.9375671284894814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 325}], {
             RGBColor[
             0.2515032344477757, 0.381676224003652, 0.9376341091848837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 347}], {
             RGBColor[
             0.26532441236379856`, 0.3962031583066853, 0.9384212048206007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 368}], {
             RGBColor[
             0.2623849802686051, 0.3931136288038779, 0.9382538085112795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 386}], {
             RGBColor[
             0.25460233538952104`, 0.38493357558777497`, 0.937810598398807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 401}], {
             RGBColor[
             0.24298039315603376`, 0.37271817742668245`, 0.9371487459817327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 378}], {
             RGBColor[
             0.2937021237391968, 0.42180576340958786`, 0.9401919410148649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 357}], {
             RGBColor[
             0.45345829973234725`, 0.5632875814490537, 0.9511916756667309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 418}], {
             RGBColor[
             0.5713669376362989, 0.6561984371543547, 0.9624397750260384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 420}], {
             RGBColor[
             0.3226316473857372, 0.45386904985259524`, 0.9417787811728233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 321}], {
             RGBColor[
             0.5895767516253461, 0.6677163224147521, 0.9646455851432827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 330}], {
             RGBColor[
             0.6417544750222266, 0.7150649069905033, 0.967891403445307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 335}], {
             RGBColor[
             0.5677434952510523, 0.6447681856569613, 0.963402213492175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 350}], {
             RGBColor[
             0.6314156820430556, 0.7061099641547899, 0.9672326246989099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 354}], {
             RGBColor[
             0.7687489837239145, 0.8198677496201479, 0.9774272299059115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 383}], {
             RGBColor[
             0.6067645960709813, 0.6847584324853855, 0.9656618792988687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 479}], {
             RGBColor[
             0.6026826934523466, 0.681222893599515, 0.9654017840734941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 482}], {
             RGBColor[
             0.5937527830185738, 0.6721055961847174, 0.9648834039532422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 496}], {
             RGBColor[
             0.5705354291838751, 0.6477026852391936, 0.9635612099993531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 331}], {
             RGBColor[
             0.2565236525355098, 0.38695300172675207`, 0.9379200145679372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 377}], {
             RGBColor[
             0.3269697234553643, 0.45265119379477414`, 0.9422373688988873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 449}], {
             RGBColor[
             0.5246672447046095, 0.6122965826398199, 0.9589857787345331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 488}], {
             RGBColor[
             0.2879103505401459, 0.4188199281567767, 0.939748540195577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 337}], {
             RGBColor[
             0.2811030293913728, 0.41278748522476705`, 0.9393197737179491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 348}], {
             RGBColor[
             0.3636747805582836, 0.48714690981872516`, 0.9444771891609133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 361}], {
             RGBColor[
             0.29419449559428246`, 0.4265474462509236, 0.9400653133511161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 375}], {
             RGBColor[
             0.40508782360435214`, 0.5210433365223803, 0.9476612672025286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 335}], {
             RGBColor[
             0.2636060496983948, 0.3943970501948603, 0.9383233466088958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 383}], {
             RGBColor[
             0.3026271505183238, 0.43438729702328455`, 0.9405830124155895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 479}], {
             RGBColor[
             0.29854524789968917`, 0.43085175813741416`, 0.9403229171902149]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 482}], {
             RGBColor[
             0.2896153374659164, 0.42173446072261656`, 0.939804537069963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 496}], {
             RGBColor[
             0.2663979836312177, 0.3973315497770926, 0.9384823431160738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 494}], {
             RGBColor[
             0.2779983052463516, 0.4091636832675718, 0.9391561654075613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 342}], {
             RGBColor[
             0.36110696385054364`, 0.4871944351487765, 0.9442303943155743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 395}], {
             RGBColor[
             0.35093087038673487`, 0.47683393796048823`, 0.9436386067185205]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 447}], {
             RGBColor[
             0.6699287042510715, 0.644823532566928, 0.6049412749500439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 452}], {
             RGBColor[
             0.33381731860291747`, 0.4588465099738429, 0.9426640152616632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 463}], {
             RGBColor[
             0.6998569946464631, 0.7597430955997935, 0.8824250714653752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 441}], {
             RGBColor[
             0.6123610534219819, 0.6897663986177393, 0.9659445494243118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 481}], {
             RGBColor[
             0.5946777022256553, 0.6756661743755695, 0.9642578956010922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 347}], {
             RGBColor[
             0.28069649360744797`, 0.4123601903400046, 0.9392966221064702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 368}], {
             RGBColor[
             0.27775706151225454`, 0.4092706608371972, 0.9391292257971491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 386}], {
             RGBColor[
             0.26997441663317046`, 0.40109060762109433`, 0.9386860156846766]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 401}], {
             RGBColor[
             0.25835247439968323`, 0.3888752094600018, 0.9380241632676023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 421}], {
             RGBColor[
             0.24367550115238262`, 0.3734487800032376, 0.9371883313538046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 405}], {
             RGBColor[
             0.40619921231564, 0.5236726787305142, 0.9475915514322624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 428}], {
             RGBColor[
             0.3889120805242967, 0.505502807150351, 0.9466070748507651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 434}], {
             RGBColor[
             0.6485801470930683, 0.7234253855476096, 0.9669547070141209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 469}], {
             RGBColor[
             0.4583627302208659, 0.5697907279255549, 0.950881069988387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 474}], {
             RGBColor[
             0.3663056985511087, 0.4817420663691283, 0.9453196748405371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 475}], {
             RGBColor[
             0.4773932038583929, 0.5862739676909643, 0.9520936749405831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 491}], {
             RGBColor[
             0.5749425131613002, 0.6658032589062217, 0.9596807272013292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 495}], {
             RGBColor[
             0.3937005210337001, 0.5105357617303976, 0.9468797694539126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 399}], {
             RGBColor[
             0.44326746423423885`, 0.5551077235035414, 0.9503635755235533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 412}], {
             RGBColor[
             0.49260223582489593`, 0.5978390230176498, 0.9535071435442843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 483}], {
             RGBColor[
             0.42071200808766995`, 0.5318420500190769, 0.949062908683979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 431}], {
             RGBColor[
             0.3885770347923928, 0.5109876299126955, 0.945980762945159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 433}], {
             RGBColor[
             0.5056259896986834, 0.6055454275566176, 0.9555730596491164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 436}], {
             RGBColor[
             0.28102137578582076`, 0.4108223368852976, 0.9393839349684209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 462}], {
             RGBColor[
             0.3656406998465538, 0.4911213293963237, 0.9445192799642148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 487}], {
             RGBColor[
             0.42491209196471447`, 0.5406282479793738, 0.9488019064964294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 406}], {
             RGBColor[
             0.346272572362378, 0.4743456308399229, 0.9432851600074857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 413}], {
             RGBColor[
             0.3077950390489783, 0.4352607528756909, 0.9410442185441494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 486}], {
             RGBColor[
             0.46903357124389067`, 0.5775353586847212, 0.9519748850313865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 350}], {
             RGBColor[
             0.37945595988727865`, 0.5030874132684401, 0.945399576117655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 354}], {
             RGBColor[
             0.5167892615681375, 0.6168451987337982, 0.9555941813246566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 414}], {
             RGBColor[
             0.4718859773821623, 0.5804125154251087, 0.9520443079821295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 415}], {
             RGBColor[
             0.34146181671703135`, 0.46873488669907637`, 0.9430314915079178]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 482}], {
             RGBColor[
             0.3417930608627968, 0.4690830452983677, 0.9430503553719873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 496}], {
             RGBColor[
             0.3185757070280981, 0.4446801343528438, 0.9417281614180981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 377}], {
             RGBColor[
             0.3285592941957055, 0.45432193342747873`, 0.9423278926009906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 403}], {
             RGBColor[
             0.325923721436505, 0.45203913277119784`, 0.9421599562353198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 449}], {
             RGBColor[
             0.5262568154449505, 0.6139673222725244, 0.9590763024366363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 488}], {
             RGBColor[
             0.28949992128048707`, 0.4204906677894813, 0.9398390638976801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 344}], {
             RGBColor[
             0.42035536639171034`, 0.5370052672458699, 0.9484220819029325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 393}], {
             RGBColor[
             0.37277586190860784`, 0.48913557997254153`, 0.9456341660115397]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 424}], {
             RGBColor[
             0.391777433377553, 0.5091074363556182, 0.9467162773963903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 392}], {
             RGBColor[
             0.5523338284508713, 0.6378369364521901, 0.9611210284533277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 442}], {
             RGBColor[
             0.556805572402005, 0.6425370228697738, 0.9613756876559925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 459}], {
             RGBColor[
             0.5377348231826343, 0.6224924562848771, 0.9602896367005944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 492}], {
             RGBColor[
             0.5698467996389806, 0.6552939624628844, 0.9621531583569551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 340}], {
             RGBColor[
             0.28628923249238825`, 0.4154475865011843, 0.9397173098216727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 355}], {
             RGBColor[
             0.2963805255643143, 0.42418815735694926`, 0.9403603180928357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 361}], {
             RGBColor[
             0.26892945587706074`, 0.3999922876120844, 0.9386265067154971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 363}], {
             RGBColor[
             0.2589402131355509, 0.38949296013618684`, 0.9380576341191285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 369}], {
             RGBColor[
             0.34911672354704265`, 0.46955961480720343`, 0.9438051670169327]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 370}], {
             RGBColor[
             0.29538922453996064`, 0.4233295422338923, 0.940297153268137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 379}], {
             RGBColor[
             0.27207088393023604`, 0.4031323676116257, 0.9388113292240843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 498}], {
             RGBColor[
             0.2473999787887434, 0.37736344214457407`, 0.9374004348453245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 383}], {
             RGBColor[
             0.28079389414403, 0.4114391602654937, 0.9393396407644818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 409}], {
             RGBColor[
             0.2402235248149036, 0.3698205340046061, 0.9369917464081265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 482}], {
             RGBColor[
             0.2677820810916225, 0.3987863239648257, 0.9385611654188553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 496}], {
             RGBColor[
             0.24456472725692383`, 0.3743834130193018, 0.9372389714649662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 409}], {
             RGBColor[
             0.23836618775359522`, 0.36786835499119974`, 0.936885973810169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 456}], {
             RGBColor[
             0.2905064388191045, 0.41950823129297765`, 0.9399710907999219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 458}], {
             RGBColor[
             0.2541467216262284, 0.38445469663497345`, 0.9377846518690077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 348}], {
             RGBColor[
             0.36060153656838845`, 0.48391673553042214`, 0.9443021724621459]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 361}], {
             RGBColor[
             0.2911212516043873, 0.4233172719626206, 0.9398902966523486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 370}], {
             RGBColor[
             0.3175810202672872, 0.4466545265844284, 0.9415609432049885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 375}], {
             RGBColor[
             0.40201457961445697`, 0.5178131622340773, 0.9474862505037611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 498}], {
             RGBColor[
             0.26959177451606997`, 0.40068842649511016`, 0.938664224782176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 369}], {
             RGBColor[
             0.3762823644606207, 0.4981124258084891, 0.9453522100789966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 379}], {
             RGBColor[
             0.2992365248438141, 0.43168517861291134`, 0.9403583722861483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 390}], {
             RGBColor[
             0.4990493185936098, 0.5967421398727433, 0.9557265811229383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 425}], {
             RGBColor[
             0.30294308343756277`, 0.4348956133697647, 0.9405945509221609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 478}], {
             RGBColor[
             0.3232381328412462, 0.4524741651043927, 0.941887733523956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 365}], {
             RGBColor[
             0.2664208497974997, 0.39686859457346974`, 0.9385014763630678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 355}], {
             RGBColor[
             0.349023564109878, 0.4767284016227419, 0.94346045076903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 362}], {
             RGBColor[
             0.33965246745562305`, 0.4686116287058391, 0.9428633327767562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 363}], {
             RGBColor[
             0.31158325168111456`, 0.44203320440197946`, 0.9411577667953226]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 378}], {
             RGBColor[
             0.2859512536480837, 0.4150923493067238, 0.9396980624264845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 379}], {
             RGBColor[
             0.32471392247579967`, 0.45567261187741825`, 0.9419114619002785]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 380}], {
             RGBColor[
             0.2969945916881088, 0.4266995977748629, 0.9403269641907093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 498}], {
             RGBColor[
             0.30004301733430705`, 0.4299036864103666, 0.9405005675215188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 387}], {
             RGBColor[
             0.2532538915932333, 0.38351627566160185`, 0.9377338065194523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 403}], {
             RGBColor[
             0.3503546787669288, 0.4777176179376347, 0.9435512631129249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 405}], {
             RGBColor[
             0.3027953305526198, 0.4355874691165689, 0.9405551181781983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 450}], {
             RGBColor[
             0.2896905748838666, 0.4218135400192101, 0.9398088217296114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 469}], {
             RGBColor[
             0.3549588484578457, 0.4817055183116096, 0.9438446367343227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 491}], {
             RGBColor[
             0.47153863139828006`, 0.5777180492922765, 0.952644293947265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 395}], {
             RGBColor[
             0.3021956228242944, 0.4346219160266674, 0.9405332398387292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 447}], {
             RGBColor[
             0.621193456688631, 0.6026115106331071, 0.6018359080702526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 453}], {
             RGBColor[
             0.3948492143114877, 0.5157683837342849, 0.9465605406087976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 463}], {
             RGBColor[
             0.6511217470840227, 0.7175310736659726, 0.8793197045855838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 392}], {
             RGBColor[
             0.36028925760485436`, 0.4841980085027917, 0.9442620719310348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 433}], {
             RGBColor[
             0.5593802541099313, 0.6521046696217538, 0.9589982338443714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 465}], {
             RGBColor[
             0.40628780098341527`, 0.5263278054183675, 0.9471092773058353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 387}], {
             RGBColor[
             0.2657089848875702, 0.3944679797592421, 0.9385214391555547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 424}], {
             RGBColor[
             0.3033073915112151, 0.4339862889973589, 0.9406626127909132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 375}], {
             RGBColor[
             0.4509566697806504, 0.5630442647451228, 0.9505008136853013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 426}], {
             RGBColor[
             0.3891395671620182, 0.511474867177566, 0.9460166070103236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 448}], {
             RGBColor[
             0.45344716303890265`, 0.5650661593676147, 0.9506968744375682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 489}], {
             RGBColor[
             0.29747258482185285`, 0.4237827885105943, 0.9404793792330371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 498}], {
             RGBColor[
             0.3185338646822634, 0.4459195290061558, 0.9416787879637162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 358}], {
             RGBColor[
             0.4370307510363033, 0.5500454345153181, 0.9498723345391485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 404}], {
             RGBColor[
             0.5837609489665214, 0.6729624623589062, 0.9603749467709108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 407}], {
             RGBColor[
             0.39044423236130543`, 0.5015248450823406, 0.9472030150788647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 408}], {
             RGBColor[
             0.40844159822281634`, 0.520441217701691, 0.948227938439961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 430}], {
             RGBColor[
             0.43099319825544163`, 0.5441443791900067, 0.9495122186997165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 368}], {
             RGBColor[
             0.2915782394282773, 0.4237975951402305, 0.9399163214328662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 386}], {
             RGBColor[
             0.2837955945491933, 0.4156175419241276, 0.9394731113203937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 421}], {
             RGBColor[
             0.25749667906840545`, 0.38797571430627087`, 0.9379754269895217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 477}], {
             RGBColor[
             0.330695884288776, 0.45953838035408784`, 0.9423407943429076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 375}], {
             RGBColor[
             0.48458633078136776`, 0.5921725868280354, 0.9526436659467254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 428}], {
             RGBColor[
             0.35360727366057687`, 0.4765653217524307, 0.9439038595366307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 359}], {
             RGBColor[
             0.32653035589527857`, 0.44963070457280935`, 0.9423060335969726]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 371}], {
             RGBColor[
             0.4947390825680813, 0.5999672099119273, 0.953566666785141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 397}], {
             RGBColor[
             0.41020446737239036`, 0.5297202249871213, 0.9473588438247686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 419}], {
             RGBColor[
             0.32043926736739536`, 0.44322858433268575`, 0.9419591551162677]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 354}], {
             RGBColor[
             0.5064504685889667, 0.6078902558980848, 0.9549354025782595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 383}], {
             RGBColor[
             0.34446608093603337`, 0.4727809387633223, 0.9431700519712167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 414}], {
             RGBColor[
             0.46154718440299136`, 0.5714575725893953, 0.9513855292357323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 479}], {
             RGBColor[
             0.34038417831739876`, 0.46924539987745195`, 0.9429099567458421]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 482}], {
             RGBColor[
             0.3314542678836259, 0.4601281024626543, 0.9423915766255901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 356}], {
             RGBColor[
             0.4127430343192738, 0.5314457313388554, 0.9476513657355758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 463}], {
             RGBColor[
             0.7303100248487446, 0.7856467070016357, 0.8844962782910257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 367}], {
             RGBColor[
             0.3939398952088271, 0.5087303852608752, 0.9470806400178498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 399}], {
             RGBColor[
             0.42225100274745697`, 0.5380456132877713, 0.9487090826894787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 412}], {
             RGBColor[
             0.47158577433811405`, 0.5807769128018796, 0.9518526507102099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 457}], {
             RGBColor[
             0.44025217643760994`, 0.553637325172885, 0.9498561015592024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 418}], {
             RGBColor[
             0.5914482487402649, 0.6735918595165667, 0.963719338412377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 420}], {
             RGBColor[
             0.3427129584897032, 0.4712624722148073, 0.9430583445591618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 432}], {
             RGBColor[
             0.3316098794612853, 0.46164554321736995`, 0.9423508661815383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 441}], {
             RGBColor[
             0.6196420418670605, 0.6960728248557465, 0.966408487569707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 372}], {
             RGBColor[
             0.5956005815968521, 0.682552583834195, 0.9613219283468313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 414}], {
             RGBColor[
             0.5988804860838504, 0.6852153580547534, 0.9615801344427339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 415}], {
             RGBColor[
             0.4684563254187194, 0.573537729328721, 0.9525673179685222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 479}], {
             RGBColor[
             0.47771747999825764`, 0.58300318534281, 0.9531045619528437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 482}], {
             RGBColor[
             0.46878756956448486`, 0.5738858879280124, 0.9525861818325918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 362}], {
             RGBColor[
             0.34974376052754913`, 0.47735219956160413`, 0.9435063410479192]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 363}], {
             RGBColor[
             0.32167454475304064`, 0.4507737752577444, 0.9418007750664856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 378}], {
             RGBColor[
             0.29604254672000974`, 0.42383292016248875`, 0.9403410706976475]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 384}], {
             RGBColor[
             0.39823122601043914`, 0.5193496051120079, 0.9465959194727067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 498}], {
             RGBColor[
             0.3101343104062332, 0.4386442572661316, 0.9411435757926818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 463}], {
             RGBColor[
             0.6723047873504713, 0.7358787584542094, 0.8806694691799348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 418}], {
             RGBColor[
             0.7147479137078537, 0.7764908929627028, 0.9726526199263468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 420}], {
             RGBColor[
             0.466012623457292, 0.5741615056609433, 0.9519916260731318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 404}], {
             RGBColor[
             0.4602870424941751, 0.5689259396048092, 0.9517031549933148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 407}], {
             RGBColor[
             0.2669703258889591, 0.3974883223282437, 0.9385312233012687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 408}], {
             RGBColor[
             0.28496769175047, 0.416404694947594, 0.939556146662365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 430}], {
             RGBColor[
             0.3075192917830953, 0.4401078564359097, 0.9408404269221204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 371}], {
             RGBColor[
             0.3945896874975766, 0.5056076269208492, 0.9474640660552952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 397}], {
             RGBColor[
             0.3100550723018857, 0.4353606419960431, 0.941256243094923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 419}], {
             RGBColor[
             0.22028987229689073`, 0.34886900134160753`, 0.9358565543864219]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 427}], {
             RGBColor[
             0.3798105362455182, 0.49360924614125157`, 0.9463005971309183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 393}], {
             RGBColor[
             0.22838934233135863`, 0.3573820578838939, 0.9363178072227928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 466}], {
             RGBColor[
             0.2736004787646523, 0.4032003837901173, 0.9389548127963174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 468}], {
             RGBColor[
             0.25856380359082465`, 0.3890973298389361, 0.9380361981524044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 363}], {
             RGBColor[
             0.29422347506578705`, 0.42657790551287955`, 0.940066963689147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 370}], {
             RGBColor[
             0.3306724864701968, 0.46041448761058495`, 0.9423064828381555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 498}], {
             RGBColor[
             0.2826832407189796, 0.4144483875212667, 0.9394097644153431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 363}], {
             RGBColor[
             0.3123034480987857, 0.4426570023408417, 0.9412036570742119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 384}], {
             RGBColor[
             0.3888601293561842, 0.5112328321951052, 0.945998801480433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 498}], {
             RGBColor[
             0.30076321375197823`, 0.43052748434922883`, 0.940546457800408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 370}], {
             RGBColor[
             0.32068324372868695`, 0.4499151601346874, 0.9417376102417869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 379}], {
             RGBColor[
             0.29736490311896235`, 0.4297179855124208, 0.9402517861977342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 498}], {
             RGBColor[
             0.27269399797746974`, 0.4039490600453692, 0.9388408918189743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 374}], {
             RGBColor[
             0.7765895732071173, 0.8260875801030143, 0.9782221515537421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 437}], {
             RGBColor[
             0.5922630601721746, 0.667606432485182, 0.965242951889024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 435}], {
             RGBColor[
             0.4464252698818928, 0.5558393044186494, 0.9508029606035121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 473}], {
             RGBColor[
             0.44724099555442565`, 0.5566966838204762, 0.9508494149738049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 416}], {
             RGBColor[
             0.24172116635535817`, 0.37139465021958196`, 0.9370770348782933]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 457}], {
             RGBColor[
             0.30321171130249636`, 0.432254907657086, 0.9407168760841775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 499}], {
             RGBColor[
             0.28003994836037044`, 0.4116701196579532, 0.9392592328259208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 386}], {
             RGBColor[
             0.2808561624539998, 0.4125280124213202, 0.9393057150110725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 401}], {
             RGBColor[
             0.2692342202205126, 0.4003126142602277, 0.9386438625939981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 500}], {
             RGBColor[
             0.32031654091030964`, 0.4500047736385234, 0.9416993334654716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 370}], {
             RGBColor[
             0.4108597541401787, 0.529981814805704, 0.9474851431395912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 379}], {
             RGBColor[
             0.3875414135304541, 0.5097846401834374, 0.9459993190955385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 390}], {
             RGBColor[
             0.5873542072802498, 0.6748416014432693, 0.9613675279323284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 425}], {
             RGBColor[
             0.3912479721242028, 0.5129950749402908, 0.946235497731551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 466}], {
             RGBColor[
             0.3958679207865078, 0.5169966422662079, 0.946529876775053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 466}], {
             RGBColor[
             0.3421404217794257, 0.4707665696928967, 0.9430218630262572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 382}], {
             RGBColor[
             0.45040455936281, 0.5615668742294488, 0.9507417101699807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 419}], {
             RGBColor[
             0.3884985989696934, 0.49920550668072555`, 0.9471171875745903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 427}], {
             RGBColor[
             0.5480192629183209, 0.6439457514803696, 0.9575612303190866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 429}], {
             RGBColor[
             0.42351632324732824`, 0.5360113551484746, 0.9491113951681209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 417}], {
             RGBColor[
             0.5067053173839196, 0.610405229323506, 0.9543088451886494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 398}], {
             RGBColor[
             0.23985294611653313`, 0.36943103229657226`, 0.9369706424994765]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 472}], {
             RGBColor[
             0.2635109407289557, 0.39429708463772284`, 0.9383179302937873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 391}], {
             RGBColor[
             0.4605995891779458, 0.5661920457418392, 0.9520239146904479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 437}], {
             RGBColor[
             0.4520128561754036, 0.5571668449258502, 0.9515349129488863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 426}], {
             RGBColor[
             0.46418227120880406`, 0.5744996159641337, 0.9513435373133631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 489}], {
             RGBColor[
             0.3725152888686387, 0.486807537297162, 0.9458063095360766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 400}], {
             RGBColor[
             0.38403686758226685`, 0.5059973927628966, 0.9458179857031899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 414}], {
             RGBColor[
             0.5103921235054778, 0.61339834462171, 0.9545990840717544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 415}], {
             RGBColor[
             0.37996796284034684`, 0.5017207158956776, 0.9455862675975427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 464}], {
             RGBColor[
             0.5979642684322207, 0.6831642662364397, 0.962401790689747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 485}], {
             RGBColor[
             0.35544406144865526`, 0.4759445406278544, 0.9441896676931467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 497}], {
             RGBColor[
             0.3322967461695083, 0.4516152446449163, 0.9428714623313836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 403}], {
             RGBColor[
             0.3963697923563595, 0.5177373248392199, 0.94647731056627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 449}], {
             RGBColor[
             0.5967028863648051, 0.6796655143405466, 0.9633936567675865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 484}], {
             RGBColor[
             0.36886822045671325`, 0.4939168455289412, 0.9447249347235096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 488}], {
             RGBColor[
             0.3599459922003416, 0.4861888598575034, 0.9441564182286304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 380}], {
             RGBColor[
             0.2440135742982406, 0.37380411631460986`, 0.9372075841193268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 380}], {
             RGBColor[
             0.2827762431259566, 0.4143843788853043, 0.9394209835931209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 390}], {
             RGBColor[
             0.5103083676634432, 0.6084143542476915, 0.9563736901394801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 478}], {
             RGBColor[
             0.3344971819110796, 0.464146379479341, 0.9425348425404979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 390}], {
             RGBColor[
             0.48258903687575233`, 0.5794413401451362, 0.9547891924299109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 411}], {
             RGBColor[
             0.28050936757309475`, 0.4121635090134235, 0.939285965555642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 478}], {
             RGBColor[
             0.30677785112338873`, 0.4351733653767857, 0.9409503448309287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 419}], {
             RGBColor[
             0.29010238829297363`, 0.4169523044542987, 0.9400261160074944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 439}], {
             RGBColor[
             0.3635721694589597, 0.48932967234195, 0.9443874750370469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 416}], {
             RGBColor[
             0.28227680359612173`, 0.41131547444650907`, 0.9394856881551299]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 427}], {
             RGBColor[
             0.43562540811075146`, 0.5495684934498513, 0.9495782412456037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 429}], {
             RGBColor[
             0.3111224684397589, 0.4416340971179562, 0.9411284060946381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 499}], {
             RGBColor[
             0.320595585601134, 0.4515909438848803, 0.9416678861027574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 479}], {
             RGBColor[
             0.3157330923453243, 0.44789386820804755`, 0.9413392113458009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 482}], {
             RGBColor[
             0.30680318191155154`, 0.43877657079324994`, 0.940820831225549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 496}], {
             RGBColor[
             0.28358582807685284`, 0.414373659847726, 0.9394986372716598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 435}], {
             RGBColor[
             0.3659302949647987, 0.49005622358050793`, 0.9445859156657348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 391}], {
             RGBColor[
             0.2822037141411573, 0.4139443746842344, 0.939382456086132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 421}], {
             RGBColor[
             0.24677460209412794`, 0.3767061315873606, 0.9373648205677281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 403}], {
             RGBColor[
             0.29663343242346357`, 0.4212531819069062, 0.9404919176071266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 405}], {
             RGBColor[
             0.2490740842091546, 0.3791230330858405, 0.9374957726723999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 491}], {
             RGBColor[
             0.4178173850548148, 0.5212536132615481, 0.9495849484414667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 487}], {
             RGBColor[
             0.41353723706232354`, 0.5305518794924018, 0.9480853140348157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 490}], {
             RGBColor[
             0.3140477995174865, 0.44621011137850314`, 0.9412400292114345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 409}], {
             RGBColor[
             0.34378156990494324`, 0.4657094382386658, 0.9433636492359327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 451}], {
             RGBColor[
             0.4070326012661707, 0.5269729139885397, 0.9471567353212516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 456}], {
             RGBColor[
             0.3959218209704525, 0.5173493145404437, 0.9464487662256855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 458}], {
             RGBColor[
             0.3595621037775764, 0.48229577988243943`, 0.9442623272947714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 425}], {
             RGBColor[
             0.5140149262571918, 0.611624789004545, 0.9566098687754927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 478}], {
             RGBColor[
             0.5343099756608753, 0.629203340739173, 0.9579030513772879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 459}], {
             RGBColor[
             0.2693984658055498, 0.4004852467838734, 0.9386532161370864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 465}], {
             RGBColor[
             0.3299960144523478, 0.4579595238667623, 0.9423318132646201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 492}], {
             RGBColor[
             0.3015104422618961, 0.4332867529618807, 0.9405167377934471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 468}], {
             RGBColor[
             0.26690077681863345`, 0.39786001729599596`, 0.9385109764442814]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 398}], {
             RGBColor[
             0.2492717482164607, 0.3793307904901411, 0.9375070293451984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 445}], {
             RGBColor[
             0.2849219859108267, 0.41680145066254154`, 0.939537257642092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 460}], {
             RGBColor[
             0.2559377723129188, 0.3863372044658575, 0.9378866495559927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 440}], {
             RGBColor[
             0.28580791853486365`, 0.4177326220217771, 0.939587710194411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 447}], {
             RGBColor[
             0.6110173632248224, 0.5922510134448189, 0.6012441204731989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 453}], {
             RGBColor[
             0.3846731208476789, 0.5054078865459967, 0.9459687530117439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 463}], {
             RGBColor[
             0.6409456536202138, 0.7071705764776843, 0.87872791698853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 422}], {
             RGBColor[
             0.35081546325813295`, 0.4782804546014903, 0.9435746289982425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 443}], {
             RGBColor[
             0.6576873028701187, 0.7270916133188894, 0.9647592667401638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 446}], {
             RGBColor[
             0.4690666891692976, 0.5777001577457866, 0.95193938657846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 419}], {
             RGBColor[
             0.3039639837740025, 0.4289585217559195, 0.9409093646142179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 472}], {
             RGBColor[
             0.32685829634267305`, 0.4530218958488485, 0.9422131618459035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 445}], {
             RGBColor[
             0.24832165737586948`, 0.3783321847774412, 0.9374529230773601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 460}], {
             RGBColor[
             0.2193374437779616, 0.34786793858075715`, 0.9358023149912607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 472}], {
             RGBColor[
             0.236329414293926, 0.3657275769461914, 0.9367699825747772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 412}], {
             RGBColor[
             0.3628564167416303, 0.48870972331297685`, 0.9443418679068138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 414}], {
             RGBColor[
             0.4276219459746641, 0.5413817228872506, 0.9492491627316422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 415}], {
             RGBColor[
             0.29719778530953317`, 0.4297040941612182, 0.9402363462574306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 464}], {
             RGBColor[
             0.515194090901407, 0.6111476445019803, 0.9570518693496348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 450}], {
             RGBColor[
             0.261117822469488, 0.3917817656145611, 0.9381816457492118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 454}], {
             RGBColor[0.395455282412895, 0.5091150322633, 0.947276909767746]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 471}], {
             RGBColor[
             0.2635197882629969, 0.3943063839569662, 0.9383184341477622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 475}], {
             RGBColor[
             0.3454165696809941, 0.46815698367237, 0.9434300657061192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 500}], {
             RGBColor[
             0.30091195379773833`, 0.429609322261328, 0.9405942709359247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 431}], {
             RGBColor[
             0.38575476604400394`, 0.5085431225741929, 0.9458009304761459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 436}], {
             RGBColor[
             0.2781991070374319, 0.4083778295467949, 0.9392041024994078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 459}], {
             RGBColor[
             0.2891137191769806, 0.41984977893183983`, 0.9398256735140335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 462}], {
             RGBColor[
             0.3628184310981648, 0.488676822057821, 0.9443394474952017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 487}], {
             RGBColor[
             0.4220898232163256, 0.5381837406408712, 0.9486220740274163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 405}], {
             RGBColor[
             0.3461748713828501, 0.4733243753618733, 0.9433132292658726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 449}], {
             RGBColor[
             0.5940673136056046, 0.6773827136842656, 0.9632257204019158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 491}], {
             RGBColor[
             0.5149181722285103, 0.6154549555375809, 0.9554024050349393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 407}], {
             RGBColor[
             0.41370052381917727`, 0.5204053501718319, 0.949033835533031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 408}], {
             RGBColor[
             0.4316978896806882, 0.5393217227911822, 0.9500587588941273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 434}], {
             RGBColor[
             0.5409964579459694, 0.630946933357903, 0.9596802399130044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 469}], {
             RGBColor[
             0.350779041073767, 0.4773122757358482, 0.9436066028872704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 474}], {
             RGBColor[
             0.2587220094040099, 0.3892636141794217, 0.9380452077394206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 491}], {
             RGBColor[
             0.46735882401420137`, 0.5733248067165151, 0.9524062601002127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 413}], {
             RGBColor[
             0.2849504445032486, 0.4154739132828872, 0.9395885811803774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 476}], {
             RGBColor[
             0.29064902597384645`, 0.4214634837194191, 0.9399131069648321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 486}], {
             RGBColor[
             0.44618897669816093`, 0.5577485190919175, 0.9505192476676143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 493}], {
             RGBColor[
             0.37011880931709223`, 0.4950000427433777, 0.9448046211398408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 408}], {
             RGBColor[
             0.23838117307547213`, 0.3678841055146167, 0.9368868272020812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 430}], {
             RGBColor[
             0.2609327731080974, 0.39158726700293234`, 0.9381711074618366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{408, 430}], {
             RGBColor[
             0.27893013896960833`, 0.4105036396222827, 0.9391960308229328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 456}], {
             RGBColor[
             0.2908145073712155, 0.41983203087392074`, 0.939988634848218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 458}], {
             RGBColor[
             0.2544547901783395, 0.38477849621591653`, 0.9378021959173038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 496}], {
             RGBColor[
             0.24301545874772648`, 0.3727550335868385, 0.9371507429153048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{411, 478}], {
             RGBColor[
             0.3322303063582177, 0.46192550960746026`, 0.942399824503019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 476}], {
             RGBColor[
             0.25217149266044675`, 0.3823786057551871, 0.9376721655014958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 486}], {
             RGBColor[
             0.40771144338476123`, 0.5186636411276855, 0.9482783062042781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 493}], {
             RGBColor[
             0.33164127600369253`, 0.45591516477914573`, 0.9425636796765045]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 415}], {
             RGBColor[
             0.4235530412327441, 0.5371050460200316, 0.9490174446259951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 485}], {
             RGBColor[
             0.3990291398410525, 0.5113288707522085, 0.9476208447215991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{415, 464}], {
             RGBColor[
             0.5111251861594871, 0.6068709676347613, 0.9568201512439877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{415, 485}], {
             RGBColor[
             0.2686049791759216, 0.3996512420261761, 0.9386080282473874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 427}], {
             RGBColor[
             0.3798915071516326, 0.4936943516974298, 0.9463052083042358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 429}], {
             RGBColor[
             0.25538856748064, 0.3857599553655348, 0.9378553731532702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 499}], {
             RGBColor[
             0.2648616846420151, 0.39571680213245886`, 0.9383948531613895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{417, 461}], {
             RGBColor[
             0.35354192324240735`, 0.4740426111098907, 0.9440724833951911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 420}], {
             RGBColor[
             0.5839212613612437, 0.6670723613662444, 0.9632397254324393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 432}], {
             RGBColor[
             0.5728181823328258, 0.657455432368807, 0.9625322470548158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 432}], {
             RGBColor[
             0.32408289208226404`, 0.45512604506704746`, 0.9418712532016007]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 439}], {
             RGBColor[
             0.3481621586058308, 0.47598229547063564`, 0.943405562772023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 423}], {
             RGBColor[
             0.41149134993839653`, 0.5186228329126159, 0.9488589209291588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 477}], {
             RGBColor[
             0.29367489183371065`, 0.42062697001732086`, 0.9402325035902421]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 443}], {
             RGBColor[
             0.6343063900512014, 0.7068402417939909, 0.9632694556502718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 446}], {
             RGBColor[
             0.4456857763503804, 0.5574487862208881, 0.950449575488568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 446}], {
             RGBColor[
             0.583222007762499, 0.6725249256104562, 0.9603325193451235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 477}], {
             RGBColor[
             0.48469055515876713`, 0.5901854989604328, 0.9532242882825448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 440}], {
             RGBColor[
             0.27716288310314974`, 0.4086461416561411, 0.9390953882157588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 453}], {
             RGBColor[
             0.376028085415965, 0.4963214061803607, 0.9454764310330916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 470}], {
             RGBColor[
             0.3130619114668164, 0.44243516390647236`, 0.9412841621769008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{425, 466}], {
             RGBColor[
             0.3225286397634498, 0.45377982982748355`, 0.9417722176182173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 448}], {
             RGBColor[
             0.4666727644670563, 0.5765215105866255, 0.95153959806563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 489}], {
             RGBColor[
             0.3106981862500065, 0.4352381397296051, 0.941322102861099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 460}], {
             RGBColor[
             0.3796217897703411, 0.49341086162862274`, 0.9462898482983824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 499}], {
             RGBColor[
             0.4182102891566449, 0.533969821135801, 0.9484874062518633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 495}], {
             RGBColor[
             0.268829700095258, 0.39988743796052784`, 0.9386208257712988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{429, 499}], {
             RGBColor[
             0.29370734948565225`, 0.42603542480390605`, 0.9400375711008977]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 433}], {
             RGBColor[
             0.5651305091776502, 0.6570852515451886, 0.9593646350125357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 436}], {
             RGBColor[
             0.3405258952647875, 0.4623621608738686, 0.9431755103318401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 459}], {
             RGBColor[
             0.3514405074043362, 0.47383411025891353`, 0.9437970813464658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 462}], {
             RGBColor[
             0.42514521932552046`, 0.5426611533848946, 0.948310855327634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 487}], {
             RGBColor[
             0.4844166114436812, 0.5921680719679449, 0.9525934818598486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{432, 467}], {
             RGBColor[
             0.3048115848365754, 0.4373152352622944, 0.9406842735938514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 462}], {
             RGBColor[
             0.542194174231811, 0.6372189510288166, 0.9579031520315915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 469}], {
             RGBColor[
             0.5931599758511953, 0.6770649825529437, 0.9629697584691289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 474}], {
             RGBColor[
             0.5011029441814382, 0.5890163209965171, 0.9574083633212791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 495}], {
             RGBColor[
             0.5284977666640296, 0.6178100163577864, 0.9589684579346547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 459}], {
             RGBColor[
             0.24388484839776414`, 0.37366881723151557`, 0.9372002533697277]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 462}], {
             RGBColor[
             0.3175895603189484, 0.4424958603574968, 0.9417140273508959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 487}], {
             RGBColor[
             0.37686095243710915`, 0.4920027789405469, 0.9459966538831105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 457}], {
             RGBColor[
             0.3972450480686217, 0.5184954273455502, 0.9465330810862971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 460}], {
             RGBColor[
             0.335484785740192, 0.457351679839239, 0.9428778798745596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 453}], {
             RGBColor[
             0.37846151002205697`, 0.49887908972939465`, 0.9456150109644794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 470}], {
             RGBColor[
             0.3154953360729083, 0.44499284745550627`, 0.9414227421082886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 467}], {
             RGBColor[
             0.5928437472423507, 0.671742516900671, 0.9647418949820201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 444}], {
             RGBColor[
             0.27506610649145713`, 0.4064422964939365, 0.938975979889626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 492}], {
             RGBColor[
             0.30598218621302975`, 0.4379868393794643, 0.9407713969961118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{443, 446}], {
             RGBColor[
             0.7525576159623661, 0.8062599449382872, 0.9716342132304894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{444, 492}], {
             RGBColor[
             0.28810733372843267`, 0.4191992360870472, 0.9397534505905886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{445, 460}], {
             RGBColor[
             0.25498768147232764`, 0.38533859875315757`, 0.9378325432881545]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 453}], {
             RGBColor[
             0.7036709547120156, 0.6733974811524364, 0.6072714212432673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 463}], {
             RGBColor[
             0.9599434874845505, 0.8751601710841241, 0.5400305852200534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{449, 488}], {
             RGBColor[
             0.5576435134495867, 0.645834248702549, 0.9609048280642761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 454}], {
             RGBColor[
             0.4067434717744418, 0.5209796349948288, 0.9479197554525065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 469}], {
             RGBColor[
             0.3376742854050139, 0.46353834663848936`, 0.9428603064386836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 471}], {
             RGBColor[
             0.2748079776245437, 0.406170986688495, 0.9389612798325226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 475}], {
             RGBColor[
             0.35670475904254084`, 0.4800215864038988, 0.9440729113908797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 491}], {
             RGBColor[
             0.45425406834544824`, 0.5595508776191563, 0.9516599636516259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 500}], {
             RGBColor[
             0.3122001431592851, 0.44147392499285676`, 0.9412371166206852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{451, 456}], {
             RGBColor[
             0.354065538732443, 0.4810955066237947, 0.9437817209335367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{453, 463}], {
             RGBColor[
             0.7335992451074071, 0.788317044185302, 0.8847552177585984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 469}], {
             RGBColor[
             0.47201174534842083`, 0.5808716132872284, 0.9519555704572178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 471}], {
             RGBColor[
             0.40914543756795063`, 0.5235042533372339, 0.9480565438510569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 475}], {
             RGBColor[
             0.49104221898594785`, 0.5973548530526378, 0.953168175409414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 500}], {
             RGBColor[
             0.4465376031026921, 0.5588071916415958, 0.9503323806392195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{456, 458}], {
             RGBColor[
             0.30659504124384873`, 0.43641837251769444`, 0.9408873129070567]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{461, 486}], {
             RGBColor[
             0.405020290110264, 0.5158350684072162, 0.9481250490065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{461, 493}], {
             RGBColor[
             0.3289501227291953, 0.45308659205867646`, 0.9424104224787264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{462, 487}], {
             RGBColor[
             0.4614802764978421, 0.572301771451573, 0.9511319988789044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 485}], {
             RGBColor[
             0.48660128476779546`, 0.5810947923669382, 0.9554235513395917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 497}], {
             RGBColor[
             0.4634539694886485, 0.556765496384, 0.9541053459778286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 468}], {
             RGBColor[
             0.3121119132519271, 0.4436783432022194, 0.9411479820178059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 471}], {
             RGBColor[
             0.3400762511985227, 0.4660629649808945, 0.9429970948372339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 474}], {
             RGBColor[
             0.3108855273092358, 0.4353816633744624, 0.9413347262955452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 475}], {
             RGBColor[
             0.4219730326165199, 0.5399135646962983, 0.948108726395591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 491}], {
             RGBColor[
             0.5195223419194273, 0.6194428559115559, 0.9556957786563371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 495}], {
             RGBColor[
             0.33828034979182714`, 0.4641753587357317, 0.9428948209089206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 475}], {
             RGBColor[
             0.3591067248360497, 0.48254620474630394`, 0.94420969978943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 500}], {
             RGBColor[
             0.31460210895279395`, 0.4439985433352619, 0.9413739050192356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{474, 495}], {
             RGBColor[
             0.24622331812207002`, 0.37612669717930514`, 0.9373334257610708]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{476, 493}], {
             RGBColor[
             0.3373398574742904, 0.46190473521567765`, 0.9428882054609592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{479, 482}], {
             RGBColor[
             0.3027212792929169, 0.43524103190737956`, 0.9405607360001744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{480, 481}], {
             RGBColor[
             0.5500079293102216, 0.631205455360673, 0.9616228453879365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{482, 496}], {
             RGBColor[
             0.2705740150244454, 0.401720823547058, 0.9387201619260334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{484, 500}], {
             RGBColor[
             0.3453626751427009, 0.4735575236010027, 0.9432271821612384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{485, 497}], {
             RGBColor[
             0.22093376250508298`, 0.3495457707754147, 0.9358932229812283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{486, 493}], {
             RGBColor[
             0.4928798081986049, 0.598189770588176, 0.9534943461637415]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.1263497464931148], {
             RGBColor[
             0.28734139441138196`, 0.419344402395984, 0.9396750393770045]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.1263497464931148], {
             RGBColor[
             0.20203577401600706`, 0.32968278667172085`, 0.934817010493844]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.1263497464931148], {
             RGBColor[
             0.3193688250189132, 0.4510429571126728, 0.9415708770168099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.1263497464931148], {
             RGBColor[
             0.28386252546805024`, 0.41568789056351163`, 0.9394769229372072]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.1263497464931148], {
             RGBColor[
             0.29816555625768904`, 0.4307212827879521, 0.9402914593812393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.1263497464931148], {
             RGBColor[
             0.6060273964641905, 0.6910393675295425, 0.9621278430826121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.1263497464931148], {
             RGBColor[
             0.2578700741310447, 0.3883681761917191, 0.9379966912859505]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.1263497464931148], {
             RGBColor[
             0.21744660342311906`, 0.3458805454816148, 0.9356946344303001]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.1263497464931148], {
             RGBColor[
             0.291745581075652, 0.4239734818216946, 0.9399258512921244]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.1263497464931148], {
             RGBColor[
             0.2713342211124329, 0.40251984834538274`, 0.9387634545381202]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.1263497464931148], {
             RGBColor[
             0.24195654313467688`, 0.3716420461383957, 0.9370904392376668]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.1263497464931148], {
             RGBColor[
             0.7131904678759505, 0.7758690810437868, 0.9720478187601735]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.1263497464931148], {
             RGBColor[
             0.5282026472248309, 0.627857730132031, 0.95600119374104]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.1263497464931148], {
             RGBColor[
             0.38339916029872123`, 0.5065028152738162, 0.9456508333610368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.1263497464931148], {
             RGBColor[
             0.955642469129801, 0.966438806622572, 0.9599699088530541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.1263497464931148], {
             RGBColor[
             0.2666102183235196, 0.39755462189515867`, 0.9384944295678274]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.1263497464931148], {
             RGBColor[
             0.3448057587577522, 0.47307515061979144`, 0.9431916959416513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.1263497464931148], {
             RGBColor[
             0.4244601006875862, 0.54206773805578, 0.9482672001738514]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.1263497464931148], {
             RGBColor[
             0.31473650233925, 0.44703067203485614`, 0.9412757095118638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.1263497464931148], {
             RGBColor[
             0.5173305771282382, 0.6190312938464405, 0.9551453045573312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.1263497464931148], {
             RGBColor[
             0.3217281490033978, 0.4530864849649619, 0.9417212110548329]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.1263497464931148], {
             RGBColor[
             0.43650016848452144`, 0.5524962396300823, 0.9490343826472581]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.1263497464931148], {
             RGBColor[
             0.28918806341115794`, 0.4212853686003256, 0.9397802044446398]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.1263497464931148], {
             RGBColor[
             0.3194257799564875, 0.45109228861696127`, 0.9415745061350688]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.1263497464931148], {
             RGBColor[
             0.2818144183600219, 0.413535200135483, 0.9393602862673079]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.1263497464931148], {
             RGBColor[
             0.4901143415244938, 0.5969359277058792, 0.9530027427942485]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.1263497464931148], {
             RGBColor[
             0.26128260961297217`, 0.39195496735047125`, 0.9381910301332524]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.1263497464931148], {
             RGBColor[
             0.7693593698491171, 0.8197486541646907, 0.9776462099806265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.1263497464931148], {
             RGBColor[
             0.35237383592407895`, 0.4796302386786452, 0.9436739271265018]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.1263497464931148], {
             RGBColor[
             0.27391337588420983`, 0.4052307035383778, 0.9389103335868553]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.1263497464931148], {
             RGBColor[
             0.38979475286644955`, 0.5120423561041535, 0.9460583548640521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.1263497464931148], {
             RGBColor[
             0.5517075347468677, 0.6469400567055362, 0.9578515845880147]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.1263497464931148], {
             RGBColor[
             0.2803969845977723, 0.41204538738086743`, 0.9392795655114531]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.1263497464931148], {
             RGBColor[
             0.41530738715222193`, 0.5341401176202057, 0.9476839973608048]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.1263497464931148], {
             RGBColor[
             0.6472302902622149, 0.7243404889760194, 0.9654735246885419]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.1263497464931148], {
             RGBColor[
             0.3681987691041759, 0.4933370004149767, 0.9446822778752986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.1263497464931148], {
             RGBColor[
             0.3684546425450429, 0.4935586251288826, 0.9446985819046907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.1263497464931148], {
             RGBColor[
             0.3429368584804563, 0.47145640313325693`, 0.9430726112685857]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.1263497464931148], {
             RGBColor[
             0.3360501618496745, 0.4654914926471107, 0.9426337970489389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.1263497464931148], {
             RGBColor[
             0.471808519414278, 0.5820744366489178, 0.9515616414212964]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.1263497464931148], {
             RGBColor[
             0.2644764126776603, 0.3953118568702686, 0.9383729124929783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.1263497464931148], {
             RGBColor[
             0.2882283313405391, 0.4202766293435774, 0.9397255491230144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.1263497464931148], {
             RGBColor[
             0.27270811185718274`, 0.4039638946278193, 0.9388416955835445]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.1263497464931148], {
             RGBColor[
             0.3814458569014465, 0.5048109620469803, 0.9455263705958009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.1263497464931148], {
             RGBColor[
             0.29716999494709834`, 0.4296748847282884, 0.9402347636374021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.1263497464931148], {
             RGBColor[
             0.3998347376938894, 0.5207384863373719, 0.9466980938192465]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.1263497464931148], {
             RGBColor[
             0.3068504580456016, 0.4398496652216259, 0.9407860516899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.1263497464931148], {
             RGBColor[
             0.3014547716284265, 0.43417845669089683`, 0.9404787753306446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.1263497464931148], {
             RGBColor[
             0.995012282944504, 0.9917401024908713, 0.6984959630099713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.1263497464931148], {
             RGBColor[
             0.288026604294227, 0.42006460142766994`, 0.9397140610661554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.1263497464931148], {
             RGBColor[
             0.47845288838444977`, 0.5874686347043143, 0.9520847104857538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.1263497464931148], {
             RGBColor[
             0.5541205279346776, 0.6488990332795047, 0.9580415442508443]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.1263497464931148], {
             RGBColor[
             0.3887230257826245, 0.5111140799707138, 0.9459900653619617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.1263497464931148], {
             RGBColor[
             0.2214983333727114, 0.3501391705531527, 0.935925374456932]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.1263497464931148], {
             RGBColor[
             0.32142541763141447`, 0.45282427426627114`, 0.9417019212795049]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.1263497464931148], {
             RGBColor[
             0.3794966559540616, 0.5031226621560437, 0.9454021692350443]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.1263497464931148], {
             RGBColor[
             0.3106402383398704, 0.4434826940428085, 0.9410146991920073]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.1263497464931148], {
             RGBColor[
             0.3389322710379519, 0.46798783076697686`, 0.9428174424978669]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.1263497464931148], {
             RGBColor[
             0.530060180855995, 0.6293657596147464, 0.956147425592855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.1263497464931148], {
             RGBColor[
             0.20251399589249727`, 0.3301854281849303, 0.9348442445222443]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.1263497464931148], {
             RGBColor[
             0.2895300426964028, 0.42164481051185704`, 0.9397996796590214]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.1263497464931148], {
             RGBColor[
             0.2571567874572822, 0.3876184666726076, 0.9379560706650929]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.1263497464931148], {
             RGBColor[
             0.29187902171512436`, 0.4241137363944052, 0.9399334505391346]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.1263497464931148], {
             RGBColor[
             0.26669510879236896`, 0.3976438471602859, 0.9384992639544442]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.1263497464931148], {
             RGBColor[
             0.26758724701855985`, 0.39858154100084314`, 0.9385500699066255]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.1263497464931148], {
             RGBColor[
             0.9363477620849906, 0.9520488457007356, 0.992630815014362]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.1263497464931148], {
             RGBColor[
             0.40218098833047056`, 0.5227706907127926, 0.9468475948351015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.1263497464931148], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.1263497464931148], {
             RGBColor[
             0.3852067069606633, 0.5080684213424537, 0.945766008635985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.1263497464931148], {
             RGBColor[
             0.2763851217593817, 0.4078286651709235, 0.939051095857826]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.1263497464931148], {
             RGBColor[
             0.34719934599752944`, 0.47514835558169377`, 0.9433442132040039]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.1263497464931148], {
             RGBColor[
             0.19926625391872904`, 0.32677184545176546`, 0.9346592904214419]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.1263497464931148], {
             RGBColor[
             0.3455712107016766, 0.4737381466208854, 0.9432404698626556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.1263497464931148], {
             RGBColor[
             0.5137829014627389, 0.6161511309202208, 0.9548660185333789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.1263497464931148], {
             RGBColor[
             0.5793721418847915, 0.6693994310564518, 0.9600294438007071]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.1263497464931148], {
             RGBColor[
             0.3122630708211355, 0.44488830997214823`, 0.9411181046426992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.1263497464931148], {
             RGBColor[
             0.23568827926952945`, 0.3650537033852422, 0.936733470883612]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.1263497464931148], {
             RGBColor[
             0.19277174118480567`, 0.3199457007925216, 0.9342894375290156]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.1263497464931148], {
             RGBColor[
             0.2979010200002716, 0.4304432384088389, 0.9402763944327256]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.1263497464931148], {
             RGBColor[
             0.2889184473446245, 0.4210019850197531, 0.939764850208512]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.1263497464931148], {
             RGBColor[
             0.2621492674059923, 0.3928658796402132, 0.9382403850124597]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.1263497464931148], {
             RGBColor[
             0.31902341345000534`, 0.450743778972575, 0.9415488676970745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.1263497464931148], {
             RGBColor[
             0.301356219775506, 0.43407487244492904`, 0.9404731629484152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.1263497464931148], {
             RGBColor[
             0.416374086342034, 0.5350640388445608, 0.9477519664899345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.1263497464931148], {
             RGBColor[
             0.30662735634542504`, 0.43961517118927546`, 0.9407733463781244]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.1263497464931148], {
             RGBColor[
             0.39818389112836733`, 0.5193086060162776, 0.9465929033358778]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.1263497464931148], {
             RGBColor[
             0.3692294396346824, 0.4942297154254943, 0.9447479512901164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.1263497464931148], {
             RGBColor[
             0.553977201897875, 0.648782674746064, 0.9580302611002067]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.1263497464931148], {
             RGBColor[
             0.291996334556541, 0.42423703962879783`, 0.9399401313319045]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.1263497464931148], {
             RGBColor[
             0.22428623966818392`, 0.3530694368331628, 0.9360841415961214]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.1263497464931148], {
             RGBColor[
             0.656025350727376, 0.7312112570563387, 0.9663501341211961]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.1263497464931148], {
             RGBColor[
             0.4285381936064057, 0.5455999771711516, 0.9485270526485227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.1263497464931148], {
             RGBColor[
             0.40498369429033654`, 0.525198253747131, 0.9470261807805286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.1263497464931148], {
             RGBColor[
             0.9949596982996386, 0.9916276292526274, 0.692772448931186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.1263497464931148], {
             RGBColor[
             0.2947683579884542, 0.42715061201217536`, 0.9400979939655107]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.1263497464931148], {
             RGBColor[
             0.2363082503315866, 0.36570533227989993`, 0.9367687773184312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.1263497464931148], {
             RGBColor[
             0.6075938207150032, 0.6923110613029606, 0.9622511577376371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.1263497464931148], {
             RGBColor[
             0.48022841070602895`, 0.5889100837113413, 0.9522244861068611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.1263497464931148], {
             RGBColor[
             0.39105467897519935`, 0.5131336407738251, 0.9461386362415927]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.1263497464931148], {
             RGBColor[
             0.3741963760770501, 0.4985318261263888, 0.9450644400881345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.1263497464931148], {
             RGBColor[
             0.2799053703836748, 0.4115286696717095, 0.9392515688092383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.1263497464931148], {
             RGBColor[
             0.2623735277803323, 0.3931015915125735, 0.9382531563090148]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.1263497464931148], {
             RGBColor[
             0.39516723391201586`, 0.5166957291570742, 0.9464006846055771]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.1263497464931148], {
             RGBColor[
             0.3487481921166316, 0.4764898882427906, 0.9434429043091221]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.1263497464931148], {
             RGBColor[
             0.37032050149252915`, 0.4951747383683977, 0.9448174727869102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.1263497464931148], {
             RGBColor[
             0.4157976544452876, 0.5345647625079085, 0.9477152367591926]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.1263497464931148], {
             RGBColor[
             0.3135604109961346, 0.44601200082551923`, 0.9412007700114572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.1263497464931148], {
             RGBColor[
             0.6876799566185954, 0.7559400757624746, 0.9695051694073222]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.1263497464931148], {
             RGBColor[
             0.4901143415244938, 0.5969359277058792, 0.9530027427942485]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.1263497464931148], {
             RGBColor[
             0.494496410593867, 0.6004934887863583, 0.9533477153234374]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.1263497464931148], {
             RGBColor[
             0.301303003063684, 0.4340189383066697, 0.940470132335404]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.1263497464931148], {
             RGBColor[
             0.23926945414690937`, 0.36881774524097, 0.9369374134950054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.1263497464931148], {
             RGBColor[
             0.31410757120538035`, 0.4464859234976962, 0.9412356345761556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.1263497464931148], {
             RGBColor[
             0.23331075579955812`, 0.3625547754746078, 0.9365980744392279]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.1263497464931148], {
             RGBColor[
             0.3182432196046995, 0.45006801427745396`, 0.9414991544351499]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.1263497464931148], {
             RGBColor[
             0.3779384082588587, 0.5017729863222653, 0.9453028790698103]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.1263497464931148], {
             RGBColor[
             0.6153213944453961, 0.698584653780523, 0.962859500648729]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.1263497464931148], {
             RGBColor[
             0.6833813758557328, 0.7525819918001024, 0.9690767270494012]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.1263497464931148], {
             RGBColor[
             0.2320242175897836, 0.3612025422449009, 0.936524807991444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.1263497464931148], {
             RGBColor[
             0.34596868370604683`, 0.4740824177596968, 0.9432657964910225]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.1263497464931148], {
             RGBColor[
             0.28840833842546415`, 0.42046582820294204`, 0.9397358002602043]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.1263497464931148], {
             RGBColor[
             0.3102196746805117, 0.4431184229392161, 0.9409879012475229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.1263497464931148], {
             RGBColor[
             0.3236577569152101, 0.4547578143532601, 0.9418441639646883]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.1263497464931148], {
             RGBColor[
             0.4004290815560116, 0.521253277118151, 0.9467359648845833]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.1263497464931148], {
             RGBColor[
             0.2172751095202088, 0.3457002945163146, 0.9356848681062317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.1263497464931148], {
             RGBColor[
             0.3078496401587032, 0.44089986897430067`, 0.9408429536330837]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.1263497464931148], {
             RGBColor[
             0.841841169007533, 0.8767253132695593, 0.9847767562920636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.1263497464931148], {
             RGBColor[
             0.30390794757221024`, 0.43675690014815194`, 0.9406184800714945]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.1263497464931148], {
             RGBColor[
             0.3068504580456016, 0.4398496652216259, 0.9407860516899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.1263497464931148], {
             RGBColor[
             0.2975736159784852, 0.4300991160233274, 0.9402577492580357]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.1263497464931148], {
             RGBColor[
             0.4440759690627916, 0.5590580173201715, 0.9495171059610882]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.1263497464931148], {
             RGBColor[
             0.37083347648853443`, 0.4956190515270645, 0.9448501591000497]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.1263497464931148], {
             RGBColor[
             0.3044178854310391, 0.4372928771697087, 0.9406475202781694]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.1263497464931148], {
             RGBColor[
             0.2233920588936733, 0.35212959614481654`, 0.936033219323835]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.1263497464931148], {
             RGBColor[
             0.4418865112029795, 0.5571616189673539, 0.9493775956423225]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.1263497464931148], {
             RGBColor[
             0.3510127698847786, 0.4784513516845714, 0.943587201202021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.1263497464931148], {
             RGBColor[
             0.3826252166161558, 0.5058324641555186, 0.9456015183539553]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.1263497464931148], {
             RGBColor[
             0.3348425196861791, 0.464445493702951, 0.942556847158157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.1263497464931148], {
             RGBColor[
             0.44294914720501394`, 0.5580820208626778, 0.94944530586872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.1263497464931148], {
             RGBColor[
             0.35332627545105666`, 0.48045519392591074`, 0.9437346157309516]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.1263497464931148], {
             RGBColor[
             0.37747771707631605`, 0.5013739587749589, 0.9452735242350319]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.1263497464931148], {
             RGBColor[
             0.86546623712304, 0.8955633012994741, 0.987030136379268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.1263497464931148], {
             RGBColor[
             0.38905185977966283`, 0.511398899451271, 0.9460110183734766]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.1263497464931148], {
             RGBColor[
             0.2853505394384257, 0.4172518875919111, 0.9395616631315007]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.1263497464931148], {
             RGBColor[
             0.4000615889679724, 0.520934973509106, 0.9467125485818344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.1263497464931148], {
             RGBColor[
             0.35804381475151087`, 0.48454128935754465`, 0.9440352131636204]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.1263497464931148], {
             RGBColor[
             0.2526024801987934, 0.3828316009841777, 0.9376967096042157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.1263497464931148], {
             RGBColor[
             0.2905164730427267, 0.42268161134913973`, 0.9398558554079517]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.1263497464931148], {
             RGBColor[
             0.2660623798388358, 0.39697880891278986`, 0.938463230976579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.1263497464931148], {
             RGBColor[
             0.31352164515097325`, 0.44597842379886854`, 0.9411982998860828]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.1263497464931148], {
             RGBColor[
             0.391931119245013, 0.5138927692843689, 0.9461944822405796]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.1263497464931148], {
             RGBColor[
             0.28432359578093563`, 0.4161725046959005, 0.9395031802094336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.1263497464931148], {
             RGBColor[
             0.41009588933998004`, 0.529626180152738, 0.9473519253285553]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.1263497464931148], {
             RGBColor[
             0.9763455405678506, 0.9818791234029012, 0.9249250091342547]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.1263497464931148], {
             RGBColor[
             0.3403726638732942, 0.46923542664470136`, 0.9429092230556455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.1263497464931148], {
             RGBColor[
             0.3743304578450115, 0.4986479610146514, 0.9450729836598252]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.1263497464931148], {
             RGBColor[
             0.3429547584367248, 0.4714719071756987, 0.9430737518379708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.1263497464931148], {
             RGBColor[
             0.345424804738416, 0.47361133713408676`, 0.9432311410041383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.1263497464931148], {
             RGBColor[
             0.2564022138562854, 0.3868253619752304, 0.9379130988148077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.1263497464931148], {
             RGBColor[
             0.23259888533210393`, 0.36180655447811894`, 0.9365575344692244]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.1263497464931148], {
             RGBColor[
             0.29323406906676647`, 0.4255379770759454, 0.9400106184811977]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.1263497464931148], {
             RGBColor[
             0.31110456385472046`, 0.4438848694660927, 0.9410442856032266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.1263497464931148], {
             RGBColor[
             0.23791540801165786`, 0.36739455690133715`, 0.9368603025707346]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.1263497464931148], {
             RGBColor[
             0.3306015516213065, 0.46077218032241113`, 0.9422866164232042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.1263497464931148], {
             RGBColor[
             0.4177227225406916, 0.5362321597354117, 0.9478379003959608]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.1263497464931148], {
             RGBColor[
             0.24982963310794126`, 0.3799171628830323, 0.9375388000644513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.1263497464931148], {
             RGBColor[
             0.6305168272859865, 0.7109209907069626, 0.9640557407846448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.1263497464931148], {
             RGBColor[
             0.24187432365529554`, 0.37155562825254984`, 0.9370857569599489]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.1263497464931148], {
             RGBColor[
             0.3085519841343849, 0.4416380770239221, 0.940882951083474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.1263497464931148], {
             RGBColor[
             0.24283364722484507`, 0.37256393814877375`, 0.9371403890180426]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.1263497464931148], {
             RGBColor[
             0.2789703608052202, 0.4105459153217224, 0.939198321396968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.1263497464931148], {
             RGBColor[
             0.25422770536722106`, 0.3845398156814224, 0.9377892637732526]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.1263497464931148], {
             RGBColor[
             0.39105467897519935`, 0.5131336407738251, 0.9461386362415927]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.1263497464931148], {
             RGBColor[
             0.39373421959715904`, 0.515454524182939, 0.9463093742005992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.1263497464931148], {
             RGBColor[
             0.24068534235875738`, 0.3703059335241199, 0.9370180462340513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.1263497464931148], {
             RGBColor[
             0.7898528347050083, 0.8357583046662146, 0.979688807035144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.1263497464931148], {
             RGBColor[
             0.2640412595858546, 0.3948544833804812, 0.9383481311681512]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.1263497464931148], {
             RGBColor[
             0.43873288028925916`, 0.5544301023759879, 0.9491766490691466]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.1263497464931148], {
             RGBColor[
             0.20473819468527868`, 0.33252320213849207`, 0.934970909353086]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.1263497464931148], {
             RGBColor[
             0.3403726638732942, 0.46923542664470136`, 0.9429092230556455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.1263497464931148], {
             RGBColor[
             0.34214614154167994`, 0.47077152386347776`, 0.9430222274844503]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.1263497464931148], {
             RGBColor[
             0.41202834719650605`, 0.5312999780199048, 0.9474750598343677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.1263497464931148], {
             RGBColor[
             0.32028268195277443`, 0.4518344940569983, 0.9416291071725434]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.1263497464931148], {
             RGBColor[
             0.26721187170256727`, 0.39818699774356525`, 0.9385286928376977]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.1263497464931148], {
             RGBColor[
             0.32556760667796747`, 0.45641203022592036`, 0.9419658579027573]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.1263497464931148], {
             RGBColor[
             0.9909148173168201, 0.9905110577290295, 0.8002285189667835]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.1263497464931148], {
             RGBColor[
             0.4155630504731227, 0.5343615603387578, 0.9477002880015384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.1263497464931148], {
             RGBColor[
             0.2640412595858546, 0.3948544833804812, 0.9383481311681512]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.1263497464931148], {
             RGBColor[
             0.24982963310794126`, 0.3799171628830323, 0.9375388000644513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.1263497464931148], {
             RGBColor[
             0.9784512450090639, 0.938973130906601, 0.37078758531148404`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.1263497464931148], {
             RGBColor[
             0.2703651483960346, 0.40150129147768915`, 0.9387082672805359]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.1263497464931148], {
             RGBColor[
             0.2981060148764662, 0.43065870102114523`, 0.9402880685876621]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.1263497464931148], {
             RGBColor[
             0.31057843075404973`, 0.44342915941851024`, 0.9410107608672932]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.1263497464931148], {
             RGBColor[
             0.33724244063134634`, 0.46652418460212086`, 0.9427097679986164]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.1263497464931148], {
             RGBColor[
             0.5917880531841802, 0.6794792271797255, 0.9610068698191766]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.1263497464931148], {
             RGBColor[
             0.2609614153704024, 0.39161737183663925`, 0.9381727385963025]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.1263497464931148], {
             RGBColor[
             0.25637853893698304`, 0.386800478133967, 0.9379117505631773]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.1263497464931148], {
             RGBColor[
             0.2934081991942264, 0.4257209988803935, 0.9400205349343541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.1263497464931148], {
             RGBColor[
             0.3429547584367248, 0.4714719071756987, 0.9430737518379708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.1263497464931148], {
             RGBColor[
             0.3643072251141414, 0.4899663406054969, 0.9444343121334108]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.1263497464931148], {
             RGBColor[
             0.3177587826822878, 0.44964841936376865`, 0.9414682865428246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.1263497464931148], {
             RGBColor[
             0.2604654349402351, 0.3910960649575579, 0.9381444932445417]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.1263497464931148], {
             RGBColor[
             0.34006042540258136`, 0.4689649813749318, 0.9428893274963933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.1263497464931148], {
             RGBColor[
             0.22145272846017797`, 0.3500912368985616, 0.9359227773246297]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.1263497464931148], {
             RGBColor[
             0.23303276419501, 0.36226258867254196`, 0.9365822432286007]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.1263497464931148], {
             RGBColor[
             0.2614327329736084, 0.39211275652087074`, 0.9381995794365531]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.1263497464931148], {
             RGBColor[
             0.37223172557132045`, 0.4968301446045314, 0.9449392542951817]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.1263497464931148], {
             RGBColor[
             0.9219637925311737, 0.9406129183966325, 0.9924189236500589]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.1263497464931148], {
             RGBColor[
             0.31284192079969264`, 0.4453896807297285, 0.9411549884514758]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.1263497464931148], {
             RGBColor[
             0.2739345514949209, 0.40525296044784637`, 0.9389115395065588]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.1263497464931148], {
             RGBColor[
             0.9450685746849082, 0.9585528134587341, 0.9778687540349044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.1263497464931148], {
             RGBColor[
             0.3241551197616185, 0.45518860505263553`, 0.9418758554854607]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.1263497464931148], {
             RGBColor[
             0.322981006193891, 0.45417164689293377`, 0.941801042007153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.1263497464931148], {
             RGBColor[
             0.190886573652768, 0.317964270189825, 0.9341820800269215]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.1263497464931148], {
             RGBColor[
             0.48600558716019193`, 0.5936002558156642, 0.9526792865998274]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.1263497464931148], {
             RGBColor[
             0.3404353889756858, 0.4692897559757377, 0.9429132198437044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.1263497464931148], {
             RGBColor[
             0.21081320880196697`, 0.3389084271532733, 0.9353168724198534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.1263497464931148], {
             RGBColor[
             0.24636484907183565`, 0.3762754551810893, 0.9373414857392838]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.1263497464931148], {
             RGBColor[
             0.9508283575833907, 0.9628484501136434, 0.9681189439797453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.1263497464931148], {
             RGBColor[
             0.3757160617457869, 0.4998481014710261, 0.9451612731151412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.1263497464931148], {
             RGBColor[
             0.9521058220396501, 0.8478225747155727, 0.28032142407349914`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.1263497464931148], {
             RGBColor[
             0.4341790567390778, 0.5504858092986474, 0.948886483459317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.1263497464931148], {
             RGBColor[
             0.41917177103906966`, 0.5374872527134116, 0.9479302324849342]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.1263497464931148], {
             RGBColor[
             0.881462385278418, 0.908318195634698, 0.9885558632702579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.1263497464931148], {
             RGBColor[
             0.48672762523454555`, 0.5941864388518691, 0.9527361280819532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.1263497464931148], {
             RGBColor[
             0.28988292992790077`, 0.4220157173665042, 0.9398197760648054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.1263497464931148], {
             RGBColor[
             0.27474097159163696`, 0.4061005590994822, 0.9389574639380751]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.1263497464931148], {
             RGBColor[
             0.7110674593149863, 0.7742105706204989, 0.9718362171074596]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.1263497464931148], {
             RGBColor[
             0.25723769376736616`, 0.38770350433426215`, 0.937960678159762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.1263497464931148], {
             RGBColor[
             0.2640412595858546, 0.3948544833804812, 0.9383481311681512]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.1263497464931148], {
             RGBColor[
             0.2895300426964028, 0.42164481051185704`, 0.9397996796590214]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.1263497464931148], {
             RGBColor[
             0.31238003535526393`, 0.4449896187728018, 0.9411255575193861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.1263497464931148], {
             RGBColor[
             0.2987618743518642, 0.4313480509136811, 0.9403254188145289]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.1263497464931148], {
             RGBColor[
             0.31790869110114484`, 0.44977826250156644`, 0.9414778385747153]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.1263497464931148], {
             RGBColor[
             0.24249915840560815`, 0.3722123691919397, 0.937121340374619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.1263497464931148], {
             RGBColor[
             0.2761634891521908, 0.40759571524844695`, 0.9390384742087226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.1263497464931148], {
             RGBColor[
             0.28201933659117717`, 0.4137505821889934, 0.9393719560574229]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.1263497464931148], {
             RGBColor[
             0.18993562096280595`, 0.3169647586187919, 0.9341279246780365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.1263497464931148], {
             RGBColor[
             0.32947872720587, 0.45979964624855607`, 0.9422150710443272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.1263497464931148], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.1263497464931148], {
             RGBColor[
             0.9949596982996386, 0.9916276292526274, 0.692772448931186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.1263497464931148], {
             RGBColor[
             0.24629796206569626`, 0.3762051526967557, 0.9373376766232346]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.1263497464931148], {
             RGBColor[
             0.2593586947252473, 0.38993281082022313`, 0.9380814660265736]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.1263497464931148], {
             RGBColor[
             0.5531499089006892, 0.6481110410218236, 0.9579651335649941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.1263497464931148], {
             RGBColor[
             0.363833838033907, 0.4895563165097243, 0.944404148327258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.1263497464931148], {
             RGBColor[
             0.3301378532698699, 0.46037054811655354`, 0.942257069974283]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.1263497464931148], {
             RGBColor[
             0.2978407394021351, 0.4303798796781868, 0.9402729615418389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.1263497464931148], {
             RGBColor[
             0.20481525269579837`, 0.33260419499330834`, 0.934975297692788]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.1263497464931148], {
             RGBColor[
             0.28158475652826787`, 0.4132938109889084, 0.9393472073657437]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.1263497464931148], {
             RGBColor[
             0.2443647772527096, 0.3741732528873102, 0.9372275846080257]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.1263497464931148], {
             RGBColor[
             0.31206837416396493`, 0.44471967351344555`, 0.9411056987438677]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.1263497464931148], {
             RGBColor[
             0.29236228241265233`, 0.424621674028005, 0.9399609715209387]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.1263497464931148], {
             RGBColor[
             0.28558522535741165`, 0.417498557372712, 0.9395750281474002]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.1263497464931148], {
             RGBColor[
             0.2949613123304219, 0.42735341925959536`, 0.9401089824298354]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.1263497464931148], {
             RGBColor[
             0.3572972301241252, 0.4838946352777376, 0.9439876414513422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.1263497464931148], {
             RGBColor[
             0.294485059473295, 0.4268528473105798, 0.9400818605341751]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.1263497464931148], {
             RGBColor[
             0.6385005636960097, 0.717402547587846, 0.9646842497602319]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.1263497464931148], {
             RGBColor[
             0.2497128460926812, 0.37979441232526956`, 0.9375321492167032]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.1263497464931148], {
             RGBColor[
             0.3389322710379519, 0.46798783076697686`, 0.9428174424978669]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.1263497464931148], {
             RGBColor[
             0.34285457077674, 0.4713851296601981, 0.943067367968869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.1263497464931148], {
             RGBColor[
             0.7824241877958404, 0.829954989240965, 0.9789483889358905]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.1263497464931148], {
             RGBColor[
             0.7714491483865085, 0.821381205041006, 0.9778544995751428]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.1263497464931148], {
             RGBColor[
             0.41176255164045766`, 0.5310697592685288, 0.9474581235765701]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.1263497464931148], {
             RGBColor[
             0.34082807495452555`, 0.46962988083363755`, 0.9429382414470374]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.1263497464931148], {
             RGBColor[
             0.431798115729033, 0.5484235578653214, 0.9487347720035405]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.1263497464931148], {
             RGBColor[
             0.22600346787441977`, 0.3548743525564735, 0.9361819352020551]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.1263497464931148], {
             RGBColor[
             0.2527814280371599, 0.38301968650824914`, 0.937706900418881]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.1263497464931148], {
             RGBColor[
             0.31902341345000534`, 0.450743778972575, 0.9415488676970745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.1263497464931148], {
             RGBColor[
             0.8707038114149154, 0.8997396008696488, 0.9875297008908648]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.1263497464931148], {
             RGBColor[
             0.39182516281796154`, 0.5138009951527818, 0.9461877307907414]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.1263497464931148], {
             RGBColor[
             0.3329471961402636, 0.46280385970921023`, 0.9424360788177801]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.1263497464931148], {
             RGBColor[
             0.27616017668670506`, 0.407592233637199, 0.9390382855687135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.1263497464931148], {
             RGBColor[
             0.4754721631120105, 0.5850487476480047, 0.951850056873551]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.1263497464931148], {
             RGBColor[
             0.25616475885408135`, 0.3865757817123972, 0.9378995761037153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.1263497464931148], {
             RGBColor[
             0.2823940562540147, 0.4141444363132345, 0.9393932957878733]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.1263497464931148], {
             RGBColor[
             0.47829640960828, 0.5873415981845311, 0.9520723919032931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.1263497464931148], {
             RGBColor[
             0.34285457077674, 0.4713851296601981, 0.943067367968869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.1263497464931148], {
             RGBColor[
             0.305095274485351, 0.43800485601473726`, 0.9406860965827052]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.1263497464931148], {
             RGBColor[
             0.2842574575865042, 0.4161029892601493, 0.9394994137371034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.1263497464931148], {
             RGBColor[
             0.33528584737734973`, 0.46482948186674533`, 0.9425850956066192]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.1263497464931148], {
             RGBColor[
             0.2931631114368679, 0.42546339610794837`, 0.9400065775491474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.1263497464931148], {
             RGBColor[
             0.3742187028271814, 0.4985511644351775, 0.9450658627289101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.1263497464931148], {
             RGBColor[
             0.30241545488876254`, 0.43518819570834677`, 0.9405334848211173]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.1263497464931148], {
             RGBColor[
             0.2809903651668394, 0.412669067981458, 0.9393133576570336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.1263497464931148], {
             RGBColor[
             0.27679788544642303`, 0.4082625059767332, 0.9390746021391738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.1263497464931148], {
             RGBColor[
             0.23784546513965096`, 0.3673210425082237, 0.9368563194276449]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.1263497464931148], {
             RGBColor[
             0.23568827926952945`, 0.3650537033852422, 0.936733470883612]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.1263497464931148], {
             RGBColor[
             0.431436111676341, 0.5481100081497322, 0.9487117054254105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.1263497464931148], {
             RGBColor[
             0.42825646614431245`, 0.5453559590035204, 0.9485091012237599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.1263497464931148], {
             RGBColor[
             0.26115376363066223`, 0.39181954205375635`, 0.9381836925451705]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.1263497464931148], {
             RGBColor[
             0.2842342323242772, 0.416078578036982, 0.9394980910927783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.1263497464931148], {
             RGBColor[
             0.3392696434502285, 0.46828004579366034`, 0.9428389395696505]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.1263497464931148], {
             RGBColor[
             0.24283364722484507`, 0.37256393814877375`, 0.9371403890180426]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.1263497464931148], {
             RGBColor[
             0.37428634193839216`, 0.49860975003366764`, 0.9450701726332655]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.1263497464931148], {
             RGBColor[
             0.24550305465460703`, 0.37536965460766003`, 0.9372924078221332]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.1263497464931148], {
             RGBColor[
             0.32113777698659, 0.4525751343969634, 0.9416835930719674]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.1263497464931148], {
             RGBColor[
             0.29451299509052303`, 0.42688220941550686`, 0.9400834514262492]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.1263497464931148], {
             RGBColor[
             0.25223113949169546`, 0.382441298356657, 0.9376755623002958]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.1263497464931148], {
             RGBColor[
             0.34138344439710394`, 0.47011091393111915`, 0.9429736290968246]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.1263497464931148], {
             RGBColor[
             0.23330024773793845`, 0.3625437308355959, 0.936597476020664]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.1263497464931148], {
             RGBColor[
             0.2725396687422257, 0.4037868502340891, 0.9388321029973369]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.1263497464931148], {
             RGBColor[
             0.3170695421176403, 0.44905143382890905`, 0.9414243687435168]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.1263497464931148], {
             RGBColor[
             0.30197619061609093`, 0.43472650110680544`, 0.9405084693706218]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.1263497464931148], {
             RGBColor[
             0.3516635982946137, 0.47901506654158355`, 0.9436286714127907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.1263497464931148], {
             RGBColor[
             0.23969372419159488`, 0.369263679958209, 0.936961575046399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.1263497464931148], {
             RGBColor[
             0.22651045452402593`, 0.3554072276700197, 0.9362108073417306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.1263497464931148], {
             RGBColor[
             0.2127590553435735, 0.34095363524229827`, 0.9354276855017759]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.1263497464931148], {
             RGBColor[
             0.4013451323658482, 0.522046714287579, 0.9467943348321541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.1263497464931148], {
             RGBColor[
             0.25530563621753233`, 0.3856727893498629, 0.937850650340522]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.1263497464931148], {
             RGBColor[
             0.304196194831147, 0.43705986629322624`, 0.9406348953264674]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.1263497464931148], {
             RGBColor[
             0.3031977926073366, 0.4360104822536444, 0.9405780377968251]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.1263497464931148], {
             RGBColor[
             0.30509924920052034`, 0.43800903369239164`, 0.940686322936854]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.1263497464931148], {
             RGBColor[
             0.6207065268524481, 0.702956546866018, 0.9632834379982022]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.1263497464931148], {
             RGBColor[
             0.2406667356563421, 0.3702863767001484, 0.9370169866098749]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.1263497464931148], {
             RGBColor[
             0.23613115320412625`, 0.36551919197033267`, 0.9367586918990141]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.1263497464931148], {
             RGBColor[
             0.3544340112201781, 0.4814146589727051, 0.9438051996746277]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.1263497464931148], {
             RGBColor[
             0.31007732366079244`, 0.4429951256407056, 0.9409788307664224]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.1263497464931148], {
             RGBColor[
             0.8937141971780036, 0.918087457876853, 0.989724452026562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.1263497464931148], {
             RGBColor[
             0.2549340817951686, 0.38528226209404753`, 0.9378294908658339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.1263497464931148], {
             RGBColor[
             0.284176273381268, 0.4160176595130701, 0.9394947904167165]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.1263497464931148], {
             RGBColor[
             0.28543930607268864`, 0.41734518695265116`, 0.9395667182600035]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.1263497464931148], {
             RGBColor[
             0.24335106061728462`, 0.3731077724301316, 0.9371698549452976]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.1263497464931148], {
             RGBColor[
             0.40984221141298405`, 0.5294064570825974, 0.9473357611953657]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.1263497464931148], {
             RGBColor[
             0.3356779689785671, 0.46516911788911514`, 0.9426100812483093]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.1263497464931148], {
             RGBColor[
             0.2668753156914252, 0.39783325603697134`, 0.9385095264707531]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.1263497464931148], {
             RGBColor[
             0.5137829014627389, 0.6161511309202208, 0.9548660185333789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.1263497464931148], {
             RGBColor[
             0.5730132833175045, 0.6642370232082143, 0.9595288511610238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.1263497464931148], {
             RGBColor[
             0.32907251531342613`, 0.45944780592412454`, 0.9421891875817398]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.1263497464931148], {
             RGBColor[
             0.36911716690810775`, 0.4941324704327267, 0.9447407973712578]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.1263497464931148], {
             RGBColor[
             0.38979475286644955`, 0.5120423561041535, 0.9460583548640521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.1263497464931148], {
             RGBColor[
             0.25811322327585096`, 0.38862374135945665`, 0.9380105382700403]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.1263497464931148], {
             RGBColor[
             0.5088254082580482, 0.6121264146041292, 0.9544757465084097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.1263497464931148], {
             RGBColor[
             0.8206701858279558, 0.8598441459531938, 0.9827574490168357]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.1263497464931148], {
             RGBColor[
             0.23364619394682457`, 0.36290734223539173`, 0.9366171771454785]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.1263497464931148], {
             RGBColor[
             0.24177279332410095`, 0.3714489134370695, 0.937079974957788]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.1263497464931148], {
             RGBColor[
             0.23805811920148418`, 0.36754455541025666`, 0.9368684297618729]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.1263497464931148], {
             RGBColor[
             0.27802978540147766`, 0.409557310936464, 0.9391447570191815]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.1263497464931148], {
             RGBColor[
             0.2879774757739807, 0.42001296423796297`, 0.9397112632696064]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.1263497464931148], {
             RGBColor[
             0.31401320395552074`, 0.4464041873289037, 0.9412296215784403]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.1263497464931148], {
             RGBColor[
             0.3389322710379519, 0.46798783076697686`, 0.9428174424978669]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.1263497464931148], {
             RGBColor[
             0.3069751379366985, 0.43998071169233033`, 0.9407931520252506]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.1263497464931148], {
             RGBColor[
             0.3123717162881032, 0.44498241321495563`, 0.941125027435783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.1263497464931148], {
             RGBColor[
             0.43658104413592186`, 0.552566290054397, 0.9490395359722499]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.1263497464931148], {
             RGBColor[
             0.3318853245253724, 0.4618841198876107, 0.9423684172974555]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.1263497464931148], {
             RGBColor[
             0.37591396573386454`, 0.5000195159585552, 0.9451738833822618]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.1263497464931148], {
             RGBColor[
             0.5605046575086496, 0.654081957269415, 0.9585441263167446]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.1263497464931148], {
             RGBColor[
             0.2945176715234708, 0.4268871246430379, 0.9400837177421874]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.1263497464931148], {
             RGBColor[
             0.4431732877352992, 0.5582761601243802, 0.9494595879051101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.1263497464931148], {
             RGBColor[
             0.42667975096578326`, 0.5439902875638876, 0.9484086343268184]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.1263497464931148], {
             RGBColor[
             0.36911716690810775`, 0.4941324704327267, 0.9447407973712578]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.1263497464931148], {
             RGBColor[
             0.47074827181754725`, 0.5812136798862819, 0.9514781748466667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.1263497464931148], {
             RGBColor[
             0.5309803603439407, 0.6301128027766741, 0.9562198654928746]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.1263497464931148], {
             RGBColor[
             0.3502399458687244, 0.47778197036512976`, 0.9435379575390995]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.1263497464931148], {
             RGBColor[
             0.6437837702698256, 0.7216480413634428, 0.965130007785261]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.1263497464931148], {
             RGBColor[
             0.3591148571818041, 0.48546897247850684`, 0.944103459040193]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.1263497464931148], {
             RGBColor[
             0.3547377968210003, 0.48167778279142903`, 0.9438245566244851]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.1263497464931148], {
             RGBColor[
             0.5968392758039021, 0.6835800372574017, 0.9614045205670393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.1263497464931148], {
             RGBColor[
             0.31355684456395694`, 0.44600891176122104`, 0.9412005427615525]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.1263497464931148], {
             RGBColor[
             0.22638096082477394`, 0.35527112158173113`, 0.9362034328671269]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.1263497464931148], {
             RGBColor[
             0.2200523691035498, 0.348619370426834, 0.9358430289309158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.1263497464931148], {
             RGBColor[
             0.304212717807297, 0.4370772329887771, 0.9406358362855156]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.1263497464931148], {
             RGBColor[
             0.3403726638732942, 0.46923542664470136`, 0.9429092230556455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.1263497464931148], {
             RGBColor[
             0.2842342323242772, 0.416078578036982, 0.9394980910927783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.1263497464931148], {
             RGBColor[
             0.9168397772038883, 0.936527167662346, 0.9919301904938799]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.1263497464931148], {
             RGBColor[
             0.21882849563947865`, 0.3473330018180358, 0.9357733311476953]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.1263497464931148], {
             RGBColor[
             0.5983375446732625, 0.6847963994217918, 0.961522469780775]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.1263497464931148], {
             RGBColor[
             0.2568994300737135, 0.3873479677450763, 0.9379414145428248]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.1263497464931148], {
             RGBColor[
             0.2886388073330839, 0.42070806563742313`, 0.939748925123545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.1263497464931148], {
             RGBColor[
             0.46458725314726074`, 0.5762118873790152, 0.9509931568883868]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.1263497464931148], {
             RGBColor[
             0.35713225513309665`, 0.4837517422323928, 0.9439771293907955]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.1263497464931148], {
             RGBColor[
             0.5627984141703793, 0.6559441322599672, 0.9587246992434635]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.1263497464931148], {
             RGBColor[
             0.5474173929238788, 0.6434571263049472, 0.9575138489084016]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.1263497464931148], {
             RGBColor[
             0.2670344725515628, 0.39800053998810375`, 0.9385185902184866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.1263497464931148], {
             RGBColor[
             0.6363393692103464, 0.7156479925436825, 0.9645141126136043]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.1263497464931148], {
             RGBColor[
             0.5259993738274363, 0.6260690135316905, 0.9558277439883407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.1263497464931148], {
             RGBColor[
             0.4668070451130805, 0.578014014497356, 0.951167907043302]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.1263497464931148], {
             RGBColor[
             0.39900536511556, 0.5200201254955008, 0.9466452469319407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.1263497464931148], {
             RGBColor[
             0.23297023625821545`, 0.3621968678464707, 0.936578682355102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.1263497464931148], {
             RGBColor[
             0.31049557391364746`, 0.44335739298785964`, 0.9410054813026901]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.1263497464931148], {
             RGBColor[
             0.2550569123382658, 0.38541136478274896`, 0.9378364858835517]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.1263497464931148], {
             RGBColor[
             0.36600599281693974`, 0.4914377278071135, 0.9445425561092718]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.1263497464931148], {
             RGBColor[
             0.33801070455524057`, 0.46718961619893046`, 0.9427587210964978]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.1263497464931148], {
             RGBColor[
             0.319814994963959, 0.45142940709391793`, 0.9415993065711755]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.1263497464931148], {
             RGBColor[
             0.43734759483907426`, 0.553230237745509, 0.9490883799052205]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.1263497464931148], {
             RGBColor[
             0.2795476191367694, 0.41115265042847277`, 0.9392311954049726]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.1263497464931148], {
             RGBColor[
             0.27307351757491577`, 0.4043479592052173, 0.9388625048986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.1263497464931148], {
             RGBColor[
             0.19953264524976808`, 0.3270518396308734, 0.9346744610136539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.1263497464931148], {
             RGBColor[
             0.3063228055086442, 0.4392950689501805, 0.9407560026585123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.1263497464931148], {
             RGBColor[
             0.44888888350418016`, 0.5632267219051887, 0.9498237806134003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.1263497464931148], {
             RGBColor[
             0.7101211614132389, 0.7734713155075235, 0.9717418989762701]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.1263497464931148], {
             RGBColor[
             0.2848598091455452, 0.4167360989399961, 0.9395337167672915]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.1263497464931148], {
             RGBColor[
             0.28399747107378687`, 0.4158297269511864, 0.9394846078898197]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.1263497464931148], {
             RGBColor[
             0.23672631555916746`, 0.3661447453409538, 0.9367925855146698]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.1263497464931148], {
             RGBColor[
             0.2858720767514179, 0.4178000563752415, 0.9395913639099303]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.1263497464931148], {
             RGBColor[
             0.29201952936048564`, 0.42426141883837915`, 0.9399414522416755]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.1263497464931148], {
             RGBColor[
             0.3741963760770501, 0.4985318261263888, 0.9450644400881345]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.1263497464931148], {
             RGBColor[
             0.3937291837789975, 0.515450162410355, 0.946309053322719]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.1263497464931148], {
             RGBColor[
             0.21267141968150347`, 0.34086152460504077`, 0.9354226947804664]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.1263497464931148], {
             RGBColor[
             0.31352164515097325`, 0.44597842379886854`, 0.9411982998860828]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.1263497464931148], {
             RGBColor[
             0.3012666900514531, 0.43398077102843713`, 0.9404680643630777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[401, 0.1263497464931148], {
             RGBColor[
             0.24982963310794126`, 0.3799171628830323, 0.9375388000644513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[402, 0.1263497464931148], {
             RGBColor[
             0.3234279778166483, 0.4545587912471192, 0.9418295226437137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[403, 0.1263497464931148], {
             RGBColor[
             0.39373421959715904`, 0.515454524182939, 0.9463093742005992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[404, 0.1263497464931148], {
             RGBColor[
             0.6070172404243933, 0.6918429674483975, 0.9622057672250772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[405, 0.1263497464931148], {
             RGBColor[
             0.2986155231685411, 0.4311942265408075, 0.9403170843311459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[406, 0.1263497464931148], {
             RGBColor[
             0.3234279778166483, 0.4545587912471192, 0.9418295226437137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[407, 0.1263497464931148], {
             RGBColor[
             0.2203838072139612, 0.34896773289526634`, 0.9358619038409849]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[408, 0.1263497464931148], {
             RGBColor[
             0.25637853893698304`, 0.386800478133967, 0.9379117505631773]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[409, 0.1263497464931148], {
             RGBColor[
             0.23867425630570627`, 0.3681921545721428, 0.9369035178584652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[410, 0.1263497464931148], {
             RGBColor[
             0.24636484907183565`, 0.3762754551810893, 0.9373414857392838]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[411, 0.1263497464931148], {
             RGBColor[
             0.3059618228079237, 0.4389156532440981, 0.9407354452277323]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[412, 0.1263497464931148], {
             RGBColor[
             0.4121911883322874, 0.5314410228270852, 0.947485435927545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[413, 0.1263497464931148], {
             RGBColor[
             0.24647291118984882`, 0.37638903531865514`, 0.937347639717041]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[414, 0.1263497464931148], {
             RGBColor[
             0.553977201897875, 0.648782674746064, 0.9580302611002067]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[415, 0.1263497464931148], {
             RGBColor[
             0.2931288805676132, 0.42542741729399924`, 0.9400046281517834]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[416, 0.1263497464931148], {
             RGBColor[
             0.22654290263700283`, 0.3554413326940876, 0.936212655213762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[417, 0.1263497464931148], {
             RGBColor[
             0.4659932418439603, 0.5773533323420648, 0.9511038414688974]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[418, 0.1263497464931148], {
             RGBColor[
             0.8326565516118054, 0.8694017486680038, 0.9839007192856544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[419, 0.1263497464931148], {
             RGBColor[
             0.21419878376900753`, 0.34246688110148393`, 0.935509675905717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[420, 0.1263497464931148], {
             RGBColor[
             0.33518597111068194`, 0.46474297406448484`, 0.9425787315792242]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[421, 0.1263497464931148], {
             RGBColor[
             0.22047568661334008`, 0.3490643039695039, 0.9358671362368561]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[422, 0.1263497464931148], {
             RGBColor[
             0.32743455043921577`, 0.45802908307659185`, 0.9420848179083505]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[423, 0.1263497464931148], {
             RGBColor[
             0.602507013263453, 0.6881813618557279, 0.9618507056214615]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[424, 0.1263497464931148], {
             RGBColor[
             0.2747294584970578, 0.40608845810710714`, 0.9389568082843709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[425, 0.1263497464931148], {
             RGBColor[
             0.31790869110114484`, 0.44977826250156644`, 0.9414778385747153]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[426, 0.1263497464931148], {
             RGBColor[
             0.40236516859017185`, 0.5229302183965768, 0.9468593306383855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[427, 0.1263497464931148], {
             RGBColor[
             0.5332401116662624, 0.631947370700772, 0.9563977613947097]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[428, 0.1263497464931148], {
             RGBColor[
             0.2640412595858546, 0.3948544833804812, 0.9383481311681512]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[429, 0.1263497464931148], {
             RGBColor[
             0.2842342323242772, 0.416078578036982, 0.9394980910927783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[430, 0.1263497464931148], {
             RGBColor[
             0.30148173900223363`, 0.4342068011105984, 0.9404803110826883]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[431, 0.1263497464931148], {
             RGBColor[
             0.44808155427135954`, 0.5625274539012666, 0.9497723383085782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[432, 0.1263497464931148], {
             RGBColor[
             0.3129798130538462, 0.44550911606961013`, 0.9411637748239772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[433, 0.1263497464931148], {
             RGBColor[
             0.6821794640839407, 0.7516430491891106, 0.9689569317164931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[434, 0.1263497464931148], {
             RGBColor[
             0.7833773927233977, 0.8306996401749984, 0.979043395494863]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[435, 0.1263497464931148], {
             RGBColor[
             0.29451299509052303`, 0.42688220941550686`, 0.9400834514262492]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[436, 0.1263497464931148], {
             RGBColor[
             0.23297023625821545`, 0.3621968678464707, 0.936578682355102]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[437, 0.1263497464931148], {
             RGBColor[
             0.2676863431404608, 0.39868569730801806`, 0.9385557132841682]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[438, 0.1263497464931148], {
             RGBColor[
             0.4449661036059642, 0.5598290071220046, 0.9495738245470641]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[439, 0.1263497464931148], {
             RGBColor[
             0.36113834610097967`, 0.4872216168767865, 0.9442323939648218]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[440, 0.1263497464931148], {
             RGBColor[
             0.2795963077092417, 0.411203825205175, 0.9392339681471467]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[441, 0.1263497464931148], {
             RGBColor[
             0.8890441378653967, 0.9143636793463633, 0.9892790176003144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[442, 0.1263497464931148], {
             RGBColor[
             0.2929409589760542, 0.4252298997863536, 0.9399939262951492]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[443, 0.1263497464931148], {
             RGBColor[
             0.9411782296631871, 0.9556514005113899, 0.984454093392193]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[444, 0.1263497464931148], {
             RGBColor[
             0.25719125400686005`, 0.38765469320151935`, 0.9379580334841027]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[445, 0.1263497464931148], {
             RGBColor[
             0.28397189507023546`, 0.4158028449498416, 0.9394831513742538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[446, 0.1263497464931148], {
             RGBColor[
             0.5639370022615451, 0.6568684893651845, 0.9588143330687856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[447, 0.1263497464931148], {
             RGBColor[
             0.9300151970891589, 0.7602406080512586, 0.26254678870472214`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[448, 0.1263497464931148], {
             RGBColor[
             0.5309803603439407, 0.6301128027766741, 0.9562198654928746]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[449, 0.1263497464931148], {
             RGBColor[
             0.7944004076140502, 0.8393109031855922, 0.9801420666032323]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[450, 0.1263497464931148], {
             RGBColor[
             0.2724060118310348, 0.40364636834608986`, 0.9388244914339723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[451, 0.1263497464931148], {
             RGBColor[
             0.3651763190281612, 0.4907191060718907, 0.9444896900291027]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[452, 0.1263497464931148], {
             RGBColor[
             0.2577924257928509, 0.38828656286508845`, 0.9379922693279609]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[453, 0.1263497464931148], {
             RGBColor[
             0.47732671233487217`, 0.5865543542536142, 0.9519960537818123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[454, 0.1263497464931148], {
             RGBColor[
             0.5410809317178488, 0.6383129016435678, 0.9570150194710408]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[455, 0.1263497464931148], {
             RGBColor[
             0.28397189507023546`, 0.4158028449498416, 0.9394831513742538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[456, 0.1263497464931148], {
             RGBColor[
             0.3429547584367248, 0.4714719071756987, 0.9430737518379708]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[457, 0.1263497464931148], {
             RGBColor[
             0.3495239925312792, 0.47716184756909574`, 0.9434923376255302]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[458, 0.1263497464931148], {
             RGBColor[
             0.27023532405097267`, 0.4013648378596902, 0.9387008739761425]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[459, 0.1263497464931148], {
             RGBColor[
             0.25479946053731284`, 0.3851407666165605, 0.9378218243843532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[460, 0.1263497464931148], {
             RGBColor[
             0.22600346787441977`, 0.3548743525564735, 0.9361819352020551]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[461, 0.1263497464931148], {
             RGBColor[
             0.2410906046408544, 0.37073188987771666`, 0.9370411253214849]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[462, 0.1263497464931148], {
             RGBColor[
             0.4022088843796814, 0.5227948528685228, 0.9468493723466898]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[463, 0.1263497464931148], {
             RGBColor[
             0.9898717778799422, 0.9900797341169897, 0.8175143817353847]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[464, 0.1263497464931148], {
             RGBColor[
             0.729121491751361, 0.7883145179755234, 0.9736356743361919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[465, 0.1263497464931148], {
             RGBColor[
             0.3759945578309087, 0.5000893207823383, 0.9451790186394207]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[466, 0.1263497464931148], {
             RGBColor[
             0.3271485884257548, 0.4577813971534006, 0.9420665966617191]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[467, 0.1263497464931148], {
             RGBColor[
             0.2966433566193046, 0.4291213544549786, 0.9402047723637258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[468, 0.1263497464931148], {
             RGBColor[
             0.2970752380780995, 0.42957528925103816`, 0.9402293673738928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[469, 0.1263497464931148], {
             RGBColor[
             0.4029425589789929, 0.5234303249308889, 0.9468961214433949]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[470, 0.1263497464931148], {
             RGBColor[
             0.3513943644365749, 0.4787818697058376, 0.9436115160694306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[471, 0.1263497464931148], {
             RGBColor[
             0.2772099434180525, 0.40869560503090013`, 0.939098068231073]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[472, 0.1263497464931148], {
             RGBColor[
             0.2599874089063486, 0.390593629287342, 0.938117270369088]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[473, 0.1263497464931148], {
             RGBColor[
             0.29614444643558874`, 0.4285969682191606, 0.9401763601668347]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[474, 0.1263497464931148], {
             RGBColor[
             0.21882849563947865`, 0.3473330018180358, 0.9357733311476953]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[475, 0.1263497464931148], {
             RGBColor[
             0.44100350625404694`, 0.5563968044617077, 0.9493213313477872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[476, 0.1263497464931148], {
             RGBColor[
             0.2578700741310447, 0.3883681761917191, 0.9379966912859505]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[477, 0.1263497464931148], {
             RGBColor[
             0.3668740970540812, 0.49218963606513777`, 0.944597870943628]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[478, 0.1263497464931148], {
             RGBColor[
             0.3584987899085117, 0.48493536597082243`, 0.9440642037783057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[479, 0.1263497464931148], {
             RGBColor[
             0.3116511897266897, 0.4443583293221772, 0.9410791161204263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[480, 0.1263497464931148], {
             RGBColor[
             0.24633842314769983`, 0.37624767985932217`, 0.9373399808219979]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[481, 0.1263497464931148], {
             RGBColor[
             0.8536774354727434, 0.8861632308620239, 0.9859057099538752]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[482, 0.1263497464931148], {
             RGBColor[
             0.2937913688591441, 0.4261237344925819, 0.9400423558799225]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[483, 0.1263497464931148], {
             RGBColor[
             0.26841073285783545`, 0.3994470768299396, 0.9385969662069341]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[484, 0.1263497464931148], {
             RGBColor[
             0.3387310757978665, 0.46781356556238163`, 0.9428046225150786]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[485, 0.1263497464931148], {
             RGBColor[
             0.24408107778422997`, 0.37387506675835286`, 0.9372114283429915]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[486, 0.1263497464931148], {
             RGBColor[
             0.5689499755796736, 0.6609382469367158, 0.9592089726915151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[487, 0.1263497464931148], {
             RGBColor[
             0.5207516686160029, 0.6218086900346231, 0.955414625411119]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[488, 0.1263497464931148], {
             RGBColor[
             0.3208866192851232, 0.4523575942195059, 0.9416675895253199]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[489, 0.1263497464931148], {
             RGBColor[
             0.21903120390984115`, 0.3475460610626334, 0.9357848750838125]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[490, 0.1263497464931148], {
             RGBColor[
             0.32177279352632876`, 0.4531251538068258, 0.9417240557643565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[491, 0.1263497464931148], {
             RGBColor[
             0.6361021248598616, 0.7154553868922228, 0.9644954358692794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[492, 0.1263497464931148], {
             RGBColor[
             0.31902341345000534`, 0.450743778972575, 0.9415488676970745]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[493, 0.1263497464931148], {
             RGBColor[
             0.4168096408175362, 0.5354412942396363, 0.9477797196359679]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[494, 0.1263497464931148], {
             RGBColor[
             0.31264554987541854`, 0.44521959410501194`, 0.9411424758698251]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[495, 0.1263497464931148], {
             RGBColor[
             0.2736181406046614, 0.4049203925405745, 0.9388935203744464]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[496, 0.1263497464931148], {
             RGBColor[
             0.2473566611897467, 0.37731791260153413`, 0.9373979679721443]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[497, 0.1263497464931148], {
             RGBColor[
             0.197786447225936, 0.32521647479247656`, 0.9345750176194652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[498, 0.1263497464931148], {
             RGBColor[
             0.26115376363066223`, 0.39181954205375635`, 0.9381836925451705]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[499, 0.1263497464931148], {
             RGBColor[
             0.30318046664702736`, 0.4359922715708301, 0.940577051109017]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[500, 0.1263497464931148], {
             RGBColor[
             0.3519942744875354, 0.47930148163962366`, 0.9436497418073982]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1dOWGAgQBNBMbNu2bds2J+bEtm3btm3btu01sjdnH271F1R1ssCg6p0C
ggUL9l38vMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEIS
kZgkJCUZyUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpR
mCIUpRjFKUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGY
JjSlGYE0pwUtaUVr2tCWdrSnAx3pRBCd6UJXutGdHvSkF73pQ1/60Z8BDGQQ
gxnCUIYxnBGMZBSjGcNYxjGeCUxkEpOZwlSmMZ0ZzGQWs5nDXOYxnwUsZBGL
WcJSlrGcFaxkFatZw1rWsZ4NbGQTm9nCVraxnR3sZBe72cNe9rGfAxzkEIc5
wlGOcZwTnOQUpznDWc5xngtc5BKXucJVrnGdG9zkFre5w13ucZ8HPOQRj3nC
U57xnBe85BWvecNb3vGeD3zkE5/5wle+8Z1f+JXf+J0/+JO/+Jt/+Jcf/Cx/
AMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEISkZgkJCUZ
yUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpRmCIUpRjF
KUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGYJjSlGYE0
pwUtaUVr2tCWdrSnAx35Od5BdKYLXelGd3rQk170pg996Ud/BjCQQQxmCEMZ
xnBGMJJRjGYMYxnHeCYwkUlMZgpTmcZ0ZjCTWcxmDnOZx3wWsJBFLGYJS1nG
clawklWsZg1rWcd6NrCRTWxmC1vZxnZ2sJNd7GYPe9nHfg5wkEMc5ghHOcZx
TnCSU5zmDGc5x3kucJFLXOYKV7nGdW5wk1vc5g53ucd9HvCQRzzmCU95xnNe
8JJXvOYNb3nHez7wkU985gtf+Rbw/z//Dz189+A=
          "], {Null, CompressedData["
1:eJw13A2c1mO6wPH7tsdpl2O9LLLYQ3Ioas/uCqvVrqQihdKSUmmVzEwspdpK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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[196, 330] -> 
             RGBColor[
              0.3010744440099954, 0.433778708249762, 0.9404571162354194], 
             UndirectedEdge[136, 319] -> 
             RGBColor[
              0.8419251732908781, 0.8767840075536342, 0.9548214315268342], 
             UndirectedEdge[60, 188] -> 
             RGBColor[
              0.31499337168742486`, 0.44577048443841216`, 0.9413463649912971],
              UndirectedEdge[145, 408] -> 
             RGBColor[
              0.2215813501340996, 0.35022642643293833`, 0.9359301021386808], 
             UndirectedEdge[398, 460] -> 
             RGBColor[
              0.2547486544855675, 0.3850873662348864, 0.9378189310548671], 
             UndirectedEdge[413, 476] -> 
             RGBColor[
              0.9111642263834832, 0.6485722673362936, 0.273464018883213], 
             UndirectedEdge[244, 274] -> 
             RGBColor[
              0.40258764491589, 0.5228672426461249, 0.9469441500000384], 
             UndirectedEdge[198, 223] -> 
             RGBColor[
              0.335871613441881, 0.4628528461466326, 0.9427133713948876], 
             UndirectedEdge[36, 310] -> 
             RGBColor[
              0.2755731801551128, 0.4069752630647657, 0.9390048569846228], 
             UndirectedEdge[252, 432] -> 
             RGBColor[
              0.8172102397534445, 0.8577657390481622, 0.982246863062763], 
             UndirectedEdge[469, 475] -> 
             RGBColor[
              0.8497170345102683, 0.3799664311487149, 0.19511763635494941`], 
             UndirectedEdge[113, 347] -> 
             RGBColor[
              0.17905963034776856`, 0.3055334029047545, 0.9335085531020964], 
             UndirectedEdge[35, 131] -> 
             RGBColor[
              0.2509907389862678, 0.38113755877951816`, 0.9376049233265198], 
             UndirectedEdge[156, 479] -> 
             RGBColor[
              0.4393999195807523, 0.5546279653397757, 0.9493241177753168], 
             UndirectedEdge[318, 354] -> 
             RGBColor[
              0.35185308329442466`, 0.47917918892462685`, 0.9436407452294238],
              UndirectedEdge[6, 77] -> 
             RGBColor[
              0.7172538475630181, 0.7785612627115652, 0.9728085302210365], 
             UndirectedEdge[23, 202] -> 
             RGBColor[
              0.23077928410080303`, 0.35989403821464017`, 0.9364539108709606],
              UndirectedEdge[342, 395] -> 
             RGBColor[
              0.2624873580585535, 0.3932212343522405, 0.9382596387749628], 
             UndirectedEdge[53, 418] -> 
             RGBColor[
              0.9774928986004763, 0.9579493905915291, 0.642289060004833], 
             UndirectedEdge[75, 149] -> 
             RGBColor[
              0.3494116417234011, 0.4770645349462275, 0.9434851787314], 
             UndirectedEdge[293, 418] -> 
             RGBColor[
              0.9663729017016692, 0.9744415456652006, 0.9418060854539165], 
             UndirectedEdge[282, 432] -> 
             RGBColor[
              0.7531414292760994, 0.8071831282683875, 0.9762245194841053], 
             UndirectedEdge[466, 468] -> 
             RGBColor[
              0.49094259840512156`, 0.5976083439541202, 0.9530679462098963], 
             UndirectedEdge[105, 190] -> 
             RGBColor[
              0.24700744449895456`, 0.37695086371789455`, 0.9373780805982235],
              UndirectedEdge[64, 473] -> 
             RGBColor[
              0.3073328542986736, 0.43868458843205593`, 0.9408747474285853], 
             UndirectedEdge[214, 273] -> 
             RGBColor[
              0.24667426527178135`, 0.3766006712253524, 0.9373591065341305], 
             UndirectedEdge[30, 64] -> 
             RGBColor[
              0.27788283656739987`, 0.4094028583947541, 0.9391363885004721], 
             UndirectedEdge[296, 395] -> 
             RGBColor[
              0.289203696626415, 0.4208696734674796, 0.9397969170059906], 
             UndirectedEdge[114, 203] -> 
             RGBColor[
              0.5176225598035007, 0.6192683385358883, 0.9551682905030956], 
             UndirectedEdge[81, 237] -> 
             RGBColor[
              0.8648552697662895, 0.8950761325134684, 0.9869718617673642], 
             UndirectedEdge[382, 427] -> 
             RGBColor[
              0.2808624118228371, 0.41253458090420103`, 0.9393060709033827], 
             UndirectedEdge[39, 450] -> 
             RGBColor[
              0.7206850354992045, 0.4212381693670362, 0.5640535204963621], 
             UndirectedEdge[50, 57] -> 
             RGBColor[
              0.5210905073010532, 0.6217476292469348, 0.9555341779806428], 
             UndirectedEdge[74, 153] -> 
             RGBColor[
              0.2633334885240648, 0.39411057111926295`, 0.9383078246532357], 
             UndirectedEdge[239, 332] -> 
             RGBColor[
              0.37656128496655794`, 0.5005801913427036, 0.9452151299913671], 
             UndirectedEdge[14, 72] -> 
             RGBColor[
              0.2803635687690008, 0.4120102652261427, 0.9392776625294388], 
             UndirectedEdge[331, 403] -> 
             RGBColor[
              0.8828018353475209, 0.9093862367613971, 0.9886836212135901], 
             UndirectedEdge[214, 302] -> 
             RGBColor[
              0.19497823659732902`, 0.32226486737097304`, 0.9344150941785414],
              UndirectedEdge[128, 197] -> 
             RGBColor[
              0.5961844176461558, 0.6822017797294064, 0.9619318024689351], 
             UndirectedEdge[191, 212] -> 
             RGBColor[
              0.21845881642544385`, 0.3469444455250692, 0.9357522784633475], 
             UndirectedEdge[404, 407] -> 
             RGBColor[
              0.2139033248740353, 0.3421563350696921, 0.9354928499587406], 
             UndirectedEdge[60, 116] -> 
             RGBColor[
              0.27071777339856856`, 0.4018719227130688, 0.9387283487527682], 
             UndirectedEdge[272, 357] -> 
             RGBColor[
              0.8638626077841431, 0.41438606964025426`, 0.20574312527482636`],
              UndirectedEdge[228, 490] -> 
             RGBColor[
              0.9918174311383581, 0.9889858002878001, 0.6472681311594083], 
             UndirectedEdge[111, 415] -> 
             RGBColor[
              0.2800519643946353, 0.41168274927182613`, 0.9392599171212961], 
             UndirectedEdge[227, 428] -> 
             RGBColor[
              0.8379823315719487, 0.29295442119162834`, 0.18400522964919308`],
              UndirectedEdge[367, 499] -> 
             RGBColor[
              0.24528184927831587`, 0.3751371537319471, 0.9372798105031974], 
             UndirectedEdge[434, 495] -> 
             RGBColor[
              0.9167025248852594, 0.6580111596730529, 0.4917530067660364], 
             UndirectedEdge[226, 283] -> 
             RGBColor[
              0.18031957576389654`, 0.30685768542225833`, 0.9335803051296228],
              UndirectedEdge[9, 34] -> 
             RGBColor[
              0.559448373541096, 0.6532244183595045, 0.9584609717735231], 
             UndirectedEdge[127, 386] -> 
             RGBColor[
              0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993],
              UndirectedEdge[326, 469] -> 
             RGBColor[
              0.8678030946468546, 0.4926065528105953, 0.21140400054171546`], 
             UndirectedEdge[192, 483] -> 
             RGBColor[
              0.275631905541692, 0.4070369871694651, 0.9390082013085121], 
             UndirectedEdge[16, 39] -> 
             RGBColor[
              0.5137718344766236, 0.6147998451486828, 0.9552360290912556], 
             UndirectedEdge[209, 421] -> 
             RGBColor[
              0.37249008899703795`, 0.4820057501195733, 0.9462395519949527], 
             UndirectedEdge[293, 317] -> 
             RGBColor[
              0.9188363181868828, 0.7644234365766909, 0.5933539685152149], 
             UndirectedEdge[3, 381] -> 
             RGBColor[
              0.5154854178683257, 0.6175333104357662, 0.9550000468613498], 
             UndirectedEdge[211, 497] -> 
             RGBColor[
              0.23351702426712523`, 0.36277157671219695`, 0.936609821123309], 
             UndirectedEdge[196, 479] -> 
             RGBColor[
              0.35359500425427093`, 0.4794816999667437, 0.9437959057364866], 
             UndirectedEdge[221, 439] -> 
             RGBColor[
              0.6987612824501502, 0.7633077628527738, 0.9716294265306357], 
             UndirectedEdge[379, 390] -> 
             RGBColor[
              0.30502633329137085`, 0.4378812473959014, 0.9406840432278518], 
             UndirectedEdge[119, 320] -> 
             RGBColor[
              0.9896249360090673, 0.9899776586598361, 0.8216051903420669], 
             UndirectedEdge[179, 401] -> 
             RGBColor[
              0.47619075737058414`, 0.5641711945885997, 0.9557776422261561], 
             UndirectedEdge[59, 342] -> 
             RGBColor[
              0.25108912406320616`, 0.3812409677333546, 0.9376105262111039], 
             UndirectedEdge[86, 98] -> 
             RGBColor[
              0.9552139147274563, 0.8468459050338089, 0.4866646892725739], 
             UndirectedEdge[328, 431] -> 
             RGBColor[
              0.4169264678183623, 0.535542483915856, 0.9477871637491544], 
             UndirectedEdge[270, 375] -> 
             RGBColor[
              0.9741122632489756, 0.9792447932430604, 0.8853225104060825], 
             UndirectedEdge[39, 45] -> 
             RGBColor[
              0.45322202962692537`, 0.5599541419213354, 0.9514657433370749], 
             UndirectedEdge[59, 463] -> 
             RGBColor[
              0.2546442329532448, 0.38497761258370766`, 0.9378129844030793], 
             UndirectedEdge[2, 55] -> 
             RGBColor[
              0.21196267506411343`, 0.3401165890751596, 0.9353823328229998], 
             UndirectedEdge[193, 496] -> 
             RGBColor[
              0.28235063055336573`, 0.41409879314850406`, 0.939390822758464], 
             UndirectedEdge[201, 246] -> 
             RGBColor[
              0.2993400916080083, 0.43195579391098005`, 0.9403583474318706], 
             UndirectedEdge[69, 487] -> 
             RGBColor[
              0.7444469428218465, 0.8000461273805028, 0.9756303235156909], 
             UndirectedEdge[15, 408] -> 
             RGBColor[
              0.22837166352845595`, 0.3573634763411423, 0.9363168004411209], 
             UndirectedEdge[118, 310] -> 
             RGBColor[
              0.3109325878407584, 0.44262745407148385`, 0.9410739135361832], 
             UndirectedEdge[289, 297] -> 
             RGBColor[
              0.47936763079523015`, 0.5878325714725148, 0.9522613561781106], 
             UndirectedEdge[397, 419] -> 
             RGBColor[
              0.43561929438142943`, 0.5501211672171827, 0.9494236831393772], 
             UndirectedEdge[13, 380] -> 
             RGBColor[
              0.28473366122711574`, 0.4166035094794867, 0.939526532829956], 
             UndirectedEdge[155, 262] -> 
             RGBColor[
              0.520987467347936, 0.6220001220678183, 0.9554331883510561], 
             UndirectedEdge[182, 324] -> 
             RGBColor[
              0.37413205522389265`, 0.49847611463624397`, 0.9450603416202481],
              UndirectedEdge[177, 245] -> 
             RGBColor[
              0.21512971428686242`, 0.34344534810015337`, 0.9355626910215206],
              UndirectedEdge[113, 325] -> 
             RGBColor[
              0.1791045905323438, 0.30558065890938335`, 0.9335111135180953], 
             UndirectedEdge[94, 368] -> 
             RGBColor[
              0.6817603644893816, 0.7470855364406719, 0.9537864521193352], 
             UndirectedEdge[50, 140] -> 
             RGBColor[
              0.47028604559026116`, 0.5805022785151959, 0.9515346646518938], 
             UndirectedEdge[389, 458] -> 
             RGBColor[
              0.2244995192065336, 0.35329360715067204`, 0.9360962875503116], 
             UndirectedEdge[429, 499] -> 
             RGBColor[
              0.2771583025105514, 0.4086413271628938, 0.9390951273577867], 
             UndirectedEdge[97, 358] -> 
             RGBColor[
              0.2286803601297014, 0.35768793604154625`, 0.9363343802558861], 
             UndirectedEdge[274, 363] -> 
             RGBColor[
              0.4337728092244554, 0.5498782645582716, 0.9489312410938221], 
             UndirectedEdge[255, 274] -> 
             RGBColor[
              0.43015989340709154`, 0.5467489384677, 0.9487010292927157], 
             UndirectedEdge[289, 381] -> 
             RGBColor[
              0.5043379271734174, 0.6081045829713598, 0.9542271093782111], 
             UndirectedEdge[55, 230] -> 
             RGBColor[
              0.21767784356668446`, 0.34612359353397393`, 0.935707803214387], 
             UndirectedEdge[289, 349] -> 
             RGBColor[
              0.42648626116779464`, 0.5438226964259498, 0.9483963053279869], 
             UndirectedEdge[29, 318] -> 
             RGBColor[
              0.37578131668551923`, 0.4999046220200136, 0.9451654311021982], 
             UndirectedEdge[69, 402] -> 
             RGBColor[
              0.7308868707375382, 0.7890374499881754, 0.9745628249690335], 
             UndirectedEdge[6, 413] -> 
             RGBColor[
              0.9007629224656561, 0.8944231613369187, 0.6681426582115271], 
             UndirectedEdge[29, 482] -> 
             RGBColor[
              0.38405087443932273`, 0.5070672973063002, 0.9456923600097877], 
             UndirectedEdge[212, 456] -> 
             RGBColor[
              0.22108739015867407`, 0.34970724317989477`, 0.9359019718488286],
              UndirectedEdge[354, 482] -> 
             RGBColor[
              0.3601226410482282, 0.48634186421091347`, 0.9441676741370133], 
             UndirectedEdge[106, 247] -> 
             RGBColor[
              0.5064333598698463, 0.6101844419620349, 0.9542874356969284], 
             UndirectedEdge[305, 382] -> 
             RGBColor[
              0.2666682843502908, 0.39761565297089385`, 0.938497736342151], 
             UndirectedEdge[279, 285] -> 
             RGBColor[
              0.2964892825686648, 0.42843496613236076`, 0.9402152006381983], 
             UndirectedEdge[27, 319] -> 
             RGBColor[
              0.6135043005796454, 0.695998377538924, 0.9634761021745089], 
             UndirectedEdge[118, 483] -> 
             RGBColor[
              0.31087863822406303`, 0.44257074960373377`, 0.9410708411853237],
              UndirectedEdge[342, 447] -> 
             RGBColor[
              0.2532435452217043, 0.38350540096912705`, 0.9377332173088998], 
             UndirectedEdge[207, 458] -> 
             RGBColor[
              0.22378112515977486`, 0.35253852945871533`, 0.9360553760721175],
              UndirectedEdge[462, 487] -> 
             RGBColor[
              0.5216548713893666, 0.6225419507348611, 0.9554857288419789], 
             UndirectedEdge[64, 384] -> 
             RGBColor[
              0.28582762436265047`, 0.41775333409620263`, 0.9395888324121513],
              UndirectedEdge[203, 221] -> 
             RGBColor[
              0.5355883582024223, 0.6338537830261275, 0.9565826239639467], 
             UndirectedEdge[139, 370] -> 
             RGBColor[
              0.5777392587332322, 0.6680737829534684, 0.9599008972575682], 
             UndirectedEdge[46, 357] -> 
             RGBColor[
              0.9123985653292456, 0.6903965335177349, 0.2483720332752017], 
             UndirectedEdge[18, 326] -> 
             RGBColor[
              0.8797797158009789, 0.5469895922605361, 0.22139758680656518`], 
             UndirectedEdge[73, 93] -> 
             RGBColor[
              0.2585978739086303, 0.3891331399031328, 0.9380381384066008], 
             UndirectedEdge[104, 112] -> 
             RGBColor[
              0.24741859649764936`, 0.37738301053706513`, 0.9374014950963042],
              UndirectedEdge[40, 314] -> 
             RGBColor[
              0.35813781501059505`, 0.484622707657373, 0.944041202777008], 
             UndirectedEdge[264, 398] -> 
             RGBColor[0.2479686232623, 0.377961123540424, 0.9374328183068594],
              UndirectedEdge[345, 489] -> 
             RGBColor[
              0.8249113944148371, 0.8621373590775923, 0.8902454594075883], 
             UndirectedEdge[80, 417] -> 
             RGBColor[
              0.7452877880838611, 0.8009437515388753, 0.9752469796719869], 
             UndirectedEdge[271, 442] -> 
             RGBColor[
              0.26987532258207286`, 0.400986453490465, 0.9386803724250632], 
             UndirectedEdge[318, 482] -> 
             RGBColor[
              0.35021188070592757`, 0.4777576617317112, 0.9435361692517431], 
             UndirectedEdge[235, 260] -> 
             RGBColor[
              0.32130907660212404`, 0.45058132040043347`, 0.941772944022762], 
             UndirectedEdge[79, 278] -> 
             RGBColor[
              0.9710962278680113, 0.9751094566161655, 0.770981396643022], 
             UndirectedEdge[137, 404] -> 
             RGBColor[
              0.2167644246749318, 0.34516353236463915`, 0.9356557853597838], 
             UndirectedEdge[380, 478] -> 
             RGBColor[
              0.26944650218814237`, 0.40053573606766074`, 0.9386559517380118],
              UndirectedEdge[247, 370] -> 
             RGBColor[
              0.5432273595581627, 0.6400554684598069, 0.9571839941332545], 
             UndirectedEdge[251, 429] -> 
             RGBColor[
              0.2760715850682322, 0.4074991182291509, 0.9390332404071009], 
             UndirectedEdge[286, 407] -> 
             RGBColor[
              0.21872930348009942`, 0.347228744569382, 0.9357676823009604], 
             UndirectedEdge[206, 410] -> 
             RGBColor[
              0.35319958507105037`, 0.4803454610863929, 0.9437265431319655], 
             UndirectedEdge[86, 500] -> 
             RGBColor[
              0.8673428769617186, 0.42615530998421236`, 0.20846003809980468`],
              UndirectedEdge[78, 407] -> 
             RGBColor[
              0.21689372054729342`, 0.34529943052432305`, 0.9356631485684387],
              UndirectedEdge[363, 370] -> 
             RGBColor[
              0.4981273475389003, 0.6021241779008506, 0.9539974660883765], 
             UndirectedEdge[447, 453] -> 
             RGBColor[
              0.26540338983624123`, 0.39628616863768357`, 0.9384257024708196],
              UndirectedEdge[256, 492] -> 
             RGBColor[
              0.28300272562501616`, 0.4147841864140242, 0.9394279586081062], 
             UndirectedEdge[114, 349] -> 
             RGBColor[
              0.45713997699902986`, 0.5690874562014547, 0.9507048443075143], 
             UndirectedEdge[22, 160] -> 
             RGBColor[
              0.4369491379476227, 0.5528851144131592, 0.949062990584439], 
             UndirectedEdge[149, 324] -> 
             RGBColor[
              0.361776111320833, 0.4877740170552114, 0.9442730318006773], 
             UndirectedEdge[94, 315] -> 
             RGBColor[
              0.5704593476328262, 0.6392872195268108, 0.9471116754258844], 
             UndirectedEdge[246, 492] -> 
             RGBColor[
              0.2854203608730804, 0.4173252743466679, 0.9395656393589127], 
             UndirectedEdge[193, 202] -> 
             RGBColor[
              0.2634343891958272, 0.39421662412275726`, 0.9383135707972234], 
             UndirectedEdge[321, 335] -> 
             RGBColor[
              0.3049738126003747, 0.4356185220197354, 0.94076188047572], 
             UndirectedEdge[321, 496] -> 
             RGBColor[
              0.3050324981109774, 0.4356802042122551, 0.9407652225287313], 
             UndirectedEdge[18, 474] -> 
             RGBColor[
              0.9387405372806834, 0.7796548598202627, 0.49465049788910304`], 
             UndirectedEdge[184, 192] -> 
             RGBColor[
              0.25582325613433854`, 0.3862168407014245, 0.9378801280290341], 
             UndirectedEdge[170, 171] -> 
             RGBColor[
              0.2792113970027737, 0.4107992596479288, 0.9392120480518376], 
             UndirectedEdge[80, 156] -> 
             RGBColor[
              0.6284260394446897, 0.7069689251123001, 0.9654326763878454], 
             UndirectedEdge[353, 418] -> 
             RGBColor[
              0.809068015481273, 0.8509060188194038, 0.9430493347226458], 
             UndirectedEdge[201, 312] -> 
             RGBColor[
              0.30443515610797417`, 0.4373110297461917, 0.9406485038176712], 
             UndirectedEdge[152, 212] -> 
             RGBColor[
              0.21125959360220817`, 0.3393776058807578, 0.93534229337386], 
             UndirectedEdge[192, 260] -> 
             RGBColor[
              0.27009553441077905`, 0.4012179100846716, 0.9386929131629338], 
             UndirectedEdge[90, 357] -> 
             RGBColor[
              0.8859560304571115, 0.5741950476247133, 0.2265078159100875], 
             UndirectedEdge[57, 369] -> 
             RGBColor[
              0.5105952058083258, 0.6126571266031253, 0.9548654266501568], 
             UndirectedEdge[83, 448] -> 
             RGBColor[
              0.7443425082604527, 0.7998796964136958, 0.9757160754212024], 
             UndirectedEdge[67, 180] -> 
             RGBColor[
              0.26337700695553745`, 0.3941563117499686, 0.9383103029635284], 
             UndirectedEdge[373, 472] -> 
             RGBColor[
              0.31103110428016545`, 0.44242232361832246`, 0.9410908260962028],
              UndirectedEdge[353, 432] -> 
             RGBColor[
              0.7691435045990516, 0.820174333900838, 0.9774842614710615], 
             UndirectedEdge[1, 433] -> 
             RGBColor[
              0.2958358704615542, 0.4267230355457211, 0.940215525659722], 
             UndirectedEdge[300, 301] -> 
             RGBColor[
              0.2173551636481656, 0.3457844364805221, 0.9356894270703895], 
             UndirectedEdge[212, 389] -> 
             RGBColor[
              0.21850801717300872`, 0.34699615863026745`, 0.9357550803731354],
              UndirectedEdge[97, 174] -> 
             RGBColor[
              0.24919580773922206`, 0.37925097223365895`, 0.9375027046473634],
              UndirectedEdge[200, 471] -> 
             RGBColor[
              0.8788202951923778, 0.5401284768128874, 0.22049894846562806`], 
             UndirectedEdge[155, 387] -> 
             RGBColor[
              0.6705014636086952, 0.7413486854414358, 0.9685938847155504], 
             UndirectedEdge[156, 354] -> 
             RGBColor[
              0.4145365045344412, 0.533092524898237, 0.9477398429544205], 
             UndirectedEdge[314, 472] -> 
             RGBColor[
              0.3292610947634469, 0.4596111439654538, 0.9422012036975409], 
             UndirectedEdge[117, 269] -> 
             RGBColor[
              0.41500730712434825`, 0.5338802033825223, 0.947664876526779], 
             UndirectedEdge[336, 409] -> 
             RGBColor[
              0.23189710424361965`, 0.36106893805863094`, 0.9365175690744273],
              UndirectedEdge[63, 252] -> 
             RGBColor[
              0.5775658026497799, 0.6655789256820774, 0.9611207995905398], 
             UndirectedEdge[201, 444] -> 
             RGBColor[
              0.2878759109078417, 0.4199062131240665, 0.9397054793007316], 
             UndirectedEdge[201, 442] -> 
             RGBColor[
              0.2942020501296223, 0.426555386546551, 0.9400657435707277], 
             UndirectedEdge[25, 333] -> 
             RGBColor[
              0.34601220845973285`, 0.4741201167137219, 0.94326856984984], 
             UndirectedEdge[203, 397] -> 
             RGBColor[
              0.44655734447149653`, 0.5590011690338403, 0.950284766509865], 
             UndirectedEdge[7, 436] -> 
             RGBColor[
              0.6558009604167452, 0.7285914992480711, 0.9680622843636464], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.24125115959042637`, 0.3709006433094886, 0.9370502686883432], 
             UndirectedEdge[274, 369] -> 
             RGBColor[
              0.4413408424038283, 0.5564333145178368, 0.9494134694758627], 
             UndirectedEdge[38, 364] -> 
             RGBColor[
              0.2592676752099878, 0.3898371435387148, 0.9380762825998308], 
             UndirectedEdge[215, 356] -> 
             RGBColor[
              0.2767305167100354, 0.40819169716336523`, 0.9390707655892996], 
             UndirectedEdge[16, 283] -> 
             RGBColor[
              0.29254812031783006`, 0.4160210207001029, 0.9402936186581154], 
             UndirectedEdge[236, 276] -> 
             RGBColor[
              0.45343165662521556`, 0.5606674341824253, 0.9514328089086481], 
             UndirectedEdge[39, 454] -> 
             RGBColor[
              0.761772006870989, 0.6718134516549312, 0.6008439261608904], 
             UndirectedEdge[179, 315] -> 
             RGBColor[
              0.18221437666537932`, 0.3088492413070327, 0.9336882112378554], 
             UndirectedEdge[149, 182] -> 
             RGBColor[
              0.36623071660169665`, 0.4916323722545241, 0.9445568753101211], 
             UndirectedEdge[97, 407] -> 
             RGBColor[
              0.2230464248259349, 0.3517663128251578, 0.936013535974997], 
             UndirectedEdge[274, 379] -> 
             RGBColor[
              0.386016730119334, 0.5085143491277428, 0.9458882659622865], 
             UndirectedEdge[39, 325] -> 
             RGBColor[
              0.40133925395865816`, 0.5054220551360133, 0.9485110960164554], 
             UndirectedEdge[127, 347] -> 
             RGBColor[
              0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993],
              UndirectedEdge[327, 483] -> 
             RGBColor[
              0.27685916583525294`, 0.4083269155507945, 0.9390780919666615], 
             UndirectedEdge[269, 360] -> 
             RGBColor[
              0.5141528316673345, 0.616332566062272, 0.9549279906939228], 
             UndirectedEdge[54, 147] -> 
             RGBColor[
              0.2401069833110282, 0.36969804149487495`, 0.9369851095418886], 
             UndirectedEdge[276, 422] -> 
             RGBColor[
              0.4267760803352025, 0.5326507334404715, 0.9499148132723232], 
             UndirectedEdge[181, 424] -> 
             RGBColor[
              0.3706458143967508, 0.4954565080553325, 0.9448382014375043], 
             UndirectedEdge[336, 456] -> 
             RGBColor[
              0.22294853768143919`, 0.3516634272298894, 0.936007961446929], 
             UndirectedEdge[46, 298] -> 
             RGBColor[
              0.9096473304128414, 0.8178215341712867, 0.6215408826637097], 
             UndirectedEdge[107, 132] -> 
             RGBColor[
              0.5874023021726906, 0.6508098778838103, 0.8735074338464627], 
             UndirectedEdge[78, 95] -> 
             RGBColor[
              0.22325600943798377`, 0.3519865995408531, 0.9360254715086005], 
             UndirectedEdge[296, 332] -> 
             RGBColor[
              0.3578059368755654, 0.48433525149749035`, 0.9440200557957121], 
             UndirectedEdge[397, 472] -> 
             RGBColor[
              0.3434973849835166, 0.4719419030173265, 0.9431083275217065], 
             UndirectedEdge[19, 269] -> 
             RGBColor[
              0.5043319337096805, 0.6083595186738375, 0.9541548536315616], 
             UndirectedEdge[185, 335] -> 
             RGBColor[
              0.28035846079175497`, 0.4120048964181928, 0.9392773716376912], 
             UndirectedEdge[112, 351] -> 
             RGBColor[
              0.26915448795361524`, 0.4002288105924009, 0.9386393219593516], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.2633838374698597, 0.39416349105360093`, 0.9383106919512142], 
             UndirectedEdge[251, 305] -> 
             RGBColor[
              0.25482853774731307`, 0.38517132860787223`, 0.9378234802884469],
              UndirectedEdge[131, 170] -> 
             RGBColor[
              0.28014480934839103`, 0.4117803352049335, 0.9392652045040607], 
             UndirectedEdge[76, 333] -> 
             RGBColor[
              0.3949872182942583, 0.5165398086768207, 0.9463892141695951], 
             UndirectedEdge[114, 115] -> 
             RGBColor[
              0.7109234320173796, 0.7727455262693818, 0.9730887236423327], 
             UndirectedEdge[87, 421] -> 
             RGBColor[
              0.17915493384170816`, 0.30563357291947557`, 0.9335139804950874],
              UndirectedEdge[60, 192] -> 
             RGBColor[
              0.2736621188386635, 0.4049666164528918, 0.9388960248698129], 
             UndirectedEdge[84, 147] -> 
             RGBColor[
              0.24240373141068797`, 0.37211206936985763`, 0.93711590594843], 
             UndirectedEdge[431, 433] -> 
             RGBColor[
              0.3870230907643596, 0.509641681699111, 0.9458817470057914], 
             UndirectedEdge[201, 492] -> 
             RGBColor[
              0.29053904388296076`, 0.4227053347332997, 0.9398571407839125], 
             UndirectedEdge[86, 124] -> 
             RGBColor[
              0.9389228207101663, 0.7935781606519255, 0.2800166062249653], 
             UndirectedEdge[234, 239] -> 
             RGBColor[
              0.36975457999068184`, 0.4946845656075394, 0.9447814127692372], 
             UndirectedEdge[100, 450] -> 
             RGBColor[
              0.8744616680202064, 0.45105879141128646`, 0.21405151473609035`],
              UndirectedEdge[22, 275] -> 
             RGBColor[
              0.43256024452096153`, 0.549083675519183, 0.9487833341762382], 
             UndirectedEdge[160, 324] -> 
             RGBColor[
              0.3960795993510239, 0.5174859742435227, 0.9464588197245776], 
             UndirectedEdge[191, 218] -> 
             RGBColor[
              0.2251871593264507, 0.3540163605156067, 0.9361354476378685], 
             UndirectedEdge[349, 397] -> 
             RGBColor[
              0.38607476166702576`, 0.5088202866994067, 0.9458213203142838], 
             UndirectedEdge[401, 454] -> 
             RGBColor[
              0.8366674019364873, 0.7306087240183134, 0.6081129719353302], 
             UndirectedEdge[311, 349] -> 
             RGBColor[
              0.5802291691633081, 0.667416033439714, 0.9614893343765445], 
             UndirectedEdge[63, 324] -> 
             RGBColor[
              0.3945065223315428, 0.5161234539943981, 0.9463585846479137], 
             UndirectedEdge[22, 353] -> 
             RGBColor[
              0.5455395337034719, 0.641880966146923, 0.9573802823215901], 
             UndirectedEdge[93, 437] -> 
             RGBColor[
              0.26255787085876586`, 0.3932953477760335, 0.9382636543746206], 
             UndirectedEdge[417, 461] -> 
             RGBColor[
              0.8227440842305245, 0.8622334494485463, 0.9748712810946092], 
             UndirectedEdge[151, 249] -> 
             RGBColor[
              0.29817109629594896`, 0.43072710571942197`, 0.9402917748782225],
              UndirectedEdge[148, 452] -> 
             RGBColor[
              0.23180463347080354`, 0.3609717454134156, 0.9365123030007138], 
             UndirectedEdge[262, 424] -> 
             RGBColor[
              0.39834012297090404`, 0.5188257266580119, 0.9467736686621999], 
             UndirectedEdge[50, 139] -> 
             RGBColor[
              0.50248660335272, 0.6066441419253559, 0.9540696105134843], 
             UndirectedEdge[237, 267] -> 
             RGBColor[
              0.9475774996267206, 0.9513626199375382, 0.7014579081154306], 
             UndirectedEdge[256, 442] -> 
             RGBColor[
              0.28666573187167776`, 0.4186342382272755, 0.9396365613949216], 
             UndirectedEdge[60, 133] -> 
             RGBColor[
              0.31894163191943015`, 0.44919026900604586`, 0.9415979446419711],
              UndirectedEdge[77, 156] -> 
             RGBColor[
              0.5370635204917655, 0.6350513862279201, 0.9566987541430614], 
             UndirectedEdge[219, 498] -> 
             RGBColor[
              0.49407920545967077`, 0.6001547828635406, 0.9533148714070008], 
             UndirectedEdge[102, 185] -> 
             RGBColor[
              0.28024115314486164`, 0.4118815986435736, 0.9392706911407418], 
             UndirectedEdge[92, 169] -> 
             RGBColor[
              0.5509398864490034, 0.6463168452351683, 0.9577911525020184], 
             UndirectedEdge[53, 357] -> 
             RGBColor[
              0.9418272950686917, 0.8009948820936315, 0.3036989405074137], 
             UndirectedEdge[162, 289] -> 
             RGBColor[
              0.45070123455015054`, 0.5645598995943251, 0.9500046324572284], 
             UndirectedEdge[169, 204] -> 
             RGBColor[
              0.4973176178268257, 0.6027838719120118, 0.9535698110912385], 
             UndirectedEdge[176, 448] -> 
             RGBColor[
              0.587441960125221, 0.6759508730452015, 0.9606647294533119], 
             UndirectedEdge[377, 403] -> 
             RGBColor[
              0.9550085431684978, 0.9657910070072111, 0.9549749729457403], 
             UndirectedEdge[86, 357] -> 
             RGBColor[
              0.911167687629582, 0.6855165136042474, 0.2473816401856394], 
             UndirectedEdge[12, 373] -> 
             RGBColor[
              0.28300945147034123`, 0.414791255703904, 0.9394283416350475], 
             UndirectedEdge[200, 469] -> 
             RGBColor[
              0.8806293426662699, 0.5508475494204266, 0.22210653628922422`], 
             UndirectedEdge[112, 153] -> 
             RGBColor[
              0.24659824483285725`, 0.37652076892406894`, 0.9373547772825959],
              UndirectedEdge[166, 243] -> 
             RGBColor[
              0.838713260625803, 0.29857266219470613`, 0.18470516813663024`], 
             UndirectedEdge[394, 460] -> 
             RGBColor[
              0.23849436642390026`, 0.3680030789006874, 0.9368932733958195], 
             UndirectedEdge[18, 348] -> 
             RGBColor[
              0.9221477650002106, 0.7221653986171828, 0.2620020254952798], 
             UndirectedEdge[315, 325] -> 
             RGBColor[
              0.1822582683189515, 0.30889537421782864`, 0.9336907108025945], 
             UndirectedEdge[195, 447] -> 
             RGBColor[
              0.25832593618087096`, 0.38884731610940987`, 0.9380226519553008],
              UndirectedEdge[128, 204] -> 
             RGBColor[
              0.4983181319181479, 0.6035961343239933, 0.9536485752255113], 
             UndirectedEdge[91, 435] -> 
             RGBColor[
              0.29287326479962417`, 0.4234129007814571, 0.9400539952643586], 
             UndirectedEdge[158, 206] -> 
             RGBColor[
              0.3501277440364893, 0.4776847867774757, 0.9435308081375656], 
             UndirectedEdge[30, 290] -> 
             RGBColor[
              0.2772082322816696, 0.40869380651806936`, 0.9390979707843874], 
             UndirectedEdge[2, 250] -> 
             RGBColor[
              0.20844651025640323`, 0.33642087692453115`, 0.9351820924389003],
              UndirectedEdge[148, 195] -> 
             RGBColor[
              0.2549038837878154, 0.3852505220736551, 0.9378277711339891], 
             UndirectedEdge[5, 202] -> 
             RGBColor[
              0.23883220085490312`, 0.3683581643076115, 0.9369125125668838], 
             UndirectedEdge[220, 359] -> 
             RGBColor[
              0.3621822341604067, 0.48812578024652276`, 0.9442989095888945], 
             UndirectedEdge[175, 337] -> 
             RGBColor[
              0.9079704822927377, 0.9289384814961321, 0.9731750764283525], 
             UndirectedEdge[263, 447] -> 
             RGBColor[
              0.2599502995006695, 0.3905546249491011, 0.938115157043333], 
             UndirectedEdge[344, 387] -> 
             RGBColor[
              0.6194283934274943, 0.6998852662527452, 0.9645732255440658], 
             UndirectedEdge[82, 470] -> 
             RGBColor[
              0.25688036525862096`, 0.38732792941563493`, 0.937940328829809], 
             UndirectedEdge[273, 446] -> 
             RGBColor[
              0.26084634450324296`, 0.39149642505934035`, 0.9381661854806498],
              UndirectedEdge[68, 306] -> 
             RGBColor[
              0.8387829864974263, 0.2991086057980758, 0.18477193771004097`], 
             UndirectedEdge[21, 33] -> 
             RGBColor[
              0.9296510090196749, 0.7439907144053559, 0.3002556094938443], 
             UndirectedEdge[77, 479] -> 
             RGBColor[
              0.5091542746403608, 0.6112576931750507, 0.9548154361242309], 
             UndirectedEdge[253, 311] -> 
             RGBColor[
              0.8659443575362178, 0.8951239135712197, 0.9365639679939195], 
             UndirectedEdge[308, 386] -> 
             RGBColor[
              0.17893664238380538`, 0.3054041347567419, 0.9335015491194931], 
             UndirectedEdge[151, 280] -> 
             RGBColor[
              0.2818433506476452, 0.4135656098041881, 0.9393619339182866], 
             UndirectedEdge[305, 416] -> 
             RGBColor[
              0.2563227786802443, 0.3867418705687301, 0.9379085750990459], 
             UndirectedEdge[38, 189] -> 
             RGBColor[
              0.2598720197723208, 0.3904723479913851, 0.9381106991286081], 
             UndirectedEdge[277, 291] -> 
             RGBColor[
              0.7131143362098424, 0.7758096064076011, 0.9720402306671867], 
             UndirectedEdge[27, 40] -> 
             RGBColor[
              0.44915953688308596`, 0.5618645655130168, 0.9502821669769903], 
             UndirectedEdge[88, 167] -> 
             RGBColor[
              0.9266401906833595, 0.7379726928092079, 0.5404902319838795], 
             UndirectedEdge[89, 296] -> 
             RGBColor[
              0.2994607686458766, 0.4316505064958615, 0.9403810420835206], 
             UndirectedEdge[169, 340] -> 
             RGBColor[
              0.41508837309382146`, 0.5328799596159772, 0.9479658129994224], 
             UndirectedEdge[169, 363] -> 
             RGBColor[
              0.44877677089386697`, 0.5620591565622703, 0.9501124079177607], 
             UndirectedEdge[43, 378] -> 
             RGBColor[
              0.2881161193118442, 0.42015868738676554`, 0.939719158813983], 
             UndirectedEdge[350, 482] -> 
             RGBColor[
              0.36032571563534044`, 0.4865177572114446, 0.9441806138701323], 
             UndirectedEdge[199, 429] -> 
             RGBColor[
              0.318220922727511, 0.44864816272084596`, 0.9415490142958283], 
             UndirectedEdge[135, 216] -> 
             RGBColor[
              0.25825637493020664`, 0.38877420282452363`, 0.938018690544982], 
             UndirectedEdge[153, 351] -> 
             RGBColor[
              0.267489207183899, 0.39847849491853005`, 0.9385444866830785], 
             UndirectedEdge[207, 218] -> 
             RGBColor[
              0.22451796602725682`, 0.35331299592884813`, 0.9360973380694622],
              UndirectedEdge[218, 389] -> 
             RGBColor[
              0.22523636007401557`, 0.35406807362080495`, 0.9361382495476563],
              UndirectedEdge[421, 477] -> 
             RGBColor[
              0.21186411660990806`, 0.34001299789082284`, 0.9353767200648369],
              UndirectedEdge[171, 391] -> 
             RGBColor[
              0.25143472628896596`, 0.3816042175850748, 0.9376302077465881], 
             UndirectedEdge[25, 246] -> 
             RGBColor[
              0.3037983452782409, 0.43621369244109887`, 0.940627909879872], 
             UndirectedEdge[130, 254] -> 
             RGBColor[
              0.20771262472504887`, 0.3356495167000475, 0.935140298743576], 
             UndirectedEdge[65, 434] -> 
             RGBColor[
              0.9883337030612244, 0.9766308233101144, 0.5967468015081936], 
             UndirectedEdge[174, 430] -> 
             RGBColor[
              0.2531980668507343, 0.38345760031774234`, 0.9377306273829522], 
             UndirectedEdge[213, 454] -> 
             RGBColor[
              0.902044161930851, 0.6480872421427781, 0.23997558640884487`], 
             UndirectedEdge[52, 495] -> 
             RGBColor[
              0.8389987580384334, 0.3007671204139477, 0.18497856078138836`], 
             UndirectedEdge[26, 224] -> 
             RGBColor[
              0.34279791451999597`, 0.4704318560417961, 0.9430968651035153], 
             UndirectedEdge[8, 31] -> 
             RGBColor[
              0.5366659458722182, 0.6347210217205881, 0.9566695542776334], 
             UndirectedEdge[29, 321] -> 
             RGBColor[
              0.3713978817482214, 0.49610791099517215`, 0.944886122504113], 
             UndirectedEdge[319, 377] -> 
             RGBColor[
              0.8479973976544979, 0.8813126625416667, 0.9445427395689829], 
             UndirectedEdge[323, 447] -> 
             RGBColor[
              0.24292230663621342`, 0.3726571248114532, 0.9371454380403603], 
             UndirectedEdge[13, 340] -> 
             RGBColor[
              0.3170254114231826, 0.44789173278801986`, 0.9414626195505558], 
             UndirectedEdge[176, 237] -> 
             RGBColor[
              0.7565184993634433, 0.8098707472801487, 0.9765525722729846], 
             UndirectedEdge[22, 268] -> 
             RGBColor[
              0.4305356531895016, 0.5473300762667914, 0.9486543290068734], 
             UndirectedEdge[461, 493] -> 
             RGBColor[
              0.9690163833229786, 0.9733831615410689, 0.7606045943611018], 
             UndirectedEdge[401, 450] -> 
             RGBColor[
              0.7955804305647025, 0.4800334417304184, 0.5713225662708019], 
             UndirectedEdge[100, 200] -> 
             RGBColor[
              0.9160214299715226, 0.703780905297789, 0.25123642844933736`], 
             UndirectedEdge[197, 375] -> 
             RGBColor[
              0.8279135305907634, 0.8660284937370616, 0.9630673509377192], 
             UndirectedEdge[94, 401] -> 
             RGBColor[
              0.8644357283380311, 0.8946091728083778, 0.9692011064141851], 
             UndirectedEdge[118, 327] -> 
             RGBColor[
              0.2910886324434072, 0.42177019876942656`, 0.9399438296328053], 
             UndirectedEdge[44, 255] -> 
             RGBColor[
              0.44713138767076954`, 0.5605271620680575, 0.9500370874897843], 
             UndirectedEdge[148, 356] -> 
             RGBColor[
              0.2544968866209464, 0.384822742246165, 0.9378045932474341], 
             UndirectedEdge[26, 34] -> 
             RGBColor[
              0.46519130263863967`, 0.5748915338435057, 0.9515410249790447], 
             UndirectedEdge[244, 313] -> 
             RGBColor[
              0.3046994618698019, 0.43447349621750786`, 0.9407776233385161], 
             UndirectedEdge[331, 488] -> 
             RGBColor[
              0.8030279977952235, 0.8461858842867422, 0.9809661481473407], 
             UndirectedEdge[382, 429] -> 
             RGBColor[
              0.2879113316712099, 0.41994344259217253`, 0.9397074964608051], 
             UndirectedEdge[409, 496] -> 
             RGBColor[
              0.25922260246551676`, 0.38978976922649866`, 0.9380737157737123],
              UndirectedEdge[14, 324] -> 
             RGBColor[
              0.33821006500838097`, 0.4671770715883025, 0.9427782060023248], 
             UndirectedEdge[259, 471] -> 
             RGBColor[
              0.8593266411159032, 0.451612346510198, 0.20423296567103144`], 
             UndirectedEdge[178, 439] -> 
             RGBColor[
              0.9262985601874452, 0.9413808299607197, 0.8870332114673454], 
             UndirectedEdge[127, 454] -> 
             RGBColor[
              0.562931118749189, 0.49656039652436856`, 0.5871761845581333], 
             UndirectedEdge[190, 452] -> 
             RGBColor[
              0.2360315215156537, 0.3654144727487341, 0.9367530180217474], 
             UndirectedEdge[218, 295] -> 
             RGBColor[
              0.2307804101674582, 0.3598952217820915, 0.9364539749987908], 
             UndirectedEdge[35, 67] -> 
             RGBColor[
              0.24749774961125026`, 0.377466205478057, 0.9374060027490273], 
             UndirectedEdge[192, 249] -> 
             RGBColor[
              0.27208125411189216`, 0.40330502739244223`, 0.938805996962303], 
             UndirectedEdge[186, 202] -> 
             RGBColor[
              0.2373837352876954, 0.3668357351584549, 0.9368300245956442], 
             UndirectedEdge[243, 469] -> 
             RGBColor[
              0.8498683936659192, 0.3811298439450528, 0.19526257805333647`], 
             UndirectedEdge[48, 183] -> 
             RGBColor[
              0.20623910902756293`, 0.3341007582756985, 0.9350563842044752], 
             UndirectedEdge[255, 390] -> 
             RGBColor[
              0.3491694965791283, 0.4761158367358585, 0.9434968065582812], 
             UndirectedEdge[202, 497] -> 
             RGBColor[
              0.23752535161991525`, 0.36698458290261204`, 0.9368380894362616],
              UndirectedEdge[84, 365] -> 
             RGBColor[
              0.22514447908377305`, 0.3539715008744688, 0.9361330170611878], 
             UndirectedEdge[239, 262] -> 
             RGBColor[
              0.41350816527111056`, 0.531963522530478, 0.947740162904996], 
             UndirectedEdge[299, 456] -> 
             RGBColor[
              0.21641245264037934`, 0.34479358744000865`, 0.935635741073112], 
             UndirectedEdge[136, 253] -> 
             RGBColor[
              0.9769962544035893, 0.9822248956493935, 0.9175751236598007], 
             UndirectedEdge[338, 478] -> 
             RGBColor[
              0.29307363534810826`, 0.42431910359583813`, 0.9400399367228911],
              UndirectedEdge[284, 444] -> 
             RGBColor[
              0.25819284063858217`, 0.3887074242557196, 0.9380150723610645], 
             UndirectedEdge[135, 147] -> 
             RGBColor[
              0.2510599689447852, 0.3812103238553528, 0.9376088658702408], 
             UndirectedEdge[72, 73] -> 
             RGBColor[
              0.2509474629421924, 0.38109207291333524`, 0.9376024588198308], 
             UndirectedEdge[8, 291] -> 
             RGBColor[
              0.637610384777719, 0.7164873323549865, 0.9647458039813404], 
             UndirectedEdge[141, 240] -> 
             RGBColor[
              0.2831042170303842, 0.4148134850118461, 0.939436571482416], 
             UndirectedEdge[9, 466] -> 
             RGBColor[
              0.5393259259475076, 0.6368881088970959, 0.9568768589880016], 
             UndirectedEdge[78, 346] -> 
             RGBColor[
              0.21865587786091514`, 0.34715156958816623`, 0.9357635008205714],
              UndirectedEdge[255, 425] -> 
             RGBColor[
              0.38646418769848023`, 0.5091575879547311, 0.9458461341966522], 
             UndirectedEdge[297, 349] -> 
             RGBColor[
              0.4664828396818328, 0.5766724130185215, 0.9514403486819383], 
             UndirectedEdge[248, 478] -> 
             RGBColor[
              0.25429079969208646`, 0.3846061318172672, 0.9377928569017139], 
             UndirectedEdge[113, 130] -> 
             RGBColor[
              0.17905963034776856`, 0.3055334029047545, 0.9335085531020964], 
             UndirectedEdge[51, 179] -> 
             RGBColor[
              0.1789280689363169, 0.30539512351984355`, 0.9335010608743419], 
             UndirectedEdge[440, 470] -> 
             RGBColor[
              0.2685779731534025, 0.3996228569842277, 0.9386064902943567], 
             UndirectedEdge[5, 414] -> 
             RGBColor[
              0.2566326545868817, 0.38706756979387325`, 0.9379262220735086], 
             UndirectedEdge[148, 463] -> 
             RGBColor[
              0.25337660171868737`, 0.3836452517837254, 0.9377407946795635], 
             UndirectedEdge[63, 441] -> 
             RGBColor[
              0.4347339982883702, 0.5509664717764713, 0.9489218438441225], 
             UndirectedEdge[163, 187] -> 
             RGBColor[
              0.2658102034815037, 0.3967137555723293, 0.9384488699060904], 
             UndirectedEdge[120, 177] -> 
             RGBColor[
              0.20805903153131503`, 0.3360136122168933, 0.9351600260987298], 
             UndirectedEdge[450, 454] -> 
             RGBColor[
              0.8587954548220276, 0.3876960227591984, 0.20138137545633958`], 
             UndirectedEdge[15, 190] -> 
             RGBColor[
              0.24117420601353035`, 0.37081976022103225`, 0.9370458862959816],
              UndirectedEdge[191, 287] -> 
             RGBColor[
              0.21410654860741013`, 0.342369936098598, 0.9355044232497137], 
             UndirectedEdge[179, 292] -> 
             RGBColor[
              0.17894988462017136`, 0.30541805318676885`, 0.9335023032452641],
              UndirectedEdge[291, 297] -> 
             RGBColor[
              0.5871456749634538, 0.6755178075184964, 0.9607730371664382], 
             UndirectedEdge[289, 397] -> 
             RGBColor[
              0.39895955278042317`, 0.5199804451534001, 0.9466423278104561], 
             UndirectedEdge[175, 370] -> 
             RGBColor[
              0.7735868010178651, 0.822851827878325, 0.9604005134157099], 
             UndirectedEdge[23, 186] -> 
             RGBColor[
              0.22910595895914918`, 0.35813526739582024`, 0.9363586174796061],
              UndirectedEdge[241, 461] -> 
             RGBColor[
              0.8249688230204753, 0.8639714322998968, 0.9750930222658254], 
             UndirectedEdge[157, 216] -> 
             RGBColor[
              0.28421479544229167`, 0.41605814864164575`, 0.9394969841911034],
              UndirectedEdge[51, 302] -> 
             RGBColor[
              0.18453817957609825`, 0.31129170550381263`, 0.9338205483758626],
              UndirectedEdge[174, 390] -> 
             RGBColor[
              0.28370528761633407`, 0.41552262361190234`, 0.9394679684741645],
              UndirectedEdge[79, 406] -> 
             RGBColor[
              0.9922235479450122, 0.984612153776488, 0.4938632532617516], 
             UndirectedEdge[181, 235] -> 
             RGBColor[
              0.38886946031407776`, 0.511240914201845, 0.9459993960408191], 
             UndirectedEdge[78, 404] -> 
             RGBColor[
              0.2164387033219317, 0.3448211785707095, 0.935637236010592], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.2711970471587578, 0.4023756698227392, 0.938755642684389], 
             UndirectedEdge[43, 384] -> 
             RGBColor[
              0.28848430619933074`, 0.4205456751499109, 0.9397401265125418], 
             UndirectedEdge[101, 363] -> 
             RGBColor[
              0.4628220425559936, 0.5734617408298626, 0.9512181031525286], 
             UndirectedEdge[120, 455] -> 
             RGBColor[
              0.2056810719300792, 0.33351422590464763`, 0.9350246048173154], 
             UndirectedEdge[295, 456] -> 
             RGBColor[
              0.22662320577002346`, 0.355525736378405, 0.9362172283583896], 
             UndirectedEdge[58, 240] -> 
             RGBColor[
              0.2858686487739417, 0.41720789684373627`, 0.9396127186286245], 
             UndirectedEdge[39, 471] -> 
             RGBColor[
              0.7402370852900231, 0.5715237918221177, 0.5827765854569318], 
             UndirectedEdge[54, 365] -> 
             RGBColor[
              0.22284773098411328`, 0.35155747299948614`, 0.9360022206546466],
              UndirectedEdge[169, 334] -> 
             RGBColor[
              0.44777313143376407`, 0.5611898545063152, 0.9500484568988465], 
             UndirectedEdge[18, 65] -> 
             RGBColor[
              0.9349243740088637, 0.7652639008938271, 0.3116367388337401], 
             UndirectedEdge[384, 435] -> 
             RGBColor[
              0.2709692417504848, 0.4021362318949472, 0.9387426695033958], 
             UndirectedEdge[9, 360] -> 
             RGBColor[
              0.5772550006439877, 0.6676806404210414, 0.9598627746868871], 
             UndirectedEdge[135, 171] -> 
             RGBColor[
              0.25618449679905386`, 0.3865965275440213, 0.9379007001504819], 
             UndirectedEdge[149, 187] -> 
             RGBColor[
              0.30925143443909986`, 0.4382007802607746, 0.9410755580672832], 
             UndirectedEdge[271, 464] -> 
             RGBColor[
              0.24983604138275278`, 0.37992389838616725`, 0.9375391650062217],
              UndirectedEdge[21, 348] -> 
             RGBColor[
              0.9703996877499586, 0.911813337676092, 0.3395088057688662], 
             UndirectedEdge[1, 70] -> 
             RGBColor[
              0.26220782647507634`, 0.3929274289346799, 0.9382437198648137], 
             UndirectedEdge[52, 276] -> 
             RGBColor[
              0.7276676005214341, 0.4890758052767825, 0.5725511491543327], 
             UndirectedEdge[58, 429] -> 
             RGBColor[
              0.3043548555603097, 0.4366380722694161, 0.9406654807572159], 
             UndirectedEdge[243, 495] -> 
             RGBColor[
              0.8407542903650291, 0.31426091115533294`, 0.1866596605199266], 
             UndirectedEdge[131, 135] -> 
             RGBColor[
              0.25711790914467114`, 0.38757760310102596`, 0.937953856602705], 
             UndirectedEdge[145, 430] -> 
             RGBColor[
              0.23019859628253192`, 0.35928369849990305`, 0.9364208415587607],
              UndirectedEdge[291, 419] -> 
             RGBColor[
              0.583808838050422, 0.6728088129897074, 0.960510349141408], 
             UndirectedEdge[151, 260] -> 
             RGBColor[
              0.2961853765948359, 0.4286399884116514, 0.940178691078853], 
             UndirectedEdge[189, 437] -> 
             RGBColor[
              0.25780291323833093`, 0.38829758583523044`, 0.9379928665724662],
              UndirectedEdge[196, 354] -> 
             RGBColor[
              0.32873158920795986`, 0.45794625952520507`, 0.9422116309155903],
              UndirectedEdge[340, 355] -> 
             RGBColor[
              0.3330706823231735, 0.4629108172342508, 0.9424439472481606], 
             UndirectedEdge[58, 310] -> 
             RGBColor[
              0.3059344073310527, 0.43829828132983367`, 0.9407554338938223], 
             UndirectedEdge[261, 500] -> 
             RGBColor[
              0.8497397394109806, 0.34938235459205963`, 0.19393494909850834`],
              UndirectedEdge[237, 270] -> 
             RGBColor[
              0.9480577404464491, 0.9590498999175098, 0.9029559373872008], 
             UndirectedEdge[23, 497] -> 
             RGBColor[
              0.22924757529136902`, 0.3582841151399774, 0.9363666823202235], 
             UndirectedEdge[431, 462] -> 
             RGBColor[
              0.4562091477173884, 0.5692804281616477, 0.9503694481270373], 
             UndirectedEdge[108, 129] -> 
             RGBColor[
              0.3203552344901264, 0.4497120899906687, 0.9417137426958612], 
             UndirectedEdge[376, 485] -> 
             RGBColor[
              0.26372814560153673`, 0.3945253807303899, 0.938330299789955], 
             UndirectedEdge[124, 261] -> 
             RGBColor[
              0.9213196831594281, 0.7168052052597729, 0.265491517223669], 
             UndirectedEdge[63, 158] -> 
             RGBColor[
              0.38842846253649266`, 0.5108589440920934, 0.9459712960523903], 
             UndirectedEdge[66, 427] -> 
             RGBColor[
              0.271390600085227, 0.40257910622042264`, 0.9387666652372155], 
             UndirectedEdge[66, 208] -> 
             RGBColor[
              0.2926997987840062, 0.4237400438284219, 0.9400254625551399], 
             UndirectedEdge[54, 230] -> 
             RGBColor[
              0.22629940994459397`, 0.3551854064360376, 0.9361987886651444], 
             UndirectedEdge[186, 295] -> 
             RGBColor[
              0.23264914651192115`, 0.36185938216484964`, 0.9365603967690603],
              UndirectedEdge[245, 394] -> 
             RGBColor[
              0.22510267482771082`, 0.3539275619508045, 0.936130636370649], 
             UndirectedEdge[49, 459] -> 
             RGBColor[
              0.44038041665413563`, 0.554855283237734, 0.9495584378871766], 
             UndirectedEdge[55, 365] -> 
             RGBColor[
              0.21422616460620378`, 0.3424956600974225, 0.935511235203889], 
             UndirectedEdge[197, 448] -> 
             RGBColor[
              0.6327824685500147, 0.7119137261765637, 0.9648129350991647], 
             UndirectedEdge[185, 321] -> 
             RGBColor[
              0.30856010126890854`, 0.43938793879419913`, 0.9409661143099544],
              UndirectedEdge[242, 339] -> 
             RGBColor[
              0.21834915626655288`, 0.34682918574521915`, 0.9357460334795263],
              UndirectedEdge[186, 191] -> 
             RGBColor[
              0.22705589567091367`, 0.35598052089836485`, 0.936241869408138], 
             UndirectedEdge[218, 456] -> 
             RGBColor[
              0.2278157330596809, 0.3567791581704322, 0.9362851410233497], 
             UndirectedEdge[63, 182] -> 
             RGBColor[
              0.3989611276124065, 0.5199818091937107, 0.9466424281573576], 
             UndirectedEdge[133, 181] -> 
             RGBColor[
              0.3829354312034995, 0.5061011564392373, 0.9456212849531489], 
             UndirectedEdge[11, 186] -> 
             RGBColor[
              0.23731427099118235`, 0.3667627237785289, 0.936826068706721], 
             UndirectedEdge[105, 148] -> 
             RGBColor[
              0.24278055645410443`, 0.37250813638257607`, 0.9371373655771897],
              UndirectedEdge[235, 393] -> 
             RGBColor[
              0.40912660425444114`, 0.5285723075143651, 0.947349382422311], 
             UndirectedEdge[110, 290] -> 
             RGBColor[
              0.2791002706073135, 0.4106824587604797, 0.9392057195680129], 
             UndirectedEdge[225, 296] -> 
             RGBColor[
              0.29383455667092717`, 0.42573700098774714`, 0.940060637634782], 
             UndirectedEdge[38, 93] -> 
             RGBColor[
              0.2646269773927557, 0.3954701099321881, 0.9383814869307624], 
             UndirectedEdge[80, 486] -> 
             RGBColor[
              0.8622352558727102, 0.8932330485230531, 0.9866566699988166], 
             UndirectedEdge[471, 500] -> 
             RGBColor[
              0.8381526226622067, 0.29426335313338325`, 0.18416830058954048`],
              UndirectedEdge[200, 213] -> 
             RGBColor[
              0.9025169525103827, 0.6502340737413859, 0.24037009445756363`], 
             UndirectedEdge[191, 295] -> 
             RGBColor[
              0.22399463203679326`, 0.35276293872357944`, 0.9360675349729086],
              UndirectedEdge[295, 300] -> 
             RGBColor[
              0.22777276498654234`, 0.3567339960012304, 0.9362826940551499], 
             UndirectedEdge[191, 451] -> 
             RGBColor[
              0.21492359957141377`, 0.343228708465789, 0.9355509530933952], 
             UndirectedEdge[137, 145] -> 
             RGBColor[
              0.2203693542453783, 0.34895254190891456`, 0.9358610807658054], 
             UndirectedEdge[332, 344] -> 
             RGBColor[
              0.4329675168621825, 0.5491533716913533, 0.9488874962659426], 
             UndirectedEdge[76, 392] -> 
             RGBColor[
              0.35866334703698777`, 0.48482413936361163`, 0.9440839805262493],
              UndirectedEdge[157, 465] -> 
             RGBColor[
              0.2925845958094424, 0.42485533950351484`, 0.9399736319400027], 
             UndirectedEdge[204, 337] -> 
             RGBColor[
              0.6810518757467315, 0.7489355468683991, 0.970229432274497], 
             UndirectedEdge[112, 395] -> 
             RGBColor[
              0.2566255492107321, 0.38706010159303317`, 0.9379258174328484], 
             UndirectedEdge[51, 107] -> 
             RGBColor[
              0.18179934664985797`, 0.3084130184462969, 0.9336645758924533], 
             UndirectedEdge[5, 41] -> 
             RGBColor[
              0.23556700835298144`, 0.36492623996293, 0.9367265646843188], 
             UndirectedEdge[88, 210] -> 
             RGBColor[
              0.8513369203215293, 0.3826983248089265, 0.19628825904818903`], 
             UndirectedEdge[248, 411] -> 
             RGBColor[
              0.2410648104835609, 0.37070477858295714`, 0.937039656382386], 
             UndirectedEdge[101, 128] -> 
             RGBColor[
              0.5077879700548952, 0.6112841755347511, 0.9543940755727961], 
             UndirectedEdge[298, 418] -> 
             RGBColor[
              0.9400566522436402, 0.9539366372768199, 0.955901674523727], 
             UndirectedEdge[1, 391] -> 
             RGBColor[
              0.25364635844324135`, 0.38392878320479584`, 0.9377561569259576],
              UndirectedEdge[116, 327] -> 
             RGBColor[
              0.25289755432094124`, 0.38314174259533496`, 0.937713513638949], 
             UndirectedEdge[79, 81] -> 
             RGBColor[
              0.9087234308797807, 0.9257016701540246, 0.7763552620147077], 
             UndirectedEdge[254, 368] -> 
             RGBColor[
              0.32229994971598047`, 0.44690195182710835`, 0.9420022258236223],
              UndirectedEdge[4, 318] -> 
             RGBColor[
              0.33312298494508064`, 0.46295611913654056`, 0.9424472799249791],
              UndirectedEdge[352, 412] -> 
             RGBColor[
              0.23510619043035305`, 0.36444189110870373`, 0.9367003217853442],
              UndirectedEdge[239, 424] -> 
             RGBColor[
              0.3357624743157177, 0.4652423121647933, 0.9426154658536674], 
             UndirectedEdge[58, 188] -> 
             RGBColor[
              0.32619444448890195`, 0.45695496563196736`, 0.9420057994537792],
              UndirectedEdge[407, 408] -> 
             RGBColor[
              0.2184314377890148, 0.3469156688422765, 0.9357507192905059], 
             UndirectedEdge[255, 466] -> 
             RGBColor[
              0.45054684949746193`, 0.5632999878437683, 0.9503059651560305], 
             UndirectedEdge[197, 489] -> 
             RGBColor[
              0.843861608566709, 0.8769414103999965, 0.8921342396544271], 
             UndirectedEdge[50, 363] -> 
             RGBColor[
              0.422874692158388, 0.5406945368727382, 0.9481661793442926], 
             UndirectedEdge[57, 175] -> 
             RGBColor[
              0.7784866261079177, 0.8268297266210345, 0.9607862455954495], 
             UndirectedEdge[278, 486] -> 
             RGBColor[
              0.9416456695144926, 0.9559801240610102, 0.9829731602176706], 
             UndirectedEdge[82, 263] -> 
             RGBColor[
              0.26583963752085393`, 0.39674469261391226`, 0.9384505461310877],
              UndirectedEdge[41, 186] -> 
             RGBColor[
              0.23411854278577374`, 0.36340381081377343`, 0.9366440767130793],
              UndirectedEdge[390, 425] -> 
             RGBColor[
              0.3380481584260487, 0.4664830926023694, 0.94278816472538], 
             UndirectedEdge[218, 458] -> 
             RGBColor[
              0.23123609658963368`, 0.36037417710398584`, 0.936479925666406], 
             UndirectedEdge[230, 374] -> 
             RGBColor[
              0.23780417240741958`, 0.3672776412285381, 0.9368539678676315], 
             UndirectedEdge[104, 408] -> 
             RGBColor[
              0.23453910043567894`, 0.36384584356871885`, 0.9366680268490819],
              UndirectedEdge[121, 213] -> 
             RGBColor[
              0.86583591956703, 0.4350120088827739, 0.20785705715207875`], 
             UndirectedEdge[143, 421] -> 
             RGBColor[
              0.1789918035644768, 0.3054621126550484, 0.9335046904671287], 
             UndirectedEdge[185, 482] -> 
             RGBColor[
              0.32121309396000997`, 0.4503473251053272, 0.9417723518156291], 
             UndirectedEdge[256, 333] -> 
             RGBColor[
              0.3340176365315557, 0.4619410698643276, 0.9425698252260324], 
             UndirectedEdge[351, 463] -> 
             RGBColor[
              0.27857140569147526`, 0.4101265882019613, 0.9391756014934415], 
             UndirectedEdge[42, 411] -> 
             RGBColor[
              0.23603211668449622`, 0.3654150983089235, 0.9367530519157325], 
             UndirectedEdge[52, 243] -> 
             RGBColor[
              0.837550577025578, 0.2896357665521757, 0.18359178100799164`], 
             UndirectedEdge[385, 391] -> 
             RGBColor[
              0.23729940724147955`, 0.36674710103517516`, 0.9368252222381643],
              UndirectedEdge[366, 435] -> 
             RGBColor[
              0.2615619901606841, 0.3922486140198663, 0.9382069404421383], 
             UndirectedEdge[114, 419] -> 
             RGBColor[
              0.5066845097134336, 0.6103883367192307, 0.9543072071326079], 
             UndirectedEdge[67, 391] -> 
             RGBColor[
              0.24887514925956578`, 0.37891393984061833`, 0.9374844436213188],
              UndirectedEdge[310, 327] -> 
             RGBColor[
              0.2769131154519483, 0.40838362001854456`, 0.939081164317521], 
             UndirectedEdge[309, 348] -> 
             RGBColor[
              0.976471187338104, 0.9319682118150352, 0.39079228120582354`], 
             UndirectedEdge[28, 194] -> 
             RGBColor[
              0.9756860818103763, 0.9810011844305191, 0.9087502503850045], 
             UndirectedEdge[92, 337] -> 
             RGBColor[
              0.7346741443689091, 0.7924685201915558, 0.974450773685277], 
             UndirectedEdge[205, 432] -> 
             RGBColor[
              0.9462255159241673, 0.9556033712696023, 0.7798152269955922], 
             UndirectedEdge[314, 398] -> 
             RGBColor[
              0.29561326424229706`, 0.426066606556162, 0.9402183167389095], 
             UndirectedEdge[235, 453] -> 
             RGBColor[
              0.32067427818872773`, 0.4499141070194098, 0.9417367931922191], 
             UndirectedEdge[92, 334] -> 
             RGBColor[
              0.505970833581321, 0.6084373708863062, 0.9546299931971096], 
             UndirectedEdge[35, 54] -> 
             RGBColor[
              0.23354661261843296`, 0.36280267594543125`, 0.936611506136144], 
             UndirectedEdge[191, 456] -> 
             RGBColor[
              0.22102995492901595`, 0.34964687511192016`, 0.9358987009974674],
              UndirectedEdge[78, 137] -> 
             RGBColor[
              0.21975482034818994`, 0.34830662781927, 0.9358260839694819], 
             UndirectedEdge[57, 169] -> 
             RGBColor[
              0.5469925860365322, 0.6431122489364671, 0.9574804065541109], 
             UndirectedEdge[343, 392] -> 
             RGBColor[
              0.29944445035868683`, 0.4320654815746701, 0.9403642905083368], 
             UndirectedEdge[24, 197] -> 
             RGBColor[
              0.7672988184851579, 0.8182762435725834, 0.9774043962108645], 
             UndirectedEdge[450, 471] -> 
             RGBColor[
              0.8372605332410615, 0.2874063629263848, 0.183314034752381], 
             UndirectedEdge[150, 267] -> 
             RGBColor[
              0.9052536312416688, 0.5703031723537458, 0.2900897268509228], 
             UndirectedEdge[40, 371] -> 
             RGBColor[
              0.37457203795785354`, 0.49885720556622565`, 0.9450883769309946],
              UndirectedEdge[217, 362] -> 
             RGBColor[
              0.35409065029754605`, 0.481117256999343, 0.9437833210202597], 
             UndirectedEdge[229, 478] -> 
             RGBColor[
              0.27850887095594073`, 0.41006086022998334`, 0.9391720402327646],
              UndirectedEdge[100, 168] -> 
             RGBColor[
              0.9210035362936968, 0.7245123759551941, 0.25529579489782767`], 
             UndirectedEdge[221, 297] -> 
             RGBColor[
              0.5279871450253872, 0.627682775738259, 0.9559842286184892], 
             UndirectedEdge[50, 338] -> 
             RGBColor[
              0.3805216773222415, 0.5040104841460892, 0.9454674826902338], 
             UndirectedEdge[5, 186] -> 
             RGBColor[
              0.23715887571324926`, 0.36659939348879156`, 0.9368172191755294],
              UndirectedEdge[147, 391] -> 
             RGBColor[
              0.24631019843469731`, 0.37621801389640636`, 0.9373383734663472],
              UndirectedEdge[24, 426] -> 
             RGBColor[
              0.8535732035252862, 0.8860801191364223, 0.9858957682176778], 
             UndirectedEdge[100, 127] -> 
             RGBColor[
              0.5785973319473678, 0.5599231651764567, 0.5998463238378839], 
             UndirectedEdge[418, 432] -> 
             RGBColor[
              0.9385489798096075, 0.9527344602026001, 0.9557578713810538], 
             UndirectedEdge[200, 259] -> 
             RGBColor[
              0.8813343532764009, 0.5540488379416193, 0.22269481442370878`], 
             UndirectedEdge[17, 293] -> 
             RGBColor[
              0.9171217844286204, 0.9362730779745756, 0.9753514321588153], 
             UndirectedEdge[269, 468] -> 
             RGBColor[
              0.4636581822326119, 0.5753387348931303, 0.9509528669224259], 
             UndirectedEdge[154, 390] -> 
             RGBColor[
              0.30514733542854805`, 0.43798605336538, 0.9406917533770347], 
             UndirectedEdge[162, 439] -> 
             RGBColor[
              0.6614719504889517, 0.7330346033014116, 0.9686938737233264], 
             UndirectedEdge[103, 304] -> 
             RGBColor[
              0.4094598762170423, 0.5283411604549934, 0.947514243402197], 
             UndirectedEdge[3, 480] -> 
             RGBColor[
              0.4076066344287682, 0.5272434439758863, 0.9472559414401728], 
             UndirectedEdge[358, 404] -> 
             RGBColor[
              0.21953726017780179`, 0.34807795828608057`, 0.9358136942396298],
              UndirectedEdge[3, 439] -> 
             RGBColor[
              0.6612892589149015, 0.732886286051436, 0.9686794915733958], 
             UndirectedEdge[336, 458] -> 
             RGBColor[
              0.22636890121139194`, 0.35525844616344304`, 0.9362027460899854],
              UndirectedEdge[212, 287] -> 
             RGBColor[
              0.21416398383706822`, 0.3424303041665726, 0.9355076941010749], 
             UndirectedEdge[190, 195] -> 
             RGBColor[
              0.25913077183266553`, 0.38969324940897365`, 0.9380684861550228],
              UndirectedEdge[253, 377] -> 
             RGBColor[
              0.9830684787672088, 0.9867535506374262, 0.9072964317019494], 
             UndirectedEdge[192, 327] -> 
             RGBColor[
              0.25584189976103616`, 0.38623643633515786`, 0.9378811897559938],
              UndirectedEdge[151, 483] -> 
             RGBColor[
              0.3017217477257488, 0.43445906549644486`, 0.9404939792244313], 
             UndirectedEdge[38, 163] -> 
             RGBColor[
              0.2634804930859057, 0.3942650822343853, 0.9383161963455589], 
             UndirectedEdge[88, 227] -> 
             RGBColor[
              0.8561206468687188, 0.41946814329296433`, 0.20086916099222407`],
              UndirectedEdge[281, 343] -> 
             RGBColor[
              0.26889808498261325`, 0.3999593148129905, 0.9386247201894673], 
             UndirectedEdge[76, 157] -> 
             RGBColor[
              0.35693445553108405`, 0.4830069647728541, 0.9439855227126539], 
             UndirectedEdge[364, 437] -> 
             RGBColor[
              0.25719856867599794`, 0.38766238138256004`, 0.9379584500436889],
              UndirectedEdge[229, 244] -> 
             RGBColor[
              0.3167084139494082, 0.447095666264713, 0.9414615153937971], 
             UndirectedEdge[154, 425] -> 
             RGBColor[
              0.3424420265478999, 0.47102780458425264`, 0.9430410810154058], 
             UndirectedEdge[128, 355] -> 
             RGBColor[
              0.4117250076221206, 0.5299124488854325, 0.9477665145867664], 
             UndirectedEdge[58, 382] -> 
             RGBColor[
              0.2986682199237062, 0.43066105766182183`, 0.9403416352703349], 
             UndirectedEdge[45, 179] -> 
             RGBColor[
              0.2308558043838454, 0.3599744658837838, 0.9364582685878783], 
             UndirectedEdge[181, 296] -> 
             RGBColor[
              0.3670585086059648, 0.49234936408258523`, 0.9446096214846453], 
             UndirectedEdge[350, 354] -> 
             RGBColor[
              0.36196691822383753`, 0.4879392844043602, 0.9442851898478128], 
             UndirectedEdge[318, 335] -> 
             RGBColor[
              0.3093572475376726, 0.43941523304457686`, 0.9410411890738053], 
             UndirectedEdge[354, 372] -> 
             RGBColor[
              0.416108457877265, 0.5343687074376324, 0.9478635928798225], 
             UndirectedEdge[44, 57] -> 
             RGBColor[
              0.5489601186307986, 0.6447095805328258, 0.9576352979272409], 
             UndirectedEdge[257, 420] -> 
             RGBColor[
              0.9137481314322007, 0.7140513423503487, 0.5709499365964574], 
             UndirectedEdge[84, 171] -> 
             RGBColor[
              0.2475282592649566, 0.3774982730585261, 0.9374077402286709], 
             UndirectedEdge[376, 497] -> 
             RGBColor[
              0.25772437162935435`, 0.38821503362437043`, 0.9379883937440268],
              UndirectedEdge[164, 443] -> 
             RGBColor[
              0.8760183447320038, 0.45688851313920237`, 0.21528999668843654`],
              UndirectedEdge[2, 54] -> 
             RGBColor[
              0.22058424144202293`, 0.3491784019772233, 0.9358733182737572], 
             UndirectedEdge[165, 324] -> 
             RGBColor[
              0.3968553526992069, 0.5181578928032218, 0.9465082500419522], 
             UndirectedEdge[82, 395] -> 
             RGBColor[
              0.26163309800222595`, 0.39232335286982434`, 0.9382109899285194],
              UndirectedEdge[298, 420] -> 
             RGBColor[
              0.9351413217232607, 0.9502707918228358, 0.9642220469712115], 
             UndirectedEdge[163, 437] -> 
             RGBColor[
              0.26141138655191587`, 0.3920903200782306, 0.9381983637894169], 
             UndirectedEdge[156, 372] -> 
             RGBColor[
              0.46888111877498084`, 0.5796978409320405, 0.951331185719549], 
             UndirectedEdge[272, 317] -> 
             RGBColor[
              0.8519916278011412, 0.36132246904964216`, 0.1958811278335439], 
             UndirectedEdge[282, 441] -> 
             RGBColor[
              0.5288953957407483, 0.628333638126909, 0.9560796286709814], 
             UndirectedEdge[209, 423] -> 
             RGBColor[
              0.37687473184245884`, 0.48661428775252374`, 0.9464892509185017],
              UndirectedEdge[222, 333] -> 
             RGBColor[
              0.41068141899913524`, 0.5301333365139219, 0.9473892347606732], 
             UndirectedEdge[125, 455] -> 
             RGBColor[
              0.20630711262003382`, 0.3341722343630622, 0.9350602569084642], 
             UndirectedEdge[343, 433] -> 
             RGBColor[
              0.3091968798489231, 0.4407663035487692, 0.9409764153784905], 
             UndirectedEdge[29, 77] -> 
             RGBColor[
              0.5082190929851442, 0.6104476858288989, 0.9547558471761093], 
             UndirectedEdge[298, 353] -> 
             RGBColor[
              0.7706511770330843, 0.8213765109750578, 0.9776280646137345], 
             UndirectedEdge[65, 337] -> 
             RGBColor[
              0.9228377639355362, 0.92700213552959, 0.6922814441739551], 
             UndirectedEdge[93, 364] -> 
             RGBColor[
              0.2639259772143767, 0.39473331429873343`, 0.9383415660076406], 
             UndirectedEdge[170, 328] -> 
             RGBColor[
              0.3409967871765409, 0.4686604793300483, 0.9429898367152708], 
             UndirectedEdge[13, 244] -> 
             RGBColor[
              0.3195286449146627, 0.4500599078221664, 0.9416221233751105], 
             UndirectedEdge[114, 291] -> 
             RGBColor[
              0.577802812280651, 0.6679328507014297, 0.9600375327920143], 
             UndirectedEdge[198, 373] -> 
             RGBColor[
              0.28774746699468884`, 0.4197712104275283, 0.9396981646098933], 
             UndirectedEdge[54, 84] -> 
             RGBColor[
              0.23101754524273913`, 0.3601444657814439, 0.9364674794905181], 
             UndirectedEdge[1, 385] -> 
             RGBColor[
              0.2498185382943033, 0.379905501530447, 0.937538168231228], 
             UndirectedEdge[97, 294] -> 
             RGBColor[
              0.23502362506905988`, 0.3643551096790384, 0.936695619810163], 
             UndirectedEdge[83, 489] -> 
             RGBColor[
              0.9554216482771469, 0.9649073806371287, 0.9030373799764648], 
             UndirectedEdge[349, 359] -> 
             RGBColor[
              0.3995263663781553, 0.520471390602876, 0.94667844467169], 
             UndirectedEdge[47, 55] -> 
             RGBColor[
              0.22170565849658444`, 0.35035708240351526`, 0.9359371813160265],
              UndirectedEdge[166, 309] -> 
             RGBColor[
              0.9155755884315661, 0.6407588014939913, 0.33347870741883034`], 
             UndirectedEdge[196, 482] -> 
             RGBColor[
              0.3270903866194627, 0.45652473233228946`, 0.9421070549379097], 
             UndirectedEdge[114, 311] -> 
             RGBColor[
              0.6237676761079407, 0.7038409516692123, 0.9646188808522442], 
             UndirectedEdge[101, 169] -> 
             RGBColor[
              0.506787455963573, 0.6104719131227696, 0.9543153114385234], 
             UndirectedEdge[160, 353] -> 
             RGBColor[
              0.531072144514868, 0.6293500407838779, 0.9564584330755022], 
             UndirectedEdge[80, 329] -> 
             RGBColor[
              0.8360503988309712, 0.8723539542869803, 0.9841591349586778], 
             UndirectedEdge[130, 386] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[216, 238] -> 
             RGBColor[
              0.29301995095784455`, 0.42425818517520597`, 0.9400370439768699],
              UndirectedEdge[240, 382] -> 
             RGBColor[
              0.26942512488484194`, 0.40051326716649266`, 0.9386547343322136],
              UndirectedEdge[424, 470] -> 
             RGBColor[
              0.28803826967359597`, 0.4189813939860375, 0.9397548358601392], 
             UndirectedEdge[184, 225] -> 
             RGBColor[
              0.2656405828545585, 0.396535473538841, 0.9384392102623171], 
             UndirectedEdge[169, 274] -> 
             RGBColor[
              0.4777382226320348, 0.5868884368511786, 0.9520284493798168], 
             UndirectedEdge[345, 375] -> 
             RGBColor[
              0.8089633164388916, 0.8512244424146573, 0.9611785706908804], 
             UndirectedEdge[326, 434] -> 
             RGBColor[
              0.9331890448533395, 0.7583565146768234, 0.5065076494810187], 
             UndirectedEdge[59, 105] -> 
             RGBColor[
              0.2440481876886619, 0.3738404971825583, 0.9372095553007055], 
             UndirectedEdge[90, 306] -> 
             RGBColor[
              0.8611746456929213, 0.4612099603827511, 0.20582221997608346`], 
             UndirectedEdge[44, 466] -> 
             RGBColor[
              0.5000927113166715, 0.6050368178236056, 0.9537882766162615], 
             UndirectedEdge[88, 434] -> 
             RGBColor[
              0.9289063525023188, 0.7389098089590498, 0.5029340660049313], 
             UndirectedEdge[174, 356] -> 
             RGBColor[
              0.2679975194043914, 0.3990127632911238, 0.938573434312055], 
             UndirectedEdge[65, 88] -> 
             RGBColor[
              0.9260374771709088, 0.7249105779401631, 0.30422129427437533`], 
             UndirectedEdge[82, 195] -> 
             RGBColor[
              0.2642152742010554, 0.39503738377422104`, 0.9383580410430554], 
             UndirectedEdge[150, 413] -> 
             RGBColor[
              0.8976403406773998, 0.5446217555948332, 0.26051353065802335`], 
             UndirectedEdge[156, 307] -> 
             RGBColor[
              0.4685593666518582, 0.5794366280637215, 0.9513058562137999], 
             UndirectedEdge[245, 460] -> 
             RGBColor[
              0.23495456172986623`, 0.36428251973067727`, 0.936691686755166], 
             UndirectedEdge[101, 204] -> 
             RGBColor[
              0.5113628894889524, 0.6141864561796039, 0.9546755063260064], 
             UndirectedEdge[210, 428] -> 
             RGBColor[
              0.8331986050247592, 0.2561846027075905, 0.17942432770515804`], 
             UndirectedEdge[25, 76] -> 
             RGBColor[
              0.36235029179287925`, 0.48827134332094824`, 0.9443096180726283],
              UndirectedEdge[130, 421] -> 
             RGBColor[
              0.17899180289058533`, 0.3054621119467458, 0.9335046904287516], 
             UndirectedEdge[79, 493] -> 
             RGBColor[
              0.9937029879453217, 0.9889396528776512, 0.5559872823811043], 
             UndirectedEdge[194, 490] -> 
             RGBColor[
              0.9885348242076832, 0.9895268694153684, 0.8396711640099095], 
             UndirectedEdge[214, 347] -> 
             RGBColor[
              0.1893670574265447, 0.316367162293171, 0.9340955458257609], 
             UndirectedEdge[41, 202] -> 
             RGBColor[
              0.2357918679274276, 0.3651625816325934, 0.9367393701044336], 
             UndirectedEdge[85, 97] -> 
             RGBColor[
              0.22297503114412753`, 0.3516912735389574, 0.9360094702104356], 
             UndirectedEdge[31, 114] -> 
             RGBColor[
              0.47685837337515014`, 0.5861665400670314, 0.9519612830883075], 
             UndirectedEdge[247, 425] -> 
             RGBColor[
              0.4351771155351065, 0.550218204604259, 0.9492628740426365], 
             UndirectedEdge[35, 281] -> 
             RGBColor[
              0.2416405448941051, 0.37130991195210916`, 0.9370724436053437], 
             UndirectedEdge[157, 288] -> 
             RGBColor[
              0.2793047597177943, 0.4108973897809534, 0.9392173649203402], 
             UndirectedEdge[208, 427] -> 
             RGBColor[
              0.3008093263098471, 0.4322636714318231, 0.9404872881507658], 
             UndirectedEdge[154, 313] -> 
             RGBColor[
              0.2882495492104231, 0.42022540866860447`, 0.9397294494499471], 
             UndirectedEdge[189, 364] -> 
             RGBColor[
              0.25917101959394173`, 0.3897355523579304, 0.9380707782054862], 
             UndirectedEdge[314, 373] -> 
             RGBColor[
              0.3118454823562334, 0.44312769697598026`, 0.9411427175470836], 
             UndirectedEdge[156, 232] -> 
             RGBColor[
              0.4117533959329014, 0.5306819361106889, 0.9475625057353367], 
             UndirectedEdge[321, 383] -> 
             RGBColor[
              0.3310589867507921, 0.46116838764021345`, 0.942315763785161], 
             UndirectedEdge[15, 323] -> 
             RGBColor[
              0.2367917298527569, 0.36621349991102203`, 0.936796310761918], 
             UndirectedEdge[225, 235] -> 
             RGBColor[
              0.31564550837904015`, 0.44462855110700683`, 0.9414504121909557],
              UndirectedEdge[170, 265] -> 
             RGBColor[
              0.3088475371272851, 0.4408144148056739, 0.9409413149305978], 
             UndirectedEdge[102, 485] -> 
             RGBColor[
              0.2622693737921402, 0.3929921190672394, 0.9382472248934693], 
             UndirectedEdge[342, 463] -> 
             RGBColor[
              0.2635422521882549, 0.3943299949667075, 0.9383197134350733], 
             UndirectedEdge[70, 147] -> 
             RGBColor[
              0.2548716664665323, 0.3852166596262904, 0.9378259364052033], 
             UndirectedEdge[162, 381] -> 
             RGBColor[
              0.515668109442376, 0.6176816276857418, 0.9550144290112803], 
             UndirectedEdge[212, 299] -> 
             RGBColor[
              0.21384131413680724`, 0.3420911578531577, 0.9354893185389921], 
             UndirectedEdge[92, 361] -> 
             RGBColor[
              0.6266695180780231, 0.7077693478258749, 0.9637721633771799], 
             UndirectedEdge[82, 184] -> 
             RGBColor[
              0.2576552479933815, 0.38814238030027126`, 0.9379844572552174], 
             UndirectedEdge[232, 376] -> 
             RGBColor[
              0.3178263634409366, 0.4469988106247622, 0.9415717511395277], 
             UndirectedEdge[293, 298] -> 
             RGBColor[
              0.9279560632534805, 0.9449120378208546, 0.9763848153450053], 
             UndirectedEdge[225, 249] -> 
             RGBColor[
              0.28189858083211217`, 0.41362366022985875`, 0.9393650791955862],
              UndirectedEdge[19, 34] -> 
             RGBColor[
              0.5517387974757788, 0.6469654371972362, 0.9578540457045537], 
             UndirectedEdge[338, 390] -> 
             RGBColor[
              0.3104293975603457, 0.44256111009978116`, 0.9410283217053288], 
             UndirectedEdge[82, 342] -> 
             RGBColor[
              0.2591328832418887, 0.3896954686339382, 0.9380686063966545], 
             UndirectedEdge[54, 374] -> 
             RGBColor[
              0.24022555960590497`, 0.3698226726989618, 0.9369918622864639], 
             UndirectedEdge[196, 350] -> 
             RGBColor[
              0.3289346637950721, 0.4581221525257362, 0.9422245706487093], 
             UndirectedEdge[19, 44] -> 
             RGBColor[
              0.5282008880554978, 0.6278563019591167, 0.956001055252786], 
             UndirectedEdge[85, 408] -> 
             RGBColor[
              0.21836004410720744`, 0.3468406295560761, 0.9357466535259444], 
             UndirectedEdge[57, 255] -> 
             RGBColor[
              0.499414256811589, 0.6029727505529885, 0.9541529864670097], 
             UndirectedEdge[106, 269] -> 
             RGBColor[
              0.48339733950661234`, 0.5913638720070653, 0.9525068056899508], 
             UndirectedEdge[382, 416] -> 
             RGBColor[
              0.2718791903645599, 0.40309264558241453`, 0.938794489730819], 
             UndirectedEdge[246, 392] -> 
             RGBColor[
              0.3001114005223494, 0.4327664884837622, 0.940402272333493], 
             UndirectedEdge[350, 414] -> 
             RGBColor[
              0.31841398035212815`, 0.44706424717734483`, 0.94162543329059], 
             UndirectedEdge[146, 211] -> 
             RGBColor[
              0.2444868180291041, 0.37430152548113294`, 0.9372345346496982], 
             UndirectedEdge[71, 487] -> 
             RGBColor[
              0.6676064579243342, 0.7392945350984725, 0.9681635028375868], 
             UndirectedEdge[415, 485] -> 
             RGBColor[
              0.2675069384795197, 0.39849713163445644`, 0.9385454964541331], 
             UndirectedEdge[238, 433] -> 
             RGBColor[
              0.32283008594645624`, 0.45404092736007795`, 0.94179142550244], 
             UndirectedEdge[141, 429] -> 
             RGBColor[
              0.30159042381675216`, 0.434243660437526, 0.9404893336110074], 
             UndirectedEdge[406, 493] -> 
             RGBColor[
              0.9920978208950986, 0.9843432363296774, 0.4801786397760631], 
             UndirectedEdge[257, 357] -> 
             RGBColor[
              0.8829978584207956, 0.5607626793064351, 0.22403944465155362`], 
             UndirectedEdge[311, 488] -> 
             RGBColor[
              0.7581105843852092, 0.8109610174663499, 0.9765250361714609], 
             UndirectedEdge[258, 381] -> 
             RGBColor[
              0.4713636222770108, 0.5795438974068458, 0.952126015828245], 
             UndirectedEdge[168, 200] -> 
             RGBColor[
              0.9058101136750496, 0.6632964389017137, 0.24302016366679569`], 
             UndirectedEdge[16, 254] -> 
             RGBColor[
              0.3201901654275895, 0.4450745627173458, 0.941867792234375], 
             UndirectedEdge[325, 347] -> 
             RGBColor[
              0.1789719601845752, 0.3054412560046289, 0.9335035604159989], 
             UndirectedEdge[154, 478] -> 
             RGBColor[
              0.28779157321631055`, 0.419744046861437, 0.9397033683945971], 
             UndirectedEdge[302, 386] -> 
             RGBColor[
              0.18453817917078433`, 0.311291705077802, 0.9338205483527805], 
             UndirectedEdge[330, 414] -> 
             RGBColor[
              0.2905537605670515, 0.4227208029013707, 0.9398579788773], 
             UndirectedEdge[50, 334] -> 
             RGBColor[
              0.42187105269828507`, 0.539825234816783, 0.9481022283253784], 
             UndirectedEdge[72, 187] -> 
             RGBColor[
              0.2593062768219157, 0.38987771628033463`, 0.9380784809045242], 
             UndirectedEdge[14, 149] -> 
             RGBColor[
              0.33030872638618497`, 0.46033332920658265`, 0.9422747396921978],
              UndirectedEdge[113, 214] -> 
             RGBColor[
              0.18949968777431325`, 0.3165065651979255, 0.9341030989278573], 
             UndirectedEdge[63, 149] -> 
             RGBColor[
              0.3866051837093468, 0.5092797116126782, 0.9458551183377868], 
             UndirectedEdge[245, 445] -> 
             RGBColor[
              0.22560109399094413`, 0.3544514320929628, 0.93615902060465], 
             UndirectedEdge[207, 336] -> 
             RGBColor[
              0.2196507706490151, 0.34819726498830533`, 0.9358201584930417], 
             UndirectedEdge[264, 394] -> 
             RGBColor[
              0.23171433520063273`, 0.36087683620622507`, 0.9365071606478118],
              UndirectedEdge[255, 370] -> 
             RGBColor[
              0.4945144317215364, 0.598994851810279, 0.9537672542872702], 
             UndirectedEdge[330, 482] -> 
             RGBColor[
              0.33246549585026375`, 0.4621743129354704, 0.9424131594568423], 
             UndirectedEdge[383, 482] -> 
             RGBColor[
              0.34371197944189347`, 0.47212777395134153`, 0.9431220012908359],
              UndirectedEdge[358, 407] -> 
             RGBColor[
              0.21999227740316346`, 0.34855621023969413`, 0.9358396067974764],
              UndirectedEdge[28, 142] -> 
             RGBColor[
              0.8321901895218196, 0.869251634409216, 0.9575296911592543], 
             UndirectedEdge[348, 375] -> 
             RGBColor[
              0.959056524042907, 0.9223909347161948, 0.6272014222552931], 
             UndirectedEdge[41, 295] -> 
             RGBColor[
              0.23105727915165333`, 0.3601862286389881, 0.9364697422778497], 
             UndirectedEdge[83, 345] -> 
             RGBColor[
              0.7902354483667869, 0.8368716246944006, 0.9795108205407682], 
             UndirectedEdge[140, 425] -> 
             RGBColor[
              0.4374884569477172, 0.5520946556877604, 0.9494448313053598], 
             UndirectedEdge[160, 441] -> 
             RGBColor[
              0.4363070753078513, 0.5523289920255958, 0.9490220789207864], 
             UndirectedEdge[66, 394] -> 
             RGBColor[
              0.24596177604056546`, 0.3758517998689181, 0.937318531326446], 
             UndirectedEdge[201, 271] -> 
             RGBColor[
              0.2801320470703391, 0.4117669212415258, 0.9392644777112058], 
             UndirectedEdge[192, 470] -> 
             RGBColor[
              0.255048373399578, 0.3854023898167881, 0.9378359996036256], 
             UndirectedEdge[255, 379] -> 
             RGBColor[
              0.35344236256380235`, 0.4805557427482631, 0.943742012699124], 
             UndirectedEdge[82, 440] -> 
             RGBColor[
              0.26997623108034263`, 0.40109251472011487`, 0.9386861190147588],
              UndirectedEdge[43, 362] -> 
             RGBColor[
              0.34080467652755875`, 0.4681674552795022, 0.9429895550260083], 
             UndirectedEdge[127, 302] -> 
             RGBColor[
              0.2080645848230672, 0.3360194490786239, 0.9351603423504797], 
             UndirectedEdge[137, 358] -> 
             RGBColor[
              0.22285337720406, 0.3515634075346411, 0.9360025421985196], 
             UndirectedEdge[238, 328] -> 
             RGBColor[
              0.35273346300045894`, 0.47994172957682313`, 0.943696842245803], 
             UndirectedEdge[185, 196] -> 
             RGBColor[
              0.2898220421197416, 0.4219517204196188, 0.9398163085942062], 
             UndirectedEdge[114, 208] -> 
             RGBColor[
              0.41139850447614446`, 0.5294684917353877, 0.9477902381259522], 
             UndirectedEdge[249, 424] -> 
             RGBColor[
              0.30507115038591015`, 0.4368840315616916, 0.9407248332188166], 
             UndirectedEdge[21, 65] -> 
             RGBColor[
              0.9831762967586118, 0.9549118399527363, 0.38914351910732653`], 
             UndirectedEdge[369, 466] -> 
             RGBColor[
              0.46172779849419876`, 0.5729843638939052, 0.9510184053391775], 
             UndirectedEdge[246, 459] -> 
             RGBColor[
              0.3423837632254584, 0.4696344421074833, 0.9430865385917233], 
             UndirectedEdge[46, 317] -> 
             RGBColor[
              0.9005275853462438, 0.6373329329271229, 0.23851003583391922`], 
             UndirectedEdge[66, 305] -> 
             RGBColor[
              0.25719647261268064`, 0.38766017828711546`, 0.9379583306759838],
              UndirectedEdge[56, 243] -> 
             RGBColor[
              0.8379898589381207, 0.2930122798265395, 0.18401243786354038`], 
             UndirectedEdge[281, 288] -> 
             RGBColor[
              0.2504872858476244, 0.38060839761003135`, 0.9375762524150663], 
             UndirectedEdge[81, 329] -> 
             RGBColor[
              0.8530880154845231, 0.8856932433627962, 0.9858494905492173], 
             UndirectedEdge[57, 140] -> 
             RGBColor[
              0.550438526060826, 0.6459098182860178, 0.9577516835757175], 
             UndirectedEdge[184, 440] -> 
             RGBColor[
              0.26935285588816305`, 0.4004373078688641, 0.9386506187197652], 
             UndirectedEdge[422, 446] -> 
             RGBColor[
              0.2310816388212659, 0.36021183219624314`, 0.9364711295249972], 
             UndirectedEdge[232, 307] -> 
             RGBColor[
              0.4130035971526026, 0.5316969057817654, 0.9476609261549895], 
             UndirectedEdge[90, 261] -> 
             RGBColor[
              0.8723782969076955, 0.5133814777114375, 0.21522166145663085`], 
             UndirectedEdge[118, 304] -> 
             RGBColor[
              0.3318360758338559, 0.46184146314633034`, 0.9423652792143808], 
             UndirectedEdge[427, 460] -> 
             RGBColor[
              0.2639231904685617, 0.39473038525219195`, 0.938341407306589], 
             UndirectedEdge[299, 300] -> 
             RGBColor[
              0.21756201185689822`, 0.346001847062834, 0.9357012067698722], 
             UndirectedEdge[106, 425] -> 
             RGBColor[
              0.4465990938801403, 0.559491081179018, 0.9501620540180429], 
             UndirectedEdge[428, 495] -> 
             RGBColor[
              0.8362679836981737, 0.2797771922017657, 0.1823635681891872], 
             UndirectedEdge[230, 365] -> 
             RGBColor[
              0.22042634378562792`, 0.3490124415290624, 0.9358643262358141], 
             UndirectedEdge[224, 463] -> 
             RGBColor[
              0.2830318265857735, 0.4148147733688876, 0.9394296158647704], 
             UndirectedEdge[251, 382] -> 
             RGBColor[
              0.27038494943162866`, 0.40152210362155666`, 0.9387093949202199],
              UndirectedEdge[81, 278] -> 
             RGBColor[
              0.8859909437525565, 0.9116025564457284, 0.9776647627909368], 
             UndirectedEdge[42, 294] -> 
             RGBColor[
              0.23539350574473433`, 0.36474387772096156`, 0.9367166839674533],
              UndirectedEdge[8, 419] -> 
             RGBColor[
              0.5664920822105015, 0.6589428183727875, 0.9590154783219338], 
             UndirectedEdge[159, 164] -> 
             RGBColor[
              0.819137437150352, 0.14810430478184575`, 0.1659593374688081], 
             UndirectedEdge[346, 404] -> 
             RGBColor[
              0.21566548218765702`, 0.3440084741335353, 0.9355932022108733], 
             UndirectedEdge[7, 194] -> 
             RGBColor[
              0.9125990982944516, 0.9314492168831301, 0.9288011319761822], 
             UndirectedEdge[268, 353] -> 
             RGBColor[
              0.5246586597567469, 0.6237950026375101, 0.9560497714979366], 
             UndirectedEdge[51, 423] -> 
             RGBColor[
              0.18337644614132015`, 0.31007065000570677`, 0.9337543893753826],
              UndirectedEdge[14, 322] -> 
             RGBColor[
              0.2829806146027809, 0.4147609463277351, 0.9394266994181002], 
             UndirectedEdge[109, 458] -> 
             RGBColor[
              0.24222963005763265`, 0.3719290778091332, 0.9371059911339332], 
             UndirectedEdge[217, 384] -> 
             RGBColor[
              0.30177027996931804`, 0.4334954768697517, 0.9405338925067932], 
             UndirectedEdge[202, 485] -> 
             RGBColor[
              0.2435291255920976, 0.37329493000863156`, 0.9371799954821897], 
             UndirectedEdge[125, 457] -> 
             RGBColor[
              0.21513132866869134`, 0.3434470449178132, 0.9355627829581774], 
             UndirectedEdge[454, 475] -> 
             RGBColor[
              0.8694429086173421, 0.4695370183739893, 0.21157738923531183`], 
             UndirectedEdge[30, 378] -> 
             RGBColor[
              0.2755078252460146, 0.406906570911563, 0.9390011351192336], 
             UndirectedEdge[445, 460] -> 
             RGBColor[
              0.23899278558713355`, 0.3685269490428458, 0.9369216576298206], 
             UndirectedEdge[173, 461] -> 
             RGBColor[
              0.9645092309315171, 0.9729899937684735, 0.9422009085196323], 
             UndirectedEdge[23, 41] -> 
             RGBColor[
              0.22751409159888136`, 0.35646211386995863`, 0.9362679629883957],
              UndirectedEdge[111, 444] -> 
             RGBColor[
              0.272192144891436, 0.40342158063262434`, 0.9388123120281499], 
             UndirectedEdge[139, 360] -> 
             RGBColor[
              0.5717007512056378, 0.6631714505109032, 0.9594255238252141], 
             UndirectedEdge[53, 432] -> 
             RGBColor[
              0.9375683877182548, 0.9272177056729635, 0.6767239867532486], 
             UndirectedEdge[184, 260] -> 
             RGBColor[
              0.2713041510776424, 0.40248824283226764`, 0.9387617420941234], 
             UndirectedEdge[244, 379] -> 
             RGBColor[
              0.3258701140726008, 0.45667404692668806`, 0.9419851334064466], 
             UndirectedEdge[14, 187] -> 
             RGBColor[
              0.28568538812664784`, 0.41760383479386565`, 0.9395807322689307],
              UndirectedEdge[133, 332] -> 
             RGBColor[
              0.3736828594731001, 0.4980870438541423, 0.9450317192642157], 
             UndirectedEdge[424, 440] -> 
             RGBColor[
              0.30113413549531765`, 0.4327459792905174, 0.940500626045089], 
             UndirectedEdge[381, 419] -> 
             RGBColor[
              0.5409976687744238, 0.6382453050351424, 0.9570084647071322], 
             UndirectedEdge[39, 368] -> 
             RGBColor[
              0.5158816187650146, 0.6166272342584453, 0.9553704626805029], 
             UndirectedEdge[40, 208] -> 
             RGBColor[
              0.3541593410951509, 0.4811767535157284, 0.9437876979371422], 
             UndirectedEdge[436, 462] -> 
             RGBColor[
              0.46839908955768095`, 0.5793065078982675, 0.951293238613832], 
             UndirectedEdge[103, 188] -> 
             RGBColor[
              0.408816425381794, 0.5277838356822806, 0.9474732432839563], 
             UndirectedEdge[313, 411] -> 
             RGBColor[
              0.2532739296678089, 0.38353733694846814`, 0.9377349476581557], 
             UndirectedEdge[181, 344] -> 
             RGBColor[
              0.4422200885925819, 0.5571674842764482, 0.9494770619548758], 
             UndirectedEdge[5, 485] -> 
             RGBColor[
              0.24330426601765148`, 0.37305858833896816`, 0.9371671900620748],
              UndirectedEdge[371, 429] -> 
             RGBColor[
              0.3282709430209225, 0.4573529851702918, 0.9421893927020404], 
             UndirectedEdge[426, 448] -> 
             RGBColor[
              0.7190568535901429, 0.7797176017404024, 0.9733043071059779], 
             UndirectedEdge[32, 403] -> 
             RGBColor[
              0.73231135392298, 0.7900531713799142, 0.9748369526254256], 
             UndirectedEdge[115, 484] -> 
             RGBColor[
              0.9570300393594782, 0.9635915325846716, 0.7300132516870645], 
             UndirectedEdge[36, 251] -> 
             RGBColor[
              0.25646724614478844`, 0.3868937150337323, 0.9379168023074314], 
             UndirectedEdge[243, 454] -> 
             RGBColor[
              0.869594267772993, 0.47070043117032717`, 0.21172233093369885`], 
             UndirectedEdge[106, 139] -> 
             RGBColor[
              0.5409452590449157, 0.6382027564556965, 0.9570043388212421], 
             UndirectedEdge[220, 499] -> 
             RGBColor[
              0.2998159216660946, 0.42966675719263536`, 0.9404875702170554], 
             UndirectedEdge[359, 419] -> 
             RGBColor[
              0.44907089909255904`, 0.561772271120652, 0.9502808074967835], 
             UndirectedEdge[115, 297] -> 
             RGBColor[
              0.7202662947001824, 0.7803304830864486, 0.9738242280167566], 
             UndirectedEdge[155, 235] -> 
             RGBColor[
              0.4614654223098702, 0.5710633178486462, 0.9514696859030422], 
             UndirectedEdge[98, 261] -> 
             RGBColor[
              0.9376107771767181, 0.7700729496416561, 0.47213960027127755`], 
             UndirectedEdge[386, 421] -> 
             RGBColor[
              0.17899180289058533`, 0.3054621119467458, 0.9335046904287516], 
             UndirectedEdge[37, 58] -> 
             RGBColor[
              0.31037597127891847`, 0.44296664665046, 0.9410083743899482], 
             UndirectedEdge[71, 194] -> 
             RGBColor[
              0.8711488139703549, 0.898916809896938, 0.9247098602219754], 
             UndirectedEdge[47, 339] -> 
             RGBColor[
              0.22181216919966315`, 0.3504690319056196, 0.9359432469429985], 
             UndirectedEdge[108, 410] -> 
             RGBColor[
              0.32438785376155105`, 0.4532049421182389, 0.9419706976299311], 
             UndirectedEdge[193, 196] -> 
             RGBColor[
              0.29175552637074975`, 0.4239839349574104, 0.9399264176619675], 
             UndirectedEdge[131, 171] -> 
             RGBColor[
              0.26267563753313167`, 0.39341912801763035`, 0.9382703610125054],
              UndirectedEdge[203, 258] -> 
             RGBColor[
              0.45399453907585874`, 0.5654428931958693, 0.950758657973602], 
             UndirectedEdge[164, 428] -> 
             RGBColor[
              0.8239291026561835, 0.1849351455808791, 0.17054784176860438`], 
             UndirectedEdge[143, 325] -> 
             RGBColor[
              0.17897196085846667`, 0.30544125671293154`, 0.9335035604543761],
              UndirectedEdge[101, 498] -> 
             RGBColor[
              0.491361119566665, 0.5979481182872246, 0.9531008937288266], 
             UndirectedEdge[35, 391] -> 
             RGBColor[
              0.23974982774210207`, 0.3693226483469626, 0.9369647700606025], 
             UndirectedEdge[8, 221] -> 
             RGBColor[
              0.5784518548396522, 0.6686523005747489, 0.9599569954333912], 
             UndirectedEdge[240, 251] -> 
             RGBColor[
              0.25758537828186423`, 0.38806894280347104`, 0.9379804782785095],
              UndirectedEdge[464, 485] -> 
             RGBColor[
              0.24593397699878092`, 0.3758225813134415, 0.9373169482121415], 
             UndirectedEdge[104, 452] -> 
             RGBColor[
              0.2352635459876256, 0.36460728177631574`, 0.9367092829515442], 
             UndirectedEdge[121, 475] -> 
             RGBColor[
              0.8332346662535209, 0.256461785113985, 0.17945885997854572`], 
             UndirectedEdge[168, 315] -> 
             RGBColor[
              0.5481459181329882, 0.49816507299275914`, 0.5904774154442385], 
             UndirectedEdge[65, 320] -> 
             RGBColor[
              0.9870336626851595, 0.9760932232050978, 0.618291834936235], 
             UndirectedEdge[323, 452] -> 
             RGBColor[
              0.23164904535488023`, 0.3608082124387239, 0.9365034424876839], 
             UndirectedEdge[72, 322] -> 
             RGBColor[
              0.25660150329804876`, 0.38703482781420406`, 0.9379244480536938],
              UndirectedEdge[60, 327] -> 
             RGBColor[
              0.27488937913222444`, 0.40625654483422113`, 0.9389659155279624],
              UndirectedEdge[1, 135] -> 
             RGBColor[
              0.2583961289533292, 0.38892109316374235`, 0.9380266493298512], 
             UndirectedEdge[420, 439] -> 
             RGBColor[
              0.9147776569049322, 0.9340333582536569, 0.9622797424419812], 
             UndirectedEdge[134, 367] -> 
             RGBColor[
              0.23152572380893705`, 0.3606785936749, 0.9364964195080803], 
             UndirectedEdge[119, 345] -> 
             RGBColor[
              0.8251862844410536, 0.8622510331677843, 0.8856898202805965], 
             UndirectedEdge[64, 366] -> 
             RGBColor[
              0.27642037277284975`, 0.4078657162211217, 0.9390531033508938], 
             UndirectedEdge[86, 90] -> 
             RGBColor[
              0.8899814344584336, 0.5901544331035902, 0.2297467504579272], 
             UndirectedEdge[81, 426] -> 
             RGBColor[
              0.8468962698264015, 0.8807561134454687, 0.9852589163209091], 
             UndirectedEdge[70, 265] -> 
             RGBColor[
              0.28963233444531233`, 0.42061801847270397`, 0.9398470375642044],
              UndirectedEdge[245, 438] -> 
             RGBColor[
              0.22151371355788788`, 0.3501553361029332, 0.9359262503357249], 
             UndirectedEdge[121, 259] -> 
             RGBColor[
              0.8446533203330481, 0.33882677308300735`, 0.1901817771182239], 
             UndirectedEdge[74, 105] -> 
             RGBColor[
              0.2638196417670582, 0.3946215490015449, 0.938335510361225], 
             UndirectedEdge[358, 430] -> 
             RGBColor[
              0.23268261924121364`, 0.3618945641256297, 0.936562302991475], 
             UndirectedEdge[43, 316] -> 
             RGBColor[
              0.2718214258604257, 0.4030319314260883, 0.9387912001277635], 
             UndirectedEdge[162, 203] -> 
             RGBColor[
              0.4982990262412239, 0.6035806234747654, 0.9536470711566374], 
             UndirectedEdge[226, 236] -> 
             RGBColor[
              0.23337407460187973`, 0.3626213275504917, 0.9366016803513484], 
             UndirectedEdge[110, 340] -> 
             RGBColor[
              0.3045749314378675, 0.43480548891742876`, 0.9407535831342266], 
             UndirectedEdge[145, 407] -> 
             RGBColor[
              0.2175082544444818, 0.34594534461396753`, 0.9356981453647621], 
             UndirectedEdge[258, 289] -> 
             RGBColor[
              0.4063967473847854, 0.5264221693154291, 0.9471162192741931], 
             UndirectedEdge[13, 334] -> 
             RGBColor[
              0.3497101697631252, 0.47620162767835794`, 0.94354526344998], 
             UndirectedEdge[300, 389] -> 
             RGBColor[
              0.2222287148930997, 0.35090684783994386`, 0.9359669686040155], 
             UndirectedEdge[57, 363] -> 
             RGBColor[
              0.5030271726289528, 0.6061020766435601, 0.9543831982681161], 
             UndirectedEdge[305, 427] -> 
             RGBColor[
              0.26530600013852146`, 0.3961838058905166, 0.9384201562716097], 
             UndirectedEdge[277, 419] -> 
             RGBColor[
              0.6419960336426249, 0.718265092425402, 0.9663099050077802], 
             UndirectedEdge[40, 349] -> 
             RGBColor[
              0.3999008136180363, 0.5207957179817955, 0.9467023041187045], 
             UndirectedEdge[28, 241] -> 
             RGBColor[
              0.8351691071867402, 0.8715787875296648, 0.9578266018325254], 
             UndirectedEdge[164, 396] -> 
             RGBColor[
              0.9055353853140414, 0.5621560872497313, 0.3516608883245811], 
             UndirectedEdge[111, 284] -> 
             RGBColor[
              0.2590919383322233, 0.3896524329378227, 0.9380662746446216], 
             UndirectedEdge[25, 343] -> 
             RGBColor[
              0.3031313951145783, 0.4355126855320067, 0.9405899280547156], 
             UndirectedEdge[84, 131] -> 
             RGBColor[
              0.24846167161057395`, 0.3784793486155308, 0.9374608966808939], 
             UndirectedEdge[169, 244] -> 
             RGBColor[
              0.4175916065853016, 0.5350481346501237, 0.9481253168239769], 
             UndirectedEdge[219, 363] -> 
             RGBColor[
              0.4655401284489993, 0.5756684054061787, 0.9514320808307029], 
             UndirectedEdge[400, 415] -> 
             RGBColor[
              0.2914672574254832, 0.4236809460186285, 0.9399100011719903], 
             UndirectedEdge[248, 286] -> 
             RGBColor[
              0.23281996068137648`, 0.36203891868719107`, 0.9365701243833138],
              UndirectedEdge[136, 484] -> 
             RGBColor[
              0.980926180317411, 0.981787940062676, 0.7025545645628573], 
             UndirectedEdge[74, 263] -> 
             RGBColor[
              0.27756733242056764`, 0.40907124353231517`, 0.9391184210060566],
              UndirectedEdge[69, 142] -> 
             RGBColor[
              0.8044934065793106, 0.8479188521576653, 0.9809561216743297], 
             UndirectedEdge[109, 409] -> 
             RGBColor[
              0.24775783308986035`, 0.3777395697043211, 0.9374208141183751], 
             UndirectedEdge[101, 219] -> 
             RGBColor[
              0.5235508135187052, 0.6240811619666777, 0.9556349843514654], 
             UndirectedEdge[380, 390] -> 
             RGBColor[
              0.2868022644003798, 0.4187777425716037, 0.9396443367204493], 
             UndirectedEdge[53, 293] -> 
             RGBColor[
              0.9653923096103165, 0.9489247911355639, 0.6627722008261114], 
             UndirectedEdge[221, 258] -> 
             RGBColor[
              0.45501626161494246`, 0.5662723735811732, 0.9508390917145717], 
             UndirectedEdge[235, 424] -> 
             RGBColor[
              0.3388180779328382, 0.46788892243883967`, 0.9428101662141861], 
             UndirectedEdge[367, 457] -> 
             RGBColor[
              0.22571706608911693`, 0.3545733261211982, 0.9361656250440755], 
             UndirectedEdge[58, 220] -> 
             RGBColor[
              0.32701247471585293`, 0.45766350229915764`, 0.9420579236164848],
              UndirectedEdge[334, 379] -> 
             RGBColor[
              0.3560516389210633, 0.4828157667828796, 0.9439082734813162], 
             UndirectedEdge[14, 163] -> 
             RGBColor[
              0.2868674954285888, 0.4188463045181374, 0.9396480515310051], 
             UndirectedEdge[284, 442] -> 
             RGBColor[
              0.26451897986036277`, 0.3953565976782041, 0.9383753366310607], 
             UndirectedEdge[130, 302] -> 
             RGBColor[
              0.18453817917078433`, 0.311291705077802, 0.9338205483527805], 
             UndirectedEdge[65, 428] -> 
             RGBColor[
              0.9078991618741388, 0.5983968558388272, 0.2873573629313444], 
             UndirectedEdge[388, 487] -> 
             RGBColor[
              0.7628017392959624, 0.8144116714200249, 0.9680174393113103], 
             UndirectedEdge[456, 458] -> 
             RGBColor[
              0.22707889219219896`, 0.35600469170029936`, 0.9362431790260048],
              UndirectedEdge[281, 465] -> 
             RGBColor[
              0.26376712193927254`, 0.39456634733259277`, 0.9383325194347287],
              UndirectedEdge[166, 428] -> 
             RGBColor[
              0.8342269539589475, 0.26408894324113896`, 0.18040907580589088`],
              UndirectedEdge[92, 128] -> 
             RGBColor[
              0.5519404005403256, 0.6471291076471498, 0.9578699166362912], 
             UndirectedEdge[120, 457] -> 
             RGBColor[
              0.21450528797873675`, 0.3427890364593986, 0.9355271308670288], 
             UndirectedEdge[79, 329] -> 
             RGBColor[
              0.9381932995999778, 0.9492001435332333, 0.7791661244013025], 
             UndirectedEdge[105, 195] -> 
             RGBColor[
              0.2580285978828387, 0.38853479470584096`, 0.9380057189791005], 
             UndirectedEdge[98, 377] -> 
             RGBColor[
              0.9881699242791049, 0.9888223570121889, 0.8197885510745015], 
             UndirectedEdge[21, 309] -> 
             RGBColor[
              0.9869592653755547, 0.967346961753188, 0.4315364838739727], 
             UndirectedEdge[93, 322] -> 
             RGBColor[
              0.26425191426448674`, 0.3950758948040016, 0.9383601276404636], 
             UndirectedEdge[8, 115] -> 
             RGBColor[
              0.7707310045144475, 0.8213000079229384, 0.9777969948316587], 
             UndirectedEdge[54, 131] -> 
             RGBColor[
              0.24616492351091418`, 0.3760653207405481, 0.9373301002743527], 
             UndirectedEdge[186, 212] -> 
             RGBColor[
              0.22711333090057176`, 0.3560408889663394, 0.9362451402594992], 
             UndirectedEdge[252, 467] -> 
             RGBColor[
              0.7213175895970523, 0.7822180503007243, 0.9728578543010624], 
             UndirectedEdge[244, 378] -> 
             RGBColor[
              0.3127627275114677, 0.4429484996474682, 0.9412368143882763], 
             UndirectedEdge[55, 339] -> 
             RGBColor[
              0.21158417509033906`, 0.33971876160443837`, 0.9353607778094337],
              UndirectedEdge[69, 490] -> 
             RGBColor[
              0.9500080335378767, 0.9605032008441318, 0.8987210231001681], 
             UndirectedEdge[299, 451] -> 
             RGBColor[
              0.21030609728277713`, 0.3383754207938774, 0.9352879931690398], 
             UndirectedEdge[146, 464] -> 
             RGBColor[
              0.25089999678857744`, 0.38104218297635795`, 0.9375997556926023],
              UndirectedEdge[199, 220] -> 
             RGBColor[
              0.3408785418830542, 0.4696735927505875, 0.9429414571550971], 
             UndirectedEdge[345, 426] -> 
             RGBColor[
              0.7649497936964772, 0.8167095300211071, 0.9770990522255436], 
             UndirectedEdge[66, 472] -> 
             RGBColor[
              0.29586389462338253`, 0.42648062461240877`, 0.9402270759441249],
              UndirectedEdge[40, 114] -> 
             RGBColor[
              0.443439320562669, 0.5572206362112937, 0.9498318505944043], 
             UndirectedEdge[248, 294] -> 
             RGBColor[
              0.240426199543799, 0.37003355799499527`, 0.9370032884341067], 
             UndirectedEdge[304, 483] -> 
             RGBColor[
              0.3176066092257016, 0.44839817992769826`, 0.941499541548237], 
             UndirectedEdge[9, 425] -> 
             RGBColor[
              0.47524326414852586`, 0.5827457090080587, 0.9524170280286233], 
             UndirectedEdge[290, 384] -> 
             RGBColor[
              0.2851530200769201, 0.4170442822195179, 0.9395504146960666], 
             UndirectedEdge[294, 358] -> 
             RGBColor[
              0.23196947764628847`, 0.36114500709357467`, 0.9365216906326425],
              UndirectedEdge[148, 342] -> 
             RGBColor[
              0.2498214928286487, 0.3799086069333723, 0.9375383364875882], 
             UndirectedEdge[178, 420] -> 
             RGBColor[
              0.9801637329335828, 0.9834819259202605, 0.8627171585529716], 
             UndirectedEdge[193, 354] -> 
             RGBColor[
              0.3247877807995152, 0.4538010668360344, 0.941987036861071], 
             UndirectedEdge[194, 228] -> 
             RGBColor[
              0.9897986964683487, 0.9881510016226367, 0.6807237889593197], 
             UndirectedEdge[326, 491] -> 
             RGBColor[
              0.9346684716417725, 0.7580015966571071, 0.4117209054738351], 
             UndirectedEdge[324, 481] -> 
             RGBColor[
              0.3439470735768655, 0.47233140067487944`, 0.9431369812812307], 
             UndirectedEdge[94, 213] -> 
             RGBColor[
              0.9298124883323949, 0.8120876909328425, 0.6010637208876998], 
             UndirectedEdge[92, 175] -> 
             RGBColor[
              0.7824339265203888, 0.8300343229197356, 0.9610969915433571], 
             UndirectedEdge[254, 401] -> 
             RGBColor[
              0.50497531356463, 0.5944255881948143, 0.9574168801184721], 
             UndirectedEdge[161, 491] -> 
             RGBColor[
              0.992246695040947, 0.9844848921088973, 0.5114139987289448], 
             UndirectedEdge[172, 303] -> 
             RGBColor[
              0.32845548787730483`, 0.4585909264869045, 0.9421616772940785], 
             UndirectedEdge[57, 274] -> 
             RGBColor[
              0.5319886243671207, 0.6309313569324684, 0.9562992397301722], 
             UndirectedEdge[44, 360] -> 
             RGBColor[
              0.5380217860131518, 0.6358293493475512, 0.9567741923151472], 
             UndirectedEdge[170, 238] -> 
             RGBColor[
              0.3084172446419511, 0.44044171708200675`, 0.940913897073925], 
             UndirectedEdge[5, 11] -> 
             RGBColor[
              0.23876273655839006`, 0.3682851529276855, 0.9369085566779607], 
             UndirectedEdge[3, 223] -> 
             RGBColor[
              0.4257649092191724, 0.5429712289379067, 0.9484129706530855], 
             UndirectedEdge[65, 227] -> 
             RGBColor[
              0.9155479974276244, 0.657189157644029, 0.2946818964954864], 
             UndirectedEdge[78, 85] -> 
             RGBColor[
              0.21682232686548605`, 0.34522439123812265`, 0.9356590828038773],
              UndirectedEdge[181, 393] -> 
             RGBColor[
              0.4409543407183537, 0.5561398931308579, 0.9493774176456293], 
             UndirectedEdge[45, 56] -> 
             RGBColor[
              0.5597280401148761, 0.3487238439697099, 0.5610837052268939], 
             UndirectedEdge[141, 310] -> 
             RGBColor[
              0.3031699755874952, 0.4359038694979436, 0.9405792867476138], 
             UndirectedEdge[39, 236] -> 
             RGBColor[
              0.4554923722273556, 0.5623404159424226, 0.9515950359894985], 
             UndirectedEdge[337, 375] -> 
             RGBColor[
              0.9092060692572821, 0.9298599802312014, 0.9710835499900707], 
             UndirectedEdge[57, 334] -> 
             RGBColor[
              0.5020235331688498, 0.6052327745876049, 0.9543192472492019], 
             UndirectedEdge[123, 438] -> 
             RGBColor[
              0.21421403684205725`, 0.34248291304835987`, 0.9355105445456623],
              UndirectedEdge[35, 385] -> 
             RGBColor[
              0.235922007593164, 0.36529936667261376`, 0.936746781365873], 
             UndirectedEdge[268, 285] -> 
             RGBColor[
              0.3620365603618595, 0.4879996049239992, 0.9442896273832655], 
             UndirectedEdge[169, 361] -> 
             RGBColor[
              0.5684718159304661, 0.6605218314458838, 0.9591906270789168], 
             UndirectedEdge[337, 361] -> 
             RGBColor[
              0.752206073850372, 0.8066735064022713, 0.9758502482621753], 
             UndirectedEdge[119, 270] -> 
             RGBColor[
              0.9903352312511376, 0.9902713839961873, 0.8098337599957988], 
             UndirectedEdge[254, 386] -> 
             RGBColor[
              0.20771262472504887`, 0.3356495167000475, 0.935140298743576], 
             UndirectedEdge[253, 488] -> 
             RGBColor[
              0.877198073649208, 0.9039154021300979, 0.937685633244106], 
             UndirectedEdge[340, 380] -> 
             RGBColor[
              0.3051428116901297, 0.43540236706824387`, 0.9407859230744895], 
             UndirectedEdge[388, 490] -> 
             RGBColor[
              0.9683628300119925, 0.9748687448836537, 0.8911081388957877], 
             UndirectedEdge[27, 311] -> 
             RGBColor[
              0.6294878924283578, 0.7084848809709354, 0.9650691972348303], 
             UndirectedEdge[222, 417] -> 
             RGBColor[
              0.5718731828738293, 0.6621247011020224, 0.9601331729684849], 
             UndirectedEdge[274, 361] -> 
             RGBColor[
              0.5534678542610545, 0.6483409394418851, 0.9580094602549781], 
             UndirectedEdge[65, 474] -> 
             RGBColor[
              0.989280991001634, 0.9770225512176633, 0.5810477888330006], 
             UndirectedEdge[243, 326] -> 
             RGBColor[
              0.8572408103331092, 0.41460626615910345`, 0.2014143032349089], 
             UndirectedEdge[47, 437] -> 
             RGBColor[
              0.2438820574631478, 0.37366588378227833`, 0.93720009443013], 
             UndirectedEdge[232, 414] -> 
             RGBColor[
              0.31542779716347613`, 0.44447776538926564`, 0.9414351563383871],
              UndirectedEdge[102, 196] -> 
             RGBColor[
              0.28611844580431445`, 0.41805900587053585`, 0.9396053942630224],
              UndirectedEdge[90, 257] -> 
             RGBColor[
              0.8618116052496472, 0.4654005988057779, 0.20640455492384144`], 
             UndirectedEdge[116, 310] -> 
             RGBColor[
              0.2727415097182925, 0.40399899789739224`, 0.9388435975423268], 
             UndirectedEdge[333, 459] -> 
             RGBColor[
              0.3845976264069504, 0.5075408663801063, 0.9457271985616913], 
             UndirectedEdge[68, 257] -> 
             RGBColor[
              0.8394199460541523, 0.30329924422110266`, 0.18535427265779897`],
              UndirectedEdge[220, 349] -> 
             RGBColor[
              0.3762573378366486, 0.5003169276156031, 0.9451957627490192], 
             UndirectedEdge[92, 204] -> 
             RGBColor[
              0.5555153199743827, 0.6500313882920026, 0.9581513473895016], 
             UndirectedEdge[120, 123] -> 
             RGBColor[
              0.20719251066229882`, 0.33510284384296096`, 0.9351106790171422],
              UndirectedEdge[190, 224] -> 
             RGBColor[
              0.2735379552710175, 0.40483611267087094`, 0.938888953938319], 
             UndirectedEdge[450, 469] -> 
             RGBColor[
              0.8390695807149537, 0.298125435533924, 0.18492162257597716`], 
             UndirectedEdge[405, 434] -> 
             RGBColor[
              0.9926076308918226, 0.9901160572249841, 0.6925776468321798], 
             UndirectedEdge[312, 400] -> 
             RGBColor[
              0.30016668312241634`, 0.43282459400155193`, 0.9404054205957836],
              UndirectedEdge[100, 259] -> 
             RGBColor[
              0.8965277758950481, 0.6152647749950997, 0.2349704456547408], 
             UndirectedEdge[87, 423] -> 
             RGBColor[
              0.18353957668712906`, 0.310242110552426, 0.9337636794186364], 
             UndirectedEdge[403, 449] -> 
             RGBColor[
              0.8286073759188407, 0.8669140710830616, 0.9833178599894938], 
             UndirectedEdge[268, 275] -> 
             RGBColor[
              0.4116793705742366, 0.5309977120097701, 0.9474528233525847], 
             UndirectedEdge[166, 210] -> 
             RGBColor[
              0.8370920629652436, 0.28611142656230293`, 0.18315270742599782`],
              UndirectedEdge[102, 496] -> 
             RGBColor[
              0.27671354998693043`, 0.4081738640616296, 0.9390697993595188], 
             UndirectedEdge[11, 202] -> 
             RGBColor[
              0.2389875961328362, 0.3685214945973489, 0.9369213620980754], 
             UndirectedEdge[187, 494] -> 
             RGBColor[
              0.26156581469201307`, 0.3922526338447824, 0.9382071582435395], 
             UndirectedEdge[158, 282] -> 
             RGBColor[
              0.4825898599888707, 0.5882261104425313, 0.9531290808792493], 
             UndirectedEdge[232, 372] -> 
             RGBColor[
              0.41332534927572523`, 0.5319581186500844, 0.9476862556607386], 
             UndirectedEdge[143, 477] -> 
             RGBColor[
              0.21179931439321417`, 0.33994488665237976`, 0.9353730296744625],
              UndirectedEdge[479, 482] -> 
             RGBColor[
              0.3849860560945393, 0.5078773046524521, 0.9457519489579096], 
             UndirectedEdge[45, 283] -> 
             RGBColor[
              0.23199831546813182`, 0.3611753174727555, 0.9365233329039347], 
             UndirectedEdge[323, 463] -> 
             RGBColor[
              0.25322101360276406`, 0.3834817188090337, 0.9377319341665338], 
             UndirectedEdge[130, 347] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[338, 369] -> 
             RGBColor[
              0.37002637582951403`, 0.49491998150227967`, 0.9447987313597479],
              UndirectedEdge[143, 386] -> 
             RGBColor[
              0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772],
              UndirectedEdge[168, 254] -> 
             RGBColor[
              0.5736452347236608, 0.5249664714796068, 0.591929563801219], 
             UndirectedEdge[86, 115] -> 
             RGBColor[
              0.9181807358610004, 0.8207272885954675, 0.6214818156174652], 
             UndirectedEdge[138, 457] -> 
             RGBColor[
              0.22077773189024535`, 0.349381772706308, 0.9358843372685399], 
             UndirectedEdge[11, 497] -> 
             RGBColor[
              0.2374558873234022, 0.36691157152268605`, 0.9368341335473384], 
             UndirectedEdge[154, 379] -> 
             RGBColor[
              0.3094202014132221, 0.4424259593777846, 0.9409369595178776], 
             UndirectedEdge[17, 467] -> 
             RGBColor[
              0.7934052123801664, 0.8390183037645371, 0.979914209324252], 
             UndirectedEdge[75, 93] -> 
             RGBColor[
              0.30711689507265494`, 0.43678253795558514`, 0.940923781155411], 
             UndirectedEdge[100, 315] -> 
             RGBColor[
              0.5583572344294613, 0.5386495393888345, 0.5986936802267802], 
             UndirectedEdge[45, 52] -> 
             RGBColor[
              0.5592887582023336, 0.3453473306953461, 0.5606630483713451], 
             UndirectedEdge[8, 203] -> 
             RGBColor[
              0.5774301323005686, 0.6678228201894449, 0.9598765616924215], 
             UndirectedEdge[244, 340] -> 
             RGBColor[
              0.33993779537767665`, 0.4688587654109236, 0.9428815136196439], 
             UndirectedEdge[104, 190] -> 
             RGBColor[
              0.24734164292075334`, 0.3773021274486088, 0.9373971127039427], 
             UndirectedEdge[38, 437] -> 
             RGBColor[
              0.2578995688543769, 0.3883991770160148, 0.9379983709668107], 
             UndirectedEdge[96, 465] -> 
             RGBColor[
              0.2893936582907169, 0.42150146185421045`, 0.9397919127688803], 
             UndirectedEdge[48, 346] -> 
             RGBColor[
              0.21269676667826953`, 0.34088816590573434`, 0.9354241382544346],
              UndirectedEdge[153, 342] -> 
             RGBColor[
              0.25246005368067864`, 0.38268190168327626`, 0.9376885986247103],
              UndirectedEdge[151, 327] -> 
             RGBColor[
              0.28193174194509296`, 0.41365851466213766`, 0.939366967671913], 
             UndirectedEdge[375, 489] -> 
             RGBColor[
              0.9741495163492516, 0.9792601983573855, 0.8847051301265769], 
             UndirectedEdge[203, 289] -> 
             RGBColor[
              0.48696884397226536`, 0.5940035787603833, 0.9528597515235682], 
             UndirectedEdge[6, 79] -> 
             RGBColor[
              0.9107592672849488, 0.9273249908421985, 0.7765494419084453], 
             UndirectedEdge[105, 463] -> 
             RGBColor[
              0.2565013158137106, 0.3869295244159112, 0.9379187425246749], 
             UndirectedEdge[10, 125] -> 
             RGBColor[
              0.21381800062875955`, 0.3420666538780378, 0.935487990869198], 
             UndirectedEdge[32, 331] -> 
             RGBColor[
              0.6862012136677067, 0.7532861971667737, 0.9704389262848694], 
             UndirectedEdge[26, 44] -> 
             RGBColor[
              0.4416533932183588, 0.5557823986053863, 0.949688034527277], 
             UndirectedEdge[86, 253] -> 
             RGBColor[
              0.9501124692155603, 0.8447770986590462, 0.5741725699000219], 
             UndirectedEdge[370, 466] -> 
             RGBColor[
              0.5474757553674385, 0.6435045075658272, 0.9575184434137474], 
             UndirectedEdge[301, 456] -> 
             RGBColor[
              0.21620560443164671`, 0.3445761768576967, 0.9356239613736292], 
             UndirectedEdge[21, 337] -> 
             RGBColor[
              0.9205492329643337, 0.9192823831910986, 0.6833909335036439], 
             UndirectedEdge[61, 172] -> 
             RGBColor[
              0.3377395733706075, 0.4669547759942509, 0.9427414448571648], 
             UndirectedEdge[291, 359] -> 
             RGBColor[
              0.5201892016597764, 0.619316785102851, 0.95601113315619], 
             UndirectedEdge[134, 499] -> 
             RGBColor[
              0.2469625122439105, 0.37690363706897373`, 0.93737552177277], 
             UndirectedEdge[140, 244] -> 
             RGBColor[
              0.42103754660959536`, 0.5378457039996745, 0.9483965938455836], 
             UndirectedEdge[108, 364] -> 
             RGBColor[
              0.27183868506633, 0.4030500719457907, 0.938792183014007], 
             UndirectedEdge[113, 421] -> 
             RGBColor[
              0.17912443323835392`, 0.3056015148515002, 0.9335122435308479], 
             UndirectedEdge[54, 55] -> 
             RGBColor[
              0.22009923076516985`, 0.34866862500439766`, 0.9358456976332195],
              UndirectedEdge[56, 210] -> 
             RGBColor[
              0.8363686612775614, 0.28055104419413623`, 0.18245997715290796`],
              UndirectedEdge[36, 58] -> 
             RGBColor[
              0.28475051663686596`, 0.4160326690739975, 0.9395490426575464], 
             UndirectedEdge[25, 288] -> 
             RGBColor[
              0.2847205959795895, 0.4161617683290476, 0.9395414602803146], 
             UndirectedEdge[262, 344] -> 
             RGBColor[
              0.4699143971667351, 0.5805367028791276, 0.9514125291795714], 
             UndirectedEdge[8, 439] -> 
             RGBColor[
              0.7406030565482964, 0.7972768000160912, 0.9749233642591105], 
             UndirectedEdge[102, 186] -> 
             RGBColor[
              0.256123983487738, 0.3865329242170628, 0.9378972540069239], 
             UndirectedEdge[85, 145] -> 
             RGBColor[
              0.21743686076267443`, 0.3458703053277671, 0.9356940796002007], 
             UndirectedEdge[421, 423] -> 
             RGBColor[
              0.18344124862659156`, 0.31013876152644193`, 0.9337580797810521],
              UndirectedEdge[406, 476] -> 
             RGBColor[
              0.9195554041525527, 0.6768776802935997, 0.3060621599750899], 
             UndirectedEdge[111, 400] -> 
             RGBColor[
              0.2845065356159251, 0.4163647860615299, 0.939513598362401], 
             UndirectedEdge[137, 183] -> 
             RGBColor[
              0.2125239415632086, 0.34070651575206007`, 0.9354142961198038], 
             UndirectedEdge[85, 358] -> 
             RGBColor[
              0.2199208837213561, 0.34848117095349374`, 0.935835541032915], 
             UndirectedEdge[399, 412] -> 
             RGBColor[
              0.24194122045751632`, 0.37162594103318614`, 0.9370895666338703],
              UndirectedEdge[283, 292] -> 
             RGBColor[
              0.18009239570445779`, 0.3066189047757405, 0.9335673675613205], 
             UndirectedEdge[240, 310] -> 
             RGBColor[
              0.2766913122921885, 0.4081504908345045, 0.939068532955701], 
             UndirectedEdge[186, 300] -> 
             RGBColor[
              0.23083402862066274`, 0.35995157817601575`, 0.9364570284903794],
              UndirectedEdge[37, 240] -> 
             RGBColor[
              0.28113287624005423`, 0.4128188561551308, 0.9393214734518269], 
             UndirectedEdge[36, 429] -> 
             RGBColor[
              0.2739936283843697, 0.4053150540043482, 0.9389149038480165], 
             UndirectedEdge[56, 276] -> 
             RGBColor[
              0.7281068824339767, 0.4924523185511463, 0.5729718060098814], 
             UndirectedEdge[95, 174] -> 
             RGBColor[
              0.24687001390337449`, 0.3768064154483368, 0.9373702541291156], 
             UndirectedEdge[7, 28] -> 
             RGBColor[
              0.901769090567154, 0.9237583305634441, 0.9644245605513657], 
             UndirectedEdge[251, 367] -> 
             RGBColor[
              0.24419513183599667`, 0.3739949447982042, 0.9372179235525118], 
             UndirectedEdge[31, 314] -> 
             RGBColor[
              0.3915568678230763, 0.5135686115131106, 0.9461706352709112], 
             UndirectedEdge[238, 436] -> 
             RGBColor[
              0.3965368671240651, 0.5173498014044343, 0.9466350145946033], 
             UndirectedEdge[291, 488] -> 
             RGBColor[
              0.7121457205579194, 0.7750529164985673, 0.971943688111231], 
             UndirectedEdge[96, 171] -> 
             RGBColor[
              0.2789519797924134, 0.41052659571183897`, 0.939197274625481], 
             UndirectedEdge[127, 179] -> 
             RGBColor[
              0.20245447418328588`, 0.33012286709465477`, 0.9348408548489592],
              UndirectedEdge[296, 453] -> 
             RGBColor[
              0.2988633264806147, 0.4310225569001501, 0.9403470186360454], 
             UndirectedEdge[14, 494] -> 
             RGBColor[
              0.2826231066390982, 0.4143851827905905, 0.9394063398684542], 
             UndirectedEdge[317, 420] -> 
             RGBColor[
              0.9260215766566631, 0.7697821905786719, 0.5811912001414211], 
             UndirectedEdge[7, 388] -> 
             RGBColor[
              0.8924271040987608, 0.9167910923514154, 0.9802381068620604], 
             UndirectedEdge[146, 271] -> 
             RGBColor[
              0.25686927492861433`, 0.3873162727756304, 0.9379396972519218], 
             UndirectedEdge[331, 449] -> 
             RGBColor[
              0.7824972356635673, 0.8301470968699212, 0.9789198336489376], 
             UndirectedEdge[27, 359] -> 
             RGBColor[
              0.44878508964320496`, 0.5615402381340974, 0.9502583075299758], 
             UndirectedEdge[100, 471] -> 
             RGBColor[
              0.894013717811025, 0.6013444138663678, 0.23277457969666004`], 
             UndirectedEdge[219, 337] -> 
             RGBColor[
              0.6932397997764845, 0.7588302526554731, 0.971188910299956], 
             UndirectedEdge[199, 419] -> 
             RGBColor[
              0.4277672068152066, 0.5433200836247167, 0.948923355062986], 
             UndirectedEdge[266, 437] -> 
             RGBColor[
              0.2726756027922651, 0.40392972553939704`, 0.9388398442403902], 
             UndirectedEdge[327, 399] -> 
             RGBColor[
              0.24928505714751653`, 0.3793447790205158, 0.9375077872691331], 
             UndirectedEdge[311, 419] -> 
             RGBColor[
              0.6297737018777119, 0.70871691395749, 0.9650916972016379], 
             UndirectedEdge[267, 329] -> 
             RGBColor[
              0.9358102453449542, 0.941979730786866, 0.7003355368972839], 
             UndirectedEdge[219, 244] -> 
             RGBColor[
              0.43435496414043395`, 0.548657383494032, 0.949444989736919], 
             UndirectedEdge[17, 205] -> 
             RGBColor[
              0.9368989095333399, 0.9481665884975428, 0.7789256469520753], 
             UndirectedEdge[175, 361] -> 
             RGBColor[
              0.7999658560018515, 0.8442393091304512, 0.9624964661202554], 
             UndirectedEdge[189, 266] -> 
             RGBColor[
              0.2746480537102089, 0.4060028965147674, 0.9389521724021874], 
             UndirectedEdge[225, 280] -> 
             RGBColor[
              0.26557083518380836`, 0.39646216431462483`, 0.9384352382356503],
              UndirectedEdge[300, 458] -> 
             RGBColor[
              0.22822845140871784`, 0.35721295132312475`, 0.9363086447227651],
              UndirectedEdge[171, 343] -> 
             RGBColor[
              0.2773148667291586, 0.40880588608339485`, 0.9391040434584204], 
             UndirectedEdge[358, 408] -> 
             RGBColor[
              0.2240653730927813, 0.35283729205866493`, 0.936071563571395], 
             UndirectedEdge[380, 411] -> 
             RGBColor[
              0.2562205129796168, 0.38663438283335066`, 0.9379027512186837], 
             UndirectedEdge[345, 498] -> 
             RGBColor[
              0.5608073530060538, 0.6540616711594758, 0.9587498403781267], 
             UndirectedEdge[161, 450] -> 
             RGBColor[
              0.9040202207813182, 0.5580851531997648, 0.2907664410126593], 
             UndirectedEdge[94, 214] -> 
             RGBColor[
              0.5776130969249946, 0.6468062636067821, 0.9475190708650497], 
             UndirectedEdge[157, 343] -> 
             RGBColor[
              0.2977155588527831, 0.4302483069839126, 0.9402658326947413], 
             UndirectedEdge[155, 332] -> 
             RGBColor[
              0.4840405870433834, 0.5906167908800439, 0.9529081554374272], 
             UndirectedEdge[127, 168] -> 
             RGBColor[
              0.5683860156508949, 0.5194386987803812, 0.5916300590553423], 
             UndirectedEdge[378, 380] -> 
             RGBColor[
              0.27796774382392075`, 0.40949210130478847`, 0.939141223843122], 
             UndirectedEdge[160, 481] -> 
             RGBColor[
              0.3703492229848604, 0.49519961548147085`, 0.9448193028950042], 
             UndirectedEdge[23, 485] -> 
             RGBColor[
              0.2352513492635514, 0.3645944622459968, 0.9367085883661517], 
             UndirectedEdge[352, 399] -> 
             RGBColor[
              0.23466592421327268`, 0.3639791434000619, 0.936675249275597], 
             UndirectedEdge[389, 456] -> 
             RGBColor[
              0.22107915567658082`, 0.3496985882171184, 0.9359015029072553], 
             UndirectedEdge[105, 263] -> 
             RGBColor[
              0.2596529612026372, 0.3902421035455322, 0.9380982240671327], 
             UndirectedEdge[143, 347] -> 
             RGBColor[
              0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772],
              UndirectedEdge[98, 484] -> 
             RGBColor[
              0.9940632182259341, 0.9897101490230129, 0.5951961253421731], 
             UndirectedEdge[100, 500] -> 
             RGBColor[
              0.8753537574413516, 0.45791578161828494`, 0.21490578057324983`],
              UndirectedEdge[89, 424] -> 
             RGBColor[
              0.3030480744366626, 0.4347576504686087, 0.9406096220363795], 
             UndirectedEdge[231, 442] -> 
             RGBColor[
              0.2711958428958343, 0.40237440406605196`, 0.938755574103397], 
             UndirectedEdge[15, 104] -> 
             RGBColor[
              0.24040623048550225`, 0.3700125692486139, 0.9370021512257783], 
             UndirectedEdge[75, 182] -> 
             RGBColor[
              0.3617675856264607, 0.48776663252726005`, 0.9442724885509708], 
             UndirectedEdge[290, 316] -> 
             RGBColor[
              0.268490139738015, 0.3995305384956953, 0.9386014883112883], 
             UndirectedEdge[344, 424] -> 
             RGBColor[
              0.39216870621134226`, 0.5138154925134429, 0.9462878321282429], 
             UndirectedEdge[369, 425] -> 
             RGBColor[
              0.397645136695217, 0.5188419640048679, 0.9465585743797993], 
             UndirectedEdge[106, 255] -> 
             RGBColor[
              0.45772043203322, 0.569123825312507, 0.9508706958509441], 
             UndirectedEdge[84, 242] -> 
             RGBColor[
              0.22916096004104347`, 0.3581930770201611, 0.9363617497098533], 
             UndirectedEdge[143, 446] -> 
             RGBColor[
              0.20353913733189777`, 0.3312629168354616, 0.9349026248106573], 
             UndirectedEdge[376, 415] -> 
             RGBColor[
              0.28323389332621046`, 0.41502715832485815`, 0.9394411232667073],
              UndirectedEdge[93, 108] -> 
             RGBColor[
              0.27719798724909794`, 0.408683038339264, 0.9390973873449386], 
             UndirectedEdge[78, 183] -> 
             RGBColor[
              0.21219822021020854`, 0.34036416195813046`, 0.935395746770612], 
             UndirectedEdge[17, 298] -> 
             RGBColor[
              0.8908055349705915, 0.9157681695861948, 0.9894470212286257], 
             UndirectedEdge[204, 370] -> 
             RGBColor[
              0.546668194471859, 0.642848893250592, 0.9574548692618543], 
             UndirectedEdge[208, 314] -> 
             RGBColor[
              0.32609699892407057`, 0.4568705631814669, 0.9419995903085558], 
             UndirectedEdge[313, 379] -> 
             RGBColor[
              0.288128547073246, 0.4201206026991259, 0.9397217393007642], 
             UndirectedEdge[3, 221] -> 
             RGBColor[
              0.4991380572062573, 0.6042617866100937, 0.9537131227476765], 
             UndirectedEdge[154, 229] -> 
             RGBColor[
              0.3002585012900294, 0.4328475787158096, 0.940413341505228], 
             UndirectedEdge[25, 180] -> 
             RGBColor[
              0.2917531123703574, 0.42355338894303707`, 0.9399419516850931], 
             UndirectedEdge[371, 419] -> 
             RGBColor[
              0.43781722710861815`, 0.5520249060741627, 0.9495637334691982], 
             UndirectedEdge[31, 419] -> 
             RGBColor[
              0.4828643991449212, 0.5910425023553091, 0.9524340994377012], 
             UndirectedEdge[321, 482] -> 
             RGBColor[
              0.3458284457686297, 0.47396095070686983`, 0.9432568606536578], 
             UndirectedEdge[212, 300] -> 
             RGBColor[
              0.22223694937519295`, 0.35091550280272016`, 0.9359674375455889],
              UndirectedEdge[376, 414] -> 
             RGBColor[
              0.27705653417076703`, 0.40853436218529504`, 0.9390893318013886],
              UndirectedEdge[140, 274] -> 
             RGBColor[
              0.4811841626563286, 0.5896860062007292, 0.9522997264014235], 
             UndirectedEdge[1, 131] -> 
             RGBColor[
              0.26488726968740706`, 0.3957436936373514, 0.9383963101918749], 
             UndirectedEdge[360, 466] -> 
             RGBColor[
              0.5414372478398441, 0.638602175123262, 0.9570430699813932], 
             UndirectedEdge[165, 182] -> 
             RGBColor[
              0.4013099579800705, 0.5220162480025345, 0.9467920935513959], 
             UndirectedEdge[268, 480] -> 
             RGBColor[
              0.3816010072146523, 0.5049453454501976, 0.9455362566365644], 
             UndirectedEdge[54, 385] -> 
             RGBColor[
              0.23109619211781043`, 0.36022712863364376`, 0.9364719583137058],
              UndirectedEdge[149, 158] -> 
             RGBColor[
              0.3556980515257828, 0.48250950715290686`, 0.943885743205154], 
             UndirectedEdge[229, 379] -> 
             RGBColor[
              0.30013749915285226`, 0.43274277274633094`, 0.9404056313560452],
              UndirectedEdge[98, 253] -> 
             RGBColor[
              0.9901332923121124, 0.9901471046097305, 0.8102166844391167], 
             UndirectedEdge[121, 469] -> 
             RGBColor[
              0.8439483097229172, 0.3356254845618147, 0.18959349898373934`], 
             UndirectedEdge[34, 269] -> 
             RGBColor[
              0.4963462045644428, 0.6018763440007352, 0.9535261877805588], 
             UndirectedEdge[145, 286] -> 
             RGBColor[
              0.22187921582518422`, 0.3505395021600439, 0.9359470651491353], 
             UndirectedEdge[34, 234] -> 
             RGBColor[
              0.4661658558479902, 0.5757356428509766, 0.951603122647781], 
             UndirectedEdge[85, 286] -> 
             RGBColor[
              0.21865790979829205`, 0.3471537052831816, 0.935763616536399], 
             UndirectedEdge[86, 261] -> 
             RGBColor[
              0.897589954080166, 0.6247029436909717, 0.23609548573218275`], 
             UndirectedEdge[140, 255] -> 
             RGBColor[
              0.4486097951007969, 0.5617273998212495, 0.950153473138261], 
             UndirectedEdge[345, 448] -> 
             RGBColor[
              0.6138322543981429, 0.6971096748541594, 0.9629241548523259], 
             UndirectedEdge[146, 444] -> 
             RGBColor[
              0.2646131387661169, 0.39545556465817117`, 0.9383806988414477], 
             UndirectedEdge[215, 224] -> 
             RGBColor[
              0.2915446973152564, 0.4237623402527527, 0.9399144112591507], 
             UndirectedEdge[40, 359] -> 
             RGBColor[
              0.38582570994179444`, 0.508604570612715, 0.9458054509585798], 
             UndirectedEdge[88, 495] -> 
             RGBColor[
              0.8544062989949438, 0.4062909143031017, 0.1992274995322182], 
             UndirectedEdge[341, 403] -> 
             RGBColor[
              0.9612426733705868, 0.9674078133042042, 0.7674804702008887], 
             UndirectedEdge[134, 416] -> 
             RGBColor[
              0.24737003573452257`, 0.37733197009608865`, 0.9373987296326833],
              UndirectedEdge[113, 423] -> 
             RGBColor[
              0.1835090760837748, 0.31021005248445066`, 0.9337619424543968], 
             UndirectedEdge[204, 362] -> 
             RGBColor[
              0.4451772959687064, 0.5586930048020928, 0.9499517048675632], 
             UndirectedEdge[231, 256] -> 
             RGBColor[
              0.27391624912615603`, 0.40523372349783726`, 0.9389104972137335],
              UndirectedEdge[183, 407] -> 
             RGBColor[
              0.2096628417623121, 0.3376993184571131, 0.9352513607187605], 
             UndirectedEdge[231, 271] -> 
             RGBColor[
              0.25712583983655113`, 0.38758593876102676`, 0.9379543082438752],
              UndirectedEdge[106, 140] -> 
             RGBColor[
              0.508744701282457, 0.6120608930455363, 0.9544693929596517], 
             UndirectedEdge[96, 147] -> 
             RGBColor[
              0.27382745193814473`, 0.40514039202317054`, 0.9389054403452399],
              UndirectedEdge[149, 275] -> 
             RGBColor[
              0.38378936730216673`, 0.5068407929678266, 0.9456756970062499], 
             UndirectedEdge[207, 287] -> 
             RGBColor[
              0.21343735530821623`, 0.3416665715118395, 0.9354663136813074], 
             UndirectedEdge[223, 480] -> 
             RGBColor[
              0.3717055099769321, 0.496374363105037, 0.9449057243028214], 
             UndirectedEdge[11, 102] -> 
             RGBColor[
              0.2577278443328788, 0.3882186836559568, 0.9379885915093551], 
             UndirectedEdge[230, 339] -> 
             RGBColor[
              0.21778435426976317`, 0.3462355430360783, 0.9357138688413589], 
             UndirectedEdge[103, 449] -> 
             RGBColor[
              0.6043292409167387, 0.6883441793156388, 0.9628942898259707], 
             UndirectedEdge[226, 396] -> 
             RGBColor[
              0.5864855268156967, 0.6472607121015193, 0.7362180745608087], 
             UndirectedEdge[144, 279] -> 
             RGBColor[
              0.2623939933592224, 0.3931231021335797, 0.9382543217934566], 
             UndirectedEdge[205, 228] -> 
             RGBColor[
              0.9934539331599859, 0.9884069498751192, 0.5288792059852668], 
             UndirectedEdge[267, 406] -> 
             RGBColor[
              0.9898404936899885, 0.9773917410301207, 0.415032665757733], 
             UndirectedEdge[209, 233] -> 
             RGBColor[
              0.7045416845554648, 0.49561598240663746`, 0.5739669497124782], 
             UndirectedEdge[387, 405] -> 
             RGBColor[
              0.8845632449194131, 0.9069230619459494, 0.7839577394340637], 
             UndirectedEdge[75, 206] -> 
             RGBColor[
              0.34384133423410757`, 0.4722398145707964, 0.9431302436638118], 
             UndirectedEdge[183, 404] -> 
             RGBColor[
              0.20920782453695042`, 0.33722106650349953`, 0.9352254481609139],
              UndirectedEdge[319, 488] -> 
             RGBColor[
              0.7421269925364968, 0.7984745140343386, 0.9749319411111395], 
             UndirectedEdge[220, 371] -> 
             RGBColor[
              0.3509285621764658, 0.4783784152000333, 0.9435818355613093], 
             UndirectedEdge[66, 460] -> 
             RGBColor[
              0.2558136629427209, 0.38620675764879087`, 0.9378795817109632], 
             UndirectedEdge[87, 446] -> 
             RGBColor[
              0.20370226760912918`, 0.33143437709988877`, 0.934911914838616], 
             UndirectedEdge[273, 308] -> 
             RGBColor[
              0.23624385022904204`, 0.36563764368892326`, 0.9367651098278627],
              UndirectedEdge[326, 428] -> 
             RGBColor[
              0.8527545036662538, 0.3801225472055363, 0.19711821090416948`], 
             UndirectedEdge[130, 315] -> 
             RGBColor[
              0.1822133081343763, 0.30884811821319974`, 0.9336881503865955], 
             UndirectedEdge[95, 407] -> 
             RGBColor[
              0.22072063099008732`, 0.34932175603983573`, 0.9358810854567492],
              UndirectedEdge[148, 153] -> 
             RGBColor[
              0.2422944032111111, 0.37199715850029413`, 0.9371096798692006], 
             UndirectedEdge[85, 137] -> 
             RGBColor[
              0.21714804821848613`, 0.34556674503205226`, 0.9356776321530691],
              UndirectedEdge[289, 359] -> 
             RGBColor[
              0.4124111574915527, 0.5316315490568694, 0.9474994521678624], 
             UndirectedEdge[32, 449] -> 
             RGBColor[
              0.6320067542390264, 0.7108140314884382, 0.9650731650607731], 
             UndirectedEdge[329, 406] -> 
             RGBColor[
              0.9365881325497546, 0.9446037269852596, 0.7033574817962612], 
             UndirectedEdge[168, 213] -> 
             RGBColor[
              0.9074990588325569, 0.6709655443987909, 0.2444294609060539], 
             UndirectedEdge[111, 464] -> 
             RGBColor[
              0.2584790029138965, 0.3890081989508112, 0.9380313688793045], 
             UndirectedEdge[50, 117] -> 
             RGBColor[
              0.41100665014042015`, 0.5304150353819104, 0.9474099582014052], 
             UndirectedEdge[357, 420] -> 
             RGBColor[
              0.937892556639665, 0.822845791169284, 0.5910531975827036], 
             UndirectedEdge[153, 190] -> 
             RGBColor[
              0.24652129125596123`, 0.3764398858356126, 0.9373503948902342], 
             UndirectedEdge[165, 275] -> 
             RGBColor[
              0.41886860868054065`, 0.537224668715837, 0.9479109152475247], 
             UndirectedEdge[152, 301] -> 
             RGBColor[
              0.2063778078751808, 0.33424653955855976`, 0.9350642828986606], 
             UndirectedEdge[208, 349] -> 
             RGBColor[
              0.3678599975315118, 0.49304357350588934`, 0.9446606916502523], 
             UndirectedEdge[5, 23] -> 
             RGBColor[
              0.23055442452635688`, 0.3596576965449768, 0.9364411054508459], 
             UndirectedEdge[56, 227] -> 
             RGBColor[
              0.8411523878247509, 0.31732086267817405`, 0.187040879096943], 
             UndirectedEdge[56, 326] -> 
             RGBColor[
              0.8559245599190561, 0.404488988692082, 0.2001538603519194], 
             UndirectedEdge[155, 181] -> 
             RGBColor[
              0.49329315877378277`, 0.5986309034651389, 0.9534977211263604], 
             UndirectedEdge[148, 323] -> 
             RGBColor[
              0.23950025424315785`, 0.36906033077569844`, 0.9369505572190486],
              UndirectedEdge[177, 438] -> 
             RGBColor[
              0.21508055771107348`, 0.3433936814222922, 0.9355598916272501], 
             UndirectedEdge[53, 90] -> 
             RGBColor[
              0.9206410418975434, 0.7056328015929743, 0.28606405077970154`], 
             UndirectedEdge[30, 217] -> 
             RGBColor[
              0.2938254921740675, 0.42514500116830317`, 0.9400814485951139], 
             UndirectedEdge[43, 290] -> 
             RGBColor[
              0.2898165263474991, 0.4219459229932718, 0.9398159944791369], 
             UndirectedEdge[114, 397] -> 
             RGBColor[
              0.4296132686116584, 0.545245204928905, 0.9489508667899835], 
             UndirectedEdge[227, 320] -> 
             RGBColor[
              0.9171168323829694, 0.670650788557899, 0.5149397016540836], 
             UndirectedEdge[298, 432] -> 
             RGBColor[
              0.9001321413614187, 0.9232049523582542, 0.9903366012721426], 
             UndirectedEdge[42, 85] -> 
             RGBColor[
              0.22334491181980198`, 0.3520800415808806, 0.9360305343677259], 
             UndirectedEdge[329, 413] -> 
             RGBColor[
              0.9281969547806851, 0.9162983140279535, 0.6707593407043844], 
             UndirectedEdge[244, 380] -> 
             RGBColor[
              0.3076460451816098, 0.43757054210239044`, 0.9409454268990441], 
             UndirectedEdge[87, 113] -> 
             RGBColor[
              0.17922276129889142`, 0.3057048638774843, 0.9335178431684322], 
             UndirectedEdge[334, 370] -> 
             RGBColor[
              0.49712370807879736`, 0.6012548758448955, 0.9539335150694623], 
             UndirectedEdge[24, 278] -> 
             RGBColor[
              0.8926678774514412, 0.9169265621366819, 0.9783016146877055], 
             UndirectedEdge[51, 325] -> 
             RGBColor[
              0.17897196058988912`, 0.30544125643063946`, 0.933503560439081], 
             UndirectedEdge[112, 463] -> 
             RGBColor[
              0.2576804433404335, 0.3881688622075002, 0.9379858920929589], 
             UndirectedEdge[308, 421] -> 
             RGBColor[
              0.1790014452743907, 0.3054722467034876, 0.9335052395482446], 
             UndirectedEdge[302, 421] -> 
             RGBColor[
              0.18460298206136966`, 0.31135981702454774`, 0.9338242387815321],
              UndirectedEdge[103, 488] -> 
             RGBColor[
              0.6248600030483947, 0.70438296673246, 0.9649406043243738], 
             UndirectedEdge[225, 424] -> 
             RGBColor[
              0.2974218624617132, 0.42884414496049433`, 0.940289217587641], 
             UndirectedEdge[205, 388] -> 
             RGBColor[
              0.9699993320336204, 0.9742898944709728, 0.7727192137216462], 
             UndirectedEdge[114, 297] -> 
             RGBColor[
              0.5100213466264654, 0.6130973312480197, 0.954569895157638], 
             UndirectedEdge[203, 381] -> 
             RGBColor[
              0.5519357188644908, 0.6471253068518, 0.9578695480776199], 
             UndirectedEdge[17, 252] -> 
             RGBColor[
              0.8078836333626171, 0.8503289562761027, 0.9813572830192461], 
             UndirectedEdge[361, 363] -> 
             RGBColor[
              0.5245064025228867, 0.6235116591529769, 0.9560934187929221], 
             UndirectedEdge[318, 383] -> 
             RGBColor[
              0.3354424216880899, 0.46496509866505487`, 0.9425950723832464], 
             UndirectedEdge[209, 273] -> 
             RGBColor[
              0.4297324939516893, 0.5421711471050089, 0.9494994222745707], 
             UndirectedEdge[47, 230] -> 
             RGBColor[
              0.22790583767600858`, 0.3568738638351552, 0.9362902723479516], 
             UndirectedEdge[1, 170] -> 
             RGBColor[
              0.2814230291570491, 0.41312382526764985`, 0.939337997231207], 
             UndirectedEdge[139, 247] -> 
             RGBColor[
              0.529523280699882, 0.6289298798809373, 0.9561051588458358], 
             UndirectedEdge[246, 288] -> 
             RGBColor[
              0.2751436592994766, 0.40652380941229693`, 0.9389803964073136], 
             UndirectedEdge[1, 147] -> 
             RGBColor[
              0.2588293294875211, 0.38937641439167825`, 0.9380513194594108], 
             UndirectedEdge[352, 457] -> 
             RGBColor[
              0.22470998276050042`, 0.3535148176900512, 0.9361082731383572], 
             UndirectedEdge[157, 238] -> 
             RGBColor[
              0.31134876495031627`, 0.4435229307952213, 0.9410808428186908], 
             UndirectedEdge[97, 145] -> 
             RGBColor[
              0.2261963371710197, 0.3550770704158197, 0.9361929188231719], 
             UndirectedEdge[83, 237] -> 
             RGBColor[
              0.913419047498675, 0.933799570648643, 0.9916039182408752], 
             UndirectedEdge[73, 494] -> 
             RGBColor[
              0.25320700081228975`, 0.383466990477783, 0.9377311361588463], 
             UndirectedEdge[101, 197] -> 
             RGBColor[
              0.6092291752169602, 0.6927921015850171, 0.9629587335694303], 
             UndirectedEdge[224, 356] -> 
             RGBColor[
              0.28415211148803254`, 0.41599226383132715`, 0.939493414432641], 
             UndirectedEdge[182, 441] -> 
             RGBColor[
              0.41435953118072005`, 0.5333191324183171, 0.9476236008164568], 
             UndirectedEdge[160, 480] -> 
             RGBColor[
              0.3880144919727734, 0.5105003835965654, 0.94594491821413], 
             UndirectedEdge[263, 440] -> 
             RGBColor[
              0.2775372454156354, 0.40903962018250506`, 0.9391167075956355], 
             UndirectedEdge[31, 223] -> 
             RGBColor[
              0.42145102378698707`, 0.5394614268850837, 0.9480754644545675], 
             UndirectedEdge[5, 102] -> 
             RGBColor[
              0.2575724490549457, 0.3880553533662194, 0.9379797419781635], 
             UndirectedEdge[171, 216] -> 
             RGBColor[
              0.26381410331866717`, 0.39461572774112796`, 0.9383351949547825],
              UndirectedEdge[102, 414] -> 
             RGBColor[
              0.27559776236137046`, 0.40700110052214455`, 0.9390062569049031],
              UndirectedEdge[68, 205] -> 
             RGBColor[
              0.9069065109079608, 0.5719171126049378, 0.3681050087560027], 
             UndirectedEdge[111, 376] -> 
             RGBColor[
              0.2762731715166523, 0.4077109983677596, 0.9390447204571181], 
             UndirectedEdge[302, 325] -> 
             RGBColor[
              0.18458313935535953`, 0.31133896108243087`, 0.9338231087687794],
              UndirectedEdge[39, 315] -> 
             RGBColor[
              0.40458060190845924`, 0.5088289173445842, 0.948695685987052], 
             UndirectedEdge[66, 314] -> 
             RGBColor[
              0.29667827269945046`, 0.4271859979700665, 0.9402789673950056], 
             UndirectedEdge[274, 370] -> 
             RGBColor[
              0.5270887992770681, 0.6269534581897589, 0.9559135075504326], 
             UndirectedEdge[94, 477] -> 
             RGBColor[
              0.6000453532177727, 0.6703839872576882, 0.948796554675374], 
             UndirectedEdge[99, 329] -> 
             RGBColor[
              0.9380897089070905, 0.9489785735157732, 0.7678909167681753], 
             UndirectedEdge[25, 465] -> 
             RGBColor[
              0.2980004320712376, 0.430119718051609, 0.9402977272999771], 
             UndirectedEdge[223, 381] -> 
             RGBColor[
              0.47958429341648956`, 0.5866642295649169, 0.9526498297239985], 
             UndirectedEdge[196, 318] -> 
             RGBColor[
              0.3188208288656592, 0.44936205704600285`, 0.9415801260303202], 
             UndirectedEdge[76, 462] -> 
             RGBColor[
              0.4376018334802528, 0.5531637078002476, 0.949183806517649], 
             UndirectedEdge[89, 440] -> 
             RGBColor[
              0.2835877779164691, 0.415399113466799, 0.9394612764705972], 
             UndirectedEdge[88, 326] -> 
             RGBColor[
              0.8708928189630238, 0.5066362693068722, 0.21398214224720047`], 
             UndirectedEdge[149, 282] -> 
             RGBColor[
              0.48076658116172494`, 0.586646877963116, 0.9530129031646457], 
             UndirectedEdge[238, 462] -> 
             RGBColor[
              0.392016142899485, 0.5136796738226148, 0.9462791266236859], 
             UndirectedEdge[168, 261] -> 
             RGBColor[
              0.8953895182633258, 0.6159789489289689, 0.23432496342308617`], 
             UndirectedEdge[155, 344] -> 
             RGBColor[
              0.5148160505883743, 0.6169898879232494, 0.9549473518170989], 
             UndirectedEdge[4, 496] -> 
             RGBColor[
              0.3005965950412318, 0.4318380479282125, 0.9404825707076422], 
             UndirectedEdge[87, 226] -> 
             RGBColor[
              0.17933912709972993`, 0.30582717171218354`, 0.9335244700286423],
              UndirectedEdge[128, 362] -> 
             RGBColor[
              0.4416023765346493, 0.55579072415724, 0.9496702741143528], 
             UndirectedEdge[295, 389] -> 
             RGBColor[
              0.22404383278435813`, 0.3528146518287777, 0.9360703368826964], 
             UndirectedEdge[89, 133] -> 
             RGBColor[
              0.3153376912434113, 0.4454022988525135, 0.9413927055520241], 
             UndirectedEdge[33, 164] -> 
             RGBColor[
              0.8479694807729221, 0.33824875648589925`, 0.19233659900141542`],
              UndirectedEdge[276, 396] -> 
             RGBColor[
              0.8065431088390325, 0.8453068187334528, 0.7510492031181083], 
             UndirectedEdge[50, 274] -> 
             RGBColor[
              0.4518361438965558, 0.5655238171616463, 0.9500822208063486], 
             UndirectedEdge[21, 375] -> 
             RGBColor[
              0.9695446020803578, 0.9577696846543478, 0.6679456249234423], 
             UndirectedEdge[41, 485] -> 
             RGBColor[
              0.24026393309017596`, 0.36986300566395003`, 0.9369940475996247],
              UndirectedEdge[30, 316] -> 
             RGBColor[
              0.25921313179459604`, 0.3897798149508858, 0.938073176433014], 
             UndirectedEdge[285, 324] -> 
             RGBColor[
              0.3420478957119857, 0.4706864282637755, 0.9430159673470576], 
             UndirectedEdge[95, 358] -> 
             RGBColor[
              0.2263545662938538, 0.3552433792562242, 0.9362019297376383], 
             UndirectedEdge[333, 492] -> 
             RGBColor[
              0.32763422405457243`, 0.45523169861929097`, 0.9422062993288807],
              UndirectedEdge[332, 393] -> 
             RGBColor[
              0.4317017689879543, 0.548125780545763, 0.9487878519566961], 
             UndirectedEdge[418, 420] -> 
             RGBColor[
              0.9735581601714495, 0.9798002996671817, 0.9296433170801228], 
             UndirectedEdge[107, 273] -> 
             RGBColor[
              0.2391065540897807, 0.3686465269524677, 0.9369281365777409], 
             UndirectedEdge[310, 483] -> 
             RGBColor[
              0.2967031212326041, 0.4291841708528518, 0.9402081758700394], 
             UndirectedEdge[155, 403] -> 
             RGBColor[
              0.7474005481861847, 0.8023032590432388, 0.9760248292713649], 
             UndirectedEdge[140, 169] -> 
             RGBColor[
              0.4961881243257401, 0.601866898204728, 0.953480893225362], 
             UndirectedEdge[147, 216] -> 
             RGBColor[
              0.2586895754643985, 0.38922952405245953`, 0.9380433606745415], 
             UndirectedEdge[70, 171] -> 
             RGBColor[
              0.25999619432080096`, 0.39060286331495886`, 0.9381177706854442],
              UndirectedEdge[7, 402] -> 
             RGBColor[
              0.6954966701641224, 0.7608182646923372, 0.971187276045136], 
             UndirectedEdge[185, 409] -> 
             RGBColor[
              0.262750205623448, 0.39349750380844273`, 0.9382746075549353], 
             UndirectedEdge[126, 481] -> 
             RGBColor[
              0.28467725623571494`, 0.41566859359098884`, 0.9395553817772139],
              UndirectedEdge[115, 311] -> 
             RGBColor[
              0.8340126241816578, 0.871074103507641, 0.9838732137113628], 
             UndirectedEdge[383, 496] -> 
             RGBColor[
              0.30291603178424115`, 0.4338470274567268, 0.9406303631659094], 
             UndirectedEdge[8, 297] -> 
             RGBColor[
              0.5698289191235334, 0.6616518129015765, 0.9592781663469641], 
             UndirectedEdge[381, 439] -> 
             RGBColor[
              0.7151086431122187, 0.7765792866784462, 0.9729163506443089], 
             UndirectedEdge[16, 276] -> 
             RGBColor[
              0.5117111188744836, 0.6131268633886855, 0.9550738020104051], 
             UndirectedEdge[74, 342] -> 
             RGBColor[
              0.27086057814160247`, 0.4020220195523411, 0.9387364812716233], 
             UndirectedEdge[26, 269] -> 
             RGBColor[
              0.4177844388725415, 0.5362856153201071, 0.9478418329060527], 
             UndirectedEdge[127, 315] -> 
             RGBColor[
              0.20573971378665917`, 0.3335758622140216, 0.9350279443842948], 
             UndirectedEdge[175, 348] -> 
             RGBColor[
              0.9578209370783626, 0.9214694359811255, 0.6292929486935749], 
             UndirectedEdge[180, 288] -> 
             RGBColor[
              0.2630984263915931, 0.39386350591423513`, 0.9382944382125347], 
             UndirectedEdge[288, 343] -> 
             RGBColor[
              0.274476709135814, 0.40582280250320485`, 0.9389424145821572], 
             UndirectedEdge[484, 500] -> 
             RGBColor[
              0.9061921804601966, 0.5690195539734165, 0.316991474169404], 
             UndirectedEdge[59, 323] -> 
             RGBColor[
              0.24076788547771533`, 0.3703926915756808, 0.9370227469425643], 
             UndirectedEdge[108, 189] -> 
             RGBColor[
              0.27244302962866296`, 0.40368527639846097`, 0.9388265995427842],
              UndirectedEdge[59, 74] -> 
             RGBColor[
              0.26196255890659237`, 0.3926696371693413, 0.9382297522396293], 
             UndirectedEdge[40, 199] -> 
             RGBColor[
              0.3645220176644419, 0.4901523831167798, 0.9444479985247825], 
             UndirectedEdge[69, 241] -> 
             RGBColor[
              0.8074723242442312, 0.8502460052781141, 0.9812530323476005], 
             UndirectedEdge[275, 353] -> 
             RGBColor[
              0.5266832510882068, 0.6255486018899017, 0.9561787766673014], 
             UndirectedEdge[196, 335] -> 
             RGBColor[
              0.2862357534512077, 0.4181823036451551, 0.9396120747599719], 
             UndirectedEdge[157, 281] -> 
             RGBColor[
              0.2737261355645935, 0.4050339020907391, 0.9388996705276503], 
             UndirectedEdge[120, 438] -> 
             RGBColor[
              0.21444303080234048`, 0.3427236002196732, 0.9355235854129342], 
             UndirectedEdge[152, 389] -> 
             RGBColor[
              0.21125135912011495`, 0.33936895091798147`, 0.9353418244322866],
              UndirectedEdge[126, 144] -> 
             RGBColor[
              0.24868278916139275`, 0.37871175718110384`, 0.937473488998299], 
             UndirectedEdge[96, 157] -> 
             RGBColor[
              0.29935267191603787`, 0.43196901661235676`, 0.940359063861802], 
             UndirectedEdge[303, 366] -> 
             RGBColor[
              0.2851324087513453, 0.4170226184095053, 0.9395492409115669], 
             UndirectedEdge[119, 309] -> 
             RGBColor[
              0.9918390696706652, 0.9889511495464178, 0.6437403499501158], 
             UndirectedEdge[325, 386] -> 
             RGBColor[
              0.1789719601845752, 0.3054412560046289, 0.9335035604159989], 
             UndirectedEdge[27, 220] -> 
             RGBColor[
              0.4255160611016982, 0.5413857751468245, 0.948775625607305], 
             UndirectedEdge[95, 346] -> 
             RGBColor[
              0.22248278830370904`, 0.3511738951036789, 0.9359814377088818], 
             UndirectedEdge[235, 239] -> 
             RGBColor[
              0.35398612023304477`, 0.4810267183113057, 0.943776660456982], 
             UndirectedEdge[64, 303] -> 
             RGBColor[
              0.29654648477504475`, 0.4290195360046319, 0.9401992556555043], 
             UndirectedEdge[310, 429] -> 
             RGBColor[
              0.2951775190785565, 0.4275806662601843, 0.9401212950842925], 
             UndirectedEdge[67, 238] -> 
             RGBColor[
              0.28838849579729153`, 0.41939023215024707`, 0.9397732894571003],
              UndirectedEdge[38, 108] -> 
             RGBColor[
              0.272539685244709, 0.40378686757924537`, 0.9388321039371288], 
             UndirectedEdge[20, 490] -> 
             RGBColor[
              0.9375437932423437, 0.7794697399272263, 0.5157901036631747], 
             UndirectedEdge[112, 148] -> 
             RGBColor[
              0.2439596839808273, 0.373747474174165, 0.9372045151454738], 
             UndirectedEdge[76, 402] -> 
             RGBColor[
              0.4818182674522101, 0.589060600826333, 0.952664686170056], 
             UndirectedEdge[99, 406] -> 
             RGBColor[
              0.992119957252125, 0.9843905837590278, 0.48258804562862445`], 
             UndirectedEdge[8, 258] -> 
             RGBColor[
              0.4968580357130886, 0.6002414107444907, 0.9541330294430466], 
             UndirectedEdge[15, 153] -> 
             RGBColor[
              0.23958587882071014`, 0.3691503276356177, 0.93695543341207], 
             UndirectedEdge[195, 463] -> 
             RGBColor[
              0.2686246431474216, 0.3996719101069903, 0.9386091480814742], 
             UndirectedEdge[184, 249] -> 
             RGBColor[
              0.2732898707787555, 0.40457536014003825`, 0.9388748258934928], 
             UndirectedEdge[109, 185] -> 
             RGBColor[
              0.26895237692670115`, 0.40001637908853493`, 0.9386278120353654],
              UndirectedEdge[77, 81] -> 
             RGBColor[
              0.7152180111578499, 0.7769379420233913, 0.972614350327299], 
             UndirectedEdge[355, 384] -> 
             RGBColor[
              0.3062638013444511, 0.43738753923394075`, 0.9408202157153518], 
             UndirectedEdge[67, 343] -> 
             RGBColor[
              0.2747552896997584, 0.40611560833893834`, 0.9389582793331509], 
             UndirectedEdge[247, 255] -> 
             RGBColor[
              0.4462984536881862, 0.5598509487377481, 0.9499715158755377], 
             UndirectedEdge[95, 145] -> 
             RGBColor[
              0.22387054333517215`, 0.3526325136304976, 0.9360604683049241], 
             UndirectedEdge[220, 416] -> 
             RGBColor[
              0.3002234451567067, 0.4300950902197503, 0.9405107780769688], 
             UndirectedEdge[287, 451] -> 
             RGBColor[
              0.21062876698303812`, 0.3387145671072923, 0.9353063687311225], 
             UndirectedEdge[387, 491] -> 
             RGBColor[
              0.8846376192086578, 0.9070821410302499, 0.7920529218334498], 
             UndirectedEdge[211, 464] -> 
             RGBColor[
              0.23745358448324252`, 0.36690915109166977`, 0.936834002403998], 
             UndirectedEdge[335, 482] -> 
             RGBColor[
              0.3176268052914761, 0.44657790833086347`, 0.9415681179813948], 
             UndirectedEdge[214, 423] -> 
             RGBColor[
              0.19381650316255092`, 0.32104381187286724`, 0.9343489351780614],
              UndirectedEdge[69, 194] -> 
             RGBColor[
              0.9479892988678673, 0.9596684021789683, 0.9321766809000795], 
             UndirectedEdge[111, 312] -> 
             RGBColor[
              0.28875139009156847`, 0.4208263972547496, 0.9397553365450895], 
             UndirectedEdge[174, 294] -> 
             RGBColor[
              0.2524849252558091, 0.3827080432856873, 0.9376900150241196], 
             UndirectedEdge[212, 295] -> 
             RGBColor[
              0.22405206726645135`, 0.35282330679155405`, 0.9360708058242697],
              UndirectedEdge[193, 414] -> 
             RGBColor[
              0.28123484292780576`, 0.41292602960901903`, 0.9393272803038482],
              UndirectedEdge[320, 348] -> 
             RGBColor[
              0.9742570536765062, 0.9329947209284535, 0.5686571215977747], 
             UndirectedEdge[247, 468] -> 
             RGBColor[
              0.48669420259584584`, 0.5941593048480999, 0.9527334969294036], 
             UndirectedEdge[449, 488] -> 
             RGBColor[
              0.7488335383665432, 0.8037137186084069, 0.9756003869232444], 
             UndirectedEdge[290, 355] -> 
             RGBColor[
              0.30759602149261944`, 0.4387877870773017, 0.9408960836819469], 
             UndirectedEdge[88, 469] -> 
             RGBColor[
              0.8635204022958338, 0.47315984709282155`, 0.20783041706562805`],
              UndirectedEdge[6, 278] -> 
             RGBColor[
              0.8880267801577246, 0.9132258771339024, 0.9778589426846744], 
             UndirectedEdge[24, 448] -> 
             RGBColor[
              0.7024556642269519, 0.7664802639694746, 0.97172087084446], 
             UndirectedEdge[204, 274] -> 
             RGBColor[
              0.4823136561574142, 0.5906029799080129, 0.9523886442672999], 
             UndirectedEdge[81, 99] -> 
             RGBColor[
              0.9086198401868935, 0.9254801001365643, 0.7650800543815806], 
             UndirectedEdge[213, 368] -> 
             RGBColor[
              0.6561537738248766, 0.5929010247462924, 0.5945021229284573], 
             UndirectedEdge[167, 474] -> 
             RGBColor[
              0.9898837045140847, 0.9900846660867081, 0.8173167265425048], 
             UndirectedEdge[78, 430] -> 
             RGBColor[
              0.22958406238534357`, 0.3586377844102586, 0.9363858447624374], 
             UndirectedEdge[110, 316] -> 
             RGBColor[
              0.26110517012024004`, 0.39176846719329617`, 0.9381809252166395],
              UndirectedEdge[153, 463] -> 
             RGBColor[
              0.25601516257071727`, 0.38641854653362934`, 0.9378910568166856],
              UndirectedEdge[471, 475] -> 
             RGBColor[
              0.847907987036376, 0.36924735854117574`, 0.19351004853135326`], 
             UndirectedEdge[79, 486] -> 
             RGBColor[
              0.9643781566417168, 0.9700792377693064, 0.7816636594414414], 
             UndirectedEdge[49, 402] -> 
             RGBColor[
              0.521262974366249, 0.6222237910767345, 0.9554548772727531], 
             UndirectedEdge[340, 498] -> 
             RGBColor[
              0.39966203669691347`, 0.5203561647804322, 0.9467513952897255], 
             UndirectedEdge[248, 313] -> 
             RGBColor[
              0.254748775686199, 0.38508749362443473`, 0.9378189379570638], 
             UndirectedEdge[37, 429] -> 
             RGBColor[
              0.29961908302642226`, 0.4322490315808106, 0.9403742355804184], 
             UndirectedEdge[18, 166] -> 
             RGBColor[
              0.8612521660936727, 0.43095598829613885`, 0.2046884517082866], 
             UndirectedEdge[147, 238] -> 
             RGBColor[
              0.2858235449724231, 0.4166943062060351, 0.9396272193021288], 
             UndirectedEdge[165, 441] -> 
             RGBColor[
              0.4370828286560343, 0.553000910585295, 0.9490715092381609], 
             UndirectedEdge[13, 154] -> 
             RGBColor[
              0.3030787322552839, 0.435811820273263, 0.9405739494865415], 
             UndirectedEdge[133, 249] -> 
             RGBColor[
              0.3173607671926588, 0.44752867994559636`, 0.9415079167344612], 
             UndirectedEdge[84, 385] -> 
             RGBColor[
              0.2333929402174702, 0.3626411565086264, 0.9366027547202471], 
             UndirectedEdge[125, 438] -> 
             RGBColor[
              0.2150690714922951, 0.34338160867808776`, 0.9355592375040829], 
             UndirectedEdge[21, 489] -> 
             RGBColor[
              0.9854926800563032, 0.9686826013172827, 0.5970125136401502], 
             UndirectedEdge[16, 200] -> 
             RGBColor[
              0.6523550443789783, 0.5834045301394526, 0.5929583920999518], 
             UndirectedEdge[402, 436] -> 
             RGBColor[
              0.5126155235296384, 0.6152034009243532, 0.954774118266239], 
             UndirectedEdge[127, 401] -> 
             RGBColor[
              0.499716094491864, 0.5888978154955886, 0.9571173753725956], 
             UndirectedEdge[195, 395] -> 
             RGBColor[
              0.26756974901772024`, 0.3985631494925233, 0.9385490734213637], 
             UndirectedEdge[27, 297] -> 
             RGBColor[
              0.5157415629468824, 0.6177412605497428, 0.9550202115402241], 
             UndirectedEdge[35, 70] -> 
             RGBColor[
              0.24831129577393707`, 0.37832129407684667`, 0.9374523329994586],
              UndirectedEdge[240, 367] -> 
             RGBColor[
              0.24323530728920995`, 0.3729861083431402, 0.9371632629645055], 
             UndirectedEdge[121, 471] -> 
             RGBColor[
              0.842139262249025, 0.3249064119542755, 0.18798591116014318`], 
             UndirectedEdge[184, 424] -> 
             RGBColor[
              0.28881315240835653`, 0.41979584487067384`, 0.9397989642855475],
              UndirectedEdge[122, 159] -> 
             RGBColor[
              0.8441272348319537, 0.3258751275198433, 0.1893291851678579], 
             UndirectedEdge[158, 324] -> 
             RGBColor[
              0.3635993901479788, 0.48935324953462667`, 0.9443892095152808], 
             UndirectedEdge[180, 465] -> 
             RGBColor[
              0.27637826248324115`, 0.40782145563679656`, 0.9390507052321971],
              UndirectedEdge[254, 454] -> 
             RGBColor[
              0.568190337821955, 0.5020881692235942, 0.5874756893040098], 
             UndirectedEdge[297, 314] -> 
             RGBColor[
              0.42471984107439154`, 0.540499402694099, 0.9487792473402418], 
             UndirectedEdge[262, 393] -> 
             RGBColor[
              0.46864864929250694`, 0.5795091117335374, 0.951312884870325], 
             UndirectedEdge[201, 333] -> 
             RGBColor[
              0.34155395478950024`, 0.4698622181836031, 0.9429990074018386], 
             UndirectedEdge[219, 340] -> 
             RGBColor[
              0.43185173064895377`, 0.5464892084598855, 0.9492854859123644], 
             UndirectedEdge[361, 370] -> 
             RGBColor[
              0.6178223925754994, 0.7005868527844641, 0.9630756852495326], 
             UndirectedEdge[48, 358] -> 
             RGBColor[
              0.2165685446684143, 0.3449576500582796, 0.9356446302831911], 
             UndirectedEdge[287, 299] -> 
             RGBColor[
              0.2094890463187735, 0.33751664842668644`, 0.9352414633253583], 
             UndirectedEdge[62, 233] -> 
             RGBColor[
              0.8302393984490122, 0.2334388442338099, 0.17659058814627704`], 
             UndirectedEdge[61, 91] -> 
             RGBColor[
              0.32572776888358806`, 0.4565507546784424, 0.9419760632968737], 
             UndirectedEdge[204, 340] -> 
             RGBColor[
              0.4196638066192008, 0.5365945026728116, 0.9483260078869054], 
             UndirectedEdge[258, 373] -> 
             RGBColor[
              0.3335189671806654, 0.461900180189882, 0.9425237328349862], 
             UndirectedEdge[167, 210] -> 
             RGBColor[
              0.9113669843928855, 0.6334814540290358, 0.5263699322609554], 
             UndirectedEdge[275, 481] -> 
             RGBColor[
              0.36596032955819924`, 0.49139817658749463`, 0.9445396464868034],
              UndirectedEdge[253, 277] -> 
             RGBColor[
              0.8781666893011308, 0.9046720920391318, 0.9377821758000617], 
             UndirectedEdge[193, 485] -> 
             RGBColor[
              0.2679064543585755, 0.3989170481541139, 0.9385682482924145], 
             UndirectedEdge[89, 260] -> 
             RGBColor[
              0.2855390731059485, 0.4174500484302025, 0.9395723998449554], 
             UndirectedEdge[359, 397] -> 
             RGBColor[
              0.3719996579907838, 0.4966291393303264, 0.9449244671541592], 
             UndirectedEdge[1, 171] -> 
             RGBColor[
              0.2639538573417897, 0.3947626180803467, 0.9383431537396518], 
             UndirectedEdge[193, 330] -> 
             RGBColor[
              0.2971306356015508, 0.42963351556059126`, 0.9402325221809], 
             UndirectedEdge[92, 320] -> 
             RGBColor[
              0.7988700431185324, 0.8415596078670635, 0.9004611644475569], 
             UndirectedEdge[126, 279] -> 
             RGBColor[
              0.26484901945855754`, 0.3957034902216259, 0.9383941318979281], 
             UndirectedEdge[93, 163] -> 
             RGBColor[
              0.26813879509029465`, 0.39916125299440397`, 0.9385814797533685],
              UndirectedEdge[31, 297] -> 
             RGBColor[
              0.48620123605795307`, 0.5937514968840982, 0.9526967874627315], 
             UndirectedEdge[127, 325] -> 
             RGBColor[
              0.20249836583685807`, 0.33016900000545074`, 0.9348433544136983],
              UndirectedEdge[334, 498] -> 
             RGBColor[
              0.4323467950368561, 0.5486660596707702, 0.9488340391891498], 
             UndirectedEdge[41, 300] -> 
             RGBColor[
              0.22924216126039493`, 0.3582784246501542, 0.9363663739991688], 
             UndirectedEdge[330, 496] -> 
             RGBColor[
              0.2916695481926115, 0.42389356644085574`, 0.9399215213319159], 
             UndirectedEdge[18, 227] -> 
             RGBColor[
              0.8650075437066738, 0.45982146624662823`, 0.2082846055515888], 
             UndirectedEdge[156, 350] -> 
             RGBColor[
              0.41473957912155346`, 0.5332684178987681, 0.9477527826875395], 
             UndirectedEdge[315, 386] -> 
             RGBColor[
              0.1822133081343763, 0.30884811821319974`, 0.9336881503865955], 
             UndirectedEdge[29, 479] -> 
             RGBColor[
              0.410555492074131, 0.5300242649407545, 0.9473812108083647], 
             UndirectedEdge[277, 488] -> 
             RGBColor[
              0.7703329161501223, 0.8205091959342619, 0.9777432439776033], 
             UndirectedEdge[242, 374] -> 
             RGBColor[
              0.2383689744042093, 0.367871283937679, 0.936886132505799], 
             UndirectedEdge[244, 363] -> 
             RGBColor[
              0.37362619317772217`, 0.49803796235721676`, 0.9450281085379824],
              UndirectedEdge[335, 409] -> 
             RGBColor[
              0.25916391695491414`, 0.389728087033979, 0.938070373720701], 
             UndirectedEdge[235, 332] -> 
             RGBColor[
              0.37961688858367837`, 0.50322680161675, 0.9454098303518859], 
             UndirectedEdge[249, 440] -> 
             RGBColor[
              0.2856108538657166, 0.41752549455988186`, 0.9395764876530341], 
             UndirectedEdge[96, 265] -> 
             RGBColor[
              0.3085881199169248, 0.4405417508695841, 0.9409265415042412], 
             UndirectedEdge[39, 200] -> 
             RGBColor[
              0.7622447974505207, 0.6739602832535388, 0.6012384342096092], 
             UndirectedEdge[146, 312] -> 
             RGBColor[
              0.28117238396624933`, 0.41286038128029634`, 0.9393237233583873],
              UndirectedEdge[237, 448] -> 
             RGBColor[
              0.7370158535300309, 0.7940376208084021, 0.9750172525524329], 
             UndirectedEdge[31, 162] -> 
             RGBColor[
              0.4575348398128734, 0.5704788250059085, 0.9504400637418493], 
             UndirectedEdge[41, 102] -> 
             RGBColor[
              0.2545321161274702, 0.38485977069120125`, 0.9378065995157133], 
             UndirectedEdge[266, 374] -> 
             RGBColor[
              0.27062553266643685`, 0.40177497185519817`, 0.9387230957795312],
              UndirectedEdge[44, 139] -> 
             RGBColor[
              0.5303562146824653, 0.6296060932112468, 0.9561707304600824], 
             UndirectedEdge[47, 189] -> 
             RGBColor[
              0.24585450838109163`, 0.3757390547576487, 0.9373124225919274], 
             UndirectedEdge[208, 359] -> 
             RGBColor[
              0.3537848938552699, 0.480852426136809, 0.9437638384901277], 
             UndirectedEdge[122, 413] -> 
             RGBColor[
              0.9206701650068785, 0.7073273642826143, 0.2820065056616069], 
             UndirectedEdge[36, 141] -> 
             RGBColor[
              0.28198608489330845`, 0.4136382572421074, 0.9393728955113378], 
             UndirectedEdge[179, 347] -> 
             RGBColor[
              0.17892806853100302`, 0.30539512309383293`, 0.93350106085126], 
             UndirectedEdge[226, 422] -> 
             RGBColor[
              0.20671849831186667`, 0.3346046268085379, 0.9350836847150235], 
             UndirectedEdge[18, 167] -> 
             RGBColor[
              0.9355270875213144, 0.7783260157628717, 0.5479056765432442], 
             UndirectedEdge[112, 452] -> 
             RGBColor[
              0.2361084750925497, 0.3654953558371904, 0.936757400414109], 
             UndirectedEdge[323, 342] -> 
             RGBColor[
              0.2496659047127254, 0.3797450739586806, 0.9375294759745583], 
             UndirectedEdge[74, 82] -> 
             RGBColor[
              0.27000631808527487`, 0.401124138069925, 0.93868783242518], 
             UndirectedEdge[291, 349] -> 
             RGBColor[
              0.5342643053360183, 0.6315079324719315, 0.9569079863163146], 
             UndirectedEdge[86, 136] -> 
             RGBColor[
              0.942076876818933, 0.8389236960734718, 0.594023128493258], 
             UndirectedEdge[11, 23] -> 
             RGBColor[
              0.23070981980428998`, 0.3598210268347142, 0.9364499549820375], 
             UndirectedEdge[249, 470] -> 
             RGBColor[
              0.27251498804399493`, 0.40376090925540187`, 0.9388306974680845],
              UndirectedEdge[35, 135] -> 
             RGBColor[
              0.24449959825218992`, 0.3743149583059091, 0.9372352624644963], 
             UndirectedEdge[161, 326] -> 
             RGBColor[
              0.9327537347132191, 0.7525662704764362, 0.31724881897839763`], 
             UndirectedEdge[26, 139] -> 
             RGBColor[
              0.4753323584108449, 0.5831244997687381, 0.952339366037344], 
             UndirectedEdge[109, 218] -> 
             RGBColor[
              0.24296647092511459`, 0.372703544279266, 0.937147953131278], 
             UndirectedEdge[238, 465] -> 
             RGBColor[
              0.30138975132499524`, 0.433055376037075, 0.940513691725769], 
             UndirectedEdge[258, 314] -> 
             RGBColor[
              0.35174895766394676`, 0.47908900053701325`, 0.9436341104363243],
              UndirectedEdge[28, 493] -> 
             RGBColor[
              0.9792166674892435, 0.9809905167708368, 0.7433381739278018], 
             UndirectedEdge[106, 466] -> 
             RGBColor[
              0.5106817556791221, 0.6136334810680553, 0.9546218849774213], 
             UndirectedEdge[45, 236] -> 
             RGBColor[
              0.285052814306115, 0.4169389596009889, 0.9395447081256605], 
             UndirectedEdge[157, 246] -> 
             RGBColor[
              0.2983825090164457, 0.4309493138930047, 0.9403038145198976], 
             UndirectedEdge[371, 427] -> 
             RGBColor[
              0.3212220231725497, 0.4499441234823203, 0.9417879671446181], 
             UndirectedEdge[341, 450] -> 
             RGBColor[
              0.9056409272943111, 0.562891578052587, 0.35323513131972123`], 
             UndirectedEdge[277, 484] -> 
             RGBColor[
              0.8820966152149525, 0.9042351364524142, 0.7227616167031183], 
             UndirectedEdge[84, 135] -> 
             RGBColor[
              0.24197053087649611`, 0.37165674814192173`, 0.9370912358188704],
              UndirectedEdge[35, 84] -> 
             RGBColor[
              0.2358433607180927, 0.36521670382041393`, 0.9367423025426853], 
             UndirectedEdge[68, 272] -> 
             RGBColor[
              0.8202846954174998, 0.15692263455492186`, 0.1670579532810717], 
             UndirectedEdge[164, 227] -> 
             RGBColor[
              0.8315779382096691, 0.24372744738608088`, 0.17787237533274636`],
              UndirectedEdge[355, 498] -> 
             RGBColor[
              0.3952981571338905, 0.516576391637906, 0.946473332742797], 
             UndirectedEdge[223, 373] -> 
             RGBColor[
              0.3417396383201442, 0.4690205123479532, 0.9430475467307398], 
             UndirectedEdge[116, 192] -> 
             RGBColor[
              0.2516702940273803, 0.3818518142140055, 0.9376436229807996], 
             UndirectedEdge[3, 31] -> 
             RGBColor[
              0.4573521482388232, 0.5703305077559329, 0.9504256815919188], 
             UndirectedEdge[40, 419] -> 
             RGBColor[
              0.44944534633244004`, 0.5620965984995714, 0.950304666943798], 
             UndirectedEdge[282, 324] -> 
             RGBColor[
              0.48866791978392093`, 0.5934906203448358, 0.9535163694747727], 
             UndirectedEdge[250, 339] -> 
             RGBColor[
              0.20806801028262886`, 0.33602304945380984`, 0.9351605374253343],
              UndirectedEdge[259, 405] -> 
             RGBColor[
              0.9279266912954685, 0.7275673838799486, 0.39806227602736116`], 
             UndirectedEdge[22, 441] -> 
             RGBColor[
              0.45077446449645514`, 0.564859917388641, 0.9499439281668742], 
             UndirectedEdge[142, 241] -> 
             RGBColor[
              0.7025032226254809, 0.7675201238280478, 0.9709826140315919], 
             UndirectedEdge[170, 266] -> 
             RGBColor[
              0.29310065604108804`, 0.425397751527083, 0.9400030208067522], 
             UndirectedEdge[105, 153] -> 
             RGBColor[
              0.24541911730613436`, 0.37528143113248, 0.9372876277143118], 
             UndirectedEdge[95, 404] -> 
             RGBColor[
              0.22026561376472564`, 0.3488435040862222, 0.9358551728989024], 
             UndirectedEdge[200, 454] -> 
             RGBColor[
              0.9003552167733437, 0.640418136645701, 0.2385662891695866], 
             UndirectedEdge[96, 131] -> 
             RGBColor[
              0.2798853921380307, 0.4115076712688437, 0.9392504310777041], 
             UndirectedEdge[190, 395] -> 
             RGBColor[
              0.2565485956338361, 0.38697921850457684`, 0.9379214350404868], 
             UndirectedEdge[297, 381] -> 
             RGBColor[
              0.5443345056874556, 0.6409542995639315, 0.9572711527321625], 
             UndirectedEdge[203, 419] -> 
             RGBColor[
              0.5236285855732716, 0.6241443008241659, 0.9556411068524893], 
             UndirectedEdge[107, 209] -> 
             RGBColor[
              0.37529763235099667`, 0.4849566561931139, 0.9463994374355724], 
             UndirectedEdge[205, 252] -> 
             RGBColor[
              0.8648112867502258, 0.89136633503373, 0.7718692919288858], 
             UndirectedEdge[98, 488] -> 
             RGBColor[
              0.8822995191611039, 0.9059842085048606, 0.8501777526166581], 
             UndirectedEdge[182, 275] -> 
             RGBColor[
              0.39614531120522645`, 0.517542890548859, 0.9464630068258206], 
             UndirectedEdge[88, 474] -> 
             RGBColor[
              0.9298536404427284, 0.7393015368665987, 0.48723505332973827`], 
             UndirectedEdge[47, 242] -> 
             RGBColor[
              0.2284706396727983, 0.35746750654429615`, 0.9363224369861192], 
             UndirectedEdge[133, 262] -> 
             RGBColor[
              0.4106297397776527, 0.5294703750419166, 0.9475567521778445], 
             UndirectedEdge[4, 321] -> 
             RGBColor[
              0.32873955000778277`, 0.45915940811169914`, 0.9421679713268938],
              UndirectedEdge[369, 370] -> 
             RGBColor[
              0.5056953807182732, 0.6086792278604158, 0.9544796944704173], 
             UndirectedEdge[49, 436] -> 
             RGBColor[
              0.4815672646188717, 0.5899970256324685, 0.9523298855912635], 
             UndirectedEdge[34, 393] -> 
             RGBColor[
              0.5024822764946291, 0.606976774483756, 0.9539763919403361], 
             UndirectedEdge[268, 324] -> 
             RGBColor[
              0.3896661145929028, 0.5119309360971549, 0.946050158147012], 
             UndirectedEdge[359, 371] -> 
             RGBColor[
              0.37419759071797254`, 0.49853287818730624`, 0.94506451748398], 
             UndirectedEdge[296, 440] -> 
             RGBColor[
              0.29754682970453167`, 0.4296388353177702, 0.94027204609223], 
             UndirectedEdge[113, 143] -> 
             RGBColor[
              0.17905963102166003`, 0.30553340361305714`, 0.9335085531404735],
              UndirectedEdge[270, 489] -> 
             RGBColor[
              0.9900603412249211, 0.9901577099059953, 0.8143893991227904], 
             UndirectedEdge[237, 426] -> 
             RGBColor[
              0.8881333928283652, 0.9136374759753497, 0.9891921499256506], 
             UndirectedEdge[131, 385] -> 
             RGBColor[
              0.24854031848564526`, 0.3785620114677306, 0.9374653755040816], 
             UndirectedEdge[427, 499] -> 
             RGBColor[
              0.27010938266217854`, 0.4012324654749223, 0.9386937018003643], 
             UndirectedEdge[45, 243] -> 
             RGBColor[
              0.5610442905289292, 0.35884112143673136`, 0.5623441481098833], 
             UndirectedEdge[33, 443] -> 
             RGBColor[
              0.9064631162110222, 0.6594290978497701, 0.24321160823769428`], 
             UndirectedEdge[232, 330] -> 
             RGBColor[
              0.3313235898372211, 0.4611852513408379, 0.942340398215439], 
             UndirectedEdge[19, 360] -> 
             RGBColor[
              0.5695454245786704, 0.661421659258773, 0.9592558486179177], 
             UndirectedEdge[44, 370] -> 
             RGBColor[
              0.5440602935407461, 0.6407316817901163, 0.9572495657475013], 
             UndirectedEdge[310, 412] -> 
             RGBColor[
              0.26956927876194814`, 0.4006647820312149, 0.9386629436822582], 
             UndirectedEdge[107, 214] -> 
             RGBColor[
              0.19223940367108877`, 0.31938618031345734`, 0.9342591216951321],
              UndirectedEdge[268, 481] -> 
             RGBColor[
              0.3639357382267393, 0.48964457733510314`, 0.9444106413174386], 
             UndirectedEdge[224, 351] -> 
             RGBColor[
              0.29450587119895527`, 0.4268747217537883, 0.9400830457311632], 
             UndirectedEdge[78, 408] -> 
             RGBColor[
              0.22096681623691122`, 0.34958051234329385`, 0.9358951053423573],
              UndirectedEdge[124, 136] -> 
             RGBColor[
              0.9658066058981951, 0.931025957642273, 0.6234191599847442], 
             UndirectedEdge[51, 315] -> 
             RGBColor[
              0.1822133085396902, 0.30884811863921036`, 0.9336881504096776], 
             UndirectedEdge[24, 270] -> 
             RGBColor[
              0.9134975511433701, 0.9314925430785823, 0.899659555679228], 
             UndirectedEdge[43, 340] -> 
             RGBColor[
              0.31529118717805316`, 0.446068953150221, 0.9413638580453506], 
             UndirectedEdge[116, 483] -> 
             RGBColor[
              0.27268756010159706`, 0.40394229342964216`, 0.9388405251914673],
              UndirectedEdge[50, 169] -> 
             RGBColor[
              0.46684010556596744`, 0.5777047091656451, 0.9512633876302873], 
             UndirectedEdge[247, 369] -> 
             RGBColor[
              0.457479402684923, 0.5695353247878849, 0.9506839560586847], 
             UndirectedEdge[327, 412] -> 
             RGBColor[
              0.2497253233645969, 0.37980752672915763`, 0.9375328597788803], 
             UndirectedEdge[134, 305] -> 
             RGBColor[
              0.2421591297202534, 0.37185497748456803`, 0.9371019762440154], 
             UndirectedEdge[7, 49] -> 
             RGBColor[
              0.6644484112533559, 0.7356118894004525, 0.9687430433701605], 
             UndirectedEdge[81, 486] -> 
             RGBColor[
              0.879272872526262, 0.9065723375988691, 0.9883470255893563], 
             UndirectedEdge[110, 384] -> 
             RGBColor[
              0.27776805045914515`, 0.4092822109171187, 0.9391298516014178], 
             UndirectedEdge[18, 88] -> 
             RGBColor[
              0.8754970234499582, 0.5275428865427625, 0.2178240033304778], 
             UndirectedEdge[11, 41] -> 
             RGBColor[
              0.23572240363091454`, 0.3650895702526674, 0.9367354142155104], 
             UndirectedEdge[231, 288] -> 
             RGBColor[
              0.2572561350755689, 0.3877228873184297, 0.9379617283649826], 
             UndirectedEdge[236, 396] -> 
             RGBColor[
              0.6404346091203621, 0.7039646181731036, 0.7392903949875442], 
             UndirectedEdge[46, 418] -> 
             RGBColor[
              0.9480641688610301, 0.8473510420156326, 0.586962152772621], 
             UndirectedEdge[74, 447] -> 
             RGBColor[
              0.26411698006509043`, 0.39493407040511375`, 0.9383524433374253],
              UndirectedEdge[270, 426] -> 
             RGBColor[
              0.9300987405065613, 0.9447298808495102, 0.9012429919407459], 
             UndirectedEdge[383, 479] -> 
             RGBColor[
              0.37021659707670174`, 0.49508474158579574`, 0.9448108520894127],
              UndirectedEdge[408, 430] -> 
             RGBColor[
              0.23112177962706493`, 0.36025402272821205`, 0.9364734154845045],
              UndirectedEdge[13, 390] -> 
             RGBColor[
              0.29868486413343276`, 0.4312671082913797, 0.9403210331965157], 
             UndirectedEdge[15, 97] -> 
             RGBColor[
              0.23298665056537604`, 0.36221412032402367`, 0.936579617125612], 
             UndirectedEdge[289, 472] -> 
             RGBColor[
              0.3839088844842855, 0.5069443127438695, 0.9456833125354096], 
             UndirectedEdge[254, 315] -> 
             RGBColor[
              0.21099893285942517`, 0.33910363491324724`, 0.9353274491301715],
              UndirectedEdge[347, 386] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[66, 445] -> 
             RGBColor[
              0.24646019520379875`, 0.3763756700110764, 0.9373469155604471], 
             UndirectedEdge[127, 213] -> 
             RGBColor[
              0.5650928544862279, 0.5063763336200533, 0.5889799898461102], 
             UndirectedEdge[423, 446] -> 
             RGBColor[
              0.20798858239401255`, 0.3359395657068551, 0.9351560141245807], 
             UndirectedEdge[63, 410] -> 
             RGBColor[
              0.39150030357105375`, 0.5135196184010107, 0.9461670310467902], 
             UndirectedEdge[107, 421] -> 
             RGBColor[
              0.18186414913512938`, 0.30848112996703203`, 0.9336682662981228],
              UndirectedEdge[226, 308] -> 
             RGBColor[
              0.17918563853241248`, 0.3056658454961956, 0.9335157290817995], 
             UndirectedEdge[51, 386] -> 
             RGBColor[
              0.1789270004053139, 0.3053940004260106, 0.9335010000230821], 
             UndirectedEdge[89, 470] -> 
             RGBColor[
              0.27049191209474743`, 0.40163452816231904`, 0.9387154862856475],
              UndirectedEdge[205, 490] -> 
             RGBColor[
              0.9921900608993205, 0.9897828176678509, 0.6878265810358566], 
             UndirectedEdge[270, 345] -> 
             RGBColor[
              0.824874141314561, 0.8621219539632672, 0.8908628396870938], 
             UndirectedEdge[152, 191] -> 
             RGBColor[
              0.21120215837255008`, 0.3393172378127832, 0.9353390225224988], 
             UndirectedEdge[85, 404] -> 
             RGBColor[
              0.21383193119222793`, 0.3420812957834917, 0.9354887841941792], 
             UndirectedEdge[26, 468] -> 
             RGBColor[
              0.43250328030680874`, 0.5483539247359007, 0.9489677041209118], 
             UndirectedEdge[191, 301] -> 
             RGBColor[
              0.2135770306984165, 0.34181337920287114`, 0.935474267988148], 
             UndirectedEdge[375, 426] -> 
             RGBColor[
              0.9141879156308917, 0.9338323693009003, 0.9715587229445324], 
             UndirectedEdge[39, 213] -> 
             RGBColor[
              0.7639337426080279, 0.681629388750616, 0.6026477314488674], 
             UndirectedEdge[360, 468] -> 
             RGBColor[
              0.5288716731016017, 0.6284008754780657, 0.9560538619087819], 
             UndirectedEdge[80, 278] -> 
             RGBColor[
              0.8689533270990046, 0.8982632673699124, 0.9759744072003973], 
             UndirectedEdge[152, 299] -> 
             RGBColor[
              0.20658465608391344`, 0.3344639501408717, 0.9350760625981434], 
             UndirectedEdge[227, 309] -> 
             RGBColor[
              0.9193309660445672, 0.6696242794444807, 0.3370748612621325], 
             UndirectedEdge[98, 115] -> 
             RGBColor[
              0.9582015589575525, 0.9660972945461519, 0.85752593015656], 
             UndirectedEdge[213, 261] -> 
             RGBColor[
              0.8920963570986589, 0.602916583768641, 0.23167489421385412`], 
             UndirectedEdge[199, 208] -> 
             RGBColor[
              0.33248120157791744`, 0.46240023864087376`, 0.9424063860563303],
              UndirectedEdge[204, 219] -> 
             RGBColor[
              0.5140809753819581, 0.6163931207559199, 0.9548894840041806], 
             UndirectedEdge[52, 166] -> 
             RGBColor[
              0.8369577282992072, 0.2850788714533209, 0.18302406839809204`], 
             UndirectedEdge[218, 300] -> 
             RGBColor[
              0.22896529227619977`, 0.3579874177932576, 0.93635060672011], 
             UndirectedEdge[128, 345] -> 
             RGBColor[
              0.5772342034942839, 0.6673977284070023, 0.9600430222220963], 
             UndirectedEdge[325, 421] -> 
             RGBColor[
              0.17903676307516053`, 0.3055093679513746, 0.9335072508447505], 
             UndirectedEdge[257, 272] -> 
             RGBColor[
              0.8397181825766789, 0.3055916208213189, 0.18563986428858031`], 
             UndirectedEdge[461, 486] -> 
             RGBColor[
              0.9396915520193736, 0.9545227464327241, 0.9862809714214389], 
             UndirectedEdge[115, 203] -> 
             RGBColor[
              0.7278675078772177, 0.786501490374317, 0.9744226233622142], 
             UndirectedEdge[128, 169] -> 
             RGBColor[
              0.4937426983927686, 0.5998815912671589, 0.9532883803380281], 
             UndirectedEdge[190, 356] -> 
             RGBColor[
              0.2587237746657965, 0.38926546958148345`, 0.9380453082684679], 
             UndirectedEdge[46, 272] -> 
             RGBColor[
              0.8691188894851287, 0.4352254750326188, 0.20997245291222838`], 
             UndirectedEdge[121, 450] -> 
             RGBColor[
              0.8225872124582064, 0.17462078949919407`, 0.16926284619957344`],
              UndirectedEdge[255, 269] -> 
             RGBColor[
              0.4232624333249523, 0.5410303787827784, 0.94819088586856], 
             UndirectedEdge[15, 356] -> 
             RGBColor[
              0.2517883622305454, 0.38197591138148856`, 0.9376503467903037], 
             UndirectedEdge[85, 183] -> 
             RGBColor[
              0.20959144808050473`, 0.33762427917091264`, 0.9352472949541991],
              UndirectedEdge[136, 261] -> 
             RGBColor[
              0.924473739268195, 0.762150740681319, 0.5794980394919615], 
             UndirectedEdge[295, 336] -> 
             RGBColor[
              0.22591321478921644`, 0.3547794908415487, 0.9361767954223702], 
             UndirectedEdge[259, 475] -> 
             RGBColor[
              0.8504220451203991, 0.38316771966990754`, 0.19570591448943397`],
              UndirectedEdge[51, 143] -> 
             RGBColor[
              0.17892700107920537`, 0.30539400113431325`, 0.9335010000614592],
              UndirectedEdge[53, 178] -> 
             RGBColor[
              0.9840984713626098, 0.9616310168446078, 0.5753629014776818], 
             UndirectedEdge[67, 385] -> 
             RGBColor[
              0.24504732911062774`, 0.37489065816626943`, 0.9372664549265891],
              UndirectedEdge[69, 173] -> 
             RGBColor[
              0.9470127321552729, 0.9592645667466908, 0.9483609186014075], 
             UndirectedEdge[221, 381] -> 
             RGBColor[
              0.5529574414035745, 0.647954787237104, 0.9579499818185896], 
             UndirectedEdge[140, 334] -> 
             RGBColor[
              0.4512190714580578, 0.563987423855866, 0.9503197339204532], 
             UndirectedEdge[57, 370] -> 
             RGBColor[
              0.5963431626815656, 0.6831772702750474, 0.9613654647247267], 
             UndirectedEdge[432, 467] -> 
             RGBColor[
              0.8027318187709938, 0.8464550865365966, 0.9808037893677689], 
             UndirectedEdge[235, 440] -> 
             RGBColor[
              0.3193577814126447, 0.44853038543702994`, 0.9416618206484036], 
             UndirectedEdge[229, 390] -> 
             RGBColor[
              0.29586463316817824`, 0.4283028667339263, 0.9401604252152023], 
             UndirectedEdge[12, 198] -> 
             RGBColor[
              0.2771414265920781, 0.4086235895025834, 0.9390941662991953], 
             UndirectedEdge[232, 400] -> 
             RGBColor[
              0.3260597275402094, 0.45565259831853255`, 0.9420406290448107], 
             UndirectedEdge[143, 273] -> 
             RGBColor[
              0.23623420851912813`, 0.365627509640484, 0.9367645607467467], 
             UndirectedEdge[115, 277] -> 
             RGBColor[
              0.8462349559465709, 0.8806222819755531, 0.9850914215175051], 
             UndirectedEdge[44, 468] -> 
             RGBColor[
              0.48752713657842917`, 0.5948355181784093, 0.9527990685436503], 
             UndirectedEdge[183, 346] -> 
             RGBColor[
              0.21142499907593382`, 0.3395514575209563, 0.9353517129708931], 
             UndirectedEdge[434, 469] -> 
             RGBColor[
              0.9258166281861495, 0.7248800924627727, 0.5003559242994462], 
             UndirectedEdge[255, 334] -> 
             RGBColor[
              0.40019480220882075`, 0.5210503561228367, 0.9467210368117455], 
             UndirectedEdge[65, 210] -> 
             RGBColor[
              0.9107642708804349, 0.6204193391599911, 0.29010099455145133`], 
             UndirectedEdge[49, 76] -> 
             RGBColor[
              0.45077000854144356`, 0.5638542255344485, 0.9502204534950804], 
             UndirectedEdge[74, 395] -> 
             RGBColor[
              0.2733607929019397, 0.4046499037882272, 0.9388788648034883], 
             UndirectedEdge[52, 88] -> 
             RGBColor[
              0.8512025856554928, 0.3816657696999445, 0.19615962002028325`], 
             UndirectedEdge[312, 354] -> 
             RGBColor[
              0.3330876906173925, 0.4625247982993003, 0.942459704446583], 
             UndirectedEdge[372, 417] -> 
             RGBColor[
              0.5857428674141524, 0.6736726673586156, 0.9611454890036907], 
             UndirectedEdge[354, 415] -> 
             RGBColor[
              0.32438826492045936`, 0.4533811503163769, 0.9419642850227896], 
             UndirectedEdge[301, 451] -> 
             RGBColor[
              0.2100992490740445, 0.3381580102115655, 0.9352762134695569], 
             UndirectedEdge[243, 428] -> 
             RGBColor[
              0.8348198026853184, 0.2686458383399938, 0.18097678841579048`], 
             UndirectedEdge[102, 354] -> 
             RGBColor[
              0.3191507002330799, 0.44787613774915985`, 0.941666013462126], 
             UndirectedEdge[255, 369] -> 
             RGBColor[
              0.40876647484829665`, 0.5284747081383571, 0.9472672162127003], 
             UndirectedEdge[300, 409] -> 
             RGBColor[
              0.23375665444094554`, 0.3630234432183127, 0.936623467707207], 
             UndirectedEdge[93, 187] -> 
             RGBColor[
              0.2669566877883537, 0.3979187832701322, 0.9385141604912941], 
             UndirectedEdge[181, 332] -> 
             RGBColor[
              0.41144462504759094`, 0.5307943872332428, 0.947437865575204], 
             UndirectedEdge[195, 351] -> 
             RGBColor[
              0.2800986877606033, 0.41173185849189103`, 0.9392625779478669], 
             UndirectedEdge[480, 481] -> 
             RGBColor[
              0.33588196619861493`, 0.46534581002792214`, 0.9426230797707831],
              UndirectedEdge[47, 365] -> 
             RGBColor[
              0.22445415871552787`, 0.3532459303986038, 0.9360937043374536], 
             UndirectedEdge[50, 370] -> 
             RGBColor[
              0.5161906822110007, 0.6177697305042253, 0.9551484458009031], 
             UndirectedEdge[122, 150] -> 
             RGBColor[
              0.8444744803276283, 0.32854420856354566`, 0.1896617078466737], 
             UndirectedEdge[246, 256] -> 
             RGBColor[
              0.2918037733500637, 0.42403464559170456`, 0.9399291652560644], 
             UndirectedEdge[63, 282] -> 
             RGBColor[
              0.5134969921724348, 0.6149963149023026, 0.9550984560118821], 
             UndirectedEdge[230, 391] -> 
             RGBColor[
              0.23250262506826308`, 0.3617053788375689, 0.936552052589603], 
             UndirectedEdge[312, 415] -> 
             RGBColor[
              0.29571211190112656`, 0.42814255721184813`, 0.9401517393546788],
              UndirectedEdge[199, 397] -> 
             RGBColor[
              0.3506959657134314, 0.47817695183439113`, 0.9435670147203616], 
             UndirectedEdge[129, 328] -> 
             RGBColor[
              0.3704563897071251, 0.49529243790994043`, 0.944826131463783], 
             UndirectedEdge[188, 304] -> 
             RGBColor[
              0.33792059600024626`, 0.4671115686975821, 0.9427529794590535], 
             UndirectedEdge[323, 395] -> 
             RGBColor[
              0.25216611947306267`, 0.3823729581945666, 0.9376718595064233], 
             UndirectedEdge[49, 238] -> 
             RGBColor[
              0.4051843179606758, 0.5243701915568157, 0.9473157736011174], 
             UndirectedEdge[171, 385] -> 
             RGBColor[
              0.24760690614002792`, 0.37758093591072595`, 0.9374122190518586],
              UndirectedEdge[117, 425] -> 
             RGBColor[
              0.3782090614978762, 0.502007412554475, 0.9453201248548712], 
             UndirectedEdge[32, 103] -> 
             RGBColor[
              0.5080332189208779, 0.6114832796124914, 0.9544133824619024], 
             UndirectedEdge[131, 216] -> 
             RGBColor[
              0.26474751566428445`, 0.3955968032981327, 0.9383883514070055], 
             UndirectedEdge[65, 175] -> 
             RGBColor[
              0.9705975460870158, 0.9645679382577699, 0.6789276620320353], 
             UndirectedEdge[143, 226] -> 
             RGBColor[
              0.17917599682249857`, 0.3056557114477564, 0.9335151800006836], 
             UndirectedEdge[234, 235] -> 
             RGBColor[
              0.3728101836078023, 0.49733117588158576`, 0.9449761131297559], 
             UndirectedEdge[179, 386] -> 
             RGBColor[
              0.17892806853100302`, 0.30539512309383293`, 0.93350106085126], 
             UndirectedEdge[267, 476] -> 
             RGBColor[
              0.9187775169477521, 0.6742536840952063, 0.3030402150761125], 
             UndirectedEdge[59, 195] -> 
             RGBColor[
              0.2561715150223729, 0.3865828828736374, 0.9378999608575047], 
             UndirectedEdge[75, 108] -> 
             RGBColor[
              0.31502960292460824`, 0.4450992956026424, 0.9413743981617775], 
             UndirectedEdge[334, 363] -> 
             RGBColor[
              0.40380771802618465`, 0.5241796822134083, 0.9469512486128518], 
             UndirectedEdge[77, 329] -> 
             RGBColor[
              0.7446878798780471, 0.8004364154026, 0.9754252127138938], 
             UndirectedEdge[328, 462] -> 
             RGBColor[
              0.4245956854340748, 0.5418984360706564, 0.9483550662650316], 
             UndirectedEdge[285, 480] -> 
             RGBColor[
              0.3339827883337351, 0.46370083761681824`, 0.9425020658366099], 
             UndirectedEdge[204, 334] -> 
             RGBColor[
              0.4523485649591434, 0.5649043975631496, 0.9504086517863296], 
             UndirectedEdge[70, 238] -> 
             RGBColor[
              0.28920204195997834`, 0.42024532074903687`, 0.9398196197075317],
              UndirectedEdge[83, 270] -> 
             RGBColor[
              0.955384395176871, 0.9648919755228036, 0.9036547602559704], 
             UndirectedEdge[112, 190] -> 
             RGBColor[
              0.24818657202567745`, 0.37819020150948346`, 0.9374452301665075],
              UndirectedEdge[263, 453] -> 
             RGBColor[
              0.27885374219171843`, 0.41042334176488493`, 0.9391916801394509],
              UndirectedEdge[210, 474] -> 
             RGBColor[
              0.9145804341522545, 0.6348102980864267, 0.4731147536068143], 
             UndirectedEdge[96, 392] -> 
             RGBColor[
              0.3010815634219416, 0.43378619120311424`, 0.9404575216753974], 
             UndirectedEdge[70, 84] -> 
             RGBColor[
              0.24578222839824324`, 0.37566308391285935`, 0.9373083063538328],
              UndirectedEdge[77, 278] -> 
             RGBColor[
              0.7775908081460805, 0.8263457284855322, 0.9672404849556133], 
             UndirectedEdge[238, 265] -> 
             RGBColor[
              0.32058421295120315`, 0.4520956650524487, 0.9416483204611299], 
             UndirectedEdge[157, 392] -> 
             RGBColor[
              0.3042725009406671, 0.4371400688524187, 0.9406392408465198], 
             UndirectedEdge[145, 294] -> 
             RGBColor[
              0.22948545468760678`, 0.35853414146784807`, 0.9363802291999281],
              UndirectedEdge[29, 383] -> 
             RGBColor[
              0.3692814154214852, 0.49427473423964385`, 0.944751263141291], 
             UndirectedEdge[210, 227] -> 
             RGBColor[
              0.8408474405782448, 0.3149769045127923, 0.18674886126930004`], 
             UndirectedEdge[45, 276] -> 
             RGBColor[
              0.4511613140247853, 0.5582811601613382, 0.9513035162562244], 
             UndirectedEdge[57, 219] -> 
             RGBColor[
              0.5637559435916646, 0.6567214977803754, 0.9588000794670529], 
             UndirectedEdge[291, 311] -> 
             RGBColor[
              0.7008920044449292, 0.7662614279396891, 0.9708220228610445], 
             UndirectedEdge[11, 485] -> 
             RGBColor[
              0.24345966129558455`, 0.3732219186287056, 0.9371760395932665], 
             UndirectedEdge[13, 338] -> 
             RGBColor[
              0.30836079438708164`, 0.4403868770076641, 0.9409105178148355], 
             UndirectedEdge[190, 351] -> 
             RGBColor[
              0.2690775343767192, 0.40014792750394457`, 0.9386349395669901], 
             UndirectedEdge[314, 397] -> 
             RGBColor[
              0.34431176305958455`, 0.4726472763749843, 0.9431602189725873], 
             UndirectedEdge[339, 365] -> 
             RGBColor[
              0.2143326753092825, 0.34260760959952685`, 0.9355173008308608], 
             UndirectedEdge[320, 337] -> 
             RGBColor[
              0.9244065988908812, 0.9404637664434601, 0.9125392493325524], 
             UndirectedEdge[317, 357] -> 
             RGBColor[
              0.895271303645258, 0.6164935275347583, 0.23428070819651722`], 
             UndirectedEdge[153, 452] -> 
             RGBColor[
              0.2344431943228335, 0.36374504016331954`, 0.9366625651378359], 
             UndirectedEdge[308, 423] -> 
             RGBColor[
              0.1833860881198116, 0.31008078433643804`, 0.9337549384717936], 
             UndirectedEdge[149, 441] -> 
             RGBColor[
              0.4020035872776604, 0.5226170348372846, 0.946836290996886], 
             UndirectedEdge[486, 493] -> 
             RGBColor[
              0.9642524295918031, 0.9698103203224957, 0.7679790459557528], 
             UndirectedEdge[241, 402] -> 
             RGBColor[
              0.6288966867837086, 0.7086387216585579, 0.9645893173262957], 
             UndirectedEdge[293, 432] -> 
             RGBColor[
              0.9264483908194477, 0.943709860746635, 0.9762410122023322], 
             UndirectedEdge[23, 211] -> 
             RGBColor[
              0.226770956748013, 0.3556810320242251, 0.9362256425580082], 
             UndirectedEdge[8, 381] -> 
             RGBColor[
              0.5947992155017207, 0.6819238244004215, 0.9612439195470645], 
             UndirectedEdge[238, 343] -> 
             RGBColor[
              0.306520714368336, 0.43844834351747275`, 0.9408058924805078], 
             UndirectedEdge[355, 363] -> 
             RGBColor[
              0.366759080123219, 0.492090014180544, 0.9445905421664991], 
             UndirectedEdge[66, 398] -> 
             RGBColor[
              0.26221606410223275`, 0.392936087203117, 0.9382441889854937], 
             UndirectedEdge[113, 477] -> 
             RGBColor[
              0.2119319440670913, 0.3400842888488316, 0.9353805827381816], 
             UndirectedEdge[7, 241] -> 
             RGBColor[
              0.7720821236708154, 0.8220268199822758, 0.9778774834237032], 
             UndirectedEdge[161, 259] -> 
             RGBColor[
              0.9260863286561598, 0.722291136783578, 0.31168537193130974`], 
             UndirectedEdge[346, 408] -> 
             RGBColor[
              0.22019359510263653`, 0.34876780790611966`, 0.9358510715426385],
              UndirectedEdge[33, 270] -> 
             RGBColor[
              0.9342186701882929, 0.7654658229940685, 0.5176324949764846], 
             UndirectedEdge[197, 270] -> 
             RGBColor[
              0.843824355466433, 0.8769260052856713, 0.8927516199339326], 
             UndirectedEdge[115, 381] -> 
             RGBColor[
              0.7452365910783697, 0.8006024945852935, 0.9757899812168571], 
             UndirectedEdge[112, 224] -> 
             RGBColor[
              0.2736149088479135, 0.4049169957593272, 0.9388933363306806], 
             UndirectedEdge[133, 296] -> 
             RGBColor[
              0.3292967430314739, 0.4596420207034847, 0.942203475173657], 
             UndirectedEdge[204, 244] -> 
             RGBColor[
              0.42216704011068096`, 0.5387626777069581, 0.9484855117114601], 
             UndirectedEdge[116, 280] -> 
             RGBColor[
              0.25280916302349343`, 0.3830488377373854, 0.9377084798853226], 
             UndirectedEdge[81, 267] -> 
             RGBColor[
              0.906340376624757, 0.9184812574076573, 0.6975246745106891], 
             UndirectedEdge[431, 459] -> 
             RGBColor[
              0.41954302397723237`, 0.5378088133487329, 0.9479538883938678], 
             UndirectedEdge[46, 293] -> 
             RGBColor[
              0.9359635798708703, 0.8383264425596675, 0.6074452935938994], 
             UndirectedEdge[145, 358] -> 
             RGBColor[
              0.2231421897482483, 0.351866967830356, 0.9360189896456512], 
             UndirectedEdge[12, 480] -> 
             RGBColor[
              0.31297532312712917`, 0.4421451064609878, 0.9412865192071291], 
             UndirectedEdge[318, 321] -> 
             RGBColor[
              0.33755888801482614`, 0.46679827542058316`, 0.9427299317460682],
              UndirectedEdge[38, 47] -> 
             RGBColor[
              0.24595116399713765`, 0.375840645938433, 0.9373179269862719], 
             UndirectedEdge[271, 492] -> 
             RGBColor[
              0.2662123163354113, 0.39713640167721365`, 0.9384717696382479], 
             UndirectedEdge[246, 333] -> 
             RGBColor[
              0.33643527177961996`, 0.46448215779697133`, 0.9427075059768388],
              UndirectedEdge[97, 137] -> 
             RGBColor[
              0.2259075246268314, 0.35477351012010483`, 0.9361764713760403], 
             UndirectedEdge[406, 486] -> 
             RGBColor[
              0.9627729895914936, 0.9654828212213326, 0.7058550168364002], 
             UndirectedEdge[272, 306] -> 
             RGBColor[
              0.8390812230199529, 0.30140098239829205`, 0.18505752934082234`],
              UndirectedEdge[50, 219] -> 
             RGBColor[
              0.48360346312109975`, 0.5913139580095534, 0.9525830605432293], 
             UndirectedEdge[326, 405] -> 
             RGBColor[
              0.9345940973525277, 0.7578425175728066, 0.403625723074449], 
             UndirectedEdge[180, 343] -> 
             RGBColor[
              0.28150922552658186`, 0.4132144231171943, 0.9393429059869358], 
             UndirectedEdge[229, 380] -> 
             RGBColor[
              0.2819134302618612, 0.4136392679220333, 0.9393659248486427], 
             UndirectedEdge[184, 470] -> 
             RGBColor[
              0.2562569900664413, 0.3866727225643841, 0.9379048285348154], 
             UndirectedEdge[188, 483] -> 
             RGBColor[
              0.31696315839045336`, 0.4478408551549855, 0.9414585414299963], 
             UndirectedEdge[364, 374] -> 
             RGBColor[
              0.2551484985501697, 0.3855076276983612, 0.93784170158283], 
             UndirectedEdge[161, 469] -> 
             RGBColor[
              0.9253813180460291, 0.7190898482623855, 0.3110970937968252], 
             UndirectedEdge[14, 182] -> 
             RGBColor[
              0.34266467028924463`, 0.47103542678761523`, 0.9430620495117685],
              UndirectedEdge[374, 391] -> 
             RGBColor[
              0.24642877472957408`, 0.3763426451004932, 0.9373451262109225], 
             UndirectedEdge[352, 367] -> 
             RGBColor[
              0.2288379775147259, 0.35785360190672644`, 0.9363433563327893], 
             UndirectedEdge[8, 289] -> 
             RGBColor[
              0.5298323406094952, 0.6288020963090049, 0.9562341229930127], 
             UndirectedEdge[160, 275] -> 
             RGBColor[
              0.4180928553323577, 0.5365527501561378, 0.9478614849301503], 
             UndirectedEdge[118, 151] -> 
             RGBColor[
              0.31595121433390305`, 0.44790234871507695`, 0.9413597168905753],
              UndirectedEdge[43, 217] -> 
             RGBColor[
              0.30643378623989703`, 0.43839711764350564`, 0.9407994722898634],
              UndirectedEdge[117, 154] -> 
             RGBColor[
              0.34530823850037556`, 0.4735103733174856, 0.9432237135065259], 
             UndirectedEdge[139, 468] -> 
             RGBColor[
              0.5212061017709153, 0.6221776193417614, 0.9554504000537172], 
             UndirectedEdge[279, 324] -> 
             RGBColor[
              0.3241188367997081, 0.45236629730551653`, 0.9419757314019449], 
             UndirectedEdge[4, 29] -> 
             RGBColor[
              0.36696197867847585`, 0.49226575471112954`, 0.9446034706830237],
              UndirectedEdge[239, 393] -> 
             RGBColor[
              0.4060710006373207, 0.5259256972403187, 0.9471546820617923], 
             UndirectedEdge[94, 127] -> 
             RGBColor[
              0.5906994451507328, 0.6605608453144329, 0.9482643190369882], 
             UndirectedEdge[157, 459] -> 
             RGBColor[
              0.3465448636437761, 0.4740080224761397, 0.94332350710475], 
             UndirectedEdge[48, 85] -> 
             RGBColor[
              0.21086321568284044`, 0.3389609875556907, 0.9353197202377406], 
             UndirectedEdge[26, 215] -> 
             RGBColor[
              0.33537631974199883`, 0.4626312893738342, 0.942674216260174], 
             UndirectedEdge[63, 165] -> 
             RGBColor[
              0.42168442508772075`, 0.5396635873606885, 0.9480903365790616], 
             UndirectedEdge[165, 282] -> 
             RGBColor[
              0.5158458225400988, 0.6170307537111264, 0.9552481214059205], 
             UndirectedEdge[288, 465] -> 
             RGBColor[
              0.2693457460924733, 0.4004298350228071, 0.9386502138274186], 
             UndirectedEdge[200, 500] -> 
             RGBColor[
              0.8601603348227043, 0.3966998445648045, 0.2026301493422178], 
             UndirectedEdge[293, 353] -> 
             RGBColor[
              0.7969674264911133, 0.8418814193634385, 0.9635324755439242], 
             UndirectedEdge[239, 296] -> 
             RGBColor[
              0.33217516852493173`, 0.46213516819204603`, 0.9423868859008084],
              UndirectedEdge[139, 274] -> 
             RGBColor[
              0.5133847204187874, 0.6158278696108893, 0.9548346722630138], 
             UndirectedEdge[140, 361] -> 
             RGBColor[
              0.5719177559547599, 0.6633194007954346, 0.9594619041005235], 
             UndirectedEdge[83, 197] -> 
             RGBColor[
              0.8091856625186589, 0.8516756760168047, 0.981399600787607], 
             UndirectedEdge[256, 444] -> 
             RGBColor[
              0.28033959264989716`, 0.411985064804791, 0.9392762971249253], 
             UndirectedEdge[21, 166] -> 
             RGBColor[
              0.9095040888434207, 0.6206039273550481, 0.282195231981873], 
             UndirectedEdge[92, 363] -> 
             RGBColor[
              0.506974473041424, 0.6093066729422614, 0.9546939442160238], 
             UndirectedEdge[41, 212] -> 
             RGBColor[
              0.22552146354030395`, 0.35436773544047784`, 0.9361544857682886],
              UndirectedEdge[96, 433] -> 
             RGBColor[
              0.31083399291217784`, 0.4424870131772134, 0.9410696465455513], 
             UndirectedEdge[346, 407] -> 
             RGBColor[
              0.2161204994130187, 0.34448672608714886`, 0.9356191147687198], 
             UndirectedEdge[32, 155] -> 
             RGBColor[
              0.5507999265063706, 0.6462032194486154, 0.9577801343426442], 
             UndirectedEdge[302, 477] -> 
             RGBColor[
              0.21741049289010705`, 0.3458425910218791, 0.9356925779888657], 
             UndirectedEdge[24, 489] -> 
             RGBColor[
              0.9135348042436461, 0.9315079481929074, 0.8990421753997224], 
             UndirectedEdge[359, 427] -> 
             RGBColor[
              0.3324756951564906, 0.4596914885288097, 0.9425050411722034], 
             UndirectedEdge[217, 290] -> 
             RGBColor[
              0.3031025001174864, 0.43489572471311266`, 0.9406097604733883], 
             UndirectedEdge[40, 297] -> 
             RGBColor[
              0.4527821832454718, 0.5648055930283604, 0.9505673549688282], 
             UndirectedEdge[41, 456] -> 
             RGBColor[
              0.22809260204387605`, 0.3570701650273288, 0.9363009083024085], 
             UndirectedEdge[341, 469] -> 
             RGBColor[
              0.927002024559022, 0.7238962731152077, 0.3735657841038871], 
             UndirectedEdge[169, 498] -> 
             RGBColor[
              0.4773158479045384, 0.5865455340196324, 0.9519951984940587], 
             UndirectedEdge[6, 329] -> 
             RGBColor[
              0.8551238518896912, 0.8873165640509703, 0.9860436704429549], 
             UndirectedEdge[92, 219] -> 
             RGBColor[
              0.5677032440041356, 0.6599260940790765, 0.9591108254149605], 
             UndirectedEdge[341, 387] -> 
             RGBColor[
              0.8843435887930974, 0.9064532397024012, 0.7600495256450741], 
             UndirectedEdge[13, 478] -> 
             RGBColor[
              0.28132910192119526`, 0.41302510178743673`, 0.939332648214078], 
             UndirectedEdge[33, 267] -> 
             RGBColor[
              0.9337384293685642, 0.7577785430140971, 0.3161344657047144], 
             UndirectedEdge[10, 123] -> 
             RGBColor[
              0.21296296597852177`, 0.34116795824830987`, 0.9354392979107774],
              UndirectedEdge[57, 337] -> 
             RGBColor[
              0.730726843956438, 0.7892639238928545, 0.9741400277373693], 
             UndirectedEdge[70, 135] -> 
             RGBColor[
              0.25443846593234043`, 0.3847613383983545, 0.9378012662756438], 
             UndirectedEdge[51, 130] -> 
             RGBColor[
              0.1789270004053139, 0.3053940004260106, 0.9335010000230821], 
             UndirectedEdge[219, 361] -> 
             RGBColor[
              0.5852351734855985, 0.6741310802897922, 0.9605102999918589], 
             UndirectedEdge[70, 131] -> 
             RGBColor[
              0.2609296066664183, 0.3915839388719636, 0.9381709271376673], 
             UndirectedEdge[61, 362] -> 
             RGBColor[
              0.3561441161626767, 0.48289586592152384`, 0.9439141660493773], 
             UndirectedEdge[49, 487] -> 
             RGBColor[
              0.5348230464505574, 0.633232468469062, 0.9565223758194106], 
             UndirectedEdge[83, 375] -> 
             RGBColor[
              0.9394735703012015, 0.9539944639741937, 0.9739704912597569], 
             UndirectedEdge[147, 385] -> 
             RGBColor[
              0.24248237828575928`, 0.37219473222205746`, 0.9371203847716176],
              UndirectedEdge[105, 395] -> 
             RGBColor[
              0.2554464216840092, 0.38582076380144426`, 0.9378586678645644], 
             UndirectedEdge[57, 204] -> 
             RGBColor[
              0.5515680195619116, 0.6468267919933015, 0.9578406014415939], 
             UndirectedEdge[362, 363] -> 
             RGBColor[
              0.3966364490357477, 0.5179682894523514, 0.9464943016940854], 
             UndirectedEdge[313, 390] -> 
             RGBColor[
              0.28385568108857195`, 0.41568069668672125`, 0.9394765331599213],
              UndirectedEdge[15, 430] -> 
             RGBColor[
              0.23698890967688827`, 0.36642074840810707`, 0.9368075398612009],
              UndirectedEdge[104, 430] -> 
             RGBColor[
              0.24315634658411125`, 0.3729031156356836, 0.937158766269162], 
             UndirectedEdge[341, 405] -> 
             RGBColor[
              0.9937930272646951, 0.989132237877419, 0.5657875066366207], 
             UndirectedEdge[8, 311] -> 
             RGBColor[
              0.6835752486050087, 0.752395433322769, 0.9693271520415703], 
             UndirectedEdge[305, 460] -> 
             RGBColor[
              0.24972906299601538`, 0.37981145731888477`, 0.9375330727453572],
              UndirectedEdge[451, 456] -> 
             RGBColor[
              0.21755217330464396`, 0.3459915061206145, 0.9357006464788762], 
             UndirectedEdge[257, 306] -> 
             RGBColor[
              0.8582164736566054, 0.4477775920644729, 0.2033538487175496], 
             UndirectedEdge[65, 167] -> 
             RGBColor[
              0.986067541242265, 0.9756937071602725, 0.6343029674871418], 
             UndirectedEdge[24, 329] -> 
             RGBColor[
              0.8597649491834076, 0.8910172490537498, 0.986486342445986], 
             UndirectedEdge[14, 63] -> 
             RGBColor[
              0.3630391373968948, 0.48868276614576933`, 0.9443602925394342], 
             UndirectedEdge[64, 172] -> 
             RGBColor[
              0.31974345189880926`, 0.449434024298521, 0.9416655397334055], 
             UndirectedEdge[50, 361] -> 
             RGBColor[
              0.5425697371949871, 0.6391572117563517, 0.9572443985054486], 
             UndirectedEdge[253, 291] -> 
             RGBColor[
              0.819979493708928, 0.8592158126034372, 0.9319826199336896], 
             UndirectedEdge[184, 280] -> 
             RGBColor[
              0.2569621251304517, 0.38741386422480434`, 0.9379449849335569], 
             UndirectedEdge[402, 487] -> 
             RGBColor[
              0.565871305361324, 0.6584388437609466, 0.958966608494386], 
             UndirectedEdge[356, 463] -> 
             RGBColor[
              0.26821764598055253`, 0.3992441302795001, 0.9385859701949193], 
             UndirectedEdge[287, 301] -> 
             RGBColor[
              0.20928219811004087`, 0.33729923784437454`, 0.9352296836258756],
              UndirectedEdge[265, 328] -> 
             RGBColor[
              0.35316375548579293`, 0.48031442730049023`, 0.9437242601024758],
              UndirectedEdge[196, 321] -> 
             RGBColor[
              0.31443739392836134`, 0.4455653460211614, 0.9413008174322348], 
             UndirectedEdge[122, 267] -> 
             RGBColor[
              0.9282834555711476, 0.7330087810415269, 0.3115827018545064], 
             UndirectedEdge[330, 354] -> 
             RGBColor[
              0.3341066984387609, 0.463595840128386, 0.9425177354345229], 
             UndirectedEdge[155, 393] -> 
             RGBColor[
              0.5135503027141461, 0.615962296777659, 0.9548477075078524], 
             UndirectedEdge[291, 319] -> 
             RGBColor[
              0.6849084125962169, 0.7537749245076777, 0.969228927800723], 
             UndirectedEdge[63, 206] -> 
             RGBColor[
              0.3810348762200533, 0.5044549912372471, 0.9455001832701985], 
             UndirectedEdge[174, 215] -> 
             RGBColor[
              0.2753901052316153, 0.40678283971254936`, 0.9389944311385647], 
             UndirectedEdge[254, 471] -> 
             RGBColor[
              0.5466554162409889, 0.4017985093907806, 0.5694083486000513], 
             UndirectedEdge[453, 463] -> 
             RGBColor[
              0.2757020968027919, 0.407110762635264, 0.939012198596993], 
             UndirectedEdge[154, 174] -> 
             RGBColor[
              0.2880991557381853, 0.4200673355937856, 0.9397208847641902], 
             UndirectedEdge[119, 197] -> 
             RGBColor[
              0.8441364985929255, 0.8770550844901885, 0.8875786005274353], 
             UndirectedEdge[50, 340] -> 
             RGBColor[
              0.3891862943583425, 0.5115153399264449, 0.9460195844259542], 
             UndirectedEdge[443, 446] -> 
             RGBColor[
              0.5813316267430582, 0.5676003433786956, 0.6012346277346379], 
             UndirectedEdge[275, 324] -> 
             RGBColor[
              0.3916907059243627, 0.5136845353495464, 0.9461791633163769], 
             UndirectedEdge[95, 286] -> 
             RGBColor[
              0.22509159237078977`, 0.3539159135859121, 0.9361300052411223], 
             UndirectedEdge[306, 317] -> 
             RGBColor[
              0.8704899188810679, 0.5035084402927961, 0.2135951122625132], 
             UndirectedEdge[118, 188] -> 
             RGBColor[
              0.3311926249986076, 0.4612841383736176, 0.9423242790961401], 
             UndirectedEdge[7, 69] -> 
             RGBColor[
              0.874072307624645, 0.9024255483118935, 0.9878509910664408], 
             UndirectedEdge[88, 166] -> 
             RGBColor[
              0.8523652692557177, 0.3906026653424749, 0.19727300714892185`], 
             UndirectedEdge[9, 44] -> 
             RGBColor[
              0.5359104641208152, 0.634115283121385, 0.9566079813217554], 
             UndirectedEdge[76, 459] -> 
             RGBColor[
              0.40093570974009674`, 0.5216920929873327, 0.9467682467844796], 
             UndirectedEdge[254, 325] -> 
             RGBColor[
              0.20775758490962407`, 0.33569677270467635`, 0.935142859159575], 
             UndirectedEdge[171, 433] -> 
             RGBColor[
              0.2936242383072788, 0.42439846992600005`, 0.9400895764803525], 
             UndirectedEdge[112, 447] -> 
             RGBColor[
              0.2473817363738829, 0.37734426820991973`, 0.9373993959667855], 
             UndirectedEdge[199, 359] -> 
             RGBColor[
              0.364147570424561, 0.48982805573786037`, 0.9444241390777679], 
             UndirectedEdge[74, 224] -> 
             RGBColor[
              0.2903501525391211, 0.42250679795452123`, 0.9398463837013205], 
             UndirectedEdge[292, 386] -> 
             RGBColor[
              0.17894881608916835`, 0.3054169300929359, 0.9335022423940041], 
             UndirectedEdge[112, 195] -> 
             RGBColor[
              0.25920772540956155`, 0.3897741324974299, 0.9380728685473844], 
             UndirectedEdge[97, 408] -> 
             RGBColor[
              0.2271195205155527, 0.3560473946441286, 0.9362454927489157], 
             UndirectedEdge[236, 422] -> 
             RGBColor[
              0.26066758061653217`, 0.39130853288012224`, 0.9381560051417591],
              UndirectedEdge[27, 114] -> 
             RGBColor[
              0.5063987002640795, 0.610156303732676, 0.9542847071658003], 
             UndirectedEdge[110, 355] -> 
             RGBColor[
              0.30021105187484454`, 0.43102571577490256`, 0.9404755205872981],
              UndirectedEdge[104, 215] -> 
             RGBColor[
              0.26534838496499225`, 0.39622835503049064`, 0.9384225700247744],
              UndirectedEdge[80, 406] -> 
             RGBColor[
              0.8900806471760057, 0.9077659645302347, 0.6988562638191269], 
             UndirectedEdge[276, 292] -> 
             RGBColor[
              0.39925539426111123`, 0.5037247474643232, 0.9483475509136101], 
             UndirectedEdge[425, 466] -> 
             RGBColor[
              0.4394255113443823, 0.5536672437102792, 0.9495973233231294], 
             UndirectedEdge[164, 309] -> 
             RGBColor[
              0.9052777371288019, 0.5616050038337315, 0.3236174733815438], 
             UndirectedEdge[95, 137] -> 
             RGBColor[
              0.22358173079098384`, 0.35232895333478276`, 0.9360440208577924],
              UndirectedEdge[119, 426] -> 
             RGBColor[
              0.9304108836330538, 0.9448589600540273, 0.8960699725342486], 
             UndirectedEdge[238, 431] -> 
             RGBColor[
              0.38434692528377257`, 0.5073237216678145, 0.9457112241078087], 
             UndirectedEdge[93, 266] -> 
             RGBColor[
              0.2794030113306438, 0.41100065845557043`, 0.9392229602043418], 
             UndirectedEdge[15, 148] -> 
             RGBColor[
              0.2369473179686802, 0.36637703288571377`, 0.9368051712749479], 
             UndirectedEdge[225, 470] -> 
             RGBColor[
              0.26486570011979793`, 0.3957210226542046, 0.9383950818369088], 
             UndirectedEdge[249, 296] -> 
             RGBColor[
              0.3014838445951241, 0.4337768875889444, 0.9404962532659576], 
             UndirectedEdge[273, 421] -> 
             RGBColor[
              0.236299010735822, 0.36569562087892715`, 0.9367682511371211], 
             UndirectedEdge[150, 159] -> 
             RGBColor[
              0.821097410502475, 0.1631695188320622, 0.16783621016427433`], 
             UndirectedEdge[85, 407] -> 
             RGBColor[
              0.2142869484175896, 0.3425595477371053, 0.9355146967520258], 
             UndirectedEdge[71, 388] -> 
             RGBColor[
              0.8509768197746642, 0.8842586853652235, 0.9761468351078537], 
             UndirectedEdge[61, 435] -> 
             RGBColor[
              0.2909721876561818, 0.42176628331072286`, 0.9399328603098349], 
             UndirectedEdge[10, 177] -> 
             RGBColor[
              0.21382948684753797`, 0.34207872662224226`, 0.9354886449923652],
              UndirectedEdge[16, 52] -> 
             RGBColor[
              0.6198385630520318, 0.4001930339226935, 0.5644333341255259], 
             UndirectedEdge[25, 459] -> 
             RGBColor[
              0.35196069990557133`, 0.47927240102423385`, 0.9436476024647243],
              UndirectedEdge[105, 453] -> 
             RGBColor[
              0.265106051538209, 0.39597364723411466`, 0.9384087694946193], 
             UndirectedEdge[61, 384] -> 
             RGBColor[
              0.3038237458344487, 0.43527408579193255`, 0.9406647375359107], 
             UndirectedEdge[104, 323] -> 
             RGBColor[
              0.2429591667599799, 0.3726958671385986, 0.9371475371698791], 
             UndirectedEdge[150, 406] -> 
             RGBColor[
              0.9060315184464693, 0.5729271685521393, 0.29311167174990027`], 
             UndirectedEdge[413, 493] -> 
             RGBColor[
              0.9837066431260291, 0.9560378233723712, 0.44758049868418615`], 
             UndirectedEdge[94, 254] -> 
             RGBColor[
              0.5959586642234989, 0.6660886180136586, 0.9485638237828649], 
             UndirectedEdge[431, 487] -> 
             RGBColor[
              0.5139856537736541, 0.6161859985800608, 0.9549178263261018], 
             UndirectedEdge[234, 332] -> 
             RGBColor[
              0.3953853483413155, 0.5168846489129837, 0.946414582664141], 
             UndirectedEdge[82, 89] -> 
             RGBColor[
              0.2718901700216876, 0.4031041858982062, 0.9387951150060494], 
             UndirectedEdge[154, 255] -> 
             RGBColor[
              0.3535633647009796, 0.4806605487177418, 0.9437497228483069], 
             UndirectedEdge[22, 324] -> 
             RGBColor[
              0.41054698853962773`, 0.5300168996065678, 0.9473806689706655], 
             UndirectedEdge[105, 112] -> 
             RGBColor[
              0.2470843980758506, 0.3770317468063509, 0.9373824629905851], 
             UndirectedEdge[6, 406] -> 
             RGBColor[
              0.9091541002347256, 0.9227285742942248, 0.700740799303404], 
             UndirectedEdge[396, 422] -> 
             RGBColor[
              0.6137790328303492, 0.6759479174311498, 0.7377723993512193], 
             UndirectedEdge[409, 456] -> 
             RGBColor[
              0.23260709522442666`, 0.3618151835954873, 0.9365580020104467], 
             UndirectedEdge[91, 473] -> 
             RGBColor[
              0.32723005291391416`, 0.4578519575985201, 0.9420717875068684], 
             UndirectedEdge[369, 379] -> 
             RGBColor[
              0.3646233115605392, 0.49024011879839996`, 0.944454452882271], 
             UndirectedEdge[353, 441] -> 
             RGBColor[
              0.5448974710637005, 0.6413248437593597, 0.9573393706579376], 
             UndirectedEdge[165, 481] -> 
             RGBColor[
              0.3711249763330434, 0.49587153404117, 0.9448687332123786], 
             UndirectedEdge[185, 318] -> 
             RGBColor[
              0.3129435362062064, 0.4431846498190406, 0.9412454229080396], 
             UndirectedEdge[264, 445] -> 
             RGBColor[
              0.23221275436386601`, 0.3614007063483834, 0.9365355448818129], 
             UndirectedEdge[258, 297] -> 
             RGBColor[
              0.4463933258988235, 0.5592718859080008, 0.9501602626281445], 
             UndirectedEdge[57, 139] -> 
             RGBColor[
              0.5826390838232848, 0.6720516816961779, 0.9602866294373078], 
             UndirectedEdge[447, 463] -> 
             RGBColor[
              0.2567986541117429, 0.38724204581948013`, 0.9379356755008752], 
             UndirectedEdge[9, 26] -> 
             RGBColor[
              0.4808866078491948, 0.5876336896788764, 0.952776616899017], 
             UndirectedEdge[181, 262] -> 
             RGBColor[
              0.4483915053521436, 0.5621777184210172, 0.9499628984888329], 
             UndirectedEdge[203, 291] -> 
             RGBColor[
              0.5947468881404891, 0.681688814806365, 0.9613714325118958], 
             UndirectedEdge[45, 254] -> 
             RGBColor[
              0.25964036057789125`, 0.3902288594899984, 0.9380975064801944], 
             UndirectedEdge[240, 412] -> 
             RGBColor[
              0.2495035202048371, 0.3795743975451175, 0.9375202284170604], 
             UndirectedEdge[208, 258] -> 
             RGBColor[
              0.3477704837485026, 0.4756430463953687, 0.9433806055964585], 
             UndirectedEdge[293, 420] -> 
             RGBColor[
              0.9614575711812897, 0.9707757002112165, 0.9501264579014013], 
             UndirectedEdge[85, 346] -> 
             RGBColor[
              0.21604910573121133`, 0.34441168680094847`, 0.9356150490041585],
              UndirectedEdge[65, 166] -> 
             RGBColor[
              0.9117926198146232, 0.6283236796935395, 0.2910857426521841], 
             UndirectedEdge[254, 347] -> 
             RGBColor[
              0.20771262472504887`, 0.3356495167000475, 0.935140298743576], 
             UndirectedEdge[236, 292] -> 
             RGBColor[
              0.23314689454244097`, 0.36238254690397387`, 0.9365887427830462],
              UndirectedEdge[100, 401] -> 
             RGBColor[
              0.8523336151346661, 0.7939714926704016, 0.620783111215081], 
             UndirectedEdge[146, 400] -> 
             RGBColor[
              0.276927529490606, 0.4083987700870767, 0.9390819851756989], 
             UndirectedEdge[104, 153] -> 
             RGBColor[
              0.24575331572793313`, 0.3756326948631943, 0.937306659820031], 
             UndirectedEdge[216, 281] -> 
             RGBColor[
              0.2553973215721218, 0.3857691564707237, 0.9378558716858294], 
             UndirectedEdge[123, 125] -> 
             RGBColor[
              0.2078185513522534, 0.33576085230137553`, 0.9351463311082908], 
             UndirectedEdge[78, 358] -> 
             RGBColor[
              0.22252765585105994`, 0.3512210537407115, 0.9359839928493279], 
             UndirectedEdge[313, 478] -> 
             RGBColor[
              0.26649991887633445`, 0.3974386901827782, 0.9384881481774836], 
             UndirectedEdge[368, 401] -> 
             RGBColor[
              0.5907770138305127, 0.6754225066218276, 0.9626395084549426], 
             UndirectedEdge[106, 369] -> 
             RGBColor[
              0.46890138102995677`, 0.5788082013626439, 0.9515831360340911], 
             UndirectedEdge[111, 146] -> 
             RGBColor[
              0.2655122364597581, 0.39640057334027434`, 0.9384319011250047], 
             UndirectedEdge[129, 266] -> 
             RGBColor[
              0.32256025857167225`, 0.4520297101069751, 0.9418393155552645], 
             UndirectedEdge[99, 278] -> 
             RGBColor[
              0.9709926371751241, 0.9748878865987054, 0.7597061890098948], 
             UndirectedEdge[147, 171] -> 
             RGBColor[
              0.2566176973332457, 0.3870518487719572, 0.9379253702800414], 
             UndirectedEdge[164, 166] -> 
             RGBColor[
              0.8278225605966679, 0.21486196943559147`, 0.17427622148944416`],
              UndirectedEdge[129, 433] -> 
             RGBColor[
              0.3405530126531223, 0.4693916356931953, 0.94292071472042], 
             UndirectedEdge[179, 283] -> 
             RGBColor[
              0.18007164814629245`, 0.3065970977766376, 0.9335661860185762], 
             UndirectedEdge[136, 291] -> 
             RGBColor[
              0.8119439013123007, 0.853362410017863, 0.9518331785269256], 
             UndirectedEdge[321, 479] -> 
             RGBColor[
              0.37233306340343797`, 0.49691791834132404`, 0.9449457114522347],
              UndirectedEdge[181, 239] -> 
             RGBColor[
              0.38581385669695734`, 0.5085943039277986, 0.9458046956803003], 
             UndirectedEdge[102, 330] -> 
             RGBColor[
              0.2914935550351155, 0.4237085864737168, 0.939911498781955], 
             UndirectedEdge[406, 413] -> 
             RGBColor[
              0.9822272031257195, 0.951710324271208, 0.3854564695648335], 
             UndirectedEdge[37, 310] -> 
             RGBColor[
              0.30119863479716524`, 0.4339092406412282, 0.9404641887170249], 
             UndirectedEdge[203, 439] -> 
             RGBColor[
              0.6977395599110665, 0.7624782824674698, 0.971548992789666], 
             UndirectedEdge[320, 375] -> 
             RGBColor[
              0.9734019680069053, 0.9789510679067093, 0.8970939407523506], 
             UndirectedEdge[42, 407] -> 
             RGBColor[
              0.22341630550160935`, 0.352155080867081, 0.9360346001322872], 
             UndirectedEdge[131, 374] -> 
             RGBColor[
              0.2576696859737398, 0.38815755553304865`, 0.9379852794768397], 
             UndirectedEdge[387, 403] -> 
             RGBColor[
              0.8520128910253049, 0.8851986373727346, 0.9856507029983317], 
             UndirectedEdge[65, 348] -> 
             RGBColor[
              0.9726882187211612, 0.9195330900145834, 0.3483993164391773], 
             UndirectedEdge[217, 498] -> 
             RGBColor[
              0.3908046357587574, 0.5126843292737169, 0.9461870095342384], 
             UndirectedEdge[40, 397] -> 
             RGBColor[
              0.37237410523066483`, 0.4969534667092458, 0.9449483266011737], 
             UndirectedEdge[226, 292] -> 
             RGBColor[
              0.17919781223777545`, 0.3056786408323896, 0.9335164223563106], 
             UndirectedEdge[53, 257] -> 
             RGBColor[
              0.9176828698612274, 0.692200433274696, 0.28359567952116765`], 
             UndirectedEdge[220, 429] -> 
             RGBColor[
              0.3162555864633567, 0.44694588722950834`, 0.9414237848069549], 
             UndirectedEdge[139, 425] -> 
             RGBColor[
              0.469689014710176, 0.5782365190979204, 0.9519797771669503], 
             UndirectedEdge[317, 418] -> 
             RGBColor[
              0.9309369071770426, 0.7734480360326559, 0.5728708276939365], 
             UndirectedEdge[482, 496] -> 
             RGBColor[
              0.31768549080207875`, 0.4466395905233832, 0.9415714600344062], 
             UndirectedEdge[117, 466] -> 
             RGBColor[
              0.44229172329685795`, 0.5561498124435122, 0.9497799558142495], 
             UndirectedEdge[82, 105] -> 
             RGBColor[
              0.25209194686734443`, 0.382294998083142, 0.9376676354862561], 
             UndirectedEdge[239, 453] -> 
             RGBColor[
              0.31761867457160725`, 0.44726749674536337`, 0.9415420928317004],
              UndirectedEdge[274, 340] -> 
             RGBColor[
              0.40008441142440987`, 0.5206990676119785, 0.9467846461754836], 
             UndirectedEdge[311, 484] -> 
             RGBColor[
              0.8698742834500395, 0.8946869579845022, 0.7215434088969761], 
             UndirectedEdge[44, 140] -> 
             RGBColor[
              0.4981556569200065, 0.6034642298010868, 0.9536357845984921], 
             UndirectedEdge[139, 466] -> 
             RGBColor[
              0.5337716765091578, 0.6323789189869576, 0.9564396081263286], 
             UndirectedEdge[22, 481] -> 
             RGBColor[
              0.38481661217346425`, 0.507730540844516, 0.9457411521410921], 
             UndirectedEdge[45, 386] -> 
             RGBColor[
              0.23085473585284239`, 0.35997334278995086`, 0.9364582077366184],
              UndirectedEdge[40, 220] -> 
             RGBColor[
              0.36255668140028763`, 0.48845010762544216`, 0.9443227690359091],
              UndirectedEdge[237, 489] -> 
             RGBColor[
              0.9480949935467251, 0.959065305031835, 0.9023385571076953], 
             UndirectedEdge[61, 64] -> 
             RGBColor[
              0.3058305702683475, 0.43738338551197825`, 0.9407790232185906], 
             UndirectedEdge[82, 296] -> 
             RGBColor[
              0.28584922180975014`, 0.4173439077491774, 0.9396058846276822], 
             UndirectedEdge[27, 277] -> 
             RGBColor[
              0.6417102241932708, 0.7180330594388474, 0.9662874050409727], 
             UndirectedEdge[416, 427] -> 
             RGBColor[
              0.2705169061527906, 0.4016607985020373, 0.9387169096602777], 
             UndirectedEdge[59, 82] -> 
             RGBColor[
              0.25023486400687867`, 0.3803430862509384, 0.9375618773646605], 
             UndirectedEdge[271, 444] -> 
             RGBColor[
              0.26354918336029226`, 0.3943372800679805, 0.938320108155067], 
             UndirectedEdge[6, 486] -> 
             RGBColor[
              0.8813087089314302, 0.9081956582870432, 0.9885412054830938], 
             UndirectedEdge[171, 265] -> 
             RGBColor[
              0.29137836531202577`, 0.42245320761837074`, 0.9399464714390425],
              UndirectedEdge[219, 369] -> 
             RGBColor[
              0.47310816162837227`, 0.5822234553657439, 0.9519143092127434], 
             UndirectedEdge[244, 355] -> 
             RGBColor[
              0.3355739158146536, 0.46507899226839733`, 0.9426034510727153], 
             UndirectedEdge[450, 500] -> 
             RGBColor[
              0.8186005728713881, 0.14397773067830186`, 0.16544523562897076`],
              UndirectedEdge[18, 243] -> 
             RGBColor[
              0.8618450148200435, 0.43551288339499367`, 0.2052561643181862], 
             UndirectedEdge[377, 449] -> 
             RGBColor[
              0.8547039434845443, 0.8865518671157351, 0.9452111853810878], 
             UndirectedEdge[7, 173] -> 
             RGBColor[
              0.9116225315818571, 0.9310453814508525, 0.9449853696775101], 
             UndirectedEdge[3, 8] -> 
             RGBColor[
              0.5409798313044035, 0.6382308237734111, 0.9570070604761514], 
             UndirectedEdge[405, 469] -> 
             RGBColor[
              0.9272216806853377, 0.724366095358756, 0.3974739978928766], 
             UndirectedEdge[148, 190] -> 
             RGBColor[
              0.2438827304039313, 0.37366659108570865`, 0.9372001327531121], 
             UndirectedEdge[180, 216] -> 
             RGBColor[
              0.2680084621160904, 0.3990242647749275, 0.9385740574832979], 
             UndirectedEdge[257, 317] -> 
             RGBColor[
              0.8711268784377937, 0.5076990787158229, 0.21417744721027115`], 
             UndirectedEdge[49, 462] -> 
             RGBColor[
              0.4770465403942916, 0.586326898050649, 0.9519739976203461], 
             UndirectedEdge[223, 258] -> 
             RGBColor[
              0.3816431136278576, 0.5049818159089863, 0.9455389396199805], 
             UndirectedEdge[260, 440] -> 
             RGBColor[
              0.28362513416460355`, 0.4154383772521112, 0.9394634038536649], 
             UndirectedEdge[262, 332] -> 
             RGBColor[
              0.43913893362174417`, 0.5541636058359223, 0.9493733327998998], 
             UndirectedEdge[283, 386] -> 
             RGBColor[
              0.18007057961528944`, 0.30659597468280464`, 0.9335661251673164],
              UndirectedEdge[40, 289] -> 
             RGBColor[
              0.41278560473143366`, 0.5319558764357888, 0.9475233116148768], 
             UndirectedEdge[95, 430] -> 
             RGBColor[
              0.23341097282813747`, 0.36266010992577125`, 0.9366037816507478],
              UndirectedEdge[274, 334] -> 
             RGBColor[
              0.4327691697643524, 0.5490089625023165, 0.9488672900749079], 
             UndirectedEdge[75, 158] -> 
             RGBColor[
              0.3512349205505469, 0.4786437674256428, 0.9436013564460036], 
             UndirectedEdge[233, 476] -> 
             RGBColor[
              0.8458261121541704, 0.35324515591315253`, 0.19151644279301172`],
              UndirectedEdge[240, 416] -> 
             RGBColor[
              0.2590796192147955, 0.38963948476432886`, 0.9380655730891085], 
             UndirectedEdge[260, 280] -> 
             RGBColor[
              0.27123440340689225`, 0.4024149336080515, 0.9387577700674566], 
             UndirectedEdge[11, 193] -> 
             RGBColor[
              0.2633649248993141, 0.3941436127428313, 0.9383096149083003], 
             UndirectedEdge[3, 162] -> 
             RGBColor[
              0.4618487252450588, 0.5739886270587315, 0.9507775699403673], 
             UndirectedEdge[117, 338] -> 
             RGBColor[
              0.3505903006321732, 0.47808543005188675`, 0.9435602818348199], 
             UndirectedEdge[40, 472] -> 
             RGBColor[
              0.35732343693452717`, 0.4839173342997152, 0.9439893113261273], 
             UndirectedEdge[101, 355] -> 
             RGBColor[
              0.424769765192925, 0.5405027707410431, 0.9487934456872616], 
             UndirectedEdge[47, 364] -> 
             RGBColor[
              0.24525016381875867`, 0.3751038503049783, 0.93727800606315], 
             UndirectedEdge[377, 484] -> 
             RGBColor[
              0.9869984046810305, 0.9863165950507087, 0.692275872605006], 
             UndirectedEdge[21, 227] -> 
             RGBColor[
              0.9132594664564218, 0.6494694053055374, 0.28579138582517527`], 
             UndirectedEdge[158, 441] -> 
             RGBColor[
              0.4038268661048062, 0.5241962673166999, 0.9469524687114896], 
             UndirectedEdge[201, 222] -> 
             RGBColor[
              0.3735862388275236, 0.49760697262793063`, 0.9450400762157048], 
             UndirectedEdge[107, 477] -> 
             RGBColor[
              0.21467165996386678`, 0.3429639039643634, 0.9355366055054566], 
             UndirectedEdge[89, 239] -> 
             RGBColor[
              0.31821611673686917`, 0.4478954463410748, 0.9415761162791756], 
             UndirectedEdge[63, 275] -> 
             RGBColor[
              0.41651977831287657`, 0.5351902299070133, 0.9477612498534863], 
             UndirectedEdge[133, 344] -> 
             RGBColor[
              0.404458323018091, 0.5244601408973477, 0.9470709156438875], 
             UndirectedEdge[153, 356] -> 
             RGBColor[
              0.2571354474729763, 0.3875960369960689, 0.9379548553845563], 
             UndirectedEdge[151, 188] -> 
             RGBColor[
              0.32203573450029344`, 0.4531724542663287, 0.9417474171352478], 
             UndirectedEdge[140, 204] -> 
             RGBColor[
              0.5007635578511195, 0.6055814412615623, 0.9538410881128452], 
             UndirectedEdge[154, 369] -> 
             RGBColor[
              0.36474431369771637`, 0.4903449247678786, 0.944462163031454], 
             UndirectedEdge[16, 179] -> 
             RGBColor[
              0.29140560923354364`, 0.4148201691111312, 0.940228554342059], 
             UndirectedEdge[161, 341] -> 
             RGBColor[
              0.9919526646253864, 0.9838559907810486, 0.4794106025405692], 
             UndirectedEdge[48, 408] -> 
             RGBColor[
              0.21500770505426564`, 0.34331710866086196`, 0.9355557427762207],
              UndirectedEdge[153, 263] -> 
             RGBColor[
              0.25916680795964386`, 0.3897311256632503, 0.9380705383591434], 
             UndirectedEdge[62, 132] -> 
             RGBColor[
              0.9037259559281465, 0.5621573598635239, 0.4887023579770914], 
             UndirectedEdge[82, 225] -> 
             RGBColor[
              0.2662639580467382, 0.39719068039009175`, 0.9384747105573108], 
             UndirectedEdge[216, 465] -> 
             RGBColor[
              0.27425578181697063`, 0.40559059388349944`, 0.9389298330981818],
              UndirectedEdge[119, 489] -> 
             RGBColor[
              0.9903724843514137, 0.9902867891105125, 0.8092163797162932], 
             UndirectedEdge[287, 295] -> 
             RGBColor[
              0.2196997994484176, 0.34824879736508285`, 0.9358229506106359], 
             UndirectedEdge[28, 417] -> 
             RGBColor[
              0.8329443683967894, 0.8698408046783143, 0.9576048606613091], 
             UndirectedEdge[148, 351] -> 
             RGBColor[
              0.26485064633186906`, 0.3957052001686261, 0.9383942245459564], 
             UndirectedEdge[218, 336] -> 
             RGBColor[
              0.2271057420788739, 0.35603291263357584`, 0.9362447080873302], 
             UndirectedEdge[127, 254] -> 
             RGBColor[
              0.23123903037733173`, 0.3603772607008694, 0.9364800927412753], 
             UndirectedEdge[303, 473] -> 
             RGBColor[
              0.31604489027716914`, 0.44784149062043943`, 0.9413708849892584],
              UndirectedEdge[99, 267] -> 
             RGBColor[
              0.9913420700473246, 0.9817665875606343, 0.479566100729647], 
             UndirectedEdge[48, 145] -> 
             RGBColor[
              0.21408452170973263`, 0.34234678443255295`, 0.9355031688504769],
              UndirectedEdge[224, 342] -> 
             RGBColor[
              0.2794767176957349, 0.41107812851853454`, 0.939227157672795], 
             UndirectedEdge[193, 232] -> 
             RGBColor[
              0.32200467219797546`, 0.4513904780484862, 0.9418096996419872], 
             UndirectedEdge[216, 343] -> 
             RGBColor[
              0.2793867448603114, 0.4109835613638972, 0.9392220338529205], 
             UndirectedEdge[277, 449] -> 
             RGBColor[
              0.7498021540184663, 0.8044704085174408, 0.9756969294792002], 
             UndirectedEdge[257, 418] -> 
             RGBColor[
              0.9186634619525802, 0.7177171878043327, 0.5626295641489729], 
             UndirectedEdge[45, 422] -> 
             RGBColor[
              0.2583972380161019, 0.3889222588590351, 0.9380267124893356], 
             UndirectedEdge[133, 235] -> 
             RGBColor[
              0.3511076947395869, 0.47853357082274445`, 0.9435932497298307], 
             UndirectedEdge[145, 183] -> 
             RGBColor[
              0.21281275410739692`, 0.3410100760477749, 0.9354307435669353], 
             UndirectedEdge[196, 496] -> 
             RGBColor[
              0.2862944389618104, 0.41824398583767475`, 0.9396154168129832], 
             UndirectedEdge[115, 136] -> 
             RGBColor[
              0.9450645210490293, 0.9581750855858149, 0.964884369377244], 
             UndirectedEdge[267, 413] -> 
             RGBColor[
              0.981449315920919, 0.9490863280728146, 0.38243452466585603`], 
             UndirectedEdge[217, 340] -> 
             RGBColor[
              0.32857716094804046`, 0.4590187548700618, 0.9421576240396021], 
             UndirectedEdge[335, 383] -> 
             RGBColor[
              0.3028573462736385, 0.4337853452642071, 0.940627021112898], 
             UndirectedEdge[80, 493] -> 
             RGBColor[
              0.8915600871763152, 0.912093463631398, 0.7609802929384797], 
             UndirectedEdge[307, 372] -> 
             RGBColor[
              0.47013131999468205`, 0.580712810603117, 0.9514296061392018], 
             UndirectedEdge[18, 434] -> 
             RGBColor[
              0.9377932493402739, 0.7792631319127137, 0.510349510564296], 
             UndirectedEdge[130, 179] -> 
             RGBColor[
              0.17892806853100302`, 0.30539512309383293`, 0.93350106085126], 
             UndirectedEdge[20, 228] -> 
             RGBColor[
              0.9388076655030091, 0.7780938721344945, 0.3568427286125849], 
             UndirectedEdge[297, 311] -> 
             RGBColor[
              0.6331105387907436, 0.7114259084862791, 0.9653543852266682], 
             UndirectedEdge[127, 200] -> 
             RGBColor[
              0.5634039093287206, 0.4987072281229762, 0.587570692606852], 
             UndirectedEdge[54, 391] -> 
             RGBColor[
              0.23492401226674847`, 0.36425041030799266`, 0.9366899470084354],
              UndirectedEdge[347, 368] -> 
             RGBColor[
              0.2935143249909316, 0.4166464351270609, 0.9403629270800464], 
             UndirectedEdge[22, 182] -> 
             RGBColor[
              0.4150015938204914, 0.5338752548058805, 0.9476645124801093], 
             UndirectedEdge[96, 216] -> 
             RGBColor[
              0.2810238579235662, 0.4127042709923413, 0.9393152650199811], 
             UndirectedEdge[340, 363] -> 
             RGBColor[
              0.37112295968624204`, 0.49586978732307024`, 0.9448686047134276],
              UndirectedEdge[71, 490] -> 
             RGBColor[
              0.8731675486403643, 0.8997516085621015, 0.891254202422064], 
             UndirectedEdge[111, 201] -> 
             RGBColor[
              0.28877500860148286`, 0.42085122180616963`, 0.9397566815842886],
              UndirectedEdge[261, 484] -> 
             RGBColor[
              0.9364392575786439, 0.7675671876801757, 0.34462692180178206`], 
             UndirectedEdge[416, 499] -> 
             RGBColor[
              0.26112616120390136`, 0.3917905301531358, 0.9381821206278006], 
             UndirectedEdge[42, 430] -> 
             RGBColor[
              0.2361066473396595, 0.36549343475301654`, 0.9367572963262859], 
             UndirectedEdge[6, 81] -> 
             RGBColor[
              0.825653983169494, 0.8638180906717614, 0.9832328080563602], 
             UndirectedEdge[282, 353] -> 
             RGBColor[
              0.6236604649477651, 0.705354686885191, 0.9635159828256973], 
             UndirectedEdge[275, 441] -> 
             RGBColor[
              0.43191818188119013`, 0.5485275531316196, 0.9487424225125856], 
             UndirectedEdge[50, 255] -> 
             RGBColor[
              0.41926177634102413`, 0.5375652107821666, 0.9479359675431862], 
             UndirectedEdge[110, 217] -> 
             RGBColor[
              0.29571753049971145`, 0.4271336534107135, 0.9401891973787395], 
             UndirectedEdge[30, 110] -> 
             RGBColor[
              0.26982326266389456`, 0.40093173521567016`, 0.9386774076897386],
              UndirectedEdge[77, 482] -> 
             RGBColor[
              0.4826496570055525, 0.5883007255405965, 0.9531265853256541], 
             UndirectedEdge[52, 326] -> 
             RGBColor[
              0.8554852780065134, 0.4011124754177182, 0.19973320349637064`], 
             UndirectedEdge[44, 247] -> 
             RGBColor[
              0.4958443155073958, 0.6015877787175854, 0.9534538273357688], 
             UndirectedEdge[337, 348] -> 
             RGBColor[
              0.9100611549268829, 0.8839036332529456, 0.6426467308354947], 
             UndirectedEdge[48, 78] -> 
             RGBColor[
              0.21346998781254425`, 0.3417008703429085, 0.9354681720541533], 
             UndirectedEdge[420, 432] -> 
             RGBColor[
              0.933633649289228, 0.949068614748616, 0.9640782438285385], 
             UndirectedEdge[469, 474] -> 
             RGBColor[
              0.9267639161265591, 0.7252718203703219, 0.4846569116242533], 
             UndirectedEdge[172, 366] -> 
             RGBColor[
              0.3083293758751098, 0.43743710670339436`, 0.941015524989468], 
             UndirectedEdge[102, 415] -> 
             RGBColor[
              0.28177512151681394`, 0.41349389666170766`, 0.9393580483702217],
              UndirectedEdge[414, 485] -> 
             RGBColor[
              0.26132957932407624`, 0.39200433549489333`, 0.9381937049888145],
              UndirectedEdge[102, 193] -> 
             RGBColor[
              0.2821746373958698, 0.4139138131813651, 0.9393808002085031], 
             UndirectedEdge[128, 498] -> 
             RGBColor[
              0.4783163619958606, 0.5873577964316139, 0.9520739626283314], 
             UndirectedEdge[150, 443] -> 
             RGBColor[
              0.8779783180841267, 0.47195372718941886`, 0.21716686938390278`],
              UndirectedEdge[2, 230] -> 
             RGBColor[
              0.21816285424353754`, 0.34663337050679954`, 0.9357354238549247],
              UndirectedEdge[367, 416] -> 
             RGBColor[
              0.24568937276892794`, 0.3755654867590621, 0.9373030183631108], 
             UndirectedEdge[61, 473] -> 
             RGBColor[
              0.3253289757704718, 0.4562053401277858, 0.9419506525523447], 
             UndirectedEdge[56, 164] -> 
             RGBColor[
              0.8270991589089857, 0.20930158706742483`, 0.17358349121635427`],
              UndirectedEdge[20, 388] -> 
             RGBColor[
              0.9153530643766437, 0.7639768167303482, 0.6006827363489642], 
             UndirectedEdge[195, 296] -> 
             RGBColor[
              0.29178587282524443`, 0.4235837043718764, 0.9399439681205266], 
             UndirectedEdge[135, 391] -> 
             RGBColor[
              0.24587699790050546`, 0.37576269266847045`, 0.9373137033367878],
              UndirectedEdge[310, 399] -> 
             RGBColor[
              0.26912901254486776`, 0.40020203432257306`, 0.938637871172511], 
             UndirectedEdge[150, 476] -> 
             RGBColor[
              0.834968541704233, 0.26978911161722496`, 0.18111922106827977`], 
             UndirectedEdge[142, 222] -> 
             RGBColor[
              0.5711190039988594, 0.6615355308329243, 0.9600580034664301], 
             UndirectedEdge[48, 404] -> 
             RGBColor[
              0.21047959213928613`, 0.3385577748882776, 0.9352978734444553], 
             UndirectedEdge[330, 415] -> 
             RGBColor[
              0.29673111972249494`, 0.4292135990409338, 0.9402097703426187], 
             UndirectedEdge[326, 495] -> 
             RGBColor[
              0.8586889913459645, 0.42573762002087545`, 0.2028010830083056], 
             UndirectedEdge[36, 382] -> 
             RGBColor[
              0.26830699274776615`, 0.39933803939675394`, 0.9385910583611354],
              UndirectedEdge[31, 289] -> 
             RGBColor[
              0.4462046575439149, 0.5609017802915265, 0.9496527441087801], 
             UndirectedEdge[436, 487] -> 
             RGBColor[
              0.5261755956139467, 0.6262120783166807, 0.9558416168128965], 
             UndirectedEdge[251, 427] -> 
             RGBColor[
              0.2690226652198594, 0.4000902565411794, 0.9386318148496786], 
             UndirectedEdge[108, 437] -> 
             RGBColor[
              0.27047057871071917`, 0.40161210542309067`, 0.938714271380987], 
             UndirectedEdge[258, 397] -> 
             RGBColor[
              0.36598524788401654`, 0.49141975958888606`, 0.94454123426049], 
             UndirectedEdge[308, 422] -> 
             RGBColor[
              0.20647914454706495`, 0.3343530508258261, 0.9350700538722102], 
             UndirectedEdge[16, 292] -> 
             RGBColor[
              0.29142635679170903`, 0.41484197611023416`, 0.9402297358848033],
              UndirectedEdge[68, 317] -> 
             RGBColor[
              0.8516933912786147, 0.35903009244942585`, 0.19559553620276254`],
              UndirectedEdge[34, 468] -> 
             RGBColor[
              0.51106504599871, 0.6139446534165288, 0.9546520589954179], 
             UndirectedEdge[350, 383] -> 
             RGBColor[
              0.34555625661750283`, 0.4737251941447882, 0.9432395170016354], 
             UndirectedEdge[190, 342] -> 
             RGBColor[
              0.25404838087349885`, 0.38435133426869084`, 0.9377790515086218],
              UndirectedEdge[61, 303] -> 
             RGBColor[
              0.31454260624684305`, 0.4465402877003618, 0.9412751607792637], 
             UndirectedEdge[214, 421] -> 
             RGBColor[
              0.18943186031713002`, 0.3164352742399168, 0.9340992362545124], 
             UndirectedEdge[219, 370] -> 
             RGBColor[
              0.5588561185016121, 0.6527435990376659, 0.9584143472873132], 
             UndirectedEdge[91, 366] -> 
             RGBColor[
              0.29631757138809034`, 0.4270330853875859, 0.9402501434291768], 
             UndirectedEdge[273, 477] -> 
             RGBColor[
              0.2691065215645594, 0.4001783948762585, 0.9386365903444549], 
             UndirectedEdge[153, 323] -> 
             RGBColor[
              0.24213881509518778`, 0.3718336255256024, 0.9371008193561707], 
             UndirectedEdge[170, 433] -> 
             RGBColor[
              0.31109341012253816`, 0.4427596771133032, 0.9410844199719078], 
             UndirectedEdge[1, 54] -> 
             RGBColor[
              0.24744314331957223`, 0.3774088108032645, 0.937402893001499], 
             UndirectedEdge[277, 377] -> 
             RGBColor[
              0.8762033212681233, 0.9033473444415901, 0.9473540424354466], 
             UndirectedEdge[307, 417] -> 
             RGBColor[
              0.5854211152910297, 0.6734114544902967, 0.9611201594979415], 
             UndirectedEdge[58, 371] -> 
             RGBColor[
              0.3390278312734188, 0.4680706002399412, 0.9428235315115703], 
             UndirectedEdge[9, 269] -> 
             RGBColor[
              0.512041509774998, 0.614618499836106, 0.9547617797005311], 
             UndirectedEdge[184, 453] -> 
             RGBColor[
              0.2706693526642461, 0.401821029451244, 0.9387255912635806], 
             UndirectedEdge[42, 97] -> 
             RGBColor[
              0.23210438822814727`, 0.3612868066689332, 0.936529373590697], 
             UndirectedEdge[161, 405] -> 
             RGBColor[
              0.9921723207517021, 0.9843258130245969, 0.5033188163295588], 
             UndirectedEdge[304, 429] -> 
             RGBColor[
              0.316081007071654, 0.4467946753350308, 0.9414126607624902], 
             UndirectedEdge[127, 130] -> 
             RGBColor[
              0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993],
              UndirectedEdge[318, 330] -> 
             RGBColor[
              0.32419593809646025`, 0.45501163764918373`, 0.9418862305492528],
              UndirectedEdge[393, 468] -> 
             RGBColor[
              0.4697942541627981, 0.5804391653761509, 0.9514030710822032], 
             UndirectedEdge[334, 355] -> 
             RGBColor[
              0.36575544066311605`, 0.49122071212458884`, 0.9445265911475849],
              UndirectedEdge[290, 378] -> 
             RGBColor[
              0.28478483318943354`, 0.41665729445637256`, 0.939529446997508], 
             UndirectedEdge[92, 498] -> 
             RGBColor[
              0.5355135500520953, 0.6337930503996233, 0.9565767347923217], 
             UndirectedEdge[340, 362] -> 
             RGBColor[
              0.3629480512357022, 0.4887890925060583, 0.944347706775747], 
             UndirectedEdge[58, 304] -> 
             RGBColor[
              0.3268378953241502, 0.4575122904046801, 0.94204679957202], 
             UndirectedEdge[51, 308] -> 
             RGBColor[
              0.1789366427891193, 0.3054041351827525, 0.9335015491425751], 
             UndirectedEdge[59, 447] -> 
             RGBColor[
              0.2443455259866942, 0.3741530185861272, 0.9372264882769058], 
             UndirectedEdge[186, 485] -> 
             RGBColor[
              0.24185580045044375`, 0.3715361591898116, 0.9370847020908353], 
             UndirectedEdge[340, 379] -> 
             RGBColor[
              0.32336688058112073`, 0.45450587189254155`, 0.941825629581892], 
             UndirectedEdge[129, 410] -> 
             RGBColor[
              0.3596323931506261, 0.48591723612258636`, 0.9441364359744873], 
             UndirectedEdge[192, 225] -> 
             RGBColor[
              0.26443196618769516`, 0.395265140791245, 0.9383703813311275], 
             UndirectedEdge[306, 420] -> 
             RGBColor[
              0.9131111718754747, 0.7098607039273219, 0.5703676016486996], 
             UndirectedEdge[16, 45] -> 
             RGBColor[
              0.343332276555383, 0.46939838880724916`, 0.9431857012274175], 
             UndirectedEdge[334, 361] -> 
             RGBColor[
              0.5235027630627838, 0.6226423570970218, 0.9560294677740079], 
             UndirectedEdge[306, 357] -> 
             RGBColor[
              0.8823608988640697, 0.5565720408834082, 0.22345710970379568`], 
             UndirectedEdge[335, 496] -> 
             RGBColor[
              0.27683085763382376`, 0.40829716183624876`, 0.9390764798564684],
              UndirectedEdge[176, 345] -> 
             RGBColor[
              0.6333349002315553, 0.7129428013259062, 0.9644594745728776], 
             UndirectedEdge[15, 78] -> 
             RGBColor[
              0.22683394628673456`, 0.35574723802318886`, 0.9362292297190538],
              UndirectedEdge[52, 210] -> 
             RGBColor[
              0.8359293793650189, 0.2771745309197725, 0.1820393202973592], 
             UndirectedEdge[392, 465] -> 
             RGBColor[
              0.2943134873153461, 0.42667251409427237`, 0.9400720897535981], 
             UndirectedEdge[354, 414] -> 
             RGBColor[
              0.3182109057650159, 0.4468883541768137, 0.941612493557471], 
             UndirectedEdge[56, 428] -> 
             RGBColor[
              0.8335035522712653, 0.25852856087297227`, 0.179716345532801], 
             UndirectedEdge[44, 425] -> 
             RGBColor[
              0.43601004951768985`, 0.5508944179345684, 0.9493284456568833], 
             UndirectedEdge[106, 468] -> 
             RGBColor[
              0.4981161809408796, 0.6034321814228589, 0.9536326769048099], 
             UndirectedEdge[142, 461] -> 
             RGBColor[
              0.8219899053555546, 0.8616442791794481, 0.9747961115925544], 
             UndirectedEdge[203, 297] -> 
             RGBColor[
              0.5269654224863035, 0.6268532953529551, 0.9559037948775195], 
             UndirectedEdge[24, 176] -> 
             RGBColor[
              0.7219583100603643, 0.7823133904412213, 0.9732561905650118], 
             UndirectedEdge[351, 356] -> 
             RGBColor[
              0.2796916905937343, 0.4113040786644009, 0.9392394000613121], 
             UndirectedEdge[315, 368] -> 
             RGBColor[
              0.2968006331253079, 0.42010055334026064`, 0.9405500774666419], 
             UndirectedEdge[278, 406] -> 
             RGBColor[
              0.969491060817788, 0.9705130400681918, 0.6951727540379807], 
             UndirectedEdge[247, 360] -> 
             RGBColor[
              0.5371888520305683, 0.6351531360172418, 0.9567086207009003], 
             UndirectedEdge[78, 145] -> 
             RGBColor[
              0.22004363289237822`, 0.3486101881149849, 0.9358425314166136], 
             UndirectedEdge[19, 466] -> 
             RGBColor[
              0.5316163498821903, 0.6306291277348275, 0.9562699329190321], 
             UndirectedEdge[60, 151] -> 
             RGBColor[
              0.2997519610227203, 0.4323886947798715, 0.9403818027857322], 
             UndirectedEdge[109, 186] -> 
             RGBColor[
              0.24483520726957755`, 0.37466770466202415`, 0.9372543749015474],
              UndirectedEdge[474, 495] -> 
             RGBColor[
              0.917649812825669, 0.658402887580602, 0.4760539940908434], 
             UndirectedEdge[36, 412] -> 
             RGBColor[
              0.24838538806776134`, 0.3783991697753788, 0.9374565524459821], 
             UndirectedEdge[259, 469] -> 
             RGBColor[
              0.8611356885897954, 0.46233141911773723`, 0.2058405534946276], 
             UndirectedEdge[6, 80] -> 
             RGBColor[
              0.8086163665159423, 0.8504788015959455, 0.9815424524658205], 
             UndirectedEdge[287, 389] -> 
             RGBColor[
              0.214155749354975, 0.34242164920379625`, 0.9355072251595016], 
             UndirectedEdge[158, 410] -> 
             RGBColor[
              0.3605931713874897, 0.48674941394123933`, 0.9441976559141574], 
             UndirectedEdge[414, 415] -> 
             RGBColor[
              0.2808353270487499, 0.4125061130893616, 0.9393045284655668], 
             UndirectedEdge[10, 245] -> 
             RGBColor[
              0.22026264269435236`, 0.3488403813028832, 0.93585500370084], 
             UndirectedEdge[115, 178] -> 
             RGBColor[
              0.9564265081535962, 0.965404037867567, 0.8899068420398936], 
             UndirectedEdge[88, 348] -> 
             RGBColor[
              0.9132608681622556, 0.6818120756635188, 0.2545865809359151], 
             UndirectedEdge[135, 170] -> 
             RGBColor[
              0.2736536686143132, 0.40495773473132446`, 0.9388955436420372], 
             UndirectedEdge[3, 203] -> 
             RGBColor[
              0.49811633466717364`, 0.6034323062247897, 0.9536326890067068], 
             UndirectedEdge[84, 374] -> 
             RGBColor[
              0.24252230770556474`, 0.3722367005739444, 0.9371226586930053], 
             UndirectedEdge[29, 172] -> 
             RGBColor[
              0.3806363827099919, 0.5041098361876981, 0.9454747916161113], 
             UndirectedEdge[262, 387] -> 
             RGBColor[
              0.6255998101870561, 0.7048955003973141, 0.9650590620780228], 
             UndirectedEdge[179, 276] -> 
             RGBColor[
              0.39923464670294595`, 0.5037029404652202, 0.9483463693708659], 
             UndirectedEdge[348, 428] -> 
             RGBColor[
              0.8951225528654855, 0.5552983535621828, 0.23772264959288408`], 
             UndirectedEdge[104, 351] -> 
             RGBColor[
              0.2683095588486911, 0.39934073653152624`, 0.9385912044967868], 
             UndirectedEdge[111, 271] -> 
             RGBColor[
              0.2644482810539334, 0.39528228875008364`, 0.938371310438624], 
             UndirectedEdge[136, 277] -> 
             RGBColor[
              0.8701310969045036, 0.8988186894535575, 0.9576327343932979], 
             UndirectedEdge[246, 442] -> 
             RGBColor[
              0.28908336711974203`, 0.42117532615991926`, 0.939774242145728], 
             UndirectedEdge[206, 266] -> 
             RGBColor[
              0.31612745049209645`, 0.4464579350707817, 0.9414294227127427], 
             UndirectedEdge[31, 381] -> 
             RGBColor[
              0.5111715324361403, 0.6140235083829432, 0.9546625406628318], 
             UndirectedEdge[31, 472] -> 
             RGBColor[
              0.39074248974700837`, 0.5128632381554529, 0.9461187438200305], 
             UndirectedEdge[342, 453] -> 
             RGBColor[
              0.27214698791275327`, 0.40337411778491095`, 0.9388097404050177],
              UndirectedEdge[200, 475] -> 
             RGBColor[
              0.8699156991968737, 0.47168384997259694`, 0.2119718972840306], 
             UndirectedEdge[92, 101] -> 
             RGBColor[
              0.5649851581111299, 0.6577194295027604, 0.9588968477367864], 
             UndirectedEdge[193, 376] -> 
             RGBColor[
              0.2836334092052663, 0.4154470748445156, 0.9394638751049887], 
             UndirectedEdge[253, 319] -> 
             RGBColor[
              0.8499607656875054, 0.8826374101392084, 0.934970872933598], 
             UndirectedEdge[249, 280] -> 
             RGBColor[
              0.27322012310800536`, 0.4045020509158221, 0.938870853866826], 
             UndirectedEdge[153, 195] -> 
             RGBColor[
              0.2575424446398453, 0.3880238168235591, 0.9379780332711112], 
             UndirectedEdge[313, 380] -> 
             RGBColor[
              0.26990447818225494`, 0.4010170978748282, 0.9386820327933616], 
             UndirectedEdge[178, 357] -> 
             RGBColor[
              0.9494134599221778, 0.8301932628763469, 0.5158066666080678], 
             UndirectedEdge[163, 494] -> 
             RGBColor[
              0.262747921993954, 0.39349510356905415`, 0.938274477505614], 
             UndirectedEdge[24, 237] -> 
             RGBColor[
              0.871532203465174, 0.9004001382044219, 0.9876087136641327], 
             UndirectedEdge[101, 345] -> 
             RGBColor[
              0.5902789610650883, 0.677988050262613, 0.9610699533225915], 
             UndirectedEdge[320, 361] -> 
             RGBColor[
              0.8164019725999951, 0.8557645940777792, 0.9018606390244552], 
             UndirectedEdge[328, 487] -> 
             RGBColor[
              0.4823721914903405, 0.5888040064890694, 0.952903444464096], 
             UndirectedEdge[322, 494] -> 
             RGBColor[
              0.2588610411681461, 0.3894097453786518, 0.9380531253927091], 
             UndirectedEdge[108, 266] -> 
             RGBColor[
              0.28731571918259713`, 0.4193174161026276, 0.9396735772107083], 
             UndirectedEdge[405, 474] -> 
             RGBColor[
              0.9935549188322322, 0.9905077851325332, 0.6768786341569868], 
             UndirectedEdge[338, 379] -> 
             RGBColor[
              0.31470226354501973`, 0.4470010161121858, 0.9412735278461717], 
             UndirectedEdge[175, 309] -> 
             RGBColor[
              0.9743805147039586, 0.9770030600582216, 0.7213206267986814], 
             UndirectedEdge[294, 430] -> 
             RGBColor[
              0.23902588418057213`, 0.36856173776312173`, 0.9369235425457519],
              UndirectedEdge[197, 237] -> 
             RGBColor[
              0.8018590077882369, 0.845833600411511, 0.9807007779188375], 
             UndirectedEdge[94, 500] -> 
             RGBColor[
              0.8874558706447166, 0.5585534617562613, 0.5633237757723539], 
             UndirectedEdge[242, 365] -> 
             RGBColor[
              0.22099114578241763`, 0.3496060842382034, 0.9358964908739815], 
             UndirectedEdge[401, 500] -> 
             RGBColor[
              0.7964725199858478, 0.48689043193741693`, 0.5721768321079614], 
             UndirectedEdge[334, 340] -> 
             RGBColor[
              0.37011932022613914`, 0.4950004852671151, 0.9448046536945134], 
             UndirectedEdge[60, 310] -> 
             RGBColor[
              0.2947333345295756, 0.4271138001362785, 0.9400959994313403], 
             UndirectedEdge[50, 379] -> 
             RGBColor[
              0.37511861305326666`, 0.49933062144220947`, 0.9451232042127569],
              UndirectedEdge[123, 177] -> 
             RGBColor[
              0.2078300375710318, 0.33577292504558, 0.935146985231458], 
             UndirectedEdge[231, 246] -> 
             RGBColor[
              0.27633388437422024`, 0.407774811430481, 0.93904817796454], 
             UndirectedEdge[182, 282] -> 
             RGBColor[
              0.4931225250647846, 0.5973489755441486, 0.9538002129842165], 
             UndirectedEdge[185, 193] -> 
             RGBColor[
              0.28587823371129695`, 0.41780652773044813`, 0.9395917145396869],
              UndirectedEdge[395, 447] -> 
             RGBColor[
              0.2557437599820415, 0.3861332852050131, 0.9378756008407647], 
             UndirectedEdge[22, 282] -> 
             RGBColor[
              0.5295374583805197, 0.6288897605144723, 0.956120540334634], 
             UndirectedEdge[195, 323] -> 
             RGBColor[
              0.2547482956718921, 0.38508698909896344`, 0.9378189106209592], 
             UndirectedEdge[99, 486] -> 
             RGBColor[
              0.9642745659488295, 0.9698576677518461, 0.7703884518083142], 
             UndirectedEdge[454, 469] -> 
             RGBColor[
              0.8801565520867384, 0.5487007178218191, 0.22171202824050545`], 
             UndirectedEdge[31, 208] -> 
             RGBColor[
              0.38757839390763205`, 0.5101226573714661, 0.9459171304310454], 
             UndirectedEdge[398, 472] -> 
             RGBColor[
              0.2947988861662292, 0.4253612331985043, 0.9401664252880289], 
             UndirectedEdge[191, 389] -> 
             RGBColor[
              0.21845058194335062`, 0.3469357905622929, 0.9357518095217741], 
             UndirectedEdge[133, 151] -> 
             RGBColor[
              0.3259839947322987, 0.4565922388339624, 0.9419989967859217], 
             UndirectedEdge[165, 268] -> 
             RGBColor[
              0.4168440173490807, 0.5354710694634455, 0.9477819100781599], 
             UndirectedEdge[166, 495] -> 
             RGBColor[
              0.8401614416386582, 0.3097040160564781, 0.18609194791002698`], 
             UndirectedEdge[346, 430] -> 
             RGBColor[
              0.22881084125106885`, 0.35782507997308444`, 0.9363418109627185],
              UndirectedEdge[169, 219] -> 
             RGBColor[
              0.5095055418565787, 0.6126785776990856, 0.9545292891166974], 
             UndirectedEdge[197, 345] -> 
             RGBColor[
              0.6786754086563489, 0.7489056544572683, 0.9686076802187304], 
             UndirectedEdge[100, 213] -> 
             RGBColor[
              0.9177103751290299, 0.7114500107948662, 0.2526457256885956], 
             UndirectedEdge[73, 187] -> 
             RGBColor[
              0.25626928229983936`, 0.38668564248105813`, 0.9379055285593227],
              UndirectedEdge[97, 346] -> 
             RGBColor[
              0.22480858213955662`, 0.353618451889001, 0.9361138882271296], 
             UndirectedEdge[129, 170] -> 
             RGBColor[
              0.3261401713486173, 0.4557924254151241, 0.9420431862919051], 
             UndirectedEdge[36, 37] -> 
             RGBColor[
              0.2800147441029785, 0.41164362838539204`, 0.9392577974807488], 
             UndirectedEdge[143, 302] -> 
             RGBColor[
              0.1845381798446758, 0.31129170578610466`, 0.9338205483911577], 
             UndirectedEdge[16, 236] -> 
             RGBColor[
              0.34560261915581325`, 0.4717846628283363, 0.9433149938798411], 
             UndirectedEdge[187, 322] -> 
             RGBColor[
              0.2619233226556958, 0.392628397381927, 0.9382275177931856], 
             UndirectedEdge[108, 163] -> 
             RGBColor[
              0.27605150294224795`, 0.40747801064146116`, 0.939032096759735], 
             UndirectedEdge[137, 346] -> 
             RGBColor[
              0.21898159921391522`, 0.34749392338209584`, 0.9357820501697631],
              UndirectedEdge[243, 276] -> 
             RGBColor[
              0.7294231328480298, 0.5025695960181678, 0.5742322488928711], 
             UndirectedEdge[131, 147] -> 
             RGBColor[
              0.257551109678863, 0.38803292432896186`, 0.9379785267322645], 
             UndirectedEdge[9, 468] -> 
             RGBColor[
              0.5267603512092651, 0.6266868092518996, 0.9558876509153902], 
             UndirectedEdge[331, 377] -> 
             RGBColor[
              0.9088984029132244, 0.9290240327940705, 0.9505769466051841], 
             UndirectedEdge[280, 470] -> 
             RGBColor[
              0.25618724239569113`, 0.386599413340168, 0.9379008565081486], 
             UndirectedEdge[234, 468] -> 
             RGBColor[
              0.4334778335161593, 0.5491980337433716, 0.9490298017896481], 
             UndirectedEdge[136, 488] -> 
             RGBColor[
              0.8691624812525807, 0.8980619995445237, 0.9575361918373422], 
             UndirectedEdge[57, 361] -> 
             RGBColor[
              0.622722217665552, 0.7045647515271736, 0.9634614174292722], 
             UndirectedEdge[196, 414] -> 
             RGBColor[
              0.2851786513362504, 0.4170712222981897, 0.9395518743583675], 
             UndirectedEdge[103, 319] -> 
             RGBColor[
              0.5976226950866923, 0.6831049747415705, 0.9622258440138658], 
             UndirectedEdge[224, 263] -> 
             RGBColor[
              0.2861834719747001, 0.4181273524985085, 0.9396090974072282], 
             UndirectedEdge[89, 184] -> 
             RGBColor[
              0.271266794829508, 0.4024489790469554, 0.9387596147110557], 
             UndirectedEdge[137, 407] -> 
             RGBColor[
              0.2172194419002935, 0.34564178431825265`, 0.9356816979176306], 
             UndirectedEdge[53, 272] -> 
             RGBColor[
              0.8985476192245749, 0.5458238236085153, 0.2652993601444404], 
             UndirectedEdge[236, 243] -> 
             RGBColor[
              0.5633146331293595, 0.36122739545781846`, 0.562473440762307], 
             UndirectedEdge[26, 351] -> 
             RGBColor[
              0.3383374936256977, 0.4657436708748698, 0.9428428507321864], 
             UndirectedEdge[67, 96] -> 
             RGBColor[
              0.2763924027630132, 0.4078363179673825, 0.9390515105002115], 
             UndirectedEdge[284, 464] -> 
             RGBColor[
              0.24447969866104266`, 0.37429404257390636`, 0.9372341292122193],
              UndirectedEdge[325, 401] -> 
             RGBColor[
              0.4762346490241563, 0.5642173274993956, 0.9557801417908952], 
             UndirectedEdge[227, 348] -> 
             RGBColor[
              0.9027713884189711, 0.6140906553673846, 0.24504718315702606`], 
             UndirectedEdge[106, 117] -> 
             RGBColor[
              0.44946530583261596`, 0.561973649912251, 0.9503446865091629], 
             UndirectedEdge[395, 440] -> 
             RGBColor[
              0.2733307058970075, 0.4046182804384171, 0.9388771513930672], 
             UndirectedEdge[204, 361] -> 
             RGBColor[
              0.5730472494558454, 0.6642363745027182, 0.9595508219663998], 
             UndirectedEdge[195, 263] -> 
             RGBColor[
              0.27177628853634817`, 0.40298448923661123`, 0.9387886296239321],
              UndirectedEdge[360, 393] -> 
             RGBColor[
              0.5202889035975207, 0.6214329965452928, 0.9553781948537], 
             UndirectedEdge[74, 440] -> 
             RGBColor[
              0.2817039259800564, 0.4134190656385177, 0.9393539938897277], 
             UndirectedEdge[166, 348] -> 
             RGBColor[
              0.8990160108059699, 0.5852251774168952, 0.24145102931372386`], 
             UndirectedEdge[209, 477] -> 
             RGBColor[
              0.40529759982577535`, 0.5164885241169046, 0.9481078912022864], 
             UndirectedEdge[292, 422] -> 
             RGBColor[
              0.20649131825242792`, 0.3343658461620201, 0.9350707471467212], 
             UndirectedEdge[36, 416] -> 
             RGBColor[
              0.2579614870777197, 0.3884642569945902, 0.9380018971180304], 
             UndirectedEdge[306, 418] -> 
             RGBColor[
              0.9180265023958543, 0.7135265493813059, 0.5620472292012149], 
             UndirectedEdge[363, 498] -> 
             RGBColor[
              0.433350434496959, 0.5495353617267253, 0.948897990208064], 
             UndirectedEdge[57, 466] -> 
             RGBColor[
              0.552375580457491, 0.6474824063085367, 0.957904175593487], 
             UndirectedEdge[263, 395] -> 
             RGBColor[
              0.2691941123375187, 0.40027045833221453`, 0.938641578509396], 
             UndirectedEdge[171, 238] -> 
             RGBColor[
              0.2909480728266918, 0.4220805098947036, 0.9399190535823698], 
             UndirectedEdge[42, 286] -> 
             RGBColor[
              0.2277872668823118, 0.3567492384131574, 0.9362835199166604], 
             UndirectedEdge[246, 444] -> 
             RGBColor[
              0.2827572278979614, 0.41452615273743476`, 0.9394139778757318], 
             UndirectedEdge[46, 306] -> 
             RGBColor[
              0.8876171805650555, 0.5774114462757728, 0.22768643734119767`], 
             UndirectedEdge[229, 411] -> 
             RGBColor[
              0.26528288174741516`, 0.39615950699567326`, 0.9384188397134368],
              UndirectedEdge[239, 440] -> 
             RGBColor[
              0.3163021777955242, 0.4458837751629835, 0.9414671202878849], 
             UndirectedEdge[57, 106] -> 
             RGBColor[
              0.5595491629932491, 0.6533062437772754, 0.9584689062884005], 
             UndirectedEdge[60, 280] -> 
             RGBColor[
              0.2748009878347767, 0.4061636399762716, 0.9389608817743358], 
             UndirectedEdge[438, 457] -> 
             RGBColor[
              0.22152681415849518`, 0.35016910566479753`, 0.9359269963955489],
              UndirectedEdge[130, 368] -> 
             RGBColor[
              0.2935143249909316, 0.4166464351270609, 0.9403629270800464], 
             UndirectedEdge[152, 287] -> 
             RGBColor[
              0.20690732578417442`, 0.33480309645428663`, 0.9350944381602262],
              UndirectedEdge[54, 242] -> 
             RGBColor[
              0.22686421194138368`, 0.35577904914517844`, 0.936230953303312], 
             UndirectedEdge[89, 235] -> 
             RGBColor[
              0.32127172035398965`, 0.45054205661512126`, 0.9417708166396943],
              UndirectedEdge[60, 260] -> 
             RGBColor[
              0.2891430137819674, 0.4212380185837349, 0.9397776389349024], 
             UndirectedEdge[88, 243] -> 
             RGBColor[
              0.8529581179820884, 0.3951595604413297, 0.19784071975882145`], 
             UndirectedEdge[36, 367] -> 
             RGBColor[
              0.2421171751521342, 0.3718108805734015, 0.9370995869934273], 
             UndirectedEdge[17, 282] -> 
             RGBColor[
              0.7438148228852721, 0.7997463454963281, 0.9753349394405884], 
             UndirectedEdge[150, 233] -> 
             RGBColor[
              0.832302226448087, 0.24929464417169217`, 0.1785659545678221], 
             UndirectedEdge[250, 365] -> 
             RGBColor[
              0.21070999979849359`, 0.338799947946794, 0.9353109948197895], 
             UndirectedEdge[107, 423] -> 
             RGBColor[
              0.18624879198055028`, 0.31308966759998247`, 0.9339179652216718],
              UndirectedEdge[315, 347] -> 
             RGBColor[
              0.1822133081343763, 0.30884811821319974`, 0.9336881503865955], 
             UndirectedEdge[288, 492] -> 
             RGBColor[
              0.26634261157442907`, 0.39727335023461663`, 0.9384791897593554],
              UndirectedEdge[24, 267] -> 
             RGBColor[
              0.9130173103236416, 0.9238052630986108, 0.6981615264074577], 
             UndirectedEdge[198, 480] -> 
             RGBColor[
              0.3177133386514768, 0.44712506118461215`, 0.9415563421819749], 
             UndirectedEdge[4, 479] -> 
             RGBColor[
              0.3678971603336924, 0.49307576205728143`, 0.9446630596311456], 
             UndirectedEdge[133, 239] -> 
             RGBColor[
              0.34805209112246643`, 0.47588696054869806`, 0.943398549369312], 
             UndirectedEdge[115, 253] -> 
             RGBColor[
              0.9531001134456565, 0.9640284881713892, 0.9450338107840079], 
             UndirectedEdge[199, 371] -> 
             RGBColor[
              0.3528938984406201, 0.480080690691371, 0.9437070650501826], 
             UndirectedEdge[93, 189] -> 
             RGBColor[
              0.26453032177670965`, 0.3953685187514038, 0.9383759825364177], 
             UndirectedEdge[357, 418] -> 
             RGBColor[
              0.9428078871600445, 0.8265116366232681, 0.582732825135219], 
             UndirectedEdge[82, 463] -> 
             RGBColor[
              0.26268799213192734`, 0.3934321134842913, 0.9382710645886299], 
             UndirectedEdge[102, 350] -> 
             RGBColor[
              0.3193537748201921, 0.44805203074969097`, 0.941678953195245], 
             UndirectedEdge[235, 296] -> 
             RGBColor[
              0.3352307721420522, 0.4647817784660925, 0.9425815862613272], 
             UndirectedEdge[26, 360] -> 
             RGBColor[
              0.48299792974153133`, 0.5893477559050426, 0.9529428278924086], 
             UndirectedEdge[309, 320] -> 
             RGBColor[
              0.9908166313021023, 0.9885283450055495, 0.6606847997028811], 
             UndirectedEdge[13, 229] -> 
             RGBColor[
              0.2937960299949141, 0.4261286336418093, 0.9400426213247091], 
             UndirectedEdge[353, 420] -> 
             RGBColor[
              0.8041526849608935, 0.8472401733654197, 0.9513697071701304], 
             UndirectedEdge[171, 465] -> 
             RGBColor[
              0.27218390368581785`, 0.4034129186029971, 0.9388118427036817], 
             UndirectedEdge[104, 224] -> 
             RGBColor[
              0.2727699797429894, 0.40402892169845256`, 0.9388452188681158], 
             UndirectedEdge[22, 285] -> 
             RGBColor[
              0.38291743430858444`, 0.506085568433412, 0.9456201382069189], 
             UndirectedEdge[126, 285] -> 
             RGBColor[
              0.28277807837083513`, 0.4140236211798849, 0.9394343678430408], 
             UndirectedEdge[98, 319] -> 
             RGBColor[
              0.8550622111994015, 0.8847062165139711, 0.8474629923061501], 
             UndirectedEdge[286, 411] -> 
             RGBColor[
              0.2313451146629863, 0.3604887620112245, 0.9364861340844057], 
             UndirectedEdge[259, 491] -> 
             RGBColor[
              0.9280010655847133, 0.727726462964249, 0.4061574584267472], 
             UndirectedEdge[1, 266] -> 
             RGBColor[
              0.27784311638010406`, 0.40936110995950087`, 0.9391341264945663],
              UndirectedEdge[67, 216] -> 
             RGBColor[
              0.26125452628926693`, 0.3919254499966715, 0.938189430829513], 
             UndirectedEdge[41, 451] -> 
             RGBColor[
              0.22198624668627384`, 0.3506519983811976, 0.9359531603983363], 
             UndirectedEdge[300, 456] -> 
             RGBColor[
              0.22480808787876505`, 0.3536179323895711, 0.9361138600797088], 
             UndirectedEdge[117, 139] -> 
             RGBColor[
              0.47255522666265165`, 0.5807190878311534, 0.9521624096580703], 
             UndirectedEdge[70, 96] -> 
             RGBColor[
              0.2772059489257, 0.4086914065661722, 0.9390978407506428], 
             UndirectedEdge[92, 274] -> 
             RGBColor[
              0.5359359247795917, 0.6341359532311694, 0.9566099856780799], 
             UndirectedEdge[241, 436] -> 
             RGBColor[
              0.5892009770363313, 0.6764119562142918, 0.9614643256448061], 
             UndirectedEdge[207, 295] -> 
             RGBColor[
              0.22332543873759936`, 0.352059574136821, 0.9360294254045023], 
             UndirectedEdge[83, 176] -> 
             RGBColor[
              0.7638451540938651, 0.8157128228854424, 0.9772513951417543], 
             UndirectedEdge[56, 495] -> 
             RGBColor[
              0.839438039950976, 0.30414363368831143`, 0.18539921763693712`], 
             UndirectedEdge[219, 334] -> 
             RGBColor[
              0.4645364889888964, 0.5747991033502236, 0.9513681298117886], 
             UndirectedEdge[124, 357] -> 
             RGBColor[
              0.9348974167088442, 0.7776187751730486, 0.27677767167712564`], 
             UndirectedEdge[40, 291] -> 
             RGBColor[
              0.5205636488996574, 0.6196411124817705, 0.9560349926032045], 
             UndirectedEdge[7, 487] -> 
             RGBColor[
              0.7090567422484308, 0.7718269420846646, 0.9722547745917934], 
             UndirectedEdge[423, 477] -> 
             RGBColor[
              0.21624875945532895`, 0.3446215355237733, 0.9356264189883857], 
             UndirectedEdge[22, 165] -> 
             RGBColor[
              0.4377248912958056, 0.5535570329728583, 0.9491124209018134], 
             UndirectedEdge[302, 368] -> 
             RGBColor[
              0.2991255041617159, 0.42254414020486286`, 0.9406824754328269], 
             UndirectedEdge[297, 419] -> 
             RGBColor[
              0.5160273723962365, 0.6179732935362974, 0.9550427115070317], 
             UndirectedEdge[263, 463] -> 
             RGBColor[
              0.2702490064672201, 0.4013792189466815, 0.9387016531695065], 
             UndirectedEdge[260, 424] -> 
             RGBColor[
              0.3030854306847971, 0.434796914253921, 0.9406117494194473], 
             UndirectedEdge[193, 415] -> 
             RGBColor[
              0.28741220208324925`, 0.41941882574858214`, 0.9396790717691668],
              UndirectedEdge[434, 474] -> 
             RGBColor[
              0.992149866333044, 0.99102178223655, 0.7797605605635565], 
             UndirectedEdge[102, 109] -> 
             RGBColor[
              0.265248780611274, 0.396123664539452, 0.9384168977041816], 
             UndirectedEdge[58, 118] -> 
             RGBColor[
              0.3201099243225116, 0.4516848600807156, 0.9416180992091068], 
             UndirectedEdge[39, 100] -> 
             RGBColor[
              0.7774382200691679, 0.7351762203070193, 0.6135140654406412], 
             UndirectedEdge[35, 216] -> 
             RGBColor[
              0.25212920477180323`, 0.3823341585030158, 0.9376697572687969], 
             UndirectedEdge[72, 163] -> 
             RGBColor[
              0.26048838412385666`, 0.3911201860046064, 0.9381458001665987], 
             UndirectedEdge[202, 414] -> 
             RGBColor[
              0.25685751416132785`, 0.38730391146353665`, 0.9379390274936235],
              UndirectedEdge[324, 441] -> 
             RGBColor[
              0.4099049258998564, 0.5294607772190044, 0.947339757307013], 
             UndirectedEdge[18, 52] -> 
             RGBColor[
              0.8600894824934477, 0.42201909265360843`, 0.20357506457964797`],
              UndirectedEdge[168, 368] -> 
             RGBColor[
              0.6594469349895435, 0.6059633899066202, 0.5971521921376893], 
             UndirectedEdge[208, 397] -> 
             RGBColor[
              0.3403332891441403, 0.46920132223333977`, 0.9429067141327215], 
             UndirectedEdge[193, 350] -> 
             RGBColor[
              0.3249908553866274, 0.4539769598365655, 0.94199997659419], 
             UndirectedEdge[2, 365] -> 
             RGBColor[
              0.21471117528305686`, 0.3430054370702481, 0.9355388558444269], 
             UndirectedEdge[42, 248] -> 
             RGBColor[
              0.2375069627028864, 0.3669652549848901, 0.9368370422146407], 
             UndirectedEdge[46, 68] -> 
             RGBColor[
              0.8688206529626022, 0.4329330984324026, 0.20968686128144703`], 
             UndirectedEdge[260, 470] -> 
             RGBColor[
              0.2705292683428818, 0.4016737919476313, 0.9387176136687151], 
             UndirectedEdge[32, 344] -> 
             RGBColor[
              0.49972685632516956`, 0.6047398002599247, 0.9537594751711596], 
             UndirectedEdge[60, 483] -> 
             RGBColor[
              0.29467938491288026`, 0.4270570956685284, 0.9400929270804808], 
             UndirectedEdge[337, 498] -> 
             RGBColor[
              0.6610501058244442, 0.7326972089760198, 0.9686548196773171], 
             UndirectedEdge[86, 168] -> 
             RGBColor[
              0.912992655814064, 0.6927519043211215, 0.24885005242438252`], 
             UndirectedEdge[151, 424] -> 
             RGBColor[
              0.31369437792555, 0.4459475904500576, 0.9412159132702771], 
             UndirectedEdge[234, 296] -> 
             RGBColor[
              0.3509992318996893, 0.478439625762326, 0.9435863385735823], 
             UndirectedEdge[223, 268] -> 
             RGBColor[
              0.3997592820050565, 0.5206731304122181, 0.946693285849477], 
             UndirectedEdge[50, 204] -> 
             RGBColor[
              0.47141553909134676`, 0.5814192522224795, 0.9516235825177704], 
             UndirectedEdge[26, 247] -> 
             RGBColor[
              0.44082045923577545`, 0.5551061852750767, 0.9496224629130303], 
             UndirectedEdge[64, 435] -> 
             RGBColor[
              0.2729760661843835, 0.4042455316149929, 0.9388569551860756], 
             UndirectedEdge[143, 214] -> 
             RGBColor[
              0.18936705810043614`, 0.31636716300147366`, 0.934095545864138], 
             UndirectedEdge[38, 266] -> 
             RGBColor[
              0.27474470932625494`, 0.40610448769555174`, 0.9389576767965321],
              UndirectedEdge[309, 375] -> 
             RGBColor[
              0.9756161016685031, 0.977924558793291, 0.7192291003603996], 
             UndirectedEdge[70, 385] -> 
             RGBColor[
              0.24586087527331454`, 0.37574574676505923`, 0.9373127851770204],
              UndirectedEdge[232, 354] -> 
             RGBColor[
              0.35898073503518557`, 0.48535280261628094`, 0.94409491289561], 
             UndirectedEdge[86, 484] -> 
             RGBColor[
              0.9540423951293819, 0.8443401430723285, 0.3591520108030784], 
             UndirectedEdge[106, 360] -> 
             RGBColor[
              0.5486108303756021, 0.6444260125920007, 0.9576078006763067], 
             UndirectedEdge[163, 322] -> 
             RGBColor[
              0.26310542995763675`, 0.3938708671061988, 0.9382948370552601], 
             UndirectedEdge[44, 117] -> 
             RGBColor[
              0.4388762614701655, 0.5533769866678013, 0.9495110781480034], 
             UndirectedEdge[113, 273] -> 
             RGBColor[
              0.23636683819300525`, 0.3657669118369359, 0.936772113810466], 
             UndirectedEdge[53, 298] -> 
             RGBColor[
              0.9390760601522875, 0.9284198827471832, 0.6768677898959217], 
             UndirectedEdge[50, 369] -> 
             RGBColor[
              0.43044272533776096`, 0.5472495868323034, 0.9486484077263333], 
             UndirectedEdge[135, 385] -> 
             RGBColor[
              0.24204917775156742`, 0.37173941099412156`, 0.9370957146420581],
              UndirectedEdge[376, 464] -> 
             RGBColor[
              0.2616609318454717, 0.3923526080038432, 0.9382125750247157], 
             UndirectedEdge[95, 408] -> 
             RGBColor[
              0.22479372667970515`, 0.35360283785880653`, 0.9361130422306678],
              UndirectedEdge[34, 332] -> 
             RGBColor[
              0.47297256082386624`, 0.5816312685861409, 0.9520368398699108], 
             UndirectedEdge[251, 416] -> 
             RGBColor[
              0.26003944376158217`, 0.39064832121939286`, 0.9381202336771148],
              UndirectedEdge[62, 209] -> 
             RGBColor[
              0.6916212861064526, 0.39630413817282756`, 0.5615943615662011], 
             UndirectedEdge[109, 496] -> 
             RGBColor[
              0.26542477376877, 0.3963086445065909, 0.9384269202541424], 
             UndirectedEdge[179, 254] -> 
             RGBColor[
              0.20771369325605188`, 0.33565063979388043`, 0.9351403595948358],
              UndirectedEdge[27, 199] -> 
             RGBColor[
              0.4274813973658525, 0.5430880506381621, 0.9489008550961784], 
             UndirectedEdge[59, 453] -> 
             RGBColor[
              0.26324896867774317`, 0.3940217354019111, 0.9383030113730237], 
             UndirectedEdge[450, 475] -> 
             RGBColor[
              0.8283559372455574, 0.2189617360860943, 0.17478698357078354`], 
             UndirectedEdge[311, 331] -> 
             RGBColor[
              0.7917742816822333, 0.837394395727864, 0.9798444828971542], 
             UndirectedEdge[329, 486] -> 
             RGBColor[
              0.9087427412464592, 0.930070810978078, 0.9911578879759511], 
             UndirectedEdge[287, 456] -> 
             RGBColor[
              0.21673512234064032`, 0.34513273375342357`, 0.9356541166351948],
              UndirectedEdge[60, 118] -> 
             RGBColor[
              0.30890885152103453`, 0.4405003788871604, 0.9409586647466246], 
             UndirectedEdge[267, 493] -> 
             RGBColor[
              0.991319933690298, 0.9817192401312839, 0.4771566948770857], 
             UndirectedEdge[239, 263] -> 
             RGBColor[
              0.31216558423603546`, 0.4415359530567809, 0.9412315474042139], 
             UndirectedEdge[64, 91] -> 
             RGBColor[
              0.3077316474117898, 0.43903000298271255`, 0.9409001581731142], 
             UndirectedEdge[469, 471] -> 
             RGBColor[
              0.8586216305057723, 0.4484110579890054, 0.20364468753654688`], 
             UndirectedEdge[275, 282] -> 
             RGBColor[
              0.5106811757652547, 0.612557396257451, 0.9549190346803453], 
             UndirectedEdge[132, 423] -> 
             RGBColor[
              0.5889794016641527, 0.6524675094432201, 0.8735972473293918], 
             UndirectedEdge[116, 412] -> 
             RGBColor[
              0.24555371763094103`, 0.3754229046080053, 0.9372952930036862], 
             UndirectedEdge[89, 453] -> 
             RGBColor[
              0.28490427469255214`, 0.4167828350491789, 0.9395362490144127], 
             UndirectedEdge[136, 311] -> 
             RGBColor[
              0.8579087651395905, 0.8892705109856455, 0.9564145265871555], 
             UndirectedEdge[6, 24] -> 
             RGBColor[
              0.8323309168683787, 0.869142096362715, 0.9838696599531287], 
             UndirectedEdge[51, 477] -> 
             RGBColor[
              0.21179931412463662`, 0.3399448863700877, 0.9353730296591674], 
             UndirectedEdge[114, 381] -> 
             RGBColor[
              0.5349916430046526, 0.6333693427468647, 0.9565356483577385], 
             UndirectedEdge[95, 294] -> 
             RGBColor[
              0.2326978312332123, 0.36191055289371626`, 0.9365631692919152], 
             UndirectedEdge[89, 192] -> 
             RGBColor[
              0.27005817816264466`, 0.4011786462993594, 0.9386907857798661], 
             UndirectedEdge[108, 374] -> 
             RGBColor[
              0.2684205085848909, 0.3994573517388918, 0.938597522920128], 
             UndirectedEdge[208, 472] -> 
             RGBColor[
              0.32528262084800263`, 0.45616518982380916`, 0.9419476988576752],
              UndirectedEdge[34, 360] -> 
             RGBColor[
              0.5615596954334325, 0.6549384845856707, 0.9586271827669148], 
             UndirectedEdge[395, 453] -> 
             RGBColor[
              0.2746472026730905, 0.406002002020797, 0.9389521239368825], 
             UndirectedEdge[101, 361] -> 
             RGBColor[
              0.5825170875925927, 0.671924415713476, 0.9602963223136847], 
             UndirectedEdge[11, 211] -> 
             RGBColor[
              0.23497926878004616`, 0.3643084884069338, 0.936693093785123], 
             UndirectedEdge[70, 433] -> 
             RGBColor[
              0.2918782074405654, 0.4225632807803333, 0.9399901426055144], 
             UndirectedEdge[108, 206] -> 
             RGBColor[
              0.31392242641055057`, 0.44414031495447526`, 0.9413038498533395],
              UndirectedEdge[251, 499] -> 
             RGBColor[
              0.25963192027097015`, 0.39021998819227793`, 0.9380970258172014],
              UndirectedEdge[116, 399] -> 
             RGBColor[
              0.24511345141386065`, 0.3749601568993634, 0.937270220493939], 
             UndirectedEdge[350, 479] -> 
             RGBColor[
              0.3868303332701487, 0.5094747248458988, 0.9458694646687091], 
             UndirectedEdge[347, 421] -> 
             RGBColor[
              0.17899180289058533`, 0.3054621119467458, 0.9335046904287516], 
             UndirectedEdge[153, 447] -> 
             RGBColor[
              0.24571645560416666`, 0.3755939525360489, 0.9373045606905122], 
             UndirectedEdge[195, 453] -> 
             RGBColor[
              0.27722937887191995`, 0.40871603292519376`, 0.9390991750514186],
              UndirectedEdge[338, 425] -> 
             RGBColor[
              0.3477240886796976, 0.47560286131865376`, 0.9433776493436998], 
             UndirectedEdge[164, 348] -> 
             RGBColor[
              0.8887181595032059, 0.5060713797566354, 0.23158979527643736`], 
             UndirectedEdge[31, 258] -> 
             RGBColor[
              0.4132303526475083, 0.5323410947270124, 0.947551650558814], 
             UndirectedEdge[31, 203] -> 
             RGBColor[
              0.4938024492349883, 0.5999225041719667, 0.9532951828081889], 
             UndirectedEdge[398, 445] -> 
             RGBColor[
              0.2453951867466454, 0.3752562785971719, 0.9372862649043511], 
             UndirectedEdge[44, 369] -> 
             RGBColor[
              0.4583123366675063, 0.5702115381181944, 0.9507495276729314], 
             UndirectedEdge[267, 278] -> 
             RGBColor[
              0.9687131736129876, 0.9678890438697982, 0.6921508091390034], 
             UndirectedEdge[130, 477] -> 
             RGBColor[
              0.2117993137193227, 0.3399448859440771, 0.9353730296360853], 
             UndirectedEdge[4, 482] -> 
             RGBColor[
              0.3413925426988842, 0.4701187944228272, 0.9429742088325687], 
             UndirectedEdge[219, 274] -> 
             RGBColor[
              0.49450158018716717`, 0.6004976856950868, 0.9533481222927589], 
             UndirectedEdge[44, 269] -> 
             RGBColor[
              0.4728082951441619, 0.5827672087626157, 0.9516731973287911], 
             UndirectedEdge[130, 143] -> 
             RGBColor[
              0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772],
              UndirectedEdge[315, 401] -> 
             RGBColor[
              0.47947599697395743`, 0.5676241897079666, 0.9559647317614918], 
             UndirectedEdge[75, 163] -> 
             RGBColor[
              0.3059704107658049, 0.43557751025778224`, 0.9408584905702073], 
             UndirectedEdge[9, 139] -> 
             RGBColor[
              0.5695894293133013, 0.6614573842847371, 0.9592593128318224], 
             UndirectedEdge[134, 438] -> 
             RGBColor[
              0.22733547187831532`, 0.35627437321849936`, 0.9362577908595535],
              UndirectedEdge[76, 431] -> 
             RGBColor[
              0.42993261586454035`, 0.5468077556454473, 0.9486159040017718], 
             UndirectedEdge[90, 124] -> 
             RGBColor[
              0.9137111635376958, 0.6822566946723914, 0.2591427819494134], 
             UndirectedEdge[37, 188] -> 
             RGBColor[
              0.3214586719550145, 0.4525659249433619, 0.9417145542769817], 
             UndirectedEdge[26, 106] -> 
             RGBColor[
              0.45224243758080923`, 0.5643790618498358, 0.9505216428884367], 
             UndirectedEdge[107, 446] -> 
             RGBColor[
              0.2064114829025504, 0.3342819341474452, 0.9350662006416515], 
             UndirectedEdge[19, 234] -> 
             RGBColor[
              0.474151584993228, 0.582218817524079, 0.9522317884987839], 
             UndirectedEdge[39, 243] -> 
             RGBColor[
              0.7314838484501698, 0.504242577778165, 0.5743944759737214], 
             UndirectedEdge[129, 265] -> 
             RGBColor[
              0.3383071396578693, 0.46744637338556605`, 0.9427776096791101], 
             UndirectedEdge[396, 446] -> 
             RGBColor[
              0.6108486673250959, 0.6728679174892245, 0.7376055193707824], 
             UndirectedEdge[325, 368] -> 
             RGBColor[
              0.2935592851755068, 0.41669369113168975`, 0.9403654874960453], 
             UndirectedEdge[52, 56] -> 
             RGBColor[
              0.836234326611525, 0.27951848908515425`, 0.18233133812500216`], 
             UndirectedEdge[402, 431] -> 
             RGBColor[
              0.5004255816893457, 0.6051773211877334, 0.9538503277794443], 
             UndirectedEdge[165, 353] -> 
             RGBColor[
              0.531847897863051, 0.630021959343577, 0.9565078633928767], 
             UndirectedEdge[237, 329] -> 
             RGBColor[
              0.8943251384864865, 0.9185746058926771, 0.989782724153959], 
             UndirectedEdge[63, 75] -> 
             RGBColor[
              0.38214205273411095`, 0.5054139718854141, 0.9455707315786365], 
             UndirectedEdge[392, 492] -> 
             RGBColor[
              0.2913103527973019, 0.4235160293060819, 0.9399010656855349], 
             UndirectedEdge[125, 177] -> 
             RGBColor[
              0.20868507222126964`, 0.3366716206753079, 0.9351956781898786], 
             UndirectedEdge[210, 348] -> 
             RGBColor[
              0.8979876618717816, 0.5773208368833467, 0.24046628121299102`], 
             UndirectedEdge[469, 491] -> 
             RGBColor[
              0.9272960549745825, 0.7245251744430564, 0.40556918029226263`], 
             UndirectedEdge[35, 171] -> 
             RGBColor[
              0.25005732664065045`, 0.38015648322251344`, 0.9375517668742968],
              UndirectedEdge[8, 40] -> 
             RGBColor[
              0.5032468930597369, 0.6057751178648505, 0.9545401217837302], 
             UndirectedEdge[405, 491] -> 
             RGBColor[
              0.9940870576802556, 0.9897611392052678, 0.5977909028249961], 
             UndirectedEdge[98, 136] -> 
             RGBColor[
              0.9820976999154852, 0.9842937020241562, 0.8300672430323528], 
             UndirectedEdge[14, 75] -> 
             RGBColor[
              0.32584559541094904`, 0.45646758947931865`, 0.9419903529330476],
              UndirectedEdge[121, 500] -> 
             RGBColor[
              0.8234793018793516, 0.18147777970619255`, 0.1701171120367329], 
             UndirectedEdge[1, 265] -> 
             RGBColor[
              0.2935899974663011, 0.4247777732380918, 0.9400724206184119], 
             UndirectedEdge[227, 495] -> 
             RGBColor[
              0.8439168192516593, 0.3385694940069675, 0.1896881017533292], 
             UndirectedEdge[127, 368] -> 
             RGBColor[
              0.3170407306432145, 0.44137417912788274`, 0.9417027210777457], 
             UndirectedEdge[207, 389] -> 
             RGBColor[
              0.21778138864415675`, 0.3462324259755344, 0.9357136999533677], 
             UndirectedEdge[249, 260] -> 
             RGBColor[
              0.28756214905519606`, 0.4195764295232854, 0.9396876110273925], 
             UndirectedEdge[42, 95] -> 
             RGBColor[
              0.2297785943922997, 0.3588422498836111, 0.9363969230724491], 
             UndirectedEdge[190, 323] -> 
             RGBColor[
              0.243727142288008, 0.373503058111017, 0.9371912722400824], 
             UndirectedEdge[109, 295] -> 
             RGBColor[
              0.24177394363545715`, 0.37145012248723885`, 0.937080040466318], 
             UndirectedEdge[382, 499] -> 
             RGBColor[
              0.27147166687394786`, 0.40266431255529955`, 0.9387712818709056],
              UndirectedEdge[213, 254] -> 
             RGBColor[
              0.5703520735589939, 0.511904106319279, 0.5892794945919869], 
             UndirectedEdge[47, 374] -> 
             RGBColor[
              0.24183198733731956`, 0.37151113009807946`, 0.9370833459692711],
              UndirectedEdge[244, 390] -> 
             RGBColor[
              0.3215972480879268, 0.45223414091428343`, 0.9417399272656037], 
             UndirectedEdge[92, 370] -> 
             RGBColor[
              0.6002904630940367, 0.6863818665737486, 0.9616762106726342], 
             UndirectedEdge[295, 458] -> 
             RGBColor[
              0.2300435692999762, 0.35912075531195864`, 0.936412013001446], 
             UndirectedEdge[278, 493] -> 
             RGBColor[
              0.9709705008180975, 0.974840539169355, 0.7572967831573334], 
             UndirectedEdge[6, 156] -> 
             RGBColor[
              0.6474994925034097, 0.7219315348762902, 0.9673172118721224], 
             UndirectedEdge[79, 413] -> 
             RGBColor[
              0.9838323701759427, 0.9563067408191819, 0.46126511216987476`], 
             UndirectedEdge[122, 476] -> 
             RGBColor[
              0.8579983660337116, 0.432494720305006, 0.20261219607186334`], 
             UndirectedEdge[123, 455] -> 
             RGBColor[
              0.20545207796979598`, 0.3332735387333343, 0.9350115639500436], 
             UndirectedEdge[113, 302] -> 
             RGBColor[
              0.18467080951855291`, 0.3114311079825565, 0.9338281014548768], 
             UndirectedEdge[402, 462] -> 
             RGBColor[
              0.5080947993050582, 0.6115332733425336, 0.9544182302953215], 
             UndirectedEdge[140, 363] -> 
             RGBColor[
              0.4522227109181607, 0.5648567259118211, 0.9503836849393674], 
             UndirectedEdge[440, 453] -> 
             RGBColor[
              0.2829903357512072, 0.4147711638710876, 0.939427253023122], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.5464995084832656, 0.6427119463658346, 0.9574415896829152], 
             UndirectedEdge[102, 202] -> 
             RGBColor[
              0.2577973086293919, 0.3882916950358828, 0.9379925473982783], 
             UndirectedEdge[363, 379] -> 
             RGBColor[
              0.35705527838116624`, 0.4836850688388347, 0.9439722245002304], 
             UndirectedEdge[162, 297] -> 
             RGBColor[
              0.4906978130641887, 0.5974096161868968, 0.9530486758111798], 
             UndirectedEdge[19, 393] -> 
             RGBColor[
              0.5104680056398668, 0.6134599491568583, 0.954605057791339], 
             UndirectedEdge[96, 238] -> 
             RGBColor[
              0.3081578274315908, 0.4401690531459169, 0.9408991236475683], 
             UndirectedEdge[117, 247] -> 
             RGBColor[
              0.4380433274875822, 0.5527007733374919, 0.9494455065337566], 
             UndirectedEdge[162, 223] -> 
             RGBColor[
              0.4259476007932227, 0.5431195461878823, 0.9484273528030159], 
             UndirectedEdge[355, 362] -> 
             RGBColor[
              0.3585841716726791, 0.48500931936353203`, 0.9440696442288183], 
             UndirectedEdge[59, 395] -> 
             RGBColor[
              0.2535893388235434, 0.38386885196924064`, 0.9377529097429688], 
             UndirectedEdge[161, 403] -> 
             RGBColor[
              0.9596219668575938, 0.962601388451382, 0.7050117798938269], 
             UndirectedEdge[214, 477] -> 
             RGBColor[
              0.2222393711458674, 0.35091804823724815`, 0.9359675754618462], 
             UndirectedEdge[65, 309] -> 
             RGBColor[
              0.9892477963467572, 0.9750667140916796, 0.4404269945442838], 
             UndirectedEdge[361, 498] -> 
             RGBColor[
              0.5530454795335582, 0.6479980366103388, 0.95797620936922], 
             UndirectedEdge[54, 70] -> 
             RGBColor[
              0.24348548029858347`, 0.3732490560378767, 0.9371775099472914], 
             UndirectedEdge[369, 390] -> 
             RGBColor[
              0.36035044557586515`, 0.48580021278599533`, 0.9442092467414281],
              UndirectedEdge[56, 88] -> 
             RGBColor[
              0.8516418675680354, 0.38504228297430826`, 0.19658027687583196`],
              UndirectedEdge[289, 419] -> 
             RGBColor[
              0.4760307938821983, 0.5851235769437257, 0.9519986681530803], 
             UndirectedEdge[124, 178] -> 
             RGBColor[
              0.977168593002762, 0.938254909924025, 0.5484416326473938], 
             UndirectedEdge[67, 465] -> 
             RGBColor[
              0.26962432665641767`, 0.4007226408585406, 0.9386660785784122], 
             UndirectedEdge[7, 461] -> 
             RGBColor[
              0.8915688064008891, 0.9161509753336762, 0.9816909809846657], 
             UndirectedEdge[273, 423] -> 
             RGBColor[
              0.24068365358124288`, 0.3703041585118776, 0.9370179500606701], 
             UndirectedEdge[63, 467] -> 
             RGBColor[
              0.563087381667329, 0.6542682731705118, 0.9596777258955458], 
             UndirectedEdge[179, 368] -> 
             RGBColor[
              0.2935153935219346, 0.41664755822089383`, 0.9403629879313062], 
             UndirectedEdge[211, 485] -> 
             RGBColor[
              0.23952079823930758`, 0.3690819238182165, 0.9369517271692371], 
             UndirectedEdge[21, 320] -> 
             RGBColor[
              0.9847451317139568, 0.9683734708666063, 0.6094013242659239], 
             UndirectedEdge[318, 479] -> 
             RGBColor[
              0.3767164983407358, 0.5007146293661655, 0.94522502005032], 
             UndirectedEdge[343, 465] -> 
             RGBColor[
              0.2877565452274621, 0.4197807522257663, 0.9396986816018197], 
             UndirectedEdge[229, 313] -> 
             RGBColor[
              0.2789668469500533, 0.41054222203715074`, 0.9391981212881146], 
             UndirectedEdge[168, 401] -> 
             RGBColor[
              0.842122298838193, 0.7534870262743261, 0.6125668464325392], 
             UndirectedEdge[70, 216] -> 
             RGBColor[
              0.26206807245195374`, 0.39278053859546125`, 0.9382357610799443],
              UndirectedEdge[5, 193] -> 
             RGBColor[
              0.263209529621381, 0.3939802824530939, 0.9383007653771087], 
             UndirectedEdge[213, 471] -> 
             RGBColor[
              0.8805092403498851, 0.5477975823099646, 0.2219082457048863], 
             UndirectedEdge[145, 404] -> 
             RGBColor[
              0.2170532372191201, 0.345467092660354, 0.9356722328069155], 
             UndirectedEdge[28, 173] -> 
             RGBColor[
              0.9747095150977819, 0.9805973489982415, 0.9249344880863324], 
             UndirectedEdge[210, 243] -> 
             RGBColor[
              0.8376849116916145, 0.29066832166115775`, 0.18372042003589745`],
              UndirectedEdge[133, 424] -> 
             RGBColor[
              0.33288404882225986`, 0.46274916467623195`, 0.942432055126516], 
             UndirectedEdge[201, 400] -> 
             RGBColor[
              0.30019030163233085`, 0.432849418552972, 0.9404067656349827], 
             UndirectedEdge[120, 125] -> 
             RGBColor[
              0.2080475453125366, 0.33600153947268885`, 0.9351593719755629], 
             UndirectedEdge[96, 343] -> 
             RGBColor[
              0.29452462133405766`, 0.4268944293346082, 0.940084113523619], 
             UndirectedEdge[22, 149] -> 
             RGBColor[
              0.40264564991743174`, 0.5231731572248479, 0.9468772026605385], 
             UndirectedEdge[140, 369] -> 
             RGBColor[
              0.4597907440975337, 0.5714117758713864, 0.950865913321408], 
             UndirectedEdge[169, 370] -> 
             RGBColor[
              0.5420927609464797, 0.6391343501937576, 0.9570946743743712], 
             UndirectedEdge[154, 380] -> 
             RGBColor[
              0.2911961325222311, 0.423322454553487, 0.9398972530104752], 
             UndirectedEdge[33, 489] -> 
             RGBColor[
              0.9342559232885688, 0.7654812281083937, 0.517015114696979], 
             UndirectedEdge[271, 284] -> 
             RGBColor[
              0.2504489768010796, 0.3805681323731789, 0.9375740707715388], 
             UndirectedEdge[112, 356] -> 
             RGBColor[
              0.2588007282426925, 0.3893463526699398, 0.9380496906608295], 
             UndirectedEdge[133, 155] -> 
             RGBColor[
              0.4555313931992919, 0.5659235600860384, 0.9510915748153721], 
             UndirectedEdge[82, 447] -> 
             RGBColor[
              0.25238928516537673`, 0.3826075194867109, 0.9376845684624564], 
             UndirectedEdge[225, 260] -> 
             RGBColor[
              0.27991286113099906`, 0.41153654292208813`, 0.9392519953962168],
              UndirectedEdge[133, 225] -> 
             RGBColor[
              0.3097114792684619, 0.4394887933443991, 0.9410723011032855], 
             UndirectedEdge[442, 444] -> 
             RGBColor[
              0.27761918641957545`, 0.4091257453730057, 0.939121374014589], 
             UndirectedEdge[49, 431] -> 
             RGBColor[
              0.4693773227785792, 0.5799709458958486, 0.9514060951044689], 
             UndirectedEdge[220, 427] -> 
             RGBColor[
              0.30920666661498386`, 0.43953702554153684`, 0.9410223592495326],
              UndirectedEdge[151, 192] -> 
             RGBColor[
              0.28070448165153206`, 0.4123685862808082, 0.9392970770137636], 
             UndirectedEdge[167, 326] -> 
             RGBColor[
              0.9309228830343801, 0.7574193985269815, 0.5440638154599668], 
             UndirectedEdge[109, 196] -> 
             RGBColor[
              0.27482966958615396`, 0.4061937863154972, 0.938962515157646], 
             UndirectedEdge[212, 451] -> 
             RGBColor[
              0.21498103480107186`, 0.34328907653376356`, 0.9355542239447563],
              UndirectedEdge[186, 414] -> 
             RGBColor[
              0.255184189019674, 0.3855451406447167, 0.937843734102269], 
             UndirectedEdge[349, 419] -> 
             RGBColor[
              0.4631460027688009, 0.5739634184897324, 0.951177660656908], 
             UndirectedEdge[162, 221] -> 
             RGBColor[
              0.4993207487803075, 0.6044101038600693, 0.953727504897607], 
             UndirectedEdge[163, 364] -> 
             RGBColor[
              0.2627794929075267, 0.39352828660093053`, 0.938276275422437], 
             UndirectedEdge[191, 300] -> 
             RGBColor[
              0.22217951414553483`, 0.3508551347347456, 0.9359641666942277], 
             UndirectedEdge[438, 460] -> 
             RGBColor[
              0.23490540515407732`, 0.3642308530528161, 0.9366888873608955], 
             UndirectedEdge[172, 473] -> 
             RGBColor[
              0.3392418574009336, 0.4682559789143286, 0.9428371690671595], 
             UndirectedEdge[141, 188] -> 
             RGBColor[
              0.32343001274534444`, 0.45456055380007726`, 0.9418296523075707],
              UndirectedEdge[79, 122] -> 
             RGBColor[
              0.9306665098261713, 0.7402291937878942, 0.3904132893585251], 
             UndirectedEdge[326, 475] -> 
             RGBColor[
              0.8570894511774583, 0.4134428533627656, 0.20126936153652183`], 
             UndirectedEdge[98, 124] -> 
             RGBColor[
              0.9789436438067185, 0.93894816660261, 0.5160607207640602], 
             UndirectedEdge[204, 498] -> 
             RGBColor[
              0.4818912814299178, 0.5902600770764668, 0.9523553933815417], 
             UndirectedEdge[72, 144] -> 
             RGBColor[
              0.2501061102631632, 0.3802077579028347, 0.93755454502943], 
             UndirectedEdge[98, 331] -> 
             RGBColor[
              0.9159632164581281, 0.9324175867663749, 0.8534971993423514], 
             UndirectedEdge[311, 377] -> 
             RGBColor[
              0.8639809895032101, 0.8937991659736781, 0.9461358346293043], 
             UndirectedEdge[299, 389] -> 
             RGBColor[
              0.213833079654714, 0.34208250289038133`, 0.9354888495974187], 
             UndirectedEdge[131, 238] -> 
             RGBColor[
              0.29188148517230905`, 0.42306158545170824`, 0.9399722100345929],
              UndirectedEdge[4, 185] -> 
             RGBColor[
              0.30412419819916303`, 0.4355457825101565, 0.9406834624888651], 
             UndirectedEdge[162, 258] -> 
             RGBColor[
              0.4177269296537439, 0.5359992140298111, 0.9479035389072623], 
             UndirectedEdge[124, 253] -> 
             RGBColor[
              0.9738421982948224, 0.9368793602278473, 0.603568601391508], 
             UndirectedEdge[319, 449] -> 
             RGBColor[
              0.7215962304048408, 0.7824357266175173, 0.9728856266127364], 
             UndirectedEdge[256, 271] -> 
             RGBColor[
              0.2725957288123946, 0.4038457729222503, 0.9388352955353996], 
             UndirectedEdge[379, 478] -> 
             RGBColor[
              0.2876705710791334, 0.41963924089195836`, 0.9396956582454141], 
             UndirectedEdge[349, 371] -> 
             RGBColor[
              0.3882726943942144, 0.5107240255563866, 0.9459613706441047], 
             UndirectedEdge[130, 325] -> 
             RGBColor[
              0.1789719601845752, 0.3054412560046289, 0.9335035604159989], 
             UndirectedEdge[269, 369] -> 
             RGBColor[
              0.43444338232168905`, 0.5507147548329152, 0.948903326051707], 
             UndirectedEdge[43, 355] -> 
             RGBColor[
              0.3109273076150301, 0.4422891800076947, 0.941085795498422], 
             UndirectedEdge[11, 414] -> 
             RGBColor[
              0.25678804986481485`, 0.38723090008361066`, 0.9379350716047002],
              UndirectedEdge[117, 255] -> 
             RGBColor[
              0.38933039965095584`, 0.511640156687964, 0.9460287666877722], 
             UndirectedEdge[401, 475] -> 
             RGBColor[
              0.806227884360017, 0.5618744373452094, 0.5815185800497742], 
             UndirectedEdge[58, 141] -> 
             RGBColor[
              0.3123473120692484, 0.44496127550717535`, 0.9411234724205373], 
             UndirectedEdge[96, 180] -> 
             RGBColor[
              0.2831463385898367, 0.4149351327456384, 0.9394361371539964], 
             UndirectedEdge[119, 375] -> 
             RGBColor[
              0.9744244063754681, 0.9793738724475776, 0.8801494909995853], 
             UndirectedEdge[220, 382] -> 
             RGBColor[
              0.3105689508267532, 0.4409688726219141, 0.9410999393200739], 
             UndirectedEdge[104, 356] -> 
             RGBColor[
              0.2579557991377684, 0.3884582786090651, 0.9380015731982647], 
             UndirectedEdge[225, 440] -> 
             RGBColor[
              0.27796156594151966`, 0.4094856079586846, 0.9391408720218586], 
             UndirectedEdge[259, 341] -> 
             RGBColor[
              0.9277070351691528, 0.7270975616364004, 0.37415406223837167`], 
             UndirectedEdge[290, 362] -> 
             RGBColor[
              0.3374733904051481, 0.4646660623491092, 0.9427998432095333], 
             UndirectedEdge[79, 267] -> 
             RGBColor[
              0.9914456607402118, 0.9819881575780944, 0.49084130836277423`], 
             UndirectedEdge[90, 317] -> 
             RGBColor[
              0.8740850504741097, 0.5211314470341011, 0.21664581846880504`], 
             UndirectedEdge[41, 389] -> 
             RGBColor[
              0.2255132290582107, 0.3543590804777015, 0.9361540168267153], 
             UndirectedEdge[5, 300] -> 
             RGBColor[
              0.23228249418787045`, 0.3614740073251723, 0.936539516461619], 
             UndirectedEdge[290, 340] -> 
             RGBColor[
              0.31195990105564253`, 0.44256756021982796`, 0.9411741462288754],
              UndirectedEdge[288, 392] -> 
             RGBColor[
              0.281033651223698, 0.41271456437171095`, 0.9393158227339358], 
             UndirectedEdge[45, 292] -> 
             RGBColor[
              0.23087655194201073`, 0.35999627288288677`, 0.9364594501306225],
              UndirectedEdge[42, 145] -> 
             RGBColor[
              0.22656621784669417`, 0.3554658384577429, 0.9362139829804621], 
             UndirectedEdge[100, 368] -> 
             RGBColor[
              0.6696582512860165, 0.6464478563026956, 0.6053684569202311], 
             UndirectedEdge[302, 315] -> 
             RGBColor[
              0.18782448730516063`, 0.31474582329100176`, 0.934007698739376], 
             UndirectedEdge[255, 338] -> 
             RGBColor[
              0.35884542683277726`, 0.48523560545214284`, 0.9440862911766009],
              UndirectedEdge[59, 263] -> 
             RGBColor[
              0.25779587834217144`, 0.38829019171332857`, 0.9379924659455371],
              UndirectedEdge[413, 486] -> 
             RGBColor[
              0.9543818118224241, 0.9371774082640264, 0.6732568757445232], 
             UndirectedEdge[140, 247] -> 
             RGBColor[
              0.4973227229374232, 0.6027880164707773, 0.9535702129842454], 
             UndirectedEdge[82, 453] -> 
             RGBColor[
              0.27129272785642566`, 0.40247623630249474`, 0.9387610915585742],
              UndirectedEdge[199, 349] -> 
             RGBColor[
              0.3782226741008029, 0.5020192031069408, 0.9453209922378925], 
             UndirectedEdge[265, 462] -> 
             RGBColor[
              0.392446435384819, 0.5140523715462819, 0.9463065444803587], 
             UndirectedEdge[113, 386] -> 
             RGBColor[
              0.17905963034776856`, 0.3055334029047545, 0.9335085531020964], 
             UndirectedEdge[140, 219] -> 
             RGBColor[
              0.5129514818808725, 0.6154761470486363, 0.9548005661383041], 
             UndirectedEdge[13, 313] -> 
             RGBColor[
              0.2817870779153078, 0.4135064635946042, 0.939358729269428], 
             UndirectedEdge[74, 463] -> 
             RGBColor[
              0.2744156870316411, 0.4057586644026942, 0.9389389394635987], 
             UndirectedEdge[146, 415] -> 
             RGBColor[
              0.27247295826931617`, 0.4037167332973729, 0.9388283039345939], 
             UndirectedEdge[213, 475] -> 
             RGBColor[
              0.871604644354381, 0.4793529554696741, 0.21338119452328883`], 
             UndirectedEdge[49, 328] -> 
             RGBColor[
              0.4377638604952656, 0.5525889538048573, 0.9493917132424632], 
             UndirectedEdge[259, 450] -> 
             RGBColor[
              0.8397745913250846, 0.3013267240551166, 0.18550990071046175`], 
             UndirectedEdge[454, 500] -> 
             RGBColor[
              0.8596875442431727, 0.3945530129661969, 0.20223564129349905`], 
             UndirectedEdge[469, 495] -> 
             RGBColor[
              0.8513165746787745, 0.3922611978068248, 0.19664935782673318`], 
             UndirectedEdge[158, 182] -> 
             RGBColor[
              0.36805399542884243`, 0.4932116047339394, 0.9446730530247247], 
             UndirectedEdge[302, 347] -> 
             RGBColor[
              0.18453817917078433`, 0.311291705077802, 0.9338205483527805], 
             UndirectedEdge[87, 107] -> 
             RGBColor[
              0.1819624771956669, 0.3085844789930161, 0.9336738659357071], 
             UndirectedEdge[80, 307] -> 
             RGBColor[
              0.6296762406643908, 0.7079838947833768, 0.9655310968074982], 
             UndirectedEdge[159, 443] -> 
             RGBColor[
              0.877631072588452, 0.4692846461457165, 0.21683434670508697`], 
             UndirectedEdge[396, 443] -> 
             RGBColor[
              0.9640290207521414, 0.8833364286136021, 0.40253589756085995`], 
             UndirectedEdge[15, 452] -> 
             RGBColor[
              0.22909610908040262`, 0.3581249145487392, 0.9363580565435832], 
             UndirectedEdge[55, 250] -> 
             RGBColor[
              0.20796149957955015`, 0.33591109995170554`, 0.9351544717983624],
              UndirectedEdge[105, 447] -> 
             RGBColor[
              0.24620260884716, 0.3761049304183308, 0.9373322463985014], 
             UndirectedEdge[55, 242] -> 
             RGBColor[
              0.21824264556347417`, 0.34671723624311485`, 0.9357399678525544],
              UndirectedEdge[133, 440] -> 
             RGBColor[
              0.31342375230206637`, 0.44339062767442217`, 0.9412837095607336],
              UndirectedEdge[177, 455] -> 
             RGBColor[
              0.2063185988388122, 0.33418430710726665`, 0.9350609110316312], 
             UndirectedEdge[186, 456] -> 
             RGBColor[
              0.22968446940414386`, 0.35874331855319036`, 0.9363915627936191],
              UndirectedEdge[94, 302] -> 
             RGBColor[
              0.5727842186692342, 0.6417308063914131, 0.9472440733920693], 
             UndirectedEdge[146, 376] -> 
             RGBColor[
              0.2686941653913333, 0.39974498239330636`, 0.9386131072704159], 
             UndirectedEdge[44, 106] -> 
             RGBColor[
              0.5072662938524296, 0.6108606552923443, 0.9543530073111751], 
             UndirectedEdge[46, 205] -> 
             RGBColor[
              0.9557407049755898, 0.8502199530826348, 0.4110195083871594], 
             UndirectedEdge[134, 457] -> 
             RGBColor[
              0.22739772905471156`, 0.3563398094582248, 0.936261336313648], 
             UndirectedEdge[229, 248] -> 
             RGBColor[
              0.2667577277658053, 0.3977096636716398, 0.9385028300123448], 
             UndirectedEdge[101, 362] -> 
             RGBColor[
              0.45464713410545365`, 0.5663810460128507, 0.950697205214848], 
             UndirectedEdge[286, 346] -> 
             RGBColor[
              0.22049146079372114`, 0.3490808836332252, 0.935868034553093], 
             UndirectedEdge[134, 138] -> 
             RGBColor[
              0.2265863896100655, 0.3554870402600099, 0.9362151317325447], 
             UndirectedEdge[144, 494] -> 
             RGBColor[
              0.25236564813326057`, 0.3825826754672824, 0.9376832223684453], 
             UndirectedEdge[35, 147] -> 
             RGBColor[
              0.2449327987863818, 0.374770279533845, 0.9372599325940558], 
             UndirectedEdge[5, 211] -> 
             RGBColor[
              0.2348238735021131, 0.3641451581171964, 0.9366842442539314], 
             UndirectedEdge[243, 471] -> 
             RGBColor[
              0.8480593461920269, 0.37041077133751354`, 0.1936549902297403], 
             UndirectedEdge[154, 338] -> 
             RGBColor[
              0.314823265682197, 0.4471058220816644, 0.9412812379953546], 
             UndirectedEdge[185, 383] -> 
             RGBColor[
              0.3064436349421723, 0.43755476203867083`, 0.9408312549471323], 
             UndirectedEdge[416, 429] -> 
             RGBColor[
              0.2775658260011634, 0.4090696601900088, 0.9391183352177], 
             UndirectedEdge[159, 396] -> 
             RGBColor[
              0.9071481131704897, 0.5745522202562454, 0.3532052383412315], 
             UndirectedEdge[73, 322] -> 
             RGBColor[
              0.2535645087759725, 0.3838427540149276, 0.9377514957084923], 
             UndirectedEdge[287, 300] -> 
             RGBColor[
              0.2178846815571592, 0.3463409933762489, 0.9357195823319551], 
             UndirectedEdge[392, 459] -> 
             RGBColor[
              0.34827375514967984`, 0.47582519706689724`, 0.9434219649183455],
              UndirectedEdge[200, 450] -> 
             RGBColor[
              0.8592682454015592, 0.38984285435780597`, 0.20177588350505832`],
              UndirectedEdge[104, 148] -> 
             RGBColor[
              0.2431147548759032, 0.37285940011329033`, 0.9371563976829089], 
             UndirectedEdge[94, 325] -> 
             RGBColor[
              0.5672179996830251, 0.6358803573182399, 0.9469270854552878], 
             UndirectedEdge[355, 378] -> 
             RGBColor[
              0.30589561445696456`, 0.4370005514707954, 0.940799248016793], 
             UndirectedEdge[424, 453] -> 
             RGBColor[
              0.3024506322714007, 0.4341297008728973, 0.9405755985889044], 
             UndirectedEdge[212, 301] -> 
             RGBColor[
              0.2136344659280746, 0.34187374727084574`, 0.9354775388395093], 
             UndirectedEdge[46, 420] -> 
             RGBColor[
              0.9431488383406506, 0.8436851965616485, 0.5952825252201055], 
             UndirectedEdge[146, 284] -> 
             RGBColor[
              0.25151293220690424`, 0.3816864169633695, 0.9376346614579194], 
             UndirectedEdge[76, 343] -> 
             RGBColor[
              0.3521064049491038, 0.47793237749510553`, 0.9437105723744709], 
             UndirectedEdge[111, 256] -> 
             RGBColor[
              0.2812386903435383, 0.41293007348689414`, 0.9393274994084824], 
             UndirectedEdge[277, 319] -> 
             RGBColor[
              0.7430956081884199, 0.7992312039433723, 0.9750284836670953], 
             UndirectedEdge[240, 429] -> 
             RGBColor[
              0.2751117605214455, 0.4064902817740869, 0.9389785798190946], 
             UndirectedEdge[49, 71] -> 
             RGBColor[
              0.6229981269292593, 0.7030794824142605, 0.9646517716159538], 
             UndirectedEdge[19, 139] -> 
             RGBColor[
              0.5618798532479841, 0.6551984031224687, 0.9586523867628529], 
             UndirectedEdge[9, 247] -> 
             RGBColor[
              0.5350775301382318, 0.6334390697910756, 0.9565424097075088], 
             UndirectedEdge[333, 392] -> 
             RGBColor[
              0.34232526370384136`, 0.4706729127563853, 0.943042932303461], 
             UndirectedEdge[169, 337] -> 
             RGBColor[
              0.6764764422213522, 0.7452210038115648, 0.9698692373870139], 
             UndirectedEdge[21, 119] -> 
             RGBColor[
              0.9857675700825197, 0.9687962754074746, 0.5924568745131584], 
             UndirectedEdge[354, 479] -> 
             RGBColor[
              0.38662725868303643`, 0.5092988318453677, 0.9458565249355901], 
             UndirectedEdge[179, 236] -> 
             RGBColor[
              0.23312614698427564`, 0.36236073990487094`, 0.9365875612403018],
              UndirectedEdge[121, 341] -> 
             RGBColor[
              0.9105196563022746, 0.6003916270804778, 0.3579070077274834], 
             UndirectedEdge[263, 323] -> 
             RGBColor[
              0.2563726589916906, 0.3867942979386546, 0.9379114157089916], 
             UndirectedEdge[200, 401] -> 
             RGBColor[
              0.8371401925160188, 0.7327555556169211, 0.6085074799840489], 
             UndirectedEdge[56, 236] -> 
             RGBColor[
              0.5619983827153064, 0.35111011799079705`, 0.5612129978793174], 
             UndirectedEdge[374, 437] -> 
             RGBColor[
              0.25378039219455883`, 0.3840696611756612, 0.9377637899498099], 
             UndirectedEdge[74, 195] -> 
             RGBColor[
              0.27594296910076915`, 0.40736393469262394`, 0.9390259159180243],
              UndirectedEdge[240, 399] -> 
             RGBColor[
              0.24906325398775672`, 0.3791116498364756, 0.9374951559073132], 
             UndirectedEdge[138, 352] -> 
             RGBColor[
              0.22389864331585435`, 0.3526620484918363, 0.9360620685572537], 
             UndirectedEdge[195, 342] -> 
             RGBColor[
              0.265069534257383, 0.39593526525663725`, 0.9384066898894987], 
             UndirectedEdge[13, 363] -> 
             RGBColor[
              0.3507138092232281, 0.4770709297343131, 0.9436092144688942], 
             UndirectedEdge[368, 386] -> 
             RGBColor[
              0.2935143249909316, 0.4166464351270609, 0.9403629270800464], 
             UndirectedEdge[132, 233] -> 
             RGBColor[
              0.9166463543771588, 0.6614692040973338, 0.5010749461233683], 
             UndirectedEdge[304, 310] -> 
             RGBColor[
              0.317660558842397, 0.44845488439544834`, 0.9415026138990965], 
             UndirectedEdge[213, 259] -> 
             RGBColor[
              0.8830232984339081, 0.5617179434386964, 0.224104111662967], 
             UndirectedEdge[226, 446] -> 
             RGBColor[
              0.20378813280661343`, 0.33152462686661266`, 0.9349168047345866],
              UndirectedEdge[60, 249] -> 
             RGBColor[
              0.29112873348308044`, 0.42332513589150556`, 0.9398907227342717],
              UndirectedEdge[181, 387] -> 
             RGBColor[
              0.5979055016129029, 0.6815262817946347, 0.9631235948533272], 
             UndirectedEdge[94, 168] -> 
             RGBColor[
              0.9331056494970619, 0.8251500560931704, 0.6037137900969318], 
             UndirectedEdge[142, 402] -> 
             RGBColor[
              0.6259177691187879, 0.7063115685381091, 0.9642924066530247], 
             UndirectedEdge[188, 310] -> 
             RGBColor[
              0.3170171080071488, 0.4478975596227356, 0.9414616137808558], 
             UndirectedEdge[74, 239] -> 
             RGBColor[
              0.31633226480045645`, 0.4459153985127936, 0.9414688336983061], 
             UndirectedEdge[376, 400] -> 
             RGBColor[
              0.2876884645475003, 0.41970919511456195`, 0.9396948045078122], 
             UndirectedEdge[292, 308] -> 
             RGBColor[
              0.17895845847297373`, 0.30542706484967774`, 0.9335027915134972],
              UndirectedEdge[7, 142] -> 
             RGBColor[
              0.7691032060058948, 0.819699666861827, 0.9775805727504322], 
             UndirectedEdge[20, 194] -> 
             RGBColor[
              0.9355250585723344, 0.7786349412620628, 0.5492457614630861], 
             UndirectedEdge[168, 500] -> 
             RGBColor[
              0.8651424411448785, 0.41743131522220955`, 0.2066895157907081], 
             UndirectedEdge[4, 383] -> 
             RGBColor[
              0.32662308368104653`, 0.45732623135617084`, 0.9420331119640719],
              UndirectedEdge[91, 303] -> 
             RGBColor[
              0.3164436833902854, 0.44818690517109605`, 0.9413962957337874], 
             UndirectedEdge[142, 417] -> 
             RGBColor[
              0.7002784838355302, 0.7657821409766972, 0.9707608728603756], 
             UndirectedEdge[229, 338] -> 
             RGBColor[
              0.3055405634218271, 0.43742263545021065`, 0.9407499098335221], 
             UndirectedEdge[69, 388] -> 
             RGBColor[
              0.9278173046721767, 0.9450102776472538, 0.9836136557859578], 
             UndirectedEdge[170, 374] -> 
             RGBColor[
              0.2742054454433818, 0.40553768716334715`, 0.9389269665161719], 
             UndirectedEdge[96, 281] -> 
             RGBColor[
              0.27053519804586806`, 0.4016800244414347, 0.938717951356528], 
             UndirectedEdge[131, 265] -> 
             RGBColor[
              0.29231177765764305`, 0.42343428317537546`, 0.9399996278912657],
              UndirectedEdge[117, 369] -> 
             RGBColor[
              0.40051134864769267`, 0.5213245327381009, 0.9467412068709193], 
             UndirectedEdge[19, 247] -> 
             RGBColor[
              0.5273679540729146, 0.6271800886288073, 0.9559354836385393], 
             UndirectedEdge[328, 436] -> 
             RGBColor[
              0.42911640965865483`, 0.5455685636524759, 0.9487109542359491], 
             UndirectedEdge[86, 178] -> 
             RGBColor[
              0.9534388639235, 0.8461526483552239, 0.5190456011559075], 
             UndirectedEdge[42, 137] -> 
             RGBColor[
              0.22627740530250587`, 0.35516227816202806`, 0.9361975355333305],
              UndirectedEdge[54, 135] -> 
             RGBColor[
              0.23967378277683635`, 0.36924272026693905`, 0.9369604394123292],
              UndirectedEdge[42, 174] -> 
             RGBColor[
              0.2495656884148965, 0.3796397402755821, 0.9375237688046536], 
             UndirectedEdge[1, 374] -> 
             RGBColor[
              0.25894790578239785`, 0.38950104559576504`, 0.9380580722039861],
              UndirectedEdge[160, 285] -> 
             RGBColor[
              0.3684500451199806, 0.49355464307036695`, 0.9446982889608311], 
             UndirectedEdge[454, 471] -> 
             RGBColor[
              0.8783475046128462, 0.5379816452142798, 0.2201044404169093], 
             UndirectedEdge[26, 425] -> 
             RGBColor[
              0.38098619324606947`, 0.5044128244920598, 0.9454970812341448], 
             UndirectedEdge[333, 442] -> 
             RGBColor[
              0.331297230301234, 0.4590817504325423, 0.942414902115696], 
             UndirectedEdge[75, 410] -> 
             RGBColor[
              0.354306761585108, 0.48130444173456, 0.9437970914404035], 
             UndirectedEdge[31, 40] -> 
             RGBColor[
              0.4196192099941566, 0.5378748018473721, 0.9479587428994976], 
             UndirectedEdge[3, 258] -> 
             RGBColor[
              0.41754423807969365`, 0.5358508967798354, 0.9478891567573319], 
             UndirectedEdge[132, 273] -> 
             RGBColor[
              0.6418371637733833, 0.7080243687957053, 0.8766074186854609], 
             UndirectedEdge[157, 180] -> 
             RGBColor[
              0.2863372761085622, 0.4182890103949429, 0.9396178563251187], 
             UndirectedEdge[213, 401] -> 
             RGBColor[
              0.8388291376735261, 0.7404246611139982, 0.6099167772233072], 
             UndirectedEdge[84, 391] -> 
             RGBColor[
              0.23722076036640824`, 0.3666644381829753, 0.9368207434149767], 
             UndirectedEdge[43, 110] -> 
             RGBColor[
              0.2824315567297242, 0.4141838516908727, 0.9393954313844881], 
             UndirectedEdge[39, 127] -> 
             RGBColor[
              0.4248206994263658, 0.5301025431322064, 0.9498483295981558], 
             UndirectedEdge[52, 469] -> 
             RGBColor[
              0.8481128613393234, 0.36763605320366755`, 0.19358147831479822`],
              UndirectedEdge[260, 483] -> 
             RGBColor[
              0.2911128004849959, 0.42330838930030823`, 0.9398898153736015], 
             UndirectedEdge[98, 311] -> 
             RGBColor[
              0.8710458030481137, 0.8971927199459824, 0.8490560873664715], 
             UndirectedEdge[51, 127] -> 
             RGBColor[
              0.20245340605759676`, 0.3301217444268325, 0.9348407940207814], 
             UndirectedEdge[243, 475] -> 
             RGBColor[
              0.8391547501965229, 0.3019661444972231, 0.18512793904814284`], 
             UndirectedEdge[76, 96] -> 
             RGBColor[
              0.3537435180123586, 0.4796530871235497, 0.9438038035415315], 
             UndirectedEdge[99, 476] -> 
             RGBColor[
              0.9210569805098886, 0.6812525268241133, 0.37059559494700395`], 
             UndirectedEdge[107, 308] -> 
             RGBColor[
              0.18180898862834943`, 0.3084231527770282, 0.9336651249888644], 
             UndirectedEdge[190, 263] -> 
             RGBColor[
              0.26075513515246407`, 0.3914005582486648, 0.9381609912430551], 
             UndirectedEdge[191, 299] -> 
             RGBColor[
              0.21378387890714912`, 0.3420307897851831, 0.935486047687631], 
             UndirectedEdge[39, 276] -> 
             RGBColor[
              0.6216008719460259, 0.7036826165027719, 0.9633538441200625], 
             UndirectedEdge[51, 214] -> 
             RGBColor[
              0.1893670578318586, 0.31636716271918164`, 0.9340955458488429], 
             UndirectedEdge[295, 409] -> 
             RGBColor[
              0.23557177233220394`, 0.3649312472071466, 0.9367268359858879], 
             UndirectedEdge[371, 382] -> 
             RGBColor[
              0.322584307384319, 0.45137597056269757`, 0.9418655472151594], 
             UndirectedEdge[53, 420] -> 
             RGBColor[
              0.9725775680800968, 0.9542835451375451, 0.6506094324523175], 
             UndirectedEdge[87, 308] -> 
             RGBColor[
              0.17909977333492821`, 0.3055755957294717, 0.9335108391858289], 
             UndirectedEdge[286, 358] -> 
             RGBColor[
              0.22436323878386594`, 0.35315036778577047`, 0.9360885265818495],
              UndirectedEdge[215, 351] -> 
             RGBColor[
              0.28708427642095813`, 0.4190741550858264, 0.9396603968878219], 
             UndirectedEdge[114, 258] -> 
             RGBColor[
              0.4370504632160207, 0.551686929090934, 0.9494247582537205], 
             UndirectedEdge[87, 292] -> 
             RGBColor[
              0.1791119470402912, 0.3055883910656657, 0.93351153246034], 
             UndirectedEdge[196, 383] -> 
             RGBColor[
              0.3123209276016251, 0.4437321692656331, 0.941165958069413], 
             UndirectedEdge[65, 495] -> 
             RGBColor[
              0.9138336495538494, 0.6440119286541663, 0.2930402350354805], 
             UndirectedEdge[14, 279] -> 
             RGBColor[
              0.2926514518650601, 0.4249256094568878, 0.9399774392934654], 
             UndirectedEdge[26, 466] -> 
             RGBColor[
              0.4450688550450512, 0.558555224381097, 0.9499569121935232], 
             UndirectedEdge[27, 371] -> 
             RGBColor[
              0.43753141765926407`, 0.551792873087608, 0.9495412335023905], 
             UndirectedEdge[258, 472] -> 
             RGBColor[
              0.3509345795878789, 0.47838362717935545`, 0.9435822189854435], 
             UndirectedEdge[26, 117] -> 
             RGBColor[
              0.38385240519854513`, 0.5068953932252928, 0.9456797137252648], 
             UndirectedEdge[97, 104] -> 
             RGBColor[
              0.23915408747259903`, 0.3686964875516002, 0.936930843533573], 
             UndirectedEdge[21, 428] -> 
             RGBColor[
              0.9056106309029361, 0.5906771035003356, 0.2784668522610333], 
             UndirectedEdge[160, 268] -> 
             RGBColor[
              0.41606826400089775`, 0.5347991509037464, 0.9477324797607855], 
             UndirectedEdge[48, 137] -> 
             RGBColor[
              0.21379570916554433`, 0.34204322413683813`, 0.9354867214033452],
              UndirectedEdge[27, 291] -> 
             RGBColor[
              0.583523028601068, 0.6725767800031528, 0.9604878491746004], 
             UndirectedEdge[117, 140] -> 
             RGBColor[
              0.44035466890019287`, 0.5545772244209933, 0.9496274637964799], 
             UndirectedEdge[31, 221] -> 
             RGBColor[
              0.4948241717740719, 0.6007519845572706, 0.9533756165491586], 
             UndirectedEdge[87, 386] -> 
             RGBColor[
              0.17909013095112286`, 0.3055654609727298, 0.9335102900663359], 
             UndirectedEdge[207, 409] -> 
             RGBColor[
              0.22930932819200256`, 0.35834902135390323`, 0.9363701990565594],
              UndirectedEdge[274, 498] -> 
             RGBColor[
              0.46231188623512687`, 0.5743646420156336, 0.95081403167012], 
             UndirectedEdge[28, 69] -> 
             RGBColor[
              0.9371592911405698, 0.9519775158592825, 0.9678001094752631], 
             UndirectedEdge[442, 492] -> 
             RGBColor[
              0.2802823193946945, 0.4119248669822389, 0.9392730354977699], 
             UndirectedEdge[476, 493] -> 
             RGBColor[
              0.9210348441528622, 0.6812051793947629, 0.36818618909444256`], 
             UndirectedEdge[297, 359] -> 
             RGBColor[
              0.45240773600559087`, 0.5644812656494411, 0.9505434955218137], 
             UndirectedEdge[112, 323] -> 
             RGBColor[
              0.24380409586490398`, 0.37358394119947325`, 0.9371956546324439],
              UndirectedEdge[27, 349] -> 
             RGBColor[
              0.46286019331944683`, 0.5737313855031778, 0.9511551606901004], 
             UndirectedEdge[2, 242] -> 
             RGBColor[
              0.21872765624032725`, 0.34722701321594046`, 0.9357675884930923],
              UndirectedEdge[71, 462] -> 
             RGBColor[
              0.6098299518680684, 0.6923889646800596, 0.9636151246385223], 
             UndirectedEdge[165, 285] -> 
             RGBColor[
              0.3692257984681636, 0.49422656163006606`, 0.9447477192782054], 
             UndirectedEdge[91, 172] -> 
             RGBColor[
              0.33964065051404985`, 0.4686013934649852, 0.9428625798116885], 
             UndirectedEdge[19, 26] -> 
             RGBColor[
              0.4731770317838775, 0.5813747085166081, 0.9521696908300475], 
             UndirectedEdge[73, 163] -> 
             RGBColor[
              0.2574513896017804, 0.3879281122053299, 0.9379728478213971], 
             UndirectedEdge[67, 131] -> 
             RGBColor[
              0.2601160605037315, 0.39072885027317383`, 0.938124596887236], 
             UndirectedEdge[24, 81] -> 
             RGBColor[
              0.8302950804632105, 0.8675187756745408, 0.9836754800593912], 
             UndirectedEdge[282, 467] -> 
             RGBColor[
              0.6572487791197071, 0.7316354395209496, 0.9668355107224047], 
             UndirectedEdge[122, 406] -> 
             RGBColor[
              0.929061342775948, 0.7356327772399205, 0.3146046467534838], 
             UndirectedEdge[139, 255] -> 
             RGBColor[
              0.4808103528632557, 0.5878692632314095, 0.9526884189998513], 
             UndirectedEdge[409, 458] -> 
             RGBColor[
              0.23602745875437942`, 0.36541020252904094`, 0.9367527866535031],
              UndirectedEdge[4, 196] -> 
             RGBColor[
              0.31000149085861584`, 0.44172318973711877`, 0.9410181656111457],
              UndirectedEdge[46, 90] -> 
             RGBColor[
              0.8912123121580973, 0.5950344530170778, 0.2307371435474895], 
             UndirectedEdge[115, 124] -> 
             RGBColor[
              0.9419104649402625, 0.9128295501642687, 0.6508778471089514], 
             UndirectedEdge[330, 350] -> 
             RGBColor[
              0.33430977302587317`, 0.4637717331289171, 0.9425306751676419], 
             UndirectedEdge[213, 315] -> 
             RGBColor[
              0.5448527569683213, 0.48510270783243126`, 0.5878273462350064], 
             UndirectedEdge[107, 143] -> 
             RGBColor[
              0.18179934691843552`, 0.30841301872858895`, 0.9336645759077484],
              UndirectedEdge[403, 491] -> 
             RGBColor[
              0.9615367037861473, 0.968036714632053, 0.7994838663892643], 
             UndirectedEdge[200, 254] -> 
             RGBColor[
              0.5686631284014866, 0.5042350008222019, 0.5878701973527287], 
             UndirectedEdge[37, 304] -> 
             RGBColor[
              0.32210212279026273`, 0.45312324971607465`, 0.9417555543952225],
              UndirectedEdge[25, 392] -> 
             RGBColor[
              0.3096883372024623, 0.4424044474005129, 0.9409633362064942], 
             UndirectedEdge[231, 492] -> 
             RGBColor[
              0.2675328366491727, 0.39852435225280064`, 0.9385469713165818], 
             UndirectedEdge[22, 63] -> 
             RGBColor[
              0.4353760609281416, 0.5515225941640346, 0.948962755507775], 
             UndirectedEdge[201, 256] -> 
             RGBColor[
              0.2969224563599441, 0.4294147059783363, 0.9402206666810642], 
             UndirectedEdge[57, 92] -> 
             RGBColor[
              0.6051902881840892, 0.690359765316458, 0.9620619428523739], 
             UndirectedEdge[433, 462] -> 
             RGBColor[
              0.3946923083800721, 0.5159976338539112, 0.9464496495216687], 
             UndirectedEdge[286, 294] -> 
             RGBColor[
              0.23070650372322443`, 0.3598175414232626, 0.9364497661361264], 
             UndirectedEdge[319, 331] -> 
             RGBColor[
              0.775790689833521, 0.8249078922958527, 0.9782513878368327], 
             UndirectedEdge[222, 307] -> 
             RGBColor[
              0.456261635454359, 0.5691648443465238, 0.950417290103996], 
             UndirectedEdge[276, 283] -> 
             RGBColor[
              0.4003771577872324, 0.5049037920541919, 0.9484114336869224], 
             UndirectedEdge[464, 497] -> 
             RGBColor[
              0.23993020302659857`, 0.369512234207422, 0.9369750421662133], 
             UndirectedEdge[143, 283] -> 
             RGBColor[
              0.18007058028918088`, 0.3065959753911073, 0.9335661252056935], 
             UndirectedEdge[265, 433] -> 
             RGBColor[
              0.32326037843179023`, 0.45441362508374517`, 0.9418188433591128],
              UndirectedEdge[74, 234] -> 
             RGBColor[
              0.335156328175214, 0.4622198560830736, 0.94266828637108], 
             UndirectedEdge[17, 432] -> 
             RGBColor[
              0.8892978625365586, 0.9145659925119751, 0.9893032180859526], 
             UndirectedEdge[103, 118] -> 
             RGBColor[
              0.4027319052154037, 0.522513730131029, 0.9470855430392838], 
             UndirectedEdge[426, 489] -> 
             RGBColor[
              0.9301359936068372, 0.9447452859638352, 0.9006256116612403], 
             UndirectedEdge[277, 331] -> 
             RGBColor[
              0.8039966134471465, 0.8469425741957761, 0.9810626907032964], 
             UndirectedEdge[74, 112] -> 
             RGBColor[
              0.264998769293781, 0.3958608867931338, 0.938402659929509], 
             UndirectedEdge[80, 372] -> 
             RGBColor[
              0.6299979927875134, 0.7082451076516956, 0.9655564263132472], 
             UndirectedEdge[180, 281] -> 
             RGBColor[
              0.2575198022383923, 0.3880000182240208, 0.9379767438198447], 
             UndirectedEdge[263, 296] -> 
             RGBColor[
              0.2934102361450429, 0.4252910132115676, 0.9400364732085589], 
             UndirectedEdge[37, 141] -> 
             RGBColor[
              0.3076115395353609, 0.4405722348185699, 0.9408322272437397], 
             UndirectedEdge[18, 210] -> 
             RGBColor[
              0.8602238171594843, 0.4230516477625904, 0.20370370360755374`], 
             UndirectedEdge[279, 494] -> 
             RGBColor[
              0.2685318784304253, 0.3995744085078045, 0.9386038652680744], 
             UndirectedEdge[101, 337] -> 
             RGBColor[
              0.6905217138834787, 0.756623588079157, 0.9709749326217818], 
             UndirectedEdge[217, 378] -> 
             RGBColor[
              0.30140209308183147`, 0.4331084891066064, 0.9405129248082346], 
             UndirectedEdge[20, 62] -> 
             RGBColor[
              0.8509265138034974, 0.3513524058869604, 0.19479135055817565`], 
             UndirectedEdge[18, 56] -> 
             RGBColor[
              0.8605287644059905, 0.4253956059279722, 0.2039957214351967], 
             UndirectedEdge[444, 492] -> 
             RGBColor[
              0.2739561801729139, 0.4052756935597544, 0.9389127712277736], 
             UndirectedEdge[199, 427] -> 
             RGBColor[
              0.31117200287913815`, 0.44123930103287445`, 0.9411475887384059],
              UndirectedEdge[190, 463] -> 
             RGBColor[
              0.2576034897635375, 0.3880879791190439, 0.9379815097005972], 
             UndirectedEdge[139, 369] -> 
             RGBColor[
              0.49199130185999246`, 0.5975536392815464, 0.9534008591829983], 
             UndirectedEdge[10, 455] -> 
             RGBColor[
              0.21145152724630215`, 0.3395793403099965, 0.9353532237109508], 
             UndirectedEdge[52, 236] -> 
             RGBColor[
              0.5615591008027638, 0.3477336047164332, 0.5607923410237687], 
             UndirectedEdge[9, 19] -> 
             RGBColor[
              0.5674341026863339, 0.6597075930326068, 0.9590896376245259], 
             UndirectedEdge[33, 309] -> 
             RGBColor[
              0.9357225086078202, 0.7641455885442991, 0.35153908493080155`], 
             UndirectedEdge[341, 491] -> 
             RGBColor[
              0.9938674015539399, 0.9892913169617195, 0.5738826890360067], 
             UndirectedEdge[87, 143] -> 
             RGBColor[
              0.1790901316250143, 0.30556546168103244`, 0.933510290104713], 
             UndirectedEdge[110, 378] -> 
             RGBColor[
              0.2773998635716586, 0.40889522315397336`, 0.9391088839028592], 
             UndirectedEdge[401, 471] -> 
             RGBColor[
              0.8151324803555211, 0.6303190641854999, 0.5900456312313715], 
             UndirectedEdge[160, 165] -> 
             RGBColor[
              0.4232575021072018, 0.5410261076098133, 0.9481905716557255], 
             UndirectedEdge[13, 379] -> 
             RGBColor[
              0.3029577301181068, 0.43570701430378433`, 0.9405662393373586], 
             UndirectedEdge[210, 434] -> 
             RGBColor[
              0.9136331462118448, 0.6344185701788778, 0.48881376628200723`], 
             UndirectedEdge[308, 446] -> 
             RGBColor[
              0.2035487790418117, 0.3312730508839008, 0.9349031738917732], 
             UndirectedEdge[153, 395] -> 
             RGBColor[
              0.2549602684410159, 0.3853097859191623, 0.9378309821565751], 
             UndirectedEdge[24, 83] -> 
             RGBColor[
              0.878858858195596, 0.9062422138097157, 0.9883075365329024], 
             UndirectedEdge[133, 260] -> 
             RGBColor[
              0.31537504749154577`, 0.44544156263782575`, 0.9413948329350919],
              UndirectedEdge[83, 119] -> 
             RGBColor[
              0.9556965383033635, 0.9650210547273206, 0.8984817408494732], 
             UndirectedEdge[400, 464] -> 
             RGBColor[
              0.26989429594474446`, 0.40100639569761354`, 0.9386814529299987],
              UndirectedEdge[175, 320] -> 
             RGBColor[
              0.9721663810423609, 0.9780295691716399, 0.8991854671906325], 
             UndirectedEdge[39, 475] -> 
             RGBColor[
              0.731332489294519, 0.5030791649818271, 0.5742495342753344], 
             UndirectedEdge[289, 291] -> 
             RGBColor[
              0.5471490964494157, 0.6426680909259248, 0.9577289938124869], 
             UndirectedEdge[263, 342] -> 
             RGBColor[
              0.2666938975771815, 0.3976425740963284, 0.9384991949775311], 
             UndirectedEdge[311, 319] -> 
             RGBColor[
              0.7308732764235066, 0.7896830254754603, 0.9738102758609529], 
             UndirectedEdge[141, 304] -> 
             RGBColor[
              0.3240734635805927, 0.45511787857278996`, 0.9418706524258115], 
             UndirectedEdge[30, 43] -> 
             RGBColor[
              0.2805395184040802, 0.4121951994484624, 0.9392876826008625], 
             UndirectedEdge[85, 95] -> 
             RGBColor[
              0.22064923730827996`, 0.3492467167536353, 0.9358770196921877], 
             UndirectedEdge[305, 438] -> 
             RGBColor[
              0.23628821482403703`, 0.36568427369114076`, 0.9367676363259161],
              UndirectedEdge[23, 212] -> 
             RGBColor[
              0.22050887971367938`, 0.3490991920225246, 0.9358690265348157], 
             UndirectedEdge[80, 461] -> 
             RGBColor[
              0.8669992096038857, 0.8968058897416262, 0.9792822184041656], 
             UndirectedEdge[115, 439] -> 
             RGBColor[
              0.8910404321249454, 0.9159554702009634, 0.9894694259289032], 
             UndirectedEdge[136, 377] -> 
             RGBColor[
              0.9750328863705816, 0.980900148051852, 0.9271469902951855], 
             UndirectedEdge[27, 488] -> 
             RGBColor[
              0.640741608541348, 0.7172763695298137, 0.9661908624850168], 
             UndirectedEdge[70, 170] -> 
             RGBColor[
              0.2774653661360603, 0.408964070502262, 0.9391126141769994], 
             UndirectedEdge[268, 441] -> 
             RGBColor[
              0.4298935905497302, 0.5467739538792281, 0.9486134173432208], 
             UndirectedEdge[394, 445] -> 
             RGBColor[
              0.2291408986849781, 0.35817199126297306`, 0.9363606072453035], 
             UndirectedEdge[234, 393] -> 
             RGBColor[
              0.42489506401207827`, 0.5422301548105988, 0.9483541347345662], 
             UndirectedEdge[228, 388] -> 
             RGBColor[
              0.9696267022726579, 0.9734928770909221, 0.7321607638451979], 
             UndirectedEdge[8, 114] -> 
             RGBColor[
              0.5604860564407306, 0.6540668560845098, 0.9585426619725401], 
             UndirectedEdge[21, 164] -> 
             RGBColor[
              0.8992062375406565, 0.5414501296947882, 0.27233399794458657`], 
             UndirectedEdge[100, 454] -> 
             RGBColor[
              0.915548639391991, 0.7016340736991815, 0.25084192040061865`], 
             UndirectedEdge[6, 267] -> 
             RGBColor[
              0.9083762130299251, 0.9201045780958312, 0.6977188544044266], 
             UndirectedEdge[210, 495] -> 
             RGBColor[
              0.8391330927044698, 0.3017996755229297, 0.18510719980929416`], 
             UndirectedEdge[112, 342] -> 
             RGBColor[
              0.25412533445039487`, 0.3844322173571471, 0.9377834339009834], 
             UndirectedEdge[93, 206] -> 
             RGBColor[
              0.30600971855859727`, 0.43582355730741806`, 0.940853232846973], 
             UndirectedEdge[485, 497] -> 
             RGBColor[
              0.24199741678266362`, 0.3716850069339687, 0.9370927669314526], 
             UndirectedEdge[36, 240] -> 
             RGBColor[
              0.25550742159800177`, 0.3858848785786683, 0.9378621417194251], 
             UndirectedEdge[275, 285] -> 
             RGBColor[
              0.36406115169331943`, 0.4897532041763907, 0.9444186325526303], 
             UndirectedEdge[36, 399] -> 
             RGBColor[
              0.24794512185068096`, 0.37793642206673694`, 0.937431479936235], 
             UndirectedEdge[72, 279] -> 
             RGBColor[
              0.26627234056032795`, 0.3971994909433567, 0.9384751879290589], 
             UndirectedEdge[278, 413] -> 
             RGBColor[
              0.9610998830487185, 0.9422076271108857, 0.6625746129461039], 
             UndirectedEdge[10, 120] -> 
             RGBColor[
              0.21319195993880496`, 0.3414086454196232, 0.9354523387780493], 
             UndirectedEdge[59, 153] -> 
             RGBColor[
              0.24356203444566857`, 0.3733295193002764, 0.9371818695927163], 
             UndirectedEdge[377, 488] -> 
             RGBColor[
              0.8752347056162003, 0.9025906545325564, 0.9472574998794909], 
             UndirectedEdge[53, 306] -> 
             RGBColor[
              0.9170459103045016, 0.6880097948516692, 0.28301334457340965`], 
             UndirectedEdge[172, 448] -> 
             RGBColor[
              0.45979588464643895`, 0.5695615806771241, 0.9513786855523698], 
             UndirectedEdge[138, 367] -> 
             RGBColor[
              0.22490572664447084`, 0.3537205569229832, 0.9361194204629721], 
             UndirectedEdge[71, 431] -> 
             RGBColor[
              0.602160734252356, 0.6860330125252593, 0.9630472221226452], 
             UndirectedEdge[180, 392] -> 
             RGBColor[
              0.2880661676144659, 0.4201061849857004, 0.9397163141387143], 
             UndirectedEdge[33, 227] -> 
             RGBColor[
              0.8620227096886874, 0.44626803209664856`, 0.20579398688200412`],
              UndirectedEdge[30, 384] -> 
             RGBColor[
              0.2758760121335012, 0.4072935586747084, 0.9390221028177923], 
             UndirectedEdge[441, 467] -> 
             RGBColor[
              0.5784857852356426, 0.6676055963951182, 0.960658898554645], 
             UndirectedEdge[99, 122] -> 
             RGBColor[
              0.930562919133284, 0.740007623770434, 0.37913808172539787`], 
             UndirectedEdge[89, 225] -> 
             RGBColor[
              0.2798755048828646, 0.4114972791367759, 0.9392498680131491], 
             UndirectedEdge[146, 497] -> 
             RGBColor[
              0.24696343657246012`, 0.3769046085968852, 0.9373755744119134], 
             UndirectedEdge[176, 197] -> 
             RGBColor[
              0.6522851143834272, 0.7277468526483104, 0.9663482548197164], 
             UndirectedEdge[326, 474] -> 
             RGBColor[
              0.9341363327937491, 0.7587482425843726, 0.49080863680582576`], 
             UndirectedEdge[173, 241] -> 
             RGBColor[
              0.8450225482014433, 0.8788658384170731, 0.9383874109586698], 
             UndirectedEdge[403, 405] -> 
             RGBColor[
              0.9614623294969025, 0.9678776355477525, 0.7913886839898783], 
             UndirectedEdge[79, 476] -> 
             RGBColor[
              0.9211605712027758, 0.6814740968415736, 0.3818708025801312], 
             UndirectedEdge[46, 257] -> 
             RGBColor[
              0.8882541401217813, 0.5816020846987996, 0.22826877228895565`], 
             UndirectedEdge[450, 491] -> 
             RGBColor[
              0.9059349577098716, 0.5635204793804358, 0.38523852750809673`], 
             UndirectedEdge[200, 243] -> 
             RGBColor[
              0.8700670583525245, 0.4728472627689348, 0.21211683898241762`], 
             UndirectedEdge[296, 424] -> 
             RGBColor[
              0.31700712622472516`, 0.4489973723195799, 0.9414203916580124], 
             UndirectedEdge[269, 466] -> 
             RGBColor[
              0.47622375697085434`, 0.5855400345383266, 0.9519420749950372], 
             UndirectedEdge[74, 453] -> 
             RGBColor[
              0.2830204227561394, 0.41480278722089764`, 0.9394289664335431], 
             UndirectedEdge[18, 469] -> 
             RGBColor[
              0.8724072991337889, 0.5135131700464854, 0.21524586162499276`], 
             UndirectedEdge[279, 481] -> 
             RGBColor[
              0.2983884604335446, 0.4300799385434647, 0.9403362145723715], 
             UndirectedEdge[19, 468] -> 
             RGBColor[
              0.5190507751439478, 0.6204278280896312, 0.9552807248464208], 
             UndirectedEdge[415, 464] -> 
             RGBColor[
              0.2654397247234546, 0.39632435890790974`, 0.9384277716888938], 
             UndirectedEdge[234, 262] -> 
             RGBColor[
              0.4323322286458682, 0.548267980100758, 0.9489396155777698], 
             UndirectedEdge[241, 417] -> 
             RGBColor[
              0.7032574015004508, 0.7681092940971459, 0.9710577835336467], 
             UndirectedEdge[309, 489] -> 
             RGBColor[
              0.9915641796444485, 0.9888374754562259, 0.6482959890771074], 
             UndirectedEdge[83, 426] -> 
             RGBColor[
              0.895460047558787, 0.9194795515806435, 0.9898909727944203], 
             UndirectedEdge[6, 99] -> 
             RGBColor[
              0.9106556765920616, 0.9271034208247384, 0.765274234275318], 
             UndirectedEdge[121, 491] -> 
             RGBColor[
              0.9108136867178351, 0.6010205284083265, 0.38991040391585896`], 
             UndirectedEdge[42, 358] -> 
             RGBColor[
              0.22905024080537584`, 0.3580767040834695, 0.9363554444131764], 
             UndirectedEdge[69, 461] -> 
             RGBColor[
              0.926959006974305, 0.9443701606295145, 0.985066529908563], 
             UndirectedEdge[161, 387] -> 
             RGBColor[
              0.8827228822801044, 0.901646814849579, 0.6975808353380122], 
             UndirectedEdge[117, 390] -> 
             RGBColor[
              0.34091437037852435`, 0.46896566133560236`, 0.9429707972165], 
             UndirectedEdge[244, 334] -> 
             RGBColor[
              0.3726225537176192, 0.4971686603012616, 0.9449641575190681], 
             UndirectedEdge[173, 493] -> 
             RGBColor[
              0.9890701085039466, 0.9882775676582451, 0.7238989830539463], 
             UndirectedEdge[229, 255] -> 
             RGBColor[
              0.34428066244060973`, 0.47097736208628804`, 0.9432183946864745],
              UndirectedEdge[39, 401] -> 
             RGBColor[
              0.6985569826136641, 0.7641508706261513, 0.9707851169753527], 
             UndirectedEdge[379, 380] -> 
             RGBColor[
              0.29107513038505384`, 0.42321764858400834`, 0.9398895428612922],
              UndirectedEdge[92, 140] -> 
             RGBColor[
              0.554385826473297, 0.649114414584719, 0.9580624295236251], 
             UndirectedEdge[78, 97] -> 
             RGBColor[
              0.22558180327383132`, 0.35443115632617517`, 0.9361579220268484],
              UndirectedEdge[395, 463] -> 
             RGBColor[
              0.2660424669485921, 0.39695787920259357`, 0.9384620969669382], 
             UndirectedEdge[174, 338] -> 
             RGBColor[
              0.29338121786998295`, 0.4246423923281867, 0.9400574530924843], 
             UndirectedEdge[143, 423] -> 
             RGBColor[
              0.1833764464098977, 0.31007065028799885`, 0.9337543893906777], 
             UndirectedEdge[94, 100] -> 
             RGBColor[
              0.943316965793535, 0.8656345224892459, 0.6119300548794735], 
             UndirectedEdge[404, 408] -> 
             RGBColor[
              0.2179764205636531, 0.3464374168886629, 0.9357248067326592], 
             UndirectedEdge[301, 389] -> 
             RGBColor[
              0.21362623144598136`, 0.3418650923080694, 0.9354770698979359], 
             UndirectedEdge[16, 422] -> 
             RGBColor[
              0.3189470428658002, 0.4437679620863825, 0.9417969982435161], 
             UndirectedEdge[389, 451] -> 
             RGBColor[
              0.21497280031897864`, 0.34328042157098726`, 0.9355537550031829],
              UndirectedEdge[74, 296] -> 
             RGBColor[
              0.2975769167094639, 0.42967045866758025`, 0.9402737595026511], 
             UndirectedEdge[225, 453] -> 
             RGBColor[
              0.2792780627176027, 0.4108693295410645, 0.939215844565674], 
             UndirectedEdge[340, 378] -> 
             RGBColor[
              0.31025949401998754`, 0.4407803246133216, 0.9410773105637218], 
             UndirectedEdge[52, 428] -> 
             RGBColor[
              0.8330642703587228, 0.25515204759860854`, 0.17929568867725226`],
              UndirectedEdge[84, 230] -> 
             RGBColor[
              0.22859615804425376`, 0.3575994343110202, 0.9363295850716857], 
             UndirectedEdge[119, 237] -> 
             RGBColor[
              0.9483698835729416, 0.9591789791220269, 0.8977829179807035], 
             UndirectedEdge[67, 171] -> 
             RGBColor[
              0.25918264815811415`, 0.38974777471616917`, 0.9380714404350129],
              UndirectedEdge[25, 157] -> 
             RGBColor[
              0.3079594456965586, 0.4405872728097553, 0.9408648783928987], 
             UndirectedEdge[124, 484] -> 
             RGBColor[
              0.9777721242086441, 0.9364424046411297, 0.38854804229456463`], 
             UndirectedEdge[368, 500] -> 
             RGBColor[
              0.6137971561371982, 0.33936679556971105`, 0.5567621778131115], 
             UndirectedEdge[283, 422] -> 
             RGBColor[
              0.207613081778549, 0.3355448907518888, 0.9351346299200334], 
             UndirectedEdge[334, 369] -> 
             RGBColor[
              0.4113757512055576, 0.5307347321729735, 0.9474334769948924], 
             UndirectedEdge[42, 346] -> 
             RGBColor[
              0.22517846281523107`, 0.3540072199309242, 0.9361349523844199], 
             UndirectedEdge[112, 263] -> 
             RGBColor[
              0.2608320887293601, 0.39148144133712115`, 0.9381653736354167], 
             UndirectedEdge[146, 201] -> 
             RGBColor[
              0.28119600247616383`, 0.41288520583171645`, 0.9393250683975864],
              UndirectedEdge[16, 243] -> 
             RGBColor[
              0.6215940953786275, 0.41368682466407874`, 0.566114433864064], 
             UndirectedEdge[285, 481] -> 
             RGBColor[
              0.3163175193458222, 0.44840006950172373`, 0.9413764505174842], 
             UndirectedEdge[231, 444] -> 
             RGBColor[
              0.2648697036740537, 0.39572523064356746`, 0.938395309833401], 
             UndirectedEdge[137, 408] -> 
             RGBColor[
              0.2212925375899113, 0.34992286613722345`, 0.9359136546915492], 
             UndirectedEdge[431, 436] -> 
             RGBColor[
              0.46072987194196846`, 0.5729505557434673, 0.9507253360979548], 
             UndirectedEdge[98, 277] -> 
             RGBColor[
              0.8832681348130269, 0.9067408984138945, 0.8502742951726139], 
             UndirectedEdge[131, 391] -> 
             RGBColor[
              0.2523681386345833, 0.3825852931420795, 0.9376833641988113], 
             UndirectedEdge[52, 227] -> 
             RGBColor[
              0.8407131059122084, 0.31394434940381033`, 0.18662022224139424`],
              UndirectedEdge[27, 419] -> 
             RGBColor[
              0.5124047260338506, 0.6150322660209537, 0.9547575235151939], 
             UndirectedEdge[232, 312] -> 
             RGBColor[
              0.3303045820158528, 0.4601142095117522, 0.9422823672274991], 
             UndirectedEdge[247, 466] -> 
             RGBColor[
              0.4992597773340883, 0.6043606044932961, 0.953722705002015], 
             UndirectedEdge[253, 484] -> 
             RGBColor[
              0.9889617727140382, 0.9876413426482502, 0.6827040059696212], 
             UndirectedEdge[121, 200] -> 
             RGBColor[
              0.8641469744095227, 0.4273429033856967, 0.2064477599128205], 
             UndirectedEdge[79, 99] -> 
             RGBColor[
              0.9937251243023482, 0.9889870003070016, 0.5583966882336657], 
             UndirectedEdge[109, 300] -> 
             RGBColor[
              0.23995882574419874`, 0.3695423184984049, 0.9369766721876371], 
             UndirectedEdge[31, 397] -> 
             RGBColor[
              0.40579315804314603`, 0.5258993705649835, 0.947077759095077], 
             UndirectedEdge[70, 374] -> 
             RGBColor[
              0.2549902427614091, 0.38534129083037727`, 0.9378326891497786], 
             UndirectedEdge[240, 352] -> 
             RGBColor[
              0.24222822396059346`, 0.3719275999119933, 0.937105911058787], 
             UndirectedEdge[105, 323] -> 
             RGBColor[
              0.24262496833818112`, 0.37234460340788433`, 0.93712850506416], 
             UndirectedEdge[46, 53] -> 
             RGBColor[
              0.9470835767696775, 0.821834287485996, 0.3079282681448157], 
             UndirectedEdge[221, 223] -> 
             RGBColor[
              0.46323693275442124`, 0.5733927057392445, 0.9513629056103252], 
             UndirectedEdge[33, 159] -> 
             RGBColor[
              0.8495822086293704, 0.3506448894924134, 0.19388094901806585`], 
             UndirectedEdge[16, 454] -> 
             RGBColor[
              0.6518822537994468, 0.581257698540845, 0.5925638840512331], 
             UndirectedEdge[195, 224] -> 
             RGBColor[
              0.28455910865490164`, 0.41642004365881735`, 0.9395165923191959],
              UndirectedEdge[259, 500] -> 
             RGBColor[
              0.8406666807462297, 0.3081837142621151, 0.18636416654762122`], 
             UndirectedEdge[24, 77] -> 
             RGBColor[
              0.7218949448567346, 0.7822619477143448, 0.9732512022240677], 
             UndirectedEdge[226, 386] -> 
             RGBColor[
              0.1791759961486071, 0.30565571073945375`, 0.9335151799623065], 
             UndirectedEdge[289, 314] -> 
             RGBColor[
              0.3847232625603534, 0.5076496861015274, 0.9457352039862904], 
             UndirectedEdge[179, 325] -> 
             RGBColor[
              0.1789730287155782, 0.30544237909846184`, 0.9335036212672588], 
             UndirectedEdge[81, 83] -> 
             RGBColor[
              0.8721819244967113, 0.9009182081187621, 0.9876706846361336], 
             UndirectedEdge[312, 376] -> 
             RGBColor[
              0.2919333190231436, 0.4241708063077816, 0.9399365426905006], 
             UndirectedEdge[270, 309] -> 
             RGBColor[
              0.9915269265441726, 0.9888220703419007, 0.6489133693566129], 
             UndirectedEdge[139, 269] -> 
             RGBColor[
              0.506487260336648, 0.6101093099259678, 0.9543245288388581], 
             UndirectedEdge[269, 425] -> 
             RGBColor[
              0.4121410951718726, 0.5313976346492894, 0.947482244035659], 
             UndirectedEdge[25, 492] -> 
             RGBColor[
              0.29499729755319337`, 0.42696323326341856`, 0.9401267032319138],
              UndirectedEdge[142, 173] -> 
             RGBColor[
              0.8420436305365226, 0.8765386852966244, 0.9380905002853989], 
             UndirectedEdge[132, 209] -> 
             RGBColor[
              0.7780282420345992, 0.8243344980363514, 0.8860787195432924], 
             UndirectedEdge[389, 409] -> 
             RGBColor[
              0.23002772223876133`, 0.35910409904586005`, 0.9364111105347535],
              UndirectedEdge[337, 370] -> 
             RGBColor[
              0.7258270188663856, 0.785286025150145, 0.9737542955576297], 
             UndirectedEdge[230, 242] -> 
             RGBColor[
              0.2244428247428983, 0.35323401767475476`, 0.9360930588844796], 
             UndirectedEdge[28, 461] -> 
             RGBColor[
              0.954655789916814, 0.9657029428810652, 0.9616400993934879], 
             UndirectedEdge[318, 350] -> 
             RGBColor[
              0.3520561578815369, 0.47935508192515797`, 0.9436536849625428], 
             UndirectedEdge[390, 478] -> 
             RGBColor[
              0.2833977050944594, 0.41519933487955374`, 0.9394504521045712], 
             UndirectedEdge[167, 434] -> 
             RGBColor[
              0.988936416573675, 0.989692938179159, 0.8330157392176978], 
             UndirectedEdge[247, 269] -> 
             RGBColor[
              0.47197536116157857`, 0.5820909954323062, 0.9516076257145445], 
             UndirectedEdge[394, 398] -> 
             RGBColor[
              0.24489676758341208`, 0.3747324084550136, 0.93725788067035], 
             UndirectedEdge[14, 158] -> 
             RGBColor[
              0.33213200521333075`, 0.4619125616859979, 0.9423909174068014], 
             UndirectedEdge[131, 433] -> 
             RGBColor[
              0.29455765065289613`, 0.4253795454830047, 0.9401427329325757], 
             UndirectedEdge[87, 422] -> 
             RGBColor[
              0.2066326331143824, 0.33451437704181397`, 0.9350787948190529], 
             UndirectedEdge[210, 469] -> 
             RGBColor[
              0.8482471960053599, 0.3686686083126496, 0.19371011734270402`], 
             UndirectedEdge[312, 414] -> 
             RGBColor[
              0.2895347527456831, 0.421649761072285, 0.9397999478893602], 
             UndirectedEdge[277, 311] -> 
             RGBColor[
              0.7590792000371321, 0.8117177073753836, 0.9766215787274166], 
             UndirectedEdge[332, 424] -> 
             RGBColor[
              0.36139324266635137`, 0.48744239547023754`, 0.9442486357485711],
              UndirectedEdge[328, 433] -> 
             RGBColor[
              0.35540962848104596`, 0.48225968960811955`, 0.9438673651437858],
              UndirectedEdge[88, 428] -> 
             RGBColor[
              0.8484718113152332, 0.36067584148776255`, 0.1935446274280821], 
             UndirectedEdge[8, 162] -> 
             RGBColor[
              0.5411625228784538, 0.6383791410233868, 0.9570214426260819], 
             UndirectedEdge[27, 289] -> 
             RGBColor[
              0.47574498443284424`, 0.5848915439571711, 0.9519761681862727], 
             UndirectedEdge[192, 280] -> 
             RGBColor[
              0.25575350846358835`, 0.3861435314772083, 0.9378761560023672], 
             UndirectedEdge[347, 477] -> 
             RGBColor[
              0.2117993137193227, 0.3399448859440771, 0.9353730296360853], 
             UndirectedEdge[145, 346] -> 
             RGBColor[
              0.21927041175810352`, 0.3477974836778107, 0.9357984976168947], 
             UndirectedEdge[232, 415] -> 
             RGBColor[
              0.3216051563189196, 0.45097056152882875`, 0.9417869478037058], 
             UndirectedEdge[189, 374] -> 
             RGBColor[
              0.2557528431125027, 0.3861428321510315, 0.9378761181116072], 
             UndirectedEdge[139, 140] -> 
             RGBColor[
              0.5318346221124927, 0.6308063309644387, 0.9562871161085591], 
             UndirectedEdge[134, 251] -> 
             RGBColor[
              0.24587579480159133`, 0.37576142813523083`, 0.9373136348220843],
              UndirectedEdge[67, 281] -> 
             RGBColor[
              0.25076586641156884`, 0.38090120344576484`, 0.93759211716606], 
             UndirectedEdge[167, 495] -> 
             RGBColor[0.9144363630663, 0.657074043523211, 0.5293091727449846],
              UndirectedEdge[143, 179] -> 
             RGBColor[
              0.17892806920489446`, 0.30539512380213557`, 0.933501060889637], 
             UndirectedEdge[21, 175] -> 
             RGBColor[
              0.9683090151158134, 0.9568481859192783, 0.670037151361724], 
             UndirectedEdge[366, 473] -> 
             RGBColor[
              0.29591877827497415`, 0.42668767083692927`, 0.940224732684648], 
             UndirectedEdge[143, 292] -> 
             RGBColor[
              0.1789488167630598, 0.30541693080123855`, 0.9335022424323813], 
             UndirectedEdge[267, 486] -> 
             RGBColor[
              0.9619951023866931, 0.9628588250229391, 0.7028330719374227], 
             UndirectedEdge[248, 380] -> 
             RGBColor[
              0.257695358998007, 0.3881845395093172, 0.937986741517592], 
             UndirectedEdge[48, 407] -> 
             RGBColor[
              0.2109346093646478, 0.33903602684189116`, 0.935323786002302], 
             UndirectedEdge[436, 459] -> 
             RGBColor[
              0.4317329658175249, 0.5478348930853527, 0.9488776788806625], 
             UndirectedEdge[235, 262] -> 
             RGBColor[
              0.416563768888231, 0.5346101328045243, 0.9479348632655147], 
             UndirectedEdge[236, 283] -> 
             RGBColor[
              0.23426865806856206`, 0.3635615914938426, 0.9366526255563583], 
             UndirectedEdge[99, 493] -> 
             RGBColor[
              0.9935993972524345, 0.9887180828601909, 0.5447120747479771], 
             UndirectedEdge[109, 456] -> 
             RGBColor[
              0.23880926652767986`, 0.3683340588755796, 0.9369112064908769], 
             UndirectedEdge[208, 289] -> 
             RGBColor[
              0.3807447886449092, 0.5042037319598828, 0.9454816991464247], 
             UndirectedEdge[266, 410] -> 
             RGBColor[
              0.326592877843097, 0.45552256223454524`, 0.9420962704893343], 
             UndirectedEdge[299, 301] -> 
             RGBColor[
              0.20895952840977988`, 0.3369600915309596, 0.9352113080637927], 
             UndirectedEdge[314, 359] -> 
             RGBColor[
              0.3577633677707141, 0.48429838027845357`, 0.9440173433299934], 
             UndirectedEdge[209, 214] -> 
             RGBColor[
              0.3828653435329973, 0.49291080046599856`, 0.946830407391962], 
             UndirectedEdge[210, 326] -> 
             RGBColor[
              0.8556196126725499, 0.40214503052670025`, 0.19986184252427644`],
              UndirectedEdge[53, 317] -> 
             RGBColor[
              0.9299563150856899, 0.7479312815030192, 0.29383694306613123`], 
             UndirectedEdge[402, 459] -> 
             RGBColor[
              0.4714286755649022, 0.5800616585296188, 0.952002670562152], 
             UndirectedEdge[89, 249] -> 
             RGBColor[
              0.28752479280706156`, 0.41953716573797317`, 0.9396854836443249],
              UndirectedEdge[67, 135] -> 
             RGBColor[
              0.2536249197696536, 0.3839062497995648, 0.9377549360252124], 
             UndirectedEdge[90, 178] -> 
             RGBColor[
              0.9282272067510295, 0.7348311823756897, 0.4981717768803556], 
             UndirectedEdge[174, 229] -> 
             RGBColor[
              0.2788164534778155, 0.4103841489623319, 0.9391895566023578], 
             UndirectedEdge[266, 364] -> 
             RGBColor[
              0.2740437091478759, 0.405367692062097, 0.9389177558734103], 
             UndirectedEdge[407, 430] -> 
             RGBColor[
              0.22704868393744712`, 0.35597294090924125`, 0.9362414587105858],
              UndirectedEdge[217, 355] -> 
             RGBColor[
              0.32421328138501737`, 0.4552389817275355, 0.9418795614926734], 
             UndirectedEdge[176, 426] -> 
             RGBColor[
              0.7385594994235554, 0.7955507282121491, 0.9748396268265297], 
             UndirectedEdge[280, 483] -> 
             RGBColor[
              0.2767707745378052, 0.40823401069284493`, 0.939073058213035], 
             UndirectedEdge[51, 347] -> 
             RGBColor[
              0.1789270004053139, 0.3053940004260106, 0.9335010000230821], 
             UndirectedEdge[152, 451] -> 
             RGBColor[
              0.20772437674817806`, 0.3356618688214776, 0.9351409680039076], 
             UndirectedEdge[105, 342] -> 
             RGBColor[
              0.252946206923672, 0.38319287956555814`, 0.9377162843326995], 
             UndirectedEdge[318, 496] -> 
             RGBColor[
              0.3094159330482752, 0.43947691523709653`, 0.9410445311268166], 
             UndirectedEdge[114, 289] -> 
             RGBColor[
              0.47002476811242727`, 0.580247614655448, 0.9515258518036867], 
             UndirectedEdge[103, 331] -> 
             RGBColor[
              0.6585237003454188, 0.7308163449939742, 0.968260051050067], 
             UndirectedEdge[107, 113] -> 
             RGBColor[
              0.18193197659231264`, 0.3085524209250408, 0.9336721289714678], 
             UndirectedEdge[16, 56] -> 
             RGBColor[
              0.6202778449645745, 0.4035695471970573, 0.5648539909810746], 
             UndirectedEdge[140, 370] -> 
             RGBColor[
              0.5455387009707735, 0.6419319195433083, 0.9573659513959778], 
             UndirectedEdge[213, 500] -> 
             RGBColor[
              0.8618492799802115, 0.40436895006188167`, 0.20403944658147605`],
              UndirectedEdge[280, 327] -> 
             RGBColor[
              0.25698076875714937`, 0.3874334598585377, 0.9379460466605166], 
             UndirectedEdge[76, 238] -> 
             RGBColor[
              0.36573961104663694`, 0.49120700130641426`, 0.9445255824984202],
              UndirectedEdge[253, 261] -> 
             RGBColor[
              0.9325093316648222, 0.7680041432668934, 0.5596474808987255], 
             UndirectedEdge[232, 350] -> 
             RGBColor[
              0.3591838096222978, 0.48552869561681206`, 0.944107852628729], 
             UndirectedEdge[166, 320] -> 
             RGBColor[
              0.9133614547699682, 0.6417853106074096, 0.5113435478107814], 
             UndirectedEdge[33, 119] -> 
             RGBColor[
              0.9345308133147854, 0.7655949021985857, 0.5124594755699873], 
             UndirectedEdge[71, 228] -> 
             RGBColor[
              0.8744314209010298, 0.8983757407693698, 0.7323068273714743], 
             UndirectedEdge[50, 244] -> 
             RGBColor[
              0.3916895278498226, 0.5136835149605915, 0.9461790882505088], 
             UndirectedEdge[235, 344] -> 
             RGBColor[
              0.4103923521286693, 0.5295998986599555, 0.9474490267315575], 
             UndirectedEdge[72, 494] -> 
             RGBColor[
              0.25624399533436604`, 0.3866590642770594, 0.9379040885040477], 
             UndirectedEdge[185, 496] -> 
             RGBColor[
              0.2804171463023576, 0.4120665786107125, 0.9392807136907027], 
             UndirectedEdge[106, 370] -> 
             RGBColor[
              0.5546493379031965, 0.6493283450345659, 0.9580831741086608], 
             UndirectedEdge[51, 113] -> 
             RGBColor[
              0.17905963075308248`, 0.3055334033307651, 0.9335085531251784], 
             UndirectedEdge[422, 443] -> 
             RGBColor[
              0.5842619922483114, 0.5706803433206208, 0.6014015077150748], 
             UndirectedEdge[4, 335] -> 
             RGBColor[
              0.3005379095306292, 0.4317763657356928, 0.9404792286546308], 
             UndirectedEdge[1, 84] -> 
             RGBColor[
              0.249739891419232, 0.3798228386782472, 0.9375336894080404], 
             UndirectedEdge[90, 272] -> 
             RGBColor[
              0.8426763546129947, 0.3190239891395971, 0.18810823554711417`], 
             UndirectedEdge[213, 450] -> 
             RGBColor[
              0.8609571905590665, 0.3975119598548832, 0.20318518074431657`], 
             UndirectedEdge[5, 212] -> 
             RGBColor[
              0.22856179646777947`, 0.35756331811549596`, 0.9363276282307389],
              UndirectedEdge[50, 106] -> 
             RGBColor[
              0.47939668252268425`, 0.5878987040064534, 0.9522518873645769], 
             UndirectedEdge[115, 291] -> 
             RGBColor[
              0.7880477603543681, 0.8351660025398585, 0.9792918656511329], 
             UndirectedEdge[9, 117] -> 
             RGBColor[
              0.4781094761010015, 0.5852282777412916, 0.9525996605197433], 
             UndirectedEdge[194, 388] -> 
             RGBColor[
              0.9663440953419832, 0.9740339462184904, 0.9245637966956991], 
             UndirectedEdge[202, 211] -> 
             RGBColor[
              0.2350487330765592, 0.3643814997868598, 0.9366970496740461], 
             UndirectedEdge[113, 308] -> 
             RGBColor[
              0.17906927273157397`, 0.3055435376614964, 0.9335091022215896], 
             UndirectedEdge[51, 421] -> 
             RGBColor[
              0.17899180329589925`, 0.30546211237275633`, 0.9335046904518336],
              UndirectedEdge[109, 335] -> 
             RGBColor[
              0.2653660882581673, 0.3962469623140712, 0.938423578201131], 
             UndirectedEdge[278, 329] -> 
             RGBColor[
              0.9154608124727537, 0.9351010298249371, 0.9804756251775316], 
             UndirectedEdge[129, 206] -> 
             RGBColor[
              0.3491669657996257, 0.47685260895882275`, 0.9434695881978956], 
             UndirectedEdge[166, 227] -> 
             RGBColor[
              0.8418757895124331, 0.32288124504634075`, 0.18773360937003286`],
              UndirectedEdge[294, 411] -> 
             RGBColor[
              0.23895135352540886`, 0.3684834013190287, 0.9369192981351986], 
             UndirectedEdge[362, 384] -> 
             RGBColor[
              0.33614117025697976`, 0.4632658145057482, 0.9427239752429382], 
             UndirectedEdge[143, 308] -> 
             RGBColor[
              0.17893664305769685`, 0.3054041354650445, 0.9335015491578702], 
             UndirectedEdge[151, 310] -> 
             RGBColor[
              0.3017756973424442, 0.43451576996419494`, 0.9404970515752908], 
             UndirectedEdge[297, 397] -> 
             RGBColor[
              0.4389561312944613, 0.5528301617459719, 0.9496863711644075], 
             UndirectedEdge[114, 359] -> 
             RGBColor[
              0.443064873322788, 0.5568963088323743, 0.9498079911473898], 
             UndirectedEdge[141, 220] -> 
             RGBColor[
              0.32424804297229537`, 0.4552690904672675, 0.9418817764702763], 
             UndirectedEdge[122, 493] -> 
             RGBColor[
              0.9305407827762575, 0.7399602763410837, 0.37672867587283654`], 
             UndirectedEdge[146, 442] -> 
             RGBColor[
              0.2709392779878975, 0.40210473808065567`, 0.9387409631114438], 
             UndirectedEdge[294, 478] -> 
             RGBColor[
              0.25217734273393444`, 0.38238475455333876`, 0.9376724986545265],
              UndirectedEdge[76, 487] -> 
             RGBColor[
              0.49537833953651855`, 0.6000692782186605, 0.9537321847167134], 
             UndirectedEdge[67, 70] -> 
             RGBColor[
              0.25743661729140077`, 0.3879125855705024, 0.9379720065601748], 
             UndirectedEdge[346, 358] -> 
             RGBColor[
              0.2217544347167852, 0.3504083493035373, 0.935939959049609], 
             UndirectedEdge[149, 165] -> 
             RGBColor[
              0.3889540140770109, 0.511314150421502, 0.9460047837318252], 
             UndirectedEdge[175, 375] -> 
             RGBColor[
              0.9569658514087618, 0.9674257829593813, 0.9577297678481509], 
             UndirectedEdge[18, 428] -> 
             RGBColor[
              0.8573587081531882, 0.40102916444142644`, 0.2009600719874468], 
             UndirectedEdge[2, 47] -> 
             RGBColor[
              0.22219066917343752`, 0.3508668593763409, 0.9359648019565643], 
             UndirectedEdge[140, 466] -> 
             RGBColor[
              0.5015711187466989, 0.6062370555767975, 0.9539046622647382], 
             UndirectedEdge[199, 382] -> 
             RGBColor[
              0.31253428709090747`, 0.4426711481132517, 0.9412251688089472], 
             UndirectedEdge[305, 499] -> 
             RGBColor[
              0.2559152551896322, 0.3863135375416151, 0.9378853672391325], 
             UndirectedEdge[252, 282] -> 
             RGBColor[
              0.6717272001021579, 0.7429460920325152, 0.9682785844173988], 
             UndirectedEdge[235, 249] -> 
             RGBColor[
              0.32329479630323715`, 0.4526684377082041, 0.9418860278221313], 
             UndirectedEdge[130, 214] -> 
             RGBColor[
              0.1893670574265447, 0.316367162293171, 0.9340955458257609], 
             UndirectedEdge[100, 475] -> 
             RGBColor[
              0.8851091218155209, 0.5328997870260774, 0.22424752851506258`], 
             UndirectedEdge[10, 438] -> 
             RGBColor[
              0.22021348611856342`, 0.3487887146250221, 0.9358522043065695], 
             UndirectedEdge[39, 179] -> 
             RGBColor[
              0.40129536230508595`, 0.5053759222252174, 0.9485085964517164], 
             UndirectedEdge[400, 414] -> 
             RGBColor[
              0.28528989827003975`, 0.41718814987906533`, 0.9395582097066717],
              UndirectedEdge[41, 191] -> 
             RGBColor[
              0.22546402831064583`, 0.35430736737250323`, 0.9361512149169275],
              UndirectedEdge[25, 96] -> 
             RGBColor[
              0.3047685081778331, 0.4372333951604509, 0.9406831592217764], 
             UndirectedEdge[106, 274] -> 
             RGBColor[
              0.49029479958875166`, 0.5970824316919869, 0.9530169491141065], 
             UndirectedEdge[204, 363] -> 
             RGBColor[
              0.4533522044192463, 0.5657736996191047, 0.9504726028052438], 
             UndirectedEdge[99, 413] -> 
             RGBColor[
              0.9837287794830555, 0.9560851708017216, 0.4499899045367475], 
             UndirectedEdge[37, 118] -> 
             RGBColor[
              0.31537415178862416`, 0.44729581939211016`, 0.9413268540323092],
              UndirectedEdge[411, 478] -> 
             RGBColor[
              0.2528159536736963, 0.3830559751413007, 0.9377088666028057], 
             UndirectedEdge[300, 451] -> 
             RGBColor[
              0.21870173252116284`, 0.3471997657434399, 0.9357661121756364], 
             UndirectedEdge[122, 233] -> 
             RGBColor[
              0.8553320507775657, 0.4120002528594733, 0.20005892957140564`], 
             UndirectedEdge[97, 404] -> 
             RGBColor[
              0.2225914076005732, 0.3512880608715443, 0.9359876234171504], 
             UndirectedEdge[362, 498] -> 
             RGBColor[
              0.4251755260464191, 0.5424546669097134, 0.9483770922703834], 
             UndirectedEdge[121, 454] -> 
             RGBColor[
              0.8636741838299911, 0.42519607178708907`, 0.20605325186410173`],
              UndirectedEdge[173, 417] -> 
             RGBColor[
              0.8427978094114925, 0.8771278555657226, 0.9381656697874536], 
             UndirectedEdge[36, 352] -> 
             RGBColor[
              0.2411100918235177, 0.37075237214225454`, 0.9370422350877088], 
             UndirectedEdge[309, 337] -> 
             RGBColor[
              0.926620732552479, 0.9394372573300418, 0.7346744089406012], 
             UndirectedEdge[207, 456] -> 
             RGBColor[
              0.2203607616298221, 0.3489435105251617, 0.9358605914290611], 
             UndirectedEdge[95, 97] -> 
             RGBColor[
              0.22940871371662525`, 0.3584534818416879, 0.936375858915159], 
             UndirectedEdge[185, 350] -> 
             RGBColor[
              0.3230573711356193, 0.45194474529877393`, 0.9418898675264287], 
             UndirectedEdge[303, 435] -> 
             RGBColor[
              0.2816881021628791, 0.4134024338033765, 0.9393530927467486], 
             UndirectedEdge[14, 441] -> 
             RGBColor[
              0.3784375409652084, 0.5020200893703757, 0.9453414651985335], 
             UndirectedEdge[67, 147] -> 
             RGBColor[
              0.2540581203038455, 0.3843615710275007, 0.9377796061547718], 
             UndirectedEdge[115, 419] -> 
             RGBColor[
              0.7169294577871506, 0.7776214885576594, 0.9735615399917263], 
             UndirectedEdge[113, 209] -> 
             RGBColor[
              0.3725579164542212, 0.4820770410775821, 0.9462434146682975], 
             UndirectedEdge[100, 121] -> 
             RGBColor[
              0.8793403970281699, 0.48855884043917713`, 0.2187233911438525], 
             UndirectedEdge[39, 254] -> 
             RGBColor[
              0.43007991849913185`, 0.5356303158314321, 0.9501478343440324], 
             UndirectedEdge[2, 339] -> 
             RGBColor[
              0.21206918576719214`, 0.340228538577264, 0.9353883984499716], 
             UndirectedEdge[76, 436] -> 
             RGBColor[
              0.4421225577048329, 0.5568338353820671, 0.9495396944885663], 
             UndirectedEdge[121, 161] -> 
             RGBColor[
              0.9088989497892817, 0.5955852022276555, 0.2954383174204215], 
             UndirectedEdge[215, 430] -> 
             RGBColor[
              0.26193106415637823`, 0.3926365341899838, 0.9382279586601969], 
             UndirectedEdge[100, 254] -> 
             RGBColor[
              0.5838565510201338, 0.5654509378756822, 0.6001458285837606], 
             UndirectedEdge[186, 389] -> 
             RGBColor[
              0.22710509641847854`, 0.3560322340035631, 0.9362446713179258], 
             UndirectedEdge[197, 426] -> 
             RGBColor[
              0.7839000078483491, 0.8315135813435113, 0.9789878324723824], 
             UndirectedEdge[316, 378] -> 
             RGBColor[
              0.26678973270236006`, 0.397743302889189, 0.9385046526461347], 
             UndirectedEdge[185, 330] -> 
             RGBColor[
              0.29519715135054264`, 0.42760130102279975`, 0.9401224131131387],
              UndirectedEdge[56, 166] -> 
             RGBColor[
              0.8373970102117498, 0.28845538472768467`, 0.18344472525364075`],
              UndirectedEdge[38, 73] -> 
             RGBColor[
              0.25393957190424143`, 0.3842369691431141, 0.937772854998791], 
             UndirectedEdge[97, 430] -> 
             RGBColor[
              0.23573676666398502`, 0.3651046667110934, 0.9367362321689956], 
             UndirectedEdge[222, 372] -> 
             RGBColor[
              0.4565833875774816, 0.5694260572148426, 0.9504426196097452], 
             UndirectedEdge[137, 430] -> 
             RGBColor[
              0.22990978373834364`, 0.3589801382041882, 0.9364043941116291], 
             UndirectedEdge[30, 355] -> 
             RGBColor[
              0.29831901354920054`, 0.4290370635324922, 0.9403677718036725], 
             UndirectedEdge[111, 442] -> 
             RGBColor[
              0.2785182841132166, 0.41007075405510884`, 0.939172576298146], 
             UndirectedEdge[183, 408] -> 
             RGBColor[
              0.21373593745192992`, 0.3419804002760839, 0.9354833174926791], 
             UndirectedEdge[39, 283] -> 
             RGBColor[
              0.4024378733893724, 0.5065767738141891, 0.9485736607677728], 
             UndirectedEdge[244, 498] -> 
             RGBColor[
              0.40216527018839365`, 0.5225243398145787, 0.9469108991142803], 
             UndirectedEdge[259, 454] -> 
             RGBColor[
              0.8808615626968692, 0.5519020063430116, 0.22230030637499004`], 
             UndirectedEdge[17, 418] -> 
             RGBColor[
              0.9292223734187801, 0.9452976774305406, 0.9548682913375369], 
             UndirectedEdge[70, 391] -> 
             RGBColor[
              0.24968869542225258`, 0.3797690284394081, 0.93753077387175], 
             UndirectedEdge[18, 495] -> 
             RGBColor[
              0.8632931958328989, 0.4466442372567656, 0.2066429440915829], 
             UndirectedEdge[48, 95] -> 
             RGBColor[
              0.21729689825533816`, 0.34572319585842115`, 0.9356861089424638],
              UndirectedEdge[50, 92] -> 
             RGBColor[
              0.5250378077135244, 0.6249522255456361, 0.9558449239285502], 
             UndirectedEdge[118, 141] -> 
             RGBColor[
              0.31734549257895406`, 0.4492904482488255, 0.9414419520628983], 
             UndirectedEdge[373, 398] -> 
             RGBColor[
              0.27738327375901567`, 0.40887778620903076`, 0.9391079391375716],
              UndirectedEdge[218, 409] -> 
             RGBColor[
              0.2367642996218614, 0.3661846689991738, 0.9367947486508479]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {4}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.2206581667895666, 0.3492561022046294, 0.935877528212937], 316 -> 
             RGBColor[
              0.2504950392509415, 0.38061654692851177`, 0.937576693959915], 
             308 -> RGBColor[
              0.17894628476761076`, 0.30541426951348377`, 0.9335020982389862],
              160 -> RGBColor[
              0.42248174875901884`, 0.5403541890501141, 0.948141141338351], 
             245 -> RGBColor[
              0.22156287013367681`, 0.3502070027807943, 0.9359290497299955], 
             155 -> RGBColor[
              0.5658891207695752, 0.6584533071119401, 0.9589680109885835], 
             425 -> RGBColor[
              0.37534284954540054`, 0.499524843821242, 0.9451374923637511], 
             213 -> RGBColor[
              0.90420589766789, 0.657903179238463, 0.24177939169682186`], 352 -> 
             RGBColor[
              0.2278308941861094, 0.35679509347557953`, 0.9362860044270709], 
             27 -> RGBColor[
              0.5121189165844965, 0.6148002330343991, 0.9547350235483862], 
             485 -> RGBColor[
              0.24800119075484597`, 0.3779953540399882, 0.9374346729773807], 
             454 -> RGBColor[
              0.8998824261938122, 0.6382713050470934, 0.23817178112086787`], 
             367 -> RGBColor[
              0.2298450608433424, 0.3589121103378734, 0.9364007082385077], 19 -> 
             RGBColor[
              0.5597245266210166, 0.6534486118703385, 0.9584827115555565], 
             164 -> RGBColor[
              0.8175247092939038, 0.13570817177533162`, 0.16441498745215766`],
              190 -> RGBColor[
              0.24810961844878143`, 0.3781093184210272, 0.9374408477741458], 
             103 -> RGBColor[
              0.4803557055985901, 0.589013427439692, 0.9522345072271], 138 -> 
             RGBColor[
              0.2199663924455993, 0.34852900350809307`, 0.9358381326874365], 
             416 -> RGBColor[
              0.26153368469451344`, 0.39221886318025073`, 0.938205328487714], 
             476 -> RGBColor[
              0.8484924274103163, 0.3737396233586853, 0.19406970929346942`], 
             291 -> RGBColor[
              0.6549271406176395, 0.7303533269719065, 0.9662406748008145], 28 -> 
             RGBColor[
              0.9648560740830788, 0.9733102981108331, 0.9443736789601879], 
             337 -> RGBColor[
              0.860210700141258, 0.8913726787679522, 0.9865288585702724], 195 -> 
             RGBColor[
              0.2701519252165497, 0.40127718039692006`, 0.9386961245358997], 
             114 -> RGBColor[
              0.5006784839436625, 0.605512374430953, 0.9538343907832142], 479 -> 
             RGBColor[
              0.41149067372934756`, 0.5308342722869064, 0.9474407997564864], 
             93 -> RGBColor[
              0.26928527939714464`, 0.4003662806922068, 0.9386467703385721], 
             34 -> RGBColor[
              0.5437530683305409, 0.6404822625241338, 0.9572253798535508], 
             161 -> RGBColor[
              0.9903319581123935, 0.9790495659282263, 0.41694191223350735`], 
             22 -> RGBColor[
              0.4514165271362265, 0.5654160397762044, 0.9499848398305268], 
             124 -> RGBColor[
              0.9626525497894284, 0.8856804222207267, 0.30941263771645156`], 
             84 -> RGBColor[
              0.2333142933423989, 0.36255849365642656`, 0.9365982758970595], 
             46 -> RGBColor[
              0.9176548470302313, 0.7112359389100995, 0.2526013609126037], 
             241 -> RGBColor[
              0.7054821402904016, 0.7698472769484965, 0.9712795247048629], 
             185 -> RGBColor[
              0.2839447494602888, 0.41577431319265656`, 0.9394816054719256], 
             426 -> RGBColor[
              0.8701743928884773, 0.8993174569073501, 0.9874792044791957], 
             390 -> RGBColor[
              0.30075346730669683`, 0.43344134138349677`, 0.9404388370870089],
              121 -> RGBColor[
              0.8274659414661699, 0.21212083852708477`, 0.1739347226073356], 
             322 -> RGBColor[
              0.25921854913182885`, 0.38978550891579644`, 0.9380734849423552],
              488 -> RGBColor[
              0.7693643004981994, 0.8197525060252281, 0.9776467014216474], 
             126 -> RGBColor[
              0.2511378152607278, 0.38129214526915, 0.9376132991027705], 433 -> 
             RGBColor[
              0.32550625142704326`, 0.4563588873913744, 0.9419619484004228], 
             236 -> RGBColor[
              0.28732315690654525`, 0.419325233622076, 0.939674000778084], 78 -> 
             RGBColor[
              0.21942909899518986`, 0.3479642740253404, 0.9358075346202901], 
             376 -> RGBColor[
              0.2794551004482275, 0.4110554074207916, 0.9392259266025292], 
             458 -> 
             RGBColor[
              0.2304992557221517, 0.359599710633853, 0.9364379636690613], 254 -> 
             RGBColor[
              0.23649824945009773`, 0.365905033400095, 0.9367795974871519], 
             290 -> RGBColor[
              0.2864852402250885, 0.41844453006287885`, 0.9396262826626617], 
             251 -> RGBColor[
              0.25854520282865096`, 0.38907777925853504`, 0.9380351388665158],
              165 -> RGBColor[
              0.4240332554553848, 0.5416980261695123, 0.9482400019731], 460 -> 
             RGBColor[
              0.24834625332605567`, 0.3783580366805602, 0.9374543237803367], 
             100 -> RGBColor[
              0.9312148525901699, 0.7649968423512695, 0.2635120596803694], 
             235 -> RGBColor[
              0.3570417238501652, 0.48367332858535217`, 0.9439713608175008], 
             70 -> RGBColor[
              0.2582501634540876, 0.38876767416929214`, 0.9380183368106061], 
             234 -> RGBColor[
              0.38857864336543946`, 0.5109890231778194, 0.9459808654420111], 
             435 -> RGBColor[
              0.25811768357221787`, 0.3886284294137375, 0.93801079227732], 
             257 -> RGBColor[
              0.8588534332133313, 0.4519682304874997, 0.20393618366530758`], 
             135 -> RGBColor[
              0.25062676841059334`, 0.3807550026274169, 0.9375841957406814], 
             265 -> RGBColor[
              0.32101450543653715`, 0.45246836277611585`, 0.9416757383178027],
              111 -> RGBColor[
              0.27309124258507717`, 0.4043665893147275, 0.9388635143117069], 
             497 -> RGBColor[
              0.23599364281048124`, 0.36537465982794926`, 0.9367508608855244],
              481 -> RGBColor[
              0.318216697210702, 0.4500450419128276, 0.9414974644516573], 381 -> 
             RGBColor[
              0.5693048020656428, 0.6612263110627765, 0.9592369059322629], 
             182 -> RGBColor[
              0.3785866605047563, 0.5023344698355566, 0.9453441851296919], 
             188 -> RGBColor[
              0.33727714516499796`, 0.4665542439248693, 0.9427119793408126], 
             154 -> RGBColor[
              0.30954120355039927`, 0.44253076534726327`, 0.9409446696670606],
              336 -> RGBColor[
              0.22223854670063217`, 0.35091718169303304`, 0.9359675285109096],
              463 -> RGBColor[
              0.2670973610782935, 0.3980666398170606, 0.9385221716270487], 
             315 -> RGBColor[
              0.1854996162687526, 0.3123022364263995, 0.933875300773191], 368 -> 
             RGBColor[
              0.4081016499818632, 0.5278988702541217, 0.9472248541600927], 
             269 -> RGBColor[
              0.44893934079834463`, 0.5632704254773366, 0.9498269957075668], 
             208 -> RGBColor[
              0.32211852500862637`, 0.45342460903982235`, 0.9417460854686901],
              86 -> RGBColor[
              0.9151930916309041, 0.7014758990831244, 0.2506205747334791], 
             119 -> RGBColor[
              0.9906473743776302, 0.9904004632007044, 0.8046607405893015], 
             436 -> RGBColor[
              0.472919813782261, 0.5829766354800872, 0.9516491265847494], 377 -> 
             RGBColor[
              0.9811051107342013, 0.9854288030398846, 0.9168682983373343], 
             140 -> RGBColor[
              0.4996340643500339, 0.6046644675542787, 0.9537521702469687], 85 -> 
             RGBColor[
              0.21421555473578224`, 0.34248450845090483`, 0.9355106309874645],
              351 -> RGBColor[
              0.290045450304657, 0.422186536586862, 0.9398290313598343], 443 -> 
             RGBColor[
              0.9345119801701037, 0.7780688545030732, 0.2661650059247154], 
             242 -> RGBColor[
              0.22500762673968802`, 0.3538276603838957, 0.936125223522647], 
             117 -> RGBColor[
              0.38107527345035186`, 0.504489981287708, 0.9455027573459912], 
             47 -> RGBColor[
              0.23193365260590854`, 0.36110735270469657`, 0.9365196504495912],
              451 -> RGBColor[
              0.21144581794704176`, 0.3395733394744833, 0.935352898574804], 
             81 -> RGBColor[
              0.8236181467643259, 0.8621947699835874, 0.9830386281626226], 
             275 -> RGBColor[
              0.4137039619056965, 0.5327513112621616, 0.9475818285219495], 23 -> 
             RGBColor[
              0.2225015077722568, 0.35119357045200544`, 0.9359825037549226], 
             328 -> RGBColor[
              0.3853130055350487, 0.5081604918248647, 0.9457727818871488], 
             418 -> RGBColor[
              0.978473490691829, 0.9834661451211657, 0.9213229446326382], 110 -> 
             RGBColor[
              0.27171530098953856`, 0.4029203874580805, 0.9387851564733641], 
             6 -> RGBColor[
              0.8276898195746623, 0.8654414113599355, 0.9834269879500976], 
             218 -> RGBColor[
              0.23197293745711564`, 0.3611486435741187, 0.9365218876637508], 
             108 -> RGBColor[
              0.28511069510105125`, 0.41699979598632125`, 0.939548004351305], 
             297 -> 
             RGBColor[
              0.5193642093092683, 0.6206822880650865, 0.955305399532062], 487 -> 
             RGBColor[
              0.5794313774456323, 0.6694475211532741, 0.9600341070410434], 
             464 -> RGBColor[
              0.24386676324271586`, 0.3736498085868948, 0.9371992234469022], 
             157 -> RGBColor[
              0.3025436094347634, 0.43532289426166115`, 0.9405407830329243], 
             441 -> RGBColor[
              0.4501324018566838, 0.5643037950010776, 0.9499030165032217], 
             354 -> RGBColor[
              0.3617638436367253, 0.48776339140382907`, 0.9442722501146938], 
             385 -> RGBColor[
              0.2334715870925415, 0.36272381936082626`, 0.9366072335434348], 
             270 -> RGBColor[
              0.9900230881246451, 0.9901423047916702, 0.8150067794022959], 
             392 -> RGBColor[
              0.3060013924465708, 0.4389572434431762, 0.9407376986601153], 33 -> 
             RGBColor[
              0.8784142522519405, 0.5407893411964669, 0.22025821055067316`], 
             252 -> RGBColor[
              0.7357960105795031, 0.7935287028122899, 0.9743009279960564], 
             394 -> RGBColor[
              0.22864247952174482`, 0.3576481211208147, 0.9363322230113024], 
             260 -> RGBColor[
              0.28557642935408295`, 0.4174893122155148, 0.9395745272280231], 
             159 -> RGBColor[
              0.8207501650068003, 0.16050043778835987`, 0.16750368748545852`],
              183 -> RGBColor[
              0.2049673414252272, 0.33276404989092045`, 0.9349839589209338], 
             99 -> RGBColor[
              0.9936215336094609, 0.9887654302895413, 0.5471214806005384], 
             329 -> RGBColor[
              0.8825578842047201, 0.909191716742005, 0.9886603529358121], 309 -> 
             RGBColor[
              0.9930307649637, 0.9875018358921313, 0.48281995931092997`], 17 -> 
             RGBColor[
              0.8799712561457314, 0.9071292097399156, 0.9884136380424356], 
             349 -> RGBColor[
              0.41360147005439724`, 0.5326625379719564, 0.9475752978318146], 
             495 -> RGBColor[
              0.8422024713778844, 0.3253922650171049, 0.18804644029332332`], 
             347 -> RGBColor[0.178927, 0.305394, 0.933501], 340 -> 
             RGBColor[
              0.3374345618861965, 0.46669059037677707`, 0.9427220097950892], 
             404 -> RGBColor[
              0.2134483076486736, 0.3416780831160786, 0.9354669374008939], 
             277 -> RGBColor[
              0.7713015318020453, 0.8212658858432957, 0.977839786533559], 104 -> 
             RGBColor[
              0.24657366739272524`, 0.3764949364761905, 0.9373533776337394], 
             79 -> RGBColor[
              0.9938287149952354, 0.9892085703244617, 0.5696718958667929], 
             327 -> RGBColor[
              0.2570691600545971, 0.38752636471648727`, 0.9379510804141431], 
             191 -> RGBColor[
              0.21840138119578575`, 0.34688407745709465`, 0.9357490076119863],
              50 -> RGBColor[
              0.44093802683048844`, 0.5563400894761129, 0.9493171590568191], 
             225 -> RGBColor[
              0.27424929290791517`, 0.4055837736286615, 0.9389294635644105], 
             405 -> RGBColor[
              0.9940126833910108, 0.9896020601209673, 0.5896957204256101], 61 -> 
             RGBColor[
              0.3238266917401457, 0.45490413720770817`, 0.94185492834235], 
             196 -> RGBColor[
              0.29569933477919436`, 0.42812912764658106`, 0.9401510117164867],
              1 -> RGBColor[
              0.2661654894960651, 0.39708718370006774`, 0.9384691029190212], 
             263 -> RGBColor[
              0.2734006518561467, 0.40469179807630246`, 0.9388811347119643], 
             201 -> RGBColor[
              0.3044587746178886, 0.4373358542976118, 0.9406498488568703], 
             371 -> RGBColor[
              0.36294391873403165`, 0.48878551314081686`, 0.9443474434563948],
              293 -> RGBColor[
              0.9542723127115095, 0.9654169462092355, 0.962289226275195], 362 -> 
             RGBColor[
              0.38846154058520777`, 0.5108875946353395, 0.9459734037564047], 
             184 -> RGBColor[
              0.2570318728012019, 0.3874871734490205, 0.9379489569602237], 
             106 -> RGBColor[
              0.5178553382148801, 0.619457318536794, 0.9551866156723348], 206 -> 
             RGBColor[
              0.3427341577200499, 0.4712808339226293, 0.9430596953553738], 
             358 -> RGBColor[
              0.22562621270692998`, 0.3544778334560826, 0.9361604510783655], 
             247 -> RGBColor[
              0.4950113815248125, 0.6009115653872759, 0.9533882557215221], 
             220 -> RGBColor[
              0.3389132056188999, 0.46797131725924984`, 0.9428162276662237], 
             407 -> RGBColor[
              0.21435834209939697`, 0.3426345870233057, 0.9355187625165873], 
             107 -> RGBColor[
              0.18467169248908813`, 0.3114320360405726, 0.9338281517387427], 
             375 -> 
             RGBColor[
              0.9582014383733062, 0.9683472816944506, 0.9556382414098691], 
             131 -> RGBColor[
              0.263609049878749, 0.394400203574635, 0.9383235174647285], 411 -> 
             RGBColor[
              0.23958996446517072`, 0.3691546219069906, 0.9369556660834778], 
             462 -> RGBColor[
              0.46387836533310084`, 0.575636380316448, 0.9509373506429145], 
             127 -> RGBColor[
              0.22597981130456574`, 0.35484948800164373`, 0.9361805879953986],
              210 -> RGBColor[
              0.8360637140310553, 0.2782070860287545, 0.182167959325265], 357 -> 
             RGBColor[
              0.9071422836282599, 0.6695571281253704, 0.2441427056377997], 
             181 -> RGBColor[
              0.4206971967779904, 0.5388084998183378, 0.9480274312641372], 
             194 -> RGBColor[
              0.9865160895376739, 0.9886920707502049, 0.8731268218098209], 
             440 -> RGBColor[
              0.28167383897512416`, 0.41338744228870766`, 0.9393522804793065],
              490 -> RGBColor[
              0.9905535588776926, 0.9903616680805318, 0.806215506209998], 118 -> 
             RGBColor[
              0.32510810483221725`, 0.45601403282236586`, 0.9419365788514676],
              348 -> RGBColor[
              0.9599116097125079, 0.876434587737939, 0.29876460310071706`], 
             276 -> RGBColor[
              0.6195401563438858, 0.7020096347427746, 0.9631916170392121], 
             305 -> RGBColor[
              0.2511118726659751, 0.3812648779572094, 0.9376118217103779], 
             343 -> RGBColor[
              0.29288750827080284`, 0.425173719706164, 0.9399908823565584], 
             280 -> RGBColor[
              0.25689237745970156`, 0.38734055500058817`, 0.9379410129068901],
              474 -> RGBColor[
              0.9930971542734537, 0.9914135101440991, 0.7640615478883636], 
             189 -> RGBColor[
              0.2597753641562747, 0.39037075681060074`, 0.9381051947342635], 
             168 -> RGBColor[
              0.9107922199972238, 0.6840279095591187, 0.24707953011528597`], 
             363 -> RGBColor[
              0.40481135748628755`, 0.5250489842693634, 0.9470151996317661], 
             41 -> RGBColor[
              0.23252667542550592`, 0.36173065728791187`, 0.9365534222218687],
              14 -> RGBColor[
              0.30674268007373295`, 0.4397363837396738, 0.9407799138938453], 
             77 -> RGBColor[
              0.606817875551374, 0.6916811140631951, 0.9621900724919755], 51 -> 
             RGBColor[
              0.17892700081062782`, 0.30539400085202123`, 0.9335010000461641],
              438 -> RGBColor[
              0.22146455698209894`, 0.3501036694250721, 0.9359234509414543], 
             179 -> RGBColor[
              0.178929137062006, 0.30539624618766587`, 0.9335011217025198], 
             467 -> RGBColor[
              0.7068391686146014, 0.7709073977891587, 0.9714147806060683], 
             223 -> RGBColor[
              0.38986378476733635`, 0.5121021480670574, 0.9460627535157341], 
             456 -> RGBColor[
              0.22365852866224617`, 0.35240967276674573`, 0.9360483943829485],
              323 -> RGBColor[
              0.23934466612723454`, 0.36889679780100676`, 0.9369416967060188],
              500 -> RGBColor[
              0.8194926622925333, 0.15083472088530037`, 0.16629950146613023`],
              478 -> RGBColor[
              0.2660419428822219, 0.39695732837561076`, 0.9384620671221336], 
             292 -> RGBColor[
              0.1789706321783367, 0.30543986018587177`, 0.9335034847880083], 
             491 -> RGBColor[
              0.9941614319695004, 0.9899202182895682, 0.6058860852243823], 
             396 -> RGBColor[
              0.9935460613341791, 0.9886040027241311, 0.5389067891970045], 
             321 -> RGBColor[
              0.3331754530775283, 0.46300156439574175`, 0.942450623147983], 
             143 -> RGBColor[
              0.17892700134778292`, 0.3053940014166053, 0.9335010000767543], 
             112 -> RGBColor[
              0.24826352560257345`, 0.3782710845979398, 0.937449612558869], 
             197 -> RGBColor[
              0.6976256228082208, 0.7637097057796726, 0.9704964604655693], 
             421 -> RGBColor[
              0.17905660578117066`, 0.3055302238934915, 0.9335083808575031], 
             54 -> RGBColor[
              0.22872079714307936`, 0.35773043790646125`, 0.9363366830839769],
              71 -> RGBColor[
              0.755781538403036, 0.8091415490436711, 0.97629289863413], 177 -> 
             RGBColor[
              0.20869655844004803`, 0.3366836934195124, 0.9351963323130457], 
             158 -> RGBColor[
              0.3575213303529286, 0.48408873963232213`, 0.9440019209197574], 
             226 -> RGBColor[
              0.1794249922972142, 0.30591742147890744`, 0.9335293599246128], 
             432 -> RGBColor[
              0.898624468927386, 0.9220027752840345, 0.9901927981294695], 350 -> 
             RGBColor[
              0.3621699928109498, 0.4881151774048913, 0.9442981295809318], 
             203 -> 
             RGBColor[
              0.5345666356633387, 0.6330243026408235, 0.956502190222977], 475 -> 
             RGBColor[
              0.839003391040872, 0.30080273170088523`, 0.1849829973497558], 
             115 -> RGBColor[
              0.9211683800910966, 0.9399786781078106, 0.9923430565014513], 
             173 -> RGBColor[
              0.984562956112485, 0.9878843998856498, 0.9054952972124768], 212 -> 
             RGBColor[
              0.21851625165510197`, 0.3470048135930438, 0.9357555493147087], 
             129 -> RGBColor[
              0.35559977387920144`, 0.4824243839950162, 0.9438794810404173], 
             279 -> RGBColor[
              0.2785602236563872, 0.4101148351741018, 0.9391749646930856], 26 -> 
             RGBColor[
              0.3866295369467384, 0.5093008051628776, 0.9458566701045386], 40 -> 
             RGBColor[
              0.3862001571816754, 0.5089288979916344, 0.9458293104055944], 
             146 -> RGBColor[
              0.257933230334439, 0.3884345573658211, 0.9380002879383026], 386 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 192 -> 
             RGBColor[
              0.2546146394674752, 0.38494650795382845`, 0.9378112990978443], 
             300 -> RGBColor[
              0.22595764709528393`, 0.3548261920123965, 0.936179325776469], 
             221 -> RGBColor[
              0.5366100807415061, 0.6346832634114314, 0.9566630577049163], 62 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 286 -> 
             RGBColor[
              0.22310026486080187`, 0.3518229021154584, 0.9360166020853335], 
             472 -> RGBColor[
              0.32844671668737896`, 0.45890577060779597`, 0.9421493122466601],
              152 -> RGBColor[
              0.20400293554931437`, 0.33175039816847185`, 0.9349290374330113],
              64 -> RGBColor[
              0.2878344487965492, 0.41986263381624833`, 0.9397031180948312], 
             307 -> RGBColor[
              0.46980956787155936`, 0.580451597734798, 0.9514042766334527], 
             37 -> RGBColor[
              0.305640198745031, 0.4385776059618545, 0.9407171292131508], 148 -> 
             RGBColor[
              0.23965584235908116`, 0.3692238637503902, 0.9369594177320785], 
             261 -> RGBColor[
              0.8799868165294279, 0.5479299882988189, 0.2215703967308864], 
             387 -> RGBColor[
              0.7751138064478154, 0.8242440637709316, 0.9782197584425172], 15 -> 
             RGBColor[
              0.23423879357827926`, 0.36353020202103736`, 0.9366509248178173],
              136 -> 
             RGBColor[
              0.968960662006962, 0.9763714930638193, 0.9374256822530368], 198 -> 
             RGBColor[
              0.2818794421164257, 0.41360354422620765`, 0.9393639892740411], 
             63 -> RGBColor[
              0.41933559472005666`, 0.5376291485518648, 0.9479406711850231], 
             444 -> RGBColor[
              0.27129304719779485`, 0.4024765719505212, 0.9387611097445928], 
             310 -> RGBColor[
              0.29675707084929953`, 0.4292408753206019, 0.9402112482208989], 
             171 -> RGBColor[
              0.26174222518751433`, 0.39243805246062563`, 0.9382172045602823],
              395 -> RGBColor[
              0.26498757281889074`, 0.39584911858812655`, 0.9384020223068277],
              311 -> RGBColor[
              0.746856868272219, 0.8021695289074716, 0.9754033709212744], 353 -> 
             RGBColor[
              0.6396625402707171, 0.7183458925176417, 0.9647757248126534], 59 -> 
             RGBColor[
              0.2421911048281961, 0.37188858535035474`, 0.9371037971791099], 
             397 -> RGBColor[
              0.3585480532796543, 0.48497803542685713`, 0.944067342796753], 
             229 -> RGBColor[
              0.2909757990296596, 0.42316439208435586`, 0.9398820133433956], 
             102 -> RGBColor[
              0.2765375568294345, 0.40798888409449063`, 0.939059776809558], 
             453 -> RGBColor[
              0.2843068325272902, 0.41615488545346746`, 0.9395022255669375], 
             299 -> RGBColor[
              0.2091663766185125, 0.3371775021132715, 0.9352230877632756], 
             128 -> RGBColor[
              0.49474321248409076`, 0.6006938536791404, 0.9533671444723009], 
             12 -> RGBColor[
              0.27240341106773047`, 0.40364363477895904`, 0.9388243433243495],
              222 -> RGBColor[
              0.4427137030371586, 0.5578780909582495, 0.9494303035745394], 
             483 -> RGBColor[
              0.29664917161590876`, 0.42912746638510174`, 0.9402051035191799],
              92 -> RGBColor[
              0.6091375885965603, 0.6935643616151592, 0.9623726888002815], 
             271 -> RGBColor[
              0.2558053195227897, 0.38619798818543977`, 0.9378791065655412], 
             361 -> RGBColor[
              0.6442014475594858, 0.7219743340365904, 0.9651716379540781], 
             344 -> RGBColor[
              0.4637429804071734, 0.5755264687345587, 0.9509266926456142], 
             132 -> RGBColor[
              0.9901329118562932, 0.9901877197270478, 0.8131867159541827], 80 -> 
             RGBColor[
              0.7895429134572223, 0.8355161918319554, 0.9796579169815435], 
             324 -> RGBColor[
              0.369677449943029, 0.49461775943693126`, 0.9447764981108042], 
             244 -> RGBColor[
              0.3424410288691568, 0.4710269404450701, 0.9430410174441985], 
             150 -> RGBColor[
              0.8214446559981496, 0.16583859987576455`, 0.16816873284309014`],
              125 -> RGBColor[
              0.20867358600249122`, 0.3366595479311035, 0.9351950240667115], 
             258 -> RGBColor[
              0.3734224424883788, 0.497861483750915, 0.945015125724227], 133 -> 
             RGBColor[
              0.3451736656290086, 0.4733938130601367, 0.9432151386421606], 
             469 -> RGBColor[
              0.8604306779796645, 0.4591301305965446, 0.20525227536014304`], 
             255 -> RGBColor[
              0.3975855258515599, 0.5187903320882202, 0.9465547760295533], 
             408 -> RGBColor[
              0.2225045334786326, 0.3511967506612473, 0.9359826760644245], 
             326 -> RGBColor[
              0.8751755113140446, 0.526082975024646, 0.21755572572328788`], 
             176 -> RGBColor[
              0.6069446059586334, 0.6917839995169481, 0.9622000491738637], 
             230 -> RGBColor[
              0.2238780227461086, 0.35264037496561385`, 0.936060894246312], 
             274 -> RGBColor[
              0.4627342609626232, 0.5747075448471798, 0.9508472825558781], 87 -> 
             RGBColor[
              0.1792532619022457, 0.3057369219454596, 0.9335195801326717], 
             439 -> RGBColor[
              0.8609124841587944, 0.891932262294116, 0.986595795356355], 130 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 35 -> 
             RGBColor[
              0.23837242809378653`, 0.36787491398440125`, 0.9368863291883112],
              379 -> RGBColor[
              0.3092991992760449, 0.442321153408306, 0.9409292493686947], 31 -> 
             RGBColor[
              0.4530382628066378, 0.5668207057031098, 0.9500881753934008], 18 -> 
             RGBColor[
              0.8843839202879132, 0.5678962094964264, 0.22523944788984251`], 
             24 -> RGBColor[
              0.8369720141620951, 0.8728427813654944, 0.9843123319561599], 
             151 -> RGBColor[
              0.30679432383558886`, 0.439790664607788, 0.9407828549296829], 
             137 -> RGBColor[
              0.22008054170119, 0.3486489816131997, 0.9358446333186737], 330 -> 
             RGBColor[
              0.3064495532407965, 0.43942828885294294`, 0.9407632207543519], 
             296 -> 
             RGBColor[
              0.3134198204339392, 0.44589022834683273`, 0.9411918117051534], 
             266 -> RGBColor[
              0.28952074326414307`, 0.421635036218934, 0.9397991500701115], 
             302 -> RGBColor[
              0.19014935834156865`, 0.31718941015560403`, 0.934140096705561], 
             442 -> RGBColor[
              0.28394532564135605`, 0.4157749187954902, 0.9394816382845851], 
             283 -> RGBColor[
              0.18121415923057888`, 0.3077979493656092, 0.9336312503346327], 
             388 -> RGBColor[
              0.9461721011462925, 0.9593758216867757, 0.9760007715815773], 
             284 -> RGBColor[
              0.24509263407936946`, 0.37493827656091794`, 0.9372690349775362],
              417 -> RGBColor[
              0.7010326627105, 0.7663713112457954, 0.9708360423624304], 318 -> 
             RGBColor[
              0.341942322952124, 0.4705949864454246, 0.9430092403441536], 413 -> 
             RGBColor[
              0.97383602535665, 0.9234049113139019, 0.35285832847295656`], 
             238 -> RGBColor[
              0.32015392046586916`, 0.45172296732878153`, 0.9416209026044572],
              72 -> RGBColor[
              0.2539844574642687, 0.3842841467126117, 0.9377754111650324], 
             437 -> RGBColor[
              0.2558304623203871, 0.3862244148598601, 0.9378805384106689], 
             288 -> RGBColor[
              0.2560659100008252, 0.3864718853002457, 0.9378939468077562], 
             382 -> RGBColor[
              0.28222469603460637`, 0.4139664279845783, 0.9393836509739241], 
             461 -> RGBColor[
              0.944455505750549, 0.9580955876512972, 0.9789065198267879], 389 -> 
             RGBColor[
              0.2184997826909155, 0.34698750366749115`, 0.9357546114315619], 
             172 -> RGBColor[
              0.3516524550010693, 0.4790054147807936, 0.9436279613719797], 
             447 -> RGBColor[
              0.2464999471451923, 0.3764174518218997, 0.9373491793747017], 
             243 -> RGBColor[
              0.8393061093521738, 0.30312955729356095`, 0.18527288074652987`],
              410 -> RGBColor[
              0.36366501242205085`, 0.4894100882501565, 0.9443933909085572], 
             88 -> RGBColor[
              0.8666101266120032, 0.4871895635890985, 0.21040855877111306`], 
             273 -> RGBColor[
              0.2935414156904733, 0.42586101786436276`, 0.9400281214167392], 
             477 -> RGBColor[
              0.24467162743864543`, 0.3744957718881542, 0.9372450592721705], 
             202 -> 
             RGBColor[
              0.23905706042934927`, 0.3685945059772749, 0.9369253179869986], 
             393 -> RGBColor[
              0.4612114846587171, 0.5734712864433781, 0.9507274040271213], 98 -> 
             RGBColor[
              0.9952347378240085, 0.9922159109844932, 0.7227088038116687], 30 -> 
             RGBColor[
              0.2679312243382506, 0.39894308297325987`, 0.938569658906113], 
             116 -> RGBColor[
              0.24872594858728536`, 0.3787571204741826, 0.9374759468637549], 
             373 -> RGBColor[
              0.293615491872952, 0.425938876628849, 0.9400323399457455], 434 -> 
             RGBColor[
              0.9912025783926344, 0.990630054329001, 0.7954595732387495], 401 -> 
             RGBColor[
              0.7734523776791622, 0.8229461429895335, 0.9780541627497925], 
             240 -> RGBColor[
              0.2566255537350775, 0.38706010634840704`, 0.9379258176905032], 
             480 -> RGBColor[
              0.35354723518652786`, 0.48064657814301665`, 0.9437486950899088],
              403 -> RGBColor[
              0.9289119756027943, 0.9461532109745376, 0.9930816475541463], 
             317 -> RGBColor[
              0.8834003236622562, 0.5634299269441462, 0.22441871075523476`], 
             429 -> RGBColor[
              0.29359796730781346`, 0.4259204571997668, 0.9400313419476861], 
             391 -> RGBColor[
              0.2411272273904176, 0.370770382709524, 0.937043210932894], 73 -> 
             RGBColor[
              0.24791046842011605`, 0.37789999911405875`, 0.9374295064746294],
              303 -> RGBColor[
              0.3052585207535403, 0.43817643819301544`, 0.9406953932161773], 
             449 -> RGBColor[
              0.7283027762348872, 0.7876749311915857, 0.9735540724248413], 29 -> 
             RGBColor[
              0.40962031041891445`, 0.5292142575946026, 0.9473216218602429], 
             360 -> RGBColor[
              0.5793663225363243, 0.6693947066472076, 0.9600289856802787], 
             320 -> RGBColor[
              0.9886024976405045, 0.9895548541189678, 0.8385496400948322], 
             482 -> RGBColor[
              0.35848143845973107`, 0.48492033701799786`, 0.9440630981593326],
              75 -> RGBColor[
              0.3449485107481652, 0.47319879521896346`, 0.9432007919722498], 
             200 -> RGBColor[
              0.9008280073528754, 0.6425649682443086, 0.23896079721830538`], 
             301 -> RGBColor[
              0.20875268020104726`, 0.3367426809486477, 0.9351995283643099], 
             156 -> 
             RGBColor[
              0.46730916543215706`, 0.578421658392645, 0.9512074357941471], 
             25 -> RGBColor[
              0.3133752819583538, 0.4458516513578495, 0.941188973752873], 38 -> 
             RGBColor[
              0.25996867538836677`, 0.3905739391721695, 0.9381162035229527], 
             365 -> RGBColor[
              0.2169746648251472, 0.34538450809251103`, 0.9356677582253161], 
             380 -> RGBColor[
              0.27285106149406285`, 0.4041141437597107, 0.9388498363538897], 
             370 -> RGBColor[
              0.591443337591513, 0.6791993715323379, 0.960979732544987], 3 -> 
             RGBColor[
              0.46166603367100856`, 0.5738403098087559, 0.9507631877904368], 
             57 -> RGBColor[
              0.6012429877716181, 0.6871551690177569, 0.9617511969044663], 
             227 -> RGBColor[
              0.8456311671254343, 0.35174672299683013`, 0.19132976321333509`],
              494 -> RGBColor[
              0.2585035332044634, 0.3890339818415072, 0.938032765843063], 39 -> 
             RGBColor[
              0.6236615875481659, 0.7053555982627691, 0.963516071200913], 424 -> 
             RGBColor[
              0.3205944320155112, 0.4521045162923272, 0.9416489716108714], 
             109 -> RGBColor[
              0.25396000439311356`, 0.38425844498441336`, 0.9377740185988052],
              465 -> RGBColor[
              0.28262558218412137`, 0.4143877847453685, 0.939406480847081], 
             256 -> RGBColor[
              0.2893861381019995, 0.4214935576590608, 0.939791484505258], 457 -> 
             RGBColor[
              0.22158907133489145`, 0.35023454190452297`, 0.9359305418496434],
              339 -> RGBColor[
              0.21169068579341777`, 0.33983071110654267`, 0.9353668434364056],
              420 -> RGBColor[
              0.96864282965107, 0.9761344542131977, 0.9379636895276074], 287 -> 
             RGBColor[
              0.20981171601903448`, 0.33785579474010136`, 0.9352598388874411],
              239 -> RGBColor[
              0.3509305166159243, 0.47838010803725933`, 0.9435819600964633], 
             427 -> RGBColor[
              0.2795001276110678, 0.4111027338238238, 0.9392284908328413], 
             285 -> RGBColor[
              0.3144183414809424, 0.4467550970906198, 0.941255436583311], 345 -> 
             RGBColor[
              0.6597251945044771, 0.7341016031348642, 0.9667188999718916], 
             366 -> RGBColor[
              0.2650062967491503, 0.3958687986259951, 0.9384030886069564], 
             216 -> 
             RGBColor[
              0.26588598144981995`, 0.39679340302163035`, 0.9384531853492826],
              21 -> RGBColor[
              0.9808877657874093, 0.9471920876142448, 0.3802530084370154], 
             355 -> RGBColor[
              0.32870680276015046`, 0.45913104409172456`, 0.942165884701232], 
             175 -> RGBColor[
              0.9557302644442173, 0.966504284224312, 0.9598212942864327], 7 -> 
             RGBColor[
              0.8386821070512293, 0.8742063630160551, 0.9844754421425435], 13 -> 
             RGBColor[
              0.29661626096016863`, 0.4290928751992627, 0.9402032293060224], 
             294 -> RGBColor[
              0.23831274258564697`, 0.36781218073106675`, 0.9368829301869194],
              412 -> RGBColor[
              0.2423814866745967, 0.372088688741828, 0.9371146391436176], 193 -> 
             RGBColor[
              0.2878117179623051, 0.41983874226823964`, 0.9397018236074483], 
             60 -> RGBColor[
              0.29270959820985176`, 0.42498672495195505`, 0.9399807506417815],
              65 -> RGBColor[
              0.9854648277298144, 0.9626315922912277, 0.39803402977763763`], 
             448 -> RGBColor[
              0.5679393142918087, 0.6601177465734548, 0.9591294097327601], 69 -> 
             RGBColor[
              0.9094625081980608, 0.9306447336077317, 0.9912265399903383], 
             217 -> RGBColor[
              0.31971976000988434`, 0.4513469193633465, 0.9415932382841149], 
             214 -> RGBColor[
              0.19980711485308938`, 0.32734032458634205`, 0.9346900916515217],
              170 -> RGBColor[
              0.29668056881803306`, 0.42916046683523196`, 0.9402068915433929],
              359 -> RGBColor[
              0.38545126270191343`, 0.5082802432337956, 0.9457815915115654], 
             74 -> RGBColor[
              0.2817340129849886, 0.4134506889883278, 0.9393557073001488], 
             246 -> RGBColor[
              0.29422140859812795`, 0.42657573352434824`, 0.9400668460068708],
              264 -> RGBColor[
              0.23478619087952063`, 0.36410555129163547`, 0.9366820982843213],
              278 -> RGBColor[
              0.9483637407407871, 0.9610103429078694, 0.9722908974192511], 45 -> 
             RGBColor[
              0.28278247170568477`, 0.41455268557990177`, 0.9394154154732368],
              492 -> RGBColor[
              0.2766193131480329, 0.4080748151689876, 0.9390644327109545], 
             306 -> RGBColor[
              0.8575795140998795, 0.443586953641446, 0.20277151376979163`], 
             237 -> 
             RGBColor[
              0.906092392768253, 0.9279574950433493, 0.9909050953721057], 228 -> 
             RGBColor[
              0.9930813033990235, 0.9876099324950685, 0.48832075610881853`], 
             180 -> RGBColor[
              0.27013094278236094`, 0.4012551265282246, 0.9386949296173133], 
             383 -> RGBColor[
              0.32894252042405586`, 0.45933521088468515`, 0.942180904422339], 
             53 -> RGBColor[
              0.9765123065091236, 0.9324326360618924, 0.36325517537702773`], 
             304 -> RGBColor[
              0.3385640468354945, 0.4676688934702948, 0.9427939795772942], 48 -> 
             RGBColor[
              0.20751087662989864`, 0.3354374666604766, 0.9351288094880167], 
             5 -> RGBColor[
              0.23860734128045696`, 0.3681218226379481, 0.9368997071467691], 
             101 -> RGBColor[
              0.5208327276256995, 0.6218744973903617, 0.9554210066732913], 
             333 -> RGBColor[
              0.3786491349611119, 0.5023885820695944, 0.9453481659468069], 
             267 -> RGBColor[
              0.9890626064851881, 0.9747677448317271, 0.41201072085875556`], 
             120 -> RGBColor[
              0.20742150462258202`, 0.3353435310142743, 0.9351237198844141], 
             147 -> RGBColor[
              0.25149316947897704`, 0.3816656450832887, 0.9376335359998004], 
             89 -> RGBColor[
              0.28550171685781406`, 0.4174107846448903, 0.9395702724618878], 
             43 -> RGBColor[
              0.2931478124699098, 0.42544731592366486`, 0.940005706295612], 
             199 -> RGBColor[
              0.3428438781472085, 0.4713758682419251, 0.9430666866439704], 
             268 -> RGBColor[
              0.40965477924277666`, 0.5292441127573786, 0.9473238181832199], 
             169 -> RGBColor[
              0.4927421843014464, 0.5990693288551774, 0.9532096162037554], 20 -> 
             RGBColor[
              0.8845340276069948, 0.5685778117739207, 0.22536470111635126`], 
             4 -> RGBColor[
              0.32430364693803726`, 0.45531725182765653`, 0.9418853195058047],
              167 -> RGBColor[
              0.9866702547547157, 0.9887558220293171, 0.870571905196646], 431 -> 
             RGBColor[
              0.4485399301016759, 0.5629244760068475, 0.9498015456111601], 
             142 -> RGBColor[
              0.6995243049605603, 0.765192970707599, 0.9706857033583209], 16 -> 
             RGBColor[
              0.4038820814050813, 0.5242440920345965, 0.9469559869815982], 
             414 -> 
             RGBColor[
              0.2746579678933065, 0.4060133169497984, 0.9389527370002482], 
             281 -> RGBColor[
              0.24490866169442368`, 0.374744909919817, 0.9372585580223763], 
             289 -> RGBColor[
              0.439371052281192, 0.5549828548799431, 0.9492173128241592], 398 -> 
             RGBColor[
              0.26115105564507934`, 0.3918166957892125, 0.9381835383293976], 
             178 -> RGBColor[
              0.9916846362160958, 0.9908293976273234, 0.7874706275783359], 58 -> 
             RGBColor[
              0.31511174381280593`, 0.44735568733906544`, 0.9412996195667458],
              186 -> RGBColor[
              0.23571041014604155`, 0.365076964339635, 0.9367347312042897], 
             122 -> RGBColor[
              0.867504304657107, 0.49124981725132677`, 0.21115468285025726`], 
             249 -> RGBColor[
              0.2895478687563091, 0.421663546831056, 0.9398006948267619], 113 -> 
             RGBColor[
              0.17919226069553715`, 0.305672805809509, 0.9335161062041928], 
             52 -> RGBColor[
              0.8357950446989824, 0.2761419758107905, 0.18191068126945342`], 
             409 -> RGBColor[
              0.24155566178660715`, 0.3712206944242289, 0.937067609637945], 
             187 -> RGBColor[
              0.26462809617956273`, 0.3954712858480575, 0.938381550644016], 
             259 -> RGBColor[
              0.8618406991999262, 0.46553270763892984`, 0.20642883162911219`],
              42 -> RGBColor[
              0.23247426890382172`, 0.3616755747108564, 0.9365504377479873], 
             134 -> RGBColor[
              0.2332063867745317, 0.36244507701192663`, 0.9365921307776528], 
             470 -> RGBColor[
              0.25548210733168075`, 0.3858582716797478, 0.937860700109407], 
             313 -> RGBColor[
              0.266957894870447, 0.3979200519899457, 0.9385142292328336], 248 -> 
             RGBColor[
              0.24253965650195108`, 0.3722549352589237, 0.9371236466812941], 
             174 -> RGBColor[
              0.2666571079259713, 0.3976039058403079, 0.93849709986132], 215 -> 
             RGBColor[
              0.28412310253725925`, 0.4159617735847908, 0.9394917624158093], 
             399 -> RGBColor[
              0.24150095424043594`, 0.3711631933245442, 0.9370644941241232], 
             422 -> RGBColor[
              0.23401200432651914`, 0.3632918321381684, 0.9366380095054342], 
             83 -> RGBColor[
              0.9207457022290968, 0.9396416462539369, 0.9923027411096448], 95 -> 
             RGBColor[
              0.22708291988077767`, 0.3560089250563658, 0.936243408396911], 
             166 -> RGBColor[
              0.8381204118994321, 0.2940157670958513, 0.18413745552673064`], 
             384 -> RGBColor[
              0.28382079992875175`, 0.41564403437615693`, 0.9394745467294715],
              233 -> RGBColor[
              0.8431597968980244, 0.3327506884676198, 0.18896317629255405`], 
             295 -> RGBColor[
              0.22958788287780074`, 0.3586417999900643, 0.9363860623338308], 
             499 -> RGBColor[
              0.2607186377132893, 0.3913621971260208, 0.9381589127678872], 
             141 -> RGBColor[
              0.30958288032569087`, 0.4425668636752852, 0.9409473252743288], 
             319 -> RGBColor[
              0.7148896845747944, 0.7771965220434489, 0.9722171808006315], 
             205 -> RGBColor[
              0.9938265629209484, 0.98920396725517, 0.5694376558617151], 468 -> 
             RGBColor[
              0.4783770236668791, 0.5874070443089239, 0.952078738137285], 486 -> 
             RGBColor[
              0.9349275982881982, 0.9509499052141509, 0.9936554230160899], 
             224 -> RGBColor[
              0.29896629209325354`, 0.43156290692071464`, 0.9403370601024921],
              231 -> RGBColor[
              0.2584463601503126, 0.3889738893366137, 0.9380295099222091], 
             332 -> RGBColor[
              0.40219205331719154`, 0.5227802746481479, 0.946848299886271], 
             68 -> RGBColor[
              0.8199864588949732, 0.15463025795470559`, 0.16677236165029033`],
              484 -> RGBColor[
              0.9928916986278599, 0.9872043870615327, 0.4676834468726777], 10 -> 
             RGBColor[
              0.2189624152550279, 0.3474737598249721, 0.9357809576716846], 
             250 -> RGBColor[
              0.20444533477183996`, 0.332215387801077, 0.934954231414263], 
             282 -> RGBColor[
              0.6076583896248129, 0.6923634812527404, 0.9622562408387412], 
             374 -> RGBColor[
              0.2517303220687306, 0.38191490749146234`, 0.937647041488951], 
             232 -> RGBColor[
              0.3561976264336458, 0.4829422138287328, 0.9439175756765262], 
             489 -> RGBColor[
              0.9900975943251971, 0.9901731150203205, 0.8137720188432849], 
             253 -> RGBColor[
              0.9850318468002165, 0.9880782982349678, 0.8977245650665646], 
             459 -> RGBColor[
              0.3905461178527888, 0.5126931506906183, 0.9461062311765757], 
             415 -> 
             RGBColor[
              0.2870126862041934, 0.4189989092289247, 0.9396563199308854], 55 -> 
             RGBColor[
              0.21147766438726034`, 0.339606812102334, 0.9353547121824619], 
             446 -> RGBColor[
              0.22815127331601265`, 0.3571318322543179, 0.9363042495445604], 
             325 -> RGBColor[
              0.1790169203691504, 0.30548851200925775`, 0.9335061208319979], 
             91 -> RGBColor[
              0.3276288460270304, 0.4581973721491767, 0.9420971982513973], 
             450 -> RGBColor[
              0.8177084834502429, 0.13712074047130335`, 0.1645909697918113], 
             423 -> RGBColor[
              0.18782589147201245`, 0.31474729915939237`, 0.9340077787046009],
              105 -> RGBColor[
              0.2459052705491277, 0.3757924090147619, 0.9373153134223011], 36 -> 
             RGBColor[
              0.254389289460926, 0.3847096508089296, 0.9377984657483468], 123 -> 
             RGBColor[
              0.2069635167020156, 0.33486215667164765`, 0.9350976381498702], 
             94 -> RGBColor[
              0.9554190789968999, 0.9662722026272221, 0.9603480500785777], 
             473 -> RGBColor[
              0.32683125980079797`, 0.4575065430478635, 0.9420463767623395], 
             312 -> RGBColor[
              0.3044115375980597, 0.43728620519477157`, 0.940647158778472], 
             96 -> RGBColor[
              0.2961617343973124, 0.4286151389630523, 0.9401773446906796], 
             496 -> RGBColor[
              0.27688954314442643`, 0.4083588440287685, 0.9390798219094797], 
             2 -> RGBColor[
              0.2124476857409665, 0.34062636604798524`, 0.9354099534635375], 
             262 -> RGBColor[
              0.47608581392629684`, 0.5855469370236965, 0.9518983657135286], 
             272 -> RGBColor[
              0.8205829319400263, 0.15921501115513814`, 0.16734354491185305`],
              97 -> RGBColor[
              0.2317345075524728, 0.36089803862701, 0.9365083094334068], 372 -> 
             RGBColor[
              0.4704530721178047, 0.5809740234714359, 0.951454935644951], 356 -> 
             RGBColor[
              0.26933793088281155`, 0.4004216207419397, 0.9386497687627899], 
             402 -> RGBColor[
              0.5523112332770156, 0.6474301663686192, 0.9578991099477285], 
             455 -> RGBColor[
              0.20394063923757638`, 0.33168492079502093`, 0.9349254897502168],
              428 -> RGBColor[
              0.8303334960184631, 0.23416211938642656`, 0.1766806960850511], 
             346 -> 
             RGBColor[
              0.21788265672664042`, 0.34633886515099205`, 0.9357194670208525],
              341 -> RGBColor[
              0.9935733711383794, 0.9886624156338708, 0.5418792928476311], 
             209 -> RGBColor[
              0.5659235722129052, 0.6584812763456551, 0.9589707231324023], 
             498 -> RGBColor[
              0.46188951150763047`, 0.5740217391840874, 0.9507807807843619], 
             378 -> RGBColor[
              0.2830844261537786, 0.4148700588498662, 0.9394326113323542], 
             419 -> RGBColor[
              0.5126905354832046, 0.6152642990075083, 0.9547800234820015], 66 -> 
             RGBColor[
              0.2632810725593861, 0.3940554786170215, 0.9383048396415897], 
             139 -> RGBColor[
              0.5640351798749514, 0.6569481943745988, 0.9588220619701494], 56 -> 
             RGBColor[
              0.8366736085240676, 0.28289500235951803`, 0.1827519949805509], 
             335 -> RGBColor[
              0.2767721721232211, 0.4082354796437291, 0.9390731378034569], 
             314 -> RGBColor[
              0.33007547283951477`, 0.4603165173231115, 0.9422530951484216], 
             144 -> RGBColor[
              0.24622776306205768`, 0.3761313690930576, 0.9373336788938276], 
             298 -> RGBColor[
              0.9016398137954514, 0.9244071294324739, 0.9904804044148157], 
             204 -> RGBColor[
              0.5018930513522051, 0.606498414968846, 0.9539300059787216], 452 -> 
             RGBColor[
              0.22395342458252596`, 0.35271962707644106`, 0.936065188269349], 
             466 -> RGBColor[
              0.503508173143364, 0.6078096435993164, 0.9540571542825077], 207 -> 
             RGBColor[
              0.217062994597398, 0.3454773482835776, 0.9356727884751737], 334 -> 
             RGBColor[
              0.4028040785660817, 0.5233103801574531, 0.9468872975939376], 
             149 -> RGBColor[
              0.353874772698637, 0.4809302746734916, 0.9437695654905504], 219 -> 
             RGBColor[
              0.5262688994117111, 0.6262878265429939, 0.9558489620296395], 
             400 -> RGBColor[
              0.295921828646773, 0.42836298280833224`, 0.9401636824130951], 9 -> 
             RGBColor[
              0.5751436787516512, 0.6659665741948753, 0.9596965636934954], 11 -> 
             RGBColor[
              0.23891813183632316`, 0.3684484832174229, 0.9369174062091523], 
             44 -> RGBColor[
              0.49667724948997916`, 0.6022639920478948, 0.9535193989500155], 
             153 -> 
             RGBColor[
              0.24493296406314102`, 0.3747704532501981, 0.9372599420063227], 
             471 -> RGBColor[
              0.8568125830318801, 0.4376919853814662, 0.20203709971295072`], 
             406 -> RGBColor[
              0.990618380894789, 0.9800157372285142, 0.4180546106567104], 32 -> 
             RGBColor[
              0.5357107322431658, 0.6339531317852908, 0.9565922576967049], 
             162 -> RGBColor[
              0.46203141681910903`, 0.5741369443087071, 0.9507919520902978], 
             493 -> RGBColor[
              0.9935772608954081, 0.9886707354308406, 0.5423026688954158], 90 -> 
             RGBColor[
              0.8647697772859632, 0.4788329671240561, 0.2088729261823753], 
             331 -> RGBColor[
              0.8366916950922476, 0.8726192625482565, 0.984285594873034], 8 -> 
             RGBColor[
              0.6202936289377985, 0.7026213377380665, 0.963250933161866], 364 -> 
             RGBColor[
              0.2585666750316088, 0.38910034790526005`, 0.938036361676709], 
             342 -> RGBColor[
              0.25998714329821626`, 0.39059335011635443`, 0.9381172552430979],
              163 -> RGBColor[
              0.26699231078344465`, 0.3979562252966011, 0.9385161891681649], 
             49 -> RGBColor[
              0.49021471545548245`, 0.5970174157848499, 0.9530106445977776], 
             338 -> RGBColor[
              0.32010532781399464`, 0.4516808788160655, 0.9416178063236486], 
             76 -> RGBColor[
              0.4113253016274047, 0.530691035284047, 0.9474302623923834], 369 -> 
             RGBColor[
              0.4199474238450335, 0.5381590841884939, 0.9479796563958474], 
             445 -> RGBColor[
              0.22963931784821143`, 0.3586958614051314, 0.9363889914793045], 
             82 -> RGBColor[
              0.25827862318556116`, 0.3887975871515221, 0.9380199575502111], 
             67 -> RGBColor[
              0.25662307112871396`, 0.38705749697171266`, 0.9379256763097434],
              430 -> RGBColor[
              0.23973902577549727`, 0.36931129479517677`, 0.9369641549045845],
              211 -> RGBColor[
              0.2310404057237692, 0.3601684935964447, 
               0.9364687813610937]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9V3c41W/cPkZ2skfWMY5xzsFxzjFCvnekUipFSBqEZKVlFlIpoUVlJUVG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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 54}], {
             RGBColor[
             0.24744314331957223`, 0.3774088108032645, 0.937402893001499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 70}], {
             RGBColor[
             0.26220782647507634`, 0.3929274289346799, 0.9382437198648137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 84}], {
             RGBColor[
             0.249739891419232, 0.3798228386782472, 0.9375336894080404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 131}], {
             RGBColor[
             0.26488726968740706`, 0.3957436936373514, 0.9383963101918749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 135}], {
             RGBColor[
             0.2583961289533292, 0.38892109316374235`, 0.9380266493298512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 147}], {
             RGBColor[
             0.2588293294875211, 0.38937641439167825`, 0.9380513194594108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 170}], {
             RGBColor[
             0.2814230291570491, 0.41312382526764985`, 0.939337997231207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 171}], {
             RGBColor[
             0.2639538573417897, 0.3947626180803467, 0.9383431537396518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 265}], {
             RGBColor[
             0.2935899974663011, 0.4247777732380918, 0.9400724206184119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 266}], {
             RGBColor[
             0.27784311638010406`, 0.40936110995950087`, 0.9391341264945663]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 374}], {
             RGBColor[
             0.25894790578239785`, 0.38950104559576504`, 0.9380580722039861]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 385}], {
             RGBColor[
             0.2498185382943033, 0.379905501530447, 0.937538168231228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 391}], {
             RGBColor[
             0.25364635844324135`, 0.38392878320479584`, 0.9377561569259576]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 433}], {
             RGBColor[
             0.2958358704615542, 0.4267230355457211, 0.940215525659722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 47}], {
             RGBColor[
             0.22219066917343752`, 0.3508668593763409, 0.9359648019565643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 54}], {
             RGBColor[
             0.22058424144202293`, 0.3491784019772233, 0.9358733182737572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 55}], {
             RGBColor[
             0.21196267506411343`, 0.3401165890751596, 0.9353823328229998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 230}], {
             RGBColor[
             0.21816285424353754`, 0.34663337050679954`, 0.9357354238549247]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 242}], {
             RGBColor[
             0.21872765624032725`, 0.34722701321594046`, 0.9357675884930923]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 250}], {
             RGBColor[
             0.20844651025640323`, 0.33642087692453115`, 0.9351820924389003]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 339}], {
             RGBColor[
             0.21206918576719214`, 0.340228538577264, 0.9353883984499716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 365}], {
             RGBColor[
             0.21471117528305686`, 0.3430054370702481, 0.9355388558444269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 8}], {
             RGBColor[
             0.5409798313044035, 0.6382308237734111, 0.9570070604761514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 31}], {
             RGBColor[
             0.4573521482388232, 0.5703305077559329, 0.9504256815919188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[
             0.4618487252450588, 0.5739886270587315, 0.9507775699403673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 203}], {
             RGBColor[
             0.49811633466717364`, 0.6034323062247897, 0.9536326890067068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 221}], {
             RGBColor[
             0.4991380572062573, 0.6042617866100937, 0.9537131227476765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 223}], {
             RGBColor[
             0.4257649092191724, 0.5429712289379067, 0.9484129706530855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 258}], {
             RGBColor[
             0.41754423807969365`, 0.5358508967798354, 0.9478891567573319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 381}], {
             RGBColor[
             0.5154854178683257, 0.6175333104357662, 0.9550000468613498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 439}], {
             RGBColor[
             0.6612892589149015, 0.732886286051436, 0.9686794915733958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 480}], {
             RGBColor[
             0.4076066344287682, 0.5272434439758863, 0.9472559414401728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 29}], {
             RGBColor[
             0.36696197867847585`, 0.49226575471112954`, 0.9446034706830237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 185}], {
             RGBColor[
             0.30412419819916303`, 0.4355457825101565, 0.9406834624888651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 196}], {
             RGBColor[
             0.31000149085861584`, 0.44172318973711877`, 0.9410181656111457]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 318}], {
             RGBColor[
             0.33312298494508064`, 0.46295611913654056`, 0.9424472799249791]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 321}], {
             RGBColor[
             0.32873955000778277`, 0.45915940811169914`, 0.9421679713268938]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 335}], {
             RGBColor[
             0.3005379095306292, 0.4317763657356928, 0.9404792286546308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 383}], {
             RGBColor[
             0.32662308368104653`, 0.45732623135617084`, 0.9420331119640719]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 479}], {
             RGBColor[
             0.3678971603336924, 0.49307576205728143`, 0.9446630596311456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 482}], {
             RGBColor[
             0.3413925426988842, 0.4701187944228272, 0.9429742088325687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 496}], {
             RGBColor[
             0.3005965950412318, 0.4318380479282125, 0.9404825707076422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.23876273655839006`, 0.3682851529276855, 0.9369085566779607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 23}], {
             RGBColor[
             0.23055442452635688`, 0.3596576965449768, 0.9364411054508459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 41}], {
             RGBColor[
             0.23556700835298144`, 0.36492623996293, 0.9367265646843188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 102}], {
             RGBColor[
             0.2575724490549457, 0.3880553533662194, 0.9379797419781635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 186}], {
             RGBColor[
             0.23715887571324926`, 0.36659939348879156`, 0.9368172191755294]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 193}], {
             RGBColor[
             0.263209529621381, 0.3939802824530939, 0.9383007653771087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 202}], {
             RGBColor[
             0.23883220085490312`, 0.3683581643076115, 0.9369125125668838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 211}], {
             RGBColor[
             0.2348238735021131, 0.3641451581171964, 0.9366842442539314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 212}], {
             RGBColor[
             0.22856179646777947`, 0.35756331811549596`, 0.9363276282307389]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 300}], {
             RGBColor[
             0.23228249418787045`, 0.3614740073251723, 0.936539516461619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 414}], {
             RGBColor[
             0.2566326545868817, 0.38706756979387325`, 0.9379262220735086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 485}], {
             RGBColor[
             0.24330426601765148`, 0.37305858833896816`, 0.9371671900620748]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 24}], {
             RGBColor[
             0.8323309168683787, 0.869142096362715, 0.9838696599531287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 77}], {
             RGBColor[
             0.7172538475630181, 0.7785612627115652, 0.9728085302210365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 79}], {
             RGBColor[
             0.9107592672849488, 0.9273249908421985, 0.7765494419084453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 80}], {
             RGBColor[
             0.8086163665159423, 0.8504788015959455, 0.9815424524658205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 81}], {
             RGBColor[
             0.825653983169494, 0.8638180906717614, 0.9832328080563602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 99}], {
             RGBColor[
             0.9106556765920616, 0.9271034208247384, 0.765274234275318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 156}], {
             RGBColor[
             0.6474994925034097, 0.7219315348762902, 0.9673172118721224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 267}], {
             RGBColor[
             0.9083762130299251, 0.9201045780958312, 0.6977188544044266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 278}], {
             RGBColor[
             0.8880267801577246, 0.9132258771339024, 0.9778589426846744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 329}], {
             RGBColor[
             0.8551238518896912, 0.8873165640509703, 0.9860436704429549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 406}], {
             RGBColor[
             0.9091541002347256, 0.9227285742942248, 0.700740799303404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 413}], {
             RGBColor[
             0.9007629224656561, 0.8944231613369187, 0.6681426582115271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 486}], {
             RGBColor[
             0.8813087089314302, 0.9081956582870432, 0.9885412054830938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 28}], {
             RGBColor[
             0.901769090567154, 0.9237583305634441, 0.9644245605513657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 49}], {
             RGBColor[
             0.6644484112533559, 0.7356118894004525, 0.9687430433701605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 69}], {
             RGBColor[
             0.874072307624645, 0.9024255483118935, 0.9878509910664408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 142}], {
             RGBColor[
             0.7691032060058948, 0.819699666861827, 0.9775805727504322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 173}], {
             RGBColor[
             0.9116225315818571, 0.9310453814508525, 0.9449853696775101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[
             0.9125990982944516, 0.9314492168831301, 0.9288011319761822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 241}], {
             RGBColor[
             0.7720821236708154, 0.8220268199822758, 0.9778774834237032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 388}], {
             RGBColor[
             0.8924271040987608, 0.9167910923514154, 0.9802381068620604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 402}], {
             RGBColor[
             0.6954966701641224, 0.7608182646923372, 0.971187276045136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 436}], {
             RGBColor[
             0.6558009604167452, 0.7285914992480711, 0.9680622843636464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 461}], {
             RGBColor[
             0.8915688064008891, 0.9161509753336762, 0.9816909809846657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 487}], {
             RGBColor[
             0.7090567422484308, 0.7718269420846646, 0.9722547745917934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 31}], {
             RGBColor[
             0.5366659458722182, 0.6347210217205881, 0.9566695542776334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 40}], {
             RGBColor[
             0.5032468930597369, 0.6057751178648505, 0.9545401217837302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 114}], {
             RGBColor[
             0.5604860564407306, 0.6540668560845098, 0.9585426619725401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 115}], {
             RGBColor[
             0.7707310045144475, 0.8213000079229384, 0.9777969948316587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 162}], {
             RGBColor[
             0.5411625228784538, 0.6383791410233868, 0.9570214426260819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 203}], {
             RGBColor[
             0.5774301323005686, 0.6678228201894449, 0.9598765616924215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 221}], {
             RGBColor[
             0.5784518548396522, 0.6686523005747489, 0.9599569954333912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 258}], {
             RGBColor[
             0.4968580357130886, 0.6002414107444907, 0.9541330294430466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 289}], {
             RGBColor[
             0.5298323406094952, 0.6288020963090049, 0.9562341229930127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 291}], {
             RGBColor[
             0.637610384777719, 0.7164873323549865, 0.9647458039813404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 297}], {
             RGBColor[
             0.5698289191235334, 0.6616518129015765, 0.9592781663469641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 311}], {
             RGBColor[
             0.6835752486050087, 0.752395433322769, 0.9693271520415703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 381}], {
             RGBColor[
             0.5947992155017207, 0.6819238244004215, 0.9612439195470645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 419}], {
             RGBColor[
             0.5664920822105015, 0.6589428183727875, 0.9590154783219338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 439}], {
             RGBColor[
             0.7406030565482964, 0.7972768000160912, 0.9749233642591105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 19}], {
             RGBColor[
             0.5674341026863339, 0.6597075930326068, 0.9590896376245259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 26}], {
             RGBColor[
             0.4808866078491948, 0.5876336896788764, 0.952776616899017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 34}], {
             RGBColor[
             0.559448373541096, 0.6532244183595045, 0.9584609717735231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 44}], {
             RGBColor[
             0.5359104641208152, 0.634115283121385, 0.9566079813217554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.5464995084832656, 0.6427119463658346, 0.9574415896829152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 117}], {
             RGBColor[
             0.4781094761010015, 0.5852282777412916, 0.9525996605197433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 139}], {
             RGBColor[
             0.5695894293133013, 0.6614573842847371, 0.9592593128318224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 247}], {
             RGBColor[
             0.5350775301382318, 0.6334390697910756, 0.9565424097075088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 269}], {
             RGBColor[
             0.512041509774998, 0.614618499836106, 0.9547617797005311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 360}], {
             RGBColor[
             0.5772550006439877, 0.6676806404210414, 0.9598627746868871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 425}], {
             RGBColor[
             0.47524326414852586`, 0.5827457090080587, 0.9524170280286233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 466}], {
             RGBColor[
             0.5393259259475076, 0.6368881088970959, 0.9568768589880016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 468}], {
             RGBColor[
             0.5267603512092651, 0.6266868092518996, 0.9558876509153902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 120}], {
             RGBColor[
             0.21319195993880496`, 0.3414086454196232, 0.9354523387780493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 123}], {
             RGBColor[
             0.21296296597852177`, 0.34116795824830987`, 0.9354392979107774]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 125}], {
             RGBColor[
             0.21381800062875955`, 0.3420666538780378, 0.935487990869198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 177}], {
             RGBColor[
             0.21382948684753797`, 0.34207872662224226`, 0.9354886449923652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 245}], {
             RGBColor[
             0.22026264269435236`, 0.3488403813028832, 0.93585500370084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 438}], {
             RGBColor[
             0.22021348611856342`, 0.3487887146250221, 0.9358522043065695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 455}], {
             RGBColor[
             0.21145152724630215`, 0.3395793403099965, 0.9353532237109508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 23}], {
             RGBColor[
             0.23070981980428998`, 0.3598210268347142, 0.9364499549820375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 41}], {
             RGBColor[
             0.23572240363091454`, 0.3650895702526674, 0.9367354142155104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 102}], {
             RGBColor[
             0.2577278443328788, 0.3882186836559568, 0.9379885915093551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 186}], {
             RGBColor[
             0.23731427099118235`, 0.3667627237785289, 0.936826068706721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 193}], {
             RGBColor[
             0.2633649248993141, 0.3941436127428313, 0.9383096149083003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 202}], {
             RGBColor[
             0.2389875961328362, 0.3685214945973489, 0.9369213620980754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 211}], {
             RGBColor[
             0.23497926878004616`, 0.3643084884069338, 0.936693093785123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 414}], {
             RGBColor[
             0.25678804986481485`, 0.38723090008361066`, 0.9379350716047002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 485}], {
             RGBColor[
             0.24345966129558455`, 0.3732219186287056, 0.9371760395932665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 497}], {
             RGBColor[
             0.2374558873234022, 0.36691157152268605`, 0.9368341335473384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 198}], {
             RGBColor[
             0.2771414265920781, 0.4086235895025834, 0.9390941662991953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 373}], {
             RGBColor[
             0.28300945147034123`, 0.414791255703904, 0.9394283416350475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 480}], {
             RGBColor[
             0.31297532312712917`, 0.4421451064609878, 0.9412865192071291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 154}], {
             RGBColor[
             0.3030787322552839, 0.435811820273263, 0.9405739494865415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 229}], {
             RGBColor[
             0.2937960299949141, 0.4261286336418093, 0.9400426213247091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 244}], {
             RGBColor[
             0.3195286449146627, 0.4500599078221664, 0.9416221233751105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 313}], {
             RGBColor[
             0.2817870779153078, 0.4135064635946042, 0.939358729269428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 334}], {
             RGBColor[
             0.3497101697631252, 0.47620162767835794`, 0.94354526344998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 338}], {
             RGBColor[
             0.30836079438708164`, 0.4403868770076641, 0.9409105178148355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 340}], {
             RGBColor[
             0.3170254114231826, 0.44789173278801986`, 0.9414626195505558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 363}], {
             RGBColor[
             0.3507138092232281, 0.4770709297343131, 0.9436092144688942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 379}], {
             RGBColor[
             0.3029577301181068, 0.43570701430378433`, 0.9405662393373586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 380}], {
             RGBColor[
             0.28473366122711574`, 0.4166035094794867, 0.939526532829956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 390}], {
             RGBColor[
             0.29868486413343276`, 0.4312671082913797, 0.9403210331965157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 478}], {
             RGBColor[
             0.28132910192119526`, 0.41302510178743673`, 0.939332648214078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 63}], {
             RGBColor[
             0.3630391373968948, 0.48868276614576933`, 0.9443602925394342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 72}], {
             RGBColor[
             0.2803635687690008, 0.4120102652261427, 0.9392776625294388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 75}], {
             RGBColor[
             0.32584559541094904`, 0.45646758947931865`, 0.9419903529330476]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 149}], {
             RGBColor[
             0.33030872638618497`, 0.46033332920658265`, 0.9422747396921978]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 158}], {
             RGBColor[
             0.33213200521333075`, 0.4619125616859979, 0.9423909174068014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 163}], {
             RGBColor[
             0.2868674954285888, 0.4188463045181374, 0.9396480515310051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 182}], {
             RGBColor[
             0.34266467028924463`, 0.47103542678761523`, 0.9430620495117685]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 187}], {
             RGBColor[
             0.28568538812664784`, 0.41760383479386565`, 0.9395807322689307]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 279}], {
             RGBColor[
             0.2926514518650601, 0.4249256094568878, 0.9399774392934654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 322}], {
             RGBColor[
             0.2829806146027809, 0.4147609463277351, 0.9394266994181002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 324}], {
             RGBColor[
             0.33821006500838097`, 0.4671770715883025, 0.9427782060023248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 441}], {
             RGBColor[
             0.3784375409652084, 0.5020200893703757, 0.9453414651985335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 494}], {
             RGBColor[
             0.2826231066390982, 0.4143851827905905, 0.9394063398684542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 78}], {
             RGBColor[
             0.22683394628673456`, 0.35574723802318886`, 0.9362292297190538]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 97}], {
             RGBColor[
             0.23298665056537604`, 0.36221412032402367`, 0.936579617125612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 104}], {
             RGBColor[
             0.24040623048550225`, 0.3700125692486139, 0.9370021512257783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.24125115959042637`, 0.3709006433094886, 0.9370502686883432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 148}], {
             RGBColor[
             0.2369473179686802, 0.36637703288571377`, 0.9368051712749479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 153}], {
             RGBColor[
             0.23958587882071014`, 0.3691503276356177, 0.93695543341207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 190}], {
             RGBColor[
             0.24117420601353035`, 0.37081976022103225`, 0.9370458862959816]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 323}], {
             RGBColor[
             0.2367917298527569, 0.36621349991102203`, 0.936796310761918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 356}], {
             RGBColor[
             0.2517883622305454, 0.38197591138148856`, 0.9376503467903037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 408}], {
             RGBColor[
             0.22837166352845595`, 0.3573634763411423, 0.9363168004411209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 430}], {
             RGBColor[
             0.23698890967688827`, 0.36642074840810707`, 0.9368075398612009]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 452}], {
             RGBColor[
             0.22909610908040262`, 0.3581249145487392, 0.9363580565435832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 39}], {
             RGBColor[
             0.5137718344766236, 0.6147998451486828, 0.9552360290912556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 45}], {
             RGBColor[
             0.343332276555383, 0.46939838880724916`, 0.9431857012274175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 52}], {
             RGBColor[
             0.6198385630520318, 0.4001930339226935, 0.5644333341255259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 56}], {
             RGBColor[
             0.6202778449645745, 0.4035695471970573, 0.5648539909810746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 179}], {
             RGBColor[
             0.29140560923354364`, 0.4148201691111312, 0.940228554342059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 200}], {
             RGBColor[
             0.6523550443789783, 0.5834045301394526, 0.5929583920999518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 236}], {
             RGBColor[
             0.34560261915581325`, 0.4717846628283363, 0.9433149938798411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 243}], {
             RGBColor[
             0.6215940953786275, 0.41368682466407874`, 0.566114433864064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 254}], {
             RGBColor[
             0.3201901654275895, 0.4450745627173458, 0.941867792234375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 276}], {
             RGBColor[
             0.5117111188744836, 0.6131268633886855, 0.9550738020104051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 283}], {
             RGBColor[
             0.29254812031783006`, 0.4160210207001029, 0.9402936186581154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 292}], {
             RGBColor[
             0.29142635679170903`, 0.41484197611023416`, 0.9402297358848033]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 422}], {
             RGBColor[
             0.3189470428658002, 0.4437679620863825, 0.9417969982435161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 454}], {
             RGBColor[
             0.6518822537994468, 0.581257698540845, 0.5925638840512331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 205}], {
             RGBColor[
             0.9368989095333399, 0.9481665884975428, 0.7789256469520753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 252}], {
             RGBColor[
             0.8078836333626171, 0.8503289562761027, 0.9813572830192461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 282}], {
             RGBColor[
             0.7438148228852721, 0.7997463454963281, 0.9753349394405884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 293}], {
             RGBColor[
             0.9171217844286204, 0.9362730779745756, 0.9753514321588153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 298}], {
             RGBColor[
             0.8908055349705915, 0.9157681695861948, 0.9894470212286257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 418}], {
             RGBColor[
             0.9292223734187801, 0.9452976774305406, 0.9548682913375369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 432}], {
             RGBColor[
             0.8892978625365586, 0.9145659925119751, 0.9893032180859526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 467}], {
             RGBColor[
             0.7934052123801664, 0.8390183037645371, 0.979914209324252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 52}], {
             RGBColor[
             0.8600894824934477, 0.42201909265360843`, 0.20357506457964797`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 56}], {
             RGBColor[
             0.8605287644059905, 0.4253956059279722, 0.2039957214351967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 65}], {
             RGBColor[
             0.9349243740088637, 0.7652639008938271, 0.3116367388337401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 88}], {
             RGBColor[
             0.8754970234499582, 0.5275428865427625, 0.2178240033304778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 166}], {
             RGBColor[
             0.8612521660936727, 0.43095598829613885`, 0.2046884517082866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 167}], {
             RGBColor[
             0.9355270875213144, 0.7783260157628717, 0.5479056765432442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 210}], {
             RGBColor[
             0.8602238171594843, 0.4230516477625904, 0.20370370360755374`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 227}], {
             RGBColor[
             0.8650075437066738, 0.45982146624662823`, 0.2082846055515888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 243}], {
             RGBColor[
             0.8618450148200435, 0.43551288339499367`, 0.2052561643181862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 326}], {
             RGBColor[
             0.8797797158009789, 0.5469895922605361, 0.22139758680656518`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 348}], {
             RGBColor[
             0.9221477650002106, 0.7221653986171828, 0.2620020254952798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 428}], {
             RGBColor[
             0.8573587081531882, 0.40102916444142644`, 0.2009600719874468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 434}], {
             RGBColor[
             0.9377932493402739, 0.7792631319127137, 0.510349510564296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 469}], {
             RGBColor[
             0.8724072991337889, 0.5135131700464854, 0.21524586162499276`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 474}], {
             RGBColor[
             0.9387405372806834, 0.7796548598202627, 0.49465049788910304`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 495}], {
             RGBColor[
             0.8632931958328989, 0.4466442372567656, 0.2066429440915829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 26}], {
             RGBColor[
             0.4731770317838775, 0.5813747085166081, 0.9521696908300475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 34}], {
             RGBColor[
             0.5517387974757788, 0.6469654371972362, 0.9578540457045537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 44}], {
             RGBColor[
             0.5282008880554978, 0.6278563019591167, 0.956001055252786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 139}], {
             RGBColor[
             0.5618798532479841, 0.6551984031224687, 0.9586523867628529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 234}], {
             RGBColor[
             0.474151584993228, 0.582218817524079, 0.9522317884987839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 247}], {
             RGBColor[
             0.5273679540729146, 0.6271800886288073, 0.9559354836385393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 269}], {
             RGBColor[
             0.5043319337096805, 0.6083595186738375, 0.9541548536315616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 360}], {
             RGBColor[
             0.5695454245786704, 0.661421659258773, 0.9592558486179177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 393}], {
             RGBColor[
             0.5104680056398668, 0.6134599491568583, 0.954605057791339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 466}], {
             RGBColor[
             0.5316163498821903, 0.6306291277348275, 0.9562699329190321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 468}], {
             RGBColor[
             0.5190507751439478, 0.6204278280896312, 0.9552807248464208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 62}], {
             RGBColor[
             0.8509265138034974, 0.3513524058869604, 0.19479135055817565`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 194}], {
             RGBColor[
             0.9355250585723344, 0.7786349412620628, 0.5492457614630861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 228}], {
             RGBColor[
             0.9388076655030091, 0.7780938721344945, 0.3568427286125849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 388}], {
             RGBColor[
             0.9153530643766437, 0.7639768167303482, 0.6006827363489642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 490}], {
             RGBColor[
             0.9375437932423437, 0.7794697399272263, 0.5157901036631747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 33}], {
             RGBColor[
             0.9296510090196749, 0.7439907144053559, 0.3002556094938443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 65}], {
             RGBColor[
             0.9831762967586118, 0.9549118399527363, 0.38914351910732653`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 119}], {
             RGBColor[
             0.9857675700825197, 0.9687962754074746, 0.5924568745131584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 164}], {
             RGBColor[
             0.8992062375406565, 0.5414501296947882, 0.27233399794458657`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 166}], {
             RGBColor[
             0.9095040888434207, 0.6206039273550481, 0.282195231981873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 175}], {
             RGBColor[
             0.9683090151158134, 0.9568481859192783, 0.670037151361724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 227}], {
             RGBColor[
             0.9132594664564218, 0.6494694053055374, 0.28579138582517527`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 309}], {
             RGBColor[
             0.9869592653755547, 0.967346961753188, 0.4315364838739727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 320}], {
             RGBColor[
             0.9847451317139568, 0.9683734708666063, 0.6094013242659239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 337}], {
             RGBColor[
             0.9205492329643337, 0.9192823831910986, 0.6833909335036439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 348}], {
             RGBColor[
             0.9703996877499586, 0.911813337676092, 0.3395088057688662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 375}], {
             RGBColor[
             0.9695446020803578, 0.9577696846543478, 0.6679456249234423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 428}], {
             RGBColor[
             0.9056106309029361, 0.5906771035003356, 0.2784668522610333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 489}], {
             RGBColor[
             0.9854926800563032, 0.9686826013172827, 0.5970125136401502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 63}], {
             RGBColor[
             0.4353760609281416, 0.5515225941640346, 0.948962755507775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 149}], {
             RGBColor[
             0.40264564991743174`, 0.5231731572248479, 0.9468772026605385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 160}], {
             RGBColor[
             0.4369491379476227, 0.5528851144131592, 0.949062990584439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 165}], {
             RGBColor[
             0.4377248912958056, 0.5535570329728583, 0.9491124209018134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 182}], {
             RGBColor[
             0.4150015938204914, 0.5338752548058805, 0.9476645124801093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 268}], {
             RGBColor[
             0.4305356531895016, 0.5473300762667914, 0.9486543290068734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 275}], {
             RGBColor[
             0.43256024452096153`, 0.549083675519183, 0.9487833341762382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 282}], {
             RGBColor[
             0.5295374583805197, 0.6288897605144723, 0.956120540334634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 285}], {
             RGBColor[
             0.38291743430858444`, 0.506085568433412, 0.9456201382069189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 324}], {
             RGBColor[
             0.41054698853962773`, 0.5300168996065678, 0.9473806689706655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 353}], {
             RGBColor[
             0.5455395337034719, 0.641880966146923, 0.9573802823215901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 441}], {
             RGBColor[
             0.45077446449645514`, 0.564859917388641, 0.9499439281668742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 481}], {
             RGBColor[
             0.38481661217346425`, 0.507730540844516, 0.9457411521410921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 41}], {
             RGBColor[
             0.22751409159888136`, 0.35646211386995863`, 0.9362679629883957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 186}], {
             RGBColor[
             0.22910595895914918`, 0.35813526739582024`, 0.9363586174796061]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 202}], {
             RGBColor[
             0.23077928410080303`, 0.35989403821464017`, 0.9364539108709606]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 211}], {
             RGBColor[
             0.226770956748013, 0.3556810320242251, 0.9362256425580082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 212}], {
             RGBColor[
             0.22050887971367938`, 0.3490991920225246, 0.9358690265348157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 485}], {
             RGBColor[
             0.2352513492635514, 0.3645944622459968, 0.9367085883661517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 497}], {
             RGBColor[
             0.22924757529136902`, 0.3582841151399774, 0.9363666823202235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 77}], {
             RGBColor[
             0.7218949448567346, 0.7822619477143448, 0.9732512022240677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 81}], {
             RGBColor[
             0.8302950804632105, 0.8675187756745408, 0.9836754800593912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 83}], {
             RGBColor[
             0.878858858195596, 0.9062422138097157, 0.9883075365329024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 176}], {
             RGBColor[
             0.7219583100603643, 0.7823133904412213, 0.9732561905650118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 197}], {
             RGBColor[
             0.7672988184851579, 0.8182762435725834, 0.9774043962108645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 237}], {
             RGBColor[
             0.871532203465174, 0.9004001382044219, 0.9876087136641327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 267}], {
             RGBColor[
             0.9130173103236416, 0.9238052630986108, 0.6981615264074577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 270}], {
             RGBColor[
             0.9134975511433701, 0.9314925430785823, 0.899659555679228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 278}], {
             RGBColor[
             0.8926678774514412, 0.9169265621366819, 0.9783016146877055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 329}], {
             RGBColor[
             0.8597649491834076, 0.8910172490537498, 0.986486342445986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 426}], {
             RGBColor[
             0.8535732035252862, 0.8860801191364223, 0.9858957682176778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 448}], {
             RGBColor[
             0.7024556642269519, 0.7664802639694746, 0.97172087084446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 489}], {
             RGBColor[
             0.9135348042436461, 0.9315079481929074, 0.8990421753997224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[
             0.36235029179287925`, 0.48827134332094824`, 0.9443096180726283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 96}], {
             RGBColor[
             0.3047685081778331, 0.4372333951604509, 0.9406831592217764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 157}], {
             RGBColor[
             0.3079594456965586, 0.4405872728097553, 0.9408648783928987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.2917531123703574, 0.42355338894303707`, 0.9399419516850931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 246}], {
             RGBColor[
             0.3037983452782409, 0.43621369244109887`, 0.940627909879872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 288}], {
             RGBColor[
             0.2847205959795895, 0.4161617683290476, 0.9395414602803146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 333}], {
             RGBColor[
             0.34601220845973285`, 0.4741201167137219, 0.94326856984984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 343}], {
             RGBColor[
             0.3031313951145783, 0.4355126855320067, 0.9405899280547156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 392}], {
             RGBColor[
             0.3096883372024623, 0.4424044474005129, 0.9409633362064942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 459}], {
             RGBColor[
             0.35196069990557133`, 0.47927240102423385`, 0.9436476024647243]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 465}], {
             RGBColor[
             0.2980004320712376, 0.430119718051609, 0.9402977272999771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 492}], {
             RGBColor[
             0.29499729755319337`, 0.42696323326341856`, 0.9401267032319138]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 34}], {
             RGBColor[
             0.46519130263863967`, 0.5748915338435057, 0.9515410249790447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 44}], {
             RGBColor[
             0.4416533932183588, 0.5557823986053863, 0.949688034527277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 106}], {
             RGBColor[
             0.45224243758080923`, 0.5643790618498358, 0.9505216428884367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 117}], {
             RGBColor[
             0.38385240519854513`, 0.5068953932252928, 0.9456797137252648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 139}], {
             RGBColor[
             0.4753323584108449, 0.5831244997687381, 0.952339366037344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 215}], {
             RGBColor[
             0.33537631974199883`, 0.4626312893738342, 0.942674216260174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 224}], {
             RGBColor[
             0.34279791451999597`, 0.4704318560417961, 0.9430968651035153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 247}], {
             RGBColor[
             0.44082045923577545`, 0.5551061852750767, 0.9496224629130303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 269}], {
             RGBColor[
             0.4177844388725415, 0.5362856153201071, 0.9478418329060527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 351}], {
             RGBColor[
             0.3383374936256977, 0.4657436708748698, 0.9428428507321864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 360}], {
             RGBColor[
             0.48299792974153133`, 0.5893477559050426, 0.9529428278924086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 425}], {
             RGBColor[
             0.38098619324606947`, 0.5044128244920598, 0.9454970812341448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 466}], {
             RGBColor[
             0.4450688550450512, 0.558555224381097, 0.9499569121935232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 468}], {
             RGBColor[
             0.43250328030680874`, 0.5483539247359007, 0.9489677041209118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 40}], {
             RGBColor[
             0.44915953688308596`, 0.5618645655130168, 0.9502821669769903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 114}], {
             RGBColor[
             0.5063987002640795, 0.610156303732676, 0.9542847071658003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 199}], {
             RGBColor[
             0.4274813973658525, 0.5430880506381621, 0.9489008550961784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 220}], {
             RGBColor[
             0.4255160611016982, 0.5413857751468245, 0.948775625607305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 277}], {
             RGBColor[
             0.6417102241932708, 0.7180330594388474, 0.9662874050409727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 289}], {
             RGBColor[
             0.47574498443284424`, 0.5848915439571711, 0.9519761681862727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 291}], {
             RGBColor[
             0.583523028601068, 0.6725767800031528, 0.9604878491746004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 297}], {
             RGBColor[
             0.5157415629468824, 0.6177412605497428, 0.9550202115402241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 311}], {
             RGBColor[
             0.6294878924283578, 0.7084848809709354, 0.9650691972348303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 319}], {
             RGBColor[
             0.6135043005796454, 0.695998377538924, 0.9634761021745089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 349}], {
             RGBColor[
             0.46286019331944683`, 0.5737313855031778, 0.9511551606901004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 359}], {
             RGBColor[
             0.44878508964320496`, 0.5615402381340974, 0.9502583075299758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 371}], {
             RGBColor[
             0.43753141765926407`, 0.551792873087608, 0.9495412335023905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 419}], {
             RGBColor[
             0.5124047260338506, 0.6150322660209537, 0.9547575235151939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 488}], {
             RGBColor[
             0.640741608541348, 0.7172763695298137, 0.9661908624850168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 69}], {
             RGBColor[
             0.9371592911405698, 0.9519775158592825, 0.9678001094752631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 142}], {
             RGBColor[
             0.8321901895218196, 0.869251634409216, 0.9575296911592543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 173}], {
             RGBColor[
             0.9747095150977819, 0.9805973489982415, 0.9249344880863324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 194}], {
             RGBColor[
             0.9756860818103763, 0.9810011844305191, 0.9087502503850045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 241}], {
             RGBColor[
             0.8351691071867402, 0.8715787875296648, 0.9578266018325254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 417}], {
             RGBColor[
             0.8329443683967894, 0.8698408046783143, 0.9576048606613091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 461}], {
             RGBColor[
             0.954655789916814, 0.9657029428810652, 0.9616400993934879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 493}], {
             RGBColor[
             0.9792166674892435, 0.9809905167708368, 0.7433381739278018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 77}], {
             RGBColor[
             0.5082190929851442, 0.6104476858288989, 0.9547558471761093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 172}], {
             RGBColor[
             0.3806363827099919, 0.5041098361876981, 0.9454747916161113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 318}], {
             RGBColor[
             0.37578131668551923`, 0.4999046220200136, 0.9451654311021982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 321}], {
             RGBColor[
             0.3713978817482214, 0.49610791099517215`, 0.944886122504113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 383}], {
             RGBColor[
             0.3692814154214852, 0.49427473423964385`, 0.944751263141291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 479}], {
             RGBColor[
             0.410555492074131, 0.5300242649407545, 0.9473812108083647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 482}], {
             RGBColor[
             0.38405087443932273`, 0.5070672973063002, 0.9456923600097877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 43}], {
             RGBColor[
             0.2805395184040802, 0.4121951994484624, 0.9392876826008625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 64}], {
             RGBColor[
             0.27788283656739987`, 0.4094028583947541, 0.9391363885004721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 110}], {
             RGBColor[
             0.26982326266389456`, 0.40093173521567016`, 0.9386774076897386]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 217}], {
             RGBColor[
             0.2938254921740675, 0.42514500116830317`, 0.9400814485951139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 290}], {
             RGBColor[
             0.2772082322816696, 0.40869380651806936`, 0.9390979707843874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 316}], {
             RGBColor[
             0.25921313179459604`, 0.3897798149508858, 0.938073176433014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 355}], {
             RGBColor[
             0.29831901354920054`, 0.4290370635324922, 0.9403677718036725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 378}], {
             RGBColor[
             0.2755078252460146, 0.406906570911563, 0.9390011351192336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 384}], {
             RGBColor[
             0.2758760121335012, 0.4072935586747084, 0.9390221028177923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[
             0.4196192099941566, 0.5378748018473721, 0.9479587428994976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 114}], {
             RGBColor[
             0.47685837337515014`, 0.5861665400670314, 0.9519612830883075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 162}], {
             RGBColor[
             0.4575348398128734, 0.5704788250059085, 0.9504400637418493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 203}], {
             RGBColor[
             0.4938024492349883, 0.5999225041719667, 0.9532951828081889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 208}], {
             RGBColor[
             0.38757839390763205`, 0.5101226573714661, 0.9459171304310454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 221}], {
             RGBColor[
             0.4948241717740719, 0.6007519845572706, 0.9533756165491586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 223}], {
             RGBColor[
             0.42145102378698707`, 0.5394614268850837, 0.9480754644545675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 258}], {
             RGBColor[
             0.4132303526475083, 0.5323410947270124, 0.947551650558814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 289}], {
             RGBColor[
             0.4462046575439149, 0.5609017802915265, 0.9496527441087801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 297}], {
             RGBColor[
             0.48620123605795307`, 0.5937514968840982, 0.9526967874627315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 314}], {
             RGBColor[
             0.3915568678230763, 0.5135686115131106, 0.9461706352709112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 381}], {
             RGBColor[
             0.5111715324361403, 0.6140235083829432, 0.9546625406628318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 397}], {
             RGBColor[
             0.40579315804314603`, 0.5258993705649835, 0.947077759095077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 419}], {
             RGBColor[
             0.4828643991449212, 0.5910425023553091, 0.9524340994377012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 472}], {
             RGBColor[
             0.39074248974700837`, 0.5128632381554529, 0.9461187438200305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 103}], {
             RGBColor[
             0.5080332189208779, 0.6114832796124914, 0.9544133824619024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 155}], {
             RGBColor[
             0.5507999265063706, 0.6462032194486154, 0.9577801343426442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 331}], {
             RGBColor[
             0.6862012136677067, 0.7532861971667737, 0.9704389262848694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 344}], {
             RGBColor[
             0.49972685632516956`, 0.6047398002599247, 0.9537594751711596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 403}], {
             RGBColor[
             0.73231135392298, 0.7900531713799142, 0.9748369526254256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 449}], {
             RGBColor[
             0.6320067542390264, 0.7108140314884382, 0.9650731650607731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 119}], {
             RGBColor[
             0.9345308133147854, 0.7655949021985857, 0.5124594755699873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 159}], {
             RGBColor[
             0.8495822086293704, 0.3506448894924134, 0.19388094901806585`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 164}], {
             RGBColor[
             0.8479694807729221, 0.33824875648589925`, 0.19233659900141542`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 227}], {
             RGBColor[
             0.8620227096886874, 0.44626803209664856`, 0.20579398688200412`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 267}], {
             RGBColor[
             0.9337384293685642, 0.7577785430140971, 0.3161344657047144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 270}], {
             RGBColor[
             0.9342186701882929, 0.7654658229940685, 0.5176324949764846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 309}], {
             RGBColor[
             0.9357225086078202, 0.7641455885442991, 0.35153908493080155`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 443}], {
             RGBColor[
             0.9064631162110222, 0.6594290978497701, 0.24321160823769428`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 489}], {
             RGBColor[
             0.9342559232885688, 0.7654812281083937, 0.517015114696979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 234}], {
             RGBColor[
             0.4661658558479902, 0.5757356428509766, 0.951603122647781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 269}], {
             RGBColor[
             0.4963462045644428, 0.6018763440007352, 0.9535261877805588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 332}], {
             RGBColor[
             0.47297256082386624`, 0.5816312685861409, 0.9520368398699108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 360}], {
             RGBColor[
             0.5615596954334325, 0.6549384845856707, 0.9586271827669148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 393}], {
             RGBColor[
             0.5024822764946291, 0.606976774483756, 0.9539763919403361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 468}], {
             RGBColor[
             0.51106504599871, 0.6139446534165288, 0.9546520589954179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 54}], {
             RGBColor[
             0.23354661261843296`, 0.36280267594543125`, 0.936611506136144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 67}], {
             RGBColor[
             0.24749774961125026`, 0.377466205478057, 0.9374060027490273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 70}], {
             RGBColor[
             0.24831129577393707`, 0.37832129407684667`, 0.9374523329994586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 84}], {
             RGBColor[
             0.2358433607180927, 0.36521670382041393`, 0.9367423025426853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 131}], {
             RGBColor[
             0.2509907389862678, 0.38113755877951816`, 0.9376049233265198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 135}], {
             RGBColor[
             0.24449959825218992`, 0.3743149583059091, 0.9372352624644963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 147}], {
             RGBColor[
             0.2449327987863818, 0.374770279533845, 0.9372599325940558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 171}], {
             RGBColor[
             0.25005732664065045`, 0.38015648322251344`, 0.9375517668742968]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 216}], {
             RGBColor[
             0.25212920477180323`, 0.3823341585030158, 0.9376697572687969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 281}], {
             RGBColor[
             0.2416405448941051, 0.37130991195210916`, 0.9370724436053437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 385}], {
             RGBColor[
             0.235922007593164, 0.36529936667261376`, 0.936746781365873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 391}], {
             RGBColor[
             0.23974982774210207`, 0.3693226483469626, 0.9369647700606025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 37}], {
             RGBColor[
             0.2800147441029785, 0.41164362838539204`, 0.9392577974807488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 58}], {
             RGBColor[
             0.28475051663686596`, 0.4160326690739975, 0.9395490426575464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 141}], {
             RGBColor[
             0.28198608489330845`, 0.4136382572421074, 0.9393728955113378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 240}], {
             RGBColor[
             0.25550742159800177`, 0.3858848785786683, 0.9378621417194251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 251}], {
             RGBColor[
             0.25646724614478844`, 0.3868937150337323, 0.9379168023074314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 310}], {
             RGBColor[
             0.2755731801551128, 0.4069752630647657, 0.9390048569846228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 352}], {
             RGBColor[
             0.2411100918235177, 0.37075237214225454`, 0.9370422350877088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 367}], {
             RGBColor[
             0.2421171751521342, 0.3718108805734015, 0.9370995869934273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 382}], {
             RGBColor[
             0.26830699274776615`, 0.39933803939675394`, 0.9385910583611354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 399}], {
             RGBColor[
             0.24794512185068096`, 0.37793642206673694`, 0.937431479936235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 412}], {
             RGBColor[
             0.24838538806776134`, 0.3783991697753788, 0.9374565524459821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 416}], {
             RGBColor[
             0.2579614870777197, 0.3884642569945902, 0.9380018971180304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 429}], {
             RGBColor[
             0.2739936283843697, 0.4053150540043482, 0.9389149038480165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 58}], {
             RGBColor[
             0.31037597127891847`, 0.44296664665046, 0.9410083743899482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 118}], {
             RGBColor[
             0.31537415178862416`, 0.44729581939211016`, 0.9413268540323092]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 141}], {
             RGBColor[
             0.3076115395353609, 0.4405722348185699, 0.9408322272437397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 188}], {
             RGBColor[
             0.3214586719550145, 0.4525659249433619, 0.9417145542769817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 240}], {
             RGBColor[
             0.28113287624005423`, 0.4128188561551308, 0.9393214734518269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 304}], {
             RGBColor[
             0.32210212279026273`, 0.45312324971607465`, 0.9417555543952225]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 310}], {
             RGBColor[
             0.30119863479716524`, 0.4339092406412282, 0.9404641887170249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 429}], {
             RGBColor[
             0.29961908302642226`, 0.4322490315808106, 0.9403742355804184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 47}], {
             RGBColor[
             0.24595116399713765`, 0.375840645938433, 0.9373179269862719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 73}], {
             RGBColor[
             0.25393957190424143`, 0.3842369691431141, 0.937772854998791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 93}], {
             RGBColor[
             0.2646269773927557, 0.3954701099321881, 0.9383814869307624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 108}], {
             RGBColor[
             0.272539685244709, 0.40378686757924537`, 0.9388321039371288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 163}], {
             RGBColor[
             0.2634804930859057, 0.3942650822343853, 0.9383161963455589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 189}], {
             RGBColor[
             0.2598720197723208, 0.3904723479913851, 0.9381106991286081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 266}], {
             RGBColor[
             0.27474470932625494`, 0.40610448769555174`, 0.9389576767965321]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 364}], {
             RGBColor[
             0.2592676752099878, 0.3898371435387148, 0.9380762825998308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 437}], {
             RGBColor[
             0.2578995688543769, 0.3883991770160148, 0.9379983709668107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 45}], {
             RGBColor[
             0.45322202962692537`, 0.5599541419213354, 0.9514657433370749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 100}], {
             RGBColor[
             0.7774382200691679, 0.7351762203070193, 0.6135140654406412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 127}], {
             RGBColor[
             0.4248206994263658, 0.5301025431322064, 0.9498483295981558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 179}], {
             RGBColor[
             0.40129536230508595`, 0.5053759222252174, 0.9485085964517164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 200}], {
             RGBColor[
             0.7622447974505207, 0.6739602832535388, 0.6012384342096092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 213}], {
             RGBColor[
             0.7639337426080279, 0.681629388750616, 0.6026477314488674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 236}], {
             RGBColor[
             0.4554923722273556, 0.5623404159424226, 0.9515950359894985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 243}], {
             RGBColor[
             0.7314838484501698, 0.504242577778165, 0.5743944759737214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 254}], {
             RGBColor[
             0.43007991849913185`, 0.5356303158314321, 0.9501478343440324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 276}], {
             RGBColor[
             0.6216008719460259, 0.7036826165027719, 0.9633538441200625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 283}], {
             RGBColor[
             0.4024378733893724, 0.5065767738141891, 0.9485736607677728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 315}], {
             RGBColor[
             0.40458060190845924`, 0.5088289173445842, 0.948695685987052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 325}], {
             RGBColor[
             0.40133925395865816`, 0.5054220551360133, 0.9485110960164554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 368}], {
             RGBColor[
             0.5158816187650146, 0.6166272342584453, 0.9553704626805029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 401}], {
             RGBColor[
             0.6985569826136641, 0.7641508706261513, 0.9707851169753527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 450}], {
             RGBColor[
             0.7206850354992045, 0.4212381693670362, 0.5640535204963621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 454}], {
             RGBColor[
             0.761772006870989, 0.6718134516549312, 0.6008439261608904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 471}], {
             RGBColor[
             0.7402370852900231, 0.5715237918221177, 0.5827765854569318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 475}], {
             RGBColor[
             0.731332489294519, 0.5030791649818271, 0.5742495342753344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 114}], {
             RGBColor[
             0.443439320562669, 0.5572206362112937, 0.9498318505944043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 199}], {
             RGBColor[
             0.3645220176644419, 0.4901523831167798, 0.9444479985247825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 208}], {
             RGBColor[
             0.3541593410951509, 0.4811767535157284, 0.9437876979371422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 220}], {
             RGBColor[
             0.36255668140028763`, 0.48845010762544216`, 0.9443227690359091]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 289}], {
             RGBColor[
             0.41278560473143366`, 0.5319558764357888, 0.9475233116148768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 291}], {
             RGBColor[
             0.5205636488996574, 0.6196411124817705, 0.9560349926032045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 297}], {
             RGBColor[
             0.4527821832454718, 0.5648055930283604, 0.9505673549688282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 314}], {
             RGBColor[
             0.35813781501059505`, 0.484622707657373, 0.944041202777008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 349}], {
             RGBColor[
             0.3999008136180363, 0.5207957179817955, 0.9467023041187045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 359}], {
             RGBColor[
             0.38582570994179444`, 0.508604570612715, 0.9458054509585798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 371}], {
             RGBColor[
             0.37457203795785354`, 0.49885720556622565`, 0.9450883769309946]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 397}], {
             RGBColor[
             0.37237410523066483`, 0.4969534667092458, 0.9449483266011737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 419}], {
             RGBColor[
             0.44944534633244004`, 0.5620965984995714, 0.950304666943798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 472}], {
             RGBColor[
             0.35732343693452717`, 0.4839173342997152, 0.9439893113261273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 102}], {
             RGBColor[
             0.2545321161274702, 0.38485977069120125`, 0.9378065995157133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 186}], {
             RGBColor[
             0.23411854278577374`, 0.36340381081377343`, 0.9366440767130793]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 191}], {
             RGBColor[
             0.22546402831064583`, 0.35430736737250323`, 0.9361512149169275]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 202}], {
             RGBColor[
             0.2357918679274276, 0.3651625816325934, 0.9367393701044336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 212}], {
             RGBColor[
             0.22552146354030395`, 0.35436773544047784`, 0.9361544857682886]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 295}], {
             RGBColor[
             0.23105727915165333`, 0.3601862286389881, 0.9364697422778497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 300}], {
             RGBColor[
             0.22924216126039493`, 0.3582784246501542, 0.9363663739991688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 389}], {
             RGBColor[
             0.2255132290582107, 0.3543590804777015, 0.9361540168267153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 451}], {
             RGBColor[
             0.22198624668627384`, 0.3506519983811976, 0.9359531603983363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 456}], {
             RGBColor[
             0.22809260204387605`, 0.3570701650273288, 0.9363009083024085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 485}], {
             RGBColor[
             0.24026393309017596`, 0.36986300566395003`, 0.9369940475996247]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 85}], {
             RGBColor[
             0.22334491181980198`, 0.3520800415808806, 0.9360305343677259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 95}], {
             RGBColor[
             0.2297785943922997, 0.3588422498836111, 0.9363969230724491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[
             0.23210438822814727`, 0.3612868066689332, 0.936529373590697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 137}], {
             RGBColor[
             0.22627740530250587`, 0.35516227816202806`, 0.9361975355333305]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 145}], {
             RGBColor[
             0.22656621784669417`, 0.3554658384577429, 0.9362139829804621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 174}], {
             RGBColor[
             0.2495656884148965, 0.3796397402755821, 0.9375237688046536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 248}], {
             RGBColor[
             0.2375069627028864, 0.3669652549848901, 0.9368370422146407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 286}], {
             RGBColor[
             0.2277872668823118, 0.3567492384131574, 0.9362835199166604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 294}], {
             RGBColor[
             0.23539350574473433`, 0.36474387772096156`, 0.9367166839674533]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 346}], {
             RGBColor[
             0.22517846281523107`, 0.3540072199309242, 0.9361349523844199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 358}], {
             RGBColor[
             0.22905024080537584`, 0.3580767040834695, 0.9363554444131764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 407}], {
             RGBColor[
             0.22341630550160935`, 0.352155080867081, 0.9360346001322872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 411}], {
             RGBColor[
             0.23603211668449622`, 0.3654150983089235, 0.9367530519157325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 430}], {
             RGBColor[
             0.2361066473396595, 0.36549343475301654`, 0.9367572963262859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 110}], {
             RGBColor[
             0.2824315567297242, 0.4141838516908727, 0.9393954313844881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 217}], {
             RGBColor[
             0.30643378623989703`, 0.43839711764350564`, 0.9407994722898634]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 290}], {
             RGBColor[
             0.2898165263474991, 0.4219459229932718, 0.9398159944791369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 316}], {
             RGBColor[
             0.2718214258604257, 0.4030319314260883, 0.9387912001277635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 340}], {
             RGBColor[
             0.31529118717805316`, 0.446068953150221, 0.9413638580453506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 355}], {
             RGBColor[
             0.3109273076150301, 0.4422891800076947, 0.941085795498422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 362}], {
             RGBColor[
             0.34080467652755875`, 0.4681674552795022, 0.9429895550260083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 378}], {
             RGBColor[
             0.2881161193118442, 0.42015868738676554`, 0.939719158813983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 384}], {
             RGBColor[
             0.28848430619933074`, 0.4205456751499109, 0.9397401265125418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 57}], {
             RGBColor[
             0.5489601186307986, 0.6447095805328258, 0.9576352979272409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 106}], {
             RGBColor[
             0.5072662938524296, 0.6108606552923443, 0.9543530073111751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 117}], {
             RGBColor[
             0.4388762614701655, 0.5533769866678013, 0.9495110781480034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 139}], {
             RGBColor[
             0.5303562146824653, 0.6296060932112468, 0.9561707304600824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 140}], {
             RGBColor[
             0.4981556569200065, 0.6034642298010868, 0.9536357845984921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 247}], {
             RGBColor[
             0.4958443155073958, 0.6015877787175854, 0.9534538273357688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 255}], {
             RGBColor[
             0.44713138767076954`, 0.5605271620680575, 0.9500370874897843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 269}], {
             RGBColor[
             0.4728082951441619, 0.5827672087626157, 0.9516731973287911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 360}], {
             RGBColor[
             0.5380217860131518, 0.6358293493475512, 0.9567741923151472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 369}], {
             RGBColor[
             0.4583123366675063, 0.5702115381181944, 0.9507495276729314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 370}], {
             RGBColor[
             0.5440602935407461, 0.6407316817901163, 0.9572495657475013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 425}], {
             RGBColor[
             0.43601004951768985`, 0.5508944179345684, 0.9493284456568833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 466}], {
             RGBColor[
             0.5000927113166715, 0.6050368178236056, 0.9537882766162615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 468}], {
             RGBColor[
             0.48752713657842917`, 0.5948355181784093, 0.9527990685436503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 52}], {
             RGBColor[
             0.5592887582023336, 0.3453473306953461, 0.5606630483713451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 56}], {
             RGBColor[
             0.5597280401148761, 0.3487238439697099, 0.5610837052268939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 179}], {
             RGBColor[
             0.2308558043838454, 0.3599744658837838, 0.9364582685878783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 236}], {
             RGBColor[
             0.285052814306115, 0.4169389596009889, 0.9395447081256605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 243}], {
             RGBColor[
             0.5610442905289292, 0.35884112143673136`, 0.5623441481098833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 254}], {
             RGBColor[
             0.25964036057789125`, 0.3902288594899984, 0.9380975064801944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 276}], {
             RGBColor[
             0.4511613140247853, 0.5582811601613382, 0.9513035162562244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 283}], {
             RGBColor[
             0.23199831546813182`, 0.3611753174727555, 0.9365233329039347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 292}], {
             RGBColor[
             0.23087655194201073`, 0.35999627288288677`, 0.9364594501306225]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 386}], {
             RGBColor[
             0.23085473585284239`, 0.35997334278995086`, 0.9364582077366184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 422}], {
             RGBColor[
             0.2583972380161019, 0.3889222588590351, 0.9380267124893356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 53}], {
             RGBColor[
             0.9470835767696775, 0.821834287485996, 0.3079282681448157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 68}], {
             RGBColor[
             0.8688206529626022, 0.4329330984324026, 0.20968686128144703`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 90}], {
             RGBColor[
             0.8912123121580973, 0.5950344530170778, 0.2307371435474895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 205}], {
             RGBColor[
             0.9557407049755898, 0.8502199530826348, 0.4110195083871594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 257}], {
             RGBColor[
             0.8882541401217813, 0.5816020846987996, 0.22826877228895565`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 272}], {
             RGBColor[
             0.8691188894851287, 0.4352254750326188, 0.20997245291222838`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 293}], {
             RGBColor[
             0.9359635798708703, 0.8383264425596675, 0.6074452935938994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 298}], {
             RGBColor[
             0.9096473304128414, 0.8178215341712867, 0.6215408826637097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 306}], {
             RGBColor[
             0.8876171805650555, 0.5774114462757728, 0.22768643734119767`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 317}], {
             RGBColor[
             0.9005275853462438, 0.6373329329271229, 0.23851003583391922`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 357}], {
             RGBColor[
             0.9123985653292456, 0.6903965335177349, 0.2483720332752017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 418}], {
             RGBColor[
             0.9480641688610301, 0.8473510420156326, 0.586962152772621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 420}], {
             RGBColor[
             0.9431488383406506, 0.8436851965616485, 0.5952825252201055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 55}], {
             RGBColor[
             0.22170565849658444`, 0.35035708240351526`, 0.9359371813160265]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 189}], {
             RGBColor[
             0.24585450838109163`, 0.3757390547576487, 0.9373124225919274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 230}], {
             RGBColor[
             0.22790583767600858`, 0.3568738638351552, 0.9362902723479516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 242}], {
             RGBColor[
             0.2284706396727983, 0.35746750654429615`, 0.9363224369861192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 339}], {
             RGBColor[
             0.22181216919966315`, 0.3504690319056196, 0.9359432469429985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 364}], {
             RGBColor[
             0.24525016381875867`, 0.3751038503049783, 0.93727800606315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 365}], {
             RGBColor[
             0.22445415871552787`, 0.3532459303986038, 0.9360937043374536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 374}], {
             RGBColor[
             0.24183198733731956`, 0.37151113009807946`, 0.9370833459692711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 437}], {
             RGBColor[
             0.2438820574631478, 0.37366588378227833`, 0.93720009443013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 78}], {
             RGBColor[
             0.21346998781254425`, 0.3417008703429085, 0.9354681720541533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 85}], {
             RGBColor[
             0.21086321568284044`, 0.3389609875556907, 0.9353197202377406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 95}], {
             RGBColor[
             0.21729689825533816`, 0.34572319585842115`, 0.9356861089424638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 137}], {
             RGBColor[
             0.21379570916554433`, 0.34204322413683813`, 0.9354867214033452]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 145}], {
             RGBColor[
             0.21408452170973263`, 0.34234678443255295`, 0.9355031688504769]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 183}], {
             RGBColor[
             0.20623910902756293`, 0.3341007582756985, 0.9350563842044752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 346}], {
             RGBColor[
             0.21269676667826953`, 0.34088816590573434`, 0.9354241382544346]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 358}], {
             RGBColor[
             0.2165685446684143, 0.3449576500582796, 0.9356446302831911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 404}], {
             RGBColor[
             0.21047959213928613`, 0.3385577748882776, 0.9352978734444553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 407}], {
             RGBColor[
             0.2109346093646478, 0.33903602684189116`, 0.935323786002302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 408}], {
             RGBColor[
             0.21500770505426564`, 0.34331710866086196`, 0.9355557427762207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 71}], {
             RGBColor[
             0.6229981269292593, 0.7030794824142605, 0.9646517716159538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 76}], {
             RGBColor[
             0.45077000854144356`, 0.5638542255344485, 0.9502204534950804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 238}], {
             RGBColor[
             0.4051843179606758, 0.5243701915568157, 0.9473157736011174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 328}], {
             RGBColor[
             0.4377638604952656, 0.5525889538048573, 0.9493917132424632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 402}], {
             RGBColor[
             0.521262974366249, 0.6222237910767345, 0.9554548772727531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 431}], {
             RGBColor[
             0.4693773227785792, 0.5799709458958486, 0.9514060951044689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 436}], {
             RGBColor[
             0.4815672646188717, 0.5899970256324685, 0.9523298855912635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 459}], {
             RGBColor[
             0.44038041665413563`, 0.554855283237734, 0.9495584378871766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 462}], {
             RGBColor[
             0.4770465403942916, 0.586326898050649, 0.9519739976203461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 487}], {
             RGBColor[
             0.5348230464505574, 0.633232468469062, 0.9565223758194106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 57}], {
             RGBColor[
             0.5210905073010532, 0.6217476292469348, 0.9555341779806428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 92}], {
             RGBColor[
             0.5250378077135244, 0.6249522255456361, 0.9558449239285502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 106}], {
             RGBColor[
             0.47939668252268425`, 0.5878987040064534, 0.9522518873645769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 117}], {
             RGBColor[
             0.41100665014042015`, 0.5304150353819104, 0.9474099582014052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 139}], {
             RGBColor[
             0.50248660335272, 0.6066441419253559, 0.9540696105134843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 140}], {
             RGBColor[
             0.47028604559026116`, 0.5805022785151959, 0.9515346646518938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 169}], {
             RGBColor[
             0.46684010556596744`, 0.5777047091656451, 0.9512633876302873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 204}], {
             RGBColor[
             0.47141553909134676`, 0.5814192522224795, 0.9516235825177704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 219}], {
             RGBColor[
             0.48360346312109975`, 0.5913139580095534, 0.9525830605432293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 244}], {
             RGBColor[
             0.3916895278498226, 0.5136835149605915, 0.9461790882505088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 255}], {
             RGBColor[
             0.41926177634102413`, 0.5375652107821666, 0.9479359675431862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 274}], {
             RGBColor[
             0.4518361438965558, 0.5655238171616463, 0.9500822208063486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 334}], {
             RGBColor[
             0.42187105269828507`, 0.539825234816783, 0.9481022283253784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 338}], {
             RGBColor[
             0.3805216773222415, 0.5040104841460892, 0.9454674826902338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 340}], {
             RGBColor[
             0.3891862943583425, 0.5115153399264449, 0.9460195844259542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 361}], {
             RGBColor[
             0.5425697371949871, 0.6391572117563517, 0.9572443985054486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 363}], {
             RGBColor[
             0.422874692158388, 0.5406945368727382, 0.9481661793442926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 369}], {
             RGBColor[
             0.43044272533776096`, 0.5472495868323034, 0.9486484077263333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 370}], {
             RGBColor[
             0.5161906822110007, 0.6177697305042253, 0.9551484458009031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 379}], {
             RGBColor[
             0.37511861305326666`, 0.49933062144220947`, 0.9451232042127569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[
             0.18179934664985797`, 0.3084130184462969, 0.9336645758924533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 113}], {
             RGBColor[
             0.17905963075308248`, 0.3055334033307651, 0.9335085531251784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 127}], {
             RGBColor[
             0.20245340605759676`, 0.3301217444268325, 0.9348407940207814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 130}], {
             RGBColor[
             0.1789270004053139, 0.3053940004260106, 0.9335010000230821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 143}], {
             RGBColor[
             0.17892700107920537`, 0.30539400113431325`, 0.9335010000614592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 179}], {
             RGBColor[
             0.1789280689363169, 0.30539512351984355`, 0.9335010608743419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 214}], {
             RGBColor[
             0.1893670578318586, 0.31636716271918164`, 0.9340955458488429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 302}], {
             RGBColor[
             0.18453817957609825`, 0.31129170550381263`, 0.9338205483758626]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 308}], {
             RGBColor[
             0.1789366427891193, 0.3054041351827525, 0.9335015491425751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 315}], {
             RGBColor[
             0.1822133085396902, 0.30884811863921036`, 0.9336881504096776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 325}], {
             RGBColor[
             0.17897196058988912`, 0.30544125643063946`, 0.933503560439081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 347}], {
             RGBColor[
             0.1789270004053139, 0.3053940004260106, 0.9335010000230821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 386}], {
             RGBColor[
             0.1789270004053139, 0.3053940004260106, 0.9335010000230821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 421}], {
             RGBColor[
             0.17899180329589925`, 0.30546211237275633`, 0.9335046904518336]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 423}], {
             RGBColor[
             0.18337644614132015`, 0.31007065000570677`, 0.9337543893753826]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 477}], {
             RGBColor[
             0.21179931412463662`, 0.3399448863700877, 0.9353730296591674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 56}], {
             RGBColor[
             0.836234326611525, 0.27951848908515425`, 0.18233133812500216`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 88}], {
             RGBColor[
             0.8512025856554928, 0.3816657696999445, 0.19615962002028325`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 166}], {
             RGBColor[
             0.8369577282992072, 0.2850788714533209, 0.18302406839809204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 210}], {
             RGBColor[
             0.8359293793650189, 0.2771745309197725, 0.1820393202973592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 227}], {
             RGBColor[
             0.8407131059122084, 0.31394434940381033`, 0.18662022224139424`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 236}], {
             RGBColor[
             0.5615591008027638, 0.3477336047164332, 0.5607923410237687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 243}], {
             RGBColor[
             0.837550577025578, 0.2896357665521757, 0.18359178100799164`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 276}], {
             RGBColor[
             0.7276676005214341, 0.4890758052767825, 0.5725511491543327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 326}], {
             RGBColor[
             0.8554852780065134, 0.4011124754177182, 0.19973320349637064`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 428}], {
             RGBColor[
             0.8330642703587228, 0.25515204759860854`, 0.17929568867725226`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 469}], {
             RGBColor[
             0.8481128613393234, 0.36763605320366755`, 0.19358147831479822`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 495}], {
             RGBColor[
             0.8389987580384334, 0.3007671204139477, 0.18497856078138836`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 90}], {
             RGBColor[
             0.9206410418975434, 0.7056328015929743, 0.28606405077970154`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 178}], {
             RGBColor[
             0.9840984713626098, 0.9616310168446078, 0.5753629014776818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 257}], {
             RGBColor[
             0.9176828698612274, 0.692200433274696, 0.28359567952116765`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 272}], {
             RGBColor[
             0.8985476192245749, 0.5458238236085153, 0.2652993601444404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[
             0.9653923096103165, 0.9489247911355639, 0.6627722008261114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 298}], {
             RGBColor[
             0.9390760601522875, 0.9284198827471832, 0.6768677898959217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 306}], {
             RGBColor[
             0.9170459103045016, 0.6880097948516692, 0.28301334457340965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 317}], {
             RGBColor[
             0.9299563150856899, 0.7479312815030192, 0.29383694306613123`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 357}], {
             RGBColor[
             0.9418272950686917, 0.8009948820936315, 0.3036989405074137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 418}], {
             RGBColor[
             0.9774928986004763, 0.9579493905915291, 0.642289060004833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 420}], {
             RGBColor[
             0.9725775680800968, 0.9542835451375451, 0.6506094324523175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 432}], {
             RGBColor[
             0.9375683877182548, 0.9272177056729635, 0.6767239867532486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 55}], {
             RGBColor[
             0.22009923076516985`, 0.34866862500439766`, 0.9358456976332195]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 70}], {
             RGBColor[
             0.24348548029858347`, 0.3732490560378767, 0.9371775099472914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 84}], {
             RGBColor[
             0.23101754524273913`, 0.3601444657814439, 0.9364674794905181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 131}], {
             RGBColor[
             0.24616492351091418`, 0.3760653207405481, 0.9373301002743527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 135}], {
             RGBColor[
             0.23967378277683635`, 0.36924272026693905`, 0.9369604394123292]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 147}], {
             RGBColor[
             0.2401069833110282, 0.36969804149487495`, 0.9369851095418886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 230}], {
             RGBColor[
             0.22629940994459397`, 0.3551854064360376, 0.9361987886651444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 242}], {
             RGBColor[
             0.22686421194138368`, 0.35577904914517844`, 0.936230953303312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 365}], {
             RGBColor[
             0.22284773098411328`, 0.35155747299948614`, 0.9360022206546466]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 374}], {
             RGBColor[
             0.24022555960590497`, 0.3698226726989618, 0.9369918622864639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 385}], {
             RGBColor[
             0.23109619211781043`, 0.36022712863364376`, 0.9364719583137058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 391}], {
             RGBColor[
             0.23492401226674847`, 0.36425041030799266`, 0.9366899470084354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 230}], {
             RGBColor[
             0.21767784356668446`, 0.34612359353397393`, 0.935707803214387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 242}], {
             RGBColor[
             0.21824264556347417`, 0.34671723624311485`, 0.9357399678525544]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 250}], {
             RGBColor[
             0.20796149957955015`, 0.33591109995170554`, 0.9351544717983624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 339}], {
             RGBColor[
             0.21158417509033906`, 0.33971876160443837`, 0.9353607778094337]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 365}], {
             RGBColor[
             0.21422616460620378`, 0.3424956600974225, 0.935511235203889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 88}], {
             RGBColor[
             0.8516418675680354, 0.38504228297430826`, 0.19658027687583196`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 164}], {
             RGBColor[
             0.8270991589089857, 0.20930158706742483`, 0.17358349121635427`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 166}], {
             RGBColor[
             0.8373970102117498, 0.28845538472768467`, 0.18344472525364075`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 210}], {
             RGBColor[
             0.8363686612775614, 0.28055104419413623`, 0.18245997715290796`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 227}], {
             RGBColor[
             0.8411523878247509, 0.31732086267817405`, 0.187040879096943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 236}], {
             RGBColor[
             0.5619983827153064, 0.35111011799079705`, 0.5612129978793174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 243}], {
             RGBColor[
             0.8379898589381207, 0.2930122798265395, 0.18401243786354038`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 276}], {
             RGBColor[
             0.7281068824339767, 0.4924523185511463, 0.5729718060098814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 326}], {
             RGBColor[
             0.8559245599190561, 0.404488988692082, 0.2001538603519194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 428}], {
             RGBColor[
             0.8335035522712653, 0.25852856087297227`, 0.179716345532801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 495}], {
             RGBColor[
             0.839438039950976, 0.30414363368831143`, 0.18539921763693712`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 92}], {
             RGBColor[
             0.6051902881840892, 0.690359765316458, 0.9620619428523739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 106}], {
             RGBColor[
             0.5595491629932491, 0.6533062437772754, 0.9584689062884005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 139}], {
             RGBColor[
             0.5826390838232848, 0.6720516816961779, 0.9602866294373078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 140}], {
             RGBColor[
             0.550438526060826, 0.6459098182860178, 0.9577516835757175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 169}], {
             RGBColor[
             0.5469925860365322, 0.6431122489364671, 0.9574804065541109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 175}], {
             RGBColor[
             0.7784866261079177, 0.8268297266210345, 0.9607862455954495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 204}], {
             RGBColor[
             0.5515680195619116, 0.6468267919933015, 0.9578406014415939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 219}], {
             RGBColor[
             0.5637559435916646, 0.6567214977803754, 0.9588000794670529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 255}], {
             RGBColor[
             0.499414256811589, 0.6029727505529885, 0.9541529864670097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 274}], {
             RGBColor[
             0.5319886243671207, 0.6309313569324684, 0.9562992397301722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 334}], {
             RGBColor[
             0.5020235331688498, 0.6052327745876049, 0.9543192472492019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 337}], {
             RGBColor[
             0.730726843956438, 0.7892639238928545, 0.9741400277373693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 361}], {
             RGBColor[
             0.622722217665552, 0.7045647515271736, 0.9634614174292722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 363}], {
             RGBColor[
             0.5030271726289528, 0.6061020766435601, 0.9543831982681161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 369}], {
             RGBColor[
             0.5105952058083258, 0.6126571266031253, 0.9548654266501568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 370}], {
             RGBColor[
             0.5963431626815656, 0.6831772702750474, 0.9613654647247267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 466}], {
             RGBColor[
             0.552375580457491, 0.6474824063085367, 0.957904175593487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 118}], {
             RGBColor[
             0.3201099243225116, 0.4516848600807156, 0.9416180992091068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 141}], {
             RGBColor[
             0.3123473120692484, 0.44496127550717535`, 0.9411234724205373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 188}], {
             RGBColor[
             0.32619444448890195`, 0.45695496563196736`, 0.9420057994537792]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 220}], {
             RGBColor[
             0.32701247471585293`, 0.45766350229915764`, 0.9420579236164848]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 240}], {
             RGBColor[
             0.2858686487739417, 0.41720789684373627`, 0.9396127186286245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 304}], {
             RGBColor[
             0.3268378953241502, 0.4575122904046801, 0.94204679957202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 310}], {
             RGBColor[
             0.3059344073310527, 0.43829828132983367`, 0.9407554338938223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 371}], {
             RGBColor[
             0.3390278312734188, 0.4680706002399412, 0.9428235315115703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 382}], {
             RGBColor[
             0.2986682199237062, 0.43066105766182183`, 0.9403416352703349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 429}], {
             RGBColor[
             0.3043548555603097, 0.4366380722694161, 0.9406654807572159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 74}], {
             RGBColor[
             0.26196255890659237`, 0.3926696371693413, 0.9382297522396293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 82}], {
             RGBColor[
             0.25023486400687867`, 0.3803430862509384, 0.9375618773646605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 105}], {
             RGBColor[
             0.2440481876886619, 0.3738404971825583, 0.9372095553007055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 153}], {
             RGBColor[
             0.24356203444566857`, 0.3733295193002764, 0.9371818695927163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 195}], {
             RGBColor[
             0.2561715150223729, 0.3865828828736374, 0.9378999608575047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 263}], {
             RGBColor[
             0.25779587834217144`, 0.38829019171332857`, 0.9379924659455371]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 323}], {
             RGBColor[
             0.24076788547771533`, 0.3703926915756808, 0.9370227469425643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 342}], {
             RGBColor[
             0.25108912406320616`, 0.3812409677333546, 0.9376105262111039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 395}], {
             RGBColor[
             0.2535893388235434, 0.38386885196924064`, 0.9377529097429688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 447}], {
             RGBColor[
             0.2443455259866942, 0.3741530185861272, 0.9372264882769058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 453}], {
             RGBColor[
             0.26324896867774317`, 0.3940217354019111, 0.9383030113730237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 463}], {
             RGBColor[
             0.2546442329532448, 0.38497761258370766`, 0.9378129844030793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 116}], {
             RGBColor[
             0.27071777339856856`, 0.4018719227130688, 0.9387283487527682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 118}], {
             RGBColor[
             0.30890885152103453`, 0.4405003788871604, 0.9409586647466246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 133}], {
             RGBColor[
             0.31894163191943015`, 0.44919026900604586`, 0.9415979446419711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 151}], {
             RGBColor[
             0.2997519610227203, 0.4323886947798715, 0.9403818027857322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 188}], {
             RGBColor[
             0.31499337168742486`, 0.44577048443841216`, 0.9413463649912971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 192}], {
             RGBColor[
             0.2736621188386635, 0.4049666164528918, 0.9388960248698129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 249}], {
             RGBColor[
             0.29112873348308044`, 0.42332513589150556`, 0.9398907227342717]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 260}], {
             RGBColor[
             0.2891430137819674, 0.4212380185837349, 0.9397776389349024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 280}], {
             RGBColor[
             0.2748009878347767, 0.4061636399762716, 0.9389608817743358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 310}], {
             RGBColor[
             0.2947333345295756, 0.4271138001362785, 0.9400959994313403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 327}], {
             RGBColor[
             0.27488937913222444`, 0.40625654483422113`, 0.9389659155279624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 483}], {
             RGBColor[
             0.29467938491288026`, 0.4270570956685284, 0.9400929270804808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 64}], {
             RGBColor[
             0.3058305702683475, 0.43738338551197825`, 0.9407790232185906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 91}], {
             RGBColor[
             0.32572776888358806`, 0.4565507546784424, 0.9419760632968737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 172}], {
             RGBColor[
             0.3377395733706075, 0.4669547759942509, 0.9427414448571648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 303}], {
             RGBColor[
             0.31454260624684305`, 0.4465402877003618, 0.9412751607792637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 362}], {
             RGBColor[
             0.3561441161626767, 0.48289586592152384`, 0.9439141660493773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 384}], {
             RGBColor[
             0.3038237458344487, 0.43527408579193255`, 0.9406647375359107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 435}], {
             RGBColor[
             0.2909721876561818, 0.42176628331072286`, 0.9399328603098349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 473}], {
             RGBColor[
             0.3253289757704718, 0.4562053401277858, 0.9419506525523447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 132}], {
             RGBColor[
             0.9037259559281465, 0.5621573598635239, 0.4887023579770914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 209}], {
             RGBColor[
             0.6916212861064526, 0.39630413817282756`, 0.5615943615662011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 233}], {
             RGBColor[
             0.8302393984490122, 0.2334388442338099, 0.17659058814627704`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 75}], {
             RGBColor[
             0.38214205273411095`, 0.5054139718854141, 0.9455707315786365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 149}], {
             RGBColor[
             0.3866051837093468, 0.5092797116126782, 0.9458551183377868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 158}], {
             RGBColor[
             0.38842846253649266`, 0.5108589440920934, 0.9459712960523903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 165}], {
             RGBColor[
             0.42168442508772075`, 0.5396635873606885, 0.9480903365790616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 182}], {
             RGBColor[
             0.3989611276124065, 0.5199818091937107, 0.9466424281573576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 206}], {
             RGBColor[
             0.3810348762200533, 0.5044549912372471, 0.9455001832701985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 252}], {
             RGBColor[
             0.5775658026497799, 0.6655789256820774, 0.9611207995905398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 275}], {
             RGBColor[
             0.41651977831287657`, 0.5351902299070133, 0.9477612498534863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 282}], {
             RGBColor[
             0.5134969921724348, 0.6149963149023026, 0.9550984560118821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 324}], {
             RGBColor[
             0.3945065223315428, 0.5161234539943981, 0.9463585846479137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 410}], {
             RGBColor[
             0.39150030357105375`, 0.5135196184010107, 0.9461670310467902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 441}], {
             RGBColor[
             0.4347339982883702, 0.5509664717764713, 0.9489218438441225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 467}], {
             RGBColor[
             0.563087381667329, 0.6542682731705118, 0.9596777258955458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 91}], {
             RGBColor[
             0.3077316474117898, 0.43903000298271255`, 0.9409001581731142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 172}], {
             RGBColor[
             0.31974345189880926`, 0.449434024298521, 0.9416655397334055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 303}], {
             RGBColor[
             0.29654648477504475`, 0.4290195360046319, 0.9401992556555043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 366}], {
             RGBColor[
             0.27642037277284975`, 0.4078657162211217, 0.9390531033508938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 384}], {
             RGBColor[
             0.28582762436265047`, 0.41775333409620263`, 0.9395888324121513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 435}], {
             RGBColor[
             0.2729760661843835, 0.4042455316149929, 0.9388569551860756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 473}], {
             RGBColor[
             0.3073328542986736, 0.43868458843205593`, 0.9408747474285853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 88}], {
             RGBColor[
             0.9260374771709088, 0.7249105779401631, 0.30422129427437533`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 166}], {
             RGBColor[
             0.9117926198146232, 0.6283236796935395, 0.2910857426521841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 167}], {
             RGBColor[
             0.986067541242265, 0.9756937071602725, 0.6343029674871418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 175}], {
             RGBColor[
             0.9705975460870158, 0.9645679382577699, 0.6789276620320353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[
             0.9107642708804349, 0.6204193391599911, 0.29010099455145133`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 227}], {
             RGBColor[
             0.9155479974276244, 0.657189157644029, 0.2946818964954864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 309}], {
             RGBColor[
             0.9892477963467572, 0.9750667140916796, 0.4404269945442838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 320}], {
             RGBColor[
             0.9870336626851595, 0.9760932232050978, 0.618291834936235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 337}], {
             RGBColor[
             0.9228377639355362, 0.92700213552959, 0.6922814441739551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 348}], {
             RGBColor[
             0.9726882187211612, 0.9195330900145834, 0.3483993164391773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 428}], {
             RGBColor[
             0.9078991618741388, 0.5983968558388272, 0.2873573629313444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 434}], {
             RGBColor[
             0.9883337030612244, 0.9766308233101144, 0.5967468015081936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 474}], {
             RGBColor[
             0.989280991001634, 0.9770225512176633, 0.5810477888330006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 495}], {
             RGBColor[
             0.9138336495538494, 0.6440119286541663, 0.2930402350354805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 208}], {
             RGBColor[
             0.2926997987840062, 0.4237400438284219, 0.9400254625551399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 305}], {
             RGBColor[
             0.25719647261268064`, 0.38766017828711546`, 0.9379583306759838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 314}], {
             RGBColor[
             0.29667827269945046`, 0.4271859979700665, 0.9402789673950056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 394}], {
             RGBColor[
             0.24596177604056546`, 0.3758517998689181, 0.937318531326446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 398}], {
             RGBColor[
             0.26221606410223275`, 0.392936087203117, 0.9382441889854937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 427}], {
             RGBColor[
             0.271390600085227, 0.40257910622042264`, 0.9387666652372155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 445}], {
             RGBColor[
             0.24646019520379875`, 0.3763756700110764, 0.9373469155604471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 460}], {
             RGBColor[
             0.2558136629427209, 0.38620675764879087`, 0.9378795817109632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 472}], {
             RGBColor[
             0.29586389462338253`, 0.42648062461240877`, 0.9402270759441249]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 70}], {
             RGBColor[
             0.25743661729140077`, 0.3879125855705024, 0.9379720065601748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 96}], {
             RGBColor[
             0.2763924027630132, 0.4078363179673825, 0.9390515105002115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 131}], {
             RGBColor[
             0.2601160605037315, 0.39072885027317383`, 0.938124596887236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 135}], {
             RGBColor[
             0.2536249197696536, 0.3839062497995648, 0.9377549360252124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 147}], {
             RGBColor[
             0.2540581203038455, 0.3843615710275007, 0.9377796061547718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 171}], {
             RGBColor[
             0.25918264815811415`, 0.38974777471616917`, 0.9380714404350129]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 180}], {
             RGBColor[
             0.26337700695553745`, 0.3941563117499686, 0.9383103029635284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 216}], {
             RGBColor[
             0.26125452628926693`, 0.3919254499966715, 0.938189430829513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 238}], {
             RGBColor[
             0.28838849579729153`, 0.41939023215024707`, 0.9397732894571003]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 281}], {
             RGBColor[
             0.25076586641156884`, 0.38090120344576484`, 0.93759211716606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 343}], {
             RGBColor[
             0.2747552896997584, 0.40611560833893834`, 0.9389582793331509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 385}], {
             RGBColor[
             0.24504732911062774`, 0.37489065816626943`, 0.9372664549265891]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 391}], {
             RGBColor[
             0.24887514925956578`, 0.37891393984061833`, 0.9374844436213188]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 465}], {
             RGBColor[
             0.26962432665641767`, 0.4007226408585406, 0.9386660785784122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 205}], {
             RGBColor[
             0.9069065109079608, 0.5719171126049378, 0.3681050087560027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 257}], {
             RGBColor[
             0.8394199460541523, 0.30329924422110266`, 0.18535427265779897`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 272}], {
             RGBColor[
             0.8202846954174998, 0.15692263455492186`, 0.1670579532810717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 306}], {
             RGBColor[
             0.8387829864974263, 0.2991086057980758, 0.18477193771004097`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 317}], {
             RGBColor[
             0.8516933912786147, 0.35903009244942585`, 0.19559553620276254`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 142}], {
             RGBColor[
             0.8044934065793106, 0.8479188521576653, 0.9809561216743297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 173}], {
             RGBColor[
             0.9470127321552729, 0.9592645667466908, 0.9483609186014075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 194}], {
             RGBColor[
             0.9479892988678673, 0.9596684021789683, 0.9321766809000795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 241}], {
             RGBColor[
             0.8074723242442312, 0.8502460052781141, 0.9812530323476005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 388}], {
             RGBColor[
             0.9278173046721767, 0.9450102776472538, 0.9836136557859578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 402}], {
             RGBColor[
             0.7308868707375382, 0.7890374499881754, 0.9745628249690335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 461}], {
             RGBColor[
             0.926959006974305, 0.9443701606295145, 0.985066529908563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 487}], {
             RGBColor[
             0.7444469428218465, 0.8000461273805028, 0.9756303235156909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 490}], {
             RGBColor[
             0.9500080335378767, 0.9605032008441318, 0.8987210231001681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 84}], {
             RGBColor[
             0.24578222839824324`, 0.37566308391285935`, 0.9373083063538328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 96}], {
             RGBColor[
             0.2772059489257, 0.4086914065661722, 0.9390978407506428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 131}], {
             RGBColor[
             0.2609296066664183, 0.3915839388719636, 0.9381709271376673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 135}], {
             RGBColor[
             0.25443846593234043`, 0.3847613383983545, 0.9378012662756438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 147}], {
             RGBColor[
             0.2548716664665323, 0.3852166596262904, 0.9378259364052033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 170}], {
             RGBColor[
             0.2774653661360603, 0.408964070502262, 0.9391126141769994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 171}], {
             RGBColor[
             0.25999619432080096`, 0.39060286331495886`, 0.9381177706854442]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 216}], {
             RGBColor[
             0.26206807245195374`, 0.39278053859546125`, 0.9382357610799443]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[
             0.28920204195997834`, 0.42024532074903687`, 0.9398196197075317]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 265}], {
             RGBColor[
             0.28963233444531233`, 0.42061801847270397`, 0.9398470375642044]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 374}], {
             RGBColor[
             0.2549902427614091, 0.38534129083037727`, 0.9378326891497786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 385}], {
             RGBColor[
             0.24586087527331454`, 0.37574574676505923`, 0.9373127851770204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 391}], {
             RGBColor[
             0.24968869542225258`, 0.3797690284394081, 0.93753077387175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 433}], {
             RGBColor[
             0.2918782074405654, 0.4225632807803333, 0.9399901426055144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 194}], {
             RGBColor[
             0.8711488139703549, 0.898916809896938, 0.9247098602219754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 228}], {
             RGBColor[
             0.8744314209010298, 0.8983757407693698, 0.7323068273714743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 388}], {
             RGBColor[
             0.8509768197746642, 0.8842586853652235, 0.9761468351078537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 431}], {
             RGBColor[
             0.602160734252356, 0.6860330125252593, 0.9630472221226452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 462}], {
             RGBColor[
             0.6098299518680684, 0.6923889646800596, 0.9636151246385223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 487}], {
             RGBColor[
             0.6676064579243342, 0.7392945350984725, 0.9681635028375868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 490}], {
             RGBColor[
             0.8731675486403643, 0.8997516085621015, 0.891254202422064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 73}], {
             RGBColor[
             0.2509474629421924, 0.38109207291333524`, 0.9376024588198308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 144}], {
             RGBColor[
             0.2501061102631632, 0.3802077579028347, 0.93755454502943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 163}], {
             RGBColor[
             0.26048838412385666`, 0.3911201860046064, 0.9381458001665987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 187}], {
             RGBColor[
             0.2593062768219157, 0.38987771628033463`, 0.9380784809045242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 279}], {
             RGBColor[
             0.26627234056032795`, 0.3971994909433567, 0.9384751879290589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 322}], {
             RGBColor[
             0.25660150329804876`, 0.38703482781420406`, 0.9379244480536938]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 494}], {
             RGBColor[
             0.25624399533436604`, 0.3866590642770594, 0.9379040885040477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 93}], {
             RGBColor[
             0.2585978739086303, 0.3891331399031328, 0.9380381384066008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 163}], {
             RGBColor[
             0.2574513896017804, 0.3879281122053299, 0.9379728478213971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 187}], {
             RGBColor[
             0.25626928229983936`, 0.38668564248105813`, 0.9379055285593227]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 322}], {
             RGBColor[
             0.2535645087759725, 0.3838427540149276, 0.9377514957084923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 494}], {
             RGBColor[
             0.25320700081228975`, 0.383466990477783, 0.9377311361588463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 82}], {
             RGBColor[
             0.27000631808527487`, 0.401124138069925, 0.93868783242518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 105}], {
             RGBColor[
             0.2638196417670582, 0.3946215490015449, 0.938335510361225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 112}], {
             RGBColor[
             0.264998769293781, 0.3958608867931338, 0.938402659929509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 153}], {
             RGBColor[
             0.2633334885240648, 0.39411057111926295`, 0.9383078246532357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 195}], {
             RGBColor[
             0.27594296910076915`, 0.40736393469262394`, 0.9390259159180243]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 224}], {
             RGBColor[
             0.2903501525391211, 0.42250679795452123`, 0.9398463837013205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 234}], {
             RGBColor[
             0.335156328175214, 0.4622198560830736, 0.94266828637108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 239}], {
             RGBColor[
             0.31633226480045645`, 0.4459153985127936, 0.9414688336983061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 263}], {
             RGBColor[
             0.27756733242056764`, 0.40907124353231517`, 0.9391184210060566]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 296}], {
             RGBColor[
             0.2975769167094639, 0.42967045866758025`, 0.9402737595026511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 342}], {
             RGBColor[
             0.27086057814160247`, 0.4020220195523411, 0.9387364812716233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 395}], {
             RGBColor[
             0.2733607929019397, 0.4046499037882272, 0.9388788648034883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 440}], {
             RGBColor[
             0.2817039259800564, 0.4134190656385177, 0.9393539938897277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 447}], {
             RGBColor[
             0.26411698006509043`, 0.39493407040511375`, 0.9383524433374253]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 453}], {
             RGBColor[
             0.2830204227561394, 0.41480278722089764`, 0.9394289664335431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 463}], {
             RGBColor[
             0.2744156870316411, 0.4057586644026942, 0.9389389394635987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 93}], {
             RGBColor[
             0.30711689507265494`, 0.43678253795558514`, 0.940923781155411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 108}], {
             RGBColor[
             0.31502960292460824`, 0.4450992956026424, 0.9413743981617775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 149}], {
             RGBColor[
             0.3494116417234011, 0.4770645349462275, 0.9434851787314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 158}], {
             RGBColor[
             0.3512349205505469, 0.4786437674256428, 0.9436013564460036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.3059704107658049, 0.43557751025778224`, 0.9408584905702073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 182}], {
             RGBColor[
             0.3617675856264607, 0.48776663252726005`, 0.9442724885509708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 206}], {
             RGBColor[
             0.34384133423410757`, 0.4722398145707964, 0.9431302436638118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 410}], {
             RGBColor[
             0.354306761585108, 0.48130444173456, 0.9437970914404035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.3537435180123586, 0.4796530871235497, 0.9438038035415315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[
             0.35693445553108405`, 0.4830069647728541, 0.9439855227126539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 238}], {
             RGBColor[
             0.36573961104663694`, 0.49120700130641426`, 0.9445255824984202]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 333}], {
             RGBColor[
             0.3949872182942583, 0.5165398086768207, 0.9463892141695951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 343}], {
             RGBColor[
             0.3521064049491038, 0.47793237749510553`, 0.9437105723744709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 392}], {
             RGBColor[
             0.35866334703698777`, 0.48482413936361163`, 0.9440839805262493]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 402}], {
             RGBColor[
             0.4818182674522101, 0.589060600826333, 0.952664686170056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 431}], {
             RGBColor[
             0.42993261586454035`, 0.5468077556454473, 0.9486159040017718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 436}], {
             RGBColor[
             0.4421225577048329, 0.5568338353820671, 0.9495396944885663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 459}], {
             RGBColor[
             0.40093570974009674`, 0.5216920929873327, 0.9467682467844796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 462}], {
             RGBColor[
             0.4376018334802528, 0.5531637078002476, 0.949183806517649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 487}], {
             RGBColor[
             0.49537833953651855`, 0.6000692782186605, 0.9537321847167134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 81}], {
             RGBColor[
             0.7152180111578499, 0.7769379420233913, 0.972614350327299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 156}], {
             RGBColor[
             0.5370635204917655, 0.6350513862279201, 0.9566987541430614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 278}], {
             RGBColor[
             0.7775908081460805, 0.8263457284855322, 0.9672404849556133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 329}], {
             RGBColor[
             0.7446878798780471, 0.8004364154026, 0.9754252127138938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 479}], {
             RGBColor[
             0.5091542746403608, 0.6112576931750507, 0.9548154361242309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 482}], {
             RGBColor[
             0.4826496570055525, 0.5883007255405965, 0.9531265853256541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 85}], {
             RGBColor[
             0.21682232686548605`, 0.34522439123812265`, 0.9356590828038773]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 95}], {
             RGBColor[
             0.22325600943798377`, 0.3519865995408531, 0.9360254715086005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 97}], {
             RGBColor[
             0.22558180327383132`, 0.35443115632617517`, 0.9361579220268484]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 137}], {
             RGBColor[
             0.21975482034818994`, 0.34830662781927, 0.9358260839694819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 145}], {
             RGBColor[
             0.22004363289237822`, 0.3486101881149849, 0.9358425314166136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 183}], {
             RGBColor[
             0.21219822021020854`, 0.34036416195813046`, 0.935395746770612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 346}], {
             RGBColor[
             0.21865587786091514`, 0.34715156958816623`, 0.9357635008205714]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 358}], {
             RGBColor[
             0.22252765585105994`, 0.3512210537407115, 0.9359839928493279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 404}], {
             RGBColor[
             0.2164387033219317, 0.3448211785707095, 0.935637236010592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 407}], {
             RGBColor[
             0.21689372054729342`, 0.34529943052432305`, 0.9356631485684387]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 408}], {
             RGBColor[
             0.22096681623691122`, 0.34958051234329385`, 0.9358951053423573]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 430}], {
             RGBColor[
             0.22958406238534357`, 0.3586377844102586, 0.9363858447624374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 81}], {
             RGBColor[
             0.9087234308797807, 0.9257016701540246, 0.7763552620147077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 99}], {
             RGBColor[
             0.9937251243023482, 0.9889870003070016, 0.5583966882336657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 122}], {
             RGBColor[
             0.9306665098261713, 0.7402291937878942, 0.3904132893585251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 267}], {
             RGBColor[
             0.9914456607402118, 0.9819881575780944, 0.49084130836277423`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 278}], {
             RGBColor[
             0.9710962278680113, 0.9751094566161655, 0.770981396643022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 329}], {
             RGBColor[
             0.9381932995999778, 0.9492001435332333, 0.7791661244013025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 406}], {
             RGBColor[
             0.9922235479450122, 0.984612153776488, 0.4938632532617516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 413}], {
             RGBColor[
             0.9838323701759427, 0.9563067408191819, 0.46126511216987476`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 476}], {
             RGBColor[
             0.9211605712027758, 0.6814740968415736, 0.3818708025801312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 486}], {
             RGBColor[
             0.9643781566417168, 0.9700792377693064, 0.7816636594414414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 493}], {
             RGBColor[
             0.9937029879453217, 0.9889396528776512, 0.5559872823811043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 156}], {
             RGBColor[
             0.6284260394446897, 0.7069689251123001, 0.9654326763878454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 278}], {
             RGBColor[
             0.8689533270990046, 0.8982632673699124, 0.9759744072003973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 307}], {
             RGBColor[
             0.6296762406643908, 0.7079838947833768, 0.9655310968074982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 329}], {
             RGBColor[
             0.8360503988309712, 0.8723539542869803, 0.9841591349586778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 372}], {
             RGBColor[
             0.6299979927875134, 0.7082451076516956, 0.9655564263132472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 406}], {
             RGBColor[
             0.8900806471760057, 0.9077659645302347, 0.6988562638191269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 417}], {
             RGBColor[
             0.7452877880838611, 0.8009437515388753, 0.9752469796719869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 461}], {
             RGBColor[
             0.8669992096038857, 0.8968058897416262, 0.9792822184041656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 486}], {
             RGBColor[
             0.8622352558727102, 0.8932330485230531, 0.9866566699988166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 493}], {
             RGBColor[
             0.8915600871763152, 0.912093463631398, 0.7609802929384797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 83}], {
             RGBColor[
             0.8721819244967113, 0.9009182081187621, 0.9876706846361336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 99}], {
             RGBColor[
             0.9086198401868935, 0.9254801001365643, 0.7650800543815806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 237}], {
             RGBColor[
             0.8648552697662895, 0.8950761325134684, 0.9869718617673642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[
             0.906340376624757, 0.9184812574076573, 0.6975246745106891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 278}], {
             RGBColor[
             0.8859909437525565, 0.9116025564457284, 0.9776647627909368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 329}], {
             RGBColor[
             0.8530880154845231, 0.8856932433627962, 0.9858494905492173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 426}], {
             RGBColor[
             0.8468962698264015, 0.8807561134454687, 0.9852589163209091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 486}], {
             RGBColor[
             0.879272872526262, 0.9065723375988691, 0.9883470255893563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 89}], {
             RGBColor[
             0.2718901700216876, 0.4031041858982062, 0.9387951150060494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 105}], {
             RGBColor[
             0.25209194686734443`, 0.382294998083142, 0.9376676354862561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 184}], {
             RGBColor[
             0.2576552479933815, 0.38814238030027126`, 0.9379844572552174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 195}], {
             RGBColor[
             0.2642152742010554, 0.39503738377422104`, 0.9383580410430554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 225}], {
             RGBColor[
             0.2662639580467382, 0.39719068039009175`, 0.9384747105573108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 263}], {
             RGBColor[
             0.26583963752085393`, 0.39674469261391226`, 0.9384505461310877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 296}], {
             RGBColor[
             0.28584922180975014`, 0.4173439077491774, 0.9396058846276822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 342}], {
             RGBColor[
             0.2591328832418887, 0.3896954686339382, 0.9380686063966545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 395}], {
             RGBColor[
             0.26163309800222595`, 0.39232335286982434`, 0.9382109899285194]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 440}], {
             RGBColor[
             0.26997623108034263`, 0.40109251472011487`, 0.9386861190147588]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 447}], {
             RGBColor[
             0.25238928516537673`, 0.3826075194867109, 0.9376845684624564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 453}], {
             RGBColor[
             0.27129272785642566`, 0.40247623630249474`, 0.9387610915585742]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 463}], {
             RGBColor[
             0.26268799213192734`, 0.3934321134842913, 0.9382710645886299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 470}], {
             RGBColor[
             0.25688036525862096`, 0.38732792941563493`, 0.937940328829809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 119}], {
             RGBColor[
             0.9556965383033635, 0.9650210547273206, 0.8984817408494732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 176}], {
             RGBColor[
             0.7638451540938651, 0.8157128228854424, 0.9772513951417543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[
             0.8091856625186589, 0.8516756760168047, 0.981399600787607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 237}], {
             RGBColor[
             0.913419047498675, 0.933799570648643, 0.9916039182408752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 270}], {
             RGBColor[
             0.955384395176871, 0.9648919755228036, 0.9036547602559704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 345}], {
             RGBColor[
             0.7902354483667869, 0.8368716246944006, 0.9795108205407682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 375}], {
             RGBColor[
             0.9394735703012015, 0.9539944639741937, 0.9739704912597569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 426}], {
             RGBColor[
             0.895460047558787, 0.9194795515806435, 0.9898909727944203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 448}], {
             RGBColor[
             0.7443425082604527, 0.7998796964136958, 0.9757160754212024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 489}], {
             RGBColor[
             0.9554216482771469, 0.9649073806371287, 0.9030373799764648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 131}], {
             RGBColor[
             0.24846167161057395`, 0.3784793486155308, 0.9374608966808939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 135}], {
             RGBColor[
             0.24197053087649611`, 0.37165674814192173`, 0.9370912358188704]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 147}], {
             RGBColor[
             0.24240373141068797`, 0.37211206936985763`, 0.93711590594843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 171}], {
             RGBColor[
             0.2475282592649566, 0.3774982730585261, 0.9374077402286709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 230}], {
             RGBColor[
             0.22859615804425376`, 0.3575994343110202, 0.9363295850716857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 242}], {
             RGBColor[
             0.22916096004104347`, 0.3581930770201611, 0.9363617497098533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 365}], {
             RGBColor[
             0.22514447908377305`, 0.3539715008744688, 0.9361330170611878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 374}], {
             RGBColor[
             0.24252230770556474`, 0.3722367005739444, 0.9371226586930053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 385}], {
             RGBColor[
             0.2333929402174702, 0.3626411565086264, 0.9366027547202471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 391}], {
             RGBColor[
             0.23722076036640824`, 0.3666644381829753, 0.9368207434149767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 95}], {
             RGBColor[
             0.22064923730827996`, 0.3492467167536353, 0.9358770196921877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 97}], {
             RGBColor[
             0.22297503114412753`, 0.3516912735389574, 0.9360094702104356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 137}], {
             RGBColor[
             0.21714804821848613`, 0.34556674503205226`, 0.9356776321530691]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 145}], {
             RGBColor[
             0.21743686076267443`, 0.3458703053277671, 0.9356940796002007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 183}], {
             RGBColor[
             0.20959144808050473`, 0.33762427917091264`, 0.9352472949541991]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 286}], {
             RGBColor[
             0.21865790979829205`, 0.3471537052831816, 0.935763616536399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 346}], {
             RGBColor[
             0.21604910573121133`, 0.34441168680094847`, 0.9356150490041585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 358}], {
             RGBColor[
             0.2199208837213561, 0.34848117095349374`, 0.935835541032915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 404}], {
             RGBColor[
             0.21383193119222793`, 0.3420812957834917, 0.9354887841941792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 407}], {
             RGBColor[
             0.2142869484175896, 0.3425595477371053, 0.9355146967520258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 408}], {
             RGBColor[
             0.21836004410720744`, 0.3468406295560761, 0.9357466535259444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 90}], {
             RGBColor[
             0.8899814344584336, 0.5901544331035902, 0.2297467504579272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 98}], {
             RGBColor[
             0.9552139147274563, 0.8468459050338089, 0.4866646892725739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 115}], {
             RGBColor[
             0.9181807358610004, 0.8207272885954675, 0.6214818156174652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 124}], {
             RGBColor[
             0.9389228207101663, 0.7935781606519255, 0.2800166062249653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 136}], {
             RGBColor[
             0.942076876818933, 0.8389236960734718, 0.594023128493258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 168}], {
             RGBColor[
             0.912992655814064, 0.6927519043211215, 0.24885005242438252`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[
             0.9534388639235, 0.8461526483552239, 0.5190456011559075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 253}], {
             RGBColor[
             0.9501124692155603, 0.8447770986590462, 0.5741725699000219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 261}], {
             RGBColor[
             0.897589954080166, 0.6247029436909717, 0.23609548573218275`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 357}], {
             RGBColor[
             0.911167687629582, 0.6855165136042474, 0.2473816401856394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 484}], {
             RGBColor[
             0.9540423951293819, 0.8443401430723285, 0.3591520108030784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 500}], {
             RGBColor[
             0.8673428769617186, 0.42615530998421236`, 0.20846003809980468`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 107}], {
             RGBColor[
             0.1819624771956669, 0.3085844789930161, 0.9336738659357071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 113}], {
             RGBColor[
             0.17922276129889142`, 0.3057048638774843, 0.9335178431684322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 143}], {
             RGBColor[
             0.1790901316250143, 0.30556546168103244`, 0.933510290104713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 226}], {
             RGBColor[
             0.17933912709972993`, 0.30582717171218354`, 0.9335244700286423]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 292}], {
             RGBColor[
             0.1791119470402912, 0.3055883910656657, 0.93351153246034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 308}], {
             RGBColor[
             0.17909977333492821`, 0.3055755957294717, 0.9335108391858289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 386}], {
             RGBColor[
             0.17909013095112286`, 0.3055654609727298, 0.9335102900663359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 421}], {
             RGBColor[
             0.17915493384170816`, 0.30563357291947557`, 0.9335139804950874]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 422}], {
             RGBColor[
             0.2066326331143824, 0.33451437704181397`, 0.9350787948190529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 423}], {
             RGBColor[
             0.18353957668712906`, 0.310242110552426, 0.9337636794186364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 446}], {
             RGBColor[
             0.20370226760912918`, 0.33143437709988877`, 0.934911914838616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 166}], {
             RGBColor[
             0.8523652692557177, 0.3906026653424749, 0.19727300714892185`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 167}], {
             RGBColor[
             0.9266401906833595, 0.7379726928092079, 0.5404902319838795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 210}], {
             RGBColor[
             0.8513369203215293, 0.3826983248089265, 0.19628825904818903`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 227}], {
             RGBColor[
             0.8561206468687188, 0.41946814329296433`, 0.20086916099222407`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 243}], {
             RGBColor[
             0.8529581179820884, 0.3951595604413297, 0.19784071975882145`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 326}], {
             RGBColor[
             0.8708928189630238, 0.5066362693068722, 0.21398214224720047`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 348}], {
             RGBColor[
             0.9132608681622556, 0.6818120756635188, 0.2545865809359151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 428}], {
             RGBColor[
             0.8484718113152332, 0.36067584148776255`, 0.1935446274280821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 434}], {
             RGBColor[
             0.9289063525023188, 0.7389098089590498, 0.5029340660049313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 469}], {
             RGBColor[
             0.8635204022958338, 0.47315984709282155`, 0.20783041706562805`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 474}], {
             RGBColor[
             0.9298536404427284, 0.7393015368665987, 0.48723505332973827`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 495}], {
             RGBColor[
             0.8544062989949438, 0.4062909143031017, 0.1992274995322182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 133}], {
             RGBColor[
             0.3153376912434113, 0.4454022988525135, 0.9413927055520241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 184}], {
             RGBColor[
             0.271266794829508, 0.4024489790469554, 0.9387596147110557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 192}], {
             RGBColor[
             0.27005817816264466`, 0.4011786462993594, 0.9386907857798661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 225}], {
             RGBColor[
             0.2798755048828646, 0.4114972791367759, 0.9392498680131491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 235}], {
             RGBColor[
             0.32127172035398965`, 0.45054205661512126`, 0.9417708166396943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 239}], {
             RGBColor[
             0.31821611673686917`, 0.4478954463410748, 0.9415761162791756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 249}], {
             RGBColor[
             0.28752479280706156`, 0.41953716573797317`, 0.9396854836443249]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 260}], {
             RGBColor[
             0.2855390731059485, 0.4174500484302025, 0.9395723998449554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.2711970471587578, 0.4023756698227392, 0.938755642684389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 296}], {
             RGBColor[
             0.2994607686458766, 0.4316505064958615, 0.9403810420835206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 424}], {
             RGBColor[
             0.3030480744366626, 0.4347576504686087, 0.9406096220363795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 440}], {
             RGBColor[
             0.2835877779164691, 0.415399113466799, 0.9394612764705972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 453}], {
             RGBColor[
             0.28490427469255214`, 0.4167828350491789, 0.9395362490144127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 470}], {
             RGBColor[
             0.27049191209474743`, 0.40163452816231904`, 0.9387154862856475]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 124}], {
             RGBColor[
             0.9137111635376958, 0.6822566946723914, 0.2591427819494134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 178}], {
             RGBColor[
             0.9282272067510295, 0.7348311823756897, 0.4981717768803556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[
             0.8618116052496472, 0.4654005988057779, 0.20640455492384144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 261}], {
             RGBColor[
             0.8723782969076955, 0.5133814777114375, 0.21522166145663085`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 272}], {
             RGBColor[
             0.8426763546129947, 0.3190239891395971, 0.18810823554711417`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 306}], {
             RGBColor[
             0.8611746456929213, 0.4612099603827511, 0.20582221997608346`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 317}], {
             RGBColor[
             0.8740850504741097, 0.5211314470341011, 0.21664581846880504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 357}], {
             RGBColor[
             0.8859560304571115, 0.5741950476247133, 0.2265078159100875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 172}], {
             RGBColor[
             0.33964065051404985`, 0.4686013934649852, 0.9428625798116885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 303}], {
             RGBColor[
             0.3164436833902854, 0.44818690517109605`, 0.9413962957337874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 366}], {
             RGBColor[
             0.29631757138809034`, 0.4270330853875859, 0.9402501434291768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 435}], {
             RGBColor[
             0.29287326479962417`, 0.4234129007814571, 0.9400539952643586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 473}], {
             RGBColor[
             0.32723005291391416`, 0.4578519575985201, 0.9420717875068684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 101}], {
             RGBColor[
             0.5649851581111299, 0.6577194295027604, 0.9588968477367864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 128}], {
             RGBColor[
             0.5519404005403256, 0.6471291076471498, 0.9578699166362912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 140}], {
             RGBColor[
             0.554385826473297, 0.649114414584719, 0.9580624295236251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 169}], {
             RGBColor[
             0.5509398864490034, 0.6463168452351683, 0.9577911525020184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 175}], {
             RGBColor[
             0.7824339265203888, 0.8300343229197356, 0.9610969915433571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 204}], {
             RGBColor[
             0.5555153199743827, 0.6500313882920026, 0.9581513473895016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 219}], {
             RGBColor[
             0.5677032440041356, 0.6599260940790765, 0.9591108254149605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 274}], {
             RGBColor[
             0.5359359247795917, 0.6341359532311694, 0.9566099856780799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 320}], {
             RGBColor[
             0.7988700431185324, 0.8415596078670635, 0.9004611644475569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 334}], {
             RGBColor[
             0.505970833581321, 0.6084373708863062, 0.9546299931971096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 337}], {
             RGBColor[
             0.7346741443689091, 0.7924685201915558, 0.974450773685277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 361}], {
             RGBColor[
             0.6266695180780231, 0.7077693478258749, 0.9637721633771799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 363}], {
             RGBColor[
             0.506974473041424, 0.6093066729422614, 0.9546939442160238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 370}], {
             RGBColor[
             0.6002904630940367, 0.6863818665737486, 0.9616762106726342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 498}], {
             RGBColor[
             0.5355135500520953, 0.6337930503996233, 0.9565767347923217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 108}], {
             RGBColor[
             0.27719798724909794`, 0.408683038339264, 0.9390973873449386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 163}], {
             RGBColor[
             0.26813879509029465`, 0.39916125299440397`, 0.9385814797533685]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 187}], {
             RGBColor[
             0.2669566877883537, 0.3979187832701322, 0.9385141604912941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 189}], {
             RGBColor[
             0.26453032177670965`, 0.3953685187514038, 0.9383759825364177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 206}], {
             RGBColor[
             0.30600971855859727`, 0.43582355730741806`, 0.940853232846973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 266}], {
             RGBColor[
             0.2794030113306438, 0.41100065845557043`, 0.9392229602043418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 322}], {
             RGBColor[
             0.26425191426448674`, 0.3950758948040016, 0.9383601276404636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 364}], {
             RGBColor[
             0.2639259772143767, 0.39473331429873343`, 0.9383415660076406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 437}], {
             RGBColor[
             0.26255787085876586`, 0.3932953477760335, 0.9382636543746206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 100}], {
             RGBColor[
             0.943316965793535, 0.8656345224892459, 0.6119300548794735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 127}], {
             RGBColor[
             0.5906994451507328, 0.6605608453144329, 0.9482643190369882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 168}], {
             RGBColor[
             0.9331056494970619, 0.8251500560931704, 0.6037137900969318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 213}], {
             RGBColor[
             0.9298124883323949, 0.8120876909328425, 0.6010637208876998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 214}], {
             RGBColor[
             0.5776130969249946, 0.6468062636067821, 0.9475190708650497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 254}], {
             RGBColor[
             0.5959586642234989, 0.6660886180136586, 0.9485638237828649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 302}], {
             RGBColor[
             0.5727842186692342, 0.6417308063914131, 0.9472440733920693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 315}], {
             RGBColor[
             0.5704593476328262, 0.6392872195268108, 0.9471116754258844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 325}], {
             RGBColor[
             0.5672179996830251, 0.6358803573182399, 0.9469270854552878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 368}], {
             RGBColor[
             0.6817603644893816, 0.7470855364406719, 0.9537864521193352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 401}], {
             RGBColor[
             0.8644357283380311, 0.8946091728083778, 0.9692011064141851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 477}], {
             RGBColor[
             0.6000453532177727, 0.6703839872576882, 0.948796554675374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 500}], {
             RGBColor[
             0.8874558706447166, 0.5585534617562613, 0.5633237757723539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 97}], {
             RGBColor[
             0.22940871371662525`, 0.3584534818416879, 0.936375858915159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 137}], {
             RGBColor[
             0.22358173079098384`, 0.35232895333478276`, 0.9360440208577924]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 145}], {
             RGBColor[
             0.22387054333517215`, 0.3526325136304976, 0.9360604683049241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 174}], {
             RGBColor[
             0.24687001390337449`, 0.3768064154483368, 0.9373702541291156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 286}], {
             RGBColor[
             0.22509159237078977`, 0.3539159135859121, 0.9361300052411223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 294}], {
             RGBColor[
             0.2326978312332123, 0.36191055289371626`, 0.9365631692919152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 346}], {
             RGBColor[
             0.22248278830370904`, 0.3511738951036789, 0.9359814377088818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 358}], {
             RGBColor[
             0.2263545662938538, 0.3552433792562242, 0.9362019297376383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 404}], {
             RGBColor[
             0.22026561376472564`, 0.3488435040862222, 0.9358551728989024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 407}], {
             RGBColor[
             0.22072063099008732`, 0.34932175603983573`, 0.9358810854567492]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 408}], {
             RGBColor[
             0.22479372667970515`, 0.35360283785880653`, 0.9361130422306678]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 430}], {
             RGBColor[
             0.23341097282813747`, 0.36266010992577125`, 0.9366037816507478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 131}], {
             RGBColor[
             0.2798853921380307, 0.4115076712688437, 0.9392504310777041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 147}], {
             RGBColor[
             0.27382745193814473`, 0.40514039202317054`, 0.9389054403452399]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.29935267191603787`, 0.43196901661235676`, 0.940359063861802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 171}], {
             RGBColor[
             0.2789519797924134, 0.41052659571183897`, 0.939197274625481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 180}], {
             RGBColor[
             0.2831463385898367, 0.4149351327456384, 0.9394361371539964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 216}], {
             RGBColor[
             0.2810238579235662, 0.4127042709923413, 0.9393152650199811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 238}], {
             RGBColor[
             0.3081578274315908, 0.4401690531459169, 0.9408991236475683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 265}], {
             RGBColor[
             0.3085881199169248, 0.4405417508695841, 0.9409265415042412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 281}], {
             RGBColor[
             0.27053519804586806`, 0.4016800244414347, 0.938717951356528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 343}], {
             RGBColor[
             0.29452462133405766`, 0.4268944293346082, 0.940084113523619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 392}], {
             RGBColor[
             0.3010815634219416, 0.43378619120311424`, 0.9404575216753974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 433}], {
             RGBColor[
             0.31083399291217784`, 0.4424870131772134, 0.9410696465455513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 465}], {
             RGBColor[
             0.2893936582907169, 0.42150146185421045`, 0.9397919127688803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 104}], {
             RGBColor[
             0.23915408747259903`, 0.3686964875516002, 0.936930843533573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 137}], {
             RGBColor[
             0.2259075246268314, 0.35477351012010483`, 0.9361764713760403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 145}], {
             RGBColor[
             0.2261963371710197, 0.3550770704158197, 0.9361929188231719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 174}], {
             RGBColor[
             0.24919580773922206`, 0.37925097223365895`, 0.9375027046473634]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 294}], {
             RGBColor[
             0.23502362506905988`, 0.3643551096790384, 0.936695619810163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 346}], {
             RGBColor[
             0.22480858213955662`, 0.353618451889001, 0.9361138882271296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 358}], {
             RGBColor[
             0.2286803601297014, 0.35768793604154625`, 0.9363343802558861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 404}], {
             RGBColor[
             0.2225914076005732, 0.3512880608715443, 0.9359876234171504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 407}], {
             RGBColor[
             0.2230464248259349, 0.3517663128251578, 0.936013535974997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 408}], {
             RGBColor[
             0.2271195205155527, 0.3560473946441286, 0.9362454927489157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 430}], {
             RGBColor[
             0.23573676666398502`, 0.3651046667110934, 0.9367362321689956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 115}], {
             RGBColor[
             0.9582015589575525, 0.9660972945461519, 0.85752593015656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 124}], {
             RGBColor[
             0.9789436438067185, 0.93894816660261, 0.5160607207640602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 136}], {
             RGBColor[
             0.9820976999154852, 0.9842937020241562, 0.8300672430323528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 253}], {
             RGBColor[
             0.9901332923121124, 0.9901471046097305, 0.8102166844391167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 261}], {
             RGBColor[
             0.9376107771767181, 0.7700729496416561, 0.47213960027127755`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 277}], {
             RGBColor[
             0.8832681348130269, 0.9067408984138945, 0.8502742951726139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 311}], {
             RGBColor[
             0.8710458030481137, 0.8971927199459824, 0.8490560873664715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 319}], {
             RGBColor[
             0.8550622111994015, 0.8847062165139711, 0.8474629923061501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 331}], {
             RGBColor[
             0.9159632164581281, 0.9324175867663749, 0.8534971993423514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 377}], {
             RGBColor[
             0.9881699242791049, 0.9888223570121889, 0.8197885510745015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 484}], {
             RGBColor[
             0.9940632182259341, 0.9897101490230129, 0.5951961253421731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 488}], {
             RGBColor[
             0.8822995191611039, 0.9059842085048606, 0.8501777526166581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 122}], {
             RGBColor[
             0.930562919133284, 0.740007623770434, 0.37913808172539787`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 267}], {
             RGBColor[
             0.9913420700473246, 0.9817665875606343, 0.479566100729647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 278}], {
             RGBColor[
             0.9709926371751241, 0.9748878865987054, 0.7597061890098948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 329}], {
             RGBColor[
             0.9380897089070905, 0.9489785735157732, 0.7678909167681753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 406}], {
             RGBColor[
             0.992119957252125, 0.9843905837590278, 0.48258804562862445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 413}], {
             RGBColor[
             0.9837287794830555, 0.9560851708017216, 0.4499899045367475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 476}], {
             RGBColor[
             0.9210569805098886, 0.6812525268241133, 0.37059559494700395`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 486}], {
             RGBColor[
             0.9642745659488295, 0.9698576677518461, 0.7703884518083142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 493}], {
             RGBColor[
             0.9935993972524345, 0.9887180828601909, 0.5447120747479771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 121}], {
             RGBColor[
             0.8793403970281699, 0.48855884043917713`, 0.2187233911438525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 127}], {
             RGBColor[
             0.5785973319473678, 0.5599231651764567, 0.5998463238378839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 168}], {
             RGBColor[
             0.9210035362936968, 0.7245123759551941, 0.25529579489782767`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 200}], {
             RGBColor[
             0.9160214299715226, 0.703780905297789, 0.25123642844933736`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 213}], {
             RGBColor[
             0.9177103751290299, 0.7114500107948662, 0.2526457256885956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 254}], {
             RGBColor[
             0.5838565510201338, 0.5654509378756822, 0.6001458285837606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 259}], {
             RGBColor[
             0.8965277758950481, 0.6152647749950997, 0.2349704456547408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 315}], {
             RGBColor[
             0.5583572344294613, 0.5386495393888345, 0.5986936802267802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 368}], {
             RGBColor[
             0.6696582512860165, 0.6464478563026956, 0.6053684569202311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 401}], {
             RGBColor[
             0.8523336151346661, 0.7939714926704016, 0.620783111215081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 450}], {
             RGBColor[
             0.8744616680202064, 0.45105879141128646`, 0.21405151473609035`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 454}], {
             RGBColor[
             0.915548639391991, 0.7016340736991815, 0.25084192040061865`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 471}], {
             RGBColor[
             0.894013717811025, 0.6013444138663678, 0.23277457969666004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 475}], {
             RGBColor[
             0.8851091218155209, 0.5328997870260774, 0.22424752851506258`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 500}], {
             RGBColor[
             0.8753537574413516, 0.45791578161828494`, 0.21490578057324983`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 128}], {
             RGBColor[
             0.5077879700548952, 0.6112841755347511, 0.9543940755727961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 169}], {
             RGBColor[
             0.506787455963573, 0.6104719131227696, 0.9543153114385234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 197}], {
             RGBColor[
             0.6092291752169602, 0.6927921015850171, 0.9629587335694303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[
             0.5113628894889524, 0.6141864561796039, 0.9546755063260064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 219}], {
             RGBColor[
             0.5235508135187052, 0.6240811619666777, 0.9556349843514654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 337}], {
             RGBColor[
             0.6905217138834787, 0.756623588079157, 0.9709749326217818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 345}], {
             RGBColor[
             0.5902789610650883, 0.677988050262613, 0.9610699533225915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 355}], {
             RGBColor[
             0.424769765192925, 0.5405027707410431, 0.9487934456872616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 361}], {
             RGBColor[
             0.5825170875925927, 0.671924415713476, 0.9602963223136847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 362}], {
             RGBColor[
             0.45464713410545365`, 0.5663810460128507, 0.950697205214848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 363}], {
             RGBColor[
             0.4628220425559936, 0.5734617408298626, 0.9512181031525286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 498}], {
             RGBColor[
             0.491361119566665, 0.5979481182872246, 0.9531008937288266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 109}], {
             RGBColor[
             0.265248780611274, 0.396123664539452, 0.9384168977041816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[
             0.28024115314486164`, 0.4118815986435736, 0.9392706911407418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 186}], {
             RGBColor[
             0.256123983487738, 0.3865329242170628, 0.9378972540069239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 193}], {
             RGBColor[
             0.2821746373958698, 0.4139138131813651, 0.9393808002085031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 196}], {
             RGBColor[
             0.28611844580431445`, 0.41805900587053585`, 0.9396053942630224]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 202}], {
             RGBColor[
             0.2577973086293919, 0.3882916950358828, 0.9379925473982783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 330}], {
             RGBColor[
             0.2914935550351155, 0.4237085864737168, 0.939911498781955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 350}], {
             RGBColor[
             0.3193537748201921, 0.44805203074969097`, 0.941678953195245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 354}], {
             RGBColor[
             0.3191507002330799, 0.44787613774915985`, 0.941666013462126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 414}], {
             RGBColor[
             0.27559776236137046`, 0.40700110052214455`, 0.9390062569049031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 415}], {
             RGBColor[
             0.28177512151681394`, 0.41349389666170766`, 0.9393580483702217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 485}], {
             RGBColor[
             0.2622693737921402, 0.3929921190672394, 0.9382472248934693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 496}], {
             RGBColor[
             0.27671354998693043`, 0.4081738640616296, 0.9390697993595188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 118}], {
             RGBColor[
             0.4027319052154037, 0.522513730131029, 0.9470855430392838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 188}], {
             RGBColor[
             0.408816425381794, 0.5277838356822806, 0.9474732432839563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 304}], {
             RGBColor[
             0.4094598762170423, 0.5283411604549934, 0.947514243402197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 319}], {
             RGBColor[
             0.5976226950866923, 0.6831049747415705, 0.9622258440138658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 331}], {
             RGBColor[
             0.6585237003454188, 0.7308163449939742, 0.968260051050067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 449}], {
             RGBColor[
             0.6043292409167387, 0.6883441793156388, 0.9628942898259707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 488}], {
             RGBColor[
             0.6248600030483947, 0.70438296673246, 0.9649406043243738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 112}], {
             RGBColor[
             0.24741859649764936`, 0.37738301053706513`, 0.9374014950963042]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 148}], {
             RGBColor[
             0.2431147548759032, 0.37285940011329033`, 0.9371563976829089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 153}], {
             RGBColor[
             0.24575331572793313`, 0.3756326948631943, 0.937306659820031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 190}], {
             RGBColor[
             0.24734164292075334`, 0.3773021274486088, 0.9373971127039427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 215}], {
             RGBColor[
             0.26534838496499225`, 0.39622835503049064`, 0.9384225700247744]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 224}], {
             RGBColor[
             0.2727699797429894, 0.40402892169845256`, 0.9388452188681158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 323}], {
             RGBColor[
             0.2429591667599799, 0.3726958671385986, 0.9371475371698791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 351}], {
             RGBColor[
             0.2683095588486911, 0.39934073653152624`, 0.9385912044967868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 356}], {
             RGBColor[
             0.2579557991377684, 0.3884582786090651, 0.9380015731982647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 408}], {
             RGBColor[
             0.23453910043567894`, 0.36384584356871885`, 0.9366680268490819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 430}], {
             RGBColor[
             0.24315634658411125`, 0.3729031156356836, 0.937158766269162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 452}], {
             RGBColor[
             0.2352635459876256, 0.36460728177631574`, 0.9367092829515442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 112}], {
             RGBColor[
             0.2470843980758506, 0.3770317468063509, 0.9373824629905851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 148}], {
             RGBColor[
             0.24278055645410443`, 0.37250813638257607`, 0.9371373655771897]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 153}], {
             RGBColor[
             0.24541911730613436`, 0.37528143113248, 0.9372876277143118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 190}], {
             RGBColor[
             0.24700744449895456`, 0.37695086371789455`, 0.9373780805982235]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 195}], {
             RGBColor[
             0.2580285978828387, 0.38853479470584096`, 0.9380057189791005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 263}], {
             RGBColor[
             0.2596529612026372, 0.3902421035455322, 0.9380982240671327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 323}], {
             RGBColor[
             0.24262496833818112`, 0.37234460340788433`, 0.93712850506416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 342}], {
             RGBColor[
             0.252946206923672, 0.38319287956555814`, 0.9377162843326995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 395}], {
             RGBColor[
             0.2554464216840092, 0.38582076380144426`, 0.9378586678645644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 447}], {
             RGBColor[
             0.24620260884716, 0.3761049304183308, 0.9373322463985014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 453}], {
             RGBColor[
             0.265106051538209, 0.39597364723411466`, 0.9384087694946193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 463}], {
             RGBColor[
             0.2565013158137106, 0.3869295244159112, 0.9379187425246749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 117}], {
             RGBColor[
             0.44946530583261596`, 0.561973649912251, 0.9503446865091629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 139}], {
             RGBColor[
             0.5409452590449157, 0.6382027564556965, 0.9570043388212421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 140}], {
             RGBColor[
             0.508744701282457, 0.6120608930455363, 0.9544693929596517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 247}], {
             RGBColor[
             0.5064333598698463, 0.6101844419620349, 0.9542874356969284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 255}], {
             RGBColor[
             0.45772043203322, 0.569123825312507, 0.9508706958509441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 269}], {
             RGBColor[
             0.48339733950661234`, 0.5913638720070653, 0.9525068056899508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 274}], {
             RGBColor[
             0.49029479958875166`, 0.5970824316919869, 0.9530169491141065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 360}], {
             RGBColor[
             0.5486108303756021, 0.6444260125920007, 0.9576078006763067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 369}], {
             RGBColor[
             0.46890138102995677`, 0.5788082013626439, 0.9515831360340911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 370}], {
             RGBColor[
             0.5546493379031965, 0.6493283450345659, 0.9580831741086608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 425}], {
             RGBColor[
             0.4465990938801403, 0.559491081179018, 0.9501620540180429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 466}], {
             RGBColor[
             0.5106817556791221, 0.6136334810680553, 0.9546218849774213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 468}], {
             RGBColor[
             0.4981161809408796, 0.6034321814228589, 0.9536326769048099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 113}], {
             RGBColor[
             0.18193197659231264`, 0.3085524209250408, 0.9336721289714678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 132}], {
             RGBColor[
             0.5874023021726906, 0.6508098778838103, 0.8735074338464627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 143}], {
             RGBColor[
             0.18179934691843552`, 0.30841301872858895`, 0.9336645759077484]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 209}], {
             RGBColor[
             0.37529763235099667`, 0.4849566561931139, 0.9463994374355724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 214}], {
             RGBColor[
             0.19223940367108877`, 0.31938618031345734`, 0.9342591216951321]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 273}], {
             RGBColor[
             0.2391065540897807, 0.3686465269524677, 0.9369281365777409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 308}], {
             RGBColor[
             0.18180898862834943`, 0.3084231527770282, 0.9336651249888644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 421}], {
             RGBColor[
             0.18186414913512938`, 0.30848112996703203`, 0.9336682662981228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 423}], {
             RGBColor[
             0.18624879198055028`, 0.31308966759998247`, 0.9339179652216718]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 446}], {
             RGBColor[
             0.2064114829025504, 0.3342819341474452, 0.9350662006416515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 477}], {
             RGBColor[
             0.21467165996386678`, 0.3429639039643634, 0.9355366055054566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 129}], {
             RGBColor[
             0.3203552344901264, 0.4497120899906687, 0.9417137426958612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 163}], {
             RGBColor[
             0.27605150294224795`, 0.40747801064146116`, 0.939032096759735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 189}], {
             RGBColor[
             0.27244302962866296`, 0.40368527639846097`, 0.9388265995427842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 206}], {
             RGBColor[
             0.31392242641055057`, 0.44414031495447526`, 0.9413038498533395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 266}], {
             RGBColor[
             0.28731571918259713`, 0.4193174161026276, 0.9396735772107083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 364}], {
             RGBColor[
             0.27183868506633, 0.4030500719457907, 0.938792183014007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 374}], {
             RGBColor[
             0.2684205085848909, 0.3994573517388918, 0.938597522920128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 410}], {
             RGBColor[
             0.32438785376155105`, 0.4532049421182389, 0.9419706976299311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 437}], {
             RGBColor[
             0.27047057871071917`, 0.40161210542309067`, 0.938714271380987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 185}], {
             RGBColor[
             0.26895237692670115`, 0.40001637908853493`, 0.9386278120353654]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 186}], {
             RGBColor[
             0.24483520726957755`, 0.37466770466202415`, 0.9372543749015474]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 196}], {
             RGBColor[
             0.27482966958615396`, 0.4061937863154972, 0.938962515157646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 218}], {
             RGBColor[
             0.24296647092511459`, 0.372703544279266, 0.937147953131278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 295}], {
             RGBColor[
             0.24177394363545715`, 0.37145012248723885`, 0.937080040466318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 300}], {
             RGBColor[
             0.23995882574419874`, 0.3695423184984049, 0.9369766721876371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 335}], {
             RGBColor[
             0.2653660882581673, 0.3962469623140712, 0.938423578201131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 409}], {
             RGBColor[
             0.24775783308986035`, 0.3777395697043211, 0.9374208141183751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 456}], {
             RGBColor[
             0.23880926652767986`, 0.3683340588755796, 0.9369112064908769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 458}], {
             RGBColor[
             0.24222963005763265`, 0.3719290778091332, 0.9371059911339332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 496}], {
             RGBColor[
             0.26542477376877, 0.3963086445065909, 0.9384269202541424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 217}], {
             RGBColor[
             0.29571753049971145`, 0.4271336534107135, 0.9401891973787395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 290}], {
             RGBColor[
             0.2791002706073135, 0.4106824587604797, 0.9392057195680129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 316}], {
             RGBColor[
             0.26110517012024004`, 0.39176846719329617`, 0.9381809252166395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 340}], {
             RGBColor[
             0.3045749314378675, 0.43480548891742876`, 0.9407535831342266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 355}], {
             RGBColor[
             0.30021105187484454`, 0.43102571577490256`, 0.9404755205872981]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 378}], {
             RGBColor[
             0.2773998635716586, 0.40889522315397336`, 0.9391088839028592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 384}], {
             RGBColor[
             0.27776805045914515`, 0.4092822109171187, 0.9391298516014178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 146}], {
             RGBColor[
             0.2655122364597581, 0.39640057334027434`, 0.9384319011250047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 201}], {
             RGBColor[
             0.28877500860148286`, 0.42085122180616963`, 0.9397566815842886]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 256}], {
             RGBColor[
             0.2812386903435383, 0.41293007348689414`, 0.9393274994084824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 271}], {
             RGBColor[
             0.2644482810539334, 0.39528228875008364`, 0.938371310438624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 284}], {
             RGBColor[
             0.2590919383322233, 0.3896524329378227, 0.9380662746446216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 312}], {
             RGBColor[
             0.28875139009156847`, 0.4208263972547496, 0.9397553365450895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 376}], {
             RGBColor[
             0.2762731715166523, 0.4077109983677596, 0.9390447204571181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[
             0.2845065356159251, 0.4163647860615299, 0.939513598362401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 415}], {
             RGBColor[
             0.2800519643946353, 0.41168274927182613`, 0.9392599171212961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 442}], {
             RGBColor[
             0.2785182841132166, 0.41007075405510884`, 0.939172576298146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 444}], {
             RGBColor[
             0.272192144891436, 0.40342158063262434`, 0.9388123120281499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 464}], {
             RGBColor[
             0.2584790029138965, 0.3890081989508112, 0.9380313688793045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 148}], {
             RGBColor[
             0.2439596839808273, 0.373747474174165, 0.9372045151454738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 153}], {
             RGBColor[
             0.24659824483285725`, 0.37652076892406894`, 0.9373547772825959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 190}], {
             RGBColor[
             0.24818657202567745`, 0.37819020150948346`, 0.9374452301665075]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 195}], {
             RGBColor[
             0.25920772540956155`, 0.3897741324974299, 0.9380728685473844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 224}], {
             RGBColor[
             0.2736149088479135, 0.4049169957593272, 0.9388933363306806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 263}], {
             RGBColor[
             0.2608320887293601, 0.39148144133712115`, 0.9381653736354167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 323}], {
             RGBColor[
             0.24380409586490398`, 0.37358394119947325`, 0.9371956546324439]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 342}], {
             RGBColor[
             0.25412533445039487`, 0.3844322173571471, 0.9377834339009834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 351}], {
             RGBColor[
             0.26915448795361524`, 0.4002288105924009, 0.9386393219593516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 356}], {
             RGBColor[
             0.2588007282426925, 0.3893463526699398, 0.9380496906608295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 395}], {
             RGBColor[
             0.2566255492107321, 0.38706010159303317`, 0.9379258174328484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 447}], {
             RGBColor[
             0.2473817363738829, 0.37734426820991973`, 0.9373993959667855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 452}], {
             RGBColor[
             0.2361084750925497, 0.3654953558371904, 0.936757400414109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 463}], {
             RGBColor[
             0.2576804433404335, 0.3881688622075002, 0.9379858920929589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 130}], {
             RGBColor[
             0.17905963034776856`, 0.3055334029047545, 0.9335085531020964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 143}], {
             RGBColor[
             0.17905963102166003`, 0.30553340361305714`, 0.9335085531404735]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 209}], {
             RGBColor[
             0.3725579164542212, 0.4820770410775821, 0.9462434146682975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 214}], {
             RGBColor[
             0.18949968777431325`, 0.3165065651979255, 0.9341030989278573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 273}], {
             RGBColor[
             0.23636683819300525`, 0.3657669118369359, 0.936772113810466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 302}], {
             RGBColor[
             0.18467080951855291`, 0.3114311079825565, 0.9338281014548768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 308}], {
             RGBColor[
             0.17906927273157397`, 0.3055435376614964, 0.9335091022215896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 325}], {
             RGBColor[
             0.1791045905323438, 0.30558065890938335`, 0.9335111135180953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 347}], {
             RGBColor[
             0.17905963034776856`, 0.3055334029047545, 0.9335085531020964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 386}], {
             RGBColor[
             0.17905963034776856`, 0.3055334029047545, 0.9335085531020964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 421}], {
             RGBColor[
             0.17912443323835392`, 0.3056015148515002, 0.9335122435308479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 423}], {
             RGBColor[
             0.1835090760837748, 0.31021005248445066`, 0.9337619424543968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 477}], {
             RGBColor[
             0.2119319440670913, 0.3400842888488316, 0.9353805827381816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 115}], {
             RGBColor[
             0.7109234320173796, 0.7727455262693818, 0.9730887236423327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 203}], {
             RGBColor[
             0.5176225598035007, 0.6192683385358883, 0.9551682905030956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 208}], {
             RGBColor[
             0.41139850447614446`, 0.5294684917353877, 0.9477902381259522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 258}], {
             RGBColor[
             0.4370504632160207, 0.551686929090934, 0.9494247582537205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 289}], {
             RGBColor[
             0.47002476811242727`, 0.580247614655448, 0.9515258518036867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 291}], {
             RGBColor[
             0.577802812280651, 0.6679328507014297, 0.9600375327920143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 297}], {
             RGBColor[
             0.5100213466264654, 0.6130973312480197, 0.954569895157638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 311}], {
             RGBColor[
             0.6237676761079407, 0.7038409516692123, 0.9646188808522442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 349}], {
             RGBColor[
             0.45713997699902986`, 0.5690874562014547, 0.9507048443075143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 359}], {
             RGBColor[
             0.443064873322788, 0.5568963088323743, 0.9498079911473898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 381}], {
             RGBColor[
             0.5349916430046526, 0.6333693427468647, 0.9565356483577385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 397}], {
             RGBColor[
             0.4296132686116584, 0.545245204928905, 0.9489508667899835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 419}], {
             RGBColor[
             0.5066845097134336, 0.6103883367192307, 0.9543072071326079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 124}], {
             RGBColor[
             0.9419104649402625, 0.9128295501642687, 0.6508778471089514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 136}], {
             RGBColor[
             0.9450645210490293, 0.9581750855858149, 0.964884369377244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 178}], {
             RGBColor[
             0.9564265081535962, 0.965404037867567, 0.8899068420398936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 203}], {
             RGBColor[
             0.7278675078772177, 0.786501490374317, 0.9744226233622142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 253}], {
             RGBColor[
             0.9531001134456565, 0.9640284881713892, 0.9450338107840079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 277}], {
             RGBColor[
             0.8462349559465709, 0.8806222819755531, 0.9850914215175051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 291}], {
             RGBColor[
             0.7880477603543681, 0.8351660025398585, 0.9792918656511329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 297}], {
             RGBColor[
             0.7202662947001824, 0.7803304830864486, 0.9738242280167566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 311}], {
             RGBColor[
             0.8340126241816578, 0.871074103507641, 0.9838732137113628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 381}], {
             RGBColor[
             0.7452365910783697, 0.8006024945852935, 0.9757899812168571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 419}], {
             RGBColor[
             0.7169294577871506, 0.7776214885576594, 0.9735615399917263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 439}], {
             RGBColor[
             0.8910404321249454, 0.9159554702009634, 0.9894694259289032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 484}], {
             RGBColor[
             0.9570300393594782, 0.9635915325846716, 0.7300132516870645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 192}], {
             RGBColor[
             0.2516702940273803, 0.3818518142140055, 0.9376436229807996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 280}], {
             RGBColor[
             0.25280916302349343`, 0.3830488377373854, 0.9377084798853226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 310}], {
             RGBColor[
             0.2727415097182925, 0.40399899789739224`, 0.9388435975423268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 327}], {
             RGBColor[
             0.25289755432094124`, 0.38314174259533496`, 0.937713513638949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 399}], {
             RGBColor[
             0.24511345141386065`, 0.3749601568993634, 0.937270220493939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 412}], {
             RGBColor[
             0.24555371763094103`, 0.3754229046080053, 0.9372952930036862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 483}], {
             RGBColor[
             0.27268756010159706`, 0.40394229342964216`, 0.9388405251914673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 139}], {
             RGBColor[
             0.47255522666265165`, 0.5807190878311534, 0.9521624096580703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 140}], {
             RGBColor[
             0.44035466890019287`, 0.5545772244209933, 0.9496274637964799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 154}], {
             RGBColor[
             0.34530823850037556`, 0.4735103733174856, 0.9432237135065259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 247}], {
             RGBColor[
             0.4380433274875822, 0.5527007733374919, 0.9494455065337566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 255}], {
             RGBColor[
             0.38933039965095584`, 0.511640156687964, 0.9460287666877722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 269}], {
             RGBColor[
             0.41500730712434825`, 0.5338802033825223, 0.947664876526779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 338}], {
             RGBColor[
             0.3505903006321732, 0.47808543005188675`, 0.9435602818348199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 369}], {
             RGBColor[
             0.40051134864769267`, 0.5213245327381009, 0.9467412068709193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 390}], {
             RGBColor[
             0.34091437037852435`, 0.46896566133560236`, 0.9429707972165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 425}], {
             RGBColor[
             0.3782090614978762, 0.502007412554475, 0.9453201248548712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 466}], {
             RGBColor[
             0.44229172329685795`, 0.5561498124435122, 0.9497799558142495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[
             0.31734549257895406`, 0.4492904482488255, 0.9414419520628983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 151}], {
             RGBColor[
             0.31595121433390305`, 0.44790234871507695`, 0.9413597168905753]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 188}], {
             RGBColor[
             0.3311926249986076, 0.4612841383736176, 0.9423242790961401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 304}], {
             RGBColor[
             0.3318360758338559, 0.46184146314633034`, 0.9423652792143808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 310}], {
             RGBColor[
             0.3109325878407584, 0.44262745407148385`, 0.9410739135361832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 327}], {
             RGBColor[
             0.2910886324434072, 0.42177019876942656`, 0.9399438296328053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 483}], {
             RGBColor[
             0.31087863822406303`, 0.44257074960373377`, 0.9410708411853237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 197}], {
             RGBColor[
             0.8441364985929255, 0.8770550844901885, 0.8875786005274353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 237}], {
             RGBColor[
             0.9483698835729416, 0.9591789791220269, 0.8977829179807035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 270}], {
             RGBColor[
             0.9903352312511376, 0.9902713839961873, 0.8098337599957988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 309}], {
             RGBColor[
             0.9918390696706652, 0.9889511495464178, 0.6437403499501158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 320}], {
             RGBColor[
             0.9896249360090673, 0.9899776586598361, 0.8216051903420669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 345}], {
             RGBColor[
             0.8251862844410536, 0.8622510331677843, 0.8856898202805965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 375}], {
             RGBColor[
             0.9744244063754681, 0.9793738724475776, 0.8801494909995853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 426}], {
             RGBColor[
             0.9304108836330538, 0.9448589600540273, 0.8960699725342486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 489}], {
             RGBColor[
             0.9903724843514137, 0.9902867891105125, 0.8092163797162932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 123}], {
             RGBColor[
             0.20719251066229882`, 0.33510284384296096`, 0.9351106790171422]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 125}], {
             RGBColor[
             0.2080475453125366, 0.33600153947268885`, 0.9351593719755629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 177}], {
             RGBColor[
             0.20805903153131503`, 0.3360136122168933, 0.9351600260987298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 438}], {
             RGBColor[
             0.21444303080234048`, 0.3427236002196732, 0.9355235854129342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 455}], {
             RGBColor[
             0.2056810719300792, 0.33351422590464763`, 0.9350246048173154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 457}], {
             RGBColor[
             0.21450528797873675`, 0.3427890364593986, 0.9355271308670288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 161}], {
             RGBColor[
             0.9088989497892817, 0.5955852022276555, 0.2954383174204215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[
             0.8641469744095227, 0.4273429033856967, 0.2064477599128205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.86583591956703, 0.4350120088827739, 0.20785705715207875`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 259}], {
             RGBColor[
             0.8446533203330481, 0.33882677308300735`, 0.1901817771182239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 341}], {
             RGBColor[
             0.9105196563022746, 0.6003916270804778, 0.3579070077274834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 450}], {
             RGBColor[
             0.8225872124582064, 0.17462078949919407`, 0.16926284619957344`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 454}], {
             RGBColor[
             0.8636741838299911, 0.42519607178708907`, 0.20605325186410173`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 469}], {
             RGBColor[
             0.8439483097229172, 0.3356254845618147, 0.18959349898373934`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 471}], {
             RGBColor[
             0.842139262249025, 0.3249064119542755, 0.18798591116014318`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 475}], {
             RGBColor[
             0.8332346662535209, 0.256461785113985, 0.17945885997854572`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 491}], {
             RGBColor[
             0.9108136867178351, 0.6010205284083265, 0.38991040391585896`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 500}], {
             RGBColor[
             0.8234793018793516, 0.18147777970619255`, 0.1701171120367329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 150}], {
             RGBColor[
             0.8444744803276283, 0.32854420856354566`, 0.1896617078466737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.8441272348319537, 0.3258751275198433, 0.1893291851678579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 233}], {
             RGBColor[
             0.8553320507775657, 0.4120002528594733, 0.20005892957140564`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 267}], {
             RGBColor[
             0.9282834555711476, 0.7330087810415269, 0.3115827018545064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 406}], {
             RGBColor[
             0.929061342775948, 0.7356327772399205, 0.3146046467534838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 413}], {
             RGBColor[
             0.9206701650068785, 0.7073273642826143, 0.2820065056616069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 476}], {
             RGBColor[
             0.8579983660337116, 0.432494720305006, 0.20261219607186334`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 493}], {
             RGBColor[
             0.9305407827762575, 0.7399602763410837, 0.37672867587283654`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 125}], {
             RGBColor[
             0.2078185513522534, 0.33576085230137553`, 0.9351463311082908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 177}], {
             RGBColor[
             0.2078300375710318, 0.33577292504558, 0.935146985231458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 438}], {
             RGBColor[
             0.21421403684205725`, 0.34248291304835987`, 0.9355105445456623]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 455}], {
             RGBColor[
             0.20545207796979598`, 0.3332735387333343, 0.9350115639500436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 136}], {
             RGBColor[
             0.9658066058981951, 0.931025957642273, 0.6234191599847442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 178}], {
             RGBColor[
             0.977168593002762, 0.938254909924025, 0.5484416326473938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 253}], {
             RGBColor[
             0.9738421982948224, 0.9368793602278473, 0.603568601391508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 261}], {
             RGBColor[
             0.9213196831594281, 0.7168052052597729, 0.265491517223669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 357}], {
             RGBColor[
             0.9348974167088442, 0.7776187751730486, 0.27677767167712564`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 484}], {
             RGBColor[
             0.9777721242086441, 0.9364424046411297, 0.38854804229456463`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 177}], {
             RGBColor[
             0.20868507222126964`, 0.3366716206753079, 0.9351956781898786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 438}], {
             RGBColor[
             0.2150690714922951, 0.34338160867808776`, 0.9355592375040829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 455}], {
             RGBColor[
             0.20630711262003382`, 0.3341722343630622, 0.9350602569084642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 457}], {
             RGBColor[
             0.21513132866869134`, 0.3434470449178132, 0.9355627829581774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 144}], {
             RGBColor[
             0.24868278916139275`, 0.37871175718110384`, 0.937473488998299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 279}], {
             RGBColor[
             0.26484901945855754`, 0.3957034902216259, 0.9383941318979281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 285}], {
             RGBColor[
             0.28277807837083513`, 0.4140236211798849, 0.9394343678430408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 481}], {
             RGBColor[
             0.28467725623571494`, 0.41566859359098884`, 0.9395553817772139]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 130}], {
             RGBColor[
             0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 168}], {
             RGBColor[
             0.5683860156508949, 0.5194386987803812, 0.5916300590553423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 179}], {
             RGBColor[
             0.20245447418328588`, 0.33012286709465477`, 0.9348408548489592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 200}], {
             RGBColor[
             0.5634039093287206, 0.4987072281229762, 0.587570692606852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 213}], {
             RGBColor[
             0.5650928544862279, 0.5063763336200533, 0.5889799898461102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 254}], {
             RGBColor[
             0.23123903037733173`, 0.3603772607008694, 0.9364800927412753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 302}], {
             RGBColor[
             0.2080645848230672, 0.3360194490786239, 0.9351603423504797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 315}], {
             RGBColor[
             0.20573971378665917`, 0.3335758622140216, 0.9350279443842948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 325}], {
             RGBColor[
             0.20249836583685807`, 0.33016900000545074`, 0.9348433544136983]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 347}], {
             RGBColor[
             0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 368}], {
             RGBColor[
             0.3170407306432145, 0.44137417912788274`, 0.9417027210777457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 386}], {
             RGBColor[
             0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 401}], {
             RGBColor[
             0.499716094491864, 0.5888978154955886, 0.9571173753725956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 454}], {
             RGBColor[
             0.562931118749189, 0.49656039652436856`, 0.5871761845581333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 169}], {
             RGBColor[
             0.4937426983927686, 0.5998815912671589, 0.9532883803380281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 197}], {
             RGBColor[
             0.5961844176461558, 0.6822017797294064, 0.9619318024689351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 204}], {
             RGBColor[
             0.4983181319181479, 0.6035961343239933, 0.9536485752255113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 345}], {
             RGBColor[
             0.5772342034942839, 0.6673977284070023, 0.9600430222220963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 355}], {
             RGBColor[
             0.4117250076221206, 0.5299124488854325, 0.9477665145867664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 362}], {
             RGBColor[
             0.4416023765346493, 0.55579072415724, 0.9496702741143528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 498}], {
             RGBColor[
             0.4783163619958606, 0.5873577964316139, 0.9520739626283314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 170}], {
             RGBColor[
             0.3261401713486173, 0.4557924254151241, 0.9420431862919051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 206}], {
             RGBColor[
             0.3491669657996257, 0.47685260895882275`, 0.9434695881978956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 265}], {
             RGBColor[
             0.3383071396578693, 0.46744637338556605`, 0.9427776096791101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 266}], {
             RGBColor[
             0.32256025857167225`, 0.4520297101069751, 0.9418393155552645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 328}], {
             RGBColor[
             0.3704563897071251, 0.49529243790994043`, 0.944826131463783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 410}], {
             RGBColor[
             0.3596323931506261, 0.48591723612258636`, 0.9441364359744873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 433}], {
             RGBColor[
             0.3405530126531223, 0.4693916356931953, 0.94292071472042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 143}], {
             RGBColor[
             0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 179}], {
             RGBColor[
             0.17892806853100302`, 0.30539512309383293`, 0.93350106085126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 214}], {
             RGBColor[
             0.1893670574265447, 0.316367162293171, 0.9340955458257609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 254}], {
             RGBColor[
             0.20771262472504887`, 0.3356495167000475, 0.935140298743576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 302}], {
             RGBColor[
             0.18453817917078433`, 0.311291705077802, 0.9338205483527805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 315}], {
             RGBColor[
             0.1822133081343763, 0.30884811821319974`, 0.9336881503865955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 325}], {
             RGBColor[
             0.1789719601845752, 0.3054412560046289, 0.9335035604159989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 347}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 368}], {
             RGBColor[
             0.2935143249909316, 0.4166464351270609, 0.9403629270800464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 386}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 421}], {
             RGBColor[
             0.17899180289058533`, 0.3054621119467458, 0.9335046904287516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 477}], {
             RGBColor[
             0.2117993137193227, 0.3399448859440771, 0.9353730296360853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 135}], {
             RGBColor[
             0.25711790914467114`, 0.38757760310102596`, 0.937953856602705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 147}], {
             RGBColor[
             0.257551109678863, 0.38803292432896186`, 0.9379785267322645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 170}], {
             RGBColor[
             0.28014480934839103`, 0.4117803352049335, 0.9392652045040607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 171}], {
             RGBColor[
             0.26267563753313167`, 0.39341912801763035`, 0.9382703610125054]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 216}], {
             RGBColor[
             0.26474751566428445`, 0.3955968032981327, 0.9383883514070055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 238}], {
             RGBColor[
             0.29188148517230905`, 0.42306158545170824`, 0.9399722100345929]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 265}], {
             RGBColor[
             0.29231177765764305`, 0.42343428317537546`, 0.9399996278912657]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 374}], {
             RGBColor[
             0.2576696859737398, 0.38815755553304865`, 0.9379852794768397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 385}], {
             RGBColor[
             0.24854031848564526`, 0.3785620114677306, 0.9374653755040816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 391}], {
             RGBColor[
             0.2523681386345833, 0.3825852931420795, 0.9376833641988113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 433}], {
             RGBColor[
             0.29455765065289613`, 0.4253795454830047, 0.9401427329325757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 209}], {
             RGBColor[
             0.7780282420345992, 0.8243344980363514, 0.8860787195432924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 233}], {
             RGBColor[
             0.9166463543771588, 0.6614692040973338, 0.5010749461233683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 273}], {
             RGBColor[
             0.6418371637733833, 0.7080243687957053, 0.8766074186854609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 423}], {
             RGBColor[
             0.5889794016641527, 0.6524675094432201, 0.8735972473293918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 151}], {
             RGBColor[
             0.3259839947322987, 0.4565922388339624, 0.9419989967859217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 155}], {
             RGBColor[
             0.4555313931992919, 0.5659235600860384, 0.9510915748153721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 181}], {
             RGBColor[
             0.3829354312034995, 0.5061011564392373, 0.9456212849531489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 225}], {
             RGBColor[
             0.3097114792684619, 0.4394887933443991, 0.9410723011032855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 235}], {
             RGBColor[
             0.3511076947395869, 0.47853357082274445`, 0.9435932497298307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 239}], {
             RGBColor[
             0.34805209112246643`, 0.47588696054869806`, 0.943398549369312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 249}], {
             RGBColor[
             0.3173607671926588, 0.44752867994559636`, 0.9415079167344612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 260}], {
             RGBColor[
             0.31537504749154577`, 0.44544156263782575`, 0.9413948329350919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 262}], {
             RGBColor[
             0.4106297397776527, 0.5294703750419166, 0.9475567521778445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 296}], {
             RGBColor[
             0.3292967430314739, 0.4596420207034847, 0.942203475173657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 332}], {
             RGBColor[
             0.3736828594731001, 0.4980870438541423, 0.9450317192642157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 344}], {
             RGBColor[
             0.404458323018091, 0.5244601408973477, 0.9470709156438875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 424}], {
             RGBColor[
             0.33288404882225986`, 0.46274916467623195`, 0.942432055126516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 440}], {
             RGBColor[
             0.31342375230206637`, 0.44339062767442217`, 0.9412837095607336]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 138}], {
             RGBColor[
             0.2265863896100655, 0.3554870402600099, 0.9362151317325447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 251}], {
             RGBColor[
             0.24587579480159133`, 0.37576142813523083`, 0.9373136348220843]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 305}], {
             RGBColor[
             0.2421591297202534, 0.37185497748456803`, 0.9371019762440154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 367}], {
             RGBColor[
             0.23152572380893705`, 0.3606785936749, 0.9364964195080803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 416}], {
             RGBColor[
             0.24737003573452257`, 0.37733197009608865`, 0.9373987296326833]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 438}], {
             RGBColor[
             0.22733547187831532`, 0.35627437321849936`, 0.9362577908595535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 457}], {
             RGBColor[
             0.22739772905471156`, 0.3563398094582248, 0.936261336313648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 499}], {
             RGBColor[
             0.2469625122439105, 0.37690363706897373`, 0.93737552177277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 147}], {
             RGBColor[
             0.2510599689447852, 0.3812103238553528, 0.9376088658702408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 170}], {
             RGBColor[
             0.2736536686143132, 0.40495773473132446`, 0.9388955436420372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 171}], {
             RGBColor[
             0.25618449679905386`, 0.3865965275440213, 0.9379007001504819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 216}], {
             RGBColor[
             0.25825637493020664`, 0.38877420282452363`, 0.938018690544982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 385}], {
             RGBColor[
             0.24204917775156742`, 0.37173941099412156`, 0.9370957146420581]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 391}], {
             RGBColor[
             0.24587699790050546`, 0.37576269266847045`, 0.9373137033367878]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 253}], {
             RGBColor[
             0.9769962544035893, 0.9822248956493935, 0.9175751236598007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 261}], {
             RGBColor[
             0.924473739268195, 0.762150740681319, 0.5794980394919615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 277}], {
             RGBColor[
             0.8701310969045036, 0.8988186894535575, 0.9576327343932979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 291}], {
             RGBColor[
             0.8119439013123007, 0.853362410017863, 0.9518331785269256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 311}], {
             RGBColor[
             0.8579087651395905, 0.8892705109856455, 0.9564145265871555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 319}], {
             RGBColor[
             0.8419251732908781, 0.8767840075536342, 0.9548214315268342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 377}], {
             RGBColor[
             0.9750328863705816, 0.980900148051852, 0.9271469902951855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 484}], {
             RGBColor[
             0.980926180317411, 0.981787940062676, 0.7025545645628573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 488}], {
             RGBColor[
             0.8691624812525807, 0.8980619995445237, 0.9575361918373422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 145}], {
             RGBColor[
             0.2203693542453783, 0.34895254190891456`, 0.9358610807658054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 183}], {
             RGBColor[
             0.2125239415632086, 0.34070651575206007`, 0.9354142961198038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 346}], {
             RGBColor[
             0.21898159921391522`, 0.34749392338209584`, 0.9357820501697631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 358}], {
             RGBColor[
             0.22285337720406, 0.3515634075346411, 0.9360025421985196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 404}], {
             RGBColor[
             0.2167644246749318, 0.34516353236463915`, 0.9356557853597838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 407}], {
             RGBColor[
             0.2172194419002935, 0.34564178431825265`, 0.9356816979176306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 408}], {
             RGBColor[
             0.2212925375899113, 0.34992286613722345`, 0.9359136546915492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 430}], {
             RGBColor[
             0.22990978373834364`, 0.3589801382041882, 0.9364043941116291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 352}], {
             RGBColor[
             0.22389864331585435`, 0.3526620484918363, 0.9360620685572537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 367}], {
             RGBColor[
             0.22490572664447084`, 0.3537205569229832, 0.9361194204629721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 457}], {
             RGBColor[
             0.22077773189024535`, 0.349381772706308, 0.9358843372685399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 140}], {
             RGBColor[
             0.5318346221124927, 0.6308063309644387, 0.9562871161085591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 247}], {
             RGBColor[
             0.529523280699882, 0.6289298798809373, 0.9561051588458358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 255}], {
             RGBColor[
             0.4808103528632557, 0.5878692632314095, 0.9526884189998513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 269}], {
             RGBColor[
             0.506487260336648, 0.6101093099259678, 0.9543245288388581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 274}], {
             RGBColor[
             0.5133847204187874, 0.6158278696108893, 0.9548346722630138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 360}], {
             RGBColor[
             0.5717007512056378, 0.6631714505109032, 0.9594255238252141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 369}], {
             RGBColor[
             0.49199130185999246`, 0.5975536392815464, 0.9534008591829983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 370}], {
             RGBColor[
             0.5777392587332322, 0.6680737829534684, 0.9599008972575682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 425}], {
             RGBColor[
             0.469689014710176, 0.5782365190979204, 0.9519797771669503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 466}], {
             RGBColor[
             0.5337716765091578, 0.6323789189869576, 0.9564396081263286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 468}], {
             RGBColor[
             0.5212061017709153, 0.6221776193417614, 0.9554504000537172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 169}], {
             RGBColor[
             0.4961881243257401, 0.601866898204728, 0.953480893225362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 204}], {
             RGBColor[
             0.5007635578511195, 0.6055814412615623, 0.9538410881128452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 219}], {
             RGBColor[
             0.5129514818808725, 0.6154761470486363, 0.9548005661383041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 244}], {
             RGBColor[
             0.42103754660959536`, 0.5378457039996745, 0.9483965938455836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 247}], {
             RGBColor[
             0.4973227229374232, 0.6027880164707773, 0.9535702129842454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 255}], {
             RGBColor[
             0.4486097951007969, 0.5617273998212495, 0.950153473138261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 274}], {
             RGBColor[
             0.4811841626563286, 0.5896860062007292, 0.9522997264014235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 334}], {
             RGBColor[
             0.4512190714580578, 0.563987423855866, 0.9503197339204532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 361}], {
             RGBColor[
             0.5719177559547599, 0.6633194007954346, 0.9594619041005235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 363}], {
             RGBColor[
             0.4522227109181607, 0.5648567259118211, 0.9503836849393674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 369}], {
             RGBColor[
             0.4597907440975337, 0.5714117758713864, 0.950865913321408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 370}], {
             RGBColor[
             0.5455387009707735, 0.6419319195433083, 0.9573659513959778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 425}], {
             RGBColor[
             0.4374884569477172, 0.5520946556877604, 0.9494448313053598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 466}], {
             RGBColor[
             0.5015711187466989, 0.6062370555767975, 0.9539046622647382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 188}], {
             RGBColor[
             0.32343001274534444`, 0.45456055380007726`, 0.9418296523075707]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 220}], {
             RGBColor[
             0.32424804297229537`, 0.4552690904672675, 0.9418817764702763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[
             0.2831042170303842, 0.4148134850118461, 0.939436571482416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 304}], {
             RGBColor[
             0.3240734635805927, 0.45511787857278996`, 0.9418706524258115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 310}], {
             RGBColor[
             0.3031699755874952, 0.4359038694979436, 0.9405792867476138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 429}], {
             RGBColor[
             0.30159042381675216`, 0.434243660437526, 0.9404893336110074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 173}], {
             RGBColor[
             0.8420436305365226, 0.8765386852966244, 0.9380905002853989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 222}], {
             RGBColor[
             0.5711190039988594, 0.6615355308329243, 0.9600580034664301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 241}], {
             RGBColor[
             0.7025032226254809, 0.7675201238280478, 0.9709826140315919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 402}], {
             RGBColor[
             0.6259177691187879, 0.7063115685381091, 0.9642924066530247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 417}], {
             RGBColor[
             0.7002784838355302, 0.7657821409766972, 0.9707608728603756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 461}], {
             RGBColor[
             0.8219899053555546, 0.8616442791794481, 0.9747961115925544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 179}], {
             RGBColor[
             0.17892806920489446`, 0.30539512380213557`, 0.933501060889637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 214}], {
             RGBColor[
             0.18936705810043614`, 0.31636716300147366`, 0.934095545864138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 226}], {
             RGBColor[
             0.17917599682249857`, 0.3056557114477564, 0.9335151800006836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 273}], {
             RGBColor[
             0.23623420851912813`, 0.365627509640484, 0.9367645607467467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 283}], {
             RGBColor[
             0.18007058028918088`, 0.3065959753911073, 0.9335661252056935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 292}], {
             RGBColor[
             0.1789488167630598, 0.30541693080123855`, 0.9335022424323813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 302}], {
             RGBColor[
             0.1845381798446758, 0.31129170578610466`, 0.9338205483911577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 308}], {
             RGBColor[
             0.17893664305769685`, 0.3054041354650445, 0.9335015491578702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 325}], {
             RGBColor[
             0.17897196085846667`, 0.30544125671293154`, 0.9335035604543761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 347}], {
             RGBColor[
             0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 386}], {
             RGBColor[
             0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 421}], {
             RGBColor[
             0.1789918035644768, 0.3054621126550484, 0.9335046904671287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 423}], {
             RGBColor[
             0.1833764464098977, 0.31007065028799885`, 0.9337543893906777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 446}], {
             RGBColor[
             0.20353913733189777`, 0.3312629168354616, 0.9349026248106573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 477}], {
             RGBColor[
             0.21179931439321417`, 0.33994488665237976`, 0.9353730296744625]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 279}], {
             RGBColor[
             0.2623939933592224, 0.3931231021335797, 0.9382543217934566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 494}], {
             RGBColor[
             0.25236564813326057`, 0.3825826754672824, 0.9376832223684453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 183}], {
             RGBColor[
             0.21281275410739692`, 0.3410100760477749, 0.9354307435669353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 286}], {
             RGBColor[
             0.22187921582518422`, 0.3505395021600439, 0.9359470651491353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 294}], {
             RGBColor[
             0.22948545468760678`, 0.35853414146784807`, 0.9363802291999281]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 346}], {
             RGBColor[
             0.21927041175810352`, 0.3477974836778107, 0.9357984976168947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 358}], {
             RGBColor[
             0.2231421897482483, 0.351866967830356, 0.9360189896456512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 404}], {
             RGBColor[
             0.2170532372191201, 0.345467092660354, 0.9356722328069155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 407}], {
             RGBColor[
             0.2175082544444818, 0.34594534461396753`, 0.9356981453647621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 408}], {
             RGBColor[
             0.2215813501340996, 0.35022642643293833`, 0.9359301021386808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 430}], {
             RGBColor[
             0.23019859628253192`, 0.35928369849990305`, 0.9364208415587607]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 201}], {
             RGBColor[
             0.28119600247616383`, 0.41288520583171645`, 0.9393250683975864]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 211}], {
             RGBColor[
             0.2444868180291041, 0.37430152548113294`, 0.9372345346496982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 271}], {
             RGBColor[
             0.25686927492861433`, 0.3873162727756304, 0.9379396972519218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 284}], {
             RGBColor[
             0.25151293220690424`, 0.3816864169633695, 0.9376346614579194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 312}], {
             RGBColor[
             0.28117238396624933`, 0.41286038128029634`, 0.9393237233583873]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 376}], {
             RGBColor[
             0.2686941653913333, 0.39974498239330636`, 0.9386131072704159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 400}], {
             RGBColor[
             0.276927529490606, 0.4083987700870767, 0.9390819851756989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 415}], {
             RGBColor[
             0.27247295826931617`, 0.4037167332973729, 0.9388283039345939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 442}], {
             RGBColor[
             0.2709392779878975, 0.40210473808065567`, 0.9387409631114438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 444}], {
             RGBColor[
             0.2646131387661169, 0.39545556465817117`, 0.9383806988414477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 464}], {
             RGBColor[
             0.25089999678857744`, 0.38104218297635795`, 0.9375997556926023]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 497}], {
             RGBColor[
             0.24696343657246012`, 0.3769046085968852, 0.9373755744119134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 171}], {
             RGBColor[
             0.2566176973332457, 0.3870518487719572, 0.9379253702800414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 216}], {
             RGBColor[
             0.2586895754643985, 0.38922952405245953`, 0.9380433606745415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 238}], {
             RGBColor[
             0.2858235449724231, 0.4166943062060351, 0.9396272193021288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 385}], {
             RGBColor[
             0.24248237828575928`, 0.37219473222205746`, 0.9371203847716176]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 391}], {
             RGBColor[
             0.24631019843469731`, 0.37621801389640636`, 0.9373383734663472]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 153}], {
             RGBColor[
             0.2422944032111111, 0.37199715850029413`, 0.9371096798692006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 190}], {
             RGBColor[
             0.2438827304039313, 0.37366659108570865`, 0.9372001327531121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 195}], {
             RGBColor[
             0.2549038837878154, 0.3852505220736551, 0.9378277711339891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 323}], {
             RGBColor[
             0.23950025424315785`, 0.36906033077569844`, 0.9369505572190486]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 342}], {
             RGBColor[
             0.2498214928286487, 0.3799086069333723, 0.9375383364875882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 351}], {
             RGBColor[
             0.26485064633186906`, 0.3957052001686261, 0.9383942245459564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 356}], {
             RGBColor[
             0.2544968866209464, 0.384822742246165, 0.9378045932474341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 452}], {
             RGBColor[
             0.23180463347080354`, 0.3609717454134156, 0.9365123030007138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 463}], {
             RGBColor[
             0.25337660171868737`, 0.3836452517837254, 0.9377407946795635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 158}], {
             RGBColor[
             0.3556980515257828, 0.48250950715290686`, 0.943885743205154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 165}], {
             RGBColor[
             0.3889540140770109, 0.511314150421502, 0.9460047837318252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 182}], {
             RGBColor[
             0.36623071660169665`, 0.4916323722545241, 0.9445568753101211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 187}], {
             RGBColor[
             0.30925143443909986`, 0.4382007802607746, 0.9410755580672832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 275}], {
             RGBColor[
             0.38378936730216673`, 0.5068407929678266, 0.9456756970062499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 282}], {
             RGBColor[
             0.48076658116172494`, 0.586646877963116, 0.9530129031646457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 324}], {
             RGBColor[
             0.361776111320833, 0.4877740170552114, 0.9442730318006773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 441}], {
             RGBColor[
             0.4020035872776604, 0.5226170348372846, 0.946836290996886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 159}], {
             RGBColor[
             0.821097410502475, 0.1631695188320622, 0.16783621016427433`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 233}], {
             RGBColor[
             0.832302226448087, 0.24929464417169217`, 0.1785659545678221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 267}], {
             RGBColor[
             0.9052536312416688, 0.5703031723537458, 0.2900897268509228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 406}], {
             RGBColor[
             0.9060315184464693, 0.5729271685521393, 0.29311167174990027`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 413}], {
             RGBColor[
             0.8976403406773998, 0.5446217555948332, 0.26051353065802335`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 443}], {
             RGBColor[
             0.8779783180841267, 0.47195372718941886`, 0.21716686938390278`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 476}], {
             RGBColor[
             0.834968541704233, 0.26978911161722496`, 0.18111922106827977`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 188}], {
             RGBColor[
             0.32203573450029344`, 0.4531724542663287, 0.9417474171352478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 192}], {
             RGBColor[
             0.28070448165153206`, 0.4123685862808082, 0.9392970770137636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 249}], {
             RGBColor[
             0.29817109629594896`, 0.43072710571942197`, 0.9402917748782225]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 260}], {
             RGBColor[
             0.2961853765948359, 0.4286399884116514, 0.940178691078853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 280}], {
             RGBColor[
             0.2818433506476452, 0.4135656098041881, 0.9393619339182866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 310}], {
             RGBColor[
             0.3017756973424442, 0.43451576996419494`, 0.9404970515752908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 327}], {
             RGBColor[
             0.28193174194509296`, 0.41365851466213766`, 0.939366967671913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 424}], {
             RGBColor[
             0.31369437792555, 0.4459475904500576, 0.9412159132702771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 483}], {
             RGBColor[
             0.3017217477257488, 0.43445906549644486`, 0.9404939792244313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 191}], {
             RGBColor[
             0.21120215837255008`, 0.3393172378127832, 0.9353390225224988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 212}], {
             RGBColor[
             0.21125959360220817`, 0.3393776058807578, 0.93534229337386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 287}], {
             RGBColor[
             0.20690732578417442`, 0.33480309645428663`, 0.9350944381602262]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 299}], {
             RGBColor[
             0.20658465608391344`, 0.3344639501408717, 0.9350760625981434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 301}], {
             RGBColor[
             0.2063778078751808, 0.33424653955855976`, 0.9350642828986606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 389}], {
             RGBColor[
             0.21125135912011495`, 0.33936895091798147`, 0.9353418244322866]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 451}], {
             RGBColor[
             0.20772437674817806`, 0.3356618688214776, 0.9351409680039076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 190}], {
             RGBColor[
             0.24652129125596123`, 0.3764398858356126, 0.9373503948902342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 195}], {
             RGBColor[
             0.2575424446398453, 0.3880238168235591, 0.9379780332711112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 263}], {
             RGBColor[
             0.25916680795964386`, 0.3897311256632503, 0.9380705383591434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 323}], {
             RGBColor[
             0.24213881509518778`, 0.3718336255256024, 0.9371008193561707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 342}], {
             RGBColor[
             0.25246005368067864`, 0.38268190168327626`, 0.9376885986247103]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 351}], {
             RGBColor[
             0.267489207183899, 0.39847849491853005`, 0.9385444866830785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[
             0.2571354474729763, 0.3875960369960689, 0.9379548553845563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 395}], {
             RGBColor[
             0.2549602684410159, 0.3853097859191623, 0.9378309821565751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 447}], {
             RGBColor[
             0.24571645560416666`, 0.3755939525360489, 0.9373045606905122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 452}], {
             RGBColor[
             0.2344431943228335, 0.36374504016331954`, 0.9366625651378359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 463}], {
             RGBColor[
             0.25601516257071727`, 0.38641854653362934`, 0.9378910568166856]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 174}], {
             RGBColor[
             0.2880991557381853, 0.4200673355937856, 0.9397208847641902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 229}], {
             RGBColor[
             0.3002585012900294, 0.4328475787158096, 0.940413341505228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 255}], {
             RGBColor[
             0.3535633647009796, 0.4806605487177418, 0.9437497228483069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 313}], {
             RGBColor[
             0.2882495492104231, 0.42022540866860447`, 0.9397294494499471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 338}], {
             RGBColor[
             0.314823265682197, 0.4471058220816644, 0.9412812379953546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 369}], {
             RGBColor[
             0.36474431369771637`, 0.4903449247678786, 0.944462163031454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 379}], {
             RGBColor[
             0.3094202014132221, 0.4424259593777846, 0.9409369595178776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 380}], {
             RGBColor[
             0.2911961325222311, 0.423322454553487, 0.9398972530104752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 390}], {
             RGBColor[
             0.30514733542854805`, 0.43798605336538, 0.9406917533770347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 425}], {
             RGBColor[
             0.3424420265478999, 0.47102780458425264`, 0.9430410810154058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 478}], {
             RGBColor[
             0.28779157321631055`, 0.419744046861437, 0.9397033683945971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 181}], {
             RGBColor[
             0.49329315877378277`, 0.5986309034651389, 0.9534977211263604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 235}], {
             RGBColor[
             0.4614654223098702, 0.5710633178486462, 0.9514696859030422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 262}], {
             RGBColor[
             0.520987467347936, 0.6220001220678183, 0.9554331883510561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 332}], {
             RGBColor[
             0.4840405870433834, 0.5906167908800439, 0.9529081554374272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 344}], {
             RGBColor[
             0.5148160505883743, 0.6169898879232494, 0.9549473518170989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 387}], {
             RGBColor[
             0.6705014636086952, 0.7413486854414358, 0.9685938847155504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 393}], {
             RGBColor[
             0.5135503027141461, 0.615962296777659, 0.9548477075078524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 403}], {
             RGBColor[
             0.7474005481861847, 0.8023032590432388, 0.9760248292713649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 232}], {
             RGBColor[
             0.4117533959329014, 0.5306819361106889, 0.9475625057353367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 307}], {
             RGBColor[
             0.4685593666518582, 0.5794366280637215, 0.9513058562137999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 350}], {
             RGBColor[
             0.41473957912155346`, 0.5332684178987681, 0.9477527826875395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 354}], {
             RGBColor[
             0.4145365045344412, 0.533092524898237, 0.9477398429544205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 372}], {
             RGBColor[
             0.46888111877498084`, 0.5796978409320405, 0.951331185719549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 479}], {
             RGBColor[
             0.4393999195807523, 0.5546279653397757, 0.9493241177753168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 180}], {
             RGBColor[
             0.2863372761085622, 0.4182890103949429, 0.9396178563251187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 216}], {
             RGBColor[
             0.28421479544229167`, 0.41605814864164575`, 0.9394969841911034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 238}], {
             RGBColor[
             0.31134876495031627`, 0.4435229307952213, 0.9410808428186908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 246}], {
             RGBColor[
             0.2983825090164457, 0.4309493138930047, 0.9403038145198976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 281}], {
             RGBColor[
             0.2737261355645935, 0.4050339020907391, 0.9388996705276503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 288}], {
             RGBColor[
             0.2793047597177943, 0.4108973897809534, 0.9392173649203402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 343}], {
             RGBColor[
             0.2977155588527831, 0.4302483069839126, 0.9402658326947413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 392}], {
             RGBColor[
             0.3042725009406671, 0.4371400688524187, 0.9406392408465198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 459}], {
             RGBColor[
             0.3465448636437761, 0.4740080224761397, 0.94332350710475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 465}], {
             RGBColor[
             0.2925845958094424, 0.42485533950351484`, 0.9399736319400027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 182}], {
             RGBColor[
             0.36805399542884243`, 0.4932116047339394, 0.9446730530247247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 206}], {
             RGBColor[
             0.3501277440364893, 0.4776847867774757, 0.9435308081375656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 282}], {
             RGBColor[
             0.4825898599888707, 0.5882261104425313, 0.9531290808792493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 324}], {
             RGBColor[
             0.3635993901479788, 0.48935324953462667`, 0.9443892095152808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 410}], {
             RGBColor[
             0.3605931713874897, 0.48674941394123933`, 0.9441976559141574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 441}], {
             RGBColor[
             0.4038268661048062, 0.5241962673166999, 0.9469524687114896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 164}], {
             RGBColor[
             0.819137437150352, 0.14810430478184575`, 0.1659593374688081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 396}], {
             RGBColor[
             0.9071481131704897, 0.5745522202562454, 0.3532052383412315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 443}], {
             RGBColor[
             0.877631072588452, 0.4692846461457165, 0.21683434670508697`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 165}], {
             RGBColor[
             0.4232575021072018, 0.5410261076098133, 0.9481905716557255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 268}], {
             RGBColor[
             0.41606826400089775`, 0.5347991509037464, 0.9477324797607855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 275}], {
             RGBColor[
             0.4180928553323577, 0.5365527501561378, 0.9478614849301503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 285}], {
             RGBColor[
             0.3684500451199806, 0.49355464307036695`, 0.9446982889608311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 324}], {
             RGBColor[
             0.3960795993510239, 0.5174859742435227, 0.9464588197245776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 353}], {
             RGBColor[
             0.531072144514868, 0.6293500407838779, 0.9564584330755022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 441}], {
             RGBColor[
             0.4363070753078513, 0.5523289920255958, 0.9490220789207864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 480}], {
             RGBColor[
             0.3880144919727734, 0.5105003835965654, 0.94594491821413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 481}], {
             RGBColor[
             0.3703492229848604, 0.49519961548147085`, 0.9448193028950042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 259}], {
             RGBColor[
             0.9260863286561598, 0.722291136783578, 0.31168537193130974`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 326}], {
             RGBColor[
             0.9327537347132191, 0.7525662704764362, 0.31724881897839763`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 341}], {
             RGBColor[
             0.9919526646253864, 0.9838559907810486, 0.4794106025405692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 387}], {
             RGBColor[
             0.8827228822801044, 0.901646814849579, 0.6975808353380122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 403}], {
             RGBColor[
             0.9596219668575938, 0.962601388451382, 0.7050117798938269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 405}], {
             RGBColor[
             0.9921723207517021, 0.9843258130245969, 0.5033188163295588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 450}], {
             RGBColor[
             0.9040202207813182, 0.5580851531997648, 0.2907664410126593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 469}], {
             RGBColor[
             0.9253813180460291, 0.7190898482623855, 0.3110970937968252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 491}], {
             RGBColor[
             0.992246695040947, 0.9844848921088973, 0.5114139987289448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 203}], {
             RGBColor[
             0.4982990262412239, 0.6035806234747654, 0.9536470711566374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 221}], {
             RGBColor[
             0.4993207487803075, 0.6044101038600693, 0.953727504897607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 223}], {
             RGBColor[
             0.4259476007932227, 0.5431195461878823, 0.9484273528030159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 258}], {
             RGBColor[
             0.4177269296537439, 0.5359992140298111, 0.9479035389072623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 289}], {
             RGBColor[
             0.45070123455015054`, 0.5645598995943251, 0.9500046324572284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 297}], {
             RGBColor[
             0.4906978130641887, 0.5974096161868968, 0.9530486758111798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 381}], {
             RGBColor[
             0.515668109442376, 0.6176816276857418, 0.9550144290112803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 439}], {
             RGBColor[
             0.6614719504889517, 0.7330346033014116, 0.9686938737233264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 187}], {
             RGBColor[
             0.2658102034815037, 0.3967137555723293, 0.9384488699060904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.2633838374698597, 0.39416349105360093`, 0.9383106919512142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 322}], {
             RGBColor[
             0.26310542995763675`, 0.3938708671061988, 0.9382948370552601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 364}], {
             RGBColor[
             0.2627794929075267, 0.39352828660093053`, 0.938276275422437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 437}], {
             RGBColor[
             0.26141138655191587`, 0.3920903200782306, 0.9381983637894169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 494}], {
             RGBColor[
             0.262747921993954, 0.39349510356905415`, 0.938274477505614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 166}], {
             RGBColor[
             0.8278225605966679, 0.21486196943559147`, 0.17427622148944416`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 227}], {
             RGBColor[
             0.8315779382096691, 0.24372744738608088`, 0.17787237533274636`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 309}], {
             RGBColor[
             0.9052777371288019, 0.5616050038337315, 0.3236174733815438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 348}], {
             RGBColor[
             0.8887181595032059, 0.5060713797566354, 0.23158979527643736`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 396}], {
             RGBColor[
             0.9055353853140414, 0.5621560872497313, 0.3516608883245811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 428}], {
             RGBColor[
             0.8239291026561835, 0.1849351455808791, 0.17054784176860438`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 443}], {
             RGBColor[
             0.8760183447320038, 0.45688851313920237`, 0.21528999668843654`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 182}], {
             RGBColor[
             0.4013099579800705, 0.5220162480025345, 0.9467920935513959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 268}], {
             RGBColor[
             0.4168440173490807, 0.5354710694634455, 0.9477819100781599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 275}], {
             RGBColor[
             0.41886860868054065`, 0.537224668715837, 0.9479109152475247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 282}], {
             RGBColor[
             0.5158458225400988, 0.6170307537111264, 0.9552481214059205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 285}], {
             RGBColor[
             0.3692257984681636, 0.49422656163006606`, 0.9447477192782054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 324}], {
             RGBColor[
             0.3968553526992069, 0.5181578928032218, 0.9465082500419522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 353}], {
             RGBColor[
             0.531847897863051, 0.630021959343577, 0.9565078633928767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 441}], {
             RGBColor[
             0.4370828286560343, 0.553000910585295, 0.9490715092381609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 481}], {
             RGBColor[
             0.3711249763330434, 0.49587153404117, 0.9448687332123786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 210}], {
             RGBColor[
             0.8370920629652436, 0.28611142656230293`, 0.18315270742599782`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 227}], {
             RGBColor[
             0.8418757895124331, 0.32288124504634075`, 0.18773360937003286`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 243}], {
             RGBColor[
             0.838713260625803, 0.29857266219470613`, 0.18470516813663024`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 309}], {
             RGBColor[
             0.9155755884315661, 0.6407588014939913, 0.33347870741883034`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 320}], {
             RGBColor[
             0.9133614547699682, 0.6417853106074096, 0.5113435478107814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 348}], {
             RGBColor[
             0.8990160108059699, 0.5852251774168952, 0.24145102931372386`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 428}], {
             RGBColor[
             0.8342269539589475, 0.26408894324113896`, 0.18040907580589088`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 495}], {
             RGBColor[
             0.8401614416386582, 0.3097040160564781, 0.18609194791002698`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 210}], {
             RGBColor[
             0.9113669843928855, 0.6334814540290358, 0.5263699322609554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 326}], {
             RGBColor[
             0.9309228830343801, 0.7574193985269815, 0.5440638154599668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 434}], {
             RGBColor[
             0.988936416573675, 0.989692938179159, 0.8330157392176978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 474}], {
             RGBColor[
             0.9898837045140847, 0.9900846660867081, 0.8173167265425048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 495}], {
             RGBColor[
             0.9144363630663, 0.657074043523211, 0.5293091727449846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 200}], {
             RGBColor[
             0.9058101136750496, 0.6632964389017137, 0.24302016366679569`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 213}], {
             RGBColor[
             0.9074990588325569, 0.6709655443987909, 0.2444294609060539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 254}], {
             RGBColor[
             0.5736452347236608, 0.5249664714796068, 0.591929563801219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 261}], {
             RGBColor[
             0.8953895182633258, 0.6159789489289689, 0.23432496342308617`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 315}], {
             RGBColor[
             0.5481459181329882, 0.49816507299275914`, 0.5904774154442385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 368}], {
             RGBColor[
             0.6594469349895435, 0.6059633899066202, 0.5971521921376893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 401}], {
             RGBColor[
             0.842122298838193, 0.7534870262743261, 0.6125668464325392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 500}], {
             RGBColor[
             0.8651424411448785, 0.41743131522220955`, 0.2066895157907081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 204}], {
             RGBColor[
             0.4973176178268257, 0.6027838719120118, 0.9535698110912385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 219}], {
             RGBColor[
             0.5095055418565787, 0.6126785776990856, 0.9545292891166974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 244}], {
             RGBColor[
             0.4175916065853016, 0.5350481346501237, 0.9481253168239769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 274}], {
             RGBColor[
             0.4777382226320348, 0.5868884368511786, 0.9520284493798168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 334}], {
             RGBColor[
             0.44777313143376407`, 0.5611898545063152, 0.9500484568988465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 337}], {
             RGBColor[
             0.6764764422213522, 0.7452210038115648, 0.9698692373870139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 340}], {
             RGBColor[
             0.41508837309382146`, 0.5328799596159772, 0.9479658129994224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 361}], {
             RGBColor[
             0.5684718159304661, 0.6605218314458838, 0.9591906270789168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 363}], {
             RGBColor[
             0.44877677089386697`, 0.5620591565622703, 0.9501124079177607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 370}], {
             RGBColor[
             0.5420927609464797, 0.6391343501937576, 0.9570946743743712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 498}], {
             RGBColor[
             0.4773158479045384, 0.5865455340196324, 0.9519951984940587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 171}], {
             RGBColor[
             0.2792113970027737, 0.4107992596479288, 0.9392120480518376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 238}], {
             RGBColor[
             0.3084172446419511, 0.44044171708200675`, 0.940913897073925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 265}], {
             RGBColor[
             0.3088475371272851, 0.4408144148056739, 0.9409413149305978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 266}], {
             RGBColor[
             0.29310065604108804`, 0.425397751527083, 0.9400030208067522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 328}], {
             RGBColor[
             0.3409967871765409, 0.4686604793300483, 0.9429898367152708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 374}], {
             RGBColor[
             0.2742054454433818, 0.40553768716334715`, 0.9389269665161719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 433}], {
             RGBColor[
             0.31109341012253816`, 0.4427596771133032, 0.9410844199719078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 216}], {
             RGBColor[
             0.26381410331866717`, 0.39461572774112796`, 0.9383351949547825]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 238}], {
             RGBColor[
             0.2909480728266918, 0.4220805098947036, 0.9399190535823698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 265}], {
             RGBColor[
             0.29137836531202577`, 0.42245320761837074`, 0.9399464714390425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 343}], {
             RGBColor[
             0.2773148667291586, 0.40880588608339485`, 0.9391040434584204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 385}], {
             RGBColor[
             0.24760690614002792`, 0.37758093591072595`, 0.9374122190518586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 391}], {
             RGBColor[
             0.25143472628896596`, 0.3816042175850748, 0.9376302077465881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 433}], {
             RGBColor[
             0.2936242383072788, 0.42439846992600005`, 0.9400895764803525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 465}], {
             RGBColor[
             0.27218390368581785`, 0.4034129186029971, 0.9388118427036817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 303}], {
             RGBColor[
             0.32845548787730483`, 0.4585909264869045, 0.9421616772940785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 366}], {
             RGBColor[
             0.3083293758751098, 0.43743710670339436`, 0.941015524989468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 448}], {
             RGBColor[
             0.45979588464643895`, 0.5695615806771241, 0.9513786855523698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 473}], {
             RGBColor[
             0.3392418574009336, 0.4682559789143286, 0.9428371690671595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 241}], {
             RGBColor[
             0.8450225482014433, 0.8788658384170731, 0.9383874109586698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 417}], {
             RGBColor[
             0.8427978094114925, 0.8771278555657226, 0.9381656697874536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 461}], {
             RGBColor[
             0.9645092309315171, 0.9729899937684735, 0.9422009085196323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 493}], {
             RGBColor[
             0.9890701085039466, 0.9882775676582451, 0.7238989830539463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 215}], {
             RGBColor[
             0.2753901052316153, 0.40678283971254936`, 0.9389944311385647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 229}], {
             RGBColor[
             0.2788164534778155, 0.4103841489623319, 0.9391895566023578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 294}], {
             RGBColor[
             0.2524849252558091, 0.3827080432856873, 0.9376900150241196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 338}], {
             RGBColor[
             0.29338121786998295`, 0.4246423923281867, 0.9400574530924843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 356}], {
             RGBColor[
             0.2679975194043914, 0.3990127632911238, 0.938573434312055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 390}], {
             RGBColor[
             0.28370528761633407`, 0.41552262361190234`, 0.9394679684741645]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 430}], {
             RGBColor[
             0.2531980668507343, 0.38345760031774234`, 0.9377306273829522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 309}], {
             RGBColor[
             0.9743805147039586, 0.9770030600582216, 0.7213206267986814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 320}], {
             RGBColor[
             0.9721663810423609, 0.9780295691716399, 0.8991854671906325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 337}], {
             RGBColor[
             0.9079704822927377, 0.9289384814961321, 0.9731750764283525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 348}], {
             RGBColor[
             0.9578209370783626, 0.9214694359811255, 0.6292929486935749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 361}], {
             RGBColor[
             0.7999658560018515, 0.8442393091304512, 0.9624964661202554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 370}], {
             RGBColor[
             0.7735868010178651, 0.822851827878325, 0.9604005134157099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 375}], {
             RGBColor[
             0.9569658514087618, 0.9674257829593813, 0.9577297678481509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 197}], {
             RGBColor[
             0.6522851143834272, 0.7277468526483104, 0.9663482548197164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 237}], {
             RGBColor[
             0.7565184993634433, 0.8098707472801487, 0.9765525722729846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 345}], {
             RGBColor[
             0.6333349002315553, 0.7129428013259062, 0.9644594745728776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 426}], {
             RGBColor[
             0.7385594994235554, 0.7955507282121491, 0.9748396268265297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 448}], {
             RGBColor[
             0.587441960125221, 0.6759508730452015, 0.9606647294533119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 245}], {
             RGBColor[
             0.21512971428686242`, 0.34344534810015337`, 0.9355626910215206]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 438}], {
             RGBColor[
             0.21508055771107348`, 0.3433936814222922, 0.9355598916272501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 455}], {
             RGBColor[
             0.2063185988388122, 0.33418430710726665`, 0.9350609110316312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 357}], {
             RGBColor[
             0.9494134599221778, 0.8301932628763469, 0.5158066666080678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 420}], {
             RGBColor[
             0.9801637329335828, 0.9834819259202605, 0.8627171585529716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 439}], {
             RGBColor[
             0.9262985601874452, 0.9413808299607197, 0.8870332114673454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 236}], {
             RGBColor[
             0.23312614698427564`, 0.36236073990487094`, 0.9365875612403018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 254}], {
             RGBColor[
             0.20771369325605188`, 0.33565063979388043`, 0.9351403595948358]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 276}], {
             RGBColor[
             0.39923464670294595`, 0.5037029404652202, 0.9483463693708659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 283}], {
             RGBColor[
             0.18007164814629245`, 0.3065970977766376, 0.9335661860185762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 292}], {
             RGBColor[
             0.17894988462017136`, 0.30541805318676885`, 0.9335023032452641]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 315}], {
             RGBColor[
             0.18221437666537932`, 0.3088492413070327, 0.9336882112378554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 325}], {
             RGBColor[
             0.1789730287155782, 0.30544237909846184`, 0.9335036212672588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 347}], {
             RGBColor[
             0.17892806853100302`, 0.30539512309383293`, 0.93350106085126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 368}], {
             RGBColor[
             0.2935153935219346, 0.41664755822089383`, 0.9403629879313062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 386}], {
             RGBColor[
             0.17892806853100302`, 0.30539512309383293`, 0.93350106085126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 401}], {
             RGBColor[
             0.47619075737058414`, 0.5641711945885997, 0.9557776422261561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 216}], {
             RGBColor[
             0.2680084621160904, 0.3990242647749275, 0.9385740574832979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 281}], {
             RGBColor[
             0.2575198022383923, 0.3880000182240208, 0.9379767438198447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 288}], {
             RGBColor[
             0.2630984263915931, 0.39386350591423513`, 0.9382944382125347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 343}], {
             RGBColor[
             0.28150922552658186`, 0.4132144231171943, 0.9393429059869358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 392}], {
             RGBColor[
             0.2880661676144659, 0.4201061849857004, 0.9397163141387143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 465}], {
             RGBColor[
             0.27637826248324115`, 0.40782145563679656`, 0.9390507052321971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 235}], {
             RGBColor[
             0.38886946031407776`, 0.511240914201845, 0.9459993960408191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 239}], {
             RGBColor[
             0.38581385669695734`, 0.5085943039277986, 0.9458046956803003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 262}], {
             RGBColor[
             0.4483915053521436, 0.5621777184210172, 0.9499628984888329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 296}], {
             RGBColor[
             0.3670585086059648, 0.49234936408258523`, 0.9446096214846453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 332}], {
             RGBColor[
             0.41144462504759094`, 0.5307943872332428, 0.947437865575204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 344}], {
             RGBColor[
             0.4422200885925819, 0.5571674842764482, 0.9494770619548758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 387}], {
             RGBColor[
             0.5979055016129029, 0.6815262817946347, 0.9631235948533272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 393}], {
             RGBColor[
             0.4409543407183537, 0.5561398931308579, 0.9493774176456293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 424}], {
             RGBColor[
             0.3706458143967508, 0.4954565080553325, 0.9448382014375043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 275}], {
             RGBColor[
             0.39614531120522645`, 0.517542890548859, 0.9464630068258206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 282}], {
             RGBColor[
             0.4931225250647846, 0.5973489755441486, 0.9538002129842165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 324}], {
             RGBColor[
             0.37413205522389265`, 0.49847611463624397`, 0.9450603416202481]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 441}], {
             RGBColor[
             0.41435953118072005`, 0.5333191324183171, 0.9476236008164568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 346}], {
             RGBColor[
             0.21142499907593382`, 0.3395514575209563, 0.9353517129708931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 404}], {
             RGBColor[
             0.20920782453695042`, 0.33722106650349953`, 0.9352254481609139]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 407}], {
             RGBColor[
             0.2096628417623121, 0.3376993184571131, 0.9352513607187605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 408}], {
             RGBColor[
             0.21373593745192992`, 0.3419804002760839, 0.9354833174926791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 192}], {
             RGBColor[
             0.25582325613433854`, 0.3862168407014245, 0.9378801280290341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 225}], {
             RGBColor[
             0.2656405828545585, 0.396535473538841, 0.9384392102623171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 249}], {
             RGBColor[
             0.2732898707787555, 0.40457536014003825`, 0.9388748258934928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 260}], {
             RGBColor[
             0.2713041510776424, 0.40248824283226764`, 0.9387617420941234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 280}], {
             RGBColor[
             0.2569621251304517, 0.38741386422480434`, 0.9379449849335569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 424}], {
             RGBColor[
             0.28881315240835653`, 0.41979584487067384`, 0.9397989642855475]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 440}], {
             RGBColor[
             0.26935285588816305`, 0.4004373078688641, 0.9386506187197652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 453}], {
             RGBColor[
             0.2706693526642461, 0.401821029451244, 0.9387255912635806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 470}], {
             RGBColor[
             0.2562569900664413, 0.3866727225643841, 0.9379048285348154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 193}], {
             RGBColor[
             0.28587823371129695`, 0.41780652773044813`, 0.9395917145396869]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 196}], {
             RGBColor[
             0.2898220421197416, 0.4219517204196188, 0.9398163085942062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 318}], {
             RGBColor[
             0.3129435362062064, 0.4431846498190406, 0.9412454229080396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 321}], {
             RGBColor[
             0.30856010126890854`, 0.43938793879419913`, 0.9409661143099544]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 330}], {
             RGBColor[
             0.29519715135054264`, 0.42760130102279975`, 0.9401224131131387]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 335}], {
             RGBColor[
             0.28035846079175497`, 0.4120048964181928, 0.9392773716376912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 350}], {
             RGBColor[
             0.3230573711356193, 0.45194474529877393`, 0.9418898675264287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 383}], {
             RGBColor[
             0.3064436349421723, 0.43755476203867083`, 0.9408312549471323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 409}], {
             RGBColor[
             0.262750205623448, 0.39349750380844273`, 0.9382746075549353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 482}], {
             RGBColor[
             0.32121309396000997`, 0.4503473251053272, 0.9417723518156291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 496}], {
             RGBColor[
             0.2804171463023576, 0.4120665786107125, 0.9392807136907027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 191}], {
             RGBColor[
             0.22705589567091367`, 0.35598052089836485`, 0.936241869408138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 202}], {
             RGBColor[
             0.2373837352876954, 0.3668357351584549, 0.9368300245956442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 212}], {
             RGBColor[
             0.22711333090057176`, 0.3560408889663394, 0.9362451402594992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 295}], {
             RGBColor[
             0.23264914651192115`, 0.36185938216484964`, 0.9365603967690603]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 300}], {
             RGBColor[
             0.23083402862066274`, 0.35995157817601575`, 0.9364570284903794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 389}], {
             RGBColor[
             0.22710509641847854`, 0.3560322340035631, 0.9362446713179258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 414}], {
             RGBColor[
             0.255184189019674, 0.3855451406447167, 0.937843734102269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 456}], {
             RGBColor[
             0.22968446940414386`, 0.35874331855319036`, 0.9363915627936191]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 485}], {
             RGBColor[
             0.24185580045044375`, 0.3715361591898116, 0.9370847020908353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 322}], {
             RGBColor[
             0.2619233226556958, 0.392628397381927, 0.9382275177931856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 494}], {
             RGBColor[
             0.26156581469201307`, 0.3922526338447824, 0.9382071582435395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 304}], {
             RGBColor[
             0.33792059600024626`, 0.4671115686975821, 0.9427529794590535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 310}], {
             RGBColor[
             0.3170171080071488, 0.4478975596227356, 0.9414616137808558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 483}], {
             RGBColor[
             0.31696315839045336`, 0.4478408551549855, 0.9414585414299963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 266}], {
             RGBColor[
             0.2746480537102089, 0.4060028965147674, 0.9389521724021874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 364}], {
             RGBColor[
             0.25917101959394173`, 0.3897355523579304, 0.9380707782054862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 374}], {
             RGBColor[
             0.2557528431125027, 0.3861428321510315, 0.9378761181116072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 437}], {
             RGBColor[
             0.25780291323833093`, 0.38829758583523044`, 0.9379928665724662]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 195}], {
             RGBColor[
             0.25913077183266553`, 0.38969324940897365`, 0.9380684861550228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 224}], {
             RGBColor[
             0.2735379552710175, 0.40483611267087094`, 0.938888953938319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 263}], {
             RGBColor[
             0.26075513515246407`, 0.3914005582486648, 0.9381609912430551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 323}], {
             RGBColor[
             0.243727142288008, 0.373503058111017, 0.9371912722400824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 342}], {
             RGBColor[
             0.25404838087349885`, 0.38435133426869084`, 0.9377790515086218]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 351}], {
             RGBColor[
             0.2690775343767192, 0.40014792750394457`, 0.9386349395669901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 356}], {
             RGBColor[
             0.2587237746657965, 0.38926546958148345`, 0.9380453082684679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 395}], {
             RGBColor[
             0.2565485956338361, 0.38697921850457684`, 0.9379214350404868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 452}], {
             RGBColor[
             0.2360315215156537, 0.3654144727487341, 0.9367530180217474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 463}], {
             RGBColor[
             0.2576034897635375, 0.3880879791190439, 0.9379815097005972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 212}], {
             RGBColor[
             0.21845881642544385`, 0.3469444455250692, 0.9357522784633475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 218}], {
             RGBColor[
             0.2251871593264507, 0.3540163605156067, 0.9361354476378685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 287}], {
             RGBColor[
             0.21410654860741013`, 0.342369936098598, 0.9355044232497137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 295}], {
             RGBColor[
             0.22399463203679326`, 0.35276293872357944`, 0.9360675349729086]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 299}], {
             RGBColor[
             0.21378387890714912`, 0.3420307897851831, 0.935486047687631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 300}], {
             RGBColor[
             0.22217951414553483`, 0.3508551347347456, 0.9359641666942277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 301}], {
             RGBColor[
             0.2135770306984165, 0.34181337920287114`, 0.935474267988148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 389}], {
             RGBColor[
             0.21845058194335062`, 0.3469357905622929, 0.9357518095217741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 451}], {
             RGBColor[
             0.21492359957141377`, 0.343228708465789, 0.9355509530933952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 456}], {
             RGBColor[
             0.22102995492901595`, 0.34964687511192016`, 0.9358987009974674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[
             0.26443196618769516`, 0.395265140791245, 0.9383703813311275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 249}], {
             RGBColor[
             0.27208125411189216`, 0.40330502739244223`, 0.938805996962303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 260}], {
             RGBColor[
             0.27009553441077905`, 0.4012179100846716, 0.9386929131629338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 280}], {
             RGBColor[
             0.25575350846358835`, 0.3861435314772083, 0.9378761560023672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 327}], {
             RGBColor[
             0.25584189976103616`, 0.38623643633515786`, 0.9378811897559938]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 470}], {
             RGBColor[
             0.255048373399578, 0.3854023898167881, 0.9378359996036256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 483}], {
             RGBColor[
             0.275631905541692, 0.4070369871694651, 0.9390082013085121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 196}], {
             RGBColor[
             0.29175552637074975`, 0.4239839349574104, 0.9399264176619675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 202}], {
             RGBColor[
             0.2634343891958272, 0.39421662412275726`, 0.9383135707972234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 232}], {
             RGBColor[
             0.32200467219797546`, 0.4513904780484862, 0.9418096996419872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 330}], {
             RGBColor[
             0.2971306356015508, 0.42963351556059126`, 0.9402325221809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 350}], {
             RGBColor[
             0.3249908553866274, 0.4539769598365655, 0.94199997659419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 354}], {
             RGBColor[
             0.3247877807995152, 0.4538010668360344, 0.941987036861071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 376}], {
             RGBColor[
             0.2836334092052663, 0.4154470748445156, 0.9394638751049887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 414}], {
             RGBColor[
             0.28123484292780576`, 0.41292602960901903`, 0.9393272803038482]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 415}], {
             RGBColor[
             0.28741220208324925`, 0.41941882574858214`, 0.9396790717691668]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 485}], {
             RGBColor[
             0.2679064543585755, 0.3989170481541139, 0.9385682482924145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 496}], {
             RGBColor[
             0.28235063055336573`, 0.41409879314850406`, 0.939390822758464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 228}], {
             RGBColor[
             0.9897986964683487, 0.9881510016226367, 0.6807237889593197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 388}], {
             RGBColor[
             0.9663440953419832, 0.9740339462184904, 0.9245637966956991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 490}], {
             RGBColor[
             0.9885348242076832, 0.9895268694153684, 0.8396711640099095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 224}], {
             RGBColor[
             0.28455910865490164`, 0.41642004365881735`, 0.9395165923191959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 263}], {
             RGBColor[
             0.27177628853634817`, 0.40298448923661123`, 0.9387886296239321]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 296}], {
             RGBColor[
             0.29178587282524443`, 0.4235837043718764, 0.9399439681205266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 323}], {
             RGBColor[
             0.2547482956718921, 0.38508698909896344`, 0.9378189106209592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 342}], {
             RGBColor[
             0.265069534257383, 0.39593526525663725`, 0.9384066898894987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 351}], {
             RGBColor[
             0.2800986877606033, 0.41173185849189103`, 0.9392625779478669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 395}], {
             RGBColor[
             0.26756974901772024`, 0.3985631494925233, 0.9385490734213637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 447}], {
             RGBColor[
             0.25832593618087096`, 0.38884731610940987`, 0.9380226519553008]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 453}], {
             RGBColor[
             0.27722937887191995`, 0.40871603292519376`, 0.9390991750514186]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 463}], {
             RGBColor[
             0.2686246431474216, 0.3996719101069903, 0.9386091480814742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 318}], {
             RGBColor[
             0.3188208288656592, 0.44936205704600285`, 0.9415801260303202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 321}], {
             RGBColor[
             0.31443739392836134`, 0.4455653460211614, 0.9413008174322348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 330}], {
             RGBColor[
             0.3010744440099954, 0.433778708249762, 0.9404571162354194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 335}], {
             RGBColor[
             0.2862357534512077, 0.4181823036451551, 0.9396120747599719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 350}], {
             RGBColor[
             0.3289346637950721, 0.4581221525257362, 0.9422245706487093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 354}], {
             RGBColor[
             0.32873158920795986`, 0.45794625952520507`, 0.9422116309155903]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 383}], {
             RGBColor[
             0.3123209276016251, 0.4437321692656331, 0.941165958069413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 414}], {
             RGBColor[
             0.2851786513362504, 0.4170712222981897, 0.9395518743583675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 479}], {
             RGBColor[
             0.35359500425427093`, 0.4794816999667437, 0.9437959057364866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 482}], {
             RGBColor[
             0.3270903866194627, 0.45652473233228946`, 0.9421070549379097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 496}], {
             RGBColor[
             0.2862944389618104, 0.41824398583767475`, 0.9396154168129832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 237}], {
             RGBColor[
             0.8018590077882369, 0.845833600411511, 0.9807007779188375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 270}], {
             RGBColor[
             0.843824355466433, 0.8769260052856713, 0.8927516199339326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 345}], {
             RGBColor[
             0.6786754086563489, 0.7489056544572683, 0.9686076802187304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 375}], {
             RGBColor[
             0.8279135305907634, 0.8660284937370616, 0.9630673509377192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 426}], {
             RGBColor[
             0.7839000078483491, 0.8315135813435113, 0.9789878324723824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 448}], {
             RGBColor[
             0.6327824685500147, 0.7119137261765637, 0.9648129350991647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 489}], {
             RGBColor[
             0.843861608566709, 0.8769414103999965, 0.8921342396544271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 223}], {
             RGBColor[
             0.335871613441881, 0.4628528461466326, 0.9427133713948876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 373}], {
             RGBColor[
             0.28774746699468884`, 0.4197712104275283, 0.9396981646098933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 480}], {
             RGBColor[
             0.3177133386514768, 0.44712506118461215`, 0.9415563421819749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 208}], {
             RGBColor[
             0.33248120157791744`, 0.46240023864087376`, 0.9424063860563303]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 220}], {
             RGBColor[
             0.3408785418830542, 0.4696735927505875, 0.9429414571550971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 349}], {
             RGBColor[
             0.3782226741008029, 0.5020192031069408, 0.9453209922378925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 359}], {
             RGBColor[
             0.364147570424561, 0.48982805573786037`, 0.9444241390777679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 371}], {
             RGBColor[
             0.3528938984406201, 0.480080690691371, 0.9437070650501826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 382}], {
             RGBColor[
             0.31253428709090747`, 0.4426711481132517, 0.9412251688089472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 397}], {
             RGBColor[
             0.3506959657134314, 0.47817695183439113`, 0.9435670147203616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 419}], {
             RGBColor[
             0.4277672068152066, 0.5433200836247167, 0.948923355062986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 427}], {
             RGBColor[
             0.31117200287913815`, 0.44123930103287445`, 0.9411475887384059]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 429}], {
             RGBColor[
             0.318220922727511, 0.44864816272084596`, 0.9415490142958283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 213}], {
             RGBColor[
             0.9025169525103827, 0.6502340737413859, 0.24037009445756363`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 243}], {
             RGBColor[
             0.8700670583525245, 0.4728472627689348, 0.21211683898241762`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 254}], {
             RGBColor[
             0.5686631284014866, 0.5042350008222019, 0.5878701973527287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 259}], {
             RGBColor[
             0.8813343532764009, 0.5540488379416193, 0.22269481442370878`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 401}], {
             RGBColor[
             0.8371401925160188, 0.7327555556169211, 0.6085074799840489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 450}], {
             RGBColor[
             0.8592682454015592, 0.38984285435780597`, 0.20177588350505832`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 454}], {
             RGBColor[
             0.9003552167733437, 0.640418136645701, 0.2385662891695866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 469}], {
             RGBColor[
             0.8806293426662699, 0.5508475494204266, 0.22210653628922422`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 471}], {
             RGBColor[
             0.8788202951923778, 0.5401284768128874, 0.22049894846562806`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 475}], {
             RGBColor[
             0.8699156991968737, 0.47168384997259694`, 0.2119718972840306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 500}], {
             RGBColor[
             0.8601603348227043, 0.3966998445648045, 0.2026301493422178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 222}], {
             RGBColor[
             0.3735862388275236, 0.49760697262793063`, 0.9450400762157048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 246}], {
             RGBColor[
             0.2993400916080083, 0.43195579391098005`, 0.9403583474318706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 256}], {
             RGBColor[
             0.2969224563599441, 0.4294147059783363, 0.9402206666810642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 271}], {
             RGBColor[
             0.2801320470703391, 0.4117669212415258, 0.9392644777112058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 312}], {
             RGBColor[
             0.30443515610797417`, 0.4373110297461917, 0.9406485038176712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 333}], {
             RGBColor[
             0.34155395478950024`, 0.4698622181836031, 0.9429990074018386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 400}], {
             RGBColor[
             0.30019030163233085`, 0.432849418552972, 0.9404067656349827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 442}], {
             RGBColor[
             0.2942020501296223, 0.426555386546551, 0.9400657435707277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 444}], {
             RGBColor[
             0.2878759109078417, 0.4199062131240665, 0.9397054793007316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 492}], {
             RGBColor[
             0.29053904388296076`, 0.4227053347332997, 0.9398571407839125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 211}], {
             RGBColor[
             0.2350487330765592, 0.3643814997868598, 0.9366970496740461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 414}], {
             RGBColor[
             0.25685751416132785`, 0.38730391146353665`, 0.9379390274936235]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 485}], {
             RGBColor[
             0.2435291255920976, 0.37329493000863156`, 0.9371799954821897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 497}], {
             RGBColor[
             0.23752535161991525`, 0.36698458290261204`, 0.9368380894362616]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 221}], {
             RGBColor[
             0.5355883582024223, 0.6338537830261275, 0.9565826239639467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 258}], {
             RGBColor[
             0.45399453907585874`, 0.5654428931958693, 0.950758657973602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 289}], {
             RGBColor[
             0.48696884397226536`, 0.5940035787603833, 0.9528597515235682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 291}], {
             RGBColor[
             0.5947468881404891, 0.681688814806365, 0.9613714325118958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 297}], {
             RGBColor[
             0.5269654224863035, 0.6268532953529551, 0.9559037948775195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 381}], {
             RGBColor[
             0.5519357188644908, 0.6471253068518, 0.9578695480776199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 397}], {
             RGBColor[
             0.44655734447149653`, 0.5590011690338403, 0.950284766509865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 419}], {
             RGBColor[
             0.5236285855732716, 0.6241443008241659, 0.9556411068524893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 439}], {
             RGBColor[
             0.6977395599110665, 0.7624782824674698, 0.971548992789666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 219}], {
             RGBColor[
             0.5140809753819581, 0.6163931207559199, 0.9548894840041806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 244}], {
             RGBColor[
             0.42216704011068096`, 0.5387626777069581, 0.9484855117114601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 274}], {
             RGBColor[
             0.4823136561574142, 0.5906029799080129, 0.9523886442672999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 334}], {
             RGBColor[
             0.4523485649591434, 0.5649043975631496, 0.9504086517863296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 337}], {
             RGBColor[
             0.6810518757467315, 0.7489355468683991, 0.970229432274497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 340}], {
             RGBColor[
             0.4196638066192008, 0.5365945026728116, 0.9483260078869054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 361}], {
             RGBColor[
             0.5730472494558454, 0.6642363745027182, 0.9595508219663998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 362}], {
             RGBColor[
             0.4451772959687064, 0.5586930048020928, 0.9499517048675632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 363}], {
             RGBColor[
             0.4533522044192463, 0.5657736996191047, 0.9504726028052438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 370}], {
             RGBColor[
             0.546668194471859, 0.642848893250592, 0.9574548692618543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 498}], {
             RGBColor[
             0.4818912814299178, 0.5902600770764668, 0.9523553933815417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 228}], {
             RGBColor[
             0.9934539331599859, 0.9884069498751192, 0.5288792059852668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 252}], {
             RGBColor[
             0.8648112867502258, 0.89136633503373, 0.7718692919288858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 388}], {
             RGBColor[
             0.9699993320336204, 0.9742898944709728, 0.7727192137216462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 432}], {
             RGBColor[
             0.9462255159241673, 0.9556033712696023, 0.7798152269955922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 490}], {
             RGBColor[
             0.9921900608993205, 0.9897828176678509, 0.6878265810358566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 266}], {
             RGBColor[
             0.31612745049209645`, 0.4464579350707817, 0.9414294227127427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 410}], {
             RGBColor[
             0.35319958507105037`, 0.4803454610863929, 0.9437265431319655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 218}], {
             RGBColor[
             0.22451796602725682`, 0.35331299592884813`, 0.9360973380694622]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 287}], {
             RGBColor[
             0.21343735530821623`, 0.3416665715118395, 0.9354663136813074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 295}], {
             RGBColor[
             0.22332543873759936`, 0.352059574136821, 0.9360294254045023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 336}], {
             RGBColor[
             0.2196507706490151, 0.34819726498830533`, 0.9358201584930417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 389}], {
             RGBColor[
             0.21778138864415675`, 0.3462324259755344, 0.9357136999533677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 409}], {
             RGBColor[
             0.22930932819200256`, 0.35834902135390323`, 0.9363701990565594]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 456}], {
             RGBColor[
             0.2203607616298221, 0.3489435105251617, 0.9358605914290611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 458}], {
             RGBColor[
             0.22378112515977486`, 0.35253852945871533`, 0.9360553760721175]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[
             0.3477704837485026, 0.4756430463953687, 0.9433806055964585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 289}], {
             RGBColor[
             0.3807447886449092, 0.5042037319598828, 0.9454816991464247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 314}], {
             RGBColor[
             0.32609699892407057`, 0.4568705631814669, 0.9419995903085558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 349}], {
             RGBColor[
             0.3678599975315118, 0.49304357350588934`, 0.9446606916502523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 359}], {
             RGBColor[
             0.3537848938552699, 0.480852426136809, 0.9437638384901277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 397}], {
             RGBColor[
             0.3403332891441403, 0.46920132223333977`, 0.9429067141327215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 427}], {
             RGBColor[
             0.3008093263098471, 0.4322636714318231, 0.9404872881507658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 472}], {
             RGBColor[
             0.32528262084800263`, 0.45616518982380916`, 0.9419476988576752]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 214}], {
             RGBColor[
             0.3828653435329973, 0.49291080046599856`, 0.946830407391962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 233}], {
             RGBColor[
             0.7045416845554648, 0.49561598240663746`, 0.5739669497124782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 273}], {
             RGBColor[
             0.4297324939516893, 0.5421711471050089, 0.9494994222745707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 421}], {
             RGBColor[
             0.37249008899703795`, 0.4820057501195733, 0.9462395519949527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 423}], {
             RGBColor[
             0.37687473184245884`, 0.48661428775252374`, 0.9464892509185017]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 477}], {
             RGBColor[
             0.40529759982577535`, 0.5164885241169046, 0.9481078912022864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 227}], {
             RGBColor[
             0.8408474405782448, 0.3149769045127923, 0.18674886126930004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 243}], {
             RGBColor[
             0.8376849116916145, 0.29066832166115775`, 0.18372042003589745`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 326}], {
             RGBColor[
             0.8556196126725499, 0.40214503052670025`, 0.19986184252427644`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 348}], {
             RGBColor[
             0.8979876618717816, 0.5773208368833467, 0.24046628121299102`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 428}], {
             RGBColor[
             0.8331986050247592, 0.2561846027075905, 0.17942432770515804`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 434}], {
             RGBColor[
             0.9136331462118448, 0.6344185701788778, 0.48881376628200723`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 469}], {
             RGBColor[
             0.8482471960053599, 0.3686686083126496, 0.19371011734270402`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 474}], {
             RGBColor[
             0.9145804341522545, 0.6348102980864267, 0.4731147536068143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 495}], {
             RGBColor[
             0.8391330927044698, 0.3017996755229297, 0.18510719980929416`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 464}], {
             RGBColor[
             0.23745358448324252`, 0.36690915109166977`, 0.936834002403998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 485}], {
             RGBColor[
             0.23952079823930758`, 0.3690819238182165, 0.9369517271692371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 497}], {
             RGBColor[
             0.23351702426712523`, 0.36277157671219695`, 0.936609821123309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 287}], {
             RGBColor[
             0.21416398383706822`, 0.3424303041665726, 0.9355076941010749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 295}], {
             RGBColor[
             0.22405206726645135`, 0.35282330679155405`, 0.9360708058242697]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 299}], {
             RGBColor[
             0.21384131413680724`, 0.3420911578531577, 0.9354893185389921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 300}], {
             RGBColor[
             0.22223694937519295`, 0.35091550280272016`, 0.9359674375455889]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 301}], {
             RGBColor[
             0.2136344659280746, 0.34187374727084574`, 0.9354775388395093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 389}], {
             RGBColor[
             0.21850801717300872`, 0.34699615863026745`, 0.9357550803731354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 451}], {
             RGBColor[
             0.21498103480107186`, 0.34328907653376356`, 0.9355542239447563]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 456}], {
             RGBColor[
             0.22108739015867407`, 0.34970724317989477`, 0.9359019718488286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 254}], {
             RGBColor[
             0.5703520735589939, 0.511904106319279, 0.5892794945919869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 259}], {
             RGBColor[
             0.8830232984339081, 0.5617179434386964, 0.224104111662967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 261}], {
             RGBColor[
             0.8920963570986589, 0.602916583768641, 0.23167489421385412`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 315}], {
             RGBColor[
             0.5448527569683213, 0.48510270783243126`, 0.5878273462350064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 368}], {
             RGBColor[
             0.6561537738248766, 0.5929010247462924, 0.5945021229284573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 401}], {
             RGBColor[
             0.8388291376735261, 0.7404246611139982, 0.6099167772233072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 450}], {
             RGBColor[
             0.8609571905590665, 0.3975119598548832, 0.20318518074431657`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 454}], {
             RGBColor[
             0.902044161930851, 0.6480872421427781, 0.23997558640884487`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 471}], {
             RGBColor[
             0.8805092403498851, 0.5477975823099646, 0.2219082457048863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 475}], {
             RGBColor[
             0.871604644354381, 0.4793529554696741, 0.21338119452328883`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 500}], {
             RGBColor[
             0.8618492799802115, 0.40436895006188167`, 0.20403944658147605`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 273}], {
             RGBColor[
             0.24667426527178135`, 0.3766006712253524, 0.9373591065341305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 302}], {
             RGBColor[
             0.19497823659732902`, 0.32226486737097304`, 0.9344150941785414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 347}], {
             RGBColor[
             0.1893670574265447, 0.316367162293171, 0.9340955458257609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 421}], {
             RGBColor[
             0.18943186031713002`, 0.3164352742399168, 0.9340992362545124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 423}], {
             RGBColor[
             0.19381650316255092`, 0.32104381187286724`, 0.9343489351780614]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 477}], {
             RGBColor[
             0.2222393711458674, 0.35091804823724815`, 0.9359675754618462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 224}], {
             RGBColor[
             0.2915446973152564, 0.4237623402527527, 0.9399144112591507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 351}], {
             RGBColor[
             0.28708427642095813`, 0.4190741550858264, 0.9396603968878219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 356}], {
             RGBColor[
             0.2767305167100354, 0.40819169716336523`, 0.9390707655892996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 430}], {
             RGBColor[
             0.26193106415637823`, 0.3926365341899838, 0.9382279586601969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 238}], {
             RGBColor[
             0.29301995095784455`, 0.42425818517520597`, 0.9400370439768699]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 281}], {
             RGBColor[
             0.2553973215721218, 0.3857691564707237, 0.9378558716858294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 343}], {
             RGBColor[
             0.2793867448603114, 0.4109835613638972, 0.9392220338529205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 465}], {
             RGBColor[
             0.27425578181697063`, 0.40559059388349944`, 0.9389298330981818]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 290}], {
             RGBColor[
             0.3031025001174864, 0.43489572471311266`, 0.9406097604733883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 340}], {
             RGBColor[
             0.32857716094804046`, 0.4590187548700618, 0.9421576240396021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 355}], {
             RGBColor[
             0.32421328138501737`, 0.4552389817275355, 0.9418795614926734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 362}], {
             RGBColor[
             0.35409065029754605`, 0.481117256999343, 0.9437833210202597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 378}], {
             RGBColor[
             0.30140209308183147`, 0.4331084891066064, 0.9405129248082346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 384}], {
             RGBColor[
             0.30177027996931804`, 0.4334954768697517, 0.9405338925067932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 498}], {
             RGBColor[
             0.3908046357587574, 0.5126843292737169, 0.9461870095342384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 295}], {
             RGBColor[
             0.2307804101674582, 0.3598952217820915, 0.9364539749987908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.22896529227619977`, 0.3579874177932576, 0.93635060672011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 336}], {
             RGBColor[
             0.2271057420788739, 0.35603291263357584`, 0.9362447080873302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 389}], {
             RGBColor[
             0.22523636007401557`, 0.35406807362080495`, 0.9361382495476563]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 409}], {
             RGBColor[
             0.2367642996218614, 0.3661846689991738, 0.9367947486508479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 456}], {
             RGBColor[
             0.2278157330596809, 0.3567791581704322, 0.9362851410233497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 458}], {
             RGBColor[
             0.23123609658963368`, 0.36037417710398584`, 0.936479925666406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 244}], {
             RGBColor[
             0.43435496414043395`, 0.548657383494032, 0.949444989736919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 274}], {
             RGBColor[
             0.49450158018716717`, 0.6004976856950868, 0.9533481222927589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 334}], {
             RGBColor[
             0.4645364889888964, 0.5747991033502236, 0.9513681298117886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 337}], {
             RGBColor[
             0.6932397997764845, 0.7588302526554731, 0.971188910299956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 340}], {
             RGBColor[
             0.43185173064895377`, 0.5464892084598855, 0.9492854859123644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 361}], {
             RGBColor[
             0.5852351734855985, 0.6741310802897922, 0.9605102999918589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 363}], {
             RGBColor[
             0.4655401284489993, 0.5756684054061787, 0.9514320808307029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 369}], {
             RGBColor[
             0.47310816162837227`, 0.5822234553657439, 0.9519143092127434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 370}], {
             RGBColor[
             0.5588561185016121, 0.6527435990376659, 0.9584143472873132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 498}], {
             RGBColor[
             0.49407920545967077`, 0.6001547828635406, 0.9533148714070008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 349}], {
             RGBColor[
             0.3762573378366486, 0.5003169276156031, 0.9451957627490192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 359}], {
             RGBColor[
             0.3621822341604067, 0.48812578024652276`, 0.9442989095888945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 371}], {
             RGBColor[
             0.3509285621764658, 0.4783784152000333, 0.9435818355613093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 382}], {
             RGBColor[
             0.3105689508267532, 0.4409688726219141, 0.9410999393200739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 416}], {
             RGBColor[
             0.3002234451567067, 0.4300950902197503, 0.9405107780769688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 427}], {
             RGBColor[
             0.30920666661498386`, 0.43953702554153684`, 0.9410223592495326]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 429}], {
             RGBColor[
             0.3162555864633567, 0.44694588722950834`, 0.9414237848069549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 499}], {
             RGBColor[
             0.2998159216660946, 0.42966675719263536`, 0.9404875702170554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 223}], {
             RGBColor[
             0.46323693275442124`, 0.5733927057392445, 0.9513629056103252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 258}], {
             RGBColor[
             0.45501626161494246`, 0.5662723735811732, 0.9508390917145717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 297}], {
             RGBColor[
             0.5279871450253872, 0.627682775738259, 0.9559842286184892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 381}], {
             RGBColor[
             0.5529574414035745, 0.647954787237104, 0.9579499818185896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 439}], {
             RGBColor[
             0.6987612824501502, 0.7633077628527738, 0.9716294265306357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 307}], {
             RGBColor[
             0.456261635454359, 0.5691648443465238, 0.950417290103996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 333}], {
             RGBColor[
             0.41068141899913524`, 0.5301333365139219, 0.9473892347606732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 372}], {
             RGBColor[
             0.4565833875774816, 0.5694260572148426, 0.9504426196097452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 417}], {
             RGBColor[
             0.5718731828738293, 0.6621247011020224, 0.9601331729684849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 258}], {
             RGBColor[
             0.3816431136278576, 0.5049818159089863, 0.9455389396199805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 268}], {
             RGBColor[
             0.3997592820050565, 0.5206731304122181, 0.946693285849477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 373}], {
             RGBColor[
             0.3417396383201442, 0.4690205123479532, 0.9430475467307398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 381}], {
             RGBColor[
             0.47958429341648956`, 0.5866642295649169, 0.9526498297239985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 480}], {
             RGBColor[
             0.3717055099769321, 0.496374363105037, 0.9449057243028214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 263}], {
             RGBColor[
             0.2861834719747001, 0.4181273524985085, 0.9396090974072282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 342}], {
             RGBColor[
             0.2794767176957349, 0.41107812851853454`, 0.939227157672795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 351}], {
             RGBColor[
             0.29450587119895527`, 0.4268747217537883, 0.9400830457311632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 356}], {
             RGBColor[
             0.28415211148803254`, 0.41599226383132715`, 0.939493414432641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 463}], {
             RGBColor[
             0.2830318265857735, 0.4148147733688876, 0.9394296158647704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 235}], {
             RGBColor[
             0.31564550837904015`, 0.44462855110700683`, 0.9414504121909557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 249}], {
             RGBColor[
             0.28189858083211217`, 0.41362366022985875`, 0.9393650791955862]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 260}], {
             RGBColor[
             0.27991286113099906`, 0.41153654292208813`, 0.9392519953962168]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 280}], {
             RGBColor[
             0.26557083518380836`, 0.39646216431462483`, 0.9384352382356503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 296}], {
             RGBColor[
             0.29383455667092717`, 0.42573700098774714`, 0.940060637634782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 424}], {
             RGBColor[
             0.2974218624617132, 0.42884414496049433`, 0.940289217587641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 440}], {
             RGBColor[
             0.27796156594151966`, 0.4094856079586846, 0.9391408720218586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 453}], {
             RGBColor[
             0.2792780627176027, 0.4108693295410645, 0.939215844565674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 470}], {
             RGBColor[
             0.26486570011979793`, 0.3957210226542046, 0.9383950818369088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 236}], {
             RGBColor[
             0.23337407460187973`, 0.3626213275504917, 0.9366016803513484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 283}], {
             RGBColor[
             0.18031957576389654`, 0.30685768542225833`, 0.9335803051296228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 292}], {
             RGBColor[
             0.17919781223777545`, 0.3056786408323896, 0.9335164223563106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 308}], {
             RGBColor[
             0.17918563853241248`, 0.3056658454961956, 0.9335157290817995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 386}], {
             RGBColor[
             0.1791759961486071, 0.30565571073945375`, 0.9335151799623065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 396}], {
             RGBColor[
             0.5864855268156967, 0.6472607121015193, 0.7362180745608087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 422}], {
             RGBColor[
             0.20671849831186667`, 0.3346046268085379, 0.9350836847150235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 446}], {
             RGBColor[
             0.20378813280661343`, 0.33152462686661266`, 0.9349168047345866]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 309}], {
             RGBColor[
             0.9193309660445672, 0.6696242794444807, 0.3370748612621325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 320}], {
             RGBColor[
             0.9171168323829694, 0.670650788557899, 0.5149397016540836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 348}], {
             RGBColor[
             0.9027713884189711, 0.6140906553673846, 0.24504718315702606`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 428}], {
             RGBColor[
             0.8379823315719487, 0.29295442119162834`, 0.18400522964919308`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 495}], {
             RGBColor[
             0.8439168192516593, 0.3385694940069675, 0.1896881017533292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 388}], {
             RGBColor[
             0.9696267022726579, 0.9734928770909221, 0.7321607638451979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 490}], {
             RGBColor[
             0.9918174311383581, 0.9889858002878001, 0.6472681311594083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 244}], {
             RGBColor[
             0.3167084139494082, 0.447095666264713, 0.9414615153937971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 248}], {
             RGBColor[
             0.2667577277658053, 0.3977096636716398, 0.9385028300123448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 255}], {
             RGBColor[
             0.34428066244060973`, 0.47097736208628804`, 0.9432183946864745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 313}], {
             RGBColor[
             0.2789668469500533, 0.41054222203715074`, 0.9391981212881146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 338}], {
             RGBColor[
             0.3055405634218271, 0.43742263545021065`, 0.9407499098335221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 379}], {
             RGBColor[
             0.30013749915285226`, 0.43274277274633094`, 0.9404056313560452]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 380}], {
             RGBColor[
             0.2819134302618612, 0.4136392679220333, 0.9393659248486427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 390}], {
             RGBColor[
             0.29586463316817824`, 0.4283028667339263, 0.9401604252152023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 411}], {
             RGBColor[
             0.26528288174741516`, 0.39615950699567326`, 0.9384188397134368]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 478}], {
             RGBColor[
             0.27850887095594073`, 0.41006086022998334`, 0.9391720402327646]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 242}], {
             RGBColor[
             0.2244428247428983, 0.35323401767475476`, 0.9360930588844796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 339}], {
             RGBColor[
             0.21778435426976317`, 0.3462355430360783, 0.9357138688413589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 365}], {
             RGBColor[
             0.22042634378562792`, 0.3490124415290624, 0.9358643262358141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 374}], {
             RGBColor[
             0.23780417240741958`, 0.3672776412285381, 0.9368539678676315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 391}], {
             RGBColor[
             0.23250262506826308`, 0.3617053788375689, 0.936552052589603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 246}], {
             RGBColor[
             0.27633388437422024`, 0.407774811430481, 0.93904817796454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 256}], {
             RGBColor[
             0.27391624912615603`, 0.40523372349783726`, 0.9389104972137335]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 271}], {
             RGBColor[
             0.25712583983655113`, 0.38758593876102676`, 0.9379543082438752]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 288}], {
             RGBColor[
             0.2572561350755689, 0.3877228873184297, 0.9379617283649826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 442}], {
             RGBColor[
             0.2711958428958343, 0.40237440406605196`, 0.938755574103397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 444}], {
             RGBColor[
             0.2648697036740537, 0.39572523064356746`, 0.938395309833401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 492}], {
             RGBColor[
             0.2675328366491727, 0.39852435225280064`, 0.9385469713165818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 307}], {
             RGBColor[
             0.4130035971526026, 0.5316969057817654, 0.9476609261549895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 312}], {
             RGBColor[
             0.3303045820158528, 0.4601142095117522, 0.9422823672274991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 330}], {
             RGBColor[
             0.3313235898372211, 0.4611852513408379, 0.942340398215439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 350}], {
             RGBColor[
             0.3591838096222978, 0.48552869561681206`, 0.944107852628729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 354}], {
             RGBColor[
             0.35898073503518557`, 0.48535280261628094`, 0.94409491289561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 372}], {
             RGBColor[
             0.41332534927572523`, 0.5319581186500844, 0.9476862556607386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 376}], {
             RGBColor[
             0.3178263634409366, 0.4469988106247622, 0.9415717511395277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 400}], {
             RGBColor[
             0.3260597275402094, 0.45565259831853255`, 0.9420406290448107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 414}], {
             RGBColor[
             0.31542779716347613`, 0.44447776538926564`, 0.9414351563383871]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 415}], {
             RGBColor[
             0.3216051563189196, 0.45097056152882875`, 0.9417869478037058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 476}], {
             RGBColor[
             0.8458261121541704, 0.35324515591315253`, 0.19151644279301172`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 235}], {
             RGBColor[
             0.3728101836078023, 0.49733117588158576`, 0.9449761131297559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[
             0.36975457999068184`, 0.4946845656075394, 0.9447814127692372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 262}], {
             RGBColor[
             0.4323322286458682, 0.548267980100758, 0.9489396155777698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 296}], {
             RGBColor[
             0.3509992318996893, 0.478439625762326, 0.9435863385735823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 332}], {
             RGBColor[
             0.3953853483413155, 0.5168846489129837, 0.946414582664141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 393}], {
             RGBColor[
             0.42489506401207827`, 0.5422301548105988, 0.9483541347345662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 468}], {
             RGBColor[
             0.4334778335161593, 0.5491980337433716, 0.9490298017896481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 239}], {
             RGBColor[
             0.35398612023304477`, 0.4810267183113057, 0.943776660456982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 249}], {
             RGBColor[
             0.32329479630323715`, 0.4526684377082041, 0.9418860278221313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 260}], {
             RGBColor[
             0.32130907660212404`, 0.45058132040043347`, 0.941772944022762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 262}], {
             RGBColor[
             0.416563768888231, 0.5346101328045243, 0.9479348632655147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 296}], {
             RGBColor[
             0.3352307721420522, 0.4647817784660925, 0.9425815862613272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 332}], {
             RGBColor[
             0.37961688858367837`, 0.50322680161675, 0.9454098303518859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 344}], {
             RGBColor[
             0.4103923521286693, 0.5295998986599555, 0.9474490267315575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 393}], {
             RGBColor[
             0.40912660425444114`, 0.5285723075143651, 0.947349382422311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 424}], {
             RGBColor[
             0.3388180779328382, 0.46788892243883967`, 0.9428101662141861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 440}], {
             RGBColor[
             0.3193577814126447, 0.44853038543702994`, 0.9416618206484036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 453}], {
             RGBColor[
             0.32067427818872773`, 0.4499141070194098, 0.9417367931922191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 243}], {
             RGBColor[
             0.5633146331293595, 0.36122739545781846`, 0.562473440762307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 276}], {
             RGBColor[
             0.45343165662521556`, 0.5606674341824253, 0.9514328089086481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 283}], {
             RGBColor[
             0.23426865806856206`, 0.3635615914938426, 0.9366526255563583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 292}], {
             RGBColor[
             0.23314689454244097`, 0.36238254690397387`, 0.9365887427830462]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 396}], {
             RGBColor[
             0.6404346091203621, 0.7039646181731036, 0.7392903949875442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 422}], {
             RGBColor[
             0.26066758061653217`, 0.39130853288012224`, 0.9381560051417591]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 267}], {
             RGBColor[
             0.9475774996267206, 0.9513626199375382, 0.7014579081154306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 270}], {
             RGBColor[
             0.9480577404464491, 0.9590498999175098, 0.9029559373872008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 329}], {
             RGBColor[
             0.8943251384864865, 0.9185746058926771, 0.989782724153959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 426}], {
             RGBColor[
             0.8881333928283652, 0.9136374759753497, 0.9891921499256506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 448}], {
             RGBColor[
             0.7370158535300309, 0.7940376208084021, 0.9750172525524329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 489}], {
             RGBColor[
             0.9480949935467251, 0.959065305031835, 0.9023385571076953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 265}], {
             RGBColor[
             0.32058421295120315`, 0.4520956650524487, 0.9416483204611299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 328}], {
             RGBColor[
             0.35273346300045894`, 0.47994172957682313`, 0.943696842245803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 343}], {
             RGBColor[
             0.306520714368336, 0.43844834351747275`, 0.9408058924805078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 431}], {
             RGBColor[
             0.38434692528377257`, 0.5073237216678145, 0.9457112241078087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 433}], {
             RGBColor[
             0.32283008594645624`, 0.45404092736007795`, 0.94179142550244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 436}], {
             RGBColor[
             0.3965368671240651, 0.5173498014044343, 0.9466350145946033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 462}], {
             RGBColor[
             0.392016142899485, 0.5136796738226148, 0.9462791266236859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 465}], {
             RGBColor[
             0.30138975132499524`, 0.433055376037075, 0.940513691725769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 262}], {
             RGBColor[
             0.41350816527111056`, 0.531963522530478, 0.947740162904996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 263}], {
             RGBColor[
             0.31216558423603546`, 0.4415359530567809, 0.9412315474042139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 296}], {
             RGBColor[
             0.33217516852493173`, 0.46213516819204603`, 0.9423868859008084]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 332}], {
             RGBColor[
             0.37656128496655794`, 0.5005801913427036, 0.9452151299913671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 393}], {
             RGBColor[
             0.4060710006373207, 0.5259256972403187, 0.9471546820617923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 424}], {
             RGBColor[
             0.3357624743157177, 0.4652423121647933, 0.9426154658536674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 440}], {
             RGBColor[
             0.3163021777955242, 0.4458837751629835, 0.9414671202878849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 453}], {
             RGBColor[
             0.31761867457160725`, 0.44726749674536337`, 0.9415420928317004]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 251}], {
             RGBColor[
             0.25758537828186423`, 0.38806894280347104`, 0.9379804782785095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 310}], {
             RGBColor[
             0.2766913122921885, 0.4081504908345045, 0.939068532955701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 352}], {
             RGBColor[
             0.24222822396059346`, 0.3719275999119933, 0.937105911058787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 367}], {
             RGBColor[
             0.24323530728920995`, 0.3729861083431402, 0.9371632629645055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 382}], {
             RGBColor[
             0.26942512488484194`, 0.40051326716649266`, 0.9386547343322136]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 399}], {
             RGBColor[
             0.24906325398775672`, 0.3791116498364756, 0.9374951559073132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 412}], {
             RGBColor[
             0.2495035202048371, 0.3795743975451175, 0.9375202284170604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 416}], {
             RGBColor[
             0.2590796192147955, 0.38963948476432886`, 0.9380655730891085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 429}], {
             RGBColor[
             0.2751117605214455, 0.4064902817740869, 0.9389785798190946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 402}], {
             RGBColor[
             0.6288966867837086, 0.7086387216585579, 0.9645893173262957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 417}], {
             RGBColor[
             0.7032574015004508, 0.7681092940971459, 0.9710577835336467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 436}], {
             RGBColor[
             0.5892009770363313, 0.6764119562142918, 0.9614643256448061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 461}], {
             RGBColor[
             0.8249688230204753, 0.8639714322998968, 0.9750930222658254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 339}], {
             RGBColor[
             0.21834915626655288`, 0.34682918574521915`, 0.9357460334795263]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 365}], {
             RGBColor[
             0.22099114578241763`, 0.3496060842382034, 0.9358964908739815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 374}], {
             RGBColor[
             0.2383689744042093, 0.367871283937679, 0.936886132505799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 276}], {
             RGBColor[
             0.7294231328480298, 0.5025695960181678, 0.5742322488928711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 326}], {
             RGBColor[
             0.8572408103331092, 0.41460626615910345`, 0.2014143032349089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 428}], {
             RGBColor[
             0.8348198026853184, 0.2686458383399938, 0.18097678841579048`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 454}], {
             RGBColor[
             0.869594267772993, 0.47070043117032717`, 0.21172233093369885`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 469}], {
             RGBColor[
             0.8498683936659192, 0.3811298439450528, 0.19526257805333647`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 471}], {
             RGBColor[
             0.8480593461920269, 0.37041077133751354`, 0.1936549902297403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 475}], {
             RGBColor[
             0.8391547501965229, 0.3019661444972231, 0.18512793904814284`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 495}], {
             RGBColor[
             0.8407542903650291, 0.31426091115533294`, 0.1866596605199266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 274}], {
             RGBColor[
             0.40258764491589, 0.5228672426461249, 0.9469441500000384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 313}], {
             RGBColor[
             0.3046994618698019, 0.43447349621750786`, 0.9407776233385161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 334}], {
             RGBColor[
             0.3726225537176192, 0.4971686603012616, 0.9449641575190681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 340}], {
             RGBColor[
             0.33993779537767665`, 0.4688587654109236, 0.9428815136196439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 355}], {
             RGBColor[
             0.3355739158146536, 0.46507899226839733`, 0.9426034510727153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 363}], {
             RGBColor[
             0.37362619317772217`, 0.49803796235721676`, 0.9450281085379824]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 378}], {
             RGBColor[
             0.3127627275114677, 0.4429484996474682, 0.9412368143882763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 379}], {
             RGBColor[
             0.3258701140726008, 0.45667404692668806`, 0.9419851334064466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 380}], {
             RGBColor[
             0.3076460451816098, 0.43757054210239044`, 0.9409454268990441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 390}], {
             RGBColor[
             0.3215972480879268, 0.45223414091428343`, 0.9417399272656037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 498}], {
             RGBColor[
             0.40216527018839365`, 0.5225243398145787, 0.9469108991142803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 394}], {
             RGBColor[
             0.22510267482771082`, 0.3539275619508045, 0.936130636370649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 438}], {
             RGBColor[
             0.22151371355788788`, 0.3501553361029332, 0.9359262503357249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 445}], {
             RGBColor[
             0.22560109399094413`, 0.3544514320929628, 0.93615902060465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 460}], {
             RGBColor[
             0.23495456172986623`, 0.36428251973067727`, 0.936691686755166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 256}], {
             RGBColor[
             0.2918037733500637, 0.42403464559170456`, 0.9399291652560644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 288}], {
             RGBColor[
             0.2751436592994766, 0.40652380941229693`, 0.9389803964073136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 333}], {
             RGBColor[
             0.33643527177961996`, 0.46448215779697133`, 0.9427075059768388]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 392}], {
             RGBColor[
             0.3001114005223494, 0.4327664884837622, 0.940402272333493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 442}], {
             RGBColor[
             0.28908336711974203`, 0.42117532615991926`, 0.939774242145728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 444}], {
             RGBColor[
             0.2827572278979614, 0.41452615273743476`, 0.9394139778757318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 459}], {
             RGBColor[
             0.3423837632254584, 0.4696344421074833, 0.9430865385917233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 492}], {
             RGBColor[
             0.2854203608730804, 0.4173252743466679, 0.9395656393589127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 255}], {
             RGBColor[
             0.4462984536881862, 0.5598509487377481, 0.9499715158755377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 269}], {
             RGBColor[
             0.47197536116157857`, 0.5820909954323062, 0.9516076257145445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 360}], {
             RGBColor[
             0.5371888520305683, 0.6351531360172418, 0.9567086207009003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 369}], {
             RGBColor[
             0.457479402684923, 0.5695353247878849, 0.9506839560586847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 370}], {
             RGBColor[
             0.5432273595581627, 0.6400554684598069, 0.9571839941332545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 425}], {
             RGBColor[
             0.4351771155351065, 0.550218204604259, 0.9492628740426365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 466}], {
             RGBColor[
             0.4992597773340883, 0.6043606044932961, 0.953722705002015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 468}], {
             RGBColor[
             0.48669420259584584`, 0.5941593048480999, 0.9527334969294036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 286}], {
             RGBColor[
             0.23281996068137648`, 0.36203891868719107`, 0.9365701243833138]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 294}], {
             RGBColor[
             0.240426199543799, 0.37003355799499527`, 0.9370032884341067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 313}], {
             RGBColor[
             0.254748775686199, 0.38508749362443473`, 0.9378189379570638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 380}], {
             RGBColor[
             0.257695358998007, 0.3881845395093172, 0.937986741517592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 411}], {
             RGBColor[
             0.2410648104835609, 0.37070477858295714`, 0.937039656382386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 478}], {
             RGBColor[
             0.25429079969208646`, 0.3846061318172672, 0.9377928569017139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 260}], {
             RGBColor[
             0.28756214905519606`, 0.4195764295232854, 0.9396876110273925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 280}], {
             RGBColor[
             0.27322012310800536`, 0.4045020509158221, 0.938870853866826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 296}], {
             RGBColor[
             0.3014838445951241, 0.4337768875889444, 0.9404962532659576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 424}], {
             RGBColor[
             0.30507115038591015`, 0.4368840315616916, 0.9407248332188166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 440}], {
             RGBColor[
             0.2856108538657166, 0.41752549455988186`, 0.9395764876530341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 470}], {
             RGBColor[
             0.27251498804399493`, 0.40376090925540187`, 0.9388306974680845]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 339}], {
             RGBColor[
             0.20806801028262886`, 0.33602304945380984`, 0.9351605374253343]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 365}], {
             RGBColor[
             0.21070999979849359`, 0.338799947946794, 0.9353109948197895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 305}], {
             RGBColor[
             0.25482853774731307`, 0.38517132860787223`, 0.9378234802884469]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 367}], {
             RGBColor[
             0.24419513183599667`, 0.3739949447982042, 0.9372179235525118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 382}], {
             RGBColor[
             0.27038494943162866`, 0.40152210362155666`, 0.9387093949202199]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 416}], {
             RGBColor[
             0.26003944376158217`, 0.39064832121939286`, 0.9381202336771148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 427}], {
             RGBColor[
             0.2690226652198594, 0.4000902565411794, 0.9386318148496786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 429}], {
             RGBColor[
             0.2760715850682322, 0.4074991182291509, 0.9390332404071009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 499}], {
             RGBColor[
             0.25963192027097015`, 0.39021998819227793`, 0.9380970258172014]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 282}], {
             RGBColor[
             0.6717272001021579, 0.7429460920325152, 0.9682785844173988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 432}], {
             RGBColor[
             0.8172102397534445, 0.8577657390481622, 0.982246863062763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 467}], {
             RGBColor[
             0.7213175895970523, 0.7822180503007243, 0.9728578543010624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 261}], {
             RGBColor[
             0.9325093316648222, 0.7680041432668934, 0.5596474808987255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 277}], {
             RGBColor[
             0.8781666893011308, 0.9046720920391318, 0.9377821758000617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 291}], {
             RGBColor[
             0.819979493708928, 0.8592158126034372, 0.9319826199336896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 311}], {
             RGBColor[
             0.8659443575362178, 0.8951239135712197, 0.9365639679939195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 319}], {
             RGBColor[
             0.8499607656875054, 0.8826374101392084, 0.934970872933598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 377}], {
             RGBColor[
             0.9830684787672088, 0.9867535506374262, 0.9072964317019494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 484}], {
             RGBColor[
             0.9889617727140382, 0.9876413426482502, 0.6827040059696212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 488}], {
             RGBColor[
             0.877198073649208, 0.9039154021300979, 0.937685633244106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 315}], {
             RGBColor[
             0.21099893285942517`, 0.33910363491324724`, 0.9353274491301715]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 325}], {
             RGBColor[
             0.20775758490962407`, 0.33569677270467635`, 0.935142859159575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 347}], {
             RGBColor[
             0.20771262472504887`, 0.3356495167000475, 0.935140298743576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 368}], {
             RGBColor[
             0.32229994971598047`, 0.44690195182710835`, 0.9420022258236223]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 386}], {
             RGBColor[
             0.20771262472504887`, 0.3356495167000475, 0.935140298743576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 401}], {
             RGBColor[
             0.50497531356463, 0.5944255881948143, 0.9574168801184721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 454}], {
             RGBColor[
             0.568190337821955, 0.5020881692235942, 0.5874756893040098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 471}], {
             RGBColor[
             0.5466554162409889, 0.4017985093907806, 0.5694083486000513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 269}], {
             RGBColor[
             0.4232624333249523, 0.5410303787827784, 0.94819088586856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 274}], {
             RGBColor[
             0.43015989340709154`, 0.5467489384677, 0.9487010292927157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 334}], {
             RGBColor[
             0.40019480220882075`, 0.5210503561228367, 0.9467210368117455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 338}], {
             RGBColor[
             0.35884542683277726`, 0.48523560545214284`, 0.9440862911766009]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 369}], {
             RGBColor[
             0.40876647484829665`, 0.5284747081383571, 0.9472672162127003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 370}], {
             RGBColor[
             0.4945144317215364, 0.598994851810279, 0.9537672542872702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 379}], {
             RGBColor[
             0.35344236256380235`, 0.4805557427482631, 0.943742012699124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 390}], {
             RGBColor[
             0.3491694965791283, 0.4761158367358585, 0.9434968065582812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 425}], {
             RGBColor[
             0.38646418769848023`, 0.5091575879547311, 0.9458461341966522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 466}], {
             RGBColor[
             0.45054684949746193`, 0.5632999878437683, 0.9503059651560305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 271}], {
             RGBColor[
             0.2725957288123946, 0.4038457729222503, 0.9388352955353996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 333}], {
             RGBColor[
             0.3340176365315557, 0.4619410698643276, 0.9425698252260324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 442}], {
             RGBColor[
             0.28666573187167776`, 0.4186342382272755, 0.9396365613949216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 444}], {
             RGBColor[
             0.28033959264989716`, 0.411985064804791, 0.9392762971249253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 492}], {
             RGBColor[
             0.28300272562501616`, 0.4147841864140242, 0.9394279586081062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 272}], {
             RGBColor[
             0.8397181825766789, 0.3055916208213189, 0.18563986428858031`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 306}], {
             RGBColor[
             0.8582164736566054, 0.4477775920644729, 0.2033538487175496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 317}], {
             RGBColor[
             0.8711268784377937, 0.5076990787158229, 0.21417744721027115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 357}], {
             RGBColor[
             0.8829978584207956, 0.5607626793064351, 0.22403944465155362`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 418}], {
             RGBColor[
             0.9186634619525802, 0.7177171878043327, 0.5626295641489729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 420}], {
             RGBColor[
             0.9137481314322007, 0.7140513423503487, 0.5709499365964574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 289}], {
             RGBColor[
             0.4063967473847854, 0.5264221693154291, 0.9471162192741931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 297}], {
             RGBColor[
             0.4463933258988235, 0.5592718859080008, 0.9501602626281445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 314}], {
             RGBColor[
             0.35174895766394676`, 0.47908900053701325`, 0.9436341104363243]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 373}], {
             RGBColor[
             0.3335189671806654, 0.461900180189882, 0.9425237328349862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 381}], {
             RGBColor[
             0.4713636222770108, 0.5795438974068458, 0.952126015828245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 397}], {
             RGBColor[
             0.36598524788401654`, 0.49141975958888606`, 0.94454123426049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 472}], {
             RGBColor[
             0.3509345795878789, 0.47838362717935545`, 0.9435822189854435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 341}], {
             RGBColor[
             0.9277070351691528, 0.7270975616364004, 0.37415406223837167`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 405}], {
             RGBColor[
             0.9279266912954685, 0.7275673838799486, 0.39806227602736116`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 450}], {
             RGBColor[
             0.8397745913250846, 0.3013267240551166, 0.18550990071046175`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 454}], {
             RGBColor[
             0.8808615626968692, 0.5519020063430116, 0.22230030637499004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 469}], {
             RGBColor[
             0.8611356885897954, 0.46233141911773723`, 0.2058405534946276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 471}], {
             RGBColor[
             0.8593266411159032, 0.451612346510198, 0.20423296567103144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 475}], {
             RGBColor[
             0.8504220451203991, 0.38316771966990754`, 0.19570591448943397`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 491}], {
             RGBColor[
             0.9280010655847133, 0.727726462964249, 0.4061574584267472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 500}], {
             RGBColor[
             0.8406666807462297, 0.3081837142621151, 0.18636416654762122`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 280}], {
             RGBColor[
             0.27123440340689225`, 0.4024149336080515, 0.9387577700674566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 424}], {
             RGBColor[
             0.3030854306847971, 0.434796914253921, 0.9406117494194473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 440}], {
             RGBColor[
             0.28362513416460355`, 0.4154383772521112, 0.9394634038536649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 470}], {
             RGBColor[
             0.2705292683428818, 0.4016737919476313, 0.9387176136687151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 483}], {
             RGBColor[
             0.2911128004849959, 0.42330838930030823`, 0.9398898153736015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 484}], {
             RGBColor[
             0.9364392575786439, 0.7675671876801757, 0.34462692180178206`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 500}], {
             RGBColor[
             0.8497397394109806, 0.34938235459205963`, 0.19393494909850834`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 332}], {
             RGBColor[
             0.43913893362174417`, 0.5541636058359223, 0.9493733327998998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 344}], {
             RGBColor[
             0.4699143971667351, 0.5805367028791276, 0.9514125291795714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 387}], {
             RGBColor[
             0.6255998101870561, 0.7048955003973141, 0.9650590620780228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 393}], {
             RGBColor[
             0.46864864929250694`, 0.5795091117335374, 0.951312884870325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 424}], {
             RGBColor[
             0.39834012297090404`, 0.5188257266580119, 0.9467736686621999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 296}], {
             RGBColor[
             0.2934102361450429, 0.4252910132115676, 0.9400364732085589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 323}], {
             RGBColor[
             0.2563726589916906, 0.3867942979386546, 0.9379114157089916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 342}], {
             RGBColor[
             0.2666938975771815, 0.3976425740963284, 0.9384991949775311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 395}], {
             RGBColor[
             0.2691941123375187, 0.40027045833221453`, 0.938641578509396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 440}], {
             RGBColor[
             0.2775372454156354, 0.40903962018250506`, 0.9391167075956355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 447}], {
             RGBColor[
             0.2599502995006695, 0.3905546249491011, 0.938115157043333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 453}], {
             RGBColor[
             0.27885374219171843`, 0.41042334176488493`, 0.9391916801394509]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 463}], {
             RGBColor[
             0.2702490064672201, 0.4013792189466815, 0.9387016531695065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 394}], {
             RGBColor[
             0.23171433520063273`, 0.36087683620622507`, 0.9365071606478118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 398}], {
             RGBColor[
             0.2479686232623, 0.377961123540424, 0.9374328183068594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 445}], {
             RGBColor[
             0.23221275436386601`, 0.3614007063483834, 0.9365355448818129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 328}], {
             RGBColor[
             0.35316375548579293`, 0.48031442730049023`, 0.9437242601024758]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 433}], {
             RGBColor[
             0.32326037843179023`, 0.45441362508374517`, 0.9418188433591128]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 462}], {
             RGBColor[
             0.392446435384819, 0.5140523715462819, 0.9463065444803587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 364}], {
             RGBColor[
             0.2740437091478759, 0.405367692062097, 0.9389177558734103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 374}], {
             RGBColor[
             0.27062553266643685`, 0.40177497185519817`, 0.9387230957795312]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 410}], {
             RGBColor[
             0.326592877843097, 0.45552256223454524`, 0.9420962704893343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 437}], {
             RGBColor[
             0.2726756027922651, 0.40392972553939704`, 0.9388398442403902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 278}], {
             RGBColor[
             0.9687131736129876, 0.9678890438697982, 0.6921508091390034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 329}], {
             RGBColor[
             0.9358102453449542, 0.941979730786866, 0.7003355368972839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 406}], {
             RGBColor[
             0.9898404936899885, 0.9773917410301207, 0.415032665757733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 413}], {
             RGBColor[
             0.981449315920919, 0.9490863280728146, 0.38243452466585603`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 476}], {
             RGBColor[
             0.9187775169477521, 0.6742536840952063, 0.3030402150761125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 486}], {
             RGBColor[
             0.9619951023866931, 0.9628588250229391, 0.7028330719374227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 493}], {
             RGBColor[
             0.991319933690298, 0.9817192401312839, 0.4771566948770857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 275}], {
             RGBColor[
             0.4116793705742366, 0.5309977120097701, 0.9474528233525847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 285}], {
             RGBColor[
             0.3620365603618595, 0.4879996049239992, 0.9442896273832655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 324}], {
             RGBColor[
             0.3896661145929028, 0.5119309360971549, 0.946050158147012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 353}], {
             RGBColor[
             0.5246586597567469, 0.6237950026375101, 0.9560497714979366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 441}], {
             RGBColor[
             0.4298935905497302, 0.5467739538792281, 0.9486134173432208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 480}], {
             RGBColor[
             0.3816010072146523, 0.5049453454501976, 0.9455362566365644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 481}], {
             RGBColor[
             0.3639357382267393, 0.48964457733510314`, 0.9444106413174386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 360}], {
             RGBColor[
             0.5141528316673345, 0.616332566062272, 0.9549279906939228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 369}], {
             RGBColor[
             0.43444338232168905`, 0.5507147548329152, 0.948903326051707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 425}], {
             RGBColor[
             0.4121410951718726, 0.5313976346492894, 0.947482244035659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 466}], {
             RGBColor[
             0.47622375697085434`, 0.5855400345383266, 0.9519420749950372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 468}], {
             RGBColor[
             0.4636581822326119, 0.5753387348931303, 0.9509528669224259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 309}], {
             RGBColor[
             0.9915269265441726, 0.9888220703419007, 0.6489133693566129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 345}], {
             RGBColor[
             0.824874141314561, 0.8621219539632672, 0.8908628396870938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 375}], {
             RGBColor[
             0.9741122632489756, 0.9792447932430604, 0.8853225104060825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 426}], {
             RGBColor[
             0.9300987405065613, 0.9447298808495102, 0.9012429919407459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 489}], {
             RGBColor[
             0.9900603412249211, 0.9901577099059953, 0.8143893991227904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 284}], {
             RGBColor[
             0.2504489768010796, 0.3805681323731789, 0.9375740707715388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 442}], {
             RGBColor[
             0.26987532258207286`, 0.400986453490465, 0.9386803724250632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 444}], {
             RGBColor[
             0.26354918336029226`, 0.3943372800679805, 0.938320108155067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 464}], {
             RGBColor[
             0.24983604138275278`, 0.37992389838616725`, 0.9375391650062217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 492}], {
             RGBColor[
             0.2662123163354113, 0.39713640167721365`, 0.9384717696382479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 306}], {
             RGBColor[
             0.8390812230199529, 0.30140098239829205`, 0.18505752934082234`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 317}], {
             RGBColor[
             0.8519916278011412, 0.36132246904964216`, 0.1958811278335439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 357}], {
             RGBColor[
             0.8638626077841431, 0.41438606964025426`, 0.20574312527482636`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 308}], {
             RGBColor[
             0.23624385022904204`, 0.36563764368892326`, 0.9367651098278627]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 421}], {
             RGBColor[
             0.236299010735822, 0.36569562087892715`, 0.9367682511371211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 423}], {
             RGBColor[
             0.24068365358124288`, 0.3703041585118776, 0.9370179500606701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 446}], {
             RGBColor[
             0.26084634450324296`, 0.39149642505934035`, 0.9381661854806498]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 477}], {
             RGBColor[
             0.2691065215645594, 0.4001783948762585, 0.9386365903444549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 334}], {
             RGBColor[
             0.4327691697643524, 0.5490089625023165, 0.9488672900749079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 340}], {
             RGBColor[
             0.40008441142440987`, 0.5206990676119785, 0.9467846461754836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 361}], {
             RGBColor[
             0.5534678542610545, 0.6483409394418851, 0.9580094602549781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 363}], {
             RGBColor[
             0.4337728092244554, 0.5498782645582716, 0.9489312410938221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 369}], {
             RGBColor[
             0.4413408424038283, 0.5564333145178368, 0.9494134694758627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 370}], {
             RGBColor[
             0.5270887992770681, 0.6269534581897589, 0.9559135075504326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 379}], {
             RGBColor[
             0.386016730119334, 0.5085143491277428, 0.9458882659622865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 498}], {
             RGBColor[
             0.46231188623512687`, 0.5743646420156336, 0.95081403167012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 282}], {
             RGBColor[
             0.5106811757652547, 0.612557396257451, 0.9549190346803453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 285}], {
             RGBColor[
             0.36406115169331943`, 0.4897532041763907, 0.9444186325526303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 324}], {
             RGBColor[
             0.3916907059243627, 0.5136845353495464, 0.9461791633163769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 353}], {
             RGBColor[
             0.5266832510882068, 0.6255486018899017, 0.9561787766673014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 441}], {
             RGBColor[
             0.43191818188119013`, 0.5485275531316196, 0.9487424225125856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 481}], {
             RGBColor[
             0.36596032955819924`, 0.49139817658749463`, 0.9445396464868034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 283}], {
             RGBColor[
             0.4003771577872324, 0.5049037920541919, 0.9484114336869224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 292}], {
             RGBColor[
             0.39925539426111123`, 0.5037247474643232, 0.9483475509136101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 396}], {
             RGBColor[
             0.8065431088390325, 0.8453068187334528, 0.7510492031181083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 422}], {
             RGBColor[
             0.4267760803352025, 0.5326507334404715, 0.9499148132723232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 291}], {
             RGBColor[
             0.7131143362098424, 0.7758096064076011, 0.9720402306671867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 311}], {
             RGBColor[
             0.7590792000371321, 0.8117177073753836, 0.9766215787274166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 319}], {
             RGBColor[
             0.7430956081884199, 0.7992312039433723, 0.9750284836670953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 331}], {
             RGBColor[
             0.8039966134471465, 0.8469425741957761, 0.9810626907032964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 377}], {
             RGBColor[
             0.8762033212681233, 0.9033473444415901, 0.9473540424354466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 419}], {
             RGBColor[
             0.6419960336426249, 0.718265092425402, 0.9663099050077802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 449}], {
             RGBColor[
             0.7498021540184663, 0.8044704085174408, 0.9756969294792002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 484}], {
             RGBColor[
             0.8820966152149525, 0.9042351364524142, 0.7227616167031183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 488}], {
             RGBColor[
             0.7703329161501223, 0.8205091959342619, 0.9777432439776033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 329}], {
             RGBColor[
             0.9154608124727537, 0.9351010298249371, 0.9804756251775316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 406}], {
             RGBColor[
             0.969491060817788, 0.9705130400681918, 0.6951727540379807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 413}], {
             RGBColor[
             0.9610998830487185, 0.9422076271108857, 0.6625746129461039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 486}], {
             RGBColor[
             0.9416456695144926, 0.9559801240610102, 0.9829731602176706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 493}], {
             RGBColor[
             0.9709705008180975, 0.974840539169355, 0.7572967831573334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.2964892825686648, 0.42843496613236076`, 0.9402152006381983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 324}], {
             RGBColor[
             0.3241188367997081, 0.45236629730551653`, 0.9419757314019449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 481}], {
             RGBColor[
             0.2983884604335446, 0.4300799385434647, 0.9403362145723715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 494}], {
             RGBColor[
             0.2685318784304253, 0.3995744085078045, 0.9386038652680744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 327}], {
             RGBColor[
             0.25698076875714937`, 0.3874334598585377, 0.9379460466605166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 470}], {
             RGBColor[
             0.25618724239569113`, 0.386599413340168, 0.9379008565081486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 483}], {
             RGBColor[
             0.2767707745378052, 0.40823401069284493`, 0.939073058213035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 288}], {
             RGBColor[
             0.2504872858476244, 0.38060839761003135`, 0.9375762524150663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 343}], {
             RGBColor[
             0.26889808498261325`, 0.3999593148129905, 0.9386247201894673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 465}], {
             RGBColor[
             0.26376712193927254`, 0.39456634733259277`, 0.9383325194347287]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 324}], {
             RGBColor[
             0.48866791978392093`, 0.5934906203448358, 0.9535163694747727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 353}], {
             RGBColor[
             0.6236604649477651, 0.705354686885191, 0.9635159828256973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 432}], {
             RGBColor[
             0.7531414292760994, 0.8071831282683875, 0.9762245194841053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 441}], {
             RGBColor[
             0.5288953957407483, 0.628333638126909, 0.9560796286709814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 467}], {
             RGBColor[
             0.6572487791197071, 0.7316354395209496, 0.9668355107224047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 292}], {
             RGBColor[
             0.18009239570445779`, 0.3066189047757405, 0.9335673675613205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 386}], {
             RGBColor[
             0.18007057961528944`, 0.30659597468280464`, 0.9335661251673164]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 422}], {
             RGBColor[
             0.207613081778549, 0.3355448907518888, 0.9351346299200334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 442}], {
             RGBColor[
             0.26451897986036277`, 0.3953565976782041, 0.9383753366310607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 444}], {
             RGBColor[
             0.25819284063858217`, 0.3887074242557196, 0.9380150723610645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 464}], {
             RGBColor[
             0.24447969866104266`, 0.37429404257390636`, 0.9372341292122193]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 324}], {
             RGBColor[
             0.3420478957119857, 0.4706864282637755, 0.9430159673470576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 480}], {
             RGBColor[
             0.3339827883337351, 0.46370083761681824`, 0.9425020658366099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 481}], {
             RGBColor[
             0.3163175193458222, 0.44840006950172373`, 0.9413764505174842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 294}], {
             RGBColor[
             0.23070650372322443`, 0.3598175414232626, 0.9364497661361264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 346}], {
             RGBColor[
             0.22049146079372114`, 0.3490808836332252, 0.935868034553093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 358}], {
             RGBColor[
             0.22436323878386594`, 0.35315036778577047`, 0.9360885265818495]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 407}], {
             RGBColor[
             0.21872930348009942`, 0.347228744569382, 0.9357676823009604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 411}], {
             RGBColor[
             0.2313451146629863, 0.3604887620112245, 0.9364861340844057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 295}], {
             RGBColor[
             0.2196997994484176, 0.34824879736508285`, 0.9358229506106359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 299}], {
             RGBColor[
             0.2094890463187735, 0.33751664842668644`, 0.9352414633253583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 300}], {
             RGBColor[
             0.2178846815571592, 0.3463409933762489, 0.9357195823319551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 301}], {
             RGBColor[
             0.20928219811004087`, 0.33729923784437454`, 0.9352296836258756]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 389}], {
             RGBColor[
             0.214155749354975, 0.34242164920379625`, 0.9355072251595016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 451}], {
             RGBColor[
             0.21062876698303812`, 0.3387145671072923, 0.9353063687311225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 456}], {
             RGBColor[
             0.21673512234064032`, 0.34513273375342357`, 0.9356541166351948]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 343}], {
             RGBColor[
             0.274476709135814, 0.40582280250320485`, 0.9389424145821572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 392}], {
             RGBColor[
             0.281033651223698, 0.41271456437171095`, 0.9393158227339358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 465}], {
             RGBColor[
             0.2693457460924733, 0.4004298350228071, 0.9386502138274186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 492}], {
             RGBColor[
             0.26634261157442907`, 0.39727335023461663`, 0.9384791897593554]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 291}], {
             RGBColor[
             0.5471490964494157, 0.6426680909259248, 0.9577289938124869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 297}], {
             RGBColor[
             0.47936763079523015`, 0.5878325714725148, 0.9522613561781106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 314}], {
             RGBColor[
             0.3847232625603534, 0.5076496861015274, 0.9457352039862904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 349}], {
             RGBColor[
             0.42648626116779464`, 0.5438226964259498, 0.9483963053279869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 359}], {
             RGBColor[
             0.4124111574915527, 0.5316315490568694, 0.9474994521678624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 381}], {
             RGBColor[
             0.5043379271734174, 0.6081045829713598, 0.9542271093782111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 397}], {
             RGBColor[
             0.39895955278042317`, 0.5199804451534001, 0.9466423278104561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 419}], {
             RGBColor[
             0.4760307938821983, 0.5851235769437257, 0.9519986681530803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 472}], {
             RGBColor[
             0.3839088844842855, 0.5069443127438695, 0.9456833125354096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 316}], {
             RGBColor[
             0.268490139738015, 0.3995305384956953, 0.9386014883112883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 340}], {
             RGBColor[
             0.31195990105564253`, 0.44256756021982796`, 0.9411741462288754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 355}], {
             RGBColor[
             0.30759602149261944`, 0.4387877870773017, 0.9408960836819469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 362}], {
             RGBColor[
             0.3374733904051481, 0.4646660623491092, 0.9427998432095333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 378}], {
             RGBColor[
             0.28478483318943354`, 0.41665729445637256`, 0.939529446997508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 384}], {
             RGBColor[
             0.2851530200769201, 0.4170442822195179, 0.9395504146960666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 297}], {
             RGBColor[
             0.5871456749634538, 0.6755178075184964, 0.9607730371664382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 311}], {
             RGBColor[
             0.7008920044449292, 0.7662614279396891, 0.9708220228610445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 319}], {
             RGBColor[
             0.6849084125962169, 0.7537749245076777, 0.969228927800723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 349}], {
             RGBColor[
             0.5342643053360183, 0.6315079324719315, 0.9569079863163146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 359}], {
             RGBColor[
             0.5201892016597764, 0.619316785102851, 0.95601113315619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 419}], {
             RGBColor[
             0.583808838050422, 0.6728088129897074, 0.960510349141408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 488}], {
             RGBColor[
             0.7121457205579194, 0.7750529164985673, 0.971943688111231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 308}], {
             RGBColor[
             0.17895845847297373`, 0.30542706484967774`, 0.9335027915134972]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 386}], {
             RGBColor[
             0.17894881608916835`, 0.3054169300929359, 0.9335022423940041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 422}], {
             RGBColor[
             0.20649131825242792`, 0.3343658461620201, 0.9350707471467212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 298}], {
             RGBColor[
             0.9279560632534805, 0.9449120378208546, 0.9763848153450053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 317}], {
             RGBColor[
             0.9188363181868828, 0.7644234365766909, 0.5933539685152149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 353}], {
             RGBColor[
             0.7969674264911133, 0.8418814193634385, 0.9635324755439242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 418}], {
             RGBColor[
             0.9663729017016692, 0.9744415456652006, 0.9418060854539165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 420}], {
             RGBColor[
             0.9614575711812897, 0.9707757002112165, 0.9501264579014013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 432}], {
             RGBColor[
             0.9264483908194477, 0.943709860746635, 0.9762410122023322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 358}], {
             RGBColor[
             0.23196947764628847`, 0.36114500709357467`, 0.9365216906326425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 411}], {
             RGBColor[
             0.23895135352540886`, 0.3684834013190287, 0.9369192981351986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 430}], {
             RGBColor[
             0.23902588418057213`, 0.36856173776312173`, 0.9369235425457519]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 478}], {
             RGBColor[
             0.25217734273393444`, 0.38238475455333876`, 0.9376724986545265]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 300}], {
             RGBColor[
             0.22777276498654234`, 0.3567339960012304, 0.9362826940551499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 336}], {
             RGBColor[
             0.22591321478921644`, 0.3547794908415487, 0.9361767954223702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 389}], {
             RGBColor[
             0.22404383278435813`, 0.3528146518287777, 0.9360703368826964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 409}], {
             RGBColor[
             0.23557177233220394`, 0.3649312472071466, 0.9367268359858879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 456}], {
             RGBColor[
             0.22662320577002346`, 0.355525736378405, 0.9362172283583896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 458}], {
             RGBColor[
             0.2300435692999762, 0.35912075531195864`, 0.936412013001446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 332}], {
             RGBColor[
             0.3578059368755654, 0.48433525149749035`, 0.9440200557957121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 395}], {
             RGBColor[
             0.289203696626415, 0.4208696734674796, 0.9397969170059906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 424}], {
             RGBColor[
             0.31700712622472516`, 0.4489973723195799, 0.9414203916580124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 440}], {
             RGBColor[
             0.29754682970453167`, 0.4296388353177702, 0.94027204609223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 453}], {
             RGBColor[
             0.2988633264806147, 0.4310225569001501, 0.9403470186360454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 311}], {
             RGBColor[
             0.6331105387907436, 0.7114259084862791, 0.9653543852266682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 314}], {
             RGBColor[
             0.42471984107439154`, 0.540499402694099, 0.9487792473402418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 349}], {
             RGBColor[
             0.4664828396818328, 0.5766724130185215, 0.9514403486819383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 359}], {
             RGBColor[
             0.45240773600559087`, 0.5644812656494411, 0.9505434955218137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 381}], {
             RGBColor[
             0.5443345056874556, 0.6409542995639315, 0.9572711527321625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 397}], {
             RGBColor[
             0.4389561312944613, 0.5528301617459719, 0.9496863711644075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 419}], {
             RGBColor[
             0.5160273723962365, 0.6179732935362974, 0.9550427115070317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 353}], {
             RGBColor[
             0.7706511770330843, 0.8213765109750578, 0.9776280646137345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 418}], {
             RGBColor[
             0.9400566522436402, 0.9539366372768199, 0.955901674523727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 420}], {
             RGBColor[
             0.9351413217232607, 0.9502707918228358, 0.9642220469712115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 432}], {
             RGBColor[
             0.9001321413614187, 0.9232049523582542, 0.9903366012721426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 300}], {
             RGBColor[
             0.21756201185689822`, 0.346001847062834, 0.9357012067698722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 301}], {
             RGBColor[
             0.20895952840977988`, 0.3369600915309596, 0.9352113080637927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 389}], {
             RGBColor[
             0.213833079654714, 0.34208250289038133`, 0.9354888495974187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 451}], {
             RGBColor[
             0.21030609728277713`, 0.3383754207938774, 0.9352879931690398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 456}], {
             RGBColor[
             0.21641245264037934`, 0.34479358744000865`, 0.935635741073112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 301}], {
             RGBColor[
             0.2173551636481656, 0.3457844364805221, 0.9356894270703895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 389}], {
             RGBColor[
             0.2222287148930997, 0.35090684783994386`, 0.9359669686040155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 409}], {
             RGBColor[
             0.23375665444094554`, 0.3630234432183127, 0.936623467707207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 451}], {
             RGBColor[
             0.21870173252116284`, 0.3471997657434399, 0.9357661121756364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 456}], {
             RGBColor[
             0.22480808787876505`, 0.3536179323895711, 0.9361138600797088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 458}], {
             RGBColor[
             0.22822845140871784`, 0.35721295132312475`, 0.9363086447227651]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 389}], {
             RGBColor[
             0.21362623144598136`, 0.3418650923080694, 0.9354770698979359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 451}], {
             RGBColor[
             0.2100992490740445, 0.3381580102115655, 0.9352762134695569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 456}], {
             RGBColor[
             0.21620560443164671`, 0.3445761768576967, 0.9356239613736292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 315}], {
             RGBColor[
             0.18782448730516063`, 0.31474582329100176`, 0.934007698739376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 325}], {
             RGBColor[
             0.18458313935535953`, 0.31133896108243087`, 0.9338231087687794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 347}], {
             RGBColor[
             0.18453817917078433`, 0.311291705077802, 0.9338205483527805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 368}], {
             RGBColor[
             0.2991255041617159, 0.42254414020486286`, 0.9406824754328269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 386}], {
             RGBColor[
             0.18453817917078433`, 0.311291705077802, 0.9338205483527805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 421}], {
             RGBColor[
             0.18460298206136966`, 0.31135981702454774`, 0.9338242387815321]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 477}], {
             RGBColor[
             0.21741049289010705`, 0.3458425910218791, 0.9356925779888657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 366}], {
             RGBColor[
             0.2851324087513453, 0.4170226184095053, 0.9395492409115669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 435}], {
             RGBColor[
             0.2816881021628791, 0.4134024338033765, 0.9393530927467486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 473}], {
             RGBColor[
             0.31604489027716914`, 0.44784149062043943`, 0.9413708849892584]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 310}], {
             RGBColor[
             0.317660558842397, 0.44845488439544834`, 0.9415026138990965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 429}], {
             RGBColor[
             0.316081007071654, 0.4467946753350308, 0.9414126607624902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 483}], {
             RGBColor[
             0.3176066092257016, 0.44839817992769826`, 0.941499541548237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 382}], {
             RGBColor[
             0.2666682843502908, 0.39761565297089385`, 0.938497736342151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 416}], {
             RGBColor[
             0.2563227786802443, 0.3867418705687301, 0.9379085750990459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 427}], {
             RGBColor[
             0.26530600013852146`, 0.3961838058905166, 0.9384201562716097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 438}], {
             RGBColor[
             0.23628821482403703`, 0.36568427369114076`, 0.9367676363259161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 460}], {
             RGBColor[
             0.24972906299601538`, 0.37981145731888477`, 0.9375330727453572]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 499}], {
             RGBColor[
             0.2559152551896322, 0.3863135375416151, 0.9378853672391325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 317}], {
             RGBColor[
             0.8704899188810679, 0.5035084402927961, 0.2135951122625132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 357}], {
             RGBColor[
             0.8823608988640697, 0.5565720408834082, 0.22345710970379568`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 418}], {
             RGBColor[
             0.9180265023958543, 0.7135265493813059, 0.5620472292012149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 420}], {
             RGBColor[
             0.9131111718754747, 0.7098607039273219, 0.5703676016486996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 372}], {
             RGBColor[
             0.47013131999468205`, 0.580712810603117, 0.9514296061392018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 417}], {
             RGBColor[
             0.5854211152910297, 0.6734114544902967, 0.9611201594979415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 386}], {
             RGBColor[
             0.17893664238380538`, 0.3054041347567419, 0.9335015491194931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 421}], {
             RGBColor[
             0.1790014452743907, 0.3054722467034876, 0.9335052395482446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 422}], {
             RGBColor[
             0.20647914454706495`, 0.3343530508258261, 0.9350700538722102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 423}], {
             RGBColor[
             0.1833860881198116, 0.31008078433643804`, 0.9337549384717936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 446}], {
             RGBColor[
             0.2035487790418117, 0.3312730508839008, 0.9349031738917732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 320}], {
             RGBColor[
             0.9908166313021023, 0.9885283450055495, 0.6606847997028811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 337}], {
             RGBColor[
             0.926620732552479, 0.9394372573300418, 0.7346744089406012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 348}], {
             RGBColor[
             0.976471187338104, 0.9319682118150352, 0.39079228120582354`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 375}], {
             RGBColor[
             0.9756161016685031, 0.977924558793291, 0.7192291003603996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 489}], {
             RGBColor[
             0.9915641796444485, 0.9888374754562259, 0.6482959890771074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 327}], {
             RGBColor[
             0.2769131154519483, 0.40838362001854456`, 0.939081164317521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 399}], {
             RGBColor[
             0.26912901254486776`, 0.40020203432257306`, 0.938637871172511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 412}], {
             RGBColor[
             0.26956927876194814`, 0.4006647820312149, 0.9386629436822582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 429}], {
             RGBColor[
             0.2951775190785565, 0.4275806662601843, 0.9401212950842925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 483}], {
             RGBColor[
             0.2967031212326041, 0.4291841708528518, 0.9402081758700394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 319}], {
             RGBColor[
             0.7308732764235066, 0.7896830254754603, 0.9738102758609529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 331}], {
             RGBColor[
             0.7917742816822333, 0.837394395727864, 0.9798444828971542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 349}], {
             RGBColor[
             0.5802291691633081, 0.667416033439714, 0.9614893343765445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 377}], {
             RGBColor[
             0.8639809895032101, 0.8937991659736781, 0.9461358346293043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 419}], {
             RGBColor[
             0.6297737018777119, 0.70871691395749, 0.9650916972016379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 484}], {
             RGBColor[
             0.8698742834500395, 0.8946869579845022, 0.7215434088969761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 488}], {
             RGBColor[
             0.7581105843852092, 0.8109610174663499, 0.9765250361714609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 354}], {
             RGBColor[
             0.3330876906173925, 0.4625247982993003, 0.942459704446583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 376}], {
             RGBColor[
             0.2919333190231436, 0.4241708063077816, 0.9399365426905006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 400}], {
             RGBColor[
             0.30016668312241634`, 0.43282459400155193`, 0.9404054205957836]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 414}], {
             RGBColor[
             0.2895347527456831, 0.421649761072285, 0.9397999478893602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 415}], {
             RGBColor[
             0.29571211190112656`, 0.42814255721184813`, 0.9401517393546788]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 379}], {
             RGBColor[
             0.288128547073246, 0.4201206026991259, 0.9397217393007642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 380}], {
             RGBColor[
             0.26990447818225494`, 0.4010170978748282, 0.9386820327933616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 390}], {
             RGBColor[
             0.28385568108857195`, 0.41568069668672125`, 0.9394765331599213]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 411}], {
             RGBColor[
             0.2532739296678089, 0.38353733694846814`, 0.9377349476581557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 478}], {
             RGBColor[
             0.26649991887633445`, 0.3974386901827782, 0.9384881481774836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 359}], {
             RGBColor[
             0.3577633677707141, 0.48429838027845357`, 0.9440173433299934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 373}], {
             RGBColor[
             0.3118454823562334, 0.44312769697598026`, 0.9411427175470836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 397}], {
             RGBColor[
             0.34431176305958455`, 0.4726472763749843, 0.9431602189725873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 398}], {
             RGBColor[
             0.29561326424229706`, 0.426066606556162, 0.9402183167389095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 472}], {
             RGBColor[
             0.3292610947634469, 0.4596111439654538, 0.9422012036975409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 325}], {
             RGBColor[
             0.1822582683189515, 0.30889537421782864`, 0.9336907108025945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 347}], {
             RGBColor[
             0.1822133081343763, 0.30884811821319974`, 0.9336881503865955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 368}], {
             RGBColor[
             0.2968006331253079, 0.42010055334026064`, 0.9405500774666419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 386}], {
             RGBColor[
             0.1822133081343763, 0.30884811821319974`, 0.9336881503865955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 401}], {
             RGBColor[
             0.47947599697395743`, 0.5676241897079666, 0.9559647317614918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 378}], {
             RGBColor[
             0.26678973270236006`, 0.397743302889189, 0.9385046526461347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 357}], {
             RGBColor[
             0.895271303645258, 0.6164935275347583, 0.23428070819651722`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 418}], {
             RGBColor[
             0.9309369071770426, 0.7734480360326559, 0.5728708276939365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 420}], {
             RGBColor[
             0.9260215766566631, 0.7697821905786719, 0.5811912001414211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 321}], {
             RGBColor[
             0.33755888801482614`, 0.46679827542058316`, 0.9427299317460682]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 330}], {
             RGBColor[
             0.32419593809646025`, 0.45501163764918373`, 0.9418862305492528]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 335}], {
             RGBColor[
             0.3093572475376726, 0.43941523304457686`, 0.9410411890738053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 350}], {
             RGBColor[
             0.3520561578815369, 0.47935508192515797`, 0.9436536849625428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 354}], {
             RGBColor[
             0.35185308329442466`, 0.47917918892462685`, 0.9436407452294238]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 383}], {
             RGBColor[
             0.3354424216880899, 0.46496509866505487`, 0.9425950723832464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 479}], {
             RGBColor[
             0.3767164983407358, 0.5007146293661655, 0.94522502005032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 482}], {
             RGBColor[
             0.35021188070592757`, 0.4777576617317112, 0.9435361692517431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 496}], {
             RGBColor[
             0.3094159330482752, 0.43947691523709653`, 0.9410445311268166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 331}], {
             RGBColor[
             0.775790689833521, 0.8249078922958527, 0.9782513878368327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 377}], {
             RGBColor[
             0.8479973976544979, 0.8813126625416667, 0.9445427395689829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 449}], {
             RGBColor[
             0.7215962304048408, 0.7824357266175173, 0.9728856266127364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 488}], {
             RGBColor[
             0.7421269925364968, 0.7984745140343386, 0.9749319411111395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 337}], {
             RGBColor[
             0.9244065988908812, 0.9404637664434601, 0.9125392493325524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 348}], {
             RGBColor[
             0.9742570536765062, 0.9329947209284535, 0.5686571215977747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 361}], {
             RGBColor[
             0.8164019725999951, 0.8557645940777792, 0.9018606390244552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 375}], {
             RGBColor[
             0.9734019680069053, 0.9789510679067093, 0.8970939407523506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 335}], {
             RGBColor[
             0.3049738126003747, 0.4356185220197354, 0.94076188047572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 383}], {
             RGBColor[
             0.3310589867507921, 0.46116838764021345`, 0.942315763785161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 479}], {
             RGBColor[
             0.37233306340343797`, 0.49691791834132404`, 0.9449457114522347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 482}], {
             RGBColor[
             0.3458284457686297, 0.47396095070686983`, 0.9432568606536578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 496}], {
             RGBColor[
             0.3050324981109774, 0.4356802042122551, 0.9407652225287313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 494}], {
             RGBColor[
             0.2588610411681461, 0.3894097453786518, 0.9380531253927091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 342}], {
             RGBColor[
             0.2496659047127254, 0.3797450739586806, 0.9375294759745583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 395}], {
             RGBColor[
             0.25216611947306267`, 0.3823729581945666, 0.9376718595064233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 447}], {
             RGBColor[
             0.24292230663621342`, 0.3726571248114532, 0.9371454380403603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 452}], {
             RGBColor[
             0.23164904535488023`, 0.3608082124387239, 0.9365034424876839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 463}], {
             RGBColor[
             0.25322101360276406`, 0.3834817188090337, 0.9377319341665338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 441}], {
             RGBColor[
             0.4099049258998564, 0.5294607772190044, 0.947339757307013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 481}], {
             RGBColor[
             0.3439470735768655, 0.47233140067487944`, 0.9431369812812307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 347}], {
             RGBColor[
             0.1789719601845752, 0.3054412560046289, 0.9335035604159989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 368}], {
             RGBColor[
             0.2935592851755068, 0.41669369113168975`, 0.9403654874960453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 386}], {
             RGBColor[
             0.1789719601845752, 0.3054412560046289, 0.9335035604159989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 401}], {
             RGBColor[
             0.4762346490241563, 0.5642173274993956, 0.9557801417908952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 421}], {
             RGBColor[
             0.17903676307516053`, 0.3055093679513746, 0.9335072508447505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 405}], {
             RGBColor[
             0.9345940973525277, 0.7578425175728066, 0.403625723074449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 428}], {
             RGBColor[
             0.8527545036662538, 0.3801225472055363, 0.19711821090416948`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 434}], {
             RGBColor[
             0.9331890448533395, 0.7583565146768234, 0.5065076494810187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 469}], {
             RGBColor[
             0.8678030946468546, 0.4926065528105953, 0.21140400054171546`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 474}], {
             RGBColor[
             0.9341363327937491, 0.7587482425843726, 0.49080863680582576`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 475}], {
             RGBColor[
             0.8570894511774583, 0.4134428533627656, 0.20126936153652183`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 491}], {
             RGBColor[
             0.9346684716417725, 0.7580015966571071, 0.4117209054738351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 495}], {
             RGBColor[
             0.8586889913459645, 0.42573762002087545`, 0.2028010830083056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 399}], {
             RGBColor[
             0.24928505714751653`, 0.3793447790205158, 0.9375077872691331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 412}], {
             RGBColor[
             0.2497253233645969, 0.37980752672915763`, 0.9375328597788803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 483}], {
             RGBColor[
             0.27685916583525294`, 0.4083269155507945, 0.9390780919666615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 431}], {
             RGBColor[
             0.4169264678183623, 0.535542483915856, 0.9477871637491544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 433}], {
             RGBColor[
             0.35540962848104596`, 0.48225968960811955`, 0.9438673651437858]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 436}], {
             RGBColor[
             0.42911640965865483`, 0.5455685636524759, 0.9487109542359491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 462}], {
             RGBColor[
             0.4245956854340748, 0.5418984360706564, 0.9483550662650316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 487}], {
             RGBColor[
             0.4823721914903405, 0.5888040064890694, 0.952903444464096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 406}], {
             RGBColor[
             0.9365881325497546, 0.9446037269852596, 0.7033574817962612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 413}], {
             RGBColor[
             0.9281969547806851, 0.9162983140279535, 0.6707593407043844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 486}], {
             RGBColor[
             0.9087427412464592, 0.930070810978078, 0.9911578879759511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 350}], {
             RGBColor[
             0.33430977302587317`, 0.4637717331289171, 0.9425306751676419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 354}], {
             RGBColor[
             0.3341066984387609, 0.463595840128386, 0.9425177354345229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 414}], {
             RGBColor[
             0.2905537605670515, 0.4227208029013707, 0.9398579788773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 415}], {
             RGBColor[
             0.29673111972249494`, 0.4292135990409338, 0.9402097703426187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 482}], {
             RGBColor[
             0.33246549585026375`, 0.4621743129354704, 0.9424131594568423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 496}], {
             RGBColor[
             0.2916695481926115, 0.42389356644085574`, 0.9399215213319159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 377}], {
             RGBColor[
             0.9088984029132244, 0.9290240327940705, 0.9505769466051841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 403}], {
             RGBColor[
             0.8828018353475209, 0.9093862367613971, 0.9886836212135901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 449}], {
             RGBColor[
             0.7824972356635673, 0.8301470968699212, 0.9789198336489376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 488}], {
             RGBColor[
             0.8030279977952235, 0.8461858842867422, 0.9809661481473407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 344}], {
             RGBColor[
             0.4329675168621825, 0.5491533716913533, 0.9488874962659426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 393}], {
             RGBColor[
             0.4317017689879543, 0.548125780545763, 0.9487878519566961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 424}], {
             RGBColor[
             0.36139324266635137`, 0.48744239547023754`, 0.9442486357485711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 392}], {
             RGBColor[
             0.34232526370384136`, 0.4706729127563853, 0.943042932303461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 442}], {
             RGBColor[
             0.331297230301234, 0.4590817504325423, 0.942414902115696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 459}], {
             RGBColor[
             0.3845976264069504, 0.5075408663801063, 0.9457271985616913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 492}], {
             RGBColor[
             0.32763422405457243`, 0.45523169861929097`, 0.9422062993288807]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 340}], {
             RGBColor[
             0.37011932022613914`, 0.4950004852671151, 0.9448046536945134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 355}], {
             RGBColor[
             0.36575544066311605`, 0.49122071212458884`, 0.9445265911475849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 361}], {
             RGBColor[
             0.5235027630627838, 0.6226423570970218, 0.9560294677740079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 363}], {
             RGBColor[
             0.40380771802618465`, 0.5241796822134083, 0.9469512486128518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 369}], {
             RGBColor[
             0.4113757512055576, 0.5307347321729735, 0.9474334769948924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 370}], {
             RGBColor[
             0.49712370807879736`, 0.6012548758448955, 0.9539335150694623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 379}], {
             RGBColor[
             0.3560516389210633, 0.4828157667828796, 0.9439082734813162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 498}], {
             RGBColor[
             0.4323467950368561, 0.5486660596707702, 0.9488340391891498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 383}], {
             RGBColor[
             0.3028573462736385, 0.4337853452642071, 0.940627021112898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 409}], {
             RGBColor[
             0.25916391695491414`, 0.389728087033979, 0.938070373720701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 482}], {
             RGBColor[
             0.3176268052914761, 0.44657790833086347`, 0.9415681179813948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 496}], {
             RGBColor[
             0.27683085763382376`, 0.40829716183624876`, 0.9390764798564684]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 409}], {
             RGBColor[
             0.23189710424361965`, 0.36106893805863094`, 0.9365175690744273]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 456}], {
             RGBColor[
             0.22294853768143919`, 0.3516634272298894, 0.936007961446929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 458}], {
             RGBColor[
             0.22636890121139194`, 0.35525844616344304`, 0.9362027460899854]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 348}], {
             RGBColor[
             0.9100611549268829, 0.8839036332529456, 0.6426467308354947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 361}], {
             RGBColor[
             0.752206073850372, 0.8066735064022713, 0.9758502482621753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 370}], {
             RGBColor[
             0.7258270188663856, 0.785286025150145, 0.9737542955576297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 375}], {
             RGBColor[
             0.9092060692572821, 0.9298599802312014, 0.9710835499900707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 498}], {
             RGBColor[
             0.6610501058244442, 0.7326972089760198, 0.9686548196773171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 369}], {
             RGBColor[
             0.37002637582951403`, 0.49491998150227967`, 0.9447987313597479]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 379}], {
             RGBColor[
             0.31470226354501973`, 0.4470010161121858, 0.9412735278461717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 390}], {
             RGBColor[
             0.3104293975603457, 0.44256111009978116`, 0.9410283217053288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 425}], {
             RGBColor[
             0.3477240886796976, 0.47560286131865376`, 0.9433776493436998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 478}], {
             RGBColor[
             0.29307363534810826`, 0.42431910359583813`, 0.9400399367228911]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 365}], {
             RGBColor[
             0.2143326753092825, 0.34260760959952685`, 0.9355173008308608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 355}], {
             RGBColor[
             0.3330706823231735, 0.4629108172342508, 0.9424439472481606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 362}], {
             RGBColor[
             0.3629480512357022, 0.4887890925060583, 0.944347706775747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 363}], {
             RGBColor[
             0.37112295968624204`, 0.49586978732307024`, 0.9448686047134276]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 378}], {
             RGBColor[
             0.31025949401998754`, 0.4407803246133216, 0.9410773105637218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 379}], {
             RGBColor[
             0.32336688058112073`, 0.45450587189254155`, 0.941825629581892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 380}], {
             RGBColor[
             0.3051428116901297, 0.43540236706824387`, 0.9407859230744895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 498}], {
             RGBColor[
             0.39966203669691347`, 0.5203561647804322, 0.9467513952897255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 387}], {
             RGBColor[
             0.8843435887930974, 0.9064532397024012, 0.7600495256450741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 403}], {
             RGBColor[
             0.9612426733705868, 0.9674078133042042, 0.7674804702008887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 405}], {
             RGBColor[
             0.9937930272646951, 0.989132237877419, 0.5657875066366207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 450}], {
             RGBColor[
             0.9056409272943111, 0.562891578052587, 0.35323513131972123`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 469}], {
             RGBColor[
             0.927002024559022, 0.7238962731152077, 0.3735657841038871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 491}], {
             RGBColor[
             0.9938674015539399, 0.9892913169617195, 0.5738826890360067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 395}], {
             RGBColor[
             0.2624873580585535, 0.3932212343522405, 0.9382596387749628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 447}], {
             RGBColor[
             0.2532435452217043, 0.38350540096912705`, 0.9377332173088998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 453}], {
             RGBColor[
             0.27214698791275327`, 0.40337411778491095`, 0.9388097404050177]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 463}], {
             RGBColor[
             0.2635422521882549, 0.3943299949667075, 0.9383197134350733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 392}], {
             RGBColor[
             0.29944445035868683`, 0.4320654815746701, 0.9403642905083368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 433}], {
             RGBColor[
             0.3091968798489231, 0.4407663035487692, 0.9409764153784905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 465}], {
             RGBColor[
             0.2877565452274621, 0.4197807522257663, 0.9396986816018197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 387}], {
             RGBColor[
             0.6194283934274943, 0.6998852662527452, 0.9645732255440658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 424}], {
             RGBColor[
             0.39216870621134226`, 0.5138154925134429, 0.9462878321282429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 375}], {
             RGBColor[
             0.8089633164388916, 0.8512244424146573, 0.9611785706908804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 426}], {
             RGBColor[
             0.7649497936964772, 0.8167095300211071, 0.9770990522255436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 448}], {
             RGBColor[
             0.6138322543981429, 0.6971096748541594, 0.9629241548523259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 489}], {
             RGBColor[
             0.8249113944148371, 0.8621373590775923, 0.8902454594075883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 498}], {
             RGBColor[
             0.5608073530060538, 0.6540616711594758, 0.9587498403781267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 358}], {
             RGBColor[
             0.2217544347167852, 0.3504083493035373, 0.935939959049609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 404}], {
             RGBColor[
             0.21566548218765702`, 0.3440084741335353, 0.9355932022108733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 407}], {
             RGBColor[
             0.2161204994130187, 0.34448672608714886`, 0.9356191147687198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 408}], {
             RGBColor[
             0.22019359510263653`, 0.34876780790611966`, 0.9358510715426385]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 430}], {
             RGBColor[
             0.22881084125106885`, 0.35782507997308444`, 0.9363418109627185]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 368}], {
             RGBColor[
             0.2935143249909316, 0.4166464351270609, 0.9403629270800464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 386}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 421}], {
             RGBColor[
             0.17899180289058533`, 0.3054621119467458, 0.9335046904287516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 477}], {
             RGBColor[
             0.2117993137193227, 0.3399448859440771, 0.9353730296360853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 375}], {
             RGBColor[
             0.959056524042907, 0.9223909347161948, 0.6272014222552931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 428}], {
             RGBColor[
             0.8951225528654855, 0.5552983535621828, 0.23772264959288408`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 359}], {
             RGBColor[
             0.3995263663781553, 0.520471390602876, 0.94667844467169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 371}], {
             RGBColor[
             0.3882726943942144, 0.5107240255563866, 0.9459613706441047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 397}], {
             RGBColor[
             0.38607476166702576`, 0.5088202866994067, 0.9458213203142838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 419}], {
             RGBColor[
             0.4631460027688009, 0.5739634184897324, 0.951177660656908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 354}], {
             RGBColor[
             0.36196691822383753`, 0.4879392844043602, 0.9442851898478128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 383}], {
             RGBColor[
             0.34555625661750283`, 0.4737251941447882, 0.9432395170016354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 414}], {
             RGBColor[
             0.31841398035212815`, 0.44706424717734483`, 0.94162543329059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 479}], {
             RGBColor[
             0.3868303332701487, 0.5094747248458988, 0.9458694646687091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 482}], {
             RGBColor[
             0.36032571563534044`, 0.4865177572114446, 0.9441806138701323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 356}], {
             RGBColor[
             0.2796916905937343, 0.4113040786644009, 0.9392394000613121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 463}], {
             RGBColor[
             0.27857140569147526`, 0.4101265882019613, 0.9391756014934415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 367}], {
             RGBColor[
             0.2288379775147259, 0.35785360190672644`, 0.9363433563327893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 399}], {
             RGBColor[
             0.23466592421327268`, 0.3639791434000619, 0.936675249275597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 412}], {
             RGBColor[
             0.23510619043035305`, 0.36444189110870373`, 0.9367003217853442]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 457}], {
             RGBColor[
             0.22470998276050042`, 0.3535148176900512, 0.9361082731383572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 418}], {
             RGBColor[
             0.809068015481273, 0.8509060188194038, 0.9430493347226458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 420}], {
             RGBColor[
             0.8041526849608935, 0.8472401733654197, 0.9513697071701304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 432}], {
             RGBColor[
             0.7691435045990516, 0.820174333900838, 0.9774842614710615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 441}], {
             RGBColor[
             0.5448974710637005, 0.6413248437593597, 0.9573393706579376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 372}], {
             RGBColor[
             0.416108457877265, 0.5343687074376324, 0.9478635928798225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 414}], {
             RGBColor[
             0.3182109057650159, 0.4468883541768137, 0.941612493557471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 415}], {
             RGBColor[
             0.32438826492045936`, 0.4533811503163769, 0.9419642850227896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 479}], {
             RGBColor[
             0.38662725868303643`, 0.5092988318453677, 0.9458565249355901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 482}], {
             RGBColor[
             0.3601226410482282, 0.48634186421091347`, 0.9441676741370133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 362}], {
             RGBColor[
             0.3585841716726791, 0.48500931936353203`, 0.9440696442288183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 363}], {
             RGBColor[
             0.366759080123219, 0.492090014180544, 0.9445905421664991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 378}], {
             RGBColor[
             0.30589561445696456`, 0.4370005514707954, 0.940799248016793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 384}], {
             RGBColor[
             0.3062638013444511, 0.43738753923394075`, 0.9408202157153518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 498}], {
             RGBColor[
             0.3952981571338905, 0.516576391637906, 0.946473332742797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 463}], {
             RGBColor[
             0.26821764598055253`, 0.3992441302795001, 0.9385859701949193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 418}], {
             RGBColor[
             0.9428078871600445, 0.8265116366232681, 0.582732825135219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 420}], {
             RGBColor[
             0.937892556639665, 0.822845791169284, 0.5910531975827036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 404}], {
             RGBColor[
             0.21953726017780179`, 0.34807795828608057`, 0.9358136942396298]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 407}], {
             RGBColor[
             0.21999227740316346`, 0.34855621023969413`, 0.9358396067974764]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 408}], {
             RGBColor[
             0.2240653730927813, 0.35283729205866493`, 0.936071563571395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 430}], {
             RGBColor[
             0.23268261924121364`, 0.3618945641256297, 0.936562302991475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 371}], {
             RGBColor[
             0.37419759071797254`, 0.49853287818730624`, 0.94506451748398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 397}], {
             RGBColor[
             0.3719996579907838, 0.4966291393303264, 0.9449244671541592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 419}], {
             RGBColor[
             0.44907089909255904`, 0.561772271120652, 0.9502808074967835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 427}], {
             RGBColor[
             0.3324756951564906, 0.4596914885288097, 0.9425050411722034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 393}], {
             RGBColor[
             0.5202889035975207, 0.6214329965452928, 0.9553781948537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 466}], {
             RGBColor[
             0.5414372478398441, 0.638602175123262, 0.9570430699813932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 468}], {
             RGBColor[
             0.5288716731016017, 0.6284008754780657, 0.9560538619087819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 363}], {
             RGBColor[
             0.5245064025228867, 0.6235116591529769, 0.9560934187929221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 370}], {
             RGBColor[
             0.6178223925754994, 0.7005868527844641, 0.9630756852495326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 498}], {
             RGBColor[
             0.5530454795335582, 0.6479980366103388, 0.95797620936922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 363}], {
             RGBColor[
             0.3966364490357477, 0.5179682894523514, 0.9464943016940854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 384}], {
             RGBColor[
             0.33614117025697976`, 0.4632658145057482, 0.9427239752429382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 498}], {
             RGBColor[
             0.4251755260464191, 0.5424546669097134, 0.9483770922703834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 370}], {
             RGBColor[
             0.4981273475389003, 0.6021241779008506, 0.9539974660883765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 379}], {
             RGBColor[
             0.35705527838116624`, 0.4836850688388347, 0.9439722245002304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 498}], {
             RGBColor[
             0.433350434496959, 0.5495353617267253, 0.948897990208064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 374}], {
             RGBColor[
             0.2551484985501697, 0.3855076276983612, 0.93784170158283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 437}], {
             RGBColor[
             0.25719856867599794`, 0.38766238138256004`, 0.9379584500436889]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 435}], {
             RGBColor[
             0.2615619901606841, 0.3922486140198663, 0.9382069404421383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 473}], {
             RGBColor[
             0.29591877827497415`, 0.42668767083692927`, 0.940224732684648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 416}], {
             RGBColor[
             0.24568937276892794`, 0.3755654867590621, 0.9373030183631108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 457}], {
             RGBColor[
             0.22571706608911693`, 0.3545733261211982, 0.9361656250440755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 499}], {
             RGBColor[
             0.24528184927831587`, 0.3751371537319471, 0.9372798105031974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 386}], {
             RGBColor[
             0.2935143249909316, 0.4166464351270609, 0.9403629270800464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 401}], {
             RGBColor[
             0.5907770138305127, 0.6754225066218276, 0.9626395084549426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 500}], {
             RGBColor[
             0.6137971561371982, 0.33936679556971105`, 0.5567621778131115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 370}], {
             RGBColor[
             0.5056953807182732, 0.6086792278604158, 0.9544796944704173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 379}], {
             RGBColor[
             0.3646233115605392, 0.49024011879839996`, 0.944454452882271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 390}], {
             RGBColor[
             0.36035044557586515`, 0.48580021278599533`, 0.9442092467414281]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 425}], {
             RGBColor[
             0.397645136695217, 0.5188419640048679, 0.9465585743797993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 466}], {
             RGBColor[
             0.46172779849419876`, 0.5729843638939052, 0.9510184053391775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 466}], {
             RGBColor[
             0.5474757553674385, 0.6435045075658272, 0.9575184434137474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 382}], {
             RGBColor[
             0.322584307384319, 0.45137597056269757`, 0.9418655472151594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 419}], {
             RGBColor[
             0.43781722710861815`, 0.5520249060741627, 0.9495637334691982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 427}], {
             RGBColor[
             0.3212220231725497, 0.4499441234823203, 0.9417879671446181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 429}], {
             RGBColor[
             0.3282709430209225, 0.4573529851702918, 0.9421893927020404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 417}], {
             RGBColor[
             0.5857428674141524, 0.6736726673586156, 0.9611454890036907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 398}], {
             RGBColor[
             0.27738327375901567`, 0.40887778620903076`, 0.9391079391375716]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 472}], {
             RGBColor[
             0.31103110428016545`, 0.44242232361832246`, 0.9410908260962028]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 391}], {
             RGBColor[
             0.24642877472957408`, 0.3763426451004932, 0.9373451262109225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 437}], {
             RGBColor[
             0.25378039219455883`, 0.3840696611756612, 0.9377637899498099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 426}], {
             RGBColor[
             0.9141879156308917, 0.9338323693009003, 0.9715587229445324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 489}], {
             RGBColor[
             0.9741495163492516, 0.9792601983573855, 0.8847051301265769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 400}], {
             RGBColor[
             0.2876884645475003, 0.41970919511456195`, 0.9396948045078122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 414}], {
             RGBColor[
             0.27705653417076703`, 0.40853436218529504`, 0.9390893318013886]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 415}], {
             RGBColor[
             0.28323389332621046`, 0.41502715832485815`, 0.9394411232667073]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 464}], {
             RGBColor[
             0.2616609318454717, 0.3923526080038432, 0.9382125750247157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 485}], {
             RGBColor[
             0.26372814560153673`, 0.3945253807303899, 0.938330299789955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 497}], {
             RGBColor[
             0.25772437162935435`, 0.38821503362437043`, 0.9379883937440268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 403}], {
             RGBColor[
             0.9550085431684978, 0.9657910070072111, 0.9549749729457403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 449}], {
             RGBColor[
             0.8547039434845443, 0.8865518671157351, 0.9452111853810878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 484}], {
             RGBColor[
             0.9869984046810305, 0.9863165950507087, 0.692275872605006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 488}], {
             RGBColor[
             0.8752347056162003, 0.9025906545325564, 0.9472574998794909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 380}], {
             RGBColor[
             0.27796774382392075`, 0.40949210130478847`, 0.939141223843122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 380}], {
             RGBColor[
             0.29107513038505384`, 0.42321764858400834`, 0.9398895428612922]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 390}], {
             RGBColor[
             0.30502633329137085`, 0.4378812473959014, 0.9406840432278518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 478}], {
             RGBColor[
             0.2876705710791334, 0.41963924089195836`, 0.9396956582454141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 390}], {
             RGBColor[
             0.2868022644003798, 0.4187777425716037, 0.9396443367204493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 411}], {
             RGBColor[
             0.2562205129796168, 0.38663438283335066`, 0.9379027512186837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 478}], {
             RGBColor[
             0.26944650218814237`, 0.40053573606766074`, 0.9386559517380118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 419}], {
             RGBColor[
             0.5409976687744238, 0.6382453050351424, 0.9570084647071322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 439}], {
             RGBColor[
             0.7151086431122187, 0.7765792866784462, 0.9729163506443089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 416}], {
             RGBColor[
             0.2718791903645599, 0.40309264558241453`, 0.938794489730819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 427}], {
             RGBColor[
             0.2808624118228371, 0.41253458090420103`, 0.9393060709033827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 429}], {
             RGBColor[
             0.2879113316712099, 0.41994344259217253`, 0.9397074964608051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 499}], {
             RGBColor[
             0.27147166687394786`, 0.40266431255529955`, 0.9387712818709056]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 479}], {
             RGBColor[
             0.37021659707670174`, 0.49508474158579574`, 0.9448108520894127]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 482}], {
             RGBColor[
             0.34371197944189347`, 0.47212777395134153`, 0.9431220012908359]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 496}], {
             RGBColor[
             0.30291603178424115`, 0.4338470274567268, 0.9406303631659094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 435}], {
             RGBColor[
             0.2709692417504848, 0.4021362318949472, 0.9387426695033958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 391}], {
             RGBColor[
             0.23729940724147955`, 0.36674710103517516`, 0.9368252222381643]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 421}], {
             RGBColor[
             0.17899180289058533`, 0.3054621119467458, 0.9335046904287516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 403}], {
             RGBColor[
             0.8520128910253049, 0.8851986373727346, 0.9856507029983317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 405}], {
             RGBColor[
             0.8845632449194131, 0.9069230619459494, 0.7839577394340637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 491}], {
             RGBColor[
             0.8846376192086578, 0.9070821410302499, 0.7920529218334498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 487}], {
             RGBColor[
             0.7628017392959624, 0.8144116714200249, 0.9680174393113103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 490}], {
             RGBColor[
             0.9683628300119925, 0.9748687448836537, 0.8911081388957877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 409}], {
             RGBColor[
             0.23002772223876133`, 0.35910409904586005`, 0.9364111105347535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 451}], {
             RGBColor[
             0.21497280031897864`, 0.34328042157098726`, 0.9355537550031829]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 456}], {
             RGBColor[
             0.22107915567658082`, 0.3496985882171184, 0.9359015029072553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 458}], {
             RGBColor[
             0.2244995192065336, 0.35329360715067204`, 0.9360962875503116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 425}], {
             RGBColor[
             0.3380481584260487, 0.4664830926023694, 0.94278816472538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 478}], {
             RGBColor[
             0.2833977050944594, 0.41519933487955374`, 0.9394504521045712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 459}], {
             RGBColor[
             0.34827375514967984`, 0.47582519706689724`, 0.9434219649183455]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 465}], {
             RGBColor[
             0.2943134873153461, 0.42667251409427237`, 0.9400720897535981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 492}], {
             RGBColor[
             0.2913103527973019, 0.4235160293060819, 0.9399010656855349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 468}], {
             RGBColor[
             0.4697942541627981, 0.5804391653761509, 0.9514030710822032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 398}], {
             RGBColor[
             0.24489676758341208`, 0.3747324084550136, 0.93725788067035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 445}], {
             RGBColor[
             0.2291408986849781, 0.35817199126297306`, 0.9363606072453035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 460}], {
             RGBColor[
             0.23849436642390026`, 0.3680030789006874, 0.9368932733958195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 440}], {
             RGBColor[
             0.2733307058970075, 0.4046182804384171, 0.9388771513930672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 447}], {
             RGBColor[
             0.2557437599820415, 0.3861332852050131, 0.9378756008407647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 453}], {
             RGBColor[
             0.2746472026730905, 0.406002002020797, 0.9389521239368825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 463}], {
             RGBColor[
             0.2660424669485921, 0.39695787920259357`, 0.9384620969669382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 422}], {
             RGBColor[
             0.6137790328303492, 0.6759479174311498, 0.7377723993512193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 443}], {
             RGBColor[
             0.9640290207521414, 0.8833364286136021, 0.40253589756085995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 446}], {
             RGBColor[
             0.6108486673250959, 0.6728679174892245, 0.7376055193707824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 419}], {
             RGBColor[
             0.43561929438142943`, 0.5501211672171827, 0.9494236831393772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 472}], {
             RGBColor[
             0.3434973849835166, 0.4719419030173265, 0.9431083275217065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 445}], {
             RGBColor[
             0.2453951867466454, 0.3752562785971719, 0.9372862649043511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 460}], {
             RGBColor[
             0.2547486544855675, 0.3850873662348864, 0.9378189310548671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 472}], {
             RGBColor[
             0.2947988861662292, 0.4253612331985043, 0.9401664252880289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 412}], {
             RGBColor[
             0.24194122045751632`, 0.37162594103318614`, 0.9370895666338703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 414}], {
             RGBColor[
             0.28528989827003975`, 0.41718814987906533`, 0.9395582097066717]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 415}], {
             RGBColor[
             0.2914672574254832, 0.4236809460186285, 0.9399100011719903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 464}], {
             RGBColor[
             0.26989429594474446`, 0.40100639569761354`, 0.9386814529299987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 450}], {
             RGBColor[
             0.7955804305647025, 0.4800334417304184, 0.5713225662708019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 454}], {
             RGBColor[
             0.8366674019364873, 0.7306087240183134, 0.6081129719353302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 471}], {
             RGBColor[
             0.8151324803555211, 0.6303190641854999, 0.5900456312313715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 475}], {
             RGBColor[
             0.806227884360017, 0.5618744373452094, 0.5815185800497742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 500}], {
             RGBColor[
             0.7964725199858478, 0.48689043193741693`, 0.5721768321079614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 431}], {
             RGBColor[
             0.5004255816893457, 0.6051773211877334, 0.9538503277794443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 436}], {
             RGBColor[
             0.5126155235296384, 0.6152034009243532, 0.954774118266239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 459}], {
             RGBColor[
             0.4714286755649022, 0.5800616585296188, 0.952002670562152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 462}], {
             RGBColor[
             0.5080947993050582, 0.6115332733425336, 0.9544182302953215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 487}], {
             RGBColor[
             0.565871305361324, 0.6584388437609466, 0.958966608494386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 405}], {
             RGBColor[
             0.9614623294969025, 0.9678776355477525, 0.7913886839898783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 449}], {
             RGBColor[
             0.8286073759188407, 0.8669140710830616, 0.9833178599894938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 491}], {
             RGBColor[
             0.9615367037861473, 0.968036714632053, 0.7994838663892643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 407}], {
             RGBColor[
             0.2139033248740353, 0.3421563350696921, 0.9354928499587406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 408}], {
             RGBColor[
             0.2179764205636531, 0.3464374168886629, 0.9357248067326592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 434}], {
             RGBColor[
             0.9926076308918226, 0.9901160572249841, 0.6925776468321798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 469}], {
             RGBColor[
             0.9272216806853377, 0.724366095358756, 0.3974739978928766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 474}], {
             RGBColor[
             0.9935549188322322, 0.9905077851325332, 0.6768786341569868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 491}], {
             RGBColor[
             0.9940870576802556, 0.9897611392052678, 0.5977909028249961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 413}], {
             RGBColor[
             0.9822272031257195, 0.951710324271208, 0.3854564695648335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 476}], {
             RGBColor[
             0.9195554041525527, 0.6768776802935997, 0.3060621599750899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 486}], {
             RGBColor[
             0.9627729895914936, 0.9654828212213326, 0.7058550168364002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 493}], {
             RGBColor[
             0.9920978208950986, 0.9843432363296774, 0.4801786397760631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 408}], {
             RGBColor[
             0.2184314377890148, 0.3469156688422765, 0.9357507192905059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 430}], {
             RGBColor[
             0.22704868393744712`, 0.35597294090924125`, 0.9362414587105858]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{408, 430}], {
             RGBColor[
             0.23112177962706493`, 0.36025402272821205`, 0.9364734154845045]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 456}], {
             RGBColor[
             0.23260709522442666`, 0.3618151835954873, 0.9365580020104467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 458}], {
             RGBColor[
             0.23602745875437942`, 0.36541020252904094`, 0.9367527866535031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 496}], {
             RGBColor[
             0.25922260246551676`, 0.38978976922649866`, 0.9380737157737123]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{411, 478}], {
             RGBColor[
             0.2528159536736963, 0.3830559751413007, 0.9377088666028057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 476}], {
             RGBColor[
             0.9111642263834832, 0.6485722673362936, 0.273464018883213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 486}], {
             RGBColor[
             0.9543818118224241, 0.9371774082640264, 0.6732568757445232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 493}], {
             RGBColor[
             0.9837066431260291, 0.9560378233723712, 0.44758049868418615`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 415}], {
             RGBColor[
             0.2808353270487499, 0.4125061130893616, 0.9393045284655668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 485}], {
             RGBColor[
             0.26132957932407624`, 0.39200433549489333`, 0.9381937049888145]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{415, 464}], {
             RGBColor[
             0.2654397247234546, 0.39632435890790974`, 0.9384277716888938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{415, 485}], {
             RGBColor[
             0.2675069384795197, 0.39849713163445644`, 0.9385454964541331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 427}], {
             RGBColor[
             0.2705169061527906, 0.4016607985020373, 0.9387169096602777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 429}], {
             RGBColor[
             0.2775658260011634, 0.4090696601900088, 0.9391183352177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 499}], {
             RGBColor[
             0.26112616120390136`, 0.3917905301531358, 0.9381821206278006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{417, 461}], {
             RGBColor[
             0.8227440842305245, 0.8622334494485463, 0.9748712810946092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 420}], {
             RGBColor[
             0.9735581601714495, 0.9798002996671817, 0.9296433170801228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 432}], {
             RGBColor[
             0.9385489798096075, 0.9527344602026001, 0.9557578713810538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 432}], {
             RGBColor[
             0.933633649289228, 0.949068614748616, 0.9640782438285385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 439}], {
             RGBColor[
             0.9147776569049322, 0.9340333582536569, 0.9622797424419812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 423}], {
             RGBColor[
             0.18344124862659156`, 0.31013876152644193`, 0.9337580797810521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 477}], {
             RGBColor[
             0.21186411660990806`, 0.34001299789082284`, 0.9353767200648369]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 443}], {
             RGBColor[
             0.5842619922483114, 0.5706803433206208, 0.6014015077150748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 446}], {
             RGBColor[
             0.2310816388212659, 0.36021183219624314`, 0.9364711295249972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 446}], {
             RGBColor[
             0.20798858239401255`, 0.3359395657068551, 0.9351560141245807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 477}], {
             RGBColor[
             0.21624875945532895`, 0.3446215355237733, 0.9356264189883857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 440}], {
             RGBColor[
             0.30113413549531765`, 0.4327459792905174, 0.940500626045089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 453}], {
             RGBColor[
             0.3024506322714007, 0.4341297008728973, 0.9405755985889044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 470}], {
             RGBColor[
             0.28803826967359597`, 0.4189813939860375, 0.9397548358601392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{425, 466}], {
             RGBColor[
             0.4394255113443823, 0.5536672437102792, 0.9495973233231294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 448}], {
             RGBColor[
             0.7190568535901429, 0.7797176017404024, 0.9733043071059779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 489}], {
             RGBColor[
             0.9301359936068372, 0.9447452859638352, 0.9006256116612403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 460}], {
             RGBColor[
             0.2639231904685617, 0.39473038525219195`, 0.938341407306589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 499}], {
             RGBColor[
             0.27010938266217854`, 0.4012324654749223, 0.9386937018003643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 495}], {
             RGBColor[
             0.8362679836981737, 0.2797771922017657, 0.1823635681891872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{429, 499}], {
             RGBColor[
             0.2771583025105514, 0.4086413271628938, 0.9390951273577867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 433}], {
             RGBColor[
             0.3870230907643596, 0.509641681699111, 0.9458817470057914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 436}], {
             RGBColor[
             0.46072987194196846`, 0.5729505557434673, 0.9507253360979548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 459}], {
             RGBColor[
             0.41954302397723237`, 0.5378088133487329, 0.9479538883938678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 462}], {
             RGBColor[
             0.4562091477173884, 0.5692804281616477, 0.9503694481270373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 487}], {
             RGBColor[
             0.5139856537736541, 0.6161859985800608, 0.9549178263261018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{432, 467}], {
             RGBColor[
             0.8027318187709938, 0.8464550865365966, 0.9808037893677689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 462}], {
             RGBColor[
             0.3946923083800721, 0.5159976338539112, 0.9464496495216687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 469}], {
             RGBColor[
             0.9258166281861495, 0.7248800924627727, 0.5003559242994462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 474}], {
             RGBColor[
             0.992149866333044, 0.99102178223655, 0.7797605605635565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 495}], {
             RGBColor[
             0.9167025248852594, 0.6580111596730529, 0.4917530067660364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 459}], {
             RGBColor[
             0.4317329658175249, 0.5478348930853527, 0.9488776788806625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 462}], {
             RGBColor[
             0.46839908955768095`, 0.5793065078982675, 0.951293238613832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 487}], {
             RGBColor[
             0.5261755956139467, 0.6262120783166807, 0.9558416168128965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 457}], {
             RGBColor[
             0.22152681415849518`, 0.35016910566479753`, 0.9359269963955489]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 460}], {
             RGBColor[
             0.23490540515407732`, 0.3642308530528161, 0.9366888873608955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 453}], {
             RGBColor[
             0.2829903357512072, 0.4147711638710876, 0.939427253023122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 470}], {
             RGBColor[
             0.2685779731534025, 0.3996228569842277, 0.9386064902943567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 467}], {
             RGBColor[
             0.5784857852356426, 0.6676055963951182, 0.960658898554645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 444}], {
             RGBColor[
             0.27761918641957545`, 0.4091257453730057, 0.939121374014589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 492}], {
             RGBColor[
             0.2802823193946945, 0.4119248669822389, 0.9392730354977699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{443, 446}], {
             RGBColor[
             0.5813316267430582, 0.5676003433786956, 0.6012346277346379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{444, 492}], {
             RGBColor[
             0.2739561801729139, 0.4052756935597544, 0.9389127712277736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{445, 460}], {
             RGBColor[
             0.23899278558713355`, 0.3685269490428458, 0.9369216576298206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 453}], {
             RGBColor[
             0.26540338983624123`, 0.39628616863768357`, 0.9384257024708196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 463}], {
             RGBColor[
             0.2567986541117429, 0.38724204581948013`, 0.9379356755008752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{449, 488}], {
             RGBColor[
             0.7488335383665432, 0.8037137186084069, 0.9756003869232444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 454}], {
             RGBColor[
             0.8587954548220276, 0.3876960227591984, 0.20138137545633958`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 469}], {
             RGBColor[
             0.8390695807149537, 0.298125435533924, 0.18492162257597716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 471}], {
             RGBColor[
             0.8372605332410615, 0.2874063629263848, 0.183314034752381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 475}], {
             RGBColor[
             0.8283559372455574, 0.2189617360860943, 0.17478698357078354`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 491}], {
             RGBColor[
             0.9059349577098716, 0.5635204793804358, 0.38523852750809673`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 500}], {
             RGBColor[
             0.8186005728713881, 0.14397773067830186`, 0.16544523562897076`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{451, 456}], {
             RGBColor[
             0.21755217330464396`, 0.3459915061206145, 0.9357006464788762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{453, 463}], {
             RGBColor[
             0.2757020968027919, 0.407110762635264, 0.939012198596993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 469}], {
             RGBColor[
             0.8801565520867384, 0.5487007178218191, 0.22171202824050545`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 471}], {
             RGBColor[
             0.8783475046128462, 0.5379816452142798, 0.2201044404169093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 475}], {
             RGBColor[
             0.8694429086173421, 0.4695370183739893, 0.21157738923531183`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 500}], {
             RGBColor[
             0.8596875442431727, 0.3945530129661969, 0.20223564129349905`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{456, 458}], {
             RGBColor[
             0.22707889219219896`, 0.35600469170029936`, 0.9362431790260048]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{461, 486}], {
             RGBColor[
             0.9396915520193736, 0.9545227464327241, 0.9862809714214389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{461, 493}], {
             RGBColor[
             0.9690163833229786, 0.9733831615410689, 0.7606045943611018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{462, 487}], {
             RGBColor[
             0.5216548713893666, 0.6225419507348611, 0.9554857288419789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 485}], {
             RGBColor[
             0.24593397699878092`, 0.3758225813134415, 0.9373169482121415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 497}], {
             RGBColor[
             0.23993020302659857`, 0.369512234207422, 0.9369750421662133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 468}], {
             RGBColor[
             0.49094259840512156`, 0.5976083439541202, 0.9530679462098963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 471}], {
             RGBColor[
             0.8586216305057723, 0.4484110579890054, 0.20364468753654688`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 474}], {
             RGBColor[
             0.9267639161265591, 0.7252718203703219, 0.4846569116242533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 475}], {
             RGBColor[
             0.8497170345102683, 0.3799664311487149, 0.19511763635494941`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 491}], {
             RGBColor[
             0.9272960549745825, 0.7245251744430564, 0.40556918029226263`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 495}], {
             RGBColor[
             0.8513165746787745, 0.3922611978068248, 0.19664935782673318`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 475}], {
             RGBColor[
             0.847907987036376, 0.36924735854117574`, 0.19351004853135326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 500}], {
             RGBColor[
             0.8381526226622067, 0.29426335313338325`, 0.18416830058954048`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{474, 495}], {
             RGBColor[
             0.917649812825669, 0.658402887580602, 0.4760539940908434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{476, 493}], {
             RGBColor[
             0.9210348441528622, 0.6812051793947629, 0.36818618909444256`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{479, 482}], {
             RGBColor[
             0.3849860560945393, 0.5078773046524521, 0.9457519489579096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{480, 481}], {
             RGBColor[
             0.33588196619861493`, 0.46534581002792214`, 0.9426230797707831]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{482, 496}], {
             RGBColor[
             0.31768549080207875`, 0.4466395905233832, 0.9415714600344062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{484, 500}], {
             RGBColor[
             0.9061921804601966, 0.5690195539734165, 0.316991474169404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{485, 497}], {
             RGBColor[
             0.24199741678266362`, 0.3716850069339687, 0.9370927669314526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{486, 493}], {
             RGBColor[
             0.9642524295918031, 0.9698103203224957, 0.7679790459557528]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.1263497464931148], {
             RGBColor[
             0.2661654894960651, 0.39708718370006774`, 0.9384691029190212]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.1263497464931148], {
             RGBColor[
             0.2124476857409665, 0.34062636604798524`, 0.9354099534635375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.1263497464931148], {
             RGBColor[
             0.46166603367100856`, 0.5738403098087559, 0.9507631877904368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.1263497464931148], {
             RGBColor[
             0.32430364693803726`, 0.45531725182765653`, 0.9418853195058047]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.1263497464931148], {
             RGBColor[
             0.23860734128045696`, 0.3681218226379481, 0.9368997071467691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.1263497464931148], {
             RGBColor[
             0.8276898195746623, 0.8654414113599355, 0.9834269879500976]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.1263497464931148], {
             RGBColor[
             0.8386821070512293, 0.8742063630160551, 0.9844754421425435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.1263497464931148], {
             RGBColor[
             0.6202936289377985, 0.7026213377380665, 0.963250933161866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.1263497464931148], {
             RGBColor[
             0.5751436787516512, 0.6659665741948753, 0.9596965636934954]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.1263497464931148], {
             RGBColor[
             0.2189624152550279, 0.3474737598249721, 0.9357809576716846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.1263497464931148], {
             RGBColor[
             0.23891813183632316`, 0.3684484832174229, 0.9369174062091523]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.1263497464931148], {
             RGBColor[
             0.27240341106773047`, 0.40364363477895904`, 0.9388243433243495]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.1263497464931148], {
             RGBColor[
             0.29661626096016863`, 0.4290928751992627, 0.9402032293060224]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.1263497464931148], {
             RGBColor[
             0.30674268007373295`, 0.4397363837396738, 0.9407799138938453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.1263497464931148], {
             RGBColor[
             0.23423879357827926`, 0.36353020202103736`, 0.9366509248178173]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.1263497464931148], {
             RGBColor[
             0.4038820814050813, 0.5242440920345965, 0.9469559869815982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.1263497464931148], {
             RGBColor[
             0.8799712561457314, 0.9071292097399156, 0.9884136380424356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.1263497464931148], {
             RGBColor[
             0.8843839202879132, 0.5678962094964264, 0.22523944788984251`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.1263497464931148], {
             RGBColor[
             0.5597245266210166, 0.6534486118703385, 0.9584827115555565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.1263497464931148], {
             RGBColor[
             0.8845340276069948, 0.5685778117739207, 0.22536470111635126`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.1263497464931148], {
             RGBColor[
             0.9808877657874093, 0.9471920876142448, 0.3802530084370154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.1263497464931148], {
             RGBColor[
             0.4514165271362265, 0.5654160397762044, 0.9499848398305268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.1263497464931148], {
             RGBColor[
             0.2225015077722568, 0.35119357045200544`, 0.9359825037549226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.1263497464931148], {
             RGBColor[
             0.8369720141620951, 0.8728427813654944, 0.9843123319561599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.1263497464931148], {
             RGBColor[
             0.3133752819583538, 0.4458516513578495, 0.941188973752873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.1263497464931148], {
             RGBColor[
             0.3866295369467384, 0.5093008051628776, 0.9458566701045386]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.1263497464931148], {
             RGBColor[
             0.5121189165844965, 0.6148002330343991, 0.9547350235483862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.1263497464931148], {
             RGBColor[
             0.9648560740830788, 0.9733102981108331, 0.9443736789601879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.1263497464931148], {
             RGBColor[
             0.40962031041891445`, 0.5292142575946026, 0.9473216218602429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.1263497464931148], {
             RGBColor[
             0.2679312243382506, 0.39894308297325987`, 0.938569658906113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.1263497464931148], {
             RGBColor[
             0.4530382628066378, 0.5668207057031098, 0.9500881753934008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.1263497464931148], {
             RGBColor[
             0.5357107322431658, 0.6339531317852908, 0.9565922576967049]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.1263497464931148], {
             RGBColor[
             0.8784142522519405, 0.5407893411964669, 0.22025821055067316`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.1263497464931148], {
             RGBColor[
             0.5437530683305409, 0.6404822625241338, 0.9572253798535508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.1263497464931148], {
             RGBColor[
             0.23837242809378653`, 0.36787491398440125`, 0.9368863291883112]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.1263497464931148], {
             RGBColor[
             0.254389289460926, 0.3847096508089296, 0.9377984657483468]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.1263497464931148], {
             RGBColor[
             0.305640198745031, 0.4385776059618545, 0.9407171292131508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.1263497464931148], {
             RGBColor[
             0.25996867538836677`, 0.3905739391721695, 0.9381162035229527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.1263497464931148], {
             RGBColor[
             0.6236615875481659, 0.7053555982627691, 0.963516071200913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.1263497464931148], {
             RGBColor[
             0.3862001571816754, 0.5089288979916344, 0.9458293104055944]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.1263497464931148], {
             RGBColor[
             0.23252667542550592`, 0.36173065728791187`, 0.9365534222218687]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.1263497464931148], {
             RGBColor[
             0.23247426890382172`, 0.3616755747108564, 0.9365504377479873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.1263497464931148], {
             RGBColor[
             0.2931478124699098, 0.42544731592366486`, 0.940005706295612]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.1263497464931148], {
             RGBColor[
             0.49667724948997916`, 0.6022639920478948, 0.9535193989500155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.1263497464931148], {
             RGBColor[
             0.28278247170568477`, 0.41455268557990177`, 0.9394154154732368]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.1263497464931148], {
             RGBColor[
             0.9176548470302313, 0.7112359389100995, 0.2526013609126037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.1263497464931148], {
             RGBColor[
             0.23193365260590854`, 0.36110735270469657`, 0.9365196504495912]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.1263497464931148], {
             RGBColor[
             0.20751087662989864`, 0.3354374666604766, 0.9351288094880167]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.1263497464931148], {
             RGBColor[
             0.49021471545548245`, 0.5970174157848499, 0.9530106445977776]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.1263497464931148], {
             RGBColor[
             0.44093802683048844`, 0.5563400894761129, 0.9493171590568191]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.1263497464931148], {
             RGBColor[
             0.17892700081062782`, 0.30539400085202123`, 0.9335010000461641]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.1263497464931148], {
             RGBColor[
             0.8357950446989824, 0.2761419758107905, 0.18191068126945342`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.1263497464931148], {
             RGBColor[
             0.9765123065091236, 0.9324326360618924, 0.36325517537702773`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.1263497464931148], {
             RGBColor[
             0.22872079714307936`, 0.35773043790646125`, 0.9363366830839769]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.1263497464931148], {
             RGBColor[
             0.21147766438726034`, 0.339606812102334, 0.9353547121824619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.1263497464931148], {
             RGBColor[
             0.8366736085240676, 0.28289500235951803`, 0.1827519949805509]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.1263497464931148], {
             RGBColor[
             0.6012429877716181, 0.6871551690177569, 0.9617511969044663]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.1263497464931148], {
             RGBColor[
             0.31511174381280593`, 0.44735568733906544`, 0.9412996195667458]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.1263497464931148], {
             RGBColor[
             0.2421911048281961, 0.37188858535035474`, 0.9371037971791099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.1263497464931148], {
             RGBColor[
             0.29270959820985176`, 0.42498672495195505`, 0.9399807506417815]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.1263497464931148], {
             RGBColor[
             0.3238266917401457, 0.45490413720770817`, 0.94185492834235]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.1263497464931148], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.1263497464931148], {
             RGBColor[
             0.41933559472005666`, 0.5376291485518648, 0.9479406711850231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.1263497464931148], {
             RGBColor[
             0.2878344487965492, 0.41986263381624833`, 0.9397031180948312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.1263497464931148], {
             RGBColor[
             0.9854648277298144, 0.9626315922912277, 0.39803402977763763`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.1263497464931148], {
             RGBColor[
             0.2632810725593861, 0.3940554786170215, 0.9383048396415897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.1263497464931148], {
             RGBColor[
             0.25662307112871396`, 0.38705749697171266`, 0.9379256763097434]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.1263497464931148], {
             RGBColor[
             0.8199864588949732, 0.15463025795470559`, 0.16677236165029033`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.1263497464931148], {
             RGBColor[
             0.9094625081980608, 0.9306447336077317, 0.9912265399903383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.1263497464931148], {
             RGBColor[
             0.2582501634540876, 0.38876767416929214`, 0.9380183368106061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.1263497464931148], {
             RGBColor[
             0.755781538403036, 0.8091415490436711, 0.97629289863413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.1263497464931148], {
             RGBColor[
             0.2539844574642687, 0.3842841467126117, 0.9377754111650324]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.1263497464931148], {
             RGBColor[
             0.24791046842011605`, 0.37789999911405875`, 0.9374295064746294]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.1263497464931148], {
             RGBColor[
             0.2817340129849886, 0.4134506889883278, 0.9393557073001488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.1263497464931148], {
             RGBColor[
             0.3449485107481652, 0.47319879521896346`, 0.9432007919722498]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.1263497464931148], {
             RGBColor[
             0.4113253016274047, 0.530691035284047, 0.9474302623923834]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.1263497464931148], {
             RGBColor[
             0.606817875551374, 0.6916811140631951, 0.9621900724919755]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.1263497464931148], {
             RGBColor[
             0.21942909899518986`, 0.3479642740253404, 0.9358075346202901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.1263497464931148], {
             RGBColor[
             0.9938287149952354, 0.9892085703244617, 0.5696718958667929]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.1263497464931148], {
             RGBColor[
             0.7895429134572223, 0.8355161918319554, 0.9796579169815435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.1263497464931148], {
             RGBColor[
             0.8236181467643259, 0.8621947699835874, 0.9830386281626226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.1263497464931148], {
             RGBColor[
             0.25827862318556116`, 0.3887975871515221, 0.9380199575502111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.1263497464931148], {
             RGBColor[
             0.9207457022290968, 0.9396416462539369, 0.9923027411096448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.1263497464931148], {
             RGBColor[
             0.2333142933423989, 0.36255849365642656`, 0.9365982758970595]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.1263497464931148], {
             RGBColor[
             0.21421555473578224`, 0.34248450845090483`, 0.9355106309874645]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.1263497464931148], {
             RGBColor[
             0.9151930916309041, 0.7014758990831244, 0.2506205747334791]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.1263497464931148], {
             RGBColor[
             0.1792532619022457, 0.3057369219454596, 0.9335195801326717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.1263497464931148], {
             RGBColor[
             0.8666101266120032, 0.4871895635890985, 0.21040855877111306`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.1263497464931148], {
             RGBColor[
             0.28550171685781406`, 0.4174107846448903, 0.9395702724618878]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.1263497464931148], {
             RGBColor[
             0.8647697772859632, 0.4788329671240561, 0.2088729261823753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.1263497464931148], {
             RGBColor[
             0.3276288460270304, 0.4581973721491767, 0.9420971982513973]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.1263497464931148], {
             RGBColor[
             0.6091375885965603, 0.6935643616151592, 0.9623726888002815]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.1263497464931148], {
             RGBColor[
             0.26928527939714464`, 0.4003662806922068, 0.9386467703385721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.1263497464931148], {
             RGBColor[
             0.9554190789968999, 0.9662722026272221, 0.9603480500785777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.1263497464931148], {
             RGBColor[
             0.22708291988077767`, 0.3560089250563658, 0.936243408396911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.1263497464931148], {
             RGBColor[
             0.2961617343973124, 0.4286151389630523, 0.9401773446906796]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.1263497464931148], {
             RGBColor[
             0.2317345075524728, 0.36089803862701, 0.9365083094334068]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.1263497464931148], {
             RGBColor[
             0.9952347378240085, 0.9922159109844932, 0.7227088038116687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.1263497464931148], {
             RGBColor[
             0.9936215336094609, 0.9887654302895413, 0.5471214806005384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.1263497464931148], {
             RGBColor[
             0.9312148525901699, 0.7649968423512695, 0.2635120596803694]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.1263497464931148], {
             RGBColor[
             0.5208327276256995, 0.6218744973903617, 0.9554210066732913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.1263497464931148], {
             RGBColor[
             0.2765375568294345, 0.40798888409449063`, 0.939059776809558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.1263497464931148], {
             RGBColor[
             0.4803557055985901, 0.589013427439692, 0.9522345072271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.1263497464931148], {
             RGBColor[
             0.24657366739272524`, 0.3764949364761905, 0.9373533776337394]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.1263497464931148], {
             RGBColor[
             0.2459052705491277, 0.3757924090147619, 0.9373153134223011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.1263497464931148], {
             RGBColor[
             0.5178553382148801, 0.619457318536794, 0.9551866156723348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.1263497464931148], {
             RGBColor[
             0.18467169248908813`, 0.3114320360405726, 0.9338281517387427]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.1263497464931148], {
             RGBColor[
             0.28511069510105125`, 0.41699979598632125`, 0.939548004351305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.1263497464931148], {
             RGBColor[
             0.25396000439311356`, 0.38425844498441336`, 0.9377740185988052]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.1263497464931148], {
             RGBColor[
             0.27171530098953856`, 0.4029203874580805, 0.9387851564733641]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.1263497464931148], {
             RGBColor[
             0.27309124258507717`, 0.4043665893147275, 0.9388635143117069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.1263497464931148], {
             RGBColor[
             0.24826352560257345`, 0.3782710845979398, 0.937449612558869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.1263497464931148], {
             RGBColor[
             0.17919226069553715`, 0.305672805809509, 0.9335161062041928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.1263497464931148], {
             RGBColor[
             0.5006784839436625, 0.605512374430953, 0.9538343907832142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.1263497464931148], {
             RGBColor[
             0.9211683800910966, 0.9399786781078106, 0.9923430565014513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.1263497464931148], {
             RGBColor[
             0.24872594858728536`, 0.3787571204741826, 0.9374759468637549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.1263497464931148], {
             RGBColor[
             0.38107527345035186`, 0.504489981287708, 0.9455027573459912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.1263497464931148], {
             RGBColor[
             0.32510810483221725`, 0.45601403282236586`, 0.9419365788514676]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.1263497464931148], {
             RGBColor[
             0.9906473743776302, 0.9904004632007044, 0.8046607405893015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.1263497464931148], {
             RGBColor[
             0.20742150462258202`, 0.3353435310142743, 0.9351237198844141]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.1263497464931148], {
             RGBColor[
             0.8274659414661699, 0.21212083852708477`, 0.1739347226073356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.1263497464931148], {
             RGBColor[
             0.867504304657107, 0.49124981725132677`, 0.21115468285025726`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.1263497464931148], {
             RGBColor[
             0.2069635167020156, 0.33486215667164765`, 0.9350976381498702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.1263497464931148], {
             RGBColor[
             0.9626525497894284, 0.8856804222207267, 0.30941263771645156`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.1263497464931148], {
             RGBColor[
             0.20867358600249122`, 0.3366595479311035, 0.9351950240667115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.1263497464931148], {
             RGBColor[
             0.2511378152607278, 0.38129214526915, 0.9376132991027705]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.1263497464931148], {
             RGBColor[
             0.22597981130456574`, 0.35484948800164373`, 0.9361805879953986]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.1263497464931148], {
             RGBColor[
             0.49474321248409076`, 0.6006938536791404, 0.9533671444723009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.1263497464931148], {
             RGBColor[
             0.35559977387920144`, 0.4824243839950162, 0.9438794810404173]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.1263497464931148], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.1263497464931148], {
             RGBColor[
             0.263609049878749, 0.394400203574635, 0.9383235174647285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.1263497464931148], {
             RGBColor[
             0.9901329118562932, 0.9901877197270478, 0.8131867159541827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.1263497464931148], {
             RGBColor[
             0.3451736656290086, 0.4733938130601367, 0.9432151386421606]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.1263497464931148], {
             RGBColor[
             0.2332063867745317, 0.36244507701192663`, 0.9365921307776528]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.1263497464931148], {
             RGBColor[
             0.25062676841059334`, 0.3807550026274169, 0.9375841957406814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.1263497464931148], {
             RGBColor[
             0.968960662006962, 0.9763714930638193, 0.9374256822530368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.1263497464931148], {
             RGBColor[
             0.22008054170119, 0.3486489816131997, 0.9358446333186737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.1263497464931148], {
             RGBColor[
             0.2199663924455993, 0.34852900350809307`, 0.9358381326874365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.1263497464931148], {
             RGBColor[
             0.5640351798749514, 0.6569481943745988, 0.9588220619701494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.1263497464931148], {
             RGBColor[
             0.4996340643500339, 0.6046644675542787, 0.9537521702469687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.1263497464931148], {
             RGBColor[
             0.30958288032569087`, 0.4425668636752852, 0.9409473252743288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.1263497464931148], {
             RGBColor[
             0.6995243049605603, 0.765192970707599, 0.9706857033583209]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.1263497464931148], {
             RGBColor[
             0.17892700134778292`, 0.3053940014166053, 0.9335010000767543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.1263497464931148], {
             RGBColor[
             0.24622776306205768`, 0.3761313690930576, 0.9373336788938276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.1263497464931148], {
             RGBColor[
             0.2206581667895666, 0.3492561022046294, 0.935877528212937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.1263497464931148], {
             RGBColor[
             0.257933230334439, 0.3884345573658211, 0.9380002879383026]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.1263497464931148], {
             RGBColor[
             0.25149316947897704`, 0.3816656450832887, 0.9376335359998004]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.1263497464931148], {
             RGBColor[
             0.23965584235908116`, 0.3692238637503902, 0.9369594177320785]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.1263497464931148], {
             RGBColor[
             0.353874772698637, 0.4809302746734916, 0.9437695654905504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.1263497464931148], {
             RGBColor[
             0.8214446559981496, 0.16583859987576455`, 0.16816873284309014`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.1263497464931148], {
             RGBColor[
             0.30679432383558886`, 0.439790664607788, 0.9407828549296829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.1263497464931148], {
             RGBColor[
             0.20400293554931437`, 0.33175039816847185`, 0.9349290374330113]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.1263497464931148], {
             RGBColor[
             0.24493296406314102`, 0.3747704532501981, 0.9372599420063227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.1263497464931148], {
             RGBColor[
             0.30954120355039927`, 0.44253076534726327`, 0.9409446696670606]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.1263497464931148], {
             RGBColor[
             0.5658891207695752, 0.6584533071119401, 0.9589680109885835]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.1263497464931148], {
             RGBColor[
             0.46730916543215706`, 0.578421658392645, 0.9512074357941471]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.1263497464931148], {
             RGBColor[
             0.3025436094347634, 0.43532289426166115`, 0.9405407830329243]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.1263497464931148], {
             RGBColor[
             0.3575213303529286, 0.48408873963232213`, 0.9440019209197574]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.1263497464931148], {
             RGBColor[
             0.8207501650068003, 0.16050043778835987`, 0.16750368748545852`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.1263497464931148], {
             RGBColor[
             0.42248174875901884`, 0.5403541890501141, 0.948141141338351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.1263497464931148], {
             RGBColor[
             0.9903319581123935, 0.9790495659282263, 0.41694191223350735`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.1263497464931148], {
             RGBColor[
             0.46203141681910903`, 0.5741369443087071, 0.9507919520902978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.1263497464931148], {
             RGBColor[
             0.26699231078344465`, 0.3979562252966011, 0.9385161891681649]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.1263497464931148], {
             RGBColor[
             0.8175247092939038, 0.13570817177533162`, 0.16441498745215766`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.1263497464931148], {
             RGBColor[
             0.4240332554553848, 0.5416980261695123, 0.9482400019731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.1263497464931148], {
             RGBColor[
             0.8381204118994321, 0.2940157670958513, 0.18413745552673064`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.1263497464931148], {
             RGBColor[
             0.9866702547547157, 0.9887558220293171, 0.870571905196646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.1263497464931148], {
             RGBColor[
             0.9107922199972238, 0.6840279095591187, 0.24707953011528597`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.1263497464931148], {
             RGBColor[
             0.4927421843014464, 0.5990693288551774, 0.9532096162037554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.1263497464931148], {
             RGBColor[
             0.29668056881803306`, 0.42916046683523196`, 0.9402068915433929]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.1263497464931148], {
             RGBColor[
             0.26174222518751433`, 0.39243805246062563`, 0.9382172045602823]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.1263497464931148], {
             RGBColor[
             0.3516524550010693, 0.4790054147807936, 0.9436279613719797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.1263497464931148], {
             RGBColor[
             0.984562956112485, 0.9878843998856498, 0.9054952972124768]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.1263497464931148], {
             RGBColor[
             0.2666571079259713, 0.3976039058403079, 0.93849709986132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.1263497464931148], {
             RGBColor[
             0.9557302644442173, 0.966504284224312, 0.9598212942864327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.1263497464931148], {
             RGBColor[
             0.6069446059586334, 0.6917839995169481, 0.9622000491738637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.1263497464931148], {
             RGBColor[
             0.20869655844004803`, 0.3366836934195124, 0.9351963323130457]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.1263497464931148], {
             RGBColor[
             0.9916846362160958, 0.9908293976273234, 0.7874706275783359]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.1263497464931148], {
             RGBColor[
             0.178929137062006, 0.30539624618766587`, 0.9335011217025198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.1263497464931148], {
             RGBColor[
             0.27013094278236094`, 0.4012551265282246, 0.9386949296173133]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.1263497464931148], {
             RGBColor[
             0.4206971967779904, 0.5388084998183378, 0.9480274312641372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.1263497464931148], {
             RGBColor[
             0.3785866605047563, 0.5023344698355566, 0.9453441851296919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.1263497464931148], {
             RGBColor[
             0.2049673414252272, 0.33276404989092045`, 0.9349839589209338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.1263497464931148], {
             RGBColor[
             0.2570318728012019, 0.3874871734490205, 0.9379489569602237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.1263497464931148], {
             RGBColor[
             0.2839447494602888, 0.41577431319265656`, 0.9394816054719256]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.1263497464931148], {
             RGBColor[
             0.23571041014604155`, 0.365076964339635, 0.9367347312042897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.1263497464931148], {
             RGBColor[
             0.26462809617956273`, 0.3954712858480575, 0.938381550644016]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.1263497464931148], {
             RGBColor[
             0.33727714516499796`, 0.4665542439248693, 0.9427119793408126]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.1263497464931148], {
             RGBColor[
             0.2597753641562747, 0.39037075681060074`, 0.9381051947342635]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.1263497464931148], {
             RGBColor[
             0.24810961844878143`, 0.3781093184210272, 0.9374408477741458]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.1263497464931148], {
             RGBColor[
             0.21840138119578575`, 0.34688407745709465`, 0.9357490076119863]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.1263497464931148], {
             RGBColor[
             0.2546146394674752, 0.38494650795382845`, 0.9378112990978443]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.1263497464931148], {
             RGBColor[
             0.2878117179623051, 0.41983874226823964`, 0.9397018236074483]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.1263497464931148], {
             RGBColor[
             0.9865160895376739, 0.9886920707502049, 0.8731268218098209]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.1263497464931148], {
             RGBColor[
             0.2701519252165497, 0.40127718039692006`, 0.9386961245358997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.1263497464931148], {
             RGBColor[
             0.29569933477919436`, 0.42812912764658106`, 0.9401510117164867]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.1263497464931148], {
             RGBColor[
             0.6976256228082208, 0.7637097057796726, 0.9704964604655693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.1263497464931148], {
             RGBColor[
             0.2818794421164257, 0.41360354422620765`, 0.9393639892740411]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.1263497464931148], {
             RGBColor[
             0.3428438781472085, 0.4713758682419251, 0.9430666866439704]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.1263497464931148], {
             RGBColor[
             0.9008280073528754, 0.6425649682443086, 0.23896079721830538`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.1263497464931148], {
             RGBColor[
             0.3044587746178886, 0.4373358542976118, 0.9406498488568703]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.1263497464931148], {
             RGBColor[
             0.23905706042934927`, 0.3685945059772749, 0.9369253179869986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.1263497464931148], {
             RGBColor[
             0.5345666356633387, 0.6330243026408235, 0.956502190222977]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.1263497464931148], {
             RGBColor[
             0.5018930513522051, 0.606498414968846, 0.9539300059787216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.1263497464931148], {
             RGBColor[
             0.9938265629209484, 0.98920396725517, 0.5694376558617151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.1263497464931148], {
             RGBColor[
             0.3427341577200499, 0.4712808339226293, 0.9430596953553738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.1263497464931148], {
             RGBColor[
             0.217062994597398, 0.3454773482835776, 0.9356727884751737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.1263497464931148], {
             RGBColor[
             0.32211852500862637`, 0.45342460903982235`, 0.9417460854686901]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.1263497464931148], {
             RGBColor[
             0.5659235722129052, 0.6584812763456551, 0.9589707231324023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.1263497464931148], {
             RGBColor[
             0.8360637140310553, 0.2782070860287545, 0.182167959325265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.1263497464931148], {
             RGBColor[
             0.2310404057237692, 0.3601684935964447, 0.9364687813610937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.1263497464931148], {
             RGBColor[
             0.21851625165510197`, 0.3470048135930438, 0.9357555493147087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.1263497464931148], {
             RGBColor[
             0.90420589766789, 0.657903179238463, 0.24177939169682186`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.1263497464931148], {
             RGBColor[
             0.19980711485308938`, 0.32734032458634205`, 0.9346900916515217]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.1263497464931148], {
             RGBColor[
             0.28412310253725925`, 0.4159617735847908, 0.9394917624158093]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.1263497464931148], {
             RGBColor[
             0.26588598144981995`, 0.39679340302163035`, 0.9384531853492826]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.1263497464931148], {
             RGBColor[
             0.31971976000988434`, 0.4513469193633465, 0.9415932382841149]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.1263497464931148], {
             RGBColor[
             0.23197293745711564`, 0.3611486435741187, 0.9365218876637508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.1263497464931148], {
             RGBColor[
             0.5262688994117111, 0.6262878265429939, 0.9558489620296395]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.1263497464931148], {
             RGBColor[
             0.3389132056188999, 0.46797131725924984`, 0.9428162276662237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.1263497464931148], {
             RGBColor[
             0.5366100807415061, 0.6346832634114314, 0.9566630577049163]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.1263497464931148], {
             RGBColor[
             0.4427137030371586, 0.5578780909582495, 0.9494303035745394]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.1263497464931148], {
             RGBColor[
             0.38986378476733635`, 0.5121021480670574, 0.9460627535157341]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.1263497464931148], {
             RGBColor[
             0.29896629209325354`, 0.43156290692071464`, 0.9403370601024921]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.1263497464931148], {
             RGBColor[
             0.27424929290791517`, 0.4055837736286615, 0.9389294635644105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.1263497464931148], {
             RGBColor[
             0.1794249922972142, 0.30591742147890744`, 0.9335293599246128]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.1263497464931148], {
             RGBColor[
             0.8456311671254343, 0.35174672299683013`, 0.19132976321333509`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.1263497464931148], {
             RGBColor[
             0.9930813033990235, 0.9876099324950685, 0.48832075610881853`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.1263497464931148], {
             RGBColor[
             0.2909757990296596, 0.42316439208435586`, 0.9398820133433956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.1263497464931148], {
             RGBColor[
             0.2238780227461086, 0.35264037496561385`, 0.936060894246312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.1263497464931148], {
             RGBColor[
             0.2584463601503126, 0.3889738893366137, 0.9380295099222091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.1263497464931148], {
             RGBColor[
             0.3561976264336458, 0.4829422138287328, 0.9439175756765262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.1263497464931148], {
             RGBColor[
             0.8431597968980244, 0.3327506884676198, 0.18896317629255405`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.1263497464931148], {
             RGBColor[
             0.38857864336543946`, 0.5109890231778194, 0.9459808654420111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.1263497464931148], {
             RGBColor[
             0.3570417238501652, 0.48367332858535217`, 0.9439713608175008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.1263497464931148], {
             RGBColor[
             0.28732315690654525`, 0.419325233622076, 0.939674000778084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.1263497464931148], {
             RGBColor[
             0.906092392768253, 0.9279574950433493, 0.9909050953721057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.1263497464931148], {
             RGBColor[
             0.32015392046586916`, 0.45172296732878153`, 0.9416209026044572]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.1263497464931148], {
             RGBColor[
             0.3509305166159243, 0.47838010803725933`, 0.9435819600964633]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.1263497464931148], {
             RGBColor[
             0.2566255537350775, 0.38706010634840704`, 0.9379258176905032]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.1263497464931148], {
             RGBColor[
             0.7054821402904016, 0.7698472769484965, 0.9712795247048629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.1263497464931148], {
             RGBColor[
             0.22500762673968802`, 0.3538276603838957, 0.936125223522647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.1263497464931148], {
             RGBColor[
             0.8393061093521738, 0.30312955729356095`, 0.18527288074652987`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.1263497464931148], {
             RGBColor[
             0.3424410288691568, 0.4710269404450701, 0.9430410174441985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.1263497464931148], {
             RGBColor[
             0.22156287013367681`, 0.3502070027807943, 0.9359290497299955]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.1263497464931148], {
             RGBColor[
             0.29422140859812795`, 0.42657573352434824`, 0.9400668460068708]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.1263497464931148], {
             RGBColor[
             0.4950113815248125, 0.6009115653872759, 0.9533882557215221]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.1263497464931148], {
             RGBColor[
             0.24253965650195108`, 0.3722549352589237, 0.9371236466812941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.1263497464931148], {
             RGBColor[
             0.2895478687563091, 0.421663546831056, 0.9398006948267619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.1263497464931148], {
             RGBColor[
             0.20444533477183996`, 0.332215387801077, 0.934954231414263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.1263497464931148], {
             RGBColor[
             0.25854520282865096`, 0.38907777925853504`, 0.9380351388665158]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.1263497464931148], {
             RGBColor[
             0.7357960105795031, 0.7935287028122899, 0.9743009279960564]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.1263497464931148], {
             RGBColor[
             0.9850318468002165, 0.9880782982349678, 0.8977245650665646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.1263497464931148], {
             RGBColor[
             0.23649824945009773`, 0.365905033400095, 0.9367795974871519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.1263497464931148], {
             RGBColor[
             0.3975855258515599, 0.5187903320882202, 0.9465547760295533]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.1263497464931148], {
             RGBColor[
             0.2893861381019995, 0.4214935576590608, 0.939791484505258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.1263497464931148], {
             RGBColor[
             0.8588534332133313, 0.4519682304874997, 0.20393618366530758`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.1263497464931148], {
             RGBColor[
             0.3734224424883788, 0.497861483750915, 0.945015125724227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.1263497464931148], {
             RGBColor[
             0.8618406991999262, 0.46553270763892984`, 0.20642883162911219`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.1263497464931148], {
             RGBColor[
             0.28557642935408295`, 0.4174893122155148, 0.9395745272280231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.1263497464931148], {
             RGBColor[
             0.8799868165294279, 0.5479299882988189, 0.2215703967308864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.1263497464931148], {
             RGBColor[
             0.47608581392629684`, 0.5855469370236965, 0.9518983657135286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.1263497464931148], {
             RGBColor[
             0.2734006518561467, 0.40469179807630246`, 0.9388811347119643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.1263497464931148], {
             RGBColor[
             0.23478619087952063`, 0.36410555129163547`, 0.9366820982843213]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.1263497464931148], {
             RGBColor[
             0.32101450543653715`, 0.45246836277611585`, 0.9416757383178027]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.1263497464931148], {
             RGBColor[
             0.28952074326414307`, 0.421635036218934, 0.9397991500701115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.1263497464931148], {
             RGBColor[
             0.9890626064851881, 0.9747677448317271, 0.41201072085875556`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.1263497464931148], {
             RGBColor[
             0.40965477924277666`, 0.5292441127573786, 0.9473238181832199]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.1263497464931148], {
             RGBColor[
             0.44893934079834463`, 0.5632704254773366, 0.9498269957075668]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.1263497464931148], {
             RGBColor[
             0.9900230881246451, 0.9901423047916702, 0.8150067794022959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.1263497464931148], {
             RGBColor[
             0.2558053195227897, 0.38619798818543977`, 0.9378791065655412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.1263497464931148], {
             RGBColor[
             0.8205829319400263, 0.15921501115513814`, 0.16734354491185305`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.1263497464931148], {
             RGBColor[
             0.2935414156904733, 0.42586101786436276`, 0.9400281214167392]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.1263497464931148], {
             RGBColor[
             0.4627342609626232, 0.5747075448471798, 0.9508472825558781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.1263497464931148], {
             RGBColor[
             0.4137039619056965, 0.5327513112621616, 0.9475818285219495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.1263497464931148], {
             RGBColor[
             0.6195401563438858, 0.7020096347427746, 0.9631916170392121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.1263497464931148], {
             RGBColor[
             0.7713015318020453, 0.8212658858432957, 0.977839786533559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.1263497464931148], {
             RGBColor[
             0.9483637407407871, 0.9610103429078694, 0.9722908974192511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.1263497464931148], {
             RGBColor[
             0.2785602236563872, 0.4101148351741018, 0.9391749646930856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.1263497464931148], {
             RGBColor[
             0.25689237745970156`, 0.38734055500058817`, 0.9379410129068901]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.1263497464931148], {
             RGBColor[
             0.24490866169442368`, 0.374744909919817, 0.9372585580223763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.1263497464931148], {
             RGBColor[
             0.6076583896248129, 0.6923634812527404, 0.9622562408387412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.1263497464931148], {
             RGBColor[
             0.18121415923057888`, 0.3077979493656092, 0.9336312503346327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.1263497464931148], {
             RGBColor[
             0.24509263407936946`, 0.37493827656091794`, 0.9372690349775362]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.1263497464931148], {
             RGBColor[
             0.3144183414809424, 0.4467550970906198, 0.941255436583311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.1263497464931148], {
             RGBColor[
             0.22310026486080187`, 0.3518229021154584, 0.9360166020853335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.1263497464931148], {
             RGBColor[
             0.20981171601903448`, 0.33785579474010136`, 0.9352598388874411]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.1263497464931148], {
             RGBColor[
             0.2560659100008252, 0.3864718853002457, 0.9378939468077562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.1263497464931148], {
             RGBColor[
             0.439371052281192, 0.5549828548799431, 0.9492173128241592]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.1263497464931148], {
             RGBColor[
             0.2864852402250885, 0.41844453006287885`, 0.9396262826626617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.1263497464931148], {
             RGBColor[
             0.6549271406176395, 0.7303533269719065, 0.9662406748008145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.1263497464931148], {
             RGBColor[
             0.1789706321783367, 0.30543986018587177`, 0.9335034847880083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.1263497464931148], {
             RGBColor[
             0.9542723127115095, 0.9654169462092355, 0.962289226275195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.1263497464931148], {
             RGBColor[
             0.23831274258564697`, 0.36781218073106675`, 0.9368829301869194]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.1263497464931148], {
             RGBColor[
             0.22958788287780074`, 0.3586417999900643, 0.9363860623338308]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.1263497464931148], {
             RGBColor[
             0.3134198204339392, 0.44589022834683273`, 0.9411918117051534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.1263497464931148], {
             RGBColor[
             0.5193642093092683, 0.6206822880650865, 0.955305399532062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.1263497464931148], {
             RGBColor[
             0.9016398137954514, 0.9244071294324739, 0.9904804044148157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.1263497464931148], {
             RGBColor[
             0.2091663766185125, 0.3371775021132715, 0.9352230877632756]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.1263497464931148], {
             RGBColor[
             0.22595764709528393`, 0.3548261920123965, 0.936179325776469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.1263497464931148], {
             RGBColor[
             0.20875268020104726`, 0.3367426809486477, 0.9351995283643099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.1263497464931148], {
             RGBColor[
             0.19014935834156865`, 0.31718941015560403`, 0.934140096705561]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.1263497464931148], {
             RGBColor[
             0.3052585207535403, 0.43817643819301544`, 0.9406953932161773]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.1263497464931148], {
             RGBColor[
             0.3385640468354945, 0.4676688934702948, 0.9427939795772942]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.1263497464931148], {
             RGBColor[
             0.2511118726659751, 0.3812648779572094, 0.9376118217103779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.1263497464931148], {
             RGBColor[
             0.8575795140998795, 0.443586953641446, 0.20277151376979163`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.1263497464931148], {
             RGBColor[
             0.46980956787155936`, 0.580451597734798, 0.9514042766334527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.1263497464931148], {
             RGBColor[
             0.17894628476761076`, 0.30541426951348377`, 0.9335020982389862]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.1263497464931148], {
             RGBColor[
             0.9930307649637, 0.9875018358921313, 0.48281995931092997`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.1263497464931148], {
             RGBColor[
             0.29675707084929953`, 0.4292408753206019, 0.9402112482208989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.1263497464931148], {
             RGBColor[
             0.746856868272219, 0.8021695289074716, 0.9754033709212744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.1263497464931148], {
             RGBColor[
             0.3044115375980597, 0.43728620519477157`, 0.940647158778472]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.1263497464931148], {
             RGBColor[
             0.266957894870447, 0.3979200519899457, 0.9385142292328336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.1263497464931148], {
             RGBColor[
             0.33007547283951477`, 0.4603165173231115, 0.9422530951484216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.1263497464931148], {
             RGBColor[
             0.1854996162687526, 0.3123022364263995, 0.933875300773191]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.1263497464931148], {
             RGBColor[
             0.2504950392509415, 0.38061654692851177`, 0.937576693959915]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.1263497464931148], {
             RGBColor[
             0.8834003236622562, 0.5634299269441462, 0.22441871075523476`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.1263497464931148], {
             RGBColor[
             0.341942322952124, 0.4705949864454246, 0.9430092403441536]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.1263497464931148], {
             RGBColor[
             0.7148896845747944, 0.7771965220434489, 0.9722171808006315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.1263497464931148], {
             RGBColor[
             0.9886024976405045, 0.9895548541189678, 0.8385496400948322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.1263497464931148], {
             RGBColor[
             0.3331754530775283, 0.46300156439574175`, 0.942450623147983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.1263497464931148], {
             RGBColor[
             0.25921854913182885`, 0.38978550891579644`, 0.9380734849423552]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.1263497464931148], {
             RGBColor[
             0.23934466612723454`, 0.36889679780100676`, 0.9369416967060188]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.1263497464931148], {
             RGBColor[
             0.369677449943029, 0.49461775943693126`, 0.9447764981108042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.1263497464931148], {
             RGBColor[
             0.1790169203691504, 0.30548851200925775`, 0.9335061208319979]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.1263497464931148], {
             RGBColor[
             0.8751755113140446, 0.526082975024646, 0.21755572572328788`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.1263497464931148], {
             RGBColor[
             0.2570691600545971, 0.38752636471648727`, 0.9379510804141431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.1263497464931148], {
             RGBColor[
             0.3853130055350487, 0.5081604918248647, 0.9457727818871488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.1263497464931148], {
             RGBColor[
             0.8825578842047201, 0.909191716742005, 0.9886603529358121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.1263497464931148], {
             RGBColor[
             0.3064495532407965, 0.43942828885294294`, 0.9407632207543519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.1263497464931148], {
             RGBColor[
             0.8366916950922476, 0.8726192625482565, 0.984285594873034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.1263497464931148], {
             RGBColor[
             0.40219205331719154`, 0.5227802746481479, 0.946848299886271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.1263497464931148], {
             RGBColor[
             0.3786491349611119, 0.5023885820695944, 0.9453481659468069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.1263497464931148], {
             RGBColor[
             0.4028040785660817, 0.5233103801574531, 0.9468872975939376]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.1263497464931148], {
             RGBColor[
             0.2767721721232211, 0.4082354796437291, 0.9390731378034569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.1263497464931148], {
             RGBColor[
             0.22223854670063217`, 0.35091718169303304`, 0.9359675285109096]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.1263497464931148], {
             RGBColor[
             0.860210700141258, 0.8913726787679522, 0.9865288585702724]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.1263497464931148], {
             RGBColor[
             0.32010532781399464`, 0.4516808788160655, 0.9416178063236486]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.1263497464931148], {
             RGBColor[
             0.21169068579341777`, 0.33983071110654267`, 0.9353668434364056]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.1263497464931148], {
             RGBColor[
             0.3374345618861965, 0.46669059037677707`, 0.9427220097950892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.1263497464931148], {
             RGBColor[
             0.9935733711383794, 0.9886624156338708, 0.5418792928476311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.1263497464931148], {
             RGBColor[
             0.25998714329821626`, 0.39059335011635443`, 0.9381172552430979]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.1263497464931148], {
             RGBColor[
             0.29288750827080284`, 0.425173719706164, 0.9399908823565584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.1263497464931148], {
             RGBColor[
             0.4637429804071734, 0.5755264687345587, 0.9509266926456142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.1263497464931148], {
             RGBColor[
             0.6597251945044771, 0.7341016031348642, 0.9667188999718916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.1263497464931148], {
             RGBColor[
             0.21788265672664042`, 0.34633886515099205`, 0.9357194670208525]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.1263497464931148], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.1263497464931148], {
             RGBColor[
             0.9599116097125079, 0.876434587737939, 0.29876460310071706`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.1263497464931148], {
             RGBColor[
             0.41360147005439724`, 0.5326625379719564, 0.9475752978318146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.1263497464931148], {
             RGBColor[
             0.3621699928109498, 0.4881151774048913, 0.9442981295809318]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.1263497464931148], {
             RGBColor[
             0.290045450304657, 0.422186536586862, 0.9398290313598343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.1263497464931148], {
             RGBColor[
             0.2278308941861094, 0.35679509347557953`, 0.9362860044270709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.1263497464931148], {
             RGBColor[
             0.6396625402707171, 0.7183458925176417, 0.9647757248126534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.1263497464931148], {
             RGBColor[
             0.3617638436367253, 0.48776339140382907`, 0.9442722501146938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.1263497464931148], {
             RGBColor[
             0.32870680276015046`, 0.45913104409172456`, 0.942165884701232]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.1263497464931148], {
             RGBColor[
             0.26933793088281155`, 0.4004216207419397, 0.9386497687627899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.1263497464931148], {
             RGBColor[
             0.9071422836282599, 0.6695571281253704, 0.2441427056377997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.1263497464931148], {
             RGBColor[
             0.22562621270692998`, 0.3544778334560826, 0.9361604510783655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.1263497464931148], {
             RGBColor[
             0.38545126270191343`, 0.5082802432337956, 0.9457815915115654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.1263497464931148], {
             RGBColor[
             0.5793663225363243, 0.6693947066472076, 0.9600289856802787]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.1263497464931148], {
             RGBColor[
             0.6442014475594858, 0.7219743340365904, 0.9651716379540781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.1263497464931148], {
             RGBColor[
             0.38846154058520777`, 0.5108875946353395, 0.9459734037564047]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.1263497464931148], {
             RGBColor[
             0.40481135748628755`, 0.5250489842693634, 0.9470151996317661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.1263497464931148], {
             RGBColor[
             0.2585666750316088, 0.38910034790526005`, 0.938036361676709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.1263497464931148], {
             RGBColor[
             0.2169746648251472, 0.34538450809251103`, 0.9356677582253161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.1263497464931148], {
             RGBColor[
             0.2650062967491503, 0.3958687986259951, 0.9384030886069564]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.1263497464931148], {
             RGBColor[
             0.2298450608433424, 0.3589121103378734, 0.9364007082385077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.1263497464931148], {
             RGBColor[
             0.4081016499818632, 0.5278988702541217, 0.9472248541600927]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.1263497464931148], {
             RGBColor[
             0.4199474238450335, 0.5381590841884939, 0.9479796563958474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.1263497464931148], {
             RGBColor[
             0.591443337591513, 0.6791993715323379, 0.960979732544987]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.1263497464931148], {
             RGBColor[
             0.36294391873403165`, 0.48878551314081686`, 0.9443474434563948]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.1263497464931148], {
             RGBColor[
             0.4704530721178047, 0.5809740234714359, 0.951454935644951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.1263497464931148], {
             RGBColor[
             0.293615491872952, 0.425938876628849, 0.9400323399457455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.1263497464931148], {
             RGBColor[
             0.2517303220687306, 0.38191490749146234`, 0.937647041488951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.1263497464931148], {
             RGBColor[
             0.9582014383733062, 0.9683472816944506, 0.9556382414098691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.1263497464931148], {
             RGBColor[
             0.2794551004482275, 0.4110554074207916, 0.9392259266025292]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.1263497464931148], {
             RGBColor[
             0.9811051107342013, 0.9854288030398846, 0.9168682983373343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.1263497464931148], {
             RGBColor[
             0.2830844261537786, 0.4148700588498662, 0.9394326113323542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.1263497464931148], {
             RGBColor[
             0.3092991992760449, 0.442321153408306, 0.9409292493686947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.1263497464931148], {
             RGBColor[
             0.27285106149406285`, 0.4041141437597107, 0.9388498363538897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.1263497464931148], {
             RGBColor[
             0.5693048020656428, 0.6612263110627765, 0.9592369059322629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.1263497464931148], {
             RGBColor[
             0.28222469603460637`, 0.4139664279845783, 0.9393836509739241]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.1263497464931148], {
             RGBColor[
             0.32894252042405586`, 0.45933521088468515`, 0.942180904422339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.1263497464931148], {
             RGBColor[
             0.28382079992875175`, 0.41564403437615693`, 0.9394745467294715]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.1263497464931148], {
             RGBColor[
             0.2334715870925415, 0.36272381936082626`, 0.9366072335434348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.1263497464931148], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.1263497464931148], {
             RGBColor[
             0.7751138064478154, 0.8242440637709316, 0.9782197584425172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.1263497464931148], {
             RGBColor[
             0.9461721011462925, 0.9593758216867757, 0.9760007715815773]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.1263497464931148], {
             RGBColor[
             0.2184997826909155, 0.34698750366749115`, 0.9357546114315619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.1263497464931148], {
             RGBColor[
             0.30075346730669683`, 0.43344134138349677`, 0.9404388370870089]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.1263497464931148], {
             RGBColor[
             0.2411272273904176, 0.370770382709524, 0.937043210932894]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.1263497464931148], {
             RGBColor[
             0.3060013924465708, 0.4389572434431762, 0.9407376986601153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.1263497464931148], {
             RGBColor[
             0.4612114846587171, 0.5734712864433781, 0.9507274040271213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.1263497464931148], {
             RGBColor[
             0.22864247952174482`, 0.3576481211208147, 0.9363322230113024]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.1263497464931148], {
             RGBColor[
             0.26498757281889074`, 0.39584911858812655`, 0.9384020223068277]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.1263497464931148], {
             RGBColor[
             0.9935460613341791, 0.9886040027241311, 0.5389067891970045]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.1263497464931148], {
             RGBColor[
             0.3585480532796543, 0.48497803542685713`, 0.944067342796753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.1263497464931148], {
             RGBColor[
             0.26115105564507934`, 0.3918166957892125, 0.9381835383293976]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.1263497464931148], {
             RGBColor[
             0.24150095424043594`, 0.3711631933245442, 0.9370644941241232]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.1263497464931148], {
             RGBColor[
             0.295921828646773, 0.42836298280833224`, 0.9401636824130951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[401, 0.1263497464931148], {
             RGBColor[
             0.7734523776791622, 0.8229461429895335, 0.9780541627497925]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[402, 0.1263497464931148], {
             RGBColor[
             0.5523112332770156, 0.6474301663686192, 0.9578991099477285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[403, 0.1263497464931148], {
             RGBColor[
             0.9289119756027943, 0.9461532109745376, 0.9930816475541463]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[404, 0.1263497464931148], {
             RGBColor[
             0.2134483076486736, 0.3416780831160786, 0.9354669374008939]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[405, 0.1263497464931148], {
             RGBColor[
             0.9940126833910108, 0.9896020601209673, 0.5896957204256101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[406, 0.1263497464931148], {
             RGBColor[
             0.990618380894789, 0.9800157372285142, 0.4180546106567104]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[407, 0.1263497464931148], {
             RGBColor[
             0.21435834209939697`, 0.3426345870233057, 0.9355187625165873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[408, 0.1263497464931148], {
             RGBColor[
             0.2225045334786326, 0.3511967506612473, 0.9359826760644245]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[409, 0.1263497464931148], {
             RGBColor[
             0.24155566178660715`, 0.3712206944242289, 0.937067609637945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[410, 0.1263497464931148], {
             RGBColor[
             0.36366501242205085`, 0.4894100882501565, 0.9443933909085572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[411, 0.1263497464931148], {
             RGBColor[
             0.23958996446517072`, 0.3691546219069906, 0.9369556660834778]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[412, 0.1263497464931148], {
             RGBColor[
             0.2423814866745967, 0.372088688741828, 0.9371146391436176]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[413, 0.1263497464931148], {
             RGBColor[
             0.97383602535665, 0.9234049113139019, 0.35285832847295656`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[414, 0.1263497464931148], {
             RGBColor[
             0.2746579678933065, 0.4060133169497984, 0.9389527370002482]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[415, 0.1263497464931148], {
             RGBColor[
             0.2870126862041934, 0.4189989092289247, 0.9396563199308854]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[416, 0.1263497464931148], {
             RGBColor[
             0.26153368469451344`, 0.39221886318025073`, 0.938205328487714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[417, 0.1263497464931148], {
             RGBColor[
             0.7010326627105, 0.7663713112457954, 0.9708360423624304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[418, 0.1263497464931148], {
             RGBColor[
             0.978473490691829, 0.9834661451211657, 0.9213229446326382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[419, 0.1263497464931148], {
             RGBColor[
             0.5126905354832046, 0.6152642990075083, 0.9547800234820015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[420, 0.1263497464931148], {
             RGBColor[
             0.96864282965107, 0.9761344542131977, 0.9379636895276074]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[421, 0.1263497464931148], {
             RGBColor[
             0.17905660578117066`, 0.3055302238934915, 0.9335083808575031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[422, 0.1263497464931148], {
             RGBColor[
             0.23401200432651914`, 0.3632918321381684, 0.9366380095054342]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[423, 0.1263497464931148], {
             RGBColor[
             0.18782589147201245`, 0.31474729915939237`, 0.9340077787046009]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[424, 0.1263497464931148], {
             RGBColor[
             0.3205944320155112, 0.4521045162923272, 0.9416489716108714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[425, 0.1263497464931148], {
             RGBColor[
             0.37534284954540054`, 0.499524843821242, 0.9451374923637511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[426, 0.1263497464931148], {
             RGBColor[
             0.8701743928884773, 0.8993174569073501, 0.9874792044791957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[427, 0.1263497464931148], {
             RGBColor[
             0.2795001276110678, 0.4111027338238238, 0.9392284908328413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[428, 0.1263497464931148], {
             RGBColor[
             0.8303334960184631, 0.23416211938642656`, 0.1766806960850511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[429, 0.1263497464931148], {
             RGBColor[
             0.29359796730781346`, 0.4259204571997668, 0.9400313419476861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[430, 0.1263497464931148], {
             RGBColor[
             0.23973902577549727`, 0.36931129479517677`, 0.9369641549045845]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[431, 0.1263497464931148], {
             RGBColor[
             0.4485399301016759, 0.5629244760068475, 0.9498015456111601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[432, 0.1263497464931148], {
             RGBColor[
             0.898624468927386, 0.9220027752840345, 0.9901927981294695]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[433, 0.1263497464931148], {
             RGBColor[
             0.32550625142704326`, 0.4563588873913744, 0.9419619484004228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[434, 0.1263497464931148], {
             RGBColor[
             0.9912025783926344, 0.990630054329001, 0.7954595732387495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[435, 0.1263497464931148], {
             RGBColor[
             0.25811768357221787`, 0.3886284294137375, 0.93801079227732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[436, 0.1263497464931148], {
             RGBColor[
             0.472919813782261, 0.5829766354800872, 0.9516491265847494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[437, 0.1263497464931148], {
             RGBColor[
             0.2558304623203871, 0.3862244148598601, 0.9378805384106689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[438, 0.1263497464931148], {
             RGBColor[
             0.22146455698209894`, 0.3501036694250721, 0.9359234509414543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[439, 0.1263497464931148], {
             RGBColor[
             0.8609124841587944, 0.891932262294116, 0.986595795356355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[440, 0.1263497464931148], {
             RGBColor[
             0.28167383897512416`, 0.41338744228870766`, 0.9393522804793065]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[441, 0.1263497464931148], {
             RGBColor[
             0.4501324018566838, 0.5643037950010776, 0.9499030165032217]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[442, 0.1263497464931148], {
             RGBColor[
             0.28394532564135605`, 0.4157749187954902, 0.9394816382845851]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[443, 0.1263497464931148], {
             RGBColor[
             0.9345119801701037, 0.7780688545030732, 0.2661650059247154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[444, 0.1263497464931148], {
             RGBColor[
             0.27129304719779485`, 0.4024765719505212, 0.9387611097445928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[445, 0.1263497464931148], {
             RGBColor[
             0.22963931784821143`, 0.3586958614051314, 0.9363889914793045]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[446, 0.1263497464931148], {
             RGBColor[
             0.22815127331601265`, 0.3571318322543179, 0.9363042495445604]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[447, 0.1263497464931148], {
             RGBColor[
             0.2464999471451923, 0.3764174518218997, 0.9373491793747017]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[448, 0.1263497464931148], {
             RGBColor[
             0.5679393142918087, 0.6601177465734548, 0.9591294097327601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[449, 0.1263497464931148], {
             RGBColor[
             0.7283027762348872, 0.7876749311915857, 0.9735540724248413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[450, 0.1263497464931148], {
             RGBColor[
             0.8177084834502429, 0.13712074047130335`, 0.1645909697918113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[451, 0.1263497464931148], {
             RGBColor[
             0.21144581794704176`, 0.3395733394744833, 0.935352898574804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[452, 0.1263497464931148], {
             RGBColor[
             0.22395342458252596`, 0.35271962707644106`, 0.936065188269349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[453, 0.1263497464931148], {
             RGBColor[
             0.2843068325272902, 0.41615488545346746`, 0.9395022255669375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[454, 0.1263497464931148], {
             RGBColor[
             0.8998824261938122, 0.6382713050470934, 0.23817178112086787`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[455, 0.1263497464931148], {
             RGBColor[
             0.20394063923757638`, 0.33168492079502093`, 0.9349254897502168]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[456, 0.1263497464931148], {
             RGBColor[
             0.22365852866224617`, 0.35240967276674573`, 0.9360483943829485]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[457, 0.1263497464931148], {
             RGBColor[
             0.22158907133489145`, 0.35023454190452297`, 0.9359305418496434]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[458, 0.1263497464931148], {
             RGBColor[
             0.2304992557221517, 0.359599710633853, 0.9364379636690613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[459, 0.1263497464931148], {
             RGBColor[
             0.3905461178527888, 0.5126931506906183, 0.9461062311765757]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[460, 0.1263497464931148], {
             RGBColor[
             0.24834625332605567`, 0.3783580366805602, 0.9374543237803367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[461, 0.1263497464931148], {
             RGBColor[
             0.944455505750549, 0.9580955876512972, 0.9789065198267879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[462, 0.1263497464931148], {
             RGBColor[
             0.46387836533310084`, 0.575636380316448, 0.9509373506429145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[463, 0.1263497464931148], {
             RGBColor[
             0.2670973610782935, 0.3980666398170606, 0.9385221716270487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[464, 0.1263497464931148], {
             RGBColor[
             0.24386676324271586`, 0.3736498085868948, 0.9371992234469022]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[465, 0.1263497464931148], {
             RGBColor[
             0.28262558218412137`, 0.4143877847453685, 0.939406480847081]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[466, 0.1263497464931148], {
             RGBColor[
             0.503508173143364, 0.6078096435993164, 0.9540571542825077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[467, 0.1263497464931148], {
             RGBColor[
             0.7068391686146014, 0.7709073977891587, 0.9714147806060683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[468, 0.1263497464931148], {
             RGBColor[
             0.4783770236668791, 0.5874070443089239, 0.952078738137285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[469, 0.1263497464931148], {
             RGBColor[
             0.8604306779796645, 0.4591301305965446, 0.20525227536014304`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[470, 0.1263497464931148], {
             RGBColor[
             0.25548210733168075`, 0.3858582716797478, 0.937860700109407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[471, 0.1263497464931148], {
             RGBColor[
             0.8568125830318801, 0.4376919853814662, 0.20203709971295072`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[472, 0.1263497464931148], {
             RGBColor[
             0.32844671668737896`, 0.45890577060779597`, 0.9421493122466601]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[473, 0.1263497464931148], {
             RGBColor[
             0.32683125980079797`, 0.4575065430478635, 0.9420463767623395]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[474, 0.1263497464931148], {
             RGBColor[
             0.9930971542734537, 0.9914135101440991, 0.7640615478883636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[475, 0.1263497464931148], {
             RGBColor[
             0.839003391040872, 0.30080273170088523`, 0.1849829973497558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[476, 0.1263497464931148], {
             RGBColor[
             0.8484924274103163, 0.3737396233586853, 0.19406970929346942`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[477, 0.1263497464931148], {
             RGBColor[
             0.24467162743864543`, 0.3744957718881542, 0.9372450592721705]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[478, 0.1263497464931148], {
             RGBColor[
             0.2660419428822219, 0.39695732837561076`, 0.9384620671221336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[479, 0.1263497464931148], {
             RGBColor[
             0.41149067372934756`, 0.5308342722869064, 0.9474407997564864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[480, 0.1263497464931148], {
             RGBColor[
             0.35354723518652786`, 0.48064657814301665`, 0.9437486950899088]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[481, 0.1263497464931148], {
             RGBColor[
             0.318216697210702, 0.4500450419128276, 0.9414974644516573]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[482, 0.1263497464931148], {
             RGBColor[
             0.35848143845973107`, 0.48492033701799786`, 0.9440630981593326]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[483, 0.1263497464931148], {
             RGBColor[
             0.29664917161590876`, 0.42912746638510174`, 0.9402051035191799]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[484, 0.1263497464931148], {
             RGBColor[
             0.9928916986278599, 0.9872043870615327, 0.4676834468726777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[485, 0.1263497464931148], {
             RGBColor[
             0.24800119075484597`, 0.3779953540399882, 0.9374346729773807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[486, 0.1263497464931148], {
             RGBColor[
             0.9349275982881982, 0.9509499052141509, 0.9936554230160899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[487, 0.1263497464931148], {
             RGBColor[
             0.5794313774456323, 0.6694475211532741, 0.9600341070410434]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[488, 0.1263497464931148], {
             RGBColor[
             0.7693643004981994, 0.8197525060252281, 0.9776467014216474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[489, 0.1263497464931148], {
             RGBColor[
             0.9900975943251971, 0.9901731150203205, 0.8137720188432849]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[490, 0.1263497464931148], {
             RGBColor[
             0.9905535588776926, 0.9903616680805318, 0.806215506209998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[491, 0.1263497464931148], {
             RGBColor[
             0.9941614319695004, 0.9899202182895682, 0.6058860852243823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[492, 0.1263497464931148], {
             RGBColor[
             0.2766193131480329, 0.4080748151689876, 0.9390644327109545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[493, 0.1263497464931148], {
             RGBColor[
             0.9935772608954081, 0.9886707354308406, 0.5423026688954158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[494, 0.1263497464931148], {
             RGBColor[
             0.2585035332044634, 0.3890339818415072, 0.938032765843063]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[495, 0.1263497464931148], {
             RGBColor[
             0.8422024713778844, 0.3253922650171049, 0.18804644029332332`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[496, 0.1263497464931148], {
             RGBColor[
             0.27688954314442643`, 0.4083588440287685, 0.9390798219094797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[497, 0.1263497464931148], {
             RGBColor[
             0.23599364281048124`, 0.36537465982794926`, 0.9367508608855244]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[498, 0.1263497464931148], {
             RGBColor[
             0.46188951150763047`, 0.5740217391840874, 0.9507807807843619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[499, 0.1263497464931148], {
             RGBColor[
             0.2607186377132893, 0.3913621971260208, 0.9381589127678872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[500, 0.1263497464931148], {
             RGBColor[
             0.8194926622925333, 0.15083472088530037`, 0.16629950146613023`]},
             StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{
  3.834950276960332*^9, {3.8349573666066523`*^9, 3.83495737580899*^9}, 
   3.8349587938370156`*^9, 3.8350189212906833`*^9, 3.835019008666805*^9, 
   3.8350204886401753`*^9, 3.83502054312705*^9, {3.8350446267813253`*^9, 
   3.8350446323653708`*^9}, 3.835045028161322*^9, 3.8350456979409313`*^9, 
   3.8350520818267603`*^9, 3.835052514411209*^9, {3.8350527293751154`*^9, 
   3.835052736761989*^9}},
 CellLabel->
  "Out[446]=",ExpressionUUID->"f241de3d-6d56-4143-b2af-cdb0bb34f972"]
}, Open  ]],

Cell["Estimated with absolute Mean Deviation v Calculated: (r=3)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 
  3.8349503756793146`*^9}},ExpressionUUID->"4963adef-b661-4c45-999c-\
95f08181a173"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphinf5", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsif5", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}],
      "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"AMDi3f500", ",", "krif5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502409842243`*^9}, {3.834957391671958*^9, 3.8349574025038147`*^9}, {
   3.8350188314314775`*^9, 3.835018832832349*^9}, {3.8350443332621727`*^9, 
   3.835044338598092*^9}, {3.835044923956807*^9, 3.8350449330660315`*^9}, {
   3.835045604518895*^9, 3.8350456066714773`*^9}, {3.8350524576599884`*^9, 
   3.8350524591977186`*^9}},
 CellLabel->
  "In[428]:=",ExpressionUUID->"fe827fc3-5274-4049-8236-914556fad6e6"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1dOWGAgQBNBMbNu2bds2J+bEtm3btm3btu01sjdnH271F1R1ssCg6p0C
ggUL9l38vMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEIS
kZgkJCUZyUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpR
mCIUpRjFKUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGY
JjSlGYE0pwUtaUVr2tCWdrSnAx3pRBCd6UJXutGdHvSkF73pQ1/60Z8BDGQQ
gxnCUIYxnBGMZBSjGcNYxjGeCUxkEpOZwlSmMZ0ZzGQWs5nDXOYxnwUsZBGL
WcJSlrGcFaxkFatZw1rWsZ4NbGQTm9nCVraxnR3sZBe72cNe9rGfAxzkEIc5
wlGOcZwTnOQUpznDWc5xngtc5BKXucJVrnGdG9zkFre5w13ucZ8HPOQRj3nC
U57xnBe85BWvecNb3vGeD3zkE5/5wle+8Z1f+JXf+J0/+JO/+Jt/+Jcf/Cx/
AMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEISkZgkJCUZ
yUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpRmCIUpRjF
KUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGYJjSlGYE0
pwUtaUVr2tCWdrSnAx35Od5BdKYLXelGd3rQk170pg996Ud/BjCQQQxmCEMZ
xnBGMJJRjGYMYxnHeCYwkUlMZgpTmcZ0ZjCTWcxmDnOZx3wWsJBFLGYJS1nG
clawklWsZg1rWcd6NrCRTWxmC1vZxnZ2sJNd7GYPe9nHfg5wkEMc5ghHOcZx
TnCSU5zmDGc5x3kucJFLXOYKV7nGdW5wk1vc5g53ucd9HvCQRzzmCU95xnNe
8JJXvOYNb3nHez7wkU985gtf+Rbw/z//Dz189+A=
          "], {Null, CompressedData["
1:eJw13A2c1mO6wPH7tsdpl2O9LLLYQ3Ioas/uCqvVrqQihdKSUmmVzEwspdpK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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[196, 330] -> 
             RGBColor[
              0.9892038017023336, 0.9886305797636378, 0.7433249166924638], 
             UndirectedEdge[136, 319] -> 
             RGBColor[
              0.849242282437791, 0.8826267602209747, 0.9854826810980937], 
             UndirectedEdge[60, 188] -> 
             RGBColor[
              0.7196962586144342, 0.7809514542145313, 0.9726962551809144], 
             UndirectedEdge[145, 408] -> 
             RGBColor[
              0.7182864192464733, 0.7782052018941821, 0.9627179477111449], 
             UndirectedEdge[398, 460] -> 
             RGBColor[
              0.8352508633471827, 0.8719653005959196, 0.9741669639357662], 
             UndirectedEdge[413, 476] -> 
             RGBColor[
              0.9201176226728698, 0.9382436192012213, 0.961135880317177], 
             UndirectedEdge[244, 274] -> 
             RGBColor[
              0.9355421934432513, 0.9498460760016805, 0.9354472218773706], 
             UndirectedEdge[198, 223] -> 
             RGBColor[
              0.978918785935668, 0.9820183390131567, 0.8408613230907375], 
             UndirectedEdge[36, 310] -> 
             RGBColor[
              0.8167880503586722, 0.8560676426640277, 0.9019644927582541], 
             UndirectedEdge[252, 432] -> 
             RGBColor[
              0.9470942003472385, 0.9591884973306145, 0.9422446821589721], 
             UndirectedEdge[469, 475] -> 
             RGBColor[
              0.8307526848482449, 0.8680497735447846, 0.9836750445480744], 
             UndirectedEdge[113, 347] -> 
             RGBColor[
              0.784392567990965, 0.832059971356059, 0.9789940430478717], 
             UndirectedEdge[35, 131] -> 
             RGBColor[
              0.9769392942096554, 0.9791585682277746, 0.7366015281363352], 
             UndirectedEdge[156, 479] -> 
             RGBColor[
              0.9606630952779145, 0.9668332799916726, 0.7583142102788825], 
             UndirectedEdge[318, 354] -> 
             RGBColor[
              0.9712954117204725, 0.9593868660912162, 0.6656430688433792], 
             UndirectedEdge[6, 77] -> 
             RGBColor[
              0.7768410668034023, 0.825172052113966, 0.9520273177989209], 
             UndirectedEdge[23, 202] -> 
             RGBColor[
              0.9104887992234149, 0.9310161410198159, 0.9758291128405425], 
             UndirectedEdge[342, 395] -> 
             RGBColor[
              0.8392402216123258, 0.8751874083798062, 0.979909574234079], 
             UndirectedEdge[53, 418] -> 
             RGBColor[
              0.9411021908147474, 0.953029879448487, 0.8817161343328792], 
             UndirectedEdge[75, 149] -> 
             RGBColor[
              0.8854081798996511, 0.8220373838150957, 0.6245009536766744], 
             UndirectedEdge[293, 418] -> 
             RGBColor[
              0.7817182662223785, 0.8299671060045891, 0.9787284703277462], 
             UndirectedEdge[282, 432] -> 
             RGBColor[
              0.9870992326871739, 0.9889332154286186, 0.8634626306965099], 
             UndirectedEdge[466, 468] -> 
             RGBColor[
              0.9031545995218399, 0.9250396437772013, 0.970677671653295], 
             UndirectedEdge[105, 190] -> 
             RGBColor[
              0.897328374161849, 0.9209693044995504, 0.9900691754536951], 
             UndirectedEdge[64, 473] -> 
             RGBColor[
              0.7560854839483786, 0.8094293454856077, 0.9763098312469481], 
             UndirectedEdge[214, 273] -> 
             RGBColor[
              0.9914722373426182, 0.989983191805417, 0.7358648840677819], 
             UndirectedEdge[30, 64] -> 
             RGBColor[
              0.8394803454555719, 0.8710187864174312, 0.7245855233026598], 
             UndirectedEdge[296, 395] -> 
             RGBColor[
              0.8002944967936116, 0.8447627121529553, 0.9760278283526405], 
             UndirectedEdge[114, 203] -> 
             RGBColor[
              0.9067685424238932, 0.9284090149434359, 0.9879316260123663], 
             UndirectedEdge[81, 237] -> 
             RGBColor[
              0.41930857022456014`, 0.5375506390385025, 0.9479541741249288], 
             UndirectedEdge[382, 427] -> 
             RGBColor[
              0.9474529864528105, 0.944166687578361, 0.6910059319735603], 
             UndirectedEdge[39, 450] -> 
             RGBColor[
              0.9905862887093364, 0.9889003492442852, 0.6984668108003123], 
             UndirectedEdge[50, 57] -> 
             RGBColor[
              0.7265325363090505, 0.7862920063072003, 0.9733776314528666], 
             UndirectedEdge[74, 153] -> 
             RGBColor[
              0.8617932443441612, 0.8896784313641974, 0.8252171718411485], 
             UndirectedEdge[239, 332] -> 
             RGBColor[
              0.957422683383976, 0.9213213560252286, 0.6302832533751241], 
             UndirectedEdge[14, 72] -> 
             RGBColor[
              0.9843430523847123, 0.9847302048412182, 0.7280303025079349], 
             UndirectedEdge[331, 403] -> 
             RGBColor[
              0.9006732511633146, 0.9229305193136317, 0.9659142405083103], 
             UndirectedEdge[214, 302] -> 
             RGBColor[
              0.8361455947821947, 0.8711996649765884, 0.9043364991072581], 
             UndirectedEdge[128, 197] -> 
             RGBColor[
              0.7406542485554657, 0.7914094376351894, 0.7125999366414513], 
             UndirectedEdge[191, 212] -> 
             RGBColor[
              0.9112747991739798, 0.9302128367328008, 0.9208403607523055], 
             UndirectedEdge[404, 407] -> 
             RGBColor[
              0.8518642025458676, 0.8831733488461602, 0.8920363693374749], 
             UndirectedEdge[60, 116] -> 
             RGBColor[
              0.835890189024991, 0.8713110012914744, 0.9184068108801008], 
             UndirectedEdge[272, 357] -> 
             RGBColor[
              0.9767227420890303, 0.980054594760787, 0.820878636159585], 
             UndirectedEdge[228, 490] -> 
             RGBColor[
              0.9796720621233582, 0.9506625583253443, 0.5855582726481259], 
             UndirectedEdge[111, 415] -> 
             RGBColor[
              0.9871779110548171, 0.9888234025668078, 0.8557840748475085], 
             UndirectedEdge[227, 428] -> 
             RGBColor[
              0.8565872741756109, 0.8884196048211903, 0.965467914655673], 
             UndirectedEdge[367, 499] -> 
             RGBColor[
              0.7508346096228833, 0.8040376573820496, 0.949411884951247], 
             UndirectedEdge[434, 495] -> 
             RGBColor[
              0.6915656288000633, 0.7517739632458079, 0.852949499156882], 
             UndirectedEdge[226, 283] -> 
             RGBColor[
              0.9898833904237612, 0.9900845362022875, 0.8173219318320037], 
             UndirectedEdge[9, 34] -> 
             RGBColor[
              0.8669778613697069, 0.8967686294418192, 0.9871743164493579], 
             UndirectedEdge[127, 386] -> 
             RGBColor[
              0.8164850856057813, 0.8572668855795191, 0.9703503948706995], 
             UndirectedEdge[326, 469] -> 
             RGBColor[
              0.7954234477912208, 0.8404503050436908, 0.9801537563687215], 
             UndirectedEdge[192, 483] -> 
             RGBColor[
              0.9458565603769344, 0.9566602319977147, 0.8751935160674339], 
             UndirectedEdge[16, 39] -> 
             RGBColor[
              0.8974060741191874, 0.9192298803898447, 0.9182897986602916], 
             UndirectedEdge[209, 421] -> 
             RGBColor[
              0.9790728862661359, 0.9824026790281464, 0.8526653020134665], 
             UndirectedEdge[293, 317] -> 
             RGBColor[
              0.8057368565927784, 0.8490660011991018, 0.9791861130839628], 
             UndirectedEdge[3, 381] -> 
             RGBColor[
              0.8378214647222612, 0.8741102552519044, 0.9842367469532977], 
             UndirectedEdge[211, 497] -> 
             RGBColor[
              0.7969865607127535, 0.8421898304241593, 0.9762702841979518], 
             UndirectedEdge[196, 479] -> 
             RGBColor[
              0.9609213782317322, 0.9673857211134762, 0.7864267158643166], 
             UndirectedEdge[221, 439] -> 
             RGBColor[
              0.8784813849518831, 0.9059412268914173, 0.9882715327979427], 
             UndirectedEdge[379, 390] -> 
             RGBColor[
              0.9625971466865353, 0.9557253940667052, 0.6863653461065284], 
             UndirectedEdge[119, 320] -> 
             RGBColor[
              0.9771736151182321, 0.9417788640580995, 0.5727014882590722], 
             UndirectedEdge[179, 401] -> 
             RGBColor[
              0.9805668804818763, 0.9843675743377538, 0.8882314077621546], 
             UndirectedEdge[59, 342] -> 
             RGBColor[
              0.8662058707780871, 0.892980566428951, 0.8140398361730246], 
             UndirectedEdge[86, 98] -> 
             RGBColor[
              0.8741599174237422, 0.9023395681264568, 0.976942492329028], 
             UndirectedEdge[328, 431] -> 
             RGBColor[
              0.91904709271374, 0.9381645172375068, 0.9878865051012269], 
             UndirectedEdge[270, 375] -> 
             RGBColor[
              0.8191908142021, 0.8421487410407764, 0.6768407250721037], 
             UndirectedEdge[39, 45] -> 
             RGBColor[
              0.6745782985216511, 0.7383620488784198, 0.8997098136269776], 
             UndirectedEdge[59, 463] -> 
             RGBColor[
              0.9749162417764856, 0.9784953757580812, 0.8071205113761031], 
             UndirectedEdge[2, 55] -> 
             RGBColor[
              0.8505130851594567, 0.8488918737389511, 0.6540772441733904], 
             UndirectedEdge[193, 496] -> 
             RGBColor[
              0.9334279517932309, 0.9480401894732822, 0.9300326812180959], 
             UndirectedEdge[201, 246] -> 
             RGBColor[
              0.9188512489319138, 0.9063960167539925, 0.6662632486458684], 
             UndirectedEdge[69, 487] -> 
             RGBColor[
              0.6789994527050913, 0.741068585648379, 0.8587210921320636], 
             UndirectedEdge[15, 408] -> 
             RGBColor[
              0.7399984024014545, 0.789463377279406, 0.6874110382576459], 
             UndirectedEdge[118, 310] -> 
             RGBColor[
              0.8925828153069654, 0.9152790891031835, 0.9095190065859506], 
             UndirectedEdge[289, 297] -> 
             RGBColor[
              0.7242209325103136, 0.783704540107018, 0.9739473616107028], 
             UndirectedEdge[397, 419] -> 
             RGBColor[
              0.8519816901116437, 0.8848497318940293, 0.9857337137551373], 
             UndirectedEdge[13, 380] -> 
             RGBColor[
              0.8554766720906393, 0.8876234180531875, 0.9689726925042076], 
             UndirectedEdge[155, 262] -> 
             RGBColor[
              0.945267883966812, 0.9068380520238837, 0.638511436018806], 
             UndirectedEdge[182, 324] -> 
             RGBColor[
              0.9665601099686997, 0.9385768299658165, 0.6369798078510805], 
             UndirectedEdge[177, 245] -> 
             RGBColor[
              0.6989697640482373, 0.7647597591322252, 0.97063043190266], 
             UndirectedEdge[113, 325] -> 
             RGBColor[
              0.9395323525711218, 0.9524681048148445, 0.9115273581727468], 
             UndirectedEdge[94, 368] -> 
             RGBColor[
              0.7032322844372247, 0.7624108776024319, 0.8732409304285744], 
             UndirectedEdge[50, 140] -> 
             RGBColor[
              0.8601284239548976, 0.890975688132133, 0.9551760275934271], 
             UndirectedEdge[389, 458] -> 
             RGBColor[
              0.9008142634782487, 0.9200961096494683, 0.8238330991430134], 
             UndirectedEdge[429, 499] -> 
             RGBColor[
              0.944370894635808, 0.9576954057892992, 0.9673630027607643], 
             UndirectedEdge[97, 358] -> 
             RGBColor[
              0.9468385457694086, 0.9592887937316226, 0.9546228840059467], 
             UndirectedEdge[274, 363] -> 
             RGBColor[
              0.9543043301162205, 0.9648064945000732, 0.9372367712223955], 
             UndirectedEdge[255, 274] -> 
             RGBColor[
              0.9274077195886081, 0.9433598673543986, 0.9346713484993843], 
             UndirectedEdge[289, 381] -> 
             RGBColor[
              0.9136228642155828, 0.9339620885662481, 0.9916233584612832], 
             UndirectedEdge[55, 230] -> 
             RGBColor[
              0.8617522598637992, 0.8576720024388749, 0.65519746007186], 
             UndirectedEdge[289, 349] -> 
             RGBColor[
              0.8195791970916242, 0.8596159688095479, 0.9824830894400354], 
             UndirectedEdge[29, 318] -> 
             RGBColor[
              0.9781897118472928, 0.9645286238374183, 0.6539728170501272], 
             UndirectedEdge[69, 402] -> 
             RGBColor[
              0.6777407286941604, 0.7405480709221275, 0.8795814064665078], 
             UndirectedEdge[6, 413] -> 
             RGBColor[
              0.9679824213544639, 0.9756419227869082, 0.9390815885116919], 
             UndirectedEdge[29, 482] -> 
             RGBColor[
              0.8497844467103097, 0.8828122999514393, 0.9499641145126922], 
             UndirectedEdge[212, 456] -> 
             RGBColor[
              0.9126614652374272, 0.9313185266117461, 0.9209726221993284], 
             UndirectedEdge[354, 482] -> 
             RGBColor[
              0.8428901465834895, 0.8776705422052371, 0.9616343663059441], 
             UndirectedEdge[106, 247] -> 
             RGBColor[
              0.8405347185153026, 0.8759886147844009, 0.9694051713087742], 
             UndirectedEdge[305, 382] -> 
             RGBColor[
              0.854479046259099, 0.8869832978201564, 0.9859341671810526], 
             UndirectedEdge[279, 285] -> 
             RGBColor[
              0.9638582727185763, 0.9725661394869369, 0.9460626964020157], 
             UndirectedEdge[27, 319] -> 
             RGBColor[
              0.8757715353005651, 0.9037804663363656, 0.9880130649190886], 
             UndirectedEdge[118, 483] -> 
             RGBColor[
              0.894950050720055, 0.9162580017816712, 0.8702877895821872], 
             UndirectedEdge[342, 447] -> 
             RGBColor[
              0.8635968174861253, 0.8924903545705276, 0.9000707840976093], 
             UndirectedEdge[207, 458] -> 
             RGBColor[
              0.886197975815624, 0.8721579002611852, 0.65090012088695], 
             UndirectedEdge[462, 487] -> 
             RGBColor[
              0.9938478666356387, 0.9915963239323412, 0.7423433062498275], 
             UndirectedEdge[64, 384] -> 
             RGBColor[
              0.8337173700239671, 0.8701504049459433, 0.9427857803053437], 
             UndirectedEdge[203, 221] -> 
             RGBColor[
              0.8860620005517819, 0.9118981805187203, 0.985956617563656], 
             UndirectedEdge[139, 370] -> 
             RGBColor[
              0.8590912153182594, 0.8872824575024694, 0.8021105379392189], 
             UndirectedEdge[46, 357] -> 
             RGBColor[
              0.970064645467424, 0.9771948421210249, 0.9355569262194754], 
             UndirectedEdge[18, 326] -> 
             RGBColor[
              0.7041540855947148, 0.7688097905266366, 0.9711471566241735], 
             UndirectedEdge[73, 93] -> 
             RGBColor[
              0.8187099257992256, 0.8587019082181605, 0.9824588048696923], 
             UndirectedEdge[104, 112] -> 
             RGBColor[
              0.9049003029465079, 0.8900142821681197, 0.6571979342421106], 
             UndirectedEdge[40, 314] -> 
             RGBColor[
              0.8288566572586158, 0.8667996910042838, 0.9649036647878384], 
             UndirectedEdge[264, 398] -> 
             RGBColor[
              0.964584590975502, 0.9731078264537151, 0.9448332290471809], 
             UndirectedEdge[345, 489] -> 
             RGBColor[
              0.9315486520011638, 0.945033259592783, 0.864352313285436], 
             UndirectedEdge[80, 417] -> 
             RGBColor[
              0.7980122397856839, 0.8428615373375454, 0.9698141387669204], 
             UndirectedEdge[271, 442] -> 
             RGBColor[
              0.9478672158597551, 0.9560646261339865, 0.7112470383311846], 
             UndirectedEdge[318, 482] -> 
             RGBColor[
              0.8527195609790477, 0.8662754238811181, 0.6771652405111882], 
             UndirectedEdge[235, 260] -> 
             RGBColor[
              0.8482825031980501, 0.8818614583077187, 0.985391136497402], 
             UndirectedEdge[79, 278] -> 
             RGBColor[
              0.8713859303231479, 0.8996629268537363, 0.950871076791427], 
             UndirectedEdge[137, 404] -> 
             RGBColor[
              0.9783176463215653, 0.9823509359614132, 0.8768503524528282], 
             UndirectedEdge[380, 478] -> 
             RGBColor[
              0.806757192476101, 0.8492652326108727, 0.9812937687282938], 
             UndirectedEdge[247, 370] -> 
             RGBColor[
              0.7261626892613338, 0.7860030789825824, 0.9733407685555673], 
             UndirectedEdge[251, 429] -> 
             RGBColor[
              0.7717624467751504, 0.8221268211743864, 0.9778903458571124], 
             UndirectedEdge[286, 407] -> 
             RGBColor[
              0.7204124105073617, 0.7815109175162422, 0.9727676345087816], 
             UndirectedEdge[206, 410] -> 
             RGBColor[
              0.8198519411498831, 0.858213799069284, 0.8910526872300086], 
             UndirectedEdge[86, 500] -> 
             RGBColor[
              0.8965274265196466, 0.9176247441924418, 0.8765431035304748], 
             UndirectedEdge[78, 407] -> 
             RGBColor[0.719060969910481, 0.78045516185063, 0.972632935540015],
              UndirectedEdge[363, 370] -> 
             RGBColor[
              0.8232083255738818, 0.8626454965171947, 0.9827932126459996], 
             UndirectedEdge[447, 453] -> 
             RGBColor[
              0.9920226315958601, 0.9904358298735714, 0.7431011612436595], 
             UndirectedEdge[256, 492] -> 
             RGBColor[
              0.8480974579974812, 0.8803261642051226, 0.8959879023356571], 
             UndirectedEdge[114, 349] -> 
             RGBColor[
              0.8075128760811838, 0.8499946119673814, 0.9813321929703276], 
             UndirectedEdge[22, 160] -> 
             RGBColor[
              0.9676075578017744, 0.9723134067410941, 0.7614774331210481], 
             UndirectedEdge[149, 324] -> 
             RGBColor[
              0.9502469855259443, 0.8369015075039777, 0.2973215113912086], 
             UndirectedEdge[94, 315] -> 
             RGBColor[
              0.9719417395109207, 0.9774634302979884, 0.8817155332364972], 
             UndirectedEdge[246, 492] -> 
             RGBColor[
              0.8392212442125899, 0.8438183889912426, 0.658424677266279], 
             UndirectedEdge[193, 202] -> 
             RGBColor[
              0.927276945863512, 0.9431355443095322, 0.9294459927814515], 
             UndirectedEdge[321, 335] -> 
             RGBColor[
              0.8896815190544101, 0.9145770441993767, 0.9791166359290298], 
             UndirectedEdge[321, 496] -> 
             RGBColor[
              0.9136913789313514, 0.9337218547349653, 0.9814067177979474], 
             UndirectedEdge[18, 474] -> 
             RGBColor[
              0.6081464633282567, 0.6921902334705806, 0.9626840258458338], 
             UndirectedEdge[184, 192] -> 
             RGBColor[
              0.9283456566665036, 0.9451186373337148, 0.9728144373736064], 
             UndirectedEdge[170, 171] -> 
             RGBColor[
              0.6468313234777108, 0.7236853586422232, 0.9656685810909065], 
             UndirectedEdge[80, 156] -> 
             RGBColor[
              0.8210412367219012, 0.8568872133448273, 0.744629518936192], 
             UndirectedEdge[353, 418] -> 
             RGBColor[
              0.9240899421103723, 0.8932299748589061, 0.6412487519187291], 
             UndirectedEdge[201, 312] -> 
             RGBColor[
              0.88499027391724, 0.9111312382733086, 0.9888923564380121], 
             UndirectedEdge[152, 212] -> 
             RGBColor[
              0.8864846744360776, 0.9107244788384448, 0.9184019207598161], 
             UndirectedEdge[192, 260] -> 
             RGBColor[
              0.8695315517857698, 0.8988048728615081, 0.9874178897209483], 
             UndirectedEdge[90, 357] -> 
             RGBColor[
              0.9278475164307181, 0.9447153917626412, 0.9725574419979439], 
             UndirectedEdge[57, 369] -> 
             RGBColor[
              0.8329564295957265, 0.8698916716561627, 0.9597039856033649], 
             UndirectedEdge[83, 448] -> 
             RGBColor[
              0.9288759350177044, 0.9437886604893867, 0.902594573661238], 
             UndirectedEdge[67, 180] -> 
             RGBColor[
              0.9802661887783646, 0.9835529955084967, 0.8623045102303596], 
             UndirectedEdge[373, 472] -> 
             RGBColor[
              0.8769598259207181, 0.9047279770215859, 0.9881264051392383], 
             UndirectedEdge[353, 432] -> 
             RGBColor[
              0.9718826712685251, 0.9298758736787437, 0.5932360628681437], 
             UndirectedEdge[1, 433] -> 
             RGBColor[
              0.901624575620463, 0.924333651542296, 0.9883526921144761], 
             UndirectedEdge[300, 301] -> 
             RGBColor[
              0.8822460704150856, 0.9089430848901103, 0.9886306118581973], 
             UndirectedEdge[212, 389] -> 
             RGBColor[
              0.9910862118676729, 0.9900938883686409, 0.7619123183353138], 
             UndirectedEdge[97, 174] -> 
             RGBColor[
              0.9380613702627131, 0.9527427906100349, 0.9694803526847788], 
             UndirectedEdge[200, 471] -> 
             RGBColor[
              0.967077188548399, 0.9749668016423279, 0.9406139115298314], 
             UndirectedEdge[155, 387] -> 
             RGBColor[
              0.9626802363256959, 0.9705691484452665, 0.8982569107477336], 
             UndirectedEdge[156, 354] -> 
             RGBColor[
              0.9774359039163545, 0.979543002401682, 0.7368767734554873], 
             UndirectedEdge[314, 472] -> 
             RGBColor[
              0.9407633793664085, 0.9550730556932274, 0.9758316563351772], 
             UndirectedEdge[117, 269] -> 
             RGBColor[
              0.8319298795063776, 0.86908274207275, 0.9837623006555617], 
             UndirectedEdge[336, 409] -> 
             RGBColor[
              0.8941214977750593, 0.9184122283170649, 0.9897633007211107], 
             UndirectedEdge[63, 252] -> 
             RGBColor[
              0.6126416314055296, 0.6893269315369526, 0.9662766150692091], 
             UndirectedEdge[201, 444] -> 
             RGBColor[
              0.9067658545382771, 0.9281834045575387, 0.9801836236524641], 
             UndirectedEdge[201, 442] -> 
             RGBColor[
              0.9291658053488782, 0.9411526290288783, 0.7094632811017109], 
             UndirectedEdge[25, 333] -> 
             RGBColor[
              0.9105503474391146, 0.7024949338194095, 0.5726190248886993], 
             UndirectedEdge[203, 397] -> 
             RGBColor[
              0.9139286167553227, 0.9341182638602776, 0.9886145602939718], 
             UndirectedEdge[7, 436] -> 
             RGBColor[
              0.9036058487156083, 0.9259291652194444, 0.9890860066664596], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.91678602047035, 0.9301075982752272, 0.703371702392819], 
             UndirectedEdge[274, 369] -> 
             RGBColor[
              0.9742481891099879, 0.9800176709137152, 0.9151637617506145], 
             UndirectedEdge[38, 364] -> 
             RGBColor[
              0.9666669666322734, 0.9738894078445135, 0.9067611598762901], 
             UndirectedEdge[215, 356] -> 
             RGBColor[
              0.8168579836859979, 0.8575152552833334, 0.9822051984905751], 
             UndirectedEdge[16, 283] -> 
             RGBColor[
              0.898671621198037, 0.9197532166300253, 0.8973164084329004], 
             UndirectedEdge[236, 276] -> 
             RGBColor[
              0.9890251901316981, 0.9882999725314106, 0.7276221937243997], 
             UndirectedEdge[39, 454] -> 
             RGBColor[
              0.9895721923963543, 0.9899558478205304, 0.8224792885008156], 
             UndirectedEdge[179, 315] -> 
             RGBColor[
              0.962925978078927, 0.9718708356711787, 0.947640828045557], 
             UndirectedEdge[149, 182] -> 
             RGBColor[
              0.9488345995459398, 0.8718524876710702, 0.6042216952845851], 
             UndirectedEdge[97, 407] -> 
             RGBColor[
              0.8132865790299558, 0.8548171398127654, 0.9818248486769298], 
             UndirectedEdge[274, 379] -> 
             RGBColor[
              0.9639498826286867, 0.97233721080189, 0.9325961083949568], 
             UndirectedEdge[39, 325] -> 
             RGBColor[
              0.988248604554012, 0.9894085102330658, 0.844414564383962], 
             UndirectedEdge[127, 347] -> 
             RGBColor[
              0.8137106761521237, 0.8550994958280289, 0.9700738676646894], 
             UndirectedEdge[327, 483] -> 
             RGBColor[
              0.9744610174743449, 0.9789556405136217, 0.8601354862696705], 
             UndirectedEdge[269, 360] -> 
             RGBColor[
              0.9143979904614248, 0.9341417377006732, 0.976497150308478], 
             UndirectedEdge[54, 147] -> 
             RGBColor[
              0.8557392572889209, 0.8880843066028177, 0.9819451406265393], 
             UndirectedEdge[276, 422] -> 
             RGBColor[
              0.9278670649763094, 0.9440246900737568, 0.9476793709402426], 
             UndirectedEdge[181, 424] -> 
             RGBColor[
              0.7441030742516477, 0.7993741222299375, 0.9703773669271694], 
             UndirectedEdge[336, 456] -> 
             RGBColor[
              0.8708111630877966, 0.8998252001796208, 0.9875399401892582], 
             UndirectedEdge[46, 298] -> 
             RGBColor[
              0.9532044288754397, 0.9643400114310217, 0.9543714601997547], 
             UndirectedEdge[107, 132] -> 
             RGBColor[
              0.9848976513095365, 0.9604601490738547, 0.4177881591953958], 
             UndirectedEdge[78, 95] -> 
             RGBColor[
              0.8533240092390875, 0.8679459695514016, 0.6789754325362254], 
             UndirectedEdge[296, 332] -> 
             RGBColor[
              0.8073705400063681, 0.8500400135950716, 0.9640499329210868], 
             UndirectedEdge[397, 472] -> 
             RGBColor[
              0.9070148575196493, 0.9286930433964742, 0.9909930808835878], 
             UndirectedEdge[19, 269] -> 
             RGBColor[
              0.9223738346948875, 0.9400901092707434, 0.9629961264545606], 
             UndirectedEdge[185, 335] -> 
             RGBColor[
              0.7470943815918236, 0.8024540518251491, 0.9754007789198086], 
             UndirectedEdge[112, 351] -> 
             RGBColor[
              0.9182130753313816, 0.9337031960741666, 0.8125019091873824], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.67008487741937, 0.7343425783039177, 0.894737384705526], 
             UndirectedEdge[251, 305] -> 
             RGBColor[
              0.7092510220108934, 0.772462792171028, 0.9718799492332584], 
             UndirectedEdge[131, 170] -> 
             RGBColor[
              0.8335549157817563, 0.8666492885253478, 0.7447789840307517], 
             UndirectedEdge[76, 333] -> 
             RGBColor[
              0.7575444633603949, 0.5825507086891315, 0.5839603790275212], 
             UndirectedEdge[114, 115] -> 
             RGBColor[
              0.7771743442877657, 0.8262939203489814, 0.9783083316508586], 
             UndirectedEdge[87, 421] -> 
             RGBColor[
              0.9856188219199122, 0.964392843685083, 0.5649108235944575], 
             UndirectedEdge[60, 192] -> 
             RGBColor[
              0.7916568696458397, 0.8378013084414514, 0.9797004577294102], 
             UndirectedEdge[84, 147] -> 
             RGBColor[
              0.7961236258387273, 0.8415121222183461, 0.9760032116233346], 
             UndirectedEdge[431, 433] -> 
             RGBColor[
              0.9178570371323195, 0.9372769757334205, 0.9899009587843663], 
             UndirectedEdge[201, 492] -> 
             RGBColor[
              0.786138965013996, 0.8332270643027037, 0.9792204399062996], 
             UndirectedEdge[86, 124] -> 
             RGBColor[
              0.8046220164828772, 0.8472961017210247, 0.9811608610489113], 
             UndirectedEdge[234, 239] -> 
             RGBColor[
              0.8845398995234149, 0.8637880269357416, 0.6404038538744757], 
             UndirectedEdge[100, 450] -> 
             RGBColor[
              0.9273524027491971, 0.9403839765632817, 0.7641948997003021], 
             UndirectedEdge[22, 275] -> 
             RGBColor[
              0.9838826956120112, 0.9844513778718764, 0.7339278700440863], 
             UndirectedEdge[160, 324] -> 
             RGBColor[
              0.9548188534749037, 0.9298202200972865, 0.6568546924849399], 
             UndirectedEdge[191, 218] -> 
             RGBColor[
              0.9125168567695547, 0.9307264594679953, 0.9002562520516089], 
             UndirectedEdge[349, 397] -> 
             RGBColor[
              0.8146729504126135, 0.8557038608842231, 0.9820151272519331], 
             UndirectedEdge[401, 454] -> 
             RGBColor[
              0.9898538722242727, 0.9900723296682159, 0.8178111247881805], 
             UndirectedEdge[311, 349] -> 
             RGBColor[
              0.8443573690467285, 0.8790528716593446, 0.9737331693546496], 
             UndirectedEdge[63, 324] -> 
             RGBColor[
              0.6421825688006073, 0.6760454932333722, 0.6357304306010712], 
             UndirectedEdge[22, 353] -> 
             RGBColor[
              0.9760087338017839, 0.9300878510942413, 0.4162399297711218], 
             UndirectedEdge[93, 437] -> 
             RGBColor[
              0.9244130080284318, 0.9414408525562115, 0.9536479441860829], 
             UndirectedEdge[417, 461] -> 
             RGBColor[
              0.8798063833054135, 0.9067597439136734, 0.9779666145832373], 
             UndirectedEdge[151, 249] -> 
             RGBColor[
              0.8766598834351323, 0.9008838406033832, 0.7939783908499026], 
             UndirectedEdge[148, 452] -> 
             RGBColor[
              0.9082486013740243, 0.9264868794623471, 0.8635389281452988], 
             UndirectedEdge[262, 424] -> 
             RGBColor[
              0.7511449694121702, 0.7527907306063764, 0.6204143703224321], 
             UndirectedEdge[50, 139] -> 
             RGBColor[
              0.8720303151966338, 0.8973905806682567, 0.8034001864923321], 
             UndirectedEdge[237, 267] -> 
             RGBColor[
              0.33688926713479533`, 0.46453212671992494`, 0.942749002554194], 
             UndirectedEdge[256, 442] -> 
             RGBColor[
              0.9911242983323633, 0.9882517289312971, 0.6262307435310684], 
             UndirectedEdge[60, 133] -> 
             RGBColor[
              0.7703859125303378, 0.8208404246222998, 0.977671614850926], 
             UndirectedEdge[77, 156] -> 
             RGBColor[
              0.7908075079414627, 0.8324388888455557, 0.7421832410413682], 
             UndirectedEdge[219, 498] -> 
             RGBColor[
              0.8464899786357308, 0.8802869726469374, 0.9520825229639706], 
             UndirectedEdge[102, 185] -> 
             RGBColor[
              0.6180652246819422, 0.7005119675313799, 0.9632807884308078], 
             UndirectedEdge[92, 169] -> 
             RGBColor[
              0.9065051648561786, 0.9252211967530793, 0.8685488897515703], 
             UndirectedEdge[53, 357] -> 
             RGBColor[
              0.9755168419224491, 0.9798821397188923, 0.8645759579877377], 
             UndirectedEdge[162, 289] -> 
             RGBColor[
              0.9305480489914351, 0.9467660463955077, 0.9692551546219657], 
             UndirectedEdge[169, 204] -> 
             RGBColor[
              0.8307230612718615, 0.867865286048767, 0.9837149080372922], 
             UndirectedEdge[176, 448] -> 
             RGBColor[
              0.9137825043907246, 0.9334714916771972, 0.970215963680536], 
             UndirectedEdge[377, 403] -> 
             RGBColor[
              0.9322974470406578, 0.9481467946902958, 0.9689305845423442], 
             UndirectedEdge[86, 357] -> 
             RGBColor[
              0.8794994381083725, 0.9063217739103913, 0.9679040765799806], 
             UndirectedEdge[12, 373] -> 
             RGBColor[
              0.9097317064324433, 0.9283381232361583, 0.8927157426486279], 
             UndirectedEdge[200, 469] -> 
             RGBColor[
              0.9216162594882219, 0.9391635205299602, 0.9517419377893199], 
             UndirectedEdge[112, 153] -> 
             RGBColor[
              0.9183812825389537, 0.9340629742828059, 0.8308102256770471], 
             UndirectedEdge[166, 243] -> 
             RGBColor[
              0.8111208566619652, 0.8515927924078128, 0.905080184865843], 
             UndirectedEdge[394, 460] -> 
             RGBColor[
              0.8307123942435525, 0.8685805177694934, 0.9818494083058935], 
             UndirectedEdge[18, 348] -> 
             RGBColor[
              0.8362010745748556, 0.8704477745854824, 0.8682828503405449], 
             UndirectedEdge[315, 325] -> 
             RGBColor[
              0.9708893819789809, 0.9770282534141764, 0.8991558209547295], 
             UndirectedEdge[195, 447] -> 
             RGBColor[
              0.9816426596818081, 0.9567553061548775, 0.5893807090989396], 
             UndirectedEdge[128, 204] -> 
             RGBColor[
              0.9175230510812129, 0.9321183929132109, 0.728568344222593], 
             UndirectedEdge[91, 435] -> 
             RGBColor[
              0.7720770893597826, 0.8178161247628035, 0.7885268250651409], 
             UndirectedEdge[158, 206] -> 
             RGBColor[
              0.8223185929771863, 0.8588814758571491, 0.8245619659732324], 
             UndirectedEdge[30, 290] -> 
             RGBColor[
              0.8567294350273142, 0.8844939062888124, 0.7263047513492643], 
             UndirectedEdge[2, 250] -> 
             RGBColor[
              0.5999405801660692, 0.6847248686790988, 0.9625873580865101], 
             UndirectedEdge[148, 195] -> 
             RGBColor[
              0.9841004895633463, 0.9577716819742405, 0.5486481073020129], 
             UndirectedEdge[5, 202] -> 
             RGBColor[
              0.7489365215465533, 0.8039913784764542, 0.9756379945405598], 
             UndirectedEdge[220, 359] -> 
             RGBColor[
              0.8118574852691974, 0.8524224215384606, 0.9148199988244533], 
             UndirectedEdge[175, 337] -> 
             RGBColor[
              0.8403140573506173, 0.8755466736558164, 0.955738147959555], 
             UndirectedEdge[263, 447] -> 
             RGBColor[
              0.9921524504656842, 0.9907134993094241, 0.7572311440748194], 
             UndirectedEdge[344, 387] -> 
             RGBColor[
              0.992079034760891, 0.9893721854260068, 0.6631552718146649], 
             UndirectedEdge[82, 470] -> 
             RGBColor[
              0.8485866953967285, 0.880528476442539, 0.8878799725243245], 
             UndirectedEdge[273, 446] -> 
             RGBColor[
              0.9625900267336354, 0.9690385847436827, 0.8127148747751083], 
             UndirectedEdge[68, 306] -> 
             RGBColor[
              0.9179874368415561, 0.9335534925085012, 0.8149296681268247], 
             UndirectedEdge[21, 33] -> 
             RGBColor[
              0.8575846037170682, 0.8895690522765534, 0.9862013287847279], 
             UndirectedEdge[77, 479] -> 
             RGBColor[
              0.7580647927115824, 0.8109681484491995, 0.9768560990474111], 
             UndirectedEdge[253, 311] -> 
             RGBColor[
              0.9421176088023335, 0.9563519879352731, 0.9828639695389364], 
             UndirectedEdge[308, 386] -> 
             RGBColor[
              0.8284967683171962, 0.866225178878367, 0.9500177491888648], 
             UndirectedEdge[151, 280] -> 
             RGBColor[
              0.876639519462654, 0.9008402841253655, 0.7917618981175044], 
             UndirectedEdge[305, 416] -> 
             RGBColor[
              0.4882658051083254, 0.5736040253057928, 0.9569812157868419], 
             UndirectedEdge[38, 189] -> 
             RGBColor[
              0.9663309970645628, 0.973750475794241, 0.9123290450746243], 
             UndirectedEdge[277, 291] -> 
             RGBColor[
              0.88165328444368, 0.9084704134472581, 0.9885740714030583], 
             UndirectedEdge[27, 40] -> 
             RGBColor[
              0.8134475103468843, 0.8550429984716506, 0.9818143152893053], 
             UndirectedEdge[88, 167] -> 
             RGBColor[
              0.9639487637652642, 0.972363962756545, 0.9338333777453169], 
             UndirectedEdge[89, 296] -> 
             RGBColor[
              0.814986362934131, 0.8557198818648316, 0.9511583312291243], 
             UndirectedEdge[169, 340] -> 
             RGBColor[
              0.9025720546209914, 0.9235947545945069, 0.9337307049116297], 
             UndirectedEdge[169, 363] -> 
             RGBColor[
              0.8709809534002098, 0.8999658364605412, 0.9875547417271386], 
             UndirectedEdge[43, 378] -> 
             RGBColor[
              0.9589453606567464, 0.9689020977153794, 0.9543789750300107], 
             UndirectedEdge[350, 482] -> 
             RGBColor[
              0.8007196950212125, 0.8447094287284119, 0.9806493532745203], 
             UndirectedEdge[199, 429] -> 
             RGBColor[
              0.9053505569160331, 0.927365975271387, 0.9908343384062762], 
             UndirectedEdge[135, 216] -> 
             RGBColor[
              0.9869170811270909, 0.9888578910774426, 0.866481353440214], 
             UndirectedEdge[153, 351] -> 
             RGBColor[
              0.9946450512955711, 0.9909546311266192, 0.6585250643146678], 
             UndirectedEdge[207, 218] -> 
             RGBColor[
              0.9777119818006232, 0.9426693017155523, 0.5683952313785541], 
             UndirectedEdge[218, 389] -> 
             RGBColor[
              0.9923282694632478, 0.9906075111038354, 0.7413282096346174], 
             UndirectedEdge[421, 477] -> 
             RGBColor[
              0.9690417880317913, 0.974921502389388, 0.8696453347947836], 
             UndirectedEdge[171, 391] -> 
             RGBColor[
              0.7584140889680444, 0.8114762635875413, 0.9766251546988056], 
             UndirectedEdge[25, 246] -> 
             RGBColor[
              0.9685134363664569, 0.9452372977590922, 0.6447197639334383], 
             UndirectedEdge[130, 254] -> 
             RGBColor[
              0.9826300749100902, 0.9530693053986836, 0.3870215503711608], 
             UndirectedEdge[65, 434] -> 
             RGBColor[
              0.973610473709486, 0.9783175415308374, 0.8614066379764993], 
             UndirectedEdge[174, 430] -> 
             RGBColor[
              0.95390713131284, 0.9651445945200373, 0.9629073831285797], 
             UndirectedEdge[213, 454] -> 
             RGBColor[
              0.8670092607742412, 0.8947585864661765, 0.8823822710299299], 
             UndirectedEdge[52, 495] -> 
             RGBColor[
              0.41585272278667335`, 0.5346124599374016, 0.9477187456652106], 
             UndirectedEdge[26, 224] -> 
             RGBColor[
              0.9937193338581207, 0.9889746151323029, 0.5577664341139897], 
             UndirectedEdge[8, 31] -> 
             RGBColor[
              0.8694739996778852, 0.8979817879443008, 0.9414724631507002], 
             UndirectedEdge[29, 321] -> 
             RGBColor[
              0.9611940746806348, 0.9705791849524641, 0.9505724887461161], 
             UndirectedEdge[319, 377] -> 
             RGBColor[
              0.8638129749854657, 0.8942450349475777, 0.9868724467607016], 
             UndirectedEdge[323, 447] -> 
             RGBColor[
              0.8907296017117042, 0.9136866918243476, 0.9027751264589303], 
             UndirectedEdge[13, 340] -> 
             RGBColor[
              0.9702436177177145, 0.9770595668702768, 0.9232186885424901], 
             UndirectedEdge[176, 237] -> 
             RGBColor[
              0.6714649108560151, 0.7379129283221747, 0.9494058862622683], 
             UndirectedEdge[22, 268] -> 
             RGBColor[
              0.8500294324485589, 0.8796308298131466, 0.7553534868783152], 
             UndirectedEdge[461, 493] -> 
             RGBColor[
              0.8998912532548877, 0.9211865112718615, 0.9192262795971295], 
             UndirectedEdge[401, 450] -> 
             RGBColor[
              0.9908679685372548, 0.9890168310919707, 0.6937986470876771], 
             UndirectedEdge[100, 200] -> 
             RGBColor[
              0.9211456321258485, 0.9387882550460431, 0.9516970489313628], 
             UndirectedEdge[197, 375] -> 
             RGBColor[
              0.5720182884927316, 0.663225448832393, 0.959589855741916], 
             UndirectedEdge[94, 401] -> 
             RGBColor[
              0.98958264191387, 0.9899601689645634, 0.8223061129530946], 
             UndirectedEdge[118, 327] -> 
             RGBColor[
              0.8760819418698753, 0.9037042057466662, 0.9702061051741622], 
             UndirectedEdge[44, 255] -> 
             RGBColor[
              0.7966629392557802, 0.8414732483933927, 0.9802627966698155], 
             UndirectedEdge[148, 356] -> 
             RGBColor[
              0.947988862330354, 0.9581746848282775, 0.8673293897118632], 
             UndirectedEdge[26, 34] -> 
             RGBColor[
              0.9236780043061057, 0.9367752306626795, 0.7088121932049805], 
             UndirectedEdge[244, 313] -> 
             RGBColor[
              0.859502122624205, 0.8908076782896786, 0.9864612738141412], 
             UndirectedEdge[331, 488] -> 
             RGBColor[
              0.9073557777117283, 0.9279143366718056, 0.9546024661439058], 
             UndirectedEdge[382, 429] -> 
             RGBColor[
              0.9169904710233561, 0.9366473268235148, 0.9919445638049067], 
             UndirectedEdge[409, 496] -> 
             RGBColor[
              0.8823683274151937, 0.9090405693034187, 0.9886422728400077], 
             UndirectedEdge[14, 324] -> 
             RGBColor[
              0.9807148961094632, 0.9460199965132879, 0.42966244186873437`], 
             UndirectedEdge[259, 471] -> 
             RGBColor[
              0.9694025928521721, 0.9764323319026071, 0.9246423242654379], 
             UndirectedEdge[178, 439] -> 
             RGBColor[
              0.9083540922987261, 0.9297609128567503, 0.9911208182923652], 
             UndirectedEdge[127, 454] -> 
             RGBColor[
              0.9701740485746227, 0.9760549668742788, 0.8806719069064181], 
             UndirectedEdge[190, 452] -> 
             RGBColor[
              0.848138025400509, 0.8817462556337049, 0.9853773560760957], 
             UndirectedEdge[218, 295] -> 
             RGBColor[
              0.9402354526740302, 0.9528285154409819, 0.9029000764736606], 
             UndirectedEdge[35, 67] -> 
             RGBColor[
              0.9646542781157826, 0.9731597990088342, 0.9447152668960027], 
             UndirectedEdge[192, 249] -> 
             RGBColor[
              0.9462977316943071, 0.9559191348989857, 0.8007510821127146], 
             UndirectedEdge[186, 202] -> 
             RGBColor[
              0.9210172667463036, 0.9388682548596029, 0.9580071635884063], 
             UndirectedEdge[243, 469] -> 
             RGBColor[
              0.7480759182362808, 0.8033352033630408, 0.9755213263364252], 
             UndirectedEdge[48, 183] -> 
             RGBColor[
              0.8953634339134093, 0.9188949005410936, 0.9722824636993399], 
             UndirectedEdge[255, 390] -> 
             RGBColor[
              0.9260549836464567, 0.9267480506192138, 0.6884405862109559], 
             UndirectedEdge[202, 497] -> 
             RGBColor[
              0.9039885344219691, 0.9261682541741044, 0.9868323656088074], 
             UndirectedEdge[84, 365] -> 
             RGBColor[
              0.5943866646717806, 0.6814409741817983, 0.9613125777083855], 
             UndirectedEdge[239, 262] -> 
             RGBColor[
              0.9579772772873407, 0.8698997457460601, 0.2913015656396062], 
             UndirectedEdge[299, 456] -> 
             RGBColor[
              0.9138450464325935, 0.9318079678525967, 0.9013576187854774], 
             UndirectedEdge[136, 253] -> 
             RGBColor[
              0.904243312240472, 0.9264725908088807, 0.9903647695682812], 
             UndirectedEdge[338, 478] -> 
             RGBColor[
              0.9244300046104814, 0.9399030319060957, 0.8873820365990736], 
             UndirectedEdge[284, 444] -> 
             RGBColor[
              0.7779890832388091, 0.826688913223444, 0.9678041644455148], 
             UndirectedEdge[135, 147] -> 
             RGBColor[
              0.9631490729495484, 0.9717258404484193, 0.9333189982807641], 
             UndirectedEdge[72, 73] -> 
             RGBColor[
              0.871574003861318, 0.8998349241903945, 0.9521590062339615], 
             UndirectedEdge[8, 291] -> 
             RGBColor[
              0.838545116055849, 0.8746267138056323, 0.9843218405907863], 
             UndirectedEdge[141, 240] -> 
             RGBColor[
              0.9474192020786127, 0.9575206659739397, 0.8581941630002572], 
             UndirectedEdge[9, 466] -> 
             RGBColor[
              0.9185849148385036, 0.9373433583659576, 0.9721494289030035], 
             UndirectedEdge[78, 346] -> 
             RGBColor[
              0.8510794464749043, 0.8837831413078099, 0.9480267697370635], 
             UndirectedEdge[255, 425] -> 
             RGBColor[
              0.8223524814371344, 0.8615421139932186, 0.982823290152032], 
             UndirectedEdge[297, 349] -> 
             RGBColor[
              0.6452273413849894, 0.721358942428199, 0.9662425822735661], 
             UndirectedEdge[248, 478] -> 
             RGBColor[
              0.7358938871820142, 0.7934802686591389, 0.9745220429471453], 
             UndirectedEdge[113, 130] -> 
             RGBColor[
              0.9329042477807861, 0.9223762286716878, 0.6746278924339961], 
             UndirectedEdge[51, 179] -> 
             RGBColor[
              0.8094815324860887, 0.8513678011029921, 0.9479943682203371], 
             UndirectedEdge[440, 470] -> 
             RGBColor[
              0.9425567803697338, 0.9545404949484655, 0.8970863135600509], 
             UndirectedEdge[5, 414] -> 
             RGBColor[
              0.7860041113425138, 0.8333834587725959, 0.9734664149925658], 
             UndirectedEdge[148, 463] -> 
             RGBColor[
              0.9747650183660621, 0.9790215397190207, 0.8524188575037612], 
             UndirectedEdge[63, 441] -> 
             RGBColor[
              0.6356345633140761, 0.6536362333280539, 0.611966000876027], 
             UndirectedEdge[163, 187] -> 
             RGBColor[
              0.6585421355856416, 0.6865870273679395, 0.6312428919231102], 
             UndirectedEdge[120, 177] -> 
             RGBColor[
              0.8560649740149544, 0.8880300742165607, 0.9663520325899655], 
             UndirectedEdge[450, 454] -> 
             RGBColor[
              0.9925582985128965, 0.9897158259763975, 0.6657855049575434], 
             UndirectedEdge[15, 190] -> 
             RGBColor[
              0.9328493669896587, 0.9429160747617983, 0.7049038387237494], 
             UndirectedEdge[191, 287] -> 
             RGBColor[
              0.711651326312055, 0.7739593102021995, 0.9724291411884336], 
             UndirectedEdge[179, 292] -> 
             RGBColor[
              0.9293433102922292, 0.9455360234419052, 0.95980008188815], 
             UndirectedEdge[291, 297] -> 
             RGBColor[
              0.7362482682744218, 0.7932948111719857, 0.9750945396328128], 
             UndirectedEdge[289, 397] -> 
             RGBColor[
              0.8936665415379377, 0.9180494585630421, 0.9897199065890698], 
             UndirectedEdge[175, 370] -> 
             RGBColor[
              0.8457738937237735, 0.8798119393268193, 0.9562823334241595], 
             UndirectedEdge[23, 186] -> 
             RGBColor[
              0.9635588717491685, 0.9723428467341767, 0.9465695041469439], 
             UndirectedEdge[241, 461] -> 
             RGBColor[
              0.901633345777288, 0.9219069112996097, 0.8903552981100267], 
             UndirectedEdge[157, 216] -> 
             RGBColor[
              0.9128173518585578, 0.9313829897356871, 0.9183891774655497], 
             UndirectedEdge[51, 302] -> 
             RGBColor[
              0.6648712388877172, 0.7381217321184372, 0.9672318095834941], 
             UndirectedEdge[174, 390] -> 
             RGBColor[
              0.9731743492927526, 0.9636138544518424, 0.6684609010704623], 
             UndirectedEdge[79, 406] -> 
             RGBColor[
              0.9833446045011855, 0.9861267467398782, 0.869537313037386], 
             UndirectedEdge[181, 235] -> 
             RGBColor[
              0.8988658406074196, 0.9220367298764268, 0.9847202265511159], 
             UndirectedEdge[78, 404] -> 
             RGBColor[
              0.8574017849393312, 0.8874993502991189, 0.8925883037988056], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.9821113866725442, 0.9835627823297489, 0.7712387971366248], 
             UndirectedEdge[43, 384] -> 
             RGBColor[
              0.9809498841245536, 0.9853130352885697, 0.9171310564978838], 
             UndirectedEdge[101, 363] -> 
             RGBColor[
              0.9584311569264348, 0.9656096847186866, 0.8031799283402069], 
             UndirectedEdge[120, 455] -> 
             RGBColor[
              0.9762183130779583, 0.9795847689352045, 0.8143038790108752], 
             UndirectedEdge[295, 456] -> 
             RGBColor[
              0.8641987092169023, 0.8945526089532483, 0.986909238436045], 
             UndirectedEdge[58, 240] -> 
             RGBColor[
              0.9426910625322946, 0.9555793124068834, 0.9375586849145621], 
             UndirectedEdge[39, 471] -> 
             RGBColor[
              0.9702978530552052, 0.9768025450036991, 0.9098055458420431], 
             UndirectedEdge[54, 365] -> 
             RGBColor[
              0.654002296121974, 0.7280131585662698, 0.9672545067115901], 
             UndirectedEdge[169, 334] -> 
             RGBColor[
              0.9064539401470337, 0.923726056381599, 0.7622566553647214], 
             UndirectedEdge[18, 65] -> 
             RGBColor[
              0.8167020504886378, 0.8573467016085563, 0.9658325045363787], 
             UndirectedEdge[384, 435] -> 
             RGBColor[
              0.7656732451510122, 0.8155769897787313, 0.936972470656992], 
             UndirectedEdge[9, 360] -> 
             RGBColor[
              0.9159301300058088, 0.935363424184545, 0.9766432871459785], 
             UndirectedEdge[135, 171] -> 
             RGBColor[
              0.8030023368216136, 0.8454195107168275, 0.9219024992309002], 
             UndirectedEdge[149, 187] -> 
             RGBColor[
              0.9487997668421794, 0.8320196990605321, 0.291699340089098], 
             UndirectedEdge[271, 464] -> 
             RGBColor[
              0.9292576241200964, 0.9459222452516123, 0.9755512916588052], 
             UndirectedEdge[21, 348] -> 
             RGBColor[
              0.9619876631351928, 0.969611388459906, 0.8805817339495667], 
             UndirectedEdge[1, 70] -> 
             RGBColor[
              0.8808952541962134, 0.9078659807041112, 0.9885017698013534], 
             UndirectedEdge[52, 276] -> 
             RGBColor[
              0.7131757961409324, 0.7725117037321457, 0.928575737135658], 
             UndirectedEdge[58, 429] -> 
             RGBColor[
              0.9542185609659464, 0.9647710267522682, 0.9386581880058831], 
             UndirectedEdge[243, 495] -> 
             RGBColor[
              0.5119288206147397, 0.6129206845093766, 0.9551967419382559], 
             UndirectedEdge[131, 135] -> 
             RGBColor[
              0.9897259291256593, 0.9883834405999522, 0.7010129021707454], 
             UndirectedEdge[145, 430] -> 
             RGBColor[
              0.9464700303495606, 0.9595980167987587, 0.9754964551528256], 
             UndirectedEdge[291, 419] -> 
             RGBColor[
              0.8689152725547626, 0.8983521108843219, 0.9873488539653494], 
             UndirectedEdge[151, 260] -> 
             RGBColor[
              0.7998937035265952, 0.8437695785659056, 0.9806451984581364], 
             UndirectedEdge[189, 437] -> 
             RGBColor[
              0.9837444529652384, 0.9867374026930478, 0.8828526063914568], 
             UndirectedEdge[196, 354] -> 
             RGBColor[
              0.9776941868701722, 0.9800954435234857, 0.7649892790409214], 
             UndirectedEdge[340, 355] -> 
             RGBColor[
              0.741747429819704, 0.7957411172488937, 0.9192164497481243], 
             UndirectedEdge[58, 310] -> 
             RGBColor[
              0.9872021588425366, 0.9889757780389425, 0.8617568779377982], 
             UndirectedEdge[261, 500] -> 
             RGBColor[
              0.9926014129641094, 0.9888992910467445, 0.6044215420609141], 
             UndirectedEdge[237, 270] -> 
             RGBColor[
              0.6829944443064742, 0.7298802113735849, 0.6665050347293914], 
             UndirectedEdge[23, 497] -> 
             RGBColor[
              0.9465301394248342, 0.9596428460486782, 0.9753947061673449], 
             UndirectedEdge[431, 462] -> 
             RGBColor[
              0.9463854646158439, 0.9566079313098507, 0.8509246716886205], 
             UndirectedEdge[108, 129] -> 
             RGBColor[
              0.9277036824205495, 0.9450733463100744, 0.9889305831049923], 
             UndirectedEdge[376, 485] -> 
             RGBColor[
              0.8274809230015515, 0.8654152186518569, 0.949087642670781], 
             UndirectedEdge[124, 261] -> 
             RGBColor[
              0.9006960029273402, 0.9185706485753273, 0.7090392995793505], 
             UndirectedEdge[63, 158] -> 
             RGBColor[
              0.6556331057986235, 0.7199542730392123, 0.8123895731335666], 
             UndirectedEdge[66, 427] -> 
             RGBColor[
              0.986720172956491, 0.9731336063375164, 0.6039264491445331], 
             UndirectedEdge[66, 208] -> 
             RGBColor[
              0.9729830123473411, 0.9784250668535606, 0.8882401595494425], 
             UndirectedEdge[54, 230] -> 
             RGBColor[
              0.7628546894791091, 0.8146671484222386, 0.9769978842310381], 
             UndirectedEdge[186, 295] -> 
             RGBColor[
              0.9323089891649938, 0.9478719678106267, 0.9590841781529407], 
             UndirectedEdge[245, 394] -> 
             RGBColor[
              0.7905160712206705, 0.8371788447206481, 0.9778430144829682], 
             UndirectedEdge[49, 459] -> 
             RGBColor[
              0.9344635501551247, 0.9478361663495926, 0.8854148047295534], 
             UndirectedEdge[55, 365] -> 
             RGBColor[
              0.7528998665066642, 0.771018012582906, 0.645454082552412], 
             UndirectedEdge[197, 448] -> 
             RGBColor[
              0.6781395121318152, 0.746515482520224, 0.9700642428174714], 
             UndirectedEdge[185, 321] -> 
             RGBColor[
              0.8045464143201284, 0.8479698776229609, 0.9706574294313798], 
             UndirectedEdge[242, 339] -> 
             RGBColor[
              0.8486612085621383, 0.8794171069643555, 0.8237097988556957], 
             UndirectedEdge[186, 191] -> 
             RGBColor[
              0.9045903932605184, 0.92576991183764, 0.956440353730889], 
             UndirectedEdge[218, 456] -> 
             RGBColor[
              0.9139035228330021, 0.9318321493469406, 0.900388513498632], 
             UndirectedEdge[63, 182] -> 
             RGBColor[
              0.6407701828206029, 0.7109964734004646, 0.9426306144944476], 
             UndirectedEdge[133, 181] -> 
             RGBColor[
              0.8988439320796375, 0.9220192606110645, 0.9847181368961782], 
             UndirectedEdge[11, 186] -> 
             RGBColor[
              0.8934779713676855, 0.9169666793602439, 0.9553651793325959], 
             UndirectedEdge[105, 148] -> 
             RGBColor[
              0.9574389501353642, 0.9657099283281927, 0.8682307475228981], 
             UndirectedEdge[235, 393] -> 
             RGBColor[
              0.8771927403304753, 0.9049136966496331, 0.9881486207235661], 
             UndirectedEdge[110, 290] -> 
             RGBColor[
              0.8551473983023621, 0.8794661337896086, 0.6938999615125812], 
             UndirectedEdge[225, 296] -> 
             RGBColor[
              0.8263140104321511, 0.860532181978348, 0.7071770770251342], 
             UndirectedEdge[38, 93] -> 
             RGBColor[
              0.9069995521277563, 0.9284539256574047, 0.9831243828692504], 
             UndirectedEdge[80, 486] -> 
             RGBColor[
              0.815095630068406, 0.8556023018389153, 0.9408964150800474], 
             UndirectedEdge[471, 500] -> 
             RGBColor[
              0.9727965618875951, 0.9778358253197803, 0.868395474038171], 
             UndirectedEdge[200, 213] -> 
             RGBColor[
              0.8618165864638749, 0.8921073663726927, 0.9458719425604871], 
             UndirectedEdge[191, 295] -> 
             RGBColor[
              0.8628120431534549, 0.893446919074303, 0.986776976989022], 
             UndirectedEdge[295, 300] -> 
             RGBColor[
              0.8754056008934707, 0.9034886801731734, 0.9879781617686665], 
             UndirectedEdge[191, 451] -> 
             RGBColor[
              0.9119426535398276, 0.9304890116761532, 0.9097722855585126], 
             UndirectedEdge[137, 145] -> 
             RGBColor[
              0.9573145215621928, 0.9676858205889152, 0.9571395602261323], 
             UndirectedEdge[332, 344] -> 
             RGBColor[
              0.9741120884986423, 0.9770626992837925, 0.7423914848212554], 
             UndirectedEdge[76, 392] -> 
             RGBColor[
              0.7268354945391219, 0.7865286795791, 0.9734078274979345], 
             UndirectedEdge[157, 465] -> 
             RGBColor[
              0.9128509476256454, 0.9313968824487497, 0.9178324086618502], 
             UndirectedEdge[204, 337] -> 
             RGBColor[
              0.7774905970723772, 0.8262796804344175, 0.9784091934915489], 
             UndirectedEdge[112, 395] -> 
             RGBColor[
              0.8913088033122505, 0.9160413175354825, 0.9850521708832914], 
             UndirectedEdge[51, 107] -> 
             RGBColor[
              0.8194571238548769, 0.8553208533573561, 0.7181333019432221], 
             UndirectedEdge[5, 41] -> 
             RGBColor[
              0.7923387975294516, 0.8381078573587173, 0.9627434436288438], 
             UndirectedEdge[88, 210] -> 
             RGBColor[
              0.8879241796081399, 0.9133060453982473, 0.983465075628578], 
             UndirectedEdge[248, 411] -> 
             RGBColor[
              0.7810044059418005, 0.8291468970051107, 0.9683099960824135], 
             UndirectedEdge[101, 128] -> 
             RGBColor[
              0.9935846403908313, 0.9886865194253691, 0.5431058814312542], 
             UndirectedEdge[298, 418] -> 
             RGBColor[
              0.9072667557353398, 0.9288939001960708, 0.9910171071602726], 
             UndirectedEdge[1, 391] -> 
             RGBColor[
              0.8810308437498311, 0.9079740961336855, 0.9885147024540197], 
             UndirectedEdge[116, 327] -> 
             RGBColor[
              0.9712217709059061, 0.9776161288127326, 0.9138181848100994], 
             UndirectedEdge[79, 81] -> 
             RGBColor[
              0.7159961791794762, 0.7754064926535587, 0.9373419440563358], 
             UndirectedEdge[254, 368] -> 
             RGBColor[
              0.7025410800904813, 0.7554602328827466, 0.6809336998323787], 
             UndirectedEdge[4, 318] -> 
             RGBColor[
              0.9880000053788088, 0.9697193054253967, 0.5323738009293608], 
             UndirectedEdge[352, 412] -> 
             RGBColor[
              0.9313399528010772, 0.9443701714599828, 0.8299633366286789], 
             UndirectedEdge[239, 424] -> 
             RGBColor[
              0.7531926724175317, 0.7597079981859289, 0.6283178310793602], 
             UndirectedEdge[58, 188] -> 
             RGBColor[
              0.8701362172766307, 0.898255631939598, 0.9304978037752775], 
             UndirectedEdge[407, 408] -> 
             RGBColor[
              0.6009487289769955, 0.6858261288181913, 0.9624733716790499], 
             UndirectedEdge[255, 466] -> 
             RGBColor[
              0.9134220305075973, 0.9332266145432546, 0.9716569883865604], 
             UndirectedEdge[197, 489] -> 
             RGBColor[
              0.6785025783745603, 0.7468049816870184, 0.9700988723998175], 
             UndirectedEdge[50, 363] -> 
             RGBColor[
              0.8361474254522562, 0.872753619682982, 0.9840828611991128], 
             UndirectedEdge[57, 175] -> 
             RGBColor[
              0.8355781387518508, 0.8718469380521454, 0.9552661158533056], 
             UndirectedEdge[278, 486] -> 
             RGBColor[
              0.8738207365900151, 0.9014788013809365, 0.9467495848807994], 
             UndirectedEdge[82, 263] -> 
             RGBColor[
              0.8507161847143524, 0.8810997234683738, 0.8301022328662335], 
             UndirectedEdge[41, 186] -> 
             RGBColor[
              0.9644195427292017, 0.972984733741866, 0.9451126126766904], 
             UndirectedEdge[390, 425] -> 
             RGBColor[
              0.8795732263936511, 0.8900413102854792, 0.6839124969876185], 
             UndirectedEdge[218, 458] -> 
             RGBColor[
              0.898426260305131, 0.9195966543803071, 0.8988842410446434], 
             UndirectedEdge[230, 374] -> 
             RGBColor[
              0.795092544901438, 0.5418471405969066, 0.5790012469603982], 
             UndirectedEdge[104, 408] -> 
             RGBColor[
              0.7281126848776127, 0.7493700611722987, 0.6412372701069378], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.8085000433043423, 0.8507664865480473, 0.9814304009265467], 
             UndirectedEdge[143, 421] -> 
             RGBColor[
              0.9766082809397845, 0.9805645804111744, 0.8568372359589612], 
             UndirectedEdge[185, 482] -> 
             RGBColor[
              0.6931367863498032, 0.7602029926219362, 0.9700490551979559], 
             UndirectedEdge[256, 333] -> 
             RGBColor[
              0.9228466529880566, 0.7107527527167289, 0.510929972030487], 
             UndirectedEdge[351, 463] -> 
             RGBColor[
              0.9748548646298555, 0.9783640962476207, 0.8004399877412486], 
             UndirectedEdge[42, 411] -> 
             RGBColor[
              0.8873281815927394, 0.9126921475722685, 0.9786006197445004], 
             UndirectedEdge[52, 243] -> 
             RGBColor[
              0.5380020732472333, 0.6355040254598614, 0.9568581065403263], 
             UndirectedEdge[385, 391] -> 
             RGBColor[
              0.8412672379394774, 0.8765452277207613, 0.9846483605986923], 
             UndirectedEdge[366, 435] -> 
             RGBColor[
              0.5511941434564878, 0.6465232625279917, 0.9578111685450217], 
             UndirectedEdge[114, 419] -> 
             RGBColor[
              0.844821615780214, 0.8791404829771875, 0.9850507794735317], 
             UndirectedEdge[67, 391] -> 
             RGBColor[
              0.9328526651782173, 0.9484414242517256, 0.9638492963983183], 
             UndirectedEdge[310, 327] -> 
             RGBColor[
              0.9720937820612552, 0.977976727835134, 0.8993667032734338], 
             UndirectedEdge[309, 348] -> 
             RGBColor[
              0.982794265604982, 0.9852473047169221, 0.8494661071654084], 
             UndirectedEdge[28, 194] -> 
             RGBColor[
              0.9862685283871894, 0.9885896978524482, 0.8772295507410689], 
             UndirectedEdge[92, 337] -> 
             RGBColor[
              0.8532727006566944, 0.8836355911387299, 0.8632431752058269], 
             UndirectedEdge[205, 432] -> 
             RGBColor[
              0.8290715818780768, 0.866269731656643, 0.9306719846457889], 
             UndirectedEdge[314, 398] -> 
             RGBColor[
              0.9514448317355528, 0.9633082155269421, 0.9670754140423444], 
             UndirectedEdge[235, 453] -> 
             RGBColor[
              0.9252748343241447, 0.9394594349321561, 0.8233394932767583], 
             UndirectedEdge[92, 334] -> 
             RGBColor[
              0.9936246579479575, 0.9901576888318986, 0.6481782864834066], 
             UndirectedEdge[35, 54] -> 
             RGBColor[
              0.8658697873363086, 0.895639639324939, 0.9647967957217102], 
             UndirectedEdge[191, 456] -> 
             RGBColor[
              0.8364801133124268, 0.8724505529802618, 0.9842654140139935], 
             UndirectedEdge[78, 137] -> 
             RGBColor[
              0.8455144136861785, 0.8796327489658831, 0.9574469186553682], 
             UndirectedEdge[57, 169] -> 
             RGBColor[
              0.761366064257004, 0.8135042230847593, 0.9768495119808923], 
             UndirectedEdge[343, 392] -> 
             RGBColor[
              0.8732917252290537, 0.9015881839360933, 0.9731533281231411], 
             UndirectedEdge[24, 197] -> 
             RGBColor[
              0.7300418787400942, 0.7869724043367263, 0.9428190211033176], 
             UndirectedEdge[450, 471] -> 
             RGBColor[
              0.9732839591717475, 0.9765625231595663, 0.7531117622987707], 
             UndirectedEdge[150, 267] -> 
             RGBColor[
              0.44315503877754875`, 0.5527054411204136, 0.9505891123447616], 
             UndirectedEdge[40, 371] -> 
             RGBColor[
              0.7922690518829236, 0.8381558705664287, 0.9797942950147795], 
             UndirectedEdge[217, 362] -> 
             RGBColor[
              0.8918334340179412, 0.9141196906787915, 0.8834178033599729], 
             UndirectedEdge[229, 478] -> 
             RGBColor[
              0.9255494294793968, 0.9391394138280299, 0.7796745570132477], 
             UndirectedEdge[100, 168] -> 
             RGBColor[
              0.6788989875499013, 0.7471810656570032, 0.9700676256013204], 
             UndirectedEdge[221, 297] -> 
             RGBColor[
              0.691448069627762, 0.7575723488401358, 0.9708214566922849], 
             UndirectedEdge[50, 338] -> 
             RGBColor[
              0.8706443931803429, 0.8975841882950814, 0.8821010962161012], 
             UndirectedEdge[5, 186] -> 
             RGBColor[
              0.8020065940723071, 0.845318084190815, 0.946378385846961], 
             UndirectedEdge[147, 391] -> 
             RGBColor[
              0.9185608250959794, 0.937782593319133, 0.9880416537486695], 
             UndirectedEdge[24, 426] -> 
             RGBColor[
              0.9806843057327788, 0.9842067125884646, 0.8769071071510599], 
             UndirectedEdge[100, 127] -> 
             RGBColor[
              0.9049681528109232, 0.926723117461163, 0.9790813016491768], 
             UndirectedEdge[418, 432] -> 
             RGBColor[
              0.9375050503777753, 0.9515423694355065, 0.9413300604745495], 
             UndirectedEdge[200, 259] -> 
             RGBColor[
              0.9834842578829548, 0.9869344146259547, 0.9008057384547677], 
             UndirectedEdge[17, 293] -> 
             RGBColor[
              0.728142460176262, 0.7875496910681405, 0.9735380936183564], 
             UndirectedEdge[269, 468] -> 
             RGBColor[
              0.8621975524907051, 0.892956940899731, 0.9867183663210466], 
             UndirectedEdge[154, 390] -> 
             RGBColor[
              0.9869718506046503, 0.9728281140045478, 0.596924583839912], 
             UndirectedEdge[162, 439] -> 
             RGBColor[
              0.9432295086089213, 0.9568778980654401, 0.9704647235611541], 
             UndirectedEdge[103, 304] -> 
             RGBColor[
              0.8866383038529356, 0.5504004182283067, 0.5618272307225357], 
             UndirectedEdge[3, 480] -> 
             RGBColor[
              0.84578290892613, 0.8802290700393569, 0.9770418177843827], 
             UndirectedEdge[358, 404] -> 
             RGBColor[
              0.9854161692853204, 0.9876450027650172, 0.864834404666492], 
             UndirectedEdge[3, 439] -> 
             RGBColor[
              0.8354528483411131, 0.8722215848439558, 0.984010826208375], 
             UndirectedEdge[336, 458] -> 
             RGBColor[
              0.8553339005599254, 0.8875897052129873, 0.9860356677352696], 
             UndirectedEdge[212, 287] -> 
             RGBColor[
              0.7878326782370553, 0.8328272838336839, 0.9091363493737685], 
             UndirectedEdge[190, 195] -> 
             RGBColor[
              0.9239899135898311, 0.9130310581455983, 0.6704865352328099], 
             UndirectedEdge[253, 377] -> 
             RGBColor[
              0.9188140047881468, 0.9380908655354836, 0.9917545352308892], 
             UndirectedEdge[192, 327] -> 
             RGBColor[
              0.9269884515267548, 0.9441064359627096, 0.9751118316594087], 
             UndirectedEdge[151, 483] -> 
             RGBColor[
              0.8762187121177598, 0.9016249377021122, 0.8684208248046219], 
             UndirectedEdge[38, 163] -> 
             RGBColor[
              0.6482523322353018, 0.7187197193143695, 0.9612421628618361], 
             UndirectedEdge[88, 227] -> 
             RGBColor[
              0.9503970748985795, 0.9625268001934719, 0.9688489930685912], 
             UndirectedEdge[281, 343] -> 
             RGBColor[
              0.9684305757553071, 0.9758639946938925, 0.9333001852387186], 
             UndirectedEdge[76, 157] -> 
             RGBColor[
              0.7484741779104205, 0.8035775233371518, 0.9755262127998445], 
             UndirectedEdge[364, 437] -> 
             RGBColor[
              0.9840804225329489, 0.98687633474332, 0.8772847211931226], 
             UndirectedEdge[229, 244] -> 
             RGBColor[
              0.9394817156691978, 0.9502486406539432, 0.7810034309075295], 
             UndirectedEdge[154, 425] -> 
             RGBColor[
              0.883269348395328, 0.9076221773785524, 0.891307287780988], 
             UndirectedEdge[128, 355] -> 
             RGBColor[
              0.7453098120633188, 0.7951890338216105, 0.7129664396546804], 
             UndirectedEdge[58, 382] -> 
             RGBColor[
              0.9485815722441376, 0.9602762449574805, 0.9381205269893977], 
             UndirectedEdge[45, 179] -> 
             RGBColor[
              0.667263316582815, 0.7334727702800701, 0.9374487907581828], 
             UndirectedEdge[181, 296] -> 
             RGBColor[
              0.8008832387492104, 0.8452017949394643, 0.9750312417903061], 
             UndirectedEdge[350, 354] -> 
             RGBColor[
              0.9192955457626373, 0.93782087093851, 0.9691271816067113], 
             UndirectedEdge[318, 335] -> 
             RGBColor[
              0.906677156221068, 0.9085264830843309, 0.6825169642330409], 
             UndirectedEdge[354, 372] -> 
             RGBColor[
              0.9750796422876606, 0.9721519643739331, 0.6803440900049261], 
             UndirectedEdge[44, 57] -> 
             RGBColor[
              0.7139446606401869, 0.7764582621632856, 0.9721229896465806], 
             UndirectedEdge[257, 420] -> 
             RGBColor[
              0.9041692450060008, 0.8989900930991347, 0.6711903587710788], 
             UndirectedEdge[84, 171] -> 
             RGBColor[
              0.6359768897107925, 0.7152057924867545, 0.9645867125734706], 
             UndirectedEdge[376, 497] -> 
             RGBColor[0.956890993302835, 0.96736995390655, 0.957856483095364],
              UndirectedEdge[164, 443] -> 
             RGBColor[
              0.9476824992080357, 0.960502274088174, 0.9734440616379514], 
             UndirectedEdge[2, 54] -> 
             RGBColor[
              0.7516155147747666, 0.8058870197223149, 0.9758776683325685], 
             UndirectedEdge[165, 324] -> 
             RGBColor[
              0.9089177374511077, 0.8933737682864881, 0.6578107538217846], 
             UndirectedEdge[82, 395] -> 
             RGBColor[
              0.8235886301722044, 0.8629602661902827, 0.9783495698717657], 
             UndirectedEdge[298, 420] -> 
             RGBColor[
              0.8789433019022536, 0.906309546929241, 0.9883155908490271], 
             UndirectedEdge[163, 437] -> 
             RGBColor[
              0.6656657881359773, 0.7317066462131763, 0.9317657241786685], 
             UndirectedEdge[156, 372] -> 
             RGBColor[
              0.9910495488791009, 0.9809129823602799, 0.46710866882227836`], 
             UndirectedEdge[272, 317] -> 
             RGBColor[
              0.9663266813517285, 0.9723012296848945, 0.8384764552609432], 
             UndirectedEdge[282, 441] -> 
             RGBColor[
              0.9718885854070307, 0.9242427462949903, 0.5580793272383358], 
             UndirectedEdge[209, 423] -> 
             RGBColor[
              0.9778698902791196, 0.9819052092719285, 0.872602058772142], 
             UndirectedEdge[222, 333] -> 
             RGBColor[
              0.9252634205247232, 0.711094341714728, 0.42306229214338315`], 
             UndirectedEdge[125, 455] -> 
             RGBColor[
              0.979719657019583, 0.9821960655139437, 0.8083770170144592], 
             UndirectedEdge[343, 433] -> 
             RGBColor[
              0.9450356218859481, 0.958528237315225, 0.9779245345280773], 
             UndirectedEdge[29, 77] -> 
             RGBColor[
              0.7817319014768427, 0.828819628605411, 0.9437484104307641], 
             UndirectedEdge[298, 353] -> 
             RGBColor[
              0.9416443766260896, 0.907227404439308, 0.6429231095538668], 
             UndirectedEdge[65, 337] -> 
             RGBColor[
              0.8333693393146557, 0.8703673143155284, 0.9674937441218865], 
             UndirectedEdge[93, 364] -> 
             RGBColor[
              0.929168066879535, 0.9442157166972253, 0.9110517195146063], 
             UndirectedEdge[170, 328] -> 
             RGBColor[
              0.8070907641675207, 0.8500757432515244, 0.9768943007155737], 
             UndirectedEdge[13, 244] -> 
             RGBColor[
              0.9198903798239637, 0.9384702302379182, 0.9752531760129741], 
             UndirectedEdge[114, 291] -> 
             RGBColor[
              0.8985338029706162, 0.9219304807111681, 0.9901841503295743], 
             UndirectedEdge[198, 373] -> 
             RGBColor[
              0.8957911367790243, 0.9190412879723491, 0.9655745782477756], 
             UndirectedEdge[54, 84] -> 
             RGBColor[
              0.7116309751414913, 0.7746507934670436, 0.9718923830986909], 
             UndirectedEdge[1, 385] -> 
             RGBColor[
              0.8254083394835067, 0.863899772570301, 0.983135724706556], 
             UndirectedEdge[97, 294] -> 
             RGBColor[
              0.8421481885672897, 0.8773640485396874, 0.9847015041885354], 
             UndirectedEdge[83, 489] -> 
             RGBColor[
              0.9292390012604494, 0.944078159656181, 0.9026292032435841], 
             UndirectedEdge[349, 359] -> 
             RGBColor[
              0.688649962247816, 0.7566113822114191, 0.969660970050189], 
             UndirectedEdge[47, 55] -> 
             RGBColor[
              0.9546273901289833, 0.9310821221141232, 0.6601606917687098], 
             UndirectedEdge[166, 309] -> 
             RGBColor[
              0.980442432656567, 0.9842747613534026, 0.8884420654692121], 
             UndirectedEdge[196, 482] -> 
             RGBColor[
              0.8591183361287473, 0.8869840013133876, 0.7765114507087305], 
             UndirectedEdge[114, 311] -> 
             RGBColor[
              0.9112846391616123, 0.931777112495997, 0.9802870522220786], 
             UndirectedEdge[101, 169] -> 
             RGBColor[
              0.9067846505814798, 0.9244334125609253, 0.7982524452459534], 
             UndirectedEdge[160, 353] -> 
             RGBColor[
              0.9500663870011127, 0.9137890347489961, 0.6383922576622495], 
             UndirectedEdge[80, 329] -> 
             RGBColor[
              0.7629008785681841, 0.8151650818816554, 0.9768799270874159], 
             UndirectedEdge[130, 386] -> 
             RGBColor[
              0.8299035465983948, 0.8413440295272618, 0.6645122807667239], 
             UndirectedEdge[216, 238] -> 
             RGBColor[
              0.9909311893609303, 0.9905178279900114, 0.7999571918263855], 
             UndirectedEdge[240, 382] -> 
             RGBColor[
              0.9054629725897041, 0.9274556124781301, 0.9908450607135857], 
             UndirectedEdge[424, 470] -> 
             RGBColor[
              0.7685123975205731, 0.8165032496956848, 0.8809043561420624], 
             UndirectedEdge[184, 225] -> 
             RGBColor[
              0.9755073231152392, 0.9776181413560121, 0.7015373909259248], 
             UndirectedEdge[169, 274] -> 
             RGBColor[
              0.9026578237712655, 0.9236302223423118, 0.9323092881281421], 
             UndirectedEdge[345, 375] -> 
             RGBColor[
              0.825064362119335, 0.8614537267381577, 0.8538432966275347], 
             UndirectedEdge[326, 434] -> 
             RGBColor[
              0.861062508815563, 0.8897806304489178, 0.866721290064294], 
             UndirectedEdge[59, 105] -> 
             RGBColor[
              0.9575901735457878, 0.9651837643672532, 0.8229324013952399], 
             UndirectedEdge[90, 306] -> 
             RGBColor[
              0.8693031970693932, 0.8986227890091929, 0.9873961090442458], 
             UndirectedEdge[44, 466] -> 
             RGBColor[
              0.8412507310734374, 0.8764510086096942, 0.9645684056810065], 
             UndirectedEdge[88, 434] -> 
             RGBColor[
              0.9677170806292088, 0.9739222586211123, 0.8713826152183204], 
             UndirectedEdge[174, 356] -> 
             RGBColor[
              0.9323767715414137, 0.9482100458939925, 0.9689381505840401], 
             UndirectedEdge[65, 88] -> 
             RGBColor[
              0.947975766892748, 0.9607209926472506, 0.9729476359441959], 
             UndirectedEdge[82, 195] -> 
             RGBColor[
              0.8402063939304762, 0.8471415303138272, 0.6622517978903537], 
             UndirectedEdge[150, 413] -> 
             RGBColor[
              0.7831466122599993, 0.8301254342708182, 0.9480782396677829], 
             UndirectedEdge[156, 307] -> 
             RGBColor[
              0.9911451861206246, 0.988987757629074, 0.6787582301945081], 
             UndirectedEdge[245, 460] -> 
             RGBColor[
              0.6836730787528231, 0.7528098723203335, 0.9691058012680647], 
             UndirectedEdge[101, 204] -> 
             RGBColor[
              0.9181732647980865, 0.9335091343069124, 0.7993400946503605], 
             UndirectedEdge[210, 428] -> 
             RGBColor[
              0.7941143788851712, 0.8391988500259657, 0.9800839972156599], 
             UndirectedEdge[25, 76] -> 
             RGBColor[
              0.8120874605236865, 0.8535430289453746, 0.9553133959998505], 
             UndirectedEdge[130, 421] -> 
             RGBColor[
              0.984462356706115, 0.9604918149679997, 0.5604181746189859], 
             UndirectedEdge[79, 493] -> 
             RGBColor[
              0.9820812706006891, 0.9856043257058227, 0.8904740251719433], 
             UndirectedEdge[194, 490] -> 
             RGBColor[
              0.9872376984792239, 0.9889904745920398, 0.861167894184258], 
             UndirectedEdge[214, 347] -> 
             RGBColor[
              0.8335795077004635, 0.8691950182453557, 0.9040807355283984], 
             UndirectedEdge[41, 202] -> 
             RGBColor[
              0.911349470203448, 0.9316580280275053, 0.974372221370289], 
             UndirectedEdge[85, 97] -> 
             RGBColor[
              0.9541302956062282, 0.9628349369186935, 0.8558371327124588], 
             UndirectedEdge[31, 114] -> 
             RGBColor[
              0.9294626865926523, 0.9452855548498366, 0.9473347728894881], 
             UndirectedEdge[247, 425] -> 
             RGBColor[
              0.7522034556521986, 0.8063463236042809, 0.9759362687846109], 
             UndirectedEdge[35, 281] -> 
             RGBColor[
              0.972680040883358, 0.9790332388285323, 0.9261069492149382], 
             UndirectedEdge[157, 288] -> 
             RGBColor[
              0.9157676611390866, 0.9326030184426759, 0.8694949175315201], 
             UndirectedEdge[208, 427] -> 
             RGBColor[
              0.9698153299949239, 0.9614722906440388, 0.6749186715636087], 
             UndirectedEdge[154, 313] -> 
             RGBColor[
              0.9122845157277555, 0.9304015330277307, 0.8941693980651109], 
             UndirectedEdge[189, 364] -> 
             RGBColor[
              0.9884995118163415, 0.9895122668340616, 0.8402563817199802], 
             UndirectedEdge[314, 373] -> 
             RGBColor[
              0.8924537851067547, 0.9165522965595823, 0.9712238441082075], 
             UndirectedEdge[156, 232] -> 
             RGBColor[
              0.9011053527754592, 0.9194339093156862, 0.7526095617827069], 
             UndirectedEdge[321, 383] -> 
             RGBColor[
              0.9636761681779862, 0.9724303262187337, 0.9463709518887637], 
             UndirectedEdge[15, 323] -> 
             RGBColor[
              0.8918502229960041, 0.9104500263733708, 0.7009334481049275], 
             UndirectedEdge[225, 235] -> 
             RGBColor[
              0.9242966122903604, 0.9373671169153106, 0.7168660617859441], 
             UndirectedEdge[170, 265] -> 
             RGBColor[
              0.8344149251838267, 0.8686409058233369, 0.8494449734730447], 
             UndirectedEdge[102, 485] -> 
             RGBColor[
              0.627690453263582, 0.7080312692538036, 0.9642401412629504], 
             UndirectedEdge[342, 463] -> 
             RGBColor[
              0.8465225141733134, 0.8806185302481311, 0.9675825524544154], 
             UndirectedEdge[70, 147] -> 
             RGBColor[
              0.9184252355423617, 0.9376744778895587, 0.9880287210960033], 
             UndirectedEdge[162, 381] -> 
             RGBColor[
              0.9455981249900693, 0.9587665684733886, 0.9706906443060768], 
             UndirectedEdge[212, 299] -> 
             RGBColor[
              0.9886397322941465, 0.9895702516051357, 0.8379325655237893], 
             UndirectedEdge[92, 361] -> 
             RGBColor[
              0.9727603815191634, 0.9776297001776217, 0.8604343784524375], 
             UndirectedEdge[82, 184] -> 
             RGBColor[
              0.8324081395991674, 0.8695378418802904, 0.9634204409083753], 
             UndirectedEdge[232, 376] -> 
             RGBColor[
              0.8912785035127027, 0.9152543734267384, 0.9554463892738461], 
             UndirectedEdge[293, 298] -> 
             RGBColor[
              0.7992727007380958, 0.8439645355849911, 0.980402827962884], 
             UndirectedEdge[225, 249] -> 
             RGBColor[
              0.9934593981430427, 0.9884186389212831, 0.5294740356650329], 
             UndirectedEdge[19, 34] -> 
             RGBColor[
              0.9117238282572258, 0.9315980832240753, 0.9619803193331633], 
             UndirectedEdge[338, 390] -> 
             RGBColor[
              0.9874485619021558, 0.9730252463769878, 0.5890242439509555], 
             UndirectedEdge[82, 342] -> 
             RGBColor[
              0.7221605517347935, 0.7828765787294774, 0.9729418728890233], 
             UndirectedEdge[54, 374] -> 
             RGBColor[
              0.8034844620140137, 0.5484029700261831, 0.5798376748312557], 
             UndirectedEdge[196, 350] -> 
             RGBColor[
              0.9355237353078953, 0.9471343300466605, 0.7840042660094976], 
             UndirectedEdge[19, 44] -> 
             RGBColor[
              0.8465717904742054, 0.8804194459983518, 0.9555612400700639], 
             UndirectedEdge[85, 408] -> 
             RGBColor[
              0.7417924455532678, 0.7938439259241195, 0.836485655714579], 
             UndirectedEdge[57, 255] -> 
             RGBColor[
              0.7861159600743467, 0.8332338680968461, 0.9792115723521344], 
             UndirectedEdge[106, 269] -> 
             RGBColor[
              0.9143144890867607, 0.9340794625121697, 0.9766384963551378], 
             UndirectedEdge[382, 416] -> 
             RGBColor[
              0.5451402411507736, 0.6187732725143635, 0.9624539513942107], 
             UndirectedEdge[246, 392] -> 
             RGBColor[
              0.8832614703818922, 0.8782229483928174, 0.6628141954315221], 
             UndirectedEdge[350, 414] -> 
             RGBColor[
              0.9096037340064156, 0.9305927335996051, 0.9855328908806522], 
             UndirectedEdge[146, 211] -> 
             RGBColor[
              0.8238308640572017, 0.8592787466341585, 0.7619081246106718], 
             UndirectedEdge[71, 487] -> 
             RGBColor[
              0.8998437503474199, 0.9202220865910622, 0.8771731433196117], 
             UndirectedEdge[415, 485] -> 
             RGBColor[
              0.8322724586450173, 0.8689887380893342, 0.9409768226590364], 
             UndirectedEdge[238, 433] -> 
             RGBColor[
              0.9660858301638424, 0.9725822907346112, 0.8686185109248784], 
             UndirectedEdge[141, 429] -> 
             RGBColor[
              0.9589467005122647, 0.9667123803193245, 0.8592936660915783], 
             UndirectedEdge[406, 493] -> 
             RGBColor[
              0.9887808904348048, 0.9896286241238967, 0.8355932098275236], 
             UndirectedEdge[257, 357] -> 
             RGBColor[
              0.9669073499467886, 0.9484267066363696, 0.6567516987371829], 
             UndirectedEdge[311, 488] -> 
             RGBColor[
              0.962283577603258, 0.9713917344482592, 0.9487282444859868], 
             UndirectedEdge[258, 381] -> 
             RGBColor[
              0.733246366476605, 0.7908139863760124, 0.974908569405037], 
             UndirectedEdge[168, 200] -> 
             RGBColor[
              0.7389122090032344, 0.7938616949766353, 0.9351479023891189], 
             UndirectedEdge[16, 254] -> 
             RGBColor[
              0.8984156492656015, 0.9129825516986192, 0.6977962503862409], 
             UndirectedEdge[325, 347] -> 
             RGBColor[
              0.833757241935073, 0.8692685159189282, 0.9011352192994644], 
             UndirectedEdge[154, 478] -> 
             RGBColor[
              0.9239532933129759, 0.9397058995336556, 0.89528237648803], 
             UndirectedEdge[302, 386] -> 
             RGBColor[
              0.6839579538903051, 0.7530324189428657, 0.9691341949594592], 
             UndirectedEdge[330, 414] -> 
             RGBColor[
              0.9632838004008539, 0.9720889833165824, 0.9448535415636183], 
             UndirectedEdge[50, 334] -> 
             RGBColor[0.87162041219908, 0.89651383960404, 0.7587847748366958],
              UndirectedEdge[72, 187] -> 
             RGBColor[
              0.9701534335401885, 0.9374542496832087, 0.6228253132947938], 
             UndirectedEdge[14, 149] -> 
             RGBColor[
              0.9629893856867033, 0.8792956542185416, 0.396904329302239], 
             UndirectedEdge[113, 214] -> 
             RGBColor[
              0.9393546183365122, 0.9523946071412719, 0.9144728744016808], 
             UndirectedEdge[63, 149] -> 
             RGBColor[
              0.6244570583778475, 0.6093211509386258, 0.6029723180345757], 
             UndirectedEdge[245, 445] -> 
             RGBColor[
              0.8166563155370289, 0.8557365433836304, 0.8916043935559693], 
             UndirectedEdge[207, 336] -> 
             RGBColor[
              0.9346196220554177, 0.9106623525482324, 0.6555466580691804], 
             UndirectedEdge[264, 394] -> 
             RGBColor[
              0.9600461218718717, 0.9697230436272888, 0.9525156734173084], 
             UndirectedEdge[255, 370] -> 
             RGBColor[
              0.7963117150462695, 0.84119886937152, 0.9802277899229883], 
             UndirectedEdge[330, 482] -> 
             RGBColor[
              0.8543997614156509, 0.8862056784453892, 0.9399700039574865], 
             UndirectedEdge[383, 482] -> 
             RGBColor[
              0.8522665402076611, 0.8846634412177089, 0.9457625776553398], 
             UndirectedEdge[358, 407] -> 
             RGBColor[
              0.8470753542564702, 0.8806008143165285, 0.9448790364077011], 
             UndirectedEdge[28, 142] -> 
             RGBColor[
              0.9905334040888218, 0.9892459742822535, 0.72605619379764], 
             UndirectedEdge[348, 375] -> 
             RGBColor[
              0.8242648573469753, 0.8611231109684514, 0.8670931597575616], 
             UndirectedEdge[41, 295] -> 
             RGBColor[
              0.9226411926221383, 0.940661740978529, 0.9754492359348234], 
             UndirectedEdge[83, 345] -> 
             RGBColor[
              0.9921565669494662, 0.9910245531136386, 0.7796495140088009], 
             UndirectedEdge[140, 425] -> 
             RGBColor[
              0.8732300904673883, 0.9012108095880442, 0.9564818792693576], 
             UndirectedEdge[160, 441] -> 
             RGBColor[
              0.9482708479883724, 0.9074109601919682, 0.6330902627598958], 
             UndirectedEdge[66, 394] -> 
             RGBColor[
              0.963721621010154, 0.971517936358423, 0.903917279325582], 
             UndirectedEdge[201, 271] -> 
             RGBColor[
              0.8844703802441969, 0.9107166891705618, 0.9888427685153627], 
             UndirectedEdge[192, 470] -> 
             RGBColor[
              0.9445242124640647, 0.9561092718959634, 0.8972739689895555], 
             UndirectedEdge[255, 379] -> 
             RGBColor[
              0.9053764017300188, 0.9272261977744446, 0.9852761392709419], 
             UndirectedEdge[82, 440] -> 
             RGBColor[
              0.8004790452676773, 0.8446614550458802, 0.9805882095624364], 
             UndirectedEdge[43, 362] -> 
             RGBColor[
              0.9860695720784292, 0.9878811492715168, 0.8524808960681279], 
             UndirectedEdge[127, 302] -> 
             RGBColor[
              0.816276763233855, 0.8571041425592616, 0.9703296312435491], 
             UndirectedEdge[137, 358] -> 
             RGBColor[
              0.9735287980321676, 0.9797784014317815, 0.9296930195230544], 
             UndirectedEdge[238, 328] -> 
             RGBColor[
              0.967275885745263, 0.9734698322386974, 0.8666040572417388], 
             UndirectedEdge[185, 196] -> 
             RGBColor[
              0.827940826636486, 0.8626278939401848, 0.7734039679329332], 
             UndirectedEdge[114, 208] -> 
             RGBColor[
              0.9152591577909208, 0.9347413019820583, 0.9735592289031374], 
             UndirectedEdge[249, 424] -> 
             RGBColor[
              0.7702859167508154, 0.8163131126987071, 0.7843814692652216], 
             UndirectedEdge[21, 65] -> 
             RGBColor[
              0.9424886390489748, 0.9565103154829798, 0.9781313881454007], 
             UndirectedEdge[369, 466] -> 
             RGBColor[
              0.9602625000289771, 0.9698844181025712, 0.9521494016377908], 
             UndirectedEdge[246, 459] -> 
             RGBColor[
              0.9819529023830251, 0.9539678428876588, 0.5640855837222032], 
             UndirectedEdge[46, 317] -> 
             RGBColor[
              0.9596685847301223, 0.9694414770451324, 0.9531547453208334], 
             UndirectedEdge[66, 305] -> 
             RGBColor[
              0.8937462327627794, 0.9159502165793119, 0.8988546843520253], 
             UndirectedEdge[56, 243] -> 
             RGBColor[
              0.7842393248677504, 0.8321709221814517, 0.978970624344389], 
             UndirectedEdge[281, 288] -> 
             RGBColor[
              0.9892678282940414, 0.9898299854424233, 0.8275233893451877], 
             UndirectedEdge[81, 329] -> 
             RGBColor[
              0.6662362339461215, 0.736785147223499, 0.9692039641530765], 
             UndirectedEdge[57, 140] -> 
             RGBColor[
              0.8369935691046007, 0.8729025636916717, 0.9528701614694601], 
             UndirectedEdge[184, 440] -> 
             RGBColor[
              0.9263782245721726, 0.9435498603862168, 0.9726267819441017], 
             UndirectedEdge[422, 446] -> 
             RGBColor[
              0.9010428249589829, 0.9239311067391042, 0.9904234630866551], 
             UndirectedEdge[232, 307] -> 
             RGBColor[
              0.8988447283882891, 0.9201176465567316, 0.9077264397043754], 
             UndirectedEdge[90, 261] -> 
             RGBColor[
              0.9448793175485277, 0.9537107213708559, 0.7132775602735121], 
             UndirectedEdge[118, 304] -> 
             RGBColor[
              0.8762642914107284, 0.9038402017356644, 0.9698974349658751], 
             UndirectedEdge[427, 460] -> 
             RGBColor[
              0.8537109461898894, 0.8701961877485868, 0.6818585781248445], 
             UndirectedEdge[299, 300] -> 
             RGBColor[
              0.925051938109162, 0.9407440390725217, 0.9024265421180988], 
             UndirectedEdge[106, 425] -> 
             RGBColor[
              0.8642019870474327, 0.8944776648396039, 0.9717641034528577], 
             UndirectedEdge[428, 495] -> 
             RGBColor[
              0.5721211212603565, 0.6600702189899395, 0.9611094187116604], 
             UndirectedEdge[230, 365] -> 
             RGBColor[
              0.6456103790093983, 0.7214573291369933, 0.9664180788407327], 
             UndirectedEdge[224, 463] -> 
             RGBColor[
              0.9750556298317015, 0.9787935127138938, 0.8222920409829864], 
             UndirectedEdge[251, 382] -> 
             RGBColor[
              0.7661254580533416, 0.8176320393795987, 0.9773526848406271], 
             UndirectedEdge[81, 278] -> 
             RGBColor[
              0.6107371248355543, 0.6929669711854909, 0.9637948924659571], 
             UndirectedEdge[42, 294] -> 
             RGBColor[
              0.7992216591189835, 0.8431355991672091, 0.9806071334887908], 
             UndirectedEdge[8, 419] -> 
             RGBColor[
              0.784832928865447, 0.8318367160716518, 0.9791884697347438], 
             UndirectedEdge[159, 164] -> 
             RGBColor[
              0.9396571348785014, 0.9541494293650059, 0.9742860278219299], 
             UndirectedEdge[346, 404] -> 
             RGBColor[
              0.983882679110291, 0.98650132830334, 0.8674302035345235], 
             UndirectedEdge[7, 194] -> 
             RGBColor[
              0.9276059811752921, 0.9436163298396281, 0.9389620009620864], 
             UndirectedEdge[268, 353] -> 
             RGBColor[
              0.8324882616478971, 0.8211064578210485, 0.6322683114195167], 
             UndirectedEdge[51, 423] -> 
             RGBColor[
              0.8184353753803475, 0.8569347908232148, 0.8830952238215821], 
             UndirectedEdge[14, 322] -> 
             RGBColor[
              0.9866099988362087, 0.9659055622465447, 0.45256380276540253`], 
             UndirectedEdge[109, 458] -> 
             RGBColor[
              0.899736273772341, 0.9177903986700098, 0.70650057223627], 
             UndirectedEdge[217, 384] -> 
             RGBColor[
              0.8867137460640658, 0.9115515766958444, 0.9480679637897289], 
             UndirectedEdge[202, 485] -> 
             RGBColor[
              0.7745784641206857, 0.8242135189194113, 0.9780635251842245], 
             UndirectedEdge[125, 457] -> 
             RGBColor[
              0.7264783332115676, 0.784311836049703, 0.9487738785421514], 
             UndirectedEdge[454, 475] -> 
             RGBColor[
              0.8954879532495711, 0.9170063574739834, 0.8852207609473585], 
             UndirectedEdge[30, 378] -> 
             RGBColor[
              0.9652358654621431, 0.9701639097300911, 0.7352857483991934], 
             UndirectedEdge[445, 460] -> 
             RGBColor[
              0.8568526385599109, 0.8871382164324757, 0.8956107873788945], 
             UndirectedEdge[173, 461] -> 
             RGBColor[
              0.7794618023632138, 0.8276407512260339, 0.9786531260410322], 
             UndirectedEdge[23, 41] -> 
             RGBColor[
              0.953891075206313, 0.9651326199020791, 0.9629345619288265], 
             UndirectedEdge[111, 444] -> 
             RGBColor[
              0.9693916890918277, 0.9755584673490758, 0.8858915092412138], 
             UndirectedEdge[139, 360] -> 
             RGBColor[
              0.9735467459468924, 0.9773302684927914, 0.798033594645766], 
             UndirectedEdge[53, 432] -> 
             RGBColor[
              0.9888949199729004, 0.9896757782683248, 0.8337034452822939], 
             UndirectedEdge[184, 260] -> 
             RGBColor[
              0.8994932140229288, 0.9221124827484203, 0.9700624656373826], 
             UndirectedEdge[244, 379] -> 
             RGBColor[
              0.9135108755846619, 0.9337124064217264, 0.9860520126489283], 
             UndirectedEdge[14, 187] -> 
             RGBColor[
              0.9792676774256981, 0.9411381880698423, 0.42404027056662374`], 
             UndirectedEdge[133, 332] -> 
             RGBColor[
              0.9053312333367952, 0.926857479266672, 0.9737368280269589], 
             UndirectedEdge[424, 440] -> 
             RGBColor[
              0.7204047473915219, 0.780636228299026, 0.9736125931801745], 
             UndirectedEdge[381, 419] -> 
             RGBColor[
              0.8719380127892888, 0.9007623618972351, 0.9876371656273506], 
             UndirectedEdge[39, 368] -> 
             RGBColor[
              0.7015315049440672, 0.761707561573972, 0.9014272481064293], 
             UndirectedEdge[40, 208] -> 
             RGBColor[
              0.82876707267528, 0.8667328789687133, 0.9650553081200243], 
             UndirectedEdge[436, 462] -> 
             RGBColor[
              0.9663012137384228, 0.97244258196982, 0.8512423337047905], 
             UndirectedEdge[103, 188] -> 
             RGBColor[
              0.7858908861832667, 0.4711191594964811, 0.5701897281800904], 
             UndirectedEdge[313, 411] -> 
             RGBColor[
              0.8906803551941902, 0.9153650798097368, 0.9789203530551275], 
             UndirectedEdge[181, 344] -> 
             RGBColor[
              0.9676247872414846, 0.9722244806281851, 0.7533727936904746], 
             UndirectedEdge[5, 485] -> 
             RGBColor[
              0.6555677914466892, 0.7306633482506234, 0.9664347474427792], 
             UndirectedEdge[371, 429] -> 
             RGBColor[
              0.9028547937731128, 0.9253759214869082, 0.9905962902897104], 
             UndirectedEdge[426, 448] -> 
             RGBColor[
              0.9287819391244997, 0.9437497907719623, 0.9041523288652136], 
             UndirectedEdge[32, 403] -> 
             RGBColor[
              0.9790025445436787, 0.9817745510679085, 0.8185813164346175], 
             UndirectedEdge[115, 484] -> 
             RGBColor[
              0.8344038019367139, 0.869773239393823, 0.9011826985121587], 
             UndirectedEdge[36, 251] -> 
             RGBColor[
              0.6329394395120675, 0.7128476039334372, 0.9642739238620595], 
             UndirectedEdge[243, 454] -> 
             RGBColor[
              0.8128111866376069, 0.8522917872922395, 0.8770670427357092], 
             UndirectedEdge[106, 139] -> 
             RGBColor[
              0.9734632445722282, 0.9772679933042878, 0.7981749406924259], 
             UndirectedEdge[220, 499] -> 
             RGBColor[
              0.976557490767757, 0.981570576372554, 0.9036700741757818], 
             UndirectedEdge[359, 419] -> 
             RGBColor[
              0.7259587019468463, 0.7857572532212254, 0.9733795565533931], 
             UndirectedEdge[115, 297] -> 
             RGBColor[
              0.6148888095915713, 0.697658250809799, 0.9632187209540971], 
             UndirectedEdge[155, 235] -> 
             RGBColor[
              0.8952460454527749, 0.9193089121102418, 0.9898705610825067], 
             UndirectedEdge[98, 261] -> 
             RGBColor[
              0.9702339038682052, 0.9736141149807596, 0.7048209308594672], 
             UndirectedEdge[386, 421] -> 
             RGBColor[
              0.8387250863699516, 0.8723429474038611, 0.8650608524388717], 
             UndirectedEdge[37, 58] -> 
             RGBColor[
              0.9672712437857096, 0.9748427752586031, 0.9282501422900941], 
             UndirectedEdge[71, 194] -> 
             RGBColor[
              0.8962972299098877, 0.9187555092487247, 0.9359481650702015], 
             UndirectedEdge[47, 339] -> 
             RGBColor[
              0.8213629210927927, 0.861229585672831, 0.9785357446472339], 
             UndirectedEdge[108, 410] -> 
             RGBColor[
              0.9525672991171636, 0.9626615950556822, 0.9040762989961758], 
             UndirectedEdge[193, 196] -> 
             RGBColor[
              0.990264536960952, 0.9890692210527292, 0.7257457883623029], 
             UndirectedEdge[131, 171] -> 
             RGBColor[
              0.8066620280343326, 0.8452969057740616, 0.7423333739913004], 
             UndirectedEdge[203, 258] -> 
             RGBColor[
              0.7384583656953558, 0.7948822695953668, 0.9723677334258277], 
             UndirectedEdge[164, 428] -> 
             RGBColor[
              0.8561654342290401, 0.8881049972797372, 0.9661819796517387], 
             UndirectedEdge[143, 325] -> 
             RGBColor[
              0.9744148459585634, 0.9796575386777316, 0.8931881300255642], 
             UndirectedEdge[101, 498] -> 
             RGBColor[
              0.857345179900389, 0.8858109223109631, 0.7933247808465839], 
             UndirectedEdge[35, 391] -> 
             RGBColor[
              0.9286913551433672, 0.9453379260412542, 0.9708933088438404], 
             UndirectedEdge[8, 221] -> 
             RGBColor[
              0.7937449174091893, 0.8389042514737823, 0.9800487576502586], 
             UndirectedEdge[240, 251] -> 
             RGBColor[
              0.7602349483414985, 0.8129351068290016, 0.9767908427657914], 
             UndirectedEdge[464, 485] -> 
             RGBColor[
              0.8182765957529703, 0.8585506464605677, 0.964668167829609], 
             UndirectedEdge[104, 452] -> 
             RGBColor[
              0.895025675252944, 0.8821405220849001, 0.6562560834375143], 
             UndirectedEdge[121, 475] -> 
             RGBColor[
              0.8369787357796721, 0.8730142575558542, 0.9842688908439752], 
             UndirectedEdge[168, 315] -> 
             RGBColor[
              0.7247736509350096, 0.7833171815191173, 0.9590807932720979], 
             UndirectedEdge[65, 320] -> 
             RGBColor[
              0.9715919798386664, 0.9774828424423272, 0.8948583051106682], 
             UndirectedEdge[323, 452] -> 
             RGBColor[
              0.8071388814068544, 0.8492802072452774, 0.9814069654572739], 
             UndirectedEdge[72, 322] -> 
             RGBColor[
              0.977495754950699, 0.9622216238599111, 0.6513488454935726], 
             UndirectedEdge[60, 327] -> 
             RGBColor[
              0.8202613267432501, 0.8600967169573586, 0.9646424279316468], 
             UndirectedEdge[1, 135] -> 
             RGBColor[
              0.9256190916034003, 0.9419173432629717, 0.9337920469861143], 
             UndirectedEdge[420, 439] -> 
             RGBColor[
              0.8785005605026855, 0.9059565169551207, 0.9882733617790964], 
             UndirectedEdge[134, 367] -> 
             RGBColor[
              0.6945943582047324, 0.7599775351031577, 0.9712407698558094], 
             UndirectedEdge[119, 345] -> 
             RGBColor[
              0.9797493241111684, 0.9428439859193805, 0.5300153245249178], 
             UndirectedEdge[64, 366] -> 
             RGBColor[
              0.6192382683294427, 0.7010966776952038, 0.9636244781933734], 
             UndirectedEdge[86, 90] -> 
             RGBColor[
              0.8488053311040648, 0.8824361745165532, 0.9853991217430728], 
             UndirectedEdge[81, 426] -> 
             RGBColor[
              0.7225031490571125, 0.7793511253637506, 0.885653837052883], 
             UndirectedEdge[70, 265] -> 
             RGBColor[
              0.9458621011205426, 0.9563236953390806, 0.8603886144282775], 
             UndirectedEdge[245, 438] -> 
             RGBColor[
              0.7252004992515454, 0.7852514088340208, 0.9732448664475686], 
             UndirectedEdge[121, 259] -> 
             RGBColor[
              0.9301677147234222, 0.9455935348013091, 0.9363641968208273], 
             UndirectedEdge[74, 105] -> 
             RGBColor[
              0.8246769894477477, 0.8637762850943708, 0.982943985286866], 
             UndirectedEdge[358, 430] -> 
             RGBColor[
              0.9626843068195354, 0.971690597641625, 0.9480499144497476], 
             UndirectedEdge[43, 316] -> 
             RGBColor[
              0.9597596467012401, 0.9695093909140917, 0.9530006011564967], 
             UndirectedEdge[162, 203] -> 
             RGBColor[
              0.95081012420882, 0.9628348516927431, 0.9681498083268676], 
             UndirectedEdge[226, 236] -> 
             RGBColor[
              0.9916301337488637, 0.9893771836611059, 0.6844515366099849], 
             UndirectedEdge[110, 340] -> 
             RGBColor[
              0.9878244765491895, 0.9828938143312977, 0.6499310721906952], 
             UndirectedEdge[145, 407] -> 
             RGBColor[
              0.8308610777864952, 0.8685082334736621, 0.972325577110779], 
             UndirectedEdge[258, 289] -> 
             RGBColor[
              0.7181962904779706, 0.7788134642981315, 0.9734730797209258], 
             UndirectedEdge[13, 334] -> 
             RGBColor[
              0.9741255032437568, 0.9771908686573689, 0.751744638995582], 
             UndirectedEdge[300, 389] -> 
             RGBColor[
              0.9274984176826884, 0.9412676758360269, 0.8264062949296234], 
             UndirectedEdge[57, 363] -> 
             RGBColor[
              0.8130125706019591, 0.8546804952425208, 0.9817769950751458], 
             UndirectedEdge[305, 427] -> 
             RGBColor[
              0.8905785504103623, 0.8989974403697902, 0.6855331963661916], 
             UndirectedEdge[277, 419] -> 
             RGBColor[
              0.8279410972532778, 0.8656804157132774, 0.9834407005470158], 
             UndirectedEdge[40, 349] -> 
             RGBColor[
              0.7210207909655432, 0.7819861889540363, 0.9728282721872145], 
             UndirectedEdge[28, 241] -> 
             RGBColor[
              0.9890350834356947, 0.9897337394622269, 0.8313805739723776], 
             UndirectedEdge[164, 396] -> 
             RGBColor[
              0.9095002533820311, 0.9301031506464617, 0.9714096375434305], 
             UndirectedEdge[111, 284] -> 
             RGBColor[
              0.7996180329874027, 0.841685263522896, 0.8803874376676892], 
             UndirectedEdge[25, 343] -> 
             RGBColor[
              0.9585436912136185, 0.968602533302368, 0.9550588966250573], 
             UndirectedEdge[84, 131] -> 
             RGBColor[
              0.822700482014838, 0.8581697223698792, 0.7436971155133159], 
             UndirectedEdge[169, 244] -> 
             RGBColor[
              0.8522188167272406, 0.8850054179621483, 0.9857651923821137], 
             UndirectedEdge[219, 363] -> 
             RGBColor[
              0.9475759556617767, 0.9600857350546609, 0.9619376704575936], 
             UndirectedEdge[400, 415] -> 
             RGBColor[
              0.9697638634570375, 0.9769705193901639, 0.9360660717065477], 
             UndirectedEdge[248, 286] -> 
             RGBColor[
              0.6709252969210551, 0.7424251969917004, 0.9681264877451956], 
             UndirectedEdge[136, 484] -> 
             RGBColor[
              0.9306398002486991, 0.9453770344144463, 0.9106622191127234], 
             UndirectedEdge[74, 263] -> 
             RGBColor[
              0.861848319659606, 0.8897962318949652, 0.8312117800418606], 
             UndirectedEdge[69, 142] -> 
             RGBColor[
              0.6797178079691915, 0.7402582847358468, 0.7663227569392245], 
             UndirectedEdge[109, 409] -> 
             RGBColor[
              0.9385238709874748, 0.9486129217740875, 0.7102282052221112], 
             UndirectedEdge[101, 219] -> 
             RGBColor[
              0.9833796528430466, 0.984553311155045, 0.7726353739764085], 
             UndirectedEdge[380, 390] -> 
             RGBColor[
              0.8697757497677754, 0.882387447081765, 0.6829359760801758], 
             UndirectedEdge[53, 293] -> 
             RGBColor[
              0.8331081358175035, 0.8681005148374074, 0.8711018551354907], 
             UndirectedEdge[221, 258] -> 
             RGBColor[
              0.685423427595419, 0.7526812730312492, 0.9703471748025079], 
             UndirectedEdge[235, 424] -> 
             RGBColor[
              0.7011231308981332, 0.7652615906927346, 0.9717734953861328], 
             UndirectedEdge[367, 457] -> 
             RGBColor[
              0.511920846297913, 0.6146394306527858, 0.954719430729871], 
             UndirectedEdge[58, 220] -> 
             RGBColor[
              0.9864051570978954, 0.988646197335523, 0.8749652594209008], 
             UndirectedEdge[334, 379] -> 
             RGBColor[
              0.967745999004455, 0.9724330448411771, 0.7625434756315361], 
             UndirectedEdge[14, 163] -> 
             RGBColor[
              0.6727317544301654, 0.7338629825259491, 0.7364478811362513], 
             UndirectedEdge[284, 442] -> 
             RGBColor[
              0.8003890340494102, 0.8396581376947836, 0.6970838218947615], 
             UndirectedEdge[130, 302] -> 
             RGBColor[
              0.8296952242264686, 0.8411812865070043, 0.6644915171395736], 
             UndirectedEdge[65, 428] -> 
             RGBColor[
              0.8541659661697792, 0.886613797274969, 0.9695665575312777], 
             UndirectedEdge[388, 487] -> 
             RGBColor[
              0.9936042341385563, 0.9916232006996771, 0.7556579222429891], 
             UndirectedEdge[456, 458] -> 
             RGBColor[
              0.8223895168480029, 0.8613207478925735, 0.982893403007028], 
             UndirectedEdge[281, 465] -> 
             RGBColor[
              0.9863511147806001, 0.9886238494484971, 0.8758608804755177], 
             UndirectedEdge[166, 428] -> 
             RGBColor[
              0.8713131573075822, 0.8987423268883756, 0.9109928616392475], 
             UndirectedEdge[92, 128] -> 
             RGBColor[
              0.99330515466553, 0.9894743036175233, 0.613402325936871], 
             UndirectedEdge[120, 457] -> 
             RGBColor[
              0.722976989269943, 0.7817005394709639, 0.9547007405385675], 
             UndirectedEdge[79, 329] -> 
             RGBColor[
              0.9268850394337151, 0.9434811028917445, 0.9562801484785466], 
             UndirectedEdge[105, 195] -> 
             RGBColor[
              0.9472422881382982, 0.9315718704416529, 0.6727043674748825], 
             UndirectedEdge[98, 377] -> 
             RGBColor[
              0.9246922530822745, 0.9424748534884959, 0.9818041941616262], 
             UndirectedEdge[21, 309] -> 
             RGBColor[0.9519147205947138, 0.963540271666, 0.9621754908042683],
              UndirectedEdge[93, 322] -> 
             RGBColor[
              0.9246316768886065, 0.921088607887677, 0.6816486441293035], 
             UndirectedEdge[8, 115] -> 
             RGBColor[
              0.7171856573729987, 0.7789901534434457, 0.9724460219120707], 
             UndirectedEdge[54, 131] -> 
             RGBColor[
              0.8823161134650315, 0.9047419067543507, 0.7496390445165206], 
             UndirectedEdge[186, 212] -> 
             RGBColor[
              0.9807717451855187, 0.9846378854691245, 0.893147561916224], 
             UndirectedEdge[252, 467] -> 
             RGBColor[
              0.9158254250973081, 0.9357183508264133, 0.9918334406844315], 
             UndirectedEdge[244, 378] -> 
             RGBColor[
              0.9112857764809787, 0.9320529311534649, 0.9898185250326732], 
             UndirectedEdge[55, 339] -> 
             RGBColor[
              0.8357772783248744, 0.8373801494434954, 0.6526085166620634], 
             UndirectedEdge[69, 490] -> 
             RGBColor[
              0.6772219992646844, 0.7403335629723009, 0.8881780955416538], 
             UndirectedEdge[299, 451] -> 
             RGBColor[
              0.9893075866599943, 0.9898464265484881, 0.8268644903299965], 
             UndirectedEdge[146, 464] -> 
             RGBColor[
              0.9745309693987019, 0.9775942979252601, 0.7590748486669119], 
             UndirectedEdge[199, 220] -> 
             RGBColor[
              0.9375371530479821, 0.9512411458546416, 0.9271414098212938], 
             UndirectedEdge[345, 426] -> 
             RGBColor[
              0.9920625710562615, 0.9909856833962142, 0.7812072692127766], 
             UndirectedEdge[66, 472] -> 
             RGBColor[
              0.95757863774464, 0.9666675593511346, 0.9049910772482874], 
             UndirectedEdge[40, 114] -> 
             RGBColor[
              0.7879480610804269, 0.8347104297906887, 0.9793821550546434], 
             UndirectedEdge[248, 294] -> 
             RGBColor[
              0.6928978834680446, 0.7595903486000515, 0.9703165098267039], 
             UndirectedEdge[304, 483] -> 
             RGBColor[
              0.9746433670151979, 0.9790916365026199, 0.8598268160613836], 
             UndirectedEdge[9, 425] -> 
             RGBColor[
              0.8275153657680407, 0.8656588578159214, 0.983315730668475], 
             UndirectedEdge[290, 384] -> 
             RGBColor[
              0.8509664595957094, 0.8836255248173246, 0.9445050083519482], 
             UndirectedEdge[294, 358] -> 
             RGBColor[
              0.8759369637938039, 0.9031477230434504, 0.9477556919193069], 
             UndirectedEdge[148, 342] -> 
             RGBColor[
              0.8660546473676636, 0.8935067303898905, 0.8593381823006826], 
             UndirectedEdge[178, 420] -> 
             RGBColor[
              0.8629189453494907, 0.8935321599836392, 0.9867871734159126], 
             UndirectedEdge[193, 354] -> 
             RGBColor[
              0.9740363474156941, 0.9797557619445787, 0.9108687039595165], 
             UndirectedEdge[194, 228] -> 
             RGBColor[
              0.9779029951262328, 0.9499310036590849, 0.6148762909891254], 
             UndirectedEdge[326, 491] -> 
             RGBColor[
              0.8597631296869597, 0.8892433037867198, 0.8882553649106444], 
             UndirectedEdge[324, 481] -> 
             RGBColor[
              0.9810334751646617, 0.9477258845832899, 0.5388066640701961], 
             UndirectedEdge[94, 213] -> 
             RGBColor[
              0.8667380304638387, 0.894646425762524, 0.8868772591948441], 
             UndirectedEdge[92, 175] -> 
             RGBColor[
              0.9807172393510254, 0.9835639117204654, 0.8469654936239834], 
             UndirectedEdge[254, 401] -> 
             RGBColor[
              0.9888914375671267, 0.9830095242448781, 0.6299988823568988], 
             UndirectedEdge[161, 491] -> 
             RGBColor[
              0.9906581599362924, 0.9851370295957529, 0.6103751812667149], 
             UndirectedEdge[172, 303] -> 
             RGBColor[
              0.8725008409890392, 0.8968916400500846, 0.7340433293408963], 
             UndirectedEdge[57, 274] -> 
             RGBColor[
              0.8446894409730148, 0.8783448811242915, 0.9265315414761492], 
             UndirectedEdge[44, 360] -> 
             RGBColor[
              0.8385959462407426, 0.8744710744282815, 0.9690622639239814], 
             UndirectedEdge[170, 238] -> 
             RGBColor[
              0.8339093328028768, 0.8684318303806826, 0.8578239476565228], 
             UndirectedEdge[5, 11] -> 
             RGBColor[
              0.7213972261679353, 0.7820898029770952, 0.9729960102847494], 
             UndirectedEdge[3, 223] -> 
             RGBColor[
              0.8709377596023283, 0.8972096099146178, 0.8547533641796966], 
             UndirectedEdge[65, 227] -> 
             RGBColor[
              0.9562904679788568, 0.966922083103197, 0.95887301582677], 
             UndirectedEdge[78, 85] -> 
             RGBColor[
              0.8599046864867533, 0.8884729589565581, 0.846645219575544], 
             UndirectedEdge[181, 393] -> 
             RGBColor[
              0.92017268368399, 0.939026228186836, 0.9867524922646027], 
             UndirectedEdge[45, 56] -> 
             RGBColor[
              0.6479784465553546, 0.7190566604997445, 0.9689320893928883], 
             UndirectedEdge[141, 310] -> 
             RGBColor[
              0.9919302983888549, 0.9909171316059988, 0.7823923560234934], 
             UndirectedEdge[39, 236] -> 
             RGBColor[
              0.9906124729967463, 0.988956354787417, 0.7013168088941746], 
             UndirectedEdge[337, 375] -> 
             RGBColor[
              0.6842660126023878, 0.7532730767500777, 0.9691648993729074], 
             UndirectedEdge[57, 334] -> 
             RGBColor[
              0.8484855573487831, 0.8784407151635787, 0.7564789087127286], 
             UndirectedEdge[123, 438] -> 
             RGBColor[
              0.88106645990262, 0.9076049517914611, 0.9710472655866884], 
             UndirectedEdge[35, 385] -> 
             RGBColor[
              0.8730688508770428, 0.9012636024778697, 0.9655143310963767], 
             UndirectedEdge[268, 285] -> 
             RGBColor[
              0.8318053795941028, 0.8690883044554422, 0.9644407563719625], 
             UndirectedEdge[169, 361] -> 
             RGBColor[
              0.8855896637182396, 0.9111980677273221, 0.9745127473337525], 
             UndirectedEdge[337, 361] -> 
             RGBColor[
              0.8323571995187553, 0.8696124621129726, 0.9692070327880091], 
             UndirectedEdge[119, 270] -> 
             RGBColor[
              0.9738757761939335, 0.9235390002219993, 0.35301275296948686`], 
             UndirectedEdge[254, 386] -> 
             RGBColor[
              0.8368928045739268, 0.8649204378345451, 0.6916642281910466], 
             UndirectedEdge[253, 488] -> 
             RGBColor[
              0.9562720542784344, 0.9669083501955718, 0.9589041854185227], 
             UndirectedEdge[340, 380] -> 
             RGBColor[
              0.8710427165596528, 0.8989637960691446, 0.9305881551520917], 
             UndirectedEdge[388, 490] -> 
             RGBColor[
              0.9918267806981494, 0.9908881780235991, 0.7851149256525793], 
             UndirectedEdge[27, 311] -> 
             RGBColor[
              0.9367840884280698, 0.9521096811769589, 0.9827192124567403], 
             UndirectedEdge[222, 417] -> 
             RGBColor[
              0.9709336537044918, 0.9754693691198772, 0.8094345841523463], 
             UndirectedEdge[274, 361] -> 
             RGBColor[
              0.9689130404342503, 0.9760387257668541, 0.9241947768290093], 
             UndirectedEdge[65, 474] -> 
             RGBColor[
              0.7453135728126442, 0.7999598074190002, 0.9598231800118298], 
             UndirectedEdge[243, 326] -> 
             RGBColor[
              0.6814257006302393, 0.7509273517124864, 0.968968532845668], 
             UndirectedEdge[47, 437] -> 
             RGBColor[
              0.9597691982893737, 0.9695165144728826, 0.9529844328092398], 
             UndirectedEdge[232, 414] -> 
             RGBColor[
              0.8754436344277972, 0.9034447539904346, 0.9822506922392955], 
             UndirectedEdge[102, 196] -> 
             RGBColor[
              0.7840467744608863, 0.8272929762228314, 0.7697431839415824], 
             UndirectedEdge[90, 257] -> 
             RGBColor[
              0.936213242942481, 0.9245411072425315, 0.6742467439002751], 
             UndirectedEdge[116, 310] -> 
             RGBColor[
              0.9877226443429961, 0.9891910121692499, 0.8531310862218878], 
             UndirectedEdge[333, 459] -> 
             RGBColor[
              0.9239898134556828, 0.7112254789479764, 0.4919848446774643], 
             UndirectedEdge[68, 257] -> 
             RGBColor[
              0.984897482714644, 0.9594718107418396, 0.5017803029828539], 
             UndirectedEdge[220, 349] -> 
             RGBColor[
              0.8637931289876815, 0.8930814104577705, 0.9199373388771629], 
             UndirectedEdge[92, 204] -> 
             RGBColor[
              0.9178937790727854, 0.9342969184990666, 0.8696365391559773], 
             UndirectedEdge[120, 123] -> 
             RGBColor[
              0.956437926347733, 0.967032057313264, 0.9586234072715648], 
             UndirectedEdge[190, 224] -> 
             RGBColor[
              0.9344771870525365, 0.9469410890270109, 0.8358860987600507], 
             UndirectedEdge[450, 469] -> 
             RGBColor[
              0.9278230301115704, 0.9407592420471987, 0.7642397885582592], 
             UndirectedEdge[405, 434] -> 
             RGBColor[
              0.9863393847042776, 0.9878107425090741, 0.8398599118940036], 
             UndirectedEdge[312, 400] -> 
             RGBColor[
              0.9302020608730109, 0.9466534178882018, 0.974882238885801], 
             UndirectedEdge[100, 259] -> 
             RGBColor[
              0.9234710364296217, 0.9402537853063224, 0.9357254616669692], 
             UndirectedEdge[87, 423] -> 
             RGBColor[
              0.9844158259328961, 0.9638953739288652, 0.5848475803531331], 
             UndirectedEdge[403, 449] -> 
             RGBColor[
              0.9065243633182973, 0.9275960373218064, 0.966472324809002], 
             UndirectedEdge[268, 275] -> 
             RGBColor[
              0.8403622234581245, 0.8754699845986836, 0.9499562516924811], 
             UndirectedEdge[166, 210] -> 
             RGBColor[
              0.9109647638262199, 0.9298298579213793, 0.9149154024947266], 
             UndirectedEdge[102, 496] -> 
             RGBColor[
              0.7272101892931652, 0.7862639446433841, 0.9740300767973754], 
             UndirectedEdge[11, 202] -> 
             RGBColor[
              0.8404078988419319, 0.8756399736458831, 0.9846247880261947], 
             UndirectedEdge[187, 494] -> 
             RGBColor[
              0.9791825632181285, 0.9426771386012459, 0.5398747348568291], 
             UndirectedEdge[158, 282] -> 
             RGBColor[
              0.9918871278915782, 0.9905607860061487, 0.7585028994958753], 
             UndirectedEdge[232, 372] -> 
             RGBColor[
              0.8987490911467655, 0.9120428712879374, 0.6960768783321456], 
             UndirectedEdge[143, 477] -> 
             RGBColor[
              0.9523661724939039, 0.9639953499559634, 0.9655158244626111], 
             UndirectedEdge[479, 482] -> 
             RGBColor[
              0.8261173379450495, 0.8649608197952277, 0.9830718031293393], 
             UndirectedEdge[45, 283] -> 
             RGBColor[
              0.6758438456005007, 0.7388853851186006, 0.8787364233995865], 
             UndirectedEdge[323, 463] -> 
             RGBColor[
              0.8736552983988923, 0.9018148675019511, 0.9702868948157364], 
             UndirectedEdge[130, 347] -> 
             RGBColor[
              0.8271291371447371, 0.8391766397757716, 0.6642357535607137], 
             UndirectedEdge[338, 369] -> 
             RGBColor[
              0.9770682864670189, 0.9811838536440437, 0.8684274503665994], 
             UndirectedEdge[143, 386] -> 
             RGBColor[
              0.8220494708320643, 0.8614167949704364, 0.9609313421066992], 
             UndirectedEdge[168, 254] -> 
             RGBColor[
              0.7431424486564547, 0.7894501096467812, 0.68384598842728], 
             UndirectedEdge[86, 115] -> 
             RGBColor[
              0.7401828975805915, 0.7969557722791163, 0.974738171894535], 
             UndirectedEdge[138, 457] -> 
             RGBColor[
              0.7348422129263097, 0.7905496038463615, 0.9346160118342903], 
             UndirectedEdge[11, 497] -> 
             RGBColor[
              0.8764492390433511, 0.9042666786747454, 0.9841903813529971], 
             UndirectedEdge[154, 379] -> 
             RGBColor[
              0.9662932686882124, 0.9733062611597785, 0.893760136899898], 
             UndirectedEdge[17, 467] -> 
             RGBColor[
              0.8526604690817285, 0.8856548079948567, 0.985728442290619], 
             UndirectedEdge[75, 93] -> 
             RGBColor[
              0.8538977685355678, 0.8863389184655384, 0.985926725518101], 
             UndirectedEdge[100, 315] -> 
             RGBColor[
              0.9070070740576237, 0.9282437415885252, 0.9756299398143418], 
             UndirectedEdge[45, 52] -> 
             RGBColor[
              0.4017411949348375, 0.522389763778154, 0.9468195715888258], 
             UndirectedEdge[8, 203] -> 
             RGBColor[
              0.8467798555091259, 0.8811052480379, 0.9820693162735783], 
             UndirectedEdge[244, 340] -> 
             RGBColor[
              0.9354564242929773, 0.9498106082538754, 0.9368686386608582], 
             UndirectedEdge[104, 190] -> 
             RGBColor[
              0.9209636494658168, 0.9028227586546909, 0.658730070573041], 
             UndirectedEdge[38, 437] -> 
             RGBColor[
              0.9619119077811702, 0.9711145437034996, 0.9493573845477667], 
             UndirectedEdge[96, 465] -> 
             RGBColor[
              0.8129256178083084, 0.8531233880998363, 0.9079566272101083], 
             UndirectedEdge[48, 346] -> 
             RGBColor[
              0.9664720150749461, 0.9745154642567072, 0.9416383123658666], 
             UndirectedEdge[153, 342] -> 
             RGBColor[
              0.866312700839029, 0.8932090651271296, 0.8256676290278346], 
             UndirectedEdge[151, 327] -> 
             RGBColor[
              0.8573506032675802, 0.8890711416671071, 0.9683391403965969], 
             UndirectedEdge[375, 489] -> 
             RGBColor[
              0.7621467964303184, 0.8145073332807, 0.9768229858623179], 
             UndirectedEdge[203, 289] -> 
             RGBColor[
              0.9188348634343335, 0.9380303717856024, 0.989082522482074], 
             UndirectedEdge[6, 79] -> 
             RGBColor[
              0.9710589564493719, 0.9779363976233267, 0.9338738170848753], 
             UndirectedEdge[105, 463] -> 
             RGBColor[
              0.9379068169410141, 0.9528217281864333, 0.9764751176766309], 
             UndirectedEdge[10, 125] -> 
             RGBColor[
              0.9725132856944789, 0.979021033993082, 0.9314120170227249], 
             UndirectedEdge[32, 331] -> 
             RGBColor[
              0.9166028257244616, 0.9327246083893299, 0.8371035478485456], 
             UndirectedEdge[26, 44] -> 
             RGBColor[
              0.8585259665230853, 0.8855965934369558, 0.7023931139418811], 
             UndirectedEdge[86, 253] -> 
             RGBColor[
              0.8682816691296145, 0.8979555801734446, 0.9868928333982909], 
             UndirectedEdge[370, 466] -> 
             RGBColor[
              0.8408995068639267, 0.8761766295878215, 0.9645333989341793], 
             UndirectedEdge[301, 456] -> 
             RGBColor[
              0.8710391787385171, 0.9000070136701853, 0.9875616885255759], 
             UndirectedEdge[21, 337] -> 
             RGBColor[
              0.8219888183906054, 0.8617613542415323, 0.9826534735649126], 
             UndirectedEdge[61, 172] -> 
             RGBColor[
              0.8647904571799105, 0.8944918850657779, 0.9492717656768159], 
             UndirectedEdge[291, 359] -> 
             RGBColor[
              0.7796708891372484, 0.8285472509552059, 0.9785129274094357], 
             UndirectedEdge[134, 499] -> 
             RGBColor[
              0.9098740781083003, 0.9301885806814041, 0.964072665604699], 
             UndirectedEdge[140, 244] -> 
             RGBColor[
              0.9278463215748372, 0.9444037585690607, 0.9617858418706815], 
             UndirectedEdge[108, 364] -> 
             RGBColor[
              0.9520149066641246, 0.962433166580512, 0.913230871488875], 
             UndirectedEdge[113, 421] -> 
             RGBColor[
              0.9417257875523428, 0.9533751465482871, 0.8751764641061439], 
             UndirectedEdge[54, 55] -> 
             RGBColor[
              0.8701441769763749, 0.8642278318681513, 0.6560338879427174], 
             UndirectedEdge[56, 210] -> 
             RGBColor[
              0.8840832320320051, 0.9104079876950183, 0.9888058419732726], 
             UndirectedEdge[36, 58] -> 
             RGBColor[
              0.8153955537028637, 0.855491809511319, 0.9250417660108301], 
             UndirectedEdge[25, 288] -> 
             RGBColor[
              0.9793809437523526, 0.9825685240508987, 0.8492821007315263], 
             UndirectedEdge[262, 344] -> 
             RGBColor[
              0.9746666824020072, 0.925641089004624, 0.4034097970857373], 
             UndirectedEdge[8, 439] -> 
             RGBColor[
              0.8391992399092272, 0.875148294410597, 0.9843842315078648], 
             UndirectedEdge[102, 186] -> 
             RGBColor[
              0.7741292558891999, 0.822686005193995, 0.9441837796671323], 
             UndirectedEdge[85, 145] -> 
             RGBColor[
              0.9717047943627676, 0.9765260305795902, 0.8463378611463082], 
             UndirectedEdge[421, 423] -> 
             RGBColor[
              0.9920809004906557, 0.9909932630883812, 0.7809035030498093], 
             UndirectedEdge[406, 476] -> 
             RGBColor[
              0.9298937776018934, 0.944562392455714, 0.9010472935459408], 
             UndirectedEdge[111, 400] -> 
             RGBColor[
              0.9736065912426415, 0.9787019344718839, 0.8787567793224276], 
             UndirectedEdge[137, 183] -> 
             RGBColor[
              0.9008867266956015, 0.9230141632544908, 0.9629329697245594], 
             UndirectedEdge[85, 358] -> 
             RGBColor[
              0.9879190708327426, 0.9886186114224566, 0.8188913204432302], 
             UndirectedEdge[399, 412] -> 
             RGBColor[
              0.7952881309091211, 0.836984922505449, 0.816993369000979], 
             UndirectedEdge[283, 292] -> 
             RGBColor[
              0.937923839309915, 0.9509486382804357, 0.9010877145295537], 
             UndirectedEdge[240, 310] -> 
             RGBColor[
              0.9440835591881032, 0.9561551455595921, 0.9144814116619862], 
             UndirectedEdge[186, 300] -> 
             RGBColor[
              0.9171839510005342, 0.9358116729365105, 0.9576415385105335], 
             UndirectedEdge[37, 240] -> 
             RGBColor[
              0.9241526441312761, 0.9420221427792526, 0.9809746760142819], 
             UndirectedEdge[36, 429] -> 
             RGBColor[
              0.783804452482082, 0.8318628913773533, 0.978865802826339], 
             UndirectedEdge[56, 276] -> 
             RGBColor[
              0.9594130477614495, 0.9691786004537362, 0.9506882549397205], 
             UndirectedEdge[95, 174] -> 
             RGBColor[
              0.9725612180783811, 0.9615456188957123, 0.6660790020827436], 
             UndirectedEdge[7, 28] -> 
             RGBColor[
              0.928405878080383, 0.9439471077662959, 0.9257056391778977], 
             UndirectedEdge[251, 367] -> 
             RGBColor[
              0.5782261617622256, 0.6684690727671367, 0.9599392280475951], 
             UndirectedEdge[31, 314] -> 
             RGBColor[
              0.9703712827708411, 0.9773748160634317, 0.9328562826226832], 
             UndirectedEdge[238, 436] -> 
             RGBColor[
              0.9657814104716751, 0.9723552550266343, 0.869133814058346], 
             UndirectedEdge[291, 488] -> 
             RGBColor[
              0.9495327414122618, 0.9615451026634302, 0.9586253425934826], 
             UndirectedEdge[96, 171] -> 
             RGBColor[
              0.6289772777357436, 0.7096711150261585, 0.9639345418044939], 
             UndirectedEdge[127, 179] -> 
             RGBColor[
              0.9608870568322265, 0.9703502115438167, 0.9510921898803921], 
             UndirectedEdge[296, 453] -> 
             RGBColor[
              0.8272922324659355, 0.8626244999951936, 0.8136505085159484], 
             UndirectedEdge[14, 494] -> 
             RGBColor[
              0.9933721820626524, 0.9899530937592554, 0.6450797240699702], 
             UndirectedEdge[317, 420] -> 
             RGBColor[
              0.8854074577569362, 0.9114110125433519, 0.9870988759701058], 
             UndirectedEdge[7, 388] -> 
             RGBColor[
              0.9321950633942175, 0.9455140332711873, 0.8629090324304078], 
             UndirectedEdge[146, 271] -> 
             RGBColor[
              0.9484451360336793, 0.9573007389493177, 0.7741500827529431], 
             UndirectedEdge[331, 449] -> 
             RGBColor[
              0.8441246444990801, 0.878546094643228, 0.9849945562229301], 
             UndirectedEdge[27, 359] -> 
             RGBColor[
              0.7810766816291572, 0.8296681917290334, 0.9786470131522798], 
             UndirectedEdge[100, 471] -> 
             RGBColor[
              0.9070639670950659, 0.9282861723226956, 0.9755336347420329], 
             UndirectedEdge[219, 337] -> 
             RGBColor[
              0.8426969851173374, 0.87732385728255, 0.9517044728175967], 
             UndirectedEdge[199, 419] -> 
             RGBColor[
              0.8516383697256309, 0.8845759775374062, 0.9857009675502337], 
             UndirectedEdge[266, 437] -> 
             RGBColor[
              0.8515973827287754, 0.8841565079857425, 0.9464965704777946], 
             UndirectedEdge[327, 399] -> 
             RGBColor[
              0.7756971093334548, 0.824569607185643, 0.9606883049808862], 
             UndirectedEdge[311, 419] -> 
             RGBColor[
              0.8816661087457588, 0.9081987426691509, 0.9774517558578537], 
             UndirectedEdge[267, 329] -> 
             RGBColor[
              0.5838169308563568, 0.6637666349049215, 0.9639987925823418], 
             UndirectedEdge[219, 244] -> 
             RGBColor[
              0.9288138189888074, 0.9451253165562681, 0.9601481211125686], 
             UndirectedEdge[17, 205] -> 
             RGBColor[
              0.7277030466738076, 0.7872064179003568, 0.9734942969869843], 
             UndirectedEdge[175, 361] -> 
             RGBColor[
              0.9598017382130863, 0.9695407826947082, 0.9529293512061656], 
             UndirectedEdge[189, 266] -> 
             RGBColor[
              0.856016472012168, 0.886792440076484, 0.909468231004652], 
             UndirectedEdge[225, 280] -> 
             RGBColor[
              0.9934390341705643, 0.9883750824432653, 0.5272575429326347], 
             UndirectedEdge[300, 458] -> 
             RGBColor[
              0.8335964085245715, 0.8702568191124986, 0.9839623263396493], 
             UndirectedEdge[171, 343] -> 
             RGBColor[
              0.7859662367775588, 0.8330253942100101, 0.9646843612202705], 
             UndirectedEdge[358, 408] -> 
             RGBColor[
              0.7345006957164482, 0.7902977827370483, 0.935271407008067], 
             UndirectedEdge[380, 411] -> 
             RGBColor[
              0.8518677112358872, 0.8849318609568444, 0.9750817218635619], 
             UndirectedEdge[345, 498] -> 
             RGBColor[
              0.8574608616916268, 0.8867621184265481, 0.8570722769423995], 
             UndirectedEdge[161, 450] -> 
             RGBColor[
              0.9920678427548617, 0.9842451162056773, 0.47980681142357257`], 
             UndirectedEdge[94, 214] -> 
             RGBColor[
              0.9897716498125599, 0.990038328587953, 0.8191737629350412], 
             UndirectedEdge[157, 343] -> 
             RGBColor[
              0.8949304086003524, 0.9186370276941451, 0.9752717134250511], 
             UndirectedEdge[155, 332] -> 
             RGBColor[
              0.9447132900634473, 0.9582596623030522, 0.9774931237543241], 
             UndirectedEdge[127, 168] -> 
             RGBColor[
              0.7227347296883091, 0.7817965573917551, 0.9625321551069329], 
             UndirectedEdge[378, 380] -> 
             RGBColor[
              0.8468720687476543, 0.8812061189687341, 0.9835380415239066], 
             UndirectedEdge[160, 481] -> 
             RGBColor[
              0.9678798326908612, 0.9739202548818523, 0.865581732597432], 
             UndirectedEdge[23, 485] -> 
             RGBColor[
              0.8171200691235507, 0.8576881107939851, 0.966625865742762], 
             UndirectedEdge[352, 399] -> 
             RGBColor[
              0.7318531319347006, 0.790122618847203, 0.974292775727827], 
             UndirectedEdge[389, 456] -> 
             RGBColor[
              0.91629152600612, 0.9323316046161019, 0.8253373715970019], 
             UndirectedEdge[105, 263] -> 
             RGBColor[
              0.9577520789221744, 0.9655300635961995, 0.8405548024507623], 
             UndirectedEdge[143, 347] -> 
             RGBColor[
              0.8192750613784067, 0.8592494052189463, 0.960654814900689], 
             UndirectedEdge[98, 484] -> 
             RGBColor[
              0.9683808217798647, 0.9751570352411636, 0.9033870189466515], 
             UndirectedEdge[100, 500] -> 
             RGBColor[
              0.9268650054650447, 0.9416572787234956, 0.8794786114397023], 
             UndirectedEdge[89, 424] -> 
             RGBColor[
              0.7582061984365682, 0.8098922091553049, 0.9465044563659875], 
             UndirectedEdge[231, 442] -> 
             RGBColor[
              0.9851293265588832, 0.9846934344462301, 0.6772532819584853], 
             UndirectedEdge[15, 104] -> 
             RGBColor[
              0.9797370168420937, 0.9433103412129935, 0.3757825660851679], 
             UndirectedEdge[75, 182] -> 
             RGBColor[
              0.9017213043424065, 0.9237127062769345, 0.9641592501365464], 
             UndirectedEdge[290, 316] -> 
             RGBColor[
              0.8297762221723959, 0.8678218804428467, 0.980374553010561], 
             UndirectedEdge[344, 424] -> 
             RGBColor[
              0.7698820775321982, 0.8154493414444929, 0.7404260625254915], 
             UndirectedEdge[369, 425] -> 
             RGBColor[
              0.8691929509585141, 0.898199917552535, 0.9633157034032623], 
             UndirectedEdge[106, 255] -> 
             RGBColor[
              0.9106837443002384, 0.9311844051733386, 0.9762921926761952], 
             UndirectedEdge[84, 242] -> 
             RGBColor[
              0.8234124757634453, 0.8596926050045399, 0.8211932411331451], 
             UndirectedEdge[143, 446] -> 
             RGBColor[
              0.9453549011149711, 0.9586394339424248, 0.9729836369618243], 
             UndirectedEdge[376, 415] -> 
             RGBColor[
              0.9785436476257473, 0.9835184680476106, 0.9212041872433734], 
             UndirectedEdge[93, 108] -> 
             RGBColor[
              0.8923474921596075, 0.9169976843934033, 0.9895940944818353], 
             UndirectedEdge[78, 183] -> 
             RGBColor[
              0.7799708653133676, 0.8281625775921964, 0.9786709210705369], 
             UndirectedEdge[17, 298] -> 
             RGBColor[
              0.8536909496892233, 0.8864764852596223, 0.9858267304508828], 
             UndirectedEdge[204, 370] -> 
             RGBColor[
              0.7829504334455335, 0.8305449461054205, 0.9789533789561532], 
             UndirectedEdge[208, 314] -> 
             RGBColor[
              0.9561677539691096, 0.9668305631956534, 0.9590807386363324], 
             UndirectedEdge[313, 379] -> 
             RGBColor[
              0.8879098118096405, 0.913298813089888, 0.9836101603317273], 
             UndirectedEdge[3, 221] -> 
             RGBColor[
              0.7899985258410751, 0.8359775419071411, 0.9796753523507686], 
             UndirectedEdge[154, 229] -> 
             RGBColor[
              0.9922641087727482, 0.9898424953919953, 0.6887115551584992], 
             UndirectedEdge[25, 180] -> 
             RGBColor[
              0.9784050670042512, 0.9821649739366702, 0.8654549039356336], 
             UndirectedEdge[371, 419] -> 
             RGBColor[
              0.8491426065827107, 0.8825859237529275, 0.9854629194336679], 
             UndirectedEdge[31, 419] -> 
             RGBColor[
              0.8998441561767987, 0.9217071850229903, 0.9444994765252633], 
             UndirectedEdge[321, 482] -> 
             RGBColor[
              0.8357239238123897, 0.8723259849961639, 0.9737649122071771], 
             UndirectedEdge[212, 300] -> 
             RGBColor[
              0.9238683569139956, 0.9402545978316712, 0.9220415455319498], 
             UndirectedEdge[376, 414] -> 
             RGBColor[
              0.9579172428973761, 0.9681353291738293, 0.9561193102205675], 
             UndirectedEdge[140, 274] -> 
             RGBColor[
              0.978285328618862, 0.9830285629492241, 0.9083299376167098], 
             UndirectedEdge[1, 131] -> 
             RGBColor[
              0.9292787828161193, 0.9417947383202058, 0.7542229217465145], 
             UndirectedEdge[360, 466] -> 
             RGBColor[
              0.9553550374925597, 0.9662244405781435, 0.9604564556407263], 
             UndirectedEdge[165, 182] -> 
             RGBColor[
              0.9075053514711033, 0.9283247484535805, 0.9647109377151613], 
             UndirectedEdge[268, 480] -> 
             RGBColor[
              0.8255523944583134, 0.8644248383794939, 0.9750254291671372], 
             UndirectedEdge[54, 385] -> 
             RGBColor[
              0.7784456701324188, 0.8268469410044459, 0.9785518474765621], 
             UndirectedEdge[149, 158] -> 
             RGBColor[
              0.9636975225239606, 0.8808102873098179, 0.4739806539237041], 
             UndirectedEdge[229, 379] -> 
             RGBColor[
              0.9678894048546333, 0.9727397754541528, 0.7781523174251157], 
             UndirectedEdge[98, 253] -> 
             RGBColor[
              0.9419843337716377, 0.956252591635598, 0.9830895694022094], 
             UndirectedEdge[121, 469] -> 
             RGBColor[
              0.8682997163286892, 0.8978226407053147, 0.9873003961553795], 
             UndirectedEdge[34, 269] -> 
             RGBColor[
              0.8654457218253229, 0.8955469429579475, 0.9870281796118574], 
             UndirectedEdge[145, 286] -> 
             RGBColor[
              0.8377501007768395, 0.873889990592233, 0.9730122105408765], 
             UndirectedEdge[34, 234] -> 
             RGBColor[
              0.8319252670708943, 0.868906978728575, 0.9838075269214386], 
             UndirectedEdge[85, 286] -> 
             RGBColor[
              0.8612561270836341, 0.8895287146221703, 0.8467799185443106], 
             UndirectedEdge[86, 261] -> 
             RGBColor[
              0.8965312392261819, 0.9153171035186061, 0.7086241948555487], 
             UndirectedEdge[140, 255] -> 
             RGBColor[
              0.919711847720194, 0.9379175499217789, 0.961009968492695], 
             UndirectedEdge[345, 448] -> 
             RGBColor[
              0.9311855857584186, 0.9447437604259886, 0.8643176837030899], 
             UndirectedEdge[146, 444] -> 
             RGBColor[
              0.9707406103277594, 0.9747674543362945, 0.7654909378900445], 
             UndirectedEdge[215, 224] -> 
             RGBColor[
              0.8634568843816957, 0.8910222833107091, 0.8289234796079654], 
             UndirectedEdge[40, 359] -> 
             RGBColor[
              0.6690851472470591, 0.7413272000347265, 0.9677109321345049], 
             UndirectedEdge[88, 495] -> 
             RGBColor[
              0.6659309219833252, 0.7341774143622211, 0.9644904971245787], 
             UndirectedEdge[341, 403] -> 
             RGBColor[
              0.9319078423911338, 0.947836134518302, 0.9688934237030684], 
             UndirectedEdge[134, 416] -> 
             RGBColor[
              0.5162804133450747, 0.5957612292012561, 0.9597012752546307], 
             UndirectedEdge[113, 423] -> 
             RGBColor[
              0.9405227915653267, 0.9528776767920693, 0.8951132208648195], 
             UndirectedEdge[204, 362] -> 
             RGBColor[
              0.9169142324472823, 0.9338918507962211, 0.8858701617259689], 
             UndirectedEdge[231, 256] -> 
             RGBColor[
              0.9836909839268101, 0.9864445973852244, 0.871616474572021], 
             UndirectedEdge[183, 407] -> 
             RGBColor[
              0.774433282919904, 0.8238365761392377, 0.9781189866092062], 
             UndirectedEdge[231, 271] -> 
             RGBColor[
              0.9404339014542019, 0.9542574945879136, 0.9566327693721373], 
             UndirectedEdge[106, 140] -> 
             RGBColor[
              0.9615613533304923, 0.9708531007681642, 0.9499507817935209], 
             UndirectedEdge[96, 147] -> 
             RGBColor[
              0.7891240138636786, 0.8359774447577503, 0.9753510408543578], 
             UndirectedEdge[149, 275] -> 
             RGBColor[
              0.9533684808623808, 0.8752338489333225, 0.5965470168414828], 
             UndirectedEdge[207, 287] -> 
             RGBColor[
              0.7768464513431235, 0.7859021524497565, 0.6405681205153788], 
             UndirectedEdge[223, 480] -> 
             RGBColor[
              0.9697506792981531, 0.9751807800942949, 0.8563805362028784], 
             UndirectedEdge[11, 102] -> 
             RGBColor[
              0.6935198879848281, 0.7594577239802753, 0.9708014041049207], 
             UndirectedEdge[230, 339] -> 
             RGBColor[
              0.7284877908276086, 0.7878194659975827, 0.973572512950384], 
             UndirectedEdge[103, 449] -> 
             RGBColor[
              0.8336473783270313, 0.5086693063257013, 0.5748853202618109], 
             UndirectedEdge[226, 396] -> 
             RGBColor[
              0.9253839573847722, 0.9410448272811034, 0.9040234109593848], 
             UndirectedEdge[144, 279] -> 
             RGBColor[
              0.9069774507530426, 0.9277628352920382, 0.959772739748711], 
             UndirectedEdge[205, 228] -> 
             RGBColor[
              0.8215913714952963, 0.8279771412251655, 0.6536466336603034], 
             UndirectedEdge[267, 406] -> 
             RGBColor[
              0.6402764959238271, 0.7064122787530553, 0.8772559571411813], 
             UndirectedEdge[209, 233] -> 
             RGBColor[
              0.8095543369870397, 0.8515682316485009, 0.9552683611673126], 
             UndirectedEdge[387, 405] -> 
             RGBColor[
              0.9850406304811776, 0.9872736742613613, 0.8613836304389582], 
             UndirectedEdge[75, 206] -> 
             RGBColor[
              0.7440292503528769, 0.8001085723624269, 0.9750822657262026], 
             UndirectedEdge[183, 404] -> 
             RGBColor[
              0.9127740979487542, 0.9308807645877264, 0.8980743548679968], 
             UndirectedEdge[319, 488] -> 
             RGBColor[
              0.9012710244757534, 0.9230625196076658, 0.9540220969483352], 
             UndirectedEdge[220, 371] -> 
             RGBColor[
              0.9350413899050618, 0.9492510920701629, 0.926903361704728], 
             UndirectedEdge[66, 460] -> 
             RGBColor[
              0.8568786285423066, 0.8871489639581085, 0.8951800661106784], 
             UndirectedEdge[87, 446] -> 
             RGBColor[
              0.9543654420950989, 0.9424676972163334, 0.6810572245973205], 
             UndirectedEdge[273, 308] -> 
             RGBColor[
              0.9836150885056933, 0.9848459626869382, 0.7815253705222384], 
             UndirectedEdge[326, 428] -> 
             RGBColor[
              0.7416180012758563, 0.7980768861930493, 0.9748812096190724], 
             UndirectedEdge[130, 315] -> 
             RGBColor[
              0.9642612771886452, 0.9469363772710198, 0.6622563552159787], 
             UndirectedEdge[95, 407] -> 
             RGBColor[
              0.8477864268456239, 0.8636199680984429, 0.6784234980748947], 
             UndirectedEdge[148, 153] -> 
             RGBColor[
              0.9945552050317777, 0.9916120745980193, 0.7105039340771806], 
             UndirectedEdge[85, 137] -> 
             RGBColor[
              0.9808205478689873, 0.9833245446188525, 0.8309072682295664], 
             UndirectedEdge[289, 359] -> 
             RGBColor[
              0.7676435533731403, 0.8189569798902382, 0.9773657493873258], 
             UndirectedEdge[32, 449] -> 
             RGBColor[
              0.9224539378794441, 0.9373901263975046, 0.8376616321492373], 
             UndirectedEdge[329, 406] -> 
             RGBColor[
              0.9335846592678307, 0.9475054013098185, 0.9013993331341268], 
             UndirectedEdge[168, 213] -> 
             RGBColor[
              0.6195699418879277, 0.7005001769836527, 0.9642425192304448], 
             UndirectedEdge[111, 464] -> 
             RGBColor[
              0.9731820481627701, 0.9783853109380412, 0.8794754200180812], 
             UndirectedEdge[50, 117] -> 
             RGBColor[
              0.768715710954559, 0.8192458229442732, 0.9775820560773512], 
             UndirectedEdge[357, 420] -> 
             RGBColor[
              0.8958035184942379, 0.9191643776192444, 0.9695010568687478], 
             UndirectedEdge[153, 190] -> 
             RGBColor[
              0.9344446290582624, 0.9468714507693771, 0.8323423620079775], 
             UndirectedEdge[165, 275] -> 
             RGBColor[
              0.9120392327875442, 0.9317061097158328, 0.9570362592720587], 
             UndirectedEdge[152, 301] -> 
             RGBColor[
              0.8448623879371675, 0.8794129658968839, 0.9849909870860636], 
             UndirectedEdge[208, 349] -> 
             RGBColor[
              0.8483318876760371, 0.8820170611454059, 0.9670053460357084], 
             UndirectedEdge[5, 23] -> 
             RGBColor[
              0.7914781265494184, 0.837465970351028, 0.9642003350990973], 
             UndirectedEdge[56, 227] -> 
             RGBColor[
              0.9465561273224448, 0.9596287424902428, 0.9741897594132858], 
             UndirectedEdge[56, 326] -> 
             RGBColor[
              0.8315868544226902, 0.8692860238621019, 0.9836030543766853], 
             UndirectedEdge[155, 181] -> 
             RGBColor[
              0.9382259888062896, 0.9534214436474449, 0.9884744326235433], 
             UndirectedEdge[148, 323] -> 
             RGBColor[
              0.8931874315932424, 0.9147030676437105, 0.8620425246620036], 
             UndirectedEdge[177, 438] -> 
             RGBColor[
              0.7806935075698416, 0.8286029686947578, 0.9787758909050892], 
             UndirectedEdge[53, 90] -> 
             RGBColor[
              0.9448227349181415, 0.9559965403250541, 0.8820710031508299], 
             UndirectedEdge[30, 217] -> 
             RGBColor[
              0.8924767214956707, 0.9124199581673322, 0.7298677067870449], 
             UndirectedEdge[43, 290] -> 
             RGBColor[
              0.8504389302219175, 0.8832320942741008, 0.9453979779800816], 
             UndirectedEdge[114, 397] -> 
             RGBColor[
              0.8816002205274972, 0.9084281017208755, 0.988569010119362], 
             UndirectedEdge[227, 320] -> 
             RGBColor[
              0.974013287844498, 0.9792886499885485, 0.8907596622350635], 
             UndirectedEdge[298, 432] -> 
             RGBColor[
              0.9550594848934926, 0.9655397990159085, 0.9430044181096873], 
             UndirectedEdge[42, 85] -> 
             RGBColor[
              0.911203766157922, 0.9286064875462154, 0.8517427620127141], 
             UndirectedEdge[329, 413] -> 
             RGBColor[
              0.9238085043388071, 0.941186628055326, 0.9614879199053631], 
             UndirectedEdge[244, 380] -> 
             RGBColor[
              0.820689478665902, 0.8603744594367861, 0.9826226426225757], 
             UndirectedEdge[87, 113] -> 
             RGBColor[
              0.9340607129945833, 0.926277257388771, 0.6791205414094678], 
             UndirectedEdge[334, 370] -> 
             RGBColor[
              0.8586813123207058, 0.8864057164382526, 0.7574951262835825], 
             UndirectedEdge[24, 278] -> 
             RGBColor[
              0.8689182815112204, 0.8978225584102049, 0.9550481625641339], 
             UndirectedEdge[51, 325] -> 
             RGBColor[
              0.8174449363861426, 0.8565252188459899, 0.8995093611295094], 
             UndirectedEdge[112, 463] -> 
             RGBColor[
              0.898591095873238, 0.9214724394038074, 0.9727251491036278], 
             UndirectedEdge[308, 421] -> 
             RGBColor[
              0.9830555784249164, 0.985372964319105, 0.8459236430411269], 
             UndirectedEdge[302, 421] -> 
             RGBColor[
              0.8385167639980253, 0.8721802043836037, 0.8650400888117213], 
             UndirectedEdge[103, 488] -> 
             RGBColor[
              0.8968785115396795, 0.558037548354279, 0.5444932301827866], 
             UndirectedEdge[225, 424] -> 
             RGBColor[
              0.7695338459345886, 0.8147045092688213, 0.7025232021619975], 
             UndirectedEdge[205, 388] -> 
             RGBColor[
              0.8337460900700875, 0.8682027609234204, 0.853203286664757], 
             UndirectedEdge[114, 297] -> 
             RGBColor[
              0.7121546114998731, 0.7740831832648514, 0.972796465140995], 
             UndirectedEdge[203, 381] -> 
             RGBColor[
              0.9338849394329678, 0.9500308938634834, 0.9905180121661852], 
             UndirectedEdge[17, 252] -> 
             RGBColor[
              0.8457256651429692, 0.8801251835743283, 0.9850669945001675], 
             UndirectedEdge[361, 363] -> 
             RGBColor[
              0.9372361700631946, 0.9523743398850835, 0.9794402304280059], 
             UndirectedEdge[318, 383] -> 
             RGBColor[
              0.9806718053446442, 0.966379765103688, 0.6497712801927749], 
             UndirectedEdge[209, 273] -> 
             RGBColor[
              0.9796323963469128, 0.9818756773959796, 0.7882670294945779], 
             UndirectedEdge[47, 230] -> 
             RGBColor[
              0.8473379026317176, 0.8815214386682105, 0.9811246880570306], 
             UndirectedEdge[1, 170] -> 
             RGBColor[
              0.7694480782594975, 0.8201831911883674, 0.9775581288461206], 
             UndirectedEdge[139, 247] -> 
             RGBColor[
              0.8614647131769941, 0.8891366520689649, 0.8023471060241791], 
             UndirectedEdge[246, 288] -> 
             RGBColor[
              0.9828010355164034, 0.954318567734338, 0.5500298228039358], 
             UndirectedEdge[1, 147] -> 
             RGBColor[
              0.9027019266400087, 0.9251371381686728, 0.9865290178565331], 
             UndirectedEdge[352, 457] -> 
             RGBColor[
              0.6780958783515837, 0.7464800586517526, 0.9700608078064558], 
             UndirectedEdge[157, 238] -> 
             RGBColor[
              0.9159806168782467, 0.9326910811135314, 0.8659656898218523], 
             UndirectedEdge[97, 145] -> 
             RGBColor[
              0.9306242692994336, 0.9471962128887562, 0.9820694247090247], 
             UndirectedEdge[83, 237] -> 
             RGBColor[
              0.6865583414829948, 0.7482300971343642, 0.8817844962429704], 
             UndirectedEdge[73, 494] -> 
             RGBColor[
              0.8806031335392581, 0.9050578131084317, 0.8692084277959967], 
             UndirectedEdge[101, 197] -> 
             RGBColor[
              0.7413044622723393, 0.792800179028891, 0.7833716870692188], 
             UndirectedEdge[224, 356] -> 
             RGBColor[
              0.9482794737959934, 0.9579466578231505, 0.8372025731910884], 
             UndirectedEdge[182, 441] -> 
             RGBColor[
              0.9600121044821683, 0.9161675700604982, 0.6132153781260364], 
             UndirectedEdge[160, 480] -> 
             RGBColor[
              0.943130519811529, 0.9571074153074415, 0.9811493754098701], 
             UndirectedEdge[263, 440] -> 
             RGBColor[
              0.9446862696873577, 0.9551117419743003, 0.8393085739019599], 
             UndirectedEdge[31, 223] -> 
             RGBColor[
              0.9896953784817942, 0.9900067884325976, 0.8204377762697059], 
             UndirectedEdge[5, 102] -> 
             RGBColor[
              0.6020485106894496, 0.6878091288108463, 0.9618146106192857], 
             UndirectedEdge[171, 216] -> 
             RGBColor[
              0.8038531800357642, 0.8457713562515521, 0.9078018252607689], 
             UndirectedEdge[102, 414] -> 
             RGBColor[
              0.7581267731594066, 0.8107513797757759, 0.971271808812737], 
             UndirectedEdge[68, 205] -> 
             RGBColor[
              0.8336836365954811, 0.8675211972126806, 0.8065731015969038], 
             UndirectedEdge[111, 376] -> 
             RGBColor[
              0.9823863754113513, 0.9852498831293305, 0.8638948948592532], 
             UndirectedEdge[302, 325] -> 
             RGBColor[
              0.8363233290168043, 0.8712731626501609, 0.9013909828783242], 
             UndirectedEdge[39, 315] -> 
             RGBColor[
              0.970240960017763, 0.9767601142695286, 0.9099018509143519], 
             UndirectedEdge[66, 314] -> 
             RGBColor[
              0.9730725969306766, 0.978491878889131, 0.8880885162172567], 
             UndirectedEdge[274, 370] -> 
             RGBColor[
              0.8548851959449375, 0.8863098823989655, 0.9275477590470032], 
             UndirectedEdge[94, 477] -> 
             RGBColor[
              0.9679007105825099, 0.9744496375397573, 0.8885559411431543], 
             UndirectedEdge[99, 329] -> 
             RGBColor[
              0.8118918744756605, 0.8534372202299354, 0.9817628917125867], 
             UndirectedEdge[25, 465] -> 
             RGBColor[
              0.9764642302389115, 0.9813623880569725, 0.8976195918618564], 
             UndirectedEdge[223, 381] -> 
             RGBColor[
              0.9617892350942843, 0.9690619653068424, 0.8635754653717933], 
             UndirectedEdge[196, 318] -> 
             RGBColor[
              0.9875236012657305, 0.9687003251993667, 0.4805201532461655], 
             UndirectedEdge[76, 462] -> 
             RGBColor[
              0.8271078186795408, 0.8627996885346618, 0.8392027468071248], 
             UndirectedEdge[89, 440] -> 
             RGBColor[
              0.9322505812857289, 0.9479294544080855, 0.9626864137839759], 
             UndirectedEdge[88, 326] -> 
             RGBColor[
              0.835427801998825, 0.8721840815653309, 0.9782622880319907], 
             UndirectedEdge[149, 282] -> 
             RGBColor[
              0.9607110804708021, 0.8799276639055622, 0.5490856443968845], 
             UndirectedEdge[238, 462] -> 
             RGBColor[
              0.9946142576473669, 0.9919132463110414, 0.7296422238291326], 
             UndirectedEdge[168, 261] -> 
             RGBColor[
              0.744635395048966, 0.794423077980252, 0.6950105562225323], 
             UndirectedEdge[155, 344] -> 
             RGBColor[
              0.9640049920868399, 0.9694966628620001, 0.7585231282218654], 
             UndirectedEdge[4, 496] -> 
             RGBColor[
              0.9375621953607873, 0.9493988512782191, 0.8360069039826961], 
             UndirectedEdge[87, 226] -> 
             RGBColor[
              0.9837946257295909, 0.9636384916806813, 0.5951424753364933], 
             UndirectedEdge[128, 362] -> 
             RGBColor[
              0.992325608040027, 0.9890692359146778, 0.6296359485068626], 
             UndirectedEdge[295, 389] -> 
             RGBColor[
              0.942623455847148, 0.9533279707101431, 0.8278489345720305], 
             UndirectedEdge[89, 133] -> 
             RGBColor[
              0.9129470562645581, 0.9325373475364318, 0.9608452263349964], 
             UndirectedEdge[33, 164] -> 
             RGBColor[
              0.8709645927003793, 0.8996662123553176, 0.9676570214621629], 
             UndirectedEdge[276, 396] -> 
             RGBColor[
              0.9227790137676066, 0.9399676161514081, 0.9471940680737996], 
             UndirectedEdge[50, 274] -> 
             RGBColor[
              0.8678242958233119, 0.8964180055647528, 0.9288374076001163], 
             UndirectedEdge[21, 375] -> 
             RGBColor[
              0.7933853123367072, 0.8394160779175293, 0.9798025433964215], 
             UndirectedEdge[41, 485] -> 
             RGBColor[
              0.8179807401035839, 0.8583299978016745, 0.9651689742725086], 
             UndirectedEdge[30, 316] -> 
             RGBColor[
              0.9660501515066369, 0.9707712029288036, 0.7339073745256794], 
             UndirectedEdge[285, 324] -> 
             RGBColor[
              0.9625371474211188, 0.9355765110848273, 0.6437896340874594], 
             UndirectedEdge[95, 358] -> 
             RGBColor[
              0.9813383935850766, 0.9680916220172999, 0.6512215334039115], 
             UndirectedEdge[333, 492] -> 
             RGBColor[
              0.7812581552852476, 0.6010760250515601, 0.58632393822154], 
             UndirectedEdge[332, 393] -> 
             RGBColor[
              0.9266599849411477, 0.9438644468424433, 0.9757711833953834], 
             UndirectedEdge[418, 420] -> 
             RGBColor[
              0.8613888673865362, 0.8923121173488391, 0.9866412332138893], 
             UndirectedEdge[107, 273] -> 
             RGBColor[
              0.9936621590459621, 0.9888523239903557, 0.5515433086525607], 
             UndirectedEdge[310, 483] -> 
             RGBColor[
              0.9909618909114348, 0.990530523870139, 0.799448387681459], 
             UndirectedEdge[155, 403] -> 
             RGBColor[
              0.9488395818170884, 0.961337043936735, 0.9705083881246581], 
             UndirectedEdge[140, 169] -> 
             RGBColor[
              0.8949619519028513, 0.9181879049096922, 0.958647908121453], 
             UndirectedEdge[147, 216] -> 
             RGBColor[
              0.9639999161636992, 0.9720776859831437, 0.9192183243106329], 
             UndirectedEdge[70, 171] -> 
             RGBColor[
              0.7582784994144267, 0.811368148157967, 0.9766122220461393], 
             UndirectedEdge[7, 402] -> 
             RGBColor[
              0.9298937776018934, 0.944562392455714, 0.9010472935459408], 
             UndirectedEdge[185, 409] -> 
             RGBColor[
              0.7732233628039706, 0.8232885921914144, 0.9778929844734401], 
             UndirectedEdge[126, 481] -> 
             RGBColor[
              0.9940088068796284, 0.9906182483393113, 0.6637426441698175], 
             UndirectedEdge[115, 311] -> 
             RGBColor[
              0.8140188372533105, 0.8553521800409448, 0.9707093080351805], 
             UndirectedEdge[383, 496] -> 
             RGBColor[
              0.9302339953266228, 0.9460593109565103, 0.9534043832461101], 
             UndirectedEdge[8, 297] -> 
             RGBColor[
              0.6521659245851061, 0.7267794163593155, 0.9669341554022071], 
             UndirectedEdge[381, 439] -> 
             RGBColor[
              0.926304323833069, 0.9440739402361804, 0.9928329274004717], 
             UndirectedEdge[16, 276] -> 
             RGBColor[
              0.8958187912541393, 0.9185734981338383, 0.9445951834905166], 
             UndirectedEdge[74, 342] -> 
             RGBColor[
              0.7332926866800471, 0.7915730871560687, 0.9740514200646505], 
             UndirectedEdge[26, 269] -> 
             RGBColor[
              0.9343280107437675, 0.9452672567093474, 0.7098280003263777], 
             UndirectedEdge[127, 315] -> 
             RGBColor[
              0.9508428161960316, 0.9628592333232772, 0.9680944693199542], 
             UndirectedEdge[175, 348] -> 
             RGBColor[
              0.9803129020952046, 0.9833967078741901, 0.8536664083442093], 
             UndirectedEdge[180, 288] -> 
             RGBColor[
              0.9926926661541977, 0.9912462439119163, 0.7707649628061312], 
             UndirectedEdge[288, 343] -> 
             RGBColor[
              0.972831290363565, 0.9776838032776138, 0.8603689554955547], 
             UndirectedEdge[484, 500] -> 
             RGBColor[
              0.990748330875769, 0.9904422113071485, 0.8029876301480985], 
             UndirectedEdge[59, 323] -> 
             RGBColor[
              0.893338655003666, 0.9141769036827709, 0.8167441785343456], 
             UndirectedEdge[108, 189] -> 
             RGBColor[
              0.951678937096414, 0.9622942345302397, 0.9187987566872092], 
             UndirectedEdge[59, 74] -> 
             RGBColor[
              0.8616864142832193, 0.8894499326660188, 0.8135893789863382], 
             UndirectedEdge[40, 199] -> 
             RGBColor[
              0.7947648150258437, 0.8401459243509075, 0.9800323431313454], 
             UndirectedEdge[69, 241] -> 
             RGBColor[
              0.6782194873160643, 0.7407460499158202, 0.8716471371139622], 
             UndirectedEdge[275, 353] -> 
             RGBColor[
              0.9663415248113496, 0.9259270058797784, 0.6108426945852877], 
             UndirectedEdge[196, 335] -> 
             RGBColor[
              0.9130759313707677, 0.9292350605166004, 0.7818631744305832], 
             UndirectedEdge[157, 281] -> 
             RGBColor[
              0.911366946530829, 0.9307832098589546, 0.942426147274684], 
             UndirectedEdge[120, 438] -> 
             RGBColor[
              0.8822957092182626, 0.9085217239183563, 0.9689664671348741], 
             UndirectedEdge[152, 389] -> 
             RGBColor[
              0.8901147352047704, 0.9117375568428003, 0.8227666701574896], 
             UndirectedEdge[126, 144] -> 
             RGBColor[
              0.9186316571705518, 0.93366557064595, 0.7824356575337763], 
             UndirectedEdge[96, 157] -> 
             RGBColor[
              0.7379414495585372, 0.7952827485102937, 0.9745218940092746], 
             UndirectedEdge[303, 366] -> 
             RGBColor[
              0.772817994940442, 0.8176424120995427, 0.7250488114867044], 
             UndirectedEdge[119, 309] -> 
             RGBColor[
              0.9688768767983298, 0.9364422533557684, 0.6248589445096464], 
             UndirectedEdge[325, 386] -> 
             RGBColor[
              0.8365316513887305, 0.8714359056704184, 0.9014117465054745], 
             UndirectedEdge[27, 220] -> 
             RGBColor[
              0.9562198483690226, 0.9661382199753845, 0.9289233819792537], 
             UndirectedEdge[95, 346] -> 
             RGBColor[
              0.9798049034100473, 0.9669479475556227, 0.6538173322719432], 
             UndirectedEdge[235, 239] -> 
             RGBColor[
              0.9079554387733035, 0.8823706058324183, 0.642660690703307], 
             UndirectedEdge[64, 303] -> 
             RGBColor[
              0.839537053160588, 0.8711400784644321, 0.7307578070342678], 
             UndirectedEdge[310, 429] -> 
             RGBColor[
              0.955611057621755, 0.9653468599049768, 0.9155809147533072], 
             UndirectedEdge[67, 238] -> 
             RGBColor[
              0.9814550212656259, 0.9840446082935806, 0.8426024793165843], 
             UndirectedEdge[38, 108] -> 
             RGBColor[
              0.929846391912346, 0.9466713755406915, 0.9853035348435193], 
             UndirectedEdge[20, 490] -> 
             RGBColor[
              0.9081505320338978, 0.9274240314611747, 0.9076195693244455], 
             UndirectedEdge[112, 148] -> 
             RGBColor[
              0.9181232290675883, 0.9343606395455668, 0.8644807789498951], 
             UndirectedEdge[76, 402] -> 
             RGBColor[
              0.824562900390134, 0.8618749244865245, 0.8906556239158194], 
             UndirectedEdge[99, 406] -> 
             RGBColor[
              0.8683514395431309, 0.8960828640780691, 0.8950200562714261], 
             UndirectedEdge[8, 258] -> 
             RGBColor[
              0.6461412825527632, 0.721888340550429, 0.9664598735124301], 
             UndirectedEdge[15, 153] -> 
             RGBColor[
              0.9932179964345393, 0.9873590333276796, 0.5493948575201044], 
             UndirectedEdge[195, 463] -> 
             RGBColor[
              0.9645683563689962, 0.944883481832481, 0.6568924774557456], 
             UndirectedEdge[184, 249] -> 
             RGBColor[
              0.9762593939314661, 0.979226744785898, 0.7833956580291488], 
             UndirectedEdge[109, 185] -> 
             RGBColor[
              0.8272597850410461, 0.8611712148314064, 0.6992767931708297], 
             UndirectedEdge[77, 81] -> 
             RGBColor[
              0.5217782895335066, 0.622642147144198, 0.9554954447703813], 
             UndirectedEdge[355, 384] -> 
             RGBColor[
              0.7395813054755127, 0.7943943777216735, 0.9349184175878125], 
             UndirectedEdge[67, 343] -> 
             RGBColor[
              0.9604048129877317, 0.9699905548741944, 0.9519085029197831], 
             UndirectedEdge[247, 255] -> 
             RGBColor[
              0.7986852129050043, 0.8430530639380156, 0.9804643580079484], 
             UndirectedEdge[95, 145] -> 
             RGBColor[
              0.9651241171151017, 0.9559990411744337, 0.6786680741069895], 
             UndirectedEdge[220, 416] -> 
             RGBColor[
              0.5829638260045314, 0.6471432248924059, 0.8992986838257135], 
             UndirectedEdge[287, 451] -> 
             RGBColor[
              0.7885005326029031, 0.8331034587770363, 0.8980682741799758], 
             UndirectedEdge[387, 491] -> 
             RGBColor[
              0.9907536540942434, 0.9904444125947882, 0.8028994106419287], 
             UndirectedEdge[211, 464] -> 
             RGBColor[
              0.8046433521436188, 0.8479002529364532, 0.9633093335165339], 
             UndirectedEdge[335, 482] -> 
             RGBColor[
              0.7782718910840849, 0.8268101591983519, 0.9785082616956059], 
             UndirectedEdge[214, 423] -> 
             RGBColor[
              0.9897097312748251, 0.990012723681366, 0.8201999133453461], 
             UndirectedEdge[69, 194] -> 
             RGBColor[
              0.6754529322675591, 0.7396020083060415, 0.9174961138826534], 
             UndirectedEdge[111, 312] -> 
             RGBColor[
              0.9476161084707906, 0.9585063010648456, 0.8946002420267618], 
             UndirectedEdge[174, 294] -> 
             RGBColor[
              0.8671597882871085, 0.8966017199218628, 0.962613160598139], 
             UndirectedEdge[212, 295] -> 
             RGBColor[
              0.9389933950784553, 0.9523148927057874, 0.9234841851743569], 
             UndirectedEdge[193, 414] -> 
             RGBColor[
              0.9643445356594723, 0.9725276246056739, 0.9272744132334575], 
             UndirectedEdge[320, 348] -> 
             RGBColor[
              0.9910910039248844, 0.9905839154192534, 0.7973086509148344], 
             UndirectedEdge[247, 468] -> 
             RGBColor[
              0.7884177819192468, 0.8348660931719623, 0.979485041274683], 
             UndirectedEdge[449, 488] -> 
             RGBColor[
              0.9132068898667107, 0.9325798546799802, 0.9551605504445975], 
             UndirectedEdge[290, 355] -> 
             RGBColor[
              0.6090703515728766, 0.6923134367072046, 0.9631853390700101], 
             UndirectedEdge[88, 469] -> 
             RGBColor[
              0.9020780196048664, 0.9245919332158853, 0.9848150815227479], 
             UndirectedEdge[6, 278] -> 
             RGBColor[
              0.8657999021054499, 0.8954968761552589, 0.9603267654944967], 
             UndirectedEdge[24, 448] -> 
             RGBColor[
              0.9198073204349358, 0.937964789618239, 0.9600175216413733], 
             UndirectedEdge[204, 274] -> 
             RGBColor[
              0.9140464379878722, 0.932705944088299, 0.933396937532549], 
             UndirectedEdge[81, 99] -> 
             RGBColor[
              0.6010030142214215, 0.6853626099917496, 0.9628246872903758], 
             UndirectedEdge[213, 368] -> 
             RGBColor[
              0.5789685733219543, 0.6665103002196182, 0.9613302306355436], 
             UndirectedEdge[167, 474] -> 
             RGBColor[
              0.7612865696851604, 0.8116027775282946, 0.9207089218129507], 
             UndirectedEdge[78, 430] -> 
             RGBColor[
              0.8346699224735463, 0.8715449451757266, 0.9758038135820615], 
             UndirectedEdge[110, 316] -> 
             RGBColor[
              0.9644681147816846, 0.9657434304295995, 0.7015025846889962], 
             UndirectedEdge[153, 463] -> 
             RGBColor[
              0.9750230718374275, 0.9787238744562599, 0.8187483042309134], 
             UndirectedEdge[471, 475] -> 
             RGBColor[
              0.876213613908422, 0.9038530546571522, 0.9725470182885858], 
             UndirectedEdge[79, 486] -> 
             RGBColor[
              0.979079790933937, 0.9839183228490044, 0.9202966364711781], 
             UndirectedEdge[49, 402] -> 
             RGBColor[
              0.9334995240050039, 0.9474375167621756, 0.9013912128567573], 
             UndirectedEdge[340, 498] -> 
             RGBColor[
              0.8531325839399007, 0.8849722643445448, 0.92880304051226], 
             UndirectedEdge[248, 313] -> 
             RGBColor[
              0.7242251095967938, 0.784175902153214, 0.9734090645242262], 
             UndirectedEdge[37, 429] -> 
             RGBColor[
              0.9356801425649279, 0.9512138571246374, 0.9820741791056029], 
             UndirectedEdge[18, 166] -> 
             RGBColor[
              0.8338492416264407, 0.8694752312219629, 0.9072588086443485], 
             UndirectedEdge[147, 238] -> 
             RGBColor[
              0.9671631811833881, 0.973385777360988, 0.8667948366669356], 
             UndirectedEdge[165, 441] -> 
             RGBColor[
              0.9023697319645765, 0.8709645083811698, 0.6340463240967404], 
             UndirectedEdge[13, 154] -> 
             RGBColor[
              0.9726727729275142, 0.9780640849759703, 0.8829613002639438], 
             UndirectedEdge[133, 249] -> 
             RGBColor[
              0.9250267745788052, 0.9389582510798341, 0.7987222392342304], 
             UndirectedEdge[84, 385] -> 
             RGBColor[
              0.7188300386822253, 0.7802747566199744, 0.9726099184733574], 
             UndirectedEdge[125, 438] -> 
             RGBColor[
              0.8857970531598872, 0.9111330204970953, 0.963039605138458], 
             UndirectedEdge[21, 489] -> 
             RGBColor[
              0.8998696022185358, 0.9229956107721546, 0.990311560054323], 
             UndirectedEdge[16, 200] -> 
             RGBColor[
              0.8941854096123811, 0.9173941370284733, 0.9490981643480798], 
             UndirectedEdge[402, 436] -> 
             RGBColor[
              0.9637562954490161, 0.9715178179216827, 0.9026952108134851], 
             UndirectedEdge[127, 401] -> 
             RGBColor[
              0.9684837185989811, 0.9753559719898521, 0.9086850490365518], 
             UndirectedEdge[195, 395] -> 
             RGBColor[
              0.9572860638080085, 0.9394523599641562, 0.6692194992354092], 
             UndirectedEdge[27, 297] -> 
             RGBColor[
              0.7376540607663307, 0.7944157519458132, 0.9752286253756568], 
             UndirectedEdge[35, 70] -> 
             RGBColor[
              0.9285557655897495, 0.9452298106116799, 0.9708803761911742], 
             UndirectedEdge[240, 367] -> 
             RGBColor[
              0.7175636762985882, 0.778292645865668, 0.9734316039205537], 
             UndirectedEdge[121, 471] -> 
             RGBColor[
              0.9137606453888663, 0.9336259218176823, 0.976172369895891], 
             UndirectedEdge[184, 424] -> 
             RGBColor[
              0.7523338417230119, 0.8055126151334362, 0.9564448245261135], 
             UndirectedEdge[122, 159] -> 
             RGBColor[
              0.8306115455424911, 0.8684194003276138, 0.9835336301433717], 
             UndirectedEdge[158, 324] -> 
             RGBColor[
              0.9814230329467204, 0.9475346296045642, 0.5067387664901994], 
             UndirectedEdge[180, 465] -> 
             RGBColor[
              0.9897759526407565, 0.9900401079179901, 0.8191024539364613], 
             UndirectedEdge[254, 454] -> 
             RGBColor[
              0.9905817675427684, 0.9837085191293049, 0.6019857402267651], 
             UndirectedEdge[297, 314] -> 
             RGBColor[
              0.753063207678062, 0.8061724444784464, 0.95831797487419], 
             UndirectedEdge[262, 393] -> 
             RGBColor[
              0.9272145788445125, 0.8924428365632748, 0.6367894956598654], 
             UndirectedEdge[201, 333] -> 
             RGBColor[
              0.8608881600045715, 0.66365365281431, 0.5941625096011295], 
             UndirectedEdge[219, 340] -> 
             RGBColor[
              0.9791670568825582, 0.9837146531886266, 0.9081136336420847], 
             UndirectedEdge[361, 370] -> 
             RGBColor[
              0.8378170358919117, 0.8738777277839757, 0.9697512182526135], 
             UndirectedEdge[48, 358] -> 
             RGBColor[
              0.9680055052499754, 0.9756591387183844, 0.9390425134978351], 
             UndirectedEdge[287, 299] -> 
             RGBColor[
              0.7890162594322216, 0.8333167250745345, 0.8895213459599175], 
             UndirectedEdge[62, 233] -> 
             RGBColor[
              0.7529437209562244, 0.8071804933542959, 0.9759421517815476], 
             UndirectedEdge[61, 91] -> 
             RGBColor[
              0.9859905570346081, 0.9865355193500478, 0.770992904342743], 
             UndirectedEdge[204, 340] -> 
             RGBColor[
              0.9139606688375981, 0.932670476340494, 0.9348183543160367], 
             UndirectedEdge[258, 373] -> 
             RGBColor[
              0.6832350122000286, 0.7509362899979183, 0.9701384417884741], 
             UndirectedEdge[167, 210] -> 
             RGBColor[
              0.9097905695609332, 0.9293442984172671, 0.9343748401878778], 
             UndirectedEdge[275, 481] -> 
             RGBColor[
              0.9841549705010981, 0.9860582260126346, 0.8380321695204702], 
             UndirectedEdge[253, 277] -> 
             RGBColor[
              0.8883925973098525, 0.9138336609793997, 0.9888529142280984], 
             UndirectedEdge[193, 485] -> 
             RGBColor[
              0.8339082157636477, 0.8698075140837014, 0.920242745683671], 
             UndirectedEdge[89, 260] -> 
             RGBColor[
              0.9053655707364852, 0.926492076770289, 0.9601220974772567], 
             UndirectedEdge[359, 397] -> 
             RGBColor[
              0.7627373066941294, 0.8150448719649133, 0.9768977871992235], 
             UndirectedEdge[1, 171] -> 
             RGBColor[
              0.7425551905120737, 0.7988308084370811, 0.9751125188066693], 
             UndirectedEdge[193, 330] -> 
             RGBColor[
              0.9855459622478555, 0.9882908981847309, 0.8892043416110589], 
             UndirectedEdge[92, 320] -> 
             RGBColor[
              0.991495341180705, 0.9907511192655287, 0.7906077361946086], 
             UndirectedEdge[126, 279] -> 
             RGBColor[
              0.9822689529611284, 0.9835078419568551, 0.7572886663718816], 
             UndirectedEdge[93, 163] -> 
             RGBColor[
              0.6107534324825633, 0.6890460281670814, 0.9655327225001522], 
             UndirectedEdge[31, 297] -> 
             RGBColor[
              0.7671771518964579, 0.8166498853106542, 0.9322451621927266], 
             UndirectedEdge[127, 325] -> 
             RGBColor[
              0.9688504607322804, 0.9755076292868143, 0.9026071827895644], 
             UndirectedEdge[334, 498] -> 
             RGBColor[
              0.857014469465943, 0.885103566131637, 0.7573289909653519], 
             UndirectedEdge[41, 300] -> 
             RGBColor[
              0.9075161544576786, 0.9286014461044128, 0.9740065962924163], 
             UndirectedEdge[330, 496] -> 
             RGBColor[
              0.9323672165346124, 0.9476015481841906, 0.9476118095482569], 
             UndirectedEdge[18, 227] -> 
             RGBColor[
              0.8191233584944693, 0.8591525091547776, 0.961733861660774], 
             UndirectedEdge[156, 350] -> 
             RGBColor[
              0.9352654523540775, 0.9465818889248567, 0.7558917604240635], 
             UndirectedEdge[315, 386] -> 
             RGBColor[
              0.8185240068524817, 0.8587875097068812, 0.9668990330358644], 
             UndirectedEdge[29, 479] -> 
             RGBColor[
              0.9515874888132945, 0.9632140197515279, 0.9598793796682783], 
             UndirectedEdge[277, 488] -> 
             RGBColor[
              0.908558566110777, 0.9288734074923857, 0.9547171891751489], 
             UndirectedEdge[242, 374] -> 
             RGBColor[
              0.9152659626359678, 0.6334447815636794, 0.4291385328657099], 
             UndirectedEdge[244, 363] -> 
             RGBColor[
              0.9038653230721956, 0.9261816901199097, 0.9906926754763672], 
             UndirectedEdge[335, 409] -> 
             RGBColor[
              0.8583584675382523, 0.88989575876783, 0.9863521909710901], 
             UndirectedEdge[235, 332] -> 
             RGBColor[
              0.9053531418645773, 0.9268749485320342, 0.9737389176818967], 
             UndirectedEdge[249, 440] -> 
             RGBColor[
              0.944330299599976, 0.9543503579514878, 0.8005634266832099], 
             UndirectedEdge[96, 265] -> 
             RGBColor[
              0.8165608794418595, 0.8546266622072722, 0.8477109341866321], 
             UndirectedEdge[39, 200] -> 
             RGBColor[
              0.9843795180859879, 0.9873046277270465, 0.8859689600313729], 
             UndirectedEdge[146, 312] -> 
             RGBColor[
              0.9489650297067225, 0.9577152880520645, 0.7741996706755925], 
             UndirectedEdge[237, 448] -> 
             RGBColor[
              0.6255873602919473, 0.7019493044467142, 0.9664526659372594], 
             UndirectedEdge[31, 162] -> 
             RGBColor[
              0.9735042683775793, 0.9797113915991438, 0.9275529552039895], 
             UndirectedEdge[41, 102] -> 
             RGBColor[
              0.7644614593463444, 0.8154757783618974, 0.960548837449015], 
             UndirectedEdge[266, 374] -> 
             RGBColor[
              0.7797958596060238, 0.529897253785015, 0.5774766163258029], 
             UndirectedEdge[44, 139] -> 
             RGBColor[
              0.8594424395277702, 0.887556836524342, 0.8021455446860462], 
             UndirectedEdge[47, 189] -> 
             RGBColor[
              0.9641882875727663, 0.972152446563624, 0.9159560933360973], 
             UndirectedEdge[208, 359] -> 
             RGBColor[
              0.7963962439575529, 0.8413580722260962, 0.9618880059829988], 
             UndirectedEdge[122, 413] -> 
             RGBColor[
              0.8551344159483899, 0.8870760580703478, 0.9547656894108096], 
             UndirectedEdge[36, 141] -> 
             RGBColor[
              0.8201236932491818, 0.8574331630783752, 0.8456772440965252], 
             UndirectedEdge[179, 347] -> 
             RGBColor[
              0.8257938380350189, 0.8641110981759306, 0.9496202263902922], 
             UndirectedEdge[226, 422] -> 
             RGBColor[
              0.930472008593475, 0.945101901203452, 0.9045087138258278], 
             UndirectedEdge[18, 167] -> 
             RGBColor[
              0.8326750473611539, 0.8689896717178507, 0.9267182463374997], 
             UndirectedEdge[112, 452] -> 
             RGBColor[
              0.8320746788812001, 0.8689377791471338, 0.9838452197451653], 
             UndirectedEdge[323, 342] -> 
             RGBColor[
              0.7649449274004938, 0.8163000581728208, 0.9772062196126579], 
             UndirectedEdge[74, 82] -> 
             RGBColor[
              0.7176410952399257, 0.7793459449665451, 0.9724914157023372], 
             UndirectedEdge[291, 349] -> 
             RGBColor[
              0.8316065328557325, 0.8692062398745157, 0.9836302674621453], 
             UndirectedEdge[86, 136] -> 
             RGBColor[
              0.8364188958925767, 0.8725595672997395, 0.9842176924950998], 
             UndirectedEdge[11, 23] -> 
             RGBColor[
              0.8829495038447968, 0.9091145655204569, 0.9731871285847322], 
             UndirectedEdge[249, 470] -> 
             RGBColor[
              0.9924379497290272, 0.9902173793481466, 0.707855189645098], 
             UndirectedEdge[35, 135] -> 
             RGBColor[
              0.9732796029969364, 0.9792811731705404, 0.9161706533759351], 
             UndirectedEdge[161, 326] -> 
             RGBColor[
              0.859668260434512, 0.8839361792021694, 0.6957207792340347], 
             UndirectedEdge[26, 139] -> 
             RGBColor[
              0.9934767662292351, 0.9884557875014657, 0.5313644446636656], 
             UndirectedEdge[109, 218] -> 
             RGBColor[
              0.9912502797573401, 0.9883018001243769, 0.623995682727874], 
             UndirectedEdge[238, 465] -> 
             RGBColor[
              0.9909647851280179, 0.9905317207030739, 0.799400423022686], 
             UndirectedEdge[258, 314] -> 
             RGBColor[
              0.747038565645719, 0.8012813686695599, 0.957843692984413], 
             UndirectedEdge[28, 493] -> 
             RGBColor[
              0.9872929909132943, 0.9890133394344787, 0.8602515554594805], 
             UndirectedEdge[106, 466] -> 
             RGBColor[
              0.9552715361178956, 0.96616216538964, 0.9605978016873862], 
             UndirectedEdge[45, 236] -> 
             RGBColor[
              0.6775905889256031, 0.738178032577419, 0.7458660281775675], 
             UndirectedEdge[157, 246] -> 
             RGBColor[
              0.9049001537531909, 0.8952717921508693, 0.6649325807334321], 
             UndirectedEdge[371, 427] -> 
             RGBColor[
              0.9333173092025673, 0.9328952822417542, 0.689657658458364], 
             UndirectedEdge[341, 450] -> 
             RGBColor[
              0.9471575548128073, 0.956176067222273, 0.7660839327843972], 
             UndirectedEdge[277, 484] -> 
             RGBColor[
              0.9147890853180796, 0.9327381045849652, 0.9091503637725407], 
             UndirectedEdge[84, 135] -> 
             RGBColor[
              0.8190407908021189, 0.858292327312645, 0.9232662407529157], 
             UndirectedEdge[35, 84] -> 
             RGBColor[
              0.8062541558861152, 0.8490674549404674, 0.9588548667185055], 
             UndirectedEdge[68, 272] -> 
             RGBColor[
              0.9947128748568856, 0.991099698866257, 0.6659072404052562], 
             UndirectedEdge[164, 227] -> 
             RGBColor[
              0.9582899360381176, 0.9684132831079654, 0.955488437947231], 
             UndirectedEdge[355, 498] -> 
             RGBColor[
              0.6090703515728766, 0.6923134367072046, 0.9631853390700101], 
             UndirectedEdge[223, 373] -> 
             RGBColor[
              0.9117778808177078, 0.9291842689287484, 0.8588053377552305], 
             UndirectedEdge[116, 192] -> 
             RGBColor[
              0.9426173138084957, 0.9553207202968255, 0.9288762146078627], 
             UndirectedEdge[3, 31] -> 
             RGBColor[
              0.8657276081097711, 0.8950550783776596, 0.9410990578512104], 
             UndirectedEdge[40, 419] -> 
             RGBColor[
              0.7583295306645734, 0.8111320599638425, 0.9765468586904187], 
             UndirectedEdge[282, 324] -> 
             RGBColor[
              0.9784365908935619, 0.9466520062003085, 0.5818437569633799], 
             UndirectedEdge[250, 339] -> 
             RGBColor[
              0.5852047733314869, 0.673213144383643, 0.9611186305751831], 
             UndirectedEdge[259, 405] -> 
             RGBColor[
              0.9825683220746682, 0.9862513111998417, 0.9023561788638788], 
             UndirectedEdge[22, 441] -> 
             RGBColor[
              0.9742131947890436, 0.9237097765372134, 0.41093793486876806`], 
             UndirectedEdge[142, 241] -> 
             RGBColor[
              0.9925000622322364, 0.9900592379653642, 0.6934635788131374], 
             UndirectedEdge[170, 266] -> 
             RGBColor[
              0.6987968065004198, 0.7646246433813442, 0.9706131931106738], 
             UndirectedEdge[105, 153] -> 
             RGBColor[
              0.9576970036067296, 0.9654122630654318, 0.8345601942500502], 
             UndirectedEdge[95, 404] -> 
             RGBColor[
              0.9861272418744742, 0.9706641565469316, 0.5983788663336853], 
             UndirectedEdge[200, 454] -> 
             RGBColor[
              0.986351527889548, 0.988120104459159, 0.8532876541886041], 
             UndirectedEdge[96, 131] -> 
             RGBColor[
              0.8157008700397892, 0.8526350449092832, 0.7430449447443391], 
             UndirectedEdge[190, 395] -> 
             RGBColor[
              0.9073721498315592, 0.9288497940220537, 0.9865843072142219], 
             UndirectedEdge[297, 381] -> 
             RGBColor[
              0.739271008508948, 0.795705062184899, 0.975382851294814], 
             UndirectedEdge[203, 419] -> 
             RGBColor[
              0.8771500120080395, 0.9048306451165895, 0.9850963296481414], 
             UndirectedEdge[107, 209] -> 
             RGBColor[
              0.9788916387536492, 0.9802912718060699, 0.707640136893782], 
             UndirectedEdge[205, 252] -> 
             RGBColor[
              0.7908680026893871, 0.8372699607319134, 0.9795992953807968], 
             UndirectedEdge[98, 488] -> 
             RGBColor[
              0.9621503025725622, 0.9712923381485841, 0.9489538443492598], 
             UndirectedEdge[182, 275] -> 
             RGBColor[
              0.969681605305136, 0.9769091713951612, 0.9362053133013547], 
             UndirectedEdge[88, 474] -> 
             RGBColor[
              0.739420179732367, 0.795564524509275, 0.9697991572536508], 
             UndirectedEdge[47, 242] -> 
             RGBColor[
              0.9675113203662473, 0.9731190796349833, 0.8312619739623421], 
             UndirectedEdge[133, 262] -> 
             RGBColor[
              0.90588582724016, 0.8754358689875035, 0.6347551402914409], 
             UndirectedEdge[4, 321] -> 
             RGBColor[
              0.9710043682121509, 0.9757698665404425, 0.8289734726253497], 
             UndirectedEdge[369, 370] -> 
             RGBColor[
              0.8431521845676493, 0.8778566729308366, 0.9607202031742187], 
             UndirectedEdge[49, 436] -> 
             RGBColor[
              0.907211595118719, 0.9288042895259059, 0.9894299259772761], 
             UndirectedEdge[34, 393] -> 
             RGBColor[
              0.8766476493973534, 0.9044790559356608, 0.9880966294637565], 
             UndirectedEdge[268, 324] -> 
             RGBColor[
              0.8372407281216881, 0.8371376431693389, 0.650730746242207], 
             UndirectedEdge[359, 371] -> 
             RGBColor[
              0.7598982231651965, 0.8127810638238115, 0.9766269928777541], 
             UndirectedEdge[296, 440] -> 
             RGBColor[
              0.7771849118890846, 0.8264639010085527, 0.9782664680433113], 
             UndirectedEdge[113, 143] -> 
             RGBColor[
              0.9250501720144555, 0.9424489941148624, 0.9710469537739714], 
             UndirectedEdge[270, 489] -> 
             RGBColor[
              0.9256751040839288, 0.9257282738954018, 0.6873497417300052], 
             UndirectedEdge[237, 426] -> 
             RGBColor[
              0.6864643455897901, 0.7481912274169398, 0.883342251446946], 
             UndirectedEdge[131, 385] -> 
             RGBColor[
              0.8895151770057657, 0.9103658699072815, 0.7503565798911871], 
             UndirectedEdge[427, 499] -> 
             RGBColor[
              0.9748334100652625, 0.9652147665441454, 0.666424370929418], 
             UndirectedEdge[45, 243] -> 
             RGBColor[
              0.49781729276290376`, 0.6006979883501291, 0.954297567861871], 
             UndirectedEdge[33, 443] -> 
             RGBColor[
              0.8607789958168681, 0.8920698108769792, 0.9848985801568176], 
             UndirectedEdge[232, 330] -> 
             RGBColor[
              0.8966450610161804, 0.9192080275694916, 0.9441806206168969], 
             UndirectedEdge[19, 360] -> 
             RGBColor[
              0.9606760968933277, 0.9701928779668012, 0.9514492900297837], 
             UndirectedEdge[44, 370] -> 
             RGBColor[
              0.7241404156121096, 0.7844232634379595, 0.9731392072174344], 
             UndirectedEdge[310, 412] -> 
             RGBColor[
              0.9916848036369215, 0.99039204315494, 0.7556717672935266], 
             UndirectedEdge[107, 214] -> 
             RGBColor[
              0.9907314797493546, 0.9883987862155073, 0.6552379914669861], 
             UndirectedEdge[268, 481] -> 
             RGBColor[
              0.8503017073376457, 0.8812376779539047, 0.8594577863546992], 
             UndirectedEdge[224, 351] -> 
             RGBColor[
              0.994677609289845, 0.991024269384253, 0.662068801066741], 
             UndirectedEdge[78, 408] -> 
             RGBColor[
              0.606486311370459, 0.69015213027115, 0.9630253061403807], 
             UndirectedEdge[124, 136] -> 
             RGBColor[
              0.8405836595937348, 0.8758131123564608, 0.9846327972189016], 
             UndirectedEdge[51, 315] -> 
             RGBColor[
              0.7994372918498938, 0.8438768228824527, 0.9649966476598992], 
             UndirectedEdge[24, 270] -> 
             RGBColor[
              0.9772144044494627, 0.9658956965451098, 0.6600698904335053], 
             UndirectedEdge[43, 340] -> 
             RGBColor[
              0.9831160084687449, 0.9866597748157899, 0.9014290886581957], 
             UndirectedEdge[116, 483] -> 
             RGBColor[
              0.9900898797560858, 0.9901699248477376, 0.8138998692181245], 
             UndirectedEdge[50, 169] -> 
             RGBColor[
              0.7845009191073011, 0.8315773475252206, 0.9791553781048594], 
             UndirectedEdge[247, 369] -> 
             RGBColor[
              0.845525682426384, 0.8797108674973321, 0.9609567712591789], 
             UndirectedEdge[327, 412] -> 
             RGBColor[
              0.9751839301998314, 0.9788171597984228, 0.8163588658817381], 
             UndirectedEdge[134, 305] -> 
             RGBColor[
              0.8256192184534001, 0.8639712545070489, 0.9831814910414726], 
             UndirectedEdge[7, 49] -> 
             RGBColor[
              0.8733490772715962, 0.9018488640599372, 0.9877820087097318], 
             UndirectedEdge[81, 486] -> 
             RGBColor[
              0.7184309854463433, 0.777222367180759, 0.9332204521457081], 
             UndirectedEdge[110, 384] -> 
             RGBColor[
              0.9856583522049982, 0.9815470748040775, 0.6656330400303834], 
             UndirectedEdge[18, 88] -> 
             RGBColor[
              0.8108086574083605, 0.8529514186988311, 0.9758084817781999], 
             UndirectedEdge[11, 41] -> 
             RGBColor[
              0.8838101748248299, 0.9097564525281463, 0.9717302371144787], 
             UndirectedEdge[231, 288] -> 
             RGBColor[
              0.9856822775278146, 0.9872680484631511, 0.8386155863007309], 
             UndirectedEdge[236, 396] -> 
             RGBColor[
              0.9273785870366069, 0.9404399821064136, 0.7670448977941645], 
             UndirectedEdge[46, 418] -> 
             RGBColor[
              0.9356499943597223, 0.9503425818506197, 0.9526971025646169], 
             UndirectedEdge[74, 447] -> 
             RGBColor[
              0.8590773609912575, 0.8889597208075953, 0.8996203269109231], 
             UndirectedEdge[270, 426] -> 
             RGBColor[
              0.9861890231390266, 0.971680697698833, 0.6042046976573456], 
             UndirectedEdge[383, 479] -> 
             RGBColor[
              0.954069582310646, 0.9650651610177975, 0.9556778428109259], 
             UndirectedEdge[408, 430] -> 
             RGBColor[
              0.7165576815400607, 0.7769159121432878, 0.9656442497210964], 
             UndirectedEdge[13, 390] -> 
             RGBColor[
              0.9689766509258371, 0.960483217882897, 0.6755665094705742], 
             UndirectedEdge[15, 97] -> 
             RGBColor[
              0.952336252454415, 0.9584543882739802, 0.7067625152555258], 
             UndirectedEdge[289, 472] -> 
             RGBColor[
              0.9119211041986601, 0.932605151321799, 0.99146104307169], 
             UndirectedEdge[254, 315] -> 
             RGBColor[
              0.9712505351641771, 0.9705127855783031, 0.6894083026403013], 
             UndirectedEdge[347, 386] -> 
             RGBColor[
              0.6813918668085738, 0.751027772211633, 0.9688784313805995], 
             UndirectedEdge[66, 445] -> 
             RGBColor[
              0.9898618653265123, 0.9900756350214055, 0.8176786583985831], 
             UndirectedEdge[127, 213] -> 
             RGBColor[
              0.8456391071489497, 0.8800422287878127, 0.9732561952783012], 
             UndirectedEdge[423, 446] -> 
             RGBColor[
              0.9608275206658422, 0.9690681166196315, 0.8970499040526723], 
             UndirectedEdge[63, 410] -> 
             RGBColor[
              0.6531664539713202, 0.7192865962513473, 0.8788802943903429], 
             UndirectedEdge[107, 421] -> 
             RGBColor[
              0.9931026489651852, 0.9893793256225225, 0.6159415811714493], 
             UndirectedEdge[226, 308] -> 
             RGBColor[
              0.981231382234595, 0.9846186123147034, 0.8761552947831626], 
             UndirectedEdge[51, 386] -> 
             RGBColor[
              0.6650795612596434, 0.7382844751386947, 0.9672525732106445], 
             UndirectedEdge[89, 470] -> 
             RGBColor[
              0.9803582314147801, 0.9837964758047444, 0.8699781767458639], 
             UndirectedEdge[205, 490] -> 
             RGBColor[
              0.8309260748482874, 0.8670366121581206, 0.8999382368554361], 
             UndirectedEdge[270, 345] -> 
             RGBColor[
              0.9885926697729455, 0.9726746673528592, 0.564370052495222], 
             UndirectedEdge[152, 191] -> 
             RGBColor[
              0.8103033225110772, 0.8518565052069602, 0.981694712574481], 
             UndirectedEdge[85, 404] -> 
             RGBColor[
              0.99270791912214, 0.9911911459520882, 0.766048653373004], 
             UndirectedEdge[26, 468] -> 
             RGBColor[
              0.9204298349714878, 0.934185228604463, 0.7085023799141696], 
             UndirectedEdge[191, 301] -> 
             RGBColor[
              0.8696525126750697, 0.89890132379124, 0.9874294270785529], 
             UndirectedEdge[375, 426] -> 
             RGBColor[
              0.8226607154854161, 0.8604597570841312, 0.8936779417896583], 
             UndirectedEdge[39, 213] -> 
             RGBColor[
              0.8650372509706812, 0.893943109734064, 0.9150635768726989], 
             UndirectedEdge[360, 468] -> 
             RGBColor[
              0.9004998146891451, 0.9230597095957888, 0.97517152989627], 
             UndirectedEdge[80, 278] -> 
             RGBColor[
              0.7074017694576169, 0.7713469058436472, 0.9714708554002964], 
             UndirectedEdge[152, 299] -> 
             RGBColor[
              0.8876682556312439, 0.9112139200792952, 0.898786917345965], 
             UndirectedEdge[227, 309] -> 
             RGBColor[
              0.9657165495245957, 0.9739520392862172, 0.9429171184856376], 
             UndirectedEdge[98, 115] -> 
             RGBColor[
              0.8138855622226147, 0.8552527837412698, 0.9709349078984535], 
             UndirectedEdge[213, 261] -> 
             RGBColor[
              0.8675397725096066, 0.8926687493763095, 0.7057345963939006], 
             UndirectedEdge[199, 208] -> 
             RGBColor[
              0.9220759117363376, 0.9401767965422771, 0.9742094169798393], 
             UndirectedEdge[204, 219] -> 
             RGBColor[
              0.9073180635334284, 0.9279851846428867, 0.9580978367677472], 
             UndirectedEdge[52, 166] -> 
             RGBColor[
              0.7150447588338991, 0.7732845678358378, 0.8976021885927976], 
             UndirectedEdge[218, 300] -> 
             RGBColor[
              0.9251104145095707, 0.9407682205668657, 0.9014574368312533], 
             UndirectedEdge[128, 345] -> 
             RGBColor[
              0.993700322182069, 0.9896377155409541, 0.6068533775270698], 
             UndirectedEdge[325, 421] -> 
             RGBColor[
              0.9910904614964509, 0.9905836911111563, 0.7973176403577367], 
             UndirectedEdge[257, 272] -> 
             RGBColor[
              0.985088468600793, 0.9598803102406774, 0.5225679380619161], 
             UndirectedEdge[461, 486] -> 
             RGBColor[
              0.8968897735881356, 0.9195005084150432, 0.9490488908963643], 
             UndirectedEdge[115, 203] -> 
             RGBColor[
              0.8095027405155912, 0.8519840824883835, 0.9783538818254682], 
             UndirectedEdge[128, 169] -> 
             RGBColor[
              0.9061344368646063, 0.9230426711672237, 0.7274806948181859], 
             UndirectedEdge[190, 356] -> 
             RGBColor[
              0.8878782863568386, 0.9134340609996352, 0.9891678176426602], 
             UndirectedEdge[46, 272] -> 
             RGBColor[
              0.9882457641214285, 0.9886484457253327, 0.8013731655442087], 
             UndirectedEdge[121, 450] -> 
             RGBColor[
              0.9340490810429976, 0.9457237260582683, 0.7648336348541601], 
             UndirectedEdge[255, 269] -> 
             RGBColor[
              0.8724649834764624, 0.9011439116657843, 0.987697683054312], 
             UndirectedEdge[15, 356] -> 
             RGBColor[
              0.9466516537331156, 0.9539216435579378, 0.7062203131547871], 
             UndirectedEdge[85, 183] -> 
             RGBColor[
              0.9152769994961764, 0.9318543732451658, 0.8521312706447352], 
             UndirectedEdge[136, 261] -> 
             RGBColor[
              0.9324928823370395, 0.9438341141540423, 0.712096131025539], 
             UndirectedEdge[295, 336] -> 
             RGBColor[
              0.8971430929288248, 0.9208215662736621, 0.9900515031642867], 
             UndirectedEdge[259, 475] -> 
             RGBColor[
              0.8926206832429779, 0.915820667640779, 0.9327388452135221], 
             UndirectedEdge[51, 143] -> 
             RGBColor[
              0.8029627558294763, 0.8465061081460079, 0.959028956730734], 
             UndirectedEdge[53, 178] -> 
             RGBColor[
              0.9426322687777019, 0.9542499220832871, 0.8818620745349025], 
             UndirectedEdge[67, 385] -> 
             RGBColor[
              0.8772301609118929, 0.9043671006883411, 0.9584703186508546], 
             UndirectedEdge[69, 173] -> 
             RGBColor[
              0.55604794390199, 0.6464798898422444, 0.9599449650449676], 
             UndirectedEdge[221, 381] -> 
             RGBColor[
              0.8808500013330312, 0.9078298972993658, 0.9884974535428653], 
             UndirectedEdge[140, 334] -> 
             RGBColor[
              0.9820814449946302, 0.9831243969885114, 0.7382773048532892], 
             UndirectedEdge[57, 370] -> 
             RGBColor[
              0.7135934364306762, 0.776183883141413, 0.9720879828997533], 
             UndirectedEdge[432, 467] -> 
             RGBColor[
              0.9540290042859978, 0.9647181217511429, 0.9429061299494235], 
             UndirectedEdge[235, 440] -> 
             RGBColor[
              0.8751675137472938, 0.9032988359455152, 0.9879554528041211], 
             UndirectedEdge[229, 390] -> 
             RGBColor[
              0.9885679867710713, 0.972261628298922, 0.48131676436512966`], 
             UndirectedEdge[12, 198] -> 
             RGBColor[
              0.9768726115504034, 0.9811721933205667, 0.8747717279841349], 
             UndirectedEdge[232, 400] -> 
             RGBColor[
              0.8824987193439928, 0.9087064247692919, 0.9703082737370203], 
             UndirectedEdge[143, 273] -> 
             RGBColor[
              0.9771677910205614, 0.9800375787790077, 0.7924389634400727], 
             UndirectedEdge[115, 277] -> 
             RGBColor[
              0.7602938257608295, 0.8128338530850714, 0.9766982527243426], 
             UndirectedEdge[44, 468] -> 
             RGBColor[
              0.7863955082700229, 0.8332862776273393, 0.9792834799365502], 
             UndirectedEdge[183, 346] -> 
             RGBColor[
              0.9064517594843273, 0.9271645555964176, 0.9535128208062547], 
             UndirectedEdge[434, 469] -> 
             RGBColor[
              0.9277127264216045, 0.9421884820994721, 0.8732740835550512], 
             UndirectedEdge[255, 334] -> 
             RGBColor[
              0.9312038359643764, 0.9434557013936857, 0.7646187157359636], 
             UndirectedEdge[65, 210] -> 
             RGBColor[
              0.893817572688417, 0.9177013283079727, 0.9734890983867568], 
             UndirectedEdge[49, 76] -> 
             RGBColor[
              0.7680182000598368, 0.8191613960907477, 0.9773903390796104], 
             UndirectedEdge[74, 395] -> 
             RGBColor[
              0.834720765117458, 0.871656774616874, 0.9794591170473927], 
             UndirectedEdge[52, 88] -> 
             RGBColor[
              0.6920041746158189, 0.7567607553127058, 0.9661518617266491], 
             UndirectedEdge[312, 354] -> 
             RGBColor[
              0.9328387877130371, 0.9486198844482494, 0.9704189481141352], 
             UndirectedEdge[372, 417] -> 
             RGBColor[
              0.9680205519428836, 0.9668873063529979, 0.6922932886530067], 
             UndirectedEdge[354, 415] -> 
             RGBColor[
              0.9724005902970636, 0.9789369859502115, 0.9316027809348819], 
             UndirectedEdge[301, 451] -> 
             RGBColor[
              0.946501718965918, 0.9580454723660767, 0.9130685600700951], 
             UndirectedEdge[243, 428] -> 
             RGBColor[
              0.6942704717209165, 0.7609617845123993, 0.9702487795867762], 
             UndirectedEdge[102, 354] -> 
             RGBColor[
              0.7678185849156283, 0.8179795171146809, 0.9548660995387961], 
             UndirectedEdge[255, 369] -> 
             RGBColor[
              0.9156747082113198, 0.9349066578862697, 0.9678437926265998], 
             UndirectedEdge[300, 409] -> 
             RGBColor[
              0.8723840057397053, 0.9010793422165764, 0.9876899593254904], 
             UndirectedEdge[93, 187] -> 
             RGBColor[
              0.9172893554780961, 0.8963212337109747, 0.6531251119305246], 
             UndirectedEdge[181, 332] -> 
             RGBColor[
              0.948333085218092, 0.9609874800692371, 0.9723427892229333], 
             UndirectedEdge[195, 351] -> 
             RGBColor[
              0.9841903358271398, 0.9571142385028404, 0.4966692375395002], 
             UndirectedEdge[480, 481] -> 
             RGBColor[
              0.9693451415012869, 0.9750130797934449, 0.8631013469951263], 
             UndirectedEdge[47, 365] -> 
             RGBColor[
              0.7384855092745826, 0.7948674488122417, 0.9713813105375826], 
             UndirectedEdge[50, 370] -> 
             RGBColor[
              0.7367282912809732, 0.7942570075818742, 0.9743938490237205], 
             UndirectedEdge[122, 150] -> 
             RGBColor[
              0.6677891137311351, 0.7396879936921987, 0.9680102578431538], 
             UndirectedEdge[246, 256] -> 
             RGBColor[
              0.9808097419153989, 0.9534951166564114, 0.583030711075226], 
             UndirectedEdge[63, 282] -> 
             RGBColor[
              0.6526466637454651, 0.7190716496349566, 0.887494563606747], 
             UndirectedEdge[230, 391] -> 
             RGBColor[
              0.8256762572861676, 0.8643654351385539, 0.9830943973531683], 
             UndirectedEdge[312, 415] -> 
             RGBColor[
              0.9437733806851866, 0.9567748859831258, 0.951909534410882], 
             UndirectedEdge[199, 397] -> 
             RGBColor[
              0.888416974472914, 0.9138635962810944, 0.9892191981960641], 
             UndirectedEdge[129, 328] -> 
             RGBColor[
              0.9403351750034042, 0.955022651726499, 0.9858811650273349], 
             UndirectedEdge[188, 304] -> 
             RGBColor[
              0.8552101900362024, 0.8873925777247877, 0.9677989589026261], 
             UndirectedEdge[323, 395] -> 
             RGBColor[
              0.8663730058379047, 0.8963837456336262, 0.9826139165954], 
             UndirectedEdge[49, 238] -> 
             RGBColor[
              0.935524639027663, 0.9482749538671273, 0.8678298161016181], 
             UndirectedEdge[171, 385] -> 
             RGBColor[
              0.70279158470172, 0.7674019400241568, 0.9712461769513419], 
             UndirectedEdge[117, 425] -> 
             RGBColor[
              0.7818173774670496, 0.8294809444001843, 0.9788879077532816], 
             UndirectedEdge[32, 103] -> 
             RGBColor[
              0.9061255595524128, 0.5628478200718033, 0.42699431188742637`], 
             UndirectedEdge[131, 216] -> 
             RGBColor[
              0.9905767723398099, 0.9887352861346768, 0.6869122282006141], 
             UndirectedEdge[65, 175] -> 
             RGBColor[
              0.9608138780089868, 0.9702956348972639, 0.9512160625400432], 
             UndirectedEdge[143, 226] -> 
             RGBColor[
              0.9747840847494631, 0.9798102284067727, 0.8870688877009969], 
             UndirectedEdge[234, 235] -> 
             RGBColor[
              0.8324703580040163, 0.8693416194425472, 0.9838595181812482], 
             UndirectedEdge[179, 386] -> 
             RGBColor[
              0.8285682474886766, 0.8662784879274208, 0.9498967535963023], 
             UndirectedEdge[267, 476] -> 
             RGBColor[
              0.5801260491904193, 0.6608236260508169, 0.9636467529941557], 
             UndirectedEdge[59, 195] -> 
             RGBColor[
              0.9842517129737699, 0.9572455180133009, 0.5033497611743548], 
             UndirectedEdge[75, 108] -> 
             RGBColor[
              0.8767446083201575, 0.9045563683488251, 0.9881058774923699], 
             UndirectedEdge[334, 363] -> 
             RGBColor[
              0.9581004464919887, 0.9649023285393604, 0.7671841384589749], 
             UndirectedEdge[77, 329] -> 
             RGBColor[
              0.7326671497877455, 0.7907167573823837, 0.974433649192592], 
             UndirectedEdge[328, 462] -> 
             RGBColor[
              0.9677956890120107, 0.9735571591818832, 0.8487125768881834], 
             UndirectedEdge[285, 480] -> 
             RGBColor[
              0.9508488137577441, 0.9628637062949823, 0.9680843170123896], 
             UndirectedEdge[204, 334] -> 
             RGBColor[
              0.9178425543636404, 0.9328017781275862, 0.7633443047691285], 
             UndirectedEdge[70, 238] -> 
             RGBColor[
              0.9453565087395928, 0.9561146198964263, 0.8687675886117557], 
             UndirectedEdge[83, 270] -> 
             RGBColor[
              0.9862830190322313, 0.9717195674162573, 0.60264694245337], 
             UndirectedEdge[112, 190] -> 
             RGBColor[
              0.858012653094073, 0.8896200157169245, 0.9863192068806921], 
             UndirectedEdge[263, 453] -> 
             RGBColor[
              0.9947935902642085, 0.9912723409609412, 0.674692614374597], 
             UndirectedEdge[210, 474] -> 
             RGBColor[
              0.6852619855280362, 0.7525448601699969, 0.9703406196962119], 
             UndirectedEdge[96, 392] -> 
             RGBColor[
              0.7163027661872385, 0.7782339047522419, 0.9724035087073646], 
             UndirectedEdge[70, 84] -> 
             RGBColor[
              0.7743169533949321, 0.8242409647537845, 0.9779759635681549], 
             UndirectedEdge[77, 278] -> 
             RGBColor[
              0.6771680406771783, 0.7468985813443756, 0.9690245775054726], 
             UndirectedEdge[238, 265] -> 
             RGBColor[
              0.994600046761569, 0.9920349948105099, 0.7391547299992098], 
             UndirectedEdge[157, 392] -> 
             RGBColor[
              0.8162280960045756, 0.8565073991011553, 0.9822792901591065], 
             UndirectedEdge[145, 294] -> 
             RGBColor[
              0.8597226873238291, 0.8910551422005841, 0.9752022326223848], 
             UndirectedEdge[29, 383] -> 
             RGBColor[
              0.9777366910759062, 0.9829166411740091, 0.9225701541942788], 
             UndirectedEdge[210, 227] -> 
             RGBColor[
              0.8962388806942487, 0.9195071358541939, 0.9693904555111521], 
             UndirectedEdge[45, 276] -> 
             RGBColor[
              0.672991015656603, 0.7377056666224134, 0.9260151984572027], 
             UndirectedEdge[57, 219] -> 
             RGBColor[
              0.8379610665185708, 0.8736241216788792, 0.9512324407113473], 
             UndirectedEdge[291, 311] -> 
             RGBColor[
              0.935378295936161, 0.9509887404031314, 0.9825851267138963], 
             UndirectedEdge[11, 485] -> 
             RGBColor[
              0.7470391687420677, 0.8023119434200523, 0.9754215409284142], 
             UndirectedEdge[13, 338] -> 
             RGBColor[
              0.9731494842250197, 0.9782612173484104, 0.8750609603749874], 
             UndirectedEdge[190, 351] -> 
             RGBColor[
              0.9342764218506905, 0.9465116725607379, 0.8140340455183128], 
             UndirectedEdge[314, 397] -> 
             RGBColor[
              0.9225088167056861, 0.9405173629344705, 0.9740905198525571], 
             UndirectedEdge[339, 365] -> 
             RGBColor[
              0.6196353974704736, 0.7011654761416138, 0.9638291354309361], 
             UndirectedEdge[320, 337] -> 
             RGBColor[
              0.8510921591802969, 0.8827338812008797, 0.89938039053018], 
             UndirectedEdge[317, 357] -> 
             RGBColor[
              0.948145562697724, 0.9608476260805867, 0.9726602159362098], 
             UndirectedEdge[153, 452] -> 
             RGBColor[
              0.9085066548453897, 0.9261892141995862, 0.8298683748724508], 
             UndirectedEdge[308, 423] -> 
             RGBColor[
              0.9818525824379003, 0.9848754945628871, 0.8658603997998024], 
             UndirectedEdge[149, 441] -> 
             RGBColor[
              0.9436989800394131, 0.8144922475986595, 0.2735570816661645], 
             UndirectedEdge[486, 493] -> 
             RGBColor[
              0.9845160768675563, 0.9874202002330228, 0.8863525332613157], 
             UndirectedEdge[241, 402] -> 
             RGBColor[
              0.9905229829572051, 0.990349024151645, 0.8067222283404207], 
             UndirectedEdge[293, 432] -> 
             RGBColor[
              0.8295109953805313, 0.8666130048244267, 0.9307157812771609], 
             UndirectedEdge[23, 211] -> 
             RGBColor[
              0.8034868255141993, 0.8470377172698706, 0.965267031429687], 
             UndirectedEdge[8, 381] -> 
             RGBColor[
              0.8415678562903752, 0.8770369648185457, 0.9846101522527875], 
             UndirectedEdge[238, 343] -> 
             RGBColor[
              0.9730442461027249, 0.9777718659484694, 0.8568397277858869], 
             UndirectedEdge[355, 363] -> 
             RGBColor[
              0.7101563285989224, 0.772112199114928, 0.9730404865636332], 
             UndirectedEdge[66, 398] -> 
             RGBColor[
              0.9682600901137842, 0.9749027191848493, 0.8962348349554545], 
             UndirectedEdge[113, 477] -> 
             RGBColor[
              0.9174836791064622, 0.9368059160930762, 0.9838550526097938], 
             UndirectedEdge[7, 241] -> 
             RGBColor[
              0.9303725362237973, 0.9447603714494066, 0.8931130241933951], 
             UndirectedEdge[161, 259] -> 
             RGBColor[
              0.9881864764352863, 0.9841149249487182, 0.6513373733902397], 
             UndirectedEdge[346, 408] -> 
             RGBColor[
              0.7329672055414189, 0.7891541082753712, 0.9378672058760986], 
             UndirectedEdge[33, 270] -> 
             RGBColor[
              0.8833901055824611, 0.8923017153998005, 0.6832395104604101], 
             UndirectedEdge[197, 270] -> 
             RGBColor[
              0.7355465961463421, 0.7744463894470947, 0.6701166116096033], 
             UndirectedEdge[115, 381] -> 
             RGBColor[
              0.8042907412968405, 0.8479157992690292, 0.9808947178046775], 
             UndirectedEdge[112, 224] -> 
             RGBColor[
              0.9184138405332276, 0.9341326125404398, 0.8343539624291203], 
             UndirectedEdge[133, 296] -> 
             RGBColor[
              0.7578813868679136, 0.811071794136899, 0.9764252805943318], 
             UndirectedEdge[204, 244] -> 
             RGBColor[
              0.8636074309438473, 0.8940811397081355, 0.9868528417865208], 
             UndirectedEdge[116, 280] -> 
             RGBColor[
              0.9905106871009799, 0.989385271270991, 0.7372409425310069], 
             UndirectedEdge[81, 267] -> 
             RGBColor[
              0.37292807060211774`, 0.4956920246667357, 0.945060588160131], 
             UndirectedEdge[431, 459] -> 
             RGBColor[
              0.9448045724765579, 0.9560818168491303, 0.8864011406701113], 
             UndirectedEdge[46, 293] -> 
             RGBColor[
              0.8276559393624784, 0.86541321723954, 0.9420828233672284], 
             UndirectedEdge[145, 358] -> 
             RGBColor[
              0.964413044525948, 0.9729798873925193, 0.9451236124397961], 
             UndirectedEdge[12, 480] -> 
             RGBColor[
              0.9677045049128885, 0.974334634401705, 0.8902909410962758], 
             UndirectedEdge[318, 321] -> 
             RGBColor[
              0.9641291889493728, 0.9540423088821429, 0.6777736147446121], 
             UndirectedEdge[38, 47] -> 
             RGBColor[
              0.9423557423886982, 0.9565295875740759, 0.9824608714924074], 
             UndirectedEdge[271, 492] -> 
             RGBColor[
              0.804840375524873, 0.8481390614078119, 0.9810041971357732], 
             UndirectedEdge[246, 333] -> 
             RGBColor[
              0.9139704392031652, 0.674244977502849, 0.27336674696110885`], 
             UndirectedEdge[97, 137] -> 
             RGBColor[
              0.9397400228056534, 0.9539947269280185, 0.966638831792283], 
             UndirectedEdge[406, 486] -> 
             RGBColor[
              0.9857794107680526, 0.9879426212670785, 0.8654158211267584], 
             UndirectedEdge[272, 306] -> 
             RGBColor[
              0.9181784227277052, 0.9339619920073389, 0.8357173032058869], 
             UndirectedEdge[50, 219] -> 
             RGBColor[
              0.861095921368868, 0.8916972461193404, 0.9535383068353145], 
             UndirectedEdge[326, 405] -> 
             RGBColor[
              0.8540501060738939, 0.8860725654532928, 0.9467395847076738], 
             UndirectedEdge[180, 343] -> 
             RGBColor[
              0.9718554136154636, 0.9772802531633855, 0.8765417586996622], 
             UndirectedEdge[229, 380] -> 
             RGBColor[
              0.8750680079358734, 0.8994018284692125, 0.7747229473987631], 
             UndirectedEdge[184, 470] -> 
             RGBColor[
              0.9744858747012237, 0.9794168817828757, 0.8799185449059898], 
             UndirectedEdge[188, 483] -> 
             RGBColor[
              0.8738959493455289, 0.8998103777707944, 0.8681893135189382], 
             UndirectedEdge[364, 374] -> 
             RGBColor[
              0.9122788994101974, 0.6326170805425926, 0.5082647670411309], 
             UndirectedEdge[161, 469] -> 
             RGBColor[
              0.9263184780405535, 0.9363440308527238, 0.702273572724792], 
             UndirectedEdge[14, 182] -> 
             RGBColor[
              0.9793025101294586, 0.9809709766803804, 0.736562625762111], 
             UndirectedEdge[374, 391] -> 
             RGBColor[
              0.8663060298210723, 0.5981012567424984, 0.5859341879533859], 
             UndirectedEdge[352, 367] -> 
             RGBColor[
              0.701729921772986, 0.76566723980277, 0.9719213662789422], 
             UndirectedEdge[8, 289] -> 
             RGBColor[
              0.8265177802917409, 0.8650364427406646, 0.9831746625686764], 
             UndirectedEdge[160, 275] -> 
             RGBColor[
              0.95794034881134, 0.9681525615266312, 0.956080197935214], 
             UndirectedEdge[118, 151] -> 
             RGBColor[
              0.7778396365132902, 0.8263735029351567, 0.9784914437091136], 
             UndirectedEdge[43, 217] -> 
             RGBColor[
              0.8861862166902741, 0.9111581461526205, 0.9489609334178623], 
             UndirectedEdge[117, 154] -> 
             RGBColor[
              0.8892160016780488, 0.9122677481192529, 0.8918999946055751], 
             UndirectedEdge[139, 468] -> 
             RGBColor[
              0.9213463079761726, 0.9361454716918491, 0.8082548106583347], 
             UndirectedEdge[279, 324] -> 
             RGBColor[
              0.9692936212461616, 0.9406154782008336, 0.6323526862722602], 
             UndirectedEdge[4, 29] -> 
             RGBColor[
              0.9850648911100708, 0.9862561814957179, 0.8051726749308648], 
             UndirectedEdge[239, 393] -> 
             RGBColor[
              0.9292622818498739, 0.8993601041428274, 0.6446929564167936], 
             UndirectedEdge[94, 127] -> 
             RGBColor[
              0.9699028182642202, 0.9759428061706263, 0.8851668950713322], 
             UndirectedEdge[157, 459] -> 
             RGBColor[
              0.9149195280057084, 0.9322522935959967, 0.8835506784497875], 
             UndirectedEdge[48, 85] -> 
             RGBColor[
              0.9752972550867951, 0.9792052819054554, 0.8402567622043471], 
             UndirectedEdge[26, 215] -> 
             RGBColor[
              0.8622978437481252, 0.8885432125924857, 0.7027690594134763], 
             UndirectedEdge[63, 165] -> 
             RGBColor[
              0.5831278103030109, 0.6657934117211362, 0.9634615604651517], 
             UndirectedEdge[165, 282] -> 
             RGBColor[
              0.9193818323959655, 0.9363999246880725, 0.9095748868274605], 
             UndirectedEdge[288, 465] -> 
             RGBColor[
              0.9907518293888579, 0.9904436580322185, 0.8029296507323538], 
             UndirectedEdge[200, 500] -> 
             RGBColor[
              0.9868782269183778, 0.9883379080431277, 0.8445588882275008], 
             UndirectedEdge[293, 353] -> 
             RGBColor[
              0.8160958871131283, 0.8083006102478263, 0.6306344727213404], 
             UndirectedEdge[239, 296] -> 
             RGBColor[
              0.8099728369150944, 0.8055356708954557, 0.6329717059424971], 
             UndirectedEdge[139, 274] -> 
             RGBColor[
              0.9901872198605981, 0.989443455485348, 0.7565540965156148], 
             UndirectedEdge[140, 361] -> 
             RGBColor[
              0.9612171685658362, 0.9705964083342344, 0.9505333968223202], 
             UndirectedEdge[83, 197] -> 
             RGBColor[
              0.7391104933228627, 0.7927962752078739, 0.8853960731231824], 
             UndirectedEdge[256, 444] -> 
             RGBColor[
              0.9687243475217622, 0.9752825044599576, 0.8969510860818217], 
             UndirectedEdge[21, 166] -> 
             RGBColor[
              0.9596358301867778, 0.9686388450963865, 0.9195576922533705], 
             UndirectedEdge[92, 363] -> 
             RGBColor[
              0.9581516712011336, 0.9663974689108408, 0.8734763728458237], 
             UndirectedEdge[41, 212] -> 
             RGBColor[
              0.9711039486426631, 0.9774276586370267, 0.9095126196981067], 
             UndirectedEdge[96, 433] -> 
             RGBColor[
              0.7880466628441329, 0.8351739581313735, 0.9771747151123007], 
             UndirectedEdge[346, 407] -> 
             RGBColor[
              0.8455418640814407, 0.8794571398548512, 0.9474748352757327], 
             UndirectedEdge[32, 155] -> 
             RGBColor[
              0.9647691563782352, 0.9711311330124333, 0.8416976954648934], 
             UndirectedEdge[302, 477] -> 
             RGBColor[
              0.8142746555521447, 0.8556109739283926, 0.9737186773153712], 
             UndirectedEdge[24, 489] -> 
             RGBColor[
              0.9201703866776809, 0.9382542887850334, 0.9600521512237195], 
             UndirectedEdge[359, 427] -> 
             RGBColor[
              0.8101334045667029, 0.836066611710052, 0.6775742955780893], 
             UndirectedEdge[217, 290] -> 
             RGBColor[
              0.7562027921614297, 0.8094706356813754, 0.9763348852719266], 
             UndirectedEdge[40, 297] -> 
             RGBColor[
              0.6256625263842326, 0.7060747602515063, 0.9642925443578819], 
             UndirectedEdge[41, 456] -> 
             RGBColor[
              0.8963092627811102, 0.9196653748844877, 0.9729376729597948], 
             UndirectedEdge[341, 469] -> 
             RGBColor[
              0.8814081900984989, 0.9082749818693194, 0.9885506940856166], 
             UndirectedEdge[169, 498] -> 
             RGBColor[
              0.769894976374164, 0.8201670740528177, 0.9776995942335156], 
             UndirectedEdge[6, 329] -> 
             RGBColor[
              0.9212990112160171, 0.939315052193267, 0.9657358371816162], 
             UndirectedEdge[92, 219] -> 
             RGBColor[
              0.9831001671177455, 0.985341095347199, 0.8429318184820253], 
             UndirectedEdge[341, 387] -> 
             RGBColor[
              0.9457484968997414, 0.9570682390268335, 0.8966419463261438], 
             UndirectedEdge[13, 478] -> 
             RGBColor[
              0.9059580936341627, 0.9273610034120049, 0.9739243021186922], 
             UndirectedEdge[33, 267] -> 
             RGBColor[
              0.5372849284107823, 0.6269536307461405, 0.9594834782852126], 
             UndirectedEdge[10, 123] -> 
             RGBColor[
              0.9677826924372117, 0.9754929652874478, 0.9394196774709553], 
             UndirectedEdge[57, 337] -> 
             RGBColor[
              0.7081336000575198, 0.7719186174704099, 0.971543797435149], 
             UndirectedEdge[70, 135] -> 
             RGBColor[
              0.9413424005057534, 0.9544546829838576, 0.9352917502255844], 
             UndirectedEdge[51, 130] -> 
             RGBColor[
              0.8108168315958069, 0.8264333427028332, 0.6626098953907587], 
             UndirectedEdge[219, 361] -> 
             RGBColor[
              0.9621846659798063, 0.9713179663214419, 0.9488956760642074], 
             UndirectedEdge[70, 131] -> 
             RGBColor[
              0.9450020917184724, 0.9543320780410917, 0.7557226249859845], 
             UndirectedEdge[61, 362] -> 
             RGBColor[
              0.9847064007797132, 0.9868644983489226, 0.8547883895048383], 
             UndirectedEdge[49, 487] -> 
             RGBColor[
              0.9347582480159349, 0.947958031488427, 0.880530898522313], 
             UndirectedEdge[83, 375] -> 
             RGBColor[
              0.8227547113786208, 0.8604986268015558, 0.8921201865856827], 
             UndirectedEdge[147, 385] -> 
             RGBColor[
              0.8629383208296548, 0.8937082697557486, 0.9826626760012058], 
             UndirectedEdge[105, 395] -> 
             RGBColor[
              0.9306245243800264, 0.9473906063181083, 0.9888021394562945], 
             UndirectedEdge[57, 204] -> 
             RGBColor[
              0.7727546784736108, 0.8225799448307466, 0.9779371613852994], 
             UndirectedEdge[362, 363] -> 
             RGBColor[
              0.9571721245756306, 0.9659924012079952, 0.8897099954158153], 
             UndirectedEdge[313, 390] -> 
             RGBColor[
              0.9085883937260784, 0.9128206659346574, 0.6867746072717413], 
             UndirectedEdge[15, 430] -> 
             RGBColor[
              0.9681820135045418, 0.9708561921839827, 0.7001895456993267], 
             UndirectedEdge[104, 430] -> 
             RGBColor[
              0.9562962959806999, 0.9307628760768752, 0.6540157775486184], 
             UndirectedEdge[341, 405] -> 
             RGBColor[
              0.940034848381172, 0.9538972422789215, 0.9551365224245689], 
             UndirectedEdge[8, 311] -> 
             RGBColor[
              0.8512959522468453, 0.8844733455904613, 0.9744247424832906], 
             UndirectedEdge[305, 460] -> 
             RGBColor[
              0.760737005996178, 0.8130127979903823, 0.9767868133323369], 
             UndirectedEdge[451, 456] -> 
             RGBColor[
              0.913329319603275, 0.9315947015550985, 0.9099045470055357], 
             UndirectedEdge[257, 306] -> 
             RGBColor[
              0.9083630305854636, 0.9023341038829213, 0.6715903657834846], 
             UndirectedEdge[65, 167] -> 
             RGBColor[
              0.9698421568455413, 0.9767592456662703, 0.9238574005034956], 
             UndirectedEdge[24, 329] -> 
             RGBColor[
              0.9244173906217876, 0.9416407344482131, 0.9604572342512534], 
             UndirectedEdge[14, 63] -> 
             RGBColor[
              0.6549249689613663, 0.718439639947936, 0.7353132485121014], 
             UndirectedEdge[64, 172] -> 
             RGBColor[
              0.71892111437804, 0.7803459056457457, 0.9726189960475655], 
             UndirectedEdge[50, 361] -> 
             RGBColor[
              0.850756135770286, 0.883985850949763, 0.9710408668057267], 
             UndirectedEdge[253, 291] -> 
             RGBColor[
              0.9293667726113374, 0.9465053561504442, 0.9927610676464322], 
             UndirectedEdge[184, 280] -> 
             RGBColor[
              0.9762390299589878, 0.9791831883078802, 0.7811791652967506], 
             UndirectedEdge[402, 487] -> 
             RGBColor[
              0.9913029483462321, 0.9906715598842039, 0.7937961833585221], 
             UndirectedEdge[356, 463] -> 
             RGBColor[
              0.9284567291360037, 0.9452864846865181, 0.975573759865596], 
             UndirectedEdge[287, 301] -> 
             RGBColor[
              0.7462103917381453, 0.8015157708921231, 0.975725415700016], 
             UndirectedEdge[265, 328] -> 
             RGBColor[
              0.9677814781262128, 0.9736789076813517, 0.8582250830582606], 
             UndirectedEdge[196, 321] -> 
             RGBColor[
              0.9705279640990725, 0.9747508863144124, 0.7771198249421544], 
             UndirectedEdge[122, 267] -> 
             RGBColor[
              0.5151428424659394, 0.6096560649199433, 0.9572765620877883], 
             UndirectedEdge[330, 354] -> 
             RGBColor[
              0.9729756121570756, 0.9793171206554873, 0.9284478322896774], 
             UndirectedEdge[155, 393] -> 
             RGBColor[
              0.9165528885293452, 0.9362984104206511, 0.9919028267959935], 
             UndirectedEdge[291, 319] -> 
             RGBColor[
              0.8743657428086563, 0.9026595255625381, 0.9878789791762446], 
             UndirectedEdge[63, 206] -> 
             RGBColor[
              0.4830781288310734, 0.587392339485957, 0.953553630084104], 
             UndirectedEdge[174, 215] -> 
             RGBColor[
              0.8475541821271161, 0.8812856713815511, 0.9606590570009172], 
             UndirectedEdge[254, 471] -> 
             RGBColor[
              0.9713074282016193, 0.9705552163124737, 0.6893119975679924], 
             UndirectedEdge[453, 463] -> 
             RGBColor[
              0.9749483282830482, 0.9785640055511748, 0.8106129296004656], 
             UndirectedEdge[154, 174] -> 
             RGBColor[
              0.9768704712944296, 0.9811947215449157, 0.8758556918638318], 
             UndirectedEdge[119, 197] -> 
             RGBColor[
              0.726703250484565, 0.7446157080136159, 0.6357618836392993], 
             UndirectedEdge[50, 340] -> 
             RGBColor[
              0.8677385266730377, 0.8963825378169478, 0.930258824383604], 
             UndirectedEdge[443, 446] -> 
             RGBColor[
              0.9341370195762848, 0.9502731562584678, 0.991972584314733], 
             UndirectedEdge[275, 324] -> 
             RGBColor[
              0.9710939912851406, 0.9419581912280688, 0.6293051294079781], 
             UndirectedEdge[95, 286] -> 
             RGBColor[
              0.8546754498359681, 0.8690017252170137, 0.6791101315049921], 
             UndirectedEdge[306, 317] -> 
             RGBColor[
              0.8896012433363991, 0.9147550233271385, 0.9874988829825115], 
             UndirectedEdge[118, 188] -> 
             RGBColor[
              0.7755168737410594, 0.8245589430038389, 0.9782599324234298], 
             UndirectedEdge[7, 69] -> 
             RGBColor[
              0.6175902819607526, 0.6949594182198892, 0.9659722023194823], 
             UndirectedEdge[88, 166] -> 
             RGBColor[
              0.9651229580305509, 0.9728495222606572, 0.9143739400521657], 
             UndirectedEdge[9, 44] -> 
             RGBColor[
              0.8018258235866866, 0.8455899922160957, 0.9807552371862587], 
             UndirectedEdge[76, 459] -> 
             RGBColor[
              0.8255269265402547, 0.8622735740739413, 0.8746792157886154], 
             UndirectedEdge[254, 325] -> 
             RGBColor[
              0.9892581797004261, 0.9831611815418403, 0.6239210161099115], 
             UndirectedEdge[171, 433] -> 
             RGBColor[
              0.7790078208386764, 0.8278358189961519, 0.976463144359262], 
             UndirectedEdge[112, 447] -> 
             RGBColor[
              0.9156653991860499, 0.9333442637262038, 0.9052133807468218], 
             UndirectedEdge[199, 359] -> 
             RGBColor[
              0.7623939863081166, 0.8147711176082904, 0.9768650409943199], 
             UndirectedEdge[74, 224] -> 
             RGBColor[
              0.8618258023384352, 0.8897480696218313, 0.8287609085932215], 
             UndirectedEdge[292, 386] -> 
             RGBColor[
              0.784941339065784, 0.8324526974776076, 0.9790582868784574], 
             UndirectedEdge[112, 195] -> 
             RGBColor[
              0.9079265670705223, 0.900222581659027, 0.6689543989018795], 
             UndirectedEdge[97, 408] -> 
             RGBColor[
              0.7007119204899339, 0.7645141082332854, 0.9722172192772955], 
             UndirectedEdge[236, 422] -> 
             RGBColor[
              0.9324666382453095, 0.9444970560287622, 0.7675302006606075], 
             UndirectedEdge[27, 114] -> 
             RGBColor[
              0.899939595462525, 0.9230514214849955, 0.9903182360724183], 
             UndirectedEdge[110, 355] -> 
             RGBColor[
              0.7437622441821654, 0.7902349866939575, 0.6843133707484452], 
             UndirectedEdge[104, 215] -> 
             RGBColor[
              0.849943346794976, 0.846903952938389, 0.6517674514209559], 
             UndirectedEdge[80, 406] -> 
             RGBColor[
              0.8193604436356544, 0.8578107257297891, 0.8901370916462554], 
             UndirectedEdge[276, 292] -> 
             RGBColor[
              0.9350710093660173, 0.9497689197842486, 0.94836648958717], 
             UndirectedEdge[425, 466] -> 
             RGBColor[
              0.8669402732547916, 0.89651987420952, 0.967128899163223], 
             UndirectedEdge[164, 309] -> 
             RGBColor[
              0.9652947095780249, 0.9736374317447642, 0.9436311834817033], 
             UndirectedEdge[95, 137] -> 
             RGBColor[
              0.9742398706213214, 0.9627975552136959, 0.663237481190248], 
             UndirectedEdge[119, 426] -> 
             RGBColor[
              0.9773456774772495, 0.9418500162653543, 0.5698499696870416], 
             UndirectedEdge[238, 431] -> 
             RGBColor[
              0.9458656613490962, 0.956520604366665, 0.868816152042176], 
             UndirectedEdge[93, 266] -> 
             RGBColor[
              0.7966850270753614, 0.8414958899396476, 0.9802635687992782], 
             UndirectedEdge[15, 148] -> 
             RGBColor[
              0.9929599429631739, 0.9876566985904405, 0.5830654107929523], 
             UndirectedEdge[225, 470] -> 
             RGBColor[
              0.9916858789128005, 0.9886087759182608, 0.6259969225418738], 
             UndirectedEdge[249, 296] -> 
             RGBColor[
              0.8270660812483781, 0.8621407854082339, 0.7890353441283584], 
             UndirectedEdge[273, 421] -> 
             RGBColor[
              0.9938434065584488, 0.9909637312124323, 0.6965684737722452], 
             UndirectedEdge[150, 159] -> 
             RGBColor[
              0.7586237418541004, 0.8114687765280842, 0.976846180400345], 
             UndirectedEdge[85, 407] -> 
             RGBColor[
              0.8543671040932898, 0.8841469575035994, 0.8460932851142131], 
             UndirectedEdge[71, 388] -> 
             RGBColor[
              0.9008863121288131, 0.920653212680284, 0.859895196538523], 
             UndirectedEdge[61, 435] -> 
             RGBColor[
              0.7637825444785045, 0.8141669083129133, 0.9401729337218357], 
             UndirectedEdge[10, 177] -> 
             RGBColor[
              0.8674097401044332, 0.8964909821907444, 0.9471483027893561], 
             UndirectedEdge[16, 52] -> 
             RGBColor[
              0.6245689705323738, 0.7032575952895788, 0.9653995566221398], 
             UndirectedEdge[25, 459] -> 
             RGBColor[
              0.9785328106189745, 0.9822177992042195, 0.8633378616497936], 
             UndirectedEdge[105, 453] -> 
             RGBColor[
              0.9576222600523503, 0.9652523941603468, 0.8264248196196025], 
             UndirectedEdge[61, 384] -> 
             RGBColor[
              0.9795867128258378, 0.9842963843659756, 0.9194385499345943], 
             UndirectedEdge[104, 323] -> 
             RGBColor[
              0.8799645054721622, 0.8703567102662635, 0.6547596799542192], 
             UndirectedEdge[150, 406] -> 
             RGBColor[
              0.7929227671890229, 0.8364442075253108, 0.8879896528965467], 
             UndirectedEdge[413, 493] -> 
             RGBColor[
              0.9790047355057812, 0.9833098508694041, 0.8956817965987598], 
             UndirectedEdge[94, 254] -> 
             RGBColor[
              0.9903105372323657, 0.9835963584256523, 0.6064807283916792], 
             UndirectedEdge[431, 487] -> 
             RGBColor[
              0.9450992703373682, 0.9562036819879648, 0.881517234462871], 
             UndirectedEdge[234, 332] -> 
             RGBColor[
              0.8819376026146887, 0.9082923696353575, 0.9714820808530655], 
             UndirectedEdge[82, 89] -> 
             RGBColor[
              0.8382804963127237, 0.8739174359021591, 0.9534800727482495], 
             UndirectedEdge[154, 255] -> 
             RGBColor[
              0.9297511056481337, 0.9443289177122871, 0.8958353770043255], 
             UndirectedEdge[22, 324] -> 
             RGBColor[
              0.9807612002755749, 0.9461190364425317, 0.4347023645938122], 
             UndirectedEdge[105, 112] -> 
             RGBColor[
              0.8812650276425402, 0.9081608280129793, 0.9885370391227647], 
             UndirectedEdge[6, 406] -> 
             RGBColor[
              0.9777585762834875, 0.9819606960414009, 0.8789930017404557], 
             UndirectedEdge[396, 422] -> 
             RGBColor[
              0.8662204618812182, 0.8961646996487598, 0.9871020750100074], 
             UndirectedEdge[409, 456] -> 
             RGBColor[
              0.8611771140631368, 0.8921432709966512, 0.9866210359928691], 
             UndirectedEdge[91, 473] -> 
             RGBColor[
              0.9102493716315273, 0.9272245413555302, 0.8013164922195037], 
             UndirectedEdge[369, 379] -> 
             RGBColor[
              0.9522168712513985, 0.9638840013337611, 0.9657685525221723], 
             UndirectedEdge[353, 441] -> 
             RGBColor[
              0.9566720239883819, 0.8651854045451154, 0.28785275940996946`], 
             UndirectedEdge[165, 481] -> 
             RGBColor[
              0.9219787166670652, 0.9374738030710539, 0.8665377939342768], 
             UndirectedEdge[185, 318] -> 
             RGBColor[
              0.8215420514867864, 0.8419193165079153, 0.6740577577353909], 
             UndirectedEdge[264, 445] -> 
             RGBColor[
              0.9861863661882301, 0.9882807422902713, 0.8662770524903094], 
             UndirectedEdge[258, 297] -> 
             RGBColor[
              0.5438444347713358, 0.6405564379167824, 0.9572325725544566], 
             UndirectedEdge[57, 139] -> 
             RGBColor[
              0.8488954603463366, 0.8793174562277954, 0.8010943203683651], 
             UndirectedEdge[447, 463] -> 
             RGBColor[
              0.9723071884845238, 0.9780051638996579, 0.893151459300688], 
             UndirectedEdge[9, 26] -> 
             RGBColor[
              0.9358601502881515, 0.9464889431932193, 0.7099741371638781], 
             UndirectedEdge[181, 262] -> 
             RGBColor[
              0.9488876791214567, 0.9095658697900686, 0.6333611014874152], 
             UndirectedEdge[203, 291] -> 
             RGBColor[
              0.9308621991984417, 0.9476206428505702, 0.990229700504184], 
             UndirectedEdge[45, 254] -> 
             RGBColor[
              0.6755878736680652, 0.7321147201871944, 0.679216265352927], 
             UndirectedEdge[240, 412] -> 
             RGBColor[
              0.9471737073266793, 0.9569955775228809, 0.8314735742702903], 
             UndirectedEdge[208, 258] -> 
             RGBColor[
              0.7469489810623835, 0.8012145566339894, 0.9579953363165989], 
             UndirectedEdge[293, 420] -> 
             RGBColor[
              0.7533948123892923, 0.8073827527377595, 0.9760269540165007], 
             UndirectedEdge[85, 346] -> 
             RGBColor[
              0.9863855806577131, 0.9874749369607794, 0.8214871193112618], 
             UndirectedEdge[65, 166] -> 
             RGBColor[
              0.9710163511108281, 0.9772448051703826, 0.9043979628103445], 
             UndirectedEdge[254, 347] -> 
             RGBColor[
              0.8341183951202693, 0.862753048083055, 0.6913877009850364], 
             UndirectedEdge[236, 292] -> 
             RGBColor[
              0.9396705826350173, 0.9502412857392541, 0.768217319307535], 
             UndirectedEdge[100, 401] -> 
             RGBColor[
              0.9246479764605733, 0.9407404802551, 0.9162205195309393], 
             UndirectedEdge[146, 400] -> 
             RGBColor[
              0.9749555124785734, 0.9779109214591026, 0.7583562079712582], 
             UndirectedEdge[104, 153] -> 
             RGBColor[
              0.9813322789106975, 0.9472657172205723, 0.5032210893693961], 
             UndirectedEdge[216, 281] -> 
             RGBColor[
              0.9863175190135125, 0.9886099567354345, 0.8764176492792172], 
             UndirectedEdge[123, 125] -> 
             RGBColor[
              0.9599392702893575, 0.9696433538920031, 0.9526965452751488], 
             UndirectedEdge[78, 358] -> 
             RGBColor[
              0.8526129366499338, 0.8849268157694872, 0.9454309708690319], 
             UndirectedEdge[313, 478] -> 
             RGBColor[
              0.845569836434404, 0.8796984514637651, 0.9851323999198593], 
             UndirectedEdge[368, 401] -> 
             RGBColor[
              0.7018131847719857, 0.7618240434216577, 0.896759084393794], 
             UndirectedEdge[106, 369] -> 
             RGBColor[
              0.9575242138216181, 0.967842208732655, 0.9567846059274256], 
             UndirectedEdge[111, 146] -> 
             RGBColor[
              0.992369560076353, 0.9897638046357465, 0.6780742111122191], 
             UndirectedEdge[129, 266] -> 
             RGBColor[
              0.8320412173363034, 0.8695715518563188, 0.979600057422435], 
             UndirectedEdge[99, 278] -> 
             RGBColor[
              0.7563927653650933, 0.8096190441919271, 0.9763538200254671], 
             UndirectedEdge[147, 171] -> 
             RGBColor[
              0.780085171858222, 0.8286393056225285, 0.974639470101319], 
             UndirectedEdge[164, 166] -> 
             RGBColor[
              0.9730158191700888, 0.9787360051751508, 0.9010133849308055], 
             UndirectedEdge[129, 433] -> 
             RGBColor[
              0.9391451194219838, 0.9541351102224128, 0.9878956187104746], 
             UndirectedEdge[179, 283] -> 
             RGBColor[
              0.9815507477328076, 0.9847744287302488, 0.8719261812473986], 
             UndirectedEdge[136, 291] -> 
             RGBColor[
              0.8975039993742995, 0.9211093432767391, 0.9900859267432411], 
             UndirectedEdge[321, 479] -> 
             RGBColor[
              0.9375269659153745, 0.9527277047962525, 0.9836801773627633], 
             UndirectedEdge[181, 239] -> 
             RGBColor[
              0.9509353821268183, 0.9164831373696212, 0.6412645622443435], 
             UndirectedEdge[102, 330] -> 
             RGBColor[
              0.7793281997477897, 0.8265146533548329, 0.9332017371903383], 
             UndirectedEdge[406, 413] -> 
             RGBColor[
              0.9802680694062775, 0.9838322719034598, 0.8747450844642026], 
             UndirectedEdge[37, 310] -> 
             RGBColor[
              0.9686637404415182, 0.9754186084113117, 0.905172869037518], 
             UndirectedEdge[203, 439] -> 
             RGBColor[
              0.9315163230518198, 0.9481422234555349, 0.9902920914212625], 
             UndirectedEdge[320, 375] -> 
             RGBColor[
              0.8224886531263986, 0.8603886048768767, 0.8965294603616891], 
             UndirectedEdge[42, 407] -> 
             RGBColor[
              0.7703600495816496, 0.8205886904402873, 0.9777304779771852], 
             UndirectedEdge[131, 374] -> 
             RGBColor[
              0.9145539688873605, 0.6319218989290187, 0.35164240724588075`], 
             UndirectedEdge[387, 403] -> 
             RGBColor[
              0.9769136244911394, 0.9812125665007416, 0.8751405317174576], 
             UndirectedEdge[65, 348] -> 
             RGBColor[
              0.973368184059243, 0.9782173485339021, 0.8654220045065408], 
             UndirectedEdge[217, 498] -> 
             RGBColor[
              0.7562027921614297, 0.8094706356813754, 0.9763348852719266], 
             UndirectedEdge[40, 397] -> 
             RGBColor[
              0.7951081354118565, 0.8404196787075304, 0.980065089336249], 
             UndirectedEdge[226, 292] -> 
             RGBColor[
              0.9376759529831828, 0.950846130913944, 0.9051958324727551], 
             UndirectedEdge[53, 257] -> 
             RGBColor[
              0.9838825684342121, 0.9597078551987825, 0.5662652598900688], 
             UndirectedEdge[220, 429] -> 
             RGBColor[
              0.9548140558771139, 0.9650172792015572, 0.9287892962364096], 
             UndirectedEdge[139, 425] -> 
             RGBColor[
              0.8851319817091243, 0.9076257021241678, 0.8047060381682626], 
             UndirectedEdge[317, 418] -> 
             RGBColor[
              0.9137309115900223, 0.9339953658101815, 0.9898003922813513], 
             UndirectedEdge[482, 496] -> 
             RGBColor[
              0.8022817509610263, 0.8459549697339405, 0.9807983435645236], 
             UndirectedEdge[117, 466] -> 
             RGBColor[
              0.8728869265375124, 0.9011654449502204, 0.9677216059878101], 
             UndirectedEdge[82, 105] -> 
             RGBColor[
              0.8135448545024941, 0.8550797766677795, 0.9818344381112389], 
             UndirectedEdge[239, 453] -> 
             RGBColor[
              0.9773443758435434, 0.9339058424253506, 0.47988382896998577`], 
             UndirectedEdge[274, 340] -> 
             RGBColor[
              0.9858954313370021, 0.9884354126340389, 0.8834127344068866], 
             UndirectedEdge[311, 484] -> 
             RGBColor[
              0.9685140968105606, 0.9752564315408386, 0.9031614190833785], 
             UndirectedEdge[44, 140] -> 
             RGBColor[
              0.8475405482860341, 0.8811419439882183, 0.9539213857871411], 
             UndirectedEdge[139, 466] -> 
             RGBColor[
              0.9762015307795872, 0.979310202674204, 0.7935397364027911], 
             UndirectedEdge[22, 481] -> 
             RGBColor[
              0.9938221794915324, 0.9902190712270975, 0.6434294047063043], 
             UndirectedEdge[45, 386] -> 
             RGBColor[
              0.5228613453563697, 0.6203894443157725, 0.95670699574849], 
             UndirectedEdge[40, 220] -> 
             RGBColor[
              0.8442283139869246, 0.8777972282810778, 0.9179873009614787], 
             UndirectedEdge[237, 489] -> 
             RGBColor[
              0.6259504265346924, 0.7022388036135085, 0.9664872955196055], 
             UndirectedEdge[61, 64] -> 
             RGBColor[
              0.8318266693514593, 0.8687403234801252, 0.9459862433701874], 
             UndirectedEdge[82, 296] -> 
             RGBColor[
              0.6832148269160794, 0.7524518825026263, 0.9690601270075849], 
             UndirectedEdge[27, 277] -> 
             RGBColor[
              0.8830590769355888, 0.9095913542210854, 0.9887081571459024], 
             UndirectedEdge[416, 427] -> 
             RGBColor[
              0.5812397453020368, 0.6307874150639974, 0.6620529805793497], 
             UndirectedEdge[59, 82] -> 
             RGBColor[
              0.8505542793379658, 0.8807534242394275, 0.8124798318107112], 
             UndirectedEdge[271, 444] -> 
             RGBColor[
              0.925467265049154, 0.9430954016626469, 0.9819673808819379], 
             UndirectedEdge[6, 486] -> 
             RGBColor[
              0.973493762716239, 0.979752272150527, 0.9297523251742477], 
             UndirectedEdge[171, 265] -> 
             RGBColor[
              0.8075220374364029, 0.8472885230720506, 0.8469993634335934], 
             UndirectedEdge[219, 369] -> 
             RGBColor[
              0.9675198146555439, 0.9752969114683028, 0.9398646609858127], 
             UndirectedEdge[244, 355] -> 
             RGBColor[
              0.6913941919259532, 0.7571517806165352, 0.9712509372186082], 
             UndirectedEdge[450, 500] -> 
             RGBColor[
              0.9930849975417264, 0.9899336295603662, 0.6570567389964401], 
             UndirectedEdge[18, 243] -> 
             RGBColor[
              0.6568065560397749, 0.7316946888459865, 0.9665147265918772], 
             UndirectedEdge[377, 449] -> 
             RGBColor[
              0.8757488403764231, 0.903762370019892, 0.9880109002569639], 
             UndirectedEdge[7, 173] -> 
             RGBColor[
              0.8082009928097231, 0.8504942113758307, 0.9814108521244006], 
             UndirectedEdge[3, 8] -> 
             RGBColor[
              0.7507163807984193, 0.805184609426321, 0.9757880510606909], 
             UndirectedEdge[405, 469] -> 
             RGBColor[
              0.9207003236799353, 0.9384804171038472, 0.953292378198431], 
             UndirectedEdge[148, 190] -> 
             RGBColor[
              0.934186575586897, 0.9471691160321379, 0.8660129152808255], 
             UndirectedEdge[180, 216] -> 
             RGBColor[
              0.989742356873669, 0.9900262152049275, 0.8196592227401607], 
             UndirectedEdge[257, 317] -> 
             RGBColor[
              0.9565112892094869, 0.9406733415604771, 0.6743495178385408], 
             UndirectedEdge[49, 462] -> 
             RGBColor[
              0.9360444422944108, 0.9483622808103129, 0.8499383357480627], 
             UndirectedEdge[223, 258] -> 
             RGBColor[
              0.7663626613566722, 0.8139133410387258, 0.845425186631436], 
             UndirectedEdge[260, 440] -> 
             RGBColor[
              0.8675641196914389, 0.8972360959140101, 0.9872302342914436], 
             UndirectedEdge[262, 332] -> 
             RGBColor[
              0.9553749803786145, 0.914404088445676, 0.622379792618196], 
             UndirectedEdge[283, 386] -> 
             RGBColor[
              0.8371487765063623, 0.8716911027659513, 0.891184386237706], 
             UndirectedEdge[40, 289] -> 
             RGBColor[
              0.8000143820908674, 0.8443317866328554, 0.9805330515243511], 
             UndirectedEdge[95, 430] -> 
             RGBColor[
              0.9633953794086891, 0.9547097514235394, 0.6815943761169412], 
             UndirectedEdge[274, 334] -> 
             RGBColor[
              0.9897773168630444, 0.9885667144211312, 0.7119386848599785], 
             UndirectedEdge[75, 158] -> 
             RGBColor[
              0.9165842273204272, 0.9326705059156822, 0.8339182087756651], 
             UndirectedEdge[233, 476] -> 
             RGBColor[
              0.7619950643939827, 0.8143977889193919, 0.9768054769988705], 
             UndirectedEdge[240, 416] -> 
             RGBColor[
              0.5392497314389305, 0.6140763399637665, 0.961892109319375], 
             UndirectedEdge[260, 280] -> 
             RGBColor[
              0.917424925078254, 0.9328694238356735, 0.7957826176440925], 
             UndirectedEdge[11, 193] -> 
             RGBColor[
              0.8997376504848938, 0.9212339688101732, 0.926804008525641], 
             UndirectedEdge[3, 162] -> 
             RGBColor[
              0.8547466494981134, 0.886914213081164, 0.9618685431139802], 
             UndirectedEdge[117, 338] -> 
             RGBColor[
              0.8896927129755543, 0.9124648804916928, 0.8839996547166187], 
             UndirectedEdge[40, 472] -> 
             RGBColor[
              0.813362698072579, 0.8549753714662873, 0.9818062258188691], 
             UndirectedEdge[101, 355] -> 
             RGBColor[
              0.7459600257801924, 0.7965797752153121, 0.783738190082448], 
             UndirectedEdge[47, 364] -> 
             RGBColor[
              0.9645242571404768, 0.9722913786138965, 0.9103882081377632], 
             UndirectedEdge[377, 484] -> 
             RGBColor[
              0.9452104927963738, 0.9569953091410491, 0.9120519847753314], 
             UndirectedEdge[21, 227] -> 
             RGBColor[
              0.9449099470548066, 0.958316123029201, 0.974032745269796], 
             UndirectedEdge[158, 441] -> 
             RGBColor[
              0.9748750274601891, 0.925125369699246, 0.48297433676515533`], 
             UndirectedEdge[201, 222] -> 
             RGBColor[
              0.9301442302534717, 0.9432453809658715, 0.8159587938281427], 
             UndirectedEdge[107, 477] -> 
             RGBColor[
              0.9688605405193046, 0.9728100951673115, 0.7246201696750991], 
             UndirectedEdge[89, 239] -> 
             RGBColor[
              0.9650385063117388, 0.9270012242949885, 0.6173916516831617], 
             UndirectedEdge[63, 275] -> 
             RGBColor[
              0.6453040641370438, 0.7143778346627169, 0.9349559360513453], 
             UndirectedEdge[133, 344] -> 
             RGBColor[
              0.9246229353601878, 0.9380944798256199, 0.7547668324945003], 
             UndirectedEdge[153, 356] -> 
             RGBColor[
              0.9482469158017194, 0.9578770195655166, 0.8336588364390153], 
             UndirectedEdge[151, 188] -> 
             RGBColor[
              0.7567855351387642, 0.8099258789242798, 0.9763929676458645], 
             UndirectedEdge[140, 204] -> 
             RGBColor[
              0.906350566119458, 0.9272636266556793, 0.9597355575258599], 
             UndirectedEdge[154, 369] -> 
             RGBColor[
              0.9765915751695134, 0.9809867212716037, 0.8763277902555558], 
             UndirectedEdge[16, 179] -> 
             RGBColor[
              0.8900910921803513, 0.9143406017914948, 0.9560287757914967], 
             UndirectedEdge[161, 341] -> 
             RGBColor[
              0.9456530027417902, 0.9517608560277981, 0.7041177169509298], 
             UndirectedEdge[48, 408] -> 
             RGBColor[
              0.7218788799705007, 0.7808844532200472, 0.9566368487691839], 
             UndirectedEdge[153, 263] -> 
             RGBColor[
              0.994868333818588, 0.9914322098660262, 0.6828279890050448], 
             UndirectedEdge[62, 132] -> 
             RGBColor[
              0.9142572725796719, 0.9090957641852735, 0.675185670651648], 
             UndirectedEdge[82, 225] -> 
             RGBColor[
              0.849608143810744, 0.8787297360156756, 0.7094988185442594], 
             UndirectedEdge[216, 465] -> 
             RGBColor[
              0.987801520108329, 0.9892236293252297, 0.8518239106663834], 
             UndirectedEdge[119, 489] -> 
             RGBColor[
              0.9168317584221517, 0.895897592461923, 0.6529950137597009], 
             UndirectedEdge[287, 295] -> 
             RGBColor[
              0.7393699222165304, 0.7960613661751861, 0.9750729656104852], 
             UndirectedEdge[28, 417] -> 
             RGBColor[
              0.9672081209638201, 0.9745865720762905, 0.9189918904455883], 
             UndirectedEdge[148, 351] -> 
             RGBColor[
              0.9943869978242057, 0.9912522963893801, 0.6921956175875158], 
             UndirectedEdge[218, 336] -> 
             RGBColor[
              0.9468479065449247, 0.9581011066673544, 0.9035307782268737], 
             UndirectedEdge[127, 254] -> 
             RGBColor[
              0.9692116139174767, 0.968992161450941, 0.6928596644751364], 
             UndirectedEdge[303, 473] -> 
             RGBColor[
              0.9096652105593779, 0.9259750798899467, 0.7377341645402791], 
             UndirectedEdge[99, 267] -> 
             RGBColor[
              0.5185837111316567, 0.612344097673172, 0.9576195157196411], 
             UndirectedEdge[48, 145] -> 
             RGBColor[
              0.9517912287800006, 0.9635665578755181, 0.966489054200913], 
             UndirectedEdge[224, 342] -> 
             RGBColor[
              0.8663452588333029, 0.8932787033847636, 0.8292113657799078], 
             UndirectedEdge[193, 232] -> 
             RGBColor[
              0.8977057962747987, 0.919646668858583, 0.926601492286736], 
             UndirectedEdge[216, 343] -> 
             RGBColor[
              0.9698809810830361, 0.9764637745706252, 0.9092632154295843], 
             UndirectedEdge[277, 449] -> 
             RGBColor[
              0.8453274328981288, 0.8795051654638081, 0.9851092792541731], 
             UndirectedEdge[257, 418] -> 
             RGBColor[
              0.9324926988390869, 0.9215744463659643, 0.6738918750823244], 
             UndirectedEdge[45, 422] -> 
             RGBColor[
              0.6164324637702145, 0.6939027501197651, 0.9659232053934104], 
             UndirectedEdge[133, 235] -> 
             RGBColor[
              0.8558639887261228, 0.8879067290738616, 0.9861142653551416], 
             UndirectedEdge[145, 183] -> 
             RGBColor[
              0.8917709731893818, 0.9162156492152285, 0.9783635626413011], 
             UndirectedEdge[196, 496] -> 
             RGBColor[
              0.9370857912477091, 0.948379871052189, 0.7841532562995008], 
             UndirectedEdge[115, 136] -> 
             RGBColor[
              0.776144540691449, 0.8254727829145525, 0.9782101080645254], 
             UndirectedEdge[267, 413] -> 
             RGBColor[
              0.6305003409948035, 0.7000935054985626, 0.9373445439124175], 
             UndirectedEdge[217, 340] -> 
             RGBColor[
              0.8888798704082571, 0.9128983162230646, 0.9323659959500408], 
             UndirectedEdge[335, 383] -> 
             RGBColor[
              0.9062241354496814, 0.9269145004209217, 0.9511143013771926], 
             UndirectedEdge[80, 493] -> 
             RGBColor[
              0.8180971097351579, 0.8572883046957336, 0.9110738037808126], 
             UndirectedEdge[307, 372] -> 
             RGBColor[
              0.9887889244919308, 0.9815967196013251, 0.6222255467439468], 
             UndirectedEdge[18, 434] -> 
             RGBColor[
              0.8364433642250986, 0.8705479675824179, 0.8642674838105033], 
             UndirectedEdge[130, 179] -> 
             RGBColor[
              0.97430551782484, 0.9544273554915593, 0.6452540757764165], 
             UndirectedEdge[20, 228] -> 
             RGBColor[
              0.8988158286809067, 0.8883645605282198, 0.661327966129313], 
             UndirectedEdge[297, 311] -> 
             RGBColor[
              0.748999104465418, 0.8031414429568147, 0.9651974415253171], 
             UndirectedEdge[127, 200] -> 
             RGBColor[
              0.9649813742642563, 0.9734037467807952, 0.9441615784369752], 
             UndirectedEdge[54, 391] -> 
             RGBColor[
              0.8340681743987433, 0.8709212645678304, 0.9839308252240258], 
             UndirectedEdge[347, 368] -> 
             RGBColor[
              0.5470401423251282, 0.6415675672598344, 0.9581479030219316], 
             UndirectedEdge[22, 182] -> 
             RGBColor[
              0.9793488142955704, 0.9810700166096241, 0.7416025484871888], 
             UndirectedEdge[96, 216] -> 
             RGBColor[
              0.8128920220412208, 0.8531094953867737, 0.9085133960138077], 
             UndirectedEdge[340, 363] -> 
             RGBColor[
              0.9542185609659464, 0.9647710267522682, 0.9386581880058831], 
             UndirectedEdge[71, 490] -> 
             RGBColor[
              0.898066296907013, 0.9194870639149841, 0.906630146729202], 
             UndirectedEdge[111, 201] -> 
             RGBColor[
              0.9283948042868706, 0.9431797548569907, 0.8927668968746387], 
             UndirectedEdge[261, 484] -> 
             RGBColor[
              0.9907521435823045, 0.9881345706333128, 0.6350687214731724], 
             UndirectedEdge[416, 499] -> 
             RGBColor[
              0.5725206647632257, 0.6398213514801481, 0.9378723903500683], 
             UndirectedEdge[42, 430] -> 
             RGBColor[
              0.885969002144715, 0.9116784737653838, 0.9809013560192317], 
             UndirectedEdge[6, 81] -> 
             RGBColor[
              0.7104101509617782, 0.7712404419550813, 0.9467976327594054], 
             UndirectedEdge[282, 353] -> 
             RGBColor[
              0.9736841244197709, 0.9306208208520181, 0.5633813221406895], 
             UndirectedEdge[275, 441] -> 
             RGBColor[
              0.9645459857986093, 0.9195489313227505, 0.605540699682934], 
             UndirectedEdge[50, 255] -> 
             RGBColor[
              0.8092508149246438, 0.8513069925373073, 0.9815174384761016], 
             UndirectedEdge[110, 217] -> 
             RGBColor[
              0.8908946847707184, 0.9073921856681283, 0.6974629169503617], 
             UndirectedEdge[30, 110] -> 
             RGBColor[
              0.9914213276366031, 0.9824154562755654, 0.44743278302769945`], 
             UndirectedEdge[77, 482] -> 
             RGBColor[
              0.6562617506085976, 0.7305664286491109, 0.9669408338918251], 
             UndirectedEdge[52, 326] -> 
             RGBColor[
              0.5853496028021732, 0.6726191271405113, 0.9614905365726227], 
             UndirectedEdge[44, 247] -> 
             RGBColor[
              0.7265139134708445, 0.786277458004455, 0.9733757753023946], 
             UndirectedEdge[337, 348] -> 
             RGBColor[
              0.8528683634008736, 0.8834683872924545, 0.8699440899260527], 
             UndirectedEdge[48, 78] -> 
             RGBColor[
              0.8399911209039863, 0.875513486252486, 0.9667964126301487], 
             UndirectedEdge[420, 432] -> 
             RGBColor[
              0.9091815965446891, 0.9289580161686768, 0.938628544163304], 
             UndirectedEdge[469, 474] -> 
             RGBColor[
              0.6994158255247627, 0.7638307479876348, 0.9716906255903817], 
             UndirectedEdge[172, 366] -> 
             RGBColor[
              0.652202056157894, 0.7268482392808564, 0.966910000500002], 
             UndirectedEdge[102, 415] -> 
             RGBColor[
              0.7787531778877778, 0.8261345186495572, 0.9363566858355428], 
             UndirectedEdge[414, 485] -> 
             RGBColor[
              0.8116460539166461, 0.8536055992155529, 0.9758919456362305], 
             UndirectedEdge[102, 193] -> 
             RGBColor[
              0.7803889350064082, 0.8269532946439244, 0.9156226088601774], 
             UndirectedEdge[128, 498] -> 
             RGBColor[
              0.8566949661835155, 0.8844201809172616, 0.7225530304188164], 
             UndirectedEdge[150, 443] -> 
             RGBColor[
              0.7666491061836345, 0.8178216212512524, 0.9760042142163666], 
             UndirectedEdge[2, 230] -> 
             RGBColor[
              0.7432235976621909, 0.7993311902930385, 0.975041240461711], 
             UndirectedEdge[367, 416] -> 
             RGBColor[
              0.3572409448596576, 0.46961030590190156`, 0.9450404946011788], 
             UndirectedEdge[61, 473] -> 
             RGBColor[
              0.9019548267502492, 0.92357532490564, 0.9529626008761987], 
             UndirectedEdge[56, 164] -> 
             RGBColor[
              0.946134287375874, 0.9593141349487898, 0.9749038244093515], 
             UndirectedEdge[20, 388] -> 
             RGBColor[
              0.9109705472556979, 0.9285901802264745, 0.8608846191337666], 
             UndirectedEdge[195, 296] -> 
             RGBColor[
              0.8169122605518835, 0.8289439762764998, 0.6599300563712285], 
             UndirectedEdge[135, 391] -> 
             RGBColor[
              0.941477990059371, 0.954562798413432, 0.9353046828782506], 
             UndirectedEdge[310, 399] -> 
             RGBColor[
              0.7921979827705449, 0.8361444905421602, 0.9000012063926747], 
             UndirectedEdge[150, 476] -> 
             RGBColor[
              0.7327723204556151, 0.7908555548230725, 0.9743804487495211], 
             UndirectedEdge[142, 222] -> 
             RGBColor[
              0.9942589368294936, 0.9901287713258402, 0.616498887504398], 
             UndirectedEdge[48, 404] -> 
             RGBColor[
              0.9727943535393729, 0.9782316732480161, 0.8861998464276087], 
             UndirectedEdge[330, 415] -> 
             RGBColor[
              0.983910205129225, 0.9874721221903636, 0.9099384185864242], 
             UndirectedEdge[326, 495] -> 
             RGBColor[
              0.5592763501696795, 0.6500357861900266, 0.9598291719705523], 
             UndirectedEdge[36, 382] -> 
             RGBColor[
              0.7781674637602731, 0.8273681095825656, 0.9783281418098536], 
             UndirectedEdge[31, 289] -> 
             RGBColor[
              0.9415290076030927, 0.9549069116920033, 0.9484856693591959], 
             UndirectedEdge[436, 487] -> 
             RGBColor[
              0.9650150194599469, 0.9720383326479342, 0.881834896479041], 
             UndirectedEdge[251, 427] -> 
             RGBColor[
              0.8022249622046049, 0.8296461819292325, 0.6769517140257661], 
             UndirectedEdge[108, 437] -> 
             RGBColor[
              0.9472598478130214, 0.9596583024394982, 0.9558270961603517], 
             UndirectedEdge[258, 397] -> 
             RGBColor[
              0.7132900437989599, 0.7749013563728065, 0.9730051175328236], 
             UndirectedEdge[308, 422] -> 
             RGBColor[
              0.922067886731041, 0.9397384846823598, 0.9592339588337853], 
             UndirectedEdge[16, 292] -> 
             RGBColor[
              0.8464641837574587, 0.8805148113416816, 0.9851903090736518], 
             UndirectedEdge[68, 317] -> 
             RGBColor[
              0.9661356954655794, 0.9718927301860567, 0.8176888201818808], 
             UndirectedEdge[34, 468] -> 
             RGBColor[
              0.8515475460530432, 0.884464914853063, 0.9857025591996494], 
             UndirectedEdge[350, 383] -> 
             RGBColor[
              0.928671939386809, 0.9448137699509818, 0.953255392956107], 
             UndirectedEdge[190, 342] -> 
             RGBColor[
              0.8059440713941484, 0.8487661065612483, 0.9811766102314796], 
             UndirectedEdge[61, 303] -> 
             RGBColor[
              0.9854063959624586, 0.9852860578844642, 0.7074105766635184], 
             UndirectedEdge[214, 421] -> 
             RGBColor[
              0.9909127272618413, 0.9905101934375838, 0.8002631565866705], 
             UndirectedEdge[219, 370] -> 
             RGBColor[
              0.8481568214904937, 0.8815891229535531, 0.9522486582822012], 
             UndirectedEdge[91, 366] -> 
             RGBColor[
              0.7734021560125914, 0.8188918735651263, 0.7886311391659291], 
             UndirectedEdge[273, 477] -> 
             RGBColor[
              0.9696012981125682, 0.9743945007572212, 0.805247062275895], 
             UndirectedEdge[153, 323] -> 
             RGBColor[
              0.8934454850646079, 0.9144054023809496, 0.8283719713891557], 
             UndirectedEdge[170, 433] -> 
             RGBColor[
              0.8059007085861001, 0.8491882017474381, 0.9789087543987132], 
             UndirectedEdge[1, 54] -> 
             RGBColor[
              0.8182092759427726, 0.8582758094173701, 0.9824181893318895], 
             UndirectedEdge[277, 377] -> 
             RGBColor[
              0.8711005166204893, 0.9000559228322975, 0.9875675389875154], 
             UndirectedEdge[307, 417] -> 
             RGBColor[
              0.9681161891844072, 0.9749620816217921, 0.9039428500252364], 
             UndirectedEdge[58, 371] -> 
             RGBColor[
              0.9344458949938945, 0.9490048396208739, 0.9367722534742016], 
             UndirectedEdge[9, 269] -> 
             RGBColor[
              0.8776278678073688, 0.9052606554884872, 0.9881901235707551], 
             UndirectedEdge[184, 453] -> 
             RGBColor[
              0.9764855451490235, 0.9797104593728577, 0.8080108224167388], 
             UndirectedEdge[42, 97] -> 
             RGBColor[
              0.870123241094588, 0.8992766698553813, 0.9874743255754308], 
             UndirectedEdge[161, 405] -> 
             RGBColor[
              0.9849451363232266, 0.9819662912623259, 0.6688594010637443], 
             UndirectedEdge[304, 429] -> 
             RGBColor[
              0.939292533725518, 0.9539079725374578, 0.9759593431332317], 
             UndirectedEdge[127, 130] -> 
             RGBColor[
              0.9622223559419447, 0.9454157531436578, 0.6657077170508137], 
             UndirectedEdge[318, 330] -> 
             RGBColor[
              0.9828050265526339, 0.9679220023313683, 0.6439787064949214], 
             UndirectedEdge[393, 468] -> 
             RGBColor[
              0.8733994800627355, 0.9018890538774444, 0.9877868161729457], 
             UndirectedEdge[334, 355] -> 
             RGBColor[
              0.7456293153457463, 0.7958724190359859, 0.7477424002012161], 
             UndirectedEdge[290, 378] -> 
             RGBColor[
              0.8289619361279021, 0.8672145872441344, 0.981752926884075], 
             UndirectedEdge[92, 498] -> 
             RGBColor[
              0.8570656941750878, 0.8865987065031173, 0.8636212253522006], 
             UndirectedEdge[340, 362] -> 
             RGBColor[
              0.9887632257964122, 0.989621319341961, 0.8358859586003065], 
             UndirectedEdge[58, 304] -> 
             RGBColor[
              0.9708836349462997, 0.9775368906714236, 0.9221353063177229], 
             UndirectedEdge[51, 308] -> 
             RGBColor[
              0.8094100533146082, 0.8513144920539386, 0.9481153638128996], 
             UndirectedEdge[59, 447] -> 
             RGBColor[
              0.9919905450892976, 0.9903672000804777, 0.739608743019297], 
             UndirectedEdge[186, 485] -> 
             RGBColor[
              0.8276485366464394, 0.8655402246337721, 0.9488039164906259], 
             UndirectedEdge[340, 379] -> 
             RGBColor[
              0.9638641134784127, 0.972301743054085, 0.9340175251784444], 
             UndirectedEdge[129, 410] -> 
             RGBColor[
              0.9650766495935159, 0.9725198070890666, 0.9012336356450639], 
             UndirectedEdge[192, 225] -> 
             RGBColor[
              0.9455456608780801, 0.9543105314690999, 0.7188928150094904], 
             UndirectedEdge[306, 420] -> 
             RGBColor[
              0.837259199132913, 0.8730717748657961, 0.9843397239150495], 
             UndirectedEdge[16, 45] -> 
             RGBColor[
              0.5843841900480444, 0.6684515581798465, 0.9628390179436845], 
             UndirectedEdge[334, 361] -> 
             RGBColor[
              0.9727091568100186, 0.9761345598061414, 0.7541421440655888], 
             UndirectedEdge[306, 357] -> 
             RGBColor[
              0.8999973040737008, 0.9225083884030311, 0.9699010638811536], 
             UndirectedEdge[335, 496] -> 
             RGBColor[
              0.8562393462030465, 0.8882060289371533, 0.9861500672863762], 
             UndirectedEdge[176, 345] -> 
             RGBColor[
              0.9770631363224864, 0.9807073843014491, 0.847270904028099], 
             UndirectedEdge[15, 78] -> 
             RGBColor[
              0.8581106433349401, 0.8840924103118448, 0.697570602118611], 
             UndirectedEdge[52, 210] -> 
             RGBColor[
              0.637845980411488, 0.7137410909734279, 0.9666933241692099], 
             UndirectedEdge[392, 465] -> 
             RGBColor[
              0.8912122642543467, 0.9143480386906979, 0.9157140233599402], 
             UndirectedEdge[354, 414] -> 
             RGBColor[
              0.9517741855686925, 0.9635538470764302, 0.9665179039120761], 
             UndirectedEdge[56, 428] -> 
             RGBColor[
              0.8444316255133673, 0.8793204566620147, 0.9848833011177935], 
             UndirectedEdge[44, 425] -> 
             RGBColor[
              0.7501811820029747, 0.804766508059658, 0.9757347074464781], 
             UndirectedEdge[106, 468] -> 
             RGBColor[
              0.9004163133144809, 0.9229974344072852, 0.9753128759429298], 
             UndirectedEdge[142, 461] -> 
             RGBColor[
              0.9031316664304153, 0.9214191461196364, 0.785030917935289], 
             UndirectedEdge[203, 297] -> 
             RGBColor[
              0.7444830077276987, 0.7997733454042535, 0.9728420153156048], 
             UndirectedEdge[24, 176] -> 
             RGBColor[
              0.9656848709990038, 0.9739284134936995, 0.9429707419663822], 
             UndirectedEdge[351, 356] -> 
             RGBColor[
              0.9480787085941473, 0.9575172413568773, 0.8153505199493505], 
             UndirectedEdge[315, 368] -> 
             RGBColor[
              0.6841722823690362, 0.7493273047550827, 0.9561685046771966], 
             UndirectedEdge[278, 406] -> 
             RGBColor[
              0.8780855501572635, 0.9036872252718104, 0.8959902614470073], 
             UndirectedEdge[247, 360] -> 
             RGBColor[
              0.8406182198899668, 0.8760508899729045, 0.9692638252621144], 
             UndirectedEdge[78, 145] -> 
             RGBColor[
              0.8363986601799588, 0.8728342349266208, 0.9728775115721099], 
             UndirectedEdge[19, 466] -> 
             RGBColor[
              0.9633308817260224, 0.9721728121482137, 0.946955431786809], 
             UndirectedEdge[60, 151] -> 
             RGBColor[
              0.7220190213866651, 0.7827660141458489, 0.9729277664665983], 
             UndirectedEdge[109, 186] -> 
             RGBColor[
              0.9833238162483038, 0.9833452524940216, 0.6801797844071541], 
             UndirectedEdge[474, 495] -> 
             RGBColor[
              0.4632687279032215, 0.5734162291339706, 0.9513660411922125], 
             UndirectedEdge[36, 412] -> 
             RGBColor[
              0.8198781984972483, 0.8569080746273163, 0.8189566553665584], 
             UndirectedEdge[259, 469] -> 
             RGBColor[
              0.923941663791995, 0.9406290507902395, 0.9357703505249264], 
             UndirectedEdge[6, 80] -> 
             RGBColor[
              0.8070747955838408, 0.8496203766132376, 0.9544735956937447], 
             UndirectedEdge[287, 389] -> 
             RGBColor[
              0.791462739005748, 0.8338403618380397, 0.813501098771442], 
             UndirectedEdge[158, 410] -> 
             RGBColor[
              0.9924069181174333, 0.9907757326225393, 0.7498886302794712], 
             UndirectedEdge[414, 415] -> 
             RGBColor[
              0.9627087785408419, 0.9717088486113066, 0.9480084902088228], 
             UndirectedEdge[10, 245] -> 
             RGBColor[
              0.8119167317861371, 0.8531394223300074, 0.9416172783318354], 
             UndirectedEdge[115, 178] -> 
             RGBColor[
              0.7863405097624976, 0.8336027718895991, 0.979182608696571], 
             UndirectedEdge[88, 348] -> 
             RGBColor[
              0.9674747909789658, 0.9738220656241767, 0.8753979817483619], 
             UndirectedEdge[135, 170] -> 
             RGBColor[
              0.8298952245690373, 0.8667718934681138, 0.9243481092703515], 
             UndirectedEdge[3, 203] -> 
             RGBColor[
              0.843033463941012, 0.8781785384712588, 0.9816959109740884], 
             UndirectedEdge[84, 374] -> 
             RGBColor[
              0.7438688305638201, 0.5018307856417116, 0.573895745828051], 
             UndirectedEdge[29, 172] -> 
             RGBColor[
              0.863569749892523, 0.8935814835695689, 0.9513381047029126], 
             UndirectedEdge[262, 387] -> 
             RGBColor[
              0.973341926640863, 0.9267135745878903, 0.5431435796116055], 
             UndirectedEdge[179, 276] -> 
             RGBColor[
              0.9786979177889099, 0.9835947102340616, 0.9192049563050149], 
             UndirectedEdge[348, 428] -> 
             RGBColor[
              0.8736649902559972, 0.8997148702518951, 0.8720169033354438], 
             UndirectedEdge[104, 351] -> 
             RGBColor[
              0.9811640717031254, 0.946905939011933, 0.4849127728797314], 
             UndirectedEdge[111, 271] -> 
             RGBColor[
              0.9470962147977475, 0.9580917519620988, 0.8945506541041124], 
             UndirectedEdge[136, 277] -> 
             RGBColor[
              0.8565298240728146, 0.8884376481056946, 0.9861777733249073], 
             UndirectedEdge[246, 442] -> 
             RGBColor[
              0.9822480845474719, 0.9517439537174173, 0.38866751846169023`], 
             UndirectedEdge[206, 266] -> 
             RGBColor[
              0.6868165088926705, 0.7552655438365363, 0.9694191090073798], 
             UndirectedEdge[31, 381] -> 
             RGBColor[
              0.956579083601727, 0.9669074337698842, 0.949921159043307], 
             UndirectedEdge[31, 472] -> 
             RGBColor[
              0.9548773235848045, 0.9655504965254351, 0.9497588436537139], 
             UndirectedEdge[342, 453] -> 
             RGBColor[
              0.8662379572846497, 0.8930491962220446, 0.8175322543973869], 
             UndirectedEdge[200, 475] -> 
             RGBColor[
              0.8902952789392047, 0.9143551373804997, 0.9487104324779156], 
             UndirectedEdge[92, 101] -> 
             RGBColor[
              0.9939553683824036, 0.9908650450112249, 0.6841740763646386], 
             UndirectedEdge[193, 376] -> 
             RGBColor[
              0.9801794047443777, 0.9843372440419778, 0.9004701102680079], 
             UndirectedEdge[253, 319] -> 
             RGBColor[
              0.8811050556748289, 0.9080227730946797, 0.9881578220012848], 
             UndirectedEdge[249, 280] -> 
             RGBColor[
              0.9941911049867913, 0.9899836858731512, 0.6091158100358588], 
             UndirectedEdge[153, 195] -> 
             RGBColor[
              0.9843585430347117, 0.9574740167114796, 0.514977554029165], 
             UndirectedEdge[313, 380] -> 
             RGBColor[
              0.7950884148908806, 0.8399608661049477, 0.9801807903053747], 
             UndirectedEdge[178, 357] -> 
             RGBColor[
              0.9256570502902786, 0.942968773520874, 0.9723485133820166], 
             UndirectedEdge[163, 494] -> 
             RGBColor[
              0.6726466402225957, 0.7354019330573527, 0.8522823454264565], 
             UndirectedEdge[24, 237] -> 
             RGBColor[
              0.6774897269002262, 0.7424062262632165, 0.9392074442231056], 
             UndirectedEdge[101, 345] -> 
             RGBColor[
              0.9943505358989426, 0.9910284569346556, 0.6776251279548373], 
             UndirectedEdge[320, 361] -> 
             RGBColor[
              0.9705798400427661, 0.9767279902397715, 0.8965715937767907], 
             UndirectedEdge[328, 487] -> 
             RGBColor[
              0.9665094947335349, 0.9731529098599974, 0.8793051396624338], 
             UndirectedEdge[322, 494] -> 
             RGBColor[
              0.986524884628639, 0.9674445127779483, 0.5683982670556078], 
             UndirectedEdge[108, 266] -> 
             RGBColor[
              0.8195318668599512, 0.8597133398229344, 0.9824427207735471], 
             UndirectedEdge[405, 474] -> 
             RGBColor[
              0.7580424838074358, 0.8094530083972369, 0.938276453929334], 
             UndirectedEdge[338, 379] -> 
             RGBColor[
              0.9667699799857179, 0.9735033935322186, 0.8858597970109416], 
             UndirectedEdge[175, 309] -> 
             RGBColor[
              0.9702399595547258, 0.977325591080284, 0.9352601651989108], 
             UndirectedEdge[294, 430] -> 
             RGBColor[
              0.8579939496174165, 0.8897658524496899, 0.9781285346323363], 
             UndirectedEdge[197, 237] -> 
             RGBColor[
              0.4358219185971056, 0.5509569191652015, 0.9492541653992037], 
             UndirectedEdge[94, 500] -> 
             RGBColor[
              0.9917996709183416, 0.9908769674329589, 0.7855642048618576], 
             UndirectedEdge[242, 365] -> 
             RGBColor[
              0.7657837967439282, 0.8130549701037662, 0.8165553647460444], 
             UndirectedEdge[401, 500] -> 
             RGBColor[
              0.9903805712531025, 0.9902901332521847, 0.8090823588270772], 
             UndirectedEdge[334, 340] -> 
             RGBColor[
              0.9896915477127703, 0.9885312466733261, 0.7133601016434661], 
             UndirectedEdge[60, 310] -> 
             RGBColor[
              0.8367622001803401, 0.8716716003138758, 0.9039553293434353], 
             UndirectedEdge[50, 379] -> 
             RGBColor[
              0.8457929779647224, 0.8802843359847987, 0.9794421983716741], 
             UndirectedEdge[123, 177] -> 
             RGBColor[
              0.8548357246993119, 0.8871133020896655, 0.96843283104178], 
             UndirectedEdge[231, 246] -> 
             RGBColor[
              0.9748147701419188, 0.9499368221713445, 0.6340532495026429], 
             UndirectedEdge[182, 282] -> 
             RGBColor[
              0.9770242049135575, 0.981602986367401, 0.8887439408567563], 
             UndirectedEdge[185, 193] -> 
             RGBColor[
              0.8242829871820079, 0.8622882123612778, 0.9192833928515283], 
             UndirectedEdge[395, 447] -> 
             RGBColor[
              0.9650248959235362, 0.9725740420313329, 0.9054784810803516], 
             UndirectedEdge[22, 282] -> 
             RGBColor[
              0.9912252952204327, 0.9891451928441162, 0.6864664975994881], 
             UndirectedEdge[195, 323] -> 
             RGBColor[
              0.8829907695961765, 0.8805650097571708, 0.666516144613988], 
             UndirectedEdge[99, 486] -> 
             RGBColor[
              0.8640866259758824, 0.8938744401871952, 0.9457793797052183], 
             UndirectedEdge[454, 469] -> 
             RGBColor[
              0.9268089337985883, 0.941814740623444, 0.8882522662587627], 
             UndirectedEdge[31, 208] -> 
             RGBColor[
              0.9702816981875055, 0.9773080040278612, 0.9330079259548689], 
             UndirectedEdge[398, 472] -> 
             RGBColor[
              0.935950872549516, 0.9514838959889457, 0.9839779750733753], 
             UndirectedEdge[191, 389] -> 
             RGBColor[
              0.9149048599426726, 0.9312259147371564, 0.8252051101499789], 
             UndirectedEdge[133, 151] -> 
             RGBColor[
              0.8074751890546679, 0.8498148493320484, 0.981368327315876], 
             UndirectedEdge[165, 268] -> 
             RGBColor[
              0.7781859696240918, 0.8268855616571029, 0.9784618761062877], 
             UndirectedEdge[166, 495] -> 
             RGBColor[
              0.6889715062014053, 0.750701226885353, 0.8959408239907272], 
             UndirectedEdge[346, 430] -> 
             RGBColor[
              0.9611508166445061, 0.9705469231799477, 0.9506457133177793], 
             UndirectedEdge[169, 219] -> 
             RGBColor[
              0.8959294493168215, 0.9189094628968995, 0.9570101873633401], 
             UndirectedEdge[197, 345] -> 
             RGBColor[
              0.741420144063577, 0.7937513751444758, 0.8471191831650344], 
             UndirectedEdge[100, 213] -> 
             RGBColor[
              0.8018033650105418, 0.8454267370530606, 0.9807916657726887], 
             UndirectedEdge[73, 187] -> 
             RGBColor[
              0.8664986289023038, 0.8562429074190185, 0.6481689742926504], 
             UndirectedEdge[97, 346] -> 
             RGBColor[
              0.9453050555943792, 0.9581451192699453, 0.9572186828739784], 
             UndirectedEdge[129, 170] -> 
             RGBColor[
              0.8069686220610182, 0.8499846498684842, 0.977101055442119], 
             UndirectedEdge[36, 37] -> 
             RGBColor[
              0.7968571353018451, 0.8419346398836881, 0.9684577571105499], 
             UndirectedEdge[143, 302] -> 
             RGBColor[
              0.821841148460138, 0.861254051950179, 0.9609105784795489], 
             UndirectedEdge[16, 236] -> 
             RGBColor[
              0.9004183645231395, 0.9190458640888437, 0.7644460132108816], 
             UndirectedEdge[187, 322] -> 
             RGBColor[
              0.9724203799916847, 0.9186296070885351, 0.3473588135522615], 
             UndirectedEdge[108, 163] -> 
             RGBColor[
              0.633600272267153, 0.7072634780503682, 0.967711874474421], 
             UndirectedEdge[137, 346] -> 
             RGBColor[
              0.9719953078571384, 0.9786347269701043, 0.932288818391086], 
             UndirectedEdge[243, 276] -> 
             RGBColor[
              0.8092518939689988, 0.8508199283041207, 0.9360537334087032], 
             UndirectedEdge[131, 147] -> 
             RGBColor[
              0.9668087641622676, 0.9716032355056532, 0.7537498730411643], 
             UndirectedEdge[9, 468] -> 
             RGBColor[
              0.863729692035089, 0.8941786273836028, 0.9868645031585471], 
             UndirectedEdge[331, 377] -> 
             RGBColor[
              0.8698977282214405, 0.8990968520117173, 0.9874528159562722], 
             UndirectedEdge[280, 470] -> 
             RGBColor[
              0.9924175857565489, 0.9901738228701289, 0.7056386969126998], 
             UndirectedEdge[234, 468] -> 
             RGBColor[
              0.8286770977362765, 0.8663169766703585, 0.9834977136306278], 
             UndirectedEdge[136, 488] -> 
             RGBColor[
              0.9244092810413965, 0.9415123373218668, 0.9562290445153316], 
             UndirectedEdge[57, 361] -> 
             RGBColor[
              0.8276212809199889, 0.8659127265093017, 0.9687350006817597], 
             UndirectedEdge[196, 414] -> 
             RGBColor[
              0.9680023751139504, 0.9728673061845807, 0.7813949883148624], 
             UndirectedEdge[103, 319] -> 
             RGBColor[
              0.8217115129360739, 0.4991519712533869, 0.5737468667655485], 
             UndirectedEdge[224, 263] -> 
             RGBColor[
              0.9949008918128619, 0.99150184812366, 0.6863717257571178], 
             UndirectedEdge[89, 184] -> 
             RGBColor[
              0.964179675617219, 0.9728058412424957, 0.9455186451299148], 
             UndirectedEdge[137, 407] -> 
             RGBColor[
              0.8399768312927149, 0.8753067475129244, 0.9568949841940374], 
             UndirectedEdge[53, 272] -> 
             RGBColor[
              0.9936979605764537, 0.9913357433232001, 0.730392197312471], 
             UndirectedEdge[236, 243] -> 
             RGBColor[
              0.8138514672379988, 0.8512922942591262, 0.7559045631290682], 
             UndirectedEdge[26, 351] -> 
             RGBColor[
              0.9935185686562746, 0.9885451986660297, 0.5359143808722518], 
             UndirectedEdge[67, 96] -> 
             RGBColor[
              0.8034158539459164, 0.8466362756903429, 0.9511586835040067], 
             UndirectedEdge[284, 464] -> 
             RGBColor[
              0.7817794423097515, 0.8295157568124094, 0.961388075222382], 
             UndirectedEdge[325, 401] -> 
             RGBColor[
              0.9885302843819304, 0.9895249920807514, 0.8397464006713269], 
             UndirectedEdge[227, 348] -> 
             RGBColor[
              0.9757894920650747, 0.9800231560801232, 0.8613233616309361], 
             UndirectedEdge[106, 117] -> 
             RGBColor[
              0.8701486403301535, 0.8991232355803043, 0.9723568102774449], 
             UndirectedEdge[395, 440] -> 
             RGBColor[
              0.9175587151452096, 0.9369722846962092, 0.9875559109074921], 
             UndirectedEdge[204, 361] -> 
             RGBColor[
              0.8969782779348463, 0.9202737894733093, 0.9756003967381595], 
             UndirectedEdge[195, 263] -> 
             RGBColor[
              0.9844136183501565, 0.9575918172422473, 0.5209721622298771], 
             UndirectedEdge[360, 393] -> 
             RGBColor[
              0.9255999180334553, 0.9430738506783867, 0.977565600160377], 
             UndirectedEdge[74, 440] -> 
             RGBColor[
              0.8116111802129309, 0.8533579634724715, 0.9816977567380636], 
             UndirectedEdge[166, 348] -> 
             RGBColor[
              0.9905153751970459, 0.9903458781473087, 0.8068483086145106], 
             UndirectedEdge[209, 477] -> 
             RGBColor[
              0.9548307778202553, 0.9658334485729354, 0.9613438905171163], 
             UndirectedEdge[292, 422] -> 
             RGBColor[
              0.8785124574796287, 0.9059660032816003, 0.9882744965233778], 
             UndirectedEdge[36, 416] -> 
             RGBColor[
              0.41195422260949954`, 0.513988837068202, 0.9493751904156429], 
             UndirectedEdge[306, 418] -> 
             RGBColor[
              0.8655826529659991, 0.8956561281326259, 0.9870412402262951], 
             UndirectedEdge[363, 498] -> 
             RGBColor[
              0.821541482719119, 0.8613433462105791, 0.982627077327769], 
             UndirectedEdge[57, 466] -> 
             RGBColor[
              0.830703751892004, 0.8682116283131476, 0.9635171813633254], 
             UndirectedEdge[263, 395] -> 
             RGBColor[
              0.9677958545918847, 0.9734105531187027, 0.8370699342112891], 
             UndirectedEdge[171, 238] -> 
             RGBColor[
              0.8070164450554531, 0.8470794476293964, 0.8553783376170716], 
             UndirectedEdge[42, 286] -> 
             RGBColor[
              0.7772490725719939, 0.8259704475588581, 0.9784171114072826], 
             UndirectedEdge[246, 444] -> 
             RGBColor[
              0.9598481337368708, 0.9387747292460776, 0.6593878610124435], 
             UndirectedEdge[46, 306] -> 
             RGBColor[
              0.9115203261060991, 0.9311022393675767, 0.9503955932657773], 
             UndirectedEdge[229, 411] -> 
             RGBColor[
              0.9706599482391831, 0.9748060421740017, 0.7734625101485159], 
             UndirectedEdge[239, 440] -> 
             RGBColor[
              0.9272370552666924, 0.8977452434387097, 0.6444997884973487], 
             UndirectedEdge[57, 106] -> 
             RGBColor[
              0.827965465684645, 0.8661694189432314, 0.9681523856529602], 
             UndirectedEdge[60, 280] -> 
             RGBColor[
              0.8395502429383239, 0.8718658594156168, 0.7880651856525545], 
             UndirectedEdge[438, 457] -> 
             RGBColor[
              0.6476055228248301, 0.722273433949161, 0.9671245988536912], 
             UndirectedEdge[130, 368] -> 
             RGBColor[
              0.6955518221149493, 0.7318838245754633, 0.653781752408056], 
             UndirectedEdge[152, 287] -> 
             RGBColor[
              0.6868612015741529, 0.7544709523078434, 0.9699907011959443], 
             UndirectedEdge[54, 242] -> 
             RGBColor[
              0.8830281072136389, 0.9062647893890114, 0.8271351701363497], 
             UndirectedEdge[89, 235] -> 
             RGBColor[
              0.9129689647923401, 0.9325548168017941, 0.9608473159899342], 
             UndirectedEdge[60, 260] -> 
             RGBColor[
              0.762804427002265, 0.8147951538561569, 0.9769484859931864], 
             UndirectedEdge[88, 243] -> 
             RGBColor[
              0.7880802724438851, 0.8350689798846809, 0.9736298579996944], 
             UndirectedEdge[36, 367] -> 
             RGBColor[
              0.5902681674691572, 0.6782051429701036, 0.9609146850168216], 
             UndirectedEdge[17, 282] -> 
             RGBColor[
              0.8857306974829047, 0.9098699016723324, 0.9062849430377053], 
             UndirectedEdge[150, 233] -> 
             RGBColor[
              0.625024053981112, 0.7062796039889887, 0.9637478363494765], 
             UndirectedEdge[250, 365] -> 
             RGBColor[
              0.5023273615132766, 0.6068510075230537, 0.9539641964655318], 
             UndirectedEdge[107, 423] -> 
             RGBColor[
              0.991899652978169, 0.9888818558663046, 0.6358783379301248], 
             UndirectedEdge[315, 347] -> 
             RGBColor[
              0.8157495973988241, 0.8566201199553911, 0.9666225058298543], 
             UndirectedEdge[288, 492] -> 
             RGBColor[
              0.8500887515984856, 0.8811496152830491, 0.862987014064367], 
             UndirectedEdge[24, 267] -> 
             RGBColor[
              0.631109227277784, 0.7005476118914498, 0.9363138582583079], 
             UndirectedEdge[198, 480] -> 
             RGBColor[
              0.9537639352594696, 0.9650377991378958, 0.9631497766954236], 
             UndirectedEdge[4, 479] -> 
             RGBColor[
              0.9613977823448105, 0.9684047013395063, 0.8382803635475119], 
             UndirectedEdge[133, 239] -> 
             RGBColor[
              0.9079335302455215, 0.882353136567056, 0.6426586010483691], 
             UndirectedEdge[115, 253] -> 
             RGBColor[
              0.8080073139284869, 0.8508687957882575, 0.9808852489677164], 
             UndirectedEdge[199, 371] -> 
             RGBColor[
              0.8855778909439811, 0.9115997881399927, 0.9889484038745946], 
             UndirectedEdge[93, 189] -> 
             RGBColor[
              0.9288320973118245, 0.9440767846469529, 0.9166196047129405], 
             UndirectedEdge[357, 418] -> 
             RGBColor[
              0.9241269723273241, 0.941748730886074, 0.9722025731799933], 
             UndirectedEdge[82, 463] -> 
             RGBColor[
              0.8308709227331921, 0.8683913880586076, 0.9660225480921021], 
             UndirectedEdge[102, 350] -> 
             RGBColor[
              0.7256481333533514, 0.7850184036378556, 0.9738810865073722], 
             UndirectedEdge[235, 296] -> 
             RGBColor[
              0.7579032953956957, 0.8110892634022613, 0.9764273702492696], 
             UndirectedEdge[26, 360] -> 
             RGBColor[
              0.9726302729422076, 0.9753700254054052, 0.6982811639016009], 
             UndirectedEdge[309, 320] -> 
             RGBColor[
              0.9810180613844054, 0.9845127986253474, 0.8789024077695359], 
             UndirectedEdge[13, 229] -> 
             RGBColor[
              0.974268909093935, 0.9774975992703446, 0.7673534807891615], 
             UndirectedEdge[353, 420] -> 
             RGBColor[
              0.8957664882772861, 0.8706456215920764, 0.6385472356074835], 
             UndirectedEdge[171, 465] -> 
             RGBColor[
              0.8038867758028518, 0.8457852489646146, 0.9072450564570695], 
             UndirectedEdge[104, 224] -> 
             RGBColor[
              0.9813648369049714, 0.9473353554782061, 0.5067648261214692], 
             UndirectedEdge[22, 285] -> 
             RGBColor[
              0.9753258517479896, 0.978069697728635, 0.7484123747235676], 
             UndirectedEdge[126, 285] -> 
             RGBColor[
              0.9755124791360856, 0.9784688748408488, 0.7687256141870809], 
             UndirectedEdge[98, 319] -> 
             RGBColor[
              0.8869833039689566, 0.912406761047692, 0.9782074809320218], 
             UndirectedEdge[286, 411] -> 
             RGBColor[
              0.8373805425184515, 0.8736143746482233, 0.9736377762760968], 
             UndirectedEdge[259, 491] -> 
             RGBColor[
              0.988281345687734, 0.9894220495332686, 0.8438719590668493], 
             UndirectedEdge[1, 266] -> 
             RGBColor[
              0.7945206735347827, 0.839770093176202, 0.9800571308264366], 
             UndirectedEdge[67, 216] -> 
             RGBColor[
              0.9782917562459371, 0.9827365169157364, 0.8950259669602817], 
             UndirectedEdge[41, 451] -> 
             RGBColor[
              0.971771803008511, 0.9777038335803792, 0.898444544504314], 
             UndirectedEdge[300, 456] -> 
             RGBColor[
              0.8490736710524427, 0.8824923140791321, 0.985466598793638], 
             UndirectedEdge[117, 139] -> 
             RGBColor[
              0.8910786349918451, 0.9122712728648683, 0.8052987449928497], 
             UndirectedEdge[70, 96] -> 
             RGBColor[
              0.7673173414198833, 0.8187062872931887, 0.977323792799178], 
             UndirectedEdge[92, 274] -> 
             RGBColor[
              0.9898285415721894, 0.9900618547926114, 0.8182309192468271], 
             UndirectedEdge[241, 436] -> 
             RGBColor[
              0.9642350540709201, 0.9717157969153754, 0.8947609414609395], 
             UndirectedEdge[207, 295] -> 
             RGBColor[
              0.9280071681845233, 0.90538976132186, 0.6549159563159672], 
             UndirectedEdge[83, 176] -> 
             RGBColor[
              0.9747534855817723, 0.9797522843648472, 0.885547793986247], 
             UndirectedEdge[56, 495] -> 
             RGBColor[
              0.6620899744071904, 0.731279356658992, 0.9698312634692732], 
             UndirectedEdge[219, 334] -> 
             RGBColor[
              0.9830489424086005, 0.9838459549757188, 0.7366395840951765], 
             UndirectedEdge[124, 357] -> 
             RGBColor[
              0.8836642018095306, 0.9095753189671125, 0.9683191813037824], 
             UndirectedEdge[40, 291] -> 
             RGBColor[
              0.8120417178549755, 0.853922057697823, 0.9816802295464612], 
             UndirectedEdge[7, 487] -> 
             RGBColor[
              0.9311525016128244, 0.9450829071819655, 0.8801869792114966], 
             UndirectedEdge[423, 477] -> 
             RGBColor[
              0.9678387920447751, 0.9744240326331701, 0.8895820915534591], 
             UndirectedEdge[22, 165] -> 
             RGBColor[
              0.9217064417779786, 0.9358669549302957, 0.7624334944578928], 
             UndirectedEdge[302, 368] -> 
             RGBColor[
              0.5496062294068595, 0.6435722139910671, 0.9584036666007913], 
             UndirectedEdge[297, 419] -> 
             RGBColor[
              0.6825360810840196, 0.7505048134380051, 0.9699611687767702], 
             UndirectedEdge[263, 463] -> 
             RGBColor[
              0.9750781471528722, 0.9788416749870277, 0.8247429124316255], 
             UndirectedEdge[260, 424] -> 
             RGBColor[
              0.6935197368422782, 0.7591988506612295, 0.9710482768734554], 
             UndirectedEdge[193, 415] -> 
             RGBColor[
              0.9849709403878435, 0.9879107634794551, 0.8923592902562634], 
             UndirectedEdge[434, 474] -> 
             RGBColor[
              0.7650548865491051, 0.8131610733928618, 0.8582581592859543], 
             UndirectedEdge[102, 109] -> 
             RGBColor[
              0.7833657328654464, 0.8258362971140529, 0.6956160091794787], 
             UndirectedEdge[58, 118] -> 
             RGBColor[
              0.8911903186511567, 0.9147032559504749, 0.9325962798385266], 
             UndirectedEdge[39, 100] -> 
             RGBColor[
              0.9243662966326548, 0.9406239984074145, 0.9208886832435745], 
             UndirectedEdge[35, 216] -> 
             RGBColor[
              0.974130446211087, 0.979633018705265, 0.9020699794058038], 
             UndirectedEdge[72, 163] -> 
             RGBColor[
              0.6636175105446558, 0.7301790441393154, 0.9352329238644214], 
             UndirectedEdge[202, 414] -> 
             RGBColor[
              0.9050147840165104, 0.9269336294413837, 0.985095192734011], 
             UndirectedEdge[324, 441] -> 
             RGBColor[
              0.9614244904621729, 0.8812165898934058, 0.30631519423265985`], 
             UndirectedEdge[18, 52] -> 
             RGBColor[
              0.5607304582117086, 0.6533864642740115, 0.9590367303188319], 
             UndirectedEdge[168, 368] -> 
             RGBColor[
              0.4560641958613137, 0.5682646288235607, 0.9506061904641752], 
             UndirectedEdge[208, 397] -> 
             RGBColor[
              0.9224192321223503, 0.9404505508989001, 0.9742421631847429], 
             UndirectedEdge[193, 350] -> 
             RGBColor[
              0.9318658958534172, 0.9467946484677536, 0.9298836909280926], 
             UndirectedEdge[2, 365] -> 
             RGBColor[
              0.6343712043050559, 0.7126772004370696, 0.965297862942263], 
             UndirectedEdge[42, 248] -> 
             RGBColor[
              0.720872935995343, 0.7815029699157454, 0.9730893312135991], 
             UndirectedEdge[46, 68] -> 
             RGBColor[
              0.9880547782352794, 0.988239946226495, 0.7805855304651466], 
             UndirectedEdge[260, 470] -> 
             RGBColor[
              0.91567176982049, 0.933103117310669, 0.8945219972533317], 
             UndirectedEdge[32, 344] -> 
             RGBColor[
              0.9941679548134303, 0.9899341699931736, 0.6065960565318247], 
             UndirectedEdge[60, 483] -> 
             RGBColor[
              0.8391294355934298, 0.8726505129923634, 0.864724112339672], 
             UndirectedEdge[337, 498] -> 
             RGBColor[
              0.7166625121746797, 0.7785814684384682, 0.9723938796877722], 
             UndirectedEdge[86, 168] -> 
             RGBColor[
              0.6485614086045031, 0.7231485311259493, 0.967132117692093], 
             UndirectedEdge[151, 424] -> 
             RGBColor[
              0.6527343312266782, 0.7271697109509214, 0.9670275573468672], 
             UndirectedEdge[234, 296] -> 
             RGBColor[
              0.7344877561458071, 0.7925066845055846, 0.9741705334204384], 
             UndirectedEdge[223, 268] -> 
             RGBColor[
              0.8507072451345118, 0.8814053782547548, 0.8527369755624512], 
             UndirectedEdge[50, 204] -> 
             RGBColor[
              0.7958895333239079, 0.8406530692712079, 0.9802430275092664], 
             UndirectedEdge[26, 247] -> 
             RGBColor[
              0.8605482401723095, 0.8871764089815787, 0.7025946752800141], 
             UndirectedEdge[64, 435] -> 
             RGBColor[
              0.6179132016766338, 0.700020928892881, 0.9635201640925852], 
             UndirectedEdge[143, 214] -> 
             RGBColor[
              0.9742371117239539, 0.9795840410041592, 0.896133646254498], 
             UndirectedEdge[38, 266] -> 
             RGBColor[
              0.8341839268280999, 0.8711695810869359, 0.9759730091609622], 
             UndirectedEdge[309, 375] -> 
             RGBColor[
              0.8141919148064963, 0.8550519941745454, 0.9486869166122631], 
             UndirectedEdge[70, 385] -> 
             RGBColor[
              0.8411316483858597, 0.8764371122911869, 0.9846354279460261], 
             UndirectedEdge[232, 354] -> 
             RGBColor[
              0.885135446184019, 0.9106728913293394, 0.9658449829653546], 
             UndirectedEdge[86, 484] -> 
             RGBColor[
              0.8946781571378415, 0.9168600237790101, 0.9071902829427331], 
             UndirectedEdge[106, 360] -> 
             RGBColor[
              0.9526167512852008, 0.9641822312082274, 0.9650916599303612], 
             UndirectedEdge[163, 322] -> 
             RGBColor[
              0.665884456996152, 0.7113544015446418, 0.659766424121889], 
             UndirectedEdge[44, 117] -> 
             RGBColor[
              0.7561278352856955, 0.8094120788003585, 0.9763274142710652], 
             UndirectedEdge[113, 273] -> 
             RGBColor[
              0.9422852976331197, 0.9528481449161204, 0.8107781915872554], 
             UndirectedEdge[53, 298] -> 
             RGBColor[
              0.9586566253304648, 0.967027309028889, 0.883390491968017], 
             UndirectedEdge[50, 369] -> 
             RGBColor[
              0.8560912844460236, 0.8879647960966239, 0.9620098517273319], 
             UndirectedEdge[135, 385] -> 
             RGBColor[
              0.8858554857930465, 0.9104884748500475, 0.929925705130787], 
             UndirectedEdge[376, 464] -> 
             RGBColor[
              0.9645477847337003, 0.973080376418844, 0.9448955324139459], 
             UndirectedEdge[95, 408] -> 
             RGBColor[
              0.735211768305602, 0.7733169365189627, 0.6688158686752603], 
             UndirectedEdge[34, 332] -> 
             RGBColor[
              0.9048080509314553, 0.926440307818062, 0.9736869264220871], 
             UndirectedEdge[251, 416] -> 
             RGBColor[
              0.39991221690256795`, 0.5042527668652351, 0.9483997334464165], 
             UndirectedEdge[62, 209] -> 
             RGBColor[
              0.9082512600237845, 0.9289268869174887, 0.9650376483500342], 
             UndirectedEdge[109, 496] -> 
             RGBColor[
              0.9364047496522692, 0.9469231919434107, 0.7100260815373973], 
             UndirectedEdge[179, 254] -> 
             RGBColor[
              0.981294775800372, 0.9780037637988426, 0.6724060232007392], 
             UndirectedEdge[27, 199] -> 
             RGBColor[
              0.9067563494079418, 0.9284869160452143, 0.9909684241491203], 
             UndirectedEdge[59, 453] -> 
             RGBColor[
              0.9946316848878219, 0.9909260417319947, 0.6570702133190747], 
             UndirectedEdge[450, 475] -> 
             RGBColor[
              0.8965020495625533, 0.9159508588977382, 0.761208283246855], 
             UndirectedEdge[311, 331] -> 
             RGBColor[
              0.8932013322356274, 0.9173579744115068, 0.9785622502643194], 
             UndirectedEdge[329, 486] -> 
             RGBColor[
              0.9293198457005823, 0.9452969774189447, 0.952158656567919], 
             UndirectedEdge[287, 456] -> 
             RGBColor[
              0.7130379923755024, 0.7750650000811449, 0.9725614026354567], 
             UndirectedEdge[60, 118] -> 
             RGBColor[
              0.7407503599889602, 0.7973990782254079, 0.9747947312441636], 
             UndirectedEdge[267, 493] -> 
             RGBColor[
              0.6390131620233306, 0.7058898577189996, 0.8981926692757385], 
             UndirectedEdge[239, 263] -> 
             RGBColor[
              0.9774741947133674, 0.9341835118612033, 0.4940138118011457], 
             UndirectedEdge[64, 91] -> 
             RGBColor[
              0.8401212142327374, 0.8723895399300157, 0.7943401347134926], 
             UndirectedEdge[469, 471] -> 
             RGBColor[
              0.9075345944574392, 0.9286614378066127, 0.9755785235999901], 
             UndirectedEdge[275, 282] -> 
             RGBColor[
              0.9815580862299984, 0.9849843476296533, 0.881069262413654], 
             UndirectedEdge[132, 423] -> 
             RGBColor[
              0.983875902835007, 0.9620740865397133, 0.5827500810737558], 
             UndirectedEdge[116, 412] -> 
             RGBColor[
              0.9908127924815723, 0.9900314441325386, 0.7701232488301921], 
             UndirectedEdge[89, 453] -> 
             RGBColor[
              0.9823579018625799, 0.9840900533947264, 0.798070454256613], 
             UndirectedEdge[136, 311] -> 
             RGBColor[
              0.9102548355652956, 0.9309559750615681, 0.9801888286357453], 
             UndirectedEdge[6, 24] -> 
             RGBColor[
              0.9685913076374444, 0.9760960291797953, 0.9380509028575823], 
             UndirectedEdge[51, 477] -> 
             RGBColor[
              0.795396262921483, 0.8408630301242216, 0.9718370555665563], 
             UndirectedEdge[114, 381] -> 
             RGBColor[
              0.9015565432051423, 0.9243407317240814, 0.9904724619915755], 
             UndirectedEdge[95, 294] -> 
             RGBColor[
              0.8766480363829576, 0.8861668768253648, 0.6813001535865002], 
             UndirectedEdge[89, 192] -> 
             RGBColor[
              0.9342180133800599, 0.9494982313555835, 0.9628740692134805], 
             UndirectedEdge[108, 374] -> 
             RGBColor[
              0.8754583246902699, 0.6053990482387707, 0.58680714200836], 
             UndirectedEdge[208, 472] -> 
             RGBColor[
              0.9406737947830729, 0.955006243657657, 0.9759832996673632], 
             UndirectedEdge[34, 360] -> 
             RGBColor[
              0.903747984023763, 0.9256497116540052, 0.9754813431870808], 
             UndirectedEdge[395, 453] -> 
             RGBColor[
              0.9676660357220606, 0.9731328836828501, 0.8229399513801292], 
             UndirectedEdge[101, 361] -> 
             RGBColor[
              0.9730398672444647, 0.9768419159854675, 0.7901379339468207], 
             UndirectedEdge[11, 211] -> 
             RGBColor[
              0.7334059251327163, 0.7916615498959378, 0.9740627066153391], 
             UndirectedEdge[70, 433] -> 
             RGBColor[
              0.917347884522816, 0.9368709912631819, 0.9898523953539461], 
             UndirectedEdge[108, 206] -> 
             RGBColor[
              0.7824789739769167, 0.830767338290292, 0.9787496346899369], 
             UndirectedEdge[251, 499] -> 
             RGBColor[
              0.7935058816657936, 0.8386801183453831, 0.9527711237964847], 
             UndirectedEdge[116, 399] -> 
             RGBColor[
              0.7913259716151957, 0.8357838915197588, 0.9144526879293402], 
             UndirectedEdge[350, 479] -> 
             RGBColor[
              0.9025227371241973, 0.9251111485285005, 0.9905646184301065], 
             UndirectedEdge[347, 421] -> 
             RGBColor[
              0.8359506769162941, 0.870175557652371, 0.8647843252328615], 
             UndirectedEdge[153, 447] -> 
             RGBColor[
              0.9920973751502395, 0.9905956987786564, 0.7512365358741073], 
             UndirectedEdge[195, 453] -> 
             RGBColor[
              0.9842837994803324, 0.9573141478063947, 0.5068421793987172], 
             UndirectedEdge[338, 425] -> 
             RGBColor[
              0.8837460596928335, 0.9078193097509926, 0.8834069478920317], 
             UndirectedEdge[164, 348] -> 
             RGBColor[
              0.9753676521185038, 0.9797085485386703, 0.8620374266270018], 
             UndirectedEdge[31, 258] -> 
             RGBColor[
              0.761152509864115, 0.8117588095017676, 0.9317708803029496], 
             UndirectedEdge[31, 203] -> 
             RGBColor[
              0.9617910828204779, 0.9709757169892386, 0.9473803230640978], 
             UndirectedEdge[398, 445] -> 
             RGBColor[
              0.9682341001313886, 0.9748919716592166, 0.8966655562236708], 
             UndirectedEdge[44, 369] -> 
             RGBColor[
              0.84350340877716, 0.8781310519527092, 0.9607552099210459], 
             UndirectedEdge[267, 278] -> 
             RGBColor[
              0.5283178217457896, 0.6199484588669133, 0.9585897208952223], 
             UndirectedEdge[130, 477] -> 
             RGBColor[
              0.9602202482602344, 0.9439225845127888, 0.6690967631226358], 
             UndirectedEdge[4, 482] -> 
             RGBColor[
              0.8595947402418258, 0.8880029815394177, 0.8283650983919257], 
             UndirectedEdge[219, 274] -> 
             RGBColor[
              0.9792528260328324, 0.9837501209364317, 0.9066922168585971], 
             UndirectedEdge[44, 269] -> 
             RGBColor[
              0.8002936840423026, 0.8443683057322238, 0.9806091003487581], 
             UndirectedEdge[130, 143] -> 
             RGBColor[
              0.9677867411682277, 0.949565662534575, 0.6562886642868134], 
             UndirectedEdge[315, 401] -> 
             RGBColor[
              0.9705226398456815, 0.9768765961172142, 0.9052336872017168], 
             UndirectedEdge[75, 163] -> 
             RGBColor[
              0.5951505486431132, 0.6766047121225032, 0.9640445055106865], 
             UndirectedEdge[9, 139] -> 
             RGBColor[
              0.9367766232928363, 0.9484491862806055, 0.8097265679080432], 
             UndirectedEdge[134, 438] -> 
             RGBColor[
              0.8302790347316495, 0.8676115383995328, 0.9836459379796295], 
             UndirectedEdge[76, 431] -> 
             RGBColor[
              0.7783592223812701, 0.8274070465902854, 0.9783766750201682], 
             UndirectedEdge[90, 124] -> 
             RGBColor[
              0.852970094805223, 0.8856897195732745, 0.9858142264668746], 
             UndirectedEdge[37, 188] -> 
             RGBColor[
              0.8515977988756123, 0.8846984623119671, 0.9739137948749973], 
             UndirectedEdge[26, 106] -> 
             RGBColor[
              0.9725467715675435, 0.9753077502169016, 0.6984225099482608], 
             UndirectedEdge[107, 446] -> 
             RGBColor[
              0.9618492691403717, 0.967454179153773, 0.7320879821743123], 
             UndirectedEdge[19, 234] -> 
             RGBColor[
              0.888853379940459, 0.9134501450413709, 0.9597754737641417], 
             UndirectedEdge[39, 243] -> 
             RGBColor[
              0.8108391768340468, 0.8514763105601271, 0.9097483485784781], 
             UndirectedEdge[129, 265] -> 
             RGBColor[
              0.9676593360197103, 0.9735878142983115, 0.8584318377848059], 
             UndirectedEdge[396, 446] -> 
             RGBColor[
              0.8959547737502802, 0.9198740328167554, 0.9899381602202121], 
             UndirectedEdge[325, 368] -> 
             RGBColor[
              0.702179926905285, 0.7619757007186199, 0.8906812181468067], 
             UndirectedEdge[52, 56] -> 
             RGBColor[
              0.688163227039684, 0.7538626976094768, 0.9714926280713436], 
             UndirectedEdge[402, 431] -> 
             RGBColor[
              0.9438405463264372, 0.9556831672617133, 0.9023775487973151], 
             UndirectedEdge[165, 353] -> 
             RGBColor[
              0.9041652709773167, 0.8773425829381977, 0.6393483189990943], 
             UndirectedEdge[237, 329] -> 
             RGBColor[
              0.6301974304787991, 0.7056252492766882, 0.9668923785471395], 
             UndirectedEdge[63, 75] -> 
             RGBColor[
              0.5773437631743141, 0.6611813695444901, 0.9629098728865368], 
             UndirectedEdge[392, 492] -> 
             RGBColor[
              0.7505491864639745, 0.8050539959415286, 0.9757713866919533], 
             UndirectedEdge[125, 177] -> 
             RGBColor[
              0.8595663179565791, 0.8906413707952998, 0.9604251705935496], 
             UndirectedEdge[210, 348] -> 
             RGBColor[
              0.913316596774635, 0.9308024012848988, 0.875939444190923], 
             UndirectedEdge[469, 491] -> 
             RGBColor[
              0.9264133472930011, 0.9416511554372742, 0.8948081584014016], 
             UndirectedEdge[35, 171] -> 
             RGBColor[
              0.7902157019056097, 0.8361946383446499, 0.9574911251964899], 
             UndirectedEdge[8, 40] -> 
             RGBColor[
              0.7279593741656598, 0.7874066628851529, 0.9735198453158556], 
             UndirectedEdge[405, 491] -> 
             RGBColor[
              0.9850400055756742, 0.9872734158468762, 0.8613939867403538], 
             UndirectedEdge[98, 136] -> 
             RGBColor[
              0.9101215605345998, 0.930856578761893, 0.9804144284990183], 
             UndirectedEdge[14, 75] -> 
             RGBColor[
              0.91587609048317, 0.9311558728244059, 0.7568418841542002], 
             UndirectedEdge[121, 500] -> 
             RGBColor[
              0.9335616837588452, 0.9469970282184823, 0.8801173465935603], 
             UndirectedEdge[1, 265] -> 
             RGBColor[
              0.9301387922181896, 0.9437863556181947, 0.8588889111888075], 
             UndirectedEdge[227, 495] -> 
             RGBColor[
              0.674245623069434, 0.7403785048181676, 0.9504158770071527], 
             UndirectedEdge[127, 368] -> 
             RGBColor[
              0.6821333611223357, 0.7478066806277206, 0.9596198665120317], 
             UndirectedEdge[207, 389] -> 
             RGBColor[
              0.980099984973741, 0.9431687569847134, 0.4933440894769241], 
             UndirectedEdge[249, 260] -> 
             RGBColor[
              0.9174452890507323, 0.9329129803136913, 0.7979991103764907], 
             UndirectedEdge[42, 95] -> 
             RGBColor[
              0.9046230889102562, 0.9080794981410587, 0.6840729749733956], 
             UndirectedEdge[190, 323] -> 
             RGBColor[
              0.8330768556197272, 0.8699624438150683, 0.9838809525928007], 
             UndirectedEdge[109, 295] -> 
             RGBColor[
              0.9415454661412404, 0.9510222597306845, 0.710516407665287], 
             UndirectedEdge[382, 499] -> 
             RGBColor[
              0.9387339059139992, 0.9532006239945117, 0.9668253417442789], 
             UndirectedEdge[213, 254] -> 
             RGBColor[
              0.8660468261170953, 0.8876957810428385, 0.6945700285986482], 
             UndirectedEdge[47, 374] -> 
             RGBColor[
              0.8879676751666221, 0.615257260272155, 0.5839644786572481], 
             UndirectedEdge[244, 390] -> 
             RGBColor[
              0.9341894575010998, 0.9332342592664957, 0.6892164595889423], 
             UndirectedEdge[92, 370] -> 
             RGBColor[
              0.8587325370298506, 0.8879008568097329, 0.8637873606704313], 
             UndirectedEdge[295, 458] -> 
             RGBColor[
              0.848721446689031, 0.8823171139866148, 0.9854049659820565], 
             UndirectedEdge[278, 493] -> 
             RGBColor[
              0.8768222162567672, 0.9031648042377547, 0.9169269735815646], 
             UndirectedEdge[6, 156] -> 
             RGBColor[
              0.9794393693697343, 0.9810371836564391, 0.7334854290303923], 
             UndirectedEdge[79, 413] -> 
             RGBColor[
              0.9735684495721619, 0.9798079734853857, 0.9296258998086222], 
             UndirectedEdge[122, 476] -> 
             RGBColor[
              0.8047601241440058, 0.847806178622602, 0.9810678984925478], 
             UndirectedEdge[123, 455] -> 
             RGBColor[
              0.9749890637623158, 0.9786679968083094, 0.8163846774626896], 
             UndirectedEdge[113, 302] -> 
             RGBColor[
              0.7869586550726964, 0.8340646180872917, 0.9792498066267314], 
             UndirectedEdge[402, 462] -> 
             RGBColor[
              0.9925891426247079, 0.9910758092060897, 0.7632036205842717], 
             UndirectedEdge[140, 363] -> 
             RGBColor[
              0.9466084582478063, 0.9593641770674535, 0.9635753912157063], 
             UndirectedEdge[440, 453] -> 
             RGBColor[
              0.9445564508175335, 0.9548340725384475, 0.8251785910707999], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.9158466286311446, 0.9353011489960414, 0.9767846331926383], 
             UndirectedEdge[102, 202] -> 
             RGBColor[
              0.7210591833634461, 0.7813592994796343, 0.973443388360731], 
             UndirectedEdge[363, 379] -> 
             RGBColor[
              0.932273012257631, 0.9486728249201193, 0.9878415619939532], 
             UndirectedEdge[162, 297] -> 
             RGBColor[
              0.7561961932848003, 0.8085090200141587, 0.9530146474554964], 
             UndirectedEdge[19, 393] -> 
             RGBColor[
              0.9335757622669181, 0.9490222222484568, 0.9640645763064596], 
             UndirectedEdge[96, 238] -> 
             RGBColor[
              0.8160552870609097, 0.854417586764618, 0.8560899083701103], 
             UndirectedEdge[117, 247] -> 
             RGBColor[
              0.7581501089349194, 0.8109918943449812, 0.9765289756091982], 
             UndirectedEdge[162, 223] -> 
             RGBColor[
              0.9787144198701365, 0.9818659231361021, 0.8412072615324757], 
             UndirectedEdge[355, 362] -> 
             RGBColor[
              0.7447009934293881, 0.7969624917046207, 0.8702682571580564], 
             UndirectedEdge[59, 395] -> 
             RGBColor[
              0.9676339492154981, 0.9730642538897564, 0.8194475331557667], 
             UndirectedEdge[161, 403] -> 
             RGBColor[
              0.9768181303331883, 0.9759051835017063, 0.6826163023422438], 
             UndirectedEdge[214, 477] -> 
             RGBColor[
              0.9666706188159607, 0.9739409629823728, 0.9089417450903203], 
             UndirectedEdge[65, 309] -> 
             RGBColor[
              0.9632952415187641, 0.972146231739996, 0.9470157613612423], 
             UndirectedEdge[361, 498] -> 
             RGBColor[
              0.8361501930371489, 0.87257557747736, 0.9695850829343828], 
             UndirectedEdge[54, 70] -> 
             RGBColor[
              0.8339325848451256, 0.870813149138256, 0.9839178925713594], 
             UndirectedEdge[369, 390] -> 
             RGBColor[
              0.9728954531678364, 0.9634058541785304, 0.6689329994621862], 
             UndirectedEdge[56, 88] -> 
             RGBColor[
              0.9382414262363359, 0.9534276520342964, 0.9882643795307117], 
             UndirectedEdge[289, 419] -> 
             RGBColor[
              0.8568879367906544, 0.8887618398193542, 0.9862016759432395], 
             UndirectedEdge[124, 178] -> 
             RGBColor[
              0.8507796286647833, 0.8839431013315073, 0.9856052978509473], 
             UndirectedEdge[67, 465] -> 
             RGBColor[
              0.9783253520130246, 0.9827504096287989, 0.8944691981565822], 
             UndirectedEdge[7, 461] -> 
             RGBColor[
              0.8410041404219764, 0.8761202796036787, 0.9846803633155468], 
             UndirectedEdge[273, 423] -> 
             RGBColor[
              0.9926404105714326, 0.9904662614562144, 0.7165052305309207], 
             UndirectedEdge[63, 467] -> 
             RGBColor[
              0.619576435344289, 0.6948565559574811, 0.9669380628596606], 
             UndirectedEdge[179, 368] -> 
             RGBColor[
              0.6942165230052311, 0.7568182829756223, 0.9391662252376345], 
             UndirectedEdge[211, 485] -> 
             RGBColor[
              0.66757649041147, 0.7402350951694661, 0.9675014437733689], 
             UndirectedEdge[21, 320] -> 
             RGBColor[
              0.9602114589146162, 0.9688768823683311, 0.9100180345536942], 
             UndirectedEdge[318, 479] -> 
             RGBColor[
              0.9545226030820325, 0.9466771436812067, 0.6870805056667744], 
             UndirectedEdge[343, 465] -> 
             RGBColor[
              0.9699145768501236, 0.9764776672836877, 0.9087064466258848], 
             UndirectedEdge[229, 313] -> 
             RGBColor[
              0.9138806518941763, 0.9298350473221049, 0.7785615785903286], 
             UndirectedEdge[168, 401] -> 
             RGBColor[
              0.742414553337959, 0.7958139201856922, 0.8996713729886954], 
             UndirectedEdge[70, 216] -> 
             RGBColor[
              0.942193243719904, 0.954806528518582, 0.9211910762554532], 
             UndirectedEdge[5, 193] -> 
             RGBColor[
              0.8082662731895154, 0.8495853736407444, 0.9178172150400061], 
             UndirectedEdge[213, 471] -> 
             RGBColor[
              0.8477349214330923, 0.8816052836493453, 0.9697085283711573], 
             UndirectedEdge[145, 404] -> 
             RGBColor[
              0.9692018928153454, 0.975552421922151, 0.8922809453695699], 
             UndirectedEdge[28, 173] -> 
             RGBColor[
              0.8668635400216204, 0.8954675793886511, 0.9196784019033831], 
             UndirectedEdge[210, 243] -> 
             RGBColor[
              0.7339220782395542, 0.7920493155454029, 0.9741713204422553], 
             UndirectedEdge[133, 424] -> 
             RGBColor[
              0.701101222370351, 0.7652441214273723, 0.971771405731195], 
             UndirectedEdge[201, 400] -> 
             RGBColor[
              0.9109807566890908, 0.9313268716803468, 0.9730488937336779], 
             UndirectedEdge[120, 125] -> 
             RGBColor[
              0.9611685196050002, 0.9705601260188983, 0.9506157468233344], 
             UndirectedEdge[96, 343] -> 
             RGBColor[
              0.7950050787830154, 0.8403635333452317, 0.9653959319733092], 
             UndirectedEdge[22, 149] -> 
             RGBColor[
              0.9630356898528151, 0.8793946941477854, 0.4019442520273168], 
             UndirectedEdge[140, 369] -> 
             RGBColor[
              0.9665523172415738, 0.9745753534810954, 0.9415023817439254], 
             UndirectedEdge[169, 370] -> 
             RGBColor[
              0.7715618192289269, 0.8214692243594333, 0.9778657295517461], 
             UndirectedEdge[154, 380] -> 
             RGBColor[
              0.8734718717694525, 0.8999683141748382, 0.8903307668735454], 
             UndirectedEdge[33, 489] -> 
             RGBColor[
              0.8263460878106794, 0.8646603076397241, 0.9832217712506242], 
             UndirectedEdge[271, 284] -> 
             RGBColor[
              0.755693608944729, 0.8092221978364671, 0.9764633093084133], 
             UndirectedEdge[112, 356] -> 
             RGBColor[
              0.8718149398375299, 0.9006255845130641, 0.9876356813117297], 
             UndirectedEdge[133, 155] -> 
             RGBColor[
              0.8952241369249928, 0.9192914428448795, 0.989868471427569], 
             UndirectedEdge[82, 447] -> 
             RGBColor[
              0.847945226046004, 0.880263212381004, 0.898510779735296], 
             UndirectedEdge[225, 260] -> 
             RGBColor[
              0.9166932182345056, 0.9313043768838054, 0.7161408432732668], 
             UndirectedEdge[133, 225] -> 
             RGBColor[
              0.9242747037625783, 0.9373496476499483, 0.7168639721310064], 
             UndirectedEdge[442, 444] -> 
             RGBColor[
              0.9701626901538352, 0.9735313415209634, 0.7025878934682861], 
             UndirectedEdge[49, 431] -> 
             RGBColor[
              0.88729584599614, 0.9129696388659365, 0.9891122639611061], 
             UndirectedEdge[220, 427] -> 
             RGBColor[
              0.9852765713065683, 0.9725366399564033, 0.6278506644050632], 
             UndirectedEdge[151, 192] -> 
             RGBColor[
              0.8287461461701697, 0.8667757331512, 0.9833971701943602], 
             UndirectedEdge[167, 326] -> 
             RGBColor[
              0.8572941919516184, 0.8882223345843505, 0.9291720525912905], 
             UndirectedEdge[109, 196] -> 
             RGBColor[
              0.9932413348199902, 0.9879522235228578, 0.5057391886816042], 
             UndirectedEdge[212, 451] -> 
             RGBColor[
              0.9881240054648279, 0.9893569853076376, 0.8464794937438476], 
             UndirectedEdge[186, 414] -> 
             RGBColor[
              0.9580848565422639, 0.9682603351557446, 0.9558355840404124], 
             UndirectedEdge[349, 419] -> 
             RGBColor[
              0.7778943456653302, 0.8264162421405351, 0.9784968966061027], 
             UndirectedEdge[162, 221] -> 
             RGBColor[
              0.8977751861088834, 0.9206338551286255, 0.9661292497035479], 
             UndirectedEdge[163, 364] -> 
             RGBColor[
              0.6704208469870805, 0.7344815103541901, 0.8891694995071919], 
             UndirectedEdge[191, 300] -> 
             RGBColor[
              0.8476870049889953, 0.8813866242001868, 0.9853343373466148], 
             UndirectedEdge[438, 460] -> 
             RGBColor[
              0.7653968222744274, 0.8166530818828661, 0.9772512602704938], 
             UndirectedEdge[172, 473] -> 
             RGBColor[
              0.7890492717768298, 0.8351809070712604, 0.9795953535535766], 
             UndirectedEdge[141, 188] -> 
             RGBColor[
              0.8748643568229489, 0.9001969855066543, 0.8511332818609727], 
             UndirectedEdge[79, 122] -> 
             RGBColor[
              0.8582109510432978, 0.8893705329067663, 0.949557917983993], 
             UndirectedEdge[326, 475] -> 
             RGBColor[
              0.7641024672422035, 0.8156419218942302, 0.9771222510573172], 
             UndirectedEdge[98, 124] -> 
             RGBColor[
              0.8783246811249005, 0.905593113183178, 0.9773575970528298], 
             UndirectedEdge[204, 498] -> 
             RGBColor[
              0.7812835905907707, 0.8292427957988049, 0.9787872436379226], 
             UndirectedEdge[72, 144] -> 
             RGBColor[
              0.9092844817308343, 0.9294834152178588, 0.9558675380733553], 
             UndirectedEdge[98, 331] -> 
             RGBColor[
              0.8930680572049314, 0.9172585781118318, 0.9787878501275924], 
             UndirectedEdge[311, 377] -> 
             RGBColor[
              0.9248255281129703, 0.942574249788171, 0.9815785942983533], 
             UndirectedEdge[299, 389] -> 
             RGBColor[
              0.9922697930628392, 0.9905833296094915, 0.7422973149214628], 
             UndirectedEdge[131, 238] -> 
             RGBColor[
              0.9937400373594987, 0.990043377512521, 0.6344887405569168], 
             UndirectedEdge[4, 185] -> 
             RGBColor[
              0.8284172307495644, 0.8636468741662149, 0.8252576156161284], 
             UndirectedEdge[162, 258] -> 
             RGBColor[
              0.7501715512524573, 0.803617944205272, 0.9525403655657194], 
             UndirectedEdge[124, 253] -> 
             RGBColor[
              0.8724464328307727, 0.9012091252301658, 0.9873079381220927], 
             UndirectedEdge[319, 449] -> 
             RGBColor[
              0.8380398912631053, 0.8736942775790881, 0.9844141870273595], 
             UndirectedEdge[256, 271] -> 
             RGBColor[
              0.946428873227682, 0.9578157890729806, 0.9056102309447203], 
             UndirectedEdge[379, 478] -> 
             RGBColor[
              0.8995785893948609, 0.9226031795958131, 0.9847231387546465], 
             UndirectedEdge[349, 371] -> 
             RGBColor[
              0.8118338668836804, 0.8534400527431214, 0.9817443329304637], 
             UndirectedEdge[130, 325] -> 
             RGBColor[
              0.9822689217248939, 0.959584773234557, 0.5967690686855889], 
             UndirectedEdge[269, 369] -> 
             RGBColor[
              0.9193054529978422, 0.9378017152251008, 0.9681900963055424], 
             UndirectedEdge[43, 355] -> 
             RGBColor[
              0.739053776101721, 0.7940009471784497, 0.9358113872159458], 
             UndirectedEdge[11, 414] -> 
             RGBColor[
              0.8774754886378923, 0.9050320539420247, 0.9824532084782007], 
             UndirectedEdge[117, 255] -> 
             RGBColor[
              0.8282991347198552, 0.8661876847339189, 0.9834159969766191], 
             UndirectedEdge[401, 475] -> 
             RGBColor[
              0.8937976232739294, 0.9163073625895566, 0.9132339030774922], 
             UndirectedEdge[58, 141] -> 
             RGBColor[
              0.9905378017330463, 0.9903412984532902, 0.8054696292760695], 
             UndirectedEdge[96, 180] -> 
             RGBColor[
              0.8148664545736483, 0.8539259739795341, 0.8757919392838855], 
             UndirectedEdge[119, 375] -> 
             RGBColor[
              0.810347468540323, 0.8123180596072976, 0.6424859971017995], 
             UndirectedEdge[220, 382] -> 
             RGBColor[
              0.949177067155305, 0.9605224974067694, 0.9282516352199243], 
             UndirectedEdge[104, 356] -> 
             RGBColor[
              0.9347659362092737, 0.9138283274508304, 0.6600465450040788], 
             UndirectedEdge[225, 440] -> 
             RGBColor[
              0.9435782287837493, 0.9527417545216019, 0.7187051595799858], 
             UndirectedEdge[259, 341] -> 
             RGBColor[
              0.9432761884932319, 0.9560458759653139, 0.9376144947510644], 
             UndirectedEdge[290, 362] -> 
             RGBColor[
              0.8560861475495848, 0.8861936388002718, 0.8798548479221923], 
             UndirectedEdge[79, 267] -> 
             RGBColor[
              0.6335768760897114, 0.7023879803349812, 0.9321367724856009], 
             UndirectedEdge[90, 317] -> 
             RGBColor[
              0.9174514556934164, 0.9369620266867487, 0.990155261099302], 
             UndirectedEdge[41, 389] -> 
             RGBColor[
              0.9747340094113559, 0.9784407366413825, 0.8138773690957802], 
             UndirectedEdge[5, 300] -> 
             RGBColor[
              0.745103205800784, 0.8009347965533617, 0.9752723694626868], 
             UndirectedEdge[290, 340] -> 
             RGBColor[
              0.8531325839399007, 0.8849722643445448, 0.92880304051226], 
             UndirectedEdge[288, 392] -> 
             RGBColor[
              0.894128977767788, 0.9155541746846241, 0.8673765322296101], 
             UndirectedEdge[45, 292] -> 
             RGBColor[
              0.6236364081599224, 0.6996469798302569, 0.9666103240403379], 
             UndirectedEdge[42, 145] -> 
             RGBColor[
              0.8876977398511274, 0.9129677635162781, 0.9779750540092801], 
             UndirectedEdge[100, 368] -> 
             RGBColor[
              0.6382976189839279, 0.7131911888929685, 0.9671553370064192], 
             UndirectedEdge[302, 315] -> 
             RGBColor[
              0.8183156844805555, 0.8586247666866238, 0.9668782694087141], 
             UndirectedEdge[255, 338] -> 
             RGBColor[
              0.9302278169456392, 0.9445260500847272, 0.8879350371153691], 
             UndirectedEdge[59, 263] -> 
             RGBColor[
              0.994761503757646, 0.9912037111678476, 0.6712001961502345], 
             UndirectedEdge[413, 486] -> 
             RGBColor[
              0.976003255839029, 0.9816238480125858, 0.9255044078979946], 
             UndirectedEdge[140, 247] -> 
             RGBColor[
              0.8495628219352582, 0.8827217595328412, 0.9541229471252741], 
             UndirectedEdge[82, 453] -> 
             RGBColor[
              0.8505863658445283, 0.8808220540325211, 0.8159722500350736], 
             UndirectedEdge[199, 349] -> 
             RGBColor[
              0.8143296300266007, 0.8554301065276002, 0.9819823810470295], 
             UndirectedEdge[265, 462] -> 
             RGBColor[
              0.9951198500283167, 0.9921223217536956, 0.7212632496456544], 
             UndirectedEdge[113, 386] -> 
             RGBColor[
              0.7871669774446226, 0.8342273611075492, 0.9792705702538819], 
             UndirectedEdge[140, 219] -> 
             RGBColor[
              0.9715569541644181, 0.9783078035038119, 0.9330308368519079], 
             UndirectedEdge[13, 313] -> 
             RGBColor[
              0.8942893160489422, 0.9180566369060799, 0.9728113236957732], 
             UndirectedEdge[74, 463] -> 
             RGBColor[
              0.8420030576784456, 0.8770878964851989, 0.9671320952677291], 
             UndirectedEdge[146, 415] -> 
             RGBColor[
              0.988526832290749, 0.9880323895540266, 0.7353835034963392], 
             UndirectedEdge[213, 475] -> 
             RGBColor[
              0.7709530118238981, 0.8209936193875171, 0.9778050493192416], 
             UndirectedEdge[49, 328] -> 
             RGBColor[
              0.9087060703923068, 0.9299188667379691, 0.9869001691606689], 
             UndirectedEdge[259, 450] -> 
             RGBColor[
              0.9896910285063034, 0.9885301361431931, 0.7133035892237071], 
             UndirectedEdge[454, 500] -> 
             RGBColor[
              0.9920709012287442, 0.9909891281366114, 0.7810692166969435], 
             UndirectedEdge[469, 495] -> 
             RGBColor[
              0.6259265677757209, 0.702443637840581, 0.9663819654613095], 
             UndirectedEdge[158, 182] -> 
             RGBColor[
              0.9800106469667158, 0.9824856097716567, 0.813638950383576], 
             UndirectedEdge[302, 347] -> 
             RGBColor[
              0.6811835444366475, 0.7508650291913755, 0.9688576677534491], 
             UndirectedEdge[87, 107] -> 
             RGBColor[
              0.9854375744074255, 0.9622814364630065, 0.4198856584747731], 
             UndirectedEdge[80, 307] -> 
             RGBColor[
              0.8187806123347311, 0.8575709505858726, 0.8997463968578605], 
             UndirectedEdge[159, 443] -> 
             RGBColor[
              0.9294715379949904, 0.9465530278866674, 0.9915275865165846], 
             UndirectedEdge[396, 443] -> 
             RGBColor[
              0.8993146564985199, 0.9225067491681234, 0.9886511962380853], 
             UndirectedEdge[15, 452] -> 
             RGBColor[
              0.9069113927767859, 0.9222338381920074, 0.7024298515882226], 
             UndirectedEdge[55, 250] -> 
             RGBColor[
              0.7184692423676775, 0.7430656808249352, 0.642743577696659], 
             UndirectedEdge[105, 447] -> 
             RGBColor[
              0.954981120253826, 0.9646935525088297, 0.9089633493198248], 
             UndirectedEdge[55, 242] -> 
             RGBColor[
              0.9819256775983289, 0.9492696434056477, 0.5053347459771717], 
             UndirectedEdge[133, 440] -> 
             RGBColor[
              0.8751456052195117, 0.9032813666801529, 0.9879533631491833], 
             UndirectedEdge[177, 455] -> 
             RGBColor[
              0.8746161114295372, 0.899666013711606, 0.8241133027810903], 
             UndirectedEdge[186, 456] -> 
             RGBColor[
              0.9059770593239658, 0.9268756017165853, 0.9565726151779121], 
             UndirectedEdge[94, 302] -> 
             RGBColor[
              0.8373756865487441, 0.8717083395339729, 0.883950695160092], 
             UndirectedEdge[146, 376] -> 
             RGBColor[
              0.9837352966472832, 0.9844588701165493, 0.7434943235080839], 
             UndirectedEdge[44, 106] -> 
             RGBColor[
              0.8385124448660786, 0.874408799239778, 0.9692036099706414], 
             UndirectedEdge[46, 205] -> 
             RGBColor[
              0.8272165258600239, 0.8650699440717562, 0.9420390267358563], 
             UndirectedEdge[134, 457] -> 
             RGBColor[
              0.6709603147833301, 0.7407903539521403, 0.969380211383323], 
             UndirectedEdge[229, 248] -> 
             RGBColor[
              0.8042047026417867, 0.8436168645174786, 0.7679512216176145], 
             UndirectedEdge[101, 362] -> 
             RGBColor[
              0.9929758217569006, 0.9904599773083793, 0.7004076989346302], 
             UndirectedEdge[286, 346] -> 
             RGBColor[
              0.852430887071785, 0.8848388969734221, 0.9481614687058302], 
             UndirectedEdge[134, 138] -> 
             RGBColor[
              0.9175157248331292, 0.9358877082967334, 0.9511373509602287], 
             UndirectedEdge[144, 494] -> 
             RGBColor[
              0.9183136114087744, 0.9347063041358961, 0.8729169596353905], 
             UndirectedEdge[35, 147] -> 
             RGBColor[
              0.9503624380335447, 0.9625009680762415, 0.9689076242463539], 
             UndirectedEdge[5, 211] -> 
             RGBColor[
              0.6419345478373377, 0.7200129547265091, 0.9650759131297042], 
             UndirectedEdge[243, 471] -> 
             RGBColor[
              0.7935368472964579, 0.8391384844754084, 0.9643933000769367], 
             UndirectedEdge[154, 338] -> 
             RGBColor[
              0.9911446839038328, 0.9906061134700611, 0.7964190347443252], 
             UndirectedEdge[185, 383] -> 
             RGBColor[
              0.8210890307153997, 0.860307333844506, 0.9426550948795425], 
             UndirectedEdge[416, 429] -> 
             RGBColor[
              0.5507772298725824, 0.6232680543091513, 0.9629916124106961], 
             UndirectedEdge[159, 396] -> 
             RGBColor[
              0.8912892921689859, 0.9161539044449551, 0.9894931624220636], 
             UndirectedEdge[73, 322] -> 
             RGBColor[
              0.8738409503128144, 0.881010281595721, 0.6766925064914291], 
             UndirectedEdge[287, 300] -> 
             RGBColor[
              0.7242448840520709, 0.7840010713010699, 0.9736303259680781], 
             UndirectedEdge[392, 459] -> 
             RGBColor[
              0.8932808446344098, 0.9152034498379449, 0.8814322931478775], 
             UndirectedEdge[200, 450] -> 
             RGBColor[
              0.9873656242025302, 0.9870646058829138, 0.7292751764881006], 
             UndirectedEdge[104, 148] -> 
             RGBColor[
              0.9810742254393321, 0.9475633824833332, 0.5368916426422441], 
             UndirectedEdge[94, 325] -> 
             RGBColor[
              0.9899493840471694, 0.9901118262615256, 0.8162282467061073], 
             UndirectedEdge[355, 378] -> 
             RGBColor[
              0.7175767820077055, 0.7779834401484833, 0.9721663361199392], 
             UndirectedEdge[424, 453] -> 
             RGBColor[
              0.7705120679683728, 0.8167968272856669, 0.8089966336528116], 
             UndirectedEdge[212, 301] -> 
             RGBColor[
              0.9458338646000701, 0.9577692974227243, 0.9241366352638878], 
             UndirectedEdge[46, 420] -> 
             RGBColor[
              0.9073265405266362, 0.92775822858379, 0.9499955862533714], 
             UndirectedEdge[146, 284] -> 
             RGBColor[
              0.8009669542233344, 0.8408942505101147, 0.7599868663165199], 
             UndirectedEdge[76, 343] -> 
             RGBColor[
              0.8055378071348989, 0.8486583081720898, 0.9664002507638791], 
             UndirectedEdge[111, 256] -> 
             RGBColor[
              0.9903532972703557, 0.9902788547594095, 0.8095343593039963], 
             UndirectedEdge[277, 319] -> 
             RGBColor[
              0.8333915675071715, 0.8699878303914936, 0.9839708257579108], 
             UndirectedEdge[240, 429] -> 
             RGBColor[
              0.9110999613115129, 0.9319503942729177, 0.991382721730071], 
             UndirectedEdge[49, 71] -> 
             RGBColor[
              0.8420403260061917, 0.8769880434690339, 0.9847681728178469], 
             UndirectedEdge[19, 139] -> 
             RGBColor[
              0.981522590180355, 0.9832786400628616, 0.7845325707918485], 
             UndirectedEdge[9, 247] -> 
             RGBColor[
              0.8038480972359106, 0.8471698077607184, 0.9809567985243915], 
             UndirectedEdge[333, 392] -> 
             RGBColor[
              0.8252983814545498, 0.6354805844531349, 0.5907134563867833], 
             UndirectedEdge[169, 337] -> 
             RGBColor[
              0.7661019828557705, 0.8172039586884303, 0.9773215440871418], 
             UndirectedEdge[21, 119] -> 
             RGBColor[
              0.9480702743285405, 0.9208063370987521, 0.6559745712938048], 
             UndirectedEdge[354, 479] -> 
             RGBColor[
              0.9446931886864742, 0.9580722620053257, 0.9715496314615303], 
             UndirectedEdge[179, 236] -> 
             RGBColor[
              0.98329749105791, 0.9840670761890672, 0.7390557860253798], 
             UndirectedEdge[121, 341] -> 
             RGBColor[
              0.887634241029926, 0.9132394658803891, 0.9891445403815174], 
             UndirectedEdge[263, 323] -> 
             RGBColor[
              0.8935005603800527, 0.9145232029117174, 0.8343665795898678], 
             UndirectedEdge[200, 401] -> 
             RGBColor[
              0.9846611979139064, 0.9874211095747323, 0.8813007963187378], 
             UndirectedEdge[56, 236] -> 
             RGBColor[
              0.9640126210304497, 0.9696509664087416, 0.7705390846600855], 
             UndirectedEdge[374, 437] -> 
             RGBColor[
              0.9075238405590942, 0.6298422164015787, 0.5508609917126075], 
             UndirectedEdge[74, 195] -> 
             RGBColor[
              0.8513385288757298, 0.8558380387404185, 0.6633613450659808], 
             UndirectedEdge[240, 399] -> 
             RGBColor[
              0.7476868864603028, 0.8027480249101011, 0.9758030133694384], 
             UndirectedEdge[138, 352] -> 
             RGBColor[
              0.9246512884013828, 0.9415774129963457, 0.9518179473833615], 
             UndirectedEdge[195, 342] -> 
             RGBColor[
              0.8558579853705977, 0.8593686725033508, 0.6638118022526671], 
             UndirectedEdge[13, 363] -> 
             RGBColor[
              0.9386525164969328, 0.9534306487363111, 0.977042725357999], 
             UndirectedEdge[368, 386] -> 
             RGBColor[
              0.5498145517787858, 0.6437349570113247, 0.9584244302279418], 
             UndirectedEdge[132, 233] -> 
             RGBColor[
              0.8155603495429271, 0.8317371089162857, 0.6654163834689264], 
             UndirectedEdge[304, 310] -> 
             RGBColor[
              0.9722761316021082, 0.9781127238241323, 0.8990580330651469], 
             UndirectedEdge[213, 259] -> 
             RGBColor[
              0.8641419907676482, 0.8935728966329721, 0.9299003552960936], 
             UndirectedEdge[226, 446] -> 
             RGBColor[
              0.9602063204625371, 0.9688112343714479, 0.9073447990360325], 
             UndirectedEdge[60, 249] -> 
             RGBColor[
              0.8395706069108022, 0.8719094158936346, 0.7902816783849527], 
             UndirectedEdge[181, 387] -> 
             RGBColor[
              0.9663000314803405, 0.9732969662114515, 0.8931065762163428], 
             UndirectedEdge[94, 168] -> 
             RGBColor[
              0.7438336530031981, 0.7964007543664664, 0.8761532190234758], 
             UndirectedEdge[142, 402] -> 
             RGBColor[
              0.9920213036103324, 0.9898612589716715, 0.701397848165683], 
             UndirectedEdge[188, 310] -> 
             RGBColor[
              0.8715287139324392, 0.8988314650923067, 0.9074205305227014], 
             UndirectedEdge[74, 239] -> 
             RGBColor[
              0.8443991052389408, 0.8324297333593745, 0.6364029946372494], 
             UndirectedEdge[376, 400] -> 
             RGBColor[
              0.9649723278135717, 0.9733969999526866, 0.9441768917182923], 
             UndirectedEdge[292, 308] -> 
             RGBColor[
              0.9292718311207488, 0.9454827143928515, 0.9599210774807126], 
             UndirectedEdge[7, 142] -> 
             RGBColor[
              0.9318708568769246, 0.9442726062694332, 0.7877886440186574], 
             UndirectedEdge[20, 194] -> 
             RGBColor[
              0.9063814650367724, 0.9266924767949153, 0.9369375876654451], 
             UndirectedEdge[168, 500] -> 
             RGBColor[
              0.7446315823424305, 0.7967307186540877, 0.8629294648974584], 
             UndirectedEdge[4, 383] -> 
             RGBColor[
              0.9875469846074223, 0.9881073227619875, 0.8009711380735124], 
             UndirectedEdge[91, 303] -> 
             RGBColor[
              0.9937009408437367, 0.9889352743343546, 0.5557644680068234], 
             UndirectedEdge[142, 417] -> 
             RGBColor[
              0.9706730997603619, 0.9749120705794279, 0.781074895286348], 
             UndirectedEdge[229, 338] -> 
             RGBColor[
              0.9927408200702537, 0.9900396277644354, 0.6808112152695429], 
             UndirectedEdge[69, 388] -> 
             RGBColor[
              0.6800420144864845, 0.7414997117376008, 0.8414431453509749], 
             UndirectedEdge[170, 374] -> 
             RGBColor[
              0.7547232643307386, 0.5103103517971803, 0.5749776143454868], 
             UndirectedEdge[96, 281] -> 
             RGBColor[
              0.8114416167134919, 0.8525097155100412, 0.9325503658229422], 
             UndirectedEdge[131, 265] -> 
             RGBColor[
              0.9942456297404485, 0.9902524529551753, 0.6261097663734386], 
             UndirectedEdge[117, 369] -> 
             RGBColor[
              0.8751396042412349, 0.9028454882932355, 0.9639084102278495], 
             UndirectedEdge[19, 247] -> 
             RGBColor[
              0.8485940641234294, 0.8819992615429746, 0.9557628014081969], 
             UndirectedEdge[328, 436] -> 
             RGBColor[
              0.938962841836319, 0.9539991678974762, 0.9882041671173969], 
             UndirectedEdge[86, 178] -> 
             RGBColor[
              0.8466148649636251, 0.8806895562747861, 0.9851901931271454], 
             UndirectedEdge[42, 137] -> 
             RGBColor[
              0.8968134933573473, 0.9197662775555404, 0.9625444610925384], 
             UndirectedEdge[54, 135] -> 
             RGBColor[
              0.8786564222523124, 0.9048645116971166, 0.9292081697561204], 
             UndirectedEdge[42, 174] -> 
             RGBColor[
              0.8951348408144069, 0.9185143412375567, 0.9653859819850341], 
             UndirectedEdge[1, 374] -> 
             RGBColor[
              0.8504471313651015, 0.5854558015920382, 0.5844215520612497], 
             UndirectedEdge[160, 285] -> 
             RGBColor[
              0.9493835049473184, 0.9617708813833897, 0.9705647026146953], 
             UndirectedEdge[454, 471] -> 
             RGBColor[
              0.9722698628587654, 0.9776180217358115, 0.8771242399992742], 
             UndirectedEdge[26, 425] -> 
             RGBColor[
              0.8842155087044395, 0.9056654590367816, 0.7049536074240976], 
             UndirectedEdge[333, 442] -> 
             RGBColor[
              0.9242849956201296, 0.7090015897777346, 0.3165667794169514], 
             UndirectedEdge[75, 410] -> 
             RGBColor[
              0.9141175754931239, 0.9320028291278171, 0.9004089300324414], 
             UndirectedEdge[31, 40] -> 
             RGBColor[
              0.8429706014770116, 0.8772771318364916, 0.9388308521063751], 
             UndirectedEdge[3, 258] -> 
             RGBColor[
              0.6423948909846491, 0.7189616309837878, 0.9660864682129402], 
             UndirectedEdge[132, 273] -> 
             RGBColor[
              0.9856384089028002, 0.9620445546637644, 0.4984150517961917], 
             UndirectedEdge[157, 180] -> 
             RGBColor[
              0.9147917843909852, 0.9321994683284475, 0.8856677207356276], 
             UndirectedEdge[213, 401] -> 
             RGBColor[
              0.8653189307985996, 0.8940595915817497, 0.9103954131600637], 
             UndirectedEdge[84, 391] -> 
             RGBColor[
              0.7744525429485498, 0.8243490801833588, 0.9779888962208211], 
             UndirectedEdge[43, 110] -> 
             RGBColor[
              0.9851308228312063, 0.9811536442608536, 0.6665260096585168], 
             UndirectedEdge[39, 127] -> 
             RGBColor[
              0.9682020387710626, 0.9752394901421665, 0.913353212749187], 
             UndirectedEdge[52, 469] -> 
             RGBColor[
              0.6519998204082146, 0.7250269787910657, 0.96804333006338], 
             UndirectedEdge[260, 483] -> 
             RGBColor[
              0.9170041177333599, 0.9336540774124201, 0.8724415443312101], 
             UndirectedEdge[98, 311] -> 
             RGBColor[
              0.9479958570964613, 0.9607359758882854, 0.9729136284696734], 
             UndirectedEdge[51, 127] -> 
             RGBColor[
              0.7973983706031933, 0.8423561987550906, 0.9684480094947343], 
             UndirectedEdge[243, 475] -> 
             RGBColor[
              0.7167549376872637, 0.7785268202135802, 0.9724898210250209], 
             UndirectedEdge[76, 96] -> 
             RGBColor[
              0.6485488480930836, 0.7253040289882384, 0.9656504313481025], 
             UndirectedEdge[99, 476] -> 
             RGBColor[
              0.8082009928097231, 0.8504942113758307, 0.9814108521244006], 
             UndirectedEdge[107, 308] -> 
             RGBColor[
              0.9828743309124297, 0.9832615570970284, 0.7008984779214424], 
             UndirectedEdge[190, 263] -> 
             RGBColor[
              0.9344997043737072, 0.9469892513001448, 0.8383369702086897], 
             UndirectedEdge[191, 299] -> 
             RGBColor[
              0.9124583803691461, 0.9307022779736513, 0.9012253573384543], 
             UndirectedEdge[39, 276] -> 
             RGBColor[
              0.986012899727746, 0.9884839888324115, 0.8814659791738098], 
             UndirectedEdge[51, 214] -> 
             RGBColor[
              0.817267202151533, 0.8564517211724174, 0.9024548773584433], 
             UndirectedEdge[295, 409] -> 
             RGBColor[
              0.8875090439041649, 0.9131396370906926, 0.9891325989678976], 
             UndirectedEdge[371, 382] -> 
             RGBColor[
              0.897217805051304, 0.9208811396921205, 0.9900586292732251], 
             UndirectedEdge[53, 420] -> 
             RGBColor[
              0.9127787369816613, 0.9304455261816573, 0.8790146180216337], 
             UndirectedEdge[87, 308] -> 
             RGBColor[
              0.9753905038671569, 0.958275075159589, 0.6498677203444507], 
             UndirectedEdge[286, 358] -> 
             RGBColor[
              0.8539643772468144, 0.8859825714350993, 0.9455656698377986], 
             UndirectedEdge[215, 351] -> 
             RGBColor[
              0.8632561191798497, 0.890592866844436, 0.8070714263662276], 
             UndirectedEdge[114, 258] -> 
             RGBColor[
              0.7061299694675303, 0.7691921074559648, 0.9723221832512181], 
             UndirectedEdge[87, 292] -> 
             RGBColor[
              0.9318350746157447, 0.9245025937588295, 0.6789082580340433], 
             UndirectedEdge[196, 383] -> 
             RGBColor[
              0.9870705804943438, 0.9870883425359575, 0.749117490390317], 
             UndirectedEdge[65, 495] -> 
             RGBColor[
              0.6718243150636024, 0.7385726972719464, 0.9545145198827574], 
             UndirectedEdge[14, 279] -> 
             RGBColor[
              0.9820360214069206, 0.9830096249153975, 0.7319355041832907], 
             UndirectedEdge[26, 466] -> 
             RGBColor[
              0.9752850577749024, 0.9773499595868178, 0.6937873056586261], 
             UndirectedEdge[27, 371] -> 
             RGBColor[
              0.9042605862650217, 0.9264968622607356, 0.9907303760325545], 
             UndirectedEdge[258, 472] -> 
             RGBColor[
              0.7315446064596824, 0.7894570491315633, 0.9747462540154438], 
             UndirectedEdge[26, 117] -> 
             RGBColor[
              0.8901621619871604, 0.9103110297774821, 0.7055463142486846], 
             UndirectedEdge[97, 104] -> 
             RGBColor[
              0.940450534930573, 0.9183610721668728, 0.6605887471048175], 
             UndirectedEdge[21, 428] -> 
             RGBColor[
              0.8427854452457291, 0.878007837200973, 0.9847262869743036], 
             UndirectedEdge[160, 268] -> 
             RGBColor[
              0.8240870856478877, 0.8633320134679013, 0.9775058147694429], 
             UndirectedEdge[48, 137] -> 
             RGBColor[
              0.9609069822862202, 0.9703650719147804, 0.9510584612841713], 
             UndirectedEdge[27, 291] -> 
             RGBColor[
              0.9240332522370736, 0.9422630493921299, 0.992616310564236], 
             UndirectedEdge[117, 140] -> 
             RGBColor[
              0.8791767437501091, 0.9058563803287445, 0.9570745860939447], 
             UndirectedEdge[31, 221] -> 
             RGBColor[
              0.908756144720541, 0.928774720425121, 0.9453597644407781], 
             UndirectedEdge[87, 386] -> 
             RGBColor[
              0.831060011812192, 0.845245058244345, 0.6690049297421955], 
             UndirectedEdge[207, 409] -> 
             RGBColor[
              0.9249855730307579, 0.9029804233652629, 0.6546277538727912], 
             UndirectedEdge[274, 498] -> 
             RGBColor[
              0.8532183530901747, 0.8850077320923497, 0.9273816237287724], 
             UndirectedEdge[28, 69] -> 
             RGBColor[
              0.6762528291726498, 0.7399327862327094, 0.9042397520984649], 
             UndirectedEdge[442, 492] -> 
             RGBColor[
              0.8495358006295542, 0.8785750012661284, 0.7016247097221213], 
             UndirectedEdge[476, 493] -> 
             RGBColor[
              0.928630443701397, 0.9440399714216583, 0.921984005680498], 
             UndirectedEdge[297, 359] -> 
             RGBColor[
              0.5932916976665055, 0.6806999535088891, 0.9611252422208565], 
             UndirectedEdge[112, 323] -> 
             RGBColor[
              0.8170135091004185, 0.8571539673284971, 0.9823488162618703], 
             UndirectedEdge[27, 349] -> 
             RGBColor[
              0.8330123253476412, 0.8703271806483431, 0.9837643532049893], 
             UndirectedEdge[2, 242] -> 
             RGBColor[
              0.8633970153967208, 0.8909288312598111, 0.8251785263670226], 
             UndirectedEdge[71, 462] -> 
             RGBColor[
              0.9011299446258957, 0.9206263359129481, 0.8465805805453613], 
             UndirectedEdge[165, 285] -> 
             RGBColor[
              0.9034823889235224, 0.9253244295725913, 0.9715207639515401], 
             UndirectedEdge[91, 172] -> 
             RGBColor[
              0.8730850020611887, 0.8981411015156682, 0.7976256570201211], 
             UndirectedEdge[19, 26] -> 
             RGBColor[
              0.9806061171756704, 0.9813183969754754, 0.6847801400476835], 
             UndirectedEdge[73, 163] -> 
             RGBColor[
              0.5599627059067711, 0.6489677018751253, 0.9605765848622778], 
             UndirectedEdge[67, 131] -> 
             RGBColor[
              0.9811006042445055, 0.982262066438246, 0.7295575156908132], 
             UndirectedEdge[24, 81] -> 
             RGBColor[
              0.7135285303675487, 0.7735661242100274, 0.9415190298290427], 
             UndirectedEdge[282, 467] -> 
             RGBColor[
              0.9558304574372436, 0.9654630689244175, 0.9130513892219693], 
             UndirectedEdge[122, 406] -> 
             RGBColor[
              0.8649105708774135, 0.8933948313248403, 0.8946771026395733], 
             UndirectedEdge[139, 255] -> 
             RGBColor[
              0.9316137389619299, 0.9443324424579025, 0.8092341273916], 
             UndirectedEdge[409, 458] -> 
             RGBColor[
              0.8456998515352656, 0.8799077760300178, 0.9851167635388804], 
             UndirectedEdge[4, 196] -> 
             RGBColor[
              0.9943987805285085, 0.9904278828576663, 0.631720011126903], 
             UndirectedEdge[46, 90] -> 
             RGBColor[
              0.9393705384631164, 0.9533092427271868, 0.9530519713825676], 
             UndirectedEdge[115, 124] -> 
             RGBColor[
              0.7443476612817497, 0.8002093173358376, 0.9751532766183368], 
             UndirectedEdge[330, 350] -> 
             RGBColor[
              0.9308051605947987, 0.9463560071786621, 0.9474628192582535], 
             UndirectedEdge[213, 315] -> 
             RGBColor[
              0.8476780283956502, 0.8815628529151747, 0.9698048334434661], 
             UndirectedEdge[107, 143] -> 
             RGBColor[
              0.9764270334272978, 0.9784531731890979, 0.7118120708392768], 
             UndirectedEdge[403, 491] -> 
             RGBColor[
              0.9769129995856359, 0.9812123080862567, 0.8751508880188533], 
             UndirectedEdge[200, 254] -> 
             RGBColor[
              0.985389093232402, 0.9810572990358211, 0.6654754117573224], 
             UndirectedEdge[37, 304] -> 
             RGBColor[
              0.9523452165452811, 0.9639797210437927, 0.9655512974174427], 
             UndirectedEdge[25, 392] -> 
             RGBColor[
              0.8798413786178416, 0.906472904709378, 0.9620664733591127], 
             UndirectedEdge[231, 492] -> 
             RGBColor[
              0.8421024862240011, 0.8767678697200556, 0.947010440763074], 
             UndirectedEdge[22, 63] -> 
             RGBColor[
              0.654971273127478, 0.7185386798771798, 0.7403531712371794], 
             UndirectedEdge[201, 256] -> 
             RGBColor[
              0.9277274627168051, 0.9429037919678724, 0.9038264737152466], 
             UndirectedEdge[57, 92] -> 
             RGBColor[
              0.8485367820579279, 0.8799358555350589, 0.8627711430995775], 
             UndirectedEdge[433, 462] -> 
             RGBColor[
              0.9666056334305901, 0.9726696176777969, 0.8507270305713229], 
             UndirectedEdge[286, 294] -> 
             RGBColor[
              0.7492740200446955, 0.8040578262431641, 0.9756442900203872], 
             UndirectedEdge[319, 331] -> 
             RGBColor[
              0.8321887791081226, 0.8690287595709135, 0.9838561027266677], 
             UndirectedEdge[222, 307] -> 
             RGBColor[
              0.991702026253539, 0.9901787823682044, 0.7393668422432864], 
             UndirectedEdge[276, 283] -> 
             RGBColor[
              0.9872784468065956, 0.9890073250725921, 0.8604925889464186], 
             UndirectedEdge[464, 497] -> 
             RGBColor[
              0.9476866660542538, 0.9605053817152607, 0.9734370082541919], 
             UndirectedEdge[143, 283] -> 
             RGBColor[
              0.9750319710761952, 0.9799127357732644, 0.8829607697577955], 
             UndirectedEdge[265, 433] -> 
             RGBColor[
              0.9665914225447922, 0.9727913661772655, 0.8602395367414002], 
             UndirectedEdge[74, 234] -> 
             RGBColor[
              0.7689140244696535, 0.8194007469695035, 0.9776018221151906], 
             UndirectedEdge[17, 432] -> 
             RGBColor[
              0.8839292443316589, 0.909124954499058, 0.9361396837651597], 
             UndirectedEdge[103, 118] -> 
             RGBColor[
              0.8069449875577928, 0.4875667835073578, 0.5722882042433395], 
             UndirectedEdge[426, 489] -> 
             RGBColor[
              0.9291450053672448, 0.9440392899387566, 0.9041869584475597], 
             UndirectedEdge[277, 331] -> 
             RGBColor[
              0.8394763207431464, 0.8748396474556335, 0.9845511949534814], 
             UndirectedEdge[74, 112] -> 
             RGBColor[
              0.7853612683799718, 0.8324269963117449, 0.979194016713863], 
             UndirectedEdge[80, 372] -> 
             RGBColor[
              0.8186849750932075, 0.8494961753170784, 0.6880968354856307], 
             UndirectedEdge[180, 281] -> 
             RGBColor[
              0.98829195154594, 0.989426435328195, 0.8436961925492951], 
             UndirectedEdge[263, 296] -> 
             RGBColor[
              0.8274220513357595, 0.8629021694310464, 0.8277804913471083], 
             UndirectedEdge[37, 141] -> 
             RGBColor[
              0.9719993833320277, 0.9767841288256593, 0.8488856203757893], 
             UndirectedEdge[18, 210] -> 
             RGBColor[
              0.7566504632040296, 0.809931754359553, 0.9763499442207608], 
             UndirectedEdge[279, 494] -> 
             RGBColor[
              0.9819509071993509, 0.9845485754468011, 0.847769968473496], 
             UndirectedEdge[101, 337] -> 
             RGBColor[
              0.8535521863819955, 0.8828478069465757, 0.79294673070021], 
             UndirectedEdge[217, 378] -> 
             RGBColor[
              0.8647092225962586, 0.8951406391226541, 0.9853158823218556], 
             UndirectedEdge[20, 62] -> 
             RGBColor[
              0.8394674712922078, 0.874832591143667, 0.9845503508849509], 
             UndirectedEdge[18, 56] -> 
             RGBColor[
              0.8069677098322257, 0.850053360995602, 0.9811492481228945], 
             UndirectedEdge[444, 492] -> 
             RGBColor[
              0.8271358498189532, 0.8656057767947888, 0.9723450522728747], 
             UndirectedEdge[199, 427] -> 
             RGBColor[
              0.9358130723454876, 0.934885336026233, 0.6898957065749298], 
             UndirectedEdge[190, 463] -> 
             RGBColor[
              0.9146544423925469, 0.9342809158903785, 0.9742572854345583], 
             UndirectedEdge[139, 369] -> 
             RGBColor[
              0.9784542084833097, 0.9809902460172191, 0.7897265406428304], 
             UndirectedEdge[10, 455] -> 
             RGBColor[
              0.987563079167437, 0.9880456769093883, 0.7951001492102657], 
             UndirectedEdge[52, 236] -> 
             RGBColor[
              0.7177753694099327, 0.7729840696871513, 0.7484265668560228], 
             UndirectedEdge[9, 19] -> 
             RGBColor[
              0.9239059742392715, 0.9413117957546151, 0.963142263292061], 
             UndirectedEdge[33, 309] -> 
             RGBColor[
              0.8783912061868574, 0.9052049685335695, 0.9550857020005695], 
             UndirectedEdge[341, 491] -> 
             RGBColor[
              0.9457478719942378, 0.9570679806123484, 0.8966523026275395], 
             UndirectedEdge[87, 143] -> 
             RGBColor[
              0.9689432063820249, 0.9534666912516583, 0.6607813132622851], 
             UndirectedEdge[110, 378] -> 
             RGBColor[
              0.963653828737191, 0.9651361372308872, 0.7028809585625102], 
             UndirectedEdge[401, 471] -> 
             RGBColor[
              0.9705795328831237, 0.9769190268513848, 0.905137382129408], 
             UndirectedEdge[160, 165] -> 
             RGBColor[
              0.8957640949773074, 0.9195681385850505, 0.9845858223490205], 
             UndirectedEdge[13, 379] -> 
             RGBColor[
              0.9482980690093992, 0.9609613650381278, 0.9724020625305603], 
             UndirectedEdge[210, 434] -> 
             RGBColor[
              0.9135588864248779, 0.9309025942818342, 0.8719240776608814], 
             UndirectedEdge[308, 446] -> 
             RGBColor[
              0.9518021986001031, 0.9634478178503554, 0.96207004404399], 
             UndirectedEdge[153, 395] -> 
             RGBColor[
              0.9677407792764399, 0.973292752587935, 0.831075326010577], 
             UndirectedEdge[24, 83] -> 
             RGBColor[
              0.9807783016259835, 0.984245582305889, 0.8753493519470843], 
             UndirectedEdge[133, 260] -> 
             RGBColor[
              0.8482605946702679, 0.8818439890423564, 0.9853890468424642], 
             UndirectedEdge[83, 119] -> 
             RGBColor[
              0.9774396733704542, 0.9418888859827785, 0.5682922144830659], 
             UndirectedEdge[400, 464] -> 
             RGBColor[
              0.9557680005649904, 0.9665324277613974, 0.9597574168771204], 
             UndirectedEdge[175, 320] -> 
             RGBColor[
              0.9785366978746279, 0.9826622017826152, 0.8831027089483368], 
             UndirectedEdge[39, 475] -> 
             RGBColor[
              0.8935159434460109, 0.916190880741871, 0.9179020667901274], 
             UndirectedEdge[289, 291] -> 
             RGBColor[
              0.9106001239810566, 0.9315518375533347, 0.9913350467992821], 
             UndirectedEdge[263, 342] -> 
             RGBColor[
              0.8663677761544737, 0.8933268656578974, 0.8316622372285468], 
             UndirectedEdge[311, 319] -> 
             RGBColor[
              0.8871165789996525, 0.9125061573473672, 0.9779818810687488], 
             UndirectedEdge[141, 304] -> 
             RGBColor[
              0.9756117744926178, 0.9794782442384798, 0.842770784403418], 
             UndirectedEdge[30, 43] -> 
             RGBColor[
              0.9867128595561585, 0.9861814167600575, 0.6989307994952], 
             UndirectedEdge[85, 95] -> 
             RGBColor[
              0.9886301434218963, 0.971637765204371, 0.5524357821104237], 
             UndirectedEdge[305, 438] -> 
             RGBColor[
              0.8022644264949003, 0.8454543345040695, 0.9809258785118408], 
             UndirectedEdge[23, 212] -> 
             RGBColor[
              0.97024327766263, 0.9767857716293374, 0.9109695111683602], 
             UndirectedEdge[80, 461] -> 
             RGBColor[
              0.7304708064557374, 0.789368612877754, 0.9737701614158614], 
             UndirectedEdge[115, 439] -> 
             RGBColor[
              0.8019221249156925, 0.8460271288610806, 0.9806687970597548], 
             UndirectedEdge[136, 377] -> 
             RGBColor[
              0.8869512315511088, 0.9126948526617786, 0.9890793943276981], 
             UndirectedEdge[27, 488] -> 
             RGBColor[
              0.9509385339041707, 0.9626660434372576, 0.9587594283363268], 
             UndirectedEdge[70, 170] -> 
             RGBColor[
              0.7851713871618504, 0.8327205309092532, 0.9790578320855905], 
             UndirectedEdge[268, 441] -> 
             RGBColor[
              0.8306927226351568, 0.8147283832640206, 0.6269663165171628], 
             UndirectedEdge[394, 445] -> 
             RGBColor[
              0.9636956310277582, 0.9715071888327903, 0.9043480005937983], 
             UndirectedEdge[234, 393] -> 
             RGBColor[
              0.8537772010805866, 0.8863311177529564, 0.985891783894735], 
             UndirectedEdge[228, 388] -> 
             RGBColor[
              0.9824920773451583, 0.9518287070906442, 0.5388233224574468], 
             UndirectedEdge[8, 114] -> 
             RGBColor[
              0.8144514592813005, 0.8554150858984979, 0.9820237660989686], 
             UndirectedEdge[21, 164] -> 
             RGBColor[
              0.9444881071082357, 0.9580015154877481, 0.9747468102658616], 
             UndirectedEdge[100, 454] -> 
             RGBColor[
              0.926338306436215, 0.9414394751395269, 0.8882073774008056], 
             UndirectedEdge[6, 267] -> 
             RGBColor[
              0.6279908478720134, 0.6982219296365038, 0.9415924611886706], 
             UndirectedEdge[210, 495] -> 
             RGBColor[
              0.6117727277789944, 0.6911577500229431, 0.9650319595671395], 
             UndirectedEdge[112, 342] -> 
             RGBColor[
              0.7898807248748395, 0.8359576300746772, 0.9796444739005492], 
             UndirectedEdge[93, 206] -> 
             RGBColor[
              0.759632134192327, 0.8125498884070053, 0.9765704827156682], 
             UndirectedEdge[485, 497] -> 
             RGBColor[
              0.810619804322105, 0.8528402239482736, 0.977629118511027], 
             UndirectedEdge[36, 240] -> 
             RGBColor[
              0.7722769540484301, 0.8226711770319686, 0.9777662997350178], 
             UndirectedEdge[275, 285] -> 
             RGBColor[
              0.9656586427575553, 0.973908852514172, 0.9430151395377335], 
             UndirectedEdge[36, 399] -> 
             RGBColor[
              0.6203913776308718, 0.7026605220145365, 0.9632860944657065], 
             UndirectedEdge[72, 279] -> 
             RGBColor[
              0.9729217775214108, 0.9793256865287638, 0.9307205469114608], 
             UndirectedEdge[278, 413] -> 
             RGBColor[
              0.8683093952282399, 0.8973684520173177, 0.9560788482182436], 
             UndirectedEdge[10, 120] -> 
             RGBColor[
              0.9690119417528542, 0.9764097374143429, 0.9373388790191409], 
             UndirectedEdge[59, 153] -> 
             RGBColor[
              0.9947064284422014, 0.9910859106370797, 0.6652055879495224], 
             UndirectedEdge[377, 488] -> 
             RGBColor[
              0.9389799735890711, 0.9531306120484697, 0.9576188101779397], 
             UndirectedEdge[53, 306] -> 
             RGBColor[
              0.9169725225611243, 0.9337895369654441, 0.8794146250340396], 
             UndirectedEdge[172, 448] -> 
             RGBColor[
              0.8098949280165739, 0.8518026675165675, 0.9815836308548604], 
             UndirectedEdge[138, 367] -> 
             RGBColor[
              0.7584762563477121, 0.8097367849973789, 0.9364765703067768], 
             UndirectedEdge[71, 431] -> 
             RGBColor[
              0.852381348327625, 0.8852336939685717, 0.9857545087584048], 
             UndirectedEdge[180, 392] -> 
             RGBColor[
              0.8931531010196866, 0.9151506245703956, 0.8835493354337176], 
             UndirectedEdge[33, 227] -> 
             RGBColor[
              0.87138643264695, 0.8999808198967706, 0.9669429564660972], 
             UndirectedEdge[30, 384] -> 
             RGBColor[
              0.9872403889299504, 0.9865748473032814, 0.6980378298670666], 
             UndirectedEdge[441, 467] -> 
             RGBColor[
              0.9388183570058546, 0.9000276526175146, 0.6375228264912494], 
             UndirectedEdge[99, 122] -> 
             RGBColor[
              0.7432177860852431, 0.7993266502449572, 0.9750406612180331], 
             UndirectedEdge[89, 225] -> 
             RGBColor[
              0.9813796798287956, 0.9819977353778808, 0.6915970227657988], 
             UndirectedEdge[146, 497] -> 
             RGBColor[
              0.9668741779678367, 0.9718838754129661, 0.7720357993483298], 
             UndirectedEdge[176, 197] -> 
             RGBColor[
              0.7240170626958831, 0.7824791063956844, 0.9530174631424804], 
             UndirectedEdge[326, 474] -> 
             RGBColor[
              0.6327656079187213, 0.7114228963370804, 0.9651378320996244], 
             UndirectedEdge[173, 241] -> 
             RGBColor[
              0.8688301981650348, 0.8962808430717617, 0.8870857869188805], 
             UndirectedEdge[403, 405] -> 
             RGBColor[
              0.9711999759725701, 0.9780415697528297, 0.9336351078158828], 
             UndirectedEdge[79, 476] -> 
             RGBColor[
              0.9231941577677778, 0.9405380940376399, 0.9559281088903604], 
             UndirectedEdge[46, 257] -> 
             RGBColor[
              0.9784303719791869, 0.9570205576009152, 0.6372462281218065], 
             UndirectedEdge[450, 491] -> 
             RGBColor[
              0.9921627120073093, 0.9895522407902277, 0.6723413971001821], 
             UndirectedEdge[200, 243] -> 
             RGBColor[
              0.8076185123272406, 0.8496405671987558, 0.9405567142662665], 
             UndirectedEdge[296, 424] -> 
             RGBColor[
              0.6031405290399239, 0.6884266557557721, 0.9620845106253229], 
             UndirectedEdge[269, 466] -> 
             RGBColor[
              0.9170527752941195, 0.9361216718820857, 0.9720032920655031], 
             UndirectedEdge[74, 453] -> 
             RGBColor[
              0.8617185007897818, 0.8895185624591124, 0.8170817972107007], 
             UndirectedEdge[18, 469] -> 
             RGBColor[
              0.7708043032007562, 0.821217642177191, 0.9776999501149307], 
             UndirectedEdge[279, 481] -> 
             RGBColor[
              0.9823546004621191, 0.9847155129853995, 0.8410797263847524], 
             UndirectedEdge[19, 468] -> 
             RGBColor[
              0.9084756589226077, 0.929008081165859, 0.9616705060423525], 
             UndirectedEdge[415, 464] -> 
             RGBColor[
              0.9693393203771661, 0.9766538958563213, 0.9367847124022013], 
             UndirectedEdge[234, 262] -> 
             RGBColor[
              0.8824921965180534, 0.8568707593561891, 0.6325003931175475], 
             UndirectedEdge[241, 417] -> 
             RGBColor[
              0.9691747791072346, 0.9753998357594013, 0.8863992754610857], 
             UndirectedEdge[309, 489] -> 
             RGBColor[
              0.920676204688325, 0.9386315270291707, 0.9591959332701646], 
             UndirectedEdge[83, 426] -> 
             RGBColor[
              0.9897529203155473, 0.9900305834596123, 0.8194841591709245], 
             UndirectedEdge[6, 99] -> 
             RGBColor[
              0.8560657914913172, 0.8878925149615176, 0.9593565603189155], 
             UndirectedEdge[121, 491] -> 
             RGBColor[
              0.9326393982244281, 0.9466156394483438, 0.8954020046973024], 
             UndirectedEdge[42, 358] -> 
             RGBColor[
              0.9039120163211024, 0.9250603443591443, 0.9505285133062021], 
             UndirectedEdge[69, 461] -> 
             RGBColor[
              0.5888510915142433, 0.6721059580700923, 0.9632144762361139], 
             UndirectedEdge[161, 387] -> 
             RGBColor[
              0.9906587848417958, 0.9851372880102378, 0.6103648249653191], 
             UndirectedEdge[117, 390] -> 
             RGBColor[
              0.8855198796763719, 0.8946868810261797, 0.6845052038122055], 
             UndirectedEdge[244, 334] -> 
             RGBColor[
              0.9393383098190196, 0.9499419100409676, 0.76539458911395], 
             UndirectedEdge[173, 493] -> 
             RGBColor[
              0.8670881056426344, 0.8955604430440135, 0.9159567684059835], 
             UndirectedEdge[229, 255] -> 
             RGBColor[
              0.9313472418145545, 0.9437624320066614, 0.7802275575295432], 
             UndirectedEdge[39, 401] -> 
             RGBColor[
              0.9878818624207126, 0.9892568529361035, 0.8504924306309494], 
             UndirectedEdge[379, 380] -> 
             RGBColor[
              0.8490971678513375, 0.8828655942369956, 0.9797715291401619], 
             UndirectedEdge[92, 140] -> 
             RGBColor[
              0.9821326697037751, 0.9846195373599917, 0.844569539240138], 
             UndirectedEdge[78, 97] -> 
             RGBColor[
              0.8188241614234194, 0.8591431412657241, 0.9823767831382606], 
             UndirectedEdge[395, 463] -> 
             RGBColor[
              0.9479505926107243, 0.9607022177089365, 0.9729902494371576], 
             UndirectedEdge[174, 338] -> 
             RGBColor[
              0.9773471825919351, 0.9813918539173556, 0.8679553519748755], 
             UndirectedEdge[143, 423] -> 
             RGBColor[
              0.9754052849527683, 0.9800671106549566, 0.8767739927176368], 
             UndirectedEdge[94, 100] -> 
             RGBColor[
              0.9260670761258123, 0.9413273144358743, 0.8927023655657197], 
             UndirectedEdge[404, 408] -> 
             RGBColor[
              0.7392895440058458, 0.79287031726668, 0.8824287399378408], 
             UndirectedEdge[301, 389] -> 
             RGBColor[
              0.9494639253687629, 0.9587823754270801, 0.8285013846615613], 
             UndirectedEdge[16, 422] -> 
             RGBColor[
              0.8392602393677508, 0.8747705816311899, 0.9845031904267244], 
             UndirectedEdge[389, 451] -> 
             RGBColor[
              0.9917540662335207, 0.9903700633119933, 0.7508442431415211], 
             UndirectedEdge[74, 296] -> 
             RGBColor[
              0.6943469618613329, 0.7611483909292176, 0.970169674183212], 
             UndirectedEdge[225, 453] -> 
             RGBColor[
              0.9936855493606002, 0.9889023535082428, 0.554089200052623], 
             UndirectedEdge[340, 378] -> 
             RGBColor[
              0.9616390143747295, 0.9706422677858235, 0.9377840375621891], 
             UndirectedEdge[52, 428] -> 
             RGBColor[
              0.5981943738928501, 0.6826535599404242, 0.9627707833137309], 
             UndirectedEdge[84, 230] -> 
             RGBColor[
              0.7032390580289156, 0.7680949640377671, 0.9710559552278335], 
             UndirectedEdge[119, 237] -> 
             RGBColor[
              0.674151098644697, 0.7000495299401062, 0.6321503067590872], 
             UndirectedEdge[67, 171] -> 
             RGBColor[
              0.7943770119404598, 0.8392981365551213, 0.9504471127509679], 
             UndirectedEdge[25, 157] -> 
             RGBColor[
              0.9014800619891402, 0.9235217484674298, 0.9641848586610227], 
             UndirectedEdge[124, 484] -> 
             RGBColor[
              0.8988429208389997, 0.9201135688357314, 0.9076053876665349], 
             UndirectedEdge[368, 500] -> 
             RGBColor[
              0.7040302137764571, 0.7627408418900532, 0.860017176302557], 
             UndirectedEdge[283, 422] -> 
             RGBColor[
              0.9307198949202071, 0.9452044085699438, 0.9004005958826263], 
             UndirectedEdge[334, 369] -> 
             RGBColor[
              0.9780443054857562, 0.9801135049530023, 0.745111128987194], 
             UndirectedEdge[42, 346] -> 
             RGBColor[
              0.9023785261460731, 0.9239166698974672, 0.9531243121742337], 
             UndirectedEdge[112, 263] -> 
             RGBColor[
              0.9184363578543984, 0.9341807748135736, 0.8368048338777593], 
             UndirectedEdge[146, 201] -> 
             RGBColor[
              0.9297437255228024, 0.9423887418442094, 0.7723663255234694], 
             UndirectedEdge[16, 243] -> 
             RGBColor[
              0.7206450683604402, 0.7815658198615538, 0.9728775528951851], 
             UndirectedEdge[285, 481] -> 
             RGBColor[
              0.9755981266370763, 0.9796765458693931, 0.8525166741999516], 
             UndirectedEdge[231, 444] -> 
             RGBColor[
              0.962729375748282, 0.9717242099748906, 0.9479736245092387], 
             UndirectedEdge[137, 408] -> 
             RGBColor[
              0.727402172752693, 0.7850037159334444, 0.9472873547944032], 
             UndirectedEdge[431, 436] -> 
             RGBColor[
              0.9175526174401522, 0.9370499400254436, 0.990416261917834], 
             UndirectedEdge[98, 277] -> 
             RGBColor[
              0.8942708456039803, 0.9182176489324119, 0.9789025731588354], 
             UndirectedEdge[131, 391] -> 
             RGBColor[
              0.9451376812720901, 0.954440193470666, 0.7557355576386509], 
             UndirectedEdge[52, 227] -> 
             RGBColor[
              0.7003188757019276, 0.7629618457686523, 0.9520772416092231], 
             UndirectedEdge[27, 419] -> 
             RGBColor[
              0.8703210650466715, 0.8994730516581493, 0.9874829397081936], 
             UndirectedEdge[232, 312] -> 
             RGBColor[
              0.8565082365721419, 0.8885107913622536, 0.9861517364413547], 
             UndirectedEdge[247, 466] -> 
             RGBColor[
              0.8432730047226615, 0.878030824154317, 0.9647699670191394], 
             UndirectedEdge[253, 484] -> 
             RGBColor[
              0.962502573485737, 0.9707730472881513, 0.9133373600159145], 
             UndirectedEdge[121, 200] -> 
             RGBColor[
              0.9278423104196489, 0.9441280045410299, 0.9523357840852208], 
             UndirectedEdge[79, 99] -> 
             RGBColor[
              0.8616518197090152, 0.8920585656599951, 0.9499008716158459], 
             UndirectedEdge[109, 300] -> 
             RGBColor[
              0.9264204279767807, 0.9389619648565684, 0.70907376802288], 
             UndirectedEdge[31, 397] -> 
             RGBColor[
              0.9366227609240819, 0.9509948037666783, 0.9480177071710937], 
             UndirectedEdge[70, 374] -> 
             RGBColor[
              0.8661704402674546, 0.5979931413129241, 0.5859212553007196], 
             UndirectedEdge[240, 352] -> 
             RGBColor[
              0.883738708352259, 0.9101332738646348, 0.9887729809971384], 
             UndirectedEdge[105, 323] -> 
             RGBColor[
              0.8563292301681944, 0.888503256111123, 0.9860987848348732], 
             UndirectedEdge[46, 53] -> 
             RGBColor[
              0.9870398639548474, 0.9884759906834379, 0.8450704873723613], 
             UndirectedEdge[221, 223] -> 
             RGBColor[
              0.9139662962130983, 0.9309292519620793, 0.8590140707692643], 
             UndirectedEdge[33, 159] -> 
             RGBColor[
              0.852753631487334, 0.8857169661538111, 0.985740546340796], 
             UndirectedEdge[16, 454] -> 
             RGBColor[
              0.8993780839227475, 0.920045357121957, 0.8856084928175226], 
             UndirectedEdge[195, 224] -> 
             RGBColor[
              0.9843911010289857, 0.9575436549691134, 0.5185212907812381], 
             UndirectedEdge[259, 500] -> 
             RGBColor[
              0.989203631222151, 0.9898034383034071, 0.8285873009631073], 
             UndirectedEdge[24, 77] -> 
             RGBColor[
              0.7799594462091728, 0.827497734368912, 0.9467487148685582], 
             UndirectedEdge[226, 386] -> 
             RGBColor[
              0.8369008901796302, 0.8715885953994595, 0.8952925041809074], 
             UndirectedEdge[289, 314] -> 
             RGBColor[
              0.9274150633846968, 0.9444294708597955, 0.9745584820406592], 
             UndirectedEdge[179, 325] -> 
             RGBColor[
              0.9809336226151757, 0.984519231634716, 0.8821535415151672], 
             UndirectedEdge[81, 83] -> 
             RGBColor[
              0.7225971449503172, 0.7793899950811749, 0.8840960818489074], 
             UndirectedEdge[312, 376] -> 
             RGBColor[
              0.9389818450417208, 0.9532013665456485, 0.9600203544226267], 
             UndirectedEdge[270, 309] -> 
             RGBColor[
              0.9777202224601068, 0.9662729347892471, 0.6592136724799504], 
             UndirectedEdge[139, 269] -> 
             RGBColor[
              0.9352444837484524, 0.9472274997967336, 0.8095804310705427], 
             UndirectedEdge[269, 425] -> 
             RGBColor[
              0.8259832262236568, 0.8644371713320497, 0.9831695938309746], 
             UndirectedEdge[25, 492] -> 
             RGBColor[
              0.8358011524485391, 0.8720683453078033, 0.9576769551938694], 
             UndirectedEdge[142, 173] -> 
             RGBColor[
              0.870328518818162, 0.8957930778917884, 0.7817614067441427], 
             UndirectedEdge[132, 209] -> 
             RGBColor[
              0.9708678886104872, 0.9534835024794786, 0.654511880037413], 
             UndirectedEdge[389, 409] -> 
             RGBColor[
              0.9396018606933825, 0.9509186327535459, 0.8275607321288545], 
             UndirectedEdge[337, 370] -> 
             RGBColor[
              0.7183293550294425, 0.7798836187450838, 0.9725600150060028], 
             UndirectedEdge[230, 242] -> 
             RGBColor[
              0.8746361901010632, 0.899708959959735, 0.8262987422654924], 
             UndirectedEdge[28, 461] -> 
             RGBColor[
              0.8996666876338737, 0.921093647616499, 0.9229479130945293], 
             UndirectedEdge[318, 350] -> 
             RGBColor[
              0.9291249601581957, 0.926425752614391, 0.6846580558119553], 
             UndirectedEdge[390, 478] -> 
             RGBColor[
              0.9202571713112988, 0.9221250324405823, 0.6878875856946604], 
             UndirectedEdge[167, 434] -> 
             RGBColor[
              0.9895834705820021, 0.9899605116401318, 0.8222923797776203], 
             UndirectedEdge[247, 269] -> 
             RGBColor[
              0.8023159576915266, 0.8459481212768467, 0.980810661686891], 
             UndirectedEdge[394, 398] -> 
             RGBColor[
              0.9420938558150301, 0.9563342729962341, 0.9829041771506697], 
             UndirectedEdge[14, 158] -> 
             RGBColor[
              0.9941654331074793, 0.9899287763191281, 0.6063215844012299], 
             UndirectedEdge[131, 433] -> 
             RGBColor[
              0.9657314131427219, 0.9707997488792766, 0.7555735472991072], 
             UndirectedEdge[87, 422] -> 
             RGBColor[
              0.9246311302260368, 0.9187583640483377, 0.6782211393871158], 
             UndirectedEdge[210, 469] -> 
             RGBColor[
              0.8479198254005356, 0.8815722688766072, 0.9853565439653088], 
             UndirectedEdge[312, 414] -> 
             RGBColor[
              0.9231469759568154, 0.9413917471093445, 0.9868246573880761], 
             UndirectedEdge[277, 311] -> 
             RGBColor[
              0.8944041206346761, 0.918317045232087, 0.9786769732955625], 
             UndirectedEdge[332, 424] -> 
             RGBColor[
              0.7505903755088055, 0.8042123408855448, 0.95939605805795], 
             UndirectedEdge[328, 433] -> 
             RGBColor[
              0.9392672615284863, 0.954226203605453, 0.9876888639839292], 
             UndirectedEdge[88, 428] -> 
             RGBColor[
              0.848272573089502, 0.8822185143652438, 0.9795425347730988], 
             UndirectedEdge[8, 162] -> 
             RGBColor[
              0.8584930410662275, 0.8898409226478052, 0.96224194841347], 
             UndirectedEdge[27, 289] -> 
             RGBColor[
              0.9120059164729655, 0.9326727783271622, 0.9914691325421261], 
             UndirectedEdge[192, 280] -> 
             RGBColor[
              0.9462773677218287, 0.955875578420968, 0.7985345893803164], 
             UndirectedEdge[347, 477] -> 
             RGBColor[
              0.8117085684704135, 0.8536063271971599, 0.9734629137365114], 
             UndirectedEdge[145, 346] -> 
             RGBColor[
              0.9628795543509185, 0.971836212930842, 0.9477194113078278], 
             UndirectedEdge[232, 415] -> 
             RGBColor[
              0.8960700391561685, 0.9188278928642157, 0.9473355692621014], 
             UndirectedEdge[189, 374] -> 
             RGBColor[
              0.9119429298424868, 0.6324781484923202, 0.5138326522394651], 
             UndirectedEdge[139, 140] -> 
             RGBColor[
              0.9824913479921838, 0.9840011380527282, 0.7828927165089257], 
             UndirectedEdge[134, 251] -> 
             RGBColor[
              0.7372656302476427, 0.7946199960664913, 0.9746000087010471], 
             UndirectedEdge[67, 281] -> 
             RGBColor[
              0.9768413509182081, 0.9821367370390037, 0.9190629367694161], 
             UndirectedEdge[167, 495] -> 
             RGBColor[
              0.6877973119361186, 0.7502156673812408, 0.9154002616838784], 
             UndirectedEdge[143, 179] -> 
             RGBColor[
              0.9664514420585095, 0.9745001209347339, 0.9416731371163918], 
             UndirectedEdge[21, 175] -> 
             RGBColor[
              0.9494333570849365, 0.9616896748232678, 0.9663757919830691], 
             UndirectedEdge[366, 473] -> 
             RGBColor[
              0.6893664257282326, 0.7559316791207185, 0.9706008356993847], 
             UndirectedEdge[143, 292] -> 
             RGBColor[
              0.9228245336356169, 0.9406743304849209, 0.970834670398547], 
             UndirectedEdge[267, 486] -> 
             RGBColor[
              0.6360116823565787, 0.7042038548621814, 0.9280152805749733], 
             UndirectedEdge[248, 380] -> 
             RGBColor[
              0.6854124656384908, 0.7537426833003216, 0.9695704333326607], 
             UndirectedEdge[48, 407] -> 
             RGBColor[
              0.8344535385105227, 0.8711874847995273, 0.966244478168818], 
             UndirectedEdge[436, 459] -> 
             RGBColor[
              0.9647203215991369, 0.9719164675090997, 0.8867188026862813], 
             UndirectedEdge[235, 262] -> 
             RGBColor[
              0.9059077357679421, 0.8754533382528658, 0.6347572299463787], 
             UndirectedEdge[236, 283] -> 
             RGBColor[
              0.9918780200755959, 0.9894796910275977, 0.6803434186667835], 
             UndirectedEdge[99, 493] -> 
             RGBColor[
              0.8670881056426344, 0.8955604430440135, 0.9159567684059835], 
             UndirectedEdge[109, 456] -> 
             RGBColor[
              0.9152135363002123, 0.9300258936366432, 0.7080048446902585], 
             UndirectedEdge[208, 289] -> 
             RGBColor[
              0.9273254788013612, 0.944362658824225, 0.9747101253728452], 
             UndirectedEdge[266, 410] -> 
             RGBColor[
              0.8569048340329175, 0.8871598006019266, 0.8947457733136186], 
             UndirectedEdge[299, 301] -> 
             RGBColor[
              0.9470174457952364, 0.9582587386635749, 0.9045216318500368], 
             UndirectedEdge[314, 359] -> 
             RGBColor[
              0.7964858285408887, 0.8414248842616666, 0.961736362650813], 
             UndirectedEdge[209, 214] -> 
             RGBColor[
              0.9767017170503053, 0.9814221396211311, 0.8919617123090033], 
             UndirectedEdge[210, 326] -> 
             RGBColor[
              0.7812696077944941, 0.8291644172260528, 0.9788037504745516], 
             UndirectedEdge[53, 317] -> 
             RGBColor[
              0.9651207811851474, 0.9721287746429997, 0.8821737770890957], 
             UndirectedEdge[402, 459] -> 
             RGBColor[
              0.9910082504854218, 0.9905496947453694, 0.7986800895657624], 
             UndirectedEdge[89, 249] -> 
             RGBColor[
              0.9821317506450224, 0.9836063388077667, 0.773455289869023], 
             UndirectedEdge[67, 135] -> 
             RGBColor[
              0.9774409130317865, 0.9823846713810118, 0.909126640930413], 
             UndirectedEdge[90, 178] -> 
             RGBColor[
              0.8949629432859708, 0.919083174127036, 0.9898435585451087], 
             UndirectedEdge[174, 229] -> 
             RGBColor[
              0.9784666074608506, 0.9806282358392899, 0.7602478723890496], 
             UndirectedEdge[266, 364] -> 
             RGBColor[
              0.8563524415798786, 0.8869313721267564, 0.903900345806318], 
             UndirectedEdge[407, 430] -> 
             RGBColor[
              0.8291323400800827, 0.8672189437227679, 0.9752518791207306], 
             UndirectedEdge[217, 355] -> 
             RGBColor[
              0.644817638041233, 0.7202394885857244, 0.9667482945077908], 
             UndirectedEdge[176, 426] -> 
             RGBColor[
              0.9746594896885676, 0.9797134146474228, 0.8871055491902227], 
             UndirectedEdge[280, 483] -> 
             RGBColor[
              0.9937499336694187, 0.99072478297188, 0.6835582439905781], 
             UndirectedEdge[51, 347] -> 
             RGBColor[
              0.6623051518059858, 0.7361170853872046, 0.9669760460046344], 
             UndirectedEdge[152, 451] -> 
             RGBColor[
              0.8871525288019254, 0.9110006537817972, 0.9073338455660234], 
             UndirectedEdge[105, 342] -> 
             RGBColor[
              0.8291964459426155, 0.867306918857303, 0.9833944424735522], 
             UndirectedEdge[318, 496] -> 
             RGBColor[
              0.9306870160980094, 0.9276712936199195, 0.6848070461019585], 
             UndirectedEdge[114, 289] -> 
             RGBColor[
              0.8865064672065079, 0.9123402096462003, 0.9890369723074643], 
             UndirectedEdge[103, 331] -> 
             RGBColor[
              0.8277962661720488, 0.5040037883175266, 0.5743272359611191], 
             UndirectedEdge[107, 113] -> 
             RGBColor[
              0.9415445400398561, 0.9512637393262107, 0.7301512989864595], 
             UndirectedEdge[16, 56] -> 
             RGBColor[
              0.8708062221528909, 0.8999244920111693, 0.9875120744262024], 
             UndirectedEdge[140, 370] -> 
             RGBColor[
              0.8471893240765234, 0.8808675649663457, 0.9538863790403139], 
             UndirectedEdge[213, 500] -> 
             RGBColor[
              0.8675359598030712, 0.8949763900501452, 0.8736535050688267], 
             UndirectedEdge[280, 327] -> 
             RGBColor[
              0.974881824819239, 0.9781709869368751, 0.783476559582553], 
             UndirectedEdge[76, 238] -> 
             RGBColor[
              0.826588015412793, 0.862712361591476, 0.8570942271606803], 
             UndirectedEdge[253, 261] -> 
             RGBColor[
              0.9643556555740774, 0.9692301270277472, 0.7147712719287301], 
             UndirectedEdge[232, 350] -> 
             RGBColor[
              0.8429649946217421, 0.8777117778525143, 0.9848599699339307], 
             UndirectedEdge[166, 320] -> 
             RGBColor[
              0.9887391709764694, 0.9896113720557339, 0.836284609218638], 
             UndirectedEdge[33, 119] -> 
             RGBColor[
              0.8745467599206841, 0.8624710339663217, 0.648884782490106], 
             UndirectedEdge[71, 228] -> 
             RGBColor[
              0.8887315935540219, 0.8804275929820291, 0.6603385435340694], 
             UndirectedEdge[50, 244] -> 
             RGBColor[
              0.817385288779287, 0.8577932011845892, 0.982293311854088], 
             UndirectedEdge[235, 344] -> 
             RGBColor[
              0.92464484388797, 0.9381119490909822, 0.754768922149438], 
             UndirectedEdge[72, 494] -> 
             RGBColor[
              0.9842579381771427, 0.9862691553726218, 0.8438647667981403], 
             UndirectedEdge[185, 496] -> 
             RGBColor[
              0.771104241468765, 0.8215988623607375, 0.9776908607887262], 
             UndirectedEdge[106, 370] -> 
             RGBColor[
              0.8381612206565678, 0.8741344202179053, 0.969168603223814], 
             UndirectedEdge[51, 113] -> 
             RGBColor[
              0.7680802624420346, 0.8193166742831206, 0.9773681848779168], 
             UndirectedEdge[422, 443] -> 
             RGBColor[
              0.9044027077072228, 0.926563823090472, 0.9891364991045283], 
             UndirectedEdge[4, 335] -> 
             RGBColor[
              0.913552335483846, 0.9302540407426305, 0.8337168221137785], 
             UndirectedEdge[1, 84] -> 
             RGBColor[
              0.7585936444925792, 0.8117036250328986, 0.9764762603286847], 
             UndirectedEdge[90, 272] -> 
             RGBColor[
              0.9460286350847226, 0.956168995366949, 0.8383736813226772], 
             UndirectedEdge[213, 450] -> 
             RGBColor[
              0.8680233570872234, 0.8937030878899312, 0.7583697933294264], 
             UndirectedEdge[5, 212] -> 
             RGBColor[
              0.8086909999857685, 0.8497610090859757, 0.9107783928683775], 
             UndirectedEdge[50, 106] -> 
             RGBColor[
              0.8511003205349421, 0.8842425433836927, 0.9704582517769273], 
             UndirectedEdge[115, 291] -> 
             RGBColor[
              0.8012680010623143, 0.8455055482561158, 0.9806064061426764], 
             UndirectedEdge[9, 117] -> 
             RGBColor[
              0.8334620190507616, 0.8703044285566218, 0.9839084374930622], 
             UndirectedEdge[194, 388] -> 
             RGBColor[
              0.990057713701024, 0.9901566233573397, 0.8144329439935789], 
             UndirectedEdge[202, 211] -> 
             RGBColor[
              0.7609452205113343, 0.8135631253952968, 0.9767046908711494], 
             UndirectedEdge[113, 308] -> 
             RGBColor[
              0.9314974694995874, 0.9472573780227931, 0.9601333608561371], 
             UndirectedEdge[51, 421] -> 
             RGBColor[
              0.8196383713673636, 0.8574322605794327, 0.8631584670629064], 
             UndirectedEdge[109, 335] -> 
             RGBColor[
              0.9123948897753278, 0.9277783814078221, 0.7077359996684796], 
             UndirectedEdge[278, 329] -> 
             RGBColor[
              0.8216259850897932, 0.8610415814236766, 0.9827330968881678], 
             UndirectedEdge[129, 206] -> 
             RGBColor[
              0.794988324453269, 0.8406255503236764, 0.9759069713388251], 
             UndirectedEdge[166, 227] -> 
             RGBColor[
              0.9734376591166597, 0.9790506127166038, 0.9002993199347398], 
             UndirectedEdge[294, 411] -> 
             RGBColor[
              0.859353129065441, 0.8907795262565744, 0.9758277983576051], 
             UndirectedEdge[362, 384] -> 
             RGBColor[
              0.9865971014522209, 0.9882745798147408, 0.8515879264399946], 
             UndirectedEdge[143, 308] -> 
             RGBColor[
              0.9663799628870291, 0.9744468118856804, 0.9417941327089544], 
             UndirectedEdge[151, 310] -> 
             RGBColor[
              0.8738514767046701, 0.9006460250236243, 0.9076520418083853], 
             UndirectedEdge[297, 397] -> 
             RGBColor[
              0.7193146858313029, 0.7797924321816931, 0.9734793994226005], 
             UndirectedEdge[114, 359] -> 
             RGBColor[
              0.7555772323626998, 0.8093356230480715, 0.976214852917618], 
             UndirectedEdge[141, 220] -> 
             RGBColor[
              0.9911332966442137, 0.9905875509025792, 0.7956007375065959], 
             UndirectedEdge[122, 493] -> 
             RGBColor[
              0.863647236976917, 0.8928724102907848, 0.9156138147741306], 
             UndirectedEdge[146, 442] -> 
             RGBColor[
              0.9931405611383606, 0.9877366788076342, 0.49477059533929124`], 
             UndirectedEdge[294, 478] -> 
             RGBColor[
              0.8142426103056547, 0.8551128979106026, 0.9820398452223369], 
             UndirectedEdge[76, 487] -> 
             RGBColor[
              0.825821624401065, 0.862395439212776, 0.8697953095813752], 
             UndirectedEdge[67, 70] -> 
             RGBColor[
              0.9327170756245996, 0.9483333088221513, 0.963836363745652], 
             UndirectedEdge[346, 358] -> 
             RGBColor[
              0.9790938308208935, 0.9839287937737083, 0.9202728706047498], 
             UndirectedEdge[149, 165] -> 
             RGBColor[
              0.8911922270283479, 0.8266494259917417, 0.6250526412552893], 
             UndirectedEdge[175, 375] -> 
             RGBColor[
              0.8117105512967189, 0.8532013973318133, 0.952887217791064], 
             UndirectedEdge[18, 428] -> 
             RGBColor[
              0.7169988566853918, 0.7788442233265495, 0.9724274033652818], 
             UndirectedEdge[2, 47] -> 
             RGBColor[
              0.836098727927375, 0.8727413099682868, 0.9800044721585608], 
             UndirectedEdge[140, 466] -> 
             RGBColor[
              0.9642996395378511, 0.9728953101380803, 0.9453155775038861], 
             UndirectedEdge[199, 382] -> 
             RGBColor[
              0.8997135681942243, 0.9228711934765992, 0.9902966773897909], 
             UndirectedEdge[305, 499] -> 
             RGBColor[
              0.8818594698715511, 0.9080313767859409, 0.9613526061369102], 
             UndirectedEdge[252, 282] -> 
             RGBColor[
              0.9488956534984843, 0.959933444503889, 0.9123899414315179], 
             UndirectedEdge[235, 249] -> 
             RGBColor[
              0.9250486831065873, 0.9389757203451964, 0.7987243288891682], 
             UndirectedEdge[130, 214] -> 
             RGBColor[
              0.9820911874902845, 0.9595112755609845, 0.5997145849145227], 
             UndirectedEdge[100, 475] -> 
             RGBColor[
              0.8302820574858716, 0.8676745080608675, 0.9836301556901172], 
             UndirectedEdge[10, 438] -> 
             RGBColor[
              0.8936404753077414, 0.91698263189254, 0.9497627373342645], 
             UndirectedEdge[39, 179] -> 
             RGBColor[
              0.980285200653958, 0.984251092490068, 0.8928995714747898], 
             UndirectedEdge[400, 414] -> 
             RGBColor[
              0.9491374587286663, 0.9615873805163827, 0.9709811946837419], 
             UndirectedEdge[41, 191] -> 
             RGBColor[
              0.8949225967176628, 0.9185596850055424, 0.9728054115127718], 
             UndirectedEdge[25, 96] -> 
             RGBColor[
              0.8015547321718033, 0.8452482541185165, 0.9543090772092807], 
             UndirectedEdge[106, 274] -> 
             RGBColor[
              0.9692572251989064, 0.9762954182007839, 0.92361216180021], 
             UndirectedEdge[204, 363] -> 
             RGBColor[
              0.8823695676168165, 0.9090415582065283, 0.9886423911315456], 
             UndirectedEdge[99, 413] -> 
             RGBColor[
              0.8585752846141073, 0.8897640908235765, 0.9551086430426624], 
             UndirectedEdge[37, 118] -> 
             RGBColor[
              0.8726519002501383, 0.901146086322844, 0.9760122709382464], 
             UndirectedEdge[411, 478] -> 
             RGBColor[
              0.9023491327794106, 0.924669446315662, 0.9800333314780465], 
             UndirectedEdge[300, 451] -> 
             RGBColor[
              0.9245362112798434, 0.9405307727750236, 0.9109734703381571], 
             UndirectedEdge[122, 233] -> 
             RGBColor[
              0.6970118576695028, 0.7632302277885182, 0.9704352860925032], 
             UndirectedEdge[97, 404] -> 
             RGBColor[
              0.951627394058806, 0.9618613282612543, 0.9017802169357205], 
             UndirectedEdge[362, 498] -> 
             RGBColor[
              0.8560861475495848, 0.8861936388002718, 0.8798548479221923], 
             UndirectedEdge[121, 454] -> 
             RGBColor[
              0.9330349847300153, 0.9467792246345135, 0.8888461125546636], 
             UndirectedEdge[173, 417] -> 
             RGBColor[
              0.8470032356931603, 0.8811336756858255, 0.9746971033920911], 
             UndirectedEdge[36, 352] -> 
             RGBColor[
              0.756443199522828, 0.8100457709690704, 0.9762560620934064], 
             UndirectedEdge[309, 337] -> 
             RGBColor[
              0.8427954208603947, 0.8773972704985484, 0.9515378467807543], 
             UndirectedEdge[207, 456] -> 
             RGBColor[
              0.9016752383434952, 0.8843933952278187, 0.6524043933409387], 
             UndirectedEdge[95, 97] -> 
             RGBColor[
              0.9475496183585623, 0.942307947513537, 0.6881673456731403], 
             UndirectedEdge[185, 350] -> 
             RGBColor[
              0.7695421855289513, 0.820353321355209, 0.977541870498723], 
             UndirectedEdge[303, 435] -> 
             RGBColor[
              0.771492928287633, 0.8165666632972199, 0.7249444973859162], 
             UndirectedEdge[14, 441] -> 
             RGBColor[
              0.9741668906229318, 0.9236107366079697, 0.40589801214369026`], 
             UndirectedEdge[67, 147] -> 
             RGBColor[
              0.9545237480683948, 0.9656044662867129, 0.9618636118008318], 
             UndirectedEdge[115, 419] -> 
             RGBColor[
              0.7475558138719122, 0.8027155505221353, 0.9754730352866339], 
             UndirectedEdge[113, 209] -> 
             RGBColor[
              0.9275147773408068, 0.9442870927318344, 0.9668750198284767], 
             UndirectedEdge[100, 121] -> 
             RGBColor[
              0.8678290889663158, 0.8974473752213976, 0.9872555072974223], 
             UndirectedEdge[39, 254] -> 
             RGBColor[
              0.9886097577392082, 0.9828930423971924, 0.6346670460695341], 
             UndirectedEdge[2, 339] -> 
             RGBColor[
              0.7172486161232661, 0.779039337297659, 0.9724522970519145], 
             UndirectedEdge[76, 436] -> 
             RGBColor[
              0.798274971503849, 0.8432416972502548, 0.9786943370363382], 
             UndirectedEdge[121, 161] -> 
             RGBColor[
              0.9325445289719805, 0.9413085148637934, 0.7028674190206927], 
             UndirectedEdge[215, 430] -> 
             RGBColor[
              0.8383883434574242, 0.8744498039093782, 0.9761744310351146], 
             UndirectedEdge[100, 254] -> 
             RGBColor[
              0.9253758717790689, 0.934376669716189, 0.7003951349695239], 
             UndirectedEdge[186, 389] -> 
             RGBColor[
              0.9844018059542115, 0.9856509634734801, 0.7975123113138975], 
             UndirectedEdge[197, 426] -> 
             RGBColor[
              0.739016497429658, 0.7927574054904496, 0.8869538283271581], 
             UndirectedEdge[316, 378] -> 
             RGBColor[
              0.9382826526072248, 0.9534918838841253, 0.98935555006049], 
             UndirectedEdge[185, 330] -> 
             RGBColor[
              0.8232222519233895, 0.8618495710721863, 0.9368625211816892], 
             UndirectedEdge[56, 166] -> 
             RGBColor[
              0.9612820104544161, 0.9699514645574282, 0.9197147063968603], 
             UndirectedEdge[38, 73] -> 
             RGBColor[
              0.8562088255519641, 0.8883755993654487, 0.9781682452313762], 
             UndirectedEdge[97, 430] -> 
             RGBColor[
              0.9288955315930212, 0.945906923137862, 0.9849957267189763], 
             UndirectedEdge[222, 372] -> 
             RGBColor[
              0.9916063890120154, 0.9821040070994103, 0.5277172808710567], 
             UndirectedEdge[137, 430] -> 
             RGBColor[
              0.9555857838557802, 0.9663965308380209, 0.9600658622360839], 
             UndirectedEdge[30, 355] -> 
             RGBColor[
              0.7453442809071176, 0.7952627591931614, 0.7167181605851285], 
             UndirectedEdge[111, 442] -> 
             RGBColor[
              0.9917916399024288, 0.9885276918204153, 0.6151711666904606], 
             UndirectedEdge[183, 408] -> 
             RGBColor[
              0.6618586243798821, 0.7335335445597576, 0.9685113572095719], 
             UndirectedEdge[39, 283] -> 
             RGBColor[
              0.9888657296716438, 0.9896637073285985, 0.8341872041161935], 
             UndirectedEdge[244, 498] -> 
             RGBColor[
              0.8027793460461499, 0.8463829277121863, 0.9808375279827442], 
             UndirectedEdge[259, 454] -> 
             RGBColor[
              0.9886769321933212, 0.9895856347194383, 0.8373160669242106], 
             UndirectedEdge[17, 418] -> 
             RGBColor[
              0.8361365151735061, 0.8724790556792203, 0.9841523728157449], 
             UndirectedEdge[70, 391] -> 
             RGBColor[
              0.8967541526521842, 0.9205114358545714, 0.9900144056934896], 
             UndirectedEdge[18, 495] -> 
             RGBColor[
              0.5346572055792149, 0.6308031233235267, 0.9573753657167614], 
             UndirectedEdge[48, 95] -> 
             RGBColor[
              0.9687165778391291, 0.9586782925002988, 0.6725869751650284], 
             UndirectedEdge[50, 92] -> 
             RGBColor[
              0.871671636908225, 0.8980089799755202, 0.8650770092235445], 
             UndirectedEdge[118, 141] -> 
             RGBColor[
              0.8959184581974751, 0.9166446095175311, 0.8532317579242217], 
             UndirectedEdge[373, 398] -> 
             RGBColor[
              0.8876412782898623, 0.9129631368553006, 0.9793701628464055], 
             UndirectedEdge[218, 409] -> 
             RGBColor[
              0.9372138575202648, 0.9504191774843849, 0.9026118740304845]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.948198768055973, 0.9608873065496529, 0.9725701531428741], 316 -> 
             RGBColor[
              0.9390969386517184, 0.9540991770828378, 0.9879771761869761], 
             308 -> RGBColor[
              0.972827260372161, 0.979255195793611, 0.9308805397911201], 160 -> 
             RGBColor[
              0.9416652110011032, 0.9560145903958489, 0.9836297610121757], 
             245 -> RGBColor[
              0.6434767557299411, 0.7214081992714881, 0.9650994074451393], 
             155 -> RGBColor[
              0.9346061936516449, 0.9506936258812598, 0.9936247671549341], 
             425 -> RGBColor[
              0.7758707241843288, 0.8248353736594839, 0.9782952009286945], 
             213 -> RGBColor[
              0.7424743193485682, 0.7987458483797102, 0.9749665594018131], 
             352 -> RGBColor[
              0.8679049538266568, 0.8975078678017367, 0.987262743355527], 27 -> 
             RGBColor[
              0.9254390447289824, 0.9433839901659573, 0.9927503963070802], 
             485 -> RGBColor[
              0.6812097340208215, 0.7508854886935805, 0.968860278086444], 454 -> 
             RGBColor[
              0.9915442021999143, 0.9907713245526427, 0.7897979826580468], 
             367 -> RGBColor[
              0.5355548897193153, 0.6338266118038032, 0.9565799892023574], 19 -> 
             RGBColor[
              0.9686519411267903, 0.9761412495368713, 0.9379482661758664], 
             164 -> RGBColor[
              0.9578680960915468, 0.9680986755665124, 0.9562025029432967], 
             190 -> RGBColor[
              0.8740759996133818, 0.9024284922034957, 0.9878513432116225], 
             103 -> RGBColor[0.817319, 0.134127, 0.164218], 138 -> 
             RGBColor[
              0.9813976229761088, 0.9856469581909545, 0.916373151411196], 416 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 476 -> 
             RGBColor[
              0.8697433308684857, 0.8989737397534756, 0.9874380893989152], 
             291 -> RGBColor[
              0.9226274597451648, 0.9411421086183025, 0.992482224821392], 28 -> 
             RGBColor[
              0.9870684252922802, 0.9889204757791161, 0.8639731889568802], 
             337 -> RGBColor[
              0.7128695186562862, 0.7756183530740808, 0.9720158295413984], 
             195 -> RGBColor[
              0.9739038275662804, 0.9236336240877008, 0.3531217272539973], 
             114 -> RGBColor[
              0.8744401461960676, 0.9027188528040337, 0.9878860758377566], 
             479 -> RGBColor[
              0.9279203800480342, 0.9453625395953162, 0.9929870682849254], 93 -> 
             RGBColor[
              0.8695006523750178, 0.8987802345101166, 0.9874149425075666], 34 -> 
             RGBColor[
              0.8547957153876611, 0.8870549169112795, 0.9860123724904603], 
             161 -> RGBColor[
              0.9905632906838447, 0.9798299050112025, 0.4178405955901052], 22 -> 
             RGBColor[
              0.9935499046024456, 0.9886122230863393, 0.5393251052299204], 
             124 -> RGBColor[
              0.8087867801840355, 0.8505496467777459, 0.9815759657727131], 84 -> 
             RGBColor[
              0.6520153436912978, 0.728078609082572, 0.9659504540954862], 46 -> 
             RGBColor[
              0.9815876674998223, 0.9857886930855706, 0.9160514556040991], 
             241 -> RGBColor[
              0.9910017415791091, 0.9905470031453376, 0.798787958987875], 185 -> 
             RGBColor[
              0.661959276857542, 0.7358468852487333, 0.9669415724221586], 426 -> 
             RGBColor[
              0.9896589244223426, 0.9899917137421879, 0.8210419143749003], 
             390 -> RGBColor[
              0.9832757286029733, 0.9552472469114746, 0.38952979304654234`], 
             121 -> RGBColor[
              0.8745257672601163, 0.9027871247163843, 0.9878942424512803], 
             322 -> RGBColor[
              0.9797627014021952, 0.9433969812652375, 0.3758823457510403], 
             488 -> RGBColor[
              0.9764380230793589, 0.9819480967085579, 0.9247684603655733], 
             126 -> RGBColor[
              0.9939231593786376, 0.9894105773107671, 0.5799515841569468], 
             433 -> RGBColor[
              0.9380772059470657, 0.9533386621013668, 0.9897033176670688], 
             236 -> RGBColor[
              0.9936247634006983, 0.9887723384864161, 0.5474730234447647], 78 -> 
             RGBColor[
              0.7245985523039445, 0.7847811633035887, 0.9731848700013457], 
             376 -> RGBColor[
              0.9737521119822815, 0.9799449486101333, 0.929315007255118], 458 -> 
             RGBColor[
              0.8069122543201317, 0.8490852529259401, 0.9813891305530393], 
             254 -> RGBColor[
              0.9896193328856223, 0.976645713705967, 0.41417349779548346`], 
             290 -> RGBColor[
              0.7204555056930733, 0.7815445838028556, 0.972771929834146], 251 -> 
             RGBColor[
              0.620897433805136, 0.7031115337304703, 0.9632984668928329], 165 -> 
             RGBColor[
              0.8498629789535114, 0.8831216867742521, 0.9855418836858653], 
             460 -> 
             RGBColor[
              0.723869401775705, 0.7842115453691788, 0.9731121950909899], 100 -> 
             RGBColor[
              0.8611324106725154, 0.892107625726411, 0.9866167721435644], 235 -> 
             RGBColor[
              0.855885897253905, 0.8879241983392239, 0.9861163550100794], 70 -> 
             RGBColor[
              0.8966185630985665, 0.9204033204249971, 0.9900014730408234], 
             234 -> RGBColor[
              0.8090548187541277, 0.8507590405458705, 0.981602681352417], 435 -> 
             RGBColor[
              0.5498690768036788, 0.645447513725669, 0.9577068544442335], 257 -> 
             RGBColor[
              0.9752730764585514, 0.9282524221162599, 0.3584410006395139], 
             135 -> RGBColor[
              0.9860662379129401, 0.9885060455427181, 0.8805820274103453], 
             265 -> RGBColor[
              0.9951056391425188, 0.9922440702531642, 0.7307757558157316], 
             111 -> RGBColor[
              0.9910206388404212, 0.9905548176485277, 0.7984747824633884], 
             497 -> RGBColor[
              0.9400298746233885, 0.9547949592029668, 0.9863979589356099], 
             481 -> RGBColor[
              0.9940944543806192, 0.9918259193678557, 0.7475337041826883], 
             381 -> RGBColor[
              0.9286729402142171, 0.945962610644129, 0.9930588481453944], 182 -> 
             RGBColor[
              0.9651477239886952, 0.9735278101329089, 0.9438799917444571], 
             188 -> RGBColor[
              0.7544627723665334, 0.8081113189929622, 0.9761614563601807], 
             154 -> RGBColor[
              0.9906679726063273, 0.9904089810976211, 0.8043193746332815], 
             336 -> RGBColor[
              0.9037555467997191, 0.9260941575000344, 0.9906822049174999], 
             463 -> RGBColor[
              0.9552328851717119, 0.9661333395772613, 0.960663227657494], 315 -> 
             RGBColor[
              0.9528817374427321, 0.9643798574506393, 0.9646431074851193], 
             368 -> RGBColor[
              0.4154628272953403, 0.5342747520595261, 0.9476939018692739], 
             269 -> RGBColor[
              0.8760957282629848, 0.9040389690046154, 0.9880439867332547], 
             208 -> RGBColor[
              0.956078169385774, 0.966763751160083, 0.9592323819685182], 86 -> 
             RGBColor[
              0.8004572527817191, 0.8440425566643034, 0.9807457563251094], 
             119 -> RGBColor[
              0.9650324305321565, 0.8937083187885205, 0.3186580249991828], 
             436 -> RGBColor[
              0.937468366562731, 0.952884590685413, 0.9907339239340041], 377 -> 
             RGBColor[
              0.9015219240987835, 0.9243131273883815, 0.9904691599903062], 
             140 -> RGBColor[
              0.9705894567504478, 0.9775862455166044, 0.9346685576100207], 85 -> 
             RGBColor[
              0.9952108206695621, 0.9921647546095276, 0.7201055691497422], 
             351 -> RGBColor[
              0.9944768440879991, 0.99059485291798, 0.6402167478250032], 443 -> 
             RGBColor[
              0.9374969023245245, 0.9529058726098356, 0.9906856203326062], 
             242 -> RGBColor[
              0.994809607835593, 0.9913066009265077, 0.676436028170804], 117 -> 
             RGBColor[
              0.7877640307497704, 0.8341265151408847, 0.9794806145778687], 47 -> 
             RGBColor[
              0.9402130328969017, 0.9549315583434589, 0.9860879197538803], 
             451 -> RGBColor[
              0.9887918598306757, 0.98963316025099, 0.8354114185500549], 81 -> 
             RGBColor[
              0.45534737369188255`, 0.5687105369853133, 0.9502657597308658], 
             275 -> RGBColor[
              0.974215486621577, 0.9802905326574135, 0.9285306348582523], 23 -> 
             RGBColor[
              0.9530304042262798, 0.9644907328943897, 0.9643914533990801], 
             328 -> RGBColor[
              0.9404573171099068, 0.9551137451095393, 0.9856744103007896], 
             418 -> RGBColor[
              0.8897123212196224, 0.9148964706156688, 0.9893427495251348], 
             110 -> RGBColor[
              0.9898392909116508, 0.9773876837763614, 0.41502799319101624`], 
             6 -> RGBColor[
              0.9654729282316739, 0.9737703469248493, 0.9433295057879449], 
             218 -> RGBColor[
              0.9899402662901301, 0.9901080558346742, 0.8163793515362474], 
             108 -> RGBColor[
              0.9151943319441972, 0.9352151342766901, 0.9917732464561042], 
             297 -> RGBColor[
              0.5498690768036788, 0.645447513725669, 0.9577068544442335], 487 -> 
             RGBColor[
              0.992561672357163, 0.9911920746104553, 0.772935869024078], 464 -> 
             RGBColor[
              0.955343457485119, 0.9662158042275547, 0.9604760575727739], 157 -> 
             RGBColor[
              0.8378667793758742, 0.8735562428592071, 0.9843976754610165], 
             441 -> RGBColor[
              0.9548764849756416, 0.8588073299880875, 0.28255076450761574`], 
             354 -> RGBColor[
              0.9614659973249142, 0.9707819844153351, 0.9501121946381351], 
             385 -> 
             RGBColor[
              0.7856447336731529, 0.8324709041573768, 0.9792693828512287], 
             270 -> RGBColor[
              0.9827191218557105, 0.9533696816554781, 0.387367480939791], 392 -> 
             RGBColor[
              0.7945894126332769, 0.8394585553431034, 0.9801609048571965], 33 -> 
             RGBColor[
              0.7840610893092117, 0.8312337491441228, 0.9791115399810291], 
             252 -> RGBColor[
              0.9088906211585487, 0.9301887264058849, 0.9911719928939801], 
             394 -> RGBColor[
              0.9375553867113999, 0.9529494901698079, 0.9905866215207971], 
             260 -> RGBColor[
              0.8406791091421951, 0.8757987182762136, 0.9846659179847246], 
             159 -> RGBColor[
              0.9214461736654562, 0.9402001831634993, 0.9923695527005629], 
             183 -> RGBColor[
              0.8353431783227906, 0.871543991880804, 0.9841569721397281], 99 -> 
             RGBColor[
              0.7466586547509605, 0.8020146829981859, 0.975383614849886], 329 -> 
             RGBColor[
              0.8771250942003604, 0.9048597574616848, 0.9881421685752874], 
             309 -> RGBColor[
              0.9727213230645031, 0.9791761879230161, 0.93105986402011], 17 -> 
             RGBColor[
              0.7825607091273896, 0.8300616407427718, 0.978961996106355], 349 -> 
             RGBColor[
              0.7405856059663001, 0.797270371130729, 0.9747783101028986], 495 -> 
             RGBColor[
              0.3897794701541797, 0.5120291189869168, 0.9460573810631402], 
             347 -> RGBColor[
              0.6786174573549162, 0.7488603824601429, 0.9686019041745894], 
             340 -> RGBColor[
              0.985809662186728, 0.988399944886234, 0.8848341511903742], 404 -> 
             RGBColor[
              0.9902050175747179, 0.9902175372946489, 0.8119917375962656], 
             277 -> RGBColor[
              0.8406791091421951, 0.8757987182762136, 0.9846659179847246], 
             104 -> RGBColor[
              0.9678512993182518, 0.9032170251058861, 0.32960879793445963`], 
             79 -> RGBColor[
              0.9766449846670698, 0.9821024483218042, 0.9244181283818057], 
             327 -> RGBColor[
              0.9555929086241652, 0.9664018444786168, 0.9600538018616454], 
             191 -> RGBColor[
              0.8350934472489794, 0.8713448631013163, 0.9841331525669704], 50 -> 
             RGBColor[
              0.7496673911593476, 0.8043651307476616, 0.9756834975768337], 
             225 -> RGBColor[
              0.9927073273268159, 0.9868100354913973, 0.44761576856180885`], 
             405 -> RGBColor[
              0.9793269819626084, 0.9841026775134493, 0.9198782065373833], 61 -> 
             RGBColor[
              0.97769601215333, 0.9828863029001574, 0.922639012999438], 196 -> 
             RGBColor[
              0.9939223764154301, 0.9894089026316362, 0.5798663634437078], 1 -> 
             RGBColor[
              0.8651719452938604, 0.8953286409832253, 0.9870020665618834], 
             263 -> RGBColor[
              0.9949234091340327, 0.9915500103967939, 0.6888225972057569], 
             201 -> RGBColor[
              0.86576896973332, 0.8958046920654535, 0.987059011285889], 371 -> 
             RGBColor[
              0.8830821278010609, 0.9096097343555138, 0.9887103557580288], 
             293 -> RGBColor[
              0.6737242112251345, 0.7450377413935094, 0.9681141911303577], 
             362 -> RGBColor[
              0.9917167894060963, 0.9908426937976879, 0.7869377660102386], 
             184 -> RGBColor[
              0.9583073189036626, 0.968426247220627, 0.9554590132900407], 106 -> 
             RGBColor[
              0.9525332499105367, 0.9641199560197239, 0.965233005977021], 206 -> 
             RGBColor[
              0.6497636160096362, 0.7263195423038938, 0.9657260229237697], 
             358 -> RGBColor[
              0.9806273209959229, 0.9850724682353855, 0.9176770717367182], 
             247 -> RGBColor[
              0.7285361871200685, 0.7878572735490779, 0.9735773366405275], 
             220 -> RGBColor[
              0.9870006520090628, 0.9888924497848118, 0.8650963676514272], 
             407 -> RGBColor[
              0.7135233875170174, 0.7761291603976713, 0.9720810010786841], 
             107 -> RGBColor[
              0.9929214014526985, 0.987267918400446, 0.4709164160517648], 375 -> 
             RGBColor[
              0.6556625065484896, 0.7309278004260747, 0.9663139692044164], 
             131 -> RGBColor[
              0.9933856203383783, 0.9882608356571863, 0.5214437769311456], 
             411 -> RGBColor[
              0.947459651539197, 0.9603360746616336, 0.9738212846133147], 462 -> 
             RGBColor[
              0.9951340609141146, 0.9920005732542271, 0.7117507434755771], 
             127 -> RGBColor[
              0.9488038949493312, 0.9613386091959151, 0.9715458311547893], 
             210 -> RGBColor[
              0.833765985403809, 0.8702863810589694, 0.9840065380711389], 357 -> 
             RGBColor[
              0.9585416234350258, 0.9686009911564792, 0.9550623968348517], 
             181 -> 
             RGBColor[
              0.9418457839609342, 0.9561492614136298, 0.9833240980921525], 
             194 -> RGBColor[
              0.9854686314820985, 0.9882589199257804, 0.8904859125252576], 
             440 -> RGBColor[
              0.8944491302406826, 0.9186734735518066, 0.9897945505981628], 
             490 -> RGBColor[
              0.9890067654763494, 0.9897220292582992, 0.8318498758432584], 
             118 -> RGBColor[
              0.7965709751155855, 0.8410065670147157, 0.9803584084866789], 
             348 -> RGBColor[
              0.9928672081454609, 0.9913184215108282, 0.7678723503107069], 
             276 -> RGBColor[
              0.9844256168626979, 0.9878276065764051, 0.9077713640040348], 
             305 -> RGBColor[
              0.7976046102166509, 0.8418140506115857, 0.9804614315736838], 
             343 -> RGBColor[
              0.9519940378248307, 0.9637178125290832, 0.9661457513890858], 
             280 -> RGBColor[
              0.9941707410143129, 0.9899401293951334, 0.6068993173034606], 
             474 -> RGBColor[
              0.5367579856522633, 0.6348033392810245, 0.9566747013212847], 
             189 -> RGBColor[
              0.988163542248631, 0.9893733347837892, 0.8458242669183142], 168 -> 
             RGBColor[
              0.4966655644272871, 0.6022545055875953, 0.9535184790590765], 
             363 -> RGBColor[
              0.9226274597451648, 0.9411421086183025, 0.992482224821392], 41 -> 
             RGBColor[
              0.9547517461863462, 0.9657745069097684, 0.9614776704585731], 14 -> 
             RGBColor[
              0.9934572962702221, 0.9884141432278518, 0.5292452597797648], 77 -> 
             RGBColor[
              0.5882092053751306, 0.6765737573030827, 0.9607251298098968], 51 -> 
             RGBColor[
              0.6459928462570554, 0.7233737883142661, 0.9653501878346793], 
             438 -> RGBColor[
              0.8069242427731497, 0.8490946183965533, 0.9813903254499977], 
             179 -> RGBColor[
              0.9729702187151218, 0.9793618138917183, 0.9306385486059949], 
             467 -> RGBColor[
              0.9227602290360675, 0.9412479752469418, 0.9924948884748829], 
             223 -> RGBColor[
              0.9949055299743514, 0.9921613199695559, 0.7340920825981923], 
             456 -> RGBColor[
              0.8378667793758742, 0.8735562428592071, 0.9843976754610165], 
             323 -> RGBColor[
              0.7920777116260727, 0.8374963954266408, 0.9799105619739789], 
             500 -> RGBColor[
              0.992597600257574, 0.9912069317205802, 0.7723404507358402], 478 -> 
             RGBColor[
              0.8572386140196244, 0.8890028179696902, 0.9862453783427784], 
             292 -> RGBColor[
              0.8857164018693365, 0.9117102329920921, 0.9889616151703052], 
             491 -> RGBColor[
              0.99075302918874, 0.9904441541803032, 0.8029097669433244], 396 -> 
             RGBColor[
              0.8611324106725154, 0.892107625726411, 0.9866167721435644], 321 -> 
             RGBColor[
              0.9471335517827149, 0.9600928699971887, 0.974373286440601], 143 -> 
             RGBColor[
              0.9599326654018971, 0.9696384279777497, 0.9527077256267887], 
             112 -> RGBColor[
              0.8419493065747642, 0.8768115392303534, 0.9847870705497617], 
             197 -> RGBColor[
              0.48837407043697356`, 0.5955230972387112, 0.9528657422794158], 
             421 -> RGBColor[
              0.9932838964776719, 0.9914907328445991, 0.7609667462911337], 54 -> 
             RGBColor[
              0.7712466065916848, 0.8212229778515151, 0.9778343121018955], 71 -> 
             RGBColor[
              0.8071258283376768, 0.849252098571669, 0.9814104176151456], 177 -> 
             RGBColor[
              0.7544627723665334, 0.8081113189929622, 0.9761614563601807], 
             158 -> RGBColor[
              0.9948735699447365, 0.9914434094104044, 0.6833979090226949], 
             226 -> RGBColor[
              0.989635504097029, 0.9899820288357958, 0.8214300497752052], 432 -> 
             RGBColor[
              0.9852977795359281, 0.9881882682553441, 0.8933173714239642], 
             350 -> RGBColor[
              0.8771250942003604, 0.9048597574616848, 0.9881421685752874], 
             203 -> RGBColor[
              0.9390969386517186, 0.9540991770828379, 0.9879771761869759], 
             475 -> RGBColor[
              0.7994317042992278, 0.8432413903953241, 0.9806435392366701], 
             115 -> RGBColor[
              0.6799085423794639, 0.7498689878939292, 0.9687305874639607], 
             173 -> RGBColor[
              0.7466586547509605, 0.8020146829981859, 0.975383614849886], 212 -> 
             RGBColor[
              0.9874561510989801, 0.9890808103642852, 0.8575475689376404], 
             129 -> RGBColor[
              0.9402130328969017, 0.9549315583434589, 0.9860879197538803], 
             279 -> RGBColor[
              0.970614746543619, 0.9776051066029432, 0.9346257485868165], 26 -> 
             RGBColor[
              0.9925602932245503, 0.9864955444140795, 0.4316120139195006], 40 -> 
             RGBColor[
              0.7014559759647863, 0.7667020067773437, 0.9708782342715303], 
             146 -> RGBColor[
              0.9937184813122848, 0.9889727916229654, 0.5576736397610498], 
             386 -> RGBColor[
              0.6841662762622314, 0.7531951619631232, 0.9691549585866096], 
             192 -> RGBColor[
              0.8983839944293445, 0.9218110274468025, 0.9901698614571721], 
             300 -> RGBColor[
              0.8602805627290112, 0.8914283852990572, 0.9865355221262593], 
             221 -> RGBColor[
              0.8330270624518451, 0.8696971839546026, 0.9839360589403363], 62 -> 
             RGBColor[
              0.8516406439929692, 0.8845391486232838, 0.9857114389642692], 
             286 -> RGBColor[
              0.7273014334977059, 0.786892674634813, 0.973454267938879], 472 -> 
             RGBColor[
              0.9252694201803718, 0.943248736155231, 0.992734217366208], 152 -> 
             RGBColor[
              0.7855131977731751, 0.8323681473126042, 0.9792562725819918], 64 -> 
             RGBColor[
              0.6859573265495887, 0.7545943440600931, 0.9693334737409369], 
             307 -> RGBColor[
              0.9888845617334545, 0.9896714948701193, 0.8338751081161766], 37 -> 
             RGBColor[
              0.9487328253846911, 0.9612856056309722, 0.9716661333898139], 
             148 -> RGBColor[
              0.9942971515604123, 0.9919097398607801, 0.7441744873500284], 
             261 -> RGBColor[
              0.9926052256706449, 0.9865916503729087, 0.436502633385988], 387 -> 
             RGBColor[
              0.9907542789997469, 0.9904446710092731, 0.802889054340533], 15 -> 
             RGBColor[
              0.9916227343659356, 0.9834036573201008, 0.4219563342358762], 
             136 -> RGBColor[
              0.8723805390034342, 0.9010765779351757, 0.9876896286650901], 
             198 -> RGBColor[
              0.9629320418969844, 0.9718753580567575, 0.9476305635832827], 63 -> 
             RGBColor[
              0.3163926416525105, 0.44846513666802024`, 0.9413812372444382], 
             444 -> RGBColor[
              0.9477627393432341, 0.9605621170496238, 0.9733082360190394], 
             310 -> RGBColor[
              0.9885946554983452, 0.9895516111916512, 0.8386796046852223], 
             171 -> RGBColor[
              0.6199384357302871, 0.7023329758909369, 0.9632229710514552], 
             395 -> RGBColor[
              0.9406683000497367, 0.9552710958406117, 0.9853172712168212], 
             311 -> RGBColor[
              0.9481291321271571, 0.9608353721879604, 0.9726880286064005], 
             353 -> 
             RGBColor[
              0.9584675630011221, 0.8715634791021433, 0.29315475431232324`], 
             59 -> RGBColor[
              0.9945995983812594, 0.9908574119389011, 0.6535777950947123], 
             397 -> RGBColor[
              0.8887602948589268, 0.9141373506377173, 0.9892519444009676], 
             229 -> RGBColor[
              0.9938602449391691, 0.9892760096863696, 0.573103735683717], 102 -> 
             RGBColor[
              0.5741711725063424, 0.6651770498140265, 0.9596200044394569], 
             453 -> RGBColor[
              0.9946637713943844, 0.9909946715250885, 0.6605626315434371], 
             299 -> RGBColor[
              0.9898233134893127, 0.9900596928459863, 0.8183175621099382], 
             128 -> RGBColor[
              0.9929344266739577, 0.9872957780316677, 0.47233413100348665`], 
             12 -> RGBColor[
              0.9908131812038222, 0.9904690285843759, 0.8019128923849871], 
             222 -> RGBColor[
              0.9945194907736236, 0.9906860698662895, 0.6448585763703963], 
             483 -> RGBColor[
              0.9933291263245245, 0.9915094365486267, 0.7602171706776957], 92 -> 
             RGBColor[
              0.9936758826571025, 0.9916528292033789, 0.7544705208702553], 
             271 -> RGBColor[
              0.9031717907550738, 0.92562868627567, 0.9906265257448365], 361 -> 
             RGBColor[
              0.9518448803812244, 0.9636065711518644, 0.9663982360346197], 
             344 -> RGBColor[
              0.993403790522035, 0.9882996998427405, 0.5234214892887967], 132 -> 
             RGBColor[
              0.9768739011663746, 0.9336523797472633, 0.36465990233902684`], 
             80 -> RGBColor[
              0.6486766629360077, 0.725470406301626, 0.9656176855995444], 324 -> 
             RGBColor[
              0.9679724959487042, 0.9036258497987241, 0.33007962395770396`], 
             244 -> RGBColor[
              0.8851031863992265, 0.9112212716215169, 0.9889031261313422], 
             150 -> RGBColor[
              0.5958013100427445, 0.6827373698926692, 0.961322808100127], 125 -> 
             RGBColor[
              0.9646698635466248, 0.9731714225976374, 0.9446888848269184], 
             258 -> RGBColor[
              0.5378197927389929, 0.6356653621078958, 0.9567582906646795], 
             133 -> RGBColor[
              0.8558420801983407, 0.8878892598084993, 0.9861121757002038], 
             469 -> RGBColor[
              0.8620736653972622, 0.8928581566942452, 0.9867065498594787], 
             255 -> RGBColor[
              0.86883423868994, 0.8982488543269532, 0.9873513793753694], 408 -> 
             RGBColor[
              0.48837407043697356`, 0.5955230972387112, 0.9528657422794158], 
             326 -> RGBColor[
              0.7287732301851793, 0.7880424533931364, 0.9736009628779643], 
             176 -> RGBColor[
              0.9596600549547926, 0.9694351155526577, 0.953169184005545], 230 -> 
             RGBColor[
              0.7544627723665334, 0.8081113189929622, 0.9761614563601807], 
             274 -> RGBColor[
              0.9859812004872762, 0.9884708803818439, 0.881991317623399], 87 -> 
             RGBColor[
              0.9779537473621527, 0.9372949545255669, 0.3688549008977814], 
             439 -> RGBColor[
              0.923935707451921, 0.9421852698282319, 0.992607006655549], 130 -> 
             RGBColor[
              0.9756408169345582, 0.9294928970914004, 0.3598696029468381], 35 -> 
             RGBColor[
              0.9604929680809325, 0.9700563007983628, 0.9517592793415248], 
             379 -> RGBColor[
              0.9419185647700974, 0.956203541221936, 0.9832008991665144], 31 -> 
             RGBColor[
              0.984485226989237, 0.9878522568956394, 0.9067834699412197], 18 -> 
             RGBColor[
              0.6795349410042503, 0.7495771276601367, 0.9686933503703827], 24 -> 
             RGBColor[
              0.9717096870432149, 0.9784217114347413, 0.9327722999272196], 
             151 -> RGBColor[
              0.7591082979109951, 0.8117404388555975, 0.9766244789315482], 
             137 -> RGBColor[
              0.9664302750684125, 0.9744843346281775, 0.9417089673093907], 
             330 -> RGBColor[
              0.984485226989237, 0.9878522568956394, 0.9067834699412197], 296 -> 
             RGBColor[
              0.6599206935374865, 0.7342543284652988, 0.9667383854884597], 
             266 -> RGBColor[
              0.723869401775705, 0.7842115453691788, 0.9731121950909899], 302 -> 
             RGBColor[
              0.6837496315183789, 0.7528696759226082, 0.9691134313323089], 
             442 -> RGBColor[
              0.9925626409644364, 0.986500565992303, 0.43186755091753276`], 
             283 -> RGBColor[
              0.9901312767504934, 0.9901870435687793, 0.8132138138888023], 
             388 -> RGBColor[
              0.9946467959199495, 0.9920543267888989, 0.7383799754619004], 
             284 -> RGBColor[
              0.6082154271343841, 0.6928157093972641, 0.9623000928719901], 
             417 -> RGBColor[
              0.94734781663536, 0.9602526683734649, 0.9740105919342963], 318 -> 
             RGBColor[
              0.9811248261160308, 0.9479917477670972, 0.3811739430486232], 
             413 -> RGBColor[
              0.9704919144772539, 0.9775134986489672, 0.9348336712354388], 
             238 -> RGBColor[
              0.9940944543806192, 0.9918259193678557, 0.747533704182688], 72 -> 
             RGBColor[
              0.9752288084992027, 0.9810462664545846, 0.926815345236105], 437 -> 
             RGBColor[
              0.9793253636818458, 0.9841014706023062, 0.9198809458645992], 
             288 -> RGBColor[
              0.9936685429022991, 0.9916497940261446, 0.7545921596020237], 
             382 -> RGBColor[
              0.9113534823015472, 0.9321525450287271, 0.9914069027884214], 
             461 -> RGBColor[
              0.812264949975467, 0.8532668194538818, 0.9819226372321783], 389 -> 
             RGBColor[
              0.9947162726363656, 0.9911069663729966, 0.6662770677329873], 
             172 -> RGBColor[
              0.7518849022064912, 0.8060974672313983, 0.975904518354194], 447 -> 
             RGBColor[
              0.9893814917973358, 0.9898769882220543, 0.8256396909438819], 
             243 -> RGBColor[
              0.6340781710752995, 0.7138122500318363, 0.9643361028133717], 
             410 -> RGBColor[
              0.9899402662901301, 0.9901080558346742, 0.8163793515362474], 88 -> 
             RGBColor[
              0.9420823738124707, 0.9563257097375254, 0.9829236131860171], 
             273 -> RGBColor[
              0.9944029166392258, 0.9904367295802655, 0.6321702012533567], 
             477 -> RGBColor[
              0.9447996795859107, 0.958352271934177, 0.9783239232984334], 202 -> 
             RGBColor[
              0.8679471942205499, 0.8975415491452421, 0.987266772282005], 393 -> 
             RGBColor[
              0.8984995834070457, 0.9219031949600422, 0.9901808864370528], 98 -> 
             RGBColor[
              0.9478625820657655, 0.9606365795886103, 0.9731392283329464], 30 -> 
             RGBColor[
              0.9930033643615552, 0.9874432287747693, 0.47983757286438267`], 
             116 -> RGBColor[
              0.986850633187647, 0.9888304131468485, 0.8675825677585534], 373 -> 
             RGBColor[
              0.8286502316610642, 0.8662072178879408, 0.9835185929122686], 
             434 -> RGBColor[
              0.9933517874459469, 0.991518807504699, 0.7598416172506238], 401 -> 
             RGBColor[
              0.988163542248631, 0.9893733347837892, 0.8458242669183142], 240 -> 
             RGBColor[
              0.8995724628778611, 0.922758679927533, 0.9902832186387499], 480 -> R\
GBColor[0.9445958286219547, 0.9582002402190339, 0.9786689898075644], 403 -> 
             RGBColor[
              0.9630729699825319, 0.9719804619922102, 0.9473920090943823], 
             317 -> RGBColor[
              0.9377495019604223, 0.9530942610046942, 0.9902580350375678], 
             429 -> RGBColor[
              0.9226274597451648, 0.9411421086183025, 0.992482224821392], 391 -> 
             RGBColor[
              0.8968897422058019, 0.9206195512841457, 0.990027338346156], 73 -> 
             RGBColor[
              0.7679191992234334, 0.8186235819262044, 0.977502667231818], 303 -> 
             RGBColor[
              0.9931167797715873, 0.987685812868771, 0.49218214032759877`], 
             449 -> RGBColor[
              0.8499757566540627, 0.8832116126514026, 0.9855526405236218], 29 -> 
             RGBColor[
              0.9752545975785547, 0.9810654999077395, 0.9267716910516313], 
             360 -> RGBColor[
              0.9527002526598649, 0.964244506396731, 0.9649503138837012], 320 -> 
             RGBColor[
              0.9893147997043077, 0.9898494093276786, 0.8267449515189618], 
             482 -> RGBColor[
              0.7243142958420646, 0.7845590999951391, 0.9731565379737532], 75 -> 
             RGBColor[
              0.8382948846961178, 0.87389760242096, 0.9844385085286355], 200 -> 
             RGBColor[
              0.9811588535791816, 0.9854688843656753, 0.9167773257191613], 
             301 -> RGBColor[
              0.90421157810116, 0.9264577844811636, 0.9907257015901353], 156 -> 
             RGBColor[
              0.9934058105077948, 0.9883040203880288, 0.5236413522728396], 25 -> 
             RGBColor[
              0.9650933446024063, 0.9734872540756527, 0.9439720418610288], 38 -> 
             RGBColor[
              0.9444984518804947, 0.9581276168046929, 0.9788338232309344], 
             365 -> RGBColor[
              0.5367579856522633, 0.6348033392810245, 0.9566747013212847], 
             380 -> RGBColor[
              0.7562757709325776, 0.8095276472520553, 0.9763421591138092], 
             370 -> RGBColor[
              0.7237891914025989, 0.7841488844160869, 0.9731042004706072], 3 -> 
             RGBColor[
              0.7469699892303052, 0.8022578998596798, 0.975414645761201], 57 -> 
             RGBColor[
              0.7033976814587534, 0.768218881866739, 0.9710717653288995], 227 -> 
             RGBColor[
              0.9587117759846884, 0.9687278906494183, 0.9547743729511653], 
             494 -> RGBColor[
              0.9932870678550827, 0.9914920442906591, 0.7609141883601754], 39 -> 
             RGBColor[
              0.9876001825927941, 0.9891403710884179, 0.8551605943435846], 
             424 -> RGBColor[
              0.5463603645423613, 0.6425989830462453, 0.9574306357621861], 
             109 -> RGBColor[
              0.9925602932245503, 0.9864955444140795, 0.4316120139195006], 
             465 -> RGBColor[
              0.9878351158754166, 0.9892375220382923, 0.8512671418626839], 
             256 -> RGBColor[
              0.9896859557002902, 0.9900028918702913, 0.8205939361446041], 
             457 -> RGBColor[
              0.4882868028765106, 0.5954522495017686, 0.9528588722573845], 
             339 -> RGBColor[
              0.7025128092886838, 0.7675276130022032, 0.9709835695405875], 
             420 -> RGBColor[
              0.8330654135534501, 0.8697277640820095, 0.9839397169026438], 
             287 -> RGBColor[
              0.5882092053751306, 0.6765737573030827, 0.9607251298098968], 
             239 -> RGBColor[
              0.9600249802927022, 0.8768170133256127, 0.29920502639653446`], 
             427 -> RGBColor[
              0.9835524906040738, 0.9561808301279947, 0.3906049611586993], 
             285 -> RGBColor[
              0.9571017988935335, 0.9675271723709306, 0.9574996442172149], 
             345 -> RGBColor[
              0.9944662176901804, 0.9919796530502405, 0.741372624050653], 366 -> 
             RGBColor[
              0.5525192101092967, 0.6475990113303145, 0.95791548264581], 216 -> 
             RGBColor[
              0.9877679243412415, 0.9892097366121672, 0.8523806794700828], 21 -> 
             RGBColor[
              0.9311081181249247, 0.9479043554089838, 0.9932911175884267], 
             355 -> RGBColor[
              0.49768519745268, 0.6030822896115535, 0.9535987483058743], 175 -> 
             RGBColor[
              0.9677585960449483, 0.9754749942375519, 0.9394604663777116], 7 -> 
             RGBColor[
              0.8697433308684857, 0.8989737397534756, 0.9874380893989152], 13 -> 
             RGBColor[
              0.954677573248701, 0.9657191888543196, 0.961603225894606], 294 -> 
             RGBColor[
              0.771246606591685, 0.8212229778515152, 0.9778343121018955], 412 -> 
             RGBColor[
              0.9947749517754976, 0.9912324751182288, 0.6726639299018309], 
             193 -> RGBColor[
              0.9866066975064739, 0.9887295394738224, 0.8716252132808979], 60 -> 
             RGBColor[
              0.6849297448623349, 0.7537915894361003, 0.9692310540016482], 65 -> 
             RGBColor[
              0.9538691599730251, 0.9651162755569759, 0.9629716587023747], 
             448 -> 
             RGBColor[
              0.8679049538266568, 0.8975078678017367, 0.987262743355527], 69 -> 
             RGBColor[
              0.3654372330530195, 0.4909450966863027, 0.9445063152400494], 
             217 -> RGBColor[
              0.7919500786297862, 0.8373966875598952, 0.9798978407097072], 
             214 -> RGBColor[
              0.9885415580460107, 0.9895296540305686, 0.8395595668822073], 
             170 -> RGBColor[
              0.6737242112251345, 0.7450377413935094, 0.9681141911303577], 
             359 -> RGBColor[
              0.636714318529332, 0.7159523932921094, 0.9645436299974794], 74 -> 
             RGBColor[
              0.7287732301851793, 0.7880424533931364, 0.9736009628779643], 
             246 -> RGBColor[
              0.9719335281305076, 0.9169873414425315, 0.34546748600584776`], 
             264 -> RGBColor[
              0.9825368570323435, 0.9864965970847698, 0.9144447253138195], 
             278 -> RGBColor[
              0.766126875979226, 0.8172234053856684, 0.9773240252010483], 45 -> 
             RGBColor[
              0.36155641445050807`, 0.48758372666842176`, 0.9442590329103705],
              492 -> RGBColor[
              0.7065089602946721, 0.7706494365399538, 0.97138186852671], 306 -> 
             RGBColor[
              0.8414529847123758, 0.8764157856495829, 0.9847397309274554], 
             237 -> RGBColor[
              0.3832697667572377, 0.5063907410916917, 0.9456425885189917], 
             228 -> RGBColor[
              0.9703373587703671, 0.9116030873923893, 0.3392666694529933], 
             180 -> RGBColor[
              0.9917167894060963, 0.9908426937976879, 0.7869377660102386], 
             383 -> RGBColor[
              0.9802187845732576, 0.9847677824402787, 0.9183686173369264], 53 -> 
             RGBColor[
              0.9924920604098726, 0.9911632882813053, 0.7740895191406236], 
             304 -> RGBColor[
              0.9559576077058712, 0.9666738364566132, 0.9594364614450714], 48 -> 
             RGBColor[
              0.955383689504028, 0.9662458092013833, 0.9604079552589518], 5 -> 
             RGBColor[
              0.6299258488725569, 0.7104412078076663, 0.9640092167991144], 
             101 -> RGBColor[
              0.9942348541077048, 0.9900772608190707, 0.6138776318590218], 
             333 -> RGBColor[
              0.8560073502758229, 0.43150261356316644`, 0.20126600791636998`],
              267 -> RGBColor[
              0.290508767512353, 0.42267351234815814`, 0.9398554165893962], 
             120 -> RGBColor[
              0.9576671756633754, 0.9679488294401591, 0.9565426088197504], 
             147 -> RGBColor[
              0.9402319079861569, 0.9549456353541202, 0.986055969151183], 89 -> 
             RGBColor[
              0.9700520323307753, 0.9771854352643644, 0.9355782769697889], 43 -> 
             RGBColor[
              0.9804223547507619, 0.9849196047453458, 0.9180240261260173], 
             199 -> RGBColor[
              0.8880736540869013, 0.9135898419244713, 0.9891864519911604], 
             268 -> RGBColor[
              0.7065089602946721, 0.7706494365399538, 0.97138186852671], 169 -> 
             RGBColor[
              0.8193344470552547, 0.8587895643027798, 0.9826272586328851], 20 -> 
             RGBColor[
              0.8272942985914463, 0.8651260336640502, 0.9833892628056328], 4 -> 
             RGBColor[
              0.9948751846415869, 0.9914468630836963, 0.6835736588100984], 
             167 -> RGBColor[
              0.9858151537180575, 0.9884022157755646, 0.8847431423046167], 
             431 -> RGBColor[
              0.8976368683175733, 0.9212152893654743, 0.990098599901664], 142 -> 
             RGBColor[
              0.9939983828853636, 0.9895714727853908, 0.5881391986383996], 16 -> 
             RGBColor[
              0.8072119656455807, 0.8493193896912713, 0.9814190029769985], 
             414 -> RGBColor[
              0.9420823738124707, 0.9563257097375254, 0.9829236131860171], 
             281 -> RGBColor[
              0.9848671136857836, 0.988010176858702, 0.9004546190883516], 289 -> 
             RGBColor[
              0.8985727882169484, 0.921961566488367, 0.990187868777172], 398 -> 
             RGBColor[
              0.9466323249186603, 0.9597190558226604, 0.9752217327805424], 
             178 -> RGBColor[
              0.8927724771455312, 0.9173365558852689, 0.9896346299291814], 58 -> 
             RGBColor[
              0.985809662186728, 0.988399944886234, 0.8848341511903742], 186 -> 
             RGBColor[
              0.9740873392720573, 0.9801949605739637, 0.9287475548948076], 
             122 -> RGBColor[
              0.7397769174195259, 0.7966386174917284, 0.9746977075861804], 
             249 -> RGBColor[
              0.9942114689592696, 0.9900272423511689, 0.611332302768257], 113 -> 
             RGBColor[
              0.8901676786270138, 0.9152595602519752, 0.9893861819211541], 52 -> 
             RGBColor[
              0.441925975419167, 0.5571958008878863, 0.9493801102672811], 409 -> 
             RGBColor[
              0.8844874487503994, 0.9107302991340954, 0.9888443965247216], 
             187 -> 
             RGBColor[
              0.9650780585811742, 0.8938622329118328, 0.3188352813534827], 
             259 -> RGBColor[
              0.985809662186728, 0.988399944886234, 0.8848341511903742], 42 -> 
             RGBColor[
              0.827196711646282, 0.8650482204829032, 0.9833799548756861], 134 -> 
             RGBColor[
              0.8536338266901494, 0.8861284584025122, 0.9859015505092613], 
             470 -> RGBColor[
              0.9906644304987849, 0.9904075163451243, 0.8043780765219388], 
             313 -> RGBColor[
              0.8339010588491835, 0.8703940849578401, 0.9840194214969402], 
             248 -> RGBColor[
              0.6145491603444041, 0.6979577193485877, 0.9627987075515122], 
             174 -> RGBColor[
              0.9630729699825319, 0.9719804619922102, 0.9473920090943823], 
             215 -> RGBColor[
              0.7320353942717003, 0.7905908807708919, 0.9739261049074521], 
             399 -> RGBColor[
              0.5958013100427445, 0.6827373698926692, 0.961322808100127], 422 -> 
             RGBColor[
              0.8713085130899209, 0.9002217735711084, 0.9875873778764503], 83 -> 
             RGBColor[
              0.989846916208752, 0.9900694531770367, 0.8179264039669489], 95 -> 
             RGBColor[
              0.9820494661742304, 0.9511107757992143, 0.38476599507110504`], 
             166 -> RGBColor[
              0.988163542248631, 0.9893733347837892, 0.8458242669183142], 384 -> 
             RGBColor[
              0.9814774134983455, 0.9857064658317936, 0.9162380868697505], 
             233 -> RGBColor[
              0.6542467979194797, 0.7298218380853081, 0.966172864598826], 295 -> 
             RGBColor[
              0.8905306390579304, 0.9155489750472896, 0.9894208014110736], 
             499 -> RGBColor[
              0.9661143295264513, 0.9742487029602961, 0.9422437807001365], 
             141 -> RGBColor[
              0.9952659412793645, 0.9922826520203465, 0.7261051073617646], 
             319 -> RGBColor[
              0.8261040258721478, 0.8641769425067738, 0.9832757335310971], 
             205 -> RGBColor[
              0.6728453842202256, 0.7443511950579419, 0.9680265978676136], 
             468 -> RGBColor[
              0.8482993767184253, 0.8818749127948465, 0.9853927459088386], 
             486 -> RGBColor[
              0.9815145972008043, 0.9857341973762046, 0.9161751445605505], 
             224 -> RGBColor[
              0.9948783744916911, 0.9914536858505262, 0.6839208543084788], 
             231 -> RGBColor[
              0.97769601215333, 0.9828863029001574, 0.922639012999438], 332 -> 
             RGBColor[
              0.9548203864752497, 0.9658256987248445, 0.9613614803537139], 68 -> 
             RGBColor[
              0.9945218889707366, 0.9906911993674193, 0.645119605326194], 484 -> 
             RGBColor[
              0.988899061493964, 0.9896774908937168, 0.8336348095603567], 10 -> 
             RGBColor[
              0.9803567078423331, 0.9848706453885266, 0.9181351492185315], 
             250 -> RGBColor[
              0.46789673737428994`, 0.5788986757650828, 0.9512536916097788], 
             282 -> RGBColor[
              0.9889006858384197, 0.989678162601893, 0.8336078899690557], 374 -> 
             RGBColor[
              0.8357223174363426, 0.27558296220085116`, 0.18184103756061584`],
              232 -> RGBColor[
              0.8088048950431237, 0.8505637982433437, 0.9815777712925741], 
             489 -> RGBColor[
              0.868631086312147, 0.8980868661353254, 0.9873320025202192], 253 -> 
             RGBColor[
              0.93610608547751, 0.9518686036825857, 0.9930399104714723], 459 -> 
             RGBColor[
              0.9919722766355427, 0.9909483443327862, 0.7827036814385585], 
             415 -> RGBColor[
              0.9833351832692131, 0.9870919874850879, 0.9130933672316287], 55 -> 
             RGBColor[
              0.969041747361065, 0.9072326858847877, 0.3342334637835394], 446 -> 
             RGBColor[
              0.930777136828045, 0.9476404399070999, 0.9932595482968598], 325 -> 
             RGBColor[
              0.9888970265152297, 0.9896766493777136, 0.8336685344243395], 91 -> 
             RGBColor[
              0.9942851019158863, 0.9901847357999382, 0.6193467956860482], 
             450 -> RGBColor[
              0.9935723948258787, 0.9886603274001523, 0.5417730272570399], 
             423 -> RGBColor[
              0.9908779045036394, 0.9904957933321633, 0.8008402598084848], 
             105 -> RGBColor[
              0.9205807487103161, 0.9395101167956051, 0.9922870076957677], 36 -> 
             RGBColor[
              0.6449814452189991, 0.722583674136404, 0.9652493808312859], 123 -> 
             RGBColor[
              0.9552086770320903, 0.9661152851863688, 0.9607042057233792], 94 -> 
             RGBColor[
              0.9910017415791091, 0.9905470031453376, 0.798787958987875], 473 -> 
             RGBColor[
              0.8262136413471683, 0.8642643469111224, 0.9832861887529594], 
             312 -> RGBColor[
              0.90421157810116, 0.9264577844811636, 0.9907257015901353], 96 -> 
             RGBColor[
              0.6380161197412002, 0.7170092541613803, 0.9646461125575326], 
             496 -> RGBColor[
              0.8802492060799879, 0.9073508394727419, 0.9884401491552939], 2 -> 
             RGBColor[
              0.7319844229578485, 0.7905510615931146, 0.9739210245632414], 
             262 -> RGBColor[
              0.9559295742819792, 0.8629824781665075, 0.28339810488267797`], 
             272 -> RGBColor[
              0.9949038607430347, 0.9915081983650949, 0.6866948754843184], 97 -> 
             RGBColor[
              0.9130497705428943, 0.9335051192278595, 0.9915686962751754], 
             372 -> RGBColor[
              0.9886932872504072, 0.973521944332531, 0.41057598537171713`], 
             356 -> RGBColor[
              0.9016805731002956, 0.9244396297957748, 0.9904842920736979], 
             402 -> RGBColor[
              0.9900442243353011, 0.9901510451579524, 0.8146564976929663], 
             455 -> RGBColor[
              0.9947694504925411, 0.9912207084302499, 0.672065149202], 428 -> 
             RGBColor[
              0.7544627723665334, 0.8081113189929622, 0.9761614563601807], 
             346 -> RGBColor[
              0.9775603406458642, 0.9827851193120312, 0.9228686694727813], 
             341 -> RGBColor[
              0.9007427147997358, 0.9236918070443937, 0.9903948383117546], 
             209 -> RGBColor[
              0.9648618760545998, 0.9733146252116937, 0.9443638577357992], 
             498 -> RGBColor[
              0.7204555056930733, 0.7815445838028556, 0.972771929834146], 378 -> 
             RGBColor[
              0.937468366562731, 0.952884590685413, 0.9907339239340041], 419 -> 
             RGBColor[
              0.8152030853643605, 0.8555621131503413, 0.982215483109307], 66 -> 
             RGBColor[
              0.9898878553089081, 0.9900863825470382, 0.8172479371303668], 
             139 -> RGBColor[
              0.9943932392339199, 0.9904160305888519, 0.6311168754078307], 56 -> 
             RGBColor[
              0.9344004786602012, 0.9505295943310672, 0.9936051458754063], 
             335 -> RGBColor[
              0.8322294863261052, 0.8690612184015647, 0.9838599854174586], 
             314 -> RGBColor[
              0.9562573385524452, 0.9668973752312239, 0.9589290953041465], 
             144 -> RGBColor[
              0.8433401549624661, 0.877920563981133, 0.9849197309106057], 298 -> 
             RGBColor[
              0.924821190251057, 0.9428913297764727, 0.9926914647954104], 204 -> 
             RGBColor[
              0.8421116754884682, 0.8769410077947541, 0.9848025574416992], 
             452 -> 
             RGBColor[
              0.8222000511876362, 0.861064019063914, 0.982903368940569], 466 -> 
             RGBColor[
              0.9580098223252544, 0.9682043747595561, 0.9559625973977515], 
             207 -> RGBColor[
              0.9654836973111163, 0.8952305475964303, 0.32041111122086086`], 
             334 -> RGBColor[
              0.9935734332388126, 0.9886625484604183, 0.5418860520965578], 
             149 -> RGBColor[
              0.9325214751031845, 0.7701771652092314, 0.26456339882471325`], 
             219 -> RGBColor[
              0.9725244515783884, 0.9790293614910193, 0.9313931160937952], 
             400 -> RGBColor[
              0.9561925436448618, 0.96684905129524, 0.9590387761814667], 9 -> 
             RGBColor[
              0.8791600073517527, 0.906482341972359, 0.9883362604082556], 11 -> 
             RGBColor[
              0.8128686034633138, 0.8537383981465241, 0.9819828037703843], 44 -> 
             RGBColor[
              0.7244916398216205, 0.7846976424598322, 0.9731742139642616], 
             153 -> RGBColor[
              0.9948132585031432, 0.9913144093352584, 0.6768333808043326], 
             471 -> RGBColor[
              0.9529955235176163, 0.9644647189189803, 0.9644504973405016], 
             406 -> RGBColor[
              0.9900442243353011, 0.9901510451579524, 0.8146564976929663], 32 -> 
             RGBColor[
              0.9949321191048256, 0.9915686401436067, 0.6897706237748528], 
             162 -> RGBColor[
              0.9625233097659216, 0.9715705263026483, 0.9483224404667593], 
             493 -> RGBColor[
              0.9875175565343083, 0.9891062030898411, 0.8565299219620809], 90 -> 
             RGBColor[
              0.8971534094264104, 0.920829792368803, 0.9900524871610361], 331 -> 
             RGBColor[
              0.8382735323440975, 0.8738805766350533, 0.9844364719222383], 8 -> 
             RGBColor[
              0.7544627723665334, 0.8081113189929622, 0.9761614563601807], 
             364 -> RGBColor[
              0.9888354813840521, 0.989651198884334, 0.834688496521646], 342 -> 
             RGBColor[
              0.7378121431749148, 0.7951037209190008, 0.9745018772513367], 
             163 -> RGBColor[
              0.3520062125901088, 0.4793118218240462, 0.9436505024927377], 49 -> 
             RGBColor[
              0.8769548236747068, 0.9047239883663989, 0.9881259280205482], 
             338 -> RGBColor[
              0.9916213952013383, 0.9908032458425011, 0.7885186948553687], 76 -> 
             RGBColor[
              0.6590815764449669, 0.7335988038150965, 0.9666547501386724], 
             369 -> RGBColor[
              0.9625151777326996, 0.9715644614455863, 0.9483362058778302], 
             445 -> RGBColor[
              0.9898358753441167, 0.9900648874957727, 0.8181093796667993], 82 -> 
             RGBColor[
              0.7065089602946721, 0.7706494365399538, 0.97138186852671], 67 -> 
             RGBColor[
              0.9688155881506327, 0.9762632972193056, 0.9376712544504806], 
             430 -> RGBColor[
              0.944741292643148, 0.9583087270478644, 0.9784227571627772], 211 -> 
             RGBColor[
              0.6539432468021187, 0.7295847016453517, 
               0.9661426094602938]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9V3c41W/cPkZ2skfWMY5xzsFxzjFCvnekUipFSBqEZKVlFlIpoUVlJUVG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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 54}], {
             RGBColor[
             0.8182092759427726, 0.8582758094173701, 0.9824181893318895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 70}], {
             RGBColor[
             0.8808952541962134, 0.9078659807041112, 0.9885017698013534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 84}], {
             RGBColor[
             0.7585936444925792, 0.8117036250328986, 0.9764762603286847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 131}], {
             RGBColor[
             0.9292787828161193, 0.9417947383202058, 0.7542229217465145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 135}], {
             RGBColor[
             0.9256190916034003, 0.9419173432629717, 0.9337920469861143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 147}], {
             RGBColor[
             0.9027019266400087, 0.9251371381686728, 0.9865290178565331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 170}], {
             RGBColor[
             0.7694480782594975, 0.8201831911883674, 0.9775581288461206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 171}], {
             RGBColor[
             0.7425551905120737, 0.7988308084370811, 0.9751125188066693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 265}], {
             RGBColor[
             0.9301387922181896, 0.9437863556181947, 0.8588889111888075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 266}], {
             RGBColor[
             0.7945206735347827, 0.839770093176202, 0.9800571308264366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 374}], {
             RGBColor[
             0.8504471313651015, 0.5854558015920382, 0.5844215520612497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 385}], {
             RGBColor[
             0.8254083394835067, 0.863899772570301, 0.983135724706556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 391}], {
             RGBColor[
             0.8810308437498311, 0.9079740961336855, 0.9885147024540197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 433}], {
             RGBColor[
             0.901624575620463, 0.924333651542296, 0.9883526921144761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 47}], {
             RGBColor[
             0.836098727927375, 0.8727413099682868, 0.9800044721585608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 54}], {
             RGBColor[
             0.7516155147747666, 0.8058870197223149, 0.9758776683325685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 55}], {
             RGBColor[
             0.8505130851594567, 0.8488918737389511, 0.6540772441733904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 230}], {
             RGBColor[
             0.7432235976621909, 0.7993311902930385, 0.975041240461711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 242}], {
             RGBColor[
             0.8633970153967208, 0.8909288312598111, 0.8251785263670226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 250}], {
             RGBColor[
             0.5999405801660692, 0.6847248686790988, 0.9625873580865101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 339}], {
             RGBColor[
             0.7172486161232661, 0.779039337297659, 0.9724522970519145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 365}], {
             RGBColor[
             0.6343712043050559, 0.7126772004370696, 0.965297862942263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 8}], {
             RGBColor[
             0.7507163807984193, 0.805184609426321, 0.9757880510606909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 31}], {
             RGBColor[
             0.8657276081097711, 0.8950550783776596, 0.9410990578512104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[
             0.8547466494981134, 0.886914213081164, 0.9618685431139802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 203}], {
             RGBColor[
             0.843033463941012, 0.8781785384712588, 0.9816959109740884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 221}], {
             RGBColor[
             0.7899985258410751, 0.8359775419071411, 0.9796753523507686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 223}], {
             RGBColor[
             0.8709377596023283, 0.8972096099146178, 0.8547533641796966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 258}], {
             RGBColor[
             0.6423948909846491, 0.7189616309837878, 0.9660864682129402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 381}], {
             RGBColor[
             0.8378214647222612, 0.8741102552519044, 0.9842367469532977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 439}], {
             RGBColor[
             0.8354528483411131, 0.8722215848439558, 0.984010826208375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 480}], {
             RGBColor[
             0.84578290892613, 0.8802290700393569, 0.9770418177843827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 29}], {
             RGBColor[
             0.9850648911100708, 0.9862561814957179, 0.8051726749308648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 185}], {
             RGBColor[
             0.8284172307495644, 0.8636468741662149, 0.8252576156161284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 196}], {
             RGBColor[
             0.9943987805285085, 0.9904278828576663, 0.631720011126903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 318}], {
             RGBColor[
             0.9880000053788088, 0.9697193054253967, 0.5323738009293608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 321}], {
             RGBColor[
             0.9710043682121509, 0.9757698665404425, 0.8289734726253497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 335}], {
             RGBColor[
             0.913552335483846, 0.9302540407426305, 0.8337168221137785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 383}], {
             RGBColor[
             0.9875469846074223, 0.9881073227619875, 0.8009711380735124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 479}], {
             RGBColor[
             0.9613977823448105, 0.9684047013395063, 0.8382803635475119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 482}], {
             RGBColor[
             0.8595947402418258, 0.8880029815394177, 0.8283650983919257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 496}], {
             RGBColor[
             0.9375621953607873, 0.9493988512782191, 0.8360069039826961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.7213972261679353, 0.7820898029770952, 0.9729960102847494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 23}], {
             RGBColor[
             0.7914781265494184, 0.837465970351028, 0.9642003350990973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 41}], {
             RGBColor[
             0.7923387975294516, 0.8381078573587173, 0.9627434436288438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 102}], {
             RGBColor[
             0.6020485106894496, 0.6878091288108463, 0.9618146106192857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 186}], {
             RGBColor[
             0.8020065940723071, 0.845318084190815, 0.946378385846961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 193}], {
             RGBColor[
             0.8082662731895154, 0.8495853736407444, 0.9178172150400061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 202}], {
             RGBColor[
             0.7489365215465533, 0.8039913784764542, 0.9756379945405598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 211}], {
             RGBColor[
             0.6419345478373377, 0.7200129547265091, 0.9650759131297042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 212}], {
             RGBColor[
             0.8086909999857685, 0.8497610090859757, 0.9107783928683775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 300}], {
             RGBColor[
             0.745103205800784, 0.8009347965533617, 0.9752723694626868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 414}], {
             RGBColor[
             0.7860041113425138, 0.8333834587725959, 0.9734664149925658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 485}], {
             RGBColor[
             0.6555677914466892, 0.7306633482506234, 0.9664347474427792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 24}], {
             RGBColor[
             0.9685913076374444, 0.9760960291797953, 0.9380509028575823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 77}], {
             RGBColor[
             0.7768410668034023, 0.825172052113966, 0.9520273177989209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 79}], {
             RGBColor[
             0.9710589564493719, 0.9779363976233267, 0.9338738170848753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 80}], {
             RGBColor[
             0.8070747955838408, 0.8496203766132376, 0.9544735956937447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 81}], {
             RGBColor[
             0.7104101509617782, 0.7712404419550813, 0.9467976327594054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 99}], {
             RGBColor[
             0.8560657914913172, 0.8878925149615176, 0.9593565603189155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 156}], {
             RGBColor[
             0.9794393693697343, 0.9810371836564391, 0.7334854290303923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 267}], {
             RGBColor[
             0.6279908478720134, 0.6982219296365038, 0.9415924611886706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 278}], {
             RGBColor[
             0.8657999021054499, 0.8954968761552589, 0.9603267654944967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 329}], {
             RGBColor[
             0.9212990112160171, 0.939315052193267, 0.9657358371816162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 406}], {
             RGBColor[
             0.9777585762834875, 0.9819606960414009, 0.8789930017404557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 413}], {
             RGBColor[
             0.9679824213544639, 0.9756419227869082, 0.9390815885116919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 486}], {
             RGBColor[
             0.973493762716239, 0.979752272150527, 0.9297523251742477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 28}], {
             RGBColor[
             0.928405878080383, 0.9439471077662959, 0.9257056391778977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 49}], {
             RGBColor[
             0.8733490772715962, 0.9018488640599372, 0.9877820087097318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 69}], {
             RGBColor[
             0.6175902819607526, 0.6949594182198892, 0.9659722023194823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 142}], {
             RGBColor[
             0.9318708568769246, 0.9442726062694332, 0.7877886440186574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 173}], {
             RGBColor[
             0.8082009928097231, 0.8504942113758307, 0.9814108521244006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[
             0.9276059811752921, 0.9436163298396281, 0.9389620009620864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 241}], {
             RGBColor[
             0.9303725362237973, 0.9447603714494066, 0.8931130241933951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 388}], {
             RGBColor[
             0.9321950633942175, 0.9455140332711873, 0.8629090324304078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 402}], {
             RGBColor[
             0.9298937776018934, 0.944562392455714, 0.9010472935459408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 436}], {
             RGBColor[
             0.9036058487156083, 0.9259291652194444, 0.9890860066664596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 461}], {
             RGBColor[
             0.8410041404219764, 0.8761202796036787, 0.9846803633155468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 487}], {
             RGBColor[
             0.9311525016128244, 0.9450829071819655, 0.8801869792114966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 31}], {
             RGBColor[
             0.8694739996778852, 0.8979817879443008, 0.9414724631507002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 40}], {
             RGBColor[
             0.7279593741656598, 0.7874066628851529, 0.9735198453158556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 114}], {
             RGBColor[
             0.8144514592813005, 0.8554150858984979, 0.9820237660989686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 115}], {
             RGBColor[
             0.7171856573729987, 0.7789901534434457, 0.9724460219120707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 162}], {
             RGBColor[
             0.8584930410662275, 0.8898409226478052, 0.96224194841347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 203}], {
             RGBColor[
             0.8467798555091259, 0.8811052480379, 0.9820693162735783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 221}], {
             RGBColor[
             0.7937449174091893, 0.8389042514737823, 0.9800487576502586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 258}], {
             RGBColor[
             0.6461412825527632, 0.721888340550429, 0.9664598735124301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 289}], {
             RGBColor[
             0.8265177802917409, 0.8650364427406646, 0.9831746625686764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 291}], {
             RGBColor[
             0.838545116055849, 0.8746267138056323, 0.9843218405907863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 297}], {
             RGBColor[
             0.6521659245851061, 0.7267794163593155, 0.9669341554022071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 311}], {
             RGBColor[
             0.8512959522468453, 0.8844733455904613, 0.9744247424832906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 381}], {
             RGBColor[
             0.8415678562903752, 0.8770369648185457, 0.9846101522527875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 419}], {
             RGBColor[
             0.784832928865447, 0.8318367160716518, 0.9791884697347438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 439}], {
             RGBColor[
             0.8391992399092272, 0.875148294410597, 0.9843842315078648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 19}], {
             RGBColor[
             0.9239059742392715, 0.9413117957546151, 0.963142263292061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 26}], {
             RGBColor[
             0.9358601502881515, 0.9464889431932193, 0.7099741371638781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 34}], {
             RGBColor[
             0.8669778613697069, 0.8967686294418192, 0.9871743164493579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 44}], {
             RGBColor[
             0.8018258235866866, 0.8455899922160957, 0.9807552371862587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.9158466286311446, 0.9353011489960414, 0.9767846331926383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 117}], {
             RGBColor[
             0.8334620190507616, 0.8703044285566218, 0.9839084374930622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 139}], {
             RGBColor[
             0.9367766232928363, 0.9484491862806055, 0.8097265679080432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 247}], {
             RGBColor[
             0.8038480972359106, 0.8471698077607184, 0.9809567985243915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 269}], {
             RGBColor[
             0.8776278678073688, 0.9052606554884872, 0.9881901235707551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 360}], {
             RGBColor[
             0.9159301300058088, 0.935363424184545, 0.9766432871459785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 425}], {
             RGBColor[
             0.8275153657680407, 0.8656588578159214, 0.983315730668475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 466}], {
             RGBColor[
             0.9185849148385036, 0.9373433583659576, 0.9721494289030035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 468}], {
             RGBColor[
             0.863729692035089, 0.8941786273836028, 0.9868645031585471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 120}], {
             RGBColor[
             0.9690119417528542, 0.9764097374143429, 0.9373388790191409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 123}], {
             RGBColor[
             0.9677826924372117, 0.9754929652874478, 0.9394196774709553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 125}], {
             RGBColor[
             0.9725132856944789, 0.979021033993082, 0.9314120170227249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 177}], {
             RGBColor[
             0.8674097401044332, 0.8964909821907444, 0.9471483027893561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 245}], {
             RGBColor[
             0.8119167317861371, 0.8531394223300074, 0.9416172783318354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 438}], {
             RGBColor[
             0.8936404753077414, 0.91698263189254, 0.9497627373342645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 455}], {
             RGBColor[
             0.987563079167437, 0.9880456769093883, 0.7951001492102657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 23}], {
             RGBColor[
             0.8829495038447968, 0.9091145655204569, 0.9731871285847322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 41}], {
             RGBColor[
             0.8838101748248299, 0.9097564525281463, 0.9717302371144787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 102}], {
             RGBColor[
             0.6935198879848281, 0.7594577239802753, 0.9708014041049207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 186}], {
             RGBColor[
             0.8934779713676855, 0.9169666793602439, 0.9553651793325959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 193}], {
             RGBColor[
             0.8997376504848938, 0.9212339688101732, 0.926804008525641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 202}], {
             RGBColor[
             0.8404078988419319, 0.8756399736458831, 0.9846247880261947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 211}], {
             RGBColor[
             0.7334059251327163, 0.7916615498959378, 0.9740627066153391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 414}], {
             RGBColor[
             0.8774754886378923, 0.9050320539420247, 0.9824532084782007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 485}], {
             RGBColor[
             0.7470391687420677, 0.8023119434200523, 0.9754215409284142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 497}], {
             RGBColor[
             0.8764492390433511, 0.9042666786747454, 0.9841903813529971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 198}], {
             RGBColor[
             0.9768726115504034, 0.9811721933205667, 0.8747717279841349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 373}], {
             RGBColor[
             0.9097317064324433, 0.9283381232361583, 0.8927157426486279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 480}], {
             RGBColor[
             0.9677045049128885, 0.974334634401705, 0.8902909410962758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 154}], {
             RGBColor[
             0.9726727729275142, 0.9780640849759703, 0.8829613002639438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 229}], {
             RGBColor[
             0.974268909093935, 0.9774975992703446, 0.7673534807891615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 244}], {
             RGBColor[
             0.9198903798239637, 0.9384702302379182, 0.9752531760129741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 313}], {
             RGBColor[
             0.8942893160489422, 0.9180566369060799, 0.9728113236957732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 334}], {
             RGBColor[
             0.9741255032437568, 0.9771908686573689, 0.751744638995582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 338}], {
             RGBColor[
             0.9731494842250197, 0.9782612173484104, 0.8750609603749874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 340}], {
             RGBColor[
             0.9702436177177145, 0.9770595668702768, 0.9232186885424901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 363}], {
             RGBColor[
             0.9386525164969328, 0.9534306487363111, 0.977042725357999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 379}], {
             RGBColor[
             0.9482980690093992, 0.9609613650381278, 0.9724020625305603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 380}], {
             RGBColor[
             0.8554766720906393, 0.8876234180531875, 0.9689726925042076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 390}], {
             RGBColor[
             0.9689766509258371, 0.960483217882897, 0.6755665094705742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 478}], {
             RGBColor[
             0.9059580936341627, 0.9273610034120049, 0.9739243021186922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 63}], {
             RGBColor[
             0.6549249689613663, 0.718439639947936, 0.7353132485121014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 72}], {
             RGBColor[
             0.9843430523847123, 0.9847302048412182, 0.7280303025079349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 75}], {
             RGBColor[
             0.91587609048317, 0.9311558728244059, 0.7568418841542002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 149}], {
             RGBColor[
             0.9629893856867033, 0.8792956542185416, 0.396904329302239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 158}], {
             RGBColor[
             0.9941654331074793, 0.9899287763191281, 0.6063215844012299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 163}], {
             RGBColor[
             0.6727317544301654, 0.7338629825259491, 0.7364478811362513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 182}], {
             RGBColor[
             0.9793025101294586, 0.9809709766803804, 0.736562625762111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 187}], {
             RGBColor[
             0.9792676774256981, 0.9411381880698423, 0.42404027056662374`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 279}], {
             RGBColor[
             0.9820360214069206, 0.9830096249153975, 0.7319355041832907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 322}], {
             RGBColor[
             0.9866099988362087, 0.9659055622465447, 0.45256380276540253`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 324}], {
             RGBColor[
             0.9807148961094632, 0.9460199965132879, 0.42966244186873437`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 441}], {
             RGBColor[
             0.9741668906229318, 0.9236107366079697, 0.40589801214369026`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 494}], {
             RGBColor[
             0.9933721820626524, 0.9899530937592554, 0.6450797240699702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 78}], {
             RGBColor[
             0.8581106433349401, 0.8840924103118448, 0.697570602118611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 97}], {
             RGBColor[
             0.952336252454415, 0.9584543882739802, 0.7067625152555258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 104}], {
             RGBColor[
             0.9797370168420937, 0.9433103412129935, 0.3757825660851679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.91678602047035, 0.9301075982752272, 0.703371702392819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 148}], {
             RGBColor[
             0.9929599429631739, 0.9876566985904405, 0.5830654107929523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 153}], {
             RGBColor[
             0.9932179964345393, 0.9873590333276796, 0.5493948575201044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 190}], {
             RGBColor[
             0.9328493669896587, 0.9429160747617983, 0.7049038387237494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 323}], {
             RGBColor[
             0.8918502229960041, 0.9104500263733708, 0.7009334481049275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 356}], {
             RGBColor[
             0.9466516537331156, 0.9539216435579378, 0.7062203131547871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 408}], {
             RGBColor[
             0.7399984024014545, 0.789463377279406, 0.6874110382576459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 430}], {
             RGBColor[
             0.9681820135045418, 0.9708561921839827, 0.7001895456993267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 452}], {
             RGBColor[
             0.9069113927767859, 0.9222338381920074, 0.7024298515882226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 39}], {
             RGBColor[
             0.8974060741191874, 0.9192298803898447, 0.9182897986602916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 45}], {
             RGBColor[
             0.5843841900480444, 0.6684515581798465, 0.9628390179436845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 52}], {
             RGBColor[
             0.6245689705323738, 0.7032575952895788, 0.9653995566221398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 56}], {
             RGBColor[
             0.8708062221528909, 0.8999244920111693, 0.9875120744262024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 179}], {
             RGBColor[
             0.8900910921803513, 0.9143406017914948, 0.9560287757914967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 200}], {
             RGBColor[
             0.8941854096123811, 0.9173941370284733, 0.9490981643480798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 236}], {
             RGBColor[
             0.9004183645231395, 0.9190458640888437, 0.7644460132108816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 243}], {
             RGBColor[
             0.7206450683604402, 0.7815658198615538, 0.9728775528951851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 254}], {
             RGBColor[
             0.8984156492656015, 0.9129825516986192, 0.6977962503862409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 276}], {
             RGBColor[
             0.8958187912541393, 0.9185734981338383, 0.9445951834905166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 283}], {
             RGBColor[
             0.898671621198037, 0.9197532166300253, 0.8973164084329004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 292}], {
             RGBColor[
             0.8464641837574587, 0.8805148113416816, 0.9851903090736518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 422}], {
             RGBColor[
             0.8392602393677508, 0.8747705816311899, 0.9845031904267244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 454}], {
             RGBColor[
             0.8993780839227475, 0.920045357121957, 0.8856084928175226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 205}], {
             RGBColor[
             0.7277030466738076, 0.7872064179003568, 0.9734942969869843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 252}], {
             RGBColor[
             0.8457256651429692, 0.8801251835743283, 0.9850669945001675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 282}], {
             RGBColor[
             0.8857306974829047, 0.9098699016723324, 0.9062849430377053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 293}], {
             RGBColor[
             0.728142460176262, 0.7875496910681405, 0.9735380936183564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 298}], {
             RGBColor[
             0.8536909496892233, 0.8864764852596223, 0.9858267304508828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 418}], {
             RGBColor[
             0.8361365151735061, 0.8724790556792203, 0.9841523728157449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 432}], {
             RGBColor[
             0.8839292443316589, 0.909124954499058, 0.9361396837651597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 467}], {
             RGBColor[
             0.8526604690817285, 0.8856548079948567, 0.985728442290619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 52}], {
             RGBColor[
             0.5607304582117086, 0.6533864642740115, 0.9590367303188319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 56}], {
             RGBColor[
             0.8069677098322257, 0.850053360995602, 0.9811492481228945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 65}], {
             RGBColor[
             0.8167020504886378, 0.8573467016085563, 0.9658325045363787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 88}], {
             RGBColor[
             0.8108086574083605, 0.8529514186988311, 0.9758084817781999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 166}], {
             RGBColor[
             0.8338492416264407, 0.8694752312219629, 0.9072588086443485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 167}], {
             RGBColor[
             0.8326750473611539, 0.8689896717178507, 0.9267182463374997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 210}], {
             RGBColor[
             0.7566504632040296, 0.809931754359553, 0.9763499442207608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 227}], {
             RGBColor[
             0.8191233584944693, 0.8591525091547776, 0.961733861660774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 243}], {
             RGBColor[
             0.6568065560397749, 0.7316946888459865, 0.9665147265918772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 326}], {
             RGBColor[
             0.7041540855947148, 0.7688097905266366, 0.9711471566241735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 348}], {
             RGBColor[
             0.8362010745748556, 0.8704477745854824, 0.8682828503405449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 428}], {
             RGBColor[
             0.7169988566853918, 0.7788442233265495, 0.9724274033652818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 434}], {
             RGBColor[
             0.8364433642250986, 0.8705479675824179, 0.8642674838105033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 469}], {
             RGBColor[
             0.7708043032007562, 0.821217642177191, 0.9776999501149307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 474}], {
             RGBColor[
             0.6081464633282567, 0.6921902334705806, 0.9626840258458338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 495}], {
             RGBColor[
             0.5346572055792149, 0.6308031233235267, 0.9573753657167614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 26}], {
             RGBColor[
             0.9806061171756704, 0.9813183969754754, 0.6847801400476835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 34}], {
             RGBColor[
             0.9117238282572258, 0.9315980832240753, 0.9619803193331633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 44}], {
             RGBColor[
             0.8465717904742054, 0.8804194459983518, 0.9555612400700639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 139}], {
             RGBColor[
             0.981522590180355, 0.9832786400628616, 0.7845325707918485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 234}], {
             RGBColor[
             0.888853379940459, 0.9134501450413709, 0.9597754737641417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 247}], {
             RGBColor[
             0.8485940641234294, 0.8819992615429746, 0.9557628014081969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 269}], {
             RGBColor[
             0.9223738346948875, 0.9400901092707434, 0.9629961264545606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 360}], {
             RGBColor[
             0.9606760968933277, 0.9701928779668012, 0.9514492900297837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 393}], {
             RGBColor[
             0.9335757622669181, 0.9490222222484568, 0.9640645763064596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 466}], {
             RGBColor[
             0.9633308817260224, 0.9721728121482137, 0.946955431786809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 468}], {
             RGBColor[
             0.9084756589226077, 0.929008081165859, 0.9616705060423525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 62}], {
             RGBColor[
             0.8394674712922078, 0.874832591143667, 0.9845503508849509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 194}], {
             RGBColor[
             0.9063814650367724, 0.9266924767949153, 0.9369375876654451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 228}], {
             RGBColor[
             0.8988158286809067, 0.8883645605282198, 0.661327966129313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 388}], {
             RGBColor[
             0.9109705472556979, 0.9285901802264745, 0.8608846191337666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 490}], {
             RGBColor[
             0.9081505320338978, 0.9274240314611747, 0.9076195693244455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 33}], {
             RGBColor[
             0.8575846037170682, 0.8895690522765534, 0.9862013287847279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 65}], {
             RGBColor[
             0.9424886390489748, 0.9565103154829798, 0.9781313881454007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 119}], {
             RGBColor[
             0.9480702743285405, 0.9208063370987521, 0.6559745712938048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 164}], {
             RGBColor[
             0.9444881071082357, 0.9580015154877481, 0.9747468102658616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 166}], {
             RGBColor[
             0.9596358301867778, 0.9686388450963865, 0.9195576922533705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 175}], {
             RGBColor[
             0.9494333570849365, 0.9616896748232678, 0.9663757919830691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 227}], {
             RGBColor[
             0.9449099470548066, 0.958316123029201, 0.974032745269796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 309}], {
             RGBColor[
             0.9519147205947138, 0.963540271666, 0.9621754908042683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 320}], {
             RGBColor[
             0.9602114589146162, 0.9688768823683311, 0.9100180345536942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 337}], {
             RGBColor[
             0.8219888183906054, 0.8617613542415323, 0.9826534735649126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 348}], {
             RGBColor[
             0.9619876631351928, 0.969611388459906, 0.8805817339495667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 375}], {
             RGBColor[
             0.7933853123367072, 0.8394160779175293, 0.9798025433964215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 428}], {
             RGBColor[
             0.8427854452457291, 0.878007837200973, 0.9847262869743036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 489}], {
             RGBColor[
             0.8998696022185358, 0.9229956107721546, 0.990311560054323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 63}], {
             RGBColor[
             0.654971273127478, 0.7185386798771798, 0.7403531712371794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 149}], {
             RGBColor[
             0.9630356898528151, 0.8793946941477854, 0.4019442520273168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 160}], {
             RGBColor[
             0.9676075578017744, 0.9723134067410941, 0.7614774331210481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 165}], {
             RGBColor[
             0.9217064417779786, 0.9358669549302957, 0.7624334944578928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 182}], {
             RGBColor[
             0.9793488142955704, 0.9810700166096241, 0.7416025484871888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 268}], {
             RGBColor[
             0.8500294324485589, 0.8796308298131466, 0.7553534868783152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 275}], {
             RGBColor[
             0.9838826956120112, 0.9844513778718764, 0.7339278700440863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 282}], {
             RGBColor[
             0.9912252952204327, 0.9891451928441162, 0.6864664975994881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 285}], {
             RGBColor[
             0.9753258517479896, 0.978069697728635, 0.7484123747235676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 324}], {
             RGBColor[
             0.9807612002755749, 0.9461190364425317, 0.4347023645938122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 353}], {
             RGBColor[
             0.9760087338017839, 0.9300878510942413, 0.4162399297711218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 441}], {
             RGBColor[
             0.9742131947890436, 0.9237097765372134, 0.41093793486876806`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 481}], {
             RGBColor[
             0.9938221794915324, 0.9902190712270975, 0.6434294047063043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 41}], {
             RGBColor[
             0.953891075206313, 0.9651326199020791, 0.9629345619288265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 186}], {
             RGBColor[
             0.9635588717491685, 0.9723428467341767, 0.9465695041469439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 202}], {
             RGBColor[
             0.9104887992234149, 0.9310161410198159, 0.9758291128405425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 211}], {
             RGBColor[
             0.8034868255141993, 0.8470377172698706, 0.965267031429687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 212}], {
             RGBColor[
             0.97024327766263, 0.9767857716293374, 0.9109695111683602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 485}], {
             RGBColor[
             0.8171200691235507, 0.8576881107939851, 0.966625865742762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 497}], {
             RGBColor[
             0.9465301394248342, 0.9596428460486782, 0.9753947061673449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 77}], {
             RGBColor[
             0.7799594462091728, 0.827497734368912, 0.9467487148685582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 81}], {
             RGBColor[
             0.7135285303675487, 0.7735661242100274, 0.9415190298290427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 83}], {
             RGBColor[
             0.9807783016259835, 0.984245582305889, 0.8753493519470843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 176}], {
             RGBColor[
             0.9656848709990038, 0.9739284134936995, 0.9429707419663822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 197}], {
             RGBColor[
             0.7300418787400942, 0.7869724043367263, 0.9428190211033176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 237}], {
             RGBColor[
             0.6774897269002262, 0.7424062262632165, 0.9392074442231056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 267}], {
             RGBColor[
             0.631109227277784, 0.7005476118914498, 0.9363138582583079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 270}], {
             RGBColor[
             0.9772144044494627, 0.9658956965451098, 0.6600698904335053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 278}], {
             RGBColor[
             0.8689182815112204, 0.8978225584102049, 0.9550481625641339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 329}], {
             RGBColor[
             0.9244173906217876, 0.9416407344482131, 0.9604572342512534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 426}], {
             RGBColor[
             0.9806843057327788, 0.9842067125884646, 0.8769071071510599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 448}], {
             RGBColor[
             0.9198073204349358, 0.937964789618239, 0.9600175216413733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 489}], {
             RGBColor[
             0.9201703866776809, 0.9382542887850334, 0.9600521512237195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[
             0.8120874605236865, 0.8535430289453746, 0.9553133959998505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 96}], {
             RGBColor[
             0.8015547321718033, 0.8452482541185165, 0.9543090772092807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 157}], {
             RGBColor[
             0.9014800619891402, 0.9235217484674298, 0.9641848586610227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.9784050670042512, 0.9821649739366702, 0.8654549039356336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 246}], {
             RGBColor[
             0.9685134363664569, 0.9452372977590922, 0.6447197639334383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 288}], {
             RGBColor[
             0.9793809437523526, 0.9825685240508987, 0.8492821007315263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 333}], {
             RGBColor[
             0.9105503474391146, 0.7024949338194095, 0.5726190248886993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 343}], {
             RGBColor[
             0.9585436912136185, 0.968602533302368, 0.9550588966250573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 392}], {
             RGBColor[
             0.8798413786178416, 0.906472904709378, 0.9620664733591127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 459}], {
             RGBColor[
             0.9785328106189745, 0.9822177992042195, 0.8633378616497936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 465}], {
             RGBColor[
             0.9764642302389115, 0.9813623880569725, 0.8976195918618564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 492}], {
             RGBColor[
             0.8358011524485391, 0.8720683453078033, 0.9576769551938694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 34}], {
             RGBColor[
             0.9236780043061057, 0.9367752306626795, 0.7088121932049805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 44}], {
             RGBColor[
             0.8585259665230853, 0.8855965934369558, 0.7023931139418811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 106}], {
             RGBColor[
             0.9725467715675435, 0.9753077502169016, 0.6984225099482608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 117}], {
             RGBColor[
             0.8901621619871604, 0.9103110297774821, 0.7055463142486846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 139}], {
             RGBColor[
             0.9934767662292351, 0.9884557875014657, 0.5313644446636656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 215}], {
             RGBColor[
             0.8622978437481252, 0.8885432125924857, 0.7027690594134763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 224}], {
             RGBColor[
             0.9937193338581207, 0.9889746151323029, 0.5577664341139897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 247}], {
             RGBColor[
             0.8605482401723095, 0.8871764089815787, 0.7025946752800141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 269}], {
             RGBColor[
             0.9343280107437675, 0.9452672567093474, 0.7098280003263777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 351}], {
             RGBColor[
             0.9935185686562746, 0.9885451986660297, 0.5359143808722518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 360}], {
             RGBColor[
             0.9726302729422076, 0.9753700254054052, 0.6982811639016009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 425}], {
             RGBColor[
             0.8842155087044395, 0.9056654590367816, 0.7049536074240976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 466}], {
             RGBColor[
             0.9752850577749024, 0.9773499595868178, 0.6937873056586261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 468}], {
             RGBColor[
             0.9204298349714878, 0.934185228604463, 0.7085023799141696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 40}], {
             RGBColor[
             0.8134475103468843, 0.8550429984716506, 0.9818143152893053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 114}], {
             RGBColor[
             0.899939595462525, 0.9230514214849955, 0.9903182360724183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 199}], {
             RGBColor[
             0.9067563494079418, 0.9284869160452143, 0.9909684241491203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 220}], {
             RGBColor[
             0.9562198483690226, 0.9661382199753845, 0.9289233819792537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 277}], {
             RGBColor[
             0.8830590769355888, 0.9095913542210854, 0.9887081571459024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 289}], {
             RGBColor[
             0.9120059164729655, 0.9326727783271622, 0.9914691325421261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 291}], {
             RGBColor[
             0.9240332522370736, 0.9422630493921299, 0.992616310564236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 297}], {
             RGBColor[
             0.7376540607663307, 0.7944157519458132, 0.9752286253756568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 311}], {
             RGBColor[
             0.9367840884280698, 0.9521096811769589, 0.9827192124567403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 319}], {
             RGBColor[
             0.8757715353005651, 0.9037804663363656, 0.9880130649190886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 349}], {
             RGBColor[
             0.8330123253476412, 0.8703271806483431, 0.9837643532049893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 359}], {
             RGBColor[
             0.7810766816291572, 0.8296681917290334, 0.9786470131522798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 371}], {
             RGBColor[
             0.9042605862650217, 0.9264968622607356, 0.9907303760325545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 419}], {
             RGBColor[
             0.8703210650466715, 0.8994730516581493, 0.9874829397081936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 488}], {
             RGBColor[
             0.9509385339041707, 0.9626660434372576, 0.9587594283363268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 69}], {
             RGBColor[
             0.6762528291726498, 0.7399327862327094, 0.9042397520984649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 142}], {
             RGBColor[
             0.9905334040888218, 0.9892459742822535, 0.72605619379764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 173}], {
             RGBColor[
             0.8668635400216204, 0.8954675793886511, 0.9196784019033831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 194}], {
             RGBColor[
             0.9862685283871894, 0.9885896978524482, 0.8772295507410689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 241}], {
             RGBColor[
             0.9890350834356947, 0.9897337394622269, 0.8313805739723776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 417}], {
             RGBColor[
             0.9672081209638201, 0.9745865720762905, 0.9189918904455883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 461}], {
             RGBColor[
             0.8996666876338737, 0.921093647616499, 0.9229479130945293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 493}], {
             RGBColor[
             0.9872929909132943, 0.9890133394344787, 0.8602515554594805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 77}], {
             RGBColor[
             0.7817319014768427, 0.828819628605411, 0.9437484104307641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 172}], {
             RGBColor[
             0.863569749892523, 0.8935814835695689, 0.9513381047029126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 318}], {
             RGBColor[
             0.9781897118472928, 0.9645286238374183, 0.6539728170501272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 321}], {
             RGBColor[
             0.9611940746806348, 0.9705791849524641, 0.9505724887461161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 383}], {
             RGBColor[
             0.9777366910759062, 0.9829166411740091, 0.9225701541942788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 479}], {
             RGBColor[
             0.9515874888132945, 0.9632140197515279, 0.9598793796682783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 482}], {
             RGBColor[
             0.8497844467103097, 0.8828122999514393, 0.9499641145126922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 43}], {
             RGBColor[
             0.9867128595561585, 0.9861814167600575, 0.6989307994952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 64}], {
             RGBColor[
             0.8394803454555719, 0.8710187864174312, 0.7245855233026598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 110}], {
             RGBColor[
             0.9914213276366031, 0.9824154562755654, 0.44743278302769945`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 217}], {
             RGBColor[
             0.8924767214956707, 0.9124199581673322, 0.7298677067870449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 290}], {
             RGBColor[
             0.8567294350273142, 0.8844939062888124, 0.7263047513492643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 316}], {
             RGBColor[
             0.9660501515066369, 0.9707712029288036, 0.7339073745256794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 355}], {
             RGBColor[
             0.7453442809071176, 0.7952627591931614, 0.7167181605851285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 378}], {
             RGBColor[
             0.9652358654621431, 0.9701639097300911, 0.7352857483991934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 384}], {
             RGBColor[
             0.9872403889299504, 0.9865748473032814, 0.6980378298670666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[
             0.8429706014770116, 0.8772771318364916, 0.9388308521063751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 114}], {
             RGBColor[
             0.9294626865926523, 0.9452855548498366, 0.9473347728894881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 162}], {
             RGBColor[
             0.9735042683775793, 0.9797113915991438, 0.9275529552039895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 203}], {
             RGBColor[
             0.9617910828204779, 0.9709757169892386, 0.9473803230640978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 208}], {
             RGBColor[
             0.9702816981875055, 0.9773080040278612, 0.9330079259548689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 221}], {
             RGBColor[
             0.908756144720541, 0.928774720425121, 0.9453597644407781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 223}], {
             RGBColor[
             0.9896953784817942, 0.9900067884325976, 0.8204377762697059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 258}], {
             RGBColor[
             0.761152509864115, 0.8117588095017676, 0.9317708803029496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 289}], {
             RGBColor[
             0.9415290076030927, 0.9549069116920033, 0.9484856693591959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 297}], {
             RGBColor[
             0.7671771518964579, 0.8166498853106542, 0.9322451621927266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 314}], {
             RGBColor[
             0.9703712827708411, 0.9773748160634317, 0.9328562826226832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 381}], {
             RGBColor[
             0.956579083601727, 0.9669074337698842, 0.949921159043307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 397}], {
             RGBColor[
             0.9366227609240819, 0.9509948037666783, 0.9480177071710937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 419}], {
             RGBColor[
             0.8998441561767987, 0.9217071850229903, 0.9444994765252633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 472}], {
             RGBColor[
             0.9548773235848045, 0.9655504965254351, 0.9497588436537139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 103}], {
             RGBColor[
             0.9061255595524128, 0.5628478200718033, 0.42699431188742637`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 155}], {
             RGBColor[
             0.9647691563782352, 0.9711311330124333, 0.8416976954648934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 331}], {
             RGBColor[
             0.9166028257244616, 0.9327246083893299, 0.8371035478485456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 344}], {
             RGBColor[
             0.9941679548134303, 0.9899341699931736, 0.6065960565318247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 403}], {
             RGBColor[
             0.9790025445436787, 0.9817745510679085, 0.8185813164346175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 449}], {
             RGBColor[
             0.9224539378794441, 0.9373901263975046, 0.8376616321492373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 119}], {
             RGBColor[
             0.8745467599206841, 0.8624710339663217, 0.648884782490106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 159}], {
             RGBColor[
             0.852753631487334, 0.8857169661538111, 0.985740546340796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 164}], {
             RGBColor[
             0.8709645927003793, 0.8996662123553176, 0.9676570214621629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 227}], {
             RGBColor[
             0.87138643264695, 0.8999808198967706, 0.9669429564660972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 267}], {
             RGBColor[
             0.5372849284107823, 0.6269536307461405, 0.9594834782852126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 270}], {
             RGBColor[
             0.8833901055824611, 0.8923017153998005, 0.6832395104604101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 309}], {
             RGBColor[
             0.8783912061868574, 0.9052049685335695, 0.9550857020005695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 443}], {
             RGBColor[
             0.8607789958168681, 0.8920698108769792, 0.9848985801568176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 489}], {
             RGBColor[
             0.8263460878106794, 0.8646603076397241, 0.9832217712506242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 234}], {
             RGBColor[
             0.8319252670708943, 0.868906978728575, 0.9838075269214386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 269}], {
             RGBColor[
             0.8654457218253229, 0.8955469429579475, 0.9870281796118574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 332}], {
             RGBColor[
             0.9048080509314553, 0.926440307818062, 0.9736869264220871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 360}], {
             RGBColor[
             0.903747984023763, 0.9256497116540052, 0.9754813431870808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 393}], {
             RGBColor[
             0.8766476493973534, 0.9044790559356608, 0.9880966294637565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 468}], {
             RGBColor[
             0.8515475460530432, 0.884464914853063, 0.9857025591996494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 54}], {
             RGBColor[
             0.8658697873363086, 0.895639639324939, 0.9647967957217102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 67}], {
             RGBColor[
             0.9646542781157826, 0.9731597990088342, 0.9447152668960027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 70}], {
             RGBColor[
             0.9285557655897495, 0.9452298106116799, 0.9708803761911742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 84}], {
             RGBColor[
             0.8062541558861152, 0.8490674549404674, 0.9588548667185055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 131}], {
             RGBColor[
             0.9769392942096554, 0.9791585682277746, 0.7366015281363352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 135}], {
             RGBColor[
             0.9732796029969364, 0.9792811731705404, 0.9161706533759351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 147}], {
             RGBColor[
             0.9503624380335447, 0.9625009680762415, 0.9689076242463539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 171}], {
             RGBColor[
             0.7902157019056097, 0.8361946383446499, 0.9574911251964899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 216}], {
             RGBColor[
             0.974130446211087, 0.979633018705265, 0.9020699794058038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 281}], {
             RGBColor[
             0.972680040883358, 0.9790332388285323, 0.9261069492149382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 385}], {
             RGBColor[
             0.8730688508770428, 0.9012636024778697, 0.9655143310963767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 391}], {
             RGBColor[
             0.9286913551433672, 0.9453379260412542, 0.9708933088438404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 37}], {
             RGBColor[
             0.7968571353018451, 0.8419346398836881, 0.9684577571105499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 58}], {
             RGBColor[
             0.8153955537028637, 0.855491809511319, 0.9250417660108301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 141}], {
             RGBColor[
             0.8201236932491818, 0.8574331630783752, 0.8456772440965252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 240}], {
             RGBColor[
             0.7722769540484301, 0.8226711770319686, 0.9777662997350178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 251}], {
             RGBColor[
             0.6329394395120675, 0.7128476039334372, 0.9642739238620595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 310}], {
             RGBColor[
             0.8167880503586722, 0.8560676426640277, 0.9019644927582541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 352}], {
             RGBColor[
             0.756443199522828, 0.8100457709690704, 0.9762560620934064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 367}], {
             RGBColor[
             0.5902681674691572, 0.6782051429701036, 0.9609146850168216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 382}], {
             RGBColor[
             0.7781674637602731, 0.8273681095825656, 0.9783281418098536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 399}], {
             RGBColor[
             0.6203913776308718, 0.7026605220145365, 0.9632860944657065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 412}], {
             RGBColor[
             0.8198781984972483, 0.8569080746273163, 0.8189566553665584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 416}], {
             RGBColor[
             0.41195422260949954`, 0.513988837068202, 0.9493751904156429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 429}], {
             RGBColor[
             0.783804452482082, 0.8318628913773533, 0.978865802826339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 58}], {
             RGBColor[
             0.9672712437857096, 0.9748427752586031, 0.9282501422900941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 118}], {
             RGBColor[
             0.8726519002501383, 0.901146086322844, 0.9760122709382464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 141}], {
             RGBColor[
             0.9719993833320277, 0.9767841288256593, 0.8488856203757893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 188}], {
             RGBColor[
             0.8515977988756123, 0.8846984623119671, 0.9739137948749973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 240}], {
             RGBColor[
             0.9241526441312761, 0.9420221427792526, 0.9809746760142819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 304}], {
             RGBColor[
             0.9523452165452811, 0.9639797210437927, 0.9655512974174427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 310}], {
             RGBColor[
             0.9686637404415182, 0.9754186084113117, 0.905172869037518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 429}], {
             RGBColor[
             0.9356801425649279, 0.9512138571246374, 0.9820741791056029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 47}], {
             RGBColor[
             0.9423557423886982, 0.9565295875740759, 0.9824608714924074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 73}], {
             RGBColor[
             0.8562088255519641, 0.8883755993654487, 0.9781682452313762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 93}], {
             RGBColor[
             0.9069995521277563, 0.9284539256574047, 0.9831243828692504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 108}], {
             RGBColor[
             0.929846391912346, 0.9466713755406915, 0.9853035348435193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 163}], {
             RGBColor[
             0.6482523322353018, 0.7187197193143695, 0.9612421628618361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 189}], {
             RGBColor[
             0.9663309970645628, 0.973750475794241, 0.9123290450746243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 266}], {
             RGBColor[
             0.8341839268280999, 0.8711695810869359, 0.9759730091609622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 364}], {
             RGBColor[
             0.9666669666322734, 0.9738894078445135, 0.9067611598762901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 437}], {
             RGBColor[
             0.9619119077811702, 0.9711145437034996, 0.9493573845477667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 45}], {
             RGBColor[
             0.6745782985216511, 0.7383620488784198, 0.8997098136269776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 100}], {
             RGBColor[
             0.9243662966326548, 0.9406239984074145, 0.9208886832435745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 127}], {
             RGBColor[
             0.9682020387710626, 0.9752394901421665, 0.913353212749187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 179}], {
             RGBColor[
             0.980285200653958, 0.984251092490068, 0.8928995714747898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 200}], {
             RGBColor[
             0.9843795180859879, 0.9873046277270465, 0.8859689600313729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 213}], {
             RGBColor[
             0.8650372509706812, 0.893943109734064, 0.9150635768726989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 236}], {
             RGBColor[
             0.9906124729967463, 0.988956354787417, 0.7013168088941746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 243}], {
             RGBColor[
             0.8108391768340468, 0.8514763105601271, 0.9097483485784781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 254}], {
             RGBColor[
             0.9886097577392082, 0.9828930423971924, 0.6346670460695341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 276}], {
             RGBColor[
             0.986012899727746, 0.9884839888324115, 0.8814659791738098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 283}], {
             RGBColor[
             0.9888657296716438, 0.9896637073285985, 0.8341872041161935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 315}], {
             RGBColor[
             0.970240960017763, 0.9767601142695286, 0.9099018509143519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 325}], {
             RGBColor[
             0.988248604554012, 0.9894085102330658, 0.844414564383962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 368}], {
             RGBColor[
             0.7015315049440672, 0.761707561573972, 0.9014272481064293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 401}], {
             RGBColor[
             0.9878818624207126, 0.9892568529361035, 0.8504924306309494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 450}], {
             RGBColor[
             0.9905862887093364, 0.9889003492442852, 0.6984668108003123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 454}], {
             RGBColor[
             0.9895721923963543, 0.9899558478205304, 0.8224792885008156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 471}], {
             RGBColor[
             0.9702978530552052, 0.9768025450036991, 0.9098055458420431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 475}], {
             RGBColor[
             0.8935159434460109, 0.916190880741871, 0.9179020667901274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 114}], {
             RGBColor[
             0.7879480610804269, 0.8347104297906887, 0.9793821550546434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 199}], {
             RGBColor[
             0.7947648150258437, 0.8401459243509075, 0.9800323431313454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 208}], {
             RGBColor[
             0.82876707267528, 0.8667328789687133, 0.9650553081200243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 220}], {
             RGBColor[
             0.8442283139869246, 0.8777972282810778, 0.9179873009614787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 289}], {
             RGBColor[
             0.8000143820908674, 0.8443317866328554, 0.9805330515243511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 291}], {
             RGBColor[
             0.8120417178549755, 0.853922057697823, 0.9816802295464612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 297}], {
             RGBColor[
             0.6256625263842326, 0.7060747602515063, 0.9642925443578819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 314}], {
             RGBColor[
             0.8288566572586158, 0.8667996910042838, 0.9649036647878384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 349}], {
             RGBColor[
             0.7210207909655432, 0.7819861889540363, 0.9728282721872145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 359}], {
             RGBColor[
             0.6690851472470591, 0.7413272000347265, 0.9677109321345049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 371}], {
             RGBColor[
             0.7922690518829236, 0.8381558705664287, 0.9797942950147795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 397}], {
             RGBColor[
             0.7951081354118565, 0.8404196787075304, 0.980065089336249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 419}], {
             RGBColor[
             0.7583295306645734, 0.8111320599638425, 0.9765468586904187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 472}], {
             RGBColor[
             0.813362698072579, 0.8549753714662873, 0.9818062258188691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 102}], {
             RGBColor[
             0.7644614593463444, 0.8154757783618974, 0.960548837449015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 186}], {
             RGBColor[
             0.9644195427292017, 0.972984733741866, 0.9451126126766904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 191}], {
             RGBColor[
             0.8949225967176628, 0.9185596850055424, 0.9728054115127718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 202}], {
             RGBColor[
             0.911349470203448, 0.9316580280275053, 0.974372221370289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 212}], {
             RGBColor[
             0.9711039486426631, 0.9774276586370267, 0.9095126196981067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 295}], {
             RGBColor[
             0.9226411926221383, 0.940661740978529, 0.9754492359348234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 300}], {
             RGBColor[
             0.9075161544576786, 0.9286014461044128, 0.9740065962924163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 389}], {
             RGBColor[
             0.9747340094113559, 0.9784407366413825, 0.8138773690957802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 451}], {
             RGBColor[
             0.971771803008511, 0.9777038335803792, 0.898444544504314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 456}], {
             RGBColor[
             0.8963092627811102, 0.9196653748844877, 0.9729376729597948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 485}], {
             RGBColor[
             0.8179807401035839, 0.8583299978016745, 0.9651689742725086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 85}], {
             RGBColor[
             0.911203766157922, 0.9286064875462154, 0.8517427620127141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 95}], {
             RGBColor[
             0.9046230889102562, 0.9080794981410587, 0.6840729749733956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[
             0.870123241094588, 0.8992766698553813, 0.9874743255754308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 137}], {
             RGBColor[
             0.8968134933573473, 0.9197662775555404, 0.9625444610925384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 145}], {
             RGBColor[
             0.8876977398511274, 0.9129677635162781, 0.9779750540092801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 174}], {
             RGBColor[
             0.8951348408144069, 0.9185143412375567, 0.9653859819850341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 248}], {
             RGBColor[
             0.720872935995343, 0.7815029699157454, 0.9730893312135991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 286}], {
             RGBColor[
             0.7772490725719939, 0.8259704475588581, 0.9784171114072826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 294}], {
             RGBColor[
             0.7992216591189835, 0.8431355991672091, 0.9806071334887908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 346}], {
             RGBColor[
             0.9023785261460731, 0.9239166698974672, 0.9531243121742337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 358}], {
             RGBColor[
             0.9039120163211024, 0.9250603443591443, 0.9505285133062021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 407}], {
             RGBColor[
             0.7703600495816496, 0.8205886904402873, 0.9777304779771852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 411}], {
             RGBColor[
             0.8873281815927394, 0.9126921475722685, 0.9786006197445004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 430}], {
             RGBColor[
             0.885969002144715, 0.9116784737653838, 0.9809013560192317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 110}], {
             RGBColor[
             0.9851308228312063, 0.9811536442608536, 0.6665260096585168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 217}], {
             RGBColor[
             0.8861862166902741, 0.9111581461526205, 0.9489609334178623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 290}], {
             RGBColor[
             0.8504389302219175, 0.8832320942741008, 0.9453979779800816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 316}], {
             RGBColor[
             0.9597596467012401, 0.9695093909140917, 0.9530006011564967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 340}], {
             RGBColor[
             0.9831160084687449, 0.9866597748157899, 0.9014290886581957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 355}], {
             RGBColor[
             0.739053776101721, 0.7940009471784497, 0.9358113872159458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 362}], {
             RGBColor[
             0.9860695720784292, 0.9878811492715168, 0.8524808960681279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 378}], {
             RGBColor[
             0.9589453606567464, 0.9689020977153794, 0.9543789750300107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 384}], {
             RGBColor[
             0.9809498841245536, 0.9853130352885697, 0.9171310564978838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 57}], {
             RGBColor[
             0.7139446606401869, 0.7764582621632856, 0.9721229896465806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 106}], {
             RGBColor[
             0.8385124448660786, 0.874408799239778, 0.9692036099706414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 117}], {
             RGBColor[
             0.7561278352856955, 0.8094120788003585, 0.9763274142710652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 139}], {
             RGBColor[
             0.8594424395277702, 0.887556836524342, 0.8021455446860462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 140}], {
             RGBColor[
             0.8475405482860341, 0.8811419439882183, 0.9539213857871411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 247}], {
             RGBColor[
             0.7265139134708445, 0.786277458004455, 0.9733757753023946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 255}], {
             RGBColor[
             0.7966629392557802, 0.8414732483933927, 0.9802627966698155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 269}], {
             RGBColor[
             0.8002936840423026, 0.8443683057322238, 0.9806091003487581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 360}], {
             RGBColor[
             0.8385959462407426, 0.8744710744282815, 0.9690622639239814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 369}], {
             RGBColor[
             0.84350340877716, 0.8781310519527092, 0.9607552099210459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 370}], {
             RGBColor[
             0.7241404156121096, 0.7844232634379595, 0.9731392072174344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 425}], {
             RGBColor[
             0.7501811820029747, 0.804766508059658, 0.9757347074464781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 466}], {
             RGBColor[
             0.8412507310734374, 0.8764510086096942, 0.9645684056810065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 468}], {
             RGBColor[
             0.7863955082700229, 0.8332862776273393, 0.9792834799365502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 52}], {
             RGBColor[
             0.4017411949348375, 0.522389763778154, 0.9468195715888258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 56}], {
             RGBColor[
             0.6479784465553546, 0.7190566604997445, 0.9689320893928883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 179}], {
             RGBColor[
             0.667263316582815, 0.7334727702800701, 0.9374487907581828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 236}], {
             RGBColor[
             0.6775905889256031, 0.738178032577419, 0.7458660281775675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 243}], {
             RGBColor[
             0.49781729276290376`, 0.6006979883501291, 0.954297567861871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 254}], {
             RGBColor[
             0.6755878736680652, 0.7321147201871944, 0.679216265352927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 276}], {
             RGBColor[
             0.672991015656603, 0.7377056666224134, 0.9260151984572027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 283}], {
             RGBColor[
             0.6758438456005007, 0.7388853851186006, 0.8787364233995865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 292}], {
             RGBColor[
             0.6236364081599224, 0.6996469798302569, 0.9666103240403379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 386}], {
             RGBColor[
             0.5228613453563697, 0.6203894443157725, 0.95670699574849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 422}], {
             RGBColor[
             0.6164324637702145, 0.6939027501197651, 0.9659232053934104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 53}], {
             RGBColor[
             0.9870398639548474, 0.9884759906834379, 0.8450704873723613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 68}], {
             RGBColor[
             0.9880547782352794, 0.988239946226495, 0.7805855304651466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 90}], {
             RGBColor[
             0.9393705384631164, 0.9533092427271868, 0.9530519713825676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 205}], {
             RGBColor[
             0.8272165258600239, 0.8650699440717562, 0.9420390267358563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 257}], {
             RGBColor[
             0.9784303719791869, 0.9570205576009152, 0.6372462281218065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 272}], {
             RGBColor[
             0.9882457641214285, 0.9886484457253327, 0.8013731655442087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 293}], {
             RGBColor[
             0.8276559393624784, 0.86541321723954, 0.9420828233672284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 298}], {
             RGBColor[
             0.9532044288754397, 0.9643400114310217, 0.9543714601997547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 306}], {
             RGBColor[
             0.9115203261060991, 0.9311022393675767, 0.9503955932657773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 317}], {
             RGBColor[
             0.9596685847301223, 0.9694414770451324, 0.9531547453208334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 357}], {
             RGBColor[
             0.970064645467424, 0.9771948421210249, 0.9355569262194754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 418}], {
             RGBColor[
             0.9356499943597223, 0.9503425818506197, 0.9526971025646169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 420}], {
             RGBColor[
             0.9073265405266362, 0.92775822858379, 0.9499955862533714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 55}], {
             RGBColor[
             0.9546273901289833, 0.9310821221141232, 0.6601606917687098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 189}], {
             RGBColor[
             0.9641882875727663, 0.972152446563624, 0.9159560933360973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 230}], {
             RGBColor[
             0.8473379026317176, 0.8815214386682105, 0.9811246880570306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 242}], {
             RGBColor[
             0.9675113203662473, 0.9731190796349833, 0.8312619739623421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 339}], {
             RGBColor[
             0.8213629210927927, 0.861229585672831, 0.9785357446472339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 364}], {
             RGBColor[
             0.9645242571404768, 0.9722913786138965, 0.9103882081377632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 365}], {
             RGBColor[
             0.7384855092745826, 0.7948674488122417, 0.9713813105375826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 374}], {
             RGBColor[
             0.8879676751666221, 0.615257260272155, 0.5839644786572481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 437}], {
             RGBColor[
             0.9597691982893737, 0.9695165144728826, 0.9529844328092398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 78}], {
             RGBColor[
             0.8399911209039863, 0.875513486252486, 0.9667964126301487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 85}], {
             RGBColor[
             0.9752972550867951, 0.9792052819054554, 0.8402567622043471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 95}], {
             RGBColor[
             0.9687165778391291, 0.9586782925002988, 0.6725869751650284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 137}], {
             RGBColor[
             0.9609069822862202, 0.9703650719147804, 0.9510584612841713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 145}], {
             RGBColor[
             0.9517912287800006, 0.9635665578755181, 0.966489054200913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 183}], {
             RGBColor[
             0.8953634339134093, 0.9188949005410936, 0.9722824636993399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 346}], {
             RGBColor[
             0.9664720150749461, 0.9745154642567072, 0.9416383123658666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 358}], {
             RGBColor[
             0.9680055052499754, 0.9756591387183844, 0.9390425134978351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 404}], {
             RGBColor[
             0.9727943535393729, 0.9782316732480161, 0.8861998464276087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 407}], {
             RGBColor[
             0.8344535385105227, 0.8711874847995273, 0.966244478168818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 408}], {
             RGBColor[
             0.7218788799705007, 0.7808844532200472, 0.9566368487691839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 71}], {
             RGBColor[
             0.8420403260061917, 0.8769880434690339, 0.9847681728178469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 76}], {
             RGBColor[
             0.7680182000598368, 0.8191613960907477, 0.9773903390796104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 238}], {
             RGBColor[
             0.935524639027663, 0.9482749538671273, 0.8678298161016181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 328}], {
             RGBColor[
             0.9087060703923068, 0.9299188667379691, 0.9869001691606689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 402}], {
             RGBColor[
             0.9334995240050039, 0.9474375167621756, 0.9013912128567573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 431}], {
             RGBColor[
             0.88729584599614, 0.9129696388659365, 0.9891122639611061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 436}], {
             RGBColor[
             0.907211595118719, 0.9288042895259059, 0.9894299259772761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 459}], {
             RGBColor[
             0.9344635501551247, 0.9478361663495926, 0.8854148047295534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 462}], {
             RGBColor[
             0.9360444422944108, 0.9483622808103129, 0.8499383357480627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 487}], {
             RGBColor[
             0.9347582480159349, 0.947958031488427, 0.880530898522313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 57}], {
             RGBColor[
             0.7265325363090505, 0.7862920063072003, 0.9733776314528666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 92}], {
             RGBColor[
             0.871671636908225, 0.8980089799755202, 0.8650770092235445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 106}], {
             RGBColor[
             0.8511003205349421, 0.8842425433836927, 0.9704582517769273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 117}], {
             RGBColor[
             0.768715710954559, 0.8192458229442732, 0.9775820560773512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 139}], {
             RGBColor[
             0.8720303151966338, 0.8973905806682567, 0.8034001864923321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 140}], {
             RGBColor[
             0.8601284239548976, 0.890975688132133, 0.9551760275934271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 169}], {
             RGBColor[
             0.7845009191073011, 0.8315773475252206, 0.9791553781048594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 204}], {
             RGBColor[
             0.7958895333239079, 0.8406530692712079, 0.9802430275092664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 219}], {
             RGBColor[
             0.861095921368868, 0.8916972461193404, 0.9535383068353145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 244}], {
             RGBColor[
             0.817385288779287, 0.8577932011845892, 0.982293311854088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 255}], {
             RGBColor[
             0.8092508149246438, 0.8513069925373073, 0.9815174384761016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 274}], {
             RGBColor[
             0.8678242958233119, 0.8964180055647528, 0.9288374076001163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 334}], {
             RGBColor[
             0.87162041219908, 0.89651383960404, 0.7587847748366958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 338}], {
             RGBColor[
             0.8706443931803429, 0.8975841882950814, 0.8821010962161012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 340}], {
             RGBColor[
             0.8677385266730377, 0.8963825378169478, 0.930258824383604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 361}], {
             RGBColor[
             0.850756135770286, 0.883985850949763, 0.9710408668057267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 363}], {
             RGBColor[
             0.8361474254522562, 0.872753619682982, 0.9840828611991128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 369}], {
             RGBColor[
             0.8560912844460236, 0.8879647960966239, 0.9620098517273319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 370}], {
             RGBColor[
             0.7367282912809732, 0.7942570075818742, 0.9743938490237205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 379}], {
             RGBColor[
             0.8457929779647224, 0.8802843359847987, 0.9794421983716741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[
             0.8194571238548769, 0.8553208533573561, 0.7181333019432221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 113}], {
             RGBColor[
             0.7680802624420346, 0.8193166742831206, 0.9773681848779168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 127}], {
             RGBColor[
             0.7973983706031933, 0.8423561987550906, 0.9684480094947343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 130}], {
             RGBColor[
             0.8108168315958069, 0.8264333427028332, 0.6626098953907587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 143}], {
             RGBColor[
             0.8029627558294763, 0.8465061081460079, 0.959028956730734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 179}], {
             RGBColor[
             0.8094815324860887, 0.8513678011029921, 0.9479943682203371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 214}], {
             RGBColor[
             0.817267202151533, 0.8564517211724174, 0.9024548773584433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 302}], {
             RGBColor[
             0.6648712388877172, 0.7381217321184372, 0.9672318095834941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 308}], {
             RGBColor[
             0.8094100533146082, 0.8513144920539386, 0.9481153638128996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 315}], {
             RGBColor[
             0.7994372918498938, 0.8438768228824527, 0.9649966476598992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 325}], {
             RGBColor[
             0.8174449363861426, 0.8565252188459899, 0.8995093611295094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 347}], {
             RGBColor[
             0.6623051518059858, 0.7361170853872046, 0.9669760460046344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 386}], {
             RGBColor[
             0.6650795612596434, 0.7382844751386947, 0.9672525732106445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 421}], {
             RGBColor[
             0.8196383713673636, 0.8574322605794327, 0.8631584670629064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 423}], {
             RGBColor[
             0.8184353753803475, 0.8569347908232148, 0.8830952238215821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 477}], {
             RGBColor[
             0.795396262921483, 0.8408630301242216, 0.9718370555665563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 56}], {
             RGBColor[
             0.688163227039684, 0.7538626976094768, 0.9714926280713436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 88}], {
             RGBColor[
             0.6920041746158189, 0.7567607553127058, 0.9661518617266491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 166}], {
             RGBColor[
             0.7150447588338991, 0.7732845678358378, 0.8976021885927976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 210}], {
             RGBColor[
             0.637845980411488, 0.7137410909734279, 0.9666933241692099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 227}], {
             RGBColor[
             0.7003188757019276, 0.7629618457686523, 0.9520772416092231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 236}], {
             RGBColor[
             0.7177753694099327, 0.7729840696871513, 0.7484265668560228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 243}], {
             RGBColor[
             0.5380020732472333, 0.6355040254598614, 0.9568581065403263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 276}], {
             RGBColor[
             0.7131757961409324, 0.7725117037321457, 0.928575737135658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 326}], {
             RGBColor[
             0.5853496028021732, 0.6726191271405113, 0.9614905365726227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 428}], {
             RGBColor[
             0.5981943738928501, 0.6826535599404242, 0.9627707833137309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 469}], {
             RGBColor[
             0.6519998204082146, 0.7250269787910657, 0.96804333006338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 495}], {
             RGBColor[
             0.41585272278667335`, 0.5346124599374016, 0.9477187456652106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 90}], {
             RGBColor[
             0.9448227349181415, 0.9559965403250541, 0.8820710031508299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 178}], {
             RGBColor[
             0.9426322687777019, 0.9542499220832871, 0.8818620745349025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 257}], {
             RGBColor[
             0.9838825684342121, 0.9597078551987825, 0.5662652598900688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 272}], {
             RGBColor[
             0.9936979605764537, 0.9913357433232001, 0.730392197312471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[
             0.8331081358175035, 0.8681005148374074, 0.8711018551354907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 298}], {
             RGBColor[
             0.9586566253304648, 0.967027309028889, 0.883390491968017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 306}], {
             RGBColor[
             0.9169725225611243, 0.9337895369654441, 0.8794146250340396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 317}], {
             RGBColor[
             0.9651207811851474, 0.9721287746429997, 0.8821737770890957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 357}], {
             RGBColor[
             0.9755168419224491, 0.9798821397188923, 0.8645759579877377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 418}], {
             RGBColor[
             0.9411021908147474, 0.953029879448487, 0.8817161343328792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 420}], {
             RGBColor[
             0.9127787369816613, 0.9304455261816573, 0.8790146180216337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 432}], {
             RGBColor[
             0.9888949199729004, 0.9896757782683248, 0.8337034452822939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 55}], {
             RGBColor[
             0.8701441769763749, 0.8642278318681513, 0.6560338879427174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 70}], {
             RGBColor[
             0.8339325848451256, 0.870813149138256, 0.9839178925713594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 84}], {
             RGBColor[
             0.7116309751414913, 0.7746507934670436, 0.9718923830986909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 131}], {
             RGBColor[
             0.8823161134650315, 0.9047419067543507, 0.7496390445165206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 135}], {
             RGBColor[
             0.8786564222523124, 0.9048645116971166, 0.9292081697561204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 147}], {
             RGBColor[
             0.8557392572889209, 0.8880843066028177, 0.9819451406265393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 230}], {
             RGBColor[
             0.7628546894791091, 0.8146671484222386, 0.9769978842310381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 242}], {
             RGBColor[
             0.8830281072136389, 0.9062647893890114, 0.8271351701363497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 365}], {
             RGBColor[
             0.654002296121974, 0.7280131585662698, 0.9672545067115901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 374}], {
             RGBColor[
             0.8034844620140137, 0.5484029700261831, 0.5798376748312557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 385}], {
             RGBColor[
             0.7784456701324188, 0.8268469410044459, 0.9785518474765621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 391}], {
             RGBColor[
             0.8340681743987433, 0.8709212645678304, 0.9839308252240258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 230}], {
             RGBColor[
             0.8617522598637992, 0.8576720024388749, 0.65519746007186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 242}], {
             RGBColor[
             0.9819256775983289, 0.9492696434056477, 0.5053347459771717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 250}], {
             RGBColor[
             0.7184692423676775, 0.7430656808249352, 0.642743577696659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 339}], {
             RGBColor[
             0.8357772783248744, 0.8373801494434954, 0.6526085166620634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 365}], {
             RGBColor[
             0.7528998665066642, 0.771018012582906, 0.645454082552412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 88}], {
             RGBColor[
             0.9382414262363359, 0.9534276520342964, 0.9882643795307117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 164}], {
             RGBColor[
             0.946134287375874, 0.9593141349487898, 0.9749038244093515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 166}], {
             RGBColor[
             0.9612820104544161, 0.9699514645574282, 0.9197147063968603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 210}], {
             RGBColor[
             0.8840832320320051, 0.9104079876950183, 0.9888058419732726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 227}], {
             RGBColor[
             0.9465561273224448, 0.9596287424902428, 0.9741897594132858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 236}], {
             RGBColor[
             0.9640126210304497, 0.9696509664087416, 0.7705390846600855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 243}], {
             RGBColor[
             0.7842393248677504, 0.8321709221814517, 0.978970624344389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 276}], {
             RGBColor[
             0.9594130477614495, 0.9691786004537362, 0.9506882549397205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 326}], {
             RGBColor[
             0.8315868544226902, 0.8692860238621019, 0.9836030543766853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 428}], {
             RGBColor[
             0.8444316255133673, 0.8793204566620147, 0.9848833011177935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 495}], {
             RGBColor[
             0.6620899744071904, 0.731279356658992, 0.9698312634692732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 92}], {
             RGBColor[
             0.8485367820579279, 0.8799358555350589, 0.8627711430995775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 106}], {
             RGBColor[
             0.827965465684645, 0.8661694189432314, 0.9681523856529602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 139}], {
             RGBColor[
             0.8488954603463366, 0.8793174562277954, 0.8010943203683651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 140}], {
             RGBColor[
             0.8369935691046007, 0.8729025636916717, 0.9528701614694601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 169}], {
             RGBColor[
             0.761366064257004, 0.8135042230847593, 0.9768495119808923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 175}], {
             RGBColor[
             0.8355781387518508, 0.8718469380521454, 0.9552661158533056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 204}], {
             RGBColor[
             0.7727546784736108, 0.8225799448307466, 0.9779371613852994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 219}], {
             RGBColor[
             0.8379610665185708, 0.8736241216788792, 0.9512324407113473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 255}], {
             RGBColor[
             0.7861159600743467, 0.8332338680968461, 0.9792115723521344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 274}], {
             RGBColor[
             0.8446894409730148, 0.8783448811242915, 0.9265315414761492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 334}], {
             RGBColor[
             0.8484855573487831, 0.8784407151635787, 0.7564789087127286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 337}], {
             RGBColor[
             0.7081336000575198, 0.7719186174704099, 0.971543797435149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 361}], {
             RGBColor[
             0.8276212809199889, 0.8659127265093017, 0.9687350006817597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 363}], {
             RGBColor[
             0.8130125706019591, 0.8546804952425208, 0.9817769950751458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 369}], {
             RGBColor[
             0.8329564295957265, 0.8698916716561627, 0.9597039856033649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 370}], {
             RGBColor[
             0.7135934364306762, 0.776183883141413, 0.9720879828997533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 466}], {
             RGBColor[
             0.830703751892004, 0.8682116283131476, 0.9635171813633254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 118}], {
             RGBColor[
             0.8911903186511567, 0.9147032559504749, 0.9325962798385266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 141}], {
             RGBColor[
             0.9905378017330463, 0.9903412984532902, 0.8054696292760695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 188}], {
             RGBColor[
             0.8701362172766307, 0.898255631939598, 0.9304978037752775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 220}], {
             RGBColor[
             0.9864051570978954, 0.988646197335523, 0.8749652594209008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 240}], {
             RGBColor[
             0.9426910625322946, 0.9555793124068834, 0.9375586849145621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 304}], {
             RGBColor[
             0.9708836349462997, 0.9775368906714236, 0.9221353063177229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 310}], {
             RGBColor[
             0.9872021588425366, 0.9889757780389425, 0.8617568779377982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 371}], {
             RGBColor[
             0.9344458949938945, 0.9490048396208739, 0.9367722534742016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 382}], {
             RGBColor[
             0.9485815722441376, 0.9602762449574805, 0.9381205269893977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 429}], {
             RGBColor[
             0.9542185609659464, 0.9647710267522682, 0.9386581880058831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 74}], {
             RGBColor[
             0.8616864142832193, 0.8894499326660188, 0.8135893789863382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 82}], {
             RGBColor[
             0.8505542793379658, 0.8807534242394275, 0.8124798318107112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 105}], {
             RGBColor[
             0.9575901735457878, 0.9651837643672532, 0.8229324013952399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 153}], {
             RGBColor[
             0.9947064284422014, 0.9910859106370797, 0.6652055879495224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 195}], {
             RGBColor[
             0.9842517129737699, 0.9572455180133009, 0.5033497611743548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 263}], {
             RGBColor[
             0.994761503757646, 0.9912037111678476, 0.6712001961502345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 323}], {
             RGBColor[
             0.893338655003666, 0.9141769036827709, 0.8167441785343456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 342}], {
             RGBColor[
             0.8662058707780871, 0.892980566428951, 0.8140398361730246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 395}], {
             RGBColor[
             0.9676339492154981, 0.9730642538897564, 0.8194475331557667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 447}], {
             RGBColor[
             0.9919905450892976, 0.9903672000804777, 0.739608743019297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 453}], {
             RGBColor[
             0.9946316848878219, 0.9909260417319947, 0.6570702133190747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 463}], {
             RGBColor[
             0.9749162417764856, 0.9784953757580812, 0.8071205113761031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 116}], {
             RGBColor[
             0.835890189024991, 0.8713110012914744, 0.9184068108801008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 118}], {
             RGBColor[
             0.7407503599889602, 0.7973990782254079, 0.9747947312441636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 133}], {
             RGBColor[
             0.7703859125303378, 0.8208404246222998, 0.977671614850926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 151}], {
             RGBColor[
             0.7220190213866651, 0.7827660141458489, 0.9729277664665983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 188}], {
             RGBColor[
             0.7196962586144342, 0.7809514542145313, 0.9726962551809144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 192}], {
             RGBColor[
             0.7916568696458397, 0.8378013084414514, 0.9797004577294102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 249}], {
             RGBColor[
             0.8395706069108022, 0.8719094158936346, 0.7902816783849527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 260}], {
             RGBColor[
             0.762804427002265, 0.8147951538561569, 0.9769484859931864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 280}], {
             RGBColor[
             0.8395502429383239, 0.8718658594156168, 0.7880651856525545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 310}], {
             RGBColor[
             0.8367622001803401, 0.8716716003138758, 0.9039553293434353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 327}], {
             RGBColor[
             0.8202613267432501, 0.8600967169573586, 0.9646424279316468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 483}], {
             RGBColor[
             0.8391294355934298, 0.8726505129923634, 0.864724112339672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 64}], {
             RGBColor[
             0.8318266693514593, 0.8687403234801252, 0.9459862433701874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 91}], {
             RGBColor[
             0.9859905570346081, 0.9865355193500478, 0.770992904342743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 172}], {
             RGBColor[
             0.8647904571799105, 0.8944918850657779, 0.9492717656768159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 303}], {
             RGBColor[
             0.9854063959624586, 0.9852860578844642, 0.7074105766635184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 362}], {
             RGBColor[
             0.9847064007797132, 0.9868644983489226, 0.8547883895048383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 384}], {
             RGBColor[
             0.9795867128258378, 0.9842963843659756, 0.9194385499345943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 435}], {
             RGBColor[
             0.7637825444785045, 0.8141669083129133, 0.9401729337218357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 473}], {
             RGBColor[
             0.9019548267502492, 0.92357532490564, 0.9529626008761987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 132}], {
             RGBColor[
             0.9142572725796719, 0.9090957641852735, 0.675185670651648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 209}], {
             RGBColor[
             0.9082512600237845, 0.9289268869174887, 0.9650376483500342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 233}], {
             RGBColor[
             0.7529437209562244, 0.8071804933542959, 0.9759421517815476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 75}], {
             RGBColor[
             0.5773437631743141, 0.6611813695444901, 0.9629098728865368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 149}], {
             RGBColor[
             0.6244570583778475, 0.6093211509386258, 0.6029723180345757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 158}], {
             RGBColor[
             0.6556331057986235, 0.7199542730392123, 0.8123895731335666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 165}], {
             RGBColor[
             0.5831278103030109, 0.6657934117211362, 0.9634615604651517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 182}], {
             RGBColor[
             0.6407701828206029, 0.7109964734004646, 0.9426306144944476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 206}], {
             RGBColor[
             0.4830781288310734, 0.587392339485957, 0.953553630084104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 252}], {
             RGBColor[
             0.6126416314055296, 0.6893269315369526, 0.9662766150692091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 275}], {
             RGBColor[
             0.6453040641370438, 0.7143778346627169, 0.9349559360513453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 282}], {
             RGBColor[
             0.6526466637454651, 0.7190716496349566, 0.887494563606747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 324}], {
             RGBColor[
             0.6421825688006073, 0.6760454932333722, 0.6357304306010712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 410}], {
             RGBColor[
             0.6531664539713202, 0.7192865962513473, 0.8788802943903429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 441}], {
             RGBColor[
             0.6356345633140761, 0.6536362333280539, 0.611966000876027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 467}], {
             RGBColor[
             0.619576435344289, 0.6948565559574811, 0.9669380628596606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 91}], {
             RGBColor[
             0.8401212142327374, 0.8723895399300157, 0.7943401347134926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 172}], {
             RGBColor[
             0.71892111437804, 0.7803459056457457, 0.9726189960475655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 303}], {
             RGBColor[
             0.839537053160588, 0.8711400784644321, 0.7307578070342678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 366}], {
             RGBColor[
             0.6192382683294427, 0.7010966776952038, 0.9636244781933734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 384}], {
             RGBColor[
             0.8337173700239671, 0.8701504049459433, 0.9427857803053437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 435}], {
             RGBColor[
             0.6179132016766338, 0.700020928892881, 0.9635201640925852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 473}], {
             RGBColor[
             0.7560854839483786, 0.8094293454856077, 0.9763098312469481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 88}], {
             RGBColor[
             0.947975766892748, 0.9607209926472506, 0.9729476359441959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 166}], {
             RGBColor[
             0.9710163511108281, 0.9772448051703826, 0.9043979628103445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 167}], {
             RGBColor[
             0.9698421568455413, 0.9767592456662703, 0.9238574005034956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 175}], {
             RGBColor[
             0.9608138780089868, 0.9702956348972639, 0.9512160625400432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[
             0.893817572688417, 0.9177013283079727, 0.9734890983867568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 227}], {
             RGBColor[
             0.9562904679788568, 0.966922083103197, 0.95887301582677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 309}], {
             RGBColor[
             0.9632952415187641, 0.972146231739996, 0.9470157613612423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 320}], {
             RGBColor[
             0.9715919798386664, 0.9774828424423272, 0.8948583051106682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 337}], {
             RGBColor[
             0.8333693393146557, 0.8703673143155284, 0.9674937441218865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 348}], {
             RGBColor[
             0.973368184059243, 0.9782173485339021, 0.8654220045065408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 428}], {
             RGBColor[
             0.8541659661697792, 0.886613797274969, 0.9695665575312777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 434}], {
             RGBColor[
             0.973610473709486, 0.9783175415308374, 0.8614066379764993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 474}], {
             RGBColor[
             0.7453135728126442, 0.7999598074190002, 0.9598231800118298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 495}], {
             RGBColor[
             0.6718243150636024, 0.7385726972719464, 0.9545145198827574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 208}], {
             RGBColor[
             0.9729830123473411, 0.9784250668535606, 0.8882401595494425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 305}], {
             RGBColor[
             0.8937462327627794, 0.9159502165793119, 0.8988546843520253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 314}], {
             RGBColor[
             0.9730725969306766, 0.978491878889131, 0.8880885162172567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 394}], {
             RGBColor[
             0.963721621010154, 0.971517936358423, 0.903917279325582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 398}], {
             RGBColor[
             0.9682600901137842, 0.9749027191848493, 0.8962348349554545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 427}], {
             RGBColor[
             0.986720172956491, 0.9731336063375164, 0.6039264491445331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 445}], {
             RGBColor[
             0.9898618653265123, 0.9900756350214055, 0.8176786583985831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 460}], {
             RGBColor[
             0.8568786285423066, 0.8871489639581085, 0.8951800661106784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 472}], {
             RGBColor[
             0.95757863774464, 0.9666675593511346, 0.9049910772482874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 70}], {
             RGBColor[
             0.9327170756245996, 0.9483333088221513, 0.963836363745652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 96}], {
             RGBColor[
             0.8034158539459164, 0.8466362756903429, 0.9511586835040067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 131}], {
             RGBColor[
             0.9811006042445055, 0.982262066438246, 0.7295575156908132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 135}], {
             RGBColor[
             0.9774409130317865, 0.9823846713810118, 0.909126640930413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 147}], {
             RGBColor[
             0.9545237480683948, 0.9656044662867129, 0.9618636118008318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 171}], {
             RGBColor[
             0.7943770119404598, 0.8392981365551213, 0.9504471127509679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 180}], {
             RGBColor[
             0.9802661887783646, 0.9835529955084967, 0.8623045102303596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 216}], {
             RGBColor[
             0.9782917562459371, 0.9827365169157364, 0.8950259669602817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 238}], {
             RGBColor[
             0.9814550212656259, 0.9840446082935806, 0.8426024793165843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 281}], {
             RGBColor[
             0.9768413509182081, 0.9821367370390037, 0.9190629367694161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 343}], {
             RGBColor[
             0.9604048129877317, 0.9699905548741944, 0.9519085029197831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 385}], {
             RGBColor[
             0.8772301609118929, 0.9043671006883411, 0.9584703186508546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 391}], {
             RGBColor[
             0.9328526651782173, 0.9484414242517256, 0.9638492963983183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 465}], {
             RGBColor[
             0.9783253520130246, 0.9827504096287989, 0.8944691981565822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 205}], {
             RGBColor[
             0.8336836365954811, 0.8675211972126806, 0.8065731015969038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 257}], {
             RGBColor[
             0.984897482714644, 0.9594718107418396, 0.5017803029828539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 272}], {
             RGBColor[
             0.9947128748568856, 0.991099698866257, 0.6659072404052562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 306}], {
             RGBColor[
             0.9179874368415561, 0.9335534925085012, 0.8149296681268247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 317}], {
             RGBColor[
             0.9661356954655794, 0.9718927301860567, 0.8176888201818808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 142}], {
             RGBColor[
             0.6797178079691915, 0.7402582847358468, 0.7663227569392245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 173}], {
             RGBColor[
             0.55604794390199, 0.6464798898422444, 0.9599449650449676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 194}], {
             RGBColor[
             0.6754529322675591, 0.7396020083060415, 0.9174961138826534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 241}], {
             RGBColor[
             0.6782194873160643, 0.7407460499158202, 0.8716471371139622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 388}], {
             RGBColor[
             0.6800420144864845, 0.7414997117376008, 0.8414431453509749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 402}], {
             RGBColor[
             0.6777407286941604, 0.7405480709221275, 0.8795814064665078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 461}], {
             RGBColor[
             0.5888510915142433, 0.6721059580700923, 0.9632144762361139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 487}], {
             RGBColor[
             0.6789994527050913, 0.741068585648379, 0.8587210921320636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 490}], {
             RGBColor[
             0.6772219992646844, 0.7403335629723009, 0.8881780955416538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 84}], {
             RGBColor[
             0.7743169533949321, 0.8242409647537845, 0.9779759635681549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 96}], {
             RGBColor[
             0.7673173414198833, 0.8187062872931887, 0.977323792799178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 131}], {
             RGBColor[
             0.9450020917184724, 0.9543320780410917, 0.7557226249859845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 135}], {
             RGBColor[
             0.9413424005057534, 0.9544546829838576, 0.9352917502255844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 147}], {
             RGBColor[
             0.9184252355423617, 0.9376744778895587, 0.9880287210960033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 170}], {
             RGBColor[
             0.7851713871618504, 0.8327205309092532, 0.9790578320855905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 171}], {
             RGBColor[
             0.7582784994144267, 0.811368148157967, 0.9766122220461393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 216}], {
             RGBColor[
             0.942193243719904, 0.954806528518582, 0.9211910762554532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[
             0.9453565087395928, 0.9561146198964263, 0.8687675886117557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 265}], {
             RGBColor[
             0.9458621011205426, 0.9563236953390806, 0.8603886144282775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 374}], {
             RGBColor[
             0.8661704402674546, 0.5979931413129241, 0.5859212553007196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 385}], {
             RGBColor[
             0.8411316483858597, 0.8764371122911869, 0.9846354279460261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 391}], {
             RGBColor[
             0.8967541526521842, 0.9205114358545714, 0.9900144056934896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 433}], {
             RGBColor[
             0.917347884522816, 0.9368709912631819, 0.9898523953539461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 194}], {
             RGBColor[
             0.8962972299098877, 0.9187555092487247, 0.9359481650702015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 228}], {
             RGBColor[
             0.8887315935540219, 0.8804275929820291, 0.6603385435340694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 388}], {
             RGBColor[
             0.9008863121288131, 0.920653212680284, 0.859895196538523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 431}], {
             RGBColor[
             0.852381348327625, 0.8852336939685717, 0.9857545087584048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 462}], {
             RGBColor[
             0.9011299446258957, 0.9206263359129481, 0.8465805805453613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 487}], {
             RGBColor[
             0.8998437503474199, 0.9202220865910622, 0.8771731433196117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 490}], {
             RGBColor[
             0.898066296907013, 0.9194870639149841, 0.906630146729202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 73}], {
             RGBColor[
             0.871574003861318, 0.8998349241903945, 0.9521590062339615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 144}], {
             RGBColor[
             0.9092844817308343, 0.9294834152178588, 0.9558675380733553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 163}], {
             RGBColor[
             0.6636175105446558, 0.7301790441393154, 0.9352329238644214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 187}], {
             RGBColor[
             0.9701534335401885, 0.9374542496832087, 0.6228253132947938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 279}], {
             RGBColor[
             0.9729217775214108, 0.9793256865287638, 0.9307205469114608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 322}], {
             RGBColor[
             0.977495754950699, 0.9622216238599111, 0.6513488454935726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 494}], {
             RGBColor[
             0.9842579381771427, 0.9862691553726218, 0.8438647667981403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 93}], {
             RGBColor[
             0.8187099257992256, 0.8587019082181605, 0.9824588048696923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 163}], {
             RGBColor[
             0.5599627059067711, 0.6489677018751253, 0.9605765848622778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 187}], {
             RGBColor[
             0.8664986289023038, 0.8562429074190185, 0.6481689742926504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 322}], {
             RGBColor[
             0.8738409503128144, 0.881010281595721, 0.6766925064914291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 494}], {
             RGBColor[
             0.8806031335392581, 0.9050578131084317, 0.8692084277959967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 82}], {
             RGBColor[
             0.7176410952399257, 0.7793459449665451, 0.9724914157023372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 105}], {
             RGBColor[
             0.8246769894477477, 0.8637762850943708, 0.982943985286866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 112}], {
             RGBColor[
             0.7853612683799718, 0.8324269963117449, 0.979194016713863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 153}], {
             RGBColor[
             0.8617932443441612, 0.8896784313641974, 0.8252171718411485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 195}], {
             RGBColor[
             0.8513385288757298, 0.8558380387404185, 0.6633613450659808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 224}], {
             RGBColor[
             0.8618258023384352, 0.8897480696218313, 0.8287609085932215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 234}], {
             RGBColor[
             0.7689140244696535, 0.8194007469695035, 0.9776018221151906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 239}], {
             RGBColor[
             0.8443991052389408, 0.8324297333593745, 0.6364029946372494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 263}], {
             RGBColor[
             0.861848319659606, 0.8897962318949652, 0.8312117800418606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 296}], {
             RGBColor[
             0.6943469618613329, 0.7611483909292176, 0.970169674183212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 342}], {
             RGBColor[
             0.7332926866800471, 0.7915730871560687, 0.9740514200646505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 395}], {
             RGBColor[
             0.834720765117458, 0.871656774616874, 0.9794591170473927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 440}], {
             RGBColor[
             0.8116111802129309, 0.8533579634724715, 0.9816977567380636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 447}], {
             RGBColor[
             0.8590773609912575, 0.8889597208075953, 0.8996203269109231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 453}], {
             RGBColor[
             0.8617185007897818, 0.8895185624591124, 0.8170817972107007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 463}], {
             RGBColor[
             0.8420030576784456, 0.8770878964851989, 0.9671320952677291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 93}], {
             RGBColor[
             0.8538977685355678, 0.8863389184655384, 0.985926725518101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 108}], {
             RGBColor[
             0.8767446083201575, 0.9045563683488251, 0.9881058774923699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 149}], {
             RGBColor[
             0.8854081798996511, 0.8220373838150957, 0.6245009536766744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 158}], {
             RGBColor[
             0.9165842273204272, 0.9326705059156822, 0.8339182087756651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.5951505486431132, 0.6766047121225032, 0.9640445055106865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 182}], {
             RGBColor[
             0.9017213043424065, 0.9237127062769345, 0.9641592501365464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 206}], {
             RGBColor[
             0.7440292503528769, 0.8001085723624269, 0.9750822657262026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 410}], {
             RGBColor[
             0.9141175754931239, 0.9320028291278171, 0.9004089300324414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.6485488480930836, 0.7253040289882384, 0.9656504313481025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[
             0.7484741779104205, 0.8035775233371518, 0.9755262127998445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 238}], {
             RGBColor[
             0.826588015412793, 0.862712361591476, 0.8570942271606803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 333}], {
             RGBColor[
             0.7575444633603949, 0.5825507086891315, 0.5839603790275212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 343}], {
             RGBColor[
             0.8055378071348989, 0.8486583081720898, 0.9664002507638791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 392}], {
             RGBColor[
             0.7268354945391219, 0.7865286795791, 0.9734078274979345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 402}], {
             RGBColor[
             0.824562900390134, 0.8618749244865245, 0.8906556239158194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 431}], {
             RGBColor[
             0.7783592223812701, 0.8274070465902854, 0.9783766750201682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 436}], {
             RGBColor[
             0.798274971503849, 0.8432416972502548, 0.9786943370363382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 459}], {
             RGBColor[
             0.8255269265402547, 0.8622735740739413, 0.8746792157886154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 462}], {
             RGBColor[
             0.8271078186795408, 0.8627996885346618, 0.8392027468071248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 487}], {
             RGBColor[
             0.825821624401065, 0.862395439212776, 0.8697953095813752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 81}], {
             RGBColor[
             0.5217782895335066, 0.622642147144198, 0.9554954447703813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 156}], {
             RGBColor[
             0.7908075079414627, 0.8324388888455557, 0.7421832410413682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 278}], {
             RGBColor[
             0.6771680406771783, 0.7468985813443756, 0.9690245775054726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 329}], {
             RGBColor[
             0.7326671497877455, 0.7907167573823837, 0.974433649192592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 479}], {
             RGBColor[
             0.7580647927115824, 0.8109681484491995, 0.9768560990474111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 482}], {
             RGBColor[
             0.6562617506085976, 0.7305664286491109, 0.9669408338918251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 85}], {
             RGBColor[
             0.8599046864867533, 0.8884729589565581, 0.846645219575544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 95}], {
             RGBColor[
             0.8533240092390875, 0.8679459695514016, 0.6789754325362254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 97}], {
             RGBColor[
             0.8188241614234194, 0.8591431412657241, 0.9823767831382606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 137}], {
             RGBColor[
             0.8455144136861785, 0.8796327489658831, 0.9574469186553682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 145}], {
             RGBColor[
             0.8363986601799588, 0.8728342349266208, 0.9728775115721099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 183}], {
             RGBColor[
             0.7799708653133676, 0.8281625775921964, 0.9786709210705369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 346}], {
             RGBColor[
             0.8510794464749043, 0.8837831413078099, 0.9480267697370635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 358}], {
             RGBColor[
             0.8526129366499338, 0.8849268157694872, 0.9454309708690319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 404}], {
             RGBColor[
             0.8574017849393312, 0.8874993502991189, 0.8925883037988056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 407}], {
             RGBColor[
             0.719060969910481, 0.78045516185063, 0.972632935540015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 408}], {
             RGBColor[
             0.606486311370459, 0.69015213027115, 0.9630253061403807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 430}], {
             RGBColor[
             0.8346699224735463, 0.8715449451757266, 0.9758038135820615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 81}], {
             RGBColor[
             0.7159961791794762, 0.7754064926535587, 0.9373419440563358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 99}], {
             RGBColor[
             0.8616518197090152, 0.8920585656599951, 0.9499008716158459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 122}], {
             RGBColor[
             0.8582109510432978, 0.8893705329067663, 0.949557917983993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 267}], {
             RGBColor[
             0.6335768760897114, 0.7023879803349812, 0.9321367724856009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 278}], {
             RGBColor[
             0.8713859303231479, 0.8996629268537363, 0.950871076791427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 329}], {
             RGBColor[
             0.9268850394337151, 0.9434811028917445, 0.9562801484785466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 406}], {
             RGBColor[
             0.9833446045011855, 0.9861267467398782, 0.869537313037386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 413}], {
             RGBColor[
             0.9735684495721619, 0.9798079734853857, 0.9296258998086222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 476}], {
             RGBColor[
             0.9231941577677778, 0.9405380940376399, 0.9559281088903604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 486}], {
             RGBColor[
             0.979079790933937, 0.9839183228490044, 0.9202966364711781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 493}], {
             RGBColor[
             0.9820812706006891, 0.9856043257058227, 0.8904740251719433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 156}], {
             RGBColor[
             0.8210412367219012, 0.8568872133448273, 0.744629518936192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 278}], {
             RGBColor[
             0.7074017694576169, 0.7713469058436472, 0.9714708554002964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 307}], {
             RGBColor[
             0.8187806123347311, 0.8575709505858726, 0.8997463968578605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 329}], {
             RGBColor[
             0.7629008785681841, 0.8151650818816554, 0.9768799270874159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 372}], {
             RGBColor[
             0.8186849750932075, 0.8494961753170784, 0.6880968354856307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 406}], {
             RGBColor[
             0.8193604436356544, 0.8578107257297891, 0.8901370916462554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 417}], {
             RGBColor[
             0.7980122397856839, 0.8428615373375454, 0.9698141387669204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 461}], {
             RGBColor[
             0.7304708064557374, 0.789368612877754, 0.9737701614158614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 486}], {
             RGBColor[
             0.815095630068406, 0.8556023018389153, 0.9408964150800474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 493}], {
             RGBColor[
             0.8180971097351579, 0.8572883046957336, 0.9110738037808126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 83}], {
             RGBColor[
             0.7225971449503172, 0.7793899950811749, 0.8840960818489074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 99}], {
             RGBColor[
             0.6010030142214215, 0.6853626099917496, 0.9628246872903758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 237}], {
             RGBColor[
             0.41930857022456014`, 0.5375506390385025, 0.9479541741249288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[
             0.37292807060211774`, 0.4956920246667357, 0.945060588160131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 278}], {
             RGBColor[
             0.6107371248355543, 0.6929669711854909, 0.9637948924659571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 329}], {
             RGBColor[
             0.6662362339461215, 0.736785147223499, 0.9692039641530765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 426}], {
             RGBColor[
             0.7225031490571125, 0.7793511253637506, 0.885653837052883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 486}], {
             RGBColor[
             0.7184309854463433, 0.777222367180759, 0.9332204521457081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 89}], {
             RGBColor[
             0.8382804963127237, 0.8739174359021591, 0.9534800727482495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 105}], {
             RGBColor[
             0.8135448545024941, 0.8550797766677795, 0.9818344381112389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 184}], {
             RGBColor[
             0.8324081395991674, 0.8695378418802904, 0.9634204409083753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 195}], {
             RGBColor[
             0.8402063939304762, 0.8471415303138272, 0.6622517978903537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 225}], {
             RGBColor[
             0.849608143810744, 0.8787297360156756, 0.7094988185442594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 263}], {
             RGBColor[
             0.8507161847143524, 0.8810997234683738, 0.8301022328662335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 296}], {
             RGBColor[
             0.6832148269160794, 0.7524518825026263, 0.9690601270075849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 342}], {
             RGBColor[
             0.7221605517347935, 0.7828765787294774, 0.9729418728890233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 395}], {
             RGBColor[
             0.8235886301722044, 0.8629602661902827, 0.9783495698717657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 440}], {
             RGBColor[
             0.8004790452676773, 0.8446614550458802, 0.9805882095624364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 447}], {
             RGBColor[
             0.847945226046004, 0.880263212381004, 0.898510779735296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 453}], {
             RGBColor[
             0.8505863658445283, 0.8808220540325211, 0.8159722500350736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 463}], {
             RGBColor[
             0.8308709227331921, 0.8683913880586076, 0.9660225480921021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 470}], {
             RGBColor[
             0.8485866953967285, 0.880528476442539, 0.8878799725243245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 119}], {
             RGBColor[
             0.9774396733704542, 0.9418888859827785, 0.5682922144830659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 176}], {
             RGBColor[
             0.9747534855817723, 0.9797522843648472, 0.885547793986247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[
             0.7391104933228627, 0.7927962752078739, 0.8853960731231824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 237}], {
             RGBColor[
             0.6865583414829948, 0.7482300971343642, 0.8817844962429704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 270}], {
             RGBColor[
             0.9862830190322313, 0.9717195674162573, 0.60264694245337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 345}], {
             RGBColor[
             0.9921565669494662, 0.9910245531136386, 0.7796495140088009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 375}], {
             RGBColor[
             0.8227547113786208, 0.8604986268015558, 0.8921201865856827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 426}], {
             RGBColor[
             0.9897529203155473, 0.9900305834596123, 0.8194841591709245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 448}], {
             RGBColor[
             0.9288759350177044, 0.9437886604893867, 0.902594573661238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 489}], {
             RGBColor[
             0.9292390012604494, 0.944078159656181, 0.9026292032435841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 131}], {
             RGBColor[
             0.822700482014838, 0.8581697223698792, 0.7436971155133159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 135}], {
             RGBColor[
             0.8190407908021189, 0.858292327312645, 0.9232662407529157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 147}], {
             RGBColor[
             0.7961236258387273, 0.8415121222183461, 0.9760032116233346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 171}], {
             RGBColor[
             0.6359768897107925, 0.7152057924867545, 0.9645867125734706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 230}], {
             RGBColor[
             0.7032390580289156, 0.7680949640377671, 0.9710559552278335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 242}], {
             RGBColor[
             0.8234124757634453, 0.8596926050045399, 0.8211932411331451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 365}], {
             RGBColor[
             0.5943866646717806, 0.6814409741817983, 0.9613125777083855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 374}], {
             RGBColor[
             0.7438688305638201, 0.5018307856417116, 0.573895745828051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 385}], {
             RGBColor[
             0.7188300386822253, 0.7802747566199744, 0.9726099184733574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 391}], {
             RGBColor[
             0.7744525429485498, 0.8243490801833588, 0.9779888962208211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 95}], {
             RGBColor[
             0.9886301434218963, 0.971637765204371, 0.5524357821104237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 97}], {
             RGBColor[
             0.9541302956062282, 0.9628349369186935, 0.8558371327124588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 137}], {
             RGBColor[
             0.9808205478689873, 0.9833245446188525, 0.8309072682295664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 145}], {
             RGBColor[
             0.9717047943627676, 0.9765260305795902, 0.8463378611463082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 183}], {
             RGBColor[
             0.9152769994961764, 0.9318543732451658, 0.8521312706447352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 286}], {
             RGBColor[
             0.8612561270836341, 0.8895287146221703, 0.8467799185443106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 346}], {
             RGBColor[
             0.9863855806577131, 0.9874749369607794, 0.8214871193112618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 358}], {
             RGBColor[
             0.9879190708327426, 0.9886186114224566, 0.8188913204432302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 404}], {
             RGBColor[
             0.99270791912214, 0.9911911459520882, 0.766048653373004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 407}], {
             RGBColor[
             0.8543671040932898, 0.8841469575035994, 0.8460932851142131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 408}], {
             RGBColor[
             0.7417924455532678, 0.7938439259241195, 0.836485655714579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 90}], {
             RGBColor[
             0.8488053311040648, 0.8824361745165532, 0.9853991217430728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 98}], {
             RGBColor[
             0.8741599174237422, 0.9023395681264568, 0.976942492329028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 115}], {
             RGBColor[
             0.7401828975805915, 0.7969557722791163, 0.974738171894535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 124}], {
             RGBColor[
             0.8046220164828772, 0.8472961017210247, 0.9811608610489113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 136}], {
             RGBColor[
             0.8364188958925767, 0.8725595672997395, 0.9842176924950998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 168}], {
             RGBColor[
             0.6485614086045031, 0.7231485311259493, 0.967132117692093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[
             0.8466148649636251, 0.8806895562747861, 0.9851901931271454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 253}], {
             RGBColor[
             0.8682816691296145, 0.8979555801734446, 0.9868928333982909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 261}], {
             RGBColor[
             0.8965312392261819, 0.9153171035186061, 0.7086241948555487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 357}], {
             RGBColor[
             0.8794994381083725, 0.9063217739103913, 0.9679040765799806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 484}], {
             RGBColor[
             0.8946781571378415, 0.9168600237790101, 0.9071902829427331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 500}], {
             RGBColor[
             0.8965274265196466, 0.9176247441924418, 0.8765431035304748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 107}], {
             RGBColor[
             0.9854375744074255, 0.9622814364630065, 0.4198856584747731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 113}], {
             RGBColor[
             0.9340607129945833, 0.926277257388771, 0.6791205414094678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 143}], {
             RGBColor[
             0.9689432063820249, 0.9534666912516583, 0.6607813132622851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 226}], {
             RGBColor[
             0.9837946257295909, 0.9636384916806813, 0.5951424753364933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 292}], {
             RGBColor[
             0.9318350746157447, 0.9245025937588295, 0.6789082580340433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 308}], {
             RGBColor[
             0.9753905038671569, 0.958275075159589, 0.6498677203444507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 386}], {
             RGBColor[
             0.831060011812192, 0.845245058244345, 0.6690049297421955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 421}], {
             RGBColor[
             0.9856188219199122, 0.964392843685083, 0.5649108235944575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 422}], {
             RGBColor[
             0.9246311302260368, 0.9187583640483377, 0.6782211393871158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 423}], {
             RGBColor[
             0.9844158259328961, 0.9638953739288652, 0.5848475803531331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 446}], {
             RGBColor[
             0.9543654420950989, 0.9424676972163334, 0.6810572245973205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 166}], {
             RGBColor[
             0.9651229580305509, 0.9728495222606572, 0.9143739400521657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 167}], {
             RGBColor[
             0.9639487637652642, 0.972363962756545, 0.9338333777453169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 210}], {
             RGBColor[
             0.8879241796081399, 0.9133060453982473, 0.983465075628578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 227}], {
             RGBColor[
             0.9503970748985795, 0.9625268001934719, 0.9688489930685912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 243}], {
             RGBColor[
             0.7880802724438851, 0.8350689798846809, 0.9736298579996944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 326}], {
             RGBColor[
             0.835427801998825, 0.8721840815653309, 0.9782622880319907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 348}], {
             RGBColor[
             0.9674747909789658, 0.9738220656241767, 0.8753979817483619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 428}], {
             RGBColor[
             0.848272573089502, 0.8822185143652438, 0.9795425347730988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 434}], {
             RGBColor[
             0.9677170806292088, 0.9739222586211123, 0.8713826152183204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 469}], {
             RGBColor[
             0.9020780196048664, 0.9245919332158853, 0.9848150815227479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 474}], {
             RGBColor[
             0.739420179732367, 0.795564524509275, 0.9697991572536508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 495}], {
             RGBColor[
             0.6659309219833252, 0.7341774143622211, 0.9644904971245787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 133}], {
             RGBColor[
             0.9129470562645581, 0.9325373475364318, 0.9608452263349964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 184}], {
             RGBColor[
             0.964179675617219, 0.9728058412424957, 0.9455186451299148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 192}], {
             RGBColor[
             0.9342180133800599, 0.9494982313555835, 0.9628740692134805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 225}], {
             RGBColor[
             0.9813796798287956, 0.9819977353778808, 0.6915970227657988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 235}], {
             RGBColor[
             0.9129689647923401, 0.9325548168017941, 0.9608473159899342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 239}], {
             RGBColor[
             0.9650385063117388, 0.9270012242949885, 0.6173916516831617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 249}], {
             RGBColor[
             0.9821317506450224, 0.9836063388077667, 0.773455289869023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 260}], {
             RGBColor[
             0.9053655707364852, 0.926492076770289, 0.9601220974772567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.9821113866725442, 0.9835627823297489, 0.7712387971366248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 296}], {
             RGBColor[
             0.814986362934131, 0.8557198818648316, 0.9511583312291243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 424}], {
             RGBColor[
             0.7582061984365682, 0.8098922091553049, 0.9465044563659875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 440}], {
             RGBColor[
             0.9322505812857289, 0.9479294544080855, 0.9626864137839759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 453}], {
             RGBColor[
             0.9823579018625799, 0.9840900533947264, 0.798070454256613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 470}], {
             RGBColor[
             0.9803582314147801, 0.9837964758047444, 0.8699781767458639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 124}], {
             RGBColor[
             0.852970094805223, 0.8856897195732745, 0.9858142264668746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 178}], {
             RGBColor[
             0.8949629432859708, 0.919083174127036, 0.9898435585451087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[
             0.936213242942481, 0.9245411072425315, 0.6742467439002751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 261}], {
             RGBColor[
             0.9448793175485277, 0.9537107213708559, 0.7132775602735121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 272}], {
             RGBColor[
             0.9460286350847226, 0.956168995366949, 0.8383736813226772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 306}], {
             RGBColor[
             0.8693031970693932, 0.8986227890091929, 0.9873961090442458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 317}], {
             RGBColor[
             0.9174514556934164, 0.9369620266867487, 0.990155261099302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 357}], {
             RGBColor[
             0.9278475164307181, 0.9447153917626412, 0.9725574419979439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 172}], {
             RGBColor[
             0.8730850020611887, 0.8981411015156682, 0.7976256570201211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 303}], {
             RGBColor[
             0.9937009408437367, 0.9889352743343546, 0.5557644680068234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 366}], {
             RGBColor[
             0.7734021560125914, 0.8188918735651263, 0.7886311391659291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 435}], {
             RGBColor[
             0.7720770893597826, 0.8178161247628035, 0.7885268250651409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 473}], {
             RGBColor[
             0.9102493716315273, 0.9272245413555302, 0.8013164922195037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 101}], {
             RGBColor[
             0.9939553683824036, 0.9908650450112249, 0.6841740763646386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 128}], {
             RGBColor[
             0.99330515466553, 0.9894743036175233, 0.613402325936871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 140}], {
             RGBColor[
             0.9821326697037751, 0.9846195373599917, 0.844569539240138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 169}], {
             RGBColor[
             0.9065051648561786, 0.9252211967530793, 0.8685488897515703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 175}], {
             RGBColor[
             0.9807172393510254, 0.9835639117204654, 0.8469654936239834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 204}], {
             RGBColor[
             0.9178937790727854, 0.9342969184990666, 0.8696365391559773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 219}], {
             RGBColor[
             0.9831001671177455, 0.985341095347199, 0.8429318184820253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 274}], {
             RGBColor[
             0.9898285415721894, 0.9900618547926114, 0.8182309192468271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 320}], {
             RGBColor[
             0.991495341180705, 0.9907511192655287, 0.7906077361946086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 334}], {
             RGBColor[
             0.9936246579479575, 0.9901576888318986, 0.6481782864834066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 337}], {
             RGBColor[
             0.8532727006566944, 0.8836355911387299, 0.8632431752058269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 361}], {
             RGBColor[
             0.9727603815191634, 0.9776297001776217, 0.8604343784524375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 363}], {
             RGBColor[
             0.9581516712011336, 0.9663974689108408, 0.8734763728458237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 370}], {
             RGBColor[
             0.8587325370298506, 0.8879008568097329, 0.8637873606704313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 498}], {
             RGBColor[
             0.8570656941750878, 0.8865987065031173, 0.8636212253522006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 108}], {
             RGBColor[
             0.8923474921596075, 0.9169976843934033, 0.9895940944818353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 163}], {
             RGBColor[
             0.6107534324825633, 0.6890460281670814, 0.9655327225001522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 187}], {
             RGBColor[
             0.9172893554780961, 0.8963212337109747, 0.6531251119305246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 189}], {
             RGBColor[
             0.9288320973118245, 0.9440767846469529, 0.9166196047129405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 206}], {
             RGBColor[
             0.759632134192327, 0.8125498884070053, 0.9765704827156682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 266}], {
             RGBColor[
             0.7966850270753614, 0.8414958899396476, 0.9802635687992782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 322}], {
             RGBColor[
             0.9246316768886065, 0.921088607887677, 0.6816486441293035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 364}], {
             RGBColor[
             0.929168066879535, 0.9442157166972253, 0.9110517195146063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 437}], {
             RGBColor[
             0.9244130080284318, 0.9414408525562115, 0.9536479441860829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 100}], {
             RGBColor[
             0.9260670761258123, 0.9413273144358743, 0.8927023655657197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 127}], {
             RGBColor[
             0.9699028182642202, 0.9759428061706263, 0.8851668950713322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 168}], {
             RGBColor[
             0.7438336530031981, 0.7964007543664664, 0.8761532190234758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 213}], {
             RGBColor[
             0.8667380304638387, 0.894646425762524, 0.8868772591948441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 214}], {
             RGBColor[
             0.9897716498125599, 0.990038328587953, 0.8191737629350412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 254}], {
             RGBColor[
             0.9903105372323657, 0.9835963584256523, 0.6064807283916792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 302}], {
             RGBColor[
             0.8373756865487441, 0.8717083395339729, 0.883950695160092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 315}], {
             RGBColor[
             0.9719417395109207, 0.9774634302979884, 0.8817155332364972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 325}], {
             RGBColor[
             0.9899493840471694, 0.9901118262615256, 0.8162282467061073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 368}], {
             RGBColor[
             0.7032322844372247, 0.7624108776024319, 0.8732409304285744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 401}], {
             RGBColor[
             0.98958264191387, 0.9899601689645634, 0.8223061129530946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 477}], {
             RGBColor[
             0.9679007105825099, 0.9744496375397573, 0.8885559411431543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 500}], {
             RGBColor[
             0.9917996709183416, 0.9908769674329589, 0.7855642048618576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 97}], {
             RGBColor[
             0.9475496183585623, 0.942307947513537, 0.6881673456731403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 137}], {
             RGBColor[
             0.9742398706213214, 0.9627975552136959, 0.663237481190248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 145}], {
             RGBColor[
             0.9651241171151017, 0.9559990411744337, 0.6786680741069895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 174}], {
             RGBColor[
             0.9725612180783811, 0.9615456188957123, 0.6660790020827436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 286}], {
             RGBColor[
             0.8546754498359681, 0.8690017252170137, 0.6791101315049921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 294}], {
             RGBColor[
             0.8766480363829576, 0.8861668768253648, 0.6813001535865002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 346}], {
             RGBColor[
             0.9798049034100473, 0.9669479475556227, 0.6538173322719432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 358}], {
             RGBColor[
             0.9813383935850766, 0.9680916220172999, 0.6512215334039115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 404}], {
             RGBColor[
             0.9861272418744742, 0.9706641565469316, 0.5983788663336853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 407}], {
             RGBColor[
             0.8477864268456239, 0.8636199680984429, 0.6784234980748947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 408}], {
             RGBColor[
             0.735211768305602, 0.7733169365189627, 0.6688158686752603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 430}], {
             RGBColor[
             0.9633953794086891, 0.9547097514235394, 0.6815943761169412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 131}], {
             RGBColor[
             0.8157008700397892, 0.8526350449092832, 0.7430449447443391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 147}], {
             RGBColor[
             0.7891240138636786, 0.8359774447577503, 0.9753510408543578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.7379414495585372, 0.7952827485102937, 0.9745218940092746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 171}], {
             RGBColor[
             0.6289772777357436, 0.7096711150261585, 0.9639345418044939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 180}], {
             RGBColor[
             0.8148664545736483, 0.8539259739795341, 0.8757919392838855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 216}], {
             RGBColor[
             0.8128920220412208, 0.8531094953867737, 0.9085133960138077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 238}], {
             RGBColor[
             0.8160552870609097, 0.854417586764618, 0.8560899083701103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 265}], {
             RGBColor[
             0.8165608794418595, 0.8546266622072722, 0.8477109341866321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 281}], {
             RGBColor[
             0.8114416167134919, 0.8525097155100412, 0.9325503658229422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 343}], {
             RGBColor[
             0.7950050787830154, 0.8403635333452317, 0.9653959319733092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 392}], {
             RGBColor[
             0.7163027661872385, 0.7782339047522419, 0.9724035087073646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 433}], {
             RGBColor[
             0.7880466628441329, 0.8351739581313735, 0.9771747151123007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 465}], {
             RGBColor[
             0.8129256178083084, 0.8531233880998363, 0.9079566272101083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 104}], {
             RGBColor[
             0.940450534930573, 0.9183610721668728, 0.6605887471048175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 137}], {
             RGBColor[
             0.9397400228056534, 0.9539947269280185, 0.966638831792283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 145}], {
             RGBColor[
             0.9306242692994336, 0.9471962128887562, 0.9820694247090247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 174}], {
             RGBColor[
             0.9380613702627131, 0.9527427906100349, 0.9694803526847788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 294}], {
             RGBColor[
             0.8421481885672897, 0.8773640485396874, 0.9847015041885354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 346}], {
             RGBColor[
             0.9453050555943792, 0.9581451192699453, 0.9572186828739784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 358}], {
             RGBColor[
             0.9468385457694086, 0.9592887937316226, 0.9546228840059467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 404}], {
             RGBColor[
             0.951627394058806, 0.9618613282612543, 0.9017802169357205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 407}], {
             RGBColor[
             0.8132865790299558, 0.8548171398127654, 0.9818248486769298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 408}], {
             RGBColor[
             0.7007119204899339, 0.7645141082332854, 0.9722172192772955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 430}], {
             RGBColor[
             0.9288955315930212, 0.945906923137862, 0.9849957267189763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 115}], {
             RGBColor[
             0.8138855622226147, 0.8552527837412698, 0.9709349078984535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 124}], {
             RGBColor[
             0.8783246811249005, 0.905593113183178, 0.9773575970528298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 136}], {
             RGBColor[
             0.9101215605345998, 0.930856578761893, 0.9804144284990183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 253}], {
             RGBColor[
             0.9419843337716377, 0.956252591635598, 0.9830895694022094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 261}], {
             RGBColor[
             0.9702339038682052, 0.9736141149807596, 0.7048209308594672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 277}], {
             RGBColor[
             0.8942708456039803, 0.9182176489324119, 0.9789025731588354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 311}], {
             RGBColor[
             0.9479958570964613, 0.9607359758882854, 0.9729136284696734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 319}], {
             RGBColor[
             0.8869833039689566, 0.912406761047692, 0.9782074809320218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 331}], {
             RGBColor[
             0.8930680572049314, 0.9172585781118318, 0.9787878501275924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 377}], {
             RGBColor[
             0.9246922530822745, 0.9424748534884959, 0.9818041941616262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 484}], {
             RGBColor[
             0.9683808217798647, 0.9751570352411636, 0.9033870189466515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 488}], {
             RGBColor[
             0.9621503025725622, 0.9712923381485841, 0.9489538443492598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 122}], {
             RGBColor[
             0.7432177860852431, 0.7993266502449572, 0.9750406612180331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 267}], {
             RGBColor[
             0.5185837111316567, 0.612344097673172, 0.9576195157196411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 278}], {
             RGBColor[
             0.7563927653650933, 0.8096190441919271, 0.9763538200254671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 329}], {
             RGBColor[
             0.8118918744756605, 0.8534372202299354, 0.9817628917125867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 406}], {
             RGBColor[
             0.8683514395431309, 0.8960828640780691, 0.8950200562714261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 413}], {
             RGBColor[
             0.8585752846141073, 0.8897640908235765, 0.9551086430426624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 476}], {
             RGBColor[
             0.8082009928097231, 0.8504942113758307, 0.9814108521244006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 486}], {
             RGBColor[
             0.8640866259758824, 0.8938744401871952, 0.9457793797052183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 493}], {
             RGBColor[
             0.8670881056426344, 0.8955604430440135, 0.9159567684059835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 121}], {
             RGBColor[
             0.8678290889663158, 0.8974473752213976, 0.9872555072974223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 127}], {
             RGBColor[
             0.9049681528109232, 0.926723117461163, 0.9790813016491768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 168}], {
             RGBColor[
             0.6788989875499013, 0.7471810656570032, 0.9700676256013204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 200}], {
             RGBColor[
             0.9211456321258485, 0.9387882550460431, 0.9516970489313628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 213}], {
             RGBColor[
             0.8018033650105418, 0.8454267370530606, 0.9807916657726887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 254}], {
             RGBColor[
             0.9253758717790689, 0.934376669716189, 0.7003951349695239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 259}], {
             RGBColor[
             0.9234710364296217, 0.9402537853063224, 0.9357254616669692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 315}], {
             RGBColor[
             0.9070070740576237, 0.9282437415885252, 0.9756299398143418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 368}], {
             RGBColor[
             0.6382976189839279, 0.7131911888929685, 0.9671553370064192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 401}], {
             RGBColor[
             0.9246479764605733, 0.9407404802551, 0.9162205195309393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 450}], {
             RGBColor[
             0.9273524027491971, 0.9403839765632817, 0.7641948997003021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 454}], {
             RGBColor[
             0.926338306436215, 0.9414394751395269, 0.8882073774008056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 471}], {
             RGBColor[
             0.9070639670950659, 0.9282861723226956, 0.9755336347420329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 475}], {
             RGBColor[
             0.8302820574858716, 0.8676745080608675, 0.9836301556901172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 500}], {
             RGBColor[
             0.9268650054650447, 0.9416572787234956, 0.8794786114397023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 128}], {
             RGBColor[
             0.9935846403908313, 0.9886865194253691, 0.5431058814312542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 169}], {
             RGBColor[
             0.9067846505814798, 0.9244334125609253, 0.7982524452459534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 197}], {
             RGBColor[
             0.7413044622723393, 0.792800179028891, 0.7833716870692188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[
             0.9181732647980865, 0.9335091343069124, 0.7993400946503605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 219}], {
             RGBColor[
             0.9833796528430466, 0.984553311155045, 0.7726353739764085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 337}], {
             RGBColor[
             0.8535521863819955, 0.8828478069465757, 0.79294673070021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 345}], {
             RGBColor[
             0.9943505358989426, 0.9910284569346556, 0.6776251279548373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 355}], {
             RGBColor[
             0.7459600257801924, 0.7965797752153121, 0.783738190082448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 361}], {
             RGBColor[
             0.9730398672444647, 0.9768419159854675, 0.7901379339468207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 362}], {
             RGBColor[
             0.9929758217569006, 0.9904599773083793, 0.7004076989346302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 363}], {
             RGBColor[
             0.9584311569264348, 0.9656096847186866, 0.8031799283402069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 498}], {
             RGBColor[
             0.857345179900389, 0.8858109223109631, 0.7933247808465839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 109}], {
             RGBColor[
             0.7833657328654464, 0.8258362971140529, 0.6956160091794787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[
             0.6180652246819422, 0.7005119675313799, 0.9632807884308078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 186}], {
             RGBColor[
             0.7741292558891999, 0.822686005193995, 0.9441837796671323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 193}], {
             RGBColor[
             0.7803889350064082, 0.8269532946439244, 0.9156226088601774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 196}], {
             RGBColor[
             0.7840467744608863, 0.8272929762228314, 0.7697431839415824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 202}], {
             RGBColor[
             0.7210591833634461, 0.7813592994796343, 0.973443388360731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 330}], {
             RGBColor[
             0.7793281997477897, 0.8265146533548329, 0.9332017371903383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 350}], {
             RGBColor[
             0.7256481333533514, 0.7850184036378556, 0.9738810865073722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 354}], {
             RGBColor[
             0.7678185849156283, 0.8179795171146809, 0.9548660995387961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 414}], {
             RGBColor[
             0.7581267731594066, 0.8107513797757759, 0.971271808812737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 415}], {
             RGBColor[
             0.7787531778877778, 0.8261345186495572, 0.9363566858355428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 485}], {
             RGBColor[
             0.627690453263582, 0.7080312692538036, 0.9642401412629504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 496}], {
             RGBColor[
             0.7272101892931652, 0.7862639446433841, 0.9740300767973754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 118}], {
             RGBColor[
             0.8069449875577928, 0.4875667835073578, 0.5722882042433395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 188}], {
             RGBColor[
             0.7858908861832667, 0.4711191594964811, 0.5701897281800904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 304}], {
             RGBColor[
             0.8866383038529356, 0.5504004182283067, 0.5618272307225357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 319}], {
             RGBColor[
             0.8217115129360739, 0.4991519712533869, 0.5737468667655485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 331}], {
             RGBColor[
             0.8277962661720488, 0.5040037883175266, 0.5743272359611191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 449}], {
             RGBColor[
             0.8336473783270313, 0.5086693063257013, 0.5748853202618109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 488}], {
             RGBColor[
             0.8968785115396795, 0.558037548354279, 0.5444932301827866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 112}], {
             RGBColor[
             0.9049003029465079, 0.8900142821681197, 0.6571979342421106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 148}], {
             RGBColor[
             0.9810742254393321, 0.9475633824833332, 0.5368916426422441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 153}], {
             RGBColor[
             0.9813322789106975, 0.9472657172205723, 0.5032210893693961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 190}], {
             RGBColor[
             0.9209636494658168, 0.9028227586546909, 0.658730070573041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 215}], {
             RGBColor[
             0.849943346794976, 0.846903952938389, 0.6517674514209559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 224}], {
             RGBColor[
             0.9813648369049714, 0.9473353554782061, 0.5067648261214692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 323}], {
             RGBColor[
             0.8799645054721622, 0.8703567102662635, 0.6547596799542192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 351}], {
             RGBColor[
             0.9811640717031254, 0.946905939011933, 0.4849127728797314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 356}], {
             RGBColor[
             0.9347659362092737, 0.9138283274508304, 0.6600465450040788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 408}], {
             RGBColor[
             0.7281126848776127, 0.7493700611722987, 0.6412372701069378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 430}], {
             RGBColor[
             0.9562962959806999, 0.9307628760768752, 0.6540157775486184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 452}], {
             RGBColor[
             0.895025675252944, 0.8821405220849001, 0.6562560834375143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 112}], {
             RGBColor[
             0.8812650276425402, 0.9081608280129793, 0.9885370391227647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 148}], {
             RGBColor[
             0.9574389501353642, 0.9657099283281927, 0.8682307475228981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 153}], {
             RGBColor[
             0.9576970036067296, 0.9654122630654318, 0.8345601942500502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 190}], {
             RGBColor[
             0.897328374161849, 0.9209693044995504, 0.9900691754536951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 195}], {
             RGBColor[
             0.9472422881382982, 0.9315718704416529, 0.6727043674748825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 263}], {
             RGBColor[
             0.9577520789221744, 0.9655300635961995, 0.8405548024507623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 323}], {
             RGBColor[
             0.8563292301681944, 0.888503256111123, 0.9860987848348732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 342}], {
             RGBColor[
             0.8291964459426155, 0.867306918857303, 0.9833944424735522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 395}], {
             RGBColor[
             0.9306245243800264, 0.9473906063181083, 0.9888021394562945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 447}], {
             RGBColor[
             0.954981120253826, 0.9646935525088297, 0.9089633493198248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 453}], {
             RGBColor[
             0.9576222600523503, 0.9652523941603468, 0.8264248196196025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 463}], {
             RGBColor[
             0.9379068169410141, 0.9528217281864333, 0.9764751176766309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 117}], {
             RGBColor[
             0.8701486403301535, 0.8991232355803043, 0.9723568102774449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 139}], {
             RGBColor[
             0.9734632445722282, 0.9772679933042878, 0.7981749406924259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 140}], {
             RGBColor[
             0.9615613533304923, 0.9708531007681642, 0.9499507817935209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 247}], {
             RGBColor[
             0.8405347185153026, 0.8759886147844009, 0.9694051713087742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 255}], {
             RGBColor[
             0.9106837443002384, 0.9311844051733386, 0.9762921926761952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 269}], {
             RGBColor[
             0.9143144890867607, 0.9340794625121697, 0.9766384963551378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 274}], {
             RGBColor[
             0.9692572251989064, 0.9762954182007839, 0.92361216180021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 360}], {
             RGBColor[
             0.9526167512852008, 0.9641822312082274, 0.9650916599303612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 369}], {
             RGBColor[
             0.9575242138216181, 0.967842208732655, 0.9567846059274256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 370}], {
             RGBColor[
             0.8381612206565678, 0.8741344202179053, 0.969168603223814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 425}], {
             RGBColor[
             0.8642019870474327, 0.8944776648396039, 0.9717641034528577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 466}], {
             RGBColor[
             0.9552715361178956, 0.96616216538964, 0.9605978016873862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 468}], {
             RGBColor[
             0.9004163133144809, 0.9229974344072852, 0.9753128759429298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 113}], {
             RGBColor[
             0.9415445400398561, 0.9512637393262107, 0.7301512989864595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 132}], {
             RGBColor[
             0.9848976513095365, 0.9604601490738547, 0.4177881591953958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 143}], {
             RGBColor[
             0.9764270334272978, 0.9784531731890979, 0.7118120708392768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 209}], {
             RGBColor[
             0.9788916387536492, 0.9802912718060699, 0.707640136893782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 214}], {
             RGBColor[
             0.9907314797493546, 0.9883987862155073, 0.6552379914669861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 273}], {
             RGBColor[
             0.9936621590459621, 0.9888523239903557, 0.5515433086525607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 308}], {
             RGBColor[
             0.9828743309124297, 0.9832615570970284, 0.7008984779214424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 421}], {
             RGBColor[
             0.9931026489651852, 0.9893793256225225, 0.6159415811714493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 423}], {
             RGBColor[
             0.991899652978169, 0.9888818558663046, 0.6358783379301248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 446}], {
             RGBColor[
             0.9618492691403717, 0.967454179153773, 0.7320879821743123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 477}], {
             RGBColor[
             0.9688605405193046, 0.9728100951673115, 0.7246201696750991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 129}], {
             RGBColor[
             0.9277036824205495, 0.9450733463100744, 0.9889305831049923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 163}], {
             RGBColor[
             0.633600272267153, 0.7072634780503682, 0.967711874474421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 189}], {
             RGBColor[
             0.951678937096414, 0.9622942345302397, 0.9187987566872092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 206}], {
             RGBColor[
             0.7824789739769167, 0.830767338290292, 0.9787496346899369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 266}], {
             RGBColor[
             0.8195318668599512, 0.8597133398229344, 0.9824427207735471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 364}], {
             RGBColor[
             0.9520149066641246, 0.962433166580512, 0.913230871488875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 374}], {
             RGBColor[
             0.8754583246902699, 0.6053990482387707, 0.58680714200836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 410}], {
             RGBColor[
             0.9525672991171636, 0.9626615950556822, 0.9040762989961758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 437}], {
             RGBColor[
             0.9472598478130214, 0.9596583024394982, 0.9558270961603517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 185}], {
             RGBColor[
             0.8272597850410461, 0.8611712148314064, 0.6992767931708297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 186}], {
             RGBColor[
             0.9833238162483038, 0.9833452524940216, 0.6801797844071541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 196}], {
             RGBColor[
             0.9932413348199902, 0.9879522235228578, 0.5057391886816042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 218}], {
             RGBColor[
             0.9912502797573401, 0.9883018001243769, 0.623995682727874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 295}], {
             RGBColor[
             0.9415454661412404, 0.9510222597306845, 0.710516407665287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 300}], {
             RGBColor[
             0.9264204279767807, 0.9389619648565684, 0.70907376802288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 335}], {
             RGBColor[
             0.9123948897753278, 0.9277783814078221, 0.7077359996684796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 409}], {
             RGBColor[
             0.9385238709874748, 0.9486129217740875, 0.7102282052221112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 456}], {
             RGBColor[
             0.9152135363002123, 0.9300258936366432, 0.7080048446902585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 458}], {
             RGBColor[
             0.899736273772341, 0.9177903986700098, 0.70650057223627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 496}], {
             RGBColor[
             0.9364047496522692, 0.9469231919434107, 0.7100260815373973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 217}], {
             RGBColor[
             0.8908946847707184, 0.9073921856681283, 0.6974629169503617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 290}], {
             RGBColor[
             0.8551473983023621, 0.8794661337896086, 0.6938999615125812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 316}], {
             RGBColor[
             0.9644681147816846, 0.9657434304295995, 0.7015025846889962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 340}], {
             RGBColor[
             0.9878244765491895, 0.9828938143312977, 0.6499310721906952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 355}], {
             RGBColor[
             0.7437622441821654, 0.7902349866939575, 0.6843133707484452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 378}], {
             RGBColor[
             0.963653828737191, 0.9651361372308872, 0.7028809585625102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 384}], {
             RGBColor[
             0.9856583522049982, 0.9815470748040775, 0.6656330400303834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 146}], {
             RGBColor[
             0.992369560076353, 0.9897638046357465, 0.6780742111122191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 201}], {
             RGBColor[
             0.9283948042868706, 0.9431797548569907, 0.8927668968746387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 256}], {
             RGBColor[
             0.9903532972703557, 0.9902788547594095, 0.8095343593039963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 271}], {
             RGBColor[
             0.9470962147977475, 0.9580917519620988, 0.8945506541041124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 284}], {
             RGBColor[
             0.7996180329874027, 0.841685263522896, 0.8803874376676892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 312}], {
             RGBColor[
             0.9476161084707906, 0.9585063010648456, 0.8946002420267618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 376}], {
             RGBColor[
             0.9823863754113513, 0.9852498831293305, 0.8638948948592532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[
             0.9736065912426415, 0.9787019344718839, 0.8787567793224276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 415}], {
             RGBColor[
             0.9871779110548171, 0.9888234025668078, 0.8557840748475085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 442}], {
             RGBColor[
             0.9917916399024288, 0.9885276918204153, 0.6151711666904606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 444}], {
             RGBColor[
             0.9693916890918277, 0.9755584673490758, 0.8858915092412138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 464}], {
             RGBColor[
             0.9731820481627701, 0.9783853109380412, 0.8794754200180812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 148}], {
             RGBColor[
             0.9181232290675883, 0.9343606395455668, 0.8644807789498951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 153}], {
             RGBColor[
             0.9183812825389537, 0.9340629742828059, 0.8308102256770471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 190}], {
             RGBColor[
             0.858012653094073, 0.8896200157169245, 0.9863192068806921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 195}], {
             RGBColor[
             0.9079265670705223, 0.900222581659027, 0.6689543989018795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 224}], {
             RGBColor[
             0.9184138405332276, 0.9341326125404398, 0.8343539624291203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 263}], {
             RGBColor[
             0.9184363578543984, 0.9341807748135736, 0.8368048338777593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 323}], {
             RGBColor[
             0.8170135091004185, 0.8571539673284971, 0.9823488162618703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 342}], {
             RGBColor[
             0.7898807248748395, 0.8359576300746772, 0.9796444739005492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 351}], {
             RGBColor[
             0.9182130753313816, 0.9337031960741666, 0.8125019091873824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 356}], {
             RGBColor[
             0.8718149398375299, 0.9006255845130641, 0.9876356813117297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 395}], {
             RGBColor[
             0.8913088033122505, 0.9160413175354825, 0.9850521708832914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 447}], {
             RGBColor[
             0.9156653991860499, 0.9333442637262038, 0.9052133807468218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 452}], {
             RGBColor[
             0.8320746788812001, 0.8689377791471338, 0.9838452197451653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 463}], {
             RGBColor[
             0.898591095873238, 0.9214724394038074, 0.9727251491036278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 130}], {
             RGBColor[
             0.9329042477807861, 0.9223762286716878, 0.6746278924339961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 143}], {
             RGBColor[
             0.9250501720144555, 0.9424489941148624, 0.9710469537739714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 209}], {
             RGBColor[
             0.9275147773408068, 0.9442870927318344, 0.9668750198284767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 214}], {
             RGBColor[
             0.9393546183365122, 0.9523946071412719, 0.9144728744016808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 273}], {
             RGBColor[
             0.9422852976331197, 0.9528481449161204, 0.8107781915872554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 302}], {
             RGBColor[
             0.7869586550726964, 0.8340646180872917, 0.9792498066267314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 308}], {
             RGBColor[
             0.9314974694995874, 0.9472573780227931, 0.9601333608561371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 325}], {
             RGBColor[
             0.9395323525711218, 0.9524681048148445, 0.9115273581727468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 347}], {
             RGBColor[
             0.784392567990965, 0.832059971356059, 0.9789940430478717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 386}], {
             RGBColor[
             0.7871669774446226, 0.8342273611075492, 0.9792705702538819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 421}], {
             RGBColor[
             0.9417257875523428, 0.9533751465482871, 0.8751764641061439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 423}], {
             RGBColor[
             0.9405227915653267, 0.9528776767920693, 0.8951132208648195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 477}], {
             RGBColor[
             0.9174836791064622, 0.9368059160930762, 0.9838550526097938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 115}], {
             RGBColor[
             0.7771743442877657, 0.8262939203489814, 0.9783083316508586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 203}], {
             RGBColor[
             0.9067685424238932, 0.9284090149434359, 0.9879316260123663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 208}], {
             RGBColor[
             0.9152591577909208, 0.9347413019820583, 0.9735592289031374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 258}], {
             RGBColor[
             0.7061299694675303, 0.7691921074559648, 0.9723221832512181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 289}], {
             RGBColor[
             0.8865064672065079, 0.9123402096462003, 0.9890369723074643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 291}], {
             RGBColor[
             0.8985338029706162, 0.9219304807111681, 0.9901841503295743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 297}], {
             RGBColor[
             0.7121546114998731, 0.7740831832648514, 0.972796465140995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 311}], {
             RGBColor[
             0.9112846391616123, 0.931777112495997, 0.9802870522220786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 349}], {
             RGBColor[
             0.8075128760811838, 0.8499946119673814, 0.9813321929703276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 359}], {
             RGBColor[
             0.7555772323626998, 0.8093356230480715, 0.976214852917618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 381}], {
             RGBColor[
             0.9015565432051423, 0.9243407317240814, 0.9904724619915755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 397}], {
             RGBColor[
             0.8816002205274972, 0.9084281017208755, 0.988569010119362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 419}], {
             RGBColor[
             0.844821615780214, 0.8791404829771875, 0.9850507794735317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 124}], {
             RGBColor[
             0.7443476612817497, 0.8002093173358376, 0.9751532766183368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 136}], {
             RGBColor[
             0.776144540691449, 0.8254727829145525, 0.9782101080645254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 178}], {
             RGBColor[
             0.7863405097624976, 0.8336027718895991, 0.979182608696571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 203}], {
             RGBColor[
             0.8095027405155912, 0.8519840824883835, 0.9783538818254682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 253}], {
             RGBColor[
             0.8080073139284869, 0.8508687957882575, 0.9808852489677164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 277}], {
             RGBColor[
             0.7602938257608295, 0.8128338530850714, 0.9766982527243426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 291}], {
             RGBColor[
             0.8012680010623143, 0.8455055482561158, 0.9806064061426764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 297}], {
             RGBColor[
             0.6148888095915713, 0.697658250809799, 0.9632187209540971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 311}], {
             RGBColor[
             0.8140188372533105, 0.8553521800409448, 0.9707093080351805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 381}], {
             RGBColor[
             0.8042907412968405, 0.8479157992690292, 0.9808947178046775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 419}], {
             RGBColor[
             0.7475558138719122, 0.8027155505221353, 0.9754730352866339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 439}], {
             RGBColor[
             0.8019221249156925, 0.8460271288610806, 0.9806687970597548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 484}], {
             RGBColor[
             0.8344038019367139, 0.869773239393823, 0.9011826985121587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 192}], {
             RGBColor[
             0.9426173138084957, 0.9553207202968255, 0.9288762146078627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 280}], {
             RGBColor[
             0.9905106871009799, 0.989385271270991, 0.7372409425310069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 310}], {
             RGBColor[
             0.9877226443429961, 0.9891910121692499, 0.8531310862218878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 327}], {
             RGBColor[
             0.9712217709059061, 0.9776161288127326, 0.9138181848100994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 399}], {
             RGBColor[
             0.7913259716151957, 0.8357838915197588, 0.9144526879293402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 412}], {
             RGBColor[
             0.9908127924815723, 0.9900314441325386, 0.7701232488301921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 483}], {
             RGBColor[
             0.9900898797560858, 0.9901699248477376, 0.8138998692181245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 139}], {
             RGBColor[
             0.8910786349918451, 0.9122712728648683, 0.8052987449928497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 140}], {
             RGBColor[
             0.8791767437501091, 0.9058563803287445, 0.9570745860939447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 154}], {
             RGBColor[
             0.8892160016780488, 0.9122677481192529, 0.8918999946055751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 247}], {
             RGBColor[
             0.7581501089349194, 0.8109918943449812, 0.9765289756091982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 255}], {
             RGBColor[
             0.8282991347198552, 0.8661876847339189, 0.9834159969766191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 269}], {
             RGBColor[
             0.8319298795063776, 0.86908274207275, 0.9837623006555617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 338}], {
             RGBColor[
             0.8896927129755543, 0.9124648804916928, 0.8839996547166187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 369}], {
             RGBColor[
             0.8751396042412349, 0.9028454882932355, 0.9639084102278495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 390}], {
             RGBColor[
             0.8855198796763719, 0.8946868810261797, 0.6845052038122055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 425}], {
             RGBColor[
             0.7818173774670496, 0.8294809444001843, 0.9788879077532816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 466}], {
             RGBColor[
             0.8728869265375124, 0.9011654449502204, 0.9677216059878101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[
             0.8959184581974751, 0.9166446095175311, 0.8532317579242217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 151}], {
             RGBColor[
             0.7778396365132902, 0.8263735029351567, 0.9784914437091136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 188}], {
             RGBColor[
             0.7755168737410594, 0.8245589430038389, 0.9782599324234298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 304}], {
             RGBColor[
             0.8762642914107284, 0.9038402017356644, 0.9698974349658751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 310}], {
             RGBColor[
             0.8925828153069654, 0.9152790891031835, 0.9095190065859506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 327}], {
             RGBColor[
             0.8760819418698753, 0.9037042057466662, 0.9702061051741622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 483}], {
             RGBColor[
             0.894950050720055, 0.9162580017816712, 0.8702877895821872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 197}], {
             RGBColor[
             0.726703250484565, 0.7446157080136159, 0.6357618836392993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 237}], {
             RGBColor[
             0.674151098644697, 0.7000495299401062, 0.6321503067590872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 270}], {
             RGBColor[
             0.9738757761939335, 0.9235390002219993, 0.35301275296948686`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 309}], {
             RGBColor[
             0.9688768767983298, 0.9364422533557684, 0.6248589445096464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 320}], {
             RGBColor[
             0.9771736151182321, 0.9417788640580995, 0.5727014882590722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 345}], {
             RGBColor[
             0.9797493241111684, 0.9428439859193805, 0.5300153245249178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 375}], {
             RGBColor[
             0.810347468540323, 0.8123180596072976, 0.6424859971017995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 426}], {
             RGBColor[
             0.9773456774772495, 0.9418500162653543, 0.5698499696870416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 489}], {
             RGBColor[
             0.9168317584221517, 0.895897592461923, 0.6529950137597009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 123}], {
             RGBColor[
             0.956437926347733, 0.967032057313264, 0.9586234072715648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 125}], {
             RGBColor[
             0.9611685196050002, 0.9705601260188983, 0.9506157468233344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 177}], {
             RGBColor[
             0.8560649740149544, 0.8880300742165607, 0.9663520325899655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 438}], {
             RGBColor[
             0.8822957092182626, 0.9085217239183563, 0.9689664671348741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 455}], {
             RGBColor[
             0.9762183130779583, 0.9795847689352045, 0.8143038790108752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 457}], {
             RGBColor[
             0.722976989269943, 0.7817005394709639, 0.9547007405385675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 161}], {
             RGBColor[
             0.9325445289719805, 0.9413085148637934, 0.7028674190206927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[
             0.9278423104196489, 0.9441280045410299, 0.9523357840852208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.8085000433043423, 0.8507664865480473, 0.9814304009265467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 259}], {
             RGBColor[
             0.9301677147234222, 0.9455935348013091, 0.9363641968208273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 341}], {
             RGBColor[
             0.887634241029926, 0.9132394658803891, 0.9891445403815174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 450}], {
             RGBColor[
             0.9340490810429976, 0.9457237260582683, 0.7648336348541601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 454}], {
             RGBColor[
             0.9330349847300153, 0.9467792246345135, 0.8888461125546636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 469}], {
             RGBColor[
             0.8682997163286892, 0.8978226407053147, 0.9873003961553795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 471}], {
             RGBColor[
             0.9137606453888663, 0.9336259218176823, 0.976172369895891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 475}], {
             RGBColor[
             0.8369787357796721, 0.8730142575558542, 0.9842688908439752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 491}], {
             RGBColor[
             0.9326393982244281, 0.9466156394483438, 0.8954020046973024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 500}], {
             RGBColor[
             0.9335616837588452, 0.9469970282184823, 0.8801173465935603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 150}], {
             RGBColor[
             0.6677891137311351, 0.7396879936921987, 0.9680102578431538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.8306115455424911, 0.8684194003276138, 0.9835336301433717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 233}], {
             RGBColor[
             0.6970118576695028, 0.7632302277885182, 0.9704352860925032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 267}], {
             RGBColor[
             0.5151428424659394, 0.6096560649199433, 0.9572765620877883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 406}], {
             RGBColor[
             0.8649105708774135, 0.8933948313248403, 0.8946771026395733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 413}], {
             RGBColor[
             0.8551344159483899, 0.8870760580703478, 0.9547656894108096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 476}], {
             RGBColor[
             0.8047601241440058, 0.847806178622602, 0.9810678984925478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 493}], {
             RGBColor[
             0.863647236976917, 0.8928724102907848, 0.9156138147741306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 125}], {
             RGBColor[
             0.9599392702893575, 0.9696433538920031, 0.9526965452751488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 177}], {
             RGBColor[
             0.8548357246993119, 0.8871133020896655, 0.96843283104178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 438}], {
             RGBColor[
             0.88106645990262, 0.9076049517914611, 0.9710472655866884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 455}], {
             RGBColor[
             0.9749890637623158, 0.9786679968083094, 0.8163846774626896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 136}], {
             RGBColor[
             0.8405836595937348, 0.8758131123564608, 0.9846327972189016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 178}], {
             RGBColor[
             0.8507796286647833, 0.8839431013315073, 0.9856052978509473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 253}], {
             RGBColor[
             0.8724464328307727, 0.9012091252301658, 0.9873079381220927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 261}], {
             RGBColor[
             0.9006960029273402, 0.9185706485753273, 0.7090392995793505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 357}], {
             RGBColor[
             0.8836642018095306, 0.9095753189671125, 0.9683191813037824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 484}], {
             RGBColor[
             0.8988429208389997, 0.9201135688357314, 0.9076053876665349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 177}], {
             RGBColor[
             0.8595663179565791, 0.8906413707952998, 0.9604251705935496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 438}], {
             RGBColor[
             0.8857970531598872, 0.9111330204970953, 0.963039605138458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 455}], {
             RGBColor[
             0.979719657019583, 0.9821960655139437, 0.8083770170144592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 457}], {
             RGBColor[
             0.7264783332115676, 0.784311836049703, 0.9487738785421514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 144}], {
             RGBColor[
             0.9186316571705518, 0.93366557064595, 0.7824356575337763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 279}], {
             RGBColor[
             0.9822689529611284, 0.9835078419568551, 0.7572886663718816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 285}], {
             RGBColor[
             0.9755124791360856, 0.9784688748408488, 0.7687256141870809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 481}], {
             RGBColor[
             0.9940088068796284, 0.9906182483393113, 0.6637426441698175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 130}], {
             RGBColor[
             0.9622223559419447, 0.9454157531436578, 0.6657077170508137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 168}], {
             RGBColor[
             0.7227347296883091, 0.7817965573917551, 0.9625321551069329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 179}], {
             RGBColor[
             0.9608870568322265, 0.9703502115438167, 0.9510921898803921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 200}], {
             RGBColor[
             0.9649813742642563, 0.9734037467807952, 0.9441615784369752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 213}], {
             RGBColor[
             0.8456391071489497, 0.8800422287878127, 0.9732561952783012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 254}], {
             RGBColor[
             0.9692116139174767, 0.968992161450941, 0.6928596644751364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 302}], {
             RGBColor[
             0.816276763233855, 0.8571041425592616, 0.9703296312435491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 315}], {
             RGBColor[
             0.9508428161960316, 0.9628592333232772, 0.9680944693199542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 325}], {
             RGBColor[
             0.9688504607322804, 0.9755076292868143, 0.9026071827895644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 347}], {
             RGBColor[
             0.8137106761521237, 0.8550994958280289, 0.9700738676646894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 368}], {
             RGBColor[
             0.6821333611223357, 0.7478066806277206, 0.9596198665120317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 386}], {
             RGBColor[
             0.8164850856057813, 0.8572668855795191, 0.9703503948706995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 401}], {
             RGBColor[
             0.9684837185989811, 0.9753559719898521, 0.9086850490365518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 454}], {
             RGBColor[
             0.9701740485746227, 0.9760549668742788, 0.8806719069064181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 169}], {
             RGBColor[
             0.9061344368646063, 0.9230426711672237, 0.7274806948181859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 197}], {
             RGBColor[
             0.7406542485554657, 0.7914094376351894, 0.7125999366414513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 204}], {
             RGBColor[
             0.9175230510812129, 0.9321183929132109, 0.728568344222593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 345}], {
             RGBColor[
             0.993700322182069, 0.9896377155409541, 0.6068533775270698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 355}], {
             RGBColor[
             0.7453098120633188, 0.7951890338216105, 0.7129664396546804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 362}], {
             RGBColor[
             0.992325608040027, 0.9890692359146778, 0.6296359485068626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 498}], {
             RGBColor[
             0.8566949661835155, 0.8844201809172616, 0.7225530304188164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 170}], {
             RGBColor[
             0.8069686220610182, 0.8499846498684842, 0.977101055442119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 206}], {
             RGBColor[
             0.794988324453269, 0.8406255503236764, 0.9759069713388251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 265}], {
             RGBColor[
             0.9676593360197103, 0.9735878142983115, 0.8584318377848059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 266}], {
             RGBColor[
             0.8320412173363034, 0.8695715518563188, 0.979600057422435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 328}], {
             RGBColor[
             0.9403351750034042, 0.955022651726499, 0.9858811650273349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 410}], {
             RGBColor[
             0.9650766495935159, 0.9725198070890666, 0.9012336356450639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 433}], {
             RGBColor[
             0.9391451194219838, 0.9541351102224128, 0.9878956187104746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 143}], {
             RGBColor[
             0.9677867411682277, 0.949565662534575, 0.6562886642868134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 179}], {
             RGBColor[
             0.97430551782484, 0.9544273554915593, 0.6452540757764165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 214}], {
             RGBColor[
             0.9820911874902845, 0.9595112755609845, 0.5997145849145227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 254}], {
             RGBColor[
             0.9826300749100902, 0.9530693053986836, 0.3870215503711608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 302}], {
             RGBColor[
             0.8296952242264686, 0.8411812865070043, 0.6644915171395736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 315}], {
             RGBColor[
             0.9642612771886452, 0.9469363772710198, 0.6622563552159787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 325}], {
             RGBColor[
             0.9822689217248939, 0.959584773234557, 0.5967690686855889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 347}], {
             RGBColor[
             0.8271291371447371, 0.8391766397757716, 0.6642357535607137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 368}], {
             RGBColor[
             0.6955518221149493, 0.7318838245754633, 0.653781752408056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 386}], {
             RGBColor[
             0.8299035465983948, 0.8413440295272618, 0.6645122807667239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 421}], {
             RGBColor[
             0.984462356706115, 0.9604918149679997, 0.5604181746189859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 477}], {
             RGBColor[
             0.9602202482602344, 0.9439225845127888, 0.6690967631226358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 135}], {
             RGBColor[
             0.9897259291256593, 0.9883834405999522, 0.7010129021707454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 147}], {
             RGBColor[
             0.9668087641622676, 0.9716032355056532, 0.7537498730411643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 170}], {
             RGBColor[
             0.8335549157817563, 0.8666492885253478, 0.7447789840307517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 171}], {
             RGBColor[
             0.8066620280343326, 0.8452969057740616, 0.7423333739913004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 216}], {
             RGBColor[
             0.9905767723398099, 0.9887352861346768, 0.6869122282006141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 238}], {
             RGBColor[
             0.9937400373594987, 0.990043377512521, 0.6344887405569168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 265}], {
             RGBColor[
             0.9942456297404485, 0.9902524529551753, 0.6261097663734386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 374}], {
             RGBColor[
             0.9145539688873605, 0.6319218989290187, 0.35164240724588075`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 385}], {
             RGBColor[
             0.8895151770057657, 0.9103658699072815, 0.7503565798911871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 391}], {
             RGBColor[
             0.9451376812720901, 0.954440193470666, 0.7557355576386509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 433}], {
             RGBColor[
             0.9657314131427219, 0.9707997488792766, 0.7555735472991072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 209}], {
             RGBColor[
             0.9708678886104872, 0.9534835024794786, 0.654511880037413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 233}], {
             RGBColor[
             0.8155603495429271, 0.8317371089162857, 0.6654163834689264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 273}], {
             RGBColor[
             0.9856384089028002, 0.9620445546637644, 0.4984150517961917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 423}], {
             RGBColor[
             0.983875902835007, 0.9620740865397133, 0.5827500810737558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 151}], {
             RGBColor[
             0.8074751890546679, 0.8498148493320484, 0.981368327315876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 155}], {
             RGBColor[
             0.8952241369249928, 0.9192914428448795, 0.989868471427569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 181}], {
             RGBColor[
             0.8988439320796375, 0.9220192606110645, 0.9847181368961782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 225}], {
             RGBColor[
             0.9242747037625783, 0.9373496476499483, 0.7168639721310064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 235}], {
             RGBColor[
             0.8558639887261228, 0.8879067290738616, 0.9861142653551416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 239}], {
             RGBColor[
             0.9079335302455215, 0.882353136567056, 0.6426586010483691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 249}], {
             RGBColor[
             0.9250267745788052, 0.9389582510798341, 0.7987222392342304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 260}], {
             RGBColor[
             0.8482605946702679, 0.8818439890423564, 0.9853890468424642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 262}], {
             RGBColor[
             0.90588582724016, 0.8754358689875035, 0.6347551402914409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 296}], {
             RGBColor[
             0.7578813868679136, 0.811071794136899, 0.9764252805943318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 332}], {
             RGBColor[
             0.9053312333367952, 0.926857479266672, 0.9737368280269589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 344}], {
             RGBColor[
             0.9246229353601878, 0.9380944798256199, 0.7547668324945003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 424}], {
             RGBColor[
             0.701101222370351, 0.7652441214273723, 0.971771405731195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 440}], {
             RGBColor[
             0.8751456052195117, 0.9032813666801529, 0.9879533631491833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 138}], {
             RGBColor[
             0.9175157248331292, 0.9358877082967334, 0.9511373509602287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 251}], {
             RGBColor[
             0.7372656302476427, 0.7946199960664913, 0.9746000087010471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 305}], {
             RGBColor[
             0.8256192184534001, 0.8639712545070489, 0.9831814910414726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 367}], {
             RGBColor[
             0.6945943582047324, 0.7599775351031577, 0.9712407698558094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 416}], {
             RGBColor[
             0.5162804133450747, 0.5957612292012561, 0.9597012752546307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 438}], {
             RGBColor[
             0.8302790347316495, 0.8676115383995328, 0.9836459379796295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 457}], {
             RGBColor[
             0.6709603147833301, 0.7407903539521403, 0.969380211383323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 499}], {
             RGBColor[
             0.9098740781083003, 0.9301885806814041, 0.964072665604699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 147}], {
             RGBColor[
             0.9631490729495484, 0.9717258404484193, 0.9333189982807641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 170}], {
             RGBColor[
             0.8298952245690373, 0.8667718934681138, 0.9243481092703515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 171}], {
             RGBColor[
             0.8030023368216136, 0.8454195107168275, 0.9219024992309002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 216}], {
             RGBColor[
             0.9869170811270909, 0.9888578910774426, 0.866481353440214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 385}], {
             RGBColor[
             0.8858554857930465, 0.9104884748500475, 0.929925705130787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 391}], {
             RGBColor[
             0.941477990059371, 0.954562798413432, 0.9353046828782506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 253}], {
             RGBColor[
             0.904243312240472, 0.9264725908088807, 0.9903647695682812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 261}], {
             RGBColor[
             0.9324928823370395, 0.9438341141540423, 0.712096131025539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 277}], {
             RGBColor[
             0.8565298240728146, 0.8884376481056946, 0.9861777733249073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 291}], {
             RGBColor[
             0.8975039993742995, 0.9211093432767391, 0.9900859267432411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 311}], {
             RGBColor[
             0.9102548355652956, 0.9309559750615681, 0.9801888286357453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 319}], {
             RGBColor[
             0.849242282437791, 0.8826267602209747, 0.9854826810980937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 377}], {
             RGBColor[
             0.8869512315511088, 0.9126948526617786, 0.9890793943276981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 484}], {
             RGBColor[
             0.9306398002486991, 0.9453770344144463, 0.9106622191127234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 488}], {
             RGBColor[
             0.9244092810413965, 0.9415123373218668, 0.9562290445153316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 145}], {
             RGBColor[
             0.9573145215621928, 0.9676858205889152, 0.9571395602261323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 183}], {
             RGBColor[
             0.9008867266956015, 0.9230141632544908, 0.9629329697245594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 346}], {
             RGBColor[
             0.9719953078571384, 0.9786347269701043, 0.932288818391086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 358}], {
             RGBColor[
             0.9735287980321676, 0.9797784014317815, 0.9296930195230544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 404}], {
             RGBColor[
             0.9783176463215653, 0.9823509359614132, 0.8768503524528282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 407}], {
             RGBColor[
             0.8399768312927149, 0.8753067475129244, 0.9568949841940374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 408}], {
             RGBColor[
             0.727402172752693, 0.7850037159334444, 0.9472873547944032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 430}], {
             RGBColor[
             0.9555857838557802, 0.9663965308380209, 0.9600658622360839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 352}], {
             RGBColor[
             0.9246512884013828, 0.9415774129963457, 0.9518179473833615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 367}], {
             RGBColor[
             0.7584762563477121, 0.8097367849973789, 0.9364765703067768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 457}], {
             RGBColor[
             0.7348422129263097, 0.7905496038463615, 0.9346160118342903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 140}], {
             RGBColor[
             0.9824913479921838, 0.9840011380527282, 0.7828927165089257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 247}], {
             RGBColor[
             0.8614647131769941, 0.8891366520689649, 0.8023471060241791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 255}], {
             RGBColor[
             0.9316137389619299, 0.9443324424579025, 0.8092341273916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 269}], {
             RGBColor[
             0.9352444837484524, 0.9472274997967336, 0.8095804310705427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 274}], {
             RGBColor[
             0.9901872198605981, 0.989443455485348, 0.7565540965156148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 360}], {
             RGBColor[
             0.9735467459468924, 0.9773302684927914, 0.798033594645766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 369}], {
             RGBColor[
             0.9784542084833097, 0.9809902460172191, 0.7897265406428304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 370}], {
             RGBColor[
             0.8590912153182594, 0.8872824575024694, 0.8021105379392189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 425}], {
             RGBColor[
             0.8851319817091243, 0.9076257021241678, 0.8047060381682626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 466}], {
             RGBColor[
             0.9762015307795872, 0.979310202674204, 0.7935397364027911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 468}], {
             RGBColor[
             0.9213463079761726, 0.9361454716918491, 0.8082548106583347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 169}], {
             RGBColor[
             0.8949619519028513, 0.9181879049096922, 0.958647908121453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 204}], {
             RGBColor[
             0.906350566119458, 0.9272636266556793, 0.9597355575258599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 219}], {
             RGBColor[
             0.9715569541644181, 0.9783078035038119, 0.9330308368519079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 244}], {
             RGBColor[
             0.9278463215748372, 0.9444037585690607, 0.9617858418706815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 247}], {
             RGBColor[
             0.8495628219352582, 0.8827217595328412, 0.9541229471252741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 255}], {
             RGBColor[
             0.919711847720194, 0.9379175499217789, 0.961009968492695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 274}], {
             RGBColor[
             0.978285328618862, 0.9830285629492241, 0.9083299376167098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 334}], {
             RGBColor[
             0.9820814449946302, 0.9831243969885114, 0.7382773048532892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 361}], {
             RGBColor[
             0.9612171685658362, 0.9705964083342344, 0.9505333968223202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 363}], {
             RGBColor[
             0.9466084582478063, 0.9593641770674535, 0.9635753912157063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 369}], {
             RGBColor[
             0.9665523172415738, 0.9745753534810954, 0.9415023817439254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 370}], {
             RGBColor[
             0.8471893240765234, 0.8808675649663457, 0.9538863790403139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 425}], {
             RGBColor[
             0.8732300904673883, 0.9012108095880442, 0.9564818792693576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 466}], {
             RGBColor[
             0.9642996395378511, 0.9728953101380803, 0.9453155775038861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 188}], {
             RGBColor[
             0.8748643568229489, 0.9001969855066543, 0.8511332818609727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 220}], {
             RGBColor[
             0.9911332966442137, 0.9905875509025792, 0.7956007375065959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[
             0.9474192020786127, 0.9575206659739397, 0.8581941630002572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 304}], {
             RGBColor[
             0.9756117744926178, 0.9794782442384798, 0.842770784403418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 310}], {
             RGBColor[
             0.9919302983888549, 0.9909171316059988, 0.7823923560234934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 429}], {
             RGBColor[
             0.9589467005122647, 0.9667123803193245, 0.8592936660915783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 173}], {
             RGBColor[
             0.870328518818162, 0.8957930778917884, 0.7817614067441427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 222}], {
             RGBColor[
             0.9942589368294936, 0.9901287713258402, 0.616498887504398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 241}], {
             RGBColor[
             0.9925000622322364, 0.9900592379653642, 0.6934635788131374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 402}], {
             RGBColor[
             0.9920213036103324, 0.9898612589716715, 0.701397848165683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 417}], {
             RGBColor[
             0.9706730997603619, 0.9749120705794279, 0.781074895286348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 461}], {
             RGBColor[
             0.9031316664304153, 0.9214191461196364, 0.785030917935289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 179}], {
             RGBColor[
             0.9664514420585095, 0.9745001209347339, 0.9416731371163918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 214}], {
             RGBColor[
             0.9742371117239539, 0.9795840410041592, 0.896133646254498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 226}], {
             RGBColor[
             0.9747840847494631, 0.9798102284067727, 0.8870688877009969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 273}], {
             RGBColor[
             0.9771677910205614, 0.9800375787790077, 0.7924389634400727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 283}], {
             RGBColor[
             0.9750319710761952, 0.9799127357732644, 0.8829607697577955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 292}], {
             RGBColor[
             0.9228245336356169, 0.9406743304849209, 0.970834670398547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 302}], {
             RGBColor[
             0.821841148460138, 0.861254051950179, 0.9609105784795489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 308}], {
             RGBColor[
             0.9663799628870291, 0.9744468118856804, 0.9417941327089544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 325}], {
             RGBColor[
             0.9744148459585634, 0.9796575386777316, 0.8931881300255642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 347}], {
             RGBColor[
             0.8192750613784067, 0.8592494052189463, 0.960654814900689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 386}], {
             RGBColor[
             0.8220494708320643, 0.8614167949704364, 0.9609313421066992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 421}], {
             RGBColor[
             0.9766082809397845, 0.9805645804111744, 0.8568372359589612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 423}], {
             RGBColor[
             0.9754052849527683, 0.9800671106549566, 0.8767739927176368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 446}], {
             RGBColor[
             0.9453549011149711, 0.9586394339424248, 0.9729836369618243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 477}], {
             RGBColor[
             0.9523661724939039, 0.9639953499559634, 0.9655158244626111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 279}], {
             RGBColor[
             0.9069774507530426, 0.9277628352920382, 0.959772739748711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 494}], {
             RGBColor[
             0.9183136114087744, 0.9347063041358961, 0.8729169596353905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 183}], {
             RGBColor[
             0.8917709731893818, 0.9162156492152285, 0.9783635626413011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 286}], {
             RGBColor[
             0.8377501007768395, 0.873889990592233, 0.9730122105408765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 294}], {
             RGBColor[
             0.8597226873238291, 0.8910551422005841, 0.9752022326223848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 346}], {
             RGBColor[
             0.9628795543509185, 0.971836212930842, 0.9477194113078278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 358}], {
             RGBColor[
             0.964413044525948, 0.9729798873925193, 0.9451236124397961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 404}], {
             RGBColor[
             0.9692018928153454, 0.975552421922151, 0.8922809453695699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 407}], {
             RGBColor[
             0.8308610777864952, 0.8685082334736621, 0.972325577110779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 408}], {
             RGBColor[
             0.7182864192464733, 0.7782052018941821, 0.9627179477111449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 430}], {
             RGBColor[
             0.9464700303495606, 0.9595980167987587, 0.9754964551528256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 201}], {
             RGBColor[
             0.9297437255228024, 0.9423887418442094, 0.7723663255234694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 211}], {
             RGBColor[
             0.8238308640572017, 0.8592787466341585, 0.7619081246106718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 271}], {
             RGBColor[
             0.9484451360336793, 0.9573007389493177, 0.7741500827529431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 284}], {
             RGBColor[
             0.8009669542233344, 0.8408942505101147, 0.7599868663165199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 312}], {
             RGBColor[
             0.9489650297067225, 0.9577152880520645, 0.7741996706755925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 376}], {
             RGBColor[
             0.9837352966472832, 0.9844588701165493, 0.7434943235080839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 400}], {
             RGBColor[
             0.9749555124785734, 0.9779109214591026, 0.7583562079712582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 415}], {
             RGBColor[
             0.988526832290749, 0.9880323895540266, 0.7353835034963392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 442}], {
             RGBColor[
             0.9931405611383606, 0.9877366788076342, 0.49477059533929124`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 444}], {
             RGBColor[
             0.9707406103277594, 0.9747674543362945, 0.7654909378900445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 464}], {
             RGBColor[
             0.9745309693987019, 0.9775942979252601, 0.7590748486669119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 497}], {
             RGBColor[
             0.9668741779678367, 0.9718838754129661, 0.7720357993483298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 171}], {
             RGBColor[
             0.780085171858222, 0.8286393056225285, 0.974639470101319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 216}], {
             RGBColor[
             0.9639999161636992, 0.9720776859831437, 0.9192183243106329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 238}], {
             RGBColor[
             0.9671631811833881, 0.973385777360988, 0.8667948366669356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 385}], {
             RGBColor[
             0.8629383208296548, 0.8937082697557486, 0.9826626760012058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 391}], {
             RGBColor[
             0.9185608250959794, 0.937782593319133, 0.9880416537486695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 153}], {
             RGBColor[
             0.9945552050317777, 0.9916120745980193, 0.7105039340771806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 190}], {
             RGBColor[
             0.934186575586897, 0.9471691160321379, 0.8660129152808255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 195}], {
             RGBColor[
             0.9841004895633463, 0.9577716819742405, 0.5486481073020129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 323}], {
             RGBColor[
             0.8931874315932424, 0.9147030676437105, 0.8620425246620036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 342}], {
             RGBColor[
             0.8660546473676636, 0.8935067303898905, 0.8593381823006826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 351}], {
             RGBColor[
             0.9943869978242057, 0.9912522963893801, 0.6921956175875158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 356}], {
             RGBColor[
             0.947988862330354, 0.9581746848282775, 0.8673293897118632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 452}], {
             RGBColor[
             0.9082486013740243, 0.9264868794623471, 0.8635389281452988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 463}], {
             RGBColor[
             0.9747650183660621, 0.9790215397190207, 0.8524188575037612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 158}], {
             RGBColor[
             0.9636975225239606, 0.8808102873098179, 0.4739806539237041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 165}], {
             RGBColor[
             0.8911922270283479, 0.8266494259917417, 0.6250526412552893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 182}], {
             RGBColor[
             0.9488345995459398, 0.8718524876710702, 0.6042216952845851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 187}], {
             RGBColor[
             0.9487997668421794, 0.8320196990605321, 0.291699340089098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 275}], {
             RGBColor[
             0.9533684808623808, 0.8752338489333225, 0.5965470168414828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 282}], {
             RGBColor[
             0.9607110804708021, 0.8799276639055622, 0.5490856443968845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 324}], {
             RGBColor[
             0.9502469855259443, 0.8369015075039777, 0.2973215113912086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 441}], {
             RGBColor[
             0.9436989800394131, 0.8144922475986595, 0.2735570816661645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 159}], {
             RGBColor[
             0.7586237418541004, 0.8114687765280842, 0.976846180400345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 233}], {
             RGBColor[
             0.625024053981112, 0.7062796039889887, 0.9637478363494765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 267}], {
             RGBColor[
             0.44315503877754875`, 0.5527054411204136, 0.9505891123447616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 406}], {
             RGBColor[
             0.7929227671890229, 0.8364442075253108, 0.8879896528965467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 413}], {
             RGBColor[
             0.7831466122599993, 0.8301254342708182, 0.9480782396677829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 443}], {
             RGBColor[
             0.7666491061836345, 0.8178216212512524, 0.9760042142163666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 476}], {
             RGBColor[
             0.7327723204556151, 0.7908555548230725, 0.9743804487495211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 188}], {
             RGBColor[
             0.7567855351387642, 0.8099258789242798, 0.9763929676458645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 192}], {
             RGBColor[
             0.8287461461701697, 0.8667757331512, 0.9833971701943602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 249}], {
             RGBColor[
             0.8766598834351323, 0.9008838406033832, 0.7939783908499026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 260}], {
             RGBColor[
             0.7998937035265952, 0.8437695785659056, 0.9806451984581364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 280}], {
             RGBColor[
             0.876639519462654, 0.9008402841253655, 0.7917618981175044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 310}], {
             RGBColor[
             0.8738514767046701, 0.9006460250236243, 0.9076520418083853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 327}], {
             RGBColor[
             0.8573506032675802, 0.8890711416671071, 0.9683391403965969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 424}], {
             RGBColor[
             0.6527343312266782, 0.7271697109509214, 0.9670275573468672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 483}], {
             RGBColor[
             0.8762187121177598, 0.9016249377021122, 0.8684208248046219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 191}], {
             RGBColor[
             0.8103033225110772, 0.8518565052069602, 0.981694712574481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 212}], {
             RGBColor[
             0.8864846744360776, 0.9107244788384448, 0.9184019207598161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 287}], {
             RGBColor[
             0.6868612015741529, 0.7544709523078434, 0.9699907011959443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 299}], {
             RGBColor[
             0.8876682556312439, 0.9112139200792952, 0.898786917345965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 301}], {
             RGBColor[
             0.8448623879371675, 0.8794129658968839, 0.9849909870860636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 389}], {
             RGBColor[
             0.8901147352047704, 0.9117375568428003, 0.8227666701574896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 451}], {
             RGBColor[
             0.8871525288019254, 0.9110006537817972, 0.9073338455660234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 190}], {
             RGBColor[
             0.9344446290582624, 0.9468714507693771, 0.8323423620079775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 195}], {
             RGBColor[
             0.9843585430347117, 0.9574740167114796, 0.514977554029165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 263}], {
             RGBColor[
             0.994868333818588, 0.9914322098660262, 0.6828279890050448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 323}], {
             RGBColor[
             0.8934454850646079, 0.9144054023809496, 0.8283719713891557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 342}], {
             RGBColor[
             0.866312700839029, 0.8932090651271296, 0.8256676290278346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 351}], {
             RGBColor[
             0.9946450512955711, 0.9909546311266192, 0.6585250643146678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[
             0.9482469158017194, 0.9578770195655166, 0.8336588364390153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 395}], {
             RGBColor[
             0.9677407792764399, 0.973292752587935, 0.831075326010577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 447}], {
             RGBColor[
             0.9920973751502395, 0.9905956987786564, 0.7512365358741073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 452}], {
             RGBColor[
             0.9085066548453897, 0.9261892141995862, 0.8298683748724508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 463}], {
             RGBColor[
             0.9750230718374275, 0.9787238744562599, 0.8187483042309134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 174}], {
             RGBColor[
             0.9768704712944296, 0.9811947215449157, 0.8758556918638318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 229}], {
             RGBColor[
             0.9922641087727482, 0.9898424953919953, 0.6887115551584992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 255}], {
             RGBColor[
             0.9297511056481337, 0.9443289177122871, 0.8958353770043255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 313}], {
             RGBColor[
             0.9122845157277555, 0.9304015330277307, 0.8941693980651109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 338}], {
             RGBColor[
             0.9911446839038328, 0.9906061134700611, 0.7964190347443252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 369}], {
             RGBColor[
             0.9765915751695134, 0.9809867212716037, 0.8763277902555558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 379}], {
             RGBColor[
             0.9662932686882124, 0.9733062611597785, 0.893760136899898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 380}], {
             RGBColor[
             0.8734718717694525, 0.8999683141748382, 0.8903307668735454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 390}], {
             RGBColor[
             0.9869718506046503, 0.9728281140045478, 0.596924583839912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 425}], {
             RGBColor[
             0.883269348395328, 0.9076221773785524, 0.891307287780988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 478}], {
             RGBColor[
             0.9239532933129759, 0.9397058995336556, 0.89528237648803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 181}], {
             RGBColor[
             0.9382259888062896, 0.9534214436474449, 0.9884744326235433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 235}], {
             RGBColor[
             0.8952460454527749, 0.9193089121102418, 0.9898705610825067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 262}], {
             RGBColor[
             0.945267883966812, 0.9068380520238837, 0.638511436018806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 332}], {
             RGBColor[
             0.9447132900634473, 0.9582596623030522, 0.9774931237543241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 344}], {
             RGBColor[
             0.9640049920868399, 0.9694966628620001, 0.7585231282218654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 387}], {
             RGBColor[
             0.9626802363256959, 0.9705691484452665, 0.8982569107477336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 393}], {
             RGBColor[
             0.9165528885293452, 0.9362984104206511, 0.9919028267959935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 403}], {
             RGBColor[
             0.9488395818170884, 0.961337043936735, 0.9705083881246581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 232}], {
             RGBColor[
             0.9011053527754592, 0.9194339093156862, 0.7526095617827069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 307}], {
             RGBColor[
             0.9911451861206246, 0.988987757629074, 0.6787582301945081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 350}], {
             RGBColor[
             0.9352654523540775, 0.9465818889248567, 0.7558917604240635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 354}], {
             RGBColor[
             0.9774359039163545, 0.979543002401682, 0.7368767734554873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 372}], {
             RGBColor[
             0.9910495488791009, 0.9809129823602799, 0.46710866882227836`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 479}], {
             RGBColor[
             0.9606630952779145, 0.9668332799916726, 0.7583142102788825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 180}], {
             RGBColor[
             0.9147917843909852, 0.9321994683284475, 0.8856677207356276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 216}], {
             RGBColor[
             0.9128173518585578, 0.9313829897356871, 0.9183891774655497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 238}], {
             RGBColor[
             0.9159806168782467, 0.9326910811135314, 0.8659656898218523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 246}], {
             RGBColor[
             0.9049001537531909, 0.8952717921508693, 0.6649325807334321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 281}], {
             RGBColor[
             0.911366946530829, 0.9307832098589546, 0.942426147274684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 288}], {
             RGBColor[
             0.9157676611390866, 0.9326030184426759, 0.8694949175315201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 343}], {
             RGBColor[
             0.8949304086003524, 0.9186370276941451, 0.9752717134250511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 392}], {
             RGBColor[
             0.8162280960045756, 0.8565073991011553, 0.9822792901591065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 459}], {
             RGBColor[
             0.9149195280057084, 0.9322522935959967, 0.8835506784497875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 465}], {
             RGBColor[
             0.9128509476256454, 0.9313968824487497, 0.9178324086618502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 182}], {
             RGBColor[
             0.9800106469667158, 0.9824856097716567, 0.813638950383576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 206}], {
             RGBColor[
             0.8223185929771863, 0.8588814758571491, 0.8245619659732324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 282}], {
             RGBColor[
             0.9918871278915782, 0.9905607860061487, 0.7585028994958753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 324}], {
             RGBColor[
             0.9814230329467204, 0.9475346296045642, 0.5067387664901994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 410}], {
             RGBColor[
             0.9924069181174333, 0.9907757326225393, 0.7498886302794712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 441}], {
             RGBColor[
             0.9748750274601891, 0.925125369699246, 0.48297433676515533`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 164}], {
             RGBColor[
             0.9396571348785014, 0.9541494293650059, 0.9742860278219299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 396}], {
             RGBColor[
             0.8912892921689859, 0.9161539044449551, 0.9894931624220636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 443}], {
             RGBColor[
             0.9294715379949904, 0.9465530278866674, 0.9915275865165846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 165}], {
             RGBColor[
             0.8957640949773074, 0.9195681385850505, 0.9845858223490205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 268}], {
             RGBColor[
             0.8240870856478877, 0.8633320134679013, 0.9775058147694429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 275}], {
             RGBColor[
             0.95794034881134, 0.9681525615266312, 0.956080197935214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 285}], {
             RGBColor[
             0.9493835049473184, 0.9617708813833897, 0.9705647026146953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 324}], {
             RGBColor[
             0.9548188534749037, 0.9298202200972865, 0.6568546924849399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 353}], {
             RGBColor[
             0.9500663870011127, 0.9137890347489961, 0.6383922576622495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 441}], {
             RGBColor[
             0.9482708479883724, 0.9074109601919682, 0.6330902627598958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 480}], {
             RGBColor[
             0.943130519811529, 0.9571074153074415, 0.9811493754098701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 481}], {
             RGBColor[
             0.9678798326908612, 0.9739202548818523, 0.865581732597432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 259}], {
             RGBColor[
             0.9881864764352863, 0.9841149249487182, 0.6513373733902397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 326}], {
             RGBColor[
             0.859668260434512, 0.8839361792021694, 0.6957207792340347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 341}], {
             RGBColor[
             0.9456530027417902, 0.9517608560277981, 0.7041177169509298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 387}], {
             RGBColor[
             0.9906587848417958, 0.9851372880102378, 0.6103648249653191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 403}], {
             RGBColor[
             0.9768181303331883, 0.9759051835017063, 0.6826163023422438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 405}], {
             RGBColor[
             0.9849451363232266, 0.9819662912623259, 0.6688594010637443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 450}], {
             RGBColor[
             0.9920678427548617, 0.9842451162056773, 0.47980681142357257`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 469}], {
             RGBColor[
             0.9263184780405535, 0.9363440308527238, 0.702273572724792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 491}], {
             RGBColor[
             0.9906581599362924, 0.9851370295957529, 0.6103751812667149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 203}], {
             RGBColor[
             0.95081012420882, 0.9628348516927431, 0.9681498083268676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 221}], {
             RGBColor[
             0.8977751861088834, 0.9206338551286255, 0.9661292497035479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 223}], {
             RGBColor[
             0.9787144198701365, 0.9818659231361021, 0.8412072615324757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 258}], {
             RGBColor[
             0.7501715512524573, 0.803617944205272, 0.9525403655657194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 289}], {
             RGBColor[
             0.9305480489914351, 0.9467660463955077, 0.9692551546219657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 297}], {
             RGBColor[
             0.7561961932848003, 0.8085090200141587, 0.9530146474554964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 381}], {
             RGBColor[
             0.9455981249900693, 0.9587665684733886, 0.9706906443060768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 439}], {
             RGBColor[
             0.9432295086089213, 0.9568778980654401, 0.9704647235611541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 187}], {
             RGBColor[
             0.6585421355856416, 0.6865870273679395, 0.6312428919231102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.67008487741937, 0.7343425783039177, 0.894737384705526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 322}], {
             RGBColor[
             0.665884456996152, 0.7113544015446418, 0.659766424121889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 364}], {
             RGBColor[
             0.6704208469870805, 0.7344815103541901, 0.8891694995071919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 437}], {
             RGBColor[
             0.6656657881359773, 0.7317066462131763, 0.9317657241786685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 494}], {
             RGBColor[
             0.6726466402225957, 0.7354019330573527, 0.8522823454264565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 166}], {
             RGBColor[
             0.9730158191700888, 0.9787360051751508, 0.9010133849308055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 227}], {
             RGBColor[
             0.9582899360381176, 0.9684132831079654, 0.955488437947231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 309}], {
             RGBColor[
             0.9652947095780249, 0.9736374317447642, 0.9436311834817033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 348}], {
             RGBColor[
             0.9753676521185038, 0.9797085485386703, 0.8620374266270018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 396}], {
             RGBColor[
             0.9095002533820311, 0.9301031506464617, 0.9714096375434305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 428}], {
             RGBColor[
             0.8561654342290401, 0.8881049972797372, 0.9661819796517387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 443}], {
             RGBColor[
             0.9476824992080357, 0.960502274088174, 0.9734440616379514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 182}], {
             RGBColor[
             0.9075053514711033, 0.9283247484535805, 0.9647109377151613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 268}], {
             RGBColor[
             0.7781859696240918, 0.8268855616571029, 0.9784618761062877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 275}], {
             RGBColor[
             0.9120392327875442, 0.9317061097158328, 0.9570362592720587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 282}], {
             RGBColor[
             0.9193818323959655, 0.9363999246880725, 0.9095748868274605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 285}], {
             RGBColor[
             0.9034823889235224, 0.9253244295725913, 0.9715207639515401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 324}], {
             RGBColor[
             0.9089177374511077, 0.8933737682864881, 0.6578107538217846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 353}], {
             RGBColor[
             0.9041652709773167, 0.8773425829381977, 0.6393483189990943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 441}], {
             RGBColor[
             0.9023697319645765, 0.8709645083811698, 0.6340463240967404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 481}], {
             RGBColor[
             0.9219787166670652, 0.9374738030710539, 0.8665377939342768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 210}], {
             RGBColor[
             0.9109647638262199, 0.9298298579213793, 0.9149154024947266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 227}], {
             RGBColor[
             0.9734376591166597, 0.9790506127166038, 0.9002993199347398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 243}], {
             RGBColor[
             0.8111208566619652, 0.8515927924078128, 0.905080184865843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 309}], {
             RGBColor[
             0.980442432656567, 0.9842747613534026, 0.8884420654692121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 320}], {
             RGBColor[
             0.9887391709764694, 0.9896113720557339, 0.836284609218638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 348}], {
             RGBColor[
             0.9905153751970459, 0.9903458781473087, 0.8068483086145106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 428}], {
             RGBColor[
             0.8713131573075822, 0.8987423268883756, 0.9109928616392475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 495}], {
             RGBColor[
             0.6889715062014053, 0.750701226885353, 0.8959408239907272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 210}], {
             RGBColor[
             0.9097905695609332, 0.9293442984172671, 0.9343748401878778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 326}], {
             RGBColor[
             0.8572941919516184, 0.8882223345843505, 0.9291720525912905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 434}], {
             RGBColor[
             0.9895834705820021, 0.9899605116401318, 0.8222923797776203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 474}], {
             RGBColor[
             0.7612865696851604, 0.8116027775282946, 0.9207089218129507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 495}], {
             RGBColor[
             0.6877973119361186, 0.7502156673812408, 0.9154002616838784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 200}], {
             RGBColor[
             0.7389122090032344, 0.7938616949766353, 0.9351479023891189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 213}], {
             RGBColor[
             0.6195699418879277, 0.7005001769836527, 0.9642425192304448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 254}], {
             RGBColor[
             0.7431424486564547, 0.7894501096467812, 0.68384598842728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 261}], {
             RGBColor[
             0.744635395048966, 0.794423077980252, 0.6950105562225323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 315}], {
             RGBColor[
             0.7247736509350096, 0.7833171815191173, 0.9590807932720979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 368}], {
             RGBColor[
             0.4560641958613137, 0.5682646288235607, 0.9506061904641752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 401}], {
             RGBColor[
             0.742414553337959, 0.7958139201856922, 0.8996713729886954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 500}], {
             RGBColor[
             0.7446315823424305, 0.7967307186540877, 0.8629294648974584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 204}], {
             RGBColor[
             0.8307230612718615, 0.867865286048767, 0.9837149080372922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 219}], {
             RGBColor[
             0.8959294493168215, 0.9189094628968995, 0.9570101873633401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 244}], {
             RGBColor[
             0.8522188167272406, 0.8850054179621483, 0.9857651923821137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 274}], {
             RGBColor[
             0.9026578237712655, 0.9236302223423118, 0.9323092881281421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 334}], {
             RGBColor[
             0.9064539401470337, 0.923726056381599, 0.7622566553647214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 337}], {
             RGBColor[
             0.7661019828557705, 0.8172039586884303, 0.9773215440871418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 340}], {
             RGBColor[
             0.9025720546209914, 0.9235947545945069, 0.9337307049116297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 361}], {
             RGBColor[
             0.8855896637182396, 0.9111980677273221, 0.9745127473337525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 363}], {
             RGBColor[
             0.8709809534002098, 0.8999658364605412, 0.9875547417271386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 370}], {
             RGBColor[
             0.7715618192289269, 0.8214692243594333, 0.9778657295517461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 498}], {
             RGBColor[
             0.769894976374164, 0.8201670740528177, 0.9776995942335156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 171}], {
             RGBColor[
             0.6468313234777108, 0.7236853586422232, 0.9656685810909065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 238}], {
             RGBColor[
             0.8339093328028768, 0.8684318303806826, 0.8578239476565228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 265}], {
             RGBColor[
             0.8344149251838267, 0.8686409058233369, 0.8494449734730447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 266}], {
             RGBColor[
             0.6987968065004198, 0.7646246433813442, 0.9706131931106738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 328}], {
             RGBColor[
             0.8070907641675207, 0.8500757432515244, 0.9768943007155737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 374}], {
             RGBColor[
             0.7547232643307386, 0.5103103517971803, 0.5749776143454868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 433}], {
             RGBColor[
             0.8059007085861001, 0.8491882017474381, 0.9789087543987132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 216}], {
             RGBColor[
             0.8038531800357642, 0.8457713562515521, 0.9078018252607689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 238}], {
             RGBColor[
             0.8070164450554531, 0.8470794476293964, 0.8553783376170716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 265}], {
             RGBColor[
             0.8075220374364029, 0.8472885230720506, 0.8469993634335934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 343}], {
             RGBColor[
             0.7859662367775588, 0.8330253942100101, 0.9646843612202705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 385}], {
             RGBColor[
             0.70279158470172, 0.7674019400241568, 0.9712461769513419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 391}], {
             RGBColor[
             0.7584140889680444, 0.8114762635875413, 0.9766251546988056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 433}], {
             RGBColor[
             0.7790078208386764, 0.8278358189961519, 0.976463144359262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 465}], {
             RGBColor[
             0.8038867758028518, 0.8457852489646146, 0.9072450564570695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 303}], {
             RGBColor[
             0.8725008409890392, 0.8968916400500846, 0.7340433293408963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 366}], {
             RGBColor[
             0.652202056157894, 0.7268482392808564, 0.966910000500002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 448}], {
             RGBColor[
             0.8098949280165739, 0.8518026675165675, 0.9815836308548604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 473}], {
             RGBColor[
             0.7890492717768298, 0.8351809070712604, 0.9795953535535766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 241}], {
             RGBColor[
             0.8688301981650348, 0.8962808430717617, 0.8870857869188805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 417}], {
             RGBColor[
             0.8470032356931603, 0.8811336756858255, 0.9746971033920911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 461}], {
             RGBColor[
             0.7794618023632138, 0.8276407512260339, 0.9786531260410322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 493}], {
             RGBColor[
             0.8670881056426344, 0.8955604430440135, 0.9159567684059835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 215}], {
             RGBColor[
             0.8475541821271161, 0.8812856713815511, 0.9606590570009172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 229}], {
             RGBColor[
             0.9784666074608506, 0.9806282358392899, 0.7602478723890496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 294}], {
             RGBColor[
             0.8671597882871085, 0.8966017199218628, 0.962613160598139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 338}], {
             RGBColor[
             0.9773471825919351, 0.9813918539173556, 0.8679553519748755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 356}], {
             RGBColor[
             0.9323767715414137, 0.9482100458939925, 0.9689381505840401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 390}], {
             RGBColor[
             0.9731743492927526, 0.9636138544518424, 0.6684609010704623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 430}], {
             RGBColor[
             0.95390713131284, 0.9651445945200373, 0.9629073831285797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 309}], {
             RGBColor[
             0.9702399595547258, 0.977325591080284, 0.9352601651989108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 320}], {
             RGBColor[
             0.9785366978746279, 0.9826622017826152, 0.8831027089483368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 337}], {
             RGBColor[
             0.8403140573506173, 0.8755466736558164, 0.955738147959555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 348}], {
             RGBColor[
             0.9803129020952046, 0.9833967078741901, 0.8536664083442093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 361}], {
             RGBColor[
             0.9598017382130863, 0.9695407826947082, 0.9529293512061656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 370}], {
             RGBColor[
             0.8457738937237735, 0.8798119393268193, 0.9562823334241595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 375}], {
             RGBColor[
             0.8117105512967189, 0.8532013973318133, 0.952887217791064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 197}], {
             RGBColor[
             0.7240170626958831, 0.7824791063956844, 0.9530174631424804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 237}], {
             RGBColor[
             0.6714649108560151, 0.7379129283221747, 0.9494058862622683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 345}], {
             RGBColor[
             0.9770631363224864, 0.9807073843014491, 0.847270904028099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 426}], {
             RGBColor[
             0.9746594896885676, 0.9797134146474228, 0.8871055491902227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 448}], {
             RGBColor[
             0.9137825043907246, 0.9334714916771972, 0.970215963680536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 245}], {
             RGBColor[
             0.6989697640482373, 0.7647597591322252, 0.97063043190266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 438}], {
             RGBColor[
             0.7806935075698416, 0.8286029686947578, 0.9787758909050892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 455}], {
             RGBColor[
             0.8746161114295372, 0.899666013711606, 0.8241133027810903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 357}], {
             RGBColor[
             0.9256570502902786, 0.942968773520874, 0.9723485133820166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 420}], {
             RGBColor[
             0.8629189453494907, 0.8935321599836392, 0.9867871734159126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 439}], {
             RGBColor[
             0.9083540922987261, 0.9297609128567503, 0.9911208182923652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 236}], {
             RGBColor[
             0.98329749105791, 0.9840670761890672, 0.7390557860253798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 254}], {
             RGBColor[
             0.981294775800372, 0.9780037637988426, 0.6724060232007392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 276}], {
             RGBColor[
             0.9786979177889099, 0.9835947102340616, 0.9192049563050149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 283}], {
             RGBColor[
             0.9815507477328076, 0.9847744287302488, 0.8719261812473986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 292}], {
             RGBColor[
             0.9293433102922292, 0.9455360234419052, 0.95980008188815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 315}], {
             RGBColor[
             0.962925978078927, 0.9718708356711787, 0.947640828045557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 325}], {
             RGBColor[
             0.9809336226151757, 0.984519231634716, 0.8821535415151672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 347}], {
             RGBColor[
             0.8257938380350189, 0.8641110981759306, 0.9496202263902922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 368}], {
             RGBColor[
             0.6942165230052311, 0.7568182829756223, 0.9391662252376345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 386}], {
             RGBColor[
             0.8285682474886766, 0.8662784879274208, 0.9498967535963023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 401}], {
             RGBColor[
             0.9805668804818763, 0.9843675743377538, 0.8882314077621546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 216}], {
             RGBColor[
             0.989742356873669, 0.9900262152049275, 0.8196592227401607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 281}], {
             RGBColor[
             0.98829195154594, 0.989426435328195, 0.8436961925492951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 288}], {
             RGBColor[
             0.9926926661541977, 0.9912462439119163, 0.7707649628061312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 343}], {
             RGBColor[
             0.9718554136154636, 0.9772802531633855, 0.8765417586996622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 392}], {
             RGBColor[
             0.8931531010196866, 0.9151506245703956, 0.8835493354337176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 465}], {
             RGBColor[
             0.9897759526407565, 0.9900401079179901, 0.8191024539364613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 235}], {
             RGBColor[
             0.8988658406074196, 0.9220367298764268, 0.9847202265511159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 239}], {
             RGBColor[
             0.9509353821268183, 0.9164831373696212, 0.6412645622443435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 262}], {
             RGBColor[
             0.9488876791214567, 0.9095658697900686, 0.6333611014874152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 296}], {
             RGBColor[
             0.8008832387492104, 0.8452017949394643, 0.9750312417903061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 332}], {
             RGBColor[
             0.948333085218092, 0.9609874800692371, 0.9723427892229333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 344}], {
             RGBColor[
             0.9676247872414846, 0.9722244806281851, 0.7533727936904746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 387}], {
             RGBColor[
             0.9663000314803405, 0.9732969662114515, 0.8931065762163428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 393}], {
             RGBColor[
             0.92017268368399, 0.939026228186836, 0.9867524922646027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 424}], {
             RGBColor[
             0.7441030742516477, 0.7993741222299375, 0.9703773669271694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 275}], {
             RGBColor[
             0.969681605305136, 0.9769091713951612, 0.9362053133013547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 282}], {
             RGBColor[
             0.9770242049135575, 0.981602986367401, 0.8887439408567563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 324}], {
             RGBColor[
             0.9665601099686997, 0.9385768299658165, 0.6369798078510805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 441}], {
             RGBColor[
             0.9600121044821683, 0.9161675700604982, 0.6132153781260364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 346}], {
             RGBColor[
             0.9064517594843273, 0.9271645555964176, 0.9535128208062547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 404}], {
             RGBColor[
             0.9127740979487542, 0.9308807645877264, 0.8980743548679968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 407}], {
             RGBColor[
             0.774433282919904, 0.8238365761392377, 0.9781189866092062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 408}], {
             RGBColor[
             0.6618586243798821, 0.7335335445597576, 0.9685113572095719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 192}], {
             RGBColor[
             0.9283456566665036, 0.9451186373337148, 0.9728144373736064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 225}], {
             RGBColor[
             0.9755073231152392, 0.9776181413560121, 0.7015373909259248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 249}], {
             RGBColor[
             0.9762593939314661, 0.979226744785898, 0.7833956580291488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 260}], {
             RGBColor[
             0.8994932140229288, 0.9221124827484203, 0.9700624656373826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 280}], {
             RGBColor[
             0.9762390299589878, 0.9791831883078802, 0.7811791652967506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 424}], {
             RGBColor[
             0.7523338417230119, 0.8055126151334362, 0.9564448245261135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 440}], {
             RGBColor[
             0.9263782245721726, 0.9435498603862168, 0.9726267819441017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 453}], {
             RGBColor[
             0.9764855451490235, 0.9797104593728577, 0.8080108224167388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 470}], {
             RGBColor[
             0.9744858747012237, 0.9794168817828757, 0.8799185449059898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 193}], {
             RGBColor[
             0.8242829871820079, 0.8622882123612778, 0.9192833928515283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 196}], {
             RGBColor[
             0.827940826636486, 0.8626278939401848, 0.7734039679329332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 318}], {
             RGBColor[
             0.8215420514867864, 0.8419193165079153, 0.6740577577353909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 321}], {
             RGBColor[
             0.8045464143201284, 0.8479698776229609, 0.9706574294313798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 330}], {
             RGBColor[
             0.8232222519233895, 0.8618495710721863, 0.9368625211816892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 335}], {
             RGBColor[
             0.7470943815918236, 0.8024540518251491, 0.9754007789198086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 350}], {
             RGBColor[
             0.7695421855289513, 0.820353321355209, 0.977541870498723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 383}], {
             RGBColor[
             0.8210890307153997, 0.860307333844506, 0.9426550948795425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 409}], {
             RGBColor[
             0.7732233628039706, 0.8232885921914144, 0.9778929844734401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 482}], {
             RGBColor[
             0.6931367863498032, 0.7602029926219362, 0.9700490551979559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 496}], {
             RGBColor[
             0.771104241468765, 0.8215988623607375, 0.9776908607887262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 191}], {
             RGBColor[
             0.9045903932605184, 0.92576991183764, 0.956440353730889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 202}], {
             RGBColor[
             0.9210172667463036, 0.9388682548596029, 0.9580071635884063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 212}], {
             RGBColor[
             0.9807717451855187, 0.9846378854691245, 0.893147561916224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 295}], {
             RGBColor[
             0.9323089891649938, 0.9478719678106267, 0.9590841781529407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 300}], {
             RGBColor[
             0.9171839510005342, 0.9358116729365105, 0.9576415385105335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 389}], {
             RGBColor[
             0.9844018059542115, 0.9856509634734801, 0.7975123113138975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 414}], {
             RGBColor[
             0.9580848565422639, 0.9682603351557446, 0.9558355840404124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 456}], {
             RGBColor[
             0.9059770593239658, 0.9268756017165853, 0.9565726151779121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 485}], {
             RGBColor[
             0.8276485366464394, 0.8655402246337721, 0.9488039164906259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 322}], {
             RGBColor[
             0.9724203799916847, 0.9186296070885351, 0.3473588135522615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 494}], {
             RGBColor[
             0.9791825632181285, 0.9426771386012459, 0.5398747348568291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 304}], {
             RGBColor[
             0.8552101900362024, 0.8873925777247877, 0.9677989589026261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 310}], {
             RGBColor[
             0.8715287139324392, 0.8988314650923067, 0.9074205305227014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 483}], {
             RGBColor[
             0.8738959493455289, 0.8998103777707944, 0.8681893135189382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 266}], {
             RGBColor[
             0.856016472012168, 0.886792440076484, 0.909468231004652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 364}], {
             RGBColor[
             0.9884995118163415, 0.9895122668340616, 0.8402563817199802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 374}], {
             RGBColor[
             0.9119429298424868, 0.6324781484923202, 0.5138326522394651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 437}], {
             RGBColor[
             0.9837444529652384, 0.9867374026930478, 0.8828526063914568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 195}], {
             RGBColor[
             0.9239899135898311, 0.9130310581455983, 0.6704865352328099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 224}], {
             RGBColor[
             0.9344771870525365, 0.9469410890270109, 0.8358860987600507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 263}], {
             RGBColor[
             0.9344997043737072, 0.9469892513001448, 0.8383369702086897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 323}], {
             RGBColor[
             0.8330768556197272, 0.8699624438150683, 0.9838809525928007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 342}], {
             RGBColor[
             0.8059440713941484, 0.8487661065612483, 0.9811766102314796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 351}], {
             RGBColor[
             0.9342764218506905, 0.9465116725607379, 0.8140340455183128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 356}], {
             RGBColor[
             0.8878782863568386, 0.9134340609996352, 0.9891678176426602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 395}], {
             RGBColor[
             0.9073721498315592, 0.9288497940220537, 0.9865843072142219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 452}], {
             RGBColor[
             0.848138025400509, 0.8817462556337049, 0.9853773560760957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 463}], {
             RGBColor[
             0.9146544423925469, 0.9342809158903785, 0.9742572854345583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 212}], {
             RGBColor[
             0.9112747991739798, 0.9302128367328008, 0.9208403607523055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 218}], {
             RGBColor[
             0.9125168567695547, 0.9307264594679953, 0.9002562520516089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 287}], {
             RGBColor[
             0.711651326312055, 0.7739593102021995, 0.9724291411884336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 295}], {
             RGBColor[
             0.8628120431534549, 0.893446919074303, 0.986776976989022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 299}], {
             RGBColor[
             0.9124583803691461, 0.9307022779736513, 0.9012253573384543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 300}], {
             RGBColor[
             0.8476870049889953, 0.8813866242001868, 0.9853343373466148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 301}], {
             RGBColor[
             0.8696525126750697, 0.89890132379124, 0.9874294270785529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 389}], {
             RGBColor[
             0.9149048599426726, 0.9312259147371564, 0.8252051101499789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 451}], {
             RGBColor[
             0.9119426535398276, 0.9304890116761532, 0.9097722855585126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 456}], {
             RGBColor[
             0.8364801133124268, 0.8724505529802618, 0.9842654140139935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[
             0.9455456608780801, 0.9543105314690999, 0.7188928150094904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 249}], {
             RGBColor[
             0.9462977316943071, 0.9559191348989857, 0.8007510821127146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 260}], {
             RGBColor[
             0.8695315517857698, 0.8988048728615081, 0.9874178897209483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 280}], {
             RGBColor[
             0.9462773677218287, 0.955875578420968, 0.7985345893803164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 327}], {
             RGBColor[
             0.9269884515267548, 0.9441064359627096, 0.9751118316594087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 470}], {
             RGBColor[
             0.9445242124640647, 0.9561092718959634, 0.8972739689895555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 483}], {
             RGBColor[
             0.9458565603769344, 0.9566602319977147, 0.8751935160674339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 196}], {
             RGBColor[
             0.990264536960952, 0.9890692210527292, 0.7257457883623029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 202}], {
             RGBColor[
             0.927276945863512, 0.9431355443095322, 0.9294459927814515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 232}], {
             RGBColor[
             0.8977057962747987, 0.919646668858583, 0.926601492286736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 330}], {
             RGBColor[
             0.9855459622478555, 0.9882908981847309, 0.8892043416110589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 350}], {
             RGBColor[
             0.9318658958534172, 0.9467946484677536, 0.9298836909280926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 354}], {
             RGBColor[
             0.9740363474156941, 0.9797557619445787, 0.9108687039595165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 376}], {
             RGBColor[
             0.9801794047443777, 0.9843372440419778, 0.9004701102680079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 414}], {
             RGBColor[
             0.9643445356594723, 0.9725276246056739, 0.9272744132334575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 415}], {
             RGBColor[
             0.9849709403878435, 0.9879107634794551, 0.8923592902562634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 485}], {
             RGBColor[
             0.8339082157636477, 0.8698075140837014, 0.920242745683671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 496}], {
             RGBColor[
             0.9334279517932309, 0.9480401894732822, 0.9300326812180959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 228}], {
             RGBColor[
             0.9779029951262328, 0.9499310036590849, 0.6148762909891254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 388}], {
             RGBColor[
             0.990057713701024, 0.9901566233573397, 0.8144329439935789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 490}], {
             RGBColor[
             0.9872376984792239, 0.9889904745920398, 0.861167894184258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 224}], {
             RGBColor[
             0.9843911010289857, 0.9575436549691134, 0.5185212907812381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 263}], {
             RGBColor[
             0.9844136183501565, 0.9575918172422473, 0.5209721622298771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 296}], {
             RGBColor[
             0.8169122605518835, 0.8289439762764998, 0.6599300563712285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 323}], {
             RGBColor[
             0.8829907695961765, 0.8805650097571708, 0.666516144613988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 342}], {
             RGBColor[
             0.8558579853705977, 0.8593686725033508, 0.6638118022526671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 351}], {
             RGBColor[
             0.9841903358271398, 0.9571142385028404, 0.4966692375395002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 395}], {
             RGBColor[
             0.9572860638080085, 0.9394523599641562, 0.6692194992354092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 447}], {
             RGBColor[
             0.9816426596818081, 0.9567553061548775, 0.5893807090989396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 453}], {
             RGBColor[
             0.9842837994803324, 0.9573141478063947, 0.5068421793987172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 463}], {
             RGBColor[
             0.9645683563689962, 0.944883481832481, 0.6568924774557456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 318}], {
             RGBColor[
             0.9875236012657305, 0.9687003251993667, 0.4805201532461655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 321}], {
             RGBColor[
             0.9705279640990725, 0.9747508863144124, 0.7771198249421544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 330}], {
             RGBColor[
             0.9892038017023336, 0.9886305797636378, 0.7433249166924638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 335}], {
             RGBColor[
             0.9130759313707677, 0.9292350605166004, 0.7818631744305832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 350}], {
             RGBColor[
             0.9355237353078953, 0.9471343300466605, 0.7840042660094976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 354}], {
             RGBColor[
             0.9776941868701722, 0.9800954435234857, 0.7649892790409214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 383}], {
             RGBColor[
             0.9870705804943438, 0.9870883425359575, 0.749117490390317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 414}], {
             RGBColor[
             0.9680023751139504, 0.9728673061845807, 0.7813949883148624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 479}], {
             RGBColor[
             0.9609213782317322, 0.9673857211134762, 0.7864267158643166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 482}], {
             RGBColor[
             0.8591183361287473, 0.8869840013133876, 0.7765114507087305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 496}], {
             RGBColor[
             0.9370857912477091, 0.948379871052189, 0.7841532562995008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 237}], {
             RGBColor[
             0.4358219185971056, 0.5509569191652015, 0.9492541653992037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 270}], {
             RGBColor[
             0.7355465961463421, 0.7744463894470947, 0.6701166116096033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 345}], {
             RGBColor[
             0.741420144063577, 0.7937513751444758, 0.8471191831650344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 375}], {
             RGBColor[
             0.5720182884927316, 0.663225448832393, 0.959589855741916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 426}], {
             RGBColor[
             0.739016497429658, 0.7927574054904496, 0.8869538283271581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 448}], {
             RGBColor[
             0.6781395121318152, 0.746515482520224, 0.9700642428174714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 489}], {
             RGBColor[
             0.6785025783745603, 0.7468049816870184, 0.9700988723998175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 223}], {
             RGBColor[
             0.978918785935668, 0.9820183390131567, 0.8408613230907375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 373}], {
             RGBColor[
             0.8957911367790243, 0.9190412879723491, 0.9655745782477756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 480}], {
             RGBColor[
             0.9537639352594696, 0.9650377991378958, 0.9631497766954236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 208}], {
             RGBColor[
             0.9220759117363376, 0.9401767965422771, 0.9742094169798393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 220}], {
             RGBColor[
             0.9375371530479821, 0.9512411458546416, 0.9271414098212938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 349}], {
             RGBColor[
             0.8143296300266007, 0.8554301065276002, 0.9819823810470295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 359}], {
             RGBColor[
             0.7623939863081166, 0.8147711176082904, 0.9768650409943199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 371}], {
             RGBColor[
             0.8855778909439811, 0.9115997881399927, 0.9889484038745946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 382}], {
             RGBColor[
             0.8997135681942243, 0.9228711934765992, 0.9902966773897909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 397}], {
             RGBColor[
             0.888416974472914, 0.9138635962810944, 0.9892191981960641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 419}], {
             RGBColor[
             0.8516383697256309, 0.8845759775374062, 0.9857009675502337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 427}], {
             RGBColor[
             0.9358130723454876, 0.934885336026233, 0.6898957065749298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 429}], {
             RGBColor[
             0.9053505569160331, 0.927365975271387, 0.9908343384062762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 213}], {
             RGBColor[
             0.8618165864638749, 0.8921073663726927, 0.9458719425604871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 243}], {
             RGBColor[
             0.8076185123272406, 0.8496405671987558, 0.9405567142662665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 254}], {
             RGBColor[
             0.985389093232402, 0.9810572990358211, 0.6654754117573224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 259}], {
             RGBColor[
             0.9834842578829548, 0.9869344146259547, 0.9008057384547677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 401}], {
             RGBColor[
             0.9846611979139064, 0.9874211095747323, 0.8813007963187378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 450}], {
             RGBColor[
             0.9873656242025302, 0.9870646058829138, 0.7292751764881006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 454}], {
             RGBColor[
             0.986351527889548, 0.988120104459159, 0.8532876541886041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 469}], {
             RGBColor[
             0.9216162594882219, 0.9391635205299602, 0.9517419377893199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 471}], {
             RGBColor[
             0.967077188548399, 0.9749668016423279, 0.9406139115298314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 475}], {
             RGBColor[
             0.8902952789392047, 0.9143551373804997, 0.9487104324779156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 500}], {
             RGBColor[
             0.9868782269183778, 0.9883379080431277, 0.8445588882275008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 222}], {
             RGBColor[
             0.9301442302534717, 0.9432453809658715, 0.8159587938281427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 246}], {
             RGBColor[
             0.9188512489319138, 0.9063960167539925, 0.6662632486458684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 256}], {
             RGBColor[
             0.9277274627168051, 0.9429037919678724, 0.9038264737152466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 271}], {
             RGBColor[
             0.8844703802441969, 0.9107166891705618, 0.9888427685153627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 312}], {
             RGBColor[
             0.88499027391724, 0.9111312382733086, 0.9888923564380121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 333}], {
             RGBColor[
             0.8608881600045715, 0.66365365281431, 0.5941625096011295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 400}], {
             RGBColor[
             0.9109807566890908, 0.9313268716803468, 0.9730488937336779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 442}], {
             RGBColor[
             0.9291658053488782, 0.9411526290288783, 0.7094632811017109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 444}], {
             RGBColor[
             0.9067658545382771, 0.9281834045575387, 0.9801836236524641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 492}], {
             RGBColor[
             0.786138965013996, 0.8332270643027037, 0.9792204399062996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 211}], {
             RGBColor[
             0.7609452205113343, 0.8135631253952968, 0.9767046908711494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 414}], {
             RGBColor[
             0.9050147840165104, 0.9269336294413837, 0.985095192734011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 485}], {
             RGBColor[
             0.7745784641206857, 0.8242135189194113, 0.9780635251842245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 497}], {
             RGBColor[
             0.9039885344219691, 0.9261682541741044, 0.9868323656088074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 221}], {
             RGBColor[
             0.8860620005517819, 0.9118981805187203, 0.985956617563656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 258}], {
             RGBColor[
             0.7384583656953558, 0.7948822695953668, 0.9723677334258277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 289}], {
             RGBColor[
             0.9188348634343335, 0.9380303717856024, 0.989082522482074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 291}], {
             RGBColor[
             0.9308621991984417, 0.9476206428505702, 0.990229700504184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 297}], {
             RGBColor[
             0.7444830077276987, 0.7997733454042535, 0.9728420153156048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 381}], {
             RGBColor[
             0.9338849394329678, 0.9500308938634834, 0.9905180121661852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 397}], {
             RGBColor[
             0.9139286167553227, 0.9341182638602776, 0.9886145602939718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 419}], {
             RGBColor[
             0.8771500120080395, 0.9048306451165895, 0.9850963296481414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 439}], {
             RGBColor[
             0.9315163230518198, 0.9481422234555349, 0.9902920914212625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 219}], {
             RGBColor[
             0.9073180635334284, 0.9279851846428867, 0.9580978367677472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 244}], {
             RGBColor[
             0.8636074309438473, 0.8940811397081355, 0.9868528417865208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 274}], {
             RGBColor[
             0.9140464379878722, 0.932705944088299, 0.933396937532549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 334}], {
             RGBColor[
             0.9178425543636404, 0.9328017781275862, 0.7633443047691285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 337}], {
             RGBColor[
             0.7774905970723772, 0.8262796804344175, 0.9784091934915489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 340}], {
             RGBColor[
             0.9139606688375981, 0.932670476340494, 0.9348183543160367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 361}], {
             RGBColor[
             0.8969782779348463, 0.9202737894733093, 0.9756003967381595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 362}], {
             RGBColor[
             0.9169142324472823, 0.9338918507962211, 0.8858701617259689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 363}], {
             RGBColor[
             0.8823695676168165, 0.9090415582065283, 0.9886423911315456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 370}], {
             RGBColor[
             0.7829504334455335, 0.8305449461054205, 0.9789533789561532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 498}], {
             RGBColor[
             0.7812835905907707, 0.8292427957988049, 0.9787872436379226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 228}], {
             RGBColor[
             0.8215913714952963, 0.8279771412251655, 0.6536466336603034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 252}], {
             RGBColor[
             0.7908680026893871, 0.8372699607319134, 0.9795992953807968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 388}], {
             RGBColor[
             0.8337460900700875, 0.8682027609234204, 0.853203286664757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 432}], {
             RGBColor[
             0.8290715818780768, 0.866269731656643, 0.9306719846457889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 490}], {
             RGBColor[
             0.8309260748482874, 0.8670366121581206, 0.8999382368554361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 266}], {
             RGBColor[
             0.6868165088926705, 0.7552655438365363, 0.9694191090073798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 410}], {
             RGBColor[
             0.8198519411498831, 0.858213799069284, 0.8910526872300086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 218}], {
             RGBColor[
             0.9777119818006232, 0.9426693017155523, 0.5683952313785541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 287}], {
             RGBColor[
             0.7768464513431235, 0.7859021524497565, 0.6405681205153788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 295}], {
             RGBColor[
             0.9280071681845233, 0.90538976132186, 0.6549159563159672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 336}], {
             RGBColor[
             0.9346196220554177, 0.9106623525482324, 0.6555466580691804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 389}], {
             RGBColor[
             0.980099984973741, 0.9431687569847134, 0.4933440894769241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 409}], {
             RGBColor[
             0.9249855730307579, 0.9029804233652629, 0.6546277538727912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 456}], {
             RGBColor[
             0.9016752383434952, 0.8843933952278187, 0.6524043933409387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 458}], {
             RGBColor[
             0.886197975815624, 0.8721579002611852, 0.65090012088695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[
             0.7469489810623835, 0.8012145566339894, 0.9579953363165989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 289}], {
             RGBColor[
             0.9273254788013612, 0.944362658824225, 0.9747101253728452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 314}], {
             RGBColor[
             0.9561677539691096, 0.9668305631956534, 0.9590807386363324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 349}], {
             RGBColor[
             0.8483318876760371, 0.8820170611454059, 0.9670053460357084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 359}], {
             RGBColor[
             0.7963962439575529, 0.8413580722260962, 0.9618880059829988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 397}], {
             RGBColor[
             0.9224192321223503, 0.9404505508989001, 0.9742421631847429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 427}], {
             RGBColor[
             0.9698153299949239, 0.9614722906440388, 0.6749186715636087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 472}], {
             RGBColor[
             0.9406737947830729, 0.955006243657657, 0.9759832996673632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 214}], {
             RGBColor[
             0.9767017170503053, 0.9814221396211311, 0.8919617123090033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 233}], {
             RGBColor[
             0.8095543369870397, 0.8515682316485009, 0.9552683611673126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 273}], {
             RGBColor[
             0.9796323963469128, 0.9818756773959796, 0.7882670294945779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 421}], {
             RGBColor[
             0.9790728862661359, 0.9824026790281464, 0.8526653020134665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 423}], {
             RGBColor[
             0.9778698902791196, 0.9819052092719285, 0.872602058772142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 477}], {
             RGBColor[
             0.9548307778202553, 0.9658334485729354, 0.9613438905171163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 227}], {
             RGBColor[
             0.8962388806942487, 0.9195071358541939, 0.9693904555111521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 243}], {
             RGBColor[
             0.7339220782395542, 0.7920493155454029, 0.9741713204422553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 326}], {
             RGBColor[
             0.7812696077944941, 0.8291644172260528, 0.9788037504745516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 348}], {
             RGBColor[
             0.913316596774635, 0.9308024012848988, 0.875939444190923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 428}], {
             RGBColor[
             0.7941143788851712, 0.8391988500259657, 0.9800839972156599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 434}], {
             RGBColor[
             0.9135588864248779, 0.9309025942818342, 0.8719240776608814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 469}], {
             RGBColor[
             0.8479198254005356, 0.8815722688766072, 0.9853565439653088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 474}], {
             RGBColor[
             0.6852619855280362, 0.7525448601699969, 0.9703406196962119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 495}], {
             RGBColor[
             0.6117727277789944, 0.6911577500229431, 0.9650319595671395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 464}], {
             RGBColor[
             0.8046433521436188, 0.8479002529364532, 0.9633093335165339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 485}], {
             RGBColor[
             0.66757649041147, 0.7402350951694661, 0.9675014437733689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 497}], {
             RGBColor[
             0.7969865607127535, 0.8421898304241593, 0.9762702841979518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 287}], {
             RGBColor[
             0.7878326782370553, 0.8328272838336839, 0.9091363493737685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 295}], {
             RGBColor[
             0.9389933950784553, 0.9523148927057874, 0.9234841851743569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 299}], {
             RGBColor[
             0.9886397322941465, 0.9895702516051357, 0.8379325655237893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 300}], {
             RGBColor[
             0.9238683569139956, 0.9402545978316712, 0.9220415455319498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 301}], {
             RGBColor[
             0.9458338646000701, 0.9577692974227243, 0.9241366352638878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 389}], {
             RGBColor[
             0.9910862118676729, 0.9900938883686409, 0.7619123183353138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 451}], {
             RGBColor[
             0.9881240054648279, 0.9893569853076376, 0.8464794937438476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 456}], {
             RGBColor[
             0.9126614652374272, 0.9313185266117461, 0.9209726221993284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 254}], {
             RGBColor[
             0.8660468261170953, 0.8876957810428385, 0.6945700285986482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 259}], {
             RGBColor[
             0.8641419907676482, 0.8935728966329721, 0.9299003552960936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 261}], {
             RGBColor[
             0.8675397725096066, 0.8926687493763095, 0.7057345963939006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 315}], {
             RGBColor[
             0.8476780283956502, 0.8815628529151747, 0.9698048334434661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 368}], {
             RGBColor[
             0.5789685733219543, 0.6665103002196182, 0.9613302306355436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 401}], {
             RGBColor[
             0.8653189307985996, 0.8940595915817497, 0.9103954131600637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 450}], {
             RGBColor[
             0.8680233570872234, 0.8937030878899312, 0.7583697933294264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 454}], {
             RGBColor[
             0.8670092607742412, 0.8947585864661765, 0.8823822710299299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 471}], {
             RGBColor[
             0.8477349214330923, 0.8816052836493453, 0.9697085283711573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 475}], {
             RGBColor[
             0.7709530118238981, 0.8209936193875171, 0.9778050493192416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 500}], {
             RGBColor[
             0.8675359598030712, 0.8949763900501452, 0.8736535050688267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 273}], {
             RGBColor[
             0.9914722373426182, 0.989983191805417, 0.7358648840677819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 302}], {
             RGBColor[
             0.8361455947821947, 0.8711996649765884, 0.9043364991072581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 347}], {
             RGBColor[
             0.8335795077004635, 0.8691950182453557, 0.9040807355283984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 421}], {
             RGBColor[
             0.9909127272618413, 0.9905101934375838, 0.8002631565866705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 423}], {
             RGBColor[
             0.9897097312748251, 0.990012723681366, 0.8201999133453461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 477}], {
             RGBColor[
             0.9666706188159607, 0.9739409629823728, 0.9089417450903203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 224}], {
             RGBColor[
             0.8634568843816957, 0.8910222833107091, 0.8289234796079654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 351}], {
             RGBColor[
             0.8632561191798497, 0.890592866844436, 0.8070714263662276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 356}], {
             RGBColor[
             0.8168579836859979, 0.8575152552833334, 0.9822051984905751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 430}], {
             RGBColor[
             0.8383883434574242, 0.8744498039093782, 0.9761744310351146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 238}], {
             RGBColor[
             0.9909311893609303, 0.9905178279900114, 0.7999571918263855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 281}], {
             RGBColor[
             0.9863175190135125, 0.9886099567354345, 0.8764176492792172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 343}], {
             RGBColor[
             0.9698809810830361, 0.9764637745706252, 0.9092632154295843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 465}], {
             RGBColor[
             0.987801520108329, 0.9892236293252297, 0.8518239106663834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 290}], {
             RGBColor[
             0.7562027921614297, 0.8094706356813754, 0.9763348852719266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 340}], {
             RGBColor[
             0.8888798704082571, 0.9128983162230646, 0.9323659959500408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 355}], {
             RGBColor[
             0.644817638041233, 0.7202394885857244, 0.9667482945077908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 362}], {
             RGBColor[
             0.8918334340179412, 0.9141196906787915, 0.8834178033599729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 378}], {
             RGBColor[
             0.8647092225962586, 0.8951406391226541, 0.9853158823218556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 384}], {
             RGBColor[
             0.8867137460640658, 0.9115515766958444, 0.9480679637897289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 498}], {
             RGBColor[
             0.7562027921614297, 0.8094706356813754, 0.9763348852719266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 295}], {
             RGBColor[
             0.9402354526740302, 0.9528285154409819, 0.9029000764736606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.9251104145095707, 0.9407682205668657, 0.9014574368312533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 336}], {
             RGBColor[
             0.9468479065449247, 0.9581011066673544, 0.9035307782268737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 389}], {
             RGBColor[
             0.9923282694632478, 0.9906075111038354, 0.7413282096346174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 409}], {
             RGBColor[
             0.9372138575202648, 0.9504191774843849, 0.9026118740304845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 456}], {
             RGBColor[
             0.9139035228330021, 0.9318321493469406, 0.900388513498632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 458}], {
             RGBColor[
             0.898426260305131, 0.9195966543803071, 0.8988842410446434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 244}], {
             RGBColor[
             0.9288138189888074, 0.9451253165562681, 0.9601481211125686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 274}], {
             RGBColor[
             0.9792528260328324, 0.9837501209364317, 0.9066922168585971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 334}], {
             RGBColor[
             0.9830489424086005, 0.9838459549757188, 0.7366395840951765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 337}], {
             RGBColor[
             0.8426969851173374, 0.87732385728255, 0.9517044728175967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 340}], {
             RGBColor[
             0.9791670568825582, 0.9837146531886266, 0.9081136336420847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 361}], {
             RGBColor[
             0.9621846659798063, 0.9713179663214419, 0.9488956760642074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 363}], {
             RGBColor[
             0.9475759556617767, 0.9600857350546609, 0.9619376704575936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 369}], {
             RGBColor[
             0.9675198146555439, 0.9752969114683028, 0.9398646609858127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 370}], {
             RGBColor[
             0.8481568214904937, 0.8815891229535531, 0.9522486582822012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 498}], {
             RGBColor[
             0.8464899786357308, 0.8802869726469374, 0.9520825229639706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 349}], {
             RGBColor[
             0.8637931289876815, 0.8930814104577705, 0.9199373388771629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 359}], {
             RGBColor[
             0.8118574852691974, 0.8524224215384606, 0.9148199988244533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 371}], {
             RGBColor[
             0.9350413899050618, 0.9492510920701629, 0.926903361704728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 382}], {
             RGBColor[
             0.949177067155305, 0.9605224974067694, 0.9282516352199243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 416}], {
             RGBColor[
             0.5829638260045314, 0.6471432248924059, 0.8992986838257135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 427}], {
             RGBColor[
             0.9852765713065683, 0.9725366399564033, 0.6278506644050632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 429}], {
             RGBColor[
             0.9548140558771139, 0.9650172792015572, 0.9287892962364096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 499}], {
             RGBColor[
             0.976557490767757, 0.981570576372554, 0.9036700741757818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 223}], {
             RGBColor[
             0.9139662962130983, 0.9309292519620793, 0.8590140707692643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 258}], {
             RGBColor[
             0.685423427595419, 0.7526812730312492, 0.9703471748025079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 297}], {
             RGBColor[
             0.691448069627762, 0.7575723488401358, 0.9708214566922849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 381}], {
             RGBColor[
             0.8808500013330312, 0.9078298972993658, 0.9884974535428653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 439}], {
             RGBColor[
             0.8784813849518831, 0.9059412268914173, 0.9882715327979427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 307}], {
             RGBColor[
             0.991702026253539, 0.9901787823682044, 0.7393668422432864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 333}], {
             RGBColor[
             0.9252634205247232, 0.711094341714728, 0.42306229214338315`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 372}], {
             RGBColor[
             0.9916063890120154, 0.9821040070994103, 0.5277172808710567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 417}], {
             RGBColor[
             0.9709336537044918, 0.9754693691198772, 0.8094345841523463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 258}], {
             RGBColor[
             0.7663626613566722, 0.8139133410387258, 0.845425186631436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 268}], {
             RGBColor[
             0.8507072451345118, 0.8814053782547548, 0.8527369755624512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 373}], {
             RGBColor[
             0.9117778808177078, 0.9291842689287484, 0.8588053377552305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 381}], {
             RGBColor[
             0.9617892350942843, 0.9690619653068424, 0.8635754653717933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 480}], {
             RGBColor[
             0.9697506792981531, 0.9751807800942949, 0.8563805362028784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 263}], {
             RGBColor[
             0.9949008918128619, 0.99150184812366, 0.6863717257571178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 342}], {
             RGBColor[
             0.8663452588333029, 0.8932787033847636, 0.8292113657799078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 351}], {
             RGBColor[
             0.994677609289845, 0.991024269384253, 0.662068801066741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 356}], {
             RGBColor[
             0.9482794737959934, 0.9579466578231505, 0.8372025731910884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 463}], {
             RGBColor[
             0.9750556298317015, 0.9787935127138938, 0.8222920409829864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 235}], {
             RGBColor[
             0.9242966122903604, 0.9373671169153106, 0.7168660617859441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 249}], {
             RGBColor[
             0.9934593981430427, 0.9884186389212831, 0.5294740356650329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 260}], {
             RGBColor[
             0.9166932182345056, 0.9313043768838054, 0.7161408432732668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 280}], {
             RGBColor[
             0.9934390341705643, 0.9883750824432653, 0.5272575429326347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 296}], {
             RGBColor[
             0.8263140104321511, 0.860532181978348, 0.7071770770251342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 424}], {
             RGBColor[
             0.7695338459345886, 0.8147045092688213, 0.7025232021619975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 440}], {
             RGBColor[
             0.9435782287837493, 0.9527417545216019, 0.7187051595799858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 453}], {
             RGBColor[
             0.9936855493606002, 0.9889023535082428, 0.554089200052623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 470}], {
             RGBColor[
             0.9916858789128005, 0.9886087759182608, 0.6259969225418738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 236}], {
             RGBColor[
             0.9916301337488637, 0.9893771836611059, 0.6844515366099849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 283}], {
             RGBColor[
             0.9898833904237612, 0.9900845362022875, 0.8173219318320037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 292}], {
             RGBColor[
             0.9376759529831828, 0.950846130913944, 0.9051958324727551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 308}], {
             RGBColor[
             0.981231382234595, 0.9846186123147034, 0.8761552947831626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 386}], {
             RGBColor[
             0.8369008901796302, 0.8715885953994595, 0.8952925041809074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 396}], {
             RGBColor[
             0.9253839573847722, 0.9410448272811034, 0.9040234109593848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 422}], {
             RGBColor[
             0.930472008593475, 0.945101901203452, 0.9045087138258278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 446}], {
             RGBColor[
             0.9602063204625371, 0.9688112343714479, 0.9073447990360325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 309}], {
             RGBColor[
             0.9657165495245957, 0.9739520392862172, 0.9429171184856376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 320}], {
             RGBColor[
             0.974013287844498, 0.9792886499885485, 0.8907596622350635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 348}], {
             RGBColor[
             0.9757894920650747, 0.9800231560801232, 0.8613233616309361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 428}], {
             RGBColor[
             0.8565872741756109, 0.8884196048211903, 0.965467914655673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 495}], {
             RGBColor[
             0.674245623069434, 0.7403785048181676, 0.9504158770071527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 388}], {
             RGBColor[
             0.9824920773451583, 0.9518287070906442, 0.5388233224574468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 490}], {
             RGBColor[
             0.9796720621233582, 0.9506625583253443, 0.5855582726481259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 244}], {
             RGBColor[
             0.9394817156691978, 0.9502486406539432, 0.7810034309075295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 248}], {
             RGBColor[
             0.8042047026417867, 0.8436168645174786, 0.7679512216176145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 255}], {
             RGBColor[
             0.9313472418145545, 0.9437624320066614, 0.7802275575295432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 313}], {
             RGBColor[
             0.9138806518941763, 0.9298350473221049, 0.7785615785903286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 338}], {
             RGBColor[
             0.9927408200702537, 0.9900396277644354, 0.6808112152695429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 379}], {
             RGBColor[
             0.9678894048546333, 0.9727397754541528, 0.7781523174251157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 380}], {
             RGBColor[
             0.8750680079358734, 0.8994018284692125, 0.7747229473987631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 390}], {
             RGBColor[
             0.9885679867710713, 0.972261628298922, 0.48131676436512966`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 411}], {
             RGBColor[
             0.9706599482391831, 0.9748060421740017, 0.7734625101485159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 478}], {
             RGBColor[
             0.9255494294793968, 0.9391394138280299, 0.7796745570132477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 242}], {
             RGBColor[
             0.8746361901010632, 0.899708959959735, 0.8262987422654924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 339}], {
             RGBColor[
             0.7284877908276086, 0.7878194659975827, 0.973572512950384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 365}], {
             RGBColor[
             0.6456103790093983, 0.7214573291369933, 0.9664180788407327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 374}], {
             RGBColor[
             0.795092544901438, 0.5418471405969066, 0.5790012469603982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 391}], {
             RGBColor[
             0.8256762572861676, 0.8643654351385539, 0.9830943973531683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 246}], {
             RGBColor[
             0.9748147701419188, 0.9499368221713445, 0.6340532495026429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 256}], {
             RGBColor[
             0.9836909839268101, 0.9864445973852244, 0.871616474572021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 271}], {
             RGBColor[
             0.9404339014542019, 0.9542574945879136, 0.9566327693721373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 288}], {
             RGBColor[
             0.9856822775278146, 0.9872680484631511, 0.8386155863007309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 442}], {
             RGBColor[
             0.9851293265588832, 0.9846934344462301, 0.6772532819584853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 444}], {
             RGBColor[
             0.962729375748282, 0.9717242099748906, 0.9479736245092387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 492}], {
             RGBColor[
             0.8421024862240011, 0.8767678697200556, 0.947010440763074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 307}], {
             RGBColor[
             0.8988447283882891, 0.9201176465567316, 0.9077264397043754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 312}], {
             RGBColor[
             0.8565082365721419, 0.8885107913622536, 0.9861517364413547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 330}], {
             RGBColor[
             0.8966450610161804, 0.9192080275694916, 0.9441806206168969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 350}], {
             RGBColor[
             0.8429649946217421, 0.8777117778525143, 0.9848599699339307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 354}], {
             RGBColor[
             0.885135446184019, 0.9106728913293394, 0.9658449829653546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 372}], {
             RGBColor[
             0.8987490911467655, 0.9120428712879374, 0.6960768783321456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 376}], {
             RGBColor[
             0.8912785035127027, 0.9152543734267384, 0.9554463892738461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 400}], {
             RGBColor[
             0.8824987193439928, 0.9087064247692919, 0.9703082737370203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 414}], {
             RGBColor[
             0.8754436344277972, 0.9034447539904346, 0.9822506922392955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 415}], {
             RGBColor[
             0.8960700391561685, 0.9188278928642157, 0.9473355692621014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 476}], {
             RGBColor[
             0.7619950643939827, 0.8143977889193919, 0.9768054769988705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 235}], {
             RGBColor[
             0.8324703580040163, 0.8693416194425472, 0.9838595181812482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[
             0.8845398995234149, 0.8637880269357416, 0.6404038538744757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 262}], {
             RGBColor[
             0.8824921965180534, 0.8568707593561891, 0.6325003931175475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 296}], {
             RGBColor[
             0.7344877561458071, 0.7925066845055846, 0.9741705334204384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 332}], {
             RGBColor[
             0.8819376026146887, 0.9082923696353575, 0.9714820808530655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 393}], {
             RGBColor[
             0.8537772010805866, 0.8863311177529564, 0.985891783894735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 468}], {
             RGBColor[
             0.8286770977362765, 0.8663169766703585, 0.9834977136306278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 239}], {
             RGBColor[
             0.9079554387733035, 0.8823706058324183, 0.642660690703307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 249}], {
             RGBColor[
             0.9250486831065873, 0.9389757203451964, 0.7987243288891682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 260}], {
             RGBColor[
             0.8482825031980501, 0.8818614583077187, 0.985391136497402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 262}], {
             RGBColor[
             0.9059077357679421, 0.8754533382528658, 0.6347572299463787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 296}], {
             RGBColor[
             0.7579032953956957, 0.8110892634022613, 0.9764273702492696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 332}], {
             RGBColor[
             0.9053531418645773, 0.9268749485320342, 0.9737389176818967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 344}], {
             RGBColor[
             0.92464484388797, 0.9381119490909822, 0.754768922149438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 393}], {
             RGBColor[
             0.8771927403304753, 0.9049136966496331, 0.9881486207235661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 424}], {
             RGBColor[
             0.7011231308981332, 0.7652615906927346, 0.9717734953861328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 440}], {
             RGBColor[
             0.8751675137472938, 0.9032988359455152, 0.9879554528041211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 453}], {
             RGBColor[
             0.9252748343241447, 0.9394594349321561, 0.8233394932767583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 243}], {
             RGBColor[
             0.8138514672379988, 0.8512922942591262, 0.7559045631290682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 276}], {
             RGBColor[
             0.9890251901316981, 0.9882999725314106, 0.7276221937243997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 283}], {
             RGBColor[
             0.9918780200755959, 0.9894796910275977, 0.6803434186667835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 292}], {
             RGBColor[
             0.9396705826350173, 0.9502412857392541, 0.768217319307535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 396}], {
             RGBColor[
             0.9273785870366069, 0.9404399821064136, 0.7670448977941645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 422}], {
             RGBColor[
             0.9324666382453095, 0.9444970560287622, 0.7675302006606075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 267}], {
             RGBColor[
             0.33688926713479533`, 0.46453212671992494`, 0.942749002554194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 270}], {
             RGBColor[
             0.6829944443064742, 0.7298802113735849, 0.6665050347293914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 329}], {
             RGBColor[
             0.6301974304787991, 0.7056252492766882, 0.9668923785471395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 426}], {
             RGBColor[
             0.6864643455897901, 0.7481912274169398, 0.883342251446946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 448}], {
             RGBColor[
             0.6255873602919473, 0.7019493044467142, 0.9664526659372594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 489}], {
             RGBColor[
             0.6259504265346924, 0.7022388036135085, 0.9664872955196055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 265}], {
             RGBColor[
             0.994600046761569, 0.9920349948105099, 0.7391547299992098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 328}], {
             RGBColor[
             0.967275885745263, 0.9734698322386974, 0.8666040572417388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 343}], {
             RGBColor[
             0.9730442461027249, 0.9777718659484694, 0.8568397277858869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 431}], {
             RGBColor[
             0.9458656613490962, 0.956520604366665, 0.868816152042176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 433}], {
             RGBColor[
             0.9660858301638424, 0.9725822907346112, 0.8686185109248784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 436}], {
             RGBColor[
             0.9657814104716751, 0.9723552550266343, 0.869133814058346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 462}], {
             RGBColor[
             0.9946142576473669, 0.9919132463110414, 0.7296422238291326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 465}], {
             RGBColor[
             0.9909647851280179, 0.9905317207030739, 0.799400423022686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 262}], {
             RGBColor[
             0.9579772772873407, 0.8698997457460601, 0.2913015656396062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 263}], {
             RGBColor[
             0.9774741947133674, 0.9341835118612033, 0.4940138118011457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 296}], {
             RGBColor[
             0.8099728369150944, 0.8055356708954557, 0.6329717059424971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 332}], {
             RGBColor[
             0.957422683383976, 0.9213213560252286, 0.6302832533751241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 393}], {
             RGBColor[
             0.9292622818498739, 0.8993601041428274, 0.6446929564167936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 424}], {
             RGBColor[
             0.7531926724175317, 0.7597079981859289, 0.6283178310793602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 440}], {
             RGBColor[
             0.9272370552666924, 0.8977452434387097, 0.6444997884973487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 453}], {
             RGBColor[
             0.9773443758435434, 0.9339058424253506, 0.47988382896998577`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 251}], {
             RGBColor[
             0.7602349483414985, 0.8129351068290016, 0.9767908427657914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 310}], {
             RGBColor[
             0.9440835591881032, 0.9561551455595921, 0.9144814116619862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 352}], {
             RGBColor[
             0.883738708352259, 0.9101332738646348, 0.9887729809971384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 367}], {
             RGBColor[
             0.7175636762985882, 0.778292645865668, 0.9734316039205537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 382}], {
             RGBColor[
             0.9054629725897041, 0.9274556124781301, 0.9908450607135857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 399}], {
             RGBColor[
             0.7476868864603028, 0.8027480249101011, 0.9758030133694384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 412}], {
             RGBColor[
             0.9471737073266793, 0.9569955775228809, 0.8314735742702903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 416}], {
             RGBColor[
             0.5392497314389305, 0.6140763399637665, 0.961892109319375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 429}], {
             RGBColor[
             0.9110999613115129, 0.9319503942729177, 0.991382721730071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 402}], {
             RGBColor[
             0.9905229829572051, 0.990349024151645, 0.8067222283404207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 417}], {
             RGBColor[
             0.9691747791072346, 0.9753998357594013, 0.8863992754610857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 436}], {
             RGBColor[
             0.9642350540709201, 0.9717157969153754, 0.8947609414609395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 461}], {
             RGBColor[
             0.901633345777288, 0.9219069112996097, 0.8903552981100267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 339}], {
             RGBColor[
             0.8486612085621383, 0.8794171069643555, 0.8237097988556957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 365}], {
             RGBColor[
             0.7657837967439282, 0.8130549701037662, 0.8165553647460444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 374}], {
             RGBColor[
             0.9152659626359678, 0.6334447815636794, 0.4291385328657099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 276}], {
             RGBColor[
             0.8092518939689988, 0.8508199283041207, 0.9360537334087032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 326}], {
             RGBColor[
             0.6814257006302393, 0.7509273517124864, 0.968968532845668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 428}], {
             RGBColor[
             0.6942704717209165, 0.7609617845123993, 0.9702487795867762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 454}], {
             RGBColor[
             0.8128111866376069, 0.8522917872922395, 0.8770670427357092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 469}], {
             RGBColor[
             0.7480759182362808, 0.8033352033630408, 0.9755213263364252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 471}], {
             RGBColor[
             0.7935368472964579, 0.8391384844754084, 0.9643933000769367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 475}], {
             RGBColor[
             0.7167549376872637, 0.7785268202135802, 0.9724898210250209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 495}], {
             RGBColor[
             0.5119288206147397, 0.6129206845093766, 0.9551967419382559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 274}], {
             RGBColor[
             0.9355421934432513, 0.9498460760016805, 0.9354472218773706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 313}], {
             RGBColor[
             0.859502122624205, 0.8908076782896786, 0.9864612738141412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 334}], {
             RGBColor[
             0.9393383098190196, 0.9499419100409676, 0.76539458911395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 340}], {
             RGBColor[
             0.9354564242929773, 0.9498106082538754, 0.9368686386608582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 355}], {
             RGBColor[
             0.6913941919259532, 0.7571517806165352, 0.9712509372186082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 363}], {
             RGBColor[
             0.9038653230721956, 0.9261816901199097, 0.9906926754763672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 378}], {
             RGBColor[
             0.9112857764809787, 0.9320529311534649, 0.9898185250326732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 379}], {
             RGBColor[
             0.9135108755846619, 0.9337124064217264, 0.9860520126489283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 380}], {
             RGBColor[
             0.820689478665902, 0.8603744594367861, 0.9826226426225757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 390}], {
             RGBColor[
             0.9341894575010998, 0.9332342592664957, 0.6892164595889423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 498}], {
             RGBColor[
             0.8027793460461499, 0.8463829277121863, 0.9808375279827442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 394}], {
             RGBColor[
             0.7905160712206705, 0.8371788447206481, 0.9778430144829682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 438}], {
             RGBColor[
             0.7252004992515454, 0.7852514088340208, 0.9732448664475686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 445}], {
             RGBColor[
             0.8166563155370289, 0.8557365433836304, 0.8916043935559693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 460}], {
             RGBColor[
             0.6836730787528231, 0.7528098723203335, 0.9691058012680647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 256}], {
             RGBColor[
             0.9808097419153989, 0.9534951166564114, 0.583030711075226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 288}], {
             RGBColor[
             0.9828010355164034, 0.954318567734338, 0.5500298228039358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 333}], {
             RGBColor[
             0.9139704392031652, 0.674244977502849, 0.27336674696110885`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 392}], {
             RGBColor[
             0.8832614703818922, 0.8782229483928174, 0.6628141954315221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 442}], {
             RGBColor[
             0.9822480845474719, 0.9517439537174173, 0.38866751846169023`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 444}], {
             RGBColor[
             0.9598481337368708, 0.9387747292460776, 0.6593878610124435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 459}], {
             RGBColor[
             0.9819529023830251, 0.9539678428876588, 0.5640855837222032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 492}], {
             RGBColor[
             0.8392212442125899, 0.8438183889912426, 0.658424677266279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 255}], {
             RGBColor[
             0.7986852129050043, 0.8430530639380156, 0.9804643580079484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 269}], {
             RGBColor[
             0.8023159576915266, 0.8459481212768467, 0.980810661686891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 360}], {
             RGBColor[
             0.8406182198899668, 0.8760508899729045, 0.9692638252621144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 369}], {
             RGBColor[
             0.845525682426384, 0.8797108674973321, 0.9609567712591789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 370}], {
             RGBColor[
             0.7261626892613338, 0.7860030789825824, 0.9733407685555673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 425}], {
             RGBColor[
             0.7522034556521986, 0.8063463236042809, 0.9759362687846109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 466}], {
             RGBColor[
             0.8432730047226615, 0.878030824154317, 0.9647699670191394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 468}], {
             RGBColor[
             0.7884177819192468, 0.8348660931719623, 0.979485041274683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 286}], {
             RGBColor[
             0.6709252969210551, 0.7424251969917004, 0.9681264877451956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 294}], {
             RGBColor[
             0.6928978834680446, 0.7595903486000515, 0.9703165098267039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 313}], {
             RGBColor[
             0.7242251095967938, 0.784175902153214, 0.9734090645242262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 380}], {
             RGBColor[
             0.6854124656384908, 0.7537426833003216, 0.9695704333326607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 411}], {
             RGBColor[
             0.7810044059418005, 0.8291468970051107, 0.9683099960824135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 478}], {
             RGBColor[
             0.7358938871820142, 0.7934802686591389, 0.9745220429471453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 260}], {
             RGBColor[
             0.9174452890507323, 0.9329129803136913, 0.7979991103764907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 280}], {
             RGBColor[
             0.9941911049867913, 0.9899836858731512, 0.6091158100358588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 296}], {
             RGBColor[
             0.8270660812483781, 0.8621407854082339, 0.7890353441283584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 424}], {
             RGBColor[
             0.7702859167508154, 0.8163131126987071, 0.7843814692652216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 440}], {
             RGBColor[
             0.944330299599976, 0.9543503579514878, 0.8005634266832099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 470}], {
             RGBColor[
             0.9924379497290272, 0.9902173793481466, 0.707855189645098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 339}], {
             RGBColor[
             0.5852047733314869, 0.673213144383643, 0.9611186305751831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 365}], {
             RGBColor[
             0.5023273615132766, 0.6068510075230537, 0.9539641964655318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 305}], {
             RGBColor[
             0.7092510220108934, 0.772462792171028, 0.9718799492332584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 367}], {
             RGBColor[
             0.5782261617622256, 0.6684690727671367, 0.9599392280475951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 382}], {
             RGBColor[
             0.7661254580533416, 0.8176320393795987, 0.9773526848406271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 416}], {
             RGBColor[
             0.39991221690256795`, 0.5042527668652351, 0.9483997334464165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 427}], {
             RGBColor[
             0.8022249622046049, 0.8296461819292325, 0.6769517140257661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 429}], {
             RGBColor[
             0.7717624467751504, 0.8221268211743864, 0.9778903458571124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 499}], {
             RGBColor[
             0.7935058816657936, 0.8386801183453831, 0.9527711237964847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 282}], {
             RGBColor[
             0.9488956534984843, 0.959933444503889, 0.9123899414315179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 432}], {
             RGBColor[
             0.9470942003472385, 0.9591884973306145, 0.9422446821589721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 467}], {
             RGBColor[
             0.9158254250973081, 0.9357183508264133, 0.9918334406844315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 261}], {
             RGBColor[
             0.9643556555740774, 0.9692301270277472, 0.7147712719287301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 277}], {
             RGBColor[
             0.8883925973098525, 0.9138336609793997, 0.9888529142280984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 291}], {
             RGBColor[
             0.9293667726113374, 0.9465053561504442, 0.9927610676464322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 311}], {
             RGBColor[
             0.9421176088023335, 0.9563519879352731, 0.9828639695389364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 319}], {
             RGBColor[
             0.8811050556748289, 0.9080227730946797, 0.9881578220012848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 377}], {
             RGBColor[
             0.9188140047881468, 0.9380908655354836, 0.9917545352308892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 484}], {
             RGBColor[
             0.962502573485737, 0.9707730472881513, 0.9133373600159145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 488}], {
             RGBColor[
             0.9562720542784344, 0.9669083501955718, 0.9589041854185227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 315}], {
             RGBColor[
             0.9712505351641771, 0.9705127855783031, 0.6894083026403013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 325}], {
             RGBColor[
             0.9892581797004261, 0.9831611815418403, 0.6239210161099115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 347}], {
             RGBColor[
             0.8341183951202693, 0.862753048083055, 0.6913877009850364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 368}], {
             RGBColor[
             0.7025410800904813, 0.7554602328827466, 0.6809336998323787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 386}], {
             RGBColor[
             0.8368928045739268, 0.8649204378345451, 0.6916642281910466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 401}], {
             RGBColor[
             0.9888914375671267, 0.9830095242448781, 0.6299988823568988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 454}], {
             RGBColor[
             0.9905817675427684, 0.9837085191293049, 0.6019857402267651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 471}], {
             RGBColor[
             0.9713074282016193, 0.9705552163124737, 0.6893119975679924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 269}], {
             RGBColor[
             0.8724649834764624, 0.9011439116657843, 0.987697683054312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 274}], {
             RGBColor[
             0.9274077195886081, 0.9433598673543986, 0.9346713484993843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 334}], {
             RGBColor[
             0.9312038359643764, 0.9434557013936857, 0.7646187157359636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 338}], {
             RGBColor[
             0.9302278169456392, 0.9445260500847272, 0.8879350371153691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 369}], {
             RGBColor[
             0.9156747082113198, 0.9349066578862697, 0.9678437926265998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 370}], {
             RGBColor[
             0.7963117150462695, 0.84119886937152, 0.9802277899229883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 379}], {
             RGBColor[
             0.9053764017300188, 0.9272261977744446, 0.9852761392709419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 390}], {
             RGBColor[
             0.9260549836464567, 0.9267480506192138, 0.6884405862109559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 425}], {
             RGBColor[
             0.8223524814371344, 0.8615421139932186, 0.982823290152032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 466}], {
             RGBColor[
             0.9134220305075973, 0.9332266145432546, 0.9716569883865604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 271}], {
             RGBColor[
             0.946428873227682, 0.9578157890729806, 0.9056102309447203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 333}], {
             RGBColor[
             0.9228466529880566, 0.7107527527167289, 0.510929972030487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 442}], {
             RGBColor[
             0.9911242983323633, 0.9882517289312971, 0.6262307435310684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 444}], {
             RGBColor[
             0.9687243475217622, 0.9752825044599576, 0.8969510860818217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 492}], {
             RGBColor[
             0.8480974579974812, 0.8803261642051226, 0.8959879023356571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 272}], {
             RGBColor[
             0.985088468600793, 0.9598803102406774, 0.5225679380619161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 306}], {
             RGBColor[
             0.9083630305854636, 0.9023341038829213, 0.6715903657834846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 317}], {
             RGBColor[
             0.9565112892094869, 0.9406733415604771, 0.6743495178385408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 357}], {
             RGBColor[
             0.9669073499467886, 0.9484267066363696, 0.6567516987371829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 418}], {
             RGBColor[
             0.9324926988390869, 0.9215744463659643, 0.6738918750823244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 420}], {
             RGBColor[
             0.9041692450060008, 0.8989900930991347, 0.6711903587710788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 289}], {
             RGBColor[
             0.7181962904779706, 0.7788134642981315, 0.9734730797209258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 297}], {
             RGBColor[
             0.5438444347713358, 0.6405564379167824, 0.9572325725544566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 314}], {
             RGBColor[
             0.747038565645719, 0.8012813686695599, 0.957843692984413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 373}], {
             RGBColor[
             0.6832350122000286, 0.7509362899979183, 0.9701384417884741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 381}], {
             RGBColor[
             0.733246366476605, 0.7908139863760124, 0.974908569405037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 397}], {
             RGBColor[
             0.7132900437989599, 0.7749013563728065, 0.9730051175328236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 472}], {
             RGBColor[
             0.7315446064596824, 0.7894570491315633, 0.9747462540154438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 341}], {
             RGBColor[
             0.9432761884932319, 0.9560458759653139, 0.9376144947510644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 405}], {
             RGBColor[
             0.9825683220746682, 0.9862513111998417, 0.9023561788638788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 450}], {
             RGBColor[
             0.9896910285063034, 0.9885301361431931, 0.7133035892237071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 454}], {
             RGBColor[
             0.9886769321933212, 0.9895856347194383, 0.8373160669242106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 469}], {
             RGBColor[
             0.923941663791995, 0.9406290507902395, 0.9357703505249264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 471}], {
             RGBColor[
             0.9694025928521721, 0.9764323319026071, 0.9246423242654379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 475}], {
             RGBColor[
             0.8926206832429779, 0.915820667640779, 0.9327388452135221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 491}], {
             RGBColor[
             0.988281345687734, 0.9894220495332686, 0.8438719590668493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 500}], {
             RGBColor[
             0.989203631222151, 0.9898034383034071, 0.8285873009631073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 280}], {
             RGBColor[
             0.917424925078254, 0.9328694238356735, 0.7957826176440925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 424}], {
             RGBColor[
             0.6935197368422782, 0.7591988506612295, 0.9710482768734554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 440}], {
             RGBColor[
             0.8675641196914389, 0.8972360959140101, 0.9872302342914436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 470}], {
             RGBColor[
             0.91567176982049, 0.933103117310669, 0.8945219972533317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 483}], {
             RGBColor[
             0.9170041177333599, 0.9336540774124201, 0.8724415443312101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 484}], {
             RGBColor[
             0.9907521435823045, 0.9881345706333128, 0.6350687214731724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 500}], {
             RGBColor[
             0.9926014129641094, 0.9888992910467445, 0.6044215420609141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 332}], {
             RGBColor[
             0.9553749803786145, 0.914404088445676, 0.622379792618196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 344}], {
             RGBColor[
             0.9746666824020072, 0.925641089004624, 0.4034097970857373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 387}], {
             RGBColor[
             0.973341926640863, 0.9267135745878903, 0.5431435796116055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 393}], {
             RGBColor[
             0.9272145788445125, 0.8924428365632748, 0.6367894956598654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 424}], {
             RGBColor[
             0.7511449694121702, 0.7527907306063764, 0.6204143703224321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 296}], {
             RGBColor[
             0.8274220513357595, 0.8629021694310464, 0.8277804913471083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 323}], {
             RGBColor[
             0.8935005603800527, 0.9145232029117174, 0.8343665795898678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 342}], {
             RGBColor[
             0.8663677761544737, 0.8933268656578974, 0.8316622372285468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 395}], {
             RGBColor[
             0.9677958545918847, 0.9734105531187027, 0.8370699342112891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 440}], {
             RGBColor[
             0.9446862696873577, 0.9551117419743003, 0.8393085739019599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 447}], {
             RGBColor[
             0.9921524504656842, 0.9907134993094241, 0.7572311440748194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 453}], {
             RGBColor[
             0.9947935902642085, 0.9912723409609412, 0.674692614374597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 463}], {
             RGBColor[
             0.9750781471528722, 0.9788416749870277, 0.8247429124316255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 394}], {
             RGBColor[
             0.9600461218718717, 0.9697230436272888, 0.9525156734173084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 398}], {
             RGBColor[
             0.964584590975502, 0.9731078264537151, 0.9448332290471809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 445}], {
             RGBColor[
             0.9861863661882301, 0.9882807422902713, 0.8662770524903094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 328}], {
             RGBColor[
             0.9677814781262128, 0.9736789076813517, 0.8582250830582606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 433}], {
             RGBColor[
             0.9665914225447922, 0.9727913661772655, 0.8602395367414002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 462}], {
             RGBColor[
             0.9951198500283167, 0.9921223217536956, 0.7212632496456544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 364}], {
             RGBColor[
             0.8563524415798786, 0.8869313721267564, 0.903900345806318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 374}], {
             RGBColor[
             0.7797958596060238, 0.529897253785015, 0.5774766163258029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 410}], {
             RGBColor[
             0.8569048340329175, 0.8871598006019266, 0.8947457733136186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 437}], {
             RGBColor[
             0.8515973827287754, 0.8841565079857425, 0.9464965704777946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 278}], {
             RGBColor[
             0.5283178217457896, 0.6199484588669133, 0.9585897208952223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 329}], {
             RGBColor[
             0.5838169308563568, 0.6637666349049215, 0.9639987925823418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 406}], {
             RGBColor[
             0.6402764959238271, 0.7064122787530553, 0.8772559571411813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 413}], {
             RGBColor[
             0.6305003409948035, 0.7000935054985626, 0.9373445439124175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 476}], {
             RGBColor[
             0.5801260491904193, 0.6608236260508169, 0.9636467529941557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 486}], {
             RGBColor[
             0.6360116823565787, 0.7042038548621814, 0.9280152805749733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 493}], {
             RGBColor[
             0.6390131620233306, 0.7058898577189996, 0.8981926692757385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 275}], {
             RGBColor[
             0.8403622234581245, 0.8754699845986836, 0.9499562516924811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 285}], {
             RGBColor[
             0.8318053795941028, 0.8690883044554422, 0.9644407563719625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 324}], {
             RGBColor[
             0.8372407281216881, 0.8371376431693389, 0.650730746242207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 353}], {
             RGBColor[
             0.8324882616478971, 0.8211064578210485, 0.6322683114195167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 441}], {
             RGBColor[
             0.8306927226351568, 0.8147283832640206, 0.6269663165171628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 480}], {
             RGBColor[
             0.8255523944583134, 0.8644248383794939, 0.9750254291671372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 481}], {
             RGBColor[
             0.8503017073376457, 0.8812376779539047, 0.8594577863546992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 360}], {
             RGBColor[
             0.9143979904614248, 0.9341417377006732, 0.976497150308478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 369}], {
             RGBColor[
             0.9193054529978422, 0.9378017152251008, 0.9681900963055424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 425}], {
             RGBColor[
             0.8259832262236568, 0.8644371713320497, 0.9831695938309746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 466}], {
             RGBColor[
             0.9170527752941195, 0.9361216718820857, 0.9720032920655031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 468}], {
             RGBColor[
             0.8621975524907051, 0.892956940899731, 0.9867183663210466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 309}], {
             RGBColor[
             0.9777202224601068, 0.9662729347892471, 0.6592136724799504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 345}], {
             RGBColor[
             0.9885926697729455, 0.9726746673528592, 0.564370052495222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 375}], {
             RGBColor[
             0.8191908142021, 0.8421487410407764, 0.6768407250721037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 426}], {
             RGBColor[
             0.9861890231390266, 0.971680697698833, 0.6042046976573456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 489}], {
             RGBColor[
             0.9256751040839288, 0.9257282738954018, 0.6873497417300052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 284}], {
             RGBColor[
             0.755693608944729, 0.8092221978364671, 0.9764633093084133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 442}], {
             RGBColor[
             0.9478672158597551, 0.9560646261339865, 0.7112470383311846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 444}], {
             RGBColor[
             0.925467265049154, 0.9430954016626469, 0.9819673808819379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 464}], {
             RGBColor[
             0.9292576241200964, 0.9459222452516123, 0.9755512916588052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 492}], {
             RGBColor[
             0.804840375524873, 0.8481390614078119, 0.9810041971357732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 306}], {
             RGBColor[
             0.9181784227277052, 0.9339619920073389, 0.8357173032058869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 317}], {
             RGBColor[
             0.9663266813517285, 0.9723012296848945, 0.8384764552609432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 357}], {
             RGBColor[
             0.9767227420890303, 0.980054594760787, 0.820878636159585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 308}], {
             RGBColor[
             0.9836150885056933, 0.9848459626869382, 0.7815253705222384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 421}], {
             RGBColor[
             0.9938434065584488, 0.9909637312124323, 0.6965684737722452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 423}], {
             RGBColor[
             0.9926404105714326, 0.9904662614562144, 0.7165052305309207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 446}], {
             RGBColor[
             0.9625900267336354, 0.9690385847436827, 0.8127148747751083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 477}], {
             RGBColor[
             0.9696012981125682, 0.9743945007572212, 0.805247062275895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 334}], {
             RGBColor[
             0.9897773168630444, 0.9885667144211312, 0.7119386848599785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 340}], {
             RGBColor[
             0.9858954313370021, 0.9884354126340389, 0.8834127344068866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 361}], {
             RGBColor[
             0.9689130404342503, 0.9760387257668541, 0.9241947768290093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 363}], {
             RGBColor[
             0.9543043301162205, 0.9648064945000732, 0.9372367712223955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 369}], {
             RGBColor[
             0.9742481891099879, 0.9800176709137152, 0.9151637617506145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 370}], {
             RGBColor[
             0.8548851959449375, 0.8863098823989655, 0.9275477590470032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 379}], {
             RGBColor[
             0.9639498826286867, 0.97233721080189, 0.9325961083949568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 498}], {
             RGBColor[
             0.8532183530901747, 0.8850077320923497, 0.9273816237287724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 282}], {
             RGBColor[
             0.9815580862299984, 0.9849843476296533, 0.881069262413654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 285}], {
             RGBColor[
             0.9656586427575553, 0.973908852514172, 0.9430151395377335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 324}], {
             RGBColor[
             0.9710939912851406, 0.9419581912280688, 0.6293051294079781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 353}], {
             RGBColor[
             0.9663415248113496, 0.9259270058797784, 0.6108426945852877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 441}], {
             RGBColor[
             0.9645459857986093, 0.9195489313227505, 0.605540699682934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 481}], {
             RGBColor[
             0.9841549705010981, 0.9860582260126346, 0.8380321695204702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 283}], {
             RGBColor[
             0.9872784468065956, 0.9890073250725921, 0.8604925889464186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 292}], {
             RGBColor[
             0.9350710093660173, 0.9497689197842486, 0.94836648958717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 396}], {
             RGBColor[
             0.9227790137676066, 0.9399676161514081, 0.9471940680737996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 422}], {
             RGBColor[
             0.9278670649763094, 0.9440246900737568, 0.9476793709402426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 291}], {
             RGBColor[
             0.88165328444368, 0.9084704134472581, 0.9885740714030583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 311}], {
             RGBColor[
             0.8944041206346761, 0.918317045232087, 0.9786769732955625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 319}], {
             RGBColor[
             0.8333915675071715, 0.8699878303914936, 0.9839708257579108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 331}], {
             RGBColor[
             0.8394763207431464, 0.8748396474556335, 0.9845511949534814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 377}], {
             RGBColor[
             0.8711005166204893, 0.9000559228322975, 0.9875675389875154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 419}], {
             RGBColor[
             0.8279410972532778, 0.8656804157132774, 0.9834407005470158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 449}], {
             RGBColor[
             0.8453274328981288, 0.8795051654638081, 0.9851092792541731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 484}], {
             RGBColor[
             0.9147890853180796, 0.9327381045849652, 0.9091503637725407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 488}], {
             RGBColor[
             0.908558566110777, 0.9288734074923857, 0.9547171891751489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 329}], {
             RGBColor[
             0.8216259850897932, 0.8610415814236766, 0.9827330968881678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 406}], {
             RGBColor[
             0.8780855501572635, 0.9036872252718104, 0.8959902614470073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 413}], {
             RGBColor[
             0.8683093952282399, 0.8973684520173177, 0.9560788482182436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 486}], {
             RGBColor[
             0.8738207365900151, 0.9014788013809365, 0.9467495848807994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 493}], {
             RGBColor[
             0.8768222162567672, 0.9031648042377547, 0.9169269735815646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.9638582727185763, 0.9725661394869369, 0.9460626964020157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 324}], {
             RGBColor[
             0.9692936212461616, 0.9406154782008336, 0.6323526862722602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 481}], {
             RGBColor[
             0.9823546004621191, 0.9847155129853995, 0.8410797263847524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 494}], {
             RGBColor[
             0.9819509071993509, 0.9845485754468011, 0.847769968473496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 327}], {
             RGBColor[
             0.974881824819239, 0.9781709869368751, 0.783476559582553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 470}], {
             RGBColor[
             0.9924175857565489, 0.9901738228701289, 0.7056386969126998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 483}], {
             RGBColor[
             0.9937499336694187, 0.99072478297188, 0.6835582439905781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 288}], {
             RGBColor[
             0.9892678282940414, 0.9898299854424233, 0.8275233893451877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 343}], {
             RGBColor[
             0.9684305757553071, 0.9758639946938925, 0.9333001852387186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 465}], {
             RGBColor[
             0.9863511147806001, 0.9886238494484971, 0.8758608804755177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 324}], {
             RGBColor[
             0.9784365908935619, 0.9466520062003085, 0.5818437569633799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 353}], {
             RGBColor[
             0.9736841244197709, 0.9306208208520181, 0.5633813221406895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 432}], {
             RGBColor[
             0.9870992326871739, 0.9889332154286186, 0.8634626306965099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 441}], {
             RGBColor[
             0.9718885854070307, 0.9242427462949903, 0.5580793272383358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 467}], {
             RGBColor[
             0.9558304574372436, 0.9654630689244175, 0.9130513892219693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 292}], {
             RGBColor[
             0.937923839309915, 0.9509486382804357, 0.9010877145295537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 386}], {
             RGBColor[
             0.8371487765063623, 0.8716911027659513, 0.891184386237706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 422}], {
             RGBColor[
             0.9307198949202071, 0.9452044085699438, 0.9004005958826263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 442}], {
             RGBColor[
             0.8003890340494102, 0.8396581376947836, 0.6970838218947615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 444}], {
             RGBColor[
             0.7779890832388091, 0.826688913223444, 0.9678041644455148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 464}], {
             RGBColor[
             0.7817794423097515, 0.8295157568124094, 0.961388075222382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 324}], {
             RGBColor[
             0.9625371474211188, 0.9355765110848273, 0.6437896340874594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 480}], {
             RGBColor[
             0.9508488137577441, 0.9628637062949823, 0.9680843170123896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 481}], {
             RGBColor[
             0.9755981266370763, 0.9796765458693931, 0.8525166741999516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 294}], {
             RGBColor[
             0.7492740200446955, 0.8040578262431641, 0.9756442900203872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 346}], {
             RGBColor[
             0.852430887071785, 0.8848388969734221, 0.9481614687058302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 358}], {
             RGBColor[
             0.8539643772468144, 0.8859825714350993, 0.9455656698377986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 407}], {
             RGBColor[
             0.7204124105073617, 0.7815109175162422, 0.9727676345087816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 411}], {
             RGBColor[
             0.8373805425184515, 0.8736143746482233, 0.9736377762760968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 295}], {
             RGBColor[
             0.7393699222165304, 0.7960613661751861, 0.9750729656104852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 299}], {
             RGBColor[
             0.7890162594322216, 0.8333167250745345, 0.8895213459599175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 300}], {
             RGBColor[
             0.7242448840520709, 0.7840010713010699, 0.9736303259680781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 301}], {
             RGBColor[
             0.7462103917381453, 0.8015157708921231, 0.975725415700016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 389}], {
             RGBColor[
             0.791462739005748, 0.8338403618380397, 0.813501098771442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 451}], {
             RGBColor[
             0.7885005326029031, 0.8331034587770363, 0.8980682741799758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 456}], {
             RGBColor[
             0.7130379923755024, 0.7750650000811449, 0.9725614026354567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 343}], {
             RGBColor[
             0.972831290363565, 0.9776838032776138, 0.8603689554955547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 392}], {
             RGBColor[
             0.894128977767788, 0.9155541746846241, 0.8673765322296101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 465}], {
             RGBColor[
             0.9907518293888579, 0.9904436580322185, 0.8029296507323538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 492}], {
             RGBColor[
             0.8500887515984856, 0.8811496152830491, 0.862987014064367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 291}], {
             RGBColor[
             0.9106001239810566, 0.9315518375533347, 0.9913350467992821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 297}], {
             RGBColor[
             0.7242209325103136, 0.783704540107018, 0.9739473616107028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 314}], {
             RGBColor[
             0.9274150633846968, 0.9444294708597955, 0.9745584820406592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 349}], {
             RGBColor[
             0.8195791970916242, 0.8596159688095479, 0.9824830894400354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 359}], {
             RGBColor[
             0.7676435533731403, 0.8189569798902382, 0.9773657493873258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 381}], {
             RGBColor[
             0.9136228642155828, 0.9339620885662481, 0.9916233584612832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 397}], {
             RGBColor[
             0.8936665415379377, 0.9180494585630421, 0.9897199065890698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 419}], {
             RGBColor[
             0.8568879367906544, 0.8887618398193542, 0.9862016759432395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 472}], {
             RGBColor[
             0.9119211041986601, 0.932605151321799, 0.99146104307169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 316}], {
             RGBColor[
             0.8297762221723959, 0.8678218804428467, 0.980374553010561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 340}], {
             RGBColor[
             0.8531325839399007, 0.8849722643445448, 0.92880304051226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 355}], {
             RGBColor[
             0.6090703515728766, 0.6923134367072046, 0.9631853390700101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 362}], {
             RGBColor[
             0.8560861475495848, 0.8861936388002718, 0.8798548479221923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 378}], {
             RGBColor[
             0.8289619361279021, 0.8672145872441344, 0.981752926884075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 384}], {
             RGBColor[
             0.8509664595957094, 0.8836255248173246, 0.9445050083519482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 297}], {
             RGBColor[
             0.7362482682744218, 0.7932948111719857, 0.9750945396328128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 311}], {
             RGBColor[
             0.935378295936161, 0.9509887404031314, 0.9825851267138963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 319}], {
             RGBColor[
             0.8743657428086563, 0.9026595255625381, 0.9878789791762446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 349}], {
             RGBColor[
             0.8316065328557325, 0.8692062398745157, 0.9836302674621453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 359}], {
             RGBColor[
             0.7796708891372484, 0.8285472509552059, 0.9785129274094357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 419}], {
             RGBColor[
             0.8689152725547626, 0.8983521108843219, 0.9873488539653494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 488}], {
             RGBColor[
             0.9495327414122618, 0.9615451026634302, 0.9586253425934826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 308}], {
             RGBColor[
             0.9292718311207488, 0.9454827143928515, 0.9599210774807126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 386}], {
             RGBColor[
             0.784941339065784, 0.8324526974776076, 0.9790582868784574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 422}], {
             RGBColor[
             0.8785124574796287, 0.9059660032816003, 0.9882744965233778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 298}], {
             RGBColor[
             0.7992727007380958, 0.8439645355849911, 0.980402827962884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 317}], {
             RGBColor[
             0.8057368565927784, 0.8490660011991018, 0.9791861130839628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 353}], {
             RGBColor[
             0.8160958871131283, 0.8083006102478263, 0.6306344727213404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 418}], {
             RGBColor[
             0.7817182662223785, 0.8299671060045891, 0.9787284703277462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 420}], {
             RGBColor[
             0.7533948123892923, 0.8073827527377595, 0.9760269540165007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 432}], {
             RGBColor[
             0.8295109953805313, 0.8666130048244267, 0.9307157812771609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 358}], {
             RGBColor[
             0.8759369637938039, 0.9031477230434504, 0.9477556919193069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 411}], {
             RGBColor[
             0.859353129065441, 0.8907795262565744, 0.9758277983576051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 430}], {
             RGBColor[
             0.8579939496174165, 0.8897658524496899, 0.9781285346323363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 478}], {
             RGBColor[
             0.8142426103056547, 0.8551128979106026, 0.9820398452223369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 300}], {
             RGBColor[
             0.8754056008934707, 0.9034886801731734, 0.9879781617686665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 336}], {
             RGBColor[
             0.8971430929288248, 0.9208215662736621, 0.9900515031642867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 389}], {
             RGBColor[
             0.942623455847148, 0.9533279707101431, 0.8278489345720305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 409}], {
             RGBColor[
             0.8875090439041649, 0.9131396370906926, 0.9891325989678976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 456}], {
             RGBColor[
             0.8641987092169023, 0.8945526089532483, 0.986909238436045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 458}], {
             RGBColor[
             0.848721446689031, 0.8823171139866148, 0.9854049659820565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 332}], {
             RGBColor[
             0.8073705400063681, 0.8500400135950716, 0.9640499329210868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 395}], {
             RGBColor[
             0.8002944967936116, 0.8447627121529553, 0.9760278283526405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 424}], {
             RGBColor[
             0.6031405290399239, 0.6884266557557721, 0.9620845106253229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 440}], {
             RGBColor[
             0.7771849118890846, 0.8264639010085527, 0.9782664680433113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 453}], {
             RGBColor[
             0.8272922324659355, 0.8626244999951936, 0.8136505085159484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 311}], {
             RGBColor[
             0.748999104465418, 0.8031414429568147, 0.9651974415253171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 314}], {
             RGBColor[
             0.753063207678062, 0.8061724444784464, 0.95831797487419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 349}], {
             RGBColor[
             0.6452273413849894, 0.721358942428199, 0.9662425822735661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 359}], {
             RGBColor[
             0.5932916976665055, 0.6806999535088891, 0.9611252422208565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 381}], {
             RGBColor[
             0.739271008508948, 0.795705062184899, 0.975382851294814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 397}], {
             RGBColor[
             0.7193146858313029, 0.7797924321816931, 0.9734793994226005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 419}], {
             RGBColor[
             0.6825360810840196, 0.7505048134380051, 0.9699611687767702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 353}], {
             RGBColor[
             0.9416443766260896, 0.907227404439308, 0.6429231095538668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 418}], {
             RGBColor[
             0.9072667557353398, 0.9288939001960708, 0.9910171071602726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 420}], {
             RGBColor[
             0.8789433019022536, 0.906309546929241, 0.9883155908490271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 432}], {
             RGBColor[
             0.9550594848934926, 0.9655397990159085, 0.9430044181096873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 300}], {
             RGBColor[
             0.925051938109162, 0.9407440390725217, 0.9024265421180988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 301}], {
             RGBColor[
             0.9470174457952364, 0.9582587386635749, 0.9045216318500368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 389}], {
             RGBColor[
             0.9922697930628392, 0.9905833296094915, 0.7422973149214628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 451}], {
             RGBColor[
             0.9893075866599943, 0.9898464265484881, 0.8268644903299965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 456}], {
             RGBColor[
             0.9138450464325935, 0.9318079678525967, 0.9013576187854774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 301}], {
             RGBColor[
             0.8822460704150856, 0.9089430848901103, 0.9886306118581973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 389}], {
             RGBColor[
             0.9274984176826884, 0.9412676758360269, 0.8264062949296234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 409}], {
             RGBColor[
             0.8723840057397053, 0.9010793422165764, 0.9876899593254904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 451}], {
             RGBColor[
             0.9245362112798434, 0.9405307727750236, 0.9109734703381571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 456}], {
             RGBColor[
             0.8490736710524427, 0.8824923140791321, 0.985466598793638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 458}], {
             RGBColor[
             0.8335964085245715, 0.8702568191124986, 0.9839623263396493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 389}], {
             RGBColor[
             0.9494639253687629, 0.9587823754270801, 0.8285013846615613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 451}], {
             RGBColor[
             0.946501718965918, 0.9580454723660767, 0.9130685600700951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 456}], {
             RGBColor[
             0.8710391787385171, 0.9000070136701853, 0.9875616885255759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 315}], {
             RGBColor[
             0.8183156844805555, 0.8586247666866238, 0.9668782694087141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 325}], {
             RGBColor[
             0.8363233290168043, 0.8712731626501609, 0.9013909828783242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 347}], {
             RGBColor[
             0.6811835444366475, 0.7508650291913755, 0.9688576677534491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 368}], {
             RGBColor[
             0.5496062294068595, 0.6435722139910671, 0.9584036666007913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 386}], {
             RGBColor[
             0.6839579538903051, 0.7530324189428657, 0.9691341949594592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 421}], {
             RGBColor[
             0.8385167639980253, 0.8721802043836037, 0.8650400888117213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 477}], {
             RGBColor[
             0.8142746555521447, 0.8556109739283926, 0.9737186773153712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 366}], {
             RGBColor[
             0.772817994940442, 0.8176424120995427, 0.7250488114867044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 435}], {
             RGBColor[
             0.771492928287633, 0.8165666632972199, 0.7249444973859162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 473}], {
             RGBColor[
             0.9096652105593779, 0.9259750798899467, 0.7377341645402791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 310}], {
             RGBColor[
             0.9722761316021082, 0.9781127238241323, 0.8990580330651469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 429}], {
             RGBColor[
             0.939292533725518, 0.9539079725374578, 0.9759593431332317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 483}], {
             RGBColor[
             0.9746433670151979, 0.9790916365026199, 0.8598268160613836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 382}], {
             RGBColor[
             0.854479046259099, 0.8869832978201564, 0.9859341671810526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 416}], {
             RGBColor[
             0.4882658051083254, 0.5736040253057928, 0.9569812157868419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 427}], {
             RGBColor[
             0.8905785504103623, 0.8989974403697902, 0.6855331963661916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 438}], {
             RGBColor[
             0.8022644264949003, 0.8454543345040695, 0.9809258785118408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 460}], {
             RGBColor[
             0.760737005996178, 0.8130127979903823, 0.9767868133323369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 499}], {
             RGBColor[
             0.8818594698715511, 0.9080313767859409, 0.9613526061369102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 317}], {
             RGBColor[
             0.8896012433363991, 0.9147550233271385, 0.9874988829825115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 357}], {
             RGBColor[
             0.8999973040737008, 0.9225083884030311, 0.9699010638811536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 418}], {
             RGBColor[
             0.8655826529659991, 0.8956561281326259, 0.9870412402262951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 420}], {
             RGBColor[
             0.837259199132913, 0.8730717748657961, 0.9843397239150495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 372}], {
             RGBColor[
             0.9887889244919308, 0.9815967196013251, 0.6222255467439468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 417}], {
             RGBColor[
             0.9681161891844072, 0.9749620816217921, 0.9039428500252364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 386}], {
             RGBColor[
             0.8284967683171962, 0.866225178878367, 0.9500177491888648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 421}], {
             RGBColor[
             0.9830555784249164, 0.985372964319105, 0.8459236430411269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 422}], {
             RGBColor[
             0.922067886731041, 0.9397384846823598, 0.9592339588337853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 423}], {
             RGBColor[
             0.9818525824379003, 0.9848754945628871, 0.8658603997998024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 446}], {
             RGBColor[
             0.9518021986001031, 0.9634478178503554, 0.96207004404399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 320}], {
             RGBColor[
             0.9810180613844054, 0.9845127986253474, 0.8789024077695359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 337}], {
             RGBColor[
             0.8427954208603947, 0.8773972704985484, 0.9515378467807543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 348}], {
             RGBColor[
             0.982794265604982, 0.9852473047169221, 0.8494661071654084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 375}], {
             RGBColor[
             0.8141919148064963, 0.8550519941745454, 0.9486869166122631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 489}], {
             RGBColor[
             0.920676204688325, 0.9386315270291707, 0.9591959332701646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 327}], {
             RGBColor[
             0.9720937820612552, 0.977976727835134, 0.8993667032734338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 399}], {
             RGBColor[
             0.7921979827705449, 0.8361444905421602, 0.9000012063926747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 412}], {
             RGBColor[
             0.9916848036369215, 0.99039204315494, 0.7556717672935266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 429}], {
             RGBColor[
             0.955611057621755, 0.9653468599049768, 0.9155809147533072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 483}], {
             RGBColor[
             0.9909618909114348, 0.990530523870139, 0.799448387681459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 319}], {
             RGBColor[
             0.8871165789996525, 0.9125061573473672, 0.9779818810687488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 331}], {
             RGBColor[
             0.8932013322356274, 0.9173579744115068, 0.9785622502643194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 349}], {
             RGBColor[
             0.8443573690467285, 0.8790528716593446, 0.9737331693546496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 377}], {
             RGBColor[
             0.9248255281129703, 0.942574249788171, 0.9815785942983533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 419}], {
             RGBColor[
             0.8816661087457588, 0.9081987426691509, 0.9774517558578537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 484}], {
             RGBColor[
             0.9685140968105606, 0.9752564315408386, 0.9031614190833785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 488}], {
             RGBColor[
             0.962283577603258, 0.9713917344482592, 0.9487282444859868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 354}], {
             RGBColor[
             0.9328387877130371, 0.9486198844482494, 0.9704189481141352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 376}], {
             RGBColor[
             0.9389818450417208, 0.9532013665456485, 0.9600203544226267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 400}], {
             RGBColor[
             0.9302020608730109, 0.9466534178882018, 0.974882238885801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 414}], {
             RGBColor[
             0.9231469759568154, 0.9413917471093445, 0.9868246573880761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 415}], {
             RGBColor[
             0.9437733806851866, 0.9567748859831258, 0.951909534410882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 379}], {
             RGBColor[
             0.8879098118096405, 0.913298813089888, 0.9836101603317273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 380}], {
             RGBColor[
             0.7950884148908806, 0.8399608661049477, 0.9801807903053747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 390}], {
             RGBColor[
             0.9085883937260784, 0.9128206659346574, 0.6867746072717413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 411}], {
             RGBColor[
             0.8906803551941902, 0.9153650798097368, 0.9789203530551275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 478}], {
             RGBColor[
             0.845569836434404, 0.8796984514637651, 0.9851323999198593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 359}], {
             RGBColor[
             0.7964858285408887, 0.8414248842616666, 0.961736362650813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 373}], {
             RGBColor[
             0.8924537851067547, 0.9165522965595823, 0.9712238441082075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 397}], {
             RGBColor[
             0.9225088167056861, 0.9405173629344705, 0.9740905198525571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 398}], {
             RGBColor[
             0.9514448317355528, 0.9633082155269421, 0.9670754140423444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 472}], {
             RGBColor[
             0.9407633793664085, 0.9550730556932274, 0.9758316563351772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 325}], {
             RGBColor[
             0.9708893819789809, 0.9770282534141764, 0.8991558209547295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 347}], {
             RGBColor[
             0.8157495973988241, 0.8566201199553911, 0.9666225058298543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 368}], {
             RGBColor[
             0.6841722823690362, 0.7493273047550827, 0.9561685046771966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 386}], {
             RGBColor[
             0.8185240068524817, 0.8587875097068812, 0.9668990330358644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 401}], {
             RGBColor[
             0.9705226398456815, 0.9768765961172142, 0.9052336872017168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 378}], {
             RGBColor[
             0.9382826526072248, 0.9534918838841253, 0.98935555006049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 357}], {
             RGBColor[
             0.948145562697724, 0.9608476260805867, 0.9726602159362098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 418}], {
             RGBColor[
             0.9137309115900223, 0.9339953658101815, 0.9898003922813513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 420}], {
             RGBColor[
             0.8854074577569362, 0.9114110125433519, 0.9870988759701058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 321}], {
             RGBColor[
             0.9641291889493728, 0.9540423088821429, 0.6777736147446121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 330}], {
             RGBColor[
             0.9828050265526339, 0.9679220023313683, 0.6439787064949214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 335}], {
             RGBColor[
             0.906677156221068, 0.9085264830843309, 0.6825169642330409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 350}], {
             RGBColor[
             0.9291249601581957, 0.926425752614391, 0.6846580558119553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 354}], {
             RGBColor[
             0.9712954117204725, 0.9593868660912162, 0.6656430688433792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 383}], {
             RGBColor[
             0.9806718053446442, 0.966379765103688, 0.6497712801927749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 479}], {
             RGBColor[
             0.9545226030820325, 0.9466771436812067, 0.6870805056667744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 482}], {
             RGBColor[
             0.8527195609790477, 0.8662754238811181, 0.6771652405111882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 496}], {
             RGBColor[
             0.9306870160980094, 0.9276712936199195, 0.6848070461019585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 331}], {
             RGBColor[
             0.8321887791081226, 0.8690287595709135, 0.9838561027266677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 377}], {
             RGBColor[
             0.8638129749854657, 0.8942450349475777, 0.9868724467607016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 449}], {
             RGBColor[
             0.8380398912631053, 0.8736942775790881, 0.9844141870273595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 488}], {
             RGBColor[
             0.9012710244757534, 0.9230625196076658, 0.9540220969483352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 337}], {
             RGBColor[
             0.8510921591802969, 0.8827338812008797, 0.89938039053018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 348}], {
             RGBColor[
             0.9910910039248844, 0.9905839154192534, 0.7973086509148344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 361}], {
             RGBColor[
             0.9705798400427661, 0.9767279902397715, 0.8965715937767907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 375}], {
             RGBColor[
             0.8224886531263986, 0.8603886048768767, 0.8965294603616891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 335}], {
             RGBColor[
             0.8896815190544101, 0.9145770441993767, 0.9791166359290298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 383}], {
             RGBColor[
             0.9636761681779862, 0.9724303262187337, 0.9463709518887637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 479}], {
             RGBColor[
             0.9375269659153745, 0.9527277047962525, 0.9836801773627633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 482}], {
             RGBColor[
             0.8357239238123897, 0.8723259849961639, 0.9737649122071771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 496}], {
             RGBColor[
             0.9136913789313514, 0.9337218547349653, 0.9814067177979474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 494}], {
             RGBColor[
             0.986524884628639, 0.9674445127779483, 0.5683982670556078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 342}], {
             RGBColor[
             0.7649449274004938, 0.8163000581728208, 0.9772062196126579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 395}], {
             RGBColor[
             0.8663730058379047, 0.8963837456336262, 0.9826139165954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 447}], {
             RGBColor[
             0.8907296017117042, 0.9136866918243476, 0.9027751264589303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 452}], {
             RGBColor[
             0.8071388814068544, 0.8492802072452774, 0.9814069654572739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 463}], {
             RGBColor[
             0.8736552983988923, 0.9018148675019511, 0.9702868948157364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 441}], {
             RGBColor[
             0.9614244904621729, 0.8812165898934058, 0.30631519423265985`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 481}], {
             RGBColor[
             0.9810334751646617, 0.9477258845832899, 0.5388066640701961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 347}], {
             RGBColor[
             0.833757241935073, 0.8692685159189282, 0.9011352192994644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 368}], {
             RGBColor[
             0.702179926905285, 0.7619757007186199, 0.8906812181468067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 386}], {
             RGBColor[
             0.8365316513887305, 0.8714359056704184, 0.9014117465054745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 401}], {
             RGBColor[
             0.9885302843819304, 0.9895249920807514, 0.8397464006713269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 421}], {
             RGBColor[
             0.9910904614964509, 0.9905836911111563, 0.7973176403577367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 405}], {
             RGBColor[
             0.8540501060738939, 0.8860725654532928, 0.9467395847076738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 428}], {
             RGBColor[
             0.7416180012758563, 0.7980768861930493, 0.9748812096190724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 434}], {
             RGBColor[
             0.861062508815563, 0.8897806304489178, 0.866721290064294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 469}], {
             RGBColor[
             0.7954234477912208, 0.8404503050436908, 0.9801537563687215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 474}], {
             RGBColor[
             0.6327656079187213, 0.7114228963370804, 0.9651378320996244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 475}], {
             RGBColor[
             0.7641024672422035, 0.8156419218942302, 0.9771222510573172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 491}], {
             RGBColor[
             0.8597631296869597, 0.8892433037867198, 0.8882553649106444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 495}], {
             RGBColor[
             0.5592763501696795, 0.6500357861900266, 0.9598291719705523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 399}], {
             RGBColor[
             0.7756971093334548, 0.824569607185643, 0.9606883049808862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 412}], {
             RGBColor[
             0.9751839301998314, 0.9788171597984228, 0.8163588658817381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 483}], {
             RGBColor[
             0.9744610174743449, 0.9789556405136217, 0.8601354862696705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 431}], {
             RGBColor[
             0.91904709271374, 0.9381645172375068, 0.9878865051012269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 433}], {
             RGBColor[
             0.9392672615284863, 0.954226203605453, 0.9876888639839292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 436}], {
             RGBColor[
             0.938962841836319, 0.9539991678974762, 0.9882041671173969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 462}], {
             RGBColor[
             0.9677956890120107, 0.9735571591818832, 0.8487125768881834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 487}], {
             RGBColor[
             0.9665094947335349, 0.9731529098599974, 0.8793051396624338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 406}], {
             RGBColor[
             0.9335846592678307, 0.9475054013098185, 0.9013993331341268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 413}], {
             RGBColor[
             0.9238085043388071, 0.941186628055326, 0.9614879199053631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 486}], {
             RGBColor[
             0.9293198457005823, 0.9452969774189447, 0.952158656567919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 350}], {
             RGBColor[
             0.9308051605947987, 0.9463560071786621, 0.9474628192582535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 354}], {
             RGBColor[
             0.9729756121570756, 0.9793171206554873, 0.9284478322896774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 414}], {
             RGBColor[
             0.9632838004008539, 0.9720889833165824, 0.9448535415636183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 415}], {
             RGBColor[
             0.983910205129225, 0.9874721221903636, 0.9099384185864242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 482}], {
             RGBColor[
             0.8543997614156509, 0.8862056784453892, 0.9399700039574865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 496}], {
             RGBColor[
             0.9323672165346124, 0.9476015481841906, 0.9476118095482569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 377}], {
             RGBColor[
             0.8698977282214405, 0.8990968520117173, 0.9874528159562722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 403}], {
             RGBColor[
             0.9006732511633146, 0.9229305193136317, 0.9659142405083103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 449}], {
             RGBColor[
             0.8441246444990801, 0.878546094643228, 0.9849945562229301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 488}], {
             RGBColor[
             0.9073557777117283, 0.9279143366718056, 0.9546024661439058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 344}], {
             RGBColor[
             0.9741120884986423, 0.9770626992837925, 0.7423914848212554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 393}], {
             RGBColor[
             0.9266599849411477, 0.9438644468424433, 0.9757711833953834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 424}], {
             RGBColor[
             0.7505903755088055, 0.8042123408855448, 0.95939605805795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 392}], {
             RGBColor[
             0.8252983814545498, 0.6354805844531349, 0.5907134563867833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 442}], {
             RGBColor[
             0.9242849956201296, 0.7090015897777346, 0.3165667794169514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 459}], {
             RGBColor[
             0.9239898134556828, 0.7112254789479764, 0.4919848446774643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 492}], {
             RGBColor[
             0.7812581552852476, 0.6010760250515601, 0.58632393822154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 340}], {
             RGBColor[
             0.9896915477127703, 0.9885312466733261, 0.7133601016434661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 355}], {
             RGBColor[
             0.7456293153457463, 0.7958724190359859, 0.7477424002012161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 361}], {
             RGBColor[
             0.9727091568100186, 0.9761345598061414, 0.7541421440655888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 363}], {
             RGBColor[
             0.9581004464919887, 0.9649023285393604, 0.7671841384589749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 369}], {
             RGBColor[
             0.9780443054857562, 0.9801135049530023, 0.745111128987194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 370}], {
             RGBColor[
             0.8586813123207058, 0.8864057164382526, 0.7574951262835825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 379}], {
             RGBColor[
             0.967745999004455, 0.9724330448411771, 0.7625434756315361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 498}], {
             RGBColor[
             0.857014469465943, 0.885103566131637, 0.7573289909653519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 383}], {
             RGBColor[
             0.9062241354496814, 0.9269145004209217, 0.9511143013771926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 409}], {
             RGBColor[
             0.8583584675382523, 0.88989575876783, 0.9863521909710901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 482}], {
             RGBColor[
             0.7782718910840849, 0.8268101591983519, 0.9785082616956059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 496}], {
             RGBColor[
             0.8562393462030465, 0.8882060289371533, 0.9861500672863762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 409}], {
             RGBColor[
             0.8941214977750593, 0.9184122283170649, 0.9897633007211107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 456}], {
             RGBColor[
             0.8708111630877966, 0.8998252001796208, 0.9875399401892582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 458}], {
             RGBColor[
             0.8553339005599254, 0.8875897052129873, 0.9860356677352696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 348}], {
             RGBColor[
             0.8528683634008736, 0.8834683872924545, 0.8699440899260527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 361}], {
             RGBColor[
             0.8323571995187553, 0.8696124621129726, 0.9692070327880091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 370}], {
             RGBColor[
             0.7183293550294425, 0.7798836187450838, 0.9725600150060028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 375}], {
             RGBColor[
             0.6842660126023878, 0.7532730767500777, 0.9691648993729074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 498}], {
             RGBColor[
             0.7166625121746797, 0.7785814684384682, 0.9723938796877722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 369}], {
             RGBColor[
             0.9770682864670189, 0.9811838536440437, 0.8684274503665994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 379}], {
             RGBColor[
             0.9667699799857179, 0.9735033935322186, 0.8858597970109416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 390}], {
             RGBColor[
             0.9874485619021558, 0.9730252463769878, 0.5890242439509555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 425}], {
             RGBColor[
             0.8837460596928335, 0.9078193097509926, 0.8834069478920317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 478}], {
             RGBColor[
             0.9244300046104814, 0.9399030319060957, 0.8873820365990736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 365}], {
             RGBColor[
             0.6196353974704736, 0.7011654761416138, 0.9638291354309361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 355}], {
             RGBColor[
             0.741747429819704, 0.7957411172488937, 0.9192164497481243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 362}], {
             RGBColor[
             0.9887632257964122, 0.989621319341961, 0.8358859586003065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 363}], {
             RGBColor[
             0.9542185609659464, 0.9647710267522682, 0.9386581880058831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 378}], {
             RGBColor[
             0.9616390143747295, 0.9706422677858235, 0.9377840375621891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 379}], {
             RGBColor[
             0.9638641134784127, 0.972301743054085, 0.9340175251784444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 380}], {
             RGBColor[
             0.8710427165596528, 0.8989637960691446, 0.9305881551520917]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 498}], {
             RGBColor[
             0.8531325839399007, 0.8849722643445448, 0.92880304051226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 387}], {
             RGBColor[
             0.9457484968997414, 0.9570682390268335, 0.8966419463261438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 403}], {
             RGBColor[
             0.9319078423911338, 0.947836134518302, 0.9688934237030684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 405}], {
             RGBColor[
             0.940034848381172, 0.9538972422789215, 0.9551365224245689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 450}], {
             RGBColor[
             0.9471575548128073, 0.956176067222273, 0.7660839327843972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 469}], {
             RGBColor[
             0.8814081900984989, 0.9082749818693194, 0.9885506940856166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 491}], {
             RGBColor[
             0.9457478719942378, 0.9570679806123484, 0.8966523026275395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 395}], {
             RGBColor[
             0.8392402216123258, 0.8751874083798062, 0.979909574234079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 447}], {
             RGBColor[
             0.8635968174861253, 0.8924903545705276, 0.9000707840976093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 453}], {
             RGBColor[
             0.8662379572846497, 0.8930491962220446, 0.8175322543973869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 463}], {
             RGBColor[
             0.8465225141733134, 0.8806185302481311, 0.9675825524544154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 392}], {
             RGBColor[
             0.8732917252290537, 0.9015881839360933, 0.9731533281231411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 433}], {
             RGBColor[
             0.9450356218859481, 0.958528237315225, 0.9779245345280773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 465}], {
             RGBColor[
             0.9699145768501236, 0.9764776672836877, 0.9087064466258848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 387}], {
             RGBColor[
             0.992079034760891, 0.9893721854260068, 0.6631552718146649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 424}], {
             RGBColor[
             0.7698820775321982, 0.8154493414444929, 0.7404260625254915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 375}], {
             RGBColor[
             0.825064362119335, 0.8614537267381577, 0.8538432966275347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 426}], {
             RGBColor[
             0.9920625710562615, 0.9909856833962142, 0.7812072692127766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 448}], {
             RGBColor[
             0.9311855857584186, 0.9447437604259886, 0.8643176837030899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 489}], {
             RGBColor[
             0.9315486520011638, 0.945033259592783, 0.864352313285436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 498}], {
             RGBColor[
             0.8574608616916268, 0.8867621184265481, 0.8570722769423995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 358}], {
             RGBColor[
             0.9790938308208935, 0.9839287937737083, 0.9202728706047498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 404}], {
             RGBColor[
             0.983882679110291, 0.98650132830334, 0.8674302035345235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 407}], {
             RGBColor[
             0.8455418640814407, 0.8794571398548512, 0.9474748352757327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 408}], {
             RGBColor[
             0.7329672055414189, 0.7891541082753712, 0.9378672058760986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 430}], {
             RGBColor[
             0.9611508166445061, 0.9705469231799477, 0.9506457133177793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 368}], {
             RGBColor[
             0.5470401423251282, 0.6415675672598344, 0.9581479030219316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 386}], {
             RGBColor[
             0.6813918668085738, 0.751027772211633, 0.9688784313805995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 421}], {
             RGBColor[
             0.8359506769162941, 0.870175557652371, 0.8647843252328615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 477}], {
             RGBColor[
             0.8117085684704135, 0.8536063271971599, 0.9734629137365114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 375}], {
             RGBColor[
             0.8242648573469753, 0.8611231109684514, 0.8670931597575616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 428}], {
             RGBColor[
             0.8736649902559972, 0.8997148702518951, 0.8720169033354438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 359}], {
             RGBColor[
             0.688649962247816, 0.7566113822114191, 0.969660970050189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 371}], {
             RGBColor[
             0.8118338668836804, 0.8534400527431214, 0.9817443329304637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 397}], {
             RGBColor[
             0.8146729504126135, 0.8557038608842231, 0.9820151272519331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 419}], {
             RGBColor[
             0.7778943456653302, 0.8264162421405351, 0.9784968966061027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 354}], {
             RGBColor[
             0.9192955457626373, 0.93782087093851, 0.9691271816067113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 383}], {
             RGBColor[
             0.928671939386809, 0.9448137699509818, 0.953255392956107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 414}], {
             RGBColor[
             0.9096037340064156, 0.9305927335996051, 0.9855328908806522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 479}], {
             RGBColor[
             0.9025227371241973, 0.9251111485285005, 0.9905646184301065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 482}], {
             RGBColor[
             0.8007196950212125, 0.8447094287284119, 0.9806493532745203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 356}], {
             RGBColor[
             0.9480787085941473, 0.9575172413568773, 0.8153505199493505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 463}], {
             RGBColor[
             0.9748548646298555, 0.9783640962476207, 0.8004399877412486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 367}], {
             RGBColor[
             0.701729921772986, 0.76566723980277, 0.9719213662789422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 399}], {
             RGBColor[
             0.7318531319347006, 0.790122618847203, 0.974292775727827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 412}], {
             RGBColor[
             0.9313399528010772, 0.9443701714599828, 0.8299633366286789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 457}], {
             RGBColor[
             0.6780958783515837, 0.7464800586517526, 0.9700608078064558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 418}], {
             RGBColor[
             0.9240899421103723, 0.8932299748589061, 0.6412487519187291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 420}], {
             RGBColor[
             0.8957664882772861, 0.8706456215920764, 0.6385472356074835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 432}], {
             RGBColor[
             0.9718826712685251, 0.9298758736787437, 0.5932360628681437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 441}], {
             RGBColor[
             0.9566720239883819, 0.8651854045451154, 0.28785275940996946`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 372}], {
             RGBColor[
             0.9750796422876606, 0.9721519643739331, 0.6803440900049261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 414}], {
             RGBColor[
             0.9517741855686925, 0.9635538470764302, 0.9665179039120761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 415}], {
             RGBColor[
             0.9724005902970636, 0.9789369859502115, 0.9316027809348819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 479}], {
             RGBColor[
             0.9446931886864742, 0.9580722620053257, 0.9715496314615303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 482}], {
             RGBColor[
             0.8428901465834895, 0.8776705422052371, 0.9616343663059441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 362}], {
             RGBColor[
             0.7447009934293881, 0.7969624917046207, 0.8702682571580564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 363}], {
             RGBColor[
             0.7101563285989224, 0.772112199114928, 0.9730404865636332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 378}], {
             RGBColor[
             0.7175767820077055, 0.7779834401484833, 0.9721663361199392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 384}], {
             RGBColor[
             0.7395813054755127, 0.7943943777216735, 0.9349184175878125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 498}], {
             RGBColor[
             0.6090703515728766, 0.6923134367072046, 0.9631853390700101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 463}], {
             RGBColor[
             0.9284567291360037, 0.9452864846865181, 0.975573759865596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 418}], {
             RGBColor[
             0.9241269723273241, 0.941748730886074, 0.9722025731799933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 420}], {
             RGBColor[
             0.8958035184942379, 0.9191643776192444, 0.9695010568687478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 404}], {
             RGBColor[
             0.9854161692853204, 0.9876450027650172, 0.864834404666492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 407}], {
             RGBColor[
             0.8470753542564702, 0.8806008143165285, 0.9448790364077011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 408}], {
             RGBColor[
             0.7345006957164482, 0.7902977827370483, 0.935271407008067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 430}], {
             RGBColor[
             0.9626843068195354, 0.971690597641625, 0.9480499144497476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 371}], {
             RGBColor[
             0.7598982231651965, 0.8127810638238115, 0.9766269928777541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 397}], {
             RGBColor[
             0.7627373066941294, 0.8150448719649133, 0.9768977871992235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 419}], {
             RGBColor[
             0.7259587019468463, 0.7857572532212254, 0.9733795565533931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 427}], {
             RGBColor[
             0.8101334045667029, 0.836066611710052, 0.6775742955780893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 393}], {
             RGBColor[
             0.9255999180334553, 0.9430738506783867, 0.977565600160377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 466}], {
             RGBColor[
             0.9553550374925597, 0.9662244405781435, 0.9604564556407263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 468}], {
             RGBColor[
             0.9004998146891451, 0.9230597095957888, 0.97517152989627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 363}], {
             RGBColor[
             0.9372361700631946, 0.9523743398850835, 0.9794402304280059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 370}], {
             RGBColor[
             0.8378170358919117, 0.8738777277839757, 0.9697512182526135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 498}], {
             RGBColor[
             0.8361501930371489, 0.87257557747736, 0.9695850829343828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 363}], {
             RGBColor[
             0.9571721245756306, 0.9659924012079952, 0.8897099954158153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 384}], {
             RGBColor[
             0.9865971014522209, 0.9882745798147408, 0.8515879264399946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 498}], {
             RGBColor[
             0.8560861475495848, 0.8861936388002718, 0.8798548479221923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 370}], {
             RGBColor[
             0.8232083255738818, 0.8626454965171947, 0.9827932126459996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 379}], {
             RGBColor[
             0.932273012257631, 0.9486728249201193, 0.9878415619939532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 498}], {
             RGBColor[
             0.821541482719119, 0.8613433462105791, 0.982627077327769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 374}], {
             RGBColor[
             0.9122788994101974, 0.6326170805425926, 0.5082647670411309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 437}], {
             RGBColor[
             0.9840804225329489, 0.98687633474332, 0.8772847211931226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 435}], {
             RGBColor[
             0.5511941434564878, 0.6465232625279917, 0.9578111685450217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 473}], {
             RGBColor[
             0.6893664257282326, 0.7559316791207185, 0.9706008356993847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 416}], {
             RGBColor[
             0.3572409448596576, 0.46961030590190156`, 0.9450404946011788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 457}], {
             RGBColor[
             0.511920846297913, 0.6146394306527858, 0.954719430729871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 499}], {
             RGBColor[
             0.7508346096228833, 0.8040376573820496, 0.949411884951247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 386}], {
             RGBColor[
             0.5498145517787858, 0.6437349570113247, 0.9584244302279418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 401}], {
             RGBColor[
             0.7018131847719857, 0.7618240434216577, 0.896759084393794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 500}], {
             RGBColor[
             0.7040302137764571, 0.7627408418900532, 0.860017176302557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 370}], {
             RGBColor[
             0.8431521845676493, 0.8778566729308366, 0.9607202031742187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 379}], {
             RGBColor[
             0.9522168712513985, 0.9638840013337611, 0.9657685525221723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 390}], {
             RGBColor[
             0.9728954531678364, 0.9634058541785304, 0.6689329994621862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 425}], {
             RGBColor[
             0.8691929509585141, 0.898199917552535, 0.9633157034032623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 466}], {
             RGBColor[
             0.9602625000289771, 0.9698844181025712, 0.9521494016377908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 466}], {
             RGBColor[
             0.8408995068639267, 0.8761766295878215, 0.9645333989341793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 382}], {
             RGBColor[
             0.897217805051304, 0.9208811396921205, 0.9900586292732251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 419}], {
             RGBColor[
             0.8491426065827107, 0.8825859237529275, 0.9854629194336679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 427}], {
             RGBColor[
             0.9333173092025673, 0.9328952822417542, 0.689657658458364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 429}], {
             RGBColor[
             0.9028547937731128, 0.9253759214869082, 0.9905962902897104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 417}], {
             RGBColor[
             0.9680205519428836, 0.9668873063529979, 0.6922932886530067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 398}], {
             RGBColor[
             0.8876412782898623, 0.9129631368553006, 0.9793701628464055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 472}], {
             RGBColor[
             0.8769598259207181, 0.9047279770215859, 0.9881264051392383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 391}], {
             RGBColor[
             0.8663060298210723, 0.5981012567424984, 0.5859341879533859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 437}], {
             RGBColor[
             0.9075238405590942, 0.6298422164015787, 0.5508609917126075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 426}], {
             RGBColor[
             0.8226607154854161, 0.8604597570841312, 0.8936779417896583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 489}], {
             RGBColor[
             0.7621467964303184, 0.8145073332807, 0.9768229858623179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 400}], {
             RGBColor[
             0.9649723278135717, 0.9733969999526866, 0.9441768917182923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 414}], {
             RGBColor[
             0.9579172428973761, 0.9681353291738293, 0.9561193102205675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 415}], {
             RGBColor[
             0.9785436476257473, 0.9835184680476106, 0.9212041872433734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 464}], {
             RGBColor[
             0.9645477847337003, 0.973080376418844, 0.9448955324139459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 485}], {
             RGBColor[
             0.8274809230015515, 0.8654152186518569, 0.949087642670781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 497}], {
             RGBColor[
             0.956890993302835, 0.96736995390655, 0.957856483095364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 403}], {
             RGBColor[
             0.9322974470406578, 0.9481467946902958, 0.9689305845423442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 449}], {
             RGBColor[
             0.8757488403764231, 0.903762370019892, 0.9880109002569639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 484}], {
             RGBColor[
             0.9452104927963738, 0.9569953091410491, 0.9120519847753314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 488}], {
             RGBColor[
             0.9389799735890711, 0.9531306120484697, 0.9576188101779397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 380}], {
             RGBColor[
             0.8468720687476543, 0.8812061189687341, 0.9835380415239066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 380}], {
             RGBColor[
             0.8490971678513375, 0.8828655942369956, 0.9797715291401619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 390}], {
             RGBColor[
             0.9625971466865353, 0.9557253940667052, 0.6863653461065284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 478}], {
             RGBColor[
             0.8995785893948609, 0.9226031795958131, 0.9847231387546465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 390}], {
             RGBColor[
             0.8697757497677754, 0.882387447081765, 0.6829359760801758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 411}], {
             RGBColor[
             0.8518677112358872, 0.8849318609568444, 0.9750817218635619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 478}], {
             RGBColor[
             0.806757192476101, 0.8492652326108727, 0.9812937687282938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 419}], {
             RGBColor[
             0.8719380127892888, 0.9007623618972351, 0.9876371656273506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 439}], {
             RGBColor[
             0.926304323833069, 0.9440739402361804, 0.9928329274004717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 416}], {
             RGBColor[
             0.5451402411507736, 0.6187732725143635, 0.9624539513942107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 427}], {
             RGBColor[
             0.9474529864528105, 0.944166687578361, 0.6910059319735603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 429}], {
             RGBColor[
             0.9169904710233561, 0.9366473268235148, 0.9919445638049067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 499}], {
             RGBColor[
             0.9387339059139992, 0.9532006239945117, 0.9668253417442789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 479}], {
             RGBColor[
             0.954069582310646, 0.9650651610177975, 0.9556778428109259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 482}], {
             RGBColor[
             0.8522665402076611, 0.8846634412177089, 0.9457625776553398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 496}], {
             RGBColor[
             0.9302339953266228, 0.9460593109565103, 0.9534043832461101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 435}], {
             RGBColor[
             0.7656732451510122, 0.8155769897787313, 0.936972470656992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 391}], {
             RGBColor[
             0.8412672379394774, 0.8765452277207613, 0.9846483605986923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 421}], {
             RGBColor[
             0.8387250863699516, 0.8723429474038611, 0.8650608524388717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 403}], {
             RGBColor[
             0.9769136244911394, 0.9812125665007416, 0.8751405317174576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 405}], {
             RGBColor[
             0.9850406304811776, 0.9872736742613613, 0.8613836304389582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 491}], {
             RGBColor[
             0.9907536540942434, 0.9904444125947882, 0.8028994106419287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 487}], {
             RGBColor[
             0.9936042341385563, 0.9916232006996771, 0.7556579222429891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 490}], {
             RGBColor[
             0.9918267806981494, 0.9908881780235991, 0.7851149256525793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 409}], {
             RGBColor[
             0.9396018606933825, 0.9509186327535459, 0.8275607321288545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 451}], {
             RGBColor[
             0.9917540662335207, 0.9903700633119933, 0.7508442431415211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 456}], {
             RGBColor[
             0.91629152600612, 0.9323316046161019, 0.8253373715970019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 458}], {
             RGBColor[
             0.9008142634782487, 0.9200961096494683, 0.8238330991430134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 425}], {
             RGBColor[
             0.8795732263936511, 0.8900413102854792, 0.6839124969876185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 478}], {
             RGBColor[
             0.9202571713112988, 0.9221250324405823, 0.6878875856946604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 459}], {
             RGBColor[
             0.8932808446344098, 0.9152034498379449, 0.8814322931478775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 465}], {
             RGBColor[
             0.8912122642543467, 0.9143480386906979, 0.9157140233599402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 492}], {
             RGBColor[
             0.7505491864639745, 0.8050539959415286, 0.9757713866919533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 468}], {
             RGBColor[
             0.8733994800627355, 0.9018890538774444, 0.9877868161729457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 398}], {
             RGBColor[
             0.9420938558150301, 0.9563342729962341, 0.9829041771506697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 445}], {
             RGBColor[
             0.9636956310277582, 0.9715071888327903, 0.9043480005937983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 460}], {
             RGBColor[
             0.8307123942435525, 0.8685805177694934, 0.9818494083058935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 440}], {
             RGBColor[
             0.9175587151452096, 0.9369722846962092, 0.9875559109074921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 447}], {
             RGBColor[
             0.9650248959235362, 0.9725740420313329, 0.9054784810803516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 453}], {
             RGBColor[
             0.9676660357220606, 0.9731328836828501, 0.8229399513801292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 463}], {
             RGBColor[
             0.9479505926107243, 0.9607022177089365, 0.9729902494371576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 422}], {
             RGBColor[
             0.8662204618812182, 0.8961646996487598, 0.9871020750100074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 443}], {
             RGBColor[
             0.8993146564985199, 0.9225067491681234, 0.9886511962380853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 446}], {
             RGBColor[
             0.8959547737502802, 0.9198740328167554, 0.9899381602202121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 419}], {
             RGBColor[
             0.8519816901116437, 0.8848497318940293, 0.9857337137551373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 472}], {
             RGBColor[
             0.9070148575196493, 0.9286930433964742, 0.9909930808835878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 445}], {
             RGBColor[
             0.9682341001313886, 0.9748919716592166, 0.8966655562236708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 460}], {
             RGBColor[
             0.8352508633471827, 0.8719653005959196, 0.9741669639357662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 472}], {
             RGBColor[
             0.935950872549516, 0.9514838959889457, 0.9839779750733753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 412}], {
             RGBColor[
             0.7952881309091211, 0.836984922505449, 0.816993369000979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 414}], {
             RGBColor[
             0.9491374587286663, 0.9615873805163827, 0.9709811946837419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 415}], {
             RGBColor[
             0.9697638634570375, 0.9769705193901639, 0.9360660717065477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 464}], {
             RGBColor[
             0.9557680005649904, 0.9665324277613974, 0.9597574168771204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 450}], {
             RGBColor[
             0.9908679685372548, 0.9890168310919707, 0.6937986470876771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 454}], {
             RGBColor[
             0.9898538722242727, 0.9900723296682159, 0.8178111247881805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 471}], {
             RGBColor[
             0.9705795328831237, 0.9769190268513848, 0.905137382129408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 475}], {
             RGBColor[
             0.8937976232739294, 0.9163073625895566, 0.9132339030774922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 500}], {
             RGBColor[
             0.9903805712531025, 0.9902901332521847, 0.8090823588270772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 431}], {
             RGBColor[
             0.9438405463264372, 0.9556831672617133, 0.9023775487973151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 436}], {
             RGBColor[
             0.9637562954490161, 0.9715178179216827, 0.9026952108134851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 459}], {
             RGBColor[
             0.9910082504854218, 0.9905496947453694, 0.7986800895657624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 462}], {
             RGBColor[
             0.9925891426247079, 0.9910758092060897, 0.7632036205842717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 487}], {
             RGBColor[
             0.9913029483462321, 0.9906715598842039, 0.7937961833585221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 405}], {
             RGBColor[
             0.9711999759725701, 0.9780415697528297, 0.9336351078158828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 449}], {
             RGBColor[
             0.9065243633182973, 0.9275960373218064, 0.966472324809002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 491}], {
             RGBColor[
             0.9769129995856359, 0.9812123080862567, 0.8751508880188533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 407}], {
             RGBColor[
             0.8518642025458676, 0.8831733488461602, 0.8920363693374749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 408}], {
             RGBColor[
             0.7392895440058458, 0.79287031726668, 0.8824287399378408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 434}], {
             RGBColor[
             0.9863393847042776, 0.9878107425090741, 0.8398599118940036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 469}], {
             RGBColor[
             0.9207003236799353, 0.9384804171038472, 0.953292378198431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 474}], {
             RGBColor[
             0.7580424838074358, 0.8094530083972369, 0.938276453929334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 491}], {
             RGBColor[
             0.9850400055756742, 0.9872734158468762, 0.8613939867403538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 413}], {
             RGBColor[
             0.9802680694062775, 0.9838322719034598, 0.8747450844642026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 476}], {
             RGBColor[
             0.9298937776018934, 0.944562392455714, 0.9010472935459408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 486}], {
             RGBColor[
             0.9857794107680526, 0.9879426212670785, 0.8654158211267584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 493}], {
             RGBColor[
             0.9887808904348048, 0.9896286241238967, 0.8355932098275236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 408}], {
             RGBColor[
             0.6009487289769955, 0.6858261288181913, 0.9624733716790499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 430}], {
             RGBColor[
             0.8291323400800827, 0.8672189437227679, 0.9752518791207306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{408, 430}], {
             RGBColor[
             0.7165576815400607, 0.7769159121432878, 0.9656442497210964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 456}], {
             RGBColor[
             0.8611771140631368, 0.8921432709966512, 0.9866210359928691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 458}], {
             RGBColor[
             0.8456998515352656, 0.8799077760300178, 0.9851167635388804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 496}], {
             RGBColor[
             0.8823683274151937, 0.9090405693034187, 0.9886422728400077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{411, 478}], {
             RGBColor[
             0.9023491327794106, 0.924669446315662, 0.9800333314780465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 476}], {
             RGBColor[
             0.9201176226728698, 0.9382436192012213, 0.961135880317177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 486}], {
             RGBColor[
             0.976003255839029, 0.9816238480125858, 0.9255044078979946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 493}], {
             RGBColor[
             0.9790047355057812, 0.9833098508694041, 0.8956817965987598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 415}], {
             RGBColor[
             0.9627087785408419, 0.9717088486113066, 0.9480084902088228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 485}], {
             RGBColor[
             0.8116460539166461, 0.8536055992155529, 0.9758919456362305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{415, 464}], {
             RGBColor[
             0.9693393203771661, 0.9766538958563213, 0.9367847124022013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{415, 485}], {
             RGBColor[
             0.8322724586450173, 0.8689887380893342, 0.9409768226590364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 427}], {
             RGBColor[
             0.5812397453020368, 0.6307874150639974, 0.6620529805793497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 429}], {
             RGBColor[
             0.5507772298725824, 0.6232680543091513, 0.9629916124106961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 499}], {
             RGBColor[
             0.5725206647632257, 0.6398213514801481, 0.9378723903500683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{417, 461}], {
             RGBColor[
             0.8798063833054135, 0.9067597439136734, 0.9779666145832373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 420}], {
             RGBColor[
             0.8613888673865362, 0.8923121173488391, 0.9866412332138893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 432}], {
             RGBColor[
             0.9375050503777753, 0.9515423694355065, 0.9413300604745495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 432}], {
             RGBColor[
             0.9091815965446891, 0.9289580161686768, 0.938628544163304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 439}], {
             RGBColor[
             0.8785005605026855, 0.9059565169551207, 0.9882733617790964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 423}], {
             RGBColor[
             0.9920809004906557, 0.9909932630883812, 0.7809035030498093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 477}], {
             RGBColor[
             0.9690417880317913, 0.974921502389388, 0.8696453347947836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 443}], {
             RGBColor[
             0.9044027077072228, 0.926563823090472, 0.9891364991045283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 446}], {
             RGBColor[
             0.9010428249589829, 0.9239311067391042, 0.9904234630866551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 446}], {
             RGBColor[
             0.9608275206658422, 0.9690681166196315, 0.8970499040526723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 477}], {
             RGBColor[
             0.9678387920447751, 0.9744240326331701, 0.8895820915534591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 440}], {
             RGBColor[
             0.7204047473915219, 0.780636228299026, 0.9736125931801745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 453}], {
             RGBColor[
             0.7705120679683728, 0.8167968272856669, 0.8089966336528116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 470}], {
             RGBColor[
             0.7685123975205731, 0.8165032496956848, 0.8809043561420624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{425, 466}], {
             RGBColor[
             0.8669402732547916, 0.89651987420952, 0.967128899163223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 448}], {
             RGBColor[
             0.9287819391244997, 0.9437497907719623, 0.9041523288652136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 489}], {
             RGBColor[
             0.9291450053672448, 0.9440392899387566, 0.9041869584475597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 460}], {
             RGBColor[
             0.8537109461898894, 0.8701961877485868, 0.6818585781248445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 499}], {
             RGBColor[
             0.9748334100652625, 0.9652147665441454, 0.666424370929418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 495}], {
             RGBColor[
             0.5721211212603565, 0.6600702189899395, 0.9611094187116604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{429, 499}], {
             RGBColor[
             0.944370894635808, 0.9576954057892992, 0.9673630027607643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 433}], {
             RGBColor[
             0.9178570371323195, 0.9372769757334205, 0.9899009587843663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 436}], {
             RGBColor[
             0.9175526174401522, 0.9370499400254436, 0.990416261917834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 459}], {
             RGBColor[
             0.9448045724765579, 0.9560818168491303, 0.8864011406701113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 462}], {
             RGBColor[
             0.9463854646158439, 0.9566079313098507, 0.8509246716886205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 487}], {
             RGBColor[
             0.9450992703373682, 0.9562036819879648, 0.881517234462871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{432, 467}], {
             RGBColor[
             0.9540290042859978, 0.9647181217511429, 0.9429061299494235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 462}], {
             RGBColor[
             0.9666056334305901, 0.9726696176777969, 0.8507270305713229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 469}], {
             RGBColor[
             0.9277127264216045, 0.9421884820994721, 0.8732740835550512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 474}], {
             RGBColor[
             0.7650548865491051, 0.8131610733928618, 0.8582581592859543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 495}], {
             RGBColor[
             0.6915656288000633, 0.7517739632458079, 0.852949499156882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 459}], {
             RGBColor[
             0.9647203215991369, 0.9719164675090997, 0.8867188026862813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 462}], {
             RGBColor[
             0.9663012137384228, 0.97244258196982, 0.8512423337047905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 487}], {
             RGBColor[
             0.9650150194599469, 0.9720383326479342, 0.881834896479041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 457}], {
             RGBColor[
             0.6476055228248301, 0.722273433949161, 0.9671245988536912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 460}], {
             RGBColor[
             0.7653968222744274, 0.8166530818828661, 0.9772512602704938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 453}], {
             RGBColor[
             0.9445564508175335, 0.9548340725384475, 0.8251785910707999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 470}], {
             RGBColor[
             0.9425567803697338, 0.9545404949484655, 0.8970863135600509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 467}], {
             RGBColor[
             0.9388183570058546, 0.9000276526175146, 0.6375228264912494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 444}], {
             RGBColor[
             0.9701626901538352, 0.9735313415209634, 0.7025878934682861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 492}], {
             RGBColor[
             0.8495358006295542, 0.8785750012661284, 0.7016247097221213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{443, 446}], {
             RGBColor[
             0.9341370195762848, 0.9502731562584678, 0.991972584314733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{444, 492}], {
             RGBColor[
             0.8271358498189532, 0.8656057767947888, 0.9723450522728747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{445, 460}], {
             RGBColor[
             0.8568526385599109, 0.8871382164324757, 0.8956107873788945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 453}], {
             RGBColor[
             0.9920226315958601, 0.9904358298735714, 0.7431011612436595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 463}], {
             RGBColor[
             0.9723071884845238, 0.9780051638996579, 0.893151459300688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{449, 488}], {
             RGBColor[
             0.9132068898667107, 0.9325798546799802, 0.9551605504445975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 454}], {
             RGBColor[
             0.9925582985128965, 0.9897158259763975, 0.6657855049575434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 469}], {
             RGBColor[
             0.9278230301115704, 0.9407592420471987, 0.7642397885582592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 471}], {
             RGBColor[
             0.9732839591717475, 0.9765625231595663, 0.7531117622987707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 475}], {
             RGBColor[
             0.8965020495625533, 0.9159508588977382, 0.761208283246855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 491}], {
             RGBColor[
             0.9921627120073093, 0.9895522407902277, 0.6723413971001821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 500}], {
             RGBColor[
             0.9930849975417264, 0.9899336295603662, 0.6570567389964401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{451, 456}], {
             RGBColor[
             0.913329319603275, 0.9315947015550985, 0.9099045470055357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{453, 463}], {
             RGBColor[
             0.9749483282830482, 0.9785640055511748, 0.8106129296004656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 469}], {
             RGBColor[
             0.9268089337985883, 0.941814740623444, 0.8882522662587627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 471}], {
             RGBColor[
             0.9722698628587654, 0.9776180217358115, 0.8771242399992742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 475}], {
             RGBColor[
             0.8954879532495711, 0.9170063574739834, 0.8852207609473585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 500}], {
             RGBColor[
             0.9920709012287442, 0.9909891281366114, 0.7810692166969435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{456, 458}], {
             RGBColor[
             0.8223895168480029, 0.8613207478925735, 0.982893403007028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{461, 486}], {
             RGBColor[
             0.8968897735881356, 0.9195005084150432, 0.9490488908963643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{461, 493}], {
             RGBColor[
             0.8998912532548877, 0.9211865112718615, 0.9192262795971295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{462, 487}], {
             RGBColor[
             0.9938478666356387, 0.9915963239323412, 0.7423433062498275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 485}], {
             RGBColor[
             0.8182765957529703, 0.8585506464605677, 0.964668167829609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 497}], {
             RGBColor[
             0.9476866660542538, 0.9605053817152607, 0.9734370082541919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 468}], {
             RGBColor[
             0.9031545995218399, 0.9250396437772013, 0.970677671653295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 471}], {
             RGBColor[
             0.9075345944574392, 0.9286614378066127, 0.9755785235999901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 474}], {
             RGBColor[
             0.6994158255247627, 0.7638307479876348, 0.9716906255903817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 475}], {
             RGBColor[
             0.8307526848482449, 0.8680497735447846, 0.9836750445480744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 491}], {
             RGBColor[
             0.9264133472930011, 0.9416511554372742, 0.8948081584014016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 495}], {
             RGBColor[
             0.6259265677757209, 0.702443637840581, 0.9663819654613095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 475}], {
             RGBColor[
             0.876213613908422, 0.9038530546571522, 0.9725470182885858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 500}], {
             RGBColor[
             0.9727965618875951, 0.9778358253197803, 0.868395474038171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{474, 495}], {
             RGBColor[
             0.4632687279032215, 0.5734162291339706, 0.9513660411922125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{476, 493}], {
             RGBColor[
             0.928630443701397, 0.9440399714216583, 0.921984005680498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{479, 482}], {
             RGBColor[
             0.8261173379450495, 0.8649608197952277, 0.9830718031293393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{480, 481}], {
             RGBColor[
             0.9693451415012869, 0.9750130797934449, 0.8631013469951263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{482, 496}], {
             RGBColor[
             0.8022817509610263, 0.8459549697339405, 0.9807983435645236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{484, 500}], {
             RGBColor[
             0.990748330875769, 0.9904422113071485, 0.8029876301480985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{485, 497}], {
             RGBColor[
             0.810619804322105, 0.8528402239482736, 0.977629118511027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{486, 493}], {
             RGBColor[
             0.9845160768675563, 0.9874202002330228, 0.8863525332613157]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.0315874366232787], {
             RGBColor[
             0.8651719452938604, 0.8953286409832253, 0.9870020665618834]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.0315874366232787], {
             RGBColor[
             0.7319844229578485, 0.7905510615931146, 0.9739210245632414]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.0315874366232787], {
             RGBColor[
             0.7469699892303052, 0.8022578998596798, 0.975414645761201]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.0315874366232787], {
             RGBColor[
             0.9948751846415869, 0.9914468630836963, 0.6835736588100984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.0315874366232787], {
             RGBColor[
             0.6299258488725569, 0.7104412078076663, 0.9640092167991144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.0315874366232787], {
             RGBColor[
             0.9654729282316739, 0.9737703469248493, 0.9433295057879449]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.0315874366232787], {
             RGBColor[
             0.8697433308684857, 0.8989737397534756, 0.9874380893989152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.0315874366232787], {
             RGBColor[
             0.7544627723665334, 0.8081113189929622, 0.9761614563601807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.0315874366232787], {
             RGBColor[
             0.8791600073517527, 0.906482341972359, 0.9883362604082556]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.0315874366232787], {
             RGBColor[
             0.9803567078423331, 0.9848706453885266, 0.9181351492185315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.0315874366232787], {
             RGBColor[
             0.8128686034633138, 0.8537383981465241, 0.9819828037703843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.0315874366232787], {
             RGBColor[
             0.9908131812038222, 0.9904690285843759, 0.8019128923849871]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.0315874366232787], {
             RGBColor[
             0.954677573248701, 0.9657191888543196, 0.961603225894606]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.0315874366232787], {
             RGBColor[
             0.9934572962702221, 0.9884141432278518, 0.5292452597797648]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.0315874366232787], {
             RGBColor[
             0.9916227343659356, 0.9834036573201008, 0.4219563342358762]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.0315874366232787], {
             RGBColor[
             0.8072119656455807, 0.8493193896912713, 0.9814190029769985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.0315874366232787], {
             RGBColor[
             0.7825607091273896, 0.8300616407427718, 0.978961996106355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.0315874366232787], {
             RGBColor[
             0.6795349410042503, 0.7495771276601367, 0.9686933503703827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.0315874366232787], {
             RGBColor[
             0.9686519411267903, 0.9761412495368713, 0.9379482661758664]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.0315874366232787], {
             RGBColor[
             0.8272942985914463, 0.8651260336640502, 0.9833892628056328]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.0315874366232787], {
             RGBColor[
             0.9311081181249247, 0.9479043554089838, 0.9932911175884267]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.0315874366232787], {
             RGBColor[
             0.9935499046024456, 0.9886122230863393, 0.5393251052299204]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.0315874366232787], {
             RGBColor[
             0.9530304042262798, 0.9644907328943897, 0.9643914533990801]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.0315874366232787], {
             RGBColor[
             0.9717096870432149, 0.9784217114347413, 0.9327722999272196]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.0315874366232787], {
             RGBColor[
             0.9650933446024063, 0.9734872540756527, 0.9439720418610288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.0315874366232787], {
             RGBColor[
             0.9925602932245503, 0.9864955444140795, 0.4316120139195006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.0315874366232787], {
             RGBColor[
             0.9254390447289824, 0.9433839901659573, 0.9927503963070802]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.0315874366232787], {
             RGBColor[
             0.9870684252922802, 0.9889204757791161, 0.8639731889568802]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.0315874366232787], {
             RGBColor[
             0.9752545975785547, 0.9810654999077395, 0.9267716910516313]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.0315874366232787], {
             RGBColor[
             0.9930033643615552, 0.9874432287747693, 0.47983757286438267`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.0315874366232787], {
             RGBColor[
             0.984485226989237, 0.9878522568956394, 0.9067834699412197]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.0315874366232787], {
             RGBColor[
             0.9949321191048256, 0.9915686401436067, 0.6897706237748528]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.0315874366232787], {
             RGBColor[
             0.7840610893092117, 0.8312337491441228, 0.9791115399810291]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.0315874366232787], {
             RGBColor[
             0.8547957153876611, 0.8870549169112795, 0.9860123724904603]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.0315874366232787], {
             RGBColor[
             0.9604929680809325, 0.9700563007983628, 0.9517592793415248]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.0315874366232787], {
             RGBColor[
             0.6449814452189991, 0.722583674136404, 0.9652493808312859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.0315874366232787], {
             RGBColor[
             0.9487328253846911, 0.9612856056309722, 0.9716661333898139]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.0315874366232787], {
             RGBColor[
             0.9444984518804947, 0.9581276168046929, 0.9788338232309344]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.0315874366232787], {
             RGBColor[
             0.9876001825927941, 0.9891403710884179, 0.8551605943435846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.0315874366232787], {
             RGBColor[
             0.7014559759647863, 0.7667020067773437, 0.9708782342715303]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.0315874366232787], {
             RGBColor[
             0.9547517461863462, 0.9657745069097684, 0.9614776704585731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.0315874366232787], {
             RGBColor[
             0.827196711646282, 0.8650482204829032, 0.9833799548756861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.0315874366232787], {
             RGBColor[
             0.9804223547507619, 0.9849196047453458, 0.9180240261260173]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.0315874366232787], {
             RGBColor[
             0.7244916398216205, 0.7846976424598322, 0.9731742139642616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.0315874366232787], {
             RGBColor[
             0.36155641445050807`, 0.48758372666842176`, 0.9442590329103705]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.0315874366232787], {
             RGBColor[
             0.9815876674998223, 0.9857886930855706, 0.9160514556040991]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.0315874366232787], {
             RGBColor[
             0.9402130328969017, 0.9549315583434589, 0.9860879197538803]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.0315874366232787], {
             RGBColor[
             0.955383689504028, 0.9662458092013833, 0.9604079552589518]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.0315874366232787], {
             RGBColor[
             0.8769548236747068, 0.9047239883663989, 0.9881259280205482]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.0315874366232787], {
             RGBColor[
             0.7496673911593476, 0.8043651307476616, 0.9756834975768337]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.0315874366232787], {
             RGBColor[
             0.6459928462570554, 0.7233737883142661, 0.9653501878346793]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.0315874366232787], {
             RGBColor[
             0.441925975419167, 0.5571958008878863, 0.9493801102672811]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.0315874366232787], {
             RGBColor[
             0.9924920604098726, 0.9911632882813053, 0.7740895191406236]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.0315874366232787], {
             RGBColor[
             0.7712466065916848, 0.8212229778515151, 0.9778343121018955]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.0315874366232787], {
             RGBColor[
             0.969041747361065, 0.9072326858847877, 0.3342334637835394]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.0315874366232787], {
             RGBColor[
             0.9344004786602012, 0.9505295943310672, 0.9936051458754063]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.0315874366232787], {
             RGBColor[
             0.7033976814587534, 0.768218881866739, 0.9710717653288995]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.0315874366232787], {
             RGBColor[
             0.985809662186728, 0.988399944886234, 0.8848341511903742]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.0315874366232787], {
             RGBColor[
             0.9945995983812594, 0.9908574119389011, 0.6535777950947123]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.0315874366232787], {
             RGBColor[
             0.6849297448623349, 0.7537915894361003, 0.9692310540016482]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.0315874366232787], {
             RGBColor[
             0.97769601215333, 0.9828863029001574, 0.922639012999438]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.0315874366232787], {
             RGBColor[
             0.8516406439929692, 0.8845391486232838, 0.9857114389642692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.0315874366232787], {
             RGBColor[
             0.3163926416525105, 0.44846513666802024`, 0.9413812372444382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.0315874366232787], {
             RGBColor[
             0.6859573265495887, 0.7545943440600931, 0.9693334737409369]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.0315874366232787], {
             RGBColor[
             0.9538691599730251, 0.9651162755569759, 0.9629716587023747]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.0315874366232787], {
             RGBColor[
             0.9898878553089081, 0.9900863825470382, 0.8172479371303668]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.0315874366232787], {
             RGBColor[
             0.9688155881506327, 0.9762632972193056, 0.9376712544504806]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.0315874366232787], {
             RGBColor[
             0.9945218889707366, 0.9906911993674193, 0.645119605326194]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.0315874366232787], {
             RGBColor[
             0.3654372330530195, 0.4909450966863027, 0.9445063152400494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.0315874366232787], {
             RGBColor[
             0.8966185630985665, 0.9204033204249971, 0.9900014730408234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.0315874366232787], {
             RGBColor[
             0.8071258283376768, 0.849252098571669, 0.9814104176151456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.0315874366232787], {
             RGBColor[
             0.9752288084992027, 0.9810462664545846, 0.926815345236105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.0315874366232787], {
             RGBColor[
             0.7679191992234334, 0.8186235819262044, 0.977502667231818]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.0315874366232787], {
             RGBColor[
             0.7287732301851793, 0.7880424533931364, 0.9736009628779643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.0315874366232787], {
             RGBColor[
             0.8382948846961178, 0.87389760242096, 0.9844385085286355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.0315874366232787], {
             RGBColor[
             0.6590815764449669, 0.7335988038150965, 0.9666547501386724]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.0315874366232787], {
             RGBColor[
             0.5882092053751306, 0.6765737573030827, 0.9607251298098968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.0315874366232787], {
             RGBColor[
             0.7245985523039445, 0.7847811633035887, 0.9731848700013457]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.0315874366232787], {
             RGBColor[
             0.9766449846670698, 0.9821024483218042, 0.9244181283818057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.0315874366232787], {
             RGBColor[
             0.6486766629360077, 0.725470406301626, 0.9656176855995444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.0315874366232787], {
             RGBColor[
             0.45534737369188255`, 0.5687105369853133, 0.9502657597308658]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.0315874366232787], {
             RGBColor[
             0.7065089602946721, 0.7706494365399538, 0.97138186852671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.0315874366232787], {
             RGBColor[
             0.989846916208752, 0.9900694531770367, 0.8179264039669489]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.0315874366232787], {
             RGBColor[
             0.6520153436912978, 0.728078609082572, 0.9659504540954862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.0315874366232787], {
             RGBColor[
             0.9952108206695621, 0.9921647546095276, 0.7201055691497422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.0315874366232787], {
             RGBColor[
             0.8004572527817191, 0.8440425566643034, 0.9807457563251094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.0315874366232787], {
             RGBColor[
             0.9779537473621527, 0.9372949545255669, 0.3688549008977814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.0315874366232787], {
             RGBColor[
             0.9420823738124707, 0.9563257097375254, 0.9829236131860171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.0315874366232787], {
             RGBColor[
             0.9700520323307753, 0.9771854352643644, 0.9355782769697889]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.0315874366232787], {
             RGBColor[
             0.8971534094264104, 0.920829792368803, 0.9900524871610361]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.0315874366232787], {
             RGBColor[
             0.9942851019158863, 0.9901847357999382, 0.6193467956860482]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.0315874366232787], {
             RGBColor[
             0.9936758826571025, 0.9916528292033789, 0.7544705208702553]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.0315874366232787], {
             RGBColor[
             0.8695006523750178, 0.8987802345101166, 0.9874149425075666]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.0315874366232787], {
             RGBColor[
             0.9910017415791091, 0.9905470031453376, 0.798787958987875]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.0315874366232787], {
             RGBColor[
             0.9820494661742304, 0.9511107757992143, 0.38476599507110504`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.0315874366232787], {
             RGBColor[
             0.6380161197412002, 0.7170092541613803, 0.9646461125575326]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.0315874366232787], {
             RGBColor[
             0.9130497705428943, 0.9335051192278595, 0.9915686962751754]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.0315874366232787], {
             RGBColor[
             0.9478625820657655, 0.9606365795886103, 0.9731392283329464]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.0315874366232787], {
             RGBColor[
             0.7466586547509605, 0.8020146829981859, 0.975383614849886]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.0315874366232787], {
             RGBColor[
             0.8611324106725154, 0.892107625726411, 0.9866167721435644]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.0315874366232787], {
             RGBColor[
             0.9942348541077048, 0.9900772608190707, 0.6138776318590218]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.0315874366232787], {
             RGBColor[
             0.5741711725063424, 0.6651770498140265, 0.9596200044394569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.0315874366232787], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.0315874366232787], {
             RGBColor[
             0.9678512993182518, 0.9032170251058861, 0.32960879793445963`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.0315874366232787], {
             RGBColor[
             0.9205807487103161, 0.9395101167956051, 0.9922870076957677]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.0315874366232787], {
             RGBColor[
             0.9525332499105367, 0.9641199560197239, 0.965233005977021]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.0315874366232787], {
             RGBColor[
             0.9929214014526985, 0.987267918400446, 0.4709164160517648]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.0315874366232787], {
             RGBColor[
             0.9151943319441972, 0.9352151342766901, 0.9917732464561042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.0315874366232787], {
             RGBColor[
             0.9925602932245503, 0.9864955444140795, 0.4316120139195006]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.0315874366232787], {
             RGBColor[
             0.9898392909116508, 0.9773876837763614, 0.41502799319101624`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.0315874366232787], {
             RGBColor[
             0.9910206388404212, 0.9905548176485277, 0.7984747824633884]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.0315874366232787], {
             RGBColor[
             0.8419493065747642, 0.8768115392303534, 0.9847870705497617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.0315874366232787], {
             RGBColor[
             0.8901676786270138, 0.9152595602519752, 0.9893861819211541]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.0315874366232787], {
             RGBColor[
             0.8744401461960676, 0.9027188528040337, 0.9878860758377566]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.0315874366232787], {
             RGBColor[
             0.6799085423794639, 0.7498689878939292, 0.9687305874639607]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.0315874366232787], {
             RGBColor[
             0.986850633187647, 0.9888304131468485, 0.8675825677585534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.0315874366232787], {
             RGBColor[
             0.7877640307497704, 0.8341265151408847, 0.9794806145778687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.0315874366232787], {
             RGBColor[
             0.7965709751155855, 0.8410065670147157, 0.9803584084866789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.0315874366232787], {
             RGBColor[
             0.9650324305321565, 0.8937083187885205, 0.3186580249991828]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.0315874366232787], {
             RGBColor[
             0.9576671756633754, 0.9679488294401591, 0.9565426088197504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.0315874366232787], {
             RGBColor[
             0.8745257672601163, 0.9027871247163843, 0.9878942424512803]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.0315874366232787], {
             RGBColor[
             0.7397769174195259, 0.7966386174917284, 0.9746977075861804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.0315874366232787], {
             RGBColor[
             0.9552086770320903, 0.9661152851863688, 0.9607042057233792]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.0315874366232787], {
             RGBColor[
             0.8087867801840355, 0.8505496467777459, 0.9815759657727131]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.0315874366232787], {
             RGBColor[
             0.9646698635466248, 0.9731714225976374, 0.9446888848269184]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.0315874366232787], {
             RGBColor[
             0.9939231593786376, 0.9894105773107671, 0.5799515841569468]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.0315874366232787], {
             RGBColor[
             0.9488038949493312, 0.9613386091959151, 0.9715458311547893]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.0315874366232787], {
             RGBColor[
             0.9929344266739577, 0.9872957780316677, 0.47233413100348665`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.0315874366232787], {
             RGBColor[
             0.9402130328969017, 0.9549315583434589, 0.9860879197538803]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.0315874366232787], {
             RGBColor[
             0.9756408169345582, 0.9294928970914004, 0.3598696029468381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.0315874366232787], {
             RGBColor[
             0.9933856203383783, 0.9882608356571863, 0.5214437769311456]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.0315874366232787], {
             RGBColor[
             0.9768739011663746, 0.9336523797472633, 0.36465990233902684`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.0315874366232787], {
             RGBColor[
             0.8558420801983407, 0.8878892598084993, 0.9861121757002038]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.0315874366232787], {
             RGBColor[
             0.8536338266901494, 0.8861284584025122, 0.9859015505092613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.0315874366232787], {
             RGBColor[
             0.9860662379129401, 0.9885060455427181, 0.8805820274103453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.0315874366232787], {
             RGBColor[
             0.8723805390034342, 0.9010765779351757, 0.9876896286650901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.0315874366232787], {
             RGBColor[
             0.9664302750684125, 0.9744843346281775, 0.9417089673093907]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.0315874366232787], {
             RGBColor[
             0.9813976229761088, 0.9856469581909545, 0.916373151411196]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.0315874366232787], {
             RGBColor[
             0.9943932392339199, 0.9904160305888519, 0.6311168754078307]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.0315874366232787], {
             RGBColor[
             0.9705894567504478, 0.9775862455166044, 0.9346685576100207]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.0315874366232787], {
             RGBColor[
             0.9952659412793645, 0.9922826520203465, 0.7261051073617646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.0315874366232787], {
             RGBColor[
             0.9939983828853636, 0.9895714727853908, 0.5881391986383996]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.0315874366232787], {
             RGBColor[
             0.9599326654018971, 0.9696384279777497, 0.9527077256267887]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.0315874366232787], {
             RGBColor[
             0.8433401549624661, 0.877920563981133, 0.9849197309106057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.0315874366232787], {
             RGBColor[
             0.948198768055973, 0.9608873065496529, 0.9725701531428741]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.0315874366232787], {
             RGBColor[
             0.9937184813122848, 0.9889727916229654, 0.5576736397610498]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.0315874366232787], {
             RGBColor[
             0.9402319079861569, 0.9549456353541202, 0.986055969151183]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.0315874366232787], {
             RGBColor[
             0.9942971515604123, 0.9919097398607801, 0.7441744873500284]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.0315874366232787], {
             RGBColor[
             0.9325214751031845, 0.7701771652092314, 0.26456339882471325`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.0315874366232787], {
             RGBColor[
             0.5958013100427445, 0.6827373698926692, 0.961322808100127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.0315874366232787], {
             RGBColor[
             0.7591082979109951, 0.8117404388555975, 0.9766244789315482]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.0315874366232787], {
             RGBColor[
             0.7855131977731751, 0.8323681473126042, 0.9792562725819918]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.0315874366232787], {
             RGBColor[
             0.9948132585031432, 0.9913144093352584, 0.6768333808043326]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.0315874366232787], {
             RGBColor[
             0.9906679726063273, 0.9904089810976211, 0.8043193746332815]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.0315874366232787], {
             RGBColor[
             0.9346061936516449, 0.9506936258812598, 0.9936247671549341]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.0315874366232787], {
             RGBColor[
             0.9934058105077948, 0.9883040203880288, 0.5236413522728396]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.0315874366232787], {
             RGBColor[
             0.8378667793758742, 0.8735562428592071, 0.9843976754610165]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.0315874366232787], {
             RGBColor[
             0.9948735699447365, 0.9914434094104044, 0.6833979090226949]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.0315874366232787], {
             RGBColor[
             0.9214461736654562, 0.9402001831634993, 0.9923695527005629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.0315874366232787], {
             RGBColor[
             0.9416652110011032, 0.9560145903958489, 0.9836297610121757]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.0315874366232787], {
             RGBColor[
             0.9905632906838447, 0.9798299050112025, 0.4178405955901052]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.0315874366232787], {
             RGBColor[
             0.9625233097659216, 0.9715705263026483, 0.9483224404667593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.0315874366232787], {
             RGBColor[
             0.3520062125901088, 0.4793118218240462, 0.9436505024927377]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.0315874366232787], {
             RGBColor[
             0.9578680960915468, 0.9680986755665124, 0.9562025029432967]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.0315874366232787], {
             RGBColor[
             0.8498629789535114, 0.8831216867742521, 0.9855418836858653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.0315874366232787], {
             RGBColor[
             0.988163542248631, 0.9893733347837892, 0.8458242669183142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.0315874366232787], {
             RGBColor[
             0.9858151537180575, 0.9884022157755646, 0.8847431423046167]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.0315874366232787], {
             RGBColor[
             0.4966655644272871, 0.6022545055875953, 0.9535184790590765]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.0315874366232787], {
             RGBColor[
             0.8193344470552547, 0.8587895643027798, 0.9826272586328851]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.0315874366232787], {
             RGBColor[
             0.6737242112251345, 0.7450377413935094, 0.9681141911303577]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.0315874366232787], {
             RGBColor[
             0.6199384357302871, 0.7023329758909369, 0.9632229710514552]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.0315874366232787], {
             RGBColor[
             0.7518849022064912, 0.8060974672313983, 0.975904518354194]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.0315874366232787], {
             RGBColor[
             0.7466586547509605, 0.8020146829981859, 0.975383614849886]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.0315874366232787], {
             RGBColor[
             0.9630729699825319, 0.9719804619922102, 0.9473920090943823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.0315874366232787], {
             RGBColor[
             0.9677585960449483, 0.9754749942375519, 0.9394604663777116]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.0315874366232787], {
             RGBColor[
             0.9596600549547926, 0.9694351155526577, 0.953169184005545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.0315874366232787], {
             RGBColor[
             0.7544627723665334, 0.8081113189929622, 0.9761614563601807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.0315874366232787], {
             RGBColor[
             0.8927724771455312, 0.9173365558852689, 0.9896346299291814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.0315874366232787], {
             RGBColor[
             0.9729702187151218, 0.9793618138917183, 0.9306385486059949]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.0315874366232787], {
             RGBColor[
             0.9917167894060963, 0.9908426937976879, 0.7869377660102386]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.0315874366232787], {
             RGBColor[
             0.9418457839609342, 0.9561492614136298, 0.9833240980921525]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.0315874366232787], {
             RGBColor[
             0.9651477239886952, 0.9735278101329089, 0.9438799917444571]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.0315874366232787], {
             RGBColor[
             0.8353431783227906, 0.871543991880804, 0.9841569721397281]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.0315874366232787], {
             RGBColor[
             0.9583073189036626, 0.968426247220627, 0.9554590132900407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.0315874366232787], {
             RGBColor[
             0.661959276857542, 0.7358468852487333, 0.9669415724221586]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.0315874366232787], {
             RGBColor[
             0.9740873392720573, 0.9801949605739637, 0.9287475548948076]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.0315874366232787], {
             RGBColor[
             0.9650780585811742, 0.8938622329118328, 0.3188352813534827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.0315874366232787], {
             RGBColor[
             0.7544627723665334, 0.8081113189929622, 0.9761614563601807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.0315874366232787], {
             RGBColor[
             0.988163542248631, 0.9893733347837892, 0.8458242669183142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.0315874366232787], {
             RGBColor[
             0.8740759996133818, 0.9024284922034957, 0.9878513432116225]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.0315874366232787], {
             RGBColor[
             0.8350934472489794, 0.8713448631013163, 0.9841331525669704]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.0315874366232787], {
             RGBColor[
             0.8983839944293445, 0.9218110274468025, 0.9901698614571721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.0315874366232787], {
             RGBColor[
             0.9866066975064739, 0.9887295394738224, 0.8716252132808979]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.0315874366232787], {
             RGBColor[
             0.9854686314820985, 0.9882589199257804, 0.8904859125252576]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.0315874366232787], {
             RGBColor[
             0.9739038275662804, 0.9236336240877008, 0.3531217272539973]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.0315874366232787], {
             RGBColor[
             0.9939223764154301, 0.9894089026316362, 0.5798663634437078]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.0315874366232787], {
             RGBColor[
             0.48837407043697356`, 0.5955230972387112, 0.9528657422794158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.0315874366232787], {
             RGBColor[
             0.9629320418969844, 0.9718753580567575, 0.9476305635832827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.0315874366232787], {
             RGBColor[
             0.8880736540869013, 0.9135898419244713, 0.9891864519911604]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.0315874366232787], {
             RGBColor[
             0.9811588535791816, 0.9854688843656753, 0.9167773257191613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.0315874366232787], {
             RGBColor[
             0.86576896973332, 0.8958046920654535, 0.987059011285889]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.0315874366232787], {
             RGBColor[
             0.8679471942205499, 0.8975415491452421, 0.987266772282005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.0315874366232787], {
             RGBColor[
             0.9390969386517186, 0.9540991770828379, 0.9879771761869759]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.0315874366232787], {
             RGBColor[
             0.8421116754884682, 0.8769410077947541, 0.9848025574416992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.0315874366232787], {
             RGBColor[
             0.6728453842202256, 0.7443511950579419, 0.9680265978676136]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.0315874366232787], {
             RGBColor[
             0.6497636160096362, 0.7263195423038938, 0.9657260229237697]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.0315874366232787], {
             RGBColor[
             0.9654836973111163, 0.8952305475964303, 0.32041111122086086`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.0315874366232787], {
             RGBColor[
             0.956078169385774, 0.966763751160083, 0.9592323819685182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.0315874366232787], {
             RGBColor[
             0.9648618760545998, 0.9733146252116937, 0.9443638577357992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.0315874366232787], {
             RGBColor[
             0.833765985403809, 0.8702863810589694, 0.9840065380711389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.0315874366232787], {
             RGBColor[
             0.6539432468021187, 0.7295847016453517, 0.9661426094602938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.0315874366232787], {
             RGBColor[
             0.9874561510989801, 0.9890808103642852, 0.8575475689376404]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.0315874366232787], {
             RGBColor[
             0.7424743193485682, 0.7987458483797102, 0.9749665594018131]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.0315874366232787], {
             RGBColor[
             0.9885415580460107, 0.9895296540305686, 0.8395595668822073]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.0315874366232787], {
             RGBColor[
             0.7320353942717003, 0.7905908807708919, 0.9739261049074521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.0315874366232787], {
             RGBColor[
             0.9877679243412415, 0.9892097366121672, 0.8523806794700828]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.0315874366232787], {
             RGBColor[
             0.7919500786297862, 0.8373966875598952, 0.9798978407097072]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.0315874366232787], {
             RGBColor[
             0.9899402662901301, 0.9901080558346742, 0.8163793515362474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.0315874366232787], {
             RGBColor[
             0.9725244515783884, 0.9790293614910193, 0.9313931160937952]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.0315874366232787], {
             RGBColor[
             0.9870006520090628, 0.9888924497848118, 0.8650963676514272]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.0315874366232787], {
             RGBColor[
             0.8330270624518451, 0.8696971839546026, 0.9839360589403363]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.0315874366232787], {
             RGBColor[
             0.9945194907736236, 0.9906860698662895, 0.6448585763703963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.0315874366232787], {
             RGBColor[
             0.9949055299743514, 0.9921613199695559, 0.7340920825981923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.0315874366232787], {
             RGBColor[
             0.9948783744916911, 0.9914536858505262, 0.6839208543084788]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.0315874366232787], {
             RGBColor[
             0.9927073273268159, 0.9868100354913973, 0.44761576856180885`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.0315874366232787], {
             RGBColor[
             0.989635504097029, 0.9899820288357958, 0.8214300497752052]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.0315874366232787], {
             RGBColor[
             0.9587117759846884, 0.9687278906494183, 0.9547743729511653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.0315874366232787], {
             RGBColor[
             0.9703373587703671, 0.9116030873923893, 0.3392666694529933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.0315874366232787], {
             RGBColor[
             0.9938602449391691, 0.9892760096863696, 0.573103735683717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.0315874366232787], {
             RGBColor[
             0.7544627723665334, 0.8081113189929622, 0.9761614563601807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.0315874366232787], {
             RGBColor[
             0.97769601215333, 0.9828863029001574, 0.922639012999438]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.0315874366232787], {
             RGBColor[
             0.8088048950431237, 0.8505637982433437, 0.9815777712925741]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.0315874366232787], {
             RGBColor[
             0.6542467979194797, 0.7298218380853081, 0.966172864598826]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.0315874366232787], {
             RGBColor[
             0.8090548187541277, 0.8507590405458705, 0.981602681352417]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.0315874366232787], {
             RGBColor[
             0.855885897253905, 0.8879241983392239, 0.9861163550100794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.0315874366232787], {
             RGBColor[
             0.9936247634006983, 0.9887723384864161, 0.5474730234447647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.0315874366232787], {
             RGBColor[
             0.3832697667572377, 0.5063907410916917, 0.9456425885189917]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.0315874366232787], {
             RGBColor[
             0.9940944543806192, 0.9918259193678557, 0.747533704182688]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.0315874366232787], {
             RGBColor[
             0.9600249802927022, 0.8768170133256127, 0.29920502639653446`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.0315874366232787], {
             RGBColor[
             0.8995724628778611, 0.922758679927533, 0.9902832186387499]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.0315874366232787], {
             RGBColor[
             0.9910017415791091, 0.9905470031453376, 0.798787958987875]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.0315874366232787], {
             RGBColor[
             0.994809607835593, 0.9913066009265077, 0.676436028170804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.0315874366232787], {
             RGBColor[
             0.6340781710752995, 0.7138122500318363, 0.9643361028133717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.0315874366232787], {
             RGBColor[
             0.8851031863992265, 0.9112212716215169, 0.9889031261313422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.0315874366232787], {
             RGBColor[
             0.6434767557299411, 0.7214081992714881, 0.9650994074451393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.0315874366232787], {
             RGBColor[
             0.9719335281305076, 0.9169873414425315, 0.34546748600584776`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.0315874366232787], {
             RGBColor[
             0.7285361871200685, 0.7878572735490779, 0.9735773366405275]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.0315874366232787], {
             RGBColor[
             0.6145491603444041, 0.6979577193485877, 0.9627987075515122]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.0315874366232787], {
             RGBColor[
             0.9942114689592696, 0.9900272423511689, 0.611332302768257]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.0315874366232787], {
             RGBColor[
             0.46789673737428994`, 0.5788986757650828, 0.9512536916097788]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.0315874366232787], {
             RGBColor[
             0.620897433805136, 0.7031115337304703, 0.9632984668928329]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.0315874366232787], {
             RGBColor[
             0.9088906211585487, 0.9301887264058849, 0.9911719928939801]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.0315874366232787], {
             RGBColor[
             0.93610608547751, 0.9518686036825857, 0.9930399104714723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.0315874366232787], {
             RGBColor[
             0.9896193328856223, 0.976645713705967, 0.41417349779548346`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.0315874366232787], {
             RGBColor[
             0.86883423868994, 0.8982488543269532, 0.9873513793753694]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.0315874366232787], {
             RGBColor[
             0.9896859557002902, 0.9900028918702913, 0.8205939361446041]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.0315874366232787], {
             RGBColor[
             0.9752730764585514, 0.9282524221162599, 0.3584410006395139]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.0315874366232787], {
             RGBColor[
             0.5378197927389929, 0.6356653621078958, 0.9567582906646795]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.0315874366232787], {
             RGBColor[
             0.985809662186728, 0.988399944886234, 0.8848341511903742]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.0315874366232787], {
             RGBColor[
             0.8406791091421951, 0.8757987182762136, 0.9846659179847246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.0315874366232787], {
             RGBColor[
             0.9926052256706449, 0.9865916503729087, 0.436502633385988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.0315874366232787], {
             RGBColor[
             0.9559295742819792, 0.8629824781665075, 0.28339810488267797`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.0315874366232787], {
             RGBColor[
             0.9949234091340327, 0.9915500103967939, 0.6888225972057569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.0315874366232787], {
             RGBColor[
             0.9825368570323435, 0.9864965970847698, 0.9144447253138195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.0315874366232787], {
             RGBColor[
             0.9951056391425188, 0.9922440702531642, 0.7307757558157316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.0315874366232787], {
             RGBColor[
             0.723869401775705, 0.7842115453691788, 0.9731121950909899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.0315874366232787], {
             RGBColor[
             0.290508767512353, 0.42267351234815814`, 0.9398554165893962]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.0315874366232787], {
             RGBColor[
             0.7065089602946721, 0.7706494365399538, 0.97138186852671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.0315874366232787], {
             RGBColor[
             0.8760957282629848, 0.9040389690046154, 0.9880439867332547]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.0315874366232787], {
             RGBColor[
             0.9827191218557105, 0.9533696816554781, 0.387367480939791]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.0315874366232787], {
             RGBColor[
             0.9031717907550738, 0.92562868627567, 0.9906265257448365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.0315874366232787], {
             RGBColor[
             0.9949038607430347, 0.9915081983650949, 0.6866948754843184]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.0315874366232787], {
             RGBColor[
             0.9944029166392258, 0.9904367295802655, 0.6321702012533567]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.0315874366232787], {
             RGBColor[
             0.9859812004872762, 0.9884708803818439, 0.881991317623399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.0315874366232787], {
             RGBColor[
             0.974215486621577, 0.9802905326574135, 0.9285306348582523]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.0315874366232787], {
             RGBColor[
             0.9844256168626979, 0.9878276065764051, 0.9077713640040348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.0315874366232787], {
             RGBColor[
             0.8406791091421951, 0.8757987182762136, 0.9846659179847246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.0315874366232787], {
             RGBColor[
             0.766126875979226, 0.8172234053856684, 0.9773240252010483]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.0315874366232787], {
             RGBColor[
             0.970614746543619, 0.9776051066029432, 0.9346257485868165]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.0315874366232787], {
             RGBColor[
             0.9941707410143129, 0.9899401293951334, 0.6068993173034606]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.0315874366232787], {
             RGBColor[
             0.9848671136857836, 0.988010176858702, 0.9004546190883516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.0315874366232787], {
             RGBColor[
             0.9889006858384197, 0.989678162601893, 0.8336078899690557]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.0315874366232787], {
             RGBColor[
             0.9901312767504934, 0.9901870435687793, 0.8132138138888023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.0315874366232787], {
             RGBColor[
             0.6082154271343841, 0.6928157093972641, 0.9623000928719901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.0315874366232787], {
             RGBColor[
             0.9571017988935335, 0.9675271723709306, 0.9574996442172149]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.0315874366232787], {
             RGBColor[
             0.7273014334977059, 0.786892674634813, 0.973454267938879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.0315874366232787], {
             RGBColor[
             0.5882092053751306, 0.6765737573030827, 0.9607251298098968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.0315874366232787], {
             RGBColor[
             0.9936685429022991, 0.9916497940261446, 0.7545921596020237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.0315874366232787], {
             RGBColor[
             0.8985727882169484, 0.921961566488367, 0.990187868777172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.0315874366232787], {
             RGBColor[
             0.7204555056930733, 0.7815445838028556, 0.972771929834146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.0315874366232787], {
             RGBColor[
             0.9226274597451648, 0.9411421086183025, 0.992482224821392]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.0315874366232787], {
             RGBColor[
             0.8857164018693365, 0.9117102329920921, 0.9889616151703052]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.0315874366232787], {
             RGBColor[
             0.6737242112251345, 0.7450377413935094, 0.9681141911303577]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.0315874366232787], {
             RGBColor[
             0.771246606591685, 0.8212229778515152, 0.9778343121018955]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.0315874366232787], {
             RGBColor[
             0.8905306390579304, 0.9155489750472896, 0.9894208014110736]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.0315874366232787], {
             RGBColor[
             0.6599206935374865, 0.7342543284652988, 0.9667383854884597]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.0315874366232787], {
             RGBColor[
             0.5498690768036788, 0.645447513725669, 0.9577068544442335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.0315874366232787], {
             RGBColor[
             0.924821190251057, 0.9428913297764727, 0.9926914647954104]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.0315874366232787], {
             RGBColor[
             0.9898233134893127, 0.9900596928459863, 0.8183175621099382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.0315874366232787], {
             RGBColor[
             0.8602805627290112, 0.8914283852990572, 0.9865355221262593]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.0315874366232787], {
             RGBColor[
             0.90421157810116, 0.9264577844811636, 0.9907257015901353]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.0315874366232787], {
             RGBColor[
             0.6837496315183789, 0.7528696759226082, 0.9691134313323089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.0315874366232787], {
             RGBColor[
             0.9931167797715873, 0.987685812868771, 0.49218214032759877`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.0315874366232787], {
             RGBColor[
             0.9559576077058712, 0.9666738364566132, 0.9594364614450714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.0315874366232787], {
             RGBColor[
             0.7976046102166509, 0.8418140506115857, 0.9804614315736838]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.0315874366232787], {
             RGBColor[
             0.8414529847123758, 0.8764157856495829, 0.9847397309274554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.0315874366232787], {
             RGBColor[
             0.9888845617334545, 0.9896714948701193, 0.8338751081161766]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.0315874366232787], {
             RGBColor[
             0.972827260372161, 0.979255195793611, 0.9308805397911201]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.0315874366232787], {
             RGBColor[
             0.9727213230645031, 0.9791761879230161, 0.93105986402011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.0315874366232787], {
             RGBColor[
             0.9885946554983452, 0.9895516111916512, 0.8386796046852223]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.0315874366232787], {
             RGBColor[
             0.9481291321271571, 0.9608353721879604, 0.9726880286064005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.0315874366232787], {
             RGBColor[
             0.90421157810116, 0.9264577844811636, 0.9907257015901353]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.0315874366232787], {
             RGBColor[
             0.8339010588491835, 0.8703940849578401, 0.9840194214969402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.0315874366232787], {
             RGBColor[
             0.9562573385524452, 0.9668973752312239, 0.9589290953041465]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.0315874366232787], {
             RGBColor[
             0.9528817374427321, 0.9643798574506393, 0.9646431074851193]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.0315874366232787], {
             RGBColor[
             0.9390969386517184, 0.9540991770828378, 0.9879771761869761]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.0315874366232787], {
             RGBColor[
             0.9377495019604223, 0.9530942610046942, 0.9902580350375678]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.0315874366232787], {
             RGBColor[
             0.9811248261160308, 0.9479917477670972, 0.3811739430486232]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.0315874366232787], {
             RGBColor[
             0.8261040258721478, 0.8641769425067738, 0.9832757335310971]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.0315874366232787], {
             RGBColor[
             0.9893147997043077, 0.9898494093276786, 0.8267449515189618]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.0315874366232787], {
             RGBColor[
             0.9471335517827149, 0.9600928699971887, 0.974373286440601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.0315874366232787], {
             RGBColor[
             0.9797627014021952, 0.9433969812652375, 0.3758823457510403]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.0315874366232787], {
             RGBColor[
             0.7920777116260727, 0.8374963954266408, 0.9799105619739789]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.0315874366232787], {
             RGBColor[
             0.9679724959487042, 0.9036258497987241, 0.33007962395770396`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.0315874366232787], {
             RGBColor[
             0.9888970265152297, 0.9896766493777136, 0.8336685344243395]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.0315874366232787], {
             RGBColor[
             0.7287732301851793, 0.7880424533931364, 0.9736009628779643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.0315874366232787], {
             RGBColor[
             0.9555929086241652, 0.9664018444786168, 0.9600538018616454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.0315874366232787], {
             RGBColor[
             0.9404573171099068, 0.9551137451095393, 0.9856744103007896]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.0315874366232787], {
             RGBColor[
             0.8771250942003604, 0.9048597574616848, 0.9881421685752874]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.0315874366232787], {
             RGBColor[
             0.984485226989237, 0.9878522568956394, 0.9067834699412197]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.0315874366232787], {
             RGBColor[
             0.8382735323440975, 0.8738805766350533, 0.9844364719222383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.0315874366232787], {
             RGBColor[
             0.9548203864752497, 0.9658256987248445, 0.9613614803537139]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.0315874366232787], {
             RGBColor[
             0.8560073502758229, 0.43150261356316644`, 0.20126600791636998`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.0315874366232787], {
             RGBColor[
             0.9935734332388126, 0.9886625484604183, 0.5418860520965578]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.0315874366232787], {
             RGBColor[
             0.8322294863261052, 0.8690612184015647, 0.9838599854174586]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.0315874366232787], {
             RGBColor[
             0.9037555467997191, 0.9260941575000344, 0.9906822049174999]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.0315874366232787], {
             RGBColor[
             0.7128695186562862, 0.7756183530740808, 0.9720158295413984]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.0315874366232787], {
             RGBColor[
             0.9916213952013383, 0.9908032458425011, 0.7885186948553687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.0315874366232787], {
             RGBColor[
             0.7025128092886838, 0.7675276130022032, 0.9709835695405875]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.0315874366232787], {
             RGBColor[
             0.985809662186728, 0.988399944886234, 0.8848341511903742]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.0315874366232787], {
             RGBColor[
             0.9007427147997358, 0.9236918070443937, 0.9903948383117546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.0315874366232787], {
             RGBColor[
             0.7378121431749148, 0.7951037209190008, 0.9745018772513367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.0315874366232787], {
             RGBColor[
             0.9519940378248307, 0.9637178125290832, 0.9661457513890858]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.0315874366232787], {
             RGBColor[
             0.993403790522035, 0.9882996998427405, 0.5234214892887967]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.0315874366232787], {
             RGBColor[
             0.9944662176901804, 0.9919796530502405, 0.741372624050653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.0315874366232787], {
             RGBColor[
             0.9775603406458642, 0.9827851193120312, 0.9228686694727813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.0315874366232787], {
             RGBColor[
             0.6786174573549162, 0.7488603824601429, 0.9686019041745894]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.0315874366232787], {
             RGBColor[
             0.9928672081454609, 0.9913184215108282, 0.7678723503107069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.0315874366232787], {
             RGBColor[
             0.7405856059663001, 0.797270371130729, 0.9747783101028986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.0315874366232787], {
             RGBColor[
             0.8771250942003604, 0.9048597574616848, 0.9881421685752874]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.0315874366232787], {
             RGBColor[
             0.9944768440879991, 0.99059485291798, 0.6402167478250032]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.0315874366232787], {
             RGBColor[
             0.8679049538266568, 0.8975078678017367, 0.987262743355527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.0315874366232787], {
             RGBColor[
             0.9584675630011221, 0.8715634791021433, 0.29315475431232324`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.0315874366232787], {
             RGBColor[
             0.9614659973249142, 0.9707819844153351, 0.9501121946381351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.0315874366232787], {
             RGBColor[
             0.49768519745268, 0.6030822896115535, 0.9535987483058743]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.0315874366232787], {
             RGBColor[
             0.9016805731002956, 0.9244396297957748, 0.9904842920736979]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.0315874366232787], {
             RGBColor[
             0.9585416234350258, 0.9686009911564792, 0.9550623968348517]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.0315874366232787], {
             RGBColor[
             0.9806273209959229, 0.9850724682353855, 0.9176770717367182]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.0315874366232787], {
             RGBColor[
             0.636714318529332, 0.7159523932921094, 0.9645436299974794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.0315874366232787], {
             RGBColor[
             0.9527002526598649, 0.964244506396731, 0.9649503138837012]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.0315874366232787], {
             RGBColor[
             0.9518448803812244, 0.9636065711518644, 0.9663982360346197]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.0315874366232787], {
             RGBColor[
             0.9917167894060963, 0.9908426937976879, 0.7869377660102386]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.0315874366232787], {
             RGBColor[
             0.9226274597451648, 0.9411421086183025, 0.992482224821392]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.0315874366232787], {
             RGBColor[
             0.9888354813840521, 0.989651198884334, 0.834688496521646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.0315874366232787], {
             RGBColor[
             0.5367579856522633, 0.6348033392810245, 0.9566747013212847]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.0315874366232787], {
             RGBColor[
             0.5525192101092967, 0.6475990113303145, 0.95791548264581]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.0315874366232787], {
             RGBColor[
             0.5355548897193153, 0.6338266118038032, 0.9565799892023574]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.0315874366232787], {
             RGBColor[
             0.4154628272953403, 0.5342747520595261, 0.9476939018692739]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.0315874366232787], {
             RGBColor[
             0.9625151777326996, 0.9715644614455863, 0.9483362058778302]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.0315874366232787], {
             RGBColor[
             0.7237891914025989, 0.7841488844160869, 0.9731042004706072]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.0315874366232787], {
             RGBColor[
             0.8830821278010609, 0.9096097343555138, 0.9887103557580288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.0315874366232787], {
             RGBColor[
             0.9886932872504072, 0.973521944332531, 0.41057598537171713`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.0315874366232787], {
             RGBColor[
             0.8286502316610642, 0.8662072178879408, 0.9835185929122686]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.0315874366232787], {
             RGBColor[
             0.8357223174363426, 0.27558296220085116`, 0.18184103756061584`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.0315874366232787], {
             RGBColor[
             0.6556625065484896, 0.7309278004260747, 0.9663139692044164]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.0315874366232787], {
             RGBColor[
             0.9737521119822815, 0.9799449486101333, 0.929315007255118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.0315874366232787], {
             RGBColor[
             0.9015219240987835, 0.9243131273883815, 0.9904691599903062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.0315874366232787], {
             RGBColor[
             0.937468366562731, 0.952884590685413, 0.9907339239340041]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.0315874366232787], {
             RGBColor[
             0.9419185647700974, 0.956203541221936, 0.9832008991665144]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.0315874366232787], {
             RGBColor[
             0.7562757709325776, 0.8095276472520553, 0.9763421591138092]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.0315874366232787], {
             RGBColor[
             0.9286729402142171, 0.945962610644129, 0.9930588481453944]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.0315874366232787], {
             RGBColor[
             0.9113534823015472, 0.9321525450287271, 0.9914069027884214]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.0315874366232787], {
             RGBColor[
             0.9802187845732576, 0.9847677824402787, 0.9183686173369264]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.0315874366232787], {
             RGBColor[
             0.9814774134983455, 0.9857064658317936, 0.9162380868697505]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.0315874366232787], {
             RGBColor[
             0.7856447336731529, 0.8324709041573768, 0.9792693828512287]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.0315874366232787], {
             RGBColor[
             0.6841662762622314, 0.7531951619631232, 0.9691549585866096]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.0315874366232787], {
             RGBColor[
             0.9907542789997469, 0.9904446710092731, 0.802889054340533]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.0315874366232787], {
             RGBColor[
             0.9946467959199495, 0.9920543267888989, 0.7383799754619004]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.0315874366232787], {
             RGBColor[
             0.9947162726363656, 0.9911069663729966, 0.6662770677329873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.0315874366232787], {
             RGBColor[
             0.9832757286029733, 0.9552472469114746, 0.38952979304654234`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.0315874366232787], {
             RGBColor[
             0.8968897422058019, 0.9206195512841457, 0.990027338346156]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.0315874366232787], {
             RGBColor[
             0.7945894126332769, 0.8394585553431034, 0.9801609048571965]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.0315874366232787], {
             RGBColor[
             0.8984995834070457, 0.9219031949600422, 0.9901808864370528]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.0315874366232787], {
             RGBColor[
             0.9375553867113999, 0.9529494901698079, 0.9905866215207971]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.0315874366232787], {
             RGBColor[
             0.9406683000497367, 0.9552710958406117, 0.9853172712168212]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.0315874366232787], {
             RGBColor[
             0.8611324106725154, 0.892107625726411, 0.9866167721435644]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.0315874366232787], {
             RGBColor[
             0.8887602948589268, 0.9141373506377173, 0.9892519444009676]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.0315874366232787], {
             RGBColor[
             0.9466323249186603, 0.9597190558226604, 0.9752217327805424]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.0315874366232787], {
             RGBColor[
             0.5958013100427445, 0.6827373698926692, 0.961322808100127]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.0315874366232787], {
             RGBColor[
             0.9561925436448618, 0.96684905129524, 0.9590387761814667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[401, 0.0315874366232787], {
             RGBColor[
             0.988163542248631, 0.9893733347837892, 0.8458242669183142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[402, 0.0315874366232787], {
             RGBColor[
             0.9900442243353011, 0.9901510451579524, 0.8146564976929663]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[403, 0.0315874366232787], {
             RGBColor[
             0.9630729699825319, 0.9719804619922102, 0.9473920090943823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[404, 0.0315874366232787], {
             RGBColor[
             0.9902050175747179, 0.9902175372946489, 0.8119917375962656]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[405, 0.0315874366232787], {
             RGBColor[
             0.9793269819626084, 0.9841026775134493, 0.9198782065373833]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[406, 0.0315874366232787], {
             RGBColor[
             0.9900442243353011, 0.9901510451579524, 0.8146564976929663]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[407, 0.0315874366232787], {
             RGBColor[
             0.7135233875170174, 0.7761291603976713, 0.9720810010786841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[408, 0.0315874366232787], {
             RGBColor[
             0.48837407043697356`, 0.5955230972387112, 0.9528657422794158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[409, 0.0315874366232787], {
             RGBColor[
             0.8844874487503994, 0.9107302991340954, 0.9888443965247216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[410, 0.0315874366232787], {
             RGBColor[
             0.9899402662901301, 0.9901080558346742, 0.8163793515362474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[411, 0.0315874366232787], {
             RGBColor[
             0.947459651539197, 0.9603360746616336, 0.9738212846133147]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[412, 0.0315874366232787], {
             RGBColor[
             0.9947749517754976, 0.9912324751182288, 0.6726639299018309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[413, 0.0315874366232787], {
             RGBColor[
             0.9704919144772539, 0.9775134986489672, 0.9348336712354388]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[414, 0.0315874366232787], {
             RGBColor[
             0.9420823738124707, 0.9563257097375254, 0.9829236131860171]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[415, 0.0315874366232787], {
             RGBColor[
             0.9833351832692131, 0.9870919874850879, 0.9130933672316287]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[416, 0.0315874366232787], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[417, 0.0315874366232787], {
             RGBColor[
             0.94734781663536, 0.9602526683734649, 0.9740105919342963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[418, 0.0315874366232787], {
             RGBColor[
             0.8897123212196224, 0.9148964706156688, 0.9893427495251348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[419, 0.0315874366232787], {
             RGBColor[
             0.8152030853643605, 0.8555621131503413, 0.982215483109307]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[420, 0.0315874366232787], {
             RGBColor[
             0.8330654135534501, 0.8697277640820095, 0.9839397169026438]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[421, 0.0315874366232787], {
             RGBColor[
             0.9932838964776719, 0.9914907328445991, 0.7609667462911337]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[422, 0.0315874366232787], {
             RGBColor[
             0.8713085130899209, 0.9002217735711084, 0.9875873778764503]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[423, 0.0315874366232787], {
             RGBColor[
             0.9908779045036394, 0.9904957933321633, 0.8008402598084848]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[424, 0.0315874366232787], {
             RGBColor[
             0.5463603645423613, 0.6425989830462453, 0.9574306357621861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[425, 0.0315874366232787], {
             RGBColor[
             0.7758707241843288, 0.8248353736594839, 0.9782952009286945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[426, 0.0315874366232787], {
             RGBColor[
             0.9896589244223426, 0.9899917137421879, 0.8210419143749003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[427, 0.0315874366232787], {
             RGBColor[
             0.9835524906040738, 0.9561808301279947, 0.3906049611586993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[428, 0.0315874366232787], {
             RGBColor[
             0.7544627723665334, 0.8081113189929622, 0.9761614563601807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[429, 0.0315874366232787], {
             RGBColor[
             0.9226274597451648, 0.9411421086183025, 0.992482224821392]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[430, 0.0315874366232787], {
             RGBColor[
             0.944741292643148, 0.9583087270478644, 0.9784227571627772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[431, 0.0315874366232787], {
             RGBColor[
             0.8976368683175733, 0.9212152893654743, 0.990098599901664]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[432, 0.0315874366232787], {
             RGBColor[
             0.9852977795359281, 0.9881882682553441, 0.8933173714239642]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[433, 0.0315874366232787], {
             RGBColor[
             0.9380772059470657, 0.9533386621013668, 0.9897033176670688]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[434, 0.0315874366232787], {
             RGBColor[
             0.9933517874459469, 0.991518807504699, 0.7598416172506238]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[435, 0.0315874366232787], {
             RGBColor[
             0.5498690768036788, 0.645447513725669, 0.9577068544442335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[436, 0.0315874366232787], {
             RGBColor[
             0.937468366562731, 0.952884590685413, 0.9907339239340041]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[437, 0.0315874366232787], {
             RGBColor[
             0.9793253636818458, 0.9841014706023062, 0.9198809458645992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[438, 0.0315874366232787], {
             RGBColor[
             0.8069242427731497, 0.8490946183965533, 0.9813903254499977]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[439, 0.0315874366232787], {
             RGBColor[
             0.923935707451921, 0.9421852698282319, 0.992607006655549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[440, 0.0315874366232787], {
             RGBColor[
             0.8944491302406826, 0.9186734735518066, 0.9897945505981628]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[441, 0.0315874366232787], {
             RGBColor[
             0.9548764849756416, 0.8588073299880875, 0.28255076450761574`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[442, 0.0315874366232787], {
             RGBColor[
             0.9925626409644364, 0.986500565992303, 0.43186755091753276`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[443, 0.0315874366232787], {
             RGBColor[
             0.9374969023245245, 0.9529058726098356, 0.9906856203326062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[444, 0.0315874366232787], {
             RGBColor[
             0.9477627393432341, 0.9605621170496238, 0.9733082360190394]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[445, 0.0315874366232787], {
             RGBColor[
             0.9898358753441167, 0.9900648874957727, 0.8181093796667993]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[446, 0.0315874366232787], {
             RGBColor[
             0.930777136828045, 0.9476404399070999, 0.9932595482968598]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[447, 0.0315874366232787], {
             RGBColor[
             0.9893814917973358, 0.9898769882220543, 0.8256396909438819]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[448, 0.0315874366232787], {
             RGBColor[
             0.8679049538266568, 0.8975078678017367, 0.987262743355527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[449, 0.0315874366232787], {
             RGBColor[
             0.8499757566540627, 0.8832116126514026, 0.9855526405236218]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[450, 0.0315874366232787], {
             RGBColor[
             0.9935723948258787, 0.9886603274001523, 0.5417730272570399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[451, 0.0315874366232787], {
             RGBColor[
             0.9887918598306757, 0.98963316025099, 0.8354114185500549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[452, 0.0315874366232787], {
             RGBColor[
             0.8222000511876362, 0.861064019063914, 0.982903368940569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[453, 0.0315874366232787], {
             RGBColor[
             0.9946637713943844, 0.9909946715250885, 0.6605626315434371]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[454, 0.0315874366232787], {
             RGBColor[
             0.9915442021999143, 0.9907713245526427, 0.7897979826580468]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[455, 0.0315874366232787], {
             RGBColor[
             0.9947694504925411, 0.9912207084302499, 0.672065149202]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[456, 0.0315874366232787], {
             RGBColor[
             0.8378667793758742, 0.8735562428592071, 0.9843976754610165]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[457, 0.0315874366232787], {
             RGBColor[
             0.4882868028765106, 0.5954522495017686, 0.9528588722573845]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[458, 0.0315874366232787], {
             RGBColor[
             0.8069122543201317, 0.8490852529259401, 0.9813891305530393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[459, 0.0315874366232787], {
             RGBColor[
             0.9919722766355427, 0.9909483443327862, 0.7827036814385585]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[460, 0.0315874366232787], {
             RGBColor[
             0.723869401775705, 0.7842115453691788, 0.9731121950909899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[461, 0.0315874366232787], {
             RGBColor[
             0.812264949975467, 0.8532668194538818, 0.9819226372321783]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[462, 0.0315874366232787], {
             RGBColor[
             0.9951340609141146, 0.9920005732542271, 0.7117507434755771]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[463, 0.0315874366232787], {
             RGBColor[
             0.9552328851717119, 0.9661333395772613, 0.960663227657494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[464, 0.0315874366232787], {
             RGBColor[
             0.955343457485119, 0.9662158042275547, 0.9604760575727739]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[465, 0.0315874366232787], {
             RGBColor[
             0.9878351158754166, 0.9892375220382923, 0.8512671418626839]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[466, 0.0315874366232787], {
             RGBColor[
             0.9580098223252544, 0.9682043747595561, 0.9559625973977515]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[467, 0.0315874366232787], {
             RGBColor[
             0.9227602290360675, 0.9412479752469418, 0.9924948884748829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[468, 0.0315874366232787], {
             RGBColor[
             0.8482993767184253, 0.8818749127948465, 0.9853927459088386]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[469, 0.0315874366232787], {
             RGBColor[
             0.8620736653972622, 0.8928581566942452, 0.9867065498594787]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[470, 0.0315874366232787], {
             RGBColor[
             0.9906644304987849, 0.9904075163451243, 0.8043780765219388]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[471, 0.0315874366232787], {
             RGBColor[
             0.9529955235176163, 0.9644647189189803, 0.9644504973405016]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[472, 0.0315874366232787], {
             RGBColor[
             0.9252694201803718, 0.943248736155231, 0.992734217366208]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[473, 0.0315874366232787], {
             RGBColor[
             0.8262136413471683, 0.8642643469111224, 0.9832861887529594]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[474, 0.0315874366232787], {
             RGBColor[
             0.5367579856522633, 0.6348033392810245, 0.9566747013212847]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[475, 0.0315874366232787], {
             RGBColor[
             0.7994317042992278, 0.8432413903953241, 0.9806435392366701]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[476, 0.0315874366232787], {
             RGBColor[
             0.8697433308684857, 0.8989737397534756, 0.9874380893989152]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[477, 0.0315874366232787], {
             RGBColor[
             0.9447996795859107, 0.958352271934177, 0.9783239232984334]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[478, 0.0315874366232787], {
             RGBColor[
             0.8572386140196244, 0.8890028179696902, 0.9862453783427784]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[479, 0.0315874366232787], {
             RGBColor[
             0.9279203800480342, 0.9453625395953162, 0.9929870682849254]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[480, 0.0315874366232787], {
             RGBColor[
             0.9445958286219547, 0.9582002402190339, 0.9786689898075644]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[481, 0.0315874366232787], {
             RGBColor[
             0.9940944543806192, 0.9918259193678557, 0.7475337041826883]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[482, 0.0315874366232787], {
             RGBColor[
             0.7243142958420646, 0.7845590999951391, 0.9731565379737532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[483, 0.0315874366232787], {
             RGBColor[
             0.9933291263245245, 0.9915094365486267, 0.7602171706776957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[484, 0.0315874366232787], {
             RGBColor[
             0.988899061493964, 0.9896774908937168, 0.8336348095603567]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[485, 0.0315874366232787], {
             RGBColor[
             0.6812097340208215, 0.7508854886935805, 0.968860278086444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[486, 0.0315874366232787], {
             RGBColor[
             0.9815145972008043, 0.9857341973762046, 0.9161751445605505]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[487, 0.0315874366232787], {
             RGBColor[
             0.992561672357163, 0.9911920746104553, 0.772935869024078]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[488, 0.0315874366232787], {
             RGBColor[
             0.9764380230793589, 0.9819480967085579, 0.9247684603655733]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[489, 0.0315874366232787], {
             RGBColor[
             0.868631086312147, 0.8980868661353254, 0.9873320025202192]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[490, 0.0315874366232787], {
             RGBColor[
             0.9890067654763494, 0.9897220292582992, 0.8318498758432584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[491, 0.0315874366232787], {
             RGBColor[
             0.99075302918874, 0.9904441541803032, 0.8029097669433244]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[492, 0.0315874366232787], {
             RGBColor[
             0.7065089602946721, 0.7706494365399538, 0.97138186852671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[493, 0.0315874366232787], {
             RGBColor[
             0.9875175565343083, 0.9891062030898411, 0.8565299219620809]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[494, 0.0315874366232787], {
             RGBColor[
             0.9932870678550827, 0.9914920442906591, 0.7609141883601754]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[495, 0.0315874366232787], {
             RGBColor[
             0.3897794701541797, 0.5120291189869168, 0.9460573810631402]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[496, 0.0315874366232787], {
             RGBColor[
             0.8802492060799879, 0.9073508394727419, 0.9884401491552939]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[497, 0.0315874366232787], {
             RGBColor[
             0.9400298746233885, 0.9547949592029668, 0.9863979589356099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[498, 0.0315874366232787], {
             RGBColor[
             0.7204555056930733, 0.7815445838028556, 0.972771929834146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[499, 0.0315874366232787], {
             RGBColor[
             0.9661143295264513, 0.9742487029602961, 0.9422437807001365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[500, 0.0315874366232787], {
             RGBColor[
             0.992597600257574, 0.9912069317205802, 0.7723404507358402]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1dOWGAgQBNBMbNu2bds2J+bEtm3btm3btu01sjdnH271F1R1ssCg6p0C
ggUL9l38vMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEIS
kZgkJCUZyUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpR
mCIUpRjFKUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGY
JjSlGYE0pwUtaUVr2tCWdrSnAx3pRBCd6UJXutGdHvSkF73pQ1/60Z8BDGQQ
gxnCUIYxnBGMZBSjGcNYxjGeCUxkEpOZwlSmMZ0ZzGQWs5nDXOYxnwUsZBGL
WcJSlrGcFaxkFatZw1rWsZ4NbGQTm9nCVraxnR3sZBe72cNe9rGfAxzkEIc5
wlGOcZwTnOQUpznDWc5xngtc5BKXucJVrnGdG9zkFre5w13ucZ8HPOQRj3nC
U57xnBe85BWvecNb3vGeD3zkE5/5wle+8Z1f+JXf+J0/+JO/+Jt/+Jcf/Cx/
AMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEISkZgkJCUZ
yUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpRmCIUpRjF
KUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGYJjSlGYE0
pwUtaUVr2tCWdrSnAx35Od5BdKYLXelGd3rQk170pg996Ud/BjCQQQxmCEMZ
xnBGMJJRjGYMYxnHeCYwkUlMZgpTmcZ0ZjCTWcxmDnOZx3wWsJBFLGYJS1nG
clawklWsZg1rWcd6NrCRTWxmC1vZxnZ2sJNd7GYPe9nHfg5wkEMc5ghHOcZx
TnCSU5zmDGc5x3kucJFLXOYKV7nGdW5wk1vc5g53ucd9HvCQRzzmCU95xnNe
8JJXvOYNb3nHez7wkU985gtf+Rbw/z//Dz189+A=
          "], {Null, CompressedData["
1:eJw13A2c1mO6wPH7tsdpl2O9LLLYQ3Ioas/uCqvVrqQihdKSUmmVzEwspdpK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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[196, 330] -> 
             RGBColor[
              0.3010744440099954, 0.433778708249762, 0.9404571162354194], 
             UndirectedEdge[136, 319] -> 
             RGBColor[
              0.8419251732908781, 0.8767840075536342, 0.9548214315268342], 
             UndirectedEdge[60, 188] -> 
             RGBColor[
              0.31499337168742486`, 0.44577048443841216`, 0.9413463649912971],
              UndirectedEdge[145, 408] -> 
             RGBColor[
              0.2215813501340996, 0.35022642643293833`, 0.9359301021386808], 
             UndirectedEdge[398, 460] -> 
             RGBColor[
              0.2547486544855675, 0.3850873662348864, 0.9378189310548671], 
             UndirectedEdge[413, 476] -> 
             RGBColor[
              0.9111642263834832, 0.6485722673362936, 0.273464018883213], 
             UndirectedEdge[244, 274] -> 
             RGBColor[
              0.40258764491589, 0.5228672426461249, 0.9469441500000384], 
             UndirectedEdge[198, 223] -> 
             RGBColor[
              0.335871613441881, 0.4628528461466326, 0.9427133713948876], 
             UndirectedEdge[36, 310] -> 
             RGBColor[
              0.2755731801551128, 0.4069752630647657, 0.9390048569846228], 
             UndirectedEdge[252, 432] -> 
             RGBColor[
              0.8172102397534445, 0.8577657390481622, 0.982246863062763], 
             UndirectedEdge[469, 475] -> 
             RGBColor[
              0.8497170345102683, 0.3799664311487149, 0.19511763635494941`], 
             UndirectedEdge[113, 347] -> 
             RGBColor[
              0.17905963034776856`, 0.3055334029047545, 0.9335085531020964], 
             UndirectedEdge[35, 131] -> 
             RGBColor[
              0.2509907389862678, 0.38113755877951816`, 0.9376049233265198], 
             UndirectedEdge[156, 479] -> 
             RGBColor[
              0.4393999195807523, 0.5546279653397757, 0.9493241177753168], 
             UndirectedEdge[318, 354] -> 
             RGBColor[
              0.35185308329442466`, 0.47917918892462685`, 0.9436407452294238],
              UndirectedEdge[6, 77] -> 
             RGBColor[
              0.7172538475630181, 0.7785612627115652, 0.9728085302210365], 
             UndirectedEdge[23, 202] -> 
             RGBColor[
              0.23077928410080303`, 0.35989403821464017`, 0.9364539108709606],
              UndirectedEdge[342, 395] -> 
             RGBColor[
              0.2624873580585535, 0.3932212343522405, 0.9382596387749628], 
             UndirectedEdge[53, 418] -> 
             RGBColor[
              0.9774928986004763, 0.9579493905915291, 0.642289060004833], 
             UndirectedEdge[75, 149] -> 
             RGBColor[
              0.3494116417234011, 0.4770645349462275, 0.9434851787314], 
             UndirectedEdge[293, 418] -> 
             RGBColor[
              0.9663729017016692, 0.9744415456652006, 0.9418060854539165], 
             UndirectedEdge[282, 432] -> 
             RGBColor[
              0.7531414292760994, 0.8071831282683875, 0.9762245194841053], 
             UndirectedEdge[466, 468] -> 
             RGBColor[
              0.49094259840512156`, 0.5976083439541202, 0.9530679462098963], 
             UndirectedEdge[105, 190] -> 
             RGBColor[
              0.24700744449895456`, 0.37695086371789455`, 0.9373780805982235],
              UndirectedEdge[64, 473] -> 
             RGBColor[
              0.3073328542986736, 0.43868458843205593`, 0.9408747474285853], 
             UndirectedEdge[214, 273] -> 
             RGBColor[
              0.24667426527178135`, 0.3766006712253524, 0.9373591065341305], 
             UndirectedEdge[30, 64] -> 
             RGBColor[
              0.27788283656739987`, 0.4094028583947541, 0.9391363885004721], 
             UndirectedEdge[296, 395] -> 
             RGBColor[
              0.289203696626415, 0.4208696734674796, 0.9397969170059906], 
             UndirectedEdge[114, 203] -> 
             RGBColor[
              0.5176225598035007, 0.6192683385358883, 0.9551682905030956], 
             UndirectedEdge[81, 237] -> 
             RGBColor[
              0.8648552697662895, 0.8950761325134684, 0.9869718617673642], 
             UndirectedEdge[382, 427] -> 
             RGBColor[
              0.2808624118228371, 0.41253458090420103`, 0.9393060709033827], 
             UndirectedEdge[39, 450] -> 
             RGBColor[
              0.7206850354992045, 0.4212381693670362, 0.5640535204963621], 
             UndirectedEdge[50, 57] -> 
             RGBColor[
              0.5210905073010532, 0.6217476292469348, 0.9555341779806428], 
             UndirectedEdge[74, 153] -> 
             RGBColor[
              0.2633334885240648, 0.39411057111926295`, 0.9383078246532357], 
             UndirectedEdge[239, 332] -> 
             RGBColor[
              0.37656128496655794`, 0.5005801913427036, 0.9452151299913671], 
             UndirectedEdge[14, 72] -> 
             RGBColor[
              0.2803635687690008, 0.4120102652261427, 0.9392776625294388], 
             UndirectedEdge[331, 403] -> 
             RGBColor[
              0.8828018353475209, 0.9093862367613971, 0.9886836212135901], 
             UndirectedEdge[214, 302] -> 
             RGBColor[
              0.19497823659732902`, 0.32226486737097304`, 0.9344150941785414],
              UndirectedEdge[128, 197] -> 
             RGBColor[
              0.5961844176461558, 0.6822017797294064, 0.9619318024689351], 
             UndirectedEdge[191, 212] -> 
             RGBColor[
              0.21845881642544385`, 0.3469444455250692, 0.9357522784633475], 
             UndirectedEdge[404, 407] -> 
             RGBColor[
              0.2139033248740353, 0.3421563350696921, 0.9354928499587406], 
             UndirectedEdge[60, 116] -> 
             RGBColor[
              0.27071777339856856`, 0.4018719227130688, 0.9387283487527682], 
             UndirectedEdge[272, 357] -> 
             RGBColor[
              0.8638626077841431, 0.41438606964025426`, 0.20574312527482636`],
              UndirectedEdge[228, 490] -> 
             RGBColor[
              0.9918174311383581, 0.9889858002878001, 0.6472681311594083], 
             UndirectedEdge[111, 415] -> 
             RGBColor[
              0.2800519643946353, 0.41168274927182613`, 0.9392599171212961], 
             UndirectedEdge[227, 428] -> 
             RGBColor[
              0.8379823315719487, 0.29295442119162834`, 0.18400522964919308`],
              UndirectedEdge[367, 499] -> 
             RGBColor[
              0.24528184927831587`, 0.3751371537319471, 0.9372798105031974], 
             UndirectedEdge[434, 495] -> 
             RGBColor[
              0.9167025248852594, 0.6580111596730529, 0.4917530067660364], 
             UndirectedEdge[226, 283] -> 
             RGBColor[
              0.18031957576389654`, 0.30685768542225833`, 0.9335803051296228],
              UndirectedEdge[9, 34] -> 
             RGBColor[
              0.559448373541096, 0.6532244183595045, 0.9584609717735231], 
             UndirectedEdge[127, 386] -> 
             RGBColor[
              0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993],
              UndirectedEdge[326, 469] -> 
             RGBColor[
              0.8678030946468546, 0.4926065528105953, 0.21140400054171546`], 
             UndirectedEdge[192, 483] -> 
             RGBColor[
              0.275631905541692, 0.4070369871694651, 0.9390082013085121], 
             UndirectedEdge[16, 39] -> 
             RGBColor[
              0.5137718344766236, 0.6147998451486828, 0.9552360290912556], 
             UndirectedEdge[209, 421] -> 
             RGBColor[
              0.37249008899703795`, 0.4820057501195733, 0.9462395519949527], 
             UndirectedEdge[293, 317] -> 
             RGBColor[
              0.9188363181868828, 0.7644234365766909, 0.5933539685152149], 
             UndirectedEdge[3, 381] -> 
             RGBColor[
              0.5154854178683257, 0.6175333104357662, 0.9550000468613498], 
             UndirectedEdge[211, 497] -> 
             RGBColor[
              0.23351702426712523`, 0.36277157671219695`, 0.936609821123309], 
             UndirectedEdge[196, 479] -> 
             RGBColor[
              0.35359500425427093`, 0.4794816999667437, 0.9437959057364866], 
             UndirectedEdge[221, 439] -> 
             RGBColor[
              0.6987612824501502, 0.7633077628527738, 0.9716294265306357], 
             UndirectedEdge[379, 390] -> 
             RGBColor[
              0.30502633329137085`, 0.4378812473959014, 0.9406840432278518], 
             UndirectedEdge[119, 320] -> 
             RGBColor[
              0.9896249360090673, 0.9899776586598361, 0.8216051903420669], 
             UndirectedEdge[179, 401] -> 
             RGBColor[
              0.47619075737058414`, 0.5641711945885997, 0.9557776422261561], 
             UndirectedEdge[59, 342] -> 
             RGBColor[
              0.25108912406320616`, 0.3812409677333546, 0.9376105262111039], 
             UndirectedEdge[86, 98] -> 
             RGBColor[
              0.9552139147274563, 0.8468459050338089, 0.4866646892725739], 
             UndirectedEdge[328, 431] -> 
             RGBColor[
              0.4169264678183623, 0.535542483915856, 0.9477871637491544], 
             UndirectedEdge[270, 375] -> 
             RGBColor[
              0.9741122632489756, 0.9792447932430604, 0.8853225104060825], 
             UndirectedEdge[39, 45] -> 
             RGBColor[
              0.45322202962692537`, 0.5599541419213354, 0.9514657433370749], 
             UndirectedEdge[59, 463] -> 
             RGBColor[
              0.2546442329532448, 0.38497761258370766`, 0.9378129844030793], 
             UndirectedEdge[2, 55] -> 
             RGBColor[
              0.21196267506411343`, 0.3401165890751596, 0.9353823328229998], 
             UndirectedEdge[193, 496] -> 
             RGBColor[
              0.28235063055336573`, 0.41409879314850406`, 0.939390822758464], 
             UndirectedEdge[201, 246] -> 
             RGBColor[
              0.2993400916080083, 0.43195579391098005`, 0.9403583474318706], 
             UndirectedEdge[69, 487] -> 
             RGBColor[
              0.7444469428218465, 0.8000461273805028, 0.9756303235156909], 
             UndirectedEdge[15, 408] -> 
             RGBColor[
              0.22837166352845595`, 0.3573634763411423, 0.9363168004411209], 
             UndirectedEdge[118, 310] -> 
             RGBColor[
              0.3109325878407584, 0.44262745407148385`, 0.9410739135361832], 
             UndirectedEdge[289, 297] -> 
             RGBColor[
              0.47936763079523015`, 0.5878325714725148, 0.9522613561781106], 
             UndirectedEdge[397, 419] -> 
             RGBColor[
              0.43561929438142943`, 0.5501211672171827, 0.9494236831393772], 
             UndirectedEdge[13, 380] -> 
             RGBColor[
              0.28473366122711574`, 0.4166035094794867, 0.939526532829956], 
             UndirectedEdge[155, 262] -> 
             RGBColor[
              0.520987467347936, 0.6220001220678183, 0.9554331883510561], 
             UndirectedEdge[182, 324] -> 
             RGBColor[
              0.37413205522389265`, 0.49847611463624397`, 0.9450603416202481],
              UndirectedEdge[177, 245] -> 
             RGBColor[
              0.21512971428686242`, 0.34344534810015337`, 0.9355626910215206],
              UndirectedEdge[113, 325] -> 
             RGBColor[
              0.1791045905323438, 0.30558065890938335`, 0.9335111135180953], 
             UndirectedEdge[94, 368] -> 
             RGBColor[
              0.6817603644893816, 0.7470855364406719, 0.9537864521193352], 
             UndirectedEdge[50, 140] -> 
             RGBColor[
              0.47028604559026116`, 0.5805022785151959, 0.9515346646518938], 
             UndirectedEdge[389, 458] -> 
             RGBColor[
              0.2244995192065336, 0.35329360715067204`, 0.9360962875503116], 
             UndirectedEdge[429, 499] -> 
             RGBColor[
              0.2771583025105514, 0.4086413271628938, 0.9390951273577867], 
             UndirectedEdge[97, 358] -> 
             RGBColor[
              0.2286803601297014, 0.35768793604154625`, 0.9363343802558861], 
             UndirectedEdge[274, 363] -> 
             RGBColor[
              0.4337728092244554, 0.5498782645582716, 0.9489312410938221], 
             UndirectedEdge[255, 274] -> 
             RGBColor[
              0.43015989340709154`, 0.5467489384677, 0.9487010292927157], 
             UndirectedEdge[289, 381] -> 
             RGBColor[
              0.5043379271734174, 0.6081045829713598, 0.9542271093782111], 
             UndirectedEdge[55, 230] -> 
             RGBColor[
              0.21767784356668446`, 0.34612359353397393`, 0.935707803214387], 
             UndirectedEdge[289, 349] -> 
             RGBColor[
              0.42648626116779464`, 0.5438226964259498, 0.9483963053279869], 
             UndirectedEdge[29, 318] -> 
             RGBColor[
              0.37578131668551923`, 0.4999046220200136, 0.9451654311021982], 
             UndirectedEdge[69, 402] -> 
             RGBColor[
              0.7308868707375382, 0.7890374499881754, 0.9745628249690335], 
             UndirectedEdge[6, 413] -> 
             RGBColor[
              0.9007629224656561, 0.8944231613369187, 0.6681426582115271], 
             UndirectedEdge[29, 482] -> 
             RGBColor[
              0.38405087443932273`, 0.5070672973063002, 0.9456923600097877], 
             UndirectedEdge[212, 456] -> 
             RGBColor[
              0.22108739015867407`, 0.34970724317989477`, 0.9359019718488286],
              UndirectedEdge[354, 482] -> 
             RGBColor[
              0.3601226410482282, 0.48634186421091347`, 0.9441676741370133], 
             UndirectedEdge[106, 247] -> 
             RGBColor[
              0.5064333598698463, 0.6101844419620349, 0.9542874356969284], 
             UndirectedEdge[305, 382] -> 
             RGBColor[
              0.2666682843502908, 0.39761565297089385`, 0.938497736342151], 
             UndirectedEdge[279, 285] -> 
             RGBColor[
              0.2964892825686648, 0.42843496613236076`, 0.9402152006381983], 
             UndirectedEdge[27, 319] -> 
             RGBColor[
              0.6135043005796454, 0.695998377538924, 0.9634761021745089], 
             UndirectedEdge[118, 483] -> 
             RGBColor[
              0.31087863822406303`, 0.44257074960373377`, 0.9410708411853237],
              UndirectedEdge[342, 447] -> 
             RGBColor[
              0.2532435452217043, 0.38350540096912705`, 0.9377332173088998], 
             UndirectedEdge[207, 458] -> 
             RGBColor[
              0.22378112515977486`, 0.35253852945871533`, 0.9360553760721175],
              UndirectedEdge[462, 487] -> 
             RGBColor[
              0.5216548713893666, 0.6225419507348611, 0.9554857288419789], 
             UndirectedEdge[64, 384] -> 
             RGBColor[
              0.28582762436265047`, 0.41775333409620263`, 0.9395888324121513],
              UndirectedEdge[203, 221] -> 
             RGBColor[
              0.5355883582024223, 0.6338537830261275, 0.9565826239639467], 
             UndirectedEdge[139, 370] -> 
             RGBColor[
              0.5777392587332322, 0.6680737829534684, 0.9599008972575682], 
             UndirectedEdge[46, 357] -> 
             RGBColor[
              0.9123985653292456, 0.6903965335177349, 0.2483720332752017], 
             UndirectedEdge[18, 326] -> 
             RGBColor[
              0.8797797158009789, 0.5469895922605361, 0.22139758680656518`], 
             UndirectedEdge[73, 93] -> 
             RGBColor[
              0.2585978739086303, 0.3891331399031328, 0.9380381384066008], 
             UndirectedEdge[104, 112] -> 
             RGBColor[
              0.24741859649764936`, 0.37738301053706513`, 0.9374014950963042],
              UndirectedEdge[40, 314] -> 
             RGBColor[
              0.35813781501059505`, 0.484622707657373, 0.944041202777008], 
             UndirectedEdge[264, 398] -> 
             RGBColor[0.2479686232623, 0.377961123540424, 0.9374328183068594],
              UndirectedEdge[345, 489] -> 
             RGBColor[
              0.8249113944148371, 0.8621373590775923, 0.8902454594075883], 
             UndirectedEdge[80, 417] -> 
             RGBColor[
              0.7452877880838611, 0.8009437515388753, 0.9752469796719869], 
             UndirectedEdge[271, 442] -> 
             RGBColor[
              0.26987532258207286`, 0.400986453490465, 0.9386803724250632], 
             UndirectedEdge[318, 482] -> 
             RGBColor[
              0.35021188070592757`, 0.4777576617317112, 0.9435361692517431], 
             UndirectedEdge[235, 260] -> 
             RGBColor[
              0.32130907660212404`, 0.45058132040043347`, 0.941772944022762], 
             UndirectedEdge[79, 278] -> 
             RGBColor[
              0.9710962278680113, 0.9751094566161655, 0.770981396643022], 
             UndirectedEdge[137, 404] -> 
             RGBColor[
              0.2167644246749318, 0.34516353236463915`, 0.9356557853597838], 
             UndirectedEdge[380, 478] -> 
             RGBColor[
              0.26944650218814237`, 0.40053573606766074`, 0.9386559517380118],
              UndirectedEdge[247, 370] -> 
             RGBColor[
              0.5432273595581627, 0.6400554684598069, 0.9571839941332545], 
             UndirectedEdge[251, 429] -> 
             RGBColor[
              0.2760715850682322, 0.4074991182291509, 0.9390332404071009], 
             UndirectedEdge[286, 407] -> 
             RGBColor[
              0.21872930348009942`, 0.347228744569382, 0.9357676823009604], 
             UndirectedEdge[206, 410] -> 
             RGBColor[
              0.35319958507105037`, 0.4803454610863929, 0.9437265431319655], 
             UndirectedEdge[86, 500] -> 
             RGBColor[
              0.8673428769617186, 0.42615530998421236`, 0.20846003809980468`],
              UndirectedEdge[78, 407] -> 
             RGBColor[
              0.21689372054729342`, 0.34529943052432305`, 0.9356631485684387],
              UndirectedEdge[363, 370] -> 
             RGBColor[
              0.4981273475389003, 0.6021241779008506, 0.9539974660883765], 
             UndirectedEdge[447, 453] -> 
             RGBColor[
              0.26540338983624123`, 0.39628616863768357`, 0.9384257024708196],
              UndirectedEdge[256, 492] -> 
             RGBColor[
              0.28300272562501616`, 0.4147841864140242, 0.9394279586081062], 
             UndirectedEdge[114, 349] -> 
             RGBColor[
              0.45713997699902986`, 0.5690874562014547, 0.9507048443075143], 
             UndirectedEdge[22, 160] -> 
             RGBColor[
              0.4369491379476227, 0.5528851144131592, 0.949062990584439], 
             UndirectedEdge[149, 324] -> 
             RGBColor[
              0.361776111320833, 0.4877740170552114, 0.9442730318006773], 
             UndirectedEdge[94, 315] -> 
             RGBColor[
              0.5704593476328262, 0.6392872195268108, 0.9471116754258844], 
             UndirectedEdge[246, 492] -> 
             RGBColor[
              0.2854203608730804, 0.4173252743466679, 0.9395656393589127], 
             UndirectedEdge[193, 202] -> 
             RGBColor[
              0.2634343891958272, 0.39421662412275726`, 0.9383135707972234], 
             UndirectedEdge[321, 335] -> 
             RGBColor[
              0.3049738126003747, 0.4356185220197354, 0.94076188047572], 
             UndirectedEdge[321, 496] -> 
             RGBColor[
              0.3050324981109774, 0.4356802042122551, 0.9407652225287313], 
             UndirectedEdge[18, 474] -> 
             RGBColor[
              0.9387405372806834, 0.7796548598202627, 0.49465049788910304`], 
             UndirectedEdge[184, 192] -> 
             RGBColor[
              0.25582325613433854`, 0.3862168407014245, 0.9378801280290341], 
             UndirectedEdge[170, 171] -> 
             RGBColor[
              0.2792113970027737, 0.4107992596479288, 0.9392120480518376], 
             UndirectedEdge[80, 156] -> 
             RGBColor[
              0.6284260394446897, 0.7069689251123001, 0.9654326763878454], 
             UndirectedEdge[353, 418] -> 
             RGBColor[
              0.809068015481273, 0.8509060188194038, 0.9430493347226458], 
             UndirectedEdge[201, 312] -> 
             RGBColor[
              0.30443515610797417`, 0.4373110297461917, 0.9406485038176712], 
             UndirectedEdge[152, 212] -> 
             RGBColor[
              0.21125959360220817`, 0.3393776058807578, 0.93534229337386], 
             UndirectedEdge[192, 260] -> 
             RGBColor[
              0.27009553441077905`, 0.4012179100846716, 0.9386929131629338], 
             UndirectedEdge[90, 357] -> 
             RGBColor[
              0.8859560304571115, 0.5741950476247133, 0.2265078159100875], 
             UndirectedEdge[57, 369] -> 
             RGBColor[
              0.5105952058083258, 0.6126571266031253, 0.9548654266501568], 
             UndirectedEdge[83, 448] -> 
             RGBColor[
              0.7443425082604527, 0.7998796964136958, 0.9757160754212024], 
             UndirectedEdge[67, 180] -> 
             RGBColor[
              0.26337700695553745`, 0.3941563117499686, 0.9383103029635284], 
             UndirectedEdge[373, 472] -> 
             RGBColor[
              0.31103110428016545`, 0.44242232361832246`, 0.9410908260962028],
              UndirectedEdge[353, 432] -> 
             RGBColor[
              0.7691435045990516, 0.820174333900838, 0.9774842614710615], 
             UndirectedEdge[1, 433] -> 
             RGBColor[
              0.2958358704615542, 0.4267230355457211, 0.940215525659722], 
             UndirectedEdge[300, 301] -> 
             RGBColor[
              0.2173551636481656, 0.3457844364805221, 0.9356894270703895], 
             UndirectedEdge[212, 389] -> 
             RGBColor[
              0.21850801717300872`, 0.34699615863026745`, 0.9357550803731354],
              UndirectedEdge[97, 174] -> 
             RGBColor[
              0.24919580773922206`, 0.37925097223365895`, 0.9375027046473634],
              UndirectedEdge[200, 471] -> 
             RGBColor[
              0.8788202951923778, 0.5401284768128874, 0.22049894846562806`], 
             UndirectedEdge[155, 387] -> 
             RGBColor[
              0.6705014636086952, 0.7413486854414358, 0.9685938847155504], 
             UndirectedEdge[156, 354] -> 
             RGBColor[
              0.4145365045344412, 0.533092524898237, 0.9477398429544205], 
             UndirectedEdge[314, 472] -> 
             RGBColor[
              0.3292610947634469, 0.4596111439654538, 0.9422012036975409], 
             UndirectedEdge[117, 269] -> 
             RGBColor[
              0.41500730712434825`, 0.5338802033825223, 0.947664876526779], 
             UndirectedEdge[336, 409] -> 
             RGBColor[
              0.23189710424361965`, 0.36106893805863094`, 0.9365175690744273],
              UndirectedEdge[63, 252] -> 
             RGBColor[
              0.5775658026497799, 0.6655789256820774, 0.9611207995905398], 
             UndirectedEdge[201, 444] -> 
             RGBColor[
              0.2878759109078417, 0.4199062131240665, 0.9397054793007316], 
             UndirectedEdge[201, 442] -> 
             RGBColor[
              0.2942020501296223, 0.426555386546551, 0.9400657435707277], 
             UndirectedEdge[25, 333] -> 
             RGBColor[
              0.34601220845973285`, 0.4741201167137219, 0.94326856984984], 
             UndirectedEdge[203, 397] -> 
             RGBColor[
              0.44655734447149653`, 0.5590011690338403, 0.950284766509865], 
             UndirectedEdge[7, 436] -> 
             RGBColor[
              0.6558009604167452, 0.7285914992480711, 0.9680622843636464], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.24125115959042637`, 0.3709006433094886, 0.9370502686883432], 
             UndirectedEdge[274, 369] -> 
             RGBColor[
              0.4413408424038283, 0.5564333145178368, 0.9494134694758627], 
             UndirectedEdge[38, 364] -> 
             RGBColor[
              0.2592676752099878, 0.3898371435387148, 0.9380762825998308], 
             UndirectedEdge[215, 356] -> 
             RGBColor[
              0.2767305167100354, 0.40819169716336523`, 0.9390707655892996], 
             UndirectedEdge[16, 283] -> 
             RGBColor[
              0.29254812031783006`, 0.4160210207001029, 0.9402936186581154], 
             UndirectedEdge[236, 276] -> 
             RGBColor[
              0.45343165662521556`, 0.5606674341824253, 0.9514328089086481], 
             UndirectedEdge[39, 454] -> 
             RGBColor[
              0.761772006870989, 0.6718134516549312, 0.6008439261608904], 
             UndirectedEdge[179, 315] -> 
             RGBColor[
              0.18221437666537932`, 0.3088492413070327, 0.9336882112378554], 
             UndirectedEdge[149, 182] -> 
             RGBColor[
              0.36623071660169665`, 0.4916323722545241, 0.9445568753101211], 
             UndirectedEdge[97, 407] -> 
             RGBColor[
              0.2230464248259349, 0.3517663128251578, 0.936013535974997], 
             UndirectedEdge[274, 379] -> 
             RGBColor[
              0.386016730119334, 0.5085143491277428, 0.9458882659622865], 
             UndirectedEdge[39, 325] -> 
             RGBColor[
              0.40133925395865816`, 0.5054220551360133, 0.9485110960164554], 
             UndirectedEdge[127, 347] -> 
             RGBColor[
              0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993],
              UndirectedEdge[327, 483] -> 
             RGBColor[
              0.27685916583525294`, 0.4083269155507945, 0.9390780919666615], 
             UndirectedEdge[269, 360] -> 
             RGBColor[
              0.5141528316673345, 0.616332566062272, 0.9549279906939228], 
             UndirectedEdge[54, 147] -> 
             RGBColor[
              0.2401069833110282, 0.36969804149487495`, 0.9369851095418886], 
             UndirectedEdge[276, 422] -> 
             RGBColor[
              0.4267760803352025, 0.5326507334404715, 0.9499148132723232], 
             UndirectedEdge[181, 424] -> 
             RGBColor[
              0.3706458143967508, 0.4954565080553325, 0.9448382014375043], 
             UndirectedEdge[336, 456] -> 
             RGBColor[
              0.22294853768143919`, 0.3516634272298894, 0.936007961446929], 
             UndirectedEdge[46, 298] -> 
             RGBColor[
              0.9096473304128414, 0.8178215341712867, 0.6215408826637097], 
             UndirectedEdge[107, 132] -> 
             RGBColor[
              0.5874023021726906, 0.6508098778838103, 0.8735074338464627], 
             UndirectedEdge[78, 95] -> 
             RGBColor[
              0.22325600943798377`, 0.3519865995408531, 0.9360254715086005], 
             UndirectedEdge[296, 332] -> 
             RGBColor[
              0.3578059368755654, 0.48433525149749035`, 0.9440200557957121], 
             UndirectedEdge[397, 472] -> 
             RGBColor[
              0.3434973849835166, 0.4719419030173265, 0.9431083275217065], 
             UndirectedEdge[19, 269] -> 
             RGBColor[
              0.5043319337096805, 0.6083595186738375, 0.9541548536315616], 
             UndirectedEdge[185, 335] -> 
             RGBColor[
              0.28035846079175497`, 0.4120048964181928, 0.9392773716376912], 
             UndirectedEdge[112, 351] -> 
             RGBColor[
              0.26915448795361524`, 0.4002288105924009, 0.9386393219593516], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.2633838374698597, 0.39416349105360093`, 0.9383106919512142], 
             UndirectedEdge[251, 305] -> 
             RGBColor[
              0.25482853774731307`, 0.38517132860787223`, 0.9378234802884469],
              UndirectedEdge[131, 170] -> 
             RGBColor[
              0.28014480934839103`, 0.4117803352049335, 0.9392652045040607], 
             UndirectedEdge[76, 333] -> 
             RGBColor[
              0.3949872182942583, 0.5165398086768207, 0.9463892141695951], 
             UndirectedEdge[114, 115] -> 
             RGBColor[
              0.7109234320173796, 0.7727455262693818, 0.9730887236423327], 
             UndirectedEdge[87, 421] -> 
             RGBColor[
              0.17915493384170816`, 0.30563357291947557`, 0.9335139804950874],
              UndirectedEdge[60, 192] -> 
             RGBColor[
              0.2736621188386635, 0.4049666164528918, 0.9388960248698129], 
             UndirectedEdge[84, 147] -> 
             RGBColor[
              0.24240373141068797`, 0.37211206936985763`, 0.93711590594843], 
             UndirectedEdge[431, 433] -> 
             RGBColor[
              0.3870230907643596, 0.509641681699111, 0.9458817470057914], 
             UndirectedEdge[201, 492] -> 
             RGBColor[
              0.29053904388296076`, 0.4227053347332997, 0.9398571407839125], 
             UndirectedEdge[86, 124] -> 
             RGBColor[
              0.9389228207101663, 0.7935781606519255, 0.2800166062249653], 
             UndirectedEdge[234, 239] -> 
             RGBColor[
              0.36975457999068184`, 0.4946845656075394, 0.9447814127692372], 
             UndirectedEdge[100, 450] -> 
             RGBColor[
              0.8744616680202064, 0.45105879141128646`, 0.21405151473609035`],
              UndirectedEdge[22, 275] -> 
             RGBColor[
              0.43256024452096153`, 0.549083675519183, 0.9487833341762382], 
             UndirectedEdge[160, 324] -> 
             RGBColor[
              0.3960795993510239, 0.5174859742435227, 0.9464588197245776], 
             UndirectedEdge[191, 218] -> 
             RGBColor[
              0.2251871593264507, 0.3540163605156067, 0.9361354476378685], 
             UndirectedEdge[349, 397] -> 
             RGBColor[
              0.38607476166702576`, 0.5088202866994067, 0.9458213203142838], 
             UndirectedEdge[401, 454] -> 
             RGBColor[
              0.8366674019364873, 0.7306087240183134, 0.6081129719353302], 
             UndirectedEdge[311, 349] -> 
             RGBColor[
              0.5802291691633081, 0.667416033439714, 0.9614893343765445], 
             UndirectedEdge[63, 324] -> 
             RGBColor[
              0.3945065223315428, 0.5161234539943981, 0.9463585846479137], 
             UndirectedEdge[22, 353] -> 
             RGBColor[
              0.5455395337034719, 0.641880966146923, 0.9573802823215901], 
             UndirectedEdge[93, 437] -> 
             RGBColor[
              0.26255787085876586`, 0.3932953477760335, 0.9382636543746206], 
             UndirectedEdge[417, 461] -> 
             RGBColor[
              0.8227440842305245, 0.8622334494485463, 0.9748712810946092], 
             UndirectedEdge[151, 249] -> 
             RGBColor[
              0.29817109629594896`, 0.43072710571942197`, 0.9402917748782225],
              UndirectedEdge[148, 452] -> 
             RGBColor[
              0.23180463347080354`, 0.3609717454134156, 0.9365123030007138], 
             UndirectedEdge[262, 424] -> 
             RGBColor[
              0.39834012297090404`, 0.5188257266580119, 0.9467736686621999], 
             UndirectedEdge[50, 139] -> 
             RGBColor[
              0.50248660335272, 0.6066441419253559, 0.9540696105134843], 
             UndirectedEdge[237, 267] -> 
             RGBColor[
              0.9475774996267206, 0.9513626199375382, 0.7014579081154306], 
             UndirectedEdge[256, 442] -> 
             RGBColor[
              0.28666573187167776`, 0.4186342382272755, 0.9396365613949216], 
             UndirectedEdge[60, 133] -> 
             RGBColor[
              0.31894163191943015`, 0.44919026900604586`, 0.9415979446419711],
              UndirectedEdge[77, 156] -> 
             RGBColor[
              0.5370635204917655, 0.6350513862279201, 0.9566987541430614], 
             UndirectedEdge[219, 498] -> 
             RGBColor[
              0.49407920545967077`, 0.6001547828635406, 0.9533148714070008], 
             UndirectedEdge[102, 185] -> 
             RGBColor[
              0.28024115314486164`, 0.4118815986435736, 0.9392706911407418], 
             UndirectedEdge[92, 169] -> 
             RGBColor[
              0.5509398864490034, 0.6463168452351683, 0.9577911525020184], 
             UndirectedEdge[53, 357] -> 
             RGBColor[
              0.9418272950686917, 0.8009948820936315, 0.3036989405074137], 
             UndirectedEdge[162, 289] -> 
             RGBColor[
              0.45070123455015054`, 0.5645598995943251, 0.9500046324572284], 
             UndirectedEdge[169, 204] -> 
             RGBColor[
              0.4973176178268257, 0.6027838719120118, 0.9535698110912385], 
             UndirectedEdge[176, 448] -> 
             RGBColor[
              0.587441960125221, 0.6759508730452015, 0.9606647294533119], 
             UndirectedEdge[377, 403] -> 
             RGBColor[
              0.9550085431684978, 0.9657910070072111, 0.9549749729457403], 
             UndirectedEdge[86, 357] -> 
             RGBColor[
              0.911167687629582, 0.6855165136042474, 0.2473816401856394], 
             UndirectedEdge[12, 373] -> 
             RGBColor[
              0.28300945147034123`, 0.414791255703904, 0.9394283416350475], 
             UndirectedEdge[200, 469] -> 
             RGBColor[
              0.8806293426662699, 0.5508475494204266, 0.22210653628922422`], 
             UndirectedEdge[112, 153] -> 
             RGBColor[
              0.24659824483285725`, 0.37652076892406894`, 0.9373547772825959],
              UndirectedEdge[166, 243] -> 
             RGBColor[
              0.838713260625803, 0.29857266219470613`, 0.18470516813663024`], 
             UndirectedEdge[394, 460] -> 
             RGBColor[
              0.23849436642390026`, 0.3680030789006874, 0.9368932733958195], 
             UndirectedEdge[18, 348] -> 
             RGBColor[
              0.9221477650002106, 0.7221653986171828, 0.2620020254952798], 
             UndirectedEdge[315, 325] -> 
             RGBColor[
              0.1822582683189515, 0.30889537421782864`, 0.9336907108025945], 
             UndirectedEdge[195, 447] -> 
             RGBColor[
              0.25832593618087096`, 0.38884731610940987`, 0.9380226519553008],
              UndirectedEdge[128, 204] -> 
             RGBColor[
              0.4983181319181479, 0.6035961343239933, 0.9536485752255113], 
             UndirectedEdge[91, 435] -> 
             RGBColor[
              0.29287326479962417`, 0.4234129007814571, 0.9400539952643586], 
             UndirectedEdge[158, 206] -> 
             RGBColor[
              0.3501277440364893, 0.4776847867774757, 0.9435308081375656], 
             UndirectedEdge[30, 290] -> 
             RGBColor[
              0.2772082322816696, 0.40869380651806936`, 0.9390979707843874], 
             UndirectedEdge[2, 250] -> 
             RGBColor[
              0.20844651025640323`, 0.33642087692453115`, 0.9351820924389003],
              UndirectedEdge[148, 195] -> 
             RGBColor[
              0.2549038837878154, 0.3852505220736551, 0.9378277711339891], 
             UndirectedEdge[5, 202] -> 
             RGBColor[
              0.23883220085490312`, 0.3683581643076115, 0.9369125125668838], 
             UndirectedEdge[220, 359] -> 
             RGBColor[
              0.3621822341604067, 0.48812578024652276`, 0.9442989095888945], 
             UndirectedEdge[175, 337] -> 
             RGBColor[
              0.9079704822927377, 0.9289384814961321, 0.9731750764283525], 
             UndirectedEdge[263, 447] -> 
             RGBColor[
              0.2599502995006695, 0.3905546249491011, 0.938115157043333], 
             UndirectedEdge[344, 387] -> 
             RGBColor[
              0.6194283934274943, 0.6998852662527452, 0.9645732255440658], 
             UndirectedEdge[82, 470] -> 
             RGBColor[
              0.25688036525862096`, 0.38732792941563493`, 0.937940328829809], 
             UndirectedEdge[273, 446] -> 
             RGBColor[
              0.26084634450324296`, 0.39149642505934035`, 0.9381661854806498],
              UndirectedEdge[68, 306] -> 
             RGBColor[
              0.8387829864974263, 0.2991086057980758, 0.18477193771004097`], 
             UndirectedEdge[21, 33] -> 
             RGBColor[
              0.9296510090196749, 0.7439907144053559, 0.3002556094938443], 
             UndirectedEdge[77, 479] -> 
             RGBColor[
              0.5091542746403608, 0.6112576931750507, 0.9548154361242309], 
             UndirectedEdge[253, 311] -> 
             RGBColor[
              0.8659443575362178, 0.8951239135712197, 0.9365639679939195], 
             UndirectedEdge[308, 386] -> 
             RGBColor[
              0.17893664238380538`, 0.3054041347567419, 0.9335015491194931], 
             UndirectedEdge[151, 280] -> 
             RGBColor[
              0.2818433506476452, 0.4135656098041881, 0.9393619339182866], 
             UndirectedEdge[305, 416] -> 
             RGBColor[
              0.2563227786802443, 0.3867418705687301, 0.9379085750990459], 
             UndirectedEdge[38, 189] -> 
             RGBColor[
              0.2598720197723208, 0.3904723479913851, 0.9381106991286081], 
             UndirectedEdge[277, 291] -> 
             RGBColor[
              0.7131143362098424, 0.7758096064076011, 0.9720402306671867], 
             UndirectedEdge[27, 40] -> 
             RGBColor[
              0.44915953688308596`, 0.5618645655130168, 0.9502821669769903], 
             UndirectedEdge[88, 167] -> 
             RGBColor[
              0.9266401906833595, 0.7379726928092079, 0.5404902319838795], 
             UndirectedEdge[89, 296] -> 
             RGBColor[
              0.2994607686458766, 0.4316505064958615, 0.9403810420835206], 
             UndirectedEdge[169, 340] -> 
             RGBColor[
              0.41508837309382146`, 0.5328799596159772, 0.9479658129994224], 
             UndirectedEdge[169, 363] -> 
             RGBColor[
              0.44877677089386697`, 0.5620591565622703, 0.9501124079177607], 
             UndirectedEdge[43, 378] -> 
             RGBColor[
              0.2881161193118442, 0.42015868738676554`, 0.939719158813983], 
             UndirectedEdge[350, 482] -> 
             RGBColor[
              0.36032571563534044`, 0.4865177572114446, 0.9441806138701323], 
             UndirectedEdge[199, 429] -> 
             RGBColor[
              0.318220922727511, 0.44864816272084596`, 0.9415490142958283], 
             UndirectedEdge[135, 216] -> 
             RGBColor[
              0.25825637493020664`, 0.38877420282452363`, 0.938018690544982], 
             UndirectedEdge[153, 351] -> 
             RGBColor[
              0.267489207183899, 0.39847849491853005`, 0.9385444866830785], 
             UndirectedEdge[207, 218] -> 
             RGBColor[
              0.22451796602725682`, 0.35331299592884813`, 0.9360973380694622],
              UndirectedEdge[218, 389] -> 
             RGBColor[
              0.22523636007401557`, 0.35406807362080495`, 0.9361382495476563],
              UndirectedEdge[421, 477] -> 
             RGBColor[
              0.21186411660990806`, 0.34001299789082284`, 0.9353767200648369],
              UndirectedEdge[171, 391] -> 
             RGBColor[
              0.25143472628896596`, 0.3816042175850748, 0.9376302077465881], 
             UndirectedEdge[25, 246] -> 
             RGBColor[
              0.3037983452782409, 0.43621369244109887`, 0.940627909879872], 
             UndirectedEdge[130, 254] -> 
             RGBColor[
              0.20771262472504887`, 0.3356495167000475, 0.935140298743576], 
             UndirectedEdge[65, 434] -> 
             RGBColor[
              0.9883337030612244, 0.9766308233101144, 0.5967468015081936], 
             UndirectedEdge[174, 430] -> 
             RGBColor[
              0.2531980668507343, 0.38345760031774234`, 0.9377306273829522], 
             UndirectedEdge[213, 454] -> 
             RGBColor[
              0.902044161930851, 0.6480872421427781, 0.23997558640884487`], 
             UndirectedEdge[52, 495] -> 
             RGBColor[
              0.8389987580384334, 0.3007671204139477, 0.18497856078138836`], 
             UndirectedEdge[26, 224] -> 
             RGBColor[
              0.34279791451999597`, 0.4704318560417961, 0.9430968651035153], 
             UndirectedEdge[8, 31] -> 
             RGBColor[
              0.5366659458722182, 0.6347210217205881, 0.9566695542776334], 
             UndirectedEdge[29, 321] -> 
             RGBColor[
              0.3713978817482214, 0.49610791099517215`, 0.944886122504113], 
             UndirectedEdge[319, 377] -> 
             RGBColor[
              0.8479973976544979, 0.8813126625416667, 0.9445427395689829], 
             UndirectedEdge[323, 447] -> 
             RGBColor[
              0.24292230663621342`, 0.3726571248114532, 0.9371454380403603], 
             UndirectedEdge[13, 340] -> 
             RGBColor[
              0.3170254114231826, 0.44789173278801986`, 0.9414626195505558], 
             UndirectedEdge[176, 237] -> 
             RGBColor[
              0.7565184993634433, 0.8098707472801487, 0.9765525722729846], 
             UndirectedEdge[22, 268] -> 
             RGBColor[
              0.4305356531895016, 0.5473300762667914, 0.9486543290068734], 
             UndirectedEdge[461, 493] -> 
             RGBColor[
              0.9690163833229786, 0.9733831615410689, 0.7606045943611018], 
             UndirectedEdge[401, 450] -> 
             RGBColor[
              0.7955804305647025, 0.4800334417304184, 0.5713225662708019], 
             UndirectedEdge[100, 200] -> 
             RGBColor[
              0.9160214299715226, 0.703780905297789, 0.25123642844933736`], 
             UndirectedEdge[197, 375] -> 
             RGBColor[
              0.8279135305907634, 0.8660284937370616, 0.9630673509377192], 
             UndirectedEdge[94, 401] -> 
             RGBColor[
              0.8644357283380311, 0.8946091728083778, 0.9692011064141851], 
             UndirectedEdge[118, 327] -> 
             RGBColor[
              0.2910886324434072, 0.42177019876942656`, 0.9399438296328053], 
             UndirectedEdge[44, 255] -> 
             RGBColor[
              0.44713138767076954`, 0.5605271620680575, 0.9500370874897843], 
             UndirectedEdge[148, 356] -> 
             RGBColor[
              0.2544968866209464, 0.384822742246165, 0.9378045932474341], 
             UndirectedEdge[26, 34] -> 
             RGBColor[
              0.46519130263863967`, 0.5748915338435057, 0.9515410249790447], 
             UndirectedEdge[244, 313] -> 
             RGBColor[
              0.3046994618698019, 0.43447349621750786`, 0.9407776233385161], 
             UndirectedEdge[331, 488] -> 
             RGBColor[
              0.8030279977952235, 0.8461858842867422, 0.9809661481473407], 
             UndirectedEdge[382, 429] -> 
             RGBColor[
              0.2879113316712099, 0.41994344259217253`, 0.9397074964608051], 
             UndirectedEdge[409, 496] -> 
             RGBColor[
              0.25922260246551676`, 0.38978976922649866`, 0.9380737157737123],
              UndirectedEdge[14, 324] -> 
             RGBColor[
              0.33821006500838097`, 0.4671770715883025, 0.9427782060023248], 
             UndirectedEdge[259, 471] -> 
             RGBColor[
              0.8593266411159032, 0.451612346510198, 0.20423296567103144`], 
             UndirectedEdge[178, 439] -> 
             RGBColor[
              0.9262985601874452, 0.9413808299607197, 0.8870332114673454], 
             UndirectedEdge[127, 454] -> 
             RGBColor[
              0.562931118749189, 0.49656039652436856`, 0.5871761845581333], 
             UndirectedEdge[190, 452] -> 
             RGBColor[
              0.2360315215156537, 0.3654144727487341, 0.9367530180217474], 
             UndirectedEdge[218, 295] -> 
             RGBColor[
              0.2307804101674582, 0.3598952217820915, 0.9364539749987908], 
             UndirectedEdge[35, 67] -> 
             RGBColor[
              0.24749774961125026`, 0.377466205478057, 0.9374060027490273], 
             UndirectedEdge[192, 249] -> 
             RGBColor[
              0.27208125411189216`, 0.40330502739244223`, 0.938805996962303], 
             UndirectedEdge[186, 202] -> 
             RGBColor[
              0.2373837352876954, 0.3668357351584549, 0.9368300245956442], 
             UndirectedEdge[243, 469] -> 
             RGBColor[
              0.8498683936659192, 0.3811298439450528, 0.19526257805333647`], 
             UndirectedEdge[48, 183] -> 
             RGBColor[
              0.20623910902756293`, 0.3341007582756985, 0.9350563842044752], 
             UndirectedEdge[255, 390] -> 
             RGBColor[
              0.3491694965791283, 0.4761158367358585, 0.9434968065582812], 
             UndirectedEdge[202, 497] -> 
             RGBColor[
              0.23752535161991525`, 0.36698458290261204`, 0.9368380894362616],
              UndirectedEdge[84, 365] -> 
             RGBColor[
              0.22514447908377305`, 0.3539715008744688, 0.9361330170611878], 
             UndirectedEdge[239, 262] -> 
             RGBColor[
              0.41350816527111056`, 0.531963522530478, 0.947740162904996], 
             UndirectedEdge[299, 456] -> 
             RGBColor[
              0.21641245264037934`, 0.34479358744000865`, 0.935635741073112], 
             UndirectedEdge[136, 253] -> 
             RGBColor[
              0.9769962544035893, 0.9822248956493935, 0.9175751236598007], 
             UndirectedEdge[338, 478] -> 
             RGBColor[
              0.29307363534810826`, 0.42431910359583813`, 0.9400399367228911],
              UndirectedEdge[284, 444] -> 
             RGBColor[
              0.25819284063858217`, 0.3887074242557196, 0.9380150723610645], 
             UndirectedEdge[135, 147] -> 
             RGBColor[
              0.2510599689447852, 0.3812103238553528, 0.9376088658702408], 
             UndirectedEdge[72, 73] -> 
             RGBColor[
              0.2509474629421924, 0.38109207291333524`, 0.9376024588198308], 
             UndirectedEdge[8, 291] -> 
             RGBColor[
              0.637610384777719, 0.7164873323549865, 0.9647458039813404], 
             UndirectedEdge[141, 240] -> 
             RGBColor[
              0.2831042170303842, 0.4148134850118461, 0.939436571482416], 
             UndirectedEdge[9, 466] -> 
             RGBColor[
              0.5393259259475076, 0.6368881088970959, 0.9568768589880016], 
             UndirectedEdge[78, 346] -> 
             RGBColor[
              0.21865587786091514`, 0.34715156958816623`, 0.9357635008205714],
              UndirectedEdge[255, 425] -> 
             RGBColor[
              0.38646418769848023`, 0.5091575879547311, 0.9458461341966522], 
             UndirectedEdge[297, 349] -> 
             RGBColor[
              0.4664828396818328, 0.5766724130185215, 0.9514403486819383], 
             UndirectedEdge[248, 478] -> 
             RGBColor[
              0.25429079969208646`, 0.3846061318172672, 0.9377928569017139], 
             UndirectedEdge[113, 130] -> 
             RGBColor[
              0.17905963034776856`, 0.3055334029047545, 0.9335085531020964], 
             UndirectedEdge[51, 179] -> 
             RGBColor[
              0.1789280689363169, 0.30539512351984355`, 0.9335010608743419], 
             UndirectedEdge[440, 470] -> 
             RGBColor[
              0.2685779731534025, 0.3996228569842277, 0.9386064902943567], 
             UndirectedEdge[5, 414] -> 
             RGBColor[
              0.2566326545868817, 0.38706756979387325`, 0.9379262220735086], 
             UndirectedEdge[148, 463] -> 
             RGBColor[
              0.25337660171868737`, 0.3836452517837254, 0.9377407946795635], 
             UndirectedEdge[63, 441] -> 
             RGBColor[
              0.4347339982883702, 0.5509664717764713, 0.9489218438441225], 
             UndirectedEdge[163, 187] -> 
             RGBColor[
              0.2658102034815037, 0.3967137555723293, 0.9384488699060904], 
             UndirectedEdge[120, 177] -> 
             RGBColor[
              0.20805903153131503`, 0.3360136122168933, 0.9351600260987298], 
             UndirectedEdge[450, 454] -> 
             RGBColor[
              0.8587954548220276, 0.3876960227591984, 0.20138137545633958`], 
             UndirectedEdge[15, 190] -> 
             RGBColor[
              0.24117420601353035`, 0.37081976022103225`, 0.9370458862959816],
              UndirectedEdge[191, 287] -> 
             RGBColor[
              0.21410654860741013`, 0.342369936098598, 0.9355044232497137], 
             UndirectedEdge[179, 292] -> 
             RGBColor[
              0.17894988462017136`, 0.30541805318676885`, 0.9335023032452641],
              UndirectedEdge[291, 297] -> 
             RGBColor[
              0.5871456749634538, 0.6755178075184964, 0.9607730371664382], 
             UndirectedEdge[289, 397] -> 
             RGBColor[
              0.39895955278042317`, 0.5199804451534001, 0.9466423278104561], 
             UndirectedEdge[175, 370] -> 
             RGBColor[
              0.7735868010178651, 0.822851827878325, 0.9604005134157099], 
             UndirectedEdge[23, 186] -> 
             RGBColor[
              0.22910595895914918`, 0.35813526739582024`, 0.9363586174796061],
              UndirectedEdge[241, 461] -> 
             RGBColor[
              0.8249688230204753, 0.8639714322998968, 0.9750930222658254], 
             UndirectedEdge[157, 216] -> 
             RGBColor[
              0.28421479544229167`, 0.41605814864164575`, 0.9394969841911034],
              UndirectedEdge[51, 302] -> 
             RGBColor[
              0.18453817957609825`, 0.31129170550381263`, 0.9338205483758626],
              UndirectedEdge[174, 390] -> 
             RGBColor[
              0.28370528761633407`, 0.41552262361190234`, 0.9394679684741645],
              UndirectedEdge[79, 406] -> 
             RGBColor[
              0.9922235479450122, 0.984612153776488, 0.4938632532617516], 
             UndirectedEdge[181, 235] -> 
             RGBColor[
              0.38886946031407776`, 0.511240914201845, 0.9459993960408191], 
             UndirectedEdge[78, 404] -> 
             RGBColor[
              0.2164387033219317, 0.3448211785707095, 0.935637236010592], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.2711970471587578, 0.4023756698227392, 0.938755642684389], 
             UndirectedEdge[43, 384] -> 
             RGBColor[
              0.28848430619933074`, 0.4205456751499109, 0.9397401265125418], 
             UndirectedEdge[101, 363] -> 
             RGBColor[
              0.4628220425559936, 0.5734617408298626, 0.9512181031525286], 
             UndirectedEdge[120, 455] -> 
             RGBColor[
              0.2056810719300792, 0.33351422590464763`, 0.9350246048173154], 
             UndirectedEdge[295, 456] -> 
             RGBColor[
              0.22662320577002346`, 0.355525736378405, 0.9362172283583896], 
             UndirectedEdge[58, 240] -> 
             RGBColor[
              0.2858686487739417, 0.41720789684373627`, 0.9396127186286245], 
             UndirectedEdge[39, 471] -> 
             RGBColor[
              0.7402370852900231, 0.5715237918221177, 0.5827765854569318], 
             UndirectedEdge[54, 365] -> 
             RGBColor[
              0.22284773098411328`, 0.35155747299948614`, 0.9360022206546466],
              UndirectedEdge[169, 334] -> 
             RGBColor[
              0.44777313143376407`, 0.5611898545063152, 0.9500484568988465], 
             UndirectedEdge[18, 65] -> 
             RGBColor[
              0.9349243740088637, 0.7652639008938271, 0.3116367388337401], 
             UndirectedEdge[384, 435] -> 
             RGBColor[
              0.2709692417504848, 0.4021362318949472, 0.9387426695033958], 
             UndirectedEdge[9, 360] -> 
             RGBColor[
              0.5772550006439877, 0.6676806404210414, 0.9598627746868871], 
             UndirectedEdge[135, 171] -> 
             RGBColor[
              0.25618449679905386`, 0.3865965275440213, 0.9379007001504819], 
             UndirectedEdge[149, 187] -> 
             RGBColor[
              0.30925143443909986`, 0.4382007802607746, 0.9410755580672832], 
             UndirectedEdge[271, 464] -> 
             RGBColor[
              0.24983604138275278`, 0.37992389838616725`, 0.9375391650062217],
              UndirectedEdge[21, 348] -> 
             RGBColor[
              0.9703996877499586, 0.911813337676092, 0.3395088057688662], 
             UndirectedEdge[1, 70] -> 
             RGBColor[
              0.26220782647507634`, 0.3929274289346799, 0.9382437198648137], 
             UndirectedEdge[52, 276] -> 
             RGBColor[
              0.7276676005214341, 0.4890758052767825, 0.5725511491543327], 
             UndirectedEdge[58, 429] -> 
             RGBColor[
              0.3043548555603097, 0.4366380722694161, 0.9406654807572159], 
             UndirectedEdge[243, 495] -> 
             RGBColor[
              0.8407542903650291, 0.31426091115533294`, 0.1866596605199266], 
             UndirectedEdge[131, 135] -> 
             RGBColor[
              0.25711790914467114`, 0.38757760310102596`, 0.937953856602705], 
             UndirectedEdge[145, 430] -> 
             RGBColor[
              0.23019859628253192`, 0.35928369849990305`, 0.9364208415587607],
              UndirectedEdge[291, 419] -> 
             RGBColor[
              0.583808838050422, 0.6728088129897074, 0.960510349141408], 
             UndirectedEdge[151, 260] -> 
             RGBColor[
              0.2961853765948359, 0.4286399884116514, 0.940178691078853], 
             UndirectedEdge[189, 437] -> 
             RGBColor[
              0.25780291323833093`, 0.38829758583523044`, 0.9379928665724662],
              UndirectedEdge[196, 354] -> 
             RGBColor[
              0.32873158920795986`, 0.45794625952520507`, 0.9422116309155903],
              UndirectedEdge[340, 355] -> 
             RGBColor[
              0.3330706823231735, 0.4629108172342508, 0.9424439472481606], 
             UndirectedEdge[58, 310] -> 
             RGBColor[
              0.3059344073310527, 0.43829828132983367`, 0.9407554338938223], 
             UndirectedEdge[261, 500] -> 
             RGBColor[
              0.8497397394109806, 0.34938235459205963`, 0.19393494909850834`],
              UndirectedEdge[237, 270] -> 
             RGBColor[
              0.9480577404464491, 0.9590498999175098, 0.9029559373872008], 
             UndirectedEdge[23, 497] -> 
             RGBColor[
              0.22924757529136902`, 0.3582841151399774, 0.9363666823202235], 
             UndirectedEdge[431, 462] -> 
             RGBColor[
              0.4562091477173884, 0.5692804281616477, 0.9503694481270373], 
             UndirectedEdge[108, 129] -> 
             RGBColor[
              0.3203552344901264, 0.4497120899906687, 0.9417137426958612], 
             UndirectedEdge[376, 485] -> 
             RGBColor[
              0.26372814560153673`, 0.3945253807303899, 0.938330299789955], 
             UndirectedEdge[124, 261] -> 
             RGBColor[
              0.9213196831594281, 0.7168052052597729, 0.265491517223669], 
             UndirectedEdge[63, 158] -> 
             RGBColor[
              0.38842846253649266`, 0.5108589440920934, 0.9459712960523903], 
             UndirectedEdge[66, 427] -> 
             RGBColor[
              0.271390600085227, 0.40257910622042264`, 0.9387666652372155], 
             UndirectedEdge[66, 208] -> 
             RGBColor[
              0.2926997987840062, 0.4237400438284219, 0.9400254625551399], 
             UndirectedEdge[54, 230] -> 
             RGBColor[
              0.22629940994459397`, 0.3551854064360376, 0.9361987886651444], 
             UndirectedEdge[186, 295] -> 
             RGBColor[
              0.23264914651192115`, 0.36185938216484964`, 0.9365603967690603],
              UndirectedEdge[245, 394] -> 
             RGBColor[
              0.22510267482771082`, 0.3539275619508045, 0.936130636370649], 
             UndirectedEdge[49, 459] -> 
             RGBColor[
              0.44038041665413563`, 0.554855283237734, 0.9495584378871766], 
             UndirectedEdge[55, 365] -> 
             RGBColor[
              0.21422616460620378`, 0.3424956600974225, 0.935511235203889], 
             UndirectedEdge[197, 448] -> 
             RGBColor[
              0.6327824685500147, 0.7119137261765637, 0.9648129350991647], 
             UndirectedEdge[185, 321] -> 
             RGBColor[
              0.30856010126890854`, 0.43938793879419913`, 0.9409661143099544],
              UndirectedEdge[242, 339] -> 
             RGBColor[
              0.21834915626655288`, 0.34682918574521915`, 0.9357460334795263],
              UndirectedEdge[186, 191] -> 
             RGBColor[
              0.22705589567091367`, 0.35598052089836485`, 0.936241869408138], 
             UndirectedEdge[218, 456] -> 
             RGBColor[
              0.2278157330596809, 0.3567791581704322, 0.9362851410233497], 
             UndirectedEdge[63, 182] -> 
             RGBColor[
              0.3989611276124065, 0.5199818091937107, 0.9466424281573576], 
             UndirectedEdge[133, 181] -> 
             RGBColor[
              0.3829354312034995, 0.5061011564392373, 0.9456212849531489], 
             UndirectedEdge[11, 186] -> 
             RGBColor[
              0.23731427099118235`, 0.3667627237785289, 0.936826068706721], 
             UndirectedEdge[105, 148] -> 
             RGBColor[
              0.24278055645410443`, 0.37250813638257607`, 0.9371373655771897],
              UndirectedEdge[235, 393] -> 
             RGBColor[
              0.40912660425444114`, 0.5285723075143651, 0.947349382422311], 
             UndirectedEdge[110, 290] -> 
             RGBColor[
              0.2791002706073135, 0.4106824587604797, 0.9392057195680129], 
             UndirectedEdge[225, 296] -> 
             RGBColor[
              0.29383455667092717`, 0.42573700098774714`, 0.940060637634782], 
             UndirectedEdge[38, 93] -> 
             RGBColor[
              0.2646269773927557, 0.3954701099321881, 0.9383814869307624], 
             UndirectedEdge[80, 486] -> 
             RGBColor[
              0.8622352558727102, 0.8932330485230531, 0.9866566699988166], 
             UndirectedEdge[471, 500] -> 
             RGBColor[
              0.8381526226622067, 0.29426335313338325`, 0.18416830058954048`],
              UndirectedEdge[200, 213] -> 
             RGBColor[
              0.9025169525103827, 0.6502340737413859, 0.24037009445756363`], 
             UndirectedEdge[191, 295] -> 
             RGBColor[
              0.22399463203679326`, 0.35276293872357944`, 0.9360675349729086],
              UndirectedEdge[295, 300] -> 
             RGBColor[
              0.22777276498654234`, 0.3567339960012304, 0.9362826940551499], 
             UndirectedEdge[191, 451] -> 
             RGBColor[
              0.21492359957141377`, 0.343228708465789, 0.9355509530933952], 
             UndirectedEdge[137, 145] -> 
             RGBColor[
              0.2203693542453783, 0.34895254190891456`, 0.9358610807658054], 
             UndirectedEdge[332, 344] -> 
             RGBColor[
              0.4329675168621825, 0.5491533716913533, 0.9488874962659426], 
             UndirectedEdge[76, 392] -> 
             RGBColor[
              0.35866334703698777`, 0.48482413936361163`, 0.9440839805262493],
              UndirectedEdge[157, 465] -> 
             RGBColor[
              0.2925845958094424, 0.42485533950351484`, 0.9399736319400027], 
             UndirectedEdge[204, 337] -> 
             RGBColor[
              0.6810518757467315, 0.7489355468683991, 0.970229432274497], 
             UndirectedEdge[112, 395] -> 
             RGBColor[
              0.2566255492107321, 0.38706010159303317`, 0.9379258174328484], 
             UndirectedEdge[51, 107] -> 
             RGBColor[
              0.18179934664985797`, 0.3084130184462969, 0.9336645758924533], 
             UndirectedEdge[5, 41] -> 
             RGBColor[
              0.23556700835298144`, 0.36492623996293, 0.9367265646843188], 
             UndirectedEdge[88, 210] -> 
             RGBColor[
              0.8513369203215293, 0.3826983248089265, 0.19628825904818903`], 
             UndirectedEdge[248, 411] -> 
             RGBColor[
              0.2410648104835609, 0.37070477858295714`, 0.937039656382386], 
             UndirectedEdge[101, 128] -> 
             RGBColor[
              0.5077879700548952, 0.6112841755347511, 0.9543940755727961], 
             UndirectedEdge[298, 418] -> 
             RGBColor[
              0.9400566522436402, 0.9539366372768199, 0.955901674523727], 
             UndirectedEdge[1, 391] -> 
             RGBColor[
              0.25364635844324135`, 0.38392878320479584`, 0.9377561569259576],
              UndirectedEdge[116, 327] -> 
             RGBColor[
              0.25289755432094124`, 0.38314174259533496`, 0.937713513638949], 
             UndirectedEdge[79, 81] -> 
             RGBColor[
              0.9087234308797807, 0.9257016701540246, 0.7763552620147077], 
             UndirectedEdge[254, 368] -> 
             RGBColor[
              0.32229994971598047`, 0.44690195182710835`, 0.9420022258236223],
              UndirectedEdge[4, 318] -> 
             RGBColor[
              0.33312298494508064`, 0.46295611913654056`, 0.9424472799249791],
              UndirectedEdge[352, 412] -> 
             RGBColor[
              0.23510619043035305`, 0.36444189110870373`, 0.9367003217853442],
              UndirectedEdge[239, 424] -> 
             RGBColor[
              0.3357624743157177, 0.4652423121647933, 0.9426154658536674], 
             UndirectedEdge[58, 188] -> 
             RGBColor[
              0.32619444448890195`, 0.45695496563196736`, 0.9420057994537792],
              UndirectedEdge[407, 408] -> 
             RGBColor[
              0.2184314377890148, 0.3469156688422765, 0.9357507192905059], 
             UndirectedEdge[255, 466] -> 
             RGBColor[
              0.45054684949746193`, 0.5632999878437683, 0.9503059651560305], 
             UndirectedEdge[197, 489] -> 
             RGBColor[
              0.843861608566709, 0.8769414103999965, 0.8921342396544271], 
             UndirectedEdge[50, 363] -> 
             RGBColor[
              0.422874692158388, 0.5406945368727382, 0.9481661793442926], 
             UndirectedEdge[57, 175] -> 
             RGBColor[
              0.7784866261079177, 0.8268297266210345, 0.9607862455954495], 
             UndirectedEdge[278, 486] -> 
             RGBColor[
              0.9416456695144926, 0.9559801240610102, 0.9829731602176706], 
             UndirectedEdge[82, 263] -> 
             RGBColor[
              0.26583963752085393`, 0.39674469261391226`, 0.9384505461310877],
              UndirectedEdge[41, 186] -> 
             RGBColor[
              0.23411854278577374`, 0.36340381081377343`, 0.9366440767130793],
              UndirectedEdge[390, 425] -> 
             RGBColor[
              0.3380481584260487, 0.4664830926023694, 0.94278816472538], 
             UndirectedEdge[218, 458] -> 
             RGBColor[
              0.23123609658963368`, 0.36037417710398584`, 0.936479925666406], 
             UndirectedEdge[230, 374] -> 
             RGBColor[
              0.23780417240741958`, 0.3672776412285381, 0.9368539678676315], 
             UndirectedEdge[104, 408] -> 
             RGBColor[
              0.23453910043567894`, 0.36384584356871885`, 0.9366680268490819],
              UndirectedEdge[121, 213] -> 
             RGBColor[
              0.86583591956703, 0.4350120088827739, 0.20785705715207875`], 
             UndirectedEdge[143, 421] -> 
             RGBColor[
              0.1789918035644768, 0.3054621126550484, 0.9335046904671287], 
             UndirectedEdge[185, 482] -> 
             RGBColor[
              0.32121309396000997`, 0.4503473251053272, 0.9417723518156291], 
             UndirectedEdge[256, 333] -> 
             RGBColor[
              0.3340176365315557, 0.4619410698643276, 0.9425698252260324], 
             UndirectedEdge[351, 463] -> 
             RGBColor[
              0.27857140569147526`, 0.4101265882019613, 0.9391756014934415], 
             UndirectedEdge[42, 411] -> 
             RGBColor[
              0.23603211668449622`, 0.3654150983089235, 0.9367530519157325], 
             UndirectedEdge[52, 243] -> 
             RGBColor[
              0.837550577025578, 0.2896357665521757, 0.18359178100799164`], 
             UndirectedEdge[385, 391] -> 
             RGBColor[
              0.23729940724147955`, 0.36674710103517516`, 0.9368252222381643],
              UndirectedEdge[366, 435] -> 
             RGBColor[
              0.2615619901606841, 0.3922486140198663, 0.9382069404421383], 
             UndirectedEdge[114, 419] -> 
             RGBColor[
              0.5066845097134336, 0.6103883367192307, 0.9543072071326079], 
             UndirectedEdge[67, 391] -> 
             RGBColor[
              0.24887514925956578`, 0.37891393984061833`, 0.9374844436213188],
              UndirectedEdge[310, 327] -> 
             RGBColor[
              0.2769131154519483, 0.40838362001854456`, 0.939081164317521], 
             UndirectedEdge[309, 348] -> 
             RGBColor[
              0.976471187338104, 0.9319682118150352, 0.39079228120582354`], 
             UndirectedEdge[28, 194] -> 
             RGBColor[
              0.9756860818103763, 0.9810011844305191, 0.9087502503850045], 
             UndirectedEdge[92, 337] -> 
             RGBColor[
              0.7346741443689091, 0.7924685201915558, 0.974450773685277], 
             UndirectedEdge[205, 432] -> 
             RGBColor[
              0.9462255159241673, 0.9556033712696023, 0.7798152269955922], 
             UndirectedEdge[314, 398] -> 
             RGBColor[
              0.29561326424229706`, 0.426066606556162, 0.9402183167389095], 
             UndirectedEdge[235, 453] -> 
             RGBColor[
              0.32067427818872773`, 0.4499141070194098, 0.9417367931922191], 
             UndirectedEdge[92, 334] -> 
             RGBColor[
              0.505970833581321, 0.6084373708863062, 0.9546299931971096], 
             UndirectedEdge[35, 54] -> 
             RGBColor[
              0.23354661261843296`, 0.36280267594543125`, 0.936611506136144], 
             UndirectedEdge[191, 456] -> 
             RGBColor[
              0.22102995492901595`, 0.34964687511192016`, 0.9358987009974674],
              UndirectedEdge[78, 137] -> 
             RGBColor[
              0.21975482034818994`, 0.34830662781927, 0.9358260839694819], 
             UndirectedEdge[57, 169] -> 
             RGBColor[
              0.5469925860365322, 0.6431122489364671, 0.9574804065541109], 
             UndirectedEdge[343, 392] -> 
             RGBColor[
              0.29944445035868683`, 0.4320654815746701, 0.9403642905083368], 
             UndirectedEdge[24, 197] -> 
             RGBColor[
              0.7672988184851579, 0.8182762435725834, 0.9774043962108645], 
             UndirectedEdge[450, 471] -> 
             RGBColor[
              0.8372605332410615, 0.2874063629263848, 0.183314034752381], 
             UndirectedEdge[150, 267] -> 
             RGBColor[
              0.9052536312416688, 0.5703031723537458, 0.2900897268509228], 
             UndirectedEdge[40, 371] -> 
             RGBColor[
              0.37457203795785354`, 0.49885720556622565`, 0.9450883769309946],
              UndirectedEdge[217, 362] -> 
             RGBColor[
              0.35409065029754605`, 0.481117256999343, 0.9437833210202597], 
             UndirectedEdge[229, 478] -> 
             RGBColor[
              0.27850887095594073`, 0.41006086022998334`, 0.9391720402327646],
              UndirectedEdge[100, 168] -> 
             RGBColor[
              0.9210035362936968, 0.7245123759551941, 0.25529579489782767`], 
             UndirectedEdge[221, 297] -> 
             RGBColor[
              0.5279871450253872, 0.627682775738259, 0.9559842286184892], 
             UndirectedEdge[50, 338] -> 
             RGBColor[
              0.3805216773222415, 0.5040104841460892, 0.9454674826902338], 
             UndirectedEdge[5, 186] -> 
             RGBColor[
              0.23715887571324926`, 0.36659939348879156`, 0.9368172191755294],
              UndirectedEdge[147, 391] -> 
             RGBColor[
              0.24631019843469731`, 0.37621801389640636`, 0.9373383734663472],
              UndirectedEdge[24, 426] -> 
             RGBColor[
              0.8535732035252862, 0.8860801191364223, 0.9858957682176778], 
             UndirectedEdge[100, 127] -> 
             RGBColor[
              0.5785973319473678, 0.5599231651764567, 0.5998463238378839], 
             UndirectedEdge[418, 432] -> 
             RGBColor[
              0.9385489798096075, 0.9527344602026001, 0.9557578713810538], 
             UndirectedEdge[200, 259] -> 
             RGBColor[
              0.8813343532764009, 0.5540488379416193, 0.22269481442370878`], 
             UndirectedEdge[17, 293] -> 
             RGBColor[
              0.9171217844286204, 0.9362730779745756, 0.9753514321588153], 
             UndirectedEdge[269, 468] -> 
             RGBColor[
              0.4636581822326119, 0.5753387348931303, 0.9509528669224259], 
             UndirectedEdge[154, 390] -> 
             RGBColor[
              0.30514733542854805`, 0.43798605336538, 0.9406917533770347], 
             UndirectedEdge[162, 439] -> 
             RGBColor[
              0.6614719504889517, 0.7330346033014116, 0.9686938737233264], 
             UndirectedEdge[103, 304] -> 
             RGBColor[
              0.4094598762170423, 0.5283411604549934, 0.947514243402197], 
             UndirectedEdge[3, 480] -> 
             RGBColor[
              0.4076066344287682, 0.5272434439758863, 0.9472559414401728], 
             UndirectedEdge[358, 404] -> 
             RGBColor[
              0.21953726017780179`, 0.34807795828608057`, 0.9358136942396298],
              UndirectedEdge[3, 439] -> 
             RGBColor[
              0.6612892589149015, 0.732886286051436, 0.9686794915733958], 
             UndirectedEdge[336, 458] -> 
             RGBColor[
              0.22636890121139194`, 0.35525844616344304`, 0.9362027460899854],
              UndirectedEdge[212, 287] -> 
             RGBColor[
              0.21416398383706822`, 0.3424303041665726, 0.9355076941010749], 
             UndirectedEdge[190, 195] -> 
             RGBColor[
              0.25913077183266553`, 0.38969324940897365`, 0.9380684861550228],
              UndirectedEdge[253, 377] -> 
             RGBColor[
              0.9830684787672088, 0.9867535506374262, 0.9072964317019494], 
             UndirectedEdge[192, 327] -> 
             RGBColor[
              0.25584189976103616`, 0.38623643633515786`, 0.9378811897559938],
              UndirectedEdge[151, 483] -> 
             RGBColor[
              0.3017217477257488, 0.43445906549644486`, 0.9404939792244313], 
             UndirectedEdge[38, 163] -> 
             RGBColor[
              0.2634804930859057, 0.3942650822343853, 0.9383161963455589], 
             UndirectedEdge[88, 227] -> 
             RGBColor[
              0.8561206468687188, 0.41946814329296433`, 0.20086916099222407`],
              UndirectedEdge[281, 343] -> 
             RGBColor[
              0.26889808498261325`, 0.3999593148129905, 0.9386247201894673], 
             UndirectedEdge[76, 157] -> 
             RGBColor[
              0.35693445553108405`, 0.4830069647728541, 0.9439855227126539], 
             UndirectedEdge[364, 437] -> 
             RGBColor[
              0.25719856867599794`, 0.38766238138256004`, 0.9379584500436889],
              UndirectedEdge[229, 244] -> 
             RGBColor[
              0.3167084139494082, 0.447095666264713, 0.9414615153937971], 
             UndirectedEdge[154, 425] -> 
             RGBColor[
              0.3424420265478999, 0.47102780458425264`, 0.9430410810154058], 
             UndirectedEdge[128, 355] -> 
             RGBColor[
              0.4117250076221206, 0.5299124488854325, 0.9477665145867664], 
             UndirectedEdge[58, 382] -> 
             RGBColor[
              0.2986682199237062, 0.43066105766182183`, 0.9403416352703349], 
             UndirectedEdge[45, 179] -> 
             RGBColor[
              0.2308558043838454, 0.3599744658837838, 0.9364582685878783], 
             UndirectedEdge[181, 296] -> 
             RGBColor[
              0.3670585086059648, 0.49234936408258523`, 0.9446096214846453], 
             UndirectedEdge[350, 354] -> 
             RGBColor[
              0.36196691822383753`, 0.4879392844043602, 0.9442851898478128], 
             UndirectedEdge[318, 335] -> 
             RGBColor[
              0.3093572475376726, 0.43941523304457686`, 0.9410411890738053], 
             UndirectedEdge[354, 372] -> 
             RGBColor[
              0.416108457877265, 0.5343687074376324, 0.9478635928798225], 
             UndirectedEdge[44, 57] -> 
             RGBColor[
              0.5489601186307986, 0.6447095805328258, 0.9576352979272409], 
             UndirectedEdge[257, 420] -> 
             RGBColor[
              0.9137481314322007, 0.7140513423503487, 0.5709499365964574], 
             UndirectedEdge[84, 171] -> 
             RGBColor[
              0.2475282592649566, 0.3774982730585261, 0.9374077402286709], 
             UndirectedEdge[376, 497] -> 
             RGBColor[
              0.25772437162935435`, 0.38821503362437043`, 0.9379883937440268],
              UndirectedEdge[164, 443] -> 
             RGBColor[
              0.8760183447320038, 0.45688851313920237`, 0.21528999668843654`],
              UndirectedEdge[2, 54] -> 
             RGBColor[
              0.22058424144202293`, 0.3491784019772233, 0.9358733182737572], 
             UndirectedEdge[165, 324] -> 
             RGBColor[
              0.3968553526992069, 0.5181578928032218, 0.9465082500419522], 
             UndirectedEdge[82, 395] -> 
             RGBColor[
              0.26163309800222595`, 0.39232335286982434`, 0.9382109899285194],
              UndirectedEdge[298, 420] -> 
             RGBColor[
              0.9351413217232607, 0.9502707918228358, 0.9642220469712115], 
             UndirectedEdge[163, 437] -> 
             RGBColor[
              0.26141138655191587`, 0.3920903200782306, 0.9381983637894169], 
             UndirectedEdge[156, 372] -> 
             RGBColor[
              0.46888111877498084`, 0.5796978409320405, 0.951331185719549], 
             UndirectedEdge[272, 317] -> 
             RGBColor[
              0.8519916278011412, 0.36132246904964216`, 0.1958811278335439], 
             UndirectedEdge[282, 441] -> 
             RGBColor[
              0.5288953957407483, 0.628333638126909, 0.9560796286709814], 
             UndirectedEdge[209, 423] -> 
             RGBColor[
              0.37687473184245884`, 0.48661428775252374`, 0.9464892509185017],
              UndirectedEdge[222, 333] -> 
             RGBColor[
              0.41068141899913524`, 0.5301333365139219, 0.9473892347606732], 
             UndirectedEdge[125, 455] -> 
             RGBColor[
              0.20630711262003382`, 0.3341722343630622, 0.9350602569084642], 
             UndirectedEdge[343, 433] -> 
             RGBColor[
              0.3091968798489231, 0.4407663035487692, 0.9409764153784905], 
             UndirectedEdge[29, 77] -> 
             RGBColor[
              0.5082190929851442, 0.6104476858288989, 0.9547558471761093], 
             UndirectedEdge[298, 353] -> 
             RGBColor[
              0.7706511770330843, 0.8213765109750578, 0.9776280646137345], 
             UndirectedEdge[65, 337] -> 
             RGBColor[
              0.9228377639355362, 0.92700213552959, 0.6922814441739551], 
             UndirectedEdge[93, 364] -> 
             RGBColor[
              0.2639259772143767, 0.39473331429873343`, 0.9383415660076406], 
             UndirectedEdge[170, 328] -> 
             RGBColor[
              0.3409967871765409, 0.4686604793300483, 0.9429898367152708], 
             UndirectedEdge[13, 244] -> 
             RGBColor[
              0.3195286449146627, 0.4500599078221664, 0.9416221233751105], 
             UndirectedEdge[114, 291] -> 
             RGBColor[
              0.577802812280651, 0.6679328507014297, 0.9600375327920143], 
             UndirectedEdge[198, 373] -> 
             RGBColor[
              0.28774746699468884`, 0.4197712104275283, 0.9396981646098933], 
             UndirectedEdge[54, 84] -> 
             RGBColor[
              0.23101754524273913`, 0.3601444657814439, 0.9364674794905181], 
             UndirectedEdge[1, 385] -> 
             RGBColor[
              0.2498185382943033, 0.379905501530447, 0.937538168231228], 
             UndirectedEdge[97, 294] -> 
             RGBColor[
              0.23502362506905988`, 0.3643551096790384, 0.936695619810163], 
             UndirectedEdge[83, 489] -> 
             RGBColor[
              0.9554216482771469, 0.9649073806371287, 0.9030373799764648], 
             UndirectedEdge[349, 359] -> 
             RGBColor[
              0.3995263663781553, 0.520471390602876, 0.94667844467169], 
             UndirectedEdge[47, 55] -> 
             RGBColor[
              0.22170565849658444`, 0.35035708240351526`, 0.9359371813160265],
              UndirectedEdge[166, 309] -> 
             RGBColor[
              0.9155755884315661, 0.6407588014939913, 0.33347870741883034`], 
             UndirectedEdge[196, 482] -> 
             RGBColor[
              0.3270903866194627, 0.45652473233228946`, 0.9421070549379097], 
             UndirectedEdge[114, 311] -> 
             RGBColor[
              0.6237676761079407, 0.7038409516692123, 0.9646188808522442], 
             UndirectedEdge[101, 169] -> 
             RGBColor[
              0.506787455963573, 0.6104719131227696, 0.9543153114385234], 
             UndirectedEdge[160, 353] -> 
             RGBColor[
              0.531072144514868, 0.6293500407838779, 0.9564584330755022], 
             UndirectedEdge[80, 329] -> 
             RGBColor[
              0.8360503988309712, 0.8723539542869803, 0.9841591349586778], 
             UndirectedEdge[130, 386] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[216, 238] -> 
             RGBColor[
              0.29301995095784455`, 0.42425818517520597`, 0.9400370439768699],
              UndirectedEdge[240, 382] -> 
             RGBColor[
              0.26942512488484194`, 0.40051326716649266`, 0.9386547343322136],
              UndirectedEdge[424, 470] -> 
             RGBColor[
              0.28803826967359597`, 0.4189813939860375, 0.9397548358601392], 
             UndirectedEdge[184, 225] -> 
             RGBColor[
              0.2656405828545585, 0.396535473538841, 0.9384392102623171], 
             UndirectedEdge[169, 274] -> 
             RGBColor[
              0.4777382226320348, 0.5868884368511786, 0.9520284493798168], 
             UndirectedEdge[345, 375] -> 
             RGBColor[
              0.8089633164388916, 0.8512244424146573, 0.9611785706908804], 
             UndirectedEdge[326, 434] -> 
             RGBColor[
              0.9331890448533395, 0.7583565146768234, 0.5065076494810187], 
             UndirectedEdge[59, 105] -> 
             RGBColor[
              0.2440481876886619, 0.3738404971825583, 0.9372095553007055], 
             UndirectedEdge[90, 306] -> 
             RGBColor[
              0.8611746456929213, 0.4612099603827511, 0.20582221997608346`], 
             UndirectedEdge[44, 466] -> 
             RGBColor[
              0.5000927113166715, 0.6050368178236056, 0.9537882766162615], 
             UndirectedEdge[88, 434] -> 
             RGBColor[
              0.9289063525023188, 0.7389098089590498, 0.5029340660049313], 
             UndirectedEdge[174, 356] -> 
             RGBColor[
              0.2679975194043914, 0.3990127632911238, 0.938573434312055], 
             UndirectedEdge[65, 88] -> 
             RGBColor[
              0.9260374771709088, 0.7249105779401631, 0.30422129427437533`], 
             UndirectedEdge[82, 195] -> 
             RGBColor[
              0.2642152742010554, 0.39503738377422104`, 0.9383580410430554], 
             UndirectedEdge[150, 413] -> 
             RGBColor[
              0.8976403406773998, 0.5446217555948332, 0.26051353065802335`], 
             UndirectedEdge[156, 307] -> 
             RGBColor[
              0.4685593666518582, 0.5794366280637215, 0.9513058562137999], 
             UndirectedEdge[245, 460] -> 
             RGBColor[
              0.23495456172986623`, 0.36428251973067727`, 0.936691686755166], 
             UndirectedEdge[101, 204] -> 
             RGBColor[
              0.5113628894889524, 0.6141864561796039, 0.9546755063260064], 
             UndirectedEdge[210, 428] -> 
             RGBColor[
              0.8331986050247592, 0.2561846027075905, 0.17942432770515804`], 
             UndirectedEdge[25, 76] -> 
             RGBColor[
              0.36235029179287925`, 0.48827134332094824`, 0.9443096180726283],
              UndirectedEdge[130, 421] -> 
             RGBColor[
              0.17899180289058533`, 0.3054621119467458, 0.9335046904287516], 
             UndirectedEdge[79, 493] -> 
             RGBColor[
              0.9937029879453217, 0.9889396528776512, 0.5559872823811043], 
             UndirectedEdge[194, 490] -> 
             RGBColor[
              0.9885348242076832, 0.9895268694153684, 0.8396711640099095], 
             UndirectedEdge[214, 347] -> 
             RGBColor[
              0.1893670574265447, 0.316367162293171, 0.9340955458257609], 
             UndirectedEdge[41, 202] -> 
             RGBColor[
              0.2357918679274276, 0.3651625816325934, 0.9367393701044336], 
             UndirectedEdge[85, 97] -> 
             RGBColor[
              0.22297503114412753`, 0.3516912735389574, 0.9360094702104356], 
             UndirectedEdge[31, 114] -> 
             RGBColor[
              0.47685837337515014`, 0.5861665400670314, 0.9519612830883075], 
             UndirectedEdge[247, 425] -> 
             RGBColor[
              0.4351771155351065, 0.550218204604259, 0.9492628740426365], 
             UndirectedEdge[35, 281] -> 
             RGBColor[
              0.2416405448941051, 0.37130991195210916`, 0.9370724436053437], 
             UndirectedEdge[157, 288] -> 
             RGBColor[
              0.2793047597177943, 0.4108973897809534, 0.9392173649203402], 
             UndirectedEdge[208, 427] -> 
             RGBColor[
              0.3008093263098471, 0.4322636714318231, 0.9404872881507658], 
             UndirectedEdge[154, 313] -> 
             RGBColor[
              0.2882495492104231, 0.42022540866860447`, 0.9397294494499471], 
             UndirectedEdge[189, 364] -> 
             RGBColor[
              0.25917101959394173`, 0.3897355523579304, 0.9380707782054862], 
             UndirectedEdge[314, 373] -> 
             RGBColor[
              0.3118454823562334, 0.44312769697598026`, 0.9411427175470836], 
             UndirectedEdge[156, 232] -> 
             RGBColor[
              0.4117533959329014, 0.5306819361106889, 0.9475625057353367], 
             UndirectedEdge[321, 383] -> 
             RGBColor[
              0.3310589867507921, 0.46116838764021345`, 0.942315763785161], 
             UndirectedEdge[15, 323] -> 
             RGBColor[
              0.2367917298527569, 0.36621349991102203`, 0.936796310761918], 
             UndirectedEdge[225, 235] -> 
             RGBColor[
              0.31564550837904015`, 0.44462855110700683`, 0.9414504121909557],
              UndirectedEdge[170, 265] -> 
             RGBColor[
              0.3088475371272851, 0.4408144148056739, 0.9409413149305978], 
             UndirectedEdge[102, 485] -> 
             RGBColor[
              0.2622693737921402, 0.3929921190672394, 0.9382472248934693], 
             UndirectedEdge[342, 463] -> 
             RGBColor[
              0.2635422521882549, 0.3943299949667075, 0.9383197134350733], 
             UndirectedEdge[70, 147] -> 
             RGBColor[
              0.2548716664665323, 0.3852166596262904, 0.9378259364052033], 
             UndirectedEdge[162, 381] -> 
             RGBColor[
              0.515668109442376, 0.6176816276857418, 0.9550144290112803], 
             UndirectedEdge[212, 299] -> 
             RGBColor[
              0.21384131413680724`, 0.3420911578531577, 0.9354893185389921], 
             UndirectedEdge[92, 361] -> 
             RGBColor[
              0.6266695180780231, 0.7077693478258749, 0.9637721633771799], 
             UndirectedEdge[82, 184] -> 
             RGBColor[
              0.2576552479933815, 0.38814238030027126`, 0.9379844572552174], 
             UndirectedEdge[232, 376] -> 
             RGBColor[
              0.3178263634409366, 0.4469988106247622, 0.9415717511395277], 
             UndirectedEdge[293, 298] -> 
             RGBColor[
              0.9279560632534805, 0.9449120378208546, 0.9763848153450053], 
             UndirectedEdge[225, 249] -> 
             RGBColor[
              0.28189858083211217`, 0.41362366022985875`, 0.9393650791955862],
              UndirectedEdge[19, 34] -> 
             RGBColor[
              0.5517387974757788, 0.6469654371972362, 0.9578540457045537], 
             UndirectedEdge[338, 390] -> 
             RGBColor[
              0.3104293975603457, 0.44256111009978116`, 0.9410283217053288], 
             UndirectedEdge[82, 342] -> 
             RGBColor[
              0.2591328832418887, 0.3896954686339382, 0.9380686063966545], 
             UndirectedEdge[54, 374] -> 
             RGBColor[
              0.24022555960590497`, 0.3698226726989618, 0.9369918622864639], 
             UndirectedEdge[196, 350] -> 
             RGBColor[
              0.3289346637950721, 0.4581221525257362, 0.9422245706487093], 
             UndirectedEdge[19, 44] -> 
             RGBColor[
              0.5282008880554978, 0.6278563019591167, 0.956001055252786], 
             UndirectedEdge[85, 408] -> 
             RGBColor[
              0.21836004410720744`, 0.3468406295560761, 0.9357466535259444], 
             UndirectedEdge[57, 255] -> 
             RGBColor[
              0.499414256811589, 0.6029727505529885, 0.9541529864670097], 
             UndirectedEdge[106, 269] -> 
             RGBColor[
              0.48339733950661234`, 0.5913638720070653, 0.9525068056899508], 
             UndirectedEdge[382, 416] -> 
             RGBColor[
              0.2718791903645599, 0.40309264558241453`, 0.938794489730819], 
             UndirectedEdge[246, 392] -> 
             RGBColor[
              0.3001114005223494, 0.4327664884837622, 0.940402272333493], 
             UndirectedEdge[350, 414] -> 
             RGBColor[
              0.31841398035212815`, 0.44706424717734483`, 0.94162543329059], 
             UndirectedEdge[146, 211] -> 
             RGBColor[
              0.2444868180291041, 0.37430152548113294`, 0.9372345346496982], 
             UndirectedEdge[71, 487] -> 
             RGBColor[
              0.6676064579243342, 0.7392945350984725, 0.9681635028375868], 
             UndirectedEdge[415, 485] -> 
             RGBColor[
              0.2675069384795197, 0.39849713163445644`, 0.9385454964541331], 
             UndirectedEdge[238, 433] -> 
             RGBColor[
              0.32283008594645624`, 0.45404092736007795`, 0.94179142550244], 
             UndirectedEdge[141, 429] -> 
             RGBColor[
              0.30159042381675216`, 0.434243660437526, 0.9404893336110074], 
             UndirectedEdge[406, 493] -> 
             RGBColor[
              0.9920978208950986, 0.9843432363296774, 0.4801786397760631], 
             UndirectedEdge[257, 357] -> 
             RGBColor[
              0.8829978584207956, 0.5607626793064351, 0.22403944465155362`], 
             UndirectedEdge[311, 488] -> 
             RGBColor[
              0.7581105843852092, 0.8109610174663499, 0.9765250361714609], 
             UndirectedEdge[258, 381] -> 
             RGBColor[
              0.4713636222770108, 0.5795438974068458, 0.952126015828245], 
             UndirectedEdge[168, 200] -> 
             RGBColor[
              0.9058101136750496, 0.6632964389017137, 0.24302016366679569`], 
             UndirectedEdge[16, 254] -> 
             RGBColor[
              0.3201901654275895, 0.4450745627173458, 0.941867792234375], 
             UndirectedEdge[325, 347] -> 
             RGBColor[
              0.1789719601845752, 0.3054412560046289, 0.9335035604159989], 
             UndirectedEdge[154, 478] -> 
             RGBColor[
              0.28779157321631055`, 0.419744046861437, 0.9397033683945971], 
             UndirectedEdge[302, 386] -> 
             RGBColor[
              0.18453817917078433`, 0.311291705077802, 0.9338205483527805], 
             UndirectedEdge[330, 414] -> 
             RGBColor[
              0.2905537605670515, 0.4227208029013707, 0.9398579788773], 
             UndirectedEdge[50, 334] -> 
             RGBColor[
              0.42187105269828507`, 0.539825234816783, 0.9481022283253784], 
             UndirectedEdge[72, 187] -> 
             RGBColor[
              0.2593062768219157, 0.38987771628033463`, 0.9380784809045242], 
             UndirectedEdge[14, 149] -> 
             RGBColor[
              0.33030872638618497`, 0.46033332920658265`, 0.9422747396921978],
              UndirectedEdge[113, 214] -> 
             RGBColor[
              0.18949968777431325`, 0.3165065651979255, 0.9341030989278573], 
             UndirectedEdge[63, 149] -> 
             RGBColor[
              0.3866051837093468, 0.5092797116126782, 0.9458551183377868], 
             UndirectedEdge[245, 445] -> 
             RGBColor[
              0.22560109399094413`, 0.3544514320929628, 0.93615902060465], 
             UndirectedEdge[207, 336] -> 
             RGBColor[
              0.2196507706490151, 0.34819726498830533`, 0.9358201584930417], 
             UndirectedEdge[264, 394] -> 
             RGBColor[
              0.23171433520063273`, 0.36087683620622507`, 0.9365071606478118],
              UndirectedEdge[255, 370] -> 
             RGBColor[
              0.4945144317215364, 0.598994851810279, 0.9537672542872702], 
             UndirectedEdge[330, 482] -> 
             RGBColor[
              0.33246549585026375`, 0.4621743129354704, 0.9424131594568423], 
             UndirectedEdge[383, 482] -> 
             RGBColor[
              0.34371197944189347`, 0.47212777395134153`, 0.9431220012908359],
              UndirectedEdge[358, 407] -> 
             RGBColor[
              0.21999227740316346`, 0.34855621023969413`, 0.9358396067974764],
              UndirectedEdge[28, 142] -> 
             RGBColor[
              0.8321901895218196, 0.869251634409216, 0.9575296911592543], 
             UndirectedEdge[348, 375] -> 
             RGBColor[
              0.959056524042907, 0.9223909347161948, 0.6272014222552931], 
             UndirectedEdge[41, 295] -> 
             RGBColor[
              0.23105727915165333`, 0.3601862286389881, 0.9364697422778497], 
             UndirectedEdge[83, 345] -> 
             RGBColor[
              0.7902354483667869, 0.8368716246944006, 0.9795108205407682], 
             UndirectedEdge[140, 425] -> 
             RGBColor[
              0.4374884569477172, 0.5520946556877604, 0.9494448313053598], 
             UndirectedEdge[160, 441] -> 
             RGBColor[
              0.4363070753078513, 0.5523289920255958, 0.9490220789207864], 
             UndirectedEdge[66, 394] -> 
             RGBColor[
              0.24596177604056546`, 0.3758517998689181, 0.937318531326446], 
             UndirectedEdge[201, 271] -> 
             RGBColor[
              0.2801320470703391, 0.4117669212415258, 0.9392644777112058], 
             UndirectedEdge[192, 470] -> 
             RGBColor[
              0.255048373399578, 0.3854023898167881, 0.9378359996036256], 
             UndirectedEdge[255, 379] -> 
             RGBColor[
              0.35344236256380235`, 0.4805557427482631, 0.943742012699124], 
             UndirectedEdge[82, 440] -> 
             RGBColor[
              0.26997623108034263`, 0.40109251472011487`, 0.9386861190147588],
              UndirectedEdge[43, 362] -> 
             RGBColor[
              0.34080467652755875`, 0.4681674552795022, 0.9429895550260083], 
             UndirectedEdge[127, 302] -> 
             RGBColor[
              0.2080645848230672, 0.3360194490786239, 0.9351603423504797], 
             UndirectedEdge[137, 358] -> 
             RGBColor[
              0.22285337720406, 0.3515634075346411, 0.9360025421985196], 
             UndirectedEdge[238, 328] -> 
             RGBColor[
              0.35273346300045894`, 0.47994172957682313`, 0.943696842245803], 
             UndirectedEdge[185, 196] -> 
             RGBColor[
              0.2898220421197416, 0.4219517204196188, 0.9398163085942062], 
             UndirectedEdge[114, 208] -> 
             RGBColor[
              0.41139850447614446`, 0.5294684917353877, 0.9477902381259522], 
             UndirectedEdge[249, 424] -> 
             RGBColor[
              0.30507115038591015`, 0.4368840315616916, 0.9407248332188166], 
             UndirectedEdge[21, 65] -> 
             RGBColor[
              0.9831762967586118, 0.9549118399527363, 0.38914351910732653`], 
             UndirectedEdge[369, 466] -> 
             RGBColor[
              0.46172779849419876`, 0.5729843638939052, 0.9510184053391775], 
             UndirectedEdge[246, 459] -> 
             RGBColor[
              0.3423837632254584, 0.4696344421074833, 0.9430865385917233], 
             UndirectedEdge[46, 317] -> 
             RGBColor[
              0.9005275853462438, 0.6373329329271229, 0.23851003583391922`], 
             UndirectedEdge[66, 305] -> 
             RGBColor[
              0.25719647261268064`, 0.38766017828711546`, 0.9379583306759838],
              UndirectedEdge[56, 243] -> 
             RGBColor[
              0.8379898589381207, 0.2930122798265395, 0.18401243786354038`], 
             UndirectedEdge[281, 288] -> 
             RGBColor[
              0.2504872858476244, 0.38060839761003135`, 0.9375762524150663], 
             UndirectedEdge[81, 329] -> 
             RGBColor[
              0.8530880154845231, 0.8856932433627962, 0.9858494905492173], 
             UndirectedEdge[57, 140] -> 
             RGBColor[
              0.550438526060826, 0.6459098182860178, 0.9577516835757175], 
             UndirectedEdge[184, 440] -> 
             RGBColor[
              0.26935285588816305`, 0.4004373078688641, 0.9386506187197652], 
             UndirectedEdge[422, 446] -> 
             RGBColor[
              0.2310816388212659, 0.36021183219624314`, 0.9364711295249972], 
             UndirectedEdge[232, 307] -> 
             RGBColor[
              0.4130035971526026, 0.5316969057817654, 0.9476609261549895], 
             UndirectedEdge[90, 261] -> 
             RGBColor[
              0.8723782969076955, 0.5133814777114375, 0.21522166145663085`], 
             UndirectedEdge[118, 304] -> 
             RGBColor[
              0.3318360758338559, 0.46184146314633034`, 0.9423652792143808], 
             UndirectedEdge[427, 460] -> 
             RGBColor[
              0.2639231904685617, 0.39473038525219195`, 0.938341407306589], 
             UndirectedEdge[299, 300] -> 
             RGBColor[
              0.21756201185689822`, 0.346001847062834, 0.9357012067698722], 
             UndirectedEdge[106, 425] -> 
             RGBColor[
              0.4465990938801403, 0.559491081179018, 0.9501620540180429], 
             UndirectedEdge[428, 495] -> 
             RGBColor[
              0.8362679836981737, 0.2797771922017657, 0.1823635681891872], 
             UndirectedEdge[230, 365] -> 
             RGBColor[
              0.22042634378562792`, 0.3490124415290624, 0.9358643262358141], 
             UndirectedEdge[224, 463] -> 
             RGBColor[
              0.2830318265857735, 0.4148147733688876, 0.9394296158647704], 
             UndirectedEdge[251, 382] -> 
             RGBColor[
              0.27038494943162866`, 0.40152210362155666`, 0.9387093949202199],
              UndirectedEdge[81, 278] -> 
             RGBColor[
              0.8859909437525565, 0.9116025564457284, 0.9776647627909368], 
             UndirectedEdge[42, 294] -> 
             RGBColor[
              0.23539350574473433`, 0.36474387772096156`, 0.9367166839674533],
              UndirectedEdge[8, 419] -> 
             RGBColor[
              0.5664920822105015, 0.6589428183727875, 0.9590154783219338], 
             UndirectedEdge[159, 164] -> 
             RGBColor[
              0.819137437150352, 0.14810430478184575`, 0.1659593374688081], 
             UndirectedEdge[346, 404] -> 
             RGBColor[
              0.21566548218765702`, 0.3440084741335353, 0.9355932022108733], 
             UndirectedEdge[7, 194] -> 
             RGBColor[
              0.9125990982944516, 0.9314492168831301, 0.9288011319761822], 
             UndirectedEdge[268, 353] -> 
             RGBColor[
              0.5246586597567469, 0.6237950026375101, 0.9560497714979366], 
             UndirectedEdge[51, 423] -> 
             RGBColor[
              0.18337644614132015`, 0.31007065000570677`, 0.9337543893753826],
              UndirectedEdge[14, 322] -> 
             RGBColor[
              0.2829806146027809, 0.4147609463277351, 0.9394266994181002], 
             UndirectedEdge[109, 458] -> 
             RGBColor[
              0.24222963005763265`, 0.3719290778091332, 0.9371059911339332], 
             UndirectedEdge[217, 384] -> 
             RGBColor[
              0.30177027996931804`, 0.4334954768697517, 0.9405338925067932], 
             UndirectedEdge[202, 485] -> 
             RGBColor[
              0.2435291255920976, 0.37329493000863156`, 0.9371799954821897], 
             UndirectedEdge[125, 457] -> 
             RGBColor[
              0.21513132866869134`, 0.3434470449178132, 0.9355627829581774], 
             UndirectedEdge[454, 475] -> 
             RGBColor[
              0.8694429086173421, 0.4695370183739893, 0.21157738923531183`], 
             UndirectedEdge[30, 378] -> 
             RGBColor[
              0.2755078252460146, 0.406906570911563, 0.9390011351192336], 
             UndirectedEdge[445, 460] -> 
             RGBColor[
              0.23899278558713355`, 0.3685269490428458, 0.9369216576298206], 
             UndirectedEdge[173, 461] -> 
             RGBColor[
              0.9645092309315171, 0.9729899937684735, 0.9422009085196323], 
             UndirectedEdge[23, 41] -> 
             RGBColor[
              0.22751409159888136`, 0.35646211386995863`, 0.9362679629883957],
              UndirectedEdge[111, 444] -> 
             RGBColor[
              0.272192144891436, 0.40342158063262434`, 0.9388123120281499], 
             UndirectedEdge[139, 360] -> 
             RGBColor[
              0.5717007512056378, 0.6631714505109032, 0.9594255238252141], 
             UndirectedEdge[53, 432] -> 
             RGBColor[
              0.9375683877182548, 0.9272177056729635, 0.6767239867532486], 
             UndirectedEdge[184, 260] -> 
             RGBColor[
              0.2713041510776424, 0.40248824283226764`, 0.9387617420941234], 
             UndirectedEdge[244, 379] -> 
             RGBColor[
              0.3258701140726008, 0.45667404692668806`, 0.9419851334064466], 
             UndirectedEdge[14, 187] -> 
             RGBColor[
              0.28568538812664784`, 0.41760383479386565`, 0.9395807322689307],
              UndirectedEdge[133, 332] -> 
             RGBColor[
              0.3736828594731001, 0.4980870438541423, 0.9450317192642157], 
             UndirectedEdge[424, 440] -> 
             RGBColor[
              0.30113413549531765`, 0.4327459792905174, 0.940500626045089], 
             UndirectedEdge[381, 419] -> 
             RGBColor[
              0.5409976687744238, 0.6382453050351424, 0.9570084647071322], 
             UndirectedEdge[39, 368] -> 
             RGBColor[
              0.5158816187650146, 0.6166272342584453, 0.9553704626805029], 
             UndirectedEdge[40, 208] -> 
             RGBColor[
              0.3541593410951509, 0.4811767535157284, 0.9437876979371422], 
             UndirectedEdge[436, 462] -> 
             RGBColor[
              0.46839908955768095`, 0.5793065078982675, 0.951293238613832], 
             UndirectedEdge[103, 188] -> 
             RGBColor[
              0.408816425381794, 0.5277838356822806, 0.9474732432839563], 
             UndirectedEdge[313, 411] -> 
             RGBColor[
              0.2532739296678089, 0.38353733694846814`, 0.9377349476581557], 
             UndirectedEdge[181, 344] -> 
             RGBColor[
              0.4422200885925819, 0.5571674842764482, 0.9494770619548758], 
             UndirectedEdge[5, 485] -> 
             RGBColor[
              0.24330426601765148`, 0.37305858833896816`, 0.9371671900620748],
              UndirectedEdge[371, 429] -> 
             RGBColor[
              0.3282709430209225, 0.4573529851702918, 0.9421893927020404], 
             UndirectedEdge[426, 448] -> 
             RGBColor[
              0.7190568535901429, 0.7797176017404024, 0.9733043071059779], 
             UndirectedEdge[32, 403] -> 
             RGBColor[
              0.73231135392298, 0.7900531713799142, 0.9748369526254256], 
             UndirectedEdge[115, 484] -> 
             RGBColor[
              0.9570300393594782, 0.9635915325846716, 0.7300132516870645], 
             UndirectedEdge[36, 251] -> 
             RGBColor[
              0.25646724614478844`, 0.3868937150337323, 0.9379168023074314], 
             UndirectedEdge[243, 454] -> 
             RGBColor[
              0.869594267772993, 0.47070043117032717`, 0.21172233093369885`], 
             UndirectedEdge[106, 139] -> 
             RGBColor[
              0.5409452590449157, 0.6382027564556965, 0.9570043388212421], 
             UndirectedEdge[220, 499] -> 
             RGBColor[
              0.2998159216660946, 0.42966675719263536`, 0.9404875702170554], 
             UndirectedEdge[359, 419] -> 
             RGBColor[
              0.44907089909255904`, 0.561772271120652, 0.9502808074967835], 
             UndirectedEdge[115, 297] -> 
             RGBColor[
              0.7202662947001824, 0.7803304830864486, 0.9738242280167566], 
             UndirectedEdge[155, 235] -> 
             RGBColor[
              0.4614654223098702, 0.5710633178486462, 0.9514696859030422], 
             UndirectedEdge[98, 261] -> 
             RGBColor[
              0.9376107771767181, 0.7700729496416561, 0.47213960027127755`], 
             UndirectedEdge[386, 421] -> 
             RGBColor[
              0.17899180289058533`, 0.3054621119467458, 0.9335046904287516], 
             UndirectedEdge[37, 58] -> 
             RGBColor[
              0.31037597127891847`, 0.44296664665046, 0.9410083743899482], 
             UndirectedEdge[71, 194] -> 
             RGBColor[
              0.8711488139703549, 0.898916809896938, 0.9247098602219754], 
             UndirectedEdge[47, 339] -> 
             RGBColor[
              0.22181216919966315`, 0.3504690319056196, 0.9359432469429985], 
             UndirectedEdge[108, 410] -> 
             RGBColor[
              0.32438785376155105`, 0.4532049421182389, 0.9419706976299311], 
             UndirectedEdge[193, 196] -> 
             RGBColor[
              0.29175552637074975`, 0.4239839349574104, 0.9399264176619675], 
             UndirectedEdge[131, 171] -> 
             RGBColor[
              0.26267563753313167`, 0.39341912801763035`, 0.9382703610125054],
              UndirectedEdge[203, 258] -> 
             RGBColor[
              0.45399453907585874`, 0.5654428931958693, 0.950758657973602], 
             UndirectedEdge[164, 428] -> 
             RGBColor[
              0.8239291026561835, 0.1849351455808791, 0.17054784176860438`], 
             UndirectedEdge[143, 325] -> 
             RGBColor[
              0.17897196085846667`, 0.30544125671293154`, 0.9335035604543761],
              UndirectedEdge[101, 498] -> 
             RGBColor[
              0.491361119566665, 0.5979481182872246, 0.9531008937288266], 
             UndirectedEdge[35, 391] -> 
             RGBColor[
              0.23974982774210207`, 0.3693226483469626, 0.9369647700606025], 
             UndirectedEdge[8, 221] -> 
             RGBColor[
              0.5784518548396522, 0.6686523005747489, 0.9599569954333912], 
             UndirectedEdge[240, 251] -> 
             RGBColor[
              0.25758537828186423`, 0.38806894280347104`, 0.9379804782785095],
              UndirectedEdge[464, 485] -> 
             RGBColor[
              0.24593397699878092`, 0.3758225813134415, 0.9373169482121415], 
             UndirectedEdge[104, 452] -> 
             RGBColor[
              0.2352635459876256, 0.36460728177631574`, 0.9367092829515442], 
             UndirectedEdge[121, 475] -> 
             RGBColor[
              0.8332346662535209, 0.256461785113985, 0.17945885997854572`], 
             UndirectedEdge[168, 315] -> 
             RGBColor[
              0.5481459181329882, 0.49816507299275914`, 0.5904774154442385], 
             UndirectedEdge[65, 320] -> 
             RGBColor[
              0.9870336626851595, 0.9760932232050978, 0.618291834936235], 
             UndirectedEdge[323, 452] -> 
             RGBColor[
              0.23164904535488023`, 0.3608082124387239, 0.9365034424876839], 
             UndirectedEdge[72, 322] -> 
             RGBColor[
              0.25660150329804876`, 0.38703482781420406`, 0.9379244480536938],
              UndirectedEdge[60, 327] -> 
             RGBColor[
              0.27488937913222444`, 0.40625654483422113`, 0.9389659155279624],
              UndirectedEdge[1, 135] -> 
             RGBColor[
              0.2583961289533292, 0.38892109316374235`, 0.9380266493298512], 
             UndirectedEdge[420, 439] -> 
             RGBColor[
              0.9147776569049322, 0.9340333582536569, 0.9622797424419812], 
             UndirectedEdge[134, 367] -> 
             RGBColor[
              0.23152572380893705`, 0.3606785936749, 0.9364964195080803], 
             UndirectedEdge[119, 345] -> 
             RGBColor[
              0.8251862844410536, 0.8622510331677843, 0.8856898202805965], 
             UndirectedEdge[64, 366] -> 
             RGBColor[
              0.27642037277284975`, 0.4078657162211217, 0.9390531033508938], 
             UndirectedEdge[86, 90] -> 
             RGBColor[
              0.8899814344584336, 0.5901544331035902, 0.2297467504579272], 
             UndirectedEdge[81, 426] -> 
             RGBColor[
              0.8468962698264015, 0.8807561134454687, 0.9852589163209091], 
             UndirectedEdge[70, 265] -> 
             RGBColor[
              0.28963233444531233`, 0.42061801847270397`, 0.9398470375642044],
              UndirectedEdge[245, 438] -> 
             RGBColor[
              0.22151371355788788`, 0.3501553361029332, 0.9359262503357249], 
             UndirectedEdge[121, 259] -> 
             RGBColor[
              0.8446533203330481, 0.33882677308300735`, 0.1901817771182239], 
             UndirectedEdge[74, 105] -> 
             RGBColor[
              0.2638196417670582, 0.3946215490015449, 0.938335510361225], 
             UndirectedEdge[358, 430] -> 
             RGBColor[
              0.23268261924121364`, 0.3618945641256297, 0.936562302991475], 
             UndirectedEdge[43, 316] -> 
             RGBColor[
              0.2718214258604257, 0.4030319314260883, 0.9387912001277635], 
             UndirectedEdge[162, 203] -> 
             RGBColor[
              0.4982990262412239, 0.6035806234747654, 0.9536470711566374], 
             UndirectedEdge[226, 236] -> 
             RGBColor[
              0.23337407460187973`, 0.3626213275504917, 0.9366016803513484], 
             UndirectedEdge[110, 340] -> 
             RGBColor[
              0.3045749314378675, 0.43480548891742876`, 0.9407535831342266], 
             UndirectedEdge[145, 407] -> 
             RGBColor[
              0.2175082544444818, 0.34594534461396753`, 0.9356981453647621], 
             UndirectedEdge[258, 289] -> 
             RGBColor[
              0.4063967473847854, 0.5264221693154291, 0.9471162192741931], 
             UndirectedEdge[13, 334] -> 
             RGBColor[
              0.3497101697631252, 0.47620162767835794`, 0.94354526344998], 
             UndirectedEdge[300, 389] -> 
             RGBColor[
              0.2222287148930997, 0.35090684783994386`, 0.9359669686040155], 
             UndirectedEdge[57, 363] -> 
             RGBColor[
              0.5030271726289528, 0.6061020766435601, 0.9543831982681161], 
             UndirectedEdge[305, 427] -> 
             RGBColor[
              0.26530600013852146`, 0.3961838058905166, 0.9384201562716097], 
             UndirectedEdge[277, 419] -> 
             RGBColor[
              0.6419960336426249, 0.718265092425402, 0.9663099050077802], 
             UndirectedEdge[40, 349] -> 
             RGBColor[
              0.3999008136180363, 0.5207957179817955, 0.9467023041187045], 
             UndirectedEdge[28, 241] -> 
             RGBColor[
              0.8351691071867402, 0.8715787875296648, 0.9578266018325254], 
             UndirectedEdge[164, 396] -> 
             RGBColor[
              0.9055353853140414, 0.5621560872497313, 0.3516608883245811], 
             UndirectedEdge[111, 284] -> 
             RGBColor[
              0.2590919383322233, 0.3896524329378227, 0.9380662746446216], 
             UndirectedEdge[25, 343] -> 
             RGBColor[
              0.3031313951145783, 0.4355126855320067, 0.9405899280547156], 
             UndirectedEdge[84, 131] -> 
             RGBColor[
              0.24846167161057395`, 0.3784793486155308, 0.9374608966808939], 
             UndirectedEdge[169, 244] -> 
             RGBColor[
              0.4175916065853016, 0.5350481346501237, 0.9481253168239769], 
             UndirectedEdge[219, 363] -> 
             RGBColor[
              0.4655401284489993, 0.5756684054061787, 0.9514320808307029], 
             UndirectedEdge[400, 415] -> 
             RGBColor[
              0.2914672574254832, 0.4236809460186285, 0.9399100011719903], 
             UndirectedEdge[248, 286] -> 
             RGBColor[
              0.23281996068137648`, 0.36203891868719107`, 0.9365701243833138],
              UndirectedEdge[136, 484] -> 
             RGBColor[
              0.980926180317411, 0.981787940062676, 0.7025545645628573], 
             UndirectedEdge[74, 263] -> 
             RGBColor[
              0.27756733242056764`, 0.40907124353231517`, 0.9391184210060566],
              UndirectedEdge[69, 142] -> 
             RGBColor[
              0.8044934065793106, 0.8479188521576653, 0.9809561216743297], 
             UndirectedEdge[109, 409] -> 
             RGBColor[
              0.24775783308986035`, 0.3777395697043211, 0.9374208141183751], 
             UndirectedEdge[101, 219] -> 
             RGBColor[
              0.5235508135187052, 0.6240811619666777, 0.9556349843514654], 
             UndirectedEdge[380, 390] -> 
             RGBColor[
              0.2868022644003798, 0.4187777425716037, 0.9396443367204493], 
             UndirectedEdge[53, 293] -> 
             RGBColor[
              0.9653923096103165, 0.9489247911355639, 0.6627722008261114], 
             UndirectedEdge[221, 258] -> 
             RGBColor[
              0.45501626161494246`, 0.5662723735811732, 0.9508390917145717], 
             UndirectedEdge[235, 424] -> 
             RGBColor[
              0.3388180779328382, 0.46788892243883967`, 0.9428101662141861], 
             UndirectedEdge[367, 457] -> 
             RGBColor[
              0.22571706608911693`, 0.3545733261211982, 0.9361656250440755], 
             UndirectedEdge[58, 220] -> 
             RGBColor[
              0.32701247471585293`, 0.45766350229915764`, 0.9420579236164848],
              UndirectedEdge[334, 379] -> 
             RGBColor[
              0.3560516389210633, 0.4828157667828796, 0.9439082734813162], 
             UndirectedEdge[14, 163] -> 
             RGBColor[
              0.2868674954285888, 0.4188463045181374, 0.9396480515310051], 
             UndirectedEdge[284, 442] -> 
             RGBColor[
              0.26451897986036277`, 0.3953565976782041, 0.9383753366310607], 
             UndirectedEdge[130, 302] -> 
             RGBColor[
              0.18453817917078433`, 0.311291705077802, 0.9338205483527805], 
             UndirectedEdge[65, 428] -> 
             RGBColor[
              0.9078991618741388, 0.5983968558388272, 0.2873573629313444], 
             UndirectedEdge[388, 487] -> 
             RGBColor[
              0.7628017392959624, 0.8144116714200249, 0.9680174393113103], 
             UndirectedEdge[456, 458] -> 
             RGBColor[
              0.22707889219219896`, 0.35600469170029936`, 0.9362431790260048],
              UndirectedEdge[281, 465] -> 
             RGBColor[
              0.26376712193927254`, 0.39456634733259277`, 0.9383325194347287],
              UndirectedEdge[166, 428] -> 
             RGBColor[
              0.8342269539589475, 0.26408894324113896`, 0.18040907580589088`],
              UndirectedEdge[92, 128] -> 
             RGBColor[
              0.5519404005403256, 0.6471291076471498, 0.9578699166362912], 
             UndirectedEdge[120, 457] -> 
             RGBColor[
              0.21450528797873675`, 0.3427890364593986, 0.9355271308670288], 
             UndirectedEdge[79, 329] -> 
             RGBColor[
              0.9381932995999778, 0.9492001435332333, 0.7791661244013025], 
             UndirectedEdge[105, 195] -> 
             RGBColor[
              0.2580285978828387, 0.38853479470584096`, 0.9380057189791005], 
             UndirectedEdge[98, 377] -> 
             RGBColor[
              0.9881699242791049, 0.9888223570121889, 0.8197885510745015], 
             UndirectedEdge[21, 309] -> 
             RGBColor[
              0.9869592653755547, 0.967346961753188, 0.4315364838739727], 
             UndirectedEdge[93, 322] -> 
             RGBColor[
              0.26425191426448674`, 0.3950758948040016, 0.9383601276404636], 
             UndirectedEdge[8, 115] -> 
             RGBColor[
              0.7707310045144475, 0.8213000079229384, 0.9777969948316587], 
             UndirectedEdge[54, 131] -> 
             RGBColor[
              0.24616492351091418`, 0.3760653207405481, 0.9373301002743527], 
             UndirectedEdge[186, 212] -> 
             RGBColor[
              0.22711333090057176`, 0.3560408889663394, 0.9362451402594992], 
             UndirectedEdge[252, 467] -> 
             RGBColor[
              0.7213175895970523, 0.7822180503007243, 0.9728578543010624], 
             UndirectedEdge[244, 378] -> 
             RGBColor[
              0.3127627275114677, 0.4429484996474682, 0.9412368143882763], 
             UndirectedEdge[55, 339] -> 
             RGBColor[
              0.21158417509033906`, 0.33971876160443837`, 0.9353607778094337],
              UndirectedEdge[69, 490] -> 
             RGBColor[
              0.9500080335378767, 0.9605032008441318, 0.8987210231001681], 
             UndirectedEdge[299, 451] -> 
             RGBColor[
              0.21030609728277713`, 0.3383754207938774, 0.9352879931690398], 
             UndirectedEdge[146, 464] -> 
             RGBColor[
              0.25089999678857744`, 0.38104218297635795`, 0.9375997556926023],
              UndirectedEdge[199, 220] -> 
             RGBColor[
              0.3408785418830542, 0.4696735927505875, 0.9429414571550971], 
             UndirectedEdge[345, 426] -> 
             RGBColor[
              0.7649497936964772, 0.8167095300211071, 0.9770990522255436], 
             UndirectedEdge[66, 472] -> 
             RGBColor[
              0.29586389462338253`, 0.42648062461240877`, 0.9402270759441249],
              UndirectedEdge[40, 114] -> 
             RGBColor[
              0.443439320562669, 0.5572206362112937, 0.9498318505944043], 
             UndirectedEdge[248, 294] -> 
             RGBColor[
              0.240426199543799, 0.37003355799499527`, 0.9370032884341067], 
             UndirectedEdge[304, 483] -> 
             RGBColor[
              0.3176066092257016, 0.44839817992769826`, 0.941499541548237], 
             UndirectedEdge[9, 425] -> 
             RGBColor[
              0.47524326414852586`, 0.5827457090080587, 0.9524170280286233], 
             UndirectedEdge[290, 384] -> 
             RGBColor[
              0.2851530200769201, 0.4170442822195179, 0.9395504146960666], 
             UndirectedEdge[294, 358] -> 
             RGBColor[
              0.23196947764628847`, 0.36114500709357467`, 0.9365216906326425],
              UndirectedEdge[148, 342] -> 
             RGBColor[
              0.2498214928286487, 0.3799086069333723, 0.9375383364875882], 
             UndirectedEdge[178, 420] -> 
             RGBColor[
              0.9801637329335828, 0.9834819259202605, 0.8627171585529716], 
             UndirectedEdge[193, 354] -> 
             RGBColor[
              0.3247877807995152, 0.4538010668360344, 0.941987036861071], 
             UndirectedEdge[194, 228] -> 
             RGBColor[
              0.9897986964683487, 0.9881510016226367, 0.6807237889593197], 
             UndirectedEdge[326, 491] -> 
             RGBColor[
              0.9346684716417725, 0.7580015966571071, 0.4117209054738351], 
             UndirectedEdge[324, 481] -> 
             RGBColor[
              0.3439470735768655, 0.47233140067487944`, 0.9431369812812307], 
             UndirectedEdge[94, 213] -> 
             RGBColor[
              0.9298124883323949, 0.8120876909328425, 0.6010637208876998], 
             UndirectedEdge[92, 175] -> 
             RGBColor[
              0.7824339265203888, 0.8300343229197356, 0.9610969915433571], 
             UndirectedEdge[254, 401] -> 
             RGBColor[
              0.50497531356463, 0.5944255881948143, 0.9574168801184721], 
             UndirectedEdge[161, 491] -> 
             RGBColor[
              0.992246695040947, 0.9844848921088973, 0.5114139987289448], 
             UndirectedEdge[172, 303] -> 
             RGBColor[
              0.32845548787730483`, 0.4585909264869045, 0.9421616772940785], 
             UndirectedEdge[57, 274] -> 
             RGBColor[
              0.5319886243671207, 0.6309313569324684, 0.9562992397301722], 
             UndirectedEdge[44, 360] -> 
             RGBColor[
              0.5380217860131518, 0.6358293493475512, 0.9567741923151472], 
             UndirectedEdge[170, 238] -> 
             RGBColor[
              0.3084172446419511, 0.44044171708200675`, 0.940913897073925], 
             UndirectedEdge[5, 11] -> 
             RGBColor[
              0.23876273655839006`, 0.3682851529276855, 0.9369085566779607], 
             UndirectedEdge[3, 223] -> 
             RGBColor[
              0.4257649092191724, 0.5429712289379067, 0.9484129706530855], 
             UndirectedEdge[65, 227] -> 
             RGBColor[
              0.9155479974276244, 0.657189157644029, 0.2946818964954864], 
             UndirectedEdge[78, 85] -> 
             RGBColor[
              0.21682232686548605`, 0.34522439123812265`, 0.9356590828038773],
              UndirectedEdge[181, 393] -> 
             RGBColor[
              0.4409543407183537, 0.5561398931308579, 0.9493774176456293], 
             UndirectedEdge[45, 56] -> 
             RGBColor[
              0.5597280401148761, 0.3487238439697099, 0.5610837052268939], 
             UndirectedEdge[141, 310] -> 
             RGBColor[
              0.3031699755874952, 0.4359038694979436, 0.9405792867476138], 
             UndirectedEdge[39, 236] -> 
             RGBColor[
              0.4554923722273556, 0.5623404159424226, 0.9515950359894985], 
             UndirectedEdge[337, 375] -> 
             RGBColor[
              0.9092060692572821, 0.9298599802312014, 0.9710835499900707], 
             UndirectedEdge[57, 334] -> 
             RGBColor[
              0.5020235331688498, 0.6052327745876049, 0.9543192472492019], 
             UndirectedEdge[123, 438] -> 
             RGBColor[
              0.21421403684205725`, 0.34248291304835987`, 0.9355105445456623],
              UndirectedEdge[35, 385] -> 
             RGBColor[
              0.235922007593164, 0.36529936667261376`, 0.936746781365873], 
             UndirectedEdge[268, 285] -> 
             RGBColor[
              0.3620365603618595, 0.4879996049239992, 0.9442896273832655], 
             UndirectedEdge[169, 361] -> 
             RGBColor[
              0.5684718159304661, 0.6605218314458838, 0.9591906270789168], 
             UndirectedEdge[337, 361] -> 
             RGBColor[
              0.752206073850372, 0.8066735064022713, 0.9758502482621753], 
             UndirectedEdge[119, 270] -> 
             RGBColor[
              0.9903352312511376, 0.9902713839961873, 0.8098337599957988], 
             UndirectedEdge[254, 386] -> 
             RGBColor[
              0.20771262472504887`, 0.3356495167000475, 0.935140298743576], 
             UndirectedEdge[253, 488] -> 
             RGBColor[
              0.877198073649208, 0.9039154021300979, 0.937685633244106], 
             UndirectedEdge[340, 380] -> 
             RGBColor[
              0.3051428116901297, 0.43540236706824387`, 0.9407859230744895], 
             UndirectedEdge[388, 490] -> 
             RGBColor[
              0.9683628300119925, 0.9748687448836537, 0.8911081388957877], 
             UndirectedEdge[27, 311] -> 
             RGBColor[
              0.6294878924283578, 0.7084848809709354, 0.9650691972348303], 
             UndirectedEdge[222, 417] -> 
             RGBColor[
              0.5718731828738293, 0.6621247011020224, 0.9601331729684849], 
             UndirectedEdge[274, 361] -> 
             RGBColor[
              0.5534678542610545, 0.6483409394418851, 0.9580094602549781], 
             UndirectedEdge[65, 474] -> 
             RGBColor[
              0.989280991001634, 0.9770225512176633, 0.5810477888330006], 
             UndirectedEdge[243, 326] -> 
             RGBColor[
              0.8572408103331092, 0.41460626615910345`, 0.2014143032349089], 
             UndirectedEdge[47, 437] -> 
             RGBColor[
              0.2438820574631478, 0.37366588378227833`, 0.93720009443013], 
             UndirectedEdge[232, 414] -> 
             RGBColor[
              0.31542779716347613`, 0.44447776538926564`, 0.9414351563383871],
              UndirectedEdge[102, 196] -> 
             RGBColor[
              0.28611844580431445`, 0.41805900587053585`, 0.9396053942630224],
              UndirectedEdge[90, 257] -> 
             RGBColor[
              0.8618116052496472, 0.4654005988057779, 0.20640455492384144`], 
             UndirectedEdge[116, 310] -> 
             RGBColor[
              0.2727415097182925, 0.40399899789739224`, 0.9388435975423268], 
             UndirectedEdge[333, 459] -> 
             RGBColor[
              0.3845976264069504, 0.5075408663801063, 0.9457271985616913], 
             UndirectedEdge[68, 257] -> 
             RGBColor[
              0.8394199460541523, 0.30329924422110266`, 0.18535427265779897`],
              UndirectedEdge[220, 349] -> 
             RGBColor[
              0.3762573378366486, 0.5003169276156031, 0.9451957627490192], 
             UndirectedEdge[92, 204] -> 
             RGBColor[
              0.5555153199743827, 0.6500313882920026, 0.9581513473895016], 
             UndirectedEdge[120, 123] -> 
             RGBColor[
              0.20719251066229882`, 0.33510284384296096`, 0.9351106790171422],
              UndirectedEdge[190, 224] -> 
             RGBColor[
              0.2735379552710175, 0.40483611267087094`, 0.938888953938319], 
             UndirectedEdge[450, 469] -> 
             RGBColor[
              0.8390695807149537, 0.298125435533924, 0.18492162257597716`], 
             UndirectedEdge[405, 434] -> 
             RGBColor[
              0.9926076308918226, 0.9901160572249841, 0.6925776468321798], 
             UndirectedEdge[312, 400] -> 
             RGBColor[
              0.30016668312241634`, 0.43282459400155193`, 0.9404054205957836],
              UndirectedEdge[100, 259] -> 
             RGBColor[
              0.8965277758950481, 0.6152647749950997, 0.2349704456547408], 
             UndirectedEdge[87, 423] -> 
             RGBColor[
              0.18353957668712906`, 0.310242110552426, 0.9337636794186364], 
             UndirectedEdge[403, 449] -> 
             RGBColor[
              0.8286073759188407, 0.8669140710830616, 0.9833178599894938], 
             UndirectedEdge[268, 275] -> 
             RGBColor[
              0.4116793705742366, 0.5309977120097701, 0.9474528233525847], 
             UndirectedEdge[166, 210] -> 
             RGBColor[
              0.8370920629652436, 0.28611142656230293`, 0.18315270742599782`],
              UndirectedEdge[102, 496] -> 
             RGBColor[
              0.27671354998693043`, 0.4081738640616296, 0.9390697993595188], 
             UndirectedEdge[11, 202] -> 
             RGBColor[
              0.2389875961328362, 0.3685214945973489, 0.9369213620980754], 
             UndirectedEdge[187, 494] -> 
             RGBColor[
              0.26156581469201307`, 0.3922526338447824, 0.9382071582435395], 
             UndirectedEdge[158, 282] -> 
             RGBColor[
              0.4825898599888707, 0.5882261104425313, 0.9531290808792493], 
             UndirectedEdge[232, 372] -> 
             RGBColor[
              0.41332534927572523`, 0.5319581186500844, 0.9476862556607386], 
             UndirectedEdge[143, 477] -> 
             RGBColor[
              0.21179931439321417`, 0.33994488665237976`, 0.9353730296744625],
              UndirectedEdge[479, 482] -> 
             RGBColor[
              0.3849860560945393, 0.5078773046524521, 0.9457519489579096], 
             UndirectedEdge[45, 283] -> 
             RGBColor[
              0.23199831546813182`, 0.3611753174727555, 0.9365233329039347], 
             UndirectedEdge[323, 463] -> 
             RGBColor[
              0.25322101360276406`, 0.3834817188090337, 0.9377319341665338], 
             UndirectedEdge[130, 347] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[338, 369] -> 
             RGBColor[
              0.37002637582951403`, 0.49491998150227967`, 0.9447987313597479],
              UndirectedEdge[143, 386] -> 
             RGBColor[
              0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772],
              UndirectedEdge[168, 254] -> 
             RGBColor[
              0.5736452347236608, 0.5249664714796068, 0.591929563801219], 
             UndirectedEdge[86, 115] -> 
             RGBColor[
              0.9181807358610004, 0.8207272885954675, 0.6214818156174652], 
             UndirectedEdge[138, 457] -> 
             RGBColor[
              0.22077773189024535`, 0.349381772706308, 0.9358843372685399], 
             UndirectedEdge[11, 497] -> 
             RGBColor[
              0.2374558873234022, 0.36691157152268605`, 0.9368341335473384], 
             UndirectedEdge[154, 379] -> 
             RGBColor[
              0.3094202014132221, 0.4424259593777846, 0.9409369595178776], 
             UndirectedEdge[17, 467] -> 
             RGBColor[
              0.7934052123801664, 0.8390183037645371, 0.979914209324252], 
             UndirectedEdge[75, 93] -> 
             RGBColor[
              0.30711689507265494`, 0.43678253795558514`, 0.940923781155411], 
             UndirectedEdge[100, 315] -> 
             RGBColor[
              0.5583572344294613, 0.5386495393888345, 0.5986936802267802], 
             UndirectedEdge[45, 52] -> 
             RGBColor[
              0.5592887582023336, 0.3453473306953461, 0.5606630483713451], 
             UndirectedEdge[8, 203] -> 
             RGBColor[
              0.5774301323005686, 0.6678228201894449, 0.9598765616924215], 
             UndirectedEdge[244, 340] -> 
             RGBColor[
              0.33993779537767665`, 0.4688587654109236, 0.9428815136196439], 
             UndirectedEdge[104, 190] -> 
             RGBColor[
              0.24734164292075334`, 0.3773021274486088, 0.9373971127039427], 
             UndirectedEdge[38, 437] -> 
             RGBColor[
              0.2578995688543769, 0.3883991770160148, 0.9379983709668107], 
             UndirectedEdge[96, 465] -> 
             RGBColor[
              0.2893936582907169, 0.42150146185421045`, 0.9397919127688803], 
             UndirectedEdge[48, 346] -> 
             RGBColor[
              0.21269676667826953`, 0.34088816590573434`, 0.9354241382544346],
              UndirectedEdge[153, 342] -> 
             RGBColor[
              0.25246005368067864`, 0.38268190168327626`, 0.9376885986247103],
              UndirectedEdge[151, 327] -> 
             RGBColor[
              0.28193174194509296`, 0.41365851466213766`, 0.939366967671913], 
             UndirectedEdge[375, 489] -> 
             RGBColor[
              0.9741495163492516, 0.9792601983573855, 0.8847051301265769], 
             UndirectedEdge[203, 289] -> 
             RGBColor[
              0.48696884397226536`, 0.5940035787603833, 0.9528597515235682], 
             UndirectedEdge[6, 79] -> 
             RGBColor[
              0.9107592672849488, 0.9273249908421985, 0.7765494419084453], 
             UndirectedEdge[105, 463] -> 
             RGBColor[
              0.2565013158137106, 0.3869295244159112, 0.9379187425246749], 
             UndirectedEdge[10, 125] -> 
             RGBColor[
              0.21381800062875955`, 0.3420666538780378, 0.935487990869198], 
             UndirectedEdge[32, 331] -> 
             RGBColor[
              0.6862012136677067, 0.7532861971667737, 0.9704389262848694], 
             UndirectedEdge[26, 44] -> 
             RGBColor[
              0.4416533932183588, 0.5557823986053863, 0.949688034527277], 
             UndirectedEdge[86, 253] -> 
             RGBColor[
              0.9501124692155603, 0.8447770986590462, 0.5741725699000219], 
             UndirectedEdge[370, 466] -> 
             RGBColor[
              0.5474757553674385, 0.6435045075658272, 0.9575184434137474], 
             UndirectedEdge[301, 456] -> 
             RGBColor[
              0.21620560443164671`, 0.3445761768576967, 0.9356239613736292], 
             UndirectedEdge[21, 337] -> 
             RGBColor[
              0.9205492329643337, 0.9192823831910986, 0.6833909335036439], 
             UndirectedEdge[61, 172] -> 
             RGBColor[
              0.3377395733706075, 0.4669547759942509, 0.9427414448571648], 
             UndirectedEdge[291, 359] -> 
             RGBColor[
              0.5201892016597764, 0.619316785102851, 0.95601113315619], 
             UndirectedEdge[134, 499] -> 
             RGBColor[
              0.2469625122439105, 0.37690363706897373`, 0.93737552177277], 
             UndirectedEdge[140, 244] -> 
             RGBColor[
              0.42103754660959536`, 0.5378457039996745, 0.9483965938455836], 
             UndirectedEdge[108, 364] -> 
             RGBColor[
              0.27183868506633, 0.4030500719457907, 0.938792183014007], 
             UndirectedEdge[113, 421] -> 
             RGBColor[
              0.17912443323835392`, 0.3056015148515002, 0.9335122435308479], 
             UndirectedEdge[54, 55] -> 
             RGBColor[
              0.22009923076516985`, 0.34866862500439766`, 0.9358456976332195],
              UndirectedEdge[56, 210] -> 
             RGBColor[
              0.8363686612775614, 0.28055104419413623`, 0.18245997715290796`],
              UndirectedEdge[36, 58] -> 
             RGBColor[
              0.28475051663686596`, 0.4160326690739975, 0.9395490426575464], 
             UndirectedEdge[25, 288] -> 
             RGBColor[
              0.2847205959795895, 0.4161617683290476, 0.9395414602803146], 
             UndirectedEdge[262, 344] -> 
             RGBColor[
              0.4699143971667351, 0.5805367028791276, 0.9514125291795714], 
             UndirectedEdge[8, 439] -> 
             RGBColor[
              0.7406030565482964, 0.7972768000160912, 0.9749233642591105], 
             UndirectedEdge[102, 186] -> 
             RGBColor[
              0.256123983487738, 0.3865329242170628, 0.9378972540069239], 
             UndirectedEdge[85, 145] -> 
             RGBColor[
              0.21743686076267443`, 0.3458703053277671, 0.9356940796002007], 
             UndirectedEdge[421, 423] -> 
             RGBColor[
              0.18344124862659156`, 0.31013876152644193`, 0.9337580797810521],
              UndirectedEdge[406, 476] -> 
             RGBColor[
              0.9195554041525527, 0.6768776802935997, 0.3060621599750899], 
             UndirectedEdge[111, 400] -> 
             RGBColor[
              0.2845065356159251, 0.4163647860615299, 0.939513598362401], 
             UndirectedEdge[137, 183] -> 
             RGBColor[
              0.2125239415632086, 0.34070651575206007`, 0.9354142961198038], 
             UndirectedEdge[85, 358] -> 
             RGBColor[
              0.2199208837213561, 0.34848117095349374`, 0.935835541032915], 
             UndirectedEdge[399, 412] -> 
             RGBColor[
              0.24194122045751632`, 0.37162594103318614`, 0.9370895666338703],
              UndirectedEdge[283, 292] -> 
             RGBColor[
              0.18009239570445779`, 0.3066189047757405, 0.9335673675613205], 
             UndirectedEdge[240, 310] -> 
             RGBColor[
              0.2766913122921885, 0.4081504908345045, 0.939068532955701], 
             UndirectedEdge[186, 300] -> 
             RGBColor[
              0.23083402862066274`, 0.35995157817601575`, 0.9364570284903794],
              UndirectedEdge[37, 240] -> 
             RGBColor[
              0.28113287624005423`, 0.4128188561551308, 0.9393214734518269], 
             UndirectedEdge[36, 429] -> 
             RGBColor[
              0.2739936283843697, 0.4053150540043482, 0.9389149038480165], 
             UndirectedEdge[56, 276] -> 
             RGBColor[
              0.7281068824339767, 0.4924523185511463, 0.5729718060098814], 
             UndirectedEdge[95, 174] -> 
             RGBColor[
              0.24687001390337449`, 0.3768064154483368, 0.9373702541291156], 
             UndirectedEdge[7, 28] -> 
             RGBColor[
              0.901769090567154, 0.9237583305634441, 0.9644245605513657], 
             UndirectedEdge[251, 367] -> 
             RGBColor[
              0.24419513183599667`, 0.3739949447982042, 0.9372179235525118], 
             UndirectedEdge[31, 314] -> 
             RGBColor[
              0.3915568678230763, 0.5135686115131106, 0.9461706352709112], 
             UndirectedEdge[238, 436] -> 
             RGBColor[
              0.3965368671240651, 0.5173498014044343, 0.9466350145946033], 
             UndirectedEdge[291, 488] -> 
             RGBColor[
              0.7121457205579194, 0.7750529164985673, 0.971943688111231], 
             UndirectedEdge[96, 171] -> 
             RGBColor[
              0.2789519797924134, 0.41052659571183897`, 0.939197274625481], 
             UndirectedEdge[127, 179] -> 
             RGBColor[
              0.20245447418328588`, 0.33012286709465477`, 0.9348408548489592],
              UndirectedEdge[296, 453] -> 
             RGBColor[
              0.2988633264806147, 0.4310225569001501, 0.9403470186360454], 
             UndirectedEdge[14, 494] -> 
             RGBColor[
              0.2826231066390982, 0.4143851827905905, 0.9394063398684542], 
             UndirectedEdge[317, 420] -> 
             RGBColor[
              0.9260215766566631, 0.7697821905786719, 0.5811912001414211], 
             UndirectedEdge[7, 388] -> 
             RGBColor[
              0.8924271040987608, 0.9167910923514154, 0.9802381068620604], 
             UndirectedEdge[146, 271] -> 
             RGBColor[
              0.25686927492861433`, 0.3873162727756304, 0.9379396972519218], 
             UndirectedEdge[331, 449] -> 
             RGBColor[
              0.7824972356635673, 0.8301470968699212, 0.9789198336489376], 
             UndirectedEdge[27, 359] -> 
             RGBColor[
              0.44878508964320496`, 0.5615402381340974, 0.9502583075299758], 
             UndirectedEdge[100, 471] -> 
             RGBColor[
              0.894013717811025, 0.6013444138663678, 0.23277457969666004`], 
             UndirectedEdge[219, 337] -> 
             RGBColor[
              0.6932397997764845, 0.7588302526554731, 0.971188910299956], 
             UndirectedEdge[199, 419] -> 
             RGBColor[
              0.4277672068152066, 0.5433200836247167, 0.948923355062986], 
             UndirectedEdge[266, 437] -> 
             RGBColor[
              0.2726756027922651, 0.40392972553939704`, 0.9388398442403902], 
             UndirectedEdge[327, 399] -> 
             RGBColor[
              0.24928505714751653`, 0.3793447790205158, 0.9375077872691331], 
             UndirectedEdge[311, 419] -> 
             RGBColor[
              0.6297737018777119, 0.70871691395749, 0.9650916972016379], 
             UndirectedEdge[267, 329] -> 
             RGBColor[
              0.9358102453449542, 0.941979730786866, 0.7003355368972839], 
             UndirectedEdge[219, 244] -> 
             RGBColor[
              0.43435496414043395`, 0.548657383494032, 0.949444989736919], 
             UndirectedEdge[17, 205] -> 
             RGBColor[
              0.9368989095333399, 0.9481665884975428, 0.7789256469520753], 
             UndirectedEdge[175, 361] -> 
             RGBColor[
              0.7999658560018515, 0.8442393091304512, 0.9624964661202554], 
             UndirectedEdge[189, 266] -> 
             RGBColor[
              0.2746480537102089, 0.4060028965147674, 0.9389521724021874], 
             UndirectedEdge[225, 280] -> 
             RGBColor[
              0.26557083518380836`, 0.39646216431462483`, 0.9384352382356503],
              UndirectedEdge[300, 458] -> 
             RGBColor[
              0.22822845140871784`, 0.35721295132312475`, 0.9363086447227651],
              UndirectedEdge[171, 343] -> 
             RGBColor[
              0.2773148667291586, 0.40880588608339485`, 0.9391040434584204], 
             UndirectedEdge[358, 408] -> 
             RGBColor[
              0.2240653730927813, 0.35283729205866493`, 0.936071563571395], 
             UndirectedEdge[380, 411] -> 
             RGBColor[
              0.2562205129796168, 0.38663438283335066`, 0.9379027512186837], 
             UndirectedEdge[345, 498] -> 
             RGBColor[
              0.5608073530060538, 0.6540616711594758, 0.9587498403781267], 
             UndirectedEdge[161, 450] -> 
             RGBColor[
              0.9040202207813182, 0.5580851531997648, 0.2907664410126593], 
             UndirectedEdge[94, 214] -> 
             RGBColor[
              0.5776130969249946, 0.6468062636067821, 0.9475190708650497], 
             UndirectedEdge[157, 343] -> 
             RGBColor[
              0.2977155588527831, 0.4302483069839126, 0.9402658326947413], 
             UndirectedEdge[155, 332] -> 
             RGBColor[
              0.4840405870433834, 0.5906167908800439, 0.9529081554374272], 
             UndirectedEdge[127, 168] -> 
             RGBColor[
              0.5683860156508949, 0.5194386987803812, 0.5916300590553423], 
             UndirectedEdge[378, 380] -> 
             RGBColor[
              0.27796774382392075`, 0.40949210130478847`, 0.939141223843122], 
             UndirectedEdge[160, 481] -> 
             RGBColor[
              0.3703492229848604, 0.49519961548147085`, 0.9448193028950042], 
             UndirectedEdge[23, 485] -> 
             RGBColor[
              0.2352513492635514, 0.3645944622459968, 0.9367085883661517], 
             UndirectedEdge[352, 399] -> 
             RGBColor[
              0.23466592421327268`, 0.3639791434000619, 0.936675249275597], 
             UndirectedEdge[389, 456] -> 
             RGBColor[
              0.22107915567658082`, 0.3496985882171184, 0.9359015029072553], 
             UndirectedEdge[105, 263] -> 
             RGBColor[
              0.2596529612026372, 0.3902421035455322, 0.9380982240671327], 
             UndirectedEdge[143, 347] -> 
             RGBColor[
              0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772],
              UndirectedEdge[98, 484] -> 
             RGBColor[
              0.9940632182259341, 0.9897101490230129, 0.5951961253421731], 
             UndirectedEdge[100, 500] -> 
             RGBColor[
              0.8753537574413516, 0.45791578161828494`, 0.21490578057324983`],
              UndirectedEdge[89, 424] -> 
             RGBColor[
              0.3030480744366626, 0.4347576504686087, 0.9406096220363795], 
             UndirectedEdge[231, 442] -> 
             RGBColor[
              0.2711958428958343, 0.40237440406605196`, 0.938755574103397], 
             UndirectedEdge[15, 104] -> 
             RGBColor[
              0.24040623048550225`, 0.3700125692486139, 0.9370021512257783], 
             UndirectedEdge[75, 182] -> 
             RGBColor[
              0.3617675856264607, 0.48776663252726005`, 0.9442724885509708], 
             UndirectedEdge[290, 316] -> 
             RGBColor[
              0.268490139738015, 0.3995305384956953, 0.9386014883112883], 
             UndirectedEdge[344, 424] -> 
             RGBColor[
              0.39216870621134226`, 0.5138154925134429, 0.9462878321282429], 
             UndirectedEdge[369, 425] -> 
             RGBColor[
              0.397645136695217, 0.5188419640048679, 0.9465585743797993], 
             UndirectedEdge[106, 255] -> 
             RGBColor[
              0.45772043203322, 0.569123825312507, 0.9508706958509441], 
             UndirectedEdge[84, 242] -> 
             RGBColor[
              0.22916096004104347`, 0.3581930770201611, 0.9363617497098533], 
             UndirectedEdge[143, 446] -> 
             RGBColor[
              0.20353913733189777`, 0.3312629168354616, 0.9349026248106573], 
             UndirectedEdge[376, 415] -> 
             RGBColor[
              0.28323389332621046`, 0.41502715832485815`, 0.9394411232667073],
              UndirectedEdge[93, 108] -> 
             RGBColor[
              0.27719798724909794`, 0.408683038339264, 0.9390973873449386], 
             UndirectedEdge[78, 183] -> 
             RGBColor[
              0.21219822021020854`, 0.34036416195813046`, 0.935395746770612], 
             UndirectedEdge[17, 298] -> 
             RGBColor[
              0.8908055349705915, 0.9157681695861948, 0.9894470212286257], 
             UndirectedEdge[204, 370] -> 
             RGBColor[
              0.546668194471859, 0.642848893250592, 0.9574548692618543], 
             UndirectedEdge[208, 314] -> 
             RGBColor[
              0.32609699892407057`, 0.4568705631814669, 0.9419995903085558], 
             UndirectedEdge[313, 379] -> 
             RGBColor[
              0.288128547073246, 0.4201206026991259, 0.9397217393007642], 
             UndirectedEdge[3, 221] -> 
             RGBColor[
              0.4991380572062573, 0.6042617866100937, 0.9537131227476765], 
             UndirectedEdge[154, 229] -> 
             RGBColor[
              0.3002585012900294, 0.4328475787158096, 0.940413341505228], 
             UndirectedEdge[25, 180] -> 
             RGBColor[
              0.2917531123703574, 0.42355338894303707`, 0.9399419516850931], 
             UndirectedEdge[371, 419] -> 
             RGBColor[
              0.43781722710861815`, 0.5520249060741627, 0.9495637334691982], 
             UndirectedEdge[31, 419] -> 
             RGBColor[
              0.4828643991449212, 0.5910425023553091, 0.9524340994377012], 
             UndirectedEdge[321, 482] -> 
             RGBColor[
              0.3458284457686297, 0.47396095070686983`, 0.9432568606536578], 
             UndirectedEdge[212, 300] -> 
             RGBColor[
              0.22223694937519295`, 0.35091550280272016`, 0.9359674375455889],
              UndirectedEdge[376, 414] -> 
             RGBColor[
              0.27705653417076703`, 0.40853436218529504`, 0.9390893318013886],
              UndirectedEdge[140, 274] -> 
             RGBColor[
              0.4811841626563286, 0.5896860062007292, 0.9522997264014235], 
             UndirectedEdge[1, 131] -> 
             RGBColor[
              0.26488726968740706`, 0.3957436936373514, 0.9383963101918749], 
             UndirectedEdge[360, 466] -> 
             RGBColor[
              0.5414372478398441, 0.638602175123262, 0.9570430699813932], 
             UndirectedEdge[165, 182] -> 
             RGBColor[
              0.4013099579800705, 0.5220162480025345, 0.9467920935513959], 
             UndirectedEdge[268, 480] -> 
             RGBColor[
              0.3816010072146523, 0.5049453454501976, 0.9455362566365644], 
             UndirectedEdge[54, 385] -> 
             RGBColor[
              0.23109619211781043`, 0.36022712863364376`, 0.9364719583137058],
              UndirectedEdge[149, 158] -> 
             RGBColor[
              0.3556980515257828, 0.48250950715290686`, 0.943885743205154], 
             UndirectedEdge[229, 379] -> 
             RGBColor[
              0.30013749915285226`, 0.43274277274633094`, 0.9404056313560452],
              UndirectedEdge[98, 253] -> 
             RGBColor[
              0.9901332923121124, 0.9901471046097305, 0.8102166844391167], 
             UndirectedEdge[121, 469] -> 
             RGBColor[
              0.8439483097229172, 0.3356254845618147, 0.18959349898373934`], 
             UndirectedEdge[34, 269] -> 
             RGBColor[
              0.4963462045644428, 0.6018763440007352, 0.9535261877805588], 
             UndirectedEdge[145, 286] -> 
             RGBColor[
              0.22187921582518422`, 0.3505395021600439, 0.9359470651491353], 
             UndirectedEdge[34, 234] -> 
             RGBColor[
              0.4661658558479902, 0.5757356428509766, 0.951603122647781], 
             UndirectedEdge[85, 286] -> 
             RGBColor[
              0.21865790979829205`, 0.3471537052831816, 0.935763616536399], 
             UndirectedEdge[86, 261] -> 
             RGBColor[
              0.897589954080166, 0.6247029436909717, 0.23609548573218275`], 
             UndirectedEdge[140, 255] -> 
             RGBColor[
              0.4486097951007969, 0.5617273998212495, 0.950153473138261], 
             UndirectedEdge[345, 448] -> 
             RGBColor[
              0.6138322543981429, 0.6971096748541594, 0.9629241548523259], 
             UndirectedEdge[146, 444] -> 
             RGBColor[
              0.2646131387661169, 0.39545556465817117`, 0.9383806988414477], 
             UndirectedEdge[215, 224] -> 
             RGBColor[
              0.2915446973152564, 0.4237623402527527, 0.9399144112591507], 
             UndirectedEdge[40, 359] -> 
             RGBColor[
              0.38582570994179444`, 0.508604570612715, 0.9458054509585798], 
             UndirectedEdge[88, 495] -> 
             RGBColor[
              0.8544062989949438, 0.4062909143031017, 0.1992274995322182], 
             UndirectedEdge[341, 403] -> 
             RGBColor[
              0.9612426733705868, 0.9674078133042042, 0.7674804702008887], 
             UndirectedEdge[134, 416] -> 
             RGBColor[
              0.24737003573452257`, 0.37733197009608865`, 0.9373987296326833],
              UndirectedEdge[113, 423] -> 
             RGBColor[
              0.1835090760837748, 0.31021005248445066`, 0.9337619424543968], 
             UndirectedEdge[204, 362] -> 
             RGBColor[
              0.4451772959687064, 0.5586930048020928, 0.9499517048675632], 
             UndirectedEdge[231, 256] -> 
             RGBColor[
              0.27391624912615603`, 0.40523372349783726`, 0.9389104972137335],
              UndirectedEdge[183, 407] -> 
             RGBColor[
              0.2096628417623121, 0.3376993184571131, 0.9352513607187605], 
             UndirectedEdge[231, 271] -> 
             RGBColor[
              0.25712583983655113`, 0.38758593876102676`, 0.9379543082438752],
              UndirectedEdge[106, 140] -> 
             RGBColor[
              0.508744701282457, 0.6120608930455363, 0.9544693929596517], 
             UndirectedEdge[96, 147] -> 
             RGBColor[
              0.27382745193814473`, 0.40514039202317054`, 0.9389054403452399],
              UndirectedEdge[149, 275] -> 
             RGBColor[
              0.38378936730216673`, 0.5068407929678266, 0.9456756970062499], 
             UndirectedEdge[207, 287] -> 
             RGBColor[
              0.21343735530821623`, 0.3416665715118395, 0.9354663136813074], 
             UndirectedEdge[223, 480] -> 
             RGBColor[
              0.3717055099769321, 0.496374363105037, 0.9449057243028214], 
             UndirectedEdge[11, 102] -> 
             RGBColor[
              0.2577278443328788, 0.3882186836559568, 0.9379885915093551], 
             UndirectedEdge[230, 339] -> 
             RGBColor[
              0.21778435426976317`, 0.3462355430360783, 0.9357138688413589], 
             UndirectedEdge[103, 449] -> 
             RGBColor[
              0.6043292409167387, 0.6883441793156388, 0.9628942898259707], 
             UndirectedEdge[226, 396] -> 
             RGBColor[
              0.5864855268156967, 0.6472607121015193, 0.7362180745608087], 
             UndirectedEdge[144, 279] -> 
             RGBColor[
              0.2623939933592224, 0.3931231021335797, 0.9382543217934566], 
             UndirectedEdge[205, 228] -> 
             RGBColor[
              0.9934539331599859, 0.9884069498751192, 0.5288792059852668], 
             UndirectedEdge[267, 406] -> 
             RGBColor[
              0.9898404936899885, 0.9773917410301207, 0.415032665757733], 
             UndirectedEdge[209, 233] -> 
             RGBColor[
              0.7045416845554648, 0.49561598240663746`, 0.5739669497124782], 
             UndirectedEdge[387, 405] -> 
             RGBColor[
              0.8845632449194131, 0.9069230619459494, 0.7839577394340637], 
             UndirectedEdge[75, 206] -> 
             RGBColor[
              0.34384133423410757`, 0.4722398145707964, 0.9431302436638118], 
             UndirectedEdge[183, 404] -> 
             RGBColor[
              0.20920782453695042`, 0.33722106650349953`, 0.9352254481609139],
              UndirectedEdge[319, 488] -> 
             RGBColor[
              0.7421269925364968, 0.7984745140343386, 0.9749319411111395], 
             UndirectedEdge[220, 371] -> 
             RGBColor[
              0.3509285621764658, 0.4783784152000333, 0.9435818355613093], 
             UndirectedEdge[66, 460] -> 
             RGBColor[
              0.2558136629427209, 0.38620675764879087`, 0.9378795817109632], 
             UndirectedEdge[87, 446] -> 
             RGBColor[
              0.20370226760912918`, 0.33143437709988877`, 0.934911914838616], 
             UndirectedEdge[273, 308] -> 
             RGBColor[
              0.23624385022904204`, 0.36563764368892326`, 0.9367651098278627],
              UndirectedEdge[326, 428] -> 
             RGBColor[
              0.8527545036662538, 0.3801225472055363, 0.19711821090416948`], 
             UndirectedEdge[130, 315] -> 
             RGBColor[
              0.1822133081343763, 0.30884811821319974`, 0.9336881503865955], 
             UndirectedEdge[95, 407] -> 
             RGBColor[
              0.22072063099008732`, 0.34932175603983573`, 0.9358810854567492],
              UndirectedEdge[148, 153] -> 
             RGBColor[
              0.2422944032111111, 0.37199715850029413`, 0.9371096798692006], 
             UndirectedEdge[85, 137] -> 
             RGBColor[
              0.21714804821848613`, 0.34556674503205226`, 0.9356776321530691],
              UndirectedEdge[289, 359] -> 
             RGBColor[
              0.4124111574915527, 0.5316315490568694, 0.9474994521678624], 
             UndirectedEdge[32, 449] -> 
             RGBColor[
              0.6320067542390264, 0.7108140314884382, 0.9650731650607731], 
             UndirectedEdge[329, 406] -> 
             RGBColor[
              0.9365881325497546, 0.9446037269852596, 0.7033574817962612], 
             UndirectedEdge[168, 213] -> 
             RGBColor[
              0.9074990588325569, 0.6709655443987909, 0.2444294609060539], 
             UndirectedEdge[111, 464] -> 
             RGBColor[
              0.2584790029138965, 0.3890081989508112, 0.9380313688793045], 
             UndirectedEdge[50, 117] -> 
             RGBColor[
              0.41100665014042015`, 0.5304150353819104, 0.9474099582014052], 
             UndirectedEdge[357, 420] -> 
             RGBColor[
              0.937892556639665, 0.822845791169284, 0.5910531975827036], 
             UndirectedEdge[153, 190] -> 
             RGBColor[
              0.24652129125596123`, 0.3764398858356126, 0.9373503948902342], 
             UndirectedEdge[165, 275] -> 
             RGBColor[
              0.41886860868054065`, 0.537224668715837, 0.9479109152475247], 
             UndirectedEdge[152, 301] -> 
             RGBColor[
              0.2063778078751808, 0.33424653955855976`, 0.9350642828986606], 
             UndirectedEdge[208, 349] -> 
             RGBColor[
              0.3678599975315118, 0.49304357350588934`, 0.9446606916502523], 
             UndirectedEdge[5, 23] -> 
             RGBColor[
              0.23055442452635688`, 0.3596576965449768, 0.9364411054508459], 
             UndirectedEdge[56, 227] -> 
             RGBColor[
              0.8411523878247509, 0.31732086267817405`, 0.187040879096943], 
             UndirectedEdge[56, 326] -> 
             RGBColor[
              0.8559245599190561, 0.404488988692082, 0.2001538603519194], 
             UndirectedEdge[155, 181] -> 
             RGBColor[
              0.49329315877378277`, 0.5986309034651389, 0.9534977211263604], 
             UndirectedEdge[148, 323] -> 
             RGBColor[
              0.23950025424315785`, 0.36906033077569844`, 0.9369505572190486],
              UndirectedEdge[177, 438] -> 
             RGBColor[
              0.21508055771107348`, 0.3433936814222922, 0.9355598916272501], 
             UndirectedEdge[53, 90] -> 
             RGBColor[
              0.9206410418975434, 0.7056328015929743, 0.28606405077970154`], 
             UndirectedEdge[30, 217] -> 
             RGBColor[
              0.2938254921740675, 0.42514500116830317`, 0.9400814485951139], 
             UndirectedEdge[43, 290] -> 
             RGBColor[
              0.2898165263474991, 0.4219459229932718, 0.9398159944791369], 
             UndirectedEdge[114, 397] -> 
             RGBColor[
              0.4296132686116584, 0.545245204928905, 0.9489508667899835], 
             UndirectedEdge[227, 320] -> 
             RGBColor[
              0.9171168323829694, 0.670650788557899, 0.5149397016540836], 
             UndirectedEdge[298, 432] -> 
             RGBColor[
              0.9001321413614187, 0.9232049523582542, 0.9903366012721426], 
             UndirectedEdge[42, 85] -> 
             RGBColor[
              0.22334491181980198`, 0.3520800415808806, 0.9360305343677259], 
             UndirectedEdge[329, 413] -> 
             RGBColor[
              0.9281969547806851, 0.9162983140279535, 0.6707593407043844], 
             UndirectedEdge[244, 380] -> 
             RGBColor[
              0.3076460451816098, 0.43757054210239044`, 0.9409454268990441], 
             UndirectedEdge[87, 113] -> 
             RGBColor[
              0.17922276129889142`, 0.3057048638774843, 0.9335178431684322], 
             UndirectedEdge[334, 370] -> 
             RGBColor[
              0.49712370807879736`, 0.6012548758448955, 0.9539335150694623], 
             UndirectedEdge[24, 278] -> 
             RGBColor[
              0.8926678774514412, 0.9169265621366819, 0.9783016146877055], 
             UndirectedEdge[51, 325] -> 
             RGBColor[
              0.17897196058988912`, 0.30544125643063946`, 0.933503560439081], 
             UndirectedEdge[112, 463] -> 
             RGBColor[
              0.2576804433404335, 0.3881688622075002, 0.9379858920929589], 
             UndirectedEdge[308, 421] -> 
             RGBColor[
              0.1790014452743907, 0.3054722467034876, 0.9335052395482446], 
             UndirectedEdge[302, 421] -> 
             RGBColor[
              0.18460298206136966`, 0.31135981702454774`, 0.9338242387815321],
              UndirectedEdge[103, 488] -> 
             RGBColor[
              0.6248600030483947, 0.70438296673246, 0.9649406043243738], 
             UndirectedEdge[225, 424] -> 
             RGBColor[
              0.2974218624617132, 0.42884414496049433`, 0.940289217587641], 
             UndirectedEdge[205, 388] -> 
             RGBColor[
              0.9699993320336204, 0.9742898944709728, 0.7727192137216462], 
             UndirectedEdge[114, 297] -> 
             RGBColor[
              0.5100213466264654, 0.6130973312480197, 0.954569895157638], 
             UndirectedEdge[203, 381] -> 
             RGBColor[
              0.5519357188644908, 0.6471253068518, 0.9578695480776199], 
             UndirectedEdge[17, 252] -> 
             RGBColor[
              0.8078836333626171, 0.8503289562761027, 0.9813572830192461], 
             UndirectedEdge[361, 363] -> 
             RGBColor[
              0.5245064025228867, 0.6235116591529769, 0.9560934187929221], 
             UndirectedEdge[318, 383] -> 
             RGBColor[
              0.3354424216880899, 0.46496509866505487`, 0.9425950723832464], 
             UndirectedEdge[209, 273] -> 
             RGBColor[
              0.4297324939516893, 0.5421711471050089, 0.9494994222745707], 
             UndirectedEdge[47, 230] -> 
             RGBColor[
              0.22790583767600858`, 0.3568738638351552, 0.9362902723479516], 
             UndirectedEdge[1, 170] -> 
             RGBColor[
              0.2814230291570491, 0.41312382526764985`, 0.939337997231207], 
             UndirectedEdge[139, 247] -> 
             RGBColor[
              0.529523280699882, 0.6289298798809373, 0.9561051588458358], 
             UndirectedEdge[246, 288] -> 
             RGBColor[
              0.2751436592994766, 0.40652380941229693`, 0.9389803964073136], 
             UndirectedEdge[1, 147] -> 
             RGBColor[
              0.2588293294875211, 0.38937641439167825`, 0.9380513194594108], 
             UndirectedEdge[352, 457] -> 
             RGBColor[
              0.22470998276050042`, 0.3535148176900512, 0.9361082731383572], 
             UndirectedEdge[157, 238] -> 
             RGBColor[
              0.31134876495031627`, 0.4435229307952213, 0.9410808428186908], 
             UndirectedEdge[97, 145] -> 
             RGBColor[
              0.2261963371710197, 0.3550770704158197, 0.9361929188231719], 
             UndirectedEdge[83, 237] -> 
             RGBColor[
              0.913419047498675, 0.933799570648643, 0.9916039182408752], 
             UndirectedEdge[73, 494] -> 
             RGBColor[
              0.25320700081228975`, 0.383466990477783, 0.9377311361588463], 
             UndirectedEdge[101, 197] -> 
             RGBColor[
              0.6092291752169602, 0.6927921015850171, 0.9629587335694303], 
             UndirectedEdge[224, 356] -> 
             RGBColor[
              0.28415211148803254`, 0.41599226383132715`, 0.939493414432641], 
             UndirectedEdge[182, 441] -> 
             RGBColor[
              0.41435953118072005`, 0.5333191324183171, 0.9476236008164568], 
             UndirectedEdge[160, 480] -> 
             RGBColor[
              0.3880144919727734, 0.5105003835965654, 0.94594491821413], 
             UndirectedEdge[263, 440] -> 
             RGBColor[
              0.2775372454156354, 0.40903962018250506`, 0.9391167075956355], 
             UndirectedEdge[31, 223] -> 
             RGBColor[
              0.42145102378698707`, 0.5394614268850837, 0.9480754644545675], 
             UndirectedEdge[5, 102] -> 
             RGBColor[
              0.2575724490549457, 0.3880553533662194, 0.9379797419781635], 
             UndirectedEdge[171, 216] -> 
             RGBColor[
              0.26381410331866717`, 0.39461572774112796`, 0.9383351949547825],
              UndirectedEdge[102, 414] -> 
             RGBColor[
              0.27559776236137046`, 0.40700110052214455`, 0.9390062569049031],
              UndirectedEdge[68, 205] -> 
             RGBColor[
              0.9069065109079608, 0.5719171126049378, 0.3681050087560027], 
             UndirectedEdge[111, 376] -> 
             RGBColor[
              0.2762731715166523, 0.4077109983677596, 0.9390447204571181], 
             UndirectedEdge[302, 325] -> 
             RGBColor[
              0.18458313935535953`, 0.31133896108243087`, 0.9338231087687794],
              UndirectedEdge[39, 315] -> 
             RGBColor[
              0.40458060190845924`, 0.5088289173445842, 0.948695685987052], 
             UndirectedEdge[66, 314] -> 
             RGBColor[
              0.29667827269945046`, 0.4271859979700665, 0.9402789673950056], 
             UndirectedEdge[274, 370] -> 
             RGBColor[
              0.5270887992770681, 0.6269534581897589, 0.9559135075504326], 
             UndirectedEdge[94, 477] -> 
             RGBColor[
              0.6000453532177727, 0.6703839872576882, 0.948796554675374], 
             UndirectedEdge[99, 329] -> 
             RGBColor[
              0.9380897089070905, 0.9489785735157732, 0.7678909167681753], 
             UndirectedEdge[25, 465] -> 
             RGBColor[
              0.2980004320712376, 0.430119718051609, 0.9402977272999771], 
             UndirectedEdge[223, 381] -> 
             RGBColor[
              0.47958429341648956`, 0.5866642295649169, 0.9526498297239985], 
             UndirectedEdge[196, 318] -> 
             RGBColor[
              0.3188208288656592, 0.44936205704600285`, 0.9415801260303202], 
             UndirectedEdge[76, 462] -> 
             RGBColor[
              0.4376018334802528, 0.5531637078002476, 0.949183806517649], 
             UndirectedEdge[89, 440] -> 
             RGBColor[
              0.2835877779164691, 0.415399113466799, 0.9394612764705972], 
             UndirectedEdge[88, 326] -> 
             RGBColor[
              0.8708928189630238, 0.5066362693068722, 0.21398214224720047`], 
             UndirectedEdge[149, 282] -> 
             RGBColor[
              0.48076658116172494`, 0.586646877963116, 0.9530129031646457], 
             UndirectedEdge[238, 462] -> 
             RGBColor[
              0.392016142899485, 0.5136796738226148, 0.9462791266236859], 
             UndirectedEdge[168, 261] -> 
             RGBColor[
              0.8953895182633258, 0.6159789489289689, 0.23432496342308617`], 
             UndirectedEdge[155, 344] -> 
             RGBColor[
              0.5148160505883743, 0.6169898879232494, 0.9549473518170989], 
             UndirectedEdge[4, 496] -> 
             RGBColor[
              0.3005965950412318, 0.4318380479282125, 0.9404825707076422], 
             UndirectedEdge[87, 226] -> 
             RGBColor[
              0.17933912709972993`, 0.30582717171218354`, 0.9335244700286423],
              UndirectedEdge[128, 362] -> 
             RGBColor[
              0.4416023765346493, 0.55579072415724, 0.9496702741143528], 
             UndirectedEdge[295, 389] -> 
             RGBColor[
              0.22404383278435813`, 0.3528146518287777, 0.9360703368826964], 
             UndirectedEdge[89, 133] -> 
             RGBColor[
              0.3153376912434113, 0.4454022988525135, 0.9413927055520241], 
             UndirectedEdge[33, 164] -> 
             RGBColor[
              0.8479694807729221, 0.33824875648589925`, 0.19233659900141542`],
              UndirectedEdge[276, 396] -> 
             RGBColor[
              0.8065431088390325, 0.8453068187334528, 0.7510492031181083], 
             UndirectedEdge[50, 274] -> 
             RGBColor[
              0.4518361438965558, 0.5655238171616463, 0.9500822208063486], 
             UndirectedEdge[21, 375] -> 
             RGBColor[
              0.9695446020803578, 0.9577696846543478, 0.6679456249234423], 
             UndirectedEdge[41, 485] -> 
             RGBColor[
              0.24026393309017596`, 0.36986300566395003`, 0.9369940475996247],
              UndirectedEdge[30, 316] -> 
             RGBColor[
              0.25921313179459604`, 0.3897798149508858, 0.938073176433014], 
             UndirectedEdge[285, 324] -> 
             RGBColor[
              0.3420478957119857, 0.4706864282637755, 0.9430159673470576], 
             UndirectedEdge[95, 358] -> 
             RGBColor[
              0.2263545662938538, 0.3552433792562242, 0.9362019297376383], 
             UndirectedEdge[333, 492] -> 
             RGBColor[
              0.32763422405457243`, 0.45523169861929097`, 0.9422062993288807],
              UndirectedEdge[332, 393] -> 
             RGBColor[
              0.4317017689879543, 0.548125780545763, 0.9487878519566961], 
             UndirectedEdge[418, 420] -> 
             RGBColor[
              0.9735581601714495, 0.9798002996671817, 0.9296433170801228], 
             UndirectedEdge[107, 273] -> 
             RGBColor[
              0.2391065540897807, 0.3686465269524677, 0.9369281365777409], 
             UndirectedEdge[310, 483] -> 
             RGBColor[
              0.2967031212326041, 0.4291841708528518, 0.9402081758700394], 
             UndirectedEdge[155, 403] -> 
             RGBColor[
              0.7474005481861847, 0.8023032590432388, 0.9760248292713649], 
             UndirectedEdge[140, 169] -> 
             RGBColor[
              0.4961881243257401, 0.601866898204728, 0.953480893225362], 
             UndirectedEdge[147, 216] -> 
             RGBColor[
              0.2586895754643985, 0.38922952405245953`, 0.9380433606745415], 
             UndirectedEdge[70, 171] -> 
             RGBColor[
              0.25999619432080096`, 0.39060286331495886`, 0.9381177706854442],
              UndirectedEdge[7, 402] -> 
             RGBColor[
              0.6954966701641224, 0.7608182646923372, 0.971187276045136], 
             UndirectedEdge[185, 409] -> 
             RGBColor[
              0.262750205623448, 0.39349750380844273`, 0.9382746075549353], 
             UndirectedEdge[126, 481] -> 
             RGBColor[
              0.28467725623571494`, 0.41566859359098884`, 0.9395553817772139],
              UndirectedEdge[115, 311] -> 
             RGBColor[
              0.8340126241816578, 0.871074103507641, 0.9838732137113628], 
             UndirectedEdge[383, 496] -> 
             RGBColor[
              0.30291603178424115`, 0.4338470274567268, 0.9406303631659094], 
             UndirectedEdge[8, 297] -> 
             RGBColor[
              0.5698289191235334, 0.6616518129015765, 0.9592781663469641], 
             UndirectedEdge[381, 439] -> 
             RGBColor[
              0.7151086431122187, 0.7765792866784462, 0.9729163506443089], 
             UndirectedEdge[16, 276] -> 
             RGBColor[
              0.5117111188744836, 0.6131268633886855, 0.9550738020104051], 
             UndirectedEdge[74, 342] -> 
             RGBColor[
              0.27086057814160247`, 0.4020220195523411, 0.9387364812716233], 
             UndirectedEdge[26, 269] -> 
             RGBColor[
              0.4177844388725415, 0.5362856153201071, 0.9478418329060527], 
             UndirectedEdge[127, 315] -> 
             RGBColor[
              0.20573971378665917`, 0.3335758622140216, 0.9350279443842948], 
             UndirectedEdge[175, 348] -> 
             RGBColor[
              0.9578209370783626, 0.9214694359811255, 0.6292929486935749], 
             UndirectedEdge[180, 288] -> 
             RGBColor[
              0.2630984263915931, 0.39386350591423513`, 0.9382944382125347], 
             UndirectedEdge[288, 343] -> 
             RGBColor[
              0.274476709135814, 0.40582280250320485`, 0.9389424145821572], 
             UndirectedEdge[484, 500] -> 
             RGBColor[
              0.9061921804601966, 0.5690195539734165, 0.316991474169404], 
             UndirectedEdge[59, 323] -> 
             RGBColor[
              0.24076788547771533`, 0.3703926915756808, 0.9370227469425643], 
             UndirectedEdge[108, 189] -> 
             RGBColor[
              0.27244302962866296`, 0.40368527639846097`, 0.9388265995427842],
              UndirectedEdge[59, 74] -> 
             RGBColor[
              0.26196255890659237`, 0.3926696371693413, 0.9382297522396293], 
             UndirectedEdge[40, 199] -> 
             RGBColor[
              0.3645220176644419, 0.4901523831167798, 0.9444479985247825], 
             UndirectedEdge[69, 241] -> 
             RGBColor[
              0.8074723242442312, 0.8502460052781141, 0.9812530323476005], 
             UndirectedEdge[275, 353] -> 
             RGBColor[
              0.5266832510882068, 0.6255486018899017, 0.9561787766673014], 
             UndirectedEdge[196, 335] -> 
             RGBColor[
              0.2862357534512077, 0.4181823036451551, 0.9396120747599719], 
             UndirectedEdge[157, 281] -> 
             RGBColor[
              0.2737261355645935, 0.4050339020907391, 0.9388996705276503], 
             UndirectedEdge[120, 438] -> 
             RGBColor[
              0.21444303080234048`, 0.3427236002196732, 0.9355235854129342], 
             UndirectedEdge[152, 389] -> 
             RGBColor[
              0.21125135912011495`, 0.33936895091798147`, 0.9353418244322866],
              UndirectedEdge[126, 144] -> 
             RGBColor[
              0.24868278916139275`, 0.37871175718110384`, 0.937473488998299], 
             UndirectedEdge[96, 157] -> 
             RGBColor[
              0.29935267191603787`, 0.43196901661235676`, 0.940359063861802], 
             UndirectedEdge[303, 366] -> 
             RGBColor[
              0.2851324087513453, 0.4170226184095053, 0.9395492409115669], 
             UndirectedEdge[119, 309] -> 
             RGBColor[
              0.9918390696706652, 0.9889511495464178, 0.6437403499501158], 
             UndirectedEdge[325, 386] -> 
             RGBColor[
              0.1789719601845752, 0.3054412560046289, 0.9335035604159989], 
             UndirectedEdge[27, 220] -> 
             RGBColor[
              0.4255160611016982, 0.5413857751468245, 0.948775625607305], 
             UndirectedEdge[95, 346] -> 
             RGBColor[
              0.22248278830370904`, 0.3511738951036789, 0.9359814377088818], 
             UndirectedEdge[235, 239] -> 
             RGBColor[
              0.35398612023304477`, 0.4810267183113057, 0.943776660456982], 
             UndirectedEdge[64, 303] -> 
             RGBColor[
              0.29654648477504475`, 0.4290195360046319, 0.9401992556555043], 
             UndirectedEdge[310, 429] -> 
             RGBColor[
              0.2951775190785565, 0.4275806662601843, 0.9401212950842925], 
             UndirectedEdge[67, 238] -> 
             RGBColor[
              0.28838849579729153`, 0.41939023215024707`, 0.9397732894571003],
              UndirectedEdge[38, 108] -> 
             RGBColor[
              0.272539685244709, 0.40378686757924537`, 0.9388321039371288], 
             UndirectedEdge[20, 490] -> 
             RGBColor[
              0.9375437932423437, 0.7794697399272263, 0.5157901036631747], 
             UndirectedEdge[112, 148] -> 
             RGBColor[
              0.2439596839808273, 0.373747474174165, 0.9372045151454738], 
             UndirectedEdge[76, 402] -> 
             RGBColor[
              0.4818182674522101, 0.589060600826333, 0.952664686170056], 
             UndirectedEdge[99, 406] -> 
             RGBColor[
              0.992119957252125, 0.9843905837590278, 0.48258804562862445`], 
             UndirectedEdge[8, 258] -> 
             RGBColor[
              0.4968580357130886, 0.6002414107444907, 0.9541330294430466], 
             UndirectedEdge[15, 153] -> 
             RGBColor[
              0.23958587882071014`, 0.3691503276356177, 0.93695543341207], 
             UndirectedEdge[195, 463] -> 
             RGBColor[
              0.2686246431474216, 0.3996719101069903, 0.9386091480814742], 
             UndirectedEdge[184, 249] -> 
             RGBColor[
              0.2732898707787555, 0.40457536014003825`, 0.9388748258934928], 
             UndirectedEdge[109, 185] -> 
             RGBColor[
              0.26895237692670115`, 0.40001637908853493`, 0.9386278120353654],
              UndirectedEdge[77, 81] -> 
             RGBColor[
              0.7152180111578499, 0.7769379420233913, 0.972614350327299], 
             UndirectedEdge[355, 384] -> 
             RGBColor[
              0.3062638013444511, 0.43738753923394075`, 0.9408202157153518], 
             UndirectedEdge[67, 343] -> 
             RGBColor[
              0.2747552896997584, 0.40611560833893834`, 0.9389582793331509], 
             UndirectedEdge[247, 255] -> 
             RGBColor[
              0.4462984536881862, 0.5598509487377481, 0.9499715158755377], 
             UndirectedEdge[95, 145] -> 
             RGBColor[
              0.22387054333517215`, 0.3526325136304976, 0.9360604683049241], 
             UndirectedEdge[220, 416] -> 
             RGBColor[
              0.3002234451567067, 0.4300950902197503, 0.9405107780769688], 
             UndirectedEdge[287, 451] -> 
             RGBColor[
              0.21062876698303812`, 0.3387145671072923, 0.9353063687311225], 
             UndirectedEdge[387, 491] -> 
             RGBColor[
              0.8846376192086578, 0.9070821410302499, 0.7920529218334498], 
             UndirectedEdge[211, 464] -> 
             RGBColor[
              0.23745358448324252`, 0.36690915109166977`, 0.936834002403998], 
             UndirectedEdge[335, 482] -> 
             RGBColor[
              0.3176268052914761, 0.44657790833086347`, 0.9415681179813948], 
             UndirectedEdge[214, 423] -> 
             RGBColor[
              0.19381650316255092`, 0.32104381187286724`, 0.9343489351780614],
              UndirectedEdge[69, 194] -> 
             RGBColor[
              0.9479892988678673, 0.9596684021789683, 0.9321766809000795], 
             UndirectedEdge[111, 312] -> 
             RGBColor[
              0.28875139009156847`, 0.4208263972547496, 0.9397553365450895], 
             UndirectedEdge[174, 294] -> 
             RGBColor[
              0.2524849252558091, 0.3827080432856873, 0.9376900150241196], 
             UndirectedEdge[212, 295] -> 
             RGBColor[
              0.22405206726645135`, 0.35282330679155405`, 0.9360708058242697],
              UndirectedEdge[193, 414] -> 
             RGBColor[
              0.28123484292780576`, 0.41292602960901903`, 0.9393272803038482],
              UndirectedEdge[320, 348] -> 
             RGBColor[
              0.9742570536765062, 0.9329947209284535, 0.5686571215977747], 
             UndirectedEdge[247, 468] -> 
             RGBColor[
              0.48669420259584584`, 0.5941593048480999, 0.9527334969294036], 
             UndirectedEdge[449, 488] -> 
             RGBColor[
              0.7488335383665432, 0.8037137186084069, 0.9756003869232444], 
             UndirectedEdge[290, 355] -> 
             RGBColor[
              0.30759602149261944`, 0.4387877870773017, 0.9408960836819469], 
             UndirectedEdge[88, 469] -> 
             RGBColor[
              0.8635204022958338, 0.47315984709282155`, 0.20783041706562805`],
              UndirectedEdge[6, 278] -> 
             RGBColor[
              0.8880267801577246, 0.9132258771339024, 0.9778589426846744], 
             UndirectedEdge[24, 448] -> 
             RGBColor[
              0.7024556642269519, 0.7664802639694746, 0.97172087084446], 
             UndirectedEdge[204, 274] -> 
             RGBColor[
              0.4823136561574142, 0.5906029799080129, 0.9523886442672999], 
             UndirectedEdge[81, 99] -> 
             RGBColor[
              0.9086198401868935, 0.9254801001365643, 0.7650800543815806], 
             UndirectedEdge[213, 368] -> 
             RGBColor[
              0.6561537738248766, 0.5929010247462924, 0.5945021229284573], 
             UndirectedEdge[167, 474] -> 
             RGBColor[
              0.9898837045140847, 0.9900846660867081, 0.8173167265425048], 
             UndirectedEdge[78, 430] -> 
             RGBColor[
              0.22958406238534357`, 0.3586377844102586, 0.9363858447624374], 
             UndirectedEdge[110, 316] -> 
             RGBColor[
              0.26110517012024004`, 0.39176846719329617`, 0.9381809252166395],
              UndirectedEdge[153, 463] -> 
             RGBColor[
              0.25601516257071727`, 0.38641854653362934`, 0.9378910568166856],
              UndirectedEdge[471, 475] -> 
             RGBColor[
              0.847907987036376, 0.36924735854117574`, 0.19351004853135326`], 
             UndirectedEdge[79, 486] -> 
             RGBColor[
              0.9643781566417168, 0.9700792377693064, 0.7816636594414414], 
             UndirectedEdge[49, 402] -> 
             RGBColor[
              0.521262974366249, 0.6222237910767345, 0.9554548772727531], 
             UndirectedEdge[340, 498] -> 
             RGBColor[
              0.39966203669691347`, 0.5203561647804322, 0.9467513952897255], 
             UndirectedEdge[248, 313] -> 
             RGBColor[
              0.254748775686199, 0.38508749362443473`, 0.9378189379570638], 
             UndirectedEdge[37, 429] -> 
             RGBColor[
              0.29961908302642226`, 0.4322490315808106, 0.9403742355804184], 
             UndirectedEdge[18, 166] -> 
             RGBColor[
              0.8612521660936727, 0.43095598829613885`, 0.2046884517082866], 
             UndirectedEdge[147, 238] -> 
             RGBColor[
              0.2858235449724231, 0.4166943062060351, 0.9396272193021288], 
             UndirectedEdge[165, 441] -> 
             RGBColor[
              0.4370828286560343, 0.553000910585295, 0.9490715092381609], 
             UndirectedEdge[13, 154] -> 
             RGBColor[
              0.3030787322552839, 0.435811820273263, 0.9405739494865415], 
             UndirectedEdge[133, 249] -> 
             RGBColor[
              0.3173607671926588, 0.44752867994559636`, 0.9415079167344612], 
             UndirectedEdge[84, 385] -> 
             RGBColor[
              0.2333929402174702, 0.3626411565086264, 0.9366027547202471], 
             UndirectedEdge[125, 438] -> 
             RGBColor[
              0.2150690714922951, 0.34338160867808776`, 0.9355592375040829], 
             UndirectedEdge[21, 489] -> 
             RGBColor[
              0.9854926800563032, 0.9686826013172827, 0.5970125136401502], 
             UndirectedEdge[16, 200] -> 
             RGBColor[
              0.6523550443789783, 0.5834045301394526, 0.5929583920999518], 
             UndirectedEdge[402, 436] -> 
             RGBColor[
              0.5126155235296384, 0.6152034009243532, 0.954774118266239], 
             UndirectedEdge[127, 401] -> 
             RGBColor[
              0.499716094491864, 0.5888978154955886, 0.9571173753725956], 
             UndirectedEdge[195, 395] -> 
             RGBColor[
              0.26756974901772024`, 0.3985631494925233, 0.9385490734213637], 
             UndirectedEdge[27, 297] -> 
             RGBColor[
              0.5157415629468824, 0.6177412605497428, 0.9550202115402241], 
             UndirectedEdge[35, 70] -> 
             RGBColor[
              0.24831129577393707`, 0.37832129407684667`, 0.9374523329994586],
              UndirectedEdge[240, 367] -> 
             RGBColor[
              0.24323530728920995`, 0.3729861083431402, 0.9371632629645055], 
             UndirectedEdge[121, 471] -> 
             RGBColor[
              0.842139262249025, 0.3249064119542755, 0.18798591116014318`], 
             UndirectedEdge[184, 424] -> 
             RGBColor[
              0.28881315240835653`, 0.41979584487067384`, 0.9397989642855475],
              UndirectedEdge[122, 159] -> 
             RGBColor[
              0.8441272348319537, 0.3258751275198433, 0.1893291851678579], 
             UndirectedEdge[158, 324] -> 
             RGBColor[
              0.3635993901479788, 0.48935324953462667`, 0.9443892095152808], 
             UndirectedEdge[180, 465] -> 
             RGBColor[
              0.27637826248324115`, 0.40782145563679656`, 0.9390507052321971],
              UndirectedEdge[254, 454] -> 
             RGBColor[
              0.568190337821955, 0.5020881692235942, 0.5874756893040098], 
             UndirectedEdge[297, 314] -> 
             RGBColor[
              0.42471984107439154`, 0.540499402694099, 0.9487792473402418], 
             UndirectedEdge[262, 393] -> 
             RGBColor[
              0.46864864929250694`, 0.5795091117335374, 0.951312884870325], 
             UndirectedEdge[201, 333] -> 
             RGBColor[
              0.34155395478950024`, 0.4698622181836031, 0.9429990074018386], 
             UndirectedEdge[219, 340] -> 
             RGBColor[
              0.43185173064895377`, 0.5464892084598855, 0.9492854859123644], 
             UndirectedEdge[361, 370] -> 
             RGBColor[
              0.6178223925754994, 0.7005868527844641, 0.9630756852495326], 
             UndirectedEdge[48, 358] -> 
             RGBColor[
              0.2165685446684143, 0.3449576500582796, 0.9356446302831911], 
             UndirectedEdge[287, 299] -> 
             RGBColor[
              0.2094890463187735, 0.33751664842668644`, 0.9352414633253583], 
             UndirectedEdge[62, 233] -> 
             RGBColor[
              0.8302393984490122, 0.2334388442338099, 0.17659058814627704`], 
             UndirectedEdge[61, 91] -> 
             RGBColor[
              0.32572776888358806`, 0.4565507546784424, 0.9419760632968737], 
             UndirectedEdge[204, 340] -> 
             RGBColor[
              0.4196638066192008, 0.5365945026728116, 0.9483260078869054], 
             UndirectedEdge[258, 373] -> 
             RGBColor[
              0.3335189671806654, 0.461900180189882, 0.9425237328349862], 
             UndirectedEdge[167, 210] -> 
             RGBColor[
              0.9113669843928855, 0.6334814540290358, 0.5263699322609554], 
             UndirectedEdge[275, 481] -> 
             RGBColor[
              0.36596032955819924`, 0.49139817658749463`, 0.9445396464868034],
              UndirectedEdge[253, 277] -> 
             RGBColor[
              0.8781666893011308, 0.9046720920391318, 0.9377821758000617], 
             UndirectedEdge[193, 485] -> 
             RGBColor[
              0.2679064543585755, 0.3989170481541139, 0.9385682482924145], 
             UndirectedEdge[89, 260] -> 
             RGBColor[
              0.2855390731059485, 0.4174500484302025, 0.9395723998449554], 
             UndirectedEdge[359, 397] -> 
             RGBColor[
              0.3719996579907838, 0.4966291393303264, 0.9449244671541592], 
             UndirectedEdge[1, 171] -> 
             RGBColor[
              0.2639538573417897, 0.3947626180803467, 0.9383431537396518], 
             UndirectedEdge[193, 330] -> 
             RGBColor[
              0.2971306356015508, 0.42963351556059126`, 0.9402325221809], 
             UndirectedEdge[92, 320] -> 
             RGBColor[
              0.7988700431185324, 0.8415596078670635, 0.9004611644475569], 
             UndirectedEdge[126, 279] -> 
             RGBColor[
              0.26484901945855754`, 0.3957034902216259, 0.9383941318979281], 
             UndirectedEdge[93, 163] -> 
             RGBColor[
              0.26813879509029465`, 0.39916125299440397`, 0.9385814797533685],
              UndirectedEdge[31, 297] -> 
             RGBColor[
              0.48620123605795307`, 0.5937514968840982, 0.9526967874627315], 
             UndirectedEdge[127, 325] -> 
             RGBColor[
              0.20249836583685807`, 0.33016900000545074`, 0.9348433544136983],
              UndirectedEdge[334, 498] -> 
             RGBColor[
              0.4323467950368561, 0.5486660596707702, 0.9488340391891498], 
             UndirectedEdge[41, 300] -> 
             RGBColor[
              0.22924216126039493`, 0.3582784246501542, 0.9363663739991688], 
             UndirectedEdge[330, 496] -> 
             RGBColor[
              0.2916695481926115, 0.42389356644085574`, 0.9399215213319159], 
             UndirectedEdge[18, 227] -> 
             RGBColor[
              0.8650075437066738, 0.45982146624662823`, 0.2082846055515888], 
             UndirectedEdge[156, 350] -> 
             RGBColor[
              0.41473957912155346`, 0.5332684178987681, 0.9477527826875395], 
             UndirectedEdge[315, 386] -> 
             RGBColor[
              0.1822133081343763, 0.30884811821319974`, 0.9336881503865955], 
             UndirectedEdge[29, 479] -> 
             RGBColor[
              0.410555492074131, 0.5300242649407545, 0.9473812108083647], 
             UndirectedEdge[277, 488] -> 
             RGBColor[
              0.7703329161501223, 0.8205091959342619, 0.9777432439776033], 
             UndirectedEdge[242, 374] -> 
             RGBColor[
              0.2383689744042093, 0.367871283937679, 0.936886132505799], 
             UndirectedEdge[244, 363] -> 
             RGBColor[
              0.37362619317772217`, 0.49803796235721676`, 0.9450281085379824],
              UndirectedEdge[335, 409] -> 
             RGBColor[
              0.25916391695491414`, 0.389728087033979, 0.938070373720701], 
             UndirectedEdge[235, 332] -> 
             RGBColor[
              0.37961688858367837`, 0.50322680161675, 0.9454098303518859], 
             UndirectedEdge[249, 440] -> 
             RGBColor[
              0.2856108538657166, 0.41752549455988186`, 0.9395764876530341], 
             UndirectedEdge[96, 265] -> 
             RGBColor[
              0.3085881199169248, 0.4405417508695841, 0.9409265415042412], 
             UndirectedEdge[39, 200] -> 
             RGBColor[
              0.7622447974505207, 0.6739602832535388, 0.6012384342096092], 
             UndirectedEdge[146, 312] -> 
             RGBColor[
              0.28117238396624933`, 0.41286038128029634`, 0.9393237233583873],
              UndirectedEdge[237, 448] -> 
             RGBColor[
              0.7370158535300309, 0.7940376208084021, 0.9750172525524329], 
             UndirectedEdge[31, 162] -> 
             RGBColor[
              0.4575348398128734, 0.5704788250059085, 0.9504400637418493], 
             UndirectedEdge[41, 102] -> 
             RGBColor[
              0.2545321161274702, 0.38485977069120125`, 0.9378065995157133], 
             UndirectedEdge[266, 374] -> 
             RGBColor[
              0.27062553266643685`, 0.40177497185519817`, 0.9387230957795312],
              UndirectedEdge[44, 139] -> 
             RGBColor[
              0.5303562146824653, 0.6296060932112468, 0.9561707304600824], 
             UndirectedEdge[47, 189] -> 
             RGBColor[
              0.24585450838109163`, 0.3757390547576487, 0.9373124225919274], 
             UndirectedEdge[208, 359] -> 
             RGBColor[
              0.3537848938552699, 0.480852426136809, 0.9437638384901277], 
             UndirectedEdge[122, 413] -> 
             RGBColor[
              0.9206701650068785, 0.7073273642826143, 0.2820065056616069], 
             UndirectedEdge[36, 141] -> 
             RGBColor[
              0.28198608489330845`, 0.4136382572421074, 0.9393728955113378], 
             UndirectedEdge[179, 347] -> 
             RGBColor[
              0.17892806853100302`, 0.30539512309383293`, 0.93350106085126], 
             UndirectedEdge[226, 422] -> 
             RGBColor[
              0.20671849831186667`, 0.3346046268085379, 0.9350836847150235], 
             UndirectedEdge[18, 167] -> 
             RGBColor[
              0.9355270875213144, 0.7783260157628717, 0.5479056765432442], 
             UndirectedEdge[112, 452] -> 
             RGBColor[
              0.2361084750925497, 0.3654953558371904, 0.936757400414109], 
             UndirectedEdge[323, 342] -> 
             RGBColor[
              0.2496659047127254, 0.3797450739586806, 0.9375294759745583], 
             UndirectedEdge[74, 82] -> 
             RGBColor[
              0.27000631808527487`, 0.401124138069925, 0.93868783242518], 
             UndirectedEdge[291, 349] -> 
             RGBColor[
              0.5342643053360183, 0.6315079324719315, 0.9569079863163146], 
             UndirectedEdge[86, 136] -> 
             RGBColor[
              0.942076876818933, 0.8389236960734718, 0.594023128493258], 
             UndirectedEdge[11, 23] -> 
             RGBColor[
              0.23070981980428998`, 0.3598210268347142, 0.9364499549820375], 
             UndirectedEdge[249, 470] -> 
             RGBColor[
              0.27251498804399493`, 0.40376090925540187`, 0.9388306974680845],
              UndirectedEdge[35, 135] -> 
             RGBColor[
              0.24449959825218992`, 0.3743149583059091, 0.9372352624644963], 
             UndirectedEdge[161, 326] -> 
             RGBColor[
              0.9327537347132191, 0.7525662704764362, 0.31724881897839763`], 
             UndirectedEdge[26, 139] -> 
             RGBColor[
              0.4753323584108449, 0.5831244997687381, 0.952339366037344], 
             UndirectedEdge[109, 218] -> 
             RGBColor[
              0.24296647092511459`, 0.372703544279266, 0.937147953131278], 
             UndirectedEdge[238, 465] -> 
             RGBColor[
              0.30138975132499524`, 0.433055376037075, 0.940513691725769], 
             UndirectedEdge[258, 314] -> 
             RGBColor[
              0.35174895766394676`, 0.47908900053701325`, 0.9436341104363243],
              UndirectedEdge[28, 493] -> 
             RGBColor[
              0.9792166674892435, 0.9809905167708368, 0.7433381739278018], 
             UndirectedEdge[106, 466] -> 
             RGBColor[
              0.5106817556791221, 0.6136334810680553, 0.9546218849774213], 
             UndirectedEdge[45, 236] -> 
             RGBColor[
              0.285052814306115, 0.4169389596009889, 0.9395447081256605], 
             UndirectedEdge[157, 246] -> 
             RGBColor[
              0.2983825090164457, 0.4309493138930047, 0.9403038145198976], 
             UndirectedEdge[371, 427] -> 
             RGBColor[
              0.3212220231725497, 0.4499441234823203, 0.9417879671446181], 
             UndirectedEdge[341, 450] -> 
             RGBColor[
              0.9056409272943111, 0.562891578052587, 0.35323513131972123`], 
             UndirectedEdge[277, 484] -> 
             RGBColor[
              0.8820966152149525, 0.9042351364524142, 0.7227616167031183], 
             UndirectedEdge[84, 135] -> 
             RGBColor[
              0.24197053087649611`, 0.37165674814192173`, 0.9370912358188704],
              UndirectedEdge[35, 84] -> 
             RGBColor[
              0.2358433607180927, 0.36521670382041393`, 0.9367423025426853], 
             UndirectedEdge[68, 272] -> 
             RGBColor[
              0.8202846954174998, 0.15692263455492186`, 0.1670579532810717], 
             UndirectedEdge[164, 227] -> 
             RGBColor[
              0.8315779382096691, 0.24372744738608088`, 0.17787237533274636`],
              UndirectedEdge[355, 498] -> 
             RGBColor[
              0.3952981571338905, 0.516576391637906, 0.946473332742797], 
             UndirectedEdge[223, 373] -> 
             RGBColor[
              0.3417396383201442, 0.4690205123479532, 0.9430475467307398], 
             UndirectedEdge[116, 192] -> 
             RGBColor[
              0.2516702940273803, 0.3818518142140055, 0.9376436229807996], 
             UndirectedEdge[3, 31] -> 
             RGBColor[
              0.4573521482388232, 0.5703305077559329, 0.9504256815919188], 
             UndirectedEdge[40, 419] -> 
             RGBColor[
              0.44944534633244004`, 0.5620965984995714, 0.950304666943798], 
             UndirectedEdge[282, 324] -> 
             RGBColor[
              0.48866791978392093`, 0.5934906203448358, 0.9535163694747727], 
             UndirectedEdge[250, 339] -> 
             RGBColor[
              0.20806801028262886`, 0.33602304945380984`, 0.9351605374253343],
              UndirectedEdge[259, 405] -> 
             RGBColor[
              0.9279266912954685, 0.7275673838799486, 0.39806227602736116`], 
             UndirectedEdge[22, 441] -> 
             RGBColor[
              0.45077446449645514`, 0.564859917388641, 0.9499439281668742], 
             UndirectedEdge[142, 241] -> 
             RGBColor[
              0.7025032226254809, 0.7675201238280478, 0.9709826140315919], 
             UndirectedEdge[170, 266] -> 
             RGBColor[
              0.29310065604108804`, 0.425397751527083, 0.9400030208067522], 
             UndirectedEdge[105, 153] -> 
             RGBColor[
              0.24541911730613436`, 0.37528143113248, 0.9372876277143118], 
             UndirectedEdge[95, 404] -> 
             RGBColor[
              0.22026561376472564`, 0.3488435040862222, 0.9358551728989024], 
             UndirectedEdge[200, 454] -> 
             RGBColor[
              0.9003552167733437, 0.640418136645701, 0.2385662891695866], 
             UndirectedEdge[96, 131] -> 
             RGBColor[
              0.2798853921380307, 0.4115076712688437, 0.9392504310777041], 
             UndirectedEdge[190, 395] -> 
             RGBColor[
              0.2565485956338361, 0.38697921850457684`, 0.9379214350404868], 
             UndirectedEdge[297, 381] -> 
             RGBColor[
              0.5443345056874556, 0.6409542995639315, 0.9572711527321625], 
             UndirectedEdge[203, 419] -> 
             RGBColor[
              0.5236285855732716, 0.6241443008241659, 0.9556411068524893], 
             UndirectedEdge[107, 209] -> 
             RGBColor[
              0.37529763235099667`, 0.4849566561931139, 0.9463994374355724], 
             UndirectedEdge[205, 252] -> 
             RGBColor[
              0.8648112867502258, 0.89136633503373, 0.7718692919288858], 
             UndirectedEdge[98, 488] -> 
             RGBColor[
              0.8822995191611039, 0.9059842085048606, 0.8501777526166581], 
             UndirectedEdge[182, 275] -> 
             RGBColor[
              0.39614531120522645`, 0.517542890548859, 0.9464630068258206], 
             UndirectedEdge[88, 474] -> 
             RGBColor[
              0.9298536404427284, 0.7393015368665987, 0.48723505332973827`], 
             UndirectedEdge[47, 242] -> 
             RGBColor[
              0.2284706396727983, 0.35746750654429615`, 0.9363224369861192], 
             UndirectedEdge[133, 262] -> 
             RGBColor[
              0.4106297397776527, 0.5294703750419166, 0.9475567521778445], 
             UndirectedEdge[4, 321] -> 
             RGBColor[
              0.32873955000778277`, 0.45915940811169914`, 0.9421679713268938],
              UndirectedEdge[369, 370] -> 
             RGBColor[
              0.5056953807182732, 0.6086792278604158, 0.9544796944704173], 
             UndirectedEdge[49, 436] -> 
             RGBColor[
              0.4815672646188717, 0.5899970256324685, 0.9523298855912635], 
             UndirectedEdge[34, 393] -> 
             RGBColor[
              0.5024822764946291, 0.606976774483756, 0.9539763919403361], 
             UndirectedEdge[268, 324] -> 
             RGBColor[
              0.3896661145929028, 0.5119309360971549, 0.946050158147012], 
             UndirectedEdge[359, 371] -> 
             RGBColor[
              0.37419759071797254`, 0.49853287818730624`, 0.94506451748398], 
             UndirectedEdge[296, 440] -> 
             RGBColor[
              0.29754682970453167`, 0.4296388353177702, 0.94027204609223], 
             UndirectedEdge[113, 143] -> 
             RGBColor[
              0.17905963102166003`, 0.30553340361305714`, 0.9335085531404735],
              UndirectedEdge[270, 489] -> 
             RGBColor[
              0.9900603412249211, 0.9901577099059953, 0.8143893991227904], 
             UndirectedEdge[237, 426] -> 
             RGBColor[
              0.8881333928283652, 0.9136374759753497, 0.9891921499256506], 
             UndirectedEdge[131, 385] -> 
             RGBColor[
              0.24854031848564526`, 0.3785620114677306, 0.9374653755040816], 
             UndirectedEdge[427, 499] -> 
             RGBColor[
              0.27010938266217854`, 0.4012324654749223, 0.9386937018003643], 
             UndirectedEdge[45, 243] -> 
             RGBColor[
              0.5610442905289292, 0.35884112143673136`, 0.5623441481098833], 
             UndirectedEdge[33, 443] -> 
             RGBColor[
              0.9064631162110222, 0.6594290978497701, 0.24321160823769428`], 
             UndirectedEdge[232, 330] -> 
             RGBColor[
              0.3313235898372211, 0.4611852513408379, 0.942340398215439], 
             UndirectedEdge[19, 360] -> 
             RGBColor[
              0.5695454245786704, 0.661421659258773, 0.9592558486179177], 
             UndirectedEdge[44, 370] -> 
             RGBColor[
              0.5440602935407461, 0.6407316817901163, 0.9572495657475013], 
             UndirectedEdge[310, 412] -> 
             RGBColor[
              0.26956927876194814`, 0.4006647820312149, 0.9386629436822582], 
             UndirectedEdge[107, 214] -> 
             RGBColor[
              0.19223940367108877`, 0.31938618031345734`, 0.9342591216951321],
              UndirectedEdge[268, 481] -> 
             RGBColor[
              0.3639357382267393, 0.48964457733510314`, 0.9444106413174386], 
             UndirectedEdge[224, 351] -> 
             RGBColor[
              0.29450587119895527`, 0.4268747217537883, 0.9400830457311632], 
             UndirectedEdge[78, 408] -> 
             RGBColor[
              0.22096681623691122`, 0.34958051234329385`, 0.9358951053423573],
              UndirectedEdge[124, 136] -> 
             RGBColor[
              0.9658066058981951, 0.931025957642273, 0.6234191599847442], 
             UndirectedEdge[51, 315] -> 
             RGBColor[
              0.1822133085396902, 0.30884811863921036`, 0.9336881504096776], 
             UndirectedEdge[24, 270] -> 
             RGBColor[
              0.9134975511433701, 0.9314925430785823, 0.899659555679228], 
             UndirectedEdge[43, 340] -> 
             RGBColor[
              0.31529118717805316`, 0.446068953150221, 0.9413638580453506], 
             UndirectedEdge[116, 483] -> 
             RGBColor[
              0.27268756010159706`, 0.40394229342964216`, 0.9388405251914673],
              UndirectedEdge[50, 169] -> 
             RGBColor[
              0.46684010556596744`, 0.5777047091656451, 0.9512633876302873], 
             UndirectedEdge[247, 369] -> 
             RGBColor[
              0.457479402684923, 0.5695353247878849, 0.9506839560586847], 
             UndirectedEdge[327, 412] -> 
             RGBColor[
              0.2497253233645969, 0.37980752672915763`, 0.9375328597788803], 
             UndirectedEdge[134, 305] -> 
             RGBColor[
              0.2421591297202534, 0.37185497748456803`, 0.9371019762440154], 
             UndirectedEdge[7, 49] -> 
             RGBColor[
              0.6644484112533559, 0.7356118894004525, 0.9687430433701605], 
             UndirectedEdge[81, 486] -> 
             RGBColor[
              0.879272872526262, 0.9065723375988691, 0.9883470255893563], 
             UndirectedEdge[110, 384] -> 
             RGBColor[
              0.27776805045914515`, 0.4092822109171187, 0.9391298516014178], 
             UndirectedEdge[18, 88] -> 
             RGBColor[
              0.8754970234499582, 0.5275428865427625, 0.2178240033304778], 
             UndirectedEdge[11, 41] -> 
             RGBColor[
              0.23572240363091454`, 0.3650895702526674, 0.9367354142155104], 
             UndirectedEdge[231, 288] -> 
             RGBColor[
              0.2572561350755689, 0.3877228873184297, 0.9379617283649826], 
             UndirectedEdge[236, 396] -> 
             RGBColor[
              0.6404346091203621, 0.7039646181731036, 0.7392903949875442], 
             UndirectedEdge[46, 418] -> 
             RGBColor[
              0.9480641688610301, 0.8473510420156326, 0.586962152772621], 
             UndirectedEdge[74, 447] -> 
             RGBColor[
              0.26411698006509043`, 0.39493407040511375`, 0.9383524433374253],
              UndirectedEdge[270, 426] -> 
             RGBColor[
              0.9300987405065613, 0.9447298808495102, 0.9012429919407459], 
             UndirectedEdge[383, 479] -> 
             RGBColor[
              0.37021659707670174`, 0.49508474158579574`, 0.9448108520894127],
              UndirectedEdge[408, 430] -> 
             RGBColor[
              0.23112177962706493`, 0.36025402272821205`, 0.9364734154845045],
              UndirectedEdge[13, 390] -> 
             RGBColor[
              0.29868486413343276`, 0.4312671082913797, 0.9403210331965157], 
             UndirectedEdge[15, 97] -> 
             RGBColor[
              0.23298665056537604`, 0.36221412032402367`, 0.936579617125612], 
             UndirectedEdge[289, 472] -> 
             RGBColor[
              0.3839088844842855, 0.5069443127438695, 0.9456833125354096], 
             UndirectedEdge[254, 315] -> 
             RGBColor[
              0.21099893285942517`, 0.33910363491324724`, 0.9353274491301715],
              UndirectedEdge[347, 386] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[66, 445] -> 
             RGBColor[
              0.24646019520379875`, 0.3763756700110764, 0.9373469155604471], 
             UndirectedEdge[127, 213] -> 
             RGBColor[
              0.5650928544862279, 0.5063763336200533, 0.5889799898461102], 
             UndirectedEdge[423, 446] -> 
             RGBColor[
              0.20798858239401255`, 0.3359395657068551, 0.9351560141245807], 
             UndirectedEdge[63, 410] -> 
             RGBColor[
              0.39150030357105375`, 0.5135196184010107, 0.9461670310467902], 
             UndirectedEdge[107, 421] -> 
             RGBColor[
              0.18186414913512938`, 0.30848112996703203`, 0.9336682662981228],
              UndirectedEdge[226, 308] -> 
             RGBColor[
              0.17918563853241248`, 0.3056658454961956, 0.9335157290817995], 
             UndirectedEdge[51, 386] -> 
             RGBColor[
              0.1789270004053139, 0.3053940004260106, 0.9335010000230821], 
             UndirectedEdge[89, 470] -> 
             RGBColor[
              0.27049191209474743`, 0.40163452816231904`, 0.9387154862856475],
              UndirectedEdge[205, 490] -> 
             RGBColor[
              0.9921900608993205, 0.9897828176678509, 0.6878265810358566], 
             UndirectedEdge[270, 345] -> 
             RGBColor[
              0.824874141314561, 0.8621219539632672, 0.8908628396870938], 
             UndirectedEdge[152, 191] -> 
             RGBColor[
              0.21120215837255008`, 0.3393172378127832, 0.9353390225224988], 
             UndirectedEdge[85, 404] -> 
             RGBColor[
              0.21383193119222793`, 0.3420812957834917, 0.9354887841941792], 
             UndirectedEdge[26, 468] -> 
             RGBColor[
              0.43250328030680874`, 0.5483539247359007, 0.9489677041209118], 
             UndirectedEdge[191, 301] -> 
             RGBColor[
              0.2135770306984165, 0.34181337920287114`, 0.935474267988148], 
             UndirectedEdge[375, 426] -> 
             RGBColor[
              0.9141879156308917, 0.9338323693009003, 0.9715587229445324], 
             UndirectedEdge[39, 213] -> 
             RGBColor[
              0.7639337426080279, 0.681629388750616, 0.6026477314488674], 
             UndirectedEdge[360, 468] -> 
             RGBColor[
              0.5288716731016017, 0.6284008754780657, 0.9560538619087819], 
             UndirectedEdge[80, 278] -> 
             RGBColor[
              0.8689533270990046, 0.8982632673699124, 0.9759744072003973], 
             UndirectedEdge[152, 299] -> 
             RGBColor[
              0.20658465608391344`, 0.3344639501408717, 0.9350760625981434], 
             UndirectedEdge[227, 309] -> 
             RGBColor[
              0.9193309660445672, 0.6696242794444807, 0.3370748612621325], 
             UndirectedEdge[98, 115] -> 
             RGBColor[
              0.9582015589575525, 0.9660972945461519, 0.85752593015656], 
             UndirectedEdge[213, 261] -> 
             RGBColor[
              0.8920963570986589, 0.602916583768641, 0.23167489421385412`], 
             UndirectedEdge[199, 208] -> 
             RGBColor[
              0.33248120157791744`, 0.46240023864087376`, 0.9424063860563303],
              UndirectedEdge[204, 219] -> 
             RGBColor[
              0.5140809753819581, 0.6163931207559199, 0.9548894840041806], 
             UndirectedEdge[52, 166] -> 
             RGBColor[
              0.8369577282992072, 0.2850788714533209, 0.18302406839809204`], 
             UndirectedEdge[218, 300] -> 
             RGBColor[
              0.22896529227619977`, 0.3579874177932576, 0.93635060672011], 
             UndirectedEdge[128, 345] -> 
             RGBColor[
              0.5772342034942839, 0.6673977284070023, 0.9600430222220963], 
             UndirectedEdge[325, 421] -> 
             RGBColor[
              0.17903676307516053`, 0.3055093679513746, 0.9335072508447505], 
             UndirectedEdge[257, 272] -> 
             RGBColor[
              0.8397181825766789, 0.3055916208213189, 0.18563986428858031`], 
             UndirectedEdge[461, 486] -> 
             RGBColor[
              0.9396915520193736, 0.9545227464327241, 0.9862809714214389], 
             UndirectedEdge[115, 203] -> 
             RGBColor[
              0.7278675078772177, 0.786501490374317, 0.9744226233622142], 
             UndirectedEdge[128, 169] -> 
             RGBColor[
              0.4937426983927686, 0.5998815912671589, 0.9532883803380281], 
             UndirectedEdge[190, 356] -> 
             RGBColor[
              0.2587237746657965, 0.38926546958148345`, 0.9380453082684679], 
             UndirectedEdge[46, 272] -> 
             RGBColor[
              0.8691188894851287, 0.4352254750326188, 0.20997245291222838`], 
             UndirectedEdge[121, 450] -> 
             RGBColor[
              0.8225872124582064, 0.17462078949919407`, 0.16926284619957344`],
              UndirectedEdge[255, 269] -> 
             RGBColor[
              0.4232624333249523, 0.5410303787827784, 0.94819088586856], 
             UndirectedEdge[15, 356] -> 
             RGBColor[
              0.2517883622305454, 0.38197591138148856`, 0.9376503467903037], 
             UndirectedEdge[85, 183] -> 
             RGBColor[
              0.20959144808050473`, 0.33762427917091264`, 0.9352472949541991],
              UndirectedEdge[136, 261] -> 
             RGBColor[
              0.924473739268195, 0.762150740681319, 0.5794980394919615], 
             UndirectedEdge[295, 336] -> 
             RGBColor[
              0.22591321478921644`, 0.3547794908415487, 0.9361767954223702], 
             UndirectedEdge[259, 475] -> 
             RGBColor[
              0.8504220451203991, 0.38316771966990754`, 0.19570591448943397`],
              UndirectedEdge[51, 143] -> 
             RGBColor[
              0.17892700107920537`, 0.30539400113431325`, 0.9335010000614592],
              UndirectedEdge[53, 178] -> 
             RGBColor[
              0.9840984713626098, 0.9616310168446078, 0.5753629014776818], 
             UndirectedEdge[67, 385] -> 
             RGBColor[
              0.24504732911062774`, 0.37489065816626943`, 0.9372664549265891],
              UndirectedEdge[69, 173] -> 
             RGBColor[
              0.9470127321552729, 0.9592645667466908, 0.9483609186014075], 
             UndirectedEdge[221, 381] -> 
             RGBColor[
              0.5529574414035745, 0.647954787237104, 0.9579499818185896], 
             UndirectedEdge[140, 334] -> 
             RGBColor[
              0.4512190714580578, 0.563987423855866, 0.9503197339204532], 
             UndirectedEdge[57, 370] -> 
             RGBColor[
              0.5963431626815656, 0.6831772702750474, 0.9613654647247267], 
             UndirectedEdge[432, 467] -> 
             RGBColor[
              0.8027318187709938, 0.8464550865365966, 0.9808037893677689], 
             UndirectedEdge[235, 440] -> 
             RGBColor[
              0.3193577814126447, 0.44853038543702994`, 0.9416618206484036], 
             UndirectedEdge[229, 390] -> 
             RGBColor[
              0.29586463316817824`, 0.4283028667339263, 0.9401604252152023], 
             UndirectedEdge[12, 198] -> 
             RGBColor[
              0.2771414265920781, 0.4086235895025834, 0.9390941662991953], 
             UndirectedEdge[232, 400] -> 
             RGBColor[
              0.3260597275402094, 0.45565259831853255`, 0.9420406290448107], 
             UndirectedEdge[143, 273] -> 
             RGBColor[
              0.23623420851912813`, 0.365627509640484, 0.9367645607467467], 
             UndirectedEdge[115, 277] -> 
             RGBColor[
              0.8462349559465709, 0.8806222819755531, 0.9850914215175051], 
             UndirectedEdge[44, 468] -> 
             RGBColor[
              0.48752713657842917`, 0.5948355181784093, 0.9527990685436503], 
             UndirectedEdge[183, 346] -> 
             RGBColor[
              0.21142499907593382`, 0.3395514575209563, 0.9353517129708931], 
             UndirectedEdge[434, 469] -> 
             RGBColor[
              0.9258166281861495, 0.7248800924627727, 0.5003559242994462], 
             UndirectedEdge[255, 334] -> 
             RGBColor[
              0.40019480220882075`, 0.5210503561228367, 0.9467210368117455], 
             UndirectedEdge[65, 210] -> 
             RGBColor[
              0.9107642708804349, 0.6204193391599911, 0.29010099455145133`], 
             UndirectedEdge[49, 76] -> 
             RGBColor[
              0.45077000854144356`, 0.5638542255344485, 0.9502204534950804], 
             UndirectedEdge[74, 395] -> 
             RGBColor[
              0.2733607929019397, 0.4046499037882272, 0.9388788648034883], 
             UndirectedEdge[52, 88] -> 
             RGBColor[
              0.8512025856554928, 0.3816657696999445, 0.19615962002028325`], 
             UndirectedEdge[312, 354] -> 
             RGBColor[
              0.3330876906173925, 0.4625247982993003, 0.942459704446583], 
             UndirectedEdge[372, 417] -> 
             RGBColor[
              0.5857428674141524, 0.6736726673586156, 0.9611454890036907], 
             UndirectedEdge[354, 415] -> 
             RGBColor[
              0.32438826492045936`, 0.4533811503163769, 0.9419642850227896], 
             UndirectedEdge[301, 451] -> 
             RGBColor[
              0.2100992490740445, 0.3381580102115655, 0.9352762134695569], 
             UndirectedEdge[243, 428] -> 
             RGBColor[
              0.8348198026853184, 0.2686458383399938, 0.18097678841579048`], 
             UndirectedEdge[102, 354] -> 
             RGBColor[
              0.3191507002330799, 0.44787613774915985`, 0.941666013462126], 
             UndirectedEdge[255, 369] -> 
             RGBColor[
              0.40876647484829665`, 0.5284747081383571, 0.9472672162127003], 
             UndirectedEdge[300, 409] -> 
             RGBColor[
              0.23375665444094554`, 0.3630234432183127, 0.936623467707207], 
             UndirectedEdge[93, 187] -> 
             RGBColor[
              0.2669566877883537, 0.3979187832701322, 0.9385141604912941], 
             UndirectedEdge[181, 332] -> 
             RGBColor[
              0.41144462504759094`, 0.5307943872332428, 0.947437865575204], 
             UndirectedEdge[195, 351] -> 
             RGBColor[
              0.2800986877606033, 0.41173185849189103`, 0.9392625779478669], 
             UndirectedEdge[480, 481] -> 
             RGBColor[
              0.33588196619861493`, 0.46534581002792214`, 0.9426230797707831],
              UndirectedEdge[47, 365] -> 
             RGBColor[
              0.22445415871552787`, 0.3532459303986038, 0.9360937043374536], 
             UndirectedEdge[50, 370] -> 
             RGBColor[
              0.5161906822110007, 0.6177697305042253, 0.9551484458009031], 
             UndirectedEdge[122, 150] -> 
             RGBColor[
              0.8444744803276283, 0.32854420856354566`, 0.1896617078466737], 
             UndirectedEdge[246, 256] -> 
             RGBColor[
              0.2918037733500637, 0.42403464559170456`, 0.9399291652560644], 
             UndirectedEdge[63, 282] -> 
             RGBColor[
              0.5134969921724348, 0.6149963149023026, 0.9550984560118821], 
             UndirectedEdge[230, 391] -> 
             RGBColor[
              0.23250262506826308`, 0.3617053788375689, 0.936552052589603], 
             UndirectedEdge[312, 415] -> 
             RGBColor[
              0.29571211190112656`, 0.42814255721184813`, 0.9401517393546788],
              UndirectedEdge[199, 397] -> 
             RGBColor[
              0.3506959657134314, 0.47817695183439113`, 0.9435670147203616], 
             UndirectedEdge[129, 328] -> 
             RGBColor[
              0.3704563897071251, 0.49529243790994043`, 0.944826131463783], 
             UndirectedEdge[188, 304] -> 
             RGBColor[
              0.33792059600024626`, 0.4671115686975821, 0.9427529794590535], 
             UndirectedEdge[323, 395] -> 
             RGBColor[
              0.25216611947306267`, 0.3823729581945666, 0.9376718595064233], 
             UndirectedEdge[49, 238] -> 
             RGBColor[
              0.4051843179606758, 0.5243701915568157, 0.9473157736011174], 
             UndirectedEdge[171, 385] -> 
             RGBColor[
              0.24760690614002792`, 0.37758093591072595`, 0.9374122190518586],
              UndirectedEdge[117, 425] -> 
             RGBColor[
              0.3782090614978762, 0.502007412554475, 0.9453201248548712], 
             UndirectedEdge[32, 103] -> 
             RGBColor[
              0.5080332189208779, 0.6114832796124914, 0.9544133824619024], 
             UndirectedEdge[131, 216] -> 
             RGBColor[
              0.26474751566428445`, 0.3955968032981327, 0.9383883514070055], 
             UndirectedEdge[65, 175] -> 
             RGBColor[
              0.9705975460870158, 0.9645679382577699, 0.6789276620320353], 
             UndirectedEdge[143, 226] -> 
             RGBColor[
              0.17917599682249857`, 0.3056557114477564, 0.9335151800006836], 
             UndirectedEdge[234, 235] -> 
             RGBColor[
              0.3728101836078023, 0.49733117588158576`, 0.9449761131297559], 
             UndirectedEdge[179, 386] -> 
             RGBColor[
              0.17892806853100302`, 0.30539512309383293`, 0.93350106085126], 
             UndirectedEdge[267, 476] -> 
             RGBColor[
              0.9187775169477521, 0.6742536840952063, 0.3030402150761125], 
             UndirectedEdge[59, 195] -> 
             RGBColor[
              0.2561715150223729, 0.3865828828736374, 0.9378999608575047], 
             UndirectedEdge[75, 108] -> 
             RGBColor[
              0.31502960292460824`, 0.4450992956026424, 0.9413743981617775], 
             UndirectedEdge[334, 363] -> 
             RGBColor[
              0.40380771802618465`, 0.5241796822134083, 0.9469512486128518], 
             UndirectedEdge[77, 329] -> 
             RGBColor[
              0.7446878798780471, 0.8004364154026, 0.9754252127138938], 
             UndirectedEdge[328, 462] -> 
             RGBColor[
              0.4245956854340748, 0.5418984360706564, 0.9483550662650316], 
             UndirectedEdge[285, 480] -> 
             RGBColor[
              0.3339827883337351, 0.46370083761681824`, 0.9425020658366099], 
             UndirectedEdge[204, 334] -> 
             RGBColor[
              0.4523485649591434, 0.5649043975631496, 0.9504086517863296], 
             UndirectedEdge[70, 238] -> 
             RGBColor[
              0.28920204195997834`, 0.42024532074903687`, 0.9398196197075317],
              UndirectedEdge[83, 270] -> 
             RGBColor[
              0.955384395176871, 0.9648919755228036, 0.9036547602559704], 
             UndirectedEdge[112, 190] -> 
             RGBColor[
              0.24818657202567745`, 0.37819020150948346`, 0.9374452301665075],
              UndirectedEdge[263, 453] -> 
             RGBColor[
              0.27885374219171843`, 0.41042334176488493`, 0.9391916801394509],
              UndirectedEdge[210, 474] -> 
             RGBColor[
              0.9145804341522545, 0.6348102980864267, 0.4731147536068143], 
             UndirectedEdge[96, 392] -> 
             RGBColor[
              0.3010815634219416, 0.43378619120311424`, 0.9404575216753974], 
             UndirectedEdge[70, 84] -> 
             RGBColor[
              0.24578222839824324`, 0.37566308391285935`, 0.9373083063538328],
              UndirectedEdge[77, 278] -> 
             RGBColor[
              0.7775908081460805, 0.8263457284855322, 0.9672404849556133], 
             UndirectedEdge[238, 265] -> 
             RGBColor[
              0.32058421295120315`, 0.4520956650524487, 0.9416483204611299], 
             UndirectedEdge[157, 392] -> 
             RGBColor[
              0.3042725009406671, 0.4371400688524187, 0.9406392408465198], 
             UndirectedEdge[145, 294] -> 
             RGBColor[
              0.22948545468760678`, 0.35853414146784807`, 0.9363802291999281],
              UndirectedEdge[29, 383] -> 
             RGBColor[
              0.3692814154214852, 0.49427473423964385`, 0.944751263141291], 
             UndirectedEdge[210, 227] -> 
             RGBColor[
              0.8408474405782448, 0.3149769045127923, 0.18674886126930004`], 
             UndirectedEdge[45, 276] -> 
             RGBColor[
              0.4511613140247853, 0.5582811601613382, 0.9513035162562244], 
             UndirectedEdge[57, 219] -> 
             RGBColor[
              0.5637559435916646, 0.6567214977803754, 0.9588000794670529], 
             UndirectedEdge[291, 311] -> 
             RGBColor[
              0.7008920044449292, 0.7662614279396891, 0.9708220228610445], 
             UndirectedEdge[11, 485] -> 
             RGBColor[
              0.24345966129558455`, 0.3732219186287056, 0.9371760395932665], 
             UndirectedEdge[13, 338] -> 
             RGBColor[
              0.30836079438708164`, 0.4403868770076641, 0.9409105178148355], 
             UndirectedEdge[190, 351] -> 
             RGBColor[
              0.2690775343767192, 0.40014792750394457`, 0.9386349395669901], 
             UndirectedEdge[314, 397] -> 
             RGBColor[
              0.34431176305958455`, 0.4726472763749843, 0.9431602189725873], 
             UndirectedEdge[339, 365] -> 
             RGBColor[
              0.2143326753092825, 0.34260760959952685`, 0.9355173008308608], 
             UndirectedEdge[320, 337] -> 
             RGBColor[
              0.9244065988908812, 0.9404637664434601, 0.9125392493325524], 
             UndirectedEdge[317, 357] -> 
             RGBColor[
              0.895271303645258, 0.6164935275347583, 0.23428070819651722`], 
             UndirectedEdge[153, 452] -> 
             RGBColor[
              0.2344431943228335, 0.36374504016331954`, 0.9366625651378359], 
             UndirectedEdge[308, 423] -> 
             RGBColor[
              0.1833860881198116, 0.31008078433643804`, 0.9337549384717936], 
             UndirectedEdge[149, 441] -> 
             RGBColor[
              0.4020035872776604, 0.5226170348372846, 0.946836290996886], 
             UndirectedEdge[486, 493] -> 
             RGBColor[
              0.9642524295918031, 0.9698103203224957, 0.7679790459557528], 
             UndirectedEdge[241, 402] -> 
             RGBColor[
              0.6288966867837086, 0.7086387216585579, 0.9645893173262957], 
             UndirectedEdge[293, 432] -> 
             RGBColor[
              0.9264483908194477, 0.943709860746635, 0.9762410122023322], 
             UndirectedEdge[23, 211] -> 
             RGBColor[
              0.226770956748013, 0.3556810320242251, 0.9362256425580082], 
             UndirectedEdge[8, 381] -> 
             RGBColor[
              0.5947992155017207, 0.6819238244004215, 0.9612439195470645], 
             UndirectedEdge[238, 343] -> 
             RGBColor[
              0.306520714368336, 0.43844834351747275`, 0.9408058924805078], 
             UndirectedEdge[355, 363] -> 
             RGBColor[
              0.366759080123219, 0.492090014180544, 0.9445905421664991], 
             UndirectedEdge[66, 398] -> 
             RGBColor[
              0.26221606410223275`, 0.392936087203117, 0.9382441889854937], 
             UndirectedEdge[113, 477] -> 
             RGBColor[
              0.2119319440670913, 0.3400842888488316, 0.9353805827381816], 
             UndirectedEdge[7, 241] -> 
             RGBColor[
              0.7720821236708154, 0.8220268199822758, 0.9778774834237032], 
             UndirectedEdge[161, 259] -> 
             RGBColor[
              0.9260863286561598, 0.722291136783578, 0.31168537193130974`], 
             UndirectedEdge[346, 408] -> 
             RGBColor[
              0.22019359510263653`, 0.34876780790611966`, 0.9358510715426385],
              UndirectedEdge[33, 270] -> 
             RGBColor[
              0.9342186701882929, 0.7654658229940685, 0.5176324949764846], 
             UndirectedEdge[197, 270] -> 
             RGBColor[
              0.843824355466433, 0.8769260052856713, 0.8927516199339326], 
             UndirectedEdge[115, 381] -> 
             RGBColor[
              0.7452365910783697, 0.8006024945852935, 0.9757899812168571], 
             UndirectedEdge[112, 224] -> 
             RGBColor[
              0.2736149088479135, 0.4049169957593272, 0.9388933363306806], 
             UndirectedEdge[133, 296] -> 
             RGBColor[
              0.3292967430314739, 0.4596420207034847, 0.942203475173657], 
             UndirectedEdge[204, 244] -> 
             RGBColor[
              0.42216704011068096`, 0.5387626777069581, 0.9484855117114601], 
             UndirectedEdge[116, 280] -> 
             RGBColor[
              0.25280916302349343`, 0.3830488377373854, 0.9377084798853226], 
             UndirectedEdge[81, 267] -> 
             RGBColor[
              0.906340376624757, 0.9184812574076573, 0.6975246745106891], 
             UndirectedEdge[431, 459] -> 
             RGBColor[
              0.41954302397723237`, 0.5378088133487329, 0.9479538883938678], 
             UndirectedEdge[46, 293] -> 
             RGBColor[
              0.9359635798708703, 0.8383264425596675, 0.6074452935938994], 
             UndirectedEdge[145, 358] -> 
             RGBColor[
              0.2231421897482483, 0.351866967830356, 0.9360189896456512], 
             UndirectedEdge[12, 480] -> 
             RGBColor[
              0.31297532312712917`, 0.4421451064609878, 0.9412865192071291], 
             UndirectedEdge[318, 321] -> 
             RGBColor[
              0.33755888801482614`, 0.46679827542058316`, 0.9427299317460682],
              UndirectedEdge[38, 47] -> 
             RGBColor[
              0.24595116399713765`, 0.375840645938433, 0.9373179269862719], 
             UndirectedEdge[271, 492] -> 
             RGBColor[
              0.2662123163354113, 0.39713640167721365`, 0.9384717696382479], 
             UndirectedEdge[246, 333] -> 
             RGBColor[
              0.33643527177961996`, 0.46448215779697133`, 0.9427075059768388],
              UndirectedEdge[97, 137] -> 
             RGBColor[
              0.2259075246268314, 0.35477351012010483`, 0.9361764713760403], 
             UndirectedEdge[406, 486] -> 
             RGBColor[
              0.9627729895914936, 0.9654828212213326, 0.7058550168364002], 
             UndirectedEdge[272, 306] -> 
             RGBColor[
              0.8390812230199529, 0.30140098239829205`, 0.18505752934082234`],
              UndirectedEdge[50, 219] -> 
             RGBColor[
              0.48360346312109975`, 0.5913139580095534, 0.9525830605432293], 
             UndirectedEdge[326, 405] -> 
             RGBColor[
              0.9345940973525277, 0.7578425175728066, 0.403625723074449], 
             UndirectedEdge[180, 343] -> 
             RGBColor[
              0.28150922552658186`, 0.4132144231171943, 0.9393429059869358], 
             UndirectedEdge[229, 380] -> 
             RGBColor[
              0.2819134302618612, 0.4136392679220333, 0.9393659248486427], 
             UndirectedEdge[184, 470] -> 
             RGBColor[
              0.2562569900664413, 0.3866727225643841, 0.9379048285348154], 
             UndirectedEdge[188, 483] -> 
             RGBColor[
              0.31696315839045336`, 0.4478408551549855, 0.9414585414299963], 
             UndirectedEdge[364, 374] -> 
             RGBColor[
              0.2551484985501697, 0.3855076276983612, 0.93784170158283], 
             UndirectedEdge[161, 469] -> 
             RGBColor[
              0.9253813180460291, 0.7190898482623855, 0.3110970937968252], 
             UndirectedEdge[14, 182] -> 
             RGBColor[
              0.34266467028924463`, 0.47103542678761523`, 0.9430620495117685],
              UndirectedEdge[374, 391] -> 
             RGBColor[
              0.24642877472957408`, 0.3763426451004932, 0.9373451262109225], 
             UndirectedEdge[352, 367] -> 
             RGBColor[
              0.2288379775147259, 0.35785360190672644`, 0.9363433563327893], 
             UndirectedEdge[8, 289] -> 
             RGBColor[
              0.5298323406094952, 0.6288020963090049, 0.9562341229930127], 
             UndirectedEdge[160, 275] -> 
             RGBColor[
              0.4180928553323577, 0.5365527501561378, 0.9478614849301503], 
             UndirectedEdge[118, 151] -> 
             RGBColor[
              0.31595121433390305`, 0.44790234871507695`, 0.9413597168905753],
              UndirectedEdge[43, 217] -> 
             RGBColor[
              0.30643378623989703`, 0.43839711764350564`, 0.9407994722898634],
              UndirectedEdge[117, 154] -> 
             RGBColor[
              0.34530823850037556`, 0.4735103733174856, 0.9432237135065259], 
             UndirectedEdge[139, 468] -> 
             RGBColor[
              0.5212061017709153, 0.6221776193417614, 0.9554504000537172], 
             UndirectedEdge[279, 324] -> 
             RGBColor[
              0.3241188367997081, 0.45236629730551653`, 0.9419757314019449], 
             UndirectedEdge[4, 29] -> 
             RGBColor[
              0.36696197867847585`, 0.49226575471112954`, 0.9446034706830237],
              UndirectedEdge[239, 393] -> 
             RGBColor[
              0.4060710006373207, 0.5259256972403187, 0.9471546820617923], 
             UndirectedEdge[94, 127] -> 
             RGBColor[
              0.5906994451507328, 0.6605608453144329, 0.9482643190369882], 
             UndirectedEdge[157, 459] -> 
             RGBColor[
              0.3465448636437761, 0.4740080224761397, 0.94332350710475], 
             UndirectedEdge[48, 85] -> 
             RGBColor[
              0.21086321568284044`, 0.3389609875556907, 0.9353197202377406], 
             UndirectedEdge[26, 215] -> 
             RGBColor[
              0.33537631974199883`, 0.4626312893738342, 0.942674216260174], 
             UndirectedEdge[63, 165] -> 
             RGBColor[
              0.42168442508772075`, 0.5396635873606885, 0.9480903365790616], 
             UndirectedEdge[165, 282] -> 
             RGBColor[
              0.5158458225400988, 0.6170307537111264, 0.9552481214059205], 
             UndirectedEdge[288, 465] -> 
             RGBColor[
              0.2693457460924733, 0.4004298350228071, 0.9386502138274186], 
             UndirectedEdge[200, 500] -> 
             RGBColor[
              0.8601603348227043, 0.3966998445648045, 0.2026301493422178], 
             UndirectedEdge[293, 353] -> 
             RGBColor[
              0.7969674264911133, 0.8418814193634385, 0.9635324755439242], 
             UndirectedEdge[239, 296] -> 
             RGBColor[
              0.33217516852493173`, 0.46213516819204603`, 0.9423868859008084],
              UndirectedEdge[139, 274] -> 
             RGBColor[
              0.5133847204187874, 0.6158278696108893, 0.9548346722630138], 
             UndirectedEdge[140, 361] -> 
             RGBColor[
              0.5719177559547599, 0.6633194007954346, 0.9594619041005235], 
             UndirectedEdge[83, 197] -> 
             RGBColor[
              0.8091856625186589, 0.8516756760168047, 0.981399600787607], 
             UndirectedEdge[256, 444] -> 
             RGBColor[
              0.28033959264989716`, 0.411985064804791, 0.9392762971249253], 
             UndirectedEdge[21, 166] -> 
             RGBColor[
              0.9095040888434207, 0.6206039273550481, 0.282195231981873], 
             UndirectedEdge[92, 363] -> 
             RGBColor[
              0.506974473041424, 0.6093066729422614, 0.9546939442160238], 
             UndirectedEdge[41, 212] -> 
             RGBColor[
              0.22552146354030395`, 0.35436773544047784`, 0.9361544857682886],
              UndirectedEdge[96, 433] -> 
             RGBColor[
              0.31083399291217784`, 0.4424870131772134, 0.9410696465455513], 
             UndirectedEdge[346, 407] -> 
             RGBColor[
              0.2161204994130187, 0.34448672608714886`, 0.9356191147687198], 
             UndirectedEdge[32, 155] -> 
             RGBColor[
              0.5507999265063706, 0.6462032194486154, 0.9577801343426442], 
             UndirectedEdge[302, 477] -> 
             RGBColor[
              0.21741049289010705`, 0.3458425910218791, 0.9356925779888657], 
             UndirectedEdge[24, 489] -> 
             RGBColor[
              0.9135348042436461, 0.9315079481929074, 0.8990421753997224], 
             UndirectedEdge[359, 427] -> 
             RGBColor[
              0.3324756951564906, 0.4596914885288097, 0.9425050411722034], 
             UndirectedEdge[217, 290] -> 
             RGBColor[
              0.3031025001174864, 0.43489572471311266`, 0.9406097604733883], 
             UndirectedEdge[40, 297] -> 
             RGBColor[
              0.4527821832454718, 0.5648055930283604, 0.9505673549688282], 
             UndirectedEdge[41, 456] -> 
             RGBColor[
              0.22809260204387605`, 0.3570701650273288, 0.9363009083024085], 
             UndirectedEdge[341, 469] -> 
             RGBColor[
              0.927002024559022, 0.7238962731152077, 0.3735657841038871], 
             UndirectedEdge[169, 498] -> 
             RGBColor[
              0.4773158479045384, 0.5865455340196324, 0.9519951984940587], 
             UndirectedEdge[6, 329] -> 
             RGBColor[
              0.8551238518896912, 0.8873165640509703, 0.9860436704429549], 
             UndirectedEdge[92, 219] -> 
             RGBColor[
              0.5677032440041356, 0.6599260940790765, 0.9591108254149605], 
             UndirectedEdge[341, 387] -> 
             RGBColor[
              0.8843435887930974, 0.9064532397024012, 0.7600495256450741], 
             UndirectedEdge[13, 478] -> 
             RGBColor[
              0.28132910192119526`, 0.41302510178743673`, 0.939332648214078], 
             UndirectedEdge[33, 267] -> 
             RGBColor[
              0.9337384293685642, 0.7577785430140971, 0.3161344657047144], 
             UndirectedEdge[10, 123] -> 
             RGBColor[
              0.21296296597852177`, 0.34116795824830987`, 0.9354392979107774],
              UndirectedEdge[57, 337] -> 
             RGBColor[
              0.730726843956438, 0.7892639238928545, 0.9741400277373693], 
             UndirectedEdge[70, 135] -> 
             RGBColor[
              0.25443846593234043`, 0.3847613383983545, 0.9378012662756438], 
             UndirectedEdge[51, 130] -> 
             RGBColor[
              0.1789270004053139, 0.3053940004260106, 0.9335010000230821], 
             UndirectedEdge[219, 361] -> 
             RGBColor[
              0.5852351734855985, 0.6741310802897922, 0.9605102999918589], 
             UndirectedEdge[70, 131] -> 
             RGBColor[
              0.2609296066664183, 0.3915839388719636, 0.9381709271376673], 
             UndirectedEdge[61, 362] -> 
             RGBColor[
              0.3561441161626767, 0.48289586592152384`, 0.9439141660493773], 
             UndirectedEdge[49, 487] -> 
             RGBColor[
              0.5348230464505574, 0.633232468469062, 0.9565223758194106], 
             UndirectedEdge[83, 375] -> 
             RGBColor[
              0.9394735703012015, 0.9539944639741937, 0.9739704912597569], 
             UndirectedEdge[147, 385] -> 
             RGBColor[
              0.24248237828575928`, 0.37219473222205746`, 0.9371203847716176],
              UndirectedEdge[105, 395] -> 
             RGBColor[
              0.2554464216840092, 0.38582076380144426`, 0.9378586678645644], 
             UndirectedEdge[57, 204] -> 
             RGBColor[
              0.5515680195619116, 0.6468267919933015, 0.9578406014415939], 
             UndirectedEdge[362, 363] -> 
             RGBColor[
              0.3966364490357477, 0.5179682894523514, 0.9464943016940854], 
             UndirectedEdge[313, 390] -> 
             RGBColor[
              0.28385568108857195`, 0.41568069668672125`, 0.9394765331599213],
              UndirectedEdge[15, 430] -> 
             RGBColor[
              0.23698890967688827`, 0.36642074840810707`, 0.9368075398612009],
              UndirectedEdge[104, 430] -> 
             RGBColor[
              0.24315634658411125`, 0.3729031156356836, 0.937158766269162], 
             UndirectedEdge[341, 405] -> 
             RGBColor[
              0.9937930272646951, 0.989132237877419, 0.5657875066366207], 
             UndirectedEdge[8, 311] -> 
             RGBColor[
              0.6835752486050087, 0.752395433322769, 0.9693271520415703], 
             UndirectedEdge[305, 460] -> 
             RGBColor[
              0.24972906299601538`, 0.37981145731888477`, 0.9375330727453572],
              UndirectedEdge[451, 456] -> 
             RGBColor[
              0.21755217330464396`, 0.3459915061206145, 0.9357006464788762], 
             UndirectedEdge[257, 306] -> 
             RGBColor[
              0.8582164736566054, 0.4477775920644729, 0.2033538487175496], 
             UndirectedEdge[65, 167] -> 
             RGBColor[
              0.986067541242265, 0.9756937071602725, 0.6343029674871418], 
             UndirectedEdge[24, 329] -> 
             RGBColor[
              0.8597649491834076, 0.8910172490537498, 0.986486342445986], 
             UndirectedEdge[14, 63] -> 
             RGBColor[
              0.3630391373968948, 0.48868276614576933`, 0.9443602925394342], 
             UndirectedEdge[64, 172] -> 
             RGBColor[
              0.31974345189880926`, 0.449434024298521, 0.9416655397334055], 
             UndirectedEdge[50, 361] -> 
             RGBColor[
              0.5425697371949871, 0.6391572117563517, 0.9572443985054486], 
             UndirectedEdge[253, 291] -> 
             RGBColor[
              0.819979493708928, 0.8592158126034372, 0.9319826199336896], 
             UndirectedEdge[184, 280] -> 
             RGBColor[
              0.2569621251304517, 0.38741386422480434`, 0.9379449849335569], 
             UndirectedEdge[402, 487] -> 
             RGBColor[
              0.565871305361324, 0.6584388437609466, 0.958966608494386], 
             UndirectedEdge[356, 463] -> 
             RGBColor[
              0.26821764598055253`, 0.3992441302795001, 0.9385859701949193], 
             UndirectedEdge[287, 301] -> 
             RGBColor[
              0.20928219811004087`, 0.33729923784437454`, 0.9352296836258756],
              UndirectedEdge[265, 328] -> 
             RGBColor[
              0.35316375548579293`, 0.48031442730049023`, 0.9437242601024758],
              UndirectedEdge[196, 321] -> 
             RGBColor[
              0.31443739392836134`, 0.4455653460211614, 0.9413008174322348], 
             UndirectedEdge[122, 267] -> 
             RGBColor[
              0.9282834555711476, 0.7330087810415269, 0.3115827018545064], 
             UndirectedEdge[330, 354] -> 
             RGBColor[
              0.3341066984387609, 0.463595840128386, 0.9425177354345229], 
             UndirectedEdge[155, 393] -> 
             RGBColor[
              0.5135503027141461, 0.615962296777659, 0.9548477075078524], 
             UndirectedEdge[291, 319] -> 
             RGBColor[
              0.6849084125962169, 0.7537749245076777, 0.969228927800723], 
             UndirectedEdge[63, 206] -> 
             RGBColor[
              0.3810348762200533, 0.5044549912372471, 0.9455001832701985], 
             UndirectedEdge[174, 215] -> 
             RGBColor[
              0.2753901052316153, 0.40678283971254936`, 0.9389944311385647], 
             UndirectedEdge[254, 471] -> 
             RGBColor[
              0.5466554162409889, 0.4017985093907806, 0.5694083486000513], 
             UndirectedEdge[453, 463] -> 
             RGBColor[
              0.2757020968027919, 0.407110762635264, 0.939012198596993], 
             UndirectedEdge[154, 174] -> 
             RGBColor[
              0.2880991557381853, 0.4200673355937856, 0.9397208847641902], 
             UndirectedEdge[119, 197] -> 
             RGBColor[
              0.8441364985929255, 0.8770550844901885, 0.8875786005274353], 
             UndirectedEdge[50, 340] -> 
             RGBColor[
              0.3891862943583425, 0.5115153399264449, 0.9460195844259542], 
             UndirectedEdge[443, 446] -> 
             RGBColor[
              0.5813316267430582, 0.5676003433786956, 0.6012346277346379], 
             UndirectedEdge[275, 324] -> 
             RGBColor[
              0.3916907059243627, 0.5136845353495464, 0.9461791633163769], 
             UndirectedEdge[95, 286] -> 
             RGBColor[
              0.22509159237078977`, 0.3539159135859121, 0.9361300052411223], 
             UndirectedEdge[306, 317] -> 
             RGBColor[
              0.8704899188810679, 0.5035084402927961, 0.2135951122625132], 
             UndirectedEdge[118, 188] -> 
             RGBColor[
              0.3311926249986076, 0.4612841383736176, 0.9423242790961401], 
             UndirectedEdge[7, 69] -> 
             RGBColor[
              0.874072307624645, 0.9024255483118935, 0.9878509910664408], 
             UndirectedEdge[88, 166] -> 
             RGBColor[
              0.8523652692557177, 0.3906026653424749, 0.19727300714892185`], 
             UndirectedEdge[9, 44] -> 
             RGBColor[
              0.5359104641208152, 0.634115283121385, 0.9566079813217554], 
             UndirectedEdge[76, 459] -> 
             RGBColor[
              0.40093570974009674`, 0.5216920929873327, 0.9467682467844796], 
             UndirectedEdge[254, 325] -> 
             RGBColor[
              0.20775758490962407`, 0.33569677270467635`, 0.935142859159575], 
             UndirectedEdge[171, 433] -> 
             RGBColor[
              0.2936242383072788, 0.42439846992600005`, 0.9400895764803525], 
             UndirectedEdge[112, 447] -> 
             RGBColor[
              0.2473817363738829, 0.37734426820991973`, 0.9373993959667855], 
             UndirectedEdge[199, 359] -> 
             RGBColor[
              0.364147570424561, 0.48982805573786037`, 0.9444241390777679], 
             UndirectedEdge[74, 224] -> 
             RGBColor[
              0.2903501525391211, 0.42250679795452123`, 0.9398463837013205], 
             UndirectedEdge[292, 386] -> 
             RGBColor[
              0.17894881608916835`, 0.3054169300929359, 0.9335022423940041], 
             UndirectedEdge[112, 195] -> 
             RGBColor[
              0.25920772540956155`, 0.3897741324974299, 0.9380728685473844], 
             UndirectedEdge[97, 408] -> 
             RGBColor[
              0.2271195205155527, 0.3560473946441286, 0.9362454927489157], 
             UndirectedEdge[236, 422] -> 
             RGBColor[
              0.26066758061653217`, 0.39130853288012224`, 0.9381560051417591],
              UndirectedEdge[27, 114] -> 
             RGBColor[
              0.5063987002640795, 0.610156303732676, 0.9542847071658003], 
             UndirectedEdge[110, 355] -> 
             RGBColor[
              0.30021105187484454`, 0.43102571577490256`, 0.9404755205872981],
              UndirectedEdge[104, 215] -> 
             RGBColor[
              0.26534838496499225`, 0.39622835503049064`, 0.9384225700247744],
              UndirectedEdge[80, 406] -> 
             RGBColor[
              0.8900806471760057, 0.9077659645302347, 0.6988562638191269], 
             UndirectedEdge[276, 292] -> 
             RGBColor[
              0.39925539426111123`, 0.5037247474643232, 0.9483475509136101], 
             UndirectedEdge[425, 466] -> 
             RGBColor[
              0.4394255113443823, 0.5536672437102792, 0.9495973233231294], 
             UndirectedEdge[164, 309] -> 
             RGBColor[
              0.9052777371288019, 0.5616050038337315, 0.3236174733815438], 
             UndirectedEdge[95, 137] -> 
             RGBColor[
              0.22358173079098384`, 0.35232895333478276`, 0.9360440208577924],
              UndirectedEdge[119, 426] -> 
             RGBColor[
              0.9304108836330538, 0.9448589600540273, 0.8960699725342486], 
             UndirectedEdge[238, 431] -> 
             RGBColor[
              0.38434692528377257`, 0.5073237216678145, 0.9457112241078087], 
             UndirectedEdge[93, 266] -> 
             RGBColor[
              0.2794030113306438, 0.41100065845557043`, 0.9392229602043418], 
             UndirectedEdge[15, 148] -> 
             RGBColor[
              0.2369473179686802, 0.36637703288571377`, 0.9368051712749479], 
             UndirectedEdge[225, 470] -> 
             RGBColor[
              0.26486570011979793`, 0.3957210226542046, 0.9383950818369088], 
             UndirectedEdge[249, 296] -> 
             RGBColor[
              0.3014838445951241, 0.4337768875889444, 0.9404962532659576], 
             UndirectedEdge[273, 421] -> 
             RGBColor[
              0.236299010735822, 0.36569562087892715`, 0.9367682511371211], 
             UndirectedEdge[150, 159] -> 
             RGBColor[
              0.821097410502475, 0.1631695188320622, 0.16783621016427433`], 
             UndirectedEdge[85, 407] -> 
             RGBColor[
              0.2142869484175896, 0.3425595477371053, 0.9355146967520258], 
             UndirectedEdge[71, 388] -> 
             RGBColor[
              0.8509768197746642, 0.8842586853652235, 0.9761468351078537], 
             UndirectedEdge[61, 435] -> 
             RGBColor[
              0.2909721876561818, 0.42176628331072286`, 0.9399328603098349], 
             UndirectedEdge[10, 177] -> 
             RGBColor[
              0.21382948684753797`, 0.34207872662224226`, 0.9354886449923652],
              UndirectedEdge[16, 52] -> 
             RGBColor[
              0.6198385630520318, 0.4001930339226935, 0.5644333341255259], 
             UndirectedEdge[25, 459] -> 
             RGBColor[
              0.35196069990557133`, 0.47927240102423385`, 0.9436476024647243],
              UndirectedEdge[105, 453] -> 
             RGBColor[
              0.265106051538209, 0.39597364723411466`, 0.9384087694946193], 
             UndirectedEdge[61, 384] -> 
             RGBColor[
              0.3038237458344487, 0.43527408579193255`, 0.9406647375359107], 
             UndirectedEdge[104, 323] -> 
             RGBColor[
              0.2429591667599799, 0.3726958671385986, 0.9371475371698791], 
             UndirectedEdge[150, 406] -> 
             RGBColor[
              0.9060315184464693, 0.5729271685521393, 0.29311167174990027`], 
             UndirectedEdge[413, 493] -> 
             RGBColor[
              0.9837066431260291, 0.9560378233723712, 0.44758049868418615`], 
             UndirectedEdge[94, 254] -> 
             RGBColor[
              0.5959586642234989, 0.6660886180136586, 0.9485638237828649], 
             UndirectedEdge[431, 487] -> 
             RGBColor[
              0.5139856537736541, 0.6161859985800608, 0.9549178263261018], 
             UndirectedEdge[234, 332] -> 
             RGBColor[
              0.3953853483413155, 0.5168846489129837, 0.946414582664141], 
             UndirectedEdge[82, 89] -> 
             RGBColor[
              0.2718901700216876, 0.4031041858982062, 0.9387951150060494], 
             UndirectedEdge[154, 255] -> 
             RGBColor[
              0.3535633647009796, 0.4806605487177418, 0.9437497228483069], 
             UndirectedEdge[22, 324] -> 
             RGBColor[
              0.41054698853962773`, 0.5300168996065678, 0.9473806689706655], 
             UndirectedEdge[105, 112] -> 
             RGBColor[
              0.2470843980758506, 0.3770317468063509, 0.9373824629905851], 
             UndirectedEdge[6, 406] -> 
             RGBColor[
              0.9091541002347256, 0.9227285742942248, 0.700740799303404], 
             UndirectedEdge[396, 422] -> 
             RGBColor[
              0.6137790328303492, 0.6759479174311498, 0.7377723993512193], 
             UndirectedEdge[409, 456] -> 
             RGBColor[
              0.23260709522442666`, 0.3618151835954873, 0.9365580020104467], 
             UndirectedEdge[91, 473] -> 
             RGBColor[
              0.32723005291391416`, 0.4578519575985201, 0.9420717875068684], 
             UndirectedEdge[369, 379] -> 
             RGBColor[
              0.3646233115605392, 0.49024011879839996`, 0.944454452882271], 
             UndirectedEdge[353, 441] -> 
             RGBColor[
              0.5448974710637005, 0.6413248437593597, 0.9573393706579376], 
             UndirectedEdge[165, 481] -> 
             RGBColor[
              0.3711249763330434, 0.49587153404117, 0.9448687332123786], 
             UndirectedEdge[185, 318] -> 
             RGBColor[
              0.3129435362062064, 0.4431846498190406, 0.9412454229080396], 
             UndirectedEdge[264, 445] -> 
             RGBColor[
              0.23221275436386601`, 0.3614007063483834, 0.9365355448818129], 
             UndirectedEdge[258, 297] -> 
             RGBColor[
              0.4463933258988235, 0.5592718859080008, 0.9501602626281445], 
             UndirectedEdge[57, 139] -> 
             RGBColor[
              0.5826390838232848, 0.6720516816961779, 0.9602866294373078], 
             UndirectedEdge[447, 463] -> 
             RGBColor[
              0.2567986541117429, 0.38724204581948013`, 0.9379356755008752], 
             UndirectedEdge[9, 26] -> 
             RGBColor[
              0.4808866078491948, 0.5876336896788764, 0.952776616899017], 
             UndirectedEdge[181, 262] -> 
             RGBColor[
              0.4483915053521436, 0.5621777184210172, 0.9499628984888329], 
             UndirectedEdge[203, 291] -> 
             RGBColor[
              0.5947468881404891, 0.681688814806365, 0.9613714325118958], 
             UndirectedEdge[45, 254] -> 
             RGBColor[
              0.25964036057789125`, 0.3902288594899984, 0.9380975064801944], 
             UndirectedEdge[240, 412] -> 
             RGBColor[
              0.2495035202048371, 0.3795743975451175, 0.9375202284170604], 
             UndirectedEdge[208, 258] -> 
             RGBColor[
              0.3477704837485026, 0.4756430463953687, 0.9433806055964585], 
             UndirectedEdge[293, 420] -> 
             RGBColor[
              0.9614575711812897, 0.9707757002112165, 0.9501264579014013], 
             UndirectedEdge[85, 346] -> 
             RGBColor[
              0.21604910573121133`, 0.34441168680094847`, 0.9356150490041585],
              UndirectedEdge[65, 166] -> 
             RGBColor[
              0.9117926198146232, 0.6283236796935395, 0.2910857426521841], 
             UndirectedEdge[254, 347] -> 
             RGBColor[
              0.20771262472504887`, 0.3356495167000475, 0.935140298743576], 
             UndirectedEdge[236, 292] -> 
             RGBColor[
              0.23314689454244097`, 0.36238254690397387`, 0.9365887427830462],
              UndirectedEdge[100, 401] -> 
             RGBColor[
              0.8523336151346661, 0.7939714926704016, 0.620783111215081], 
             UndirectedEdge[146, 400] -> 
             RGBColor[
              0.276927529490606, 0.4083987700870767, 0.9390819851756989], 
             UndirectedEdge[104, 153] -> 
             RGBColor[
              0.24575331572793313`, 0.3756326948631943, 0.937306659820031], 
             UndirectedEdge[216, 281] -> 
             RGBColor[
              0.2553973215721218, 0.3857691564707237, 0.9378558716858294], 
             UndirectedEdge[123, 125] -> 
             RGBColor[
              0.2078185513522534, 0.33576085230137553`, 0.9351463311082908], 
             UndirectedEdge[78, 358] -> 
             RGBColor[
              0.22252765585105994`, 0.3512210537407115, 0.9359839928493279], 
             UndirectedEdge[313, 478] -> 
             RGBColor[
              0.26649991887633445`, 0.3974386901827782, 0.9384881481774836], 
             UndirectedEdge[368, 401] -> 
             RGBColor[
              0.5907770138305127, 0.6754225066218276, 0.9626395084549426], 
             UndirectedEdge[106, 369] -> 
             RGBColor[
              0.46890138102995677`, 0.5788082013626439, 0.9515831360340911], 
             UndirectedEdge[111, 146] -> 
             RGBColor[
              0.2655122364597581, 0.39640057334027434`, 0.9384319011250047], 
             UndirectedEdge[129, 266] -> 
             RGBColor[
              0.32256025857167225`, 0.4520297101069751, 0.9418393155552645], 
             UndirectedEdge[99, 278] -> 
             RGBColor[
              0.9709926371751241, 0.9748878865987054, 0.7597061890098948], 
             UndirectedEdge[147, 171] -> 
             RGBColor[
              0.2566176973332457, 0.3870518487719572, 0.9379253702800414], 
             UndirectedEdge[164, 166] -> 
             RGBColor[
              0.8278225605966679, 0.21486196943559147`, 0.17427622148944416`],
              UndirectedEdge[129, 433] -> 
             RGBColor[
              0.3405530126531223, 0.4693916356931953, 0.94292071472042], 
             UndirectedEdge[179, 283] -> 
             RGBColor[
              0.18007164814629245`, 0.3065970977766376, 0.9335661860185762], 
             UndirectedEdge[136, 291] -> 
             RGBColor[
              0.8119439013123007, 0.853362410017863, 0.9518331785269256], 
             UndirectedEdge[321, 479] -> 
             RGBColor[
              0.37233306340343797`, 0.49691791834132404`, 0.9449457114522347],
              UndirectedEdge[181, 239] -> 
             RGBColor[
              0.38581385669695734`, 0.5085943039277986, 0.9458046956803003], 
             UndirectedEdge[102, 330] -> 
             RGBColor[
              0.2914935550351155, 0.4237085864737168, 0.939911498781955], 
             UndirectedEdge[406, 413] -> 
             RGBColor[
              0.9822272031257195, 0.951710324271208, 0.3854564695648335], 
             UndirectedEdge[37, 310] -> 
             RGBColor[
              0.30119863479716524`, 0.4339092406412282, 0.9404641887170249], 
             UndirectedEdge[203, 439] -> 
             RGBColor[
              0.6977395599110665, 0.7624782824674698, 0.971548992789666], 
             UndirectedEdge[320, 375] -> 
             RGBColor[
              0.9734019680069053, 0.9789510679067093, 0.8970939407523506], 
             UndirectedEdge[42, 407] -> 
             RGBColor[
              0.22341630550160935`, 0.352155080867081, 0.9360346001322872], 
             UndirectedEdge[131, 374] -> 
             RGBColor[
              0.2576696859737398, 0.38815755553304865`, 0.9379852794768397], 
             UndirectedEdge[387, 403] -> 
             RGBColor[
              0.8520128910253049, 0.8851986373727346, 0.9856507029983317], 
             UndirectedEdge[65, 348] -> 
             RGBColor[
              0.9726882187211612, 0.9195330900145834, 0.3483993164391773], 
             UndirectedEdge[217, 498] -> 
             RGBColor[
              0.3908046357587574, 0.5126843292737169, 0.9461870095342384], 
             UndirectedEdge[40, 397] -> 
             RGBColor[
              0.37237410523066483`, 0.4969534667092458, 0.9449483266011737], 
             UndirectedEdge[226, 292] -> 
             RGBColor[
              0.17919781223777545`, 0.3056786408323896, 0.9335164223563106], 
             UndirectedEdge[53, 257] -> 
             RGBColor[
              0.9176828698612274, 0.692200433274696, 0.28359567952116765`], 
             UndirectedEdge[220, 429] -> 
             RGBColor[
              0.3162555864633567, 0.44694588722950834`, 0.9414237848069549], 
             UndirectedEdge[139, 425] -> 
             RGBColor[
              0.469689014710176, 0.5782365190979204, 0.9519797771669503], 
             UndirectedEdge[317, 418] -> 
             RGBColor[
              0.9309369071770426, 0.7734480360326559, 0.5728708276939365], 
             UndirectedEdge[482, 496] -> 
             RGBColor[
              0.31768549080207875`, 0.4466395905233832, 0.9415714600344062], 
             UndirectedEdge[117, 466] -> 
             RGBColor[
              0.44229172329685795`, 0.5561498124435122, 0.9497799558142495], 
             UndirectedEdge[82, 105] -> 
             RGBColor[
              0.25209194686734443`, 0.382294998083142, 0.9376676354862561], 
             UndirectedEdge[239, 453] -> 
             RGBColor[
              0.31761867457160725`, 0.44726749674536337`, 0.9415420928317004],
              UndirectedEdge[274, 340] -> 
             RGBColor[
              0.40008441142440987`, 0.5206990676119785, 0.9467846461754836], 
             UndirectedEdge[311, 484] -> 
             RGBColor[
              0.8698742834500395, 0.8946869579845022, 0.7215434088969761], 
             UndirectedEdge[44, 140] -> 
             RGBColor[
              0.4981556569200065, 0.6034642298010868, 0.9536357845984921], 
             UndirectedEdge[139, 466] -> 
             RGBColor[
              0.5337716765091578, 0.6323789189869576, 0.9564396081263286], 
             UndirectedEdge[22, 481] -> 
             RGBColor[
              0.38481661217346425`, 0.507730540844516, 0.9457411521410921], 
             UndirectedEdge[45, 386] -> 
             RGBColor[
              0.23085473585284239`, 0.35997334278995086`, 0.9364582077366184],
              UndirectedEdge[40, 220] -> 
             RGBColor[
              0.36255668140028763`, 0.48845010762544216`, 0.9443227690359091],
              UndirectedEdge[237, 489] -> 
             RGBColor[
              0.9480949935467251, 0.959065305031835, 0.9023385571076953], 
             UndirectedEdge[61, 64] -> 
             RGBColor[
              0.3058305702683475, 0.43738338551197825`, 0.9407790232185906], 
             UndirectedEdge[82, 296] -> 
             RGBColor[
              0.28584922180975014`, 0.4173439077491774, 0.9396058846276822], 
             UndirectedEdge[27, 277] -> 
             RGBColor[
              0.6417102241932708, 0.7180330594388474, 0.9662874050409727], 
             UndirectedEdge[416, 427] -> 
             RGBColor[
              0.2705169061527906, 0.4016607985020373, 0.9387169096602777], 
             UndirectedEdge[59, 82] -> 
             RGBColor[
              0.25023486400687867`, 0.3803430862509384, 0.9375618773646605], 
             UndirectedEdge[271, 444] -> 
             RGBColor[
              0.26354918336029226`, 0.3943372800679805, 0.938320108155067], 
             UndirectedEdge[6, 486] -> 
             RGBColor[
              0.8813087089314302, 0.9081956582870432, 0.9885412054830938], 
             UndirectedEdge[171, 265] -> 
             RGBColor[
              0.29137836531202577`, 0.42245320761837074`, 0.9399464714390425],
              UndirectedEdge[219, 369] -> 
             RGBColor[
              0.47310816162837227`, 0.5822234553657439, 0.9519143092127434], 
             UndirectedEdge[244, 355] -> 
             RGBColor[
              0.3355739158146536, 0.46507899226839733`, 0.9426034510727153], 
             UndirectedEdge[450, 500] -> 
             RGBColor[
              0.8186005728713881, 0.14397773067830186`, 0.16544523562897076`],
              UndirectedEdge[18, 243] -> 
             RGBColor[
              0.8618450148200435, 0.43551288339499367`, 0.2052561643181862], 
             UndirectedEdge[377, 449] -> 
             RGBColor[
              0.8547039434845443, 0.8865518671157351, 0.9452111853810878], 
             UndirectedEdge[7, 173] -> 
             RGBColor[
              0.9116225315818571, 0.9310453814508525, 0.9449853696775101], 
             UndirectedEdge[3, 8] -> 
             RGBColor[
              0.5409798313044035, 0.6382308237734111, 0.9570070604761514], 
             UndirectedEdge[405, 469] -> 
             RGBColor[
              0.9272216806853377, 0.724366095358756, 0.3974739978928766], 
             UndirectedEdge[148, 190] -> 
             RGBColor[
              0.2438827304039313, 0.37366659108570865`, 0.9372001327531121], 
             UndirectedEdge[180, 216] -> 
             RGBColor[
              0.2680084621160904, 0.3990242647749275, 0.9385740574832979], 
             UndirectedEdge[257, 317] -> 
             RGBColor[
              0.8711268784377937, 0.5076990787158229, 0.21417744721027115`], 
             UndirectedEdge[49, 462] -> 
             RGBColor[
              0.4770465403942916, 0.586326898050649, 0.9519739976203461], 
             UndirectedEdge[223, 258] -> 
             RGBColor[
              0.3816431136278576, 0.5049818159089863, 0.9455389396199805], 
             UndirectedEdge[260, 440] -> 
             RGBColor[
              0.28362513416460355`, 0.4154383772521112, 0.9394634038536649], 
             UndirectedEdge[262, 332] -> 
             RGBColor[
              0.43913893362174417`, 0.5541636058359223, 0.9493733327998998], 
             UndirectedEdge[283, 386] -> 
             RGBColor[
              0.18007057961528944`, 0.30659597468280464`, 0.9335661251673164],
              UndirectedEdge[40, 289] -> 
             RGBColor[
              0.41278560473143366`, 0.5319558764357888, 0.9475233116148768], 
             UndirectedEdge[95, 430] -> 
             RGBColor[
              0.23341097282813747`, 0.36266010992577125`, 0.9366037816507478],
              UndirectedEdge[274, 334] -> 
             RGBColor[
              0.4327691697643524, 0.5490089625023165, 0.9488672900749079], 
             UndirectedEdge[75, 158] -> 
             RGBColor[
              0.3512349205505469, 0.4786437674256428, 0.9436013564460036], 
             UndirectedEdge[233, 476] -> 
             RGBColor[
              0.8458261121541704, 0.35324515591315253`, 0.19151644279301172`],
              UndirectedEdge[240, 416] -> 
             RGBColor[
              0.2590796192147955, 0.38963948476432886`, 0.9380655730891085], 
             UndirectedEdge[260, 280] -> 
             RGBColor[
              0.27123440340689225`, 0.4024149336080515, 0.9387577700674566], 
             UndirectedEdge[11, 193] -> 
             RGBColor[
              0.2633649248993141, 0.3941436127428313, 0.9383096149083003], 
             UndirectedEdge[3, 162] -> 
             RGBColor[
              0.4618487252450588, 0.5739886270587315, 0.9507775699403673], 
             UndirectedEdge[117, 338] -> 
             RGBColor[
              0.3505903006321732, 0.47808543005188675`, 0.9435602818348199], 
             UndirectedEdge[40, 472] -> 
             RGBColor[
              0.35732343693452717`, 0.4839173342997152, 0.9439893113261273], 
             UndirectedEdge[101, 355] -> 
             RGBColor[
              0.424769765192925, 0.5405027707410431, 0.9487934456872616], 
             UndirectedEdge[47, 364] -> 
             RGBColor[
              0.24525016381875867`, 0.3751038503049783, 0.93727800606315], 
             UndirectedEdge[377, 484] -> 
             RGBColor[
              0.9869984046810305, 0.9863165950507087, 0.692275872605006], 
             UndirectedEdge[21, 227] -> 
             RGBColor[
              0.9132594664564218, 0.6494694053055374, 0.28579138582517527`], 
             UndirectedEdge[158, 441] -> 
             RGBColor[
              0.4038268661048062, 0.5241962673166999, 0.9469524687114896], 
             UndirectedEdge[201, 222] -> 
             RGBColor[
              0.3735862388275236, 0.49760697262793063`, 0.9450400762157048], 
             UndirectedEdge[107, 477] -> 
             RGBColor[
              0.21467165996386678`, 0.3429639039643634, 0.9355366055054566], 
             UndirectedEdge[89, 239] -> 
             RGBColor[
              0.31821611673686917`, 0.4478954463410748, 0.9415761162791756], 
             UndirectedEdge[63, 275] -> 
             RGBColor[
              0.41651977831287657`, 0.5351902299070133, 0.9477612498534863], 
             UndirectedEdge[133, 344] -> 
             RGBColor[
              0.404458323018091, 0.5244601408973477, 0.9470709156438875], 
             UndirectedEdge[153, 356] -> 
             RGBColor[
              0.2571354474729763, 0.3875960369960689, 0.9379548553845563], 
             UndirectedEdge[151, 188] -> 
             RGBColor[
              0.32203573450029344`, 0.4531724542663287, 0.9417474171352478], 
             UndirectedEdge[140, 204] -> 
             RGBColor[
              0.5007635578511195, 0.6055814412615623, 0.9538410881128452], 
             UndirectedEdge[154, 369] -> 
             RGBColor[
              0.36474431369771637`, 0.4903449247678786, 0.944462163031454], 
             UndirectedEdge[16, 179] -> 
             RGBColor[
              0.29140560923354364`, 0.4148201691111312, 0.940228554342059], 
             UndirectedEdge[161, 341] -> 
             RGBColor[
              0.9919526646253864, 0.9838559907810486, 0.4794106025405692], 
             UndirectedEdge[48, 408] -> 
             RGBColor[
              0.21500770505426564`, 0.34331710866086196`, 0.9355557427762207],
              UndirectedEdge[153, 263] -> 
             RGBColor[
              0.25916680795964386`, 0.3897311256632503, 0.9380705383591434], 
             UndirectedEdge[62, 132] -> 
             RGBColor[
              0.9037259559281465, 0.5621573598635239, 0.4887023579770914], 
             UndirectedEdge[82, 225] -> 
             RGBColor[
              0.2662639580467382, 0.39719068039009175`, 0.9384747105573108], 
             UndirectedEdge[216, 465] -> 
             RGBColor[
              0.27425578181697063`, 0.40559059388349944`, 0.9389298330981818],
              UndirectedEdge[119, 489] -> 
             RGBColor[
              0.9903724843514137, 0.9902867891105125, 0.8092163797162932], 
             UndirectedEdge[287, 295] -> 
             RGBColor[
              0.2196997994484176, 0.34824879736508285`, 0.9358229506106359], 
             UndirectedEdge[28, 417] -> 
             RGBColor[
              0.8329443683967894, 0.8698408046783143, 0.9576048606613091], 
             UndirectedEdge[148, 351] -> 
             RGBColor[
              0.26485064633186906`, 0.3957052001686261, 0.9383942245459564], 
             UndirectedEdge[218, 336] -> 
             RGBColor[
              0.2271057420788739, 0.35603291263357584`, 0.9362447080873302], 
             UndirectedEdge[127, 254] -> 
             RGBColor[
              0.23123903037733173`, 0.3603772607008694, 0.9364800927412753], 
             UndirectedEdge[303, 473] -> 
             RGBColor[
              0.31604489027716914`, 0.44784149062043943`, 0.9413708849892584],
              UndirectedEdge[99, 267] -> 
             RGBColor[
              0.9913420700473246, 0.9817665875606343, 0.479566100729647], 
             UndirectedEdge[48, 145] -> 
             RGBColor[
              0.21408452170973263`, 0.34234678443255295`, 0.9355031688504769],
              UndirectedEdge[224, 342] -> 
             RGBColor[
              0.2794767176957349, 0.41107812851853454`, 0.939227157672795], 
             UndirectedEdge[193, 232] -> 
             RGBColor[
              0.32200467219797546`, 0.4513904780484862, 0.9418096996419872], 
             UndirectedEdge[216, 343] -> 
             RGBColor[
              0.2793867448603114, 0.4109835613638972, 0.9392220338529205], 
             UndirectedEdge[277, 449] -> 
             RGBColor[
              0.7498021540184663, 0.8044704085174408, 0.9756969294792002], 
             UndirectedEdge[257, 418] -> 
             RGBColor[
              0.9186634619525802, 0.7177171878043327, 0.5626295641489729], 
             UndirectedEdge[45, 422] -> 
             RGBColor[
              0.2583972380161019, 0.3889222588590351, 0.9380267124893356], 
             UndirectedEdge[133, 235] -> 
             RGBColor[
              0.3511076947395869, 0.47853357082274445`, 0.9435932497298307], 
             UndirectedEdge[145, 183] -> 
             RGBColor[
              0.21281275410739692`, 0.3410100760477749, 0.9354307435669353], 
             UndirectedEdge[196, 496] -> 
             RGBColor[
              0.2862944389618104, 0.41824398583767475`, 0.9396154168129832], 
             UndirectedEdge[115, 136] -> 
             RGBColor[
              0.9450645210490293, 0.9581750855858149, 0.964884369377244], 
             UndirectedEdge[267, 413] -> 
             RGBColor[
              0.981449315920919, 0.9490863280728146, 0.38243452466585603`], 
             UndirectedEdge[217, 340] -> 
             RGBColor[
              0.32857716094804046`, 0.4590187548700618, 0.9421576240396021], 
             UndirectedEdge[335, 383] -> 
             RGBColor[
              0.3028573462736385, 0.4337853452642071, 0.940627021112898], 
             UndirectedEdge[80, 493] -> 
             RGBColor[
              0.8915600871763152, 0.912093463631398, 0.7609802929384797], 
             UndirectedEdge[307, 372] -> 
             RGBColor[
              0.47013131999468205`, 0.580712810603117, 0.9514296061392018], 
             UndirectedEdge[18, 434] -> 
             RGBColor[
              0.9377932493402739, 0.7792631319127137, 0.510349510564296], 
             UndirectedEdge[130, 179] -> 
             RGBColor[
              0.17892806853100302`, 0.30539512309383293`, 0.93350106085126], 
             UndirectedEdge[20, 228] -> 
             RGBColor[
              0.9388076655030091, 0.7780938721344945, 0.3568427286125849], 
             UndirectedEdge[297, 311] -> 
             RGBColor[
              0.6331105387907436, 0.7114259084862791, 0.9653543852266682], 
             UndirectedEdge[127, 200] -> 
             RGBColor[
              0.5634039093287206, 0.4987072281229762, 0.587570692606852], 
             UndirectedEdge[54, 391] -> 
             RGBColor[
              0.23492401226674847`, 0.36425041030799266`, 0.9366899470084354],
              UndirectedEdge[347, 368] -> 
             RGBColor[
              0.2935143249909316, 0.4166464351270609, 0.9403629270800464], 
             UndirectedEdge[22, 182] -> 
             RGBColor[
              0.4150015938204914, 0.5338752548058805, 0.9476645124801093], 
             UndirectedEdge[96, 216] -> 
             RGBColor[
              0.2810238579235662, 0.4127042709923413, 0.9393152650199811], 
             UndirectedEdge[340, 363] -> 
             RGBColor[
              0.37112295968624204`, 0.49586978732307024`, 0.9448686047134276],
              UndirectedEdge[71, 490] -> 
             RGBColor[
              0.8731675486403643, 0.8997516085621015, 0.891254202422064], 
             UndirectedEdge[111, 201] -> 
             RGBColor[
              0.28877500860148286`, 0.42085122180616963`, 0.9397566815842886],
              UndirectedEdge[261, 484] -> 
             RGBColor[
              0.9364392575786439, 0.7675671876801757, 0.34462692180178206`], 
             UndirectedEdge[416, 499] -> 
             RGBColor[
              0.26112616120390136`, 0.3917905301531358, 0.9381821206278006], 
             UndirectedEdge[42, 430] -> 
             RGBColor[
              0.2361066473396595, 0.36549343475301654`, 0.9367572963262859], 
             UndirectedEdge[6, 81] -> 
             RGBColor[
              0.825653983169494, 0.8638180906717614, 0.9832328080563602], 
             UndirectedEdge[282, 353] -> 
             RGBColor[
              0.6236604649477651, 0.705354686885191, 0.9635159828256973], 
             UndirectedEdge[275, 441] -> 
             RGBColor[
              0.43191818188119013`, 0.5485275531316196, 0.9487424225125856], 
             UndirectedEdge[50, 255] -> 
             RGBColor[
              0.41926177634102413`, 0.5375652107821666, 0.9479359675431862], 
             UndirectedEdge[110, 217] -> 
             RGBColor[
              0.29571753049971145`, 0.4271336534107135, 0.9401891973787395], 
             UndirectedEdge[30, 110] -> 
             RGBColor[
              0.26982326266389456`, 0.40093173521567016`, 0.9386774076897386],
              UndirectedEdge[77, 482] -> 
             RGBColor[
              0.4826496570055525, 0.5883007255405965, 0.9531265853256541], 
             UndirectedEdge[52, 326] -> 
             RGBColor[
              0.8554852780065134, 0.4011124754177182, 0.19973320349637064`], 
             UndirectedEdge[44, 247] -> 
             RGBColor[
              0.4958443155073958, 0.6015877787175854, 0.9534538273357688], 
             UndirectedEdge[337, 348] -> 
             RGBColor[
              0.9100611549268829, 0.8839036332529456, 0.6426467308354947], 
             UndirectedEdge[48, 78] -> 
             RGBColor[
              0.21346998781254425`, 0.3417008703429085, 0.9354681720541533], 
             UndirectedEdge[420, 432] -> 
             RGBColor[
              0.933633649289228, 0.949068614748616, 0.9640782438285385], 
             UndirectedEdge[469, 474] -> 
             RGBColor[
              0.9267639161265591, 0.7252718203703219, 0.4846569116242533], 
             UndirectedEdge[172, 366] -> 
             RGBColor[
              0.3083293758751098, 0.43743710670339436`, 0.941015524989468], 
             UndirectedEdge[102, 415] -> 
             RGBColor[
              0.28177512151681394`, 0.41349389666170766`, 0.9393580483702217],
              UndirectedEdge[414, 485] -> 
             RGBColor[
              0.26132957932407624`, 0.39200433549489333`, 0.9381937049888145],
              UndirectedEdge[102, 193] -> 
             RGBColor[
              0.2821746373958698, 0.4139138131813651, 0.9393808002085031], 
             UndirectedEdge[128, 498] -> 
             RGBColor[
              0.4783163619958606, 0.5873577964316139, 0.9520739626283314], 
             UndirectedEdge[150, 443] -> 
             RGBColor[
              0.8779783180841267, 0.47195372718941886`, 0.21716686938390278`],
              UndirectedEdge[2, 230] -> 
             RGBColor[
              0.21816285424353754`, 0.34663337050679954`, 0.9357354238549247],
              UndirectedEdge[367, 416] -> 
             RGBColor[
              0.24568937276892794`, 0.3755654867590621, 0.9373030183631108], 
             UndirectedEdge[61, 473] -> 
             RGBColor[
              0.3253289757704718, 0.4562053401277858, 0.9419506525523447], 
             UndirectedEdge[56, 164] -> 
             RGBColor[
              0.8270991589089857, 0.20930158706742483`, 0.17358349121635427`],
              UndirectedEdge[20, 388] -> 
             RGBColor[
              0.9153530643766437, 0.7639768167303482, 0.6006827363489642], 
             UndirectedEdge[195, 296] -> 
             RGBColor[
              0.29178587282524443`, 0.4235837043718764, 0.9399439681205266], 
             UndirectedEdge[135, 391] -> 
             RGBColor[
              0.24587699790050546`, 0.37576269266847045`, 0.9373137033367878],
              UndirectedEdge[310, 399] -> 
             RGBColor[
              0.26912901254486776`, 0.40020203432257306`, 0.938637871172511], 
             UndirectedEdge[150, 476] -> 
             RGBColor[
              0.834968541704233, 0.26978911161722496`, 0.18111922106827977`], 
             UndirectedEdge[142, 222] -> 
             RGBColor[
              0.5711190039988594, 0.6615355308329243, 0.9600580034664301], 
             UndirectedEdge[48, 404] -> 
             RGBColor[
              0.21047959213928613`, 0.3385577748882776, 0.9352978734444553], 
             UndirectedEdge[330, 415] -> 
             RGBColor[
              0.29673111972249494`, 0.4292135990409338, 0.9402097703426187], 
             UndirectedEdge[326, 495] -> 
             RGBColor[
              0.8586889913459645, 0.42573762002087545`, 0.2028010830083056], 
             UndirectedEdge[36, 382] -> 
             RGBColor[
              0.26830699274776615`, 0.39933803939675394`, 0.9385910583611354],
              UndirectedEdge[31, 289] -> 
             RGBColor[
              0.4462046575439149, 0.5609017802915265, 0.9496527441087801], 
             UndirectedEdge[436, 487] -> 
             RGBColor[
              0.5261755956139467, 0.6262120783166807, 0.9558416168128965], 
             UndirectedEdge[251, 427] -> 
             RGBColor[
              0.2690226652198594, 0.4000902565411794, 0.9386318148496786], 
             UndirectedEdge[108, 437] -> 
             RGBColor[
              0.27047057871071917`, 0.40161210542309067`, 0.938714271380987], 
             UndirectedEdge[258, 397] -> 
             RGBColor[
              0.36598524788401654`, 0.49141975958888606`, 0.94454123426049], 
             UndirectedEdge[308, 422] -> 
             RGBColor[
              0.20647914454706495`, 0.3343530508258261, 0.9350700538722102], 
             UndirectedEdge[16, 292] -> 
             RGBColor[
              0.29142635679170903`, 0.41484197611023416`, 0.9402297358848033],
              UndirectedEdge[68, 317] -> 
             RGBColor[
              0.8516933912786147, 0.35903009244942585`, 0.19559553620276254`],
              UndirectedEdge[34, 468] -> 
             RGBColor[
              0.51106504599871, 0.6139446534165288, 0.9546520589954179], 
             UndirectedEdge[350, 383] -> 
             RGBColor[
              0.34555625661750283`, 0.4737251941447882, 0.9432395170016354], 
             UndirectedEdge[190, 342] -> 
             RGBColor[
              0.25404838087349885`, 0.38435133426869084`, 0.9377790515086218],
              UndirectedEdge[61, 303] -> 
             RGBColor[
              0.31454260624684305`, 0.4465402877003618, 0.9412751607792637], 
             UndirectedEdge[214, 421] -> 
             RGBColor[
              0.18943186031713002`, 0.3164352742399168, 0.9340992362545124], 
             UndirectedEdge[219, 370] -> 
             RGBColor[
              0.5588561185016121, 0.6527435990376659, 0.9584143472873132], 
             UndirectedEdge[91, 366] -> 
             RGBColor[
              0.29631757138809034`, 0.4270330853875859, 0.9402501434291768], 
             UndirectedEdge[273, 477] -> 
             RGBColor[
              0.2691065215645594, 0.4001783948762585, 0.9386365903444549], 
             UndirectedEdge[153, 323] -> 
             RGBColor[
              0.24213881509518778`, 0.3718336255256024, 0.9371008193561707], 
             UndirectedEdge[170, 433] -> 
             RGBColor[
              0.31109341012253816`, 0.4427596771133032, 0.9410844199719078], 
             UndirectedEdge[1, 54] -> 
             RGBColor[
              0.24744314331957223`, 0.3774088108032645, 0.937402893001499], 
             UndirectedEdge[277, 377] -> 
             RGBColor[
              0.8762033212681233, 0.9033473444415901, 0.9473540424354466], 
             UndirectedEdge[307, 417] -> 
             RGBColor[
              0.5854211152910297, 0.6734114544902967, 0.9611201594979415], 
             UndirectedEdge[58, 371] -> 
             RGBColor[
              0.3390278312734188, 0.4680706002399412, 0.9428235315115703], 
             UndirectedEdge[9, 269] -> 
             RGBColor[
              0.512041509774998, 0.614618499836106, 0.9547617797005311], 
             UndirectedEdge[184, 453] -> 
             RGBColor[
              0.2706693526642461, 0.401821029451244, 0.9387255912635806], 
             UndirectedEdge[42, 97] -> 
             RGBColor[
              0.23210438822814727`, 0.3612868066689332, 0.936529373590697], 
             UndirectedEdge[161, 405] -> 
             RGBColor[
              0.9921723207517021, 0.9843258130245969, 0.5033188163295588], 
             UndirectedEdge[304, 429] -> 
             RGBColor[
              0.316081007071654, 0.4467946753350308, 0.9414126607624902], 
             UndirectedEdge[127, 130] -> 
             RGBColor[
              0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993],
              UndirectedEdge[318, 330] -> 
             RGBColor[
              0.32419593809646025`, 0.45501163764918373`, 0.9418862305492528],
              UndirectedEdge[393, 468] -> 
             RGBColor[
              0.4697942541627981, 0.5804391653761509, 0.9514030710822032], 
             UndirectedEdge[334, 355] -> 
             RGBColor[
              0.36575544066311605`, 0.49122071212458884`, 0.9445265911475849],
              UndirectedEdge[290, 378] -> 
             RGBColor[
              0.28478483318943354`, 0.41665729445637256`, 0.939529446997508], 
             UndirectedEdge[92, 498] -> 
             RGBColor[
              0.5355135500520953, 0.6337930503996233, 0.9565767347923217], 
             UndirectedEdge[340, 362] -> 
             RGBColor[
              0.3629480512357022, 0.4887890925060583, 0.944347706775747], 
             UndirectedEdge[58, 304] -> 
             RGBColor[
              0.3268378953241502, 0.4575122904046801, 0.94204679957202], 
             UndirectedEdge[51, 308] -> 
             RGBColor[
              0.1789366427891193, 0.3054041351827525, 0.9335015491425751], 
             UndirectedEdge[59, 447] -> 
             RGBColor[
              0.2443455259866942, 0.3741530185861272, 0.9372264882769058], 
             UndirectedEdge[186, 485] -> 
             RGBColor[
              0.24185580045044375`, 0.3715361591898116, 0.9370847020908353], 
             UndirectedEdge[340, 379] -> 
             RGBColor[
              0.32336688058112073`, 0.45450587189254155`, 0.941825629581892], 
             UndirectedEdge[129, 410] -> 
             RGBColor[
              0.3596323931506261, 0.48591723612258636`, 0.9441364359744873], 
             UndirectedEdge[192, 225] -> 
             RGBColor[
              0.26443196618769516`, 0.395265140791245, 0.9383703813311275], 
             UndirectedEdge[306, 420] -> 
             RGBColor[
              0.9131111718754747, 0.7098607039273219, 0.5703676016486996], 
             UndirectedEdge[16, 45] -> 
             RGBColor[
              0.343332276555383, 0.46939838880724916`, 0.9431857012274175], 
             UndirectedEdge[334, 361] -> 
             RGBColor[
              0.5235027630627838, 0.6226423570970218, 0.9560294677740079], 
             UndirectedEdge[306, 357] -> 
             RGBColor[
              0.8823608988640697, 0.5565720408834082, 0.22345710970379568`], 
             UndirectedEdge[335, 496] -> 
             RGBColor[
              0.27683085763382376`, 0.40829716183624876`, 0.9390764798564684],
              UndirectedEdge[176, 345] -> 
             RGBColor[
              0.6333349002315553, 0.7129428013259062, 0.9644594745728776], 
             UndirectedEdge[15, 78] -> 
             RGBColor[
              0.22683394628673456`, 0.35574723802318886`, 0.9362292297190538],
              UndirectedEdge[52, 210] -> 
             RGBColor[
              0.8359293793650189, 0.2771745309197725, 0.1820393202973592], 
             UndirectedEdge[392, 465] -> 
             RGBColor[
              0.2943134873153461, 0.42667251409427237`, 0.9400720897535981], 
             UndirectedEdge[354, 414] -> 
             RGBColor[
              0.3182109057650159, 0.4468883541768137, 0.941612493557471], 
             UndirectedEdge[56, 428] -> 
             RGBColor[
              0.8335035522712653, 0.25852856087297227`, 0.179716345532801], 
             UndirectedEdge[44, 425] -> 
             RGBColor[
              0.43601004951768985`, 0.5508944179345684, 0.9493284456568833], 
             UndirectedEdge[106, 468] -> 
             RGBColor[
              0.4981161809408796, 0.6034321814228589, 0.9536326769048099], 
             UndirectedEdge[142, 461] -> 
             RGBColor[
              0.8219899053555546, 0.8616442791794481, 0.9747961115925544], 
             UndirectedEdge[203, 297] -> 
             RGBColor[
              0.5269654224863035, 0.6268532953529551, 0.9559037948775195], 
             UndirectedEdge[24, 176] -> 
             RGBColor[
              0.7219583100603643, 0.7823133904412213, 0.9732561905650118], 
             UndirectedEdge[351, 356] -> 
             RGBColor[
              0.2796916905937343, 0.4113040786644009, 0.9392394000613121], 
             UndirectedEdge[315, 368] -> 
             RGBColor[
              0.2968006331253079, 0.42010055334026064`, 0.9405500774666419], 
             UndirectedEdge[278, 406] -> 
             RGBColor[
              0.969491060817788, 0.9705130400681918, 0.6951727540379807], 
             UndirectedEdge[247, 360] -> 
             RGBColor[
              0.5371888520305683, 0.6351531360172418, 0.9567086207009003], 
             UndirectedEdge[78, 145] -> 
             RGBColor[
              0.22004363289237822`, 0.3486101881149849, 0.9358425314166136], 
             UndirectedEdge[19, 466] -> 
             RGBColor[
              0.5316163498821903, 0.6306291277348275, 0.9562699329190321], 
             UndirectedEdge[60, 151] -> 
             RGBColor[
              0.2997519610227203, 0.4323886947798715, 0.9403818027857322], 
             UndirectedEdge[109, 186] -> 
             RGBColor[
              0.24483520726957755`, 0.37466770466202415`, 0.9372543749015474],
              UndirectedEdge[474, 495] -> 
             RGBColor[
              0.917649812825669, 0.658402887580602, 0.4760539940908434], 
             UndirectedEdge[36, 412] -> 
             RGBColor[
              0.24838538806776134`, 0.3783991697753788, 0.9374565524459821], 
             UndirectedEdge[259, 469] -> 
             RGBColor[
              0.8611356885897954, 0.46233141911773723`, 0.2058405534946276], 
             UndirectedEdge[6, 80] -> 
             RGBColor[
              0.8086163665159423, 0.8504788015959455, 0.9815424524658205], 
             UndirectedEdge[287, 389] -> 
             RGBColor[
              0.214155749354975, 0.34242164920379625`, 0.9355072251595016], 
             UndirectedEdge[158, 410] -> 
             RGBColor[
              0.3605931713874897, 0.48674941394123933`, 0.9441976559141574], 
             UndirectedEdge[414, 415] -> 
             RGBColor[
              0.2808353270487499, 0.4125061130893616, 0.9393045284655668], 
             UndirectedEdge[10, 245] -> 
             RGBColor[
              0.22026264269435236`, 0.3488403813028832, 0.93585500370084], 
             UndirectedEdge[115, 178] -> 
             RGBColor[
              0.9564265081535962, 0.965404037867567, 0.8899068420398936], 
             UndirectedEdge[88, 348] -> 
             RGBColor[
              0.9132608681622556, 0.6818120756635188, 0.2545865809359151], 
             UndirectedEdge[135, 170] -> 
             RGBColor[
              0.2736536686143132, 0.40495773473132446`, 0.9388955436420372], 
             UndirectedEdge[3, 203] -> 
             RGBColor[
              0.49811633466717364`, 0.6034323062247897, 0.9536326890067068], 
             UndirectedEdge[84, 374] -> 
             RGBColor[
              0.24252230770556474`, 0.3722367005739444, 0.9371226586930053], 
             UndirectedEdge[29, 172] -> 
             RGBColor[
              0.3806363827099919, 0.5041098361876981, 0.9454747916161113], 
             UndirectedEdge[262, 387] -> 
             RGBColor[
              0.6255998101870561, 0.7048955003973141, 0.9650590620780228], 
             UndirectedEdge[179, 276] -> 
             RGBColor[
              0.39923464670294595`, 0.5037029404652202, 0.9483463693708659], 
             UndirectedEdge[348, 428] -> 
             RGBColor[
              0.8951225528654855, 0.5552983535621828, 0.23772264959288408`], 
             UndirectedEdge[104, 351] -> 
             RGBColor[
              0.2683095588486911, 0.39934073653152624`, 0.9385912044967868], 
             UndirectedEdge[111, 271] -> 
             RGBColor[
              0.2644482810539334, 0.39528228875008364`, 0.938371310438624], 
             UndirectedEdge[136, 277] -> 
             RGBColor[
              0.8701310969045036, 0.8988186894535575, 0.9576327343932979], 
             UndirectedEdge[246, 442] -> 
             RGBColor[
              0.28908336711974203`, 0.42117532615991926`, 0.939774242145728], 
             UndirectedEdge[206, 266] -> 
             RGBColor[
              0.31612745049209645`, 0.4464579350707817, 0.9414294227127427], 
             UndirectedEdge[31, 381] -> 
             RGBColor[
              0.5111715324361403, 0.6140235083829432, 0.9546625406628318], 
             UndirectedEdge[31, 472] -> 
             RGBColor[
              0.39074248974700837`, 0.5128632381554529, 0.9461187438200305], 
             UndirectedEdge[342, 453] -> 
             RGBColor[
              0.27214698791275327`, 0.40337411778491095`, 0.9388097404050177],
              UndirectedEdge[200, 475] -> 
             RGBColor[
              0.8699156991968737, 0.47168384997259694`, 0.2119718972840306], 
             UndirectedEdge[92, 101] -> 
             RGBColor[
              0.5649851581111299, 0.6577194295027604, 0.9588968477367864], 
             UndirectedEdge[193, 376] -> 
             RGBColor[
              0.2836334092052663, 0.4154470748445156, 0.9394638751049887], 
             UndirectedEdge[253, 319] -> 
             RGBColor[
              0.8499607656875054, 0.8826374101392084, 0.934970872933598], 
             UndirectedEdge[249, 280] -> 
             RGBColor[
              0.27322012310800536`, 0.4045020509158221, 0.938870853866826], 
             UndirectedEdge[153, 195] -> 
             RGBColor[
              0.2575424446398453, 0.3880238168235591, 0.9379780332711112], 
             UndirectedEdge[313, 380] -> 
             RGBColor[
              0.26990447818225494`, 0.4010170978748282, 0.9386820327933616], 
             UndirectedEdge[178, 357] -> 
             RGBColor[
              0.9494134599221778, 0.8301932628763469, 0.5158066666080678], 
             UndirectedEdge[163, 494] -> 
             RGBColor[
              0.262747921993954, 0.39349510356905415`, 0.938274477505614], 
             UndirectedEdge[24, 237] -> 
             RGBColor[
              0.871532203465174, 0.9004001382044219, 0.9876087136641327], 
             UndirectedEdge[101, 345] -> 
             RGBColor[
              0.5902789610650883, 0.677988050262613, 0.9610699533225915], 
             UndirectedEdge[320, 361] -> 
             RGBColor[
              0.8164019725999951, 0.8557645940777792, 0.9018606390244552], 
             UndirectedEdge[328, 487] -> 
             RGBColor[
              0.4823721914903405, 0.5888040064890694, 0.952903444464096], 
             UndirectedEdge[322, 494] -> 
             RGBColor[
              0.2588610411681461, 0.3894097453786518, 0.9380531253927091], 
             UndirectedEdge[108, 266] -> 
             RGBColor[
              0.28731571918259713`, 0.4193174161026276, 0.9396735772107083], 
             UndirectedEdge[405, 474] -> 
             RGBColor[
              0.9935549188322322, 0.9905077851325332, 0.6768786341569868], 
             UndirectedEdge[338, 379] -> 
             RGBColor[
              0.31470226354501973`, 0.4470010161121858, 0.9412735278461717], 
             UndirectedEdge[175, 309] -> 
             RGBColor[
              0.9743805147039586, 0.9770030600582216, 0.7213206267986814], 
             UndirectedEdge[294, 430] -> 
             RGBColor[
              0.23902588418057213`, 0.36856173776312173`, 0.9369235425457519],
              UndirectedEdge[197, 237] -> 
             RGBColor[
              0.8018590077882369, 0.845833600411511, 0.9807007779188375], 
             UndirectedEdge[94, 500] -> 
             RGBColor[
              0.8874558706447166, 0.5585534617562613, 0.5633237757723539], 
             UndirectedEdge[242, 365] -> 
             RGBColor[
              0.22099114578241763`, 0.3496060842382034, 0.9358964908739815], 
             UndirectedEdge[401, 500] -> 
             RGBColor[
              0.7964725199858478, 0.48689043193741693`, 0.5721768321079614], 
             UndirectedEdge[334, 340] -> 
             RGBColor[
              0.37011932022613914`, 0.4950004852671151, 0.9448046536945134], 
             UndirectedEdge[60, 310] -> 
             RGBColor[
              0.2947333345295756, 0.4271138001362785, 0.9400959994313403], 
             UndirectedEdge[50, 379] -> 
             RGBColor[
              0.37511861305326666`, 0.49933062144220947`, 0.9451232042127569],
              UndirectedEdge[123, 177] -> 
             RGBColor[
              0.2078300375710318, 0.33577292504558, 0.935146985231458], 
             UndirectedEdge[231, 246] -> 
             RGBColor[
              0.27633388437422024`, 0.407774811430481, 0.93904817796454], 
             UndirectedEdge[182, 282] -> 
             RGBColor[
              0.4931225250647846, 0.5973489755441486, 0.9538002129842165], 
             UndirectedEdge[185, 193] -> 
             RGBColor[
              0.28587823371129695`, 0.41780652773044813`, 0.9395917145396869],
              UndirectedEdge[395, 447] -> 
             RGBColor[
              0.2557437599820415, 0.3861332852050131, 0.9378756008407647], 
             UndirectedEdge[22, 282] -> 
             RGBColor[
              0.5295374583805197, 0.6288897605144723, 0.956120540334634], 
             UndirectedEdge[195, 323] -> 
             RGBColor[
              0.2547482956718921, 0.38508698909896344`, 0.9378189106209592], 
             UndirectedEdge[99, 486] -> 
             RGBColor[
              0.9642745659488295, 0.9698576677518461, 0.7703884518083142], 
             UndirectedEdge[454, 469] -> 
             RGBColor[
              0.8801565520867384, 0.5487007178218191, 0.22171202824050545`], 
             UndirectedEdge[31, 208] -> 
             RGBColor[
              0.38757839390763205`, 0.5101226573714661, 0.9459171304310454], 
             UndirectedEdge[398, 472] -> 
             RGBColor[
              0.2947988861662292, 0.4253612331985043, 0.9401664252880289], 
             UndirectedEdge[191, 389] -> 
             RGBColor[
              0.21845058194335062`, 0.3469357905622929, 0.9357518095217741], 
             UndirectedEdge[133, 151] -> 
             RGBColor[
              0.3259839947322987, 0.4565922388339624, 0.9419989967859217], 
             UndirectedEdge[165, 268] -> 
             RGBColor[
              0.4168440173490807, 0.5354710694634455, 0.9477819100781599], 
             UndirectedEdge[166, 495] -> 
             RGBColor[
              0.8401614416386582, 0.3097040160564781, 0.18609194791002698`], 
             UndirectedEdge[346, 430] -> 
             RGBColor[
              0.22881084125106885`, 0.35782507997308444`, 0.9363418109627185],
              UndirectedEdge[169, 219] -> 
             RGBColor[
              0.5095055418565787, 0.6126785776990856, 0.9545292891166974], 
             UndirectedEdge[197, 345] -> 
             RGBColor[
              0.6786754086563489, 0.7489056544572683, 0.9686076802187304], 
             UndirectedEdge[100, 213] -> 
             RGBColor[
              0.9177103751290299, 0.7114500107948662, 0.2526457256885956], 
             UndirectedEdge[73, 187] -> 
             RGBColor[
              0.25626928229983936`, 0.38668564248105813`, 0.9379055285593227],
              UndirectedEdge[97, 346] -> 
             RGBColor[
              0.22480858213955662`, 0.353618451889001, 0.9361138882271296], 
             UndirectedEdge[129, 170] -> 
             RGBColor[
              0.3261401713486173, 0.4557924254151241, 0.9420431862919051], 
             UndirectedEdge[36, 37] -> 
             RGBColor[
              0.2800147441029785, 0.41164362838539204`, 0.9392577974807488], 
             UndirectedEdge[143, 302] -> 
             RGBColor[
              0.1845381798446758, 0.31129170578610466`, 0.9338205483911577], 
             UndirectedEdge[16, 236] -> 
             RGBColor[
              0.34560261915581325`, 0.4717846628283363, 0.9433149938798411], 
             UndirectedEdge[187, 322] -> 
             RGBColor[
              0.2619233226556958, 0.392628397381927, 0.9382275177931856], 
             UndirectedEdge[108, 163] -> 
             RGBColor[
              0.27605150294224795`, 0.40747801064146116`, 0.939032096759735], 
             UndirectedEdge[137, 346] -> 
             RGBColor[
              0.21898159921391522`, 0.34749392338209584`, 0.9357820501697631],
              UndirectedEdge[243, 276] -> 
             RGBColor[
              0.7294231328480298, 0.5025695960181678, 0.5742322488928711], 
             UndirectedEdge[131, 147] -> 
             RGBColor[
              0.257551109678863, 0.38803292432896186`, 0.9379785267322645], 
             UndirectedEdge[9, 468] -> 
             RGBColor[
              0.5267603512092651, 0.6266868092518996, 0.9558876509153902], 
             UndirectedEdge[331, 377] -> 
             RGBColor[
              0.9088984029132244, 0.9290240327940705, 0.9505769466051841], 
             UndirectedEdge[280, 470] -> 
             RGBColor[
              0.25618724239569113`, 0.386599413340168, 0.9379008565081486], 
             UndirectedEdge[234, 468] -> 
             RGBColor[
              0.4334778335161593, 0.5491980337433716, 0.9490298017896481], 
             UndirectedEdge[136, 488] -> 
             RGBColor[
              0.8691624812525807, 0.8980619995445237, 0.9575361918373422], 
             UndirectedEdge[57, 361] -> 
             RGBColor[
              0.622722217665552, 0.7045647515271736, 0.9634614174292722], 
             UndirectedEdge[196, 414] -> 
             RGBColor[
              0.2851786513362504, 0.4170712222981897, 0.9395518743583675], 
             UndirectedEdge[103, 319] -> 
             RGBColor[
              0.5976226950866923, 0.6831049747415705, 0.9622258440138658], 
             UndirectedEdge[224, 263] -> 
             RGBColor[
              0.2861834719747001, 0.4181273524985085, 0.9396090974072282], 
             UndirectedEdge[89, 184] -> 
             RGBColor[
              0.271266794829508, 0.4024489790469554, 0.9387596147110557], 
             UndirectedEdge[137, 407] -> 
             RGBColor[
              0.2172194419002935, 0.34564178431825265`, 0.9356816979176306], 
             UndirectedEdge[53, 272] -> 
             RGBColor[
              0.8985476192245749, 0.5458238236085153, 0.2652993601444404], 
             UndirectedEdge[236, 243] -> 
             RGBColor[
              0.5633146331293595, 0.36122739545781846`, 0.562473440762307], 
             UndirectedEdge[26, 351] -> 
             RGBColor[
              0.3383374936256977, 0.4657436708748698, 0.9428428507321864], 
             UndirectedEdge[67, 96] -> 
             RGBColor[
              0.2763924027630132, 0.4078363179673825, 0.9390515105002115], 
             UndirectedEdge[284, 464] -> 
             RGBColor[
              0.24447969866104266`, 0.37429404257390636`, 0.9372341292122193],
              UndirectedEdge[325, 401] -> 
             RGBColor[
              0.4762346490241563, 0.5642173274993956, 0.9557801417908952], 
             UndirectedEdge[227, 348] -> 
             RGBColor[
              0.9027713884189711, 0.6140906553673846, 0.24504718315702606`], 
             UndirectedEdge[106, 117] -> 
             RGBColor[
              0.44946530583261596`, 0.561973649912251, 0.9503446865091629], 
             UndirectedEdge[395, 440] -> 
             RGBColor[
              0.2733307058970075, 0.4046182804384171, 0.9388771513930672], 
             UndirectedEdge[204, 361] -> 
             RGBColor[
              0.5730472494558454, 0.6642363745027182, 0.9595508219663998], 
             UndirectedEdge[195, 263] -> 
             RGBColor[
              0.27177628853634817`, 0.40298448923661123`, 0.9387886296239321],
              UndirectedEdge[360, 393] -> 
             RGBColor[
              0.5202889035975207, 0.6214329965452928, 0.9553781948537], 
             UndirectedEdge[74, 440] -> 
             RGBColor[
              0.2817039259800564, 0.4134190656385177, 0.9393539938897277], 
             UndirectedEdge[166, 348] -> 
             RGBColor[
              0.8990160108059699, 0.5852251774168952, 0.24145102931372386`], 
             UndirectedEdge[209, 477] -> 
             RGBColor[
              0.40529759982577535`, 0.5164885241169046, 0.9481078912022864], 
             UndirectedEdge[292, 422] -> 
             RGBColor[
              0.20649131825242792`, 0.3343658461620201, 0.9350707471467212], 
             UndirectedEdge[36, 416] -> 
             RGBColor[
              0.2579614870777197, 0.3884642569945902, 0.9380018971180304], 
             UndirectedEdge[306, 418] -> 
             RGBColor[
              0.9180265023958543, 0.7135265493813059, 0.5620472292012149], 
             UndirectedEdge[363, 498] -> 
             RGBColor[
              0.433350434496959, 0.5495353617267253, 0.948897990208064], 
             UndirectedEdge[57, 466] -> 
             RGBColor[
              0.552375580457491, 0.6474824063085367, 0.957904175593487], 
             UndirectedEdge[263, 395] -> 
             RGBColor[
              0.2691941123375187, 0.40027045833221453`, 0.938641578509396], 
             UndirectedEdge[171, 238] -> 
             RGBColor[
              0.2909480728266918, 0.4220805098947036, 0.9399190535823698], 
             UndirectedEdge[42, 286] -> 
             RGBColor[
              0.2277872668823118, 0.3567492384131574, 0.9362835199166604], 
             UndirectedEdge[246, 444] -> 
             RGBColor[
              0.2827572278979614, 0.41452615273743476`, 0.9394139778757318], 
             UndirectedEdge[46, 306] -> 
             RGBColor[
              0.8876171805650555, 0.5774114462757728, 0.22768643734119767`], 
             UndirectedEdge[229, 411] -> 
             RGBColor[
              0.26528288174741516`, 0.39615950699567326`, 0.9384188397134368],
              UndirectedEdge[239, 440] -> 
             RGBColor[
              0.3163021777955242, 0.4458837751629835, 0.9414671202878849], 
             UndirectedEdge[57, 106] -> 
             RGBColor[
              0.5595491629932491, 0.6533062437772754, 0.9584689062884005], 
             UndirectedEdge[60, 280] -> 
             RGBColor[
              0.2748009878347767, 0.4061636399762716, 0.9389608817743358], 
             UndirectedEdge[438, 457] -> 
             RGBColor[
              0.22152681415849518`, 0.35016910566479753`, 0.9359269963955489],
              UndirectedEdge[130, 368] -> 
             RGBColor[
              0.2935143249909316, 0.4166464351270609, 0.9403629270800464], 
             UndirectedEdge[152, 287] -> 
             RGBColor[
              0.20690732578417442`, 0.33480309645428663`, 0.9350944381602262],
              UndirectedEdge[54, 242] -> 
             RGBColor[
              0.22686421194138368`, 0.35577904914517844`, 0.936230953303312], 
             UndirectedEdge[89, 235] -> 
             RGBColor[
              0.32127172035398965`, 0.45054205661512126`, 0.9417708166396943],
              UndirectedEdge[60, 260] -> 
             RGBColor[
              0.2891430137819674, 0.4212380185837349, 0.9397776389349024], 
             UndirectedEdge[88, 243] -> 
             RGBColor[
              0.8529581179820884, 0.3951595604413297, 0.19784071975882145`], 
             UndirectedEdge[36, 367] -> 
             RGBColor[
              0.2421171751521342, 0.3718108805734015, 0.9370995869934273], 
             UndirectedEdge[17, 282] -> 
             RGBColor[
              0.7438148228852721, 0.7997463454963281, 0.9753349394405884], 
             UndirectedEdge[150, 233] -> 
             RGBColor[
              0.832302226448087, 0.24929464417169217`, 0.1785659545678221], 
             UndirectedEdge[250, 365] -> 
             RGBColor[
              0.21070999979849359`, 0.338799947946794, 0.9353109948197895], 
             UndirectedEdge[107, 423] -> 
             RGBColor[
              0.18624879198055028`, 0.31308966759998247`, 0.9339179652216718],
              UndirectedEdge[315, 347] -> 
             RGBColor[
              0.1822133081343763, 0.30884811821319974`, 0.9336881503865955], 
             UndirectedEdge[288, 492] -> 
             RGBColor[
              0.26634261157442907`, 0.39727335023461663`, 0.9384791897593554],
              UndirectedEdge[24, 267] -> 
             RGBColor[
              0.9130173103236416, 0.9238052630986108, 0.6981615264074577], 
             UndirectedEdge[198, 480] -> 
             RGBColor[
              0.3177133386514768, 0.44712506118461215`, 0.9415563421819749], 
             UndirectedEdge[4, 479] -> 
             RGBColor[
              0.3678971603336924, 0.49307576205728143`, 0.9446630596311456], 
             UndirectedEdge[133, 239] -> 
             RGBColor[
              0.34805209112246643`, 0.47588696054869806`, 0.943398549369312], 
             UndirectedEdge[115, 253] -> 
             RGBColor[
              0.9531001134456565, 0.9640284881713892, 0.9450338107840079], 
             UndirectedEdge[199, 371] -> 
             RGBColor[
              0.3528938984406201, 0.480080690691371, 0.9437070650501826], 
             UndirectedEdge[93, 189] -> 
             RGBColor[
              0.26453032177670965`, 0.3953685187514038, 0.9383759825364177], 
             UndirectedEdge[357, 418] -> 
             RGBColor[
              0.9428078871600445, 0.8265116366232681, 0.582732825135219], 
             UndirectedEdge[82, 463] -> 
             RGBColor[
              0.26268799213192734`, 0.3934321134842913, 0.9382710645886299], 
             UndirectedEdge[102, 350] -> 
             RGBColor[
              0.3193537748201921, 0.44805203074969097`, 0.941678953195245], 
             UndirectedEdge[235, 296] -> 
             RGBColor[
              0.3352307721420522, 0.4647817784660925, 0.9425815862613272], 
             UndirectedEdge[26, 360] -> 
             RGBColor[
              0.48299792974153133`, 0.5893477559050426, 0.9529428278924086], 
             UndirectedEdge[309, 320] -> 
             RGBColor[
              0.9908166313021023, 0.9885283450055495, 0.6606847997028811], 
             UndirectedEdge[13, 229] -> 
             RGBColor[
              0.2937960299949141, 0.4261286336418093, 0.9400426213247091], 
             UndirectedEdge[353, 420] -> 
             RGBColor[
              0.8041526849608935, 0.8472401733654197, 0.9513697071701304], 
             UndirectedEdge[171, 465] -> 
             RGBColor[
              0.27218390368581785`, 0.4034129186029971, 0.9388118427036817], 
             UndirectedEdge[104, 224] -> 
             RGBColor[
              0.2727699797429894, 0.40402892169845256`, 0.9388452188681158], 
             UndirectedEdge[22, 285] -> 
             RGBColor[
              0.38291743430858444`, 0.506085568433412, 0.9456201382069189], 
             UndirectedEdge[126, 285] -> 
             RGBColor[
              0.28277807837083513`, 0.4140236211798849, 0.9394343678430408], 
             UndirectedEdge[98, 319] -> 
             RGBColor[
              0.8550622111994015, 0.8847062165139711, 0.8474629923061501], 
             UndirectedEdge[286, 411] -> 
             RGBColor[
              0.2313451146629863, 0.3604887620112245, 0.9364861340844057], 
             UndirectedEdge[259, 491] -> 
             RGBColor[
              0.9280010655847133, 0.727726462964249, 0.4061574584267472], 
             UndirectedEdge[1, 266] -> 
             RGBColor[
              0.27784311638010406`, 0.40936110995950087`, 0.9391341264945663],
              UndirectedEdge[67, 216] -> 
             RGBColor[
              0.26125452628926693`, 0.3919254499966715, 0.938189430829513], 
             UndirectedEdge[41, 451] -> 
             RGBColor[
              0.22198624668627384`, 0.3506519983811976, 0.9359531603983363], 
             UndirectedEdge[300, 456] -> 
             RGBColor[
              0.22480808787876505`, 0.3536179323895711, 0.9361138600797088], 
             UndirectedEdge[117, 139] -> 
             RGBColor[
              0.47255522666265165`, 0.5807190878311534, 0.9521624096580703], 
             UndirectedEdge[70, 96] -> 
             RGBColor[
              0.2772059489257, 0.4086914065661722, 0.9390978407506428], 
             UndirectedEdge[92, 274] -> 
             RGBColor[
              0.5359359247795917, 0.6341359532311694, 0.9566099856780799], 
             UndirectedEdge[241, 436] -> 
             RGBColor[
              0.5892009770363313, 0.6764119562142918, 0.9614643256448061], 
             UndirectedEdge[207, 295] -> 
             RGBColor[
              0.22332543873759936`, 0.352059574136821, 0.9360294254045023], 
             UndirectedEdge[83, 176] -> 
             RGBColor[
              0.7638451540938651, 0.8157128228854424, 0.9772513951417543], 
             UndirectedEdge[56, 495] -> 
             RGBColor[
              0.839438039950976, 0.30414363368831143`, 0.18539921763693712`], 
             UndirectedEdge[219, 334] -> 
             RGBColor[
              0.4645364889888964, 0.5747991033502236, 0.9513681298117886], 
             UndirectedEdge[124, 357] -> 
             RGBColor[
              0.9348974167088442, 0.7776187751730486, 0.27677767167712564`], 
             UndirectedEdge[40, 291] -> 
             RGBColor[
              0.5205636488996574, 0.6196411124817705, 0.9560349926032045], 
             UndirectedEdge[7, 487] -> 
             RGBColor[
              0.7090567422484308, 0.7718269420846646, 0.9722547745917934], 
             UndirectedEdge[423, 477] -> 
             RGBColor[
              0.21624875945532895`, 0.3446215355237733, 0.9356264189883857], 
             UndirectedEdge[22, 165] -> 
             RGBColor[
              0.4377248912958056, 0.5535570329728583, 0.9491124209018134], 
             UndirectedEdge[302, 368] -> 
             RGBColor[
              0.2991255041617159, 0.42254414020486286`, 0.9406824754328269], 
             UndirectedEdge[297, 419] -> 
             RGBColor[
              0.5160273723962365, 0.6179732935362974, 0.9550427115070317], 
             UndirectedEdge[263, 463] -> 
             RGBColor[
              0.2702490064672201, 0.4013792189466815, 0.9387016531695065], 
             UndirectedEdge[260, 424] -> 
             RGBColor[
              0.3030854306847971, 0.434796914253921, 0.9406117494194473], 
             UndirectedEdge[193, 415] -> 
             RGBColor[
              0.28741220208324925`, 0.41941882574858214`, 0.9396790717691668],
              UndirectedEdge[434, 474] -> 
             RGBColor[
              0.992149866333044, 0.99102178223655, 0.7797605605635565], 
             UndirectedEdge[102, 109] -> 
             RGBColor[
              0.265248780611274, 0.396123664539452, 0.9384168977041816], 
             UndirectedEdge[58, 118] -> 
             RGBColor[
              0.3201099243225116, 0.4516848600807156, 0.9416180992091068], 
             UndirectedEdge[39, 100] -> 
             RGBColor[
              0.7774382200691679, 0.7351762203070193, 0.6135140654406412], 
             UndirectedEdge[35, 216] -> 
             RGBColor[
              0.25212920477180323`, 0.3823341585030158, 0.9376697572687969], 
             UndirectedEdge[72, 163] -> 
             RGBColor[
              0.26048838412385666`, 0.3911201860046064, 0.9381458001665987], 
             UndirectedEdge[202, 414] -> 
             RGBColor[
              0.25685751416132785`, 0.38730391146353665`, 0.9379390274936235],
              UndirectedEdge[324, 441] -> 
             RGBColor[
              0.4099049258998564, 0.5294607772190044, 0.947339757307013], 
             UndirectedEdge[18, 52] -> 
             RGBColor[
              0.8600894824934477, 0.42201909265360843`, 0.20357506457964797`],
              UndirectedEdge[168, 368] -> 
             RGBColor[
              0.6594469349895435, 0.6059633899066202, 0.5971521921376893], 
             UndirectedEdge[208, 397] -> 
             RGBColor[
              0.3403332891441403, 0.46920132223333977`, 0.9429067141327215], 
             UndirectedEdge[193, 350] -> 
             RGBColor[
              0.3249908553866274, 0.4539769598365655, 0.94199997659419], 
             UndirectedEdge[2, 365] -> 
             RGBColor[
              0.21471117528305686`, 0.3430054370702481, 0.9355388558444269], 
             UndirectedEdge[42, 248] -> 
             RGBColor[
              0.2375069627028864, 0.3669652549848901, 0.9368370422146407], 
             UndirectedEdge[46, 68] -> 
             RGBColor[
              0.8688206529626022, 0.4329330984324026, 0.20968686128144703`], 
             UndirectedEdge[260, 470] -> 
             RGBColor[
              0.2705292683428818, 0.4016737919476313, 0.9387176136687151], 
             UndirectedEdge[32, 344] -> 
             RGBColor[
              0.49972685632516956`, 0.6047398002599247, 0.9537594751711596], 
             UndirectedEdge[60, 483] -> 
             RGBColor[
              0.29467938491288026`, 0.4270570956685284, 0.9400929270804808], 
             UndirectedEdge[337, 498] -> 
             RGBColor[
              0.6610501058244442, 0.7326972089760198, 0.9686548196773171], 
             UndirectedEdge[86, 168] -> 
             RGBColor[
              0.912992655814064, 0.6927519043211215, 0.24885005242438252`], 
             UndirectedEdge[151, 424] -> 
             RGBColor[
              0.31369437792555, 0.4459475904500576, 0.9412159132702771], 
             UndirectedEdge[234, 296] -> 
             RGBColor[
              0.3509992318996893, 0.478439625762326, 0.9435863385735823], 
             UndirectedEdge[223, 268] -> 
             RGBColor[
              0.3997592820050565, 0.5206731304122181, 0.946693285849477], 
             UndirectedEdge[50, 204] -> 
             RGBColor[
              0.47141553909134676`, 0.5814192522224795, 0.9516235825177704], 
             UndirectedEdge[26, 247] -> 
             RGBColor[
              0.44082045923577545`, 0.5551061852750767, 0.9496224629130303], 
             UndirectedEdge[64, 435] -> 
             RGBColor[
              0.2729760661843835, 0.4042455316149929, 0.9388569551860756], 
             UndirectedEdge[143, 214] -> 
             RGBColor[
              0.18936705810043614`, 0.31636716300147366`, 0.934095545864138], 
             UndirectedEdge[38, 266] -> 
             RGBColor[
              0.27474470932625494`, 0.40610448769555174`, 0.9389576767965321],
              UndirectedEdge[309, 375] -> 
             RGBColor[
              0.9756161016685031, 0.977924558793291, 0.7192291003603996], 
             UndirectedEdge[70, 385] -> 
             RGBColor[
              0.24586087527331454`, 0.37574574676505923`, 0.9373127851770204],
              UndirectedEdge[232, 354] -> 
             RGBColor[
              0.35898073503518557`, 0.48535280261628094`, 0.94409491289561], 
             UndirectedEdge[86, 484] -> 
             RGBColor[
              0.9540423951293819, 0.8443401430723285, 0.3591520108030784], 
             UndirectedEdge[106, 360] -> 
             RGBColor[
              0.5486108303756021, 0.6444260125920007, 0.9576078006763067], 
             UndirectedEdge[163, 322] -> 
             RGBColor[
              0.26310542995763675`, 0.3938708671061988, 0.9382948370552601], 
             UndirectedEdge[44, 117] -> 
             RGBColor[
              0.4388762614701655, 0.5533769866678013, 0.9495110781480034], 
             UndirectedEdge[113, 273] -> 
             RGBColor[
              0.23636683819300525`, 0.3657669118369359, 0.936772113810466], 
             UndirectedEdge[53, 298] -> 
             RGBColor[
              0.9390760601522875, 0.9284198827471832, 0.6768677898959217], 
             UndirectedEdge[50, 369] -> 
             RGBColor[
              0.43044272533776096`, 0.5472495868323034, 0.9486484077263333], 
             UndirectedEdge[135, 385] -> 
             RGBColor[
              0.24204917775156742`, 0.37173941099412156`, 0.9370957146420581],
              UndirectedEdge[376, 464] -> 
             RGBColor[
              0.2616609318454717, 0.3923526080038432, 0.9382125750247157], 
             UndirectedEdge[95, 408] -> 
             RGBColor[
              0.22479372667970515`, 0.35360283785880653`, 0.9361130422306678],
              UndirectedEdge[34, 332] -> 
             RGBColor[
              0.47297256082386624`, 0.5816312685861409, 0.9520368398699108], 
             UndirectedEdge[251, 416] -> 
             RGBColor[
              0.26003944376158217`, 0.39064832121939286`, 0.9381202336771148],
              UndirectedEdge[62, 209] -> 
             RGBColor[
              0.6916212861064526, 0.39630413817282756`, 0.5615943615662011], 
             UndirectedEdge[109, 496] -> 
             RGBColor[
              0.26542477376877, 0.3963086445065909, 0.9384269202541424], 
             UndirectedEdge[179, 254] -> 
             RGBColor[
              0.20771369325605188`, 0.33565063979388043`, 0.9351403595948358],
              UndirectedEdge[27, 199] -> 
             RGBColor[
              0.4274813973658525, 0.5430880506381621, 0.9489008550961784], 
             UndirectedEdge[59, 453] -> 
             RGBColor[
              0.26324896867774317`, 0.3940217354019111, 0.9383030113730237], 
             UndirectedEdge[450, 475] -> 
             RGBColor[
              0.8283559372455574, 0.2189617360860943, 0.17478698357078354`], 
             UndirectedEdge[311, 331] -> 
             RGBColor[
              0.7917742816822333, 0.837394395727864, 0.9798444828971542], 
             UndirectedEdge[329, 486] -> 
             RGBColor[
              0.9087427412464592, 0.930070810978078, 0.9911578879759511], 
             UndirectedEdge[287, 456] -> 
             RGBColor[
              0.21673512234064032`, 0.34513273375342357`, 0.9356541166351948],
              UndirectedEdge[60, 118] -> 
             RGBColor[
              0.30890885152103453`, 0.4405003788871604, 0.9409586647466246], 
             UndirectedEdge[267, 493] -> 
             RGBColor[
              0.991319933690298, 0.9817192401312839, 0.4771566948770857], 
             UndirectedEdge[239, 263] -> 
             RGBColor[
              0.31216558423603546`, 0.4415359530567809, 0.9412315474042139], 
             UndirectedEdge[64, 91] -> 
             RGBColor[
              0.3077316474117898, 0.43903000298271255`, 0.9409001581731142], 
             UndirectedEdge[469, 471] -> 
             RGBColor[
              0.8586216305057723, 0.4484110579890054, 0.20364468753654688`], 
             UndirectedEdge[275, 282] -> 
             RGBColor[
              0.5106811757652547, 0.612557396257451, 0.9549190346803453], 
             UndirectedEdge[132, 423] -> 
             RGBColor[
              0.5889794016641527, 0.6524675094432201, 0.8735972473293918], 
             UndirectedEdge[116, 412] -> 
             RGBColor[
              0.24555371763094103`, 0.3754229046080053, 0.9372952930036862], 
             UndirectedEdge[89, 453] -> 
             RGBColor[
              0.28490427469255214`, 0.4167828350491789, 0.9395362490144127], 
             UndirectedEdge[136, 311] -> 
             RGBColor[
              0.8579087651395905, 0.8892705109856455, 0.9564145265871555], 
             UndirectedEdge[6, 24] -> 
             RGBColor[
              0.8323309168683787, 0.869142096362715, 0.9838696599531287], 
             UndirectedEdge[51, 477] -> 
             RGBColor[
              0.21179931412463662`, 0.3399448863700877, 0.9353730296591674], 
             UndirectedEdge[114, 381] -> 
             RGBColor[
              0.5349916430046526, 0.6333693427468647, 0.9565356483577385], 
             UndirectedEdge[95, 294] -> 
             RGBColor[
              0.2326978312332123, 0.36191055289371626`, 0.9365631692919152], 
             UndirectedEdge[89, 192] -> 
             RGBColor[
              0.27005817816264466`, 0.4011786462993594, 0.9386907857798661], 
             UndirectedEdge[108, 374] -> 
             RGBColor[
              0.2684205085848909, 0.3994573517388918, 0.938597522920128], 
             UndirectedEdge[208, 472] -> 
             RGBColor[
              0.32528262084800263`, 0.45616518982380916`, 0.9419476988576752],
              UndirectedEdge[34, 360] -> 
             RGBColor[
              0.5615596954334325, 0.6549384845856707, 0.9586271827669148], 
             UndirectedEdge[395, 453] -> 
             RGBColor[
              0.2746472026730905, 0.406002002020797, 0.9389521239368825], 
             UndirectedEdge[101, 361] -> 
             RGBColor[
              0.5825170875925927, 0.671924415713476, 0.9602963223136847], 
             UndirectedEdge[11, 211] -> 
             RGBColor[
              0.23497926878004616`, 0.3643084884069338, 0.936693093785123], 
             UndirectedEdge[70, 433] -> 
             RGBColor[
              0.2918782074405654, 0.4225632807803333, 0.9399901426055144], 
             UndirectedEdge[108, 206] -> 
             RGBColor[
              0.31392242641055057`, 0.44414031495447526`, 0.9413038498533395],
              UndirectedEdge[251, 499] -> 
             RGBColor[
              0.25963192027097015`, 0.39021998819227793`, 0.9380970258172014],
              UndirectedEdge[116, 399] -> 
             RGBColor[
              0.24511345141386065`, 0.3749601568993634, 0.937270220493939], 
             UndirectedEdge[350, 479] -> 
             RGBColor[
              0.3868303332701487, 0.5094747248458988, 0.9458694646687091], 
             UndirectedEdge[347, 421] -> 
             RGBColor[
              0.17899180289058533`, 0.3054621119467458, 0.9335046904287516], 
             UndirectedEdge[153, 447] -> 
             RGBColor[
              0.24571645560416666`, 0.3755939525360489, 0.9373045606905122], 
             UndirectedEdge[195, 453] -> 
             RGBColor[
              0.27722937887191995`, 0.40871603292519376`, 0.9390991750514186],
              UndirectedEdge[338, 425] -> 
             RGBColor[
              0.3477240886796976, 0.47560286131865376`, 0.9433776493436998], 
             UndirectedEdge[164, 348] -> 
             RGBColor[
              0.8887181595032059, 0.5060713797566354, 0.23158979527643736`], 
             UndirectedEdge[31, 258] -> 
             RGBColor[
              0.4132303526475083, 0.5323410947270124, 0.947551650558814], 
             UndirectedEdge[31, 203] -> 
             RGBColor[
              0.4938024492349883, 0.5999225041719667, 0.9532951828081889], 
             UndirectedEdge[398, 445] -> 
             RGBColor[
              0.2453951867466454, 0.3752562785971719, 0.9372862649043511], 
             UndirectedEdge[44, 369] -> 
             RGBColor[
              0.4583123366675063, 0.5702115381181944, 0.9507495276729314], 
             UndirectedEdge[267, 278] -> 
             RGBColor[
              0.9687131736129876, 0.9678890438697982, 0.6921508091390034], 
             UndirectedEdge[130, 477] -> 
             RGBColor[
              0.2117993137193227, 0.3399448859440771, 0.9353730296360853], 
             UndirectedEdge[4, 482] -> 
             RGBColor[
              0.3413925426988842, 0.4701187944228272, 0.9429742088325687], 
             UndirectedEdge[219, 274] -> 
             RGBColor[
              0.49450158018716717`, 0.6004976856950868, 0.9533481222927589], 
             UndirectedEdge[44, 269] -> 
             RGBColor[
              0.4728082951441619, 0.5827672087626157, 0.9516731973287911], 
             UndirectedEdge[130, 143] -> 
             RGBColor[
              0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772],
              UndirectedEdge[315, 401] -> 
             RGBColor[
              0.47947599697395743`, 0.5676241897079666, 0.9559647317614918], 
             UndirectedEdge[75, 163] -> 
             RGBColor[
              0.3059704107658049, 0.43557751025778224`, 0.9408584905702073], 
             UndirectedEdge[9, 139] -> 
             RGBColor[
              0.5695894293133013, 0.6614573842847371, 0.9592593128318224], 
             UndirectedEdge[134, 438] -> 
             RGBColor[
              0.22733547187831532`, 0.35627437321849936`, 0.9362577908595535],
              UndirectedEdge[76, 431] -> 
             RGBColor[
              0.42993261586454035`, 0.5468077556454473, 0.9486159040017718], 
             UndirectedEdge[90, 124] -> 
             RGBColor[
              0.9137111635376958, 0.6822566946723914, 0.2591427819494134], 
             UndirectedEdge[37, 188] -> 
             RGBColor[
              0.3214586719550145, 0.4525659249433619, 0.9417145542769817], 
             UndirectedEdge[26, 106] -> 
             RGBColor[
              0.45224243758080923`, 0.5643790618498358, 0.9505216428884367], 
             UndirectedEdge[107, 446] -> 
             RGBColor[
              0.2064114829025504, 0.3342819341474452, 0.9350662006416515], 
             UndirectedEdge[19, 234] -> 
             RGBColor[
              0.474151584993228, 0.582218817524079, 0.9522317884987839], 
             UndirectedEdge[39, 243] -> 
             RGBColor[
              0.7314838484501698, 0.504242577778165, 0.5743944759737214], 
             UndirectedEdge[129, 265] -> 
             RGBColor[
              0.3383071396578693, 0.46744637338556605`, 0.9427776096791101], 
             UndirectedEdge[396, 446] -> 
             RGBColor[
              0.6108486673250959, 0.6728679174892245, 0.7376055193707824], 
             UndirectedEdge[325, 368] -> 
             RGBColor[
              0.2935592851755068, 0.41669369113168975`, 0.9403654874960453], 
             UndirectedEdge[52, 56] -> 
             RGBColor[
              0.836234326611525, 0.27951848908515425`, 0.18233133812500216`], 
             UndirectedEdge[402, 431] -> 
             RGBColor[
              0.5004255816893457, 0.6051773211877334, 0.9538503277794443], 
             UndirectedEdge[165, 353] -> 
             RGBColor[
              0.531847897863051, 0.630021959343577, 0.9565078633928767], 
             UndirectedEdge[237, 329] -> 
             RGBColor[
              0.8943251384864865, 0.9185746058926771, 0.989782724153959], 
             UndirectedEdge[63, 75] -> 
             RGBColor[
              0.38214205273411095`, 0.5054139718854141, 0.9455707315786365], 
             UndirectedEdge[392, 492] -> 
             RGBColor[
              0.2913103527973019, 0.4235160293060819, 0.9399010656855349], 
             UndirectedEdge[125, 177] -> 
             RGBColor[
              0.20868507222126964`, 0.3366716206753079, 0.9351956781898786], 
             UndirectedEdge[210, 348] -> 
             RGBColor[
              0.8979876618717816, 0.5773208368833467, 0.24046628121299102`], 
             UndirectedEdge[469, 491] -> 
             RGBColor[
              0.9272960549745825, 0.7245251744430564, 0.40556918029226263`], 
             UndirectedEdge[35, 171] -> 
             RGBColor[
              0.25005732664065045`, 0.38015648322251344`, 0.9375517668742968],
              UndirectedEdge[8, 40] -> 
             RGBColor[
              0.5032468930597369, 0.6057751178648505, 0.9545401217837302], 
             UndirectedEdge[405, 491] -> 
             RGBColor[
              0.9940870576802556, 0.9897611392052678, 0.5977909028249961], 
             UndirectedEdge[98, 136] -> 
             RGBColor[
              0.9820976999154852, 0.9842937020241562, 0.8300672430323528], 
             UndirectedEdge[14, 75] -> 
             RGBColor[
              0.32584559541094904`, 0.45646758947931865`, 0.9419903529330476],
              UndirectedEdge[121, 500] -> 
             RGBColor[
              0.8234793018793516, 0.18147777970619255`, 0.1701171120367329], 
             UndirectedEdge[1, 265] -> 
             RGBColor[
              0.2935899974663011, 0.4247777732380918, 0.9400724206184119], 
             UndirectedEdge[227, 495] -> 
             RGBColor[
              0.8439168192516593, 0.3385694940069675, 0.1896881017533292], 
             UndirectedEdge[127, 368] -> 
             RGBColor[
              0.3170407306432145, 0.44137417912788274`, 0.9417027210777457], 
             UndirectedEdge[207, 389] -> 
             RGBColor[
              0.21778138864415675`, 0.3462324259755344, 0.9357136999533677], 
             UndirectedEdge[249, 260] -> 
             RGBColor[
              0.28756214905519606`, 0.4195764295232854, 0.9396876110273925], 
             UndirectedEdge[42, 95] -> 
             RGBColor[
              0.2297785943922997, 0.3588422498836111, 0.9363969230724491], 
             UndirectedEdge[190, 323] -> 
             RGBColor[
              0.243727142288008, 0.373503058111017, 0.9371912722400824], 
             UndirectedEdge[109, 295] -> 
             RGBColor[
              0.24177394363545715`, 0.37145012248723885`, 0.937080040466318], 
             UndirectedEdge[382, 499] -> 
             RGBColor[
              0.27147166687394786`, 0.40266431255529955`, 0.9387712818709056],
              UndirectedEdge[213, 254] -> 
             RGBColor[
              0.5703520735589939, 0.511904106319279, 0.5892794945919869], 
             UndirectedEdge[47, 374] -> 
             RGBColor[
              0.24183198733731956`, 0.37151113009807946`, 0.9370833459692711],
              UndirectedEdge[244, 390] -> 
             RGBColor[
              0.3215972480879268, 0.45223414091428343`, 0.9417399272656037], 
             UndirectedEdge[92, 370] -> 
             RGBColor[
              0.6002904630940367, 0.6863818665737486, 0.9616762106726342], 
             UndirectedEdge[295, 458] -> 
             RGBColor[
              0.2300435692999762, 0.35912075531195864`, 0.936412013001446], 
             UndirectedEdge[278, 493] -> 
             RGBColor[
              0.9709705008180975, 0.974840539169355, 0.7572967831573334], 
             UndirectedEdge[6, 156] -> 
             RGBColor[
              0.6474994925034097, 0.7219315348762902, 0.9673172118721224], 
             UndirectedEdge[79, 413] -> 
             RGBColor[
              0.9838323701759427, 0.9563067408191819, 0.46126511216987476`], 
             UndirectedEdge[122, 476] -> 
             RGBColor[
              0.8579983660337116, 0.432494720305006, 0.20261219607186334`], 
             UndirectedEdge[123, 455] -> 
             RGBColor[
              0.20545207796979598`, 0.3332735387333343, 0.9350115639500436], 
             UndirectedEdge[113, 302] -> 
             RGBColor[
              0.18467080951855291`, 0.3114311079825565, 0.9338281014548768], 
             UndirectedEdge[402, 462] -> 
             RGBColor[
              0.5080947993050582, 0.6115332733425336, 0.9544182302953215], 
             UndirectedEdge[140, 363] -> 
             RGBColor[
              0.4522227109181607, 0.5648567259118211, 0.9503836849393674], 
             UndirectedEdge[440, 453] -> 
             RGBColor[
              0.2829903357512072, 0.4147711638710876, 0.939427253023122], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.5464995084832656, 0.6427119463658346, 0.9574415896829152], 
             UndirectedEdge[102, 202] -> 
             RGBColor[
              0.2577973086293919, 0.3882916950358828, 0.9379925473982783], 
             UndirectedEdge[363, 379] -> 
             RGBColor[
              0.35705527838116624`, 0.4836850688388347, 0.9439722245002304], 
             UndirectedEdge[162, 297] -> 
             RGBColor[
              0.4906978130641887, 0.5974096161868968, 0.9530486758111798], 
             UndirectedEdge[19, 393] -> 
             RGBColor[
              0.5104680056398668, 0.6134599491568583, 0.954605057791339], 
             UndirectedEdge[96, 238] -> 
             RGBColor[
              0.3081578274315908, 0.4401690531459169, 0.9408991236475683], 
             UndirectedEdge[117, 247] -> 
             RGBColor[
              0.4380433274875822, 0.5527007733374919, 0.9494455065337566], 
             UndirectedEdge[162, 223] -> 
             RGBColor[
              0.4259476007932227, 0.5431195461878823, 0.9484273528030159], 
             UndirectedEdge[355, 362] -> 
             RGBColor[
              0.3585841716726791, 0.48500931936353203`, 0.9440696442288183], 
             UndirectedEdge[59, 395] -> 
             RGBColor[
              0.2535893388235434, 0.38386885196924064`, 0.9377529097429688], 
             UndirectedEdge[161, 403] -> 
             RGBColor[
              0.9596219668575938, 0.962601388451382, 0.7050117798938269], 
             UndirectedEdge[214, 477] -> 
             RGBColor[
              0.2222393711458674, 0.35091804823724815`, 0.9359675754618462], 
             UndirectedEdge[65, 309] -> 
             RGBColor[
              0.9892477963467572, 0.9750667140916796, 0.4404269945442838], 
             UndirectedEdge[361, 498] -> 
             RGBColor[
              0.5530454795335582, 0.6479980366103388, 0.95797620936922], 
             UndirectedEdge[54, 70] -> 
             RGBColor[
              0.24348548029858347`, 0.3732490560378767, 0.9371775099472914], 
             UndirectedEdge[369, 390] -> 
             RGBColor[
              0.36035044557586515`, 0.48580021278599533`, 0.9442092467414281],
              UndirectedEdge[56, 88] -> 
             RGBColor[
              0.8516418675680354, 0.38504228297430826`, 0.19658027687583196`],
              UndirectedEdge[289, 419] -> 
             RGBColor[
              0.4760307938821983, 0.5851235769437257, 0.9519986681530803], 
             UndirectedEdge[124, 178] -> 
             RGBColor[
              0.977168593002762, 0.938254909924025, 0.5484416326473938], 
             UndirectedEdge[67, 465] -> 
             RGBColor[
              0.26962432665641767`, 0.4007226408585406, 0.9386660785784122], 
             UndirectedEdge[7, 461] -> 
             RGBColor[
              0.8915688064008891, 0.9161509753336762, 0.9816909809846657], 
             UndirectedEdge[273, 423] -> 
             RGBColor[
              0.24068365358124288`, 0.3703041585118776, 0.9370179500606701], 
             UndirectedEdge[63, 467] -> 
             RGBColor[
              0.563087381667329, 0.6542682731705118, 0.9596777258955458], 
             UndirectedEdge[179, 368] -> 
             RGBColor[
              0.2935153935219346, 0.41664755822089383`, 0.9403629879313062], 
             UndirectedEdge[211, 485] -> 
             RGBColor[
              0.23952079823930758`, 0.3690819238182165, 0.9369517271692371], 
             UndirectedEdge[21, 320] -> 
             RGBColor[
              0.9847451317139568, 0.9683734708666063, 0.6094013242659239], 
             UndirectedEdge[318, 479] -> 
             RGBColor[
              0.3767164983407358, 0.5007146293661655, 0.94522502005032], 
             UndirectedEdge[343, 465] -> 
             RGBColor[
              0.2877565452274621, 0.4197807522257663, 0.9396986816018197], 
             UndirectedEdge[229, 313] -> 
             RGBColor[
              0.2789668469500533, 0.41054222203715074`, 0.9391981212881146], 
             UndirectedEdge[168, 401] -> 
             RGBColor[
              0.842122298838193, 0.7534870262743261, 0.6125668464325392], 
             UndirectedEdge[70, 216] -> 
             RGBColor[
              0.26206807245195374`, 0.39278053859546125`, 0.9382357610799443],
              UndirectedEdge[5, 193] -> 
             RGBColor[
              0.263209529621381, 0.3939802824530939, 0.9383007653771087], 
             UndirectedEdge[213, 471] -> 
             RGBColor[
              0.8805092403498851, 0.5477975823099646, 0.2219082457048863], 
             UndirectedEdge[145, 404] -> 
             RGBColor[
              0.2170532372191201, 0.345467092660354, 0.9356722328069155], 
             UndirectedEdge[28, 173] -> 
             RGBColor[
              0.9747095150977819, 0.9805973489982415, 0.9249344880863324], 
             UndirectedEdge[210, 243] -> 
             RGBColor[
              0.8376849116916145, 0.29066832166115775`, 0.18372042003589745`],
              UndirectedEdge[133, 424] -> 
             RGBColor[
              0.33288404882225986`, 0.46274916467623195`, 0.942432055126516], 
             UndirectedEdge[201, 400] -> 
             RGBColor[
              0.30019030163233085`, 0.432849418552972, 0.9404067656349827], 
             UndirectedEdge[120, 125] -> 
             RGBColor[
              0.2080475453125366, 0.33600153947268885`, 0.9351593719755629], 
             UndirectedEdge[96, 343] -> 
             RGBColor[
              0.29452462133405766`, 0.4268944293346082, 0.940084113523619], 
             UndirectedEdge[22, 149] -> 
             RGBColor[
              0.40264564991743174`, 0.5231731572248479, 0.9468772026605385], 
             UndirectedEdge[140, 369] -> 
             RGBColor[
              0.4597907440975337, 0.5714117758713864, 0.950865913321408], 
             UndirectedEdge[169, 370] -> 
             RGBColor[
              0.5420927609464797, 0.6391343501937576, 0.9570946743743712], 
             UndirectedEdge[154, 380] -> 
             RGBColor[
              0.2911961325222311, 0.423322454553487, 0.9398972530104752], 
             UndirectedEdge[33, 489] -> 
             RGBColor[
              0.9342559232885688, 0.7654812281083937, 0.517015114696979], 
             UndirectedEdge[271, 284] -> 
             RGBColor[
              0.2504489768010796, 0.3805681323731789, 0.9375740707715388], 
             UndirectedEdge[112, 356] -> 
             RGBColor[
              0.2588007282426925, 0.3893463526699398, 0.9380496906608295], 
             UndirectedEdge[133, 155] -> 
             RGBColor[
              0.4555313931992919, 0.5659235600860384, 0.9510915748153721], 
             UndirectedEdge[82, 447] -> 
             RGBColor[
              0.25238928516537673`, 0.3826075194867109, 0.9376845684624564], 
             UndirectedEdge[225, 260] -> 
             RGBColor[
              0.27991286113099906`, 0.41153654292208813`, 0.9392519953962168],
              UndirectedEdge[133, 225] -> 
             RGBColor[
              0.3097114792684619, 0.4394887933443991, 0.9410723011032855], 
             UndirectedEdge[442, 444] -> 
             RGBColor[
              0.27761918641957545`, 0.4091257453730057, 0.939121374014589], 
             UndirectedEdge[49, 431] -> 
             RGBColor[
              0.4693773227785792, 0.5799709458958486, 0.9514060951044689], 
             UndirectedEdge[220, 427] -> 
             RGBColor[
              0.30920666661498386`, 0.43953702554153684`, 0.9410223592495326],
              UndirectedEdge[151, 192] -> 
             RGBColor[
              0.28070448165153206`, 0.4123685862808082, 0.9392970770137636], 
             UndirectedEdge[167, 326] -> 
             RGBColor[
              0.9309228830343801, 0.7574193985269815, 0.5440638154599668], 
             UndirectedEdge[109, 196] -> 
             RGBColor[
              0.27482966958615396`, 0.4061937863154972, 0.938962515157646], 
             UndirectedEdge[212, 451] -> 
             RGBColor[
              0.21498103480107186`, 0.34328907653376356`, 0.9355542239447563],
              UndirectedEdge[186, 414] -> 
             RGBColor[
              0.255184189019674, 0.3855451406447167, 0.937843734102269], 
             UndirectedEdge[349, 419] -> 
             RGBColor[
              0.4631460027688009, 0.5739634184897324, 0.951177660656908], 
             UndirectedEdge[162, 221] -> 
             RGBColor[
              0.4993207487803075, 0.6044101038600693, 0.953727504897607], 
             UndirectedEdge[163, 364] -> 
             RGBColor[
              0.2627794929075267, 0.39352828660093053`, 0.938276275422437], 
             UndirectedEdge[191, 300] -> 
             RGBColor[
              0.22217951414553483`, 0.3508551347347456, 0.9359641666942277], 
             UndirectedEdge[438, 460] -> 
             RGBColor[
              0.23490540515407732`, 0.3642308530528161, 0.9366888873608955], 
             UndirectedEdge[172, 473] -> 
             RGBColor[
              0.3392418574009336, 0.4682559789143286, 0.9428371690671595], 
             UndirectedEdge[141, 188] -> 
             RGBColor[
              0.32343001274534444`, 0.45456055380007726`, 0.9418296523075707],
              UndirectedEdge[79, 122] -> 
             RGBColor[
              0.9306665098261713, 0.7402291937878942, 0.3904132893585251], 
             UndirectedEdge[326, 475] -> 
             RGBColor[
              0.8570894511774583, 0.4134428533627656, 0.20126936153652183`], 
             UndirectedEdge[98, 124] -> 
             RGBColor[
              0.9789436438067185, 0.93894816660261, 0.5160607207640602], 
             UndirectedEdge[204, 498] -> 
             RGBColor[
              0.4818912814299178, 0.5902600770764668, 0.9523553933815417], 
             UndirectedEdge[72, 144] -> 
             RGBColor[
              0.2501061102631632, 0.3802077579028347, 0.93755454502943], 
             UndirectedEdge[98, 331] -> 
             RGBColor[
              0.9159632164581281, 0.9324175867663749, 0.8534971993423514], 
             UndirectedEdge[311, 377] -> 
             RGBColor[
              0.8639809895032101, 0.8937991659736781, 0.9461358346293043], 
             UndirectedEdge[299, 389] -> 
             RGBColor[
              0.213833079654714, 0.34208250289038133`, 0.9354888495974187], 
             UndirectedEdge[131, 238] -> 
             RGBColor[
              0.29188148517230905`, 0.42306158545170824`, 0.9399722100345929],
              UndirectedEdge[4, 185] -> 
             RGBColor[
              0.30412419819916303`, 0.4355457825101565, 0.9406834624888651], 
             UndirectedEdge[162, 258] -> 
             RGBColor[
              0.4177269296537439, 0.5359992140298111, 0.9479035389072623], 
             UndirectedEdge[124, 253] -> 
             RGBColor[
              0.9738421982948224, 0.9368793602278473, 0.603568601391508], 
             UndirectedEdge[319, 449] -> 
             RGBColor[
              0.7215962304048408, 0.7824357266175173, 0.9728856266127364], 
             UndirectedEdge[256, 271] -> 
             RGBColor[
              0.2725957288123946, 0.4038457729222503, 0.9388352955353996], 
             UndirectedEdge[379, 478] -> 
             RGBColor[
              0.2876705710791334, 0.41963924089195836`, 0.9396956582454141], 
             UndirectedEdge[349, 371] -> 
             RGBColor[
              0.3882726943942144, 0.5107240255563866, 0.9459613706441047], 
             UndirectedEdge[130, 325] -> 
             RGBColor[
              0.1789719601845752, 0.3054412560046289, 0.9335035604159989], 
             UndirectedEdge[269, 369] -> 
             RGBColor[
              0.43444338232168905`, 0.5507147548329152, 0.948903326051707], 
             UndirectedEdge[43, 355] -> 
             RGBColor[
              0.3109273076150301, 0.4422891800076947, 0.941085795498422], 
             UndirectedEdge[11, 414] -> 
             RGBColor[
              0.25678804986481485`, 0.38723090008361066`, 0.9379350716047002],
              UndirectedEdge[117, 255] -> 
             RGBColor[
              0.38933039965095584`, 0.511640156687964, 0.9460287666877722], 
             UndirectedEdge[401, 475] -> 
             RGBColor[
              0.806227884360017, 0.5618744373452094, 0.5815185800497742], 
             UndirectedEdge[58, 141] -> 
             RGBColor[
              0.3123473120692484, 0.44496127550717535`, 0.9411234724205373], 
             UndirectedEdge[96, 180] -> 
             RGBColor[
              0.2831463385898367, 0.4149351327456384, 0.9394361371539964], 
             UndirectedEdge[119, 375] -> 
             RGBColor[
              0.9744244063754681, 0.9793738724475776, 0.8801494909995853], 
             UndirectedEdge[220, 382] -> 
             RGBColor[
              0.3105689508267532, 0.4409688726219141, 0.9410999393200739], 
             UndirectedEdge[104, 356] -> 
             RGBColor[
              0.2579557991377684, 0.3884582786090651, 0.9380015731982647], 
             UndirectedEdge[225, 440] -> 
             RGBColor[
              0.27796156594151966`, 0.4094856079586846, 0.9391408720218586], 
             UndirectedEdge[259, 341] -> 
             RGBColor[
              0.9277070351691528, 0.7270975616364004, 0.37415406223837167`], 
             UndirectedEdge[290, 362] -> 
             RGBColor[
              0.3374733904051481, 0.4646660623491092, 0.9427998432095333], 
             UndirectedEdge[79, 267] -> 
             RGBColor[
              0.9914456607402118, 0.9819881575780944, 0.49084130836277423`], 
             UndirectedEdge[90, 317] -> 
             RGBColor[
              0.8740850504741097, 0.5211314470341011, 0.21664581846880504`], 
             UndirectedEdge[41, 389] -> 
             RGBColor[
              0.2255132290582107, 0.3543590804777015, 0.9361540168267153], 
             UndirectedEdge[5, 300] -> 
             RGBColor[
              0.23228249418787045`, 0.3614740073251723, 0.936539516461619], 
             UndirectedEdge[290, 340] -> 
             RGBColor[
              0.31195990105564253`, 0.44256756021982796`, 0.9411741462288754],
              UndirectedEdge[288, 392] -> 
             RGBColor[
              0.281033651223698, 0.41271456437171095`, 0.9393158227339358], 
             UndirectedEdge[45, 292] -> 
             RGBColor[
              0.23087655194201073`, 0.35999627288288677`, 0.9364594501306225],
              UndirectedEdge[42, 145] -> 
             RGBColor[
              0.22656621784669417`, 0.3554658384577429, 0.9362139829804621], 
             UndirectedEdge[100, 368] -> 
             RGBColor[
              0.6696582512860165, 0.6464478563026956, 0.6053684569202311], 
             UndirectedEdge[302, 315] -> 
             RGBColor[
              0.18782448730516063`, 0.31474582329100176`, 0.934007698739376], 
             UndirectedEdge[255, 338] -> 
             RGBColor[
              0.35884542683277726`, 0.48523560545214284`, 0.9440862911766009],
              UndirectedEdge[59, 263] -> 
             RGBColor[
              0.25779587834217144`, 0.38829019171332857`, 0.9379924659455371],
              UndirectedEdge[413, 486] -> 
             RGBColor[
              0.9543818118224241, 0.9371774082640264, 0.6732568757445232], 
             UndirectedEdge[140, 247] -> 
             RGBColor[
              0.4973227229374232, 0.6027880164707773, 0.9535702129842454], 
             UndirectedEdge[82, 453] -> 
             RGBColor[
              0.27129272785642566`, 0.40247623630249474`, 0.9387610915585742],
              UndirectedEdge[199, 349] -> 
             RGBColor[
              0.3782226741008029, 0.5020192031069408, 0.9453209922378925], 
             UndirectedEdge[265, 462] -> 
             RGBColor[
              0.392446435384819, 0.5140523715462819, 0.9463065444803587], 
             UndirectedEdge[113, 386] -> 
             RGBColor[
              0.17905963034776856`, 0.3055334029047545, 0.9335085531020964], 
             UndirectedEdge[140, 219] -> 
             RGBColor[
              0.5129514818808725, 0.6154761470486363, 0.9548005661383041], 
             UndirectedEdge[13, 313] -> 
             RGBColor[
              0.2817870779153078, 0.4135064635946042, 0.939358729269428], 
             UndirectedEdge[74, 463] -> 
             RGBColor[
              0.2744156870316411, 0.4057586644026942, 0.9389389394635987], 
             UndirectedEdge[146, 415] -> 
             RGBColor[
              0.27247295826931617`, 0.4037167332973729, 0.9388283039345939], 
             UndirectedEdge[213, 475] -> 
             RGBColor[
              0.871604644354381, 0.4793529554696741, 0.21338119452328883`], 
             UndirectedEdge[49, 328] -> 
             RGBColor[
              0.4377638604952656, 0.5525889538048573, 0.9493917132424632], 
             UndirectedEdge[259, 450] -> 
             RGBColor[
              0.8397745913250846, 0.3013267240551166, 0.18550990071046175`], 
             UndirectedEdge[454, 500] -> 
             RGBColor[
              0.8596875442431727, 0.3945530129661969, 0.20223564129349905`], 
             UndirectedEdge[469, 495] -> 
             RGBColor[
              0.8513165746787745, 0.3922611978068248, 0.19664935782673318`], 
             UndirectedEdge[158, 182] -> 
             RGBColor[
              0.36805399542884243`, 0.4932116047339394, 0.9446730530247247], 
             UndirectedEdge[302, 347] -> 
             RGBColor[
              0.18453817917078433`, 0.311291705077802, 0.9338205483527805], 
             UndirectedEdge[87, 107] -> 
             RGBColor[
              0.1819624771956669, 0.3085844789930161, 0.9336738659357071], 
             UndirectedEdge[80, 307] -> 
             RGBColor[
              0.6296762406643908, 0.7079838947833768, 0.9655310968074982], 
             UndirectedEdge[159, 443] -> 
             RGBColor[
              0.877631072588452, 0.4692846461457165, 0.21683434670508697`], 
             UndirectedEdge[396, 443] -> 
             RGBColor[
              0.9640290207521414, 0.8833364286136021, 0.40253589756085995`], 
             UndirectedEdge[15, 452] -> 
             RGBColor[
              0.22909610908040262`, 0.3581249145487392, 0.9363580565435832], 
             UndirectedEdge[55, 250] -> 
             RGBColor[
              0.20796149957955015`, 0.33591109995170554`, 0.9351544717983624],
              UndirectedEdge[105, 447] -> 
             RGBColor[
              0.24620260884716, 0.3761049304183308, 0.9373322463985014], 
             UndirectedEdge[55, 242] -> 
             RGBColor[
              0.21824264556347417`, 0.34671723624311485`, 0.9357399678525544],
              UndirectedEdge[133, 440] -> 
             RGBColor[
              0.31342375230206637`, 0.44339062767442217`, 0.9412837095607336],
              UndirectedEdge[177, 455] -> 
             RGBColor[
              0.2063185988388122, 0.33418430710726665`, 0.9350609110316312], 
             UndirectedEdge[186, 456] -> 
             RGBColor[
              0.22968446940414386`, 0.35874331855319036`, 0.9363915627936191],
              UndirectedEdge[94, 302] -> 
             RGBColor[
              0.5727842186692342, 0.6417308063914131, 0.9472440733920693], 
             UndirectedEdge[146, 376] -> 
             RGBColor[
              0.2686941653913333, 0.39974498239330636`, 0.9386131072704159], 
             UndirectedEdge[44, 106] -> 
             RGBColor[
              0.5072662938524296, 0.6108606552923443, 0.9543530073111751], 
             UndirectedEdge[46, 205] -> 
             RGBColor[
              0.9557407049755898, 0.8502199530826348, 0.4110195083871594], 
             UndirectedEdge[134, 457] -> 
             RGBColor[
              0.22739772905471156`, 0.3563398094582248, 0.936261336313648], 
             UndirectedEdge[229, 248] -> 
             RGBColor[
              0.2667577277658053, 0.3977096636716398, 0.9385028300123448], 
             UndirectedEdge[101, 362] -> 
             RGBColor[
              0.45464713410545365`, 0.5663810460128507, 0.950697205214848], 
             UndirectedEdge[286, 346] -> 
             RGBColor[
              0.22049146079372114`, 0.3490808836332252, 0.935868034553093], 
             UndirectedEdge[134, 138] -> 
             RGBColor[
              0.2265863896100655, 0.3554870402600099, 0.9362151317325447], 
             UndirectedEdge[144, 494] -> 
             RGBColor[
              0.25236564813326057`, 0.3825826754672824, 0.9376832223684453], 
             UndirectedEdge[35, 147] -> 
             RGBColor[
              0.2449327987863818, 0.374770279533845, 0.9372599325940558], 
             UndirectedEdge[5, 211] -> 
             RGBColor[
              0.2348238735021131, 0.3641451581171964, 0.9366842442539314], 
             UndirectedEdge[243, 471] -> 
             RGBColor[
              0.8480593461920269, 0.37041077133751354`, 0.1936549902297403], 
             UndirectedEdge[154, 338] -> 
             RGBColor[
              0.314823265682197, 0.4471058220816644, 0.9412812379953546], 
             UndirectedEdge[185, 383] -> 
             RGBColor[
              0.3064436349421723, 0.43755476203867083`, 0.9408312549471323], 
             UndirectedEdge[416, 429] -> 
             RGBColor[
              0.2775658260011634, 0.4090696601900088, 0.9391183352177], 
             UndirectedEdge[159, 396] -> 
             RGBColor[
              0.9071481131704897, 0.5745522202562454, 0.3532052383412315], 
             UndirectedEdge[73, 322] -> 
             RGBColor[
              0.2535645087759725, 0.3838427540149276, 0.9377514957084923], 
             UndirectedEdge[287, 300] -> 
             RGBColor[
              0.2178846815571592, 0.3463409933762489, 0.9357195823319551], 
             UndirectedEdge[392, 459] -> 
             RGBColor[
              0.34827375514967984`, 0.47582519706689724`, 0.9434219649183455],
              UndirectedEdge[200, 450] -> 
             RGBColor[
              0.8592682454015592, 0.38984285435780597`, 0.20177588350505832`],
              UndirectedEdge[104, 148] -> 
             RGBColor[
              0.2431147548759032, 0.37285940011329033`, 0.9371563976829089], 
             UndirectedEdge[94, 325] -> 
             RGBColor[
              0.5672179996830251, 0.6358803573182399, 0.9469270854552878], 
             UndirectedEdge[355, 378] -> 
             RGBColor[
              0.30589561445696456`, 0.4370005514707954, 0.940799248016793], 
             UndirectedEdge[424, 453] -> 
             RGBColor[
              0.3024506322714007, 0.4341297008728973, 0.9405755985889044], 
             UndirectedEdge[212, 301] -> 
             RGBColor[
              0.2136344659280746, 0.34187374727084574`, 0.9354775388395093], 
             UndirectedEdge[46, 420] -> 
             RGBColor[
              0.9431488383406506, 0.8436851965616485, 0.5952825252201055], 
             UndirectedEdge[146, 284] -> 
             RGBColor[
              0.25151293220690424`, 0.3816864169633695, 0.9376346614579194], 
             UndirectedEdge[76, 343] -> 
             RGBColor[
              0.3521064049491038, 0.47793237749510553`, 0.9437105723744709], 
             UndirectedEdge[111, 256] -> 
             RGBColor[
              0.2812386903435383, 0.41293007348689414`, 0.9393274994084824], 
             UndirectedEdge[277, 319] -> 
             RGBColor[
              0.7430956081884199, 0.7992312039433723, 0.9750284836670953], 
             UndirectedEdge[240, 429] -> 
             RGBColor[
              0.2751117605214455, 0.4064902817740869, 0.9389785798190946], 
             UndirectedEdge[49, 71] -> 
             RGBColor[
              0.6229981269292593, 0.7030794824142605, 0.9646517716159538], 
             UndirectedEdge[19, 139] -> 
             RGBColor[
              0.5618798532479841, 0.6551984031224687, 0.9586523867628529], 
             UndirectedEdge[9, 247] -> 
             RGBColor[
              0.5350775301382318, 0.6334390697910756, 0.9565424097075088], 
             UndirectedEdge[333, 392] -> 
             RGBColor[
              0.34232526370384136`, 0.4706729127563853, 0.943042932303461], 
             UndirectedEdge[169, 337] -> 
             RGBColor[
              0.6764764422213522, 0.7452210038115648, 0.9698692373870139], 
             UndirectedEdge[21, 119] -> 
             RGBColor[
              0.9857675700825197, 0.9687962754074746, 0.5924568745131584], 
             UndirectedEdge[354, 479] -> 
             RGBColor[
              0.38662725868303643`, 0.5092988318453677, 0.9458565249355901], 
             UndirectedEdge[179, 236] -> 
             RGBColor[
              0.23312614698427564`, 0.36236073990487094`, 0.9365875612403018],
              UndirectedEdge[121, 341] -> 
             RGBColor[
              0.9105196563022746, 0.6003916270804778, 0.3579070077274834], 
             UndirectedEdge[263, 323] -> 
             RGBColor[
              0.2563726589916906, 0.3867942979386546, 0.9379114157089916], 
             UndirectedEdge[200, 401] -> 
             RGBColor[
              0.8371401925160188, 0.7327555556169211, 0.6085074799840489], 
             UndirectedEdge[56, 236] -> 
             RGBColor[
              0.5619983827153064, 0.35111011799079705`, 0.5612129978793174], 
             UndirectedEdge[374, 437] -> 
             RGBColor[
              0.25378039219455883`, 0.3840696611756612, 0.9377637899498099], 
             UndirectedEdge[74, 195] -> 
             RGBColor[
              0.27594296910076915`, 0.40736393469262394`, 0.9390259159180243],
              UndirectedEdge[240, 399] -> 
             RGBColor[
              0.24906325398775672`, 0.3791116498364756, 0.9374951559073132], 
             UndirectedEdge[138, 352] -> 
             RGBColor[
              0.22389864331585435`, 0.3526620484918363, 0.9360620685572537], 
             UndirectedEdge[195, 342] -> 
             RGBColor[
              0.265069534257383, 0.39593526525663725`, 0.9384066898894987], 
             UndirectedEdge[13, 363] -> 
             RGBColor[
              0.3507138092232281, 0.4770709297343131, 0.9436092144688942], 
             UndirectedEdge[368, 386] -> 
             RGBColor[
              0.2935143249909316, 0.4166464351270609, 0.9403629270800464], 
             UndirectedEdge[132, 233] -> 
             RGBColor[
              0.9166463543771588, 0.6614692040973338, 0.5010749461233683], 
             UndirectedEdge[304, 310] -> 
             RGBColor[
              0.317660558842397, 0.44845488439544834`, 0.9415026138990965], 
             UndirectedEdge[213, 259] -> 
             RGBColor[
              0.8830232984339081, 0.5617179434386964, 0.224104111662967], 
             UndirectedEdge[226, 446] -> 
             RGBColor[
              0.20378813280661343`, 0.33152462686661266`, 0.9349168047345866],
              UndirectedEdge[60, 249] -> 
             RGBColor[
              0.29112873348308044`, 0.42332513589150556`, 0.9398907227342717],
              UndirectedEdge[181, 387] -> 
             RGBColor[
              0.5979055016129029, 0.6815262817946347, 0.9631235948533272], 
             UndirectedEdge[94, 168] -> 
             RGBColor[
              0.9331056494970619, 0.8251500560931704, 0.6037137900969318], 
             UndirectedEdge[142, 402] -> 
             RGBColor[
              0.6259177691187879, 0.7063115685381091, 0.9642924066530247], 
             UndirectedEdge[188, 310] -> 
             RGBColor[
              0.3170171080071488, 0.4478975596227356, 0.9414616137808558], 
             UndirectedEdge[74, 239] -> 
             RGBColor[
              0.31633226480045645`, 0.4459153985127936, 0.9414688336983061], 
             UndirectedEdge[376, 400] -> 
             RGBColor[
              0.2876884645475003, 0.41970919511456195`, 0.9396948045078122], 
             UndirectedEdge[292, 308] -> 
             RGBColor[
              0.17895845847297373`, 0.30542706484967774`, 0.9335027915134972],
              UndirectedEdge[7, 142] -> 
             RGBColor[
              0.7691032060058948, 0.819699666861827, 0.9775805727504322], 
             UndirectedEdge[20, 194] -> 
             RGBColor[
              0.9355250585723344, 0.7786349412620628, 0.5492457614630861], 
             UndirectedEdge[168, 500] -> 
             RGBColor[
              0.8651424411448785, 0.41743131522220955`, 0.2066895157907081], 
             UndirectedEdge[4, 383] -> 
             RGBColor[
              0.32662308368104653`, 0.45732623135617084`, 0.9420331119640719],
              UndirectedEdge[91, 303] -> 
             RGBColor[
              0.3164436833902854, 0.44818690517109605`, 0.9413962957337874], 
             UndirectedEdge[142, 417] -> 
             RGBColor[
              0.7002784838355302, 0.7657821409766972, 0.9707608728603756], 
             UndirectedEdge[229, 338] -> 
             RGBColor[
              0.3055405634218271, 0.43742263545021065`, 0.9407499098335221], 
             UndirectedEdge[69, 388] -> 
             RGBColor[
              0.9278173046721767, 0.9450102776472538, 0.9836136557859578], 
             UndirectedEdge[170, 374] -> 
             RGBColor[
              0.2742054454433818, 0.40553768716334715`, 0.9389269665161719], 
             UndirectedEdge[96, 281] -> 
             RGBColor[
              0.27053519804586806`, 0.4016800244414347, 0.938717951356528], 
             UndirectedEdge[131, 265] -> 
             RGBColor[
              0.29231177765764305`, 0.42343428317537546`, 0.9399996278912657],
              UndirectedEdge[117, 369] -> 
             RGBColor[
              0.40051134864769267`, 0.5213245327381009, 0.9467412068709193], 
             UndirectedEdge[19, 247] -> 
             RGBColor[
              0.5273679540729146, 0.6271800886288073, 0.9559354836385393], 
             UndirectedEdge[328, 436] -> 
             RGBColor[
              0.42911640965865483`, 0.5455685636524759, 0.9487109542359491], 
             UndirectedEdge[86, 178] -> 
             RGBColor[
              0.9534388639235, 0.8461526483552239, 0.5190456011559075], 
             UndirectedEdge[42, 137] -> 
             RGBColor[
              0.22627740530250587`, 0.35516227816202806`, 0.9361975355333305],
              UndirectedEdge[54, 135] -> 
             RGBColor[
              0.23967378277683635`, 0.36924272026693905`, 0.9369604394123292],
              UndirectedEdge[42, 174] -> 
             RGBColor[
              0.2495656884148965, 0.3796397402755821, 0.9375237688046536], 
             UndirectedEdge[1, 374] -> 
             RGBColor[
              0.25894790578239785`, 0.38950104559576504`, 0.9380580722039861],
              UndirectedEdge[160, 285] -> 
             RGBColor[
              0.3684500451199806, 0.49355464307036695`, 0.9446982889608311], 
             UndirectedEdge[454, 471] -> 
             RGBColor[
              0.8783475046128462, 0.5379816452142798, 0.2201044404169093], 
             UndirectedEdge[26, 425] -> 
             RGBColor[
              0.38098619324606947`, 0.5044128244920598, 0.9454970812341448], 
             UndirectedEdge[333, 442] -> 
             RGBColor[
              0.331297230301234, 0.4590817504325423, 0.942414902115696], 
             UndirectedEdge[75, 410] -> 
             RGBColor[
              0.354306761585108, 0.48130444173456, 0.9437970914404035], 
             UndirectedEdge[31, 40] -> 
             RGBColor[
              0.4196192099941566, 0.5378748018473721, 0.9479587428994976], 
             UndirectedEdge[3, 258] -> 
             RGBColor[
              0.41754423807969365`, 0.5358508967798354, 0.9478891567573319], 
             UndirectedEdge[132, 273] -> 
             RGBColor[
              0.6418371637733833, 0.7080243687957053, 0.8766074186854609], 
             UndirectedEdge[157, 180] -> 
             RGBColor[
              0.2863372761085622, 0.4182890103949429, 0.9396178563251187], 
             UndirectedEdge[213, 401] -> 
             RGBColor[
              0.8388291376735261, 0.7404246611139982, 0.6099167772233072], 
             UndirectedEdge[84, 391] -> 
             RGBColor[
              0.23722076036640824`, 0.3666644381829753, 0.9368207434149767], 
             UndirectedEdge[43, 110] -> 
             RGBColor[
              0.2824315567297242, 0.4141838516908727, 0.9393954313844881], 
             UndirectedEdge[39, 127] -> 
             RGBColor[
              0.4248206994263658, 0.5301025431322064, 0.9498483295981558], 
             UndirectedEdge[52, 469] -> 
             RGBColor[
              0.8481128613393234, 0.36763605320366755`, 0.19358147831479822`],
              UndirectedEdge[260, 483] -> 
             RGBColor[
              0.2911128004849959, 0.42330838930030823`, 0.9398898153736015], 
             UndirectedEdge[98, 311] -> 
             RGBColor[
              0.8710458030481137, 0.8971927199459824, 0.8490560873664715], 
             UndirectedEdge[51, 127] -> 
             RGBColor[
              0.20245340605759676`, 0.3301217444268325, 0.9348407940207814], 
             UndirectedEdge[243, 475] -> 
             RGBColor[
              0.8391547501965229, 0.3019661444972231, 0.18512793904814284`], 
             UndirectedEdge[76, 96] -> 
             RGBColor[
              0.3537435180123586, 0.4796530871235497, 0.9438038035415315], 
             UndirectedEdge[99, 476] -> 
             RGBColor[
              0.9210569805098886, 0.6812525268241133, 0.37059559494700395`], 
             UndirectedEdge[107, 308] -> 
             RGBColor[
              0.18180898862834943`, 0.3084231527770282, 0.9336651249888644], 
             UndirectedEdge[190, 263] -> 
             RGBColor[
              0.26075513515246407`, 0.3914005582486648, 0.9381609912430551], 
             UndirectedEdge[191, 299] -> 
             RGBColor[
              0.21378387890714912`, 0.3420307897851831, 0.935486047687631], 
             UndirectedEdge[39, 276] -> 
             RGBColor[
              0.6216008719460259, 0.7036826165027719, 0.9633538441200625], 
             UndirectedEdge[51, 214] -> 
             RGBColor[
              0.1893670578318586, 0.31636716271918164`, 0.9340955458488429], 
             UndirectedEdge[295, 409] -> 
             RGBColor[
              0.23557177233220394`, 0.3649312472071466, 0.9367268359858879], 
             UndirectedEdge[371, 382] -> 
             RGBColor[
              0.322584307384319, 0.45137597056269757`, 0.9418655472151594], 
             UndirectedEdge[53, 420] -> 
             RGBColor[
              0.9725775680800968, 0.9542835451375451, 0.6506094324523175], 
             UndirectedEdge[87, 308] -> 
             RGBColor[
              0.17909977333492821`, 0.3055755957294717, 0.9335108391858289], 
             UndirectedEdge[286, 358] -> 
             RGBColor[
              0.22436323878386594`, 0.35315036778577047`, 0.9360885265818495],
              UndirectedEdge[215, 351] -> 
             RGBColor[
              0.28708427642095813`, 0.4190741550858264, 0.9396603968878219], 
             UndirectedEdge[114, 258] -> 
             RGBColor[
              0.4370504632160207, 0.551686929090934, 0.9494247582537205], 
             UndirectedEdge[87, 292] -> 
             RGBColor[
              0.1791119470402912, 0.3055883910656657, 0.93351153246034], 
             UndirectedEdge[196, 383] -> 
             RGBColor[
              0.3123209276016251, 0.4437321692656331, 0.941165958069413], 
             UndirectedEdge[65, 495] -> 
             RGBColor[
              0.9138336495538494, 0.6440119286541663, 0.2930402350354805], 
             UndirectedEdge[14, 279] -> 
             RGBColor[
              0.2926514518650601, 0.4249256094568878, 0.9399774392934654], 
             UndirectedEdge[26, 466] -> 
             RGBColor[
              0.4450688550450512, 0.558555224381097, 0.9499569121935232], 
             UndirectedEdge[27, 371] -> 
             RGBColor[
              0.43753141765926407`, 0.551792873087608, 0.9495412335023905], 
             UndirectedEdge[258, 472] -> 
             RGBColor[
              0.3509345795878789, 0.47838362717935545`, 0.9435822189854435], 
             UndirectedEdge[26, 117] -> 
             RGBColor[
              0.38385240519854513`, 0.5068953932252928, 0.9456797137252648], 
             UndirectedEdge[97, 104] -> 
             RGBColor[
              0.23915408747259903`, 0.3686964875516002, 0.936930843533573], 
             UndirectedEdge[21, 428] -> 
             RGBColor[
              0.9056106309029361, 0.5906771035003356, 0.2784668522610333], 
             UndirectedEdge[160, 268] -> 
             RGBColor[
              0.41606826400089775`, 0.5347991509037464, 0.9477324797607855], 
             UndirectedEdge[48, 137] -> 
             RGBColor[
              0.21379570916554433`, 0.34204322413683813`, 0.9354867214033452],
              UndirectedEdge[27, 291] -> 
             RGBColor[
              0.583523028601068, 0.6725767800031528, 0.9604878491746004], 
             UndirectedEdge[117, 140] -> 
             RGBColor[
              0.44035466890019287`, 0.5545772244209933, 0.9496274637964799], 
             UndirectedEdge[31, 221] -> 
             RGBColor[
              0.4948241717740719, 0.6007519845572706, 0.9533756165491586], 
             UndirectedEdge[87, 386] -> 
             RGBColor[
              0.17909013095112286`, 0.3055654609727298, 0.9335102900663359], 
             UndirectedEdge[207, 409] -> 
             RGBColor[
              0.22930932819200256`, 0.35834902135390323`, 0.9363701990565594],
              UndirectedEdge[274, 498] -> 
             RGBColor[
              0.46231188623512687`, 0.5743646420156336, 0.95081403167012], 
             UndirectedEdge[28, 69] -> 
             RGBColor[
              0.9371592911405698, 0.9519775158592825, 0.9678001094752631], 
             UndirectedEdge[442, 492] -> 
             RGBColor[
              0.2802823193946945, 0.4119248669822389, 0.9392730354977699], 
             UndirectedEdge[476, 493] -> 
             RGBColor[
              0.9210348441528622, 0.6812051793947629, 0.36818618909444256`], 
             UndirectedEdge[297, 359] -> 
             RGBColor[
              0.45240773600559087`, 0.5644812656494411, 0.9505434955218137], 
             UndirectedEdge[112, 323] -> 
             RGBColor[
              0.24380409586490398`, 0.37358394119947325`, 0.9371956546324439],
              UndirectedEdge[27, 349] -> 
             RGBColor[
              0.46286019331944683`, 0.5737313855031778, 0.9511551606901004], 
             UndirectedEdge[2, 242] -> 
             RGBColor[
              0.21872765624032725`, 0.34722701321594046`, 0.9357675884930923],
              UndirectedEdge[71, 462] -> 
             RGBColor[
              0.6098299518680684, 0.6923889646800596, 0.9636151246385223], 
             UndirectedEdge[165, 285] -> 
             RGBColor[
              0.3692257984681636, 0.49422656163006606`, 0.9447477192782054], 
             UndirectedEdge[91, 172] -> 
             RGBColor[
              0.33964065051404985`, 0.4686013934649852, 0.9428625798116885], 
             UndirectedEdge[19, 26] -> 
             RGBColor[
              0.4731770317838775, 0.5813747085166081, 0.9521696908300475], 
             UndirectedEdge[73, 163] -> 
             RGBColor[
              0.2574513896017804, 0.3879281122053299, 0.9379728478213971], 
             UndirectedEdge[67, 131] -> 
             RGBColor[
              0.2601160605037315, 0.39072885027317383`, 0.938124596887236], 
             UndirectedEdge[24, 81] -> 
             RGBColor[
              0.8302950804632105, 0.8675187756745408, 0.9836754800593912], 
             UndirectedEdge[282, 467] -> 
             RGBColor[
              0.6572487791197071, 0.7316354395209496, 0.9668355107224047], 
             UndirectedEdge[122, 406] -> 
             RGBColor[
              0.929061342775948, 0.7356327772399205, 0.3146046467534838], 
             UndirectedEdge[139, 255] -> 
             RGBColor[
              0.4808103528632557, 0.5878692632314095, 0.9526884189998513], 
             UndirectedEdge[409, 458] -> 
             RGBColor[
              0.23602745875437942`, 0.36541020252904094`, 0.9367527866535031],
              UndirectedEdge[4, 196] -> 
             RGBColor[
              0.31000149085861584`, 0.44172318973711877`, 0.9410181656111457],
              UndirectedEdge[46, 90] -> 
             RGBColor[
              0.8912123121580973, 0.5950344530170778, 0.2307371435474895], 
             UndirectedEdge[115, 124] -> 
             RGBColor[
              0.9419104649402625, 0.9128295501642687, 0.6508778471089514], 
             UndirectedEdge[330, 350] -> 
             RGBColor[
              0.33430977302587317`, 0.4637717331289171, 0.9425306751676419], 
             UndirectedEdge[213, 315] -> 
             RGBColor[
              0.5448527569683213, 0.48510270783243126`, 0.5878273462350064], 
             UndirectedEdge[107, 143] -> 
             RGBColor[
              0.18179934691843552`, 0.30841301872858895`, 0.9336645759077484],
              UndirectedEdge[403, 491] -> 
             RGBColor[
              0.9615367037861473, 0.968036714632053, 0.7994838663892643], 
             UndirectedEdge[200, 254] -> 
             RGBColor[
              0.5686631284014866, 0.5042350008222019, 0.5878701973527287], 
             UndirectedEdge[37, 304] -> 
             RGBColor[
              0.32210212279026273`, 0.45312324971607465`, 0.9417555543952225],
              UndirectedEdge[25, 392] -> 
             RGBColor[
              0.3096883372024623, 0.4424044474005129, 0.9409633362064942], 
             UndirectedEdge[231, 492] -> 
             RGBColor[
              0.2675328366491727, 0.39852435225280064`, 0.9385469713165818], 
             UndirectedEdge[22, 63] -> 
             RGBColor[
              0.4353760609281416, 0.5515225941640346, 0.948962755507775], 
             UndirectedEdge[201, 256] -> 
             RGBColor[
              0.2969224563599441, 0.4294147059783363, 0.9402206666810642], 
             UndirectedEdge[57, 92] -> 
             RGBColor[
              0.6051902881840892, 0.690359765316458, 0.9620619428523739], 
             UndirectedEdge[433, 462] -> 
             RGBColor[
              0.3946923083800721, 0.5159976338539112, 0.9464496495216687], 
             UndirectedEdge[286, 294] -> 
             RGBColor[
              0.23070650372322443`, 0.3598175414232626, 0.9364497661361264], 
             UndirectedEdge[319, 331] -> 
             RGBColor[
              0.775790689833521, 0.8249078922958527, 0.9782513878368327], 
             UndirectedEdge[222, 307] -> 
             RGBColor[
              0.456261635454359, 0.5691648443465238, 0.950417290103996], 
             UndirectedEdge[276, 283] -> 
             RGBColor[
              0.4003771577872324, 0.5049037920541919, 0.9484114336869224], 
             UndirectedEdge[464, 497] -> 
             RGBColor[
              0.23993020302659857`, 0.369512234207422, 0.9369750421662133], 
             UndirectedEdge[143, 283] -> 
             RGBColor[
              0.18007058028918088`, 0.3065959753911073, 0.9335661252056935], 
             UndirectedEdge[265, 433] -> 
             RGBColor[
              0.32326037843179023`, 0.45441362508374517`, 0.9418188433591128],
              UndirectedEdge[74, 234] -> 
             RGBColor[
              0.335156328175214, 0.4622198560830736, 0.94266828637108], 
             UndirectedEdge[17, 432] -> 
             RGBColor[
              0.8892978625365586, 0.9145659925119751, 0.9893032180859526], 
             UndirectedEdge[103, 118] -> 
             RGBColor[
              0.4027319052154037, 0.522513730131029, 0.9470855430392838], 
             UndirectedEdge[426, 489] -> 
             RGBColor[
              0.9301359936068372, 0.9447452859638352, 0.9006256116612403], 
             UndirectedEdge[277, 331] -> 
             RGBColor[
              0.8039966134471465, 0.8469425741957761, 0.9810626907032964], 
             UndirectedEdge[74, 112] -> 
             RGBColor[
              0.264998769293781, 0.3958608867931338, 0.938402659929509], 
             UndirectedEdge[80, 372] -> 
             RGBColor[
              0.6299979927875134, 0.7082451076516956, 0.9655564263132472], 
             UndirectedEdge[180, 281] -> 
             RGBColor[
              0.2575198022383923, 0.3880000182240208, 0.9379767438198447], 
             UndirectedEdge[263, 296] -> 
             RGBColor[
              0.2934102361450429, 0.4252910132115676, 0.9400364732085589], 
             UndirectedEdge[37, 141] -> 
             RGBColor[
              0.3076115395353609, 0.4405722348185699, 0.9408322272437397], 
             UndirectedEdge[18, 210] -> 
             RGBColor[
              0.8602238171594843, 0.4230516477625904, 0.20370370360755374`], 
             UndirectedEdge[279, 494] -> 
             RGBColor[
              0.2685318784304253, 0.3995744085078045, 0.9386038652680744], 
             UndirectedEdge[101, 337] -> 
             RGBColor[
              0.6905217138834787, 0.756623588079157, 0.9709749326217818], 
             UndirectedEdge[217, 378] -> 
             RGBColor[
              0.30140209308183147`, 0.4331084891066064, 0.9405129248082346], 
             UndirectedEdge[20, 62] -> 
             RGBColor[
              0.8509265138034974, 0.3513524058869604, 0.19479135055817565`], 
             UndirectedEdge[18, 56] -> 
             RGBColor[
              0.8605287644059905, 0.4253956059279722, 0.2039957214351967], 
             UndirectedEdge[444, 492] -> 
             RGBColor[
              0.2739561801729139, 0.4052756935597544, 0.9389127712277736], 
             UndirectedEdge[199, 427] -> 
             RGBColor[
              0.31117200287913815`, 0.44123930103287445`, 0.9411475887384059],
              UndirectedEdge[190, 463] -> 
             RGBColor[
              0.2576034897635375, 0.3880879791190439, 0.9379815097005972], 
             UndirectedEdge[139, 369] -> 
             RGBColor[
              0.49199130185999246`, 0.5975536392815464, 0.9534008591829983], 
             UndirectedEdge[10, 455] -> 
             RGBColor[
              0.21145152724630215`, 0.3395793403099965, 0.9353532237109508], 
             UndirectedEdge[52, 236] -> 
             RGBColor[
              0.5615591008027638, 0.3477336047164332, 0.5607923410237687], 
             UndirectedEdge[9, 19] -> 
             RGBColor[
              0.5674341026863339, 0.6597075930326068, 0.9590896376245259], 
             UndirectedEdge[33, 309] -> 
             RGBColor[
              0.9357225086078202, 0.7641455885442991, 0.35153908493080155`], 
             UndirectedEdge[341, 491] -> 
             RGBColor[
              0.9938674015539399, 0.9892913169617195, 0.5738826890360067], 
             UndirectedEdge[87, 143] -> 
             RGBColor[
              0.1790901316250143, 0.30556546168103244`, 0.933510290104713], 
             UndirectedEdge[110, 378] -> 
             RGBColor[
              0.2773998635716586, 0.40889522315397336`, 0.9391088839028592], 
             UndirectedEdge[401, 471] -> 
             RGBColor[
              0.8151324803555211, 0.6303190641854999, 0.5900456312313715], 
             UndirectedEdge[160, 165] -> 
             RGBColor[
              0.4232575021072018, 0.5410261076098133, 0.9481905716557255], 
             UndirectedEdge[13, 379] -> 
             RGBColor[
              0.3029577301181068, 0.43570701430378433`, 0.9405662393373586], 
             UndirectedEdge[210, 434] -> 
             RGBColor[
              0.9136331462118448, 0.6344185701788778, 0.48881376628200723`], 
             UndirectedEdge[308, 446] -> 
             RGBColor[
              0.2035487790418117, 0.3312730508839008, 0.9349031738917732], 
             UndirectedEdge[153, 395] -> 
             RGBColor[
              0.2549602684410159, 0.3853097859191623, 0.9378309821565751], 
             UndirectedEdge[24, 83] -> 
             RGBColor[
              0.878858858195596, 0.9062422138097157, 0.9883075365329024], 
             UndirectedEdge[133, 260] -> 
             RGBColor[
              0.31537504749154577`, 0.44544156263782575`, 0.9413948329350919],
              UndirectedEdge[83, 119] -> 
             RGBColor[
              0.9556965383033635, 0.9650210547273206, 0.8984817408494732], 
             UndirectedEdge[400, 464] -> 
             RGBColor[
              0.26989429594474446`, 0.40100639569761354`, 0.9386814529299987],
              UndirectedEdge[175, 320] -> 
             RGBColor[
              0.9721663810423609, 0.9780295691716399, 0.8991854671906325], 
             UndirectedEdge[39, 475] -> 
             RGBColor[
              0.731332489294519, 0.5030791649818271, 0.5742495342753344], 
             UndirectedEdge[289, 291] -> 
             RGBColor[
              0.5471490964494157, 0.6426680909259248, 0.9577289938124869], 
             UndirectedEdge[263, 342] -> 
             RGBColor[
              0.2666938975771815, 0.3976425740963284, 0.9384991949775311], 
             UndirectedEdge[311, 319] -> 
             RGBColor[
              0.7308732764235066, 0.7896830254754603, 0.9738102758609529], 
             UndirectedEdge[141, 304] -> 
             RGBColor[
              0.3240734635805927, 0.45511787857278996`, 0.9418706524258115], 
             UndirectedEdge[30, 43] -> 
             RGBColor[
              0.2805395184040802, 0.4121951994484624, 0.9392876826008625], 
             UndirectedEdge[85, 95] -> 
             RGBColor[
              0.22064923730827996`, 0.3492467167536353, 0.9358770196921877], 
             UndirectedEdge[305, 438] -> 
             RGBColor[
              0.23628821482403703`, 0.36568427369114076`, 0.9367676363259161],
              UndirectedEdge[23, 212] -> 
             RGBColor[
              0.22050887971367938`, 0.3490991920225246, 0.9358690265348157], 
             UndirectedEdge[80, 461] -> 
             RGBColor[
              0.8669992096038857, 0.8968058897416262, 0.9792822184041656], 
             UndirectedEdge[115, 439] -> 
             RGBColor[
              0.8910404321249454, 0.9159554702009634, 0.9894694259289032], 
             UndirectedEdge[136, 377] -> 
             RGBColor[
              0.9750328863705816, 0.980900148051852, 0.9271469902951855], 
             UndirectedEdge[27, 488] -> 
             RGBColor[
              0.640741608541348, 0.7172763695298137, 0.9661908624850168], 
             UndirectedEdge[70, 170] -> 
             RGBColor[
              0.2774653661360603, 0.408964070502262, 0.9391126141769994], 
             UndirectedEdge[268, 441] -> 
             RGBColor[
              0.4298935905497302, 0.5467739538792281, 0.9486134173432208], 
             UndirectedEdge[394, 445] -> 
             RGBColor[
              0.2291408986849781, 0.35817199126297306`, 0.9363606072453035], 
             UndirectedEdge[234, 393] -> 
             RGBColor[
              0.42489506401207827`, 0.5422301548105988, 0.9483541347345662], 
             UndirectedEdge[228, 388] -> 
             RGBColor[
              0.9696267022726579, 0.9734928770909221, 0.7321607638451979], 
             UndirectedEdge[8, 114] -> 
             RGBColor[
              0.5604860564407306, 0.6540668560845098, 0.9585426619725401], 
             UndirectedEdge[21, 164] -> 
             RGBColor[
              0.8992062375406565, 0.5414501296947882, 0.27233399794458657`], 
             UndirectedEdge[100, 454] -> 
             RGBColor[
              0.915548639391991, 0.7016340736991815, 0.25084192040061865`], 
             UndirectedEdge[6, 267] -> 
             RGBColor[
              0.9083762130299251, 0.9201045780958312, 0.6977188544044266], 
             UndirectedEdge[210, 495] -> 
             RGBColor[
              0.8391330927044698, 0.3017996755229297, 0.18510719980929416`], 
             UndirectedEdge[112, 342] -> 
             RGBColor[
              0.25412533445039487`, 0.3844322173571471, 0.9377834339009834], 
             UndirectedEdge[93, 206] -> 
             RGBColor[
              0.30600971855859727`, 0.43582355730741806`, 0.940853232846973], 
             UndirectedEdge[485, 497] -> 
             RGBColor[
              0.24199741678266362`, 0.3716850069339687, 0.9370927669314526], 
             UndirectedEdge[36, 240] -> 
             RGBColor[
              0.25550742159800177`, 0.3858848785786683, 0.9378621417194251], 
             UndirectedEdge[275, 285] -> 
             RGBColor[
              0.36406115169331943`, 0.4897532041763907, 0.9444186325526303], 
             UndirectedEdge[36, 399] -> 
             RGBColor[
              0.24794512185068096`, 0.37793642206673694`, 0.937431479936235], 
             UndirectedEdge[72, 279] -> 
             RGBColor[
              0.26627234056032795`, 0.3971994909433567, 0.9384751879290589], 
             UndirectedEdge[278, 413] -> 
             RGBColor[
              0.9610998830487185, 0.9422076271108857, 0.6625746129461039], 
             UndirectedEdge[10, 120] -> 
             RGBColor[
              0.21319195993880496`, 0.3414086454196232, 0.9354523387780493], 
             UndirectedEdge[59, 153] -> 
             RGBColor[
              0.24356203444566857`, 0.3733295193002764, 0.9371818695927163], 
             UndirectedEdge[377, 488] -> 
             RGBColor[
              0.8752347056162003, 0.9025906545325564, 0.9472574998794909], 
             UndirectedEdge[53, 306] -> 
             RGBColor[
              0.9170459103045016, 0.6880097948516692, 0.28301334457340965`], 
             UndirectedEdge[172, 448] -> 
             RGBColor[
              0.45979588464643895`, 0.5695615806771241, 0.9513786855523698], 
             UndirectedEdge[138, 367] -> 
             RGBColor[
              0.22490572664447084`, 0.3537205569229832, 0.9361194204629721], 
             UndirectedEdge[71, 431] -> 
             RGBColor[
              0.602160734252356, 0.6860330125252593, 0.9630472221226452], 
             UndirectedEdge[180, 392] -> 
             RGBColor[
              0.2880661676144659, 0.4201061849857004, 0.9397163141387143], 
             UndirectedEdge[33, 227] -> 
             RGBColor[
              0.8620227096886874, 0.44626803209664856`, 0.20579398688200412`],
              UndirectedEdge[30, 384] -> 
             RGBColor[
              0.2758760121335012, 0.4072935586747084, 0.9390221028177923], 
             UndirectedEdge[441, 467] -> 
             RGBColor[
              0.5784857852356426, 0.6676055963951182, 0.960658898554645], 
             UndirectedEdge[99, 122] -> 
             RGBColor[
              0.930562919133284, 0.740007623770434, 0.37913808172539787`], 
             UndirectedEdge[89, 225] -> 
             RGBColor[
              0.2798755048828646, 0.4114972791367759, 0.9392498680131491], 
             UndirectedEdge[146, 497] -> 
             RGBColor[
              0.24696343657246012`, 0.3769046085968852, 0.9373755744119134], 
             UndirectedEdge[176, 197] -> 
             RGBColor[
              0.6522851143834272, 0.7277468526483104, 0.9663482548197164], 
             UndirectedEdge[326, 474] -> 
             RGBColor[
              0.9341363327937491, 0.7587482425843726, 0.49080863680582576`], 
             UndirectedEdge[173, 241] -> 
             RGBColor[
              0.8450225482014433, 0.8788658384170731, 0.9383874109586698], 
             UndirectedEdge[403, 405] -> 
             RGBColor[
              0.9614623294969025, 0.9678776355477525, 0.7913886839898783], 
             UndirectedEdge[79, 476] -> 
             RGBColor[
              0.9211605712027758, 0.6814740968415736, 0.3818708025801312], 
             UndirectedEdge[46, 257] -> 
             RGBColor[
              0.8882541401217813, 0.5816020846987996, 0.22826877228895565`], 
             UndirectedEdge[450, 491] -> 
             RGBColor[
              0.9059349577098716, 0.5635204793804358, 0.38523852750809673`], 
             UndirectedEdge[200, 243] -> 
             RGBColor[
              0.8700670583525245, 0.4728472627689348, 0.21211683898241762`], 
             UndirectedEdge[296, 424] -> 
             RGBColor[
              0.31700712622472516`, 0.4489973723195799, 0.9414203916580124], 
             UndirectedEdge[269, 466] -> 
             RGBColor[
              0.47622375697085434`, 0.5855400345383266, 0.9519420749950372], 
             UndirectedEdge[74, 453] -> 
             RGBColor[
              0.2830204227561394, 0.41480278722089764`, 0.9394289664335431], 
             UndirectedEdge[18, 469] -> 
             RGBColor[
              0.8724072991337889, 0.5135131700464854, 0.21524586162499276`], 
             UndirectedEdge[279, 481] -> 
             RGBColor[
              0.2983884604335446, 0.4300799385434647, 0.9403362145723715], 
             UndirectedEdge[19, 468] -> 
             RGBColor[
              0.5190507751439478, 0.6204278280896312, 0.9552807248464208], 
             UndirectedEdge[415, 464] -> 
             RGBColor[
              0.2654397247234546, 0.39632435890790974`, 0.9384277716888938], 
             UndirectedEdge[234, 262] -> 
             RGBColor[
              0.4323322286458682, 0.548267980100758, 0.9489396155777698], 
             UndirectedEdge[241, 417] -> 
             RGBColor[
              0.7032574015004508, 0.7681092940971459, 0.9710577835336467], 
             UndirectedEdge[309, 489] -> 
             RGBColor[
              0.9915641796444485, 0.9888374754562259, 0.6482959890771074], 
             UndirectedEdge[83, 426] -> 
             RGBColor[
              0.895460047558787, 0.9194795515806435, 0.9898909727944203], 
             UndirectedEdge[6, 99] -> 
             RGBColor[
              0.9106556765920616, 0.9271034208247384, 0.765274234275318], 
             UndirectedEdge[121, 491] -> 
             RGBColor[
              0.9108136867178351, 0.6010205284083265, 0.38991040391585896`], 
             UndirectedEdge[42, 358] -> 
             RGBColor[
              0.22905024080537584`, 0.3580767040834695, 0.9363554444131764], 
             UndirectedEdge[69, 461] -> 
             RGBColor[
              0.926959006974305, 0.9443701606295145, 0.985066529908563], 
             UndirectedEdge[161, 387] -> 
             RGBColor[
              0.8827228822801044, 0.901646814849579, 0.6975808353380122], 
             UndirectedEdge[117, 390] -> 
             RGBColor[
              0.34091437037852435`, 0.46896566133560236`, 0.9429707972165], 
             UndirectedEdge[244, 334] -> 
             RGBColor[
              0.3726225537176192, 0.4971686603012616, 0.9449641575190681], 
             UndirectedEdge[173, 493] -> 
             RGBColor[
              0.9890701085039466, 0.9882775676582451, 0.7238989830539463], 
             UndirectedEdge[229, 255] -> 
             RGBColor[
              0.34428066244060973`, 0.47097736208628804`, 0.9432183946864745],
              UndirectedEdge[39, 401] -> 
             RGBColor[
              0.6985569826136641, 0.7641508706261513, 0.9707851169753527], 
             UndirectedEdge[379, 380] -> 
             RGBColor[
              0.29107513038505384`, 0.42321764858400834`, 0.9398895428612922],
              UndirectedEdge[92, 140] -> 
             RGBColor[
              0.554385826473297, 0.649114414584719, 0.9580624295236251], 
             UndirectedEdge[78, 97] -> 
             RGBColor[
              0.22558180327383132`, 0.35443115632617517`, 0.9361579220268484],
              UndirectedEdge[395, 463] -> 
             RGBColor[
              0.2660424669485921, 0.39695787920259357`, 0.9384620969669382], 
             UndirectedEdge[174, 338] -> 
             RGBColor[
              0.29338121786998295`, 0.4246423923281867, 0.9400574530924843], 
             UndirectedEdge[143, 423] -> 
             RGBColor[
              0.1833764464098977, 0.31007065028799885`, 0.9337543893906777], 
             UndirectedEdge[94, 100] -> 
             RGBColor[
              0.943316965793535, 0.8656345224892459, 0.6119300548794735], 
             UndirectedEdge[404, 408] -> 
             RGBColor[
              0.2179764205636531, 0.3464374168886629, 0.9357248067326592], 
             UndirectedEdge[301, 389] -> 
             RGBColor[
              0.21362623144598136`, 0.3418650923080694, 0.9354770698979359], 
             UndirectedEdge[16, 422] -> 
             RGBColor[
              0.3189470428658002, 0.4437679620863825, 0.9417969982435161], 
             UndirectedEdge[389, 451] -> 
             RGBColor[
              0.21497280031897864`, 0.34328042157098726`, 0.9355537550031829],
              UndirectedEdge[74, 296] -> 
             RGBColor[
              0.2975769167094639, 0.42967045866758025`, 0.9402737595026511], 
             UndirectedEdge[225, 453] -> 
             RGBColor[
              0.2792780627176027, 0.4108693295410645, 0.939215844565674], 
             UndirectedEdge[340, 378] -> 
             RGBColor[
              0.31025949401998754`, 0.4407803246133216, 0.9410773105637218], 
             UndirectedEdge[52, 428] -> 
             RGBColor[
              0.8330642703587228, 0.25515204759860854`, 0.17929568867725226`],
              UndirectedEdge[84, 230] -> 
             RGBColor[
              0.22859615804425376`, 0.3575994343110202, 0.9363295850716857], 
             UndirectedEdge[119, 237] -> 
             RGBColor[
              0.9483698835729416, 0.9591789791220269, 0.8977829179807035], 
             UndirectedEdge[67, 171] -> 
             RGBColor[
              0.25918264815811415`, 0.38974777471616917`, 0.9380714404350129],
              UndirectedEdge[25, 157] -> 
             RGBColor[
              0.3079594456965586, 0.4405872728097553, 0.9408648783928987], 
             UndirectedEdge[124, 484] -> 
             RGBColor[
              0.9777721242086441, 0.9364424046411297, 0.38854804229456463`], 
             UndirectedEdge[368, 500] -> 
             RGBColor[
              0.6137971561371982, 0.33936679556971105`, 0.5567621778131115], 
             UndirectedEdge[283, 422] -> 
             RGBColor[
              0.207613081778549, 0.3355448907518888, 0.9351346299200334], 
             UndirectedEdge[334, 369] -> 
             RGBColor[
              0.4113757512055576, 0.5307347321729735, 0.9474334769948924], 
             UndirectedEdge[42, 346] -> 
             RGBColor[
              0.22517846281523107`, 0.3540072199309242, 0.9361349523844199], 
             UndirectedEdge[112, 263] -> 
             RGBColor[
              0.2608320887293601, 0.39148144133712115`, 0.9381653736354167], 
             UndirectedEdge[146, 201] -> 
             RGBColor[
              0.28119600247616383`, 0.41288520583171645`, 0.9393250683975864],
              UndirectedEdge[16, 243] -> 
             RGBColor[
              0.6215940953786275, 0.41368682466407874`, 0.566114433864064], 
             UndirectedEdge[285, 481] -> 
             RGBColor[
              0.3163175193458222, 0.44840006950172373`, 0.9413764505174842], 
             UndirectedEdge[231, 444] -> 
             RGBColor[
              0.2648697036740537, 0.39572523064356746`, 0.938395309833401], 
             UndirectedEdge[137, 408] -> 
             RGBColor[
              0.2212925375899113, 0.34992286613722345`, 0.9359136546915492], 
             UndirectedEdge[431, 436] -> 
             RGBColor[
              0.46072987194196846`, 0.5729505557434673, 0.9507253360979548], 
             UndirectedEdge[98, 277] -> 
             RGBColor[
              0.8832681348130269, 0.9067408984138945, 0.8502742951726139], 
             UndirectedEdge[131, 391] -> 
             RGBColor[
              0.2523681386345833, 0.3825852931420795, 0.9376833641988113], 
             UndirectedEdge[52, 227] -> 
             RGBColor[
              0.8407131059122084, 0.31394434940381033`, 0.18662022224139424`],
              UndirectedEdge[27, 419] -> 
             RGBColor[
              0.5124047260338506, 0.6150322660209537, 0.9547575235151939], 
             UndirectedEdge[232, 312] -> 
             RGBColor[
              0.3303045820158528, 0.4601142095117522, 0.9422823672274991], 
             UndirectedEdge[247, 466] -> 
             RGBColor[
              0.4992597773340883, 0.6043606044932961, 0.953722705002015], 
             UndirectedEdge[253, 484] -> 
             RGBColor[
              0.9889617727140382, 0.9876413426482502, 0.6827040059696212], 
             UndirectedEdge[121, 200] -> 
             RGBColor[
              0.8641469744095227, 0.4273429033856967, 0.2064477599128205], 
             UndirectedEdge[79, 99] -> 
             RGBColor[
              0.9937251243023482, 0.9889870003070016, 0.5583966882336657], 
             UndirectedEdge[109, 300] -> 
             RGBColor[
              0.23995882574419874`, 0.3695423184984049, 0.9369766721876371], 
             UndirectedEdge[31, 397] -> 
             RGBColor[
              0.40579315804314603`, 0.5258993705649835, 0.947077759095077], 
             UndirectedEdge[70, 374] -> 
             RGBColor[
              0.2549902427614091, 0.38534129083037727`, 0.9378326891497786], 
             UndirectedEdge[240, 352] -> 
             RGBColor[
              0.24222822396059346`, 0.3719275999119933, 0.937105911058787], 
             UndirectedEdge[105, 323] -> 
             RGBColor[
              0.24262496833818112`, 0.37234460340788433`, 0.93712850506416], 
             UndirectedEdge[46, 53] -> 
             RGBColor[
              0.9470835767696775, 0.821834287485996, 0.3079282681448157], 
             UndirectedEdge[221, 223] -> 
             RGBColor[
              0.46323693275442124`, 0.5733927057392445, 0.9513629056103252], 
             UndirectedEdge[33, 159] -> 
             RGBColor[
              0.8495822086293704, 0.3506448894924134, 0.19388094901806585`], 
             UndirectedEdge[16, 454] -> 
             RGBColor[
              0.6518822537994468, 0.581257698540845, 0.5925638840512331], 
             UndirectedEdge[195, 224] -> 
             RGBColor[
              0.28455910865490164`, 0.41642004365881735`, 0.9395165923191959],
              UndirectedEdge[259, 500] -> 
             RGBColor[
              0.8406666807462297, 0.3081837142621151, 0.18636416654762122`], 
             UndirectedEdge[24, 77] -> 
             RGBColor[
              0.7218949448567346, 0.7822619477143448, 0.9732512022240677], 
             UndirectedEdge[226, 386] -> 
             RGBColor[
              0.1791759961486071, 0.30565571073945375`, 0.9335151799623065], 
             UndirectedEdge[289, 314] -> 
             RGBColor[
              0.3847232625603534, 0.5076496861015274, 0.9457352039862904], 
             UndirectedEdge[179, 325] -> 
             RGBColor[
              0.1789730287155782, 0.30544237909846184`, 0.9335036212672588], 
             UndirectedEdge[81, 83] -> 
             RGBColor[
              0.8721819244967113, 0.9009182081187621, 0.9876706846361336], 
             UndirectedEdge[312, 376] -> 
             RGBColor[
              0.2919333190231436, 0.4241708063077816, 0.9399365426905006], 
             UndirectedEdge[270, 309] -> 
             RGBColor[
              0.9915269265441726, 0.9888220703419007, 0.6489133693566129], 
             UndirectedEdge[139, 269] -> 
             RGBColor[
              0.506487260336648, 0.6101093099259678, 0.9543245288388581], 
             UndirectedEdge[269, 425] -> 
             RGBColor[
              0.4121410951718726, 0.5313976346492894, 0.947482244035659], 
             UndirectedEdge[25, 492] -> 
             RGBColor[
              0.29499729755319337`, 0.42696323326341856`, 0.9401267032319138],
              UndirectedEdge[142, 173] -> 
             RGBColor[
              0.8420436305365226, 0.8765386852966244, 0.9380905002853989], 
             UndirectedEdge[132, 209] -> 
             RGBColor[
              0.7780282420345992, 0.8243344980363514, 0.8860787195432924], 
             UndirectedEdge[389, 409] -> 
             RGBColor[
              0.23002772223876133`, 0.35910409904586005`, 0.9364111105347535],
              UndirectedEdge[337, 370] -> 
             RGBColor[
              0.7258270188663856, 0.785286025150145, 0.9737542955576297], 
             UndirectedEdge[230, 242] -> 
             RGBColor[
              0.2244428247428983, 0.35323401767475476`, 0.9360930588844796], 
             UndirectedEdge[28, 461] -> 
             RGBColor[
              0.954655789916814, 0.9657029428810652, 0.9616400993934879], 
             UndirectedEdge[318, 350] -> 
             RGBColor[
              0.3520561578815369, 0.47935508192515797`, 0.9436536849625428], 
             UndirectedEdge[390, 478] -> 
             RGBColor[
              0.2833977050944594, 0.41519933487955374`, 0.9394504521045712], 
             UndirectedEdge[167, 434] -> 
             RGBColor[
              0.988936416573675, 0.989692938179159, 0.8330157392176978], 
             UndirectedEdge[247, 269] -> 
             RGBColor[
              0.47197536116157857`, 0.5820909954323062, 0.9516076257145445], 
             UndirectedEdge[394, 398] -> 
             RGBColor[
              0.24489676758341208`, 0.3747324084550136, 0.93725788067035], 
             UndirectedEdge[14, 158] -> 
             RGBColor[
              0.33213200521333075`, 0.4619125616859979, 0.9423909174068014], 
             UndirectedEdge[131, 433] -> 
             RGBColor[
              0.29455765065289613`, 0.4253795454830047, 0.9401427329325757], 
             UndirectedEdge[87, 422] -> 
             RGBColor[
              0.2066326331143824, 0.33451437704181397`, 0.9350787948190529], 
             UndirectedEdge[210, 469] -> 
             RGBColor[
              0.8482471960053599, 0.3686686083126496, 0.19371011734270402`], 
             UndirectedEdge[312, 414] -> 
             RGBColor[
              0.2895347527456831, 0.421649761072285, 0.9397999478893602], 
             UndirectedEdge[277, 311] -> 
             RGBColor[
              0.7590792000371321, 0.8117177073753836, 0.9766215787274166], 
             UndirectedEdge[332, 424] -> 
             RGBColor[
              0.36139324266635137`, 0.48744239547023754`, 0.9442486357485711],
              UndirectedEdge[328, 433] -> 
             RGBColor[
              0.35540962848104596`, 0.48225968960811955`, 0.9438673651437858],
              UndirectedEdge[88, 428] -> 
             RGBColor[
              0.8484718113152332, 0.36067584148776255`, 0.1935446274280821], 
             UndirectedEdge[8, 162] -> 
             RGBColor[
              0.5411625228784538, 0.6383791410233868, 0.9570214426260819], 
             UndirectedEdge[27, 289] -> 
             RGBColor[
              0.47574498443284424`, 0.5848915439571711, 0.9519761681862727], 
             UndirectedEdge[192, 280] -> 
             RGBColor[
              0.25575350846358835`, 0.3861435314772083, 0.9378761560023672], 
             UndirectedEdge[347, 477] -> 
             RGBColor[
              0.2117993137193227, 0.3399448859440771, 0.9353730296360853], 
             UndirectedEdge[145, 346] -> 
             RGBColor[
              0.21927041175810352`, 0.3477974836778107, 0.9357984976168947], 
             UndirectedEdge[232, 415] -> 
             RGBColor[
              0.3216051563189196, 0.45097056152882875`, 0.9417869478037058], 
             UndirectedEdge[189, 374] -> 
             RGBColor[
              0.2557528431125027, 0.3861428321510315, 0.9378761181116072], 
             UndirectedEdge[139, 140] -> 
             RGBColor[
              0.5318346221124927, 0.6308063309644387, 0.9562871161085591], 
             UndirectedEdge[134, 251] -> 
             RGBColor[
              0.24587579480159133`, 0.37576142813523083`, 0.9373136348220843],
              UndirectedEdge[67, 281] -> 
             RGBColor[
              0.25076586641156884`, 0.38090120344576484`, 0.93759211716606], 
             UndirectedEdge[167, 495] -> 
             RGBColor[0.9144363630663, 0.657074043523211, 0.5293091727449846],
              UndirectedEdge[143, 179] -> 
             RGBColor[
              0.17892806920489446`, 0.30539512380213557`, 0.933501060889637], 
             UndirectedEdge[21, 175] -> 
             RGBColor[
              0.9683090151158134, 0.9568481859192783, 0.670037151361724], 
             UndirectedEdge[366, 473] -> 
             RGBColor[
              0.29591877827497415`, 0.42668767083692927`, 0.940224732684648], 
             UndirectedEdge[143, 292] -> 
             RGBColor[
              0.1789488167630598, 0.30541693080123855`, 0.9335022424323813], 
             UndirectedEdge[267, 486] -> 
             RGBColor[
              0.9619951023866931, 0.9628588250229391, 0.7028330719374227], 
             UndirectedEdge[248, 380] -> 
             RGBColor[
              0.257695358998007, 0.3881845395093172, 0.937986741517592], 
             UndirectedEdge[48, 407] -> 
             RGBColor[
              0.2109346093646478, 0.33903602684189116`, 0.935323786002302], 
             UndirectedEdge[436, 459] -> 
             RGBColor[
              0.4317329658175249, 0.5478348930853527, 0.9488776788806625], 
             UndirectedEdge[235, 262] -> 
             RGBColor[
              0.416563768888231, 0.5346101328045243, 0.9479348632655147], 
             UndirectedEdge[236, 283] -> 
             RGBColor[
              0.23426865806856206`, 0.3635615914938426, 0.9366526255563583], 
             UndirectedEdge[99, 493] -> 
             RGBColor[
              0.9935993972524345, 0.9887180828601909, 0.5447120747479771], 
             UndirectedEdge[109, 456] -> 
             RGBColor[
              0.23880926652767986`, 0.3683340588755796, 0.9369112064908769], 
             UndirectedEdge[208, 289] -> 
             RGBColor[
              0.3807447886449092, 0.5042037319598828, 0.9454816991464247], 
             UndirectedEdge[266, 410] -> 
             RGBColor[
              0.326592877843097, 0.45552256223454524`, 0.9420962704893343], 
             UndirectedEdge[299, 301] -> 
             RGBColor[
              0.20895952840977988`, 0.3369600915309596, 0.9352113080637927], 
             UndirectedEdge[314, 359] -> 
             RGBColor[
              0.3577633677707141, 0.48429838027845357`, 0.9440173433299934], 
             UndirectedEdge[209, 214] -> 
             RGBColor[
              0.3828653435329973, 0.49291080046599856`, 0.946830407391962], 
             UndirectedEdge[210, 326] -> 
             RGBColor[
              0.8556196126725499, 0.40214503052670025`, 0.19986184252427644`],
              UndirectedEdge[53, 317] -> 
             RGBColor[
              0.9299563150856899, 0.7479312815030192, 0.29383694306613123`], 
             UndirectedEdge[402, 459] -> 
             RGBColor[
              0.4714286755649022, 0.5800616585296188, 0.952002670562152], 
             UndirectedEdge[89, 249] -> 
             RGBColor[
              0.28752479280706156`, 0.41953716573797317`, 0.9396854836443249],
              UndirectedEdge[67, 135] -> 
             RGBColor[
              0.2536249197696536, 0.3839062497995648, 0.9377549360252124], 
             UndirectedEdge[90, 178] -> 
             RGBColor[
              0.9282272067510295, 0.7348311823756897, 0.4981717768803556], 
             UndirectedEdge[174, 229] -> 
             RGBColor[
              0.2788164534778155, 0.4103841489623319, 0.9391895566023578], 
             UndirectedEdge[266, 364] -> 
             RGBColor[
              0.2740437091478759, 0.405367692062097, 0.9389177558734103], 
             UndirectedEdge[407, 430] -> 
             RGBColor[
              0.22704868393744712`, 0.35597294090924125`, 0.9362414587105858],
              UndirectedEdge[217, 355] -> 
             RGBColor[
              0.32421328138501737`, 0.4552389817275355, 0.9418795614926734], 
             UndirectedEdge[176, 426] -> 
             RGBColor[
              0.7385594994235554, 0.7955507282121491, 0.9748396268265297], 
             UndirectedEdge[280, 483] -> 
             RGBColor[
              0.2767707745378052, 0.40823401069284493`, 0.939073058213035], 
             UndirectedEdge[51, 347] -> 
             RGBColor[
              0.1789270004053139, 0.3053940004260106, 0.9335010000230821], 
             UndirectedEdge[152, 451] -> 
             RGBColor[
              0.20772437674817806`, 0.3356618688214776, 0.9351409680039076], 
             UndirectedEdge[105, 342] -> 
             RGBColor[
              0.252946206923672, 0.38319287956555814`, 0.9377162843326995], 
             UndirectedEdge[318, 496] -> 
             RGBColor[
              0.3094159330482752, 0.43947691523709653`, 0.9410445311268166], 
             UndirectedEdge[114, 289] -> 
             RGBColor[
              0.47002476811242727`, 0.580247614655448, 0.9515258518036867], 
             UndirectedEdge[103, 331] -> 
             RGBColor[
              0.6585237003454188, 0.7308163449939742, 0.968260051050067], 
             UndirectedEdge[107, 113] -> 
             RGBColor[
              0.18193197659231264`, 0.3085524209250408, 0.9336721289714678], 
             UndirectedEdge[16, 56] -> 
             RGBColor[
              0.6202778449645745, 0.4035695471970573, 0.5648539909810746], 
             UndirectedEdge[140, 370] -> 
             RGBColor[
              0.5455387009707735, 0.6419319195433083, 0.9573659513959778], 
             UndirectedEdge[213, 500] -> 
             RGBColor[
              0.8618492799802115, 0.40436895006188167`, 0.20403944658147605`],
              UndirectedEdge[280, 327] -> 
             RGBColor[
              0.25698076875714937`, 0.3874334598585377, 0.9379460466605166], 
             UndirectedEdge[76, 238] -> 
             RGBColor[
              0.36573961104663694`, 0.49120700130641426`, 0.9445255824984202],
              UndirectedEdge[253, 261] -> 
             RGBColor[
              0.9325093316648222, 0.7680041432668934, 0.5596474808987255], 
             UndirectedEdge[232, 350] -> 
             RGBColor[
              0.3591838096222978, 0.48552869561681206`, 0.944107852628729], 
             UndirectedEdge[166, 320] -> 
             RGBColor[
              0.9133614547699682, 0.6417853106074096, 0.5113435478107814], 
             UndirectedEdge[33, 119] -> 
             RGBColor[
              0.9345308133147854, 0.7655949021985857, 0.5124594755699873], 
             UndirectedEdge[71, 228] -> 
             RGBColor[
              0.8744314209010298, 0.8983757407693698, 0.7323068273714743], 
             UndirectedEdge[50, 244] -> 
             RGBColor[
              0.3916895278498226, 0.5136835149605915, 0.9461790882505088], 
             UndirectedEdge[235, 344] -> 
             RGBColor[
              0.4103923521286693, 0.5295998986599555, 0.9474490267315575], 
             UndirectedEdge[72, 494] -> 
             RGBColor[
              0.25624399533436604`, 0.3866590642770594, 0.9379040885040477], 
             UndirectedEdge[185, 496] -> 
             RGBColor[
              0.2804171463023576, 0.4120665786107125, 0.9392807136907027], 
             UndirectedEdge[106, 370] -> 
             RGBColor[
              0.5546493379031965, 0.6493283450345659, 0.9580831741086608], 
             UndirectedEdge[51, 113] -> 
             RGBColor[
              0.17905963075308248`, 0.3055334033307651, 0.9335085531251784], 
             UndirectedEdge[422, 443] -> 
             RGBColor[
              0.5842619922483114, 0.5706803433206208, 0.6014015077150748], 
             UndirectedEdge[4, 335] -> 
             RGBColor[
              0.3005379095306292, 0.4317763657356928, 0.9404792286546308], 
             UndirectedEdge[1, 84] -> 
             RGBColor[
              0.249739891419232, 0.3798228386782472, 0.9375336894080404], 
             UndirectedEdge[90, 272] -> 
             RGBColor[
              0.8426763546129947, 0.3190239891395971, 0.18810823554711417`], 
             UndirectedEdge[213, 450] -> 
             RGBColor[
              0.8609571905590665, 0.3975119598548832, 0.20318518074431657`], 
             UndirectedEdge[5, 212] -> 
             RGBColor[
              0.22856179646777947`, 0.35756331811549596`, 0.9363276282307389],
              UndirectedEdge[50, 106] -> 
             RGBColor[
              0.47939668252268425`, 0.5878987040064534, 0.9522518873645769], 
             UndirectedEdge[115, 291] -> 
             RGBColor[
              0.7880477603543681, 0.8351660025398585, 0.9792918656511329], 
             UndirectedEdge[9, 117] -> 
             RGBColor[
              0.4781094761010015, 0.5852282777412916, 0.9525996605197433], 
             UndirectedEdge[194, 388] -> 
             RGBColor[
              0.9663440953419832, 0.9740339462184904, 0.9245637966956991], 
             UndirectedEdge[202, 211] -> 
             RGBColor[
              0.2350487330765592, 0.3643814997868598, 0.9366970496740461], 
             UndirectedEdge[113, 308] -> 
             RGBColor[
              0.17906927273157397`, 0.3055435376614964, 0.9335091022215896], 
             UndirectedEdge[51, 421] -> 
             RGBColor[
              0.17899180329589925`, 0.30546211237275633`, 0.9335046904518336],
              UndirectedEdge[109, 335] -> 
             RGBColor[
              0.2653660882581673, 0.3962469623140712, 0.938423578201131], 
             UndirectedEdge[278, 329] -> 
             RGBColor[
              0.9154608124727537, 0.9351010298249371, 0.9804756251775316], 
             UndirectedEdge[129, 206] -> 
             RGBColor[
              0.3491669657996257, 0.47685260895882275`, 0.9434695881978956], 
             UndirectedEdge[166, 227] -> 
             RGBColor[
              0.8418757895124331, 0.32288124504634075`, 0.18773360937003286`],
              UndirectedEdge[294, 411] -> 
             RGBColor[
              0.23895135352540886`, 0.3684834013190287, 0.9369192981351986], 
             UndirectedEdge[362, 384] -> 
             RGBColor[
              0.33614117025697976`, 0.4632658145057482, 0.9427239752429382], 
             UndirectedEdge[143, 308] -> 
             RGBColor[
              0.17893664305769685`, 0.3054041354650445, 0.9335015491578702], 
             UndirectedEdge[151, 310] -> 
             RGBColor[
              0.3017756973424442, 0.43451576996419494`, 0.9404970515752908], 
             UndirectedEdge[297, 397] -> 
             RGBColor[
              0.4389561312944613, 0.5528301617459719, 0.9496863711644075], 
             UndirectedEdge[114, 359] -> 
             RGBColor[
              0.443064873322788, 0.5568963088323743, 0.9498079911473898], 
             UndirectedEdge[141, 220] -> 
             RGBColor[
              0.32424804297229537`, 0.4552690904672675, 0.9418817764702763], 
             UndirectedEdge[122, 493] -> 
             RGBColor[
              0.9305407827762575, 0.7399602763410837, 0.37672867587283654`], 
             UndirectedEdge[146, 442] -> 
             RGBColor[
              0.2709392779878975, 0.40210473808065567`, 0.9387409631114438], 
             UndirectedEdge[294, 478] -> 
             RGBColor[
              0.25217734273393444`, 0.38238475455333876`, 0.9376724986545265],
              UndirectedEdge[76, 487] -> 
             RGBColor[
              0.49537833953651855`, 0.6000692782186605, 0.9537321847167134], 
             UndirectedEdge[67, 70] -> 
             RGBColor[
              0.25743661729140077`, 0.3879125855705024, 0.9379720065601748], 
             UndirectedEdge[346, 358] -> 
             RGBColor[
              0.2217544347167852, 0.3504083493035373, 0.935939959049609], 
             UndirectedEdge[149, 165] -> 
             RGBColor[
              0.3889540140770109, 0.511314150421502, 0.9460047837318252], 
             UndirectedEdge[175, 375] -> 
             RGBColor[
              0.9569658514087618, 0.9674257829593813, 0.9577297678481509], 
             UndirectedEdge[18, 428] -> 
             RGBColor[
              0.8573587081531882, 0.40102916444142644`, 0.2009600719874468], 
             UndirectedEdge[2, 47] -> 
             RGBColor[
              0.22219066917343752`, 0.3508668593763409, 0.9359648019565643], 
             UndirectedEdge[140, 466] -> 
             RGBColor[
              0.5015711187466989, 0.6062370555767975, 0.9539046622647382], 
             UndirectedEdge[199, 382] -> 
             RGBColor[
              0.31253428709090747`, 0.4426711481132517, 0.9412251688089472], 
             UndirectedEdge[305, 499] -> 
             RGBColor[
              0.2559152551896322, 0.3863135375416151, 0.9378853672391325], 
             UndirectedEdge[252, 282] -> 
             RGBColor[
              0.6717272001021579, 0.7429460920325152, 0.9682785844173988], 
             UndirectedEdge[235, 249] -> 
             RGBColor[
              0.32329479630323715`, 0.4526684377082041, 0.9418860278221313], 
             UndirectedEdge[130, 214] -> 
             RGBColor[
              0.1893670574265447, 0.316367162293171, 0.9340955458257609], 
             UndirectedEdge[100, 475] -> 
             RGBColor[
              0.8851091218155209, 0.5328997870260774, 0.22424752851506258`], 
             UndirectedEdge[10, 438] -> 
             RGBColor[
              0.22021348611856342`, 0.3487887146250221, 0.9358522043065695], 
             UndirectedEdge[39, 179] -> 
             RGBColor[
              0.40129536230508595`, 0.5053759222252174, 0.9485085964517164], 
             UndirectedEdge[400, 414] -> 
             RGBColor[
              0.28528989827003975`, 0.41718814987906533`, 0.9395582097066717],
              UndirectedEdge[41, 191] -> 
             RGBColor[
              0.22546402831064583`, 0.35430736737250323`, 0.9361512149169275],
              UndirectedEdge[25, 96] -> 
             RGBColor[
              0.3047685081778331, 0.4372333951604509, 0.9406831592217764], 
             UndirectedEdge[106, 274] -> 
             RGBColor[
              0.49029479958875166`, 0.5970824316919869, 0.9530169491141065], 
             UndirectedEdge[204, 363] -> 
             RGBColor[
              0.4533522044192463, 0.5657736996191047, 0.9504726028052438], 
             UndirectedEdge[99, 413] -> 
             RGBColor[
              0.9837287794830555, 0.9560851708017216, 0.4499899045367475], 
             UndirectedEdge[37, 118] -> 
             RGBColor[
              0.31537415178862416`, 0.44729581939211016`, 0.9413268540323092],
              UndirectedEdge[411, 478] -> 
             RGBColor[
              0.2528159536736963, 0.3830559751413007, 0.9377088666028057], 
             UndirectedEdge[300, 451] -> 
             RGBColor[
              0.21870173252116284`, 0.3471997657434399, 0.9357661121756364], 
             UndirectedEdge[122, 233] -> 
             RGBColor[
              0.8553320507775657, 0.4120002528594733, 0.20005892957140564`], 
             UndirectedEdge[97, 404] -> 
             RGBColor[
              0.2225914076005732, 0.3512880608715443, 0.9359876234171504], 
             UndirectedEdge[362, 498] -> 
             RGBColor[
              0.4251755260464191, 0.5424546669097134, 0.9483770922703834], 
             UndirectedEdge[121, 454] -> 
             RGBColor[
              0.8636741838299911, 0.42519607178708907`, 0.20605325186410173`],
              UndirectedEdge[173, 417] -> 
             RGBColor[
              0.8427978094114925, 0.8771278555657226, 0.9381656697874536], 
             UndirectedEdge[36, 352] -> 
             RGBColor[
              0.2411100918235177, 0.37075237214225454`, 0.9370422350877088], 
             UndirectedEdge[309, 337] -> 
             RGBColor[
              0.926620732552479, 0.9394372573300418, 0.7346744089406012], 
             UndirectedEdge[207, 456] -> 
             RGBColor[
              0.2203607616298221, 0.3489435105251617, 0.9358605914290611], 
             UndirectedEdge[95, 97] -> 
             RGBColor[
              0.22940871371662525`, 0.3584534818416879, 0.936375858915159], 
             UndirectedEdge[185, 350] -> 
             RGBColor[
              0.3230573711356193, 0.45194474529877393`, 0.9418898675264287], 
             UndirectedEdge[303, 435] -> 
             RGBColor[
              0.2816881021628791, 0.4134024338033765, 0.9393530927467486], 
             UndirectedEdge[14, 441] -> 
             RGBColor[
              0.3784375409652084, 0.5020200893703757, 0.9453414651985335], 
             UndirectedEdge[67, 147] -> 
             RGBColor[
              0.2540581203038455, 0.3843615710275007, 0.9377796061547718], 
             UndirectedEdge[115, 419] -> 
             RGBColor[
              0.7169294577871506, 0.7776214885576594, 0.9735615399917263], 
             UndirectedEdge[113, 209] -> 
             RGBColor[
              0.3725579164542212, 0.4820770410775821, 0.9462434146682975], 
             UndirectedEdge[100, 121] -> 
             RGBColor[
              0.8793403970281699, 0.48855884043917713`, 0.2187233911438525], 
             UndirectedEdge[39, 254] -> 
             RGBColor[
              0.43007991849913185`, 0.5356303158314321, 0.9501478343440324], 
             UndirectedEdge[2, 339] -> 
             RGBColor[
              0.21206918576719214`, 0.340228538577264, 0.9353883984499716], 
             UndirectedEdge[76, 436] -> 
             RGBColor[
              0.4421225577048329, 0.5568338353820671, 0.9495396944885663], 
             UndirectedEdge[121, 161] -> 
             RGBColor[
              0.9088989497892817, 0.5955852022276555, 0.2954383174204215], 
             UndirectedEdge[215, 430] -> 
             RGBColor[
              0.26193106415637823`, 0.3926365341899838, 0.9382279586601969], 
             UndirectedEdge[100, 254] -> 
             RGBColor[
              0.5838565510201338, 0.5654509378756822, 0.6001458285837606], 
             UndirectedEdge[186, 389] -> 
             RGBColor[
              0.22710509641847854`, 0.3560322340035631, 0.9362446713179258], 
             UndirectedEdge[197, 426] -> 
             RGBColor[
              0.7839000078483491, 0.8315135813435113, 0.9789878324723824], 
             UndirectedEdge[316, 378] -> 
             RGBColor[
              0.26678973270236006`, 0.397743302889189, 0.9385046526461347], 
             UndirectedEdge[185, 330] -> 
             RGBColor[
              0.29519715135054264`, 0.42760130102279975`, 0.9401224131131387],
              UndirectedEdge[56, 166] -> 
             RGBColor[
              0.8373970102117498, 0.28845538472768467`, 0.18344472525364075`],
              UndirectedEdge[38, 73] -> 
             RGBColor[
              0.25393957190424143`, 0.3842369691431141, 0.937772854998791], 
             UndirectedEdge[97, 430] -> 
             RGBColor[
              0.23573676666398502`, 0.3651046667110934, 0.9367362321689956], 
             UndirectedEdge[222, 372] -> 
             RGBColor[
              0.4565833875774816, 0.5694260572148426, 0.9504426196097452], 
             UndirectedEdge[137, 430] -> 
             RGBColor[
              0.22990978373834364`, 0.3589801382041882, 0.9364043941116291], 
             UndirectedEdge[30, 355] -> 
             RGBColor[
              0.29831901354920054`, 0.4290370635324922, 0.9403677718036725], 
             UndirectedEdge[111, 442] -> 
             RGBColor[
              0.2785182841132166, 0.41007075405510884`, 0.939172576298146], 
             UndirectedEdge[183, 408] -> 
             RGBColor[
              0.21373593745192992`, 0.3419804002760839, 0.9354833174926791], 
             UndirectedEdge[39, 283] -> 
             RGBColor[
              0.4024378733893724, 0.5065767738141891, 0.9485736607677728], 
             UndirectedEdge[244, 498] -> 
             RGBColor[
              0.40216527018839365`, 0.5225243398145787, 0.9469108991142803], 
             UndirectedEdge[259, 454] -> 
             RGBColor[
              0.8808615626968692, 0.5519020063430116, 0.22230030637499004`], 
             UndirectedEdge[17, 418] -> 
             RGBColor[
              0.9292223734187801, 0.9452976774305406, 0.9548682913375369], 
             UndirectedEdge[70, 391] -> 
             RGBColor[
              0.24968869542225258`, 0.3797690284394081, 0.93753077387175], 
             UndirectedEdge[18, 495] -> 
             RGBColor[
              0.8632931958328989, 0.4466442372567656, 0.2066429440915829], 
             UndirectedEdge[48, 95] -> 
             RGBColor[
              0.21729689825533816`, 0.34572319585842115`, 0.9356861089424638],
              UndirectedEdge[50, 92] -> 
             RGBColor[
              0.5250378077135244, 0.6249522255456361, 0.9558449239285502], 
             UndirectedEdge[118, 141] -> 
             RGBColor[
              0.31734549257895406`, 0.4492904482488255, 0.9414419520628983], 
             UndirectedEdge[373, 398] -> 
             RGBColor[
              0.27738327375901567`, 0.40887778620903076`, 0.9391079391375716],
              UndirectedEdge[218, 409] -> 
             RGBColor[
              0.2367642996218614, 0.3661846689991738, 0.9367947486508479]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.2206581667895666, 0.3492561022046294, 0.935877528212937], 316 -> 
             RGBColor[
              0.2504950392509415, 0.38061654692851177`, 0.937576693959915], 
             308 -> RGBColor[
              0.17894628476761076`, 0.30541426951348377`, 0.9335020982389862],
              160 -> RGBColor[
              0.42248174875901884`, 0.5403541890501141, 0.948141141338351], 
             245 -> RGBColor[
              0.22156287013367681`, 0.3502070027807943, 0.9359290497299955], 
             155 -> 
             RGBColor[
              0.5658891207695752, 0.6584533071119401, 0.9589680109885835], 
             425 -> RGBColor[
              0.37534284954540054`, 0.499524843821242, 0.9451374923637511], 
             213 -> RGBColor[
              0.90420589766789, 0.657903179238463, 0.24177939169682186`], 352 -> 
             RGBColor[
              0.2278308941861094, 0.35679509347557953`, 0.9362860044270709], 
             27 -> RGBColor[
              0.5121189165844965, 0.6148002330343991, 0.9547350235483862], 
             485 -> RGBColor[
              0.24800119075484597`, 0.3779953540399882, 0.9374346729773807], 
             454 -> RGBColor[
              0.8998824261938122, 0.6382713050470934, 0.23817178112086787`], 
             367 -> RGBColor[
              0.2298450608433424, 0.3589121103378734, 0.9364007082385077], 19 -> 
             RGBColor[
              0.5597245266210166, 0.6534486118703385, 0.9584827115555565], 
             164 -> RGBColor[
              0.8175247092939038, 0.13570817177533162`, 0.16441498745215766`],
              190 -> RGBColor[
              0.24810961844878143`, 0.3781093184210272, 0.9374408477741458], 
             103 -> RGBColor[
              0.4803557055985901, 0.589013427439692, 0.9522345072271], 138 -> 
             RGBColor[
              0.2199663924455993, 0.34852900350809307`, 0.9358381326874365], 
             416 -> RGBColor[
              0.26153368469451344`, 0.39221886318025073`, 0.938205328487714], 
             476 -> RGBColor[
              0.8484924274103163, 0.3737396233586853, 0.19406970929346942`], 
             291 -> RGBColor[
              0.6549271406176395, 0.7303533269719065, 0.9662406748008145], 28 -> 
             RGBColor[
              0.9648560740830788, 0.9733102981108331, 0.9443736789601879], 
             337 -> RGBColor[
              0.860210700141258, 0.8913726787679522, 0.9865288585702724], 195 -> 
             RGBColor[
              0.2701519252165497, 0.40127718039692006`, 0.9386961245358997], 
             114 -> RGBColor[
              0.5006784839436625, 0.605512374430953, 0.9538343907832142], 479 -> 
             RGBColor[
              0.41149067372934756`, 0.5308342722869064, 0.9474407997564864], 
             93 -> RGBColor[
              0.26928527939714464`, 0.4003662806922068, 0.9386467703385721], 
             34 -> RGBColor[
              0.5437530683305409, 0.6404822625241338, 0.9572253798535508], 
             161 -> RGBColor[
              0.9903319581123935, 0.9790495659282263, 0.41694191223350735`], 
             22 -> 
             RGBColor[
              0.4514165271362265, 0.5654160397762044, 0.9499848398305268], 
             124 -> RGBColor[
              0.9626525497894284, 0.8856804222207267, 0.30941263771645156`], 
             84 -> RGBColor[
              0.2333142933423989, 0.36255849365642656`, 0.9365982758970595], 
             46 -> RGBColor[
              0.9176548470302313, 0.7112359389100995, 0.2526013609126037], 
             241 -> RGBColor[
              0.7054821402904016, 0.7698472769484965, 0.9712795247048629], 
             185 -> RGBColor[
              0.2839447494602888, 0.41577431319265656`, 0.9394816054719256], 
             426 -> RGBColor[
              0.8701743928884773, 0.8993174569073501, 0.9874792044791957], 
             390 -> RGBColor[
              0.30075346730669683`, 0.43344134138349677`, 0.9404388370870089],
              121 -> RGBColor[
              0.8274659414661699, 0.21212083852708477`, 0.1739347226073356], 
             322 -> RGBColor[
              0.25921854913182885`, 0.38978550891579644`, 0.9380734849423552],
              488 -> RGBColor[
              0.7693643004981994, 0.8197525060252281, 0.9776467014216474], 
             126 -> RGBColor[
              0.2511378152607278, 0.38129214526915, 0.9376132991027705], 433 -> 
             RGBColor[
              0.32550625142704326`, 0.4563588873913744, 0.9419619484004228], 
             236 -> RGBColor[
              0.28732315690654525`, 0.419325233622076, 0.939674000778084], 78 -> 
             RGBColor[
              0.21942909899518986`, 0.3479642740253404, 0.9358075346202901], 
             376 -> RGBColor[
              0.2794551004482275, 0.4110554074207916, 0.9392259266025292], 
             458 -> RGBColor[
              0.2304992557221517, 0.359599710633853, 0.9364379636690613], 254 -> 
             RGBColor[
              0.23649824945009773`, 0.365905033400095, 0.9367795974871519], 
             290 -> RGBColor[
              0.2864852402250885, 0.41844453006287885`, 0.9396262826626617], 
             251 -> RGBColor[
              0.25854520282865096`, 0.38907777925853504`, 0.9380351388665158],
              165 -> RGBColor[
              0.4240332554553848, 0.5416980261695123, 0.9482400019731], 460 -> 
             RGBColor[
              0.24834625332605567`, 0.3783580366805602, 0.9374543237803367], 
             100 -> RGBColor[
              0.9312148525901699, 0.7649968423512695, 0.2635120596803694], 
             235 -> RGBColor[
              0.3570417238501652, 0.48367332858535217`, 0.9439713608175008], 
             70 -> 
             RGBColor[
              0.2582501634540876, 0.38876767416929214`, 0.9380183368106061], 
             234 -> RGBColor[
              0.38857864336543946`, 0.5109890231778194, 0.9459808654420111], 
             435 -> RGBColor[
              0.25811768357221787`, 0.3886284294137375, 0.93801079227732], 
             257 -> RGBColor[
              0.8588534332133313, 0.4519682304874997, 0.20393618366530758`], 
             135 -> RGBColor[
              0.25062676841059334`, 0.3807550026274169, 0.9375841957406814], 
             265 -> RGBColor[
              0.32101450543653715`, 0.45246836277611585`, 0.9416757383178027],
              111 -> RGBColor[
              0.27309124258507717`, 0.4043665893147275, 0.9388635143117069], 
             497 -> RGBColor[
              0.23599364281048124`, 0.36537465982794926`, 0.9367508608855244],
              481 -> RGBColor[
              0.318216697210702, 0.4500450419128276, 0.9414974644516573], 381 -> 
             RGBColor[
              0.5693048020656428, 0.6612263110627765, 0.9592369059322629], 
             182 -> RGBColor[
              0.3785866605047563, 0.5023344698355566, 0.9453441851296919], 
             188 -> RGBColor[
              0.33727714516499796`, 0.4665542439248693, 0.9427119793408126], 
             154 -> RGBColor[
              0.30954120355039927`, 0.44253076534726327`, 0.9409446696670606],
              336 -> RGBColor[
              0.22223854670063217`, 0.35091718169303304`, 0.9359675285109096],
              463 -> RGBColor[
              0.2670973610782935, 0.3980666398170606, 0.9385221716270487], 
             315 -> RGBColor[
              0.1854996162687526, 0.3123022364263995, 0.933875300773191], 368 -> 
             RGBColor[
              0.4081016499818632, 0.5278988702541217, 0.9472248541600927], 
             269 -> RGBColor[
              0.44893934079834463`, 0.5632704254773366, 0.9498269957075668], 
             208 -> RGBColor[
              0.32211852500862637`, 0.45342460903982235`, 0.9417460854686901],
              86 -> RGBColor[
              0.9151930916309041, 0.7014758990831244, 0.2506205747334791], 
             119 -> RGBColor[
              0.9906473743776302, 0.9904004632007044, 0.8046607405893015], 
             436 -> RGBColor[
              0.472919813782261, 0.5829766354800872, 0.9516491265847494], 377 -> 
             RGBColor[
              0.9811051107342013, 0.9854288030398846, 0.9168682983373343], 
             140 -> RGBColor[
              0.4996340643500339, 0.6046644675542787, 0.9537521702469687], 85 -> 
             RGBColor[
              0.21421555473578224`, 0.34248450845090483`, 0.9355106309874645],
              351 -> RGBColor[
              0.290045450304657, 0.422186536586862, 0.9398290313598343], 443 -> 
             RGBColor[
              0.9345119801701037, 0.7780688545030732, 0.2661650059247154], 
             242 -> RGBColor[
              0.22500762673968802`, 0.3538276603838957, 0.936125223522647], 
             117 -> RGBColor[
              0.38107527345035186`, 0.504489981287708, 0.9455027573459912], 
             47 -> RGBColor[
              0.23193365260590854`, 0.36110735270469657`, 0.9365196504495912],
              451 -> RGBColor[
              0.21144581794704176`, 0.3395733394744833, 0.935352898574804], 
             81 -> RGBColor[
              0.8236181467643259, 0.8621947699835874, 0.9830386281626226], 
             275 -> RGBColor[
              0.4137039619056965, 0.5327513112621616, 0.9475818285219495], 23 -> 
             RGBColor[
              0.2225015077722568, 0.35119357045200544`, 0.9359825037549226], 
             328 -> RGBColor[
              0.3853130055350487, 0.5081604918248647, 0.9457727818871488], 
             418 -> RGBColor[
              0.978473490691829, 0.9834661451211657, 0.9213229446326382], 110 -> 
             RGBColor[
              0.27171530098953856`, 0.4029203874580805, 0.9387851564733641], 
             6 -> RGBColor[
              0.8276898195746623, 0.8654414113599355, 0.9834269879500976], 
             218 -> RGBColor[
              0.23197293745711564`, 0.3611486435741187, 0.9365218876637508], 
             108 -> RGBColor[
              0.28511069510105125`, 0.41699979598632125`, 0.939548004351305], 
             297 -> RGBColor[
              0.5193642093092683, 0.6206822880650865, 0.955305399532062], 487 -> 
             RGBColor[
              0.5794313774456323, 0.6694475211532741, 0.9600341070410434], 
             464 -> RGBColor[
              0.24386676324271586`, 0.3736498085868948, 0.9371992234469022], 
             157 -> RGBColor[
              0.3025436094347634, 0.43532289426166115`, 0.9405407830329243], 
             441 -> RGBColor[
              0.4501324018566838, 0.5643037950010776, 0.9499030165032217], 
             354 -> RGBColor[
              0.3617638436367253, 0.48776339140382907`, 0.9442722501146938], 
             385 -> RGBColor[
              0.2334715870925415, 0.36272381936082626`, 0.9366072335434348], 
             270 -> RGBColor[
              0.9900230881246451, 0.9901423047916702, 0.8150067794022959], 
             392 -> 
             RGBColor[
              0.3060013924465708, 0.4389572434431762, 0.9407376986601153], 33 -> 
             RGBColor[
              0.8784142522519405, 0.5407893411964669, 0.22025821055067316`], 
             252 -> RGBColor[
              0.7357960105795031, 0.7935287028122899, 0.9743009279960564], 
             394 -> RGBColor[
              0.22864247952174482`, 0.3576481211208147, 0.9363322230113024], 
             260 -> RGBColor[
              0.28557642935408295`, 0.4174893122155148, 0.9395745272280231], 
             159 -> RGBColor[
              0.8207501650068003, 0.16050043778835987`, 0.16750368748545852`],
              183 -> RGBColor[
              0.2049673414252272, 0.33276404989092045`, 0.9349839589209338], 
             99 -> RGBColor[
              0.9936215336094609, 0.9887654302895413, 0.5471214806005384], 
             329 -> RGBColor[
              0.8825578842047201, 0.909191716742005, 0.9886603529358121], 309 -> 
             RGBColor[
              0.9930307649637, 0.9875018358921313, 0.48281995931092997`], 17 -> 
             RGBColor[
              0.8799712561457314, 0.9071292097399156, 0.9884136380424356], 
             349 -> RGBColor[
              0.41360147005439724`, 0.5326625379719564, 0.9475752978318146], 
             495 -> RGBColor[
              0.8422024713778844, 0.3253922650171049, 0.18804644029332332`], 
             347 -> RGBColor[0.178927, 0.305394, 0.933501], 340 -> 
             RGBColor[
              0.3374345618861965, 0.46669059037677707`, 0.9427220097950892], 
             404 -> RGBColor[
              0.2134483076486736, 0.3416780831160786, 0.9354669374008939], 
             277 -> RGBColor[
              0.7713015318020453, 0.8212658858432957, 0.977839786533559], 104 -> 
             RGBColor[
              0.24657366739272524`, 0.3764949364761905, 0.9373533776337394], 
             79 -> RGBColor[
              0.9938287149952354, 0.9892085703244617, 0.5696718958667929], 
             327 -> RGBColor[
              0.2570691600545971, 0.38752636471648727`, 0.9379510804141431], 
             191 -> RGBColor[
              0.21840138119578575`, 0.34688407745709465`, 0.9357490076119863],
              50 -> RGBColor[
              0.44093802683048844`, 0.5563400894761129, 0.9493171590568191], 
             225 -> RGBColor[
              0.27424929290791517`, 0.4055837736286615, 0.9389294635644105], 
             405 -> RGBColor[
              0.9940126833910108, 0.9896020601209673, 0.5896957204256101], 61 -> 
             RGBColor[
              0.3238266917401457, 0.45490413720770817`, 0.94185492834235], 
             196 -> RGBColor[
              0.29569933477919436`, 0.42812912764658106`, 0.9401510117164867],
              1 -> RGBColor[
              0.2661654894960651, 0.39708718370006774`, 0.9384691029190212], 
             263 -> RGBColor[
              0.2734006518561467, 0.40469179807630246`, 0.9388811347119643], 
             201 -> RGBColor[
              0.3044587746178886, 0.4373358542976118, 0.9406498488568703], 
             371 -> RGBColor[
              0.36294391873403165`, 0.48878551314081686`, 0.9443474434563948],
              293 -> RGBColor[
              0.9542723127115095, 0.9654169462092355, 0.962289226275195], 362 -> 
             RGBColor[
              0.38846154058520777`, 0.5108875946353395, 0.9459734037564047], 
             184 -> RGBColor[
              0.2570318728012019, 0.3874871734490205, 0.9379489569602237], 
             106 -> RGBColor[
              0.5178553382148801, 0.619457318536794, 0.9551866156723348], 206 -> 
             RGBColor[
              0.3427341577200499, 0.4712808339226293, 0.9430596953553738], 
             358 -> RGBColor[
              0.22562621270692998`, 0.3544778334560826, 0.9361604510783655], 
             247 -> RGBColor[
              0.4950113815248125, 0.6009115653872759, 0.9533882557215221], 
             220 -> RGBColor[
              0.3389132056188999, 0.46797131725924984`, 0.9428162276662237], 
             407 -> RGBColor[
              0.21435834209939697`, 0.3426345870233057, 0.9355187625165873], 
             107 -> RGBColor[
              0.18467169248908813`, 0.3114320360405726, 0.9338281517387427], 
             375 -> RGBColor[
              0.9582014383733062, 0.9683472816944506, 0.9556382414098691], 
             131 -> RGBColor[
              0.263609049878749, 0.394400203574635, 0.9383235174647285], 411 -> 
             RGBColor[
              0.23958996446517072`, 0.3691546219069906, 0.9369556660834778], 
             462 -> RGBColor[
              0.46387836533310084`, 0.575636380316448, 0.9509373506429145], 
             127 -> RGBColor[
              0.22597981130456574`, 0.35484948800164373`, 0.9361805879953986],
              210 -> RGBColor[
              0.8360637140310553, 0.2782070860287545, 0.182167959325265], 357 -> 
             RGBColor[
              0.9071422836282599, 0.6695571281253704, 0.2441427056377997], 
             181 -> RGBColor[
              0.4206971967779904, 0.5388084998183378, 0.9480274312641372], 
             194 -> 
             RGBColor[
              0.9865160895376739, 0.9886920707502049, 0.8731268218098209], 
             440 -> RGBColor[
              0.28167383897512416`, 0.41338744228870766`, 0.9393522804793065],
              490 -> RGBColor[
              0.9905535588776926, 0.9903616680805318, 0.806215506209998], 118 -> 
             RGBColor[
              0.32510810483221725`, 0.45601403282236586`, 0.9419365788514676],
              348 -> RGBColor[
              0.9599116097125079, 0.876434587737939, 0.29876460310071706`], 
             276 -> RGBColor[
              0.6195401563438858, 0.7020096347427746, 0.9631916170392121], 
             305 -> RGBColor[
              0.2511118726659751, 0.3812648779572094, 0.9376118217103779], 
             343 -> RGBColor[
              0.29288750827080284`, 0.425173719706164, 0.9399908823565584], 
             280 -> RGBColor[
              0.25689237745970156`, 0.38734055500058817`, 0.9379410129068901],
              474 -> RGBColor[
              0.9930971542734537, 0.9914135101440991, 0.7640615478883636], 
             189 -> RGBColor[
              0.2597753641562747, 0.39037075681060074`, 0.9381051947342635], 
             168 -> RGBColor[
              0.9107922199972238, 0.6840279095591187, 0.24707953011528597`], 
             363 -> RGBColor[
              0.40481135748628755`, 0.5250489842693634, 0.9470151996317661], 
             41 -> RGBColor[
              0.23252667542550592`, 0.36173065728791187`, 0.9365534222218687],
              14 -> RGBColor[
              0.30674268007373295`, 0.4397363837396738, 0.9407799138938453], 
             77 -> RGBColor[
              0.606817875551374, 0.6916811140631951, 0.9621900724919755], 51 -> 
             RGBColor[
              0.17892700081062782`, 0.30539400085202123`, 0.9335010000461641],
              438 -> RGBColor[
              0.22146455698209894`, 0.3501036694250721, 0.9359234509414543], 
             179 -> RGBColor[
              0.178929137062006, 0.30539624618766587`, 0.9335011217025198], 
             467 -> RGBColor[
              0.7068391686146014, 0.7709073977891587, 0.9714147806060683], 
             223 -> RGBColor[
              0.38986378476733635`, 0.5121021480670574, 0.9460627535157341], 
             456 -> RGBColor[
              0.22365852866224617`, 0.35240967276674573`, 0.9360483943829485],
              323 -> RGBColor[
              0.23934466612723454`, 0.36889679780100676`, 0.9369416967060188],
              500 -> RGBColor[
              0.8194926622925333, 0.15083472088530037`, 0.16629950146613023`],
              478 -> 
             RGBColor[
              0.2660419428822219, 0.39695732837561076`, 0.9384620671221336], 
             292 -> RGBColor[
              0.1789706321783367, 0.30543986018587177`, 0.9335034847880083], 
             491 -> RGBColor[
              0.9941614319695004, 0.9899202182895682, 0.6058860852243823], 
             396 -> RGBColor[
              0.9935460613341791, 0.9886040027241311, 0.5389067891970045], 
             321 -> RGBColor[
              0.3331754530775283, 0.46300156439574175`, 0.942450623147983], 
             143 -> RGBColor[
              0.17892700134778292`, 0.3053940014166053, 0.9335010000767543], 
             112 -> RGBColor[
              0.24826352560257345`, 0.3782710845979398, 0.937449612558869], 
             197 -> RGBColor[
              0.6976256228082208, 0.7637097057796726, 0.9704964604655693], 
             421 -> RGBColor[
              0.17905660578117066`, 0.3055302238934915, 0.9335083808575031], 
             54 -> RGBColor[
              0.22872079714307936`, 0.35773043790646125`, 0.9363366830839769],
              71 -> RGBColor[
              0.755781538403036, 0.8091415490436711, 0.97629289863413], 177 -> 
             RGBColor[
              0.20869655844004803`, 0.3366836934195124, 0.9351963323130457], 
             158 -> RGBColor[
              0.3575213303529286, 0.48408873963232213`, 0.9440019209197574], 
             226 -> RGBColor[
              0.1794249922972142, 0.30591742147890744`, 0.9335293599246128], 
             432 -> RGBColor[
              0.898624468927386, 0.9220027752840345, 0.9901927981294695], 350 -> 
             RGBColor[
              0.3621699928109498, 0.4881151774048913, 0.9442981295809318], 
             203 -> RGBColor[
              0.5345666356633387, 0.6330243026408235, 0.956502190222977], 475 -> 
             RGBColor[
              0.839003391040872, 0.30080273170088523`, 0.1849829973497558], 
             115 -> RGBColor[
              0.9211683800910966, 0.9399786781078106, 0.9923430565014513], 
             173 -> RGBColor[
              0.984562956112485, 0.9878843998856498, 0.9054952972124768], 212 -> 
             RGBColor[
              0.21851625165510197`, 0.3470048135930438, 0.9357555493147087], 
             129 -> RGBColor[
              0.35559977387920144`, 0.4824243839950162, 0.9438794810404173], 
             279 -> RGBColor[
              0.2785602236563872, 0.4101148351741018, 0.9391749646930856], 26 -> 
             RGBColor[
              0.3866295369467384, 0.5093008051628776, 0.9458566701045386], 40 -> 
             RGBColor[
              0.3862001571816754, 0.5089288979916344, 0.9458293104055944], 
             146 -> RGBColor[
              0.257933230334439, 0.3884345573658211, 0.9380002879383026], 386 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 192 -> 
             RGBColor[
              0.2546146394674752, 0.38494650795382845`, 0.9378112990978443], 
             300 -> RGBColor[
              0.22595764709528393`, 0.3548261920123965, 0.936179325776469], 
             221 -> RGBColor[
              0.5366100807415061, 0.6346832634114314, 0.9566630577049163], 62 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 286 -> 
             RGBColor[
              0.22310026486080187`, 0.3518229021154584, 0.9360166020853335], 
             472 -> RGBColor[
              0.32844671668737896`, 0.45890577060779597`, 0.9421493122466601],
              152 -> RGBColor[
              0.20400293554931437`, 0.33175039816847185`, 0.9349290374330113],
              64 -> RGBColor[
              0.2878344487965492, 0.41986263381624833`, 0.9397031180948312], 
             307 -> RGBColor[
              0.46980956787155936`, 0.580451597734798, 0.9514042766334527], 
             37 -> RGBColor[
              0.305640198745031, 0.4385776059618545, 0.9407171292131508], 148 -> 
             RGBColor[
              0.23965584235908116`, 0.3692238637503902, 0.9369594177320785], 
             261 -> RGBColor[
              0.8799868165294279, 0.5479299882988189, 0.2215703967308864], 
             387 -> RGBColor[
              0.7751138064478154, 0.8242440637709316, 0.9782197584425172], 15 -> 
             RGBColor[
              0.23423879357827926`, 0.36353020202103736`, 0.9366509248178173],
              136 -> RGBColor[
              0.968960662006962, 0.9763714930638193, 0.9374256822530368], 198 -> 
             RGBColor[
              0.2818794421164257, 0.41360354422620765`, 0.9393639892740411], 
             63 -> RGBColor[
              0.41933559472005666`, 0.5376291485518648, 0.9479406711850231], 
             444 -> RGBColor[
              0.27129304719779485`, 0.4024765719505212, 0.9387611097445928], 
             310 -> RGBColor[
              0.29675707084929953`, 0.4292408753206019, 0.9402112482208989], 
             171 -> RGBColor[
              0.26174222518751433`, 0.39243805246062563`, 0.9382172045602823],
              395 -> RGBColor[
              0.26498757281889074`, 0.39584911858812655`, 0.9384020223068277],
              311 -> RGBColor[
              0.746856868272219, 0.8021695289074716, 0.9754033709212744], 353 -> 
             RGBColor[
              0.6396625402707171, 0.7183458925176417, 0.9647757248126534], 59 -> 
             RGBColor[
              0.2421911048281961, 0.37188858535035474`, 0.9371037971791099], 
             397 -> RGBColor[
              0.3585480532796543, 0.48497803542685713`, 0.944067342796753], 
             229 -> RGBColor[
              0.2909757990296596, 0.42316439208435586`, 0.9398820133433956], 
             102 -> RGBColor[
              0.2765375568294345, 0.40798888409449063`, 0.939059776809558], 
             453 -> RGBColor[
              0.2843068325272902, 0.41615488545346746`, 0.9395022255669375], 
             299 -> RGBColor[
              0.2091663766185125, 0.3371775021132715, 0.9352230877632756], 
             128 -> RGBColor[
              0.49474321248409076`, 0.6006938536791404, 0.9533671444723009], 
             12 -> RGBColor[
              0.27240341106773047`, 0.40364363477895904`, 0.9388243433243495],
              222 -> RGBColor[
              0.4427137030371586, 0.5578780909582495, 0.9494303035745394], 
             483 -> RGBColor[
              0.29664917161590876`, 0.42912746638510174`, 0.9402051035191799],
              92 -> RGBColor[
              0.6091375885965603, 0.6935643616151592, 0.9623726888002815], 
             271 -> RGBColor[
              0.2558053195227897, 0.38619798818543977`, 0.9378791065655412], 
             361 -> RGBColor[
              0.6442014475594858, 0.7219743340365904, 0.9651716379540781], 
             344 -> RGBColor[
              0.4637429804071734, 0.5755264687345587, 0.9509266926456142], 
             132 -> RGBColor[
              0.9901329118562932, 0.9901877197270478, 0.8131867159541827], 80 -> 
             RGBColor[
              0.7895429134572223, 0.8355161918319554, 0.9796579169815435], 
             324 -> RGBColor[
              0.369677449943029, 0.49461775943693126`, 0.9447764981108042], 
             244 -> RGBColor[
              0.3424410288691568, 0.4710269404450701, 0.9430410174441985], 
             150 -> RGBColor[
              0.8214446559981496, 0.16583859987576455`, 0.16816873284309014`],
              125 -> RGBColor[
              0.20867358600249122`, 0.3366595479311035, 0.9351950240667115], 
             258 -> RGBColor[
              0.3734224424883788, 0.497861483750915, 0.945015125724227], 133 -> 
             RGBColor[
              0.3451736656290086, 0.4733938130601367, 0.9432151386421606], 
             469 -> RGBColor[
              0.8604306779796645, 0.4591301305965446, 0.20525227536014304`], 
             255 -> 
             RGBColor[
              0.3975855258515599, 0.5187903320882202, 0.9465547760295533], 
             408 -> RGBColor[
              0.2225045334786326, 0.3511967506612473, 0.9359826760644245], 
             326 -> RGBColor[
              0.8751755113140446, 0.526082975024646, 0.21755572572328788`], 
             176 -> RGBColor[
              0.6069446059586334, 0.6917839995169481, 0.9622000491738637], 
             230 -> RGBColor[
              0.2238780227461086, 0.35264037496561385`, 0.936060894246312], 
             274 -> RGBColor[
              0.4627342609626232, 0.5747075448471798, 0.9508472825558781], 87 -> 
             RGBColor[
              0.1792532619022457, 0.3057369219454596, 0.9335195801326717], 
             439 -> RGBColor[
              0.8609124841587944, 0.891932262294116, 0.986595795356355], 130 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 35 -> 
             RGBColor[
              0.23837242809378653`, 0.36787491398440125`, 0.9368863291883112],
              379 -> RGBColor[
              0.3092991992760449, 0.442321153408306, 0.9409292493686947], 31 -> 
             RGBColor[
              0.4530382628066378, 0.5668207057031098, 0.9500881753934008], 18 -> 
             RGBColor[
              0.8843839202879132, 0.5678962094964264, 0.22523944788984251`], 
             24 -> RGBColor[
              0.8369720141620951, 0.8728427813654944, 0.9843123319561599], 
             151 -> RGBColor[
              0.30679432383558886`, 0.439790664607788, 0.9407828549296829], 
             137 -> RGBColor[
              0.22008054170119, 0.3486489816131997, 0.9358446333186737], 330 -> 
             RGBColor[
              0.3064495532407965, 0.43942828885294294`, 0.9407632207543519], 
             296 -> RGBColor[
              0.3134198204339392, 0.44589022834683273`, 0.9411918117051534], 
             266 -> RGBColor[
              0.28952074326414307`, 0.421635036218934, 0.9397991500701115], 
             302 -> RGBColor[
              0.19014935834156865`, 0.31718941015560403`, 0.934140096705561], 
             442 -> RGBColor[
              0.28394532564135605`, 0.4157749187954902, 0.9394816382845851], 
             283 -> RGBColor[
              0.18121415923057888`, 0.3077979493656092, 0.9336312503346327], 
             388 -> RGBColor[
              0.9461721011462925, 0.9593758216867757, 0.9760007715815773], 
             284 -> RGBColor[
              0.24509263407936946`, 0.37493827656091794`, 0.9372690349775362],
              417 -> RGBColor[
              0.7010326627105, 0.7663713112457954, 0.9708360423624304], 318 -> 
             RGBColor[
              0.341942322952124, 0.4705949864454246, 0.9430092403441536], 413 -> 
             RGBColor[
              0.97383602535665, 0.9234049113139019, 0.35285832847295656`], 
             238 -> RGBColor[
              0.32015392046586916`, 0.45172296732878153`, 0.9416209026044572],
              72 -> RGBColor[
              0.2539844574642687, 0.3842841467126117, 0.9377754111650324], 
             437 -> RGBColor[
              0.2558304623203871, 0.3862244148598601, 0.9378805384106689], 
             288 -> RGBColor[
              0.2560659100008252, 0.3864718853002457, 0.9378939468077562], 
             382 -> RGBColor[
              0.28222469603460637`, 0.4139664279845783, 0.9393836509739241], 
             461 -> RGBColor[
              0.944455505750549, 0.9580955876512972, 0.9789065198267879], 389 -> 
             RGBColor[
              0.2184997826909155, 0.34698750366749115`, 0.9357546114315619], 
             172 -> RGBColor[
              0.3516524550010693, 0.4790054147807936, 0.9436279613719797], 
             447 -> RGBColor[
              0.2464999471451923, 0.3764174518218997, 0.9373491793747017], 
             243 -> RGBColor[
              0.8393061093521738, 0.30312955729356095`, 0.18527288074652987`],
              410 -> RGBColor[
              0.36366501242205085`, 0.4894100882501565, 0.9443933909085572], 
             88 -> RGBColor[
              0.8666101266120032, 0.4871895635890985, 0.21040855877111306`], 
             273 -> RGBColor[
              0.2935414156904733, 0.42586101786436276`, 0.9400281214167392], 
             477 -> RGBColor[
              0.24467162743864543`, 0.3744957718881542, 0.9372450592721705], 
             202 -> RGBColor[
              0.23905706042934927`, 0.3685945059772749, 0.9369253179869986], 
             393 -> RGBColor[
              0.4612114846587171, 0.5734712864433781, 0.9507274040271213], 98 -> 
             RGBColor[
              0.9952347378240085, 0.9922159109844932, 0.7227088038116687], 30 -> 
             RGBColor[
              0.2679312243382506, 0.39894308297325987`, 0.938569658906113], 
             116 -> RGBColor[
              0.24872594858728536`, 0.3787571204741826, 0.9374759468637549], 
             373 -> RGBColor[
              0.293615491872952, 0.425938876628849, 0.9400323399457455], 434 -> 
             RGBColor[
              0.9912025783926344, 0.990630054329001, 0.7954595732387495], 401 -> 
             RGBColor[
              0.7734523776791622, 0.8229461429895335, 0.9780541627497925], 
             240 -> RGBColor[
              0.2566255537350775, 0.38706010634840704`, 0.9379258176905032], 
             480 -> RGBColor[
              0.35354723518652786`, 0.48064657814301665`, 0.9437486950899088],
              403 -> RGBColor[
              0.9289119756027943, 0.9461532109745376, 0.9930816475541463], 
             317 -> RGBColor[
              0.8834003236622562, 0.5634299269441462, 0.22441871075523476`], 
             429 -> RGBColor[
              0.29359796730781346`, 0.4259204571997668, 0.9400313419476861], 
             391 -> RGBColor[
              0.2411272273904176, 0.370770382709524, 0.937043210932894], 73 -> 
             RGBColor[
              0.24791046842011605`, 0.37789999911405875`, 0.9374295064746294],
              303 -> RGBColor[
              0.3052585207535403, 0.43817643819301544`, 0.9406953932161773], 
             449 -> RGBColor[
              0.7283027762348872, 0.7876749311915857, 0.9735540724248413], 29 -> 
             RGBColor[
              0.40962031041891445`, 0.5292142575946026, 0.9473216218602429], 
             360 -> RGBColor[
              0.5793663225363243, 0.6693947066472076, 0.9600289856802787], 
             320 -> RGBColor[
              0.9886024976405045, 0.9895548541189678, 0.8385496400948322], 
             482 -> RGBColor[
              0.35848143845973107`, 0.48492033701799786`, 0.9440630981593326],
              75 -> RGBColor[
              0.3449485107481652, 0.47319879521896346`, 0.9432007919722498], 
             200 -> RGBColor[
              0.9008280073528754, 0.6425649682443086, 0.23896079721830538`], 
             301 -> RGBColor[
              0.20875268020104726`, 0.3367426809486477, 0.9351995283643099], 
             156 -> RGBColor[
              0.46730916543215706`, 0.578421658392645, 0.9512074357941471], 
             25 -> RGBColor[
              0.3133752819583538, 0.4458516513578495, 0.941188973752873], 38 -> 
             RGBColor[
              0.25996867538836677`, 0.3905739391721695, 0.9381162035229527], 
             365 -> RGBColor[
              0.2169746648251472, 0.34538450809251103`, 0.9356677582253161], 
             380 -> RGBColor[
              0.27285106149406285`, 0.4041141437597107, 0.9388498363538897], 
             370 -> RGBColor[
              0.591443337591513, 0.6791993715323379, 0.960979732544987], 3 -> 
             RGBColor[
              0.46166603367100856`, 0.5738403098087559, 0.9507631877904368], 
             57 -> 
             RGBColor[
              0.6012429877716181, 0.6871551690177569, 0.9617511969044663], 
             227 -> RGBColor[
              0.8456311671254343, 0.35174672299683013`, 0.19132976321333509`],
              494 -> RGBColor[
              0.2585035332044634, 0.3890339818415072, 0.938032765843063], 39 -> 
             RGBColor[
              0.6236615875481659, 0.7053555982627691, 0.963516071200913], 424 -> 
             RGBColor[
              0.3205944320155112, 0.4521045162923272, 0.9416489716108714], 
             109 -> RGBColor[
              0.25396000439311356`, 0.38425844498441336`, 0.9377740185988052],
              465 -> RGBColor[
              0.28262558218412137`, 0.4143877847453685, 0.939406480847081], 
             256 -> RGBColor[
              0.2893861381019995, 0.4214935576590608, 0.939791484505258], 457 -> 
             RGBColor[
              0.22158907133489145`, 0.35023454190452297`, 0.9359305418496434],
              339 -> RGBColor[
              0.21169068579341777`, 0.33983071110654267`, 0.9353668434364056],
              420 -> RGBColor[
              0.96864282965107, 0.9761344542131977, 0.9379636895276074], 287 -> 
             RGBColor[
              0.20981171601903448`, 0.33785579474010136`, 0.9352598388874411],
              239 -> RGBColor[
              0.3509305166159243, 0.47838010803725933`, 0.9435819600964633], 
             427 -> RGBColor[
              0.2795001276110678, 0.4111027338238238, 0.9392284908328413], 
             285 -> RGBColor[
              0.3144183414809424, 0.4467550970906198, 0.941255436583311], 345 -> 
             RGBColor[
              0.6597251945044771, 0.7341016031348642, 0.9667188999718916], 
             366 -> RGBColor[
              0.2650062967491503, 0.3958687986259951, 0.9384030886069564], 
             216 -> RGBColor[
              0.26588598144981995`, 0.39679340302163035`, 0.9384531853492826],
              21 -> RGBColor[
              0.9808877657874093, 0.9471920876142448, 0.3802530084370154], 
             355 -> RGBColor[
              0.32870680276015046`, 0.45913104409172456`, 0.942165884701232], 
             175 -> RGBColor[
              0.9557302644442173, 0.966504284224312, 0.9598212942864327], 7 -> 
             RGBColor[
              0.8386821070512293, 0.8742063630160551, 0.9844754421425435], 13 -> 
             RGBColor[
              0.29661626096016863`, 0.4290928751992627, 0.9402032293060224], 
             294 -> RGBColor[
              0.23831274258564697`, 0.36781218073106675`, 0.9368829301869194],
              412 -> 
             RGBColor[
              0.2423814866745967, 0.372088688741828, 0.9371146391436176], 193 -> 
             RGBColor[
              0.2878117179623051, 0.41983874226823964`, 0.9397018236074483], 
             60 -> RGBColor[
              0.29270959820985176`, 0.42498672495195505`, 0.9399807506417815],
              65 -> RGBColor[
              0.9854648277298144, 0.9626315922912277, 0.39803402977763763`], 
             448 -> RGBColor[
              0.5679393142918087, 0.6601177465734548, 0.9591294097327601], 69 -> 
             RGBColor[
              0.9094625081980608, 0.9306447336077317, 0.9912265399903383], 
             217 -> RGBColor[
              0.31971976000988434`, 0.4513469193633465, 0.9415932382841149], 
             214 -> RGBColor[
              0.19980711485308938`, 0.32734032458634205`, 0.9346900916515217],
              170 -> RGBColor[
              0.29668056881803306`, 0.42916046683523196`, 0.9402068915433929],
              359 -> RGBColor[
              0.38545126270191343`, 0.5082802432337956, 0.9457815915115654], 
             74 -> RGBColor[
              0.2817340129849886, 0.4134506889883278, 0.9393557073001488], 
             246 -> RGBColor[
              0.29422140859812795`, 0.42657573352434824`, 0.9400668460068708],
              264 -> RGBColor[
              0.23478619087952063`, 0.36410555129163547`, 0.9366820982843213],
              278 -> RGBColor[
              0.9483637407407871, 0.9610103429078694, 0.9722908974192511], 45 -> 
             RGBColor[
              0.28278247170568477`, 0.41455268557990177`, 0.9394154154732368],
              492 -> RGBColor[
              0.2766193131480329, 0.4080748151689876, 0.9390644327109545], 
             306 -> RGBColor[
              0.8575795140998795, 0.443586953641446, 0.20277151376979163`], 
             237 -> RGBColor[
              0.906092392768253, 0.9279574950433493, 0.9909050953721057], 228 -> 
             RGBColor[
              0.9930813033990235, 0.9876099324950685, 0.48832075610881853`], 
             180 -> RGBColor[
              0.27013094278236094`, 0.4012551265282246, 0.9386949296173133], 
             383 -> RGBColor[
              0.32894252042405586`, 0.45933521088468515`, 0.942180904422339], 
             53 -> RGBColor[
              0.9765123065091236, 0.9324326360618924, 0.36325517537702773`], 
             304 -> RGBColor[
              0.3385640468354945, 0.4676688934702948, 0.9427939795772942], 48 -> 
             RGBColor[
              0.20751087662989864`, 0.3354374666604766, 0.9351288094880167], 
             5 -> 
             RGBColor[
              0.23860734128045696`, 0.3681218226379481, 0.9368997071467691], 
             101 -> RGBColor[
              0.5208327276256995, 0.6218744973903617, 0.9554210066732913], 
             333 -> RGBColor[
              0.3786491349611119, 0.5023885820695944, 0.9453481659468069], 
             267 -> RGBColor[
              0.9890626064851881, 0.9747677448317271, 0.41201072085875556`], 
             120 -> RGBColor[
              0.20742150462258202`, 0.3353435310142743, 0.9351237198844141], 
             147 -> RGBColor[
              0.25149316947897704`, 0.3816656450832887, 0.9376335359998004], 
             89 -> RGBColor[
              0.28550171685781406`, 0.4174107846448903, 0.9395702724618878], 
             43 -> RGBColor[
              0.2931478124699098, 0.42544731592366486`, 0.940005706295612], 
             199 -> RGBColor[
              0.3428438781472085, 0.4713758682419251, 0.9430666866439704], 
             268 -> RGBColor[
              0.40965477924277666`, 0.5292441127573786, 0.9473238181832199], 
             169 -> RGBColor[
              0.4927421843014464, 0.5990693288551774, 0.9532096162037554], 20 -> 
             RGBColor[
              0.8845340276069948, 0.5685778117739207, 0.22536470111635126`], 
             4 -> RGBColor[
              0.32430364693803726`, 0.45531725182765653`, 0.9418853195058047],
              167 -> RGBColor[
              0.9866702547547157, 0.9887558220293171, 0.870571905196646], 431 -> 
             RGBColor[
              0.4485399301016759, 0.5629244760068475, 0.9498015456111601], 
             142 -> RGBColor[
              0.6995243049605603, 0.765192970707599, 0.9706857033583209], 16 -> 
             RGBColor[
              0.4038820814050813, 0.5242440920345965, 0.9469559869815982], 
             414 -> RGBColor[
              0.2746579678933065, 0.4060133169497984, 0.9389527370002482], 
             281 -> RGBColor[
              0.24490866169442368`, 0.374744909919817, 0.9372585580223763], 
             289 -> RGBColor[
              0.439371052281192, 0.5549828548799431, 0.9492173128241592], 398 -> 
             RGBColor[
              0.26115105564507934`, 0.3918166957892125, 0.9381835383293976], 
             178 -> RGBColor[
              0.9916846362160958, 0.9908293976273234, 0.7874706275783359], 58 -> 
             RGBColor[
              0.31511174381280593`, 0.44735568733906544`, 0.9412996195667458],
              186 -> RGBColor[
              0.23571041014604155`, 0.365076964339635, 0.9367347312042897], 
             122 -> 
             RGBColor[
              0.867504304657107, 0.49124981725132677`, 0.21115468285025726`], 
             249 -> RGBColor[
              0.2895478687563091, 0.421663546831056, 0.9398006948267619], 113 -> 
             RGBColor[
              0.17919226069553715`, 0.305672805809509, 0.9335161062041928], 
             52 -> RGBColor[
              0.8357950446989824, 0.2761419758107905, 0.18191068126945342`], 
             409 -> RGBColor[
              0.24155566178660715`, 0.3712206944242289, 0.937067609637945], 
             187 -> RGBColor[
              0.26462809617956273`, 0.3954712858480575, 0.938381550644016], 
             259 -> RGBColor[
              0.8618406991999262, 0.46553270763892984`, 0.20642883162911219`],
              42 -> RGBColor[
              0.23247426890382172`, 0.3616755747108564, 0.9365504377479873], 
             134 -> RGBColor[
              0.2332063867745317, 0.36244507701192663`, 0.9365921307776528], 
             470 -> RGBColor[
              0.25548210733168075`, 0.3858582716797478, 0.937860700109407], 
             313 -> RGBColor[
              0.266957894870447, 0.3979200519899457, 0.9385142292328336], 248 -> 
             RGBColor[
              0.24253965650195108`, 0.3722549352589237, 0.9371236466812941], 
             174 -> RGBColor[
              0.2666571079259713, 0.3976039058403079, 0.93849709986132], 215 -> 
             RGBColor[
              0.28412310253725925`, 0.4159617735847908, 0.9394917624158093], 
             399 -> RGBColor[
              0.24150095424043594`, 0.3711631933245442, 0.9370644941241232], 
             422 -> RGBColor[
              0.23401200432651914`, 0.3632918321381684, 0.9366380095054342], 
             83 -> RGBColor[
              0.9207457022290968, 0.9396416462539369, 0.9923027411096448], 95 -> 
             RGBColor[
              0.22708291988077767`, 0.3560089250563658, 0.936243408396911], 
             166 -> RGBColor[
              0.8381204118994321, 0.2940157670958513, 0.18413745552673064`], 
             384 -> RGBColor[
              0.28382079992875175`, 0.41564403437615693`, 0.9394745467294715],
              233 -> RGBColor[
              0.8431597968980244, 0.3327506884676198, 0.18896317629255405`], 
             295 -> RGBColor[
              0.22958788287780074`, 0.3586417999900643, 0.9363860623338308], 
             499 -> RGBColor[
              0.2607186377132893, 0.3913621971260208, 0.9381589127678872], 
             141 -> RGBColor[
              0.30958288032569087`, 0.4425668636752852, 0.9409473252743288], 
             319 -> 
             RGBColor[
              0.7148896845747944, 0.7771965220434489, 0.9722171808006315], 
             205 -> RGBColor[
              0.9938265629209484, 0.98920396725517, 0.5694376558617151], 468 -> 
             RGBColor[
              0.4783770236668791, 0.5874070443089239, 0.952078738137285], 486 -> 
             RGBColor[
              0.9349275982881982, 0.9509499052141509, 0.9936554230160899], 
             224 -> RGBColor[
              0.29896629209325354`, 0.43156290692071464`, 0.9403370601024921],
              231 -> RGBColor[
              0.2584463601503126, 0.3889738893366137, 0.9380295099222091], 
             332 -> RGBColor[
              0.40219205331719154`, 0.5227802746481479, 0.946848299886271], 
             68 -> RGBColor[
              0.8199864588949732, 0.15463025795470559`, 0.16677236165029033`],
              484 -> RGBColor[
              0.9928916986278599, 0.9872043870615327, 0.4676834468726777], 10 -> 
             RGBColor[
              0.2189624152550279, 0.3474737598249721, 0.9357809576716846], 
             250 -> RGBColor[
              0.20444533477183996`, 0.332215387801077, 0.934954231414263], 
             282 -> RGBColor[
              0.6076583896248129, 0.6923634812527404, 0.9622562408387412], 
             374 -> RGBColor[
              0.2517303220687306, 0.38191490749146234`, 0.937647041488951], 
             232 -> RGBColor[
              0.3561976264336458, 0.4829422138287328, 0.9439175756765262], 
             489 -> RGBColor[
              0.9900975943251971, 0.9901731150203205, 0.8137720188432849], 
             253 -> RGBColor[
              0.9850318468002165, 0.9880782982349678, 0.8977245650665646], 
             459 -> RGBColor[
              0.3905461178527888, 0.5126931506906183, 0.9461062311765757], 
             415 -> RGBColor[
              0.2870126862041934, 0.4189989092289247, 0.9396563199308854], 55 -> 
             RGBColor[
              0.21147766438726034`, 0.339606812102334, 0.9353547121824619], 
             446 -> RGBColor[
              0.22815127331601265`, 0.3571318322543179, 0.9363042495445604], 
             325 -> RGBColor[
              0.1790169203691504, 0.30548851200925775`, 0.9335061208319979], 
             91 -> RGBColor[
              0.3276288460270304, 0.4581973721491767, 0.9420971982513973], 
             450 -> RGBColor[
              0.8177084834502429, 0.13712074047130335`, 0.1645909697918113], 
             423 -> RGBColor[
              0.18782589147201245`, 0.31474729915939237`, 0.9340077787046009],
              105 -> 
             RGBColor[
              0.2459052705491277, 0.3757924090147619, 0.9373153134223011], 36 -> 
             RGBColor[
              0.254389289460926, 0.3847096508089296, 0.9377984657483468], 123 -> 
             RGBColor[
              0.2069635167020156, 0.33486215667164765`, 0.9350976381498702], 
             94 -> RGBColor[
              0.9554190789968999, 0.9662722026272221, 0.9603480500785777], 
             473 -> RGBColor[
              0.32683125980079797`, 0.4575065430478635, 0.9420463767623395], 
             312 -> RGBColor[
              0.3044115375980597, 0.43728620519477157`, 0.940647158778472], 
             96 -> RGBColor[
              0.2961617343973124, 0.4286151389630523, 0.9401773446906796], 
             496 -> RGBColor[
              0.27688954314442643`, 0.4083588440287685, 0.9390798219094797], 
             2 -> RGBColor[
              0.2124476857409665, 0.34062636604798524`, 0.9354099534635375], 
             262 -> RGBColor[
              0.47608581392629684`, 0.5855469370236965, 0.9518983657135286], 
             272 -> RGBColor[
              0.8205829319400263, 0.15921501115513814`, 0.16734354491185305`],
              97 -> RGBColor[
              0.2317345075524728, 0.36089803862701, 0.9365083094334068], 372 -> 
             RGBColor[
              0.4704530721178047, 0.5809740234714359, 0.951454935644951], 356 -> 
             RGBColor[
              0.26933793088281155`, 0.4004216207419397, 0.9386497687627899], 
             402 -> RGBColor[
              0.5523112332770156, 0.6474301663686192, 0.9578991099477285], 
             455 -> RGBColor[
              0.20394063923757638`, 0.33168492079502093`, 0.9349254897502168],
              428 -> RGBColor[
              0.8303334960184631, 0.23416211938642656`, 0.1766806960850511], 
             346 -> RGBColor[
              0.21788265672664042`, 0.34633886515099205`, 0.9357194670208525],
              341 -> RGBColor[
              0.9935733711383794, 0.9886624156338708, 0.5418792928476311], 
             209 -> RGBColor[
              0.5659235722129052, 0.6584812763456551, 0.9589707231324023], 
             498 -> RGBColor[
              0.46188951150763047`, 0.5740217391840874, 0.9507807807843619], 
             378 -> RGBColor[
              0.2830844261537786, 0.4148700588498662, 0.9394326113323542], 
             419 -> RGBColor[
              0.5126905354832046, 0.6152642990075083, 0.9547800234820015], 66 -> 
             RGBColor[
              0.2632810725593861, 0.3940554786170215, 0.9383048396415897], 
             139 -> 
             RGBColor[
              0.5640351798749514, 0.6569481943745988, 0.9588220619701494], 56 -> 
             RGBColor[
              0.8366736085240676, 0.28289500235951803`, 0.1827519949805509], 
             335 -> RGBColor[
              0.2767721721232211, 0.4082354796437291, 0.9390731378034569], 
             314 -> RGBColor[
              0.33007547283951477`, 0.4603165173231115, 0.9422530951484216], 
             144 -> RGBColor[
              0.24622776306205768`, 0.3761313690930576, 0.9373336788938276], 
             298 -> RGBColor[
              0.9016398137954514, 0.9244071294324739, 0.9904804044148157], 
             204 -> RGBColor[
              0.5018930513522051, 0.606498414968846, 0.9539300059787216], 452 -> 
             RGBColor[
              0.22395342458252596`, 0.35271962707644106`, 0.936065188269349], 
             466 -> RGBColor[
              0.503508173143364, 0.6078096435993164, 0.9540571542825077], 207 -> 
             RGBColor[
              0.217062994597398, 0.3454773482835776, 0.9356727884751737], 334 -> 
             RGBColor[
              0.4028040785660817, 0.5233103801574531, 0.9468872975939376], 
             149 -> RGBColor[
              0.353874772698637, 0.4809302746734916, 0.9437695654905504], 219 -> 
             RGBColor[
              0.5262688994117111, 0.6262878265429939, 0.9558489620296395], 
             400 -> RGBColor[
              0.295921828646773, 0.42836298280833224`, 0.9401636824130951], 9 -> 
             RGBColor[
              0.5751436787516512, 0.6659665741948753, 0.9596965636934954], 11 -> 
             RGBColor[
              0.23891813183632316`, 0.3684484832174229, 0.9369174062091523], 
             44 -> RGBColor[
              0.49667724948997916`, 0.6022639920478948, 0.9535193989500155], 
             153 -> RGBColor[
              0.24493296406314102`, 0.3747704532501981, 0.9372599420063227], 
             471 -> RGBColor[
              0.8568125830318801, 0.4376919853814662, 0.20203709971295072`], 
             406 -> RGBColor[
              0.990618380894789, 0.9800157372285142, 0.4180546106567104], 32 -> 
             RGBColor[
              0.5357107322431658, 0.6339531317852908, 0.9565922576967049], 
             162 -> RGBColor[
              0.46203141681910903`, 0.5741369443087071, 0.9507919520902978], 
             493 -> RGBColor[
              0.9935772608954081, 0.9886707354308406, 0.5423026688954158], 90 -> 
             RGBColor[
              0.8647697772859632, 0.4788329671240561, 0.2088729261823753], 
             331 -> 
             RGBColor[
              0.8366916950922476, 0.8726192625482565, 0.984285594873034], 8 -> 
             RGBColor[
              0.6202936289377985, 0.7026213377380665, 0.963250933161866], 364 -> 
             RGBColor[
              0.2585666750316088, 0.38910034790526005`, 0.938036361676709], 
             342 -> RGBColor[
              0.25998714329821626`, 0.39059335011635443`, 0.9381172552430979],
              163 -> RGBColor[
              0.26699231078344465`, 0.3979562252966011, 0.9385161891681649], 
             49 -> RGBColor[
              0.49021471545548245`, 0.5970174157848499, 0.9530106445977776], 
             338 -> RGBColor[
              0.32010532781399464`, 0.4516808788160655, 0.9416178063236486], 
             76 -> RGBColor[
              0.4113253016274047, 0.530691035284047, 0.9474302623923834], 369 -> 
             RGBColor[
              0.4199474238450335, 0.5381590841884939, 0.9479796563958474], 
             445 -> RGBColor[
              0.22963931784821143`, 0.3586958614051314, 0.9363889914793045], 
             82 -> RGBColor[
              0.25827862318556116`, 0.3887975871515221, 0.9380199575502111], 
             67 -> RGBColor[
              0.25662307112871396`, 0.38705749697171266`, 0.9379256763097434],
              430 -> RGBColor[
              0.23973902577549727`, 0.36931129479517677`, 0.9369641549045845],
              211 -> RGBColor[
              0.2310404057237692, 0.3601684935964447, 
               0.9364687813610937]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9V3c41W/cPkZ2skfWMY5xzsFxzjFCvnekUipFSBqEZKVlFlIpoUVlJUVG
SYPKqqzQMKISRVQo9UP27j3vdb3X+/3n+eN5ruv5Pp/P/bmHqvuBrZ7cJBJp
nItE+t/VPFxZo1WDhIChKyFr2rXAaP6z7YvoX0JMyNhkJpuKBvKY6gcXKiSs
glQyw3VR+F1zrZT5MvTg47MC33mC7DPgtOziOIG+/St/9JHgeH47z8ZKRUSM
BkTxnVuG2oGvv93mxDExeKOm+SAZDYr7hqJu01GzzvfvChE66r6bbqRaGcDy
7IuHPKHCiDgXpGe/g4US9RtkqzQGSqY1lXxcJgneYD/LJwI8aDaitRSmauOT
eMTPBzX6SPnrLJXgxgBvjGlrl80McWlph78OSQ4Z2w7fyIQevPVFvy8eZaNk
0+1Wpqcw5M7PXbilqgOvZ3ZhhRQlJFGYQr8ayLiwKJfZuUCFpbOIPT2RimA1
NScza1lYV6kPV0QbwKQGqT6uYiAN0p5FSi3H7P343e911DB/d+cfyOrgvPsZ
M+dqMZQ0n/yzarMKFmUdZCLt9WDnrMjVqPiHeL80vmFCnBtHA29V3PJUQ8yk
XdZ/Y0LI3HeR5/PhGcJVJkct6KAqSO+3fCr9YoCRbHJbg6AI9t4Tu51N1UdA
373tMvVUbEqciR0algJ//q2Og1cVcb2/fcIuUAY/ExwdP3bNEVw6T17NG9HQ
kvVl4mNqN0G5+3xTbT8d28lddsrqunASPLPXuo6B8mGtgedb1LEzuij6h6Qm
3t3ztl+VL456j6ZVsV8N4NcftMb8mgScX//j7pYaJ6z2h68jXdZETEnoDZsS
JtJnNFTWV+sg2Uz8TnUOE47mPae6zLXhHC37d0xAGA2pfj4aqXQMHV9r6Oil
g7UqkltuxqqgQMLnyHpRfciJZCQfNKaj51aq55TlMOGc8GicK3qW0NxX6f43
hQX6bkW1bs9pwrt179+R9XSQuvPWbr/UR5R8b1CklDLQ0GO+Xy9IENzXs2XX
1mtj5QuvOd3nitgr8OnPwdvqOG9bOXL1iw5sGa7XlkWR0FVQ5mu3jgb7DhWf
7rts8E5TO+YHJwg66V3erkZBJMSMep98rAbFD9m5zrH6+GhC35MVyI1VVxcT
naY0Ma8QeK2cQcatR8YDET06eDLIx3azlsf5tto6m1oNDIjXLl4qpMJ7wrV/
afYk8ec//j9Hk7Uh4LdO5kz1KNHUNVmhX0lF+ROl4OKTOkiqreDZny6HG3k9
zZt/6eGbv2t5+K8lcKA8lPRS4dS38ILa83FtVNsx789HsnFI22RW1VIGD6h7
TAkLFpxqstpY+9Qh/93Wxmq9FlpqNE11TXuJnzvuGS35SIbrfnFBnhAVFF3O
3fPoyHIIqCzwfaDowt/v0yWLZVogy0Z2bdjcRgxdCvbJLaZCRM54SWGaJCzq
2w8HX2dASfRPke0DPTif7+dAYpLgrk5wsomgIFbp6VRMoxoYy0L9Z8J1YH/v
mh3fWUl09jfLZIaQ0ROv8q53cI6oeX/1xZ23mjBVCHbKbRbHUspt2ytO6jAo
6Urxj5VG5VdL9sh/ekjd92ShslAcq+OuS1mv0cPe6/5HqP0stKzw4IorkYHj
3rqzBZ7S+Bi3kRmsqguB7DWqH2gcHtCim561UcNTN4fDDn/k8ShmuIJ0QwCX
zh372n2RDXLvS7lljxeJzP13D7SFKmPtDl/e4C5xHFxzvOl6pyzYf9K7fr+T
wP4zMst/9JDR2ermWhq5FI7UN/nbNNhwuSXCP+gjj+fUXPcX/BTosX8NvyQE
IbB2QGy+cYpwSH10Ps9AG9RTpg0r9rJRmbjN8K7wJNHu+2ZqZF4HjM17rIIi
tHDu0cufzZ6aCCRCvQxKlGD7njXz/CEHJ/zCAVXesgj44jCQk8+CJ79LnpeW
Mudey0s7RzSRY/JVVI6qg1rPC0o5GRRkVsXJ2l18S9yRCnoXslIXs3/XJdDf
80IrnmL8S00M8v0NX0610HEpbP9Jz8PayBrv9kk4qQouT9a1ZG42xu/yLTYf
nCX2UAyqT6nPEUdSvA3Md2lAt+yY8D4lNugnj1j9zCdhMubpp2s5dOxgyuRc
4OHM8zmPWLXXygh2lVzLPSCO6tO7T+8XpaKE4Z2jo6oKHqV+jaoQGkYNGrpf
bOPGD/HaHqNeEpi+bP58VW48e5whv6afgX/mz237UjQh1qc/77CWDeaEuxGj
WATh5NR3zENsGB+TjBBbJw02+2+R2RUGfPZ2CPi/5sfv7/yN68IpuEyKCP9b
rgw29e2jHmlR2FWHpFCv06B9uG2zv9giIbckq1m9bYIwbUz0enaejsAan0eX
XvYSyeuu0DVCpgiZG/7RZwslMV9jJEXm3G/uLznk+FgCO2zagtcwNTFWryai
9E8Fh+1LJWyadSEoJfeT+xcNq95J2CzM05D5tle7iEoF38onAckXWKAmJDf2
8FFQcelo5kwnA9UaX4472S3Bw37KEjcOH1p2vJjepqSJgFrLki4eLRhtXltm
zC+CVNXgH1dKWPj8NcrWfDUDTyLSM+wSaSgOfH/SO4uMc9EKGdMXyUi1OmKi
6SOF5DXPfMYesGAmfjeq6R4D1LqwvYXLqDi/432Gd402rlbsWZGUzkKcuWvP
m7UMePNKd4ScVIJO5HbteSkGNnk9e7OCc65qwcLxVicZmjWK9pQhzrwHmj0O
DeWCl9p/zZoLQmhxONHu91YbvMIaul6hWljvUF/yxoeMSiHZidyReaLf91mU
0xtNdL+WOTG6SR12zJX9gZNKKHnbafn8HxOb6tLW9xurYL17yrhZExNvXf3D
tu/RRbLi7phW7mnCoTlu+JOgFqbTk19ZnaIjJvQKxc5NG3UXu609wtkQGy2Z
OiE3S1RcEA09kMACI/nd48YvdM75TX0lNxiIWbV0icUJAVS0RBXdeK4PW7XS
fcxDvBz+ERUeceHw5V2pH7RL2ngnaCjJfVYc2suPZxdXKKK6jtzm+kIT7lfe
5l9aroKU7SUucXFyGNygaZYpzkDPdu2ym4ZsJL1VNbK/P0WYBJgtZt2ZIOTG
MupCnCVQ+W/qqNKqaeKj5LmK7hhNWLy5MWfNwevsX/kVS7PFIfgn5ujGd8tR
UsQn7Suih4gQnur9j1ShpmCoZ1YlBenebkqMPgtDRoJPykjqIP3fd9HQSSyR
3EfoeXhu+LGTjbDS7ryoPxIYmvuqsY9mgKgbA7dWlS4Sr3nHJ0fSDSCQVLO7
lF8FatOWqwMVJdEi8V5z2lsE5DyNO9UaM0Ts3oQLbvFqaBrJEl/XLIcn/4xK
D6zRhUNT8V9/Dw1YzrGOSzVLIf7ydYGdLFUMKlSsS0nQQ3bHrY78HbqY3/h5
nHRGBXZ5pS6/n9FQwnxc4Kigi5KjguHEHg4/r/v4cquHLtJ8N0o5f9RCxQn9
Q3reUrjz2utFrpcKxhULDvbK6mEwiV/I4L0OyqzMp1tnpWBu5RTb5kiD2gqv
1GfLZFE+aSlIJOngQf6bo7rDalB3vryyp1QX0008zJ413DilyI7LNeHB32W7
hPPdteBszbJKGZgleOkHJe4LamLTCp3B7XLqmE7+0cf3bJA4JaPg0JwtBTYl
fJv2VQVYv5M8/OkZEz+C9j009eBCZpnY77IrNDhYXBLL7xOGl7Onz04uCrzo
qdkdNXxgK/hda9rGwjgzptPmKQNCezq3HzTURtj4sFqZBhV+W5R8sE0bU4Ef
mdd2qWD6tFVKv9E4IU2WiS8yVsfpo4EFhnZMXKhkzP8tVMTW6e/c10IVMEfI
91bP6iKpqI1y6zMbIg1H9oanTBKUjtuvXv9mgatjMfZxrTI8LpIbBLz5IbA0
68adrgXiQWGx4wjfGOFqsjpsX+kcUbbwnbsqXgqbvrt/0TDWQ9rEkKnBeSZu
OffKWFM1cU4n5O/aXYIwUTfL9XhNw+AAu1nGiY1s9osxO0sJMJ44zfhv7CFg
cO+SG2mEmOSSqjjE4ZPK+dLK039UQe6QTZXS54ZPR6BwaRsvWKG/nrXskYZa
Q3JVQbsq8nz2RzxWZ2Mh8UyyBEsa89I3rxXkCOCQ+zk3+3ESrpXtfRxXqQlG
ZEXK3Q4+PNh4zcg3XxvaWqKBOjv14Zfz9WWALwP0PTdJv+s4/ku24dWnlVQ8
vAOu7YfJcC6UehF0YY4wLdn5I8ZQFs5iXN9PMSYIB6fKY85ePOj7fCvXPpoO
Df7Frce20ZEbmOeSkcTRv5Smd8Yc/prbevX4fhVlLD2oEFSfrYUtDhuTLr6U
wJrszDXfe2iIEtj+a6FkkAhMMPz3nv6VqC1c/Yq+QR95I3fay9V00dG99Iej
sgaM40n04ipl8NbLsC4eo2J98TlaUZQsSn6mdSYs+UuEUd/NJFUIAJUMfZe2
XmJe9qvp9o3jhF3qiJ+oAhW7G+yUN5aqIiGJT+qfhiasj97jKggko1RJv7br
AAtyYuLDF02EoP3SiZC3mCJOf7e12CRKQc9kmYPjdjoymz2m+N/+R+z5b/fo
u6YRQsxG1qkrdoA4HP/uzB01PbhUrozafYYbat7xIktFDVD2b9XTq/I07DF5
ubEtnIYKY9u5QY6/yzxy/ulonhCyu2jude2yuEJtLVKT4/j06pd33Xj1UN1J
fztcyoLp5cc5r9vEUTfzhtpUzsJyC9f7Lw4qw62nwaNvUhPsuPVFXccVYa53
/nOVtw5WG/L+ynOWgpJYmMa9aVlIvlRM+rFZA1zJWwxLLAwgUvP0+AquWYLU
2tnRGTtJyDiM8Ri3c+5197VKaB8hgisSFHffUQD7rbgv9QM/fh6s0v4cJgK9
w/ZBubdUoVc3ODf/Rh5N/Q2xG04x8WJvILd2AcfvylY1KP5lQsJ+fI4epoh4
bQhF+mrjscYWvWf3FOBYOra6/qk64hMbZbZbCkND9rR3ezgXPot93DxzQwNX
Y3sp67RZkGyr/vIoYDmW0xrN0cDEz2GbJPZrHfA0WuT5JIpjZlj+qq+5Mhht
yt8T2yaJb+mdVWf1qIhxJ0uGyVPRIl454GOjgILHb1ZnB+hjOvjE5mBijniy
zuZYzSYmRDYcT38ewNGT729EzpGniIcCT8yZQspI2xrX0fKNgVYfsZjzFEG4
coleeEkw8SmvzTMoc4zQGeHOyD/DglFk1qOsVRy93WhIa7b+TvAa9Ny67EmD
9VSA4dwujp5ubJSNbaShdnWsswCnTy7R93iOadLAKLZ1aQyhY3/gJqMLkdqo
dNy54Ceig95wVweXGDIGQ9tqNEIZELVkNRqe50Hyh1rFR2ITRBGrM67gMqfe
JjWZy3o1OPMlpPFhDeedXC/Xvimkg134idUZqItXYTn1hg9pmMsJVX8aQMax
c2VWaZEsWPOI+JnVk8FlcPnyZX8q8otUT3Kv1oTHngmHPiMmvieamzXrK8JS
QtiZX4qNutcPHlRzcirs+sKutDHQS8uVWZbPwJ8LPEdSSTxY+uOO+FFDTZj0
2z4ptRHCnrMufy2TqDgQ0Iu2RjImXLNvUI6JY53H8Hb1nWr49WSNuNF+Pdge
8M6JoRjA6NQ9rvoQIeSv3xe5aZICESGlV4Lywuj59LU84+Io4ToeXDuZL4O7
0zXGrb80QK96dliyVQfcm2s9Q1gUdOZLFt4dUsYuH991TxX0QVob9zSJk/96
2paJPdVVQamz+/N5ph7MrMnrEq9rI93HM4qaogBXD5Zu14Auzu5e2HrvMScP
LFFq/9OpBIXzewv1j4mhpXhokMtAAR9/M6r79upDY6dtx50MFtZ7SvMN96ui
hFpiMlA4SkTnehV4cnFyZH1lSqqtMq6sFNgKbl1s5qtdZSekjddXY0cLjyih
Mi3UnrFxhHCnvFR7ViyFwXP9nQVVZPRv/5bKENPHzUfi9hcTWcjMShNeNBwn
egSvhN4+3kn03Ln26umbH8Q6kRimgN8YkV4i3MVlpoqnUUH3N3D+f+Ltpuh/
F+ioDmK+ag6ioyTSXZjboJ9I5E9/L/VZF8ct60pMEqnw4tM/M3tTCx8nc42L
VylByIvit5NXHVMr1VIVttKwI8F+W7wJC7wtYlmXz00Tle+H29J4Rwjnz0tz
Vk4PEdzMduuIKBYaB96mHc1YDt3bX39rn9WF6pW+u6qydKgs9CrbdKqh8ILl
vZoTNFT6ybEGGuuJFq6w/WVrfhEwv75tZd5vwqFYYkJCfJSAcXs06WozkXlS
l3yQ1Ucco0mvGrTSQquQosp8AxktrgsrmekURAmudJtPLCN+vLLnCeXM03sj
oQ8m1lqoUdgVN7VgAE3bsUbxLF3UnIg6PPpCA+OfO/KslamIZja2qHNzcmOx
YX1ZkwTSjm/9scdFE4426aL2dGXMtz5THXmvjRCqllkFRQzTS3KNu38xIfAz
OdrsmyYs64rvT5frwva4YG/WBR1EUSMsfSNJ0BYa/qC3SgzjgWPc4ooGCCls
LJkunyCqs5UKR8/rIf5UTJX3R47/sr9LuXlaG35XIj33kFTRe9jq3pc8Osf3
WXoEvKoi9lakv6tO0ECt4uak6Z1UBNA1W3wfLsWj06QtF/aRsD69/mFWih6O
0N3SPFZwckDVfMFvXyqG81iOfUxR5EhuOCP2nyjo1ZIpkRzXcjHK9nvcGkkU
JlYsBh3Wgyn7bZtzLBtXH96O9CVJwn7qU21PkxIUPX+HKHHmz+/aN6P2P1rY
a9b2lSeCjD330oMPetEwHPrQsKh0OdZfoglw72ehItph8+y4Bh6cvxnHVczx
O+KztVH/NKC3j6azn6yCZcs7RLWjl4H9JYVrvIoPjoXFm6RX8UIqNcjikJ4+
zlWT2fbhmrjy5cWVvCgmTsZnPL+VsxyZoQXXPZIWiXA5rRW/LijBXOCBq1Kr
HkyqLOd/XSYBH+ZWJbgLwGMyo1Lw7zQhZrUussJshCD1+GmfonwiYouO0SPb
aBi53aMxcUMQ8rePlX/l6KvQqfpYPjcSKqN3biq/9pewDE9yzVlJw9CaG4On
OTxgF7clOB5TxDeN5jO+cbpwNxKbyFtJxppycuXnrWwQcr70Ym5piM2flP/v
9wzh9kjRhCtTHQrFOl73/hngveGHhvwAFcxHvIw3+qqFy0kiXzILl8DVMPVG
1w5OHu8semO2ZJpobaPdtzykhZKoz3f9rpARtGaDV6IYFXJzXs5HNkvgovn3
3eTN+ij8dawoOpOG5frvVRy2CCHn/qXzHXd4Ue3Bk6JVycIoxTxxrkoMZPGb
c2KcfhTzBn8tfU3FXxl/nbhoVXxYtdnYeZDjs5bLW9KOCmKW605ZkZQA2n86
RtQX01EZU9D8mXeCuKvfv5lnkoVjEa5FRXmiSBLezWvmrglvrqOync06eHt5
9l68NhsX4+oF/NVmiFPB0m7JN/RhelCk+58iHTNmA268WwywNM/2d1i3KESs
FB9T/XQhWregbe20BMslRg7k3uDkYVVa0rL5caK5Vb7/IFsP6RUJpG9P/hGf
Rgbd32QIwNu7/VzWLA0hHyJ03mwZJURu+VV9XUVF4s83GbtWUv4/Z5kk1JYb
zzFxaijt2vQkDU6KAbFlLdrI2eES9MxUFVZNbMUqJwYk7vSd7Z3nAWO0OmlA
Uh8X/zWzY/T58Hd+C+1AAQMDVgVap5g0PAi1tg8IEIPjlNiWzb/FcVPq6NkN
/HRElzwV6V2mDw/xYNPDR7iRt735265bOkjpSD4is1obDasz172IEgayNhU+
rp0jyM71yfFyS7HgmZHryqUHbqGDDeWjmqj90py2oVUXAspjW6fGfxHuOUce
Rjsw8PPvVvdB93kizPbp9dgHDIgZ97y3ujpOdHN7jexYoIGie/u1ZBIdYZnv
/KYaOXxiGKR2cS0NDbZ/JvquiSI7sidnUWSRWHLnpzCPFQc/5gN1pKBe4qJH
yZ2LdhOERW86d4GZFqzb3EQvZGjBstxr2dpUTl4e0Tb8sIuBuDNjXB+pKmha
+VPwwFIZqDr5t7zbqQ47idWbvDv6iJIIq45tSv8RQ1adh7p4DKAdtHzRTGqR
mN73e/tG12nCPKJSbeCxFuQ+fdIZ3zZNJL99tH/jEVXs9/Np0lnGRJohtiuo
yOJFe37/BNMAJuPif17pMdB//+4VDws2Qk94PYxM4uh3Lg8/7aEmztSrMYuf
ymGjzuPPtUf0MM29VOFcAx0VCgWqEjIMZMxN2Ty5p49v3WrUeQ7e5bwEGUrD
Wph2K3vXY7hABKdLG2TfEcMZo0O+RzN0oBjUM/WfsCoYay69OXhQBCtCXmZe
tlDFJCfeDm/Rx4MVZlEFjmow7XHiq8tnQ+C7yV1y5TSRZ2+8ddFBF9tmzPcM
jynhi+Rxb6U5JQzlWtnXlEsg2l2utMGZDb/Cda2PE2YI95JtJIVoNlJj+Syk
6kk4+5Wnx2p0lvhhMe/TPTNCvDDtdQ8Ql8QputMi5REN7b3ubdfBRMjGjNNb
hCYIflL47nZ7FpLk+uYjBrSw4wefZGafMmQs0u/HP5RA3vDpINpLEqTS6wr8
S/lgMpxRWirI0RtNfmKsWBi14jMemhx/Zu2Vb6f0mIb4FH334asSCAm2c1Gb
lIXn0JVPGdHqcJ0KdNcSpaF0hPd4p5keOuo+ycccp+FH7G7BJXMayJULMH68
kYaY+zdvfrTRROhgweKu5yrgjw2mReprIevCosW5DQoQ7GsbTjhKwf1Brl6h
5SooWR/TvWDEQvnt+tmtDGXsCF/482+egbKxzSyXc0vQ1DxpZCJIAXfYgbMn
GgXx06ETs3QD2OWTQr/XcnRvVvLBwJAOBlvcLyfry6DddshVbZGzb36+aDUf
FcUPd96M5GFj+hh9/5k6Lsxz6UVY/OYHv/Ojr6NW6hDoDiBqY1XxVoL/ApcS
Dd7z38QrurgRtkQ5WO8lBc8XNwYunKGhrO63bPuYHMIWvvIGW2iBZGEqzjdw
gsjzkkxY2SWIbcLxVmYMNZCdy3ZQrAVhX5xUXc7hoxxNne1Tw0xYHJoiU5r0
MSEf8eLxjA5k/+1r3M3ZH3F1y9lYy8Lu6XO9VqMK8CG4B7IXleDi9jNkc78u
PgmdTD00ME7kB9wZiTovB5qGU9ykGwXtfgLjQhkyGFn61kxrcJT4j3cg/ru0
HP583DA2QjXAW/1hV6W1DJBUtEwp3ykwcW2x7fmrAL+Ai2mSB9iIFju/reir
NExd6BLH72lguduEnWoPD3IMCtTM0vRR9ZnLx0ZME0mmaYxQTl9LT16UXDjD
0fMWpt2+8VZi3Q7fcr/fQ8Qhjpi2PmND3HHFpdGzYnCJa3iqNcbRF9rnbntv
eYgdDrcyseXkpqBooUEGGRIVDzUUBlgIGxNbe6KfATLpQ8wD/CbyfhTZvPny
HxETWNh56SgLeuGXk01U9BDIv21opHGUMBk6Eb5/oo+wnTQxFDnMjfJDVNX9
NqpQsdr9++5ZA1idKi574K0PoVSzkDO10nhR9Cj9crc8PJojZ9tXCED37pf0
LRXqIPijP58z5ODhZ9Gx4zulYCKYFdPbP0Y0thP3tVzEUNLPVVhZMknETwf3
DZ9Xx/f4OF7bGgYW2/0lqycEkN1dRV3SrQylrUm6c650NLUEnJD0N0DGEh3/
V/Ji+KGVdC7QjwbjsUcKni8UsUSqoyxlkAU31/cShgdUYH5ku//ey1ToK4+k
bN1GRl1al4RVjB4Yy9XU79L1YFmdn/tnFQWZSauyyKbNhMPAZaPaQhpc49tE
kuvkoDD/jZ3+hApr8cXuKxy/YH415mVLkwoqEzXTWy9J4c+i46CBhSYYO84m
H9rCqffTc8ckOfVxDVr8vHHlFJG9rfn61UvieJJnbZZhzgORZLGfiQQFhW1a
Nlwf9GAhmbnTpZKMOMtDrwyN9bFva2vGF4jhm80ygWslXPBzC4yBAQvSWWpu
5Zs04CaqVCfRx3lvd1CMhr8WGOIFfvnhk0TgvuQhpU9LUNVa69rrqQhlT5r5
g88SyKTsE9b2E8UxHoNq76tq+Niucuv2Qz08ysxLVLPTxqFLMqR35poYH7te
sfWXMMSXCjSlHZGF85pMBu25Ou6oOJ6U3KCL8/FNp/0aVDB9dUu/seQEUb9z
M2MkVxGuAVHEhKUCpumyN76eksbJm1eP7XSRxrcRP+46OX1QPxUoKWRScVxi
72wnSQ5ni5dVHDXlR7xwWcDo4XnC+eDqjrUio0RqVTk1bUgQT2KC+SXT6Agw
D3aZOU6Csuj8mS9STNTd4mWcMaJD980lNakwKiY1HN52j6jhfwCDMYyj
         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 54}], {
             RGBColor[
             0.24744314331957223`, 0.3774088108032645, 0.937402893001499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 70}], {
             RGBColor[
             0.26220782647507634`, 0.3929274289346799, 0.9382437198648137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 84}], {
             RGBColor[
             0.249739891419232, 0.3798228386782472, 0.9375336894080404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 131}], {
             RGBColor[
             0.26488726968740706`, 0.3957436936373514, 0.9383963101918749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 135}], {
             RGBColor[
             0.2583961289533292, 0.38892109316374235`, 0.9380266493298512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 147}], {
             RGBColor[
             0.2588293294875211, 0.38937641439167825`, 0.9380513194594108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 170}], {
             RGBColor[
             0.2814230291570491, 0.41312382526764985`, 0.939337997231207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 171}], {
             RGBColor[
             0.2639538573417897, 0.3947626180803467, 0.9383431537396518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 265}], {
             RGBColor[
             0.2935899974663011, 0.4247777732380918, 0.9400724206184119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 266}], {
             RGBColor[
             0.27784311638010406`, 0.40936110995950087`, 0.9391341264945663]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 374}], {
             RGBColor[
             0.25894790578239785`, 0.38950104559576504`, 0.9380580722039861]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 385}], {
             RGBColor[
             0.2498185382943033, 0.379905501530447, 0.937538168231228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 391}], {
             RGBColor[
             0.25364635844324135`, 0.38392878320479584`, 0.9377561569259576]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 433}], {
             RGBColor[
             0.2958358704615542, 0.4267230355457211, 0.940215525659722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 47}], {
             RGBColor[
             0.22219066917343752`, 0.3508668593763409, 0.9359648019565643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 54}], {
             RGBColor[
             0.22058424144202293`, 0.3491784019772233, 0.9358733182737572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 55}], {
             RGBColor[
             0.21196267506411343`, 0.3401165890751596, 0.9353823328229998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 230}], {
             RGBColor[
             0.21816285424353754`, 0.34663337050679954`, 0.9357354238549247]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 242}], {
             RGBColor[
             0.21872765624032725`, 0.34722701321594046`, 0.9357675884930923]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 250}], {
             RGBColor[
             0.20844651025640323`, 0.33642087692453115`, 0.9351820924389003]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 339}], {
             RGBColor[
             0.21206918576719214`, 0.340228538577264, 0.9353883984499716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 365}], {
             RGBColor[
             0.21471117528305686`, 0.3430054370702481, 0.9355388558444269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 8}], {
             RGBColor[
             0.5409798313044035, 0.6382308237734111, 0.9570070604761514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 31}], {
             RGBColor[
             0.4573521482388232, 0.5703305077559329, 0.9504256815919188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[
             0.4618487252450588, 0.5739886270587315, 0.9507775699403673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 203}], {
             RGBColor[
             0.49811633466717364`, 0.6034323062247897, 0.9536326890067068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 221}], {
             RGBColor[
             0.4991380572062573, 0.6042617866100937, 0.9537131227476765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 223}], {
             RGBColor[
             0.4257649092191724, 0.5429712289379067, 0.9484129706530855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 258}], {
             RGBColor[
             0.41754423807969365`, 0.5358508967798354, 0.9478891567573319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 381}], {
             RGBColor[
             0.5154854178683257, 0.6175333104357662, 0.9550000468613498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 439}], {
             RGBColor[
             0.6612892589149015, 0.732886286051436, 0.9686794915733958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 480}], {
             RGBColor[
             0.4076066344287682, 0.5272434439758863, 0.9472559414401728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 29}], {
             RGBColor[
             0.36696197867847585`, 0.49226575471112954`, 0.9446034706830237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 185}], {
             RGBColor[
             0.30412419819916303`, 0.4355457825101565, 0.9406834624888651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 196}], {
             RGBColor[
             0.31000149085861584`, 0.44172318973711877`, 0.9410181656111457]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 318}], {
             RGBColor[
             0.33312298494508064`, 0.46295611913654056`, 0.9424472799249791]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 321}], {
             RGBColor[
             0.32873955000778277`, 0.45915940811169914`, 0.9421679713268938]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 335}], {
             RGBColor[
             0.3005379095306292, 0.4317763657356928, 0.9404792286546308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 383}], {
             RGBColor[
             0.32662308368104653`, 0.45732623135617084`, 0.9420331119640719]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 479}], {
             RGBColor[
             0.3678971603336924, 0.49307576205728143`, 0.9446630596311456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 482}], {
             RGBColor[
             0.3413925426988842, 0.4701187944228272, 0.9429742088325687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 496}], {
             RGBColor[
             0.3005965950412318, 0.4318380479282125, 0.9404825707076422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.23876273655839006`, 0.3682851529276855, 0.9369085566779607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 23}], {
             RGBColor[
             0.23055442452635688`, 0.3596576965449768, 0.9364411054508459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 41}], {
             RGBColor[
             0.23556700835298144`, 0.36492623996293, 0.9367265646843188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 102}], {
             RGBColor[
             0.2575724490549457, 0.3880553533662194, 0.9379797419781635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 186}], {
             RGBColor[
             0.23715887571324926`, 0.36659939348879156`, 0.9368172191755294]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 193}], {
             RGBColor[
             0.263209529621381, 0.3939802824530939, 0.9383007653771087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 202}], {
             RGBColor[
             0.23883220085490312`, 0.3683581643076115, 0.9369125125668838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 211}], {
             RGBColor[
             0.2348238735021131, 0.3641451581171964, 0.9366842442539314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 212}], {
             RGBColor[
             0.22856179646777947`, 0.35756331811549596`, 0.9363276282307389]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 300}], {
             RGBColor[
             0.23228249418787045`, 0.3614740073251723, 0.936539516461619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 414}], {
             RGBColor[
             0.2566326545868817, 0.38706756979387325`, 0.9379262220735086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 485}], {
             RGBColor[
             0.24330426601765148`, 0.37305858833896816`, 0.9371671900620748]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 24}], {
             RGBColor[
             0.8323309168683787, 0.869142096362715, 0.9838696599531287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 77}], {
             RGBColor[
             0.7172538475630181, 0.7785612627115652, 0.9728085302210365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 79}], {
             RGBColor[
             0.9107592672849488, 0.9273249908421985, 0.7765494419084453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 80}], {
             RGBColor[
             0.8086163665159423, 0.8504788015959455, 0.9815424524658205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 81}], {
             RGBColor[
             0.825653983169494, 0.8638180906717614, 0.9832328080563602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 99}], {
             RGBColor[
             0.9106556765920616, 0.9271034208247384, 0.765274234275318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 156}], {
             RGBColor[
             0.6474994925034097, 0.7219315348762902, 0.9673172118721224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 267}], {
             RGBColor[
             0.9083762130299251, 0.9201045780958312, 0.6977188544044266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 278}], {
             RGBColor[
             0.8880267801577246, 0.9132258771339024, 0.9778589426846744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 329}], {
             RGBColor[
             0.8551238518896912, 0.8873165640509703, 0.9860436704429549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 406}], {
             RGBColor[
             0.9091541002347256, 0.9227285742942248, 0.700740799303404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 413}], {
             RGBColor[
             0.9007629224656561, 0.8944231613369187, 0.6681426582115271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 486}], {
             RGBColor[
             0.8813087089314302, 0.9081956582870432, 0.9885412054830938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 28}], {
             RGBColor[
             0.901769090567154, 0.9237583305634441, 0.9644245605513657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 49}], {
             RGBColor[
             0.6644484112533559, 0.7356118894004525, 0.9687430433701605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 69}], {
             RGBColor[
             0.874072307624645, 0.9024255483118935, 0.9878509910664408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 142}], {
             RGBColor[
             0.7691032060058948, 0.819699666861827, 0.9775805727504322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 173}], {
             RGBColor[
             0.9116225315818571, 0.9310453814508525, 0.9449853696775101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[
             0.9125990982944516, 0.9314492168831301, 0.9288011319761822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 241}], {
             RGBColor[
             0.7720821236708154, 0.8220268199822758, 0.9778774834237032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 388}], {
             RGBColor[
             0.8924271040987608, 0.9167910923514154, 0.9802381068620604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 402}], {
             RGBColor[
             0.6954966701641224, 0.7608182646923372, 0.971187276045136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 436}], {
             RGBColor[
             0.6558009604167452, 0.7285914992480711, 0.9680622843636464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 461}], {
             RGBColor[
             0.8915688064008891, 0.9161509753336762, 0.9816909809846657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 487}], {
             RGBColor[
             0.7090567422484308, 0.7718269420846646, 0.9722547745917934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 31}], {
             RGBColor[
             0.5366659458722182, 0.6347210217205881, 0.9566695542776334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 40}], {
             RGBColor[
             0.5032468930597369, 0.6057751178648505, 0.9545401217837302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 114}], {
             RGBColor[
             0.5604860564407306, 0.6540668560845098, 0.9585426619725401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 115}], {
             RGBColor[
             0.7707310045144475, 0.8213000079229384, 0.9777969948316587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 162}], {
             RGBColor[
             0.5411625228784538, 0.6383791410233868, 0.9570214426260819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 203}], {
             RGBColor[
             0.5774301323005686, 0.6678228201894449, 0.9598765616924215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 221}], {
             RGBColor[
             0.5784518548396522, 0.6686523005747489, 0.9599569954333912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 258}], {
             RGBColor[
             0.4968580357130886, 0.6002414107444907, 0.9541330294430466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 289}], {
             RGBColor[
             0.5298323406094952, 0.6288020963090049, 0.9562341229930127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 291}], {
             RGBColor[
             0.637610384777719, 0.7164873323549865, 0.9647458039813404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 297}], {
             RGBColor[
             0.5698289191235334, 0.6616518129015765, 0.9592781663469641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 311}], {
             RGBColor[
             0.6835752486050087, 0.752395433322769, 0.9693271520415703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 381}], {
             RGBColor[
             0.5947992155017207, 0.6819238244004215, 0.9612439195470645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 419}], {
             RGBColor[
             0.5664920822105015, 0.6589428183727875, 0.9590154783219338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 439}], {
             RGBColor[
             0.7406030565482964, 0.7972768000160912, 0.9749233642591105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 19}], {
             RGBColor[
             0.5674341026863339, 0.6597075930326068, 0.9590896376245259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 26}], {
             RGBColor[
             0.4808866078491948, 0.5876336896788764, 0.952776616899017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 34}], {
             RGBColor[
             0.559448373541096, 0.6532244183595045, 0.9584609717735231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 44}], {
             RGBColor[
             0.5359104641208152, 0.634115283121385, 0.9566079813217554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.5464995084832656, 0.6427119463658346, 0.9574415896829152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 117}], {
             RGBColor[
             0.4781094761010015, 0.5852282777412916, 0.9525996605197433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 139}], {
             RGBColor[
             0.5695894293133013, 0.6614573842847371, 0.9592593128318224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 247}], {
             RGBColor[
             0.5350775301382318, 0.6334390697910756, 0.9565424097075088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 269}], {
             RGBColor[
             0.512041509774998, 0.614618499836106, 0.9547617797005311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 360}], {
             RGBColor[
             0.5772550006439877, 0.6676806404210414, 0.9598627746868871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 425}], {
             RGBColor[
             0.47524326414852586`, 0.5827457090080587, 0.9524170280286233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 466}], {
             RGBColor[
             0.5393259259475076, 0.6368881088970959, 0.9568768589880016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 468}], {
             RGBColor[
             0.5267603512092651, 0.6266868092518996, 0.9558876509153902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 120}], {
             RGBColor[
             0.21319195993880496`, 0.3414086454196232, 0.9354523387780493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 123}], {
             RGBColor[
             0.21296296597852177`, 0.34116795824830987`, 0.9354392979107774]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 125}], {
             RGBColor[
             0.21381800062875955`, 0.3420666538780378, 0.935487990869198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 177}], {
             RGBColor[
             0.21382948684753797`, 0.34207872662224226`, 0.9354886449923652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 245}], {
             RGBColor[
             0.22026264269435236`, 0.3488403813028832, 0.93585500370084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 438}], {
             RGBColor[
             0.22021348611856342`, 0.3487887146250221, 0.9358522043065695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 455}], {
             RGBColor[
             0.21145152724630215`, 0.3395793403099965, 0.9353532237109508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 23}], {
             RGBColor[
             0.23070981980428998`, 0.3598210268347142, 0.9364499549820375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 41}], {
             RGBColor[
             0.23572240363091454`, 0.3650895702526674, 0.9367354142155104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 102}], {
             RGBColor[
             0.2577278443328788, 0.3882186836559568, 0.9379885915093551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 186}], {
             RGBColor[
             0.23731427099118235`, 0.3667627237785289, 0.936826068706721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 193}], {
             RGBColor[
             0.2633649248993141, 0.3941436127428313, 0.9383096149083003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 202}], {
             RGBColor[
             0.2389875961328362, 0.3685214945973489, 0.9369213620980754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 211}], {
             RGBColor[
             0.23497926878004616`, 0.3643084884069338, 0.936693093785123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 414}], {
             RGBColor[
             0.25678804986481485`, 0.38723090008361066`, 0.9379350716047002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 485}], {
             RGBColor[
             0.24345966129558455`, 0.3732219186287056, 0.9371760395932665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 497}], {
             RGBColor[
             0.2374558873234022, 0.36691157152268605`, 0.9368341335473384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 198}], {
             RGBColor[
             0.2771414265920781, 0.4086235895025834, 0.9390941662991953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 373}], {
             RGBColor[
             0.28300945147034123`, 0.414791255703904, 0.9394283416350475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 480}], {
             RGBColor[
             0.31297532312712917`, 0.4421451064609878, 0.9412865192071291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 154}], {
             RGBColor[
             0.3030787322552839, 0.435811820273263, 0.9405739494865415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 229}], {
             RGBColor[
             0.2937960299949141, 0.4261286336418093, 0.9400426213247091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 244}], {
             RGBColor[
             0.3195286449146627, 0.4500599078221664, 0.9416221233751105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 313}], {
             RGBColor[
             0.2817870779153078, 0.4135064635946042, 0.939358729269428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 334}], {
             RGBColor[
             0.3497101697631252, 0.47620162767835794`, 0.94354526344998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 338}], {
             RGBColor[
             0.30836079438708164`, 0.4403868770076641, 0.9409105178148355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 340}], {
             RGBColor[
             0.3170254114231826, 0.44789173278801986`, 0.9414626195505558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 363}], {
             RGBColor[
             0.3507138092232281, 0.4770709297343131, 0.9436092144688942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 379}], {
             RGBColor[
             0.3029577301181068, 0.43570701430378433`, 0.9405662393373586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 380}], {
             RGBColor[
             0.28473366122711574`, 0.4166035094794867, 0.939526532829956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 390}], {
             RGBColor[
             0.29868486413343276`, 0.4312671082913797, 0.9403210331965157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 478}], {
             RGBColor[
             0.28132910192119526`, 0.41302510178743673`, 0.939332648214078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 63}], {
             RGBColor[
             0.3630391373968948, 0.48868276614576933`, 0.9443602925394342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 72}], {
             RGBColor[
             0.2803635687690008, 0.4120102652261427, 0.9392776625294388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 75}], {
             RGBColor[
             0.32584559541094904`, 0.45646758947931865`, 0.9419903529330476]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 149}], {
             RGBColor[
             0.33030872638618497`, 0.46033332920658265`, 0.9422747396921978]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 158}], {
             RGBColor[
             0.33213200521333075`, 0.4619125616859979, 0.9423909174068014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 163}], {
             RGBColor[
             0.2868674954285888, 0.4188463045181374, 0.9396480515310051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 182}], {
             RGBColor[
             0.34266467028924463`, 0.47103542678761523`, 0.9430620495117685]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 187}], {
             RGBColor[
             0.28568538812664784`, 0.41760383479386565`, 0.9395807322689307]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 279}], {
             RGBColor[
             0.2926514518650601, 0.4249256094568878, 0.9399774392934654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 322}], {
             RGBColor[
             0.2829806146027809, 0.4147609463277351, 0.9394266994181002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 324}], {
             RGBColor[
             0.33821006500838097`, 0.4671770715883025, 0.9427782060023248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 441}], {
             RGBColor[
             0.3784375409652084, 0.5020200893703757, 0.9453414651985335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 494}], {
             RGBColor[
             0.2826231066390982, 0.4143851827905905, 0.9394063398684542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 78}], {
             RGBColor[
             0.22683394628673456`, 0.35574723802318886`, 0.9362292297190538]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 97}], {
             RGBColor[
             0.23298665056537604`, 0.36221412032402367`, 0.936579617125612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 104}], {
             RGBColor[
             0.24040623048550225`, 0.3700125692486139, 0.9370021512257783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.24125115959042637`, 0.3709006433094886, 0.9370502686883432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 148}], {
             RGBColor[
             0.2369473179686802, 0.36637703288571377`, 0.9368051712749479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 153}], {
             RGBColor[
             0.23958587882071014`, 0.3691503276356177, 0.93695543341207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 190}], {
             RGBColor[
             0.24117420601353035`, 0.37081976022103225`, 0.9370458862959816]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 323}], {
             RGBColor[
             0.2367917298527569, 0.36621349991102203`, 0.936796310761918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 356}], {
             RGBColor[
             0.2517883622305454, 0.38197591138148856`, 0.9376503467903037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 408}], {
             RGBColor[
             0.22837166352845595`, 0.3573634763411423, 0.9363168004411209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 430}], {
             RGBColor[
             0.23698890967688827`, 0.36642074840810707`, 0.9368075398612009]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 452}], {
             RGBColor[
             0.22909610908040262`, 0.3581249145487392, 0.9363580565435832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 39}], {
             RGBColor[
             0.5137718344766236, 0.6147998451486828, 0.9552360290912556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 45}], {
             RGBColor[
             0.343332276555383, 0.46939838880724916`, 0.9431857012274175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 52}], {
             RGBColor[
             0.6198385630520318, 0.4001930339226935, 0.5644333341255259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 56}], {
             RGBColor[
             0.6202778449645745, 0.4035695471970573, 0.5648539909810746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 179}], {
             RGBColor[
             0.29140560923354364`, 0.4148201691111312, 0.940228554342059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 200}], {
             RGBColor[
             0.6523550443789783, 0.5834045301394526, 0.5929583920999518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 236}], {
             RGBColor[
             0.34560261915581325`, 0.4717846628283363, 0.9433149938798411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 243}], {
             RGBColor[
             0.6215940953786275, 0.41368682466407874`, 0.566114433864064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 254}], {
             RGBColor[
             0.3201901654275895, 0.4450745627173458, 0.941867792234375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 276}], {
             RGBColor[
             0.5117111188744836, 0.6131268633886855, 0.9550738020104051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 283}], {
             RGBColor[
             0.29254812031783006`, 0.4160210207001029, 0.9402936186581154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 292}], {
             RGBColor[
             0.29142635679170903`, 0.41484197611023416`, 0.9402297358848033]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 422}], {
             RGBColor[
             0.3189470428658002, 0.4437679620863825, 0.9417969982435161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 454}], {
             RGBColor[
             0.6518822537994468, 0.581257698540845, 0.5925638840512331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 205}], {
             RGBColor[
             0.9368989095333399, 0.9481665884975428, 0.7789256469520753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 252}], {
             RGBColor[
             0.8078836333626171, 0.8503289562761027, 0.9813572830192461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 282}], {
             RGBColor[
             0.7438148228852721, 0.7997463454963281, 0.9753349394405884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 293}], {
             RGBColor[
             0.9171217844286204, 0.9362730779745756, 0.9753514321588153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 298}], {
             RGBColor[
             0.8908055349705915, 0.9157681695861948, 0.9894470212286257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 418}], {
             RGBColor[
             0.9292223734187801, 0.9452976774305406, 0.9548682913375369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 432}], {
             RGBColor[
             0.8892978625365586, 0.9145659925119751, 0.9893032180859526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 467}], {
             RGBColor[
             0.7934052123801664, 0.8390183037645371, 0.979914209324252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 52}], {
             RGBColor[
             0.8600894824934477, 0.42201909265360843`, 0.20357506457964797`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 56}], {
             RGBColor[
             0.8605287644059905, 0.4253956059279722, 0.2039957214351967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 65}], {
             RGBColor[
             0.9349243740088637, 0.7652639008938271, 0.3116367388337401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 88}], {
             RGBColor[
             0.8754970234499582, 0.5275428865427625, 0.2178240033304778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 166}], {
             RGBColor[
             0.8612521660936727, 0.43095598829613885`, 0.2046884517082866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 167}], {
             RGBColor[
             0.9355270875213144, 0.7783260157628717, 0.5479056765432442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 210}], {
             RGBColor[
             0.8602238171594843, 0.4230516477625904, 0.20370370360755374`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 227}], {
             RGBColor[
             0.8650075437066738, 0.45982146624662823`, 0.2082846055515888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 243}], {
             RGBColor[
             0.8618450148200435, 0.43551288339499367`, 0.2052561643181862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 326}], {
             RGBColor[
             0.8797797158009789, 0.5469895922605361, 0.22139758680656518`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 348}], {
             RGBColor[
             0.9221477650002106, 0.7221653986171828, 0.2620020254952798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 428}], {
             RGBColor[
             0.8573587081531882, 0.40102916444142644`, 0.2009600719874468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 434}], {
             RGBColor[
             0.9377932493402739, 0.7792631319127137, 0.510349510564296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 469}], {
             RGBColor[
             0.8724072991337889, 0.5135131700464854, 0.21524586162499276`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 474}], {
             RGBColor[
             0.9387405372806834, 0.7796548598202627, 0.49465049788910304`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 495}], {
             RGBColor[
             0.8632931958328989, 0.4466442372567656, 0.2066429440915829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 26}], {
             RGBColor[
             0.4731770317838775, 0.5813747085166081, 0.9521696908300475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 34}], {
             RGBColor[
             0.5517387974757788, 0.6469654371972362, 0.9578540457045537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 44}], {
             RGBColor[
             0.5282008880554978, 0.6278563019591167, 0.956001055252786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 139}], {
             RGBColor[
             0.5618798532479841, 0.6551984031224687, 0.9586523867628529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 234}], {
             RGBColor[
             0.474151584993228, 0.582218817524079, 0.9522317884987839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 247}], {
             RGBColor[
             0.5273679540729146, 0.6271800886288073, 0.9559354836385393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 269}], {
             RGBColor[
             0.5043319337096805, 0.6083595186738375, 0.9541548536315616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 360}], {
             RGBColor[
             0.5695454245786704, 0.661421659258773, 0.9592558486179177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 393}], {
             RGBColor[
             0.5104680056398668, 0.6134599491568583, 0.954605057791339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 466}], {
             RGBColor[
             0.5316163498821903, 0.6306291277348275, 0.9562699329190321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 468}], {
             RGBColor[
             0.5190507751439478, 0.6204278280896312, 0.9552807248464208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 62}], {
             RGBColor[
             0.8509265138034974, 0.3513524058869604, 0.19479135055817565`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 194}], {
             RGBColor[
             0.9355250585723344, 0.7786349412620628, 0.5492457614630861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 228}], {
             RGBColor[
             0.9388076655030091, 0.7780938721344945, 0.3568427286125849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 388}], {
             RGBColor[
             0.9153530643766437, 0.7639768167303482, 0.6006827363489642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 490}], {
             RGBColor[
             0.9375437932423437, 0.7794697399272263, 0.5157901036631747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 33}], {
             RGBColor[
             0.9296510090196749, 0.7439907144053559, 0.3002556094938443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 65}], {
             RGBColor[
             0.9831762967586118, 0.9549118399527363, 0.38914351910732653`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 119}], {
             RGBColor[
             0.9857675700825197, 0.9687962754074746, 0.5924568745131584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 164}], {
             RGBColor[
             0.8992062375406565, 0.5414501296947882, 0.27233399794458657`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 166}], {
             RGBColor[
             0.9095040888434207, 0.6206039273550481, 0.282195231981873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 175}], {
             RGBColor[
             0.9683090151158134, 0.9568481859192783, 0.670037151361724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 227}], {
             RGBColor[
             0.9132594664564218, 0.6494694053055374, 0.28579138582517527`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 309}], {
             RGBColor[
             0.9869592653755547, 0.967346961753188, 0.4315364838739727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 320}], {
             RGBColor[
             0.9847451317139568, 0.9683734708666063, 0.6094013242659239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 337}], {
             RGBColor[
             0.9205492329643337, 0.9192823831910986, 0.6833909335036439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 348}], {
             RGBColor[
             0.9703996877499586, 0.911813337676092, 0.3395088057688662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 375}], {
             RGBColor[
             0.9695446020803578, 0.9577696846543478, 0.6679456249234423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 428}], {
             RGBColor[
             0.9056106309029361, 0.5906771035003356, 0.2784668522610333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 489}], {
             RGBColor[
             0.9854926800563032, 0.9686826013172827, 0.5970125136401502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 63}], {
             RGBColor[
             0.4353760609281416, 0.5515225941640346, 0.948962755507775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 149}], {
             RGBColor[
             0.40264564991743174`, 0.5231731572248479, 0.9468772026605385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 160}], {
             RGBColor[
             0.4369491379476227, 0.5528851144131592, 0.949062990584439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 165}], {
             RGBColor[
             0.4377248912958056, 0.5535570329728583, 0.9491124209018134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 182}], {
             RGBColor[
             0.4150015938204914, 0.5338752548058805, 0.9476645124801093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 268}], {
             RGBColor[
             0.4305356531895016, 0.5473300762667914, 0.9486543290068734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 275}], {
             RGBColor[
             0.43256024452096153`, 0.549083675519183, 0.9487833341762382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 282}], {
             RGBColor[
             0.5295374583805197, 0.6288897605144723, 0.956120540334634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 285}], {
             RGBColor[
             0.38291743430858444`, 0.506085568433412, 0.9456201382069189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 324}], {
             RGBColor[
             0.41054698853962773`, 0.5300168996065678, 0.9473806689706655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 353}], {
             RGBColor[
             0.5455395337034719, 0.641880966146923, 0.9573802823215901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 441}], {
             RGBColor[
             0.45077446449645514`, 0.564859917388641, 0.9499439281668742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 481}], {
             RGBColor[
             0.38481661217346425`, 0.507730540844516, 0.9457411521410921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 41}], {
             RGBColor[
             0.22751409159888136`, 0.35646211386995863`, 0.9362679629883957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 186}], {
             RGBColor[
             0.22910595895914918`, 0.35813526739582024`, 0.9363586174796061]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 202}], {
             RGBColor[
             0.23077928410080303`, 0.35989403821464017`, 0.9364539108709606]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 211}], {
             RGBColor[
             0.226770956748013, 0.3556810320242251, 0.9362256425580082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 212}], {
             RGBColor[
             0.22050887971367938`, 0.3490991920225246, 0.9358690265348157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 485}], {
             RGBColor[
             0.2352513492635514, 0.3645944622459968, 0.9367085883661517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 497}], {
             RGBColor[
             0.22924757529136902`, 0.3582841151399774, 0.9363666823202235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 77}], {
             RGBColor[
             0.7218949448567346, 0.7822619477143448, 0.9732512022240677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 81}], {
             RGBColor[
             0.8302950804632105, 0.8675187756745408, 0.9836754800593912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 83}], {
             RGBColor[
             0.878858858195596, 0.9062422138097157, 0.9883075365329024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 176}], {
             RGBColor[
             0.7219583100603643, 0.7823133904412213, 0.9732561905650118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 197}], {
             RGBColor[
             0.7672988184851579, 0.8182762435725834, 0.9774043962108645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 237}], {
             RGBColor[
             0.871532203465174, 0.9004001382044219, 0.9876087136641327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 267}], {
             RGBColor[
             0.9130173103236416, 0.9238052630986108, 0.6981615264074577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 270}], {
             RGBColor[
             0.9134975511433701, 0.9314925430785823, 0.899659555679228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 278}], {
             RGBColor[
             0.8926678774514412, 0.9169265621366819, 0.9783016146877055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 329}], {
             RGBColor[
             0.8597649491834076, 0.8910172490537498, 0.986486342445986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 426}], {
             RGBColor[
             0.8535732035252862, 0.8860801191364223, 0.9858957682176778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 448}], {
             RGBColor[
             0.7024556642269519, 0.7664802639694746, 0.97172087084446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 489}], {
             RGBColor[
             0.9135348042436461, 0.9315079481929074, 0.8990421753997224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[
             0.36235029179287925`, 0.48827134332094824`, 0.9443096180726283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 96}], {
             RGBColor[
             0.3047685081778331, 0.4372333951604509, 0.9406831592217764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 157}], {
             RGBColor[
             0.3079594456965586, 0.4405872728097553, 0.9408648783928987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.2917531123703574, 0.42355338894303707`, 0.9399419516850931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 246}], {
             RGBColor[
             0.3037983452782409, 0.43621369244109887`, 0.940627909879872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 288}], {
             RGBColor[
             0.2847205959795895, 0.4161617683290476, 0.9395414602803146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 333}], {
             RGBColor[
             0.34601220845973285`, 0.4741201167137219, 0.94326856984984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 343}], {
             RGBColor[
             0.3031313951145783, 0.4355126855320067, 0.9405899280547156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 392}], {
             RGBColor[
             0.3096883372024623, 0.4424044474005129, 0.9409633362064942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 459}], {
             RGBColor[
             0.35196069990557133`, 0.47927240102423385`, 0.9436476024647243]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 465}], {
             RGBColor[
             0.2980004320712376, 0.430119718051609, 0.9402977272999771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 492}], {
             RGBColor[
             0.29499729755319337`, 0.42696323326341856`, 0.9401267032319138]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 34}], {
             RGBColor[
             0.46519130263863967`, 0.5748915338435057, 0.9515410249790447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 44}], {
             RGBColor[
             0.4416533932183588, 0.5557823986053863, 0.949688034527277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 106}], {
             RGBColor[
             0.45224243758080923`, 0.5643790618498358, 0.9505216428884367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 117}], {
             RGBColor[
             0.38385240519854513`, 0.5068953932252928, 0.9456797137252648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 139}], {
             RGBColor[
             0.4753323584108449, 0.5831244997687381, 0.952339366037344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 215}], {
             RGBColor[
             0.33537631974199883`, 0.4626312893738342, 0.942674216260174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 224}], {
             RGBColor[
             0.34279791451999597`, 0.4704318560417961, 0.9430968651035153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 247}], {
             RGBColor[
             0.44082045923577545`, 0.5551061852750767, 0.9496224629130303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 269}], {
             RGBColor[
             0.4177844388725415, 0.5362856153201071, 0.9478418329060527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 351}], {
             RGBColor[
             0.3383374936256977, 0.4657436708748698, 0.9428428507321864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 360}], {
             RGBColor[
             0.48299792974153133`, 0.5893477559050426, 0.9529428278924086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 425}], {
             RGBColor[
             0.38098619324606947`, 0.5044128244920598, 0.9454970812341448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 466}], {
             RGBColor[
             0.4450688550450512, 0.558555224381097, 0.9499569121935232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 468}], {
             RGBColor[
             0.43250328030680874`, 0.5483539247359007, 0.9489677041209118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 40}], {
             RGBColor[
             0.44915953688308596`, 0.5618645655130168, 0.9502821669769903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 114}], {
             RGBColor[
             0.5063987002640795, 0.610156303732676, 0.9542847071658003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 199}], {
             RGBColor[
             0.4274813973658525, 0.5430880506381621, 0.9489008550961784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 220}], {
             RGBColor[
             0.4255160611016982, 0.5413857751468245, 0.948775625607305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 277}], {
             RGBColor[
             0.6417102241932708, 0.7180330594388474, 0.9662874050409727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 289}], {
             RGBColor[
             0.47574498443284424`, 0.5848915439571711, 0.9519761681862727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 291}], {
             RGBColor[
             0.583523028601068, 0.6725767800031528, 0.9604878491746004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 297}], {
             RGBColor[
             0.5157415629468824, 0.6177412605497428, 0.9550202115402241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 311}], {
             RGBColor[
             0.6294878924283578, 0.7084848809709354, 0.9650691972348303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 319}], {
             RGBColor[
             0.6135043005796454, 0.695998377538924, 0.9634761021745089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 349}], {
             RGBColor[
             0.46286019331944683`, 0.5737313855031778, 0.9511551606901004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 359}], {
             RGBColor[
             0.44878508964320496`, 0.5615402381340974, 0.9502583075299758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 371}], {
             RGBColor[
             0.43753141765926407`, 0.551792873087608, 0.9495412335023905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 419}], {
             RGBColor[
             0.5124047260338506, 0.6150322660209537, 0.9547575235151939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 488}], {
             RGBColor[
             0.640741608541348, 0.7172763695298137, 0.9661908624850168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 69}], {
             RGBColor[
             0.9371592911405698, 0.9519775158592825, 0.9678001094752631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 142}], {
             RGBColor[
             0.8321901895218196, 0.869251634409216, 0.9575296911592543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 173}], {
             RGBColor[
             0.9747095150977819, 0.9805973489982415, 0.9249344880863324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 194}], {
             RGBColor[
             0.9756860818103763, 0.9810011844305191, 0.9087502503850045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 241}], {
             RGBColor[
             0.8351691071867402, 0.8715787875296648, 0.9578266018325254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 417}], {
             RGBColor[
             0.8329443683967894, 0.8698408046783143, 0.9576048606613091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 461}], {
             RGBColor[
             0.954655789916814, 0.9657029428810652, 0.9616400993934879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 493}], {
             RGBColor[
             0.9792166674892435, 0.9809905167708368, 0.7433381739278018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 77}], {
             RGBColor[
             0.5082190929851442, 0.6104476858288989, 0.9547558471761093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 172}], {
             RGBColor[
             0.3806363827099919, 0.5041098361876981, 0.9454747916161113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 318}], {
             RGBColor[
             0.37578131668551923`, 0.4999046220200136, 0.9451654311021982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 321}], {
             RGBColor[
             0.3713978817482214, 0.49610791099517215`, 0.944886122504113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 383}], {
             RGBColor[
             0.3692814154214852, 0.49427473423964385`, 0.944751263141291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 479}], {
             RGBColor[
             0.410555492074131, 0.5300242649407545, 0.9473812108083647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 482}], {
             RGBColor[
             0.38405087443932273`, 0.5070672973063002, 0.9456923600097877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 43}], {
             RGBColor[
             0.2805395184040802, 0.4121951994484624, 0.9392876826008625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 64}], {
             RGBColor[
             0.27788283656739987`, 0.4094028583947541, 0.9391363885004721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 110}], {
             RGBColor[
             0.26982326266389456`, 0.40093173521567016`, 0.9386774076897386]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 217}], {
             RGBColor[
             0.2938254921740675, 0.42514500116830317`, 0.9400814485951139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 290}], {
             RGBColor[
             0.2772082322816696, 0.40869380651806936`, 0.9390979707843874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 316}], {
             RGBColor[
             0.25921313179459604`, 0.3897798149508858, 0.938073176433014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 355}], {
             RGBColor[
             0.29831901354920054`, 0.4290370635324922, 0.9403677718036725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 378}], {
             RGBColor[
             0.2755078252460146, 0.406906570911563, 0.9390011351192336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 384}], {
             RGBColor[
             0.2758760121335012, 0.4072935586747084, 0.9390221028177923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[
             0.4196192099941566, 0.5378748018473721, 0.9479587428994976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 114}], {
             RGBColor[
             0.47685837337515014`, 0.5861665400670314, 0.9519612830883075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 162}], {
             RGBColor[
             0.4575348398128734, 0.5704788250059085, 0.9504400637418493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 203}], {
             RGBColor[
             0.4938024492349883, 0.5999225041719667, 0.9532951828081889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 208}], {
             RGBColor[
             0.38757839390763205`, 0.5101226573714661, 0.9459171304310454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 221}], {
             RGBColor[
             0.4948241717740719, 0.6007519845572706, 0.9533756165491586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 223}], {
             RGBColor[
             0.42145102378698707`, 0.5394614268850837, 0.9480754644545675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 258}], {
             RGBColor[
             0.4132303526475083, 0.5323410947270124, 0.947551650558814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 289}], {
             RGBColor[
             0.4462046575439149, 0.5609017802915265, 0.9496527441087801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 297}], {
             RGBColor[
             0.48620123605795307`, 0.5937514968840982, 0.9526967874627315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 314}], {
             RGBColor[
             0.3915568678230763, 0.5135686115131106, 0.9461706352709112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 381}], {
             RGBColor[
             0.5111715324361403, 0.6140235083829432, 0.9546625406628318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 397}], {
             RGBColor[
             0.40579315804314603`, 0.5258993705649835, 0.947077759095077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 419}], {
             RGBColor[
             0.4828643991449212, 0.5910425023553091, 0.9524340994377012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 472}], {
             RGBColor[
             0.39074248974700837`, 0.5128632381554529, 0.9461187438200305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 103}], {
             RGBColor[
             0.5080332189208779, 0.6114832796124914, 0.9544133824619024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 155}], {
             RGBColor[
             0.5507999265063706, 0.6462032194486154, 0.9577801343426442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 331}], {
             RGBColor[
             0.6862012136677067, 0.7532861971667737, 0.9704389262848694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 344}], {
             RGBColor[
             0.49972685632516956`, 0.6047398002599247, 0.9537594751711596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 403}], {
             RGBColor[
             0.73231135392298, 0.7900531713799142, 0.9748369526254256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 449}], {
             RGBColor[
             0.6320067542390264, 0.7108140314884382, 0.9650731650607731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 119}], {
             RGBColor[
             0.9345308133147854, 0.7655949021985857, 0.5124594755699873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 159}], {
             RGBColor[
             0.8495822086293704, 0.3506448894924134, 0.19388094901806585`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 164}], {
             RGBColor[
             0.8479694807729221, 0.33824875648589925`, 0.19233659900141542`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 227}], {
             RGBColor[
             0.8620227096886874, 0.44626803209664856`, 0.20579398688200412`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 267}], {
             RGBColor[
             0.9337384293685642, 0.7577785430140971, 0.3161344657047144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 270}], {
             RGBColor[
             0.9342186701882929, 0.7654658229940685, 0.5176324949764846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 309}], {
             RGBColor[
             0.9357225086078202, 0.7641455885442991, 0.35153908493080155`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 443}], {
             RGBColor[
             0.9064631162110222, 0.6594290978497701, 0.24321160823769428`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 489}], {
             RGBColor[
             0.9342559232885688, 0.7654812281083937, 0.517015114696979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 234}], {
             RGBColor[
             0.4661658558479902, 0.5757356428509766, 0.951603122647781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 269}], {
             RGBColor[
             0.4963462045644428, 0.6018763440007352, 0.9535261877805588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 332}], {
             RGBColor[
             0.47297256082386624`, 0.5816312685861409, 0.9520368398699108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 360}], {
             RGBColor[
             0.5615596954334325, 0.6549384845856707, 0.9586271827669148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 393}], {
             RGBColor[
             0.5024822764946291, 0.606976774483756, 0.9539763919403361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 468}], {
             RGBColor[
             0.51106504599871, 0.6139446534165288, 0.9546520589954179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 54}], {
             RGBColor[
             0.23354661261843296`, 0.36280267594543125`, 0.936611506136144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 67}], {
             RGBColor[
             0.24749774961125026`, 0.377466205478057, 0.9374060027490273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 70}], {
             RGBColor[
             0.24831129577393707`, 0.37832129407684667`, 0.9374523329994586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 84}], {
             RGBColor[
             0.2358433607180927, 0.36521670382041393`, 0.9367423025426853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 131}], {
             RGBColor[
             0.2509907389862678, 0.38113755877951816`, 0.9376049233265198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 135}], {
             RGBColor[
             0.24449959825218992`, 0.3743149583059091, 0.9372352624644963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 147}], {
             RGBColor[
             0.2449327987863818, 0.374770279533845, 0.9372599325940558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 171}], {
             RGBColor[
             0.25005732664065045`, 0.38015648322251344`, 0.9375517668742968]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 216}], {
             RGBColor[
             0.25212920477180323`, 0.3823341585030158, 0.9376697572687969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 281}], {
             RGBColor[
             0.2416405448941051, 0.37130991195210916`, 0.9370724436053437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 385}], {
             RGBColor[
             0.235922007593164, 0.36529936667261376`, 0.936746781365873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 391}], {
             RGBColor[
             0.23974982774210207`, 0.3693226483469626, 0.9369647700606025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 37}], {
             RGBColor[
             0.2800147441029785, 0.41164362838539204`, 0.9392577974807488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 58}], {
             RGBColor[
             0.28475051663686596`, 0.4160326690739975, 0.9395490426575464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 141}], {
             RGBColor[
             0.28198608489330845`, 0.4136382572421074, 0.9393728955113378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 240}], {
             RGBColor[
             0.25550742159800177`, 0.3858848785786683, 0.9378621417194251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 251}], {
             RGBColor[
             0.25646724614478844`, 0.3868937150337323, 0.9379168023074314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 310}], {
             RGBColor[
             0.2755731801551128, 0.4069752630647657, 0.9390048569846228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 352}], {
             RGBColor[
             0.2411100918235177, 0.37075237214225454`, 0.9370422350877088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 367}], {
             RGBColor[
             0.2421171751521342, 0.3718108805734015, 0.9370995869934273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 382}], {
             RGBColor[
             0.26830699274776615`, 0.39933803939675394`, 0.9385910583611354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 399}], {
             RGBColor[
             0.24794512185068096`, 0.37793642206673694`, 0.937431479936235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 412}], {
             RGBColor[
             0.24838538806776134`, 0.3783991697753788, 0.9374565524459821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 416}], {
             RGBColor[
             0.2579614870777197, 0.3884642569945902, 0.9380018971180304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 429}], {
             RGBColor[
             0.2739936283843697, 0.4053150540043482, 0.9389149038480165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 58}], {
             RGBColor[
             0.31037597127891847`, 0.44296664665046, 0.9410083743899482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 118}], {
             RGBColor[
             0.31537415178862416`, 0.44729581939211016`, 0.9413268540323092]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 141}], {
             RGBColor[
             0.3076115395353609, 0.4405722348185699, 0.9408322272437397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 188}], {
             RGBColor[
             0.3214586719550145, 0.4525659249433619, 0.9417145542769817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 240}], {
             RGBColor[
             0.28113287624005423`, 0.4128188561551308, 0.9393214734518269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 304}], {
             RGBColor[
             0.32210212279026273`, 0.45312324971607465`, 0.9417555543952225]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 310}], {
             RGBColor[
             0.30119863479716524`, 0.4339092406412282, 0.9404641887170249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 429}], {
             RGBColor[
             0.29961908302642226`, 0.4322490315808106, 0.9403742355804184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 47}], {
             RGBColor[
             0.24595116399713765`, 0.375840645938433, 0.9373179269862719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 73}], {
             RGBColor[
             0.25393957190424143`, 0.3842369691431141, 0.937772854998791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 93}], {
             RGBColor[
             0.2646269773927557, 0.3954701099321881, 0.9383814869307624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 108}], {
             RGBColor[
             0.272539685244709, 0.40378686757924537`, 0.9388321039371288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 163}], {
             RGBColor[
             0.2634804930859057, 0.3942650822343853, 0.9383161963455589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 189}], {
             RGBColor[
             0.2598720197723208, 0.3904723479913851, 0.9381106991286081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 266}], {
             RGBColor[
             0.27474470932625494`, 0.40610448769555174`, 0.9389576767965321]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 364}], {
             RGBColor[
             0.2592676752099878, 0.3898371435387148, 0.9380762825998308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 437}], {
             RGBColor[
             0.2578995688543769, 0.3883991770160148, 0.9379983709668107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 45}], {
             RGBColor[
             0.45322202962692537`, 0.5599541419213354, 0.9514657433370749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 100}], {
             RGBColor[
             0.7774382200691679, 0.7351762203070193, 0.6135140654406412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 127}], {
             RGBColor[
             0.4248206994263658, 0.5301025431322064, 0.9498483295981558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 179}], {
             RGBColor[
             0.40129536230508595`, 0.5053759222252174, 0.9485085964517164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 200}], {
             RGBColor[
             0.7622447974505207, 0.6739602832535388, 0.6012384342096092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 213}], {
             RGBColor[
             0.7639337426080279, 0.681629388750616, 0.6026477314488674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 236}], {
             RGBColor[
             0.4554923722273556, 0.5623404159424226, 0.9515950359894985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 243}], {
             RGBColor[
             0.7314838484501698, 0.504242577778165, 0.5743944759737214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 254}], {
             RGBColor[
             0.43007991849913185`, 0.5356303158314321, 0.9501478343440324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 276}], {
             RGBColor[
             0.6216008719460259, 0.7036826165027719, 0.9633538441200625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 283}], {
             RGBColor[
             0.4024378733893724, 0.5065767738141891, 0.9485736607677728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 315}], {
             RGBColor[
             0.40458060190845924`, 0.5088289173445842, 0.948695685987052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 325}], {
             RGBColor[
             0.40133925395865816`, 0.5054220551360133, 0.9485110960164554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 368}], {
             RGBColor[
             0.5158816187650146, 0.6166272342584453, 0.9553704626805029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 401}], {
             RGBColor[
             0.6985569826136641, 0.7641508706261513, 0.9707851169753527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 450}], {
             RGBColor[
             0.7206850354992045, 0.4212381693670362, 0.5640535204963621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 454}], {
             RGBColor[
             0.761772006870989, 0.6718134516549312, 0.6008439261608904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 471}], {
             RGBColor[
             0.7402370852900231, 0.5715237918221177, 0.5827765854569318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 475}], {
             RGBColor[
             0.731332489294519, 0.5030791649818271, 0.5742495342753344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 114}], {
             RGBColor[
             0.443439320562669, 0.5572206362112937, 0.9498318505944043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 199}], {
             RGBColor[
             0.3645220176644419, 0.4901523831167798, 0.9444479985247825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 208}], {
             RGBColor[
             0.3541593410951509, 0.4811767535157284, 0.9437876979371422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 220}], {
             RGBColor[
             0.36255668140028763`, 0.48845010762544216`, 0.9443227690359091]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 289}], {
             RGBColor[
             0.41278560473143366`, 0.5319558764357888, 0.9475233116148768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 291}], {
             RGBColor[
             0.5205636488996574, 0.6196411124817705, 0.9560349926032045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 297}], {
             RGBColor[
             0.4527821832454718, 0.5648055930283604, 0.9505673549688282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 314}], {
             RGBColor[
             0.35813781501059505`, 0.484622707657373, 0.944041202777008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 349}], {
             RGBColor[
             0.3999008136180363, 0.5207957179817955, 0.9467023041187045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 359}], {
             RGBColor[
             0.38582570994179444`, 0.508604570612715, 0.9458054509585798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 371}], {
             RGBColor[
             0.37457203795785354`, 0.49885720556622565`, 0.9450883769309946]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 397}], {
             RGBColor[
             0.37237410523066483`, 0.4969534667092458, 0.9449483266011737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 419}], {
             RGBColor[
             0.44944534633244004`, 0.5620965984995714, 0.950304666943798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 472}], {
             RGBColor[
             0.35732343693452717`, 0.4839173342997152, 0.9439893113261273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 102}], {
             RGBColor[
             0.2545321161274702, 0.38485977069120125`, 0.9378065995157133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 186}], {
             RGBColor[
             0.23411854278577374`, 0.36340381081377343`, 0.9366440767130793]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 191}], {
             RGBColor[
             0.22546402831064583`, 0.35430736737250323`, 0.9361512149169275]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 202}], {
             RGBColor[
             0.2357918679274276, 0.3651625816325934, 0.9367393701044336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 212}], {
             RGBColor[
             0.22552146354030395`, 0.35436773544047784`, 0.9361544857682886]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 295}], {
             RGBColor[
             0.23105727915165333`, 0.3601862286389881, 0.9364697422778497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 300}], {
             RGBColor[
             0.22924216126039493`, 0.3582784246501542, 0.9363663739991688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 389}], {
             RGBColor[
             0.2255132290582107, 0.3543590804777015, 0.9361540168267153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 451}], {
             RGBColor[
             0.22198624668627384`, 0.3506519983811976, 0.9359531603983363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 456}], {
             RGBColor[
             0.22809260204387605`, 0.3570701650273288, 0.9363009083024085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 485}], {
             RGBColor[
             0.24026393309017596`, 0.36986300566395003`, 0.9369940475996247]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 85}], {
             RGBColor[
             0.22334491181980198`, 0.3520800415808806, 0.9360305343677259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 95}], {
             RGBColor[
             0.2297785943922997, 0.3588422498836111, 0.9363969230724491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[
             0.23210438822814727`, 0.3612868066689332, 0.936529373590697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 137}], {
             RGBColor[
             0.22627740530250587`, 0.35516227816202806`, 0.9361975355333305]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 145}], {
             RGBColor[
             0.22656621784669417`, 0.3554658384577429, 0.9362139829804621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 174}], {
             RGBColor[
             0.2495656884148965, 0.3796397402755821, 0.9375237688046536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 248}], {
             RGBColor[
             0.2375069627028864, 0.3669652549848901, 0.9368370422146407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 286}], {
             RGBColor[
             0.2277872668823118, 0.3567492384131574, 0.9362835199166604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 294}], {
             RGBColor[
             0.23539350574473433`, 0.36474387772096156`, 0.9367166839674533]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 346}], {
             RGBColor[
             0.22517846281523107`, 0.3540072199309242, 0.9361349523844199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 358}], {
             RGBColor[
             0.22905024080537584`, 0.3580767040834695, 0.9363554444131764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 407}], {
             RGBColor[
             0.22341630550160935`, 0.352155080867081, 0.9360346001322872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 411}], {
             RGBColor[
             0.23603211668449622`, 0.3654150983089235, 0.9367530519157325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 430}], {
             RGBColor[
             0.2361066473396595, 0.36549343475301654`, 0.9367572963262859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 110}], {
             RGBColor[
             0.2824315567297242, 0.4141838516908727, 0.9393954313844881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 217}], {
             RGBColor[
             0.30643378623989703`, 0.43839711764350564`, 0.9407994722898634]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 290}], {
             RGBColor[
             0.2898165263474991, 0.4219459229932718, 0.9398159944791369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 316}], {
             RGBColor[
             0.2718214258604257, 0.4030319314260883, 0.9387912001277635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 340}], {
             RGBColor[
             0.31529118717805316`, 0.446068953150221, 0.9413638580453506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 355}], {
             RGBColor[
             0.3109273076150301, 0.4422891800076947, 0.941085795498422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 362}], {
             RGBColor[
             0.34080467652755875`, 0.4681674552795022, 0.9429895550260083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 378}], {
             RGBColor[
             0.2881161193118442, 0.42015868738676554`, 0.939719158813983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 384}], {
             RGBColor[
             0.28848430619933074`, 0.4205456751499109, 0.9397401265125418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 57}], {
             RGBColor[
             0.5489601186307986, 0.6447095805328258, 0.9576352979272409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 106}], {
             RGBColor[
             0.5072662938524296, 0.6108606552923443, 0.9543530073111751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 117}], {
             RGBColor[
             0.4388762614701655, 0.5533769866678013, 0.9495110781480034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 139}], {
             RGBColor[
             0.5303562146824653, 0.6296060932112468, 0.9561707304600824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 140}], {
             RGBColor[
             0.4981556569200065, 0.6034642298010868, 0.9536357845984921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 247}], {
             RGBColor[
             0.4958443155073958, 0.6015877787175854, 0.9534538273357688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 255}], {
             RGBColor[
             0.44713138767076954`, 0.5605271620680575, 0.9500370874897843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 269}], {
             RGBColor[
             0.4728082951441619, 0.5827672087626157, 0.9516731973287911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 360}], {
             RGBColor[
             0.5380217860131518, 0.6358293493475512, 0.9567741923151472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 369}], {
             RGBColor[
             0.4583123366675063, 0.5702115381181944, 0.9507495276729314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 370}], {
             RGBColor[
             0.5440602935407461, 0.6407316817901163, 0.9572495657475013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 425}], {
             RGBColor[
             0.43601004951768985`, 0.5508944179345684, 0.9493284456568833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 466}], {
             RGBColor[
             0.5000927113166715, 0.6050368178236056, 0.9537882766162615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 468}], {
             RGBColor[
             0.48752713657842917`, 0.5948355181784093, 0.9527990685436503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 52}], {
             RGBColor[
             0.5592887582023336, 0.3453473306953461, 0.5606630483713451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 56}], {
             RGBColor[
             0.5597280401148761, 0.3487238439697099, 0.5610837052268939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 179}], {
             RGBColor[
             0.2308558043838454, 0.3599744658837838, 0.9364582685878783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 236}], {
             RGBColor[
             0.285052814306115, 0.4169389596009889, 0.9395447081256605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 243}], {
             RGBColor[
             0.5610442905289292, 0.35884112143673136`, 0.5623441481098833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 254}], {
             RGBColor[
             0.25964036057789125`, 0.3902288594899984, 0.9380975064801944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 276}], {
             RGBColor[
             0.4511613140247853, 0.5582811601613382, 0.9513035162562244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 283}], {
             RGBColor[
             0.23199831546813182`, 0.3611753174727555, 0.9365233329039347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 292}], {
             RGBColor[
             0.23087655194201073`, 0.35999627288288677`, 0.9364594501306225]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 386}], {
             RGBColor[
             0.23085473585284239`, 0.35997334278995086`, 0.9364582077366184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 422}], {
             RGBColor[
             0.2583972380161019, 0.3889222588590351, 0.9380267124893356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 53}], {
             RGBColor[
             0.9470835767696775, 0.821834287485996, 0.3079282681448157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 68}], {
             RGBColor[
             0.8688206529626022, 0.4329330984324026, 0.20968686128144703`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 90}], {
             RGBColor[
             0.8912123121580973, 0.5950344530170778, 0.2307371435474895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 205}], {
             RGBColor[
             0.9557407049755898, 0.8502199530826348, 0.4110195083871594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 257}], {
             RGBColor[
             0.8882541401217813, 0.5816020846987996, 0.22826877228895565`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 272}], {
             RGBColor[
             0.8691188894851287, 0.4352254750326188, 0.20997245291222838`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 293}], {
             RGBColor[
             0.9359635798708703, 0.8383264425596675, 0.6074452935938994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 298}], {
             RGBColor[
             0.9096473304128414, 0.8178215341712867, 0.6215408826637097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 306}], {
             RGBColor[
             0.8876171805650555, 0.5774114462757728, 0.22768643734119767`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 317}], {
             RGBColor[
             0.9005275853462438, 0.6373329329271229, 0.23851003583391922`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 357}], {
             RGBColor[
             0.9123985653292456, 0.6903965335177349, 0.2483720332752017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 418}], {
             RGBColor[
             0.9480641688610301, 0.8473510420156326, 0.586962152772621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 420}], {
             RGBColor[
             0.9431488383406506, 0.8436851965616485, 0.5952825252201055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 55}], {
             RGBColor[
             0.22170565849658444`, 0.35035708240351526`, 0.9359371813160265]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 189}], {
             RGBColor[
             0.24585450838109163`, 0.3757390547576487, 0.9373124225919274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 230}], {
             RGBColor[
             0.22790583767600858`, 0.3568738638351552, 0.9362902723479516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 242}], {
             RGBColor[
             0.2284706396727983, 0.35746750654429615`, 0.9363224369861192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 339}], {
             RGBColor[
             0.22181216919966315`, 0.3504690319056196, 0.9359432469429985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 364}], {
             RGBColor[
             0.24525016381875867`, 0.3751038503049783, 0.93727800606315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 365}], {
             RGBColor[
             0.22445415871552787`, 0.3532459303986038, 0.9360937043374536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 374}], {
             RGBColor[
             0.24183198733731956`, 0.37151113009807946`, 0.9370833459692711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 437}], {
             RGBColor[
             0.2438820574631478, 0.37366588378227833`, 0.93720009443013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 78}], {
             RGBColor[
             0.21346998781254425`, 0.3417008703429085, 0.9354681720541533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 85}], {
             RGBColor[
             0.21086321568284044`, 0.3389609875556907, 0.9353197202377406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 95}], {
             RGBColor[
             0.21729689825533816`, 0.34572319585842115`, 0.9356861089424638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 137}], {
             RGBColor[
             0.21379570916554433`, 0.34204322413683813`, 0.9354867214033452]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 145}], {
             RGBColor[
             0.21408452170973263`, 0.34234678443255295`, 0.9355031688504769]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 183}], {
             RGBColor[
             0.20623910902756293`, 0.3341007582756985, 0.9350563842044752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 346}], {
             RGBColor[
             0.21269676667826953`, 0.34088816590573434`, 0.9354241382544346]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 358}], {
             RGBColor[
             0.2165685446684143, 0.3449576500582796, 0.9356446302831911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 404}], {
             RGBColor[
             0.21047959213928613`, 0.3385577748882776, 0.9352978734444553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 407}], {
             RGBColor[
             0.2109346093646478, 0.33903602684189116`, 0.935323786002302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 408}], {
             RGBColor[
             0.21500770505426564`, 0.34331710866086196`, 0.9355557427762207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 71}], {
             RGBColor[
             0.6229981269292593, 0.7030794824142605, 0.9646517716159538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 76}], {
             RGBColor[
             0.45077000854144356`, 0.5638542255344485, 0.9502204534950804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 238}], {
             RGBColor[
             0.4051843179606758, 0.5243701915568157, 0.9473157736011174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 328}], {
             RGBColor[
             0.4377638604952656, 0.5525889538048573, 0.9493917132424632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 402}], {
             RGBColor[
             0.521262974366249, 0.6222237910767345, 0.9554548772727531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 431}], {
             RGBColor[
             0.4693773227785792, 0.5799709458958486, 0.9514060951044689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 436}], {
             RGBColor[
             0.4815672646188717, 0.5899970256324685, 0.9523298855912635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 459}], {
             RGBColor[
             0.44038041665413563`, 0.554855283237734, 0.9495584378871766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 462}], {
             RGBColor[
             0.4770465403942916, 0.586326898050649, 0.9519739976203461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 487}], {
             RGBColor[
             0.5348230464505574, 0.633232468469062, 0.9565223758194106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 57}], {
             RGBColor[
             0.5210905073010532, 0.6217476292469348, 0.9555341779806428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 92}], {
             RGBColor[
             0.5250378077135244, 0.6249522255456361, 0.9558449239285502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 106}], {
             RGBColor[
             0.47939668252268425`, 0.5878987040064534, 0.9522518873645769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 117}], {
             RGBColor[
             0.41100665014042015`, 0.5304150353819104, 0.9474099582014052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 139}], {
             RGBColor[
             0.50248660335272, 0.6066441419253559, 0.9540696105134843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 140}], {
             RGBColor[
             0.47028604559026116`, 0.5805022785151959, 0.9515346646518938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 169}], {
             RGBColor[
             0.46684010556596744`, 0.5777047091656451, 0.9512633876302873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 204}], {
             RGBColor[
             0.47141553909134676`, 0.5814192522224795, 0.9516235825177704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 219}], {
             RGBColor[
             0.48360346312109975`, 0.5913139580095534, 0.9525830605432293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 244}], {
             RGBColor[
             0.3916895278498226, 0.5136835149605915, 0.9461790882505088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 255}], {
             RGBColor[
             0.41926177634102413`, 0.5375652107821666, 0.9479359675431862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 274}], {
             RGBColor[
             0.4518361438965558, 0.5655238171616463, 0.9500822208063486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 334}], {
             RGBColor[
             0.42187105269828507`, 0.539825234816783, 0.9481022283253784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 338}], {
             RGBColor[
             0.3805216773222415, 0.5040104841460892, 0.9454674826902338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 340}], {
             RGBColor[
             0.3891862943583425, 0.5115153399264449, 0.9460195844259542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 361}], {
             RGBColor[
             0.5425697371949871, 0.6391572117563517, 0.9572443985054486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 363}], {
             RGBColor[
             0.422874692158388, 0.5406945368727382, 0.9481661793442926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 369}], {
             RGBColor[
             0.43044272533776096`, 0.5472495868323034, 0.9486484077263333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 370}], {
             RGBColor[
             0.5161906822110007, 0.6177697305042253, 0.9551484458009031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 379}], {
             RGBColor[
             0.37511861305326666`, 0.49933062144220947`, 0.9451232042127569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[
             0.18179934664985797`, 0.3084130184462969, 0.9336645758924533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 113}], {
             RGBColor[
             0.17905963075308248`, 0.3055334033307651, 0.9335085531251784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 127}], {
             RGBColor[
             0.20245340605759676`, 0.3301217444268325, 0.9348407940207814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 130}], {
             RGBColor[
             0.1789270004053139, 0.3053940004260106, 0.9335010000230821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 143}], {
             RGBColor[
             0.17892700107920537`, 0.30539400113431325`, 0.9335010000614592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 179}], {
             RGBColor[
             0.1789280689363169, 0.30539512351984355`, 0.9335010608743419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 214}], {
             RGBColor[
             0.1893670578318586, 0.31636716271918164`, 0.9340955458488429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 302}], {
             RGBColor[
             0.18453817957609825`, 0.31129170550381263`, 0.9338205483758626]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 308}], {
             RGBColor[
             0.1789366427891193, 0.3054041351827525, 0.9335015491425751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 315}], {
             RGBColor[
             0.1822133085396902, 0.30884811863921036`, 0.9336881504096776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 325}], {
             RGBColor[
             0.17897196058988912`, 0.30544125643063946`, 0.933503560439081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 347}], {
             RGBColor[
             0.1789270004053139, 0.3053940004260106, 0.9335010000230821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 386}], {
             RGBColor[
             0.1789270004053139, 0.3053940004260106, 0.9335010000230821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 421}], {
             RGBColor[
             0.17899180329589925`, 0.30546211237275633`, 0.9335046904518336]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 423}], {
             RGBColor[
             0.18337644614132015`, 0.31007065000570677`, 0.9337543893753826]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 477}], {
             RGBColor[
             0.21179931412463662`, 0.3399448863700877, 0.9353730296591674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 56}], {
             RGBColor[
             0.836234326611525, 0.27951848908515425`, 0.18233133812500216`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 88}], {
             RGBColor[
             0.8512025856554928, 0.3816657696999445, 0.19615962002028325`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 166}], {
             RGBColor[
             0.8369577282992072, 0.2850788714533209, 0.18302406839809204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 210}], {
             RGBColor[
             0.8359293793650189, 0.2771745309197725, 0.1820393202973592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 227}], {
             RGBColor[
             0.8407131059122084, 0.31394434940381033`, 0.18662022224139424`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 236}], {
             RGBColor[
             0.5615591008027638, 0.3477336047164332, 0.5607923410237687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 243}], {
             RGBColor[
             0.837550577025578, 0.2896357665521757, 0.18359178100799164`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 276}], {
             RGBColor[
             0.7276676005214341, 0.4890758052767825, 0.5725511491543327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 326}], {
             RGBColor[
             0.8554852780065134, 0.4011124754177182, 0.19973320349637064`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 428}], {
             RGBColor[
             0.8330642703587228, 0.25515204759860854`, 0.17929568867725226`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 469}], {
             RGBColor[
             0.8481128613393234, 0.36763605320366755`, 0.19358147831479822`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 495}], {
             RGBColor[
             0.8389987580384334, 0.3007671204139477, 0.18497856078138836`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 90}], {
             RGBColor[
             0.9206410418975434, 0.7056328015929743, 0.28606405077970154`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 178}], {
             RGBColor[
             0.9840984713626098, 0.9616310168446078, 0.5753629014776818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 257}], {
             RGBColor[
             0.9176828698612274, 0.692200433274696, 0.28359567952116765`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 272}], {
             RGBColor[
             0.8985476192245749, 0.5458238236085153, 0.2652993601444404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[
             0.9653923096103165, 0.9489247911355639, 0.6627722008261114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 298}], {
             RGBColor[
             0.9390760601522875, 0.9284198827471832, 0.6768677898959217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 306}], {
             RGBColor[
             0.9170459103045016, 0.6880097948516692, 0.28301334457340965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 317}], {
             RGBColor[
             0.9299563150856899, 0.7479312815030192, 0.29383694306613123`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 357}], {
             RGBColor[
             0.9418272950686917, 0.8009948820936315, 0.3036989405074137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 418}], {
             RGBColor[
             0.9774928986004763, 0.9579493905915291, 0.642289060004833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 420}], {
             RGBColor[
             0.9725775680800968, 0.9542835451375451, 0.6506094324523175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 432}], {
             RGBColor[
             0.9375683877182548, 0.9272177056729635, 0.6767239867532486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 55}], {
             RGBColor[
             0.22009923076516985`, 0.34866862500439766`, 0.9358456976332195]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 70}], {
             RGBColor[
             0.24348548029858347`, 0.3732490560378767, 0.9371775099472914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 84}], {
             RGBColor[
             0.23101754524273913`, 0.3601444657814439, 0.9364674794905181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 131}], {
             RGBColor[
             0.24616492351091418`, 0.3760653207405481, 0.9373301002743527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 135}], {
             RGBColor[
             0.23967378277683635`, 0.36924272026693905`, 0.9369604394123292]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 147}], {
             RGBColor[
             0.2401069833110282, 0.36969804149487495`, 0.9369851095418886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 230}], {
             RGBColor[
             0.22629940994459397`, 0.3551854064360376, 0.9361987886651444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 242}], {
             RGBColor[
             0.22686421194138368`, 0.35577904914517844`, 0.936230953303312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 365}], {
             RGBColor[
             0.22284773098411328`, 0.35155747299948614`, 0.9360022206546466]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 374}], {
             RGBColor[
             0.24022555960590497`, 0.3698226726989618, 0.9369918622864639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 385}], {
             RGBColor[
             0.23109619211781043`, 0.36022712863364376`, 0.9364719583137058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 391}], {
             RGBColor[
             0.23492401226674847`, 0.36425041030799266`, 0.9366899470084354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 230}], {
             RGBColor[
             0.21767784356668446`, 0.34612359353397393`, 0.935707803214387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 242}], {
             RGBColor[
             0.21824264556347417`, 0.34671723624311485`, 0.9357399678525544]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 250}], {
             RGBColor[
             0.20796149957955015`, 0.33591109995170554`, 0.9351544717983624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 339}], {
             RGBColor[
             0.21158417509033906`, 0.33971876160443837`, 0.9353607778094337]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 365}], {
             RGBColor[
             0.21422616460620378`, 0.3424956600974225, 0.935511235203889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 88}], {
             RGBColor[
             0.8516418675680354, 0.38504228297430826`, 0.19658027687583196`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 164}], {
             RGBColor[
             0.8270991589089857, 0.20930158706742483`, 0.17358349121635427`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 166}], {
             RGBColor[
             0.8373970102117498, 0.28845538472768467`, 0.18344472525364075`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 210}], {
             RGBColor[
             0.8363686612775614, 0.28055104419413623`, 0.18245997715290796`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 227}], {
             RGBColor[
             0.8411523878247509, 0.31732086267817405`, 0.187040879096943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 236}], {
             RGBColor[
             0.5619983827153064, 0.35111011799079705`, 0.5612129978793174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 243}], {
             RGBColor[
             0.8379898589381207, 0.2930122798265395, 0.18401243786354038`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 276}], {
             RGBColor[
             0.7281068824339767, 0.4924523185511463, 0.5729718060098814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 326}], {
             RGBColor[
             0.8559245599190561, 0.404488988692082, 0.2001538603519194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 428}], {
             RGBColor[
             0.8335035522712653, 0.25852856087297227`, 0.179716345532801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 495}], {
             RGBColor[
             0.839438039950976, 0.30414363368831143`, 0.18539921763693712`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 92}], {
             RGBColor[
             0.6051902881840892, 0.690359765316458, 0.9620619428523739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 106}], {
             RGBColor[
             0.5595491629932491, 0.6533062437772754, 0.9584689062884005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 139}], {
             RGBColor[
             0.5826390838232848, 0.6720516816961779, 0.9602866294373078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 140}], {
             RGBColor[
             0.550438526060826, 0.6459098182860178, 0.9577516835757175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 169}], {
             RGBColor[
             0.5469925860365322, 0.6431122489364671, 0.9574804065541109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 175}], {
             RGBColor[
             0.7784866261079177, 0.8268297266210345, 0.9607862455954495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 204}], {
             RGBColor[
             0.5515680195619116, 0.6468267919933015, 0.9578406014415939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 219}], {
             RGBColor[
             0.5637559435916646, 0.6567214977803754, 0.9588000794670529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 255}], {
             RGBColor[
             0.499414256811589, 0.6029727505529885, 0.9541529864670097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 274}], {
             RGBColor[
             0.5319886243671207, 0.6309313569324684, 0.9562992397301722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 334}], {
             RGBColor[
             0.5020235331688498, 0.6052327745876049, 0.9543192472492019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 337}], {
             RGBColor[
             0.730726843956438, 0.7892639238928545, 0.9741400277373693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 361}], {
             RGBColor[
             0.622722217665552, 0.7045647515271736, 0.9634614174292722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 363}], {
             RGBColor[
             0.5030271726289528, 0.6061020766435601, 0.9543831982681161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 369}], {
             RGBColor[
             0.5105952058083258, 0.6126571266031253, 0.9548654266501568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 370}], {
             RGBColor[
             0.5963431626815656, 0.6831772702750474, 0.9613654647247267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 466}], {
             RGBColor[
             0.552375580457491, 0.6474824063085367, 0.957904175593487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 118}], {
             RGBColor[
             0.3201099243225116, 0.4516848600807156, 0.9416180992091068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 141}], {
             RGBColor[
             0.3123473120692484, 0.44496127550717535`, 0.9411234724205373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 188}], {
             RGBColor[
             0.32619444448890195`, 0.45695496563196736`, 0.9420057994537792]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 220}], {
             RGBColor[
             0.32701247471585293`, 0.45766350229915764`, 0.9420579236164848]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 240}], {
             RGBColor[
             0.2858686487739417, 0.41720789684373627`, 0.9396127186286245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 304}], {
             RGBColor[
             0.3268378953241502, 0.4575122904046801, 0.94204679957202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 310}], {
             RGBColor[
             0.3059344073310527, 0.43829828132983367`, 0.9407554338938223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 371}], {
             RGBColor[
             0.3390278312734188, 0.4680706002399412, 0.9428235315115703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 382}], {
             RGBColor[
             0.2986682199237062, 0.43066105766182183`, 0.9403416352703349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 429}], {
             RGBColor[
             0.3043548555603097, 0.4366380722694161, 0.9406654807572159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 74}], {
             RGBColor[
             0.26196255890659237`, 0.3926696371693413, 0.9382297522396293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 82}], {
             RGBColor[
             0.25023486400687867`, 0.3803430862509384, 0.9375618773646605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 105}], {
             RGBColor[
             0.2440481876886619, 0.3738404971825583, 0.9372095553007055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 153}], {
             RGBColor[
             0.24356203444566857`, 0.3733295193002764, 0.9371818695927163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 195}], {
             RGBColor[
             0.2561715150223729, 0.3865828828736374, 0.9378999608575047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 263}], {
             RGBColor[
             0.25779587834217144`, 0.38829019171332857`, 0.9379924659455371]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 323}], {
             RGBColor[
             0.24076788547771533`, 0.3703926915756808, 0.9370227469425643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 342}], {
             RGBColor[
             0.25108912406320616`, 0.3812409677333546, 0.9376105262111039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 395}], {
             RGBColor[
             0.2535893388235434, 0.38386885196924064`, 0.9377529097429688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 447}], {
             RGBColor[
             0.2443455259866942, 0.3741530185861272, 0.9372264882769058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 453}], {
             RGBColor[
             0.26324896867774317`, 0.3940217354019111, 0.9383030113730237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 463}], {
             RGBColor[
             0.2546442329532448, 0.38497761258370766`, 0.9378129844030793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 116}], {
             RGBColor[
             0.27071777339856856`, 0.4018719227130688, 0.9387283487527682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 118}], {
             RGBColor[
             0.30890885152103453`, 0.4405003788871604, 0.9409586647466246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 133}], {
             RGBColor[
             0.31894163191943015`, 0.44919026900604586`, 0.9415979446419711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 151}], {
             RGBColor[
             0.2997519610227203, 0.4323886947798715, 0.9403818027857322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 188}], {
             RGBColor[
             0.31499337168742486`, 0.44577048443841216`, 0.9413463649912971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 192}], {
             RGBColor[
             0.2736621188386635, 0.4049666164528918, 0.9388960248698129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 249}], {
             RGBColor[
             0.29112873348308044`, 0.42332513589150556`, 0.9398907227342717]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 260}], {
             RGBColor[
             0.2891430137819674, 0.4212380185837349, 0.9397776389349024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 280}], {
             RGBColor[
             0.2748009878347767, 0.4061636399762716, 0.9389608817743358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 310}], {
             RGBColor[
             0.2947333345295756, 0.4271138001362785, 0.9400959994313403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 327}], {
             RGBColor[
             0.27488937913222444`, 0.40625654483422113`, 0.9389659155279624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 483}], {
             RGBColor[
             0.29467938491288026`, 0.4270570956685284, 0.9400929270804808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 64}], {
             RGBColor[
             0.3058305702683475, 0.43738338551197825`, 0.9407790232185906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 91}], {
             RGBColor[
             0.32572776888358806`, 0.4565507546784424, 0.9419760632968737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 172}], {
             RGBColor[
             0.3377395733706075, 0.4669547759942509, 0.9427414448571648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 303}], {
             RGBColor[
             0.31454260624684305`, 0.4465402877003618, 0.9412751607792637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 362}], {
             RGBColor[
             0.3561441161626767, 0.48289586592152384`, 0.9439141660493773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 384}], {
             RGBColor[
             0.3038237458344487, 0.43527408579193255`, 0.9406647375359107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 435}], {
             RGBColor[
             0.2909721876561818, 0.42176628331072286`, 0.9399328603098349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 473}], {
             RGBColor[
             0.3253289757704718, 0.4562053401277858, 0.9419506525523447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 132}], {
             RGBColor[
             0.9037259559281465, 0.5621573598635239, 0.4887023579770914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 209}], {
             RGBColor[
             0.6916212861064526, 0.39630413817282756`, 0.5615943615662011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 233}], {
             RGBColor[
             0.8302393984490122, 0.2334388442338099, 0.17659058814627704`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 75}], {
             RGBColor[
             0.38214205273411095`, 0.5054139718854141, 0.9455707315786365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 149}], {
             RGBColor[
             0.3866051837093468, 0.5092797116126782, 0.9458551183377868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 158}], {
             RGBColor[
             0.38842846253649266`, 0.5108589440920934, 0.9459712960523903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 165}], {
             RGBColor[
             0.42168442508772075`, 0.5396635873606885, 0.9480903365790616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 182}], {
             RGBColor[
             0.3989611276124065, 0.5199818091937107, 0.9466424281573576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 206}], {
             RGBColor[
             0.3810348762200533, 0.5044549912372471, 0.9455001832701985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 252}], {
             RGBColor[
             0.5775658026497799, 0.6655789256820774, 0.9611207995905398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 275}], {
             RGBColor[
             0.41651977831287657`, 0.5351902299070133, 0.9477612498534863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 282}], {
             RGBColor[
             0.5134969921724348, 0.6149963149023026, 0.9550984560118821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 324}], {
             RGBColor[
             0.3945065223315428, 0.5161234539943981, 0.9463585846479137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 410}], {
             RGBColor[
             0.39150030357105375`, 0.5135196184010107, 0.9461670310467902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 441}], {
             RGBColor[
             0.4347339982883702, 0.5509664717764713, 0.9489218438441225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 467}], {
             RGBColor[
             0.563087381667329, 0.6542682731705118, 0.9596777258955458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 91}], {
             RGBColor[
             0.3077316474117898, 0.43903000298271255`, 0.9409001581731142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 172}], {
             RGBColor[
             0.31974345189880926`, 0.449434024298521, 0.9416655397334055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 303}], {
             RGBColor[
             0.29654648477504475`, 0.4290195360046319, 0.9401992556555043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 366}], {
             RGBColor[
             0.27642037277284975`, 0.4078657162211217, 0.9390531033508938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 384}], {
             RGBColor[
             0.28582762436265047`, 0.41775333409620263`, 0.9395888324121513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 435}], {
             RGBColor[
             0.2729760661843835, 0.4042455316149929, 0.9388569551860756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 473}], {
             RGBColor[
             0.3073328542986736, 0.43868458843205593`, 0.9408747474285853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 88}], {
             RGBColor[
             0.9260374771709088, 0.7249105779401631, 0.30422129427437533`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 166}], {
             RGBColor[
             0.9117926198146232, 0.6283236796935395, 0.2910857426521841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 167}], {
             RGBColor[
             0.986067541242265, 0.9756937071602725, 0.6343029674871418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 175}], {
             RGBColor[
             0.9705975460870158, 0.9645679382577699, 0.6789276620320353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[
             0.9107642708804349, 0.6204193391599911, 0.29010099455145133`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 227}], {
             RGBColor[
             0.9155479974276244, 0.657189157644029, 0.2946818964954864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 309}], {
             RGBColor[
             0.9892477963467572, 0.9750667140916796, 0.4404269945442838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 320}], {
             RGBColor[
             0.9870336626851595, 0.9760932232050978, 0.618291834936235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 337}], {
             RGBColor[
             0.9228377639355362, 0.92700213552959, 0.6922814441739551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 348}], {
             RGBColor[
             0.9726882187211612, 0.9195330900145834, 0.3483993164391773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 428}], {
             RGBColor[
             0.9078991618741388, 0.5983968558388272, 0.2873573629313444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 434}], {
             RGBColor[
             0.9883337030612244, 0.9766308233101144, 0.5967468015081936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 474}], {
             RGBColor[
             0.989280991001634, 0.9770225512176633, 0.5810477888330006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 495}], {
             RGBColor[
             0.9138336495538494, 0.6440119286541663, 0.2930402350354805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 208}], {
             RGBColor[
             0.2926997987840062, 0.4237400438284219, 0.9400254625551399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 305}], {
             RGBColor[
             0.25719647261268064`, 0.38766017828711546`, 0.9379583306759838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 314}], {
             RGBColor[
             0.29667827269945046`, 0.4271859979700665, 0.9402789673950056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 394}], {
             RGBColor[
             0.24596177604056546`, 0.3758517998689181, 0.937318531326446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 398}], {
             RGBColor[
             0.26221606410223275`, 0.392936087203117, 0.9382441889854937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 427}], {
             RGBColor[
             0.271390600085227, 0.40257910622042264`, 0.9387666652372155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 445}], {
             RGBColor[
             0.24646019520379875`, 0.3763756700110764, 0.9373469155604471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 460}], {
             RGBColor[
             0.2558136629427209, 0.38620675764879087`, 0.9378795817109632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 472}], {
             RGBColor[
             0.29586389462338253`, 0.42648062461240877`, 0.9402270759441249]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 70}], {
             RGBColor[
             0.25743661729140077`, 0.3879125855705024, 0.9379720065601748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 96}], {
             RGBColor[
             0.2763924027630132, 0.4078363179673825, 0.9390515105002115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 131}], {
             RGBColor[
             0.2601160605037315, 0.39072885027317383`, 0.938124596887236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 135}], {
             RGBColor[
             0.2536249197696536, 0.3839062497995648, 0.9377549360252124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 147}], {
             RGBColor[
             0.2540581203038455, 0.3843615710275007, 0.9377796061547718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 171}], {
             RGBColor[
             0.25918264815811415`, 0.38974777471616917`, 0.9380714404350129]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 180}], {
             RGBColor[
             0.26337700695553745`, 0.3941563117499686, 0.9383103029635284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 216}], {
             RGBColor[
             0.26125452628926693`, 0.3919254499966715, 0.938189430829513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 238}], {
             RGBColor[
             0.28838849579729153`, 0.41939023215024707`, 0.9397732894571003]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 281}], {
             RGBColor[
             0.25076586641156884`, 0.38090120344576484`, 0.93759211716606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 343}], {
             RGBColor[
             0.2747552896997584, 0.40611560833893834`, 0.9389582793331509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 385}], {
             RGBColor[
             0.24504732911062774`, 0.37489065816626943`, 0.9372664549265891]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 391}], {
             RGBColor[
             0.24887514925956578`, 0.37891393984061833`, 0.9374844436213188]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 465}], {
             RGBColor[
             0.26962432665641767`, 0.4007226408585406, 0.9386660785784122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 205}], {
             RGBColor[
             0.9069065109079608, 0.5719171126049378, 0.3681050087560027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 257}], {
             RGBColor[
             0.8394199460541523, 0.30329924422110266`, 0.18535427265779897`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 272}], {
             RGBColor[
             0.8202846954174998, 0.15692263455492186`, 0.1670579532810717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 306}], {
             RGBColor[
             0.8387829864974263, 0.2991086057980758, 0.18477193771004097`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 317}], {
             RGBColor[
             0.8516933912786147, 0.35903009244942585`, 0.19559553620276254`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 142}], {
             RGBColor[
             0.8044934065793106, 0.8479188521576653, 0.9809561216743297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 173}], {
             RGBColor[
             0.9470127321552729, 0.9592645667466908, 0.9483609186014075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 194}], {
             RGBColor[
             0.9479892988678673, 0.9596684021789683, 0.9321766809000795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 241}], {
             RGBColor[
             0.8074723242442312, 0.8502460052781141, 0.9812530323476005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 388}], {
             RGBColor[
             0.9278173046721767, 0.9450102776472538, 0.9836136557859578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 402}], {
             RGBColor[
             0.7308868707375382, 0.7890374499881754, 0.9745628249690335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 461}], {
             RGBColor[
             0.926959006974305, 0.9443701606295145, 0.985066529908563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 487}], {
             RGBColor[
             0.7444469428218465, 0.8000461273805028, 0.9756303235156909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 490}], {
             RGBColor[
             0.9500080335378767, 0.9605032008441318, 0.8987210231001681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 84}], {
             RGBColor[
             0.24578222839824324`, 0.37566308391285935`, 0.9373083063538328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 96}], {
             RGBColor[
             0.2772059489257, 0.4086914065661722, 0.9390978407506428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 131}], {
             RGBColor[
             0.2609296066664183, 0.3915839388719636, 0.9381709271376673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 135}], {
             RGBColor[
             0.25443846593234043`, 0.3847613383983545, 0.9378012662756438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 147}], {
             RGBColor[
             0.2548716664665323, 0.3852166596262904, 0.9378259364052033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 170}], {
             RGBColor[
             0.2774653661360603, 0.408964070502262, 0.9391126141769994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 171}], {
             RGBColor[
             0.25999619432080096`, 0.39060286331495886`, 0.9381177706854442]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 216}], {
             RGBColor[
             0.26206807245195374`, 0.39278053859546125`, 0.9382357610799443]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[
             0.28920204195997834`, 0.42024532074903687`, 0.9398196197075317]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 265}], {
             RGBColor[
             0.28963233444531233`, 0.42061801847270397`, 0.9398470375642044]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 374}], {
             RGBColor[
             0.2549902427614091, 0.38534129083037727`, 0.9378326891497786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 385}], {
             RGBColor[
             0.24586087527331454`, 0.37574574676505923`, 0.9373127851770204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 391}], {
             RGBColor[
             0.24968869542225258`, 0.3797690284394081, 0.93753077387175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 433}], {
             RGBColor[
             0.2918782074405654, 0.4225632807803333, 0.9399901426055144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 194}], {
             RGBColor[
             0.8711488139703549, 0.898916809896938, 0.9247098602219754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 228}], {
             RGBColor[
             0.8744314209010298, 0.8983757407693698, 0.7323068273714743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 388}], {
             RGBColor[
             0.8509768197746642, 0.8842586853652235, 0.9761468351078537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 431}], {
             RGBColor[
             0.602160734252356, 0.6860330125252593, 0.9630472221226452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 462}], {
             RGBColor[
             0.6098299518680684, 0.6923889646800596, 0.9636151246385223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 487}], {
             RGBColor[
             0.6676064579243342, 0.7392945350984725, 0.9681635028375868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 490}], {
             RGBColor[
             0.8731675486403643, 0.8997516085621015, 0.891254202422064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 73}], {
             RGBColor[
             0.2509474629421924, 0.38109207291333524`, 0.9376024588198308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 144}], {
             RGBColor[
             0.2501061102631632, 0.3802077579028347, 0.93755454502943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 163}], {
             RGBColor[
             0.26048838412385666`, 0.3911201860046064, 0.9381458001665987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 187}], {
             RGBColor[
             0.2593062768219157, 0.38987771628033463`, 0.9380784809045242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 279}], {
             RGBColor[
             0.26627234056032795`, 0.3971994909433567, 0.9384751879290589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 322}], {
             RGBColor[
             0.25660150329804876`, 0.38703482781420406`, 0.9379244480536938]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 494}], {
             RGBColor[
             0.25624399533436604`, 0.3866590642770594, 0.9379040885040477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 93}], {
             RGBColor[
             0.2585978739086303, 0.3891331399031328, 0.9380381384066008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 163}], {
             RGBColor[
             0.2574513896017804, 0.3879281122053299, 0.9379728478213971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 187}], {
             RGBColor[
             0.25626928229983936`, 0.38668564248105813`, 0.9379055285593227]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 322}], {
             RGBColor[
             0.2535645087759725, 0.3838427540149276, 0.9377514957084923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 494}], {
             RGBColor[
             0.25320700081228975`, 0.383466990477783, 0.9377311361588463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 82}], {
             RGBColor[
             0.27000631808527487`, 0.401124138069925, 0.93868783242518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 105}], {
             RGBColor[
             0.2638196417670582, 0.3946215490015449, 0.938335510361225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 112}], {
             RGBColor[
             0.264998769293781, 0.3958608867931338, 0.938402659929509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 153}], {
             RGBColor[
             0.2633334885240648, 0.39411057111926295`, 0.9383078246532357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 195}], {
             RGBColor[
             0.27594296910076915`, 0.40736393469262394`, 0.9390259159180243]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 224}], {
             RGBColor[
             0.2903501525391211, 0.42250679795452123`, 0.9398463837013205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 234}], {
             RGBColor[
             0.335156328175214, 0.4622198560830736, 0.94266828637108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 239}], {
             RGBColor[
             0.31633226480045645`, 0.4459153985127936, 0.9414688336983061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 263}], {
             RGBColor[
             0.27756733242056764`, 0.40907124353231517`, 0.9391184210060566]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 296}], {
             RGBColor[
             0.2975769167094639, 0.42967045866758025`, 0.9402737595026511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 342}], {
             RGBColor[
             0.27086057814160247`, 0.4020220195523411, 0.9387364812716233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 395}], {
             RGBColor[
             0.2733607929019397, 0.4046499037882272, 0.9388788648034883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 440}], {
             RGBColor[
             0.2817039259800564, 0.4134190656385177, 0.9393539938897277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 447}], {
             RGBColor[
             0.26411698006509043`, 0.39493407040511375`, 0.9383524433374253]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 453}], {
             RGBColor[
             0.2830204227561394, 0.41480278722089764`, 0.9394289664335431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 463}], {
             RGBColor[
             0.2744156870316411, 0.4057586644026942, 0.9389389394635987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 93}], {
             RGBColor[
             0.30711689507265494`, 0.43678253795558514`, 0.940923781155411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 108}], {
             RGBColor[
             0.31502960292460824`, 0.4450992956026424, 0.9413743981617775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 149}], {
             RGBColor[
             0.3494116417234011, 0.4770645349462275, 0.9434851787314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 158}], {
             RGBColor[
             0.3512349205505469, 0.4786437674256428, 0.9436013564460036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.3059704107658049, 0.43557751025778224`, 0.9408584905702073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 182}], {
             RGBColor[
             0.3617675856264607, 0.48776663252726005`, 0.9442724885509708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 206}], {
             RGBColor[
             0.34384133423410757`, 0.4722398145707964, 0.9431302436638118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 410}], {
             RGBColor[
             0.354306761585108, 0.48130444173456, 0.9437970914404035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.3537435180123586, 0.4796530871235497, 0.9438038035415315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[
             0.35693445553108405`, 0.4830069647728541, 0.9439855227126539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 238}], {
             RGBColor[
             0.36573961104663694`, 0.49120700130641426`, 0.9445255824984202]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 333}], {
             RGBColor[
             0.3949872182942583, 0.5165398086768207, 0.9463892141695951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 343}], {
             RGBColor[
             0.3521064049491038, 0.47793237749510553`, 0.9437105723744709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 392}], {
             RGBColor[
             0.35866334703698777`, 0.48482413936361163`, 0.9440839805262493]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 402}], {
             RGBColor[
             0.4818182674522101, 0.589060600826333, 0.952664686170056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 431}], {
             RGBColor[
             0.42993261586454035`, 0.5468077556454473, 0.9486159040017718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 436}], {
             RGBColor[
             0.4421225577048329, 0.5568338353820671, 0.9495396944885663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 459}], {
             RGBColor[
             0.40093570974009674`, 0.5216920929873327, 0.9467682467844796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 462}], {
             RGBColor[
             0.4376018334802528, 0.5531637078002476, 0.949183806517649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 487}], {
             RGBColor[
             0.49537833953651855`, 0.6000692782186605, 0.9537321847167134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 81}], {
             RGBColor[
             0.7152180111578499, 0.7769379420233913, 0.972614350327299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 156}], {
             RGBColor[
             0.5370635204917655, 0.6350513862279201, 0.9566987541430614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 278}], {
             RGBColor[
             0.7775908081460805, 0.8263457284855322, 0.9672404849556133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 329}], {
             RGBColor[
             0.7446878798780471, 0.8004364154026, 0.9754252127138938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 479}], {
             RGBColor[
             0.5091542746403608, 0.6112576931750507, 0.9548154361242309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 482}], {
             RGBColor[
             0.4826496570055525, 0.5883007255405965, 0.9531265853256541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 85}], {
             RGBColor[
             0.21682232686548605`, 0.34522439123812265`, 0.9356590828038773]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 95}], {
             RGBColor[
             0.22325600943798377`, 0.3519865995408531, 0.9360254715086005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 97}], {
             RGBColor[
             0.22558180327383132`, 0.35443115632617517`, 0.9361579220268484]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 137}], {
             RGBColor[
             0.21975482034818994`, 0.34830662781927, 0.9358260839694819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 145}], {
             RGBColor[
             0.22004363289237822`, 0.3486101881149849, 0.9358425314166136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 183}], {
             RGBColor[
             0.21219822021020854`, 0.34036416195813046`, 0.935395746770612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 346}], {
             RGBColor[
             0.21865587786091514`, 0.34715156958816623`, 0.9357635008205714]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 358}], {
             RGBColor[
             0.22252765585105994`, 0.3512210537407115, 0.9359839928493279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 404}], {
             RGBColor[
             0.2164387033219317, 0.3448211785707095, 0.935637236010592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 407}], {
             RGBColor[
             0.21689372054729342`, 0.34529943052432305`, 0.9356631485684387]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 408}], {
             RGBColor[
             0.22096681623691122`, 0.34958051234329385`, 0.9358951053423573]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 430}], {
             RGBColor[
             0.22958406238534357`, 0.3586377844102586, 0.9363858447624374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 81}], {
             RGBColor[
             0.9087234308797807, 0.9257016701540246, 0.7763552620147077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 99}], {
             RGBColor[
             0.9937251243023482, 0.9889870003070016, 0.5583966882336657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 122}], {
             RGBColor[
             0.9306665098261713, 0.7402291937878942, 0.3904132893585251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 267}], {
             RGBColor[
             0.9914456607402118, 0.9819881575780944, 0.49084130836277423`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 278}], {
             RGBColor[
             0.9710962278680113, 0.9751094566161655, 0.770981396643022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 329}], {
             RGBColor[
             0.9381932995999778, 0.9492001435332333, 0.7791661244013025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 406}], {
             RGBColor[
             0.9922235479450122, 0.984612153776488, 0.4938632532617516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 413}], {
             RGBColor[
             0.9838323701759427, 0.9563067408191819, 0.46126511216987476`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 476}], {
             RGBColor[
             0.9211605712027758, 0.6814740968415736, 0.3818708025801312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 486}], {
             RGBColor[
             0.9643781566417168, 0.9700792377693064, 0.7816636594414414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 493}], {
             RGBColor[
             0.9937029879453217, 0.9889396528776512, 0.5559872823811043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 156}], {
             RGBColor[
             0.6284260394446897, 0.7069689251123001, 0.9654326763878454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 278}], {
             RGBColor[
             0.8689533270990046, 0.8982632673699124, 0.9759744072003973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 307}], {
             RGBColor[
             0.6296762406643908, 0.7079838947833768, 0.9655310968074982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 329}], {
             RGBColor[
             0.8360503988309712, 0.8723539542869803, 0.9841591349586778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 372}], {
             RGBColor[
             0.6299979927875134, 0.7082451076516956, 0.9655564263132472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 406}], {
             RGBColor[
             0.8900806471760057, 0.9077659645302347, 0.6988562638191269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 417}], {
             RGBColor[
             0.7452877880838611, 0.8009437515388753, 0.9752469796719869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 461}], {
             RGBColor[
             0.8669992096038857, 0.8968058897416262, 0.9792822184041656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 486}], {
             RGBColor[
             0.8622352558727102, 0.8932330485230531, 0.9866566699988166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 493}], {
             RGBColor[
             0.8915600871763152, 0.912093463631398, 0.7609802929384797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 83}], {
             RGBColor[
             0.8721819244967113, 0.9009182081187621, 0.9876706846361336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 99}], {
             RGBColor[
             0.9086198401868935, 0.9254801001365643, 0.7650800543815806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 237}], {
             RGBColor[
             0.8648552697662895, 0.8950761325134684, 0.9869718617673642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[
             0.906340376624757, 0.9184812574076573, 0.6975246745106891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 278}], {
             RGBColor[
             0.8859909437525565, 0.9116025564457284, 0.9776647627909368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 329}], {
             RGBColor[
             0.8530880154845231, 0.8856932433627962, 0.9858494905492173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 426}], {
             RGBColor[
             0.8468962698264015, 0.8807561134454687, 0.9852589163209091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 486}], {
             RGBColor[
             0.879272872526262, 0.9065723375988691, 0.9883470255893563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 89}], {
             RGBColor[
             0.2718901700216876, 0.4031041858982062, 0.9387951150060494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 105}], {
             RGBColor[
             0.25209194686734443`, 0.382294998083142, 0.9376676354862561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 184}], {
             RGBColor[
             0.2576552479933815, 0.38814238030027126`, 0.9379844572552174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 195}], {
             RGBColor[
             0.2642152742010554, 0.39503738377422104`, 0.9383580410430554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 225}], {
             RGBColor[
             0.2662639580467382, 0.39719068039009175`, 0.9384747105573108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 263}], {
             RGBColor[
             0.26583963752085393`, 0.39674469261391226`, 0.9384505461310877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 296}], {
             RGBColor[
             0.28584922180975014`, 0.4173439077491774, 0.9396058846276822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 342}], {
             RGBColor[
             0.2591328832418887, 0.3896954686339382, 0.9380686063966545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 395}], {
             RGBColor[
             0.26163309800222595`, 0.39232335286982434`, 0.9382109899285194]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 440}], {
             RGBColor[
             0.26997623108034263`, 0.40109251472011487`, 0.9386861190147588]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 447}], {
             RGBColor[
             0.25238928516537673`, 0.3826075194867109, 0.9376845684624564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 453}], {
             RGBColor[
             0.27129272785642566`, 0.40247623630249474`, 0.9387610915585742]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 463}], {
             RGBColor[
             0.26268799213192734`, 0.3934321134842913, 0.9382710645886299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 470}], {
             RGBColor[
             0.25688036525862096`, 0.38732792941563493`, 0.937940328829809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 119}], {
             RGBColor[
             0.9556965383033635, 0.9650210547273206, 0.8984817408494732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 176}], {
             RGBColor[
             0.7638451540938651, 0.8157128228854424, 0.9772513951417543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[
             0.8091856625186589, 0.8516756760168047, 0.981399600787607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 237}], {
             RGBColor[
             0.913419047498675, 0.933799570648643, 0.9916039182408752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 270}], {
             RGBColor[
             0.955384395176871, 0.9648919755228036, 0.9036547602559704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 345}], {
             RGBColor[
             0.7902354483667869, 0.8368716246944006, 0.9795108205407682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 375}], {
             RGBColor[
             0.9394735703012015, 0.9539944639741937, 0.9739704912597569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 426}], {
             RGBColor[
             0.895460047558787, 0.9194795515806435, 0.9898909727944203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 448}], {
             RGBColor[
             0.7443425082604527, 0.7998796964136958, 0.9757160754212024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 489}], {
             RGBColor[
             0.9554216482771469, 0.9649073806371287, 0.9030373799764648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 131}], {
             RGBColor[
             0.24846167161057395`, 0.3784793486155308, 0.9374608966808939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 135}], {
             RGBColor[
             0.24197053087649611`, 0.37165674814192173`, 0.9370912358188704]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 147}], {
             RGBColor[
             0.24240373141068797`, 0.37211206936985763`, 0.93711590594843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 171}], {
             RGBColor[
             0.2475282592649566, 0.3774982730585261, 0.9374077402286709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 230}], {
             RGBColor[
             0.22859615804425376`, 0.3575994343110202, 0.9363295850716857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 242}], {
             RGBColor[
             0.22916096004104347`, 0.3581930770201611, 0.9363617497098533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 365}], {
             RGBColor[
             0.22514447908377305`, 0.3539715008744688, 0.9361330170611878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 374}], {
             RGBColor[
             0.24252230770556474`, 0.3722367005739444, 0.9371226586930053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 385}], {
             RGBColor[
             0.2333929402174702, 0.3626411565086264, 0.9366027547202471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 391}], {
             RGBColor[
             0.23722076036640824`, 0.3666644381829753, 0.9368207434149767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 95}], {
             RGBColor[
             0.22064923730827996`, 0.3492467167536353, 0.9358770196921877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 97}], {
             RGBColor[
             0.22297503114412753`, 0.3516912735389574, 0.9360094702104356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 137}], {
             RGBColor[
             0.21714804821848613`, 0.34556674503205226`, 0.9356776321530691]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 145}], {
             RGBColor[
             0.21743686076267443`, 0.3458703053277671, 0.9356940796002007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 183}], {
             RGBColor[
             0.20959144808050473`, 0.33762427917091264`, 0.9352472949541991]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 286}], {
             RGBColor[
             0.21865790979829205`, 0.3471537052831816, 0.935763616536399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 346}], {
             RGBColor[
             0.21604910573121133`, 0.34441168680094847`, 0.9356150490041585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 358}], {
             RGBColor[
             0.2199208837213561, 0.34848117095349374`, 0.935835541032915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 404}], {
             RGBColor[
             0.21383193119222793`, 0.3420812957834917, 0.9354887841941792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 407}], {
             RGBColor[
             0.2142869484175896, 0.3425595477371053, 0.9355146967520258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 408}], {
             RGBColor[
             0.21836004410720744`, 0.3468406295560761, 0.9357466535259444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 90}], {
             RGBColor[
             0.8899814344584336, 0.5901544331035902, 0.2297467504579272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 98}], {
             RGBColor[
             0.9552139147274563, 0.8468459050338089, 0.4866646892725739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 115}], {
             RGBColor[
             0.9181807358610004, 0.8207272885954675, 0.6214818156174652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 124}], {
             RGBColor[
             0.9389228207101663, 0.7935781606519255, 0.2800166062249653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 136}], {
             RGBColor[
             0.942076876818933, 0.8389236960734718, 0.594023128493258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 168}], {
             RGBColor[
             0.912992655814064, 0.6927519043211215, 0.24885005242438252`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[
             0.9534388639235, 0.8461526483552239, 0.5190456011559075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 253}], {
             RGBColor[
             0.9501124692155603, 0.8447770986590462, 0.5741725699000219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 261}], {
             RGBColor[
             0.897589954080166, 0.6247029436909717, 0.23609548573218275`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 357}], {
             RGBColor[
             0.911167687629582, 0.6855165136042474, 0.2473816401856394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 484}], {
             RGBColor[
             0.9540423951293819, 0.8443401430723285, 0.3591520108030784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 500}], {
             RGBColor[
             0.8673428769617186, 0.42615530998421236`, 0.20846003809980468`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 107}], {
             RGBColor[
             0.1819624771956669, 0.3085844789930161, 0.9336738659357071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 113}], {
             RGBColor[
             0.17922276129889142`, 0.3057048638774843, 0.9335178431684322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 143}], {
             RGBColor[
             0.1790901316250143, 0.30556546168103244`, 0.933510290104713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 226}], {
             RGBColor[
             0.17933912709972993`, 0.30582717171218354`, 0.9335244700286423]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 292}], {
             RGBColor[
             0.1791119470402912, 0.3055883910656657, 0.93351153246034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 308}], {
             RGBColor[
             0.17909977333492821`, 0.3055755957294717, 0.9335108391858289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 386}], {
             RGBColor[
             0.17909013095112286`, 0.3055654609727298, 0.9335102900663359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 421}], {
             RGBColor[
             0.17915493384170816`, 0.30563357291947557`, 0.9335139804950874]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 422}], {
             RGBColor[
             0.2066326331143824, 0.33451437704181397`, 0.9350787948190529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 423}], {
             RGBColor[
             0.18353957668712906`, 0.310242110552426, 0.9337636794186364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 446}], {
             RGBColor[
             0.20370226760912918`, 0.33143437709988877`, 0.934911914838616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 166}], {
             RGBColor[
             0.8523652692557177, 0.3906026653424749, 0.19727300714892185`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 167}], {
             RGBColor[
             0.9266401906833595, 0.7379726928092079, 0.5404902319838795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 210}], {
             RGBColor[
             0.8513369203215293, 0.3826983248089265, 0.19628825904818903`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 227}], {
             RGBColor[
             0.8561206468687188, 0.41946814329296433`, 0.20086916099222407`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 243}], {
             RGBColor[
             0.8529581179820884, 0.3951595604413297, 0.19784071975882145`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 326}], {
             RGBColor[
             0.8708928189630238, 0.5066362693068722, 0.21398214224720047`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 348}], {
             RGBColor[
             0.9132608681622556, 0.6818120756635188, 0.2545865809359151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 428}], {
             RGBColor[
             0.8484718113152332, 0.36067584148776255`, 0.1935446274280821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 434}], {
             RGBColor[
             0.9289063525023188, 0.7389098089590498, 0.5029340660049313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 469}], {
             RGBColor[
             0.8635204022958338, 0.47315984709282155`, 0.20783041706562805`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 474}], {
             RGBColor[
             0.9298536404427284, 0.7393015368665987, 0.48723505332973827`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 495}], {
             RGBColor[
             0.8544062989949438, 0.4062909143031017, 0.1992274995322182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 133}], {
             RGBColor[
             0.3153376912434113, 0.4454022988525135, 0.9413927055520241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 184}], {
             RGBColor[
             0.271266794829508, 0.4024489790469554, 0.9387596147110557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 192}], {
             RGBColor[
             0.27005817816264466`, 0.4011786462993594, 0.9386907857798661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 225}], {
             RGBColor[
             0.2798755048828646, 0.4114972791367759, 0.9392498680131491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 235}], {
             RGBColor[
             0.32127172035398965`, 0.45054205661512126`, 0.9417708166396943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 239}], {
             RGBColor[
             0.31821611673686917`, 0.4478954463410748, 0.9415761162791756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 249}], {
             RGBColor[
             0.28752479280706156`, 0.41953716573797317`, 0.9396854836443249]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 260}], {
             RGBColor[
             0.2855390731059485, 0.4174500484302025, 0.9395723998449554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.2711970471587578, 0.4023756698227392, 0.938755642684389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 296}], {
             RGBColor[
             0.2994607686458766, 0.4316505064958615, 0.9403810420835206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 424}], {
             RGBColor[
             0.3030480744366626, 0.4347576504686087, 0.9406096220363795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 440}], {
             RGBColor[
             0.2835877779164691, 0.415399113466799, 0.9394612764705972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 453}], {
             RGBColor[
             0.28490427469255214`, 0.4167828350491789, 0.9395362490144127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 470}], {
             RGBColor[
             0.27049191209474743`, 0.40163452816231904`, 0.9387154862856475]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 124}], {
             RGBColor[
             0.9137111635376958, 0.6822566946723914, 0.2591427819494134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 178}], {
             RGBColor[
             0.9282272067510295, 0.7348311823756897, 0.4981717768803556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[
             0.8618116052496472, 0.4654005988057779, 0.20640455492384144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 261}], {
             RGBColor[
             0.8723782969076955, 0.5133814777114375, 0.21522166145663085`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 272}], {
             RGBColor[
             0.8426763546129947, 0.3190239891395971, 0.18810823554711417`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 306}], {
             RGBColor[
             0.8611746456929213, 0.4612099603827511, 0.20582221997608346`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 317}], {
             RGBColor[
             0.8740850504741097, 0.5211314470341011, 0.21664581846880504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 357}], {
             RGBColor[
             0.8859560304571115, 0.5741950476247133, 0.2265078159100875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 172}], {
             RGBColor[
             0.33964065051404985`, 0.4686013934649852, 0.9428625798116885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 303}], {
             RGBColor[
             0.3164436833902854, 0.44818690517109605`, 0.9413962957337874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 366}], {
             RGBColor[
             0.29631757138809034`, 0.4270330853875859, 0.9402501434291768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 435}], {
             RGBColor[
             0.29287326479962417`, 0.4234129007814571, 0.9400539952643586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 473}], {
             RGBColor[
             0.32723005291391416`, 0.4578519575985201, 0.9420717875068684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 101}], {
             RGBColor[
             0.5649851581111299, 0.6577194295027604, 0.9588968477367864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 128}], {
             RGBColor[
             0.5519404005403256, 0.6471291076471498, 0.9578699166362912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 140}], {
             RGBColor[
             0.554385826473297, 0.649114414584719, 0.9580624295236251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 169}], {
             RGBColor[
             0.5509398864490034, 0.6463168452351683, 0.9577911525020184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 175}], {
             RGBColor[
             0.7824339265203888, 0.8300343229197356, 0.9610969915433571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 204}], {
             RGBColor[
             0.5555153199743827, 0.6500313882920026, 0.9581513473895016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 219}], {
             RGBColor[
             0.5677032440041356, 0.6599260940790765, 0.9591108254149605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 274}], {
             RGBColor[
             0.5359359247795917, 0.6341359532311694, 0.9566099856780799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 320}], {
             RGBColor[
             0.7988700431185324, 0.8415596078670635, 0.9004611644475569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 334}], {
             RGBColor[
             0.505970833581321, 0.6084373708863062, 0.9546299931971096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 337}], {
             RGBColor[
             0.7346741443689091, 0.7924685201915558, 0.974450773685277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 361}], {
             RGBColor[
             0.6266695180780231, 0.7077693478258749, 0.9637721633771799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 363}], {
             RGBColor[
             0.506974473041424, 0.6093066729422614, 0.9546939442160238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 370}], {
             RGBColor[
             0.6002904630940367, 0.6863818665737486, 0.9616762106726342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 498}], {
             RGBColor[
             0.5355135500520953, 0.6337930503996233, 0.9565767347923217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 108}], {
             RGBColor[
             0.27719798724909794`, 0.408683038339264, 0.9390973873449386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 163}], {
             RGBColor[
             0.26813879509029465`, 0.39916125299440397`, 0.9385814797533685]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 187}], {
             RGBColor[
             0.2669566877883537, 0.3979187832701322, 0.9385141604912941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 189}], {
             RGBColor[
             0.26453032177670965`, 0.3953685187514038, 0.9383759825364177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 206}], {
             RGBColor[
             0.30600971855859727`, 0.43582355730741806`, 0.940853232846973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 266}], {
             RGBColor[
             0.2794030113306438, 0.41100065845557043`, 0.9392229602043418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 322}], {
             RGBColor[
             0.26425191426448674`, 0.3950758948040016, 0.9383601276404636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 364}], {
             RGBColor[
             0.2639259772143767, 0.39473331429873343`, 0.9383415660076406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 437}], {
             RGBColor[
             0.26255787085876586`, 0.3932953477760335, 0.9382636543746206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 100}], {
             RGBColor[
             0.943316965793535, 0.8656345224892459, 0.6119300548794735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 127}], {
             RGBColor[
             0.5906994451507328, 0.6605608453144329, 0.9482643190369882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 168}], {
             RGBColor[
             0.9331056494970619, 0.8251500560931704, 0.6037137900969318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 213}], {
             RGBColor[
             0.9298124883323949, 0.8120876909328425, 0.6010637208876998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 214}], {
             RGBColor[
             0.5776130969249946, 0.6468062636067821, 0.9475190708650497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 254}], {
             RGBColor[
             0.5959586642234989, 0.6660886180136586, 0.9485638237828649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 302}], {
             RGBColor[
             0.5727842186692342, 0.6417308063914131, 0.9472440733920693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 315}], {
             RGBColor[
             0.5704593476328262, 0.6392872195268108, 0.9471116754258844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 325}], {
             RGBColor[
             0.5672179996830251, 0.6358803573182399, 0.9469270854552878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 368}], {
             RGBColor[
             0.6817603644893816, 0.7470855364406719, 0.9537864521193352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 401}], {
             RGBColor[
             0.8644357283380311, 0.8946091728083778, 0.9692011064141851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 477}], {
             RGBColor[
             0.6000453532177727, 0.6703839872576882, 0.948796554675374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 500}], {
             RGBColor[
             0.8874558706447166, 0.5585534617562613, 0.5633237757723539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 97}], {
             RGBColor[
             0.22940871371662525`, 0.3584534818416879, 0.936375858915159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 137}], {
             RGBColor[
             0.22358173079098384`, 0.35232895333478276`, 0.9360440208577924]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 145}], {
             RGBColor[
             0.22387054333517215`, 0.3526325136304976, 0.9360604683049241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 174}], {
             RGBColor[
             0.24687001390337449`, 0.3768064154483368, 0.9373702541291156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 286}], {
             RGBColor[
             0.22509159237078977`, 0.3539159135859121, 0.9361300052411223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 294}], {
             RGBColor[
             0.2326978312332123, 0.36191055289371626`, 0.9365631692919152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 346}], {
             RGBColor[
             0.22248278830370904`, 0.3511738951036789, 0.9359814377088818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 358}], {
             RGBColor[
             0.2263545662938538, 0.3552433792562242, 0.9362019297376383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 404}], {
             RGBColor[
             0.22026561376472564`, 0.3488435040862222, 0.9358551728989024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 407}], {
             RGBColor[
             0.22072063099008732`, 0.34932175603983573`, 0.9358810854567492]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 408}], {
             RGBColor[
             0.22479372667970515`, 0.35360283785880653`, 0.9361130422306678]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 430}], {
             RGBColor[
             0.23341097282813747`, 0.36266010992577125`, 0.9366037816507478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 131}], {
             RGBColor[
             0.2798853921380307, 0.4115076712688437, 0.9392504310777041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 147}], {
             RGBColor[
             0.27382745193814473`, 0.40514039202317054`, 0.9389054403452399]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.29935267191603787`, 0.43196901661235676`, 0.940359063861802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 171}], {
             RGBColor[
             0.2789519797924134, 0.41052659571183897`, 0.939197274625481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 180}], {
             RGBColor[
             0.2831463385898367, 0.4149351327456384, 0.9394361371539964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 216}], {
             RGBColor[
             0.2810238579235662, 0.4127042709923413, 0.9393152650199811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 238}], {
             RGBColor[
             0.3081578274315908, 0.4401690531459169, 0.9408991236475683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 265}], {
             RGBColor[
             0.3085881199169248, 0.4405417508695841, 0.9409265415042412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 281}], {
             RGBColor[
             0.27053519804586806`, 0.4016800244414347, 0.938717951356528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 343}], {
             RGBColor[
             0.29452462133405766`, 0.4268944293346082, 0.940084113523619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 392}], {
             RGBColor[
             0.3010815634219416, 0.43378619120311424`, 0.9404575216753974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 433}], {
             RGBColor[
             0.31083399291217784`, 0.4424870131772134, 0.9410696465455513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 465}], {
             RGBColor[
             0.2893936582907169, 0.42150146185421045`, 0.9397919127688803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 104}], {
             RGBColor[
             0.23915408747259903`, 0.3686964875516002, 0.936930843533573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 137}], {
             RGBColor[
             0.2259075246268314, 0.35477351012010483`, 0.9361764713760403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 145}], {
             RGBColor[
             0.2261963371710197, 0.3550770704158197, 0.9361929188231719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 174}], {
             RGBColor[
             0.24919580773922206`, 0.37925097223365895`, 0.9375027046473634]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 294}], {
             RGBColor[
             0.23502362506905988`, 0.3643551096790384, 0.936695619810163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 346}], {
             RGBColor[
             0.22480858213955662`, 0.353618451889001, 0.9361138882271296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 358}], {
             RGBColor[
             0.2286803601297014, 0.35768793604154625`, 0.9363343802558861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 404}], {
             RGBColor[
             0.2225914076005732, 0.3512880608715443, 0.9359876234171504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 407}], {
             RGBColor[
             0.2230464248259349, 0.3517663128251578, 0.936013535974997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 408}], {
             RGBColor[
             0.2271195205155527, 0.3560473946441286, 0.9362454927489157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 430}], {
             RGBColor[
             0.23573676666398502`, 0.3651046667110934, 0.9367362321689956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 115}], {
             RGBColor[
             0.9582015589575525, 0.9660972945461519, 0.85752593015656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 124}], {
             RGBColor[
             0.9789436438067185, 0.93894816660261, 0.5160607207640602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 136}], {
             RGBColor[
             0.9820976999154852, 0.9842937020241562, 0.8300672430323528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 253}], {
             RGBColor[
             0.9901332923121124, 0.9901471046097305, 0.8102166844391167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 261}], {
             RGBColor[
             0.9376107771767181, 0.7700729496416561, 0.47213960027127755`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 277}], {
             RGBColor[
             0.8832681348130269, 0.9067408984138945, 0.8502742951726139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 311}], {
             RGBColor[
             0.8710458030481137, 0.8971927199459824, 0.8490560873664715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 319}], {
             RGBColor[
             0.8550622111994015, 0.8847062165139711, 0.8474629923061501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 331}], {
             RGBColor[
             0.9159632164581281, 0.9324175867663749, 0.8534971993423514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 377}], {
             RGBColor[
             0.9881699242791049, 0.9888223570121889, 0.8197885510745015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 484}], {
             RGBColor[
             0.9940632182259341, 0.9897101490230129, 0.5951961253421731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 488}], {
             RGBColor[
             0.8822995191611039, 0.9059842085048606, 0.8501777526166581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 122}], {
             RGBColor[
             0.930562919133284, 0.740007623770434, 0.37913808172539787`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 267}], {
             RGBColor[
             0.9913420700473246, 0.9817665875606343, 0.479566100729647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 278}], {
             RGBColor[
             0.9709926371751241, 0.9748878865987054, 0.7597061890098948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 329}], {
             RGBColor[
             0.9380897089070905, 0.9489785735157732, 0.7678909167681753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 406}], {
             RGBColor[
             0.992119957252125, 0.9843905837590278, 0.48258804562862445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 413}], {
             RGBColor[
             0.9837287794830555, 0.9560851708017216, 0.4499899045367475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 476}], {
             RGBColor[
             0.9210569805098886, 0.6812525268241133, 0.37059559494700395`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 486}], {
             RGBColor[
             0.9642745659488295, 0.9698576677518461, 0.7703884518083142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 493}], {
             RGBColor[
             0.9935993972524345, 0.9887180828601909, 0.5447120747479771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 121}], {
             RGBColor[
             0.8793403970281699, 0.48855884043917713`, 0.2187233911438525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 127}], {
             RGBColor[
             0.5785973319473678, 0.5599231651764567, 0.5998463238378839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 168}], {
             RGBColor[
             0.9210035362936968, 0.7245123759551941, 0.25529579489782767`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 200}], {
             RGBColor[
             0.9160214299715226, 0.703780905297789, 0.25123642844933736`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 213}], {
             RGBColor[
             0.9177103751290299, 0.7114500107948662, 0.2526457256885956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 254}], {
             RGBColor[
             0.5838565510201338, 0.5654509378756822, 0.6001458285837606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 259}], {
             RGBColor[
             0.8965277758950481, 0.6152647749950997, 0.2349704456547408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 315}], {
             RGBColor[
             0.5583572344294613, 0.5386495393888345, 0.5986936802267802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 368}], {
             RGBColor[
             0.6696582512860165, 0.6464478563026956, 0.6053684569202311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 401}], {
             RGBColor[
             0.8523336151346661, 0.7939714926704016, 0.620783111215081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 450}], {
             RGBColor[
             0.8744616680202064, 0.45105879141128646`, 0.21405151473609035`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 454}], {
             RGBColor[
             0.915548639391991, 0.7016340736991815, 0.25084192040061865`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 471}], {
             RGBColor[
             0.894013717811025, 0.6013444138663678, 0.23277457969666004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 475}], {
             RGBColor[
             0.8851091218155209, 0.5328997870260774, 0.22424752851506258`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 500}], {
             RGBColor[
             0.8753537574413516, 0.45791578161828494`, 0.21490578057324983`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 128}], {
             RGBColor[
             0.5077879700548952, 0.6112841755347511, 0.9543940755727961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 169}], {
             RGBColor[
             0.506787455963573, 0.6104719131227696, 0.9543153114385234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 197}], {
             RGBColor[
             0.6092291752169602, 0.6927921015850171, 0.9629587335694303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[
             0.5113628894889524, 0.6141864561796039, 0.9546755063260064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 219}], {
             RGBColor[
             0.5235508135187052, 0.6240811619666777, 0.9556349843514654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 337}], {
             RGBColor[
             0.6905217138834787, 0.756623588079157, 0.9709749326217818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 345}], {
             RGBColor[
             0.5902789610650883, 0.677988050262613, 0.9610699533225915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 355}], {
             RGBColor[
             0.424769765192925, 0.5405027707410431, 0.9487934456872616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 361}], {
             RGBColor[
             0.5825170875925927, 0.671924415713476, 0.9602963223136847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 362}], {
             RGBColor[
             0.45464713410545365`, 0.5663810460128507, 0.950697205214848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 363}], {
             RGBColor[
             0.4628220425559936, 0.5734617408298626, 0.9512181031525286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 498}], {
             RGBColor[
             0.491361119566665, 0.5979481182872246, 0.9531008937288266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 109}], {
             RGBColor[
             0.265248780611274, 0.396123664539452, 0.9384168977041816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[
             0.28024115314486164`, 0.4118815986435736, 0.9392706911407418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 186}], {
             RGBColor[
             0.256123983487738, 0.3865329242170628, 0.9378972540069239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 193}], {
             RGBColor[
             0.2821746373958698, 0.4139138131813651, 0.9393808002085031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 196}], {
             RGBColor[
             0.28611844580431445`, 0.41805900587053585`, 0.9396053942630224]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 202}], {
             RGBColor[
             0.2577973086293919, 0.3882916950358828, 0.9379925473982783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 330}], {
             RGBColor[
             0.2914935550351155, 0.4237085864737168, 0.939911498781955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 350}], {
             RGBColor[
             0.3193537748201921, 0.44805203074969097`, 0.941678953195245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 354}], {
             RGBColor[
             0.3191507002330799, 0.44787613774915985`, 0.941666013462126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 414}], {
             RGBColor[
             0.27559776236137046`, 0.40700110052214455`, 0.9390062569049031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 415}], {
             RGBColor[
             0.28177512151681394`, 0.41349389666170766`, 0.9393580483702217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 485}], {
             RGBColor[
             0.2622693737921402, 0.3929921190672394, 0.9382472248934693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 496}], {
             RGBColor[
             0.27671354998693043`, 0.4081738640616296, 0.9390697993595188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 118}], {
             RGBColor[
             0.4027319052154037, 0.522513730131029, 0.9470855430392838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 188}], {
             RGBColor[
             0.408816425381794, 0.5277838356822806, 0.9474732432839563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 304}], {
             RGBColor[
             0.4094598762170423, 0.5283411604549934, 0.947514243402197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 319}], {
             RGBColor[
             0.5976226950866923, 0.6831049747415705, 0.9622258440138658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 331}], {
             RGBColor[
             0.6585237003454188, 0.7308163449939742, 0.968260051050067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 449}], {
             RGBColor[
             0.6043292409167387, 0.6883441793156388, 0.9628942898259707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 488}], {
             RGBColor[
             0.6248600030483947, 0.70438296673246, 0.9649406043243738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 112}], {
             RGBColor[
             0.24741859649764936`, 0.37738301053706513`, 0.9374014950963042]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 148}], {
             RGBColor[
             0.2431147548759032, 0.37285940011329033`, 0.9371563976829089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 153}], {
             RGBColor[
             0.24575331572793313`, 0.3756326948631943, 0.937306659820031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 190}], {
             RGBColor[
             0.24734164292075334`, 0.3773021274486088, 0.9373971127039427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 215}], {
             RGBColor[
             0.26534838496499225`, 0.39622835503049064`, 0.9384225700247744]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 224}], {
             RGBColor[
             0.2727699797429894, 0.40402892169845256`, 0.9388452188681158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 323}], {
             RGBColor[
             0.2429591667599799, 0.3726958671385986, 0.9371475371698791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 351}], {
             RGBColor[
             0.2683095588486911, 0.39934073653152624`, 0.9385912044967868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 356}], {
             RGBColor[
             0.2579557991377684, 0.3884582786090651, 0.9380015731982647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 408}], {
             RGBColor[
             0.23453910043567894`, 0.36384584356871885`, 0.9366680268490819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 430}], {
             RGBColor[
             0.24315634658411125`, 0.3729031156356836, 0.937158766269162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 452}], {
             RGBColor[
             0.2352635459876256, 0.36460728177631574`, 0.9367092829515442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 112}], {
             RGBColor[
             0.2470843980758506, 0.3770317468063509, 0.9373824629905851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 148}], {
             RGBColor[
             0.24278055645410443`, 0.37250813638257607`, 0.9371373655771897]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 153}], {
             RGBColor[
             0.24541911730613436`, 0.37528143113248, 0.9372876277143118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 190}], {
             RGBColor[
             0.24700744449895456`, 0.37695086371789455`, 0.9373780805982235]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 195}], {
             RGBColor[
             0.2580285978828387, 0.38853479470584096`, 0.9380057189791005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 263}], {
             RGBColor[
             0.2596529612026372, 0.3902421035455322, 0.9380982240671327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 323}], {
             RGBColor[
             0.24262496833818112`, 0.37234460340788433`, 0.93712850506416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 342}], {
             RGBColor[
             0.252946206923672, 0.38319287956555814`, 0.9377162843326995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 395}], {
             RGBColor[
             0.2554464216840092, 0.38582076380144426`, 0.9378586678645644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 447}], {
             RGBColor[
             0.24620260884716, 0.3761049304183308, 0.9373322463985014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 453}], {
             RGBColor[
             0.265106051538209, 0.39597364723411466`, 0.9384087694946193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 463}], {
             RGBColor[
             0.2565013158137106, 0.3869295244159112, 0.9379187425246749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 117}], {
             RGBColor[
             0.44946530583261596`, 0.561973649912251, 0.9503446865091629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 139}], {
             RGBColor[
             0.5409452590449157, 0.6382027564556965, 0.9570043388212421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 140}], {
             RGBColor[
             0.508744701282457, 0.6120608930455363, 0.9544693929596517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 247}], {
             RGBColor[
             0.5064333598698463, 0.6101844419620349, 0.9542874356969284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 255}], {
             RGBColor[
             0.45772043203322, 0.569123825312507, 0.9508706958509441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 269}], {
             RGBColor[
             0.48339733950661234`, 0.5913638720070653, 0.9525068056899508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 274}], {
             RGBColor[
             0.49029479958875166`, 0.5970824316919869, 0.9530169491141065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 360}], {
             RGBColor[
             0.5486108303756021, 0.6444260125920007, 0.9576078006763067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 369}], {
             RGBColor[
             0.46890138102995677`, 0.5788082013626439, 0.9515831360340911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 370}], {
             RGBColor[
             0.5546493379031965, 0.6493283450345659, 0.9580831741086608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 425}], {
             RGBColor[
             0.4465990938801403, 0.559491081179018, 0.9501620540180429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 466}], {
             RGBColor[
             0.5106817556791221, 0.6136334810680553, 0.9546218849774213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 468}], {
             RGBColor[
             0.4981161809408796, 0.6034321814228589, 0.9536326769048099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 113}], {
             RGBColor[
             0.18193197659231264`, 0.3085524209250408, 0.9336721289714678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 132}], {
             RGBColor[
             0.5874023021726906, 0.6508098778838103, 0.8735074338464627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 143}], {
             RGBColor[
             0.18179934691843552`, 0.30841301872858895`, 0.9336645759077484]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 209}], {
             RGBColor[
             0.37529763235099667`, 0.4849566561931139, 0.9463994374355724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 214}], {
             RGBColor[
             0.19223940367108877`, 0.31938618031345734`, 0.9342591216951321]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 273}], {
             RGBColor[
             0.2391065540897807, 0.3686465269524677, 0.9369281365777409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 308}], {
             RGBColor[
             0.18180898862834943`, 0.3084231527770282, 0.9336651249888644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 421}], {
             RGBColor[
             0.18186414913512938`, 0.30848112996703203`, 0.9336682662981228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 423}], {
             RGBColor[
             0.18624879198055028`, 0.31308966759998247`, 0.9339179652216718]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 446}], {
             RGBColor[
             0.2064114829025504, 0.3342819341474452, 0.9350662006416515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 477}], {
             RGBColor[
             0.21467165996386678`, 0.3429639039643634, 0.9355366055054566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 129}], {
             RGBColor[
             0.3203552344901264, 0.4497120899906687, 0.9417137426958612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 163}], {
             RGBColor[
             0.27605150294224795`, 0.40747801064146116`, 0.939032096759735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 189}], {
             RGBColor[
             0.27244302962866296`, 0.40368527639846097`, 0.9388265995427842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 206}], {
             RGBColor[
             0.31392242641055057`, 0.44414031495447526`, 0.9413038498533395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 266}], {
             RGBColor[
             0.28731571918259713`, 0.4193174161026276, 0.9396735772107083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 364}], {
             RGBColor[
             0.27183868506633, 0.4030500719457907, 0.938792183014007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 374}], {
             RGBColor[
             0.2684205085848909, 0.3994573517388918, 0.938597522920128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 410}], {
             RGBColor[
             0.32438785376155105`, 0.4532049421182389, 0.9419706976299311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 437}], {
             RGBColor[
             0.27047057871071917`, 0.40161210542309067`, 0.938714271380987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 185}], {
             RGBColor[
             0.26895237692670115`, 0.40001637908853493`, 0.9386278120353654]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 186}], {
             RGBColor[
             0.24483520726957755`, 0.37466770466202415`, 0.9372543749015474]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 196}], {
             RGBColor[
             0.27482966958615396`, 0.4061937863154972, 0.938962515157646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 218}], {
             RGBColor[
             0.24296647092511459`, 0.372703544279266, 0.937147953131278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 295}], {
             RGBColor[
             0.24177394363545715`, 0.37145012248723885`, 0.937080040466318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 300}], {
             RGBColor[
             0.23995882574419874`, 0.3695423184984049, 0.9369766721876371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 335}], {
             RGBColor[
             0.2653660882581673, 0.3962469623140712, 0.938423578201131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 409}], {
             RGBColor[
             0.24775783308986035`, 0.3777395697043211, 0.9374208141183751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 456}], {
             RGBColor[
             0.23880926652767986`, 0.3683340588755796, 0.9369112064908769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 458}], {
             RGBColor[
             0.24222963005763265`, 0.3719290778091332, 0.9371059911339332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 496}], {
             RGBColor[
             0.26542477376877, 0.3963086445065909, 0.9384269202541424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 217}], {
             RGBColor[
             0.29571753049971145`, 0.4271336534107135, 0.9401891973787395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 290}], {
             RGBColor[
             0.2791002706073135, 0.4106824587604797, 0.9392057195680129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 316}], {
             RGBColor[
             0.26110517012024004`, 0.39176846719329617`, 0.9381809252166395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 340}], {
             RGBColor[
             0.3045749314378675, 0.43480548891742876`, 0.9407535831342266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 355}], {
             RGBColor[
             0.30021105187484454`, 0.43102571577490256`, 0.9404755205872981]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 378}], {
             RGBColor[
             0.2773998635716586, 0.40889522315397336`, 0.9391088839028592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 384}], {
             RGBColor[
             0.27776805045914515`, 0.4092822109171187, 0.9391298516014178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 146}], {
             RGBColor[
             0.2655122364597581, 0.39640057334027434`, 0.9384319011250047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 201}], {
             RGBColor[
             0.28877500860148286`, 0.42085122180616963`, 0.9397566815842886]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 256}], {
             RGBColor[
             0.2812386903435383, 0.41293007348689414`, 0.9393274994084824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 271}], {
             RGBColor[
             0.2644482810539334, 0.39528228875008364`, 0.938371310438624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 284}], {
             RGBColor[
             0.2590919383322233, 0.3896524329378227, 0.9380662746446216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 312}], {
             RGBColor[
             0.28875139009156847`, 0.4208263972547496, 0.9397553365450895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 376}], {
             RGBColor[
             0.2762731715166523, 0.4077109983677596, 0.9390447204571181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[
             0.2845065356159251, 0.4163647860615299, 0.939513598362401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 415}], {
             RGBColor[
             0.2800519643946353, 0.41168274927182613`, 0.9392599171212961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 442}], {
             RGBColor[
             0.2785182841132166, 0.41007075405510884`, 0.939172576298146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 444}], {
             RGBColor[
             0.272192144891436, 0.40342158063262434`, 0.9388123120281499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 464}], {
             RGBColor[
             0.2584790029138965, 0.3890081989508112, 0.9380313688793045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 148}], {
             RGBColor[
             0.2439596839808273, 0.373747474174165, 0.9372045151454738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 153}], {
             RGBColor[
             0.24659824483285725`, 0.37652076892406894`, 0.9373547772825959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 190}], {
             RGBColor[
             0.24818657202567745`, 0.37819020150948346`, 0.9374452301665075]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 195}], {
             RGBColor[
             0.25920772540956155`, 0.3897741324974299, 0.9380728685473844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 224}], {
             RGBColor[
             0.2736149088479135, 0.4049169957593272, 0.9388933363306806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 263}], {
             RGBColor[
             0.2608320887293601, 0.39148144133712115`, 0.9381653736354167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 323}], {
             RGBColor[
             0.24380409586490398`, 0.37358394119947325`, 0.9371956546324439]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 342}], {
             RGBColor[
             0.25412533445039487`, 0.3844322173571471, 0.9377834339009834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 351}], {
             RGBColor[
             0.26915448795361524`, 0.4002288105924009, 0.9386393219593516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 356}], {
             RGBColor[
             0.2588007282426925, 0.3893463526699398, 0.9380496906608295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 395}], {
             RGBColor[
             0.2566255492107321, 0.38706010159303317`, 0.9379258174328484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 447}], {
             RGBColor[
             0.2473817363738829, 0.37734426820991973`, 0.9373993959667855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 452}], {
             RGBColor[
             0.2361084750925497, 0.3654953558371904, 0.936757400414109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 463}], {
             RGBColor[
             0.2576804433404335, 0.3881688622075002, 0.9379858920929589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 130}], {
             RGBColor[
             0.17905963034776856`, 0.3055334029047545, 0.9335085531020964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 143}], {
             RGBColor[
             0.17905963102166003`, 0.30553340361305714`, 0.9335085531404735]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 209}], {
             RGBColor[
             0.3725579164542212, 0.4820770410775821, 0.9462434146682975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 214}], {
             RGBColor[
             0.18949968777431325`, 0.3165065651979255, 0.9341030989278573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 273}], {
             RGBColor[
             0.23636683819300525`, 0.3657669118369359, 0.936772113810466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 302}], {
             RGBColor[
             0.18467080951855291`, 0.3114311079825565, 0.9338281014548768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 308}], {
             RGBColor[
             0.17906927273157397`, 0.3055435376614964, 0.9335091022215896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 325}], {
             RGBColor[
             0.1791045905323438, 0.30558065890938335`, 0.9335111135180953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 347}], {
             RGBColor[
             0.17905963034776856`, 0.3055334029047545, 0.9335085531020964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 386}], {
             RGBColor[
             0.17905963034776856`, 0.3055334029047545, 0.9335085531020964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 421}], {
             RGBColor[
             0.17912443323835392`, 0.3056015148515002, 0.9335122435308479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 423}], {
             RGBColor[
             0.1835090760837748, 0.31021005248445066`, 0.9337619424543968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 477}], {
             RGBColor[
             0.2119319440670913, 0.3400842888488316, 0.9353805827381816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 115}], {
             RGBColor[
             0.7109234320173796, 0.7727455262693818, 0.9730887236423327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 203}], {
             RGBColor[
             0.5176225598035007, 0.6192683385358883, 0.9551682905030956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 208}], {
             RGBColor[
             0.41139850447614446`, 0.5294684917353877, 0.9477902381259522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 258}], {
             RGBColor[
             0.4370504632160207, 0.551686929090934, 0.9494247582537205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 289}], {
             RGBColor[
             0.47002476811242727`, 0.580247614655448, 0.9515258518036867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 291}], {
             RGBColor[
             0.577802812280651, 0.6679328507014297, 0.9600375327920143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 297}], {
             RGBColor[
             0.5100213466264654, 0.6130973312480197, 0.954569895157638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 311}], {
             RGBColor[
             0.6237676761079407, 0.7038409516692123, 0.9646188808522442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 349}], {
             RGBColor[
             0.45713997699902986`, 0.5690874562014547, 0.9507048443075143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 359}], {
             RGBColor[
             0.443064873322788, 0.5568963088323743, 0.9498079911473898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 381}], {
             RGBColor[
             0.5349916430046526, 0.6333693427468647, 0.9565356483577385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 397}], {
             RGBColor[
             0.4296132686116584, 0.545245204928905, 0.9489508667899835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 419}], {
             RGBColor[
             0.5066845097134336, 0.6103883367192307, 0.9543072071326079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 124}], {
             RGBColor[
             0.9419104649402625, 0.9128295501642687, 0.6508778471089514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 136}], {
             RGBColor[
             0.9450645210490293, 0.9581750855858149, 0.964884369377244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 178}], {
             RGBColor[
             0.9564265081535962, 0.965404037867567, 0.8899068420398936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 203}], {
             RGBColor[
             0.7278675078772177, 0.786501490374317, 0.9744226233622142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 253}], {
             RGBColor[
             0.9531001134456565, 0.9640284881713892, 0.9450338107840079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 277}], {
             RGBColor[
             0.8462349559465709, 0.8806222819755531, 0.9850914215175051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 291}], {
             RGBColor[
             0.7880477603543681, 0.8351660025398585, 0.9792918656511329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 297}], {
             RGBColor[
             0.7202662947001824, 0.7803304830864486, 0.9738242280167566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 311}], {
             RGBColor[
             0.8340126241816578, 0.871074103507641, 0.9838732137113628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 381}], {
             RGBColor[
             0.7452365910783697, 0.8006024945852935, 0.9757899812168571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 419}], {
             RGBColor[
             0.7169294577871506, 0.7776214885576594, 0.9735615399917263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 439}], {
             RGBColor[
             0.8910404321249454, 0.9159554702009634, 0.9894694259289032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 484}], {
             RGBColor[
             0.9570300393594782, 0.9635915325846716, 0.7300132516870645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 192}], {
             RGBColor[
             0.2516702940273803, 0.3818518142140055, 0.9376436229807996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 280}], {
             RGBColor[
             0.25280916302349343`, 0.3830488377373854, 0.9377084798853226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 310}], {
             RGBColor[
             0.2727415097182925, 0.40399899789739224`, 0.9388435975423268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 327}], {
             RGBColor[
             0.25289755432094124`, 0.38314174259533496`, 0.937713513638949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 399}], {
             RGBColor[
             0.24511345141386065`, 0.3749601568993634, 0.937270220493939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 412}], {
             RGBColor[
             0.24555371763094103`, 0.3754229046080053, 0.9372952930036862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 483}], {
             RGBColor[
             0.27268756010159706`, 0.40394229342964216`, 0.9388405251914673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 139}], {
             RGBColor[
             0.47255522666265165`, 0.5807190878311534, 0.9521624096580703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 140}], {
             RGBColor[
             0.44035466890019287`, 0.5545772244209933, 0.9496274637964799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 154}], {
             RGBColor[
             0.34530823850037556`, 0.4735103733174856, 0.9432237135065259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 247}], {
             RGBColor[
             0.4380433274875822, 0.5527007733374919, 0.9494455065337566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 255}], {
             RGBColor[
             0.38933039965095584`, 0.511640156687964, 0.9460287666877722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 269}], {
             RGBColor[
             0.41500730712434825`, 0.5338802033825223, 0.947664876526779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 338}], {
             RGBColor[
             0.3505903006321732, 0.47808543005188675`, 0.9435602818348199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 369}], {
             RGBColor[
             0.40051134864769267`, 0.5213245327381009, 0.9467412068709193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 390}], {
             RGBColor[
             0.34091437037852435`, 0.46896566133560236`, 0.9429707972165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 425}], {
             RGBColor[
             0.3782090614978762, 0.502007412554475, 0.9453201248548712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 466}], {
             RGBColor[
             0.44229172329685795`, 0.5561498124435122, 0.9497799558142495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[
             0.31734549257895406`, 0.4492904482488255, 0.9414419520628983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 151}], {
             RGBColor[
             0.31595121433390305`, 0.44790234871507695`, 0.9413597168905753]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 188}], {
             RGBColor[
             0.3311926249986076, 0.4612841383736176, 0.9423242790961401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 304}], {
             RGBColor[
             0.3318360758338559, 0.46184146314633034`, 0.9423652792143808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 310}], {
             RGBColor[
             0.3109325878407584, 0.44262745407148385`, 0.9410739135361832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 327}], {
             RGBColor[
             0.2910886324434072, 0.42177019876942656`, 0.9399438296328053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 483}], {
             RGBColor[
             0.31087863822406303`, 0.44257074960373377`, 0.9410708411853237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 197}], {
             RGBColor[
             0.8441364985929255, 0.8770550844901885, 0.8875786005274353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 237}], {
             RGBColor[
             0.9483698835729416, 0.9591789791220269, 0.8977829179807035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 270}], {
             RGBColor[
             0.9903352312511376, 0.9902713839961873, 0.8098337599957988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 309}], {
             RGBColor[
             0.9918390696706652, 0.9889511495464178, 0.6437403499501158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 320}], {
             RGBColor[
             0.9896249360090673, 0.9899776586598361, 0.8216051903420669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 345}], {
             RGBColor[
             0.8251862844410536, 0.8622510331677843, 0.8856898202805965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 375}], {
             RGBColor[
             0.9744244063754681, 0.9793738724475776, 0.8801494909995853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 426}], {
             RGBColor[
             0.9304108836330538, 0.9448589600540273, 0.8960699725342486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 489}], {
             RGBColor[
             0.9903724843514137, 0.9902867891105125, 0.8092163797162932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 123}], {
             RGBColor[
             0.20719251066229882`, 0.33510284384296096`, 0.9351106790171422]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 125}], {
             RGBColor[
             0.2080475453125366, 0.33600153947268885`, 0.9351593719755629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 177}], {
             RGBColor[
             0.20805903153131503`, 0.3360136122168933, 0.9351600260987298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 438}], {
             RGBColor[
             0.21444303080234048`, 0.3427236002196732, 0.9355235854129342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 455}], {
             RGBColor[
             0.2056810719300792, 0.33351422590464763`, 0.9350246048173154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 457}], {
             RGBColor[
             0.21450528797873675`, 0.3427890364593986, 0.9355271308670288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 161}], {
             RGBColor[
             0.9088989497892817, 0.5955852022276555, 0.2954383174204215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[
             0.8641469744095227, 0.4273429033856967, 0.2064477599128205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.86583591956703, 0.4350120088827739, 0.20785705715207875`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 259}], {
             RGBColor[
             0.8446533203330481, 0.33882677308300735`, 0.1901817771182239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 341}], {
             RGBColor[
             0.9105196563022746, 0.6003916270804778, 0.3579070077274834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 450}], {
             RGBColor[
             0.8225872124582064, 0.17462078949919407`, 0.16926284619957344`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 454}], {
             RGBColor[
             0.8636741838299911, 0.42519607178708907`, 0.20605325186410173`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 469}], {
             RGBColor[
             0.8439483097229172, 0.3356254845618147, 0.18959349898373934`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 471}], {
             RGBColor[
             0.842139262249025, 0.3249064119542755, 0.18798591116014318`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 475}], {
             RGBColor[
             0.8332346662535209, 0.256461785113985, 0.17945885997854572`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 491}], {
             RGBColor[
             0.9108136867178351, 0.6010205284083265, 0.38991040391585896`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 500}], {
             RGBColor[
             0.8234793018793516, 0.18147777970619255`, 0.1701171120367329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 150}], {
             RGBColor[
             0.8444744803276283, 0.32854420856354566`, 0.1896617078466737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.8441272348319537, 0.3258751275198433, 0.1893291851678579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 233}], {
             RGBColor[
             0.8553320507775657, 0.4120002528594733, 0.20005892957140564`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 267}], {
             RGBColor[
             0.9282834555711476, 0.7330087810415269, 0.3115827018545064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 406}], {
             RGBColor[
             0.929061342775948, 0.7356327772399205, 0.3146046467534838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 413}], {
             RGBColor[
             0.9206701650068785, 0.7073273642826143, 0.2820065056616069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 476}], {
             RGBColor[
             0.8579983660337116, 0.432494720305006, 0.20261219607186334`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 493}], {
             RGBColor[
             0.9305407827762575, 0.7399602763410837, 0.37672867587283654`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 125}], {
             RGBColor[
             0.2078185513522534, 0.33576085230137553`, 0.9351463311082908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 177}], {
             RGBColor[
             0.2078300375710318, 0.33577292504558, 0.935146985231458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 438}], {
             RGBColor[
             0.21421403684205725`, 0.34248291304835987`, 0.9355105445456623]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 455}], {
             RGBColor[
             0.20545207796979598`, 0.3332735387333343, 0.9350115639500436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 136}], {
             RGBColor[
             0.9658066058981951, 0.931025957642273, 0.6234191599847442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 178}], {
             RGBColor[
             0.977168593002762, 0.938254909924025, 0.5484416326473938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 253}], {
             RGBColor[
             0.9738421982948224, 0.9368793602278473, 0.603568601391508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 261}], {
             RGBColor[
             0.9213196831594281, 0.7168052052597729, 0.265491517223669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 357}], {
             RGBColor[
             0.9348974167088442, 0.7776187751730486, 0.27677767167712564`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 484}], {
             RGBColor[
             0.9777721242086441, 0.9364424046411297, 0.38854804229456463`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 177}], {
             RGBColor[
             0.20868507222126964`, 0.3366716206753079, 0.9351956781898786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 438}], {
             RGBColor[
             0.2150690714922951, 0.34338160867808776`, 0.9355592375040829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 455}], {
             RGBColor[
             0.20630711262003382`, 0.3341722343630622, 0.9350602569084642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 457}], {
             RGBColor[
             0.21513132866869134`, 0.3434470449178132, 0.9355627829581774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 144}], {
             RGBColor[
             0.24868278916139275`, 0.37871175718110384`, 0.937473488998299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 279}], {
             RGBColor[
             0.26484901945855754`, 0.3957034902216259, 0.9383941318979281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 285}], {
             RGBColor[
             0.28277807837083513`, 0.4140236211798849, 0.9394343678430408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 481}], {
             RGBColor[
             0.28467725623571494`, 0.41566859359098884`, 0.9395553817772139]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 130}], {
             RGBColor[
             0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 168}], {
             RGBColor[
             0.5683860156508949, 0.5194386987803812, 0.5916300590553423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 179}], {
             RGBColor[
             0.20245447418328588`, 0.33012286709465477`, 0.9348408548489592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 200}], {
             RGBColor[
             0.5634039093287206, 0.4987072281229762, 0.587570692606852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 213}], {
             RGBColor[
             0.5650928544862279, 0.5063763336200533, 0.5889799898461102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 254}], {
             RGBColor[
             0.23123903037733173`, 0.3603772607008694, 0.9364800927412753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 302}], {
             RGBColor[
             0.2080645848230672, 0.3360194490786239, 0.9351603423504797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 315}], {
             RGBColor[
             0.20573971378665917`, 0.3335758622140216, 0.9350279443842948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 325}], {
             RGBColor[
             0.20249836583685807`, 0.33016900000545074`, 0.9348433544136983]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 347}], {
             RGBColor[
             0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 368}], {
             RGBColor[
             0.3170407306432145, 0.44137417912788274`, 0.9417027210777457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 386}], {
             RGBColor[
             0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 401}], {
             RGBColor[
             0.499716094491864, 0.5888978154955886, 0.9571173753725956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 454}], {
             RGBColor[
             0.562931118749189, 0.49656039652436856`, 0.5871761845581333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 169}], {
             RGBColor[
             0.4937426983927686, 0.5998815912671589, 0.9532883803380281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 197}], {
             RGBColor[
             0.5961844176461558, 0.6822017797294064, 0.9619318024689351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 204}], {
             RGBColor[
             0.4983181319181479, 0.6035961343239933, 0.9536485752255113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 345}], {
             RGBColor[
             0.5772342034942839, 0.6673977284070023, 0.9600430222220963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 355}], {
             RGBColor[
             0.4117250076221206, 0.5299124488854325, 0.9477665145867664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 362}], {
             RGBColor[
             0.4416023765346493, 0.55579072415724, 0.9496702741143528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 498}], {
             RGBColor[
             0.4783163619958606, 0.5873577964316139, 0.9520739626283314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 170}], {
             RGBColor[
             0.3261401713486173, 0.4557924254151241, 0.9420431862919051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 206}], {
             RGBColor[
             0.3491669657996257, 0.47685260895882275`, 0.9434695881978956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 265}], {
             RGBColor[
             0.3383071396578693, 0.46744637338556605`, 0.9427776096791101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 266}], {
             RGBColor[
             0.32256025857167225`, 0.4520297101069751, 0.9418393155552645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 328}], {
             RGBColor[
             0.3704563897071251, 0.49529243790994043`, 0.944826131463783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 410}], {
             RGBColor[
             0.3596323931506261, 0.48591723612258636`, 0.9441364359744873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 433}], {
             RGBColor[
             0.3405530126531223, 0.4693916356931953, 0.94292071472042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 143}], {
             RGBColor[
             0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 179}], {
             RGBColor[
             0.17892806853100302`, 0.30539512309383293`, 0.93350106085126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 214}], {
             RGBColor[
             0.1893670574265447, 0.316367162293171, 0.9340955458257609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 254}], {
             RGBColor[
             0.20771262472504887`, 0.3356495167000475, 0.935140298743576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 302}], {
             RGBColor[
             0.18453817917078433`, 0.311291705077802, 0.9338205483527805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 315}], {
             RGBColor[
             0.1822133081343763, 0.30884811821319974`, 0.9336881503865955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 325}], {
             RGBColor[
             0.1789719601845752, 0.3054412560046289, 0.9335035604159989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 347}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 368}], {
             RGBColor[
             0.2935143249909316, 0.4166464351270609, 0.9403629270800464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 386}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 421}], {
             RGBColor[
             0.17899180289058533`, 0.3054621119467458, 0.9335046904287516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 477}], {
             RGBColor[
             0.2117993137193227, 0.3399448859440771, 0.9353730296360853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 135}], {
             RGBColor[
             0.25711790914467114`, 0.38757760310102596`, 0.937953856602705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 147}], {
             RGBColor[
             0.257551109678863, 0.38803292432896186`, 0.9379785267322645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 170}], {
             RGBColor[
             0.28014480934839103`, 0.4117803352049335, 0.9392652045040607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 171}], {
             RGBColor[
             0.26267563753313167`, 0.39341912801763035`, 0.9382703610125054]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 216}], {
             RGBColor[
             0.26474751566428445`, 0.3955968032981327, 0.9383883514070055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 238}], {
             RGBColor[
             0.29188148517230905`, 0.42306158545170824`, 0.9399722100345929]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 265}], {
             RGBColor[
             0.29231177765764305`, 0.42343428317537546`, 0.9399996278912657]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 374}], {
             RGBColor[
             0.2576696859737398, 0.38815755553304865`, 0.9379852794768397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 385}], {
             RGBColor[
             0.24854031848564526`, 0.3785620114677306, 0.9374653755040816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 391}], {
             RGBColor[
             0.2523681386345833, 0.3825852931420795, 0.9376833641988113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 433}], {
             RGBColor[
             0.29455765065289613`, 0.4253795454830047, 0.9401427329325757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 209}], {
             RGBColor[
             0.7780282420345992, 0.8243344980363514, 0.8860787195432924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 233}], {
             RGBColor[
             0.9166463543771588, 0.6614692040973338, 0.5010749461233683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 273}], {
             RGBColor[
             0.6418371637733833, 0.7080243687957053, 0.8766074186854609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 423}], {
             RGBColor[
             0.5889794016641527, 0.6524675094432201, 0.8735972473293918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 151}], {
             RGBColor[
             0.3259839947322987, 0.4565922388339624, 0.9419989967859217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 155}], {
             RGBColor[
             0.4555313931992919, 0.5659235600860384, 0.9510915748153721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 181}], {
             RGBColor[
             0.3829354312034995, 0.5061011564392373, 0.9456212849531489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 225}], {
             RGBColor[
             0.3097114792684619, 0.4394887933443991, 0.9410723011032855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 235}], {
             RGBColor[
             0.3511076947395869, 0.47853357082274445`, 0.9435932497298307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 239}], {
             RGBColor[
             0.34805209112246643`, 0.47588696054869806`, 0.943398549369312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 249}], {
             RGBColor[
             0.3173607671926588, 0.44752867994559636`, 0.9415079167344612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 260}], {
             RGBColor[
             0.31537504749154577`, 0.44544156263782575`, 0.9413948329350919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 262}], {
             RGBColor[
             0.4106297397776527, 0.5294703750419166, 0.9475567521778445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 296}], {
             RGBColor[
             0.3292967430314739, 0.4596420207034847, 0.942203475173657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 332}], {
             RGBColor[
             0.3736828594731001, 0.4980870438541423, 0.9450317192642157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 344}], {
             RGBColor[
             0.404458323018091, 0.5244601408973477, 0.9470709156438875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 424}], {
             RGBColor[
             0.33288404882225986`, 0.46274916467623195`, 0.942432055126516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 440}], {
             RGBColor[
             0.31342375230206637`, 0.44339062767442217`, 0.9412837095607336]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 138}], {
             RGBColor[
             0.2265863896100655, 0.3554870402600099, 0.9362151317325447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 251}], {
             RGBColor[
             0.24587579480159133`, 0.37576142813523083`, 0.9373136348220843]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 305}], {
             RGBColor[
             0.2421591297202534, 0.37185497748456803`, 0.9371019762440154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 367}], {
             RGBColor[
             0.23152572380893705`, 0.3606785936749, 0.9364964195080803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 416}], {
             RGBColor[
             0.24737003573452257`, 0.37733197009608865`, 0.9373987296326833]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 438}], {
             RGBColor[
             0.22733547187831532`, 0.35627437321849936`, 0.9362577908595535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 457}], {
             RGBColor[
             0.22739772905471156`, 0.3563398094582248, 0.936261336313648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 499}], {
             RGBColor[
             0.2469625122439105, 0.37690363706897373`, 0.93737552177277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 147}], {
             RGBColor[
             0.2510599689447852, 0.3812103238553528, 0.9376088658702408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 170}], {
             RGBColor[
             0.2736536686143132, 0.40495773473132446`, 0.9388955436420372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 171}], {
             RGBColor[
             0.25618449679905386`, 0.3865965275440213, 0.9379007001504819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 216}], {
             RGBColor[
             0.25825637493020664`, 0.38877420282452363`, 0.938018690544982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 385}], {
             RGBColor[
             0.24204917775156742`, 0.37173941099412156`, 0.9370957146420581]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 391}], {
             RGBColor[
             0.24587699790050546`, 0.37576269266847045`, 0.9373137033367878]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 253}], {
             RGBColor[
             0.9769962544035893, 0.9822248956493935, 0.9175751236598007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 261}], {
             RGBColor[
             0.924473739268195, 0.762150740681319, 0.5794980394919615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 277}], {
             RGBColor[
             0.8701310969045036, 0.8988186894535575, 0.9576327343932979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 291}], {
             RGBColor[
             0.8119439013123007, 0.853362410017863, 0.9518331785269256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 311}], {
             RGBColor[
             0.8579087651395905, 0.8892705109856455, 0.9564145265871555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 319}], {
             RGBColor[
             0.8419251732908781, 0.8767840075536342, 0.9548214315268342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 377}], {
             RGBColor[
             0.9750328863705816, 0.980900148051852, 0.9271469902951855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 484}], {
             RGBColor[
             0.980926180317411, 0.981787940062676, 0.7025545645628573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 488}], {
             RGBColor[
             0.8691624812525807, 0.8980619995445237, 0.9575361918373422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 145}], {
             RGBColor[
             0.2203693542453783, 0.34895254190891456`, 0.9358610807658054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 183}], {
             RGBColor[
             0.2125239415632086, 0.34070651575206007`, 0.9354142961198038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 346}], {
             RGBColor[
             0.21898159921391522`, 0.34749392338209584`, 0.9357820501697631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 358}], {
             RGBColor[
             0.22285337720406, 0.3515634075346411, 0.9360025421985196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 404}], {
             RGBColor[
             0.2167644246749318, 0.34516353236463915`, 0.9356557853597838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 407}], {
             RGBColor[
             0.2172194419002935, 0.34564178431825265`, 0.9356816979176306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 408}], {
             RGBColor[
             0.2212925375899113, 0.34992286613722345`, 0.9359136546915492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 430}], {
             RGBColor[
             0.22990978373834364`, 0.3589801382041882, 0.9364043941116291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 352}], {
             RGBColor[
             0.22389864331585435`, 0.3526620484918363, 0.9360620685572537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 367}], {
             RGBColor[
             0.22490572664447084`, 0.3537205569229832, 0.9361194204629721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 457}], {
             RGBColor[
             0.22077773189024535`, 0.349381772706308, 0.9358843372685399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 140}], {
             RGBColor[
             0.5318346221124927, 0.6308063309644387, 0.9562871161085591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 247}], {
             RGBColor[
             0.529523280699882, 0.6289298798809373, 0.9561051588458358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 255}], {
             RGBColor[
             0.4808103528632557, 0.5878692632314095, 0.9526884189998513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 269}], {
             RGBColor[
             0.506487260336648, 0.6101093099259678, 0.9543245288388581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 274}], {
             RGBColor[
             0.5133847204187874, 0.6158278696108893, 0.9548346722630138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 360}], {
             RGBColor[
             0.5717007512056378, 0.6631714505109032, 0.9594255238252141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 369}], {
             RGBColor[
             0.49199130185999246`, 0.5975536392815464, 0.9534008591829983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 370}], {
             RGBColor[
             0.5777392587332322, 0.6680737829534684, 0.9599008972575682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 425}], {
             RGBColor[
             0.469689014710176, 0.5782365190979204, 0.9519797771669503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 466}], {
             RGBColor[
             0.5337716765091578, 0.6323789189869576, 0.9564396081263286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 468}], {
             RGBColor[
             0.5212061017709153, 0.6221776193417614, 0.9554504000537172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 169}], {
             RGBColor[
             0.4961881243257401, 0.601866898204728, 0.953480893225362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 204}], {
             RGBColor[
             0.5007635578511195, 0.6055814412615623, 0.9538410881128452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 219}], {
             RGBColor[
             0.5129514818808725, 0.6154761470486363, 0.9548005661383041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 244}], {
             RGBColor[
             0.42103754660959536`, 0.5378457039996745, 0.9483965938455836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 247}], {
             RGBColor[
             0.4973227229374232, 0.6027880164707773, 0.9535702129842454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 255}], {
             RGBColor[
             0.4486097951007969, 0.5617273998212495, 0.950153473138261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 274}], {
             RGBColor[
             0.4811841626563286, 0.5896860062007292, 0.9522997264014235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 334}], {
             RGBColor[
             0.4512190714580578, 0.563987423855866, 0.9503197339204532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 361}], {
             RGBColor[
             0.5719177559547599, 0.6633194007954346, 0.9594619041005235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 363}], {
             RGBColor[
             0.4522227109181607, 0.5648567259118211, 0.9503836849393674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 369}], {
             RGBColor[
             0.4597907440975337, 0.5714117758713864, 0.950865913321408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 370}], {
             RGBColor[
             0.5455387009707735, 0.6419319195433083, 0.9573659513959778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 425}], {
             RGBColor[
             0.4374884569477172, 0.5520946556877604, 0.9494448313053598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 466}], {
             RGBColor[
             0.5015711187466989, 0.6062370555767975, 0.9539046622647382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 188}], {
             RGBColor[
             0.32343001274534444`, 0.45456055380007726`, 0.9418296523075707]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 220}], {
             RGBColor[
             0.32424804297229537`, 0.4552690904672675, 0.9418817764702763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[
             0.2831042170303842, 0.4148134850118461, 0.939436571482416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 304}], {
             RGBColor[
             0.3240734635805927, 0.45511787857278996`, 0.9418706524258115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 310}], {
             RGBColor[
             0.3031699755874952, 0.4359038694979436, 0.9405792867476138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 429}], {
             RGBColor[
             0.30159042381675216`, 0.434243660437526, 0.9404893336110074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 173}], {
             RGBColor[
             0.8420436305365226, 0.8765386852966244, 0.9380905002853989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 222}], {
             RGBColor[
             0.5711190039988594, 0.6615355308329243, 0.9600580034664301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 241}], {
             RGBColor[
             0.7025032226254809, 0.7675201238280478, 0.9709826140315919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 402}], {
             RGBColor[
             0.6259177691187879, 0.7063115685381091, 0.9642924066530247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 417}], {
             RGBColor[
             0.7002784838355302, 0.7657821409766972, 0.9707608728603756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 461}], {
             RGBColor[
             0.8219899053555546, 0.8616442791794481, 0.9747961115925544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 179}], {
             RGBColor[
             0.17892806920489446`, 0.30539512380213557`, 0.933501060889637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 214}], {
             RGBColor[
             0.18936705810043614`, 0.31636716300147366`, 0.934095545864138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 226}], {
             RGBColor[
             0.17917599682249857`, 0.3056557114477564, 0.9335151800006836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 273}], {
             RGBColor[
             0.23623420851912813`, 0.365627509640484, 0.9367645607467467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 283}], {
             RGBColor[
             0.18007058028918088`, 0.3065959753911073, 0.9335661252056935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 292}], {
             RGBColor[
             0.1789488167630598, 0.30541693080123855`, 0.9335022424323813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 302}], {
             RGBColor[
             0.1845381798446758, 0.31129170578610466`, 0.9338205483911577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 308}], {
             RGBColor[
             0.17893664305769685`, 0.3054041354650445, 0.9335015491578702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 325}], {
             RGBColor[
             0.17897196085846667`, 0.30544125671293154`, 0.9335035604543761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 347}], {
             RGBColor[
             0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 386}], {
             RGBColor[
             0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 421}], {
             RGBColor[
             0.1789918035644768, 0.3054621126550484, 0.9335046904671287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 423}], {
             RGBColor[
             0.1833764464098977, 0.31007065028799885`, 0.9337543893906777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 446}], {
             RGBColor[
             0.20353913733189777`, 0.3312629168354616, 0.9349026248106573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 477}], {
             RGBColor[
             0.21179931439321417`, 0.33994488665237976`, 0.9353730296744625]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 279}], {
             RGBColor[
             0.2623939933592224, 0.3931231021335797, 0.9382543217934566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 494}], {
             RGBColor[
             0.25236564813326057`, 0.3825826754672824, 0.9376832223684453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 183}], {
             RGBColor[
             0.21281275410739692`, 0.3410100760477749, 0.9354307435669353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 286}], {
             RGBColor[
             0.22187921582518422`, 0.3505395021600439, 0.9359470651491353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 294}], {
             RGBColor[
             0.22948545468760678`, 0.35853414146784807`, 0.9363802291999281]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 346}], {
             RGBColor[
             0.21927041175810352`, 0.3477974836778107, 0.9357984976168947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 358}], {
             RGBColor[
             0.2231421897482483, 0.351866967830356, 0.9360189896456512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 404}], {
             RGBColor[
             0.2170532372191201, 0.345467092660354, 0.9356722328069155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 407}], {
             RGBColor[
             0.2175082544444818, 0.34594534461396753`, 0.9356981453647621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 408}], {
             RGBColor[
             0.2215813501340996, 0.35022642643293833`, 0.9359301021386808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 430}], {
             RGBColor[
             0.23019859628253192`, 0.35928369849990305`, 0.9364208415587607]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 201}], {
             RGBColor[
             0.28119600247616383`, 0.41288520583171645`, 0.9393250683975864]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 211}], {
             RGBColor[
             0.2444868180291041, 0.37430152548113294`, 0.9372345346496982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 271}], {
             RGBColor[
             0.25686927492861433`, 0.3873162727756304, 0.9379396972519218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 284}], {
             RGBColor[
             0.25151293220690424`, 0.3816864169633695, 0.9376346614579194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 312}], {
             RGBColor[
             0.28117238396624933`, 0.41286038128029634`, 0.9393237233583873]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 376}], {
             RGBColor[
             0.2686941653913333, 0.39974498239330636`, 0.9386131072704159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 400}], {
             RGBColor[
             0.276927529490606, 0.4083987700870767, 0.9390819851756989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 415}], {
             RGBColor[
             0.27247295826931617`, 0.4037167332973729, 0.9388283039345939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 442}], {
             RGBColor[
             0.2709392779878975, 0.40210473808065567`, 0.9387409631114438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 444}], {
             RGBColor[
             0.2646131387661169, 0.39545556465817117`, 0.9383806988414477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 464}], {
             RGBColor[
             0.25089999678857744`, 0.38104218297635795`, 0.9375997556926023]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 497}], {
             RGBColor[
             0.24696343657246012`, 0.3769046085968852, 0.9373755744119134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 171}], {
             RGBColor[
             0.2566176973332457, 0.3870518487719572, 0.9379253702800414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 216}], {
             RGBColor[
             0.2586895754643985, 0.38922952405245953`, 0.9380433606745415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 238}], {
             RGBColor[
             0.2858235449724231, 0.4166943062060351, 0.9396272193021288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 385}], {
             RGBColor[
             0.24248237828575928`, 0.37219473222205746`, 0.9371203847716176]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 391}], {
             RGBColor[
             0.24631019843469731`, 0.37621801389640636`, 0.9373383734663472]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 153}], {
             RGBColor[
             0.2422944032111111, 0.37199715850029413`, 0.9371096798692006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 190}], {
             RGBColor[
             0.2438827304039313, 0.37366659108570865`, 0.9372001327531121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 195}], {
             RGBColor[
             0.2549038837878154, 0.3852505220736551, 0.9378277711339891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 323}], {
             RGBColor[
             0.23950025424315785`, 0.36906033077569844`, 0.9369505572190486]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 342}], {
             RGBColor[
             0.2498214928286487, 0.3799086069333723, 0.9375383364875882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 351}], {
             RGBColor[
             0.26485064633186906`, 0.3957052001686261, 0.9383942245459564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 356}], {
             RGBColor[
             0.2544968866209464, 0.384822742246165, 0.9378045932474341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 452}], {
             RGBColor[
             0.23180463347080354`, 0.3609717454134156, 0.9365123030007138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 463}], {
             RGBColor[
             0.25337660171868737`, 0.3836452517837254, 0.9377407946795635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 158}], {
             RGBColor[
             0.3556980515257828, 0.48250950715290686`, 0.943885743205154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 165}], {
             RGBColor[
             0.3889540140770109, 0.511314150421502, 0.9460047837318252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 182}], {
             RGBColor[
             0.36623071660169665`, 0.4916323722545241, 0.9445568753101211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 187}], {
             RGBColor[
             0.30925143443909986`, 0.4382007802607746, 0.9410755580672832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 275}], {
             RGBColor[
             0.38378936730216673`, 0.5068407929678266, 0.9456756970062499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 282}], {
             RGBColor[
             0.48076658116172494`, 0.586646877963116, 0.9530129031646457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 324}], {
             RGBColor[
             0.361776111320833, 0.4877740170552114, 0.9442730318006773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 441}], {
             RGBColor[
             0.4020035872776604, 0.5226170348372846, 0.946836290996886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 159}], {
             RGBColor[
             0.821097410502475, 0.1631695188320622, 0.16783621016427433`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 233}], {
             RGBColor[
             0.832302226448087, 0.24929464417169217`, 0.1785659545678221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 267}], {
             RGBColor[
             0.9052536312416688, 0.5703031723537458, 0.2900897268509228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 406}], {
             RGBColor[
             0.9060315184464693, 0.5729271685521393, 0.29311167174990027`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 413}], {
             RGBColor[
             0.8976403406773998, 0.5446217555948332, 0.26051353065802335`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 443}], {
             RGBColor[
             0.8779783180841267, 0.47195372718941886`, 0.21716686938390278`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 476}], {
             RGBColor[
             0.834968541704233, 0.26978911161722496`, 0.18111922106827977`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 188}], {
             RGBColor[
             0.32203573450029344`, 0.4531724542663287, 0.9417474171352478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 192}], {
             RGBColor[
             0.28070448165153206`, 0.4123685862808082, 0.9392970770137636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 249}], {
             RGBColor[
             0.29817109629594896`, 0.43072710571942197`, 0.9402917748782225]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 260}], {
             RGBColor[
             0.2961853765948359, 0.4286399884116514, 0.940178691078853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 280}], {
             RGBColor[
             0.2818433506476452, 0.4135656098041881, 0.9393619339182866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 310}], {
             RGBColor[
             0.3017756973424442, 0.43451576996419494`, 0.9404970515752908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 327}], {
             RGBColor[
             0.28193174194509296`, 0.41365851466213766`, 0.939366967671913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 424}], {
             RGBColor[
             0.31369437792555, 0.4459475904500576, 0.9412159132702771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 483}], {
             RGBColor[
             0.3017217477257488, 0.43445906549644486`, 0.9404939792244313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 191}], {
             RGBColor[
             0.21120215837255008`, 0.3393172378127832, 0.9353390225224988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 212}], {
             RGBColor[
             0.21125959360220817`, 0.3393776058807578, 0.93534229337386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 287}], {
             RGBColor[
             0.20690732578417442`, 0.33480309645428663`, 0.9350944381602262]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 299}], {
             RGBColor[
             0.20658465608391344`, 0.3344639501408717, 0.9350760625981434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 301}], {
             RGBColor[
             0.2063778078751808, 0.33424653955855976`, 0.9350642828986606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 389}], {
             RGBColor[
             0.21125135912011495`, 0.33936895091798147`, 0.9353418244322866]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 451}], {
             RGBColor[
             0.20772437674817806`, 0.3356618688214776, 0.9351409680039076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 190}], {
             RGBColor[
             0.24652129125596123`, 0.3764398858356126, 0.9373503948902342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 195}], {
             RGBColor[
             0.2575424446398453, 0.3880238168235591, 0.9379780332711112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 263}], {
             RGBColor[
             0.25916680795964386`, 0.3897311256632503, 0.9380705383591434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 323}], {
             RGBColor[
             0.24213881509518778`, 0.3718336255256024, 0.9371008193561707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 342}], {
             RGBColor[
             0.25246005368067864`, 0.38268190168327626`, 0.9376885986247103]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 351}], {
             RGBColor[
             0.267489207183899, 0.39847849491853005`, 0.9385444866830785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[
             0.2571354474729763, 0.3875960369960689, 0.9379548553845563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 395}], {
             RGBColor[
             0.2549602684410159, 0.3853097859191623, 0.9378309821565751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 447}], {
             RGBColor[
             0.24571645560416666`, 0.3755939525360489, 0.9373045606905122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 452}], {
             RGBColor[
             0.2344431943228335, 0.36374504016331954`, 0.9366625651378359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 463}], {
             RGBColor[
             0.25601516257071727`, 0.38641854653362934`, 0.9378910568166856]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 174}], {
             RGBColor[
             0.2880991557381853, 0.4200673355937856, 0.9397208847641902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 229}], {
             RGBColor[
             0.3002585012900294, 0.4328475787158096, 0.940413341505228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 255}], {
             RGBColor[
             0.3535633647009796, 0.4806605487177418, 0.9437497228483069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 313}], {
             RGBColor[
             0.2882495492104231, 0.42022540866860447`, 0.9397294494499471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 338}], {
             RGBColor[
             0.314823265682197, 0.4471058220816644, 0.9412812379953546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 369}], {
             RGBColor[
             0.36474431369771637`, 0.4903449247678786, 0.944462163031454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 379}], {
             RGBColor[
             0.3094202014132221, 0.4424259593777846, 0.9409369595178776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 380}], {
             RGBColor[
             0.2911961325222311, 0.423322454553487, 0.9398972530104752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 390}], {
             RGBColor[
             0.30514733542854805`, 0.43798605336538, 0.9406917533770347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 425}], {
             RGBColor[
             0.3424420265478999, 0.47102780458425264`, 0.9430410810154058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 478}], {
             RGBColor[
             0.28779157321631055`, 0.419744046861437, 0.9397033683945971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 181}], {
             RGBColor[
             0.49329315877378277`, 0.5986309034651389, 0.9534977211263604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 235}], {
             RGBColor[
             0.4614654223098702, 0.5710633178486462, 0.9514696859030422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 262}], {
             RGBColor[
             0.520987467347936, 0.6220001220678183, 0.9554331883510561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 332}], {
             RGBColor[
             0.4840405870433834, 0.5906167908800439, 0.9529081554374272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 344}], {
             RGBColor[
             0.5148160505883743, 0.6169898879232494, 0.9549473518170989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 387}], {
             RGBColor[
             0.6705014636086952, 0.7413486854414358, 0.9685938847155504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 393}], {
             RGBColor[
             0.5135503027141461, 0.615962296777659, 0.9548477075078524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 403}], {
             RGBColor[
             0.7474005481861847, 0.8023032590432388, 0.9760248292713649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 232}], {
             RGBColor[
             0.4117533959329014, 0.5306819361106889, 0.9475625057353367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 307}], {
             RGBColor[
             0.4685593666518582, 0.5794366280637215, 0.9513058562137999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 350}], {
             RGBColor[
             0.41473957912155346`, 0.5332684178987681, 0.9477527826875395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 354}], {
             RGBColor[
             0.4145365045344412, 0.533092524898237, 0.9477398429544205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 372}], {
             RGBColor[
             0.46888111877498084`, 0.5796978409320405, 0.951331185719549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 479}], {
             RGBColor[
             0.4393999195807523, 0.5546279653397757, 0.9493241177753168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 180}], {
             RGBColor[
             0.2863372761085622, 0.4182890103949429, 0.9396178563251187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 216}], {
             RGBColor[
             0.28421479544229167`, 0.41605814864164575`, 0.9394969841911034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 238}], {
             RGBColor[
             0.31134876495031627`, 0.4435229307952213, 0.9410808428186908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 246}], {
             RGBColor[
             0.2983825090164457, 0.4309493138930047, 0.9403038145198976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 281}], {
             RGBColor[
             0.2737261355645935, 0.4050339020907391, 0.9388996705276503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 288}], {
             RGBColor[
             0.2793047597177943, 0.4108973897809534, 0.9392173649203402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 343}], {
             RGBColor[
             0.2977155588527831, 0.4302483069839126, 0.9402658326947413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 392}], {
             RGBColor[
             0.3042725009406671, 0.4371400688524187, 0.9406392408465198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 459}], {
             RGBColor[
             0.3465448636437761, 0.4740080224761397, 0.94332350710475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 465}], {
             RGBColor[
             0.2925845958094424, 0.42485533950351484`, 0.9399736319400027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 182}], {
             RGBColor[
             0.36805399542884243`, 0.4932116047339394, 0.9446730530247247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 206}], {
             RGBColor[
             0.3501277440364893, 0.4776847867774757, 0.9435308081375656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 282}], {
             RGBColor[
             0.4825898599888707, 0.5882261104425313, 0.9531290808792493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 324}], {
             RGBColor[
             0.3635993901479788, 0.48935324953462667`, 0.9443892095152808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 410}], {
             RGBColor[
             0.3605931713874897, 0.48674941394123933`, 0.9441976559141574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 441}], {
             RGBColor[
             0.4038268661048062, 0.5241962673166999, 0.9469524687114896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 164}], {
             RGBColor[
             0.819137437150352, 0.14810430478184575`, 0.1659593374688081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 396}], {
             RGBColor[
             0.9071481131704897, 0.5745522202562454, 0.3532052383412315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 443}], {
             RGBColor[
             0.877631072588452, 0.4692846461457165, 0.21683434670508697`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 165}], {
             RGBColor[
             0.4232575021072018, 0.5410261076098133, 0.9481905716557255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 268}], {
             RGBColor[
             0.41606826400089775`, 0.5347991509037464, 0.9477324797607855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 275}], {
             RGBColor[
             0.4180928553323577, 0.5365527501561378, 0.9478614849301503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 285}], {
             RGBColor[
             0.3684500451199806, 0.49355464307036695`, 0.9446982889608311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 324}], {
             RGBColor[
             0.3960795993510239, 0.5174859742435227, 0.9464588197245776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 353}], {
             RGBColor[
             0.531072144514868, 0.6293500407838779, 0.9564584330755022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 441}], {
             RGBColor[
             0.4363070753078513, 0.5523289920255958, 0.9490220789207864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 480}], {
             RGBColor[
             0.3880144919727734, 0.5105003835965654, 0.94594491821413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 481}], {
             RGBColor[
             0.3703492229848604, 0.49519961548147085`, 0.9448193028950042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 259}], {
             RGBColor[
             0.9260863286561598, 0.722291136783578, 0.31168537193130974`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 326}], {
             RGBColor[
             0.9327537347132191, 0.7525662704764362, 0.31724881897839763`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 341}], {
             RGBColor[
             0.9919526646253864, 0.9838559907810486, 0.4794106025405692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 387}], {
             RGBColor[
             0.8827228822801044, 0.901646814849579, 0.6975808353380122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 403}], {
             RGBColor[
             0.9596219668575938, 0.962601388451382, 0.7050117798938269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 405}], {
             RGBColor[
             0.9921723207517021, 0.9843258130245969, 0.5033188163295588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 450}], {
             RGBColor[
             0.9040202207813182, 0.5580851531997648, 0.2907664410126593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 469}], {
             RGBColor[
             0.9253813180460291, 0.7190898482623855, 0.3110970937968252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 491}], {
             RGBColor[
             0.992246695040947, 0.9844848921088973, 0.5114139987289448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 203}], {
             RGBColor[
             0.4982990262412239, 0.6035806234747654, 0.9536470711566374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 221}], {
             RGBColor[
             0.4993207487803075, 0.6044101038600693, 0.953727504897607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 223}], {
             RGBColor[
             0.4259476007932227, 0.5431195461878823, 0.9484273528030159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 258}], {
             RGBColor[
             0.4177269296537439, 0.5359992140298111, 0.9479035389072623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 289}], {
             RGBColor[
             0.45070123455015054`, 0.5645598995943251, 0.9500046324572284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 297}], {
             RGBColor[
             0.4906978130641887, 0.5974096161868968, 0.9530486758111798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 381}], {
             RGBColor[
             0.515668109442376, 0.6176816276857418, 0.9550144290112803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 439}], {
             RGBColor[
             0.6614719504889517, 0.7330346033014116, 0.9686938737233264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 187}], {
             RGBColor[
             0.2658102034815037, 0.3967137555723293, 0.9384488699060904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.2633838374698597, 0.39416349105360093`, 0.9383106919512142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 322}], {
             RGBColor[
             0.26310542995763675`, 0.3938708671061988, 0.9382948370552601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 364}], {
             RGBColor[
             0.2627794929075267, 0.39352828660093053`, 0.938276275422437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 437}], {
             RGBColor[
             0.26141138655191587`, 0.3920903200782306, 0.9381983637894169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 494}], {
             RGBColor[
             0.262747921993954, 0.39349510356905415`, 0.938274477505614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 166}], {
             RGBColor[
             0.8278225605966679, 0.21486196943559147`, 0.17427622148944416`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 227}], {
             RGBColor[
             0.8315779382096691, 0.24372744738608088`, 0.17787237533274636`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 309}], {
             RGBColor[
             0.9052777371288019, 0.5616050038337315, 0.3236174733815438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 348}], {
             RGBColor[
             0.8887181595032059, 0.5060713797566354, 0.23158979527643736`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 396}], {
             RGBColor[
             0.9055353853140414, 0.5621560872497313, 0.3516608883245811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 428}], {
             RGBColor[
             0.8239291026561835, 0.1849351455808791, 0.17054784176860438`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 443}], {
             RGBColor[
             0.8760183447320038, 0.45688851313920237`, 0.21528999668843654`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 182}], {
             RGBColor[
             0.4013099579800705, 0.5220162480025345, 0.9467920935513959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 268}], {
             RGBColor[
             0.4168440173490807, 0.5354710694634455, 0.9477819100781599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 275}], {
             RGBColor[
             0.41886860868054065`, 0.537224668715837, 0.9479109152475247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 282}], {
             RGBColor[
             0.5158458225400988, 0.6170307537111264, 0.9552481214059205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 285}], {
             RGBColor[
             0.3692257984681636, 0.49422656163006606`, 0.9447477192782054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 324}], {
             RGBColor[
             0.3968553526992069, 0.5181578928032218, 0.9465082500419522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 353}], {
             RGBColor[
             0.531847897863051, 0.630021959343577, 0.9565078633928767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 441}], {
             RGBColor[
             0.4370828286560343, 0.553000910585295, 0.9490715092381609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 481}], {
             RGBColor[
             0.3711249763330434, 0.49587153404117, 0.9448687332123786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 210}], {
             RGBColor[
             0.8370920629652436, 0.28611142656230293`, 0.18315270742599782`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 227}], {
             RGBColor[
             0.8418757895124331, 0.32288124504634075`, 0.18773360937003286`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 243}], {
             RGBColor[
             0.838713260625803, 0.29857266219470613`, 0.18470516813663024`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 309}], {
             RGBColor[
             0.9155755884315661, 0.6407588014939913, 0.33347870741883034`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 320}], {
             RGBColor[
             0.9133614547699682, 0.6417853106074096, 0.5113435478107814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 348}], {
             RGBColor[
             0.8990160108059699, 0.5852251774168952, 0.24145102931372386`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 428}], {
             RGBColor[
             0.8342269539589475, 0.26408894324113896`, 0.18040907580589088`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 495}], {
             RGBColor[
             0.8401614416386582, 0.3097040160564781, 0.18609194791002698`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 210}], {
             RGBColor[
             0.9113669843928855, 0.6334814540290358, 0.5263699322609554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 326}], {
             RGBColor[
             0.9309228830343801, 0.7574193985269815, 0.5440638154599668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 434}], {
             RGBColor[
             0.988936416573675, 0.989692938179159, 0.8330157392176978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 474}], {
             RGBColor[
             0.9898837045140847, 0.9900846660867081, 0.8173167265425048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 495}], {
             RGBColor[
             0.9144363630663, 0.657074043523211, 0.5293091727449846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 200}], {
             RGBColor[
             0.9058101136750496, 0.6632964389017137, 0.24302016366679569`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 213}], {
             RGBColor[
             0.9074990588325569, 0.6709655443987909, 0.2444294609060539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 254}], {
             RGBColor[
             0.5736452347236608, 0.5249664714796068, 0.591929563801219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 261}], {
             RGBColor[
             0.8953895182633258, 0.6159789489289689, 0.23432496342308617`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 315}], {
             RGBColor[
             0.5481459181329882, 0.49816507299275914`, 0.5904774154442385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 368}], {
             RGBColor[
             0.6594469349895435, 0.6059633899066202, 0.5971521921376893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 401}], {
             RGBColor[
             0.842122298838193, 0.7534870262743261, 0.6125668464325392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 500}], {
             RGBColor[
             0.8651424411448785, 0.41743131522220955`, 0.2066895157907081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 204}], {
             RGBColor[
             0.4973176178268257, 0.6027838719120118, 0.9535698110912385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 219}], {
             RGBColor[
             0.5095055418565787, 0.6126785776990856, 0.9545292891166974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 244}], {
             RGBColor[
             0.4175916065853016, 0.5350481346501237, 0.9481253168239769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 274}], {
             RGBColor[
             0.4777382226320348, 0.5868884368511786, 0.9520284493798168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 334}], {
             RGBColor[
             0.44777313143376407`, 0.5611898545063152, 0.9500484568988465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 337}], {
             RGBColor[
             0.6764764422213522, 0.7452210038115648, 0.9698692373870139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 340}], {
             RGBColor[
             0.41508837309382146`, 0.5328799596159772, 0.9479658129994224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 361}], {
             RGBColor[
             0.5684718159304661, 0.6605218314458838, 0.9591906270789168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 363}], {
             RGBColor[
             0.44877677089386697`, 0.5620591565622703, 0.9501124079177607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 370}], {
             RGBColor[
             0.5420927609464797, 0.6391343501937576, 0.9570946743743712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 498}], {
             RGBColor[
             0.4773158479045384, 0.5865455340196324, 0.9519951984940587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 171}], {
             RGBColor[
             0.2792113970027737, 0.4107992596479288, 0.9392120480518376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 238}], {
             RGBColor[
             0.3084172446419511, 0.44044171708200675`, 0.940913897073925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 265}], {
             RGBColor[
             0.3088475371272851, 0.4408144148056739, 0.9409413149305978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 266}], {
             RGBColor[
             0.29310065604108804`, 0.425397751527083, 0.9400030208067522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 328}], {
             RGBColor[
             0.3409967871765409, 0.4686604793300483, 0.9429898367152708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 374}], {
             RGBColor[
             0.2742054454433818, 0.40553768716334715`, 0.9389269665161719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 433}], {
             RGBColor[
             0.31109341012253816`, 0.4427596771133032, 0.9410844199719078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 216}], {
             RGBColor[
             0.26381410331866717`, 0.39461572774112796`, 0.9383351949547825]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 238}], {
             RGBColor[
             0.2909480728266918, 0.4220805098947036, 0.9399190535823698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 265}], {
             RGBColor[
             0.29137836531202577`, 0.42245320761837074`, 0.9399464714390425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 343}], {
             RGBColor[
             0.2773148667291586, 0.40880588608339485`, 0.9391040434584204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 385}], {
             RGBColor[
             0.24760690614002792`, 0.37758093591072595`, 0.9374122190518586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 391}], {
             RGBColor[
             0.25143472628896596`, 0.3816042175850748, 0.9376302077465881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 433}], {
             RGBColor[
             0.2936242383072788, 0.42439846992600005`, 0.9400895764803525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 465}], {
             RGBColor[
             0.27218390368581785`, 0.4034129186029971, 0.9388118427036817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 303}], {
             RGBColor[
             0.32845548787730483`, 0.4585909264869045, 0.9421616772940785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 366}], {
             RGBColor[
             0.3083293758751098, 0.43743710670339436`, 0.941015524989468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 448}], {
             RGBColor[
             0.45979588464643895`, 0.5695615806771241, 0.9513786855523698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 473}], {
             RGBColor[
             0.3392418574009336, 0.4682559789143286, 0.9428371690671595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 241}], {
             RGBColor[
             0.8450225482014433, 0.8788658384170731, 0.9383874109586698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 417}], {
             RGBColor[
             0.8427978094114925, 0.8771278555657226, 0.9381656697874536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 461}], {
             RGBColor[
             0.9645092309315171, 0.9729899937684735, 0.9422009085196323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 493}], {
             RGBColor[
             0.9890701085039466, 0.9882775676582451, 0.7238989830539463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 215}], {
             RGBColor[
             0.2753901052316153, 0.40678283971254936`, 0.9389944311385647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 229}], {
             RGBColor[
             0.2788164534778155, 0.4103841489623319, 0.9391895566023578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 294}], {
             RGBColor[
             0.2524849252558091, 0.3827080432856873, 0.9376900150241196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 338}], {
             RGBColor[
             0.29338121786998295`, 0.4246423923281867, 0.9400574530924843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 356}], {
             RGBColor[
             0.2679975194043914, 0.3990127632911238, 0.938573434312055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 390}], {
             RGBColor[
             0.28370528761633407`, 0.41552262361190234`, 0.9394679684741645]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 430}], {
             RGBColor[
             0.2531980668507343, 0.38345760031774234`, 0.9377306273829522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 309}], {
             RGBColor[
             0.9743805147039586, 0.9770030600582216, 0.7213206267986814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 320}], {
             RGBColor[
             0.9721663810423609, 0.9780295691716399, 0.8991854671906325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 337}], {
             RGBColor[
             0.9079704822927377, 0.9289384814961321, 0.9731750764283525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 348}], {
             RGBColor[
             0.9578209370783626, 0.9214694359811255, 0.6292929486935749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 361}], {
             RGBColor[
             0.7999658560018515, 0.8442393091304512, 0.9624964661202554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 370}], {
             RGBColor[
             0.7735868010178651, 0.822851827878325, 0.9604005134157099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 375}], {
             RGBColor[
             0.9569658514087618, 0.9674257829593813, 0.9577297678481509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 197}], {
             RGBColor[
             0.6522851143834272, 0.7277468526483104, 0.9663482548197164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 237}], {
             RGBColor[
             0.7565184993634433, 0.8098707472801487, 0.9765525722729846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 345}], {
             RGBColor[
             0.6333349002315553, 0.7129428013259062, 0.9644594745728776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 426}], {
             RGBColor[
             0.7385594994235554, 0.7955507282121491, 0.9748396268265297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 448}], {
             RGBColor[
             0.587441960125221, 0.6759508730452015, 0.9606647294533119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 245}], {
             RGBColor[
             0.21512971428686242`, 0.34344534810015337`, 0.9355626910215206]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 438}], {
             RGBColor[
             0.21508055771107348`, 0.3433936814222922, 0.9355598916272501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 455}], {
             RGBColor[
             0.2063185988388122, 0.33418430710726665`, 0.9350609110316312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 357}], {
             RGBColor[
             0.9494134599221778, 0.8301932628763469, 0.5158066666080678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 420}], {
             RGBColor[
             0.9801637329335828, 0.9834819259202605, 0.8627171585529716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 439}], {
             RGBColor[
             0.9262985601874452, 0.9413808299607197, 0.8870332114673454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 236}], {
             RGBColor[
             0.23312614698427564`, 0.36236073990487094`, 0.9365875612403018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 254}], {
             RGBColor[
             0.20771369325605188`, 0.33565063979388043`, 0.9351403595948358]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 276}], {
             RGBColor[
             0.39923464670294595`, 0.5037029404652202, 0.9483463693708659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 283}], {
             RGBColor[
             0.18007164814629245`, 0.3065970977766376, 0.9335661860185762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 292}], {
             RGBColor[
             0.17894988462017136`, 0.30541805318676885`, 0.9335023032452641]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 315}], {
             RGBColor[
             0.18221437666537932`, 0.3088492413070327, 0.9336882112378554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 325}], {
             RGBColor[
             0.1789730287155782, 0.30544237909846184`, 0.9335036212672588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 347}], {
             RGBColor[
             0.17892806853100302`, 0.30539512309383293`, 0.93350106085126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 368}], {
             RGBColor[
             0.2935153935219346, 0.41664755822089383`, 0.9403629879313062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 386}], {
             RGBColor[
             0.17892806853100302`, 0.30539512309383293`, 0.93350106085126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 401}], {
             RGBColor[
             0.47619075737058414`, 0.5641711945885997, 0.9557776422261561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 216}], {
             RGBColor[
             0.2680084621160904, 0.3990242647749275, 0.9385740574832979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 281}], {
             RGBColor[
             0.2575198022383923, 0.3880000182240208, 0.9379767438198447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 288}], {
             RGBColor[
             0.2630984263915931, 0.39386350591423513`, 0.9382944382125347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 343}], {
             RGBColor[
             0.28150922552658186`, 0.4132144231171943, 0.9393429059869358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 392}], {
             RGBColor[
             0.2880661676144659, 0.4201061849857004, 0.9397163141387143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 465}], {
             RGBColor[
             0.27637826248324115`, 0.40782145563679656`, 0.9390507052321971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 235}], {
             RGBColor[
             0.38886946031407776`, 0.511240914201845, 0.9459993960408191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 239}], {
             RGBColor[
             0.38581385669695734`, 0.5085943039277986, 0.9458046956803003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 262}], {
             RGBColor[
             0.4483915053521436, 0.5621777184210172, 0.9499628984888329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 296}], {
             RGBColor[
             0.3670585086059648, 0.49234936408258523`, 0.9446096214846453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 332}], {
             RGBColor[
             0.41144462504759094`, 0.5307943872332428, 0.947437865575204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 344}], {
             RGBColor[
             0.4422200885925819, 0.5571674842764482, 0.9494770619548758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 387}], {
             RGBColor[
             0.5979055016129029, 0.6815262817946347, 0.9631235948533272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 393}], {
             RGBColor[
             0.4409543407183537, 0.5561398931308579, 0.9493774176456293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 424}], {
             RGBColor[
             0.3706458143967508, 0.4954565080553325, 0.9448382014375043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 275}], {
             RGBColor[
             0.39614531120522645`, 0.517542890548859, 0.9464630068258206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 282}], {
             RGBColor[
             0.4931225250647846, 0.5973489755441486, 0.9538002129842165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 324}], {
             RGBColor[
             0.37413205522389265`, 0.49847611463624397`, 0.9450603416202481]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 441}], {
             RGBColor[
             0.41435953118072005`, 0.5333191324183171, 0.9476236008164568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 346}], {
             RGBColor[
             0.21142499907593382`, 0.3395514575209563, 0.9353517129708931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 404}], {
             RGBColor[
             0.20920782453695042`, 0.33722106650349953`, 0.9352254481609139]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 407}], {
             RGBColor[
             0.2096628417623121, 0.3376993184571131, 0.9352513607187605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 408}], {
             RGBColor[
             0.21373593745192992`, 0.3419804002760839, 0.9354833174926791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 192}], {
             RGBColor[
             0.25582325613433854`, 0.3862168407014245, 0.9378801280290341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 225}], {
             RGBColor[
             0.2656405828545585, 0.396535473538841, 0.9384392102623171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 249}], {
             RGBColor[
             0.2732898707787555, 0.40457536014003825`, 0.9388748258934928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 260}], {
             RGBColor[
             0.2713041510776424, 0.40248824283226764`, 0.9387617420941234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 280}], {
             RGBColor[
             0.2569621251304517, 0.38741386422480434`, 0.9379449849335569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 424}], {
             RGBColor[
             0.28881315240835653`, 0.41979584487067384`, 0.9397989642855475]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 440}], {
             RGBColor[
             0.26935285588816305`, 0.4004373078688641, 0.9386506187197652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 453}], {
             RGBColor[
             0.2706693526642461, 0.401821029451244, 0.9387255912635806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 470}], {
             RGBColor[
             0.2562569900664413, 0.3866727225643841, 0.9379048285348154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 193}], {
             RGBColor[
             0.28587823371129695`, 0.41780652773044813`, 0.9395917145396869]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 196}], {
             RGBColor[
             0.2898220421197416, 0.4219517204196188, 0.9398163085942062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 318}], {
             RGBColor[
             0.3129435362062064, 0.4431846498190406, 0.9412454229080396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 321}], {
             RGBColor[
             0.30856010126890854`, 0.43938793879419913`, 0.9409661143099544]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 330}], {
             RGBColor[
             0.29519715135054264`, 0.42760130102279975`, 0.9401224131131387]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 335}], {
             RGBColor[
             0.28035846079175497`, 0.4120048964181928, 0.9392773716376912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 350}], {
             RGBColor[
             0.3230573711356193, 0.45194474529877393`, 0.9418898675264287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 383}], {
             RGBColor[
             0.3064436349421723, 0.43755476203867083`, 0.9408312549471323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 409}], {
             RGBColor[
             0.262750205623448, 0.39349750380844273`, 0.9382746075549353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 482}], {
             RGBColor[
             0.32121309396000997`, 0.4503473251053272, 0.9417723518156291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 496}], {
             RGBColor[
             0.2804171463023576, 0.4120665786107125, 0.9392807136907027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 191}], {
             RGBColor[
             0.22705589567091367`, 0.35598052089836485`, 0.936241869408138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 202}], {
             RGBColor[
             0.2373837352876954, 0.3668357351584549, 0.9368300245956442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 212}], {
             RGBColor[
             0.22711333090057176`, 0.3560408889663394, 0.9362451402594992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 295}], {
             RGBColor[
             0.23264914651192115`, 0.36185938216484964`, 0.9365603967690603]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 300}], {
             RGBColor[
             0.23083402862066274`, 0.35995157817601575`, 0.9364570284903794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 389}], {
             RGBColor[
             0.22710509641847854`, 0.3560322340035631, 0.9362446713179258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 414}], {
             RGBColor[
             0.255184189019674, 0.3855451406447167, 0.937843734102269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 456}], {
             RGBColor[
             0.22968446940414386`, 0.35874331855319036`, 0.9363915627936191]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 485}], {
             RGBColor[
             0.24185580045044375`, 0.3715361591898116, 0.9370847020908353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 322}], {
             RGBColor[
             0.2619233226556958, 0.392628397381927, 0.9382275177931856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 494}], {
             RGBColor[
             0.26156581469201307`, 0.3922526338447824, 0.9382071582435395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 304}], {
             RGBColor[
             0.33792059600024626`, 0.4671115686975821, 0.9427529794590535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 310}], {
             RGBColor[
             0.3170171080071488, 0.4478975596227356, 0.9414616137808558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 483}], {
             RGBColor[
             0.31696315839045336`, 0.4478408551549855, 0.9414585414299963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 266}], {
             RGBColor[
             0.2746480537102089, 0.4060028965147674, 0.9389521724021874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 364}], {
             RGBColor[
             0.25917101959394173`, 0.3897355523579304, 0.9380707782054862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 374}], {
             RGBColor[
             0.2557528431125027, 0.3861428321510315, 0.9378761181116072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 437}], {
             RGBColor[
             0.25780291323833093`, 0.38829758583523044`, 0.9379928665724662]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 195}], {
             RGBColor[
             0.25913077183266553`, 0.38969324940897365`, 0.9380684861550228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 224}], {
             RGBColor[
             0.2735379552710175, 0.40483611267087094`, 0.938888953938319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 263}], {
             RGBColor[
             0.26075513515246407`, 0.3914005582486648, 0.9381609912430551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 323}], {
             RGBColor[
             0.243727142288008, 0.373503058111017, 0.9371912722400824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 342}], {
             RGBColor[
             0.25404838087349885`, 0.38435133426869084`, 0.9377790515086218]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 351}], {
             RGBColor[
             0.2690775343767192, 0.40014792750394457`, 0.9386349395669901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 356}], {
             RGBColor[
             0.2587237746657965, 0.38926546958148345`, 0.9380453082684679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 395}], {
             RGBColor[
             0.2565485956338361, 0.38697921850457684`, 0.9379214350404868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 452}], {
             RGBColor[
             0.2360315215156537, 0.3654144727487341, 0.9367530180217474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 463}], {
             RGBColor[
             0.2576034897635375, 0.3880879791190439, 0.9379815097005972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 212}], {
             RGBColor[
             0.21845881642544385`, 0.3469444455250692, 0.9357522784633475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 218}], {
             RGBColor[
             0.2251871593264507, 0.3540163605156067, 0.9361354476378685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 287}], {
             RGBColor[
             0.21410654860741013`, 0.342369936098598, 0.9355044232497137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 295}], {
             RGBColor[
             0.22399463203679326`, 0.35276293872357944`, 0.9360675349729086]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 299}], {
             RGBColor[
             0.21378387890714912`, 0.3420307897851831, 0.935486047687631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 300}], {
             RGBColor[
             0.22217951414553483`, 0.3508551347347456, 0.9359641666942277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 301}], {
             RGBColor[
             0.2135770306984165, 0.34181337920287114`, 0.935474267988148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 389}], {
             RGBColor[
             0.21845058194335062`, 0.3469357905622929, 0.9357518095217741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 451}], {
             RGBColor[
             0.21492359957141377`, 0.343228708465789, 0.9355509530933952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 456}], {
             RGBColor[
             0.22102995492901595`, 0.34964687511192016`, 0.9358987009974674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[
             0.26443196618769516`, 0.395265140791245, 0.9383703813311275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 249}], {
             RGBColor[
             0.27208125411189216`, 0.40330502739244223`, 0.938805996962303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 260}], {
             RGBColor[
             0.27009553441077905`, 0.4012179100846716, 0.9386929131629338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 280}], {
             RGBColor[
             0.25575350846358835`, 0.3861435314772083, 0.9378761560023672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 327}], {
             RGBColor[
             0.25584189976103616`, 0.38623643633515786`, 0.9378811897559938]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 470}], {
             RGBColor[
             0.255048373399578, 0.3854023898167881, 0.9378359996036256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 483}], {
             RGBColor[
             0.275631905541692, 0.4070369871694651, 0.9390082013085121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 196}], {
             RGBColor[
             0.29175552637074975`, 0.4239839349574104, 0.9399264176619675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 202}], {
             RGBColor[
             0.2634343891958272, 0.39421662412275726`, 0.9383135707972234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 232}], {
             RGBColor[
             0.32200467219797546`, 0.4513904780484862, 0.9418096996419872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 330}], {
             RGBColor[
             0.2971306356015508, 0.42963351556059126`, 0.9402325221809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 350}], {
             RGBColor[
             0.3249908553866274, 0.4539769598365655, 0.94199997659419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 354}], {
             RGBColor[
             0.3247877807995152, 0.4538010668360344, 0.941987036861071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 376}], {
             RGBColor[
             0.2836334092052663, 0.4154470748445156, 0.9394638751049887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 414}], {
             RGBColor[
             0.28123484292780576`, 0.41292602960901903`, 0.9393272803038482]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 415}], {
             RGBColor[
             0.28741220208324925`, 0.41941882574858214`, 0.9396790717691668]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 485}], {
             RGBColor[
             0.2679064543585755, 0.3989170481541139, 0.9385682482924145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 496}], {
             RGBColor[
             0.28235063055336573`, 0.41409879314850406`, 0.939390822758464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 228}], {
             RGBColor[
             0.9897986964683487, 0.9881510016226367, 0.6807237889593197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 388}], {
             RGBColor[
             0.9663440953419832, 0.9740339462184904, 0.9245637966956991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 490}], {
             RGBColor[
             0.9885348242076832, 0.9895268694153684, 0.8396711640099095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 224}], {
             RGBColor[
             0.28455910865490164`, 0.41642004365881735`, 0.9395165923191959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 263}], {
             RGBColor[
             0.27177628853634817`, 0.40298448923661123`, 0.9387886296239321]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 296}], {
             RGBColor[
             0.29178587282524443`, 0.4235837043718764, 0.9399439681205266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 323}], {
             RGBColor[
             0.2547482956718921, 0.38508698909896344`, 0.9378189106209592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 342}], {
             RGBColor[
             0.265069534257383, 0.39593526525663725`, 0.9384066898894987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 351}], {
             RGBColor[
             0.2800986877606033, 0.41173185849189103`, 0.9392625779478669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 395}], {
             RGBColor[
             0.26756974901772024`, 0.3985631494925233, 0.9385490734213637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 447}], {
             RGBColor[
             0.25832593618087096`, 0.38884731610940987`, 0.9380226519553008]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 453}], {
             RGBColor[
             0.27722937887191995`, 0.40871603292519376`, 0.9390991750514186]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 463}], {
             RGBColor[
             0.2686246431474216, 0.3996719101069903, 0.9386091480814742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 318}], {
             RGBColor[
             0.3188208288656592, 0.44936205704600285`, 0.9415801260303202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 321}], {
             RGBColor[
             0.31443739392836134`, 0.4455653460211614, 0.9413008174322348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 330}], {
             RGBColor[
             0.3010744440099954, 0.433778708249762, 0.9404571162354194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 335}], {
             RGBColor[
             0.2862357534512077, 0.4181823036451551, 0.9396120747599719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 350}], {
             RGBColor[
             0.3289346637950721, 0.4581221525257362, 0.9422245706487093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 354}], {
             RGBColor[
             0.32873158920795986`, 0.45794625952520507`, 0.9422116309155903]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 383}], {
             RGBColor[
             0.3123209276016251, 0.4437321692656331, 0.941165958069413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 414}], {
             RGBColor[
             0.2851786513362504, 0.4170712222981897, 0.9395518743583675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 479}], {
             RGBColor[
             0.35359500425427093`, 0.4794816999667437, 0.9437959057364866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 482}], {
             RGBColor[
             0.3270903866194627, 0.45652473233228946`, 0.9421070549379097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 496}], {
             RGBColor[
             0.2862944389618104, 0.41824398583767475`, 0.9396154168129832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 237}], {
             RGBColor[
             0.8018590077882369, 0.845833600411511, 0.9807007779188375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 270}], {
             RGBColor[
             0.843824355466433, 0.8769260052856713, 0.8927516199339326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 345}], {
             RGBColor[
             0.6786754086563489, 0.7489056544572683, 0.9686076802187304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 375}], {
             RGBColor[
             0.8279135305907634, 0.8660284937370616, 0.9630673509377192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 426}], {
             RGBColor[
             0.7839000078483491, 0.8315135813435113, 0.9789878324723824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 448}], {
             RGBColor[
             0.6327824685500147, 0.7119137261765637, 0.9648129350991647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 489}], {
             RGBColor[
             0.843861608566709, 0.8769414103999965, 0.8921342396544271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 223}], {
             RGBColor[
             0.335871613441881, 0.4628528461466326, 0.9427133713948876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 373}], {
             RGBColor[
             0.28774746699468884`, 0.4197712104275283, 0.9396981646098933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 480}], {
             RGBColor[
             0.3177133386514768, 0.44712506118461215`, 0.9415563421819749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 208}], {
             RGBColor[
             0.33248120157791744`, 0.46240023864087376`, 0.9424063860563303]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 220}], {
             RGBColor[
             0.3408785418830542, 0.4696735927505875, 0.9429414571550971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 349}], {
             RGBColor[
             0.3782226741008029, 0.5020192031069408, 0.9453209922378925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 359}], {
             RGBColor[
             0.364147570424561, 0.48982805573786037`, 0.9444241390777679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 371}], {
             RGBColor[
             0.3528938984406201, 0.480080690691371, 0.9437070650501826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 382}], {
             RGBColor[
             0.31253428709090747`, 0.4426711481132517, 0.9412251688089472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 397}], {
             RGBColor[
             0.3506959657134314, 0.47817695183439113`, 0.9435670147203616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 419}], {
             RGBColor[
             0.4277672068152066, 0.5433200836247167, 0.948923355062986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 427}], {
             RGBColor[
             0.31117200287913815`, 0.44123930103287445`, 0.9411475887384059]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 429}], {
             RGBColor[
             0.318220922727511, 0.44864816272084596`, 0.9415490142958283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 213}], {
             RGBColor[
             0.9025169525103827, 0.6502340737413859, 0.24037009445756363`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 243}], {
             RGBColor[
             0.8700670583525245, 0.4728472627689348, 0.21211683898241762`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 254}], {
             RGBColor[
             0.5686631284014866, 0.5042350008222019, 0.5878701973527287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 259}], {
             RGBColor[
             0.8813343532764009, 0.5540488379416193, 0.22269481442370878`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 401}], {
             RGBColor[
             0.8371401925160188, 0.7327555556169211, 0.6085074799840489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 450}], {
             RGBColor[
             0.8592682454015592, 0.38984285435780597`, 0.20177588350505832`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 454}], {
             RGBColor[
             0.9003552167733437, 0.640418136645701, 0.2385662891695866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 469}], {
             RGBColor[
             0.8806293426662699, 0.5508475494204266, 0.22210653628922422`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 471}], {
             RGBColor[
             0.8788202951923778, 0.5401284768128874, 0.22049894846562806`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 475}], {
             RGBColor[
             0.8699156991968737, 0.47168384997259694`, 0.2119718972840306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 500}], {
             RGBColor[
             0.8601603348227043, 0.3966998445648045, 0.2026301493422178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 222}], {
             RGBColor[
             0.3735862388275236, 0.49760697262793063`, 0.9450400762157048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 246}], {
             RGBColor[
             0.2993400916080083, 0.43195579391098005`, 0.9403583474318706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 256}], {
             RGBColor[
             0.2969224563599441, 0.4294147059783363, 0.9402206666810642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 271}], {
             RGBColor[
             0.2801320470703391, 0.4117669212415258, 0.9392644777112058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 312}], {
             RGBColor[
             0.30443515610797417`, 0.4373110297461917, 0.9406485038176712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 333}], {
             RGBColor[
             0.34155395478950024`, 0.4698622181836031, 0.9429990074018386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 400}], {
             RGBColor[
             0.30019030163233085`, 0.432849418552972, 0.9404067656349827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 442}], {
             RGBColor[
             0.2942020501296223, 0.426555386546551, 0.9400657435707277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 444}], {
             RGBColor[
             0.2878759109078417, 0.4199062131240665, 0.9397054793007316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 492}], {
             RGBColor[
             0.29053904388296076`, 0.4227053347332997, 0.9398571407839125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 211}], {
             RGBColor[
             0.2350487330765592, 0.3643814997868598, 0.9366970496740461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 414}], {
             RGBColor[
             0.25685751416132785`, 0.38730391146353665`, 0.9379390274936235]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 485}], {
             RGBColor[
             0.2435291255920976, 0.37329493000863156`, 0.9371799954821897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 497}], {
             RGBColor[
             0.23752535161991525`, 0.36698458290261204`, 0.9368380894362616]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 221}], {
             RGBColor[
             0.5355883582024223, 0.6338537830261275, 0.9565826239639467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 258}], {
             RGBColor[
             0.45399453907585874`, 0.5654428931958693, 0.950758657973602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 289}], {
             RGBColor[
             0.48696884397226536`, 0.5940035787603833, 0.9528597515235682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 291}], {
             RGBColor[
             0.5947468881404891, 0.681688814806365, 0.9613714325118958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 297}], {
             RGBColor[
             0.5269654224863035, 0.6268532953529551, 0.9559037948775195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 381}], {
             RGBColor[
             0.5519357188644908, 0.6471253068518, 0.9578695480776199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 397}], {
             RGBColor[
             0.44655734447149653`, 0.5590011690338403, 0.950284766509865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 419}], {
             RGBColor[
             0.5236285855732716, 0.6241443008241659, 0.9556411068524893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 439}], {
             RGBColor[
             0.6977395599110665, 0.7624782824674698, 0.971548992789666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 219}], {
             RGBColor[
             0.5140809753819581, 0.6163931207559199, 0.9548894840041806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 244}], {
             RGBColor[
             0.42216704011068096`, 0.5387626777069581, 0.9484855117114601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 274}], {
             RGBColor[
             0.4823136561574142, 0.5906029799080129, 0.9523886442672999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 334}], {
             RGBColor[
             0.4523485649591434, 0.5649043975631496, 0.9504086517863296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 337}], {
             RGBColor[
             0.6810518757467315, 0.7489355468683991, 0.970229432274497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 340}], {
             RGBColor[
             0.4196638066192008, 0.5365945026728116, 0.9483260078869054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 361}], {
             RGBColor[
             0.5730472494558454, 0.6642363745027182, 0.9595508219663998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 362}], {
             RGBColor[
             0.4451772959687064, 0.5586930048020928, 0.9499517048675632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 363}], {
             RGBColor[
             0.4533522044192463, 0.5657736996191047, 0.9504726028052438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 370}], {
             RGBColor[
             0.546668194471859, 0.642848893250592, 0.9574548692618543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 498}], {
             RGBColor[
             0.4818912814299178, 0.5902600770764668, 0.9523553933815417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 228}], {
             RGBColor[
             0.9934539331599859, 0.9884069498751192, 0.5288792059852668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 252}], {
             RGBColor[
             0.8648112867502258, 0.89136633503373, 0.7718692919288858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 388}], {
             RGBColor[
             0.9699993320336204, 0.9742898944709728, 0.7727192137216462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 432}], {
             RGBColor[
             0.9462255159241673, 0.9556033712696023, 0.7798152269955922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 490}], {
             RGBColor[
             0.9921900608993205, 0.9897828176678509, 0.6878265810358566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 266}], {
             RGBColor[
             0.31612745049209645`, 0.4464579350707817, 0.9414294227127427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 410}], {
             RGBColor[
             0.35319958507105037`, 0.4803454610863929, 0.9437265431319655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 218}], {
             RGBColor[
             0.22451796602725682`, 0.35331299592884813`, 0.9360973380694622]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 287}], {
             RGBColor[
             0.21343735530821623`, 0.3416665715118395, 0.9354663136813074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 295}], {
             RGBColor[
             0.22332543873759936`, 0.352059574136821, 0.9360294254045023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 336}], {
             RGBColor[
             0.2196507706490151, 0.34819726498830533`, 0.9358201584930417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 389}], {
             RGBColor[
             0.21778138864415675`, 0.3462324259755344, 0.9357136999533677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 409}], {
             RGBColor[
             0.22930932819200256`, 0.35834902135390323`, 0.9363701990565594]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 456}], {
             RGBColor[
             0.2203607616298221, 0.3489435105251617, 0.9358605914290611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 458}], {
             RGBColor[
             0.22378112515977486`, 0.35253852945871533`, 0.9360553760721175]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[
             0.3477704837485026, 0.4756430463953687, 0.9433806055964585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 289}], {
             RGBColor[
             0.3807447886449092, 0.5042037319598828, 0.9454816991464247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 314}], {
             RGBColor[
             0.32609699892407057`, 0.4568705631814669, 0.9419995903085558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 349}], {
             RGBColor[
             0.3678599975315118, 0.49304357350588934`, 0.9446606916502523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 359}], {
             RGBColor[
             0.3537848938552699, 0.480852426136809, 0.9437638384901277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 397}], {
             RGBColor[
             0.3403332891441403, 0.46920132223333977`, 0.9429067141327215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 427}], {
             RGBColor[
             0.3008093263098471, 0.4322636714318231, 0.9404872881507658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 472}], {
             RGBColor[
             0.32528262084800263`, 0.45616518982380916`, 0.9419476988576752]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 214}], {
             RGBColor[
             0.3828653435329973, 0.49291080046599856`, 0.946830407391962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 233}], {
             RGBColor[
             0.7045416845554648, 0.49561598240663746`, 0.5739669497124782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 273}], {
             RGBColor[
             0.4297324939516893, 0.5421711471050089, 0.9494994222745707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 421}], {
             RGBColor[
             0.37249008899703795`, 0.4820057501195733, 0.9462395519949527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 423}], {
             RGBColor[
             0.37687473184245884`, 0.48661428775252374`, 0.9464892509185017]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 477}], {
             RGBColor[
             0.40529759982577535`, 0.5164885241169046, 0.9481078912022864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 227}], {
             RGBColor[
             0.8408474405782448, 0.3149769045127923, 0.18674886126930004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 243}], {
             RGBColor[
             0.8376849116916145, 0.29066832166115775`, 0.18372042003589745`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 326}], {
             RGBColor[
             0.8556196126725499, 0.40214503052670025`, 0.19986184252427644`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 348}], {
             RGBColor[
             0.8979876618717816, 0.5773208368833467, 0.24046628121299102`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 428}], {
             RGBColor[
             0.8331986050247592, 0.2561846027075905, 0.17942432770515804`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 434}], {
             RGBColor[
             0.9136331462118448, 0.6344185701788778, 0.48881376628200723`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 469}], {
             RGBColor[
             0.8482471960053599, 0.3686686083126496, 0.19371011734270402`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 474}], {
             RGBColor[
             0.9145804341522545, 0.6348102980864267, 0.4731147536068143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 495}], {
             RGBColor[
             0.8391330927044698, 0.3017996755229297, 0.18510719980929416`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 464}], {
             RGBColor[
             0.23745358448324252`, 0.36690915109166977`, 0.936834002403998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 485}], {
             RGBColor[
             0.23952079823930758`, 0.3690819238182165, 0.9369517271692371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 497}], {
             RGBColor[
             0.23351702426712523`, 0.36277157671219695`, 0.936609821123309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 287}], {
             RGBColor[
             0.21416398383706822`, 0.3424303041665726, 0.9355076941010749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 295}], {
             RGBColor[
             0.22405206726645135`, 0.35282330679155405`, 0.9360708058242697]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 299}], {
             RGBColor[
             0.21384131413680724`, 0.3420911578531577, 0.9354893185389921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 300}], {
             RGBColor[
             0.22223694937519295`, 0.35091550280272016`, 0.9359674375455889]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 301}], {
             RGBColor[
             0.2136344659280746, 0.34187374727084574`, 0.9354775388395093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 389}], {
             RGBColor[
             0.21850801717300872`, 0.34699615863026745`, 0.9357550803731354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 451}], {
             RGBColor[
             0.21498103480107186`, 0.34328907653376356`, 0.9355542239447563]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 456}], {
             RGBColor[
             0.22108739015867407`, 0.34970724317989477`, 0.9359019718488286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 254}], {
             RGBColor[
             0.5703520735589939, 0.511904106319279, 0.5892794945919869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 259}], {
             RGBColor[
             0.8830232984339081, 0.5617179434386964, 0.224104111662967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 261}], {
             RGBColor[
             0.8920963570986589, 0.602916583768641, 0.23167489421385412`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 315}], {
             RGBColor[
             0.5448527569683213, 0.48510270783243126`, 0.5878273462350064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 368}], {
             RGBColor[
             0.6561537738248766, 0.5929010247462924, 0.5945021229284573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 401}], {
             RGBColor[
             0.8388291376735261, 0.7404246611139982, 0.6099167772233072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 450}], {
             RGBColor[
             0.8609571905590665, 0.3975119598548832, 0.20318518074431657`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 454}], {
             RGBColor[
             0.902044161930851, 0.6480872421427781, 0.23997558640884487`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 471}], {
             RGBColor[
             0.8805092403498851, 0.5477975823099646, 0.2219082457048863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 475}], {
             RGBColor[
             0.871604644354381, 0.4793529554696741, 0.21338119452328883`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 500}], {
             RGBColor[
             0.8618492799802115, 0.40436895006188167`, 0.20403944658147605`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 273}], {
             RGBColor[
             0.24667426527178135`, 0.3766006712253524, 0.9373591065341305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 302}], {
             RGBColor[
             0.19497823659732902`, 0.32226486737097304`, 0.9344150941785414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 347}], {
             RGBColor[
             0.1893670574265447, 0.316367162293171, 0.9340955458257609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 421}], {
             RGBColor[
             0.18943186031713002`, 0.3164352742399168, 0.9340992362545124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 423}], {
             RGBColor[
             0.19381650316255092`, 0.32104381187286724`, 0.9343489351780614]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 477}], {
             RGBColor[
             0.2222393711458674, 0.35091804823724815`, 0.9359675754618462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 224}], {
             RGBColor[
             0.2915446973152564, 0.4237623402527527, 0.9399144112591507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 351}], {
             RGBColor[
             0.28708427642095813`, 0.4190741550858264, 0.9396603968878219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 356}], {
             RGBColor[
             0.2767305167100354, 0.40819169716336523`, 0.9390707655892996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 430}], {
             RGBColor[
             0.26193106415637823`, 0.3926365341899838, 0.9382279586601969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 238}], {
             RGBColor[
             0.29301995095784455`, 0.42425818517520597`, 0.9400370439768699]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 281}], {
             RGBColor[
             0.2553973215721218, 0.3857691564707237, 0.9378558716858294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 343}], {
             RGBColor[
             0.2793867448603114, 0.4109835613638972, 0.9392220338529205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 465}], {
             RGBColor[
             0.27425578181697063`, 0.40559059388349944`, 0.9389298330981818]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 290}], {
             RGBColor[
             0.3031025001174864, 0.43489572471311266`, 0.9406097604733883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 340}], {
             RGBColor[
             0.32857716094804046`, 0.4590187548700618, 0.9421576240396021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 355}], {
             RGBColor[
             0.32421328138501737`, 0.4552389817275355, 0.9418795614926734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 362}], {
             RGBColor[
             0.35409065029754605`, 0.481117256999343, 0.9437833210202597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 378}], {
             RGBColor[
             0.30140209308183147`, 0.4331084891066064, 0.9405129248082346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 384}], {
             RGBColor[
             0.30177027996931804`, 0.4334954768697517, 0.9405338925067932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 498}], {
             RGBColor[
             0.3908046357587574, 0.5126843292737169, 0.9461870095342384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 295}], {
             RGBColor[
             0.2307804101674582, 0.3598952217820915, 0.9364539749987908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.22896529227619977`, 0.3579874177932576, 0.93635060672011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 336}], {
             RGBColor[
             0.2271057420788739, 0.35603291263357584`, 0.9362447080873302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 389}], {
             RGBColor[
             0.22523636007401557`, 0.35406807362080495`, 0.9361382495476563]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 409}], {
             RGBColor[
             0.2367642996218614, 0.3661846689991738, 0.9367947486508479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 456}], {
             RGBColor[
             0.2278157330596809, 0.3567791581704322, 0.9362851410233497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 458}], {
             RGBColor[
             0.23123609658963368`, 0.36037417710398584`, 0.936479925666406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 244}], {
             RGBColor[
             0.43435496414043395`, 0.548657383494032, 0.949444989736919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 274}], {
             RGBColor[
             0.49450158018716717`, 0.6004976856950868, 0.9533481222927589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 334}], {
             RGBColor[
             0.4645364889888964, 0.5747991033502236, 0.9513681298117886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 337}], {
             RGBColor[
             0.6932397997764845, 0.7588302526554731, 0.971188910299956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 340}], {
             RGBColor[
             0.43185173064895377`, 0.5464892084598855, 0.9492854859123644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 361}], {
             RGBColor[
             0.5852351734855985, 0.6741310802897922, 0.9605102999918589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 363}], {
             RGBColor[
             0.4655401284489993, 0.5756684054061787, 0.9514320808307029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 369}], {
             RGBColor[
             0.47310816162837227`, 0.5822234553657439, 0.9519143092127434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 370}], {
             RGBColor[
             0.5588561185016121, 0.6527435990376659, 0.9584143472873132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 498}], {
             RGBColor[
             0.49407920545967077`, 0.6001547828635406, 0.9533148714070008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 349}], {
             RGBColor[
             0.3762573378366486, 0.5003169276156031, 0.9451957627490192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 359}], {
             RGBColor[
             0.3621822341604067, 0.48812578024652276`, 0.9442989095888945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 371}], {
             RGBColor[
             0.3509285621764658, 0.4783784152000333, 0.9435818355613093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 382}], {
             RGBColor[
             0.3105689508267532, 0.4409688726219141, 0.9410999393200739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 416}], {
             RGBColor[
             0.3002234451567067, 0.4300950902197503, 0.9405107780769688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 427}], {
             RGBColor[
             0.30920666661498386`, 0.43953702554153684`, 0.9410223592495326]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 429}], {
             RGBColor[
             0.3162555864633567, 0.44694588722950834`, 0.9414237848069549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 499}], {
             RGBColor[
             0.2998159216660946, 0.42966675719263536`, 0.9404875702170554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 223}], {
             RGBColor[
             0.46323693275442124`, 0.5733927057392445, 0.9513629056103252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 258}], {
             RGBColor[
             0.45501626161494246`, 0.5662723735811732, 0.9508390917145717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 297}], {
             RGBColor[
             0.5279871450253872, 0.627682775738259, 0.9559842286184892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 381}], {
             RGBColor[
             0.5529574414035745, 0.647954787237104, 0.9579499818185896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 439}], {
             RGBColor[
             0.6987612824501502, 0.7633077628527738, 0.9716294265306357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 307}], {
             RGBColor[
             0.456261635454359, 0.5691648443465238, 0.950417290103996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 333}], {
             RGBColor[
             0.41068141899913524`, 0.5301333365139219, 0.9473892347606732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 372}], {
             RGBColor[
             0.4565833875774816, 0.5694260572148426, 0.9504426196097452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 417}], {
             RGBColor[
             0.5718731828738293, 0.6621247011020224, 0.9601331729684849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 258}], {
             RGBColor[
             0.3816431136278576, 0.5049818159089863, 0.9455389396199805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 268}], {
             RGBColor[
             0.3997592820050565, 0.5206731304122181, 0.946693285849477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 373}], {
             RGBColor[
             0.3417396383201442, 0.4690205123479532, 0.9430475467307398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 381}], {
             RGBColor[
             0.47958429341648956`, 0.5866642295649169, 0.9526498297239985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 480}], {
             RGBColor[
             0.3717055099769321, 0.496374363105037, 0.9449057243028214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 263}], {
             RGBColor[
             0.2861834719747001, 0.4181273524985085, 0.9396090974072282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 342}], {
             RGBColor[
             0.2794767176957349, 0.41107812851853454`, 0.939227157672795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 351}], {
             RGBColor[
             0.29450587119895527`, 0.4268747217537883, 0.9400830457311632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 356}], {
             RGBColor[
             0.28415211148803254`, 0.41599226383132715`, 0.939493414432641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 463}], {
             RGBColor[
             0.2830318265857735, 0.4148147733688876, 0.9394296158647704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 235}], {
             RGBColor[
             0.31564550837904015`, 0.44462855110700683`, 0.9414504121909557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 249}], {
             RGBColor[
             0.28189858083211217`, 0.41362366022985875`, 0.9393650791955862]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 260}], {
             RGBColor[
             0.27991286113099906`, 0.41153654292208813`, 0.9392519953962168]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 280}], {
             RGBColor[
             0.26557083518380836`, 0.39646216431462483`, 0.9384352382356503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 296}], {
             RGBColor[
             0.29383455667092717`, 0.42573700098774714`, 0.940060637634782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 424}], {
             RGBColor[
             0.2974218624617132, 0.42884414496049433`, 0.940289217587641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 440}], {
             RGBColor[
             0.27796156594151966`, 0.4094856079586846, 0.9391408720218586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 453}], {
             RGBColor[
             0.2792780627176027, 0.4108693295410645, 0.939215844565674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 470}], {
             RGBColor[
             0.26486570011979793`, 0.3957210226542046, 0.9383950818369088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 236}], {
             RGBColor[
             0.23337407460187973`, 0.3626213275504917, 0.9366016803513484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 283}], {
             RGBColor[
             0.18031957576389654`, 0.30685768542225833`, 0.9335803051296228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 292}], {
             RGBColor[
             0.17919781223777545`, 0.3056786408323896, 0.9335164223563106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 308}], {
             RGBColor[
             0.17918563853241248`, 0.3056658454961956, 0.9335157290817995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 386}], {
             RGBColor[
             0.1791759961486071, 0.30565571073945375`, 0.9335151799623065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 396}], {
             RGBColor[
             0.5864855268156967, 0.6472607121015193, 0.7362180745608087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 422}], {
             RGBColor[
             0.20671849831186667`, 0.3346046268085379, 0.9350836847150235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 446}], {
             RGBColor[
             0.20378813280661343`, 0.33152462686661266`, 0.9349168047345866]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 309}], {
             RGBColor[
             0.9193309660445672, 0.6696242794444807, 0.3370748612621325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 320}], {
             RGBColor[
             0.9171168323829694, 0.670650788557899, 0.5149397016540836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 348}], {
             RGBColor[
             0.9027713884189711, 0.6140906553673846, 0.24504718315702606`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 428}], {
             RGBColor[
             0.8379823315719487, 0.29295442119162834`, 0.18400522964919308`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 495}], {
             RGBColor[
             0.8439168192516593, 0.3385694940069675, 0.1896881017533292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 388}], {
             RGBColor[
             0.9696267022726579, 0.9734928770909221, 0.7321607638451979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 490}], {
             RGBColor[
             0.9918174311383581, 0.9889858002878001, 0.6472681311594083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 244}], {
             RGBColor[
             0.3167084139494082, 0.447095666264713, 0.9414615153937971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 248}], {
             RGBColor[
             0.2667577277658053, 0.3977096636716398, 0.9385028300123448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 255}], {
             RGBColor[
             0.34428066244060973`, 0.47097736208628804`, 0.9432183946864745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 313}], {
             RGBColor[
             0.2789668469500533, 0.41054222203715074`, 0.9391981212881146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 338}], {
             RGBColor[
             0.3055405634218271, 0.43742263545021065`, 0.9407499098335221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 379}], {
             RGBColor[
             0.30013749915285226`, 0.43274277274633094`, 0.9404056313560452]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 380}], {
             RGBColor[
             0.2819134302618612, 0.4136392679220333, 0.9393659248486427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 390}], {
             RGBColor[
             0.29586463316817824`, 0.4283028667339263, 0.9401604252152023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 411}], {
             RGBColor[
             0.26528288174741516`, 0.39615950699567326`, 0.9384188397134368]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 478}], {
             RGBColor[
             0.27850887095594073`, 0.41006086022998334`, 0.9391720402327646]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 242}], {
             RGBColor[
             0.2244428247428983, 0.35323401767475476`, 0.9360930588844796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 339}], {
             RGBColor[
             0.21778435426976317`, 0.3462355430360783, 0.9357138688413589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 365}], {
             RGBColor[
             0.22042634378562792`, 0.3490124415290624, 0.9358643262358141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 374}], {
             RGBColor[
             0.23780417240741958`, 0.3672776412285381, 0.9368539678676315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 391}], {
             RGBColor[
             0.23250262506826308`, 0.3617053788375689, 0.936552052589603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 246}], {
             RGBColor[
             0.27633388437422024`, 0.407774811430481, 0.93904817796454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 256}], {
             RGBColor[
             0.27391624912615603`, 0.40523372349783726`, 0.9389104972137335]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 271}], {
             RGBColor[
             0.25712583983655113`, 0.38758593876102676`, 0.9379543082438752]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 288}], {
             RGBColor[
             0.2572561350755689, 0.3877228873184297, 0.9379617283649826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 442}], {
             RGBColor[
             0.2711958428958343, 0.40237440406605196`, 0.938755574103397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 444}], {
             RGBColor[
             0.2648697036740537, 0.39572523064356746`, 0.938395309833401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 492}], {
             RGBColor[
             0.2675328366491727, 0.39852435225280064`, 0.9385469713165818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 307}], {
             RGBColor[
             0.4130035971526026, 0.5316969057817654, 0.9476609261549895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 312}], {
             RGBColor[
             0.3303045820158528, 0.4601142095117522, 0.9422823672274991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 330}], {
             RGBColor[
             0.3313235898372211, 0.4611852513408379, 0.942340398215439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 350}], {
             RGBColor[
             0.3591838096222978, 0.48552869561681206`, 0.944107852628729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 354}], {
             RGBColor[
             0.35898073503518557`, 0.48535280261628094`, 0.94409491289561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 372}], {
             RGBColor[
             0.41332534927572523`, 0.5319581186500844, 0.9476862556607386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 376}], {
             RGBColor[
             0.3178263634409366, 0.4469988106247622, 0.9415717511395277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 400}], {
             RGBColor[
             0.3260597275402094, 0.45565259831853255`, 0.9420406290448107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 414}], {
             RGBColor[
             0.31542779716347613`, 0.44447776538926564`, 0.9414351563383871]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 415}], {
             RGBColor[
             0.3216051563189196, 0.45097056152882875`, 0.9417869478037058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 476}], {
             RGBColor[
             0.8458261121541704, 0.35324515591315253`, 0.19151644279301172`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 235}], {
             RGBColor[
             0.3728101836078023, 0.49733117588158576`, 0.9449761131297559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[
             0.36975457999068184`, 0.4946845656075394, 0.9447814127692372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 262}], {
             RGBColor[
             0.4323322286458682, 0.548267980100758, 0.9489396155777698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 296}], {
             RGBColor[
             0.3509992318996893, 0.478439625762326, 0.9435863385735823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 332}], {
             RGBColor[
             0.3953853483413155, 0.5168846489129837, 0.946414582664141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 393}], {
             RGBColor[
             0.42489506401207827`, 0.5422301548105988, 0.9483541347345662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 468}], {
             RGBColor[
             0.4334778335161593, 0.5491980337433716, 0.9490298017896481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 239}], {
             RGBColor[
             0.35398612023304477`, 0.4810267183113057, 0.943776660456982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 249}], {
             RGBColor[
             0.32329479630323715`, 0.4526684377082041, 0.9418860278221313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 260}], {
             RGBColor[
             0.32130907660212404`, 0.45058132040043347`, 0.941772944022762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 262}], {
             RGBColor[
             0.416563768888231, 0.5346101328045243, 0.9479348632655147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 296}], {
             RGBColor[
             0.3352307721420522, 0.4647817784660925, 0.9425815862613272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 332}], {
             RGBColor[
             0.37961688858367837`, 0.50322680161675, 0.9454098303518859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 344}], {
             RGBColor[
             0.4103923521286693, 0.5295998986599555, 0.9474490267315575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 393}], {
             RGBColor[
             0.40912660425444114`, 0.5285723075143651, 0.947349382422311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 424}], {
             RGBColor[
             0.3388180779328382, 0.46788892243883967`, 0.9428101662141861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 440}], {
             RGBColor[
             0.3193577814126447, 0.44853038543702994`, 0.9416618206484036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 453}], {
             RGBColor[
             0.32067427818872773`, 0.4499141070194098, 0.9417367931922191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 243}], {
             RGBColor[
             0.5633146331293595, 0.36122739545781846`, 0.562473440762307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 276}], {
             RGBColor[
             0.45343165662521556`, 0.5606674341824253, 0.9514328089086481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 283}], {
             RGBColor[
             0.23426865806856206`, 0.3635615914938426, 0.9366526255563583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 292}], {
             RGBColor[
             0.23314689454244097`, 0.36238254690397387`, 0.9365887427830462]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 396}], {
             RGBColor[
             0.6404346091203621, 0.7039646181731036, 0.7392903949875442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 422}], {
             RGBColor[
             0.26066758061653217`, 0.39130853288012224`, 0.9381560051417591]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 267}], {
             RGBColor[
             0.9475774996267206, 0.9513626199375382, 0.7014579081154306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 270}], {
             RGBColor[
             0.9480577404464491, 0.9590498999175098, 0.9029559373872008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 329}], {
             RGBColor[
             0.8943251384864865, 0.9185746058926771, 0.989782724153959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 426}], {
             RGBColor[
             0.8881333928283652, 0.9136374759753497, 0.9891921499256506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 448}], {
             RGBColor[
             0.7370158535300309, 0.7940376208084021, 0.9750172525524329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 489}], {
             RGBColor[
             0.9480949935467251, 0.959065305031835, 0.9023385571076953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 265}], {
             RGBColor[
             0.32058421295120315`, 0.4520956650524487, 0.9416483204611299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 328}], {
             RGBColor[
             0.35273346300045894`, 0.47994172957682313`, 0.943696842245803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 343}], {
             RGBColor[
             0.306520714368336, 0.43844834351747275`, 0.9408058924805078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 431}], {
             RGBColor[
             0.38434692528377257`, 0.5073237216678145, 0.9457112241078087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 433}], {
             RGBColor[
             0.32283008594645624`, 0.45404092736007795`, 0.94179142550244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 436}], {
             RGBColor[
             0.3965368671240651, 0.5173498014044343, 0.9466350145946033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 462}], {
             RGBColor[
             0.392016142899485, 0.5136796738226148, 0.9462791266236859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 465}], {
             RGBColor[
             0.30138975132499524`, 0.433055376037075, 0.940513691725769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 262}], {
             RGBColor[
             0.41350816527111056`, 0.531963522530478, 0.947740162904996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 263}], {
             RGBColor[
             0.31216558423603546`, 0.4415359530567809, 0.9412315474042139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 296}], {
             RGBColor[
             0.33217516852493173`, 0.46213516819204603`, 0.9423868859008084]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 332}], {
             RGBColor[
             0.37656128496655794`, 0.5005801913427036, 0.9452151299913671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 393}], {
             RGBColor[
             0.4060710006373207, 0.5259256972403187, 0.9471546820617923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 424}], {
             RGBColor[
             0.3357624743157177, 0.4652423121647933, 0.9426154658536674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 440}], {
             RGBColor[
             0.3163021777955242, 0.4458837751629835, 0.9414671202878849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 453}], {
             RGBColor[
             0.31761867457160725`, 0.44726749674536337`, 0.9415420928317004]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 251}], {
             RGBColor[
             0.25758537828186423`, 0.38806894280347104`, 0.9379804782785095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 310}], {
             RGBColor[
             0.2766913122921885, 0.4081504908345045, 0.939068532955701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 352}], {
             RGBColor[
             0.24222822396059346`, 0.3719275999119933, 0.937105911058787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 367}], {
             RGBColor[
             0.24323530728920995`, 0.3729861083431402, 0.9371632629645055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 382}], {
             RGBColor[
             0.26942512488484194`, 0.40051326716649266`, 0.9386547343322136]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 399}], {
             RGBColor[
             0.24906325398775672`, 0.3791116498364756, 0.9374951559073132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 412}], {
             RGBColor[
             0.2495035202048371, 0.3795743975451175, 0.9375202284170604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 416}], {
             RGBColor[
             0.2590796192147955, 0.38963948476432886`, 0.9380655730891085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 429}], {
             RGBColor[
             0.2751117605214455, 0.4064902817740869, 0.9389785798190946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 402}], {
             RGBColor[
             0.6288966867837086, 0.7086387216585579, 0.9645893173262957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 417}], {
             RGBColor[
             0.7032574015004508, 0.7681092940971459, 0.9710577835336467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 436}], {
             RGBColor[
             0.5892009770363313, 0.6764119562142918, 0.9614643256448061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 461}], {
             RGBColor[
             0.8249688230204753, 0.8639714322998968, 0.9750930222658254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 339}], {
             RGBColor[
             0.21834915626655288`, 0.34682918574521915`, 0.9357460334795263]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 365}], {
             RGBColor[
             0.22099114578241763`, 0.3496060842382034, 0.9358964908739815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 374}], {
             RGBColor[
             0.2383689744042093, 0.367871283937679, 0.936886132505799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 276}], {
             RGBColor[
             0.7294231328480298, 0.5025695960181678, 0.5742322488928711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 326}], {
             RGBColor[
             0.8572408103331092, 0.41460626615910345`, 0.2014143032349089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 428}], {
             RGBColor[
             0.8348198026853184, 0.2686458383399938, 0.18097678841579048`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 454}], {
             RGBColor[
             0.869594267772993, 0.47070043117032717`, 0.21172233093369885`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 469}], {
             RGBColor[
             0.8498683936659192, 0.3811298439450528, 0.19526257805333647`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 471}], {
             RGBColor[
             0.8480593461920269, 0.37041077133751354`, 0.1936549902297403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 475}], {
             RGBColor[
             0.8391547501965229, 0.3019661444972231, 0.18512793904814284`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 495}], {
             RGBColor[
             0.8407542903650291, 0.31426091115533294`, 0.1866596605199266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 274}], {
             RGBColor[
             0.40258764491589, 0.5228672426461249, 0.9469441500000384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 313}], {
             RGBColor[
             0.3046994618698019, 0.43447349621750786`, 0.9407776233385161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 334}], {
             RGBColor[
             0.3726225537176192, 0.4971686603012616, 0.9449641575190681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 340}], {
             RGBColor[
             0.33993779537767665`, 0.4688587654109236, 0.9428815136196439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 355}], {
             RGBColor[
             0.3355739158146536, 0.46507899226839733`, 0.9426034510727153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 363}], {
             RGBColor[
             0.37362619317772217`, 0.49803796235721676`, 0.9450281085379824]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 378}], {
             RGBColor[
             0.3127627275114677, 0.4429484996474682, 0.9412368143882763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 379}], {
             RGBColor[
             0.3258701140726008, 0.45667404692668806`, 0.9419851334064466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 380}], {
             RGBColor[
             0.3076460451816098, 0.43757054210239044`, 0.9409454268990441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 390}], {
             RGBColor[
             0.3215972480879268, 0.45223414091428343`, 0.9417399272656037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 498}], {
             RGBColor[
             0.40216527018839365`, 0.5225243398145787, 0.9469108991142803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 394}], {
             RGBColor[
             0.22510267482771082`, 0.3539275619508045, 0.936130636370649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 438}], {
             RGBColor[
             0.22151371355788788`, 0.3501553361029332, 0.9359262503357249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 445}], {
             RGBColor[
             0.22560109399094413`, 0.3544514320929628, 0.93615902060465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 460}], {
             RGBColor[
             0.23495456172986623`, 0.36428251973067727`, 0.936691686755166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 256}], {
             RGBColor[
             0.2918037733500637, 0.42403464559170456`, 0.9399291652560644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 288}], {
             RGBColor[
             0.2751436592994766, 0.40652380941229693`, 0.9389803964073136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 333}], {
             RGBColor[
             0.33643527177961996`, 0.46448215779697133`, 0.9427075059768388]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 392}], {
             RGBColor[
             0.3001114005223494, 0.4327664884837622, 0.940402272333493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 442}], {
             RGBColor[
             0.28908336711974203`, 0.42117532615991926`, 0.939774242145728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 444}], {
             RGBColor[
             0.2827572278979614, 0.41452615273743476`, 0.9394139778757318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 459}], {
             RGBColor[
             0.3423837632254584, 0.4696344421074833, 0.9430865385917233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 492}], {
             RGBColor[
             0.2854203608730804, 0.4173252743466679, 0.9395656393589127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 255}], {
             RGBColor[
             0.4462984536881862, 0.5598509487377481, 0.9499715158755377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 269}], {
             RGBColor[
             0.47197536116157857`, 0.5820909954323062, 0.9516076257145445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 360}], {
             RGBColor[
             0.5371888520305683, 0.6351531360172418, 0.9567086207009003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 369}], {
             RGBColor[
             0.457479402684923, 0.5695353247878849, 0.9506839560586847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 370}], {
             RGBColor[
             0.5432273595581627, 0.6400554684598069, 0.9571839941332545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 425}], {
             RGBColor[
             0.4351771155351065, 0.550218204604259, 0.9492628740426365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 466}], {
             RGBColor[
             0.4992597773340883, 0.6043606044932961, 0.953722705002015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 468}], {
             RGBColor[
             0.48669420259584584`, 0.5941593048480999, 0.9527334969294036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 286}], {
             RGBColor[
             0.23281996068137648`, 0.36203891868719107`, 0.9365701243833138]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 294}], {
             RGBColor[
             0.240426199543799, 0.37003355799499527`, 0.9370032884341067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 313}], {
             RGBColor[
             0.254748775686199, 0.38508749362443473`, 0.9378189379570638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 380}], {
             RGBColor[
             0.257695358998007, 0.3881845395093172, 0.937986741517592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 411}], {
             RGBColor[
             0.2410648104835609, 0.37070477858295714`, 0.937039656382386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 478}], {
             RGBColor[
             0.25429079969208646`, 0.3846061318172672, 0.9377928569017139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 260}], {
             RGBColor[
             0.28756214905519606`, 0.4195764295232854, 0.9396876110273925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 280}], {
             RGBColor[
             0.27322012310800536`, 0.4045020509158221, 0.938870853866826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 296}], {
             RGBColor[
             0.3014838445951241, 0.4337768875889444, 0.9404962532659576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 424}], {
             RGBColor[
             0.30507115038591015`, 0.4368840315616916, 0.9407248332188166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 440}], {
             RGBColor[
             0.2856108538657166, 0.41752549455988186`, 0.9395764876530341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 470}], {
             RGBColor[
             0.27251498804399493`, 0.40376090925540187`, 0.9388306974680845]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 339}], {
             RGBColor[
             0.20806801028262886`, 0.33602304945380984`, 0.9351605374253343]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 365}], {
             RGBColor[
             0.21070999979849359`, 0.338799947946794, 0.9353109948197895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 305}], {
             RGBColor[
             0.25482853774731307`, 0.38517132860787223`, 0.9378234802884469]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 367}], {
             RGBColor[
             0.24419513183599667`, 0.3739949447982042, 0.9372179235525118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 382}], {
             RGBColor[
             0.27038494943162866`, 0.40152210362155666`, 0.9387093949202199]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 416}], {
             RGBColor[
             0.26003944376158217`, 0.39064832121939286`, 0.9381202336771148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 427}], {
             RGBColor[
             0.2690226652198594, 0.4000902565411794, 0.9386318148496786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 429}], {
             RGBColor[
             0.2760715850682322, 0.4074991182291509, 0.9390332404071009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 499}], {
             RGBColor[
             0.25963192027097015`, 0.39021998819227793`, 0.9380970258172014]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 282}], {
             RGBColor[
             0.6717272001021579, 0.7429460920325152, 0.9682785844173988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 432}], {
             RGBColor[
             0.8172102397534445, 0.8577657390481622, 0.982246863062763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 467}], {
             RGBColor[
             0.7213175895970523, 0.7822180503007243, 0.9728578543010624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 261}], {
             RGBColor[
             0.9325093316648222, 0.7680041432668934, 0.5596474808987255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 277}], {
             RGBColor[
             0.8781666893011308, 0.9046720920391318, 0.9377821758000617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 291}], {
             RGBColor[
             0.819979493708928, 0.8592158126034372, 0.9319826199336896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 311}], {
             RGBColor[
             0.8659443575362178, 0.8951239135712197, 0.9365639679939195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 319}], {
             RGBColor[
             0.8499607656875054, 0.8826374101392084, 0.934970872933598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 377}], {
             RGBColor[
             0.9830684787672088, 0.9867535506374262, 0.9072964317019494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 484}], {
             RGBColor[
             0.9889617727140382, 0.9876413426482502, 0.6827040059696212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 488}], {
             RGBColor[
             0.877198073649208, 0.9039154021300979, 0.937685633244106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 315}], {
             RGBColor[
             0.21099893285942517`, 0.33910363491324724`, 0.9353274491301715]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 325}], {
             RGBColor[
             0.20775758490962407`, 0.33569677270467635`, 0.935142859159575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 347}], {
             RGBColor[
             0.20771262472504887`, 0.3356495167000475, 0.935140298743576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 368}], {
             RGBColor[
             0.32229994971598047`, 0.44690195182710835`, 0.9420022258236223]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 386}], {
             RGBColor[
             0.20771262472504887`, 0.3356495167000475, 0.935140298743576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 401}], {
             RGBColor[
             0.50497531356463, 0.5944255881948143, 0.9574168801184721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 454}], {
             RGBColor[
             0.568190337821955, 0.5020881692235942, 0.5874756893040098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 471}], {
             RGBColor[
             0.5466554162409889, 0.4017985093907806, 0.5694083486000513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 269}], {
             RGBColor[
             0.4232624333249523, 0.5410303787827784, 0.94819088586856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 274}], {
             RGBColor[
             0.43015989340709154`, 0.5467489384677, 0.9487010292927157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 334}], {
             RGBColor[
             0.40019480220882075`, 0.5210503561228367, 0.9467210368117455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 338}], {
             RGBColor[
             0.35884542683277726`, 0.48523560545214284`, 0.9440862911766009]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 369}], {
             RGBColor[
             0.40876647484829665`, 0.5284747081383571, 0.9472672162127003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 370}], {
             RGBColor[
             0.4945144317215364, 0.598994851810279, 0.9537672542872702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 379}], {
             RGBColor[
             0.35344236256380235`, 0.4805557427482631, 0.943742012699124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 390}], {
             RGBColor[
             0.3491694965791283, 0.4761158367358585, 0.9434968065582812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 425}], {
             RGBColor[
             0.38646418769848023`, 0.5091575879547311, 0.9458461341966522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 466}], {
             RGBColor[
             0.45054684949746193`, 0.5632999878437683, 0.9503059651560305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 271}], {
             RGBColor[
             0.2725957288123946, 0.4038457729222503, 0.9388352955353996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 333}], {
             RGBColor[
             0.3340176365315557, 0.4619410698643276, 0.9425698252260324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 442}], {
             RGBColor[
             0.28666573187167776`, 0.4186342382272755, 0.9396365613949216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 444}], {
             RGBColor[
             0.28033959264989716`, 0.411985064804791, 0.9392762971249253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 492}], {
             RGBColor[
             0.28300272562501616`, 0.4147841864140242, 0.9394279586081062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 272}], {
             RGBColor[
             0.8397181825766789, 0.3055916208213189, 0.18563986428858031`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 306}], {
             RGBColor[
             0.8582164736566054, 0.4477775920644729, 0.2033538487175496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 317}], {
             RGBColor[
             0.8711268784377937, 0.5076990787158229, 0.21417744721027115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 357}], {
             RGBColor[
             0.8829978584207956, 0.5607626793064351, 0.22403944465155362`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 418}], {
             RGBColor[
             0.9186634619525802, 0.7177171878043327, 0.5626295641489729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 420}], {
             RGBColor[
             0.9137481314322007, 0.7140513423503487, 0.5709499365964574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 289}], {
             RGBColor[
             0.4063967473847854, 0.5264221693154291, 0.9471162192741931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 297}], {
             RGBColor[
             0.4463933258988235, 0.5592718859080008, 0.9501602626281445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 314}], {
             RGBColor[
             0.35174895766394676`, 0.47908900053701325`, 0.9436341104363243]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 373}], {
             RGBColor[
             0.3335189671806654, 0.461900180189882, 0.9425237328349862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 381}], {
             RGBColor[
             0.4713636222770108, 0.5795438974068458, 0.952126015828245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 397}], {
             RGBColor[
             0.36598524788401654`, 0.49141975958888606`, 0.94454123426049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 472}], {
             RGBColor[
             0.3509345795878789, 0.47838362717935545`, 0.9435822189854435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 341}], {
             RGBColor[
             0.9277070351691528, 0.7270975616364004, 0.37415406223837167`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 405}], {
             RGBColor[
             0.9279266912954685, 0.7275673838799486, 0.39806227602736116`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 450}], {
             RGBColor[
             0.8397745913250846, 0.3013267240551166, 0.18550990071046175`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 454}], {
             RGBColor[
             0.8808615626968692, 0.5519020063430116, 0.22230030637499004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 469}], {
             RGBColor[
             0.8611356885897954, 0.46233141911773723`, 0.2058405534946276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 471}], {
             RGBColor[
             0.8593266411159032, 0.451612346510198, 0.20423296567103144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 475}], {
             RGBColor[
             0.8504220451203991, 0.38316771966990754`, 0.19570591448943397`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 491}], {
             RGBColor[
             0.9280010655847133, 0.727726462964249, 0.4061574584267472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 500}], {
             RGBColor[
             0.8406666807462297, 0.3081837142621151, 0.18636416654762122`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 280}], {
             RGBColor[
             0.27123440340689225`, 0.4024149336080515, 0.9387577700674566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 424}], {
             RGBColor[
             0.3030854306847971, 0.434796914253921, 0.9406117494194473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 440}], {
             RGBColor[
             0.28362513416460355`, 0.4154383772521112, 0.9394634038536649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 470}], {
             RGBColor[
             0.2705292683428818, 0.4016737919476313, 0.9387176136687151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 483}], {
             RGBColor[
             0.2911128004849959, 0.42330838930030823`, 0.9398898153736015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 484}], {
             RGBColor[
             0.9364392575786439, 0.7675671876801757, 0.34462692180178206`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 500}], {
             RGBColor[
             0.8497397394109806, 0.34938235459205963`, 0.19393494909850834`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 332}], {
             RGBColor[
             0.43913893362174417`, 0.5541636058359223, 0.9493733327998998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 344}], {
             RGBColor[
             0.4699143971667351, 0.5805367028791276, 0.9514125291795714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 387}], {
             RGBColor[
             0.6255998101870561, 0.7048955003973141, 0.9650590620780228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 393}], {
             RGBColor[
             0.46864864929250694`, 0.5795091117335374, 0.951312884870325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 424}], {
             RGBColor[
             0.39834012297090404`, 0.5188257266580119, 0.9467736686621999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 296}], {
             RGBColor[
             0.2934102361450429, 0.4252910132115676, 0.9400364732085589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 323}], {
             RGBColor[
             0.2563726589916906, 0.3867942979386546, 0.9379114157089916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 342}], {
             RGBColor[
             0.2666938975771815, 0.3976425740963284, 0.9384991949775311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 395}], {
             RGBColor[
             0.2691941123375187, 0.40027045833221453`, 0.938641578509396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 440}], {
             RGBColor[
             0.2775372454156354, 0.40903962018250506`, 0.9391167075956355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 447}], {
             RGBColor[
             0.2599502995006695, 0.3905546249491011, 0.938115157043333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 453}], {
             RGBColor[
             0.27885374219171843`, 0.41042334176488493`, 0.9391916801394509]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 463}], {
             RGBColor[
             0.2702490064672201, 0.4013792189466815, 0.9387016531695065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 394}], {
             RGBColor[
             0.23171433520063273`, 0.36087683620622507`, 0.9365071606478118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 398}], {
             RGBColor[
             0.2479686232623, 0.377961123540424, 0.9374328183068594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 445}], {
             RGBColor[
             0.23221275436386601`, 0.3614007063483834, 0.9365355448818129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 328}], {
             RGBColor[
             0.35316375548579293`, 0.48031442730049023`, 0.9437242601024758]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 433}], {
             RGBColor[
             0.32326037843179023`, 0.45441362508374517`, 0.9418188433591128]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 462}], {
             RGBColor[
             0.392446435384819, 0.5140523715462819, 0.9463065444803587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 364}], {
             RGBColor[
             0.2740437091478759, 0.405367692062097, 0.9389177558734103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 374}], {
             RGBColor[
             0.27062553266643685`, 0.40177497185519817`, 0.9387230957795312]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 410}], {
             RGBColor[
             0.326592877843097, 0.45552256223454524`, 0.9420962704893343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 437}], {
             RGBColor[
             0.2726756027922651, 0.40392972553939704`, 0.9388398442403902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 278}], {
             RGBColor[
             0.9687131736129876, 0.9678890438697982, 0.6921508091390034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 329}], {
             RGBColor[
             0.9358102453449542, 0.941979730786866, 0.7003355368972839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 406}], {
             RGBColor[
             0.9898404936899885, 0.9773917410301207, 0.415032665757733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 413}], {
             RGBColor[
             0.981449315920919, 0.9490863280728146, 0.38243452466585603`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 476}], {
             RGBColor[
             0.9187775169477521, 0.6742536840952063, 0.3030402150761125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 486}], {
             RGBColor[
             0.9619951023866931, 0.9628588250229391, 0.7028330719374227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 493}], {
             RGBColor[
             0.991319933690298, 0.9817192401312839, 0.4771566948770857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 275}], {
             RGBColor[
             0.4116793705742366, 0.5309977120097701, 0.9474528233525847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 285}], {
             RGBColor[
             0.3620365603618595, 0.4879996049239992, 0.9442896273832655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 324}], {
             RGBColor[
             0.3896661145929028, 0.5119309360971549, 0.946050158147012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 353}], {
             RGBColor[
             0.5246586597567469, 0.6237950026375101, 0.9560497714979366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 441}], {
             RGBColor[
             0.4298935905497302, 0.5467739538792281, 0.9486134173432208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 480}], {
             RGBColor[
             0.3816010072146523, 0.5049453454501976, 0.9455362566365644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 481}], {
             RGBColor[
             0.3639357382267393, 0.48964457733510314`, 0.9444106413174386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 360}], {
             RGBColor[
             0.5141528316673345, 0.616332566062272, 0.9549279906939228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 369}], {
             RGBColor[
             0.43444338232168905`, 0.5507147548329152, 0.948903326051707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 425}], {
             RGBColor[
             0.4121410951718726, 0.5313976346492894, 0.947482244035659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 466}], {
             RGBColor[
             0.47622375697085434`, 0.5855400345383266, 0.9519420749950372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 468}], {
             RGBColor[
             0.4636581822326119, 0.5753387348931303, 0.9509528669224259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 309}], {
             RGBColor[
             0.9915269265441726, 0.9888220703419007, 0.6489133693566129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 345}], {
             RGBColor[
             0.824874141314561, 0.8621219539632672, 0.8908628396870938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 375}], {
             RGBColor[
             0.9741122632489756, 0.9792447932430604, 0.8853225104060825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 426}], {
             RGBColor[
             0.9300987405065613, 0.9447298808495102, 0.9012429919407459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 489}], {
             RGBColor[
             0.9900603412249211, 0.9901577099059953, 0.8143893991227904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 284}], {
             RGBColor[
             0.2504489768010796, 0.3805681323731789, 0.9375740707715388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 442}], {
             RGBColor[
             0.26987532258207286`, 0.400986453490465, 0.9386803724250632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 444}], {
             RGBColor[
             0.26354918336029226`, 0.3943372800679805, 0.938320108155067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 464}], {
             RGBColor[
             0.24983604138275278`, 0.37992389838616725`, 0.9375391650062217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 492}], {
             RGBColor[
             0.2662123163354113, 0.39713640167721365`, 0.9384717696382479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 306}], {
             RGBColor[
             0.8390812230199529, 0.30140098239829205`, 0.18505752934082234`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 317}], {
             RGBColor[
             0.8519916278011412, 0.36132246904964216`, 0.1958811278335439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 357}], {
             RGBColor[
             0.8638626077841431, 0.41438606964025426`, 0.20574312527482636`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 308}], {
             RGBColor[
             0.23624385022904204`, 0.36563764368892326`, 0.9367651098278627]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 421}], {
             RGBColor[
             0.236299010735822, 0.36569562087892715`, 0.9367682511371211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 423}], {
             RGBColor[
             0.24068365358124288`, 0.3703041585118776, 0.9370179500606701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 446}], {
             RGBColor[
             0.26084634450324296`, 0.39149642505934035`, 0.9381661854806498]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 477}], {
             RGBColor[
             0.2691065215645594, 0.4001783948762585, 0.9386365903444549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 334}], {
             RGBColor[
             0.4327691697643524, 0.5490089625023165, 0.9488672900749079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 340}], {
             RGBColor[
             0.40008441142440987`, 0.5206990676119785, 0.9467846461754836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 361}], {
             RGBColor[
             0.5534678542610545, 0.6483409394418851, 0.9580094602549781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 363}], {
             RGBColor[
             0.4337728092244554, 0.5498782645582716, 0.9489312410938221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 369}], {
             RGBColor[
             0.4413408424038283, 0.5564333145178368, 0.9494134694758627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 370}], {
             RGBColor[
             0.5270887992770681, 0.6269534581897589, 0.9559135075504326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 379}], {
             RGBColor[
             0.386016730119334, 0.5085143491277428, 0.9458882659622865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 498}], {
             RGBColor[
             0.46231188623512687`, 0.5743646420156336, 0.95081403167012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 282}], {
             RGBColor[
             0.5106811757652547, 0.612557396257451, 0.9549190346803453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 285}], {
             RGBColor[
             0.36406115169331943`, 0.4897532041763907, 0.9444186325526303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 324}], {
             RGBColor[
             0.3916907059243627, 0.5136845353495464, 0.9461791633163769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 353}], {
             RGBColor[
             0.5266832510882068, 0.6255486018899017, 0.9561787766673014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 441}], {
             RGBColor[
             0.43191818188119013`, 0.5485275531316196, 0.9487424225125856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 481}], {
             RGBColor[
             0.36596032955819924`, 0.49139817658749463`, 0.9445396464868034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 283}], {
             RGBColor[
             0.4003771577872324, 0.5049037920541919, 0.9484114336869224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 292}], {
             RGBColor[
             0.39925539426111123`, 0.5037247474643232, 0.9483475509136101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 396}], {
             RGBColor[
             0.8065431088390325, 0.8453068187334528, 0.7510492031181083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 422}], {
             RGBColor[
             0.4267760803352025, 0.5326507334404715, 0.9499148132723232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 291}], {
             RGBColor[
             0.7131143362098424, 0.7758096064076011, 0.9720402306671867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 311}], {
             RGBColor[
             0.7590792000371321, 0.8117177073753836, 0.9766215787274166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 319}], {
             RGBColor[
             0.7430956081884199, 0.7992312039433723, 0.9750284836670953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 331}], {
             RGBColor[
             0.8039966134471465, 0.8469425741957761, 0.9810626907032964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 377}], {
             RGBColor[
             0.8762033212681233, 0.9033473444415901, 0.9473540424354466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 419}], {
             RGBColor[
             0.6419960336426249, 0.718265092425402, 0.9663099050077802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 449}], {
             RGBColor[
             0.7498021540184663, 0.8044704085174408, 0.9756969294792002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 484}], {
             RGBColor[
             0.8820966152149525, 0.9042351364524142, 0.7227616167031183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 488}], {
             RGBColor[
             0.7703329161501223, 0.8205091959342619, 0.9777432439776033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 329}], {
             RGBColor[
             0.9154608124727537, 0.9351010298249371, 0.9804756251775316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 406}], {
             RGBColor[
             0.969491060817788, 0.9705130400681918, 0.6951727540379807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 413}], {
             RGBColor[
             0.9610998830487185, 0.9422076271108857, 0.6625746129461039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 486}], {
             RGBColor[
             0.9416456695144926, 0.9559801240610102, 0.9829731602176706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 493}], {
             RGBColor[
             0.9709705008180975, 0.974840539169355, 0.7572967831573334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.2964892825686648, 0.42843496613236076`, 0.9402152006381983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 324}], {
             RGBColor[
             0.3241188367997081, 0.45236629730551653`, 0.9419757314019449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 481}], {
             RGBColor[
             0.2983884604335446, 0.4300799385434647, 0.9403362145723715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 494}], {
             RGBColor[
             0.2685318784304253, 0.3995744085078045, 0.9386038652680744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 327}], {
             RGBColor[
             0.25698076875714937`, 0.3874334598585377, 0.9379460466605166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 470}], {
             RGBColor[
             0.25618724239569113`, 0.386599413340168, 0.9379008565081486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 483}], {
             RGBColor[
             0.2767707745378052, 0.40823401069284493`, 0.939073058213035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 288}], {
             RGBColor[
             0.2504872858476244, 0.38060839761003135`, 0.9375762524150663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 343}], {
             RGBColor[
             0.26889808498261325`, 0.3999593148129905, 0.9386247201894673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 465}], {
             RGBColor[
             0.26376712193927254`, 0.39456634733259277`, 0.9383325194347287]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 324}], {
             RGBColor[
             0.48866791978392093`, 0.5934906203448358, 0.9535163694747727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 353}], {
             RGBColor[
             0.6236604649477651, 0.705354686885191, 0.9635159828256973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 432}], {
             RGBColor[
             0.7531414292760994, 0.8071831282683875, 0.9762245194841053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 441}], {
             RGBColor[
             0.5288953957407483, 0.628333638126909, 0.9560796286709814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 467}], {
             RGBColor[
             0.6572487791197071, 0.7316354395209496, 0.9668355107224047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 292}], {
             RGBColor[
             0.18009239570445779`, 0.3066189047757405, 0.9335673675613205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 386}], {
             RGBColor[
             0.18007057961528944`, 0.30659597468280464`, 0.9335661251673164]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 422}], {
             RGBColor[
             0.207613081778549, 0.3355448907518888, 0.9351346299200334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 442}], {
             RGBColor[
             0.26451897986036277`, 0.3953565976782041, 0.9383753366310607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 444}], {
             RGBColor[
             0.25819284063858217`, 0.3887074242557196, 0.9380150723610645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 464}], {
             RGBColor[
             0.24447969866104266`, 0.37429404257390636`, 0.9372341292122193]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 324}], {
             RGBColor[
             0.3420478957119857, 0.4706864282637755, 0.9430159673470576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 480}], {
             RGBColor[
             0.3339827883337351, 0.46370083761681824`, 0.9425020658366099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 481}], {
             RGBColor[
             0.3163175193458222, 0.44840006950172373`, 0.9413764505174842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 294}], {
             RGBColor[
             0.23070650372322443`, 0.3598175414232626, 0.9364497661361264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 346}], {
             RGBColor[
             0.22049146079372114`, 0.3490808836332252, 0.935868034553093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 358}], {
             RGBColor[
             0.22436323878386594`, 0.35315036778577047`, 0.9360885265818495]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 407}], {
             RGBColor[
             0.21872930348009942`, 0.347228744569382, 0.9357676823009604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 411}], {
             RGBColor[
             0.2313451146629863, 0.3604887620112245, 0.9364861340844057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 295}], {
             RGBColor[
             0.2196997994484176, 0.34824879736508285`, 0.9358229506106359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 299}], {
             RGBColor[
             0.2094890463187735, 0.33751664842668644`, 0.9352414633253583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 300}], {
             RGBColor[
             0.2178846815571592, 0.3463409933762489, 0.9357195823319551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 301}], {
             RGBColor[
             0.20928219811004087`, 0.33729923784437454`, 0.9352296836258756]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 389}], {
             RGBColor[
             0.214155749354975, 0.34242164920379625`, 0.9355072251595016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 451}], {
             RGBColor[
             0.21062876698303812`, 0.3387145671072923, 0.9353063687311225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 456}], {
             RGBColor[
             0.21673512234064032`, 0.34513273375342357`, 0.9356541166351948]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 343}], {
             RGBColor[
             0.274476709135814, 0.40582280250320485`, 0.9389424145821572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 392}], {
             RGBColor[
             0.281033651223698, 0.41271456437171095`, 0.9393158227339358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 465}], {
             RGBColor[
             0.2693457460924733, 0.4004298350228071, 0.9386502138274186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 492}], {
             RGBColor[
             0.26634261157442907`, 0.39727335023461663`, 0.9384791897593554]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 291}], {
             RGBColor[
             0.5471490964494157, 0.6426680909259248, 0.9577289938124869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 297}], {
             RGBColor[
             0.47936763079523015`, 0.5878325714725148, 0.9522613561781106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 314}], {
             RGBColor[
             0.3847232625603534, 0.5076496861015274, 0.9457352039862904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 349}], {
             RGBColor[
             0.42648626116779464`, 0.5438226964259498, 0.9483963053279869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 359}], {
             RGBColor[
             0.4124111574915527, 0.5316315490568694, 0.9474994521678624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 381}], {
             RGBColor[
             0.5043379271734174, 0.6081045829713598, 0.9542271093782111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 397}], {
             RGBColor[
             0.39895955278042317`, 0.5199804451534001, 0.9466423278104561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 419}], {
             RGBColor[
             0.4760307938821983, 0.5851235769437257, 0.9519986681530803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 472}], {
             RGBColor[
             0.3839088844842855, 0.5069443127438695, 0.9456833125354096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 316}], {
             RGBColor[
             0.268490139738015, 0.3995305384956953, 0.9386014883112883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 340}], {
             RGBColor[
             0.31195990105564253`, 0.44256756021982796`, 0.9411741462288754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 355}], {
             RGBColor[
             0.30759602149261944`, 0.4387877870773017, 0.9408960836819469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 362}], {
             RGBColor[
             0.3374733904051481, 0.4646660623491092, 0.9427998432095333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 378}], {
             RGBColor[
             0.28478483318943354`, 0.41665729445637256`, 0.939529446997508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 384}], {
             RGBColor[
             0.2851530200769201, 0.4170442822195179, 0.9395504146960666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 297}], {
             RGBColor[
             0.5871456749634538, 0.6755178075184964, 0.9607730371664382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 311}], {
             RGBColor[
             0.7008920044449292, 0.7662614279396891, 0.9708220228610445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 319}], {
             RGBColor[
             0.6849084125962169, 0.7537749245076777, 0.969228927800723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 349}], {
             RGBColor[
             0.5342643053360183, 0.6315079324719315, 0.9569079863163146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 359}], {
             RGBColor[
             0.5201892016597764, 0.619316785102851, 0.95601113315619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 419}], {
             RGBColor[
             0.583808838050422, 0.6728088129897074, 0.960510349141408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 488}], {
             RGBColor[
             0.7121457205579194, 0.7750529164985673, 0.971943688111231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 308}], {
             RGBColor[
             0.17895845847297373`, 0.30542706484967774`, 0.9335027915134972]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 386}], {
             RGBColor[
             0.17894881608916835`, 0.3054169300929359, 0.9335022423940041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 422}], {
             RGBColor[
             0.20649131825242792`, 0.3343658461620201, 0.9350707471467212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 298}], {
             RGBColor[
             0.9279560632534805, 0.9449120378208546, 0.9763848153450053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 317}], {
             RGBColor[
             0.9188363181868828, 0.7644234365766909, 0.5933539685152149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 353}], {
             RGBColor[
             0.7969674264911133, 0.8418814193634385, 0.9635324755439242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 418}], {
             RGBColor[
             0.9663729017016692, 0.9744415456652006, 0.9418060854539165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 420}], {
             RGBColor[
             0.9614575711812897, 0.9707757002112165, 0.9501264579014013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 432}], {
             RGBColor[
             0.9264483908194477, 0.943709860746635, 0.9762410122023322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 358}], {
             RGBColor[
             0.23196947764628847`, 0.36114500709357467`, 0.9365216906326425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 411}], {
             RGBColor[
             0.23895135352540886`, 0.3684834013190287, 0.9369192981351986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 430}], {
             RGBColor[
             0.23902588418057213`, 0.36856173776312173`, 0.9369235425457519]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 478}], {
             RGBColor[
             0.25217734273393444`, 0.38238475455333876`, 0.9376724986545265]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 300}], {
             RGBColor[
             0.22777276498654234`, 0.3567339960012304, 0.9362826940551499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 336}], {
             RGBColor[
             0.22591321478921644`, 0.3547794908415487, 0.9361767954223702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 389}], {
             RGBColor[
             0.22404383278435813`, 0.3528146518287777, 0.9360703368826964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 409}], {
             RGBColor[
             0.23557177233220394`, 0.3649312472071466, 0.9367268359858879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 456}], {
             RGBColor[
             0.22662320577002346`, 0.355525736378405, 0.9362172283583896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 458}], {
             RGBColor[
             0.2300435692999762, 0.35912075531195864`, 0.936412013001446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 332}], {
             RGBColor[
             0.3578059368755654, 0.48433525149749035`, 0.9440200557957121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 395}], {
             RGBColor[
             0.289203696626415, 0.4208696734674796, 0.9397969170059906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 424}], {
             RGBColor[
             0.31700712622472516`, 0.4489973723195799, 0.9414203916580124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 440}], {
             RGBColor[
             0.29754682970453167`, 0.4296388353177702, 0.94027204609223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 453}], {
             RGBColor[
             0.2988633264806147, 0.4310225569001501, 0.9403470186360454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 311}], {
             RGBColor[
             0.6331105387907436, 0.7114259084862791, 0.9653543852266682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 314}], {
             RGBColor[
             0.42471984107439154`, 0.540499402694099, 0.9487792473402418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 349}], {
             RGBColor[
             0.4664828396818328, 0.5766724130185215, 0.9514403486819383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 359}], {
             RGBColor[
             0.45240773600559087`, 0.5644812656494411, 0.9505434955218137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 381}], {
             RGBColor[
             0.5443345056874556, 0.6409542995639315, 0.9572711527321625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 397}], {
             RGBColor[
             0.4389561312944613, 0.5528301617459719, 0.9496863711644075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 419}], {
             RGBColor[
             0.5160273723962365, 0.6179732935362974, 0.9550427115070317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 353}], {
             RGBColor[
             0.7706511770330843, 0.8213765109750578, 0.9776280646137345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 418}], {
             RGBColor[
             0.9400566522436402, 0.9539366372768199, 0.955901674523727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 420}], {
             RGBColor[
             0.9351413217232607, 0.9502707918228358, 0.9642220469712115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 432}], {
             RGBColor[
             0.9001321413614187, 0.9232049523582542, 0.9903366012721426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 300}], {
             RGBColor[
             0.21756201185689822`, 0.346001847062834, 0.9357012067698722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 301}], {
             RGBColor[
             0.20895952840977988`, 0.3369600915309596, 0.9352113080637927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 389}], {
             RGBColor[
             0.213833079654714, 0.34208250289038133`, 0.9354888495974187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 451}], {
             RGBColor[
             0.21030609728277713`, 0.3383754207938774, 0.9352879931690398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 456}], {
             RGBColor[
             0.21641245264037934`, 0.34479358744000865`, 0.935635741073112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 301}], {
             RGBColor[
             0.2173551636481656, 0.3457844364805221, 0.9356894270703895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 389}], {
             RGBColor[
             0.2222287148930997, 0.35090684783994386`, 0.9359669686040155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 409}], {
             RGBColor[
             0.23375665444094554`, 0.3630234432183127, 0.936623467707207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 451}], {
             RGBColor[
             0.21870173252116284`, 0.3471997657434399, 0.9357661121756364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 456}], {
             RGBColor[
             0.22480808787876505`, 0.3536179323895711, 0.9361138600797088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 458}], {
             RGBColor[
             0.22822845140871784`, 0.35721295132312475`, 0.9363086447227651]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 389}], {
             RGBColor[
             0.21362623144598136`, 0.3418650923080694, 0.9354770698979359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 451}], {
             RGBColor[
             0.2100992490740445, 0.3381580102115655, 0.9352762134695569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 456}], {
             RGBColor[
             0.21620560443164671`, 0.3445761768576967, 0.9356239613736292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 315}], {
             RGBColor[
             0.18782448730516063`, 0.31474582329100176`, 0.934007698739376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 325}], {
             RGBColor[
             0.18458313935535953`, 0.31133896108243087`, 0.9338231087687794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 347}], {
             RGBColor[
             0.18453817917078433`, 0.311291705077802, 0.9338205483527805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 368}], {
             RGBColor[
             0.2991255041617159, 0.42254414020486286`, 0.9406824754328269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 386}], {
             RGBColor[
             0.18453817917078433`, 0.311291705077802, 0.9338205483527805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 421}], {
             RGBColor[
             0.18460298206136966`, 0.31135981702454774`, 0.9338242387815321]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 477}], {
             RGBColor[
             0.21741049289010705`, 0.3458425910218791, 0.9356925779888657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 366}], {
             RGBColor[
             0.2851324087513453, 0.4170226184095053, 0.9395492409115669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 435}], {
             RGBColor[
             0.2816881021628791, 0.4134024338033765, 0.9393530927467486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 473}], {
             RGBColor[
             0.31604489027716914`, 0.44784149062043943`, 0.9413708849892584]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 310}], {
             RGBColor[
             0.317660558842397, 0.44845488439544834`, 0.9415026138990965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 429}], {
             RGBColor[
             0.316081007071654, 0.4467946753350308, 0.9414126607624902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 483}], {
             RGBColor[
             0.3176066092257016, 0.44839817992769826`, 0.941499541548237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 382}], {
             RGBColor[
             0.2666682843502908, 0.39761565297089385`, 0.938497736342151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 416}], {
             RGBColor[
             0.2563227786802443, 0.3867418705687301, 0.9379085750990459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 427}], {
             RGBColor[
             0.26530600013852146`, 0.3961838058905166, 0.9384201562716097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 438}], {
             RGBColor[
             0.23628821482403703`, 0.36568427369114076`, 0.9367676363259161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 460}], {
             RGBColor[
             0.24972906299601538`, 0.37981145731888477`, 0.9375330727453572]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 499}], {
             RGBColor[
             0.2559152551896322, 0.3863135375416151, 0.9378853672391325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 317}], {
             RGBColor[
             0.8704899188810679, 0.5035084402927961, 0.2135951122625132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 357}], {
             RGBColor[
             0.8823608988640697, 0.5565720408834082, 0.22345710970379568`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 418}], {
             RGBColor[
             0.9180265023958543, 0.7135265493813059, 0.5620472292012149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 420}], {
             RGBColor[
             0.9131111718754747, 0.7098607039273219, 0.5703676016486996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 372}], {
             RGBColor[
             0.47013131999468205`, 0.580712810603117, 0.9514296061392018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 417}], {
             RGBColor[
             0.5854211152910297, 0.6734114544902967, 0.9611201594979415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 386}], {
             RGBColor[
             0.17893664238380538`, 0.3054041347567419, 0.9335015491194931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 421}], {
             RGBColor[
             0.1790014452743907, 0.3054722467034876, 0.9335052395482446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 422}], {
             RGBColor[
             0.20647914454706495`, 0.3343530508258261, 0.9350700538722102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 423}], {
             RGBColor[
             0.1833860881198116, 0.31008078433643804`, 0.9337549384717936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 446}], {
             RGBColor[
             0.2035487790418117, 0.3312730508839008, 0.9349031738917732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 320}], {
             RGBColor[
             0.9908166313021023, 0.9885283450055495, 0.6606847997028811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 337}], {
             RGBColor[
             0.926620732552479, 0.9394372573300418, 0.7346744089406012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 348}], {
             RGBColor[
             0.976471187338104, 0.9319682118150352, 0.39079228120582354`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 375}], {
             RGBColor[
             0.9756161016685031, 0.977924558793291, 0.7192291003603996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 489}], {
             RGBColor[
             0.9915641796444485, 0.9888374754562259, 0.6482959890771074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 327}], {
             RGBColor[
             0.2769131154519483, 0.40838362001854456`, 0.939081164317521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 399}], {
             RGBColor[
             0.26912901254486776`, 0.40020203432257306`, 0.938637871172511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 412}], {
             RGBColor[
             0.26956927876194814`, 0.4006647820312149, 0.9386629436822582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 429}], {
             RGBColor[
             0.2951775190785565, 0.4275806662601843, 0.9401212950842925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 483}], {
             RGBColor[
             0.2967031212326041, 0.4291841708528518, 0.9402081758700394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 319}], {
             RGBColor[
             0.7308732764235066, 0.7896830254754603, 0.9738102758609529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 331}], {
             RGBColor[
             0.7917742816822333, 0.837394395727864, 0.9798444828971542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 349}], {
             RGBColor[
             0.5802291691633081, 0.667416033439714, 0.9614893343765445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 377}], {
             RGBColor[
             0.8639809895032101, 0.8937991659736781, 0.9461358346293043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 419}], {
             RGBColor[
             0.6297737018777119, 0.70871691395749, 0.9650916972016379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 484}], {
             RGBColor[
             0.8698742834500395, 0.8946869579845022, 0.7215434088969761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 488}], {
             RGBColor[
             0.7581105843852092, 0.8109610174663499, 0.9765250361714609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 354}], {
             RGBColor[
             0.3330876906173925, 0.4625247982993003, 0.942459704446583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 376}], {
             RGBColor[
             0.2919333190231436, 0.4241708063077816, 0.9399365426905006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 400}], {
             RGBColor[
             0.30016668312241634`, 0.43282459400155193`, 0.9404054205957836]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 414}], {
             RGBColor[
             0.2895347527456831, 0.421649761072285, 0.9397999478893602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 415}], {
             RGBColor[
             0.29571211190112656`, 0.42814255721184813`, 0.9401517393546788]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 379}], {
             RGBColor[
             0.288128547073246, 0.4201206026991259, 0.9397217393007642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 380}], {
             RGBColor[
             0.26990447818225494`, 0.4010170978748282, 0.9386820327933616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 390}], {
             RGBColor[
             0.28385568108857195`, 0.41568069668672125`, 0.9394765331599213]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 411}], {
             RGBColor[
             0.2532739296678089, 0.38353733694846814`, 0.9377349476581557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 478}], {
             RGBColor[
             0.26649991887633445`, 0.3974386901827782, 0.9384881481774836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 359}], {
             RGBColor[
             0.3577633677707141, 0.48429838027845357`, 0.9440173433299934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 373}], {
             RGBColor[
             0.3118454823562334, 0.44312769697598026`, 0.9411427175470836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 397}], {
             RGBColor[
             0.34431176305958455`, 0.4726472763749843, 0.9431602189725873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 398}], {
             RGBColor[
             0.29561326424229706`, 0.426066606556162, 0.9402183167389095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 472}], {
             RGBColor[
             0.3292610947634469, 0.4596111439654538, 0.9422012036975409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 325}], {
             RGBColor[
             0.1822582683189515, 0.30889537421782864`, 0.9336907108025945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 347}], {
             RGBColor[
             0.1822133081343763, 0.30884811821319974`, 0.9336881503865955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 368}], {
             RGBColor[
             0.2968006331253079, 0.42010055334026064`, 0.9405500774666419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 386}], {
             RGBColor[
             0.1822133081343763, 0.30884811821319974`, 0.9336881503865955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 401}], {
             RGBColor[
             0.47947599697395743`, 0.5676241897079666, 0.9559647317614918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 378}], {
             RGBColor[
             0.26678973270236006`, 0.397743302889189, 0.9385046526461347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 357}], {
             RGBColor[
             0.895271303645258, 0.6164935275347583, 0.23428070819651722`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 418}], {
             RGBColor[
             0.9309369071770426, 0.7734480360326559, 0.5728708276939365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 420}], {
             RGBColor[
             0.9260215766566631, 0.7697821905786719, 0.5811912001414211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 321}], {
             RGBColor[
             0.33755888801482614`, 0.46679827542058316`, 0.9427299317460682]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 330}], {
             RGBColor[
             0.32419593809646025`, 0.45501163764918373`, 0.9418862305492528]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 335}], {
             RGBColor[
             0.3093572475376726, 0.43941523304457686`, 0.9410411890738053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 350}], {
             RGBColor[
             0.3520561578815369, 0.47935508192515797`, 0.9436536849625428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 354}], {
             RGBColor[
             0.35185308329442466`, 0.47917918892462685`, 0.9436407452294238]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 383}], {
             RGBColor[
             0.3354424216880899, 0.46496509866505487`, 0.9425950723832464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 479}], {
             RGBColor[
             0.3767164983407358, 0.5007146293661655, 0.94522502005032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 482}], {
             RGBColor[
             0.35021188070592757`, 0.4777576617317112, 0.9435361692517431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 496}], {
             RGBColor[
             0.3094159330482752, 0.43947691523709653`, 0.9410445311268166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 331}], {
             RGBColor[
             0.775790689833521, 0.8249078922958527, 0.9782513878368327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 377}], {
             RGBColor[
             0.8479973976544979, 0.8813126625416667, 0.9445427395689829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 449}], {
             RGBColor[
             0.7215962304048408, 0.7824357266175173, 0.9728856266127364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 488}], {
             RGBColor[
             0.7421269925364968, 0.7984745140343386, 0.9749319411111395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 337}], {
             RGBColor[
             0.9244065988908812, 0.9404637664434601, 0.9125392493325524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 348}], {
             RGBColor[
             0.9742570536765062, 0.9329947209284535, 0.5686571215977747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 361}], {
             RGBColor[
             0.8164019725999951, 0.8557645940777792, 0.9018606390244552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 375}], {
             RGBColor[
             0.9734019680069053, 0.9789510679067093, 0.8970939407523506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 335}], {
             RGBColor[
             0.3049738126003747, 0.4356185220197354, 0.94076188047572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 383}], {
             RGBColor[
             0.3310589867507921, 0.46116838764021345`, 0.942315763785161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 479}], {
             RGBColor[
             0.37233306340343797`, 0.49691791834132404`, 0.9449457114522347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 482}], {
             RGBColor[
             0.3458284457686297, 0.47396095070686983`, 0.9432568606536578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 496}], {
             RGBColor[
             0.3050324981109774, 0.4356802042122551, 0.9407652225287313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 494}], {
             RGBColor[
             0.2588610411681461, 0.3894097453786518, 0.9380531253927091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 342}], {
             RGBColor[
             0.2496659047127254, 0.3797450739586806, 0.9375294759745583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 395}], {
             RGBColor[
             0.25216611947306267`, 0.3823729581945666, 0.9376718595064233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 447}], {
             RGBColor[
             0.24292230663621342`, 0.3726571248114532, 0.9371454380403603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 452}], {
             RGBColor[
             0.23164904535488023`, 0.3608082124387239, 0.9365034424876839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 463}], {
             RGBColor[
             0.25322101360276406`, 0.3834817188090337, 0.9377319341665338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 441}], {
             RGBColor[
             0.4099049258998564, 0.5294607772190044, 0.947339757307013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 481}], {
             RGBColor[
             0.3439470735768655, 0.47233140067487944`, 0.9431369812812307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 347}], {
             RGBColor[
             0.1789719601845752, 0.3054412560046289, 0.9335035604159989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 368}], {
             RGBColor[
             0.2935592851755068, 0.41669369113168975`, 0.9403654874960453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 386}], {
             RGBColor[
             0.1789719601845752, 0.3054412560046289, 0.9335035604159989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 401}], {
             RGBColor[
             0.4762346490241563, 0.5642173274993956, 0.9557801417908952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 421}], {
             RGBColor[
             0.17903676307516053`, 0.3055093679513746, 0.9335072508447505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 405}], {
             RGBColor[
             0.9345940973525277, 0.7578425175728066, 0.403625723074449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 428}], {
             RGBColor[
             0.8527545036662538, 0.3801225472055363, 0.19711821090416948`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 434}], {
             RGBColor[
             0.9331890448533395, 0.7583565146768234, 0.5065076494810187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 469}], {
             RGBColor[
             0.8678030946468546, 0.4926065528105953, 0.21140400054171546`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 474}], {
             RGBColor[
             0.9341363327937491, 0.7587482425843726, 0.49080863680582576`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 475}], {
             RGBColor[
             0.8570894511774583, 0.4134428533627656, 0.20126936153652183`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 491}], {
             RGBColor[
             0.9346684716417725, 0.7580015966571071, 0.4117209054738351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 495}], {
             RGBColor[
             0.8586889913459645, 0.42573762002087545`, 0.2028010830083056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 399}], {
             RGBColor[
             0.24928505714751653`, 0.3793447790205158, 0.9375077872691331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 412}], {
             RGBColor[
             0.2497253233645969, 0.37980752672915763`, 0.9375328597788803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 483}], {
             RGBColor[
             0.27685916583525294`, 0.4083269155507945, 0.9390780919666615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 431}], {
             RGBColor[
             0.4169264678183623, 0.535542483915856, 0.9477871637491544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 433}], {
             RGBColor[
             0.35540962848104596`, 0.48225968960811955`, 0.9438673651437858]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 436}], {
             RGBColor[
             0.42911640965865483`, 0.5455685636524759, 0.9487109542359491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 462}], {
             RGBColor[
             0.4245956854340748, 0.5418984360706564, 0.9483550662650316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 487}], {
             RGBColor[
             0.4823721914903405, 0.5888040064890694, 0.952903444464096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 406}], {
             RGBColor[
             0.9365881325497546, 0.9446037269852596, 0.7033574817962612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 413}], {
             RGBColor[
             0.9281969547806851, 0.9162983140279535, 0.6707593407043844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 486}], {
             RGBColor[
             0.9087427412464592, 0.930070810978078, 0.9911578879759511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 350}], {
             RGBColor[
             0.33430977302587317`, 0.4637717331289171, 0.9425306751676419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 354}], {
             RGBColor[
             0.3341066984387609, 0.463595840128386, 0.9425177354345229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 414}], {
             RGBColor[
             0.2905537605670515, 0.4227208029013707, 0.9398579788773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 415}], {
             RGBColor[
             0.29673111972249494`, 0.4292135990409338, 0.9402097703426187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 482}], {
             RGBColor[
             0.33246549585026375`, 0.4621743129354704, 0.9424131594568423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 496}], {
             RGBColor[
             0.2916695481926115, 0.42389356644085574`, 0.9399215213319159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 377}], {
             RGBColor[
             0.9088984029132244, 0.9290240327940705, 0.9505769466051841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 403}], {
             RGBColor[
             0.8828018353475209, 0.9093862367613971, 0.9886836212135901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 449}], {
             RGBColor[
             0.7824972356635673, 0.8301470968699212, 0.9789198336489376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 488}], {
             RGBColor[
             0.8030279977952235, 0.8461858842867422, 0.9809661481473407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 344}], {
             RGBColor[
             0.4329675168621825, 0.5491533716913533, 0.9488874962659426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 393}], {
             RGBColor[
             0.4317017689879543, 0.548125780545763, 0.9487878519566961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 424}], {
             RGBColor[
             0.36139324266635137`, 0.48744239547023754`, 0.9442486357485711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 392}], {
             RGBColor[
             0.34232526370384136`, 0.4706729127563853, 0.943042932303461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 442}], {
             RGBColor[
             0.331297230301234, 0.4590817504325423, 0.942414902115696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 459}], {
             RGBColor[
             0.3845976264069504, 0.5075408663801063, 0.9457271985616913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 492}], {
             RGBColor[
             0.32763422405457243`, 0.45523169861929097`, 0.9422062993288807]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 340}], {
             RGBColor[
             0.37011932022613914`, 0.4950004852671151, 0.9448046536945134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 355}], {
             RGBColor[
             0.36575544066311605`, 0.49122071212458884`, 0.9445265911475849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 361}], {
             RGBColor[
             0.5235027630627838, 0.6226423570970218, 0.9560294677740079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 363}], {
             RGBColor[
             0.40380771802618465`, 0.5241796822134083, 0.9469512486128518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 369}], {
             RGBColor[
             0.4113757512055576, 0.5307347321729735, 0.9474334769948924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 370}], {
             RGBColor[
             0.49712370807879736`, 0.6012548758448955, 0.9539335150694623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 379}], {
             RGBColor[
             0.3560516389210633, 0.4828157667828796, 0.9439082734813162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 498}], {
             RGBColor[
             0.4323467950368561, 0.5486660596707702, 0.9488340391891498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 383}], {
             RGBColor[
             0.3028573462736385, 0.4337853452642071, 0.940627021112898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 409}], {
             RGBColor[
             0.25916391695491414`, 0.389728087033979, 0.938070373720701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 482}], {
             RGBColor[
             0.3176268052914761, 0.44657790833086347`, 0.9415681179813948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 496}], {
             RGBColor[
             0.27683085763382376`, 0.40829716183624876`, 0.9390764798564684]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 409}], {
             RGBColor[
             0.23189710424361965`, 0.36106893805863094`, 0.9365175690744273]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 456}], {
             RGBColor[
             0.22294853768143919`, 0.3516634272298894, 0.936007961446929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 458}], {
             RGBColor[
             0.22636890121139194`, 0.35525844616344304`, 0.9362027460899854]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 348}], {
             RGBColor[
             0.9100611549268829, 0.8839036332529456, 0.6426467308354947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 361}], {
             RGBColor[
             0.752206073850372, 0.8066735064022713, 0.9758502482621753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 370}], {
             RGBColor[
             0.7258270188663856, 0.785286025150145, 0.9737542955576297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 375}], {
             RGBColor[
             0.9092060692572821, 0.9298599802312014, 0.9710835499900707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 498}], {
             RGBColor[
             0.6610501058244442, 0.7326972089760198, 0.9686548196773171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 369}], {
             RGBColor[
             0.37002637582951403`, 0.49491998150227967`, 0.9447987313597479]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 379}], {
             RGBColor[
             0.31470226354501973`, 0.4470010161121858, 0.9412735278461717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 390}], {
             RGBColor[
             0.3104293975603457, 0.44256111009978116`, 0.9410283217053288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 425}], {
             RGBColor[
             0.3477240886796976, 0.47560286131865376`, 0.9433776493436998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 478}], {
             RGBColor[
             0.29307363534810826`, 0.42431910359583813`, 0.9400399367228911]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 365}], {
             RGBColor[
             0.2143326753092825, 0.34260760959952685`, 0.9355173008308608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 355}], {
             RGBColor[
             0.3330706823231735, 0.4629108172342508, 0.9424439472481606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 362}], {
             RGBColor[
             0.3629480512357022, 0.4887890925060583, 0.944347706775747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 363}], {
             RGBColor[
             0.37112295968624204`, 0.49586978732307024`, 0.9448686047134276]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 378}], {
             RGBColor[
             0.31025949401998754`, 0.4407803246133216, 0.9410773105637218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 379}], {
             RGBColor[
             0.32336688058112073`, 0.45450587189254155`, 0.941825629581892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 380}], {
             RGBColor[
             0.3051428116901297, 0.43540236706824387`, 0.9407859230744895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 498}], {
             RGBColor[
             0.39966203669691347`, 0.5203561647804322, 0.9467513952897255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 387}], {
             RGBColor[
             0.8843435887930974, 0.9064532397024012, 0.7600495256450741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 403}], {
             RGBColor[
             0.9612426733705868, 0.9674078133042042, 0.7674804702008887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 405}], {
             RGBColor[
             0.9937930272646951, 0.989132237877419, 0.5657875066366207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 450}], {
             RGBColor[
             0.9056409272943111, 0.562891578052587, 0.35323513131972123`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 469}], {
             RGBColor[
             0.927002024559022, 0.7238962731152077, 0.3735657841038871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 491}], {
             RGBColor[
             0.9938674015539399, 0.9892913169617195, 0.5738826890360067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 395}], {
             RGBColor[
             0.2624873580585535, 0.3932212343522405, 0.9382596387749628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 447}], {
             RGBColor[
             0.2532435452217043, 0.38350540096912705`, 0.9377332173088998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 453}], {
             RGBColor[
             0.27214698791275327`, 0.40337411778491095`, 0.9388097404050177]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 463}], {
             RGBColor[
             0.2635422521882549, 0.3943299949667075, 0.9383197134350733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 392}], {
             RGBColor[
             0.29944445035868683`, 0.4320654815746701, 0.9403642905083368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 433}], {
             RGBColor[
             0.3091968798489231, 0.4407663035487692, 0.9409764153784905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 465}], {
             RGBColor[
             0.2877565452274621, 0.4197807522257663, 0.9396986816018197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 387}], {
             RGBColor[
             0.6194283934274943, 0.6998852662527452, 0.9645732255440658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 424}], {
             RGBColor[
             0.39216870621134226`, 0.5138154925134429, 0.9462878321282429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 375}], {
             RGBColor[
             0.8089633164388916, 0.8512244424146573, 0.9611785706908804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 426}], {
             RGBColor[
             0.7649497936964772, 0.8167095300211071, 0.9770990522255436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 448}], {
             RGBColor[
             0.6138322543981429, 0.6971096748541594, 0.9629241548523259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 489}], {
             RGBColor[
             0.8249113944148371, 0.8621373590775923, 0.8902454594075883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 498}], {
             RGBColor[
             0.5608073530060538, 0.6540616711594758, 0.9587498403781267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 358}], {
             RGBColor[
             0.2217544347167852, 0.3504083493035373, 0.935939959049609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 404}], {
             RGBColor[
             0.21566548218765702`, 0.3440084741335353, 0.9355932022108733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 407}], {
             RGBColor[
             0.2161204994130187, 0.34448672608714886`, 0.9356191147687198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 408}], {
             RGBColor[
             0.22019359510263653`, 0.34876780790611966`, 0.9358510715426385]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 430}], {
             RGBColor[
             0.22881084125106885`, 0.35782507997308444`, 0.9363418109627185]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 368}], {
             RGBColor[
             0.2935143249909316, 0.4166464351270609, 0.9403629270800464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 386}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 421}], {
             RGBColor[
             0.17899180289058533`, 0.3054621119467458, 0.9335046904287516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 477}], {
             RGBColor[
             0.2117993137193227, 0.3399448859440771, 0.9353730296360853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 375}], {
             RGBColor[
             0.959056524042907, 0.9223909347161948, 0.6272014222552931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 428}], {
             RGBColor[
             0.8951225528654855, 0.5552983535621828, 0.23772264959288408`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 359}], {
             RGBColor[
             0.3995263663781553, 0.520471390602876, 0.94667844467169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 371}], {
             RGBColor[
             0.3882726943942144, 0.5107240255563866, 0.9459613706441047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 397}], {
             RGBColor[
             0.38607476166702576`, 0.5088202866994067, 0.9458213203142838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 419}], {
             RGBColor[
             0.4631460027688009, 0.5739634184897324, 0.951177660656908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 354}], {
             RGBColor[
             0.36196691822383753`, 0.4879392844043602, 0.9442851898478128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 383}], {
             RGBColor[
             0.34555625661750283`, 0.4737251941447882, 0.9432395170016354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 414}], {
             RGBColor[
             0.31841398035212815`, 0.44706424717734483`, 0.94162543329059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 479}], {
             RGBColor[
             0.3868303332701487, 0.5094747248458988, 0.9458694646687091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 482}], {
             RGBColor[
             0.36032571563534044`, 0.4865177572114446, 0.9441806138701323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 356}], {
             RGBColor[
             0.2796916905937343, 0.4113040786644009, 0.9392394000613121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 463}], {
             RGBColor[
             0.27857140569147526`, 0.4101265882019613, 0.9391756014934415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 367}], {
             RGBColor[
             0.2288379775147259, 0.35785360190672644`, 0.9363433563327893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 399}], {
             RGBColor[
             0.23466592421327268`, 0.3639791434000619, 0.936675249275597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 412}], {
             RGBColor[
             0.23510619043035305`, 0.36444189110870373`, 0.9367003217853442]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 457}], {
             RGBColor[
             0.22470998276050042`, 0.3535148176900512, 0.9361082731383572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 418}], {
             RGBColor[
             0.809068015481273, 0.8509060188194038, 0.9430493347226458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 420}], {
             RGBColor[
             0.8041526849608935, 0.8472401733654197, 0.9513697071701304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 432}], {
             RGBColor[
             0.7691435045990516, 0.820174333900838, 0.9774842614710615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 441}], {
             RGBColor[
             0.5448974710637005, 0.6413248437593597, 0.9573393706579376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 372}], {
             RGBColor[
             0.416108457877265, 0.5343687074376324, 0.9478635928798225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 414}], {
             RGBColor[
             0.3182109057650159, 0.4468883541768137, 0.941612493557471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 415}], {
             RGBColor[
             0.32438826492045936`, 0.4533811503163769, 0.9419642850227896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 479}], {
             RGBColor[
             0.38662725868303643`, 0.5092988318453677, 0.9458565249355901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 482}], {
             RGBColor[
             0.3601226410482282, 0.48634186421091347`, 0.9441676741370133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 362}], {
             RGBColor[
             0.3585841716726791, 0.48500931936353203`, 0.9440696442288183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 363}], {
             RGBColor[
             0.366759080123219, 0.492090014180544, 0.9445905421664991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 378}], {
             RGBColor[
             0.30589561445696456`, 0.4370005514707954, 0.940799248016793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 384}], {
             RGBColor[
             0.3062638013444511, 0.43738753923394075`, 0.9408202157153518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 498}], {
             RGBColor[
             0.3952981571338905, 0.516576391637906, 0.946473332742797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 463}], {
             RGBColor[
             0.26821764598055253`, 0.3992441302795001, 0.9385859701949193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 418}], {
             RGBColor[
             0.9428078871600445, 0.8265116366232681, 0.582732825135219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 420}], {
             RGBColor[
             0.937892556639665, 0.822845791169284, 0.5910531975827036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 404}], {
             RGBColor[
             0.21953726017780179`, 0.34807795828608057`, 0.9358136942396298]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 407}], {
             RGBColor[
             0.21999227740316346`, 0.34855621023969413`, 0.9358396067974764]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 408}], {
             RGBColor[
             0.2240653730927813, 0.35283729205866493`, 0.936071563571395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 430}], {
             RGBColor[
             0.23268261924121364`, 0.3618945641256297, 0.936562302991475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 371}], {
             RGBColor[
             0.37419759071797254`, 0.49853287818730624`, 0.94506451748398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 397}], {
             RGBColor[
             0.3719996579907838, 0.4966291393303264, 0.9449244671541592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 419}], {
             RGBColor[
             0.44907089909255904`, 0.561772271120652, 0.9502808074967835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 427}], {
             RGBColor[
             0.3324756951564906, 0.4596914885288097, 0.9425050411722034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 393}], {
             RGBColor[
             0.5202889035975207, 0.6214329965452928, 0.9553781948537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 466}], {
             RGBColor[
             0.5414372478398441, 0.638602175123262, 0.9570430699813932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 468}], {
             RGBColor[
             0.5288716731016017, 0.6284008754780657, 0.9560538619087819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 363}], {
             RGBColor[
             0.5245064025228867, 0.6235116591529769, 0.9560934187929221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 370}], {
             RGBColor[
             0.6178223925754994, 0.7005868527844641, 0.9630756852495326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 498}], {
             RGBColor[
             0.5530454795335582, 0.6479980366103388, 0.95797620936922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 363}], {
             RGBColor[
             0.3966364490357477, 0.5179682894523514, 0.9464943016940854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 384}], {
             RGBColor[
             0.33614117025697976`, 0.4632658145057482, 0.9427239752429382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 498}], {
             RGBColor[
             0.4251755260464191, 0.5424546669097134, 0.9483770922703834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 370}], {
             RGBColor[
             0.4981273475389003, 0.6021241779008506, 0.9539974660883765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 379}], {
             RGBColor[
             0.35705527838116624`, 0.4836850688388347, 0.9439722245002304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 498}], {
             RGBColor[
             0.433350434496959, 0.5495353617267253, 0.948897990208064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 374}], {
             RGBColor[
             0.2551484985501697, 0.3855076276983612, 0.93784170158283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 437}], {
             RGBColor[
             0.25719856867599794`, 0.38766238138256004`, 0.9379584500436889]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 435}], {
             RGBColor[
             0.2615619901606841, 0.3922486140198663, 0.9382069404421383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 473}], {
             RGBColor[
             0.29591877827497415`, 0.42668767083692927`, 0.940224732684648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 416}], {
             RGBColor[
             0.24568937276892794`, 0.3755654867590621, 0.9373030183631108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 457}], {
             RGBColor[
             0.22571706608911693`, 0.3545733261211982, 0.9361656250440755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 499}], {
             RGBColor[
             0.24528184927831587`, 0.3751371537319471, 0.9372798105031974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 386}], {
             RGBColor[
             0.2935143249909316, 0.4166464351270609, 0.9403629270800464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 401}], {
             RGBColor[
             0.5907770138305127, 0.6754225066218276, 0.9626395084549426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 500}], {
             RGBColor[
             0.6137971561371982, 0.33936679556971105`, 0.5567621778131115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 370}], {
             RGBColor[
             0.5056953807182732, 0.6086792278604158, 0.9544796944704173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 379}], {
             RGBColor[
             0.3646233115605392, 0.49024011879839996`, 0.944454452882271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 390}], {
             RGBColor[
             0.36035044557586515`, 0.48580021278599533`, 0.9442092467414281]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 425}], {
             RGBColor[
             0.397645136695217, 0.5188419640048679, 0.9465585743797993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 466}], {
             RGBColor[
             0.46172779849419876`, 0.5729843638939052, 0.9510184053391775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 466}], {
             RGBColor[
             0.5474757553674385, 0.6435045075658272, 0.9575184434137474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 382}], {
             RGBColor[
             0.322584307384319, 0.45137597056269757`, 0.9418655472151594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 419}], {
             RGBColor[
             0.43781722710861815`, 0.5520249060741627, 0.9495637334691982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 427}], {
             RGBColor[
             0.3212220231725497, 0.4499441234823203, 0.9417879671446181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 429}], {
             RGBColor[
             0.3282709430209225, 0.4573529851702918, 0.9421893927020404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 417}], {
             RGBColor[
             0.5857428674141524, 0.6736726673586156, 0.9611454890036907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 398}], {
             RGBColor[
             0.27738327375901567`, 0.40887778620903076`, 0.9391079391375716]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 472}], {
             RGBColor[
             0.31103110428016545`, 0.44242232361832246`, 0.9410908260962028]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 391}], {
             RGBColor[
             0.24642877472957408`, 0.3763426451004932, 0.9373451262109225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 437}], {
             RGBColor[
             0.25378039219455883`, 0.3840696611756612, 0.9377637899498099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 426}], {
             RGBColor[
             0.9141879156308917, 0.9338323693009003, 0.9715587229445324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 489}], {
             RGBColor[
             0.9741495163492516, 0.9792601983573855, 0.8847051301265769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 400}], {
             RGBColor[
             0.2876884645475003, 0.41970919511456195`, 0.9396948045078122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 414}], {
             RGBColor[
             0.27705653417076703`, 0.40853436218529504`, 0.9390893318013886]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 415}], {
             RGBColor[
             0.28323389332621046`, 0.41502715832485815`, 0.9394411232667073]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 464}], {
             RGBColor[
             0.2616609318454717, 0.3923526080038432, 0.9382125750247157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 485}], {
             RGBColor[
             0.26372814560153673`, 0.3945253807303899, 0.938330299789955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 497}], {
             RGBColor[
             0.25772437162935435`, 0.38821503362437043`, 0.9379883937440268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 403}], {
             RGBColor[
             0.9550085431684978, 0.9657910070072111, 0.9549749729457403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 449}], {
             RGBColor[
             0.8547039434845443, 0.8865518671157351, 0.9452111853810878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 484}], {
             RGBColor[
             0.9869984046810305, 0.9863165950507087, 0.692275872605006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 488}], {
             RGBColor[
             0.8752347056162003, 0.9025906545325564, 0.9472574998794909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 380}], {
             RGBColor[
             0.27796774382392075`, 0.40949210130478847`, 0.939141223843122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 380}], {
             RGBColor[
             0.29107513038505384`, 0.42321764858400834`, 0.9398895428612922]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 390}], {
             RGBColor[
             0.30502633329137085`, 0.4378812473959014, 0.9406840432278518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 478}], {
             RGBColor[
             0.2876705710791334, 0.41963924089195836`, 0.9396956582454141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 390}], {
             RGBColor[
             0.2868022644003798, 0.4187777425716037, 0.9396443367204493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 411}], {
             RGBColor[
             0.2562205129796168, 0.38663438283335066`, 0.9379027512186837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 478}], {
             RGBColor[
             0.26944650218814237`, 0.40053573606766074`, 0.9386559517380118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 419}], {
             RGBColor[
             0.5409976687744238, 0.6382453050351424, 0.9570084647071322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 439}], {
             RGBColor[
             0.7151086431122187, 0.7765792866784462, 0.9729163506443089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 416}], {
             RGBColor[
             0.2718791903645599, 0.40309264558241453`, 0.938794489730819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 427}], {
             RGBColor[
             0.2808624118228371, 0.41253458090420103`, 0.9393060709033827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 429}], {
             RGBColor[
             0.2879113316712099, 0.41994344259217253`, 0.9397074964608051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 499}], {
             RGBColor[
             0.27147166687394786`, 0.40266431255529955`, 0.9387712818709056]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 479}], {
             RGBColor[
             0.37021659707670174`, 0.49508474158579574`, 0.9448108520894127]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 482}], {
             RGBColor[
             0.34371197944189347`, 0.47212777395134153`, 0.9431220012908359]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 496}], {
             RGBColor[
             0.30291603178424115`, 0.4338470274567268, 0.9406303631659094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 435}], {
             RGBColor[
             0.2709692417504848, 0.4021362318949472, 0.9387426695033958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 391}], {
             RGBColor[
             0.23729940724147955`, 0.36674710103517516`, 0.9368252222381643]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 421}], {
             RGBColor[
             0.17899180289058533`, 0.3054621119467458, 0.9335046904287516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 403}], {
             RGBColor[
             0.8520128910253049, 0.8851986373727346, 0.9856507029983317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 405}], {
             RGBColor[
             0.8845632449194131, 0.9069230619459494, 0.7839577394340637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 491}], {
             RGBColor[
             0.8846376192086578, 0.9070821410302499, 0.7920529218334498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 487}], {
             RGBColor[
             0.7628017392959624, 0.8144116714200249, 0.9680174393113103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 490}], {
             RGBColor[
             0.9683628300119925, 0.9748687448836537, 0.8911081388957877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 409}], {
             RGBColor[
             0.23002772223876133`, 0.35910409904586005`, 0.9364111105347535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 451}], {
             RGBColor[
             0.21497280031897864`, 0.34328042157098726`, 0.9355537550031829]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 456}], {
             RGBColor[
             0.22107915567658082`, 0.3496985882171184, 0.9359015029072553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 458}], {
             RGBColor[
             0.2244995192065336, 0.35329360715067204`, 0.9360962875503116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 425}], {
             RGBColor[
             0.3380481584260487, 0.4664830926023694, 0.94278816472538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 478}], {
             RGBColor[
             0.2833977050944594, 0.41519933487955374`, 0.9394504521045712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 459}], {
             RGBColor[
             0.34827375514967984`, 0.47582519706689724`, 0.9434219649183455]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 465}], {
             RGBColor[
             0.2943134873153461, 0.42667251409427237`, 0.9400720897535981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 492}], {
             RGBColor[
             0.2913103527973019, 0.4235160293060819, 0.9399010656855349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 468}], {
             RGBColor[
             0.4697942541627981, 0.5804391653761509, 0.9514030710822032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 398}], {
             RGBColor[
             0.24489676758341208`, 0.3747324084550136, 0.93725788067035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 445}], {
             RGBColor[
             0.2291408986849781, 0.35817199126297306`, 0.9363606072453035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 460}], {
             RGBColor[
             0.23849436642390026`, 0.3680030789006874, 0.9368932733958195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 440}], {
             RGBColor[
             0.2733307058970075, 0.4046182804384171, 0.9388771513930672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 447}], {
             RGBColor[
             0.2557437599820415, 0.3861332852050131, 0.9378756008407647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 453}], {
             RGBColor[
             0.2746472026730905, 0.406002002020797, 0.9389521239368825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 463}], {
             RGBColor[
             0.2660424669485921, 0.39695787920259357`, 0.9384620969669382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 422}], {
             RGBColor[
             0.6137790328303492, 0.6759479174311498, 0.7377723993512193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 443}], {
             RGBColor[
             0.9640290207521414, 0.8833364286136021, 0.40253589756085995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 446}], {
             RGBColor[
             0.6108486673250959, 0.6728679174892245, 0.7376055193707824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 419}], {
             RGBColor[
             0.43561929438142943`, 0.5501211672171827, 0.9494236831393772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 472}], {
             RGBColor[
             0.3434973849835166, 0.4719419030173265, 0.9431083275217065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 445}], {
             RGBColor[
             0.2453951867466454, 0.3752562785971719, 0.9372862649043511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 460}], {
             RGBColor[
             0.2547486544855675, 0.3850873662348864, 0.9378189310548671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 472}], {
             RGBColor[
             0.2947988861662292, 0.4253612331985043, 0.9401664252880289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 412}], {
             RGBColor[
             0.24194122045751632`, 0.37162594103318614`, 0.9370895666338703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 414}], {
             RGBColor[
             0.28528989827003975`, 0.41718814987906533`, 0.9395582097066717]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 415}], {
             RGBColor[
             0.2914672574254832, 0.4236809460186285, 0.9399100011719903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 464}], {
             RGBColor[
             0.26989429594474446`, 0.40100639569761354`, 0.9386814529299987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 450}], {
             RGBColor[
             0.7955804305647025, 0.4800334417304184, 0.5713225662708019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 454}], {
             RGBColor[
             0.8366674019364873, 0.7306087240183134, 0.6081129719353302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 471}], {
             RGBColor[
             0.8151324803555211, 0.6303190641854999, 0.5900456312313715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 475}], {
             RGBColor[
             0.806227884360017, 0.5618744373452094, 0.5815185800497742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 500}], {
             RGBColor[
             0.7964725199858478, 0.48689043193741693`, 0.5721768321079614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 431}], {
             RGBColor[
             0.5004255816893457, 0.6051773211877334, 0.9538503277794443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 436}], {
             RGBColor[
             0.5126155235296384, 0.6152034009243532, 0.954774118266239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 459}], {
             RGBColor[
             0.4714286755649022, 0.5800616585296188, 0.952002670562152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 462}], {
             RGBColor[
             0.5080947993050582, 0.6115332733425336, 0.9544182302953215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 487}], {
             RGBColor[
             0.565871305361324, 0.6584388437609466, 0.958966608494386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 405}], {
             RGBColor[
             0.9614623294969025, 0.9678776355477525, 0.7913886839898783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 449}], {
             RGBColor[
             0.8286073759188407, 0.8669140710830616, 0.9833178599894938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 491}], {
             RGBColor[
             0.9615367037861473, 0.968036714632053, 0.7994838663892643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 407}], {
             RGBColor[
             0.2139033248740353, 0.3421563350696921, 0.9354928499587406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 408}], {
             RGBColor[
             0.2179764205636531, 0.3464374168886629, 0.9357248067326592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 434}], {
             RGBColor[
             0.9926076308918226, 0.9901160572249841, 0.6925776468321798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 469}], {
             RGBColor[
             0.9272216806853377, 0.724366095358756, 0.3974739978928766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 474}], {
             RGBColor[
             0.9935549188322322, 0.9905077851325332, 0.6768786341569868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 491}], {
             RGBColor[
             0.9940870576802556, 0.9897611392052678, 0.5977909028249961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 413}], {
             RGBColor[
             0.9822272031257195, 0.951710324271208, 0.3854564695648335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 476}], {
             RGBColor[
             0.9195554041525527, 0.6768776802935997, 0.3060621599750899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 486}], {
             RGBColor[
             0.9627729895914936, 0.9654828212213326, 0.7058550168364002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 493}], {
             RGBColor[
             0.9920978208950986, 0.9843432363296774, 0.4801786397760631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 408}], {
             RGBColor[
             0.2184314377890148, 0.3469156688422765, 0.9357507192905059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 430}], {
             RGBColor[
             0.22704868393744712`, 0.35597294090924125`, 0.9362414587105858]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{408, 430}], {
             RGBColor[
             0.23112177962706493`, 0.36025402272821205`, 0.9364734154845045]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 456}], {
             RGBColor[
             0.23260709522442666`, 0.3618151835954873, 0.9365580020104467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 458}], {
             RGBColor[
             0.23602745875437942`, 0.36541020252904094`, 0.9367527866535031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 496}], {
             RGBColor[
             0.25922260246551676`, 0.38978976922649866`, 0.9380737157737123]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{411, 478}], {
             RGBColor[
             0.2528159536736963, 0.3830559751413007, 0.9377088666028057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 476}], {
             RGBColor[
             0.9111642263834832, 0.6485722673362936, 0.273464018883213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 486}], {
             RGBColor[
             0.9543818118224241, 0.9371774082640264, 0.6732568757445232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 493}], {
             RGBColor[
             0.9837066431260291, 0.9560378233723712, 0.44758049868418615`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 415}], {
             RGBColor[
             0.2808353270487499, 0.4125061130893616, 0.9393045284655668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 485}], {
             RGBColor[
             0.26132957932407624`, 0.39200433549489333`, 0.9381937049888145]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{415, 464}], {
             RGBColor[
             0.2654397247234546, 0.39632435890790974`, 0.9384277716888938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{415, 485}], {
             RGBColor[
             0.2675069384795197, 0.39849713163445644`, 0.9385454964541331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 427}], {
             RGBColor[
             0.2705169061527906, 0.4016607985020373, 0.9387169096602777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 429}], {
             RGBColor[
             0.2775658260011634, 0.4090696601900088, 0.9391183352177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 499}], {
             RGBColor[
             0.26112616120390136`, 0.3917905301531358, 0.9381821206278006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{417, 461}], {
             RGBColor[
             0.8227440842305245, 0.8622334494485463, 0.9748712810946092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 420}], {
             RGBColor[
             0.9735581601714495, 0.9798002996671817, 0.9296433170801228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 432}], {
             RGBColor[
             0.9385489798096075, 0.9527344602026001, 0.9557578713810538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 432}], {
             RGBColor[
             0.933633649289228, 0.949068614748616, 0.9640782438285385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 439}], {
             RGBColor[
             0.9147776569049322, 0.9340333582536569, 0.9622797424419812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 423}], {
             RGBColor[
             0.18344124862659156`, 0.31013876152644193`, 0.9337580797810521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 477}], {
             RGBColor[
             0.21186411660990806`, 0.34001299789082284`, 0.9353767200648369]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 443}], {
             RGBColor[
             0.5842619922483114, 0.5706803433206208, 0.6014015077150748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 446}], {
             RGBColor[
             0.2310816388212659, 0.36021183219624314`, 0.9364711295249972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 446}], {
             RGBColor[
             0.20798858239401255`, 0.3359395657068551, 0.9351560141245807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 477}], {
             RGBColor[
             0.21624875945532895`, 0.3446215355237733, 0.9356264189883857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 440}], {
             RGBColor[
             0.30113413549531765`, 0.4327459792905174, 0.940500626045089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 453}], {
             RGBColor[
             0.3024506322714007, 0.4341297008728973, 0.9405755985889044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 470}], {
             RGBColor[
             0.28803826967359597`, 0.4189813939860375, 0.9397548358601392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{425, 466}], {
             RGBColor[
             0.4394255113443823, 0.5536672437102792, 0.9495973233231294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 448}], {
             RGBColor[
             0.7190568535901429, 0.7797176017404024, 0.9733043071059779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 489}], {
             RGBColor[
             0.9301359936068372, 0.9447452859638352, 0.9006256116612403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 460}], {
             RGBColor[
             0.2639231904685617, 0.39473038525219195`, 0.938341407306589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 499}], {
             RGBColor[
             0.27010938266217854`, 0.4012324654749223, 0.9386937018003643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 495}], {
             RGBColor[
             0.8362679836981737, 0.2797771922017657, 0.1823635681891872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{429, 499}], {
             RGBColor[
             0.2771583025105514, 0.4086413271628938, 0.9390951273577867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 433}], {
             RGBColor[
             0.3870230907643596, 0.509641681699111, 0.9458817470057914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 436}], {
             RGBColor[
             0.46072987194196846`, 0.5729505557434673, 0.9507253360979548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 459}], {
             RGBColor[
             0.41954302397723237`, 0.5378088133487329, 0.9479538883938678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 462}], {
             RGBColor[
             0.4562091477173884, 0.5692804281616477, 0.9503694481270373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 487}], {
             RGBColor[
             0.5139856537736541, 0.6161859985800608, 0.9549178263261018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{432, 467}], {
             RGBColor[
             0.8027318187709938, 0.8464550865365966, 0.9808037893677689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 462}], {
             RGBColor[
             0.3946923083800721, 0.5159976338539112, 0.9464496495216687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 469}], {
             RGBColor[
             0.9258166281861495, 0.7248800924627727, 0.5003559242994462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 474}], {
             RGBColor[
             0.992149866333044, 0.99102178223655, 0.7797605605635565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 495}], {
             RGBColor[
             0.9167025248852594, 0.6580111596730529, 0.4917530067660364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 459}], {
             RGBColor[
             0.4317329658175249, 0.5478348930853527, 0.9488776788806625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 462}], {
             RGBColor[
             0.46839908955768095`, 0.5793065078982675, 0.951293238613832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 487}], {
             RGBColor[
             0.5261755956139467, 0.6262120783166807, 0.9558416168128965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 457}], {
             RGBColor[
             0.22152681415849518`, 0.35016910566479753`, 0.9359269963955489]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 460}], {
             RGBColor[
             0.23490540515407732`, 0.3642308530528161, 0.9366888873608955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 453}], {
             RGBColor[
             0.2829903357512072, 0.4147711638710876, 0.939427253023122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 470}], {
             RGBColor[
             0.2685779731534025, 0.3996228569842277, 0.9386064902943567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 467}], {
             RGBColor[
             0.5784857852356426, 0.6676055963951182, 0.960658898554645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 444}], {
             RGBColor[
             0.27761918641957545`, 0.4091257453730057, 0.939121374014589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 492}], {
             RGBColor[
             0.2802823193946945, 0.4119248669822389, 0.9392730354977699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{443, 446}], {
             RGBColor[
             0.5813316267430582, 0.5676003433786956, 0.6012346277346379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{444, 492}], {
             RGBColor[
             0.2739561801729139, 0.4052756935597544, 0.9389127712277736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{445, 460}], {
             RGBColor[
             0.23899278558713355`, 0.3685269490428458, 0.9369216576298206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 453}], {
             RGBColor[
             0.26540338983624123`, 0.39628616863768357`, 0.9384257024708196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 463}], {
             RGBColor[
             0.2567986541117429, 0.38724204581948013`, 0.9379356755008752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{449, 488}], {
             RGBColor[
             0.7488335383665432, 0.8037137186084069, 0.9756003869232444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 454}], {
             RGBColor[
             0.8587954548220276, 0.3876960227591984, 0.20138137545633958`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 469}], {
             RGBColor[
             0.8390695807149537, 0.298125435533924, 0.18492162257597716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 471}], {
             RGBColor[
             0.8372605332410615, 0.2874063629263848, 0.183314034752381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 475}], {
             RGBColor[
             0.8283559372455574, 0.2189617360860943, 0.17478698357078354`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 491}], {
             RGBColor[
             0.9059349577098716, 0.5635204793804358, 0.38523852750809673`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 500}], {
             RGBColor[
             0.8186005728713881, 0.14397773067830186`, 0.16544523562897076`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{451, 456}], {
             RGBColor[
             0.21755217330464396`, 0.3459915061206145, 0.9357006464788762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{453, 463}], {
             RGBColor[
             0.2757020968027919, 0.407110762635264, 0.939012198596993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 469}], {
             RGBColor[
             0.8801565520867384, 0.5487007178218191, 0.22171202824050545`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 471}], {
             RGBColor[
             0.8783475046128462, 0.5379816452142798, 0.2201044404169093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 475}], {
             RGBColor[
             0.8694429086173421, 0.4695370183739893, 0.21157738923531183`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 500}], {
             RGBColor[
             0.8596875442431727, 0.3945530129661969, 0.20223564129349905`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{456, 458}], {
             RGBColor[
             0.22707889219219896`, 0.35600469170029936`, 0.9362431790260048]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{461, 486}], {
             RGBColor[
             0.9396915520193736, 0.9545227464327241, 0.9862809714214389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{461, 493}], {
             RGBColor[
             0.9690163833229786, 0.9733831615410689, 0.7606045943611018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{462, 487}], {
             RGBColor[
             0.5216548713893666, 0.6225419507348611, 0.9554857288419789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 485}], {
             RGBColor[
             0.24593397699878092`, 0.3758225813134415, 0.9373169482121415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 497}], {
             RGBColor[
             0.23993020302659857`, 0.369512234207422, 0.9369750421662133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 468}], {
             RGBColor[
             0.49094259840512156`, 0.5976083439541202, 0.9530679462098963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 471}], {
             RGBColor[
             0.8586216305057723, 0.4484110579890054, 0.20364468753654688`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 474}], {
             RGBColor[
             0.9267639161265591, 0.7252718203703219, 0.4846569116242533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 475}], {
             RGBColor[
             0.8497170345102683, 0.3799664311487149, 0.19511763635494941`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 491}], {
             RGBColor[
             0.9272960549745825, 0.7245251744430564, 0.40556918029226263`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 495}], {
             RGBColor[
             0.8513165746787745, 0.3922611978068248, 0.19664935782673318`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 475}], {
             RGBColor[
             0.847907987036376, 0.36924735854117574`, 0.19351004853135326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 500}], {
             RGBColor[
             0.8381526226622067, 0.29426335313338325`, 0.18416830058954048`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{474, 495}], {
             RGBColor[
             0.917649812825669, 0.658402887580602, 0.4760539940908434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{476, 493}], {
             RGBColor[
             0.9210348441528622, 0.6812051793947629, 0.36818618909444256`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{479, 482}], {
             RGBColor[
             0.3849860560945393, 0.5078773046524521, 0.9457519489579096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{480, 481}], {
             RGBColor[
             0.33588196619861493`, 0.46534581002792214`, 0.9426230797707831]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{482, 496}], {
             RGBColor[
             0.31768549080207875`, 0.4466395905233832, 0.9415714600344062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{484, 500}], {
             RGBColor[
             0.9061921804601966, 0.5690195539734165, 0.316991474169404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{485, 497}], {
             RGBColor[
             0.24199741678266362`, 0.3716850069339687, 0.9370927669314526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{486, 493}], {
             RGBColor[
             0.9642524295918031, 0.9698103203224957, 0.7679790459557528]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.0315874366232787], {
             RGBColor[
             0.2661654894960651, 0.39708718370006774`, 0.9384691029190212]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.0315874366232787], {
             RGBColor[
             0.2124476857409665, 0.34062636604798524`, 0.9354099534635375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.0315874366232787], {
             RGBColor[
             0.46166603367100856`, 0.5738403098087559, 0.9507631877904368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.0315874366232787], {
             RGBColor[
             0.32430364693803726`, 0.45531725182765653`, 0.9418853195058047]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.0315874366232787], {
             RGBColor[
             0.23860734128045696`, 0.3681218226379481, 0.9368997071467691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.0315874366232787], {
             RGBColor[
             0.8276898195746623, 0.8654414113599355, 0.9834269879500976]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.0315874366232787], {
             RGBColor[
             0.8386821070512293, 0.8742063630160551, 0.9844754421425435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.0315874366232787], {
             RGBColor[
             0.6202936289377985, 0.7026213377380665, 0.963250933161866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.0315874366232787], {
             RGBColor[
             0.5751436787516512, 0.6659665741948753, 0.9596965636934954]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.0315874366232787], {
             RGBColor[
             0.2189624152550279, 0.3474737598249721, 0.9357809576716846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.0315874366232787], {
             RGBColor[
             0.23891813183632316`, 0.3684484832174229, 0.9369174062091523]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.0315874366232787], {
             RGBColor[
             0.27240341106773047`, 0.40364363477895904`, 0.9388243433243495]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.0315874366232787], {
             RGBColor[
             0.29661626096016863`, 0.4290928751992627, 0.9402032293060224]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.0315874366232787], {
             RGBColor[
             0.30674268007373295`, 0.4397363837396738, 0.9407799138938453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.0315874366232787], {
             RGBColor[
             0.23423879357827926`, 0.36353020202103736`, 0.9366509248178173]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.0315874366232787], {
             RGBColor[
             0.4038820814050813, 0.5242440920345965, 0.9469559869815982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.0315874366232787], {
             RGBColor[
             0.8799712561457314, 0.9071292097399156, 0.9884136380424356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.0315874366232787], {
             RGBColor[
             0.8843839202879132, 0.5678962094964264, 0.22523944788984251`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.0315874366232787], {
             RGBColor[
             0.5597245266210166, 0.6534486118703385, 0.9584827115555565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.0315874366232787], {
             RGBColor[
             0.8845340276069948, 0.5685778117739207, 0.22536470111635126`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.0315874366232787], {
             RGBColor[
             0.9808877657874093, 0.9471920876142448, 0.3802530084370154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.0315874366232787], {
             RGBColor[
             0.4514165271362265, 0.5654160397762044, 0.9499848398305268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.0315874366232787], {
             RGBColor[
             0.2225015077722568, 0.35119357045200544`, 0.9359825037549226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.0315874366232787], {
             RGBColor[
             0.8369720141620951, 0.8728427813654944, 0.9843123319561599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.0315874366232787], {
             RGBColor[
             0.3133752819583538, 0.4458516513578495, 0.941188973752873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.0315874366232787], {
             RGBColor[
             0.3866295369467384, 0.5093008051628776, 0.9458566701045386]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.0315874366232787], {
             RGBColor[
             0.5121189165844965, 0.6148002330343991, 0.9547350235483862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.0315874366232787], {
             RGBColor[
             0.9648560740830788, 0.9733102981108331, 0.9443736789601879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.0315874366232787], {
             RGBColor[
             0.40962031041891445`, 0.5292142575946026, 0.9473216218602429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.0315874366232787], {
             RGBColor[
             0.2679312243382506, 0.39894308297325987`, 0.938569658906113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.0315874366232787], {
             RGBColor[
             0.4530382628066378, 0.5668207057031098, 0.9500881753934008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.0315874366232787], {
             RGBColor[
             0.5357107322431658, 0.6339531317852908, 0.9565922576967049]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.0315874366232787], {
             RGBColor[
             0.8784142522519405, 0.5407893411964669, 0.22025821055067316`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.0315874366232787], {
             RGBColor[
             0.5437530683305409, 0.6404822625241338, 0.9572253798535508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.0315874366232787], {
             RGBColor[
             0.23837242809378653`, 0.36787491398440125`, 0.9368863291883112]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.0315874366232787], {
             RGBColor[
             0.254389289460926, 0.3847096508089296, 0.9377984657483468]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.0315874366232787], {
             RGBColor[
             0.305640198745031, 0.4385776059618545, 0.9407171292131508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.0315874366232787], {
             RGBColor[
             0.25996867538836677`, 0.3905739391721695, 0.9381162035229527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.0315874366232787], {
             RGBColor[
             0.6236615875481659, 0.7053555982627691, 0.963516071200913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.0315874366232787], {
             RGBColor[
             0.3862001571816754, 0.5089288979916344, 0.9458293104055944]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.0315874366232787], {
             RGBColor[
             0.23252667542550592`, 0.36173065728791187`, 0.9365534222218687]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.0315874366232787], {
             RGBColor[
             0.23247426890382172`, 0.3616755747108564, 0.9365504377479873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.0315874366232787], {
             RGBColor[
             0.2931478124699098, 0.42544731592366486`, 0.940005706295612]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.0315874366232787], {
             RGBColor[
             0.49667724948997916`, 0.6022639920478948, 0.9535193989500155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.0315874366232787], {
             RGBColor[
             0.28278247170568477`, 0.41455268557990177`, 0.9394154154732368]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.0315874366232787], {
             RGBColor[
             0.9176548470302313, 0.7112359389100995, 0.2526013609126037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.0315874366232787], {
             RGBColor[
             0.23193365260590854`, 0.36110735270469657`, 0.9365196504495912]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.0315874366232787], {
             RGBColor[
             0.20751087662989864`, 0.3354374666604766, 0.9351288094880167]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.0315874366232787], {
             RGBColor[
             0.49021471545548245`, 0.5970174157848499, 0.9530106445977776]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.0315874366232787], {
             RGBColor[
             0.44093802683048844`, 0.5563400894761129, 0.9493171590568191]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.0315874366232787], {
             RGBColor[
             0.17892700081062782`, 0.30539400085202123`, 0.9335010000461641]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.0315874366232787], {
             RGBColor[
             0.8357950446989824, 0.2761419758107905, 0.18191068126945342`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.0315874366232787], {
             RGBColor[
             0.9765123065091236, 0.9324326360618924, 0.36325517537702773`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.0315874366232787], {
             RGBColor[
             0.22872079714307936`, 0.35773043790646125`, 0.9363366830839769]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.0315874366232787], {
             RGBColor[
             0.21147766438726034`, 0.339606812102334, 0.9353547121824619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.0315874366232787], {
             RGBColor[
             0.8366736085240676, 0.28289500235951803`, 0.1827519949805509]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.0315874366232787], {
             RGBColor[
             0.6012429877716181, 0.6871551690177569, 0.9617511969044663]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.0315874366232787], {
             RGBColor[
             0.31511174381280593`, 0.44735568733906544`, 0.9412996195667458]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.0315874366232787], {
             RGBColor[
             0.2421911048281961, 0.37188858535035474`, 0.9371037971791099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.0315874366232787], {
             RGBColor[
             0.29270959820985176`, 0.42498672495195505`, 0.9399807506417815]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.0315874366232787], {
             RGBColor[
             0.3238266917401457, 0.45490413720770817`, 0.94185492834235]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.0315874366232787], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.0315874366232787], {
             RGBColor[
             0.41933559472005666`, 0.5376291485518648, 0.9479406711850231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.0315874366232787], {
             RGBColor[
             0.2878344487965492, 0.41986263381624833`, 0.9397031180948312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.0315874366232787], {
             RGBColor[
             0.9854648277298144, 0.9626315922912277, 0.39803402977763763`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.0315874366232787], {
             RGBColor[
             0.2632810725593861, 0.3940554786170215, 0.9383048396415897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.0315874366232787], {
             RGBColor[
             0.25662307112871396`, 0.38705749697171266`, 0.9379256763097434]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.0315874366232787], {
             RGBColor[
             0.8199864588949732, 0.15463025795470559`, 0.16677236165029033`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.0315874366232787], {
             RGBColor[
             0.9094625081980608, 0.9306447336077317, 0.9912265399903383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.0315874366232787], {
             RGBColor[
             0.2582501634540876, 0.38876767416929214`, 0.9380183368106061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.0315874366232787], {
             RGBColor[
             0.755781538403036, 0.8091415490436711, 0.97629289863413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.0315874366232787], {
             RGBColor[
             0.2539844574642687, 0.3842841467126117, 0.9377754111650324]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.0315874366232787], {
             RGBColor[
             0.24791046842011605`, 0.37789999911405875`, 0.9374295064746294]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.0315874366232787], {
             RGBColor[
             0.2817340129849886, 0.4134506889883278, 0.9393557073001488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.0315874366232787], {
             RGBColor[
             0.3449485107481652, 0.47319879521896346`, 0.9432007919722498]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.0315874366232787], {
             RGBColor[
             0.4113253016274047, 0.530691035284047, 0.9474302623923834]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.0315874366232787], {
             RGBColor[
             0.606817875551374, 0.6916811140631951, 0.9621900724919755]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.0315874366232787], {
             RGBColor[
             0.21942909899518986`, 0.3479642740253404, 0.9358075346202901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.0315874366232787], {
             RGBColor[
             0.9938287149952354, 0.9892085703244617, 0.5696718958667929]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.0315874366232787], {
             RGBColor[
             0.7895429134572223, 0.8355161918319554, 0.9796579169815435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.0315874366232787], {
             RGBColor[
             0.8236181467643259, 0.8621947699835874, 0.9830386281626226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.0315874366232787], {
             RGBColor[
             0.25827862318556116`, 0.3887975871515221, 0.9380199575502111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.0315874366232787], {
             RGBColor[
             0.9207457022290968, 0.9396416462539369, 0.9923027411096448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.0315874366232787], {
             RGBColor[
             0.2333142933423989, 0.36255849365642656`, 0.9365982758970595]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.0315874366232787], {
             RGBColor[
             0.21421555473578224`, 0.34248450845090483`, 0.9355106309874645]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.0315874366232787], {
             RGBColor[
             0.9151930916309041, 0.7014758990831244, 0.2506205747334791]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.0315874366232787], {
             RGBColor[
             0.1792532619022457, 0.3057369219454596, 0.9335195801326717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.0315874366232787], {
             RGBColor[
             0.8666101266120032, 0.4871895635890985, 0.21040855877111306`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.0315874366232787], {
             RGBColor[
             0.28550171685781406`, 0.4174107846448903, 0.9395702724618878]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.0315874366232787], {
             RGBColor[
             0.8647697772859632, 0.4788329671240561, 0.2088729261823753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.0315874366232787], {
             RGBColor[
             0.3276288460270304, 0.4581973721491767, 0.9420971982513973]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.0315874366232787], {
             RGBColor[
             0.6091375885965603, 0.6935643616151592, 0.9623726888002815]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.0315874366232787], {
             RGBColor[
             0.26928527939714464`, 0.4003662806922068, 0.9386467703385721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.0315874366232787], {
             RGBColor[
             0.9554190789968999, 0.9662722026272221, 0.9603480500785777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.0315874366232787], {
             RGBColor[
             0.22708291988077767`, 0.3560089250563658, 0.936243408396911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.0315874366232787], {
             RGBColor[
             0.2961617343973124, 0.4286151389630523, 0.9401773446906796]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.0315874366232787], {
             RGBColor[
             0.2317345075524728, 0.36089803862701, 0.9365083094334068]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.0315874366232787], {
             RGBColor[
             0.9952347378240085, 0.9922159109844932, 0.7227088038116687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.0315874366232787], {
             RGBColor[
             0.9936215336094609, 0.9887654302895413, 0.5471214806005384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.0315874366232787], {
             RGBColor[
             0.9312148525901699, 0.7649968423512695, 0.2635120596803694]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.0315874366232787], {
             RGBColor[
             0.5208327276256995, 0.6218744973903617, 0.9554210066732913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.0315874366232787], {
             RGBColor[
             0.2765375568294345, 0.40798888409449063`, 0.939059776809558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.0315874366232787], {
             RGBColor[
             0.4803557055985901, 0.589013427439692, 0.9522345072271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.0315874366232787], {
             RGBColor[
             0.24657366739272524`, 0.3764949364761905, 0.9373533776337394]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.0315874366232787], {
             RGBColor[
             0.2459052705491277, 0.3757924090147619, 0.9373153134223011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.0315874366232787], {
             RGBColor[
             0.5178553382148801, 0.619457318536794, 0.9551866156723348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.0315874366232787], {
             RGBColor[
             0.18467169248908813`, 0.3114320360405726, 0.9338281517387427]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.0315874366232787], {
             RGBColor[
             0.28511069510105125`, 0.41699979598632125`, 0.939548004351305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.0315874366232787], {
             RGBColor[
             0.25396000439311356`, 0.38425844498441336`, 0.9377740185988052]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.0315874366232787], {
             RGBColor[
             0.27171530098953856`, 0.4029203874580805, 0.9387851564733641]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.0315874366232787], {
             RGBColor[
             0.27309124258507717`, 0.4043665893147275, 0.9388635143117069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.0315874366232787], {
             RGBColor[
             0.24826352560257345`, 0.3782710845979398, 0.937449612558869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.0315874366232787], {
             RGBColor[
             0.17919226069553715`, 0.305672805809509, 0.9335161062041928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.0315874366232787], {
             RGBColor[
             0.5006784839436625, 0.605512374430953, 0.9538343907832142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.0315874366232787], {
             RGBColor[
             0.9211683800910966, 0.9399786781078106, 0.9923430565014513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.0315874366232787], {
             RGBColor[
             0.24872594858728536`, 0.3787571204741826, 0.9374759468637549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.0315874366232787], {
             RGBColor[
             0.38107527345035186`, 0.504489981287708, 0.9455027573459912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.0315874366232787], {
             RGBColor[
             0.32510810483221725`, 0.45601403282236586`, 0.9419365788514676]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.0315874366232787], {
             RGBColor[
             0.9906473743776302, 0.9904004632007044, 0.8046607405893015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.0315874366232787], {
             RGBColor[
             0.20742150462258202`, 0.3353435310142743, 0.9351237198844141]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.0315874366232787], {
             RGBColor[
             0.8274659414661699, 0.21212083852708477`, 0.1739347226073356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.0315874366232787], {
             RGBColor[
             0.867504304657107, 0.49124981725132677`, 0.21115468285025726`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.0315874366232787], {
             RGBColor[
             0.2069635167020156, 0.33486215667164765`, 0.9350976381498702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.0315874366232787], {
             RGBColor[
             0.9626525497894284, 0.8856804222207267, 0.30941263771645156`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.0315874366232787], {
             RGBColor[
             0.20867358600249122`, 0.3366595479311035, 0.9351950240667115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.0315874366232787], {
             RGBColor[
             0.2511378152607278, 0.38129214526915, 0.9376132991027705]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.0315874366232787], {
             RGBColor[
             0.22597981130456574`, 0.35484948800164373`, 0.9361805879953986]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.0315874366232787], {
             RGBColor[
             0.49474321248409076`, 0.6006938536791404, 0.9533671444723009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.0315874366232787], {
             RGBColor[
             0.35559977387920144`, 0.4824243839950162, 0.9438794810404173]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.0315874366232787], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.0315874366232787], {
             RGBColor[
             0.263609049878749, 0.394400203574635, 0.9383235174647285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.0315874366232787], {
             RGBColor[
             0.9901329118562932, 0.9901877197270478, 0.8131867159541827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.0315874366232787], {
             RGBColor[
             0.3451736656290086, 0.4733938130601367, 0.9432151386421606]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.0315874366232787], {
             RGBColor[
             0.2332063867745317, 0.36244507701192663`, 0.9365921307776528]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.0315874366232787], {
             RGBColor[
             0.25062676841059334`, 0.3807550026274169, 0.9375841957406814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.0315874366232787], {
             RGBColor[
             0.968960662006962, 0.9763714930638193, 0.9374256822530368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.0315874366232787], {
             RGBColor[
             0.22008054170119, 0.3486489816131997, 0.9358446333186737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.0315874366232787], {
             RGBColor[
             0.2199663924455993, 0.34852900350809307`, 0.9358381326874365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.0315874366232787], {
             RGBColor[
             0.5640351798749514, 0.6569481943745988, 0.9588220619701494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.0315874366232787], {
             RGBColor[
             0.4996340643500339, 0.6046644675542787, 0.9537521702469687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.0315874366232787], {
             RGBColor[
             0.30958288032569087`, 0.4425668636752852, 0.9409473252743288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.0315874366232787], {
             RGBColor[
             0.6995243049605603, 0.765192970707599, 0.9706857033583209]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.0315874366232787], {
             RGBColor[
             0.17892700134778292`, 0.3053940014166053, 0.9335010000767543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.0315874366232787], {
             RGBColor[
             0.24622776306205768`, 0.3761313690930576, 0.9373336788938276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.0315874366232787], {
             RGBColor[
             0.2206581667895666, 0.3492561022046294, 0.935877528212937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.0315874366232787], {
             RGBColor[
             0.257933230334439, 0.3884345573658211, 0.9380002879383026]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.0315874366232787], {
             RGBColor[
             0.25149316947897704`, 0.3816656450832887, 0.9376335359998004]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.0315874366232787], {
             RGBColor[
             0.23965584235908116`, 0.3692238637503902, 0.9369594177320785]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.0315874366232787], {
             RGBColor[
             0.353874772698637, 0.4809302746734916, 0.9437695654905504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.0315874366232787], {
             RGBColor[
             0.8214446559981496, 0.16583859987576455`, 0.16816873284309014`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.0315874366232787], {
             RGBColor[
             0.30679432383558886`, 0.439790664607788, 0.9407828549296829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.0315874366232787], {
             RGBColor[
             0.20400293554931437`, 0.33175039816847185`, 0.9349290374330113]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.0315874366232787], {
             RGBColor[
             0.24493296406314102`, 0.3747704532501981, 0.9372599420063227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.0315874366232787], {
             RGBColor[
             0.30954120355039927`, 0.44253076534726327`, 0.9409446696670606]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.0315874366232787], {
             RGBColor[
             0.5658891207695752, 0.6584533071119401, 0.9589680109885835]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.0315874366232787], {
             RGBColor[
             0.46730916543215706`, 0.578421658392645, 0.9512074357941471]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.0315874366232787], {
             RGBColor[
             0.3025436094347634, 0.43532289426166115`, 0.9405407830329243]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.0315874366232787], {
             RGBColor[
             0.3575213303529286, 0.48408873963232213`, 0.9440019209197574]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.0315874366232787], {
             RGBColor[
             0.8207501650068003, 0.16050043778835987`, 0.16750368748545852`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.0315874366232787], {
             RGBColor[
             0.42248174875901884`, 0.5403541890501141, 0.948141141338351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.0315874366232787], {
             RGBColor[
             0.9903319581123935, 0.9790495659282263, 0.41694191223350735`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.0315874366232787], {
             RGBColor[
             0.46203141681910903`, 0.5741369443087071, 0.9507919520902978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.0315874366232787], {
             RGBColor[
             0.26699231078344465`, 0.3979562252966011, 0.9385161891681649]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.0315874366232787], {
             RGBColor[
             0.8175247092939038, 0.13570817177533162`, 0.16441498745215766`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.0315874366232787], {
             RGBColor[
             0.4240332554553848, 0.5416980261695123, 0.9482400019731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.0315874366232787], {
             RGBColor[
             0.8381204118994321, 0.2940157670958513, 0.18413745552673064`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.0315874366232787], {
             RGBColor[
             0.9866702547547157, 0.9887558220293171, 0.870571905196646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.0315874366232787], {
             RGBColor[
             0.9107922199972238, 0.6840279095591187, 0.24707953011528597`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.0315874366232787], {
             RGBColor[
             0.4927421843014464, 0.5990693288551774, 0.9532096162037554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.0315874366232787], {
             RGBColor[
             0.29668056881803306`, 0.42916046683523196`, 0.9402068915433929]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.0315874366232787], {
             RGBColor[
             0.26174222518751433`, 0.39243805246062563`, 0.9382172045602823]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.0315874366232787], {
             RGBColor[
             0.3516524550010693, 0.4790054147807936, 0.9436279613719797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.0315874366232787], {
             RGBColor[
             0.984562956112485, 0.9878843998856498, 0.9054952972124768]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.0315874366232787], {
             RGBColor[
             0.2666571079259713, 0.3976039058403079, 0.93849709986132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.0315874366232787], {
             RGBColor[
             0.9557302644442173, 0.966504284224312, 0.9598212942864327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.0315874366232787], {
             RGBColor[
             0.6069446059586334, 0.6917839995169481, 0.9622000491738637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.0315874366232787], {
             RGBColor[
             0.20869655844004803`, 0.3366836934195124, 0.9351963323130457]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.0315874366232787], {
             RGBColor[
             0.9916846362160958, 0.9908293976273234, 0.7874706275783359]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.0315874366232787], {
             RGBColor[
             0.178929137062006, 0.30539624618766587`, 0.9335011217025198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.0315874366232787], {
             RGBColor[
             0.27013094278236094`, 0.4012551265282246, 0.9386949296173133]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.0315874366232787], {
             RGBColor[
             0.4206971967779904, 0.5388084998183378, 0.9480274312641372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.0315874366232787], {
             RGBColor[
             0.3785866605047563, 0.5023344698355566, 0.9453441851296919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.0315874366232787], {
             RGBColor[
             0.2049673414252272, 0.33276404989092045`, 0.9349839589209338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.0315874366232787], {
             RGBColor[
             0.2570318728012019, 0.3874871734490205, 0.9379489569602237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.0315874366232787], {
             RGBColor[
             0.2839447494602888, 0.41577431319265656`, 0.9394816054719256]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.0315874366232787], {
             RGBColor[
             0.23571041014604155`, 0.365076964339635, 0.9367347312042897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.0315874366232787], {
             RGBColor[
             0.26462809617956273`, 0.3954712858480575, 0.938381550644016]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.0315874366232787], {
             RGBColor[
             0.33727714516499796`, 0.4665542439248693, 0.9427119793408126]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.0315874366232787], {
             RGBColor[
             0.2597753641562747, 0.39037075681060074`, 0.9381051947342635]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.0315874366232787], {
             RGBColor[
             0.24810961844878143`, 0.3781093184210272, 0.9374408477741458]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.0315874366232787], {
             RGBColor[
             0.21840138119578575`, 0.34688407745709465`, 0.9357490076119863]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.0315874366232787], {
             RGBColor[
             0.2546146394674752, 0.38494650795382845`, 0.9378112990978443]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.0315874366232787], {
             RGBColor[
             0.2878117179623051, 0.41983874226823964`, 0.9397018236074483]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.0315874366232787], {
             RGBColor[
             0.9865160895376739, 0.9886920707502049, 0.8731268218098209]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.0315874366232787], {
             RGBColor[
             0.2701519252165497, 0.40127718039692006`, 0.9386961245358997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.0315874366232787], {
             RGBColor[
             0.29569933477919436`, 0.42812912764658106`, 0.9401510117164867]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.0315874366232787], {
             RGBColor[
             0.6976256228082208, 0.7637097057796726, 0.9704964604655693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.0315874366232787], {
             RGBColor[
             0.2818794421164257, 0.41360354422620765`, 0.9393639892740411]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.0315874366232787], {
             RGBColor[
             0.3428438781472085, 0.4713758682419251, 0.9430666866439704]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.0315874366232787], {
             RGBColor[
             0.9008280073528754, 0.6425649682443086, 0.23896079721830538`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.0315874366232787], {
             RGBColor[
             0.3044587746178886, 0.4373358542976118, 0.9406498488568703]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.0315874366232787], {
             RGBColor[
             0.23905706042934927`, 0.3685945059772749, 0.9369253179869986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.0315874366232787], {
             RGBColor[
             0.5345666356633387, 0.6330243026408235, 0.956502190222977]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.0315874366232787], {
             RGBColor[
             0.5018930513522051, 0.606498414968846, 0.9539300059787216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.0315874366232787], {
             RGBColor[
             0.9938265629209484, 0.98920396725517, 0.5694376558617151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.0315874366232787], {
             RGBColor[
             0.3427341577200499, 0.4712808339226293, 0.9430596953553738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.0315874366232787], {
             RGBColor[
             0.217062994597398, 0.3454773482835776, 0.9356727884751737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.0315874366232787], {
             RGBColor[
             0.32211852500862637`, 0.45342460903982235`, 0.9417460854686901]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.0315874366232787], {
             RGBColor[
             0.5659235722129052, 0.6584812763456551, 0.9589707231324023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.0315874366232787], {
             RGBColor[
             0.8360637140310553, 0.2782070860287545, 0.182167959325265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.0315874366232787], {
             RGBColor[
             0.2310404057237692, 0.3601684935964447, 0.9364687813610937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.0315874366232787], {
             RGBColor[
             0.21851625165510197`, 0.3470048135930438, 0.9357555493147087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.0315874366232787], {
             RGBColor[
             0.90420589766789, 0.657903179238463, 0.24177939169682186`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.0315874366232787], {
             RGBColor[
             0.19980711485308938`, 0.32734032458634205`, 0.9346900916515217]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.0315874366232787], {
             RGBColor[
             0.28412310253725925`, 0.4159617735847908, 0.9394917624158093]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.0315874366232787], {
             RGBColor[
             0.26588598144981995`, 0.39679340302163035`, 0.9384531853492826]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.0315874366232787], {
             RGBColor[
             0.31971976000988434`, 0.4513469193633465, 0.9415932382841149]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.0315874366232787], {
             RGBColor[
             0.23197293745711564`, 0.3611486435741187, 0.9365218876637508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.0315874366232787], {
             RGBColor[
             0.5262688994117111, 0.6262878265429939, 0.9558489620296395]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.0315874366232787], {
             RGBColor[
             0.3389132056188999, 0.46797131725924984`, 0.9428162276662237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.0315874366232787], {
             RGBColor[
             0.5366100807415061, 0.6346832634114314, 0.9566630577049163]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.0315874366232787], {
             RGBColor[
             0.4427137030371586, 0.5578780909582495, 0.9494303035745394]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.0315874366232787], {
             RGBColor[
             0.38986378476733635`, 0.5121021480670574, 0.9460627535157341]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.0315874366232787], {
             RGBColor[
             0.29896629209325354`, 0.43156290692071464`, 0.9403370601024921]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.0315874366232787], {
             RGBColor[
             0.27424929290791517`, 0.4055837736286615, 0.9389294635644105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.0315874366232787], {
             RGBColor[
             0.1794249922972142, 0.30591742147890744`, 0.9335293599246128]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.0315874366232787], {
             RGBColor[
             0.8456311671254343, 0.35174672299683013`, 0.19132976321333509`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.0315874366232787], {
             RGBColor[
             0.9930813033990235, 0.9876099324950685, 0.48832075610881853`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.0315874366232787], {
             RGBColor[
             0.2909757990296596, 0.42316439208435586`, 0.9398820133433956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.0315874366232787], {
             RGBColor[
             0.2238780227461086, 0.35264037496561385`, 0.936060894246312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.0315874366232787], {
             RGBColor[
             0.2584463601503126, 0.3889738893366137, 0.9380295099222091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.0315874366232787], {
             RGBColor[
             0.3561976264336458, 0.4829422138287328, 0.9439175756765262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.0315874366232787], {
             RGBColor[
             0.8431597968980244, 0.3327506884676198, 0.18896317629255405`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.0315874366232787], {
             RGBColor[
             0.38857864336543946`, 0.5109890231778194, 0.9459808654420111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.0315874366232787], {
             RGBColor[
             0.3570417238501652, 0.48367332858535217`, 0.9439713608175008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.0315874366232787], {
             RGBColor[
             0.28732315690654525`, 0.419325233622076, 0.939674000778084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.0315874366232787], {
             RGBColor[
             0.906092392768253, 0.9279574950433493, 0.9909050953721057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.0315874366232787], {
             RGBColor[
             0.32015392046586916`, 0.45172296732878153`, 0.9416209026044572]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.0315874366232787], {
             RGBColor[
             0.3509305166159243, 0.47838010803725933`, 0.9435819600964633]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.0315874366232787], {
             RGBColor[
             0.2566255537350775, 0.38706010634840704`, 0.9379258176905032]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.0315874366232787], {
             RGBColor[
             0.7054821402904016, 0.7698472769484965, 0.9712795247048629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.0315874366232787], {
             RGBColor[
             0.22500762673968802`, 0.3538276603838957, 0.936125223522647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.0315874366232787], {
             RGBColor[
             0.8393061093521738, 0.30312955729356095`, 0.18527288074652987`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.0315874366232787], {
             RGBColor[
             0.3424410288691568, 0.4710269404450701, 0.9430410174441985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.0315874366232787], {
             RGBColor[
             0.22156287013367681`, 0.3502070027807943, 0.9359290497299955]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.0315874366232787], {
             RGBColor[
             0.29422140859812795`, 0.42657573352434824`, 0.9400668460068708]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.0315874366232787], {
             RGBColor[
             0.4950113815248125, 0.6009115653872759, 0.9533882557215221]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.0315874366232787], {
             RGBColor[
             0.24253965650195108`, 0.3722549352589237, 0.9371236466812941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.0315874366232787], {
             RGBColor[
             0.2895478687563091, 0.421663546831056, 0.9398006948267619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.0315874366232787], {
             RGBColor[
             0.20444533477183996`, 0.332215387801077, 0.934954231414263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.0315874366232787], {
             RGBColor[
             0.25854520282865096`, 0.38907777925853504`, 0.9380351388665158]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.0315874366232787], {
             RGBColor[
             0.7357960105795031, 0.7935287028122899, 0.9743009279960564]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.0315874366232787], {
             RGBColor[
             0.9850318468002165, 0.9880782982349678, 0.8977245650665646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.0315874366232787], {
             RGBColor[
             0.23649824945009773`, 0.365905033400095, 0.9367795974871519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.0315874366232787], {
             RGBColor[
             0.3975855258515599, 0.5187903320882202, 0.9465547760295533]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.0315874366232787], {
             RGBColor[
             0.2893861381019995, 0.4214935576590608, 0.939791484505258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.0315874366232787], {
             RGBColor[
             0.8588534332133313, 0.4519682304874997, 0.20393618366530758`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.0315874366232787], {
             RGBColor[
             0.3734224424883788, 0.497861483750915, 0.945015125724227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.0315874366232787], {
             RGBColor[
             0.8618406991999262, 0.46553270763892984`, 0.20642883162911219`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.0315874366232787], {
             RGBColor[
             0.28557642935408295`, 0.4174893122155148, 0.9395745272280231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.0315874366232787], {
             RGBColor[
             0.8799868165294279, 0.5479299882988189, 0.2215703967308864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.0315874366232787], {
             RGBColor[
             0.47608581392629684`, 0.5855469370236965, 0.9518983657135286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.0315874366232787], {
             RGBColor[
             0.2734006518561467, 0.40469179807630246`, 0.9388811347119643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.0315874366232787], {
             RGBColor[
             0.23478619087952063`, 0.36410555129163547`, 0.9366820982843213]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.0315874366232787], {
             RGBColor[
             0.32101450543653715`, 0.45246836277611585`, 0.9416757383178027]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.0315874366232787], {
             RGBColor[
             0.28952074326414307`, 0.421635036218934, 0.9397991500701115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.0315874366232787], {
             RGBColor[
             0.9890626064851881, 0.9747677448317271, 0.41201072085875556`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.0315874366232787], {
             RGBColor[
             0.40965477924277666`, 0.5292441127573786, 0.9473238181832199]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.0315874366232787], {
             RGBColor[
             0.44893934079834463`, 0.5632704254773366, 0.9498269957075668]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.0315874366232787], {
             RGBColor[
             0.9900230881246451, 0.9901423047916702, 0.8150067794022959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.0315874366232787], {
             RGBColor[
             0.2558053195227897, 0.38619798818543977`, 0.9378791065655412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.0315874366232787], {
             RGBColor[
             0.8205829319400263, 0.15921501115513814`, 0.16734354491185305`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.0315874366232787], {
             RGBColor[
             0.2935414156904733, 0.42586101786436276`, 0.9400281214167392]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.0315874366232787], {
             RGBColor[
             0.4627342609626232, 0.5747075448471798, 0.9508472825558781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.0315874366232787], {
             RGBColor[
             0.4137039619056965, 0.5327513112621616, 0.9475818285219495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.0315874366232787], {
             RGBColor[
             0.6195401563438858, 0.7020096347427746, 0.9631916170392121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.0315874366232787], {
             RGBColor[
             0.7713015318020453, 0.8212658858432957, 0.977839786533559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.0315874366232787], {
             RGBColor[
             0.9483637407407871, 0.9610103429078694, 0.9722908974192511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.0315874366232787], {
             RGBColor[
             0.2785602236563872, 0.4101148351741018, 0.9391749646930856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.0315874366232787], {
             RGBColor[
             0.25689237745970156`, 0.38734055500058817`, 0.9379410129068901]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.0315874366232787], {
             RGBColor[
             0.24490866169442368`, 0.374744909919817, 0.9372585580223763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.0315874366232787], {
             RGBColor[
             0.6076583896248129, 0.6923634812527404, 0.9622562408387412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.0315874366232787], {
             RGBColor[
             0.18121415923057888`, 0.3077979493656092, 0.9336312503346327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.0315874366232787], {
             RGBColor[
             0.24509263407936946`, 0.37493827656091794`, 0.9372690349775362]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.0315874366232787], {
             RGBColor[
             0.3144183414809424, 0.4467550970906198, 0.941255436583311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.0315874366232787], {
             RGBColor[
             0.22310026486080187`, 0.3518229021154584, 0.9360166020853335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.0315874366232787], {
             RGBColor[
             0.20981171601903448`, 0.33785579474010136`, 0.9352598388874411]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.0315874366232787], {
             RGBColor[
             0.2560659100008252, 0.3864718853002457, 0.9378939468077562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.0315874366232787], {
             RGBColor[
             0.439371052281192, 0.5549828548799431, 0.9492173128241592]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.0315874366232787], {
             RGBColor[
             0.2864852402250885, 0.41844453006287885`, 0.9396262826626617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.0315874366232787], {
             RGBColor[
             0.6549271406176395, 0.7303533269719065, 0.9662406748008145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.0315874366232787], {
             RGBColor[
             0.1789706321783367, 0.30543986018587177`, 0.9335034847880083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.0315874366232787], {
             RGBColor[
             0.9542723127115095, 0.9654169462092355, 0.962289226275195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.0315874366232787], {
             RGBColor[
             0.23831274258564697`, 0.36781218073106675`, 0.9368829301869194]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.0315874366232787], {
             RGBColor[
             0.22958788287780074`, 0.3586417999900643, 0.9363860623338308]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.0315874366232787], {
             RGBColor[
             0.3134198204339392, 0.44589022834683273`, 0.9411918117051534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.0315874366232787], {
             RGBColor[
             0.5193642093092683, 0.6206822880650865, 0.955305399532062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.0315874366232787], {
             RGBColor[
             0.9016398137954514, 0.9244071294324739, 0.9904804044148157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.0315874366232787], {
             RGBColor[
             0.2091663766185125, 0.3371775021132715, 0.9352230877632756]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.0315874366232787], {
             RGBColor[
             0.22595764709528393`, 0.3548261920123965, 0.936179325776469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.0315874366232787], {
             RGBColor[
             0.20875268020104726`, 0.3367426809486477, 0.9351995283643099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.0315874366232787], {
             RGBColor[
             0.19014935834156865`, 0.31718941015560403`, 0.934140096705561]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.0315874366232787], {
             RGBColor[
             0.3052585207535403, 0.43817643819301544`, 0.9406953932161773]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.0315874366232787], {
             RGBColor[
             0.3385640468354945, 0.4676688934702948, 0.9427939795772942]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.0315874366232787], {
             RGBColor[
             0.2511118726659751, 0.3812648779572094, 0.9376118217103779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.0315874366232787], {
             RGBColor[
             0.8575795140998795, 0.443586953641446, 0.20277151376979163`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.0315874366232787], {
             RGBColor[
             0.46980956787155936`, 0.580451597734798, 0.9514042766334527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.0315874366232787], {
             RGBColor[
             0.17894628476761076`, 0.30541426951348377`, 0.9335020982389862]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.0315874366232787], {
             RGBColor[
             0.9930307649637, 0.9875018358921313, 0.48281995931092997`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.0315874366232787], {
             RGBColor[
             0.29675707084929953`, 0.4292408753206019, 0.9402112482208989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.0315874366232787], {
             RGBColor[
             0.746856868272219, 0.8021695289074716, 0.9754033709212744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.0315874366232787], {
             RGBColor[
             0.3044115375980597, 0.43728620519477157`, 0.940647158778472]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.0315874366232787], {
             RGBColor[
             0.266957894870447, 0.3979200519899457, 0.9385142292328336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.0315874366232787], {
             RGBColor[
             0.33007547283951477`, 0.4603165173231115, 0.9422530951484216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.0315874366232787], {
             RGBColor[
             0.1854996162687526, 0.3123022364263995, 0.933875300773191]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.0315874366232787], {
             RGBColor[
             0.2504950392509415, 0.38061654692851177`, 0.937576693959915]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.0315874366232787], {
             RGBColor[
             0.8834003236622562, 0.5634299269441462, 0.22441871075523476`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.0315874366232787], {
             RGBColor[
             0.341942322952124, 0.4705949864454246, 0.9430092403441536]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.0315874366232787], {
             RGBColor[
             0.7148896845747944, 0.7771965220434489, 0.9722171808006315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.0315874366232787], {
             RGBColor[
             0.9886024976405045, 0.9895548541189678, 0.8385496400948322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.0315874366232787], {
             RGBColor[
             0.3331754530775283, 0.46300156439574175`, 0.942450623147983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.0315874366232787], {
             RGBColor[
             0.25921854913182885`, 0.38978550891579644`, 0.9380734849423552]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.0315874366232787], {
             RGBColor[
             0.23934466612723454`, 0.36889679780100676`, 0.9369416967060188]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.0315874366232787], {
             RGBColor[
             0.369677449943029, 0.49461775943693126`, 0.9447764981108042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.0315874366232787], {
             RGBColor[
             0.1790169203691504, 0.30548851200925775`, 0.9335061208319979]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.0315874366232787], {
             RGBColor[
             0.8751755113140446, 0.526082975024646, 0.21755572572328788`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.0315874366232787], {
             RGBColor[
             0.2570691600545971, 0.38752636471648727`, 0.9379510804141431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.0315874366232787], {
             RGBColor[
             0.3853130055350487, 0.5081604918248647, 0.9457727818871488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.0315874366232787], {
             RGBColor[
             0.8825578842047201, 0.909191716742005, 0.9886603529358121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.0315874366232787], {
             RGBColor[
             0.3064495532407965, 0.43942828885294294`, 0.9407632207543519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.0315874366232787], {
             RGBColor[
             0.8366916950922476, 0.8726192625482565, 0.984285594873034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.0315874366232787], {
             RGBColor[
             0.40219205331719154`, 0.5227802746481479, 0.946848299886271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.0315874366232787], {
             RGBColor[
             0.3786491349611119, 0.5023885820695944, 0.9453481659468069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.0315874366232787], {
             RGBColor[
             0.4028040785660817, 0.5233103801574531, 0.9468872975939376]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.0315874366232787], {
             RGBColor[
             0.2767721721232211, 0.4082354796437291, 0.9390731378034569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.0315874366232787], {
             RGBColor[
             0.22223854670063217`, 0.35091718169303304`, 0.9359675285109096]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.0315874366232787], {
             RGBColor[
             0.860210700141258, 0.8913726787679522, 0.9865288585702724]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.0315874366232787], {
             RGBColor[
             0.32010532781399464`, 0.4516808788160655, 0.9416178063236486]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.0315874366232787], {
             RGBColor[
             0.21169068579341777`, 0.33983071110654267`, 0.9353668434364056]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.0315874366232787], {
             RGBColor[
             0.3374345618861965, 0.46669059037677707`, 0.9427220097950892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.0315874366232787], {
             RGBColor[
             0.9935733711383794, 0.9886624156338708, 0.5418792928476311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.0315874366232787], {
             RGBColor[
             0.25998714329821626`, 0.39059335011635443`, 0.9381172552430979]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.0315874366232787], {
             RGBColor[
             0.29288750827080284`, 0.425173719706164, 0.9399908823565584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.0315874366232787], {
             RGBColor[
             0.4637429804071734, 0.5755264687345587, 0.9509266926456142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.0315874366232787], {
             RGBColor[
             0.6597251945044771, 0.7341016031348642, 0.9667188999718916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.0315874366232787], {
             RGBColor[
             0.21788265672664042`, 0.34633886515099205`, 0.9357194670208525]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.0315874366232787], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.0315874366232787], {
             RGBColor[
             0.9599116097125079, 0.876434587737939, 0.29876460310071706`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.0315874366232787], {
             RGBColor[
             0.41360147005439724`, 0.5326625379719564, 0.9475752978318146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.0315874366232787], {
             RGBColor[
             0.3621699928109498, 0.4881151774048913, 0.9442981295809318]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.0315874366232787], {
             RGBColor[
             0.290045450304657, 0.422186536586862, 0.9398290313598343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.0315874366232787], {
             RGBColor[
             0.2278308941861094, 0.35679509347557953`, 0.9362860044270709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.0315874366232787], {
             RGBColor[
             0.6396625402707171, 0.7183458925176417, 0.9647757248126534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.0315874366232787], {
             RGBColor[
             0.3617638436367253, 0.48776339140382907`, 0.9442722501146938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.0315874366232787], {
             RGBColor[
             0.32870680276015046`, 0.45913104409172456`, 0.942165884701232]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.0315874366232787], {
             RGBColor[
             0.26933793088281155`, 0.4004216207419397, 0.9386497687627899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.0315874366232787], {
             RGBColor[
             0.9071422836282599, 0.6695571281253704, 0.2441427056377997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.0315874366232787], {
             RGBColor[
             0.22562621270692998`, 0.3544778334560826, 0.9361604510783655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.0315874366232787], {
             RGBColor[
             0.38545126270191343`, 0.5082802432337956, 0.9457815915115654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.0315874366232787], {
             RGBColor[
             0.5793663225363243, 0.6693947066472076, 0.9600289856802787]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.0315874366232787], {
             RGBColor[
             0.6442014475594858, 0.7219743340365904, 0.9651716379540781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.0315874366232787], {
             RGBColor[
             0.38846154058520777`, 0.5108875946353395, 0.9459734037564047]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.0315874366232787], {
             RGBColor[
             0.40481135748628755`, 0.5250489842693634, 0.9470151996317661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.0315874366232787], {
             RGBColor[
             0.2585666750316088, 0.38910034790526005`, 0.938036361676709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.0315874366232787], {
             RGBColor[
             0.2169746648251472, 0.34538450809251103`, 0.9356677582253161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.0315874366232787], {
             RGBColor[
             0.2650062967491503, 0.3958687986259951, 0.9384030886069564]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.0315874366232787], {
             RGBColor[
             0.2298450608433424, 0.3589121103378734, 0.9364007082385077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.0315874366232787], {
             RGBColor[
             0.4081016499818632, 0.5278988702541217, 0.9472248541600927]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.0315874366232787], {
             RGBColor[
             0.4199474238450335, 0.5381590841884939, 0.9479796563958474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.0315874366232787], {
             RGBColor[
             0.591443337591513, 0.6791993715323379, 0.960979732544987]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.0315874366232787], {
             RGBColor[
             0.36294391873403165`, 0.48878551314081686`, 0.9443474434563948]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.0315874366232787], {
             RGBColor[
             0.4704530721178047, 0.5809740234714359, 0.951454935644951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.0315874366232787], {
             RGBColor[
             0.293615491872952, 0.425938876628849, 0.9400323399457455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.0315874366232787], {
             RGBColor[
             0.2517303220687306, 0.38191490749146234`, 0.937647041488951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.0315874366232787], {
             RGBColor[
             0.9582014383733062, 0.9683472816944506, 0.9556382414098691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.0315874366232787], {
             RGBColor[
             0.2794551004482275, 0.4110554074207916, 0.9392259266025292]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.0315874366232787], {
             RGBColor[
             0.9811051107342013, 0.9854288030398846, 0.9168682983373343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.0315874366232787], {
             RGBColor[
             0.2830844261537786, 0.4148700588498662, 0.9394326113323542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.0315874366232787], {
             RGBColor[
             0.3092991992760449, 0.442321153408306, 0.9409292493686947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.0315874366232787], {
             RGBColor[
             0.27285106149406285`, 0.4041141437597107, 0.9388498363538897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.0315874366232787], {
             RGBColor[
             0.5693048020656428, 0.6612263110627765, 0.9592369059322629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.0315874366232787], {
             RGBColor[
             0.28222469603460637`, 0.4139664279845783, 0.9393836509739241]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.0315874366232787], {
             RGBColor[
             0.32894252042405586`, 0.45933521088468515`, 0.942180904422339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.0315874366232787], {
             RGBColor[
             0.28382079992875175`, 0.41564403437615693`, 0.9394745467294715]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.0315874366232787], {
             RGBColor[
             0.2334715870925415, 0.36272381936082626`, 0.9366072335434348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.0315874366232787], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.0315874366232787], {
             RGBColor[
             0.7751138064478154, 0.8242440637709316, 0.9782197584425172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.0315874366232787], {
             RGBColor[
             0.9461721011462925, 0.9593758216867757, 0.9760007715815773]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.0315874366232787], {
             RGBColor[
             0.2184997826909155, 0.34698750366749115`, 0.9357546114315619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.0315874366232787], {
             RGBColor[
             0.30075346730669683`, 0.43344134138349677`, 0.9404388370870089]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.0315874366232787], {
             RGBColor[
             0.2411272273904176, 0.370770382709524, 0.937043210932894]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.0315874366232787], {
             RGBColor[
             0.3060013924465708, 0.4389572434431762, 0.9407376986601153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.0315874366232787], {
             RGBColor[
             0.4612114846587171, 0.5734712864433781, 0.9507274040271213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.0315874366232787], {
             RGBColor[
             0.22864247952174482`, 0.3576481211208147, 0.9363322230113024]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.0315874366232787], {
             RGBColor[
             0.26498757281889074`, 0.39584911858812655`, 0.9384020223068277]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.0315874366232787], {
             RGBColor[
             0.9935460613341791, 0.9886040027241311, 0.5389067891970045]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.0315874366232787], {
             RGBColor[
             0.3585480532796543, 0.48497803542685713`, 0.944067342796753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.0315874366232787], {
             RGBColor[
             0.26115105564507934`, 0.3918166957892125, 0.9381835383293976]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.0315874366232787], {
             RGBColor[
             0.24150095424043594`, 0.3711631933245442, 0.9370644941241232]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.0315874366232787], {
             RGBColor[
             0.295921828646773, 0.42836298280833224`, 0.9401636824130951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[401, 0.0315874366232787], {
             RGBColor[
             0.7734523776791622, 0.8229461429895335, 0.9780541627497925]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[402, 0.0315874366232787], {
             RGBColor[
             0.5523112332770156, 0.6474301663686192, 0.9578991099477285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[403, 0.0315874366232787], {
             RGBColor[
             0.9289119756027943, 0.9461532109745376, 0.9930816475541463]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[404, 0.0315874366232787], {
             RGBColor[
             0.2134483076486736, 0.3416780831160786, 0.9354669374008939]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[405, 0.0315874366232787], {
             RGBColor[
             0.9940126833910108, 0.9896020601209673, 0.5896957204256101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[406, 0.0315874366232787], {
             RGBColor[
             0.990618380894789, 0.9800157372285142, 0.4180546106567104]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[407, 0.0315874366232787], {
             RGBColor[
             0.21435834209939697`, 0.3426345870233057, 0.9355187625165873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[408, 0.0315874366232787], {
             RGBColor[
             0.2225045334786326, 0.3511967506612473, 0.9359826760644245]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[409, 0.0315874366232787], {
             RGBColor[
             0.24155566178660715`, 0.3712206944242289, 0.937067609637945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[410, 0.0315874366232787], {
             RGBColor[
             0.36366501242205085`, 0.4894100882501565, 0.9443933909085572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[411, 0.0315874366232787], {
             RGBColor[
             0.23958996446517072`, 0.3691546219069906, 0.9369556660834778]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[412, 0.0315874366232787], {
             RGBColor[
             0.2423814866745967, 0.372088688741828, 0.9371146391436176]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[413, 0.0315874366232787], {
             RGBColor[
             0.97383602535665, 0.9234049113139019, 0.35285832847295656`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[414, 0.0315874366232787], {
             RGBColor[
             0.2746579678933065, 0.4060133169497984, 0.9389527370002482]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[415, 0.0315874366232787], {
             RGBColor[
             0.2870126862041934, 0.4189989092289247, 0.9396563199308854]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[416, 0.0315874366232787], {
             RGBColor[
             0.26153368469451344`, 0.39221886318025073`, 0.938205328487714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[417, 0.0315874366232787], {
             RGBColor[
             0.7010326627105, 0.7663713112457954, 0.9708360423624304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[418, 0.0315874366232787], {
             RGBColor[
             0.978473490691829, 0.9834661451211657, 0.9213229446326382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[419, 0.0315874366232787], {
             RGBColor[
             0.5126905354832046, 0.6152642990075083, 0.9547800234820015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[420, 0.0315874366232787], {
             RGBColor[
             0.96864282965107, 0.9761344542131977, 0.9379636895276074]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[421, 0.0315874366232787], {
             RGBColor[
             0.17905660578117066`, 0.3055302238934915, 0.9335083808575031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[422, 0.0315874366232787], {
             RGBColor[
             0.23401200432651914`, 0.3632918321381684, 0.9366380095054342]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[423, 0.0315874366232787], {
             RGBColor[
             0.18782589147201245`, 0.31474729915939237`, 0.9340077787046009]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[424, 0.0315874366232787], {
             RGBColor[
             0.3205944320155112, 0.4521045162923272, 0.9416489716108714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[425, 0.0315874366232787], {
             RGBColor[
             0.37534284954540054`, 0.499524843821242, 0.9451374923637511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[426, 0.0315874366232787], {
             RGBColor[
             0.8701743928884773, 0.8993174569073501, 0.9874792044791957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[427, 0.0315874366232787], {
             RGBColor[
             0.2795001276110678, 0.4111027338238238, 0.9392284908328413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[428, 0.0315874366232787], {
             RGBColor[
             0.8303334960184631, 0.23416211938642656`, 0.1766806960850511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[429, 0.0315874366232787], {
             RGBColor[
             0.29359796730781346`, 0.4259204571997668, 0.9400313419476861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[430, 0.0315874366232787], {
             RGBColor[
             0.23973902577549727`, 0.36931129479517677`, 0.9369641549045845]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[431, 0.0315874366232787], {
             RGBColor[
             0.4485399301016759, 0.5629244760068475, 0.9498015456111601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[432, 0.0315874366232787], {
             RGBColor[
             0.898624468927386, 0.9220027752840345, 0.9901927981294695]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[433, 0.0315874366232787], {
             RGBColor[
             0.32550625142704326`, 0.4563588873913744, 0.9419619484004228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[434, 0.0315874366232787], {
             RGBColor[
             0.9912025783926344, 0.990630054329001, 0.7954595732387495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[435, 0.0315874366232787], {
             RGBColor[
             0.25811768357221787`, 0.3886284294137375, 0.93801079227732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[436, 0.0315874366232787], {
             RGBColor[
             0.472919813782261, 0.5829766354800872, 0.9516491265847494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[437, 0.0315874366232787], {
             RGBColor[
             0.2558304623203871, 0.3862244148598601, 0.9378805384106689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[438, 0.0315874366232787], {
             RGBColor[
             0.22146455698209894`, 0.3501036694250721, 0.9359234509414543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[439, 0.0315874366232787], {
             RGBColor[
             0.8609124841587944, 0.891932262294116, 0.986595795356355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[440, 0.0315874366232787], {
             RGBColor[
             0.28167383897512416`, 0.41338744228870766`, 0.9393522804793065]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[441, 0.0315874366232787], {
             RGBColor[
             0.4501324018566838, 0.5643037950010776, 0.9499030165032217]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[442, 0.0315874366232787], {
             RGBColor[
             0.28394532564135605`, 0.4157749187954902, 0.9394816382845851]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[443, 0.0315874366232787], {
             RGBColor[
             0.9345119801701037, 0.7780688545030732, 0.2661650059247154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[444, 0.0315874366232787], {
             RGBColor[
             0.27129304719779485`, 0.4024765719505212, 0.9387611097445928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[445, 0.0315874366232787], {
             RGBColor[
             0.22963931784821143`, 0.3586958614051314, 0.9363889914793045]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[446, 0.0315874366232787], {
             RGBColor[
             0.22815127331601265`, 0.3571318322543179, 0.9363042495445604]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[447, 0.0315874366232787], {
             RGBColor[
             0.2464999471451923, 0.3764174518218997, 0.9373491793747017]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[448, 0.0315874366232787], {
             RGBColor[
             0.5679393142918087, 0.6601177465734548, 0.9591294097327601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[449, 0.0315874366232787], {
             RGBColor[
             0.7283027762348872, 0.7876749311915857, 0.9735540724248413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[450, 0.0315874366232787], {
             RGBColor[
             0.8177084834502429, 0.13712074047130335`, 0.1645909697918113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[451, 0.0315874366232787], {
             RGBColor[
             0.21144581794704176`, 0.3395733394744833, 0.935352898574804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[452, 0.0315874366232787], {
             RGBColor[
             0.22395342458252596`, 0.35271962707644106`, 0.936065188269349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[453, 0.0315874366232787], {
             RGBColor[
             0.2843068325272902, 0.41615488545346746`, 0.9395022255669375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[454, 0.0315874366232787], {
             RGBColor[
             0.8998824261938122, 0.6382713050470934, 0.23817178112086787`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[455, 0.0315874366232787], {
             RGBColor[
             0.20394063923757638`, 0.33168492079502093`, 0.9349254897502168]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[456, 0.0315874366232787], {
             RGBColor[
             0.22365852866224617`, 0.35240967276674573`, 0.9360483943829485]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[457, 0.0315874366232787], {
             RGBColor[
             0.22158907133489145`, 0.35023454190452297`, 0.9359305418496434]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[458, 0.0315874366232787], {
             RGBColor[
             0.2304992557221517, 0.359599710633853, 0.9364379636690613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[459, 0.0315874366232787], {
             RGBColor[
             0.3905461178527888, 0.5126931506906183, 0.9461062311765757]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[460, 0.0315874366232787], {
             RGBColor[
             0.24834625332605567`, 0.3783580366805602, 0.9374543237803367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[461, 0.0315874366232787], {
             RGBColor[
             0.944455505750549, 0.9580955876512972, 0.9789065198267879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[462, 0.0315874366232787], {
             RGBColor[
             0.46387836533310084`, 0.575636380316448, 0.9509373506429145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[463, 0.0315874366232787], {
             RGBColor[
             0.2670973610782935, 0.3980666398170606, 0.9385221716270487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[464, 0.0315874366232787], {
             RGBColor[
             0.24386676324271586`, 0.3736498085868948, 0.9371992234469022]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[465, 0.0315874366232787], {
             RGBColor[
             0.28262558218412137`, 0.4143877847453685, 0.939406480847081]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[466, 0.0315874366232787], {
             RGBColor[
             0.503508173143364, 0.6078096435993164, 0.9540571542825077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[467, 0.0315874366232787], {
             RGBColor[
             0.7068391686146014, 0.7709073977891587, 0.9714147806060683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[468, 0.0315874366232787], {
             RGBColor[
             0.4783770236668791, 0.5874070443089239, 0.952078738137285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[469, 0.0315874366232787], {
             RGBColor[
             0.8604306779796645, 0.4591301305965446, 0.20525227536014304`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[470, 0.0315874366232787], {
             RGBColor[
             0.25548210733168075`, 0.3858582716797478, 0.937860700109407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[471, 0.0315874366232787], {
             RGBColor[
             0.8568125830318801, 0.4376919853814662, 0.20203709971295072`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[472, 0.0315874366232787], {
             RGBColor[
             0.32844671668737896`, 0.45890577060779597`, 0.9421493122466601]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[473, 0.0315874366232787], {
             RGBColor[
             0.32683125980079797`, 0.4575065430478635, 0.9420463767623395]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[474, 0.0315874366232787], {
             RGBColor[
             0.9930971542734537, 0.9914135101440991, 0.7640615478883636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[475, 0.0315874366232787], {
             RGBColor[
             0.839003391040872, 0.30080273170088523`, 0.1849829973497558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[476, 0.0315874366232787], {
             RGBColor[
             0.8484924274103163, 0.3737396233586853, 0.19406970929346942`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[477, 0.0315874366232787], {
             RGBColor[
             0.24467162743864543`, 0.3744957718881542, 0.9372450592721705]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[478, 0.0315874366232787], {
             RGBColor[
             0.2660419428822219, 0.39695732837561076`, 0.9384620671221336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[479, 0.0315874366232787], {
             RGBColor[
             0.41149067372934756`, 0.5308342722869064, 0.9474407997564864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[480, 0.0315874366232787], {
             RGBColor[
             0.35354723518652786`, 0.48064657814301665`, 0.9437486950899088]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[481, 0.0315874366232787], {
             RGBColor[
             0.318216697210702, 0.4500450419128276, 0.9414974644516573]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[482, 0.0315874366232787], {
             RGBColor[
             0.35848143845973107`, 0.48492033701799786`, 0.9440630981593326]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[483, 0.0315874366232787], {
             RGBColor[
             0.29664917161590876`, 0.42912746638510174`, 0.9402051035191799]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[484, 0.0315874366232787], {
             RGBColor[
             0.9928916986278599, 0.9872043870615327, 0.4676834468726777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[485, 0.0315874366232787], {
             RGBColor[
             0.24800119075484597`, 0.3779953540399882, 0.9374346729773807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[486, 0.0315874366232787], {
             RGBColor[
             0.9349275982881982, 0.9509499052141509, 0.9936554230160899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[487, 0.0315874366232787], {
             RGBColor[
             0.5794313774456323, 0.6694475211532741, 0.9600341070410434]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[488, 0.0315874366232787], {
             RGBColor[
             0.7693643004981994, 0.8197525060252281, 0.9776467014216474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[489, 0.0315874366232787], {
             RGBColor[
             0.9900975943251971, 0.9901731150203205, 0.8137720188432849]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[490, 0.0315874366232787], {
             RGBColor[
             0.9905535588776926, 0.9903616680805318, 0.806215506209998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[491, 0.0315874366232787], {
             RGBColor[
             0.9941614319695004, 0.9899202182895682, 0.6058860852243823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[492, 0.0315874366232787], {
             RGBColor[
             0.2766193131480329, 0.4080748151689876, 0.9390644327109545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[493, 0.0315874366232787], {
             RGBColor[
             0.9935772608954081, 0.9886707354308406, 0.5423026688954158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[494, 0.0315874366232787], {
             RGBColor[
             0.2585035332044634, 0.3890339818415072, 0.938032765843063]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[495, 0.0315874366232787], {
             RGBColor[
             0.8422024713778844, 0.3253922650171049, 0.18804644029332332`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[496, 0.0315874366232787], {
             RGBColor[
             0.27688954314442643`, 0.4083588440287685, 0.9390798219094797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[497, 0.0315874366232787], {
             RGBColor[
             0.23599364281048124`, 0.36537465982794926`, 0.9367508608855244]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[498, 0.0315874366232787], {
             RGBColor[
             0.46188951150763047`, 0.5740217391840874, 0.9507807807843619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[499, 0.0315874366232787], {
             RGBColor[
             0.2607186377132893, 0.3913621971260208, 0.9381589127678872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[500, 0.0315874366232787], {
             RGBColor[
             0.8194926622925333, 0.15083472088530037`, 0.16629950146613023`]},
             StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{3.8349502435193233`*^9, 3.834957407142641*^9, 
  3.835018921852682*^9, 3.8350190129675236`*^9, 3.8350205474078445`*^9, 
  3.8350446401426015`*^9, 3.835045030495333*^9, 3.8350457030519285`*^9, 
  3.835052519726322*^9},
 CellLabel->
  "Out[428]=",ExpressionUUID->"ccfb7151-9c38-4111-bdd3-92723bf60361"]
}, Open  ]],

Cell["Estimated with absolute Mean Deviation v Calculated: (r=6)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 
  3.8349503922098827`*^9}},ExpressionUUID->"9dd37b28-e330-4cc1-bd63-\
273634a91d6f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphinf5", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsif5", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}],
      "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"AMDi6f500", ",", "krif5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502409842243`*^9}, {3.8349504019691753`*^9, 3.834950402221115*^9}, {
   3.8349577477528667`*^9, 3.8349577551942053`*^9}, {3.835018833417392*^9, 
   3.8350188346728773`*^9}, {3.8350443403897114`*^9, 
   3.8350443452390656`*^9}, {3.8350449339623103`*^9, 3.835044937670579*^9}, {
   3.835045607563691*^9, 3.835045609169958*^9}, {3.8350524599194775`*^9, 
   3.835052461264903*^9}},
 CellLabel->
  "In[429]:=",ExpressionUUID->"310d12aa-a633-45db-82e7-8b6ad171dbd5"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1dOWGAgQBNBMbNu2bds2J+bEtm3btm3btu01sjdnH271F1R1ssCg6p0C
ggUL9l38vMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEIS
kZgkJCUZyUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpR
mCIUpRjFKUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGY
JjSlGYE0pwUtaUVr2tCWdrSnAx3pRBCd6UJXutGdHvSkF73pQ1/60Z8BDGQQ
gxnCUIYxnBGMZBSjGcNYxjGeCUxkEpOZwlSmMZ0ZzGQWs5nDXOYxnwUsZBGL
WcJSlrGcFaxkFatZw1rWsZ4NbGQTm9nCVraxnR3sZBe72cNe9rGfAxzkEIc5
wlGOcZwTnOQUpznDWc5xngtc5BKXucJVrnGdG9zkFre5w13ucZ8HPOQRj3nC
U57xnBe85BWvecNb3vGeD3zkE5/5wle+8Z1f+JXf+J0/+JO/+Jt/+Jcf/Cx/
AMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEISkZgkJCUZ
yUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpRmCIUpRjF
KUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGYJjSlGYE0
pwUtaUVr2tCWdrSnAx35Od5BdKYLXelGd3rQk170pg996Ud/BjCQQQxmCEMZ
xnBGMJJRjGYMYxnHeCYwkUlMZgpTmcZ0ZjCTWcxmDnOZx3wWsJBFLGYJS1nG
clawklWsZg1rWcd6NrCRTWxmC1vZxnZ2sJNd7GYPe9nHfg5wkEMc5ghHOcZx
TnCSU5zmDGc5x3kucJFLXOYKV7nGdW5wk1vc5g53ucd9HvCQRzzmCU95xnNe
8JJXvOYNb3nHez7wkU985gtf+Rbw/z//Dz189+A=
          "], {Null, CompressedData["
1:eJw13A2c1mO6wPH7tsdpl2O9LLLYQ3Ioas/uCqvVrqQihdKSUmmVzEwspdpK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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[196, 330] -> 
             RGBColor[
              0.94176503839232, 0.7920544287446396, 0.3353951923724421], 
             UndirectedEdge[136, 319] -> 
             RGBColor[
              0.8601059406821191, 0.8912891464188546, 0.9865188665195398], 
             UndirectedEdge[60, 188] -> 
             RGBColor[
              0.8248349490898088, 0.8633321680237502, 0.9831103306158158], 
             UndirectedEdge[145, 408] -> 
             RGBColor[
              0.7497673717508713, 0.8037373463327045, 0.9645120034228165], 
             UndirectedEdge[398, 460] -> 
             RGBColor[
              0.6183507809449341, 0.7010440462131545, 0.9630979850509811], 
             UndirectedEdge[413, 476] -> 
             RGBColor[
              0.903642048295439, 0.9260036568735563, 0.9906713793288403], 
             UndirectedEdge[244, 274] -> 
             RGBColor[
              0.9792967730812554, 0.9823167226374954, 0.8409595615595631], 
             UndirectedEdge[198, 223] -> 
             RGBColor[
              0.9874533494088276, 0.9686568029150344, 0.46379732966388687`], 
             UndirectedEdge[36, 310] -> 
             RGBColor[
              0.7666574010458361, 0.817637855599844, 0.9773769029816495], 
             UndirectedEdge[252, 432] -> 
             RGBColor[
              0.8461264059705493, 0.8778442470725187, 0.853071892677207], 
             UndirectedEdge[469, 475] -> 
             RGBColor[
              0.9945556333443583, 0.9915311575045171, 0.7046021427082596], 
             UndirectedEdge[113, 347] -> 
             RGBColor[
              0.926032880872556, 0.9409526976522442, 0.8776159496406408], 
             UndirectedEdge[35, 131] -> 
             RGBColor[
              0.9053538039949183, 0.5611971129707787, 0.34299348217736214`], 
             UndirectedEdge[156, 479] -> 
             RGBColor[
              0.9803555040025038, 0.9525636629148125, 0.5854187717889362], 
             UndirectedEdge[318, 354] -> 
             RGBColor[
              0.9866560635749474, 0.9704942025473864, 0.5869286890661098], 
             UndirectedEdge[6, 77] -> 
             RGBColor[
              0.9785893755396484, 0.9425207449916737, 0.5503198960573279], 
             UndirectedEdge[23, 202] -> 
             RGBColor[
              0.9637960683858092, 0.9725197475974094, 0.946167992111902], 
             UndirectedEdge[342, 395] -> 
             RGBColor[
              0.9465935164611103, 0.9596901125385626, 0.9752874253763079], 
             UndirectedEdge[53, 418] -> 
             RGBColor[
              0.9729977328530219, 0.9763614059559512, 0.7545761818273216], 
             UndirectedEdge[75, 149] -> 
             RGBColor[
              0.9940420603042217, 0.9898742998312493, 0.6081147827269844], 
             UndirectedEdge[293, 418] -> 
             RGBColor[
              0.8423329251413212, 0.873645563210588, 0.7567732343784594], 
             UndirectedEdge[282, 432] -> 
             RGBColor[
              0.9705969367960523, 0.9758276917344811, 0.8556544431805919], 
             UndirectedEdge[466, 468] -> 
             RGBColor[
              0.918971623376277, 0.9199084415843892, 0.6860120725643184], 
             UndirectedEdge[105, 190] -> 
             RGBColor[
              0.9329038589109746, 0.8031697901165251, 0.5883568689482371], 
             UndirectedEdge[64, 473] -> 
             RGBColor[
              0.8157457963040005, 0.8559787005713485, 0.9347476448240283], 
             UndirectedEdge[214, 273] -> 
             RGBColor[
              0.9785381900256471, 0.9465629810476419, 0.5792542596972097], 
             UndirectedEdge[30, 64] -> 
             RGBColor[
              0.7540119868661761, 0.8080921493531957, 0.9760281616517019], 
             UndirectedEdge[296, 395] -> 
             RGBColor[
              0.9744689554557879, 0.9774392071225604, 0.7505437617676292], 
             UndirectedEdge[114, 203] -> 
             RGBColor[
              0.9763318304862519, 0.9790733979537378, 0.7668191275369158], 
             UndirectedEdge[81, 237] -> 
             RGBColor[
              0.6505259616320263, 0.7261762270681371, 0.9663071727406956], 
             UndirectedEdge[382, 427] -> 
             RGBColor[
              0.8655791039452647, 0.8810111897418464, 0.6852954702705901], 
             UndirectedEdge[39, 450] -> 
             RGBColor[
              0.9724149927952243, 0.9755511437252096, 0.7257559396766307], 
             UndirectedEdge[50, 57] -> 
             RGBColor[
              0.7821787536740274, 0.8301574825273008, 0.9788193102902034], 
             UndirectedEdge[74, 153] -> 
             RGBColor[
              0.9219210979765058, 0.7016092353798542, 0.5051523671397842], 
             UndirectedEdge[239, 332] -> 
             RGBColor[
              0.9934358669201031, 0.9880808375822674, 0.5513572178349734], 
             UndirectedEdge[14, 72] -> 
             RGBColor[
              0.6246327081551771, 0.7017384377787463, 0.9661082553953674], 
             UndirectedEdge[331, 403] -> 
             RGBColor[
              0.9417652965080715, 0.9526238387042101, 0.8261572441732619], 
             UndirectedEdge[214, 302] -> 
             RGBColor[
              0.7919407318338222, 0.8358165895347633, 0.8950040676646331], 
             UndirectedEdge[128, 197] -> 
             RGBColor[
              0.7726598532993512, 0.8186018552064662, 0.8141946909760558], 
             UndirectedEdge[191, 212] -> 
             RGBColor[
              0.795616825168121, 0.83810261641951, 0.8660979672773335], 
             UndirectedEdge[404, 407] -> 
             RGBColor[
              0.7952419048259373, 0.5491278010290853, 0.5799062121005761], 
             UndirectedEdge[60, 116] -> 
             RGBColor[
              0.9219827220793828, 0.9361202062281729, 0.7651311139764612], 
             UndirectedEdge[272, 357] -> 
             RGBColor[
              0.9794730014135307, 0.9830548589947306, 0.8678307673113358], 
             UndirectedEdge[228, 490] -> 
             RGBColor[
              0.9697297713858456, 0.9518218527241399, 0.6547129020932732], 
             UndirectedEdge[111, 415] -> 
             RGBColor[
              0.8642219572727184, 0.8942293736331434, 0.9584079190826376], 
             UndirectedEdge[227, 428] -> 
             RGBColor[
              0.8759838952988839, 0.9036794608396979, 0.9728209621825405], 
             UndirectedEdge[367, 499] -> 
             RGBColor[
              0.8728311477663546, 0.8992679427335974, 0.8812056296831192], 
             UndirectedEdge[434, 495] -> 
             RGBColor[
              0.7247172678589079, 0.7592456552662812, 0.6597406612570045], 
             UndirectedEdge[226, 283] -> 
             RGBColor[
              0.9269985773767548, 0.9437086558837645, 0.961041579076473], 
             UndirectedEdge[9, 34] -> 
             RGBColor[
              0.843206710251854, 0.8763352982319752, 0.8877839058354519], 
             UndirectedEdge[127, 386] -> 
             RGBColor[
              0.9675349101209781, 0.9741093093371633, 0.8861516944477338], 
             UndirectedEdge[326, 469] -> 
             RGBColor[
              0.9241587273239374, 0.702049081402865, 0.43278042550134793`], 
             UndirectedEdge[192, 483] -> 
             RGBColor[
              0.9860936649537853, 0.9885173873289503, 0.8801274903646353], 
             UndirectedEdge[16, 39] -> 
             RGBColor[
              0.7431382569371097, 0.7982628064708613, 0.9615031014775431], 
             UndirectedEdge[209, 421] -> 
             RGBColor[
              0.891843627515077, 0.9135855838847592, 0.858839062522555], 
             UndirectedEdge[293, 317] -> 
             RGBColor[
              0.840216690130033, 0.8742300035789006, 0.8979391788077564], 
             UndirectedEdge[3, 381] -> 
             RGBColor[
              0.9640929770345422, 0.9717699776454176, 0.9021729066724584], 
             UndirectedEdge[211, 497] -> 
             RGBColor[
              0.6720170571898254, 0.7109124483745988, 0.6513878686294781], 
             UndirectedEdge[196, 479] -> 
             RGBColor[
              0.9400857906336029, 0.7936405570044918, 0.5289958832544748], 
             UndirectedEdge[221, 439] -> 
             RGBColor[
              0.9294726044794159, 0.7352522526947567, 0.36943718091978583`], 
             UndirectedEdge[379, 390] -> 
             RGBColor[
              0.9294387122161578, 0.9414721628757998, 0.7177517078886375], 
             UndirectedEdge[119, 320] -> 
             RGBColor[
              0.9372102792136772, 0.9497097064612845, 0.8719277491394292], 
             UndirectedEdge[179, 401] -> 
             RGBColor[
              0.9667022466669386, 0.9733367134505087, 0.8807723599879262], 
             UndirectedEdge[59, 342] -> 
             RGBColor[
              0.9618835396014833, 0.9708003666380955, 0.9362833646734252], 
             UndirectedEdge[86, 98] -> 
             RGBColor[
              0.9624540238889376, 0.8864501968941958, 0.5485910911949021], 
             UndirectedEdge[328, 431] -> 
             RGBColor[
              0.9716024212063443, 0.9745838116278207, 0.6984624102919355], 
             UndirectedEdge[270, 375] -> 
             RGBColor[
              0.9728881361048787, 0.9790754558929295, 0.920695222556609], 
             UndirectedEdge[39, 45] -> 
             RGBColor[
              0.9321840502915604, 0.9483476112206322, 0.979017104297004], 
             UndirectedEdge[59, 463] -> 
             RGBColor[
              0.9128866024629009, 0.6477602316855873, 0.5340879713634512], 
             UndirectedEdge[2, 55] -> 
             RGBColor[
              0.9108248790486315, 0.9272064048155559, 0.7627017435829457], 
             UndirectedEdge[193, 496] -> 
             RGBColor[
              0.8489153394849007, 0.8816657775117284, 0.9278411399713862], 
             UndirectedEdge[201, 246] -> 
             RGBColor[
              0.8775003226959586, 0.9016946237290737, 0.8064148421777795], 
             UndirectedEdge[69, 487] -> 
             RGBColor[
              0.977092321324492, 0.9819601988917093, 0.9023503668095888], 
             UndirectedEdge[15, 408] -> 
             RGBColor[
              0.7475346308284275, 0.8020721718085237, 0.9682914514124175], 
             UndirectedEdge[118, 310] -> 
             RGBColor[
              0.8657857621044763, 0.8953618165387366, 0.9540478211656179], 
             UndirectedEdge[289, 297] -> 
             RGBColor[
              0.889511045176112, 0.9127896251902385, 0.9051421186817227], 
             UndirectedEdge[397, 419] -> 
             RGBColor[
              0.8260757186498229, 0.8621481247679004, 0.8496054992365429], 
             UndirectedEdge[13, 380] -> 
             RGBColor[
              0.8439951941727863, 0.8563189161100542, 0.6717089204971787], 
             UndirectedEdge[155, 262] -> 
             RGBColor[
              0.966241155621216, 0.8911730154640121, 0.45957258948053087`], 
             UndirectedEdge[182, 324] -> 
             RGBColor[
              0.9872320384693549, 0.96924453318132, 0.5670993322130458], 
             UndirectedEdge[177, 245] -> 
             RGBColor[
              0.8615954689275169, 0.8926440087046097, 0.9866165818144399], 
             UndirectedEdge[113, 325] -> 
             RGBColor[
              0.9933799159562007, 0.9915304393665587, 0.7593754550414682], 
             UndirectedEdge[94, 368] -> 
             RGBColor[
              0.8956172386165143, 0.9154912066722644, 0.779667576049073], 
             UndirectedEdge[50, 140] -> 
             RGBColor[
              0.8454009334369627, 0.8771372940275804, 0.8447813002216609], 
             UndirectedEdge[389, 458] -> 
             RGBColor[
              0.9675895127034833, 0.9519671657051645, 0.6620327072583165], 
             UndirectedEdge[429, 499] -> 
             RGBColor[
              0.9895106588025038, 0.9899304020981319, 0.8234990593947535], 
             UndirectedEdge[97, 358] -> 
             RGBColor[
              0.9793549488683466, 0.9834597608725548, 0.8901056959363355], 
             UndirectedEdge[274, 363] -> 
             RGBColor[
              0.9755267885194614, 0.9807577371370095, 0.9034379621557864], 
             UndirectedEdge[255, 274] -> 
             RGBColor[
              0.9227856987915668, 0.9405439662734338, 0.9673847627233567], 
             UndirectedEdge[289, 381] -> 
             RGBColor[
              0.9895604017242822, 0.989950972074622, 0.8226746904503319], 
             UndirectedEdge[55, 230] -> 
             RGBColor[
              0.8964387060194833, 0.9159024138394191, 0.7612852203178737], 
             UndirectedEdge[289, 349] -> 
             RGBColor[
              0.9915065322489034, 0.9895894690903537, 0.7056461747085143], 
             UndirectedEdge[29, 318] -> 
             RGBColor[
              0.959188429040549, 0.9512272096342911, 0.6879832652235323], 
             UndirectedEdge[69, 402] -> 
             RGBColor[
              0.9554260755339594, 0.9662774206331053, 0.9603362067663253], 
             UndirectedEdge[6, 413] -> 
             RGBColor[
              0.9283942352760621, 0.9052533380373968, 0.6542981334626405], 
             UndirectedEdge[29, 482] -> 
             RGBColor[
              0.8698502005780919, 0.8991723611776516, 0.9866154751611063], 
             UndirectedEdge[212, 456] -> 
             RGBColor[
              0.9062231020369886, 0.9251804155745947, 0.8766631718572296], 
             UndirectedEdge[354, 482] -> 
             RGBColor[
              0.8973178351124902, 0.918439354090747, 0.8855608990036838], 
             UndirectedEdge[106, 247] -> 
             RGBColor[
              0.994903563667598, 0.9915075629507746, 0.6866625406563647], 
             UndirectedEdge[305, 382] -> 
             RGBColor[
              0.8105345575849638, 0.8523569039581851, 0.9816329064739467], 
             UndirectedEdge[279, 285] -> 
             RGBColor[
              0.9919699671517002, 0.9897401788754805, 0.694990501525461], 
             UndirectedEdge[27, 319] -> 
             RGBColor[
              0.7734000715784933, 0.8229316917648194, 0.9780419407791339], 
             UndirectedEdge[118, 483] -> 
             RGBColor[
              0.9792740682982568, 0.9837511054263739, 0.9059908895806631], 
             UndirectedEdge[342, 447] -> 
             RGBColor[
              0.9237372975588632, 0.8163461498078963, 0.6181622411167531], 
             UndirectedEdge[207, 458] -> 
             RGBColor[
              0.9756577063012266, 0.9784337175521997, 0.7570962523192695], 
             UndirectedEdge[462, 487] -> 
             RGBColor[
              0.9905012210242642, 0.9903400250331178, 0.8070828798873285], 
             UndirectedEdge[64, 384] -> 
             RGBColor[
              0.8177415538712652, 0.8568039976140425, 0.9016727770794292], 
             UndirectedEdge[203, 221] -> 
             RGBColor[
              0.929700109343822, 0.735738862595451, 0.3941996814131081], 
             UndirectedEdge[139, 370] -> 
             RGBColor[
              0.9745688898562002, 0.9805541002111509, 0.9279324153643607], 
             UndirectedEdge[46, 357] -> 
             RGBColor[
              0.9442992601978868, 0.8089046806960025, 0.5161969783727107], 
             UndirectedEdge[18, 326] -> 
             RGBColor[
              0.7912107843041557, 0.6005332187595857, 0.5862824807270863], 
             UndirectedEdge[73, 93] -> 
             RGBColor[
              0.8855603016014837, 0.9108732585815178, 0.9592291481874641], 
             UndirectedEdge[104, 112] -> 
             RGBColor[
              0.8013939515210213, 0.8443731445427269, 0.9326195459641533], 
             UndirectedEdge[40, 314] -> 
             RGBColor[
              0.9376876712034707, 0.9512744208717525, 0.9233890391786403], 
             UndirectedEdge[264, 398] -> 
             RGBColor[
              0.8128512768110655, 0.8506797323930686, 0.7721717108174448], 
             UndirectedEdge[345, 489] -> 
             RGBColor[
              0.8064385278281865, 0.8477011928926901, 0.9009377661063676], 
             UndirectedEdge[80, 417] -> 
             RGBColor[
              0.8543942754765883, 0.8867348196229861, 0.9859740827933725], 
             UndirectedEdge[271, 442] -> 
             RGBColor[
              0.9732697796969543, 0.9770237084748905, 0.7905679299783297], 
             UndirectedEdge[318, 482] -> 
             RGBColor[
              0.8924486204422797, 0.898170057627106, 0.6823779865078068], 
             UndirectedEdge[235, 260] -> 
             RGBColor[
              0.893574644016494, 0.9151218450864307, 0.8673539356910454], 
             UndirectedEdge[79, 278] -> 
             RGBColor[
              0.8256033891800211, 0.8626111854566814, 0.8872870137448173], 
             UndirectedEdge[137, 404] -> 
             RGBColor[
              0.8453658081288842, 0.5885513007059627, 0.5848314197587564], 
             UndirectedEdge[380, 478] -> 
             RGBColor[
              0.8459969016961092, 0.8797215401014771, 0.9429098055332907], 
             UndirectedEdge[247, 370] -> 
             RGBColor[
              0.981838502559945, 0.9838487016496351, 0.8105353595987266], 
             UndirectedEdge[251, 429] -> 
             RGBColor[
              0.9776066278409322, 0.9823088778975382, 0.8999173366935083], 
             UndirectedEdge[286, 407] -> 
             RGBColor[
              0.7520501676568163, 0.8062265738572563, 0.975920990469789], 
             UndirectedEdge[206, 410] -> 
             RGBColor[
              0.9555220732119901, 0.9663490155441989, 0.9601737077376233], 
             UndirectedEdge[86, 500] -> 
             RGBColor[
              0.9700472608826539, 0.976363320710519, 0.8989297429981444], 
             UndirectedEdge[78, 407] -> 
             RGBColor[
              0.7306658064463839, 0.7895209483525018, 0.9737895971925505], 
             UndirectedEdge[363, 370] -> 
             RGBColor[
              0.97803498190561, 0.9826283436576094, 0.8991922449946415], 
             UndirectedEdge[447, 453] -> 
             RGBColor[
              0.9515178684099788, 0.8338923310254556, 0.3830927655396655], 
             UndirectedEdge[256, 492] -> 
             RGBColor[
              0.9643601560107713, 0.9594044882420079, 0.6883998752563423], 
             UndirectedEdge[114, 349] -> 
             RGBColor[
              0.9763399940131969, 0.979090858912414, 0.7677076770654274], 
             UndirectedEdge[22, 160] -> 
             RGBColor[
              0.8531622868198208, 0.8838825957253147, 0.8783436260191967], 
             UndirectedEdge[149, 324] -> 
             RGBColor[
              0.9933637438928891, 0.9895937985632266, 0.6193562410893694], 
             UndirectedEdge[94, 315] -> 
             RGBColor[
              0.9794514798258518, 0.9813998582006515, 0.7615249557846464], 
             UndirectedEdge[246, 492] -> 
             RGBColor[
              0.9690417907365672, 0.9740021160054801, 0.8081694687877286], 
             UndirectedEdge[193, 202] -> 
             RGBColor[
              0.9769017438787397, 0.9820143932455367, 0.9114648754967126], 
             UndirectedEdge[321, 335] -> 
             RGBColor[
              0.6148643060440722, 0.6789196939373553, 0.8553912022150678], 
             UndirectedEdge[321, 496] -> 
             RGBColor[
              0.852227926940585, 0.8830356175542684, 0.8729429931291642], 
             UndirectedEdge[18, 474] -> 
             RGBColor[
              0.6119989305866624, 0.694562804064699, 0.9635035283338358], 
             UndirectedEdge[184, 192] -> 
             RGBColor[
              0.9730817431450001, 0.9791252265118651, 0.9161301659225536], 
             UndirectedEdge[170, 171] -> 
             RGBColor[
              0.818704149825092, 0.8590441892030756, 0.9727863801372808], 
             UndirectedEdge[80, 156] -> 
             RGBColor[
              0.899824588029484, 0.8905774991370397, 0.6634963900374566], 
             UndirectedEdge[353, 418] -> 
             RGBColor[
              0.9218484687265383, 0.9360071816793136, 0.7646339908034498], 
             UndirectedEdge[201, 312] -> 
             RGBColor[
              0.8611967985786386, 0.8919653648689898, 0.9631313395561464], 
             UndirectedEdge[152, 212] -> 
             RGBColor[
              0.9939402173576009, 0.9916752760351213, 0.7437758342000008], 
             UndirectedEdge[192, 260] -> 
             RGBColor[
              0.9898906614045956, 0.9900875429397182, 0.8172014328628836], 
             UndirectedEdge[90, 357] -> 
             RGBColor[
              0.7054138814064974, 0.7642659024801162, 0.8721095034180648], 
             UndirectedEdge[57, 369] -> 
             RGBColor[
              0.9314250600020724, 0.9439795005411762, 0.7928012757757084], 
             UndirectedEdge[83, 448] -> 
             RGBColor[
              0.991427163795464, 0.9888621091844346, 0.656475861226299], 
             UndirectedEdge[67, 180] -> 
             RGBColor[
              0.979454736004125, 0.9410830953180425, 0.48310669607000034`], 
             UndirectedEdge[373, 472] -> 
             RGBColor[
              0.7105108133613822, 0.7733309618202397, 0.9720848157255848], 
             UndirectedEdge[353, 432] -> 
             RGBColor[
              0.9224586976302096, 0.9377190849433885, 0.8606153722994385], 
             UndirectedEdge[1, 433] -> 
             RGBColor[
              0.9815837933570031, 0.9481460028137751, 0.501488324667385], 
             UndirectedEdge[300, 301] -> 
             RGBColor[
              0.8740699689489542, 0.9024236835153792, 0.9878507680014657], 
             UndirectedEdge[212, 389] -> 
             RGBColor[
              0.9851399632572833, 0.9636429207957502, 0.5690320211875637], 
             UndirectedEdge[97, 174] -> 
             RGBColor[
              0.9826046022899099, 0.9842899894063493, 0.798918199818242], 
             UndirectedEdge[200, 471] -> 
             RGBColor[
              0.9842099008526831, 0.9874391786898353, 0.8979464846500218], 
             UndirectedEdge[155, 387] -> 
             RGBColor[
              0.9514846701485009, 0.9602948527904548, 0.8206842928178628], 
             UndirectedEdge[156, 354] -> 
             RGBColor[
              0.9814781573177116, 0.9530279089115251, 0.566813501022298], 
             UndirectedEdge[314, 472] -> 
             RGBColor[
              0.8478093102998613, 0.8815834672554701, 0.9853196464302378], 
             UndirectedEdge[117, 269] -> 
             RGBColor[
              0.850890454188771, 0.8805371940826909, 0.7741596913830988], 
             UndirectedEdge[336, 409] -> 
             RGBColor[
              0.8714402709141807, 0.8981440972641772, 0.879376480368237], 
             UndirectedEdge[63, 252] -> 
             RGBColor[
              0.7385856641361137, 0.7957080013728665, 0.9745789745917848], 
             UndirectedEdge[201, 444] -> 
             RGBColor[
              0.8531976809761114, 0.885999636058378, 0.9766717591532232], 
             UndirectedEdge[201, 442] -> 
             RGBColor[
              0.8774058321890023, 0.9014925180891499, 0.7961301336233937], 
             UndirectedEdge[25, 333] -> 
             RGBColor[
              0.867456670486702, 0.8593908967223269, 0.6517685432387383], 
             UndirectedEdge[203, 397] -> 
             RGBColor[
              0.9944502170706857, 0.9907926732829186, 0.6558378589029429], 
             UndirectedEdge[7, 436] -> 
             RGBColor[
              0.8762594233164124, 0.9041694949968347, 0.9880596001135828], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.7812649526793958, 0.8294559666208227, 0.9709468259067658], 
             UndirectedEdge[274, 369] -> 
             RGBColor[
              0.978939286483509, 0.9811417371329691, 0.7722206700344156], 
             UndirectedEdge[38, 364] -> 
             RGBColor[
              0.9646403347315368, 0.885402318170742, 0.42419849800435283`], 
             UndirectedEdge[215, 356] -> 
             RGBColor[
              0.9918093065099896, 0.9894242133488445, 0.6795149965131975], 
             UndirectedEdge[16, 283] -> 
             RGBColor[
              0.7529144071321735, 0.8055538432793632, 0.9449546292256302], 
             UndirectedEdge[236, 276] -> 
             RGBColor[
              0.9916163115107062, 0.9894194478138612, 0.6881682466151131], 
             UndirectedEdge[39, 454] -> 
             RGBColor[
              0.9503822346885638, 0.9625157323891407, 0.9688741136732013], 
             UndirectedEdge[179, 315] -> 
             RGBColor[
              0.9530366642524506, 0.964495401611658, 0.9643808568076493], 
             UndirectedEdge[149, 182] -> 
             RGBColor[
              0.9869131516144833, 0.9671827120322626, 0.4320968857578622], 
             UndirectedEdge[97, 407] -> 
             RGBColor[
              0.861604543993265, 0.8921300290855669, 0.9553831258279971], 
             UndirectedEdge[274, 379] -> 
             RGBColor[
              0.9149750248066755, 0.9343159468529789, 0.9666397736660068], 
             UndirectedEdge[39, 325] -> 
             RGBColor[
              0.9728637113048202, 0.9776615127178073, 0.8582330517527521], 
             UndirectedEdge[127, 347] -> 
             RGBColor[
              0.9253311533189852, 0.9406625152752672, 0.8892453912160033], 
             UndirectedEdge[327, 483] -> 
             RGBColor[
              0.9890216556514562, 0.9897281867283658, 0.8316031071072028], 
             UndirectedEdge[269, 360] -> 
             RGBColor[
              0.8203562665971511, 0.8566836546676968, 0.7711163289221725], 
             UndirectedEdge[54, 147] -> 
             RGBColor[
              0.5113250532145455, 0.6132416267730181, 0.9549250996443566], 
             UndirectedEdge[276, 422] -> 
             RGBColor[
              0.9911448276080889, 0.990606172895464, 0.7964166531929071], 
             UndirectedEdge[181, 424] -> 
             RGBColor[
              0.8196369288838632, 0.8598508213343832, 0.9768245617248947], 
             UndirectedEdge[336, 456] -> 
             RGBColor[
              0.9058524182435013, 0.9250271282998487, 0.8828063616142232], 
             UndirectedEdge[46, 298] -> 
             RGBColor[
              0.7773168338425569, 0.6796599964290713, 0.6013016581636674], 
             UndirectedEdge[107, 132] -> 
             RGBColor[
              0.9402115693166695, 0.9529648456776074, 0.9096446816837538], 
             UndirectedEdge[78, 95] -> 
             RGBColor[
              0.8497674585079017, 0.8814094555765497, 0.8861185045060183], 
             UndirectedEdge[296, 332] -> 
             RGBColor[
              0.9927997173080456, 0.9867201778866685, 0.48211625842284445`], 
             UndirectedEdge[397, 472] -> 
             RGBColor[
              0.9013412886090231, 0.9209461600595458, 0.8571072678533349], 
             UndirectedEdge[19, 269] -> 
             RGBColor[
              0.985411895619122, 0.9858316760014403, 0.7503682838686626], 
             UndirectedEdge[185, 335] -> 
             RGBColor[
              0.50177522669656, 0.5920242288768799, 0.9570823198348848], 
             UndirectedEdge[112, 351] -> 
             RGBColor[
              0.8043190795681925, 0.8455827601625941, 0.8841426042338036], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.7479289305396528, 0.7994628201119183, 0.8654951847217485], 
             UndirectedEdge[251, 305] -> 
             RGBColor[
              0.9213006310242065, 0.9392525468881536, 0.9635241132405157], 
             UndirectedEdge[131, 170] -> 
             RGBColor[
              0.8422321666657939, 0.8734300510196797, 0.7458062961265539], 
             UndirectedEdge[76, 333] -> 
             RGBColor[
              0.9399858938365637, 0.9168034323255756, 0.658797979566589], 
             UndirectedEdge[114, 115] -> 
             RGBColor[
              0.96122986511456, 0.970605877399484, 0.9505119048771209], 
             UndirectedEdge[87, 421] -> 
             RGBColor[
              0.8915259268628075, 0.9123740966864179, 0.7855916032478507], 
             UndirectedEdge[60, 192] -> 
             RGBColor[
              0.9182415545992737, 0.9360250112050974, 0.9326678448015915], 
             UndirectedEdge[84, 147] -> 
             RGBColor[
              0.5399060010700352, 0.6373590400136502, 0.956922524626532], 
             UndirectedEdge[431, 433] -> 
             RGBColor[
              0.9804690282385594, 0.9457616329454668, 0.38015302105764376`], 
             UndirectedEdge[201, 492] -> 
             RGBColor[
              0.8521034564676294, 0.8851835652115803, 0.9785239958266245], 
             UndirectedEdge[86, 124] -> 
             RGBColor[
              0.990709379748383, 0.9904261040149761, 0.8036331511311702], 
             UndirectedEdge[234, 239] -> 
             RGBColor[
              0.9329640071968655, 0.945705106835731, 0.833357404633238], 
             UndirectedEdge[100, 450] -> 
             RGBColor[
              0.9800225661216055, 0.9812248594557667, 0.7128783024079666], 
             UndirectedEdge[22, 275] -> 
             RGBColor[
              0.7045450553813565, 0.763352994389788, 0.8661595329814645], 
             UndirectedEdge[160, 324] -> 
             RGBColor[
              0.8540720441105834, 0.884258803744741, 0.8632665933348639], 
             UndirectedEdge[191, 218] -> 
             RGBColor[
              0.7795131299215096, 0.8275058490681813, 0.9566496739872327], 
             UndirectedEdge[349, 397] -> 
             RGBColor[
              0.9944583805976307, 0.9908101342415948, 0.6567264084314546], 
             UndirectedEdge[401, 454] -> 
             RGBColor[
              0.9706529540912603, 0.9762831445788781, 0.8740848428280708], 
             UndirectedEdge[311, 349] -> 
             RGBColor[
              0.9935027970049026, 0.9885114646985034, 0.5341977339517501], 
             UndirectedEdge[63, 324] -> 
             RGBColor[
              0.8867058649135613, 0.9097525925822516, 0.8665192276121105], 
             UndirectedEdge[22, 353] -> 
             RGBColor[
              0.9209849643392105, 0.9371096583543425, 0.8850389468307915], 
             UndirectedEdge[93, 437] -> 
             RGBColor[
              0.9461311875156571, 0.9590273018955248, 0.9650445436543333], 
             UndirectedEdge[417, 461] -> 
             RGBColor[
              0.8972228623185659, 0.9208851722197591, 0.9900591116398911], 
             UndirectedEdge[151, 249] -> 
             RGBColor[
              0.8240721672408038, 0.8617720689899825, 0.9033261799229272], 
             UndirectedEdge[148, 452] -> 
             RGBColor[
              0.5038517037120269, 0.5858509135081994, 0.9585158138345905], 
             UndirectedEdge[262, 424] -> 
             RGBColor[
              0.817628380928368, 0.7775216932066061, 0.6196850794069216], 
             UndirectedEdge[50, 139] -> 
             RGBColor[
              0.8379664561882496, 0.8734900639977716, 0.9442338676935452], 
             UndirectedEdge[237, 267] -> 
             RGBColor[
              0.5805359866390262, 0.6693552123563778, 0.9607973055275205], 
             UndirectedEdge[256, 442] -> 
             RGBColor[
              0.9896625317321441, 0.9757134411195774, 0.5060060130531114], 
             UndirectedEdge[60, 133] -> 
             RGBColor[
              0.8635445449311365, 0.8940309961085953, 0.9868468436624893], 
             UndirectedEdge[77, 156] -> 
             RGBColor[
              0.9817358261072043, 0.9531344615777662, 0.5625432623549509], 
             UndirectedEdge[219, 498] -> 
             RGBColor[
              0.9226530418506529, 0.8590999183517506, 0.6297025104910154], 
             UndirectedEdge[102, 185] -> 
             RGBColor[
              0.8114246822108717, 0.8529057651743035, 0.981760505267847], 
             UndirectedEdge[92, 169] -> 
             RGBColor[
              0.9786440304083608, 0.9429642177172233, 0.5523231717900878], 
             UndirectedEdge[53, 357] -> 
             RGBColor[
              0.9717799064638858, 0.9773173613775723, 0.8808531703805735], 
             UndirectedEdge[162, 289] -> 
             RGBColor[
              0.992019362923221, 0.9906863620475844, 0.7614646287839296], 
             UndirectedEdge[169, 204] -> 
             RGBColor[
              0.8991280603826419, 0.9197909645513129, 0.8829049847752122], 
             UndirectedEdge[176, 448] -> 
             RGBColor[
              0.9682320934393056, 0.9003845934739234, 0.3831720973490357], 
             UndirectedEdge[377, 403] -> 
             RGBColor[
              0.9863318316873594, 0.9642085115303087, 0.5159998949390896], 
             UndirectedEdge[86, 357] -> 
             RGBColor[
              0.9901367430283816, 0.990189304015163, 0.8131232235179202], 
             UndirectedEdge[12, 373] -> 
             RGBColor[
              0.7816601538337142, 0.8295955507694504, 0.9661163504526318], 
             UndirectedEdge[200, 469] -> 
             RGBColor[
              0.9903740659693996, 0.989801971933592, 0.7739015356607983], 
             UndirectedEdge[112, 153] -> 
             RGBColor[
              0.8041340513547872, 0.845506246241343, 0.8872090005675952], 
             UndirectedEdge[166, 243] -> 
             RGBColor[
              0.8697607814373837, 0.8967653601026352, 0.8761842960678909], 
             UndirectedEdge[394, 460] -> 
             RGBColor[
              0.7750504911154783, 0.8243886334582116, 0.9698634186259836], 
             UndirectedEdge[18, 348] -> 
             RGBColor[
              0.861739586785482, 0.8895296257203364, 0.8166506431734846], 
             UndirectedEdge[315, 325] -> 
             RGBColor[
              0.9794688482930286, 0.982587613068694, 0.8470522777273448], 
             UndirectedEdge[195, 447] -> 
             RGBColor[
              0.9088908852351498, 0.6764897508097452, 0.2455496715356582], 
             UndirectedEdge[128, 204] -> 
             RGBColor[
              0.9005734206355129, 0.9199350967681723, 0.8259824997687073], 
             UndirectedEdge[91, 435] -> 
             RGBColor[
              0.8849896476412831, 0.8900793489931171, 0.6783288584315628], 
             UndirectedEdge[158, 206] -> 
             RGBColor[
              0.968805355627258, 0.9757794697084636, 0.916363540637521], 
             UndirectedEdge[30, 290] -> 
             RGBColor[
              0.884658093702348, 0.9108663667867454, 0.988860672792575], 
             UndirectedEdge[2, 250] -> 
             RGBColor[
              0.6729552201206672, 0.7425948480990892, 0.9693243949475541], 
             UndirectedEdge[148, 195] -> 
             RGBColor[
              0.8684474645128157, 0.7698677066969773, 0.6142294186477812], 
             UndirectedEdge[5, 202] -> 
             RGBColor[
              0.9042158250373055, 0.925630051538338, 0.9619106776034323], 
             UndirectedEdge[220, 359] -> 
             RGBColor[
              0.6345418940583232, 0.6999766769899922, 0.8662826299489808], 
             UndirectedEdge[175, 337] -> 
             RGBColor[
              0.8855497051485939, 0.9115773135518339, 0.9889457154882688], 
             UndirectedEdge[263, 447] -> 
             RGBColor[
              0.9351422707336213, 0.8248519601277013, 0.5988565964252884], 
             UndirectedEdge[344, 387] -> 
             RGBColor[
              0.9105937618770165, 0.9315467645842679, 0.9913344399761193], 
             UndirectedEdge[82, 470] -> 
             RGBColor[
              0.9354568237656908, 0.8534214055378617, 0.620307766819874], 
             UndirectedEdge[273, 446] -> 
             RGBColor[
              0.9812761335236301, 0.9471657772517783, 0.4953966563014838], 
             UndirectedEdge[68, 306] -> 
             RGBColor[
              0.5979504600082929, 0.6140691116043124, 0.6096232258499279], 
             UndirectedEdge[21, 33] -> 
             RGBColor[
              0.8013230548911664, 0.8448324344570339, 0.9808019302251749], 
             UndirectedEdge[77, 479] -> 
             RGBColor[
              0.990660293719443, 0.990405805680556, 0.8044466336612779], 
             UndirectedEdge[253, 311] -> 
             RGBColor[
              0.8955537108621965, 0.9148726999587569, 0.7340969853539026], 
             UndirectedEdge[308, 386] -> 
             RGBColor[
              0.9664668164038428, 0.9736676251363714, 0.9038527714785991], 
             UndirectedEdge[151, 280] -> 
             RGBColor[
              0.9874809880653475, 0.989091081088159, 0.8571359561289256], 
             UndirectedEdge[305, 416] -> 
             RGBColor[
              0.639546225310168, 0.7138076700717406, 0.9674489616163598], 
             UndirectedEdge[38, 189] -> 
             RGBColor[
              0.9638316540882483, 0.8862273850435345, 0.5218821742376369], 
             UndirectedEdge[277, 291] -> 
             RGBColor[
              0.9904654911529627, 0.9903252498131188, 0.8076750163207376], 
             UndirectedEdge[27, 40] -> 
             RGBColor[
              0.8555005894772987, 0.886520124613283, 0.9153431194122651], 
             UndirectedEdge[88, 167] -> 
             RGBColor[
              0.9938107667452614, 0.9891701808326139, 0.567718339620881], 
             UndirectedEdge[89, 296] -> 
             RGBColor[
              0.9938134269180907, 0.9891758706733109, 0.5680078830166615], 
             UndirectedEdge[169, 340] -> 
             RGBColor[
              0.9687466787461824, 0.9749370534093706, 0.880697454705873], 
             UndirectedEdge[169, 363] -> 
             RGBColor[
              0.9895659407785435, 0.9899532626159063, 0.8225828939866076], 
             UndirectedEdge[43, 378] -> 
             RGBColor[
              0.9098081182600719, 0.9297074840121959, 0.9492099383035968], 
             UndirectedEdge[350, 482] -> 
             RGBColor[
              0.8788234044314697, 0.9058645619192278, 0.9714261816237223], 
             UndirectedEdge[199, 429] -> 
             RGBColor[
              0.9035067188803267, 0.9240571213314521, 0.9216806705373815], 
             UndirectedEdge[135, 216] -> 
             RGBColor[
              0.9902666517161951, 0.9896732628105536, 0.769554633271714], 
             UndirectedEdge[153, 351] -> 
             RGBColor[
              0.9904290260835129, 0.9903101705697919, 0.8082793368900943], 
             UndirectedEdge[207, 218] -> 
             RGBColor[
              0.977104461608415, 0.9795127052914565, 0.7546472729584157], 
             UndirectedEdge[218, 389] -> 
             RGBColor[
              0.9690362680106718, 0.9530461534444213, 0.6595837278974628], 
             UndirectedEdge[421, 477] -> 
             RGBColor[
              0.8777844788194602, 0.9048403012371069, 0.960558621800776], 
             UndirectedEdge[171, 391] -> 
             RGBColor[
              0.7994321510051646, 0.8439887572523325, 0.970865527401979], 
             UndirectedEdge[25, 246] -> 
             RGBColor[
              0.8812112232488518, 0.9045936074448828, 0.8067847100645544], 
             UndirectedEdge[130, 254] -> 
             RGBColor[
              0.9945744415184337, 0.9919300270806324, 0.7327186960733401], 
             UndirectedEdge[65, 434] -> 
             RGBColor[
              0.9609017067379793, 0.947155456544136, 0.6737271297428138], 
             UndirectedEdge[174, 430] -> 
             RGBColor[
              0.9944812200348365, 0.990604212625789, 0.6406930426330426], 
             UndirectedEdge[213, 454] -> 
             RGBColor[
              0.8220811153541501, 0.861635334843451, 0.9707455787408448], 
             UndirectedEdge[52, 495] -> 
             RGBColor[
              0.7290648771072037, 0.785325281017656, 0.9132195962947183], 
             UndirectedEdge[26, 224] -> 
             RGBColor[
              0.9724520358418978, 0.9170207544290596, 0.392159831862526], 
             UndirectedEdge[8, 31] -> 
             RGBColor[
              0.6993239533986464, 0.7563747266666008, 0.6936061508499882], 
             UndirectedEdge[29, 321] -> 
             RGBColor[
              0.9645449061402767, 0.9716980016346106, 0.8830909782675642], 
             UndirectedEdge[319, 377] -> 
             RGBColor[
              0.9006142927738233, 0.8996379342073595, 0.6759744441596909], 
             UndirectedEdge[323, 447] -> 
             RGBColor[
              0.9511155273864353, 0.8330317642590135, 0.3393004280879302], 
             UndirectedEdge[13, 340] -> 
             RGBColor[
              0.9621645495653831, 0.9493932097344786, 0.6743404741624626], 
             UndirectedEdge[176, 237] -> 
             RGBColor[
              0.8251324709180571, 0.7920204173433891, 0.6223454980004905], 
             UndirectedEdge[22, 268] -> 
             RGBColor[
              0.9677540203372367, 0.9741971305807091, 0.8823956876748961], 
             UndirectedEdge[461, 493] -> 
             RGBColor[
              0.9499162041773346, 0.9492277550229014, 0.6957969162292952], 
             UndirectedEdge[401, 450] -> 
             RGBColor[
              0.9926857121979207, 0.9893185559149471, 0.6309666688315002], 
             UndirectedEdge[100, 200] -> 
             RGBColor[
              0.9765115957125403, 0.9816977953211345, 0.9109777072127374], 
             UndirectedEdge[197, 375] -> 
             RGBColor[
              0.7553962878446263, 0.8079353827389228, 0.9549837167325317], 
             UndirectedEdge[94, 401] -> 
             RGBColor[
              0.9931170622403398, 0.9902411700395022, 0.6779164589649233], 
             UndirectedEdge[118, 327] -> 
             RGBColor[
              0.9822250911470649, 0.9849714292121841, 0.8570848039735885], 
             UndirectedEdge[44, 255] -> 
             RGBColor[
              0.9231975013276568, 0.9408510879305851, 0.966687688445059], 
             UndirectedEdge[148, 356] -> 
             RGBColor[
              0.9094008137390697, 0.9282255067078404, 0.8992510377416978], 
             UndirectedEdge[26, 34] -> 
             RGBColor[
              0.9711435900249652, 0.9182511875585859, 0.5426141757931165], 
             UndirectedEdge[244, 313] -> 
             RGBColor[
              0.9939181903008997, 0.9917530296411114, 0.7504548561404552], 
             UndirectedEdge[331, 488] -> 
             RGBColor[
              0.9407406519011494, 0.9527137084953881, 0.88047058609452], 
             UndirectedEdge[382, 429] -> 
             RGBColor[
              0.8668405544016897, 0.8954132349675695, 0.9180261299269392], 
             UndirectedEdge[409, 496] -> 
             RGBColor[
              0.7314394186386669, 0.7901253000767836, 0.9738667036260603], 
             UndirectedEdge[14, 324] -> 
             RGBColor[
              0.9218372213367092, 0.9374400172007239, 0.869956429717156], 
             UndirectedEdge[259, 471] -> 
             RGBColor[
              0.9640093794342364, 0.9726788346280617, 0.9458069121473465], 
             UndirectedEdge[178, 439] -> 
             RGBColor[
              0.9831792058575495, 0.9838632221487782, 0.7300807002288374], 
             UndirectedEdge[127, 454] -> 
             RGBColor[
              0.9701967117863735, 0.976094476660915, 0.8816459585372798], 
             UndirectedEdge[190, 452] -> 
             RGBColor[
              0.5386089957825928, 0.4682194860437505, 0.5851724245285548], 
             UndirectedEdge[218, 295] -> 
             RGBColor[
              0.9156320248629278, 0.9349248024259569, 0.9696488030169637], 
             UndirectedEdge[35, 67] -> 
             RGBColor[
              0.8908297543674122, 0.5127506520475777, 0.2400940197375076], 
             UndirectedEdge[192, 249] -> 
             RGBColor[
              0.8228713157197806, 0.8612754860255629, 0.9232273973303973], 
             UndirectedEdge[186, 202] -> 
             RGBColor[
              0.9802336590311509, 0.9810254093164148, 0.6842038466474791], 
             UndirectedEdge[243, 469] -> 
             RGBColor[
              0.8709601056179277, 0.8967758402559123, 0.8210197580924183], 
             UndirectedEdge[48, 183] -> 
             RGBColor[
              0.9685621499016577, 0.9735893954453083, 0.8046169473979118], 
             UndirectedEdge[255, 390] -> 
             RGBColor[
              0.937249386201049, 0.9477001822962547, 0.7184966969459874], 
             UndirectedEdge[202, 497] -> 
             RGBColor[
              0.6683951135285787, 0.734756443163775, 0.9419483763546872], 
             UndirectedEdge[84, 365] -> 
             RGBColor[
              0.4859941676990367, 0.5935909849826575, 0.9526783876180145], 
             UndirectedEdge[239, 262] -> 
             RGBColor[
              0.9663739357157407, 0.8914570186600732, 0.474024883345774], 
             UndirectedEdge[299, 456] -> 
             RGBColor[
              0.8943468136517155, 0.9177364413387086, 0.9600589814351754], 
             UndirectedEdge[136, 253] -> 
             RGBColor[
              0.8474961035232165, 0.8814118350933384, 0.9852690443845407], 
             UndirectedEdge[338, 478] -> 
             RGBColor[
              0.9884737404170338, 0.9883580074785683, 0.764451523727088], 
             UndirectedEdge[284, 444] -> 
             RGBColor[
              0.8833681800787101, 0.9095764870884425, 0.9796769014275706], 
             UndirectedEdge[135, 147] -> 
             RGBColor[
              0.7944549556576415, 0.8385111286135899, 0.9225157985811829], 
             UndirectedEdge[72, 73] -> 
             RGBColor[
              0.6007494521830166, 0.6828381147213151, 0.9637921588238012], 
             UndirectedEdge[8, 291] -> 
             RGBColor[
              0.6966378981333865, 0.7575445141487247, 0.90389224764974], 
             UndirectedEdge[141, 240] -> 
             RGBColor[
              0.8846440233769789, 0.5660166416270225, 0.5717341600429362], 
             UndirectedEdge[9, 466] -> 
             RGBColor[
              0.8390761848553031, 0.857205706172657, 0.6781252182701198], 
             UndirectedEdge[78, 346] -> 
             RGBColor[
              0.8505755888347015, 0.8793489187491759, 0.6986548669643435], 
             UndirectedEdge[255, 425] -> 
             RGBColor[
              0.8764388340385617, 0.9043125522367024, 0.9880767124684233], 
             UndirectedEdge[297, 349] -> 
             RGBColor[
              0.891934599058182, 0.9126255490334959, 0.7802014623749371], 
             UndirectedEdge[248, 478] -> 
             RGBColor[
              0.9094157037629758, 0.9293952659205922, 0.9491961748168274], 
             UndirectedEdge[113, 130] -> 
             RGBColor[
              0.9933939316750069, 0.9915362352264726, 0.7591431783093314], 
             UndirectedEdge[51, 179] -> 
             RGBColor[
              0.9401084068860058, 0.954853528435842, 0.9862650242994931], 
             UndirectedEdge[440, 470] -> 
             RGBColor[
              0.8841222035945673, 0.8126934763688053, 0.6225155583892121], 
             UndirectedEdge[5, 414] -> 
             RGBColor[
              0.916527624649171, 0.9310684569661083, 0.7077041922239281], 
             UndirectedEdge[148, 463] -> 
             RGBColor[
              0.8342969396979467, 0.5866839707426204, 0.5846465949189021], 
             UndirectedEdge[63, 441] -> 
             RGBColor[
              0.8229461807785385, 0.6565050116876426, 0.5943577260317444], 
             UndirectedEdge[163, 187] -> 
             RGBColor[
              0.6942376479707324, 0.7594614213230804, 0.9714734090791679], 
             UndirectedEdge[120, 177] -> 
             RGBColor[
              0.8956532843450493, 0.9170511543725574, 0.8814119532298104], 
             UndirectedEdge[450, 454] -> 
             RGBColor[
              0.9710180580852981, 0.9745093121058173, 0.7281205857616121], 
             UndirectedEdge[15, 190] -> 
             RGBColor[
              0.9213983960422553, 0.7945890347475006, 0.6078326164796684], 
             UndirectedEdge[191, 287] -> 
             RGBColor[
              0.7952875716227025, 0.8379664616170492, 0.8715545506057808], 
             UndirectedEdge[179, 292] -> 
             RGBColor[
              0.9642682545454855, 0.9723301951575436, 0.9211099084100942], 
             UndirectedEdge[291, 297] -> 
             RGBColor[
              0.8886027342935237, 0.9124140152977633, 0.9201951806394235], 
             UndirectedEdge[289, 397] -> 
             RGBColor[
              0.9920348267155608, 0.9909742103983374, 0.78166706473824], 
             UndirectedEdge[175, 370] -> 
             RGBColor[
              0.9160065810580225, 0.9350091230045352, 0.962253213536735], 
             UndirectedEdge[23, 186] -> 
             RGBColor[
              0.9761008678523042, 0.9779431804220553, 0.6911995841086966], 
             UndirectedEdge[241, 461] -> 
             RGBColor[
              0.9538944148147273, 0.9617766681732995, 0.7852747146586145], 
             UndirectedEdge[157, 216] -> 
             RGBColor[
              0.9071843153330093, 0.9250081401890327, 0.8193177129056701], 
             UndirectedEdge[51, 302] -> 
             RGBColor[
              0.766910979818534, 0.8179801950064128, 0.9745757499700864], 
             UndirectedEdge[174, 390] -> 
             RGBColor[
              0.9937006306233345, 0.9889346108042819, 0.5557307024304812], 
             UndirectedEdge[79, 406] -> 
             RGBColor[
              0.9670923098032078, 0.9739366098345336, 0.8939491959014109], 
             UndirectedEdge[181, 235] -> 
             RGBColor[
              0.8677075531043582, 0.8974039583257094, 0.9816157923016697], 
             UndirectedEdge[78, 404] -> 
             RGBColor[
              0.7732211618751725, 0.5319250292721028, 0.5777113902387868], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.9902541027907737, 0.9891876261684511, 0.7348391517599535], 
             UndirectedEdge[43, 384] -> 
             RGBColor[
              0.9856861006766255, 0.9881061489621927, 0.876013280438288], 
             UndirectedEdge[101, 363] -> 
             RGBColor[
              0.9749841483887094, 0.9803530370159863, 0.9043565103539368], 
             UndirectedEdge[120, 455] -> 
             RGBColor[
              0.9775540736482757, 0.981482740783389, 0.8647654139691588], 
             UndirectedEdge[295, 456] -> 
             RGBColor[
              0.8452596992315473, 0.8794530714034492, 0.9851023105938961], 
             UndirectedEdge[58, 240] -> 
             RGBColor[
              0.8839376781962257, 0.5654898505477509, 0.5729298181896235], 
             UndirectedEdge[39, 471] -> 
             RGBColor[
              0.967085047865014, 0.9749726631077908, 0.9406006077568402], 
             UndirectedEdge[54, 365] -> 
             RGBColor[
              0.457413219843547, 0.5694735717420254, 0.9506809626358388], 
             UndirectedEdge[169, 334] -> 
             RGBColor[
              0.9899888010770217, 0.990128126216341, 0.8155750045134503], 
             UndirectedEdge[18, 65] -> 
             RGBColor[
              0.8364559874089229, 0.8729517882762938, 0.9765667743453168], 
             UndirectedEdge[384, 435] -> 
             RGBColor[
              0.8892900810787077, 0.9126982508574435, 0.9088040656124654], 
             UndirectedEdge[9, 360] -> 
             RGBColor[
              0.671310059310315, 0.7431517875694184, 0.9678735710290207], 
             UndirectedEdge[135, 171] -> 
             RGBColor[
              0.9661221641169006, 0.9739688323760745, 0.9294356796261636], 
             UndirectedEdge[149, 187] -> 
             RGBColor[
              0.9389914500520297, 0.9493107841122506, 0.7366205846234918], 
             UndirectedEdge[271, 464] -> 
             RGBColor[
              0.929771402292063, 0.816967111351536, 0.604938344552128], 
             UndirectedEdge[21, 348] -> 
             RGBColor[
              0.9143415415395699, 0.9307361791683835, 0.8218633932673332], 
             UndirectedEdge[1, 70] -> 
             RGBColor[
              0.9749491002957864, 0.9786327392812761, 0.816019665725169], 
             UndirectedEdge[52, 276] -> 
             RGBColor[
              0.9879811351717329, 0.9892979047698438, 0.8488472242368988], 
             UndirectedEdge[58, 429] -> 
             RGBColor[
              0.9664470945692957, 0.9739861162556103, 0.918807515649967], 
             UndirectedEdge[243, 495] -> 
             RGBColor[
              0.6094603406025899, 0.6922203412030684, 0.9634961587791742], 
             UndirectedEdge[131, 135] -> 
             RGBColor[
              0.9896501809576026, 0.9883546941926786, 0.7024555956154367], 
             UndirectedEdge[145, 430] -> 
             RGBColor[
              0.9716235282217234, 0.9758141154781955, 0.7947970030771405], 
             UndirectedEdge[291, 419] -> 
             RGBColor[
              0.8222155594185072, 0.860551849724184, 0.9135783274713036], 
             UndirectedEdge[151, 260] -> 
             RGBColor[
              0.9910915129256188, 0.9905841259041377, 0.7973002154554134], 
             UndirectedEdge[189, 437] -> 
             RGBColor[
              0.9578438400067832, 0.9664121217951614, 0.8847418477891621], 
             UndirectedEdge[196, 354] -> 
             RGBColor[
              0.9412084439488106, 0.7941048030012043, 0.5103906124878366], 
             UndirectedEdge[340, 355] -> 
             RGBColor[
              0.9009431154873935, 0.9235955638605515, 0.9815369804373864], 
             UndirectedEdge[58, 310] -> 
             RGBColor[
              0.8523609264760108, 0.8853495961081779, 0.9767725661267097], 
             UndirectedEdge[261, 500] -> 
             RGBColor[
              0.9721432085963744, 0.9755296154520183, 0.7405909003708404], 
             UndirectedEdge[237, 270] -> 
             RGBColor[
              0.8462364551489006, 0.8796332152026205, 0.9303039705316428], 
             UndirectedEdge[23, 497] -> 
             RGBColor[
              0.6642623223497319, 0.7316742142694155, 0.9489441138159047], 
             UndirectedEdge[431, 462] -> 
             RGBColor[
              0.9932390926559952, 0.989099896468549, 0.5892674519436851], 
             UndirectedEdge[108, 129] -> 
             RGBColor[
              0.9845651615122217, 0.9843288111592422, 0.6826619480799396], 
             UndirectedEdge[376, 485] -> 
             RGBColor[
              0.804778476586872, 0.8483382944986845, 0.9809323251170743], 
             UndirectedEdge[124, 261] -> 
             RGBColor[
              0.9928053274621036, 0.9895923987564754, 0.6452943085038662], 
             UndirectedEdge[63, 158] -> 
             RGBColor[
              0.8833936981658277, 0.908382926513261, 0.92141040223483], 
             UndirectedEdge[66, 427] -> 
             RGBColor[
              0.9890828748696869, 0.9742687560149881, 0.4603335598984682], 
             UndirectedEdge[66, 208] -> 
             RGBColor[
              0.9914672497226529, 0.9891351593365214, 0.6744544562689475], 
             UndirectedEdge[54, 230] -> 
             RGBColor[
              0.6094777175625847, 0.6905221920576534, 0.9642957943229693], 
             UndirectedEdge[186, 295] -> 
             RGBColor[
              0.931655387900872, 0.9431215338736003, 0.7083858368440024], 
             UndirectedEdge[245, 394] -> 
             RGBColor[
              0.9345320450392265, 0.9503900995947601, 0.985144117245782], 
             UndirectedEdge[49, 459] -> 
             RGBColor[
              0.9071743720435272, 0.9047560415170312, 0.6764343218005944], 
             UndirectedEdge[55, 365] -> 
             RGBColor[
              0.7443742083004455, 0.7948537935237912, 0.7476703886307433], 
             UndirectedEdge[197, 448] -> 
             RGBColor[
              0.7718442294098967, 0.8168573181791481, 0.7254190640561107], 
             UndirectedEdge[185, 321] -> 
             RGBColor[
              0.8794107237566801, 0.9042710250239092, 0.8756523202781137], 
             UndirectedEdge[242, 339] -> 
             RGBColor[
              0.9415188783075069, 0.9558419119731058, 0.9816743627559383], 
             UndirectedEdge[186, 191] -> 
             RGBColor[
              0.7955364929594537, 0.8357025805158247, 0.6953867078142715], 
             UndirectedEdge[218, 456] -> 
             RGBColor[
              0.8901194067903773, 0.9145836482232659, 0.9672148785671288], 
             UndirectedEdge[63, 182] -> 
             RGBColor[
              0.8802552726351556, 0.8873415060512877, 0.6792598722806034], 
             UndirectedEdge[133, 181] -> 
             RGBColor[
              0.9093265608243226, 0.9303756410824947, 0.9856422883344059], 
             UndirectedEdge[11, 186] -> 
             RGBColor[
              0.9289966919399305, 0.941001561882725, 0.7081322480498019], 
             UndirectedEdge[105, 148] -> 
             RGBColor[
              0.8981465668404086, 0.9208012175809739, 0.9617002582542729], 
             UndirectedEdge[235, 393] -> 
             RGBColor[
              0.6500593076926706, 0.7244714042782247, 0.9671770103993527], 
             UndirectedEdge[110, 290] -> 
             RGBColor[
              0.9260870716062445, 0.9436856210858553, 0.9853549654835176], 
             UndirectedEdge[225, 296] -> 
             RGBColor[
              0.9939490074632762, 0.9894658637501668, 0.5827649886539659], 
             UndirectedEdge[38, 93] -> 
             RGBColor[
              0.9521190015971221, 0.8788425651438978, 0.6021848701028081], 
             UndirectedEdge[80, 486] -> 
             RGBColor[
              0.9092329453232937, 0.9280489440585566, 0.8973804570537969], 
             UndirectedEdge[471, 500] -> 
             RGBColor[
              0.9666832171013507, 0.9746729783821882, 0.9412808024254742], 
             UndirectedEdge[200, 213] -> 
             RGBColor[
              0.8406029030517452, 0.8751436820448877, 0.9257268095490452], 
             UndirectedEdge[191, 295] -> 
             RGBColor[0.7346534223626797, 0.7923752722483646, 0.974537106014],
              UndirectedEdge[295, 300] -> 
             RGBColor[
              0.8624962822871655, 0.8931951399306242, 0.9867468594357123], 
             UndirectedEdge[191, 451] -> 
             RGBColor[
              0.7952894866303097, 0.8379672535219084, 0.8715228139738465], 
             UndirectedEdge[137, 145] -> 
             RGBColor[
              0.9009528191836274, 0.9235170829595505, 0.9785486611468628], 
             UndirectedEdge[332, 344] -> 
             RGBColor[
              0.952412178554094, 0.9590487461800193, 0.7075550711279865], 
             UndirectedEdge[76, 392] -> 
             RGBColor[
              0.9521786073671972, 0.9620878231180037, 0.892582395096295], 
             UndirectedEdge[157, 465] -> 
             RGBColor[
              0.903259473645152, 0.9239548790727947, 0.9257781639343843], 
             UndirectedEdge[204, 337] -> 
             RGBColor[
              0.8571402256002798, 0.8890342361403147, 0.9862068377347799], 
             UndirectedEdge[112, 395] -> 
             RGBColor[
              0.7866998957563414, 0.8335093382687061, 0.9617468849376745], 
             UndirectedEdge[51, 107] -> 
             RGBColor[
              0.9152126818611799, 0.9351412144379166, 0.9887048583584237], 
             UndirectedEdge[5, 41] -> 
             RGBColor[
              0.8286152910746977, 0.8662056759327689, 0.9835082760688983], 
             UndirectedEdge[88, 210] -> 
             RGBColor[
              0.9390098785674119, 0.9489951959759881, 0.709848569672795], 
             UndirectedEdge[248, 411] -> 
             RGBColor[
              0.9153010637938316, 0.9320761111568401, 0.8627260644049733], 
             UndirectedEdge[101, 128] -> 
             RGBColor[
              0.9787290928184671, 0.981448106386606, 0.8093239644033379], 
             UndirectedEdge[298, 418] -> 
             RGBColor[
              0.825389872196425, 0.8604095214780634, 0.7550845092027441], 
             UndirectedEdge[1, 391] -> 
             RGBColor[
              0.8236466749222944, 0.8598429882889032, 0.8186075020298436], 
             UndirectedEdge[116, 327] -> 
             RGBColor[
              0.9927858552827025, 0.9898329061378359, 0.6636846739324307], 
             UndirectedEdge[79, 81] -> 
             RGBColor[
              0.7922934665847121, 0.8358503553304288, 0.8844721582892526], 
             UndirectedEdge[254, 368] -> 
             RGBColor[
              0.8962467796721683, 0.9168377313339438, 0.8481892348799638], 
             UndirectedEdge[4, 318] -> 
             RGBColor[
              0.9167789039693524, 0.9174339821917069, 0.684734822549723], 
             UndirectedEdge[352, 412] -> 
             RGBColor[
              0.9630681083967432, 0.8799111135761686, 0.3790170337694819], 
             UndirectedEdge[239, 424] -> 
             RGBColor[
              0.8460889686751022, 0.8774245674795846, 0.8248081364566193], 
             UndirectedEdge[58, 188] -> 
             RGBColor[
              0.8724656593114637, 0.9010555662008626, 0.9787764180063373], 
             UndirectedEdge[407, 408] -> 
             RGBColor[
              0.6516250052673394, 0.7263674831595157, 0.9668729689884739], 
             UndirectedEdge[255, 466] -> 
             RGBColor[
              0.9320673776865078, 0.9303506405965861, 0.6872611573011461], 
             UndirectedEdge[197, 489] -> 
             RGBColor[
              0.5874118499495894, 0.6759264282481757, 0.960662359069989], 
             UndirectedEdge[50, 363] -> 
             RGBColor[
              0.8414325482376595, 0.8755643074442303, 0.9154936973238259], 
             UndirectedEdge[57, 175] -> 
             RGBColor[
              0.8659841611904372, 0.8959762798921425, 0.9870795364391726], 
             UndirectedEdge[278, 486] -> 
             RGBColor[
              0.8254968833963945, 0.8625671425780779, 0.8890520902076435], 
             UndirectedEdge[82, 263] -> 
             RGBColor[
              0.9521331085533795, 0.9638215312507274, 0.9659103409211078], 
             UndirectedEdge[41, 186] -> 
             RGBColor[
              0.9046331250685431, 0.9216010337108456, 0.7058014451129452], 
             UndirectedEdge[390, 425] -> 
             RGBColor[
              0.9319040430937432, 0.9434379507979624, 0.7179868533485685], 
             UndirectedEdge[218, 458] -> 
             RGBColor[
              0.9590449771145692, 0.9689763915065166, 0.95421035035105], 
             UndirectedEdge[230, 374] -> 
             RGBColor[
              0.8729649775993807, 0.8346199957996303, 0.6282716838675144], 
             UndirectedEdge[104, 408] -> 
             RGBColor[
              0.7676636296700531, 0.816989349730428, 0.9299641714698048], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.8221704140763011, 0.861701933684218, 0.97059441929708], 
             UndirectedEdge[143, 421] -> 
             RGBColor[
              0.8785127120507137, 0.8694198642136546, 0.6549031049505649], 
             UndirectedEdge[185, 482] -> 
             RGBColor[
              0.7847160181944952, 0.8317453845669502, 0.9791768171716557], 
             UndirectedEdge[256, 333] -> 
             RGBColor[
              0.9760024694769507, 0.9307128360369454, 0.361274554781681], 
             UndirectedEdge[351, 463] -> 
             RGBColor[
              0.9152157631343789, 0.6487233994799425, 0.4954877513624631], 
             UndirectedEdge[42, 411] -> 
             RGBColor[
              0.9712907255712122, 0.9764008040165366, 0.8569737613893191], 
             UndirectedEdge[52, 243] -> 
             RGBColor[
              0.8668054911754981, 0.8955432716318501, 0.9251611037533674], 
             UndirectedEdge[385, 391] -> 
             RGBColor[
              0.7473458105354204, 0.802730733810061, 0.9754045394669817], 
             UndirectedEdge[366, 435] -> 
             RGBColor[
              0.8906507524778098, 0.9132609234486322, 0.8862542192246421], 
             UndirectedEdge[114, 419] -> 
             RGBColor[
              0.8079573320653891, 0.8504288494387195, 0.9605867678705158], 
             UndirectedEdge[67, 391] -> 
             RGBColor[
              0.8084361182183606, 0.8099281581457358, 0.6409859809513975], 
             UndirectedEdge[310, 327] -> 
             RGBColor[
              0.8755333494576757, 0.9013388978407285, 0.8796600386921576], 
             UndirectedEdge[309, 348] -> 
             RGBColor[
              0.8109227262401502, 0.8495987329361696, 0.81174456955241], 
             UndirectedEdge[28, 194] -> 
             RGBColor[
              0.9826416025477092, 0.9525027663501268, 0.43854726053511317`], 
             UndirectedEdge[92, 337] -> 
             RGBColor[
              0.9366561956259987, 0.9122074893062251, 0.6556250247496556], 
             UndirectedEdge[205, 432] -> 
             RGBColor[
              0.7656841327878544, 0.813381390637923, 0.8461622682998482], 
             UndirectedEdge[314, 398] -> 
             RGBColor[
              0.7598499682071441, 0.8127068612921322, 0.9766635094855538], 
             UndirectedEdge[235, 453] -> 
             RGBColor[
              0.8934285751399778, 0.9134141314088733, 0.7500325956528565], 
             UndirectedEdge[92, 334] -> 
             RGBColor[
              0.9767673065299524, 0.9421881441638977, 0.5834253432610248], 
             UndirectedEdge[35, 54] -> 
             RGBColor[
              0.6184854745195884, 0.33601507938132813`, 0.5560894145012482], 
             UndirectedEdge[191, 456] -> 
             RGBColor[
              0.709140804290129, 0.7720341180456736, 0.9721031815641652], 
             UndirectedEdge[78, 137] -> 
             RGBColor[
              0.7807897097493308, 0.8289444480293792, 0.9787148048507307], 
             UndirectedEdge[57, 169] -> 
             RGBColor[
              0.9303121462149114, 0.944546437698977, 0.8859085069529851], 
             UndirectedEdge[343, 392] -> 
             RGBColor[
              0.9737994466171673, 0.9787968651827454, 0.8762404606551017], 
             UndirectedEdge[24, 197] -> 
             RGBColor[
              0.7677788607018101, 0.817037000723362, 0.9280544950652401], 
             UndirectedEdge[450, 471] -> 
             RGBColor[
              0.9877208712617483, 0.9869662428244674, 0.699847079845251], 
             UndirectedEdge[150, 267] -> 
             RGBColor[
              0.7167632719551671, 0.7549212584353359, 0.6622840397419936], 
             UndirectedEdge[40, 371] -> 
             RGBColor[
              0.9913342453478196, 0.9906274497173095, 0.789130412468746], 
             UndirectedEdge[217, 362] -> 
             RGBColor[
              0.9940049029727425, 0.9895854185930122, 0.5888488699122736], 
             UndirectedEdge[229, 478] -> 
             RGBColor[
              0.9864028911291416, 0.9883981626825751, 0.8639372762643418], 
             UndirectedEdge[100, 168] -> 
             RGBColor[
              0.7840642004051825, 0.8309858760579136, 0.9512484083556443], 
             UndirectedEdge[221, 297] -> 
             RGBColor[
              0.8277127857979756, 0.6589564796540119, 0.5945841749148281], 
             UndirectedEdge[50, 338] -> 
             RGBColor[
              0.8449207695336262, 0.8761102719903613, 0.7925184225716049], 
             UndirectedEdge[5, 186] -> 
             RGBColor[
              0.9165206245038005, 0.9310534843629839, 0.7069422696002269], 
             UndirectedEdge[147, 391] -> 
             RGBColor[
              0.6277649425459055, 0.7085310534898479, 0.9639456463569982], 
             UndirectedEdge[24, 426] -> 
             RGBColor[
              0.9845925010119208, 0.987896408421084, 0.9049963005418984], 
             UndirectedEdge[100, 127] -> 
             RGBColor[
              0.9792012198226809, 0.9828100240108644, 0.8664036751836343], 
             UndirectedEdge[418, 432] -> 
             RGBColor[
              0.9942003538445622, 0.9904101535874488, 0.6396842223545239], 
             UndirectedEdge[200, 259] -> 
             RGBColor[
              0.9658283539553814, 0.9737302511108482, 0.9290616488719079], 
             UndirectedEdge[17, 293] -> 
             RGBColor[
              0.8062820686903966, 0.8494133694969342, 0.9811086046663628], 
             UndirectedEdge[269, 468] -> 
             RGBColor[
              0.9247434372912683, 0.938519517397147, 0.78144429019114], 
             UndirectedEdge[154, 390] -> 
             RGBColor[
              0.9799384286820447, 0.9809279151105963, 0.6944383710052682], 
             UndirectedEdge[162, 439] -> 
             RGBColor[
              0.9942072484139399, 0.9900182150314714, 0.6108729224553102], 
             UndirectedEdge[103, 304] -> 
             RGBColor[
              0.960496741099442, 0.9664096012815386, 0.7347063133723553], 
             UndirectedEdge[3, 480] -> 
             RGBColor[
              0.7182783678787577, 0.7785305711366957, 0.9716194805984175], 
             UndirectedEdge[358, 404] -> 
             RGBColor[
              0.9129923097010189, 0.6404575328160732, 0.5146287822089146], 
             UndirectedEdge[3, 439] -> 
             RGBColor[
              0.9658034391678124, 0.970904403801779, 0.7594933409088069], 
             UndirectedEdge[336, 458] -> 
             RGBColor[
              0.9747779885676932, 0.9794198715830995, 0.8698018333981443], 
             UndirectedEdge[212, 287] -> 
             RGBColor[
              0.9923698693695621, 0.9911127591459704, 0.7761145408988452], 
             UndirectedEdge[190, 195] -> 
             RGBColor[
              0.9032047565833817, 0.6522362792325285, 0.24088602934174558`], 
             UndirectedEdge[253, 377] -> 
             RGBColor[
              0.8880044556149207, 0.8897606228818433, 0.6747246220246919], 
             UndirectedEdge[192, 327] -> 
             RGBColor[
              0.9890446878025934, 0.9897377111147605, 0.8312214047575608], 
             UndirectedEdge[151, 483] -> 
             RGBColor[
              0.9872945164748084, 0.9890139702933698, 0.8602262729571652], 
             UndirectedEdge[38, 163] -> 
             RGBColor[
              0.7194399764240182, 0.6945978167674449, 0.6104464330614263], 
             UndirectedEdge[88, 227] -> 
             RGBColor[
              0.972608381650081, 0.9753482418370274, 0.6978852243066576], 
             UndirectedEdge[281, 343] -> 
             RGBColor[
              0.9748530599217874, 0.9776281412447652, 0.742154956215394], 
             UndirectedEdge[76, 157] -> 
             RGBColor[
              0.8663946586957637, 0.8963055143870238, 0.9871181818949941], 
             UndirectedEdge[364, 437] -> 
             RGBColor[
              0.9586525206500717, 0.9655870549223691, 0.7870581715558781], 
             UndirectedEdge[229, 244] -> 
             RGBColor[
              0.9924537131715252, 0.9911474307127697, 0.7747250321195109], 
             UndirectedEdge[154, 425] -> 
             RGBColor[
              0.9191278765195574, 0.9375402850510439, 0.9640183865277041], 
             UndirectedEdge[128, 355] -> 
             RGBColor[
              0.9255073219495124, 0.9397068424377069, 0.8283898737675219], 
             UndirectedEdge[58, 382] -> 
             RGBColor[
              0.8460212923693284, 0.8803970257610338, 0.9761406906462047], 
             UndirectedEdge[45, 179] -> 
             RGBColor[
              0.9268364081573124, 0.9443593484728705, 0.9880692675418408], 
             UndirectedEdge[181, 296] -> 
             RGBColor[
              0.9677463340591784, 0.9724254870922513, 0.7619234062516183], 
             UndirectedEdge[350, 354] -> 
             RGBColor[
              0.9730308475641374, 0.9781887068395083, 0.8759768841820252], 
             UndirectedEdge[318, 335] -> 
             RGBColor[
              0.6095078289443445, 0.6584489019370356, 0.6602834891710359], 
             UndirectedEdge[354, 372] -> 
             RGBColor[
              0.9647110642237271, 0.8911261176253359, 0.529500076683858], 
             UndirectedEdge[44, 57] -> 
             RGBColor[
              0.9166847964919194, 0.9356580338772313, 0.9660665008438662], 
             UndirectedEdge[257, 420] -> 
             RGBColor[
              0.9927160564857381, 0.9898752615788076, 0.6700182928143167], 
             UndirectedEdge[84, 171] -> 
             RGBColor[
              0.7115732095292941, 0.7728167437761346, 0.9638424056715129], 
             UndirectedEdge[376, 497] -> 
             RGBColor[
              0.6513327003309293, 0.7219824573612654, 0.9691363772153632], 
             UndirectedEdge[164, 443] -> 
             RGBColor[
              0.9646971067438822, 0.9568211776780592, 0.6818121695145332], 
             UndirectedEdge[2, 54] -> 
             RGBColor[
              0.6238638905917331, 0.7018261830337902, 0.9657123175880413], 
             UndirectedEdge[165, 324] -> 
             RGBColor[
              0.9919573116006468, 0.9909421559062729, 0.7829516907950522], 
             UndirectedEdge[82, 395] -> 
             RGBColor[
              0.9495103055907269, 0.9618654490956269, 0.970350062200309], 
             UndirectedEdge[298, 420] -> 
             RGBColor[
              0.8244700727106811, 0.8614887186831792, 0.876422420697886], 
             UndirectedEdge[163, 437] -> 
             RGBColor[
              0.7134521623425532, 0.7747825535190719, 0.9733061066129516], 
             UndirectedEdge[156, 372] -> 
             RGBColor[
              0.9546639432962808, 0.8533905275258336, 0.30620197614416905`], 
             UndirectedEdge[272, 317] -> 
             RGBColor[
              0.9785745927913785, 0.9826833439414222, 0.8827197231873809], 
             UndirectedEdge[282, 441] -> 
             RGBColor[
              0.906273276660793, 0.7223468922702523, 0.5928394834472461], 
             UndirectedEdge[209, 423] -> 
             RGBColor[
              0.9941526248567136, 0.9904333383934529, 0.6435951892450555], 
             UndirectedEdge[222, 333] -> 
             RGBColor[
              0.9810675255038132, 0.9461305631935593, 0.5227771907321785], 
             UndirectedEdge[125, 455] -> 
             RGBColor[
              0.8511283962392755, 0.8840773063863984, 0.9609865378241946], 
             UndirectedEdge[343, 433] -> 
             RGBColor[
              0.9623449396518926, 0.9360026184744162, 0.6453238382332015], 
             UndirectedEdge[29, 77] -> 
             RGBColor[
              0.9643153125002524, 0.9716030587641731, 0.8868959390520621], 
             UndirectedEdge[298, 353] -> 
             RGBColor[
              0.7536482159820724, 0.8077184528340032, 0.9760156591476585], 
             UndirectedEdge[65, 337] -> 
             RGBColor[
              0.9259892298415722, 0.9436063480461272, 0.9853020636268963], 
             UndirectedEdge[93, 364] -> 
             RGBColor[
              0.9814166363560453, 0.9828825016155788, 0.7595499455298461], 
             UndirectedEdge[170, 328] -> 
             RGBColor[
              0.8208742379243177, 0.8606626373542849, 0.9691129870349147], 
             UndirectedEdge[13, 244] -> 
             RGBColor[
              0.9867537961595383, 0.9659684044415001, 0.5537475128469738], 
             UndirectedEdge[114, 291] -> 
             RGBColor[
              0.9730081292485386, 0.9788793251766814, 0.9077013953299138], 
             UndirectedEdge[198, 373] -> 
             RGBColor[
              0.8034673235261298, 0.842851467718365, 0.7542256157726834], 
             UndirectedEdge[54, 84] -> 
             RGBColor[
              0.44823289689466633`, 0.5620205720032883, 0.9499582539846719], 
             UndirectedEdge[1, 385] -> 
             RGBColor[
              0.9184607577558179, 0.9340917099026482, 0.8280101190690455], 
             UndirectedEdge[97, 294] -> 
             RGBColor[
              0.9294065582148707, 0.9456495745494452, 0.961994487487035], 
             UndirectedEdge[83, 489] -> 
             RGBColor[
              0.8069947843351567, 0.8479312192534623, 0.8917191562401773], 
             UndirectedEdge[349, 359] -> 
             RGBColor[
              0.6358445936340509, 0.6993490987729352, 0.7599174301762486], 
             UndirectedEdge[47, 55] -> 
             RGBColor[
              0.9850305125270193, 0.9853241499256897, 0.7333125342271032], 
             UndirectedEdge[166, 309] -> 
             RGBColor[
              0.8097551288193133, 0.8496561131138387, 0.8703623695271498], 
             UndirectedEdge[196, 482] -> 
             RGBColor[
              0.8470010008161429, 0.7217806580809238, 0.6058399099295336], 
             UndirectedEdge[114, 311] -> 
             RGBColor[
              0.9759127048871262, 0.9781769306773063, 0.7211998926154486], 
             UndirectedEdge[101, 169] -> 
             RGBColor[
              0.9772837325655961, 0.9813039741697467, 0.8662464494098427], 
             UndirectedEdge[160, 353] -> 
             RGBColor[
              0.7822841349927958, 0.8300890504062256, 0.9788698199367696], 
             UndirectedEdge[80, 329] -> 
             RGBColor[
              0.8913772782759097, 0.9157382970650227, 0.9726597731971839], 
             UndirectedEdge[130, 386] -> 
             RGBColor[
              0.9688189906483048, 0.9746403096345773, 0.8648711570160508], 
             UndirectedEdge[216, 238] -> 
             RGBColor[
              0.9942589215575104, 0.9901287386606124, 0.6164972252432722], 
             UndirectedEdge[240, 382] -> 
             RGBColor[
              0.7843311380286198, 0.4869169692597102, 0.5721484324665957], 
             UndirectedEdge[424, 470] -> 
             RGBColor[
              0.8123060684554366, 0.7564204978069271, 0.6154026218604707], 
             UndirectedEdge[184, 225] -> 
             RGBColor[
              0.9771912899366351, 0.9800083476334325, 0.7886892497834159], 
             UndirectedEdge[169, 274] -> 
             RGBColor[
              0.9778263726963481, 0.9817086742907699, 0.8653279012116923], 
             UndirectedEdge[345, 375] -> 
             RGBColor[
              0.9744229657232235, 0.9797101473834372, 0.8952591237689103], 
             UndirectedEdge[326, 434] -> 
             RGBColor[
              0.915656503633212, 0.674736887027428, 0.2834428361245832], 
             UndirectedEdge[59, 105] -> 
             RGBColor[
              0.9767362296053628, 0.9818774785239408, 0.9111416346988219], 
             UndirectedEdge[90, 306] -> 
             RGBColor[
              0.3305773510859905, 0.4545321482407948, 0.9425127850331434], 
             UndirectedEdge[44, 466] -> 
             RGBColor[
              0.9734807018682969, 0.9626269447921765, 0.6653622896803629], 
             UndirectedEdge[88, 434] -> 
             RGBColor[
              0.9851336339859538, 0.9614838736454987, 0.3993429775425801], 
             UndirectedEdge[174, 356] -> 
             RGBColor[
              0.9923559430222619, 0.9905934135751654, 0.739013007424522], 
             UndirectedEdge[65, 88] -> 
             RGBColor[
              0.9683205315404126, 0.9721503702459469, 0.7051434360919098], 
             UndirectedEdge[82, 195] -> 
             RGBColor[
              0.9258817230549079, 0.8154593219327713, 0.6126034160314776], 
             UndirectedEdge[150, 413] -> 
             RGBColor[
              0.9355153292845095, 0.929274460240276, 0.6819622389796935], 
             UndirectedEdge[156, 307] -> 
             RGBColor[
              0.7327191646099522, 0.7576943598814385, 0.6484123053319746], 
             UndirectedEdge[245, 460] -> 
             RGBColor[
              0.7644058978452928, 0.8161453259200204, 0.977321705365639], 
             UndirectedEdge[101, 204] -> 
             RGBColor[
              0.8845462679928077, 0.910190738951393, 0.9646786011425414], 
             UndirectedEdge[210, 428] -> 
             RGBColor[
              0.8423853922162148, 0.8773264149786586, 0.984784307548678], 
             UndirectedEdge[25, 76] -> 
             RGBColor[
              0.840513012882669, 0.8760865759700405, 0.9845385413180763], 
             UndirectedEdge[130, 421] -> 
             RGBColor[
              0.8914990843722332, 0.9134431064408384, 0.8645490340485471], 
             UndirectedEdge[79, 493] -> 
             RGBColor[
              0.9882089287735747, 0.977307709901232, 0.6038498883814432], 
             UndirectedEdge[194, 490] -> 
             RGBColor[
              0.9783441744232477, 0.9802748324502537, 0.7396591586686819], 
             UndirectedEdge[214, 347] -> 
             RGBColor[
              0.9242233078582275, 0.9402043927069141, 0.9076052575129079], 
             UndirectedEdge[41, 202] -> 
             RGBColor[
              0.8923283256020482, 0.9161776008861998, 0.9607698531161506], 
             UndirectedEdge[85, 97] -> 
             RGBColor[
              0.963438126730426, 0.9722527952969003, 0.9467738939683303], 
             UndirectedEdge[31, 114] -> 
             RGBColor[
              0.9756941845137985, 0.9777095376945574, 0.6974152985301618], 
             UndirectedEdge[247, 425] -> 
             RGBColor[
              0.9329834444207914, 0.9457466810923038, 0.8354730265049382], 
             UndirectedEdge[35, 281] -> 
             RGBColor[
              0.9053706025555518, 0.5612330433933789, 0.3448219018336237], 
             UndirectedEdge[157, 288] -> 
             RGBColor[
              0.8936206452524227, 0.9171948661355076, 0.9612881951201269], 
             UndirectedEdge[208, 427] -> 
             RGBColor[
              0.9871278305417731, 0.9750646383322333, 0.6093525319884827], 
             UndirectedEdge[154, 313] -> 
             RGBColor[
              0.9800961584922067, 0.9832080060913916, 0.8528217313635296], 
             UndirectedEdge[189, 364] -> 
             RGBColor[
              0.9931292888471714, 0.9902673215152155, 0.6792472496646749], 
             UndirectedEdge[314, 373] -> 
             RGBColor[
              0.7506242215074854, 0.8052169845061968, 0.975937224910333], 
             UndirectedEdge[156, 232] -> 
             RGBColor[
              0.8960097206300492, 0.8875356274245474, 0.6631325245793263], 
             UndirectedEdge[321, 383] -> 
             RGBColor[
              0.9847823569811278, 0.9867910593359329, 0.8488342527665207], 
             UndirectedEdge[15, 323] -> 
             RGBColor[
              0.968536803211737, 0.9723223553417963, 0.7056255533165763], 
             UndirectedEdge[225, 235] -> 
             RGBColor[
              0.893910226508456, 0.9144443349836249, 0.8024573747040173], 
             UndirectedEdge[170, 265] -> 
             RGBColor[
              0.8429634198750287, 0.8749941276931923, 0.82539869518006], 
             UndirectedEdge[102, 485] -> 
             RGBColor[
              0.7661403200084812, 0.8175292772478961, 0.9772469832499378], 
             UndirectedEdge[342, 463] -> 
             RGBColor[
              0.8888144091104222, 0.6301002494213501, 0.5879579554785974], 
             UndirectedEdge[70, 147] -> 
             RGBColor[
              0.7790673679193976, 0.8273208044822209, 0.9613578100523237], 
             UndirectedEdge[162, 381] -> 
             RGBColor[
              0.9924967862806697, 0.9908837888751101, 0.7535524882189617], 
             UndirectedEdge[212, 299] -> 
             RGBColor[
              0.9808228345297074, 0.983804939712545, 0.8540537671483438], 
             UndirectedEdge[92, 361] -> 
             RGBColor[
              0.9770515458403048, 0.9423056844233455, 0.578714762300728], 
             UndirectedEdge[82, 184] -> 
             RGBColor[
              0.9518458568466579, 0.9636072993981859, 0.9663965831333436], 
             UndirectedEdge[232, 376] -> 
             RGBColor[
              0.8771962190195952, 0.9049164704619108, 0.9881489525240399], 
             UndirectedEdge[293, 298] -> 
             RGBColor[
              0.6741326723968553, 0.7453568343652777, 0.9681549027226681], 
             UndirectedEdge[225, 249] -> 
             RGBColor[
              0.8269808625114154, 0.8621586071471303, 0.7957864811912596], 
             UndirectedEdge[19, 34] -> 
             RGBColor[
              0.9837706071006815, 0.9863501922480006, 0.864594753807173], 
             UndirectedEdge[338, 390] -> 
             RGBColor[
              0.9934786972249103, 0.9884599177059614, 0.531574621626196], 
             UndirectedEdge[82, 342] -> 
             RGBColor[
              0.9407281353786214, 0.9553157209309224, 0.9852159856125724], 
             UndirectedEdge[54, 374] -> 
             RGBColor[
              0.6831392090759727, 0.6820009625046333, 0.6119367185470415], 
             UndirectedEdge[196, 350] -> 
             RGBColor[
              0.92271401326779, 0.7815300108296852, 0.596255895107875], 
             UndirectedEdge[19, 44] -> 
             RGBColor[
              0.9707702053452797, 0.9777210475226814, 0.9343625973857539], 
             UndirectedEdge[85, 408] -> 
             RGBColor[
              0.7534585880045004, 0.8064902493708492, 0.9582637371288071], 
             UndirectedEdge[57, 255] -> 
             RGBColor[
              0.87527147231013, 0.9033817296816409, 0.9879653684646494], 
             UndirectedEdge[106, 269] -> 
             RGBColor[
              0.9944139677409998, 0.9904603667695225, 0.6333730454819755], 
             UndirectedEdge[382, 416] -> 
             RGBColor[
              0.5754264199269267, 0.6632749105865487, 0.96117536006559], 
             UndirectedEdge[246, 392] -> 
             RGBColor[
              0.99287681773338, 0.990594854592846, 0.7148285638427732], 
             UndirectedEdge[350, 414] -> 
             RGBColor[
              0.973544437835752, 0.9760463510076494, 0.6963007253468699], 
             UndirectedEdge[146, 211] -> 
             RGBColor[
              0.9826960371644015, 0.9590687208528952, 0.584902912634329], 
             UndirectedEdge[71, 487] -> 
             RGBColor[
              0.989098746229611, 0.9897600656635704, 0.8303255167231554], 
             UndirectedEdge[415, 485] -> 
             RGBColor[
              0.7183791580386811, 0.7799225252344179, 0.9725649789045281], 
             UndirectedEdge[238, 433] -> 
             RGBColor[
              0.9811511290896566, 0.9472205776949887, 0.454395489261064], 
             UndirectedEdge[141, 429] -> 
             RGBColor[
              0.9671534397500489, 0.9745129073348819, 0.9176118575032797], 
             UndirectedEdge[406, 493] -> 
             RGBColor[
              0.9648404760316446, 0.9609210253235019, 0.6900457026932167], 
             UndirectedEdge[257, 357] -> 
             RGBColor[
              0.9924180295823459, 0.9897520197953129, 0.6749573698724267], 
             UndirectedEdge[311, 488] -> 
             RGBColor[
              0.9928564423277131, 0.9894104583984002, 0.6296856001895584], 
             UndirectedEdge[258, 381] -> 
             RGBColor[
              0.8896751755963253, 0.9127423051940813, 0.89719875200466], 
             UndirectedEdge[168, 200] -> 
             RGBColor[
              0.7935814800664703, 0.8377786759094009, 0.9214719225174901], 
             UndirectedEdge[16, 254] -> 
             RGBColor[
              0.7648349714319169, 0.8125255249737726, 0.8362210225302678], 
             UndirectedEdge[325, 347] -> 
             RGBColor[
              0.9266012181275056, 0.9411877197127672, 0.8681971305164571], 
             UndirectedEdge[154, 478] -> 
             RGBColor[
              0.9749334718741681, 0.9808260048832032, 0.9273152731061602], 
             UndirectedEdge[302, 386] -> 
             RGBColor[
              0.7691753638214487, 0.8196689688881982, 0.9707427384990854], 
             UndirectedEdge[330, 414] -> 
             RGBColor[
              0.9925954629602819, 0.9865707689226038, 0.435440022611437], 
             UndirectedEdge[50, 334] -> 
             RGBColor[
              0.8418554085361377, 0.8757391710446649, 0.9084858078506688], 
             UndirectedEdge[72, 187] -> 
             RGBColor[
              0.6421058237253692, 0.7156710258393304, 0.9677748567568867], 
             UndirectedEdge[14, 149] -> 
             RGBColor[
              0.9215183344818376, 0.9353781960516665, 0.7349539832619725], 
             UndirectedEdge[113, 214] -> 
             RGBColor[
              0.9910020056869224, 0.9905471123607057, 0.798783582037919], 
             UndirectedEdge[63, 149] -> 
             RGBColor[
              0.8863869780586897, 0.9076907714331941, 0.7315167811569269], 
             UndirectedEdge[245, 445] -> 
             RGBColor[
              0.9434962582307435, 0.9570755951154415, 0.9699700425537883], 
             UndirectedEdge[207, 336] -> 
             RGBColor[
              0.992837473061539, 0.9899561853680392, 0.6702387560055101], 
             UndirectedEdge[264, 394] -> 
             RGBColor[
              0.9695509869816097, 0.9740243196381256, 0.7789371443924473], 
             UndirectedEdge[255, 370] -> 
             RGBColor[
              0.9252938921777154, 0.9424145727940338, 0.9631390455622117], 
             UndirectedEdge[330, 482] -> 
             RGBColor[
              0.8978744295559996, 0.9163889798341822, 0.7105654788882894], 
             UndirectedEdge[383, 482] -> 
             RGBColor[
              0.8900876514189431, 0.9142654188789738, 0.9523587496600627], 
             UndirectedEdge[358, 407] -> 
             RGBColor[
              0.8704369542722301, 0.8980534518964721, 0.9107069891626782], 
             UndirectedEdge[28, 142] -> 
             RGBColor[
              0.9822464561154606, 0.9516575880869795, 0.39553800994595445`], 
             UndirectedEdge[348, 375] -> 
             RGBColor[
              0.9774424587986396, 0.980418573650484, 0.8059506202454674], 
             UndirectedEdge[41, 295] -> 
             RGBColor[
              0.8437500544717692, 0.8782737254433854, 0.9849518433126738], 
             UndirectedEdge[83, 345] -> 
             RGBColor[
              0.9891730734016946, 0.9897908018593482, 0.8290937231291748], 
             UndirectedEdge[140, 425] -> 
             RGBColor[
              0.9331483089657595, 0.9460993096836282, 0.8534175147986878], 
             UndirectedEdge[160, 441] -> 
             RGBColor[
              0.7903123599755606, 0.6310112228501319, 0.5911050917544978], 
             UndirectedEdge[66, 394] -> 
             RGBColor[
              0.9692994661799894, 0.9734863420761136, 0.7515606573425297], 
             UndirectedEdge[201, 271] -> 
             RGBColor[
              0.8564259359349728, 0.8884072633209144, 0.9712071655716115], 
             UndirectedEdge[192, 470] -> 
             RGBColor[
              0.9566927100640332, 0.8689393326515409, 0.5700413496090839], 
             UndirectedEdge[255, 379] -> 
             RGBColor[
              0.8739735031609763, 0.9023467643145398, 0.9878415670084923], 
             UndirectedEdge[82, 440] -> 
             RGBColor[
              0.8923103043371143, 0.9167631283189301, 0.9824864140059117], 
             UndirectedEdge[43, 362] -> 
             RGBColor[
              0.988650057227326, 0.9887166939419042, 0.782179594332388], 
             UndirectedEdge[127, 302] -> 
             RGBColor[
              0.7930485772945799, 0.8362747121031164, 0.8766442013677285], 
             UndirectedEdge[137, 358] -> 
             RGBColor[
              0.920560857575177, 0.9374769515733495, 0.9156321968208585], 
             UndirectedEdge[238, 328] -> 
             RGBColor[
              0.9722845220574414, 0.9760427563773426, 0.7727048784953556], 
             UndirectedEdge[185, 196] -> 
             RGBColor[
              0.8286066270308157, 0.7074108334774076, 0.6040065306558084], 
             UndirectedEdge[114, 208] -> 
             RGBColor[
              0.9741310536450798, 0.9793436832724918, 0.889091632044044], 
             UndirectedEdge[249, 424] -> 
             RGBColor[
              0.6784846741111841, 0.7487566511809493, 0.968588669581784], 
             UndirectedEdge[21, 65] -> 
             RGBColor[
              0.8890579421630107, 0.9141583417243409, 0.9817795244391654], 
             UndirectedEdge[369, 466] -> 
             RGBColor[
              0.9882209653784501, 0.9709484114561213, 0.49209706461220504`], 
             UndirectedEdge[246, 459] -> 
             RGBColor[
              0.9154489626538371, 0.9314735531451295, 0.8101618704705316], 
             UndirectedEdge[46, 317] -> 
             RGBColor[
              0.9434008515757346, 0.8085331656426942, 0.5310859342487558], 
             UndirectedEdge[66, 305] -> 
             RGBColor[
              0.9340383285093861, 0.9456144702313265, 0.7566709961018248], 
             UndirectedEdge[56, 243] -> 
             RGBColor[
              0.8703250158150808, 0.8954174473850516, 0.7518941523724723], 
             UndirectedEdge[281, 288] -> 
             RGBColor[
              0.9804582072284761, 0.9818084509285072, 0.73266690388172], 
             UndirectedEdge[81, 329] -> 
             RGBColor[
              0.7743312937537015, 0.8234956654582917, 0.961516550895466], 
             UndirectedEdge[57, 140] -> 
             RGBColor[
              0.9319809472373279, 0.9451684871285668, 0.8533061707949139], 
             UndirectedEdge[184, 440] -> 
             RGBColor[
              0.9005112366755342, 0.9228793702291294, 0.9686043747026818], 
             UndirectedEdge[422, 446] -> 
             RGBColor[
              0.9937028661106919, 0.9911345737606634, 0.7155405411498312], 
             UndirectedEdge[232, 307] -> 
             RGBColor[
              0.6572978488497363, 0.729937668493963, 0.9680294294286916], 
             UndirectedEdge[90, 261] -> 
             RGBColor[
              0.7064920999859807, 0.7630113400701627, 0.7306370663436417], 
             UndirectedEdge[118, 304] -> 
             RGBColor[
              0.9502495290448025, 0.9622187805521635, 0.9622346524110199], 
             UndirectedEdge[427, 460] -> 
             RGBColor[
              0.7948338998051758, 0.8251710473970859, 0.678636321181922], 
             UndirectedEdge[299, 300] -> 
             RGBColor[
              0.9115833967073337, 0.9314785098658835, 0.9617035302769916], 
             UndirectedEdge[106, 425] -> 
             RGBColor[
              0.9330136101780625, 0.9458112025968809, 0.838756383022431], 
             UndirectedEdge[428, 495] -> 
             RGBColor[
              0.6355116063101441, 0.7125717879707624, 0.9660927054819837], 
             UndirectedEdge[230, 365] -> 
             RGBColor[
              0.6472389883669551, 0.7220926050370226, 0.9670159279563117], 
             UndirectedEdge[224, 463] -> 
             RGBColor[
              0.9165229963129773, 0.6474924648933016, 0.3450535039872782], 
             UndirectedEdge[251, 382] -> 
             RGBColor[
              0.857180825640965, 0.8887197874029618, 0.9572505116897458], 
             UndirectedEdge[81, 278] -> 
             RGBColor[
              0.6274360932195953, 0.7081382463748466, 0.9640057904444328], 
             UndirectedEdge[42, 294] -> 
             RGBColor[
              0.9181983136402977, 0.9372904840975449, 0.9809671219734226], 
             UndirectedEdge[8, 419] -> 
             RGBColor[
              0.531587100950237, 0.6290940384107628, 0.9567776201903422], 
             UndirectedEdge[159, 164] -> 
             RGBColor[
              0.947301117242646, 0.960217840042842, 0.9740896418250089], 
             UndirectedEdge[346, 404] -> 
             RGBColor[
              0.9151516872142549, 0.6389557714257594, 0.3047714818723692], 
             UndirectedEdge[7, 194] -> 
             RGBColor[
              0.954558866635395, 0.9620183615896141, 0.7619819527230836], 
             UndirectedEdge[268, 353] -> 
             RGBColor[
              0.8968758685102118, 0.92040358526162, 0.982921881592469], 
             UndirectedEdge[51, 423] -> 
             RGBColor[
              0.9663864037104972, 0.9714653435554146, 0.7685172468050887], 
             UndirectedEdge[14, 322] -> 
             RGBColor[
              0.9211016850562395, 0.9371358540463295, 0.8821461693914163], 
             UndirectedEdge[109, 458] -> 
             RGBColor[
              0.9546368864185306, 0.9070070486538089, 0.6183172738155114], 
             UndirectedEdge[217, 384] -> 
             RGBColor[
              0.991040946422042, 0.9889748736133008, 0.6826825560181735], 
             UndirectedEdge[202, 485] -> 
             RGBColor[
              0.8218408897845214, 0.861112280301194, 0.9537443242563983], 
             UndirectedEdge[125, 457] -> 
             RGBColor[
              0.8664185143379264, 0.8939034692415491, 0.8644749154539867], 
             UndirectedEdge[454, 475] -> 
             RGBColor[
              0.9716886550511915, 0.9767114335421103, 0.8569205976138441], 
             UndirectedEdge[30, 378] -> 
             RGBColor[
              0.849033500750382, 0.8824602833706627, 0.9854627673143669], 
             UndirectedEdge[445, 460] -> 
             RGBColor[
              0.7840147043069952, 0.8310741289788929, 0.9546893439339897], 
             UndirectedEdge[173, 461] -> 
             RGBColor[
              0.8890796990309044, 0.914392034854457, 0.9892824094560264], 
             UndirectedEdge[23, 41] -> 
             RGBColor[
              0.8881955344232014, 0.9130953719918404, 0.9677655905773681], 
             UndirectedEdge[111, 444] -> 
             RGBColor[
              0.9566359459988316, 0.9671797400448261, 0.958288211654051], 
             UndirectedEdge[139, 360] -> 
             RGBColor[
              0.8135762498200044, 0.8544362494104645, 0.941802879862196], 
             UndirectedEdge[53, 432] -> 
             RGBColor[
              0.9736079617566931, 0.9780733092200262, 0.8505575633233102], 
             UndirectedEdge[184, 260] -> 
             RGBColor[
              0.9768557074446731, 0.9806858577362383, 0.8535858107704437], 
             UndirectedEdge[244, 379] -> 
             RGBColor[
              0.9304845774506649, 0.944119520678601, 0.8614163658446987], 
             UndirectedEdge[14, 187] -> 
             RGBColor[
              0.8674649274958499, 0.8971570027497479, 0.9872207732512785], 
             UndirectedEdge[133, 332] -> 
             RGBColor[
              0.9343799440731897, 0.9446703318769119, 0.7058351405056322], 
             UndirectedEdge[424, 440] -> 
             RGBColor[
              0.7691595490268601, 0.8197622205879955, 0.9775812690465084], 
             UndirectedEdge[381, 419] -> 
             RGBColor[
              0.8236012936585443, 0.861124886444185, 0.8906131249486349], 
             UndirectedEdge[39, 368] -> 
             RGBColor[
              0.874550065177361, 0.9025750128310326, 0.9734713138272391], 
             UndirectedEdge[40, 208] -> 
             RGBColor[
              0.988482414677858, 0.9895051967279223, 0.8405397255506284], 
             UndirectedEdge[436, 462] -> 
             RGBColor[
              0.9154155893725515, 0.9322690174868684, 0.8671482350411741], 
             UndirectedEdge[103, 188] -> 
             RGBColor[
              0.8961377069945687, 0.9152586073607965, 0.7285233340065809], 
             UndirectedEdge[313, 411] -> 
             RGBColor[
              0.9937527282893718, 0.991684606847165, 0.7531969898734319], 
             UndirectedEdge[181, 344] -> 
             RGBColor[
              0.9273587953052269, 0.9447540553856022, 0.9873622189567604], 
             UndirectedEdge[5, 485] -> 
             RGBColor[
              0.7581278552571709, 0.8111403553477631, 0.9764827472091461], 
             UndirectedEdge[371, 429] -> 
             RGBColor[
              0.9912411116681596, 0.9905889365473437, 0.7906738785629495], 
             UndirectedEdge[426, 448] -> 
             RGBColor[
              0.9886578697200074, 0.98771672587687, 0.702360869532769], 
             UndirectedEdge[32, 403] -> 
             RGBColor[
              0.9939046704325216, 0.9893710313245441, 0.5779391764727692], 
             UndirectedEdge[115, 484] -> 
             RGBColor[
              0.9695658656973664, 0.9768228529851928, 0.9364012302675846], 
             UndirectedEdge[36, 251] -> 
             RGBColor[
              0.8710838403783964, 0.8995809281826687, 0.9586362342677135], 
             UndirectedEdge[243, 454] -> 
             RGBColor[
              0.8480931273247609, 0.8819561162935055, 0.9733382129980028], 
             UndirectedEdge[106, 139] -> 
             RGBColor[
              0.9876339509638532, 0.9882129615122903, 0.8040595964219989], 
             UndirectedEdge[220, 499] -> 
             RGBColor[
              0.9915398239914344, 0.9907695140509214, 0.7898705409029994], 
             UndirectedEdge[359, 419] -> 
             RGBColor[
              0.46746193168624306`, 0.5706870892992407, 0.952796520981337], 
             UndirectedEdge[115, 297] -> 
             RGBColor[
              0.876824470159545, 0.9041405675205659, 0.9630056901866306], 
             UndirectedEdge[155, 235] -> 
             RGBColor[
              0.8940268128010727, 0.9146937012748496, 0.8151470731681512], 
             UndirectedEdge[98, 261] -> 
             RGBColor[
              0.9645499716026582, 0.8856164916356951, 0.3902522485675981], 
             UndirectedEdge[386, 421] -> 
             RGBColor[
              0.8663417903717753, 0.8963063629285062, 0.9799281086115871], 
             UndirectedEdge[37, 58] -> 
             RGBColor[
              0.9689540136836887, 0.9750227917342944, 0.8772613782257748], 
             UndirectedEdge[71, 194] -> 
             RGBColor[
              0.992312557896881, 0.9895379247101006, 0.6643132244865018], 
             UndirectedEdge[47, 339] -> 
             RGBColor[
              0.9548609726910067, 0.9657924241186453, 0.9590896771402009], 
             UndirectedEdge[108, 410] -> 
             RGBColor[
              0.976567478172568, 0.9783641520195331, 0.6961999398440872], 
             UndirectedEdge[193, 196] -> 
             RGBColor[
              0.9383831189226433, 0.7929364584953429, 0.5572135598782135], 
             UndirectedEdge[131, 171] -> 
             RGBColor[
              0.9698605911491345, 0.9738813641249533, 0.7487490483654513], 
             UndirectedEdge[203, 258] -> 
             RGBColor[
              0.8916131425940015, 0.9123633412511369, 0.7792816867343308], 
             UndirectedEdge[164, 428] -> 
             RGBColor[
              0.872890005290538, 0.9013720427372534, 0.9780581109509213], 
             UndirectedEdge[143, 325] -> 
             RGBColor[
              0.980975896608437, 0.9477480150598119, 0.5400784300871654], 
             UndirectedEdge[101, 498] -> 
             RGBColor[
              0.9354181057093056, 0.9506446910417523, 0.9695599586704956], 
             UndirectedEdge[35, 391] -> 
             RGBColor[
              0.7349253638509484, 0.43130450609815796`, 0.5651099612138899], 
             UndirectedEdge[8, 221] -> 
             RGBColor[
              0.6357479496378383, 0.5040869785049733, 0.5782812419251446], 
             UndirectedEdge[240, 251] -> 
             RGBColor[
              0.8950972114678623, 0.5738126121896787, 0.5540396392331648], 
             UndirectedEdge[464, 485] -> 
             RGBColor[
              0.791502920572794, 0.7083091765535181, 0.6062740605199103], 
             UndirectedEdge[104, 452] -> 
             RGBColor[
              0.581845399101288, 0.6466807266256543, 0.917833912008501], 
             UndirectedEdge[121, 475] -> 
             RGBColor[
              0.9717779537733425, 0.9767780323828772, 0.8567694381700793], 
             UndirectedEdge[168, 315] -> 
             RGBColor[
              0.7830617640670097, 0.8302382606782432, 0.9529452715989011], 
             UndirectedEdge[65, 320] -> 
             RGBColor[
              0.9124435650250917, 0.932805402608742, 0.9840100660243426], 
             UndirectedEdge[323, 452] -> 
             RGBColor[
              0.5857474029520745, 0.6459528066380462, 0.6829653613654628], 
             UndirectedEdge[72, 322] -> 
             RGBColor[
              0.6957425812857587, 0.755649877135912, 0.8627002528970245], 
             UndirectedEdge[60, 327] -> 
             RGBColor[
              0.9211695452969445, 0.937235810604513, 0.8841434615441588], 
             UndirectedEdge[1, 135] -> 
             RGBColor[
              0.9903366880340303, 0.9898230634126451, 0.7771776542540283], 
             UndirectedEdge[420, 439] -> 
             RGBColor[
              0.9926046376588371, 0.9896369479742377, 0.6578910411034402], 
             UndirectedEdge[134, 367] -> 
             RGBColor[
              0.5778259665807729, 0.6650350593114004, 0.961462941988422], 
             UndirectedEdge[119, 345] -> 
             RGBColor[
              0.9911194247821669, 0.9905956681741224, 0.7968376437588408], 
             UndirectedEdge[64, 366] -> 
             RGBColor[
              0.8191022252703672, 0.8573666702052312, 0.8791229306916057], 
             UndirectedEdge[86, 90] -> 
             RGBColor[
              0.7043961522722602, 0.7638450453286634, 0.8889759089709457], 
             UndirectedEdge[81, 426] -> 
             RGBColor[
              0.7891584561910189, 0.8345537389267926, 0.9364180324323963], 
             UndirectedEdge[70, 265] -> 
             RGBColor[
              0.9749938464285934, 0.9787284467348221, 0.8208900061400837], 
             UndirectedEdge[245, 438] -> 
             RGBColor[
              0.9515565716994097, 0.9418661566317763, 0.6831992840882117], 
             UndirectedEdge[121, 259] -> 
             RGBColor[
              0.947395864979937, 0.9602885027501784, 0.9739292586199427], 
             UndirectedEdge[74, 105] -> 
             RGBColor[
              0.9105574621698336, 0.6941397111283585, 0.5694144449475236], 
             UndirectedEdge[358, 430] -> 
             RGBColor[
              0.9912315666132732, 0.9897739840919946, 0.7318805387511362], 
             UndirectedEdge[43, 316] -> 
             RGBColor[
              0.9614776646792524, 0.9707906859090971, 0.9500924448505739], 
             UndirectedEdge[162, 203] -> 
             RGBColor[
              0.994434753278346, 0.9905048249321657, 0.6356354229486325], 
             UndirectedEdge[226, 236] -> 
             RGBColor[
              0.9381730326614751, 0.9490844858382324, 0.7710986105469461], 
             UndirectedEdge[110, 340] -> 
             RGBColor[
              0.944833852253287, 0.9583777578535537, 0.9782660778862244], 
             UndirectedEdge[145, 407] -> 
             RGBColor[
              0.8508289158806804, 0.8840935832826731, 0.9736234534886825], 
             UndirectedEdge[258, 289] -> 
             RGBColor[
              0.8891977522388765, 0.9125448783665557, 0.9051108925696281], 
             UndirectedEdge[13, 334] -> 
             RGBColor[
              0.9834066718962224, 0.964584282541449, 0.6092180239700399], 
             UndirectedEdge[300, 389] -> 
             RGBColor[
              0.9159005254349094, 0.9113164909490887, 0.6766817843162114], 
             UndirectedEdge[57, 363] -> 
             RGBColor[
              0.9280125620380247, 0.9435955005452166, 0.924018567897079], 
             UndirectedEdge[305, 427] -> 
             RGBColor[
              0.9296989093285062, 0.9315439492270384, 0.69156907182136], 
             UndirectedEdge[277, 419] -> 
             RGBColor[
              0.8254146939698132, 0.8618747740751569, 0.8605603888613398], 
             UndirectedEdge[40, 349] -> 
             RGBColor[
              0.990691355045975, 0.9892523723678444, 0.7191557705720119], 
             UndirectedEdge[28, 241] -> 
             RGBColor[
              0.9828563746976662, 0.9529621422620893, 0.46192388363785486`], 
             UndirectedEdge[164, 396] -> 
             RGBColor[
              0.9567354202731677, 0.9672539277957517, 0.9581198276546461], 
             UndirectedEdge[111, 284] -> 
             RGBColor[
              0.8941707525523398, 0.9176330279516867, 0.9613909639918505], 
             UndirectedEdge[25, 343] -> 
             RGBColor[
              0.8621338521326393, 0.8927956180347822, 0.968196606876883], 
             UndirectedEdge[84, 131] -> 
             RGBColor[
              0.7351012263699963, 0.7872026055927389, 0.7368623216607859], 
             UndirectedEdge[169, 244] -> 
             RGBColor[
              0.9933359253403375, 0.991512248116392, 0.7601044933903842], 
             UndirectedEdge[219, 363] -> 
             RGBColor[
              0.9622190845300564, 0.8888082643259846, 0.5644990621744568], 
             UndirectedEdge[400, 415] -> 
             RGBColor[
              0.8769422608022308, 0.9001999804189704, 0.7215642534357523], 
             UndirectedEdge[248, 286] -> 
             RGBColor[
              0.793770255900979, 0.8389490995217421, 0.9800446347454881], 
             UndirectedEdge[136, 484] -> 
             RGBColor[
              0.9361910981309527, 0.9509330413975967, 0.9582612770365504], 
             UndirectedEdge[74, 263] -> 
             RGBColor[
              0.9071097453407124, 0.691568409562318, 0.5752505302306623], 
             UndirectedEdge[69, 142] -> 
             RGBColor[
              0.9799109865595133, 0.9808928796750922, 0.6933288239837763], 
             UndirectedEdge[109, 409] -> 
             RGBColor[
              0.8512991687650182, 0.8257312743348866, 0.627891920785604], 
             UndirectedEdge[101, 219] -> 
             RGBColor[
              0.949936876317109, 0.880158975879825, 0.6081626175976921], 
             UndirectedEdge[380, 390] -> 
             RGBColor[
              0.8510018585039858, 0.8798234503288702, 0.7100329034323987], 
             UndirectedEdge[53, 293] -> 
             RGBColor[
              0.8217405330534522, 0.8613087188431654, 0.9676465753472456], 
             UndirectedEdge[221, 258] -> 
             RGBColor[
              0.82739949286074, 0.658711732830329, 0.5945529488027335], 
             UndirectedEdge[235, 424] -> 
             RGBColor[
              0.7454140381082245, 0.8010423790174437, 0.975259563094542], 
             UndirectedEdge[367, 457] -> 
             RGBColor[
              0.873796317709553, 0.8996670653088461, 0.865210265944578], 
             UndirectedEdge[58, 220] -> 
             RGBColor[
              0.9684762597582263, 0.9748252282083998, 0.8851789971582128], 
             UndirectedEdge[334, 379] -> 
             RGBColor[
              0.9271374531873491, 0.9427353987785501, 0.9168868769677648], 
             UndirectedEdge[14, 163] -> 
             RGBColor[
              0.6767645324005404, 0.7455288332624963, 0.9698068077176486], 
             UndirectedEdge[284, 442] -> 
             RGBColor[
              0.907576331291601, 0.9250693691192144, 0.7991352758977409], 
             UndirectedEdge[130, 302] -> 
             RGBColor[
              0.7943326578219065, 0.8368057124005304, 0.8553636639360455], 
             UndirectedEdge[65, 428] -> 
             RGBColor[
              0.8716960451892155, 0.9004815892486173, 0.9800791739677928], 
             UndirectedEdge[388, 487] -> 
             RGBColor[
              0.9828087074350709, 0.9862234702932557, 0.8926740161966553], 
             UndirectedEdge[456, 458] -> 
             RGBColor[
              0.8886726514831886, 0.9135046604840091, 0.9696638579279825], 
             UndirectedEdge[281, 465] -> 
             RGBColor[
              0.9900970356212055, 0.9885684638657943, 0.6971568726959774], 
             UndirectedEdge[166, 428] -> 
             RGBColor[
              0.8958120471449379, 0.9171168068703291, 0.8787808427707005], 
             UndirectedEdge[92, 128] -> 
             RGBColor[
              0.9800893906612318, 0.9431083499340827, 0.49540068678358296`], 
             UndirectedEdge[120, 457] -> 
             RGBColor[
              0.9928441917469266, 0.9913089036385396, 0.7682537915989509], 
             UndirectedEdge[79, 329] -> 
             RGBColor[
              0.9724985897141274, 0.9779686045401264, 0.8847977741958504], 
             UndirectedEdge[105, 195] -> 
             RGBColor[
              0.9378176239291707, 0.8243610972615525, 0.5923990492328732], 
             UndirectedEdge[98, 377] -> 
             RGBColor[
              0.9568830156340056, 0.860252664617125, 0.31806888808117634`], 
             UndirectedEdge[21, 309] -> 
             RGBColor[
              0.7306084647341635, 0.7893572840718837, 0.9739126368712641], 
             UndirectedEdge[93, 322] -> 
             RGBColor[
              0.9805534307042258, 0.9836850209961148, 0.8581372422606874], 
             UndirectedEdge[8, 115] -> 
             RGBColor[
              0.6848596339994077, 0.7492710663715274, 0.9467027571969472], 
             UndirectedEdge[54, 131] -> 
             RGBColor[
              0.7065202785145066, 0.7630851923521069, 0.7348648966786103], 
             UndirectedEdge[186, 212] -> 
             RGBColor[
              0.9926187907063133, 0.9888488780447459, 0.5999466981073359], 
             UndirectedEdge[252, 467] -> 
             RGBColor[
              0.8227540179324937, 0.8621772907303975, 0.9716367017938761], 
             UndirectedEdge[244, 378] -> 
             RGBColor[
              0.9158457055320812, 0.932446881572315, 0.8600200971728289], 
             UndirectedEdge[55, 339] -> 
             RGBColor[
              0.9634043861169609, 0.9691318765191432, 0.7677168239054031], 
             UndirectedEdge[69, 490] -> 
             RGBColor[
              0.9651663354381268, 0.9735416905214216, 0.9438484874152128], 
             UndirectedEdge[299, 451] -> 
             RGBColor[
              0.9804954959918962, 0.9836695768149433, 0.8594786138448568], 
             UndirectedEdge[146, 464] -> 
             RGBColor[
              0.9487361242914274, 0.8301096118943954, 0.52799315662305], 
             UndirectedEdge[199, 220] -> 
             RGBColor[
              0.9055358840692573, 0.9248962332842416, 0.8880521520456273], 
             UndirectedEdge[345, 426] -> 
             RGBColor[
              0.9864037793262379, 0.9886454185517836, 0.8749787314356448], 
             UndirectedEdge[66, 472] -> 
             RGBColor[
              0.9005590981021623, 0.9190183607943946, 0.7534513607122114], 
             UndirectedEdge[40, 114] -> 
             RGBColor[
              0.9731012629281988, 0.9789178383466473, 0.9061579292357104], 
             UndirectedEdge[248, 294] -> 
             RGBColor[
              0.8622086518629171, 0.8929657912378484, 0.9867194249890767], 
             UndirectedEdge[304, 483] -> 
             RGBColor[
              0.9570460935491938, 0.9669755380683454, 0.9367529555446341], 
             UndirectedEdge[9, 425] -> 
             RGBColor[
              0.783447641207357, 0.8311676178127734, 0.978940773437397], 
             UndirectedEdge[290, 384] -> 
             RGBColor[
              0.9483876607074372, 0.9595782150475922, 0.9145052882203022], 
             UndirectedEdge[294, 358] -> 
             RGBColor[
              0.9382389684938358, 0.9515729973603504, 0.917318350821716], 
             UndirectedEdge[148, 342] -> 
             RGBColor[
              0.8832938768365293, 0.9097241056951286, 0.9868419882288761], 
             UndirectedEdge[178, 420] -> 
             RGBColor[
              0.9823250941681154, 0.9850829189081456, 0.8585683229742165], 
             UndirectedEdge[193, 354] -> 
             RGBColor[
              0.9886999532189906, 0.989595154505166, 0.8369345489523639], 
             UndirectedEdge[194, 228] -> 
             RGBColor[
              0.9848695689394806, 0.9600182201409575, 0.4472024892509955], 
             UndirectedEdge[326, 491] -> 
             RGBColor[
              0.9234492195319629, 0.7022411529139683, 0.4798274383140439], 
             UndirectedEdge[324, 481] -> 
             RGBColor[
              0.9919040646154045, 0.9850043744158516, 0.5852492715523421], 
             UndirectedEdge[94, 213] -> 
             RGBColor[
              0.8445452235032296, 0.8755933603040751, 0.7745771948776974], 
             UndirectedEdge[92, 175] -> 
             RGBColor[
              0.9143160453838866, 0.8943940599103888, 0.6534942012762754], 
             UndirectedEdge[254, 401] -> 
             RGBColor[
              0.9937466032959937, 0.9915876947011817, 0.746438117795814], 
             UndirectedEdge[161, 491] -> 
             RGBColor[
              0.974534374154251, 0.9790151487104006, 0.8602262173164077], 
             UndirectedEdge[172, 303] -> 
             RGBColor[
              0.9361428371651115, 0.9517374116126122, 0.9874788887117119], 
             UndirectedEdge[57, 274] -> 
             RGBColor[
              0.9162729939558293, 0.9353509122200802, 0.9667635751221639], 
             UndirectedEdge[44, 360] -> 
             RGBColor[
              0.8057145763233089, 0.8485730261889378, 0.9551106424392639], 
             UndirectedEdge[170, 238] -> 
             RGBColor[
              0.8424860094748753, 0.8739729951208598, 0.7734355193588245], 
             UndirectedEdge[5, 11] -> 
             RGBColor[
              0.8529788579460851, 0.8856062041046482, 0.985839079005755], 
             UndirectedEdge[3, 223] -> 
             RGBColor[
              0.9597229526608777, 0.9509833529264964, 0.6857145427238197], 
             UndirectedEdge[65, 227] -> 
             RGBColor[
              0.9483764544021065, 0.9610198247356647, 0.9722693765068913], 
             UndirectedEdge[78, 85] -> 
             RGBColor[
              0.8324993891835448, 0.8696437145638352, 0.9651803653328836], 
             UndirectedEdge[181, 393] -> 
             RGBColor[
              0.7242821984683094, 0.783279846595164, 0.9687420090297055], 
             UndirectedEdge[45, 56] -> 
             RGBColor[
              0.953019004071954, 0.960767110692786, 0.7599376897564547], 
             UndirectedEdge[141, 310] -> 
             RGBColor[
              0.853067271656764, 0.8858763871874494, 0.9755769079800224], 
             UndirectedEdge[39, 236] -> 
             RGBColor[
              0.9727297748782742, 0.9762244307715027, 0.76001802680678], 
             UndirectedEdge[337, 375] -> 
             RGBColor[
              0.9340594849712143, 0.9496251311079844, 0.9716412267520522], 
             UndirectedEdge[57, 334] -> 
             RGBColor[
              0.928435422336503, 0.9437703641456513, 0.9170106784239218], 
             UndirectedEdge[123, 438] -> 
             RGBColor[
              0.969337252891744, 0.9082294954277661, 0.3353814469686902], 
             UndirectedEdge[35, 385] -> 
             RGBColor[
              0.829739446684472, 0.505553227711903, 0.5745125782530918], 
             UndirectedEdge[268, 285] -> 
             RGBColor[
              0.9687637814914776, 0.9734074823412799, 0.7779098781339052], 
             UndirectedEdge[169, 361] -> 
             RGBColor[
              0.9902730403873743, 0.9902456664757889, 0.8108644235531537], 
             UndirectedEdge[337, 361] -> 
             RGBColor[
              0.9482852056050122, 0.9594889380647906, 0.9141662765127215], 
             UndirectedEdge[119, 270] -> 
             RGBColor[
              0.9895845951638221, 0.9899609766836148, 0.8222737425465396], 
             UndirectedEdge[254, 386] -> 
             RGBColor[
              0.9694171475179757, 0.9747932835683002, 0.8480977706363799], 
             UndirectedEdge[253, 488] -> 
             RGBColor[
              0.8953346453110775, 0.9166856218937615, 0.8760926360416899], 
             UndirectedEdge[340, 380] -> 
             RGBColor[
              0.8274584771443377, 0.86589561342465, 0.9742905227039486], 
             UndirectedEdge[388, 490] -> 
             RGBColor[
              0.9708827215487058, 0.9778049619229683, 0.9341721368022793], 
             UndirectedEdge[27, 311] -> 
             RGBColor[
              0.8583120314362263, 0.885779216943942, 0.7303850827920033], 
             UndirectedEdge[222, 417] -> 
             RGBColor[
              0.9378879554257517, 0.9498801665465861, 0.8539985929857735], 
             UndirectedEdge[274, 361] -> 
             RGBColor[
              0.9762338881282921, 0.9810501409968921, 0.8917194917223326], 
             UndirectedEdge[65, 474] -> 
             RGBColor[
              0.7196315474701778, 0.7794329689329894, 0.9664643422806625], 
             UndirectedEdge[243, 326] -> 
             RGBColor[
              0.8003995763768941, 0.6077115729642152, 0.5871983336467528], 
             UndirectedEdge[47, 437] -> 
             RGBColor[
              0.9499270854553743, 0.9618582763637533, 0.9586190785711332], 
             UndirectedEdge[232, 414] -> 
             RGBColor[
              0.9065704318291102, 0.9231288616921907, 0.7067544662838597], 
             UndirectedEdge[102, 196] -> 
             RGBColor[
              0.8737096648325194, 0.7429410386882772, 0.6084235980257249], 
             UndirectedEdge[90, 257] -> 
             RGBColor[
              0.7066774388262245, 0.7634077611088133, 0.7508100553254522], 
             UndirectedEdge[116, 310] -> 
             RGBColor[
              0.876346526240114, 0.9002232934643885, 0.76064769112446], 
             UndirectedEdge[333, 459] -> 
             RGBColor[
              0.9016944098916873, 0.8862708424225737, 0.6551457036447155], 
             UndirectedEdge[68, 257] -> 
             RGBColor[
              0.9740505477485268, 0.9229447244723308, 0.4179204961422367], 
             UndirectedEdge[220, 349] -> 
             RGBColor[
              0.9926273865552457, 0.990052971150668, 0.6870707181744611], 
             UndirectedEdge[92, 204] -> 
             RGBColor[
              0.8859065658355725, 0.8718509824988696, 0.6507553235227865], 
             UndirectedEdge[120, 123] -> 
             RGBColor[
              0.9757259483789078, 0.9329172765205064, 0.5395799382812867], 
             UndirectedEdge[190, 224] -> 
             RGBColor[
              0.9457597561096502, 0.8094848937026312, 0.37059414743152125`], 
             UndirectedEdge[450, 469] -> 
             RGBColor[
              0.9938850363784648, 0.9893290360682241, 0.5758021308560275], 
             UndirectedEdge[405, 434] -> 
             RGBColor[
              0.9799217986095824, 0.9613406099194355, 0.6415310754386376], 
             UndirectedEdge[312, 400] -> 
             RGBColor[
              0.9773553671308713, 0.979116075641265, 0.7079041264100887], 
             UndirectedEdge[100, 259] -> 
             RGBColor[
              0.9563110742940935, 0.9669374512593609, 0.9588381347100621], 
             UndirectedEdge[87, 423] -> 
             RGBColor[
              0.993834924204444, 0.9892218511951116, 0.5703477299703512], 
             UndirectedEdge[403, 449] -> 
             RGBColor[
              0.962230140318876, 0.8751632274614837, 0.4627034864180871], 
             UndirectedEdge[268, 275] -> 
             RGBColor[
              0.6804359595523578, 0.7466469212970656, 0.9640424677431421], 
             UndirectedEdge[166, 210] -> 
             RGBColor[
              0.9388939532751599, 0.9513019964963374, 0.8829343906759363], 
             UndirectedEdge[102, 496] -> 
             RGBColor[
              0.7842418853947768, 0.8316703577046627, 0.9790511781188975], 
             UndirectedEdge[11, 202] -> 
             RGBColor[
              0.9166918924734355, 0.9355781290580791, 0.9631006560530072], 
             UndirectedEdge[187, 494] -> 
             RGBColor[
              0.8369097461549819, 0.8730445208857714, 0.984239681511647], 
             UndirectedEdge[158, 282] -> 
             RGBColor[
              0.9667207940480822, 0.9742248070958706, 0.9198921596503316], 
             UndirectedEdge[232, 372] -> 
             RGBColor[
              0.8792426275360649, 0.8256338361383582, 0.6258191002408862], 
             UndirectedEdge[143, 477] -> 
             RGBColor[
              0.9672753067744702, 0.9391510057159942, 0.6358557411072574], 
             UndirectedEdge[479, 482] -> 
             RGBColor[
              0.8961951817972825, 0.9179751080940344, 0.904166169770322], 
             UndirectedEdge[45, 283] -> 
             RGBColor[
              0.9419602004866242, 0.955638648029134, 0.962468632045091], 
             UndirectedEdge[323, 463] -> 
             RGBColor[
              0.9161926389379944, 0.6467858638724673, 0.3090961424497745], 
             UndirectedEdge[130, 347] -> 
             RGBColor[
              0.9266152338463118, 0.9411935155726812, 0.8679648537843203], 
             UndirectedEdge[338, 369] -> 
             RGBColor[
              0.9941670758616712, 0.9899322900042365, 0.6065003880571096], 
             UndirectedEdge[143, 386] -> 
             RGBColor[
              0.9558326183267852, 0.9306170674073935, 0.6552252279180686], 
             UndirectedEdge[168, 254] -> 
             RGBColor[
              0.7981533415736086, 0.8395748788302677, 0.8388439666770331], 
             UndirectedEdge[86, 115] -> 
             RGBColor[
              0.976414421113922, 0.9811119383857307, 0.8881518015479585], 
             UndirectedEdge[138, 457] -> 
             RGBColor[
              0.990892860423889, 0.9905019779895361, 0.8005924015052696], 
             UndirectedEdge[11, 497] -> 
             RGBColor[
              0.6171581464373583, 0.6947325957300852, 0.96587677775701], 
             UndirectedEdge[154, 379] -> 
             RGBColor[
              0.9166625456419719, 0.9355744971288813, 0.9637832410677731], 
             UndirectedEdge[17, 467] -> 
             RGBColor[
              0.9347771093555821, 0.9505110035316737, 0.9825844017590966], 
             UndirectedEdge[75, 93] -> 
             RGBColor[
              0.9819672833960283, 0.984269685418532, 0.8347060442240423], 
             UndirectedEdge[100, 315] -> 
             RGBColor[
              0.9659918797130796, 0.9741573800899768, 0.9424510562941484], 
             UndirectedEdge[45, 52] -> 
             RGBColor[
              0.9494994794323712, 0.9608929349395845, 0.9332046411373498], 
             UndirectedEdge[8, 203] -> 
             RGBColor[
              0.6999615993710997, 0.7577385869257812, 0.763009979856742], 
             UndirectedEdge[244, 340] -> 
             RGBColor[
              0.9702170791310897, 0.9755451017560961, 0.8563291150537438], 
             UndirectedEdge[104, 190] -> 
             RGBColor[
              0.9415273948838808, 0.8095062126694049, 0.5695053365370557], 
             UndirectedEdge[38, 437] -> 
             RGBColor[
              0.9293548858911486, 0.861547118450688, 0.6296930961288401], 
             UndirectedEdge[96, 465] -> 
             RGBColor[
              0.8316390954871437, 0.868004495320724, 0.918639713970081], 
             UndirectedEdge[48, 346] -> 
             RGBColor[
              0.9934329015479262, 0.9883619653835455, 0.5265900448046228], 
             UndirectedEdge[153, 342] -> 
             RGBColor[
              0.9640276720595562, 0.9716870205111994, 0.9007495410062286], 
             UndirectedEdge[151, 327] -> 
             RGBColor[
              0.9902455393236166, 0.99023429407918, 0.8113201873500907], 
             UndirectedEdge[375, 489] -> 
             RGBColor[
              0.7922446766566855, 0.8378505647775514, 0.9578845568799128], 
             UndirectedEdge[203, 289] -> 
             RGBColor[
              0.9914983687219584, 0.9895720081316777, 0.7047576251800027], 
             UndirectedEdge[6, 79] -> 
             RGBColor[
              0.9777994489001456, 0.9421940900260508, 0.5634110247385002], 
             UndirectedEdge[105, 463] -> 
             RGBColor[
              0.9036670991143017, 0.6411773613071955, 0.5628162255039941], 
             UndirectedEdge[10, 125] -> 
             RGBColor[
              0.8633720672640584, 0.8926436850863859, 0.9149624274202799], 
             UndirectedEdge[32, 331] -> 
             RGBColor[
              0.9409833009501548, 0.9509512292777054, 0.7410418536112015], 
             UndirectedEdge[26, 44] -> 
             RGBColor[
              0.9581431882695632, 0.9096220428332668, 0.6123820193716975], 
             UndirectedEdge[86, 253] -> 
             RGBColor[
              0.8935754638698528, 0.9159581551589141, 0.9052468251384176], 
             UndirectedEdge[370, 466] -> 
             RGBColor[
              0.9755770927183556, 0.9641904296556252, 0.6618136467975158], 
             UndirectedEdge[301, 456] -> 
             RGBColor[
              0.8568333858933361, 0.8886816149882042, 0.9862062191596496], 
             UndirectedEdge[21, 337] -> 
             RGBColor[
              0.8709585677121445, 0.8999427366258839, 0.9875539997739182], 
             UndirectedEdge[61, 172] -> 
             RGBColor[
              0.9578310148751292, 0.9675932027277706, 0.9364713024795017], 
             UndirectedEdge[291, 359] -> 
             RGBColor[
              0.6325127288693926, 0.6991375650372027, 0.8999111484407349], 
             UndirectedEdge[134, 499] -> 
             RGBColor[
              0.6967497798177691, 0.7566255953119208, 0.8665624761641083], 
             UndirectedEdge[140, 244] -> 
             RGBColor[
              0.9950047263627539, 0.9921342975459819, 0.727502157232313], 
             UndirectedEdge[108, 364] -> 
             RGBColor[
              0.993290596706919, 0.9880575897178578, 0.5111010410646846], 
             UndirectedEdge[113, 421] -> 
             RGBColor[
              0.8909167313984774, 0.9132022885204015, 0.8742001299048678], 
             UndirectedEdge[54, 55] -> 
             RGBColor[
              0.7066129374960752, 0.7632833805444219, 0.7449502549974008], 
             UndirectedEdge[56, 210] -> 
             RGBColor[
              0.9394581876528569, 0.9499540837787537, 0.7586442469805176], 
             UndirectedEdge[36, 58] -> 
             RGBColor[
              0.8599243071067598, 0.8912581665407409, 0.9775264132241722], 
             UndirectedEdge[25, 288] -> 
             RGBColor[
              0.867738999439328, 0.8969759277185243, 0.958708554543209], 
             UndirectedEdge[262, 344] -> 
             RGBColor[
              0.9253502473497317, 0.8624249272578252, 0.6302227366387871], 
             UndirectedEdge[8, 439] -> 
             RGBColor[
              0.6997340945066937, 0.757251977025087, 0.7382474793634197], 
             UndirectedEdge[102, 186] -> 
             RGBColor[
              0.9245330892551107, 0.9374424062631168, 0.7077065056410186], 
             UndirectedEdge[85, 145] -> 
             RGBColor[
              0.9526624986178414, 0.9642163494940065, 0.9650142216290158], 
             UndirectedEdge[421, 423] -> 
             RGBColor[
              0.8913308814373403, 0.911956914243461, 0.764362112366584], 
             UndirectedEdge[406, 476] -> 
             RGBColor[
              0.9296788091775925, 0.9465577242844802, 0.9859800849164737], 
             UndirectedEdge[111, 400] -> 
             RGBColor[
              0.9801588220019739, 0.9812068876938973, 0.7031586085714455], 
             UndirectedEdge[137, 183] -> 
             RGBColor[
              0.8978494834421448, 0.9212026202447986, 0.983801799077602], 
             UndirectedEdge[85, 358] -> 
             RGBColor[
              0.9722705370093911, 0.9781762181078055, 0.9020977573030114], 
             UndirectedEdge[399, 412] -> 
             RGBColor[
              0.9561957711916356, 0.8571129835245923, 0.31967716863540974`], 
             UndirectedEdge[283, 292] -> 
             RGBColor[
              0.9793920468747973, 0.9836094947138072, 0.8955092729133445], 
             UndirectedEdge[240, 310] -> 
             RGBColor[
              0.790670772135302, 0.49186953960685414`, 0.5727803079471008], 
             UndirectedEdge[186, 300] -> 
             RGBColor[
              0.9233793528839394, 0.9365224481980844, 0.7075964612359837], 
             UndirectedEdge[37, 240] -> 
             RGBColor[
              0.9072638593429799, 0.5815427352329707, 0.4732691200461657], 
             UndirectedEdge[36, 429] -> 
             RGBColor[
              0.880743569139121, 0.9062743757472764, 0.9194118525049068], 
             UndirectedEdge[56, 276] -> 
             RGBColor[
              0.9915006598113155, 0.9891720805230452, 0.6755802728560039], 
             UndirectedEdge[95, 174] -> 
             RGBColor[
              0.9927882597553113, 0.9907721876543145, 0.7318484003580525], 
             UndirectedEdge[7, 28] -> 
             RGBColor[
              0.9437164972062214, 0.9260499280726695, 0.6683804674317925], 
             UndirectedEdge[251, 367] -> 
             RGBColor[
              0.8609271168047831, 0.8916464185330037, 0.9576239069818739], 
             UndirectedEdge[31, 314] -> 
             RGBColor[
              0.9402805927890706, 0.9500661202196625, 0.7146464084730919], 
             UndirectedEdge[238, 436] -> 
             RGBColor[
              0.9153906894734584, 0.9310632904127151, 0.7806657257133343], 
             UndirectedEdge[291, 488] -> 
             RGBColor[
              0.9899518666891255, 0.9901128528977754, 0.8161871029040236], 
             UndirectedEdge[96, 171] -> 
             RGBColor[
              0.8114194495757061, 0.853353326002483, 0.9720603092958164], 
             UndirectedEdge[127, 179] -> 
             RGBColor[
              0.9662460043620518, 0.9731480455325456, 0.8883334756971353], 
             UndirectedEdge[296, 453] -> 
             RGBColor[
              0.993467356094798, 0.9884356601754153, 0.5303402096028049], 
             UndirectedEdge[14, 494] -> 
             RGBColor[
              0.81943663058479, 0.8591119328251874, 0.9825730801501278], 
             UndirectedEdge[317, 420] -> 
             RGBColor[
              0.9905540904438588, 0.9903618878968021, 0.8062066967829744], 
             UndirectedEdge[7, 388] -> 
             RGBColor[
              0.947097413760853, 0.9595484910623286, 0.9564949308566808], 
             UndirectedEdge[146, 271] -> 
             RGBColor[
              0.9712546054422893, 0.9770809542495144, 0.8886997739974696], 
             UndirectedEdge[331, 449] -> 
             RGBColor[
              0.9093087708365091, 0.8367434254146449, 0.6258061635565195], 
             UndirectedEdge[27, 359] -> 
             RGBColor[
              0.5006538280653744, 0.5966168510183739, 0.9561047790165018], 
             UndirectedEdge[100, 471] -> 
             RGBColor[
              0.9746926211913953, 0.9806463788383479, 0.927722970488176], 
             UndirectedEdge[219, 337] -> 
             RGBColor[
              0.922530833924581, 0.8590024730687467, 0.6296908541899304], 
             UndirectedEdge[199, 419] -> 
             RGBColor[
              0.7384559216971772, 0.7956066455934903, 0.9745660430779834], 
             UndirectedEdge[266, 437] -> 
             RGBColor[
              0.764145707865614, 0.8159378574928935, 0.9772968882131029], 
             UndirectedEdge[327, 399] -> 
             RGBColor[
              0.9856765008861561, 0.9665278202798862, 0.5785469502107986], 
             UndirectedEdge[311, 419] -> 
             RGBColor[
              0.8251201350570948, 0.8598494552248088, 0.7270768247568384], 
             UndirectedEdge[267, 329] -> 
             RGBColor[
              0.7043413187607015, 0.7666746507465323, 0.9560066836822909], 
             UndirectedEdge[219, 244] -> 
             RGBColor[
              0.9659890690918504, 0.8903672498264703, 0.5020206615782334], 
             UndirectedEdge[17, 205] -> 
             RGBColor[
              0.7290230474332586, 0.7874372936601943, 0.9745162570917631], 
             UndirectedEdge[175, 361] -> 
             RGBColor[
              0.9259450553629001, 0.9416755086689543, 0.9120354530393413], 
             UndirectedEdge[189, 266] -> 
             RGBColor[
              0.7986224760627137, 0.8406181240857399, 0.8694859663218997], 
             UndirectedEdge[225, 280] -> 
             RGBColor[
              0.9903896833359592, 0.989477619245307, 0.7495962573972579], 
             UndirectedEdge[300, 458] -> 
             RGBColor[
              0.9059092345388068, 0.9272467290111841, 0.9713084067697986], 
             UndirectedEdge[171, 343] -> 
             RGBColor[
              0.9513082445204518, 0.9632063490055609, 0.9673066205698593], 
             UndirectedEdge[358, 408] -> 
             RGBColor[
              0.769375410142421, 0.8176972149465036, 0.9015955390968122], 
             UndirectedEdge[380, 411] -> 
             RGBColor[
              0.851882261726965, 0.882402385337725, 0.8564396951214366], 
             UndirectedEdge[345, 498] -> 
             RGBColor[
              0.9483755440687869, 0.9595732045061269, 0.914706092279592], 
             UndirectedEdge[161, 450] -> 
             RGBColor[
              0.9744096617597193, 0.9770387645729595, 0.7223794854127258], 
             UndirectedEdge[94, 214] -> 
             RGBColor[
              0.9915529744746954, 0.9895943795531861, 0.7038374409710368], 
             UndirectedEdge[157, 343] -> 
             RGBColor[
              0.888015497945734, 0.9130145564517655, 0.9707762474538009], 
             UndirectedEdge[155, 332] -> 
             RGBColor[
              0.9933030868255784, 0.9877968343862062, 0.5369049239697303], 
             UndirectedEdge[127, 168] -> 
             RGBColor[
              0.7962711041766111, 0.8388909045991308, 0.876897890488387], 
             UndirectedEdge[378, 380] -> 
             RGBColor[
              0.7730871035453293, 0.8227973932408692, 0.9779815048230338], 
             UndirectedEdge[160, 481] -> 
             RGBColor[
              0.8522934779782272, 0.8776075584483085, 0.694157177342653], 
             UndirectedEdge[23, 485] -> 
             RGBColor[
              0.8177080986056746, 0.8580300514068346, 0.9607400617176158], 
             UndirectedEdge[352, 399] -> 
             RGBColor[
              0.9862526604771555, 0.9649052600971726, 0.4337367440555412], 
             UndirectedEdge[389, 456] -> 
             RGBColor[
              0.8986639423792913, 0.8975744224219138, 0.6750372354743952], 
             UndirectedEdge[105, 263] -> 
             RGBColor[
              0.9640690094276422, 0.9727233065795087, 0.9457059741225033], 
             UndirectedEdge[143, 347] -> 
             RGBColor[
              0.9136288615247923, 0.8971702733454974, 0.6583189246863381], 
             UndirectedEdge[98, 484] -> 
             RGBColor[
              0.955605468472382, 0.8821611114936578, 0.5968405199145284], 
             UndirectedEdge[100, 500] -> 
             RGBColor[
              0.9589849119612079, 0.9689315950134875, 0.9543120249881897], 
             UndirectedEdge[89, 424] -> 
             RGBColor[
              0.8457040217427754, 0.8766012049154427, 0.7829090384899381], 
             UndirectedEdge[231, 442] -> 
             RGBColor[
              0.9901815438793986, 0.989317258201844, 0.7476455659601378], 
             UndirectedEdge[15, 104] -> 
             RGBColor[
              0.9646347993609504, 0.9730502753294044, 0.9404941039596144], 
             UndirectedEdge[75, 182] -> 
             RGBColor[
              0.9879103548806876, 0.9695250344493428, 0.5558578738506609], 
             UndirectedEdge[290, 316] -> 
             RGBColor[
              0.924179224710064, 0.9422627519944966, 0.9885844526325881], 
             UndirectedEdge[344, 424] -> 
             RGBColor[
              0.8050652803090932, 0.8483924760773365, 0.9810059897496326], 
             UndirectedEdge[369, 425] -> 
             RGBColor[
              0.9325924217305039, 0.9449103230962376, 0.7929126197794822], 
             UndirectedEdge[106, 255] -> 
             RGBColor[
              0.9383589532853683, 0.9500734340951732, 0.83926622661985], 
             UndirectedEdge[84, 242] -> 
             RGBColor[
              0.7133083775421108, 0.7741108292390164, 0.9609052188301117], 
             UndirectedEdge[143, 446] -> 
             RGBColor[
              0.9813359298371418, 0.9473674842580952, 0.4956289536878903], 
             UndirectedEdge[376, 415] -> 
             RGBColor[
              0.8474047146211663, 0.8816382356224832, 0.9851809101594903], 
             UndirectedEdge[93, 108] -> 
             RGBColor[
              0.9807692635725045, 0.9814978366910136, 0.6890874131631398], 
             UndirectedEdge[78, 183] -> 
             RGBColor[
              0.8257048371884332, 0.8645763488109387, 0.9766817695576324], 
             UndirectedEdge[17, 298] -> 
             RGBColor[
              0.7893390157455006, 0.8361773277644098, 0.9794198794906475], 
             UndirectedEdge[204, 370] -> 
             RGBColor[
              0.8875971015097084, 0.912466045593016, 0.9595143357832461], 
             UndirectedEdge[208, 314] -> 
             RGBColor[
              0.9387174619203519, 0.951700265797597, 0.9063227419869739], 
             UndirectedEdge[313, 379] -> 
             RGBColor[
              0.9295964420263197, 0.943752253856595, 0.8761350682468989], 
             UndirectedEdge[3, 221] -> 
             RGBColor[
              0.9018172942989571, 0.7177394052816654, 0.5995271034705317], 
             UndirectedEdge[154, 229] -> 
             RGBColor[
              0.9786316813628322, 0.9826024071630497, 0.8770919073425854], 
             UndirectedEdge[25, 180] -> 
             RGBColor[
              0.8812763764031165, 0.9047329634538606, 0.8138762288276056], 
             UndirectedEdge[371, 419] -> 
             RGBColor[
              0.82619031448501, 0.8621384608093818, 0.8435592511035515], 
             UndirectedEdge[31, 419] -> 
             RGBColor[
              0.8249016146837671, 0.85938206224206, 0.7032922306715519], 
             UndirectedEdge[321, 482] -> 
             RGBColor[
              0.8978050975420073, 0.9186408496274256, 0.8774856995518389], 
             UndirectedEdge[212, 300] -> 
             RGBColor[
              0.9234596850926068, 0.9389224841017697, 0.8783077206990457], 
             UndirectedEdge[376, 414] -> 
             RGBColor[
              0.9631782459788722, 0.9682663961170297, 0.7121537701318562], 
             UndirectedEdge[140, 274] -> 
             RGBColor[
              0.9794951737187645, 0.9823307237203598, 0.8327255650536212], 
             UndirectedEdge[1, 131] -> 
             RGBColor[
              0.9940751150662643, 0.9897355951615239, 0.5964910229933159], 
             UndirectedEdge[360, 466] -> 
             RGBColor[
              0.8145844526821598, 0.8380725788549388, 0.675684111295351], 
             UndirectedEdge[165, 182] -> 
             RGBColor[
              0.9855067193222411, 0.9685310693753089, 0.5956923354635452], 
             UndirectedEdge[268, 480] -> 
             RGBColor[
              0.7210267656392, 0.7805803216863452, 0.9669671600869278], 
             UndirectedEdge[54, 385] -> 
             RGBColor[
              0.6309059212040603, 0.7074413070932312, 0.96638399275434], 
             UndirectedEdge[149, 158] -> 
             RGBColor[
              0.9900515771451555, 0.9882241324942359, 0.6742474157120888], 
             UndirectedEdge[229, 379] -> 
             RGBColor[
              0.9281319648969453, 0.9431466549282532, 0.9004052442259547], 
             UndirectedEdge[98, 253] -> 
             RGBColor[
              0.8669104738646458, 0.8126399051893997, 0.6238482872625186], 
             UndirectedEdge[121, 469] -> 
             RGBColor[
              0.9719415769939553, 0.9763602235729222, 0.8187691454088333], 
             UndirectedEdge[34, 269] -> 
             RGBColor[
              0.9922529175386902, 0.9898671653302535, 0.6910266637286037], 
             UndirectedEdge[145, 286] -> 
             RGBColor[
              0.8501925341403481, 0.883596437030445, 0.9735600249041317], 
             UndirectedEdge[34, 234] -> 
             RGBColor[
              0.9308525599757529, 0.9452180011576119, 0.8964100012690592], 
             UndirectedEdge[85, 286] -> 
             RGBColor[
              0.8538837503939773, 0.8863493400685898, 0.9673117586101223], 
             UndirectedEdge[86, 261] -> 
             RGBColor[
              0.9912149616078649, 0.9889347416052096, 0.6716507864434971], 
             UndirectedEdge[140, 255] -> 
             RGBColor[
              0.9384936520730653, 0.9503615411819205, 0.8539273583961067], 
             UndirectedEdge[345, 448] -> 
             RGBColor[
              0.9908709072884938, 0.9886320828236623, 0.6656944710924892], 
             UndirectedEdge[146, 444] -> 
             RGBColor[
              0.9680263504834278, 0.9746733269869778, 0.8941643675790814], 
             UndirectedEdge[215, 224] -> 
             RGBColor[
              0.9934109568100042, 0.9883150278080841, 0.5242014955090566], 
             UndirectedEdge[40, 359] -> 
             RGBColor[
              0.6326058625490526, 0.6991760782071685, 0.8983676823465316], 
             UndirectedEdge[88, 495] -> 
             RGBColor[
              0.7321360926613413, 0.7842405689680919, 0.6911569676061007], 
             UndirectedEdge[341, 403] -> 
             RGBColor[
              0.994482003125633, 0.9906058875778201, 0.6407782772335601], 
             UndirectedEdge[134, 416] -> 
             RGBColor[
              0.403091343142159, 0.5235591942949139, 0.9469056018387072], 
             UndirectedEdge[113, 423] -> 
             RGBColor[
              0.993225728740114, 0.9900500430290953, 0.6589562566273683], 
             UndirectedEdge[204, 362] -> 
             RGBColor[
              0.9004797795416396, 0.9197348079369443, 0.8157902445864481], 
             UndirectedEdge[231, 256] -> 
             RGBColor[
              0.9855943996605592, 0.9749217360782956, 0.6381606809831374], 
             UndirectedEdge[183, 407] -> 
             RGBColor[
              0.8477255801391979, 0.8817791205679212, 0.9788765914194218], 
             UndirectedEdge[231, 271] -> 
             RGBColor[
              0.9692016476253692, 0.9762320034336085, 0.9227225979083558], 
             UndirectedEdge[106, 140] -> 
             RGBColor[
              0.9950684282125661, 0.991860191542099, 0.7046070289501145], 
             UndirectedEdge[96, 147] -> 
             RGBColor[
              0.6397522411164471, 0.7178956222399984, 0.9651404282508356], 
             UndirectedEdge[149, 275] -> 
             RGBColor[
              0.7051359258172475, 0.7616673812601568, 0.7160800538419481], 
             UndirectedEdge[207, 287] -> 
             RGBColor[
              0.9928789033096079, 0.9899733178403245, 0.6695521495769639], 
             UndirectedEdge[223, 480] -> 
             RGBColor[
              0.7398531915522819, 0.7761223676745045, 0.6677507598626844], 
             UndirectedEdge[11, 102] -> 
             RGBColor[
              0.8609913226973953, 0.8919951260047814, 0.9866033150465467], 
             UndirectedEdge[230, 339] -> 
             RGBColor[
              0.8662691661834705, 0.8963706880323747, 0.9870623632309714], 
             UndirectedEdge[103, 449] -> 
             RGBColor[
              0.9613727712752291, 0.8733294017704305, 0.36938415708553224`], 
             UndirectedEdge[226, 396] -> 
             RGBColor[
              0.9248300005080721, 0.9420913348058197, 0.9647124140597219], 
             UndirectedEdge[144, 279] -> 
             RGBColor[
              0.9711160715076083, 0.9770045552056903, 0.8901397787610213], 
             UndirectedEdge[205, 228] -> 
             RGBColor[
              0.756406424364777, 0.783102982419583, 0.6594575827123853], 
             UndirectedEdge[267, 406] -> 
             RGBColor[
              0.698935038849782, 0.7626426560409394, 0.9651581053878513], 
             UndirectedEdge[209, 233] -> 
             RGBColor[
              0.8802380302581241, 0.9045192031018214, 0.8576823250484545], 
             UndirectedEdge[387, 405] -> 
             RGBColor[
              0.9452645825296102, 0.9579950394675817, 0.9531303563272657], 
             UndirectedEdge[75, 206] -> 
             RGBColor[
              0.9727958387863243, 0.9774296370454769, 0.8502309076524168], 
             UndirectedEdge[183, 404] -> 
             RGBColor[
              0.8902809355679866, 0.6241832014875223, 0.5827983844656581], 
             UndirectedEdge[319, 488] -> 
             RGBColor[
              0.9079444824699802, 0.9265629332192776, 0.877342458176689], 
             UndirectedEdge[220, 371] -> 
             RGBColor[
              0.9932702768570902, 0.9914280485001332, 0.7570453600711953], 
             UndirectedEdge[66, 460] -> 
             RGBColor[
              0.7991733189860557, 0.8392415684013741, 0.7437382454623868], 
             UndirectedEdge[87, 446] -> 
             RGBColor[
              0.9943491446492355, 0.9903217167308586, 0.6263174519851761], 
             UndirectedEdge[273, 308] -> 
             RGBColor[
              0.9785779417692696, 0.946579419415203, 0.5785954704311704], 
             UndirectedEdge[326, 428] -> 
             RGBColor[
              0.8264508420844483, 0.6280630197319091, 0.5897948803495623], 
             UndirectedEdge[130, 315] -> 
             RGBColor[
              0.9794828640118348, 0.9825934089286079, 0.846820000995208], 
             UndirectedEdge[95, 407] -> 
             RGBColor[
              0.8717882014586664, 0.8986122273335322, 0.8883133263678076], 
             UndirectedEdge[148, 153] -> 
             RGBColor[
              0.9095102026470807, 0.9282707418324697, 0.8974381804465335], 
             UndirectedEdge[85, 137] -> 
             RGBColor[
              0.9046440354372565, 0.9262699859976951, 0.9723003948528532], 
             UndirectedEdge[289, 359] -> 
             RGBColor[
              0.6334210397519809, 0.6995131749296779, 0.8848580864830341], 
             UndirectedEdge[32, 449] -> 
             RGBColor[
              0.9614481447609593, 0.8734906180349788, 0.3775880958560267], 
             UndirectedEdge[329, 406] -> 
             RGBColor[
              0.9491301369721972, 0.9615819199623963, 0.9709935885076242], 
             UndirectedEdge[168, 213] -> 
             RGBColor[
              0.6481555077443875, 0.7244317627816668, 0.965997510691952], 
             UndirectedEdge[111, 464] -> 
             RGBColor[
              0.9373457198068313, 0.8226160249522436, 0.5921170006980196], 
             UndirectedEdge[50, 117] -> 
             RGBColor[
              0.7017427210970368, 0.7669260142540015, 0.9709068143465274], 
             UndirectedEdge[357, 420] -> 
             RGBColor[
              0.991452499066011, 0.9907334029501105, 0.7913177409069293], 
             UndirectedEdge[153, 190] -> 
             RGBColor[
              0.9442674947176467, 0.8106393143680208, 0.5240947911404977], 
             UndirectedEdge[165, 275] -> 
             RGBColor[
              0.7037294935250052, 0.763015738603203, 0.8796755035476311], 
             UndirectedEdge[152, 301] -> 
             RGBColor[
              0.9445505012139483, 0.9551764754487309, 0.8533188815024207], 
             UndirectedEdge[208, 349] -> 
             RGBColor[
              0.9917211457628563, 0.9896782172936889, 0.7020894733803454], 
             UndirectedEdge[5, 23] -> 
             RGBColor[
              0.9000830338584587, 0.9225478226439785, 0.9689064150646498], 
             UndirectedEdge[56, 227] -> 
             RGBColor[
              0.973056690735526, 0.9763071296397928, 0.7466809016143803], 
             UndirectedEdge[56, 326] -> 
             RGBColor[
              0.9235236375210905, 0.7006906885320042, 0.36365481978140196`], 
             UndirectedEdge[155, 181] -> 
             RGBColor[
              0.9682497035767113, 0.973502143591789, 0.816712071798504], 
             UndirectedEdge[148, 323] -> 
             RGBColor[
              0.9106721066641014, 0.9264097201462457, 0.7079801752000533], 
             UndirectedEdge[177, 438] -> 
             RGBColor[
              0.8892645888578855, 0.8923633732798171, 0.677213461917214], 
             UndirectedEdge[53, 90] -> 
             RGBColor[
              0.6860393157077643, 0.7509731026910726, 0.956705855833599], 
             UndirectedEdge[30, 217] -> 
             RGBColor[
              0.9273113794169527, 0.940263025352454, 0.7570379405904462], 
             UndirectedEdge[43, 290] -> 
             RGBColor[
              0.945432711212038, 0.9581135674282786, 0.9526078437818049], 
             UndirectedEdge[114, 397] -> 
             RGBColor[
              0.9768682884798543, 0.9804756002203977, 0.8437285670951531], 
             UndirectedEdge[227, 320] -> 
             RGBColor[
              0.91673141513476, 0.9360032741998225, 0.9767518542390904], 
             UndirectedEdge[298, 432] -> 
             RGBColor[
              0.8260001011000964, 0.8621214247421385, 0.8510658906987326], 
             UndirectedEdge[42, 85] -> 
             RGBColor[0.952229882155853, 0.963893704845, 0.965746528454718], 
             UndirectedEdge[329, 413] -> 
             RGBColor[
              0.9230933760900439, 0.9410278525514726, 0.9756848829199908], 
             UndirectedEdge[244, 380] -> 
             RGBColor[
              0.8520477237384929, 0.8824708081316716, 0.8536975613884599], 
             UndirectedEdge[87, 113] -> 
             RGBColor[
              0.9934207741655812, 0.9904672254720521, 0.680185747508635], 
             UndirectedEdge[334, 370] -> 
             RGBColor[
              0.9784578422040883, 0.9828032072580442, 0.8921843555214843], 
             UndirectedEdge[24, 278] -> 
             RGBColor[
              0.822870138040497, 0.8614809158691379, 0.9325840585539349], 
             UndirectedEdge[51, 325] -> 
             RGBColor[
              0.9665405909265838, 0.972945739892878, 0.8689364452191886], 
             UndirectedEdge[112, 463] -> 
             RGBColor[
              0.7289207884056532, 0.5039194751514936, 0.574417415039964], 
             UndirectedEdge[308, 421] -> 
             RGBColor[
              0.8891469101277714, 0.9124704219426325, 0.9035306485110954], 
             UndirectedEdge[302, 421] -> 
             RGBColor[
              0.691855457545377, 0.7584717656944593, 0.9704206155315818], 
             UndirectedEdge[103, 488] -> 
             RGBColor[
              0.9928046523398694, 0.9892996848511737, 0.6240485796235328], 
             UndirectedEdge[225, 424] -> 
             RGBColor[
              0.8458396022879608, 0.8768911979922986, 0.7976661441272425], 
             UndirectedEdge[205, 388] -> 
             RGBColor[
              0.7575593745276372, 0.8090860916184113, 0.9389168174213915], 
             UndirectedEdge[114, 297] -> 
             RGBColor[
              0.8743445069404056, 0.9022910150122988, 0.9672036210386357], 
             UndirectedEdge[203, 381] -> 
             RGBColor[
              0.9919757920794071, 0.9897694349592032, 0.6968454846150347], 
             UndirectedEdge[17, 252] -> 
             RGBColor[
              0.8094653206159537, 0.85190015009479, 0.9814258814691218], 
             UndirectedEdge[361, 363] -> 
             RGBColor[
              0.9879734562104876, 0.9892947293220286, 0.8489744844972478], 
             UndirectedEdge[318, 383] -> 
             RGBColor[
              0.9794258798814002, 0.9663202673356133, 0.6537265397224887], 
             UndirectedEdge[209, 273] -> 
             RGBColor[
              0.9812746591565753, 0.9476945813573296, 0.5339038844426299], 
             UndirectedEdge[47, 230] -> 
             RGBColor[
              0.8878952925935291, 0.912562961438921, 0.9526580735526715], 
             UndirectedEdge[1, 170] -> 
             RGBColor[
              0.8429186737422217, 0.8748984202396463, 0.8205283547651454], 
             UndirectedEdge[139, 247] -> 
             RGBColor[
              0.987603785206582, 0.9881484400077132, 0.800776239904506], 
             UndirectedEdge[246, 288] -> 
             RGBColor[
              0.9809664331553725, 0.9828954947966153, 0.7879841596175379], 
             UndirectedEdge[1, 147] -> 
             RGBColor[
              0.7988798897663032, 0.8398920295824351, 0.8165512259590622], 
             UndirectedEdge[352, 457] -> 
             RGBColor[
              0.9934051492860054, 0.9896800570166819, 0.6236955227856682], 
             UndirectedEdge[157, 238] -> 
             RGBColor[
              0.906821687383498, 0.9242325156723379, 0.7798478984816634], 
             UndirectedEdge[97, 145] -> 
             RGBColor[
              0.9597469104767968, 0.9694998922587557, 0.9530221602623399], 
             UndirectedEdge[83, 237] -> 
             RGBColor[
              0.8483275412742155, 0.8804979330539005, 0.8956492618777538], 
             UndirectedEdge[73, 494] -> 
             RGBColor[
              0.7955533746126293, 0.8402116097677561, 0.9802569835785615], 
             UndirectedEdge[101, 197] -> 
             RGBColor[
              0.756632700656646, 0.8088574973896869, 0.9528907923498899], 
             UndirectedEdge[224, 356] -> 
             RGBColor[
              0.9916268703541001, 0.9890340008585217, 0.6596579468100738], 
             UndirectedEdge[182, 441] -> 
             RGBColor[
              0.9234723543343322, 0.7159969522867111, 0.2949378306326797], 
             UndirectedEdge[160, 480] -> 
             RGBColor[
              0.606435032121784, 0.6902657868309507, 0.9629150984312285], 
             UndirectedEdge[263, 440] -> 
             RGBColor[
              0.9007984883822558, 0.9230936020816709, 0.968118132490446], 
             UndirectedEdge[31, 223] -> 
             RGBColor[
              0.9869681217332893, 0.9676189499811015, 0.41098329165964226`], 
             UndirectedEdge[5, 102] -> 
             RGBColor[
              0.8485152552612653, 0.8820470484850401, 0.9854133365969717], 
             UndirectedEdge[171, 216] -> 
             RGBColor[
              0.970477061907727, 0.975199932742828, 0.8158480860217285], 
             UndirectedEdge[102, 414] -> 
             RGBColor[
              0.9245400894004814, 0.9374573788662414, 0.7084684282647198], 
             UndirectedEdge[68, 205] -> 
             RGBColor[
              0.745488595661228, 0.745818147472487, 0.6194210016269217], 
             UndirectedEdge[111, 376] -> 
             RGBColor[
              0.9506212758209094, 0.96264514289741, 0.9667752652951837], 
             UndirectedEdge[302, 325] -> 
             RGBColor[
              0.7943186421031003, 0.8367999165406164, 0.8555959406681822], 
             UndirectedEdge[39, 315] -> 
             RGBColor[
              0.9583843063866984, 0.9684836643594197, 0.9553286935628125], 
             UndirectedEdge[66, 314] -> 
             RGBColor[
              0.9406725062482657, 0.9509043834803517, 0.7573037698969596], 
             UndirectedEdge[274, 370] -> 
             RGBColor[
              0.9662954138234146, 0.974383755332473, 0.9419372522197262], 
             UndirectedEdge[94, 477] -> 
             RGBColor[
              0.9802302949100066, 0.9819806972152214, 0.7602066249946781], 
             UndirectedEdge[99, 329] -> 
             RGBColor[
              0.9094102507961339, 0.9301172998606504, 0.9743797742143875], 
             UndirectedEdge[25, 465] -> 
             RGBColor[
              0.8773778278320574, 0.9037359406558114, 0.9231985233574664], 
             UndirectedEdge[223, 381] -> 
             RGBColor[
              0.9856678007080664, 0.9693617741832264, 0.5983041859367253], 
             UndirectedEdge[196, 318] -> 
             RGBColor[
              0.9363392292786001, 0.7738355065375633, 0.3072076999919595], 
             UndirectedEdge[76, 462] -> 
             RGBColor[
              0.9534941648193581, 0.9626318399327567, 0.8707802035604362], 
             UndirectedEdge[89, 440] -> 
             RGBColor[
              0.917520156881906, 0.9328741834773209, 0.7900219750186795], 
             UndirectedEdge[88, 326] -> 
             RGBColor[
              0.9230753284356454, 0.6997318007292387, 0.3148591424736793], 
             UndirectedEdge[149, 282] -> 
             RGBColor[
              0.9697140739409443, 0.9735326520158039, 0.7299985385724286], 
             UndirectedEdge[238, 462] -> 
             RGBColor[
              0.9939211935070924, 0.9905588412180708, 0.6635099201471054], 
             UndirectedEdge[168, 261] -> 
             RGBColor[
              0.797222497040349, 0.8375838964964444, 0.737527283738295], 
             UndirectedEdge[155, 344] -> 
             RGBColor[
              0.9536780550019412, 0.9620437983347424, 0.8208934998232418], 
             UndirectedEdge[4, 496] -> 
             RGBColor[
              0.7818635049054729, 0.8297739016619102, 0.9788243260646223], 
             UndirectedEdge[87, 226] -> 
             RGBColor[
              0.9383478272974015, 0.9494583538900304, 0.790123927960085], 
             UndirectedEdge[128, 362] -> 
             RGBColor[
              0.994662604367299, 0.9909921753721573, 0.6604356078472446], 
             UndirectedEdge[295, 389] -> 
             RGBColor[
              0.9241765604518419, 0.9179155766246048, 0.6774711599242301], 
             UndirectedEdge[89, 133] -> 
             RGBColor[
              0.9353936536832348, 0.9471260246635542, 0.7917267650994493], 
             UndirectedEdge[33, 164] -> 
             RGBColor[
              0.8575476771219163, 0.8893864993659133, 0.9765289310612815], 
             UndirectedEdge[276, 396] -> 
             RGBColor[
              0.9782732793573031, 0.9824262967814485, 0.8817820501278888], 
             UndirectedEdge[50, 274] -> 
             RGBColor[
              0.829692980155464, 0.8673197191190938, 0.9582387045489108], 
             UndirectedEdge[21, 375] -> 
             RGBColor[
              0.8971281972926528, 0.9201771247861981, 0.9681186875643214], 
             UndirectedEdge[41, 485] -> 
             RGBColor[
              0.7462403558219136, 0.8016879046956249, 0.9753419227218644], 
             UndirectedEdge[30, 316] -> 
             RGBColor[
              0.9007030471695625, 0.923543485267564, 0.986345273861344], 
             UndirectedEdge[285, 324] -> 
             RGBColor[
              0.9937826346112388, 0.9904897634534285, 0.6649499106878949], 
             UndirectedEdge[95, 358] -> 
             RGBColor[
              0.9895386063337479, 0.9899419591205201, 0.823035896476146], 
             UndirectedEdge[333, 492] -> 
             RGBColor[
              0.9552872379744174, 0.9287994052829244, 0.6531533019619122], 
             UndirectedEdge[332, 393] -> 
             RGBColor[
              0.7493355817171765, 0.7975745373895813, 0.6889348612009318], 
             UndirectedEdge[418, 420] -> 
             RGBColor[
              0.992670325455147, 0.9897774475284895, 0.6650407523536773], 
             UndirectedEdge[107, 273] -> 
             RGBColor[
              0.9295881912295214, 0.9097417825985334, 0.6596145458399939], 
             UndirectedEdge[310, 483] -> 
             RGBColor[
              0.8725823266088675, 0.9001185740549185, 0.928566124299232], 
             UndirectedEdge[155, 403] -> 
             RGBColor[
              0.9946278146319321, 0.9909177636459892, 0.6566489598499075], 
             UndirectedEdge[140, 169] -> 
             RGBColor[
              0.9935343259778466, 0.9915262491992565, 0.7518704968844423], 
             UndirectedEdge[147, 216] -> 
             RGBColor[
              0.798809853448468, 0.8397422289803436, 0.8089282049767479], 
             UndirectedEdge[70, 171] -> 
             RGBColor[
              0.9507345763786567, 0.9627785082447053, 0.9682776910973043], 
             UndirectedEdge[7, 402] -> 
             RGBColor[
              0.9296788091775925, 0.9465577242844802, 0.9859800849164737], 
             UndirectedEdge[185, 409] -> 
             RGBColor[
              0.7586222154547619, 0.8113607075464246, 0.9765760307750098], 
             UndirectedEdge[126, 481] -> 
             RGBColor[
              0.9920900485808624, 0.9840224209012085, 0.5051988981884749], 
             UndirectedEdge[115, 311] -> 
             RGBColor[
              0.9783926681062657, 0.9800264831855734, 0.7170019617634436], 
             UndirectedEdge[383, 496] -> 
             RGBColor[
              0.8445104808175208, 0.8786601868058166, 0.9478160432373881], 
             UndirectedEdge[8, 297] -> 
             RGBColor[
              0.5979742758252534, 0.6809562039843422, 0.9633944733584621], 
             UndirectedEdge[381, 439] -> 
             RGBColor[
              0.9917482872150011, 0.9892828250585091, 0.6720829841217124], 
             UndirectedEdge[16, 276] -> 
             RGBColor[
              0.7620247935695416, 0.8114578235132197, 0.8896533212858763], 
             UndirectedEdge[74, 342] -> 
             RGBColor[
              0.8957047721659543, 0.683062599242513, 0.5945561749221269], 
             UndirectedEdge[26, 269] -> 
             RGBColor[
              0.9727848785434056, 0.9177326713120257, 0.42838770585460617`], 
             UndirectedEdge[127, 315] -> 
             RGBColor[
              0.9781987834845082, 0.982062408631194, 0.868100538426891], 
             UndirectedEdge[175, 348] -> 
             RGBColor[
              0.9289326789760192, 0.9423707560943335, 0.8232551089816839], 
             UndirectedEdge[180, 288] -> 
             RGBColor[
              0.9810315863096372, 0.983034850805593, 0.795075678380589], 
             UndirectedEdge[288, 343] -> 
             RGBColor[
              0.9618890620391599, 0.9710975053865147, 0.9493960564298665], 
             UndirectedEdge[484, 500] -> 
             RGBColor[
              0.9631987054660983, 0.9720742353099812, 0.9471791717177707], 
             UndirectedEdge[59, 323] -> 
             RGBColor[
              0.9892617694290555, 0.9874859810892126, 0.6574215516446023], 
             UndirectedEdge[108, 189] -> 
             RGBColor[
              0.9924819160636306, 0.9888826565906503, 0.6087847172979686], 
             UndirectedEdge[59, 74] -> 
             RGBColor[
              0.9197769655184329, 0.7007225815067503, 0.5406861908069807], 
             UndirectedEdge[40, 199] -> 
             RGBColor[
              0.9035998525599869, 0.924095634501418, 0.920137204443178], 
             UndirectedEdge[69, 241] -> 
             RGBColor[
              0.9805209051417189, 0.9821974338502019, 0.7597146976756768], 
             UndirectedEdge[275, 353] -> 
             RGBColor[
              0.6336669035543316, 0.7095594490706989, 0.9666857268990374], 
             UndirectedEdge[196, 335] -> 
             RGBColor[
              0.5640602093182078, 0.4820595023908536, 0.5837454125927626], 
             UndirectedEdge[157, 281] -> 
             RGBColor[
              0.9065846431350502, 0.923725501993758, 0.7540470949056544], 
             UndirectedEdge[120, 438] -> 
             RGBColor[
              0.9856143871169418, 0.966273302299724, 0.5779946555035823], 
             UndirectedEdge[152, 389] -> 
             RGBColor[
              0.9863810576999035, 0.9640692828824404, 0.5421498978171664], 
             UndirectedEdge[126, 144] -> 
             RGBColor[
              0.9731147229326047, 0.9767721862689953, 0.780048814559588], 
             UndirectedEdge[96, 157] -> 
             RGBColor[
              0.7481267030009884, 0.8031615334486877, 0.9755299361797579], 
             UndirectedEdge[303, 366] -> 
             RGBColor[
              0.9670497246790035, 0.9737550563470645, 0.8873132192278613], 
             UndirectedEdge[119, 309] -> 
             RGBColor[
              0.8104058410521766, 0.8499251993446693, 0.8595783838393287], 
             UndirectedEdge[325, 386] -> 
             RGBColor[
              0.9688049749294986, 0.9746345137746634, 0.8651034337481875], 
             UndirectedEdge[27, 220] -> 
             RGBColor[
              0.8574366209865693, 0.8873207233961067, 0.8832580670147143], 
             UndirectedEdge[95, 346] -> 
             RGBColor[
              0.9916979838469842, 0.9884401977302064, 0.6131785961396006], 
             UndirectedEdge[235, 239] -> 
             RGBColor[
              0.8941595928955972, 0.9149777044709109, 0.8295993670333943], 
             UndirectedEdge[64, 303] -> 
             RGBColor[
              0.7947895569791419, 0.8404255847884119, 0.9736251178183286], 
             UndirectedEdge[310, 429] -> 
             RGBColor[
              0.873180188508372, 0.9003658053147134, 0.9186580054074442], 
             UndirectedEdge[67, 238] -> 
             RGBColor[
              0.9791184011714118, 0.9403637091195365, 0.44649872514714034`], 
             UndirectedEdge[38, 108] -> 
             RGBColor[
              0.9639929619479959, 0.8840176532461769, 0.35373596563764653`], 
             UndirectedEdge[20, 490] -> 
             RGBColor[
              0.9779756916117099, 0.9794866849757013, 0.6995520786450989], 
             UndirectedEdge[112, 148] -> 
             RGBColor[
              0.7234002561317603, 0.783543331425272, 0.9733014477902429], 
             UndirectedEdge[76, 402] -> 
             RGBColor[
              0.9283830466469042, 0.9455245184150463, 0.9858564939295558], 
             UndirectedEdge[99, 406] -> 
             RGBColor[
              0.9040039708852144, 0.9260853051550575, 0.983531195919948], 
             UndirectedEdge[8, 258] -> 
             RGBColor[
              0.5976609828880178, 0.6807114571606593, 0.9633632472463673], 
             UndirectedEdge[15, 153] -> 
             RGBColor[
              0.9673748991947163, 0.9741833770280204, 0.8950835585630565], 
             UndirectedEdge[195, 463] -> 
             RGBColor[
              0.8739679967867088, 0.4902438504231989, 0.21534538589750252`], 
             UndirectedEdge[184, 249] -> 
             RGBColor[
              0.8098363617598581, 0.8518738008220831, 0.9596117752379575], 
             UndirectedEdge[109, 185] -> 
             RGBColor[
              0.8589985977194243, 0.831746126751896, 0.6286593279085249], 
             UndirectedEdge[77, 81] -> 
             RGBColor[
              0.793083393224215, 0.8361770102960518, 0.8713810296080804], 
             UndirectedEdge[355, 384] -> 
             RGBColor[
              0.9224497243049387, 0.9388960086267674, 0.9120313046911628], 
             UndirectedEdge[67, 343] -> 
             RGBColor[
              0.9603122117336478, 0.9291457498989641, 0.6374270741192778], 
             UndirectedEdge[247, 255] -> 
             RGBColor[
              0.9383287875280972, 0.950008912590596, 0.8359828701023571], 
             UndirectedEdge[95, 145] -> 
             RGBColor[
              0.9699305679421982, 0.975982090506721, 0.8859523608021503], 
             UndirectedEdge[220, 416] -> 
             RGBColor[
              0.6978813873158245, 0.7577031130339147, 0.8702136665775981], 
             UndirectedEdge[287, 451] -> 
             RGBColor[
              0.9920425308317509, 0.9909773962483688, 0.7815393875953582], 
             UndirectedEdge[387, 491] -> 
             RGBColor[
              0.950850309002299, 0.9606476553783745, 0.8759105542715728], 
             UndirectedEdge[211, 464] -> 
             RGBColor[
              0.9412128340141752, 0.7989548779549169, 0.30114148318898737`], 
             UndirectedEdge[335, 482] -> 
             RGBColor[
              0.5201696004818874, 0.6063940534803962, 0.9589156991086099], 
             UndirectedEdge[214, 423] -> 
             RGBColor[
              0.9914161557257855, 0.9893017380837652, 0.6889455644996354], 
             UndirectedEdge[69, 194] -> 
             RGBColor[
              0.980306132991762, 0.9817380579382393, 0.7363380745729351], 
             UndirectedEdge[111, 312] -> 
             RGBColor[
              0.964635063601359, 0.973145468855438, 0.9447477920569741], 
             UndirectedEdge[174, 294] -> 
             RGBColor[
              0.9414886219153991, 0.9524032258941448, 0.8261308547036226], 
             UndirectedEdge[212, 295] -> 
             RGBColor[
              0.9317357201095393, 0.9455215697772856, 0.8790970963070646], 
             UndirectedEdge[193, 414] -> 
             RGBColor[
              0.9892135434906053, 0.987452798673307, 0.6572583901172084], 
             UndirectedEdge[320, 348] -> 
             RGBColor[
              0.9377271644016508, 0.9493832400527846, 0.8240939348525105], 
             UndirectedEdge[247, 468] -> 
             RGBColor[
              0.9252330332178664, 0.9395667135783992, 0.8347337853655293], 
             UndirectedEdge[449, 488] -> 
             RGBColor[
              0.9612054957119538, 0.8752530972526618, 0.5170168283393453], 
             UndirectedEdge[290, 355] -> 
             RGBColor[
              0.882196334840351, 0.9089034270928531, 0.9886258680346796], 
             UndirectedEdge[88, 469] -> 
             RGBColor[
              0.9936358576766791, 0.9887960680209358, 0.5486805669193447], 
             UndirectedEdge[6, 278] -> 
             RGBColor[
              0.8129420755350287, 0.8144819810704684, 0.6429446568936804], 
             UndirectedEdge[24, 448] -> 
             RGBColor[
              0.9890596289741767, 0.9878830726929627, 0.6957120401987429], 
             UndirectedEdge[204, 274] -> 
             RGBColor[
              0.8850889081235598, 0.9105954390724162, 0.963760052944391], 
             UndirectedEdge[81, 99] -> 
             RGBColor[
              0.7292051276667187, 0.7879990506509529, 0.9740541583077897], 
             UndirectedEdge[213, 368] -> 
             RGBColor[
              0.7462489458429472, 0.8016946152853429, 0.9753427788948826], 
             UndirectedEdge[167, 474] -> 
             RGBColor[
              0.7451217826750265, 0.7964527795196563, 0.8290392458096336], 
             UndirectedEdge[78, 430] -> 
             RGBColor[
              0.8514604187874268, 0.8812414805480242, 0.7949631467810084], 
             UndirectedEdge[110, 316] -> 
             RGBColor[
              0.9421320250734591, 0.956362739566674, 0.9828395665522867], 
             UndirectedEdge[153, 463] -> 
             RGBColor[
              0.9150307349209738, 0.6486468855586913, 0.49855414769625467`], 
             UndirectedEdge[471, 475] -> 
             RGBColor[
              0.9883914682276418, 0.9891683642607605, 0.8286470916974831], 
             UndirectedEdge[79, 486] -> 
             RGBColor[
              0.9903542567615113, 0.9902792515336603, 0.8095184580524634], 
             UndirectedEdge[49, 402] -> 
             RGBColor[
              0.9608066664027771, 0.9473140382617902, 0.6743751140060967], 
             UndirectedEdge[340, 498] -> 
             RGBColor[
              0.926881051889892, 0.9442777702813763, 0.9840109639665258], 
             UndirectedEdge[248, 313] -> 
             RGBColor[
              0.9145783903810143, 0.9317772671287806, 0.8747026330741967], 
             UndirectedEdge[37, 429] -> 
             RGBColor[
              0.9897732757160499, 0.99003900094083, 0.8191468175065093], 
             UndirectedEdge[18, 166] -> 
             RGBColor[
              0.8605719893646453, 0.8895870058980055, 0.8752684431482245], 
             UndirectedEdge[147, 238] -> 
             RGBColor[
              0.7984472254989567, 0.8389666044636487, 0.769458390552741], 
             UndirectedEdge[165, 441] -> 
             RGBColor[
              0.9281976274656241, 0.7376945750116639, 0.5107901892146862], 
             UndirectedEdge[13, 154] -> 
             RGBColor[
              0.9729317643508453, 0.9574233808917803, 0.6561143880700482], 
             UndirectedEdge[133, 249] -> 
             RGBColor[
              0.7681743060516435, 0.8192814709290608, 0.9774063961912952], 
             UndirectedEdge[84, 385] -> 
             RGBColor[
              0.6594868690595499, 0.7315587203338632, 0.9683814177365155], 
             UndirectedEdge[125, 438] -> 
             RGBColor[
              0.8591887097079417, 0.8688678679027333, 0.6742157793586181], 
             UndirectedEdge[21, 489] -> 
             RGBColor[
              0.7291437593976159, 0.7881681702954508, 0.9737973299017786], 
             UndirectedEdge[16, 200] -> 
             RGBColor[
              0.7602631099247787, 0.8107293220529057, 0.9188489783707248], 
             UndirectedEdge[402, 436] -> 
             RGBColor[
              0.8903044712000976, 0.9151616959691581, 0.9822245254102937], 
             UndirectedEdge[127, 401] -> 
             RGBColor[
              0.9918643658989962, 0.9909037204700448, 0.7844920416071679], 
             UndirectedEdge[195, 395] -> 
             RGBColor[
              0.9317471041373968, 0.8198337135404115, 0.6026748557952131], 
             UndirectedEdge[27, 297] -> 
             RGBColor[
              0.7567438334895056, 0.8098933012789347, 0.9763888112151904], 
             UndirectedEdge[35, 70] -> 
             RGBColor[
              0.8862277892244405, 0.550094257090531, 0.5625221249092153], 
             UndirectedEdge[240, 367] -> 
             RGBColor[
              0.7880774291924377, 0.4898436003897522, 0.5725218277587236], 
             UndirectedEdge[121, 471] -> 
             RGBColor[
              0.9657774118772389, 0.9739974303291655, 0.9428140943980567], 
             UndirectedEdge[184, 424] -> 
             RGBColor[
              0.8286951015364036, 0.8666063916672513, 0.9614914381739403], 
             UndirectedEdge[122, 159] -> 
             RGBColor[
              0.9678447308057085, 0.9749790629546309, 0.914229085607357], 
             UndirectedEdge[158, 324] -> 
             RGBColor[
              0.9903704640000269, 0.9902859536432933, 0.8092498621672723], 
             UndirectedEdge[180, 465] -> 
             RGBColor[
              0.9906704147023666, 0.9897948637428802, 0.7595656471948464], 
             UndirectedEdge[254, 454] -> 
             RGBColor[
              0.972078949183371, 0.9767784508920518, 0.8435920347259259], 
             UndirectedEdge[297, 314] -> 
             RGBColor[
              0.8389309152156776, 0.874647597537404, 0.9844347309815658], 
             UndirectedEdge[262, 393] -> 
             RGBColor[
              0.7222736505128142, 0.7009507184673871, 0.6116025267117324], 
             UndirectedEdge[201, 333] -> 
             RGBColor[
              0.8637457699338088, 0.856491913006518, 0.6513986753519633], 
             UndirectedEdge[219, 340] -> 
             RGBColor[
              0.9413998224976954, 0.8737920551194489, 0.6226136228937222], 
             UndirectedEdge[361, 370] -> 
             RGBColor[
              0.9787420815144408, 0.982920747517492, 0.8874737745611877], 
             UndirectedEdge[48, 358] -> 
             RGBColor[
              0.9912735240346899, 0.9898637267738593, 0.7364473451411682], 
             UndirectedEdge[287, 299] -> 
             RGBColor[
              0.980493580984289, 0.9836687849100842, 0.8595103504767911], 
             UndirectedEdge[62, 233] -> 
             RGBColor[
              0.7795264830390563, 0.8276912802615934, 0.9786595728063249], 
             UndirectedEdge[61, 91] -> 
             RGBColor[
              0.9830767975524946, 0.9664292730067079, 0.628380272202572], 
             UndirectedEdge[204, 340] -> 
             RGBColor[
              0.876009214173394, 0.903823818191017, 0.9791296064385716], 
             UndirectedEdge[258, 373] -> 
             RGBColor[
              0.7013191253399629, 0.7661503452784907, 0.971168674164818], 
             UndirectedEdge[167, 210] -> 
             RGBColor[
              0.9402681865242862, 0.9516865894612925, 0.8468076254019998], 
             UndirectedEdge[275, 481] -> 
             RGBColor[
              0.703676246539763, 0.7570779571127818, 0.6819730843049209], 
             UndirectedEdge[253, 277] -> 
             RGBColor[
              0.8958482697749148, 0.9168980188091047, 0.8675805494584039], 
             UndirectedEdge[193, 485] -> 
             RGBColor[
              0.830813774098605, 0.8675246970549619, 0.9260369451024264], 
             UndirectedEdge[89, 260] -> 
             RGBColor[
              0.993864627651045, 0.9906806709844298, 0.6750034110864415], 
             UndirectedEdge[359, 397] -> 
             RGBColor[
              0.6363728881007082, 0.7007338400809189, 0.8359383202059743], 
             UndirectedEdge[1, 171] -> 
             RGBColor[
              0.9705470982255622, 0.9753497333449197, 0.8234711070040428], 
             UndirectedEdge[193, 330] -> 
             RGBColor[
              0.9892565476624999, 0.9875447802486013, 0.6619391288369694], 
             UndirectedEdge[92, 320] -> 
             RGBColor[
              0.9231105308095182, 0.9014065438688399, 0.654333027147102], 
             UndirectedEdge[126, 279] -> 
             RGBColor[
              0.9920559472536796, 0.9899240816196929, 0.7043489050182519], 
             UndirectedEdge[93, 163] -> 
             RGBColor[
              0.7362162780485267, 0.7920780002122816, 0.9457978805869196], 
             UndirectedEdge[31, 297] -> 
             RGBColor[
              0.8912887895587835, 0.9112442278156393, 0.7099090838396718], 
             UndirectedEdge[127, 325] -> 
             RGBColor[
              0.9926781884026299, 0.9912402569895817, 0.7710048966168306], 
             UndirectedEdge[334, 498] -> 
             RGBColor[
              0.9481231742207314, 0.9594688430883467, 0.9188885137741032], 
             UndirectedEdge[41, 300] -> 
             RGBColor[
              0.8354740194548367, 0.8716746397678694, 0.9841624677046551], 
             UndirectedEdge[330, 496] -> 
             RGBColor[
              0.8522972589545773, 0.880783747761025, 0.7060227724656147], 
             UndirectedEdge[18, 227] -> 
             RGBColor[
              0.8407438375185912, 0.8761496598673743, 0.9693085625600646], 
             UndirectedEdge[156, 350] -> 
             RGBColor[
              0.962983726636691, 0.940453116740006, 0.6526787836423364], 
             UndirectedEdge[315, 386] -> 
             RGBColor[
              0.9543255700113769, 0.9654566654162757, 0.9621990755582479], 
             UndirectedEdge[29, 479] -> 
             RGBColor[
              0.9629349903955519, 0.9710322601012195, 0.9097714484860475], 
             UndirectedEdge[277, 488] -> 
             RGBColor[
              0.9931510012404314, 0.9914357772487483, 0.7631691642940597], 
             UndirectedEdge[242, 374] -> 
             RGBColor[
              0.9482146897234172, 0.8940912197403614, 0.6228836833924813], 
             UndirectedEdge[244, 363] -> 
             RGBColor[
              0.9910363411634509, 0.9905613109626317, 0.7982145543344783], 
             UndirectedEdge[335, 409] -> 
             RGBColor[
              0.49407579774215404`, 0.5860093764598706, 0.9563149127119639], 
             UndirectedEdge[235, 332] -> 
             RGBColor[
              0.8927609363532254, 0.9116986491201265, 0.7018086444728959], 
             UndirectedEdge[249, 440] -> 
             RGBColor[
              0.7503008092503147, 0.8050296297428274, 0.9757016061105255], 
             UndirectedEdge[96, 265] -> 
             RGBColor[
              0.835678719625643, 0.8693032644925998, 0.8246726243385956], 
             UndirectedEdge[39, 200] -> 
             RGBColor[
              0.968904022386159, 0.9760240795905775, 0.9238553444814015], 
             UndirectedEdge[146, 312] -> 
             RGBColor[
              0.976025468085955, 0.9806390557975897, 0.8806239479820045], 
             UndirectedEdge[237, 448] -> 
             RGBColor[
              0.8500253751610147, 0.8793392140182146, 0.7322500098410683], 
             UndirectedEdge[31, 162] -> 
             RGBColor[
              0.9937971073058927, 0.9891409646729852, 0.5662315939418786], 
             UndirectedEdge[41, 102] -> 
             RGBColor[
              0.836627755826008, 0.8725945978329019, 0.98427251210969], 
             UndirectedEdge[266, 374] -> 
             RGBColor[
              0.7757754065171566, 0.758121313015041, 0.6189768074187136], 
             UndirectedEdge[44, 139] -> 
             RGBColor[
              0.9724724990061415, 0.9789906153477022, 0.931481058247208], 
             UndirectedEdge[47, 189] -> 
             RGBColor[
              0.984403853652474, 0.9865385429565998, 0.8508081566799299], 
             UndirectedEdge[208, 359] -> 
             RGBColor[
              0.6336356532659337, 0.6996019231330131, 0.8813013851548652], 
             UndirectedEdge[122, 413] -> 
             RGBColor[
              0.9396070434590895, 0.9527835481901948, 0.9226459744305073], 
             UndirectedEdge[36, 141] -> 
             RGBColor[
              0.860630652287513, 0.8917849576200124, 0.9763307550774849], 
             UndirectedEdge[179, 347] -> 
             RGBColor[
              0.9001690340869276, 0.9230955082557312, 0.9855257095967616], 
             UndirectedEdge[226, 422] -> 
             RGBColor[
              0.9377015487588578, 0.9502712109198352, 0.8793470171247402], 
             UndirectedEdge[18, 167] -> 
             RGBColor[
              0.8619462226137716, 0.8899715988629607, 0.8391416778742881], 
             UndirectedEdge[112, 452] -> 
             RGBColor[
              0.3984755524197334, 0.5030864179170726, 0.9482866339556524], 
             UndirectedEdge[323, 342] -> 
             RGBColor[
              0.9651895760765768, 0.9698259988249753, 0.7112915357597485], 
             UndirectedEdge[74, 82] -> 
             RGBColor[
              0.8986215612955709, 0.6852379357995773, 0.5896188117461281], 
             UndirectedEdge[291, 349] -> 
             RGBColor[
              0.9905982213663151, 0.9892138591978785, 0.7206992366662153], 
             UndirectedEdge[86, 136] -> 
             RGBColor[
              0.9430396535475083, 0.9552221267981347, 0.9100118483169242], 
             UndirectedEdge[11, 23] -> 
             RGBColor[
              0.9125591012945888, 0.9324959001637197, 0.9700963935142247], 
             UndirectedEdge[249, 470] -> 
             RGBColor[
              0.7934473286788912, 0.741687906961759, 0.6135229589244877], 
             UndirectedEdge[35, 135] -> 
             RGBColor[
              0.9016153769626843, 0.5612845812219, 0.5236801134380745], 
             UndirectedEdge[161, 326] -> 
             RGBColor[
              0.904683352705192, 0.6897588099076002, 0.5793577800580463], 
             UndirectedEdge[26, 139] -> 
             RGBColor[
              0.9660048617662589, 0.9154852660547934, 0.5990742567946296], 
             UndirectedEdge[109, 218] -> 
             RGBColor[
              0.9560836417257191, 0.9080860363930657, 0.6158682944546576], 
             UndirectedEdge[238, 465] -> 
             RGBColor[
              0.9903340798696533, 0.9890754775443742, 0.7229576762719865], 
             UndirectedEdge[258, 314] -> 
             RGBColor[
              0.838617622278442, 0.8744028507137211, 0.984403504869471], 
             UndirectedEdge[28, 493] -> 
             RGBColor[
              0.9788781640602735, 0.9404132291116912, 0.3724460852085356], 
             UndirectedEdge[106, 466] -> 
             RGBColor[
              0.9886421538260086, 0.9718492909567646, 0.5379408278551538], 
             UndirectedEdge[45, 236] -> 
             RGBColor[
              0.9531346557713445, 0.9610144779836018, 0.772525663515564], 
             UndirectedEdge[157, 246] -> 
             RGBColor[
              0.9070928690619466, 0.924812545861866, 0.8093643506414723], 
             UndirectedEdge[371, 427] -> 
             RGBColor[
              0.9899796612117346, 0.9761868913216207, 0.5579432189066003], 
             UndirectedEdge[341, 450] -> 
             RGBColor[
              0.993664078226393, 0.9888564289232388, 0.5517521995986661], 
             UndirectedEdge[277, 484] -> 
             RGBColor[
              0.9845432643826509, 0.986419225113363, 0.8405727821104136], 
             UndirectedEdge[84, 135] -> 
             RGBColor[
              0.7313627993377623, 0.7872900738438602, 0.9175489529214983], 
             UndirectedEdge[35, 84] -> 
             RGBColor[
              0.6470664223750779, 0.3601324926219602, 0.5580868394834237], 
             UndirectedEdge[68, 272] -> 
             RGBColor[
              0.9611055195797116, 0.9162475636717484, 0.6107938935811457], 
             UndirectedEdge[164, 227] -> 
             RGBColor[
              0.9495704145034289, 0.9619102782243006, 0.9702483134900197], 
             UndirectedEdge[355, 498] -> 
             RGBColor[
              0.882196334840351, 0.9089034270928531, 0.9886258680346796], 
             UndirectedEdge[223, 373] -> 
             RGBColor[
              0.7973117504517042, 0.8227698142676358, 0.6722741080968833], 
             UndirectedEdge[116, 192] -> 
             RGBColor[
              0.9898578645850317, 0.9886221067384204, 0.7122090571898633], 
             UndirectedEdge[3, 31] -> 
             RGBColor[
              0.965393298059765, 0.9700271534432927, 0.7148520123953753], 
             UndirectedEdge[40, 419] -> 
             RGBColor[
              0.8223086930981673, 0.8605903628941498, 0.9120348613771003], 
             UndirectedEdge[282, 324] -> 
             RGBColor[
              0.9700329607958158, 0.9755944731648613, 0.8650009850276121], 
             UndirectedEdge[250, 339] -> 
             RGBColor[
              0.7255347271889965, 0.7845203198026767, 0.9743394752700114], 
             UndirectedEdge[259, 405] -> 
             RGBColor[
              0.9638783102862895, 0.9725810834721289, 0.9460287780265119], 
             UndirectedEdge[22, 441] -> 
             RGBColor[
              0.9290131893219752, 0.7380318307982487, 0.4972742186485196], 
             UndirectedEdge[142, 241] -> 
             RGBColor[
              0.9933035976945911, 0.9880853975158868, 0.5125161183399871], 
             UndirectedEdge[170, 266] -> 
             RGBColor[
              0.648000034631648, 0.724368367940637, 0.965942317322112], 
             UndirectedEdge[105, 153] -> 
             RGBColor[
              0.9788803620634356, 0.9827641323970449, 0.8756078110316253], 
             UndirectedEdge[95, 404] -> 
             RGBColor[
              0.9143435568874551, 0.6410163082531333, 0.49223511941404396`], 
             UndirectedEdge[200, 454] -> 
             RGBColor[
              0.9675070876762328, 0.9749822479711852, 0.9262199905663829], 
             UndirectedEdge[96, 131] -> 
             RGBColor[
              0.8349474664164083, 0.8677391878190872, 0.7450802252850894], 
             UndirectedEdge[190, 395] -> 
             RGBColor[
              0.9268333391192007, 0.7986424063953841, 0.598632675510577], 
             UndirectedEdge[297, 381] -> 
             RGBColor[
              0.8899884685335607, 0.9129870520177642, 0.8972299781167548], 
             UndirectedEdge[203, 419] -> 
             RGBColor[
              0.8255392606562205, 0.8607459225012405, 0.7726960596783057], 
             UndirectedEdge[107, 209] -> 
             RGBColor[
              0.9429789030073963, 0.9541092092759549, 0.8637828007983905], 
             UndirectedEdge[205, 252] -> 
             RGBColor[
              0.6169999560101703, 0.699103580858918, 0.9635685571265427], 
             UndirectedEdge[98, 488] -> 
             RGBColor[
              0.9642132053301624, 0.8871776636290432, 0.5194369020981744], 
             UndirectedEdge[182, 275] -> 
             RGBColor[
              0.6990042203937133, 0.7413181158782503, 0.6638231449656247], 
             UndirectedEdge[88, 474] -> 
             RGBColor[
              0.7438634747181523, 0.7937613860343521, 0.6920801900804288], 
             UndirectedEdge[47, 242] -> 
             RGBColor[
              0.9631450047175654, 0.9720341853796521, 0.9472700730776384], 
             UndirectedEdge[133, 262] -> 
             RGBColor[
              0.9073180128688274, 0.8480465129547177, 0.6285028060164328], 
             UndirectedEdge[4, 321] -> 
             RGBColor[
              0.92213538106908, 0.9379047741920266, 0.8798425355937549], 
             UndirectedEdge[369, 370] -> 
             RGBColor[
              0.9814474798696577, 0.9830123436535689, 0.7679749528732707], 
             UndirectedEdge[49, 436] -> 
             RGBColor[
              0.907387280541597, 0.9049258089741448, 0.676454629203206], 
             UndirectedEdge[34, 393] -> 
             RGBColor[
              0.7486227910384358, 0.8003664870622467, 0.8797781803972513], 
             UndirectedEdge[268, 324] -> 
             RGBColor[
              0.9686637776279993, 0.9745733386001354, 0.8673186549905633], 
             UndirectedEdge[359, 371] -> 
             RGBColor[
              0.6364874839358954, 0.7007241761224003, 0.8298920720729828], 
             UndirectedEdge[296, 440] -> 
             RGBColor[
              0.9172689542021754, 0.9323368863458638, 0.7626801135732318], 
             UndirectedEdge[113, 143] -> 
             RGBColor[
              0.9804075593534873, 0.9475129929992889, 0.5494972492113492], 
             UndirectedEdge[270, 489] -> 
             RGBColor[
              0.8049036982098418, 0.8470665014021824, 0.9263738648940663], 
             UndirectedEdge[237, 426] -> 
             RGBColor[
              0.8455582471987588, 0.8793525497463357, 0.9415342701842239], 
             UndirectedEdge[131, 385] -> 
             RGBColor[
              0.9177742506793902, 0.9326233406826818, 0.7532880604304539], 
             UndirectedEdge[427, 499] -> 
             RGBColor[
              0.988249208346079, 0.9755283568724089, 0.5907683997384043], 
             UndirectedEdge[45, 243] -> 
             RGBColor[
              0.8298949429277576, 0.8677879951249969, 0.9834812036218056], 
             UndirectedEdge[33, 443] -> 
             RGBColor[
              0.8757682593707156, 0.8866048169221163, 0.6828556383174142], 
             UndirectedEdge[232, 330] -> 
             RGBColor[
              0.906613436001005, 0.9232208432674849, 0.7114352050036206], 
             UndirectedEdge[19, 360] -> 
             RGBColor[
              0.8118739561591426, 0.8531666815854437, 0.944684419000742], 
             UndirectedEdge[44, 370] -> 
             RGBColor[
              0.9667072163595046, 0.9746908769896242, 0.9412401779414286], 
             UndirectedEdge[310, 412] -> 
             RGBColor[
              0.8460526197631552, 0.7919240610854347, 0.6207902571167687], 
             UndirectedEdge[107, 214] -> 
             RGBColor[
              0.9402424338764681, 0.9529776089662672, 0.9091331760529703], 
             UndirectedEdge[268, 481] -> 
             RGBColor[
              0.9668852114956432, 0.9679220933037029, 0.6982092389983524], 
             UndirectedEdge[224, 351] -> 
             RGBColor[
              0.9919212874755166, 0.9891557499044021, 0.6547786931811179], 
             UndirectedEdge[78, 408] -> 
             RGBColor[
              0.6296042623165747, 0.7091647114025332, 0.9646781471266845], 
             UndirectedEdge[124, 136] -> 
             RGBColor[
              0.9446300194017467, 0.9558797839494004, 0.8836553703772934], 
             UndirectedEdge[51, 315] -> 
             RGBColor[
              0.9520611860084622, 0.9637678915344905, 0.9660320870292489], 
             UndirectedEdge[24, 270] -> 
             RGBColor[
              0.9852707089620625, 0.9881770738773688, 0.8937660008893173], 
             UndirectedEdge[43, 340] -> 
             RGBColor[
              0.9641794918590805, 0.9728057041959768, 0.9455189561845115], 
             UndirectedEdge[116, 483] -> 
             RGBColor[
              0.9898348324338944, 0.9886125823520258, 0.7125907595395051], 
             UndirectedEdge[50, 169] -> 
             RGBColor[
              0.8437321324145461, 0.8765152445979907, 0.8773836363797319], 
             UndirectedEdge[247, 369] -> 
             RGBColor[
              0.9944823752200395, 0.9906066834501313, 0.640818777413416], 
             UndirectedEdge[327, 412] -> 
             RGBColor[
              0.9624919488057437, 0.8815336737588821, 0.5238272399247393], 
             UndirectedEdge[134, 305] -> 
             RGBColor[
              0.6381994808001963, 0.7126411876665503, 0.9673631482470639], 
             UndirectedEdge[7, 49] -> 
             RGBColor[
              0.9467616185190919, 0.9363218372894668, 0.6802101887093859], 
             UndirectedEdge[81, 486] -> 
             RGBColor[
              0.7921869608010855, 0.8358063124518254, 0.8862372347520788], 
             UndirectedEdge[110, 384] -> 
             RGBColor[
              0.9663404610708322, 0.9736782026197696, 0.9087604021400009], 
             UndirectedEdge[18, 88] -> 
             RGBColor[
              0.8606879146568973, 0.8872802053776565, 0.7021826221450831], 
             UndirectedEdge[11, 41] -> 
             RGBColor[
              0.8410913585108277, 0.8761537534525101, 0.9846982545184733], 
             UndirectedEdge[231, 288] -> 
             RGBColor[
              0.9768038105768311, 0.9819016841154095, 0.9098541189931781], 
             UndirectedEdge[236, 396] -> 
             RGBColor[
              0.9803373482046553, 0.9818981465020598, 0.7471403895381158], 
             UndirectedEdge[46, 418] -> 
             RGBColor[
              0.9455170865870228, 0.8079487252743816, 0.38991998981945875`], 
             UndirectedEdge[74, 447] -> 
             RGBColor[
              0.8816307234758127, 0.5462683646765512, 0.2225650672503086], 
             UndirectedEdge[270, 426] -> 
             RGBColor[
              0.9848689497078932, 0.9880107270612759, 0.9004148302233436], 
             UndirectedEdge[383, 479] -> 
             RGBColor[
              0.9831724412364029, 0.9861253178025418, 0.875514722985004], 
             UndirectedEdge[408, 430] -> 
             RGBColor[
              0.7724196176083824, 0.8180880153550383, 0.7880465185769319], 
             UndirectedEdge[13, 390] -> 
             RGBColor[
              0.9857079309250312, 0.9633210466386988, 0.4100828548909127], 
             UndirectedEdge[15, 97] -> 
             RGBColor[
              0.9575141695543532, 0.9678347177345747, 0.9568016082519407], 
             UndirectedEdge[289, 472] -> 
             RGBColor[
              0.8983894402602957, 0.9197254949083047, 0.9060270341303949], 
             UndirectedEdge[254, 315] -> 
             RGBColor[
              0.9800810208815057, 0.9827463828623308, 0.8300466146155372], 
             UndirectedEdge[347, 386] -> 
             RGBColor[
              0.901457939845854, 0.924056772060349, 0.9833439283473602], 
             UndirectedEdge[66, 445] -> 
             RGBColor[
              0.9782636793715063, 0.9801718375967949, 0.736386582650536], 
             UndirectedEdge[127, 213] -> 
             RGBColor[
              0.843292527161886, 0.8762559107346177, 0.8811527775199419], 
             UndirectedEdge[423, 446] -> 
             RGBColor[
              0.9941540992237683, 0.9899045342879017, 0.6050879611039095], 
             UndirectedEdge[63, 410] -> 
             RGBColor[
              0.8701104157505599, 0.8989524723489963, 0.9652205693349322], 
             UndirectedEdge[107, 421] -> 
             RGBColor[
              0.8401571595880231, 0.8756327851259631, 0.984549723919919], 
             UndirectedEdge[226, 308] -> 
             RGBColor[
              0.9359688105623654, 0.949554679146245, 0.9080629732233299], 
             UndirectedEdge[51, 386] -> 
             RGBColor[
              0.9413973126449322, 0.9558147922404598, 0.9840832430500916], 
             UndirectedEdge[89, 470] -> 
             RGBColor[
              0.9606666763104825, 0.8695324606962525, 0.4278433278326418], 
             UndirectedEdge[205, 490] -> 
             RGBColor[
              0.7498810298485441, 0.8033595947288792, 0.9519142521300719], 
             UndirectedEdge[270, 345] -> 
             RGBColor[
              0.9870819872763796, 0.9889260840080683, 0.8637484317830637], 
             UndirectedEdge[152, 191] -> 
             RGBColor[
              0.7968579196107413, 0.8385289785062002, 0.8392158439069364], 
             UndirectedEdge[85, 404] -> 
             RGBColor[
              0.8970754875630982, 0.6292505672404187, 0.5712969802409094], 
             UndirectedEdge[26, 468] -> 
             RGBColor[
              0.9036341097775433, 0.8669035396254794, 0.6330318022556529], 
             UndirectedEdge[191, 301] -> 
             RGBColor[
              0.7462271090244685, 0.8016038158331196, 0.9756410145797534], 
             UndirectedEdge[375, 426] -> 
             RGBColor[
              0.972209928154737, 0.9787947904366449, 0.93192552220919], 
             UndirectedEdge[39, 213] -> 
             RGBColor[
              0.8234780500640762, 0.8626771664628433, 0.9683809326558634], 
             UndirectedEdge[360, 468] -> 
             RGBColor[
              0.7512054978312889, 0.8058545229811505, 0.9757604253232194], 
             UndirectedEdge[80, 278] -> 
             RGBColor[
              0.7444820777418034, 0.8003808779815778, 0.9751490127461508], 
             UndirectedEdge[152, 299] -> 
             RGBColor[
              0.9820639289723276, 0.9842313017992351, 0.8271716437779466], 
             UndirectedEdge[227, 309] -> 
             RGBColor[
              0.7899269769732593, 0.8362187670832074, 0.9644024889389899], 
             UndirectedEdge[98, 115] -> 
             RGBColor[
              0.9497494311087151, 0.8777936884162163, 0.6067532636720594], 
             UndirectedEdge[213, 261] -> 
             RGBColor[
              0.844243920025624, 0.8749489026319313, 0.74178217076985], 
             UndirectedEdge[199, 208] -> 
             RGBColor[
              0.9046296432768679, 0.9245214794272625, 0.9030709072515116], 
             UndirectedEdge[204, 219] -> 
             RGBColor[
              0.8717812041341548, 0.8186459662613912, 0.6248211529630614], 
             UndirectedEdge[52, 166] -> 
             RGBColor[
              0.9893653179419974, 0.9898702999172228, 0.8259077335834353], 
             UndirectedEdge[218, 300] -> 
             RGBColor[
              0.9073559898459953, 0.9283257167504408, 0.9688594274089449], 
             UndirectedEdge[128, 345] -> 
             RGBColor[
              0.9916865311779484, 0.9903766198509806, 0.7544700980124344], 
             UndirectedEdge[325, 421] -> 
             RGBColor[
              0.891485068653427, 0.9134373105809245, 0.8647813107806839], 
             UndirectedEdge[257, 272] -> 
             RGBColor[
              0.9807365588332579, 0.9821967176234275, 0.7465313192187232], 
             UndirectedEdge[461, 486] -> 
             RGBColor[
              0.9520615321652712, 0.9621992966553297, 0.9014654859003155], 
             UndirectedEdge[115, 203] -> 
             RGBColor[
              0.9788117937053914, 0.980922950462005, 0.7626211966849108], 
             UndirectedEdge[128, 169] -> 
             RGBColor[
              0.9933108852083012, 0.991048331986526, 0.7275503480360086], 
             UndirectedEdge[190, 356] -> 
             RGBColor[
              0.9441581058096356, 0.8105940792433914, 0.5259076484356621], 
             UndirectedEdge[46, 272] -> 
             RGBColor[
              0.9326177894487986, 0.8013493785241173, 0.5877709277190072], 
             UndirectedEdge[121, 450] -> 
             RGBColor[
              0.9711073568074491, 0.9745759109465844, 0.7279694263178473], 
             UndirectedEdge[255, 269] -> 
             RGBColor[
              0.937839191601499, 0.948961716409344, 0.7826933749279678], 
             UndirectedEdge[15, 356] -> 
             RGBColor[
              0.9672655102867052, 0.974138141903391, 0.8968964158582209], 
             UndirectedEdge[85, 183] -> 
             RGBColor[
              0.9495591628763589, 0.9619018867792546, 0.9702673595597551], 
             UndirectedEdge[136, 261] -> 
             RGBColor[
              0.9451356012612288, 0.9543884215396339, 0.7516730056896201], 
             UndirectedEdge[295, 336] -> 
             RGBColor[
              0.9313650363160518, 0.9453682825025396, 0.885240286064058], 
             UndirectedEdge[259, 475] -> 
             RGBColor[
              0.9700099213303399, 0.9754594366817734, 0.8597622559193691], 
             UndirectedEdge[51, 143] -> 
             RGBColor[
              0.9535682343238705, 0.9289282935256082, 0.6590582393890696], 
             UndirectedEdge[53, 178] -> 
             RGBColor[
              0.9626525015659904, 0.9716668773356074, 0.9481037524478608], 
             UndirectedEdge[67, 385] -> 
             RGBColor[
              0.9032502010518841, 0.8841768797594809, 0.6503885979905994], 
             UndirectedEdge[69, 173] -> 
             RGBColor[
              0.9157061893578962, 0.9348128005313594, 0.9637223924730887], 
             UndirectedEdge[221, 381] -> 
             RGBColor[
              0.9277621423461457, 0.7361178265383954, 0.5121167466834373], 
             UndirectedEdge[140, 334] -> 
             RGBColor[
              0.9916576020994382, 0.9907501756459309, 0.7829726683553793], 
             UndirectedEdge[57, 370] -> 
             RGBColor[0.918781187341978, 0.93722151874068, 0.962517857961019],
              UndirectedEdge[432, 467] -> 
             RGBColor[
              0.9714381947101778, 0.9764551005094024, 0.8542304129671816], 
             UndirectedEdge[235, 440] -> 
             RGBColor[
              0.8172301732473551, 0.8573153575793218, 0.9823724996232834], 
             UndirectedEdge[229, 390] -> 
             RGBColor[
              0.9914078479370181, 0.9885000729099683, 0.6310603741634497], 
             UndirectedEdge[12, 198] -> 
             RGBColor[
              0.9718017527908378, 0.975482539416849, 0.7576395720196353], 
             UndirectedEdge[232, 400] -> 
             RGBColor[
              0.9067337652006597, 0.9234782152583981, 0.7245322958003018], 
             UndirectedEdge[143, 273] -> 
             RGBColor[
              0.967943743692212, 0.903528861686225, 0.32996792687063986`], 
             UndirectedEdge[115, 277] -> 
             RGBColor[
              0.978687227018984, 0.9820518020359214, 0.8504855258679448], 
             UndirectedEdge[44, 468] -> 
             RGBColor[
              0.910101747017426, 0.9304088889183881, 0.9654386037082314], 
             UndirectedEdge[183, 346] -> 
             RGBColor[
              0.9676353625275156, 0.9716070909645953, 0.7037418611912148], 
             UndirectedEdge[434, 469] -> 
             RGBColor[
              0.9862170328742457, 0.9638011543191249, 0.5172642605702487], 
             UndirectedEdge[255, 334] -> 
             RGBColor[
              0.9349481271722404, 0.948963418199005, 0.9176318660251147], 
             UndirectedEdge[65, 210] -> 
             RGBColor[
              0.9147779513194375, 0.9346667788746255, 0.9842327218730286], 
             UndirectedEdge[49, 76] -> 
             RGBColor[
              0.9454658559884036, 0.935288631420033, 0.6800865977224679], 
             UndirectedEdge[74, 395] -> 
             RGBColor[
              0.9044869423780598, 0.6896123274072175, 0.5796902515098634], 
             UndirectedEdge[52, 88] -> 
             RGBColor[
              0.9894812432342495, 0.9875634993968736, 0.6528219125802939], 
             UndirectedEdge[312, 354] -> 
             RGBColor[
              0.9766784434877072, 0.9809090779069165, 0.8698024557288021], 
             UndirectedEdge[372, 417] -> 
             RGBColor[
              0.909233630743385, 0.8495478480117801, 0.628679668900085], 
             UndirectedEdge[354, 415] -> 
             RGBColor[
              0.8762653371590667, 0.901992982684622, 0.8834625827544655], 
             UndirectedEdge[301, 451] -> 
             RGBColor[
              0.9429820682335168, 0.954614750464439, 0.8856258515693309], 
             UndirectedEdge[243, 428] -> 
             RGBColor[
              0.7732522203784387, 0.8227897785849565, 0.9780342129406326], 
             UndirectedEdge[102, 354] -> 
             RGBColor[
              0.9240264991288667, 0.9395997346981003, 0.8881445870998752], 
             UndirectedEdge[255, 369] -> 
             RGBColor[
              0.9379377648378098, 0.9491725545945299, 0.7934224633769011], 
             UndirectedEdge[300, 409] -> 
             RGBColor[
              0.8025715168852944, 0.8459709546922618, 0.9808830537398913], 
             UndirectedEdge[93, 187] -> 
             RGBColor[
              0.9269166731438363, 0.9437061696995332, 0.9632118461205497], 
             UndirectedEdge[181, 332] -> 
             RGBColor[
              0.966983827128864, 0.9705070914370659, 0.7033736431032489], 
             UndirectedEdge[195, 351] -> 
             RGBColor[
              0.9493662879492479, 0.8319071354342995, 0.5250705750913423], 
             UndirectedEdge[480, 481] -> 
             RGBColor[
              0.7442670526266051, 0.7910113575020614, 0.6848977766487067], 
             UndirectedEdge[47, 365] -> 
             RGBColor[
              0.7358307948744912, 0.7915143411232932, 0.9390432418655412], 
             UndirectedEdge[50, 370] -> 
             RGBColor[
              0.8322011735416127, 0.8691903256396938, 0.953992987387766], 
             UndirectedEdge[122, 150] -> 
             RGBColor[
              0.983472037446628, 0.965616217995515, 0.6150806143722829], 
             UndirectedEdge[246, 256] -> 
             RGBColor[
              0.9897570222391006, 0.9759155467595013, 0.5162907216074972], 
             UndirectedEdge[63, 282] -> 
             RGBColor[
              0.8630561949616167, 0.8936914460348289, 0.9771615250951697], 
             UndirectedEdge[230, 391] -> 
             RGBColor[
              0.7259176068939448, 0.7858116187744832, 0.9733163410356109], 
             UndirectedEdge[312, 415] -> 
             RGBColor[
              0.8614185024016159, 0.8921385615805111, 0.9631534369212807], 
             UndirectedEdge[199, 397] -> 
             RGBColor[
              0.9073668781116424, 0.9256533963751684, 0.8577078423026208], 
             UndirectedEdge[129, 328] -> 
             RGBColor[
              0.9635799248039745, 0.9723585480679797, 0.9465338668166734], 
             UndirectedEdge[188, 304] -> 
             RGBColor[
              0.8636625201908663, 0.8942922192733926, 0.9868137390092165], 
             UndirectedEdge[323, 395] -> 
             RGBColor[
              0.9739717462886823, 0.9763757269896798, 0.696425612347485], 
             UndirectedEdge[49, 238] -> 
             RGBColor[
              0.9858928846761379, 0.9632156327053472, 0.47281631430913723`], 
             UndirectedEdge[171, 385] -> 
             RGBColor[
              0.8942462338386882, 0.9182374788660775, 0.9802681444411809], 
             UndirectedEdge[117, 425] -> 
             RGBColor[
              0.7894900966258337, 0.8358880299100493, 0.9795430289235545], 
             UndirectedEdge[32, 103] -> 
             RGBColor[
              0.9930473013888748, 0.987537205633491, 0.4846198471402142], 
             UndirectedEdge[131, 216] -> 
             RGBColor[
              0.9940050787484291, 0.9895857945594323, 0.5888680020110016], 
             UndirectedEdge[65, 175] -> 
             RGBColor[
              0.9036490795994601, 0.9257929186502909, 0.983171240153516], 
             UndirectedEdge[143, 226] -> 
             RGBColor[
              0.9253346124853077, 0.9065041214172671, 0.6594354296627993], 
             UndirectedEdge[234, 235] -> 
             RGBColor[
              0.8322890766299877, 0.86932291837359, 0.9838088312711606], 
             UndirectedEdge[179, 386] -> 
             RGBColor[
              0.9423727908889206, 0.9565423023176274, 0.982432012828492], 
             UndirectedEdge[267, 476] -> 
             RGBColor[
              0.6848899909660967, 0.751650455068616, 0.9709931800911404], 
             UndirectedEdge[59, 195] -> 
             RGBColor[
              0.9470371272777699, 0.8309439676399443, 0.5636707950923303], 
             UndirectedEdge[75, 108] -> 
             RGBColor[
              0.9938412437469022, 0.9894447735208112, 0.5862571397588807], 
             UndirectedEdge[334, 363] -> 
             RGBColor[
              0.987689216900135, 0.9891771890625807, 0.8536850654575443], 
             UndirectedEdge[77, 329] -> 
             RGBColor[
              0.9732885163536301, 0.9782952595057495, 0.8717066455146781], 
             UndirectedEdge[328, 462] -> 
             RGBColor[
              0.9723094219565347, 0.9772484834514961, 0.8591873878231957], 
             UndirectedEdge[285, 480] -> 
             RGBColor[
              0.7461456226224394, 0.7964967465396384, 0.7645984157842595], 
             UndirectedEdge[204, 334] -> 
             RGBColor[
              0.8972513365042334, 0.9190148909979874, 0.9140071562461489], 
             UndirectedEdge[70, 238] -> 
             RGBColor[
              0.97451643602844, 0.9777073141624897, 0.768926830318848], 
             UndirectedEdge[83, 270] -> 
             RGBColor[
              0.9876382437833499, 0.9891561103688407, 0.8545298219168735], 
             UndirectedEdge[112, 190] -> 
             RGBColor[
              0.7581575482023262, 0.6659119039608232, 0.599958058484207], 
             UndirectedEdge[263, 453] -> 
             RGBColor[
              0.9769968902748785, 0.9791923759112224, 0.7357782285200192], 
             UndirectedEdge[210, 474] -> 
             RGBColor[
              0.690320894497177, 0.7562777946630308, 0.9711694758615474], 
             UndirectedEdge[96, 392] -> 
             RGBColor[
              0.8339106516724217, 0.8689438421796676, 0.8809941493810588], 
             UndirectedEdge[70, 84] -> 
             RGBColor[
              0.7159752115995184, 0.7760997497124911, 0.956390964392639], 
             UndirectedEdge[77, 278] -> 
             RGBColor[
              0.8263933158195238, 0.8629378404223044, 0.8741958850636451], 
             UndirectedEdge[238, 265] -> 
             RGBColor[
              0.9943737040081526, 0.99037424671625, 0.628990586640501], 
             UndirectedEdge[157, 392] -> 
             RGBColor[
              0.9055310298304302, 0.9248942259317383, 0.8881325993453622], 
             UndirectedEdge[145, 294] -> 
             RGBColor[
              0.9186309301022861, 0.9376131287465513, 0.9802348151477204], 
             UndirectedEdge[29, 383] -> 
             RGBColor[
              0.9568274600172124, 0.9673225708861589, 0.9579640283757882], 
             UndirectedEdge[210, 227] -> 
             RGBColor[
              0.9190658014291058, 0.937864650465706, 0.9769745100877764], 
             UndirectedEdge[45, 276] -> 
             RGBColor[
              0.9510705869239923, 0.9615426282629906, 0.9071673241053371], 
             UndirectedEdge[57, 219] -> 
             RGBColor[
              0.9029652899664244, 0.8434014394090552, 0.6278246751408343], 
             UndirectedEdge[291, 311] -> 
             RGBColor[
              0.9901709322402443, 0.9882999309627708, 0.6741914522162363], 
             UndirectedEdge[11, 485] -> 
             RGBColor[
              0.770603922693301, 0.8210884328675043, 0.977672725658721], 
             UndirectedEdge[13, 338] -> 
             RGBColor[
              0.9864720328937109, 0.9649553834871454, 0.49325063869097596`], 
             UndirectedEdge[190, 351] -> 
             RGBColor[
              0.9444525229310519, 0.8107158282892721, 0.5210283948067062], 
             UndirectedEdge[314, 397] -> 
             RGBColor[
              0.9414546967551263, 0.9528321827455029, 0.8609596770380831], 
             UndirectedEdge[339, 365] -> 
             RGBColor[
              0.7142046684644328, 0.7753220677167467, 0.9734475315438411], 
             UndirectedEdge[320, 337] -> 
             RGBColor[
              0.8943441905742255, 0.918589797510285, 0.9897845413590953], 
             UndirectedEdge[317, 357] -> 
             RGBColor[
              0.9902560635404667, 0.9902386461133075, 0.8111457738410844], 
             UndirectedEdge[153, 452] -> 
             RGBColor[
              0.5845854989350538, 0.6478138283242703, 0.872423366611943], 
             UndirectedEdge[308, 423] -> 
             RGBColor[
              0.9914559074694078, 0.9893181764513264, 0.688286775233596], 
             UndirectedEdge[149, 441] -> 
             RGBColor[
              0.9296040597578663, 0.7363462176686175, 0.34719473950900326`], 
             UndirectedEdge[486, 493] -> 
             RGBColor[
              0.9881024229899481, 0.9772636670226286, 0.6056149648442692], 
             UndirectedEdge[241, 402] -> 
             RGBColor[
              0.9688186866690371, 0.9734699384739001, 0.7795235011225361], 
             UndirectedEdge[293, 432] -> 
             RGBColor[
              0.8429431540449924, 0.875357466474663, 0.8527546158744479], 
             UndirectedEdge[23, 211] -> 
             RGBColor[
              0.9674180120470559, 0.9486757528082335, 0.6556074843866928], 
             UndirectedEdge[8, 381] -> 
             RGBColor[
              0.6980236323734235, 0.7581175508687257, 0.8809270451270712], 
             UndirectedEdge[238, 343] -> 
             RGBColor[
              0.9750901041702351, 0.978135154923345, 0.767955759791403], 
             UndirectedEdge[355, 363] -> 
             RGBColor[
              0.9217623775197546, 0.9386117730670871, 0.9234224197181209], 
             UndirectedEdge[66, 398] -> 
             RGBColor[
              0.8125997560094451, 0.8501417548310566, 0.7447952237675273], 
             UndirectedEdge[113, 477] -> 
             RGBColor[
              0.9796793261222339, 0.982933430022741, 0.8551527660615603], 
             UndirectedEdge[7, 241] -> 
             RGBColor[
              0.9547736387853519, 0.9624777375015767, 0.7853585758258252], 
             UndirectedEdge[161, 259] -> 
             RGBColor[
              0.9506981699322072, 0.9627513563765535, 0.9683393177148212], 
             UndirectedEdge[346, 408] -> 
             RGBColor[
              0.7715347876556571, 0.8161954535561899, 0.6917382387602669], 
             UndirectedEdge[33, 270] -> 
             RGBColor[
              0.8770829937033923, 0.9037307655637655, 0.9333784652174625], 
             UndirectedEdge[197, 270] -> 
             RGBColor[
              0.7680553093977825, 0.817151319363554, 0.9234730247466851], 
             UndirectedEdge[115, 381] -> 
             RGBColor[
              0.9768738267077152, 0.9813019144049494, 0.8805382619552399], 
             UndirectedEdge[112, 224] -> 
             RGBColor[
              0.8056263127467909, 0.8443518255759532, 0.7337083568586188], 
             UndirectedEdge[133, 296] -> 
             RGBColor[
              0.9351424510035041, 0.9465887275320972, 0.7643849036540016], 
             UndirectedEdge[204, 244] -> 
             RGBColor[
              0.9005984607675492, 0.9203990128980384, 0.8585366451230829], 
             UndirectedEdge[116, 280] -> 
             RGBColor[
              0.9900213040244334, 0.988689693146815, 0.7095004427112654], 
             UndirectedEdge[81, 267] -> 
             RGBColor[
              0.5241361956312863, 0.6245564015368348, 0.9556810677756931], 
             UndirectedEdge[431, 459] -> 
             RGBColor[
              0.9144956801242914, 0.9294345782060796, 0.7064029501073024], 
             UndirectedEdge[46, 293] -> 
             RGBColor[
              0.7942598867874531, 0.6928960381615957, 0.6029903833393828], 
             UndirectedEdge[145, 358] -> 
             RGBColor[
              0.968579320755762, 0.975423315069661, 0.9083460235970209], 
             UndirectedEdge[12, 480] -> 
             RGBColor[
              0.724201594934292, 0.7829481041763191, 0.9615930022184328], 
             UndirectedEdge[318, 321] -> 
             RGBColor[
              0.9871433260044645, 0.9706956980840651, 0.5788534896142647], 
             UndirectedEdge[38, 47] -> 
             RGBColor[
              0.9559148995368394, 0.8816735396121264, 0.595759405019608], 
             UndirectedEdge[271, 492] -> 
             RGBColor[
              0.9479674039755814, 0.9607147555973208, 0.9729617921815605], 
             UndirectedEdge[246, 333] -> 
             RGBColor[
              0.9806841042027465, 0.9453104638004179, 0.4810441483130672], 
             UndirectedEdge[97, 137] -> 
             RGBColor[
              0.9117284472962119, 0.9315535287624443, 0.9603083334861773], 
             UndirectedEdge[406, 486] -> 
             RGBColor[
              0.9669858040195812, 0.9738925669559302, 0.8957142723642371], 
             UndirectedEdge[272, 306] -> 
             RGBColor[
              0.6046364710930239, 0.6733211047554091, 0.9382340489264145], 
             UndirectedEdge[50, 219] -> 
             RGBColor[
              0.8163852761660592, 0.7753702463080689, 0.6192998045675812], 
             UndirectedEdge[326, 405] -> 
             RGBColor[
              0.9178634930592742, 0.6995885370031756, 0.5570472403697369], 
             UndirectedEdge[180, 343] -> 
             RGBColor[
              0.9754264390029485, 0.978854541121851, 0.804563730714263], 
             UndirectedEdge[229, 380] -> 
             RGBColor[
              0.8496951111847733, 0.8814979423813236, 0.8926864397697157], 
             UndirectedEdge[184, 470] -> 
             RGBColor[
              0.9436577561041107, 0.8595376474480609, 0.606425727516644], 
             UndirectedEdge[188, 483] -> 
             RGBColor[
              0.8926870594443204, 0.9158245441476032, 0.9305699761788597], 
             UndirectedEdge[364, 374] -> 
             RGBColor[
              0.9702822193016143, 0.9077705104445166, 0.4287380907614888], 
             UndirectedEdge[161, 469] -> 
             RGBColor[
              0.9752438819462256, 0.9788230771992973, 0.8131792045037117], 
             UndirectedEdge[14, 182] -> 
             RGBColor[
              0.9153866290583035, 0.9150289306697599, 0.682697074385649], 
             UndirectedEdge[374, 391] -> 
             RGBColor[
              0.7995790984073328, 0.7772903892214631, 0.6209572652596832], 
             UndirectedEdge[352, 367] -> 
             RGBColor[
              0.8735161661058108, 0.897690398440913, 0.7345913523485231], 
             UndirectedEdge[8, 289] -> 
             RGBColor[
              0.6975462090159747, 0.7579201240411999, 0.8888391856920392], 
             UndirectedEdge[160, 275] -> 
             RGBColor[
              0.5658442260349418, 0.6563323864416711, 0.9599904060874427], 
             UndirectedEdge[118, 151] -> 
             RGBColor[
              0.9804979519704172, 0.984257212777188, 0.885707969823551], 
             UndirectedEdge[43, 217] -> 
             RGBColor[
              0.9880859969266427, 0.9875102259939872, 0.7207851115796762], 
             UndirectedEdge[117, 154] -> 
             RGBColor[
              0.8375244822141352, 0.8733779942226831, 0.9559945465802542], 
             UndirectedEdge[139, 468] -> 
             RGBColor[
              0.9179634205141216, 0.9362721121399148, 0.9521308411311635], 
             UndirectedEdge[279, 324] -> 
             RGBColor[
              0.9918699632882219, 0.990906035134336, 0.7843992783821191], 
             UndirectedEdge[4, 29] -> 
             RGBColor[
              0.8941804841051645, 0.9184362857422526, 0.9889723112030224], 
             UndirectedEdge[239, 393] -> 
             RGBColor[
              0.7507342382595483, 0.8008535927403655, 0.81672558376143], 
             UndirectedEdge[94, 127] -> 
             RGBColor[
              0.9926608199354531, 0.9900525021215392, 0.6854775746741323], 
             UndirectedEdge[157, 459] -> 
             RGBColor[
              0.8281031747508873, 0.8657729244840218, 0.9834659059731206], 
             UndirectedEdge[48, 85] -> 
             RGBColor[
              0.9753567018967695, 0.9786567611982048, 0.793115543173163], 
             UndirectedEdge[26, 215] -> 
             RGBColor[
              0.9726344719977872, 0.9174109669193824, 0.4120168815656497], 
             UndirectedEdge[63, 165] -> 
             RGBColor[
              0.8849805457664475, 0.9090391287762405, 0.8951122308626098], 
             UndirectedEdge[165, 282] -> 
             RGBColor[
              0.9683076416487021, 0.9748810093588501, 0.8935939882781115], 
             UndirectedEdge[288, 465] -> 
             RGBColor[
              0.9771330377385781, 0.9820378280075439, 0.9043979729104499], 
             UndirectedEdge[200, 500] -> 
             RGBColor[
              0.9685021916224957, 0.9757243948649748, 0.9245355391500355], 
             UndirectedEdge[293, 353] -> 
             RGBColor[
              0.7705912689269685, 0.8209544945665277, 0.9777043843233739], 
             UndirectedEdge[239, 296] -> 
             RGBColor[
              0.9941983738504174, 0.9899992332374528, 0.6099069809833427], 
             UndirectedEdge[139, 274] -> 
             RGBColor[
              0.9720606964700516, 0.978683493690551, 0.9321781325255056], 
             UndirectedEdge[140, 361] -> 
             RGBColor[
              0.9919418414097907, 0.9908677159053787, 0.7782620873950826], 
             UndirectedEdge[83, 197] -> 
             RGBColor[
              0.7701463955230975, 0.818016037214834, 0.8888183160927963], 
             UndirectedEdge[256, 444] -> 
             RGBColor[
              0.9654543805192533, 0.9602205590888054, 0.686547638582941], 
             UndirectedEdge[21, 166] -> 
             RGBColor[
              0.913173944118733, 0.9307935593460527, 0.8804811932420731], 
             UndirectedEdge[92, 363] -> 
             RGBColor[
              0.9763444462314741, 0.9420132805634629, 0.5904332327341819], 
             UndirectedEdge[41, 212] -> 
             RGBColor[
              0.9047134572772105, 0.9240010696145309, 0.8765127045760073], 
             UndirectedEdge[96, 433] -> 
             RGBColor[
              0.822456144707147, 0.8261495954713384, 0.6500775269591585], 
             UndirectedEdge[346, 407] -> 
             RGBColor[
              0.8725963317854664, 0.8965516905061583, 0.7008496888261329], 
             UndirectedEdge[32, 155] -> 
             RGBColor[
              0.9938458190740154, 0.9892451542194843, 0.571533569287847], 
             UndirectedEdge[302, 477] -> 
             RGBColor[
              0.7806180522691335, 0.8282029071967988, 0.9513732516882742], 
             UndirectedEdge[24, 489] -> 
             RGBColor[
              0.8046272495138693, 0.8469521827619904, 0.9309553352126212], 
             UndirectedEdge[359, 427] -> 
             RGBColor[
              0.6312512784129678, 0.6847355198114796, 0.6671804887843859], 
             UndirectedEdge[217, 290] -> 
             RGBColor[
              0.9507875569574543, 0.9589822920793866, 0.7592771193616903], 
             UndirectedEdge[40, 297] -> 
             RGBColor[
              0.8886958679731838, 0.9124525284677292, 0.9186517145452202], 
             UndirectedEdge[41, 456] -> 
             RGBColor[
              0.8182374363992186, 0.8579325712406944, 0.982517918862839], 
             UndirectedEdge[341, 469] -> 
             RGBColor[
              0.9944982984128994, 0.9906407415495766, 0.642551918689652], 
             UndirectedEdge[169, 498] -> 
             RGBColor[
              0.9499998980991399, 0.9602449166416723, 0.8877863423031662], 
             UndirectedEdge[6, 329] -> 
             RGBColor[
              0.9598372760691349, 0.9298394001539135, 0.6404554173447135], 
             UndirectedEdge[92, 219] -> 
             RGBColor[
              0.9512971741598738, 0.8418192194273015, 0.2942393399779371], 
             UndirectedEdge[341, 387] -> 
             RGBColor[
              0.9513388586422018, 0.9599829767222858, 0.8048136102015154], 
             UndirectedEdge[13, 478] -> 
             RGBColor[
              0.9807029741171546, 0.9632191364113056, 0.6429597569918046], 
             UndirectedEdge[33, 267] -> 
             RGBColor[
              0.611382525193518, 0.6934527627175229, 0.9638718002133402], 
             UndirectedEdge[10, 123] -> 
             RGBColor[
              0.9735206104478606, 0.9320053126114187, 0.576128095030352], 
             UndirectedEdge[57, 337] -> 
             RGBColor[
              0.8883243114325493, 0.9137897092879788, 0.9892103599125528], 
             UndirectedEdge[70, 135] -> 
             RGBColor[
              0.9705241661871248, 0.9772518383124309, 0.9219842383472898], 
             UndirectedEdge[51, 130] -> 
             RGBColor[
              0.9665546066453901, 0.972951535752792, 0.8687041684870518], 
             UndirectedEdge[219, 361] -> 
             RGBColor[
              0.9629261841388872, 0.8891006681858672, 0.5527805917410029], 
             UndirectedEdge[70, 131] -> 
             RGBColor[
              0.9742625932193587, 0.9771643700613096, 0.7412976070865774], 
             UndirectedEdge[61, 362] -> 
             RGBColor[
              0.9903411875406196, 0.9896587198507457, 0.7650217932775747], 
             UndirectedEdge[49, 487] -> 
             RGBColor[
              0.9824729121933097, 0.9629968165203941, 0.6163892740493604], 
             UndirectedEdge[83, 375] -> 
             RGBColor[
              0.9749792222301936, 0.9799401737442095, 0.8860405139027201], 
             UndirectedEdge[147, 385] -> 
             RGBColor[
              0.7225790253794291, 0.782779775103593, 0.9733482633962001], 
             UndirectedEdge[105, 395] -> 
             RGBColor[
              0.9614462064649896, 0.970767224424408, 0.9501456954017046], 
             UndirectedEdge[57, 204] -> 
             RGBColor[
              0.837574681642123, 0.8734332024806233, 0.9843406586856837], 
             UndirectedEdge[362, 363] -> 
             RGBColor[
              0.9909176599375413, 0.9898971060015376, 0.7554681537978435], 
             UndirectedEdge[313, 390] -> 
             RGBColor[
              0.9928723250663924, 0.9891056718383102, 0.606790198184394], 
             UndirectedEdge[15, 430] -> 
             RGBColor[
              0.9693907872992797, 0.9741489409540147, 0.7985764510667415], 
             UndirectedEdge[104, 430] -> 
             RGBColor[
              0.9895197861409053, 0.989066118875919, 0.7602491711241288], 
             UndirectedEdge[341, 405] -> 
             RGBColor[
              0.988203064148236, 0.9881801971498871, 0.766818733558041], 
             UndirectedEdge[8, 311] -> 
             RGBColor[
              0.699542473771974, 0.7568421196493496, 0.7173907449352748], 
             UndirectedEdge[305, 460] -> 
             RGBColor[
              0.739789353444875, 0.7965167616134244, 0.9749737573852786], 
             UndirectedEdge[451, 456] -> 
             RGBColor[
              0.9058957634991774, 0.9250450526769931, 0.8820880185537426], 
             UndirectedEdge[257, 306] -> 
             RGBColor[
              0.6175814992618391, 0.6800182655559914, 0.7453606514875053], 
             UndirectedEdge[65, 167] -> 
             RGBColor[
              0.969578839497287, 0.9748417637312512, 0.8421024918211147], 
             UndirectedEdge[24, 329] -> 
             RGBColor[
              0.9697653385746035, 0.9768383349525829, 0.930094819004968], 
             UndirectedEdge[14, 63] -> 
             RGBColor[
              0.81486045550251, 0.8555369900706915, 0.9821169697847136], 
             UndirectedEdge[64, 172] -> 
             RGBColor[
              0.7881953377564752, 0.8353490254707788, 0.9792886001754563], 
             UndirectedEdge[50, 361] -> 
             RGBColor[
              0.8421396478464902, 0.8758567113041129, 0.9037752268903723], 
             UndirectedEdge[253, 291] -> 
             RGBColor[
              0.8926491352236089, 0.915575094458132, 0.9205984880683677], 
             UndirectedEdge[184, 280] -> 
             RGBColor[
              0.973245182584402, 0.9791928129202596, 0.9134215514439559], 
             UndirectedEdge[402, 487] -> 
             RGBColor[
              0.9653901028518103, 0.9732327035154074, 0.9221591702564481], 
             UndirectedEdge[356, 463] -> 
             RGBColor[
              0.9149213460129626, 0.6486016504340619, 0.5003670049914191], 
             UndirectedEdge[287, 301] -> 
             RGBColor[
              0.9429801532259094, 0.9546139585595799, 0.8856575882012652], 
             UndirectedEdge[265, 328] -> 
             RGBColor[
              0.9727619324575949, 0.9770638889496751, 0.8246680543165913], 
             UndirectedEdge[196, 321] -> 
             RGBColor[
              0.9416957063783278, 0.7943062985378829, 0.5023154130359916], 
             UndirectedEdge[122, 267] -> 
             RGBColor[
              0.7208549861297472, 0.7784303463852547, 0.9029677751928074], 
             UndirectedEdge[330, 354] -> 
             RGBColor[
              0.9920818726886673, 0.9887131247544627, 0.6151161814465924], 
             UndirectedEdge[155, 393] -> 
             RGBColor[
              0.7506014581650238, 0.8005695895443043, 0.802273289896187], 
             UndirectedEdge[291, 319] -> 
             RGBColor[
              0.9052589723825115, 0.9254524057836482, 0.9218483102033669], 
             UndirectedEdge[63, 206] -> 
             RGBColor[
              0.8651407565407923, 0.8952461086474218, 0.9736329060823592], 
             UndirectedEdge[174, 215] -> 
             RGBColor[
              0.994140029478166, 0.989874440524728, 0.603556556123505], 
             UndirectedEdge[254, 471] -> 
             RGBColor[
              0.9887817623598214, 0.989235381610702, 0.8153185288095648], 
             UndirectedEdge[453, 463] -> 
             RGBColor[
              0.9165949799615378, 0.6476464306389094, 0.3528884799015098], 
             UndirectedEdge[154, 174] -> 
             RGBColor[
              0.9809244640491486, 0.9830369450573633, 0.8017622356096167], 
             UndirectedEdge[119, 197] -> 
             RGBColor[
              0.7720927469035698, 0.8188209035296081, 0.8565622367224622], 
             UndirectedEdge[50, 340] -> 
             RGBColor[
              0.8206132862052984, 0.8605480982376945, 0.9736082580430914], 
             UndirectedEdge[443, 446] -> 
             RGBColor[
              0.9887930043306207, 0.9725219475289555, 0.5245982799447001], 
             UndirectedEdge[275, 324] -> 
             RGBColor[
              0.705454812672119, 0.7637292024092142, 0.8510825002971317], 
             UndirectedEdge[95, 286] -> 
             RGBColor[
              0.8711518197183341, 0.8981150810813043, 0.8882498977832568], 
             UndirectedEdge[306, 317] -> 
             RGBColor[
              0.6154195332199599, 0.6805048918739861, 0.8815490554561631], 
             UndirectedEdge[118, 188] -> 
             RGBColor[
              0.8858904949399292, 0.9110677866314213, 0.9560516730452455], 
             UndirectedEdge[7, 69] -> 
             RGBColor[
              0.9413810276502741, 0.955285219660782, 0.9661712814696144], 
             UndirectedEdge[88, 166] -> 
             RGBColor[
              0.992436533496135, 0.9887855878676587, 0.6038451048948175], 
             UndirectedEdge[9, 44] -> 
             RGBColor[
              0.8302063084964522, 0.867706153506656, 0.9575517494140328], 
             UndirectedEdge[76, 459] -> 
             RGBColor[
              0.8747507522876543, 0.9029665216702872, 0.9879157017240534], 
             UndirectedEdge[254, 325] -> 
             RGBColor[
              0.9945604257996274, 0.9919242312207186, 0.7329509728054768], 
             UndirectedEdge[171, 433] -> 
             RGBColor[
              0.9573692694398732, 0.9322917717772043, 0.6537463500395204], 
             UndirectedEdge[112, 447] -> 
             RGBColor[
              0.7638436768540943, 0.6901653755380399, 0.6046217006781197], 
             UndirectedEdge[199, 359] -> 
             RGBColor[
              0.5487530911480626, 0.6341923609065088, 0.9608988640474148], 
             UndirectedEdge[74, 224] -> 
             RGBColor[
              0.9234133593685093, 0.7004548147144647, 0.3516517234308077], 
             UndirectedEdge[292, 386] -> 
             RGBColor[
              0.9655571603044119, 0.9732914589621613, 0.9189281271606927], 
             UndirectedEdge[112, 195] -> 
             RGBColor[
              0.7630713132205222, 0.6871032111058506, 0.6040002387688431], 
             UndirectedEdge[97, 408] -> 
             RGBColor[
              0.7605429998634559, 0.8117737921355984, 0.9462716757621311], 
             UndirectedEdge[236, 422] -> 
             RGBColor[
              0.9932088964554411, 0.9900780226160752, 0.661774992603134], 
             UndirectedEdge[27, 114] -> 
             RGBColor[
              0.8411492284445206, 0.8763586111578527, 0.9638950259056807], 
             UndirectedEdge[110, 355] -> 
             RGBColor[
              0.900149135203746, 0.9230034146650306, 0.9828809819543782], 
             UndirectedEdge[104, 215] -> 
             RGBColor[
              0.9891785955842349, 0.9883363467748578, 0.7231126846145911], 
             UndirectedEdge[80, 406] -> 
             RGBColor[
              0.8859709983649902, 0.91170630235943, 0.9818111949027444], 
             UndirectedEdge[276, 292] -> 
             RGBColor[
              0.9885024333121654, 0.9895134749476637, 0.8402079649735905], 
             UndirectedEdge[425, 466] -> 
             RGBColor[
              0.926722034579202, 0.9260884090982938, 0.6867513137037272], 
             UndirectedEdge[164, 309] -> 
             RGBColor[
              0.7868330869649134, 0.8339113489807629, 0.9696396377073707], 
             UndirectedEdge[95, 137] -> 
             RGBColor[
              0.9219121047616132, 0.9380357270104096, 0.8932385340259879], 
             UndirectedEdge[119, 426] -> 
             RGBColor[
              0.9889063872136804, 0.98968031122733, 0.8335040421991207], 
             UndirectedEdge[238, 431] -> 
             RGBColor[
              0.993214192756902, 0.9878941693943957, 0.5027849426158452], 
             UndirectedEdge[93, 266] -> 
             RGBColor[
              0.7869098235715877, 0.8332333041861032, 0.9497886621870709], 
             UndirectedEdge[15, 148] -> 
             RGBColor[
              0.8866411039716893, 0.9122204622119494, 0.981176005785704], 
             UndirectedEdge[225, 470] -> 
             RGBColor[
              0.960802256855668, 0.8698224537731083, 0.44260043346994615`], 
             UndirectedEdge[249, 296] -> 
             RGBColor[
              0.8265940792864992, 0.8613313169388175, 0.7536875141085075], 
             UndirectedEdge[273, 421] -> 
             RGBColor[
              0.8784529157372021, 0.8692181572073376, 0.6546708075641585], 
             UndirectedEdge[150, 159] -> 
             RGBColor[
              0.9637530166311286, 0.9514699750047121, 0.6735453501565432], 
             UndirectedEdge[85, 407] -> 
             RGBColor[
              0.8545201321343097, 0.8868464863208176, 0.9673751871946731], 
             UndirectedEdge[71, 388] -> 
             RGBColor[
              0.984851105022339, 0.987068054182815, 0.858826202620099], 
             UndirectedEdge[61, 435] -> 
             RGBColor[
              0.8880262618966022, 0.9121756291469714, 0.9297488201191546], 
             UndirectedEdge[10, 177] -> 
             RGBColor[
              0.8934479464140022, 0.9161391904634697, 0.9179601099788758], 
             UndirectedEdge[16, 52] -> 
             RGBColor[
              0.7604536860779205, 0.8108081301898137, 0.915690638317889], 
             UndirectedEdge[25, 459] -> 
             RGBColor[
              0.8022215289377925, 0.8455539860670386, 0.9808862653962027], 
             UndirectedEdge[105, 453] -> 
             RGBColor[
              0.9804446071039996, 0.9817636774772629, 0.7299421432368804], 
             UndirectedEdge[61, 384] -> 
             RGBColor[
              0.9873772309899193, 0.9890481748710342, 0.8588554793834746], 
             UndirectedEdge[104, 323] -> 
             RGBColor[
              0.9886658020533625, 0.9872395332637006, 0.6672982733739637], 
             UndirectedEdge[150, 406] -> 
             RGBColor[
              0.9615520901666628, 0.9498285276512, 0.6772709445673268], 
             UndirectedEdge[413, 493] -> 
             RGBColor[
              0.9388037151494912, 0.9403669579125782, 0.6947369971055835], 
             UndirectedEdge[94, 254] -> 
             RGBColor[
              0.9945430573324506, 0.990736476352676, 0.6474236508627784], 
             UndirectedEdge[431, 487] -> 
             RGBColor[
              0.9897942202740738, 0.9876753532094424, 0.6463579023560683], 
             UndirectedEdge[234, 332] -> 
             RGBColor[
              0.9315653506544935, 0.9424260514849466, 0.7055666820727398], 
             UndirectedEdge[82, 89] -> 
             RGBColor[
              0.9688547770530297, 0.9736021126463773, 0.7878141834493414], 
             UndirectedEdge[154, 255] -> 
             RGBColor[
              0.9244732196268632, 0.9418025165493362, 0.964528230125123], 
             UndirectedEdge[22, 324] -> 
             RGBColor[
              0.9927728734569979, 0.9912794116928578, 0.7694357202288857], 
             UndirectedEdge[105, 112] -> 
             RGBColor[
              0.7927704155481151, 0.8380367219898471, 0.9514710783753346], 
             UndirectedEdge[6, 406] -> 
             RGBColor[
              0.9544309961582155, 0.9258074054483207, 0.6496068390502739], 
             UndirectedEdge[396, 422] -> 
             RGBColor[
              0.9798658643020381, 0.9830848715836626, 0.8553887961159099], 
             UndirectedEdge[409, 456] -> 
             RGBColor[
              0.7853349338296762, 0.8322288861650868, 0.9792385048980752], 
             UndirectedEdge[91, 473] -> 
             RGBColor[
              0.9823448591673354, 0.9661265976744859, 0.6405103854404818], 
             UndirectedEdge[369, 379] -> 
             RGBColor[
              0.9301270908529186, 0.9429445351740748, 0.7926774743195513], 
             UndirectedEdge[353, 441] -> 
             RGBColor[
              0.8581350374949503, 0.6842382854791598, 0.5978004125660926], 
             UndirectedEdge[165, 481] -> 
             RGBColor[
              0.9901787454682907, 0.9842909106098405, 0.6138422748028414], 
             UndirectedEdge[185, 318] -> 
             RGBColor[
              0.8740542466569524, 0.8838002330235897, 0.6805446072340816], 
             UndirectedEdge[264, 445] -> 
             RGBColor[
              0.9785152001731265, 0.980709815158807, 0.7637630697004535], 
             UndirectedEdge[258, 297] -> 
             RGBColor[
              0.7896258190481551, 0.8355809583096978, 0.9796661802360509], 
             UndirectedEdge[57, 139] -> 
             RGBColor[
              0.9245464699886149, 0.941521257098758, 0.9527587382667984], 
             UndirectedEdge[447, 463] -> 
             RGBColor[
              0.8747403604202808, 0.4933060148553882, 0.2159668478067791], 
             UndirectedEdge[9, 26] -> 
             RGBColor[
              0.8237386712565694, 0.8042008042137473, 0.6251449479614544], 
             UndirectedEdge[181, 262] -> 
             RGBColor[
              0.9399218959245017, 0.8738832725148717, 0.6260413086140495], 
             UndirectedEdge[203, 291] -> 
             RGBColor[
              0.99059005783937, 0.9891963982392025, 0.7198106871377036], 
             UndirectedEdge[45, 254] -> 
             RGBColor[
              0.9538807647863676, 0.9626103297235433, 0.8537350253497287], 
             UndirectedEdge[240, 412] -> 
             RGBColor[
              0.8776293714833701, 0.47206431552500777`, 0.2169475091796825], 
             UndirectedEdge[208, 258] -> 
             RGBColor[
              0.8894123657528293, 0.9126336265698909, 0.9015541912414591], 
             UndirectedEdge[293, 420] -> 
             RGBColor[
              0.8414131256555772, 0.8747247604157037, 0.8781111458736013], 
             UndirectedEdge[85, 346] -> 
             RGBColor[
              0.9744299145226273, 0.9766744567174919, 0.6922404569664661], 
             UndirectedEdge[65, 166] -> 
             RGBColor[
              0.9682046062481606, 0.974457170766296, 0.8782292570950512], 
             UndirectedEdge[254, 347] -> 
             RGBColor[
              0.9272133907159827, 0.9413464895064041, 0.8511914674046495], 
             UndirectedEdge[236, 292] -> 
             RGBColor[
              0.9905665021595176, 0.988985324668275, 0.7055663043838174], 
             UndirectedEdge[100, 401] -> 
             RGBColor[
              0.9796574621275677, 0.9829986919288275, 0.8588425594744252], 
             UndirectedEdge[146, 400] -> 
             RGBColor[
              0.99154922648657, 0.988700474636049, 0.6390347644964759], 
             UndirectedEdge[104, 153] -> 
             RGBColor[
              0.9875038980363419, 0.9891005549499247, 0.8567562786204439], 
             UndirectedEdge[216, 281] -> 
             RGBColor[
              0.9940218773090626, 0.9896217249820325, 0.5906964216672632], 
             UndirectedEdge[123, 125] -> 
             RGBColor[
              0.8493002709699076, 0.8355118421235157, 0.6358010621363224], 
             UndirectedEdge[78, 358] -> 
             RGBColor[
              0.8484162113214655, 0.8808506801394896, 0.9085121673008889], 
             UndirectedEdge[313, 478] -> 
             RGBColor[
              0.987867368258516, 0.9890037616109169, 0.839667100285286], 
             UndirectedEdge[368, 401] -> 
             RGBColor[
              0.8948207845800574, 0.91634242502077, 0.8786820429821085], 
             UndirectedEdge[106, 369] -> 
             RGBColor[
              0.9945125409773106, 0.9906712049547084, 0.6441021339309089], 
             UndirectedEdge[111, 146] -> 
             RGBColor[
              0.9788289229570575, 0.9827298678502219, 0.8758784301433613], 
             UndirectedEdge[129, 266] -> 
             RGBColor[
              0.7907057215113049, 0.8360642786543317, 0.9433631971038707], 
             UndirectedEdge[99, 278] -> 
             RGBColor[
              0.7625150502620277, 0.8147598807772054, 0.9768690137633544], 
             UndirectedEdge[147, 171] -> 
             RGBColor[
              0.7746653658491733, 0.8240377985458645, 0.9688092513311974], 
             UndirectedEdge[164, 166] -> 
             RGBColor[
              0.9693985663494828, 0.9753476242549319, 0.8762081940781796], 
             UndirectedEdge[129, 433] -> 
             RGBColor[
              0.9724465318361896, 0.9435363693856258, 0.6282244775823818], 
             UndirectedEdge[179, 283] -> 
             RGBColor[
              0.956207677459306, 0.9668603380692731, 0.9590131585811438], 
             UndirectedEdge[136, 291] -> 
             RGBColor[
              0.9421133249012644, 0.9548390660973525, 0.9253635112468744], 
             UndirectedEdge[321, 479] -> 
             RGBColor[
              0.9908898873594674, 0.9905007485509935, 0.80064167287678], 
             UndirectedEdge[181, 239] -> 
             RGBColor[
              0.9683824836712359, 0.9737861467878502, 0.8311643656637471], 
             UndirectedEdge[102, 330] -> 
             RGBColor[
              0.9245830935723761, 0.9375493604415355, 0.7131491669844806], 
             UndirectedEdge[406, 413] -> 
             RGBColor[
              0.9176870961791244, 0.9369958578458797, 0.9848363046255513], 
             UndirectedEdge[37, 310] -> 
             RGBColor[
              0.875687107622765, 0.9014024807933976, 0.8771118679832519], 
             UndirectedEdge[203, 439] -> 
             RGBColor[
              0.9936862542126773, 0.9889038611155646, 0.5541659188513833], 
             UndirectedEdge[320, 375] -> 
             RGBColor[
              0.9205138201547338, 0.9388241856705992, 0.9703492291494986], 
             UndirectedEdge[42, 407] -> 
             RGBColor[
              0.850396299418692, 0.8837709386336665, 0.9743557603143849], 
             UndirectedEdge[131, 374] -> 
             RGBColor[
              0.9700075385513025, 0.9071829960940838, 0.3988407862231555], 
             UndirectedEdge[387, 403] -> 
             RGBColor[
              0.9515435215070072, 0.9604207298955145, 0.8270899000027849], 
             UndirectedEdge[65, 348] -> 
             RGBColor[
              0.9693722036689973, 0.9743997905886268, 0.8196114571203112], 
             UndirectedEdge[217, 498] -> 
             RGBColor[
              0.9507875569574543, 0.9589822920793866, 0.7592771193616903], 
             UndirectedEdge[40, 397] -> 
             RGBColor[
              0.9912196495126324, 0.9906371136758281, 0.7951766606017374], 
             UndirectedEdge[226, 292] -> 
             RGBColor[
              0.9350591544629343, 0.9491785129720349, 0.9231383289054235], 
             UndirectedEdge[53, 257] -> 
             RGBColor[
              0.973043463883613, 0.9764592200062693, 0.7595537222879609], 
             UndirectedEdge[220, 429] -> 
             RGBColor[
              0.9892955217905874, 0.9898414374149355, 0.8270644364389473], 
             UndirectedEdge[139, 425] -> 
             RGBColor[
              0.9257138317170466, 0.9424520796538194, 0.9528700822705722], 
             UndirectedEdge[317, 418] -> 
             RGBColor[
              0.9914738899296027, 0.9892826906916865, 0.6848687852878325], 
             UndirectedEdge[482, 496] -> 
             RGBColor[
              0.7575332213784003, 0.8105099770973093, 0.9764674900227063], 
             UndirectedEdge[117, 466] -> 
             RGBColor[
              0.8451186402737798, 0.8619261182699332, 0.6787274737562773], 
             UndirectedEdge[82, 105] -> 
             RGBColor[
              0.9555808253825007, 0.9663928328167679, 0.9600742556379691], 
             UndirectedEdge[239, 453] -> 
             RGBColor[
              0.9941035057068555, 0.9897963198710142, 0.599581169014934], 
             UndirectedEdge[274, 340] -> 
             RGBColor[
              0.9547075264871002, 0.9657415279304739, 0.9615525228750519], 
             UndirectedEdge[311, 484] -> 
             RGBColor[
              0.9842487054699326, 0.984393906263015, 0.7070892180059123], 
             UndirectedEdge[44, 140] -> 
             RGBColor[
              0.9799069762548546, 0.9826378453775109, 0.8320284907753235], 
             UndirectedEdge[139, 466] -> 
             RGBColor[
              0.9813423753649926, 0.9684901680137032, 0.652054527103295], 
             UndirectedEdge[22, 481] -> 
             RGBColor[
              0.9909943073246419, 0.9846281663964254, 0.6003263042366749], 
             UndirectedEdge[45, 386] -> 
             RGBColor[
              0.9281253139162388, 0.9453206122774882, 0.9858874862924394], 
             UndirectedEdge[40, 220] -> 
             RGBColor[
              0.9893886554702475, 0.9898799505849013, 0.8255209703447439], 
             UndirectedEdge[237, 489] -> 
             RGBColor[
              0.6655929957007074, 0.7384083240872422, 0.9674933048549466], 
             UndirectedEdge[61, 64] -> 
             RGBColor[
              0.8164777346891596, 0.8562813759035703, 0.9226175315861185], 
             UndirectedEdge[82, 296] -> 
             RGBColor[
              0.968603574373299, 0.9730648155149202, 0.7604723220038937], 
             UndirectedEdge[27, 277] -> 
             RGBColor[
              0.8586065903489446, 0.8878045357942901, 0.8638686468965046], 
             UndirectedEdge[416, 427] -> 
             RGBColor[
              0.6945907716704689, 0.7424619558554021, 0.6711115254130032], 
             UndirectedEdge[59, 82] -> 
             RGBColor[
              0.9648003287311, 0.9729757031951597, 0.9313460014974263], 
             UndirectedEdge[271, 444] -> 
             RGBColor[
              0.9490616284840634, 0.9615308264441185, 0.9711095555081594], 
             UndirectedEdge[6, 486] -> 
             RGBColor[
              0.977692943116519, 0.9421500471474473, 0.5651761012013264], 
             UndirectedEdge[171, 265] -> 
             RGBColor[
              0.9705918443583692, 0.9754454407984657, 0.8283414474189574], 
             UndirectedEdge[219, 369] -> 
             RGBColor[
              0.9656315824941042, 0.8891922643219441, 0.433281770053086], 
             UndirectedEdge[244, 355] -> 
             RGBColor[
              0.9255323620815487, 0.9401707585675729, 0.8609440191218976], 
             UndirectedEdge[450, 500] -> 
             RGBColor[
              0.972013162031561, 0.9752514589996071, 0.7264361343452647], 
             UndirectedEdge[18, 243] -> 
             RGBColor[
              0.738012162598146, 0.795259977612633, 0.9745218133181566], 
             UndirectedEdge[377, 449] -> 
             RGBColor[
              0.953875306015797, 0.8483280982407435, 0.31564881432234715`], 
             UndirectedEdge[7, 173] -> 
             RGBColor[
              0.8899589230015292, 0.9150931041827342, 0.989366270623237], 
             UndirectedEdge[3, 8] -> 
             RGBColor[
              0.6720787843262349, 0.7397391296119956, 0.9683374019141657], 
             UndirectedEdge[405, 469] -> 
             RGBColor[
              0.9884240223003078, 0.9886528042948726, 0.7908686648154024], 
             UndirectedEdge[148, 190] -> 
             RGBColor[
              0.8635336994946197, 0.74867639955195, 0.6101872383631453], 
             UndirectedEdge[180, 216] -> 
             RGBColor[
              0.9945952563902236, 0.9908481248591182, 0.6531051961661323], 
             UndirectedEdge[257, 317] -> 
             RGBColor[
              0.9915196209601939, 0.9893805047420046, 0.6898463257484718], 
             UndirectedEdge[49, 462] -> 
             RGBColor[
              0.985917784575231, 0.9644213597795006, 0.5592988236369771], 
             UndirectedEdge[223, 258] -> 
             RGBColor[
              0.8853051512226607, 0.89195568047516, 0.6807403880560214], 
             UndirectedEdge[260, 440] -> 
             RGBColor[
              0.9173201549351298, 0.9338416866569826, 0.8696756416430118], 
             UndirectedEdge[262, 332] -> 
             RGBColor[
              0.9649752791733688, 0.888177963309289, 0.3462341607852757], 
             UndirectedEdge[283, 386] -> 
             RGBColor[
              0.9574965832182323, 0.9678216018738909, 0.9568313773317423], 
             UndirectedEdge[40, 289] -> 
             RGBColor[
              0.9882678011639052, 0.989416448524587, 0.8440964268787974], 
             UndirectedEdge[95, 430] -> 
             RGBColor[
              0.9925828137997095, 0.9903327595290548, 0.7094868759562656], 
             UndirectedEdge[274, 334] -> 
             RGBColor[
              0.9759496488179396, 0.9809326007374443, 0.8964300726826292], 
             UndirectedEdge[75, 158] -> 
             RGBColor[
              0.9910487804113597, 0.9905664549113161, 0.7980084038048875], 
             UndirectedEdge[233, 476] -> 
             RGBColor[
              0.8407222254378526, 0.8762709607405244, 0.9845538351578227], 
             UndirectedEdge[240, 416] -> 
             RGBColor[
              0.6133428057538239, 0.34836773537326576`, 0.5579644876090089], 
             UndirectedEdge[260, 280] -> 
             RGBColor[
              0.9900541008439974, 0.9901551293481129, 0.8144928183842858], 
             UndirectedEdge[11, 193] -> 
             RGBColor[
              0.9256647767875192, 0.941990545811847, 0.9353932768990354], 
             UndirectedEdge[3, 162] -> 
             RGBColor[
              0.9665519382334811, 0.9725053676183801, 0.8409628450060561], 
             UndirectedEdge[117, 338] -> 
             RGBColor[
              0.8510647507570008, 0.8809099968180483, 0.7931307972011818], 
             UndirectedEdge[40, 472] -> 
             RGBColor[
              0.8975742630573674, 0.9193883981857953, 0.9195366299938923], 
             UndirectedEdge[101, 355] -> 
             RGBColor[
              0.9094801693068071, 0.9299624846209276, 0.9670859751413561], 
             UndirectedEdge[47, 364] -> 
             RGBColor[
              0.9852125342957625, 0.9857134760838073, 0.7531244804466459], 
             UndirectedEdge[377, 484] -> 
             RGBColor[
              0.9766994502226569, 0.9592818291861016, 0.6477168546767016], 
             UndirectedEdge[21, 227] -> 
             RGBColor[
              0.8933457922726791, 0.9173562133154214, 0.9745213126539132], 
             UndirectedEdge[158, 441] -> 
             RGBColor[
              0.9266107798650042, 0.7370383727486844, 0.5370883605869062], 
             UndirectedEdge[201, 222] -> 
             RGBColor[
              0.8778837439970252, 0.902514723122215, 0.8481478845968908], 
             UndirectedEdge[107, 477] -> 
             RGBColor[
              0.9289197543117795, 0.9453639266283026, 0.9655023600766115], 
             UndirectedEdge[89, 239] -> 
             RGBColor[
              0.9944495765301482, 0.9905365303689098, 0.6372488424287904], 
             UndirectedEdge[63, 275] -> 
             RGBColor[
              0.5984780468379198, 0.6818261752791819, 0.9632430403646892], 
             UndirectedEdge[133, 344] -> 
             RGBColor[
              0.8947549122495526, 0.9189172958254481, 0.9898237163591437], 
             UndirectedEdge[153, 356] -> 
             RGBColor[
              0.9901346089620966, 0.9901884215239112, 0.8131585905190503], 
             UndirectedEdge[151, 188] -> 
             RGBColor[
              0.8939109431164809, 0.9163306514984172, 0.9102870564217477], 
             UndirectedEdge[140, 204] -> 
             RGBColor[
              0.9007968614050583, 0.9204130139809028, 0.850302648617141], 
             UndirectedEdge[154, 369] -> 
             RGBColor[
              0.9806268073188055, 0.9824002874088714, 0.7693641374361819], 
             UndirectedEdge[16, 179] -> 
             RGBColor[
              0.7377906148028617, 0.7942745437230996, 0.97055526472238], 
             UndirectedEdge[161, 341] -> 
             RGBColor[
              0.9750229237941539, 0.978350470054312, 0.7891292732463503], 
             UndirectedEdge[48, 408] -> 
             RGBColor[
              0.7724615750297992, 0.8181777580369028, 0.7926133249669638], 
             UndirectedEdge[153, 263] -> 
             RGBColor[
              0.9754326452343143, 0.9801928308310044, 0.8814438963147639], 
             UndirectedEdge[62, 132] -> 
             RGBColor[
              0.8911864900246557, 0.9140897215961755, 0.9049112680442601], 
             UndirectedEdge[82, 225] -> 
             RGBColor[
              0.9689903575982152, 0.9738921057232333, 0.8025712890866458], 
             UndirectedEdge[216, 465] -> 
             RGBColor[
              0.9906967078191645, 0.9898511020610691, 0.7624274906959931], 
             UndirectedEdge[119, 489] -> 
             RGBColor[
              0.808941135715629, 0.8487360855682365, 0.8594630768698432], 
             UndirectedEdge[287, 295] -> 
             RGBColor[
              0.9314064665641207, 0.9453854149748249, 0.8845536796355118], 
             UndirectedEdge[28, 417] -> 
             RGBColor[
              0.9261848222015048, 0.912070646308549, 0.6667082806191316], 
             UndirectedEdge[148, 351] -> 
             RGBColor[
              0.909695230860486, 0.9283472557537209, 0.8943717841127419], 
             UndirectedEdge[218, 336] -> 
             RGBColor[
              0.9762247438748817, 0.9804988593223563, 0.8673528540372907], 
             UndirectedEdge[127, 254] -> 
             RGBColor[
              0.993290360991107, 0.9913990267832186, 0.7539992335050231], 
             UndirectedEdge[303, 473] -> 
             RGBColor[
              0.9636932957126366, 0.9723670867131818, 0.9429379333602839], 
             UndirectedEdge[99, 267] -> 
             RGBColor[
              0.6592151526737188, 0.7311780359391935, 0.9685442910946147], 
             UndirectedEdge[48, 145] -> 
             RGBColor[
              0.9716654856431403, 0.9759038581600601, 0.7993638094671724], 
             UndirectedEdge[224, 342] -> 
             RGBColor[
              0.9655199334515598, 0.9705325998458099, 0.7472488972972522], 
             UndirectedEdge[193, 232] -> 
             RGBColor[
              0.9032315165313283, 0.9241028730181883, 0.933253572509392], 
             UndirectedEdge[216, 343] -> 
             RGBColor[
              0.9754527321197464, 0.9789107794400399, 0.8074255742154097], 
             UndirectedEdge[277, 449] -> 
             RGBColor[
              0.9617191201757911, 0.875465494168005, 0.5085047417560592], 
             UndirectedEdge[257, 418] -> 
             RGBColor[
              0.9936358559714821, 0.9887960643736918, 0.5486803813191747], 
             UndirectedEdge[45, 422] -> 
             RGBColor[
              0.9526631718687273, 0.9622012030652047, 0.8807740700933581], 
             UndirectedEdge[133, 235] -> 
             RGBColor[
              0.8351036700486839, 0.8715671987655553, 0.9840772897040531], 
             UndirectedEdge[145, 183] -> 
             RGBColor[
              0.9458679466227298, 0.95914898374111, 0.9765156258537646], 
             UndirectedEdge[196, 496] -> 
             RGBColor[
              0.8014238302147206, 0.6861754260077666, 0.601297203506859], 
             UndirectedEdge[115, 136] -> 
             RGBColor[
              0.9303350607672858, 0.9465656183201551, 0.9681740207940817], 
             UndirectedEdge[267, 413] -> 
             RGBColor[
              0.6728982779676287, 0.7420885886300157, 0.969849399800218], 
             UndirectedEdge[217, 340] -> 
             RGBColor[
              0.9695343376044968, 0.9736744288470849, 0.7521882317643971], 
             UndirectedEdge[335, 383] -> 
             RGBColor[
              0.6071468599210079, 0.6745442631889036, 0.9302642523232918], 
             UndirectedEdge[80, 493] -> 
             RGBColor[
              0.907087617335357, 0.9150774024261283, 0.6917118873827766], 
             UndirectedEdge[307, 372] -> 
             RGBColor[
              0.715952071515968, 0.6957925685952493, 0.6110988809935345], 
             UndirectedEdge[18, 434] -> 
             RGBColor[
              0.8532690898544639, 0.8622852916758457, 0.6707663157959871], 
             UndirectedEdge[130, 179] -> 
             RGBColor[
              0.9675300848893784, 0.9736790458299596, 0.8670529382654522], 
             UndirectedEdge[20, 228] -> 
             RGBColor[
              0.9845010861279428, 0.9592300726664051, 0.4070954092274125], 
             UndirectedEdge[297, 311] -> 
             RGBColor[
              0.8915073099321112, 0.9117116207983882, 0.7336936779249583], 
             UndirectedEdge[127, 200] -> 
             RGBColor[
              0.9887184994839688, 0.9896028238623518, 0.8366271893454801], 
             UndirectedEdge[54, 391] -> 
             RGBColor[
              0.5360918383705368, 0.6331925854794861, 0.956981375715138], 
             UndirectedEdge[347, 368] -> 
             RGBColor[
              0.8282875720000464, 0.8661012198259925, 0.983435392590944], 
             UndirectedEdge[22, 182] -> 
             RGBColor[
              0.9863222811785923, 0.9688683251618938, 0.5821763648973786], 
             UndirectedEdge[96, 216] -> 
             RGBColor[
              0.8355639371750008, 0.869057756436962, 0.8121792629413668], 
             UndirectedEdge[340, 363] -> 
             RGBColor[
              0.9664470945692957, 0.9739861162556103, 0.918807515649967], 
             UndirectedEdge[71, 490] -> 
             RGBColor[
              0.9771727603432458, 0.9813415572932829, 0.8718236373287793], 
             UndirectedEdge[111, 201] -> 
             RGBColor[
              0.8640002534497411, 0.894056176921622, 0.9583858217175032], 
             UndirectedEdge[261, 484] -> 
             RGBColor[
              0.9843664061913093, 0.9846456562046717, 0.7199002151631233], 
             UndirectedEdge[416, 499] -> 
             RGBColor[
              0.6980965243277408, 0.757792077717111, 0.8666482895334042], 
             UndirectedEdge[42, 430] -> 
             RGBColor[
              0.971190911759735, 0.9754914708291891, 0.7955293099028428], 
             UndirectedEdge[6, 81] -> 
             RGBColor[
              0.7796321529397198, 0.7877211509442159, 0.6401298014381157], 
             UndirectedEdge[282, 353] -> 
             RGBColor[
              0.8982450516780285, 0.9214247198263459, 0.9806042116295179], 
             UndirectedEdge[275, 441] -> 
             RGBColor[
              0.6416951285370963, 0.5104816215146053, 0.5789209987167656], 
             UndirectedEdge[50, 255] -> 
             RGBColor[
              0.7886914585097649, 0.8353505365806546, 0.9794404978913963], 
             UndirectedEdge[110, 217] -> 
             RGBColor[
              0.9687403573208493, 0.9730822796515639, 0.753532233281389], 
             UndirectedEdge[30, 110] -> 
             RGBColor[
              0.9026108940657429, 0.9249663543589228, 0.9831157867122735], 
             UndirectedEdge[77, 482] -> 
             RGBColor[
              0.897575503901983, 0.9185459067569881, 0.8812906603363367], 
             UndirectedEdge[52, 326] -> 
             RGBColor[
              0.9200041128815079, 0.7008165127788027, 0.536921771162297], 
             UndirectedEdge[44, 247] -> 
             RGBColor[
              0.9797421117098863, 0.9822852167861864, 0.8140840024815739], 
             UndirectedEdge[337, 348] -> 
             RGBColor[
              0.9512728292181313, 0.9601841854901698, 0.8253859324550641], 
             UndirectedEdge[48, 78] -> 
             RGBColor[
              0.8515023762088437, 0.8813312232298889, 0.7995299531710405], 
             UndirectedEdge[420, 432] -> 
             RGBColor[
              0.9932805543588182, 0.9914893507925645, 0.7610221338496659], 
             UndirectedEdge[469, 474] -> 
             RGBColor[
              0.7449468736064442, 0.7960786667079783, 0.8100014731080973], 
             UndirectedEdge[172, 366] -> 
             RGBColor[
              0.9604555054563368, 0.9686784970294313, 0.892976701584989], 
             UndirectedEdge[102, 415] -> 
             RGBColor[
              0.8087665580427755, 0.8508292183716949, 0.9814955682923538], 
             UndirectedEdge[414, 485] -> 
             RGBColor[
              0.834152689396387, 0.8665506857289643, 0.699537838876894], 
             UndirectedEdge[102, 193] -> 
             RGBColor[
              0.9212011741026995, 0.938431390192239, 0.9349675344902522], 
             UndirectedEdge[128, 498] -> 
             RGBColor[
              0.9514452583520109, 0.9603890488585316, 0.8308638572966613], 
             UndirectedEdge[150, 443] -> 
             RGBColor[
              0.9811490061323647, 0.9480733126399292, 0.3812678778460675], 
             UndirectedEdge[2, 230] -> 
             RGBColor[
              0.8136896591151412, 0.8544452163287872, 0.9820472829085142], 
             UndirectedEdge[367, 416] -> 
             RGBColor[
              0.5791727110907448, 0.6662015417165907, 0.961548755357718], 
             UndirectedEdge[61, 473] -> 
             RGBColor[
              0.9853814734226545, 0.9882228778283403, 0.8919303471280737], 
             UndirectedEdge[56, 164] -> 
             RGBColor[
              0.9699628007271801, 0.9739997115373483, 0.7519180503827609], 
             UndirectedEdge[20, 388] -> 
             RGBColor[
              0.9856540362908031, 0.9852131818652335, 0.6865546439364186], 
             UndirectedEdge[195, 296] -> 
             RGBColor[
              0.9508403729199688, 0.8310330799597048, 0.3927971155987977], 
             UndirectedEdge[135, 391] -> 
             RGBColor[
              0.8192217408136327, 0.8584620873200579, 0.9245720746519643], 
             UndirectedEdge[310, 399] -> 
             RGBColor[
              0.8692371718435675, 0.8769182076064387, 0.675509967402828], 
             UndirectedEdge[150, 476] -> 
             RGBColor[
              0.9475070422829776, 0.9388363266788766, 0.683106019270616], 
             UndirectedEdge[142, 222] -> 
             RGBColor[
              0.9939495893397075, 0.9894671083250167, 0.5828283223125964], 
             UndirectedEdge[48, 404] -> 
             RGBColor[
              0.9160784745883971, 0.6409380759064724, 0.4056465680790661], 
             UndirectedEdge[330, 415] -> 
             RGBColor[
              0.876821931602576, 0.8999426084280573, 0.7084671626390711], 
             UndirectedEdge[326, 495] -> 
             RGBColor[
              0.6626589623085997, 0.49749358235002106`, 0.5752568261881037], 
             UndirectedEdge[36, 382] -> 
             RGBColor[
              0.7603177669391539, 0.8126852852527, 0.9767450275011444], 
             UndirectedEdge[31, 289] -> 
             RGBColor[
              0.990860722749505, 0.9882081478724971, 0.6353537961732488], 
             UndirectedEdge[436, 487] -> 
             RGBColor[
              0.9119707169906301, 0.930844474227762, 0.9242386854535574], 
             UndirectedEdge[251, 427] -> 
             RGBColor[
              0.9763451773845073, 0.9679068326718151, 0.6671866770371591], 
             UndirectedEdge[108, 437] -> 
             RGBColor[
              0.9580051478665308, 0.9642023899978038, 0.7165956391891717], 
             UndirectedEdge[258, 397] -> 
             RGBColor[
              0.8921496005876037, 0.9137655435177967, 0.8561911262925681], 
             UndirectedEdge[308, 422] -> 
             RGBColor[
              0.9910046743563314, 0.9905482159240879, 0.7987393552795178], 
             UndirectedEdge[16, 292] -> 
             RGBColor[
              0.7609749842183531, 0.8110237003676337, 0.9070513790545807], 
             UndirectedEdge[68, 317] -> 
             RGBColor[
              0.9718885817066476, 0.9234313507903253, 0.5541089001108943], 
             UndirectedEdge[34, 468] -> 
             RGBColor[
              0.9231021487728279, 0.9390380336437073, 0.8956707601296505], 
             UndirectedEdge[350, 383] -> 
             RGBColor[
              0.96580066387059, 0.9740147716277352, 0.9427747348384041], 
             UndirectedEdge[190, 342] -> 
             RGBColor[
              0.9180511689070951, 0.7920926782306796, 0.6134985989228404], 
             UndirectedEdge[61, 303] -> 
             RGBColor[
              0.9644252340977959, 0.9726697620454037, 0.930807820122374], 
             UndirectedEdge[214, 421] -> 
             RGBColor[
              0.8891071583841488, 0.9124539835750715, 0.9041894377771348], 
             UndirectedEdge[219, 370] -> 
             RGBColor[
              0.9529877098340097, 0.8824342825214481, 0.6029983522383966], 
             UndirectedEdge[91, 366] -> 
             RGBColor[
              0.9857012881337022, 0.9675145673083686, 0.5848856713080592], 
             UndirectedEdge[273, 477] -> 
             RGBColor[
              0.9672155104609584, 0.9389492987096772, 0.635623443720851], 
             UndirectedEdge[153, 323] -> 
             RGBColor[
              0.9914059018871284, 0.9883726349623165, 0.6218877279774058], 
             UndirectedEdge[170, 433] -> 
             RGBColor[
              0.8297408449565327, 0.831840458671931, 0.650803597800623], 
             UndirectedEdge[1, 54] -> 
             RGBColor[
              0.7072067855909343, 0.7645535615720733, 0.8095869553172019], 
             UndirectedEdge[277, 377] -> 
             RGBColor[
              0.9858208115442746, 0.9645107782368301, 0.5618011502770617], 
             UndirectedEdge[307, 417] -> 
             RGBColor[
              0.6872888520570566, 0.7538516803673849, 0.9708899980878904], 
             UndirectedEdge[58, 371] -> 
             RGBColor[
              0.9704218496357984, 0.975572727340808, 0.8487884392822149], 
             UndirectedEdge[9, 269] -> 
             RGBColor[
              0.8448479987702944, 0.875816781985415, 0.7735574358969415], 
             UndirectedEdge[184, 453] -> 
             RGBColor[
              0.9767096385681568, 0.9789781440586809, 0.736264470732255], 
             UndirectedEdge[42, 97] -> 
             RGBColor[
              0.9593142940148085, 0.9691772476097491, 0.953754467088042], 
             UndirectedEdge[161, 405] -> 
             RGBColor[
              0.9689486476815623, 0.9763625327996078, 0.9374460193721006], 
             UndirectedEdge[304, 429] -> 
             RGBColor[
              0.9576439554486982, 0.9672227693281403, 0.9268448366528462], 
             UndirectedEdge[127, 130] -> 
             RGBColor[
              0.9926922041214361, 0.9912460528494955, 0.7707726198846938], 
             UndirectedEdge[318, 330] -> 
             RGBColor[
              0.9872126580184568, 0.9684438282908217, 0.4119332689507153], 
             UndirectedEdge[393, 468] -> 
             RGBColor[
              0.6811133107910139, 0.7490188391291401, 0.9701958068597877], 
             UndirectedEdge[334, 355] -> 
             RGBColor[
              0.9221852378182329, 0.9387866366675219, 0.9164145302449637], 
             UndirectedEdge[290, 378] -> 
             RGBColor[
              0.8725096782908836, 0.9011795500975953, 0.987701946085611], 
             UndirectedEdge[92, 498] -> 
             RGBColor[
              0.9367784035520705, 0.9123049345892289, 0.6556366810507406], 
             UndirectedEdge[340, 362] -> 
             RGBColor[0.97009839790518, 0.974880896795002, 0.813582714517109],
              UndirectedEdge[58, 304] -> 
             RGBColor[
              0.9368246934163371, 0.9522065601216048, 0.9849593973721117], 
             UndirectedEdge[51, 308] -> 
             RGBColor[
              0.9642024324009282, 0.9719788512545862, 0.9076857829496001], 
             UndirectedEdge[59, 447] -> 
             RGBColor[
              0.9478094909113419, 0.8340061320721336, 0.5642922570016069], 
             UndirectedEdge[186, 485] -> 
             RGBColor[
              0.8341456892510164, 0.8665357131258398, 0.698775916253193], 
             UndirectedEdge[340, 379] -> 
             RGBColor[
              0.9058953308565098, 0.9275443259715797, 0.9820093271601875], 
             UndirectedEdge[129, 410] -> 
             RGBColor[
              0.9684894157614115, 0.9760200383854826, 0.9382233792260486], 
             UndirectedEdge[192, 225] -> 
             RGBColor[
              0.9902262438965574, 0.9894100328369123, 0.7523048718758557], 
             UndirectedEdge[306, 420] -> 
             RGBColor[
              0.6166159687455042, 0.6809996487107892, 0.861721022522008], 
             UndirectedEdge[16, 45] -> 
             RGBColor[
              0.72354313783018, 0.7830528536829605, 0.9740107381863272], 
             UndirectedEdge[334, 361] -> 
             RGBColor[
              0.9883963165089658, 0.9894695929224633, 0.8419665950240907], 
             UndirectedEdge[306, 357] -> 
             RGBColor[
              0.6163179418421119, 0.6808764069272945, 0.8666600995801179], 
             UndirectedEdge[335, 496] -> 
             RGBColor[
              0.4745924298804651, 0.570788821407239, 0.9543729926859352], 
             UndirectedEdge[176, 345] -> 
             RGBColor[
              0.9659780030455363, 0.9013132861488369, 0.5557899592519115], 
             UndirectedEdge[15, 78] -> 
             RGBColor[
              0.8265754320074721, 0.8652256370015097, 0.9752080796164941], 
             UndirectedEdge[52, 210] -> 
             RGBColor[
              0.9359386630132743, 0.9500799080255522, 0.9319111983614126], 
             UndirectedEdge[392, 465] -> 
             RGBColor[
              0.9890434223165855, 0.9897371878037746, 0.8312423771356852], 
             UndirectedEdge[354, 414] -> 
             RGBColor[
              0.9920388685167725, 0.9886211431791685, 0.6104354427268315], 
             UndirectedEdge[56, 428] -> 
             RGBColor[
              0.896376281522635, 0.9157688941527455, 0.7544906990752818], 
             UndirectedEdge[44, 425] -> 
             RGBColor[
              0.9178521582203509, 0.9365888564322928, 0.9661778448476401], 
             UndirectedEdge[106, 468] -> 
             RGBColor[
              0.9252631989751376, 0.9396312350829763, 0.8380171418830222], 
             UndirectedEdge[142, 461] -> 
             RGBColor[
              0.9532844962325216, 0.9604721139981898, 0.718888840966714], 
             UndirectedEdge[203, 297] -> 
             RGBColor[
              0.891926435531237, 0.9126080880748197, 0.7793129128464256], 
             UndirectedEdge[24, 176] -> 
             RGBColor[
              0.9641667247312191, 0.9005642760181374, 0.5858075283581651], 
             UndirectedEdge[351, 356] -> 
             RGBColor[
              0.9903196371755019, 0.9902649354451625, 0.8100921941852587], 
             UndirectedEdge[315, 368] -> 
             RGBColor[
              0.8811552021655694, 0.9075011131819193, 0.9622905398018318], 
             UndirectedEdge[278, 406] -> 
             RGBColor[
              0.802234936438091, 0.8462245008789513, 0.973482828056591], 
             UndirectedEdge[247, 360] -> 
             RGBColor[
              0.8208458625237492, 0.8577308508489487, 0.8244058240965618], 
             UndirectedEdge[78, 145] -> 
             RGBColor[
              0.8288081729299157, 0.8668908115256906, 0.9714286316268932], 
             UndirectedEdge[19, 466] -> 
             RGBColor[
              0.9796400817041306, 0.9672206001886825, 0.654936066241841], 
             UndirectedEdge[60, 151] -> 
             RGBColor[
              0.9194424061202968, 0.936521594169517, 0.9127666273941213], 
             UndirectedEdge[109, 186] -> 
             RGBColor[
              0.9721070047636633, 0.9162827678407093, 0.35460532828169644`], 
             UndirectedEdge[474, 495] -> 
             RGBColor[
              0.4834471085911064, 0.5915231676551345, 0.9524778737948532], 
             UndirectedEdge[36, 412] -> 
             RGBColor[
              0.8536160003939042, 0.7978326315179977, 0.6215441042142312], 
             UndirectedEdge[259, 469] -> 
             RGBColor[
              0.9701735445509527, 0.9750416278718184, 0.821761963158123], 
             UndirectedEdge[6, 80] -> 
             RGBColor[
              0.8966781374619279, 0.8799637825509472, 0.6512730237398336], 
             UndirectedEdge[287, 389] -> 
             RGBColor[
              0.9848107097118647, 0.9635067659932894, 0.5744886045160109], 
             UndirectedEdge[158, 410] -> 
             RGBColor[
              0.9737750148370254, 0.979485833410038, 0.9079512038900941], 
             UndirectedEdge[414, 415] -> 
             RGBColor[
              0.8767789274306813, 0.8998506268527631, 0.7037864239193101], 
             UndirectedEdge[10, 245] -> 
             RGBColor[
              0.9557399292555263, 0.965641973815429, 0.9239459321498735], 
             UndirectedEdge[115, 178] -> 
             RGBColor[
              0.9683047453502636, 0.9758823114952186, 0.9385359780623648], 
             UndirectedEdge[88, 348] -> 
             RGBColor[
              0.9936041309169719, 0.9887282076899895, 0.5452273049200776], 
             UndirectedEdge[135, 170] -> 
             RGBColor[
              0.8384937396335601, 0.873517519270801, 0.9264929273872662], 
             UndirectedEdge[3, 203] -> 
             RGBColor[
              0.9660309440322185, 0.9713910137024733, 0.7842558414021292], 
             UndirectedEdge[84, 374] -> 
             RGBColor[
              0.7117201569314623, 0.7061183757452654, 0.6139341435292172], 
             UndirectedEdge[29, 172] -> 
             RGBColor[
              0.933069313559403, 0.9494451827399079, 0.9926815624728356], 
             UndirectedEdge[262, 387] -> 
             RGBColor[
              0.9231568624962913, 0.8606759817135375, 0.6300135296334083], 
             UndirectedEdge[179, 276] -> 
             RGBColor[
              0.9653180638966741, 0.9727643183031297, 0.9037118506413898], 
             UndirectedEdge[348, 428] -> 
             RGBColor[
              0.8969796445657747, 0.9170594266926599, 0.8201630427959606], 
             UndirectedEdge[104, 351] -> 
             RGBColor[
              0.987688926249747, 0.9891770688711758, 0.8536898822866523], 
             UndirectedEdge[111, 271] -> 
             RGBColor[
              0.9598642009576931, 0.9695873673073625, 0.9528236180724392], 
             UndirectedEdge[136, 277] -> 
             RGBColor[
              0.9453124594525704, 0.9561619904483253, 0.8723455726369105], 
             UndirectedEdge[246, 442] -> 
             RGBColor[
              0.99434416645794, 0.9903110688830499, 0.6257756065844976], 
             UndirectedEdge[206, 266] -> 
             RGBColor[
              0.7777383789618836, 0.8263932558130482, 0.9653135256154455], 
             UndirectedEdge[31, 381] -> 
             RGBColor[
              0.9913381461069537, 0.9884055747000228, 0.6274416556082809], 
             UndirectedEdge[31, 472] -> 
             RGBColor[
              0.9001671846429673, 0.9181800975337054, 0.7107939992883439], 
             UndirectedEdge[342, 453] -> 
             RGBColor[
              0.9655919171001204, 0.9706865655914175, 0.7550838732114837], 
             UndirectedEdge[200, 475] -> 
             RGBColor[
              0.9902104427487868, 0.990219780743547, 0.8119018284220445], 
             UndirectedEdge[92, 101] -> 
             RGBColor[
              0.9640622380185266, 0.9333639921173034, 0.6340967881574171], 
             UndirectedEdge[193, 376] -> 
             RGBColor[
              0.9598393306810903, 0.9692404074430272, 0.9386528763573886], 
             UndirectedEdge[253, 319] -> 
             RGBColor[
              0.8106417510044636, 0.8520251747796341, 0.9817538433410331], 
             UndirectedEdge[249, 280] -> 
             RGBColor[
              0.8230347551591823, 0.8613430724339577, 0.9205187828517996], 
             UndirectedEdge[153, 195] -> 
             RGBColor[
              0.9491812597358428, 0.8318306215130482, 0.5281369714251338], 
             UndirectedEdge[313, 380] -> 
             RGBColor[
              0.8511595883141477, 0.8821035413096655, 0.86841626379066], 
             UndirectedEdge[178, 357] -> 
             RGBColor[
              0.9820270672647233, 0.9849596771246509, 0.8635074000323265], 
             UndirectedEdge[163, 494] -> 
             RGBColor[
              0.6462093510596725, 0.7214163513985199, 0.9668257159780171], 
             UndirectedEdge[24, 237] -> 
             RGBColor[
              0.845960006452928, 0.8795188965624285, 0.9348854408501976], 
             UndirectedEdge[101, 345] -> 
             RGBColor[
              0.9756593785352431, 0.9806322620342013, 0.8931661993862685], 
             UndirectedEdge[320, 361] -> 
             RGBColor[
              0.9347395407885317, 0.9486879926274056, 0.9128742789101678], 
             UndirectedEdge[328, 487] -> 
             RGBColor[
              0.9688645495746133, 0.9758239401923895, 0.9162778382355787], 
             UndirectedEdge[322, 494] -> 
             RGBColor[
              0.8905465037153715, 0.9130233721823531, 0.8791650776517849], 
             UndirectedEdge[108, 266] -> 
             RGBColor[
              0.7987837839224614, 0.8384083922883823, 0.7013397577219094], 
             UndirectedEdge[405, 474] -> 
             RGBColor[
              0.7386516393417809, 0.7936181223082889, 0.9342682879764863], 
             UndirectedEdge[338, 379] -> 
             RGBColor[
              0.9302028141848375, 0.9431064997242464, 0.8009194916887008], 
             UndirectedEdge[175, 309] -> 
             RGBColor[
              0.7451996021706128, 0.8009918609978337, 0.9753043525856148], 
             UndirectedEdge[294, 430] -> 
             RGBColor[
              0.9412831759597973, 0.9519637977688851, 0.8037693303018356], 
             UndirectedEdge[197, 237] -> 
             RGBColor[
              0.6287446068886482, 0.7084931420486138, 0.9645924647075654], 
             UndirectedEdge[94, 500] -> 
             RGBColor[
              0.97244451207398, 0.9761740731241622, 0.7733859244786877], 
             UndirectedEdge[242, 365] -> 
             RGBColor[
              0.7224887004909916, 0.7815638289777536, 0.9616279274812787], 
             UndirectedEdge[401, 500] -> 
             RGBColor[
              0.9716480580375231, 0.9770252914726678, 0.8724003914117233], 
             UndirectedEdge[334, 340] -> 
             RGBColor[
              0.9668699548677739, 0.974160979856045, 0.9117996261768098], 
             UndirectedEdge[60, 310] -> 
             RGBColor[
              0.8047302162543559, 0.8476261979310655, 0.9811064787361881], 
             UndirectedEdge[50, 379] -> 
             RGBColor[
              0.7808807845248735, 0.8291225171601997, 0.9786955088340464], 
             UndirectedEdge[123, 177] -> 
             RGBColor[
              0.8793761501198514, 0.8590073475005995, 0.6387987446949184], 
             UndirectedEdge[231, 246] -> 
             RGBColor[
              0.990276034386355, 0.9895193638417679, 0.7579302745145235], 
             UndirectedEdge[182, 282] -> 
             RGBColor[
              0.9635823685174102, 0.9531833866338972, 0.677741629696105], 
             UndirectedEdge[185, 193] -> 
             RGBColor[
              0.8760981363009956, 0.9029011849813693, 0.9305504671203357], 
             UndirectedEdge[395, 447] -> 
             RGBColor[
              0.9325194677709687, 0.8228958779726008, 0.6032963177044897], 
             UndirectedEdge[22, 282] -> 
             RGBColor[
              0.9691232035050532, 0.9752182651454351, 0.8800780177119449], 
             UndirectedEdge[195, 323] -> 
             RGBColor[
              0.9503431637528634, 0.8299695998268242, 0.3386789661786536], 
             UndirectedEdge[99, 486] -> 
             RGBColor[
              0.927265917843518, 0.9424279468541842, 0.8991004580710005], 
             UndirectedEdge[454, 469] -> 
             RGBColor[
              0.9718522782718043, 0.9762936247321552, 0.818920304852598], 
             UndirectedEdge[31, 208] -> 
             RGBColor[
              0.9910753362634579, 0.9882968960758323, 0.63179709484508], 
             UndirectedEdge[398, 472] -> 
             RGBColor[
              0.7197365600610408, 0.780820838606175, 0.9728111003008058], 
             UndirectedEdge[191, 389] -> 
             RGBColor[
              0.7880576655104237, 0.8104966232668291, 0.6644720308944991], 
             UndirectedEdge[133, 151] -> 
             RGBColor[
              0.9326205389578086, 0.9470294795832623, 0.9140235694684212], 
             UndirectedEdge[165, 268] -> 
             RGBColor[
              0.9669384584808856, 0.9738598747941243, 0.8959116582410627], 
             UndirectedEdge[166, 495] -> 
             RGBColor[
              0.7320201673690891, 0.7865473694884411, 0.864242788609242], 
             UndirectedEdge[346, 430] -> 
             RGBColor[
              0.9933909441265093, 0.9882722227016809, 0.5220232384145909], 
             UndirectedEdge[169, 219] -> 
             RGBColor[
              0.9645186687069431, 0.889759201479745, 0.5263890012303627], 
             UndirectedEdge[197, 345] -> 
             RGBColor[
              0.7695901390161273, 0.8177860108540616, 0.8980369259589864], 
             UndirectedEdge[100, 213] -> 
             RGBColor[
              0.8310856233904574, 0.8683508821934004, 0.9555032953871994], 
             UndirectedEdge[73, 187] -> 
             RGBColor[
              0.8435816715236892, 0.8782566796923166, 0.9849046766797123], 
             UndirectedEdge[97, 346] -> 
             RGBColor[
              0.9815143263815826, 0.981957999482241, 0.6802483955997901], 
             UndirectedEdge[129, 170] -> 
             RGBColor[
              0.8337814122214082, 0.8702887868114969, 0.9472645076801423], 
             UndirectedEdge[36, 37] -> 
             RGBColor[
              0.883250488253514, 0.9073110512259606, 0.8778657150807145], 
             UndirectedEdge[143, 302] -> 
             RGBColor[
              0.781346285500387, 0.7927824701733466, 0.6457177348380632], 
             UndirectedEdge[16, 236] -> 
             RGBColor[
              0.7640888624168938, 0.8109296732338311, 0.7550116606961033], 
             UndirectedEdge[187, 322] -> 
             RGBColor[
              0.9385748006264314, 0.9510684421069135, 0.8838127707529357], 
             UndirectedEdge[108, 163] -> 
             RGBColor[
              0.7480902383994006, 0.7972530883145608, 0.6973489761217582], 
             UndirectedEdge[137, 346] -> 
             RGBColor[
              0.9227202350884132, 0.9359751901830358, 0.7057748964843131], 
             UndirectedEdge[243, 276] -> 
             RGBColor[
              0.8683765986671191, 0.8961929649552562, 0.8991237867213546], 
             UndirectedEdge[131, 147] -> 
             RGBColor[
              0.7981933826898754, 0.8384236603624686, 0.7418291673204704], 
             UndirectedEdge[9, 468] -> 
             RGBColor[
              0.7756972300044321, 0.8249876502988687, 0.9782015322979882], 
             UndirectedEdge[331, 377] -> 
             RGBColor[
              0.9334104622049926, 0.92578870948347, 0.6791025720775219], 
             UndirectedEdge[280, 470] -> 
             RGBColor[
              0.9568561495034349, 0.8690069190599355, 0.5673327351304861], 
             UndirectedEdge[234, 468] -> 
             RGBColor[
              0.863343079728331, 0.8938703532245054, 0.9868276277315957], 
             UndirectedEdge[136, 488] -> 
             RGBColor[
              0.9447988349887331, 0.955949593532982, 0.8808576592201965], 
             UndirectedEdge[57, 361] -> 
             RGBColor[
              0.9287196616468555, 0.9438879044050992, 0.9123000974636253], 
             UndirectedEdge[196, 414] -> 
             RGBColor[
              0.9417220342204252, 0.7919624471693454, 0.3307144536526812], 
             UndirectedEdge[103, 319] -> 
             RGBColor[
              0.9081117580332554, 0.9246392377370465, 0.7297097869228759], 
             UndirectedEdge[224, 263] -> 
             RGBColor[
              0.9769249066263179, 0.9790384101656148, 0.7279432526057875], 
             UndirectedEdge[89, 184] -> 
             RGBColor[
              0.9770557093914496, 0.9797183545565765, 0.7739321441461116], 
             UndirectedEdge[137, 407] -> 
             RGBColor[
              0.8028104527000954, 0.8461472197863616, 0.9809096267125201], 
             UndirectedEdge[53, 272] -> 
             RGBColor[
              0.9600984357147977, 0.9697620592056869, 0.9524271197268701], 
             UndirectedEdge[236, 243] -> 
             RGBColor[
              0.8704406675144714, 0.8956648146758674, 0.7644821261315815], 
             UndirectedEdge[26, 351] -> 
             RGBColor[
              0.9711448026632994, 0.9182516890157005, 0.5425940792377109], 
             UndirectedEdge[67, 96] -> 
             RGBColor[
              0.8204234167889022, 0.8192927268958863, 0.642180762845235], 
             UndirectedEdge[284, 464] -> 
             RGBColor[
              0.8640779538867097, 0.7650127719958602, 0.6135056904715392], 
             UndirectedEdge[325, 401] -> 
             RGBColor[
              0.9931344307075166, 0.9914289249075448, 0.7634437809076215], 
             UndirectedEdge[227, 348] -> 
             RGBColor[
              0.9736600537786657, 0.9775976621797073, 0.812353245335059], 
             UndirectedEdge[106, 117] -> 
             RGBColor[
              0.8514102158726403, 0.8816489117685202, 0.830732543074981], 
             UndirectedEdge[395, 440] -> 
             RGBColor[
              0.8981756854196032, 0.9211375199265703, 0.9725578537696471], 
             UndirectedEdge[204, 361] -> 
             RGBColor[
              0.897535575814586, 0.9191324312574352, 0.9092965752858524], 
             UndirectedEdge[195, 263] -> 
             RGBColor[
              0.9343699071000493, 0.821789795695512, 0.5982351345160118], 
             UndirectedEdge[360, 393] -> 
             RGBColor[
              0.5767261400968968, 0.6671829763996897, 0.9598678455908202], 
             UndirectedEdge[74, 440] -> 
             RGBColor[
              0.8472869411244472, 0.6445100066305208, 0.5918266033154662], 
             UndirectedEdge[166, 348] -> 
             RGBColor[
              0.9934882056247197, 0.9910350082103386, 0.7183131259232189], 
             UndirectedEdge[209, 477] -> 
             RGBColor[
              0.9806062222388334, 0.9833167253870987, 0.8397916986792475], 
             UndirectedEdge[292, 422] -> 
             RGBColor[
              0.9900950182569004, 0.9901720497498778, 0.8138147109616114], 
             UndirectedEdge[36, 416] -> 
             RGBColor[
              0.589329434664358, 0.6741360513662557, 0.9625610826435576], 
             UndirectedEdge[306, 418] -> 
             RGBColor[
              0.6175357682312481, 0.6799204515056734, 0.7403831110268659], 
             UndirectedEdge[363, 498] -> 
             RGBColor[
              0.9477003139222532, 0.959293979487912, 0.9258964032472603], 
             UndirectedEdge[57, 466] -> 
             RGBColor[
              0.9255546728507703, 0.9251575865432324, 0.6866399696999533], 
             UndirectedEdge[263, 395] -> 
             RGBColor[
              0.9579984896358684, 0.9681959228583676, 0.9559817806848432], 
             UndirectedEdge[171, 238] -> 
             RGBColor[
              0.9701144339582157, 0.9744243082261332, 0.7763782715977219], 
             UndirectedEdge[42, 286] -> 
             RGBColor[
              0.8497599176783597, 0.8832737923814385, 0.974292331729834], 
             UndirectedEdge[246, 444] -> 
             RGBColor[
              0.9701360152450491, 0.9748181868522778, 0.8063172321143273], 
             UndirectedEdge[46, 306] -> 
             RGBColor[
              0.5694627298773799, 0.4991709264566812, 0.5866002599877893], 
             UndirectedEdge[229, 411] -> 
             RGBColor[
              0.9922882511599973, 0.9910790079188231, 0.7774671658524877], 
             UndirectedEdge[239, 440] -> 
             RGBColor[
              0.9179051038142328, 0.9336975460414627, 0.8319210729853608], 
             UndirectedEdge[57, 106] -> 
             RGBColor[
              0.9318462484496308, 0.9448803800418195, 0.8386450390186571], 
             UndirectedEdge[60, 280] -> 
             RGBColor[
              0.9184049940386754, 0.9360925976134922, 0.9299592303229935], 
             UndirectedEdge[438, 457] -> 
             RGBColor[
              0.9864554962597628, 0.9666211225457995, 0.5640553002863545], 
             UndirectedEdge[130, 368] -> 
             RGBColor[
              0.8956486228024974, 0.9166847574002208, 0.8649626212596345], 
             UndirectedEdge[152, 287] -> 
             RGBColor[
              0.9936109638121823, 0.9915391212326605, 0.7492324175284482], 
             UndirectedEdge[54, 242] -> 
             RGBColor[
              0.6847274296866213, 0.7499934159983844, 0.9589077938479361], 
             UndirectedEdge[89, 235] -> 
             RGBColor[
              0.8937746459632705, 0.9141543419067689, 0.787700269066713], 
             UndirectedEdge[60, 260] -> 
             RGBColor[
              0.9220155188989467, 0.9375856424294708, 0.8701234896494816], 
             UndirectedEdge[88, 243] -> 
             RGBColor[
              0.8698767067296358, 0.894458559582286, 0.7030984750647495], 
             UndirectedEdge[36, 367] -> 
             RGBColor[
              0.7640640581029718, 0.8156119163827421, 0.9771184227932724], 
             UndirectedEdge[17, 282] -> 
             RGBColor[
              0.9339358514414566, 0.9498835947567524, 0.9840084319725069], 
             UndirectedEdge[150, 233] -> 
             RGBColor[
              0.8725955064269229, 0.879541764107244, 0.6758446948086758], 
             UndirectedEdge[250, 365] -> 
             RGBColor[
              0.5065045493724811, 0.6102422368073245, 0.9542930399953516], 
             UndirectedEdge[107, 423] -> 
             RGBColor[
              0.9424661569296596, 0.9524805396346567, 0.7693058506424195], 
             UndirectedEdge[315, 347] -> 
             RGBColor[
              0.912121813209384, 0.9320098713543796, 0.9652927723265174], 
             UndirectedEdge[288, 492] -> 
             RGBColor[
              0.9555695669270433, 0.9663844362791217, 0.960093313266383], 
             UndirectedEdge[24, 267] -> 
             RGBColor[
              0.7195702404521882, 0.777899071031126, 0.9242593358851952], 
             UndirectedEdge[198, 480] -> 
             RGBColor[
              0.7460087646267075, 0.7962040211252337, 0.7497022675384846], 
             UndirectedEdge[4, 479] -> 
             RGBColor[
              0.9205254653243551, 0.9372390326586353, 0.9065230058122382], 
             UndirectedEdge[133, 239] -> 
             RGBColor[
              0.9357786006155616, 0.9479493872276962, 0.8336258630661304], 
             UndirectedEdge[115, 253] -> 
             RGBColor[
              0.8808708710896302, 0.9073016466809345, 0.963408997615575], 
             UndirectedEdge[199, 371] -> 
             RGBColor[
              0.9074814739468295, 0.9256437324166499, 0.8516615941696293], 
             UndirectedEdge[93, 189] -> 
             RGBColor[
              0.9806079557127567, 0.9837075684883712, 0.8572336217631301], 
             UndirectedEdge[357, 418] -> 
             RGBColor[
              0.9923722985517549, 0.9896542057449949, 0.6699798294117874], 
             UndirectedEdge[82, 463] -> 
             RGBColor[
              0.8917311982400389, 0.6322755859784144, 0.5830205923025985], 
             UndirectedEdge[102, 350] -> 
             RGBColor[
              0.9055320684478462, 0.9270249425265812, 0.9740098697199135], 
             UndirectedEdge[235, 296] -> 
             RGBColor[
              0.8935234432835397, 0.9136170447753118, 0.7603584076212653], 
             UndirectedEdge[26, 360] -> 
             RGBColor[
              0.7992469390834261, 0.7850676768960291, 0.6227038409866854], 
             UndirectedEdge[309, 320] -> 
             RGBColor[
              0.7539940875962444, 0.8080043449562848, 0.9761431784564414], 
             UndirectedEdge[13, 229] -> 
             RGBColor[
              0.9844011836058186, 0.9649955386911522, 0.5927363912282297], 
             UndirectedEdge[353, 420] -> 
             RGBColor[
              0.9209286692407943, 0.9370863788844292, 0.8859719022985919], 
             UndirectedEdge[171, 465] -> 
             RGBColor[
              0.96655222021987, 0.9741466716265901, 0.9223085370504428], 
             UndirectedEdge[104, 224] -> 
             RGBColor[
              0.9889961594283454, 0.987946134284535, 0.7032556349114674], 
             UndirectedEdge[22, 285] -> 
             RGBColor[
              0.9928728773204762, 0.9901135554340024, 0.6800269433722277], 
             UndirectedEdge[126, 285] -> 
             RGBColor[
              0.9939686185766967, 0.9895078099387855, 0.5848995373240277], 
             UndirectedEdge[98, 319] -> 
             RGBColor[
              0.8795203110235486, 0.8225172165149158, 0.6250981093975176], 
             UndirectedEdge[286, 411] -> 
             RGBColor[
              0.8729445938093365, 0.8988564392401264, 0.8585389915447235], 
             UndirectedEdge[259, 491] -> 
             RGBColor[
              0.9694640367589782, 0.9752336993829217, 0.8688089759708189], 
             UndirectedEdge[1, 266] -> 
             RGBColor[
              0.7998429830321183, 0.8406739120824811, 0.816627044188874], 
             UndirectedEdge[67, 216] -> 
             RGBColor[
              0.979481029120923, 0.9411393336362314, 0.4859685395711471], 
             UndirectedEdge[41, 451] -> 
             RGBColor[
              0.9043861187393993, 0.9238657067169292, 0.8819375512725203], 
             UndirectedEdge[300, 456] -> 
             RGBColor[
              0.8369836642146149, 0.8728539857279333, 0.9843129349858775], 
             UndirectedEdge[117, 139] -> 
             RGBColor[
              0.8441104374116244, 0.8782897888254587, 0.9448462423231223], 
             UndirectedEdge[70, 96] -> 
             RGBColor[
              0.8158214516459303, 0.8566363319388394, 0.9646088680169426], 
             UndirectedEdge[92, 274] -> 
             RGBColor[
              0.9646048781492786, 0.9337686922383266, 0.6331782399592667], 
             UndirectedEdge[241, 436] -> 
             RGBColor[
              0.9153993008078571, 0.9310817091862547, 0.7816030163196452], 
             UndirectedEdge[207, 295] -> 
             RGBColor[
              0.9322447540495853, 0.9443821284716398, 0.7725347049851831], 
             UndirectedEdge[83, 176] -> 
             RGBColor[
              0.9665342595525064, 0.9015433125096093, 0.5465713493857213], 
             UndirectedEdge[56, 495] -> 
             RGBColor[
              0.7325844017467863, 0.7851994567708573, 0.7399526449138233], 
             UndirectedEdge[219, 334] -> 
             RGBColor[
              0.9626419448285347, 0.8889831279264193, 0.5574911727012997], 
             UndirectedEdge[124, 357] -> 
             RGBColor[
              0.9917271088826202, 0.9908469611664289, 0.7867667455782893], 
             UndirectedEdge[40, 291] -> 
             RGBColor[
              0.9873594902813169, 0.9890408386321118, 0.8591494888364981], 
             UndirectedEdge[7, 487] -> 
             RGBColor[
              0.951345054968125, 0.962240502543084, 0.9279942449597371], 
             UndirectedEdge[423, 477] -> 
             RGBColor[
              0.9800934761610967, 0.9816880557458005, 0.7453147485232765], 
             UndirectedEdge[22, 165] -> 
             RGBColor[
              0.9910475543098842, 0.9905659478868467, 0.798028723479385], 
             UndirectedEdge[302, 368] -> 
             RGBColor[
              0.6960049959756411, 0.7617134166538417, 0.9708342027426692], 
             UndirectedEdge[297, 419] -> 
             RGBColor[
              0.7235519371103741, 0.7839635395598015, 0.9730805531800256], 
             UndirectedEdge[263, 463] -> 
             RGBColor[
              0.9002193822851803, 0.6386060597411551, 0.5686523107871327], 
             UndirectedEdge[260, 424] -> 
             RGBColor[
              0.8455040197959991, 0.8775687080951045, 0.8625627051142704], 
             UndirectedEdge[193, 415] -> 
             RGBColor[
              0.8734400121328993, 0.9008246381787606, 0.9302855301448425], 
             UndirectedEdge[434, 474] -> 
             RGBColor[
              0.7364446499157189, 0.7687664723325414, 0.6606638837313327], 
             UndirectedEdge[102, 109] -> 
             RGBColor[
              0.9041016355211281, 0.8672763319627657, 0.6330763952784413], 
             UndirectedEdge[58, 118] -> 
             RGBColor[
              0.9590526681654, 0.9689821274796333, 0.9541973314081407], 
             UndirectedEdge[39, 100] -> 
             RGBColor[
              0.9593867427248712, 0.9692312797390901, 0.9536318303195557], 
             UndirectedEdge[35, 216] -> 
             RGBColor[
              0.9059702747535108, 0.5625156815886536, 0.4100925198336395], 
             UndirectedEdge[72, 163] -> 
             RGBColor[
              0.4514054286300596, 0.5640428563520788, 0.9503608912232567], 
             UndirectedEdge[202, 414] -> 
             RGBColor[
              0.9802406591765216, 0.9810403819195392, 0.6849657692711802], 
             UndirectedEdge[324, 441] -> 
             RGBColor[
              0.9299229466127378, 0.738408038817675, 0.4821971859641868], 
             UndirectedEdge[18, 52] -> 
             RGBColor[
              0.8576166991027597, 0.8883649174272206, 0.9242452508337009], 
             UndirectedEdge[168, 368] -> 
             RGBColor[
              0.6992275228576723, 0.7643296091498561, 0.9710878918633277], 
             UndirectedEdge[208, 397] -> 
             RGBColor[
              0.9922494402295137, 0.9910629586016726, 0.778110363410071], 
             UndirectedEdge[193, 350] -> 
             RGBColor[
              0.97020552253797, 0.9770203623336469, 0.9227998315724022], 
             UndirectedEdge[2, 365] -> 
             RGBColor[
              0.6616251613961034, 0.7333965960131594, 0.9684324512213838], 
             UndirectedEdge[42, 248] -> 
             RGBColor[
              0.8921163876628548, 0.9164934642981524, 0.978479404590084], 
             UndirectedEdge[46, 68] -> 
             RGBColor[
              0.9259317783640677, 0.7420973853730205, 0.2591601046425207], 
             UndirectedEdge[260, 470] -> 
             RGBColor[
              0.9604666743637063, 0.8704999638759142, 0.507496994456974], 
             UndirectedEdge[32, 344] -> 
             RGBColor[
              0.9529549108025309, 0.9604970660132974, 0.7421837164461034], 
             UndirectedEdge[60, 483] -> 
             RGBColor[
              0.9182185224481363, 0.936015486818703, 0.9330495471512332], 
             UndirectedEdge[337, 498] -> 
             RGBColor[
              0.9080120633167778, 0.929488188230674, 0.9910881952627341], 
             UndirectedEdge[86, 168] -> 
             RGBColor[
              0.7951265493266285, 0.8384176017549452, 0.895866126365599], 
             UndirectedEdge[151, 424] -> 
             RGBColor[
              0.8429309070173492, 0.8765046598351507, 0.90520584285891], 
             UndirectedEdge[234, 296] -> 
             RGBColor[
              0.932327857584808, 0.9443444471401319, 0.7641164452211091], 
             UndirectedEdge[223, 268] -> 
             RGBColor[
              0.96247135042132, 0.9530331034761459, 0.6810622222123301], 
             UndirectedEdge[50, 204] -> 
             RGBColor[
              0.7509946678417578, 0.8054020093796369, 0.9758157881124305], 
             UndirectedEdge[26, 247] -> 
             RGBColor[
              0.9732744744700037, 0.9187798674932777, 0.4816772010289954], 
             UndirectedEdge[64, 435] -> 
             RGBColor[
              0.7183905847779481, 0.7799314518899796, 0.9725661178151093], 
             UndirectedEdge[143, 214] -> 
             RGBColor[
              0.9785979863391587, 0.9467646880539589, 0.5794865570836162], 
             UndirectedEdge[38, 266] -> 
             RGBColor[
              0.7701335219470791, 0.7357531207412664, 0.6144372146615777], 
             UndirectedEdge[309, 375] -> 
             RGBColor[
              0.7937093819932332, 0.8390396785539841, 0.9579998638493983], 
             UndirectedEdge[70, 385] -> 
             RGBColor[
              0.8986482359089124, 0.9215204848024339, 0.9728167031623071], 
             UndirectedEdge[232, 354] -> 
             RGBColor[
              0.9060568415574957, 0.9252712175240496, 0.886430625119015], 
             UndirectedEdge[86, 484] -> 
             RGBColor[
              0.9822704584775889, 0.9854793614631723, 0.8782390577904273], 
             UndirectedEdge[106, 360] -> 
             RGBColor[
              0.8208760282810204, 0.8577953723535259, 0.8276891806140547], 
             UndirectedEdge[163, 322] -> 
             RGBColor[
              0.7478744055311219, 0.7994402726196619, 0.8663988052193057], 
             UndirectedEdge[44, 117] -> 
             RGBColor[
              0.8362487639149287, 0.8724265656039321, 0.9581540049001902], 
             UndirectedEdge[113, 273] -> 
             RGBColor[
              0.9803477630399757, 0.947311285992972, 0.5492649518249427], 
             UndirectedEdge[53, 298] -> 
             RGBColor[
              0.804797480108556, 0.8480726771106408, 0.9659578501715302], 
             UndirectedEdge[50, 369] -> 
             RGBColor[
              0.8448450462017072, 0.8759483074401898, 0.7842764052024552], 
             UndirectedEdge[135, 385] -> 
             RGBColor[
              0.9140358236471563, 0.932710808933803, 0.9339746916911663], 
             UndirectedEdge[376, 464] -> 
             RGBColor[
              0.9205284771552793, 0.8100248869415835, 0.6188899917748725], 
             UndirectedEdge[95, 408] -> 
             RGBColor[
              0.7707266573288571, 0.8182559903835638, 0.8792018763019416], 
             UndirectedEdge[34, 332] -> 
             RGBColor[
              0.9913244196989905, 0.9875937319041486, 0.6144098144707946], 
             UndirectedEdge[251, 416] -> 
             RGBColor[
              0.6861924933661692, 0.7501705535165173, 0.943066566832159], 
             UndirectedEdge[62, 209] -> 
             RGBColor[
              0.8939538237153826, 0.915234085194523, 0.8590493871588968], 
             UndirectedEdge[109, 496] -> 
             RGBColor[
              0.8318158009033293, 0.810510719282255, 0.6259500007595753], 
             UndirectedEdge[179, 254] -> 
             RGBColor[
              0.9681282417590493, 0.9738320197636825, 0.8502795518857813], 
             UndirectedEdge[27, 199] -> 
             RGBColor[
              0.7716478180763087, 0.8215364073126235, 0.9778743011131483], 
             UndirectedEdge[59, 453] -> 
             RGBColor[
              0.9896641104525989, 0.9883465478556548, 0.7012138890963375], 
             UndirectedEdge[450, 475] -> 
             RGBColor[
              0.993721413157852, 0.9897468448781792, 0.6138024236172737], 
             UndirectedEdge[311, 331] -> 
             RGBColor[
              0.9409597174522684, 0.9509007865603835, 0.7384749354067327], 
             UndirectedEdge[329, 486] -> 
             RGBColor[
              0.9723920839305007, 0.977924561661523, 0.8865628506586767], 
             UndirectedEdge[287, 456] -> 
             RGBColor[
              0.9058938484915702, 0.925044260772134, 0.882119755185677], 
             UndirectedEdge[60, 118] -> 
             RGBColor[
              0.9114219579437451, 0.9312587293025211, 0.9585312440176192], 
             UndirectedEdge[267, 493] -> 
             RGBColor[
              0.7200516578201488, 0.7660137561076379, 0.6750587978678835], 
             UndirectedEdge[239, 263] -> 
             RGBColor[
              0.9777279080304979, 0.98075594897326, 0.8153449999005569], 
             UndirectedEdge[64, 91] -> 
             RGBColor[
              0.8134411204338405, 0.8341850957497161, 0.6711975698985265], 
             UndirectedEdge[469, 471] -> 
             RGBColor[
              0.9885550914482546, 0.9887505554508054, 0.7906467989362369], 
             UndirectedEdge[275, 282] -> 
             RGBColor[
              0.6818051427201743, 0.7476680558617914, 0.961724797780191], 
             UndirectedEdge[132, 423] -> 
             RGBColor[
              0.9913852911659867, 0.9892889747951055, 0.6894570701304188], 
             UndirectedEdge[116, 412] -> 
             RGBColor[
              0.9633051255881819, 0.8804180693825421, 0.40481489235704177`], 
             UndirectedEdge[89, 453] -> 
             RGBColor[
              0.9937185587745286, 0.9889729573068724, 0.5576820710482526], 
             UndirectedEdge[136, 311] -> 
             RGBColor[
              0.945017900539852, 0.9541366715979773, 0.7388620085324092], 
             UndirectedEdge[6, 24] -> 
             RGBColor[
              0.9750661977606216, 0.9410638204385073, 0.6087080695476178], 
             UndirectedEdge[51, 477] -> 
             RGBColor[
              0.952840001092617, 0.9643487305490605, 0.9647137562392807], 
             UndirectedEdge[114, 381] -> 
             RGBColor[
              0.9743938634885757, 0.9794523618966823, 0.8847361928072449], 
             UndirectedEdge[95, 294] -> 
             RGBColor[
              0.939590215680272, 0.9521317727974106, 0.8949246880268454], 
             UndirectedEdge[89, 192] -> 
             RGBColor[
              0.990090663351372, 0.9891200397600564, 0.7375477662385513], 
             UndirectedEdge[108, 374] -> 
             RGBColor[
              0.9696348465180734, 0.9063858455199515, 0.3582755583947824], 
             UndirectedEdge[208, 472] -> 
             RGBColor[
              0.8986040537742486, 0.9198142431116398, 0.9024703328022259], 
             UndirectedEdge[34, 360] -> 
             RGBColor[
              0.8187149780787107, 0.857202170914257, 0.885342798860683], 
             UndirectedEdge[395, 453] -> 
             RGBColor[
              0.9743740873122259, 0.9772362937561219, 0.7402179497992203], 
             UndirectedEdge[101, 361] -> 
             RGBColor[
              0.9756912479975401, 0.9806454408758689, 0.8926380399204831], 
             UndirectedEdge[11, 211] -> 
             RGBColor[
              0.9203138361346822, 0.9117341342689032, 0.6725401483277982], 
             UndirectedEdge[70, 433] -> 
             RGBColor[
              0.9617712715100974, 0.9355747777135608, 0.6462949087606465], 
             UndirectedEdge[108, 206] -> 
             RGBColor[
              0.9715978189628004, 0.9746577883179586, 0.7046122765915144], 
             UndirectedEdge[251, 499] -> 
             RGBColor[
              0.9798509300417793, 0.983236954533524, 0.8627234411575602], 
             UndirectedEdge[116, 399] -> 
             RGBColor[
              0.9864896776685943, 0.9654122159035461, 0.4595346026431011], 
             UndirectedEdge[350, 479] -> 
             RGBColor[
              0.9719081942489296, 0.9777244608427957, 0.8945821549486634], 
             UndirectedEdge[347, 421] -> 
             RGBColor[
              0.8241380335697823, 0.8628595688666101, 0.9830218053798566], 
             UndirectedEdge[153, 447] -> 
             RGBColor[
              0.9499536233694148, 0.8348927859452375, 0.5287584333344104], 
             UndirectedEdge[195, 453] -> 
             RGBColor[
              0.9507455047764068, 0.8308301665932663, 0.3824713036303889], 
             UndirectedEdge[338, 425] -> 
             RGBColor[
              0.932668145062423, 0.945072287646409, 0.8011546371486318], 
             UndirectedEdge[164, 348] -> 
             RGBColor[
              0.9705661637703198, 0.9752902440772628, 0.8175903941034398], 
             UndirectedEdge[31, 258] -> 
             RGBColor[
              0.8909754966215481, 0.9109994809919564, 0.709877857727577], 
             UndirectedEdge[31, 203] -> 
             RGBColor[
              0.9932761131046299, 0.9880266107570783, 0.5095245903379517], 
             UndirectedEdge[398, 445] -> 
             RGBColor[
              0.7974411413303848, 0.8419743154085755, 0.9557463222391303], 
             UndirectedEdge[44, 369] -> 
             RGBColor[
              0.9793510890195991, 0.9814488587901202, 0.771523595756118], 
             UndirectedEdge[267, 278] -> 
             RGBColor[
              0.5574461182265952, 0.6513172316630873, 0.9584959232312578], 
             UndirectedEdge[130, 477] -> 
             RGBColor[
              0.9802616790959897, 0.983174247943178, 0.8455016702052396], 
             UndirectedEdge[4, 482] -> 
             RGBColor[
              0.8274406755068952, 0.8653791337350675, 0.983367032487297], 
             UndirectedEdge[219, 274] -> 
             RGBColor[
              0.950479516447861, 0.8805636760008482, 0.6072440693995416], 
             UndirectedEdge[44, 269] -> 
             RGBColor[
              0.9792525157832883, 0.9812380206049345, 0.7607945073071846], 
             UndirectedEdge[130, 143] -> 
             RGBColor[
              0.9809899123272432, 0.9477538109197257, 0.5398461533550286], 
             UndirectedEdge[315, 401] -> 
             RGBColor[
              0.9786550257893949, 0.9822510765491571, 0.860539422717682], 
             UndirectedEdge[75, 163] -> 
             RGBColor[
              0.7492882582229244, 0.8000249370420791, 0.8429676071826606], 
             UndirectedEdge[9, 139] -> 
             RGBColor[
              0.8380679819931477, 0.8735693767281827, 0.9442439868369649], 
             UndirectedEdge[134, 438] -> 
             RGBColor[
              0.6904851451309826, 0.7319891165483536, 0.6603079763301986], 
             UndirectedEdge[76, 431] -> 
             RGBColor[
              0.9527871640691677, 0.9599671681090814, 0.7100552260291759], 
             UndirectedEdge[90, 124] -> 
             RGBColor[
              0.7059865181264988, 0.7645027024799292, 0.8626194310313148], 
             UndirectedEdge[37, 188] -> 
             RGBColor[
              0.8957918404582179, 0.9171084508860823, 0.8791157198628796], 
             UndirectedEdge[26, 106] -> 
             RGBColor[
              0.9733046402272749, 0.9188443889978548, 0.48496055754648837`], 
             UndirectedEdge[107, 446] -> 
             RGBColor[
              0.9429803773744512, 0.9535804051704038, 0.8252755726572444], 
             UndirectedEdge[19, 234] -> 
             RGBColor[
              0.9240115380561846, 0.9411825118287986, 0.9557516214091182], 
             UndirectedEdge[39, 243] -> 
             RGBColor[
              0.8494900620346872, 0.8829979479128978, 0.9709735669130215], 
             UndirectedEdge[129, 265] -> 
             RGBColor[
              0.9856691067546856, 0.9866900384068871, 0.8028195749618188], 
             UndirectedEdge[396, 446] -> 
             RGBColor[
              0.9808313178599062, 0.9829546976466479, 0.8009059380848129], 
             UndirectedEdge[325, 368] -> 
             RGBColor[
              0.8956346070836911, 0.9166789615403069, 0.8651948979917713], 
             UndirectedEdge[52, 56] -> 
             RGBColor[
              0.9899295523196945, 0.9885223871996391, 0.7016175898880166], 
             UndirectedEdge[402, 431] -> 
             RGBColor[
              0.9681279744835413, 0.9719925749508387, 0.7043437423128047], 
             UndirectedEdge[165, 353] -> 
             RGBColor[
              0.9201694024828593, 0.9367724025677575, 0.898554917396958], 
             UndirectedEdge[237, 329] -> 
             RGBColor[
              0.8307310847614414, 0.8682944762778347, 0.9666327886472934], 
             UndirectedEdge[63, 75] -> 
             RGBColor[
              0.887384181324894, 0.9100330938502743, 0.8552777692497255], 
             UndirectedEdge[392, 492] -> 
             RGBColor[
              0.9674799515050507, 0.9740837960753526, 0.8869377174916183], 
             UndirectedEdge[125, 177] -> 
             RGBColor[
              0.7692276069360491, 0.8196457199755667, 0.9776330770848463], 
             UndirectedEdge[210, 348] -> 
             RGBColor[
              0.9400615506959966, 0.9512446163186681, 0.8243165907011964], 
             UndirectedEdge[469, 491] -> 
             RGBColor[
              0.9940097487729965, 0.9913054202056655, 0.7136488627597094], 
             UndirectedEdge[35, 171] -> 
             RGBColor[
              0.8818257871542162, 0.5468112511541745, 0.5699735661880891], 
             UndirectedEdge[8, 40] -> 
             RGBColor[
              0.6967310318130466, 0.7575830273186905, 0.9023487815555367], 
             UndirectedEdge[405, 491] -> 
             RGBColor[
              0.9877145145083333, 0.988844875805976, 0.8379156776280983], 
             UndirectedEdge[98, 136] -> 
             RGBColor[
              0.9163746635423013, 0.8519038768286202, 0.6286133104410252], 
             UndirectedEdge[14, 75] -> 
             RGBColor[
              0.922515537748042, 0.9377205184687467, 0.8587149713547713], 
             UndirectedEdge[121, 500] -> 
             RGBColor[
              0.9500697026470515, 0.9622826465043051, 0.9694031488980703], 
             UndirectedEdge[1, 265] -> 
             RGBColor[
              0.9948063682754991, 0.9912996718350364, 0.6760834220468221], 
             UndirectedEdge[227, 495] -> 
             RGBColor[
              0.7121920155230351, 0.7731100234578097, 0.9582829080210821], 
             UndirectedEdge[127, 368] -> 
             RGBColor[
              0.8943645422751707, 0.9161537571028069, 0.8862431586913175], 
             UndirectedEdge[207, 389] -> 
             RGBColor[
              0.9856489971973292, 0.9625034794901044, 0.4624696298656822], 
             UndirectedEdge[249, 260] -> 
             RGBColor[
              0.8266452800194536, 0.8628361172499364, 0.8606830421782874], 
             UndirectedEdge[42, 95] -> 
             RGBColor[
              0.9694979514802098, 0.9756594458577146, 0.8866846676278526], 
             UndirectedEdge[190, 323] -> 
             RGBColor[
              0.9454293987346674, 0.8087782926817968, 0.3346367858940176], 
             UndirectedEdge[109, 295] -> 
             RGBColor[
              0.9112239341668893, 0.8729554595732492, 0.6337557264814251], 
             UndirectedEdge[382, 499] -> 
             RGBColor[
              0.8690848566025366, 0.8963413116035555, 0.8808322343909911], 
             UndirectedEdge[213, 254] -> 
             RGBColor[
              0.8451747645588835, 0.8769398849657546, 0.8430988537085882], 
             UndirectedEdge[47, 374] -> 
             RGBColor[
              0.9615567841069168, 0.904041731885901, 0.6002989977767439], 
             UndirectedEdge[244, 390] -> 
             RGBColor[
              0.9937604604907377, 0.9894729386603163, 0.5920714957821938], 
             UndirectedEdge[92, 370] -> 
             RGBColor[
              0.9671130715354274, 0.9356392987589264, 0.6289325227981217], 
             UndirectedEdge[295, 458] -> 
             RGBColor[0.9141852695557393, 0.9338458146867, 0.9720977823778174]
              , UndirectedEdge[278, 493] -> 
             RGBColor[
              0.8233515554084578, 0.8495956009456498, 0.6833835205366232], 
             UndirectedEdge[6, 156] -> 
             RGBColor[
              0.9682845858227092, 0.9046786022259303, 0.3312920341849862], 
             UndirectedEdge[79, 413] -> 
             RGBColor[
              0.9410555489210546, 0.9533825424236098, 0.8986404903137775], 
             UndirectedEdge[122, 476] -> 
             RGBColor[
              0.9515987564575576, 0.9623454146287953, 0.9237897547214298], 
             UndirectedEdge[123, 455] -> 
             RGBColor[
              0.9612769394230778, 0.9234389339114312, 0.6221522054342667], 
             UndirectedEdge[113, 302] -> 
             RGBColor[
              0.7937503048481507, 0.8365648944800934, 0.8650147597923661], 
             UndirectedEdge[402, 462] -> 
             RGBColor[
              0.9688349752337316, 0.9746572467745138, 0.865068719844065], 
             UndirectedEdge[140, 363] -> 
             RGBColor[
              0.9912347418009599, 0.9905753120454961, 0.7899805578285364], 
             UndirectedEdge[440, 453] -> 
             RGBColor[
              0.9171740860586133, 0.9321339729794252, 0.7523543016048231], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.8453677604541636, 0.8769284996712441, 0.8301302875888237], 
             UndirectedEdge[102, 202] -> 
             RGBColor[
              0.9122282897886158, 0.9320189734384711, 0.9626749136442239], 
             UndirectedEdge[363, 379] -> 
             RGBColor[
              0.9267145928888709, 0.9425605351781153, 0.923894766440922], 
             UndirectedEdge[162, 297] -> 
             RGBColor[
              0.8924474297324996, 0.9137224419907266, 0.8360199164503525], 
             UndirectedEdge[19, 393] -> 
             RGBColor[
              0.7417817691188676, 0.7963309977334334, 0.9391198005373103], 
             UndirectedEdge[96, 238] -> 
             RGBColor[
              0.8352013092254895, 0.8682821319202672, 0.77270944851736], 
             UndirectedEdge[117, 247] -> 
             RGBColor[
              0.8513800501153692, 0.8815843902639431, 0.8274491865574881], 
             UndirectedEdge[162, 223] -> 
             RGBColor[
              0.9881267619070053, 0.9700971641561889, 0.537094124270323], 
             UndirectedEdge[355, 362] -> 
             RGBColor[
              0.925413680855639, 0.9395065536064788, 0.8181976185852629], 
             UndirectedEdge[59, 395] -> 
             RGBColor[
              0.9706657098135889, 0.9773500948027998, 0.9214174412611618], 
             UndirectedEdge[161, 403] -> 
             RGBColor[
              0.9752275866589593, 0.9787882232275407, 0.8114055630476198], 
             UndirectedEdge[214, 477] -> 
             RGBColor[
              0.9778697531079052, 0.982185125077411, 0.8851420739338273], 
             UndirectedEdge[65, 309] -> 
             RGBColor[
              0.7856391268635909, 0.833020895492127, 0.9716607007242422], 
             UndirectedEdge[361, 498] -> 
             RGBColor[
              0.9484074135310839, 0.9595863833477946, 0.9141779328138065], 
             UndirectedEdge[54, 70] -> 
             RGBColor[
              0.6873942637440288, 0.751982336471859, 0.9543935394104635], 
             UndirectedEdge[369, 390] -> 
             RGBColor[
              0.9934029738929913, 0.98829795315579, 0.5233326042570463], 
             UndirectedEdge[56, 88] -> 
             RGBColor[
              0.9930007678738322, 0.9874376751500751, 0.4795549611993988], 
             UndirectedEdge[289, 419] -> 
             RGBColor[
              0.8231238703010956, 0.8609274596166592, 0.8985252655136028], 
             UndirectedEdge[124, 178] -> 
             RGBColor[
              0.9825997039847247, 0.985196477124464, 0.8540173276455765], 
             UndirectedEdge[67, 465] -> 
             RGBColor[
              0.9755561874330658, 0.9400860725199933, 0.5924289905998613], 
             UndirectedEdge[7, 461] -> 
             RGBColor[
              0.9147545373232825, 0.9348644539838796, 0.9917312984525521], 
             UndirectedEdge[273, 423] -> 
             RGBColor[
              0.9807619130788385, 0.9460659117160315, 0.439426934286659], 
             UndirectedEdge[63, 467] -> 
             RGBColor[
              0.8638974528757422, 0.8943188548097503, 0.9757374948817594], 
             UndirectedEdge[179, 368] -> 
             RGBColor[
              0.869202423043113, 0.8985867500832709, 0.9825234770720759], 
             UndirectedEdge[211, 485] -> 
             RGBColor[
              0.8254628334457681, 0.8372682855120179, 0.6631838165311892], 
             UndirectedEdge[21, 320] -> 
             RGBColor[
              0.8574129028956641, 0.8891417911884987, 0.9862620021713645], 
             UndirectedEdge[318, 479] -> 
             RGBColor[
              0.9855334102597397, 0.9700299565506738, 0.605533959832748], 
             UndirectedEdge[343, 465] -> 
             RGBColor[
              0.9715278904318894, 0.9778575183238019, 0.9138860252441239], 
             UndirectedEdge[229, 313] -> 
             RGBColor[
              0.9915655777471801, 0.9907801638907636, 0.789443734521711], 
             UndirectedEdge[168, 401] -> 
             RGBColor[
              0.7967273464814977, 0.8390795725170939, 0.8693367747791779], 
             UndirectedEdge[70, 216] -> 
             RGBColor[
              0.9748790639779512, 0.9784829386791845, 0.8083966447428548], 
             UndirectedEdge[5, 193] -> 
             RGBColor[
              0.9131887093513891, 0.9320424682921058, 0.9342032984494604], 
             UndirectedEdge[213, 471] -> 
             RGBColor[
              0.8387839285306002, 0.8740922655621012, 0.9424720728244838], 
             UndirectedEdge[145, 404] -> 
             RGBColor[
              0.8933842713094691, 0.6264976642022742, 0.5775452465349189], 
             UndirectedEdge[28, 173] -> 
             RGBColor[
              0.9180416589138434, 0.9055775089432468, 0.6659315784352666], 
             UndirectedEdge[210, 243] -> 
             RGBColor[
              0.8163341265086606, 0.8569749682109646, 0.9821877608458685], 
             UndirectedEdge[133, 424] -> 
             RGBColor[
              0.7870330458281889, 0.8340140617742291, 0.9792860591272781], 
             UndirectedEdge[201, 400] -> 
             RGBColor[
              0.8767205569792536, 0.9000267837074492, 0.7215421560706178], 
             UndirectedEdge[120, 125] -> 
             RGBColor[
              0.8655774051951055, 0.8935556489954736, 0.8784142706712145], 
             UndirectedEdge[96, 343] -> 
             RGBColor[
              0.8163951197877255, 0.8570641726996948, 0.9636377974894975], 
             UndirectedEdge[22, 149] -> 
             RGBColor[
              0.9924539866021265, 0.9892175905438003, 0.6344332737737022], 
             UndirectedEdge[140, 369] -> 
             RGBColor[
              0.9946472397650077, 0.9909593120414557, 0.6587632657071656], 
             UndirectedEdge[169, 370] -> 
             RGBColor[
              0.9803345660824967, 0.9835792808113698, 0.8610821840505474], 
             UndirectedEdge[154, 380] -> 
             RGBColor[
              0.8382256919297999, 0.8739257845819517, 0.9560644366115343], 
             UndirectedEdge[33, 489] -> 
             RGBColor[
              0.6964395342551991, 0.7625058744483872, 0.9705677995407662], 
             UndirectedEdge[271, 284] -> 
             RGBColor[
              0.8865964350375715, 0.911984114350979, 0.9742123078459588], 
             UndirectedEdge[112, 356] -> 
             RGBColor[
              0.8040246624467762, 0.8454610111167136, 0.8890218578627596], 
             UndirectedEdge[133, 155] -> 
             RGBColor[
              0.935645820521037, 0.9476653840316349, 0.8191735692008874], 
             UndirectedEdge[82, 447] -> 
             RGBColor[
              0.9266540866884798, 0.8185214863649606, 0.6132248779407542], 
             UndirectedEdge[225, 260] -> 
             RGBColor[
              0.9940002081962305, 0.9909706640612856, 0.6897605167237458], 
             UndirectedEdge[133, 225] -> 
             RGBColor[
              0.9355292342284203, 0.9474160177404102, 0.8064838707367536], 
             UndirectedEdge[442, 444] -> 
             RGBColor[
              0.9700415247380928, 0.9746160812123539, 0.7960325235599415], 
             UndirectedEdge[49, 431] -> 
             RGBColor[
              0.9852107838250407, 0.9617566879558254, 0.398573846105717], 
             UndirectedEdge[220, 427] -> 
             RGBColor[
              0.9880340713341625, 0.9754393921892124, 0.5943337767825982], 
             UndirectedEdge[151, 192] -> 
             RGBColor[
              0.9873175486259458, 0.9890234946797645, 0.8598445706075233], 
             UndirectedEdge[167, 326] -> 
             RGBColor[
              0.9243336363925198, 0.702423194214543, 0.4518181982028842], 
             UndirectedEdge[109, 196] -> 
             RGBColor[
              0.9212835803410719, 0.7217814002658696, 0.25532242066640265`], 
             UndirectedEdge[212, 451] -> 
             RGBColor[
              0.9923717843771693, 0.9911135510508295, 0.776082804266911], 
             UndirectedEdge[186, 414] -> 
             RGBColor[
              0.9925454586430165, 0.9864638147441851, 0.42999736126797494`], 
             UndirectedEdge[349, 419] -> 
             RGBColor[
              0.8255474241831655, 0.8607633834599167, 0.7735846092068173], 
             UndirectedEdge[162, 221] -> 
             RGBColor[
              0.9302211035450845, 0.7368532165113577, 0.450906685017035], 
             UndirectedEdge[163, 364] -> 
             RGBColor[
              0.7487376111829414, 0.7986377532391259, 0.7678115084884645], 
             UndirectedEdge[191, 300] -> 
             RGBColor[
              0.7263773873457472, 0.7857761865728485, 0.9737477304059813], 
             UndirectedEdge[438, 460] -> 
             RGBColor[
              0.7920750177756614, 0.8158646904952278, 0.6679185854684131], 
             UndirectedEdge[172, 473] -> 
             RGBColor[
              0.9570990764899701, 0.9672905273955488, 0.9486014157174115], 
             UndirectedEdge[141, 188] -> 
             RGBColor[
              0.8731720044922169, 0.9015823572801341, 0.97758075985965], 
             UndirectedEdge[79, 122] -> 
             RGBColor[
              0.9890122570831731, 0.9897243001788487, 0.831758865706367], 
             UndirectedEdge[326, 475] -> 
             RGBColor[
              0.9239951041033246, 0.7024668902128199, 0.47078071826259404`], 
             UndirectedEdge[98, 124] -> 
             RGBColor[
              0.9640443897431762, 0.8871078540454617, 0.5222346132552711], 
             UndirectedEdge[204, 498] -> 
             RGBColor[
              0.8572624335263515, 0.8891316814233186, 0.9862184940358649], 
             UndirectedEdge[72, 144] -> 
             RGBColor[
              0.6757242257856149, 0.7420525603616609, 0.9562510136016664], 
             UndirectedEdge[98, 331] -> 
             RGBColor[
              0.9123164804547177, 0.8486679917910263, 0.6282262373153487], 
             UndirectedEdge[311, 377] -> 
             RGBColor[
              0.9855262526315562, 0.9624854593864822, 0.4283175861725603], 
             UndirectedEdge[299, 389] -> 
             RGBColor[
              0.97326367487201, 0.9561989465598639, 0.6524278307655094], 
             UndirectedEdge[131, 238] -> 
             RGBColor[
              0.9936424507989179, 0.9888101700427374, 0.5493981875869949], 
             UndirectedEdge[4, 185] -> 
             RGBColor[
              0.8090463017215679, 0.8510093091315512, 0.9815336532135719], 
             UndirectedEdge[162, 258] -> 
             RGBColor[
              0.892134136795264, 0.9134776951670438, 0.8359886903382578], 
             UndirectedEdge[124, 253] -> 
             RGBColor[
              0.8951658297240912, 0.91661581231018, 0.8788903471987867], 
             UndirectedEdge[319, 449] -> 
             RGBColor[
              0.8765126014053399, 0.8105926501385343, 0.6226780356386885], 
             UndirectedEdge[256, 271] -> 
             RGBColor[
              0.9686826354781146, 0.962628186351342, 0.6810830450013292], 
             UndirectedEdge[379, 478] -> 
             RGBColor[
              0.9244337554082812, 0.9413702526484066, 0.9506286099895296], 
             UndirectedEdge[349, 371] -> 
             RGBColor[
              0.9945729764328178, 0.9908004702830763, 0.6506801602984631], 
             UndirectedEdge[130, 325] -> 
             RGBColor[
              0.9939622689299565, 0.9917712572869956, 0.7497243591851476], 
             UndirectedEdge[269, 369] -> 
             RGBColor[
              0.9939927792934413, 0.9895594872688792, 0.5875292822390267], 
             UndirectedEdge[43, 355] -> 
             RGBColor[
              0.9194947748095395, 0.9374313610074537, 0.9501338602526654], 
             UndirectedEdge[11, 414] -> 
             RGBColor[
              0.9290036920853011, 0.9410165344858494, 0.708894170673503], 
             UndirectedEdge[117, 255] -> 
             RGBColor[
              0.7948354397331395, 0.8401502614083416, 0.9800528725209734], 
             UndirectedEdge[401, 475] -> 
             RGBColor[
              0.9933563091638142, 0.9915206773512399, 0.7597666806837322], 
             UndirectedEdge[58, 141] -> 
             RGBColor[
              0.9463341777176877, 0.9594966981283461, 0.9757264182225451], 
             UndirectedEdge[96, 180] -> 
             RGBColor[
              0.8355376440582027, 0.8690015181187731, 0.80931741944022], 
             UndirectedEdge[119, 375] -> 
             RGBColor[
              0.9769255736106659, 0.9807450400589837, 0.8537844345323861], 
             UndirectedEdge[220, 382] -> 
             RGBColor[
              0.8688697195906203, 0.896252346920359, 0.884397611435185], 
             UndirectedEdge[104, 356] -> 
             RGBColor[
              0.9873945091283307, 0.9890553198252954, 0.8585691359156082], 
             UndirectedEdge[225, 440] -> 
             RGBColor[
              0.9176557374270915, 0.9331641765541767, 0.8047790806559839], 
             UndirectedEdge[259, 341] -> 
             RGBColor[
              0.969952586398881, 0.9745690207268329, 0.7977120319007616], 
             UndirectedEdge[290, 362] -> 
             RGBColor[
              0.9513516172581375, 0.9601887600273036, 0.8206716021144023], 
             UndirectedEdge[79, 267] -> 
             RGBColor[
              0.7223034915917121, 0.7790293406186695, 0.8789622910760776], 
             UndirectedEdge[90, 317] -> 
             RGBColor[
              0.7045154727843452, 0.7638943874268078, 0.8869984592941099], 
             UndirectedEdge[41, 389] -> 
             RGBColor[
              0.8971542976195132, 0.89639507646185, 0.674886768193173], 
             UndirectedEdge[5, 300] -> 
             RGBColor[
              0.8473615188900939, 0.8811270904200077, 0.9853032921919368], 
             UndirectedEdge[290, 340] -> 
             RGBColor[
              0.926881051889892, 0.9442777702813763, 0.9840109639665258], 
             UndirectedEdge[288, 392] -> 
             RGBColor[
              0.979404593923856, 0.9829771748664875, 0.8667524083214277], 
             UndirectedEdge[45, 292] -> 
             RGBColor[
              0.9500207775728038, 0.9611085051174044, 0.9245653818740414], 
             UndirectedEdge[42, 145] -> 
             RGBColor[
              0.9485386659022239, 0.9611408018068552, 0.9719947947487275], 
             UndirectedEdge[100, 368] -> 
             RGBColor[
              0.8821576385037422, 0.9082487285615897, 0.960593676558575], 
             UndirectedEdge[302, 315] -> 
             RGBColor[
              0.7798392371849787, 0.8276220681822288, 0.9526915824782427], 
             UndirectedEdge[255, 338] -> 
             RGBColor[
              0.9380134881697288, 0.9493345191447013, 0.8016644807460507], 
             UndirectedEdge[59, 263] -> 
             RGBColor[
              0.9732885127762414, 0.9793061769579005, 0.9169777199819605], 
             UndirectedEdge[413, 486] -> 
             RGBColor[
              0.9409490431374279, 0.9533384995450063, 0.9004055667766038], 
             UndirectedEdge[140, 247] -> 
             RGBColor[
              0.9950382624552949, 0.9917956700375219, 0.7013236724326215], 
             UndirectedEdge[82, 453] -> 
             RGBColor[
              0.968508706229737, 0.9728619021484817, 0.7501465100354849], 
             UndirectedEdge[199, 349] -> 
             RGBColor[
              0.906838583644985, 0.9242686550671847, 0.7816869522728951], 
             UndirectedEdge[265, 462] -> 
             RGBColor[
              0.9943986039072458, 0.9915799737904034, 0.7154730959683411], 
             UndirectedEdge[113, 386] -> 
             RGBColor[
              0.9682366376745489, 0.9743994917141404, 0.8745222528723713], 
             UndirectedEdge[140, 219] -> 
             RGBColor[
              0.9661874697293596, 0.8903812509093347, 0.49378666507229163`], 
             UndirectedEdge[13, 313] -> 
             RGBColor[
              0.9858656607351931, 0.9656011376194941, 0.568466215249174], 
             UndirectedEdge[74, 463] -> 
             RGBColor[
              0.8467078350273718, 0.36002246429000495`, 0.19236078161215292`],
              UndirectedEdge[146, 415] -> 
             RGBColor[
              0.8756123617573146, 0.9017229605752952, 0.8942840750076679], 
             UndirectedEdge[213, 475] -> 
             RGBColor[
              0.844784470426704, 0.8768728676158128, 0.8564274165965063], 
             UndirectedEdge[49, 328] -> 
             RGBColor[
              0.9642811131255802, 0.9499052749387724, 0.6684937819852275], 
             UndirectedEdge[259, 450] -> 
             RGBColor[
              0.9693393243644466, 0.9732573152454804, 0.7309622440671371], 
             UndirectedEdge[454, 500] -> 
             RGBColor[
              0.9499804039249005, 0.9622160476635381, 0.9695543083418352], 
             UndirectedEdge[469, 495] -> 
             RGBColor[
              0.7332194915496333, 0.7865578496417182, 0.8090782506337693], 
             UndirectedEdge[158, 182] -> 
             RGBColor[
              0.9839198717216213, 0.9678748671123294, 0.6219905068357652], 
             UndirectedEdge[302, 347] -> 
             RGBColor[
              0.7269716070194557, 0.786222174826302, 0.973836435267355], 
             UndirectedEdge[87, 107] -> 
             RGBColor[
              0.9426612023551268, 0.9528977220776136, 0.7905353415236862], 
             UndirectedEdge[80, 307] -> 
             RGBColor[
              0.661112716249171, 0.7329795402064553, 0.968393294886822], 
             UndirectedEdge[159, 443] -> 
             RGBColor[
              0.9655216994914453, 0.9574361575990451, 0.6804163490811417], 
             UndirectedEdge[396, 443] -> 
             RGBColor[
              0.974956002521967, 0.9644722453519547, 0.6644465349107788], 
             UndirectedEdge[15, 452] -> 
             RGBColor[
              0.5617164002596624, 0.6317635487037501, 0.9561611919511135], 
             UndirectedEdge[55, 250] -> 
             RGBColor[
              0.7557042670250094, 0.804052045609721, 0.7485623323569136], 
             UndirectedEdge[105, 447] -> 
             RGBColor[
              0.9385899875627426, 0.8274232616937418, 0.5930205111421498], 
             UndirectedEdge[55, 242] -> 
             RGBColor[
              0.9716884181435197, 0.9753736377801501, 0.7558972198428406], 
             UndirectedEdge[133, 440] -> 
             RGBColor[
              0.8588491809673195, 0.8902870403361072, 0.9863989956560195], 
             UndirectedEdge[177, 455] -> 
             RGBColor[
              0.8812042753892193, 0.9075728117634821, 0.9639842203827906], 
             UndirectedEdge[186, 456] -> 
             RGBColor[
              0.9061427698283213, 0.9227803796709094, 0.7059519123941675], 
             UndirectedEdge[94, 302] -> 
             RGBColor[
              0.7943012736359236, 0.8356121616725738, 0.7700686187254839], 
             UndirectedEdge[146, 376] -> 
             RGBColor[
              0.9620116803055054, 0.9701387298395618, 0.902651421220214], 
             UndirectedEdge[44, 106] -> 
             RGBColor[
              0.9797722774671576, 0.9823497382907636, 0.8173673589990668], 
             UndirectedEdge[46, 205] -> 
             RGBColor[
              0.7170008655303151, 0.6309199623248558, 0.5963980357647831], 
             UndirectedEdge[134, 457] -> 
             RGBColor[
              0.6977149497609674, 0.7570247178871694, 0.8505671124255672], 
             UndirectedEdge[229, 248] -> 
             RGBColor[
              0.9131139132516399, 0.9311716682004387, 0.8989728090532525], 
             UndirectedEdge[101, 362] -> 
             RGBColor[
              0.9786354517245938, 0.981247817555378, 0.7991317092210788], 
             UndirectedEdge[286, 346] -> 
             RGBColor[
              0.871959950045134, 0.8960545442539305, 0.700786260241582], 
             UndirectedEdge[134, 138] -> 
             RGBColor[
              0.6949225092951088, 0.7558699719920903, 0.8968450775491136], 
             UndirectedEdge[144, 494] -> 
             RGBColor[
              0.8705281482152276, 0.8994260554081019, 0.9727158383564268], 
             UndirectedEdge[35, 147] -> 
             RGBColor[
              0.7101585786949571, 0.41135354739168994`, 0.5630536851431084], 
             UndirectedEdge[5, 211] -> 
             RGBColor[
              0.9078377686985521, 0.9017860567491619, 0.6713501698782232], 
             UndirectedEdge[243, 471] -> 
             RGBColor[
              0.8647959405012113, 0.8944130470121556, 0.9450647070816418], 
             UndirectedEdge[154, 338] -> 
             RGBColor[
              0.9807025306507244, 0.9825622519590429, 0.7776061548053315], 
             UndirectedEdge[185, 383] -> 
             RGBColor[
              0.8716932776336157, 0.8998955942754576, 0.9505253703863377], 
             UndirectedEdge[416, 429] -> 
             RGBColor[
              0.6958522221268939, 0.7568640010811252, 0.9038421850693523], 
             UndirectedEdge[159, 396] -> 
             RGBColor[
              0.9575600130207307, 0.9678689077167375, 0.9567240072212544], 
             UndirectedEdge[73, 322] -> 
             RGBColor[
              0.8972184290840788, 0.9182355309888981, 0.8798300728198502], 
             UndirectedEdge[287, 300] -> 
             RGBColor[
              0.9231304315471882, 0.9387863292993089, 0.8837643040274931], 
             UndirectedEdge[392, 459] -> 
             RGBColor[
              0.9138871234223207, 0.9315552332150019, 0.8889301191744214], 
             UndirectedEdge[200, 450] -> 
             RGBColor[
              0.9895398457828933, 0.988017659307254, 0.6831018165698124], 
             UndirectedEdge[104, 148] -> 
             RGBColor[
              0.9067701028133148, 0.9271376401338538, 0.9428487258430914], 
             UndirectedEdge[94, 325] -> 
             RGBColor[
              0.9939308847439735, 0.9905777065590391, 0.664429313974586], 
             UndirectedEdge[355, 378] -> 
             RGBColor[
              0.846571741888385, 0.8804973436767705, 0.9852279625564715], 
             UndirectedEdge[424, 453] -> 
             RGBColor[
              0.8453579509194826, 0.8758609944175471, 0.7452413650760816], 
             UndirectedEdge[212, 301] -> 
             RGBColor[
              0.9433094067713281, 0.9547501133620406, 0.8802010048728179], 
             UndirectedEdge[46, 420] -> 
             RGBColor[
              0.9445972871012789, 0.8090279224794973, 0.5112579013146007], 
             UndirectedEdge[146, 284] -> 
             RGBColor[
              0.905561157036936, 0.9251266148938384, 0.8972671199168809], 
             UndirectedEdge[76, 343] -> 
             RGBColor[
              0.9346630754825009, 0.9502081536380309, 0.9752260432047337], 
             UndirectedEdge[111, 256] -> 
             RGBColor[
              0.9762569529928831, 0.9682770999520496, 0.6682617011472209], 
             UndirectedEdge[277, 319] -> 
             RGBColor[
              0.9084581069338173, 0.9267753301346209, 0.8688303715934029], 
             UndirectedEdge[240, 429] -> 
             RGBColor[
              0.9047569402285869, 0.5805060597542866, 0.514815257470358], 
             UndirectedEdge[49, 71] -> 
             RGBColor[
              0.9845153097805779, 0.9638414004099534, 0.5825414604728041], 
             UndirectedEdge[19, 139] -> 
             RGBColor[
              0.9786318788419752, 0.9835842707442081, 0.921054834808686], 
             UndirectedEdge[9, 247] -> 
             RGBColor[
              0.8453375946968925, 0.876863978166667, 0.8268469310713307], 
             UndirectedEdge[333, 392] -> 
             RGBColor[
              0.9791222649712301, 0.9453921438702901, 0.5598123970169571], 
             UndirectedEdge[169, 337] -> 
             RGBColor[
              0.9498776901730681, 0.9601474713586684, 0.8877746860020812], 
             UndirectedEdge[21, 119] -> 
             RGBColor[
              0.9138246563515963, 0.9310626455768832, 0.869697207554252], 
             UndirectedEdge[354, 479] -> 
             RGBColor[
              0.9904026249299502, 0.9902992530143149, 0.8087168723286251], 
             UndirectedEdge[179, 236] -> 
             RGBColor[
              0.9673821327440263, 0.972236168023741, 0.7690701900516168], 
             UndirectedEdge[121, 341] -> 
             RGBColor[
              0.9717206188418837, 0.9758876164279369, 0.7947192141514718], 
             UndirectedEdge[263, 323] -> 
             RGBColor[
              0.9765945492513349, 0.9783318091447804, 0.6919858910682839], 
             UndirectedEdge[200, 401] -> 
             RGBColor[
              0.9891747417888554, 0.9897914917803148, 0.829066073636271], 
             UndirectedEdge[56, 236] -> 
             RGBColor[
              0.9935647286586677, 0.9886439302436565, 0.5409386122662307], 
             UndirectedEdge[374, 437] -> 
             RGBColor[
              0.9349967704612261, 0.8839153107244626, 0.634232688885976], 
             UndirectedEdge[74, 195] -> 
             RGBColor[
              0.8808583598422408, 0.5432062002443618, 0.22194360534103202`], 
             UndirectedEdge[240, 399] -> 
             RGBColor[
              0.9008139235637824, 0.5570584620460117, 0.2716672194657418], 
             UndirectedEdge[138, 352] -> 
             RGBColor[
              0.9906127088201468, 0.9885253111216028, 0.6699734879092147], 
             UndirectedEdge[195, 342] -> 
             RGBColor[
              0.9229649339252912, 0.813283985375707, 0.6175407792074765], 
             UndirectedEdge[13, 363] -> 
             RGBColor[
              0.9829838115977443, 0.9644094189410144, 0.6162259134431971], 
             UndirectedEdge[368, 386] -> 
             RGBColor[
              0.8704913288020394, 0.8995480138878886, 0.9803416958226745], 
             UndirectedEdge[132, 233] -> 
             RGBColor[
              0.8774706965673973, 0.903374839503474, 0.9035442059338179], 
             UndirectedEdge[304, 310] -> 
             RGBColor[
              0.8435577873554134, 0.8785862491807079, 0.984809887129589], 
             UndirectedEdge[213, 259] -> 
             RGBColor[
              0.8204023816332985, 0.8603833379831141, 0.9735872370463697], 
             UndirectedEdge[226, 446] -> 
             RGBColor[
              0.9386670023167258, 0.9501410369828205, 0.8248641590936432], 
             UndirectedEdge[60, 249] -> 
             RGBColor[
              0.7549961732141317, 0.8087735855153155, 0.9761494541169953], 
             UndirectedEdge[181, 387] -> 
             RGBColor[
              0.9251654104517865, 0.9430051098413146, 0.9871530119513814], 
             UndirectedEdge[94, 168] -> 
             RGBColor[
              0.7975238005179546, 0.8382283541685882, 0.7703223078461423], 
             UndirectedEdge[142, 402] -> 
             RGBColor[
              0.9682087680868317, 0.9721653842987903, 0.7131376274306356], 
             UndirectedEdge[188, 310] -> 
             RGBColor[
              0.77919875325054, 0.8274352552599658, 0.9786269077638146], 
             UndirectedEdge[74, 239] -> 
             RGBColor[
              0.9242163607726894, 0.7021723535221098, 0.43905347072557704`], 
             UndirectedEdge[376, 400] -> 
             RGBColor[
              0.9633415793504218, 0.968615749683237, 0.7299315996482982], 
             UndirectedEdge[292, 308] -> 
             RGBColor[
              0.9883622800604079, 0.9894555179762877, 0.8425306670602011], 
             UndirectedEdge[7, 142] -> 
             RGBColor[
              0.9541637202031463, 0.961173183326467, 0.7189727021339247], 
             UndirectedEdge[20, 194] -> 
             RGBColor[
              0.9931154891653449, 0.9876830523925191, 0.49204166580282127`], 
             UndirectedEdge[168, 500] -> 
             RGBColor[
              0.776054796315138, 0.8250124756017538, 0.9648062402929424], 
             UndirectedEdge[4, 383] -> 
             RGBColor[
              0.9144179349460155, 0.9335293434435747, 0.9547155857019789], 
             UndirectedEdge[91, 303] -> 
             RGBColor[
              0.9613886198424768, 0.9505734818915494, 0.6793878584347821], 
             UndirectedEdge[142, 417] -> 
             RGBColor[
              0.9366320451984296, 0.9471939015623465, 0.7173005153212638], 
             UndirectedEdge[229, 338] -> 
             RGBColor[
              0.9921719499056979, 0.9901344097584148, 0.714228157963513], 
             UndirectedEdge[69, 388] -> 
             RGBColor[
              0.9728446801172199, 0.9792681874109538, 0.9308510527065325], 
             UndirectedEdge[170, 374] -> 
             RGBColor[
              0.81885109722726, 0.7923458211722062, 0.622878117994985], 
             UndirectedEdge[96, 281] -> 
             RGBColor[
              0.8349642649770417, 0.8677751182416873, 0.746908644941351], 
             UndirectedEdge[131, 265] -> 
             RGBColor[
              0.9941198611990713, 0.98983130261507, 0.6013613634082304], 
             UndirectedEdge[117, 369] -> 
             RGBColor[
              0.8509890274250818, 0.8807480322678769, 0.7848887798320323], 
             UndirectedEdge[19, 247] -> 
             RGBColor[
              0.98590149154572, 0.9868788721826924, 0.8036577790430519], 
             UndirectedEdge[328, 436] -> 
             RGBColor[
              0.8937789179229008, 0.9177529326461402, 0.9763431933894244], 
             UndirectedEdge[86, 178] -> 
             RGBColor[
              0.9810093381304861, 0.9845388199731981, 0.8803738055852074], 
             UndirectedEdge[42, 137] -> 
             RGBColor[
              0.9005202027216389, 0.9231944383105439, 0.979280967972565], 
             UndirectedEdge[54, 135] -> 
             RGBColor[
              0.7027818514822727, 0.7631726606032281, 0.9155515279393227], 
             UndirectedEdge[42, 174] -> 
             RGBColor[
              0.9713963577153368, 0.9759308989544488, 0.8178908343046296], 
             UndirectedEdge[1, 374] -> 
             RGBColor[
              0.9706940456277303, 0.9086513653140503, 0.4735628448617471], 
             UndirectedEdge[160, 285] -> 
             RGBColor[
              0.8541720479740615, 0.8830929474858855, 0.7738578164782058], 
             UndirectedEdge[454, 471] -> 
             RGBColor[
              0.9656881131550878, 0.9739308314883985, 0.9429652538418216], 
             UndirectedEdge[26, 425] -> 
             RGBColor[
              0.9113845209804683, 0.8730835071393841, 0.6337710433950617], 
             UndirectedEdge[333, 442] -> 
             RGBColor[
              0.9805896136957902, 0.945108358160494, 0.4707594397586814], 
             UndirectedEdge[75, 410] -> 
             RGBColor[
              0.9777654979960919, 0.9811360007470515, 0.8418185709049897], 
             UndirectedEdge[31, 40] -> 
             RGBColor[
              0.9900455455465768, 0.9878710511499877, 0.6488633920367464], 
             UndirectedEdge[3, 258] -> 
             RGBColor[
              0.8637303275491366, 0.8943638839373513, 0.9846091087917546], 
             UndirectedEdge[132, 273] -> 
             RGBColor[
              0.9785073254658485, 0.9465502177589822, 0.5797657653279932], 
             UndirectedEdge[157, 180] -> 
             RGBColor[
              0.9071580222162112, 0.9249519018708439, 0.8164558694045234], 
             UndirectedEdge[213, 401] -> 
             RGBColor[
              0.8437487694667727, 0.8764445786525807, 0.8735916618107329], 
             UndirectedEdge[84, 391] -> 
             RGBColor[
              0.5646727862260263, 0.6573099987201181, 0.9589788006973137], 
             UndirectedEdge[43, 110] -> 
             RGBColor[
              0.9633855115754328, 0.9722135550004559, 0.9468629577015035], 
             UndirectedEdge[39, 127] -> 
             RGBColor[
              0.9715936464962998, 0.9771363082803073, 0.8792813124522985], 
             UndirectedEdge[52, 469] -> 
             RGBColor[
              0.9905646421225415, 0.9898807800704998, 0.7707431956079625], 
             UndirectedEdge[260, 483] -> 
             RGBColor[
              0.9898676292534583, 0.9900780185533237, 0.8175831352125255], 
             UndirectedEdge[98, 311] -> 
             RGBColor[
              0.9644322708812814, 0.8853647416940384, 0.3774412514103871], 
             UndirectedEdge[51, 127] -> 
             RGBColor[
              0.9652705261180634, 0.9724205354553781, 0.8899847059187349], 
             UndirectedEdge[243, 475] -> 
             RGBColor[
              0.8707964823973149, 0.8971936490658674, 0.8590200508536644], 
             UndirectedEdge[76, 96] -> 
             RGBColor[
              0.7947742805377553, 0.840355130634953, 0.9799797319306908], 
             UndirectedEdge[99, 476] -> 
             RGBColor[
              0.8899589230015292, 0.9150931041827342, 0.989366270623237], 
             UndirectedEdge[107, 308] -> 
             RGBColor[
              0.9402821856200907, 0.9529940473338283, 0.9084743867869309], 
             UndirectedEdge[190, 263] -> 
             RGBColor[
              0.9294561420818532, 0.8005984885504847, 0.5941929542313757], 
             UndirectedEdge[191, 299] -> 
             RGBColor[
              0.7837405367828478, 0.8306586421836238, 0.9494937768552794], 
             UndirectedEdge[39, 276] -> 
             RGBColor[
              0.9706657060309218, 0.9767525810508915, 0.894659687396553], 
             UndirectedEdge[51, 214] -> 
             RGBColor[
              0.9641626806573057, 0.971962412887025, 0.9083445722156394], 
             UndirectedEdge[295, 409] -> 
             RGBColor[
              0.8108475519022269, 0.8525700403677777, 0.98167242934791], 
             UndirectedEdge[371, 382] -> 
             RGBColor[
              0.8708153094681924, 0.8969998460527673, 0.848007053559187], 
             UndirectedEdge[53, 420] -> 
             RGBColor[
              0.972077933367278, 0.977440603161067, 0.8759140933224636], 
             UndirectedEdge[87, 308] -> 
             RGBColor[
              0.991650952894875, 0.9897353588942832, 0.7095162661148626], 
             UndirectedEdge[286, 358] -> 
             RGBColor[
              0.8698005725318978, 0.8975563056442442, 0.9106435605781273], 
             UndirectedEdge[215, 351] -> 
             RGBColor[
              0.992103723631406, 0.9895459623947249, 0.6746357428842416], 
             UndirectedEdge[114, 258] -> 
             RGBColor[
              0.8740312140031701, 0.9020462681886159, 0.9671723949265411], 
             UndirectedEdge[87, 292] -> 
             RGBColor[
              0.9907412967954441, 0.9893591927200731, 0.7245916217969564], 
             UndirectedEdge[196, 383] -> 
             RGBColor[
              0.9339782602552633, 0.7899308677894312, 0.5771884631442155], 
             UndirectedEdge[65, 495] -> 
             RGBColor[
              0.7079041654133669, 0.7699121518667292, 0.9655411198063343], 
             UndirectedEdge[14, 279] -> 
             RGBColor[
              0.9200245538771705, 0.9366904326227758, 0.8999970205547223], 
             UndirectedEdge[26, 466] -> 
             RGBColor[
              0.9670130646284143, 0.8991215954992677, 0.33295548822778454`], 
             UndirectedEdge[27, 371] -> 
             RGBColor[
              0.8593822108641413, 0.888068222528515, 0.8468675091387163], 
             UndirectedEdge[258, 472] -> 
             RGBColor[
              0.7985042141323387, 0.842516828027764, 0.980551095684723], 
             UndirectedEdge[26, 117] -> 
             RGBColor[
              0.8297811266750461, 0.8089212163110233, 0.6257472034476117], 
             UndirectedEdge[97, 104] -> 
             RGBColor[
              0.9776431683959788, 0.9827518956564791, 0.9184743283093282], 
             UndirectedEdge[21, 428] -> 
             RGBColor[
              0.8166653830597881, 0.856817977828374, 0.9823311101148147], 
             UndirectedEdge[160, 268] -> 
             RGBColor[
              0.8290531909908221, 0.8671765226325923, 0.9762265607808742], 
             UndirectedEdge[48, 137] -> 
             RGBColor[
              0.9236470224625553, 0.9379574946637488, 0.8066499826910101], 
             UndirectedEdge[27, 291] -> 
             RGBColor[
              0.8554074557976387, 0.8864816114433172, 0.9168865855064685], 
             UndirectedEdge[117, 140] -> 
             RGBColor[
              0.8515449146603373, 0.8819370188552675, 0.8453936748512378], 
             UndirectedEdge[31, 221] -> 
             RGBColor[
              0.9290624633713686, 0.7343750023362705, 0.3247958524063543], 
             UndirectedEdge[87, 386] -> 
             RGBColor[
              0.968845833138879, 0.9735712998801568, 0.7859137262153543], 
             UndirectedEdge[207, 409] -> 
             RGBColor[
              0.8723199886477142, 0.8971579432332774, 0.766670899289362], 
             UndirectedEdge[274, 498] -> 
             RGBColor[
              0.9359607458400577, 0.9510493911627755, 0.9686414104723451], 
             UndirectedEdge[28, 69] -> 
             RGBColor[
              0.9694637635625883, 0.9457696244212946, 0.6427365892816441], 
             UndirectedEdge[442, 492] -> 
             RGBColor[
              0.9689473002296108, 0.9738000103655563, 0.7978847602333428], 
             UndirectedEdge[476, 493] -> 
             RGBColor[
              0.9507954281479594, 0.9499288243511785, 0.6958807773965059], 
             UndirectedEdge[297, 359] -> 
             RGBColor[
              0.5338491065612595, 0.62254925487282, 0.9594133741494569], 
             UndirectedEdge[112, 323] -> 
             RGBColor[
              0.8052959553718079, 0.8436452245551189, 0.6977509953211152], 
             UndirectedEdge[27, 349] -> 
             RGBColor[
              0.8587393205622968, 0.8866931451790498, 0.7768928672419821], 
             UndirectedEdge[2, 242] -> 
             RGBColor[
              0.8889393712391775, 0.9139164402695183, 0.976659282433481], 
             UndirectedEdge[71, 462] -> 
             RGBColor[
              0.9925436186115324, 0.991184608922677, 0.7732350663107723], 
             UndirectedEdge[165, 285] -> 
             RGBColor[
              0.992057315464125, 0.9897762996474174, 0.6935429139383942], 
             UndirectedEdge[91, 172] -> 
             RGBColor[
              0.9547944006198101, 0.9454969225739163, 0.6850513407919098], 
             UndirectedEdge[19, 26] -> 
             RGBColor[
              0.9643025681053969, 0.9142156982297727, 0.6019557959331755], 
             UndirectedEdge[73, 163] -> 
             RGBColor[
              0.6528812764283798, 0.7266285102050649, 0.9674907111460824], 
             UndirectedEdge[67, 131] -> 
             RGBColor[
              0.9788645583623304, 0.9398207650183565, 0.41886950191486977`], 
             UndirectedEdge[24, 81] -> 
             RGBColor[
              0.7895602154451882, 0.8347200857428854, 0.9297692030983702], 
             UndirectedEdge[282, 467] -> 
             RGBColor[
              0.9472245487579967, 0.9601607353923598, 0.9742192522972611], 
             UndirectedEdge[122, 406] -> 
             RGBColor[
              0.965643804341243, 0.9733376156011186, 0.9179546800181406], 
             UndirectedEdge[139, 255] -> 
             RGBColor[
              0.9310591748243524, 0.9467143111521117, 0.9533799258679911], 
             UndirectedEdge[409, 458] -> 
             RGBColor[
              0.8542605041538682, 0.8866216294483376, 0.9662339766819963], 
             UndirectedEdge[4, 196] -> 
             RGBColor[
              0.8713312843432155, 0.7410445826455248, 0.6081967459714497], 
             UndirectedEdge[46, 90] -> 
             RGBColor[
              0.6585586694417653, 0.5825604220095029, 0.5920496638257362], 
             UndirectedEdge[115, 124] -> 
             RGBColor[
              0.9780047869681605, 0.9817695955369965, 0.8617953236083276], 
             UndirectedEdge[330, 350] -> 
             RGBColor[
              0.9735874420076467, 0.9761383325829436, 0.7009814640666308], 
             UndirectedEdge[213, 315] -> 
             RGBColor[
              0.8300831870522847, 0.86760326681373, 0.9572001586304562], 
             UndirectedEdge[107, 143] -> 
             RGBColor[
              0.929647987543033, 0.9099434896048504, 0.6598468432264004], 
             UndirectedEdge[403, 491] -> 
             RGBColor[
              0.9939934534857302, 0.9912705662339089, 0.7118752213036175], 
             UndirectedEdge[200, 254] -> 
             RGBColor[
              0.9906007368809664, 0.9902867980934886, 0.7985732655341262], 
             UndirectedEdge[37, 304] -> 
             RGBColor[
              0.9601508745630913, 0.9682594448068245, 0.885298699228654], 
             UndirectedEdge[25, 392] -> 
             RGBColor[
              0.8796493840173354, 0.904675287514755, 0.8855529587684443], 
             UndirectedEdge[231, 492] -> 
             RGBColor[
              0.9648791681580258, 0.9730083053242744, 0.9300394281633687], 
             UndirectedEdge[22, 63] -> 
             RGBColor[
              0.8857961076227987, 0.9093763845628253, 0.8815962602964433], 
             UndirectedEdge[201, 256] -> 
             RGBColor[
              0.8728186879701627, 0.8870969959656014, 0.6866452486463932], 
             UndirectedEdge[57, 92] -> 
             RGBColor[
              0.9170906516678421, 0.8966064556465336, 0.6537588457005594], 
             UndirectedEdge[433, 462] -> 
             RGBColor[
              0.9811760289887498, 0.948426304769142, 0.540877998588904], 
             UndirectedEdge[286, 294] -> 
             RGBColor[
              0.8198521818784219, 0.8597461193211346, 0.9825323521288268], 
             UndirectedEdge[319, 331] -> 
             RGBColor[
              0.8560477575945354, 0.8880532613812608, 0.9861317933938633], 
             UndirectedEdge[222, 307] -> 
             RGBColor[
              0.7446063961983345, 0.7961248871300552, 0.836417805079223], 
             UndirectedEdge[276, 283] -> 
             RGBColor[
              0.9804418562259858, 0.9840436178593932, 0.8781112151446401], 
             UndirectedEdge[464, 497] -> 
             RGBColor[
              0.6380571443168513, 0.581953339416099, 0.5944781126181993], 
             UndirectedEdge[143, 283] -> 
             RGBColor[
              0.9696675048971707, 0.9409351031590394, 0.6318063736707202], 
             UndirectedEdge[265, 433] -> 
             RGBColor[
              0.98162853948981, 0.9482417102673211, 0.5063586650822997], 
             UndirectedEdge[74, 234] -> 
             RGBColor[
              0.8623458445070799, 0.656517567424789, 0.5932629349633434], 
             UndirectedEdge[17, 432] -> 
             RGBColor[
              0.9581494973936378, 0.9661779598737951, 0.8640195926424273], 
             UndirectedEdge[103, 118] -> 
             RGBColor[
              0.9827247158485051, 0.9831851686395674, 0.7039442474083843], 
             UndirectedEdge[426, 489] -> 
             RGBColor[
              0.8042254902597, 0.8467858359458977, 0.9376041645466473], 
             UndirectedEdge[277, 331] -> 
             RGBColor[
              0.9412542763649867, 0.9529261054107314, 0.8719584995112339], 
             UndirectedEdge[74, 112] -> 
             RGBColor[
              0.7358111514611854, 0.5568818249726566, 0.5810156344834936], 
             UndirectedEdge[80, 372] -> 
             RGBColor[
              0.8830574949354996, 0.8286757078508504, 0.6261829656990165], 
             UndirectedEdge[180, 281] -> 
             RGBColor[
              0.9939955841922646, 0.9895654866638435, 0.5878345781661165], 
             UndirectedEdge[263, 296] -> 
             RGBColor[
              0.9770917584184404, 0.979395289277661, 0.7461040404884279], 
             UndirectedEdge[37, 141] -> 
             RGBColor[
              0.9696603588644419, 0.975549582813566, 0.8760657200790875], 
             UndirectedEdge[18, 210] -> 
             RGBColor[
              0.8071453344359222, 0.8497966140063351, 0.9812719079262019], 
             UndirectedEdge[279, 494] -> 
             RGBColor[
              0.8894693725363025, 0.9125779507587994, 0.8970159288150907], 
             UndirectedEdge[101, 337] -> 
             RGBColor[
              0.935295897783234, 0.9505472457587485, 0.9695483023694106], 
             UndirectedEdge[217, 378] -> 
             RGBColor[
              0.9151629640054884, 0.9305762086633039, 0.7558792138834822], 
             UndirectedEdge[20, 62] -> 
             RGBColor[
              0.8929946414250609, 0.9126505336361308, 0.7159806103480026], 
             UndirectedEdge[18, 56] -> 
             RGBColor[
              0.8611362237423423, 0.8882390931804219, 0.7509782994528058], 
             UndirectedEdge[444, 492] -> 
             RGBColor[
              0.94473914901672, 0.9583071283347844, 0.9784263857631723], 
             UndirectedEdge[199, 427] -> 
             RGBColor[
              0.902245268423902, 0.9096550761057292, 0.6889500108810322], 
             UndirectedEdge[190, 463] -> 
             RGBColor[
              0.8690542317685127, 0.46905254327817153`, 0.21130320561286647`],
              UndirectedEdge[139, 369] -> 
             RGBColor[
              0.9872127625162946, 0.987312082011647, 0.7582158331790501], 
             UndirectedEdge[10, 455] -> 
             RGBColor[
              0.9753487357172287, 0.9805707768743015, 0.9013135707182243], 
             UndirectedEdge[52, 236] -> 
             RGBColor[
              0.9900452040190851, 0.988769754490455, 0.7142055636471258], 
             UndirectedEdge[9, 19] -> 
             RGBColor[
              0.8363656883322859, 0.8722998089031619, 0.9471255259755108], 
             UndirectedEdge[33, 309] -> 
             RGBColor[
              0.6979042395917467, 0.7636949882248201, 0.9706831065102517], 
             UndirectedEdge[341, 491] -> 
             RGBColor[
              0.9937887906209248, 0.99083281306068, 0.689598931502348], 
             UndirectedEdge[87, 143] -> 
             RGBColor[
              0.9810167548178175, 0.9466848011653053, 0.4608887225543321], 
             UndirectedEdge[110, 378] -> 
             RGBColor[
              0.8904624786542785, 0.9152795376697727, 0.9819570600053096], 
             UndirectedEdge[401, 471] -> 
             RGBColor[
              0.9873557672677105, 0.9887400752975283, 0.8458113369117097], 
             UndirectedEdge[160, 165] -> 
             RGBColor[
              0.8523467249634695, 0.8835453399387299, 0.8918595965853633], 
             UndirectedEdge[13, 379] -> 
             RGBColor[
              0.9224320478849584, 0.9179676286569838, 0.6794277249534175], 
             UndirectedEdge[210, 434] -> 
             RGBColor[
              0.9315910537649785, 0.9240002822741774, 0.6784322633236988], 
             UndirectedEdge[308, 446] -> 
             RGBColor[
              0.9919701279141994, 0.9904180419870732, 0.7442564972484209], 
             UndirectedEdge[153, 395] -> 
             RGBColor[
              0.9728098422716618, 0.9782367486759038, 0.8858836175939652], 
             UndirectedEdge[24, 83] -> 
             RGBColor[
              0.9873617950873774, 0.9890417917286486, 0.8591112922354285], 
             UndirectedEdge[133, 260] -> 
             RGBColor[
              0.9351936517364585, 0.9480935278432161, 0.8713804317237814], 
             UndirectedEdge[83, 119] -> 
             RGBColor[
              0.9916756812891371, 0.9908256945348948, 0.7876190338926505], 
             UndirectedEdge[400, 464] -> 
             RGBColor[
              0.9500660233363438, 0.8285866317380708, 0.35527333505113434`], 
             UndirectedEdge[175, 320] -> 
             RGBColor[
              0.8720040403321134, 0.9007763681144487, 0.9876537178857152], 
             UndirectedEdge[39, 475] -> 
             RGBColor[
              0.9730855897611177, 0.9777532651615026, 0.8545559515288628], 
             UndirectedEdge[289, 291] -> 
             RGBColor[
              0.9881746674842451, 0.9893779353546212, 0.8456398929730007], 
             UndirectedEdge[263, 342] -> 
             RGBColor[
              0.9492163194237628, 0.9616461946936632, 0.9708477040971066], 
             UndirectedEdge[311, 319] -> 
             RGBColor[
              0.908163548021099, 0.924750011284273, 0.7353468074889017], 
             UndirectedEdge[141, 304] -> 
             RGBColor[
              0.9375310385970903, 0.9527333512008763, 0.9837637392254244], 
             UndirectedEdge[30, 43] -> 
             RGBColor[
              0.9219565336715364, 0.939394300701346, 0.9503686650105607], 
             UndirectedEdge[85, 95] -> 
             RGBColor[
              0.9736217841958275, 0.9787349935448657, 0.8797040945081409], 
             UndirectedEdge[305, 438] -> 
             RGBColor[
              0.9269400272989917, 0.9222375923251803, 0.6808513361078512], 
             UndirectedEdge[23, 212] -> 
             RGBColor[
              0.9761812000609715, 0.9803432163257406, 0.8619108435717587], 
             UndirectedEdge[80, 461] -> 
             RGBColor[
              0.8710467265106803, 0.9000130320588294, 0.9875624084388228], 
             UndirectedEdge[115, 439] -> 
             RGBColor[
              0.9785842888409854, 0.9804363405613108, 0.7378586961915885], 
             UndirectedEdge[136, 377] -> 
             RGBColor[
              0.9374686452925762, 0.9290245945210638, 0.6794896452031984], 
             UndirectedEdge[27, 488] -> 
             RGBColor[
              0.8580929658851073, 0.8875921388789467, 0.8723807334797906], 
             UndirectedEdge[70, 170] -> 
             RGBColor[
              0.8231061518953162, 0.862327195139432, 0.9653349388584069], 
             UndirectedEdge[268, 441] -> 
             RGBColor[
              0.9049040934929765, 0.7213257577055263, 0.5951571534101971], 
             UndirectedEdge[394, 445] -> 
             RGBColor[
              0.9541408515009289, 0.9653189026536324, 0.9625117558141327], 
             UndirectedEdge[234, 393] -> 
             RGBColor[
              0.6888637219939389, 0.7551988066430447, 0.9709350479991965], 
             UndirectedEdge[228, 388] -> 
             RGBColor[
              0.9774081160649387, 0.9575483496136721, 0.6417154673845928], 
             UndirectedEdge[8, 114] -> 
             RGBColor[
              0.6823796707802683, 0.7474215138632603, 0.9509006880489522], 
             UndirectedEdge[21, 164] -> 
             RGBColor[
              0.890251902264333, 0.9150487952129769, 0.9797584614222938], 
             UndirectedEdge[100, 454] -> 
             RGBColor[
              0.9579898080149449, 0.9681894481196978, 0.9559964764045371], 
             UndirectedEdge[6, 267] -> 
             RGBColor[
              0.7096421779467198, 0.7309001362324566, 0.6346199342249407], 
             UndirectedEdge[210, 495] -> 
             RGBColor[
              0.6785935124403661, 0.7467569775967706, 0.9702462533872194], 
             UndirectedEdge[112, 342] -> 
             RGBColor[
              0.7779177255442358, 0.8269596101040018, 0.9766128083499379], 
             UndirectedEdge[93, 206] -> 
             RGBColor[
              0.9597238586119266, 0.9694827002156794, 0.9530611810566758], 
             UndirectedEdge[485, 497] -> 
             RGBColor[
              0.5223071437484441, 0.6202667469732, 0.9565204459604011], 
             UndirectedEdge[36, 240] -> 
             RGBColor[
              0.798234152766051, 0.49777811003941713`, 0.5735341550445633], 
             UndirectedEdge[275, 285] -> 
             RGBColor[
              0.7055548165355974, 0.7625633461503587, 0.7616737234404737], 
             UndirectedEdge[36, 399] -> 
             RGBColor[
              0.8768005524743165, 0.8828267780390017, 0.6762638145002905], 
             UndirectedEdge[72, 279] -> 
             RGBColor[
              0.6946654501066898, 0.7552044557123585, 0.8805511040603304], 
             UndirectedEdge[278, 413] -> 
             RGBColor[
              0.7761981755559375, 0.8256704334680275, 0.9781741224689577], 
             UndirectedEdge[10, 120] -> 
             RGBColor[
              0.9897977446730586, 0.9900491194833767, 0.818741303565244], 
             UndirectedEdge[59, 153] -> 
             RGBColor[
              0.9880998654120349, 0.9893470027754366, 0.8468795568910825], 
             UndirectedEdge[377, 488] -> 
             RGBColor[
              0.9853071870804373, 0.9642983813214868, 0.5703132368603476], 
             UndirectedEdge[53, 306] -> 
             RGBColor[
              0.596943376143379, 0.6675836071382508, 0.9512564519956522], 
             UndirectedEdge[172, 448] -> 
             RGBColor[
              0.9613368078123541, 0.9671821212218639, 0.7431094901292264], 
             UndirectedEdge[138, 367] -> 
             RGBColor[
              0.8710038772436945, 0.8985123194137671, 0.9114882310681245], 
             UndirectedEdge[71, 431] -> 
             RGBColor[
              0.991836617861342, 0.9885199370990017, 0.6125100887795121], 
             UndirectedEdge[180, 392] -> 
             RGBColor[
              0.9929419708876446, 0.9907342106018238, 0.7219200826058243], 
             UndirectedEdge[33, 227] -> 
             RGBColor[
              0.8606415671302623, 0.8916939174683578, 0.9712917822929008], 
             UndirectedEdge[30, 384] -> 
             RGBColor[
              0.9249114831669356, 0.9408589483206596, 0.9122661094490581], 
             UndirectedEdge[441, 467] -> 
             RGBColor[
              0.9071145345749185, 0.7229743010451737, 0.5914154532338358], 
             UndirectedEdge[99, 122] -> 
             RGBColor[
              0.9259239181651797, 0.9418729954993728, 0.921340865724904], 
             UndirectedEdge[89, 225] -> 
             RGBColor[
              0.9942002101430069, 0.9900031608816238, 0.6101068500994136], 
             UndirectedEdge[146, 497] -> 
             RGBColor[
              0.6795403474670776, 0.7420671823140773, 0.8782395420635408], 
             UndirectedEdge[176, 197] -> 
             RGBColor[
              0.7469513251669391, 0.7295385215043226, 0.615514552215533], 
             UndirectedEdge[326, 474] -> 
             RGBColor[
              0.6743863443654106, 0.5070143994162812, 0.5761800486624319], 
             UndirectedEdge[173, 241] -> 
             RGBColor[
              0.9290988004929739, 0.9420053183721541, 0.7829096868292995], 
             UndirectedEdge[403, 405] -> 
             RGBColor[
              0.9884077270130414, 0.9886179503231161, 0.7890950233593104], 
             UndirectedEdge[79, 476] -> 
             RGBColor[
              0.9530472619195226, 0.9629444088622102, 0.8997842706046999], 
             UndirectedEdge[46, 257] -> 
             RGBColor[
              0.945562817617614, 0.8080465393246996, 0.3948975302800981], 
             UndirectedEdge[450, 491] -> 
             RGBColor[
              0.9931755285864903, 0.9895211075793275, 0.6228491436687235], 
             UndirectedEdge[200, 243] -> 
             RGBColor[
              0.8666149150223563, 0.8954644634949422, 0.9283194438062032], 
             UndirectedEdge[296, 424] -> 
             RGBColor[
              0.8454528190630447, 0.8760639077839856, 0.7555671770444904], 
             UndirectedEdge[269, 466] -> 
             RGBColor[
              0.9881223921421393, 0.9707375732709355, 0.48136797616327165`], 
             UndirectedEdge[74, 453] -> 
             RGBColor[
              0.9234853430170699, 0.7006087804600722, 0.3594866993450393], 
             UndirectedEdge[18, 469] -> 
             RGBColor[
              0.8617713135451893, 0.8895974860512827, 0.8201039051727518], 
             UndirectedEdge[279, 481] -> 
             RGBColor[
              0.9900913971558658, 0.9842547898379035, 0.6152898623899082], 
             UndirectedEdge[19, 468] -> 
             RGBColor[
              0.9162611268532597, 0.935002544314894, 0.9550123802697095], 
             UndirectedEdge[415, 464] -> 
             RGBColor[
              0.8341291586070884, 0.7416091176773169, 0.6105226455623263], 
             UndirectedEdge[234, 262] -> 
             RGBColor[
              0.9045034194501311, 0.8458022325627524, 0.6282343475835404], 
             UndirectedEdge[241, 417] -> 
             RGBColor[
              0.9372419637806353, 0.9484984557374562, 0.7836863890131642], 
             UndirectedEdge[309, 489] -> 
             RGBColor[
              0.6257249440981962, 0.707030724063237, 0.9636785061868555], 
             UndirectedEdge[83, 426] -> 
             RGBColor[
              0.9869600358332081, 0.9888754449125559, 0.8657601215694546], 
             UndirectedEdge[6, 99] -> 
             RGBColor[
              0.9147111099821522, 0.8943427853465747, 0.6529930247570372], 
             UndirectedEdge[121, 491] -> 
             RGBColor[
              0.9712320692019808, 0.9765522950840255, 0.8658161582215291], 
             UndirectedEdge[42, 358] -> 
             RGBColor[
              0.9681467042937736, 0.9751006704206544, 0.9090783304227232], 
             UndirectedEdge[69, 461] -> 
             RGBColor[
              0.9405018036796494, 0.9545841503325048, 0.9660874203024037], 
             UndirectedEdge[161, 387] -> 
             RGBColor[
              0.9320844421755281, 0.9481653123720064, 0.9754408960155752], 
             UndirectedEdge[117, 390] -> 
             RGBColor[
              0.850300648788321, 0.8792756599696018, 0.7099630134011186], 
             UndirectedEdge[244, 334] -> 
             RGBColor[
              0.991459201461929, 0.9907361745630665, 0.7912066648613211], 
             UndirectedEdge[173, 493] -> 
             RGBColor[
              0.9251205898555813, 0.929456405221756, 0.6934318883999802], 
             UndirectedEdge[229, 255] -> 
             RGBColor[
              0.9359426388818366, 0.9493746743487081, 0.9011502332833046], 
             UndirectedEdge[39, 401] -> 
             RGBColor[
              0.9720498888011864, 0.9773249761982704, 0.8717201967430894], 
             UndirectedEdge[379, 380] -> 
             RGBColor[
              0.787725975463913, 0.8344700323471552, 0.9793777734949036], 
             UndirectedEdge[92, 140] -> 
             RGBColor[
              0.9803128314307773, 0.9435862671468132, 0.5197208356320168], 
             UndirectedEdge[78, 97] -> 
             RGBColor[
              0.8395838010425003, 0.8749272573285845, 0.9531883039662077], 
             UndirectedEdge[395, 463] -> 
             RGBColor[
              0.8975965793225278, 0.6366499775860545, 0.573092032066334], 
             UndirectedEdge[174, 338] -> 
             RGBColor[
              0.9944647325920142, 0.9905689476527284, 0.6388984862305445], 
             UndirectedEdge[143, 423] -> 
             RGBColor[
              0.9808217093923502, 0.9462676187223484, 0.43965923167306553`], 
             UndirectedEdge[94, 100] -> 
             RGBColor[
              0.9804539161640246, 0.9821474735803218, 0.7598280925413896], 
             UndirectedEdge[404, 408] -> 
             RGBColor[
              0.6941803606961281, 0.46877156407911685`, 0.5707947620347101], 
             UndirectedEdge[301, 389] -> 
             RGBColor[
              0.9357502471136308, 0.9271441202093598, 0.6785750684899836], 
             UndirectedEdge[16, 422] -> 
             RGBColor[
              0.7636173785142766, 0.8121163983154339, 0.8632600672738973], 
             UndirectedEdge[389, 451] -> 
             RGBColor[
              0.984812624719472, 0.9635075578981485, 0.5744568678840767], 
             UndirectedEdge[74, 296] -> 
             RGBColor[
              0.9235802111606319, 0.7008116938265108, 0.3698125113134481], 
             UndirectedEdge[225, 453] -> 
             RGBColor[
              0.9938541393197141, 0.9892629503837282, 0.572439176685557], 
             UndirectedEdge[340, 378] -> 
             RGBColor[
              0.891256458937926, 0.9158716868652936, 0.9806130584883177], 
             UndirectedEdge[52, 428] -> 
             RGBColor[
              0.8928567568830523, 0.9158947183995441, 0.9277576504561769], 
             UndirectedEdge[84, 230] -> 
             RGBColor[
              0.6380586654180744, 0.7146396052982854, 0.9662932193051448], 
             UndirectedEdge[119, 237] -> 
             RGBColor[
              0.8502738926546878, 0.8813027993686746, 0.8633931825074199], 
             UndirectedEdge[67, 171] -> 
             RGBColor[
              0.9553365415216284, 0.9254349032017524, 0.6458495859255967], 
             UndirectedEdge[25, 157] -> 
             RGBColor[
              0.793865435345902, 0.8388929787837751, 0.9800887455671434], 
             UndirectedEdge[124, 484] -> 
             RGBColor[
              0.9838608243318274, 0.9861370186144383, 0.8518825798507963], 
             UndirectedEdge[368, 500] -> 
             RGBColor[
              0.8741482344136977, 0.90227532810543, 0.974151508495873], 
             UndirectedEdge[283, 422] -> 
             RGBColor[
              0.9820344411707208, 0.9847021926616074, 0.8517179611326611], 
             UndirectedEdge[334, 369] -> 
             RGBColor[
              0.9911017148641827, 0.9895611890585403, 0.7224677733361736], 
             UndirectedEdge[42, 346] -> 
             RGBColor[
              0.9703060818070097, 0.9735989090303407, 0.6992210300861779], 
             UndirectedEdge[112, 263] -> 
             RGBColor[
              0.7893226987189939, 0.8354654204238068, 0.9573071636584733], 
             UndirectedEdge[146, 201] -> 
             RGBColor[
              0.8753906579343372, 0.9015497638637737, 0.8942619776425336], 
             UndirectedEdge[16, 243] -> 
             RGBColor[
              0.6408491495733069, 0.7177031903752261, 0.9659672008023448], 
             UndirectedEdge[285, 481] -> 
             RGBColor[
              0.9920040684788828, 0.9838385181569962, 0.49584049469568403`], 
             UndirectedEdge[231, 444] -> 
             RGBColor[
              0.9659733926665077, 0.9738243761710721, 0.9281871914899675], 
             UndirectedEdge[137, 408] -> 
             RGBColor[
              0.7017489085702863, 0.7657909828363931, 0.9717981766466541], 
             UndirectedEdge[431, 436] -> 
             RGBColor[
              0.9147085886223612, 0.9296043456631933, 0.7064232575099139], 
             UndirectedEdge[98, 277] -> 
             RGBColor[
              0.9647268297939997, 0.8873900605443865, 0.5109248155148884], 
             UndirectedEdge[131, 391] -> 
             RGBColor[
              0.8229601678458667, 0.8583746190689368, 0.7438854433912521], 
             UndirectedEdge[52, 227] -> 
             RGBColor[
              0.9695371660959433, 0.9764329538865915, 0.9199478529952754], 
             UndirectedEdge[27, 419] -> 
             RGBColor[
              0.6903566586144891, 0.7580311357053553, 0.9697719580470705], 
             UndirectedEdge[232, 312] -> 
             RGBColor[
              0.8912100068000448, 0.9154167964199388, 0.9661214792858304], 
             UndirectedEdge[247, 466] -> 
             RGBColor[
              0.9886119880687374, 0.9717847694521875, 0.534657471337661], 
             UndirectedEdge[253, 484] -> 
             RGBColor[
              0.8867269084532972, 0.9116690697583762, 0.9534962538580438], 
             UndirectedEdge[121, 200] -> 
             RGBColor[
              0.9675963863983839, 0.975048846811952, 0.9260688311226182], 
             UndirectedEdge[79, 99] -> 
             RGBColor[
              0.9273724236271446, 0.9424719897327876, 0.8973353816081742], 
             UndirectedEdge[109, 300] -> 
             RGBColor[
              0.9029478991499568, 0.8663563738977331, 0.6329663508734062], 
             UndirectedEdge[31, 397] -> 
             RGBColor[
              0.9938125710982324, 0.9894288130237382, 0.586434029896189], 
             UndirectedEdge[70, 374] -> 
             RGBColor[
              0.9508815237808248, 0.8960801402138361, 0.6183694289550086], 
             UndirectedEdge[240, 352] -> 
             RGBColor[0.90768626076889, 0.579856592097588, 0.331007084599814],
              UndirectedEdge[105, 323] -> 
             RGBColor[
              0.9800422660804562, 0.9809031107108208, 0.6861498057851452], 
             UndirectedEdge[46, 53] -> 
             RGBColor[
              0.9249246944991538, 0.795611880906959, 0.6007933307882449], 
             UndirectedEdge[221, 223] -> 
             RGBColor[
              0.9233921179724812, 0.7153312018194742, 0.29565838273479866`], 
             UndirectedEdge[33, 159] -> 
             RGBColor[
              0.8583722698694793, 0.8900014792868991, 0.9751331106278899], 
             UndirectedEdge[16, 454] -> 
             RGBColor[
              0.7417413222271834, 0.797220974851469, 0.9638677475625246], 
             UndirectedEdge[195, 224] -> 
             RGBColor[
              0.9506735211278463, 0.8306762008476586, 0.3746363277161573], 
             UndirectedEdge[259, 500] -> 
             RGBColor[
              0.948301670204049, 0.9609640508032011, 0.97239596664736], 
             UndirectedEdge[24, 77] -> 
             RGBColor[
              0.9885174380451167, 0.9895196797903432, 0.8399592977175825], 
             UndirectedEdge[226, 386] -> 
             RGBColor[
              0.9131636908063694, 0.9333906201321187, 0.9844604333238214], 
             UndirectedEdge[289, 314] -> 
             RGBColor[
              0.9385028484063991, 0.9516115175942619, 0.9098794433151429], 
             UndirectedEdge[179, 325] -> 
             RGBColor[
              0.9675160691705722, 0.9736732499700456, 0.8672852149975889], 
             UndirectedEdge[81, 83] -> 
             RGBColor[
              0.7919277502664755, 0.8356991222343573, 0.8905330241259264], 
             UndirectedEdge[312, 376] -> 
             RGBColor[
              0.9478178209498068, 0.9605543308447777, 0.9715207831338268], 
             UndirectedEdge[270, 309] -> 
             RGBColor[
              0.8063684035463894, 0.8482556151786151, 0.9264891718635517], 
             UndirectedEdge[139, 269] -> 
             RGBColor[
              0.9871141892799838, 0.987101243826461, 0.7474867447301167], 
             UndirectedEdge[269, 425] -> 
             RGBColor[
              0.9324938484941931, 0.9446994849110517, 0.7821835313305489], 
             UndirectedEdge[25, 492] -> 
             RGBColor[
              0.8558143570205227, 0.8880825489273892, 0.9788938637133996], 
             UndirectedEdge[142, 173] -> 
             RGBColor[
              0.9284888819107684, 0.9407007641970444, 0.716523813137399], 
             UndirectedEdge[132, 209] -> 
             RGBColor[
              0.9918980372437234, 0.9909176444364036, 0.7839340202863898], 
             UndirectedEdge[389, 409] -> 
             RGBColor[
              0.8642517950499709, 0.8706913913862422, 0.6716073542284091], 
             UndirectedEdge[337, 370] -> 
             RGBColor[
              0.9383467313001346, 0.9528225524003715, 0.9643840370101152], 
             UndirectedEdge[230, 242] -> 
             RGBColor[
              0.8745531982100293, 0.9026124492933816, 0.975242759168409], 
             UndirectedEdge[28, 461] -> 
             RGBColor[
              0.9428372732355967, 0.9253488587443923, 0.6682966062645819], 
             UndirectedEdge[318, 350] -> 
             RGBColor[
              0.9681616328939269, 0.9579194103758673, 0.6727939716861482], 
             UndirectedEdge[390, 478] -> 
             RGBColor[
              0.9877096384483539, 0.9867236706301217, 0.6812837399270247], 
             UndirectedEdge[167, 434] -> 
             RGBColor[
              0.986391941942828, 0.964175267130803, 0.5363020332717849], 
             UndirectedEdge[247, 269] -> 
             RGBColor[
              0.9943838019837287, 0.9903958452649454, 0.6300896889644825], 
             UndirectedEdge[394, 398] -> 
             RGBColor[
              0.7884769281388678, 0.835288819887894, 0.9709203969311241], 
             UndirectedEdge[14, 158] -> 
             RGBColor[
              0.9185250545889756, 0.9360703511317332, 0.9248476043398755], 
             UndirectedEdge[131, 433] -> 
             RGBColor[
              0.9808972862805753, 0.9466776335938086, 0.4267662660287934], 
             UndirectedEdge[87, 422] -> 
             RGBColor[
              0.9933836910913676, 0.9904518906678733, 0.680800310016273], 
             UndirectedEdge[210, 469] -> 
             RGBColor[
              0.9400932774557039, 0.9513124766496144, 0.8277698527004635], 
             UndirectedEdge[312, 414] -> 
             RGBColor[
              0.9771920337593218, 0.9787667220750575, 0.6901262968936467], 
             UndirectedEdge[277, 311] -> 
             RGBColor[
              0.9933700667915503, 0.9896228553137436, 0.6211735136062724], 
             UndirectedEdge[332, 424] -> 
             RGBColor[
              0.8446903121327303, 0.8741455121288003, 0.697017413896121], 
             UndirectedEdge[328, 433] -> 
             RGBColor[
              0.9595393575390989, 0.9339102199284137, 0.6500729569371543], 
             UndirectedEdge[88, 428] -> 
             RGBColor[0.89592797243719, 0.91481000634998, 0.705695021767559], 
             UndirectedEdge[8, 162] -> 
             RGBColor[
              0.7004825935723624, 0.758852940841688, 0.819716983460669], 
             UndirectedEdge[27, 289] -> 
             RGBColor[
              0.856315766680227, 0.8868572213357924, 0.9018335235487676], 
             UndirectedEdge[192, 280] -> 
             RGBColor[
              0.9862801365443243, 0.9885944981237396, 0.8770371735363957], 
             UndirectedEdge[347, 477] -> 
             RGBColor[
              0.9129006282935388, 0.9325907103689496, 0.9639744415365491], 
             UndirectedEdge[145, 346] -> 
             RGBColor[
              0.9707386982689981, 0.9739215536793472, 0.6984887232604755], 
             UndirectedEdge[232, 415] -> 
             RGBColor[
              0.7907969004714044, 0.8365007011976442, 0.9797816063114937], 
             UndirectedEdge[189, 374] -> 
             RGBColor[
              0.9694735386583258, 0.9085955773173091, 0.5264217669947728], 
             UndirectedEdge[139, 140] -> 
             RGBColor[
              0.9877686497515501, 0.9885010685990376, 0.8187207281982556], 
             UndirectedEdge[134, 251] -> 
             RGBColor[
              0.6848457488561974, 0.7490040711113269, 0.942980753462863], 
             UndirectedEdge[67, 281] -> 
             RGBColor[
              0.978881356922964, 0.9398566954409566, 0.42069792157113134`], 
             UndirectedEdge[167, 495] -> 
             RGBColor[
              0.7333944006182156, 0.7869319624533961, 0.8281160233353055], 
             UndirectedEdge[143, 179] -> 
             RGBColor[
              0.9545437125678589, 0.9296558036027758, 0.65740700916747], 
             UndirectedEdge[21, 175] -> 
             RGBColor[
              0.8486184174700324, 0.8821293072300476, 0.9854231763005379], 
             UndirectedEdge[366, 473] -> 
             RGBColor[
              0.9880059640038621, 0.989308172130001, 0.848435746233561], 
             UndirectedEdge[143, 292] -> 
             RGBColor[
              0.9777280819833503, 0.9464049602473098, 0.5939031234996706], 
             UndirectedEdge[267, 486] -> 
             RGBColor[
              0.7221969858080854, 0.7789852977400661, 0.8807273675389038], 
             UndirectedEdge[248, 380] -> 
             RGBColor[
              0.7727079238186075, 0.8224950456193407, 0.9779453383222014], 
             UndirectedEdge[48, 407] -> 
             RGBColor[
              0.8735231191596085, 0.8985339949868714, 0.8017247750328298], 
             UndirectedEdge[436, 459] -> 
             RGBColor[
              0.8366721768408477, 0.8726036992243991, 0.9842837332047913], 
             UndirectedEdge[235, 262] -> 
             RGBColor[
              0.865699005148863, 0.8150748301979324, 0.6244763099836965], 
             UndirectedEdge[236, 283] -> 
             RGBColor[
              0.9825059250733381, 0.9835154675800046, 0.7434695545548671], 
             UndirectedEdge[99, 493] -> 
             RGBColor[
              0.9251205898555813, 0.929456405221756, 0.6934318883999802], 
             UndirectedEdge[109, 456] -> 
             RGBColor[
              0.8857113160943386, 0.8526143053705582, 0.6313218020315902], 
             UndirectedEdge[208, 289] -> 
             RGBColor[
              0.9892975918807863, 0.9898422934504316, 0.827030129687131], 
             UndirectedEdge[266, 410] -> 
             RGBColor[
              0.7827080381716511, 0.8300996195146226, 0.9569011888680183], 
             UndirectedEdge[299, 301] -> 
             RGBColor[
              0.9314331183860549, 0.9473061391261545, 0.9635968144507637], 
             UndirectedEdge[314, 359] -> 
             RGBColor[
              0.5828409097915465, 0.6613711472768433, 0.9641506987828772], 
             UndirectedEdge[209, 214] -> 
             RGBColor[
              0.9919289018035221, 0.9909304077250634, 0.7834225146556062], 
             UndirectedEdge[210, 326] -> 
             RGBColor[
              0.8695327482146703, 0.6622482093579174, 0.593948428254798], 
             UndirectedEdge[53, 317] -> 
             RGBColor[
              0.9708814978417337, 0.976945846324264, 0.8957421262566188], 
             UndirectedEdge[402, 459] -> 
             RGBColor[
              0.8900915627020278, 0.9149919285120445, 0.9822042180076822], 
             UndirectedEdge[89, 249] -> 
             RGBColor[
              0.82684528196623, 0.8618686140702745, 0.7810293755539552], 
             UndirectedEdge[67, 135] -> 
             RGBColor[
              0.9751261313300965, 0.9399082332694777, 0.5995561331755821], 
             UndirectedEdge[90, 178] -> 
             RGBColor[
              0.6962864765086019, 0.7586154184381513, 0.939360085485352], 
             UndirectedEdge[174, 229] -> 
             RGBColor[
              0.9923938833041219, 0.9906091028567353, 0.7383842387677981], 
             UndirectedEdge[266, 364] -> 
             RGBColor[
              0.7994311567060022, 0.8397930572129475, 0.7718022900886157], 
             UndirectedEdge[407, 430] -> 
             RGBColor[
              0.8734811617381917, 0.8984442523050067, 0.7971579686427979], 
             UndirectedEdge[217, 355] -> 
             RGBColor[
              0.9248496205549558, 0.9383000856585617, 0.7568031358325509], 
             UndirectedEdge[176, 426] -> 
             RGBColor[
              0.9637649654770497, 0.9003979292020445, 0.5924563576921913], 
             UndirectedEdge[280, 483] -> 
             RGBColor[
              0.986257104393187, 0.988584973737345, 0.8774188758860375], 
             UndirectedEdge[51, 347] -> 
             RGBColor[
              0.8991935558429393, 0.9223679981785636, 0.9871769398183612], 
             UndirectedEdge[152, 451] -> 
             RGBColor[
              0.9936128788197895, 0.9915399131375197, 0.7492006808965138], 
             UndirectedEdge[105, 342] -> 
             RGBColor[
              0.9526640362528841, 0.9642174962597037, 0.965011618813968], 
             UndirectedEdge[318, 496] -> 
             RGBColor[
              0.8468714498408574, 0.8625648255539488, 0.6778352800851322], 
             UndirectedEdge[114, 289] -> 
             RGBColor[
              0.973916440131127, 0.9792549350691566, 0.8926483333722128], 
             UndirectedEdge[103, 331] -> 
             RGBColor[
              0.9409079274644246, 0.9507900130131569, 0.7328379148407069], 
             UndirectedEdge[107, 113] -> 
             RGBColor[
              0.9420520068907967, 0.9537259139115972, 0.8791438681807033], 
             UndirectedEdge[16, 56] -> 
             RGBColor[
              0.7639732107175032, 0.810682305943015, 0.742423686936994], 
             UndirectedEdge[140, 370] -> 
             RGBColor[
              0.9820033671049132, 0.9842013302409596, 0.8284798478924763], 
             UndirectedEdge[213, 500] -> 
             RGBColor[
              0.8230762193004129, 0.8623774817372407, 0.9690611273244973], 
             UndirectedEdge[280, 327] -> 
             RGBColor[
              0.9892081272419952, 0.989805297523155, 0.8285127902789631], 
             UndirectedEdge[76, 238] -> 
             RGBColor[
              0.953469264920265, 0.9614261128586032, 0.7842976942325962], 
             UndirectedEdge[253, 261] -> 
             RGBColor[
              0.8956714115835732, 0.9151244499004134, 0.7469079825111136], 
             UndirectedEdge[232, 350] -> 
             RGBColor[
              0.887562410876475, 0.9126964253525305, 0.9722959077390535], 
             UndirectedEdge[166, 320] -> 
             RGBColor[
              0.936559566980814, 0.949440620230454, 0.8827117348272503], 
             UndirectedEdge[33, 119] -> 
             RGBColor[
              0.8811204312091795, 0.9054003497298196, 0.8664676771932396], 
             UndirectedEdge[71, 228] -> 
             RGBColor[
              0.9836981548594788, 0.9610849449839867, 0.5793669679110929], 
             UndirectedEdge[50, 244] -> 
             RGBColor[
              0.8452025327994535, 0.877123292944716, 0.8530152967276027], 
             UndirectedEdge[235, 344] -> 
             RGBColor[
              0.8531359045295882, 0.8859456130686627, 0.9857972203264075], 
             UndirectedEdge[72, 494] -> 
             RGBColor[
              0.5940775268143093, 0.6776259559147699, 0.9631271636557359], 
             UndirectedEdge[185, 496] -> 
             RGBColor[
              0.7391388475930729, 0.796140152493793, 0.9746341107489811], 
             UndirectedEdge[106, 370] -> 
             RGBColor[
              0.9818686683172162, 0.9839132231542123, 0.8138187161162196], 
             UndirectedEdge[51, 113] -> 
             RGBColor[
              0.9659722536716342, 0.9727107178323551, 0.8783552643433724], 
             UndirectedEdge[422, 443] -> 
             RGBColor[
              0.9878275507727527, 0.9726521214659702, 0.579081137975797], 
             UndirectedEdge[4, 335] -> 
             RGBColor[
              0.54449988400896, 0.6256579780449971, 0.961272535150526], 
             UndirectedEdge[1, 84] -> 
             RGBColor[
              0.735787733446424, 0.7886709748127054, 0.8115843802993775], 
             UndirectedEdge[90, 272] -> 
             RGBColor[
              0.6937324106574092, 0.7567106003082309, 0.9436834527643613], 
             UndirectedEdge[213, 450] -> 
             RGBColor[
              0.8441138734608105, 0.87467074617952, 0.7276274047442743], 
             UndirectedEdge[5, 212] -> 
             RGBColor[
              0.9166009567124678, 0.9334535202666692, 0.877653529063289], 
             UndirectedEdge[50, 106] -> 
             RGBColor[
              0.8452662346492656, 0.8768491869408331, 0.830120168445404], 
             UndirectedEdge[115, 291] -> 
             RGBColor[
              0.9754880924676781, 0.9807288776849485, 0.9035034644779087], 
             UndirectedEdge[9, 117] -> 
             RGBColor[
              0.7018442469019348, 0.7670053269844126, 0.970916933489947], 
             UndirectedEdge[194, 388] -> 
             RGBColor[
              0.9860225191023408, 0.9860013293397859, 0.7266617239600016], 
             UndirectedEdge[202, 211] -> 
             RGBColor[
              0.9715508032259026, 0.9517579817025928, 0.6486117469254753], 
             UndirectedEdge[113, 308] -> 
             RGBColor[
              0.991041757430545, 0.9905635507282669, 0.7981247927718798], 
             UndirectedEdge[51, 421] -> 
             RGBColor[
              0.8640774063688605, 0.894617589046721, 0.9837611200825882], 
             UndirectedEdge[109, 335] -> 
             RGBColor[
              0.5944521800068164, 0.6063947956653419, 0.608398209845479], 
             UndirectedEdge[278, 329] -> 
             RGBColor[
              0.8076412163490104, 0.8502564955845442, 0.9643314063510307], 
             UndirectedEdge[129, 206] -> 
             RGBColor[
              0.9635197565516438, 0.9723136746839081, 0.9466357159734757], 
             UndirectedEdge[166, 227] -> 
             RGBColor[
              0.9724924563578289, 0.9776550423573764, 0.870971045309799], 
             UndirectedEdge[294, 411] -> 
             RGBColor[
              0.9413829897712744, 0.9528731309562326, 0.8652137817883121], 
             UndirectedEdge[362, 384] -> 
             RGBColor[
              0.9916050067227253, 0.9901813415612178, 0.7440770387708854], 
             UndirectedEdge[143, 308] -> 
             RGBColor[
              0.9786377380827813, 0.9467811264215199, 0.5788277678175769], 
             UndirectedEdge[151, 310] -> 
             RGBColor[
              0.873806210281028, 0.9006246814057325, 0.9082832045421201], 
             UndirectedEdge[297, 397] -> 
             RGBColor[
              0.8924628935248393, 0.9140102903414796, 0.8562223524046628], 
             UndirectedEdge[114, 359] -> 
             RGBColor[
              0.6182545015162745, 0.6890145647517381, 0.9469195888399471], 
             UndirectedEdge[141, 220] -> 
             RGBColor[
              0.9691826049389795, 0.9753520192876715, 0.8839833390115255], 
             UndirectedEdge[122, 493] -> 
             RGBColor[
              0.9867604233116098, 0.9767087156678171, 0.6278553724981729], 
             UndirectedEdge[146, 442] -> 
             RGBColor[
              0.9922345016963187, 0.9901662090177499, 0.7136227420492518], 
             UndirectedEdge[294, 478] -> 
             RGBColor[
              0.9354976297404187, 0.9501922857199847, 0.9516838922001661], 
             UndirectedEdge[76, 487] -> 
             RGBColor[
              0.9500492924374367, 0.9612072966736502, 0.9278706539728193], 
             UndirectedEdge[67, 70] -> 
             RGBColor[
              0.9597385435918526, 0.9287179091381087, 0.6383981446467228], 
             UndirectedEdge[346, 358] -> 
             RGBColor[
              0.9903467366605478, 0.9878814222931462, 0.6355722589344712], 
             UndirectedEdge[149, 165] -> 
             RGBColor[
              0.9916384247457752, 0.9888803347572155, 0.6479492443398687], 
             UndirectedEdge[175, 375] -> 
             RGBColor[
              0.9117193347291022, 0.9318117017121481, 0.9695104032786721], 
             UndirectedEdge[18, 428] -> 
             RGBColor[
              0.7640634283057002, 0.815611424380327, 0.9771183600209661], 
             UndirectedEdge[2, 47] -> 
             RGBColor[
              0.9022814656226773, 0.9238669524150579, 0.9540745968177435], 
             UndirectedEdge[140, 466] -> 
             RGBColor[
              0.9887768526137055, 0.972137398043512, 0.5526019596314107], 
             UndirectedEdge[199, 382] -> 
             RGBColor[
              0.7830809166803596, 0.8304680308368757, 0.979013845533619], 
             UndirectedEdge[305, 499] -> 
             RGBColor[
              0.9332046619857781, 0.9468740710887473, 0.887105835941761], 
             UndirectedEdge[252, 282] -> 
             RGBColor[
              0.8219127600183682, 0.8615498819554761, 0.9730607320072864], 
             UndirectedEdge[235, 249] -> 
             RGBColor[
              0.726555298331679, 0.7863097881722755, 0.973379900158559], 
             UndirectedEdge[130, 214] -> 
             RGBColor[
              0.9915843586606783, 0.9907879302811425, 0.7891324861815985], 
             UndirectedEdge[100, 475] -> 
             RGBColor[
              0.9806931630874989, 0.9834269808920597, 0.8416783142601987], 
             UndirectedEdge[10, 438] -> 
             RGBColor[
              0.9834090491858949, 0.9653613383906363, 0.6145428122526476], 
             UndirectedEdge[39, 179] -> 
             RGBColor[
              0.9464315272642421, 0.9595693012607713, 0.9755616308330567], 
             UndirectedEdge[400, 414] -> 
             RGBColor[
              0.9927157921599368, 0.9868281409135169, 0.44853711340811814`], 
             UndirectedEdge[41, 191] -> 
             RGBColor[
              0.7076311595303509, 0.7708547720856098, 0.9719527142829428], 
             UndirectedEdge[25, 96] -> 
             RGBColor[
              0.7222450571878936, 0.7829425950317044, 0.9729502956028401], 
             UndirectedEdge[106, 274] -> 
             RGBColor[
              0.9793604749310676, 0.9820426166336125, 0.8180644332773644], 
             UndirectedEdge[204, 363] -> 
             RGBColor[
              0.8968284762057552, 0.9188400273975526, 0.9210150457193061], 
             UndirectedEdge[99, 413] -> 
             RGBColor[
              0.8779672100030611, 0.9055312377441338, 0.9882224903323146], 
             UndirectedEdge[37, 118] -> 
             RGBColor[
              0.9823788493121542, 0.9850350121648531, 0.854536633264683], 
             UndirectedEdge[411, 478] -> 
             RGBColor[
              0.9885900416713332, 0.9893026056389764, 0.8276905316160628], 
             UndirectedEdge[300, 451] -> 
             RGBColor[
              0.9231323465547956, 0.9387871212041681, 0.8837325673955587], 
             UndirectedEdge[122, 233] -> 
             RGBColor[
              0.8766872206015031, 0.9030508520571628, 0.9165284302594897], 
             UndirectedEdge[97, 404] -> 
             RGBColor[
              0.9041598994220537, 0.634534110005168, 0.5593049188742334], 
             UndirectedEdge[362, 498] -> 
             RGBColor[
              0.9513516172581375, 0.9601887600273036, 0.8206716021144023], 
             UndirectedEdge[121, 454] -> 
             RGBColor[
              0.9490745987007886, 0.9615404996105154, 0.9710876003144178], 
             UndirectedEdge[173, 417] -> 
             RGBColor[
              0.8724272479968125, 0.9011138224186137, 0.9876940838105761], 
             UndirectedEdge[36, 352] -> 
             RGBColor[
              0.8836728896794241, 0.9056249080905778, 0.7356036796343627], 
             UndirectedEdge[309, 337] -> 
             RGBColor[
              0.7675397524127249, 0.81880529039367, 0.977435176058995], 
             UndirectedEdge[207, 456] -> 
             RGBColor[
              0.9067321359770346, 0.9240409742689488, 0.7701007805353481], 
             UndirectedEdge[95, 97] -> 
             RGBColor[
              0.9807061960547828, 0.9840185363096149, 0.867712033141465], 
             UndirectedEdge[185, 350] -> 
             RGBColor[
              0.8604290306461424, 0.8914947373157116, 0.9695928023499971], 
             UndirectedEdge[303, 435] -> 
             RGBColor[
              0.8663380841865843, 0.8963198380318129, 0.9807564063513647], 
             UndirectedEdge[14, 441] -> 
             RGBColor[
              0.8580775372016864, 0.6841924363061149, 0.59779492813679], 
             UndirectedEdge[67, 147] -> 
             RGBColor[
              0.7836693330623693, 0.7899771994392677, 0.638929704880616], 
             UndirectedEdge[115, 419] -> 
             RGBColor[
              0.8104372952845286, 0.8522784019469867, 0.9563888370185107], 
             UndirectedEdge[113, 209] -> 
             RGBColor[
              0.9937384748178506, 0.9916787126703934, 0.7534332067833392], 
             UndirectedEdge[100, 121] -> 
             RGBColor[
              0.958079106737096, 0.9682560469604647, 0.9558453169607724], 
             UndirectedEdge[39, 254] -> 
             RGBColor[
              0.9734758838932973, 0.9778202825114441, 0.8412273886409445], 
             UndirectedEdge[2, 339] -> 
             RGBColor[
              0.8806553392126188, 0.9076746790085115, 0.9884788864960434], 
             UndirectedEdge[76, 436] -> 
             RGBColor[
              0.8749636607857241, 0.9031362891274008, 0.9879360091266649], 
             UndirectedEdge[121, 161] -> 
             RGBColor[
              0.9524662023752098, 0.9640699520776574, 0.9653464999655315], 
             UndirectedEdge[215, 430] -> 
             RGBColor[
              0.9939345835225641, 0.9894350123994681, 0.581195031721718], 
             UndirectedEdge[100, 254] -> 
             RGBColor[
              0.9810834572196785, 0.9834939982420012, 0.8283497513722804], 
             UndirectedEdge[186, 389] -> 
             RGBColor[
              0.9850596310486159, 0.9612428848920649, 0.3983207617245015], 
             UndirectedEdge[197, 426] -> 
             RGBColor[
              0.7673771014476408, 0.8168706539072692, 0.9347033243992662], 
             UndirectedEdge[316, 378] -> 
             RGBColor[
              0.8885546317580981, 0.913856668578414, 0.98518654715438], 
             UndirectedEdge[185, 330] -> 
             RGBColor[
              0.8794800557706723, 0.9020191552306659, 0.7087320996145642], 
             UndirectedEdge[56, 166] -> 
             RGBColor[
              0.99288484258158, 0.9897444756704241, 0.6526407822025402], 
             UndirectedEdge[38, 73] -> 
             RGBColor[
              0.8687839999769752, 0.8133930751366811, 0.6238777006619709], 
             UndirectedEdge[97, 430] -> 
             RGBColor[
              0.982399156334308, 0.9838505612810894, 0.776556675416455], 
             UndirectedEdge[222, 372] -> 
             RGBColor[
              0.9665511748846629, 0.8918210547744503, 0.49420747589141756`], 
             UndirectedEdge[137, 430] -> 
             RGBColor[
              0.9236050650411385, 0.9378677519818841, 0.802083176300978], 
             UndirectedEdge[30, 355] -> 
             RGBColor[
              0.8587201572998495, 0.8901841603659206, 0.9863866892634354], 
             UndirectedEdge[111, 442] -> 
             RGBColor[
              0.9808440972117225, 0.982672622075598, 0.7777465861242214], 
             UndirectedEdge[183, 408] -> 
             RGBColor[
              0.7466640360093887, 0.8014228836179527, 0.9697651413535558], 
             UndirectedEdge[39, 283] -> 
             RGBColor[
              0.9615553195935538, 0.9708486008170348, 0.949960995336307], 
             UndirectedEdge[244, 498] -> 
             RGBColor[
              0.9514702984840472, 0.9608529649883977, 0.863418002651037], 
             UndirectedEdge[259, 454] -> 
             RGBColor[
              0.947306566257786, 0.9602219039094115, 0.9740804180637075], 
             UndirectedEdge[17, 418] -> 
             RGBColor[
              0.9575392684899664, 0.9644660566097201, 0.7680382111464388], 
             UndirectedEdge[70, 391] -> 
             RGBColor[
              0.8038341530753889, 0.8472717631886888, 0.9634140861231051], 
             UndirectedEdge[18, 495] -> 
             RGBColor[
              0.6002715485298515, 0.6850419869984388, 0.9625803058595076], 
             UndirectedEdge[48, 95] -> 
             RGBColor[
              0.9926247712211262, 0.9904225022109193, 0.7140536823462975], 
             UndirectedEdge[50, 92] -> 
             RGBColor[
              0.8305106378674768, 0.8285752625455473, 0.6452339751273063], 
             UndirectedEdge[118, 141] -> 
             RGBColor[
              0.9597590133461532, 0.969508918558905, 0.9530016732614535], 
             UndirectedEdge[373, 398] -> 
             RGBColor[
              0.6225514712686651, 0.7044543558569017, 0.9634286787809008], 
             UndirectedEdge[218, 409] -> 
             RGBColor[
              0.8557072594610567, 0.8877006171875943, 0.9637849973211426]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.9489712823642122, 0.9614634464558618, 0.9712624879230253], 
             316 -> RGBColor[
              0.9402241781772785, 0.9549398704753151, 0.9860690537013571], 
             308 -> RGBColor[
              0.9892719361598389, 0.9898316841504978, 0.8274553113781075], 
             160 -> RGBColor[
              0.7144614574734061, 0.7768619877771978, 0.9721744991251748], 
             245 -> RGBColor[
              0.9238874517690411, 0.942146792056569, 0.9926024039854375], 155 -> 
             RGBColor[
              0.9945689632734257, 0.9907918865409293, 0.6502433526649855], 
             425 -> RGBColor[
              0.8710934909312559, 0.9000503207384101, 0.9875668688710044], 
             213 -> RGBColor[
              0.6951769307296625, 0.7617967689171536, 0.970252397723507], 352 -> 
             RGBColor[
              0.9931249976822633, 0.9877033901487487, 0.4930766091896134], 27 -> 
             RGBColor[
              0.7235485549936205, 0.7839608974244885, 0.9730802160822354], 
             485 -> RGBColor[
              0.6757529200043868, 0.7466225841106191, 0.9683163938621121], 
             454 -> RGBColor[
              0.9489852999786376, 0.9614739007697484, 0.9712387597581826], 
             367 -> RGBColor[
              0.7539073345293585, 0.8076774067330772, 0.9761060955074329], 19 -> 
             RGBColor[
              0.9769295851811134, 0.9823147029191873, 0.9239363739472319], 
             164 -> RGBColor[
              0.9464765244950829, 0.9596028601218561, 0.9754854622584005], 
             190 -> RGBColor[
              0.8982909915651857, 0.6310449720875011, 0.23684384905710953`], 
             103 -> RGBColor[
              0.9929719279031446, 0.9873759893689426, 0.47641590836971975`], 
             138 -> RGBColor[
              0.9881004199580306, 0.989347232094457, 0.846870366628816], 416 -> 
             RGBColor[
              0.40443808765213085`, 0.5247256767001043, 0.9469914152080031], 
             476 -> RGBColor[
              0.9156337612939072, 0.9355655233121568, 0.9918151596197627], 
             291 -> RGBColor[
              0.9872663566016568, 0.989002325462146, 0.8606929549307015], 28 -> 
             RGBColor[
              0.9717992331185357, 0.9165343328331821, 0.34494577524382214`], 
             337 -> RGBColor[
              0.907889855390706, 0.9293907429476702, 0.991076538961649], 195 -> 
             RGBColor[
              0.9081185216015778, 0.6734275863775558, 0.24492820962638162`], 
             114 -> RGBColor[
              0.9587499018954205, 0.9687563248912169, 0.9547098357291259], 
             479 -> RGBColor[
              0.9892799716147425, 0.9898350070176023, 0.8273221430952633], 93 -> 
             RGBColor[
              0.9688953032216306, 0.9763227485887345, 0.9375363176283014], 34 -> 
             RGBColor[
              0.9906116290202498, 0.9903856815768138, 0.805253133667114], 161 -> 
             RGBColor[
              0.9557685073274801, 0.9665328057040325, 0.95975655906041], 22 -> 
             RGBColor[
              0.9918631161662353, 0.9909032036734315, 0.7845127529132185], 
             124 -> RGBColor[
              0.9922997456026216, 0.991083761166242, 0.7772766731915393], 84 -> 
             RGBColor[
              0.476813844750156, 0.5861379852439204, 0.9519556789668475], 46 -> 
             RGBColor[
              0.8974440482331547, 0.6271992002253893, 0.23613713878038212`], 
             241 -> RGBColor[
              0.9939135162767967, 0.9893899516909965, 0.5789019920318876], 
             185 -> RGBColor[
              0.766321644409168, 0.8173755599634339, 0.9773434378979305], 426 -> 
             RGBColor[
              0.9841907417577515, 0.9877300616049912, 0.9116451298759246], 
             390 -> RGBColor[
              0.9927145952562305, 0.9868255808575149, 0.44840683782613266`], 
             121 -> RGBColor[
              0.9491638974229396, 0.9616070984512823, 0.970936440870653], 322 -> 
             RGBColor[
              0.9922115581868209, 0.9910472934034951, 0.7787381668930735], 
             488 -> RGBColor[
              0.9926373767765941, 0.991223380333405, 0.7716812508773457], 126 -> 
             RGBColor[
              0.9940545986786762, 0.9896917126829979, 0.5942579408168185], 
             433 -> RGBColor[
              0.968405964571314, 0.9050880412460598, 0.3317635677028626], 236 -> 
             RGBColor[
              0.9936803803580584, 0.9888912975344725, 0.55352658602534], 78 -> 
             RGBColor[
              0.7086450634956192, 0.7723181765955193, 0.9715947753307611], 
             376 -> RGBColor[
              0.9338040331693572, 0.9500540048867498, 0.9935482563720364], 
             458 -> RGBColor[
              0.9575982218073806, 0.9678974037672599, 0.9566593297119037], 
             254 -> RGBColor[
              0.9951725983881046, 0.9920830010143554, 0.7159453096936692], 
             290 -> RGBColor[
              0.9081342712428495, 0.929585633513678, 0.9910998515638191], 251 -> 
             RGBColor[
              0.9679468990802076, 0.9756154303329303, 0.9391417184563149], 
             165 -> RGBColor[
              0.990231992453533, 0.9902286921002618, 0.8115446940455516], 460 -> 
             RGBColor[
              0.6049243439215446, 0.6901438597834719, 0.9620410067458405], 
             100 -> RGBColor[
              0.9669943160512524, 0.9749049954696472, 0.9407541930508916], 
             235 -> RGBColor[
              0.7934846623287195, 0.8385955160087699, 0.9800507936713169], 70 -> 
             RGBColor[
              0.9551365784488809, 0.9660615141810618, 0.9608262498184306], 
             234 -> RGBColor[
              0.8710934909312559, 0.9000503207384101, 0.9875668688710044], 
             435 -> RGBColor[
              0.7899391119853906, 0.8358257051333807, 0.9796974063481455], 
             257 -> RGBColor[
              0.9936815870020732, 0.9888938784240099, 0.5536579217798141], 
             135 -> RGBColor[
              0.9859117539253687, 0.9884421624437999, 0.8831422268761491], 
             265 -> RGBColor[
              0.994851114408306, 0.9913953792885825, 0.6809537624617367], 111 -> 
             RGBColor[
              0.9674385184724614, 0.9752362809080701, 0.9400022742183309], 
             497 -> RGBColor[
              0.3688613674925014, 0.4939109098357809, 0.94472449805869], 481 -> 
             RGBColor[
              0.9901254984830484, 0.9783531291194192, 0.4161398555601312], 
             381 -> RGBColor[
              0.9900378250817309, 0.9901483989021477, 0.8147625498853639], 
             182 -> RGBColor[
              0.9807814461909492, 0.9468334466503561, 0.37983997688153864`], 
             188 -> RGBColor[
              0.7993034860859929, 0.8431412253526505, 0.9806307596434422], 
             154 -> RGBColor[
              0.9671622621078588, 0.9750302493636778, 0.9404699041844038], 
             336 -> RGBColor[
              0.9919577553280057, 0.990942339398939, 0.782944337084385], 463 -> 
             RGBColor[
              0.8398174719718398, 0.30706011446884196`, 0.1857625621686234], 
             315 -> RGBColor[
              0.9649894433749069, 0.9734097647103064, 0.9441479195374052], 
             368 -> RGBColor[
              0.797320960956232, 0.8415924616535322, 0.9804331600662582], 269 -> 
             RGBColor[
              0.9938942060571305, 0.9893486490836934, 0.5768001937900933], 
             208 -> RGBColor[
              0.9895122053947392, 0.9899310416537668, 0.823473428358962], 86 -> 
             RGBColor[
              0.9891190138941445, 0.9897684468637102, 0.8299896290708011], 
             119 -> RGBColor[
              0.9936220326696094, 0.9916305608496689, 0.7553629545223166], 
             436 -> RGBColor[
              0.8368850853389176, 0.8727734666815127, 0.984304040607403], 377 -> 
             RGBColor[
              0.9779769973842805, 0.9373733823095687, 0.3689452228433496], 
             140 -> RGBColor[
              0.9952031270002631, 0.9921482986288463, 0.7192681607263712], 85 -> 
             RGBColor[
              0.9563537148714706, 0.9669692525321512, 0.9587659553350063], 
             351 -> RGBColor[
              0.9906140542969182, 0.9903866844910431, 0.8052129405563028], 
             443 -> RGBColor[
              0.9829176889926815, 0.9540394952342622, 0.38813887677066594`], 
             242 -> RGBColor[
              0.9498029103340657, 0.9620836732341126, 0.9698547586933759], 
             117 -> RGBColor[
              0.7078867023204115, 0.7717257390816886, 0.9715191889761045], 47 -> 
             RGBColor[
              0.9764870991010651, 0.9819846975251917, 0.924685387461901], 451 -> 
             RGBColor[
              0.9920444458393581, 0.9909781881532278, 0.781507650963424], 81 -> 
             RGBColor[
              0.5941261706242863, 0.681377416248594, 0.9611909349888681], 275 -> 
             RGBColor[
              0.41722699459647755`, 0.5358027851061444, 0.9478063130497105], 
             23 -> RGBColor[
              0.9596632772069624, 0.9694375187030501, 0.9531637295731195], 
             328 -> RGBColor[
              0.9506727505068838, 0.9627323986107678, 0.9683823461714459], 
             418 -> RGBColor[
              0.9935901249408909, 0.9886982503233738, 0.5437028408585354], 
             110 -> RGBColor[
              0.9440398719696395, 0.9577856086580327, 0.9796100794032163], 6 -> 
             RGBColor[
              0.9651381352551532, 0.8940648856398379, 0.3190686678873633], 
             218 -> RGBColor[
              0.9604917324217577, 0.9700553792457735, 0.9517613709901963], 
             108 -> RGBColor[
              0.9926432239233782, 0.9866729247932927, 0.4406385086979782], 
             297 -> RGBColor[
              0.7899391119853906, 0.8358257051333807, 0.9796974063481455], 
             487 -> RGBColor[
              0.9870563486423428, 0.9889154817740112, 0.8641733302997117], 
             464 -> RGBColor[
              0.9072529211412013, 0.6699957689964171, 0.24423172717770847`], 
             157 -> RGBColor[
              0.8197470811589967, 0.8591119172007583, 0.9826683861440613], 
             441 -> 
             RGBColor[
              0.866163262477715, 0.48516045792306606`, 0.21003568438382075`], 
             354 -> RGBColor[
              0.9915252782451579, 0.9907634990110274, 0.7901116015619869], 
             385 -> RGBColor[
              0.8421598933689439, 0.8769794554238061, 0.9848071565061836], 
             270 -> RGBColor[
              0.9855471576580349, 0.9882913925175607, 0.8891845305707625], 
             392 -> RGBColor[
              0.9913149785018636, 0.9906765346627183, 0.793596812546663], 33 -> 
             RGBColor[
              0.7686188297487496, 0.8191701386099703, 0.9775723998641624], 
             252 -> RGBColor[
              0.6974422291928652, 0.7635664372935137, 0.9704781815039014], 
             394 -> RGBColor[
              0.945176638309412, 0.9586334071329511, 0.9776858305061266], 260 -> 
             RGBColor[
              0.9936646257042686, 0.9916481741640916, 0.7546570777107737], 
             159 -> RGBColor[
              0.9481257099902091, 0.9608328199638279, 0.9726938213916173], 
             183 -> RGBColor[
              0.9427646108812472, 0.9568345210263581, 0.9817687637845038], 99 -> 
             RGBColor[
              0.8642840847091512, 0.8946206850533116, 0.9869173816267113], 
             329 -> RGBColor[
              0.9545364168831167, 0.9656139146679892, 0.9618421668020637], 
             309 -> RGBColor[
              0.6271896494347438, 0.7082198378396697, 0.9637938131563409], 17 -> 
             RGBColor[
              0.921488412039042, 0.9402338628960664, 0.9923735814343422], 349 -> 
             RGBColor[
              0.9939300861309733, 0.9894253929336111, 0.5807055184017289], 
             495 -> RGBColor[
              0.4717197265342954, 0.5820023505888743, 0.9515546513205251], 
             347 -> RGBColor[
              0.859254183043861, 0.8906099779984528, 0.9864376251156297], 340 -> 
             RGBColor[
              0.9456278325369345, 0.9589699070490746, 0.9769220763692325], 
             404 -> RGBColor[
              0.8377972602547259, 0.2915318819486864, 0.1838280051468125], 
             277 -> RGBColor[
              0.9936646257042686, 0.9916481741640916, 0.7546570777107737], 
             104 -> RGBColor[
              0.984763798202576, 0.9879674532513087, 0.9021668240170019], 79 -> 
             RGBColor[
              0.990460762545138, 0.9903232944122636, 0.8077533815896372], 327 -> 
             RGBColor[
              0.9919726785002643, 0.990948510514176, 0.7826970215001282], 191 -> 
             RGBColor[
              0.5985345274212615, 0.6849563188905889, 0.961537976984269], 50 -> 
             RGBColor[
              0.6955987398736622, 0.7621262894263146, 0.9702944397169504], 
             225 -> RGBColor[
              0.9943357906881923, 0.9902931539584797, 0.6248639557367179], 
             405 -> RGBColor[
              0.9821287880356444, 0.9861922598951831, 0.9151354796837913], 61 -> 
             RGBColor[
              0.9861134118078136, 0.9885255531605621, 0.8798002338901638], 
             196 -> RGBColor[
              0.8908916096524633, 0.5974461069913812, 0.23066962341368627`], 
             1 -> RGBColor[
              0.994761622142692, 0.9912039643814904, 0.6712130816319075], 263 -> 
             RGBColor[
              0.9606212925985209, 0.9701520050134682, 0.9515420594056421], 
             201 -> RGBColor[
              0.7605619884270208, 0.8128760729351738, 0.9767693692166755], 
             371 -> RGBColor[
              0.9952158667346623, 0.9921755476325415, 0.7206548021951973], 
             293 -> RGBColor[
              0.6910757253417514, 0.7585928760978021, 0.9698436278983834], 
             362 -> RGBColor[
              0.9945689632734257, 0.9907918865409293, 0.6502433526649855], 
             184 -> RGBColor[
              0.9600467891850777, 0.9697235413083851, 0.9525145438301138], 
             106 -> RGBColor[
              0.9949337294248691, 0.9915720844553517, 0.6899458971738577], 
             206 -> RGBColor[
              0.9505524140022226, 0.9626426518426244, 0.9685860444850504], 
             358 -> RGBColor[
              0.9881873591473117, 0.98938318368346, 0.8454295592710166], 247 -> 
             RGBColor[
              0.9948733979103268, 0.9914430414461974, 0.6833791841388718], 
             220 -> RGBColor[
              0.991324686979518, 0.990680549367725, 0.7934359179471931], 407 -> 
             RGBColor[
              0.7526865493971486, 0.8067237201094842, 0.9759844190543399], 
             107 -> RGBColor[
              0.8912924350803424, 0.9161564105171588, 0.9894934621957545], 
             375 -> RGBColor[
              0.9602291145517226, 0.9698595192682985, 0.9522059145424555], 
             131 -> RGBColor[
              0.9933886079898365, 0.9882672259415575, 0.5217689643547243], 
             411 -> RGBColor[
              0.9944754017021891, 0.9919834508752244, 0.7412204212042086], 
             462 -> RGBColor[
              0.9939460934061856, 0.9917645682922243, 0.7499924294749454], 
             127 -> RGBColor[
              0.9914081235941095, 0.9907150525520817, 0.7920531573163769], 
             210 -> 
             RGBColor[
              0.8854672983464368, 0.9115116046046668, 0.9889378554539137], 
             357 -> RGBColor[
              0.9911544721626188, 0.9906101611666158, 0.7962568179650393], 
             181 -> RGBColor[
              0.9419304438799969, 0.9562124006426488, 0.9831807909320226], 
             194 -> RGBColor[
              0.9934839719768828, 0.9884711998670714, 0.5321487458264043], 
             440 -> RGBColor[
              0.8409756841659908, 0.8760351991498737, 0.9846942055752499], 
             490 -> RGBColor[
              0.9632043768696127, 0.9720784650334361, 0.9471695715109596], 
             118 -> RGBColor[
              0.9724775037938655, 0.9789943479101921, 0.931472586447049], 348 -> 
             RGBColor[
              0.9946558030455566, 0.9909776280326694, 0.6596953259484791], 
             276 -> RGBColor[
              0.9895522426633538, 0.9899475980932498, 0.8228099072048861], 
             305 -> RGBColor[
              0.8746543629682053, 0.902889663443377, 0.9879065080247166], 343 -> 
             RGBColor[
              0.9562839147324712, 0.9669171957027727, 0.9588841087635405], 
             280 -> RGBColor[
              0.9864435759837261, 0.9886620845321342, 0.8743285590577978], 
             474 -> RGBColor[
              0.49517449064791735`, 0.6010439847213946, 0.9534010962691813], 
             189 -> RGBColor[
              0.9923206082038829, 0.9910923883880078, 0.7769309258979589], 
             168 -> RGBColor[
              0.6011340847591126, 0.68706675664618, 0.961742623660397], 363 -> 
             RGBColor[
              0.9872663566016568, 0.989002325462146, 0.8606929549307015], 41 -> 
             RGBColor[
              0.8167277916394404, 0.8567532252806307, 0.9823674515816166], 14 -> 
             RGBColor[
              0.8499918119256579, 0.8832244146891638, 0.9855541718897592], 77 -> 
             RGBColor[
              0.9920406158241435, 0.9909766043435096, 0.7815711242272926], 51 -> 
             RGBColor[
              0.9391329286420175, 0.9541260183586745, 0.9879162545210928], 
             438 -> RGBColor[
              0.9792256916297781, 0.9415855212069837, 0.3737961641909859], 
             179 -> RGBColor[
              0.9410838851299942, 0.9555810385130096, 0.9846137940778935], 
             467 -> RGBColor[
              0.9480658066721221, 0.9607881441672812, 0.9727952220838508], 
             223 -> RGBColor[
              0.981297776334402, 0.9485751494643052, 0.38184582198808664`], 
             456 -> RGBColor[
              0.8197470811589967, 0.8591119172007583, 0.9826683861440613], 
             323 -> RGBColor[
              0.992567805904149, 0.9865116132760925, 0.4324297227309256], 500 -> 
             RGBColor[
              0.9509755078711634, 0.9629581945573278, 0.9678698569254878], 
             478 -> RGBColor[
              0.9827046816404774, 0.9866217604027284, 0.9141606420279168], 
             292 -> RGBColor[
              0.9874526239609769, 0.9890793518020776, 0.8576060227422948], 
             491 -> RGBColor[
              0.993300240981022, 0.9914974917167688, 0.7606958755724054], 396 -> 
             RGBColor[
              0.9669943160512524, 0.9749049954696472, 0.9407541930508916], 
             321 -> RGBColor[
              0.9924998031041922, 0.9911664900843846, 0.7739612026582968], 
             143 -> RGBColor[
              0.9680035400057236, 0.903730568692542, 0.33020022425704637`], 
             112 -> RGBColor[
              0.6180241048394668, 0.7007788358341452, 0.9630722679113046], 
             197 -> RGBColor[
              0.5505634611375302, 0.6460112462095473, 0.9577615189226079], 
             421 -> RGBColor[
              0.7890218840957037, 0.8351091597347673, 0.9796059856440835], 54 -> 
             RGBColor[
              0.4196519490391767, 0.5379031587626563, 0.9479608290024963], 71 -> 
             RGBColor[
              0.9911411438168791, 0.9906046495531297, 0.7964777031465992], 
             177 -> RGBColor[
              0.7993034860859929, 0.8431412253526505, 0.9806307596434422], 
             158 -> RGBColor[
              0.9870582972522933, 0.9889162875743027, 0.8641410367899918], 
             226 -> RGBColor[
              0.8826656849648918, 0.9092776741419923, 0.9886706350685521], 
             432 -> RGBColor[
              0.9948105827482334, 0.9921220568515238, 0.7356656038505125], 
             350 -> RGBColor[
              0.9545364168831167, 0.9656139146679892, 0.9618421668020637], 
             203 -> RGBColor[
              0.9939137590770833, 0.9893904710162589, 0.5789284193447056], 
             475 -> RGBColor[
              0.9943920101237455, 0.9919489663144722, 0.7426024354695057], 
             115 -> RGBColor[
              0.9637098283336994, 0.9724554299077511, 0.9463139740251159], 
             173 -> RGBColor[
              0.8642840847091512, 0.8946206850533116, 0.9869173816267113], 
             212 -> RGBColor[
              0.9926991229149806, 0.9912489139484312, 0.770657957570398], 129 -> 
             RGBColor[
              0.9764870991010651, 0.9819846975251917, 0.924685387461901], 279 -> 
             RGBColor[
              0.9900572958286832, 0.9901564505563879, 0.8144398692196853], 26 -> 
             RGBColor[
              0.9516755510296806, 0.846116693540358, 0.27997521791911906`], 
             40 -> RGBColor[
              0.9874526239609769, 0.9890793518020776, 0.8576060227422948], 
             146 -> RGBColor[
              0.9902193274416536, 0.9902234547923737, 0.8117545860683917], 
             386 -> RGBColor[
              0.9436616966478468, 0.9575035661222451, 0.9802502315790906], 
             192 -> RGBColor[
              0.9861166971049226, 0.9885269117153449, 0.8797457880149935], 
             300 -> RGBColor[
              0.8542202472702329, 0.8865960542551082, 0.9859574838276935], 
             221 -> RGBColor[
              0.8654864596105605, 0.48208725417464304`, 0.20947094348151066`],
              62 -> RGBColor[
              0.7932422764963147, 0.8384061623542949, 0.9800266349167671], 
             286 -> RGBColor[
              0.751413785916484, 0.8057294276050283, 0.9758575618852382], 472 -> 
             RGBColor[
              0.807695902153758, 0.849697444569513, 0.9814672372454898], 152 -> 
             RGBColor[
              0.9951813118002211, 0.9921016381218115, 0.7168937108296036], 64 -> 
             RGBColor[
              0.6468420575705056, 0.7240371986465786, 0.965434829282073], 307 -> 
             RGBColor[
              0.4940072928296394, 0.6000964009508541, 0.95330921018134], 37 -> 
             RGBColor[
              0.9922801948304429, 0.9910756764195141, 0.777600680082317], 148 -> 
             RGBColor[
              0.8287764074240538, 0.8663078270163989, 0.983530627669181], 261 -> 
             RGBColor[
              0.9933109093215855, 0.9881010363467089, 0.513311943816193], 387 -> 
             RGBColor[
              0.908400377023576, 0.9297978190399803, 0.9911252329707403], 15 -> 
             RGBColor[
              0.9445058005193249, 0.9581330974075001, 0.9788213839022271], 
             136 -> RGBColor[
              0.896960293200872, 0.920675806732559, 0.9900340675630473], 198 -> 
             RGBColor[
              0.9936089224832533, 0.9887384563657637, 0.545748837339687], 63 -> 
             RGBColor[
              0.779729099079362, 0.8278495654522192, 0.978679767679668], 444 -> 
             RGBColor[
              0.9458333735252019, 0.959123199181582, 0.9765741490897711], 310 -> 
             RGBColor[
              0.7590940204150871, 0.811729285167281, 0.9766230558841869], 171 -> 
             RGBColor[
              0.9463325743084324, 0.959495502308349, 0.9757291323761782], 395 -> 
             RGBColor[
              0.9553756866732158, 0.966239840703267, 0.9604215019640444], 311 -> 
             RGBColor[
              0.9930755078788319, 0.9875975364633957, 0.48768994950177114`], 
             353 -> RGBColor[
              0.8501068125121857, 0.8833161130352534, 0.9855651407483644], 59 -> 
             RGBColor[
              0.985955732953962, 0.9884603489023327, 0.882413380558279], 397 -> 
             RGBColor[
              0.9949866750642881, 0.9921948755495785, 0.7327472984611801], 
             229 -> RGBColor[
              0.9901011006178057, 0.9901745649624217, 0.8137139105007668], 
             102 -> RGBColor[
              0.8565277200125756, 0.8884359703851732, 0.9861775726377634], 
             453 -> RGBColor[
              0.9933724879512359, 0.9882327468089768, 0.5200143976343962], 
             299 -> RGBColor[
              0.9689465461444343, 0.9763609654766587, 0.9374495767262896], 
             128 -> RGBColor[
              0.9947562454611723, 0.9911924642033852, 0.6706278630295037], 12 -> 
             RGBColor[
              0.9499945830984222, 0.9622266224679343, 0.9695303066995835], 
             222 -> RGBColor[
              0.9952054995670295, 0.9921533733092563, 0.7195263999771061], 
             483 -> RGBColor[
              0.986070632802648, 0.9885078629425558, 0.8805091927142772], 92 -> 
             RGBColor[
              0.9654225358612915, 0.89502423566478, 0.32017351053766224`], 
             271 -> RGBColor[
              0.9522898834429248, 0.963938453706655, 0.9656449619265476], 361 -> 
             RGBColor[
              0.9886805558193184, 0.9895871331819112, 0.837256014063794], 344 -> 
             RGBColor[
              0.9127871467304569, 0.9332957101285555, 0.9915436469814981], 
             132 -> RGBColor[
              0.9891307035529966, 0.9897732808380562, 0.8297959011717531], 80 -> 
             RGBColor[
              0.8282181396687027, 0.8658626794620564, 0.9834773795923041], 
             324 -> RGBColor[
              0.9936826307477605, 0.991655619712284, 0.7543586875445529], 244 -> 
             RGBColor[
              0.9948063257252449, 0.9921202964631175, 0.735736153738255], 150 -> 
             RGBColor[
              0.9793803232720479, 0.9421071300455963, 0.37439687892146906`], 
             125 -> RGBColor[
              0.7391517277861053, 0.7961502145984829, 0.9746353945262503], 
             258 -> RGBColor[
              0.7893125261109195, 0.835336211486015, 0.9796349541239562], 133 -> 
             RGBColor[
              0.8767226777686483, 0.9045388815223406, 0.9881037857367893], 
             469 -> 
             RGBColor[
              0.9947192565649711, 0.991113348694562, 0.6666018499470134], 255 -> 
             RGBColor[
              0.8817841771458675, 0.9085747837349947, 0.9885865560658422], 
             408 -> RGBColor[
              0.5505634611375302, 0.6460112462095473, 0.9577615189226079], 
             326 -> RGBColor[
              0.8535981980829038, 0.4129848141111679, 0.19895900105568243`], 
             176 -> RGBColor[
              0.9433391891963481, 0.813065796799098, 0.2732675855084579], 230 -> 
             RGBColor[
              0.7993034860859929, 0.8431412253526505, 0.9806307596434422], 
             274 -> RGBColor[
              0.963787220437266, 0.9725131488118731, 0.9461829693808712], 87 -> 
             RGBColor[
              0.9940299696299112, 0.9896390336380685, 0.5915772208516179], 
             439 -> RGBColor[
              0.9934587493482713, 0.9884172512148703, 0.529403418358061], 130 -> 
             RGBColor[
              0.9939762846487628, 0.9917770531469094, 0.7494920824530108], 35 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 379 -> 
             RGBColor[
              0.866162829176085, 0.8961187448940847, 0.9870965779511425], 31 -> 
             RGBColor[
              0.9926384671321766, 0.9866627504978979, 0.4401207613311979], 18 -> 
             RGBColor[
              0.7288233705254076, 0.7880816234080034, 0.9736059603984901], 24 -> 
             RGBColor[
              0.98499426026609, 0.9880627552371767, 0.8983474712078723], 151 -> 
             RGBColor[
              0.9885184001469689, 0.9895200776441839, 0.8399433532000532], 
             137 -> RGBColor[
              0.8529343560030423, 0.8855707194632391, 0.9858348343707003], 
             330 -> RGBColor[
              0.9926384671321766, 0.9866627504978979, 0.4401207613311979], 
             296 -> RGBColor[
              0.9935622242383599, 0.9886385735418538, 0.5406660215712138], 
             266 -> RGBColor[
              0.6049243439215446, 0.6901438597834719, 0.9620410067458405], 
             302 -> RGBColor[
              0.5946890309950504, 0.6818343716541512, 0.9612352454190801], 
             442 -> RGBColor[
              0.9942496759509837, 0.9901089632431259, 0.6154908980301118], 
             283 -> RGBColor[
              0.9713314697886177, 0.9781396376255367, 0.933412523084394], 388 -> 
             RGBColor[
              0.9785610662277989, 0.9835314588125004, 0.921174702093599], 284 -> 
             RGBColor[
              0.8209029866322182, 0.8600297749953031, 0.98277965376537], 417 -> 
             RGBColor[
              0.8805704112844738, 0.9076069597839158, 0.9884707859944409], 
             318 -> RGBColor[
              0.9817868489047369, 0.9502249060837454, 0.38374577657023273`], 
             413 -> RGBColor[
              0.891650335296971, 0.9164417904349559, 0.9895275990379179], 238 -> 
             RGBColor[
              0.9938962936079991, 0.9893531141439175, 0.5770274108192655], 72 -> 
             RGBColor[
              0.3992736043846964, 0.520252460868329, 0.9466623389009755], 437 -> 
             RGBColor[
              0.9233670718096835, 0.9417318552023151, 0.9925527696803653], 
             288 -> RGBColor[
              0.9674942093458486, 0.9752778150702568, 0.9399080040961925], 
             382 -> RGBColor[
              0.7464147522017225, 0.8018241444729931, 0.9753593049231769], 
             461 -> RGBColor[
              0.9138753133526578, 0.9341633846556024, 0.9916474372853414], 
             389 -> RGBColor[
              0.9775808035995859, 0.9360369276430692, 0.36740608480472925`], 
             172 -> RGBColor[
              0.9295486179424448, 0.9466608522949791, 0.9931423710688395], 
             447 -> RGBColor[
              0.9096632488687217, 0.6795519152419345, 0.2461711334449348], 
             243 -> RGBColor[
              0.7472009546708844, 0.8024383318172625, 0.9754376662378231], 
             410 -> RGBColor[
              0.9604917324217577, 0.9700553792457735, 0.9517613709901963], 88 -> 
             RGBColor[
              0.9925524587883872, 0.9864787873473095, 0.4307592838916761], 
             273 -> RGBColor[
              0.9678839473787003, 0.9033271546799081, 0.32973562948423335`], 
             477 -> RGBColor[
              0.9665470735432166, 0.9745714427394464, 0.9415112579574685], 
             202 -> RGBColor[
              0.967928859564656, 0.9756019764917689, 0.9391722546506844], 393 -> 
             RGBColor[
              0.5066339530566218, 0.6103472925476794, 0.9543032271273885], 98 -> 
             RGBColor[
              0.9357890338837308, 0.7831319469246814, 0.2671925533190031], 30 -> 
             RGBColor[
              0.8611819161618465, 0.8921471000598129, 0.9866214940213308], 
             116 -> RGBColor[
              0.9935990320651408, 0.9887173017614959, 0.5446723263647331], 
             373 -> RGBColor[
              0.6133257245690064, 0.6969644790709664, 0.9627023942056799], 
             434 -> RGBColor[
              0.9777148091835204, 0.936488959943688, 0.367926671193484], 401 -> 
             RGBColor[
              0.9923206082038829, 0.9910923883880078, 0.7769309258979589], 
             240 -> RGBColor[
              0.8222475238555169, 0.17200979404642724`, 0.16893756001001453`],
              480 -> RGBColor[
              0.49840860677016185`, 0.6036695858847038, 0.9536556977372821], 
             403 -> RGBColor[
              0.9946866659904383, 0.9910436407510489, 0.6630545670348296], 
             317 -> RGBColor[
              0.9893576549183145, 0.9898671310599991, 0.8260347297171295], 
             429 -> RGBColor[
              0.9872663566016568, 0.989002325462146, 0.8606929549307015], 391 -> 
             RGBColor[
              0.6525317277018968, 0.7284820121963159, 0.9660019224277797], 73 -> 
             RGBColor[
              0.8022252999813367, 0.8454237685743011, 0.9809219787466268], 
             303 -> RGBColor[
              0.942737056387778, 0.9568139709302452, 0.9818154063545841], 449 -> 
             RGBColor[
              0.9297736146473136, 0.7592828141719185, 0.2623524058013447], 29 -> 
             RGBColor[
              0.9365900091763613, 0.9522295131848366, 0.9922207538768317], 
             360 -> RGBColor[
              0.6468183271371717, 0.7240186602517001, 0.9654324640542519], 
             320 -> RGBColor[
              0.8807985257577451, 0.9077888520728999, 0.9884925437565417], 
             482 -> RGBColor[
              0.8031103919798226, 0.8461152091704666, 0.9810101964453809], 75 -> 
             RGBColor[
              0.995039263570426, 0.9922166222483295, 0.7318757708197832], 200 -> 
             RGBColor[
              0.9860288753738281, 0.9884905951726218, 0.8812012213745832], 
             301 -> RGBColor[
              0.8939196906276755, 0.9182513127756502, 0.9897440521752379], 
             156 -> RGBColor[
              0.9714310363902652, 0.9152923188120228, 0.3435154004826091], 25 -> 
             RGBColor[
              0.7679837895328073, 0.8186740403667918, 0.9775091049902256], 38 -> 
             RGBColor[
              0.9353426999726137, 0.781362381699061, 0.26683342257731485`], 
             365 -> RGBColor[
              0.49517449064791735`, 0.6010439847213946, 0.9534010962691813], 
             380 -> RGBColor[
              0.709289121751741, 0.7728213198002256, 0.9716589690386647], 370 -> 
             RGBColor[
              0.9688036072095633, 0.9762543618530729, 0.9376915350585814], 3 -> 
             RGBColor[
              0.9381481289873536, 0.9533915563886877, 0.9895832634595528], 57 -> 
             RGBColor[
              0.8687587674743926, 0.8981886756282872, 0.9873441808634565], 
             227 -> 
             RGBColor[
              0.9526643045117749, 0.9642176963267451, 0.9650111647216391], 
             494 -> RGBColor[
              0.788881449243922, 0.834999450961211, 0.9795919884104962], 39 -> 
             RGBColor[
              0.9517791693984899, 0.963557564008533, 0.9665094675882199], 424 -> 
             RGBColor[
              0.6973434138877295, 0.7634892420261175, 0.970468332517767], 109 -> 
             RGBColor[
              0.9516755510296806, 0.846116693540358, 0.27997521791911906`], 
             465 -> RGBColor[
              0.9867718661313074, 0.988797840944831, 0.8688879417247074], 256 -> 
             RGBColor[
              0.9850753875133046, 0.9613179189960289, 0.39652112807611095`], 
             457 -> RGBColor[
              0.9936853008897475, 0.9916567238846151, 0.7543144363817231], 
             339 -> RGBColor[
              0.9332348462809481, 0.9496001507120989, 0.9934939668185008], 
             420 -> RGBColor[
              0.991750525969403, 0.9908566447336052, 0.7863786638488193], 287 -> 
             RGBColor[
              0.9920406158241435, 0.9909766043435096, 0.7815711242272926], 
             239 -> RGBColor[
              0.9948345234624749, 0.9913598929330517, 0.6791479403954717], 
             427 -> RGBColor[
              0.9847434556888071, 0.9601982350106999, 0.39523163561800334`], 
             285 -> RGBColor[
              0.9938826384747171, 0.9893239071945731, 0.5755411338312368], 
             345 -> RGBColor[
              0.9886168168947244, 0.9895607754985759, 0.838312332995365], 366 -> 
             RGBColor[
              0.9913623929702289, 0.9906961417638837, 0.7928110321011386], 
             216 -> RGBColor[
              0.9946215495070216, 0.9909043631773071, 0.655967039667279], 21 -> 
             RGBColor[
              0.8340272800335832, 0.8704947303040975, 0.9840314605861873], 
             355 -> RGBColor[
              0.8562583984378525, 0.8882212206720284, 0.9861518845055401], 
             175 -> RGBColor[
              0.8632095549064818, 0.8937638841559976, 0.9868148920148886], 7 -> 
             RGBColor[
              0.9156337612939072, 0.9355655233121568, 0.9918151596197627], 13 -> 
             RGBColor[
              0.9787012665938317, 0.9398165124198827, 0.3717588719556926], 
             294 -> RGBColor[
              0.8882905778403599, 0.9137628110372409, 0.9892071423724155], 
             412 -> RGBColor[
              0.9330112191112232, 0.7721188370035883, 0.26495745834935047`], 
             193 -> RGBColor[
              0.9858746281928233, 0.9884268099993047, 0.8837574963427408], 60 -> 
             RGBColor[
              0.8503664120936247, 0.88352311069485, 0.9855899015881894], 65 -> 
             RGBColor[
              0.9440886042924382, 0.9578219531445842, 0.9795275882921435], 
             448 -> RGBColor[
              0.9931249976822633, 0.9877033901487487, 0.4930766091896134], 69 -> 
             RGBColor[
              0.967128294006641, 0.9750049160094072, 0.9405274033194659], 217 -> 
             RGBColor[
              0.9934408426720591, 0.9883789506450952, 0.5274543871595616], 
             214 -> RGBColor[
              0.9891924326725939, 0.9897988074153756, 0.828772889910186], 170 -> 
             RGBColor[
              0.6910757253417514, 0.7585928760978021, 0.9698436278983834], 
             359 -> RGBColor[
              0.2777591011371284, 0.40927280461225934`, 0.9391293419507684], 
             74 -> RGBColor[
              0.8535981980829038, 0.4129848141111679, 0.19895900105568243`], 
             246 -> RGBColor[
              0.9944386569648964, 0.9905131745229737, 0.6360603151388834], 
             264 -> RGBColor[
              0.9939253356538074, 0.9894152321433002, 0.580188458278768], 278 -> 
             RGBColor[
              0.6607460158149041, 0.7348990765010991, 0.9668206458999975], 45 -> 
             RGBColor[
              0.9125889311846307, 0.9331376584327313, 0.991524741005788], 492 -> 
             RGBColor[
              0.943644924508238, 0.9574910574879867, 0.9802786224365736], 306 -> 
             RGBColor[
              0.24148141152160513`, 0.3711426526879731, 0.9370633811951966], 
             237 -> RGBColor[
              0.7069257526397661, 0.7709750378876803, 0.9714234104925231], 
             228 -> RGBColor[
              0.9762551659020785, 0.9315652404148437, 0.36225623267558665`], 
             180 -> RGBColor[
              0.9945689632734257, 0.9907918865409293, 0.6502433526649855], 
             383 -> RGBColor[
              0.9770649108580635, 0.9824156285874812, 0.9237073028747447], 53 -> 
             RGBColor[
              0.9524053407651528, 0.9640245615885287, 0.9654495227961079], 
             304 -> RGBColor[
              0.9280215542957396, 0.9454432131941348, 0.9929967183749909], 48 -> 
             RGBColor[
              0.9943596889220683, 0.9903442698642584, 0.6274651310113197], 5 -> 
             RGBColor[
              0.8405027905099549, 0.875658126584907, 0.98464910055618], 101 -> 
             RGBColor[
              0.9627019401757618, 0.9717037485698267, 0.9480200657771721], 
             333 -> 
             RGBColor[
              0.9669295514405968, 0.9001077530778621, 0.32602798148725104`], 
             267 -> RGBColor[
              0.4541462206382863, 0.5677353868250754, 0.950171200562518], 120 -> 
             RGBColor[
              0.9920030826041056, 0.9909610833924642, 0.7821931468161787], 
             147 -> RGBColor[
              0.6029981573899142, 0.6885800947833799, 0.9618893702862167], 89 -> 
             RGBColor[
              0.9940646295978214, 0.9897131678047679, 0.5953497444621092], 43 -> 
             RGBColor[
              0.9827311511812263, 0.9866415013428791, 0.9141158359997906], 
             199 -> RGBColor[
              0.8197470811589967, 0.8591119172007583, 0.9826683861440613], 
             268 -> RGBColor[
              0.943644924508238, 0.9574910574879867, 0.9802786224365736], 169 -> 
             RGBColor[
              0.9918655249554302, 0.9909041997696667, 0.7844728330425135], 20 -> 
             RGBColor[
              0.9927470063538071, 0.9868949049179667, 0.4519345857792383], 4 -> 
             RGBColor[
              0.8517709590339677, 0.8846430582996684, 0.9857238685292131], 
             167 -> RGBColor[
              0.9950690747021357, 0.9918615743179181, 0.704677395350086], 431 -> 
             RGBColor[
              0.9925320919058048, 0.9864352246448738, 0.42854247441242493`], 
             142 -> RGBColor[
              0.9926936791123855, 0.9867808433407771, 0.4461302446480867], 16 -> 
             RGBColor[
              0.5344973444757293, 0.6329680489331897, 0.9564967353668664], 
             414 -> RGBColor[
              0.9925524587883872, 0.9864787873473095, 0.4307592838916761], 
             281 -> RGBColor[
              0.9934222051111036, 0.9883390867867577, 0.5254258036672474], 
             289 -> RGBColor[
              0.9890829783668335, 0.9897535452470964, 0.8305868310152998], 
             398 -> RGBColor[
              0.6317772179683236, 0.7119442326428371, 0.9641549633561216], 
             178 -> RGBColor[
              0.9728996623668278, 0.979309193082686, 0.9307579820996137], 58 -> 
             RGBColor[
              0.9456278325369345, 0.9589699070490746, 0.9769220763692325], 
             186 -> RGBColor[
              0.9925384584976459, 0.9864488421410605, 0.42923543864427377`], 
             122 -> RGBColor[
              0.9875637516212081, 0.9891253059454338, 0.8557643498230968], 
             249 -> RGBColor[
              0.6596259343346386, 0.734024060335781, 0.9667090066458012], 113 -> 
             RGBColor[
              0.992811578701251, 0.9912954173060358, 0.768794274165652], 52 -> 
             RGBColor[
              0.9864100276801119, 0.9886482114464377, 0.8748845412689116], 
             409 -> RGBColor[
              0.7509227865003558, 0.8053458551294153, 0.975808623652089], 187 -> 
             RGBColor[
              0.8849380430660418, 0.9110895908103319, 0.9888873746127979], 
             259 -> RGBColor[
              0.9456278325369345, 0.9589699070490746, 0.9769220763692325], 42 -> 
             RGBColor[
              0.9481060494402355, 0.9608181571578488, 0.9727271015744298], 
             134 -> RGBColor[
              0.4017445986321872, 0.5223927118897236, 0.9468197884694112], 
             470 -> RGBColor[
              0.9272687230231438, 0.7493517535877369, 0.26033691120317437`], 
             313 -> RGBColor[
              0.9930300548765545, 0.9913857628191054, 0.7651735585426552], 
             248 -> RGBColor[
              0.8361267258854741, 0.8721687714384558, 0.9842317076057381], 
             174 -> RGBColor[
              0.9946866659904383, 0.9910436407510489, 0.6630545670348296], 
             215 -> RGBColor[
              0.9935933929658938, 0.9887052402984069, 0.5440585452121803], 
             399 -> RGBColor[
              0.9793803232720479, 0.9421071300455963, 0.37439687892146906`], 
             422 -> RGBColor[
              0.9927374125528239, 0.9912647476976781, 0.7700233991809281], 83 -> 
             RGBColor[
              0.9897293299086648, 0.9900208282201205, 0.8198751132629846], 95 -> 
             RGBColor[
              0.9908898535201842, 0.9905007345575803, 0.8006422336812754], 
             166 -> RGBColor[
              0.9923206082038829, 0.9910923883880078, 0.7769309258979589], 
             384 -> RGBColor[
              0.9886410501720249, 0.9895707965815064, 0.8379107248767853], 
             233 -> RGBColor[
              0.7658106895817979, 0.8169763981688919, 0.9772925106958826], 
             295 -> RGBColor[
              0.870772317304098, 0.8997942256061402, 0.987536235043731], 499 -> 
             RGBColor[
              0.9917549610033508, 0.9908584787341178, 0.7863051638588054], 
             141 -> RGBColor[
              0.9470405228984409, 0.9600234892076178, 0.9745307600758579], 
             319 -> RGBColor[
              0.8232515881633662, 0.8619024861051503, 0.9830036654760322], 
             205 -> RGBColor[
              0.5365576828274754, 0.6346407244243223, 0.956658932749184], 468 -> 
             RGBColor[
              0.855592668525406, 0.8876903857106008, 0.9860883865921869], 486 -> 
             RGBColor[
              0.9902477509778848, 0.9902352086550568, 0.8112835345152896], 
             224 -> RGBColor[
              0.9932285206541148, 0.9879248153177613, 0.504344445805933], 231 -> 
             RGBColor[
              0.9861134118078136, 0.9885255531605621, 0.8798002338901638], 
             332 -> RGBColor[
              0.9920372103777312, 0.9848017822314832, 0.4235664952744751], 68 -> 
             RGBColor[
              0.9544195084949806, 0.8569955705206517, 0.28218307050465924`], 
             484 -> RGBColor[
              0.9754219030610333, 0.9811902760626344, 0.9264884865100534], 10 -> 
             RGBColor[
              0.9875924067420115, 0.989137155574289, 0.8552894603143094], 250 -> 
             RGBColor[
              0.517834608097045, 0.6194404888932543, 0.9551849837215219], 282 -> 
             RGBColor[
              0.9463832908438712, 0.9595333266174385, 0.9756432825106715], 
             374 -> RGBColor[
              0.9466264691127686, 0.8260987662466103, 0.2759126080915867], 
             232 -> RGBColor[
              0.8205884048698333, 0.8597789360370719, 0.9827496486760433], 
             489 -> RGBColor[
              0.6242602387616486, 0.7058416102868041, 0.96356319921737], 253 -> 
             RGBColor[
              0.7980319138455609, 0.842147863454118, 0.9805040212060341], 459 -> 
             RGBColor[
              0.8364592683427778, 0.8724339317672853, 0.9842634258021798], 
             415 -> RGBColor[
              0.7610053960729755, 0.8132224663582166, 0.9768135639469442], 55 -> 
             RGBColor[
              0.9935739259529737, 0.9886636023261877, 0.5419396809923053], 
             446 -> RGBColor[
              0.9946683196685598, 0.9910043998236486, 0.6610576831187343], 
             325 -> RGBColor[
              0.9939482532111503, 0.9917654614270817, 0.7499566359172843], 91 -> 
             RGBColor[
              0.9800401832971756, 0.9443329928528535, 0.37696031051498], 450 -> 
             RGBColor[
              0.9930508161919586, 0.9875447234418863, 0.48500241176504155`], 
             423 -> RGBColor[
              0.9936398787789769, 0.9888046687521548, 0.5491182390890846], 
             105 -> RGBColor[
              0.9675167262567634, 0.975294608145549, 0.9398698888393647], 36 -> 
             RGBColor[
              0.7742207816765851, 0.823546426032407, 0.978130750079112], 123 -> 
             RGBColor[
              0.9594488141537099, 0.8748734696485485, 0.2969667297463946], 94 -> 
             RGBColor[
              0.9939135162767967, 0.9893899516909965, 0.5789019920318876], 
             473 -> RGBColor[
              0.9846495350374952, 0.9879202024961184, 0.9040604603659835], 
             312 -> RGBColor[
              0.9618316087302564, 0.9710546568028057, 0.9494933098956173], 96 -> 
             RGBColor[
              0.6765063248429799, 0.747211149696617, 0.9683914862154546], 496 -> 
             RGBColor[
              0.711956050776978, 0.7749047450241521, 0.9719247836000316], 2 -> 
             RGBColor[
              0.8280758321442895, 0.8657492073049241, 0.9834638061735862], 
             262 -> RGBColor[
              0.9379133479690065, 0.7915541443870948, 0.2689018262960763], 
             272 -> RGBColor[
              0.9677915306644426, 0.9754995568228452, 0.9394047166576323], 97 -> 
             RGBColor[
              0.9705225385893814, 0.9775363380616495, 0.9347818326016544], 
             372 -> RGBColor[
              0.9378968502022964, 0.7914887362396443, 0.268888551805729], 356 -> 
             RGBColor[
              0.9900252200540854, 0.9901431863992819, 0.8149714478142146], 
             402 -> RGBColor[
              0.9437238570612777, 0.9575499252568035, 0.9801450102131846], 
             455 -> RGBColor[
              0.9631050646924458, 0.9720043981743138, 0.947337681122139], 428 -> 
             RGBColor[
              0.7993034860859929, 0.8431412253526505, 0.9806307596434422], 
             346 -> RGBColor[
              0.992506114173784, 0.9863796609028326, 0.42571495859792585`], 
             341 -> RGBColor[
              0.9942773402608276, 0.9901681344045913, 0.6185019874322906], 
             209 -> RGBColor[
              0.9946653709344503, 0.9920620080347511, 0.7380721394010265], 
             498 -> RGBColor[
              0.9081342712428495, 0.929585633513678, 0.9910998515638191], 378 -> 
             RGBColor[
              0.8368850853389176, 0.8727734666815127, 0.984304040607403], 419 -> 
             RGBColor[
              0.6571647622353577, 0.7321013739862221, 0.9664637000119057], 66 -> 
             RGBColor[
              0.9934222940505667, 0.9883392770192762, 0.525435484178933], 139 -> 
             RGBColor[
              0.9803341725028372, 0.9848538385692288, 0.91817329567014], 56 -> 
             RGBColor[
              0.9934490769592772, 0.9883965629528405, 0.5283506385071215], 
             335 -> RGBColor[
              0.2372288089839523, 0.3666728977903259, 0.9368212017718389], 
             314 -> RGBColor[
              0.8879227184459646, 0.9134694899414273, 0.989172055614986], 144 -> 
             RGBColor[
              0.9521748471865333, 0.9638526598549928, 0.9658396883023574], 
             298 -> RGBColor[
              0.6571896194519592, 0.7321207926327531, 0.9664661775469527], 
             204 -> RGBColor[
              0.8063905958098535, 0.8486777293329593, 0.9813371365079108], 
             452 -> RGBColor[0.178927, 0.305394, 0.933501], 466 -> 
             RGBColor[
              0.982350578227148, 0.9521264974581776, 0.38593575853645007`], 
             207 -> RGBColor[
              0.9937171907950725, 0.9889700313371395, 0.5575331749266351], 
             334 -> RGBColor[
              0.9881120771986133, 0.9893520526630154, 0.8466771759843872], 
             149 -> RGBColor[
              0.9930448570380175, 0.9875319774141691, 0.4843537946341857], 
             219 -> RGBColor[
              0.9371718124584562, 0.7886142031898232, 0.268305169418212], 400 -> 
             RGBColor[
              0.9928791255314863, 0.9871774944797244, 0.46631494292456016`], 
             9 -> RGBColor[
              0.6958017914834582, 0.7622849148871366, 0.9703146780037897], 11 -> 
             RGBColor[
              0.8654549253822151, 0.8955542816243894, 0.98702905745533], 44 -> 
             RGBColor[
              0.964610825509446, 0.9731273921261755, 0.9447888208242758], 153 -> 
             RGBColor[
              0.9902439978701078, 0.9902336566485406, 0.8113457332238859], 
             471 -> RGBColor[
              0.9823909263315381, 0.9863877622070487, 0.9146917479254605], 
             406 -> RGBColor[
              0.9437238570612777, 0.9575499252568035, 0.9801450102131846], 32 -> 
             RGBColor[
              0.9931226748746049, 0.9876984218980394, 0.4928237859107087], 
             162 -> RGBColor[
              0.9949557474796086, 0.9916191788480725, 0.6923424265525594], 
             493 -> RGBColor[
              0.9859570950020115, 0.9642921253902004, 0.39994639517324904`], 
             90 -> RGBColor[
              0.4196732906503759, 0.5379216437936165, 0.9479621888710903], 
             331 -> RGBColor[
              0.8888439270257047, 0.9142040366573713, 0.9892599213116943], 8 -> 
             RGBColor[
              0.4060094396651162, 0.5260867028353036, 0.9470915403687785], 
             364 -> RGBColor[
              0.9939379694904599, 0.9894422546424231, 0.5815635734313909], 
             342 -> RGBColor[
              0.9378113462490048, 0.9531403843738583, 0.9901533487885713], 
             163 -> RGBColor[
              0.5035372528754228, 0.6078332518358287, 0.954059443545538], 49 -> 
             RGBColor[
              0.9778894757442765, 0.937078151266777, 0.368605217799009], 338 -> 
             RGBColor[
              0.9942427991935902, 0.990094254554408, 0.6147424054262592], 76 -> 
             RGBColor[
              0.9130422362325307, 0.9334991115732891, 0.991567977645927], 369 -> 
             RGBColor[
              0.9940913525297521, 0.9897703254540651, 0.5982583706879601], 
             445 -> RGBColor[
              0.9631050646924458, 0.9720043981743138, 0.947337681122139], 82 -> 
             RGBColor[
              0.943644924508238, 0.9574910574879867, 0.9802786224365736], 67 -> 
             RGBColor[
              0.9643405087348244, 0.8913743040951556, 0.31597003947501523`], 
             430 -> RGBColor[
              0.9942757740792346, 0.9901647845005292, 0.6183315182312558], 
             211 -> RGBColor[
              0.9751727468871493, 0.9279139869134168, 
               0.35805123920026627`]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9V3c41W/cPkZ2skfWMY5xzsFxzjFCvnekUipFSBqEZKVlFlIpoUVlJUVG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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 54}], {
             RGBColor[
             0.7072067855909343, 0.7645535615720733, 0.8095869553172019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 70}], {
             RGBColor[
             0.9749491002957864, 0.9786327392812761, 0.816019665725169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 84}], {
             RGBColor[
             0.735787733446424, 0.7886709748127054, 0.8115843802993775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 131}], {
             RGBColor[
             0.9940751150662643, 0.9897355951615239, 0.5964910229933159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 135}], {
             RGBColor[
             0.9903366880340303, 0.9898230634126451, 0.7771776542540283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 147}], {
             RGBColor[
             0.7988798897663032, 0.8398920295824351, 0.8165512259590622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 170}], {
             RGBColor[
             0.8429186737422217, 0.8748984202396463, 0.8205283547651454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 171}], {
             RGBColor[
             0.9705470982255622, 0.9753497333449197, 0.8234711070040428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 265}], {
             RGBColor[
             0.9948063682754991, 0.9912996718350364, 0.6760834220468221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 266}], {
             RGBColor[
             0.7998429830321183, 0.8406739120824811, 0.816627044188874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 374}], {
             RGBColor[
             0.9706940456277303, 0.9086513653140503, 0.4735628448617471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 385}], {
             RGBColor[
             0.9184607577558179, 0.9340917099026482, 0.8280101190690455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 391}], {
             RGBColor[
             0.8236466749222944, 0.8598429882889032, 0.8186075020298436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 433}], {
             RGBColor[
             0.9815837933570031, 0.9481460028137751, 0.501488324667385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 47}], {
             RGBColor[
             0.9022814656226773, 0.9238669524150579, 0.9540745968177435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 54}], {
             RGBColor[
             0.6238638905917331, 0.7018261830337902, 0.9657123175880413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 55}], {
             RGBColor[
             0.9108248790486315, 0.9272064048155559, 0.7627017435829457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 230}], {
             RGBColor[
             0.8136896591151412, 0.8544452163287872, 0.9820472829085142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 242}], {
             RGBColor[
             0.8889393712391775, 0.9139164402695183, 0.976659282433481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 250}], {
             RGBColor[
             0.6729552201206672, 0.7425948480990892, 0.9693243949475541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 339}], {
             RGBColor[
             0.8806553392126188, 0.9076746790085115, 0.9884788864960434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 365}], {
             RGBColor[
             0.6616251613961034, 0.7333965960131594, 0.9684324512213838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 8}], {
             RGBColor[
             0.6720787843262349, 0.7397391296119956, 0.9683374019141657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 31}], {
             RGBColor[
             0.965393298059765, 0.9700271534432927, 0.7148520123953753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[
             0.9665519382334811, 0.9725053676183801, 0.8409628450060561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 203}], {
             RGBColor[
             0.9660309440322185, 0.9713910137024733, 0.7842558414021292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 221}], {
             RGBColor[
             0.9018172942989571, 0.7177394052816654, 0.5995271034705317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 223}], {
             RGBColor[
             0.9597229526608777, 0.9509833529264964, 0.6857145427238197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 258}], {
             RGBColor[
             0.8637303275491366, 0.8943638839373513, 0.9846091087917546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 381}], {
             RGBColor[
             0.9640929770345422, 0.9717699776454176, 0.9021729066724584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 439}], {
             RGBColor[
             0.9658034391678124, 0.970904403801779, 0.7594933409088069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 480}], {
             RGBColor[
             0.7182783678787577, 0.7785305711366957, 0.9716194805984175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 29}], {
             RGBColor[
             0.8941804841051645, 0.9184362857422526, 0.9889723112030224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 185}], {
             RGBColor[
             0.8090463017215679, 0.8510093091315512, 0.9815336532135719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 196}], {
             RGBColor[
             0.8713312843432155, 0.7410445826455248, 0.6081967459714497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 318}], {
             RGBColor[
             0.9167789039693524, 0.9174339821917069, 0.684734822549723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 321}], {
             RGBColor[
             0.92213538106908, 0.9379047741920266, 0.8798425355937549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 335}], {
             RGBColor[
             0.54449988400896, 0.6256579780449971, 0.961272535150526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 383}], {
             RGBColor[
             0.9144179349460155, 0.9335293434435747, 0.9547155857019789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 479}], {
             RGBColor[
             0.9205254653243551, 0.9372390326586353, 0.9065230058122382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 482}], {
             RGBColor[
             0.8274406755068952, 0.8653791337350675, 0.983367032487297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 496}], {
             RGBColor[
             0.7818635049054729, 0.8297739016619102, 0.9788243260646223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.8529788579460851, 0.8856062041046482, 0.985839079005755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 23}], {
             RGBColor[
             0.9000830338584587, 0.9225478226439785, 0.9689064150646498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 41}], {
             RGBColor[
             0.8286152910746977, 0.8662056759327689, 0.9835082760688983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 102}], {
             RGBColor[
             0.8485152552612653, 0.8820470484850401, 0.9854133365969717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 186}], {
             RGBColor[
             0.9165206245038005, 0.9310534843629839, 0.7069422696002269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 193}], {
             RGBColor[
             0.9131887093513891, 0.9320424682921058, 0.9342032984494604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 202}], {
             RGBColor[
             0.9042158250373055, 0.925630051538338, 0.9619106776034323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 211}], {
             RGBColor[
             0.9078377686985521, 0.9017860567491619, 0.6713501698782232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 212}], {
             RGBColor[
             0.9166009567124678, 0.9334535202666692, 0.877653529063289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 300}], {
             RGBColor[
             0.8473615188900939, 0.8811270904200077, 0.9853032921919368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 414}], {
             RGBColor[
             0.916527624649171, 0.9310684569661083, 0.7077041922239281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 485}], {
             RGBColor[
             0.7581278552571709, 0.8111403553477631, 0.9764827472091461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 24}], {
             RGBColor[
             0.9750661977606216, 0.9410638204385073, 0.6087080695476178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 77}], {
             RGBColor[
             0.9785893755396484, 0.9425207449916737, 0.5503198960573279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 79}], {
             RGBColor[
             0.9777994489001456, 0.9421940900260508, 0.5634110247385002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 80}], {
             RGBColor[
             0.8966781374619279, 0.8799637825509472, 0.6512730237398336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 81}], {
             RGBColor[
             0.7796321529397198, 0.7877211509442159, 0.6401298014381157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 99}], {
             RGBColor[
             0.9147111099821522, 0.8943427853465747, 0.6529930247570372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 156}], {
             RGBColor[
             0.9682845858227092, 0.9046786022259303, 0.3312920341849862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 267}], {
             RGBColor[
             0.7096421779467198, 0.7309001362324566, 0.6346199342249407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 278}], {
             RGBColor[
             0.8129420755350287, 0.8144819810704684, 0.6429446568936804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 329}], {
             RGBColor[
             0.9598372760691349, 0.9298394001539135, 0.6404554173447135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 406}], {
             RGBColor[
             0.9544309961582155, 0.9258074054483207, 0.6496068390502739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 413}], {
             RGBColor[
             0.9283942352760621, 0.9052533380373968, 0.6542981334626405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 486}], {
             RGBColor[
             0.977692943116519, 0.9421500471474473, 0.5651761012013264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 28}], {
             RGBColor[
             0.9437164972062214, 0.9260499280726695, 0.6683804674317925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 49}], {
             RGBColor[
             0.9467616185190919, 0.9363218372894668, 0.6802101887093859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 69}], {
             RGBColor[
             0.9413810276502741, 0.955285219660782, 0.9661712814696144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 142}], {
             RGBColor[
             0.9541637202031463, 0.961173183326467, 0.7189727021339247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 173}], {
             RGBColor[
             0.8899589230015292, 0.9150931041827342, 0.989366270623237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[
             0.954558866635395, 0.9620183615896141, 0.7619819527230836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 241}], {
             RGBColor[
             0.9547736387853519, 0.9624777375015767, 0.7853585758258252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 388}], {
             RGBColor[
             0.947097413760853, 0.9595484910623286, 0.9564949308566808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 402}], {
             RGBColor[
             0.9296788091775925, 0.9465577242844802, 0.9859800849164737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 436}], {
             RGBColor[
             0.8762594233164124, 0.9041694949968347, 0.9880596001135828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 461}], {
             RGBColor[
             0.9147545373232825, 0.9348644539838796, 0.9917312984525521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 487}], {
             RGBColor[
             0.951345054968125, 0.962240502543084, 0.9279942449597371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 31}], {
             RGBColor[
             0.6993239533986464, 0.7563747266666008, 0.6936061508499882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 40}], {
             RGBColor[
             0.6967310318130466, 0.7575830273186905, 0.9023487815555367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 114}], {
             RGBColor[
             0.6823796707802683, 0.7474215138632603, 0.9509006880489522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 115}], {
             RGBColor[
             0.6848596339994077, 0.7492710663715274, 0.9467027571969472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 162}], {
             RGBColor[
             0.7004825935723624, 0.758852940841688, 0.819716983460669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 203}], {
             RGBColor[
             0.6999615993710997, 0.7577385869257812, 0.763009979856742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 221}], {
             RGBColor[
             0.6357479496378383, 0.5040869785049733, 0.5782812419251446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 258}], {
             RGBColor[
             0.5976609828880178, 0.6807114571606593, 0.9633632472463673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 289}], {
             RGBColor[
             0.6975462090159747, 0.7579201240411999, 0.8888391856920392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 291}], {
             RGBColor[
             0.6966378981333865, 0.7575445141487247, 0.90389224764974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 297}], {
             RGBColor[
             0.5979742758252534, 0.6809562039843422, 0.9633944733584621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 311}], {
             RGBColor[
             0.699542473771974, 0.7568421196493496, 0.7173907449352748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 381}], {
             RGBColor[
             0.6980236323734235, 0.7581175508687257, 0.8809270451270712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 419}], {
             RGBColor[
             0.531587100950237, 0.6290940384107628, 0.9567776201903422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 439}], {
             RGBColor[
             0.6997340945066937, 0.757251977025087, 0.7382474793634197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 19}], {
             RGBColor[
             0.8363656883322859, 0.8722998089031619, 0.9471255259755108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 26}], {
             RGBColor[
             0.8237386712565694, 0.8042008042137473, 0.6251449479614544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 34}], {
             RGBColor[
             0.843206710251854, 0.8763352982319752, 0.8877839058354519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 44}], {
             RGBColor[
             0.8302063084964522, 0.867706153506656, 0.9575517494140328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.8453677604541636, 0.8769284996712441, 0.8301302875888237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 117}], {
             RGBColor[
             0.7018442469019348, 0.7670053269844126, 0.970916933489947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 139}], {
             RGBColor[
             0.8380679819931477, 0.8735693767281827, 0.9442439868369649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 247}], {
             RGBColor[
             0.8453375946968925, 0.876863978166667, 0.8268469310713307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 269}], {
             RGBColor[
             0.8448479987702944, 0.875816781985415, 0.7735574358969415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 360}], {
             RGBColor[
             0.671310059310315, 0.7431517875694184, 0.9678735710290207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 425}], {
             RGBColor[
             0.783447641207357, 0.8311676178127734, 0.978940773437397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 466}], {
             RGBColor[
             0.8390761848553031, 0.857205706172657, 0.6781252182701198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 468}], {
             RGBColor[
             0.7756972300044321, 0.8249876502988687, 0.9782015322979882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 120}], {
             RGBColor[
             0.9897977446730586, 0.9900491194833767, 0.818741303565244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 123}], {
             RGBColor[
             0.9735206104478606, 0.9320053126114187, 0.576128095030352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 125}], {
             RGBColor[
             0.8633720672640584, 0.8926436850863859, 0.9149624274202799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 177}], {
             RGBColor[
             0.8934479464140022, 0.9161391904634697, 0.9179601099788758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 245}], {
             RGBColor[
             0.9557399292555263, 0.965641973815429, 0.9239459321498735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 438}], {
             RGBColor[
             0.9834090491858949, 0.9653613383906363, 0.6145428122526476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 455}], {
             RGBColor[
             0.9753487357172287, 0.9805707768743015, 0.9013135707182243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 23}], {
             RGBColor[
             0.9125591012945888, 0.9324959001637197, 0.9700963935142247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 41}], {
             RGBColor[
             0.8410913585108277, 0.8761537534525101, 0.9846982545184733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 102}], {
             RGBColor[
             0.8609913226973953, 0.8919951260047814, 0.9866033150465467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 186}], {
             RGBColor[
             0.9289966919399305, 0.941001561882725, 0.7081322480498019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 193}], {
             RGBColor[
             0.9256647767875192, 0.941990545811847, 0.9353932768990354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 202}], {
             RGBColor[
             0.9166918924734355, 0.9355781290580791, 0.9631006560530072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 211}], {
             RGBColor[
             0.9203138361346822, 0.9117341342689032, 0.6725401483277982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 414}], {
             RGBColor[
             0.9290036920853011, 0.9410165344858494, 0.708894170673503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 485}], {
             RGBColor[
             0.770603922693301, 0.8210884328675043, 0.977672725658721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 497}], {
             RGBColor[
             0.6171581464373583, 0.6947325957300852, 0.96587677775701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 198}], {
             RGBColor[
             0.9718017527908378, 0.975482539416849, 0.7576395720196353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 373}], {
             RGBColor[
             0.7816601538337142, 0.8295955507694504, 0.9661163504526318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 480}], {
             RGBColor[
             0.724201594934292, 0.7829481041763191, 0.9615930022184328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 154}], {
             RGBColor[
             0.9729317643508453, 0.9574233808917803, 0.6561143880700482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 229}], {
             RGBColor[
             0.9844011836058186, 0.9649955386911522, 0.5927363912282297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 244}], {
             RGBColor[
             0.9867537961595383, 0.9659684044415001, 0.5537475128469738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 313}], {
             RGBColor[
             0.9858656607351931, 0.9656011376194941, 0.568466215249174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 334}], {
             RGBColor[
             0.9834066718962224, 0.964584282541449, 0.6092180239700399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 338}], {
             RGBColor[
             0.9864720328937109, 0.9649553834871454, 0.49325063869097596`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 340}], {
             RGBColor[
             0.9621645495653831, 0.9493932097344786, 0.6743404741624626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 363}], {
             RGBColor[
             0.9829838115977443, 0.9644094189410144, 0.6162259134431971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 379}], {
             RGBColor[
             0.9224320478849584, 0.9179676286569838, 0.6794277249534175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 380}], {
             RGBColor[
             0.8439951941727863, 0.8563189161100542, 0.6717089204971787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 390}], {
             RGBColor[
             0.9857079309250312, 0.9633210466386988, 0.4100828548909127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 478}], {
             RGBColor[
             0.9807029741171546, 0.9632191364113056, 0.6429597569918046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 63}], {
             RGBColor[
             0.81486045550251, 0.8555369900706915, 0.9821169697847136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 72}], {
             RGBColor[
             0.6246327081551771, 0.7017384377787463, 0.9661082553953674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 75}], {
             RGBColor[
             0.922515537748042, 0.9377205184687467, 0.8587149713547713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 149}], {
             RGBColor[
             0.9215183344818376, 0.9353781960516665, 0.7349539832619725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 158}], {
             RGBColor[
             0.9185250545889756, 0.9360703511317332, 0.9248476043398755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 163}], {
             RGBColor[
             0.6767645324005404, 0.7455288332624963, 0.9698068077176486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 182}], {
             RGBColor[
             0.9153866290583035, 0.9150289306697599, 0.682697074385649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 187}], {
             RGBColor[
             0.8674649274958499, 0.8971570027497479, 0.9872207732512785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 279}], {
             RGBColor[
             0.9200245538771705, 0.9366904326227758, 0.8999970205547223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 322}], {
             RGBColor[
             0.9211016850562395, 0.9371358540463295, 0.8821461693914163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 324}], {
             RGBColor[
             0.9218372213367092, 0.9374400172007239, 0.869956429717156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 441}], {
             RGBColor[
             0.8580775372016864, 0.6841924363061149, 0.59779492813679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 494}], {
             RGBColor[
             0.81943663058479, 0.8591119328251874, 0.9825730801501278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 78}], {
             RGBColor[
             0.8265754320074721, 0.8652256370015097, 0.9752080796164941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 97}], {
             RGBColor[
             0.9575141695543532, 0.9678347177345747, 0.9568016082519407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 104}], {
             RGBColor[
             0.9646347993609504, 0.9730502753294044, 0.9404941039596144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.7812649526793958, 0.8294559666208227, 0.9709468259067658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 148}], {
             RGBColor[
             0.8866411039716893, 0.9122204622119494, 0.981176005785704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 153}], {
             RGBColor[
             0.9673748991947163, 0.9741833770280204, 0.8950835585630565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 190}], {
             RGBColor[
             0.9213983960422553, 0.7945890347475006, 0.6078326164796684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 323}], {
             RGBColor[
             0.968536803211737, 0.9723223553417963, 0.7056255533165763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 356}], {
             RGBColor[
             0.9672655102867052, 0.974138141903391, 0.8968964158582209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 408}], {
             RGBColor[
             0.7475346308284275, 0.8020721718085237, 0.9682914514124175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 430}], {
             RGBColor[
             0.9693907872992797, 0.9741489409540147, 0.7985764510667415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 452}], {
             RGBColor[
             0.5617164002596624, 0.6317635487037501, 0.9561611919511135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 39}], {
             RGBColor[
             0.7431382569371097, 0.7982628064708613, 0.9615031014775431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 45}], {
             RGBColor[
             0.72354313783018, 0.7830528536829605, 0.9740107381863272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 52}], {
             RGBColor[
             0.7604536860779205, 0.8108081301898137, 0.915690638317889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 56}], {
             RGBColor[
             0.7639732107175032, 0.810682305943015, 0.742423686936994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 179}], {
             RGBColor[
             0.7377906148028617, 0.7942745437230996, 0.97055526472238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 200}], {
             RGBColor[
             0.7602631099247787, 0.8107293220529057, 0.9188489783707248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 236}], {
             RGBColor[
             0.7640888624168938, 0.8109296732338311, 0.7550116606961033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 243}], {
             RGBColor[
             0.6408491495733069, 0.7177031903752261, 0.9659672008023448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 254}], {
             RGBColor[
             0.7648349714319169, 0.8125255249737726, 0.8362210225302678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 276}], {
             RGBColor[
             0.7620247935695416, 0.8114578235132197, 0.8896533212858763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 283}], {
             RGBColor[
             0.7529144071321735, 0.8055538432793632, 0.9449546292256302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 292}], {
             RGBColor[
             0.7609749842183531, 0.8110237003676337, 0.9070513790545807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 422}], {
             RGBColor[
             0.7636173785142766, 0.8121163983154339, 0.8632600672738973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 454}], {
             RGBColor[
             0.7417413222271834, 0.797220974851469, 0.9638677475625246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 205}], {
             RGBColor[
             0.7290230474332586, 0.7874372936601943, 0.9745162570917631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 252}], {
             RGBColor[
             0.8094653206159537, 0.85190015009479, 0.9814258814691218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 282}], {
             RGBColor[
             0.9339358514414566, 0.9498835947567524, 0.9840084319725069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 293}], {
             RGBColor[
             0.8062820686903966, 0.8494133694969342, 0.9811086046663628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 298}], {
             RGBColor[
             0.7893390157455006, 0.8361773277644098, 0.9794198794906475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 418}], {
             RGBColor[
             0.9575392684899664, 0.9644660566097201, 0.7680382111464388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 432}], {
             RGBColor[
             0.9581494973936378, 0.9661779598737951, 0.8640195926424273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 467}], {
             RGBColor[
             0.9347771093555821, 0.9505110035316737, 0.9825844017590966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 52}], {
             RGBColor[
             0.8576166991027597, 0.8883649174272206, 0.9242452508337009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 56}], {
             RGBColor[
             0.8611362237423423, 0.8882390931804219, 0.7509782994528058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 65}], {
             RGBColor[
             0.8364559874089229, 0.8729517882762938, 0.9765667743453168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 88}], {
             RGBColor[
             0.8606879146568973, 0.8872802053776565, 0.7021826221450831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 166}], {
             RGBColor[
             0.8605719893646453, 0.8895870058980055, 0.8752684431482245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 167}], {
             RGBColor[
             0.8619462226137716, 0.8899715988629607, 0.8391416778742881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 210}], {
             RGBColor[
             0.8071453344359222, 0.8497966140063351, 0.9812719079262019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 227}], {
             RGBColor[
             0.8407438375185912, 0.8761496598673743, 0.9693085625600646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 243}], {
             RGBColor[
             0.738012162598146, 0.795259977612633, 0.9745218133181566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 326}], {
             RGBColor[
             0.7912107843041557, 0.6005332187595857, 0.5862824807270863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 348}], {
             RGBColor[
             0.861739586785482, 0.8895296257203364, 0.8166506431734846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 428}], {
             RGBColor[
             0.7640634283057002, 0.815611424380327, 0.9771183600209661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 434}], {
             RGBColor[
             0.8532690898544639, 0.8622852916758457, 0.6707663157959871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 469}], {
             RGBColor[
             0.8617713135451893, 0.8895974860512827, 0.8201039051727518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 474}], {
             RGBColor[
             0.6119989305866624, 0.694562804064699, 0.9635035283338358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 495}], {
             RGBColor[
             0.6002715485298515, 0.6850419869984388, 0.9625803058595076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 26}], {
             RGBColor[
             0.9643025681053969, 0.9142156982297727, 0.6019557959331755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 34}], {
             RGBColor[
             0.9837706071006815, 0.9863501922480006, 0.864594753807173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 44}], {
             RGBColor[
             0.9707702053452797, 0.9777210475226814, 0.9343625973857539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 139}], {
             RGBColor[
             0.9786318788419752, 0.9835842707442081, 0.921054834808686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 234}], {
             RGBColor[
             0.9240115380561846, 0.9411825118287986, 0.9557516214091182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 247}], {
             RGBColor[
             0.98590149154572, 0.9868788721826924, 0.8036577790430519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 269}], {
             RGBColor[
             0.985411895619122, 0.9858316760014403, 0.7503682838686626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 360}], {
             RGBColor[
             0.8118739561591426, 0.8531666815854437, 0.944684419000742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 393}], {
             RGBColor[
             0.7417817691188676, 0.7963309977334334, 0.9391198005373103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 466}], {
             RGBColor[
             0.9796400817041306, 0.9672206001886825, 0.654936066241841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 468}], {
             RGBColor[
             0.9162611268532597, 0.935002544314894, 0.9550123802697095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 62}], {
             RGBColor[
             0.8929946414250609, 0.9126505336361308, 0.7159806103480026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 194}], {
             RGBColor[
             0.9931154891653449, 0.9876830523925191, 0.49204166580282127`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 228}], {
             RGBColor[
             0.9845010861279428, 0.9592300726664051, 0.4070954092274125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 388}], {
             RGBColor[
             0.9856540362908031, 0.9852131818652335, 0.6865546439364186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 490}], {
             RGBColor[
             0.9779756916117099, 0.9794866849757013, 0.6995520786450989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 33}], {
             RGBColor[
             0.8013230548911664, 0.8448324344570339, 0.9808019302251749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 65}], {
             RGBColor[
             0.8890579421630107, 0.9141583417243409, 0.9817795244391654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 119}], {
             RGBColor[
             0.9138246563515963, 0.9310626455768832, 0.869697207554252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 164}], {
             RGBColor[
             0.890251902264333, 0.9150487952129769, 0.9797584614222938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 166}], {
             RGBColor[
             0.913173944118733, 0.9307935593460527, 0.8804811932420731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 175}], {
             RGBColor[
             0.8486184174700324, 0.8821293072300476, 0.9854231763005379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 227}], {
             RGBColor[
             0.8933457922726791, 0.9173562133154214, 0.9745213126539132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 309}], {
             RGBColor[
             0.7306084647341635, 0.7893572840718837, 0.9739126368712641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 320}], {
             RGBColor[
             0.8574129028956641, 0.8891417911884987, 0.9862620021713645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 337}], {
             RGBColor[
             0.8709585677121445, 0.8999427366258839, 0.9875539997739182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 348}], {
             RGBColor[
             0.9143415415395699, 0.9307361791683835, 0.8218633932673332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 375}], {
             RGBColor[
             0.8971281972926528, 0.9201771247861981, 0.9681186875643214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 428}], {
             RGBColor[
             0.8166653830597881, 0.856817977828374, 0.9823311101148147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 489}], {
             RGBColor[
             0.7291437593976159, 0.7881681702954508, 0.9737973299017786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 63}], {
             RGBColor[
             0.8857961076227987, 0.9093763845628253, 0.8815962602964433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 149}], {
             RGBColor[
             0.9924539866021265, 0.9892175905438003, 0.6344332737737022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 160}], {
             RGBColor[
             0.8531622868198208, 0.8838825957253147, 0.8783436260191967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 165}], {
             RGBColor[
             0.9910475543098842, 0.9905659478868467, 0.798028723479385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 182}], {
             RGBColor[
             0.9863222811785923, 0.9688683251618938, 0.5821763648973786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 268}], {
             RGBColor[
             0.9677540203372367, 0.9741971305807091, 0.8823956876748961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 275}], {
             RGBColor[
             0.7045450553813565, 0.763352994389788, 0.8661595329814645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 282}], {
             RGBColor[
             0.9691232035050532, 0.9752182651454351, 0.8800780177119449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 285}], {
             RGBColor[
             0.9928728773204762, 0.9901135554340024, 0.6800269433722277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 324}], {
             RGBColor[
             0.9927728734569979, 0.9912794116928578, 0.7694357202288857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 353}], {
             RGBColor[
             0.9209849643392105, 0.9371096583543425, 0.8850389468307915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 441}], {
             RGBColor[
             0.9290131893219752, 0.7380318307982487, 0.4972742186485196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 481}], {
             RGBColor[
             0.9909943073246419, 0.9846281663964254, 0.6003263042366749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 41}], {
             RGBColor[
             0.8881955344232014, 0.9130953719918404, 0.9677655905773681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 186}], {
             RGBColor[
             0.9761008678523042, 0.9779431804220553, 0.6911995841086966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 202}], {
             RGBColor[
             0.9637960683858092, 0.9725197475974094, 0.946167992111902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 211}], {
             RGBColor[
             0.9674180120470559, 0.9486757528082335, 0.6556074843866928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 212}], {
             RGBColor[
             0.9761812000609715, 0.9803432163257406, 0.8619108435717587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 485}], {
             RGBColor[
             0.8177080986056746, 0.8580300514068346, 0.9607400617176158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 497}], {
             RGBColor[
             0.6642623223497319, 0.7316742142694155, 0.9489441138159047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 77}], {
             RGBColor[
             0.9885174380451167, 0.9895196797903432, 0.8399592977175825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 81}], {
             RGBColor[
             0.7895602154451882, 0.8347200857428854, 0.9297692030983702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 83}], {
             RGBColor[
             0.9873617950873774, 0.9890417917286486, 0.8591112922354285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 176}], {
             RGBColor[
             0.9641667247312191, 0.9005642760181374, 0.5858075283581651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 197}], {
             RGBColor[
             0.7677788607018101, 0.817037000723362, 0.9280544950652401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 237}], {
             RGBColor[
             0.845960006452928, 0.8795188965624285, 0.9348854408501976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 267}], {
             RGBColor[
             0.7195702404521882, 0.777899071031126, 0.9242593358851952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 270}], {
             RGBColor[
             0.9852707089620625, 0.9881770738773688, 0.8937660008893173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 278}], {
             RGBColor[
             0.822870138040497, 0.8614809158691379, 0.9325840585539349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 329}], {
             RGBColor[
             0.9697653385746035, 0.9768383349525829, 0.930094819004968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 426}], {
             RGBColor[
             0.9845925010119208, 0.987896408421084, 0.9049963005418984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 448}], {
             RGBColor[
             0.9890596289741767, 0.9878830726929627, 0.6957120401987429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 489}], {
             RGBColor[
             0.8046272495138693, 0.8469521827619904, 0.9309553352126212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[
             0.840513012882669, 0.8760865759700405, 0.9845385413180763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 96}], {
             RGBColor[
             0.7222450571878936, 0.7829425950317044, 0.9729502956028401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 157}], {
             RGBColor[
             0.793865435345902, 0.8388929787837751, 0.9800887455671434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.8812763764031165, 0.9047329634538606, 0.8138762288276056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 246}], {
             RGBColor[
             0.8812112232488518, 0.9045936074448828, 0.8067847100645544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 288}], {
             RGBColor[
             0.867738999439328, 0.8969759277185243, 0.958708554543209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 333}], {
             RGBColor[
             0.867456670486702, 0.8593908967223269, 0.6517685432387383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 343}], {
             RGBColor[
             0.8621338521326393, 0.8927956180347822, 0.968196606876883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 392}], {
             RGBColor[
             0.8796493840173354, 0.904675287514755, 0.8855529587684443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 459}], {
             RGBColor[
             0.8022215289377925, 0.8455539860670386, 0.9808862653962027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 465}], {
             RGBColor[
             0.8773778278320574, 0.9037359406558114, 0.9231985233574664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 492}], {
             RGBColor[
             0.8558143570205227, 0.8880825489273892, 0.9788938637133996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 34}], {
             RGBColor[
             0.9711435900249652, 0.9182511875585859, 0.5426141757931165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 44}], {
             RGBColor[
             0.9581431882695632, 0.9096220428332668, 0.6123820193716975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 106}], {
             RGBColor[
             0.9733046402272749, 0.9188443889978548, 0.48496055754648837`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 117}], {
             RGBColor[
             0.8297811266750461, 0.8089212163110233, 0.6257472034476117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 139}], {
             RGBColor[
             0.9660048617662589, 0.9154852660547934, 0.5990742567946296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 215}], {
             RGBColor[
             0.9726344719977872, 0.9174109669193824, 0.4120168815656497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 224}], {
             RGBColor[
             0.9724520358418978, 0.9170207544290596, 0.392159831862526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 247}], {
             RGBColor[
             0.9732744744700037, 0.9187798674932777, 0.4816772010289954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 269}], {
             RGBColor[
             0.9727848785434056, 0.9177326713120257, 0.42838770585460617`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 351}], {
             RGBColor[
             0.9711448026632994, 0.9182516890157005, 0.5425940792377109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 360}], {
             RGBColor[
             0.7992469390834261, 0.7850676768960291, 0.6227038409866854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 425}], {
             RGBColor[
             0.9113845209804683, 0.8730835071393841, 0.6337710433950617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 466}], {
             RGBColor[
             0.9670130646284143, 0.8991215954992677, 0.33295548822778454`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 468}], {
             RGBColor[
             0.9036341097775433, 0.8669035396254794, 0.6330318022556529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 40}], {
             RGBColor[
             0.8555005894772987, 0.886520124613283, 0.9153431194122651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 114}], {
             RGBColor[
             0.8411492284445206, 0.8763586111578527, 0.9638950259056807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 199}], {
             RGBColor[
             0.7716478180763087, 0.8215364073126235, 0.9778743011131483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 220}], {
             RGBColor[
             0.8574366209865693, 0.8873207233961067, 0.8832580670147143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 277}], {
             RGBColor[
             0.8586065903489446, 0.8878045357942901, 0.8638686468965046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 289}], {
             RGBColor[
             0.856315766680227, 0.8868572213357924, 0.9018335235487676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 291}], {
             RGBColor[
             0.8554074557976387, 0.8864816114433172, 0.9168865855064685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 297}], {
             RGBColor[
             0.7567438334895056, 0.8098933012789347, 0.9763888112151904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 311}], {
             RGBColor[
             0.8583120314362263, 0.885779216943942, 0.7303850827920033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 319}], {
             RGBColor[
             0.7734000715784933, 0.8229316917648194, 0.9780419407791339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 349}], {
             RGBColor[
             0.8587393205622968, 0.8866931451790498, 0.7768928672419821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 359}], {
             RGBColor[
             0.5006538280653744, 0.5966168510183739, 0.9561047790165018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 371}], {
             RGBColor[
             0.8593822108641413, 0.888068222528515, 0.8468675091387163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 419}], {
             RGBColor[
             0.6903566586144891, 0.7580311357053553, 0.9697719580470705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 488}], {
             RGBColor[
             0.8580929658851073, 0.8875921388789467, 0.8723807334797906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 69}], {
             RGBColor[
             0.9694637635625883, 0.9457696244212946, 0.6427365892816441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 142}], {
             RGBColor[
             0.9822464561154606, 0.9516575880869795, 0.39553800994595445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 173}], {
             RGBColor[
             0.9180416589138434, 0.9055775089432468, 0.6659315784352666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 194}], {
             RGBColor[
             0.9826416025477092, 0.9525027663501268, 0.43854726053511317`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 241}], {
             RGBColor[
             0.9828563746976662, 0.9529621422620893, 0.46192388363785486`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 417}], {
             RGBColor[
             0.9261848222015048, 0.912070646308549, 0.6667082806191316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 461}], {
             RGBColor[
             0.9428372732355967, 0.9253488587443923, 0.6682966062645819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 493}], {
             RGBColor[
             0.9788781640602735, 0.9404132291116912, 0.3724460852085356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 77}], {
             RGBColor[
             0.9643153125002524, 0.9716030587641731, 0.8868959390520621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 172}], {
             RGBColor[
             0.933069313559403, 0.9494451827399079, 0.9926815624728356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 318}], {
             RGBColor[
             0.959188429040549, 0.9512272096342911, 0.6879832652235323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 321}], {
             RGBColor[
             0.9645449061402767, 0.9716980016346106, 0.8830909782675642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 383}], {
             RGBColor[
             0.9568274600172124, 0.9673225708861589, 0.9579640283757882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 479}], {
             RGBColor[
             0.9629349903955519, 0.9710322601012195, 0.9097714484860475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 482}], {
             RGBColor[
             0.8698502005780919, 0.8991723611776516, 0.9866154751611063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 43}], {
             RGBColor[
             0.9219565336715364, 0.939394300701346, 0.9503686650105607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 64}], {
             RGBColor[
             0.7540119868661761, 0.8080921493531957, 0.9760281616517019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 110}], {
             RGBColor[
             0.9026108940657429, 0.9249663543589228, 0.9831157867122735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 217}], {
             RGBColor[
             0.9273113794169527, 0.940263025352454, 0.7570379405904462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 290}], {
             RGBColor[
             0.884658093702348, 0.9108663667867454, 0.988860672792575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 316}], {
             RGBColor[
             0.9007030471695625, 0.923543485267564, 0.986345273861344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 355}], {
             RGBColor[
             0.8587201572998495, 0.8901841603659206, 0.9863866892634354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 378}], {
             RGBColor[
             0.849033500750382, 0.8824602833706627, 0.9854627673143669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 384}], {
             RGBColor[
             0.9249114831669356, 0.9408589483206596, 0.9122661094490581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[
             0.9900455455465768, 0.9878710511499877, 0.6488633920367464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 114}], {
             RGBColor[
             0.9756941845137985, 0.9777095376945574, 0.6974152985301618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 162}], {
             RGBColor[
             0.9937971073058927, 0.9891409646729852, 0.5662315939418786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 203}], {
             RGBColor[
             0.9932761131046299, 0.9880266107570783, 0.5095245903379517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 208}], {
             RGBColor[
             0.9910753362634579, 0.9882968960758323, 0.63179709484508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 221}], {
             RGBColor[
             0.9290624633713686, 0.7343750023362705, 0.3247958524063543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 223}], {
             RGBColor[
             0.9869681217332893, 0.9676189499811015, 0.41098329165964226`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 258}], {
             RGBColor[
             0.8909754966215481, 0.9109994809919564, 0.709877857727577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 289}], {
             RGBColor[
             0.990860722749505, 0.9882081478724971, 0.6353537961732488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 297}], {
             RGBColor[
             0.8912887895587835, 0.9112442278156393, 0.7099090838396718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 314}], {
             RGBColor[
             0.9402805927890706, 0.9500661202196625, 0.7146464084730919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 381}], {
             RGBColor[
             0.9913381461069537, 0.9884055747000228, 0.6274416556082809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 397}], {
             RGBColor[
             0.9938125710982324, 0.9894288130237382, 0.586434029896189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 419}], {
             RGBColor[
             0.8249016146837671, 0.85938206224206, 0.7032922306715519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 472}], {
             RGBColor[
             0.9001671846429673, 0.9181800975337054, 0.7107939992883439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 103}], {
             RGBColor[
             0.9930473013888748, 0.987537205633491, 0.4846198471402142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 155}], {
             RGBColor[
             0.9938458190740154, 0.9892451542194843, 0.571533569287847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 331}], {
             RGBColor[
             0.9409833009501548, 0.9509512292777054, 0.7410418536112015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 344}], {
             RGBColor[
             0.9529549108025309, 0.9604970660132974, 0.7421837164461034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 403}], {
             RGBColor[
             0.9939046704325216, 0.9893710313245441, 0.5779391764727692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 449}], {
             RGBColor[
             0.9614481447609593, 0.8734906180349788, 0.3775880958560267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 119}], {
             RGBColor[
             0.8811204312091795, 0.9054003497298196, 0.8664676771932396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 159}], {
             RGBColor[
             0.8583722698694793, 0.8900014792868991, 0.9751331106278899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 164}], {
             RGBColor[
             0.8575476771219163, 0.8893864993659133, 0.9765289310612815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 227}], {
             RGBColor[
             0.8606415671302623, 0.8916939174683578, 0.9712917822929008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 267}], {
             RGBColor[
             0.611382525193518, 0.6934527627175229, 0.9638718002133402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 270}], {
             RGBColor[
             0.8770829937033923, 0.9037307655637655, 0.9333784652174625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 309}], {
             RGBColor[
             0.6979042395917467, 0.7636949882248201, 0.9706831065102517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 443}], {
             RGBColor[
             0.8757682593707156, 0.8866048169221163, 0.6828556383174142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 489}], {
             RGBColor[
             0.6964395342551991, 0.7625058744483872, 0.9705677995407662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 234}], {
             RGBColor[
             0.9308525599757529, 0.9452180011576119, 0.8964100012690592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 269}], {
             RGBColor[
             0.9922529175386902, 0.9898671653302535, 0.6910266637286037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 332}], {
             RGBColor[
             0.9913244196989905, 0.9875937319041486, 0.6144098144707946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 360}], {
             RGBColor[
             0.8187149780787107, 0.857202170914257, 0.885342798860683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 393}], {
             RGBColor[
             0.7486227910384358, 0.8003664870622467, 0.8797781803972513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 468}], {
             RGBColor[
             0.9231021487728279, 0.9390380336437073, 0.8956707601296505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 54}], {
             RGBColor[
             0.6184854745195884, 0.33601507938132813`, 0.5560894145012482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 67}], {
             RGBColor[
             0.8908297543674122, 0.5127506520475777, 0.2400940197375076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 70}], {
             RGBColor[
             0.8862277892244405, 0.550094257090531, 0.5625221249092153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 84}], {
             RGBColor[
             0.6470664223750779, 0.3601324926219602, 0.5580868394834237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 131}], {
             RGBColor[
             0.9053538039949183, 0.5611971129707787, 0.34299348217736214`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 135}], {
             RGBColor[
             0.9016153769626843, 0.5612845812219, 0.5236801134380745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 147}], {
             RGBColor[
             0.7101585786949571, 0.41135354739168994`, 0.5630536851431084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 171}], {
             RGBColor[
             0.8818257871542162, 0.5468112511541745, 0.5699735661880891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 216}], {
             RGBColor[
             0.9059702747535108, 0.5625156815886536, 0.4100925198336395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 281}], {
             RGBColor[
             0.9053706025555518, 0.5612330433933789, 0.3448219018336237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 385}], {
             RGBColor[
             0.829739446684472, 0.505553227711903, 0.5745125782530918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 391}], {
             RGBColor[
             0.7349253638509484, 0.43130450609815796`, 0.5651099612138899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 37}], {
             RGBColor[
             0.883250488253514, 0.9073110512259606, 0.8778657150807145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 58}], {
             RGBColor[
             0.8599243071067598, 0.8912581665407409, 0.9775264132241722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 141}], {
             RGBColor[
             0.860630652287513, 0.8917849576200124, 0.9763307550774849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 240}], {
             RGBColor[
             0.798234152766051, 0.49777811003941713`, 0.5735341550445633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 251}], {
             RGBColor[
             0.8710838403783964, 0.8995809281826687, 0.9586362342677135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 310}], {
             RGBColor[
             0.7666574010458361, 0.817637855599844, 0.9773769029816495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 352}], {
             RGBColor[
             0.8836728896794241, 0.9056249080905778, 0.7356036796343627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 367}], {
             RGBColor[
             0.7640640581029718, 0.8156119163827421, 0.9771184227932724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 382}], {
             RGBColor[
             0.7603177669391539, 0.8126852852527, 0.9767450275011444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 399}], {
             RGBColor[
             0.8768005524743165, 0.8828267780390017, 0.6762638145002905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 412}], {
             RGBColor[
             0.8536160003939042, 0.7978326315179977, 0.6215441042142312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 416}], {
             RGBColor[
             0.589329434664358, 0.6741360513662557, 0.9625610826435576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 429}], {
             RGBColor[
             0.880743569139121, 0.9062743757472764, 0.9194118525049068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 58}], {
             RGBColor[
             0.9689540136836887, 0.9750227917342944, 0.8772613782257748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 118}], {
             RGBColor[
             0.9823788493121542, 0.9850350121648531, 0.854536633264683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 141}], {
             RGBColor[
             0.9696603588644419, 0.975549582813566, 0.8760657200790875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 188}], {
             RGBColor[
             0.8957918404582179, 0.9171084508860823, 0.8791157198628796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 240}], {
             RGBColor[
             0.9072638593429799, 0.5815427352329707, 0.4732691200461657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 304}], {
             RGBColor[
             0.9601508745630913, 0.9682594448068245, 0.885298699228654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 310}], {
             RGBColor[
             0.875687107622765, 0.9014024807933976, 0.8771118679832519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 429}], {
             RGBColor[
             0.9897732757160499, 0.99003900094083, 0.8191468175065093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 47}], {
             RGBColor[
             0.9559148995368394, 0.8816735396121264, 0.595759405019608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 73}], {
             RGBColor[
             0.8687839999769752, 0.8133930751366811, 0.6238777006619709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 93}], {
             RGBColor[
             0.9521190015971221, 0.8788425651438978, 0.6021848701028081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 108}], {
             RGBColor[
             0.9639929619479959, 0.8840176532461769, 0.35373596563764653`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 163}], {
             RGBColor[
             0.7194399764240182, 0.6945978167674449, 0.6104464330614263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 189}], {
             RGBColor[
             0.9638316540882483, 0.8862273850435345, 0.5218821742376369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 266}], {
             RGBColor[
             0.7701335219470791, 0.7357531207412664, 0.6144372146615777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 364}], {
             RGBColor[
             0.9646403347315368, 0.885402318170742, 0.42419849800435283`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 437}], {
             RGBColor[
             0.9293548858911486, 0.861547118450688, 0.6296930961288401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 45}], {
             RGBColor[
             0.9321840502915604, 0.9483476112206322, 0.979017104297004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 100}], {
             RGBColor[
             0.9593867427248712, 0.9692312797390901, 0.9536318303195557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 127}], {
             RGBColor[
             0.9715936464962998, 0.9771363082803073, 0.8792813124522985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 179}], {
             RGBColor[
             0.9464315272642421, 0.9595693012607713, 0.9755616308330567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 200}], {
             RGBColor[
             0.968904022386159, 0.9760240795905775, 0.9238553444814015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 213}], {
             RGBColor[
             0.8234780500640762, 0.8626771664628433, 0.9683809326558634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 236}], {
             RGBColor[
             0.9727297748782742, 0.9762244307715027, 0.76001802680678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 243}], {
             RGBColor[
             0.8494900620346872, 0.8829979479128978, 0.9709735669130215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 254}], {
             RGBColor[
             0.9734758838932973, 0.9778202825114441, 0.8412273886409445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 276}], {
             RGBColor[
             0.9706657060309218, 0.9767525810508915, 0.894659687396553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 283}], {
             RGBColor[
             0.9615553195935538, 0.9708486008170348, 0.949960995336307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 315}], {
             RGBColor[
             0.9583843063866984, 0.9684836643594197, 0.9553286935628125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 325}], {
             RGBColor[
             0.9728637113048202, 0.9776615127178073, 0.8582330517527521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 368}], {
             RGBColor[
             0.874550065177361, 0.9025750128310326, 0.9734713138272391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 401}], {
             RGBColor[
             0.9720498888011864, 0.9773249761982704, 0.8717201967430894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 450}], {
             RGBColor[
             0.9724149927952243, 0.9755511437252096, 0.7257559396766307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 454}], {
             RGBColor[
             0.9503822346885638, 0.9625157323891407, 0.9688741136732013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 471}], {
             RGBColor[
             0.967085047865014, 0.9749726631077908, 0.9406006077568402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 475}], {
             RGBColor[
             0.9730855897611177, 0.9777532651615026, 0.8545559515288628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 114}], {
             RGBColor[
             0.9731012629281988, 0.9789178383466473, 0.9061579292357104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 199}], {
             RGBColor[
             0.9035998525599869, 0.924095634501418, 0.920137204443178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 208}], {
             RGBColor[
             0.988482414677858, 0.9895051967279223, 0.8405397255506284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 220}], {
             RGBColor[
             0.9893886554702475, 0.9898799505849013, 0.8255209703447439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 289}], {
             RGBColor[
             0.9882678011639052, 0.989416448524587, 0.8440964268787974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 291}], {
             RGBColor[
             0.9873594902813169, 0.9890408386321118, 0.8591494888364981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 297}], {
             RGBColor[
             0.8886958679731838, 0.9124525284677292, 0.9186517145452202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 314}], {
             RGBColor[
             0.9376876712034707, 0.9512744208717525, 0.9233890391786403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 349}], {
             RGBColor[
             0.990691355045975, 0.9892523723678444, 0.7191557705720119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 359}], {
             RGBColor[
             0.6326058625490526, 0.6991760782071685, 0.8983676823465316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 371}], {
             RGBColor[
             0.9913342453478196, 0.9906274497173095, 0.789130412468746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 397}], {
             RGBColor[
             0.9912196495126324, 0.9906371136758281, 0.7951766606017374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 419}], {
             RGBColor[
             0.8223086930981673, 0.8605903628941498, 0.9120348613771003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 472}], {
             RGBColor[
             0.8975742630573674, 0.9193883981857953, 0.9195366299938923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 102}], {
             RGBColor[
             0.836627755826008, 0.8725945978329019, 0.98427251210969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 186}], {
             RGBColor[
             0.9046331250685431, 0.9216010337108456, 0.7058014451129452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 191}], {
             RGBColor[
             0.7076311595303509, 0.7708547720856098, 0.9719527142829428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 202}], {
             RGBColor[
             0.8923283256020482, 0.9161776008861998, 0.9607698531161506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 212}], {
             RGBColor[
             0.9047134572772105, 0.9240010696145309, 0.8765127045760073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 295}], {
             RGBColor[
             0.8437500544717692, 0.8782737254433854, 0.9849518433126738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 300}], {
             RGBColor[
             0.8354740194548367, 0.8716746397678694, 0.9841624677046551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 389}], {
             RGBColor[
             0.8971542976195132, 0.89639507646185, 0.674886768193173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 451}], {
             RGBColor[
             0.9043861187393993, 0.9238657067169292, 0.8819375512725203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 456}], {
             RGBColor[
             0.8182374363992186, 0.8579325712406944, 0.982517918862839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 485}], {
             RGBColor[
             0.7462403558219136, 0.8016879046956249, 0.9753419227218644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 85}], {
             RGBColor[0.952229882155853, 0.963893704845, 0.965746528454718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 95}], {
             RGBColor[
             0.9694979514802098, 0.9756594458577146, 0.8866846676278526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[
             0.9593142940148085, 0.9691772476097491, 0.953754467088042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 137}], {
             RGBColor[
             0.9005202027216389, 0.9231944383105439, 0.979280967972565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 145}], {
             RGBColor[
             0.9485386659022239, 0.9611408018068552, 0.9719947947487275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 174}], {
             RGBColor[
             0.9713963577153368, 0.9759308989544488, 0.8178908343046296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 248}], {
             RGBColor[
             0.8921163876628548, 0.9164934642981524, 0.978479404590084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 286}], {
             RGBColor[
             0.8497599176783597, 0.8832737923814385, 0.974292331729834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 294}], {
             RGBColor[
             0.9181983136402977, 0.9372904840975449, 0.9809671219734226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 346}], {
             RGBColor[
             0.9703060818070097, 0.9735989090303407, 0.6992210300861779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 358}], {
             RGBColor[
             0.9681467042937736, 0.9751006704206544, 0.9090783304227232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 407}], {
             RGBColor[
             0.850396299418692, 0.8837709386336665, 0.9743557603143849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 411}], {
             RGBColor[
             0.9712907255712122, 0.9764008040165366, 0.8569737613893191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 430}], {
             RGBColor[
             0.971190911759735, 0.9754914708291891, 0.7955293099028428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 110}], {
             RGBColor[
             0.9633855115754328, 0.9722135550004559, 0.9468629577015035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 217}], {
             RGBColor[
             0.9880859969266427, 0.9875102259939872, 0.7207851115796762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 290}], {
             RGBColor[
             0.945432711212038, 0.9581135674282786, 0.9526078437818049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 316}], {
             RGBColor[
             0.9614776646792524, 0.9707906859090971, 0.9500924448505739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 340}], {
             RGBColor[
             0.9641794918590805, 0.9728057041959768, 0.9455189561845115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 355}], {
             RGBColor[
             0.9194947748095395, 0.9374313610074537, 0.9501338602526654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 362}], {
             RGBColor[
             0.988650057227326, 0.9887166939419042, 0.782179594332388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 378}], {
             RGBColor[
             0.9098081182600719, 0.9297074840121959, 0.9492099383035968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 384}], {
             RGBColor[
             0.9856861006766255, 0.9881061489621927, 0.876013280438288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 57}], {
             RGBColor[
             0.9166847964919194, 0.9356580338772313, 0.9660665008438662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 106}], {
             RGBColor[
             0.9797722774671576, 0.9823497382907636, 0.8173673589990668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 117}], {
             RGBColor[
             0.8362487639149287, 0.8724265656039321, 0.9581540049001902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 139}], {
             RGBColor[
             0.9724724990061415, 0.9789906153477022, 0.931481058247208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 140}], {
             RGBColor[
             0.9799069762548546, 0.9826378453775109, 0.8320284907753235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 247}], {
             RGBColor[
             0.9797421117098863, 0.9822852167861864, 0.8140840024815739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 255}], {
             RGBColor[
             0.9231975013276568, 0.9408510879305851, 0.966687688445059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 269}], {
             RGBColor[
             0.9792525157832883, 0.9812380206049345, 0.7607945073071846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 360}], {
             RGBColor[
             0.8057145763233089, 0.8485730261889378, 0.9551106424392639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 369}], {
             RGBColor[
             0.9793510890195991, 0.9814488587901202, 0.771523595756118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 370}], {
             RGBColor[
             0.9667072163595046, 0.9746908769896242, 0.9412401779414286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 425}], {
             RGBColor[
             0.9178521582203509, 0.9365888564322928, 0.9661778448476401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 466}], {
             RGBColor[
             0.9734807018682969, 0.9626269447921765, 0.6653622896803629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 468}], {
             RGBColor[
             0.910101747017426, 0.9304088889183881, 0.9654386037082314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 52}], {
             RGBColor[
             0.9494994794323712, 0.9608929349395845, 0.9332046411373498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 56}], {
             RGBColor[
             0.953019004071954, 0.960767110692786, 0.7599376897564547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 179}], {
             RGBColor[
             0.9268364081573124, 0.9443593484728705, 0.9880692675418408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 236}], {
             RGBColor[
             0.9531346557713445, 0.9610144779836018, 0.772525663515564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 243}], {
             RGBColor[
             0.8298949429277576, 0.8677879951249969, 0.9834812036218056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 254}], {
             RGBColor[
             0.9538807647863676, 0.9626103297235433, 0.8537350253497287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 276}], {
             RGBColor[
             0.9510705869239923, 0.9615426282629906, 0.9071673241053371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 283}], {
             RGBColor[
             0.9419602004866242, 0.955638648029134, 0.962468632045091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 292}], {
             RGBColor[
             0.9500207775728038, 0.9611085051174044, 0.9245653818740414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 386}], {
             RGBColor[
             0.9281253139162388, 0.9453206122774882, 0.9858874862924394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 422}], {
             RGBColor[
             0.9526631718687273, 0.9622012030652047, 0.8807740700933581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 53}], {
             RGBColor[
             0.9249246944991538, 0.795611880906959, 0.6007933307882449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 68}], {
             RGBColor[
             0.9259317783640677, 0.7420973853730205, 0.2591601046425207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 90}], {
             RGBColor[
             0.6585586694417653, 0.5825604220095029, 0.5920496638257362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 205}], {
             RGBColor[
             0.7170008655303151, 0.6309199623248558, 0.5963980357647831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 257}], {
             RGBColor[
             0.945562817617614, 0.8080465393246996, 0.3948975302800981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 272}], {
             RGBColor[
             0.9326177894487986, 0.8013493785241173, 0.5877709277190072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 293}], {
             RGBColor[
             0.7942598867874531, 0.6928960381615957, 0.6029903833393828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 298}], {
             RGBColor[
             0.7773168338425569, 0.6796599964290713, 0.6013016581636674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 306}], {
             RGBColor[
             0.5694627298773799, 0.4991709264566812, 0.5866002599877893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 317}], {
             RGBColor[
             0.9434008515757346, 0.8085331656426942, 0.5310859342487558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 357}], {
             RGBColor[
             0.9442992601978868, 0.8089046806960025, 0.5161969783727107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 418}], {
             RGBColor[
             0.9455170865870228, 0.8079487252743816, 0.38991998981945875`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 420}], {
             RGBColor[
             0.9445972871012789, 0.8090279224794973, 0.5112579013146007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 55}], {
             RGBColor[
             0.9850305125270193, 0.9853241499256897, 0.7333125342271032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 189}], {
             RGBColor[
             0.984403853652474, 0.9865385429565998, 0.8508081566799299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 230}], {
             RGBColor[
             0.8878952925935291, 0.912562961438921, 0.9526580735526715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 242}], {
             RGBColor[
             0.9631450047175654, 0.9720341853796521, 0.9472700730776384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 339}], {
             RGBColor[
             0.9548609726910067, 0.9657924241186453, 0.9590896771402009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 364}], {
             RGBColor[
             0.9852125342957625, 0.9857134760838073, 0.7531244804466459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 365}], {
             RGBColor[
             0.7358307948744912, 0.7915143411232932, 0.9390432418655412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 374}], {
             RGBColor[
             0.9615567841069168, 0.904041731885901, 0.6002989977767439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 437}], {
             RGBColor[
             0.9499270854553743, 0.9618582763637533, 0.9586190785711332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 78}], {
             RGBColor[
             0.8515023762088437, 0.8813312232298889, 0.7995299531710405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 85}], {
             RGBColor[
             0.9753567018967695, 0.9786567611982048, 0.793115543173163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 95}], {
             RGBColor[
             0.9926247712211262, 0.9904225022109193, 0.7140536823462975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 137}], {
             RGBColor[
             0.9236470224625553, 0.9379574946637488, 0.8066499826910101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 145}], {
             RGBColor[
             0.9716654856431403, 0.9759038581600601, 0.7993638094671724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 183}], {
             RGBColor[
             0.9685621499016577, 0.9735893954453083, 0.8046169473979118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 346}], {
             RGBColor[
             0.9934329015479262, 0.9883619653835455, 0.5265900448046228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 358}], {
             RGBColor[
             0.9912735240346899, 0.9898637267738593, 0.7364473451411682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 404}], {
             RGBColor[
             0.9160784745883971, 0.6409380759064724, 0.4056465680790661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 407}], {
             RGBColor[
             0.8735231191596085, 0.8985339949868714, 0.8017247750328298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 408}], {
             RGBColor[
             0.7724615750297992, 0.8181777580369028, 0.7926133249669638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 71}], {
             RGBColor[
             0.9845153097805779, 0.9638414004099534, 0.5825414604728041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 76}], {
             RGBColor[
             0.9454658559884036, 0.935288631420033, 0.6800865977224679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 238}], {
             RGBColor[
             0.9858928846761379, 0.9632156327053472, 0.47281631430913723`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 328}], {
             RGBColor[
             0.9642811131255802, 0.9499052749387724, 0.6684937819852275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 402}], {
             RGBColor[
             0.9608066664027771, 0.9473140382617902, 0.6743751140060967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 431}], {
             RGBColor[
             0.9852107838250407, 0.9617566879558254, 0.398573846105717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 436}], {
             RGBColor[
             0.907387280541597, 0.9049258089741448, 0.676454629203206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 459}], {
             RGBColor[
             0.9071743720435272, 0.9047560415170312, 0.6764343218005944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 462}], {
             RGBColor[
             0.985917784575231, 0.9644213597795006, 0.5592988236369771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 487}], {
             RGBColor[
             0.9824729121933097, 0.9629968165203941, 0.6163892740493604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 57}], {
             RGBColor[
             0.7821787536740274, 0.8301574825273008, 0.9788193102902034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 92}], {
             RGBColor[
             0.8305106378674768, 0.8285752625455473, 0.6452339751273063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 106}], {
             RGBColor[
             0.8452662346492656, 0.8768491869408331, 0.830120168445404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 117}], {
             RGBColor[
             0.7017427210970368, 0.7669260142540015, 0.9709068143465274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 139}], {
             RGBColor[
             0.8379664561882496, 0.8734900639977716, 0.9442338676935452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 140}], {
             RGBColor[
             0.8454009334369627, 0.8771372940275804, 0.8447813002216609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 169}], {
             RGBColor[
             0.8437321324145461, 0.8765152445979907, 0.8773836363797319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 204}], {
             RGBColor[
             0.7509946678417578, 0.8054020093796369, 0.9758157881124305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 219}], {
             RGBColor[
             0.8163852761660592, 0.7753702463080689, 0.6192998045675812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 244}], {
             RGBColor[
             0.8452025327994535, 0.877123292944716, 0.8530152967276027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 255}], {
             RGBColor[
             0.7886914585097649, 0.8353505365806546, 0.9794404978913963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 274}], {
             RGBColor[
             0.829692980155464, 0.8673197191190938, 0.9582387045489108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 334}], {
             RGBColor[
             0.8418554085361377, 0.8757391710446649, 0.9084858078506688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 338}], {
             RGBColor[
             0.8449207695336262, 0.8761102719903613, 0.7925184225716049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 340}], {
             RGBColor[
             0.8206132862052984, 0.8605480982376945, 0.9736082580430914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 361}], {
             RGBColor[
             0.8421396478464902, 0.8758567113041129, 0.9037752268903723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 363}], {
             RGBColor[
             0.8414325482376595, 0.8755643074442303, 0.9154936973238259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 369}], {
             RGBColor[
             0.8448450462017072, 0.8759483074401898, 0.7842764052024552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 370}], {
             RGBColor[
             0.8322011735416127, 0.8691903256396938, 0.953992987387766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 379}], {
             RGBColor[
             0.7808807845248735, 0.8291225171601997, 0.9786955088340464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[
             0.9152126818611799, 0.9351412144379166, 0.9887048583584237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 113}], {
             RGBColor[
             0.9659722536716342, 0.9727107178323551, 0.8783552643433724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 127}], {
             RGBColor[
             0.9652705261180634, 0.9724205354553781, 0.8899847059187349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 130}], {
             RGBColor[
             0.9665546066453901, 0.972951535752792, 0.8687041684870518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 143}], {
             RGBColor[
             0.9535682343238705, 0.9289282935256082, 0.6590582393890696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 179}], {
             RGBColor[
             0.9401084068860058, 0.954853528435842, 0.9862650242994931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 214}], {
             RGBColor[
             0.9641626806573057, 0.971962412887025, 0.9083445722156394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 302}], {
             RGBColor[
             0.766910979818534, 0.8179801950064128, 0.9745757499700864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 308}], {
             RGBColor[
             0.9642024324009282, 0.9719788512545862, 0.9076857829496001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 315}], {
             RGBColor[
             0.9520611860084622, 0.9637678915344905, 0.9660320870292489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 325}], {
             RGBColor[
             0.9665405909265838, 0.972945739892878, 0.8689364452191886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 347}], {
             RGBColor[
             0.8991935558429393, 0.9223679981785636, 0.9871769398183612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 386}], {
             RGBColor[
             0.9413973126449322, 0.9558147922404598, 0.9840832430500916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 421}], {
             RGBColor[
             0.8640774063688605, 0.894617589046721, 0.9837611200825882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 423}], {
             RGBColor[
             0.9663864037104972, 0.9714653435554146, 0.7685172468050887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 477}], {
             RGBColor[
             0.952840001092617, 0.9643487305490605, 0.9647137562392807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 56}], {
             RGBColor[
             0.9899295523196945, 0.9885223871996391, 0.7016175898880166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 88}], {
             RGBColor[
             0.9894812432342495, 0.9875634993968736, 0.6528219125802939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 166}], {
             RGBColor[
             0.9893653179419974, 0.9898702999172228, 0.8259077335834353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 210}], {
             RGBColor[
             0.9359386630132743, 0.9500799080255522, 0.9319111983614126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 227}], {
             RGBColor[
             0.9695371660959433, 0.9764329538865915, 0.9199478529952754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 236}], {
             RGBColor[
             0.9900452040190851, 0.988769754490455, 0.7142055636471258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 243}], {
             RGBColor[
             0.8668054911754981, 0.8955432716318501, 0.9251611037533674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 276}], {
             RGBColor[
             0.9879811351717329, 0.9892979047698438, 0.8488472242368988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 326}], {
             RGBColor[
             0.9200041128815079, 0.7008165127788027, 0.536921771162297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 428}], {
             RGBColor[
             0.8928567568830523, 0.9158947183995441, 0.9277576504561769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 469}], {
             RGBColor[
             0.9905646421225415, 0.9898807800704998, 0.7707431956079625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 495}], {
             RGBColor[
             0.7290648771072037, 0.785325281017656, 0.9132195962947183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 90}], {
             RGBColor[
             0.6860393157077643, 0.7509731026910726, 0.956705855833599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 178}], {
             RGBColor[
             0.9626525015659904, 0.9716668773356074, 0.9481037524478608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 257}], {
             RGBColor[
             0.973043463883613, 0.9764592200062693, 0.7595537222879609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 272}], {
             RGBColor[
             0.9600984357147977, 0.9697620592056869, 0.9524271197268701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[
             0.8217405330534522, 0.8613087188431654, 0.9676465753472456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 298}], {
             RGBColor[
             0.804797480108556, 0.8480726771106408, 0.9659578501715302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 306}], {
             RGBColor[
             0.596943376143379, 0.6675836071382508, 0.9512564519956522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 317}], {
             RGBColor[
             0.9708814978417337, 0.976945846324264, 0.8957421262566188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 357}], {
             RGBColor[
             0.9717799064638858, 0.9773173613775723, 0.8808531703805735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 418}], {
             RGBColor[
             0.9729977328530219, 0.9763614059559512, 0.7545761818273216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 420}], {
             RGBColor[
             0.972077933367278, 0.977440603161067, 0.8759140933224636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 432}], {
             RGBColor[
             0.9736079617566931, 0.9780733092200262, 0.8505575633233102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 55}], {
             RGBColor[
             0.7066129374960752, 0.7632833805444219, 0.7449502549974008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 70}], {
             RGBColor[
             0.6873942637440288, 0.751982336471859, 0.9543935394104635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 84}], {
             RGBColor[
             0.44823289689466633`, 0.5620205720032883, 0.9499582539846719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 131}], {
             RGBColor[
             0.7065202785145066, 0.7630851923521069, 0.7348648966786103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 135}], {
             RGBColor[
             0.7027818514822727, 0.7631726606032281, 0.9155515279393227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 147}], {
             RGBColor[
             0.5113250532145455, 0.6132416267730181, 0.9549250996443566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 230}], {
             RGBColor[
             0.6094777175625847, 0.6905221920576534, 0.9642957943229693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 242}], {
             RGBColor[
             0.6847274296866213, 0.7499934159983844, 0.9589077938479361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 365}], {
             RGBColor[
             0.457413219843547, 0.5694735717420254, 0.9506809626358388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 374}], {
             RGBColor[
             0.6831392090759727, 0.6820009625046333, 0.6119367185470415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 385}], {
             RGBColor[
             0.6309059212040603, 0.7074413070932312, 0.96638399275434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 391}], {
             RGBColor[
             0.5360918383705368, 0.6331925854794861, 0.956981375715138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 230}], {
             RGBColor[
             0.8964387060194833, 0.9159024138394191, 0.7612852203178737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 242}], {
             RGBColor[
             0.9716884181435197, 0.9753736377801501, 0.7558972198428406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 250}], {
             RGBColor[
             0.7557042670250094, 0.804052045609721, 0.7485623323569136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 339}], {
             RGBColor[
             0.9634043861169609, 0.9691318765191432, 0.7677168239054031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 365}], {
             RGBColor[
             0.7443742083004455, 0.7948537935237912, 0.7476703886307433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 88}], {
             RGBColor[
             0.9930007678738322, 0.9874376751500751, 0.4795549611993988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 164}], {
             RGBColor[
             0.9699628007271801, 0.9739997115373483, 0.7519180503827609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 166}], {
             RGBColor[
             0.99288484258158, 0.9897444756704241, 0.6526407822025402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 210}], {
             RGBColor[
             0.9394581876528569, 0.9499540837787537, 0.7586442469805176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 227}], {
             RGBColor[
             0.973056690735526, 0.9763071296397928, 0.7466809016143803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 236}], {
             RGBColor[
             0.9935647286586677, 0.9886439302436565, 0.5409386122662307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 243}], {
             RGBColor[
             0.8703250158150808, 0.8954174473850516, 0.7518941523724723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 276}], {
             RGBColor[
             0.9915006598113155, 0.9891720805230452, 0.6755802728560039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 326}], {
             RGBColor[
             0.9235236375210905, 0.7006906885320042, 0.36365481978140196`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 428}], {
             RGBColor[
             0.896376281522635, 0.9157688941527455, 0.7544906990752818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 495}], {
             RGBColor[
             0.7325844017467863, 0.7851994567708573, 0.7399526449138233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 92}], {
             RGBColor[
             0.9170906516678421, 0.8966064556465336, 0.6537588457005594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 106}], {
             RGBColor[
             0.9318462484496308, 0.9448803800418195, 0.8386450390186571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 139}], {
             RGBColor[
             0.9245464699886149, 0.941521257098758, 0.9527587382667984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 140}], {
             RGBColor[
             0.9319809472373279, 0.9451684871285668, 0.8533061707949139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 169}], {
             RGBColor[
             0.9303121462149114, 0.944546437698977, 0.8859085069529851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 175}], {
             RGBColor[
             0.8659841611904372, 0.8959762798921425, 0.9870795364391726]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 204}], {
             RGBColor[
             0.837574681642123, 0.8734332024806233, 0.9843406586856837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 219}], {
             RGBColor[
             0.9029652899664244, 0.8434014394090552, 0.6278246751408343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 255}], {
             RGBColor[
             0.87527147231013, 0.9033817296816409, 0.9879653684646494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 274}], {
             RGBColor[
             0.9162729939558293, 0.9353509122200802, 0.9667635751221639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 334}], {
             RGBColor[
             0.928435422336503, 0.9437703641456513, 0.9170106784239218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 337}], {
             RGBColor[
             0.8883243114325493, 0.9137897092879788, 0.9892103599125528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 361}], {
             RGBColor[
             0.9287196616468555, 0.9438879044050992, 0.9123000974636253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 363}], {
             RGBColor[
             0.9280125620380247, 0.9435955005452166, 0.924018567897079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 369}], {
             RGBColor[
             0.9314250600020724, 0.9439795005411762, 0.7928012757757084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 370}], {
             RGBColor[
             0.918781187341978, 0.93722151874068, 0.962517857961019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 466}], {
             RGBColor[
             0.9255546728507703, 0.9251575865432324, 0.6866399696999533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 118}], {
             RGBColor[
             0.9590526681654, 0.9689821274796333, 0.9541973314081407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 141}], {
             RGBColor[
             0.9463341777176877, 0.9594966981283461, 0.9757264182225451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 188}], {
             RGBColor[
             0.8724656593114637, 0.9010555662008626, 0.9787764180063373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 220}], {
             RGBColor[
             0.9684762597582263, 0.9748252282083998, 0.8851789971582128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 240}], {
             RGBColor[
             0.8839376781962257, 0.5654898505477509, 0.5729298181896235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 304}], {
             RGBColor[
             0.9368246934163371, 0.9522065601216048, 0.9849593973721117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 310}], {
             RGBColor[
             0.8523609264760108, 0.8853495961081779, 0.9767725661267097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 371}], {
             RGBColor[
             0.9704218496357984, 0.975572727340808, 0.8487884392822149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 382}], {
             RGBColor[
             0.8460212923693284, 0.8803970257610338, 0.9761406906462047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 429}], {
             RGBColor[
             0.9664470945692957, 0.9739861162556103, 0.918807515649967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 74}], {
             RGBColor[
             0.9197769655184329, 0.7007225815067503, 0.5406861908069807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 82}], {
             RGBColor[
             0.9648003287311, 0.9729757031951597, 0.9313460014974263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 105}], {
             RGBColor[
             0.9767362296053628, 0.9818774785239408, 0.9111416346988219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 153}], {
             RGBColor[
             0.9880998654120349, 0.9893470027754366, 0.8468795568910825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 195}], {
             RGBColor[
             0.9470371272777699, 0.8309439676399443, 0.5636707950923303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 263}], {
             RGBColor[
             0.9732885127762414, 0.9793061769579005, 0.9169777199819605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 323}], {
             RGBColor[
             0.9892617694290555, 0.9874859810892126, 0.6574215516446023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 342}], {
             RGBColor[
             0.9618835396014833, 0.9708003666380955, 0.9362833646734252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 395}], {
             RGBColor[
             0.9706657098135889, 0.9773500948027998, 0.9214174412611618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 447}], {
             RGBColor[
             0.9478094909113419, 0.8340061320721336, 0.5642922570016069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 453}], {
             RGBColor[
             0.9896641104525989, 0.9883465478556548, 0.7012138890963375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 463}], {
             RGBColor[
             0.9128866024629009, 0.6477602316855873, 0.5340879713634512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 116}], {
             RGBColor[
             0.9219827220793828, 0.9361202062281729, 0.7651311139764612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 118}], {
             RGBColor[
             0.9114219579437451, 0.9312587293025211, 0.9585312440176192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 133}], {
             RGBColor[
             0.8635445449311365, 0.8940309961085953, 0.9868468436624893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 151}], {
             RGBColor[
             0.9194424061202968, 0.936521594169517, 0.9127666273941213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 188}], {
             RGBColor[
             0.8248349490898088, 0.8633321680237502, 0.9831103306158158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 192}], {
             RGBColor[
             0.9182415545992737, 0.9360250112050974, 0.9326678448015915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 249}], {
             RGBColor[
             0.7549961732141317, 0.8087735855153155, 0.9761494541169953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 260}], {
             RGBColor[
             0.9220155188989467, 0.9375856424294708, 0.8701234896494816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 280}], {
             RGBColor[
             0.9184049940386754, 0.9360925976134922, 0.9299592303229935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 310}], {
             RGBColor[
             0.8047302162543559, 0.8476261979310655, 0.9811064787361881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 327}], {
             RGBColor[
             0.9211695452969445, 0.937235810604513, 0.8841434615441588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 483}], {
             RGBColor[
             0.9182185224481363, 0.936015486818703, 0.9330495471512332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 64}], {
             RGBColor[
             0.8164777346891596, 0.8562813759035703, 0.9226175315861185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 91}], {
             RGBColor[
             0.9830767975524946, 0.9664292730067079, 0.628380272202572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 172}], {
             RGBColor[
             0.9578310148751292, 0.9675932027277706, 0.9364713024795017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 303}], {
             RGBColor[
             0.9644252340977959, 0.9726697620454037, 0.930807820122374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 362}], {
             RGBColor[
             0.9903411875406196, 0.9896587198507457, 0.7650217932775747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 384}], {
             RGBColor[
             0.9873772309899193, 0.9890481748710342, 0.8588554793834746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 435}], {
             RGBColor[
             0.8880262618966022, 0.9121756291469714, 0.9297488201191546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 473}], {
             RGBColor[
             0.9853814734226545, 0.9882228778283403, 0.8919303471280737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 132}], {
             RGBColor[
             0.8911864900246557, 0.9140897215961755, 0.9049112680442601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 209}], {
             RGBColor[
             0.8939538237153826, 0.915234085194523, 0.8590493871588968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 233}], {
             RGBColor[
             0.7795264830390563, 0.8276912802615934, 0.9786595728063249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 75}], {
             RGBColor[
             0.887384181324894, 0.9100330938502743, 0.8552777692497255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 149}], {
             RGBColor[
             0.8863869780586897, 0.9076907714331941, 0.7315167811569269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 158}], {
             RGBColor[
             0.8833936981658277, 0.908382926513261, 0.92141040223483]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 165}], {
             RGBColor[
             0.8849805457664475, 0.9090391287762405, 0.8951122308626098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 182}], {
             RGBColor[
             0.8802552726351556, 0.8873415060512877, 0.6792598722806034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 206}], {
             RGBColor[
             0.8651407565407923, 0.8952461086474218, 0.9736329060823592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 252}], {
             RGBColor[
             0.7385856641361137, 0.7957080013728665, 0.9745789745917848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 275}], {
             RGBColor[
             0.5984780468379198, 0.6818261752791819, 0.9632430403646892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 282}], {
             RGBColor[
             0.8630561949616167, 0.8936914460348289, 0.9771615250951697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 324}], {
             RGBColor[
             0.8867058649135613, 0.9097525925822516, 0.8665192276121105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 410}], {
             RGBColor[
             0.8701104157505599, 0.8989524723489963, 0.9652205693349322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 441}], {
             RGBColor[
             0.8229461807785385, 0.6565050116876426, 0.5943577260317444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 467}], {
             RGBColor[
             0.8638974528757422, 0.8943188548097503, 0.9757374948817594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 91}], {
             RGBColor[
             0.8134411204338405, 0.8341850957497161, 0.6711975698985265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 172}], {
             RGBColor[
             0.7881953377564752, 0.8353490254707788, 0.9792886001754563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 303}], {
             RGBColor[
             0.7947895569791419, 0.8404255847884119, 0.9736251178183286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 366}], {
             RGBColor[
             0.8191022252703672, 0.8573666702052312, 0.8791229306916057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 384}], {
             RGBColor[
             0.8177415538712652, 0.8568039976140425, 0.9016727770794292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 435}], {
             RGBColor[
             0.7183905847779481, 0.7799314518899796, 0.9725661178151093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 473}], {
             RGBColor[
             0.8157457963040005, 0.8559787005713485, 0.9347476448240283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 88}], {
             RGBColor[
             0.9683205315404126, 0.9721503702459469, 0.7051434360919098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 166}], {
             RGBColor[
             0.9682046062481606, 0.974457170766296, 0.8782292570950512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 167}], {
             RGBColor[
             0.969578839497287, 0.9748417637312512, 0.8421024918211147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 175}], {
             RGBColor[
             0.9036490795994601, 0.9257929186502909, 0.983171240153516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[
             0.9147779513194375, 0.9346667788746255, 0.9842327218730286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 227}], {
             RGBColor[
             0.9483764544021065, 0.9610198247356647, 0.9722693765068913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 309}], {
             RGBColor[
             0.7856391268635909, 0.833020895492127, 0.9716607007242422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 320}], {
             RGBColor[
             0.9124435650250917, 0.932805402608742, 0.9840100660243426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 337}], {
             RGBColor[
             0.9259892298415722, 0.9436063480461272, 0.9853020636268963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 348}], {
             RGBColor[
             0.9693722036689973, 0.9743997905886268, 0.8196114571203112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 428}], {
             RGBColor[
             0.8716960451892155, 0.9004815892486173, 0.9800791739677928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 434}], {
             RGBColor[
             0.9609017067379793, 0.947155456544136, 0.6737271297428138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 474}], {
             RGBColor[
             0.7196315474701778, 0.7794329689329894, 0.9664643422806625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 495}], {
             RGBColor[
             0.7079041654133669, 0.7699121518667292, 0.9655411198063343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 208}], {
             RGBColor[
             0.9914672497226529, 0.9891351593365214, 0.6744544562689475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 305}], {
             RGBColor[
             0.9340383285093861, 0.9456144702313265, 0.7566709961018248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 314}], {
             RGBColor[
             0.9406725062482657, 0.9509043834803517, 0.7573037698969596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 394}], {
             RGBColor[
             0.9692994661799894, 0.9734863420761136, 0.7515606573425297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 398}], {
             RGBColor[
             0.8125997560094451, 0.8501417548310566, 0.7447952237675273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 427}], {
             RGBColor[
             0.9890828748696869, 0.9742687560149881, 0.4603335598984682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 445}], {
             RGBColor[
             0.9782636793715063, 0.9801718375967949, 0.736386582650536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 460}], {
             RGBColor[
             0.7991733189860557, 0.8392415684013741, 0.7437382454623868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 472}], {
             RGBColor[
             0.9005590981021623, 0.9190183607943946, 0.7534513607122114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 70}], {
             RGBColor[
             0.9597385435918526, 0.9287179091381087, 0.6383981446467228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 96}], {
             RGBColor[
             0.8204234167889022, 0.8192927268958863, 0.642180762845235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 131}], {
             RGBColor[
             0.9788645583623304, 0.9398207650183565, 0.41886950191486977`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 135}], {
             RGBColor[
             0.9751261313300965, 0.9399082332694777, 0.5995561331755821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 147}], {
             RGBColor[
             0.7836693330623693, 0.7899771994392677, 0.638929704880616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 171}], {
             RGBColor[
             0.9553365415216284, 0.9254349032017524, 0.6458495859255967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 180}], {
             RGBColor[
             0.979454736004125, 0.9410830953180425, 0.48310669607000034`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 216}], {
             RGBColor[
             0.979481029120923, 0.9411393336362314, 0.4859685395711471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 238}], {
             RGBColor[
             0.9791184011714118, 0.9403637091195365, 0.44649872514714034`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 281}], {
             RGBColor[
             0.978881356922964, 0.9398566954409566, 0.42069792157113134`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 343}], {
             RGBColor[
             0.9603122117336478, 0.9291457498989641, 0.6374270741192778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 385}], {
             RGBColor[
             0.9032502010518841, 0.8841768797594809, 0.6503885979905994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 391}], {
             RGBColor[
             0.8084361182183606, 0.8099281581457358, 0.6409859809513975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 465}], {
             RGBColor[
             0.9755561874330658, 0.9400860725199933, 0.5924289905998613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 205}], {
             RGBColor[
             0.745488595661228, 0.745818147472487, 0.6194210016269217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 257}], {
             RGBColor[
             0.9740505477485268, 0.9229447244723308, 0.4179204961422367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 272}], {
             RGBColor[
             0.9611055195797116, 0.9162475636717484, 0.6107938935811457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 306}], {
             RGBColor[
             0.5979504600082929, 0.6140691116043124, 0.6096232258499279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 317}], {
             RGBColor[
             0.9718885817066476, 0.9234313507903253, 0.5541089001108943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 142}], {
             RGBColor[
             0.9799109865595133, 0.9808928796750922, 0.6933288239837763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 173}], {
             RGBColor[
             0.9157061893578962, 0.9348128005313594, 0.9637223924730887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 194}], {
             RGBColor[
             0.980306132991762, 0.9817380579382393, 0.7363380745729351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 241}], {
             RGBColor[
             0.9805209051417189, 0.9821974338502019, 0.7597146976756768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 388}], {
             RGBColor[
             0.9728446801172199, 0.9792681874109538, 0.9308510527065325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 402}], {
             RGBColor[
             0.9554260755339594, 0.9662774206331053, 0.9603362067663253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 461}], {
             RGBColor[
             0.9405018036796494, 0.9545841503325048, 0.9660874203024037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 487}], {
             RGBColor[
             0.977092321324492, 0.9819601988917093, 0.9023503668095888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 490}], {
             RGBColor[
             0.9651663354381268, 0.9735416905214216, 0.9438484874152128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 84}], {
             RGBColor[
             0.7159752115995184, 0.7760997497124911, 0.956390964392639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 96}], {
             RGBColor[
             0.8158214516459303, 0.8566363319388394, 0.9646088680169426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 131}], {
             RGBColor[
             0.9742625932193587, 0.9771643700613096, 0.7412976070865774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 135}], {
             RGBColor[
             0.9705241661871248, 0.9772518383124309, 0.9219842383472898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 147}], {
             RGBColor[
             0.7790673679193976, 0.8273208044822209, 0.9613578100523237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 170}], {
             RGBColor[
             0.8231061518953162, 0.862327195139432, 0.9653349388584069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 171}], {
             RGBColor[
             0.9507345763786567, 0.9627785082447053, 0.9682776910973043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 216}], {
             RGBColor[
             0.9748790639779512, 0.9784829386791845, 0.8083966447428548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[
             0.97451643602844, 0.9777073141624897, 0.768926830318848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 265}], {
             RGBColor[
             0.9749938464285934, 0.9787284467348221, 0.8208900061400837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 374}], {
             RGBColor[
             0.9508815237808248, 0.8960801402138361, 0.6183694289550086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 385}], {
             RGBColor[
             0.8986482359089124, 0.9215204848024339, 0.9728167031623071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 391}], {
             RGBColor[
             0.8038341530753889, 0.8472717631886888, 0.9634140861231051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 433}], {
             RGBColor[
             0.9617712715100974, 0.9355747777135608, 0.6462949087606465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 194}], {
             RGBColor[
             0.992312557896881, 0.9895379247101006, 0.6643132244865018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 228}], {
             RGBColor[
             0.9836981548594788, 0.9610849449839867, 0.5793669679110929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 388}], {
             RGBColor[
             0.984851105022339, 0.987068054182815, 0.858826202620099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 431}], {
             RGBColor[
             0.991836617861342, 0.9885199370990017, 0.6125100887795121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 462}], {
             RGBColor[
             0.9925436186115324, 0.991184608922677, 0.7732350663107723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 487}], {
             RGBColor[
             0.989098746229611, 0.9897600656635704, 0.8303255167231554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 490}], {
             RGBColor[
             0.9771727603432458, 0.9813415572932829, 0.8718236373287793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 73}], {
             RGBColor[
             0.6007494521830166, 0.6828381147213151, 0.9637921588238012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 144}], {
             RGBColor[
             0.6757242257856149, 0.7420525603616609, 0.9562510136016664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 163}], {
             RGBColor[
             0.4514054286300596, 0.5640428563520788, 0.9503608912232567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 187}], {
             RGBColor[
             0.6421058237253692, 0.7156710258393304, 0.9677748567568867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 279}], {
             RGBColor[
             0.6946654501066898, 0.7552044557123585, 0.8805511040603304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 322}], {
             RGBColor[
             0.6957425812857587, 0.755649877135912, 0.8627002528970245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 494}], {
             RGBColor[
             0.5940775268143093, 0.6776259559147699, 0.9631271636557359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 93}], {
             RGBColor[
             0.8855603016014837, 0.9108732585815178, 0.9592291481874641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 163}], {
             RGBColor[
             0.6528812764283798, 0.7266285102050649, 0.9674907111460824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 187}], {
             RGBColor[
             0.8435816715236892, 0.8782566796923166, 0.9849046766797123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 322}], {
             RGBColor[
             0.8972184290840788, 0.9182355309888981, 0.8798300728198502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 494}], {
             RGBColor[
             0.7955533746126293, 0.8402116097677561, 0.9802569835785615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 82}], {
             RGBColor[
             0.8986215612955709, 0.6852379357995773, 0.5896188117461281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 105}], {
             RGBColor[
             0.9105574621698336, 0.6941397111283585, 0.5694144449475236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 112}], {
             RGBColor[
             0.7358111514611854, 0.5568818249726566, 0.5810156344834936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 153}], {
             RGBColor[
             0.9219210979765058, 0.7016092353798542, 0.5051523671397842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 195}], {
             RGBColor[
             0.8808583598422408, 0.5432062002443618, 0.22194360534103202`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 224}], {
             RGBColor[
             0.9234133593685093, 0.7004548147144647, 0.3516517234308077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 234}], {
             RGBColor[
             0.8623458445070799, 0.656517567424789, 0.5932629349633434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 239}], {
             RGBColor[
             0.9242163607726894, 0.7021723535221098, 0.43905347072557704`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 263}], {
             RGBColor[
             0.9071097453407124, 0.691568409562318, 0.5752505302306623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 296}], {
             RGBColor[
             0.9235802111606319, 0.7008116938265108, 0.3698125113134481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 342}], {
             RGBColor[
             0.8957047721659543, 0.683062599242513, 0.5945561749221269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 395}], {
             RGBColor[
             0.9044869423780598, 0.6896123274072175, 0.5796902515098634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 440}], {
             RGBColor[
             0.8472869411244472, 0.6445100066305208, 0.5918266033154662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 447}], {
             RGBColor[
             0.8816307234758127, 0.5462683646765512, 0.2225650672503086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 453}], {
             RGBColor[
             0.9234853430170699, 0.7006087804600722, 0.3594866993450393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 463}], {
             RGBColor[
             0.8467078350273718, 0.36002246429000495`, 0.19236078161215292`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 93}], {
             RGBColor[
             0.9819672833960283, 0.984269685418532, 0.8347060442240423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 108}], {
             RGBColor[
             0.9938412437469022, 0.9894447735208112, 0.5862571397588807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 149}], {
             RGBColor[
             0.9940420603042217, 0.9898742998312493, 0.6081147827269844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 158}], {
             RGBColor[
             0.9910487804113597, 0.9905664549113161, 0.7980084038048875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.7492882582229244, 0.8000249370420791, 0.8429676071826606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 182}], {
             RGBColor[
             0.9879103548806876, 0.9695250344493428, 0.5558578738506609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 206}], {
             RGBColor[
             0.9727958387863243, 0.9774296370454769, 0.8502309076524168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 410}], {
             RGBColor[
             0.9777654979960919, 0.9811360007470515, 0.8418185709049897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.7947742805377553, 0.840355130634953, 0.9799797319306908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[
             0.8663946586957637, 0.8963055143870238, 0.9871181818949941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 238}], {
             RGBColor[
             0.953469264920265, 0.9614261128586032, 0.7842976942325962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 333}], {
             RGBColor[
             0.9399858938365637, 0.9168034323255756, 0.658797979566589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 343}], {
             RGBColor[
             0.9346630754825009, 0.9502081536380309, 0.9752260432047337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 392}], {
             RGBColor[
             0.9521786073671972, 0.9620878231180037, 0.892582395096295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 402}], {
             RGBColor[
             0.9283830466469042, 0.9455245184150463, 0.9858564939295558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 431}], {
             RGBColor[
             0.9527871640691677, 0.9599671681090814, 0.7100552260291759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 436}], {
             RGBColor[
             0.8749636607857241, 0.9031362891274008, 0.9879360091266649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 459}], {
             RGBColor[
             0.8747507522876543, 0.9029665216702872, 0.9879157017240534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 462}], {
             RGBColor[
             0.9534941648193581, 0.9626318399327567, 0.8707802035604362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 487}], {
             RGBColor[
             0.9500492924374367, 0.9612072966736502, 0.9278706539728193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 81}], {
             RGBColor[
             0.793083393224215, 0.8361770102960518, 0.8713810296080804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 156}], {
             RGBColor[
             0.9817358261072043, 0.9531344615777662, 0.5625432623549509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 278}], {
             RGBColor[
             0.8263933158195238, 0.8629378404223044, 0.8741958850636451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 329}], {
             RGBColor[
             0.9732885163536301, 0.9782952595057495, 0.8717066455146781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 479}], {
             RGBColor[
             0.990660293719443, 0.990405805680556, 0.8044466336612779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 482}], {
             RGBColor[
             0.897575503901983, 0.9185459067569881, 0.8812906603363367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 85}], {
             RGBColor[
             0.8324993891835448, 0.8696437145638352, 0.9651803653328836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 95}], {
             RGBColor[
             0.8497674585079017, 0.8814094555765497, 0.8861185045060183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 97}], {
             RGBColor[
             0.8395838010425003, 0.8749272573285845, 0.9531883039662077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 137}], {
             RGBColor[
             0.7807897097493308, 0.8289444480293792, 0.9787148048507307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 145}], {
             RGBColor[
             0.8288081729299157, 0.8668908115256906, 0.9714286316268932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 183}], {
             RGBColor[
             0.8257048371884332, 0.8645763488109387, 0.9766817695576324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 346}], {
             RGBColor[
             0.8505755888347015, 0.8793489187491759, 0.6986548669643435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 358}], {
             RGBColor[
             0.8484162113214655, 0.8808506801394896, 0.9085121673008889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 404}], {
             RGBColor[
             0.7732211618751725, 0.5319250292721028, 0.5777113902387868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 407}], {
             RGBColor[
             0.7306658064463839, 0.7895209483525018, 0.9737895971925505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 408}], {
             RGBColor[
             0.6296042623165747, 0.7091647114025332, 0.9646781471266845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 430}], {
             RGBColor[
             0.8514604187874268, 0.8812414805480242, 0.7949631467810084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 81}], {
             RGBColor[
             0.7922934665847121, 0.8358503553304288, 0.8844721582892526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 99}], {
             RGBColor[
             0.9273724236271446, 0.9424719897327876, 0.8973353816081742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 122}], {
             RGBColor[
             0.9890122570831731, 0.9897243001788487, 0.831758865706367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 267}], {
             RGBColor[
             0.7223034915917121, 0.7790293406186695, 0.8789622910760776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 278}], {
             RGBColor[
             0.8256033891800211, 0.8626111854566814, 0.8872870137448173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 329}], {
             RGBColor[
             0.9724985897141274, 0.9779686045401264, 0.8847977741958504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 406}], {
             RGBColor[
             0.9670923098032078, 0.9739366098345336, 0.8939491959014109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 413}], {
             RGBColor[
             0.9410555489210546, 0.9533825424236098, 0.8986404903137775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 476}], {
             RGBColor[
             0.9530472619195226, 0.9629444088622102, 0.8997842706046999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 486}], {
             RGBColor[
             0.9903542567615113, 0.9902792515336603, 0.8095184580524634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 493}], {
             RGBColor[
             0.9882089287735747, 0.977307709901232, 0.6038498883814432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 156}], {
             RGBColor[
             0.899824588029484, 0.8905774991370397, 0.6634963900374566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 278}], {
             RGBColor[
             0.7444820777418034, 0.8003808779815778, 0.9751490127461508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 307}], {
             RGBColor[
             0.661112716249171, 0.7329795402064553, 0.968393294886822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 329}], {
             RGBColor[
             0.8913772782759097, 0.9157382970650227, 0.9726597731971839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 372}], {
             RGBColor[
             0.8830574949354996, 0.8286757078508504, 0.6261829656990165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 406}], {
             RGBColor[
             0.8859709983649902, 0.91170630235943, 0.9818111949027444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 417}], {
             RGBColor[
             0.8543942754765883, 0.8867348196229861, 0.9859740827933725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 461}], {
             RGBColor[
             0.8710467265106803, 0.9000130320588294, 0.9875624084388228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 486}], {
             RGBColor[
             0.9092329453232937, 0.9280489440585566, 0.8973804570537969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 493}], {
             RGBColor[
             0.907087617335357, 0.9150774024261283, 0.6917118873827766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 83}], {
             RGBColor[
             0.7919277502664755, 0.8356991222343573, 0.8905330241259264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 99}], {
             RGBColor[
             0.7292051276667187, 0.7879990506509529, 0.9740541583077897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 237}], {
             RGBColor[
             0.6505259616320263, 0.7261762270681371, 0.9663071727406956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[
             0.5241361956312863, 0.6245564015368348, 0.9556810677756931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 278}], {
             RGBColor[
             0.6274360932195953, 0.7081382463748466, 0.9640057904444328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 329}], {
             RGBColor[
             0.7743312937537015, 0.8234956654582917, 0.961516550895466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 426}], {
             RGBColor[
             0.7891584561910189, 0.8345537389267926, 0.9364180324323963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 486}], {
             RGBColor[
             0.7921869608010855, 0.8358063124518254, 0.8862372347520788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 89}], {
             RGBColor[
             0.9688547770530297, 0.9736021126463773, 0.7878141834493414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 105}], {
             RGBColor[
             0.9555808253825007, 0.9663928328167679, 0.9600742556379691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 184}], {
             RGBColor[
             0.9518458568466579, 0.9636072993981859, 0.9663965831333436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 195}], {
             RGBColor[
             0.9258817230549079, 0.8154593219327713, 0.6126034160314776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 225}], {
             RGBColor[
             0.9689903575982152, 0.9738921057232333, 0.8025712890866458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 263}], {
             RGBColor[
             0.9521331085533795, 0.9638215312507274, 0.9659103409211078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 296}], {
             RGBColor[
             0.968603574373299, 0.9730648155149202, 0.7604723220038937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 342}], {
             RGBColor[
             0.9407281353786214, 0.9553157209309224, 0.9852159856125724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 395}], {
             RGBColor[
             0.9495103055907269, 0.9618654490956269, 0.970350062200309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 440}], {
             RGBColor[
             0.8923103043371143, 0.9167631283189301, 0.9824864140059117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 447}], {
             RGBColor[
             0.9266540866884798, 0.8185214863649606, 0.6132248779407542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 453}], {
             RGBColor[
             0.968508706229737, 0.9728619021484817, 0.7501465100354849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 463}], {
             RGBColor[
             0.8917311982400389, 0.6322755859784144, 0.5830205923025985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 470}], {
             RGBColor[
             0.9354568237656908, 0.8534214055378617, 0.620307766819874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 119}], {
             RGBColor[
             0.9916756812891371, 0.9908256945348948, 0.7876190338926505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 176}], {
             RGBColor[
             0.9665342595525064, 0.9015433125096093, 0.5465713493857213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[
             0.7701463955230975, 0.818016037214834, 0.8888183160927963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 237}], {
             RGBColor[
             0.8483275412742155, 0.8804979330539005, 0.8956492618777538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 270}], {
             RGBColor[
             0.9876382437833499, 0.9891561103688407, 0.8545298219168735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 345}], {
             RGBColor[
             0.9891730734016946, 0.9897908018593482, 0.8290937231291748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 375}], {
             RGBColor[
             0.9749792222301936, 0.9799401737442095, 0.8860405139027201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 426}], {
             RGBColor[
             0.9869600358332081, 0.9888754449125559, 0.8657601215694546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 448}], {
             RGBColor[
             0.991427163795464, 0.9888621091844346, 0.656475861226299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 489}], {
             RGBColor[
             0.8069947843351567, 0.8479312192534623, 0.8917191562401773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 131}], {
             RGBColor[
             0.7351012263699963, 0.7872026055927389, 0.7368623216607859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 135}], {
             RGBColor[
             0.7313627993377623, 0.7872900738438602, 0.9175489529214983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 147}], {
             RGBColor[
             0.5399060010700352, 0.6373590400136502, 0.956922524626532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 171}], {
             RGBColor[
             0.7115732095292941, 0.7728167437761346, 0.9638424056715129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 230}], {
             RGBColor[
             0.6380586654180744, 0.7146396052982854, 0.9662932193051448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 242}], {
             RGBColor[
             0.7133083775421108, 0.7741108292390164, 0.9609052188301117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 365}], {
             RGBColor[
             0.4859941676990367, 0.5935909849826575, 0.9526783876180145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 374}], {
             RGBColor[
             0.7117201569314623, 0.7061183757452654, 0.6139341435292172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 385}], {
             RGBColor[
             0.6594868690595499, 0.7315587203338632, 0.9683814177365155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 391}], {
             RGBColor[
             0.5646727862260263, 0.6573099987201181, 0.9589788006973137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 95}], {
             RGBColor[
             0.9736217841958275, 0.9787349935448657, 0.8797040945081409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 97}], {
             RGBColor[
             0.963438126730426, 0.9722527952969003, 0.9467738939683303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 137}], {
             RGBColor[
             0.9046440354372565, 0.9262699859976951, 0.9723003948528532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 145}], {
             RGBColor[
             0.9526624986178414, 0.9642163494940065, 0.9650142216290158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 183}], {
             RGBColor[
             0.9495591628763589, 0.9619018867792546, 0.9702673595597551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 286}], {
             RGBColor[
             0.8538837503939773, 0.8863493400685898, 0.9673117586101223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 346}], {
             RGBColor[
             0.9744299145226273, 0.9766744567174919, 0.6922404569664661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 358}], {
             RGBColor[
             0.9722705370093911, 0.9781762181078055, 0.9020977573030114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 404}], {
             RGBColor[
             0.8970754875630982, 0.6292505672404187, 0.5712969802409094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 407}], {
             RGBColor[
             0.8545201321343097, 0.8868464863208176, 0.9673751871946731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 408}], {
             RGBColor[
             0.7534585880045004, 0.8064902493708492, 0.9582637371288071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 90}], {
             RGBColor[
             0.7043961522722602, 0.7638450453286634, 0.8889759089709457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 98}], {
             RGBColor[
             0.9624540238889376, 0.8864501968941958, 0.5485910911949021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 115}], {
             RGBColor[
             0.976414421113922, 0.9811119383857307, 0.8881518015479585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 124}], {
             RGBColor[
             0.990709379748383, 0.9904261040149761, 0.8036331511311702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 136}], {
             RGBColor[
             0.9430396535475083, 0.9552221267981347, 0.9100118483169242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 168}], {
             RGBColor[
             0.7951265493266285, 0.8384176017549452, 0.895866126365599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[
             0.9810093381304861, 0.9845388199731981, 0.8803738055852074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 253}], {
             RGBColor[
             0.8935754638698528, 0.9159581551589141, 0.9052468251384176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 261}], {
             RGBColor[
             0.9912149616078649, 0.9889347416052096, 0.6716507864434971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 357}], {
             RGBColor[
             0.9901367430283816, 0.990189304015163, 0.8131232235179202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 484}], {
             RGBColor[
             0.9822704584775889, 0.9854793614631723, 0.8782390577904273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 500}], {
             RGBColor[
             0.9700472608826539, 0.976363320710519, 0.8989297429981444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 107}], {
             RGBColor[
             0.9426612023551268, 0.9528977220776136, 0.7905353415236862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 113}], {
             RGBColor[
             0.9934207741655812, 0.9904672254720521, 0.680185747508635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 143}], {
             RGBColor[
             0.9810167548178175, 0.9466848011653053, 0.4608887225543321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 226}], {
             RGBColor[
             0.9383478272974015, 0.9494583538900304, 0.790123927960085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 292}], {
             RGBColor[
             0.9907412967954441, 0.9893591927200731, 0.7245916217969564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 308}], {
             RGBColor[
             0.991650952894875, 0.9897353588942832, 0.7095162661148626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 386}], {
             RGBColor[
             0.968845833138879, 0.9735712998801568, 0.7859137262153543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 421}], {
             RGBColor[
             0.8915259268628075, 0.9123740966864179, 0.7855916032478507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 422}], {
             RGBColor[
             0.9933836910913676, 0.9904518906678733, 0.680800310016273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 423}], {
             RGBColor[
             0.993834924204444, 0.9892218511951116, 0.5703477299703512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 446}], {
             RGBColor[
             0.9943491446492355, 0.9903217167308586, 0.6263174519851761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 166}], {
             RGBColor[
             0.992436533496135, 0.9887855878676587, 0.6038451048948175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 167}], {
             RGBColor[
             0.9938107667452614, 0.9891701808326139, 0.567718339620881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 210}], {
             RGBColor[
             0.9390098785674119, 0.9489951959759881, 0.709848569672795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 227}], {
             RGBColor[
             0.972608381650081, 0.9753482418370274, 0.6978852243066576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 243}], {
             RGBColor[
             0.8698767067296358, 0.894458559582286, 0.7030984750647495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 326}], {
             RGBColor[
             0.9230753284356454, 0.6997318007292387, 0.3148591424736793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 348}], {
             RGBColor[
             0.9936041309169719, 0.9887282076899895, 0.5452273049200776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 428}], {
             RGBColor[0.89592797243719, 0.91481000634998, 0.705695021767559]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 434}], {
             RGBColor[
             0.9851336339859538, 0.9614838736454987, 0.3993429775425801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 469}], {
             RGBColor[
             0.9936358576766791, 0.9887960680209358, 0.5486805669193447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 474}], {
             RGBColor[
             0.7438634747181523, 0.7937613860343521, 0.6920801900804288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 495}], {
             RGBColor[
             0.7321360926613413, 0.7842405689680919, 0.6911569676061007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 133}], {
             RGBColor[
             0.9353936536832348, 0.9471260246635542, 0.7917267650994493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 184}], {
             RGBColor[
             0.9770557093914496, 0.9797183545565765, 0.7739321441461116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 192}], {
             RGBColor[
             0.990090663351372, 0.9891200397600564, 0.7375477662385513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 225}], {
             RGBColor[
             0.9942002101430069, 0.9900031608816238, 0.6101068500994136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 235}], {
             RGBColor[
             0.8937746459632705, 0.9141543419067689, 0.787700269066713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 239}], {
             RGBColor[
             0.9944495765301482, 0.9905365303689098, 0.6372488424287904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 249}], {
             RGBColor[
             0.82684528196623, 0.8618686140702745, 0.7810293755539552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 260}], {
             RGBColor[
             0.993864627651045, 0.9906806709844298, 0.6750034110864415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.9902541027907737, 0.9891876261684511, 0.7348391517599535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 296}], {
             RGBColor[
             0.9938134269180907, 0.9891758706733109, 0.5680078830166615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 424}], {
             RGBColor[
             0.8457040217427754, 0.8766012049154427, 0.7829090384899381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 440}], {
             RGBColor[
             0.917520156881906, 0.9328741834773209, 0.7900219750186795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 453}], {
             RGBColor[
             0.9937185587745286, 0.9889729573068724, 0.5576820710482526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 470}], {
             RGBColor[
             0.9606666763104825, 0.8695324606962525, 0.4278433278326418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 124}], {
             RGBColor[
             0.7059865181264988, 0.7645027024799292, 0.8626194310313148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 178}], {
             RGBColor[
             0.6962864765086019, 0.7586154184381513, 0.939360085485352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[
             0.7066774388262245, 0.7634077611088133, 0.7508100553254522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 261}], {
             RGBColor[
             0.7064920999859807, 0.7630113400701627, 0.7306370663436417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 272}], {
             RGBColor[
             0.6937324106574092, 0.7567106003082309, 0.9436834527643613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 306}], {
             RGBColor[
             0.3305773510859905, 0.4545321482407948, 0.9425127850331434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 317}], {
             RGBColor[
             0.7045154727843452, 0.7638943874268078, 0.8869984592941099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 357}], {
             RGBColor[
             0.7054138814064974, 0.7642659024801162, 0.8721095034180648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 172}], {
             RGBColor[
             0.9547944006198101, 0.9454969225739163, 0.6850513407919098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 303}], {
             RGBColor[
             0.9613886198424768, 0.9505734818915494, 0.6793878584347821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 366}], {
             RGBColor[
             0.9857012881337022, 0.9675145673083686, 0.5848856713080592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 435}], {
             RGBColor[
             0.8849896476412831, 0.8900793489931171, 0.6783288584315628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 473}], {
             RGBColor[
             0.9823448591673354, 0.9661265976744859, 0.6405103854404818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 101}], {
             RGBColor[
             0.9640622380185266, 0.9333639921173034, 0.6340967881574171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 128}], {
             RGBColor[
             0.9800893906612318, 0.9431083499340827, 0.49540068678358296`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 140}], {
             RGBColor[
             0.9803128314307773, 0.9435862671468132, 0.5197208356320168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 169}], {
             RGBColor[
             0.9786440304083608, 0.9429642177172233, 0.5523231717900878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 175}], {
             RGBColor[
             0.9143160453838866, 0.8943940599103888, 0.6534942012762754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 204}], {
             RGBColor[
             0.8859065658355725, 0.8718509824988696, 0.6507553235227865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 219}], {
             RGBColor[
             0.9512971741598738, 0.8418192194273015, 0.2942393399779371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 274}], {
             RGBColor[
             0.9646048781492786, 0.9337686922383266, 0.6331782399592667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 320}], {
             RGBColor[
             0.9231105308095182, 0.9014065438688399, 0.654333027147102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 334}], {
             RGBColor[
             0.9767673065299524, 0.9421881441638977, 0.5834253432610248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 337}], {
             RGBColor[
             0.9366561956259987, 0.9122074893062251, 0.6556250247496556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 361}], {
             RGBColor[
             0.9770515458403048, 0.9423056844233455, 0.578714762300728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 363}], {
             RGBColor[
             0.9763444462314741, 0.9420132805634629, 0.5904332327341819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 370}], {
             RGBColor[
             0.9671130715354274, 0.9356392987589264, 0.6289325227981217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 498}], {
             RGBColor[
             0.9367784035520705, 0.9123049345892289, 0.6556366810507406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 108}], {
             RGBColor[
             0.9807692635725045, 0.9814978366910136, 0.6890874131631398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 163}], {
             RGBColor[
             0.7362162780485267, 0.7920780002122816, 0.9457978805869196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 187}], {
             RGBColor[
             0.9269166731438363, 0.9437061696995332, 0.9632118461205497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 189}], {
             RGBColor[
             0.9806079557127567, 0.9837075684883712, 0.8572336217631301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 206}], {
             RGBColor[
             0.9597238586119266, 0.9694827002156794, 0.9530611810566758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 266}], {
             RGBColor[
             0.7869098235715877, 0.8332333041861032, 0.9497886621870709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 322}], {
             RGBColor[
             0.9805534307042258, 0.9836850209961148, 0.8581372422606874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 364}], {
             RGBColor[
             0.9814166363560453, 0.9828825016155788, 0.7595499455298461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 437}], {
             RGBColor[
             0.9461311875156571, 0.9590273018955248, 0.9650445436543333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 100}], {
             RGBColor[
             0.9804539161640246, 0.9821474735803218, 0.7598280925413896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 127}], {
             RGBColor[
             0.9926608199354531, 0.9900525021215392, 0.6854775746741323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 168}], {
             RGBColor[
             0.7975238005179546, 0.8382283541685882, 0.7703223078461423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 213}], {
             RGBColor[
             0.8445452235032296, 0.8755933603040751, 0.7745771948776974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 214}], {
             RGBColor[
             0.9915529744746954, 0.9895943795531861, 0.7038374409710368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 254}], {
             RGBColor[
             0.9945430573324506, 0.990736476352676, 0.6474236508627784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 302}], {
             RGBColor[
             0.7943012736359236, 0.8356121616725738, 0.7700686187254839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 315}], {
             RGBColor[
             0.9794514798258518, 0.9813998582006515, 0.7615249557846464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 325}], {
             RGBColor[
             0.9939308847439735, 0.9905777065590391, 0.664429313974586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 368}], {
             RGBColor[
             0.8956172386165143, 0.9154912066722644, 0.779667576049073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 401}], {
             RGBColor[
             0.9931170622403398, 0.9902411700395022, 0.6779164589649233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 477}], {
             RGBColor[
             0.9802302949100066, 0.9819806972152214, 0.7602066249946781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 500}], {
             RGBColor[
             0.97244451207398, 0.9761740731241622, 0.7733859244786877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 97}], {
             RGBColor[
             0.9807061960547828, 0.9840185363096149, 0.867712033141465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 137}], {
             RGBColor[
             0.9219121047616132, 0.9380357270104096, 0.8932385340259879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 145}], {
             RGBColor[
             0.9699305679421982, 0.975982090506721, 0.8859523608021503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 174}], {
             RGBColor[
             0.9927882597553113, 0.9907721876543145, 0.7318484003580525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 286}], {
             RGBColor[
             0.8711518197183341, 0.8981150810813043, 0.8882498977832568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 294}], {
             RGBColor[
             0.939590215680272, 0.9521317727974106, 0.8949246880268454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 346}], {
             RGBColor[
             0.9916979838469842, 0.9884401977302064, 0.6131785961396006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 358}], {
             RGBColor[
             0.9895386063337479, 0.9899419591205201, 0.823035896476146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 404}], {
             RGBColor[
             0.9143435568874551, 0.6410163082531333, 0.49223511941404396`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 407}], {
             RGBColor[
             0.8717882014586664, 0.8986122273335322, 0.8883133263678076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 408}], {
             RGBColor[
             0.7707266573288571, 0.8182559903835638, 0.8792018763019416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 430}], {
             RGBColor[
             0.9925828137997095, 0.9903327595290548, 0.7094868759562656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 131}], {
             RGBColor[
             0.8349474664164083, 0.8677391878190872, 0.7450802252850894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 147}], {
             RGBColor[
             0.6397522411164471, 0.7178956222399984, 0.9651404282508356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.7481267030009884, 0.8031615334486877, 0.9755299361797579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 171}], {
             RGBColor[
             0.8114194495757061, 0.853353326002483, 0.9720603092958164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 180}], {
             RGBColor[
             0.8355376440582027, 0.8690015181187731, 0.80931741944022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 216}], {
             RGBColor[
             0.8355639371750008, 0.869057756436962, 0.8121792629413668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 238}], {
             RGBColor[
             0.8352013092254895, 0.8682821319202672, 0.77270944851736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 265}], {
             RGBColor[
             0.835678719625643, 0.8693032644925998, 0.8246726243385956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 281}], {
             RGBColor[
             0.8349642649770417, 0.8677751182416873, 0.746908644941351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 343}], {
             RGBColor[
             0.8163951197877255, 0.8570641726996948, 0.9636377974894975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 392}], {
             RGBColor[
             0.8339106516724217, 0.8689438421796676, 0.8809941493810588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 433}], {
             RGBColor[
             0.822456144707147, 0.8261495954713384, 0.6500775269591585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 465}], {
             RGBColor[
             0.8316390954871437, 0.868004495320724, 0.918639713970081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 104}], {
             RGBColor[
             0.9776431683959788, 0.9827518956564791, 0.9184743283093282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 137}], {
             RGBColor[
             0.9117284472962119, 0.9315535287624443, 0.9603083334861773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 145}], {
             RGBColor[
             0.9597469104767968, 0.9694998922587557, 0.9530221602623399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 174}], {
             RGBColor[
             0.9826046022899099, 0.9842899894063493, 0.798918199818242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 294}], {
             RGBColor[
             0.9294065582148707, 0.9456495745494452, 0.961994487487035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 346}], {
             RGBColor[
             0.9815143263815826, 0.981957999482241, 0.6802483955997901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 358}], {
             RGBColor[
             0.9793549488683466, 0.9834597608725548, 0.8901056959363355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 404}], {
             RGBColor[
             0.9041598994220537, 0.634534110005168, 0.5593049188742334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 407}], {
             RGBColor[
             0.861604543993265, 0.8921300290855669, 0.9553831258279971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 408}], {
             RGBColor[
             0.7605429998634559, 0.8117737921355984, 0.9462716757621311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 430}], {
             RGBColor[
             0.982399156334308, 0.9838505612810894, 0.776556675416455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 115}], {
             RGBColor[
             0.9497494311087151, 0.8777936884162163, 0.6067532636720594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 124}], {
             RGBColor[
             0.9640443897431762, 0.8871078540454617, 0.5222346132552711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 136}], {
             RGBColor[
             0.9163746635423013, 0.8519038768286202, 0.6286133104410252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 253}], {
             RGBColor[
             0.8669104738646458, 0.8126399051893997, 0.6238482872625186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 261}], {
             RGBColor[
             0.9645499716026582, 0.8856164916356951, 0.3902522485675981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 277}], {
             RGBColor[
             0.9647268297939997, 0.8873900605443865, 0.5109248155148884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 311}], {
             RGBColor[
             0.9644322708812814, 0.8853647416940384, 0.3774412514103871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 319}], {
             RGBColor[
             0.8795203110235486, 0.8225172165149158, 0.6250981093975176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 331}], {
             RGBColor[
             0.9123164804547177, 0.8486679917910263, 0.6282262373153487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 377}], {
             RGBColor[
             0.9568830156340056, 0.860252664617125, 0.31806888808117634`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 484}], {
             RGBColor[
             0.955605468472382, 0.8821611114936578, 0.5968405199145284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 488}], {
             RGBColor[
             0.9642132053301624, 0.8871776636290432, 0.5194369020981744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 122}], {
             RGBColor[
             0.9259239181651797, 0.9418729954993728, 0.921340865724904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 267}], {
             RGBColor[
             0.6592151526737188, 0.7311780359391935, 0.9685442910946147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 278}], {
             RGBColor[
             0.7625150502620277, 0.8147598807772054, 0.9768690137633544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 329}], {
             RGBColor[
             0.9094102507961339, 0.9301172998606504, 0.9743797742143875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 406}], {
             RGBColor[
             0.9040039708852144, 0.9260853051550575, 0.983531195919948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 413}], {
             RGBColor[
             0.8779672100030611, 0.9055312377441338, 0.9882224903323146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 476}], {
             RGBColor[
             0.8899589230015292, 0.9150931041827342, 0.989366270623237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 486}], {
             RGBColor[
             0.927265917843518, 0.9424279468541842, 0.8991004580710005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 493}], {
             RGBColor[
             0.9251205898555813, 0.929456405221756, 0.6934318883999802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 121}], {
             RGBColor[
             0.958079106737096, 0.9682560469604647, 0.9558453169607724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 127}], {
             RGBColor[
             0.9792012198226809, 0.9828100240108644, 0.8664036751836343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 168}], {
             RGBColor[
             0.7840642004051825, 0.8309858760579136, 0.9512484083556443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 200}], {
             RGBColor[
             0.9765115957125403, 0.9816977953211345, 0.9109777072127374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 213}], {
             RGBColor[
             0.8310856233904574, 0.8683508821934004, 0.9555032953871994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 254}], {
             RGBColor[
             0.9810834572196785, 0.9834939982420012, 0.8283497513722804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 259}], {
             RGBColor[
             0.9563110742940935, 0.9669374512593609, 0.9588381347100621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 315}], {
             RGBColor[
             0.9659918797130796, 0.9741573800899768, 0.9424510562941484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 368}], {
             RGBColor[
             0.8821576385037422, 0.9082487285615897, 0.960593676558575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 401}], {
             RGBColor[
             0.9796574621275677, 0.9829986919288275, 0.8588425594744252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 450}], {
             RGBColor[
             0.9800225661216055, 0.9812248594557667, 0.7128783024079666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 454}], {
             RGBColor[
             0.9579898080149449, 0.9681894481196978, 0.9559964764045371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 471}], {
             RGBColor[
             0.9746926211913953, 0.9806463788383479, 0.927722970488176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 475}], {
             RGBColor[
             0.9806931630874989, 0.9834269808920597, 0.8416783142601987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 500}], {
             RGBColor[
             0.9589849119612079, 0.9689315950134875, 0.9543120249881897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 128}], {
             RGBColor[
             0.9787290928184671, 0.981448106386606, 0.8093239644033379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 169}], {
             RGBColor[
             0.9772837325655961, 0.9813039741697467, 0.8662464494098427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 197}], {
             RGBColor[
             0.756632700656646, 0.8088574973896869, 0.9528907923498899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[
             0.8845462679928077, 0.910190738951393, 0.9646786011425414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 219}], {
             RGBColor[
             0.949936876317109, 0.880158975879825, 0.6081626175976921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 337}], {
             RGBColor[
             0.935295897783234, 0.9505472457587485, 0.9695483023694106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 345}], {
             RGBColor[
             0.9756593785352431, 0.9806322620342013, 0.8931661993862685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 355}], {
             RGBColor[
             0.9094801693068071, 0.9299624846209276, 0.9670859751413561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 361}], {
             RGBColor[
             0.9756912479975401, 0.9806454408758689, 0.8926380399204831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 362}], {
             RGBColor[
             0.9786354517245938, 0.981247817555378, 0.7991317092210788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 363}], {
             RGBColor[
             0.9749841483887094, 0.9803530370159863, 0.9043565103539368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 498}], {
             RGBColor[
             0.9354181057093056, 0.9506446910417523, 0.9695599586704956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 109}], {
             RGBColor[
             0.9041016355211281, 0.8672763319627657, 0.6330763952784413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[
             0.8114246822108717, 0.8529057651743035, 0.981760505267847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 186}], {
             RGBColor[
             0.9245330892551107, 0.9374424062631168, 0.7077065056410186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 193}], {
             RGBColor[
             0.9212011741026995, 0.938431390192239, 0.9349675344902522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 196}], {
             RGBColor[
             0.8737096648325194, 0.7429410386882772, 0.6084235980257249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 202}], {
             RGBColor[
             0.9122282897886158, 0.9320189734384711, 0.9626749136442239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 330}], {
             RGBColor[
             0.9245830935723761, 0.9375493604415355, 0.7131491669844806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 350}], {
             RGBColor[
             0.9055320684478462, 0.9270249425265812, 0.9740098697199135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 354}], {
             RGBColor[
             0.9240264991288667, 0.9395997346981003, 0.8881445870998752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 414}], {
             RGBColor[
             0.9245400894004814, 0.9374573788662414, 0.7084684282647198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 415}], {
             RGBColor[
             0.8087665580427755, 0.8508292183716949, 0.9814955682923538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 485}], {
             RGBColor[
             0.7661403200084812, 0.8175292772478961, 0.9772469832499378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 496}], {
             RGBColor[
             0.7842418853947768, 0.8316703577046627, 0.9790511781188975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 118}], {
             RGBColor[
             0.9827247158485051, 0.9831851686395674, 0.7039442474083843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 188}], {
             RGBColor[
             0.8961377069945687, 0.9152586073607965, 0.7285233340065809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 304}], {
             RGBColor[
             0.960496741099442, 0.9664096012815386, 0.7347063133723553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 319}], {
             RGBColor[
             0.9081117580332554, 0.9246392377370465, 0.7297097869228759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 331}], {
             RGBColor[
             0.9409079274644246, 0.9507900130131569, 0.7328379148407069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 449}], {
             RGBColor[
             0.9613727712752291, 0.8733294017704305, 0.36938415708553224`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 488}], {
             RGBColor[
             0.9928046523398694, 0.9892996848511737, 0.6240485796235328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 112}], {
             RGBColor[
             0.8013939515210213, 0.8443731445427269, 0.9326195459641533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 148}], {
             RGBColor[
             0.9067701028133148, 0.9271376401338538, 0.9428487258430914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 153}], {
             RGBColor[
             0.9875038980363419, 0.9891005549499247, 0.8567562786204439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 190}], {
             RGBColor[
             0.9415273948838808, 0.8095062126694049, 0.5695053365370557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 215}], {
             RGBColor[
             0.9891785955842349, 0.9883363467748578, 0.7231126846145911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 224}], {
             RGBColor[
             0.9889961594283454, 0.987946134284535, 0.7032556349114674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 323}], {
             RGBColor[
             0.9886658020533625, 0.9872395332637006, 0.6672982733739637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 351}], {
             RGBColor[
             0.987688926249747, 0.9891770688711758, 0.8536898822866523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 356}], {
             RGBColor[
             0.9873945091283307, 0.9890553198252954, 0.8585691359156082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 408}], {
             RGBColor[
             0.7676636296700531, 0.816989349730428, 0.9299641714698048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 430}], {
             RGBColor[
             0.9895197861409053, 0.989066118875919, 0.7602491711241288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 452}], {
             RGBColor[
             0.581845399101288, 0.6466807266256543, 0.917833912008501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 112}], {
             RGBColor[
             0.7927704155481151, 0.8380367219898471, 0.9514710783753346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 148}], {
             RGBColor[
             0.8981465668404086, 0.9208012175809739, 0.9617002582542729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 153}], {
             RGBColor[
             0.9788803620634356, 0.9827641323970449, 0.8756078110316253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 190}], {
             RGBColor[
             0.9329038589109746, 0.8031697901165251, 0.5883568689482371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 195}], {
             RGBColor[
             0.9378176239291707, 0.8243610972615525, 0.5923990492328732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 263}], {
             RGBColor[
             0.9640690094276422, 0.9727233065795087, 0.9457059741225033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 323}], {
             RGBColor[
             0.9800422660804562, 0.9809031107108208, 0.6861498057851452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 342}], {
             RGBColor[
             0.9526640362528841, 0.9642174962597037, 0.965011618813968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 395}], {
             RGBColor[
             0.9614462064649896, 0.970767224424408, 0.9501456954017046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 447}], {
             RGBColor[
             0.9385899875627426, 0.8274232616937418, 0.5930205111421498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 453}], {
             RGBColor[
             0.9804446071039996, 0.9817636774772629, 0.7299421432368804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 463}], {
             RGBColor[
             0.9036670991143017, 0.6411773613071955, 0.5628162255039941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 117}], {
             RGBColor[
             0.8514102158726403, 0.8816489117685202, 0.830732543074981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 139}], {
             RGBColor[
             0.9876339509638532, 0.9882129615122903, 0.8040595964219989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 140}], {
             RGBColor[
             0.9950684282125661, 0.991860191542099, 0.7046070289501145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 247}], {
             RGBColor[
             0.994903563667598, 0.9915075629507746, 0.6866625406563647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 255}], {
             RGBColor[
             0.9383589532853683, 0.9500734340951732, 0.83926622661985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 269}], {
             RGBColor[
             0.9944139677409998, 0.9904603667695225, 0.6333730454819755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 274}], {
             RGBColor[
             0.9793604749310676, 0.9820426166336125, 0.8180644332773644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 360}], {
             RGBColor[
             0.8208760282810204, 0.8577953723535259, 0.8276891806140547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 369}], {
             RGBColor[
             0.9945125409773106, 0.9906712049547084, 0.6441021339309089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 370}], {
             RGBColor[
             0.9818686683172162, 0.9839132231542123, 0.8138187161162196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 425}], {
             RGBColor[
             0.9330136101780625, 0.9458112025968809, 0.838756383022431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 466}], {
             RGBColor[
             0.9886421538260086, 0.9718492909567646, 0.5379408278551538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 468}], {
             RGBColor[
             0.9252631989751376, 0.9396312350829763, 0.8380171418830222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 113}], {
             RGBColor[
             0.9420520068907967, 0.9537259139115972, 0.8791438681807033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 132}], {
             RGBColor[
             0.9402115693166695, 0.9529648456776074, 0.9096446816837538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 143}], {
             RGBColor[
             0.929647987543033, 0.9099434896048504, 0.6598468432264004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 209}], {
             RGBColor[
             0.9429789030073963, 0.9541092092759549, 0.8637828007983905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 214}], {
             RGBColor[
             0.9402424338764681, 0.9529776089662672, 0.9091331760529703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 273}], {
             RGBColor[
             0.9295881912295214, 0.9097417825985334, 0.6596145458399939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 308}], {
             RGBColor[
             0.9402821856200907, 0.9529940473338283, 0.9084743867869309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 421}], {
             RGBColor[
             0.8401571595880231, 0.8756327851259631, 0.984549723919919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 423}], {
             RGBColor[
             0.9424661569296596, 0.9524805396346567, 0.7693058506424195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 446}], {
             RGBColor[
             0.9429803773744512, 0.9535804051704038, 0.8252755726572444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 477}], {
             RGBColor[
             0.9289197543117795, 0.9453639266283026, 0.9655023600766115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 129}], {
             RGBColor[
             0.9845651615122217, 0.9843288111592422, 0.6826619480799396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 163}], {
             RGBColor[
             0.7480902383994006, 0.7972530883145608, 0.6973489761217582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 189}], {
             RGBColor[
             0.9924819160636306, 0.9888826565906503, 0.6087847172979686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 206}], {
             RGBColor[
             0.9715978189628004, 0.9746577883179586, 0.7046122765915144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 266}], {
             RGBColor[
             0.7987837839224614, 0.8384083922883823, 0.7013397577219094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 364}], {
             RGBColor[
             0.993290596706919, 0.9880575897178578, 0.5111010410646846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 374}], {
             RGBColor[
             0.9696348465180734, 0.9063858455199515, 0.3582755583947824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 410}], {
             RGBColor[
             0.976567478172568, 0.9783641520195331, 0.6961999398440872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 437}], {
             RGBColor[
             0.9580051478665308, 0.9642023899978038, 0.7165956391891717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 185}], {
             RGBColor[
             0.8589985977194243, 0.831746126751896, 0.6286593279085249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 186}], {
             RGBColor[
             0.9721070047636633, 0.9162827678407093, 0.35460532828169644`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 196}], {
             RGBColor[
             0.9212835803410719, 0.7217814002658696, 0.25532242066640265`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 218}], {
             RGBColor[
             0.9560836417257191, 0.9080860363930657, 0.6158682944546576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 295}], {
             RGBColor[
             0.9112239341668893, 0.8729554595732492, 0.6337557264814251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 300}], {
             RGBColor[
             0.9029478991499568, 0.8663563738977331, 0.6329663508734062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 335}], {
             RGBColor[
             0.5944521800068164, 0.6063947956653419, 0.608398209845479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 409}], {
             RGBColor[
             0.8512991687650182, 0.8257312743348866, 0.627891920785604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 456}], {
             RGBColor[
             0.8857113160943386, 0.8526143053705582, 0.6313218020315902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 458}], {
             RGBColor[
             0.9546368864185306, 0.9070070486538089, 0.6183172738155114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 496}], {
             RGBColor[
             0.8318158009033293, 0.810510719282255, 0.6259500007595753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 217}], {
             RGBColor[
             0.9687403573208493, 0.9730822796515639, 0.753532233281389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 290}], {
             RGBColor[
             0.9260870716062445, 0.9436856210858553, 0.9853549654835176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 316}], {
             RGBColor[
             0.9421320250734591, 0.956362739566674, 0.9828395665522867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 340}], {
             RGBColor[
             0.944833852253287, 0.9583777578535537, 0.9782660778862244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 355}], {
             RGBColor[
             0.900149135203746, 0.9230034146650306, 0.9828809819543782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 378}], {
             RGBColor[
             0.8904624786542785, 0.9152795376697727, 0.9819570600053096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 384}], {
             RGBColor[
             0.9663404610708322, 0.9736782026197696, 0.9087604021400009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 146}], {
             RGBColor[
             0.9788289229570575, 0.9827298678502219, 0.8758784301433613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 201}], {
             RGBColor[
             0.8640002534497411, 0.894056176921622, 0.9583858217175032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 256}], {
             RGBColor[
             0.9762569529928831, 0.9682770999520496, 0.6682617011472209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 271}], {
             RGBColor[
             0.9598642009576931, 0.9695873673073625, 0.9528236180724392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 284}], {
             RGBColor[
             0.8941707525523398, 0.9176330279516867, 0.9613909639918505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 312}], {
             RGBColor[
             0.964635063601359, 0.973145468855438, 0.9447477920569741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 376}], {
             RGBColor[
             0.9506212758209094, 0.96264514289741, 0.9667752652951837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[
             0.9801588220019739, 0.9812068876938973, 0.7031586085714455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 415}], {
             RGBColor[
             0.8642219572727184, 0.8942293736331434, 0.9584079190826376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 442}], {
             RGBColor[
             0.9808440972117225, 0.982672622075598, 0.7777465861242214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 444}], {
             RGBColor[
             0.9566359459988316, 0.9671797400448261, 0.958288211654051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 464}], {
             RGBColor[
             0.9373457198068313, 0.8226160249522436, 0.5921170006980196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 148}], {
             RGBColor[
             0.7234002561317603, 0.783543331425272, 0.9733014477902429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 153}], {
             RGBColor[
             0.8041340513547872, 0.845506246241343, 0.8872090005675952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 190}], {
             RGBColor[
             0.7581575482023262, 0.6659119039608232, 0.599958058484207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 195}], {
             RGBColor[
             0.7630713132205222, 0.6871032111058506, 0.6040002387688431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 224}], {
             RGBColor[
             0.8056263127467909, 0.8443518255759532, 0.7337083568586188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 263}], {
             RGBColor[
             0.7893226987189939, 0.8354654204238068, 0.9573071636584733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 323}], {
             RGBColor[
             0.8052959553718079, 0.8436452245551189, 0.6977509953211152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 342}], {
             RGBColor[
             0.7779177255442358, 0.8269596101040018, 0.9766128083499379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 351}], {
             RGBColor[
             0.8043190795681925, 0.8455827601625941, 0.8841426042338036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 356}], {
             RGBColor[
             0.8040246624467762, 0.8454610111167136, 0.8890218578627596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 395}], {
             RGBColor[
             0.7866998957563414, 0.8335093382687061, 0.9617468849376745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 447}], {
             RGBColor[
             0.7638436768540943, 0.6901653755380399, 0.6046217006781197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 452}], {
             RGBColor[
             0.3984755524197334, 0.5030864179170726, 0.9482866339556524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 463}], {
             RGBColor[
             0.7289207884056532, 0.5039194751514936, 0.574417415039964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 130}], {
             RGBColor[
             0.9933939316750069, 0.9915362352264726, 0.7591431783093314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 143}], {
             RGBColor[
             0.9804075593534873, 0.9475129929992889, 0.5494972492113492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 209}], {
             RGBColor[
             0.9937384748178506, 0.9916787126703934, 0.7534332067833392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 214}], {
             RGBColor[
             0.9910020056869224, 0.9905471123607057, 0.798783582037919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 273}], {
             RGBColor[
             0.9803477630399757, 0.947311285992972, 0.5492649518249427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 302}], {
             RGBColor[
             0.7937503048481507, 0.8365648944800934, 0.8650147597923661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 308}], {
             RGBColor[
             0.991041757430545, 0.9905635507282669, 0.7981247927718798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 325}], {
             RGBColor[
             0.9933799159562007, 0.9915304393665587, 0.7593754550414682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 347}], {
             RGBColor[
             0.926032880872556, 0.9409526976522442, 0.8776159496406408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 386}], {
             RGBColor[
             0.9682366376745489, 0.9743994917141404, 0.8745222528723713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 421}], {
             RGBColor[
             0.8909167313984774, 0.9132022885204015, 0.8742001299048678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 423}], {
             RGBColor[
             0.993225728740114, 0.9900500430290953, 0.6589562566273683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 477}], {
             RGBColor[
             0.9796793261222339, 0.982933430022741, 0.8551527660615603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 115}], {
             RGBColor[
             0.96122986511456, 0.970605877399484, 0.9505119048771209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 203}], {
             RGBColor[
             0.9763318304862519, 0.9790733979537378, 0.7668191275369158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 208}], {
             RGBColor[
             0.9741310536450798, 0.9793436832724918, 0.889091632044044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 258}], {
             RGBColor[
             0.8740312140031701, 0.9020462681886159, 0.9671723949265411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 289}], {
             RGBColor[
             0.973916440131127, 0.9792549350691566, 0.8926483333722128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 291}], {
             RGBColor[
             0.9730081292485386, 0.9788793251766814, 0.9077013953299138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 297}], {
             RGBColor[
             0.8743445069404056, 0.9022910150122988, 0.9672036210386357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 311}], {
             RGBColor[
             0.9759127048871262, 0.9781769306773063, 0.7211998926154486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 349}], {
             RGBColor[
             0.9763399940131969, 0.979090858912414, 0.7677076770654274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 359}], {
             RGBColor[
             0.6182545015162745, 0.6890145647517381, 0.9469195888399471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 381}], {
             RGBColor[
             0.9743938634885757, 0.9794523618966823, 0.8847361928072449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 397}], {
             RGBColor[
             0.9768682884798543, 0.9804756002203977, 0.8437285670951531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 419}], {
             RGBColor[
             0.8079573320653891, 0.8504288494387195, 0.9605867678705158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 124}], {
             RGBColor[
             0.9780047869681605, 0.9817695955369965, 0.8617953236083276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 136}], {
             RGBColor[
             0.9303350607672858, 0.9465656183201551, 0.9681740207940817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 178}], {
             RGBColor[
             0.9683047453502636, 0.9758823114952186, 0.9385359780623648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 203}], {
             RGBColor[
             0.9788117937053914, 0.980922950462005, 0.7626211966849108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 253}], {
             RGBColor[
             0.8808708710896302, 0.9073016466809345, 0.963408997615575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 277}], {
             RGBColor[
             0.978687227018984, 0.9820518020359214, 0.8504855258679448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 291}], {
             RGBColor[
             0.9754880924676781, 0.9807288776849485, 0.9035034644779087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 297}], {
             RGBColor[
             0.876824470159545, 0.9041405675205659, 0.9630056901866306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 311}], {
             RGBColor[
             0.9783926681062657, 0.9800264831855734, 0.7170019617634436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 381}], {
             RGBColor[
             0.9768738267077152, 0.9813019144049494, 0.8805382619552399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 419}], {
             RGBColor[
             0.8104372952845286, 0.8522784019469867, 0.9563888370185107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 439}], {
             RGBColor[
             0.9785842888409854, 0.9804363405613108, 0.7378586961915885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 484}], {
             RGBColor[
             0.9695658656973664, 0.9768228529851928, 0.9364012302675846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 192}], {
             RGBColor[
             0.9898578645850317, 0.9886221067384204, 0.7122090571898633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 280}], {
             RGBColor[
             0.9900213040244334, 0.988689693146815, 0.7095004427112654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 310}], {
             RGBColor[
             0.876346526240114, 0.9002232934643885, 0.76064769112446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 327}], {
             RGBColor[
             0.9927858552827025, 0.9898329061378359, 0.6636846739324307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 399}], {
             RGBColor[
             0.9864896776685943, 0.9654122159035461, 0.4595346026431011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 412}], {
             RGBColor[
             0.9633051255881819, 0.8804180693825421, 0.40481489235704177`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 483}], {
             RGBColor[
             0.9898348324338944, 0.9886125823520258, 0.7125907595395051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 139}], {
             RGBColor[
             0.8441104374116244, 0.8782897888254587, 0.9448462423231223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 140}], {
             RGBColor[
             0.8515449146603373, 0.8819370188552675, 0.8453936748512378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 154}], {
             RGBColor[
             0.8375244822141352, 0.8733779942226831, 0.9559945465802542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 247}], {
             RGBColor[
             0.8513800501153692, 0.8815843902639431, 0.8274491865574881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 255}], {
             RGBColor[
             0.7948354397331395, 0.8401502614083416, 0.9800528725209734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 269}], {
             RGBColor[
             0.850890454188771, 0.8805371940826909, 0.7741596913830988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 338}], {
             RGBColor[
             0.8510647507570008, 0.8809099968180483, 0.7931307972011818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 369}], {
             RGBColor[
             0.8509890274250818, 0.8807480322678769, 0.7848887798320323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 390}], {
             RGBColor[
             0.850300648788321, 0.8792756599696018, 0.7099630134011186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 425}], {
             RGBColor[
             0.7894900966258337, 0.8358880299100493, 0.9795430289235545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 466}], {
             RGBColor[
             0.8451186402737798, 0.8619261182699332, 0.6787274737562773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[
             0.9597590133461532, 0.969508918558905, 0.9530016732614535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 151}], {
             RGBColor[
             0.9804979519704172, 0.984257212777188, 0.885707969823551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 188}], {
             RGBColor[
             0.8858904949399292, 0.9110677866314213, 0.9560516730452455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 304}], {
             RGBColor[
             0.9502495290448025, 0.9622187805521635, 0.9622346524110199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 310}], {
             RGBColor[
             0.8657857621044763, 0.8953618165387366, 0.9540478211656179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 327}], {
             RGBColor[
             0.9822250911470649, 0.9849714292121841, 0.8570848039735885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 483}], {
             RGBColor[
             0.9792740682982568, 0.9837511054263739, 0.9059908895806631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 197}], {
             RGBColor[
             0.7720927469035698, 0.8188209035296081, 0.8565622367224622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 237}], {
             RGBColor[
             0.8502738926546878, 0.8813027993686746, 0.8633931825074199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 270}], {
             RGBColor[
             0.9895845951638221, 0.9899609766836148, 0.8222737425465396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 309}], {
             RGBColor[
             0.8104058410521766, 0.8499251993446693, 0.8595783838393287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 320}], {
             RGBColor[
             0.9372102792136772, 0.9497097064612845, 0.8719277491394292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 345}], {
             RGBColor[
             0.9911194247821669, 0.9905956681741224, 0.7968376437588408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 375}], {
             RGBColor[
             0.9769255736106659, 0.9807450400589837, 0.8537844345323861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 426}], {
             RGBColor[
             0.9889063872136804, 0.98968031122733, 0.8335040421991207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 489}], {
             RGBColor[
             0.808941135715629, 0.8487360855682365, 0.8594630768698432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 123}], {
             RGBColor[
             0.9757259483789078, 0.9329172765205064, 0.5395799382812867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 125}], {
             RGBColor[
             0.8655774051951055, 0.8935556489954736, 0.8784142706712145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 177}], {
             RGBColor[
             0.8956532843450493, 0.9170511543725574, 0.8814119532298104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 438}], {
             RGBColor[
             0.9856143871169418, 0.966273302299724, 0.5779946555035823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 455}], {
             RGBColor[
             0.9775540736482757, 0.981482740783389, 0.8647654139691588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 457}], {
             RGBColor[
             0.9928441917469266, 0.9913089036385396, 0.7682537915989509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 161}], {
             RGBColor[
             0.9524662023752098, 0.9640699520776574, 0.9653464999655315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[
             0.9675963863983839, 0.975048846811952, 0.9260688311226182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.8221704140763011, 0.861701933684218, 0.97059441929708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 259}], {
             RGBColor[
             0.947395864979937, 0.9602885027501784, 0.9739292586199427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 341}], {
             RGBColor[
             0.9717206188418837, 0.9758876164279369, 0.7947192141514718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 450}], {
             RGBColor[
             0.9711073568074491, 0.9745759109465844, 0.7279694263178473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 454}], {
             RGBColor[
             0.9490745987007886, 0.9615404996105154, 0.9710876003144178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 469}], {
             RGBColor[
             0.9719415769939553, 0.9763602235729222, 0.8187691454088333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 471}], {
             RGBColor[
             0.9657774118772389, 0.9739974303291655, 0.9428140943980567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 475}], {
             RGBColor[
             0.9717779537733425, 0.9767780323828772, 0.8567694381700793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 491}], {
             RGBColor[
             0.9712320692019808, 0.9765522950840255, 0.8658161582215291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 500}], {
             RGBColor[
             0.9500697026470515, 0.9622826465043051, 0.9694031488980703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 150}], {
             RGBColor[
             0.983472037446628, 0.965616217995515, 0.6150806143722829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.9678447308057085, 0.9749790629546309, 0.914229085607357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 233}], {
             RGBColor[
             0.8766872206015031, 0.9030508520571628, 0.9165284302594897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 267}], {
             RGBColor[
             0.7208549861297472, 0.7784303463852547, 0.9029677751928074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 406}], {
             RGBColor[
             0.965643804341243, 0.9733376156011186, 0.9179546800181406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 413}], {
             RGBColor[
             0.9396070434590895, 0.9527835481901948, 0.9226459744305073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 476}], {
             RGBColor[
             0.9515987564575576, 0.9623454146287953, 0.9237897547214298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 493}], {
             RGBColor[
             0.9867604233116098, 0.9767087156678171, 0.6278553724981729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 125}], {
             RGBColor[
             0.8493002709699076, 0.8355118421235157, 0.6358010621363224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 177}], {
             RGBColor[
             0.8793761501198514, 0.8590073475005995, 0.6387987446949184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 438}], {
             RGBColor[
             0.969337252891744, 0.9082294954277661, 0.3353814469686902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 455}], {
             RGBColor[
             0.9612769394230778, 0.9234389339114312, 0.6221522054342667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 136}], {
             RGBColor[
             0.9446300194017467, 0.9558797839494004, 0.8836553703772934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 178}], {
             RGBColor[
             0.9825997039847247, 0.985196477124464, 0.8540173276455765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 253}], {
             RGBColor[
             0.8951658297240912, 0.91661581231018, 0.8788903471987867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 261}], {
             RGBColor[
             0.9928053274621036, 0.9895923987564754, 0.6452943085038662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 357}], {
             RGBColor[
             0.9917271088826202, 0.9908469611664289, 0.7867667455782893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 484}], {
             RGBColor[
             0.9838608243318274, 0.9861370186144383, 0.8518825798507963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 177}], {
             RGBColor[
             0.7692276069360491, 0.8196457199755667, 0.9776330770848463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 438}], {
             RGBColor[
             0.8591887097079417, 0.8688678679027333, 0.6742157793586181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 455}], {
             RGBColor[
             0.8511283962392755, 0.8840773063863984, 0.9609865378241946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 457}], {
             RGBColor[
             0.8664185143379264, 0.8939034692415491, 0.8644749154539867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 144}], {
             RGBColor[
             0.9731147229326047, 0.9767721862689953, 0.780048814559588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 279}], {
             RGBColor[
             0.9920559472536796, 0.9899240816196929, 0.7043489050182519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 285}], {
             RGBColor[
             0.9939686185766967, 0.9895078099387855, 0.5848995373240277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 481}], {
             RGBColor[
             0.9920900485808624, 0.9840224209012085, 0.5051988981884749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 130}], {
             RGBColor[
             0.9926922041214361, 0.9912460528494955, 0.7707726198846938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 168}], {
             RGBColor[
             0.7962711041766111, 0.8388909045991308, 0.876897890488387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 179}], {
             RGBColor[
             0.9662460043620518, 0.9731480455325456, 0.8883334756971353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 200}], {
             RGBColor[
             0.9887184994839688, 0.9896028238623518, 0.8366271893454801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 213}], {
             RGBColor[
             0.843292527161886, 0.8762559107346177, 0.8811527775199419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 254}], {
             RGBColor[
             0.993290360991107, 0.9913990267832186, 0.7539992335050231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 302}], {
             RGBColor[
             0.7930485772945799, 0.8362747121031164, 0.8766442013677285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 315}], {
             RGBColor[
             0.9781987834845082, 0.982062408631194, 0.868100538426891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 325}], {
             RGBColor[
             0.9926781884026299, 0.9912402569895817, 0.7710048966168306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 347}], {
             RGBColor[
             0.9253311533189852, 0.9406625152752672, 0.8892453912160033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 368}], {
             RGBColor[
             0.8943645422751707, 0.9161537571028069, 0.8862431586913175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 386}], {
             RGBColor[
             0.9675349101209781, 0.9741093093371633, 0.8861516944477338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 401}], {
             RGBColor[
             0.9918643658989962, 0.9909037204700448, 0.7844920416071679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 454}], {
             RGBColor[
             0.9701967117863735, 0.976094476660915, 0.8816459585372798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 169}], {
             RGBColor[
             0.9933108852083012, 0.991048331986526, 0.7275503480360086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 197}], {
             RGBColor[
             0.7726598532993512, 0.8186018552064662, 0.8141946909760558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 204}], {
             RGBColor[
             0.9005734206355129, 0.9199350967681723, 0.8259824997687073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 345}], {
             RGBColor[
             0.9916865311779484, 0.9903766198509806, 0.7544700980124344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 355}], {
             RGBColor[
             0.9255073219495124, 0.9397068424377069, 0.8283898737675219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 362}], {
             RGBColor[
             0.994662604367299, 0.9909921753721573, 0.6604356078472446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 498}], {
             RGBColor[
             0.9514452583520109, 0.9603890488585316, 0.8308638572966613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 170}], {
             RGBColor[
             0.8337814122214082, 0.8702887868114969, 0.9472645076801423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 206}], {
             RGBColor[
             0.9635197565516438, 0.9723136746839081, 0.9466357159734757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 265}], {
             RGBColor[
             0.9856691067546856, 0.9866900384068871, 0.8028195749618188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 266}], {
             RGBColor[
             0.7907057215113049, 0.8360642786543317, 0.9433631971038707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 328}], {
             RGBColor[
             0.9635799248039745, 0.9723585480679797, 0.9465338668166734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 410}], {
             RGBColor[
             0.9684894157614115, 0.9760200383854826, 0.9382233792260486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 433}], {
             RGBColor[
             0.9724465318361896, 0.9435363693856258, 0.6282244775823818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 143}], {
             RGBColor[
             0.9809899123272432, 0.9477538109197257, 0.5398461533550286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 179}], {
             RGBColor[
             0.9675300848893784, 0.9736790458299596, 0.8670529382654522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 214}], {
             RGBColor[
             0.9915843586606783, 0.9907879302811425, 0.7891324861815985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 254}], {
             RGBColor[
             0.9945744415184337, 0.9919300270806324, 0.7327186960733401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 302}], {
             RGBColor[
             0.7943326578219065, 0.8368057124005304, 0.8553636639360455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 315}], {
             RGBColor[
             0.9794828640118348, 0.9825934089286079, 0.846820000995208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 325}], {
             RGBColor[
             0.9939622689299565, 0.9917712572869956, 0.7497243591851476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 347}], {
             RGBColor[
             0.9266152338463118, 0.9411935155726812, 0.8679648537843203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 368}], {
             RGBColor[
             0.8956486228024974, 0.9166847574002208, 0.8649626212596345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 386}], {
             RGBColor[
             0.9688189906483048, 0.9746403096345773, 0.8648711570160508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 421}], {
             RGBColor[
             0.8914990843722332, 0.9134431064408384, 0.8645490340485471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 477}], {
             RGBColor[
             0.9802616790959897, 0.983174247943178, 0.8455016702052396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 135}], {
             RGBColor[
             0.9896501809576026, 0.9883546941926786, 0.7024555956154367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 147}], {
             RGBColor[
             0.7981933826898754, 0.8384236603624686, 0.7418291673204704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 170}], {
             RGBColor[
             0.8422321666657939, 0.8734300510196797, 0.7458062961265539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 171}], {
             RGBColor[
             0.9698605911491345, 0.9738813641249533, 0.7487490483654513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 216}], {
             RGBColor[
             0.9940050787484291, 0.9895857945594323, 0.5888680020110016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 238}], {
             RGBColor[
             0.9936424507989179, 0.9888101700427374, 0.5493981875869949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 265}], {
             RGBColor[
             0.9941198611990713, 0.98983130261507, 0.6013613634082304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 374}], {
             RGBColor[
             0.9700075385513025, 0.9071829960940838, 0.3988407862231555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 385}], {
             RGBColor[
             0.9177742506793902, 0.9326233406826818, 0.7532880604304539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 391}], {
             RGBColor[
             0.8229601678458667, 0.8583746190689368, 0.7438854433912521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 433}], {
             RGBColor[
             0.9808972862805753, 0.9466776335938086, 0.4267662660287934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 209}], {
             RGBColor[
             0.9918980372437234, 0.9909176444364036, 0.7839340202863898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 233}], {
             RGBColor[
             0.8774706965673973, 0.903374839503474, 0.9035442059338179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 273}], {
             RGBColor[
             0.9785073254658485, 0.9465502177589822, 0.5797657653279932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 423}], {
             RGBColor[
             0.9913852911659867, 0.9892889747951055, 0.6894570701304188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 151}], {
             RGBColor[
             0.9326205389578086, 0.9470294795832623, 0.9140235694684212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 155}], {
             RGBColor[
             0.935645820521037, 0.9476653840316349, 0.8191735692008874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 181}], {
             RGBColor[
             0.9093265608243226, 0.9303756410824947, 0.9856422883344059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 225}], {
             RGBColor[
             0.9355292342284203, 0.9474160177404102, 0.8064838707367536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 235}], {
             RGBColor[
             0.8351036700486839, 0.8715671987655553, 0.9840772897040531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 239}], {
             RGBColor[
             0.9357786006155616, 0.9479493872276962, 0.8336258630661304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 249}], {
             RGBColor[
             0.7681743060516435, 0.8192814709290608, 0.9774063961912952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 260}], {
             RGBColor[
             0.9351936517364585, 0.9480935278432161, 0.8713804317237814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 262}], {
             RGBColor[
             0.9073180128688274, 0.8480465129547177, 0.6285028060164328]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 296}], {
             RGBColor[
             0.9351424510035041, 0.9465887275320972, 0.7643849036540016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 332}], {
             RGBColor[
             0.9343799440731897, 0.9446703318769119, 0.7058351405056322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 344}], {
             RGBColor[
             0.8947549122495526, 0.9189172958254481, 0.9898237163591437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 424}], {
             RGBColor[
             0.7870330458281889, 0.8340140617742291, 0.9792860591272781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 440}], {
             RGBColor[
             0.8588491809673195, 0.8902870403361072, 0.9863989956560195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 138}], {
             RGBColor[
             0.6949225092951088, 0.7558699719920903, 0.8968450775491136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 251}], {
             RGBColor[
             0.6848457488561974, 0.7490040711113269, 0.942980753462863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 305}], {
             RGBColor[
             0.6381994808001963, 0.7126411876665503, 0.9673631482470639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 367}], {
             RGBColor[
             0.5778259665807729, 0.6650350593114004, 0.961462941988422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 416}], {
             RGBColor[
             0.403091343142159, 0.5235591942949139, 0.9469056018387072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 438}], {
             RGBColor[
             0.6904851451309826, 0.7319891165483536, 0.6603079763301986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 457}], {
             RGBColor[
             0.6977149497609674, 0.7570247178871694, 0.8505671124255672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 499}], {
             RGBColor[
             0.6967497798177691, 0.7566255953119208, 0.8665624761641083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 147}], {
             RGBColor[
             0.7944549556576415, 0.8385111286135899, 0.9225157985811829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 170}], {
             RGBColor[
             0.8384937396335601, 0.873517519270801, 0.9264929273872662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 171}], {
             RGBColor[
             0.9661221641169006, 0.9739688323760745, 0.9294356796261636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 216}], {
             RGBColor[
             0.9902666517161951, 0.9896732628105536, 0.769554633271714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 385}], {
             RGBColor[
             0.9140358236471563, 0.932710808933803, 0.9339746916911663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 391}], {
             RGBColor[
             0.8192217408136327, 0.8584620873200579, 0.9245720746519643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 253}], {
             RGBColor[
             0.8474961035232165, 0.8814118350933384, 0.9852690443845407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 261}], {
             RGBColor[
             0.9451356012612288, 0.9543884215396339, 0.7516730056896201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 277}], {
             RGBColor[
             0.9453124594525704, 0.9561619904483253, 0.8723455726369105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 291}], {
             RGBColor[
             0.9421133249012644, 0.9548390660973525, 0.9253635112468744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 311}], {
             RGBColor[
             0.945017900539852, 0.9541366715979773, 0.7388620085324092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 319}], {
             RGBColor[
             0.8601059406821191, 0.8912891464188546, 0.9865188665195398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 377}], {
             RGBColor[
             0.9374686452925762, 0.9290245945210638, 0.6794896452031984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 484}], {
             RGBColor[
             0.9361910981309527, 0.9509330413975967, 0.9582612770365504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 488}], {
             RGBColor[
             0.9447988349887331, 0.955949593532982, 0.8808576592201965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 145}], {
             RGBColor[
             0.9009528191836274, 0.9235170829595505, 0.9785486611468628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 183}], {
             RGBColor[
             0.8978494834421448, 0.9212026202447986, 0.983801799077602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 346}], {
             RGBColor[
             0.9227202350884132, 0.9359751901830358, 0.7057748964843131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 358}], {
             RGBColor[
             0.920560857575177, 0.9374769515733495, 0.9156321968208585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 404}], {
             RGBColor[
             0.8453658081288842, 0.5885513007059627, 0.5848314197587564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 407}], {
             RGBColor[
             0.8028104527000954, 0.8461472197863616, 0.9809096267125201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 408}], {
             RGBColor[
             0.7017489085702863, 0.7657909828363931, 0.9717981766466541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 430}], {
             RGBColor[
             0.9236050650411385, 0.9378677519818841, 0.802083176300978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 352}], {
             RGBColor[
             0.9906127088201468, 0.9885253111216028, 0.6699734879092147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 367}], {
             RGBColor[
             0.8710038772436945, 0.8985123194137671, 0.9114882310681245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 457}], {
             RGBColor[
             0.990892860423889, 0.9905019779895361, 0.8005924015052696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 140}], {
             RGBColor[
             0.9877686497515501, 0.9885010685990376, 0.8187207281982556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 247}], {
             RGBColor[
             0.987603785206582, 0.9881484400077132, 0.800776239904506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 255}], {
             RGBColor[
             0.9310591748243524, 0.9467143111521117, 0.9533799258679911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 269}], {
             RGBColor[
             0.9871141892799838, 0.987101243826461, 0.7474867447301167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 274}], {
             RGBColor[
             0.9720606964700516, 0.978683493690551, 0.9321781325255056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 360}], {
             RGBColor[
             0.8135762498200044, 0.8544362494104645, 0.941802879862196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 369}], {
             RGBColor[
             0.9872127625162946, 0.987312082011647, 0.7582158331790501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 370}], {
             RGBColor[
             0.9745688898562002, 0.9805541002111509, 0.9279324153643607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 425}], {
             RGBColor[
             0.9257138317170466, 0.9424520796538194, 0.9528700822705722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 466}], {
             RGBColor[
             0.9813423753649926, 0.9684901680137032, 0.652054527103295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 468}], {
             RGBColor[
             0.9179634205141216, 0.9362721121399148, 0.9521308411311635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 169}], {
             RGBColor[
             0.9935343259778466, 0.9915262491992565, 0.7518704968844423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 204}], {
             RGBColor[
             0.9007968614050583, 0.9204130139809028, 0.850302648617141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 219}], {
             RGBColor[
             0.9661874697293596, 0.8903812509093347, 0.49378666507229163`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 244}], {
             RGBColor[
             0.9950047263627539, 0.9921342975459819, 0.727502157232313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 247}], {
             RGBColor[
             0.9950382624552949, 0.9917956700375219, 0.7013236724326215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 255}], {
             RGBColor[
             0.9384936520730653, 0.9503615411819205, 0.8539273583961067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 274}], {
             RGBColor[
             0.9794951737187645, 0.9823307237203598, 0.8327255650536212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 334}], {
             RGBColor[
             0.9916576020994382, 0.9907501756459309, 0.7829726683553793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 361}], {
             RGBColor[
             0.9919418414097907, 0.9908677159053787, 0.7782620873950826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 363}], {
             RGBColor[
             0.9912347418009599, 0.9905753120454961, 0.7899805578285364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 369}], {
             RGBColor[
             0.9946472397650077, 0.9909593120414557, 0.6587632657071656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 370}], {
             RGBColor[
             0.9820033671049132, 0.9842013302409596, 0.8284798478924763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 425}], {
             RGBColor[
             0.9331483089657595, 0.9460993096836282, 0.8534175147986878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 466}], {
             RGBColor[
             0.9887768526137055, 0.972137398043512, 0.5526019596314107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 188}], {
             RGBColor[
             0.8731720044922169, 0.9015823572801341, 0.97758075985965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 220}], {
             RGBColor[
             0.9691826049389795, 0.9753520192876715, 0.8839833390115255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[
             0.8846440233769789, 0.5660166416270225, 0.5717341600429362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 304}], {
             RGBColor[
             0.9375310385970903, 0.9527333512008763, 0.9837637392254244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 310}], {
             RGBColor[
             0.853067271656764, 0.8858763871874494, 0.9755769079800224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 429}], {
             RGBColor[
             0.9671534397500489, 0.9745129073348819, 0.9176118575032797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 173}], {
             RGBColor[
             0.9284888819107684, 0.9407007641970444, 0.716523813137399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 222}], {
             RGBColor[
             0.9939495893397075, 0.9894671083250167, 0.5828283223125964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 241}], {
             RGBColor[
             0.9933035976945911, 0.9880853975158868, 0.5125161183399871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 402}], {
             RGBColor[
             0.9682087680868317, 0.9721653842987903, 0.7131376274306356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 417}], {
             RGBColor[
             0.9366320451984296, 0.9471939015623465, 0.7173005153212638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 461}], {
             RGBColor[
             0.9532844962325216, 0.9604721139981898, 0.718888840966714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 179}], {
             RGBColor[
             0.9545437125678589, 0.9296558036027758, 0.65740700916747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 214}], {
             RGBColor[
             0.9785979863391587, 0.9467646880539589, 0.5794865570836162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 226}], {
             RGBColor[
             0.9253346124853077, 0.9065041214172671, 0.6594354296627993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 273}], {
             RGBColor[
             0.967943743692212, 0.903528861686225, 0.32996792687063986`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 283}], {
             RGBColor[
             0.9696675048971707, 0.9409351031590394, 0.6318063736707202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 292}], {
             RGBColor[
             0.9777280819833503, 0.9464049602473098, 0.5939031234996706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 302}], {
             RGBColor[
             0.781346285500387, 0.7927824701733466, 0.6457177348380632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 308}], {
             RGBColor[
             0.9786377380827813, 0.9467811264215199, 0.5788277678175769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 325}], {
             RGBColor[
             0.980975896608437, 0.9477480150598119, 0.5400784300871654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 347}], {
             RGBColor[
             0.9136288615247923, 0.8971702733454974, 0.6583189246863381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 386}], {
             RGBColor[
             0.9558326183267852, 0.9306170674073935, 0.6552252279180686]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 421}], {
             RGBColor[
             0.8785127120507137, 0.8694198642136546, 0.6549031049505649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 423}], {
             RGBColor[
             0.9808217093923502, 0.9462676187223484, 0.43965923167306553`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 446}], {
             RGBColor[
             0.9813359298371418, 0.9473674842580952, 0.4956289536878903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 477}], {
             RGBColor[
             0.9672753067744702, 0.9391510057159942, 0.6358557411072574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 279}], {
             RGBColor[
             0.9711160715076083, 0.9770045552056903, 0.8901397787610213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 494}], {
             RGBColor[
             0.8705281482152276, 0.8994260554081019, 0.9727158383564268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 183}], {
             RGBColor[
             0.9458679466227298, 0.95914898374111, 0.9765156258537646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 286}], {
             RGBColor[
             0.8501925341403481, 0.883596437030445, 0.9735600249041317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 294}], {
             RGBColor[
             0.9186309301022861, 0.9376131287465513, 0.9802348151477204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 346}], {
             RGBColor[
             0.9707386982689981, 0.9739215536793472, 0.6984887232604755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 358}], {
             RGBColor[
             0.968579320755762, 0.975423315069661, 0.9083460235970209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 404}], {
             RGBColor[
             0.8933842713094691, 0.6264976642022742, 0.5775452465349189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 407}], {
             RGBColor[
             0.8508289158806804, 0.8840935832826731, 0.9736234534886825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 408}], {
             RGBColor[
             0.7497673717508713, 0.8037373463327045, 0.9645120034228165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 430}], {
             RGBColor[
             0.9716235282217234, 0.9758141154781955, 0.7947970030771405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 201}], {
             RGBColor[
             0.8753906579343372, 0.9015497638637737, 0.8942619776425336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 211}], {
             RGBColor[
             0.9826960371644015, 0.9590687208528952, 0.584902912634329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 271}], {
             RGBColor[
             0.9712546054422893, 0.9770809542495144, 0.8886997739974696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 284}], {
             RGBColor[
             0.905561157036936, 0.9251266148938384, 0.8972671199168809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 312}], {
             RGBColor[
             0.976025468085955, 0.9806390557975897, 0.8806239479820045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 376}], {
             RGBColor[
             0.9620116803055054, 0.9701387298395618, 0.902651421220214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 400}], {
             RGBColor[
             0.99154922648657, 0.988700474636049, 0.6390347644964759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 415}], {
             RGBColor[
             0.8756123617573146, 0.9017229605752952, 0.8942840750076679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 442}], {
             RGBColor[
             0.9922345016963187, 0.9901662090177499, 0.7136227420492518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 444}], {
             RGBColor[
             0.9680263504834278, 0.9746733269869778, 0.8941643675790814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 464}], {
             RGBColor[
             0.9487361242914274, 0.8301096118943954, 0.52799315662305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 497}], {
             RGBColor[
             0.6795403474670776, 0.7420671823140773, 0.8782395420635408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 171}], {
             RGBColor[
             0.7746653658491733, 0.8240377985458645, 0.9688092513311974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 216}], {
             RGBColor[
             0.798809853448468, 0.8397422289803436, 0.8089282049767479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 238}], {
             RGBColor[
             0.7984472254989567, 0.8389666044636487, 0.769458390552741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 385}], {
             RGBColor[
             0.7225790253794291, 0.782779775103593, 0.9733482633962001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 391}], {
             RGBColor[
             0.6277649425459055, 0.7085310534898479, 0.9639456463569982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 153}], {
             RGBColor[
             0.9095102026470807, 0.9282707418324697, 0.8974381804465335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 190}], {
             RGBColor[
             0.8635336994946197, 0.74867639955195, 0.6101872383631453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 195}], {
             RGBColor[
             0.8684474645128157, 0.7698677066969773, 0.6142294186477812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 323}], {
             RGBColor[
             0.9106721066641014, 0.9264097201462457, 0.7079801752000533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 342}], {
             RGBColor[
             0.8832938768365293, 0.9097241056951286, 0.9868419882288761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 351}], {
             RGBColor[
             0.909695230860486, 0.9283472557537209, 0.8943717841127419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 356}], {
             RGBColor[
             0.9094008137390697, 0.9282255067078404, 0.8992510377416978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 452}], {
             RGBColor[
             0.5038517037120269, 0.5858509135081994, 0.9585158138345905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 463}], {
             RGBColor[
             0.8342969396979467, 0.5866839707426204, 0.5846465949189021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 158}], {
             RGBColor[
             0.9900515771451555, 0.9882241324942359, 0.6742474157120888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 165}], {
             RGBColor[
             0.9916384247457752, 0.9888803347572155, 0.6479492443398687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 182}], {
             RGBColor[
             0.9869131516144833, 0.9671827120322626, 0.4320968857578622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 187}], {
             RGBColor[
             0.9389914500520297, 0.9493107841122506, 0.7366205846234918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 275}], {
             RGBColor[
             0.7051359258172475, 0.7616673812601568, 0.7160800538419481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 282}], {
             RGBColor[
             0.9697140739409443, 0.9735326520158039, 0.7299985385724286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 324}], {
             RGBColor[
             0.9933637438928891, 0.9895937985632266, 0.6193562410893694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 441}], {
             RGBColor[
             0.9296040597578663, 0.7363462176686175, 0.34719473950900326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 159}], {
             RGBColor[
             0.9637530166311286, 0.9514699750047121, 0.6735453501565432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 233}], {
             RGBColor[
             0.8725955064269229, 0.879541764107244, 0.6758446948086758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 267}], {
             RGBColor[
             0.7167632719551671, 0.7549212584353359, 0.6622840397419936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 406}], {
             RGBColor[
             0.9615520901666628, 0.9498285276512, 0.6772709445673268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 413}], {
             RGBColor[
             0.9355153292845095, 0.929274460240276, 0.6819622389796935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 443}], {
             RGBColor[
             0.9811490061323647, 0.9480733126399292, 0.3812678778460675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 476}], {
             RGBColor[
             0.9475070422829776, 0.9388363266788766, 0.683106019270616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 188}], {
             RGBColor[
             0.8939109431164809, 0.9163306514984172, 0.9102870564217477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 192}], {
             RGBColor[
             0.9873175486259458, 0.9890234946797645, 0.8598445706075233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 249}], {
             RGBColor[
             0.8240721672408038, 0.8617720689899825, 0.9033261799229272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 260}], {
             RGBColor[
             0.9910915129256188, 0.9905841259041377, 0.7973002154554134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 280}], {
             RGBColor[
             0.9874809880653475, 0.989091081088159, 0.8571359561289256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 310}], {
             RGBColor[
             0.873806210281028, 0.9006246814057325, 0.9082832045421201]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 327}], {
             RGBColor[
             0.9902455393236166, 0.99023429407918, 0.8113201873500907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 424}], {
             RGBColor[
             0.8429309070173492, 0.8765046598351507, 0.90520584285891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 483}], {
             RGBColor[
             0.9872945164748084, 0.9890139702933698, 0.8602262729571652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 191}], {
             RGBColor[
             0.7968579196107413, 0.8385289785062002, 0.8392158439069364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 212}], {
             RGBColor[
             0.9939402173576009, 0.9916752760351213, 0.7437758342000008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 287}], {
             RGBColor[
             0.9936109638121823, 0.9915391212326605, 0.7492324175284482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 299}], {
             RGBColor[
             0.9820639289723276, 0.9842313017992351, 0.8271716437779466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 301}], {
             RGBColor[
             0.9445505012139483, 0.9551764754487309, 0.8533188815024207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 389}], {
             RGBColor[
             0.9863810576999035, 0.9640692828824404, 0.5421498978171664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 451}], {
             RGBColor[
             0.9936128788197895, 0.9915399131375197, 0.7492006808965138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 190}], {
             RGBColor[
             0.9442674947176467, 0.8106393143680208, 0.5240947911404977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 195}], {
             RGBColor[
             0.9491812597358428, 0.8318306215130482, 0.5281369714251338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 263}], {
             RGBColor[
             0.9754326452343143, 0.9801928308310044, 0.8814438963147639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 323}], {
             RGBColor[
             0.9914059018871284, 0.9883726349623165, 0.6218877279774058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 342}], {
             RGBColor[
             0.9640276720595562, 0.9716870205111994, 0.9007495410062286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 351}], {
             RGBColor[
             0.9904290260835129, 0.9903101705697919, 0.8082793368900943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[
             0.9901346089620966, 0.9901884215239112, 0.8131585905190503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 395}], {
             RGBColor[
             0.9728098422716618, 0.9782367486759038, 0.8858836175939652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 447}], {
             RGBColor[
             0.9499536233694148, 0.8348927859452375, 0.5287584333344104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 452}], {
             RGBColor[
             0.5845854989350538, 0.6478138283242703, 0.872423366611943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 463}], {
             RGBColor[
             0.9150307349209738, 0.6486468855586913, 0.49855414769625467`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 174}], {
             RGBColor[
             0.9809244640491486, 0.9830369450573633, 0.8017622356096167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 229}], {
             RGBColor[
             0.9786316813628322, 0.9826024071630497, 0.8770919073425854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 255}], {
             RGBColor[
             0.9244732196268632, 0.9418025165493362, 0.964528230125123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 313}], {
             RGBColor[
             0.9800961584922067, 0.9832080060913916, 0.8528217313635296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 338}], {
             RGBColor[
             0.9807025306507244, 0.9825622519590429, 0.7776061548053315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 369}], {
             RGBColor[
             0.9806268073188055, 0.9824002874088714, 0.7693641374361819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 379}], {
             RGBColor[
             0.9166625456419719, 0.9355744971288813, 0.9637832410677731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 380}], {
             RGBColor[
             0.8382256919297999, 0.8739257845819517, 0.9560644366115343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 390}], {
             RGBColor[
             0.9799384286820447, 0.9809279151105963, 0.6944383710052682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 425}], {
             RGBColor[
             0.9191278765195574, 0.9375402850510439, 0.9640183865277041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 478}], {
             RGBColor[
             0.9749334718741681, 0.9808260048832032, 0.9273152731061602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 181}], {
             RGBColor[
             0.9682497035767113, 0.973502143591789, 0.816712071798504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 235}], {
             RGBColor[
             0.8940268128010727, 0.9146937012748496, 0.8151470731681512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 262}], {
             RGBColor[
             0.966241155621216, 0.8911730154640121, 0.45957258948053087`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 332}], {
             RGBColor[
             0.9933030868255784, 0.9877968343862062, 0.5369049239697303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 344}], {
             RGBColor[
             0.9536780550019412, 0.9620437983347424, 0.8208934998232418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 387}], {
             RGBColor[
             0.9514846701485009, 0.9602948527904548, 0.8206842928178628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 393}], {
             RGBColor[
             0.7506014581650238, 0.8005695895443043, 0.802273289896187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 403}], {
             RGBColor[
             0.9946278146319321, 0.9909177636459892, 0.6566489598499075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 232}], {
             RGBColor[
             0.8960097206300492, 0.8875356274245474, 0.6631325245793263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 307}], {
             RGBColor[
             0.7327191646099522, 0.7576943598814385, 0.6484123053319746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 350}], {
             RGBColor[
             0.962983726636691, 0.940453116740006, 0.6526787836423364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 354}], {
             RGBColor[
             0.9814781573177116, 0.9530279089115251, 0.566813501022298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 372}], {
             RGBColor[
             0.9546639432962808, 0.8533905275258336, 0.30620197614416905`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 479}], {
             RGBColor[
             0.9803555040025038, 0.9525636629148125, 0.5854187717889362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 180}], {
             RGBColor[
             0.9071580222162112, 0.9249519018708439, 0.8164558694045234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 216}], {
             RGBColor[
             0.9071843153330093, 0.9250081401890327, 0.8193177129056701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 238}], {
             RGBColor[
             0.906821687383498, 0.9242325156723379, 0.7798478984816634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 246}], {
             RGBColor[
             0.9070928690619466, 0.924812545861866, 0.8093643506414723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 281}], {
             RGBColor[
             0.9065846431350502, 0.923725501993758, 0.7540470949056544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 288}], {
             RGBColor[
             0.8936206452524227, 0.9171948661355076, 0.9612881951201269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 343}], {
             RGBColor[
             0.888015497945734, 0.9130145564517655, 0.9707762474538009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 392}], {
             RGBColor[
             0.9055310298304302, 0.9248942259317383, 0.8881325993453622]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 459}], {
             RGBColor[
             0.8281031747508873, 0.8657729244840218, 0.9834659059731206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 465}], {
             RGBColor[
             0.903259473645152, 0.9239548790727947, 0.9257781639343843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 182}], {
             RGBColor[
             0.9839198717216213, 0.9678748671123294, 0.6219905068357652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 206}], {
             RGBColor[
             0.968805355627258, 0.9757794697084636, 0.916363540637521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 282}], {
             RGBColor[
             0.9667207940480822, 0.9742248070958706, 0.9198921596503316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 324}], {
             RGBColor[
             0.9903704640000269, 0.9902859536432933, 0.8092498621672723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 410}], {
             RGBColor[
             0.9737750148370254, 0.979485833410038, 0.9079512038900941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 441}], {
             RGBColor[
             0.9266107798650042, 0.7370383727486844, 0.5370883605869062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 164}], {
             RGBColor[
             0.947301117242646, 0.960217840042842, 0.9740896418250089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 396}], {
             RGBColor[
             0.9575600130207307, 0.9678689077167375, 0.9567240072212544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 443}], {
             RGBColor[
             0.9655216994914453, 0.9574361575990451, 0.6804163490811417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 165}], {
             RGBColor[
             0.8523467249634695, 0.8835453399387299, 0.8918595965853633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 268}], {
             RGBColor[
             0.8290531909908221, 0.8671765226325923, 0.9762265607808742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 275}], {
             RGBColor[
             0.5658442260349418, 0.6563323864416711, 0.9599904060874427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 285}], {
             RGBColor[
             0.8541720479740615, 0.8830929474858855, 0.7738578164782058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 324}], {
             RGBColor[
             0.8540720441105834, 0.884258803744741, 0.8632665933348639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 353}], {
             RGBColor[
             0.7822841349927958, 0.8300890504062256, 0.9788698199367696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 441}], {
             RGBColor[
             0.7903123599755606, 0.6310112228501319, 0.5911050917544978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 480}], {
             RGBColor[
             0.606435032121784, 0.6902657868309507, 0.9629150984312285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 481}], {
             RGBColor[
             0.8522934779782272, 0.8776075584483085, 0.694157177342653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 259}], {
             RGBColor[
             0.9506981699322072, 0.9627513563765535, 0.9683393177148212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 326}], {
             RGBColor[
             0.904683352705192, 0.6897588099076002, 0.5793577800580463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 341}], {
             RGBColor[
             0.9750229237941539, 0.978350470054312, 0.7891292732463503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 387}], {
             RGBColor[
             0.9320844421755281, 0.9481653123720064, 0.9754408960155752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 403}], {
             RGBColor[
             0.9752275866589593, 0.9787882232275407, 0.8114055630476198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 405}], {
             RGBColor[
             0.9689486476815623, 0.9763625327996078, 0.9374460193721006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 450}], {
             RGBColor[
             0.9744096617597193, 0.9770387645729595, 0.7223794854127258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 469}], {
             RGBColor[
             0.9752438819462256, 0.9788230771992973, 0.8131792045037117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 491}], {
             RGBColor[
             0.974534374154251, 0.9790151487104006, 0.8602262173164077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 203}], {
             RGBColor[
             0.994434753278346, 0.9905048249321657, 0.6356354229486325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 221}], {
             RGBColor[
             0.9302211035450845, 0.7368532165113577, 0.450906685017035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 223}], {
             RGBColor[
             0.9881267619070053, 0.9700971641561889, 0.537094124270323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 258}], {
             RGBColor[
             0.892134136795264, 0.9134776951670438, 0.8359886903382578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 289}], {
             RGBColor[
             0.992019362923221, 0.9906863620475844, 0.7614646287839296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 297}], {
             RGBColor[
             0.8924474297324996, 0.9137224419907266, 0.8360199164503525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 381}], {
             RGBColor[
             0.9924967862806697, 0.9908837888751101, 0.7535524882189617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 439}], {
             RGBColor[
             0.9942072484139399, 0.9900182150314714, 0.6108729224553102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 187}], {
             RGBColor[
             0.6942376479707324, 0.7594614213230804, 0.9714734090791679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.7479289305396528, 0.7994628201119183, 0.8654951847217485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 322}], {
             RGBColor[
             0.7478744055311219, 0.7994402726196619, 0.8663988052193057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 364}], {
             RGBColor[
             0.7487376111829414, 0.7986377532391259, 0.7678115084884645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 437}], {
             RGBColor[
             0.7134521623425532, 0.7747825535190719, 0.9733061066129516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 494}], {
             RGBColor[
             0.6462093510596725, 0.7214163513985199, 0.9668257159780171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 166}], {
             RGBColor[
             0.9693985663494828, 0.9753476242549319, 0.8762081940781796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 227}], {
             RGBColor[
             0.9495704145034289, 0.9619102782243006, 0.9702483134900197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 309}], {
             RGBColor[
             0.7868330869649134, 0.8339113489807629, 0.9696396377073707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 348}], {
             RGBColor[
             0.9705661637703198, 0.9752902440772628, 0.8175903941034398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 396}], {
             RGBColor[
             0.9567354202731677, 0.9672539277957517, 0.9581198276546461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 428}], {
             RGBColor[
             0.872890005290538, 0.9013720427372534, 0.9780581109509213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 443}], {
             RGBColor[
             0.9646971067438822, 0.9568211776780592, 0.6818121695145332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 182}], {
             RGBColor[
             0.9855067193222411, 0.9685310693753089, 0.5956923354635452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 268}], {
             RGBColor[
             0.9669384584808856, 0.9738598747941243, 0.8959116582410627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 275}], {
             RGBColor[
             0.7037294935250052, 0.763015738603203, 0.8796755035476311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 282}], {
             RGBColor[
             0.9683076416487021, 0.9748810093588501, 0.8935939882781115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 285}], {
             RGBColor[
             0.992057315464125, 0.9897762996474174, 0.6935429139383942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 324}], {
             RGBColor[
             0.9919573116006468, 0.9909421559062729, 0.7829516907950522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 353}], {
             RGBColor[
             0.9201694024828593, 0.9367724025677575, 0.898554917396958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 441}], {
             RGBColor[
             0.9281976274656241, 0.7376945750116639, 0.5107901892146862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 481}], {
             RGBColor[
             0.9901787454682907, 0.9842909106098405, 0.6138422748028414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 210}], {
             RGBColor[
             0.9388939532751599, 0.9513019964963374, 0.8829343906759363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 227}], {
             RGBColor[
             0.9724924563578289, 0.9776550423573764, 0.870971045309799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 243}], {
             RGBColor[
             0.8697607814373837, 0.8967653601026352, 0.8761842960678909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 309}], {
             RGBColor[
             0.8097551288193133, 0.8496561131138387, 0.8703623695271498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 320}], {
             RGBColor[
             0.936559566980814, 0.949440620230454, 0.8827117348272503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 348}], {
             RGBColor[
             0.9934882056247197, 0.9910350082103386, 0.7183131259232189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 428}], {
             RGBColor[
             0.8958120471449379, 0.9171168068703291, 0.8787808427707005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 495}], {
             RGBColor[
             0.7320201673690891, 0.7865473694884411, 0.864242788609242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 210}], {
             RGBColor[
             0.9402681865242862, 0.9516865894612925, 0.8468076254019998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 326}], {
             RGBColor[
             0.9243336363925198, 0.702423194214543, 0.4518181982028842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 434}], {
             RGBColor[
             0.986391941942828, 0.964175267130803, 0.5363020332717849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 474}], {
             RGBColor[
             0.7451217826750265, 0.7964527795196563, 0.8290392458096336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 495}], {
             RGBColor[
             0.7333944006182156, 0.7869319624533961, 0.8281160233353055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 200}], {
             RGBColor[
             0.7935814800664703, 0.8377786759094009, 0.9214719225174901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 213}], {
             RGBColor[
             0.6481555077443875, 0.7244317627816668, 0.965997510691952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 254}], {
             RGBColor[
             0.7981533415736086, 0.8395748788302677, 0.8388439666770331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 261}], {
             RGBColor[
             0.797222497040349, 0.8375838964964444, 0.737527283738295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 315}], {
             RGBColor[
             0.7830617640670097, 0.8302382606782432, 0.9529452715989011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 368}], {
             RGBColor[
             0.6992275228576723, 0.7643296091498561, 0.9710878918633277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 401}], {
             RGBColor[
             0.7967273464814977, 0.8390795725170939, 0.8693367747791779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 500}], {
             RGBColor[
             0.776054796315138, 0.8250124756017538, 0.9648062402929424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 204}], {
             RGBColor[
             0.8991280603826419, 0.9197909645513129, 0.8829049847752122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 219}], {
             RGBColor[
             0.9645186687069431, 0.889759201479745, 0.5263890012303627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 244}], {
             RGBColor[
             0.9933359253403375, 0.991512248116392, 0.7601044933903842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 274}], {
             RGBColor[
             0.9778263726963481, 0.9817086742907699, 0.8653279012116923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 334}], {
             RGBColor[
             0.9899888010770217, 0.990128126216341, 0.8155750045134503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 337}], {
             RGBColor[
             0.9498776901730681, 0.9601474713586684, 0.8877746860020812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 340}], {
             RGBColor[
             0.9687466787461824, 0.9749370534093706, 0.880697454705873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 361}], {
             RGBColor[
             0.9902730403873743, 0.9902456664757889, 0.8108644235531537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 363}], {
             RGBColor[
             0.9895659407785435, 0.9899532626159063, 0.8225828939866076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 370}], {
             RGBColor[
             0.9803345660824967, 0.9835792808113698, 0.8610821840505474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 498}], {
             RGBColor[
             0.9499998980991399, 0.9602449166416723, 0.8877863423031662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 171}], {
             RGBColor[
             0.818704149825092, 0.8590441892030756, 0.9727863801372808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 238}], {
             RGBColor[
             0.8424860094748753, 0.8739729951208598, 0.7734355193588245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 265}], {
             RGBColor[
             0.8429634198750287, 0.8749941276931923, 0.82539869518006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 266}], {
             RGBColor[
             0.648000034631648, 0.724368367940637, 0.965942317322112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 328}], {
             RGBColor[
             0.8208742379243177, 0.8606626373542849, 0.9691129870349147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 374}], {
             RGBColor[
             0.81885109722726, 0.7923458211722062, 0.622878117994985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 433}], {
             RGBColor[
             0.8297408449565327, 0.831840458671931, 0.650803597800623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 216}], {
             RGBColor[
             0.970477061907727, 0.975199932742828, 0.8158480860217285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 238}], {
             RGBColor[
             0.9701144339582157, 0.9744243082261332, 0.7763782715977219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 265}], {
             RGBColor[
             0.9705918443583692, 0.9754454407984657, 0.8283414474189574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 343}], {
             RGBColor[
             0.9513082445204518, 0.9632063490055609, 0.9673066205698593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 385}], {
             RGBColor[
             0.8942462338386882, 0.9182374788660775, 0.9802681444411809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 391}], {
             RGBColor[
             0.7994321510051646, 0.8439887572523325, 0.970865527401979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 433}], {
             RGBColor[
             0.9573692694398732, 0.9322917717772043, 0.6537463500395204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 465}], {
             RGBColor[
             0.96655222021987, 0.9741466716265901, 0.9223085370504428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 303}], {
             RGBColor[
             0.9361428371651115, 0.9517374116126122, 0.9874788887117119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 366}], {
             RGBColor[
             0.9604555054563368, 0.9686784970294313, 0.892976701584989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 448}], {
             RGBColor[
             0.9613368078123541, 0.9671821212218639, 0.7431094901292264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 473}], {
             RGBColor[
             0.9570990764899701, 0.9672905273955488, 0.9486014157174115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 241}], {
             RGBColor[
             0.9290988004929739, 0.9420053183721541, 0.7829096868292995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 417}], {
             RGBColor[
             0.8724272479968125, 0.9011138224186137, 0.9876940838105761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 461}], {
             RGBColor[
             0.8890796990309044, 0.914392034854457, 0.9892824094560264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 493}], {
             RGBColor[
             0.9251205898555813, 0.929456405221756, 0.6934318883999802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 215}], {
             RGBColor[
             0.994140029478166, 0.989874440524728, 0.603556556123505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 229}], {
             RGBColor[
             0.9923938833041219, 0.9906091028567353, 0.7383842387677981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 294}], {
             RGBColor[
             0.9414886219153991, 0.9524032258941448, 0.8261308547036226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 338}], {
             RGBColor[
             0.9944647325920142, 0.9905689476527284, 0.6388984862305445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 356}], {
             RGBColor[
             0.9923559430222619, 0.9905934135751654, 0.739013007424522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 390}], {
             RGBColor[
             0.9937006306233345, 0.9889346108042819, 0.5557307024304812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 430}], {
             RGBColor[
             0.9944812200348365, 0.990604212625789, 0.6406930426330426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 309}], {
             RGBColor[
             0.7451996021706128, 0.8009918609978337, 0.9753043525856148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 320}], {
             RGBColor[
             0.8720040403321134, 0.9007763681144487, 0.9876537178857152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 337}], {
             RGBColor[
             0.8855497051485939, 0.9115773135518339, 0.9889457154882688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 348}], {
             RGBColor[
             0.9289326789760192, 0.9423707560943335, 0.8232551089816839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 361}], {
             RGBColor[
             0.9259450553629001, 0.9416755086689543, 0.9120354530393413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 370}], {
             RGBColor[
             0.9160065810580225, 0.9350091230045352, 0.962253213536735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 375}], {
             RGBColor[
             0.9117193347291022, 0.9318117017121481, 0.9695104032786721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 197}], {
             RGBColor[
             0.7469513251669391, 0.7295385215043226, 0.615514552215533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 237}], {
             RGBColor[
             0.8251324709180571, 0.7920204173433891, 0.6223454980004905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 345}], {
             RGBColor[
             0.9659780030455363, 0.9013132861488369, 0.5557899592519115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 426}], {
             RGBColor[
             0.9637649654770497, 0.9003979292020445, 0.5924563576921913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 448}], {
             RGBColor[
             0.9682320934393056, 0.9003845934739234, 0.3831720973490357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 245}], {
             RGBColor[
             0.8615954689275169, 0.8926440087046097, 0.9866165818144399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 438}], {
             RGBColor[
             0.8892645888578855, 0.8923633732798171, 0.677213461917214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 455}], {
             RGBColor[
             0.8812042753892193, 0.9075728117634821, 0.9639842203827906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 357}], {
             RGBColor[
             0.9820270672647233, 0.9849596771246509, 0.8635074000323265]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 420}], {
             RGBColor[
             0.9823250941681154, 0.9850829189081456, 0.8585683229742165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 439}], {
             RGBColor[
             0.9831792058575495, 0.9838632221487782, 0.7300807002288374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 236}], {
             RGBColor[
             0.9673821327440263, 0.972236168023741, 0.7690701900516168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 254}], {
             RGBColor[
             0.9681282417590493, 0.9738320197636825, 0.8502795518857813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 276}], {
             RGBColor[
             0.9653180638966741, 0.9727643183031297, 0.9037118506413898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 283}], {
             RGBColor[
             0.956207677459306, 0.9668603380692731, 0.9590131585811438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 292}], {
             RGBColor[
             0.9642682545454855, 0.9723301951575436, 0.9211099084100942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 315}], {
             RGBColor[
             0.9530366642524506, 0.964495401611658, 0.9643808568076493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 325}], {
             RGBColor[
             0.9675160691705722, 0.9736732499700456, 0.8672852149975889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 347}], {
             RGBColor[
             0.9001690340869276, 0.9230955082557312, 0.9855257095967616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 368}], {
             RGBColor[
             0.869202423043113, 0.8985867500832709, 0.9825234770720759]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 386}], {
             RGBColor[
             0.9423727908889206, 0.9565423023176274, 0.982432012828492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 401}], {
             RGBColor[
             0.9667022466669386, 0.9733367134505087, 0.8807723599879262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 216}], {
             RGBColor[
             0.9945952563902236, 0.9908481248591182, 0.6531051961661323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 281}], {
             RGBColor[
             0.9939955841922646, 0.9895654866638435, 0.5878345781661165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 288}], {
             RGBColor[
             0.9810315863096372, 0.983034850805593, 0.795075678380589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 343}], {
             RGBColor[
             0.9754264390029485, 0.978854541121851, 0.804563730714263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 392}], {
             RGBColor[
             0.9929419708876446, 0.9907342106018238, 0.7219200826058243]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 465}], {
             RGBColor[
             0.9906704147023666, 0.9897948637428802, 0.7595656471948464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 235}], {
             RGBColor[
             0.8677075531043582, 0.8974039583257094, 0.9816157923016697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 239}], {
             RGBColor[
             0.9683824836712359, 0.9737861467878502, 0.8311643656637471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 262}], {
             RGBColor[
             0.9399218959245017, 0.8738832725148717, 0.6260413086140495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 296}], {
             RGBColor[
             0.9677463340591784, 0.9724254870922513, 0.7619234062516183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 332}], {
             RGBColor[
             0.966983827128864, 0.9705070914370659, 0.7033736431032489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 344}], {
             RGBColor[
             0.9273587953052269, 0.9447540553856022, 0.9873622189567604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 387}], {
             RGBColor[
             0.9251654104517865, 0.9430051098413146, 0.9871530119513814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 393}], {
             RGBColor[
             0.7242821984683094, 0.783279846595164, 0.9687420090297055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 424}], {
             RGBColor[
             0.8196369288838632, 0.8598508213343832, 0.9768245617248947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 275}], {
             RGBColor[
             0.6990042203937133, 0.7413181158782503, 0.6638231449656247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 282}], {
             RGBColor[
             0.9635823685174102, 0.9531833866338972, 0.677741629696105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 324}], {
             RGBColor[
             0.9872320384693549, 0.96924453318132, 0.5670993322130458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 441}], {
             RGBColor[
             0.9234723543343322, 0.7159969522867111, 0.2949378306326797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 346}], {
             RGBColor[
             0.9676353625275156, 0.9716070909645953, 0.7037418611912148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 404}], {
             RGBColor[
             0.8902809355679866, 0.6241832014875223, 0.5827983844656581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 407}], {
             RGBColor[
             0.8477255801391979, 0.8817791205679212, 0.9788765914194218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 408}], {
             RGBColor[
             0.7466640360093887, 0.8014228836179527, 0.9697651413535558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 192}], {
             RGBColor[
             0.9730817431450001, 0.9791252265118651, 0.9161301659225536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 225}], {
             RGBColor[
             0.9771912899366351, 0.9800083476334325, 0.7886892497834159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 249}], {
             RGBColor[
             0.8098363617598581, 0.8518738008220831, 0.9596117752379575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 260}], {
             RGBColor[
             0.9768557074446731, 0.9806858577362383, 0.8535858107704437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 280}], {
             RGBColor[
             0.973245182584402, 0.9791928129202596, 0.9134215514439559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 424}], {
             RGBColor[
             0.8286951015364036, 0.8666063916672513, 0.9614914381739403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 440}], {
             RGBColor[
             0.9005112366755342, 0.9228793702291294, 0.9686043747026818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 453}], {
             RGBColor[
             0.9767096385681568, 0.9789781440586809, 0.736264470732255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 470}], {
             RGBColor[
             0.9436577561041107, 0.8595376474480609, 0.606425727516644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 193}], {
             RGBColor[
             0.8760981363009956, 0.9029011849813693, 0.9305504671203357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 196}], {
             RGBColor[
             0.8286066270308157, 0.7074108334774076, 0.6040065306558084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 318}], {
             RGBColor[
             0.8740542466569524, 0.8838002330235897, 0.6805446072340816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 321}], {
             RGBColor[
             0.8794107237566801, 0.9042710250239092, 0.8756523202781137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 330}], {
             RGBColor[
             0.8794800557706723, 0.9020191552306659, 0.7087320996145642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 335}], {
             RGBColor[
             0.50177522669656, 0.5920242288768799, 0.9570823198348848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 350}], {
             RGBColor[
             0.8604290306461424, 0.8914947373157116, 0.9695928023499971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 383}], {
             RGBColor[
             0.8716932776336157, 0.8998955942754576, 0.9505253703863377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 409}], {
             RGBColor[
             0.7586222154547619, 0.8113607075464246, 0.9765760307750098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 482}], {
             RGBColor[
             0.7847160181944952, 0.8317453845669502, 0.9791768171716557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 496}], {
             RGBColor[
             0.7391388475930729, 0.796140152493793, 0.9746341107489811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 191}], {
             RGBColor[
             0.7955364929594537, 0.8357025805158247, 0.6953867078142715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 202}], {
             RGBColor[
             0.9802336590311509, 0.9810254093164148, 0.6842038466474791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 212}], {
             RGBColor[
             0.9926187907063133, 0.9888488780447459, 0.5999466981073359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 295}], {
             RGBColor[
             0.931655387900872, 0.9431215338736003, 0.7083858368440024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 300}], {
             RGBColor[
             0.9233793528839394, 0.9365224481980844, 0.7075964612359837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 389}], {
             RGBColor[
             0.9850596310486159, 0.9612428848920649, 0.3983207617245015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 414}], {
             RGBColor[
             0.9925454586430165, 0.9864638147441851, 0.42999736126797494`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 456}], {
             RGBColor[
             0.9061427698283213, 0.9227803796709094, 0.7059519123941675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 485}], {
             RGBColor[
             0.8341456892510164, 0.8665357131258398, 0.698775916253193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 322}], {
             RGBColor[
             0.9385748006264314, 0.9510684421069135, 0.8838127707529357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 494}], {
             RGBColor[
             0.8369097461549819, 0.8730445208857714, 0.984239681511647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 304}], {
             RGBColor[
             0.8636625201908663, 0.8942922192733926, 0.9868137390092165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 310}], {
             RGBColor[
             0.77919875325054, 0.8274352552599658, 0.9786269077638146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 483}], {
             RGBColor[
             0.8926870594443204, 0.9158245441476032, 0.9305699761788597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 266}], {
             RGBColor[
             0.7986224760627137, 0.8406181240857399, 0.8694859663218997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 364}], {
             RGBColor[
             0.9931292888471714, 0.9902673215152155, 0.6792472496646749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 374}], {
             RGBColor[
             0.9694735386583258, 0.9085955773173091, 0.5264217669947728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 437}], {
             RGBColor[
             0.9578438400067832, 0.9664121217951614, 0.8847418477891621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 195}], {
             RGBColor[
             0.9032047565833817, 0.6522362792325285, 0.24088602934174558`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 224}], {
             RGBColor[
             0.9457597561096502, 0.8094848937026312, 0.37059414743152125`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 263}], {
             RGBColor[
             0.9294561420818532, 0.8005984885504847, 0.5941929542313757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 323}], {
             RGBColor[
             0.9454293987346674, 0.8087782926817968, 0.3346367858940176]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 342}], {
             RGBColor[
             0.9180511689070951, 0.7920926782306796, 0.6134985989228404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 351}], {
             RGBColor[
             0.9444525229310519, 0.8107158282892721, 0.5210283948067062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 356}], {
             RGBColor[
             0.9441581058096356, 0.8105940792433914, 0.5259076484356621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 395}], {
             RGBColor[
             0.9268333391192007, 0.7986424063953841, 0.598632675510577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 452}], {
             RGBColor[
             0.5386089957825928, 0.4682194860437505, 0.5851724245285548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 463}], {
             RGBColor[
             0.8690542317685127, 0.46905254327817153`, 0.21130320561286647`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 212}], {
             RGBColor[
             0.795616825168121, 0.83810261641951, 0.8660979672773335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 218}], {
             RGBColor[
             0.7795131299215096, 0.8275058490681813, 0.9566496739872327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 287}], {
             RGBColor[
             0.7952875716227025, 0.8379664616170492, 0.8715545506057808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 295}], {
             RGBColor[
             0.7346534223626797, 0.7923752722483646, 0.974537106014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 299}], {
             RGBColor[
             0.7837405367828478, 0.8306586421836238, 0.9494937768552794]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 300}], {
             RGBColor[
             0.7263773873457472, 0.7857761865728485, 0.9737477304059813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 301}], {
             RGBColor[
             0.7462271090244685, 0.8016038158331196, 0.9756410145797534]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 389}], {
             RGBColor[
             0.7880576655104237, 0.8104966232668291, 0.6644720308944991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 451}], {
             RGBColor[
             0.7952894866303097, 0.8379672535219084, 0.8715228139738465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 456}], {
             RGBColor[
             0.709140804290129, 0.7720341180456736, 0.9721031815641652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[
             0.9902262438965574, 0.9894100328369123, 0.7523048718758557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 249}], {
             RGBColor[
             0.8228713157197806, 0.8612754860255629, 0.9232273973303973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 260}], {
             RGBColor[
             0.9898906614045956, 0.9900875429397182, 0.8172014328628836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 280}], {
             RGBColor[
             0.9862801365443243, 0.9885944981237396, 0.8770371735363957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 327}], {
             RGBColor[
             0.9890446878025934, 0.9897377111147605, 0.8312214047575608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 470}], {
             RGBColor[
             0.9566927100640332, 0.8689393326515409, 0.5700413496090839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 483}], {
             RGBColor[
             0.9860936649537853, 0.9885173873289503, 0.8801274903646353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 196}], {
             RGBColor[
             0.9383831189226433, 0.7929364584953429, 0.5572135598782135]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 202}], {
             RGBColor[
             0.9769017438787397, 0.9820143932455367, 0.9114648754967126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 232}], {
             RGBColor[
             0.9032315165313283, 0.9241028730181883, 0.933253572509392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 330}], {
             RGBColor[
             0.9892565476624999, 0.9875447802486013, 0.6619391288369694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 350}], {
             RGBColor[
             0.97020552253797, 0.9770203623336469, 0.9227998315724022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 354}], {
             RGBColor[
             0.9886999532189906, 0.989595154505166, 0.8369345489523639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 376}], {
             RGBColor[
             0.9598393306810903, 0.9692404074430272, 0.9386528763573886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 414}], {
             RGBColor[
             0.9892135434906053, 0.987452798673307, 0.6572583901172084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 415}], {
             RGBColor[
             0.8734400121328993, 0.9008246381787606, 0.9302855301448425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 485}], {
             RGBColor[
             0.830813774098605, 0.8675246970549619, 0.9260369451024264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 496}], {
             RGBColor[
             0.8489153394849007, 0.8816657775117284, 0.9278411399713862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 228}], {
             RGBColor[
             0.9848695689394806, 0.9600182201409575, 0.4472024892509955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 388}], {
             RGBColor[
             0.9860225191023408, 0.9860013293397859, 0.7266617239600016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 490}], {
             RGBColor[
             0.9783441744232477, 0.9802748324502537, 0.7396591586686819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 224}], {
             RGBColor[
             0.9506735211278463, 0.8306762008476586, 0.3746363277161573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 263}], {
             RGBColor[
             0.9343699071000493, 0.821789795695512, 0.5982351345160118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 296}], {
             RGBColor[
             0.9508403729199688, 0.8310330799597048, 0.3927971155987977]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 323}], {
             RGBColor[
             0.9503431637528634, 0.8299695998268242, 0.3386789661786536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 342}], {
             RGBColor[
             0.9229649339252912, 0.813283985375707, 0.6175407792074765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 351}], {
             RGBColor[
             0.9493662879492479, 0.8319071354342995, 0.5250705750913423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 395}], {
             RGBColor[
             0.9317471041373968, 0.8198337135404115, 0.6026748557952131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 447}], {
             RGBColor[
             0.9088908852351498, 0.6764897508097452, 0.2455496715356582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 453}], {
             RGBColor[
             0.9507455047764068, 0.8308301665932663, 0.3824713036303889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 463}], {
             RGBColor[
             0.8739679967867088, 0.4902438504231989, 0.21534538589750252`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 318}], {
             RGBColor[
             0.9363392292786001, 0.7738355065375633, 0.3072076999919595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 321}], {
             RGBColor[
             0.9416957063783278, 0.7943062985378829, 0.5023154130359916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 330}], {
             RGBColor[
             0.94176503839232, 0.7920544287446396, 0.3353951923724421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 335}], {
             RGBColor[
             0.5640602093182078, 0.4820595023908536, 0.5837454125927626]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 350}], {
             RGBColor[
             0.92271401326779, 0.7815300108296852, 0.596255895107875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 354}], {
             RGBColor[
             0.9412084439488106, 0.7941048030012043, 0.5103906124878366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 383}], {
             RGBColor[
             0.9339782602552633, 0.7899308677894312, 0.5771884631442155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 414}], {
             RGBColor[
             0.9417220342204252, 0.7919624471693454, 0.3307144536526812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 479}], {
             RGBColor[
             0.9400857906336029, 0.7936405570044918, 0.5289958832544748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 482}], {
             RGBColor[
             0.8470010008161429, 0.7217806580809238, 0.6058399099295336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 496}], {
             RGBColor[
             0.8014238302147206, 0.6861754260077666, 0.601297203506859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 237}], {
             RGBColor[
             0.6287446068886482, 0.7084931420486138, 0.9645924647075654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 270}], {
             RGBColor[
             0.7680553093977825, 0.817151319363554, 0.9234730247466851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 345}], {
             RGBColor[
             0.7695901390161273, 0.8177860108540616, 0.8980369259589864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 375}], {
             RGBColor[
             0.7553962878446263, 0.8079353827389228, 0.9549837167325317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 426}], {
             RGBColor[
             0.7673771014476408, 0.8168706539072692, 0.9347033243992662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 448}], {
             RGBColor[
             0.7718442294098967, 0.8168573181791481, 0.7254190640561107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 489}], {
             RGBColor[
             0.5874118499495894, 0.6759264282481757, 0.960662359069989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 223}], {
             RGBColor[
             0.9874533494088276, 0.9686568029150344, 0.46379732966388687`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 373}], {
             RGBColor[
             0.8034673235261298, 0.842851467718365, 0.7542256157726834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 480}], {
             RGBColor[
             0.7460087646267075, 0.7962040211252337, 0.7497022675384846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 208}], {
             RGBColor[
             0.9046296432768679, 0.9245214794272625, 0.9030709072515116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 220}], {
             RGBColor[
             0.9055358840692573, 0.9248962332842416, 0.8880521520456273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 349}], {
             RGBColor[
             0.906838583644985, 0.9242686550671847, 0.7816869522728951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 359}], {
             RGBColor[
             0.5487530911480626, 0.6341923609065088, 0.9608988640474148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 371}], {
             RGBColor[
             0.9074814739468295, 0.9256437324166499, 0.8516615941696293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 382}], {
             RGBColor[
             0.7830809166803596, 0.8304680308368757, 0.979013845533619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 397}], {
             RGBColor[
             0.9073668781116424, 0.9256533963751684, 0.8577078423026208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 419}], {
             RGBColor[
             0.7384559216971772, 0.7956066455934903, 0.9745660430779834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 427}], {
             RGBColor[
             0.902245268423902, 0.9096550761057292, 0.6889500108810322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 429}], {
             RGBColor[
             0.9035067188803267, 0.9240571213314521, 0.9216806705373815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 213}], {
             RGBColor[
             0.8406029030517452, 0.8751436820448877, 0.9257268095490452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 243}], {
             RGBColor[
             0.8666149150223563, 0.8954644634949422, 0.9283194438062032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 254}], {
             RGBColor[
             0.9906007368809664, 0.9902867980934886, 0.7985732655341262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 259}], {
             RGBColor[
             0.9658283539553814, 0.9737302511108482, 0.9290616488719079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 401}], {
             RGBColor[
             0.9891747417888554, 0.9897914917803148, 0.829066073636271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 450}], {
             RGBColor[
             0.9895398457828933, 0.988017659307254, 0.6831018165698124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 454}], {
             RGBColor[
             0.9675070876762328, 0.9749822479711852, 0.9262199905663829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 469}], {
             RGBColor[
             0.9903740659693996, 0.989801971933592, 0.7739015356607983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 471}], {
             RGBColor[
             0.9842099008526831, 0.9874391786898353, 0.8979464846500218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 475}], {
             RGBColor[
             0.9902104427487868, 0.990219780743547, 0.8119018284220445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 500}], {
             RGBColor[
             0.9685021916224957, 0.9757243948649748, 0.9245355391500355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 222}], {
             RGBColor[
             0.8778837439970252, 0.902514723122215, 0.8481478845968908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 246}], {
             RGBColor[
             0.8775003226959586, 0.9016946237290737, 0.8064148421777795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 256}], {
             RGBColor[
             0.8728186879701627, 0.8870969959656014, 0.6866452486463932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 271}], {
             RGBColor[
             0.8564259359349728, 0.8884072633209144, 0.9712071655716115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 312}], {
             RGBColor[
             0.8611967985786386, 0.8919653648689898, 0.9631313395561464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 333}], {
             RGBColor[
             0.8637457699338088, 0.856491913006518, 0.6513986753519633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 400}], {
             RGBColor[
             0.8767205569792536, 0.9000267837074492, 0.7215421560706178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 442}], {
             RGBColor[
             0.8774058321890023, 0.9014925180891499, 0.7961301336233937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 444}], {
             RGBColor[
             0.8531976809761114, 0.885999636058378, 0.9766717591532232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 492}], {
             RGBColor[
             0.8521034564676294, 0.8851835652115803, 0.9785239958266245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 211}], {
             RGBColor[
             0.9715508032259026, 0.9517579817025928, 0.6486117469254753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 414}], {
             RGBColor[
             0.9802406591765216, 0.9810403819195392, 0.6849657692711802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 485}], {
             RGBColor[
             0.8218408897845214, 0.861112280301194, 0.9537443242563983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 497}], {
             RGBColor[
             0.6683951135285787, 0.734756443163775, 0.9419483763546872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 221}], {
             RGBColor[
             0.929700109343822, 0.735738862595451, 0.3941996814131081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 258}], {
             RGBColor[
             0.8916131425940015, 0.9123633412511369, 0.7792816867343308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 289}], {
             RGBColor[
             0.9914983687219584, 0.9895720081316777, 0.7047576251800027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 291}], {
             RGBColor[
             0.99059005783937, 0.9891963982392025, 0.7198106871377036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 297}], {
             RGBColor[
             0.891926435531237, 0.9126080880748197, 0.7793129128464256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 381}], {
             RGBColor[
             0.9919757920794071, 0.9897694349592032, 0.6968454846150347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 397}], {
             RGBColor[
             0.9944502170706857, 0.9907926732829186, 0.6558378589029429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 419}], {
             RGBColor[
             0.8255392606562205, 0.8607459225012405, 0.7726960596783057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 439}], {
             RGBColor[
             0.9936862542126773, 0.9889038611155646, 0.5541659188513833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 219}], {
             RGBColor[
             0.8717812041341548, 0.8186459662613912, 0.6248211529630614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 244}], {
             RGBColor[
             0.9005984607675492, 0.9203990128980384, 0.8585366451230829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 274}], {
             RGBColor[
             0.8850889081235598, 0.9105954390724162, 0.963760052944391]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 334}], {
             RGBColor[
             0.8972513365042334, 0.9190148909979874, 0.9140071562461489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 337}], {
             RGBColor[
             0.8571402256002798, 0.8890342361403147, 0.9862068377347799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 340}], {
             RGBColor[
             0.876009214173394, 0.903823818191017, 0.9791296064385716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 361}], {
             RGBColor[
             0.897535575814586, 0.9191324312574352, 0.9092965752858524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 362}], {
             RGBColor[
             0.9004797795416396, 0.9197348079369443, 0.8157902445864481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 363}], {
             RGBColor[
             0.8968284762057552, 0.9188400273975526, 0.9210150457193061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 370}], {
             RGBColor[
             0.8875971015097084, 0.912466045593016, 0.9595143357832461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 498}], {
             RGBColor[
             0.8572624335263515, 0.8891316814233186, 0.9862184940358649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 228}], {
             RGBColor[
             0.756406424364777, 0.783102982419583, 0.6594575827123853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 252}], {
             RGBColor[
             0.6169999560101703, 0.699103580858918, 0.9635685571265427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 388}], {
             RGBColor[
             0.7575593745276372, 0.8090860916184113, 0.9389168174213915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 432}], {
             RGBColor[
             0.7656841327878544, 0.813381390637923, 0.8461622682998482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 490}], {
             RGBColor[
             0.7498810298485441, 0.8033595947288792, 0.9519142521300719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 266}], {
             RGBColor[
             0.7777383789618836, 0.8263932558130482, 0.9653135256154455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 410}], {
             RGBColor[
             0.9555220732119901, 0.9663490155441989, 0.9601737077376233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 218}], {
             RGBColor[
             0.977104461608415, 0.9795127052914565, 0.7546472729584157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 287}], {
             RGBColor[
             0.9928789033096079, 0.9899733178403245, 0.6695521495769639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 295}], {
             RGBColor[
             0.9322447540495853, 0.9443821284716398, 0.7725347049851831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 336}], {
             RGBColor[
             0.992837473061539, 0.9899561853680392, 0.6702387560055101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 389}], {
             RGBColor[
             0.9856489971973292, 0.9625034794901044, 0.4624696298656822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 409}], {
             RGBColor[
             0.8723199886477142, 0.8971579432332774, 0.766670899289362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 456}], {
             RGBColor[
             0.9067321359770346, 0.9240409742689488, 0.7701007805353481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 458}], {
             RGBColor[
             0.9756577063012266, 0.9784337175521997, 0.7570962523192695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[
             0.8894123657528293, 0.9126336265698909, 0.9015541912414591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 289}], {
             RGBColor[
             0.9892975918807863, 0.9898422934504316, 0.827030129687131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 314}], {
             RGBColor[
             0.9387174619203519, 0.951700265797597, 0.9063227419869739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 349}], {
             RGBColor[
             0.9917211457628563, 0.9896782172936889, 0.7020894733803454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 359}], {
             RGBColor[
             0.6336356532659337, 0.6996019231330131, 0.8813013851548652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 397}], {
             RGBColor[
             0.9922494402295137, 0.9910629586016726, 0.778110363410071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 427}], {
             RGBColor[
             0.9871278305417731, 0.9750646383322333, 0.6093525319884827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 472}], {
             RGBColor[
             0.8986040537742486, 0.9198142431116398, 0.9024703328022259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 214}], {
             RGBColor[
             0.9919289018035221, 0.9909304077250634, 0.7834225146556062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 233}], {
             RGBColor[
             0.8802380302581241, 0.9045192031018214, 0.8576823250484545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 273}], {
             RGBColor[
             0.9812746591565753, 0.9476945813573296, 0.5339038844426299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 421}], {
             RGBColor[
             0.891843627515077, 0.9135855838847592, 0.858839062522555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 423}], {
             RGBColor[
             0.9941526248567136, 0.9904333383934529, 0.6435951892450555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 477}], {
             RGBColor[
             0.9806062222388334, 0.9833167253870987, 0.8397916986792475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 227}], {
             RGBColor[
             0.9190658014291058, 0.937864650465706, 0.9769745100877764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 243}], {
             RGBColor[
             0.8163341265086606, 0.8569749682109646, 0.9821877608458685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 326}], {
             RGBColor[
             0.8695327482146703, 0.6622482093579174, 0.593948428254798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 348}], {
             RGBColor[
             0.9400615506959966, 0.9512446163186681, 0.8243165907011964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 428}], {
             RGBColor[
             0.8423853922162148, 0.8773264149786586, 0.984784307548678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 434}], {
             RGBColor[
             0.9315910537649785, 0.9240002822741774, 0.6784322633236988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 469}], {
             RGBColor[
             0.9400932774557039, 0.9513124766496144, 0.8277698527004635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 474}], {
             RGBColor[
             0.690320894497177, 0.7562777946630308, 0.9711694758615474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 495}], {
             RGBColor[
             0.6785935124403661, 0.7467569775967706, 0.9702462533872194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 464}], {
             RGBColor[
             0.9412128340141752, 0.7989548779549169, 0.30114148318898737`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 485}], {
             RGBColor[
             0.8254628334457681, 0.8372682855120179, 0.6631838165311892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 497}], {
             RGBColor[
             0.6720170571898254, 0.7109124483745988, 0.6513878686294781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 287}], {
             RGBColor[
             0.9923698693695621, 0.9911127591459704, 0.7761145408988452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 295}], {
             RGBColor[
             0.9317357201095393, 0.9455215697772856, 0.8790970963070646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 299}], {
             RGBColor[
             0.9808228345297074, 0.983804939712545, 0.8540537671483438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 300}], {
             RGBColor[
             0.9234596850926068, 0.9389224841017697, 0.8783077206990457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 301}], {
             RGBColor[
             0.9433094067713281, 0.9547501133620406, 0.8802010048728179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 389}], {
             RGBColor[
             0.9851399632572833, 0.9636429207957502, 0.5690320211875637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 451}], {
             RGBColor[
             0.9923717843771693, 0.9911135510508295, 0.776082804266911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 456}], {
             RGBColor[
             0.9062231020369886, 0.9251804155745947, 0.8766631718572296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 254}], {
             RGBColor[
             0.8451747645588835, 0.8769398849657546, 0.8430988537085882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 259}], {
             RGBColor[
             0.8204023816332985, 0.8603833379831141, 0.9735872370463697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 261}], {
             RGBColor[
             0.844243920025624, 0.8749489026319313, 0.74178217076985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 315}], {
             RGBColor[
             0.8300831870522847, 0.86760326681373, 0.9572001586304562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 368}], {
             RGBColor[
             0.7462489458429472, 0.8016946152853429, 0.9753427788948826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 401}], {
             RGBColor[
             0.8437487694667727, 0.8764445786525807, 0.8735916618107329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 450}], {
             RGBColor[
             0.8441138734608105, 0.87467074617952, 0.7276274047442743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 454}], {
             RGBColor[
             0.8220811153541501, 0.861635334843451, 0.9707455787408448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 471}], {
             RGBColor[
             0.8387839285306002, 0.8740922655621012, 0.9424720728244838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 475}], {
             RGBColor[
             0.844784470426704, 0.8768728676158128, 0.8564274165965063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 500}], {
             RGBColor[
             0.8230762193004129, 0.8623774817372407, 0.9690611273244973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 273}], {
             RGBColor[
             0.9785381900256471, 0.9465629810476419, 0.5792542596972097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 302}], {
             RGBColor[
             0.7919407318338222, 0.8358165895347633, 0.8950040676646331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 347}], {
             RGBColor[
             0.9242233078582275, 0.9402043927069141, 0.9076052575129079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 421}], {
             RGBColor[
             0.8891071583841488, 0.9124539835750715, 0.9041894377771348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 423}], {
             RGBColor[
             0.9914161557257855, 0.9893017380837652, 0.6889455644996354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 477}], {
             RGBColor[
             0.9778697531079052, 0.982185125077411, 0.8851420739338273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 224}], {
             RGBColor[
             0.9934109568100042, 0.9883150278080841, 0.5242014955090566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 351}], {
             RGBColor[
             0.992103723631406, 0.9895459623947249, 0.6746357428842416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 356}], {
             RGBColor[
             0.9918093065099896, 0.9894242133488445, 0.6795149965131975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 430}], {
             RGBColor[
             0.9939345835225641, 0.9894350123994681, 0.581195031721718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 238}], {
             RGBColor[
             0.9942589215575104, 0.9901287386606124, 0.6164972252432722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 281}], {
             RGBColor[
             0.9940218773090626, 0.9896217249820325, 0.5906964216672632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 343}], {
             RGBColor[
             0.9754527321197464, 0.9789107794400399, 0.8074255742154097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 465}], {
             RGBColor[
             0.9906967078191645, 0.9898511020610691, 0.7624274906959931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 290}], {
             RGBColor[
             0.9507875569574543, 0.9589822920793866, 0.7592771193616903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 340}], {
             RGBColor[
             0.9695343376044968, 0.9736744288470849, 0.7521882317643971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 355}], {
             RGBColor[
             0.9248496205549558, 0.9383000856585617, 0.7568031358325509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 362}], {
             RGBColor[
             0.9940049029727425, 0.9895854185930122, 0.5888488699122736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 378}], {
             RGBColor[
             0.9151629640054884, 0.9305762086633039, 0.7558792138834822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 384}], {
             RGBColor[
             0.991040946422042, 0.9889748736133008, 0.6826825560181735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 498}], {
             RGBColor[
             0.9507875569574543, 0.9589822920793866, 0.7592771193616903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 295}], {
             RGBColor[
             0.9156320248629278, 0.9349248024259569, 0.9696488030169637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.9073559898459953, 0.9283257167504408, 0.9688594274089449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 336}], {
             RGBColor[
             0.9762247438748817, 0.9804988593223563, 0.8673528540372907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 389}], {
             RGBColor[
             0.9690362680106718, 0.9530461534444213, 0.6595837278974628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 409}], {
             RGBColor[
             0.8557072594610567, 0.8877006171875943, 0.9637849973211426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 456}], {
             RGBColor[
             0.8901194067903773, 0.9145836482232659, 0.9672148785671288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 458}], {
             RGBColor[
             0.9590449771145692, 0.9689763915065166, 0.95421035035105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 244}], {
             RGBColor[
             0.9659890690918504, 0.8903672498264703, 0.5020206615782334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 274}], {
             RGBColor[
             0.950479516447861, 0.8805636760008482, 0.6072440693995416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 334}], {
             RGBColor[
             0.9626419448285347, 0.8889831279264193, 0.5574911727012997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 337}], {
             RGBColor[
             0.922530833924581, 0.8590024730687467, 0.6296908541899304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 340}], {
             RGBColor[
             0.9413998224976954, 0.8737920551194489, 0.6226136228937222]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 361}], {
             RGBColor[
             0.9629261841388872, 0.8891006681858672, 0.5527805917410029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 363}], {
             RGBColor[
             0.9622190845300564, 0.8888082643259846, 0.5644990621744568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 369}], {
             RGBColor[
             0.9656315824941042, 0.8891922643219441, 0.433281770053086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 370}], {
             RGBColor[
             0.9529877098340097, 0.8824342825214481, 0.6029983522383966]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 498}], {
             RGBColor[
             0.9226530418506529, 0.8590999183517506, 0.6297025104910154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 349}], {
             RGBColor[
             0.9926273865552457, 0.990052971150668, 0.6870707181744611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 359}], {
             RGBColor[
             0.6345418940583232, 0.6999766769899922, 0.8662826299489808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 371}], {
             RGBColor[
             0.9932702768570902, 0.9914280485001332, 0.7570453600711953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 382}], {
             RGBColor[
             0.8688697195906203, 0.896252346920359, 0.884397611435185]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 416}], {
             RGBColor[
             0.6978813873158245, 0.7577031130339147, 0.8702136665775981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 427}], {
             RGBColor[
             0.9880340713341625, 0.9754393921892124, 0.5943337767825982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 429}], {
             RGBColor[
             0.9892955217905874, 0.9898414374149355, 0.8270644364389473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 499}], {
             RGBColor[
             0.9915398239914344, 0.9907695140509214, 0.7898705409029994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 223}], {
             RGBColor[
             0.9233921179724812, 0.7153312018194742, 0.29565838273479866`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 258}], {
             RGBColor[
             0.82739949286074, 0.658711732830329, 0.5945529488027335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 297}], {
             RGBColor[
             0.8277127857979756, 0.6589564796540119, 0.5945841749148281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 381}], {
             RGBColor[
             0.9277621423461457, 0.7361178265383954, 0.5121167466834373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 439}], {
             RGBColor[
             0.9294726044794159, 0.7352522526947567, 0.36943718091978583`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 307}], {
             RGBColor[
             0.7446063961983345, 0.7961248871300552, 0.836417805079223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 333}], {
             RGBColor[
             0.9810675255038132, 0.9461305631935593, 0.5227771907321785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 372}], {
             RGBColor[
             0.9665511748846629, 0.8918210547744503, 0.49420747589141756`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 417}], {
             RGBColor[
             0.9378879554257517, 0.9498801665465861, 0.8539985929857735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 258}], {
             RGBColor[
             0.8853051512226607, 0.89195568047516, 0.6807403880560214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 268}], {
             RGBColor[
             0.96247135042132, 0.9530331034761459, 0.6810622222123301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 373}], {
             RGBColor[
             0.7973117504517042, 0.8227698142676358, 0.6722741080968833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 381}], {
             RGBColor[
             0.9856678007080664, 0.9693617741832264, 0.5983041859367253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 480}], {
             RGBColor[
             0.7398531915522819, 0.7761223676745045, 0.6677507598626844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 263}], {
             RGBColor[
             0.9769249066263179, 0.9790384101656148, 0.7279432526057875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 342}], {
             RGBColor[
             0.9655199334515598, 0.9705325998458099, 0.7472488972972522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 351}], {
             RGBColor[
             0.9919212874755166, 0.9891557499044021, 0.6547786931811179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 356}], {
             RGBColor[
             0.9916268703541001, 0.9890340008585217, 0.6596579468100738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 463}], {
             RGBColor[
             0.9165229963129773, 0.6474924648933016, 0.3450535039872782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 235}], {
             RGBColor[
             0.893910226508456, 0.9144443349836249, 0.8024573747040173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 249}], {
             RGBColor[
             0.8269808625114154, 0.8621586071471303, 0.7957864811912596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 260}], {
             RGBColor[
             0.9940002081962305, 0.9909706640612856, 0.6897605167237458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 280}], {
             RGBColor[
             0.9903896833359592, 0.989477619245307, 0.7495962573972579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 296}], {
             RGBColor[
             0.9939490074632762, 0.9894658637501668, 0.5827649886539659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 424}], {
             RGBColor[
             0.8458396022879608, 0.8768911979922986, 0.7976661441272425]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 440}], {
             RGBColor[
             0.9176557374270915, 0.9331641765541767, 0.8047790806559839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 453}], {
             RGBColor[
             0.9938541393197141, 0.9892629503837282, 0.572439176685557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 470}], {
             RGBColor[
             0.960802256855668, 0.8698224537731083, 0.44260043346994615`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 236}], {
             RGBColor[
             0.9381730326614751, 0.9490844858382324, 0.7710986105469461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 283}], {
             RGBColor[
             0.9269985773767548, 0.9437086558837645, 0.961041579076473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 292}], {
             RGBColor[
             0.9350591544629343, 0.9491785129720349, 0.9231383289054235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 308}], {
             RGBColor[
             0.9359688105623654, 0.949554679146245, 0.9080629732233299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 386}], {
             RGBColor[
             0.9131636908063694, 0.9333906201321187, 0.9844604333238214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 396}], {
             RGBColor[
             0.9248300005080721, 0.9420913348058197, 0.9647124140597219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 422}], {
             RGBColor[
             0.9377015487588578, 0.9502712109198352, 0.8793470171247402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 446}], {
             RGBColor[
             0.9386670023167258, 0.9501410369828205, 0.8248641590936432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 309}], {
             RGBColor[
             0.7899269769732593, 0.8362187670832074, 0.9644024889389899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 320}], {
             RGBColor[
             0.91673141513476, 0.9360032741998225, 0.9767518542390904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 348}], {
             RGBColor[
             0.9736600537786657, 0.9775976621797073, 0.812353245335059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 428}], {
             RGBColor[
             0.8759838952988839, 0.9036794608396979, 0.9728209621825405]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 495}], {
             RGBColor[
             0.7121920155230351, 0.7731100234578097, 0.9582829080210821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 388}], {
             RGBColor[
             0.9774081160649387, 0.9575483496136721, 0.6417154673845928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 490}], {
             RGBColor[
             0.9697297713858456, 0.9518218527241399, 0.6547129020932732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 244}], {
             RGBColor[
             0.9924537131715252, 0.9911474307127697, 0.7747250321195109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 248}], {
             RGBColor[
             0.9131139132516399, 0.9311716682004387, 0.8989728090532525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 255}], {
             RGBColor[
             0.9359426388818366, 0.9493746743487081, 0.9011502332833046]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 313}], {
             RGBColor[
             0.9915655777471801, 0.9907801638907636, 0.789443734521711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 338}], {
             RGBColor[
             0.9921719499056979, 0.9901344097584148, 0.714228157963513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 379}], {
             RGBColor[
             0.9281319648969453, 0.9431466549282532, 0.9004052442259547]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 380}], {
             RGBColor[
             0.8496951111847733, 0.8814979423813236, 0.8926864397697157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 390}], {
             RGBColor[
             0.9914078479370181, 0.9885000729099683, 0.6310603741634497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 411}], {
             RGBColor[
             0.9922882511599973, 0.9910790079188231, 0.7774671658524877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 478}], {
             RGBColor[
             0.9864028911291416, 0.9883981626825751, 0.8639372762643418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 242}], {
             RGBColor[
             0.8745531982100293, 0.9026124492933816, 0.975242759168409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 339}], {
             RGBColor[
             0.8662691661834705, 0.8963706880323747, 0.9870623632309714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 365}], {
             RGBColor[
             0.6472389883669551, 0.7220926050370226, 0.9670159279563117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 374}], {
             RGBColor[
             0.8729649775993807, 0.8346199957996303, 0.6282716838675144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 391}], {
             RGBColor[
             0.7259176068939448, 0.7858116187744832, 0.9733163410356109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 246}], {
             RGBColor[
             0.990276034386355, 0.9895193638417679, 0.7579302745145235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 256}], {
             RGBColor[
             0.9855943996605592, 0.9749217360782956, 0.6381606809831374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 271}], {
             RGBColor[
             0.9692016476253692, 0.9762320034336085, 0.9227225979083558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 288}], {
             RGBColor[
             0.9768038105768311, 0.9819016841154095, 0.9098541189931781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 442}], {
             RGBColor[
             0.9901815438793986, 0.989317258201844, 0.7476455659601378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 444}], {
             RGBColor[
             0.9659733926665077, 0.9738243761710721, 0.9281871914899675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 492}], {
             RGBColor[
             0.9648791681580258, 0.9730083053242744, 0.9300394281633687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 307}], {
             RGBColor[
             0.6572978488497363, 0.729937668493963, 0.9680294294286916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 312}], {
             RGBColor[
             0.8912100068000448, 0.9154167964199388, 0.9661214792858304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 330}], {
             RGBColor[
             0.906613436001005, 0.9232208432674849, 0.7114352050036206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 350}], {
             RGBColor[
             0.887562410876475, 0.9126964253525305, 0.9722959077390535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 354}], {
             RGBColor[
             0.9060568415574957, 0.9252712175240496, 0.886430625119015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 372}], {
             RGBColor[
             0.8792426275360649, 0.8256338361383582, 0.6258191002408862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 376}], {
             RGBColor[
             0.8771962190195952, 0.9049164704619108, 0.9881489525240399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 400}], {
             RGBColor[
             0.9067337652006597, 0.9234782152583981, 0.7245322958003018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 414}], {
             RGBColor[
             0.9065704318291102, 0.9231288616921907, 0.7067544662838597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 415}], {
             RGBColor[
             0.7907969004714044, 0.8365007011976442, 0.9797816063114937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 476}], {
             RGBColor[
             0.8407222254378526, 0.8762709607405244, 0.9845538351578227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 235}], {
             RGBColor[
             0.8322890766299877, 0.86932291837359, 0.9838088312711606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[
             0.9329640071968655, 0.945705106835731, 0.833357404633238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 262}], {
             RGBColor[
             0.9045034194501311, 0.8458022325627524, 0.6282343475835404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 296}], {
             RGBColor[
             0.932327857584808, 0.9443444471401319, 0.7641164452211091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 332}], {
             RGBColor[
             0.9315653506544935, 0.9424260514849466, 0.7055666820727398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 393}], {
             RGBColor[
             0.6888637219939389, 0.7551988066430447, 0.9709350479991965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 468}], {
             RGBColor[
             0.863343079728331, 0.8938703532245054, 0.9868276277315957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 239}], {
             RGBColor[
             0.8941595928955972, 0.9149777044709109, 0.8295993670333943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 249}], {
             RGBColor[
             0.726555298331679, 0.7863097881722755, 0.973379900158559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 260}], {
             RGBColor[
             0.893574644016494, 0.9151218450864307, 0.8673539356910454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 262}], {
             RGBColor[
             0.865699005148863, 0.8150748301979324, 0.6244763099836965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 296}], {
             RGBColor[
             0.8935234432835397, 0.9136170447753118, 0.7603584076212653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 332}], {
             RGBColor[
             0.8927609363532254, 0.9116986491201265, 0.7018086444728959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 344}], {
             RGBColor[
             0.8531359045295882, 0.8859456130686627, 0.9857972203264075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 393}], {
             RGBColor[
             0.6500593076926706, 0.7244714042782247, 0.9671770103993527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 424}], {
             RGBColor[
             0.7454140381082245, 0.8010423790174437, 0.975259563094542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 440}], {
             RGBColor[
             0.8172301732473551, 0.8573153575793218, 0.9823724996232834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 453}], {
             RGBColor[
             0.8934285751399778, 0.9134141314088733, 0.7500325956528565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 243}], {
             RGBColor[
             0.8704406675144714, 0.8956648146758674, 0.7644821261315815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 276}], {
             RGBColor[
             0.9916163115107062, 0.9894194478138612, 0.6881682466151131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 283}], {
             RGBColor[
             0.9825059250733381, 0.9835154675800046, 0.7434695545548671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 292}], {
             RGBColor[
             0.9905665021595176, 0.988985324668275, 0.7055663043838174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 396}], {
             RGBColor[
             0.9803373482046553, 0.9818981465020598, 0.7471403895381158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 422}], {
             RGBColor[
             0.9932088964554411, 0.9900780226160752, 0.661774992603134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 267}], {
             RGBColor[
             0.5805359866390262, 0.6693552123563778, 0.9607973055275205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 270}], {
             RGBColor[
             0.8462364551489006, 0.8796332152026205, 0.9303039705316428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 329}], {
             RGBColor[
             0.8307310847614414, 0.8682944762778347, 0.9666327886472934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 426}], {
             RGBColor[
             0.8455582471987588, 0.8793525497463357, 0.9415342701842239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 448}], {
             RGBColor[
             0.8500253751610147, 0.8793392140182146, 0.7322500098410683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 489}], {
             RGBColor[
             0.6655929957007074, 0.7384083240872422, 0.9674933048549466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 265}], {
             RGBColor[
             0.9943737040081526, 0.99037424671625, 0.628990586640501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 328}], {
             RGBColor[
             0.9722845220574414, 0.9760427563773426, 0.7727048784953556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 343}], {
             RGBColor[
             0.9750901041702351, 0.978135154923345, 0.767955759791403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 431}], {
             RGBColor[
             0.993214192756902, 0.9878941693943957, 0.5027849426158452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 433}], {
             RGBColor[
             0.9811511290896566, 0.9472205776949887, 0.454395489261064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 436}], {
             RGBColor[
             0.9153906894734584, 0.9310632904127151, 0.7806657257133343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 462}], {
             RGBColor[
             0.9939211935070924, 0.9905588412180708, 0.6635099201471054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 465}], {
             RGBColor[
             0.9903340798696533, 0.9890754775443742, 0.7229576762719865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 262}], {
             RGBColor[
             0.9663739357157407, 0.8914570186600732, 0.474024883345774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 263}], {
             RGBColor[
             0.9777279080304979, 0.98075594897326, 0.8153449999005569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 296}], {
             RGBColor[
             0.9941983738504174, 0.9899992332374528, 0.6099069809833427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 332}], {
             RGBColor[
             0.9934358669201031, 0.9880808375822674, 0.5513572178349734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 393}], {
             RGBColor[
             0.7507342382595483, 0.8008535927403655, 0.81672558376143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 424}], {
             RGBColor[
             0.8460889686751022, 0.8774245674795846, 0.8248081364566193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 440}], {
             RGBColor[
             0.9179051038142328, 0.9336975460414627, 0.8319210729853608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 453}], {
             RGBColor[
             0.9941035057068555, 0.9897963198710142, 0.599581169014934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 251}], {
             RGBColor[
             0.8950972114678623, 0.5738126121896787, 0.5540396392331648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 310}], {
             RGBColor[
             0.790670772135302, 0.49186953960685414`, 0.5727803079471008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 352}], {
             RGBColor[
             0.90768626076889, 0.579856592097588, 0.331007084599814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 367}], {
             RGBColor[
             0.7880774291924377, 0.4898436003897522, 0.5725218277587236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 382}], {
             RGBColor[
             0.7843311380286198, 0.4869169692597102, 0.5721484324665957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 399}], {
             RGBColor[
             0.9008139235637824, 0.5570584620460117, 0.2716672194657418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 412}], {
             RGBColor[
             0.8776293714833701, 0.47206431552500777`, 0.2169475091796825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 416}], {
             RGBColor[
             0.6133428057538239, 0.34836773537326576`, 0.5579644876090089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 429}], {
             RGBColor[
             0.9047569402285869, 0.5805060597542866, 0.514815257470358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 402}], {
             RGBColor[
             0.9688186866690371, 0.9734699384739001, 0.7795235011225361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 417}], {
             RGBColor[
             0.9372419637806353, 0.9484984557374562, 0.7836863890131642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 436}], {
             RGBColor[
             0.9153993008078571, 0.9310817091862547, 0.7816030163196452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 461}], {
             RGBColor[
             0.9538944148147273, 0.9617766681732995, 0.7852747146586145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 339}], {
             RGBColor[
             0.9415188783075069, 0.9558419119731058, 0.9816743627559383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 365}], {
             RGBColor[
             0.7224887004909916, 0.7815638289777536, 0.9616279274812787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 374}], {
             RGBColor[
             0.9482146897234172, 0.8940912197403614, 0.6228836833924813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 276}], {
             RGBColor[
             0.8683765986671191, 0.8961929649552562, 0.8991237867213546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 326}], {
             RGBColor[
             0.8003995763768941, 0.6077115729642152, 0.5871983336467528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 428}], {
             RGBColor[
             0.7732522203784387, 0.8227897785849565, 0.9780342129406326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 454}], {
             RGBColor[
             0.8480931273247609, 0.8819561162935055, 0.9733382129980028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 469}], {
             RGBColor[
             0.8709601056179277, 0.8967758402559123, 0.8210197580924183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 471}], {
             RGBColor[
             0.8647959405012113, 0.8944130470121556, 0.9450647070816418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 475}], {
             RGBColor[
             0.8707964823973149, 0.8971936490658674, 0.8590200508536644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 495}], {
             RGBColor[
             0.6094603406025899, 0.6922203412030684, 0.9634961587791742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 274}], {
             RGBColor[
             0.9792967730812554, 0.9823167226374954, 0.8409595615595631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 313}], {
             RGBColor[
             0.9939181903008997, 0.9917530296411114, 0.7504548561404552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 334}], {
             RGBColor[
             0.991459201461929, 0.9907361745630665, 0.7912066648613211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 340}], {
             RGBColor[
             0.9702170791310897, 0.9755451017560961, 0.8563291150537438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 355}], {
             RGBColor[
             0.9255323620815487, 0.9401707585675729, 0.8609440191218976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 363}], {
             RGBColor[
             0.9910363411634509, 0.9905613109626317, 0.7982145543344783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 378}], {
             RGBColor[
             0.9158457055320812, 0.932446881572315, 0.8600200971728289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 379}], {
             RGBColor[
             0.9304845774506649, 0.944119520678601, 0.8614163658446987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 380}], {
             RGBColor[
             0.8520477237384929, 0.8824708081316716, 0.8536975613884599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 390}], {
             RGBColor[
             0.9937604604907377, 0.9894729386603163, 0.5920714957821938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 498}], {
             RGBColor[
             0.9514702984840472, 0.9608529649883977, 0.863418002651037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 394}], {
             RGBColor[
             0.9345320450392265, 0.9503900995947601, 0.985144117245782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 438}], {
             RGBColor[
             0.9515565716994097, 0.9418661566317763, 0.6831992840882117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 445}], {
             RGBColor[
             0.9434962582307435, 0.9570755951154415, 0.9699700425537883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 460}], {
             RGBColor[
             0.7644058978452928, 0.8161453259200204, 0.977321705365639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 256}], {
             RGBColor[
             0.9897570222391006, 0.9759155467595013, 0.5162907216074972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 288}], {
             RGBColor[
             0.9809664331553725, 0.9828954947966153, 0.7879841596175379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 333}], {
             RGBColor[
             0.9806841042027465, 0.9453104638004179, 0.4810441483130672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 392}], {
             RGBColor[
             0.99287681773338, 0.990594854592846, 0.7148285638427732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 442}], {
             RGBColor[
             0.99434416645794, 0.9903110688830499, 0.6257756065844976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 444}], {
             RGBColor[
             0.9701360152450491, 0.9748181868522778, 0.8063172321143273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 459}], {
             RGBColor[
             0.9154489626538371, 0.9314735531451295, 0.8101618704705316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 492}], {
             RGBColor[
             0.9690417907365672, 0.9740021160054801, 0.8081694687877286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 255}], {
             RGBColor[
             0.9383287875280972, 0.950008912590596, 0.8359828701023571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 269}], {
             RGBColor[
             0.9943838019837287, 0.9903958452649454, 0.6300896889644825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 360}], {
             RGBColor[
             0.8208458625237492, 0.8577308508489487, 0.8244058240965618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 369}], {
             RGBColor[
             0.9944823752200395, 0.9906066834501313, 0.640818777413416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 370}], {
             RGBColor[
             0.981838502559945, 0.9838487016496351, 0.8105353595987266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 425}], {
             RGBColor[
             0.9329834444207914, 0.9457466810923038, 0.8354730265049382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 466}], {
             RGBColor[
             0.9886119880687374, 0.9717847694521875, 0.534657471337661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 468}], {
             RGBColor[
             0.9252330332178664, 0.9395667135783992, 0.8347337853655293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 286}], {
             RGBColor[
             0.793770255900979, 0.8389490995217421, 0.9800446347454881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 294}], {
             RGBColor[
             0.8622086518629171, 0.8929657912378484, 0.9867194249890767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 313}], {
             RGBColor[
             0.9145783903810143, 0.9317772671287806, 0.8747026330741967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 380}], {
             RGBColor[
             0.7727079238186075, 0.8224950456193407, 0.9779453383222014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 411}], {
             RGBColor[
             0.9153010637938316, 0.9320761111568401, 0.8627260644049733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 478}], {
             RGBColor[
             0.9094157037629758, 0.9293952659205922, 0.9491961748168274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 260}], {
             RGBColor[
             0.8266452800194536, 0.8628361172499364, 0.8606830421782874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 280}], {
             RGBColor[
             0.8230347551591823, 0.8613430724339577, 0.9205187828517996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 296}], {
             RGBColor[
             0.8265940792864992, 0.8613313169388175, 0.7536875141085075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 424}], {
             RGBColor[
             0.6784846741111841, 0.7487566511809493, 0.968588669581784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 440}], {
             RGBColor[
             0.7503008092503147, 0.8050296297428274, 0.9757016061105255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 470}], {
             RGBColor[
             0.7934473286788912, 0.741687906961759, 0.6135229589244877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 339}], {
             RGBColor[
             0.7255347271889965, 0.7845203198026767, 0.9743394752700114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 365}], {
             RGBColor[
             0.5065045493724811, 0.6102422368073245, 0.9542930399953516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 305}], {
             RGBColor[
             0.9213006310242065, 0.9392525468881536, 0.9635241132405157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 367}], {
             RGBColor[
             0.8609271168047831, 0.8916464185330037, 0.9576239069818739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 382}], {
             RGBColor[
             0.857180825640965, 0.8887197874029618, 0.9572505116897458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 416}], {
             RGBColor[
             0.6861924933661692, 0.7501705535165173, 0.943066566832159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 427}], {
             RGBColor[
             0.9763451773845073, 0.9679068326718151, 0.6671866770371591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 429}], {
             RGBColor[
             0.9776066278409322, 0.9823088778975382, 0.8999173366935083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 499}], {
             RGBColor[
             0.9798509300417793, 0.983236954533524, 0.8627234411575602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 282}], {
             RGBColor[
             0.8219127600183682, 0.8615498819554761, 0.9730607320072864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 432}], {
             RGBColor[
             0.8461264059705493, 0.8778442470725187, 0.853071892677207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 467}], {
             RGBColor[
             0.8227540179324937, 0.8621772907303975, 0.9716367017938761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 261}], {
             RGBColor[
             0.8956714115835732, 0.9151244499004134, 0.7469079825111136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 277}], {
             RGBColor[
             0.8958482697749148, 0.9168980188091047, 0.8675805494584039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 291}], {
             RGBColor[
             0.8926491352236089, 0.915575094458132, 0.9205984880683677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 311}], {
             RGBColor[
             0.8955537108621965, 0.9148726999587569, 0.7340969853539026]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 319}], {
             RGBColor[
             0.8106417510044636, 0.8520251747796341, 0.9817538433410331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 377}], {
             RGBColor[
             0.8880044556149207, 0.8897606228818433, 0.6747246220246919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 484}], {
             RGBColor[
             0.8867269084532972, 0.9116690697583762, 0.9534962538580438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 488}], {
             RGBColor[
             0.8953346453110775, 0.9166856218937615, 0.8760926360416899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 315}], {
             RGBColor[
             0.9800810208815057, 0.9827463828623308, 0.8300466146155372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 325}], {
             RGBColor[
             0.9945604257996274, 0.9919242312207186, 0.7329509728054768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 347}], {
             RGBColor[
             0.9272133907159827, 0.9413464895064041, 0.8511914674046495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 368}], {
             RGBColor[
             0.8962467796721683, 0.9168377313339438, 0.8481892348799638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 386}], {
             RGBColor[
             0.9694171475179757, 0.9747932835683002, 0.8480977706363799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 401}], {
             RGBColor[
             0.9937466032959937, 0.9915876947011817, 0.746438117795814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 454}], {
             RGBColor[
             0.972078949183371, 0.9767784508920518, 0.8435920347259259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 471}], {
             RGBColor[
             0.9887817623598214, 0.989235381610702, 0.8153185288095648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 269}], {
             RGBColor[
             0.937839191601499, 0.948961716409344, 0.7826933749279678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 274}], {
             RGBColor[
             0.9227856987915668, 0.9405439662734338, 0.9673847627233567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 334}], {
             RGBColor[
             0.9349481271722404, 0.948963418199005, 0.9176318660251147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 338}], {
             RGBColor[
             0.9380134881697288, 0.9493345191447013, 0.8016644807460507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 369}], {
             RGBColor[
             0.9379377648378098, 0.9491725545945299, 0.7934224633769011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 370}], {
             RGBColor[
             0.9252938921777154, 0.9424145727940338, 0.9631390455622117]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 379}], {
             RGBColor[
             0.8739735031609763, 0.9023467643145398, 0.9878415670084923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 390}], {
             RGBColor[
             0.937249386201049, 0.9477001822962547, 0.7184966969459874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 425}], {
             RGBColor[
             0.8764388340385617, 0.9043125522367024, 0.9880767124684233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 466}], {
             RGBColor[
             0.9320673776865078, 0.9303506405965861, 0.6872611573011461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 271}], {
             RGBColor[
             0.9686826354781146, 0.962628186351342, 0.6810830450013292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 333}], {
             RGBColor[
             0.9760024694769507, 0.9307128360369454, 0.361274554781681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 442}], {
             RGBColor[
             0.9896625317321441, 0.9757134411195774, 0.5060060130531114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 444}], {
             RGBColor[
             0.9654543805192533, 0.9602205590888054, 0.686547638582941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 492}], {
             RGBColor[
             0.9643601560107713, 0.9594044882420079, 0.6883998752563423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 272}], {
             RGBColor[
             0.9807365588332579, 0.9821967176234275, 0.7465313192187232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 306}], {
             RGBColor[
             0.6175814992618391, 0.6800182655559914, 0.7453606514875053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 317}], {
             RGBColor[
             0.9915196209601939, 0.9893805047420046, 0.6898463257484718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 357}], {
             RGBColor[
             0.9924180295823459, 0.9897520197953129, 0.6749573698724267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 418}], {
             RGBColor[
             0.9936358559714821, 0.9887960643736918, 0.5486803813191747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 420}], {
             RGBColor[
             0.9927160564857381, 0.9898752615788076, 0.6700182928143167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 289}], {
             RGBColor[
             0.8891977522388765, 0.9125448783665557, 0.9051108925696281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 297}], {
             RGBColor[
             0.7896258190481551, 0.8355809583096978, 0.9796661802360509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 314}], {
             RGBColor[
             0.838617622278442, 0.8744028507137211, 0.984403504869471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 373}], {
             RGBColor[
             0.7013191253399629, 0.7661503452784907, 0.971168674164818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 381}], {
             RGBColor[
             0.8896751755963253, 0.9127423051940813, 0.89719875200466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 397}], {
             RGBColor[
             0.8921496005876037, 0.9137655435177967, 0.8561911262925681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 472}], {
             RGBColor[
             0.7985042141323387, 0.842516828027764, 0.980551095684723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 341}], {
             RGBColor[
             0.969952586398881, 0.9745690207268329, 0.7977120319007616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 405}], {
             RGBColor[
             0.9638783102862895, 0.9725810834721289, 0.9460287780265119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 450}], {
             RGBColor[
             0.9693393243644466, 0.9732573152454804, 0.7309622440671371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 454}], {
             RGBColor[
             0.947306566257786, 0.9602219039094115, 0.9740804180637075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 469}], {
             RGBColor[
             0.9701735445509527, 0.9750416278718184, 0.821761963158123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 471}], {
             RGBColor[
             0.9640093794342364, 0.9726788346280617, 0.9458069121473465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 475}], {
             RGBColor[
             0.9700099213303399, 0.9754594366817734, 0.8597622559193691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 491}], {
             RGBColor[
             0.9694640367589782, 0.9752336993829217, 0.8688089759708189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 500}], {
             RGBColor[
             0.948301670204049, 0.9609640508032011, 0.97239596664736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 280}], {
             RGBColor[
             0.9900541008439974, 0.9901551293481129, 0.8144928183842858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 424}], {
             RGBColor[
             0.8455040197959991, 0.8775687080951045, 0.8625627051142704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 440}], {
             RGBColor[
             0.9173201549351298, 0.9338416866569826, 0.8696756416430118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 470}], {
             RGBColor[
             0.9604666743637063, 0.8704999638759142, 0.507496994456974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 483}], {
             RGBColor[
             0.9898676292534583, 0.9900780185533237, 0.8175831352125255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 484}], {
             RGBColor[
             0.9843664061913093, 0.9846456562046717, 0.7199002151631233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 500}], {
             RGBColor[
             0.9721432085963744, 0.9755296154520183, 0.7405909003708404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 332}], {
             RGBColor[
             0.9649752791733688, 0.888177963309289, 0.3462341607852757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 344}], {
             RGBColor[
             0.9253502473497317, 0.8624249272578252, 0.6302227366387871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 387}], {
             RGBColor[
             0.9231568624962913, 0.8606759817135375, 0.6300135296334083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 393}], {
             RGBColor[
             0.7222736505128142, 0.7009507184673871, 0.6116025267117324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 424}], {
             RGBColor[
             0.817628380928368, 0.7775216932066061, 0.6196850794069216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 296}], {
             RGBColor[
             0.9770917584184404, 0.979395289277661, 0.7461040404884279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 323}], {
             RGBColor[
             0.9765945492513349, 0.9783318091447804, 0.6919858910682839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 342}], {
             RGBColor[
             0.9492163194237628, 0.9616461946936632, 0.9708477040971066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 395}], {
             RGBColor[
             0.9579984896358684, 0.9681959228583676, 0.9559817806848432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 440}], {
             RGBColor[
             0.9007984883822558, 0.9230936020816709, 0.968118132490446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 447}], {
             RGBColor[
             0.9351422707336213, 0.8248519601277013, 0.5988565964252884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 453}], {
             RGBColor[
             0.9769968902748785, 0.9791923759112224, 0.7357782285200192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 463}], {
             RGBColor[
             0.9002193822851803, 0.6386060597411551, 0.5686523107871327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 394}], {
             RGBColor[
             0.9695509869816097, 0.9740243196381256, 0.7789371443924473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 398}], {
             RGBColor[
             0.8128512768110655, 0.8506797323930686, 0.7721717108174448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 445}], {
             RGBColor[
             0.9785152001731265, 0.980709815158807, 0.7637630697004535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 328}], {
             RGBColor[
             0.9727619324575949, 0.9770638889496751, 0.8246680543165913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 433}], {
             RGBColor[
             0.98162853948981, 0.9482417102673211, 0.5063586650822997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 462}], {
             RGBColor[
             0.9943986039072458, 0.9915799737904034, 0.7154730959683411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 364}], {
             RGBColor[
             0.7994311567060022, 0.8397930572129475, 0.7718022900886157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 374}], {
             RGBColor[
             0.7757754065171566, 0.758121313015041, 0.6189768074187136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 410}], {
             RGBColor[
             0.7827080381716511, 0.8300996195146226, 0.9569011888680183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 437}], {
             RGBColor[
             0.764145707865614, 0.8159378574928935, 0.9772968882131029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 278}], {
             RGBColor[
             0.5574461182265952, 0.6513172316630873, 0.9584959232312578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 329}], {
             RGBColor[
             0.7043413187607015, 0.7666746507465323, 0.9560066836822909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 406}], {
             RGBColor[
             0.698935038849782, 0.7626426560409394, 0.9651581053878513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 413}], {
             RGBColor[
             0.6728982779676287, 0.7420885886300157, 0.969849399800218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 476}], {
             RGBColor[
             0.6848899909660967, 0.751650455068616, 0.9709931800911404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 486}], {
             RGBColor[
             0.7221969858080854, 0.7789852977400661, 0.8807273675389038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 493}], {
             RGBColor[
             0.7200516578201488, 0.7660137561076379, 0.6750587978678835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 275}], {
             RGBColor[
             0.6804359595523578, 0.7466469212970656, 0.9640424677431421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 285}], {
             RGBColor[
             0.9687637814914776, 0.9734074823412799, 0.7779098781339052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 324}], {
             RGBColor[
             0.9686637776279993, 0.9745733386001354, 0.8673186549905633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 353}], {
             RGBColor[
             0.8968758685102118, 0.92040358526162, 0.982921881592469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 441}], {
             RGBColor[
             0.9049040934929765, 0.7213257577055263, 0.5951571534101971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 480}], {
             RGBColor[
             0.7210267656392, 0.7805803216863452, 0.9669671600869278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 481}], {
             RGBColor[
             0.9668852114956432, 0.9679220933037029, 0.6982092389983524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 360}], {
             RGBColor[
             0.8203562665971511, 0.8566836546676968, 0.7711163289221725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 369}], {
             RGBColor[
             0.9939927792934413, 0.9895594872688792, 0.5875292822390267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 425}], {
             RGBColor[
             0.9324938484941931, 0.9446994849110517, 0.7821835313305489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 466}], {
             RGBColor[
             0.9881223921421393, 0.9707375732709355, 0.48136797616327165`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 468}], {
             RGBColor[
             0.9247434372912683, 0.938519517397147, 0.78144429019114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 309}], {
             RGBColor[
             0.8063684035463894, 0.8482556151786151, 0.9264891718635517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 345}], {
             RGBColor[
             0.9870819872763796, 0.9889260840080683, 0.8637484317830637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 375}], {
             RGBColor[
             0.9728881361048787, 0.9790754558929295, 0.920695222556609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 426}], {
             RGBColor[
             0.9848689497078932, 0.9880107270612759, 0.9004148302233436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 489}], {
             RGBColor[
             0.8049036982098418, 0.8470665014021824, 0.9263738648940663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 284}], {
             RGBColor[
             0.8865964350375715, 0.911984114350979, 0.9742123078459588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 442}], {
             RGBColor[
             0.9732697796969543, 0.9770237084748905, 0.7905679299783297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 444}], {
             RGBColor[
             0.9490616284840634, 0.9615308264441185, 0.9711095555081594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 464}], {
             RGBColor[
             0.929771402292063, 0.816967111351536, 0.604938344552128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 492}], {
             RGBColor[
             0.9479674039755814, 0.9607147555973208, 0.9729617921815605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 306}], {
             RGBColor[
             0.6046364710930239, 0.6733211047554091, 0.9382340489264145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 317}], {
             RGBColor[
             0.9785745927913785, 0.9826833439414222, 0.8827197231873809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 357}], {
             RGBColor[
             0.9794730014135307, 0.9830548589947306, 0.8678307673113358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 308}], {
             RGBColor[
             0.9785779417692696, 0.946579419415203, 0.5785954704311704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 421}], {
             RGBColor[
             0.8784529157372021, 0.8692181572073376, 0.6546708075641585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 423}], {
             RGBColor[
             0.9807619130788385, 0.9460659117160315, 0.439426934286659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 446}], {
             RGBColor[
             0.9812761335236301, 0.9471657772517783, 0.4953966563014838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 477}], {
             RGBColor[
             0.9672155104609584, 0.9389492987096772, 0.635623443720851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 334}], {
             RGBColor[
             0.9759496488179396, 0.9809326007374443, 0.8964300726826292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 340}], {
             RGBColor[
             0.9547075264871002, 0.9657415279304739, 0.9615525228750519]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 361}], {
             RGBColor[
             0.9762338881282921, 0.9810501409968921, 0.8917194917223326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 363}], {
             RGBColor[
             0.9755267885194614, 0.9807577371370095, 0.9034379621557864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 369}], {
             RGBColor[
             0.978939286483509, 0.9811417371329691, 0.7722206700344156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 370}], {
             RGBColor[
             0.9662954138234146, 0.974383755332473, 0.9419372522197262]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 379}], {
             RGBColor[
             0.9149750248066755, 0.9343159468529789, 0.9666397736660068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 498}], {
             RGBColor[
             0.9359607458400577, 0.9510493911627755, 0.9686414104723451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 282}], {
             RGBColor[
             0.6818051427201743, 0.7476680558617914, 0.961724797780191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 285}], {
             RGBColor[
             0.7055548165355974, 0.7625633461503587, 0.7616737234404737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 324}], {
             RGBColor[
             0.705454812672119, 0.7637292024092142, 0.8510825002971317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 353}], {
             RGBColor[
             0.6336669035543316, 0.7095594490706989, 0.9666857268990374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 441}], {
             RGBColor[
             0.6416951285370963, 0.5104816215146053, 0.5789209987167656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 481}], {
             RGBColor[
             0.703676246539763, 0.7570779571127818, 0.6819730843049209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 283}], {
             RGBColor[
             0.9804418562259858, 0.9840436178593932, 0.8781112151446401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 292}], {
             RGBColor[
             0.9885024333121654, 0.9895134749476637, 0.8402079649735905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 396}], {
             RGBColor[
             0.9782732793573031, 0.9824262967814485, 0.8817820501278888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 422}], {
             RGBColor[
             0.9911448276080889, 0.990606172895464, 0.7964166531929071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 291}], {
             RGBColor[
             0.9904654911529627, 0.9903252498131188, 0.8076750163207376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 311}], {
             RGBColor[
             0.9933700667915503, 0.9896228553137436, 0.6211735136062724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 319}], {
             RGBColor[
             0.9084581069338173, 0.9267753301346209, 0.8688303715934029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 331}], {
             RGBColor[
             0.9412542763649867, 0.9529261054107314, 0.8719584995112339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 377}], {
             RGBColor[
             0.9858208115442746, 0.9645107782368301, 0.5618011502770617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 419}], {
             RGBColor[
             0.8254146939698132, 0.8618747740751569, 0.8605603888613398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 449}], {
             RGBColor[
             0.9617191201757911, 0.875465494168005, 0.5085047417560592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 484}], {
             RGBColor[
             0.9845432643826509, 0.986419225113363, 0.8405727821104136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 488}], {
             RGBColor[
             0.9931510012404314, 0.9914357772487483, 0.7631691642940597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 329}], {
             RGBColor[
             0.8076412163490104, 0.8502564955845442, 0.9643314063510307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 406}], {
             RGBColor[
             0.802234936438091, 0.8462245008789513, 0.973482828056591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 413}], {
             RGBColor[
             0.7761981755559375, 0.8256704334680275, 0.9781741224689577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 486}], {
             RGBColor[
             0.8254968833963945, 0.8625671425780779, 0.8890520902076435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 493}], {
             RGBColor[
             0.8233515554084578, 0.8495956009456498, 0.6833835205366232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.9919699671517002, 0.9897401788754805, 0.694990501525461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 324}], {
             RGBColor[
             0.9918699632882219, 0.990906035134336, 0.7843992783821191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 481}], {
             RGBColor[
             0.9900913971558658, 0.9842547898379035, 0.6152898623899082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 494}], {
             RGBColor[
             0.8894693725363025, 0.9125779507587994, 0.8970159288150907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 327}], {
             RGBColor[
             0.9892081272419952, 0.989805297523155, 0.8285127902789631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 470}], {
             RGBColor[
             0.9568561495034349, 0.8690069190599355, 0.5673327351304861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 483}], {
             RGBColor[
             0.986257104393187, 0.988584973737345, 0.8774188758860375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 288}], {
             RGBColor[
             0.9804582072284761, 0.9818084509285072, 0.73266690388172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 343}], {
             RGBColor[
             0.9748530599217874, 0.9776281412447652, 0.742154956215394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 465}], {
             RGBColor[
             0.9900970356212055, 0.9885684638657943, 0.6971568726959774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 324}], {
             RGBColor[
             0.9700329607958158, 0.9755944731648613, 0.8650009850276121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 353}], {
             RGBColor[
             0.8982450516780285, 0.9214247198263459, 0.9806042116295179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 432}], {
             RGBColor[
             0.9705969367960523, 0.9758276917344811, 0.8556544431805919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 441}], {
             RGBColor[
             0.906273276660793, 0.7223468922702523, 0.5928394834472461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 467}], {
             RGBColor[
             0.9472245487579967, 0.9601607353923598, 0.9742192522972611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 292}], {
             RGBColor[
             0.9793920468747973, 0.9836094947138072, 0.8955092729133445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 386}], {
             RGBColor[
             0.9574965832182323, 0.9678216018738909, 0.9568313773317423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 422}], {
             RGBColor[
             0.9820344411707208, 0.9847021926616074, 0.8517179611326611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 442}], {
             RGBColor[
             0.907576331291601, 0.9250693691192144, 0.7991352758977409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 444}], {
             RGBColor[
             0.8833681800787101, 0.9095764870884425, 0.9796769014275706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 464}], {
             RGBColor[
             0.8640779538867097, 0.7650127719958602, 0.6135056904715392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 324}], {
             RGBColor[
             0.9937826346112388, 0.9904897634534285, 0.6649499106878949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 480}], {
             RGBColor[
             0.7461456226224394, 0.7964967465396384, 0.7645984157842595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 481}], {
             RGBColor[
             0.9920040684788828, 0.9838385181569962, 0.49584049469568403`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 294}], {
             RGBColor[
             0.8198521818784219, 0.8597461193211346, 0.9825323521288268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 346}], {
             RGBColor[
             0.871959950045134, 0.8960545442539305, 0.700786260241582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 358}], {
             RGBColor[
             0.8698005725318978, 0.8975563056442442, 0.9106435605781273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 407}], {
             RGBColor[
             0.7520501676568163, 0.8062265738572563, 0.975920990469789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 411}], {
             RGBColor[
             0.8729445938093365, 0.8988564392401264, 0.8585389915447235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 295}], {
             RGBColor[
             0.9314064665641207, 0.9453854149748249, 0.8845536796355118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 299}], {
             RGBColor[
             0.980493580984289, 0.9836687849100842, 0.8595103504767911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 300}], {
             RGBColor[
             0.9231304315471882, 0.9387863292993089, 0.8837643040274931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 301}], {
             RGBColor[
             0.9429801532259094, 0.9546139585595799, 0.8856575882012652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 389}], {
             RGBColor[
             0.9848107097118647, 0.9635067659932894, 0.5744886045160109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 451}], {
             RGBColor[
             0.9920425308317509, 0.9909773962483688, 0.7815393875953582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 456}], {
             RGBColor[
             0.9058938484915702, 0.925044260772134, 0.882119755185677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 343}], {
             RGBColor[
             0.9618890620391599, 0.9710975053865147, 0.9493960564298665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 392}], {
             RGBColor[
             0.979404593923856, 0.9829771748664875, 0.8667524083214277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 465}], {
             RGBColor[
             0.9771330377385781, 0.9820378280075439, 0.9043979729104499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 492}], {
             RGBColor[
             0.9555695669270433, 0.9663844362791217, 0.960093313266383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 291}], {
             RGBColor[
             0.9881746674842451, 0.9893779353546212, 0.8456398929730007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 297}], {
             RGBColor[
             0.889511045176112, 0.9127896251902385, 0.9051421186817227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 314}], {
             RGBColor[
             0.9385028484063991, 0.9516115175942619, 0.9098794433151429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 349}], {
             RGBColor[
             0.9915065322489034, 0.9895894690903537, 0.7056461747085143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 359}], {
             RGBColor[
             0.6334210397519809, 0.6995131749296779, 0.8848580864830341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 381}], {
             RGBColor[
             0.9895604017242822, 0.989950972074622, 0.8226746904503319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 397}], {
             RGBColor[
             0.9920348267155608, 0.9909742103983374, 0.78166706473824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 419}], {
             RGBColor[
             0.8231238703010956, 0.8609274596166592, 0.8985252655136028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 472}], {
             RGBColor[
             0.8983894402602957, 0.9197254949083047, 0.9060270341303949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 316}], {
             RGBColor[
             0.924179224710064, 0.9422627519944966, 0.9885844526325881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 340}], {
             RGBColor[
             0.926881051889892, 0.9442777702813763, 0.9840109639665258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 355}], {
             RGBColor[
             0.882196334840351, 0.9089034270928531, 0.9886258680346796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 362}], {
             RGBColor[
             0.9513516172581375, 0.9601887600273036, 0.8206716021144023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 378}], {
             RGBColor[
             0.8725096782908836, 0.9011795500975953, 0.987701946085611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 384}], {
             RGBColor[
             0.9483876607074372, 0.9595782150475922, 0.9145052882203022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 297}], {
             RGBColor[
             0.8886027342935237, 0.9124140152977633, 0.9201951806394235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 311}], {
             RGBColor[
             0.9901709322402443, 0.9882999309627708, 0.6741914522162363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 319}], {
             RGBColor[
             0.9052589723825115, 0.9254524057836482, 0.9218483102033669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 349}], {
             RGBColor[
             0.9905982213663151, 0.9892138591978785, 0.7206992366662153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 359}], {
             RGBColor[
             0.6325127288693926, 0.6991375650372027, 0.8999111484407349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 419}], {
             RGBColor[
             0.8222155594185072, 0.860551849724184, 0.9135783274713036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 488}], {
             RGBColor[
             0.9899518666891255, 0.9901128528977754, 0.8161871029040236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 308}], {
             RGBColor[
             0.9883622800604079, 0.9894555179762877, 0.8425306670602011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 386}], {
             RGBColor[
             0.9655571603044119, 0.9732914589621613, 0.9189281271606927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 422}], {
             RGBColor[
             0.9900950182569004, 0.9901720497498778, 0.8138147109616114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 298}], {
             RGBColor[
             0.6741326723968553, 0.7453568343652777, 0.9681549027226681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 317}], {
             RGBColor[
             0.840216690130033, 0.8742300035789006, 0.8979391788077564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 353}], {
             RGBColor[
             0.7705912689269685, 0.8209544945665277, 0.9777043843233739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 418}], {
             RGBColor[
             0.8423329251413212, 0.873645563210588, 0.7567732343784594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 420}], {
             RGBColor[
             0.8414131256555772, 0.8747247604157037, 0.8781111458736013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 432}], {
             RGBColor[
             0.8429431540449924, 0.875357466474663, 0.8527546158744479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 358}], {
             RGBColor[
             0.9382389684938358, 0.9515729973603504, 0.917318350821716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 411}], {
             RGBColor[
             0.9413829897712744, 0.9528731309562326, 0.8652137817883121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 430}], {
             RGBColor[
             0.9412831759597973, 0.9519637977688851, 0.8037693303018356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 478}], {
             RGBColor[
             0.9354976297404187, 0.9501922857199847, 0.9516838922001661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 300}], {
             RGBColor[
             0.8624962822871655, 0.8931951399306242, 0.9867468594357123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 336}], {
             RGBColor[
             0.9313650363160518, 0.9453682825025396, 0.885240286064058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 389}], {
             RGBColor[
             0.9241765604518419, 0.9179155766246048, 0.6774711599242301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 409}], {
             RGBColor[
             0.8108475519022269, 0.8525700403677777, 0.98167242934791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 456}], {
             RGBColor[
             0.8452596992315473, 0.8794530714034492, 0.9851023105938961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 458}], {
             RGBColor[
             0.9141852695557393, 0.9338458146867, 0.9720977823778174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 332}], {
             RGBColor[
             0.9927997173080456, 0.9867201778866685, 0.48211625842284445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 395}], {
             RGBColor[
             0.9744689554557879, 0.9774392071225604, 0.7505437617676292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 424}], {
             RGBColor[
             0.8454528190630447, 0.8760639077839856, 0.7555671770444904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 440}], {
             RGBColor[
             0.9172689542021754, 0.9323368863458638, 0.7626801135732318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 453}], {
             RGBColor[
             0.993467356094798, 0.9884356601754153, 0.5303402096028049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 311}], {
             RGBColor[
             0.8915073099321112, 0.9117116207983882, 0.7336936779249583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 314}], {
             RGBColor[
             0.8389309152156776, 0.874647597537404, 0.9844347309815658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 349}], {
             RGBColor[
             0.891934599058182, 0.9126255490334959, 0.7802014623749371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 359}], {
             RGBColor[
             0.5338491065612595, 0.62254925487282, 0.9594133741494569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 381}], {
             RGBColor[
             0.8899884685335607, 0.9129870520177642, 0.8972299781167548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 397}], {
             RGBColor[
             0.8924628935248393, 0.9140102903414796, 0.8562223524046628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 419}], {
             RGBColor[
             0.7235519371103741, 0.7839635395598015, 0.9730805531800256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 353}], {
             RGBColor[
             0.7536482159820724, 0.8077184528340032, 0.9760156591476585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 418}], {
             RGBColor[
             0.825389872196425, 0.8604095214780634, 0.7550845092027441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 420}], {
             RGBColor[
             0.8244700727106811, 0.8614887186831792, 0.876422420697886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 432}], {
             RGBColor[
             0.8260001011000964, 0.8621214247421385, 0.8510658906987326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 300}], {
             RGBColor[
             0.9115833967073337, 0.9314785098658835, 0.9617035302769916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 301}], {
             RGBColor[
             0.9314331183860549, 0.9473061391261545, 0.9635968144507637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 389}], {
             RGBColor[
             0.97326367487201, 0.9561989465598639, 0.6524278307655094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 451}], {
             RGBColor[
             0.9804954959918962, 0.9836695768149433, 0.8594786138448568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 456}], {
             RGBColor[
             0.8943468136517155, 0.9177364413387086, 0.9600589814351754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 301}], {
             RGBColor[
             0.8740699689489542, 0.9024236835153792, 0.9878507680014657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 389}], {
             RGBColor[
             0.9159005254349094, 0.9113164909490887, 0.6766817843162114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 409}], {
             RGBColor[
             0.8025715168852944, 0.8459709546922618, 0.9808830537398913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 451}], {
             RGBColor[
             0.9231323465547956, 0.9387871212041681, 0.8837325673955587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 456}], {
             RGBColor[
             0.8369836642146149, 0.8728539857279333, 0.9843129349858775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 458}], {
             RGBColor[
             0.9059092345388068, 0.9272467290111841, 0.9713084067697986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 389}], {
             RGBColor[
             0.9357502471136308, 0.9271441202093598, 0.6785750684899836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 451}], {
             RGBColor[
             0.9429820682335168, 0.954614750464439, 0.8856258515693309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 456}], {
             RGBColor[
             0.8568333858933361, 0.8886816149882042, 0.9862062191596496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 315}], {
             RGBColor[
             0.7798392371849787, 0.8276220681822288, 0.9526915824782427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 325}], {
             RGBColor[
             0.7943186421031003, 0.8367999165406164, 0.8555959406681822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 347}], {
             RGBColor[
             0.7269716070194557, 0.786222174826302, 0.973836435267355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 368}], {
             RGBColor[
             0.6960049959756411, 0.7617134166538417, 0.9708342027426692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 386}], {
             RGBColor[
             0.7691753638214487, 0.8196689688881982, 0.9707427384990854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 421}], {
             RGBColor[
             0.691855457545377, 0.7584717656944593, 0.9704206155315818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 477}], {
             RGBColor[
             0.7806180522691335, 0.8282029071967988, 0.9513732516882742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 366}], {
             RGBColor[
             0.9670497246790035, 0.9737550563470645, 0.8873132192278613]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 435}], {
             RGBColor[
             0.8663380841865843, 0.8963198380318129, 0.9807564063513647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 473}], {
             RGBColor[
             0.9636932957126366, 0.9723670867131818, 0.9429379333602839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 310}], {
             RGBColor[
             0.8435577873554134, 0.8785862491807079, 0.984809887129589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 429}], {
             RGBColor[
             0.9576439554486982, 0.9672227693281403, 0.9268448366528462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 483}], {
             RGBColor[
             0.9570460935491938, 0.9669755380683454, 0.9367529555446341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 382}], {
             RGBColor[
             0.8105345575849638, 0.8523569039581851, 0.9816329064739467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 416}], {
             RGBColor[
             0.639546225310168, 0.7138076700717406, 0.9674489616163598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 427}], {
             RGBColor[
             0.9296989093285062, 0.9315439492270384, 0.69156907182136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 438}], {
             RGBColor[
             0.9269400272989917, 0.9222375923251803, 0.6808513361078512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 460}], {
             RGBColor[
             0.739789353444875, 0.7965167616134244, 0.9749737573852786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 499}], {
             RGBColor[
             0.9332046619857781, 0.9468740710887473, 0.887105835941761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 317}], {
             RGBColor[
             0.6154195332199599, 0.6805048918739861, 0.8815490554561631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 357}], {
             RGBColor[
             0.6163179418421119, 0.6808764069272945, 0.8666600995801179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 418}], {
             RGBColor[
             0.6175357682312481, 0.6799204515056734, 0.7403831110268659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 420}], {
             RGBColor[
             0.6166159687455042, 0.6809996487107892, 0.861721022522008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 372}], {
             RGBColor[
             0.715952071515968, 0.6957925685952493, 0.6110988809935345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 417}], {
             RGBColor[
             0.6872888520570566, 0.7538516803673849, 0.9708899980878904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 386}], {
             RGBColor[
             0.9664668164038428, 0.9736676251363714, 0.9038527714785991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 421}], {
             RGBColor[
             0.8891469101277714, 0.9124704219426325, 0.9035306485110954]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 422}], {
             RGBColor[
             0.9910046743563314, 0.9905482159240879, 0.7987393552795178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 423}], {
             RGBColor[
             0.9914559074694078, 0.9893181764513264, 0.688286775233596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 446}], {
             RGBColor[
             0.9919701279141994, 0.9904180419870732, 0.7442564972484209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 320}], {
             RGBColor[
             0.7539940875962444, 0.8080043449562848, 0.9761431784564414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 337}], {
             RGBColor[
             0.7675397524127249, 0.81880529039367, 0.977435176058995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 348}], {
             RGBColor[
             0.8109227262401502, 0.8495987329361696, 0.81174456955241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 375}], {
             RGBColor[
             0.7937093819932332, 0.8390396785539841, 0.9579998638493983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 489}], {
             RGBColor[
             0.6257249440981962, 0.707030724063237, 0.9636785061868555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 327}], {
             RGBColor[
             0.8755333494576757, 0.9013388978407285, 0.8796600386921576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 399}], {
             RGBColor[
             0.8692371718435675, 0.8769182076064387, 0.675509967402828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 412}], {
             RGBColor[
             0.8460526197631552, 0.7919240610854347, 0.6207902571167687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 429}], {
             RGBColor[
             0.873180188508372, 0.9003658053147134, 0.9186580054074442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 483}], {
             RGBColor[
             0.8725823266088675, 0.9001185740549185, 0.928566124299232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 319}], {
             RGBColor[
             0.908163548021099, 0.924750011284273, 0.7353468074889017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 331}], {
             RGBColor[
             0.9409597174522684, 0.9509007865603835, 0.7384749354067327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 349}], {
             RGBColor[
             0.9935027970049026, 0.9885114646985034, 0.5341977339517501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 377}], {
             RGBColor[
             0.9855262526315562, 0.9624854593864822, 0.4283175861725603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 419}], {
             RGBColor[
             0.8251201350570948, 0.8598494552248088, 0.7270768247568384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 484}], {
             RGBColor[
             0.9842487054699326, 0.984393906263015, 0.7070892180059123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 488}], {
             RGBColor[
             0.9928564423277131, 0.9894104583984002, 0.6296856001895584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 354}], {
             RGBColor[
             0.9766784434877072, 0.9809090779069165, 0.8698024557288021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 376}], {
             RGBColor[
             0.9478178209498068, 0.9605543308447777, 0.9715207831338268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 400}], {
             RGBColor[
             0.9773553671308713, 0.979116075641265, 0.7079041264100887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 414}], {
             RGBColor[
             0.9771920337593218, 0.9787667220750575, 0.6901262968936467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 415}], {
             RGBColor[
             0.8614185024016159, 0.8921385615805111, 0.9631534369212807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 379}], {
             RGBColor[
             0.9295964420263197, 0.943752253856595, 0.8761350682468989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 380}], {
             RGBColor[
             0.8511595883141477, 0.8821035413096655, 0.86841626379066]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 390}], {
             RGBColor[
             0.9928723250663924, 0.9891056718383102, 0.606790198184394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 411}], {
             RGBColor[
             0.9937527282893718, 0.991684606847165, 0.7531969898734319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 478}], {
             RGBColor[
             0.987867368258516, 0.9890037616109169, 0.839667100285286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 359}], {
             RGBColor[
             0.5828409097915465, 0.6613711472768433, 0.9641506987828772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 373}], {
             RGBColor[
             0.7506242215074854, 0.8052169845061968, 0.975937224910333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 397}], {
             RGBColor[
             0.9414546967551263, 0.9528321827455029, 0.8609596770380831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 398}], {
             RGBColor[
             0.7598499682071441, 0.8127068612921322, 0.9766635094855538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 472}], {
             RGBColor[
             0.8478093102998613, 0.8815834672554701, 0.9853196464302378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 325}], {
             RGBColor[
             0.9794688482930286, 0.982587613068694, 0.8470522777273448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 347}], {
             RGBColor[
             0.912121813209384, 0.9320098713543796, 0.9652927723265174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 368}], {
             RGBColor[
             0.8811552021655694, 0.9075011131819193, 0.9622905398018318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 386}], {
             RGBColor[
             0.9543255700113769, 0.9654566654162757, 0.9621990755582479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 401}], {
             RGBColor[
             0.9786550257893949, 0.9822510765491571, 0.860539422717682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 378}], {
             RGBColor[
             0.8885546317580981, 0.913856668578414, 0.98518654715438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 357}], {
             RGBColor[
             0.9902560635404667, 0.9902386461133075, 0.8111457738410844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 418}], {
             RGBColor[
             0.9914738899296027, 0.9892826906916865, 0.6848687852878325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 420}], {
             RGBColor[
             0.9905540904438588, 0.9903618878968021, 0.8062066967829744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 321}], {
             RGBColor[
             0.9871433260044645, 0.9706956980840651, 0.5788534896142647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 330}], {
             RGBColor[
             0.9872126580184568, 0.9684438282908217, 0.4119332689507153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 335}], {
             RGBColor[
             0.6095078289443445, 0.6584489019370356, 0.6602834891710359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 350}], {
             RGBColor[
             0.9681616328939269, 0.9579194103758673, 0.6727939716861482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 354}], {
             RGBColor[
             0.9866560635749474, 0.9704942025473864, 0.5869286890661098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 383}], {
             RGBColor[
             0.9794258798814002, 0.9663202673356133, 0.6537265397224887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 479}], {
             RGBColor[
             0.9855334102597397, 0.9700299565506738, 0.605533959832748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 482}], {
             RGBColor[
             0.8924486204422797, 0.898170057627106, 0.6823779865078068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 496}], {
             RGBColor[
             0.8468714498408574, 0.8625648255539488, 0.6778352800851322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 331}], {
             RGBColor[
             0.8560477575945354, 0.8880532613812608, 0.9861317933938633]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 377}], {
             RGBColor[
             0.9006142927738233, 0.8996379342073595, 0.6759744441596909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 449}], {
             RGBColor[
             0.8765126014053399, 0.8105926501385343, 0.6226780356386885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 488}], {
             RGBColor[
             0.9079444824699802, 0.9265629332192776, 0.877342458176689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 337}], {
             RGBColor[
             0.8943441905742255, 0.918589797510285, 0.9897845413590953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 348}], {
             RGBColor[
             0.9377271644016508, 0.9493832400527846, 0.8240939348525105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 361}], {
             RGBColor[
             0.9347395407885317, 0.9486879926274056, 0.9128742789101678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 375}], {
             RGBColor[
             0.9205138201547338, 0.9388241856705992, 0.9703492291494986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 335}], {
             RGBColor[
             0.6148643060440722, 0.6789196939373553, 0.8553912022150678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 383}], {
             RGBColor[
             0.9847823569811278, 0.9867910593359329, 0.8488342527665207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 479}], {
             RGBColor[
             0.9908898873594674, 0.9905007485509935, 0.80064167287678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 482}], {
             RGBColor[
             0.8978050975420073, 0.9186408496274256, 0.8774856995518389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 496}], {
             RGBColor[
             0.852227926940585, 0.8830356175542684, 0.8729429931291642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 494}], {
             RGBColor[
             0.8905465037153715, 0.9130233721823531, 0.8791650776517849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 342}], {
             RGBColor[
             0.9651895760765768, 0.9698259988249753, 0.7112915357597485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 395}], {
             RGBColor[
             0.9739717462886823, 0.9763757269896798, 0.696425612347485]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 447}], {
             RGBColor[
             0.9511155273864353, 0.8330317642590135, 0.3393004280879302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 452}], {
             RGBColor[
             0.5857474029520745, 0.6459528066380462, 0.6829653613654628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 463}], {
             RGBColor[
             0.9161926389379944, 0.6467858638724673, 0.3090961424497745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 441}], {
             RGBColor[
             0.9299229466127378, 0.738408038817675, 0.4821971859641868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 481}], {
             RGBColor[
             0.9919040646154045, 0.9850043744158516, 0.5852492715523421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 347}], {
             RGBColor[
             0.9266012181275056, 0.9411877197127672, 0.8681971305164571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 368}], {
             RGBColor[
             0.8956346070836911, 0.9166789615403069, 0.8651948979917713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 386}], {
             RGBColor[
             0.9688049749294986, 0.9746345137746634, 0.8651034337481875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 401}], {
             RGBColor[
             0.9931344307075166, 0.9914289249075448, 0.7634437809076215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 421}], {
             RGBColor[
             0.891485068653427, 0.9134373105809245, 0.8647813107806839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 405}], {
             RGBColor[
             0.9178634930592742, 0.6995885370031756, 0.5570472403697369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 428}], {
             RGBColor[
             0.8264508420844483, 0.6280630197319091, 0.5897948803495623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 434}], {
             RGBColor[
             0.915656503633212, 0.674736887027428, 0.2834428361245832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 469}], {
             RGBColor[
             0.9241587273239374, 0.702049081402865, 0.43278042550134793`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 474}], {
             RGBColor[
             0.6743863443654106, 0.5070143994162812, 0.5761800486624319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 475}], {
             RGBColor[
             0.9239951041033246, 0.7024668902128199, 0.47078071826259404`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 491}], {
             RGBColor[
             0.9234492195319629, 0.7022411529139683, 0.4798274383140439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 495}], {
             RGBColor[
             0.6626589623085997, 0.49749358235002106`, 0.5752568261881037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 399}], {
             RGBColor[
             0.9856765008861561, 0.9665278202798862, 0.5785469502107986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 412}], {
             RGBColor[
             0.9624919488057437, 0.8815336737588821, 0.5238272399247393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 483}], {
             RGBColor[
             0.9890216556514562, 0.9897281867283658, 0.8316031071072028]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 431}], {
             RGBColor[
             0.9716024212063443, 0.9745838116278207, 0.6984624102919355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 433}], {
             RGBColor[
             0.9595393575390989, 0.9339102199284137, 0.6500729569371543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 436}], {
             RGBColor[
             0.8937789179229008, 0.9177529326461402, 0.9763431933894244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 462}], {
             RGBColor[
             0.9723094219565347, 0.9772484834514961, 0.8591873878231957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 487}], {
             RGBColor[
             0.9688645495746133, 0.9758239401923895, 0.9162778382355787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 406}], {
             RGBColor[
             0.9491301369721972, 0.9615819199623963, 0.9709935885076242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 413}], {
             RGBColor[
             0.9230933760900439, 0.9410278525514726, 0.9756848829199908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 486}], {
             RGBColor[
             0.9723920839305007, 0.977924561661523, 0.8865628506586767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 350}], {
             RGBColor[
             0.9735874420076467, 0.9761383325829436, 0.7009814640666308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 354}], {
             RGBColor[
             0.9920818726886673, 0.9887131247544627, 0.6151161814465924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 414}], {
             RGBColor[
             0.9925954629602819, 0.9865707689226038, 0.435440022611437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 415}], {
             RGBColor[
             0.876821931602576, 0.8999426084280573, 0.7084671626390711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 482}], {
             RGBColor[
             0.8978744295559996, 0.9163889798341822, 0.7105654788882894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 496}], {
             RGBColor[
             0.8522972589545773, 0.880783747761025, 0.7060227724656147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 377}], {
             RGBColor[
             0.9334104622049926, 0.92578870948347, 0.6791025720775219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 403}], {
             RGBColor[
             0.9417652965080715, 0.9526238387042101, 0.8261572441732619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 449}], {
             RGBColor[
             0.9093087708365091, 0.8367434254146449, 0.6258061635565195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 488}], {
             RGBColor[
             0.9407406519011494, 0.9527137084953881, 0.88047058609452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 344}], {
             RGBColor[
             0.952412178554094, 0.9590487461800193, 0.7075550711279865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 393}], {
             RGBColor[
             0.7493355817171765, 0.7975745373895813, 0.6889348612009318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 424}], {
             RGBColor[
             0.8446903121327303, 0.8741455121288003, 0.697017413896121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 392}], {
             RGBColor[
             0.9791222649712301, 0.9453921438702901, 0.5598123970169571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 442}], {
             RGBColor[
             0.9805896136957902, 0.945108358160494, 0.4707594397586814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 459}], {
             RGBColor[
             0.9016944098916873, 0.8862708424225737, 0.6551457036447155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 492}], {
             RGBColor[
             0.9552872379744174, 0.9287994052829244, 0.6531533019619122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 340}], {
             RGBColor[
             0.9668699548677739, 0.974160979856045, 0.9117996261768098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 355}], {
             RGBColor[
             0.9221852378182329, 0.9387866366675219, 0.9164145302449637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 361}], {
             RGBColor[
             0.9883963165089658, 0.9894695929224633, 0.8419665950240907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 363}], {
             RGBColor[
             0.987689216900135, 0.9891771890625807, 0.8536850654575443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 369}], {
             RGBColor[
             0.9911017148641827, 0.9895611890585403, 0.7224677733361736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 370}], {
             RGBColor[
             0.9784578422040883, 0.9828032072580442, 0.8921843555214843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 379}], {
             RGBColor[
             0.9271374531873491, 0.9427353987785501, 0.9168868769677648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 498}], {
             RGBColor[
             0.9481231742207314, 0.9594688430883467, 0.9188885137741032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 383}], {
             RGBColor[
             0.6071468599210079, 0.6745442631889036, 0.9302642523232918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 409}], {
             RGBColor[
             0.49407579774215404`, 0.5860093764598706, 0.9563149127119639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 482}], {
             RGBColor[
             0.5201696004818874, 0.6063940534803962, 0.9589156991086099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 496}], {
             RGBColor[
             0.4745924298804651, 0.570788821407239, 0.9543729926859352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 409}], {
             RGBColor[
             0.8714402709141807, 0.8981440972641772, 0.879376480368237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 456}], {
             RGBColor[
             0.9058524182435013, 0.9250271282998487, 0.8828063616142232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 458}], {
             RGBColor[
             0.9747779885676932, 0.9794198715830995, 0.8698018333981443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 348}], {
             RGBColor[
             0.9512728292181313, 0.9601841854901698, 0.8253859324550641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 361}], {
             RGBColor[
             0.9482852056050122, 0.9594889380647906, 0.9141662765127215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 370}], {
             RGBColor[
             0.9383467313001346, 0.9528225524003715, 0.9643840370101152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 375}], {
             RGBColor[
             0.9340594849712143, 0.9496251311079844, 0.9716412267520522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 498}], {
             RGBColor[
             0.9080120633167778, 0.929488188230674, 0.9910881952627341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 369}], {
             RGBColor[
             0.9941670758616712, 0.9899322900042365, 0.6065003880571096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 379}], {
             RGBColor[
             0.9302028141848375, 0.9431064997242464, 0.8009194916887008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 390}], {
             RGBColor[
             0.9934786972249103, 0.9884599177059614, 0.531574621626196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 425}], {
             RGBColor[
             0.932668145062423, 0.945072287646409, 0.8011546371486318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 478}], {
             RGBColor[
             0.9884737404170338, 0.9883580074785683, 0.764451523727088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 365}], {
             RGBColor[
             0.7142046684644328, 0.7753220677167467, 0.9734475315438411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 355}], {
             RGBColor[
             0.9009431154873935, 0.9235955638605515, 0.9815369804373864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 362}], {
             RGBColor[
             0.97009839790518, 0.974880896795002, 0.813582714517109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 363}], {
             RGBColor[
             0.9664470945692957, 0.9739861162556103, 0.918807515649967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 378}], {
             RGBColor[
             0.891256458937926, 0.9158716868652936, 0.9806130584883177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 379}], {
             RGBColor[
             0.9058953308565098, 0.9275443259715797, 0.9820093271601875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 380}], {
             RGBColor[
             0.8274584771443377, 0.86589561342465, 0.9742905227039486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 498}], {
             RGBColor[
             0.926881051889892, 0.9442777702813763, 0.9840109639665258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 387}], {
             RGBColor[
             0.9513388586422018, 0.9599829767222858, 0.8048136102015154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 403}], {
             RGBColor[
             0.994482003125633, 0.9906058875778201, 0.6407782772335601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 405}], {
             RGBColor[
             0.988203064148236, 0.9881801971498871, 0.766818733558041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 450}], {
             RGBColor[
             0.993664078226393, 0.9888564289232388, 0.5517521995986661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 469}], {
             RGBColor[
             0.9944982984128994, 0.9906407415495766, 0.642551918689652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 491}], {
             RGBColor[
             0.9937887906209248, 0.99083281306068, 0.689598931502348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 395}], {
             RGBColor[
             0.9465935164611103, 0.9596901125385626, 0.9752874253763079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 447}], {
             RGBColor[
             0.9237372975588632, 0.8163461498078963, 0.6181622411167531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 453}], {
             RGBColor[
             0.9655919171001204, 0.9706865655914175, 0.7550838732114837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 463}], {
             RGBColor[
             0.8888144091104222, 0.6301002494213501, 0.5879579554785974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 392}], {
             RGBColor[
             0.9737994466171673, 0.9787968651827454, 0.8762404606551017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 433}], {
             RGBColor[
             0.9623449396518926, 0.9360026184744162, 0.6453238382332015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 465}], {
             RGBColor[
             0.9715278904318894, 0.9778575183238019, 0.9138860252441239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 387}], {
             RGBColor[
             0.9105937618770165, 0.9315467645842679, 0.9913344399761193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 424}], {
             RGBColor[
             0.8050652803090932, 0.8483924760773365, 0.9810059897496326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 375}], {
             RGBColor[
             0.9744229657232235, 0.9797101473834372, 0.8952591237689103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 426}], {
             RGBColor[
             0.9864037793262379, 0.9886454185517836, 0.8749787314356448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 448}], {
             RGBColor[
             0.9908709072884938, 0.9886320828236623, 0.6656944710924892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 489}], {
             RGBColor[
             0.8064385278281865, 0.8477011928926901, 0.9009377661063676]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 498}], {
             RGBColor[
             0.9483755440687869, 0.9595732045061269, 0.914706092279592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 358}], {
             RGBColor[
             0.9903467366605478, 0.9878814222931462, 0.6355722589344712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 404}], {
             RGBColor[
             0.9151516872142549, 0.6389557714257594, 0.3047714818723692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 407}], {
             RGBColor[
             0.8725963317854664, 0.8965516905061583, 0.7008496888261329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 408}], {
             RGBColor[
             0.7715347876556571, 0.8161954535561899, 0.6917382387602669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 430}], {
             RGBColor[
             0.9933909441265093, 0.9882722227016809, 0.5220232384145909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 368}], {
             RGBColor[
             0.8282875720000464, 0.8661012198259925, 0.983435392590944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 386}], {
             RGBColor[
             0.901457939845854, 0.924056772060349, 0.9833439283473602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 421}], {
             RGBColor[
             0.8241380335697823, 0.8628595688666101, 0.9830218053798566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 477}], {
             RGBColor[
             0.9129006282935388, 0.9325907103689496, 0.9639744415365491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 375}], {
             RGBColor[
             0.9774424587986396, 0.980418573650484, 0.8059506202454674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 428}], {
             RGBColor[
             0.8969796445657747, 0.9170594266926599, 0.8201630427959606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 359}], {
             RGBColor[
             0.6358445936340509, 0.6993490987729352, 0.7599174301762486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 371}], {
             RGBColor[
             0.9945729764328178, 0.9908004702830763, 0.6506801602984631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 397}], {
             RGBColor[
             0.9944583805976307, 0.9908101342415948, 0.6567264084314546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 419}], {
             RGBColor[
             0.8255474241831655, 0.8607633834599167, 0.7735846092068173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 354}], {
             RGBColor[
             0.9730308475641374, 0.9781887068395083, 0.8759768841820252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 383}], {
             RGBColor[
             0.96580066387059, 0.9740147716277352, 0.9427747348384041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 414}], {
             RGBColor[
             0.973544437835752, 0.9760463510076494, 0.6963007253468699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 479}], {
             RGBColor[
             0.9719081942489296, 0.9777244608427957, 0.8945821549486634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 482}], {
             RGBColor[
             0.8788234044314697, 0.9058645619192278, 0.9714261816237223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 356}], {
             RGBColor[
             0.9903196371755019, 0.9902649354451625, 0.8100921941852587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 463}], {
             RGBColor[
             0.9152157631343789, 0.6487233994799425, 0.4954877513624631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 367}], {
             RGBColor[
             0.8735161661058108, 0.897690398440913, 0.7345913523485231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 399}], {
             RGBColor[
             0.9862526604771555, 0.9649052600971726, 0.4337367440555412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 412}], {
             RGBColor[
             0.9630681083967432, 0.8799111135761686, 0.3790170337694819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 457}], {
             RGBColor[
             0.9934051492860054, 0.9896800570166819, 0.6236955227856682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 418}], {
             RGBColor[
             0.9218484687265383, 0.9360071816793136, 0.7646339908034498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 420}], {
             RGBColor[
             0.9209286692407943, 0.9370863788844292, 0.8859719022985919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 432}], {
             RGBColor[
             0.9224586976302096, 0.9377190849433885, 0.8606153722994385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 441}], {
             RGBColor[
             0.8581350374949503, 0.6842382854791598, 0.5978004125660926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 372}], {
             RGBColor[
             0.9647110642237271, 0.8911261176253359, 0.529500076683858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 414}], {
             RGBColor[
             0.9920388685167725, 0.9886211431791685, 0.6104354427268315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 415}], {
             RGBColor[
             0.8762653371590667, 0.901992982684622, 0.8834625827544655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 479}], {
             RGBColor[
             0.9904026249299502, 0.9902992530143149, 0.8087168723286251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 482}], {
             RGBColor[
             0.8973178351124902, 0.918439354090747, 0.8855608990036838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 362}], {
             RGBColor[
             0.925413680855639, 0.9395065536064788, 0.8181976185852629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 363}], {
             RGBColor[
             0.9217623775197546, 0.9386117730670871, 0.9234224197181209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 378}], {
             RGBColor[
             0.846571741888385, 0.8804973436767705, 0.9852279625564715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 384}], {
             RGBColor[
             0.9224497243049387, 0.9388960086267674, 0.9120313046911628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 498}], {
             RGBColor[
             0.882196334840351, 0.9089034270928531, 0.9886258680346796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 463}], {
             RGBColor[
             0.9149213460129626, 0.6486016504340619, 0.5003670049914191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 418}], {
             RGBColor[
             0.9923722985517549, 0.9896542057449949, 0.6699798294117874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 420}], {
             RGBColor[
             0.991452499066011, 0.9907334029501105, 0.7913177409069293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 404}], {
             RGBColor[
             0.9129923097010189, 0.6404575328160732, 0.5146287822089146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 407}], {
             RGBColor[
             0.8704369542722301, 0.8980534518964721, 0.9107069891626782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 408}], {
             RGBColor[
             0.769375410142421, 0.8176972149465036, 0.9015955390968122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 430}], {
             RGBColor[
             0.9912315666132732, 0.9897739840919946, 0.7318805387511362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 371}], {
             RGBColor[
             0.6364874839358954, 0.7007241761224003, 0.8298920720729828]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 397}], {
             RGBColor[
             0.6363728881007082, 0.7007338400809189, 0.8359383202059743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 419}], {
             RGBColor[
             0.46746193168624306`, 0.5706870892992407, 0.952796520981337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 427}], {
             RGBColor[
             0.6312512784129678, 0.6847355198114796, 0.6671804887843859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 393}], {
             RGBColor[
             0.5767261400968968, 0.6671829763996897, 0.9598678455908202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 466}], {
             RGBColor[
             0.8145844526821598, 0.8380725788549388, 0.675684111295351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 468}], {
             RGBColor[
             0.7512054978312889, 0.8058545229811505, 0.9757604253232194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 363}], {
             RGBColor[
             0.9879734562104876, 0.9892947293220286, 0.8489744844972478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 370}], {
             RGBColor[
             0.9787420815144408, 0.982920747517492, 0.8874737745611877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 498}], {
             RGBColor[
             0.9484074135310839, 0.9595863833477946, 0.9141779328138065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 363}], {
             RGBColor[
             0.9909176599375413, 0.9898971060015376, 0.7554681537978435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 384}], {
             RGBColor[
             0.9916050067227253, 0.9901813415612178, 0.7440770387708854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 498}], {
             RGBColor[
             0.9513516172581375, 0.9601887600273036, 0.8206716021144023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 370}], {
             RGBColor[
             0.97803498190561, 0.9826283436576094, 0.8991922449946415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 379}], {
             RGBColor[
             0.9267145928888709, 0.9425605351781153, 0.923894766440922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 498}], {
             RGBColor[
             0.9477003139222532, 0.959293979487912, 0.9258964032472603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 374}], {
             RGBColor[
             0.9702822193016143, 0.9077705104445166, 0.4287380907614888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 437}], {
             RGBColor[
             0.9586525206500717, 0.9655870549223691, 0.7870581715558781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 435}], {
             RGBColor[
             0.8906507524778098, 0.9132609234486322, 0.8862542192246421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 473}], {
             RGBColor[
             0.9880059640038621, 0.989308172130001, 0.848435746233561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 416}], {
             RGBColor[
             0.5791727110907448, 0.6662015417165907, 0.961548755357718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 457}], {
             RGBColor[
             0.873796317709553, 0.8996670653088461, 0.865210265944578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 499}], {
             RGBColor[
             0.8728311477663546, 0.8992679427335974, 0.8812056296831192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 386}], {
             RGBColor[
             0.8704913288020394, 0.8995480138878886, 0.9803416958226745]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 401}], {
             RGBColor[
             0.8948207845800574, 0.91634242502077, 0.8786820429821085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 500}], {
             RGBColor[
             0.8741482344136977, 0.90227532810543, 0.974151508495873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 370}], {
             RGBColor[
             0.9814474798696577, 0.9830123436535689, 0.7679749528732707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 379}], {
             RGBColor[
             0.9301270908529186, 0.9429445351740748, 0.7926774743195513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 390}], {
             RGBColor[
             0.9934029738929913, 0.98829795315579, 0.5233326042570463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 425}], {
             RGBColor[
             0.9325924217305039, 0.9449103230962376, 0.7929126197794822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 466}], {
             RGBColor[
             0.9882209653784501, 0.9709484114561213, 0.49209706461220504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 466}], {
             RGBColor[
             0.9755770927183556, 0.9641904296556252, 0.6618136467975158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 382}], {
             RGBColor[
             0.8708153094681924, 0.8969998460527673, 0.848007053559187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 419}], {
             RGBColor[
             0.82619031448501, 0.8621384608093818, 0.8435592511035515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 427}], {
             RGBColor[
             0.9899796612117346, 0.9761868913216207, 0.5579432189066003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 429}], {
             RGBColor[
             0.9912411116681596, 0.9905889365473437, 0.7906738785629495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 417}], {
             RGBColor[
             0.909233630743385, 0.8495478480117801, 0.628679668900085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 398}], {
             RGBColor[
             0.6225514712686651, 0.7044543558569017, 0.9634286787809008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 472}], {
             RGBColor[
             0.7105108133613822, 0.7733309618202397, 0.9720848157255848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 391}], {
             RGBColor[
             0.7995790984073328, 0.7772903892214631, 0.6209572652596832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 437}], {
             RGBColor[
             0.9349967704612261, 0.8839153107244626, 0.634232688885976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 426}], {
             RGBColor[
             0.972209928154737, 0.9787947904366449, 0.93192552220919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 489}], {
             RGBColor[
             0.7922446766566855, 0.8378505647775514, 0.9578845568799128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 400}], {
             RGBColor[
             0.9633415793504218, 0.968615749683237, 0.7299315996482982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 414}], {
             RGBColor[
             0.9631782459788722, 0.9682663961170297, 0.7121537701318562]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 415}], {
             RGBColor[
             0.8474047146211663, 0.8816382356224832, 0.9851809101594903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 464}], {
             RGBColor[
             0.9205284771552793, 0.8100248869415835, 0.6188899917748725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 485}], {
             RGBColor[
             0.804778476586872, 0.8483382944986845, 0.9809323251170743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 497}], {
             RGBColor[
             0.6513327003309293, 0.7219824573612654, 0.9691363772153632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 403}], {
             RGBColor[
             0.9863318316873594, 0.9642085115303087, 0.5159998949390896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 449}], {
             RGBColor[
             0.953875306015797, 0.8483280982407435, 0.31564881432234715`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 484}], {
             RGBColor[
             0.9766994502226569, 0.9592818291861016, 0.6477168546767016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 488}], {
             RGBColor[
             0.9853071870804373, 0.9642983813214868, 0.5703132368603476]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 380}], {
             RGBColor[
             0.7730871035453293, 0.8227973932408692, 0.9779815048230338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 380}], {
             RGBColor[
             0.787725975463913, 0.8344700323471552, 0.9793777734949036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 390}], {
             RGBColor[
             0.9294387122161578, 0.9414721628757998, 0.7177517078886375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 478}], {
             RGBColor[
             0.9244337554082812, 0.9413702526484066, 0.9506286099895296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 390}], {
             RGBColor[
             0.8510018585039858, 0.8798234503288702, 0.7100329034323987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 411}], {
             RGBColor[
             0.851882261726965, 0.882402385337725, 0.8564396951214366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 478}], {
             RGBColor[
             0.8459969016961092, 0.8797215401014771, 0.9429098055332907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 419}], {
             RGBColor[
             0.8236012936585443, 0.861124886444185, 0.8906131249486349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 439}], {
             RGBColor[
             0.9917482872150011, 0.9892828250585091, 0.6720829841217124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 416}], {
             RGBColor[
             0.5754264199269267, 0.6632749105865487, 0.96117536006559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 427}], {
             RGBColor[
             0.8655791039452647, 0.8810111897418464, 0.6852954702705901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 429}], {
             RGBColor[
             0.8668405544016897, 0.8954132349675695, 0.9180261299269392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 499}], {
             RGBColor[
             0.8690848566025366, 0.8963413116035555, 0.8808322343909911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 479}], {
             RGBColor[
             0.9831724412364029, 0.9861253178025418, 0.875514722985004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 482}], {
             RGBColor[
             0.8900876514189431, 0.9142654188789738, 0.9523587496600627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 496}], {
             RGBColor[
             0.8445104808175208, 0.8786601868058166, 0.9478160432373881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 435}], {
             RGBColor[
             0.8892900810787077, 0.9126982508574435, 0.9088040656124654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 391}], {
             RGBColor[
             0.7473458105354204, 0.802730733810061, 0.9754045394669817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 421}], {
             RGBColor[
             0.8663417903717753, 0.8963063629285062, 0.9799281086115871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 403}], {
             RGBColor[
             0.9515435215070072, 0.9604207298955145, 0.8270899000027849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 405}], {
             RGBColor[
             0.9452645825296102, 0.9579950394675817, 0.9531303563272657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 491}], {
             RGBColor[
             0.950850309002299, 0.9606476553783745, 0.8759105542715728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 487}], {
             RGBColor[
             0.9828087074350709, 0.9862234702932557, 0.8926740161966553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 490}], {
             RGBColor[
             0.9708827215487058, 0.9778049619229683, 0.9341721368022793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 409}], {
             RGBColor[
             0.8642517950499709, 0.8706913913862422, 0.6716073542284091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 451}], {
             RGBColor[
             0.984812624719472, 0.9635075578981485, 0.5744568678840767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 456}], {
             RGBColor[
             0.8986639423792913, 0.8975744224219138, 0.6750372354743952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 458}], {
             RGBColor[
             0.9675895127034833, 0.9519671657051645, 0.6620327072583165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 425}], {
             RGBColor[
             0.9319040430937432, 0.9434379507979624, 0.7179868533485685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 478}], {
             RGBColor[
             0.9877096384483539, 0.9867236706301217, 0.6812837399270247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 459}], {
             RGBColor[
             0.9138871234223207, 0.9315552332150019, 0.8889301191744214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 465}], {
             RGBColor[
             0.9890434223165855, 0.9897371878037746, 0.8312423771356852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 492}], {
             RGBColor[
             0.9674799515050507, 0.9740837960753526, 0.8869377174916183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 468}], {
             RGBColor[
             0.6811133107910139, 0.7490188391291401, 0.9701958068597877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 398}], {
             RGBColor[
             0.7884769281388678, 0.835288819887894, 0.9709203969311241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 445}], {
             RGBColor[
             0.9541408515009289, 0.9653189026536324, 0.9625117558141327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 460}], {
             RGBColor[
             0.7750504911154783, 0.8243886334582116, 0.9698634186259836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 440}], {
             RGBColor[
             0.8981756854196032, 0.9211375199265703, 0.9725578537696471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 447}], {
             RGBColor[
             0.9325194677709687, 0.8228958779726008, 0.6032963177044897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 453}], {
             RGBColor[
             0.9743740873122259, 0.9772362937561219, 0.7402179497992203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 463}], {
             RGBColor[
             0.8975965793225278, 0.6366499775860545, 0.573092032066334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 422}], {
             RGBColor[
             0.9798658643020381, 0.9830848715836626, 0.8553887961159099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 443}], {
             RGBColor[
             0.974956002521967, 0.9644722453519547, 0.6644465349107788]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 446}], {
             RGBColor[
             0.9808313178599062, 0.9829546976466479, 0.8009059380848129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 419}], {
             RGBColor[
             0.8260757186498229, 0.8621481247679004, 0.8496054992365429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 472}], {
             RGBColor[
             0.9013412886090231, 0.9209461600595458, 0.8571072678533349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 445}], {
             RGBColor[
             0.7974411413303848, 0.8419743154085755, 0.9557463222391303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 460}], {
             RGBColor[
             0.6183507809449341, 0.7010440462131545, 0.9630979850509811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 472}], {
             RGBColor[
             0.7197365600610408, 0.780820838606175, 0.9728111003008058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 412}], {
             RGBColor[
             0.9561957711916356, 0.8571129835245923, 0.31967716863540974`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 414}], {
             RGBColor[
             0.9927157921599368, 0.9868281409135169, 0.44853711340811814`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 415}], {
             RGBColor[
             0.8769422608022308, 0.9001999804189704, 0.7215642534357523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 464}], {
             RGBColor[
             0.9500660233363438, 0.8285866317380708, 0.35527333505113434`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 450}], {
             RGBColor[
             0.9926857121979207, 0.9893185559149471, 0.6309666688315002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 454}], {
             RGBColor[
             0.9706529540912603, 0.9762831445788781, 0.8740848428280708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 471}], {
             RGBColor[
             0.9873557672677105, 0.9887400752975283, 0.8458113369117097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 475}], {
             RGBColor[
             0.9933563091638142, 0.9915206773512399, 0.7597666806837322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 500}], {
             RGBColor[
             0.9716480580375231, 0.9770252914726678, 0.8724003914117233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 431}], {
             RGBColor[
             0.9681279744835413, 0.9719925749508387, 0.7043437423128047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 436}], {
             RGBColor[
             0.8903044712000976, 0.9151616959691581, 0.9822245254102937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 459}], {
             RGBColor[
             0.8900915627020278, 0.9149919285120445, 0.9822042180076822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 462}], {
             RGBColor[
             0.9688349752337316, 0.9746572467745138, 0.865068719844065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 487}], {
             RGBColor[
             0.9653901028518103, 0.9732327035154074, 0.9221591702564481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 405}], {
             RGBColor[
             0.9884077270130414, 0.9886179503231161, 0.7890950233593104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 449}], {
             RGBColor[
             0.962230140318876, 0.8751632274614837, 0.4627034864180871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 491}], {
             RGBColor[
             0.9939934534857302, 0.9912705662339089, 0.7118752213036175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 407}], {
             RGBColor[
             0.7952419048259373, 0.5491278010290853, 0.5799062121005761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 408}], {
             RGBColor[
             0.6941803606961281, 0.46877156407911685`, 0.5707947620347101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 434}], {
             RGBColor[
             0.9799217986095824, 0.9613406099194355, 0.6415310754386376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 469}], {
             RGBColor[
             0.9884240223003078, 0.9886528042948726, 0.7908686648154024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 474}], {
             RGBColor[
             0.7386516393417809, 0.7936181223082889, 0.9342682879764863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 491}], {
             RGBColor[
             0.9877145145083333, 0.988844875805976, 0.8379156776280983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 413}], {
             RGBColor[
             0.9176870961791244, 0.9369958578458797, 0.9848363046255513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 476}], {
             RGBColor[
             0.9296788091775925, 0.9465577242844802, 0.9859800849164737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 486}], {
             RGBColor[
             0.9669858040195812, 0.9738925669559302, 0.8957142723642371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 493}], {
             RGBColor[
             0.9648404760316446, 0.9609210253235019, 0.6900457026932167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 408}], {
             RGBColor[
             0.6516250052673394, 0.7263674831595157, 0.9668729689884739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 430}], {
             RGBColor[
             0.8734811617381917, 0.8984442523050067, 0.7971579686427979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{408, 430}], {
             RGBColor[
             0.7724196176083824, 0.8180880153550383, 0.7880465185769319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 456}], {
             RGBColor[
             0.7853349338296762, 0.8322288861650868, 0.9792385048980752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 458}], {
             RGBColor[
             0.8542605041538682, 0.8866216294483376, 0.9662339766819963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 496}], {
             RGBColor[
             0.7314394186386669, 0.7901253000767836, 0.9738667036260603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{411, 478}], {
             RGBColor[
             0.9885900416713332, 0.9893026056389764, 0.8276905316160628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 476}], {
             RGBColor[
             0.903642048295439, 0.9260036568735563, 0.9906713793288403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 486}], {
             RGBColor[
             0.9409490431374279, 0.9533384995450063, 0.9004055667766038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 493}], {
             RGBColor[
             0.9388037151494912, 0.9403669579125782, 0.6947369971055835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 415}], {
             RGBColor[
             0.8767789274306813, 0.8998506268527631, 0.7037864239193101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 485}], {
             RGBColor[
             0.834152689396387, 0.8665506857289643, 0.699537838876894]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{415, 464}], {
             RGBColor[
             0.8341291586070884, 0.7416091176773169, 0.6105226455623263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{415, 485}], {
             RGBColor[
             0.7183791580386811, 0.7799225252344179, 0.9725649789045281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 427}], {
             RGBColor[
             0.6945907716704689, 0.7424619558554021, 0.6711115254130032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 429}], {
             RGBColor[
             0.6958522221268939, 0.7568640010811252, 0.9038421850693523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 499}], {
             RGBColor[
             0.6980965243277408, 0.757792077717111, 0.8666482895334042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{417, 461}], {
             RGBColor[
             0.8972228623185659, 0.9208851722197591, 0.9900591116398911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 420}], {
             RGBColor[
             0.992670325455147, 0.9897774475284895, 0.6650407523536773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 432}], {
             RGBColor[
             0.9942003538445622, 0.9904101535874488, 0.6396842223545239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 432}], {
             RGBColor[
             0.9932805543588182, 0.9914893507925645, 0.7610221338496659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 439}], {
             RGBColor[
             0.9926046376588371, 0.9896369479742377, 0.6578910411034402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 423}], {
             RGBColor[
             0.8913308814373403, 0.911956914243461, 0.764362112366584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 477}], {
             RGBColor[
             0.8777844788194602, 0.9048403012371069, 0.960558621800776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 443}], {
             RGBColor[
             0.9878275507727527, 0.9726521214659702, 0.579081137975797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 446}], {
             RGBColor[
             0.9937028661106919, 0.9911345737606634, 0.7155405411498312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 446}], {
             RGBColor[
             0.9941540992237683, 0.9899045342879017, 0.6050879611039095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 477}], {
             RGBColor[
             0.9800934761610967, 0.9816880557458005, 0.7453147485232765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 440}], {
             RGBColor[
             0.7691595490268601, 0.8197622205879955, 0.9775812690465084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 453}], {
             RGBColor[
             0.8453579509194826, 0.8758609944175471, 0.7452413650760816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 470}], {
             RGBColor[
             0.8123060684554366, 0.7564204978069271, 0.6154026218604707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{425, 466}], {
             RGBColor[
             0.926722034579202, 0.9260884090982938, 0.6867513137037272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 448}], {
             RGBColor[
             0.9886578697200074, 0.98771672587687, 0.702360869532769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 489}], {
             RGBColor[
             0.8042254902597, 0.8467858359458977, 0.9376041645466473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 460}], {
             RGBColor[
             0.7948338998051758, 0.8251710473970859, 0.678636321181922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 499}], {
             RGBColor[
             0.988249208346079, 0.9755283568724089, 0.5907683997384043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 495}], {
             RGBColor[
             0.6355116063101441, 0.7125717879707624, 0.9660927054819837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{429, 499}], {
             RGBColor[
             0.9895106588025038, 0.9899304020981319, 0.8234990593947535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 433}], {
             RGBColor[
             0.9804690282385594, 0.9457616329454668, 0.38015302105764376`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 436}], {
             RGBColor[
             0.9147085886223612, 0.9296043456631933, 0.7064232575099139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 459}], {
             RGBColor[
             0.9144956801242914, 0.9294345782060796, 0.7064029501073024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 462}], {
             RGBColor[
             0.9932390926559952, 0.989099896468549, 0.5892674519436851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 487}], {
             RGBColor[
             0.9897942202740738, 0.9876753532094424, 0.6463579023560683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{432, 467}], {
             RGBColor[
             0.9714381947101778, 0.9764551005094024, 0.8542304129671816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 462}], {
             RGBColor[
             0.9811760289887498, 0.948426304769142, 0.540877998588904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 469}], {
             RGBColor[
             0.9862170328742457, 0.9638011543191249, 0.5172642605702487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 474}], {
             RGBColor[
             0.7364446499157189, 0.7687664723325414, 0.6606638837313327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 495}], {
             RGBColor[
             0.7247172678589079, 0.7592456552662812, 0.6597406612570045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 459}], {
             RGBColor[
             0.8366721768408477, 0.8726036992243991, 0.9842837332047913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 462}], {
             RGBColor[
             0.9154155893725515, 0.9322690174868684, 0.8671482350411741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 487}], {
             RGBColor[
             0.9119707169906301, 0.930844474227762, 0.9242386854535574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 457}], {
             RGBColor[
             0.9864554962597628, 0.9666211225457995, 0.5640553002863545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 460}], {
             RGBColor[
             0.7920750177756614, 0.8158646904952278, 0.6679185854684131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 453}], {
             RGBColor[
             0.9171740860586133, 0.9321339729794252, 0.7523543016048231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 470}], {
             RGBColor[
             0.8841222035945673, 0.8126934763688053, 0.6225155583892121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 467}], {
             RGBColor[
             0.9071145345749185, 0.7229743010451737, 0.5914154532338358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 444}], {
             RGBColor[
             0.9700415247380928, 0.9746160812123539, 0.7960325235599415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 492}], {
             RGBColor[
             0.9689473002296108, 0.9738000103655563, 0.7978847602333428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{443, 446}], {
             RGBColor[
             0.9887930043306207, 0.9725219475289555, 0.5245982799447001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{444, 492}], {
             RGBColor[
             0.94473914901672, 0.9583071283347844, 0.9784263857631723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{445, 460}], {
             RGBColor[
             0.7840147043069952, 0.8310741289788929, 0.9546893439339897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 453}], {
             RGBColor[
             0.9515178684099788, 0.8338923310254556, 0.3830927655396655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 463}], {
             RGBColor[
             0.8747403604202808, 0.4933060148553882, 0.2159668478067791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{449, 488}], {
             RGBColor[
             0.9612054957119538, 0.8752530972526618, 0.5170168283393453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 454}], {
             RGBColor[
             0.9710180580852981, 0.9745093121058173, 0.7281205857616121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 469}], {
             RGBColor[
             0.9938850363784648, 0.9893290360682241, 0.5758021308560275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 471}], {
             RGBColor[
             0.9877208712617483, 0.9869662428244674, 0.699847079845251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 475}], {
             RGBColor[
             0.993721413157852, 0.9897468448781792, 0.6138024236172737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 491}], {
             RGBColor[
             0.9931755285864903, 0.9895211075793275, 0.6228491436687235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 500}], {
             RGBColor[
             0.972013162031561, 0.9752514589996071, 0.7264361343452647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{451, 456}], {
             RGBColor[
             0.9058957634991774, 0.9250450526769931, 0.8820880185537426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{453, 463}], {
             RGBColor[
             0.9165949799615378, 0.6476464306389094, 0.3528884799015098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 469}], {
             RGBColor[
             0.9718522782718043, 0.9762936247321552, 0.818920304852598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 471}], {
             RGBColor[
             0.9656881131550878, 0.9739308314883985, 0.9429652538418216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 475}], {
             RGBColor[
             0.9716886550511915, 0.9767114335421103, 0.8569205976138441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 500}], {
             RGBColor[
             0.9499804039249005, 0.9622160476635381, 0.9695543083418352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{456, 458}], {
             RGBColor[
             0.8886726514831886, 0.9135046604840091, 0.9696638579279825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{461, 486}], {
             RGBColor[
             0.9520615321652712, 0.9621992966553297, 0.9014654859003155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{461, 493}], {
             RGBColor[
             0.9499162041773346, 0.9492277550229014, 0.6957969162292952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{462, 487}], {
             RGBColor[
             0.9905012210242642, 0.9903400250331178, 0.8070828798873285]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 485}], {
             RGBColor[
             0.791502920572794, 0.7083091765535181, 0.6062740605199103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 497}], {
             RGBColor[
             0.6380571443168513, 0.581953339416099, 0.5944781126181993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 468}], {
             RGBColor[
             0.918971623376277, 0.9199084415843892, 0.6860120725643184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 471}], {
             RGBColor[
             0.9885550914482546, 0.9887505554508054, 0.7906467989362369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 474}], {
             RGBColor[
             0.7449468736064442, 0.7960786667079783, 0.8100014731080973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 475}], {
             RGBColor[
             0.9945556333443583, 0.9915311575045171, 0.7046021427082596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 491}], {
             RGBColor[
             0.9940097487729965, 0.9913054202056655, 0.7136488627597094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 495}], {
             RGBColor[
             0.7332194915496333, 0.7865578496417182, 0.8090782506337693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 475}], {
             RGBColor[
             0.9883914682276418, 0.9891683642607605, 0.8286470916974831]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 500}], {
             RGBColor[
             0.9666832171013507, 0.9746729783821882, 0.9412808024254742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{474, 495}], {
             RGBColor[
             0.4834471085911064, 0.5915231676551345, 0.9524778737948532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{476, 493}], {
             RGBColor[
             0.9507954281479594, 0.9499288243511785, 0.6958807773965059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{479, 482}], {
             RGBColor[
             0.8961951817972825, 0.9179751080940344, 0.904166169770322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{480, 481}], {
             RGBColor[
             0.7442670526266051, 0.7910113575020614, 0.6848977766487067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{482, 496}], {
             RGBColor[
             0.7575332213784003, 0.8105099770973093, 0.9764674900227063]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{484, 500}], {
             RGBColor[
             0.9631987054660983, 0.9720742353099812, 0.9471791717177707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{485, 497}], {
             RGBColor[
             0.5223071437484441, 0.6202667469732, 0.9565204459604011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{486, 493}], {
             RGBColor[
             0.9881024229899481, 0.9772636670226286, 0.6056149648442692]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.0315874366232787], {
             RGBColor[
             0.994761622142692, 0.9912039643814904, 0.6712130816319075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.0315874366232787], {
             RGBColor[
             0.8280758321442895, 0.8657492073049241, 0.9834638061735862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.0315874366232787], {
             RGBColor[
             0.9381481289873536, 0.9533915563886877, 0.9895832634595528]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.0315874366232787], {
             RGBColor[
             0.8517709590339677, 0.8846430582996684, 0.9857238685292131]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.0315874366232787], {
             RGBColor[
             0.8405027905099549, 0.875658126584907, 0.98464910055618]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.0315874366232787], {
             RGBColor[
             0.9651381352551532, 0.8940648856398379, 0.3190686678873633]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.0315874366232787], {
             RGBColor[
             0.9156337612939072, 0.9355655233121568, 0.9918151596197627]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.0315874366232787], {
             RGBColor[
             0.4060094396651162, 0.5260867028353036, 0.9470915403687785]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.0315874366232787], {
             RGBColor[
             0.6958017914834582, 0.7622849148871366, 0.9703146780037897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.0315874366232787], {
             RGBColor[
             0.9875924067420115, 0.989137155574289, 0.8552894603143094]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.0315874366232787], {
             RGBColor[
             0.8654549253822151, 0.8955542816243894, 0.98702905745533]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.0315874366232787], {
             RGBColor[
             0.9499945830984222, 0.9622266224679343, 0.9695303066995835]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.0315874366232787], {
             RGBColor[
             0.9787012665938317, 0.9398165124198827, 0.3717588719556926]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.0315874366232787], {
             RGBColor[
             0.8499918119256579, 0.8832244146891638, 0.9855541718897592]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.0315874366232787], {
             RGBColor[
             0.9445058005193249, 0.9581330974075001, 0.9788213839022271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.0315874366232787], {
             RGBColor[
             0.5344973444757293, 0.6329680489331897, 0.9564967353668664]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.0315874366232787], {
             RGBColor[
             0.921488412039042, 0.9402338628960664, 0.9923735814343422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.0315874366232787], {
             RGBColor[
             0.7288233705254076, 0.7880816234080034, 0.9736059603984901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.0315874366232787], {
             RGBColor[
             0.9769295851811134, 0.9823147029191873, 0.9239363739472319]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.0315874366232787], {
             RGBColor[
             0.9927470063538071, 0.9868949049179667, 0.4519345857792383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.0315874366232787], {
             RGBColor[
             0.8340272800335832, 0.8704947303040975, 0.9840314605861873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.0315874366232787], {
             RGBColor[
             0.9918631161662353, 0.9909032036734315, 0.7845127529132185]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.0315874366232787], {
             RGBColor[
             0.9596632772069624, 0.9694375187030501, 0.9531637295731195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.0315874366232787], {
             RGBColor[
             0.98499426026609, 0.9880627552371767, 0.8983474712078723]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.0315874366232787], {
             RGBColor[
             0.7679837895328073, 0.8186740403667918, 0.9775091049902256]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.0315874366232787], {
             RGBColor[
             0.9516755510296806, 0.846116693540358, 0.27997521791911906`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.0315874366232787], {
             RGBColor[
             0.7235485549936205, 0.7839608974244885, 0.9730802160822354]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.0315874366232787], {
             RGBColor[
             0.9717992331185357, 0.9165343328331821, 0.34494577524382214`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.0315874366232787], {
             RGBColor[
             0.9365900091763613, 0.9522295131848366, 0.9922207538768317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.0315874366232787], {
             RGBColor[
             0.8611819161618465, 0.8921471000598129, 0.9866214940213308]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.0315874366232787], {
             RGBColor[
             0.9926384671321766, 0.9866627504978979, 0.4401207613311979]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.0315874366232787], {
             RGBColor[
             0.9931226748746049, 0.9876984218980394, 0.4928237859107087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.0315874366232787], {
             RGBColor[
             0.7686188297487496, 0.8191701386099703, 0.9775723998641624]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.0315874366232787], {
             RGBColor[
             0.9906116290202498, 0.9903856815768138, 0.805253133667114]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.0315874366232787], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.0315874366232787], {
             RGBColor[
             0.7742207816765851, 0.823546426032407, 0.978130750079112]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.0315874366232787], {
             RGBColor[
             0.9922801948304429, 0.9910756764195141, 0.777600680082317]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.0315874366232787], {
             RGBColor[
             0.9353426999726137, 0.781362381699061, 0.26683342257731485`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.0315874366232787], {
             RGBColor[
             0.9517791693984899, 0.963557564008533, 0.9665094675882199]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.0315874366232787], {
             RGBColor[
             0.9874526239609769, 0.9890793518020776, 0.8576060227422948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.0315874366232787], {
             RGBColor[
             0.8167277916394404, 0.8567532252806307, 0.9823674515816166]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.0315874366232787], {
             RGBColor[
             0.9481060494402355, 0.9608181571578488, 0.9727271015744298]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.0315874366232787], {
             RGBColor[
             0.9827311511812263, 0.9866415013428791, 0.9141158359997906]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.0315874366232787], {
             RGBColor[
             0.964610825509446, 0.9731273921261755, 0.9447888208242758]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.0315874366232787], {
             RGBColor[
             0.9125889311846307, 0.9331376584327313, 0.991524741005788]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.0315874366232787], {
             RGBColor[
             0.8974440482331547, 0.6271992002253893, 0.23613713878038212`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.0315874366232787], {
             RGBColor[
             0.9764870991010651, 0.9819846975251917, 0.924685387461901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.0315874366232787], {
             RGBColor[
             0.9943596889220683, 0.9903442698642584, 0.6274651310113197]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.0315874366232787], {
             RGBColor[
             0.9778894757442765, 0.937078151266777, 0.368605217799009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.0315874366232787], {
             RGBColor[
             0.6955987398736622, 0.7621262894263146, 0.9702944397169504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.0315874366232787], {
             RGBColor[
             0.9391329286420175, 0.9541260183586745, 0.9879162545210928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.0315874366232787], {
             RGBColor[
             0.9864100276801119, 0.9886482114464377, 0.8748845412689116]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.0315874366232787], {
             RGBColor[
             0.9524053407651528, 0.9640245615885287, 0.9654495227961079]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.0315874366232787], {
             RGBColor[
             0.4196519490391767, 0.5379031587626563, 0.9479608290024963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.0315874366232787], {
             RGBColor[
             0.9935739259529737, 0.9886636023261877, 0.5419396809923053]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.0315874366232787], {
             RGBColor[
             0.9934490769592772, 0.9883965629528405, 0.5283506385071215]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.0315874366232787], {
             RGBColor[
             0.8687587674743926, 0.8981886756282872, 0.9873441808634565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.0315874366232787], {
             RGBColor[
             0.9456278325369345, 0.9589699070490746, 0.9769220763692325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.0315874366232787], {
             RGBColor[
             0.985955732953962, 0.9884603489023327, 0.882413380558279]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.0315874366232787], {
             RGBColor[
             0.8503664120936247, 0.88352311069485, 0.9855899015881894]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.0315874366232787], {
             RGBColor[
             0.9861134118078136, 0.9885255531605621, 0.8798002338901638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.0315874366232787], {
             RGBColor[
             0.7932422764963147, 0.8384061623542949, 0.9800266349167671]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.0315874366232787], {
             RGBColor[
             0.779729099079362, 0.8278495654522192, 0.978679767679668]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.0315874366232787], {
             RGBColor[
             0.6468420575705056, 0.7240371986465786, 0.965434829282073]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.0315874366232787], {
             RGBColor[
             0.9440886042924382, 0.9578219531445842, 0.9795275882921435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.0315874366232787], {
             RGBColor[
             0.9934222940505667, 0.9883392770192762, 0.525435484178933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.0315874366232787], {
             RGBColor[
             0.9643405087348244, 0.8913743040951556, 0.31597003947501523`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.0315874366232787], {
             RGBColor[
             0.9544195084949806, 0.8569955705206517, 0.28218307050465924`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.0315874366232787], {
             RGBColor[
             0.967128294006641, 0.9750049160094072, 0.9405274033194659]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.0315874366232787], {
             RGBColor[
             0.9551365784488809, 0.9660615141810618, 0.9608262498184306]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.0315874366232787], {
             RGBColor[
             0.9911411438168791, 0.9906046495531297, 0.7964777031465992]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.0315874366232787], {
             RGBColor[
             0.3992736043846964, 0.520252460868329, 0.9466623389009755]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.0315874366232787], {
             RGBColor[
             0.8022252999813367, 0.8454237685743011, 0.9809219787466268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.0315874366232787], {
             RGBColor[
             0.8535981980829038, 0.4129848141111679, 0.19895900105568243`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.0315874366232787], {
             RGBColor[
             0.995039263570426, 0.9922166222483295, 0.7318757708197832]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.0315874366232787], {
             RGBColor[
             0.9130422362325307, 0.9334991115732891, 0.991567977645927]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.0315874366232787], {
             RGBColor[
             0.9920406158241435, 0.9909766043435096, 0.7815711242272926]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.0315874366232787], {
             RGBColor[
             0.7086450634956192, 0.7723181765955193, 0.9715947753307611]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.0315874366232787], {
             RGBColor[
             0.990460762545138, 0.9903232944122636, 0.8077533815896372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.0315874366232787], {
             RGBColor[
             0.8282181396687027, 0.8658626794620564, 0.9834773795923041]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.0315874366232787], {
             RGBColor[
             0.5941261706242863, 0.681377416248594, 0.9611909349888681]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.0315874366232787], {
             RGBColor[
             0.943644924508238, 0.9574910574879867, 0.9802786224365736]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.0315874366232787], {
             RGBColor[
             0.9897293299086648, 0.9900208282201205, 0.8198751132629846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.0315874366232787], {
             RGBColor[
             0.476813844750156, 0.5861379852439204, 0.9519556789668475]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.0315874366232787], {
             RGBColor[
             0.9563537148714706, 0.9669692525321512, 0.9587659553350063]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.0315874366232787], {
             RGBColor[
             0.9891190138941445, 0.9897684468637102, 0.8299896290708011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.0315874366232787], {
             RGBColor[
             0.9940299696299112, 0.9896390336380685, 0.5915772208516179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.0315874366232787], {
             RGBColor[
             0.9925524587883872, 0.9864787873473095, 0.4307592838916761]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.0315874366232787], {
             RGBColor[
             0.9940646295978214, 0.9897131678047679, 0.5953497444621092]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.0315874366232787], {
             RGBColor[
             0.4196732906503759, 0.5379216437936165, 0.9479621888710903]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.0315874366232787], {
             RGBColor[
             0.9800401832971756, 0.9443329928528535, 0.37696031051498]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.0315874366232787], {
             RGBColor[
             0.9654225358612915, 0.89502423566478, 0.32017351053766224`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.0315874366232787], {
             RGBColor[
             0.9688953032216306, 0.9763227485887345, 0.9375363176283014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.0315874366232787], {
             RGBColor[
             0.9939135162767967, 0.9893899516909965, 0.5789019920318876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.0315874366232787], {
             RGBColor[
             0.9908898535201842, 0.9905007345575803, 0.8006422336812754]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.0315874366232787], {
             RGBColor[
             0.6765063248429799, 0.747211149696617, 0.9683914862154546]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.0315874366232787], {
             RGBColor[
             0.9705225385893814, 0.9775363380616495, 0.9347818326016544]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.0315874366232787], {
             RGBColor[
             0.9357890338837308, 0.7831319469246814, 0.2671925533190031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.0315874366232787], {
             RGBColor[
             0.8642840847091512, 0.8946206850533116, 0.9869173816267113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.0315874366232787], {
             RGBColor[
             0.9669943160512524, 0.9749049954696472, 0.9407541930508916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.0315874366232787], {
             RGBColor[
             0.9627019401757618, 0.9717037485698267, 0.9480200657771721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.0315874366232787], {
             RGBColor[
             0.8565277200125756, 0.8884359703851732, 0.9861775726377634]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.0315874366232787], {
             RGBColor[
             0.9929719279031446, 0.9873759893689426, 0.47641590836971975`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.0315874366232787], {
             RGBColor[
             0.984763798202576, 0.9879674532513087, 0.9021668240170019]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.0315874366232787], {
             RGBColor[
             0.9675167262567634, 0.975294608145549, 0.9398698888393647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.0315874366232787], {
             RGBColor[
             0.9949337294248691, 0.9915720844553517, 0.6899458971738577]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.0315874366232787], {
             RGBColor[
             0.8912924350803424, 0.9161564105171588, 0.9894934621957545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.0315874366232787], {
             RGBColor[
             0.9926432239233782, 0.9866729247932927, 0.4406385086979782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.0315874366232787], {
             RGBColor[
             0.9516755510296806, 0.846116693540358, 0.27997521791911906`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.0315874366232787], {
             RGBColor[
             0.9440398719696395, 0.9577856086580327, 0.9796100794032163]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.0315874366232787], {
             RGBColor[
             0.9674385184724614, 0.9752362809080701, 0.9400022742183309]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.0315874366232787], {
             RGBColor[
             0.6180241048394668, 0.7007788358341452, 0.9630722679113046]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.0315874366232787], {
             RGBColor[
             0.992811578701251, 0.9912954173060358, 0.768794274165652]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.0315874366232787], {
             RGBColor[
             0.9587499018954205, 0.9687563248912169, 0.9547098357291259]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.0315874366232787], {
             RGBColor[
             0.9637098283336994, 0.9724554299077511, 0.9463139740251159]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.0315874366232787], {
             RGBColor[
             0.9935990320651408, 0.9887173017614959, 0.5446723263647331]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.0315874366232787], {
             RGBColor[
             0.7078867023204115, 0.7717257390816886, 0.9715191889761045]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.0315874366232787], {
             RGBColor[
             0.9724775037938655, 0.9789943479101921, 0.931472586447049]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.0315874366232787], {
             RGBColor[
             0.9936220326696094, 0.9916305608496689, 0.7553629545223166]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.0315874366232787], {
             RGBColor[
             0.9920030826041056, 0.9909610833924642, 0.7821931468161787]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.0315874366232787], {
             RGBColor[
             0.9491638974229396, 0.9616070984512823, 0.970936440870653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.0315874366232787], {
             RGBColor[
             0.9875637516212081, 0.9891253059454338, 0.8557643498230968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.0315874366232787], {
             RGBColor[
             0.9594488141537099, 0.8748734696485485, 0.2969667297463946]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.0315874366232787], {
             RGBColor[
             0.9922997456026216, 0.991083761166242, 0.7772766731915393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.0315874366232787], {
             RGBColor[
             0.7391517277861053, 0.7961502145984829, 0.9746353945262503]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.0315874366232787], {
             RGBColor[
             0.9940545986786762, 0.9896917126829979, 0.5942579408168185]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.0315874366232787], {
             RGBColor[
             0.9914081235941095, 0.9907150525520817, 0.7920531573163769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.0315874366232787], {
             RGBColor[
             0.9947562454611723, 0.9911924642033852, 0.6706278630295037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.0315874366232787], {
             RGBColor[
             0.9764870991010651, 0.9819846975251917, 0.924685387461901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.0315874366232787], {
             RGBColor[
             0.9939762846487628, 0.9917770531469094, 0.7494920824530108]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.0315874366232787], {
             RGBColor[
             0.9933886079898365, 0.9882672259415575, 0.5217689643547243]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.0315874366232787], {
             RGBColor[
             0.9891307035529966, 0.9897732808380562, 0.8297959011717531]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.0315874366232787], {
             RGBColor[
             0.8767226777686483, 0.9045388815223406, 0.9881037857367893]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.0315874366232787], {
             RGBColor[
             0.4017445986321872, 0.5223927118897236, 0.9468197884694112]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.0315874366232787], {
             RGBColor[
             0.9859117539253687, 0.9884421624437999, 0.8831422268761491]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.0315874366232787], {
             RGBColor[
             0.896960293200872, 0.920675806732559, 0.9900340675630473]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.0315874366232787], {
             RGBColor[
             0.8529343560030423, 0.8855707194632391, 0.9858348343707003]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.0315874366232787], {
             RGBColor[
             0.9881004199580306, 0.989347232094457, 0.846870366628816]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.0315874366232787], {
             RGBColor[
             0.9803341725028372, 0.9848538385692288, 0.91817329567014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.0315874366232787], {
             RGBColor[
             0.9952031270002631, 0.9921482986288463, 0.7192681607263712]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.0315874366232787], {
             RGBColor[
             0.9470405228984409, 0.9600234892076178, 0.9745307600758579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.0315874366232787], {
             RGBColor[
             0.9926936791123855, 0.9867808433407771, 0.4461302446480867]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.0315874366232787], {
             RGBColor[
             0.9680035400057236, 0.903730568692542, 0.33020022425704637`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.0315874366232787], {
             RGBColor[
             0.9521748471865333, 0.9638526598549928, 0.9658396883023574]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.0315874366232787], {
             RGBColor[
             0.9489712823642122, 0.9614634464558618, 0.9712624879230253]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.0315874366232787], {
             RGBColor[
             0.9902193274416536, 0.9902234547923737, 0.8117545860683917]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.0315874366232787], {
             RGBColor[
             0.6029981573899142, 0.6885800947833799, 0.9618893702862167]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.0315874366232787], {
             RGBColor[
             0.8287764074240538, 0.8663078270163989, 0.983530627669181]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.0315874366232787], {
             RGBColor[
             0.9930448570380175, 0.9875319774141691, 0.4843537946341857]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.0315874366232787], {
             RGBColor[
             0.9793803232720479, 0.9421071300455963, 0.37439687892146906`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.0315874366232787], {
             RGBColor[
             0.9885184001469689, 0.9895200776441839, 0.8399433532000532]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.0315874366232787], {
             RGBColor[
             0.9951813118002211, 0.9921016381218115, 0.7168937108296036]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.0315874366232787], {
             RGBColor[
             0.9902439978701078, 0.9902336566485406, 0.8113457332238859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.0315874366232787], {
             RGBColor[
             0.9671622621078588, 0.9750302493636778, 0.9404699041844038]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.0315874366232787], {
             RGBColor[
             0.9945689632734257, 0.9907918865409293, 0.6502433526649855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.0315874366232787], {
             RGBColor[
             0.9714310363902652, 0.9152923188120228, 0.3435154004826091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.0315874366232787], {
             RGBColor[
             0.8197470811589967, 0.8591119172007583, 0.9826683861440613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.0315874366232787], {
             RGBColor[
             0.9870582972522933, 0.9889162875743027, 0.8641410367899918]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.0315874366232787], {
             RGBColor[
             0.9481257099902091, 0.9608328199638279, 0.9726938213916173]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.0315874366232787], {
             RGBColor[
             0.7144614574734061, 0.7768619877771978, 0.9721744991251748]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.0315874366232787], {
             RGBColor[
             0.9557685073274801, 0.9665328057040325, 0.95975655906041]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.0315874366232787], {
             RGBColor[
             0.9949557474796086, 0.9916191788480725, 0.6923424265525594]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.0315874366232787], {
             RGBColor[
             0.5035372528754228, 0.6078332518358287, 0.954059443545538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.0315874366232787], {
             RGBColor[
             0.9464765244950829, 0.9596028601218561, 0.9754854622584005]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.0315874366232787], {
             RGBColor[
             0.990231992453533, 0.9902286921002618, 0.8115446940455516]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.0315874366232787], {
             RGBColor[
             0.9923206082038829, 0.9910923883880078, 0.7769309258979589]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.0315874366232787], {
             RGBColor[
             0.9950690747021357, 0.9918615743179181, 0.704677395350086]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.0315874366232787], {
             RGBColor[
             0.6011340847591126, 0.68706675664618, 0.961742623660397]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.0315874366232787], {
             RGBColor[
             0.9918655249554302, 0.9909041997696667, 0.7844728330425135]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.0315874366232787], {
             RGBColor[
             0.6910757253417514, 0.7585928760978021, 0.9698436278983834]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.0315874366232787], {
             RGBColor[
             0.9463325743084324, 0.959495502308349, 0.9757291323761782]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.0315874366232787], {
             RGBColor[
             0.9295486179424448, 0.9466608522949791, 0.9931423710688395]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.0315874366232787], {
             RGBColor[
             0.8642840847091512, 0.8946206850533116, 0.9869173816267113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.0315874366232787], {
             RGBColor[
             0.9946866659904383, 0.9910436407510489, 0.6630545670348296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.0315874366232787], {
             RGBColor[
             0.8632095549064818, 0.8937638841559976, 0.9868148920148886]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.0315874366232787], {
             RGBColor[
             0.9433391891963481, 0.813065796799098, 0.2732675855084579]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.0315874366232787], {
             RGBColor[
             0.7993034860859929, 0.8431412253526505, 0.9806307596434422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.0315874366232787], {
             RGBColor[
             0.9728996623668278, 0.979309193082686, 0.9307579820996137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.0315874366232787], {
             RGBColor[
             0.9410838851299942, 0.9555810385130096, 0.9846137940778935]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.0315874366232787], {
             RGBColor[
             0.9945689632734257, 0.9907918865409293, 0.6502433526649855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.0315874366232787], {
             RGBColor[
             0.9419304438799969, 0.9562124006426488, 0.9831807909320226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.0315874366232787], {
             RGBColor[
             0.9807814461909492, 0.9468334466503561, 0.37983997688153864`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.0315874366232787], {
             RGBColor[
             0.9427646108812472, 0.9568345210263581, 0.9817687637845038]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.0315874366232787], {
             RGBColor[
             0.9600467891850777, 0.9697235413083851, 0.9525145438301138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.0315874366232787], {
             RGBColor[
             0.766321644409168, 0.8173755599634339, 0.9773434378979305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.0315874366232787], {
             RGBColor[
             0.9925384584976459, 0.9864488421410605, 0.42923543864427377`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.0315874366232787], {
             RGBColor[
             0.8849380430660418, 0.9110895908103319, 0.9888873746127979]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.0315874366232787], {
             RGBColor[
             0.7993034860859929, 0.8431412253526505, 0.9806307596434422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.0315874366232787], {
             RGBColor[
             0.9923206082038829, 0.9910923883880078, 0.7769309258979589]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.0315874366232787], {
             RGBColor[
             0.8982909915651857, 0.6310449720875011, 0.23684384905710953`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.0315874366232787], {
             RGBColor[
             0.5985345274212615, 0.6849563188905889, 0.961537976984269]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.0315874366232787], {
             RGBColor[
             0.9861166971049226, 0.9885269117153449, 0.8797457880149935]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.0315874366232787], {
             RGBColor[
             0.9858746281928233, 0.9884268099993047, 0.8837574963427408]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.0315874366232787], {
             RGBColor[
             0.9934839719768828, 0.9884711998670714, 0.5321487458264043]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.0315874366232787], {
             RGBColor[
             0.9081185216015778, 0.6734275863775558, 0.24492820962638162`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.0315874366232787], {
             RGBColor[
             0.8908916096524633, 0.5974461069913812, 0.23066962341368627`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.0315874366232787], {
             RGBColor[
             0.5505634611375302, 0.6460112462095473, 0.9577615189226079]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.0315874366232787], {
             RGBColor[
             0.9936089224832533, 0.9887384563657637, 0.545748837339687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.0315874366232787], {
             RGBColor[
             0.8197470811589967, 0.8591119172007583, 0.9826683861440613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.0315874366232787], {
             RGBColor[
             0.9860288753738281, 0.9884905951726218, 0.8812012213745832]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.0315874366232787], {
             RGBColor[
             0.7605619884270208, 0.8128760729351738, 0.9767693692166755]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.0315874366232787], {
             RGBColor[
             0.967928859564656, 0.9756019764917689, 0.9391722546506844]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.0315874366232787], {
             RGBColor[
             0.9939137590770833, 0.9893904710162589, 0.5789284193447056]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.0315874366232787], {
             RGBColor[
             0.8063905958098535, 0.8486777293329593, 0.9813371365079108]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.0315874366232787], {
             RGBColor[
             0.5365576828274754, 0.6346407244243223, 0.956658932749184]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.0315874366232787], {
             RGBColor[
             0.9505524140022226, 0.9626426518426244, 0.9685860444850504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.0315874366232787], {
             RGBColor[
             0.9937171907950725, 0.9889700313371395, 0.5575331749266351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.0315874366232787], {
             RGBColor[
             0.9895122053947392, 0.9899310416537668, 0.823473428358962]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.0315874366232787], {
             RGBColor[
             0.9946653709344503, 0.9920620080347511, 0.7380721394010265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.0315874366232787], {
             RGBColor[
             0.8854672983464368, 0.9115116046046668, 0.9889378554539137]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.0315874366232787], {
             RGBColor[
             0.9751727468871493, 0.9279139869134168, 0.35805123920026627`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.0315874366232787], {
             RGBColor[
             0.9926991229149806, 0.9912489139484312, 0.770657957570398]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.0315874366232787], {
             RGBColor[
             0.6951769307296625, 0.7617967689171536, 0.970252397723507]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.0315874366232787], {
             RGBColor[
             0.9891924326725939, 0.9897988074153756, 0.828772889910186]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.0315874366232787], {
             RGBColor[
             0.9935933929658938, 0.9887052402984069, 0.5440585452121803]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.0315874366232787], {
             RGBColor[
             0.9946215495070216, 0.9909043631773071, 0.655967039667279]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.0315874366232787], {
             RGBColor[
             0.9934408426720591, 0.9883789506450952, 0.5274543871595616]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.0315874366232787], {
             RGBColor[
             0.9604917324217577, 0.9700553792457735, 0.9517613709901963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.0315874366232787], {
             RGBColor[
             0.9371718124584562, 0.7886142031898232, 0.268305169418212]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.0315874366232787], {
             RGBColor[
             0.991324686979518, 0.990680549367725, 0.7934359179471931]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.0315874366232787], {
             RGBColor[
             0.8654864596105605, 0.48208725417464304`, 0.20947094348151066`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.0315874366232787], {
             RGBColor[
             0.9952054995670295, 0.9921533733092563, 0.7195263999771061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.0315874366232787], {
             RGBColor[
             0.981297776334402, 0.9485751494643052, 0.38184582198808664`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.0315874366232787], {
             RGBColor[
             0.9932285206541148, 0.9879248153177613, 0.504344445805933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.0315874366232787], {
             RGBColor[
             0.9943357906881923, 0.9902931539584797, 0.6248639557367179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.0315874366232787], {
             RGBColor[
             0.8826656849648918, 0.9092776741419923, 0.9886706350685521]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.0315874366232787], {
             RGBColor[
             0.9526643045117749, 0.9642176963267451, 0.9650111647216391]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.0315874366232787], {
             RGBColor[
             0.9762551659020785, 0.9315652404148437, 0.36225623267558665`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.0315874366232787], {
             RGBColor[
             0.9901011006178057, 0.9901745649624217, 0.8137139105007668]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.0315874366232787], {
             RGBColor[
             0.7993034860859929, 0.8431412253526505, 0.9806307596434422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.0315874366232787], {
             RGBColor[
             0.9861134118078136, 0.9885255531605621, 0.8798002338901638]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.0315874366232787], {
             RGBColor[
             0.8205884048698333, 0.8597789360370719, 0.9827496486760433]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.0315874366232787], {
             RGBColor[
             0.7658106895817979, 0.8169763981688919, 0.9772925106958826]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.0315874366232787], {
             RGBColor[
             0.8710934909312559, 0.9000503207384101, 0.9875668688710044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.0315874366232787], {
             RGBColor[
             0.7934846623287195, 0.8385955160087699, 0.9800507936713169]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.0315874366232787], {
             RGBColor[
             0.9936803803580584, 0.9888912975344725, 0.55352658602534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.0315874366232787], {
             RGBColor[
             0.7069257526397661, 0.7709750378876803, 0.9714234104925231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.0315874366232787], {
             RGBColor[
             0.9938962936079991, 0.9893531141439175, 0.5770274108192655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.0315874366232787], {
             RGBColor[
             0.9948345234624749, 0.9913598929330517, 0.6791479403954717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.0315874366232787], {
             RGBColor[
             0.8222475238555169, 0.17200979404642724`, 0.16893756001001453`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.0315874366232787], {
             RGBColor[
             0.9939135162767967, 0.9893899516909965, 0.5789019920318876]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.0315874366232787], {
             RGBColor[
             0.9498029103340657, 0.9620836732341126, 0.9698547586933759]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.0315874366232787], {
             RGBColor[
             0.7472009546708844, 0.8024383318172625, 0.9754376662378231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.0315874366232787], {
             RGBColor[
             0.9948063257252449, 0.9921202964631175, 0.735736153738255]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.0315874366232787], {
             RGBColor[
             0.9238874517690411, 0.942146792056569, 0.9926024039854375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.0315874366232787], {
             RGBColor[
             0.9944386569648964, 0.9905131745229737, 0.6360603151388834]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.0315874366232787], {
             RGBColor[
             0.9948733979103268, 0.9914430414461974, 0.6833791841388718]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.0315874366232787], {
             RGBColor[
             0.8361267258854741, 0.8721687714384558, 0.9842317076057381]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.0315874366232787], {
             RGBColor[
             0.6596259343346386, 0.734024060335781, 0.9667090066458012]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.0315874366232787], {
             RGBColor[
             0.517834608097045, 0.6194404888932543, 0.9551849837215219]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.0315874366232787], {
             RGBColor[
             0.9679468990802076, 0.9756154303329303, 0.9391417184563149]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.0315874366232787], {
             RGBColor[
             0.6974422291928652, 0.7635664372935137, 0.9704781815039014]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.0315874366232787], {
             RGBColor[
             0.7980319138455609, 0.842147863454118, 0.9805040212060341]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.0315874366232787], {
             RGBColor[
             0.9951725983881046, 0.9920830010143554, 0.7159453096936692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.0315874366232787], {
             RGBColor[
             0.8817841771458675, 0.9085747837349947, 0.9885865560658422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.0315874366232787], {
             RGBColor[
             0.9850753875133046, 0.9613179189960289, 0.39652112807611095`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.0315874366232787], {
             RGBColor[
             0.9936815870020732, 0.9888938784240099, 0.5536579217798141]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.0315874366232787], {
             RGBColor[
             0.7893125261109195, 0.835336211486015, 0.9796349541239562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.0315874366232787], {
             RGBColor[
             0.9456278325369345, 0.9589699070490746, 0.9769220763692325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.0315874366232787], {
             RGBColor[
             0.9936646257042686, 0.9916481741640916, 0.7546570777107737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.0315874366232787], {
             RGBColor[
             0.9933109093215855, 0.9881010363467089, 0.513311943816193]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.0315874366232787], {
             RGBColor[
             0.9379133479690065, 0.7915541443870948, 0.2689018262960763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.0315874366232787], {
             RGBColor[
             0.9606212925985209, 0.9701520050134682, 0.9515420594056421]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.0315874366232787], {
             RGBColor[
             0.9939253356538074, 0.9894152321433002, 0.580188458278768]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.0315874366232787], {
             RGBColor[
             0.994851114408306, 0.9913953792885825, 0.6809537624617367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.0315874366232787], {
             RGBColor[
             0.6049243439215446, 0.6901438597834719, 0.9620410067458405]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.0315874366232787], {
             RGBColor[
             0.4541462206382863, 0.5677353868250754, 0.950171200562518]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.0315874366232787], {
             RGBColor[
             0.943644924508238, 0.9574910574879867, 0.9802786224365736]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.0315874366232787], {
             RGBColor[
             0.9938942060571305, 0.9893486490836934, 0.5768001937900933]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.0315874366232787], {
             RGBColor[
             0.9855471576580349, 0.9882913925175607, 0.8891845305707625]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.0315874366232787], {
             RGBColor[
             0.9522898834429248, 0.963938453706655, 0.9656449619265476]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.0315874366232787], {
             RGBColor[
             0.9677915306644426, 0.9754995568228452, 0.9394047166576323]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.0315874366232787], {
             RGBColor[
             0.9678839473787003, 0.9033271546799081, 0.32973562948423335`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.0315874366232787], {
             RGBColor[
             0.963787220437266, 0.9725131488118731, 0.9461829693808712]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.0315874366232787], {
             RGBColor[
             0.41722699459647755`, 0.5358027851061444, 0.9478063130497105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.0315874366232787], {
             RGBColor[
             0.9895522426633538, 0.9899475980932498, 0.8228099072048861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.0315874366232787], {
             RGBColor[
             0.9936646257042686, 0.9916481741640916, 0.7546570777107737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.0315874366232787], {
             RGBColor[
             0.6607460158149041, 0.7348990765010991, 0.9668206458999975]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.0315874366232787], {
             RGBColor[
             0.9900572958286832, 0.9901564505563879, 0.8144398692196853]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.0315874366232787], {
             RGBColor[
             0.9864435759837261, 0.9886620845321342, 0.8743285590577978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.0315874366232787], {
             RGBColor[
             0.9934222051111036, 0.9883390867867577, 0.5254258036672474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.0315874366232787], {
             RGBColor[
             0.9463832908438712, 0.9595333266174385, 0.9756432825106715]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.0315874366232787], {
             RGBColor[
             0.9713314697886177, 0.9781396376255367, 0.933412523084394]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.0315874366232787], {
             RGBColor[
             0.8209029866322182, 0.8600297749953031, 0.98277965376537]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.0315874366232787], {
             RGBColor[
             0.9938826384747171, 0.9893239071945731, 0.5755411338312368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.0315874366232787], {
             RGBColor[
             0.751413785916484, 0.8057294276050283, 0.9758575618852382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.0315874366232787], {
             RGBColor[
             0.9920406158241435, 0.9909766043435096, 0.7815711242272926]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.0315874366232787], {
             RGBColor[
             0.9674942093458486, 0.9752778150702568, 0.9399080040961925]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.0315874366232787], {
             RGBColor[
             0.9890829783668335, 0.9897535452470964, 0.8305868310152998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.0315874366232787], {
             RGBColor[
             0.9081342712428495, 0.929585633513678, 0.9910998515638191]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.0315874366232787], {
             RGBColor[
             0.9872663566016568, 0.989002325462146, 0.8606929549307015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.0315874366232787], {
             RGBColor[
             0.9874526239609769, 0.9890793518020776, 0.8576060227422948]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.0315874366232787], {
             RGBColor[
             0.6910757253417514, 0.7585928760978021, 0.9698436278983834]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.0315874366232787], {
             RGBColor[
             0.8882905778403599, 0.9137628110372409, 0.9892071423724155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.0315874366232787], {
             RGBColor[
             0.870772317304098, 0.8997942256061402, 0.987536235043731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.0315874366232787], {
             RGBColor[
             0.9935622242383599, 0.9886385735418538, 0.5406660215712138]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.0315874366232787], {
             RGBColor[
             0.7899391119853906, 0.8358257051333807, 0.9796974063481455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.0315874366232787], {
             RGBColor[
             0.6571896194519592, 0.7321207926327531, 0.9664661775469527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.0315874366232787], {
             RGBColor[
             0.9689465461444343, 0.9763609654766587, 0.9374495767262896]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.0315874366232787], {
             RGBColor[
             0.8542202472702329, 0.8865960542551082, 0.9859574838276935]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.0315874366232787], {
             RGBColor[
             0.8939196906276755, 0.9182513127756502, 0.9897440521752379]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.0315874366232787], {
             RGBColor[
             0.5946890309950504, 0.6818343716541512, 0.9612352454190801]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.0315874366232787], {
             RGBColor[
             0.942737056387778, 0.9568139709302452, 0.9818154063545841]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.0315874366232787], {
             RGBColor[
             0.9280215542957396, 0.9454432131941348, 0.9929967183749909]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.0315874366232787], {
             RGBColor[
             0.8746543629682053, 0.902889663443377, 0.9879065080247166]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.0315874366232787], {
             RGBColor[
             0.24148141152160513`, 0.3711426526879731, 0.9370633811951966]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.0315874366232787], {
             RGBColor[
             0.4940072928296394, 0.6000964009508541, 0.95330921018134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.0315874366232787], {
             RGBColor[
             0.9892719361598389, 0.9898316841504978, 0.8274553113781075]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.0315874366232787], {
             RGBColor[
             0.6271896494347438, 0.7082198378396697, 0.9637938131563409]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.0315874366232787], {
             RGBColor[
             0.7590940204150871, 0.811729285167281, 0.9766230558841869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.0315874366232787], {
             RGBColor[
             0.9930755078788319, 0.9875975364633957, 0.48768994950177114`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.0315874366232787], {
             RGBColor[
             0.9618316087302564, 0.9710546568028057, 0.9494933098956173]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.0315874366232787], {
             RGBColor[
             0.9930300548765545, 0.9913857628191054, 0.7651735585426552]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.0315874366232787], {
             RGBColor[
             0.8879227184459646, 0.9134694899414273, 0.989172055614986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.0315874366232787], {
             RGBColor[
             0.9649894433749069, 0.9734097647103064, 0.9441479195374052]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.0315874366232787], {
             RGBColor[
             0.9402241781772785, 0.9549398704753151, 0.9860690537013571]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.0315874366232787], {
             RGBColor[
             0.9893576549183145, 0.9898671310599991, 0.8260347297171295]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.0315874366232787], {
             RGBColor[
             0.9817868489047369, 0.9502249060837454, 0.38374577657023273`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.0315874366232787], {
             RGBColor[
             0.8232515881633662, 0.8619024861051503, 0.9830036654760322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.0315874366232787], {
             RGBColor[
             0.8807985257577451, 0.9077888520728999, 0.9884925437565417]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.0315874366232787], {
             RGBColor[
             0.9924998031041922, 0.9911664900843846, 0.7739612026582968]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.0315874366232787], {
             RGBColor[
             0.9922115581868209, 0.9910472934034951, 0.7787381668930735]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.0315874366232787], {
             RGBColor[
             0.992567805904149, 0.9865116132760925, 0.4324297227309256]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.0315874366232787], {
             RGBColor[
             0.9936826307477605, 0.991655619712284, 0.7543586875445529]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.0315874366232787], {
             RGBColor[
             0.9939482532111503, 0.9917654614270817, 0.7499566359172843]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.0315874366232787], {
             RGBColor[
             0.8535981980829038, 0.4129848141111679, 0.19895900105568243`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.0315874366232787], {
             RGBColor[
             0.9919726785002643, 0.990948510514176, 0.7826970215001282]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.0315874366232787], {
             RGBColor[
             0.9506727505068838, 0.9627323986107678, 0.9683823461714459]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.0315874366232787], {
             RGBColor[
             0.9545364168831167, 0.9656139146679892, 0.9618421668020637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.0315874366232787], {
             RGBColor[
             0.9926384671321766, 0.9866627504978979, 0.4401207613311979]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.0315874366232787], {
             RGBColor[
             0.8888439270257047, 0.9142040366573713, 0.9892599213116943]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.0315874366232787], {
             RGBColor[
             0.9920372103777312, 0.9848017822314832, 0.4235664952744751]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.0315874366232787], {
             RGBColor[
             0.9669295514405968, 0.9001077530778621, 0.32602798148725104`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.0315874366232787], {
             RGBColor[
             0.9881120771986133, 0.9893520526630154, 0.8466771759843872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.0315874366232787], {
             RGBColor[
             0.2372288089839523, 0.3666728977903259, 0.9368212017718389]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.0315874366232787], {
             RGBColor[
             0.9919577553280057, 0.990942339398939, 0.782944337084385]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.0315874366232787], {
             RGBColor[
             0.907889855390706, 0.9293907429476702, 0.991076538961649]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.0315874366232787], {
             RGBColor[
             0.9942427991935902, 0.990094254554408, 0.6147424054262592]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.0315874366232787], {
             RGBColor[
             0.9332348462809481, 0.9496001507120989, 0.9934939668185008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.0315874366232787], {
             RGBColor[
             0.9456278325369345, 0.9589699070490746, 0.9769220763692325]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.0315874366232787], {
             RGBColor[
             0.9942773402608276, 0.9901681344045913, 0.6185019874322906]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.0315874366232787], {
             RGBColor[
             0.9378113462490048, 0.9531403843738583, 0.9901533487885713]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.0315874366232787], {
             RGBColor[
             0.9562839147324712, 0.9669171957027727, 0.9588841087635405]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.0315874366232787], {
             RGBColor[
             0.9127871467304569, 0.9332957101285555, 0.9915436469814981]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.0315874366232787], {
             RGBColor[
             0.9886168168947244, 0.9895607754985759, 0.838312332995365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.0315874366232787], {
             RGBColor[
             0.992506114173784, 0.9863796609028326, 0.42571495859792585`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.0315874366232787], {
             RGBColor[
             0.859254183043861, 0.8906099779984528, 0.9864376251156297]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.0315874366232787], {
             RGBColor[
             0.9946558030455566, 0.9909776280326694, 0.6596953259484791]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.0315874366232787], {
             RGBColor[
             0.9939300861309733, 0.9894253929336111, 0.5807055184017289]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.0315874366232787], {
             RGBColor[
             0.9545364168831167, 0.9656139146679892, 0.9618421668020637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.0315874366232787], {
             RGBColor[
             0.9906140542969182, 0.9903866844910431, 0.8052129405563028]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.0315874366232787], {
             RGBColor[
             0.9931249976822633, 0.9877033901487487, 0.4930766091896134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.0315874366232787], {
             RGBColor[
             0.8501068125121857, 0.8833161130352534, 0.9855651407483644]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.0315874366232787], {
             RGBColor[
             0.9915252782451579, 0.9907634990110274, 0.7901116015619869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.0315874366232787], {
             RGBColor[
             0.8562583984378525, 0.8882212206720284, 0.9861518845055401]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.0315874366232787], {
             RGBColor[
             0.9900252200540854, 0.9901431863992819, 0.8149714478142146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.0315874366232787], {
             RGBColor[
             0.9911544721626188, 0.9906101611666158, 0.7962568179650393]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.0315874366232787], {
             RGBColor[
             0.9881873591473117, 0.98938318368346, 0.8454295592710166]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.0315874366232787], {
             RGBColor[
             0.2777591011371284, 0.40927280461225934`, 0.9391293419507684]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.0315874366232787], {
             RGBColor[
             0.6468183271371717, 0.7240186602517001, 0.9654324640542519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.0315874366232787], {
             RGBColor[
             0.9886805558193184, 0.9895871331819112, 0.837256014063794]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.0315874366232787], {
             RGBColor[
             0.9945689632734257, 0.9907918865409293, 0.6502433526649855]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.0315874366232787], {
             RGBColor[
             0.9872663566016568, 0.989002325462146, 0.8606929549307015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.0315874366232787], {
             RGBColor[
             0.9939379694904599, 0.9894422546424231, 0.5815635734313909]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.0315874366232787], {
             RGBColor[
             0.49517449064791735`, 0.6010439847213946, 0.9534010962691813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.0315874366232787], {
             RGBColor[
             0.9913623929702289, 0.9906961417638837, 0.7928110321011386]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.0315874366232787], {
             RGBColor[
             0.7539073345293585, 0.8076774067330772, 0.9761060955074329]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.0315874366232787], {
             RGBColor[
             0.797320960956232, 0.8415924616535322, 0.9804331600662582]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.0315874366232787], {
             RGBColor[
             0.9940913525297521, 0.9897703254540651, 0.5982583706879601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.0315874366232787], {
             RGBColor[
             0.9688036072095633, 0.9762543618530729, 0.9376915350585814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.0315874366232787], {
             RGBColor[
             0.9952158667346623, 0.9921755476325415, 0.7206548021951973]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.0315874366232787], {
             RGBColor[
             0.9378968502022964, 0.7914887362396443, 0.268888551805729]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.0315874366232787], {
             RGBColor[
             0.6133257245690064, 0.6969644790709664, 0.9627023942056799]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.0315874366232787], {
             RGBColor[
             0.9466264691127686, 0.8260987662466103, 0.2759126080915867]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.0315874366232787], {
             RGBColor[
             0.9602291145517226, 0.9698595192682985, 0.9522059145424555]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.0315874366232787], {
             RGBColor[
             0.9338040331693572, 0.9500540048867498, 0.9935482563720364]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.0315874366232787], {
             RGBColor[
             0.9779769973842805, 0.9373733823095687, 0.3689452228433496]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.0315874366232787], {
             RGBColor[
             0.8368850853389176, 0.8727734666815127, 0.984304040607403]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.0315874366232787], {
             RGBColor[
             0.866162829176085, 0.8961187448940847, 0.9870965779511425]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.0315874366232787], {
             RGBColor[
             0.709289121751741, 0.7728213198002256, 0.9716589690386647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.0315874366232787], {
             RGBColor[
             0.9900378250817309, 0.9901483989021477, 0.8147625498853639]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.0315874366232787], {
             RGBColor[
             0.7464147522017225, 0.8018241444729931, 0.9753593049231769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.0315874366232787], {
             RGBColor[
             0.9770649108580635, 0.9824156285874812, 0.9237073028747447]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.0315874366232787], {
             RGBColor[
             0.9886410501720249, 0.9895707965815064, 0.8379107248767853]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.0315874366232787], {
             RGBColor[
             0.8421598933689439, 0.8769794554238061, 0.9848071565061836]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.0315874366232787], {
             RGBColor[
             0.9436616966478468, 0.9575035661222451, 0.9802502315790906]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.0315874366232787], {
             RGBColor[
             0.908400377023576, 0.9297978190399803, 0.9911252329707403]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.0315874366232787], {
             RGBColor[
             0.9785610662277989, 0.9835314588125004, 0.921174702093599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.0315874366232787], {
             RGBColor[
             0.9775808035995859, 0.9360369276430692, 0.36740608480472925`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.0315874366232787], {
             RGBColor[
             0.9927145952562305, 0.9868255808575149, 0.44840683782613266`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.0315874366232787], {
             RGBColor[
             0.6525317277018968, 0.7284820121963159, 0.9660019224277797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.0315874366232787], {
             RGBColor[
             0.9913149785018636, 0.9906765346627183, 0.793596812546663]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.0315874366232787], {
             RGBColor[
             0.5066339530566218, 0.6103472925476794, 0.9543032271273885]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.0315874366232787], {
             RGBColor[
             0.945176638309412, 0.9586334071329511, 0.9776858305061266]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.0315874366232787], {
             RGBColor[
             0.9553756866732158, 0.966239840703267, 0.9604215019640444]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.0315874366232787], {
             RGBColor[
             0.9669943160512524, 0.9749049954696472, 0.9407541930508916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.0315874366232787], {
             RGBColor[
             0.9949866750642881, 0.9921948755495785, 0.7327472984611801]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.0315874366232787], {
             RGBColor[
             0.6317772179683236, 0.7119442326428371, 0.9641549633561216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.0315874366232787], {
             RGBColor[
             0.9793803232720479, 0.9421071300455963, 0.37439687892146906`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.0315874366232787], {
             RGBColor[
             0.9928791255314863, 0.9871774944797244, 0.46631494292456016`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[401, 0.0315874366232787], {
             RGBColor[
             0.9923206082038829, 0.9910923883880078, 0.7769309258979589]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[402, 0.0315874366232787], {
             RGBColor[
             0.9437238570612777, 0.9575499252568035, 0.9801450102131846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[403, 0.0315874366232787], {
             RGBColor[
             0.9946866659904383, 0.9910436407510489, 0.6630545670348296]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[404, 0.0315874366232787], {
             RGBColor[
             0.8377972602547259, 0.2915318819486864, 0.1838280051468125]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[405, 0.0315874366232787], {
             RGBColor[
             0.9821287880356444, 0.9861922598951831, 0.9151354796837913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[406, 0.0315874366232787], {
             RGBColor[
             0.9437238570612777, 0.9575499252568035, 0.9801450102131846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[407, 0.0315874366232787], {
             RGBColor[
             0.7526865493971486, 0.8067237201094842, 0.9759844190543399]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[408, 0.0315874366232787], {
             RGBColor[
             0.5505634611375302, 0.6460112462095473, 0.9577615189226079]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[409, 0.0315874366232787], {
             RGBColor[
             0.7509227865003558, 0.8053458551294153, 0.975808623652089]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[410, 0.0315874366232787], {
             RGBColor[
             0.9604917324217577, 0.9700553792457735, 0.9517613709901963]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[411, 0.0315874366232787], {
             RGBColor[
             0.9944754017021891, 0.9919834508752244, 0.7412204212042086]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[412, 0.0315874366232787], {
             RGBColor[
             0.9330112191112232, 0.7721188370035883, 0.26495745834935047`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[413, 0.0315874366232787], {
             RGBColor[
             0.891650335296971, 0.9164417904349559, 0.9895275990379179]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[414, 0.0315874366232787], {
             RGBColor[
             0.9925524587883872, 0.9864787873473095, 0.4307592838916761]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[415, 0.0315874366232787], {
             RGBColor[
             0.7610053960729755, 0.8132224663582166, 0.9768135639469442]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[416, 0.0315874366232787], {
             RGBColor[
             0.40443808765213085`, 0.5247256767001043, 0.9469914152080031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[417, 0.0315874366232787], {
             RGBColor[
             0.8805704112844738, 0.9076069597839158, 0.9884707859944409]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[418, 0.0315874366232787], {
             RGBColor[
             0.9935901249408909, 0.9886982503233738, 0.5437028408585354]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[419, 0.0315874366232787], {
             RGBColor[
             0.6571647622353577, 0.7321013739862221, 0.9664637000119057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[420, 0.0315874366232787], {
             RGBColor[
             0.991750525969403, 0.9908566447336052, 0.7863786638488193]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[421, 0.0315874366232787], {
             RGBColor[
             0.7890218840957037, 0.8351091597347673, 0.9796059856440835]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[422, 0.0315874366232787], {
             RGBColor[
             0.9927374125528239, 0.9912647476976781, 0.7700233991809281]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[423, 0.0315874366232787], {
             RGBColor[
             0.9936398787789769, 0.9888046687521548, 0.5491182390890846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[424, 0.0315874366232787], {
             RGBColor[
             0.6973434138877295, 0.7634892420261175, 0.970468332517767]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[425, 0.0315874366232787], {
             RGBColor[
             0.8710934909312559, 0.9000503207384101, 0.9875668688710044]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[426, 0.0315874366232787], {
             RGBColor[
             0.9841907417577515, 0.9877300616049912, 0.9116451298759246]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[427, 0.0315874366232787], {
             RGBColor[
             0.9847434556888071, 0.9601982350106999, 0.39523163561800334`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[428, 0.0315874366232787], {
             RGBColor[
             0.7993034860859929, 0.8431412253526505, 0.9806307596434422]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[429, 0.0315874366232787], {
             RGBColor[
             0.9872663566016568, 0.989002325462146, 0.8606929549307015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[430, 0.0315874366232787], {
             RGBColor[
             0.9942757740792346, 0.9901647845005292, 0.6183315182312558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[431, 0.0315874366232787], {
             RGBColor[
             0.9925320919058048, 0.9864352246448738, 0.42854247441242493`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[432, 0.0315874366232787], {
             RGBColor[
             0.9948105827482334, 0.9921220568515238, 0.7356656038505125]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[433, 0.0315874366232787], {
             RGBColor[
             0.968405964571314, 0.9050880412460598, 0.3317635677028626]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[434, 0.0315874366232787], {
             RGBColor[
             0.9777148091835204, 0.936488959943688, 0.367926671193484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[435, 0.0315874366232787], {
             RGBColor[
             0.7899391119853906, 0.8358257051333807, 0.9796974063481455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[436, 0.0315874366232787], {
             RGBColor[
             0.8368850853389176, 0.8727734666815127, 0.984304040607403]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[437, 0.0315874366232787], {
             RGBColor[
             0.9233670718096835, 0.9417318552023151, 0.9925527696803653]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[438, 0.0315874366232787], {
             RGBColor[
             0.9792256916297781, 0.9415855212069837, 0.3737961641909859]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[439, 0.0315874366232787], {
             RGBColor[
             0.9934587493482713, 0.9884172512148703, 0.529403418358061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[440, 0.0315874366232787], {
             RGBColor[
             0.8409756841659908, 0.8760351991498737, 0.9846942055752499]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[441, 0.0315874366232787], {
             RGBColor[
             0.866163262477715, 0.48516045792306606`, 0.21003568438382075`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[442, 0.0315874366232787], {
             RGBColor[
             0.9942496759509837, 0.9901089632431259, 0.6154908980301118]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[443, 0.0315874366232787], {
             RGBColor[
             0.9829176889926815, 0.9540394952342622, 0.38813887677066594`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[444, 0.0315874366232787], {
             RGBColor[
             0.9458333735252019, 0.959123199181582, 0.9765741490897711]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[445, 0.0315874366232787], {
             RGBColor[
             0.9631050646924458, 0.9720043981743138, 0.947337681122139]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[446, 0.0315874366232787], {
             RGBColor[
             0.9946683196685598, 0.9910043998236486, 0.6610576831187343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[447, 0.0315874366232787], {
             RGBColor[
             0.9096632488687217, 0.6795519152419345, 0.2461711334449348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[448, 0.0315874366232787], {
             RGBColor[
             0.9931249976822633, 0.9877033901487487, 0.4930766091896134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[449, 0.0315874366232787], {
             RGBColor[
             0.9297736146473136, 0.7592828141719185, 0.2623524058013447]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[450, 0.0315874366232787], {
             RGBColor[
             0.9930508161919586, 0.9875447234418863, 0.48500241176504155`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[451, 0.0315874366232787], {
             RGBColor[
             0.9920444458393581, 0.9909781881532278, 0.781507650963424]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[452, 0.0315874366232787], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[453, 0.0315874366232787], {
             RGBColor[
             0.9933724879512359, 0.9882327468089768, 0.5200143976343962]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[454, 0.0315874366232787], {
             RGBColor[
             0.9489852999786376, 0.9614739007697484, 0.9712387597581826]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[455, 0.0315874366232787], {
             RGBColor[
             0.9631050646924458, 0.9720043981743138, 0.947337681122139]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[456, 0.0315874366232787], {
             RGBColor[
             0.8197470811589967, 0.8591119172007583, 0.9826683861440613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[457, 0.0315874366232787], {
             RGBColor[
             0.9936853008897475, 0.9916567238846151, 0.7543144363817231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[458, 0.0315874366232787], {
             RGBColor[
             0.9575982218073806, 0.9678974037672599, 0.9566593297119037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[459, 0.0315874366232787], {
             RGBColor[
             0.8364592683427778, 0.8724339317672853, 0.9842634258021798]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[460, 0.0315874366232787], {
             RGBColor[
             0.6049243439215446, 0.6901438597834719, 0.9620410067458405]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[461, 0.0315874366232787], {
             RGBColor[
             0.9138753133526578, 0.9341633846556024, 0.9916474372853414]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[462, 0.0315874366232787], {
             RGBColor[
             0.9939460934061856, 0.9917645682922243, 0.7499924294749454]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[463, 0.0315874366232787], {
             RGBColor[
             0.8398174719718398, 0.30706011446884196`, 0.1857625621686234]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[464, 0.0315874366232787], {
             RGBColor[
             0.9072529211412013, 0.6699957689964171, 0.24423172717770847`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[465, 0.0315874366232787], {
             RGBColor[
             0.9867718661313074, 0.988797840944831, 0.8688879417247074]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[466, 0.0315874366232787], {
             RGBColor[
             0.982350578227148, 0.9521264974581776, 0.38593575853645007`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[467, 0.0315874366232787], {
             RGBColor[
             0.9480658066721221, 0.9607881441672812, 0.9727952220838508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[468, 0.0315874366232787], {
             RGBColor[
             0.855592668525406, 0.8876903857106008, 0.9860883865921869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[469, 0.0315874366232787], {
             RGBColor[
             0.9947192565649711, 0.991113348694562, 0.6666018499470134]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[470, 0.0315874366232787], {
             RGBColor[
             0.9272687230231438, 0.7493517535877369, 0.26033691120317437`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[471, 0.0315874366232787], {
             RGBColor[
             0.9823909263315381, 0.9863877622070487, 0.9146917479254605]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[472, 0.0315874366232787], {
             RGBColor[
             0.807695902153758, 0.849697444569513, 0.9814672372454898]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[473, 0.0315874366232787], {
             RGBColor[
             0.9846495350374952, 0.9879202024961184, 0.9040604603659835]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[474, 0.0315874366232787], {
             RGBColor[
             0.49517449064791735`, 0.6010439847213946, 0.9534010962691813]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[475, 0.0315874366232787], {
             RGBColor[
             0.9943920101237455, 0.9919489663144722, 0.7426024354695057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[476, 0.0315874366232787], {
             RGBColor[
             0.9156337612939072, 0.9355655233121568, 0.9918151596197627]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[477, 0.0315874366232787], {
             RGBColor[
             0.9665470735432166, 0.9745714427394464, 0.9415112579574685]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[478, 0.0315874366232787], {
             RGBColor[
             0.9827046816404774, 0.9866217604027284, 0.9141606420279168]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[479, 0.0315874366232787], {
             RGBColor[
             0.9892799716147425, 0.9898350070176023, 0.8273221430952633]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[480, 0.0315874366232787], {
             RGBColor[
             0.49840860677016185`, 0.6036695858847038, 0.9536556977372821]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[481, 0.0315874366232787], {
             RGBColor[
             0.9901254984830484, 0.9783531291194192, 0.4161398555601312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[482, 0.0315874366232787], {
             RGBColor[
             0.8031103919798226, 0.8461152091704666, 0.9810101964453809]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[483, 0.0315874366232787], {
             RGBColor[
             0.986070632802648, 0.9885078629425558, 0.8805091927142772]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[484, 0.0315874366232787], {
             RGBColor[
             0.9754219030610333, 0.9811902760626344, 0.9264884865100534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[485, 0.0315874366232787], {
             RGBColor[
             0.6757529200043868, 0.7466225841106191, 0.9683163938621121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[486, 0.0315874366232787], {
             RGBColor[
             0.9902477509778848, 0.9902352086550568, 0.8112835345152896]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[487, 0.0315874366232787], {
             RGBColor[
             0.9870563486423428, 0.9889154817740112, 0.8641733302997117]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[488, 0.0315874366232787], {
             RGBColor[
             0.9926373767765941, 0.991223380333405, 0.7716812508773457]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[489, 0.0315874366232787], {
             RGBColor[
             0.6242602387616486, 0.7058416102868041, 0.96356319921737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[490, 0.0315874366232787], {
             RGBColor[
             0.9632043768696127, 0.9720784650334361, 0.9471695715109596]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[491, 0.0315874366232787], {
             RGBColor[
             0.993300240981022, 0.9914974917167688, 0.7606958755724054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[492, 0.0315874366232787], {
             RGBColor[
             0.943644924508238, 0.9574910574879867, 0.9802786224365736]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[493, 0.0315874366232787], {
             RGBColor[
             0.9859570950020115, 0.9642921253902004, 0.39994639517324904`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[494, 0.0315874366232787], {
             RGBColor[
             0.788881449243922, 0.834999450961211, 0.9795919884104962]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[495, 0.0315874366232787], {
             RGBColor[
             0.4717197265342954, 0.5820023505888743, 0.9515546513205251]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[496, 0.0315874366232787], {
             RGBColor[
             0.711956050776978, 0.7749047450241521, 0.9719247836000316]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[497, 0.0315874366232787], {
             RGBColor[
             0.3688613674925014, 0.4939109098357809, 0.94472449805869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[498, 0.0315874366232787], {
             RGBColor[
             0.9081342712428495, 0.929585633513678, 0.9910998515638191]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[499, 0.0315874366232787], {
             RGBColor[
             0.9917549610033508, 0.9908584787341178, 0.7863051638588054]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[500, 0.0315874366232787], {
             RGBColor[
             0.9509755078711634, 0.9629581945573278, 0.9678698569254878]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1dOWGAgQBNBMbNu2bds2J+bEtm3btm3btu01sjdnH271F1R1ssCg6p0C
ggUL9l38vMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEIS
kZgkJCUZyUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpR
mCIUpRjFKUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGY
JjSlGYE0pwUtaUVr2tCWdrSnAx3pRBCd6UJXutGdHvSkF73pQ1/60Z8BDGQQ
gxnCUIYxnBGMZBSjGcNYxjGeCUxkEpOZwlSmMZ0ZzGQWs5nDXOYxnwUsZBGL
WcJSlrGcFaxkFatZw1rWsZ4NbGQTm9nCVraxnR3sZBe72cNe9rGfAxzkEIc5
wlGOcZwTnOQUpznDWc5xngtc5BKXucJVrnGdG9zkFre5w13ucZ8HPOQRj3nC
U57xnBe85BWvecNb3vGeD3zkE5/5wle+8Z1f+JXf+J0/+JO/+Jt/+Jcf/Cx/
AMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEISkZgkJCUZ
yUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpRmCIUpRjF
KUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGYJjSlGYE0
pwUtaUVr2tCWdrSnAx35Od5BdKYLXelGd3rQk170pg996Ud/BjCQQQxmCEMZ
xnBGMJJRjGYMYxnHeCYwkUlMZgpTmcZ0ZjCTWcxmDnOZx3wWsJBFLGYJS1nG
clawklWsZg1rWcd6NrCRTWxmC1vZxnZ2sJNd7GYPe9nHfg5wkEMc5ghHOcZx
TnCSU5zmDGc5x3kucJFLXOYKV7nGdW5wk1vc5g53ucd9HvCQRzzmCU95xnNe
8JJXvOYNb3nHez7wkU985gtf+Rbw/z//Dz189+A=
          "], {Null, CompressedData["
1:eJw13A2c1mO6wPH7tsdpl2O9LLLYQ3Ioas/uCqvVrqQihdKSUmmVzEwspdpK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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[196, 330] -> 
             RGBColor[
              0.3010744440099954, 0.433778708249762, 0.9404571162354194], 
             UndirectedEdge[136, 319] -> 
             RGBColor[
              0.8419251732908781, 0.8767840075536342, 0.9548214315268342], 
             UndirectedEdge[60, 188] -> 
             RGBColor[
              0.31499337168742486`, 0.44577048443841216`, 0.9413463649912971],
              UndirectedEdge[145, 408] -> 
             RGBColor[
              0.2215813501340996, 0.35022642643293833`, 0.9359301021386808], 
             UndirectedEdge[398, 460] -> 
             RGBColor[
              0.2547486544855675, 0.3850873662348864, 0.9378189310548671], 
             UndirectedEdge[413, 476] -> 
             RGBColor[
              0.9111642263834832, 0.6485722673362936, 0.273464018883213], 
             UndirectedEdge[244, 274] -> 
             RGBColor[
              0.40258764491589, 0.5228672426461249, 0.9469441500000384], 
             UndirectedEdge[198, 223] -> 
             RGBColor[
              0.335871613441881, 0.4628528461466326, 0.9427133713948876], 
             UndirectedEdge[36, 310] -> 
             RGBColor[
              0.2755731801551128, 0.4069752630647657, 0.9390048569846228], 
             UndirectedEdge[252, 432] -> 
             RGBColor[
              0.8172102397534445, 0.8577657390481622, 0.982246863062763], 
             UndirectedEdge[469, 475] -> 
             RGBColor[
              0.8497170345102683, 0.3799664311487149, 0.19511763635494941`], 
             UndirectedEdge[113, 347] -> 
             RGBColor[
              0.17905963034776856`, 0.3055334029047545, 0.9335085531020964], 
             UndirectedEdge[35, 131] -> 
             RGBColor[
              0.2509907389862678, 0.38113755877951816`, 0.9376049233265198], 
             UndirectedEdge[156, 479] -> 
             RGBColor[
              0.4393999195807523, 0.5546279653397757, 0.9493241177753168], 
             UndirectedEdge[318, 354] -> 
             RGBColor[
              0.35185308329442466`, 0.47917918892462685`, 0.9436407452294238],
              UndirectedEdge[6, 77] -> 
             RGBColor[
              0.7172538475630181, 0.7785612627115652, 0.9728085302210365], 
             UndirectedEdge[23, 202] -> 
             RGBColor[
              0.23077928410080303`, 0.35989403821464017`, 0.9364539108709606],
              UndirectedEdge[342, 395] -> 
             RGBColor[
              0.2624873580585535, 0.3932212343522405, 0.9382596387749628], 
             UndirectedEdge[53, 418] -> 
             RGBColor[
              0.9774928986004763, 0.9579493905915291, 0.642289060004833], 
             UndirectedEdge[75, 149] -> 
             RGBColor[
              0.3494116417234011, 0.4770645349462275, 0.9434851787314], 
             UndirectedEdge[293, 418] -> 
             RGBColor[
              0.9663729017016692, 0.9744415456652006, 0.9418060854539165], 
             UndirectedEdge[282, 432] -> 
             RGBColor[
              0.7531414292760994, 0.8071831282683875, 0.9762245194841053], 
             UndirectedEdge[466, 468] -> 
             RGBColor[
              0.49094259840512156`, 0.5976083439541202, 0.9530679462098963], 
             UndirectedEdge[105, 190] -> 
             RGBColor[
              0.24700744449895456`, 0.37695086371789455`, 0.9373780805982235],
              UndirectedEdge[64, 473] -> 
             RGBColor[
              0.3073328542986736, 0.43868458843205593`, 0.9408747474285853], 
             UndirectedEdge[214, 273] -> 
             RGBColor[
              0.24667426527178135`, 0.3766006712253524, 0.9373591065341305], 
             UndirectedEdge[30, 64] -> 
             RGBColor[
              0.27788283656739987`, 0.4094028583947541, 0.9391363885004721], 
             UndirectedEdge[296, 395] -> 
             RGBColor[
              0.289203696626415, 0.4208696734674796, 0.9397969170059906], 
             UndirectedEdge[114, 203] -> 
             RGBColor[
              0.5176225598035007, 0.6192683385358883, 0.9551682905030956], 
             UndirectedEdge[81, 237] -> 
             RGBColor[
              0.8648552697662895, 0.8950761325134684, 0.9869718617673642], 
             UndirectedEdge[382, 427] -> 
             RGBColor[
              0.2808624118228371, 0.41253458090420103`, 0.9393060709033827], 
             UndirectedEdge[39, 450] -> 
             RGBColor[
              0.7206850354992045, 0.4212381693670362, 0.5640535204963621], 
             UndirectedEdge[50, 57] -> 
             RGBColor[
              0.5210905073010532, 0.6217476292469348, 0.9555341779806428], 
             UndirectedEdge[74, 153] -> 
             RGBColor[
              0.2633334885240648, 0.39411057111926295`, 0.9383078246532357], 
             UndirectedEdge[239, 332] -> 
             RGBColor[
              0.37656128496655794`, 0.5005801913427036, 0.9452151299913671], 
             UndirectedEdge[14, 72] -> 
             RGBColor[
              0.2803635687690008, 0.4120102652261427, 0.9392776625294388], 
             UndirectedEdge[331, 403] -> 
             RGBColor[
              0.8828018353475209, 0.9093862367613971, 0.9886836212135901], 
             UndirectedEdge[214, 302] -> 
             RGBColor[
              0.19497823659732902`, 0.32226486737097304`, 0.9344150941785414],
              UndirectedEdge[128, 197] -> 
             RGBColor[
              0.5961844176461558, 0.6822017797294064, 0.9619318024689351], 
             UndirectedEdge[191, 212] -> 
             RGBColor[
              0.21845881642544385`, 0.3469444455250692, 0.9357522784633475], 
             UndirectedEdge[404, 407] -> 
             RGBColor[
              0.2139033248740353, 0.3421563350696921, 0.9354928499587406], 
             UndirectedEdge[60, 116] -> 
             RGBColor[
              0.27071777339856856`, 0.4018719227130688, 0.9387283487527682], 
             UndirectedEdge[272, 357] -> 
             RGBColor[
              0.8638626077841431, 0.41438606964025426`, 0.20574312527482636`],
              UndirectedEdge[228, 490] -> 
             RGBColor[
              0.9918174311383581, 0.9889858002878001, 0.6472681311594083], 
             UndirectedEdge[111, 415] -> 
             RGBColor[
              0.2800519643946353, 0.41168274927182613`, 0.9392599171212961], 
             UndirectedEdge[227, 428] -> 
             RGBColor[
              0.8379823315719487, 0.29295442119162834`, 0.18400522964919308`],
              UndirectedEdge[367, 499] -> 
             RGBColor[
              0.24528184927831587`, 0.3751371537319471, 0.9372798105031974], 
             UndirectedEdge[434, 495] -> 
             RGBColor[
              0.9167025248852594, 0.6580111596730529, 0.4917530067660364], 
             UndirectedEdge[226, 283] -> 
             RGBColor[
              0.18031957576389654`, 0.30685768542225833`, 0.9335803051296228],
              UndirectedEdge[9, 34] -> 
             RGBColor[
              0.559448373541096, 0.6532244183595045, 0.9584609717735231], 
             UndirectedEdge[127, 386] -> 
             RGBColor[
              0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993],
              UndirectedEdge[326, 469] -> 
             RGBColor[
              0.8678030946468546, 0.4926065528105953, 0.21140400054171546`], 
             UndirectedEdge[192, 483] -> 
             RGBColor[
              0.275631905541692, 0.4070369871694651, 0.9390082013085121], 
             UndirectedEdge[16, 39] -> 
             RGBColor[
              0.5137718344766236, 0.6147998451486828, 0.9552360290912556], 
             UndirectedEdge[209, 421] -> 
             RGBColor[
              0.37249008899703795`, 0.4820057501195733, 0.9462395519949527], 
             UndirectedEdge[293, 317] -> 
             RGBColor[
              0.9188363181868828, 0.7644234365766909, 0.5933539685152149], 
             UndirectedEdge[3, 381] -> 
             RGBColor[
              0.5154854178683257, 0.6175333104357662, 0.9550000468613498], 
             UndirectedEdge[211, 497] -> 
             RGBColor[
              0.23351702426712523`, 0.36277157671219695`, 0.936609821123309], 
             UndirectedEdge[196, 479] -> 
             RGBColor[
              0.35359500425427093`, 0.4794816999667437, 0.9437959057364866], 
             UndirectedEdge[221, 439] -> 
             RGBColor[
              0.6987612824501502, 0.7633077628527738, 0.9716294265306357], 
             UndirectedEdge[379, 390] -> 
             RGBColor[
              0.30502633329137085`, 0.4378812473959014, 0.9406840432278518], 
             UndirectedEdge[119, 320] -> 
             RGBColor[
              0.9896249360090673, 0.9899776586598361, 0.8216051903420669], 
             UndirectedEdge[179, 401] -> 
             RGBColor[
              0.47619075737058414`, 0.5641711945885997, 0.9557776422261561], 
             UndirectedEdge[59, 342] -> 
             RGBColor[
              0.25108912406320616`, 0.3812409677333546, 0.9376105262111039], 
             UndirectedEdge[86, 98] -> 
             RGBColor[
              0.9552139147274563, 0.8468459050338089, 0.4866646892725739], 
             UndirectedEdge[328, 431] -> 
             RGBColor[
              0.4169264678183623, 0.535542483915856, 0.9477871637491544], 
             UndirectedEdge[270, 375] -> 
             RGBColor[
              0.9741122632489756, 0.9792447932430604, 0.8853225104060825], 
             UndirectedEdge[39, 45] -> 
             RGBColor[
              0.45322202962692537`, 0.5599541419213354, 0.9514657433370749], 
             UndirectedEdge[59, 463] -> 
             RGBColor[
              0.2546442329532448, 0.38497761258370766`, 0.9378129844030793], 
             UndirectedEdge[2, 55] -> 
             RGBColor[
              0.21196267506411343`, 0.3401165890751596, 0.9353823328229998], 
             UndirectedEdge[193, 496] -> 
             RGBColor[
              0.28235063055336573`, 0.41409879314850406`, 0.939390822758464], 
             UndirectedEdge[201, 246] -> 
             RGBColor[
              0.2993400916080083, 0.43195579391098005`, 0.9403583474318706], 
             UndirectedEdge[69, 487] -> 
             RGBColor[
              0.7444469428218465, 0.8000461273805028, 0.9756303235156909], 
             UndirectedEdge[15, 408] -> 
             RGBColor[
              0.22837166352845595`, 0.3573634763411423, 0.9363168004411209], 
             UndirectedEdge[118, 310] -> 
             RGBColor[
              0.3109325878407584, 0.44262745407148385`, 0.9410739135361832], 
             UndirectedEdge[289, 297] -> 
             RGBColor[
              0.47936763079523015`, 0.5878325714725148, 0.9522613561781106], 
             UndirectedEdge[397, 419] -> 
             RGBColor[
              0.43561929438142943`, 0.5501211672171827, 0.9494236831393772], 
             UndirectedEdge[13, 380] -> 
             RGBColor[
              0.28473366122711574`, 0.4166035094794867, 0.939526532829956], 
             UndirectedEdge[155, 262] -> 
             RGBColor[
              0.520987467347936, 0.6220001220678183, 0.9554331883510561], 
             UndirectedEdge[182, 324] -> 
             RGBColor[
              0.37413205522389265`, 0.49847611463624397`, 0.9450603416202481],
              UndirectedEdge[177, 245] -> 
             RGBColor[
              0.21512971428686242`, 0.34344534810015337`, 0.9355626910215206],
              UndirectedEdge[113, 325] -> 
             RGBColor[
              0.1791045905323438, 0.30558065890938335`, 0.9335111135180953], 
             UndirectedEdge[94, 368] -> 
             RGBColor[
              0.6817603644893816, 0.7470855364406719, 0.9537864521193352], 
             UndirectedEdge[50, 140] -> 
             RGBColor[
              0.47028604559026116`, 0.5805022785151959, 0.9515346646518938], 
             UndirectedEdge[389, 458] -> 
             RGBColor[
              0.2244995192065336, 0.35329360715067204`, 0.9360962875503116], 
             UndirectedEdge[429, 499] -> 
             RGBColor[
              0.2771583025105514, 0.4086413271628938, 0.9390951273577867], 
             UndirectedEdge[97, 358] -> 
             RGBColor[
              0.2286803601297014, 0.35768793604154625`, 0.9363343802558861], 
             UndirectedEdge[274, 363] -> 
             RGBColor[
              0.4337728092244554, 0.5498782645582716, 0.9489312410938221], 
             UndirectedEdge[255, 274] -> 
             RGBColor[
              0.43015989340709154`, 0.5467489384677, 0.9487010292927157], 
             UndirectedEdge[289, 381] -> 
             RGBColor[
              0.5043379271734174, 0.6081045829713598, 0.9542271093782111], 
             UndirectedEdge[55, 230] -> 
             RGBColor[
              0.21767784356668446`, 0.34612359353397393`, 0.935707803214387], 
             UndirectedEdge[289, 349] -> 
             RGBColor[
              0.42648626116779464`, 0.5438226964259498, 0.9483963053279869], 
             UndirectedEdge[29, 318] -> 
             RGBColor[
              0.37578131668551923`, 0.4999046220200136, 0.9451654311021982], 
             UndirectedEdge[69, 402] -> 
             RGBColor[
              0.7308868707375382, 0.7890374499881754, 0.9745628249690335], 
             UndirectedEdge[6, 413] -> 
             RGBColor[
              0.9007629224656561, 0.8944231613369187, 0.6681426582115271], 
             UndirectedEdge[29, 482] -> 
             RGBColor[
              0.38405087443932273`, 0.5070672973063002, 0.9456923600097877], 
             UndirectedEdge[212, 456] -> 
             RGBColor[
              0.22108739015867407`, 0.34970724317989477`, 0.9359019718488286],
              UndirectedEdge[354, 482] -> 
             RGBColor[
              0.3601226410482282, 0.48634186421091347`, 0.9441676741370133], 
             UndirectedEdge[106, 247] -> 
             RGBColor[
              0.5064333598698463, 0.6101844419620349, 0.9542874356969284], 
             UndirectedEdge[305, 382] -> 
             RGBColor[
              0.2666682843502908, 0.39761565297089385`, 0.938497736342151], 
             UndirectedEdge[279, 285] -> 
             RGBColor[
              0.2964892825686648, 0.42843496613236076`, 0.9402152006381983], 
             UndirectedEdge[27, 319] -> 
             RGBColor[
              0.6135043005796454, 0.695998377538924, 0.9634761021745089], 
             UndirectedEdge[118, 483] -> 
             RGBColor[
              0.31087863822406303`, 0.44257074960373377`, 0.9410708411853237],
              UndirectedEdge[342, 447] -> 
             RGBColor[
              0.2532435452217043, 0.38350540096912705`, 0.9377332173088998], 
             UndirectedEdge[207, 458] -> 
             RGBColor[
              0.22378112515977486`, 0.35253852945871533`, 0.9360553760721175],
              UndirectedEdge[462, 487] -> 
             RGBColor[
              0.5216548713893666, 0.6225419507348611, 0.9554857288419789], 
             UndirectedEdge[64, 384] -> 
             RGBColor[
              0.28582762436265047`, 0.41775333409620263`, 0.9395888324121513],
              UndirectedEdge[203, 221] -> 
             RGBColor[
              0.5355883582024223, 0.6338537830261275, 0.9565826239639467], 
             UndirectedEdge[139, 370] -> 
             RGBColor[
              0.5777392587332322, 0.6680737829534684, 0.9599008972575682], 
             UndirectedEdge[46, 357] -> 
             RGBColor[
              0.9123985653292456, 0.6903965335177349, 0.2483720332752017], 
             UndirectedEdge[18, 326] -> 
             RGBColor[
              0.8797797158009789, 0.5469895922605361, 0.22139758680656518`], 
             UndirectedEdge[73, 93] -> 
             RGBColor[
              0.2585978739086303, 0.3891331399031328, 0.9380381384066008], 
             UndirectedEdge[104, 112] -> 
             RGBColor[
              0.24741859649764936`, 0.37738301053706513`, 0.9374014950963042],
              UndirectedEdge[40, 314] -> 
             RGBColor[
              0.35813781501059505`, 0.484622707657373, 0.944041202777008], 
             UndirectedEdge[264, 398] -> 
             RGBColor[0.2479686232623, 0.377961123540424, 0.9374328183068594],
              UndirectedEdge[345, 489] -> 
             RGBColor[
              0.8249113944148371, 0.8621373590775923, 0.8902454594075883], 
             UndirectedEdge[80, 417] -> 
             RGBColor[
              0.7452877880838611, 0.8009437515388753, 0.9752469796719869], 
             UndirectedEdge[271, 442] -> 
             RGBColor[
              0.26987532258207286`, 0.400986453490465, 0.9386803724250632], 
             UndirectedEdge[318, 482] -> 
             RGBColor[
              0.35021188070592757`, 0.4777576617317112, 0.9435361692517431], 
             UndirectedEdge[235, 260] -> 
             RGBColor[
              0.32130907660212404`, 0.45058132040043347`, 0.941772944022762], 
             UndirectedEdge[79, 278] -> 
             RGBColor[
              0.9710962278680113, 0.9751094566161655, 0.770981396643022], 
             UndirectedEdge[137, 404] -> 
             RGBColor[
              0.2167644246749318, 0.34516353236463915`, 0.9356557853597838], 
             UndirectedEdge[380, 478] -> 
             RGBColor[
              0.26944650218814237`, 0.40053573606766074`, 0.9386559517380118],
              UndirectedEdge[247, 370] -> 
             RGBColor[
              0.5432273595581627, 0.6400554684598069, 0.9571839941332545], 
             UndirectedEdge[251, 429] -> 
             RGBColor[
              0.2760715850682322, 0.4074991182291509, 0.9390332404071009], 
             UndirectedEdge[286, 407] -> 
             RGBColor[
              0.21872930348009942`, 0.347228744569382, 0.9357676823009604], 
             UndirectedEdge[206, 410] -> 
             RGBColor[
              0.35319958507105037`, 0.4803454610863929, 0.9437265431319655], 
             UndirectedEdge[86, 500] -> 
             RGBColor[
              0.8673428769617186, 0.42615530998421236`, 0.20846003809980468`],
              UndirectedEdge[78, 407] -> 
             RGBColor[
              0.21689372054729342`, 0.34529943052432305`, 0.9356631485684387],
              UndirectedEdge[363, 370] -> 
             RGBColor[
              0.4981273475389003, 0.6021241779008506, 0.9539974660883765], 
             UndirectedEdge[447, 453] -> 
             RGBColor[
              0.26540338983624123`, 0.39628616863768357`, 0.9384257024708196],
              UndirectedEdge[256, 492] -> 
             RGBColor[
              0.28300272562501616`, 0.4147841864140242, 0.9394279586081062], 
             UndirectedEdge[114, 349] -> 
             RGBColor[
              0.45713997699902986`, 0.5690874562014547, 0.9507048443075143], 
             UndirectedEdge[22, 160] -> 
             RGBColor[
              0.4369491379476227, 0.5528851144131592, 0.949062990584439], 
             UndirectedEdge[149, 324] -> 
             RGBColor[
              0.361776111320833, 0.4877740170552114, 0.9442730318006773], 
             UndirectedEdge[94, 315] -> 
             RGBColor[
              0.5704593476328262, 0.6392872195268108, 0.9471116754258844], 
             UndirectedEdge[246, 492] -> 
             RGBColor[
              0.2854203608730804, 0.4173252743466679, 0.9395656393589127], 
             UndirectedEdge[193, 202] -> 
             RGBColor[
              0.2634343891958272, 0.39421662412275726`, 0.9383135707972234], 
             UndirectedEdge[321, 335] -> 
             RGBColor[
              0.3049738126003747, 0.4356185220197354, 0.94076188047572], 
             UndirectedEdge[321, 496] -> 
             RGBColor[
              0.3050324981109774, 0.4356802042122551, 0.9407652225287313], 
             UndirectedEdge[18, 474] -> 
             RGBColor[
              0.9387405372806834, 0.7796548598202627, 0.49465049788910304`], 
             UndirectedEdge[184, 192] -> 
             RGBColor[
              0.25582325613433854`, 0.3862168407014245, 0.9378801280290341], 
             UndirectedEdge[170, 171] -> 
             RGBColor[
              0.2792113970027737, 0.4107992596479288, 0.9392120480518376], 
             UndirectedEdge[80, 156] -> 
             RGBColor[
              0.6284260394446897, 0.7069689251123001, 0.9654326763878454], 
             UndirectedEdge[353, 418] -> 
             RGBColor[
              0.809068015481273, 0.8509060188194038, 0.9430493347226458], 
             UndirectedEdge[201, 312] -> 
             RGBColor[
              0.30443515610797417`, 0.4373110297461917, 0.9406485038176712], 
             UndirectedEdge[152, 212] -> 
             RGBColor[
              0.21125959360220817`, 0.3393776058807578, 0.93534229337386], 
             UndirectedEdge[192, 260] -> 
             RGBColor[
              0.27009553441077905`, 0.4012179100846716, 0.9386929131629338], 
             UndirectedEdge[90, 357] -> 
             RGBColor[
              0.8859560304571115, 0.5741950476247133, 0.2265078159100875], 
             UndirectedEdge[57, 369] -> 
             RGBColor[
              0.5105952058083258, 0.6126571266031253, 0.9548654266501568], 
             UndirectedEdge[83, 448] -> 
             RGBColor[
              0.7443425082604527, 0.7998796964136958, 0.9757160754212024], 
             UndirectedEdge[67, 180] -> 
             RGBColor[
              0.26337700695553745`, 0.3941563117499686, 0.9383103029635284], 
             UndirectedEdge[373, 472] -> 
             RGBColor[
              0.31103110428016545`, 0.44242232361832246`, 0.9410908260962028],
              UndirectedEdge[353, 432] -> 
             RGBColor[
              0.7691435045990516, 0.820174333900838, 0.9774842614710615], 
             UndirectedEdge[1, 433] -> 
             RGBColor[
              0.2958358704615542, 0.4267230355457211, 0.940215525659722], 
             UndirectedEdge[300, 301] -> 
             RGBColor[
              0.2173551636481656, 0.3457844364805221, 0.9356894270703895], 
             UndirectedEdge[212, 389] -> 
             RGBColor[
              0.21850801717300872`, 0.34699615863026745`, 0.9357550803731354],
              UndirectedEdge[97, 174] -> 
             RGBColor[
              0.24919580773922206`, 0.37925097223365895`, 0.9375027046473634],
              UndirectedEdge[200, 471] -> 
             RGBColor[
              0.8788202951923778, 0.5401284768128874, 0.22049894846562806`], 
             UndirectedEdge[155, 387] -> 
             RGBColor[
              0.6705014636086952, 0.7413486854414358, 0.9685938847155504], 
             UndirectedEdge[156, 354] -> 
             RGBColor[
              0.4145365045344412, 0.533092524898237, 0.9477398429544205], 
             UndirectedEdge[314, 472] -> 
             RGBColor[
              0.3292610947634469, 0.4596111439654538, 0.9422012036975409], 
             UndirectedEdge[117, 269] -> 
             RGBColor[
              0.41500730712434825`, 0.5338802033825223, 0.947664876526779], 
             UndirectedEdge[336, 409] -> 
             RGBColor[
              0.23189710424361965`, 0.36106893805863094`, 0.9365175690744273],
              UndirectedEdge[63, 252] -> 
             RGBColor[
              0.5775658026497799, 0.6655789256820774, 0.9611207995905398], 
             UndirectedEdge[201, 444] -> 
             RGBColor[
              0.2878759109078417, 0.4199062131240665, 0.9397054793007316], 
             UndirectedEdge[201, 442] -> 
             RGBColor[
              0.2942020501296223, 0.426555386546551, 0.9400657435707277], 
             UndirectedEdge[25, 333] -> 
             RGBColor[
              0.34601220845973285`, 0.4741201167137219, 0.94326856984984], 
             UndirectedEdge[203, 397] -> 
             RGBColor[
              0.44655734447149653`, 0.5590011690338403, 0.950284766509865], 
             UndirectedEdge[7, 436] -> 
             RGBColor[
              0.6558009604167452, 0.7285914992480711, 0.9680622843636464], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.24125115959042637`, 0.3709006433094886, 0.9370502686883432], 
             UndirectedEdge[274, 369] -> 
             RGBColor[
              0.4413408424038283, 0.5564333145178368, 0.9494134694758627], 
             UndirectedEdge[38, 364] -> 
             RGBColor[
              0.2592676752099878, 0.3898371435387148, 0.9380762825998308], 
             UndirectedEdge[215, 356] -> 
             RGBColor[
              0.2767305167100354, 0.40819169716336523`, 0.9390707655892996], 
             UndirectedEdge[16, 283] -> 
             RGBColor[
              0.29254812031783006`, 0.4160210207001029, 0.9402936186581154], 
             UndirectedEdge[236, 276] -> 
             RGBColor[
              0.45343165662521556`, 0.5606674341824253, 0.9514328089086481], 
             UndirectedEdge[39, 454] -> 
             RGBColor[
              0.761772006870989, 0.6718134516549312, 0.6008439261608904], 
             UndirectedEdge[179, 315] -> 
             RGBColor[
              0.18221437666537932`, 0.3088492413070327, 0.9336882112378554], 
             UndirectedEdge[149, 182] -> 
             RGBColor[
              0.36623071660169665`, 0.4916323722545241, 0.9445568753101211], 
             UndirectedEdge[97, 407] -> 
             RGBColor[
              0.2230464248259349, 0.3517663128251578, 0.936013535974997], 
             UndirectedEdge[274, 379] -> 
             RGBColor[
              0.386016730119334, 0.5085143491277428, 0.9458882659622865], 
             UndirectedEdge[39, 325] -> 
             RGBColor[
              0.40133925395865816`, 0.5054220551360133, 0.9485110960164554], 
             UndirectedEdge[127, 347] -> 
             RGBColor[
              0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993],
              UndirectedEdge[327, 483] -> 
             RGBColor[
              0.27685916583525294`, 0.4083269155507945, 0.9390780919666615], 
             UndirectedEdge[269, 360] -> 
             RGBColor[
              0.5141528316673345, 0.616332566062272, 0.9549279906939228], 
             UndirectedEdge[54, 147] -> 
             RGBColor[
              0.2401069833110282, 0.36969804149487495`, 0.9369851095418886], 
             UndirectedEdge[276, 422] -> 
             RGBColor[
              0.4267760803352025, 0.5326507334404715, 0.9499148132723232], 
             UndirectedEdge[181, 424] -> 
             RGBColor[
              0.3706458143967508, 0.4954565080553325, 0.9448382014375043], 
             UndirectedEdge[336, 456] -> 
             RGBColor[
              0.22294853768143919`, 0.3516634272298894, 0.936007961446929], 
             UndirectedEdge[46, 298] -> 
             RGBColor[
              0.9096473304128414, 0.8178215341712867, 0.6215408826637097], 
             UndirectedEdge[107, 132] -> 
             RGBColor[
              0.5874023021726906, 0.6508098778838103, 0.8735074338464627], 
             UndirectedEdge[78, 95] -> 
             RGBColor[
              0.22325600943798377`, 0.3519865995408531, 0.9360254715086005], 
             UndirectedEdge[296, 332] -> 
             RGBColor[
              0.3578059368755654, 0.48433525149749035`, 0.9440200557957121], 
             UndirectedEdge[397, 472] -> 
             RGBColor[
              0.3434973849835166, 0.4719419030173265, 0.9431083275217065], 
             UndirectedEdge[19, 269] -> 
             RGBColor[
              0.5043319337096805, 0.6083595186738375, 0.9541548536315616], 
             UndirectedEdge[185, 335] -> 
             RGBColor[
              0.28035846079175497`, 0.4120048964181928, 0.9392773716376912], 
             UndirectedEdge[112, 351] -> 
             RGBColor[
              0.26915448795361524`, 0.4002288105924009, 0.9386393219593516], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.2633838374698597, 0.39416349105360093`, 0.9383106919512142], 
             UndirectedEdge[251, 305] -> 
             RGBColor[
              0.25482853774731307`, 0.38517132860787223`, 0.9378234802884469],
              UndirectedEdge[131, 170] -> 
             RGBColor[
              0.28014480934839103`, 0.4117803352049335, 0.9392652045040607], 
             UndirectedEdge[76, 333] -> 
             RGBColor[
              0.3949872182942583, 0.5165398086768207, 0.9463892141695951], 
             UndirectedEdge[114, 115] -> 
             RGBColor[
              0.7109234320173796, 0.7727455262693818, 0.9730887236423327], 
             UndirectedEdge[87, 421] -> 
             RGBColor[
              0.17915493384170816`, 0.30563357291947557`, 0.9335139804950874],
              UndirectedEdge[60, 192] -> 
             RGBColor[
              0.2736621188386635, 0.4049666164528918, 0.9388960248698129], 
             UndirectedEdge[84, 147] -> 
             RGBColor[
              0.24240373141068797`, 0.37211206936985763`, 0.93711590594843], 
             UndirectedEdge[431, 433] -> 
             RGBColor[
              0.3870230907643596, 0.509641681699111, 0.9458817470057914], 
             UndirectedEdge[201, 492] -> 
             RGBColor[
              0.29053904388296076`, 0.4227053347332997, 0.9398571407839125], 
             UndirectedEdge[86, 124] -> 
             RGBColor[
              0.9389228207101663, 0.7935781606519255, 0.2800166062249653], 
             UndirectedEdge[234, 239] -> 
             RGBColor[
              0.36975457999068184`, 0.4946845656075394, 0.9447814127692372], 
             UndirectedEdge[100, 450] -> 
             RGBColor[
              0.8744616680202064, 0.45105879141128646`, 0.21405151473609035`],
              UndirectedEdge[22, 275] -> 
             RGBColor[
              0.43256024452096153`, 0.549083675519183, 0.9487833341762382], 
             UndirectedEdge[160, 324] -> 
             RGBColor[
              0.3960795993510239, 0.5174859742435227, 0.9464588197245776], 
             UndirectedEdge[191, 218] -> 
             RGBColor[
              0.2251871593264507, 0.3540163605156067, 0.9361354476378685], 
             UndirectedEdge[349, 397] -> 
             RGBColor[
              0.38607476166702576`, 0.5088202866994067, 0.9458213203142838], 
             UndirectedEdge[401, 454] -> 
             RGBColor[
              0.8366674019364873, 0.7306087240183134, 0.6081129719353302], 
             UndirectedEdge[311, 349] -> 
             RGBColor[
              0.5802291691633081, 0.667416033439714, 0.9614893343765445], 
             UndirectedEdge[63, 324] -> 
             RGBColor[
              0.3945065223315428, 0.5161234539943981, 0.9463585846479137], 
             UndirectedEdge[22, 353] -> 
             RGBColor[
              0.5455395337034719, 0.641880966146923, 0.9573802823215901], 
             UndirectedEdge[93, 437] -> 
             RGBColor[
              0.26255787085876586`, 0.3932953477760335, 0.9382636543746206], 
             UndirectedEdge[417, 461] -> 
             RGBColor[
              0.8227440842305245, 0.8622334494485463, 0.9748712810946092], 
             UndirectedEdge[151, 249] -> 
             RGBColor[
              0.29817109629594896`, 0.43072710571942197`, 0.9402917748782225],
              UndirectedEdge[148, 452] -> 
             RGBColor[
              0.23180463347080354`, 0.3609717454134156, 0.9365123030007138], 
             UndirectedEdge[262, 424] -> 
             RGBColor[
              0.39834012297090404`, 0.5188257266580119, 0.9467736686621999], 
             UndirectedEdge[50, 139] -> 
             RGBColor[
              0.50248660335272, 0.6066441419253559, 0.9540696105134843], 
             UndirectedEdge[237, 267] -> 
             RGBColor[
              0.9475774996267206, 0.9513626199375382, 0.7014579081154306], 
             UndirectedEdge[256, 442] -> 
             RGBColor[
              0.28666573187167776`, 0.4186342382272755, 0.9396365613949216], 
             UndirectedEdge[60, 133] -> 
             RGBColor[
              0.31894163191943015`, 0.44919026900604586`, 0.9415979446419711],
              UndirectedEdge[77, 156] -> 
             RGBColor[
              0.5370635204917655, 0.6350513862279201, 0.9566987541430614], 
             UndirectedEdge[219, 498] -> 
             RGBColor[
              0.49407920545967077`, 0.6001547828635406, 0.9533148714070008], 
             UndirectedEdge[102, 185] -> 
             RGBColor[
              0.28024115314486164`, 0.4118815986435736, 0.9392706911407418], 
             UndirectedEdge[92, 169] -> 
             RGBColor[
              0.5509398864490034, 0.6463168452351683, 0.9577911525020184], 
             UndirectedEdge[53, 357] -> 
             RGBColor[
              0.9418272950686917, 0.8009948820936315, 0.3036989405074137], 
             UndirectedEdge[162, 289] -> 
             RGBColor[
              0.45070123455015054`, 0.5645598995943251, 0.9500046324572284], 
             UndirectedEdge[169, 204] -> 
             RGBColor[
              0.4973176178268257, 0.6027838719120118, 0.9535698110912385], 
             UndirectedEdge[176, 448] -> 
             RGBColor[
              0.587441960125221, 0.6759508730452015, 0.9606647294533119], 
             UndirectedEdge[377, 403] -> 
             RGBColor[
              0.9550085431684978, 0.9657910070072111, 0.9549749729457403], 
             UndirectedEdge[86, 357] -> 
             RGBColor[
              0.911167687629582, 0.6855165136042474, 0.2473816401856394], 
             UndirectedEdge[12, 373] -> 
             RGBColor[
              0.28300945147034123`, 0.414791255703904, 0.9394283416350475], 
             UndirectedEdge[200, 469] -> 
             RGBColor[
              0.8806293426662699, 0.5508475494204266, 0.22210653628922422`], 
             UndirectedEdge[112, 153] -> 
             RGBColor[
              0.24659824483285725`, 0.37652076892406894`, 0.9373547772825959],
              UndirectedEdge[166, 243] -> 
             RGBColor[
              0.838713260625803, 0.29857266219470613`, 0.18470516813663024`], 
             UndirectedEdge[394, 460] -> 
             RGBColor[
              0.23849436642390026`, 0.3680030789006874, 0.9368932733958195], 
             UndirectedEdge[18, 348] -> 
             RGBColor[
              0.9221477650002106, 0.7221653986171828, 0.2620020254952798], 
             UndirectedEdge[315, 325] -> 
             RGBColor[
              0.1822582683189515, 0.30889537421782864`, 0.9336907108025945], 
             UndirectedEdge[195, 447] -> 
             RGBColor[
              0.25832593618087096`, 0.38884731610940987`, 0.9380226519553008],
              UndirectedEdge[128, 204] -> 
             RGBColor[
              0.4983181319181479, 0.6035961343239933, 0.9536485752255113], 
             UndirectedEdge[91, 435] -> 
             RGBColor[
              0.29287326479962417`, 0.4234129007814571, 0.9400539952643586], 
             UndirectedEdge[158, 206] -> 
             RGBColor[
              0.3501277440364893, 0.4776847867774757, 0.9435308081375656], 
             UndirectedEdge[30, 290] -> 
             RGBColor[
              0.2772082322816696, 0.40869380651806936`, 0.9390979707843874], 
             UndirectedEdge[2, 250] -> 
             RGBColor[
              0.20844651025640323`, 0.33642087692453115`, 0.9351820924389003],
              UndirectedEdge[148, 195] -> 
             RGBColor[
              0.2549038837878154, 0.3852505220736551, 0.9378277711339891], 
             UndirectedEdge[5, 202] -> 
             RGBColor[
              0.23883220085490312`, 0.3683581643076115, 0.9369125125668838], 
             UndirectedEdge[220, 359] -> 
             RGBColor[
              0.3621822341604067, 0.48812578024652276`, 0.9442989095888945], 
             UndirectedEdge[175, 337] -> 
             RGBColor[
              0.9079704822927377, 0.9289384814961321, 0.9731750764283525], 
             UndirectedEdge[263, 447] -> 
             RGBColor[
              0.2599502995006695, 0.3905546249491011, 0.938115157043333], 
             UndirectedEdge[344, 387] -> 
             RGBColor[
              0.6194283934274943, 0.6998852662527452, 0.9645732255440658], 
             UndirectedEdge[82, 470] -> 
             RGBColor[
              0.25688036525862096`, 0.38732792941563493`, 0.937940328829809], 
             UndirectedEdge[273, 446] -> 
             RGBColor[
              0.26084634450324296`, 0.39149642505934035`, 0.9381661854806498],
              UndirectedEdge[68, 306] -> 
             RGBColor[
              0.8387829864974263, 0.2991086057980758, 0.18477193771004097`], 
             UndirectedEdge[21, 33] -> 
             RGBColor[
              0.9296510090196749, 0.7439907144053559, 0.3002556094938443], 
             UndirectedEdge[77, 479] -> 
             RGBColor[
              0.5091542746403608, 0.6112576931750507, 0.9548154361242309], 
             UndirectedEdge[253, 311] -> 
             RGBColor[
              0.8659443575362178, 0.8951239135712197, 0.9365639679939195], 
             UndirectedEdge[308, 386] -> 
             RGBColor[
              0.17893664238380538`, 0.3054041347567419, 0.9335015491194931], 
             UndirectedEdge[151, 280] -> 
             RGBColor[
              0.2818433506476452, 0.4135656098041881, 0.9393619339182866], 
             UndirectedEdge[305, 416] -> 
             RGBColor[
              0.2563227786802443, 0.3867418705687301, 0.9379085750990459], 
             UndirectedEdge[38, 189] -> 
             RGBColor[
              0.2598720197723208, 0.3904723479913851, 0.9381106991286081], 
             UndirectedEdge[277, 291] -> 
             RGBColor[
              0.7131143362098424, 0.7758096064076011, 0.9720402306671867], 
             UndirectedEdge[27, 40] -> 
             RGBColor[
              0.44915953688308596`, 0.5618645655130168, 0.9502821669769903], 
             UndirectedEdge[88, 167] -> 
             RGBColor[
              0.9266401906833595, 0.7379726928092079, 0.5404902319838795], 
             UndirectedEdge[89, 296] -> 
             RGBColor[
              0.2994607686458766, 0.4316505064958615, 0.9403810420835206], 
             UndirectedEdge[169, 340] -> 
             RGBColor[
              0.41508837309382146`, 0.5328799596159772, 0.9479658129994224], 
             UndirectedEdge[169, 363] -> 
             RGBColor[
              0.44877677089386697`, 0.5620591565622703, 0.9501124079177607], 
             UndirectedEdge[43, 378] -> 
             RGBColor[
              0.2881161193118442, 0.42015868738676554`, 0.939719158813983], 
             UndirectedEdge[350, 482] -> 
             RGBColor[
              0.36032571563534044`, 0.4865177572114446, 0.9441806138701323], 
             UndirectedEdge[199, 429] -> 
             RGBColor[
              0.318220922727511, 0.44864816272084596`, 0.9415490142958283], 
             UndirectedEdge[135, 216] -> 
             RGBColor[
              0.25825637493020664`, 0.38877420282452363`, 0.938018690544982], 
             UndirectedEdge[153, 351] -> 
             RGBColor[
              0.267489207183899, 0.39847849491853005`, 0.9385444866830785], 
             UndirectedEdge[207, 218] -> 
             RGBColor[
              0.22451796602725682`, 0.35331299592884813`, 0.9360973380694622],
              UndirectedEdge[218, 389] -> 
             RGBColor[
              0.22523636007401557`, 0.35406807362080495`, 0.9361382495476563],
              UndirectedEdge[421, 477] -> 
             RGBColor[
              0.21186411660990806`, 0.34001299789082284`, 0.9353767200648369],
              UndirectedEdge[171, 391] -> 
             RGBColor[
              0.25143472628896596`, 0.3816042175850748, 0.9376302077465881], 
             UndirectedEdge[25, 246] -> 
             RGBColor[
              0.3037983452782409, 0.43621369244109887`, 0.940627909879872], 
             UndirectedEdge[130, 254] -> 
             RGBColor[
              0.20771262472504887`, 0.3356495167000475, 0.935140298743576], 
             UndirectedEdge[65, 434] -> 
             RGBColor[
              0.9883337030612244, 0.9766308233101144, 0.5967468015081936], 
             UndirectedEdge[174, 430] -> 
             RGBColor[
              0.2531980668507343, 0.38345760031774234`, 0.9377306273829522], 
             UndirectedEdge[213, 454] -> 
             RGBColor[
              0.902044161930851, 0.6480872421427781, 0.23997558640884487`], 
             UndirectedEdge[52, 495] -> 
             RGBColor[
              0.8389987580384334, 0.3007671204139477, 0.18497856078138836`], 
             UndirectedEdge[26, 224] -> 
             RGBColor[
              0.34279791451999597`, 0.4704318560417961, 0.9430968651035153], 
             UndirectedEdge[8, 31] -> 
             RGBColor[
              0.5366659458722182, 0.6347210217205881, 0.9566695542776334], 
             UndirectedEdge[29, 321] -> 
             RGBColor[
              0.3713978817482214, 0.49610791099517215`, 0.944886122504113], 
             UndirectedEdge[319, 377] -> 
             RGBColor[
              0.8479973976544979, 0.8813126625416667, 0.9445427395689829], 
             UndirectedEdge[323, 447] -> 
             RGBColor[
              0.24292230663621342`, 0.3726571248114532, 0.9371454380403603], 
             UndirectedEdge[13, 340] -> 
             RGBColor[
              0.3170254114231826, 0.44789173278801986`, 0.9414626195505558], 
             UndirectedEdge[176, 237] -> 
             RGBColor[
              0.7565184993634433, 0.8098707472801487, 0.9765525722729846], 
             UndirectedEdge[22, 268] -> 
             RGBColor[
              0.4305356531895016, 0.5473300762667914, 0.9486543290068734], 
             UndirectedEdge[461, 493] -> 
             RGBColor[
              0.9690163833229786, 0.9733831615410689, 0.7606045943611018], 
             UndirectedEdge[401, 450] -> 
             RGBColor[
              0.7955804305647025, 0.4800334417304184, 0.5713225662708019], 
             UndirectedEdge[100, 200] -> 
             RGBColor[
              0.9160214299715226, 0.703780905297789, 0.25123642844933736`], 
             UndirectedEdge[197, 375] -> 
             RGBColor[
              0.8279135305907634, 0.8660284937370616, 0.9630673509377192], 
             UndirectedEdge[94, 401] -> 
             RGBColor[
              0.8644357283380311, 0.8946091728083778, 0.9692011064141851], 
             UndirectedEdge[118, 327] -> 
             RGBColor[
              0.2910886324434072, 0.42177019876942656`, 0.9399438296328053], 
             UndirectedEdge[44, 255] -> 
             RGBColor[
              0.44713138767076954`, 0.5605271620680575, 0.9500370874897843], 
             UndirectedEdge[148, 356] -> 
             RGBColor[
              0.2544968866209464, 0.384822742246165, 0.9378045932474341], 
             UndirectedEdge[26, 34] -> 
             RGBColor[
              0.46519130263863967`, 0.5748915338435057, 0.9515410249790447], 
             UndirectedEdge[244, 313] -> 
             RGBColor[
              0.3046994618698019, 0.43447349621750786`, 0.9407776233385161], 
             UndirectedEdge[331, 488] -> 
             RGBColor[
              0.8030279977952235, 0.8461858842867422, 0.9809661481473407], 
             UndirectedEdge[382, 429] -> 
             RGBColor[
              0.2879113316712099, 0.41994344259217253`, 0.9397074964608051], 
             UndirectedEdge[409, 496] -> 
             RGBColor[
              0.25922260246551676`, 0.38978976922649866`, 0.9380737157737123],
              UndirectedEdge[14, 324] -> 
             RGBColor[
              0.33821006500838097`, 0.4671770715883025, 0.9427782060023248], 
             UndirectedEdge[259, 471] -> 
             RGBColor[
              0.8593266411159032, 0.451612346510198, 0.20423296567103144`], 
             UndirectedEdge[178, 439] -> 
             RGBColor[
              0.9262985601874452, 0.9413808299607197, 0.8870332114673454], 
             UndirectedEdge[127, 454] -> 
             RGBColor[
              0.562931118749189, 0.49656039652436856`, 0.5871761845581333], 
             UndirectedEdge[190, 452] -> 
             RGBColor[
              0.2360315215156537, 0.3654144727487341, 0.9367530180217474], 
             UndirectedEdge[218, 295] -> 
             RGBColor[
              0.2307804101674582, 0.3598952217820915, 0.9364539749987908], 
             UndirectedEdge[35, 67] -> 
             RGBColor[
              0.24749774961125026`, 0.377466205478057, 0.9374060027490273], 
             UndirectedEdge[192, 249] -> 
             RGBColor[
              0.27208125411189216`, 0.40330502739244223`, 0.938805996962303], 
             UndirectedEdge[186, 202] -> 
             RGBColor[
              0.2373837352876954, 0.3668357351584549, 0.9368300245956442], 
             UndirectedEdge[243, 469] -> 
             RGBColor[
              0.8498683936659192, 0.3811298439450528, 0.19526257805333647`], 
             UndirectedEdge[48, 183] -> 
             RGBColor[
              0.20623910902756293`, 0.3341007582756985, 0.9350563842044752], 
             UndirectedEdge[255, 390] -> 
             RGBColor[
              0.3491694965791283, 0.4761158367358585, 0.9434968065582812], 
             UndirectedEdge[202, 497] -> 
             RGBColor[
              0.23752535161991525`, 0.36698458290261204`, 0.9368380894362616],
              UndirectedEdge[84, 365] -> 
             RGBColor[
              0.22514447908377305`, 0.3539715008744688, 0.9361330170611878], 
             UndirectedEdge[239, 262] -> 
             RGBColor[
              0.41350816527111056`, 0.531963522530478, 0.947740162904996], 
             UndirectedEdge[299, 456] -> 
             RGBColor[
              0.21641245264037934`, 0.34479358744000865`, 0.935635741073112], 
             UndirectedEdge[136, 253] -> 
             RGBColor[
              0.9769962544035893, 0.9822248956493935, 0.9175751236598007], 
             UndirectedEdge[338, 478] -> 
             RGBColor[
              0.29307363534810826`, 0.42431910359583813`, 0.9400399367228911],
              UndirectedEdge[284, 444] -> 
             RGBColor[
              0.25819284063858217`, 0.3887074242557196, 0.9380150723610645], 
             UndirectedEdge[135, 147] -> 
             RGBColor[
              0.2510599689447852, 0.3812103238553528, 0.9376088658702408], 
             UndirectedEdge[72, 73] -> 
             RGBColor[
              0.2509474629421924, 0.38109207291333524`, 0.9376024588198308], 
             UndirectedEdge[8, 291] -> 
             RGBColor[
              0.637610384777719, 0.7164873323549865, 0.9647458039813404], 
             UndirectedEdge[141, 240] -> 
             RGBColor[
              0.2831042170303842, 0.4148134850118461, 0.939436571482416], 
             UndirectedEdge[9, 466] -> 
             RGBColor[
              0.5393259259475076, 0.6368881088970959, 0.9568768589880016], 
             UndirectedEdge[78, 346] -> 
             RGBColor[
              0.21865587786091514`, 0.34715156958816623`, 0.9357635008205714],
              UndirectedEdge[255, 425] -> 
             RGBColor[
              0.38646418769848023`, 0.5091575879547311, 0.9458461341966522], 
             UndirectedEdge[297, 349] -> 
             RGBColor[
              0.4664828396818328, 0.5766724130185215, 0.9514403486819383], 
             UndirectedEdge[248, 478] -> 
             RGBColor[
              0.25429079969208646`, 0.3846061318172672, 0.9377928569017139], 
             UndirectedEdge[113, 130] -> 
             RGBColor[
              0.17905963034776856`, 0.3055334029047545, 0.9335085531020964], 
             UndirectedEdge[51, 179] -> 
             RGBColor[
              0.1789280689363169, 0.30539512351984355`, 0.9335010608743419], 
             UndirectedEdge[440, 470] -> 
             RGBColor[
              0.2685779731534025, 0.3996228569842277, 0.9386064902943567], 
             UndirectedEdge[5, 414] -> 
             RGBColor[
              0.2566326545868817, 0.38706756979387325`, 0.9379262220735086], 
             UndirectedEdge[148, 463] -> 
             RGBColor[
              0.25337660171868737`, 0.3836452517837254, 0.9377407946795635], 
             UndirectedEdge[63, 441] -> 
             RGBColor[
              0.4347339982883702, 0.5509664717764713, 0.9489218438441225], 
             UndirectedEdge[163, 187] -> 
             RGBColor[
              0.2658102034815037, 0.3967137555723293, 0.9384488699060904], 
             UndirectedEdge[120, 177] -> 
             RGBColor[
              0.20805903153131503`, 0.3360136122168933, 0.9351600260987298], 
             UndirectedEdge[450, 454] -> 
             RGBColor[
              0.8587954548220276, 0.3876960227591984, 0.20138137545633958`], 
             UndirectedEdge[15, 190] -> 
             RGBColor[
              0.24117420601353035`, 0.37081976022103225`, 0.9370458862959816],
              UndirectedEdge[191, 287] -> 
             RGBColor[
              0.21410654860741013`, 0.342369936098598, 0.9355044232497137], 
             UndirectedEdge[179, 292] -> 
             RGBColor[
              0.17894988462017136`, 0.30541805318676885`, 0.9335023032452641],
              UndirectedEdge[291, 297] -> 
             RGBColor[
              0.5871456749634538, 0.6755178075184964, 0.9607730371664382], 
             UndirectedEdge[289, 397] -> 
             RGBColor[
              0.39895955278042317`, 0.5199804451534001, 0.9466423278104561], 
             UndirectedEdge[175, 370] -> 
             RGBColor[
              0.7735868010178651, 0.822851827878325, 0.9604005134157099], 
             UndirectedEdge[23, 186] -> 
             RGBColor[
              0.22910595895914918`, 0.35813526739582024`, 0.9363586174796061],
              UndirectedEdge[241, 461] -> 
             RGBColor[
              0.8249688230204753, 0.8639714322998968, 0.9750930222658254], 
             UndirectedEdge[157, 216] -> 
             RGBColor[
              0.28421479544229167`, 0.41605814864164575`, 0.9394969841911034],
              UndirectedEdge[51, 302] -> 
             RGBColor[
              0.18453817957609825`, 0.31129170550381263`, 0.9338205483758626],
              UndirectedEdge[174, 390] -> 
             RGBColor[
              0.28370528761633407`, 0.41552262361190234`, 0.9394679684741645],
              UndirectedEdge[79, 406] -> 
             RGBColor[
              0.9922235479450122, 0.984612153776488, 0.4938632532617516], 
             UndirectedEdge[181, 235] -> 
             RGBColor[
              0.38886946031407776`, 0.511240914201845, 0.9459993960408191], 
             UndirectedEdge[78, 404] -> 
             RGBColor[
              0.2164387033219317, 0.3448211785707095, 0.935637236010592], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.2711970471587578, 0.4023756698227392, 0.938755642684389], 
             UndirectedEdge[43, 384] -> 
             RGBColor[
              0.28848430619933074`, 0.4205456751499109, 0.9397401265125418], 
             UndirectedEdge[101, 363] -> 
             RGBColor[
              0.4628220425559936, 0.5734617408298626, 0.9512181031525286], 
             UndirectedEdge[120, 455] -> 
             RGBColor[
              0.2056810719300792, 0.33351422590464763`, 0.9350246048173154], 
             UndirectedEdge[295, 456] -> 
             RGBColor[
              0.22662320577002346`, 0.355525736378405, 0.9362172283583896], 
             UndirectedEdge[58, 240] -> 
             RGBColor[
              0.2858686487739417, 0.41720789684373627`, 0.9396127186286245], 
             UndirectedEdge[39, 471] -> 
             RGBColor[
              0.7402370852900231, 0.5715237918221177, 0.5827765854569318], 
             UndirectedEdge[54, 365] -> 
             RGBColor[
              0.22284773098411328`, 0.35155747299948614`, 0.9360022206546466],
              UndirectedEdge[169, 334] -> 
             RGBColor[
              0.44777313143376407`, 0.5611898545063152, 0.9500484568988465], 
             UndirectedEdge[18, 65] -> 
             RGBColor[
              0.9349243740088637, 0.7652639008938271, 0.3116367388337401], 
             UndirectedEdge[384, 435] -> 
             RGBColor[
              0.2709692417504848, 0.4021362318949472, 0.9387426695033958], 
             UndirectedEdge[9, 360] -> 
             RGBColor[
              0.5772550006439877, 0.6676806404210414, 0.9598627746868871], 
             UndirectedEdge[135, 171] -> 
             RGBColor[
              0.25618449679905386`, 0.3865965275440213, 0.9379007001504819], 
             UndirectedEdge[149, 187] -> 
             RGBColor[
              0.30925143443909986`, 0.4382007802607746, 0.9410755580672832], 
             UndirectedEdge[271, 464] -> 
             RGBColor[
              0.24983604138275278`, 0.37992389838616725`, 0.9375391650062217],
              UndirectedEdge[21, 348] -> 
             RGBColor[
              0.9703996877499586, 0.911813337676092, 0.3395088057688662], 
             UndirectedEdge[1, 70] -> 
             RGBColor[
              0.26220782647507634`, 0.3929274289346799, 0.9382437198648137], 
             UndirectedEdge[52, 276] -> 
             RGBColor[
              0.7276676005214341, 0.4890758052767825, 0.5725511491543327], 
             UndirectedEdge[58, 429] -> 
             RGBColor[
              0.3043548555603097, 0.4366380722694161, 0.9406654807572159], 
             UndirectedEdge[243, 495] -> 
             RGBColor[
              0.8407542903650291, 0.31426091115533294`, 0.1866596605199266], 
             UndirectedEdge[131, 135] -> 
             RGBColor[
              0.25711790914467114`, 0.38757760310102596`, 0.937953856602705], 
             UndirectedEdge[145, 430] -> 
             RGBColor[
              0.23019859628253192`, 0.35928369849990305`, 0.9364208415587607],
              UndirectedEdge[291, 419] -> 
             RGBColor[
              0.583808838050422, 0.6728088129897074, 0.960510349141408], 
             UndirectedEdge[151, 260] -> 
             RGBColor[
              0.2961853765948359, 0.4286399884116514, 0.940178691078853], 
             UndirectedEdge[189, 437] -> 
             RGBColor[
              0.25780291323833093`, 0.38829758583523044`, 0.9379928665724662],
              UndirectedEdge[196, 354] -> 
             RGBColor[
              0.32873158920795986`, 0.45794625952520507`, 0.9422116309155903],
              UndirectedEdge[340, 355] -> 
             RGBColor[
              0.3330706823231735, 0.4629108172342508, 0.9424439472481606], 
             UndirectedEdge[58, 310] -> 
             RGBColor[
              0.3059344073310527, 0.43829828132983367`, 0.9407554338938223], 
             UndirectedEdge[261, 500] -> 
             RGBColor[
              0.8497397394109806, 0.34938235459205963`, 0.19393494909850834`],
              UndirectedEdge[237, 270] -> 
             RGBColor[
              0.9480577404464491, 0.9590498999175098, 0.9029559373872008], 
             UndirectedEdge[23, 497] -> 
             RGBColor[
              0.22924757529136902`, 0.3582841151399774, 0.9363666823202235], 
             UndirectedEdge[431, 462] -> 
             RGBColor[
              0.4562091477173884, 0.5692804281616477, 0.9503694481270373], 
             UndirectedEdge[108, 129] -> 
             RGBColor[
              0.3203552344901264, 0.4497120899906687, 0.9417137426958612], 
             UndirectedEdge[376, 485] -> 
             RGBColor[
              0.26372814560153673`, 0.3945253807303899, 0.938330299789955], 
             UndirectedEdge[124, 261] -> 
             RGBColor[
              0.9213196831594281, 0.7168052052597729, 0.265491517223669], 
             UndirectedEdge[63, 158] -> 
             RGBColor[
              0.38842846253649266`, 0.5108589440920934, 0.9459712960523903], 
             UndirectedEdge[66, 427] -> 
             RGBColor[
              0.271390600085227, 0.40257910622042264`, 0.9387666652372155], 
             UndirectedEdge[66, 208] -> 
             RGBColor[
              0.2926997987840062, 0.4237400438284219, 0.9400254625551399], 
             UndirectedEdge[54, 230] -> 
             RGBColor[
              0.22629940994459397`, 0.3551854064360376, 0.9361987886651444], 
             UndirectedEdge[186, 295] -> 
             RGBColor[
              0.23264914651192115`, 0.36185938216484964`, 0.9365603967690603],
              UndirectedEdge[245, 394] -> 
             RGBColor[
              0.22510267482771082`, 0.3539275619508045, 0.936130636370649], 
             UndirectedEdge[49, 459] -> 
             RGBColor[
              0.44038041665413563`, 0.554855283237734, 0.9495584378871766], 
             UndirectedEdge[55, 365] -> 
             RGBColor[
              0.21422616460620378`, 0.3424956600974225, 0.935511235203889], 
             UndirectedEdge[197, 448] -> 
             RGBColor[
              0.6327824685500147, 0.7119137261765637, 0.9648129350991647], 
             UndirectedEdge[185, 321] -> 
             RGBColor[
              0.30856010126890854`, 0.43938793879419913`, 0.9409661143099544],
              UndirectedEdge[242, 339] -> 
             RGBColor[
              0.21834915626655288`, 0.34682918574521915`, 0.9357460334795263],
              UndirectedEdge[186, 191] -> 
             RGBColor[
              0.22705589567091367`, 0.35598052089836485`, 0.936241869408138], 
             UndirectedEdge[218, 456] -> 
             RGBColor[
              0.2278157330596809, 0.3567791581704322, 0.9362851410233497], 
             UndirectedEdge[63, 182] -> 
             RGBColor[
              0.3989611276124065, 0.5199818091937107, 0.9466424281573576], 
             UndirectedEdge[133, 181] -> 
             RGBColor[
              0.3829354312034995, 0.5061011564392373, 0.9456212849531489], 
             UndirectedEdge[11, 186] -> 
             RGBColor[
              0.23731427099118235`, 0.3667627237785289, 0.936826068706721], 
             UndirectedEdge[105, 148] -> 
             RGBColor[
              0.24278055645410443`, 0.37250813638257607`, 0.9371373655771897],
              UndirectedEdge[235, 393] -> 
             RGBColor[
              0.40912660425444114`, 0.5285723075143651, 0.947349382422311], 
             UndirectedEdge[110, 290] -> 
             RGBColor[
              0.2791002706073135, 0.4106824587604797, 0.9392057195680129], 
             UndirectedEdge[225, 296] -> 
             RGBColor[
              0.29383455667092717`, 0.42573700098774714`, 0.940060637634782], 
             UndirectedEdge[38, 93] -> 
             RGBColor[
              0.2646269773927557, 0.3954701099321881, 0.9383814869307624], 
             UndirectedEdge[80, 486] -> 
             RGBColor[
              0.8622352558727102, 0.8932330485230531, 0.9866566699988166], 
             UndirectedEdge[471, 500] -> 
             RGBColor[
              0.8381526226622067, 0.29426335313338325`, 0.18416830058954048`],
              UndirectedEdge[200, 213] -> 
             RGBColor[
              0.9025169525103827, 0.6502340737413859, 0.24037009445756363`], 
             UndirectedEdge[191, 295] -> 
             RGBColor[
              0.22399463203679326`, 0.35276293872357944`, 0.9360675349729086],
              UndirectedEdge[295, 300] -> 
             RGBColor[
              0.22777276498654234`, 0.3567339960012304, 0.9362826940551499], 
             UndirectedEdge[191, 451] -> 
             RGBColor[
              0.21492359957141377`, 0.343228708465789, 0.9355509530933952], 
             UndirectedEdge[137, 145] -> 
             RGBColor[
              0.2203693542453783, 0.34895254190891456`, 0.9358610807658054], 
             UndirectedEdge[332, 344] -> 
             RGBColor[
              0.4329675168621825, 0.5491533716913533, 0.9488874962659426], 
             UndirectedEdge[76, 392] -> 
             RGBColor[
              0.35866334703698777`, 0.48482413936361163`, 0.9440839805262493],
              UndirectedEdge[157, 465] -> 
             RGBColor[
              0.2925845958094424, 0.42485533950351484`, 0.9399736319400027], 
             UndirectedEdge[204, 337] -> 
             RGBColor[
              0.6810518757467315, 0.7489355468683991, 0.970229432274497], 
             UndirectedEdge[112, 395] -> 
             RGBColor[
              0.2566255492107321, 0.38706010159303317`, 0.9379258174328484], 
             UndirectedEdge[51, 107] -> 
             RGBColor[
              0.18179934664985797`, 0.3084130184462969, 0.9336645758924533], 
             UndirectedEdge[5, 41] -> 
             RGBColor[
              0.23556700835298144`, 0.36492623996293, 0.9367265646843188], 
             UndirectedEdge[88, 210] -> 
             RGBColor[
              0.8513369203215293, 0.3826983248089265, 0.19628825904818903`], 
             UndirectedEdge[248, 411] -> 
             RGBColor[
              0.2410648104835609, 0.37070477858295714`, 0.937039656382386], 
             UndirectedEdge[101, 128] -> 
             RGBColor[
              0.5077879700548952, 0.6112841755347511, 0.9543940755727961], 
             UndirectedEdge[298, 418] -> 
             RGBColor[
              0.9400566522436402, 0.9539366372768199, 0.955901674523727], 
             UndirectedEdge[1, 391] -> 
             RGBColor[
              0.25364635844324135`, 0.38392878320479584`, 0.9377561569259576],
              UndirectedEdge[116, 327] -> 
             RGBColor[
              0.25289755432094124`, 0.38314174259533496`, 0.937713513638949], 
             UndirectedEdge[79, 81] -> 
             RGBColor[
              0.9087234308797807, 0.9257016701540246, 0.7763552620147077], 
             UndirectedEdge[254, 368] -> 
             RGBColor[
              0.32229994971598047`, 0.44690195182710835`, 0.9420022258236223],
              UndirectedEdge[4, 318] -> 
             RGBColor[
              0.33312298494508064`, 0.46295611913654056`, 0.9424472799249791],
              UndirectedEdge[352, 412] -> 
             RGBColor[
              0.23510619043035305`, 0.36444189110870373`, 0.9367003217853442],
              UndirectedEdge[239, 424] -> 
             RGBColor[
              0.3357624743157177, 0.4652423121647933, 0.9426154658536674], 
             UndirectedEdge[58, 188] -> 
             RGBColor[
              0.32619444448890195`, 0.45695496563196736`, 0.9420057994537792],
              UndirectedEdge[407, 408] -> 
             RGBColor[
              0.2184314377890148, 0.3469156688422765, 0.9357507192905059], 
             UndirectedEdge[255, 466] -> 
             RGBColor[
              0.45054684949746193`, 0.5632999878437683, 0.9503059651560305], 
             UndirectedEdge[197, 489] -> 
             RGBColor[
              0.843861608566709, 0.8769414103999965, 0.8921342396544271], 
             UndirectedEdge[50, 363] -> 
             RGBColor[
              0.422874692158388, 0.5406945368727382, 0.9481661793442926], 
             UndirectedEdge[57, 175] -> 
             RGBColor[
              0.7784866261079177, 0.8268297266210345, 0.9607862455954495], 
             UndirectedEdge[278, 486] -> 
             RGBColor[
              0.9416456695144926, 0.9559801240610102, 0.9829731602176706], 
             UndirectedEdge[82, 263] -> 
             RGBColor[
              0.26583963752085393`, 0.39674469261391226`, 0.9384505461310877],
              UndirectedEdge[41, 186] -> 
             RGBColor[
              0.23411854278577374`, 0.36340381081377343`, 0.9366440767130793],
              UndirectedEdge[390, 425] -> 
             RGBColor[
              0.3380481584260487, 0.4664830926023694, 0.94278816472538], 
             UndirectedEdge[218, 458] -> 
             RGBColor[
              0.23123609658963368`, 0.36037417710398584`, 0.936479925666406], 
             UndirectedEdge[230, 374] -> 
             RGBColor[
              0.23780417240741958`, 0.3672776412285381, 0.9368539678676315], 
             UndirectedEdge[104, 408] -> 
             RGBColor[
              0.23453910043567894`, 0.36384584356871885`, 0.9366680268490819],
              UndirectedEdge[121, 213] -> 
             RGBColor[
              0.86583591956703, 0.4350120088827739, 0.20785705715207875`], 
             UndirectedEdge[143, 421] -> 
             RGBColor[
              0.1789918035644768, 0.3054621126550484, 0.9335046904671287], 
             UndirectedEdge[185, 482] -> 
             RGBColor[
              0.32121309396000997`, 0.4503473251053272, 0.9417723518156291], 
             UndirectedEdge[256, 333] -> 
             RGBColor[
              0.3340176365315557, 0.4619410698643276, 0.9425698252260324], 
             UndirectedEdge[351, 463] -> 
             RGBColor[
              0.27857140569147526`, 0.4101265882019613, 0.9391756014934415], 
             UndirectedEdge[42, 411] -> 
             RGBColor[
              0.23603211668449622`, 0.3654150983089235, 0.9367530519157325], 
             UndirectedEdge[52, 243] -> 
             RGBColor[
              0.837550577025578, 0.2896357665521757, 0.18359178100799164`], 
             UndirectedEdge[385, 391] -> 
             RGBColor[
              0.23729940724147955`, 0.36674710103517516`, 0.9368252222381643],
              UndirectedEdge[366, 435] -> 
             RGBColor[
              0.2615619901606841, 0.3922486140198663, 0.9382069404421383], 
             UndirectedEdge[114, 419] -> 
             RGBColor[
              0.5066845097134336, 0.6103883367192307, 0.9543072071326079], 
             UndirectedEdge[67, 391] -> 
             RGBColor[
              0.24887514925956578`, 0.37891393984061833`, 0.9374844436213188],
              UndirectedEdge[310, 327] -> 
             RGBColor[
              0.2769131154519483, 0.40838362001854456`, 0.939081164317521], 
             UndirectedEdge[309, 348] -> 
             RGBColor[
              0.976471187338104, 0.9319682118150352, 0.39079228120582354`], 
             UndirectedEdge[28, 194] -> 
             RGBColor[
              0.9756860818103763, 0.9810011844305191, 0.9087502503850045], 
             UndirectedEdge[92, 337] -> 
             RGBColor[
              0.7346741443689091, 0.7924685201915558, 0.974450773685277], 
             UndirectedEdge[205, 432] -> 
             RGBColor[
              0.9462255159241673, 0.9556033712696023, 0.7798152269955922], 
             UndirectedEdge[314, 398] -> 
             RGBColor[
              0.29561326424229706`, 0.426066606556162, 0.9402183167389095], 
             UndirectedEdge[235, 453] -> 
             RGBColor[
              0.32067427818872773`, 0.4499141070194098, 0.9417367931922191], 
             UndirectedEdge[92, 334] -> 
             RGBColor[
              0.505970833581321, 0.6084373708863062, 0.9546299931971096], 
             UndirectedEdge[35, 54] -> 
             RGBColor[
              0.23354661261843296`, 0.36280267594543125`, 0.936611506136144], 
             UndirectedEdge[191, 456] -> 
             RGBColor[
              0.22102995492901595`, 0.34964687511192016`, 0.9358987009974674],
              UndirectedEdge[78, 137] -> 
             RGBColor[
              0.21975482034818994`, 0.34830662781927, 0.9358260839694819], 
             UndirectedEdge[57, 169] -> 
             RGBColor[
              0.5469925860365322, 0.6431122489364671, 0.9574804065541109], 
             UndirectedEdge[343, 392] -> 
             RGBColor[
              0.29944445035868683`, 0.4320654815746701, 0.9403642905083368], 
             UndirectedEdge[24, 197] -> 
             RGBColor[
              0.7672988184851579, 0.8182762435725834, 0.9774043962108645], 
             UndirectedEdge[450, 471] -> 
             RGBColor[
              0.8372605332410615, 0.2874063629263848, 0.183314034752381], 
             UndirectedEdge[150, 267] -> 
             RGBColor[
              0.9052536312416688, 0.5703031723537458, 0.2900897268509228], 
             UndirectedEdge[40, 371] -> 
             RGBColor[
              0.37457203795785354`, 0.49885720556622565`, 0.9450883769309946],
              UndirectedEdge[217, 362] -> 
             RGBColor[
              0.35409065029754605`, 0.481117256999343, 0.9437833210202597], 
             UndirectedEdge[229, 478] -> 
             RGBColor[
              0.27850887095594073`, 0.41006086022998334`, 0.9391720402327646],
              UndirectedEdge[100, 168] -> 
             RGBColor[
              0.9210035362936968, 0.7245123759551941, 0.25529579489782767`], 
             UndirectedEdge[221, 297] -> 
             RGBColor[
              0.5279871450253872, 0.627682775738259, 0.9559842286184892], 
             UndirectedEdge[50, 338] -> 
             RGBColor[
              0.3805216773222415, 0.5040104841460892, 0.9454674826902338], 
             UndirectedEdge[5, 186] -> 
             RGBColor[
              0.23715887571324926`, 0.36659939348879156`, 0.9368172191755294],
              UndirectedEdge[147, 391] -> 
             RGBColor[
              0.24631019843469731`, 0.37621801389640636`, 0.9373383734663472],
              UndirectedEdge[24, 426] -> 
             RGBColor[
              0.8535732035252862, 0.8860801191364223, 0.9858957682176778], 
             UndirectedEdge[100, 127] -> 
             RGBColor[
              0.5785973319473678, 0.5599231651764567, 0.5998463238378839], 
             UndirectedEdge[418, 432] -> 
             RGBColor[
              0.9385489798096075, 0.9527344602026001, 0.9557578713810538], 
             UndirectedEdge[200, 259] -> 
             RGBColor[
              0.8813343532764009, 0.5540488379416193, 0.22269481442370878`], 
             UndirectedEdge[17, 293] -> 
             RGBColor[
              0.9171217844286204, 0.9362730779745756, 0.9753514321588153], 
             UndirectedEdge[269, 468] -> 
             RGBColor[
              0.4636581822326119, 0.5753387348931303, 0.9509528669224259], 
             UndirectedEdge[154, 390] -> 
             RGBColor[
              0.30514733542854805`, 0.43798605336538, 0.9406917533770347], 
             UndirectedEdge[162, 439] -> 
             RGBColor[
              0.6614719504889517, 0.7330346033014116, 0.9686938737233264], 
             UndirectedEdge[103, 304] -> 
             RGBColor[
              0.4094598762170423, 0.5283411604549934, 0.947514243402197], 
             UndirectedEdge[3, 480] -> 
             RGBColor[
              0.4076066344287682, 0.5272434439758863, 0.9472559414401728], 
             UndirectedEdge[358, 404] -> 
             RGBColor[
              0.21953726017780179`, 0.34807795828608057`, 0.9358136942396298],
              UndirectedEdge[3, 439] -> 
             RGBColor[
              0.6612892589149015, 0.732886286051436, 0.9686794915733958], 
             UndirectedEdge[336, 458] -> 
             RGBColor[
              0.22636890121139194`, 0.35525844616344304`, 0.9362027460899854],
              UndirectedEdge[212, 287] -> 
             RGBColor[
              0.21416398383706822`, 0.3424303041665726, 0.9355076941010749], 
             UndirectedEdge[190, 195] -> 
             RGBColor[
              0.25913077183266553`, 0.38969324940897365`, 0.9380684861550228],
              UndirectedEdge[253, 377] -> 
             RGBColor[
              0.9830684787672088, 0.9867535506374262, 0.9072964317019494], 
             UndirectedEdge[192, 327] -> 
             RGBColor[
              0.25584189976103616`, 0.38623643633515786`, 0.9378811897559938],
              UndirectedEdge[151, 483] -> 
             RGBColor[
              0.3017217477257488, 0.43445906549644486`, 0.9404939792244313], 
             UndirectedEdge[38, 163] -> 
             RGBColor[
              0.2634804930859057, 0.3942650822343853, 0.9383161963455589], 
             UndirectedEdge[88, 227] -> 
             RGBColor[
              0.8561206468687188, 0.41946814329296433`, 0.20086916099222407`],
              UndirectedEdge[281, 343] -> 
             RGBColor[
              0.26889808498261325`, 0.3999593148129905, 0.9386247201894673], 
             UndirectedEdge[76, 157] -> 
             RGBColor[
              0.35693445553108405`, 0.4830069647728541, 0.9439855227126539], 
             UndirectedEdge[364, 437] -> 
             RGBColor[
              0.25719856867599794`, 0.38766238138256004`, 0.9379584500436889],
              UndirectedEdge[229, 244] -> 
             RGBColor[
              0.3167084139494082, 0.447095666264713, 0.9414615153937971], 
             UndirectedEdge[154, 425] -> 
             RGBColor[
              0.3424420265478999, 0.47102780458425264`, 0.9430410810154058], 
             UndirectedEdge[128, 355] -> 
             RGBColor[
              0.4117250076221206, 0.5299124488854325, 0.9477665145867664], 
             UndirectedEdge[58, 382] -> 
             RGBColor[
              0.2986682199237062, 0.43066105766182183`, 0.9403416352703349], 
             UndirectedEdge[45, 179] -> 
             RGBColor[
              0.2308558043838454, 0.3599744658837838, 0.9364582685878783], 
             UndirectedEdge[181, 296] -> 
             RGBColor[
              0.3670585086059648, 0.49234936408258523`, 0.9446096214846453], 
             UndirectedEdge[350, 354] -> 
             RGBColor[
              0.36196691822383753`, 0.4879392844043602, 0.9442851898478128], 
             UndirectedEdge[318, 335] -> 
             RGBColor[
              0.3093572475376726, 0.43941523304457686`, 0.9410411890738053], 
             UndirectedEdge[354, 372] -> 
             RGBColor[
              0.416108457877265, 0.5343687074376324, 0.9478635928798225], 
             UndirectedEdge[44, 57] -> 
             RGBColor[
              0.5489601186307986, 0.6447095805328258, 0.9576352979272409], 
             UndirectedEdge[257, 420] -> 
             RGBColor[
              0.9137481314322007, 0.7140513423503487, 0.5709499365964574], 
             UndirectedEdge[84, 171] -> 
             RGBColor[
              0.2475282592649566, 0.3774982730585261, 0.9374077402286709], 
             UndirectedEdge[376, 497] -> 
             RGBColor[
              0.25772437162935435`, 0.38821503362437043`, 0.9379883937440268],
              UndirectedEdge[164, 443] -> 
             RGBColor[
              0.8760183447320038, 0.45688851313920237`, 0.21528999668843654`],
              UndirectedEdge[2, 54] -> 
             RGBColor[
              0.22058424144202293`, 0.3491784019772233, 0.9358733182737572], 
             UndirectedEdge[165, 324] -> 
             RGBColor[
              0.3968553526992069, 0.5181578928032218, 0.9465082500419522], 
             UndirectedEdge[82, 395] -> 
             RGBColor[
              0.26163309800222595`, 0.39232335286982434`, 0.9382109899285194],
              UndirectedEdge[298, 420] -> 
             RGBColor[
              0.9351413217232607, 0.9502707918228358, 0.9642220469712115], 
             UndirectedEdge[163, 437] -> 
             RGBColor[
              0.26141138655191587`, 0.3920903200782306, 0.9381983637894169], 
             UndirectedEdge[156, 372] -> 
             RGBColor[
              0.46888111877498084`, 0.5796978409320405, 0.951331185719549], 
             UndirectedEdge[272, 317] -> 
             RGBColor[
              0.8519916278011412, 0.36132246904964216`, 0.1958811278335439], 
             UndirectedEdge[282, 441] -> 
             RGBColor[
              0.5288953957407483, 0.628333638126909, 0.9560796286709814], 
             UndirectedEdge[209, 423] -> 
             RGBColor[
              0.37687473184245884`, 0.48661428775252374`, 0.9464892509185017],
              UndirectedEdge[222, 333] -> 
             RGBColor[
              0.41068141899913524`, 0.5301333365139219, 0.9473892347606732], 
             UndirectedEdge[125, 455] -> 
             RGBColor[
              0.20630711262003382`, 0.3341722343630622, 0.9350602569084642], 
             UndirectedEdge[343, 433] -> 
             RGBColor[
              0.3091968798489231, 0.4407663035487692, 0.9409764153784905], 
             UndirectedEdge[29, 77] -> 
             RGBColor[
              0.5082190929851442, 0.6104476858288989, 0.9547558471761093], 
             UndirectedEdge[298, 353] -> 
             RGBColor[
              0.7706511770330843, 0.8213765109750578, 0.9776280646137345], 
             UndirectedEdge[65, 337] -> 
             RGBColor[
              0.9228377639355362, 0.92700213552959, 0.6922814441739551], 
             UndirectedEdge[93, 364] -> 
             RGBColor[
              0.2639259772143767, 0.39473331429873343`, 0.9383415660076406], 
             UndirectedEdge[170, 328] -> 
             RGBColor[
              0.3409967871765409, 0.4686604793300483, 0.9429898367152708], 
             UndirectedEdge[13, 244] -> 
             RGBColor[
              0.3195286449146627, 0.4500599078221664, 0.9416221233751105], 
             UndirectedEdge[114, 291] -> 
             RGBColor[
              0.577802812280651, 0.6679328507014297, 0.9600375327920143], 
             UndirectedEdge[198, 373] -> 
             RGBColor[
              0.28774746699468884`, 0.4197712104275283, 0.9396981646098933], 
             UndirectedEdge[54, 84] -> 
             RGBColor[
              0.23101754524273913`, 0.3601444657814439, 0.9364674794905181], 
             UndirectedEdge[1, 385] -> 
             RGBColor[
              0.2498185382943033, 0.379905501530447, 0.937538168231228], 
             UndirectedEdge[97, 294] -> 
             RGBColor[
              0.23502362506905988`, 0.3643551096790384, 0.936695619810163], 
             UndirectedEdge[83, 489] -> 
             RGBColor[
              0.9554216482771469, 0.9649073806371287, 0.9030373799764648], 
             UndirectedEdge[349, 359] -> 
             RGBColor[
              0.3995263663781553, 0.520471390602876, 0.94667844467169], 
             UndirectedEdge[47, 55] -> 
             RGBColor[
              0.22170565849658444`, 0.35035708240351526`, 0.9359371813160265],
              UndirectedEdge[166, 309] -> 
             RGBColor[
              0.9155755884315661, 0.6407588014939913, 0.33347870741883034`], 
             UndirectedEdge[196, 482] -> 
             RGBColor[
              0.3270903866194627, 0.45652473233228946`, 0.9421070549379097], 
             UndirectedEdge[114, 311] -> 
             RGBColor[
              0.6237676761079407, 0.7038409516692123, 0.9646188808522442], 
             UndirectedEdge[101, 169] -> 
             RGBColor[
              0.506787455963573, 0.6104719131227696, 0.9543153114385234], 
             UndirectedEdge[160, 353] -> 
             RGBColor[
              0.531072144514868, 0.6293500407838779, 0.9564584330755022], 
             UndirectedEdge[80, 329] -> 
             RGBColor[
              0.8360503988309712, 0.8723539542869803, 0.9841591349586778], 
             UndirectedEdge[130, 386] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[216, 238] -> 
             RGBColor[
              0.29301995095784455`, 0.42425818517520597`, 0.9400370439768699],
              UndirectedEdge[240, 382] -> 
             RGBColor[
              0.26942512488484194`, 0.40051326716649266`, 0.9386547343322136],
              UndirectedEdge[424, 470] -> 
             RGBColor[
              0.28803826967359597`, 0.4189813939860375, 0.9397548358601392], 
             UndirectedEdge[184, 225] -> 
             RGBColor[
              0.2656405828545585, 0.396535473538841, 0.9384392102623171], 
             UndirectedEdge[169, 274] -> 
             RGBColor[
              0.4777382226320348, 0.5868884368511786, 0.9520284493798168], 
             UndirectedEdge[345, 375] -> 
             RGBColor[
              0.8089633164388916, 0.8512244424146573, 0.9611785706908804], 
             UndirectedEdge[326, 434] -> 
             RGBColor[
              0.9331890448533395, 0.7583565146768234, 0.5065076494810187], 
             UndirectedEdge[59, 105] -> 
             RGBColor[
              0.2440481876886619, 0.3738404971825583, 0.9372095553007055], 
             UndirectedEdge[90, 306] -> 
             RGBColor[
              0.8611746456929213, 0.4612099603827511, 0.20582221997608346`], 
             UndirectedEdge[44, 466] -> 
             RGBColor[
              0.5000927113166715, 0.6050368178236056, 0.9537882766162615], 
             UndirectedEdge[88, 434] -> 
             RGBColor[
              0.9289063525023188, 0.7389098089590498, 0.5029340660049313], 
             UndirectedEdge[174, 356] -> 
             RGBColor[
              0.2679975194043914, 0.3990127632911238, 0.938573434312055], 
             UndirectedEdge[65, 88] -> 
             RGBColor[
              0.9260374771709088, 0.7249105779401631, 0.30422129427437533`], 
             UndirectedEdge[82, 195] -> 
             RGBColor[
              0.2642152742010554, 0.39503738377422104`, 0.9383580410430554], 
             UndirectedEdge[150, 413] -> 
             RGBColor[
              0.8976403406773998, 0.5446217555948332, 0.26051353065802335`], 
             UndirectedEdge[156, 307] -> 
             RGBColor[
              0.4685593666518582, 0.5794366280637215, 0.9513058562137999], 
             UndirectedEdge[245, 460] -> 
             RGBColor[
              0.23495456172986623`, 0.36428251973067727`, 0.936691686755166], 
             UndirectedEdge[101, 204] -> 
             RGBColor[
              0.5113628894889524, 0.6141864561796039, 0.9546755063260064], 
             UndirectedEdge[210, 428] -> 
             RGBColor[
              0.8331986050247592, 0.2561846027075905, 0.17942432770515804`], 
             UndirectedEdge[25, 76] -> 
             RGBColor[
              0.36235029179287925`, 0.48827134332094824`, 0.9443096180726283],
              UndirectedEdge[130, 421] -> 
             RGBColor[
              0.17899180289058533`, 0.3054621119467458, 0.9335046904287516], 
             UndirectedEdge[79, 493] -> 
             RGBColor[
              0.9937029879453217, 0.9889396528776512, 0.5559872823811043], 
             UndirectedEdge[194, 490] -> 
             RGBColor[
              0.9885348242076832, 0.9895268694153684, 0.8396711640099095], 
             UndirectedEdge[214, 347] -> 
             RGBColor[
              0.1893670574265447, 0.316367162293171, 0.9340955458257609], 
             UndirectedEdge[41, 202] -> 
             RGBColor[
              0.2357918679274276, 0.3651625816325934, 0.9367393701044336], 
             UndirectedEdge[85, 97] -> 
             RGBColor[
              0.22297503114412753`, 0.3516912735389574, 0.9360094702104356], 
             UndirectedEdge[31, 114] -> 
             RGBColor[
              0.47685837337515014`, 0.5861665400670314, 0.9519612830883075], 
             UndirectedEdge[247, 425] -> 
             RGBColor[
              0.4351771155351065, 0.550218204604259, 0.9492628740426365], 
             UndirectedEdge[35, 281] -> 
             RGBColor[
              0.2416405448941051, 0.37130991195210916`, 0.9370724436053437], 
             UndirectedEdge[157, 288] -> 
             RGBColor[
              0.2793047597177943, 0.4108973897809534, 0.9392173649203402], 
             UndirectedEdge[208, 427] -> 
             RGBColor[
              0.3008093263098471, 0.4322636714318231, 0.9404872881507658], 
             UndirectedEdge[154, 313] -> 
             RGBColor[
              0.2882495492104231, 0.42022540866860447`, 0.9397294494499471], 
             UndirectedEdge[189, 364] -> 
             RGBColor[
              0.25917101959394173`, 0.3897355523579304, 0.9380707782054862], 
             UndirectedEdge[314, 373] -> 
             RGBColor[
              0.3118454823562334, 0.44312769697598026`, 0.9411427175470836], 
             UndirectedEdge[156, 232] -> 
             RGBColor[
              0.4117533959329014, 0.5306819361106889, 0.9475625057353367], 
             UndirectedEdge[321, 383] -> 
             RGBColor[
              0.3310589867507921, 0.46116838764021345`, 0.942315763785161], 
             UndirectedEdge[15, 323] -> 
             RGBColor[
              0.2367917298527569, 0.36621349991102203`, 0.936796310761918], 
             UndirectedEdge[225, 235] -> 
             RGBColor[
              0.31564550837904015`, 0.44462855110700683`, 0.9414504121909557],
              UndirectedEdge[170, 265] -> 
             RGBColor[
              0.3088475371272851, 0.4408144148056739, 0.9409413149305978], 
             UndirectedEdge[102, 485] -> 
             RGBColor[
              0.2622693737921402, 0.3929921190672394, 0.9382472248934693], 
             UndirectedEdge[342, 463] -> 
             RGBColor[
              0.2635422521882549, 0.3943299949667075, 0.9383197134350733], 
             UndirectedEdge[70, 147] -> 
             RGBColor[
              0.2548716664665323, 0.3852166596262904, 0.9378259364052033], 
             UndirectedEdge[162, 381] -> 
             RGBColor[
              0.515668109442376, 0.6176816276857418, 0.9550144290112803], 
             UndirectedEdge[212, 299] -> 
             RGBColor[
              0.21384131413680724`, 0.3420911578531577, 0.9354893185389921], 
             UndirectedEdge[92, 361] -> 
             RGBColor[
              0.6266695180780231, 0.7077693478258749, 0.9637721633771799], 
             UndirectedEdge[82, 184] -> 
             RGBColor[
              0.2576552479933815, 0.38814238030027126`, 0.9379844572552174], 
             UndirectedEdge[232, 376] -> 
             RGBColor[
              0.3178263634409366, 0.4469988106247622, 0.9415717511395277], 
             UndirectedEdge[293, 298] -> 
             RGBColor[
              0.9279560632534805, 0.9449120378208546, 0.9763848153450053], 
             UndirectedEdge[225, 249] -> 
             RGBColor[
              0.28189858083211217`, 0.41362366022985875`, 0.9393650791955862],
              UndirectedEdge[19, 34] -> 
             RGBColor[
              0.5517387974757788, 0.6469654371972362, 0.9578540457045537], 
             UndirectedEdge[338, 390] -> 
             RGBColor[
              0.3104293975603457, 0.44256111009978116`, 0.9410283217053288], 
             UndirectedEdge[82, 342] -> 
             RGBColor[
              0.2591328832418887, 0.3896954686339382, 0.9380686063966545], 
             UndirectedEdge[54, 374] -> 
             RGBColor[
              0.24022555960590497`, 0.3698226726989618, 0.9369918622864639], 
             UndirectedEdge[196, 350] -> 
             RGBColor[
              0.3289346637950721, 0.4581221525257362, 0.9422245706487093], 
             UndirectedEdge[19, 44] -> 
             RGBColor[
              0.5282008880554978, 0.6278563019591167, 0.956001055252786], 
             UndirectedEdge[85, 408] -> 
             RGBColor[
              0.21836004410720744`, 0.3468406295560761, 0.9357466535259444], 
             UndirectedEdge[57, 255] -> 
             RGBColor[
              0.499414256811589, 0.6029727505529885, 0.9541529864670097], 
             UndirectedEdge[106, 269] -> 
             RGBColor[
              0.48339733950661234`, 0.5913638720070653, 0.9525068056899508], 
             UndirectedEdge[382, 416] -> 
             RGBColor[
              0.2718791903645599, 0.40309264558241453`, 0.938794489730819], 
             UndirectedEdge[246, 392] -> 
             RGBColor[
              0.3001114005223494, 0.4327664884837622, 0.940402272333493], 
             UndirectedEdge[350, 414] -> 
             RGBColor[
              0.31841398035212815`, 0.44706424717734483`, 0.94162543329059], 
             UndirectedEdge[146, 211] -> 
             RGBColor[
              0.2444868180291041, 0.37430152548113294`, 0.9372345346496982], 
             UndirectedEdge[71, 487] -> 
             RGBColor[
              0.6676064579243342, 0.7392945350984725, 0.9681635028375868], 
             UndirectedEdge[415, 485] -> 
             RGBColor[
              0.2675069384795197, 0.39849713163445644`, 0.9385454964541331], 
             UndirectedEdge[238, 433] -> 
             RGBColor[
              0.32283008594645624`, 0.45404092736007795`, 0.94179142550244], 
             UndirectedEdge[141, 429] -> 
             RGBColor[
              0.30159042381675216`, 0.434243660437526, 0.9404893336110074], 
             UndirectedEdge[406, 493] -> 
             RGBColor[
              0.9920978208950986, 0.9843432363296774, 0.4801786397760631], 
             UndirectedEdge[257, 357] -> 
             RGBColor[
              0.8829978584207956, 0.5607626793064351, 0.22403944465155362`], 
             UndirectedEdge[311, 488] -> 
             RGBColor[
              0.7581105843852092, 0.8109610174663499, 0.9765250361714609], 
             UndirectedEdge[258, 381] -> 
             RGBColor[
              0.4713636222770108, 0.5795438974068458, 0.952126015828245], 
             UndirectedEdge[168, 200] -> 
             RGBColor[
              0.9058101136750496, 0.6632964389017137, 0.24302016366679569`], 
             UndirectedEdge[16, 254] -> 
             RGBColor[
              0.3201901654275895, 0.4450745627173458, 0.941867792234375], 
             UndirectedEdge[325, 347] -> 
             RGBColor[
              0.1789719601845752, 0.3054412560046289, 0.9335035604159989], 
             UndirectedEdge[154, 478] -> 
             RGBColor[
              0.28779157321631055`, 0.419744046861437, 0.9397033683945971], 
             UndirectedEdge[302, 386] -> 
             RGBColor[
              0.18453817917078433`, 0.311291705077802, 0.9338205483527805], 
             UndirectedEdge[330, 414] -> 
             RGBColor[
              0.2905537605670515, 0.4227208029013707, 0.9398579788773], 
             UndirectedEdge[50, 334] -> 
             RGBColor[
              0.42187105269828507`, 0.539825234816783, 0.9481022283253784], 
             UndirectedEdge[72, 187] -> 
             RGBColor[
              0.2593062768219157, 0.38987771628033463`, 0.9380784809045242], 
             UndirectedEdge[14, 149] -> 
             RGBColor[
              0.33030872638618497`, 0.46033332920658265`, 0.9422747396921978],
              UndirectedEdge[113, 214] -> 
             RGBColor[
              0.18949968777431325`, 0.3165065651979255, 0.9341030989278573], 
             UndirectedEdge[63, 149] -> 
             RGBColor[
              0.3866051837093468, 0.5092797116126782, 0.9458551183377868], 
             UndirectedEdge[245, 445] -> 
             RGBColor[
              0.22560109399094413`, 0.3544514320929628, 0.93615902060465], 
             UndirectedEdge[207, 336] -> 
             RGBColor[
              0.2196507706490151, 0.34819726498830533`, 0.9358201584930417], 
             UndirectedEdge[264, 394] -> 
             RGBColor[
              0.23171433520063273`, 0.36087683620622507`, 0.9365071606478118],
              UndirectedEdge[255, 370] -> 
             RGBColor[
              0.4945144317215364, 0.598994851810279, 0.9537672542872702], 
             UndirectedEdge[330, 482] -> 
             RGBColor[
              0.33246549585026375`, 0.4621743129354704, 0.9424131594568423], 
             UndirectedEdge[383, 482] -> 
             RGBColor[
              0.34371197944189347`, 0.47212777395134153`, 0.9431220012908359],
              UndirectedEdge[358, 407] -> 
             RGBColor[
              0.21999227740316346`, 0.34855621023969413`, 0.9358396067974764],
              UndirectedEdge[28, 142] -> 
             RGBColor[
              0.8321901895218196, 0.869251634409216, 0.9575296911592543], 
             UndirectedEdge[348, 375] -> 
             RGBColor[
              0.959056524042907, 0.9223909347161948, 0.6272014222552931], 
             UndirectedEdge[41, 295] -> 
             RGBColor[
              0.23105727915165333`, 0.3601862286389881, 0.9364697422778497], 
             UndirectedEdge[83, 345] -> 
             RGBColor[
              0.7902354483667869, 0.8368716246944006, 0.9795108205407682], 
             UndirectedEdge[140, 425] -> 
             RGBColor[
              0.4374884569477172, 0.5520946556877604, 0.9494448313053598], 
             UndirectedEdge[160, 441] -> 
             RGBColor[
              0.4363070753078513, 0.5523289920255958, 0.9490220789207864], 
             UndirectedEdge[66, 394] -> 
             RGBColor[
              0.24596177604056546`, 0.3758517998689181, 0.937318531326446], 
             UndirectedEdge[201, 271] -> 
             RGBColor[
              0.2801320470703391, 0.4117669212415258, 0.9392644777112058], 
             UndirectedEdge[192, 470] -> 
             RGBColor[
              0.255048373399578, 0.3854023898167881, 0.9378359996036256], 
             UndirectedEdge[255, 379] -> 
             RGBColor[
              0.35344236256380235`, 0.4805557427482631, 0.943742012699124], 
             UndirectedEdge[82, 440] -> 
             RGBColor[
              0.26997623108034263`, 0.40109251472011487`, 0.9386861190147588],
              UndirectedEdge[43, 362] -> 
             RGBColor[
              0.34080467652755875`, 0.4681674552795022, 0.9429895550260083], 
             UndirectedEdge[127, 302] -> 
             RGBColor[
              0.2080645848230672, 0.3360194490786239, 0.9351603423504797], 
             UndirectedEdge[137, 358] -> 
             RGBColor[
              0.22285337720406, 0.3515634075346411, 0.9360025421985196], 
             UndirectedEdge[238, 328] -> 
             RGBColor[
              0.35273346300045894`, 0.47994172957682313`, 0.943696842245803], 
             UndirectedEdge[185, 196] -> 
             RGBColor[
              0.2898220421197416, 0.4219517204196188, 0.9398163085942062], 
             UndirectedEdge[114, 208] -> 
             RGBColor[
              0.41139850447614446`, 0.5294684917353877, 0.9477902381259522], 
             UndirectedEdge[249, 424] -> 
             RGBColor[
              0.30507115038591015`, 0.4368840315616916, 0.9407248332188166], 
             UndirectedEdge[21, 65] -> 
             RGBColor[
              0.9831762967586118, 0.9549118399527363, 0.38914351910732653`], 
             UndirectedEdge[369, 466] -> 
             RGBColor[
              0.46172779849419876`, 0.5729843638939052, 0.9510184053391775], 
             UndirectedEdge[246, 459] -> 
             RGBColor[
              0.3423837632254584, 0.4696344421074833, 0.9430865385917233], 
             UndirectedEdge[46, 317] -> 
             RGBColor[
              0.9005275853462438, 0.6373329329271229, 0.23851003583391922`], 
             UndirectedEdge[66, 305] -> 
             RGBColor[
              0.25719647261268064`, 0.38766017828711546`, 0.9379583306759838],
              UndirectedEdge[56, 243] -> 
             RGBColor[
              0.8379898589381207, 0.2930122798265395, 0.18401243786354038`], 
             UndirectedEdge[281, 288] -> 
             RGBColor[
              0.2504872858476244, 0.38060839761003135`, 0.9375762524150663], 
             UndirectedEdge[81, 329] -> 
             RGBColor[
              0.8530880154845231, 0.8856932433627962, 0.9858494905492173], 
             UndirectedEdge[57, 140] -> 
             RGBColor[
              0.550438526060826, 0.6459098182860178, 0.9577516835757175], 
             UndirectedEdge[184, 440] -> 
             RGBColor[
              0.26935285588816305`, 0.4004373078688641, 0.9386506187197652], 
             UndirectedEdge[422, 446] -> 
             RGBColor[
              0.2310816388212659, 0.36021183219624314`, 0.9364711295249972], 
             UndirectedEdge[232, 307] -> 
             RGBColor[
              0.4130035971526026, 0.5316969057817654, 0.9476609261549895], 
             UndirectedEdge[90, 261] -> 
             RGBColor[
              0.8723782969076955, 0.5133814777114375, 0.21522166145663085`], 
             UndirectedEdge[118, 304] -> 
             RGBColor[
              0.3318360758338559, 0.46184146314633034`, 0.9423652792143808], 
             UndirectedEdge[427, 460] -> 
             RGBColor[
              0.2639231904685617, 0.39473038525219195`, 0.938341407306589], 
             UndirectedEdge[299, 300] -> 
             RGBColor[
              0.21756201185689822`, 0.346001847062834, 0.9357012067698722], 
             UndirectedEdge[106, 425] -> 
             RGBColor[
              0.4465990938801403, 0.559491081179018, 0.9501620540180429], 
             UndirectedEdge[428, 495] -> 
             RGBColor[
              0.8362679836981737, 0.2797771922017657, 0.1823635681891872], 
             UndirectedEdge[230, 365] -> 
             RGBColor[
              0.22042634378562792`, 0.3490124415290624, 0.9358643262358141], 
             UndirectedEdge[224, 463] -> 
             RGBColor[
              0.2830318265857735, 0.4148147733688876, 0.9394296158647704], 
             UndirectedEdge[251, 382] -> 
             RGBColor[
              0.27038494943162866`, 0.40152210362155666`, 0.9387093949202199],
              UndirectedEdge[81, 278] -> 
             RGBColor[
              0.8859909437525565, 0.9116025564457284, 0.9776647627909368], 
             UndirectedEdge[42, 294] -> 
             RGBColor[
              0.23539350574473433`, 0.36474387772096156`, 0.9367166839674533],
              UndirectedEdge[8, 419] -> 
             RGBColor[
              0.5664920822105015, 0.6589428183727875, 0.9590154783219338], 
             UndirectedEdge[159, 164] -> 
             RGBColor[
              0.819137437150352, 0.14810430478184575`, 0.1659593374688081], 
             UndirectedEdge[346, 404] -> 
             RGBColor[
              0.21566548218765702`, 0.3440084741335353, 0.9355932022108733], 
             UndirectedEdge[7, 194] -> 
             RGBColor[
              0.9125990982944516, 0.9314492168831301, 0.9288011319761822], 
             UndirectedEdge[268, 353] -> 
             RGBColor[
              0.5246586597567469, 0.6237950026375101, 0.9560497714979366], 
             UndirectedEdge[51, 423] -> 
             RGBColor[
              0.18337644614132015`, 0.31007065000570677`, 0.9337543893753826],
              UndirectedEdge[14, 322] -> 
             RGBColor[
              0.2829806146027809, 0.4147609463277351, 0.9394266994181002], 
             UndirectedEdge[109, 458] -> 
             RGBColor[
              0.24222963005763265`, 0.3719290778091332, 0.9371059911339332], 
             UndirectedEdge[217, 384] -> 
             RGBColor[
              0.30177027996931804`, 0.4334954768697517, 0.9405338925067932], 
             UndirectedEdge[202, 485] -> 
             RGBColor[
              0.2435291255920976, 0.37329493000863156`, 0.9371799954821897], 
             UndirectedEdge[125, 457] -> 
             RGBColor[
              0.21513132866869134`, 0.3434470449178132, 0.9355627829581774], 
             UndirectedEdge[454, 475] -> 
             RGBColor[
              0.8694429086173421, 0.4695370183739893, 0.21157738923531183`], 
             UndirectedEdge[30, 378] -> 
             RGBColor[
              0.2755078252460146, 0.406906570911563, 0.9390011351192336], 
             UndirectedEdge[445, 460] -> 
             RGBColor[
              0.23899278558713355`, 0.3685269490428458, 0.9369216576298206], 
             UndirectedEdge[173, 461] -> 
             RGBColor[
              0.9645092309315171, 0.9729899937684735, 0.9422009085196323], 
             UndirectedEdge[23, 41] -> 
             RGBColor[
              0.22751409159888136`, 0.35646211386995863`, 0.9362679629883957],
              UndirectedEdge[111, 444] -> 
             RGBColor[
              0.272192144891436, 0.40342158063262434`, 0.9388123120281499], 
             UndirectedEdge[139, 360] -> 
             RGBColor[
              0.5717007512056378, 0.6631714505109032, 0.9594255238252141], 
             UndirectedEdge[53, 432] -> 
             RGBColor[
              0.9375683877182548, 0.9272177056729635, 0.6767239867532486], 
             UndirectedEdge[184, 260] -> 
             RGBColor[
              0.2713041510776424, 0.40248824283226764`, 0.9387617420941234], 
             UndirectedEdge[244, 379] -> 
             RGBColor[
              0.3258701140726008, 0.45667404692668806`, 0.9419851334064466], 
             UndirectedEdge[14, 187] -> 
             RGBColor[
              0.28568538812664784`, 0.41760383479386565`, 0.9395807322689307],
              UndirectedEdge[133, 332] -> 
             RGBColor[
              0.3736828594731001, 0.4980870438541423, 0.9450317192642157], 
             UndirectedEdge[424, 440] -> 
             RGBColor[
              0.30113413549531765`, 0.4327459792905174, 0.940500626045089], 
             UndirectedEdge[381, 419] -> 
             RGBColor[
              0.5409976687744238, 0.6382453050351424, 0.9570084647071322], 
             UndirectedEdge[39, 368] -> 
             RGBColor[
              0.5158816187650146, 0.6166272342584453, 0.9553704626805029], 
             UndirectedEdge[40, 208] -> 
             RGBColor[
              0.3541593410951509, 0.4811767535157284, 0.9437876979371422], 
             UndirectedEdge[436, 462] -> 
             RGBColor[
              0.46839908955768095`, 0.5793065078982675, 0.951293238613832], 
             UndirectedEdge[103, 188] -> 
             RGBColor[
              0.408816425381794, 0.5277838356822806, 0.9474732432839563], 
             UndirectedEdge[313, 411] -> 
             RGBColor[
              0.2532739296678089, 0.38353733694846814`, 0.9377349476581557], 
             UndirectedEdge[181, 344] -> 
             RGBColor[
              0.4422200885925819, 0.5571674842764482, 0.9494770619548758], 
             UndirectedEdge[5, 485] -> 
             RGBColor[
              0.24330426601765148`, 0.37305858833896816`, 0.9371671900620748],
              UndirectedEdge[371, 429] -> 
             RGBColor[
              0.3282709430209225, 0.4573529851702918, 0.9421893927020404], 
             UndirectedEdge[426, 448] -> 
             RGBColor[
              0.7190568535901429, 0.7797176017404024, 0.9733043071059779], 
             UndirectedEdge[32, 403] -> 
             RGBColor[
              0.73231135392298, 0.7900531713799142, 0.9748369526254256], 
             UndirectedEdge[115, 484] -> 
             RGBColor[
              0.9570300393594782, 0.9635915325846716, 0.7300132516870645], 
             UndirectedEdge[36, 251] -> 
             RGBColor[
              0.25646724614478844`, 0.3868937150337323, 0.9379168023074314], 
             UndirectedEdge[243, 454] -> 
             RGBColor[
              0.869594267772993, 0.47070043117032717`, 0.21172233093369885`], 
             UndirectedEdge[106, 139] -> 
             RGBColor[
              0.5409452590449157, 0.6382027564556965, 0.9570043388212421], 
             UndirectedEdge[220, 499] -> 
             RGBColor[
              0.2998159216660946, 0.42966675719263536`, 0.9404875702170554], 
             UndirectedEdge[359, 419] -> 
             RGBColor[
              0.44907089909255904`, 0.561772271120652, 0.9502808074967835], 
             UndirectedEdge[115, 297] -> 
             RGBColor[
              0.7202662947001824, 0.7803304830864486, 0.9738242280167566], 
             UndirectedEdge[155, 235] -> 
             RGBColor[
              0.4614654223098702, 0.5710633178486462, 0.9514696859030422], 
             UndirectedEdge[98, 261] -> 
             RGBColor[
              0.9376107771767181, 0.7700729496416561, 0.47213960027127755`], 
             UndirectedEdge[386, 421] -> 
             RGBColor[
              0.17899180289058533`, 0.3054621119467458, 0.9335046904287516], 
             UndirectedEdge[37, 58] -> 
             RGBColor[
              0.31037597127891847`, 0.44296664665046, 0.9410083743899482], 
             UndirectedEdge[71, 194] -> 
             RGBColor[
              0.8711488139703549, 0.898916809896938, 0.9247098602219754], 
             UndirectedEdge[47, 339] -> 
             RGBColor[
              0.22181216919966315`, 0.3504690319056196, 0.9359432469429985], 
             UndirectedEdge[108, 410] -> 
             RGBColor[
              0.32438785376155105`, 0.4532049421182389, 0.9419706976299311], 
             UndirectedEdge[193, 196] -> 
             RGBColor[
              0.29175552637074975`, 0.4239839349574104, 0.9399264176619675], 
             UndirectedEdge[131, 171] -> 
             RGBColor[
              0.26267563753313167`, 0.39341912801763035`, 0.9382703610125054],
              UndirectedEdge[203, 258] -> 
             RGBColor[
              0.45399453907585874`, 0.5654428931958693, 0.950758657973602], 
             UndirectedEdge[164, 428] -> 
             RGBColor[
              0.8239291026561835, 0.1849351455808791, 0.17054784176860438`], 
             UndirectedEdge[143, 325] -> 
             RGBColor[
              0.17897196085846667`, 0.30544125671293154`, 0.9335035604543761],
              UndirectedEdge[101, 498] -> 
             RGBColor[
              0.491361119566665, 0.5979481182872246, 0.9531008937288266], 
             UndirectedEdge[35, 391] -> 
             RGBColor[
              0.23974982774210207`, 0.3693226483469626, 0.9369647700606025], 
             UndirectedEdge[8, 221] -> 
             RGBColor[
              0.5784518548396522, 0.6686523005747489, 0.9599569954333912], 
             UndirectedEdge[240, 251] -> 
             RGBColor[
              0.25758537828186423`, 0.38806894280347104`, 0.9379804782785095],
              UndirectedEdge[464, 485] -> 
             RGBColor[
              0.24593397699878092`, 0.3758225813134415, 0.9373169482121415], 
             UndirectedEdge[104, 452] -> 
             RGBColor[
              0.2352635459876256, 0.36460728177631574`, 0.9367092829515442], 
             UndirectedEdge[121, 475] -> 
             RGBColor[
              0.8332346662535209, 0.256461785113985, 0.17945885997854572`], 
             UndirectedEdge[168, 315] -> 
             RGBColor[
              0.5481459181329882, 0.49816507299275914`, 0.5904774154442385], 
             UndirectedEdge[65, 320] -> 
             RGBColor[
              0.9870336626851595, 0.9760932232050978, 0.618291834936235], 
             UndirectedEdge[323, 452] -> 
             RGBColor[
              0.23164904535488023`, 0.3608082124387239, 0.9365034424876839], 
             UndirectedEdge[72, 322] -> 
             RGBColor[
              0.25660150329804876`, 0.38703482781420406`, 0.9379244480536938],
              UndirectedEdge[60, 327] -> 
             RGBColor[
              0.27488937913222444`, 0.40625654483422113`, 0.9389659155279624],
              UndirectedEdge[1, 135] -> 
             RGBColor[
              0.2583961289533292, 0.38892109316374235`, 0.9380266493298512], 
             UndirectedEdge[420, 439] -> 
             RGBColor[
              0.9147776569049322, 0.9340333582536569, 0.9622797424419812], 
             UndirectedEdge[134, 367] -> 
             RGBColor[
              0.23152572380893705`, 0.3606785936749, 0.9364964195080803], 
             UndirectedEdge[119, 345] -> 
             RGBColor[
              0.8251862844410536, 0.8622510331677843, 0.8856898202805965], 
             UndirectedEdge[64, 366] -> 
             RGBColor[
              0.27642037277284975`, 0.4078657162211217, 0.9390531033508938], 
             UndirectedEdge[86, 90] -> 
             RGBColor[
              0.8899814344584336, 0.5901544331035902, 0.2297467504579272], 
             UndirectedEdge[81, 426] -> 
             RGBColor[
              0.8468962698264015, 0.8807561134454687, 0.9852589163209091], 
             UndirectedEdge[70, 265] -> 
             RGBColor[
              0.28963233444531233`, 0.42061801847270397`, 0.9398470375642044],
              UndirectedEdge[245, 438] -> 
             RGBColor[
              0.22151371355788788`, 0.3501553361029332, 0.9359262503357249], 
             UndirectedEdge[121, 259] -> 
             RGBColor[
              0.8446533203330481, 0.33882677308300735`, 0.1901817771182239], 
             UndirectedEdge[74, 105] -> 
             RGBColor[
              0.2638196417670582, 0.3946215490015449, 0.938335510361225], 
             UndirectedEdge[358, 430] -> 
             RGBColor[
              0.23268261924121364`, 0.3618945641256297, 0.936562302991475], 
             UndirectedEdge[43, 316] -> 
             RGBColor[
              0.2718214258604257, 0.4030319314260883, 0.9387912001277635], 
             UndirectedEdge[162, 203] -> 
             RGBColor[
              0.4982990262412239, 0.6035806234747654, 0.9536470711566374], 
             UndirectedEdge[226, 236] -> 
             RGBColor[
              0.23337407460187973`, 0.3626213275504917, 0.9366016803513484], 
             UndirectedEdge[110, 340] -> 
             RGBColor[
              0.3045749314378675, 0.43480548891742876`, 0.9407535831342266], 
             UndirectedEdge[145, 407] -> 
             RGBColor[
              0.2175082544444818, 0.34594534461396753`, 0.9356981453647621], 
             UndirectedEdge[258, 289] -> 
             RGBColor[
              0.4063967473847854, 0.5264221693154291, 0.9471162192741931], 
             UndirectedEdge[13, 334] -> 
             RGBColor[
              0.3497101697631252, 0.47620162767835794`, 0.94354526344998], 
             UndirectedEdge[300, 389] -> 
             RGBColor[
              0.2222287148930997, 0.35090684783994386`, 0.9359669686040155], 
             UndirectedEdge[57, 363] -> 
             RGBColor[
              0.5030271726289528, 0.6061020766435601, 0.9543831982681161], 
             UndirectedEdge[305, 427] -> 
             RGBColor[
              0.26530600013852146`, 0.3961838058905166, 0.9384201562716097], 
             UndirectedEdge[277, 419] -> 
             RGBColor[
              0.6419960336426249, 0.718265092425402, 0.9663099050077802], 
             UndirectedEdge[40, 349] -> 
             RGBColor[
              0.3999008136180363, 0.5207957179817955, 0.9467023041187045], 
             UndirectedEdge[28, 241] -> 
             RGBColor[
              0.8351691071867402, 0.8715787875296648, 0.9578266018325254], 
             UndirectedEdge[164, 396] -> 
             RGBColor[
              0.9055353853140414, 0.5621560872497313, 0.3516608883245811], 
             UndirectedEdge[111, 284] -> 
             RGBColor[
              0.2590919383322233, 0.3896524329378227, 0.9380662746446216], 
             UndirectedEdge[25, 343] -> 
             RGBColor[
              0.3031313951145783, 0.4355126855320067, 0.9405899280547156], 
             UndirectedEdge[84, 131] -> 
             RGBColor[
              0.24846167161057395`, 0.3784793486155308, 0.9374608966808939], 
             UndirectedEdge[169, 244] -> 
             RGBColor[
              0.4175916065853016, 0.5350481346501237, 0.9481253168239769], 
             UndirectedEdge[219, 363] -> 
             RGBColor[
              0.4655401284489993, 0.5756684054061787, 0.9514320808307029], 
             UndirectedEdge[400, 415] -> 
             RGBColor[
              0.2914672574254832, 0.4236809460186285, 0.9399100011719903], 
             UndirectedEdge[248, 286] -> 
             RGBColor[
              0.23281996068137648`, 0.36203891868719107`, 0.9365701243833138],
              UndirectedEdge[136, 484] -> 
             RGBColor[
              0.980926180317411, 0.981787940062676, 0.7025545645628573], 
             UndirectedEdge[74, 263] -> 
             RGBColor[
              0.27756733242056764`, 0.40907124353231517`, 0.9391184210060566],
              UndirectedEdge[69, 142] -> 
             RGBColor[
              0.8044934065793106, 0.8479188521576653, 0.9809561216743297], 
             UndirectedEdge[109, 409] -> 
             RGBColor[
              0.24775783308986035`, 0.3777395697043211, 0.9374208141183751], 
             UndirectedEdge[101, 219] -> 
             RGBColor[
              0.5235508135187052, 0.6240811619666777, 0.9556349843514654], 
             UndirectedEdge[380, 390] -> 
             RGBColor[
              0.2868022644003798, 0.4187777425716037, 0.9396443367204493], 
             UndirectedEdge[53, 293] -> 
             RGBColor[
              0.9653923096103165, 0.9489247911355639, 0.6627722008261114], 
             UndirectedEdge[221, 258] -> 
             RGBColor[
              0.45501626161494246`, 0.5662723735811732, 0.9508390917145717], 
             UndirectedEdge[235, 424] -> 
             RGBColor[
              0.3388180779328382, 0.46788892243883967`, 0.9428101662141861], 
             UndirectedEdge[367, 457] -> 
             RGBColor[
              0.22571706608911693`, 0.3545733261211982, 0.9361656250440755], 
             UndirectedEdge[58, 220] -> 
             RGBColor[
              0.32701247471585293`, 0.45766350229915764`, 0.9420579236164848],
              UndirectedEdge[334, 379] -> 
             RGBColor[
              0.3560516389210633, 0.4828157667828796, 0.9439082734813162], 
             UndirectedEdge[14, 163] -> 
             RGBColor[
              0.2868674954285888, 0.4188463045181374, 0.9396480515310051], 
             UndirectedEdge[284, 442] -> 
             RGBColor[
              0.26451897986036277`, 0.3953565976782041, 0.9383753366310607], 
             UndirectedEdge[130, 302] -> 
             RGBColor[
              0.18453817917078433`, 0.311291705077802, 0.9338205483527805], 
             UndirectedEdge[65, 428] -> 
             RGBColor[
              0.9078991618741388, 0.5983968558388272, 0.2873573629313444], 
             UndirectedEdge[388, 487] -> 
             RGBColor[
              0.7628017392959624, 0.8144116714200249, 0.9680174393113103], 
             UndirectedEdge[456, 458] -> 
             RGBColor[
              0.22707889219219896`, 0.35600469170029936`, 0.9362431790260048],
              UndirectedEdge[281, 465] -> 
             RGBColor[
              0.26376712193927254`, 0.39456634733259277`, 0.9383325194347287],
              UndirectedEdge[166, 428] -> 
             RGBColor[
              0.8342269539589475, 0.26408894324113896`, 0.18040907580589088`],
              UndirectedEdge[92, 128] -> 
             RGBColor[
              0.5519404005403256, 0.6471291076471498, 0.9578699166362912], 
             UndirectedEdge[120, 457] -> 
             RGBColor[
              0.21450528797873675`, 0.3427890364593986, 0.9355271308670288], 
             UndirectedEdge[79, 329] -> 
             RGBColor[
              0.9381932995999778, 0.9492001435332333, 0.7791661244013025], 
             UndirectedEdge[105, 195] -> 
             RGBColor[
              0.2580285978828387, 0.38853479470584096`, 0.9380057189791005], 
             UndirectedEdge[98, 377] -> 
             RGBColor[
              0.9881699242791049, 0.9888223570121889, 0.8197885510745015], 
             UndirectedEdge[21, 309] -> 
             RGBColor[
              0.9869592653755547, 0.967346961753188, 0.4315364838739727], 
             UndirectedEdge[93, 322] -> 
             RGBColor[
              0.26425191426448674`, 0.3950758948040016, 0.9383601276404636], 
             UndirectedEdge[8, 115] -> 
             RGBColor[
              0.7707310045144475, 0.8213000079229384, 0.9777969948316587], 
             UndirectedEdge[54, 131] -> 
             RGBColor[
              0.24616492351091418`, 0.3760653207405481, 0.9373301002743527], 
             UndirectedEdge[186, 212] -> 
             RGBColor[
              0.22711333090057176`, 0.3560408889663394, 0.9362451402594992], 
             UndirectedEdge[252, 467] -> 
             RGBColor[
              0.7213175895970523, 0.7822180503007243, 0.9728578543010624], 
             UndirectedEdge[244, 378] -> 
             RGBColor[
              0.3127627275114677, 0.4429484996474682, 0.9412368143882763], 
             UndirectedEdge[55, 339] -> 
             RGBColor[
              0.21158417509033906`, 0.33971876160443837`, 0.9353607778094337],
              UndirectedEdge[69, 490] -> 
             RGBColor[
              0.9500080335378767, 0.9605032008441318, 0.8987210231001681], 
             UndirectedEdge[299, 451] -> 
             RGBColor[
              0.21030609728277713`, 0.3383754207938774, 0.9352879931690398], 
             UndirectedEdge[146, 464] -> 
             RGBColor[
              0.25089999678857744`, 0.38104218297635795`, 0.9375997556926023],
              UndirectedEdge[199, 220] -> 
             RGBColor[
              0.3408785418830542, 0.4696735927505875, 0.9429414571550971], 
             UndirectedEdge[345, 426] -> 
             RGBColor[
              0.7649497936964772, 0.8167095300211071, 0.9770990522255436], 
             UndirectedEdge[66, 472] -> 
             RGBColor[
              0.29586389462338253`, 0.42648062461240877`, 0.9402270759441249],
              UndirectedEdge[40, 114] -> 
             RGBColor[
              0.443439320562669, 0.5572206362112937, 0.9498318505944043], 
             UndirectedEdge[248, 294] -> 
             RGBColor[
              0.240426199543799, 0.37003355799499527`, 0.9370032884341067], 
             UndirectedEdge[304, 483] -> 
             RGBColor[
              0.3176066092257016, 0.44839817992769826`, 0.941499541548237], 
             UndirectedEdge[9, 425] -> 
             RGBColor[
              0.47524326414852586`, 0.5827457090080587, 0.9524170280286233], 
             UndirectedEdge[290, 384] -> 
             RGBColor[
              0.2851530200769201, 0.4170442822195179, 0.9395504146960666], 
             UndirectedEdge[294, 358] -> 
             RGBColor[
              0.23196947764628847`, 0.36114500709357467`, 0.9365216906326425],
              UndirectedEdge[148, 342] -> 
             RGBColor[
              0.2498214928286487, 0.3799086069333723, 0.9375383364875882], 
             UndirectedEdge[178, 420] -> 
             RGBColor[
              0.9801637329335828, 0.9834819259202605, 0.8627171585529716], 
             UndirectedEdge[193, 354] -> 
             RGBColor[
              0.3247877807995152, 0.4538010668360344, 0.941987036861071], 
             UndirectedEdge[194, 228] -> 
             RGBColor[
              0.9897986964683487, 0.9881510016226367, 0.6807237889593197], 
             UndirectedEdge[326, 491] -> 
             RGBColor[
              0.9346684716417725, 0.7580015966571071, 0.4117209054738351], 
             UndirectedEdge[324, 481] -> 
             RGBColor[
              0.3439470735768655, 0.47233140067487944`, 0.9431369812812307], 
             UndirectedEdge[94, 213] -> 
             RGBColor[
              0.9298124883323949, 0.8120876909328425, 0.6010637208876998], 
             UndirectedEdge[92, 175] -> 
             RGBColor[
              0.7824339265203888, 0.8300343229197356, 0.9610969915433571], 
             UndirectedEdge[254, 401] -> 
             RGBColor[
              0.50497531356463, 0.5944255881948143, 0.9574168801184721], 
             UndirectedEdge[161, 491] -> 
             RGBColor[
              0.992246695040947, 0.9844848921088973, 0.5114139987289448], 
             UndirectedEdge[172, 303] -> 
             RGBColor[
              0.32845548787730483`, 0.4585909264869045, 0.9421616772940785], 
             UndirectedEdge[57, 274] -> 
             RGBColor[
              0.5319886243671207, 0.6309313569324684, 0.9562992397301722], 
             UndirectedEdge[44, 360] -> 
             RGBColor[
              0.5380217860131518, 0.6358293493475512, 0.9567741923151472], 
             UndirectedEdge[170, 238] -> 
             RGBColor[
              0.3084172446419511, 0.44044171708200675`, 0.940913897073925], 
             UndirectedEdge[5, 11] -> 
             RGBColor[
              0.23876273655839006`, 0.3682851529276855, 0.9369085566779607], 
             UndirectedEdge[3, 223] -> 
             RGBColor[
              0.4257649092191724, 0.5429712289379067, 0.9484129706530855], 
             UndirectedEdge[65, 227] -> 
             RGBColor[
              0.9155479974276244, 0.657189157644029, 0.2946818964954864], 
             UndirectedEdge[78, 85] -> 
             RGBColor[
              0.21682232686548605`, 0.34522439123812265`, 0.9356590828038773],
              UndirectedEdge[181, 393] -> 
             RGBColor[
              0.4409543407183537, 0.5561398931308579, 0.9493774176456293], 
             UndirectedEdge[45, 56] -> 
             RGBColor[
              0.5597280401148761, 0.3487238439697099, 0.5610837052268939], 
             UndirectedEdge[141, 310] -> 
             RGBColor[
              0.3031699755874952, 0.4359038694979436, 0.9405792867476138], 
             UndirectedEdge[39, 236] -> 
             RGBColor[
              0.4554923722273556, 0.5623404159424226, 0.9515950359894985], 
             UndirectedEdge[337, 375] -> 
             RGBColor[
              0.9092060692572821, 0.9298599802312014, 0.9710835499900707], 
             UndirectedEdge[57, 334] -> 
             RGBColor[
              0.5020235331688498, 0.6052327745876049, 0.9543192472492019], 
             UndirectedEdge[123, 438] -> 
             RGBColor[
              0.21421403684205725`, 0.34248291304835987`, 0.9355105445456623],
              UndirectedEdge[35, 385] -> 
             RGBColor[
              0.235922007593164, 0.36529936667261376`, 0.936746781365873], 
             UndirectedEdge[268, 285] -> 
             RGBColor[
              0.3620365603618595, 0.4879996049239992, 0.9442896273832655], 
             UndirectedEdge[169, 361] -> 
             RGBColor[
              0.5684718159304661, 0.6605218314458838, 0.9591906270789168], 
             UndirectedEdge[337, 361] -> 
             RGBColor[
              0.752206073850372, 0.8066735064022713, 0.9758502482621753], 
             UndirectedEdge[119, 270] -> 
             RGBColor[
              0.9903352312511376, 0.9902713839961873, 0.8098337599957988], 
             UndirectedEdge[254, 386] -> 
             RGBColor[
              0.20771262472504887`, 0.3356495167000475, 0.935140298743576], 
             UndirectedEdge[253, 488] -> 
             RGBColor[
              0.877198073649208, 0.9039154021300979, 0.937685633244106], 
             UndirectedEdge[340, 380] -> 
             RGBColor[
              0.3051428116901297, 0.43540236706824387`, 0.9407859230744895], 
             UndirectedEdge[388, 490] -> 
             RGBColor[
              0.9683628300119925, 0.9748687448836537, 0.8911081388957877], 
             UndirectedEdge[27, 311] -> 
             RGBColor[
              0.6294878924283578, 0.7084848809709354, 0.9650691972348303], 
             UndirectedEdge[222, 417] -> 
             RGBColor[
              0.5718731828738293, 0.6621247011020224, 0.9601331729684849], 
             UndirectedEdge[274, 361] -> 
             RGBColor[
              0.5534678542610545, 0.6483409394418851, 0.9580094602549781], 
             UndirectedEdge[65, 474] -> 
             RGBColor[
              0.989280991001634, 0.9770225512176633, 0.5810477888330006], 
             UndirectedEdge[243, 326] -> 
             RGBColor[
              0.8572408103331092, 0.41460626615910345`, 0.2014143032349089], 
             UndirectedEdge[47, 437] -> 
             RGBColor[
              0.2438820574631478, 0.37366588378227833`, 0.93720009443013], 
             UndirectedEdge[232, 414] -> 
             RGBColor[
              0.31542779716347613`, 0.44447776538926564`, 0.9414351563383871],
              UndirectedEdge[102, 196] -> 
             RGBColor[
              0.28611844580431445`, 0.41805900587053585`, 0.9396053942630224],
              UndirectedEdge[90, 257] -> 
             RGBColor[
              0.8618116052496472, 0.4654005988057779, 0.20640455492384144`], 
             UndirectedEdge[116, 310] -> 
             RGBColor[
              0.2727415097182925, 0.40399899789739224`, 0.9388435975423268], 
             UndirectedEdge[333, 459] -> 
             RGBColor[
              0.3845976264069504, 0.5075408663801063, 0.9457271985616913], 
             UndirectedEdge[68, 257] -> 
             RGBColor[
              0.8394199460541523, 0.30329924422110266`, 0.18535427265779897`],
              UndirectedEdge[220, 349] -> 
             RGBColor[
              0.3762573378366486, 0.5003169276156031, 0.9451957627490192], 
             UndirectedEdge[92, 204] -> 
             RGBColor[
              0.5555153199743827, 0.6500313882920026, 0.9581513473895016], 
             UndirectedEdge[120, 123] -> 
             RGBColor[
              0.20719251066229882`, 0.33510284384296096`, 0.9351106790171422],
              UndirectedEdge[190, 224] -> 
             RGBColor[
              0.2735379552710175, 0.40483611267087094`, 0.938888953938319], 
             UndirectedEdge[450, 469] -> 
             RGBColor[
              0.8390695807149537, 0.298125435533924, 0.18492162257597716`], 
             UndirectedEdge[405, 434] -> 
             RGBColor[
              0.9926076308918226, 0.9901160572249841, 0.6925776468321798], 
             UndirectedEdge[312, 400] -> 
             RGBColor[
              0.30016668312241634`, 0.43282459400155193`, 0.9404054205957836],
              UndirectedEdge[100, 259] -> 
             RGBColor[
              0.8965277758950481, 0.6152647749950997, 0.2349704456547408], 
             UndirectedEdge[87, 423] -> 
             RGBColor[
              0.18353957668712906`, 0.310242110552426, 0.9337636794186364], 
             UndirectedEdge[403, 449] -> 
             RGBColor[
              0.8286073759188407, 0.8669140710830616, 0.9833178599894938], 
             UndirectedEdge[268, 275] -> 
             RGBColor[
              0.4116793705742366, 0.5309977120097701, 0.9474528233525847], 
             UndirectedEdge[166, 210] -> 
             RGBColor[
              0.8370920629652436, 0.28611142656230293`, 0.18315270742599782`],
              UndirectedEdge[102, 496] -> 
             RGBColor[
              0.27671354998693043`, 0.4081738640616296, 0.9390697993595188], 
             UndirectedEdge[11, 202] -> 
             RGBColor[
              0.2389875961328362, 0.3685214945973489, 0.9369213620980754], 
             UndirectedEdge[187, 494] -> 
             RGBColor[
              0.26156581469201307`, 0.3922526338447824, 0.9382071582435395], 
             UndirectedEdge[158, 282] -> 
             RGBColor[
              0.4825898599888707, 0.5882261104425313, 0.9531290808792493], 
             UndirectedEdge[232, 372] -> 
             RGBColor[
              0.41332534927572523`, 0.5319581186500844, 0.9476862556607386], 
             UndirectedEdge[143, 477] -> 
             RGBColor[
              0.21179931439321417`, 0.33994488665237976`, 0.9353730296744625],
              UndirectedEdge[479, 482] -> 
             RGBColor[
              0.3849860560945393, 0.5078773046524521, 0.9457519489579096], 
             UndirectedEdge[45, 283] -> 
             RGBColor[
              0.23199831546813182`, 0.3611753174727555, 0.9365233329039347], 
             UndirectedEdge[323, 463] -> 
             RGBColor[
              0.25322101360276406`, 0.3834817188090337, 0.9377319341665338], 
             UndirectedEdge[130, 347] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[338, 369] -> 
             RGBColor[
              0.37002637582951403`, 0.49491998150227967`, 0.9447987313597479],
              UndirectedEdge[143, 386] -> 
             RGBColor[
              0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772],
              UndirectedEdge[168, 254] -> 
             RGBColor[
              0.5736452347236608, 0.5249664714796068, 0.591929563801219], 
             UndirectedEdge[86, 115] -> 
             RGBColor[
              0.9181807358610004, 0.8207272885954675, 0.6214818156174652], 
             UndirectedEdge[138, 457] -> 
             RGBColor[
              0.22077773189024535`, 0.349381772706308, 0.9358843372685399], 
             UndirectedEdge[11, 497] -> 
             RGBColor[
              0.2374558873234022, 0.36691157152268605`, 0.9368341335473384], 
             UndirectedEdge[154, 379] -> 
             RGBColor[
              0.3094202014132221, 0.4424259593777846, 0.9409369595178776], 
             UndirectedEdge[17, 467] -> 
             RGBColor[
              0.7934052123801664, 0.8390183037645371, 0.979914209324252], 
             UndirectedEdge[75, 93] -> 
             RGBColor[
              0.30711689507265494`, 0.43678253795558514`, 0.940923781155411], 
             UndirectedEdge[100, 315] -> 
             RGBColor[
              0.5583572344294613, 0.5386495393888345, 0.5986936802267802], 
             UndirectedEdge[45, 52] -> 
             RGBColor[
              0.5592887582023336, 0.3453473306953461, 0.5606630483713451], 
             UndirectedEdge[8, 203] -> 
             RGBColor[
              0.5774301323005686, 0.6678228201894449, 0.9598765616924215], 
             UndirectedEdge[244, 340] -> 
             RGBColor[
              0.33993779537767665`, 0.4688587654109236, 0.9428815136196439], 
             UndirectedEdge[104, 190] -> 
             RGBColor[
              0.24734164292075334`, 0.3773021274486088, 0.9373971127039427], 
             UndirectedEdge[38, 437] -> 
             RGBColor[
              0.2578995688543769, 0.3883991770160148, 0.9379983709668107], 
             UndirectedEdge[96, 465] -> 
             RGBColor[
              0.2893936582907169, 0.42150146185421045`, 0.9397919127688803], 
             UndirectedEdge[48, 346] -> 
             RGBColor[
              0.21269676667826953`, 0.34088816590573434`, 0.9354241382544346],
              UndirectedEdge[153, 342] -> 
             RGBColor[
              0.25246005368067864`, 0.38268190168327626`, 0.9376885986247103],
              UndirectedEdge[151, 327] -> 
             RGBColor[
              0.28193174194509296`, 0.41365851466213766`, 0.939366967671913], 
             UndirectedEdge[375, 489] -> 
             RGBColor[
              0.9741495163492516, 0.9792601983573855, 0.8847051301265769], 
             UndirectedEdge[203, 289] -> 
             RGBColor[
              0.48696884397226536`, 0.5940035787603833, 0.9528597515235682], 
             UndirectedEdge[6, 79] -> 
             RGBColor[
              0.9107592672849488, 0.9273249908421985, 0.7765494419084453], 
             UndirectedEdge[105, 463] -> 
             RGBColor[
              0.2565013158137106, 0.3869295244159112, 0.9379187425246749], 
             UndirectedEdge[10, 125] -> 
             RGBColor[
              0.21381800062875955`, 0.3420666538780378, 0.935487990869198], 
             UndirectedEdge[32, 331] -> 
             RGBColor[
              0.6862012136677067, 0.7532861971667737, 0.9704389262848694], 
             UndirectedEdge[26, 44] -> 
             RGBColor[
              0.4416533932183588, 0.5557823986053863, 0.949688034527277], 
             UndirectedEdge[86, 253] -> 
             RGBColor[
              0.9501124692155603, 0.8447770986590462, 0.5741725699000219], 
             UndirectedEdge[370, 466] -> 
             RGBColor[
              0.5474757553674385, 0.6435045075658272, 0.9575184434137474], 
             UndirectedEdge[301, 456] -> 
             RGBColor[
              0.21620560443164671`, 0.3445761768576967, 0.9356239613736292], 
             UndirectedEdge[21, 337] -> 
             RGBColor[
              0.9205492329643337, 0.9192823831910986, 0.6833909335036439], 
             UndirectedEdge[61, 172] -> 
             RGBColor[
              0.3377395733706075, 0.4669547759942509, 0.9427414448571648], 
             UndirectedEdge[291, 359] -> 
             RGBColor[
              0.5201892016597764, 0.619316785102851, 0.95601113315619], 
             UndirectedEdge[134, 499] -> 
             RGBColor[
              0.2469625122439105, 0.37690363706897373`, 0.93737552177277], 
             UndirectedEdge[140, 244] -> 
             RGBColor[
              0.42103754660959536`, 0.5378457039996745, 0.9483965938455836], 
             UndirectedEdge[108, 364] -> 
             RGBColor[
              0.27183868506633, 0.4030500719457907, 0.938792183014007], 
             UndirectedEdge[113, 421] -> 
             RGBColor[
              0.17912443323835392`, 0.3056015148515002, 0.9335122435308479], 
             UndirectedEdge[54, 55] -> 
             RGBColor[
              0.22009923076516985`, 0.34866862500439766`, 0.9358456976332195],
              UndirectedEdge[56, 210] -> 
             RGBColor[
              0.8363686612775614, 0.28055104419413623`, 0.18245997715290796`],
              UndirectedEdge[36, 58] -> 
             RGBColor[
              0.28475051663686596`, 0.4160326690739975, 0.9395490426575464], 
             UndirectedEdge[25, 288] -> 
             RGBColor[
              0.2847205959795895, 0.4161617683290476, 0.9395414602803146], 
             UndirectedEdge[262, 344] -> 
             RGBColor[
              0.4699143971667351, 0.5805367028791276, 0.9514125291795714], 
             UndirectedEdge[8, 439] -> 
             RGBColor[
              0.7406030565482964, 0.7972768000160912, 0.9749233642591105], 
             UndirectedEdge[102, 186] -> 
             RGBColor[
              0.256123983487738, 0.3865329242170628, 0.9378972540069239], 
             UndirectedEdge[85, 145] -> 
             RGBColor[
              0.21743686076267443`, 0.3458703053277671, 0.9356940796002007], 
             UndirectedEdge[421, 423] -> 
             RGBColor[
              0.18344124862659156`, 0.31013876152644193`, 0.9337580797810521],
              UndirectedEdge[406, 476] -> 
             RGBColor[
              0.9195554041525527, 0.6768776802935997, 0.3060621599750899], 
             UndirectedEdge[111, 400] -> 
             RGBColor[
              0.2845065356159251, 0.4163647860615299, 0.939513598362401], 
             UndirectedEdge[137, 183] -> 
             RGBColor[
              0.2125239415632086, 0.34070651575206007`, 0.9354142961198038], 
             UndirectedEdge[85, 358] -> 
             RGBColor[
              0.2199208837213561, 0.34848117095349374`, 0.935835541032915], 
             UndirectedEdge[399, 412] -> 
             RGBColor[
              0.24194122045751632`, 0.37162594103318614`, 0.9370895666338703],
              UndirectedEdge[283, 292] -> 
             RGBColor[
              0.18009239570445779`, 0.3066189047757405, 0.9335673675613205], 
             UndirectedEdge[240, 310] -> 
             RGBColor[
              0.2766913122921885, 0.4081504908345045, 0.939068532955701], 
             UndirectedEdge[186, 300] -> 
             RGBColor[
              0.23083402862066274`, 0.35995157817601575`, 0.9364570284903794],
              UndirectedEdge[37, 240] -> 
             RGBColor[
              0.28113287624005423`, 0.4128188561551308, 0.9393214734518269], 
             UndirectedEdge[36, 429] -> 
             RGBColor[
              0.2739936283843697, 0.4053150540043482, 0.9389149038480165], 
             UndirectedEdge[56, 276] -> 
             RGBColor[
              0.7281068824339767, 0.4924523185511463, 0.5729718060098814], 
             UndirectedEdge[95, 174] -> 
             RGBColor[
              0.24687001390337449`, 0.3768064154483368, 0.9373702541291156], 
             UndirectedEdge[7, 28] -> 
             RGBColor[
              0.901769090567154, 0.9237583305634441, 0.9644245605513657], 
             UndirectedEdge[251, 367] -> 
             RGBColor[
              0.24419513183599667`, 0.3739949447982042, 0.9372179235525118], 
             UndirectedEdge[31, 314] -> 
             RGBColor[
              0.3915568678230763, 0.5135686115131106, 0.9461706352709112], 
             UndirectedEdge[238, 436] -> 
             RGBColor[
              0.3965368671240651, 0.5173498014044343, 0.9466350145946033], 
             UndirectedEdge[291, 488] -> 
             RGBColor[
              0.7121457205579194, 0.7750529164985673, 0.971943688111231], 
             UndirectedEdge[96, 171] -> 
             RGBColor[
              0.2789519797924134, 0.41052659571183897`, 0.939197274625481], 
             UndirectedEdge[127, 179] -> 
             RGBColor[
              0.20245447418328588`, 0.33012286709465477`, 0.9348408548489592],
              UndirectedEdge[296, 453] -> 
             RGBColor[
              0.2988633264806147, 0.4310225569001501, 0.9403470186360454], 
             UndirectedEdge[14, 494] -> 
             RGBColor[
              0.2826231066390982, 0.4143851827905905, 0.9394063398684542], 
             UndirectedEdge[317, 420] -> 
             RGBColor[
              0.9260215766566631, 0.7697821905786719, 0.5811912001414211], 
             UndirectedEdge[7, 388] -> 
             RGBColor[
              0.8924271040987608, 0.9167910923514154, 0.9802381068620604], 
             UndirectedEdge[146, 271] -> 
             RGBColor[
              0.25686927492861433`, 0.3873162727756304, 0.9379396972519218], 
             UndirectedEdge[331, 449] -> 
             RGBColor[
              0.7824972356635673, 0.8301470968699212, 0.9789198336489376], 
             UndirectedEdge[27, 359] -> 
             RGBColor[
              0.44878508964320496`, 0.5615402381340974, 0.9502583075299758], 
             UndirectedEdge[100, 471] -> 
             RGBColor[
              0.894013717811025, 0.6013444138663678, 0.23277457969666004`], 
             UndirectedEdge[219, 337] -> 
             RGBColor[
              0.6932397997764845, 0.7588302526554731, 0.971188910299956], 
             UndirectedEdge[199, 419] -> 
             RGBColor[
              0.4277672068152066, 0.5433200836247167, 0.948923355062986], 
             UndirectedEdge[266, 437] -> 
             RGBColor[
              0.2726756027922651, 0.40392972553939704`, 0.9388398442403902], 
             UndirectedEdge[327, 399] -> 
             RGBColor[
              0.24928505714751653`, 0.3793447790205158, 0.9375077872691331], 
             UndirectedEdge[311, 419] -> 
             RGBColor[
              0.6297737018777119, 0.70871691395749, 0.9650916972016379], 
             UndirectedEdge[267, 329] -> 
             RGBColor[
              0.9358102453449542, 0.941979730786866, 0.7003355368972839], 
             UndirectedEdge[219, 244] -> 
             RGBColor[
              0.43435496414043395`, 0.548657383494032, 0.949444989736919], 
             UndirectedEdge[17, 205] -> 
             RGBColor[
              0.9368989095333399, 0.9481665884975428, 0.7789256469520753], 
             UndirectedEdge[175, 361] -> 
             RGBColor[
              0.7999658560018515, 0.8442393091304512, 0.9624964661202554], 
             UndirectedEdge[189, 266] -> 
             RGBColor[
              0.2746480537102089, 0.4060028965147674, 0.9389521724021874], 
             UndirectedEdge[225, 280] -> 
             RGBColor[
              0.26557083518380836`, 0.39646216431462483`, 0.9384352382356503],
              UndirectedEdge[300, 458] -> 
             RGBColor[
              0.22822845140871784`, 0.35721295132312475`, 0.9363086447227651],
              UndirectedEdge[171, 343] -> 
             RGBColor[
              0.2773148667291586, 0.40880588608339485`, 0.9391040434584204], 
             UndirectedEdge[358, 408] -> 
             RGBColor[
              0.2240653730927813, 0.35283729205866493`, 0.936071563571395], 
             UndirectedEdge[380, 411] -> 
             RGBColor[
              0.2562205129796168, 0.38663438283335066`, 0.9379027512186837], 
             UndirectedEdge[345, 498] -> 
             RGBColor[
              0.5608073530060538, 0.6540616711594758, 0.9587498403781267], 
             UndirectedEdge[161, 450] -> 
             RGBColor[
              0.9040202207813182, 0.5580851531997648, 0.2907664410126593], 
             UndirectedEdge[94, 214] -> 
             RGBColor[
              0.5776130969249946, 0.6468062636067821, 0.9475190708650497], 
             UndirectedEdge[157, 343] -> 
             RGBColor[
              0.2977155588527831, 0.4302483069839126, 0.9402658326947413], 
             UndirectedEdge[155, 332] -> 
             RGBColor[
              0.4840405870433834, 0.5906167908800439, 0.9529081554374272], 
             UndirectedEdge[127, 168] -> 
             RGBColor[
              0.5683860156508949, 0.5194386987803812, 0.5916300590553423], 
             UndirectedEdge[378, 380] -> 
             RGBColor[
              0.27796774382392075`, 0.40949210130478847`, 0.939141223843122], 
             UndirectedEdge[160, 481] -> 
             RGBColor[
              0.3703492229848604, 0.49519961548147085`, 0.9448193028950042], 
             UndirectedEdge[23, 485] -> 
             RGBColor[
              0.2352513492635514, 0.3645944622459968, 0.9367085883661517], 
             UndirectedEdge[352, 399] -> 
             RGBColor[
              0.23466592421327268`, 0.3639791434000619, 0.936675249275597], 
             UndirectedEdge[389, 456] -> 
             RGBColor[
              0.22107915567658082`, 0.3496985882171184, 0.9359015029072553], 
             UndirectedEdge[105, 263] -> 
             RGBColor[
              0.2596529612026372, 0.3902421035455322, 0.9380982240671327], 
             UndirectedEdge[143, 347] -> 
             RGBColor[
              0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772],
              UndirectedEdge[98, 484] -> 
             RGBColor[
              0.9940632182259341, 0.9897101490230129, 0.5951961253421731], 
             UndirectedEdge[100, 500] -> 
             RGBColor[
              0.8753537574413516, 0.45791578161828494`, 0.21490578057324983`],
              UndirectedEdge[89, 424] -> 
             RGBColor[
              0.3030480744366626, 0.4347576504686087, 0.9406096220363795], 
             UndirectedEdge[231, 442] -> 
             RGBColor[
              0.2711958428958343, 0.40237440406605196`, 0.938755574103397], 
             UndirectedEdge[15, 104] -> 
             RGBColor[
              0.24040623048550225`, 0.3700125692486139, 0.9370021512257783], 
             UndirectedEdge[75, 182] -> 
             RGBColor[
              0.3617675856264607, 0.48776663252726005`, 0.9442724885509708], 
             UndirectedEdge[290, 316] -> 
             RGBColor[
              0.268490139738015, 0.3995305384956953, 0.9386014883112883], 
             UndirectedEdge[344, 424] -> 
             RGBColor[
              0.39216870621134226`, 0.5138154925134429, 0.9462878321282429], 
             UndirectedEdge[369, 425] -> 
             RGBColor[
              0.397645136695217, 0.5188419640048679, 0.9465585743797993], 
             UndirectedEdge[106, 255] -> 
             RGBColor[
              0.45772043203322, 0.569123825312507, 0.9508706958509441], 
             UndirectedEdge[84, 242] -> 
             RGBColor[
              0.22916096004104347`, 0.3581930770201611, 0.9363617497098533], 
             UndirectedEdge[143, 446] -> 
             RGBColor[
              0.20353913733189777`, 0.3312629168354616, 0.9349026248106573], 
             UndirectedEdge[376, 415] -> 
             RGBColor[
              0.28323389332621046`, 0.41502715832485815`, 0.9394411232667073],
              UndirectedEdge[93, 108] -> 
             RGBColor[
              0.27719798724909794`, 0.408683038339264, 0.9390973873449386], 
             UndirectedEdge[78, 183] -> 
             RGBColor[
              0.21219822021020854`, 0.34036416195813046`, 0.935395746770612], 
             UndirectedEdge[17, 298] -> 
             RGBColor[
              0.8908055349705915, 0.9157681695861948, 0.9894470212286257], 
             UndirectedEdge[204, 370] -> 
             RGBColor[
              0.546668194471859, 0.642848893250592, 0.9574548692618543], 
             UndirectedEdge[208, 314] -> 
             RGBColor[
              0.32609699892407057`, 0.4568705631814669, 0.9419995903085558], 
             UndirectedEdge[313, 379] -> 
             RGBColor[
              0.288128547073246, 0.4201206026991259, 0.9397217393007642], 
             UndirectedEdge[3, 221] -> 
             RGBColor[
              0.4991380572062573, 0.6042617866100937, 0.9537131227476765], 
             UndirectedEdge[154, 229] -> 
             RGBColor[
              0.3002585012900294, 0.4328475787158096, 0.940413341505228], 
             UndirectedEdge[25, 180] -> 
             RGBColor[
              0.2917531123703574, 0.42355338894303707`, 0.9399419516850931], 
             UndirectedEdge[371, 419] -> 
             RGBColor[
              0.43781722710861815`, 0.5520249060741627, 0.9495637334691982], 
             UndirectedEdge[31, 419] -> 
             RGBColor[
              0.4828643991449212, 0.5910425023553091, 0.9524340994377012], 
             UndirectedEdge[321, 482] -> 
             RGBColor[
              0.3458284457686297, 0.47396095070686983`, 0.9432568606536578], 
             UndirectedEdge[212, 300] -> 
             RGBColor[
              0.22223694937519295`, 0.35091550280272016`, 0.9359674375455889],
              UndirectedEdge[376, 414] -> 
             RGBColor[
              0.27705653417076703`, 0.40853436218529504`, 0.9390893318013886],
              UndirectedEdge[140, 274] -> 
             RGBColor[
              0.4811841626563286, 0.5896860062007292, 0.9522997264014235], 
             UndirectedEdge[1, 131] -> 
             RGBColor[
              0.26488726968740706`, 0.3957436936373514, 0.9383963101918749], 
             UndirectedEdge[360, 466] -> 
             RGBColor[
              0.5414372478398441, 0.638602175123262, 0.9570430699813932], 
             UndirectedEdge[165, 182] -> 
             RGBColor[
              0.4013099579800705, 0.5220162480025345, 0.9467920935513959], 
             UndirectedEdge[268, 480] -> 
             RGBColor[
              0.3816010072146523, 0.5049453454501976, 0.9455362566365644], 
             UndirectedEdge[54, 385] -> 
             RGBColor[
              0.23109619211781043`, 0.36022712863364376`, 0.9364719583137058],
              UndirectedEdge[149, 158] -> 
             RGBColor[
              0.3556980515257828, 0.48250950715290686`, 0.943885743205154], 
             UndirectedEdge[229, 379] -> 
             RGBColor[
              0.30013749915285226`, 0.43274277274633094`, 0.9404056313560452],
              UndirectedEdge[98, 253] -> 
             RGBColor[
              0.9901332923121124, 0.9901471046097305, 0.8102166844391167], 
             UndirectedEdge[121, 469] -> 
             RGBColor[
              0.8439483097229172, 0.3356254845618147, 0.18959349898373934`], 
             UndirectedEdge[34, 269] -> 
             RGBColor[
              0.4963462045644428, 0.6018763440007352, 0.9535261877805588], 
             UndirectedEdge[145, 286] -> 
             RGBColor[
              0.22187921582518422`, 0.3505395021600439, 0.9359470651491353], 
             UndirectedEdge[34, 234] -> 
             RGBColor[
              0.4661658558479902, 0.5757356428509766, 0.951603122647781], 
             UndirectedEdge[85, 286] -> 
             RGBColor[
              0.21865790979829205`, 0.3471537052831816, 0.935763616536399], 
             UndirectedEdge[86, 261] -> 
             RGBColor[
              0.897589954080166, 0.6247029436909717, 0.23609548573218275`], 
             UndirectedEdge[140, 255] -> 
             RGBColor[
              0.4486097951007969, 0.5617273998212495, 0.950153473138261], 
             UndirectedEdge[345, 448] -> 
             RGBColor[
              0.6138322543981429, 0.6971096748541594, 0.9629241548523259], 
             UndirectedEdge[146, 444] -> 
             RGBColor[
              0.2646131387661169, 0.39545556465817117`, 0.9383806988414477], 
             UndirectedEdge[215, 224] -> 
             RGBColor[
              0.2915446973152564, 0.4237623402527527, 0.9399144112591507], 
             UndirectedEdge[40, 359] -> 
             RGBColor[
              0.38582570994179444`, 0.508604570612715, 0.9458054509585798], 
             UndirectedEdge[88, 495] -> 
             RGBColor[
              0.8544062989949438, 0.4062909143031017, 0.1992274995322182], 
             UndirectedEdge[341, 403] -> 
             RGBColor[
              0.9612426733705868, 0.9674078133042042, 0.7674804702008887], 
             UndirectedEdge[134, 416] -> 
             RGBColor[
              0.24737003573452257`, 0.37733197009608865`, 0.9373987296326833],
              UndirectedEdge[113, 423] -> 
             RGBColor[
              0.1835090760837748, 0.31021005248445066`, 0.9337619424543968], 
             UndirectedEdge[204, 362] -> 
             RGBColor[
              0.4451772959687064, 0.5586930048020928, 0.9499517048675632], 
             UndirectedEdge[231, 256] -> 
             RGBColor[
              0.27391624912615603`, 0.40523372349783726`, 0.9389104972137335],
              UndirectedEdge[183, 407] -> 
             RGBColor[
              0.2096628417623121, 0.3376993184571131, 0.9352513607187605], 
             UndirectedEdge[231, 271] -> 
             RGBColor[
              0.25712583983655113`, 0.38758593876102676`, 0.9379543082438752],
              UndirectedEdge[106, 140] -> 
             RGBColor[
              0.508744701282457, 0.6120608930455363, 0.9544693929596517], 
             UndirectedEdge[96, 147] -> 
             RGBColor[
              0.27382745193814473`, 0.40514039202317054`, 0.9389054403452399],
              UndirectedEdge[149, 275] -> 
             RGBColor[
              0.38378936730216673`, 0.5068407929678266, 0.9456756970062499], 
             UndirectedEdge[207, 287] -> 
             RGBColor[
              0.21343735530821623`, 0.3416665715118395, 0.9354663136813074], 
             UndirectedEdge[223, 480] -> 
             RGBColor[
              0.3717055099769321, 0.496374363105037, 0.9449057243028214], 
             UndirectedEdge[11, 102] -> 
             RGBColor[
              0.2577278443328788, 0.3882186836559568, 0.9379885915093551], 
             UndirectedEdge[230, 339] -> 
             RGBColor[
              0.21778435426976317`, 0.3462355430360783, 0.9357138688413589], 
             UndirectedEdge[103, 449] -> 
             RGBColor[
              0.6043292409167387, 0.6883441793156388, 0.9628942898259707], 
             UndirectedEdge[226, 396] -> 
             RGBColor[
              0.5864855268156967, 0.6472607121015193, 0.7362180745608087], 
             UndirectedEdge[144, 279] -> 
             RGBColor[
              0.2623939933592224, 0.3931231021335797, 0.9382543217934566], 
             UndirectedEdge[205, 228] -> 
             RGBColor[
              0.9934539331599859, 0.9884069498751192, 0.5288792059852668], 
             UndirectedEdge[267, 406] -> 
             RGBColor[
              0.9898404936899885, 0.9773917410301207, 0.415032665757733], 
             UndirectedEdge[209, 233] -> 
             RGBColor[
              0.7045416845554648, 0.49561598240663746`, 0.5739669497124782], 
             UndirectedEdge[387, 405] -> 
             RGBColor[
              0.8845632449194131, 0.9069230619459494, 0.7839577394340637], 
             UndirectedEdge[75, 206] -> 
             RGBColor[
              0.34384133423410757`, 0.4722398145707964, 0.9431302436638118], 
             UndirectedEdge[183, 404] -> 
             RGBColor[
              0.20920782453695042`, 0.33722106650349953`, 0.9352254481609139],
              UndirectedEdge[319, 488] -> 
             RGBColor[
              0.7421269925364968, 0.7984745140343386, 0.9749319411111395], 
             UndirectedEdge[220, 371] -> 
             RGBColor[
              0.3509285621764658, 0.4783784152000333, 0.9435818355613093], 
             UndirectedEdge[66, 460] -> 
             RGBColor[
              0.2558136629427209, 0.38620675764879087`, 0.9378795817109632], 
             UndirectedEdge[87, 446] -> 
             RGBColor[
              0.20370226760912918`, 0.33143437709988877`, 0.934911914838616], 
             UndirectedEdge[273, 308] -> 
             RGBColor[
              0.23624385022904204`, 0.36563764368892326`, 0.9367651098278627],
              UndirectedEdge[326, 428] -> 
             RGBColor[
              0.8527545036662538, 0.3801225472055363, 0.19711821090416948`], 
             UndirectedEdge[130, 315] -> 
             RGBColor[
              0.1822133081343763, 0.30884811821319974`, 0.9336881503865955], 
             UndirectedEdge[95, 407] -> 
             RGBColor[
              0.22072063099008732`, 0.34932175603983573`, 0.9358810854567492],
              UndirectedEdge[148, 153] -> 
             RGBColor[
              0.2422944032111111, 0.37199715850029413`, 0.9371096798692006], 
             UndirectedEdge[85, 137] -> 
             RGBColor[
              0.21714804821848613`, 0.34556674503205226`, 0.9356776321530691],
              UndirectedEdge[289, 359] -> 
             RGBColor[
              0.4124111574915527, 0.5316315490568694, 0.9474994521678624], 
             UndirectedEdge[32, 449] -> 
             RGBColor[
              0.6320067542390264, 0.7108140314884382, 0.9650731650607731], 
             UndirectedEdge[329, 406] -> 
             RGBColor[
              0.9365881325497546, 0.9446037269852596, 0.7033574817962612], 
             UndirectedEdge[168, 213] -> 
             RGBColor[
              0.9074990588325569, 0.6709655443987909, 0.2444294609060539], 
             UndirectedEdge[111, 464] -> 
             RGBColor[
              0.2584790029138965, 0.3890081989508112, 0.9380313688793045], 
             UndirectedEdge[50, 117] -> 
             RGBColor[
              0.41100665014042015`, 0.5304150353819104, 0.9474099582014052], 
             UndirectedEdge[357, 420] -> 
             RGBColor[
              0.937892556639665, 0.822845791169284, 0.5910531975827036], 
             UndirectedEdge[153, 190] -> 
             RGBColor[
              0.24652129125596123`, 0.3764398858356126, 0.9373503948902342], 
             UndirectedEdge[165, 275] -> 
             RGBColor[
              0.41886860868054065`, 0.537224668715837, 0.9479109152475247], 
             UndirectedEdge[152, 301] -> 
             RGBColor[
              0.2063778078751808, 0.33424653955855976`, 0.9350642828986606], 
             UndirectedEdge[208, 349] -> 
             RGBColor[
              0.3678599975315118, 0.49304357350588934`, 0.9446606916502523], 
             UndirectedEdge[5, 23] -> 
             RGBColor[
              0.23055442452635688`, 0.3596576965449768, 0.9364411054508459], 
             UndirectedEdge[56, 227] -> 
             RGBColor[
              0.8411523878247509, 0.31732086267817405`, 0.187040879096943], 
             UndirectedEdge[56, 326] -> 
             RGBColor[
              0.8559245599190561, 0.404488988692082, 0.2001538603519194], 
             UndirectedEdge[155, 181] -> 
             RGBColor[
              0.49329315877378277`, 0.5986309034651389, 0.9534977211263604], 
             UndirectedEdge[148, 323] -> 
             RGBColor[
              0.23950025424315785`, 0.36906033077569844`, 0.9369505572190486],
              UndirectedEdge[177, 438] -> 
             RGBColor[
              0.21508055771107348`, 0.3433936814222922, 0.9355598916272501], 
             UndirectedEdge[53, 90] -> 
             RGBColor[
              0.9206410418975434, 0.7056328015929743, 0.28606405077970154`], 
             UndirectedEdge[30, 217] -> 
             RGBColor[
              0.2938254921740675, 0.42514500116830317`, 0.9400814485951139], 
             UndirectedEdge[43, 290] -> 
             RGBColor[
              0.2898165263474991, 0.4219459229932718, 0.9398159944791369], 
             UndirectedEdge[114, 397] -> 
             RGBColor[
              0.4296132686116584, 0.545245204928905, 0.9489508667899835], 
             UndirectedEdge[227, 320] -> 
             RGBColor[
              0.9171168323829694, 0.670650788557899, 0.5149397016540836], 
             UndirectedEdge[298, 432] -> 
             RGBColor[
              0.9001321413614187, 0.9232049523582542, 0.9903366012721426], 
             UndirectedEdge[42, 85] -> 
             RGBColor[
              0.22334491181980198`, 0.3520800415808806, 0.9360305343677259], 
             UndirectedEdge[329, 413] -> 
             RGBColor[
              0.9281969547806851, 0.9162983140279535, 0.6707593407043844], 
             UndirectedEdge[244, 380] -> 
             RGBColor[
              0.3076460451816098, 0.43757054210239044`, 0.9409454268990441], 
             UndirectedEdge[87, 113] -> 
             RGBColor[
              0.17922276129889142`, 0.3057048638774843, 0.9335178431684322], 
             UndirectedEdge[334, 370] -> 
             RGBColor[
              0.49712370807879736`, 0.6012548758448955, 0.9539335150694623], 
             UndirectedEdge[24, 278] -> 
             RGBColor[
              0.8926678774514412, 0.9169265621366819, 0.9783016146877055], 
             UndirectedEdge[51, 325] -> 
             RGBColor[
              0.17897196058988912`, 0.30544125643063946`, 0.933503560439081], 
             UndirectedEdge[112, 463] -> 
             RGBColor[
              0.2576804433404335, 0.3881688622075002, 0.9379858920929589], 
             UndirectedEdge[308, 421] -> 
             RGBColor[
              0.1790014452743907, 0.3054722467034876, 0.9335052395482446], 
             UndirectedEdge[302, 421] -> 
             RGBColor[
              0.18460298206136966`, 0.31135981702454774`, 0.9338242387815321],
              UndirectedEdge[103, 488] -> 
             RGBColor[
              0.6248600030483947, 0.70438296673246, 0.9649406043243738], 
             UndirectedEdge[225, 424] -> 
             RGBColor[
              0.2974218624617132, 0.42884414496049433`, 0.940289217587641], 
             UndirectedEdge[205, 388] -> 
             RGBColor[
              0.9699993320336204, 0.9742898944709728, 0.7727192137216462], 
             UndirectedEdge[114, 297] -> 
             RGBColor[
              0.5100213466264654, 0.6130973312480197, 0.954569895157638], 
             UndirectedEdge[203, 381] -> 
             RGBColor[
              0.5519357188644908, 0.6471253068518, 0.9578695480776199], 
             UndirectedEdge[17, 252] -> 
             RGBColor[
              0.8078836333626171, 0.8503289562761027, 0.9813572830192461], 
             UndirectedEdge[361, 363] -> 
             RGBColor[
              0.5245064025228867, 0.6235116591529769, 0.9560934187929221], 
             UndirectedEdge[318, 383] -> 
             RGBColor[
              0.3354424216880899, 0.46496509866505487`, 0.9425950723832464], 
             UndirectedEdge[209, 273] -> 
             RGBColor[
              0.4297324939516893, 0.5421711471050089, 0.9494994222745707], 
             UndirectedEdge[47, 230] -> 
             RGBColor[
              0.22790583767600858`, 0.3568738638351552, 0.9362902723479516], 
             UndirectedEdge[1, 170] -> 
             RGBColor[
              0.2814230291570491, 0.41312382526764985`, 0.939337997231207], 
             UndirectedEdge[139, 247] -> 
             RGBColor[
              0.529523280699882, 0.6289298798809373, 0.9561051588458358], 
             UndirectedEdge[246, 288] -> 
             RGBColor[
              0.2751436592994766, 0.40652380941229693`, 0.9389803964073136], 
             UndirectedEdge[1, 147] -> 
             RGBColor[
              0.2588293294875211, 0.38937641439167825`, 0.9380513194594108], 
             UndirectedEdge[352, 457] -> 
             RGBColor[
              0.22470998276050042`, 0.3535148176900512, 0.9361082731383572], 
             UndirectedEdge[157, 238] -> 
             RGBColor[
              0.31134876495031627`, 0.4435229307952213, 0.9410808428186908], 
             UndirectedEdge[97, 145] -> 
             RGBColor[
              0.2261963371710197, 0.3550770704158197, 0.9361929188231719], 
             UndirectedEdge[83, 237] -> 
             RGBColor[
              0.913419047498675, 0.933799570648643, 0.9916039182408752], 
             UndirectedEdge[73, 494] -> 
             RGBColor[
              0.25320700081228975`, 0.383466990477783, 0.9377311361588463], 
             UndirectedEdge[101, 197] -> 
             RGBColor[
              0.6092291752169602, 0.6927921015850171, 0.9629587335694303], 
             UndirectedEdge[224, 356] -> 
             RGBColor[
              0.28415211148803254`, 0.41599226383132715`, 0.939493414432641], 
             UndirectedEdge[182, 441] -> 
             RGBColor[
              0.41435953118072005`, 0.5333191324183171, 0.9476236008164568], 
             UndirectedEdge[160, 480] -> 
             RGBColor[
              0.3880144919727734, 0.5105003835965654, 0.94594491821413], 
             UndirectedEdge[263, 440] -> 
             RGBColor[
              0.2775372454156354, 0.40903962018250506`, 0.9391167075956355], 
             UndirectedEdge[31, 223] -> 
             RGBColor[
              0.42145102378698707`, 0.5394614268850837, 0.9480754644545675], 
             UndirectedEdge[5, 102] -> 
             RGBColor[
              0.2575724490549457, 0.3880553533662194, 0.9379797419781635], 
             UndirectedEdge[171, 216] -> 
             RGBColor[
              0.26381410331866717`, 0.39461572774112796`, 0.9383351949547825],
              UndirectedEdge[102, 414] -> 
             RGBColor[
              0.27559776236137046`, 0.40700110052214455`, 0.9390062569049031],
              UndirectedEdge[68, 205] -> 
             RGBColor[
              0.9069065109079608, 0.5719171126049378, 0.3681050087560027], 
             UndirectedEdge[111, 376] -> 
             RGBColor[
              0.2762731715166523, 0.4077109983677596, 0.9390447204571181], 
             UndirectedEdge[302, 325] -> 
             RGBColor[
              0.18458313935535953`, 0.31133896108243087`, 0.9338231087687794],
              UndirectedEdge[39, 315] -> 
             RGBColor[
              0.40458060190845924`, 0.5088289173445842, 0.948695685987052], 
             UndirectedEdge[66, 314] -> 
             RGBColor[
              0.29667827269945046`, 0.4271859979700665, 0.9402789673950056], 
             UndirectedEdge[274, 370] -> 
             RGBColor[
              0.5270887992770681, 0.6269534581897589, 0.9559135075504326], 
             UndirectedEdge[94, 477] -> 
             RGBColor[
              0.6000453532177727, 0.6703839872576882, 0.948796554675374], 
             UndirectedEdge[99, 329] -> 
             RGBColor[
              0.9380897089070905, 0.9489785735157732, 0.7678909167681753], 
             UndirectedEdge[25, 465] -> 
             RGBColor[
              0.2980004320712376, 0.430119718051609, 0.9402977272999771], 
             UndirectedEdge[223, 381] -> 
             RGBColor[
              0.47958429341648956`, 0.5866642295649169, 0.9526498297239985], 
             UndirectedEdge[196, 318] -> 
             RGBColor[
              0.3188208288656592, 0.44936205704600285`, 0.9415801260303202], 
             UndirectedEdge[76, 462] -> 
             RGBColor[
              0.4376018334802528, 0.5531637078002476, 0.949183806517649], 
             UndirectedEdge[89, 440] -> 
             RGBColor[
              0.2835877779164691, 0.415399113466799, 0.9394612764705972], 
             UndirectedEdge[88, 326] -> 
             RGBColor[
              0.8708928189630238, 0.5066362693068722, 0.21398214224720047`], 
             UndirectedEdge[149, 282] -> 
             RGBColor[
              0.48076658116172494`, 0.586646877963116, 0.9530129031646457], 
             UndirectedEdge[238, 462] -> 
             RGBColor[
              0.392016142899485, 0.5136796738226148, 0.9462791266236859], 
             UndirectedEdge[168, 261] -> 
             RGBColor[
              0.8953895182633258, 0.6159789489289689, 0.23432496342308617`], 
             UndirectedEdge[155, 344] -> 
             RGBColor[
              0.5148160505883743, 0.6169898879232494, 0.9549473518170989], 
             UndirectedEdge[4, 496] -> 
             RGBColor[
              0.3005965950412318, 0.4318380479282125, 0.9404825707076422], 
             UndirectedEdge[87, 226] -> 
             RGBColor[
              0.17933912709972993`, 0.30582717171218354`, 0.9335244700286423],
              UndirectedEdge[128, 362] -> 
             RGBColor[
              0.4416023765346493, 0.55579072415724, 0.9496702741143528], 
             UndirectedEdge[295, 389] -> 
             RGBColor[
              0.22404383278435813`, 0.3528146518287777, 0.9360703368826964], 
             UndirectedEdge[89, 133] -> 
             RGBColor[
              0.3153376912434113, 0.4454022988525135, 0.9413927055520241], 
             UndirectedEdge[33, 164] -> 
             RGBColor[
              0.8479694807729221, 0.33824875648589925`, 0.19233659900141542`],
              UndirectedEdge[276, 396] -> 
             RGBColor[
              0.8065431088390325, 0.8453068187334528, 0.7510492031181083], 
             UndirectedEdge[50, 274] -> 
             RGBColor[
              0.4518361438965558, 0.5655238171616463, 0.9500822208063486], 
             UndirectedEdge[21, 375] -> 
             RGBColor[
              0.9695446020803578, 0.9577696846543478, 0.6679456249234423], 
             UndirectedEdge[41, 485] -> 
             RGBColor[
              0.24026393309017596`, 0.36986300566395003`, 0.9369940475996247],
              UndirectedEdge[30, 316] -> 
             RGBColor[
              0.25921313179459604`, 0.3897798149508858, 0.938073176433014], 
             UndirectedEdge[285, 324] -> 
             RGBColor[
              0.3420478957119857, 0.4706864282637755, 0.9430159673470576], 
             UndirectedEdge[95, 358] -> 
             RGBColor[
              0.2263545662938538, 0.3552433792562242, 0.9362019297376383], 
             UndirectedEdge[333, 492] -> 
             RGBColor[
              0.32763422405457243`, 0.45523169861929097`, 0.9422062993288807],
              UndirectedEdge[332, 393] -> 
             RGBColor[
              0.4317017689879543, 0.548125780545763, 0.9487878519566961], 
             UndirectedEdge[418, 420] -> 
             RGBColor[
              0.9735581601714495, 0.9798002996671817, 0.9296433170801228], 
             UndirectedEdge[107, 273] -> 
             RGBColor[
              0.2391065540897807, 0.3686465269524677, 0.9369281365777409], 
             UndirectedEdge[310, 483] -> 
             RGBColor[
              0.2967031212326041, 0.4291841708528518, 0.9402081758700394], 
             UndirectedEdge[155, 403] -> 
             RGBColor[
              0.7474005481861847, 0.8023032590432388, 0.9760248292713649], 
             UndirectedEdge[140, 169] -> 
             RGBColor[
              0.4961881243257401, 0.601866898204728, 0.953480893225362], 
             UndirectedEdge[147, 216] -> 
             RGBColor[
              0.2586895754643985, 0.38922952405245953`, 0.9380433606745415], 
             UndirectedEdge[70, 171] -> 
             RGBColor[
              0.25999619432080096`, 0.39060286331495886`, 0.9381177706854442],
              UndirectedEdge[7, 402] -> 
             RGBColor[
              0.6954966701641224, 0.7608182646923372, 0.971187276045136], 
             UndirectedEdge[185, 409] -> 
             RGBColor[
              0.262750205623448, 0.39349750380844273`, 0.9382746075549353], 
             UndirectedEdge[126, 481] -> 
             RGBColor[
              0.28467725623571494`, 0.41566859359098884`, 0.9395553817772139],
              UndirectedEdge[115, 311] -> 
             RGBColor[
              0.8340126241816578, 0.871074103507641, 0.9838732137113628], 
             UndirectedEdge[383, 496] -> 
             RGBColor[
              0.30291603178424115`, 0.4338470274567268, 0.9406303631659094], 
             UndirectedEdge[8, 297] -> 
             RGBColor[
              0.5698289191235334, 0.6616518129015765, 0.9592781663469641], 
             UndirectedEdge[381, 439] -> 
             RGBColor[
              0.7151086431122187, 0.7765792866784462, 0.9729163506443089], 
             UndirectedEdge[16, 276] -> 
             RGBColor[
              0.5117111188744836, 0.6131268633886855, 0.9550738020104051], 
             UndirectedEdge[74, 342] -> 
             RGBColor[
              0.27086057814160247`, 0.4020220195523411, 0.9387364812716233], 
             UndirectedEdge[26, 269] -> 
             RGBColor[
              0.4177844388725415, 0.5362856153201071, 0.9478418329060527], 
             UndirectedEdge[127, 315] -> 
             RGBColor[
              0.20573971378665917`, 0.3335758622140216, 0.9350279443842948], 
             UndirectedEdge[175, 348] -> 
             RGBColor[
              0.9578209370783626, 0.9214694359811255, 0.6292929486935749], 
             UndirectedEdge[180, 288] -> 
             RGBColor[
              0.2630984263915931, 0.39386350591423513`, 0.9382944382125347], 
             UndirectedEdge[288, 343] -> 
             RGBColor[
              0.274476709135814, 0.40582280250320485`, 0.9389424145821572], 
             UndirectedEdge[484, 500] -> 
             RGBColor[
              0.9061921804601966, 0.5690195539734165, 0.316991474169404], 
             UndirectedEdge[59, 323] -> 
             RGBColor[
              0.24076788547771533`, 0.3703926915756808, 0.9370227469425643], 
             UndirectedEdge[108, 189] -> 
             RGBColor[
              0.27244302962866296`, 0.40368527639846097`, 0.9388265995427842],
              UndirectedEdge[59, 74] -> 
             RGBColor[
              0.26196255890659237`, 0.3926696371693413, 0.9382297522396293], 
             UndirectedEdge[40, 199] -> 
             RGBColor[
              0.3645220176644419, 0.4901523831167798, 0.9444479985247825], 
             UndirectedEdge[69, 241] -> 
             RGBColor[
              0.8074723242442312, 0.8502460052781141, 0.9812530323476005], 
             UndirectedEdge[275, 353] -> 
             RGBColor[
              0.5266832510882068, 0.6255486018899017, 0.9561787766673014], 
             UndirectedEdge[196, 335] -> 
             RGBColor[
              0.2862357534512077, 0.4181823036451551, 0.9396120747599719], 
             UndirectedEdge[157, 281] -> 
             RGBColor[
              0.2737261355645935, 0.4050339020907391, 0.9388996705276503], 
             UndirectedEdge[120, 438] -> 
             RGBColor[
              0.21444303080234048`, 0.3427236002196732, 0.9355235854129342], 
             UndirectedEdge[152, 389] -> 
             RGBColor[
              0.21125135912011495`, 0.33936895091798147`, 0.9353418244322866],
              UndirectedEdge[126, 144] -> 
             RGBColor[
              0.24868278916139275`, 0.37871175718110384`, 0.937473488998299], 
             UndirectedEdge[96, 157] -> 
             RGBColor[
              0.29935267191603787`, 0.43196901661235676`, 0.940359063861802], 
             UndirectedEdge[303, 366] -> 
             RGBColor[
              0.2851324087513453, 0.4170226184095053, 0.9395492409115669], 
             UndirectedEdge[119, 309] -> 
             RGBColor[
              0.9918390696706652, 0.9889511495464178, 0.6437403499501158], 
             UndirectedEdge[325, 386] -> 
             RGBColor[
              0.1789719601845752, 0.3054412560046289, 0.9335035604159989], 
             UndirectedEdge[27, 220] -> 
             RGBColor[
              0.4255160611016982, 0.5413857751468245, 0.948775625607305], 
             UndirectedEdge[95, 346] -> 
             RGBColor[
              0.22248278830370904`, 0.3511738951036789, 0.9359814377088818], 
             UndirectedEdge[235, 239] -> 
             RGBColor[
              0.35398612023304477`, 0.4810267183113057, 0.943776660456982], 
             UndirectedEdge[64, 303] -> 
             RGBColor[
              0.29654648477504475`, 0.4290195360046319, 0.9401992556555043], 
             UndirectedEdge[310, 429] -> 
             RGBColor[
              0.2951775190785565, 0.4275806662601843, 0.9401212950842925], 
             UndirectedEdge[67, 238] -> 
             RGBColor[
              0.28838849579729153`, 0.41939023215024707`, 0.9397732894571003],
              UndirectedEdge[38, 108] -> 
             RGBColor[
              0.272539685244709, 0.40378686757924537`, 0.9388321039371288], 
             UndirectedEdge[20, 490] -> 
             RGBColor[
              0.9375437932423437, 0.7794697399272263, 0.5157901036631747], 
             UndirectedEdge[112, 148] -> 
             RGBColor[
              0.2439596839808273, 0.373747474174165, 0.9372045151454738], 
             UndirectedEdge[76, 402] -> 
             RGBColor[
              0.4818182674522101, 0.589060600826333, 0.952664686170056], 
             UndirectedEdge[99, 406] -> 
             RGBColor[
              0.992119957252125, 0.9843905837590278, 0.48258804562862445`], 
             UndirectedEdge[8, 258] -> 
             RGBColor[
              0.4968580357130886, 0.6002414107444907, 0.9541330294430466], 
             UndirectedEdge[15, 153] -> 
             RGBColor[
              0.23958587882071014`, 0.3691503276356177, 0.93695543341207], 
             UndirectedEdge[195, 463] -> 
             RGBColor[
              0.2686246431474216, 0.3996719101069903, 0.9386091480814742], 
             UndirectedEdge[184, 249] -> 
             RGBColor[
              0.2732898707787555, 0.40457536014003825`, 0.9388748258934928], 
             UndirectedEdge[109, 185] -> 
             RGBColor[
              0.26895237692670115`, 0.40001637908853493`, 0.9386278120353654],
              UndirectedEdge[77, 81] -> 
             RGBColor[
              0.7152180111578499, 0.7769379420233913, 0.972614350327299], 
             UndirectedEdge[355, 384] -> 
             RGBColor[
              0.3062638013444511, 0.43738753923394075`, 0.9408202157153518], 
             UndirectedEdge[67, 343] -> 
             RGBColor[
              0.2747552896997584, 0.40611560833893834`, 0.9389582793331509], 
             UndirectedEdge[247, 255] -> 
             RGBColor[
              0.4462984536881862, 0.5598509487377481, 0.9499715158755377], 
             UndirectedEdge[95, 145] -> 
             RGBColor[
              0.22387054333517215`, 0.3526325136304976, 0.9360604683049241], 
             UndirectedEdge[220, 416] -> 
             RGBColor[
              0.3002234451567067, 0.4300950902197503, 0.9405107780769688], 
             UndirectedEdge[287, 451] -> 
             RGBColor[
              0.21062876698303812`, 0.3387145671072923, 0.9353063687311225], 
             UndirectedEdge[387, 491] -> 
             RGBColor[
              0.8846376192086578, 0.9070821410302499, 0.7920529218334498], 
             UndirectedEdge[211, 464] -> 
             RGBColor[
              0.23745358448324252`, 0.36690915109166977`, 0.936834002403998], 
             UndirectedEdge[335, 482] -> 
             RGBColor[
              0.3176268052914761, 0.44657790833086347`, 0.9415681179813948], 
             UndirectedEdge[214, 423] -> 
             RGBColor[
              0.19381650316255092`, 0.32104381187286724`, 0.9343489351780614],
              UndirectedEdge[69, 194] -> 
             RGBColor[
              0.9479892988678673, 0.9596684021789683, 0.9321766809000795], 
             UndirectedEdge[111, 312] -> 
             RGBColor[
              0.28875139009156847`, 0.4208263972547496, 0.9397553365450895], 
             UndirectedEdge[174, 294] -> 
             RGBColor[
              0.2524849252558091, 0.3827080432856873, 0.9376900150241196], 
             UndirectedEdge[212, 295] -> 
             RGBColor[
              0.22405206726645135`, 0.35282330679155405`, 0.9360708058242697],
              UndirectedEdge[193, 414] -> 
             RGBColor[
              0.28123484292780576`, 0.41292602960901903`, 0.9393272803038482],
              UndirectedEdge[320, 348] -> 
             RGBColor[
              0.9742570536765062, 0.9329947209284535, 0.5686571215977747], 
             UndirectedEdge[247, 468] -> 
             RGBColor[
              0.48669420259584584`, 0.5941593048480999, 0.9527334969294036], 
             UndirectedEdge[449, 488] -> 
             RGBColor[
              0.7488335383665432, 0.8037137186084069, 0.9756003869232444], 
             UndirectedEdge[290, 355] -> 
             RGBColor[
              0.30759602149261944`, 0.4387877870773017, 0.9408960836819469], 
             UndirectedEdge[88, 469] -> 
             RGBColor[
              0.8635204022958338, 0.47315984709282155`, 0.20783041706562805`],
              UndirectedEdge[6, 278] -> 
             RGBColor[
              0.8880267801577246, 0.9132258771339024, 0.9778589426846744], 
             UndirectedEdge[24, 448] -> 
             RGBColor[
              0.7024556642269519, 0.7664802639694746, 0.97172087084446], 
             UndirectedEdge[204, 274] -> 
             RGBColor[
              0.4823136561574142, 0.5906029799080129, 0.9523886442672999], 
             UndirectedEdge[81, 99] -> 
             RGBColor[
              0.9086198401868935, 0.9254801001365643, 0.7650800543815806], 
             UndirectedEdge[213, 368] -> 
             RGBColor[
              0.6561537738248766, 0.5929010247462924, 0.5945021229284573], 
             UndirectedEdge[167, 474] -> 
             RGBColor[
              0.9898837045140847, 0.9900846660867081, 0.8173167265425048], 
             UndirectedEdge[78, 430] -> 
             RGBColor[
              0.22958406238534357`, 0.3586377844102586, 0.9363858447624374], 
             UndirectedEdge[110, 316] -> 
             RGBColor[
              0.26110517012024004`, 0.39176846719329617`, 0.9381809252166395],
              UndirectedEdge[153, 463] -> 
             RGBColor[
              0.25601516257071727`, 0.38641854653362934`, 0.9378910568166856],
              UndirectedEdge[471, 475] -> 
             RGBColor[
              0.847907987036376, 0.36924735854117574`, 0.19351004853135326`], 
             UndirectedEdge[79, 486] -> 
             RGBColor[
              0.9643781566417168, 0.9700792377693064, 0.7816636594414414], 
             UndirectedEdge[49, 402] -> 
             RGBColor[
              0.521262974366249, 0.6222237910767345, 0.9554548772727531], 
             UndirectedEdge[340, 498] -> 
             RGBColor[
              0.39966203669691347`, 0.5203561647804322, 0.9467513952897255], 
             UndirectedEdge[248, 313] -> 
             RGBColor[
              0.254748775686199, 0.38508749362443473`, 0.9378189379570638], 
             UndirectedEdge[37, 429] -> 
             RGBColor[
              0.29961908302642226`, 0.4322490315808106, 0.9403742355804184], 
             UndirectedEdge[18, 166] -> 
             RGBColor[
              0.8612521660936727, 0.43095598829613885`, 0.2046884517082866], 
             UndirectedEdge[147, 238] -> 
             RGBColor[
              0.2858235449724231, 0.4166943062060351, 0.9396272193021288], 
             UndirectedEdge[165, 441] -> 
             RGBColor[
              0.4370828286560343, 0.553000910585295, 0.9490715092381609], 
             UndirectedEdge[13, 154] -> 
             RGBColor[
              0.3030787322552839, 0.435811820273263, 0.9405739494865415], 
             UndirectedEdge[133, 249] -> 
             RGBColor[
              0.3173607671926588, 0.44752867994559636`, 0.9415079167344612], 
             UndirectedEdge[84, 385] -> 
             RGBColor[
              0.2333929402174702, 0.3626411565086264, 0.9366027547202471], 
             UndirectedEdge[125, 438] -> 
             RGBColor[
              0.2150690714922951, 0.34338160867808776`, 0.9355592375040829], 
             UndirectedEdge[21, 489] -> 
             RGBColor[
              0.9854926800563032, 0.9686826013172827, 0.5970125136401502], 
             UndirectedEdge[16, 200] -> 
             RGBColor[
              0.6523550443789783, 0.5834045301394526, 0.5929583920999518], 
             UndirectedEdge[402, 436] -> 
             RGBColor[
              0.5126155235296384, 0.6152034009243532, 0.954774118266239], 
             UndirectedEdge[127, 401] -> 
             RGBColor[
              0.499716094491864, 0.5888978154955886, 0.9571173753725956], 
             UndirectedEdge[195, 395] -> 
             RGBColor[
              0.26756974901772024`, 0.3985631494925233, 0.9385490734213637], 
             UndirectedEdge[27, 297] -> 
             RGBColor[
              0.5157415629468824, 0.6177412605497428, 0.9550202115402241], 
             UndirectedEdge[35, 70] -> 
             RGBColor[
              0.24831129577393707`, 0.37832129407684667`, 0.9374523329994586],
              UndirectedEdge[240, 367] -> 
             RGBColor[
              0.24323530728920995`, 0.3729861083431402, 0.9371632629645055], 
             UndirectedEdge[121, 471] -> 
             RGBColor[
              0.842139262249025, 0.3249064119542755, 0.18798591116014318`], 
             UndirectedEdge[184, 424] -> 
             RGBColor[
              0.28881315240835653`, 0.41979584487067384`, 0.9397989642855475],
              UndirectedEdge[122, 159] -> 
             RGBColor[
              0.8441272348319537, 0.3258751275198433, 0.1893291851678579], 
             UndirectedEdge[158, 324] -> 
             RGBColor[
              0.3635993901479788, 0.48935324953462667`, 0.9443892095152808], 
             UndirectedEdge[180, 465] -> 
             RGBColor[
              0.27637826248324115`, 0.40782145563679656`, 0.9390507052321971],
              UndirectedEdge[254, 454] -> 
             RGBColor[
              0.568190337821955, 0.5020881692235942, 0.5874756893040098], 
             UndirectedEdge[297, 314] -> 
             RGBColor[
              0.42471984107439154`, 0.540499402694099, 0.9487792473402418], 
             UndirectedEdge[262, 393] -> 
             RGBColor[
              0.46864864929250694`, 0.5795091117335374, 0.951312884870325], 
             UndirectedEdge[201, 333] -> 
             RGBColor[
              0.34155395478950024`, 0.4698622181836031, 0.9429990074018386], 
             UndirectedEdge[219, 340] -> 
             RGBColor[
              0.43185173064895377`, 0.5464892084598855, 0.9492854859123644], 
             UndirectedEdge[361, 370] -> 
             RGBColor[
              0.6178223925754994, 0.7005868527844641, 0.9630756852495326], 
             UndirectedEdge[48, 358] -> 
             RGBColor[
              0.2165685446684143, 0.3449576500582796, 0.9356446302831911], 
             UndirectedEdge[287, 299] -> 
             RGBColor[
              0.2094890463187735, 0.33751664842668644`, 0.9352414633253583], 
             UndirectedEdge[62, 233] -> 
             RGBColor[
              0.8302393984490122, 0.2334388442338099, 0.17659058814627704`], 
             UndirectedEdge[61, 91] -> 
             RGBColor[
              0.32572776888358806`, 0.4565507546784424, 0.9419760632968737], 
             UndirectedEdge[204, 340] -> 
             RGBColor[
              0.4196638066192008, 0.5365945026728116, 0.9483260078869054], 
             UndirectedEdge[258, 373] -> 
             RGBColor[
              0.3335189671806654, 0.461900180189882, 0.9425237328349862], 
             UndirectedEdge[167, 210] -> 
             RGBColor[
              0.9113669843928855, 0.6334814540290358, 0.5263699322609554], 
             UndirectedEdge[275, 481] -> 
             RGBColor[
              0.36596032955819924`, 0.49139817658749463`, 0.9445396464868034],
              UndirectedEdge[253, 277] -> 
             RGBColor[
              0.8781666893011308, 0.9046720920391318, 0.9377821758000617], 
             UndirectedEdge[193, 485] -> 
             RGBColor[
              0.2679064543585755, 0.3989170481541139, 0.9385682482924145], 
             UndirectedEdge[89, 260] -> 
             RGBColor[
              0.2855390731059485, 0.4174500484302025, 0.9395723998449554], 
             UndirectedEdge[359, 397] -> 
             RGBColor[
              0.3719996579907838, 0.4966291393303264, 0.9449244671541592], 
             UndirectedEdge[1, 171] -> 
             RGBColor[
              0.2639538573417897, 0.3947626180803467, 0.9383431537396518], 
             UndirectedEdge[193, 330] -> 
             RGBColor[
              0.2971306356015508, 0.42963351556059126`, 0.9402325221809], 
             UndirectedEdge[92, 320] -> 
             RGBColor[
              0.7988700431185324, 0.8415596078670635, 0.9004611644475569], 
             UndirectedEdge[126, 279] -> 
             RGBColor[
              0.26484901945855754`, 0.3957034902216259, 0.9383941318979281], 
             UndirectedEdge[93, 163] -> 
             RGBColor[
              0.26813879509029465`, 0.39916125299440397`, 0.9385814797533685],
              UndirectedEdge[31, 297] -> 
             RGBColor[
              0.48620123605795307`, 0.5937514968840982, 0.9526967874627315], 
             UndirectedEdge[127, 325] -> 
             RGBColor[
              0.20249836583685807`, 0.33016900000545074`, 0.9348433544136983],
              UndirectedEdge[334, 498] -> 
             RGBColor[
              0.4323467950368561, 0.5486660596707702, 0.9488340391891498], 
             UndirectedEdge[41, 300] -> 
             RGBColor[
              0.22924216126039493`, 0.3582784246501542, 0.9363663739991688], 
             UndirectedEdge[330, 496] -> 
             RGBColor[
              0.2916695481926115, 0.42389356644085574`, 0.9399215213319159], 
             UndirectedEdge[18, 227] -> 
             RGBColor[
              0.8650075437066738, 0.45982146624662823`, 0.2082846055515888], 
             UndirectedEdge[156, 350] -> 
             RGBColor[
              0.41473957912155346`, 0.5332684178987681, 0.9477527826875395], 
             UndirectedEdge[315, 386] -> 
             RGBColor[
              0.1822133081343763, 0.30884811821319974`, 0.9336881503865955], 
             UndirectedEdge[29, 479] -> 
             RGBColor[
              0.410555492074131, 0.5300242649407545, 0.9473812108083647], 
             UndirectedEdge[277, 488] -> 
             RGBColor[
              0.7703329161501223, 0.8205091959342619, 0.9777432439776033], 
             UndirectedEdge[242, 374] -> 
             RGBColor[
              0.2383689744042093, 0.367871283937679, 0.936886132505799], 
             UndirectedEdge[244, 363] -> 
             RGBColor[
              0.37362619317772217`, 0.49803796235721676`, 0.9450281085379824],
              UndirectedEdge[335, 409] -> 
             RGBColor[
              0.25916391695491414`, 0.389728087033979, 0.938070373720701], 
             UndirectedEdge[235, 332] -> 
             RGBColor[
              0.37961688858367837`, 0.50322680161675, 0.9454098303518859], 
             UndirectedEdge[249, 440] -> 
             RGBColor[
              0.2856108538657166, 0.41752549455988186`, 0.9395764876530341], 
             UndirectedEdge[96, 265] -> 
             RGBColor[
              0.3085881199169248, 0.4405417508695841, 0.9409265415042412], 
             UndirectedEdge[39, 200] -> 
             RGBColor[
              0.7622447974505207, 0.6739602832535388, 0.6012384342096092], 
             UndirectedEdge[146, 312] -> 
             RGBColor[
              0.28117238396624933`, 0.41286038128029634`, 0.9393237233583873],
              UndirectedEdge[237, 448] -> 
             RGBColor[
              0.7370158535300309, 0.7940376208084021, 0.9750172525524329], 
             UndirectedEdge[31, 162] -> 
             RGBColor[
              0.4575348398128734, 0.5704788250059085, 0.9504400637418493], 
             UndirectedEdge[41, 102] -> 
             RGBColor[
              0.2545321161274702, 0.38485977069120125`, 0.9378065995157133], 
             UndirectedEdge[266, 374] -> 
             RGBColor[
              0.27062553266643685`, 0.40177497185519817`, 0.9387230957795312],
              UndirectedEdge[44, 139] -> 
             RGBColor[
              0.5303562146824653, 0.6296060932112468, 0.9561707304600824], 
             UndirectedEdge[47, 189] -> 
             RGBColor[
              0.24585450838109163`, 0.3757390547576487, 0.9373124225919274], 
             UndirectedEdge[208, 359] -> 
             RGBColor[
              0.3537848938552699, 0.480852426136809, 0.9437638384901277], 
             UndirectedEdge[122, 413] -> 
             RGBColor[
              0.9206701650068785, 0.7073273642826143, 0.2820065056616069], 
             UndirectedEdge[36, 141] -> 
             RGBColor[
              0.28198608489330845`, 0.4136382572421074, 0.9393728955113378], 
             UndirectedEdge[179, 347] -> 
             RGBColor[
              0.17892806853100302`, 0.30539512309383293`, 0.93350106085126], 
             UndirectedEdge[226, 422] -> 
             RGBColor[
              0.20671849831186667`, 0.3346046268085379, 0.9350836847150235], 
             UndirectedEdge[18, 167] -> 
             RGBColor[
              0.9355270875213144, 0.7783260157628717, 0.5479056765432442], 
             UndirectedEdge[112, 452] -> 
             RGBColor[
              0.2361084750925497, 0.3654953558371904, 0.936757400414109], 
             UndirectedEdge[323, 342] -> 
             RGBColor[
              0.2496659047127254, 0.3797450739586806, 0.9375294759745583], 
             UndirectedEdge[74, 82] -> 
             RGBColor[
              0.27000631808527487`, 0.401124138069925, 0.93868783242518], 
             UndirectedEdge[291, 349] -> 
             RGBColor[
              0.5342643053360183, 0.6315079324719315, 0.9569079863163146], 
             UndirectedEdge[86, 136] -> 
             RGBColor[
              0.942076876818933, 0.8389236960734718, 0.594023128493258], 
             UndirectedEdge[11, 23] -> 
             RGBColor[
              0.23070981980428998`, 0.3598210268347142, 0.9364499549820375], 
             UndirectedEdge[249, 470] -> 
             RGBColor[
              0.27251498804399493`, 0.40376090925540187`, 0.9388306974680845],
              UndirectedEdge[35, 135] -> 
             RGBColor[
              0.24449959825218992`, 0.3743149583059091, 0.9372352624644963], 
             UndirectedEdge[161, 326] -> 
             RGBColor[
              0.9327537347132191, 0.7525662704764362, 0.31724881897839763`], 
             UndirectedEdge[26, 139] -> 
             RGBColor[
              0.4753323584108449, 0.5831244997687381, 0.952339366037344], 
             UndirectedEdge[109, 218] -> 
             RGBColor[
              0.24296647092511459`, 0.372703544279266, 0.937147953131278], 
             UndirectedEdge[238, 465] -> 
             RGBColor[
              0.30138975132499524`, 0.433055376037075, 0.940513691725769], 
             UndirectedEdge[258, 314] -> 
             RGBColor[
              0.35174895766394676`, 0.47908900053701325`, 0.9436341104363243],
              UndirectedEdge[28, 493] -> 
             RGBColor[
              0.9792166674892435, 0.9809905167708368, 0.7433381739278018], 
             UndirectedEdge[106, 466] -> 
             RGBColor[
              0.5106817556791221, 0.6136334810680553, 0.9546218849774213], 
             UndirectedEdge[45, 236] -> 
             RGBColor[
              0.285052814306115, 0.4169389596009889, 0.9395447081256605], 
             UndirectedEdge[157, 246] -> 
             RGBColor[
              0.2983825090164457, 0.4309493138930047, 0.9403038145198976], 
             UndirectedEdge[371, 427] -> 
             RGBColor[
              0.3212220231725497, 0.4499441234823203, 0.9417879671446181], 
             UndirectedEdge[341, 450] -> 
             RGBColor[
              0.9056409272943111, 0.562891578052587, 0.35323513131972123`], 
             UndirectedEdge[277, 484] -> 
             RGBColor[
              0.8820966152149525, 0.9042351364524142, 0.7227616167031183], 
             UndirectedEdge[84, 135] -> 
             RGBColor[
              0.24197053087649611`, 0.37165674814192173`, 0.9370912358188704],
              UndirectedEdge[35, 84] -> 
             RGBColor[
              0.2358433607180927, 0.36521670382041393`, 0.9367423025426853], 
             UndirectedEdge[68, 272] -> 
             RGBColor[
              0.8202846954174998, 0.15692263455492186`, 0.1670579532810717], 
             UndirectedEdge[164, 227] -> 
             RGBColor[
              0.8315779382096691, 0.24372744738608088`, 0.17787237533274636`],
              UndirectedEdge[355, 498] -> 
             RGBColor[
              0.3952981571338905, 0.516576391637906, 0.946473332742797], 
             UndirectedEdge[223, 373] -> 
             RGBColor[
              0.3417396383201442, 0.4690205123479532, 0.9430475467307398], 
             UndirectedEdge[116, 192] -> 
             RGBColor[
              0.2516702940273803, 0.3818518142140055, 0.9376436229807996], 
             UndirectedEdge[3, 31] -> 
             RGBColor[
              0.4573521482388232, 0.5703305077559329, 0.9504256815919188], 
             UndirectedEdge[40, 419] -> 
             RGBColor[
              0.44944534633244004`, 0.5620965984995714, 0.950304666943798], 
             UndirectedEdge[282, 324] -> 
             RGBColor[
              0.48866791978392093`, 0.5934906203448358, 0.9535163694747727], 
             UndirectedEdge[250, 339] -> 
             RGBColor[
              0.20806801028262886`, 0.33602304945380984`, 0.9351605374253343],
              UndirectedEdge[259, 405] -> 
             RGBColor[
              0.9279266912954685, 0.7275673838799486, 0.39806227602736116`], 
             UndirectedEdge[22, 441] -> 
             RGBColor[
              0.45077446449645514`, 0.564859917388641, 0.9499439281668742], 
             UndirectedEdge[142, 241] -> 
             RGBColor[
              0.7025032226254809, 0.7675201238280478, 0.9709826140315919], 
             UndirectedEdge[170, 266] -> 
             RGBColor[
              0.29310065604108804`, 0.425397751527083, 0.9400030208067522], 
             UndirectedEdge[105, 153] -> 
             RGBColor[
              0.24541911730613436`, 0.37528143113248, 0.9372876277143118], 
             UndirectedEdge[95, 404] -> 
             RGBColor[
              0.22026561376472564`, 0.3488435040862222, 0.9358551728989024], 
             UndirectedEdge[200, 454] -> 
             RGBColor[
              0.9003552167733437, 0.640418136645701, 0.2385662891695866], 
             UndirectedEdge[96, 131] -> 
             RGBColor[
              0.2798853921380307, 0.4115076712688437, 0.9392504310777041], 
             UndirectedEdge[190, 395] -> 
             RGBColor[
              0.2565485956338361, 0.38697921850457684`, 0.9379214350404868], 
             UndirectedEdge[297, 381] -> 
             RGBColor[
              0.5443345056874556, 0.6409542995639315, 0.9572711527321625], 
             UndirectedEdge[203, 419] -> 
             RGBColor[
              0.5236285855732716, 0.6241443008241659, 0.9556411068524893], 
             UndirectedEdge[107, 209] -> 
             RGBColor[
              0.37529763235099667`, 0.4849566561931139, 0.9463994374355724], 
             UndirectedEdge[205, 252] -> 
             RGBColor[
              0.8648112867502258, 0.89136633503373, 0.7718692919288858], 
             UndirectedEdge[98, 488] -> 
             RGBColor[
              0.8822995191611039, 0.9059842085048606, 0.8501777526166581], 
             UndirectedEdge[182, 275] -> 
             RGBColor[
              0.39614531120522645`, 0.517542890548859, 0.9464630068258206], 
             UndirectedEdge[88, 474] -> 
             RGBColor[
              0.9298536404427284, 0.7393015368665987, 0.48723505332973827`], 
             UndirectedEdge[47, 242] -> 
             RGBColor[
              0.2284706396727983, 0.35746750654429615`, 0.9363224369861192], 
             UndirectedEdge[133, 262] -> 
             RGBColor[
              0.4106297397776527, 0.5294703750419166, 0.9475567521778445], 
             UndirectedEdge[4, 321] -> 
             RGBColor[
              0.32873955000778277`, 0.45915940811169914`, 0.9421679713268938],
              UndirectedEdge[369, 370] -> 
             RGBColor[
              0.5056953807182732, 0.6086792278604158, 0.9544796944704173], 
             UndirectedEdge[49, 436] -> 
             RGBColor[
              0.4815672646188717, 0.5899970256324685, 0.9523298855912635], 
             UndirectedEdge[34, 393] -> 
             RGBColor[
              0.5024822764946291, 0.606976774483756, 0.9539763919403361], 
             UndirectedEdge[268, 324] -> 
             RGBColor[
              0.3896661145929028, 0.5119309360971549, 0.946050158147012], 
             UndirectedEdge[359, 371] -> 
             RGBColor[
              0.37419759071797254`, 0.49853287818730624`, 0.94506451748398], 
             UndirectedEdge[296, 440] -> 
             RGBColor[
              0.29754682970453167`, 0.4296388353177702, 0.94027204609223], 
             UndirectedEdge[113, 143] -> 
             RGBColor[
              0.17905963102166003`, 0.30553340361305714`, 0.9335085531404735],
              UndirectedEdge[270, 489] -> 
             RGBColor[
              0.9900603412249211, 0.9901577099059953, 0.8143893991227904], 
             UndirectedEdge[237, 426] -> 
             RGBColor[
              0.8881333928283652, 0.9136374759753497, 0.9891921499256506], 
             UndirectedEdge[131, 385] -> 
             RGBColor[
              0.24854031848564526`, 0.3785620114677306, 0.9374653755040816], 
             UndirectedEdge[427, 499] -> 
             RGBColor[
              0.27010938266217854`, 0.4012324654749223, 0.9386937018003643], 
             UndirectedEdge[45, 243] -> 
             RGBColor[
              0.5610442905289292, 0.35884112143673136`, 0.5623441481098833], 
             UndirectedEdge[33, 443] -> 
             RGBColor[
              0.9064631162110222, 0.6594290978497701, 0.24321160823769428`], 
             UndirectedEdge[232, 330] -> 
             RGBColor[
              0.3313235898372211, 0.4611852513408379, 0.942340398215439], 
             UndirectedEdge[19, 360] -> 
             RGBColor[
              0.5695454245786704, 0.661421659258773, 0.9592558486179177], 
             UndirectedEdge[44, 370] -> 
             RGBColor[
              0.5440602935407461, 0.6407316817901163, 0.9572495657475013], 
             UndirectedEdge[310, 412] -> 
             RGBColor[
              0.26956927876194814`, 0.4006647820312149, 0.9386629436822582], 
             UndirectedEdge[107, 214] -> 
             RGBColor[
              0.19223940367108877`, 0.31938618031345734`, 0.9342591216951321],
              UndirectedEdge[268, 481] -> 
             RGBColor[
              0.3639357382267393, 0.48964457733510314`, 0.9444106413174386], 
             UndirectedEdge[224, 351] -> 
             RGBColor[
              0.29450587119895527`, 0.4268747217537883, 0.9400830457311632], 
             UndirectedEdge[78, 408] -> 
             RGBColor[
              0.22096681623691122`, 0.34958051234329385`, 0.9358951053423573],
              UndirectedEdge[124, 136] -> 
             RGBColor[
              0.9658066058981951, 0.931025957642273, 0.6234191599847442], 
             UndirectedEdge[51, 315] -> 
             RGBColor[
              0.1822133085396902, 0.30884811863921036`, 0.9336881504096776], 
             UndirectedEdge[24, 270] -> 
             RGBColor[
              0.9134975511433701, 0.9314925430785823, 0.899659555679228], 
             UndirectedEdge[43, 340] -> 
             RGBColor[
              0.31529118717805316`, 0.446068953150221, 0.9413638580453506], 
             UndirectedEdge[116, 483] -> 
             RGBColor[
              0.27268756010159706`, 0.40394229342964216`, 0.9388405251914673],
              UndirectedEdge[50, 169] -> 
             RGBColor[
              0.46684010556596744`, 0.5777047091656451, 0.9512633876302873], 
             UndirectedEdge[247, 369] -> 
             RGBColor[
              0.457479402684923, 0.5695353247878849, 0.9506839560586847], 
             UndirectedEdge[327, 412] -> 
             RGBColor[
              0.2497253233645969, 0.37980752672915763`, 0.9375328597788803], 
             UndirectedEdge[134, 305] -> 
             RGBColor[
              0.2421591297202534, 0.37185497748456803`, 0.9371019762440154], 
             UndirectedEdge[7, 49] -> 
             RGBColor[
              0.6644484112533559, 0.7356118894004525, 0.9687430433701605], 
             UndirectedEdge[81, 486] -> 
             RGBColor[
              0.879272872526262, 0.9065723375988691, 0.9883470255893563], 
             UndirectedEdge[110, 384] -> 
             RGBColor[
              0.27776805045914515`, 0.4092822109171187, 0.9391298516014178], 
             UndirectedEdge[18, 88] -> 
             RGBColor[
              0.8754970234499582, 0.5275428865427625, 0.2178240033304778], 
             UndirectedEdge[11, 41] -> 
             RGBColor[
              0.23572240363091454`, 0.3650895702526674, 0.9367354142155104], 
             UndirectedEdge[231, 288] -> 
             RGBColor[
              0.2572561350755689, 0.3877228873184297, 0.9379617283649826], 
             UndirectedEdge[236, 396] -> 
             RGBColor[
              0.6404346091203621, 0.7039646181731036, 0.7392903949875442], 
             UndirectedEdge[46, 418] -> 
             RGBColor[
              0.9480641688610301, 0.8473510420156326, 0.586962152772621], 
             UndirectedEdge[74, 447] -> 
             RGBColor[
              0.26411698006509043`, 0.39493407040511375`, 0.9383524433374253],
              UndirectedEdge[270, 426] -> 
             RGBColor[
              0.9300987405065613, 0.9447298808495102, 0.9012429919407459], 
             UndirectedEdge[383, 479] -> 
             RGBColor[
              0.37021659707670174`, 0.49508474158579574`, 0.9448108520894127],
              UndirectedEdge[408, 430] -> 
             RGBColor[
              0.23112177962706493`, 0.36025402272821205`, 0.9364734154845045],
              UndirectedEdge[13, 390] -> 
             RGBColor[
              0.29868486413343276`, 0.4312671082913797, 0.9403210331965157], 
             UndirectedEdge[15, 97] -> 
             RGBColor[
              0.23298665056537604`, 0.36221412032402367`, 0.936579617125612], 
             UndirectedEdge[289, 472] -> 
             RGBColor[
              0.3839088844842855, 0.5069443127438695, 0.9456833125354096], 
             UndirectedEdge[254, 315] -> 
             RGBColor[
              0.21099893285942517`, 0.33910363491324724`, 0.9353274491301715],
              UndirectedEdge[347, 386] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[66, 445] -> 
             RGBColor[
              0.24646019520379875`, 0.3763756700110764, 0.9373469155604471], 
             UndirectedEdge[127, 213] -> 
             RGBColor[
              0.5650928544862279, 0.5063763336200533, 0.5889799898461102], 
             UndirectedEdge[423, 446] -> 
             RGBColor[
              0.20798858239401255`, 0.3359395657068551, 0.9351560141245807], 
             UndirectedEdge[63, 410] -> 
             RGBColor[
              0.39150030357105375`, 0.5135196184010107, 0.9461670310467902], 
             UndirectedEdge[107, 421] -> 
             RGBColor[
              0.18186414913512938`, 0.30848112996703203`, 0.9336682662981228],
              UndirectedEdge[226, 308] -> 
             RGBColor[
              0.17918563853241248`, 0.3056658454961956, 0.9335157290817995], 
             UndirectedEdge[51, 386] -> 
             RGBColor[
              0.1789270004053139, 0.3053940004260106, 0.9335010000230821], 
             UndirectedEdge[89, 470] -> 
             RGBColor[
              0.27049191209474743`, 0.40163452816231904`, 0.9387154862856475],
              UndirectedEdge[205, 490] -> 
             RGBColor[
              0.9921900608993205, 0.9897828176678509, 0.6878265810358566], 
             UndirectedEdge[270, 345] -> 
             RGBColor[
              0.824874141314561, 0.8621219539632672, 0.8908628396870938], 
             UndirectedEdge[152, 191] -> 
             RGBColor[
              0.21120215837255008`, 0.3393172378127832, 0.9353390225224988], 
             UndirectedEdge[85, 404] -> 
             RGBColor[
              0.21383193119222793`, 0.3420812957834917, 0.9354887841941792], 
             UndirectedEdge[26, 468] -> 
             RGBColor[
              0.43250328030680874`, 0.5483539247359007, 0.9489677041209118], 
             UndirectedEdge[191, 301] -> 
             RGBColor[
              0.2135770306984165, 0.34181337920287114`, 0.935474267988148], 
             UndirectedEdge[375, 426] -> 
             RGBColor[
              0.9141879156308917, 0.9338323693009003, 0.9715587229445324], 
             UndirectedEdge[39, 213] -> 
             RGBColor[
              0.7639337426080279, 0.681629388750616, 0.6026477314488674], 
             UndirectedEdge[360, 468] -> 
             RGBColor[
              0.5288716731016017, 0.6284008754780657, 0.9560538619087819], 
             UndirectedEdge[80, 278] -> 
             RGBColor[
              0.8689533270990046, 0.8982632673699124, 0.9759744072003973], 
             UndirectedEdge[152, 299] -> 
             RGBColor[
              0.20658465608391344`, 0.3344639501408717, 0.9350760625981434], 
             UndirectedEdge[227, 309] -> 
             RGBColor[
              0.9193309660445672, 0.6696242794444807, 0.3370748612621325], 
             UndirectedEdge[98, 115] -> 
             RGBColor[
              0.9582015589575525, 0.9660972945461519, 0.85752593015656], 
             UndirectedEdge[213, 261] -> 
             RGBColor[
              0.8920963570986589, 0.602916583768641, 0.23167489421385412`], 
             UndirectedEdge[199, 208] -> 
             RGBColor[
              0.33248120157791744`, 0.46240023864087376`, 0.9424063860563303],
              UndirectedEdge[204, 219] -> 
             RGBColor[
              0.5140809753819581, 0.6163931207559199, 0.9548894840041806], 
             UndirectedEdge[52, 166] -> 
             RGBColor[
              0.8369577282992072, 0.2850788714533209, 0.18302406839809204`], 
             UndirectedEdge[218, 300] -> 
             RGBColor[
              0.22896529227619977`, 0.3579874177932576, 0.93635060672011], 
             UndirectedEdge[128, 345] -> 
             RGBColor[
              0.5772342034942839, 0.6673977284070023, 0.9600430222220963], 
             UndirectedEdge[325, 421] -> 
             RGBColor[
              0.17903676307516053`, 0.3055093679513746, 0.9335072508447505], 
             UndirectedEdge[257, 272] -> 
             RGBColor[
              0.8397181825766789, 0.3055916208213189, 0.18563986428858031`], 
             UndirectedEdge[461, 486] -> 
             RGBColor[
              0.9396915520193736, 0.9545227464327241, 0.9862809714214389], 
             UndirectedEdge[115, 203] -> 
             RGBColor[
              0.7278675078772177, 0.786501490374317, 0.9744226233622142], 
             UndirectedEdge[128, 169] -> 
             RGBColor[
              0.4937426983927686, 0.5998815912671589, 0.9532883803380281], 
             UndirectedEdge[190, 356] -> 
             RGBColor[
              0.2587237746657965, 0.38926546958148345`, 0.9380453082684679], 
             UndirectedEdge[46, 272] -> 
             RGBColor[
              0.8691188894851287, 0.4352254750326188, 0.20997245291222838`], 
             UndirectedEdge[121, 450] -> 
             RGBColor[
              0.8225872124582064, 0.17462078949919407`, 0.16926284619957344`],
              UndirectedEdge[255, 269] -> 
             RGBColor[
              0.4232624333249523, 0.5410303787827784, 0.94819088586856], 
             UndirectedEdge[15, 356] -> 
             RGBColor[
              0.2517883622305454, 0.38197591138148856`, 0.9376503467903037], 
             UndirectedEdge[85, 183] -> 
             RGBColor[
              0.20959144808050473`, 0.33762427917091264`, 0.9352472949541991],
              UndirectedEdge[136, 261] -> 
             RGBColor[
              0.924473739268195, 0.762150740681319, 0.5794980394919615], 
             UndirectedEdge[295, 336] -> 
             RGBColor[
              0.22591321478921644`, 0.3547794908415487, 0.9361767954223702], 
             UndirectedEdge[259, 475] -> 
             RGBColor[
              0.8504220451203991, 0.38316771966990754`, 0.19570591448943397`],
              UndirectedEdge[51, 143] -> 
             RGBColor[
              0.17892700107920537`, 0.30539400113431325`, 0.9335010000614592],
              UndirectedEdge[53, 178] -> 
             RGBColor[
              0.9840984713626098, 0.9616310168446078, 0.5753629014776818], 
             UndirectedEdge[67, 385] -> 
             RGBColor[
              0.24504732911062774`, 0.37489065816626943`, 0.9372664549265891],
              UndirectedEdge[69, 173] -> 
             RGBColor[
              0.9470127321552729, 0.9592645667466908, 0.9483609186014075], 
             UndirectedEdge[221, 381] -> 
             RGBColor[
              0.5529574414035745, 0.647954787237104, 0.9579499818185896], 
             UndirectedEdge[140, 334] -> 
             RGBColor[
              0.4512190714580578, 0.563987423855866, 0.9503197339204532], 
             UndirectedEdge[57, 370] -> 
             RGBColor[
              0.5963431626815656, 0.6831772702750474, 0.9613654647247267], 
             UndirectedEdge[432, 467] -> 
             RGBColor[
              0.8027318187709938, 0.8464550865365966, 0.9808037893677689], 
             UndirectedEdge[235, 440] -> 
             RGBColor[
              0.3193577814126447, 0.44853038543702994`, 0.9416618206484036], 
             UndirectedEdge[229, 390] -> 
             RGBColor[
              0.29586463316817824`, 0.4283028667339263, 0.9401604252152023], 
             UndirectedEdge[12, 198] -> 
             RGBColor[
              0.2771414265920781, 0.4086235895025834, 0.9390941662991953], 
             UndirectedEdge[232, 400] -> 
             RGBColor[
              0.3260597275402094, 0.45565259831853255`, 0.9420406290448107], 
             UndirectedEdge[143, 273] -> 
             RGBColor[
              0.23623420851912813`, 0.365627509640484, 0.9367645607467467], 
             UndirectedEdge[115, 277] -> 
             RGBColor[
              0.8462349559465709, 0.8806222819755531, 0.9850914215175051], 
             UndirectedEdge[44, 468] -> 
             RGBColor[
              0.48752713657842917`, 0.5948355181784093, 0.9527990685436503], 
             UndirectedEdge[183, 346] -> 
             RGBColor[
              0.21142499907593382`, 0.3395514575209563, 0.9353517129708931], 
             UndirectedEdge[434, 469] -> 
             RGBColor[
              0.9258166281861495, 0.7248800924627727, 0.5003559242994462], 
             UndirectedEdge[255, 334] -> 
             RGBColor[
              0.40019480220882075`, 0.5210503561228367, 0.9467210368117455], 
             UndirectedEdge[65, 210] -> 
             RGBColor[
              0.9107642708804349, 0.6204193391599911, 0.29010099455145133`], 
             UndirectedEdge[49, 76] -> 
             RGBColor[
              0.45077000854144356`, 0.5638542255344485, 0.9502204534950804], 
             UndirectedEdge[74, 395] -> 
             RGBColor[
              0.2733607929019397, 0.4046499037882272, 0.9388788648034883], 
             UndirectedEdge[52, 88] -> 
             RGBColor[
              0.8512025856554928, 0.3816657696999445, 0.19615962002028325`], 
             UndirectedEdge[312, 354] -> 
             RGBColor[
              0.3330876906173925, 0.4625247982993003, 0.942459704446583], 
             UndirectedEdge[372, 417] -> 
             RGBColor[
              0.5857428674141524, 0.6736726673586156, 0.9611454890036907], 
             UndirectedEdge[354, 415] -> 
             RGBColor[
              0.32438826492045936`, 0.4533811503163769, 0.9419642850227896], 
             UndirectedEdge[301, 451] -> 
             RGBColor[
              0.2100992490740445, 0.3381580102115655, 0.9352762134695569], 
             UndirectedEdge[243, 428] -> 
             RGBColor[
              0.8348198026853184, 0.2686458383399938, 0.18097678841579048`], 
             UndirectedEdge[102, 354] -> 
             RGBColor[
              0.3191507002330799, 0.44787613774915985`, 0.941666013462126], 
             UndirectedEdge[255, 369] -> 
             RGBColor[
              0.40876647484829665`, 0.5284747081383571, 0.9472672162127003], 
             UndirectedEdge[300, 409] -> 
             RGBColor[
              0.23375665444094554`, 0.3630234432183127, 0.936623467707207], 
             UndirectedEdge[93, 187] -> 
             RGBColor[
              0.2669566877883537, 0.3979187832701322, 0.9385141604912941], 
             UndirectedEdge[181, 332] -> 
             RGBColor[
              0.41144462504759094`, 0.5307943872332428, 0.947437865575204], 
             UndirectedEdge[195, 351] -> 
             RGBColor[
              0.2800986877606033, 0.41173185849189103`, 0.9392625779478669], 
             UndirectedEdge[480, 481] -> 
             RGBColor[
              0.33588196619861493`, 0.46534581002792214`, 0.9426230797707831],
              UndirectedEdge[47, 365] -> 
             RGBColor[
              0.22445415871552787`, 0.3532459303986038, 0.9360937043374536], 
             UndirectedEdge[50, 370] -> 
             RGBColor[
              0.5161906822110007, 0.6177697305042253, 0.9551484458009031], 
             UndirectedEdge[122, 150] -> 
             RGBColor[
              0.8444744803276283, 0.32854420856354566`, 0.1896617078466737], 
             UndirectedEdge[246, 256] -> 
             RGBColor[
              0.2918037733500637, 0.42403464559170456`, 0.9399291652560644], 
             UndirectedEdge[63, 282] -> 
             RGBColor[
              0.5134969921724348, 0.6149963149023026, 0.9550984560118821], 
             UndirectedEdge[230, 391] -> 
             RGBColor[
              0.23250262506826308`, 0.3617053788375689, 0.936552052589603], 
             UndirectedEdge[312, 415] -> 
             RGBColor[
              0.29571211190112656`, 0.42814255721184813`, 0.9401517393546788],
              UndirectedEdge[199, 397] -> 
             RGBColor[
              0.3506959657134314, 0.47817695183439113`, 0.9435670147203616], 
             UndirectedEdge[129, 328] -> 
             RGBColor[
              0.3704563897071251, 0.49529243790994043`, 0.944826131463783], 
             UndirectedEdge[188, 304] -> 
             RGBColor[
              0.33792059600024626`, 0.4671115686975821, 0.9427529794590535], 
             UndirectedEdge[323, 395] -> 
             RGBColor[
              0.25216611947306267`, 0.3823729581945666, 0.9376718595064233], 
             UndirectedEdge[49, 238] -> 
             RGBColor[
              0.4051843179606758, 0.5243701915568157, 0.9473157736011174], 
             UndirectedEdge[171, 385] -> 
             RGBColor[
              0.24760690614002792`, 0.37758093591072595`, 0.9374122190518586],
              UndirectedEdge[117, 425] -> 
             RGBColor[
              0.3782090614978762, 0.502007412554475, 0.9453201248548712], 
             UndirectedEdge[32, 103] -> 
             RGBColor[
              0.5080332189208779, 0.6114832796124914, 0.9544133824619024], 
             UndirectedEdge[131, 216] -> 
             RGBColor[
              0.26474751566428445`, 0.3955968032981327, 0.9383883514070055], 
             UndirectedEdge[65, 175] -> 
             RGBColor[
              0.9705975460870158, 0.9645679382577699, 0.6789276620320353], 
             UndirectedEdge[143, 226] -> 
             RGBColor[
              0.17917599682249857`, 0.3056557114477564, 0.9335151800006836], 
             UndirectedEdge[234, 235] -> 
             RGBColor[
              0.3728101836078023, 0.49733117588158576`, 0.9449761131297559], 
             UndirectedEdge[179, 386] -> 
             RGBColor[
              0.17892806853100302`, 0.30539512309383293`, 0.93350106085126], 
             UndirectedEdge[267, 476] -> 
             RGBColor[
              0.9187775169477521, 0.6742536840952063, 0.3030402150761125], 
             UndirectedEdge[59, 195] -> 
             RGBColor[
              0.2561715150223729, 0.3865828828736374, 0.9378999608575047], 
             UndirectedEdge[75, 108] -> 
             RGBColor[
              0.31502960292460824`, 0.4450992956026424, 0.9413743981617775], 
             UndirectedEdge[334, 363] -> 
             RGBColor[
              0.40380771802618465`, 0.5241796822134083, 0.9469512486128518], 
             UndirectedEdge[77, 329] -> 
             RGBColor[
              0.7446878798780471, 0.8004364154026, 0.9754252127138938], 
             UndirectedEdge[328, 462] -> 
             RGBColor[
              0.4245956854340748, 0.5418984360706564, 0.9483550662650316], 
             UndirectedEdge[285, 480] -> 
             RGBColor[
              0.3339827883337351, 0.46370083761681824`, 0.9425020658366099], 
             UndirectedEdge[204, 334] -> 
             RGBColor[
              0.4523485649591434, 0.5649043975631496, 0.9504086517863296], 
             UndirectedEdge[70, 238] -> 
             RGBColor[
              0.28920204195997834`, 0.42024532074903687`, 0.9398196197075317],
              UndirectedEdge[83, 270] -> 
             RGBColor[
              0.955384395176871, 0.9648919755228036, 0.9036547602559704], 
             UndirectedEdge[112, 190] -> 
             RGBColor[
              0.24818657202567745`, 0.37819020150948346`, 0.9374452301665075],
              UndirectedEdge[263, 453] -> 
             RGBColor[
              0.27885374219171843`, 0.41042334176488493`, 0.9391916801394509],
              UndirectedEdge[210, 474] -> 
             RGBColor[
              0.9145804341522545, 0.6348102980864267, 0.4731147536068143], 
             UndirectedEdge[96, 392] -> 
             RGBColor[
              0.3010815634219416, 0.43378619120311424`, 0.9404575216753974], 
             UndirectedEdge[70, 84] -> 
             RGBColor[
              0.24578222839824324`, 0.37566308391285935`, 0.9373083063538328],
              UndirectedEdge[77, 278] -> 
             RGBColor[
              0.7775908081460805, 0.8263457284855322, 0.9672404849556133], 
             UndirectedEdge[238, 265] -> 
             RGBColor[
              0.32058421295120315`, 0.4520956650524487, 0.9416483204611299], 
             UndirectedEdge[157, 392] -> 
             RGBColor[
              0.3042725009406671, 0.4371400688524187, 0.9406392408465198], 
             UndirectedEdge[145, 294] -> 
             RGBColor[
              0.22948545468760678`, 0.35853414146784807`, 0.9363802291999281],
              UndirectedEdge[29, 383] -> 
             RGBColor[
              0.3692814154214852, 0.49427473423964385`, 0.944751263141291], 
             UndirectedEdge[210, 227] -> 
             RGBColor[
              0.8408474405782448, 0.3149769045127923, 0.18674886126930004`], 
             UndirectedEdge[45, 276] -> 
             RGBColor[
              0.4511613140247853, 0.5582811601613382, 0.9513035162562244], 
             UndirectedEdge[57, 219] -> 
             RGBColor[
              0.5637559435916646, 0.6567214977803754, 0.9588000794670529], 
             UndirectedEdge[291, 311] -> 
             RGBColor[
              0.7008920044449292, 0.7662614279396891, 0.9708220228610445], 
             UndirectedEdge[11, 485] -> 
             RGBColor[
              0.24345966129558455`, 0.3732219186287056, 0.9371760395932665], 
             UndirectedEdge[13, 338] -> 
             RGBColor[
              0.30836079438708164`, 0.4403868770076641, 0.9409105178148355], 
             UndirectedEdge[190, 351] -> 
             RGBColor[
              0.2690775343767192, 0.40014792750394457`, 0.9386349395669901], 
             UndirectedEdge[314, 397] -> 
             RGBColor[
              0.34431176305958455`, 0.4726472763749843, 0.9431602189725873], 
             UndirectedEdge[339, 365] -> 
             RGBColor[
              0.2143326753092825, 0.34260760959952685`, 0.9355173008308608], 
             UndirectedEdge[320, 337] -> 
             RGBColor[
              0.9244065988908812, 0.9404637664434601, 0.9125392493325524], 
             UndirectedEdge[317, 357] -> 
             RGBColor[
              0.895271303645258, 0.6164935275347583, 0.23428070819651722`], 
             UndirectedEdge[153, 452] -> 
             RGBColor[
              0.2344431943228335, 0.36374504016331954`, 0.9366625651378359], 
             UndirectedEdge[308, 423] -> 
             RGBColor[
              0.1833860881198116, 0.31008078433643804`, 0.9337549384717936], 
             UndirectedEdge[149, 441] -> 
             RGBColor[
              0.4020035872776604, 0.5226170348372846, 0.946836290996886], 
             UndirectedEdge[486, 493] -> 
             RGBColor[
              0.9642524295918031, 0.9698103203224957, 0.7679790459557528], 
             UndirectedEdge[241, 402] -> 
             RGBColor[
              0.6288966867837086, 0.7086387216585579, 0.9645893173262957], 
             UndirectedEdge[293, 432] -> 
             RGBColor[
              0.9264483908194477, 0.943709860746635, 0.9762410122023322], 
             UndirectedEdge[23, 211] -> 
             RGBColor[
              0.226770956748013, 0.3556810320242251, 0.9362256425580082], 
             UndirectedEdge[8, 381] -> 
             RGBColor[
              0.5947992155017207, 0.6819238244004215, 0.9612439195470645], 
             UndirectedEdge[238, 343] -> 
             RGBColor[
              0.306520714368336, 0.43844834351747275`, 0.9408058924805078], 
             UndirectedEdge[355, 363] -> 
             RGBColor[
              0.366759080123219, 0.492090014180544, 0.9445905421664991], 
             UndirectedEdge[66, 398] -> 
             RGBColor[
              0.26221606410223275`, 0.392936087203117, 0.9382441889854937], 
             UndirectedEdge[113, 477] -> 
             RGBColor[
              0.2119319440670913, 0.3400842888488316, 0.9353805827381816], 
             UndirectedEdge[7, 241] -> 
             RGBColor[
              0.7720821236708154, 0.8220268199822758, 0.9778774834237032], 
             UndirectedEdge[161, 259] -> 
             RGBColor[
              0.9260863286561598, 0.722291136783578, 0.31168537193130974`], 
             UndirectedEdge[346, 408] -> 
             RGBColor[
              0.22019359510263653`, 0.34876780790611966`, 0.9358510715426385],
              UndirectedEdge[33, 270] -> 
             RGBColor[
              0.9342186701882929, 0.7654658229940685, 0.5176324949764846], 
             UndirectedEdge[197, 270] -> 
             RGBColor[
              0.843824355466433, 0.8769260052856713, 0.8927516199339326], 
             UndirectedEdge[115, 381] -> 
             RGBColor[
              0.7452365910783697, 0.8006024945852935, 0.9757899812168571], 
             UndirectedEdge[112, 224] -> 
             RGBColor[
              0.2736149088479135, 0.4049169957593272, 0.9388933363306806], 
             UndirectedEdge[133, 296] -> 
             RGBColor[
              0.3292967430314739, 0.4596420207034847, 0.942203475173657], 
             UndirectedEdge[204, 244] -> 
             RGBColor[
              0.42216704011068096`, 0.5387626777069581, 0.9484855117114601], 
             UndirectedEdge[116, 280] -> 
             RGBColor[
              0.25280916302349343`, 0.3830488377373854, 0.9377084798853226], 
             UndirectedEdge[81, 267] -> 
             RGBColor[
              0.906340376624757, 0.9184812574076573, 0.6975246745106891], 
             UndirectedEdge[431, 459] -> 
             RGBColor[
              0.41954302397723237`, 0.5378088133487329, 0.9479538883938678], 
             UndirectedEdge[46, 293] -> 
             RGBColor[
              0.9359635798708703, 0.8383264425596675, 0.6074452935938994], 
             UndirectedEdge[145, 358] -> 
             RGBColor[
              0.2231421897482483, 0.351866967830356, 0.9360189896456512], 
             UndirectedEdge[12, 480] -> 
             RGBColor[
              0.31297532312712917`, 0.4421451064609878, 0.9412865192071291], 
             UndirectedEdge[318, 321] -> 
             RGBColor[
              0.33755888801482614`, 0.46679827542058316`, 0.9427299317460682],
              UndirectedEdge[38, 47] -> 
             RGBColor[
              0.24595116399713765`, 0.375840645938433, 0.9373179269862719], 
             UndirectedEdge[271, 492] -> 
             RGBColor[
              0.2662123163354113, 0.39713640167721365`, 0.9384717696382479], 
             UndirectedEdge[246, 333] -> 
             RGBColor[
              0.33643527177961996`, 0.46448215779697133`, 0.9427075059768388],
              UndirectedEdge[97, 137] -> 
             RGBColor[
              0.2259075246268314, 0.35477351012010483`, 0.9361764713760403], 
             UndirectedEdge[406, 486] -> 
             RGBColor[
              0.9627729895914936, 0.9654828212213326, 0.7058550168364002], 
             UndirectedEdge[272, 306] -> 
             RGBColor[
              0.8390812230199529, 0.30140098239829205`, 0.18505752934082234`],
              UndirectedEdge[50, 219] -> 
             RGBColor[
              0.48360346312109975`, 0.5913139580095534, 0.9525830605432293], 
             UndirectedEdge[326, 405] -> 
             RGBColor[
              0.9345940973525277, 0.7578425175728066, 0.403625723074449], 
             UndirectedEdge[180, 343] -> 
             RGBColor[
              0.28150922552658186`, 0.4132144231171943, 0.9393429059869358], 
             UndirectedEdge[229, 380] -> 
             RGBColor[
              0.2819134302618612, 0.4136392679220333, 0.9393659248486427], 
             UndirectedEdge[184, 470] -> 
             RGBColor[
              0.2562569900664413, 0.3866727225643841, 0.9379048285348154], 
             UndirectedEdge[188, 483] -> 
             RGBColor[
              0.31696315839045336`, 0.4478408551549855, 0.9414585414299963], 
             UndirectedEdge[364, 374] -> 
             RGBColor[
              0.2551484985501697, 0.3855076276983612, 0.93784170158283], 
             UndirectedEdge[161, 469] -> 
             RGBColor[
              0.9253813180460291, 0.7190898482623855, 0.3110970937968252], 
             UndirectedEdge[14, 182] -> 
             RGBColor[
              0.34266467028924463`, 0.47103542678761523`, 0.9430620495117685],
              UndirectedEdge[374, 391] -> 
             RGBColor[
              0.24642877472957408`, 0.3763426451004932, 0.9373451262109225], 
             UndirectedEdge[352, 367] -> 
             RGBColor[
              0.2288379775147259, 0.35785360190672644`, 0.9363433563327893], 
             UndirectedEdge[8, 289] -> 
             RGBColor[
              0.5298323406094952, 0.6288020963090049, 0.9562341229930127], 
             UndirectedEdge[160, 275] -> 
             RGBColor[
              0.4180928553323577, 0.5365527501561378, 0.9478614849301503], 
             UndirectedEdge[118, 151] -> 
             RGBColor[
              0.31595121433390305`, 0.44790234871507695`, 0.9413597168905753],
              UndirectedEdge[43, 217] -> 
             RGBColor[
              0.30643378623989703`, 0.43839711764350564`, 0.9407994722898634],
              UndirectedEdge[117, 154] -> 
             RGBColor[
              0.34530823850037556`, 0.4735103733174856, 0.9432237135065259], 
             UndirectedEdge[139, 468] -> 
             RGBColor[
              0.5212061017709153, 0.6221776193417614, 0.9554504000537172], 
             UndirectedEdge[279, 324] -> 
             RGBColor[
              0.3241188367997081, 0.45236629730551653`, 0.9419757314019449], 
             UndirectedEdge[4, 29] -> 
             RGBColor[
              0.36696197867847585`, 0.49226575471112954`, 0.9446034706830237],
              UndirectedEdge[239, 393] -> 
             RGBColor[
              0.4060710006373207, 0.5259256972403187, 0.9471546820617923], 
             UndirectedEdge[94, 127] -> 
             RGBColor[
              0.5906994451507328, 0.6605608453144329, 0.9482643190369882], 
             UndirectedEdge[157, 459] -> 
             RGBColor[
              0.3465448636437761, 0.4740080224761397, 0.94332350710475], 
             UndirectedEdge[48, 85] -> 
             RGBColor[
              0.21086321568284044`, 0.3389609875556907, 0.9353197202377406], 
             UndirectedEdge[26, 215] -> 
             RGBColor[
              0.33537631974199883`, 0.4626312893738342, 0.942674216260174], 
             UndirectedEdge[63, 165] -> 
             RGBColor[
              0.42168442508772075`, 0.5396635873606885, 0.9480903365790616], 
             UndirectedEdge[165, 282] -> 
             RGBColor[
              0.5158458225400988, 0.6170307537111264, 0.9552481214059205], 
             UndirectedEdge[288, 465] -> 
             RGBColor[
              0.2693457460924733, 0.4004298350228071, 0.9386502138274186], 
             UndirectedEdge[200, 500] -> 
             RGBColor[
              0.8601603348227043, 0.3966998445648045, 0.2026301493422178], 
             UndirectedEdge[293, 353] -> 
             RGBColor[
              0.7969674264911133, 0.8418814193634385, 0.9635324755439242], 
             UndirectedEdge[239, 296] -> 
             RGBColor[
              0.33217516852493173`, 0.46213516819204603`, 0.9423868859008084],
              UndirectedEdge[139, 274] -> 
             RGBColor[
              0.5133847204187874, 0.6158278696108893, 0.9548346722630138], 
             UndirectedEdge[140, 361] -> 
             RGBColor[
              0.5719177559547599, 0.6633194007954346, 0.9594619041005235], 
             UndirectedEdge[83, 197] -> 
             RGBColor[
              0.8091856625186589, 0.8516756760168047, 0.981399600787607], 
             UndirectedEdge[256, 444] -> 
             RGBColor[
              0.28033959264989716`, 0.411985064804791, 0.9392762971249253], 
             UndirectedEdge[21, 166] -> 
             RGBColor[
              0.9095040888434207, 0.6206039273550481, 0.282195231981873], 
             UndirectedEdge[92, 363] -> 
             RGBColor[
              0.506974473041424, 0.6093066729422614, 0.9546939442160238], 
             UndirectedEdge[41, 212] -> 
             RGBColor[
              0.22552146354030395`, 0.35436773544047784`, 0.9361544857682886],
              UndirectedEdge[96, 433] -> 
             RGBColor[
              0.31083399291217784`, 0.4424870131772134, 0.9410696465455513], 
             UndirectedEdge[346, 407] -> 
             RGBColor[
              0.2161204994130187, 0.34448672608714886`, 0.9356191147687198], 
             UndirectedEdge[32, 155] -> 
             RGBColor[
              0.5507999265063706, 0.6462032194486154, 0.9577801343426442], 
             UndirectedEdge[302, 477] -> 
             RGBColor[
              0.21741049289010705`, 0.3458425910218791, 0.9356925779888657], 
             UndirectedEdge[24, 489] -> 
             RGBColor[
              0.9135348042436461, 0.9315079481929074, 0.8990421753997224], 
             UndirectedEdge[359, 427] -> 
             RGBColor[
              0.3324756951564906, 0.4596914885288097, 0.9425050411722034], 
             UndirectedEdge[217, 290] -> 
             RGBColor[
              0.3031025001174864, 0.43489572471311266`, 0.9406097604733883], 
             UndirectedEdge[40, 297] -> 
             RGBColor[
              0.4527821832454718, 0.5648055930283604, 0.9505673549688282], 
             UndirectedEdge[41, 456] -> 
             RGBColor[
              0.22809260204387605`, 0.3570701650273288, 0.9363009083024085], 
             UndirectedEdge[341, 469] -> 
             RGBColor[
              0.927002024559022, 0.7238962731152077, 0.3735657841038871], 
             UndirectedEdge[169, 498] -> 
             RGBColor[
              0.4773158479045384, 0.5865455340196324, 0.9519951984940587], 
             UndirectedEdge[6, 329] -> 
             RGBColor[
              0.8551238518896912, 0.8873165640509703, 0.9860436704429549], 
             UndirectedEdge[92, 219] -> 
             RGBColor[
              0.5677032440041356, 0.6599260940790765, 0.9591108254149605], 
             UndirectedEdge[341, 387] -> 
             RGBColor[
              0.8843435887930974, 0.9064532397024012, 0.7600495256450741], 
             UndirectedEdge[13, 478] -> 
             RGBColor[
              0.28132910192119526`, 0.41302510178743673`, 0.939332648214078], 
             UndirectedEdge[33, 267] -> 
             RGBColor[
              0.9337384293685642, 0.7577785430140971, 0.3161344657047144], 
             UndirectedEdge[10, 123] -> 
             RGBColor[
              0.21296296597852177`, 0.34116795824830987`, 0.9354392979107774],
              UndirectedEdge[57, 337] -> 
             RGBColor[
              0.730726843956438, 0.7892639238928545, 0.9741400277373693], 
             UndirectedEdge[70, 135] -> 
             RGBColor[
              0.25443846593234043`, 0.3847613383983545, 0.9378012662756438], 
             UndirectedEdge[51, 130] -> 
             RGBColor[
              0.1789270004053139, 0.3053940004260106, 0.9335010000230821], 
             UndirectedEdge[219, 361] -> 
             RGBColor[
              0.5852351734855985, 0.6741310802897922, 0.9605102999918589], 
             UndirectedEdge[70, 131] -> 
             RGBColor[
              0.2609296066664183, 0.3915839388719636, 0.9381709271376673], 
             UndirectedEdge[61, 362] -> 
             RGBColor[
              0.3561441161626767, 0.48289586592152384`, 0.9439141660493773], 
             UndirectedEdge[49, 487] -> 
             RGBColor[
              0.5348230464505574, 0.633232468469062, 0.9565223758194106], 
             UndirectedEdge[83, 375] -> 
             RGBColor[
              0.9394735703012015, 0.9539944639741937, 0.9739704912597569], 
             UndirectedEdge[147, 385] -> 
             RGBColor[
              0.24248237828575928`, 0.37219473222205746`, 0.9371203847716176],
              UndirectedEdge[105, 395] -> 
             RGBColor[
              0.2554464216840092, 0.38582076380144426`, 0.9378586678645644], 
             UndirectedEdge[57, 204] -> 
             RGBColor[
              0.5515680195619116, 0.6468267919933015, 0.9578406014415939], 
             UndirectedEdge[362, 363] -> 
             RGBColor[
              0.3966364490357477, 0.5179682894523514, 0.9464943016940854], 
             UndirectedEdge[313, 390] -> 
             RGBColor[
              0.28385568108857195`, 0.41568069668672125`, 0.9394765331599213],
              UndirectedEdge[15, 430] -> 
             RGBColor[
              0.23698890967688827`, 0.36642074840810707`, 0.9368075398612009],
              UndirectedEdge[104, 430] -> 
             RGBColor[
              0.24315634658411125`, 0.3729031156356836, 0.937158766269162], 
             UndirectedEdge[341, 405] -> 
             RGBColor[
              0.9937930272646951, 0.989132237877419, 0.5657875066366207], 
             UndirectedEdge[8, 311] -> 
             RGBColor[
              0.6835752486050087, 0.752395433322769, 0.9693271520415703], 
             UndirectedEdge[305, 460] -> 
             RGBColor[
              0.24972906299601538`, 0.37981145731888477`, 0.9375330727453572],
              UndirectedEdge[451, 456] -> 
             RGBColor[
              0.21755217330464396`, 0.3459915061206145, 0.9357006464788762], 
             UndirectedEdge[257, 306] -> 
             RGBColor[
              0.8582164736566054, 0.4477775920644729, 0.2033538487175496], 
             UndirectedEdge[65, 167] -> 
             RGBColor[
              0.986067541242265, 0.9756937071602725, 0.6343029674871418], 
             UndirectedEdge[24, 329] -> 
             RGBColor[
              0.8597649491834076, 0.8910172490537498, 0.986486342445986], 
             UndirectedEdge[14, 63] -> 
             RGBColor[
              0.3630391373968948, 0.48868276614576933`, 0.9443602925394342], 
             UndirectedEdge[64, 172] -> 
             RGBColor[
              0.31974345189880926`, 0.449434024298521, 0.9416655397334055], 
             UndirectedEdge[50, 361] -> 
             RGBColor[
              0.5425697371949871, 0.6391572117563517, 0.9572443985054486], 
             UndirectedEdge[253, 291] -> 
             RGBColor[
              0.819979493708928, 0.8592158126034372, 0.9319826199336896], 
             UndirectedEdge[184, 280] -> 
             RGBColor[
              0.2569621251304517, 0.38741386422480434`, 0.9379449849335569], 
             UndirectedEdge[402, 487] -> 
             RGBColor[
              0.565871305361324, 0.6584388437609466, 0.958966608494386], 
             UndirectedEdge[356, 463] -> 
             RGBColor[
              0.26821764598055253`, 0.3992441302795001, 0.9385859701949193], 
             UndirectedEdge[287, 301] -> 
             RGBColor[
              0.20928219811004087`, 0.33729923784437454`, 0.9352296836258756],
              UndirectedEdge[265, 328] -> 
             RGBColor[
              0.35316375548579293`, 0.48031442730049023`, 0.9437242601024758],
              UndirectedEdge[196, 321] -> 
             RGBColor[
              0.31443739392836134`, 0.4455653460211614, 0.9413008174322348], 
             UndirectedEdge[122, 267] -> 
             RGBColor[
              0.9282834555711476, 0.7330087810415269, 0.3115827018545064], 
             UndirectedEdge[330, 354] -> 
             RGBColor[
              0.3341066984387609, 0.463595840128386, 0.9425177354345229], 
             UndirectedEdge[155, 393] -> 
             RGBColor[
              0.5135503027141461, 0.615962296777659, 0.9548477075078524], 
             UndirectedEdge[291, 319] -> 
             RGBColor[
              0.6849084125962169, 0.7537749245076777, 0.969228927800723], 
             UndirectedEdge[63, 206] -> 
             RGBColor[
              0.3810348762200533, 0.5044549912372471, 0.9455001832701985], 
             UndirectedEdge[174, 215] -> 
             RGBColor[
              0.2753901052316153, 0.40678283971254936`, 0.9389944311385647], 
             UndirectedEdge[254, 471] -> 
             RGBColor[
              0.5466554162409889, 0.4017985093907806, 0.5694083486000513], 
             UndirectedEdge[453, 463] -> 
             RGBColor[
              0.2757020968027919, 0.407110762635264, 0.939012198596993], 
             UndirectedEdge[154, 174] -> 
             RGBColor[
              0.2880991557381853, 0.4200673355937856, 0.9397208847641902], 
             UndirectedEdge[119, 197] -> 
             RGBColor[
              0.8441364985929255, 0.8770550844901885, 0.8875786005274353], 
             UndirectedEdge[50, 340] -> 
             RGBColor[
              0.3891862943583425, 0.5115153399264449, 0.9460195844259542], 
             UndirectedEdge[443, 446] -> 
             RGBColor[
              0.5813316267430582, 0.5676003433786956, 0.6012346277346379], 
             UndirectedEdge[275, 324] -> 
             RGBColor[
              0.3916907059243627, 0.5136845353495464, 0.9461791633163769], 
             UndirectedEdge[95, 286] -> 
             RGBColor[
              0.22509159237078977`, 0.3539159135859121, 0.9361300052411223], 
             UndirectedEdge[306, 317] -> 
             RGBColor[
              0.8704899188810679, 0.5035084402927961, 0.2135951122625132], 
             UndirectedEdge[118, 188] -> 
             RGBColor[
              0.3311926249986076, 0.4612841383736176, 0.9423242790961401], 
             UndirectedEdge[7, 69] -> 
             RGBColor[
              0.874072307624645, 0.9024255483118935, 0.9878509910664408], 
             UndirectedEdge[88, 166] -> 
             RGBColor[
              0.8523652692557177, 0.3906026653424749, 0.19727300714892185`], 
             UndirectedEdge[9, 44] -> 
             RGBColor[
              0.5359104641208152, 0.634115283121385, 0.9566079813217554], 
             UndirectedEdge[76, 459] -> 
             RGBColor[
              0.40093570974009674`, 0.5216920929873327, 0.9467682467844796], 
             UndirectedEdge[254, 325] -> 
             RGBColor[
              0.20775758490962407`, 0.33569677270467635`, 0.935142859159575], 
             UndirectedEdge[171, 433] -> 
             RGBColor[
              0.2936242383072788, 0.42439846992600005`, 0.9400895764803525], 
             UndirectedEdge[112, 447] -> 
             RGBColor[
              0.2473817363738829, 0.37734426820991973`, 0.9373993959667855], 
             UndirectedEdge[199, 359] -> 
             RGBColor[
              0.364147570424561, 0.48982805573786037`, 0.9444241390777679], 
             UndirectedEdge[74, 224] -> 
             RGBColor[
              0.2903501525391211, 0.42250679795452123`, 0.9398463837013205], 
             UndirectedEdge[292, 386] -> 
             RGBColor[
              0.17894881608916835`, 0.3054169300929359, 0.9335022423940041], 
             UndirectedEdge[112, 195] -> 
             RGBColor[
              0.25920772540956155`, 0.3897741324974299, 0.9380728685473844], 
             UndirectedEdge[97, 408] -> 
             RGBColor[
              0.2271195205155527, 0.3560473946441286, 0.9362454927489157], 
             UndirectedEdge[236, 422] -> 
             RGBColor[
              0.26066758061653217`, 0.39130853288012224`, 0.9381560051417591],
              UndirectedEdge[27, 114] -> 
             RGBColor[
              0.5063987002640795, 0.610156303732676, 0.9542847071658003], 
             UndirectedEdge[110, 355] -> 
             RGBColor[
              0.30021105187484454`, 0.43102571577490256`, 0.9404755205872981],
              UndirectedEdge[104, 215] -> 
             RGBColor[
              0.26534838496499225`, 0.39622835503049064`, 0.9384225700247744],
              UndirectedEdge[80, 406] -> 
             RGBColor[
              0.8900806471760057, 0.9077659645302347, 0.6988562638191269], 
             UndirectedEdge[276, 292] -> 
             RGBColor[
              0.39925539426111123`, 0.5037247474643232, 0.9483475509136101], 
             UndirectedEdge[425, 466] -> 
             RGBColor[
              0.4394255113443823, 0.5536672437102792, 0.9495973233231294], 
             UndirectedEdge[164, 309] -> 
             RGBColor[
              0.9052777371288019, 0.5616050038337315, 0.3236174733815438], 
             UndirectedEdge[95, 137] -> 
             RGBColor[
              0.22358173079098384`, 0.35232895333478276`, 0.9360440208577924],
              UndirectedEdge[119, 426] -> 
             RGBColor[
              0.9304108836330538, 0.9448589600540273, 0.8960699725342486], 
             UndirectedEdge[238, 431] -> 
             RGBColor[
              0.38434692528377257`, 0.5073237216678145, 0.9457112241078087], 
             UndirectedEdge[93, 266] -> 
             RGBColor[
              0.2794030113306438, 0.41100065845557043`, 0.9392229602043418], 
             UndirectedEdge[15, 148] -> 
             RGBColor[
              0.2369473179686802, 0.36637703288571377`, 0.9368051712749479], 
             UndirectedEdge[225, 470] -> 
             RGBColor[
              0.26486570011979793`, 0.3957210226542046, 0.9383950818369088], 
             UndirectedEdge[249, 296] -> 
             RGBColor[
              0.3014838445951241, 0.4337768875889444, 0.9404962532659576], 
             UndirectedEdge[273, 421] -> 
             RGBColor[
              0.236299010735822, 0.36569562087892715`, 0.9367682511371211], 
             UndirectedEdge[150, 159] -> 
             RGBColor[
              0.821097410502475, 0.1631695188320622, 0.16783621016427433`], 
             UndirectedEdge[85, 407] -> 
             RGBColor[
              0.2142869484175896, 0.3425595477371053, 0.9355146967520258], 
             UndirectedEdge[71, 388] -> 
             RGBColor[
              0.8509768197746642, 0.8842586853652235, 0.9761468351078537], 
             UndirectedEdge[61, 435] -> 
             RGBColor[
              0.2909721876561818, 0.42176628331072286`, 0.9399328603098349], 
             UndirectedEdge[10, 177] -> 
             RGBColor[
              0.21382948684753797`, 0.34207872662224226`, 0.9354886449923652],
              UndirectedEdge[16, 52] -> 
             RGBColor[
              0.6198385630520318, 0.4001930339226935, 0.5644333341255259], 
             UndirectedEdge[25, 459] -> 
             RGBColor[
              0.35196069990557133`, 0.47927240102423385`, 0.9436476024647243],
              UndirectedEdge[105, 453] -> 
             RGBColor[
              0.265106051538209, 0.39597364723411466`, 0.9384087694946193], 
             UndirectedEdge[61, 384] -> 
             RGBColor[
              0.3038237458344487, 0.43527408579193255`, 0.9406647375359107], 
             UndirectedEdge[104, 323] -> 
             RGBColor[
              0.2429591667599799, 0.3726958671385986, 0.9371475371698791], 
             UndirectedEdge[150, 406] -> 
             RGBColor[
              0.9060315184464693, 0.5729271685521393, 0.29311167174990027`], 
             UndirectedEdge[413, 493] -> 
             RGBColor[
              0.9837066431260291, 0.9560378233723712, 0.44758049868418615`], 
             UndirectedEdge[94, 254] -> 
             RGBColor[
              0.5959586642234989, 0.6660886180136586, 0.9485638237828649], 
             UndirectedEdge[431, 487] -> 
             RGBColor[
              0.5139856537736541, 0.6161859985800608, 0.9549178263261018], 
             UndirectedEdge[234, 332] -> 
             RGBColor[
              0.3953853483413155, 0.5168846489129837, 0.946414582664141], 
             UndirectedEdge[82, 89] -> 
             RGBColor[
              0.2718901700216876, 0.4031041858982062, 0.9387951150060494], 
             UndirectedEdge[154, 255] -> 
             RGBColor[
              0.3535633647009796, 0.4806605487177418, 0.9437497228483069], 
             UndirectedEdge[22, 324] -> 
             RGBColor[
              0.41054698853962773`, 0.5300168996065678, 0.9473806689706655], 
             UndirectedEdge[105, 112] -> 
             RGBColor[
              0.2470843980758506, 0.3770317468063509, 0.9373824629905851], 
             UndirectedEdge[6, 406] -> 
             RGBColor[
              0.9091541002347256, 0.9227285742942248, 0.700740799303404], 
             UndirectedEdge[396, 422] -> 
             RGBColor[
              0.6137790328303492, 0.6759479174311498, 0.7377723993512193], 
             UndirectedEdge[409, 456] -> 
             RGBColor[
              0.23260709522442666`, 0.3618151835954873, 0.9365580020104467], 
             UndirectedEdge[91, 473] -> 
             RGBColor[
              0.32723005291391416`, 0.4578519575985201, 0.9420717875068684], 
             UndirectedEdge[369, 379] -> 
             RGBColor[
              0.3646233115605392, 0.49024011879839996`, 0.944454452882271], 
             UndirectedEdge[353, 441] -> 
             RGBColor[
              0.5448974710637005, 0.6413248437593597, 0.9573393706579376], 
             UndirectedEdge[165, 481] -> 
             RGBColor[
              0.3711249763330434, 0.49587153404117, 0.9448687332123786], 
             UndirectedEdge[185, 318] -> 
             RGBColor[
              0.3129435362062064, 0.4431846498190406, 0.9412454229080396], 
             UndirectedEdge[264, 445] -> 
             RGBColor[
              0.23221275436386601`, 0.3614007063483834, 0.9365355448818129], 
             UndirectedEdge[258, 297] -> 
             RGBColor[
              0.4463933258988235, 0.5592718859080008, 0.9501602626281445], 
             UndirectedEdge[57, 139] -> 
             RGBColor[
              0.5826390838232848, 0.6720516816961779, 0.9602866294373078], 
             UndirectedEdge[447, 463] -> 
             RGBColor[
              0.2567986541117429, 0.38724204581948013`, 0.9379356755008752], 
             UndirectedEdge[9, 26] -> 
             RGBColor[
              0.4808866078491948, 0.5876336896788764, 0.952776616899017], 
             UndirectedEdge[181, 262] -> 
             RGBColor[
              0.4483915053521436, 0.5621777184210172, 0.9499628984888329], 
             UndirectedEdge[203, 291] -> 
             RGBColor[
              0.5947468881404891, 0.681688814806365, 0.9613714325118958], 
             UndirectedEdge[45, 254] -> 
             RGBColor[
              0.25964036057789125`, 0.3902288594899984, 0.9380975064801944], 
             UndirectedEdge[240, 412] -> 
             RGBColor[
              0.2495035202048371, 0.3795743975451175, 0.9375202284170604], 
             UndirectedEdge[208, 258] -> 
             RGBColor[
              0.3477704837485026, 0.4756430463953687, 0.9433806055964585], 
             UndirectedEdge[293, 420] -> 
             RGBColor[
              0.9614575711812897, 0.9707757002112165, 0.9501264579014013], 
             UndirectedEdge[85, 346] -> 
             RGBColor[
              0.21604910573121133`, 0.34441168680094847`, 0.9356150490041585],
              UndirectedEdge[65, 166] -> 
             RGBColor[
              0.9117926198146232, 0.6283236796935395, 0.2910857426521841], 
             UndirectedEdge[254, 347] -> 
             RGBColor[
              0.20771262472504887`, 0.3356495167000475, 0.935140298743576], 
             UndirectedEdge[236, 292] -> 
             RGBColor[
              0.23314689454244097`, 0.36238254690397387`, 0.9365887427830462],
              UndirectedEdge[100, 401] -> 
             RGBColor[
              0.8523336151346661, 0.7939714926704016, 0.620783111215081], 
             UndirectedEdge[146, 400] -> 
             RGBColor[
              0.276927529490606, 0.4083987700870767, 0.9390819851756989], 
             UndirectedEdge[104, 153] -> 
             RGBColor[
              0.24575331572793313`, 0.3756326948631943, 0.937306659820031], 
             UndirectedEdge[216, 281] -> 
             RGBColor[
              0.2553973215721218, 0.3857691564707237, 0.9378558716858294], 
             UndirectedEdge[123, 125] -> 
             RGBColor[
              0.2078185513522534, 0.33576085230137553`, 0.9351463311082908], 
             UndirectedEdge[78, 358] -> 
             RGBColor[
              0.22252765585105994`, 0.3512210537407115, 0.9359839928493279], 
             UndirectedEdge[313, 478] -> 
             RGBColor[
              0.26649991887633445`, 0.3974386901827782, 0.9384881481774836], 
             UndirectedEdge[368, 401] -> 
             RGBColor[
              0.5907770138305127, 0.6754225066218276, 0.9626395084549426], 
             UndirectedEdge[106, 369] -> 
             RGBColor[
              0.46890138102995677`, 0.5788082013626439, 0.9515831360340911], 
             UndirectedEdge[111, 146] -> 
             RGBColor[
              0.2655122364597581, 0.39640057334027434`, 0.9384319011250047], 
             UndirectedEdge[129, 266] -> 
             RGBColor[
              0.32256025857167225`, 0.4520297101069751, 0.9418393155552645], 
             UndirectedEdge[99, 278] -> 
             RGBColor[
              0.9709926371751241, 0.9748878865987054, 0.7597061890098948], 
             UndirectedEdge[147, 171] -> 
             RGBColor[
              0.2566176973332457, 0.3870518487719572, 0.9379253702800414], 
             UndirectedEdge[164, 166] -> 
             RGBColor[
              0.8278225605966679, 0.21486196943559147`, 0.17427622148944416`],
              UndirectedEdge[129, 433] -> 
             RGBColor[
              0.3405530126531223, 0.4693916356931953, 0.94292071472042], 
             UndirectedEdge[179, 283] -> 
             RGBColor[
              0.18007164814629245`, 0.3065970977766376, 0.9335661860185762], 
             UndirectedEdge[136, 291] -> 
             RGBColor[
              0.8119439013123007, 0.853362410017863, 0.9518331785269256], 
             UndirectedEdge[321, 479] -> 
             RGBColor[
              0.37233306340343797`, 0.49691791834132404`, 0.9449457114522347],
              UndirectedEdge[181, 239] -> 
             RGBColor[
              0.38581385669695734`, 0.5085943039277986, 0.9458046956803003], 
             UndirectedEdge[102, 330] -> 
             RGBColor[
              0.2914935550351155, 0.4237085864737168, 0.939911498781955], 
             UndirectedEdge[406, 413] -> 
             RGBColor[
              0.9822272031257195, 0.951710324271208, 0.3854564695648335], 
             UndirectedEdge[37, 310] -> 
             RGBColor[
              0.30119863479716524`, 0.4339092406412282, 0.9404641887170249], 
             UndirectedEdge[203, 439] -> 
             RGBColor[
              0.6977395599110665, 0.7624782824674698, 0.971548992789666], 
             UndirectedEdge[320, 375] -> 
             RGBColor[
              0.9734019680069053, 0.9789510679067093, 0.8970939407523506], 
             UndirectedEdge[42, 407] -> 
             RGBColor[
              0.22341630550160935`, 0.352155080867081, 0.9360346001322872], 
             UndirectedEdge[131, 374] -> 
             RGBColor[
              0.2576696859737398, 0.38815755553304865`, 0.9379852794768397], 
             UndirectedEdge[387, 403] -> 
             RGBColor[
              0.8520128910253049, 0.8851986373727346, 0.9856507029983317], 
             UndirectedEdge[65, 348] -> 
             RGBColor[
              0.9726882187211612, 0.9195330900145834, 0.3483993164391773], 
             UndirectedEdge[217, 498] -> 
             RGBColor[
              0.3908046357587574, 0.5126843292737169, 0.9461870095342384], 
             UndirectedEdge[40, 397] -> 
             RGBColor[
              0.37237410523066483`, 0.4969534667092458, 0.9449483266011737], 
             UndirectedEdge[226, 292] -> 
             RGBColor[
              0.17919781223777545`, 0.3056786408323896, 0.9335164223563106], 
             UndirectedEdge[53, 257] -> 
             RGBColor[
              0.9176828698612274, 0.692200433274696, 0.28359567952116765`], 
             UndirectedEdge[220, 429] -> 
             RGBColor[
              0.3162555864633567, 0.44694588722950834`, 0.9414237848069549], 
             UndirectedEdge[139, 425] -> 
             RGBColor[
              0.469689014710176, 0.5782365190979204, 0.9519797771669503], 
             UndirectedEdge[317, 418] -> 
             RGBColor[
              0.9309369071770426, 0.7734480360326559, 0.5728708276939365], 
             UndirectedEdge[482, 496] -> 
             RGBColor[
              0.31768549080207875`, 0.4466395905233832, 0.9415714600344062], 
             UndirectedEdge[117, 466] -> 
             RGBColor[
              0.44229172329685795`, 0.5561498124435122, 0.9497799558142495], 
             UndirectedEdge[82, 105] -> 
             RGBColor[
              0.25209194686734443`, 0.382294998083142, 0.9376676354862561], 
             UndirectedEdge[239, 453] -> 
             RGBColor[
              0.31761867457160725`, 0.44726749674536337`, 0.9415420928317004],
              UndirectedEdge[274, 340] -> 
             RGBColor[
              0.40008441142440987`, 0.5206990676119785, 0.9467846461754836], 
             UndirectedEdge[311, 484] -> 
             RGBColor[
              0.8698742834500395, 0.8946869579845022, 0.7215434088969761], 
             UndirectedEdge[44, 140] -> 
             RGBColor[
              0.4981556569200065, 0.6034642298010868, 0.9536357845984921], 
             UndirectedEdge[139, 466] -> 
             RGBColor[
              0.5337716765091578, 0.6323789189869576, 0.9564396081263286], 
             UndirectedEdge[22, 481] -> 
             RGBColor[
              0.38481661217346425`, 0.507730540844516, 0.9457411521410921], 
             UndirectedEdge[45, 386] -> 
             RGBColor[
              0.23085473585284239`, 0.35997334278995086`, 0.9364582077366184],
              UndirectedEdge[40, 220] -> 
             RGBColor[
              0.36255668140028763`, 0.48845010762544216`, 0.9443227690359091],
              UndirectedEdge[237, 489] -> 
             RGBColor[
              0.9480949935467251, 0.959065305031835, 0.9023385571076953], 
             UndirectedEdge[61, 64] -> 
             RGBColor[
              0.3058305702683475, 0.43738338551197825`, 0.9407790232185906], 
             UndirectedEdge[82, 296] -> 
             RGBColor[
              0.28584922180975014`, 0.4173439077491774, 0.9396058846276822], 
             UndirectedEdge[27, 277] -> 
             RGBColor[
              0.6417102241932708, 0.7180330594388474, 0.9662874050409727], 
             UndirectedEdge[416, 427] -> 
             RGBColor[
              0.2705169061527906, 0.4016607985020373, 0.9387169096602777], 
             UndirectedEdge[59, 82] -> 
             RGBColor[
              0.25023486400687867`, 0.3803430862509384, 0.9375618773646605], 
             UndirectedEdge[271, 444] -> 
             RGBColor[
              0.26354918336029226`, 0.3943372800679805, 0.938320108155067], 
             UndirectedEdge[6, 486] -> 
             RGBColor[
              0.8813087089314302, 0.9081956582870432, 0.9885412054830938], 
             UndirectedEdge[171, 265] -> 
             RGBColor[
              0.29137836531202577`, 0.42245320761837074`, 0.9399464714390425],
              UndirectedEdge[219, 369] -> 
             RGBColor[
              0.47310816162837227`, 0.5822234553657439, 0.9519143092127434], 
             UndirectedEdge[244, 355] -> 
             RGBColor[
              0.3355739158146536, 0.46507899226839733`, 0.9426034510727153], 
             UndirectedEdge[450, 500] -> 
             RGBColor[
              0.8186005728713881, 0.14397773067830186`, 0.16544523562897076`],
              UndirectedEdge[18, 243] -> 
             RGBColor[
              0.8618450148200435, 0.43551288339499367`, 0.2052561643181862], 
             UndirectedEdge[377, 449] -> 
             RGBColor[
              0.8547039434845443, 0.8865518671157351, 0.9452111853810878], 
             UndirectedEdge[7, 173] -> 
             RGBColor[
              0.9116225315818571, 0.9310453814508525, 0.9449853696775101], 
             UndirectedEdge[3, 8] -> 
             RGBColor[
              0.5409798313044035, 0.6382308237734111, 0.9570070604761514], 
             UndirectedEdge[405, 469] -> 
             RGBColor[
              0.9272216806853377, 0.724366095358756, 0.3974739978928766], 
             UndirectedEdge[148, 190] -> 
             RGBColor[
              0.2438827304039313, 0.37366659108570865`, 0.9372001327531121], 
             UndirectedEdge[180, 216] -> 
             RGBColor[
              0.2680084621160904, 0.3990242647749275, 0.9385740574832979], 
             UndirectedEdge[257, 317] -> 
             RGBColor[
              0.8711268784377937, 0.5076990787158229, 0.21417744721027115`], 
             UndirectedEdge[49, 462] -> 
             RGBColor[
              0.4770465403942916, 0.586326898050649, 0.9519739976203461], 
             UndirectedEdge[223, 258] -> 
             RGBColor[
              0.3816431136278576, 0.5049818159089863, 0.9455389396199805], 
             UndirectedEdge[260, 440] -> 
             RGBColor[
              0.28362513416460355`, 0.4154383772521112, 0.9394634038536649], 
             UndirectedEdge[262, 332] -> 
             RGBColor[
              0.43913893362174417`, 0.5541636058359223, 0.9493733327998998], 
             UndirectedEdge[283, 386] -> 
             RGBColor[
              0.18007057961528944`, 0.30659597468280464`, 0.9335661251673164],
              UndirectedEdge[40, 289] -> 
             RGBColor[
              0.41278560473143366`, 0.5319558764357888, 0.9475233116148768], 
             UndirectedEdge[95, 430] -> 
             RGBColor[
              0.23341097282813747`, 0.36266010992577125`, 0.9366037816507478],
              UndirectedEdge[274, 334] -> 
             RGBColor[
              0.4327691697643524, 0.5490089625023165, 0.9488672900749079], 
             UndirectedEdge[75, 158] -> 
             RGBColor[
              0.3512349205505469, 0.4786437674256428, 0.9436013564460036], 
             UndirectedEdge[233, 476] -> 
             RGBColor[
              0.8458261121541704, 0.35324515591315253`, 0.19151644279301172`],
              UndirectedEdge[240, 416] -> 
             RGBColor[
              0.2590796192147955, 0.38963948476432886`, 0.9380655730891085], 
             UndirectedEdge[260, 280] -> 
             RGBColor[
              0.27123440340689225`, 0.4024149336080515, 0.9387577700674566], 
             UndirectedEdge[11, 193] -> 
             RGBColor[
              0.2633649248993141, 0.3941436127428313, 0.9383096149083003], 
             UndirectedEdge[3, 162] -> 
             RGBColor[
              0.4618487252450588, 0.5739886270587315, 0.9507775699403673], 
             UndirectedEdge[117, 338] -> 
             RGBColor[
              0.3505903006321732, 0.47808543005188675`, 0.9435602818348199], 
             UndirectedEdge[40, 472] -> 
             RGBColor[
              0.35732343693452717`, 0.4839173342997152, 0.9439893113261273], 
             UndirectedEdge[101, 355] -> 
             RGBColor[
              0.424769765192925, 0.5405027707410431, 0.9487934456872616], 
             UndirectedEdge[47, 364] -> 
             RGBColor[
              0.24525016381875867`, 0.3751038503049783, 0.93727800606315], 
             UndirectedEdge[377, 484] -> 
             RGBColor[
              0.9869984046810305, 0.9863165950507087, 0.692275872605006], 
             UndirectedEdge[21, 227] -> 
             RGBColor[
              0.9132594664564218, 0.6494694053055374, 0.28579138582517527`], 
             UndirectedEdge[158, 441] -> 
             RGBColor[
              0.4038268661048062, 0.5241962673166999, 0.9469524687114896], 
             UndirectedEdge[201, 222] -> 
             RGBColor[
              0.3735862388275236, 0.49760697262793063`, 0.9450400762157048], 
             UndirectedEdge[107, 477] -> 
             RGBColor[
              0.21467165996386678`, 0.3429639039643634, 0.9355366055054566], 
             UndirectedEdge[89, 239] -> 
             RGBColor[
              0.31821611673686917`, 0.4478954463410748, 0.9415761162791756], 
             UndirectedEdge[63, 275] -> 
             RGBColor[
              0.41651977831287657`, 0.5351902299070133, 0.9477612498534863], 
             UndirectedEdge[133, 344] -> 
             RGBColor[
              0.404458323018091, 0.5244601408973477, 0.9470709156438875], 
             UndirectedEdge[153, 356] -> 
             RGBColor[
              0.2571354474729763, 0.3875960369960689, 0.9379548553845563], 
             UndirectedEdge[151, 188] -> 
             RGBColor[
              0.32203573450029344`, 0.4531724542663287, 0.9417474171352478], 
             UndirectedEdge[140, 204] -> 
             RGBColor[
              0.5007635578511195, 0.6055814412615623, 0.9538410881128452], 
             UndirectedEdge[154, 369] -> 
             RGBColor[
              0.36474431369771637`, 0.4903449247678786, 0.944462163031454], 
             UndirectedEdge[16, 179] -> 
             RGBColor[
              0.29140560923354364`, 0.4148201691111312, 0.940228554342059], 
             UndirectedEdge[161, 341] -> 
             RGBColor[
              0.9919526646253864, 0.9838559907810486, 0.4794106025405692], 
             UndirectedEdge[48, 408] -> 
             RGBColor[
              0.21500770505426564`, 0.34331710866086196`, 0.9355557427762207],
              UndirectedEdge[153, 263] -> 
             RGBColor[
              0.25916680795964386`, 0.3897311256632503, 0.9380705383591434], 
             UndirectedEdge[62, 132] -> 
             RGBColor[
              0.9037259559281465, 0.5621573598635239, 0.4887023579770914], 
             UndirectedEdge[82, 225] -> 
             RGBColor[
              0.2662639580467382, 0.39719068039009175`, 0.9384747105573108], 
             UndirectedEdge[216, 465] -> 
             RGBColor[
              0.27425578181697063`, 0.40559059388349944`, 0.9389298330981818],
              UndirectedEdge[119, 489] -> 
             RGBColor[
              0.9903724843514137, 0.9902867891105125, 0.8092163797162932], 
             UndirectedEdge[287, 295] -> 
             RGBColor[
              0.2196997994484176, 0.34824879736508285`, 0.9358229506106359], 
             UndirectedEdge[28, 417] -> 
             RGBColor[
              0.8329443683967894, 0.8698408046783143, 0.9576048606613091], 
             UndirectedEdge[148, 351] -> 
             RGBColor[
              0.26485064633186906`, 0.3957052001686261, 0.9383942245459564], 
             UndirectedEdge[218, 336] -> 
             RGBColor[
              0.2271057420788739, 0.35603291263357584`, 0.9362447080873302], 
             UndirectedEdge[127, 254] -> 
             RGBColor[
              0.23123903037733173`, 0.3603772607008694, 0.9364800927412753], 
             UndirectedEdge[303, 473] -> 
             RGBColor[
              0.31604489027716914`, 0.44784149062043943`, 0.9413708849892584],
              UndirectedEdge[99, 267] -> 
             RGBColor[
              0.9913420700473246, 0.9817665875606343, 0.479566100729647], 
             UndirectedEdge[48, 145] -> 
             RGBColor[
              0.21408452170973263`, 0.34234678443255295`, 0.9355031688504769],
              UndirectedEdge[224, 342] -> 
             RGBColor[
              0.2794767176957349, 0.41107812851853454`, 0.939227157672795], 
             UndirectedEdge[193, 232] -> 
             RGBColor[
              0.32200467219797546`, 0.4513904780484862, 0.9418096996419872], 
             UndirectedEdge[216, 343] -> 
             RGBColor[
              0.2793867448603114, 0.4109835613638972, 0.9392220338529205], 
             UndirectedEdge[277, 449] -> 
             RGBColor[
              0.7498021540184663, 0.8044704085174408, 0.9756969294792002], 
             UndirectedEdge[257, 418] -> 
             RGBColor[
              0.9186634619525802, 0.7177171878043327, 0.5626295641489729], 
             UndirectedEdge[45, 422] -> 
             RGBColor[
              0.2583972380161019, 0.3889222588590351, 0.9380267124893356], 
             UndirectedEdge[133, 235] -> 
             RGBColor[
              0.3511076947395869, 0.47853357082274445`, 0.9435932497298307], 
             UndirectedEdge[145, 183] -> 
             RGBColor[
              0.21281275410739692`, 0.3410100760477749, 0.9354307435669353], 
             UndirectedEdge[196, 496] -> 
             RGBColor[
              0.2862944389618104, 0.41824398583767475`, 0.9396154168129832], 
             UndirectedEdge[115, 136] -> 
             RGBColor[
              0.9450645210490293, 0.9581750855858149, 0.964884369377244], 
             UndirectedEdge[267, 413] -> 
             RGBColor[
              0.981449315920919, 0.9490863280728146, 0.38243452466585603`], 
             UndirectedEdge[217, 340] -> 
             RGBColor[
              0.32857716094804046`, 0.4590187548700618, 0.9421576240396021], 
             UndirectedEdge[335, 383] -> 
             RGBColor[
              0.3028573462736385, 0.4337853452642071, 0.940627021112898], 
             UndirectedEdge[80, 493] -> 
             RGBColor[
              0.8915600871763152, 0.912093463631398, 0.7609802929384797], 
             UndirectedEdge[307, 372] -> 
             RGBColor[
              0.47013131999468205`, 0.580712810603117, 0.9514296061392018], 
             UndirectedEdge[18, 434] -> 
             RGBColor[
              0.9377932493402739, 0.7792631319127137, 0.510349510564296], 
             UndirectedEdge[130, 179] -> 
             RGBColor[
              0.17892806853100302`, 0.30539512309383293`, 0.93350106085126], 
             UndirectedEdge[20, 228] -> 
             RGBColor[
              0.9388076655030091, 0.7780938721344945, 0.3568427286125849], 
             UndirectedEdge[297, 311] -> 
             RGBColor[
              0.6331105387907436, 0.7114259084862791, 0.9653543852266682], 
             UndirectedEdge[127, 200] -> 
             RGBColor[
              0.5634039093287206, 0.4987072281229762, 0.587570692606852], 
             UndirectedEdge[54, 391] -> 
             RGBColor[
              0.23492401226674847`, 0.36425041030799266`, 0.9366899470084354],
              UndirectedEdge[347, 368] -> 
             RGBColor[
              0.2935143249909316, 0.4166464351270609, 0.9403629270800464], 
             UndirectedEdge[22, 182] -> 
             RGBColor[
              0.4150015938204914, 0.5338752548058805, 0.9476645124801093], 
             UndirectedEdge[96, 216] -> 
             RGBColor[
              0.2810238579235662, 0.4127042709923413, 0.9393152650199811], 
             UndirectedEdge[340, 363] -> 
             RGBColor[
              0.37112295968624204`, 0.49586978732307024`, 0.9448686047134276],
              UndirectedEdge[71, 490] -> 
             RGBColor[
              0.8731675486403643, 0.8997516085621015, 0.891254202422064], 
             UndirectedEdge[111, 201] -> 
             RGBColor[
              0.28877500860148286`, 0.42085122180616963`, 0.9397566815842886],
              UndirectedEdge[261, 484] -> 
             RGBColor[
              0.9364392575786439, 0.7675671876801757, 0.34462692180178206`], 
             UndirectedEdge[416, 499] -> 
             RGBColor[
              0.26112616120390136`, 0.3917905301531358, 0.9381821206278006], 
             UndirectedEdge[42, 430] -> 
             RGBColor[
              0.2361066473396595, 0.36549343475301654`, 0.9367572963262859], 
             UndirectedEdge[6, 81] -> 
             RGBColor[
              0.825653983169494, 0.8638180906717614, 0.9832328080563602], 
             UndirectedEdge[282, 353] -> 
             RGBColor[
              0.6236604649477651, 0.705354686885191, 0.9635159828256973], 
             UndirectedEdge[275, 441] -> 
             RGBColor[
              0.43191818188119013`, 0.5485275531316196, 0.9487424225125856], 
             UndirectedEdge[50, 255] -> 
             RGBColor[
              0.41926177634102413`, 0.5375652107821666, 0.9479359675431862], 
             UndirectedEdge[110, 217] -> 
             RGBColor[
              0.29571753049971145`, 0.4271336534107135, 0.9401891973787395], 
             UndirectedEdge[30, 110] -> 
             RGBColor[
              0.26982326266389456`, 0.40093173521567016`, 0.9386774076897386],
              UndirectedEdge[77, 482] -> 
             RGBColor[
              0.4826496570055525, 0.5883007255405965, 0.9531265853256541], 
             UndirectedEdge[52, 326] -> 
             RGBColor[
              0.8554852780065134, 0.4011124754177182, 0.19973320349637064`], 
             UndirectedEdge[44, 247] -> 
             RGBColor[
              0.4958443155073958, 0.6015877787175854, 0.9534538273357688], 
             UndirectedEdge[337, 348] -> 
             RGBColor[
              0.9100611549268829, 0.8839036332529456, 0.6426467308354947], 
             UndirectedEdge[48, 78] -> 
             RGBColor[
              0.21346998781254425`, 0.3417008703429085, 0.9354681720541533], 
             UndirectedEdge[420, 432] -> 
             RGBColor[
              0.933633649289228, 0.949068614748616, 0.9640782438285385], 
             UndirectedEdge[469, 474] -> 
             RGBColor[
              0.9267639161265591, 0.7252718203703219, 0.4846569116242533], 
             UndirectedEdge[172, 366] -> 
             RGBColor[
              0.3083293758751098, 0.43743710670339436`, 0.941015524989468], 
             UndirectedEdge[102, 415] -> 
             RGBColor[
              0.28177512151681394`, 0.41349389666170766`, 0.9393580483702217],
              UndirectedEdge[414, 485] -> 
             RGBColor[
              0.26132957932407624`, 0.39200433549489333`, 0.9381937049888145],
              UndirectedEdge[102, 193] -> 
             RGBColor[
              0.2821746373958698, 0.4139138131813651, 0.9393808002085031], 
             UndirectedEdge[128, 498] -> 
             RGBColor[
              0.4783163619958606, 0.5873577964316139, 0.9520739626283314], 
             UndirectedEdge[150, 443] -> 
             RGBColor[
              0.8779783180841267, 0.47195372718941886`, 0.21716686938390278`],
              UndirectedEdge[2, 230] -> 
             RGBColor[
              0.21816285424353754`, 0.34663337050679954`, 0.9357354238549247],
              UndirectedEdge[367, 416] -> 
             RGBColor[
              0.24568937276892794`, 0.3755654867590621, 0.9373030183631108], 
             UndirectedEdge[61, 473] -> 
             RGBColor[
              0.3253289757704718, 0.4562053401277858, 0.9419506525523447], 
             UndirectedEdge[56, 164] -> 
             RGBColor[
              0.8270991589089857, 0.20930158706742483`, 0.17358349121635427`],
              UndirectedEdge[20, 388] -> 
             RGBColor[
              0.9153530643766437, 0.7639768167303482, 0.6006827363489642], 
             UndirectedEdge[195, 296] -> 
             RGBColor[
              0.29178587282524443`, 0.4235837043718764, 0.9399439681205266], 
             UndirectedEdge[135, 391] -> 
             RGBColor[
              0.24587699790050546`, 0.37576269266847045`, 0.9373137033367878],
              UndirectedEdge[310, 399] -> 
             RGBColor[
              0.26912901254486776`, 0.40020203432257306`, 0.938637871172511], 
             UndirectedEdge[150, 476] -> 
             RGBColor[
              0.834968541704233, 0.26978911161722496`, 0.18111922106827977`], 
             UndirectedEdge[142, 222] -> 
             RGBColor[
              0.5711190039988594, 0.6615355308329243, 0.9600580034664301], 
             UndirectedEdge[48, 404] -> 
             RGBColor[
              0.21047959213928613`, 0.3385577748882776, 0.9352978734444553], 
             UndirectedEdge[330, 415] -> 
             RGBColor[
              0.29673111972249494`, 0.4292135990409338, 0.9402097703426187], 
             UndirectedEdge[326, 495] -> 
             RGBColor[
              0.8586889913459645, 0.42573762002087545`, 0.2028010830083056], 
             UndirectedEdge[36, 382] -> 
             RGBColor[
              0.26830699274776615`, 0.39933803939675394`, 0.9385910583611354],
              UndirectedEdge[31, 289] -> 
             RGBColor[
              0.4462046575439149, 0.5609017802915265, 0.9496527441087801], 
             UndirectedEdge[436, 487] -> 
             RGBColor[
              0.5261755956139467, 0.6262120783166807, 0.9558416168128965], 
             UndirectedEdge[251, 427] -> 
             RGBColor[
              0.2690226652198594, 0.4000902565411794, 0.9386318148496786], 
             UndirectedEdge[108, 437] -> 
             RGBColor[
              0.27047057871071917`, 0.40161210542309067`, 0.938714271380987], 
             UndirectedEdge[258, 397] -> 
             RGBColor[
              0.36598524788401654`, 0.49141975958888606`, 0.94454123426049], 
             UndirectedEdge[308, 422] -> 
             RGBColor[
              0.20647914454706495`, 0.3343530508258261, 0.9350700538722102], 
             UndirectedEdge[16, 292] -> 
             RGBColor[
              0.29142635679170903`, 0.41484197611023416`, 0.9402297358848033],
              UndirectedEdge[68, 317] -> 
             RGBColor[
              0.8516933912786147, 0.35903009244942585`, 0.19559553620276254`],
              UndirectedEdge[34, 468] -> 
             RGBColor[
              0.51106504599871, 0.6139446534165288, 0.9546520589954179], 
             UndirectedEdge[350, 383] -> 
             RGBColor[
              0.34555625661750283`, 0.4737251941447882, 0.9432395170016354], 
             UndirectedEdge[190, 342] -> 
             RGBColor[
              0.25404838087349885`, 0.38435133426869084`, 0.9377790515086218],
              UndirectedEdge[61, 303] -> 
             RGBColor[
              0.31454260624684305`, 0.4465402877003618, 0.9412751607792637], 
             UndirectedEdge[214, 421] -> 
             RGBColor[
              0.18943186031713002`, 0.3164352742399168, 0.9340992362545124], 
             UndirectedEdge[219, 370] -> 
             RGBColor[
              0.5588561185016121, 0.6527435990376659, 0.9584143472873132], 
             UndirectedEdge[91, 366] -> 
             RGBColor[
              0.29631757138809034`, 0.4270330853875859, 0.9402501434291768], 
             UndirectedEdge[273, 477] -> 
             RGBColor[
              0.2691065215645594, 0.4001783948762585, 0.9386365903444549], 
             UndirectedEdge[153, 323] -> 
             RGBColor[
              0.24213881509518778`, 0.3718336255256024, 0.9371008193561707], 
             UndirectedEdge[170, 433] -> 
             RGBColor[
              0.31109341012253816`, 0.4427596771133032, 0.9410844199719078], 
             UndirectedEdge[1, 54] -> 
             RGBColor[
              0.24744314331957223`, 0.3774088108032645, 0.937402893001499], 
             UndirectedEdge[277, 377] -> 
             RGBColor[
              0.8762033212681233, 0.9033473444415901, 0.9473540424354466], 
             UndirectedEdge[307, 417] -> 
             RGBColor[
              0.5854211152910297, 0.6734114544902967, 0.9611201594979415], 
             UndirectedEdge[58, 371] -> 
             RGBColor[
              0.3390278312734188, 0.4680706002399412, 0.9428235315115703], 
             UndirectedEdge[9, 269] -> 
             RGBColor[
              0.512041509774998, 0.614618499836106, 0.9547617797005311], 
             UndirectedEdge[184, 453] -> 
             RGBColor[
              0.2706693526642461, 0.401821029451244, 0.9387255912635806], 
             UndirectedEdge[42, 97] -> 
             RGBColor[
              0.23210438822814727`, 0.3612868066689332, 0.936529373590697], 
             UndirectedEdge[161, 405] -> 
             RGBColor[
              0.9921723207517021, 0.9843258130245969, 0.5033188163295588], 
             UndirectedEdge[304, 429] -> 
             RGBColor[
              0.316081007071654, 0.4467946753350308, 0.9414126607624902], 
             UndirectedEdge[127, 130] -> 
             RGBColor[
              0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993],
              UndirectedEdge[318, 330] -> 
             RGBColor[
              0.32419593809646025`, 0.45501163764918373`, 0.9418862305492528],
              UndirectedEdge[393, 468] -> 
             RGBColor[
              0.4697942541627981, 0.5804391653761509, 0.9514030710822032], 
             UndirectedEdge[334, 355] -> 
             RGBColor[
              0.36575544066311605`, 0.49122071212458884`, 0.9445265911475849],
              UndirectedEdge[290, 378] -> 
             RGBColor[
              0.28478483318943354`, 0.41665729445637256`, 0.939529446997508], 
             UndirectedEdge[92, 498] -> 
             RGBColor[
              0.5355135500520953, 0.6337930503996233, 0.9565767347923217], 
             UndirectedEdge[340, 362] -> 
             RGBColor[
              0.3629480512357022, 0.4887890925060583, 0.944347706775747], 
             UndirectedEdge[58, 304] -> 
             RGBColor[
              0.3268378953241502, 0.4575122904046801, 0.94204679957202], 
             UndirectedEdge[51, 308] -> 
             RGBColor[
              0.1789366427891193, 0.3054041351827525, 0.9335015491425751], 
             UndirectedEdge[59, 447] -> 
             RGBColor[
              0.2443455259866942, 0.3741530185861272, 0.9372264882769058], 
             UndirectedEdge[186, 485] -> 
             RGBColor[
              0.24185580045044375`, 0.3715361591898116, 0.9370847020908353], 
             UndirectedEdge[340, 379] -> 
             RGBColor[
              0.32336688058112073`, 0.45450587189254155`, 0.941825629581892], 
             UndirectedEdge[129, 410] -> 
             RGBColor[
              0.3596323931506261, 0.48591723612258636`, 0.9441364359744873], 
             UndirectedEdge[192, 225] -> 
             RGBColor[
              0.26443196618769516`, 0.395265140791245, 0.9383703813311275], 
             UndirectedEdge[306, 420] -> 
             RGBColor[
              0.9131111718754747, 0.7098607039273219, 0.5703676016486996], 
             UndirectedEdge[16, 45] -> 
             RGBColor[
              0.343332276555383, 0.46939838880724916`, 0.9431857012274175], 
             UndirectedEdge[334, 361] -> 
             RGBColor[
              0.5235027630627838, 0.6226423570970218, 0.9560294677740079], 
             UndirectedEdge[306, 357] -> 
             RGBColor[
              0.8823608988640697, 0.5565720408834082, 0.22345710970379568`], 
             UndirectedEdge[335, 496] -> 
             RGBColor[
              0.27683085763382376`, 0.40829716183624876`, 0.9390764798564684],
              UndirectedEdge[176, 345] -> 
             RGBColor[
              0.6333349002315553, 0.7129428013259062, 0.9644594745728776], 
             UndirectedEdge[15, 78] -> 
             RGBColor[
              0.22683394628673456`, 0.35574723802318886`, 0.9362292297190538],
              UndirectedEdge[52, 210] -> 
             RGBColor[
              0.8359293793650189, 0.2771745309197725, 0.1820393202973592], 
             UndirectedEdge[392, 465] -> 
             RGBColor[
              0.2943134873153461, 0.42667251409427237`, 0.9400720897535981], 
             UndirectedEdge[354, 414] -> 
             RGBColor[
              0.3182109057650159, 0.4468883541768137, 0.941612493557471], 
             UndirectedEdge[56, 428] -> 
             RGBColor[
              0.8335035522712653, 0.25852856087297227`, 0.179716345532801], 
             UndirectedEdge[44, 425] -> 
             RGBColor[
              0.43601004951768985`, 0.5508944179345684, 0.9493284456568833], 
             UndirectedEdge[106, 468] -> 
             RGBColor[
              0.4981161809408796, 0.6034321814228589, 0.9536326769048099], 
             UndirectedEdge[142, 461] -> 
             RGBColor[
              0.8219899053555546, 0.8616442791794481, 0.9747961115925544], 
             UndirectedEdge[203, 297] -> 
             RGBColor[
              0.5269654224863035, 0.6268532953529551, 0.9559037948775195], 
             UndirectedEdge[24, 176] -> 
             RGBColor[
              0.7219583100603643, 0.7823133904412213, 0.9732561905650118], 
             UndirectedEdge[351, 356] -> 
             RGBColor[
              0.2796916905937343, 0.4113040786644009, 0.9392394000613121], 
             UndirectedEdge[315, 368] -> 
             RGBColor[
              0.2968006331253079, 0.42010055334026064`, 0.9405500774666419], 
             UndirectedEdge[278, 406] -> 
             RGBColor[
              0.969491060817788, 0.9705130400681918, 0.6951727540379807], 
             UndirectedEdge[247, 360] -> 
             RGBColor[
              0.5371888520305683, 0.6351531360172418, 0.9567086207009003], 
             UndirectedEdge[78, 145] -> 
             RGBColor[
              0.22004363289237822`, 0.3486101881149849, 0.9358425314166136], 
             UndirectedEdge[19, 466] -> 
             RGBColor[
              0.5316163498821903, 0.6306291277348275, 0.9562699329190321], 
             UndirectedEdge[60, 151] -> 
             RGBColor[
              0.2997519610227203, 0.4323886947798715, 0.9403818027857322], 
             UndirectedEdge[109, 186] -> 
             RGBColor[
              0.24483520726957755`, 0.37466770466202415`, 0.9372543749015474],
              UndirectedEdge[474, 495] -> 
             RGBColor[
              0.917649812825669, 0.658402887580602, 0.4760539940908434], 
             UndirectedEdge[36, 412] -> 
             RGBColor[
              0.24838538806776134`, 0.3783991697753788, 0.9374565524459821], 
             UndirectedEdge[259, 469] -> 
             RGBColor[
              0.8611356885897954, 0.46233141911773723`, 0.2058405534946276], 
             UndirectedEdge[6, 80] -> 
             RGBColor[
              0.8086163665159423, 0.8504788015959455, 0.9815424524658205], 
             UndirectedEdge[287, 389] -> 
             RGBColor[
              0.214155749354975, 0.34242164920379625`, 0.9355072251595016], 
             UndirectedEdge[158, 410] -> 
             RGBColor[
              0.3605931713874897, 0.48674941394123933`, 0.9441976559141574], 
             UndirectedEdge[414, 415] -> 
             RGBColor[
              0.2808353270487499, 0.4125061130893616, 0.9393045284655668], 
             UndirectedEdge[10, 245] -> 
             RGBColor[
              0.22026264269435236`, 0.3488403813028832, 0.93585500370084], 
             UndirectedEdge[115, 178] -> 
             RGBColor[
              0.9564265081535962, 0.965404037867567, 0.8899068420398936], 
             UndirectedEdge[88, 348] -> 
             RGBColor[
              0.9132608681622556, 0.6818120756635188, 0.2545865809359151], 
             UndirectedEdge[135, 170] -> 
             RGBColor[
              0.2736536686143132, 0.40495773473132446`, 0.9388955436420372], 
             UndirectedEdge[3, 203] -> 
             RGBColor[
              0.49811633466717364`, 0.6034323062247897, 0.9536326890067068], 
             UndirectedEdge[84, 374] -> 
             RGBColor[
              0.24252230770556474`, 0.3722367005739444, 0.9371226586930053], 
             UndirectedEdge[29, 172] -> 
             RGBColor[
              0.3806363827099919, 0.5041098361876981, 0.9454747916161113], 
             UndirectedEdge[262, 387] -> 
             RGBColor[
              0.6255998101870561, 0.7048955003973141, 0.9650590620780228], 
             UndirectedEdge[179, 276] -> 
             RGBColor[
              0.39923464670294595`, 0.5037029404652202, 0.9483463693708659], 
             UndirectedEdge[348, 428] -> 
             RGBColor[
              0.8951225528654855, 0.5552983535621828, 0.23772264959288408`], 
             UndirectedEdge[104, 351] -> 
             RGBColor[
              0.2683095588486911, 0.39934073653152624`, 0.9385912044967868], 
             UndirectedEdge[111, 271] -> 
             RGBColor[
              0.2644482810539334, 0.39528228875008364`, 0.938371310438624], 
             UndirectedEdge[136, 277] -> 
             RGBColor[
              0.8701310969045036, 0.8988186894535575, 0.9576327343932979], 
             UndirectedEdge[246, 442] -> 
             RGBColor[
              0.28908336711974203`, 0.42117532615991926`, 0.939774242145728], 
             UndirectedEdge[206, 266] -> 
             RGBColor[
              0.31612745049209645`, 0.4464579350707817, 0.9414294227127427], 
             UndirectedEdge[31, 381] -> 
             RGBColor[
              0.5111715324361403, 0.6140235083829432, 0.9546625406628318], 
             UndirectedEdge[31, 472] -> 
             RGBColor[
              0.39074248974700837`, 0.5128632381554529, 0.9461187438200305], 
             UndirectedEdge[342, 453] -> 
             RGBColor[
              0.27214698791275327`, 0.40337411778491095`, 0.9388097404050177],
              UndirectedEdge[200, 475] -> 
             RGBColor[
              0.8699156991968737, 0.47168384997259694`, 0.2119718972840306], 
             UndirectedEdge[92, 101] -> 
             RGBColor[
              0.5649851581111299, 0.6577194295027604, 0.9588968477367864], 
             UndirectedEdge[193, 376] -> 
             RGBColor[
              0.2836334092052663, 0.4154470748445156, 0.9394638751049887], 
             UndirectedEdge[253, 319] -> 
             RGBColor[
              0.8499607656875054, 0.8826374101392084, 0.934970872933598], 
             UndirectedEdge[249, 280] -> 
             RGBColor[
              0.27322012310800536`, 0.4045020509158221, 0.938870853866826], 
             UndirectedEdge[153, 195] -> 
             RGBColor[
              0.2575424446398453, 0.3880238168235591, 0.9379780332711112], 
             UndirectedEdge[313, 380] -> 
             RGBColor[
              0.26990447818225494`, 0.4010170978748282, 0.9386820327933616], 
             UndirectedEdge[178, 357] -> 
             RGBColor[
              0.9494134599221778, 0.8301932628763469, 0.5158066666080678], 
             UndirectedEdge[163, 494] -> 
             RGBColor[
              0.262747921993954, 0.39349510356905415`, 0.938274477505614], 
             UndirectedEdge[24, 237] -> 
             RGBColor[
              0.871532203465174, 0.9004001382044219, 0.9876087136641327], 
             UndirectedEdge[101, 345] -> 
             RGBColor[
              0.5902789610650883, 0.677988050262613, 0.9610699533225915], 
             UndirectedEdge[320, 361] -> 
             RGBColor[
              0.8164019725999951, 0.8557645940777792, 0.9018606390244552], 
             UndirectedEdge[328, 487] -> 
             RGBColor[
              0.4823721914903405, 0.5888040064890694, 0.952903444464096], 
             UndirectedEdge[322, 494] -> 
             RGBColor[
              0.2588610411681461, 0.3894097453786518, 0.9380531253927091], 
             UndirectedEdge[108, 266] -> 
             RGBColor[
              0.28731571918259713`, 0.4193174161026276, 0.9396735772107083], 
             UndirectedEdge[405, 474] -> 
             RGBColor[
              0.9935549188322322, 0.9905077851325332, 0.6768786341569868], 
             UndirectedEdge[338, 379] -> 
             RGBColor[
              0.31470226354501973`, 0.4470010161121858, 0.9412735278461717], 
             UndirectedEdge[175, 309] -> 
             RGBColor[
              0.9743805147039586, 0.9770030600582216, 0.7213206267986814], 
             UndirectedEdge[294, 430] -> 
             RGBColor[
              0.23902588418057213`, 0.36856173776312173`, 0.9369235425457519],
              UndirectedEdge[197, 237] -> 
             RGBColor[
              0.8018590077882369, 0.845833600411511, 0.9807007779188375], 
             UndirectedEdge[94, 500] -> 
             RGBColor[
              0.8874558706447166, 0.5585534617562613, 0.5633237757723539], 
             UndirectedEdge[242, 365] -> 
             RGBColor[
              0.22099114578241763`, 0.3496060842382034, 0.9358964908739815], 
             UndirectedEdge[401, 500] -> 
             RGBColor[
              0.7964725199858478, 0.48689043193741693`, 0.5721768321079614], 
             UndirectedEdge[334, 340] -> 
             RGBColor[
              0.37011932022613914`, 0.4950004852671151, 0.9448046536945134], 
             UndirectedEdge[60, 310] -> 
             RGBColor[
              0.2947333345295756, 0.4271138001362785, 0.9400959994313403], 
             UndirectedEdge[50, 379] -> 
             RGBColor[
              0.37511861305326666`, 0.49933062144220947`, 0.9451232042127569],
              UndirectedEdge[123, 177] -> 
             RGBColor[
              0.2078300375710318, 0.33577292504558, 0.935146985231458], 
             UndirectedEdge[231, 246] -> 
             RGBColor[
              0.27633388437422024`, 0.407774811430481, 0.93904817796454], 
             UndirectedEdge[182, 282] -> 
             RGBColor[
              0.4931225250647846, 0.5973489755441486, 0.9538002129842165], 
             UndirectedEdge[185, 193] -> 
             RGBColor[
              0.28587823371129695`, 0.41780652773044813`, 0.9395917145396869],
              UndirectedEdge[395, 447] -> 
             RGBColor[
              0.2557437599820415, 0.3861332852050131, 0.9378756008407647], 
             UndirectedEdge[22, 282] -> 
             RGBColor[
              0.5295374583805197, 0.6288897605144723, 0.956120540334634], 
             UndirectedEdge[195, 323] -> 
             RGBColor[
              0.2547482956718921, 0.38508698909896344`, 0.9378189106209592], 
             UndirectedEdge[99, 486] -> 
             RGBColor[
              0.9642745659488295, 0.9698576677518461, 0.7703884518083142], 
             UndirectedEdge[454, 469] -> 
             RGBColor[
              0.8801565520867384, 0.5487007178218191, 0.22171202824050545`], 
             UndirectedEdge[31, 208] -> 
             RGBColor[
              0.38757839390763205`, 0.5101226573714661, 0.9459171304310454], 
             UndirectedEdge[398, 472] -> 
             RGBColor[
              0.2947988861662292, 0.4253612331985043, 0.9401664252880289], 
             UndirectedEdge[191, 389] -> 
             RGBColor[
              0.21845058194335062`, 0.3469357905622929, 0.9357518095217741], 
             UndirectedEdge[133, 151] -> 
             RGBColor[
              0.3259839947322987, 0.4565922388339624, 0.9419989967859217], 
             UndirectedEdge[165, 268] -> 
             RGBColor[
              0.4168440173490807, 0.5354710694634455, 0.9477819100781599], 
             UndirectedEdge[166, 495] -> 
             RGBColor[
              0.8401614416386582, 0.3097040160564781, 0.18609194791002698`], 
             UndirectedEdge[346, 430] -> 
             RGBColor[
              0.22881084125106885`, 0.35782507997308444`, 0.9363418109627185],
              UndirectedEdge[169, 219] -> 
             RGBColor[
              0.5095055418565787, 0.6126785776990856, 0.9545292891166974], 
             UndirectedEdge[197, 345] -> 
             RGBColor[
              0.6786754086563489, 0.7489056544572683, 0.9686076802187304], 
             UndirectedEdge[100, 213] -> 
             RGBColor[
              0.9177103751290299, 0.7114500107948662, 0.2526457256885956], 
             UndirectedEdge[73, 187] -> 
             RGBColor[
              0.25626928229983936`, 0.38668564248105813`, 0.9379055285593227],
              UndirectedEdge[97, 346] -> 
             RGBColor[
              0.22480858213955662`, 0.353618451889001, 0.9361138882271296], 
             UndirectedEdge[129, 170] -> 
             RGBColor[
              0.3261401713486173, 0.4557924254151241, 0.9420431862919051], 
             UndirectedEdge[36, 37] -> 
             RGBColor[
              0.2800147441029785, 0.41164362838539204`, 0.9392577974807488], 
             UndirectedEdge[143, 302] -> 
             RGBColor[
              0.1845381798446758, 0.31129170578610466`, 0.9338205483911577], 
             UndirectedEdge[16, 236] -> 
             RGBColor[
              0.34560261915581325`, 0.4717846628283363, 0.9433149938798411], 
             UndirectedEdge[187, 322] -> 
             RGBColor[
              0.2619233226556958, 0.392628397381927, 0.9382275177931856], 
             UndirectedEdge[108, 163] -> 
             RGBColor[
              0.27605150294224795`, 0.40747801064146116`, 0.939032096759735], 
             UndirectedEdge[137, 346] -> 
             RGBColor[
              0.21898159921391522`, 0.34749392338209584`, 0.9357820501697631],
              UndirectedEdge[243, 276] -> 
             RGBColor[
              0.7294231328480298, 0.5025695960181678, 0.5742322488928711], 
             UndirectedEdge[131, 147] -> 
             RGBColor[
              0.257551109678863, 0.38803292432896186`, 0.9379785267322645], 
             UndirectedEdge[9, 468] -> 
             RGBColor[
              0.5267603512092651, 0.6266868092518996, 0.9558876509153902], 
             UndirectedEdge[331, 377] -> 
             RGBColor[
              0.9088984029132244, 0.9290240327940705, 0.9505769466051841], 
             UndirectedEdge[280, 470] -> 
             RGBColor[
              0.25618724239569113`, 0.386599413340168, 0.9379008565081486], 
             UndirectedEdge[234, 468] -> 
             RGBColor[
              0.4334778335161593, 0.5491980337433716, 0.9490298017896481], 
             UndirectedEdge[136, 488] -> 
             RGBColor[
              0.8691624812525807, 0.8980619995445237, 0.9575361918373422], 
             UndirectedEdge[57, 361] -> 
             RGBColor[
              0.622722217665552, 0.7045647515271736, 0.9634614174292722], 
             UndirectedEdge[196, 414] -> 
             RGBColor[
              0.2851786513362504, 0.4170712222981897, 0.9395518743583675], 
             UndirectedEdge[103, 319] -> 
             RGBColor[
              0.5976226950866923, 0.6831049747415705, 0.9622258440138658], 
             UndirectedEdge[224, 263] -> 
             RGBColor[
              0.2861834719747001, 0.4181273524985085, 0.9396090974072282], 
             UndirectedEdge[89, 184] -> 
             RGBColor[
              0.271266794829508, 0.4024489790469554, 0.9387596147110557], 
             UndirectedEdge[137, 407] -> 
             RGBColor[
              0.2172194419002935, 0.34564178431825265`, 0.9356816979176306], 
             UndirectedEdge[53, 272] -> 
             RGBColor[
              0.8985476192245749, 0.5458238236085153, 0.2652993601444404], 
             UndirectedEdge[236, 243] -> 
             RGBColor[
              0.5633146331293595, 0.36122739545781846`, 0.562473440762307], 
             UndirectedEdge[26, 351] -> 
             RGBColor[
              0.3383374936256977, 0.4657436708748698, 0.9428428507321864], 
             UndirectedEdge[67, 96] -> 
             RGBColor[
              0.2763924027630132, 0.4078363179673825, 0.9390515105002115], 
             UndirectedEdge[284, 464] -> 
             RGBColor[
              0.24447969866104266`, 0.37429404257390636`, 0.9372341292122193],
              UndirectedEdge[325, 401] -> 
             RGBColor[
              0.4762346490241563, 0.5642173274993956, 0.9557801417908952], 
             UndirectedEdge[227, 348] -> 
             RGBColor[
              0.9027713884189711, 0.6140906553673846, 0.24504718315702606`], 
             UndirectedEdge[106, 117] -> 
             RGBColor[
              0.44946530583261596`, 0.561973649912251, 0.9503446865091629], 
             UndirectedEdge[395, 440] -> 
             RGBColor[
              0.2733307058970075, 0.4046182804384171, 0.9388771513930672], 
             UndirectedEdge[204, 361] -> 
             RGBColor[
              0.5730472494558454, 0.6642363745027182, 0.9595508219663998], 
             UndirectedEdge[195, 263] -> 
             RGBColor[
              0.27177628853634817`, 0.40298448923661123`, 0.9387886296239321],
              UndirectedEdge[360, 393] -> 
             RGBColor[
              0.5202889035975207, 0.6214329965452928, 0.9553781948537], 
             UndirectedEdge[74, 440] -> 
             RGBColor[
              0.2817039259800564, 0.4134190656385177, 0.9393539938897277], 
             UndirectedEdge[166, 348] -> 
             RGBColor[
              0.8990160108059699, 0.5852251774168952, 0.24145102931372386`], 
             UndirectedEdge[209, 477] -> 
             RGBColor[
              0.40529759982577535`, 0.5164885241169046, 0.9481078912022864], 
             UndirectedEdge[292, 422] -> 
             RGBColor[
              0.20649131825242792`, 0.3343658461620201, 0.9350707471467212], 
             UndirectedEdge[36, 416] -> 
             RGBColor[
              0.2579614870777197, 0.3884642569945902, 0.9380018971180304], 
             UndirectedEdge[306, 418] -> 
             RGBColor[
              0.9180265023958543, 0.7135265493813059, 0.5620472292012149], 
             UndirectedEdge[363, 498] -> 
             RGBColor[
              0.433350434496959, 0.5495353617267253, 0.948897990208064], 
             UndirectedEdge[57, 466] -> 
             RGBColor[
              0.552375580457491, 0.6474824063085367, 0.957904175593487], 
             UndirectedEdge[263, 395] -> 
             RGBColor[
              0.2691941123375187, 0.40027045833221453`, 0.938641578509396], 
             UndirectedEdge[171, 238] -> 
             RGBColor[
              0.2909480728266918, 0.4220805098947036, 0.9399190535823698], 
             UndirectedEdge[42, 286] -> 
             RGBColor[
              0.2277872668823118, 0.3567492384131574, 0.9362835199166604], 
             UndirectedEdge[246, 444] -> 
             RGBColor[
              0.2827572278979614, 0.41452615273743476`, 0.9394139778757318], 
             UndirectedEdge[46, 306] -> 
             RGBColor[
              0.8876171805650555, 0.5774114462757728, 0.22768643734119767`], 
             UndirectedEdge[229, 411] -> 
             RGBColor[
              0.26528288174741516`, 0.39615950699567326`, 0.9384188397134368],
              UndirectedEdge[239, 440] -> 
             RGBColor[
              0.3163021777955242, 0.4458837751629835, 0.9414671202878849], 
             UndirectedEdge[57, 106] -> 
             RGBColor[
              0.5595491629932491, 0.6533062437772754, 0.9584689062884005], 
             UndirectedEdge[60, 280] -> 
             RGBColor[
              0.2748009878347767, 0.4061636399762716, 0.9389608817743358], 
             UndirectedEdge[438, 457] -> 
             RGBColor[
              0.22152681415849518`, 0.35016910566479753`, 0.9359269963955489],
              UndirectedEdge[130, 368] -> 
             RGBColor[
              0.2935143249909316, 0.4166464351270609, 0.9403629270800464], 
             UndirectedEdge[152, 287] -> 
             RGBColor[
              0.20690732578417442`, 0.33480309645428663`, 0.9350944381602262],
              UndirectedEdge[54, 242] -> 
             RGBColor[
              0.22686421194138368`, 0.35577904914517844`, 0.936230953303312], 
             UndirectedEdge[89, 235] -> 
             RGBColor[
              0.32127172035398965`, 0.45054205661512126`, 0.9417708166396943],
              UndirectedEdge[60, 260] -> 
             RGBColor[
              0.2891430137819674, 0.4212380185837349, 0.9397776389349024], 
             UndirectedEdge[88, 243] -> 
             RGBColor[
              0.8529581179820884, 0.3951595604413297, 0.19784071975882145`], 
             UndirectedEdge[36, 367] -> 
             RGBColor[
              0.2421171751521342, 0.3718108805734015, 0.9370995869934273], 
             UndirectedEdge[17, 282] -> 
             RGBColor[
              0.7438148228852721, 0.7997463454963281, 0.9753349394405884], 
             UndirectedEdge[150, 233] -> 
             RGBColor[
              0.832302226448087, 0.24929464417169217`, 0.1785659545678221], 
             UndirectedEdge[250, 365] -> 
             RGBColor[
              0.21070999979849359`, 0.338799947946794, 0.9353109948197895], 
             UndirectedEdge[107, 423] -> 
             RGBColor[
              0.18624879198055028`, 0.31308966759998247`, 0.9339179652216718],
              UndirectedEdge[315, 347] -> 
             RGBColor[
              0.1822133081343763, 0.30884811821319974`, 0.9336881503865955], 
             UndirectedEdge[288, 492] -> 
             RGBColor[
              0.26634261157442907`, 0.39727335023461663`, 0.9384791897593554],
              UndirectedEdge[24, 267] -> 
             RGBColor[
              0.9130173103236416, 0.9238052630986108, 0.6981615264074577], 
             UndirectedEdge[198, 480] -> 
             RGBColor[
              0.3177133386514768, 0.44712506118461215`, 0.9415563421819749], 
             UndirectedEdge[4, 479] -> 
             RGBColor[
              0.3678971603336924, 0.49307576205728143`, 0.9446630596311456], 
             UndirectedEdge[133, 239] -> 
             RGBColor[
              0.34805209112246643`, 0.47588696054869806`, 0.943398549369312], 
             UndirectedEdge[115, 253] -> 
             RGBColor[
              0.9531001134456565, 0.9640284881713892, 0.9450338107840079], 
             UndirectedEdge[199, 371] -> 
             RGBColor[
              0.3528938984406201, 0.480080690691371, 0.9437070650501826], 
             UndirectedEdge[93, 189] -> 
             RGBColor[
              0.26453032177670965`, 0.3953685187514038, 0.9383759825364177], 
             UndirectedEdge[357, 418] -> 
             RGBColor[
              0.9428078871600445, 0.8265116366232681, 0.582732825135219], 
             UndirectedEdge[82, 463] -> 
             RGBColor[
              0.26268799213192734`, 0.3934321134842913, 0.9382710645886299], 
             UndirectedEdge[102, 350] -> 
             RGBColor[
              0.3193537748201921, 0.44805203074969097`, 0.941678953195245], 
             UndirectedEdge[235, 296] -> 
             RGBColor[
              0.3352307721420522, 0.4647817784660925, 0.9425815862613272], 
             UndirectedEdge[26, 360] -> 
             RGBColor[
              0.48299792974153133`, 0.5893477559050426, 0.9529428278924086], 
             UndirectedEdge[309, 320] -> 
             RGBColor[
              0.9908166313021023, 0.9885283450055495, 0.6606847997028811], 
             UndirectedEdge[13, 229] -> 
             RGBColor[
              0.2937960299949141, 0.4261286336418093, 0.9400426213247091], 
             UndirectedEdge[353, 420] -> 
             RGBColor[
              0.8041526849608935, 0.8472401733654197, 0.9513697071701304], 
             UndirectedEdge[171, 465] -> 
             RGBColor[
              0.27218390368581785`, 0.4034129186029971, 0.9388118427036817], 
             UndirectedEdge[104, 224] -> 
             RGBColor[
              0.2727699797429894, 0.40402892169845256`, 0.9388452188681158], 
             UndirectedEdge[22, 285] -> 
             RGBColor[
              0.38291743430858444`, 0.506085568433412, 0.9456201382069189], 
             UndirectedEdge[126, 285] -> 
             RGBColor[
              0.28277807837083513`, 0.4140236211798849, 0.9394343678430408], 
             UndirectedEdge[98, 319] -> 
             RGBColor[
              0.8550622111994015, 0.8847062165139711, 0.8474629923061501], 
             UndirectedEdge[286, 411] -> 
             RGBColor[
              0.2313451146629863, 0.3604887620112245, 0.9364861340844057], 
             UndirectedEdge[259, 491] -> 
             RGBColor[
              0.9280010655847133, 0.727726462964249, 0.4061574584267472], 
             UndirectedEdge[1, 266] -> 
             RGBColor[
              0.27784311638010406`, 0.40936110995950087`, 0.9391341264945663],
              UndirectedEdge[67, 216] -> 
             RGBColor[
              0.26125452628926693`, 0.3919254499966715, 0.938189430829513], 
             UndirectedEdge[41, 451] -> 
             RGBColor[
              0.22198624668627384`, 0.3506519983811976, 0.9359531603983363], 
             UndirectedEdge[300, 456] -> 
             RGBColor[
              0.22480808787876505`, 0.3536179323895711, 0.9361138600797088], 
             UndirectedEdge[117, 139] -> 
             RGBColor[
              0.47255522666265165`, 0.5807190878311534, 0.9521624096580703], 
             UndirectedEdge[70, 96] -> 
             RGBColor[
              0.2772059489257, 0.4086914065661722, 0.9390978407506428], 
             UndirectedEdge[92, 274] -> 
             RGBColor[
              0.5359359247795917, 0.6341359532311694, 0.9566099856780799], 
             UndirectedEdge[241, 436] -> 
             RGBColor[
              0.5892009770363313, 0.6764119562142918, 0.9614643256448061], 
             UndirectedEdge[207, 295] -> 
             RGBColor[
              0.22332543873759936`, 0.352059574136821, 0.9360294254045023], 
             UndirectedEdge[83, 176] -> 
             RGBColor[
              0.7638451540938651, 0.8157128228854424, 0.9772513951417543], 
             UndirectedEdge[56, 495] -> 
             RGBColor[
              0.839438039950976, 0.30414363368831143`, 0.18539921763693712`], 
             UndirectedEdge[219, 334] -> 
             RGBColor[
              0.4645364889888964, 0.5747991033502236, 0.9513681298117886], 
             UndirectedEdge[124, 357] -> 
             RGBColor[
              0.9348974167088442, 0.7776187751730486, 0.27677767167712564`], 
             UndirectedEdge[40, 291] -> 
             RGBColor[
              0.5205636488996574, 0.6196411124817705, 0.9560349926032045], 
             UndirectedEdge[7, 487] -> 
             RGBColor[
              0.7090567422484308, 0.7718269420846646, 0.9722547745917934], 
             UndirectedEdge[423, 477] -> 
             RGBColor[
              0.21624875945532895`, 0.3446215355237733, 0.9356264189883857], 
             UndirectedEdge[22, 165] -> 
             RGBColor[
              0.4377248912958056, 0.5535570329728583, 0.9491124209018134], 
             UndirectedEdge[302, 368] -> 
             RGBColor[
              0.2991255041617159, 0.42254414020486286`, 0.9406824754328269], 
             UndirectedEdge[297, 419] -> 
             RGBColor[
              0.5160273723962365, 0.6179732935362974, 0.9550427115070317], 
             UndirectedEdge[263, 463] -> 
             RGBColor[
              0.2702490064672201, 0.4013792189466815, 0.9387016531695065], 
             UndirectedEdge[260, 424] -> 
             RGBColor[
              0.3030854306847971, 0.434796914253921, 0.9406117494194473], 
             UndirectedEdge[193, 415] -> 
             RGBColor[
              0.28741220208324925`, 0.41941882574858214`, 0.9396790717691668],
              UndirectedEdge[434, 474] -> 
             RGBColor[
              0.992149866333044, 0.99102178223655, 0.7797605605635565], 
             UndirectedEdge[102, 109] -> 
             RGBColor[
              0.265248780611274, 0.396123664539452, 0.9384168977041816], 
             UndirectedEdge[58, 118] -> 
             RGBColor[
              0.3201099243225116, 0.4516848600807156, 0.9416180992091068], 
             UndirectedEdge[39, 100] -> 
             RGBColor[
              0.7774382200691679, 0.7351762203070193, 0.6135140654406412], 
             UndirectedEdge[35, 216] -> 
             RGBColor[
              0.25212920477180323`, 0.3823341585030158, 0.9376697572687969], 
             UndirectedEdge[72, 163] -> 
             RGBColor[
              0.26048838412385666`, 0.3911201860046064, 0.9381458001665987], 
             UndirectedEdge[202, 414] -> 
             RGBColor[
              0.25685751416132785`, 0.38730391146353665`, 0.9379390274936235],
              UndirectedEdge[324, 441] -> 
             RGBColor[
              0.4099049258998564, 0.5294607772190044, 0.947339757307013], 
             UndirectedEdge[18, 52] -> 
             RGBColor[
              0.8600894824934477, 0.42201909265360843`, 0.20357506457964797`],
              UndirectedEdge[168, 368] -> 
             RGBColor[
              0.6594469349895435, 0.6059633899066202, 0.5971521921376893], 
             UndirectedEdge[208, 397] -> 
             RGBColor[
              0.3403332891441403, 0.46920132223333977`, 0.9429067141327215], 
             UndirectedEdge[193, 350] -> 
             RGBColor[
              0.3249908553866274, 0.4539769598365655, 0.94199997659419], 
             UndirectedEdge[2, 365] -> 
             RGBColor[
              0.21471117528305686`, 0.3430054370702481, 0.9355388558444269], 
             UndirectedEdge[42, 248] -> 
             RGBColor[
              0.2375069627028864, 0.3669652549848901, 0.9368370422146407], 
             UndirectedEdge[46, 68] -> 
             RGBColor[
              0.8688206529626022, 0.4329330984324026, 0.20968686128144703`], 
             UndirectedEdge[260, 470] -> 
             RGBColor[
              0.2705292683428818, 0.4016737919476313, 0.9387176136687151], 
             UndirectedEdge[32, 344] -> 
             RGBColor[
              0.49972685632516956`, 0.6047398002599247, 0.9537594751711596], 
             UndirectedEdge[60, 483] -> 
             RGBColor[
              0.29467938491288026`, 0.4270570956685284, 0.9400929270804808], 
             UndirectedEdge[337, 498] -> 
             RGBColor[
              0.6610501058244442, 0.7326972089760198, 0.9686548196773171], 
             UndirectedEdge[86, 168] -> 
             RGBColor[
              0.912992655814064, 0.6927519043211215, 0.24885005242438252`], 
             UndirectedEdge[151, 424] -> 
             RGBColor[
              0.31369437792555, 0.4459475904500576, 0.9412159132702771], 
             UndirectedEdge[234, 296] -> 
             RGBColor[
              0.3509992318996893, 0.478439625762326, 0.9435863385735823], 
             UndirectedEdge[223, 268] -> 
             RGBColor[
              0.3997592820050565, 0.5206731304122181, 0.946693285849477], 
             UndirectedEdge[50, 204] -> 
             RGBColor[
              0.47141553909134676`, 0.5814192522224795, 0.9516235825177704], 
             UndirectedEdge[26, 247] -> 
             RGBColor[
              0.44082045923577545`, 0.5551061852750767, 0.9496224629130303], 
             UndirectedEdge[64, 435] -> 
             RGBColor[
              0.2729760661843835, 0.4042455316149929, 0.9388569551860756], 
             UndirectedEdge[143, 214] -> 
             RGBColor[
              0.18936705810043614`, 0.31636716300147366`, 0.934095545864138], 
             UndirectedEdge[38, 266] -> 
             RGBColor[
              0.27474470932625494`, 0.40610448769555174`, 0.9389576767965321],
              UndirectedEdge[309, 375] -> 
             RGBColor[
              0.9756161016685031, 0.977924558793291, 0.7192291003603996], 
             UndirectedEdge[70, 385] -> 
             RGBColor[
              0.24586087527331454`, 0.37574574676505923`, 0.9373127851770204],
              UndirectedEdge[232, 354] -> 
             RGBColor[
              0.35898073503518557`, 0.48535280261628094`, 0.94409491289561], 
             UndirectedEdge[86, 484] -> 
             RGBColor[
              0.9540423951293819, 0.8443401430723285, 0.3591520108030784], 
             UndirectedEdge[106, 360] -> 
             RGBColor[
              0.5486108303756021, 0.6444260125920007, 0.9576078006763067], 
             UndirectedEdge[163, 322] -> 
             RGBColor[
              0.26310542995763675`, 0.3938708671061988, 0.9382948370552601], 
             UndirectedEdge[44, 117] -> 
             RGBColor[
              0.4388762614701655, 0.5533769866678013, 0.9495110781480034], 
             UndirectedEdge[113, 273] -> 
             RGBColor[
              0.23636683819300525`, 0.3657669118369359, 0.936772113810466], 
             UndirectedEdge[53, 298] -> 
             RGBColor[
              0.9390760601522875, 0.9284198827471832, 0.6768677898959217], 
             UndirectedEdge[50, 369] -> 
             RGBColor[
              0.43044272533776096`, 0.5472495868323034, 0.9486484077263333], 
             UndirectedEdge[135, 385] -> 
             RGBColor[
              0.24204917775156742`, 0.37173941099412156`, 0.9370957146420581],
              UndirectedEdge[376, 464] -> 
             RGBColor[
              0.2616609318454717, 0.3923526080038432, 0.9382125750247157], 
             UndirectedEdge[95, 408] -> 
             RGBColor[
              0.22479372667970515`, 0.35360283785880653`, 0.9361130422306678],
              UndirectedEdge[34, 332] -> 
             RGBColor[
              0.47297256082386624`, 0.5816312685861409, 0.9520368398699108], 
             UndirectedEdge[251, 416] -> 
             RGBColor[
              0.26003944376158217`, 0.39064832121939286`, 0.9381202336771148],
              UndirectedEdge[62, 209] -> 
             RGBColor[
              0.6916212861064526, 0.39630413817282756`, 0.5615943615662011], 
             UndirectedEdge[109, 496] -> 
             RGBColor[
              0.26542477376877, 0.3963086445065909, 0.9384269202541424], 
             UndirectedEdge[179, 254] -> 
             RGBColor[
              0.20771369325605188`, 0.33565063979388043`, 0.9351403595948358],
              UndirectedEdge[27, 199] -> 
             RGBColor[
              0.4274813973658525, 0.5430880506381621, 0.9489008550961784], 
             UndirectedEdge[59, 453] -> 
             RGBColor[
              0.26324896867774317`, 0.3940217354019111, 0.9383030113730237], 
             UndirectedEdge[450, 475] -> 
             RGBColor[
              0.8283559372455574, 0.2189617360860943, 0.17478698357078354`], 
             UndirectedEdge[311, 331] -> 
             RGBColor[
              0.7917742816822333, 0.837394395727864, 0.9798444828971542], 
             UndirectedEdge[329, 486] -> 
             RGBColor[
              0.9087427412464592, 0.930070810978078, 0.9911578879759511], 
             UndirectedEdge[287, 456] -> 
             RGBColor[
              0.21673512234064032`, 0.34513273375342357`, 0.9356541166351948],
              UndirectedEdge[60, 118] -> 
             RGBColor[
              0.30890885152103453`, 0.4405003788871604, 0.9409586647466246], 
             UndirectedEdge[267, 493] -> 
             RGBColor[
              0.991319933690298, 0.9817192401312839, 0.4771566948770857], 
             UndirectedEdge[239, 263] -> 
             RGBColor[
              0.31216558423603546`, 0.4415359530567809, 0.9412315474042139], 
             UndirectedEdge[64, 91] -> 
             RGBColor[
              0.3077316474117898, 0.43903000298271255`, 0.9409001581731142], 
             UndirectedEdge[469, 471] -> 
             RGBColor[
              0.8586216305057723, 0.4484110579890054, 0.20364468753654688`], 
             UndirectedEdge[275, 282] -> 
             RGBColor[
              0.5106811757652547, 0.612557396257451, 0.9549190346803453], 
             UndirectedEdge[132, 423] -> 
             RGBColor[
              0.5889794016641527, 0.6524675094432201, 0.8735972473293918], 
             UndirectedEdge[116, 412] -> 
             RGBColor[
              0.24555371763094103`, 0.3754229046080053, 0.9372952930036862], 
             UndirectedEdge[89, 453] -> 
             RGBColor[
              0.28490427469255214`, 0.4167828350491789, 0.9395362490144127], 
             UndirectedEdge[136, 311] -> 
             RGBColor[
              0.8579087651395905, 0.8892705109856455, 0.9564145265871555], 
             UndirectedEdge[6, 24] -> 
             RGBColor[
              0.8323309168683787, 0.869142096362715, 0.9838696599531287], 
             UndirectedEdge[51, 477] -> 
             RGBColor[
              0.21179931412463662`, 0.3399448863700877, 0.9353730296591674], 
             UndirectedEdge[114, 381] -> 
             RGBColor[
              0.5349916430046526, 0.6333693427468647, 0.9565356483577385], 
             UndirectedEdge[95, 294] -> 
             RGBColor[
              0.2326978312332123, 0.36191055289371626`, 0.9365631692919152], 
             UndirectedEdge[89, 192] -> 
             RGBColor[
              0.27005817816264466`, 0.4011786462993594, 0.9386907857798661], 
             UndirectedEdge[108, 374] -> 
             RGBColor[
              0.2684205085848909, 0.3994573517388918, 0.938597522920128], 
             UndirectedEdge[208, 472] -> 
             RGBColor[
              0.32528262084800263`, 0.45616518982380916`, 0.9419476988576752],
              UndirectedEdge[34, 360] -> 
             RGBColor[
              0.5615596954334325, 0.6549384845856707, 0.9586271827669148], 
             UndirectedEdge[395, 453] -> 
             RGBColor[
              0.2746472026730905, 0.406002002020797, 0.9389521239368825], 
             UndirectedEdge[101, 361] -> 
             RGBColor[
              0.5825170875925927, 0.671924415713476, 0.9602963223136847], 
             UndirectedEdge[11, 211] -> 
             RGBColor[
              0.23497926878004616`, 0.3643084884069338, 0.936693093785123], 
             UndirectedEdge[70, 433] -> 
             RGBColor[
              0.2918782074405654, 0.4225632807803333, 0.9399901426055144], 
             UndirectedEdge[108, 206] -> 
             RGBColor[
              0.31392242641055057`, 0.44414031495447526`, 0.9413038498533395],
              UndirectedEdge[251, 499] -> 
             RGBColor[
              0.25963192027097015`, 0.39021998819227793`, 0.9380970258172014],
              UndirectedEdge[116, 399] -> 
             RGBColor[
              0.24511345141386065`, 0.3749601568993634, 0.937270220493939], 
             UndirectedEdge[350, 479] -> 
             RGBColor[
              0.3868303332701487, 0.5094747248458988, 0.9458694646687091], 
             UndirectedEdge[347, 421] -> 
             RGBColor[
              0.17899180289058533`, 0.3054621119467458, 0.9335046904287516], 
             UndirectedEdge[153, 447] -> 
             RGBColor[
              0.24571645560416666`, 0.3755939525360489, 0.9373045606905122], 
             UndirectedEdge[195, 453] -> 
             RGBColor[
              0.27722937887191995`, 0.40871603292519376`, 0.9390991750514186],
              UndirectedEdge[338, 425] -> 
             RGBColor[
              0.3477240886796976, 0.47560286131865376`, 0.9433776493436998], 
             UndirectedEdge[164, 348] -> 
             RGBColor[
              0.8887181595032059, 0.5060713797566354, 0.23158979527643736`], 
             UndirectedEdge[31, 258] -> 
             RGBColor[
              0.4132303526475083, 0.5323410947270124, 0.947551650558814], 
             UndirectedEdge[31, 203] -> 
             RGBColor[
              0.4938024492349883, 0.5999225041719667, 0.9532951828081889], 
             UndirectedEdge[398, 445] -> 
             RGBColor[
              0.2453951867466454, 0.3752562785971719, 0.9372862649043511], 
             UndirectedEdge[44, 369] -> 
             RGBColor[
              0.4583123366675063, 0.5702115381181944, 0.9507495276729314], 
             UndirectedEdge[267, 278] -> 
             RGBColor[
              0.9687131736129876, 0.9678890438697982, 0.6921508091390034], 
             UndirectedEdge[130, 477] -> 
             RGBColor[
              0.2117993137193227, 0.3399448859440771, 0.9353730296360853], 
             UndirectedEdge[4, 482] -> 
             RGBColor[
              0.3413925426988842, 0.4701187944228272, 0.9429742088325687], 
             UndirectedEdge[219, 274] -> 
             RGBColor[
              0.49450158018716717`, 0.6004976856950868, 0.9533481222927589], 
             UndirectedEdge[44, 269] -> 
             RGBColor[
              0.4728082951441619, 0.5827672087626157, 0.9516731973287911], 
             UndirectedEdge[130, 143] -> 
             RGBColor[
              0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772],
              UndirectedEdge[315, 401] -> 
             RGBColor[
              0.47947599697395743`, 0.5676241897079666, 0.9559647317614918], 
             UndirectedEdge[75, 163] -> 
             RGBColor[
              0.3059704107658049, 0.43557751025778224`, 0.9408584905702073], 
             UndirectedEdge[9, 139] -> 
             RGBColor[
              0.5695894293133013, 0.6614573842847371, 0.9592593128318224], 
             UndirectedEdge[134, 438] -> 
             RGBColor[
              0.22733547187831532`, 0.35627437321849936`, 0.9362577908595535],
              UndirectedEdge[76, 431] -> 
             RGBColor[
              0.42993261586454035`, 0.5468077556454473, 0.9486159040017718], 
             UndirectedEdge[90, 124] -> 
             RGBColor[
              0.9137111635376958, 0.6822566946723914, 0.2591427819494134], 
             UndirectedEdge[37, 188] -> 
             RGBColor[
              0.3214586719550145, 0.4525659249433619, 0.9417145542769817], 
             UndirectedEdge[26, 106] -> 
             RGBColor[
              0.45224243758080923`, 0.5643790618498358, 0.9505216428884367], 
             UndirectedEdge[107, 446] -> 
             RGBColor[
              0.2064114829025504, 0.3342819341474452, 0.9350662006416515], 
             UndirectedEdge[19, 234] -> 
             RGBColor[
              0.474151584993228, 0.582218817524079, 0.9522317884987839], 
             UndirectedEdge[39, 243] -> 
             RGBColor[
              0.7314838484501698, 0.504242577778165, 0.5743944759737214], 
             UndirectedEdge[129, 265] -> 
             RGBColor[
              0.3383071396578693, 0.46744637338556605`, 0.9427776096791101], 
             UndirectedEdge[396, 446] -> 
             RGBColor[
              0.6108486673250959, 0.6728679174892245, 0.7376055193707824], 
             UndirectedEdge[325, 368] -> 
             RGBColor[
              0.2935592851755068, 0.41669369113168975`, 0.9403654874960453], 
             UndirectedEdge[52, 56] -> 
             RGBColor[
              0.836234326611525, 0.27951848908515425`, 0.18233133812500216`], 
             UndirectedEdge[402, 431] -> 
             RGBColor[
              0.5004255816893457, 0.6051773211877334, 0.9538503277794443], 
             UndirectedEdge[165, 353] -> 
             RGBColor[
              0.531847897863051, 0.630021959343577, 0.9565078633928767], 
             UndirectedEdge[237, 329] -> 
             RGBColor[
              0.8943251384864865, 0.9185746058926771, 0.989782724153959], 
             UndirectedEdge[63, 75] -> 
             RGBColor[
              0.38214205273411095`, 0.5054139718854141, 0.9455707315786365], 
             UndirectedEdge[392, 492] -> 
             RGBColor[
              0.2913103527973019, 0.4235160293060819, 0.9399010656855349], 
             UndirectedEdge[125, 177] -> 
             RGBColor[
              0.20868507222126964`, 0.3366716206753079, 0.9351956781898786], 
             UndirectedEdge[210, 348] -> 
             RGBColor[
              0.8979876618717816, 0.5773208368833467, 0.24046628121299102`], 
             UndirectedEdge[469, 491] -> 
             RGBColor[
              0.9272960549745825, 0.7245251744430564, 0.40556918029226263`], 
             UndirectedEdge[35, 171] -> 
             RGBColor[
              0.25005732664065045`, 0.38015648322251344`, 0.9375517668742968],
              UndirectedEdge[8, 40] -> 
             RGBColor[
              0.5032468930597369, 0.6057751178648505, 0.9545401217837302], 
             UndirectedEdge[405, 491] -> 
             RGBColor[
              0.9940870576802556, 0.9897611392052678, 0.5977909028249961], 
             UndirectedEdge[98, 136] -> 
             RGBColor[
              0.9820976999154852, 0.9842937020241562, 0.8300672430323528], 
             UndirectedEdge[14, 75] -> 
             RGBColor[
              0.32584559541094904`, 0.45646758947931865`, 0.9419903529330476],
              UndirectedEdge[121, 500] -> 
             RGBColor[
              0.8234793018793516, 0.18147777970619255`, 0.1701171120367329], 
             UndirectedEdge[1, 265] -> 
             RGBColor[
              0.2935899974663011, 0.4247777732380918, 0.9400724206184119], 
             UndirectedEdge[227, 495] -> 
             RGBColor[
              0.8439168192516593, 0.3385694940069675, 0.1896881017533292], 
             UndirectedEdge[127, 368] -> 
             RGBColor[
              0.3170407306432145, 0.44137417912788274`, 0.9417027210777457], 
             UndirectedEdge[207, 389] -> 
             RGBColor[
              0.21778138864415675`, 0.3462324259755344, 0.9357136999533677], 
             UndirectedEdge[249, 260] -> 
             RGBColor[
              0.28756214905519606`, 0.4195764295232854, 0.9396876110273925], 
             UndirectedEdge[42, 95] -> 
             RGBColor[
              0.2297785943922997, 0.3588422498836111, 0.9363969230724491], 
             UndirectedEdge[190, 323] -> 
             RGBColor[
              0.243727142288008, 0.373503058111017, 0.9371912722400824], 
             UndirectedEdge[109, 295] -> 
             RGBColor[
              0.24177394363545715`, 0.37145012248723885`, 0.937080040466318], 
             UndirectedEdge[382, 499] -> 
             RGBColor[
              0.27147166687394786`, 0.40266431255529955`, 0.9387712818709056],
              UndirectedEdge[213, 254] -> 
             RGBColor[
              0.5703520735589939, 0.511904106319279, 0.5892794945919869], 
             UndirectedEdge[47, 374] -> 
             RGBColor[
              0.24183198733731956`, 0.37151113009807946`, 0.9370833459692711],
              UndirectedEdge[244, 390] -> 
             RGBColor[
              0.3215972480879268, 0.45223414091428343`, 0.9417399272656037], 
             UndirectedEdge[92, 370] -> 
             RGBColor[
              0.6002904630940367, 0.6863818665737486, 0.9616762106726342], 
             UndirectedEdge[295, 458] -> 
             RGBColor[
              0.2300435692999762, 0.35912075531195864`, 0.936412013001446], 
             UndirectedEdge[278, 493] -> 
             RGBColor[
              0.9709705008180975, 0.974840539169355, 0.7572967831573334], 
             UndirectedEdge[6, 156] -> 
             RGBColor[
              0.6474994925034097, 0.7219315348762902, 0.9673172118721224], 
             UndirectedEdge[79, 413] -> 
             RGBColor[
              0.9838323701759427, 0.9563067408191819, 0.46126511216987476`], 
             UndirectedEdge[122, 476] -> 
             RGBColor[
              0.8579983660337116, 0.432494720305006, 0.20261219607186334`], 
             UndirectedEdge[123, 455] -> 
             RGBColor[
              0.20545207796979598`, 0.3332735387333343, 0.9350115639500436], 
             UndirectedEdge[113, 302] -> 
             RGBColor[
              0.18467080951855291`, 0.3114311079825565, 0.9338281014548768], 
             UndirectedEdge[402, 462] -> 
             RGBColor[
              0.5080947993050582, 0.6115332733425336, 0.9544182302953215], 
             UndirectedEdge[140, 363] -> 
             RGBColor[
              0.4522227109181607, 0.5648567259118211, 0.9503836849393674], 
             UndirectedEdge[440, 453] -> 
             RGBColor[
              0.2829903357512072, 0.4147711638710876, 0.939427253023122], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.5464995084832656, 0.6427119463658346, 0.9574415896829152], 
             UndirectedEdge[102, 202] -> 
             RGBColor[
              0.2577973086293919, 0.3882916950358828, 0.9379925473982783], 
             UndirectedEdge[363, 379] -> 
             RGBColor[
              0.35705527838116624`, 0.4836850688388347, 0.9439722245002304], 
             UndirectedEdge[162, 297] -> 
             RGBColor[
              0.4906978130641887, 0.5974096161868968, 0.9530486758111798], 
             UndirectedEdge[19, 393] -> 
             RGBColor[
              0.5104680056398668, 0.6134599491568583, 0.954605057791339], 
             UndirectedEdge[96, 238] -> 
             RGBColor[
              0.3081578274315908, 0.4401690531459169, 0.9408991236475683], 
             UndirectedEdge[117, 247] -> 
             RGBColor[
              0.4380433274875822, 0.5527007733374919, 0.9494455065337566], 
             UndirectedEdge[162, 223] -> 
             RGBColor[
              0.4259476007932227, 0.5431195461878823, 0.9484273528030159], 
             UndirectedEdge[355, 362] -> 
             RGBColor[
              0.3585841716726791, 0.48500931936353203`, 0.9440696442288183], 
             UndirectedEdge[59, 395] -> 
             RGBColor[
              0.2535893388235434, 0.38386885196924064`, 0.9377529097429688], 
             UndirectedEdge[161, 403] -> 
             RGBColor[
              0.9596219668575938, 0.962601388451382, 0.7050117798938269], 
             UndirectedEdge[214, 477] -> 
             RGBColor[
              0.2222393711458674, 0.35091804823724815`, 0.9359675754618462], 
             UndirectedEdge[65, 309] -> 
             RGBColor[
              0.9892477963467572, 0.9750667140916796, 0.4404269945442838], 
             UndirectedEdge[361, 498] -> 
             RGBColor[
              0.5530454795335582, 0.6479980366103388, 0.95797620936922], 
             UndirectedEdge[54, 70] -> 
             RGBColor[
              0.24348548029858347`, 0.3732490560378767, 0.9371775099472914], 
             UndirectedEdge[369, 390] -> 
             RGBColor[
              0.36035044557586515`, 0.48580021278599533`, 0.9442092467414281],
              UndirectedEdge[56, 88] -> 
             RGBColor[
              0.8516418675680354, 0.38504228297430826`, 0.19658027687583196`],
              UndirectedEdge[289, 419] -> 
             RGBColor[
              0.4760307938821983, 0.5851235769437257, 0.9519986681530803], 
             UndirectedEdge[124, 178] -> 
             RGBColor[
              0.977168593002762, 0.938254909924025, 0.5484416326473938], 
             UndirectedEdge[67, 465] -> 
             RGBColor[
              0.26962432665641767`, 0.4007226408585406, 0.9386660785784122], 
             UndirectedEdge[7, 461] -> 
             RGBColor[
              0.8915688064008891, 0.9161509753336762, 0.9816909809846657], 
             UndirectedEdge[273, 423] -> 
             RGBColor[
              0.24068365358124288`, 0.3703041585118776, 0.9370179500606701], 
             UndirectedEdge[63, 467] -> 
             RGBColor[
              0.563087381667329, 0.6542682731705118, 0.9596777258955458], 
             UndirectedEdge[179, 368] -> 
             RGBColor[
              0.2935153935219346, 0.41664755822089383`, 0.9403629879313062], 
             UndirectedEdge[211, 485] -> 
             RGBColor[
              0.23952079823930758`, 0.3690819238182165, 0.9369517271692371], 
             UndirectedEdge[21, 320] -> 
             RGBColor[
              0.9847451317139568, 0.9683734708666063, 0.6094013242659239], 
             UndirectedEdge[318, 479] -> 
             RGBColor[
              0.3767164983407358, 0.5007146293661655, 0.94522502005032], 
             UndirectedEdge[343, 465] -> 
             RGBColor[
              0.2877565452274621, 0.4197807522257663, 0.9396986816018197], 
             UndirectedEdge[229, 313] -> 
             RGBColor[
              0.2789668469500533, 0.41054222203715074`, 0.9391981212881146], 
             UndirectedEdge[168, 401] -> 
             RGBColor[
              0.842122298838193, 0.7534870262743261, 0.6125668464325392], 
             UndirectedEdge[70, 216] -> 
             RGBColor[
              0.26206807245195374`, 0.39278053859546125`, 0.9382357610799443],
              UndirectedEdge[5, 193] -> 
             RGBColor[
              0.263209529621381, 0.3939802824530939, 0.9383007653771087], 
             UndirectedEdge[213, 471] -> 
             RGBColor[
              0.8805092403498851, 0.5477975823099646, 0.2219082457048863], 
             UndirectedEdge[145, 404] -> 
             RGBColor[
              0.2170532372191201, 0.345467092660354, 0.9356722328069155], 
             UndirectedEdge[28, 173] -> 
             RGBColor[
              0.9747095150977819, 0.9805973489982415, 0.9249344880863324], 
             UndirectedEdge[210, 243] -> 
             RGBColor[
              0.8376849116916145, 0.29066832166115775`, 0.18372042003589745`],
              UndirectedEdge[133, 424] -> 
             RGBColor[
              0.33288404882225986`, 0.46274916467623195`, 0.942432055126516], 
             UndirectedEdge[201, 400] -> 
             RGBColor[
              0.30019030163233085`, 0.432849418552972, 0.9404067656349827], 
             UndirectedEdge[120, 125] -> 
             RGBColor[
              0.2080475453125366, 0.33600153947268885`, 0.9351593719755629], 
             UndirectedEdge[96, 343] -> 
             RGBColor[
              0.29452462133405766`, 0.4268944293346082, 0.940084113523619], 
             UndirectedEdge[22, 149] -> 
             RGBColor[
              0.40264564991743174`, 0.5231731572248479, 0.9468772026605385], 
             UndirectedEdge[140, 369] -> 
             RGBColor[
              0.4597907440975337, 0.5714117758713864, 0.950865913321408], 
             UndirectedEdge[169, 370] -> 
             RGBColor[
              0.5420927609464797, 0.6391343501937576, 0.9570946743743712], 
             UndirectedEdge[154, 380] -> 
             RGBColor[
              0.2911961325222311, 0.423322454553487, 0.9398972530104752], 
             UndirectedEdge[33, 489] -> 
             RGBColor[
              0.9342559232885688, 0.7654812281083937, 0.517015114696979], 
             UndirectedEdge[271, 284] -> 
             RGBColor[
              0.2504489768010796, 0.3805681323731789, 0.9375740707715388], 
             UndirectedEdge[112, 356] -> 
             RGBColor[
              0.2588007282426925, 0.3893463526699398, 0.9380496906608295], 
             UndirectedEdge[133, 155] -> 
             RGBColor[
              0.4555313931992919, 0.5659235600860384, 0.9510915748153721], 
             UndirectedEdge[82, 447] -> 
             RGBColor[
              0.25238928516537673`, 0.3826075194867109, 0.9376845684624564], 
             UndirectedEdge[225, 260] -> 
             RGBColor[
              0.27991286113099906`, 0.41153654292208813`, 0.9392519953962168],
              UndirectedEdge[133, 225] -> 
             RGBColor[
              0.3097114792684619, 0.4394887933443991, 0.9410723011032855], 
             UndirectedEdge[442, 444] -> 
             RGBColor[
              0.27761918641957545`, 0.4091257453730057, 0.939121374014589], 
             UndirectedEdge[49, 431] -> 
             RGBColor[
              0.4693773227785792, 0.5799709458958486, 0.9514060951044689], 
             UndirectedEdge[220, 427] -> 
             RGBColor[
              0.30920666661498386`, 0.43953702554153684`, 0.9410223592495326],
              UndirectedEdge[151, 192] -> 
             RGBColor[
              0.28070448165153206`, 0.4123685862808082, 0.9392970770137636], 
             UndirectedEdge[167, 326] -> 
             RGBColor[
              0.9309228830343801, 0.7574193985269815, 0.5440638154599668], 
             UndirectedEdge[109, 196] -> 
             RGBColor[
              0.27482966958615396`, 0.4061937863154972, 0.938962515157646], 
             UndirectedEdge[212, 451] -> 
             RGBColor[
              0.21498103480107186`, 0.34328907653376356`, 0.9355542239447563],
              UndirectedEdge[186, 414] -> 
             RGBColor[
              0.255184189019674, 0.3855451406447167, 0.937843734102269], 
             UndirectedEdge[349, 419] -> 
             RGBColor[
              0.4631460027688009, 0.5739634184897324, 0.951177660656908], 
             UndirectedEdge[162, 221] -> 
             RGBColor[
              0.4993207487803075, 0.6044101038600693, 0.953727504897607], 
             UndirectedEdge[163, 364] -> 
             RGBColor[
              0.2627794929075267, 0.39352828660093053`, 0.938276275422437], 
             UndirectedEdge[191, 300] -> 
             RGBColor[
              0.22217951414553483`, 0.3508551347347456, 0.9359641666942277], 
             UndirectedEdge[438, 460] -> 
             RGBColor[
              0.23490540515407732`, 0.3642308530528161, 0.9366888873608955], 
             UndirectedEdge[172, 473] -> 
             RGBColor[
              0.3392418574009336, 0.4682559789143286, 0.9428371690671595], 
             UndirectedEdge[141, 188] -> 
             RGBColor[
              0.32343001274534444`, 0.45456055380007726`, 0.9418296523075707],
              UndirectedEdge[79, 122] -> 
             RGBColor[
              0.9306665098261713, 0.7402291937878942, 0.3904132893585251], 
             UndirectedEdge[326, 475] -> 
             RGBColor[
              0.8570894511774583, 0.4134428533627656, 0.20126936153652183`], 
             UndirectedEdge[98, 124] -> 
             RGBColor[
              0.9789436438067185, 0.93894816660261, 0.5160607207640602], 
             UndirectedEdge[204, 498] -> 
             RGBColor[
              0.4818912814299178, 0.5902600770764668, 0.9523553933815417], 
             UndirectedEdge[72, 144] -> 
             RGBColor[
              0.2501061102631632, 0.3802077579028347, 0.93755454502943], 
             UndirectedEdge[98, 331] -> 
             RGBColor[
              0.9159632164581281, 0.9324175867663749, 0.8534971993423514], 
             UndirectedEdge[311, 377] -> 
             RGBColor[
              0.8639809895032101, 0.8937991659736781, 0.9461358346293043], 
             UndirectedEdge[299, 389] -> 
             RGBColor[
              0.213833079654714, 0.34208250289038133`, 0.9354888495974187], 
             UndirectedEdge[131, 238] -> 
             RGBColor[
              0.29188148517230905`, 0.42306158545170824`, 0.9399722100345929],
              UndirectedEdge[4, 185] -> 
             RGBColor[
              0.30412419819916303`, 0.4355457825101565, 0.9406834624888651], 
             UndirectedEdge[162, 258] -> 
             RGBColor[
              0.4177269296537439, 0.5359992140298111, 0.9479035389072623], 
             UndirectedEdge[124, 253] -> 
             RGBColor[
              0.9738421982948224, 0.9368793602278473, 0.603568601391508], 
             UndirectedEdge[319, 449] -> 
             RGBColor[
              0.7215962304048408, 0.7824357266175173, 0.9728856266127364], 
             UndirectedEdge[256, 271] -> 
             RGBColor[
              0.2725957288123946, 0.4038457729222503, 0.9388352955353996], 
             UndirectedEdge[379, 478] -> 
             RGBColor[
              0.2876705710791334, 0.41963924089195836`, 0.9396956582454141], 
             UndirectedEdge[349, 371] -> 
             RGBColor[
              0.3882726943942144, 0.5107240255563866, 0.9459613706441047], 
             UndirectedEdge[130, 325] -> 
             RGBColor[
              0.1789719601845752, 0.3054412560046289, 0.9335035604159989], 
             UndirectedEdge[269, 369] -> 
             RGBColor[
              0.43444338232168905`, 0.5507147548329152, 0.948903326051707], 
             UndirectedEdge[43, 355] -> 
             RGBColor[
              0.3109273076150301, 0.4422891800076947, 0.941085795498422], 
             UndirectedEdge[11, 414] -> 
             RGBColor[
              0.25678804986481485`, 0.38723090008361066`, 0.9379350716047002],
              UndirectedEdge[117, 255] -> 
             RGBColor[
              0.38933039965095584`, 0.511640156687964, 0.9460287666877722], 
             UndirectedEdge[401, 475] -> 
             RGBColor[
              0.806227884360017, 0.5618744373452094, 0.5815185800497742], 
             UndirectedEdge[58, 141] -> 
             RGBColor[
              0.3123473120692484, 0.44496127550717535`, 0.9411234724205373], 
             UndirectedEdge[96, 180] -> 
             RGBColor[
              0.2831463385898367, 0.4149351327456384, 0.9394361371539964], 
             UndirectedEdge[119, 375] -> 
             RGBColor[
              0.9744244063754681, 0.9793738724475776, 0.8801494909995853], 
             UndirectedEdge[220, 382] -> 
             RGBColor[
              0.3105689508267532, 0.4409688726219141, 0.9410999393200739], 
             UndirectedEdge[104, 356] -> 
             RGBColor[
              0.2579557991377684, 0.3884582786090651, 0.9380015731982647], 
             UndirectedEdge[225, 440] -> 
             RGBColor[
              0.27796156594151966`, 0.4094856079586846, 0.9391408720218586], 
             UndirectedEdge[259, 341] -> 
             RGBColor[
              0.9277070351691528, 0.7270975616364004, 0.37415406223837167`], 
             UndirectedEdge[290, 362] -> 
             RGBColor[
              0.3374733904051481, 0.4646660623491092, 0.9427998432095333], 
             UndirectedEdge[79, 267] -> 
             RGBColor[
              0.9914456607402118, 0.9819881575780944, 0.49084130836277423`], 
             UndirectedEdge[90, 317] -> 
             RGBColor[
              0.8740850504741097, 0.5211314470341011, 0.21664581846880504`], 
             UndirectedEdge[41, 389] -> 
             RGBColor[
              0.2255132290582107, 0.3543590804777015, 0.9361540168267153], 
             UndirectedEdge[5, 300] -> 
             RGBColor[
              0.23228249418787045`, 0.3614740073251723, 0.936539516461619], 
             UndirectedEdge[290, 340] -> 
             RGBColor[
              0.31195990105564253`, 0.44256756021982796`, 0.9411741462288754],
              UndirectedEdge[288, 392] -> 
             RGBColor[
              0.281033651223698, 0.41271456437171095`, 0.9393158227339358], 
             UndirectedEdge[45, 292] -> 
             RGBColor[
              0.23087655194201073`, 0.35999627288288677`, 0.9364594501306225],
              UndirectedEdge[42, 145] -> 
             RGBColor[
              0.22656621784669417`, 0.3554658384577429, 0.9362139829804621], 
             UndirectedEdge[100, 368] -> 
             RGBColor[
              0.6696582512860165, 0.6464478563026956, 0.6053684569202311], 
             UndirectedEdge[302, 315] -> 
             RGBColor[
              0.18782448730516063`, 0.31474582329100176`, 0.934007698739376], 
             UndirectedEdge[255, 338] -> 
             RGBColor[
              0.35884542683277726`, 0.48523560545214284`, 0.9440862911766009],
              UndirectedEdge[59, 263] -> 
             RGBColor[
              0.25779587834217144`, 0.38829019171332857`, 0.9379924659455371],
              UndirectedEdge[413, 486] -> 
             RGBColor[
              0.9543818118224241, 0.9371774082640264, 0.6732568757445232], 
             UndirectedEdge[140, 247] -> 
             RGBColor[
              0.4973227229374232, 0.6027880164707773, 0.9535702129842454], 
             UndirectedEdge[82, 453] -> 
             RGBColor[
              0.27129272785642566`, 0.40247623630249474`, 0.9387610915585742],
              UndirectedEdge[199, 349] -> 
             RGBColor[
              0.3782226741008029, 0.5020192031069408, 0.9453209922378925], 
             UndirectedEdge[265, 462] -> 
             RGBColor[
              0.392446435384819, 0.5140523715462819, 0.9463065444803587], 
             UndirectedEdge[113, 386] -> 
             RGBColor[
              0.17905963034776856`, 0.3055334029047545, 0.9335085531020964], 
             UndirectedEdge[140, 219] -> 
             RGBColor[
              0.5129514818808725, 0.6154761470486363, 0.9548005661383041], 
             UndirectedEdge[13, 313] -> 
             RGBColor[
              0.2817870779153078, 0.4135064635946042, 0.939358729269428], 
             UndirectedEdge[74, 463] -> 
             RGBColor[
              0.2744156870316411, 0.4057586644026942, 0.9389389394635987], 
             UndirectedEdge[146, 415] -> 
             RGBColor[
              0.27247295826931617`, 0.4037167332973729, 0.9388283039345939], 
             UndirectedEdge[213, 475] -> 
             RGBColor[
              0.871604644354381, 0.4793529554696741, 0.21338119452328883`], 
             UndirectedEdge[49, 328] -> 
             RGBColor[
              0.4377638604952656, 0.5525889538048573, 0.9493917132424632], 
             UndirectedEdge[259, 450] -> 
             RGBColor[
              0.8397745913250846, 0.3013267240551166, 0.18550990071046175`], 
             UndirectedEdge[454, 500] -> 
             RGBColor[
              0.8596875442431727, 0.3945530129661969, 0.20223564129349905`], 
             UndirectedEdge[469, 495] -> 
             RGBColor[
              0.8513165746787745, 0.3922611978068248, 0.19664935782673318`], 
             UndirectedEdge[158, 182] -> 
             RGBColor[
              0.36805399542884243`, 0.4932116047339394, 0.9446730530247247], 
             UndirectedEdge[302, 347] -> 
             RGBColor[
              0.18453817917078433`, 0.311291705077802, 0.9338205483527805], 
             UndirectedEdge[87, 107] -> 
             RGBColor[
              0.1819624771956669, 0.3085844789930161, 0.9336738659357071], 
             UndirectedEdge[80, 307] -> 
             RGBColor[
              0.6296762406643908, 0.7079838947833768, 0.9655310968074982], 
             UndirectedEdge[159, 443] -> 
             RGBColor[
              0.877631072588452, 0.4692846461457165, 0.21683434670508697`], 
             UndirectedEdge[396, 443] -> 
             RGBColor[
              0.9640290207521414, 0.8833364286136021, 0.40253589756085995`], 
             UndirectedEdge[15, 452] -> 
             RGBColor[
              0.22909610908040262`, 0.3581249145487392, 0.9363580565435832], 
             UndirectedEdge[55, 250] -> 
             RGBColor[
              0.20796149957955015`, 0.33591109995170554`, 0.9351544717983624],
              UndirectedEdge[105, 447] -> 
             RGBColor[
              0.24620260884716, 0.3761049304183308, 0.9373322463985014], 
             UndirectedEdge[55, 242] -> 
             RGBColor[
              0.21824264556347417`, 0.34671723624311485`, 0.9357399678525544],
              UndirectedEdge[133, 440] -> 
             RGBColor[
              0.31342375230206637`, 0.44339062767442217`, 0.9412837095607336],
              UndirectedEdge[177, 455] -> 
             RGBColor[
              0.2063185988388122, 0.33418430710726665`, 0.9350609110316312], 
             UndirectedEdge[186, 456] -> 
             RGBColor[
              0.22968446940414386`, 0.35874331855319036`, 0.9363915627936191],
              UndirectedEdge[94, 302] -> 
             RGBColor[
              0.5727842186692342, 0.6417308063914131, 0.9472440733920693], 
             UndirectedEdge[146, 376] -> 
             RGBColor[
              0.2686941653913333, 0.39974498239330636`, 0.9386131072704159], 
             UndirectedEdge[44, 106] -> 
             RGBColor[
              0.5072662938524296, 0.6108606552923443, 0.9543530073111751], 
             UndirectedEdge[46, 205] -> 
             RGBColor[
              0.9557407049755898, 0.8502199530826348, 0.4110195083871594], 
             UndirectedEdge[134, 457] -> 
             RGBColor[
              0.22739772905471156`, 0.3563398094582248, 0.936261336313648], 
             UndirectedEdge[229, 248] -> 
             RGBColor[
              0.2667577277658053, 0.3977096636716398, 0.9385028300123448], 
             UndirectedEdge[101, 362] -> 
             RGBColor[
              0.45464713410545365`, 0.5663810460128507, 0.950697205214848], 
             UndirectedEdge[286, 346] -> 
             RGBColor[
              0.22049146079372114`, 0.3490808836332252, 0.935868034553093], 
             UndirectedEdge[134, 138] -> 
             RGBColor[
              0.2265863896100655, 0.3554870402600099, 0.9362151317325447], 
             UndirectedEdge[144, 494] -> 
             RGBColor[
              0.25236564813326057`, 0.3825826754672824, 0.9376832223684453], 
             UndirectedEdge[35, 147] -> 
             RGBColor[
              0.2449327987863818, 0.374770279533845, 0.9372599325940558], 
             UndirectedEdge[5, 211] -> 
             RGBColor[
              0.2348238735021131, 0.3641451581171964, 0.9366842442539314], 
             UndirectedEdge[243, 471] -> 
             RGBColor[
              0.8480593461920269, 0.37041077133751354`, 0.1936549902297403], 
             UndirectedEdge[154, 338] -> 
             RGBColor[
              0.314823265682197, 0.4471058220816644, 0.9412812379953546], 
             UndirectedEdge[185, 383] -> 
             RGBColor[
              0.3064436349421723, 0.43755476203867083`, 0.9408312549471323], 
             UndirectedEdge[416, 429] -> 
             RGBColor[
              0.2775658260011634, 0.4090696601900088, 0.9391183352177], 
             UndirectedEdge[159, 396] -> 
             RGBColor[
              0.9071481131704897, 0.5745522202562454, 0.3532052383412315], 
             UndirectedEdge[73, 322] -> 
             RGBColor[
              0.2535645087759725, 0.3838427540149276, 0.9377514957084923], 
             UndirectedEdge[287, 300] -> 
             RGBColor[
              0.2178846815571592, 0.3463409933762489, 0.9357195823319551], 
             UndirectedEdge[392, 459] -> 
             RGBColor[
              0.34827375514967984`, 0.47582519706689724`, 0.9434219649183455],
              UndirectedEdge[200, 450] -> 
             RGBColor[
              0.8592682454015592, 0.38984285435780597`, 0.20177588350505832`],
              UndirectedEdge[104, 148] -> 
             RGBColor[
              0.2431147548759032, 0.37285940011329033`, 0.9371563976829089], 
             UndirectedEdge[94, 325] -> 
             RGBColor[
              0.5672179996830251, 0.6358803573182399, 0.9469270854552878], 
             UndirectedEdge[355, 378] -> 
             RGBColor[
              0.30589561445696456`, 0.4370005514707954, 0.940799248016793], 
             UndirectedEdge[424, 453] -> 
             RGBColor[
              0.3024506322714007, 0.4341297008728973, 0.9405755985889044], 
             UndirectedEdge[212, 301] -> 
             RGBColor[
              0.2136344659280746, 0.34187374727084574`, 0.9354775388395093], 
             UndirectedEdge[46, 420] -> 
             RGBColor[
              0.9431488383406506, 0.8436851965616485, 0.5952825252201055], 
             UndirectedEdge[146, 284] -> 
             RGBColor[
              0.25151293220690424`, 0.3816864169633695, 0.9376346614579194], 
             UndirectedEdge[76, 343] -> 
             RGBColor[
              0.3521064049491038, 0.47793237749510553`, 0.9437105723744709], 
             UndirectedEdge[111, 256] -> 
             RGBColor[
              0.2812386903435383, 0.41293007348689414`, 0.9393274994084824], 
             UndirectedEdge[277, 319] -> 
             RGBColor[
              0.7430956081884199, 0.7992312039433723, 0.9750284836670953], 
             UndirectedEdge[240, 429] -> 
             RGBColor[
              0.2751117605214455, 0.4064902817740869, 0.9389785798190946], 
             UndirectedEdge[49, 71] -> 
             RGBColor[
              0.6229981269292593, 0.7030794824142605, 0.9646517716159538], 
             UndirectedEdge[19, 139] -> 
             RGBColor[
              0.5618798532479841, 0.6551984031224687, 0.9586523867628529], 
             UndirectedEdge[9, 247] -> 
             RGBColor[
              0.5350775301382318, 0.6334390697910756, 0.9565424097075088], 
             UndirectedEdge[333, 392] -> 
             RGBColor[
              0.34232526370384136`, 0.4706729127563853, 0.943042932303461], 
             UndirectedEdge[169, 337] -> 
             RGBColor[
              0.6764764422213522, 0.7452210038115648, 0.9698692373870139], 
             UndirectedEdge[21, 119] -> 
             RGBColor[
              0.9857675700825197, 0.9687962754074746, 0.5924568745131584], 
             UndirectedEdge[354, 479] -> 
             RGBColor[
              0.38662725868303643`, 0.5092988318453677, 0.9458565249355901], 
             UndirectedEdge[179, 236] -> 
             RGBColor[
              0.23312614698427564`, 0.36236073990487094`, 0.9365875612403018],
              UndirectedEdge[121, 341] -> 
             RGBColor[
              0.9105196563022746, 0.6003916270804778, 0.3579070077274834], 
             UndirectedEdge[263, 323] -> 
             RGBColor[
              0.2563726589916906, 0.3867942979386546, 0.9379114157089916], 
             UndirectedEdge[200, 401] -> 
             RGBColor[
              0.8371401925160188, 0.7327555556169211, 0.6085074799840489], 
             UndirectedEdge[56, 236] -> 
             RGBColor[
              0.5619983827153064, 0.35111011799079705`, 0.5612129978793174], 
             UndirectedEdge[374, 437] -> 
             RGBColor[
              0.25378039219455883`, 0.3840696611756612, 0.9377637899498099], 
             UndirectedEdge[74, 195] -> 
             RGBColor[
              0.27594296910076915`, 0.40736393469262394`, 0.9390259159180243],
              UndirectedEdge[240, 399] -> 
             RGBColor[
              0.24906325398775672`, 0.3791116498364756, 0.9374951559073132], 
             UndirectedEdge[138, 352] -> 
             RGBColor[
              0.22389864331585435`, 0.3526620484918363, 0.9360620685572537], 
             UndirectedEdge[195, 342] -> 
             RGBColor[
              0.265069534257383, 0.39593526525663725`, 0.9384066898894987], 
             UndirectedEdge[13, 363] -> 
             RGBColor[
              0.3507138092232281, 0.4770709297343131, 0.9436092144688942], 
             UndirectedEdge[368, 386] -> 
             RGBColor[
              0.2935143249909316, 0.4166464351270609, 0.9403629270800464], 
             UndirectedEdge[132, 233] -> 
             RGBColor[
              0.9166463543771588, 0.6614692040973338, 0.5010749461233683], 
             UndirectedEdge[304, 310] -> 
             RGBColor[
              0.317660558842397, 0.44845488439544834`, 0.9415026138990965], 
             UndirectedEdge[213, 259] -> 
             RGBColor[
              0.8830232984339081, 0.5617179434386964, 0.224104111662967], 
             UndirectedEdge[226, 446] -> 
             RGBColor[
              0.20378813280661343`, 0.33152462686661266`, 0.9349168047345866],
              UndirectedEdge[60, 249] -> 
             RGBColor[
              0.29112873348308044`, 0.42332513589150556`, 0.9398907227342717],
              UndirectedEdge[181, 387] -> 
             RGBColor[
              0.5979055016129029, 0.6815262817946347, 0.9631235948533272], 
             UndirectedEdge[94, 168] -> 
             RGBColor[
              0.9331056494970619, 0.8251500560931704, 0.6037137900969318], 
             UndirectedEdge[142, 402] -> 
             RGBColor[
              0.6259177691187879, 0.7063115685381091, 0.9642924066530247], 
             UndirectedEdge[188, 310] -> 
             RGBColor[
              0.3170171080071488, 0.4478975596227356, 0.9414616137808558], 
             UndirectedEdge[74, 239] -> 
             RGBColor[
              0.31633226480045645`, 0.4459153985127936, 0.9414688336983061], 
             UndirectedEdge[376, 400] -> 
             RGBColor[
              0.2876884645475003, 0.41970919511456195`, 0.9396948045078122], 
             UndirectedEdge[292, 308] -> 
             RGBColor[
              0.17895845847297373`, 0.30542706484967774`, 0.9335027915134972],
              UndirectedEdge[7, 142] -> 
             RGBColor[
              0.7691032060058948, 0.819699666861827, 0.9775805727504322], 
             UndirectedEdge[20, 194] -> 
             RGBColor[
              0.9355250585723344, 0.7786349412620628, 0.5492457614630861], 
             UndirectedEdge[168, 500] -> 
             RGBColor[
              0.8651424411448785, 0.41743131522220955`, 0.2066895157907081], 
             UndirectedEdge[4, 383] -> 
             RGBColor[
              0.32662308368104653`, 0.45732623135617084`, 0.9420331119640719],
              UndirectedEdge[91, 303] -> 
             RGBColor[
              0.3164436833902854, 0.44818690517109605`, 0.9413962957337874], 
             UndirectedEdge[142, 417] -> 
             RGBColor[
              0.7002784838355302, 0.7657821409766972, 0.9707608728603756], 
             UndirectedEdge[229, 338] -> 
             RGBColor[
              0.3055405634218271, 0.43742263545021065`, 0.9407499098335221], 
             UndirectedEdge[69, 388] -> 
             RGBColor[
              0.9278173046721767, 0.9450102776472538, 0.9836136557859578], 
             UndirectedEdge[170, 374] -> 
             RGBColor[
              0.2742054454433818, 0.40553768716334715`, 0.9389269665161719], 
             UndirectedEdge[96, 281] -> 
             RGBColor[
              0.27053519804586806`, 0.4016800244414347, 0.938717951356528], 
             UndirectedEdge[131, 265] -> 
             RGBColor[
              0.29231177765764305`, 0.42343428317537546`, 0.9399996278912657],
              UndirectedEdge[117, 369] -> 
             RGBColor[
              0.40051134864769267`, 0.5213245327381009, 0.9467412068709193], 
             UndirectedEdge[19, 247] -> 
             RGBColor[
              0.5273679540729146, 0.6271800886288073, 0.9559354836385393], 
             UndirectedEdge[328, 436] -> 
             RGBColor[
              0.42911640965865483`, 0.5455685636524759, 0.9487109542359491], 
             UndirectedEdge[86, 178] -> 
             RGBColor[
              0.9534388639235, 0.8461526483552239, 0.5190456011559075], 
             UndirectedEdge[42, 137] -> 
             RGBColor[
              0.22627740530250587`, 0.35516227816202806`, 0.9361975355333305],
              UndirectedEdge[54, 135] -> 
             RGBColor[
              0.23967378277683635`, 0.36924272026693905`, 0.9369604394123292],
              UndirectedEdge[42, 174] -> 
             RGBColor[
              0.2495656884148965, 0.3796397402755821, 0.9375237688046536], 
             UndirectedEdge[1, 374] -> 
             RGBColor[
              0.25894790578239785`, 0.38950104559576504`, 0.9380580722039861],
              UndirectedEdge[160, 285] -> 
             RGBColor[
              0.3684500451199806, 0.49355464307036695`, 0.9446982889608311], 
             UndirectedEdge[454, 471] -> 
             RGBColor[
              0.8783475046128462, 0.5379816452142798, 0.2201044404169093], 
             UndirectedEdge[26, 425] -> 
             RGBColor[
              0.38098619324606947`, 0.5044128244920598, 0.9454970812341448], 
             UndirectedEdge[333, 442] -> 
             RGBColor[
              0.331297230301234, 0.4590817504325423, 0.942414902115696], 
             UndirectedEdge[75, 410] -> 
             RGBColor[
              0.354306761585108, 0.48130444173456, 0.9437970914404035], 
             UndirectedEdge[31, 40] -> 
             RGBColor[
              0.4196192099941566, 0.5378748018473721, 0.9479587428994976], 
             UndirectedEdge[3, 258] -> 
             RGBColor[
              0.41754423807969365`, 0.5358508967798354, 0.9478891567573319], 
             UndirectedEdge[132, 273] -> 
             RGBColor[
              0.6418371637733833, 0.7080243687957053, 0.8766074186854609], 
             UndirectedEdge[157, 180] -> 
             RGBColor[
              0.2863372761085622, 0.4182890103949429, 0.9396178563251187], 
             UndirectedEdge[213, 401] -> 
             RGBColor[
              0.8388291376735261, 0.7404246611139982, 0.6099167772233072], 
             UndirectedEdge[84, 391] -> 
             RGBColor[
              0.23722076036640824`, 0.3666644381829753, 0.9368207434149767], 
             UndirectedEdge[43, 110] -> 
             RGBColor[
              0.2824315567297242, 0.4141838516908727, 0.9393954313844881], 
             UndirectedEdge[39, 127] -> 
             RGBColor[
              0.4248206994263658, 0.5301025431322064, 0.9498483295981558], 
             UndirectedEdge[52, 469] -> 
             RGBColor[
              0.8481128613393234, 0.36763605320366755`, 0.19358147831479822`],
              UndirectedEdge[260, 483] -> 
             RGBColor[
              0.2911128004849959, 0.42330838930030823`, 0.9398898153736015], 
             UndirectedEdge[98, 311] -> 
             RGBColor[
              0.8710458030481137, 0.8971927199459824, 0.8490560873664715], 
             UndirectedEdge[51, 127] -> 
             RGBColor[
              0.20245340605759676`, 0.3301217444268325, 0.9348407940207814], 
             UndirectedEdge[243, 475] -> 
             RGBColor[
              0.8391547501965229, 0.3019661444972231, 0.18512793904814284`], 
             UndirectedEdge[76, 96] -> 
             RGBColor[
              0.3537435180123586, 0.4796530871235497, 0.9438038035415315], 
             UndirectedEdge[99, 476] -> 
             RGBColor[
              0.9210569805098886, 0.6812525268241133, 0.37059559494700395`], 
             UndirectedEdge[107, 308] -> 
             RGBColor[
              0.18180898862834943`, 0.3084231527770282, 0.9336651249888644], 
             UndirectedEdge[190, 263] -> 
             RGBColor[
              0.26075513515246407`, 0.3914005582486648, 0.9381609912430551], 
             UndirectedEdge[191, 299] -> 
             RGBColor[
              0.21378387890714912`, 0.3420307897851831, 0.935486047687631], 
             UndirectedEdge[39, 276] -> 
             RGBColor[
              0.6216008719460259, 0.7036826165027719, 0.9633538441200625], 
             UndirectedEdge[51, 214] -> 
             RGBColor[
              0.1893670578318586, 0.31636716271918164`, 0.9340955458488429], 
             UndirectedEdge[295, 409] -> 
             RGBColor[
              0.23557177233220394`, 0.3649312472071466, 0.9367268359858879], 
             UndirectedEdge[371, 382] -> 
             RGBColor[
              0.322584307384319, 0.45137597056269757`, 0.9418655472151594], 
             UndirectedEdge[53, 420] -> 
             RGBColor[
              0.9725775680800968, 0.9542835451375451, 0.6506094324523175], 
             UndirectedEdge[87, 308] -> 
             RGBColor[
              0.17909977333492821`, 0.3055755957294717, 0.9335108391858289], 
             UndirectedEdge[286, 358] -> 
             RGBColor[
              0.22436323878386594`, 0.35315036778577047`, 0.9360885265818495],
              UndirectedEdge[215, 351] -> 
             RGBColor[
              0.28708427642095813`, 0.4190741550858264, 0.9396603968878219], 
             UndirectedEdge[114, 258] -> 
             RGBColor[
              0.4370504632160207, 0.551686929090934, 0.9494247582537205], 
             UndirectedEdge[87, 292] -> 
             RGBColor[
              0.1791119470402912, 0.3055883910656657, 0.93351153246034], 
             UndirectedEdge[196, 383] -> 
             RGBColor[
              0.3123209276016251, 0.4437321692656331, 0.941165958069413], 
             UndirectedEdge[65, 495] -> 
             RGBColor[
              0.9138336495538494, 0.6440119286541663, 0.2930402350354805], 
             UndirectedEdge[14, 279] -> 
             RGBColor[
              0.2926514518650601, 0.4249256094568878, 0.9399774392934654], 
             UndirectedEdge[26, 466] -> 
             RGBColor[
              0.4450688550450512, 0.558555224381097, 0.9499569121935232], 
             UndirectedEdge[27, 371] -> 
             RGBColor[
              0.43753141765926407`, 0.551792873087608, 0.9495412335023905], 
             UndirectedEdge[258, 472] -> 
             RGBColor[
              0.3509345795878789, 0.47838362717935545`, 0.9435822189854435], 
             UndirectedEdge[26, 117] -> 
             RGBColor[
              0.38385240519854513`, 0.5068953932252928, 0.9456797137252648], 
             UndirectedEdge[97, 104] -> 
             RGBColor[
              0.23915408747259903`, 0.3686964875516002, 0.936930843533573], 
             UndirectedEdge[21, 428] -> 
             RGBColor[
              0.9056106309029361, 0.5906771035003356, 0.2784668522610333], 
             UndirectedEdge[160, 268] -> 
             RGBColor[
              0.41606826400089775`, 0.5347991509037464, 0.9477324797607855], 
             UndirectedEdge[48, 137] -> 
             RGBColor[
              0.21379570916554433`, 0.34204322413683813`, 0.9354867214033452],
              UndirectedEdge[27, 291] -> 
             RGBColor[
              0.583523028601068, 0.6725767800031528, 0.9604878491746004], 
             UndirectedEdge[117, 140] -> 
             RGBColor[
              0.44035466890019287`, 0.5545772244209933, 0.9496274637964799], 
             UndirectedEdge[31, 221] -> 
             RGBColor[
              0.4948241717740719, 0.6007519845572706, 0.9533756165491586], 
             UndirectedEdge[87, 386] -> 
             RGBColor[
              0.17909013095112286`, 0.3055654609727298, 0.9335102900663359], 
             UndirectedEdge[207, 409] -> 
             RGBColor[
              0.22930932819200256`, 0.35834902135390323`, 0.9363701990565594],
              UndirectedEdge[274, 498] -> 
             RGBColor[
              0.46231188623512687`, 0.5743646420156336, 0.95081403167012], 
             UndirectedEdge[28, 69] -> 
             RGBColor[
              0.9371592911405698, 0.9519775158592825, 0.9678001094752631], 
             UndirectedEdge[442, 492] -> 
             RGBColor[
              0.2802823193946945, 0.4119248669822389, 0.9392730354977699], 
             UndirectedEdge[476, 493] -> 
             RGBColor[
              0.9210348441528622, 0.6812051793947629, 0.36818618909444256`], 
             UndirectedEdge[297, 359] -> 
             RGBColor[
              0.45240773600559087`, 0.5644812656494411, 0.9505434955218137], 
             UndirectedEdge[112, 323] -> 
             RGBColor[
              0.24380409586490398`, 0.37358394119947325`, 0.9371956546324439],
              UndirectedEdge[27, 349] -> 
             RGBColor[
              0.46286019331944683`, 0.5737313855031778, 0.9511551606901004], 
             UndirectedEdge[2, 242] -> 
             RGBColor[
              0.21872765624032725`, 0.34722701321594046`, 0.9357675884930923],
              UndirectedEdge[71, 462] -> 
             RGBColor[
              0.6098299518680684, 0.6923889646800596, 0.9636151246385223], 
             UndirectedEdge[165, 285] -> 
             RGBColor[
              0.3692257984681636, 0.49422656163006606`, 0.9447477192782054], 
             UndirectedEdge[91, 172] -> 
             RGBColor[
              0.33964065051404985`, 0.4686013934649852, 0.9428625798116885], 
             UndirectedEdge[19, 26] -> 
             RGBColor[
              0.4731770317838775, 0.5813747085166081, 0.9521696908300475], 
             UndirectedEdge[73, 163] -> 
             RGBColor[
              0.2574513896017804, 0.3879281122053299, 0.9379728478213971], 
             UndirectedEdge[67, 131] -> 
             RGBColor[
              0.2601160605037315, 0.39072885027317383`, 0.938124596887236], 
             UndirectedEdge[24, 81] -> 
             RGBColor[
              0.8302950804632105, 0.8675187756745408, 0.9836754800593912], 
             UndirectedEdge[282, 467] -> 
             RGBColor[
              0.6572487791197071, 0.7316354395209496, 0.9668355107224047], 
             UndirectedEdge[122, 406] -> 
             RGBColor[
              0.929061342775948, 0.7356327772399205, 0.3146046467534838], 
             UndirectedEdge[139, 255] -> 
             RGBColor[
              0.4808103528632557, 0.5878692632314095, 0.9526884189998513], 
             UndirectedEdge[409, 458] -> 
             RGBColor[
              0.23602745875437942`, 0.36541020252904094`, 0.9367527866535031],
              UndirectedEdge[4, 196] -> 
             RGBColor[
              0.31000149085861584`, 0.44172318973711877`, 0.9410181656111457],
              UndirectedEdge[46, 90] -> 
             RGBColor[
              0.8912123121580973, 0.5950344530170778, 0.2307371435474895], 
             UndirectedEdge[115, 124] -> 
             RGBColor[
              0.9419104649402625, 0.9128295501642687, 0.6508778471089514], 
             UndirectedEdge[330, 350] -> 
             RGBColor[
              0.33430977302587317`, 0.4637717331289171, 0.9425306751676419], 
             UndirectedEdge[213, 315] -> 
             RGBColor[
              0.5448527569683213, 0.48510270783243126`, 0.5878273462350064], 
             UndirectedEdge[107, 143] -> 
             RGBColor[
              0.18179934691843552`, 0.30841301872858895`, 0.9336645759077484],
              UndirectedEdge[403, 491] -> 
             RGBColor[
              0.9615367037861473, 0.968036714632053, 0.7994838663892643], 
             UndirectedEdge[200, 254] -> 
             RGBColor[
              0.5686631284014866, 0.5042350008222019, 0.5878701973527287], 
             UndirectedEdge[37, 304] -> 
             RGBColor[
              0.32210212279026273`, 0.45312324971607465`, 0.9417555543952225],
              UndirectedEdge[25, 392] -> 
             RGBColor[
              0.3096883372024623, 0.4424044474005129, 0.9409633362064942], 
             UndirectedEdge[231, 492] -> 
             RGBColor[
              0.2675328366491727, 0.39852435225280064`, 0.9385469713165818], 
             UndirectedEdge[22, 63] -> 
             RGBColor[
              0.4353760609281416, 0.5515225941640346, 0.948962755507775], 
             UndirectedEdge[201, 256] -> 
             RGBColor[
              0.2969224563599441, 0.4294147059783363, 0.9402206666810642], 
             UndirectedEdge[57, 92] -> 
             RGBColor[
              0.6051902881840892, 0.690359765316458, 0.9620619428523739], 
             UndirectedEdge[433, 462] -> 
             RGBColor[
              0.3946923083800721, 0.5159976338539112, 0.9464496495216687], 
             UndirectedEdge[286, 294] -> 
             RGBColor[
              0.23070650372322443`, 0.3598175414232626, 0.9364497661361264], 
             UndirectedEdge[319, 331] -> 
             RGBColor[
              0.775790689833521, 0.8249078922958527, 0.9782513878368327], 
             UndirectedEdge[222, 307] -> 
             RGBColor[
              0.456261635454359, 0.5691648443465238, 0.950417290103996], 
             UndirectedEdge[276, 283] -> 
             RGBColor[
              0.4003771577872324, 0.5049037920541919, 0.9484114336869224], 
             UndirectedEdge[464, 497] -> 
             RGBColor[
              0.23993020302659857`, 0.369512234207422, 0.9369750421662133], 
             UndirectedEdge[143, 283] -> 
             RGBColor[
              0.18007058028918088`, 0.3065959753911073, 0.9335661252056935], 
             UndirectedEdge[265, 433] -> 
             RGBColor[
              0.32326037843179023`, 0.45441362508374517`, 0.9418188433591128],
              UndirectedEdge[74, 234] -> 
             RGBColor[
              0.335156328175214, 0.4622198560830736, 0.94266828637108], 
             UndirectedEdge[17, 432] -> 
             RGBColor[
              0.8892978625365586, 0.9145659925119751, 0.9893032180859526], 
             UndirectedEdge[103, 118] -> 
             RGBColor[
              0.4027319052154037, 0.522513730131029, 0.9470855430392838], 
             UndirectedEdge[426, 489] -> 
             RGBColor[
              0.9301359936068372, 0.9447452859638352, 0.9006256116612403], 
             UndirectedEdge[277, 331] -> 
             RGBColor[
              0.8039966134471465, 0.8469425741957761, 0.9810626907032964], 
             UndirectedEdge[74, 112] -> 
             RGBColor[
              0.264998769293781, 0.3958608867931338, 0.938402659929509], 
             UndirectedEdge[80, 372] -> 
             RGBColor[
              0.6299979927875134, 0.7082451076516956, 0.9655564263132472], 
             UndirectedEdge[180, 281] -> 
             RGBColor[
              0.2575198022383923, 0.3880000182240208, 0.9379767438198447], 
             UndirectedEdge[263, 296] -> 
             RGBColor[
              0.2934102361450429, 0.4252910132115676, 0.9400364732085589], 
             UndirectedEdge[37, 141] -> 
             RGBColor[
              0.3076115395353609, 0.4405722348185699, 0.9408322272437397], 
             UndirectedEdge[18, 210] -> 
             RGBColor[
              0.8602238171594843, 0.4230516477625904, 0.20370370360755374`], 
             UndirectedEdge[279, 494] -> 
             RGBColor[
              0.2685318784304253, 0.3995744085078045, 0.9386038652680744], 
             UndirectedEdge[101, 337] -> 
             RGBColor[
              0.6905217138834787, 0.756623588079157, 0.9709749326217818], 
             UndirectedEdge[217, 378] -> 
             RGBColor[
              0.30140209308183147`, 0.4331084891066064, 0.9405129248082346], 
             UndirectedEdge[20, 62] -> 
             RGBColor[
              0.8509265138034974, 0.3513524058869604, 0.19479135055817565`], 
             UndirectedEdge[18, 56] -> 
             RGBColor[
              0.8605287644059905, 0.4253956059279722, 0.2039957214351967], 
             UndirectedEdge[444, 492] -> 
             RGBColor[
              0.2739561801729139, 0.4052756935597544, 0.9389127712277736], 
             UndirectedEdge[199, 427] -> 
             RGBColor[
              0.31117200287913815`, 0.44123930103287445`, 0.9411475887384059],
              UndirectedEdge[190, 463] -> 
             RGBColor[
              0.2576034897635375, 0.3880879791190439, 0.9379815097005972], 
             UndirectedEdge[139, 369] -> 
             RGBColor[
              0.49199130185999246`, 0.5975536392815464, 0.9534008591829983], 
             UndirectedEdge[10, 455] -> 
             RGBColor[
              0.21145152724630215`, 0.3395793403099965, 0.9353532237109508], 
             UndirectedEdge[52, 236] -> 
             RGBColor[
              0.5615591008027638, 0.3477336047164332, 0.5607923410237687], 
             UndirectedEdge[9, 19] -> 
             RGBColor[
              0.5674341026863339, 0.6597075930326068, 0.9590896376245259], 
             UndirectedEdge[33, 309] -> 
             RGBColor[
              0.9357225086078202, 0.7641455885442991, 0.35153908493080155`], 
             UndirectedEdge[341, 491] -> 
             RGBColor[
              0.9938674015539399, 0.9892913169617195, 0.5738826890360067], 
             UndirectedEdge[87, 143] -> 
             RGBColor[
              0.1790901316250143, 0.30556546168103244`, 0.933510290104713], 
             UndirectedEdge[110, 378] -> 
             RGBColor[
              0.2773998635716586, 0.40889522315397336`, 0.9391088839028592], 
             UndirectedEdge[401, 471] -> 
             RGBColor[
              0.8151324803555211, 0.6303190641854999, 0.5900456312313715], 
             UndirectedEdge[160, 165] -> 
             RGBColor[
              0.4232575021072018, 0.5410261076098133, 0.9481905716557255], 
             UndirectedEdge[13, 379] -> 
             RGBColor[
              0.3029577301181068, 0.43570701430378433`, 0.9405662393373586], 
             UndirectedEdge[210, 434] -> 
             RGBColor[
              0.9136331462118448, 0.6344185701788778, 0.48881376628200723`], 
             UndirectedEdge[308, 446] -> 
             RGBColor[
              0.2035487790418117, 0.3312730508839008, 0.9349031738917732], 
             UndirectedEdge[153, 395] -> 
             RGBColor[
              0.2549602684410159, 0.3853097859191623, 0.9378309821565751], 
             UndirectedEdge[24, 83] -> 
             RGBColor[
              0.878858858195596, 0.9062422138097157, 0.9883075365329024], 
             UndirectedEdge[133, 260] -> 
             RGBColor[
              0.31537504749154577`, 0.44544156263782575`, 0.9413948329350919],
              UndirectedEdge[83, 119] -> 
             RGBColor[
              0.9556965383033635, 0.9650210547273206, 0.8984817408494732], 
             UndirectedEdge[400, 464] -> 
             RGBColor[
              0.26989429594474446`, 0.40100639569761354`, 0.9386814529299987],
              UndirectedEdge[175, 320] -> 
             RGBColor[
              0.9721663810423609, 0.9780295691716399, 0.8991854671906325], 
             UndirectedEdge[39, 475] -> 
             RGBColor[
              0.731332489294519, 0.5030791649818271, 0.5742495342753344], 
             UndirectedEdge[289, 291] -> 
             RGBColor[
              0.5471490964494157, 0.6426680909259248, 0.9577289938124869], 
             UndirectedEdge[263, 342] -> 
             RGBColor[
              0.2666938975771815, 0.3976425740963284, 0.9384991949775311], 
             UndirectedEdge[311, 319] -> 
             RGBColor[
              0.7308732764235066, 0.7896830254754603, 0.9738102758609529], 
             UndirectedEdge[141, 304] -> 
             RGBColor[
              0.3240734635805927, 0.45511787857278996`, 0.9418706524258115], 
             UndirectedEdge[30, 43] -> 
             RGBColor[
              0.2805395184040802, 0.4121951994484624, 0.9392876826008625], 
             UndirectedEdge[85, 95] -> 
             RGBColor[
              0.22064923730827996`, 0.3492467167536353, 0.9358770196921877], 
             UndirectedEdge[305, 438] -> 
             RGBColor[
              0.23628821482403703`, 0.36568427369114076`, 0.9367676363259161],
              UndirectedEdge[23, 212] -> 
             RGBColor[
              0.22050887971367938`, 0.3490991920225246, 0.9358690265348157], 
             UndirectedEdge[80, 461] -> 
             RGBColor[
              0.8669992096038857, 0.8968058897416262, 0.9792822184041656], 
             UndirectedEdge[115, 439] -> 
             RGBColor[
              0.8910404321249454, 0.9159554702009634, 0.9894694259289032], 
             UndirectedEdge[136, 377] -> 
             RGBColor[
              0.9750328863705816, 0.980900148051852, 0.9271469902951855], 
             UndirectedEdge[27, 488] -> 
             RGBColor[
              0.640741608541348, 0.7172763695298137, 0.9661908624850168], 
             UndirectedEdge[70, 170] -> 
             RGBColor[
              0.2774653661360603, 0.408964070502262, 0.9391126141769994], 
             UndirectedEdge[268, 441] -> 
             RGBColor[
              0.4298935905497302, 0.5467739538792281, 0.9486134173432208], 
             UndirectedEdge[394, 445] -> 
             RGBColor[
              0.2291408986849781, 0.35817199126297306`, 0.9363606072453035], 
             UndirectedEdge[234, 393] -> 
             RGBColor[
              0.42489506401207827`, 0.5422301548105988, 0.9483541347345662], 
             UndirectedEdge[228, 388] -> 
             RGBColor[
              0.9696267022726579, 0.9734928770909221, 0.7321607638451979], 
             UndirectedEdge[8, 114] -> 
             RGBColor[
              0.5604860564407306, 0.6540668560845098, 0.9585426619725401], 
             UndirectedEdge[21, 164] -> 
             RGBColor[
              0.8992062375406565, 0.5414501296947882, 0.27233399794458657`], 
             UndirectedEdge[100, 454] -> 
             RGBColor[
              0.915548639391991, 0.7016340736991815, 0.25084192040061865`], 
             UndirectedEdge[6, 267] -> 
             RGBColor[
              0.9083762130299251, 0.9201045780958312, 0.6977188544044266], 
             UndirectedEdge[210, 495] -> 
             RGBColor[
              0.8391330927044698, 0.3017996755229297, 0.18510719980929416`], 
             UndirectedEdge[112, 342] -> 
             RGBColor[
              0.25412533445039487`, 0.3844322173571471, 0.9377834339009834], 
             UndirectedEdge[93, 206] -> 
             RGBColor[
              0.30600971855859727`, 0.43582355730741806`, 0.940853232846973], 
             UndirectedEdge[485, 497] -> 
             RGBColor[
              0.24199741678266362`, 0.3716850069339687, 0.9370927669314526], 
             UndirectedEdge[36, 240] -> 
             RGBColor[
              0.25550742159800177`, 0.3858848785786683, 0.9378621417194251], 
             UndirectedEdge[275, 285] -> 
             RGBColor[
              0.36406115169331943`, 0.4897532041763907, 0.9444186325526303], 
             UndirectedEdge[36, 399] -> 
             RGBColor[
              0.24794512185068096`, 0.37793642206673694`, 0.937431479936235], 
             UndirectedEdge[72, 279] -> 
             RGBColor[
              0.26627234056032795`, 0.3971994909433567, 0.9384751879290589], 
             UndirectedEdge[278, 413] -> 
             RGBColor[
              0.9610998830487185, 0.9422076271108857, 0.6625746129461039], 
             UndirectedEdge[10, 120] -> 
             RGBColor[
              0.21319195993880496`, 0.3414086454196232, 0.9354523387780493], 
             UndirectedEdge[59, 153] -> 
             RGBColor[
              0.24356203444566857`, 0.3733295193002764, 0.9371818695927163], 
             UndirectedEdge[377, 488] -> 
             RGBColor[
              0.8752347056162003, 0.9025906545325564, 0.9472574998794909], 
             UndirectedEdge[53, 306] -> 
             RGBColor[
              0.9170459103045016, 0.6880097948516692, 0.28301334457340965`], 
             UndirectedEdge[172, 448] -> 
             RGBColor[
              0.45979588464643895`, 0.5695615806771241, 0.9513786855523698], 
             UndirectedEdge[138, 367] -> 
             RGBColor[
              0.22490572664447084`, 0.3537205569229832, 0.9361194204629721], 
             UndirectedEdge[71, 431] -> 
             RGBColor[
              0.602160734252356, 0.6860330125252593, 0.9630472221226452], 
             UndirectedEdge[180, 392] -> 
             RGBColor[
              0.2880661676144659, 0.4201061849857004, 0.9397163141387143], 
             UndirectedEdge[33, 227] -> 
             RGBColor[
              0.8620227096886874, 0.44626803209664856`, 0.20579398688200412`],
              UndirectedEdge[30, 384] -> 
             RGBColor[
              0.2758760121335012, 0.4072935586747084, 0.9390221028177923], 
             UndirectedEdge[441, 467] -> 
             RGBColor[
              0.5784857852356426, 0.6676055963951182, 0.960658898554645], 
             UndirectedEdge[99, 122] -> 
             RGBColor[
              0.930562919133284, 0.740007623770434, 0.37913808172539787`], 
             UndirectedEdge[89, 225] -> 
             RGBColor[
              0.2798755048828646, 0.4114972791367759, 0.9392498680131491], 
             UndirectedEdge[146, 497] -> 
             RGBColor[
              0.24696343657246012`, 0.3769046085968852, 0.9373755744119134], 
             UndirectedEdge[176, 197] -> 
             RGBColor[
              0.6522851143834272, 0.7277468526483104, 0.9663482548197164], 
             UndirectedEdge[326, 474] -> 
             RGBColor[
              0.9341363327937491, 0.7587482425843726, 0.49080863680582576`], 
             UndirectedEdge[173, 241] -> 
             RGBColor[
              0.8450225482014433, 0.8788658384170731, 0.9383874109586698], 
             UndirectedEdge[403, 405] -> 
             RGBColor[
              0.9614623294969025, 0.9678776355477525, 0.7913886839898783], 
             UndirectedEdge[79, 476] -> 
             RGBColor[
              0.9211605712027758, 0.6814740968415736, 0.3818708025801312], 
             UndirectedEdge[46, 257] -> 
             RGBColor[
              0.8882541401217813, 0.5816020846987996, 0.22826877228895565`], 
             UndirectedEdge[450, 491] -> 
             RGBColor[
              0.9059349577098716, 0.5635204793804358, 0.38523852750809673`], 
             UndirectedEdge[200, 243] -> 
             RGBColor[
              0.8700670583525245, 0.4728472627689348, 0.21211683898241762`], 
             UndirectedEdge[296, 424] -> 
             RGBColor[
              0.31700712622472516`, 0.4489973723195799, 0.9414203916580124], 
             UndirectedEdge[269, 466] -> 
             RGBColor[
              0.47622375697085434`, 0.5855400345383266, 0.9519420749950372], 
             UndirectedEdge[74, 453] -> 
             RGBColor[
              0.2830204227561394, 0.41480278722089764`, 0.9394289664335431], 
             UndirectedEdge[18, 469] -> 
             RGBColor[
              0.8724072991337889, 0.5135131700464854, 0.21524586162499276`], 
             UndirectedEdge[279, 481] -> 
             RGBColor[
              0.2983884604335446, 0.4300799385434647, 0.9403362145723715], 
             UndirectedEdge[19, 468] -> 
             RGBColor[
              0.5190507751439478, 0.6204278280896312, 0.9552807248464208], 
             UndirectedEdge[415, 464] -> 
             RGBColor[
              0.2654397247234546, 0.39632435890790974`, 0.9384277716888938], 
             UndirectedEdge[234, 262] -> 
             RGBColor[
              0.4323322286458682, 0.548267980100758, 0.9489396155777698], 
             UndirectedEdge[241, 417] -> 
             RGBColor[
              0.7032574015004508, 0.7681092940971459, 0.9710577835336467], 
             UndirectedEdge[309, 489] -> 
             RGBColor[
              0.9915641796444485, 0.9888374754562259, 0.6482959890771074], 
             UndirectedEdge[83, 426] -> 
             RGBColor[
              0.895460047558787, 0.9194795515806435, 0.9898909727944203], 
             UndirectedEdge[6, 99] -> 
             RGBColor[
              0.9106556765920616, 0.9271034208247384, 0.765274234275318], 
             UndirectedEdge[121, 491] -> 
             RGBColor[
              0.9108136867178351, 0.6010205284083265, 0.38991040391585896`], 
             UndirectedEdge[42, 358] -> 
             RGBColor[
              0.22905024080537584`, 0.3580767040834695, 0.9363554444131764], 
             UndirectedEdge[69, 461] -> 
             RGBColor[
              0.926959006974305, 0.9443701606295145, 0.985066529908563], 
             UndirectedEdge[161, 387] -> 
             RGBColor[
              0.8827228822801044, 0.901646814849579, 0.6975808353380122], 
             UndirectedEdge[117, 390] -> 
             RGBColor[
              0.34091437037852435`, 0.46896566133560236`, 0.9429707972165], 
             UndirectedEdge[244, 334] -> 
             RGBColor[
              0.3726225537176192, 0.4971686603012616, 0.9449641575190681], 
             UndirectedEdge[173, 493] -> 
             RGBColor[
              0.9890701085039466, 0.9882775676582451, 0.7238989830539463], 
             UndirectedEdge[229, 255] -> 
             RGBColor[
              0.34428066244060973`, 0.47097736208628804`, 0.9432183946864745],
              UndirectedEdge[39, 401] -> 
             RGBColor[
              0.6985569826136641, 0.7641508706261513, 0.9707851169753527], 
             UndirectedEdge[379, 380] -> 
             RGBColor[
              0.29107513038505384`, 0.42321764858400834`, 0.9398895428612922],
              UndirectedEdge[92, 140] -> 
             RGBColor[
              0.554385826473297, 0.649114414584719, 0.9580624295236251], 
             UndirectedEdge[78, 97] -> 
             RGBColor[
              0.22558180327383132`, 0.35443115632617517`, 0.9361579220268484],
              UndirectedEdge[395, 463] -> 
             RGBColor[
              0.2660424669485921, 0.39695787920259357`, 0.9384620969669382], 
             UndirectedEdge[174, 338] -> 
             RGBColor[
              0.29338121786998295`, 0.4246423923281867, 0.9400574530924843], 
             UndirectedEdge[143, 423] -> 
             RGBColor[
              0.1833764464098977, 0.31007065028799885`, 0.9337543893906777], 
             UndirectedEdge[94, 100] -> 
             RGBColor[
              0.943316965793535, 0.8656345224892459, 0.6119300548794735], 
             UndirectedEdge[404, 408] -> 
             RGBColor[
              0.2179764205636531, 0.3464374168886629, 0.9357248067326592], 
             UndirectedEdge[301, 389] -> 
             RGBColor[
              0.21362623144598136`, 0.3418650923080694, 0.9354770698979359], 
             UndirectedEdge[16, 422] -> 
             RGBColor[
              0.3189470428658002, 0.4437679620863825, 0.9417969982435161], 
             UndirectedEdge[389, 451] -> 
             RGBColor[
              0.21497280031897864`, 0.34328042157098726`, 0.9355537550031829],
              UndirectedEdge[74, 296] -> 
             RGBColor[
              0.2975769167094639, 0.42967045866758025`, 0.9402737595026511], 
             UndirectedEdge[225, 453] -> 
             RGBColor[
              0.2792780627176027, 0.4108693295410645, 0.939215844565674], 
             UndirectedEdge[340, 378] -> 
             RGBColor[
              0.31025949401998754`, 0.4407803246133216, 0.9410773105637218], 
             UndirectedEdge[52, 428] -> 
             RGBColor[
              0.8330642703587228, 0.25515204759860854`, 0.17929568867725226`],
              UndirectedEdge[84, 230] -> 
             RGBColor[
              0.22859615804425376`, 0.3575994343110202, 0.9363295850716857], 
             UndirectedEdge[119, 237] -> 
             RGBColor[
              0.9483698835729416, 0.9591789791220269, 0.8977829179807035], 
             UndirectedEdge[67, 171] -> 
             RGBColor[
              0.25918264815811415`, 0.38974777471616917`, 0.9380714404350129],
              UndirectedEdge[25, 157] -> 
             RGBColor[
              0.3079594456965586, 0.4405872728097553, 0.9408648783928987], 
             UndirectedEdge[124, 484] -> 
             RGBColor[
              0.9777721242086441, 0.9364424046411297, 0.38854804229456463`], 
             UndirectedEdge[368, 500] -> 
             RGBColor[
              0.6137971561371982, 0.33936679556971105`, 0.5567621778131115], 
             UndirectedEdge[283, 422] -> 
             RGBColor[
              0.207613081778549, 0.3355448907518888, 0.9351346299200334], 
             UndirectedEdge[334, 369] -> 
             RGBColor[
              0.4113757512055576, 0.5307347321729735, 0.9474334769948924], 
             UndirectedEdge[42, 346] -> 
             RGBColor[
              0.22517846281523107`, 0.3540072199309242, 0.9361349523844199], 
             UndirectedEdge[112, 263] -> 
             RGBColor[
              0.2608320887293601, 0.39148144133712115`, 0.9381653736354167], 
             UndirectedEdge[146, 201] -> 
             RGBColor[
              0.28119600247616383`, 0.41288520583171645`, 0.9393250683975864],
              UndirectedEdge[16, 243] -> 
             RGBColor[
              0.6215940953786275, 0.41368682466407874`, 0.566114433864064], 
             UndirectedEdge[285, 481] -> 
             RGBColor[
              0.3163175193458222, 0.44840006950172373`, 0.9413764505174842], 
             UndirectedEdge[231, 444] -> 
             RGBColor[
              0.2648697036740537, 0.39572523064356746`, 0.938395309833401], 
             UndirectedEdge[137, 408] -> 
             RGBColor[
              0.2212925375899113, 0.34992286613722345`, 0.9359136546915492], 
             UndirectedEdge[431, 436] -> 
             RGBColor[
              0.46072987194196846`, 0.5729505557434673, 0.9507253360979548], 
             UndirectedEdge[98, 277] -> 
             RGBColor[
              0.8832681348130269, 0.9067408984138945, 0.8502742951726139], 
             UndirectedEdge[131, 391] -> 
             RGBColor[
              0.2523681386345833, 0.3825852931420795, 0.9376833641988113], 
             UndirectedEdge[52, 227] -> 
             RGBColor[
              0.8407131059122084, 0.31394434940381033`, 0.18662022224139424`],
              UndirectedEdge[27, 419] -> 
             RGBColor[
              0.5124047260338506, 0.6150322660209537, 0.9547575235151939], 
             UndirectedEdge[232, 312] -> 
             RGBColor[
              0.3303045820158528, 0.4601142095117522, 0.9422823672274991], 
             UndirectedEdge[247, 466] -> 
             RGBColor[
              0.4992597773340883, 0.6043606044932961, 0.953722705002015], 
             UndirectedEdge[253, 484] -> 
             RGBColor[
              0.9889617727140382, 0.9876413426482502, 0.6827040059696212], 
             UndirectedEdge[121, 200] -> 
             RGBColor[
              0.8641469744095227, 0.4273429033856967, 0.2064477599128205], 
             UndirectedEdge[79, 99] -> 
             RGBColor[
              0.9937251243023482, 0.9889870003070016, 0.5583966882336657], 
             UndirectedEdge[109, 300] -> 
             RGBColor[
              0.23995882574419874`, 0.3695423184984049, 0.9369766721876371], 
             UndirectedEdge[31, 397] -> 
             RGBColor[
              0.40579315804314603`, 0.5258993705649835, 0.947077759095077], 
             UndirectedEdge[70, 374] -> 
             RGBColor[
              0.2549902427614091, 0.38534129083037727`, 0.9378326891497786], 
             UndirectedEdge[240, 352] -> 
             RGBColor[
              0.24222822396059346`, 0.3719275999119933, 0.937105911058787], 
             UndirectedEdge[105, 323] -> 
             RGBColor[
              0.24262496833818112`, 0.37234460340788433`, 0.93712850506416], 
             UndirectedEdge[46, 53] -> 
             RGBColor[
              0.9470835767696775, 0.821834287485996, 0.3079282681448157], 
             UndirectedEdge[221, 223] -> 
             RGBColor[
              0.46323693275442124`, 0.5733927057392445, 0.9513629056103252], 
             UndirectedEdge[33, 159] -> 
             RGBColor[
              0.8495822086293704, 0.3506448894924134, 0.19388094901806585`], 
             UndirectedEdge[16, 454] -> 
             RGBColor[
              0.6518822537994468, 0.581257698540845, 0.5925638840512331], 
             UndirectedEdge[195, 224] -> 
             RGBColor[
              0.28455910865490164`, 0.41642004365881735`, 0.9395165923191959],
              UndirectedEdge[259, 500] -> 
             RGBColor[
              0.8406666807462297, 0.3081837142621151, 0.18636416654762122`], 
             UndirectedEdge[24, 77] -> 
             RGBColor[
              0.7218949448567346, 0.7822619477143448, 0.9732512022240677], 
             UndirectedEdge[226, 386] -> 
             RGBColor[
              0.1791759961486071, 0.30565571073945375`, 0.9335151799623065], 
             UndirectedEdge[289, 314] -> 
             RGBColor[
              0.3847232625603534, 0.5076496861015274, 0.9457352039862904], 
             UndirectedEdge[179, 325] -> 
             RGBColor[
              0.1789730287155782, 0.30544237909846184`, 0.9335036212672588], 
             UndirectedEdge[81, 83] -> 
             RGBColor[
              0.8721819244967113, 0.9009182081187621, 0.9876706846361336], 
             UndirectedEdge[312, 376] -> 
             RGBColor[
              0.2919333190231436, 0.4241708063077816, 0.9399365426905006], 
             UndirectedEdge[270, 309] -> 
             RGBColor[
              0.9915269265441726, 0.9888220703419007, 0.6489133693566129], 
             UndirectedEdge[139, 269] -> 
             RGBColor[
              0.506487260336648, 0.6101093099259678, 0.9543245288388581], 
             UndirectedEdge[269, 425] -> 
             RGBColor[
              0.4121410951718726, 0.5313976346492894, 0.947482244035659], 
             UndirectedEdge[25, 492] -> 
             RGBColor[
              0.29499729755319337`, 0.42696323326341856`, 0.9401267032319138],
              UndirectedEdge[142, 173] -> 
             RGBColor[
              0.8420436305365226, 0.8765386852966244, 0.9380905002853989], 
             UndirectedEdge[132, 209] -> 
             RGBColor[
              0.7780282420345992, 0.8243344980363514, 0.8860787195432924], 
             UndirectedEdge[389, 409] -> 
             RGBColor[
              0.23002772223876133`, 0.35910409904586005`, 0.9364111105347535],
              UndirectedEdge[337, 370] -> 
             RGBColor[
              0.7258270188663856, 0.785286025150145, 0.9737542955576297], 
             UndirectedEdge[230, 242] -> 
             RGBColor[
              0.2244428247428983, 0.35323401767475476`, 0.9360930588844796], 
             UndirectedEdge[28, 461] -> 
             RGBColor[
              0.954655789916814, 0.9657029428810652, 0.9616400993934879], 
             UndirectedEdge[318, 350] -> 
             RGBColor[
              0.3520561578815369, 0.47935508192515797`, 0.9436536849625428], 
             UndirectedEdge[390, 478] -> 
             RGBColor[
              0.2833977050944594, 0.41519933487955374`, 0.9394504521045712], 
             UndirectedEdge[167, 434] -> 
             RGBColor[
              0.988936416573675, 0.989692938179159, 0.8330157392176978], 
             UndirectedEdge[247, 269] -> 
             RGBColor[
              0.47197536116157857`, 0.5820909954323062, 0.9516076257145445], 
             UndirectedEdge[394, 398] -> 
             RGBColor[
              0.24489676758341208`, 0.3747324084550136, 0.93725788067035], 
             UndirectedEdge[14, 158] -> 
             RGBColor[
              0.33213200521333075`, 0.4619125616859979, 0.9423909174068014], 
             UndirectedEdge[131, 433] -> 
             RGBColor[
              0.29455765065289613`, 0.4253795454830047, 0.9401427329325757], 
             UndirectedEdge[87, 422] -> 
             RGBColor[
              0.2066326331143824, 0.33451437704181397`, 0.9350787948190529], 
             UndirectedEdge[210, 469] -> 
             RGBColor[
              0.8482471960053599, 0.3686686083126496, 0.19371011734270402`], 
             UndirectedEdge[312, 414] -> 
             RGBColor[
              0.2895347527456831, 0.421649761072285, 0.9397999478893602], 
             UndirectedEdge[277, 311] -> 
             RGBColor[
              0.7590792000371321, 0.8117177073753836, 0.9766215787274166], 
             UndirectedEdge[332, 424] -> 
             RGBColor[
              0.36139324266635137`, 0.48744239547023754`, 0.9442486357485711],
              UndirectedEdge[328, 433] -> 
             RGBColor[
              0.35540962848104596`, 0.48225968960811955`, 0.9438673651437858],
              UndirectedEdge[88, 428] -> 
             RGBColor[
              0.8484718113152332, 0.36067584148776255`, 0.1935446274280821], 
             UndirectedEdge[8, 162] -> 
             RGBColor[
              0.5411625228784538, 0.6383791410233868, 0.9570214426260819], 
             UndirectedEdge[27, 289] -> 
             RGBColor[
              0.47574498443284424`, 0.5848915439571711, 0.9519761681862727], 
             UndirectedEdge[192, 280] -> 
             RGBColor[
              0.25575350846358835`, 0.3861435314772083, 0.9378761560023672], 
             UndirectedEdge[347, 477] -> 
             RGBColor[
              0.2117993137193227, 0.3399448859440771, 0.9353730296360853], 
             UndirectedEdge[145, 346] -> 
             RGBColor[
              0.21927041175810352`, 0.3477974836778107, 0.9357984976168947], 
             UndirectedEdge[232, 415] -> 
             RGBColor[
              0.3216051563189196, 0.45097056152882875`, 0.9417869478037058], 
             UndirectedEdge[189, 374] -> 
             RGBColor[
              0.2557528431125027, 0.3861428321510315, 0.9378761181116072], 
             UndirectedEdge[139, 140] -> 
             RGBColor[
              0.5318346221124927, 0.6308063309644387, 0.9562871161085591], 
             UndirectedEdge[134, 251] -> 
             RGBColor[
              0.24587579480159133`, 0.37576142813523083`, 0.9373136348220843],
              UndirectedEdge[67, 281] -> 
             RGBColor[
              0.25076586641156884`, 0.38090120344576484`, 0.93759211716606], 
             UndirectedEdge[167, 495] -> 
             RGBColor[0.9144363630663, 0.657074043523211, 0.5293091727449846],
              UndirectedEdge[143, 179] -> 
             RGBColor[
              0.17892806920489446`, 0.30539512380213557`, 0.933501060889637], 
             UndirectedEdge[21, 175] -> 
             RGBColor[
              0.9683090151158134, 0.9568481859192783, 0.670037151361724], 
             UndirectedEdge[366, 473] -> 
             RGBColor[
              0.29591877827497415`, 0.42668767083692927`, 0.940224732684648], 
             UndirectedEdge[143, 292] -> 
             RGBColor[
              0.1789488167630598, 0.30541693080123855`, 0.9335022424323813], 
             UndirectedEdge[267, 486] -> 
             RGBColor[
              0.9619951023866931, 0.9628588250229391, 0.7028330719374227], 
             UndirectedEdge[248, 380] -> 
             RGBColor[
              0.257695358998007, 0.3881845395093172, 0.937986741517592], 
             UndirectedEdge[48, 407] -> 
             RGBColor[
              0.2109346093646478, 0.33903602684189116`, 0.935323786002302], 
             UndirectedEdge[436, 459] -> 
             RGBColor[
              0.4317329658175249, 0.5478348930853527, 0.9488776788806625], 
             UndirectedEdge[235, 262] -> 
             RGBColor[
              0.416563768888231, 0.5346101328045243, 0.9479348632655147], 
             UndirectedEdge[236, 283] -> 
             RGBColor[
              0.23426865806856206`, 0.3635615914938426, 0.9366526255563583], 
             UndirectedEdge[99, 493] -> 
             RGBColor[
              0.9935993972524345, 0.9887180828601909, 0.5447120747479771], 
             UndirectedEdge[109, 456] -> 
             RGBColor[
              0.23880926652767986`, 0.3683340588755796, 0.9369112064908769], 
             UndirectedEdge[208, 289] -> 
             RGBColor[
              0.3807447886449092, 0.5042037319598828, 0.9454816991464247], 
             UndirectedEdge[266, 410] -> 
             RGBColor[
              0.326592877843097, 0.45552256223454524`, 0.9420962704893343], 
             UndirectedEdge[299, 301] -> 
             RGBColor[
              0.20895952840977988`, 0.3369600915309596, 0.9352113080637927], 
             UndirectedEdge[314, 359] -> 
             RGBColor[
              0.3577633677707141, 0.48429838027845357`, 0.9440173433299934], 
             UndirectedEdge[209, 214] -> 
             RGBColor[
              0.3828653435329973, 0.49291080046599856`, 0.946830407391962], 
             UndirectedEdge[210, 326] -> 
             RGBColor[
              0.8556196126725499, 0.40214503052670025`, 0.19986184252427644`],
              UndirectedEdge[53, 317] -> 
             RGBColor[
              0.9299563150856899, 0.7479312815030192, 0.29383694306613123`], 
             UndirectedEdge[402, 459] -> 
             RGBColor[
              0.4714286755649022, 0.5800616585296188, 0.952002670562152], 
             UndirectedEdge[89, 249] -> 
             RGBColor[
              0.28752479280706156`, 0.41953716573797317`, 0.9396854836443249],
              UndirectedEdge[67, 135] -> 
             RGBColor[
              0.2536249197696536, 0.3839062497995648, 0.9377549360252124], 
             UndirectedEdge[90, 178] -> 
             RGBColor[
              0.9282272067510295, 0.7348311823756897, 0.4981717768803556], 
             UndirectedEdge[174, 229] -> 
             RGBColor[
              0.2788164534778155, 0.4103841489623319, 0.9391895566023578], 
             UndirectedEdge[266, 364] -> 
             RGBColor[
              0.2740437091478759, 0.405367692062097, 0.9389177558734103], 
             UndirectedEdge[407, 430] -> 
             RGBColor[
              0.22704868393744712`, 0.35597294090924125`, 0.9362414587105858],
              UndirectedEdge[217, 355] -> 
             RGBColor[
              0.32421328138501737`, 0.4552389817275355, 0.9418795614926734], 
             UndirectedEdge[176, 426] -> 
             RGBColor[
              0.7385594994235554, 0.7955507282121491, 0.9748396268265297], 
             UndirectedEdge[280, 483] -> 
             RGBColor[
              0.2767707745378052, 0.40823401069284493`, 0.939073058213035], 
             UndirectedEdge[51, 347] -> 
             RGBColor[
              0.1789270004053139, 0.3053940004260106, 0.9335010000230821], 
             UndirectedEdge[152, 451] -> 
             RGBColor[
              0.20772437674817806`, 0.3356618688214776, 0.9351409680039076], 
             UndirectedEdge[105, 342] -> 
             RGBColor[
              0.252946206923672, 0.38319287956555814`, 0.9377162843326995], 
             UndirectedEdge[318, 496] -> 
             RGBColor[
              0.3094159330482752, 0.43947691523709653`, 0.9410445311268166], 
             UndirectedEdge[114, 289] -> 
             RGBColor[
              0.47002476811242727`, 0.580247614655448, 0.9515258518036867], 
             UndirectedEdge[103, 331] -> 
             RGBColor[
              0.6585237003454188, 0.7308163449939742, 0.968260051050067], 
             UndirectedEdge[107, 113] -> 
             RGBColor[
              0.18193197659231264`, 0.3085524209250408, 0.9336721289714678], 
             UndirectedEdge[16, 56] -> 
             RGBColor[
              0.6202778449645745, 0.4035695471970573, 0.5648539909810746], 
             UndirectedEdge[140, 370] -> 
             RGBColor[
              0.5455387009707735, 0.6419319195433083, 0.9573659513959778], 
             UndirectedEdge[213, 500] -> 
             RGBColor[
              0.8618492799802115, 0.40436895006188167`, 0.20403944658147605`],
              UndirectedEdge[280, 327] -> 
             RGBColor[
              0.25698076875714937`, 0.3874334598585377, 0.9379460466605166], 
             UndirectedEdge[76, 238] -> 
             RGBColor[
              0.36573961104663694`, 0.49120700130641426`, 0.9445255824984202],
              UndirectedEdge[253, 261] -> 
             RGBColor[
              0.9325093316648222, 0.7680041432668934, 0.5596474808987255], 
             UndirectedEdge[232, 350] -> 
             RGBColor[
              0.3591838096222978, 0.48552869561681206`, 0.944107852628729], 
             UndirectedEdge[166, 320] -> 
             RGBColor[
              0.9133614547699682, 0.6417853106074096, 0.5113435478107814], 
             UndirectedEdge[33, 119] -> 
             RGBColor[
              0.9345308133147854, 0.7655949021985857, 0.5124594755699873], 
             UndirectedEdge[71, 228] -> 
             RGBColor[
              0.8744314209010298, 0.8983757407693698, 0.7323068273714743], 
             UndirectedEdge[50, 244] -> 
             RGBColor[
              0.3916895278498226, 0.5136835149605915, 0.9461790882505088], 
             UndirectedEdge[235, 344] -> 
             RGBColor[
              0.4103923521286693, 0.5295998986599555, 0.9474490267315575], 
             UndirectedEdge[72, 494] -> 
             RGBColor[
              0.25624399533436604`, 0.3866590642770594, 0.9379040885040477], 
             UndirectedEdge[185, 496] -> 
             RGBColor[
              0.2804171463023576, 0.4120665786107125, 0.9392807136907027], 
             UndirectedEdge[106, 370] -> 
             RGBColor[
              0.5546493379031965, 0.6493283450345659, 0.9580831741086608], 
             UndirectedEdge[51, 113] -> 
             RGBColor[
              0.17905963075308248`, 0.3055334033307651, 0.9335085531251784], 
             UndirectedEdge[422, 443] -> 
             RGBColor[
              0.5842619922483114, 0.5706803433206208, 0.6014015077150748], 
             UndirectedEdge[4, 335] -> 
             RGBColor[
              0.3005379095306292, 0.4317763657356928, 0.9404792286546308], 
             UndirectedEdge[1, 84] -> 
             RGBColor[
              0.249739891419232, 0.3798228386782472, 0.9375336894080404], 
             UndirectedEdge[90, 272] -> 
             RGBColor[
              0.8426763546129947, 0.3190239891395971, 0.18810823554711417`], 
             UndirectedEdge[213, 450] -> 
             RGBColor[
              0.8609571905590665, 0.3975119598548832, 0.20318518074431657`], 
             UndirectedEdge[5, 212] -> 
             RGBColor[
              0.22856179646777947`, 0.35756331811549596`, 0.9363276282307389],
              UndirectedEdge[50, 106] -> 
             RGBColor[
              0.47939668252268425`, 0.5878987040064534, 0.9522518873645769], 
             UndirectedEdge[115, 291] -> 
             RGBColor[
              0.7880477603543681, 0.8351660025398585, 0.9792918656511329], 
             UndirectedEdge[9, 117] -> 
             RGBColor[
              0.4781094761010015, 0.5852282777412916, 0.9525996605197433], 
             UndirectedEdge[194, 388] -> 
             RGBColor[
              0.9663440953419832, 0.9740339462184904, 0.9245637966956991], 
             UndirectedEdge[202, 211] -> 
             RGBColor[
              0.2350487330765592, 0.3643814997868598, 0.9366970496740461], 
             UndirectedEdge[113, 308] -> 
             RGBColor[
              0.17906927273157397`, 0.3055435376614964, 0.9335091022215896], 
             UndirectedEdge[51, 421] -> 
             RGBColor[
              0.17899180329589925`, 0.30546211237275633`, 0.9335046904518336],
              UndirectedEdge[109, 335] -> 
             RGBColor[
              0.2653660882581673, 0.3962469623140712, 0.938423578201131], 
             UndirectedEdge[278, 329] -> 
             RGBColor[
              0.9154608124727537, 0.9351010298249371, 0.9804756251775316], 
             UndirectedEdge[129, 206] -> 
             RGBColor[
              0.3491669657996257, 0.47685260895882275`, 0.9434695881978956], 
             UndirectedEdge[166, 227] -> 
             RGBColor[
              0.8418757895124331, 0.32288124504634075`, 0.18773360937003286`],
              UndirectedEdge[294, 411] -> 
             RGBColor[
              0.23895135352540886`, 0.3684834013190287, 0.9369192981351986], 
             UndirectedEdge[362, 384] -> 
             RGBColor[
              0.33614117025697976`, 0.4632658145057482, 0.9427239752429382], 
             UndirectedEdge[143, 308] -> 
             RGBColor[
              0.17893664305769685`, 0.3054041354650445, 0.9335015491578702], 
             UndirectedEdge[151, 310] -> 
             RGBColor[
              0.3017756973424442, 0.43451576996419494`, 0.9404970515752908], 
             UndirectedEdge[297, 397] -> 
             RGBColor[
              0.4389561312944613, 0.5528301617459719, 0.9496863711644075], 
             UndirectedEdge[114, 359] -> 
             RGBColor[
              0.443064873322788, 0.5568963088323743, 0.9498079911473898], 
             UndirectedEdge[141, 220] -> 
             RGBColor[
              0.32424804297229537`, 0.4552690904672675, 0.9418817764702763], 
             UndirectedEdge[122, 493] -> 
             RGBColor[
              0.9305407827762575, 0.7399602763410837, 0.37672867587283654`], 
             UndirectedEdge[146, 442] -> 
             RGBColor[
              0.2709392779878975, 0.40210473808065567`, 0.9387409631114438], 
             UndirectedEdge[294, 478] -> 
             RGBColor[
              0.25217734273393444`, 0.38238475455333876`, 0.9376724986545265],
              UndirectedEdge[76, 487] -> 
             RGBColor[
              0.49537833953651855`, 0.6000692782186605, 0.9537321847167134], 
             UndirectedEdge[67, 70] -> 
             RGBColor[
              0.25743661729140077`, 0.3879125855705024, 0.9379720065601748], 
             UndirectedEdge[346, 358] -> 
             RGBColor[
              0.2217544347167852, 0.3504083493035373, 0.935939959049609], 
             UndirectedEdge[149, 165] -> 
             RGBColor[
              0.3889540140770109, 0.511314150421502, 0.9460047837318252], 
             UndirectedEdge[175, 375] -> 
             RGBColor[
              0.9569658514087618, 0.9674257829593813, 0.9577297678481509], 
             UndirectedEdge[18, 428] -> 
             RGBColor[
              0.8573587081531882, 0.40102916444142644`, 0.2009600719874468], 
             UndirectedEdge[2, 47] -> 
             RGBColor[
              0.22219066917343752`, 0.3508668593763409, 0.9359648019565643], 
             UndirectedEdge[140, 466] -> 
             RGBColor[
              0.5015711187466989, 0.6062370555767975, 0.9539046622647382], 
             UndirectedEdge[199, 382] -> 
             RGBColor[
              0.31253428709090747`, 0.4426711481132517, 0.9412251688089472], 
             UndirectedEdge[305, 499] -> 
             RGBColor[
              0.2559152551896322, 0.3863135375416151, 0.9378853672391325], 
             UndirectedEdge[252, 282] -> 
             RGBColor[
              0.6717272001021579, 0.7429460920325152, 0.9682785844173988], 
             UndirectedEdge[235, 249] -> 
             RGBColor[
              0.32329479630323715`, 0.4526684377082041, 0.9418860278221313], 
             UndirectedEdge[130, 214] -> 
             RGBColor[
              0.1893670574265447, 0.316367162293171, 0.9340955458257609], 
             UndirectedEdge[100, 475] -> 
             RGBColor[
              0.8851091218155209, 0.5328997870260774, 0.22424752851506258`], 
             UndirectedEdge[10, 438] -> 
             RGBColor[
              0.22021348611856342`, 0.3487887146250221, 0.9358522043065695], 
             UndirectedEdge[39, 179] -> 
             RGBColor[
              0.40129536230508595`, 0.5053759222252174, 0.9485085964517164], 
             UndirectedEdge[400, 414] -> 
             RGBColor[
              0.28528989827003975`, 0.41718814987906533`, 0.9395582097066717],
              UndirectedEdge[41, 191] -> 
             RGBColor[
              0.22546402831064583`, 0.35430736737250323`, 0.9361512149169275],
              UndirectedEdge[25, 96] -> 
             RGBColor[
              0.3047685081778331, 0.4372333951604509, 0.9406831592217764], 
             UndirectedEdge[106, 274] -> 
             RGBColor[
              0.49029479958875166`, 0.5970824316919869, 0.9530169491141065], 
             UndirectedEdge[204, 363] -> 
             RGBColor[
              0.4533522044192463, 0.5657736996191047, 0.9504726028052438], 
             UndirectedEdge[99, 413] -> 
             RGBColor[
              0.9837287794830555, 0.9560851708017216, 0.4499899045367475], 
             UndirectedEdge[37, 118] -> 
             RGBColor[
              0.31537415178862416`, 0.44729581939211016`, 0.9413268540323092],
              UndirectedEdge[411, 478] -> 
             RGBColor[
              0.2528159536736963, 0.3830559751413007, 0.9377088666028057], 
             UndirectedEdge[300, 451] -> 
             RGBColor[
              0.21870173252116284`, 0.3471997657434399, 0.9357661121756364], 
             UndirectedEdge[122, 233] -> 
             RGBColor[
              0.8553320507775657, 0.4120002528594733, 0.20005892957140564`], 
             UndirectedEdge[97, 404] -> 
             RGBColor[
              0.2225914076005732, 0.3512880608715443, 0.9359876234171504], 
             UndirectedEdge[362, 498] -> 
             RGBColor[
              0.4251755260464191, 0.5424546669097134, 0.9483770922703834], 
             UndirectedEdge[121, 454] -> 
             RGBColor[
              0.8636741838299911, 0.42519607178708907`, 0.20605325186410173`],
              UndirectedEdge[173, 417] -> 
             RGBColor[
              0.8427978094114925, 0.8771278555657226, 0.9381656697874536], 
             UndirectedEdge[36, 352] -> 
             RGBColor[
              0.2411100918235177, 0.37075237214225454`, 0.9370422350877088], 
             UndirectedEdge[309, 337] -> 
             RGBColor[
              0.926620732552479, 0.9394372573300418, 0.7346744089406012], 
             UndirectedEdge[207, 456] -> 
             RGBColor[
              0.2203607616298221, 0.3489435105251617, 0.9358605914290611], 
             UndirectedEdge[95, 97] -> 
             RGBColor[
              0.22940871371662525`, 0.3584534818416879, 0.936375858915159], 
             UndirectedEdge[185, 350] -> 
             RGBColor[
              0.3230573711356193, 0.45194474529877393`, 0.9418898675264287], 
             UndirectedEdge[303, 435] -> 
             RGBColor[
              0.2816881021628791, 0.4134024338033765, 0.9393530927467486], 
             UndirectedEdge[14, 441] -> 
             RGBColor[
              0.3784375409652084, 0.5020200893703757, 0.9453414651985335], 
             UndirectedEdge[67, 147] -> 
             RGBColor[
              0.2540581203038455, 0.3843615710275007, 0.9377796061547718], 
             UndirectedEdge[115, 419] -> 
             RGBColor[
              0.7169294577871506, 0.7776214885576594, 0.9735615399917263], 
             UndirectedEdge[113, 209] -> 
             RGBColor[
              0.3725579164542212, 0.4820770410775821, 0.9462434146682975], 
             UndirectedEdge[100, 121] -> 
             RGBColor[
              0.8793403970281699, 0.48855884043917713`, 0.2187233911438525], 
             UndirectedEdge[39, 254] -> 
             RGBColor[
              0.43007991849913185`, 0.5356303158314321, 0.9501478343440324], 
             UndirectedEdge[2, 339] -> 
             RGBColor[
              0.21206918576719214`, 0.340228538577264, 0.9353883984499716], 
             UndirectedEdge[76, 436] -> 
             RGBColor[
              0.4421225577048329, 0.5568338353820671, 0.9495396944885663], 
             UndirectedEdge[121, 161] -> 
             RGBColor[
              0.9088989497892817, 0.5955852022276555, 0.2954383174204215], 
             UndirectedEdge[215, 430] -> 
             RGBColor[
              0.26193106415637823`, 0.3926365341899838, 0.9382279586601969], 
             UndirectedEdge[100, 254] -> 
             RGBColor[
              0.5838565510201338, 0.5654509378756822, 0.6001458285837606], 
             UndirectedEdge[186, 389] -> 
             RGBColor[
              0.22710509641847854`, 0.3560322340035631, 0.9362446713179258], 
             UndirectedEdge[197, 426] -> 
             RGBColor[
              0.7839000078483491, 0.8315135813435113, 0.9789878324723824], 
             UndirectedEdge[316, 378] -> 
             RGBColor[
              0.26678973270236006`, 0.397743302889189, 0.9385046526461347], 
             UndirectedEdge[185, 330] -> 
             RGBColor[
              0.29519715135054264`, 0.42760130102279975`, 0.9401224131131387],
              UndirectedEdge[56, 166] -> 
             RGBColor[
              0.8373970102117498, 0.28845538472768467`, 0.18344472525364075`],
              UndirectedEdge[38, 73] -> 
             RGBColor[
              0.25393957190424143`, 0.3842369691431141, 0.937772854998791], 
             UndirectedEdge[97, 430] -> 
             RGBColor[
              0.23573676666398502`, 0.3651046667110934, 0.9367362321689956], 
             UndirectedEdge[222, 372] -> 
             RGBColor[
              0.4565833875774816, 0.5694260572148426, 0.9504426196097452], 
             UndirectedEdge[137, 430] -> 
             RGBColor[
              0.22990978373834364`, 0.3589801382041882, 0.9364043941116291], 
             UndirectedEdge[30, 355] -> 
             RGBColor[
              0.29831901354920054`, 0.4290370635324922, 0.9403677718036725], 
             UndirectedEdge[111, 442] -> 
             RGBColor[
              0.2785182841132166, 0.41007075405510884`, 0.939172576298146], 
             UndirectedEdge[183, 408] -> 
             RGBColor[
              0.21373593745192992`, 0.3419804002760839, 0.9354833174926791], 
             UndirectedEdge[39, 283] -> 
             RGBColor[
              0.4024378733893724, 0.5065767738141891, 0.9485736607677728], 
             UndirectedEdge[244, 498] -> 
             RGBColor[
              0.40216527018839365`, 0.5225243398145787, 0.9469108991142803], 
             UndirectedEdge[259, 454] -> 
             RGBColor[
              0.8808615626968692, 0.5519020063430116, 0.22230030637499004`], 
             UndirectedEdge[17, 418] -> 
             RGBColor[
              0.9292223734187801, 0.9452976774305406, 0.9548682913375369], 
             UndirectedEdge[70, 391] -> 
             RGBColor[
              0.24968869542225258`, 0.3797690284394081, 0.93753077387175], 
             UndirectedEdge[18, 495] -> 
             RGBColor[
              0.8632931958328989, 0.4466442372567656, 0.2066429440915829], 
             UndirectedEdge[48, 95] -> 
             RGBColor[
              0.21729689825533816`, 0.34572319585842115`, 0.9356861089424638],
              UndirectedEdge[50, 92] -> 
             RGBColor[
              0.5250378077135244, 0.6249522255456361, 0.9558449239285502], 
             UndirectedEdge[118, 141] -> 
             RGBColor[
              0.31734549257895406`, 0.4492904482488255, 0.9414419520628983], 
             UndirectedEdge[373, 398] -> 
             RGBColor[
              0.27738327375901567`, 0.40887778620903076`, 0.9391079391375716],
              UndirectedEdge[218, 409] -> 
             RGBColor[
              0.2367642996218614, 0.3661846689991738, 0.9367947486508479]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.2206581667895666, 0.3492561022046294, 0.935877528212937], 316 -> 
             RGBColor[
              0.2504950392509415, 0.38061654692851177`, 0.937576693959915], 
             308 -> 
             RGBColor[
              0.17894628476761076`, 0.30541426951348377`, 0.9335020982389862],
              160 -> RGBColor[
              0.42248174875901884`, 0.5403541890501141, 0.948141141338351], 
             245 -> RGBColor[
              0.22156287013367681`, 0.3502070027807943, 0.9359290497299955], 
             155 -> RGBColor[
              0.5658891207695752, 0.6584533071119401, 0.9589680109885835], 
             425 -> RGBColor[
              0.37534284954540054`, 0.499524843821242, 0.9451374923637511], 
             213 -> RGBColor[
              0.90420589766789, 0.657903179238463, 0.24177939169682186`], 352 -> 
             RGBColor[
              0.2278308941861094, 0.35679509347557953`, 0.9362860044270709], 
             27 -> RGBColor[
              0.5121189165844965, 0.6148002330343991, 0.9547350235483862], 
             485 -> RGBColor[
              0.24800119075484597`, 0.3779953540399882, 0.9374346729773807], 
             454 -> RGBColor[
              0.8998824261938122, 0.6382713050470934, 0.23817178112086787`], 
             367 -> RGBColor[
              0.2298450608433424, 0.3589121103378734, 0.9364007082385077], 19 -> 
             RGBColor[
              0.5597245266210166, 0.6534486118703385, 0.9584827115555565], 
             164 -> RGBColor[
              0.8175247092939038, 0.13570817177533162`, 0.16441498745215766`],
              190 -> RGBColor[
              0.24810961844878143`, 0.3781093184210272, 0.9374408477741458], 
             103 -> RGBColor[
              0.4803557055985901, 0.589013427439692, 0.9522345072271], 138 -> 
             RGBColor[
              0.2199663924455993, 0.34852900350809307`, 0.9358381326874365], 
             416 -> RGBColor[
              0.26153368469451344`, 0.39221886318025073`, 0.938205328487714], 
             476 -> RGBColor[
              0.8484924274103163, 0.3737396233586853, 0.19406970929346942`], 
             291 -> RGBColor[
              0.6549271406176395, 0.7303533269719065, 0.9662406748008145], 28 -> 
             RGBColor[
              0.9648560740830788, 0.9733102981108331, 0.9443736789601879], 
             337 -> RGBColor[
              0.860210700141258, 0.8913726787679522, 0.9865288585702724], 195 -> 
             RGBColor[
              0.2701519252165497, 0.40127718039692006`, 0.9386961245358997], 
             114 -> RGBColor[
              0.5006784839436625, 0.605512374430953, 0.9538343907832142], 479 -> 
             RGBColor[
              0.41149067372934756`, 0.5308342722869064, 0.9474407997564864], 
             93 -> 
             RGBColor[
              0.26928527939714464`, 0.4003662806922068, 0.9386467703385721], 
             34 -> RGBColor[
              0.5437530683305409, 0.6404822625241338, 0.9572253798535508], 
             161 -> RGBColor[
              0.9903319581123935, 0.9790495659282263, 0.41694191223350735`], 
             22 -> RGBColor[
              0.4514165271362265, 0.5654160397762044, 0.9499848398305268], 
             124 -> RGBColor[
              0.9626525497894284, 0.8856804222207267, 0.30941263771645156`], 
             84 -> RGBColor[
              0.2333142933423989, 0.36255849365642656`, 0.9365982758970595], 
             46 -> RGBColor[
              0.9176548470302313, 0.7112359389100995, 0.2526013609126037], 
             241 -> RGBColor[
              0.7054821402904016, 0.7698472769484965, 0.9712795247048629], 
             185 -> RGBColor[
              0.2839447494602888, 0.41577431319265656`, 0.9394816054719256], 
             426 -> RGBColor[
              0.8701743928884773, 0.8993174569073501, 0.9874792044791957], 
             390 -> RGBColor[
              0.30075346730669683`, 0.43344134138349677`, 0.9404388370870089],
              121 -> RGBColor[
              0.8274659414661699, 0.21212083852708477`, 0.1739347226073356], 
             322 -> RGBColor[
              0.25921854913182885`, 0.38978550891579644`, 0.9380734849423552],
              488 -> RGBColor[
              0.7693643004981994, 0.8197525060252281, 0.9776467014216474], 
             126 -> RGBColor[
              0.2511378152607278, 0.38129214526915, 0.9376132991027705], 433 -> 
             RGBColor[
              0.32550625142704326`, 0.4563588873913744, 0.9419619484004228], 
             236 -> RGBColor[
              0.28732315690654525`, 0.419325233622076, 0.939674000778084], 78 -> 
             RGBColor[
              0.21942909899518986`, 0.3479642740253404, 0.9358075346202901], 
             376 -> RGBColor[
              0.2794551004482275, 0.4110554074207916, 0.9392259266025292], 
             458 -> RGBColor[
              0.2304992557221517, 0.359599710633853, 0.9364379636690613], 254 -> 
             RGBColor[
              0.23649824945009773`, 0.365905033400095, 0.9367795974871519], 
             290 -> RGBColor[
              0.2864852402250885, 0.41844453006287885`, 0.9396262826626617], 
             251 -> RGBColor[
              0.25854520282865096`, 0.38907777925853504`, 0.9380351388665158],
              165 -> RGBColor[
              0.4240332554553848, 0.5416980261695123, 0.9482400019731], 460 -> 
             RGBColor[
              0.24834625332605567`, 0.3783580366805602, 0.9374543237803367], 
             100 -> RGBColor[
              0.9312148525901699, 0.7649968423512695, 0.2635120596803694], 
             235 -> RGBColor[
              0.3570417238501652, 0.48367332858535217`, 0.9439713608175008], 
             70 -> RGBColor[
              0.2582501634540876, 0.38876767416929214`, 0.9380183368106061], 
             234 -> RGBColor[
              0.38857864336543946`, 0.5109890231778194, 0.9459808654420111], 
             435 -> RGBColor[
              0.25811768357221787`, 0.3886284294137375, 0.93801079227732], 
             257 -> RGBColor[
              0.8588534332133313, 0.4519682304874997, 0.20393618366530758`], 
             135 -> RGBColor[
              0.25062676841059334`, 0.3807550026274169, 0.9375841957406814], 
             265 -> RGBColor[
              0.32101450543653715`, 0.45246836277611585`, 0.9416757383178027],
              111 -> RGBColor[
              0.27309124258507717`, 0.4043665893147275, 0.9388635143117069], 
             497 -> RGBColor[
              0.23599364281048124`, 0.36537465982794926`, 0.9367508608855244],
              481 -> RGBColor[
              0.318216697210702, 0.4500450419128276, 0.9414974644516573], 381 -> 
             RGBColor[
              0.5693048020656428, 0.6612263110627765, 0.9592369059322629], 
             182 -> RGBColor[
              0.3785866605047563, 0.5023344698355566, 0.9453441851296919], 
             188 -> RGBColor[
              0.33727714516499796`, 0.4665542439248693, 0.9427119793408126], 
             154 -> RGBColor[
              0.30954120355039927`, 0.44253076534726327`, 0.9409446696670606],
              336 -> RGBColor[
              0.22223854670063217`, 0.35091718169303304`, 0.9359675285109096],
              463 -> RGBColor[
              0.2670973610782935, 0.3980666398170606, 0.9385221716270487], 
             315 -> RGBColor[
              0.1854996162687526, 0.3123022364263995, 0.933875300773191], 368 -> 
             RGBColor[
              0.4081016499818632, 0.5278988702541217, 0.9472248541600927], 
             269 -> RGBColor[
              0.44893934079834463`, 0.5632704254773366, 0.9498269957075668], 
             208 -> RGBColor[
              0.32211852500862637`, 0.45342460903982235`, 0.9417460854686901],
              86 -> RGBColor[
              0.9151930916309041, 0.7014758990831244, 0.2506205747334791], 
             119 -> RGBColor[
              0.9906473743776302, 0.9904004632007044, 0.8046607405893015], 
             436 -> 
             RGBColor[
              0.472919813782261, 0.5829766354800872, 0.9516491265847494], 377 -> 
             RGBColor[
              0.9811051107342013, 0.9854288030398846, 0.9168682983373343], 
             140 -> RGBColor[
              0.4996340643500339, 0.6046644675542787, 0.9537521702469687], 85 -> 
             RGBColor[
              0.21421555473578224`, 0.34248450845090483`, 0.9355106309874645],
              351 -> RGBColor[
              0.290045450304657, 0.422186536586862, 0.9398290313598343], 443 -> 
             RGBColor[
              0.9345119801701037, 0.7780688545030732, 0.2661650059247154], 
             242 -> RGBColor[
              0.22500762673968802`, 0.3538276603838957, 0.936125223522647], 
             117 -> RGBColor[
              0.38107527345035186`, 0.504489981287708, 0.9455027573459912], 
             47 -> RGBColor[
              0.23193365260590854`, 0.36110735270469657`, 0.9365196504495912],
              451 -> RGBColor[
              0.21144581794704176`, 0.3395733394744833, 0.935352898574804], 
             81 -> RGBColor[
              0.8236181467643259, 0.8621947699835874, 0.9830386281626226], 
             275 -> RGBColor[
              0.4137039619056965, 0.5327513112621616, 0.9475818285219495], 23 -> 
             RGBColor[
              0.2225015077722568, 0.35119357045200544`, 0.9359825037549226], 
             328 -> RGBColor[
              0.3853130055350487, 0.5081604918248647, 0.9457727818871488], 
             418 -> RGBColor[
              0.978473490691829, 0.9834661451211657, 0.9213229446326382], 110 -> 
             RGBColor[
              0.27171530098953856`, 0.4029203874580805, 0.9387851564733641], 
             6 -> RGBColor[
              0.8276898195746623, 0.8654414113599355, 0.9834269879500976], 
             218 -> RGBColor[
              0.23197293745711564`, 0.3611486435741187, 0.9365218876637508], 
             108 -> RGBColor[
              0.28511069510105125`, 0.41699979598632125`, 0.939548004351305], 
             297 -> RGBColor[
              0.5193642093092683, 0.6206822880650865, 0.955305399532062], 487 -> 
             RGBColor[
              0.5794313774456323, 0.6694475211532741, 0.9600341070410434], 
             464 -> RGBColor[
              0.24386676324271586`, 0.3736498085868948, 0.9371992234469022], 
             157 -> RGBColor[
              0.3025436094347634, 0.43532289426166115`, 0.9405407830329243], 
             441 -> RGBColor[
              0.4501324018566838, 0.5643037950010776, 0.9499030165032217], 
             354 -> 
             RGBColor[
              0.3617638436367253, 0.48776339140382907`, 0.9442722501146938], 
             385 -> RGBColor[
              0.2334715870925415, 0.36272381936082626`, 0.9366072335434348], 
             270 -> RGBColor[
              0.9900230881246451, 0.9901423047916702, 0.8150067794022959], 
             392 -> RGBColor[
              0.3060013924465708, 0.4389572434431762, 0.9407376986601153], 33 -> 
             RGBColor[
              0.8784142522519405, 0.5407893411964669, 0.22025821055067316`], 
             252 -> RGBColor[
              0.7357960105795031, 0.7935287028122899, 0.9743009279960564], 
             394 -> RGBColor[
              0.22864247952174482`, 0.3576481211208147, 0.9363322230113024], 
             260 -> RGBColor[
              0.28557642935408295`, 0.4174893122155148, 0.9395745272280231], 
             159 -> RGBColor[
              0.8207501650068003, 0.16050043778835987`, 0.16750368748545852`],
              183 -> RGBColor[
              0.2049673414252272, 0.33276404989092045`, 0.9349839589209338], 
             99 -> RGBColor[
              0.9936215336094609, 0.9887654302895413, 0.5471214806005384], 
             329 -> RGBColor[
              0.8825578842047201, 0.909191716742005, 0.9886603529358121], 309 -> 
             RGBColor[
              0.9930307649637, 0.9875018358921313, 0.48281995931092997`], 17 -> 
             RGBColor[
              0.8799712561457314, 0.9071292097399156, 0.9884136380424356], 
             349 -> RGBColor[
              0.41360147005439724`, 0.5326625379719564, 0.9475752978318146], 
             495 -> RGBColor[
              0.8422024713778844, 0.3253922650171049, 0.18804644029332332`], 
             347 -> RGBColor[0.178927, 0.305394, 0.933501], 340 -> 
             RGBColor[
              0.3374345618861965, 0.46669059037677707`, 0.9427220097950892], 
             404 -> RGBColor[
              0.2134483076486736, 0.3416780831160786, 0.9354669374008939], 
             277 -> RGBColor[
              0.7713015318020453, 0.8212658858432957, 0.977839786533559], 104 -> 
             RGBColor[
              0.24657366739272524`, 0.3764949364761905, 0.9373533776337394], 
             79 -> RGBColor[
              0.9938287149952354, 0.9892085703244617, 0.5696718958667929], 
             327 -> RGBColor[
              0.2570691600545971, 0.38752636471648727`, 0.9379510804141431], 
             191 -> RGBColor[
              0.21840138119578575`, 0.34688407745709465`, 0.9357490076119863],
              50 -> RGBColor[
              0.44093802683048844`, 0.5563400894761129, 0.9493171590568191], 
             225 -> RGBColor[
              0.27424929290791517`, 0.4055837736286615, 0.9389294635644105], 
             405 -> RGBColor[
              0.9940126833910108, 0.9896020601209673, 0.5896957204256101], 61 -> 
             RGBColor[
              0.3238266917401457, 0.45490413720770817`, 0.94185492834235], 
             196 -> RGBColor[
              0.29569933477919436`, 0.42812912764658106`, 0.9401510117164867],
              1 -> RGBColor[
              0.2661654894960651, 0.39708718370006774`, 0.9384691029190212], 
             263 -> RGBColor[
              0.2734006518561467, 0.40469179807630246`, 0.9388811347119643], 
             201 -> RGBColor[
              0.3044587746178886, 0.4373358542976118, 0.9406498488568703], 
             371 -> RGBColor[
              0.36294391873403165`, 0.48878551314081686`, 0.9443474434563948],
              293 -> RGBColor[
              0.9542723127115095, 0.9654169462092355, 0.962289226275195], 362 -> 
             RGBColor[
              0.38846154058520777`, 0.5108875946353395, 0.9459734037564047], 
             184 -> RGBColor[
              0.2570318728012019, 0.3874871734490205, 0.9379489569602237], 
             106 -> RGBColor[
              0.5178553382148801, 0.619457318536794, 0.9551866156723348], 206 -> 
             RGBColor[
              0.3427341577200499, 0.4712808339226293, 0.9430596953553738], 
             358 -> RGBColor[
              0.22562621270692998`, 0.3544778334560826, 0.9361604510783655], 
             247 -> RGBColor[
              0.4950113815248125, 0.6009115653872759, 0.9533882557215221], 
             220 -> RGBColor[
              0.3389132056188999, 0.46797131725924984`, 0.9428162276662237], 
             407 -> RGBColor[
              0.21435834209939697`, 0.3426345870233057, 0.9355187625165873], 
             107 -> RGBColor[
              0.18467169248908813`, 0.3114320360405726, 0.9338281517387427], 
             375 -> RGBColor[
              0.9582014383733062, 0.9683472816944506, 0.9556382414098691], 
             131 -> RGBColor[
              0.263609049878749, 0.394400203574635, 0.9383235174647285], 411 -> 
             RGBColor[
              0.23958996446517072`, 0.3691546219069906, 0.9369556660834778], 
             462 -> RGBColor[
              0.46387836533310084`, 0.575636380316448, 0.9509373506429145], 
             127 -> RGBColor[
              0.22597981130456574`, 0.35484948800164373`, 0.9361805879953986],
              210 -> 
             RGBColor[
              0.8360637140310553, 0.2782070860287545, 0.182167959325265], 357 -> 
             RGBColor[
              0.9071422836282599, 0.6695571281253704, 0.2441427056377997], 
             181 -> RGBColor[
              0.4206971967779904, 0.5388084998183378, 0.9480274312641372], 
             194 -> RGBColor[
              0.9865160895376739, 0.9886920707502049, 0.8731268218098209], 
             440 -> RGBColor[
              0.28167383897512416`, 0.41338744228870766`, 0.9393522804793065],
              490 -> RGBColor[
              0.9905535588776926, 0.9903616680805318, 0.806215506209998], 118 -> 
             RGBColor[
              0.32510810483221725`, 0.45601403282236586`, 0.9419365788514676],
              348 -> RGBColor[
              0.9599116097125079, 0.876434587737939, 0.29876460310071706`], 
             276 -> RGBColor[
              0.6195401563438858, 0.7020096347427746, 0.9631916170392121], 
             305 -> RGBColor[
              0.2511118726659751, 0.3812648779572094, 0.9376118217103779], 
             343 -> RGBColor[
              0.29288750827080284`, 0.425173719706164, 0.9399908823565584], 
             280 -> RGBColor[
              0.25689237745970156`, 0.38734055500058817`, 0.9379410129068901],
              474 -> RGBColor[
              0.9930971542734537, 0.9914135101440991, 0.7640615478883636], 
             189 -> RGBColor[
              0.2597753641562747, 0.39037075681060074`, 0.9381051947342635], 
             168 -> RGBColor[
              0.9107922199972238, 0.6840279095591187, 0.24707953011528597`], 
             363 -> RGBColor[
              0.40481135748628755`, 0.5250489842693634, 0.9470151996317661], 
             41 -> RGBColor[
              0.23252667542550592`, 0.36173065728791187`, 0.9365534222218687],
              14 -> RGBColor[
              0.30674268007373295`, 0.4397363837396738, 0.9407799138938453], 
             77 -> RGBColor[
              0.606817875551374, 0.6916811140631951, 0.9621900724919755], 51 -> 
             RGBColor[
              0.17892700081062782`, 0.30539400085202123`, 0.9335010000461641],
              438 -> RGBColor[
              0.22146455698209894`, 0.3501036694250721, 0.9359234509414543], 
             179 -> RGBColor[
              0.178929137062006, 0.30539624618766587`, 0.9335011217025198], 
             467 -> RGBColor[
              0.7068391686146014, 0.7709073977891587, 0.9714147806060683], 
             223 -> RGBColor[
              0.38986378476733635`, 0.5121021480670574, 0.9460627535157341], 
             456 -> 
             RGBColor[
              0.22365852866224617`, 0.35240967276674573`, 0.9360483943829485],
              323 -> RGBColor[
              0.23934466612723454`, 0.36889679780100676`, 0.9369416967060188],
              500 -> RGBColor[
              0.8194926622925333, 0.15083472088530037`, 0.16629950146613023`],
              478 -> RGBColor[
              0.2660419428822219, 0.39695732837561076`, 0.9384620671221336], 
             292 -> RGBColor[
              0.1789706321783367, 0.30543986018587177`, 0.9335034847880083], 
             491 -> RGBColor[
              0.9941614319695004, 0.9899202182895682, 0.6058860852243823], 
             396 -> RGBColor[
              0.9935460613341791, 0.9886040027241311, 0.5389067891970045], 
             321 -> RGBColor[
              0.3331754530775283, 0.46300156439574175`, 0.942450623147983], 
             143 -> RGBColor[
              0.17892700134778292`, 0.3053940014166053, 0.9335010000767543], 
             112 -> RGBColor[
              0.24826352560257345`, 0.3782710845979398, 0.937449612558869], 
             197 -> RGBColor[
              0.6976256228082208, 0.7637097057796726, 0.9704964604655693], 
             421 -> RGBColor[
              0.17905660578117066`, 0.3055302238934915, 0.9335083808575031], 
             54 -> RGBColor[
              0.22872079714307936`, 0.35773043790646125`, 0.9363366830839769],
              71 -> RGBColor[
              0.755781538403036, 0.8091415490436711, 0.97629289863413], 177 -> 
             RGBColor[
              0.20869655844004803`, 0.3366836934195124, 0.9351963323130457], 
             158 -> RGBColor[
              0.3575213303529286, 0.48408873963232213`, 0.9440019209197574], 
             226 -> RGBColor[
              0.1794249922972142, 0.30591742147890744`, 0.9335293599246128], 
             432 -> RGBColor[
              0.898624468927386, 0.9220027752840345, 0.9901927981294695], 350 -> 
             RGBColor[
              0.3621699928109498, 0.4881151774048913, 0.9442981295809318], 
             203 -> RGBColor[
              0.5345666356633387, 0.6330243026408235, 0.956502190222977], 475 -> 
             RGBColor[
              0.839003391040872, 0.30080273170088523`, 0.1849829973497558], 
             115 -> RGBColor[
              0.9211683800910966, 0.9399786781078106, 0.9923430565014513], 
             173 -> RGBColor[
              0.984562956112485, 0.9878843998856498, 0.9054952972124768], 212 -> 
             RGBColor[
              0.21851625165510197`, 0.3470048135930438, 0.9357555493147087], 
             129 -> 
             RGBColor[
              0.35559977387920144`, 0.4824243839950162, 0.9438794810404173], 
             279 -> RGBColor[
              0.2785602236563872, 0.4101148351741018, 0.9391749646930856], 26 -> 
             RGBColor[
              0.3866295369467384, 0.5093008051628776, 0.9458566701045386], 40 -> 
             RGBColor[
              0.3862001571816754, 0.5089288979916344, 0.9458293104055944], 
             146 -> RGBColor[
              0.257933230334439, 0.3884345573658211, 0.9380002879383026], 386 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 192 -> 
             RGBColor[
              0.2546146394674752, 0.38494650795382845`, 0.9378112990978443], 
             300 -> RGBColor[
              0.22595764709528393`, 0.3548261920123965, 0.936179325776469], 
             221 -> RGBColor[
              0.5366100807415061, 0.6346832634114314, 0.9566630577049163], 62 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 286 -> 
             RGBColor[
              0.22310026486080187`, 0.3518229021154584, 0.9360166020853335], 
             472 -> RGBColor[
              0.32844671668737896`, 0.45890577060779597`, 0.9421493122466601],
              152 -> RGBColor[
              0.20400293554931437`, 0.33175039816847185`, 0.9349290374330113],
              64 -> RGBColor[
              0.2878344487965492, 0.41986263381624833`, 0.9397031180948312], 
             307 -> RGBColor[
              0.46980956787155936`, 0.580451597734798, 0.9514042766334527], 
             37 -> RGBColor[
              0.305640198745031, 0.4385776059618545, 0.9407171292131508], 148 -> 
             RGBColor[
              0.23965584235908116`, 0.3692238637503902, 0.9369594177320785], 
             261 -> RGBColor[
              0.8799868165294279, 0.5479299882988189, 0.2215703967308864], 
             387 -> RGBColor[
              0.7751138064478154, 0.8242440637709316, 0.9782197584425172], 15 -> 
             RGBColor[
              0.23423879357827926`, 0.36353020202103736`, 0.9366509248178173],
              136 -> RGBColor[
              0.968960662006962, 0.9763714930638193, 0.9374256822530368], 198 -> 
             RGBColor[
              0.2818794421164257, 0.41360354422620765`, 0.9393639892740411], 
             63 -> RGBColor[
              0.41933559472005666`, 0.5376291485518648, 0.9479406711850231], 
             444 -> RGBColor[
              0.27129304719779485`, 0.4024765719505212, 0.9387611097445928], 
             310 -> RGBColor[
              0.29675707084929953`, 0.4292408753206019, 0.9402112482208989], 
             171 -> 
             RGBColor[
              0.26174222518751433`, 0.39243805246062563`, 0.9382172045602823],
              395 -> RGBColor[
              0.26498757281889074`, 0.39584911858812655`, 0.9384020223068277],
              311 -> RGBColor[
              0.746856868272219, 0.8021695289074716, 0.9754033709212744], 353 -> 
             RGBColor[
              0.6396625402707171, 0.7183458925176417, 0.9647757248126534], 59 -> 
             RGBColor[
              0.2421911048281961, 0.37188858535035474`, 0.9371037971791099], 
             397 -> RGBColor[
              0.3585480532796543, 0.48497803542685713`, 0.944067342796753], 
             229 -> RGBColor[
              0.2909757990296596, 0.42316439208435586`, 0.9398820133433956], 
             102 -> RGBColor[
              0.2765375568294345, 0.40798888409449063`, 0.939059776809558], 
             453 -> RGBColor[
              0.2843068325272902, 0.41615488545346746`, 0.9395022255669375], 
             299 -> RGBColor[
              0.2091663766185125, 0.3371775021132715, 0.9352230877632756], 
             128 -> RGBColor[
              0.49474321248409076`, 0.6006938536791404, 0.9533671444723009], 
             12 -> RGBColor[
              0.27240341106773047`, 0.40364363477895904`, 0.9388243433243495],
              222 -> RGBColor[
              0.4427137030371586, 0.5578780909582495, 0.9494303035745394], 
             483 -> RGBColor[
              0.29664917161590876`, 0.42912746638510174`, 0.9402051035191799],
              92 -> RGBColor[
              0.6091375885965603, 0.6935643616151592, 0.9623726888002815], 
             271 -> RGBColor[
              0.2558053195227897, 0.38619798818543977`, 0.9378791065655412], 
             361 -> RGBColor[
              0.6442014475594858, 0.7219743340365904, 0.9651716379540781], 
             344 -> RGBColor[
              0.4637429804071734, 0.5755264687345587, 0.9509266926456142], 
             132 -> RGBColor[
              0.9901329118562932, 0.9901877197270478, 0.8131867159541827], 80 -> 
             RGBColor[
              0.7895429134572223, 0.8355161918319554, 0.9796579169815435], 
             324 -> RGBColor[
              0.369677449943029, 0.49461775943693126`, 0.9447764981108042], 
             244 -> RGBColor[
              0.3424410288691568, 0.4710269404450701, 0.9430410174441985], 
             150 -> RGBColor[
              0.8214446559981496, 0.16583859987576455`, 0.16816873284309014`],
              125 -> RGBColor[
              0.20867358600249122`, 0.3366595479311035, 0.9351950240667115], 
             258 -> 
             RGBColor[
              0.3734224424883788, 0.497861483750915, 0.945015125724227], 133 -> 
             RGBColor[
              0.3451736656290086, 0.4733938130601367, 0.9432151386421606], 
             469 -> RGBColor[
              0.8604306779796645, 0.4591301305965446, 0.20525227536014304`], 
             255 -> RGBColor[
              0.3975855258515599, 0.5187903320882202, 0.9465547760295533], 
             408 -> RGBColor[
              0.2225045334786326, 0.3511967506612473, 0.9359826760644245], 
             326 -> RGBColor[
              0.8751755113140446, 0.526082975024646, 0.21755572572328788`], 
             176 -> RGBColor[
              0.6069446059586334, 0.6917839995169481, 0.9622000491738637], 
             230 -> RGBColor[
              0.2238780227461086, 0.35264037496561385`, 0.936060894246312], 
             274 -> RGBColor[
              0.4627342609626232, 0.5747075448471798, 0.9508472825558781], 87 -> 
             RGBColor[
              0.1792532619022457, 0.3057369219454596, 0.9335195801326717], 
             439 -> RGBColor[
              0.8609124841587944, 0.891932262294116, 0.986595795356355], 130 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 35 -> 
             RGBColor[
              0.23837242809378653`, 0.36787491398440125`, 0.9368863291883112],
              379 -> RGBColor[
              0.3092991992760449, 0.442321153408306, 0.9409292493686947], 31 -> 
             RGBColor[
              0.4530382628066378, 0.5668207057031098, 0.9500881753934008], 18 -> 
             RGBColor[
              0.8843839202879132, 0.5678962094964264, 0.22523944788984251`], 
             24 -> RGBColor[
              0.8369720141620951, 0.8728427813654944, 0.9843123319561599], 
             151 -> RGBColor[
              0.30679432383558886`, 0.439790664607788, 0.9407828549296829], 
             137 -> RGBColor[
              0.22008054170119, 0.3486489816131997, 0.9358446333186737], 330 -> 
             RGBColor[
              0.3064495532407965, 0.43942828885294294`, 0.9407632207543519], 
             296 -> RGBColor[
              0.3134198204339392, 0.44589022834683273`, 0.9411918117051534], 
             266 -> RGBColor[
              0.28952074326414307`, 0.421635036218934, 0.9397991500701115], 
             302 -> RGBColor[
              0.19014935834156865`, 0.31718941015560403`, 0.934140096705561], 
             442 -> RGBColor[
              0.28394532564135605`, 0.4157749187954902, 0.9394816382845851], 
             283 -> RGBColor[
              0.18121415923057888`, 0.3077979493656092, 0.9336312503346327], 
             388 -> 
             RGBColor[
              0.9461721011462925, 0.9593758216867757, 0.9760007715815773], 
             284 -> RGBColor[
              0.24509263407936946`, 0.37493827656091794`, 0.9372690349775362],
              417 -> RGBColor[
              0.7010326627105, 0.7663713112457954, 0.9708360423624304], 318 -> 
             RGBColor[
              0.341942322952124, 0.4705949864454246, 0.9430092403441536], 413 -> 
             RGBColor[
              0.97383602535665, 0.9234049113139019, 0.35285832847295656`], 
             238 -> RGBColor[
              0.32015392046586916`, 0.45172296732878153`, 0.9416209026044572],
              72 -> RGBColor[
              0.2539844574642687, 0.3842841467126117, 0.9377754111650324], 
             437 -> RGBColor[
              0.2558304623203871, 0.3862244148598601, 0.9378805384106689], 
             288 -> RGBColor[
              0.2560659100008252, 0.3864718853002457, 0.9378939468077562], 
             382 -> RGBColor[
              0.28222469603460637`, 0.4139664279845783, 0.9393836509739241], 
             461 -> RGBColor[
              0.944455505750549, 0.9580955876512972, 0.9789065198267879], 389 -> 
             RGBColor[
              0.2184997826909155, 0.34698750366749115`, 0.9357546114315619], 
             172 -> RGBColor[
              0.3516524550010693, 0.4790054147807936, 0.9436279613719797], 
             447 -> RGBColor[
              0.2464999471451923, 0.3764174518218997, 0.9373491793747017], 
             243 -> RGBColor[
              0.8393061093521738, 0.30312955729356095`, 0.18527288074652987`],
              410 -> RGBColor[
              0.36366501242205085`, 0.4894100882501565, 0.9443933909085572], 
             88 -> RGBColor[
              0.8666101266120032, 0.4871895635890985, 0.21040855877111306`], 
             273 -> RGBColor[
              0.2935414156904733, 0.42586101786436276`, 0.9400281214167392], 
             477 -> RGBColor[
              0.24467162743864543`, 0.3744957718881542, 0.9372450592721705], 
             202 -> RGBColor[
              0.23905706042934927`, 0.3685945059772749, 0.9369253179869986], 
             393 -> RGBColor[
              0.4612114846587171, 0.5734712864433781, 0.9507274040271213], 98 -> 
             RGBColor[
              0.9952347378240085, 0.9922159109844932, 0.7227088038116687], 30 -> 
             RGBColor[
              0.2679312243382506, 0.39894308297325987`, 0.938569658906113], 
             116 -> RGBColor[
              0.24872594858728536`, 0.3787571204741826, 0.9374759468637549], 
             373 -> 
             RGBColor[
              0.293615491872952, 0.425938876628849, 0.9400323399457455], 434 -> 
             RGBColor[
              0.9912025783926344, 0.990630054329001, 0.7954595732387495], 401 -> 
             RGBColor[
              0.7734523776791622, 0.8229461429895335, 0.9780541627497925], 
             240 -> RGBColor[
              0.2566255537350775, 0.38706010634840704`, 0.9379258176905032], 
             480 -> RGBColor[
              0.35354723518652786`, 0.48064657814301665`, 0.9437486950899088],
              403 -> RGBColor[
              0.9289119756027943, 0.9461532109745376, 0.9930816475541463], 
             317 -> RGBColor[
              0.8834003236622562, 0.5634299269441462, 0.22441871075523476`], 
             429 -> RGBColor[
              0.29359796730781346`, 0.4259204571997668, 0.9400313419476861], 
             391 -> RGBColor[
              0.2411272273904176, 0.370770382709524, 0.937043210932894], 73 -> 
             RGBColor[
              0.24791046842011605`, 0.37789999911405875`, 0.9374295064746294],
              303 -> RGBColor[
              0.3052585207535403, 0.43817643819301544`, 0.9406953932161773], 
             449 -> RGBColor[
              0.7283027762348872, 0.7876749311915857, 0.9735540724248413], 29 -> 
             RGBColor[
              0.40962031041891445`, 0.5292142575946026, 0.9473216218602429], 
             360 -> RGBColor[
              0.5793663225363243, 0.6693947066472076, 0.9600289856802787], 
             320 -> RGBColor[
              0.9886024976405045, 0.9895548541189678, 0.8385496400948322], 
             482 -> RGBColor[
              0.35848143845973107`, 0.48492033701799786`, 0.9440630981593326],
              75 -> RGBColor[
              0.3449485107481652, 0.47319879521896346`, 0.9432007919722498], 
             200 -> RGBColor[
              0.9008280073528754, 0.6425649682443086, 0.23896079721830538`], 
             301 -> RGBColor[
              0.20875268020104726`, 0.3367426809486477, 0.9351995283643099], 
             156 -> RGBColor[
              0.46730916543215706`, 0.578421658392645, 0.9512074357941471], 
             25 -> RGBColor[
              0.3133752819583538, 0.4458516513578495, 0.941188973752873], 38 -> 
             RGBColor[
              0.25996867538836677`, 0.3905739391721695, 0.9381162035229527], 
             365 -> RGBColor[
              0.2169746648251472, 0.34538450809251103`, 0.9356677582253161], 
             380 -> RGBColor[
              0.27285106149406285`, 0.4041141437597107, 0.9388498363538897], 
             370 -> 
             RGBColor[
              0.591443337591513, 0.6791993715323379, 0.960979732544987], 3 -> 
             RGBColor[
              0.46166603367100856`, 0.5738403098087559, 0.9507631877904368], 
             57 -> RGBColor[
              0.6012429877716181, 0.6871551690177569, 0.9617511969044663], 
             227 -> RGBColor[
              0.8456311671254343, 0.35174672299683013`, 0.19132976321333509`],
              494 -> RGBColor[
              0.2585035332044634, 0.3890339818415072, 0.938032765843063], 39 -> 
             RGBColor[
              0.6236615875481659, 0.7053555982627691, 0.963516071200913], 424 -> 
             RGBColor[
              0.3205944320155112, 0.4521045162923272, 0.9416489716108714], 
             109 -> RGBColor[
              0.25396000439311356`, 0.38425844498441336`, 0.9377740185988052],
              465 -> RGBColor[
              0.28262558218412137`, 0.4143877847453685, 0.939406480847081], 
             256 -> RGBColor[
              0.2893861381019995, 0.4214935576590608, 0.939791484505258], 457 -> 
             RGBColor[
              0.22158907133489145`, 0.35023454190452297`, 0.9359305418496434],
              339 -> RGBColor[
              0.21169068579341777`, 0.33983071110654267`, 0.9353668434364056],
              420 -> RGBColor[
              0.96864282965107, 0.9761344542131977, 0.9379636895276074], 287 -> 
             RGBColor[
              0.20981171601903448`, 0.33785579474010136`, 0.9352598388874411],
              239 -> RGBColor[
              0.3509305166159243, 0.47838010803725933`, 0.9435819600964633], 
             427 -> RGBColor[
              0.2795001276110678, 0.4111027338238238, 0.9392284908328413], 
             285 -> RGBColor[
              0.3144183414809424, 0.4467550970906198, 0.941255436583311], 345 -> 
             RGBColor[
              0.6597251945044771, 0.7341016031348642, 0.9667188999718916], 
             366 -> RGBColor[
              0.2650062967491503, 0.3958687986259951, 0.9384030886069564], 
             216 -> RGBColor[
              0.26588598144981995`, 0.39679340302163035`, 0.9384531853492826],
              21 -> RGBColor[
              0.9808877657874093, 0.9471920876142448, 0.3802530084370154], 
             355 -> RGBColor[
              0.32870680276015046`, 0.45913104409172456`, 0.942165884701232], 
             175 -> RGBColor[
              0.9557302644442173, 0.966504284224312, 0.9598212942864327], 7 -> 
             RGBColor[
              0.8386821070512293, 0.8742063630160551, 0.9844754421425435], 13 -> 
             RGBColor[
              0.29661626096016863`, 0.4290928751992627, 0.9402032293060224], 
             294 -> RGBColor[
              0.23831274258564697`, 0.36781218073106675`, 0.9368829301869194],
              412 -> RGBColor[
              0.2423814866745967, 0.372088688741828, 0.9371146391436176], 193 -> 
             RGBColor[
              0.2878117179623051, 0.41983874226823964`, 0.9397018236074483], 
             60 -> RGBColor[
              0.29270959820985176`, 0.42498672495195505`, 0.9399807506417815],
              65 -> RGBColor[
              0.9854648277298144, 0.9626315922912277, 0.39803402977763763`], 
             448 -> RGBColor[
              0.5679393142918087, 0.6601177465734548, 0.9591294097327601], 69 -> 
             RGBColor[
              0.9094625081980608, 0.9306447336077317, 0.9912265399903383], 
             217 -> RGBColor[
              0.31971976000988434`, 0.4513469193633465, 0.9415932382841149], 
             214 -> RGBColor[
              0.19980711485308938`, 0.32734032458634205`, 0.9346900916515217],
              170 -> RGBColor[
              0.29668056881803306`, 0.42916046683523196`, 0.9402068915433929],
              359 -> RGBColor[
              0.38545126270191343`, 0.5082802432337956, 0.9457815915115654], 
             74 -> RGBColor[
              0.2817340129849886, 0.4134506889883278, 0.9393557073001488], 
             246 -> RGBColor[
              0.29422140859812795`, 0.42657573352434824`, 0.9400668460068708],
              264 -> RGBColor[
              0.23478619087952063`, 0.36410555129163547`, 0.9366820982843213],
              278 -> RGBColor[
              0.9483637407407871, 0.9610103429078694, 0.9722908974192511], 45 -> 
             RGBColor[
              0.28278247170568477`, 0.41455268557990177`, 0.9394154154732368],
              492 -> RGBColor[
              0.2766193131480329, 0.4080748151689876, 0.9390644327109545], 
             306 -> RGBColor[
              0.8575795140998795, 0.443586953641446, 0.20277151376979163`], 
             237 -> RGBColor[
              0.906092392768253, 0.9279574950433493, 0.9909050953721057], 228 -> 
             RGBColor[
              0.9930813033990235, 0.9876099324950685, 0.48832075610881853`], 
             180 -> RGBColor[
              0.27013094278236094`, 0.4012551265282246, 0.9386949296173133], 
             383 -> RGBColor[
              0.32894252042405586`, 0.45933521088468515`, 0.942180904422339], 
             53 -> RGBColor[
              0.9765123065091236, 0.9324326360618924, 0.36325517537702773`], 
             304 -> 
             RGBColor[
              0.3385640468354945, 0.4676688934702948, 0.9427939795772942], 48 -> 
             RGBColor[
              0.20751087662989864`, 0.3354374666604766, 0.9351288094880167], 
             5 -> RGBColor[
              0.23860734128045696`, 0.3681218226379481, 0.9368997071467691], 
             101 -> RGBColor[
              0.5208327276256995, 0.6218744973903617, 0.9554210066732913], 
             333 -> RGBColor[
              0.3786491349611119, 0.5023885820695944, 0.9453481659468069], 
             267 -> RGBColor[
              0.9890626064851881, 0.9747677448317271, 0.41201072085875556`], 
             120 -> RGBColor[
              0.20742150462258202`, 0.3353435310142743, 0.9351237198844141], 
             147 -> RGBColor[
              0.25149316947897704`, 0.3816656450832887, 0.9376335359998004], 
             89 -> RGBColor[
              0.28550171685781406`, 0.4174107846448903, 0.9395702724618878], 
             43 -> RGBColor[
              0.2931478124699098, 0.42544731592366486`, 0.940005706295612], 
             199 -> RGBColor[
              0.3428438781472085, 0.4713758682419251, 0.9430666866439704], 
             268 -> RGBColor[
              0.40965477924277666`, 0.5292441127573786, 0.9473238181832199], 
             169 -> RGBColor[
              0.4927421843014464, 0.5990693288551774, 0.9532096162037554], 20 -> 
             RGBColor[
              0.8845340276069948, 0.5685778117739207, 0.22536470111635126`], 
             4 -> RGBColor[
              0.32430364693803726`, 0.45531725182765653`, 0.9418853195058047],
              167 -> RGBColor[
              0.9866702547547157, 0.9887558220293171, 0.870571905196646], 431 -> 
             RGBColor[
              0.4485399301016759, 0.5629244760068475, 0.9498015456111601], 
             142 -> RGBColor[
              0.6995243049605603, 0.765192970707599, 0.9706857033583209], 16 -> 
             RGBColor[
              0.4038820814050813, 0.5242440920345965, 0.9469559869815982], 
             414 -> RGBColor[
              0.2746579678933065, 0.4060133169497984, 0.9389527370002482], 
             281 -> RGBColor[
              0.24490866169442368`, 0.374744909919817, 0.9372585580223763], 
             289 -> RGBColor[
              0.439371052281192, 0.5549828548799431, 0.9492173128241592], 398 -> 
             RGBColor[
              0.26115105564507934`, 0.3918166957892125, 0.9381835383293976], 
             178 -> RGBColor[
              0.9916846362160958, 0.9908293976273234, 0.7874706275783359], 58 -> 
             RGBColor[
              0.31511174381280593`, 0.44735568733906544`, 0.9412996195667458],
              186 -> RGBColor[
              0.23571041014604155`, 0.365076964339635, 0.9367347312042897], 
             122 -> RGBColor[
              0.867504304657107, 0.49124981725132677`, 0.21115468285025726`], 
             249 -> RGBColor[
              0.2895478687563091, 0.421663546831056, 0.9398006948267619], 113 -> 
             RGBColor[
              0.17919226069553715`, 0.305672805809509, 0.9335161062041928], 
             52 -> RGBColor[
              0.8357950446989824, 0.2761419758107905, 0.18191068126945342`], 
             409 -> RGBColor[
              0.24155566178660715`, 0.3712206944242289, 0.937067609637945], 
             187 -> RGBColor[
              0.26462809617956273`, 0.3954712858480575, 0.938381550644016], 
             259 -> RGBColor[
              0.8618406991999262, 0.46553270763892984`, 0.20642883162911219`],
              42 -> RGBColor[
              0.23247426890382172`, 0.3616755747108564, 0.9365504377479873], 
             134 -> RGBColor[
              0.2332063867745317, 0.36244507701192663`, 0.9365921307776528], 
             470 -> RGBColor[
              0.25548210733168075`, 0.3858582716797478, 0.937860700109407], 
             313 -> RGBColor[
              0.266957894870447, 0.3979200519899457, 0.9385142292328336], 248 -> 
             RGBColor[
              0.24253965650195108`, 0.3722549352589237, 0.9371236466812941], 
             174 -> RGBColor[
              0.2666571079259713, 0.3976039058403079, 0.93849709986132], 215 -> 
             RGBColor[
              0.28412310253725925`, 0.4159617735847908, 0.9394917624158093], 
             399 -> RGBColor[
              0.24150095424043594`, 0.3711631933245442, 0.9370644941241232], 
             422 -> RGBColor[
              0.23401200432651914`, 0.3632918321381684, 0.9366380095054342], 
             83 -> RGBColor[
              0.9207457022290968, 0.9396416462539369, 0.9923027411096448], 95 -> 
             RGBColor[
              0.22708291988077767`, 0.3560089250563658, 0.936243408396911], 
             166 -> RGBColor[
              0.8381204118994321, 0.2940157670958513, 0.18413745552673064`], 
             384 -> RGBColor[
              0.28382079992875175`, 0.41564403437615693`, 0.9394745467294715],
              233 -> RGBColor[
              0.8431597968980244, 0.3327506884676198, 0.18896317629255405`], 
             295 -> RGBColor[
              0.22958788287780074`, 0.3586417999900643, 0.9363860623338308], 
             499 -> 
             RGBColor[
              0.2607186377132893, 0.3913621971260208, 0.9381589127678872], 
             141 -> RGBColor[
              0.30958288032569087`, 0.4425668636752852, 0.9409473252743288], 
             319 -> RGBColor[
              0.7148896845747944, 0.7771965220434489, 0.9722171808006315], 
             205 -> RGBColor[
              0.9938265629209484, 0.98920396725517, 0.5694376558617151], 468 -> 
             RGBColor[
              0.4783770236668791, 0.5874070443089239, 0.952078738137285], 486 -> 
             RGBColor[
              0.9349275982881982, 0.9509499052141509, 0.9936554230160899], 
             224 -> RGBColor[
              0.29896629209325354`, 0.43156290692071464`, 0.9403370601024921],
              231 -> RGBColor[
              0.2584463601503126, 0.3889738893366137, 0.9380295099222091], 
             332 -> RGBColor[
              0.40219205331719154`, 0.5227802746481479, 0.946848299886271], 
             68 -> RGBColor[
              0.8199864588949732, 0.15463025795470559`, 0.16677236165029033`],
              484 -> RGBColor[
              0.9928916986278599, 0.9872043870615327, 0.4676834468726777], 10 -> 
             RGBColor[
              0.2189624152550279, 0.3474737598249721, 0.9357809576716846], 
             250 -> RGBColor[
              0.20444533477183996`, 0.332215387801077, 0.934954231414263], 
             282 -> RGBColor[
              0.6076583896248129, 0.6923634812527404, 0.9622562408387412], 
             374 -> RGBColor[
              0.2517303220687306, 0.38191490749146234`, 0.937647041488951], 
             232 -> RGBColor[
              0.3561976264336458, 0.4829422138287328, 0.9439175756765262], 
             489 -> RGBColor[
              0.9900975943251971, 0.9901731150203205, 0.8137720188432849], 
             253 -> RGBColor[
              0.9850318468002165, 0.9880782982349678, 0.8977245650665646], 
             459 -> RGBColor[
              0.3905461178527888, 0.5126931506906183, 0.9461062311765757], 
             415 -> RGBColor[
              0.2870126862041934, 0.4189989092289247, 0.9396563199308854], 55 -> 
             RGBColor[
              0.21147766438726034`, 0.339606812102334, 0.9353547121824619], 
             446 -> RGBColor[
              0.22815127331601265`, 0.3571318322543179, 0.9363042495445604], 
             325 -> RGBColor[
              0.1790169203691504, 0.30548851200925775`, 0.9335061208319979], 
             91 -> RGBColor[
              0.3276288460270304, 0.4581973721491767, 0.9420971982513973], 
             450 -> 
             RGBColor[
              0.8177084834502429, 0.13712074047130335`, 0.1645909697918113], 
             423 -> RGBColor[
              0.18782589147201245`, 0.31474729915939237`, 0.9340077787046009],
              105 -> RGBColor[
              0.2459052705491277, 0.3757924090147619, 0.9373153134223011], 36 -> 
             RGBColor[
              0.254389289460926, 0.3847096508089296, 0.9377984657483468], 123 -> 
             RGBColor[
              0.2069635167020156, 0.33486215667164765`, 0.9350976381498702], 
             94 -> RGBColor[
              0.9554190789968999, 0.9662722026272221, 0.9603480500785777], 
             473 -> RGBColor[
              0.32683125980079797`, 0.4575065430478635, 0.9420463767623395], 
             312 -> RGBColor[
              0.3044115375980597, 0.43728620519477157`, 0.940647158778472], 
             96 -> RGBColor[
              0.2961617343973124, 0.4286151389630523, 0.9401773446906796], 
             496 -> RGBColor[
              0.27688954314442643`, 0.4083588440287685, 0.9390798219094797], 
             2 -> RGBColor[
              0.2124476857409665, 0.34062636604798524`, 0.9354099534635375], 
             262 -> RGBColor[
              0.47608581392629684`, 0.5855469370236965, 0.9518983657135286], 
             272 -> RGBColor[
              0.8205829319400263, 0.15921501115513814`, 0.16734354491185305`],
              97 -> RGBColor[
              0.2317345075524728, 0.36089803862701, 0.9365083094334068], 372 -> 
             RGBColor[
              0.4704530721178047, 0.5809740234714359, 0.951454935644951], 356 -> 
             RGBColor[
              0.26933793088281155`, 0.4004216207419397, 0.9386497687627899], 
             402 -> RGBColor[
              0.5523112332770156, 0.6474301663686192, 0.9578991099477285], 
             455 -> RGBColor[
              0.20394063923757638`, 0.33168492079502093`, 0.9349254897502168],
              428 -> RGBColor[
              0.8303334960184631, 0.23416211938642656`, 0.1766806960850511], 
             346 -> RGBColor[
              0.21788265672664042`, 0.34633886515099205`, 0.9357194670208525],
              341 -> RGBColor[
              0.9935733711383794, 0.9886624156338708, 0.5418792928476311], 
             209 -> RGBColor[
              0.5659235722129052, 0.6584812763456551, 0.9589707231324023], 
             498 -> RGBColor[
              0.46188951150763047`, 0.5740217391840874, 0.9507807807843619], 
             378 -> RGBColor[
              0.2830844261537786, 0.4148700588498662, 0.9394326113323542], 
             419 -> 
             RGBColor[
              0.5126905354832046, 0.6152642990075083, 0.9547800234820015], 66 -> 
             RGBColor[
              0.2632810725593861, 0.3940554786170215, 0.9383048396415897], 
             139 -> RGBColor[
              0.5640351798749514, 0.6569481943745988, 0.9588220619701494], 56 -> 
             RGBColor[
              0.8366736085240676, 0.28289500235951803`, 0.1827519949805509], 
             335 -> RGBColor[
              0.2767721721232211, 0.4082354796437291, 0.9390731378034569], 
             314 -> RGBColor[
              0.33007547283951477`, 0.4603165173231115, 0.9422530951484216], 
             144 -> RGBColor[
              0.24622776306205768`, 0.3761313690930576, 0.9373336788938276], 
             298 -> RGBColor[
              0.9016398137954514, 0.9244071294324739, 0.9904804044148157], 
             204 -> RGBColor[
              0.5018930513522051, 0.606498414968846, 0.9539300059787216], 452 -> 
             RGBColor[
              0.22395342458252596`, 0.35271962707644106`, 0.936065188269349], 
             466 -> RGBColor[
              0.503508173143364, 0.6078096435993164, 0.9540571542825077], 207 -> 
             RGBColor[
              0.217062994597398, 0.3454773482835776, 0.9356727884751737], 334 -> 
             RGBColor[
              0.4028040785660817, 0.5233103801574531, 0.9468872975939376], 
             149 -> RGBColor[
              0.353874772698637, 0.4809302746734916, 0.9437695654905504], 219 -> 
             RGBColor[
              0.5262688994117111, 0.6262878265429939, 0.9558489620296395], 
             400 -> RGBColor[
              0.295921828646773, 0.42836298280833224`, 0.9401636824130951], 9 -> 
             RGBColor[
              0.5751436787516512, 0.6659665741948753, 0.9596965636934954], 11 -> 
             RGBColor[
              0.23891813183632316`, 0.3684484832174229, 0.9369174062091523], 
             44 -> RGBColor[
              0.49667724948997916`, 0.6022639920478948, 0.9535193989500155], 
             153 -> RGBColor[
              0.24493296406314102`, 0.3747704532501981, 0.9372599420063227], 
             471 -> RGBColor[
              0.8568125830318801, 0.4376919853814662, 0.20203709971295072`], 
             406 -> RGBColor[
              0.990618380894789, 0.9800157372285142, 0.4180546106567104], 32 -> 
             RGBColor[
              0.5357107322431658, 0.6339531317852908, 0.9565922576967049], 
             162 -> RGBColor[
              0.46203141681910903`, 0.5741369443087071, 0.9507919520902978], 
             493 -> 
             RGBColor[
              0.9935772608954081, 0.9886707354308406, 0.5423026688954158], 90 -> 
             RGBColor[
              0.8647697772859632, 0.4788329671240561, 0.2088729261823753], 
             331 -> RGBColor[
              0.8366916950922476, 0.8726192625482565, 0.984285594873034], 8 -> 
             RGBColor[
              0.6202936289377985, 0.7026213377380665, 0.963250933161866], 364 -> 
             RGBColor[
              0.2585666750316088, 0.38910034790526005`, 0.938036361676709], 
             342 -> RGBColor[
              0.25998714329821626`, 0.39059335011635443`, 0.9381172552430979],
              163 -> RGBColor[
              0.26699231078344465`, 0.3979562252966011, 0.9385161891681649], 
             49 -> RGBColor[
              0.49021471545548245`, 0.5970174157848499, 0.9530106445977776], 
             338 -> RGBColor[
              0.32010532781399464`, 0.4516808788160655, 0.9416178063236486], 
             76 -> RGBColor[
              0.4113253016274047, 0.530691035284047, 0.9474302623923834], 369 -> 
             RGBColor[
              0.4199474238450335, 0.5381590841884939, 0.9479796563958474], 
             445 -> RGBColor[
              0.22963931784821143`, 0.3586958614051314, 0.9363889914793045], 
             82 -> RGBColor[
              0.25827862318556116`, 0.3887975871515221, 0.9380199575502111], 
             67 -> RGBColor[
              0.25662307112871396`, 0.38705749697171266`, 0.9379256763097434],
              430 -> RGBColor[
              0.23973902577549727`, 0.36931129479517677`, 0.9369641549045845],
              211 -> RGBColor[
              0.2310404057237692, 0.3601684935964447, 
               0.9364687813610937]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9V3c41W/cPkZ2skfWMY5xzsFxzjFCvnekUipFSBqEZKVlFlIpoUVlJUVG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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 54}], {
             RGBColor[
             0.24744314331957223`, 0.3774088108032645, 0.937402893001499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 70}], {
             RGBColor[
             0.26220782647507634`, 0.3929274289346799, 0.9382437198648137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 84}], {
             RGBColor[
             0.249739891419232, 0.3798228386782472, 0.9375336894080404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 131}], {
             RGBColor[
             0.26488726968740706`, 0.3957436936373514, 0.9383963101918749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 135}], {
             RGBColor[
             0.2583961289533292, 0.38892109316374235`, 0.9380266493298512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 147}], {
             RGBColor[
             0.2588293294875211, 0.38937641439167825`, 0.9380513194594108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 170}], {
             RGBColor[
             0.2814230291570491, 0.41312382526764985`, 0.939337997231207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 171}], {
             RGBColor[
             0.2639538573417897, 0.3947626180803467, 0.9383431537396518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 265}], {
             RGBColor[
             0.2935899974663011, 0.4247777732380918, 0.9400724206184119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 266}], {
             RGBColor[
             0.27784311638010406`, 0.40936110995950087`, 0.9391341264945663]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 374}], {
             RGBColor[
             0.25894790578239785`, 0.38950104559576504`, 0.9380580722039861]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 385}], {
             RGBColor[
             0.2498185382943033, 0.379905501530447, 0.937538168231228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 391}], {
             RGBColor[
             0.25364635844324135`, 0.38392878320479584`, 0.9377561569259576]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 433}], {
             RGBColor[
             0.2958358704615542, 0.4267230355457211, 0.940215525659722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 47}], {
             RGBColor[
             0.22219066917343752`, 0.3508668593763409, 0.9359648019565643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 54}], {
             RGBColor[
             0.22058424144202293`, 0.3491784019772233, 0.9358733182737572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 55}], {
             RGBColor[
             0.21196267506411343`, 0.3401165890751596, 0.9353823328229998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 230}], {
             RGBColor[
             0.21816285424353754`, 0.34663337050679954`, 0.9357354238549247]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 242}], {
             RGBColor[
             0.21872765624032725`, 0.34722701321594046`, 0.9357675884930923]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 250}], {
             RGBColor[
             0.20844651025640323`, 0.33642087692453115`, 0.9351820924389003]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 339}], {
             RGBColor[
             0.21206918576719214`, 0.340228538577264, 0.9353883984499716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 365}], {
             RGBColor[
             0.21471117528305686`, 0.3430054370702481, 0.9355388558444269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 8}], {
             RGBColor[
             0.5409798313044035, 0.6382308237734111, 0.9570070604761514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 31}], {
             RGBColor[
             0.4573521482388232, 0.5703305077559329, 0.9504256815919188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[
             0.4618487252450588, 0.5739886270587315, 0.9507775699403673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 203}], {
             RGBColor[
             0.49811633466717364`, 0.6034323062247897, 0.9536326890067068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 221}], {
             RGBColor[
             0.4991380572062573, 0.6042617866100937, 0.9537131227476765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 223}], {
             RGBColor[
             0.4257649092191724, 0.5429712289379067, 0.9484129706530855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 258}], {
             RGBColor[
             0.41754423807969365`, 0.5358508967798354, 0.9478891567573319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 381}], {
             RGBColor[
             0.5154854178683257, 0.6175333104357662, 0.9550000468613498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 439}], {
             RGBColor[
             0.6612892589149015, 0.732886286051436, 0.9686794915733958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 480}], {
             RGBColor[
             0.4076066344287682, 0.5272434439758863, 0.9472559414401728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 29}], {
             RGBColor[
             0.36696197867847585`, 0.49226575471112954`, 0.9446034706830237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 185}], {
             RGBColor[
             0.30412419819916303`, 0.4355457825101565, 0.9406834624888651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 196}], {
             RGBColor[
             0.31000149085861584`, 0.44172318973711877`, 0.9410181656111457]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 318}], {
             RGBColor[
             0.33312298494508064`, 0.46295611913654056`, 0.9424472799249791]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 321}], {
             RGBColor[
             0.32873955000778277`, 0.45915940811169914`, 0.9421679713268938]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 335}], {
             RGBColor[
             0.3005379095306292, 0.4317763657356928, 0.9404792286546308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 383}], {
             RGBColor[
             0.32662308368104653`, 0.45732623135617084`, 0.9420331119640719]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 479}], {
             RGBColor[
             0.3678971603336924, 0.49307576205728143`, 0.9446630596311456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 482}], {
             RGBColor[
             0.3413925426988842, 0.4701187944228272, 0.9429742088325687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 496}], {
             RGBColor[
             0.3005965950412318, 0.4318380479282125, 0.9404825707076422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.23876273655839006`, 0.3682851529276855, 0.9369085566779607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 23}], {
             RGBColor[
             0.23055442452635688`, 0.3596576965449768, 0.9364411054508459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 41}], {
             RGBColor[
             0.23556700835298144`, 0.36492623996293, 0.9367265646843188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 102}], {
             RGBColor[
             0.2575724490549457, 0.3880553533662194, 0.9379797419781635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 186}], {
             RGBColor[
             0.23715887571324926`, 0.36659939348879156`, 0.9368172191755294]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 193}], {
             RGBColor[
             0.263209529621381, 0.3939802824530939, 0.9383007653771087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 202}], {
             RGBColor[
             0.23883220085490312`, 0.3683581643076115, 0.9369125125668838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 211}], {
             RGBColor[
             0.2348238735021131, 0.3641451581171964, 0.9366842442539314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 212}], {
             RGBColor[
             0.22856179646777947`, 0.35756331811549596`, 0.9363276282307389]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 300}], {
             RGBColor[
             0.23228249418787045`, 0.3614740073251723, 0.936539516461619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 414}], {
             RGBColor[
             0.2566326545868817, 0.38706756979387325`, 0.9379262220735086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 485}], {
             RGBColor[
             0.24330426601765148`, 0.37305858833896816`, 0.9371671900620748]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 24}], {
             RGBColor[
             0.8323309168683787, 0.869142096362715, 0.9838696599531287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 77}], {
             RGBColor[
             0.7172538475630181, 0.7785612627115652, 0.9728085302210365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 79}], {
             RGBColor[
             0.9107592672849488, 0.9273249908421985, 0.7765494419084453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 80}], {
             RGBColor[
             0.8086163665159423, 0.8504788015959455, 0.9815424524658205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 81}], {
             RGBColor[
             0.825653983169494, 0.8638180906717614, 0.9832328080563602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 99}], {
             RGBColor[
             0.9106556765920616, 0.9271034208247384, 0.765274234275318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 156}], {
             RGBColor[
             0.6474994925034097, 0.7219315348762902, 0.9673172118721224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 267}], {
             RGBColor[
             0.9083762130299251, 0.9201045780958312, 0.6977188544044266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 278}], {
             RGBColor[
             0.8880267801577246, 0.9132258771339024, 0.9778589426846744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 329}], {
             RGBColor[
             0.8551238518896912, 0.8873165640509703, 0.9860436704429549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 406}], {
             RGBColor[
             0.9091541002347256, 0.9227285742942248, 0.700740799303404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 413}], {
             RGBColor[
             0.9007629224656561, 0.8944231613369187, 0.6681426582115271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 486}], {
             RGBColor[
             0.8813087089314302, 0.9081956582870432, 0.9885412054830938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 28}], {
             RGBColor[
             0.901769090567154, 0.9237583305634441, 0.9644245605513657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 49}], {
             RGBColor[
             0.6644484112533559, 0.7356118894004525, 0.9687430433701605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 69}], {
             RGBColor[
             0.874072307624645, 0.9024255483118935, 0.9878509910664408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 142}], {
             RGBColor[
             0.7691032060058948, 0.819699666861827, 0.9775805727504322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 173}], {
             RGBColor[
             0.9116225315818571, 0.9310453814508525, 0.9449853696775101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[
             0.9125990982944516, 0.9314492168831301, 0.9288011319761822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 241}], {
             RGBColor[
             0.7720821236708154, 0.8220268199822758, 0.9778774834237032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 388}], {
             RGBColor[
             0.8924271040987608, 0.9167910923514154, 0.9802381068620604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 402}], {
             RGBColor[
             0.6954966701641224, 0.7608182646923372, 0.971187276045136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 436}], {
             RGBColor[
             0.6558009604167452, 0.7285914992480711, 0.9680622843636464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 461}], {
             RGBColor[
             0.8915688064008891, 0.9161509753336762, 0.9816909809846657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 487}], {
             RGBColor[
             0.7090567422484308, 0.7718269420846646, 0.9722547745917934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 31}], {
             RGBColor[
             0.5366659458722182, 0.6347210217205881, 0.9566695542776334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 40}], {
             RGBColor[
             0.5032468930597369, 0.6057751178648505, 0.9545401217837302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 114}], {
             RGBColor[
             0.5604860564407306, 0.6540668560845098, 0.9585426619725401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 115}], {
             RGBColor[
             0.7707310045144475, 0.8213000079229384, 0.9777969948316587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 162}], {
             RGBColor[
             0.5411625228784538, 0.6383791410233868, 0.9570214426260819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 203}], {
             RGBColor[
             0.5774301323005686, 0.6678228201894449, 0.9598765616924215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 221}], {
             RGBColor[
             0.5784518548396522, 0.6686523005747489, 0.9599569954333912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 258}], {
             RGBColor[
             0.4968580357130886, 0.6002414107444907, 0.9541330294430466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 289}], {
             RGBColor[
             0.5298323406094952, 0.6288020963090049, 0.9562341229930127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 291}], {
             RGBColor[
             0.637610384777719, 0.7164873323549865, 0.9647458039813404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 297}], {
             RGBColor[
             0.5698289191235334, 0.6616518129015765, 0.9592781663469641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 311}], {
             RGBColor[
             0.6835752486050087, 0.752395433322769, 0.9693271520415703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 381}], {
             RGBColor[
             0.5947992155017207, 0.6819238244004215, 0.9612439195470645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 419}], {
             RGBColor[
             0.5664920822105015, 0.6589428183727875, 0.9590154783219338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 439}], {
             RGBColor[
             0.7406030565482964, 0.7972768000160912, 0.9749233642591105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 19}], {
             RGBColor[
             0.5674341026863339, 0.6597075930326068, 0.9590896376245259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 26}], {
             RGBColor[
             0.4808866078491948, 0.5876336896788764, 0.952776616899017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 34}], {
             RGBColor[
             0.559448373541096, 0.6532244183595045, 0.9584609717735231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 44}], {
             RGBColor[
             0.5359104641208152, 0.634115283121385, 0.9566079813217554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.5464995084832656, 0.6427119463658346, 0.9574415896829152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 117}], {
             RGBColor[
             0.4781094761010015, 0.5852282777412916, 0.9525996605197433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 139}], {
             RGBColor[
             0.5695894293133013, 0.6614573842847371, 0.9592593128318224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 247}], {
             RGBColor[
             0.5350775301382318, 0.6334390697910756, 0.9565424097075088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 269}], {
             RGBColor[
             0.512041509774998, 0.614618499836106, 0.9547617797005311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 360}], {
             RGBColor[
             0.5772550006439877, 0.6676806404210414, 0.9598627746868871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 425}], {
             RGBColor[
             0.47524326414852586`, 0.5827457090080587, 0.9524170280286233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 466}], {
             RGBColor[
             0.5393259259475076, 0.6368881088970959, 0.9568768589880016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 468}], {
             RGBColor[
             0.5267603512092651, 0.6266868092518996, 0.9558876509153902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 120}], {
             RGBColor[
             0.21319195993880496`, 0.3414086454196232, 0.9354523387780493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 123}], {
             RGBColor[
             0.21296296597852177`, 0.34116795824830987`, 0.9354392979107774]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 125}], {
             RGBColor[
             0.21381800062875955`, 0.3420666538780378, 0.935487990869198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 177}], {
             RGBColor[
             0.21382948684753797`, 0.34207872662224226`, 0.9354886449923652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 245}], {
             RGBColor[
             0.22026264269435236`, 0.3488403813028832, 0.93585500370084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 438}], {
             RGBColor[
             0.22021348611856342`, 0.3487887146250221, 0.9358522043065695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 455}], {
             RGBColor[
             0.21145152724630215`, 0.3395793403099965, 0.9353532237109508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 23}], {
             RGBColor[
             0.23070981980428998`, 0.3598210268347142, 0.9364499549820375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 41}], {
             RGBColor[
             0.23572240363091454`, 0.3650895702526674, 0.9367354142155104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 102}], {
             RGBColor[
             0.2577278443328788, 0.3882186836559568, 0.9379885915093551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 186}], {
             RGBColor[
             0.23731427099118235`, 0.3667627237785289, 0.936826068706721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 193}], {
             RGBColor[
             0.2633649248993141, 0.3941436127428313, 0.9383096149083003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 202}], {
             RGBColor[
             0.2389875961328362, 0.3685214945973489, 0.9369213620980754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 211}], {
             RGBColor[
             0.23497926878004616`, 0.3643084884069338, 0.936693093785123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 414}], {
             RGBColor[
             0.25678804986481485`, 0.38723090008361066`, 0.9379350716047002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 485}], {
             RGBColor[
             0.24345966129558455`, 0.3732219186287056, 0.9371760395932665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 497}], {
             RGBColor[
             0.2374558873234022, 0.36691157152268605`, 0.9368341335473384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 198}], {
             RGBColor[
             0.2771414265920781, 0.4086235895025834, 0.9390941662991953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 373}], {
             RGBColor[
             0.28300945147034123`, 0.414791255703904, 0.9394283416350475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 480}], {
             RGBColor[
             0.31297532312712917`, 0.4421451064609878, 0.9412865192071291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 154}], {
             RGBColor[
             0.3030787322552839, 0.435811820273263, 0.9405739494865415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 229}], {
             RGBColor[
             0.2937960299949141, 0.4261286336418093, 0.9400426213247091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 244}], {
             RGBColor[
             0.3195286449146627, 0.4500599078221664, 0.9416221233751105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 313}], {
             RGBColor[
             0.2817870779153078, 0.4135064635946042, 0.939358729269428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 334}], {
             RGBColor[
             0.3497101697631252, 0.47620162767835794`, 0.94354526344998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 338}], {
             RGBColor[
             0.30836079438708164`, 0.4403868770076641, 0.9409105178148355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 340}], {
             RGBColor[
             0.3170254114231826, 0.44789173278801986`, 0.9414626195505558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 363}], {
             RGBColor[
             0.3507138092232281, 0.4770709297343131, 0.9436092144688942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 379}], {
             RGBColor[
             0.3029577301181068, 0.43570701430378433`, 0.9405662393373586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 380}], {
             RGBColor[
             0.28473366122711574`, 0.4166035094794867, 0.939526532829956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 390}], {
             RGBColor[
             0.29868486413343276`, 0.4312671082913797, 0.9403210331965157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 478}], {
             RGBColor[
             0.28132910192119526`, 0.41302510178743673`, 0.939332648214078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 63}], {
             RGBColor[
             0.3630391373968948, 0.48868276614576933`, 0.9443602925394342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 72}], {
             RGBColor[
             0.2803635687690008, 0.4120102652261427, 0.9392776625294388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 75}], {
             RGBColor[
             0.32584559541094904`, 0.45646758947931865`, 0.9419903529330476]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 149}], {
             RGBColor[
             0.33030872638618497`, 0.46033332920658265`, 0.9422747396921978]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 158}], {
             RGBColor[
             0.33213200521333075`, 0.4619125616859979, 0.9423909174068014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 163}], {
             RGBColor[
             0.2868674954285888, 0.4188463045181374, 0.9396480515310051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 182}], {
             RGBColor[
             0.34266467028924463`, 0.47103542678761523`, 0.9430620495117685]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 187}], {
             RGBColor[
             0.28568538812664784`, 0.41760383479386565`, 0.9395807322689307]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 279}], {
             RGBColor[
             0.2926514518650601, 0.4249256094568878, 0.9399774392934654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 322}], {
             RGBColor[
             0.2829806146027809, 0.4147609463277351, 0.9394266994181002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 324}], {
             RGBColor[
             0.33821006500838097`, 0.4671770715883025, 0.9427782060023248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 441}], {
             RGBColor[
             0.3784375409652084, 0.5020200893703757, 0.9453414651985335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 494}], {
             RGBColor[
             0.2826231066390982, 0.4143851827905905, 0.9394063398684542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 78}], {
             RGBColor[
             0.22683394628673456`, 0.35574723802318886`, 0.9362292297190538]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 97}], {
             RGBColor[
             0.23298665056537604`, 0.36221412032402367`, 0.936579617125612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 104}], {
             RGBColor[
             0.24040623048550225`, 0.3700125692486139, 0.9370021512257783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.24125115959042637`, 0.3709006433094886, 0.9370502686883432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 148}], {
             RGBColor[
             0.2369473179686802, 0.36637703288571377`, 0.9368051712749479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 153}], {
             RGBColor[
             0.23958587882071014`, 0.3691503276356177, 0.93695543341207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 190}], {
             RGBColor[
             0.24117420601353035`, 0.37081976022103225`, 0.9370458862959816]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 323}], {
             RGBColor[
             0.2367917298527569, 0.36621349991102203`, 0.936796310761918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 356}], {
             RGBColor[
             0.2517883622305454, 0.38197591138148856`, 0.9376503467903037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 408}], {
             RGBColor[
             0.22837166352845595`, 0.3573634763411423, 0.9363168004411209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 430}], {
             RGBColor[
             0.23698890967688827`, 0.36642074840810707`, 0.9368075398612009]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 452}], {
             RGBColor[
             0.22909610908040262`, 0.3581249145487392, 0.9363580565435832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 39}], {
             RGBColor[
             0.5137718344766236, 0.6147998451486828, 0.9552360290912556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 45}], {
             RGBColor[
             0.343332276555383, 0.46939838880724916`, 0.9431857012274175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 52}], {
             RGBColor[
             0.6198385630520318, 0.4001930339226935, 0.5644333341255259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 56}], {
             RGBColor[
             0.6202778449645745, 0.4035695471970573, 0.5648539909810746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 179}], {
             RGBColor[
             0.29140560923354364`, 0.4148201691111312, 0.940228554342059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 200}], {
             RGBColor[
             0.6523550443789783, 0.5834045301394526, 0.5929583920999518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 236}], {
             RGBColor[
             0.34560261915581325`, 0.4717846628283363, 0.9433149938798411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 243}], {
             RGBColor[
             0.6215940953786275, 0.41368682466407874`, 0.566114433864064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 254}], {
             RGBColor[
             0.3201901654275895, 0.4450745627173458, 0.941867792234375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 276}], {
             RGBColor[
             0.5117111188744836, 0.6131268633886855, 0.9550738020104051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 283}], {
             RGBColor[
             0.29254812031783006`, 0.4160210207001029, 0.9402936186581154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 292}], {
             RGBColor[
             0.29142635679170903`, 0.41484197611023416`, 0.9402297358848033]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 422}], {
             RGBColor[
             0.3189470428658002, 0.4437679620863825, 0.9417969982435161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 454}], {
             RGBColor[
             0.6518822537994468, 0.581257698540845, 0.5925638840512331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 205}], {
             RGBColor[
             0.9368989095333399, 0.9481665884975428, 0.7789256469520753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 252}], {
             RGBColor[
             0.8078836333626171, 0.8503289562761027, 0.9813572830192461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 282}], {
             RGBColor[
             0.7438148228852721, 0.7997463454963281, 0.9753349394405884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 293}], {
             RGBColor[
             0.9171217844286204, 0.9362730779745756, 0.9753514321588153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 298}], {
             RGBColor[
             0.8908055349705915, 0.9157681695861948, 0.9894470212286257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 418}], {
             RGBColor[
             0.9292223734187801, 0.9452976774305406, 0.9548682913375369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 432}], {
             RGBColor[
             0.8892978625365586, 0.9145659925119751, 0.9893032180859526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 467}], {
             RGBColor[
             0.7934052123801664, 0.8390183037645371, 0.979914209324252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 52}], {
             RGBColor[
             0.8600894824934477, 0.42201909265360843`, 0.20357506457964797`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 56}], {
             RGBColor[
             0.8605287644059905, 0.4253956059279722, 0.2039957214351967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 65}], {
             RGBColor[
             0.9349243740088637, 0.7652639008938271, 0.3116367388337401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 88}], {
             RGBColor[
             0.8754970234499582, 0.5275428865427625, 0.2178240033304778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 166}], {
             RGBColor[
             0.8612521660936727, 0.43095598829613885`, 0.2046884517082866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 167}], {
             RGBColor[
             0.9355270875213144, 0.7783260157628717, 0.5479056765432442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 210}], {
             RGBColor[
             0.8602238171594843, 0.4230516477625904, 0.20370370360755374`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 227}], {
             RGBColor[
             0.8650075437066738, 0.45982146624662823`, 0.2082846055515888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 243}], {
             RGBColor[
             0.8618450148200435, 0.43551288339499367`, 0.2052561643181862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 326}], {
             RGBColor[
             0.8797797158009789, 0.5469895922605361, 0.22139758680656518`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 348}], {
             RGBColor[
             0.9221477650002106, 0.7221653986171828, 0.2620020254952798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 428}], {
             RGBColor[
             0.8573587081531882, 0.40102916444142644`, 0.2009600719874468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 434}], {
             RGBColor[
             0.9377932493402739, 0.7792631319127137, 0.510349510564296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 469}], {
             RGBColor[
             0.8724072991337889, 0.5135131700464854, 0.21524586162499276`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 474}], {
             RGBColor[
             0.9387405372806834, 0.7796548598202627, 0.49465049788910304`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 495}], {
             RGBColor[
             0.8632931958328989, 0.4466442372567656, 0.2066429440915829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 26}], {
             RGBColor[
             0.4731770317838775, 0.5813747085166081, 0.9521696908300475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 34}], {
             RGBColor[
             0.5517387974757788, 0.6469654371972362, 0.9578540457045537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 44}], {
             RGBColor[
             0.5282008880554978, 0.6278563019591167, 0.956001055252786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 139}], {
             RGBColor[
             0.5618798532479841, 0.6551984031224687, 0.9586523867628529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 234}], {
             RGBColor[
             0.474151584993228, 0.582218817524079, 0.9522317884987839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 247}], {
             RGBColor[
             0.5273679540729146, 0.6271800886288073, 0.9559354836385393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 269}], {
             RGBColor[
             0.5043319337096805, 0.6083595186738375, 0.9541548536315616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 360}], {
             RGBColor[
             0.5695454245786704, 0.661421659258773, 0.9592558486179177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 393}], {
             RGBColor[
             0.5104680056398668, 0.6134599491568583, 0.954605057791339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 466}], {
             RGBColor[
             0.5316163498821903, 0.6306291277348275, 0.9562699329190321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 468}], {
             RGBColor[
             0.5190507751439478, 0.6204278280896312, 0.9552807248464208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 62}], {
             RGBColor[
             0.8509265138034974, 0.3513524058869604, 0.19479135055817565`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 194}], {
             RGBColor[
             0.9355250585723344, 0.7786349412620628, 0.5492457614630861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 228}], {
             RGBColor[
             0.9388076655030091, 0.7780938721344945, 0.3568427286125849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 388}], {
             RGBColor[
             0.9153530643766437, 0.7639768167303482, 0.6006827363489642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 490}], {
             RGBColor[
             0.9375437932423437, 0.7794697399272263, 0.5157901036631747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 33}], {
             RGBColor[
             0.9296510090196749, 0.7439907144053559, 0.3002556094938443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 65}], {
             RGBColor[
             0.9831762967586118, 0.9549118399527363, 0.38914351910732653`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 119}], {
             RGBColor[
             0.9857675700825197, 0.9687962754074746, 0.5924568745131584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 164}], {
             RGBColor[
             0.8992062375406565, 0.5414501296947882, 0.27233399794458657`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 166}], {
             RGBColor[
             0.9095040888434207, 0.6206039273550481, 0.282195231981873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 175}], {
             RGBColor[
             0.9683090151158134, 0.9568481859192783, 0.670037151361724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 227}], {
             RGBColor[
             0.9132594664564218, 0.6494694053055374, 0.28579138582517527`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 309}], {
             RGBColor[
             0.9869592653755547, 0.967346961753188, 0.4315364838739727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 320}], {
             RGBColor[
             0.9847451317139568, 0.9683734708666063, 0.6094013242659239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 337}], {
             RGBColor[
             0.9205492329643337, 0.9192823831910986, 0.6833909335036439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 348}], {
             RGBColor[
             0.9703996877499586, 0.911813337676092, 0.3395088057688662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 375}], {
             RGBColor[
             0.9695446020803578, 0.9577696846543478, 0.6679456249234423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 428}], {
             RGBColor[
             0.9056106309029361, 0.5906771035003356, 0.2784668522610333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 489}], {
             RGBColor[
             0.9854926800563032, 0.9686826013172827, 0.5970125136401502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 63}], {
             RGBColor[
             0.4353760609281416, 0.5515225941640346, 0.948962755507775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 149}], {
             RGBColor[
             0.40264564991743174`, 0.5231731572248479, 0.9468772026605385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 160}], {
             RGBColor[
             0.4369491379476227, 0.5528851144131592, 0.949062990584439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 165}], {
             RGBColor[
             0.4377248912958056, 0.5535570329728583, 0.9491124209018134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 182}], {
             RGBColor[
             0.4150015938204914, 0.5338752548058805, 0.9476645124801093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 268}], {
             RGBColor[
             0.4305356531895016, 0.5473300762667914, 0.9486543290068734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 275}], {
             RGBColor[
             0.43256024452096153`, 0.549083675519183, 0.9487833341762382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 282}], {
             RGBColor[
             0.5295374583805197, 0.6288897605144723, 0.956120540334634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 285}], {
             RGBColor[
             0.38291743430858444`, 0.506085568433412, 0.9456201382069189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 324}], {
             RGBColor[
             0.41054698853962773`, 0.5300168996065678, 0.9473806689706655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 353}], {
             RGBColor[
             0.5455395337034719, 0.641880966146923, 0.9573802823215901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 441}], {
             RGBColor[
             0.45077446449645514`, 0.564859917388641, 0.9499439281668742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 481}], {
             RGBColor[
             0.38481661217346425`, 0.507730540844516, 0.9457411521410921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 41}], {
             RGBColor[
             0.22751409159888136`, 0.35646211386995863`, 0.9362679629883957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 186}], {
             RGBColor[
             0.22910595895914918`, 0.35813526739582024`, 0.9363586174796061]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 202}], {
             RGBColor[
             0.23077928410080303`, 0.35989403821464017`, 0.9364539108709606]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 211}], {
             RGBColor[
             0.226770956748013, 0.3556810320242251, 0.9362256425580082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 212}], {
             RGBColor[
             0.22050887971367938`, 0.3490991920225246, 0.9358690265348157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 485}], {
             RGBColor[
             0.2352513492635514, 0.3645944622459968, 0.9367085883661517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 497}], {
             RGBColor[
             0.22924757529136902`, 0.3582841151399774, 0.9363666823202235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 77}], {
             RGBColor[
             0.7218949448567346, 0.7822619477143448, 0.9732512022240677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 81}], {
             RGBColor[
             0.8302950804632105, 0.8675187756745408, 0.9836754800593912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 83}], {
             RGBColor[
             0.878858858195596, 0.9062422138097157, 0.9883075365329024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 176}], {
             RGBColor[
             0.7219583100603643, 0.7823133904412213, 0.9732561905650118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 197}], {
             RGBColor[
             0.7672988184851579, 0.8182762435725834, 0.9774043962108645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 237}], {
             RGBColor[
             0.871532203465174, 0.9004001382044219, 0.9876087136641327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 267}], {
             RGBColor[
             0.9130173103236416, 0.9238052630986108, 0.6981615264074577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 270}], {
             RGBColor[
             0.9134975511433701, 0.9314925430785823, 0.899659555679228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 278}], {
             RGBColor[
             0.8926678774514412, 0.9169265621366819, 0.9783016146877055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 329}], {
             RGBColor[
             0.8597649491834076, 0.8910172490537498, 0.986486342445986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 426}], {
             RGBColor[
             0.8535732035252862, 0.8860801191364223, 0.9858957682176778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 448}], {
             RGBColor[
             0.7024556642269519, 0.7664802639694746, 0.97172087084446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 489}], {
             RGBColor[
             0.9135348042436461, 0.9315079481929074, 0.8990421753997224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[
             0.36235029179287925`, 0.48827134332094824`, 0.9443096180726283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 96}], {
             RGBColor[
             0.3047685081778331, 0.4372333951604509, 0.9406831592217764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 157}], {
             RGBColor[
             0.3079594456965586, 0.4405872728097553, 0.9408648783928987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.2917531123703574, 0.42355338894303707`, 0.9399419516850931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 246}], {
             RGBColor[
             0.3037983452782409, 0.43621369244109887`, 0.940627909879872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 288}], {
             RGBColor[
             0.2847205959795895, 0.4161617683290476, 0.9395414602803146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 333}], {
             RGBColor[
             0.34601220845973285`, 0.4741201167137219, 0.94326856984984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 343}], {
             RGBColor[
             0.3031313951145783, 0.4355126855320067, 0.9405899280547156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 392}], {
             RGBColor[
             0.3096883372024623, 0.4424044474005129, 0.9409633362064942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 459}], {
             RGBColor[
             0.35196069990557133`, 0.47927240102423385`, 0.9436476024647243]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 465}], {
             RGBColor[
             0.2980004320712376, 0.430119718051609, 0.9402977272999771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 492}], {
             RGBColor[
             0.29499729755319337`, 0.42696323326341856`, 0.9401267032319138]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 34}], {
             RGBColor[
             0.46519130263863967`, 0.5748915338435057, 0.9515410249790447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 44}], {
             RGBColor[
             0.4416533932183588, 0.5557823986053863, 0.949688034527277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 106}], {
             RGBColor[
             0.45224243758080923`, 0.5643790618498358, 0.9505216428884367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 117}], {
             RGBColor[
             0.38385240519854513`, 0.5068953932252928, 0.9456797137252648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 139}], {
             RGBColor[
             0.4753323584108449, 0.5831244997687381, 0.952339366037344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 215}], {
             RGBColor[
             0.33537631974199883`, 0.4626312893738342, 0.942674216260174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 224}], {
             RGBColor[
             0.34279791451999597`, 0.4704318560417961, 0.9430968651035153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 247}], {
             RGBColor[
             0.44082045923577545`, 0.5551061852750767, 0.9496224629130303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 269}], {
             RGBColor[
             0.4177844388725415, 0.5362856153201071, 0.9478418329060527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 351}], {
             RGBColor[
             0.3383374936256977, 0.4657436708748698, 0.9428428507321864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 360}], {
             RGBColor[
             0.48299792974153133`, 0.5893477559050426, 0.9529428278924086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 425}], {
             RGBColor[
             0.38098619324606947`, 0.5044128244920598, 0.9454970812341448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 466}], {
             RGBColor[
             0.4450688550450512, 0.558555224381097, 0.9499569121935232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 468}], {
             RGBColor[
             0.43250328030680874`, 0.5483539247359007, 0.9489677041209118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 40}], {
             RGBColor[
             0.44915953688308596`, 0.5618645655130168, 0.9502821669769903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 114}], {
             RGBColor[
             0.5063987002640795, 0.610156303732676, 0.9542847071658003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 199}], {
             RGBColor[
             0.4274813973658525, 0.5430880506381621, 0.9489008550961784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 220}], {
             RGBColor[
             0.4255160611016982, 0.5413857751468245, 0.948775625607305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 277}], {
             RGBColor[
             0.6417102241932708, 0.7180330594388474, 0.9662874050409727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 289}], {
             RGBColor[
             0.47574498443284424`, 0.5848915439571711, 0.9519761681862727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 291}], {
             RGBColor[
             0.583523028601068, 0.6725767800031528, 0.9604878491746004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 297}], {
             RGBColor[
             0.5157415629468824, 0.6177412605497428, 0.9550202115402241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 311}], {
             RGBColor[
             0.6294878924283578, 0.7084848809709354, 0.9650691972348303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 319}], {
             RGBColor[
             0.6135043005796454, 0.695998377538924, 0.9634761021745089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 349}], {
             RGBColor[
             0.46286019331944683`, 0.5737313855031778, 0.9511551606901004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 359}], {
             RGBColor[
             0.44878508964320496`, 0.5615402381340974, 0.9502583075299758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 371}], {
             RGBColor[
             0.43753141765926407`, 0.551792873087608, 0.9495412335023905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 419}], {
             RGBColor[
             0.5124047260338506, 0.6150322660209537, 0.9547575235151939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 488}], {
             RGBColor[
             0.640741608541348, 0.7172763695298137, 0.9661908624850168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 69}], {
             RGBColor[
             0.9371592911405698, 0.9519775158592825, 0.9678001094752631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 142}], {
             RGBColor[
             0.8321901895218196, 0.869251634409216, 0.9575296911592543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 173}], {
             RGBColor[
             0.9747095150977819, 0.9805973489982415, 0.9249344880863324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 194}], {
             RGBColor[
             0.9756860818103763, 0.9810011844305191, 0.9087502503850045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 241}], {
             RGBColor[
             0.8351691071867402, 0.8715787875296648, 0.9578266018325254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 417}], {
             RGBColor[
             0.8329443683967894, 0.8698408046783143, 0.9576048606613091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 461}], {
             RGBColor[
             0.954655789916814, 0.9657029428810652, 0.9616400993934879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 493}], {
             RGBColor[
             0.9792166674892435, 0.9809905167708368, 0.7433381739278018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 77}], {
             RGBColor[
             0.5082190929851442, 0.6104476858288989, 0.9547558471761093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 172}], {
             RGBColor[
             0.3806363827099919, 0.5041098361876981, 0.9454747916161113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 318}], {
             RGBColor[
             0.37578131668551923`, 0.4999046220200136, 0.9451654311021982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 321}], {
             RGBColor[
             0.3713978817482214, 0.49610791099517215`, 0.944886122504113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 383}], {
             RGBColor[
             0.3692814154214852, 0.49427473423964385`, 0.944751263141291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 479}], {
             RGBColor[
             0.410555492074131, 0.5300242649407545, 0.9473812108083647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 482}], {
             RGBColor[
             0.38405087443932273`, 0.5070672973063002, 0.9456923600097877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 43}], {
             RGBColor[
             0.2805395184040802, 0.4121951994484624, 0.9392876826008625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 64}], {
             RGBColor[
             0.27788283656739987`, 0.4094028583947541, 0.9391363885004721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 110}], {
             RGBColor[
             0.26982326266389456`, 0.40093173521567016`, 0.9386774076897386]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 217}], {
             RGBColor[
             0.2938254921740675, 0.42514500116830317`, 0.9400814485951139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 290}], {
             RGBColor[
             0.2772082322816696, 0.40869380651806936`, 0.9390979707843874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 316}], {
             RGBColor[
             0.25921313179459604`, 0.3897798149508858, 0.938073176433014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 355}], {
             RGBColor[
             0.29831901354920054`, 0.4290370635324922, 0.9403677718036725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 378}], {
             RGBColor[
             0.2755078252460146, 0.406906570911563, 0.9390011351192336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 384}], {
             RGBColor[
             0.2758760121335012, 0.4072935586747084, 0.9390221028177923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[
             0.4196192099941566, 0.5378748018473721, 0.9479587428994976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 114}], {
             RGBColor[
             0.47685837337515014`, 0.5861665400670314, 0.9519612830883075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 162}], {
             RGBColor[
             0.4575348398128734, 0.5704788250059085, 0.9504400637418493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 203}], {
             RGBColor[
             0.4938024492349883, 0.5999225041719667, 0.9532951828081889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 208}], {
             RGBColor[
             0.38757839390763205`, 0.5101226573714661, 0.9459171304310454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 221}], {
             RGBColor[
             0.4948241717740719, 0.6007519845572706, 0.9533756165491586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 223}], {
             RGBColor[
             0.42145102378698707`, 0.5394614268850837, 0.9480754644545675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 258}], {
             RGBColor[
             0.4132303526475083, 0.5323410947270124, 0.947551650558814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 289}], {
             RGBColor[
             0.4462046575439149, 0.5609017802915265, 0.9496527441087801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 297}], {
             RGBColor[
             0.48620123605795307`, 0.5937514968840982, 0.9526967874627315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 314}], {
             RGBColor[
             0.3915568678230763, 0.5135686115131106, 0.9461706352709112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 381}], {
             RGBColor[
             0.5111715324361403, 0.6140235083829432, 0.9546625406628318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 397}], {
             RGBColor[
             0.40579315804314603`, 0.5258993705649835, 0.947077759095077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 419}], {
             RGBColor[
             0.4828643991449212, 0.5910425023553091, 0.9524340994377012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 472}], {
             RGBColor[
             0.39074248974700837`, 0.5128632381554529, 0.9461187438200305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 103}], {
             RGBColor[
             0.5080332189208779, 0.6114832796124914, 0.9544133824619024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 155}], {
             RGBColor[
             0.5507999265063706, 0.6462032194486154, 0.9577801343426442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 331}], {
             RGBColor[
             0.6862012136677067, 0.7532861971667737, 0.9704389262848694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 344}], {
             RGBColor[
             0.49972685632516956`, 0.6047398002599247, 0.9537594751711596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 403}], {
             RGBColor[
             0.73231135392298, 0.7900531713799142, 0.9748369526254256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 449}], {
             RGBColor[
             0.6320067542390264, 0.7108140314884382, 0.9650731650607731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 119}], {
             RGBColor[
             0.9345308133147854, 0.7655949021985857, 0.5124594755699873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 159}], {
             RGBColor[
             0.8495822086293704, 0.3506448894924134, 0.19388094901806585`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 164}], {
             RGBColor[
             0.8479694807729221, 0.33824875648589925`, 0.19233659900141542`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 227}], {
             RGBColor[
             0.8620227096886874, 0.44626803209664856`, 0.20579398688200412`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 267}], {
             RGBColor[
             0.9337384293685642, 0.7577785430140971, 0.3161344657047144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 270}], {
             RGBColor[
             0.9342186701882929, 0.7654658229940685, 0.5176324949764846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 309}], {
             RGBColor[
             0.9357225086078202, 0.7641455885442991, 0.35153908493080155`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 443}], {
             RGBColor[
             0.9064631162110222, 0.6594290978497701, 0.24321160823769428`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 489}], {
             RGBColor[
             0.9342559232885688, 0.7654812281083937, 0.517015114696979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 234}], {
             RGBColor[
             0.4661658558479902, 0.5757356428509766, 0.951603122647781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 269}], {
             RGBColor[
             0.4963462045644428, 0.6018763440007352, 0.9535261877805588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 332}], {
             RGBColor[
             0.47297256082386624`, 0.5816312685861409, 0.9520368398699108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 360}], {
             RGBColor[
             0.5615596954334325, 0.6549384845856707, 0.9586271827669148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 393}], {
             RGBColor[
             0.5024822764946291, 0.606976774483756, 0.9539763919403361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 468}], {
             RGBColor[
             0.51106504599871, 0.6139446534165288, 0.9546520589954179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 54}], {
             RGBColor[
             0.23354661261843296`, 0.36280267594543125`, 0.936611506136144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 67}], {
             RGBColor[
             0.24749774961125026`, 0.377466205478057, 0.9374060027490273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 70}], {
             RGBColor[
             0.24831129577393707`, 0.37832129407684667`, 0.9374523329994586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 84}], {
             RGBColor[
             0.2358433607180927, 0.36521670382041393`, 0.9367423025426853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 131}], {
             RGBColor[
             0.2509907389862678, 0.38113755877951816`, 0.9376049233265198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 135}], {
             RGBColor[
             0.24449959825218992`, 0.3743149583059091, 0.9372352624644963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 147}], {
             RGBColor[
             0.2449327987863818, 0.374770279533845, 0.9372599325940558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 171}], {
             RGBColor[
             0.25005732664065045`, 0.38015648322251344`, 0.9375517668742968]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 216}], {
             RGBColor[
             0.25212920477180323`, 0.3823341585030158, 0.9376697572687969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 281}], {
             RGBColor[
             0.2416405448941051, 0.37130991195210916`, 0.9370724436053437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 385}], {
             RGBColor[
             0.235922007593164, 0.36529936667261376`, 0.936746781365873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 391}], {
             RGBColor[
             0.23974982774210207`, 0.3693226483469626, 0.9369647700606025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 37}], {
             RGBColor[
             0.2800147441029785, 0.41164362838539204`, 0.9392577974807488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 58}], {
             RGBColor[
             0.28475051663686596`, 0.4160326690739975, 0.9395490426575464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 141}], {
             RGBColor[
             0.28198608489330845`, 0.4136382572421074, 0.9393728955113378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 240}], {
             RGBColor[
             0.25550742159800177`, 0.3858848785786683, 0.9378621417194251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 251}], {
             RGBColor[
             0.25646724614478844`, 0.3868937150337323, 0.9379168023074314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 310}], {
             RGBColor[
             0.2755731801551128, 0.4069752630647657, 0.9390048569846228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 352}], {
             RGBColor[
             0.2411100918235177, 0.37075237214225454`, 0.9370422350877088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 367}], {
             RGBColor[
             0.2421171751521342, 0.3718108805734015, 0.9370995869934273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 382}], {
             RGBColor[
             0.26830699274776615`, 0.39933803939675394`, 0.9385910583611354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 399}], {
             RGBColor[
             0.24794512185068096`, 0.37793642206673694`, 0.937431479936235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 412}], {
             RGBColor[
             0.24838538806776134`, 0.3783991697753788, 0.9374565524459821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 416}], {
             RGBColor[
             0.2579614870777197, 0.3884642569945902, 0.9380018971180304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 429}], {
             RGBColor[
             0.2739936283843697, 0.4053150540043482, 0.9389149038480165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 58}], {
             RGBColor[
             0.31037597127891847`, 0.44296664665046, 0.9410083743899482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 118}], {
             RGBColor[
             0.31537415178862416`, 0.44729581939211016`, 0.9413268540323092]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 141}], {
             RGBColor[
             0.3076115395353609, 0.4405722348185699, 0.9408322272437397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 188}], {
             RGBColor[
             0.3214586719550145, 0.4525659249433619, 0.9417145542769817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 240}], {
             RGBColor[
             0.28113287624005423`, 0.4128188561551308, 0.9393214734518269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 304}], {
             RGBColor[
             0.32210212279026273`, 0.45312324971607465`, 0.9417555543952225]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 310}], {
             RGBColor[
             0.30119863479716524`, 0.4339092406412282, 0.9404641887170249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 429}], {
             RGBColor[
             0.29961908302642226`, 0.4322490315808106, 0.9403742355804184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 47}], {
             RGBColor[
             0.24595116399713765`, 0.375840645938433, 0.9373179269862719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 73}], {
             RGBColor[
             0.25393957190424143`, 0.3842369691431141, 0.937772854998791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 93}], {
             RGBColor[
             0.2646269773927557, 0.3954701099321881, 0.9383814869307624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 108}], {
             RGBColor[
             0.272539685244709, 0.40378686757924537`, 0.9388321039371288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 163}], {
             RGBColor[
             0.2634804930859057, 0.3942650822343853, 0.9383161963455589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 189}], {
             RGBColor[
             0.2598720197723208, 0.3904723479913851, 0.9381106991286081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 266}], {
             RGBColor[
             0.27474470932625494`, 0.40610448769555174`, 0.9389576767965321]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 364}], {
             RGBColor[
             0.2592676752099878, 0.3898371435387148, 0.9380762825998308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 437}], {
             RGBColor[
             0.2578995688543769, 0.3883991770160148, 0.9379983709668107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 45}], {
             RGBColor[
             0.45322202962692537`, 0.5599541419213354, 0.9514657433370749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 100}], {
             RGBColor[
             0.7774382200691679, 0.7351762203070193, 0.6135140654406412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 127}], {
             RGBColor[
             0.4248206994263658, 0.5301025431322064, 0.9498483295981558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 179}], {
             RGBColor[
             0.40129536230508595`, 0.5053759222252174, 0.9485085964517164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 200}], {
             RGBColor[
             0.7622447974505207, 0.6739602832535388, 0.6012384342096092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 213}], {
             RGBColor[
             0.7639337426080279, 0.681629388750616, 0.6026477314488674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 236}], {
             RGBColor[
             0.4554923722273556, 0.5623404159424226, 0.9515950359894985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 243}], {
             RGBColor[
             0.7314838484501698, 0.504242577778165, 0.5743944759737214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 254}], {
             RGBColor[
             0.43007991849913185`, 0.5356303158314321, 0.9501478343440324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 276}], {
             RGBColor[
             0.6216008719460259, 0.7036826165027719, 0.9633538441200625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 283}], {
             RGBColor[
             0.4024378733893724, 0.5065767738141891, 0.9485736607677728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 315}], {
             RGBColor[
             0.40458060190845924`, 0.5088289173445842, 0.948695685987052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 325}], {
             RGBColor[
             0.40133925395865816`, 0.5054220551360133, 0.9485110960164554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 368}], {
             RGBColor[
             0.5158816187650146, 0.6166272342584453, 0.9553704626805029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 401}], {
             RGBColor[
             0.6985569826136641, 0.7641508706261513, 0.9707851169753527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 450}], {
             RGBColor[
             0.7206850354992045, 0.4212381693670362, 0.5640535204963621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 454}], {
             RGBColor[
             0.761772006870989, 0.6718134516549312, 0.6008439261608904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 471}], {
             RGBColor[
             0.7402370852900231, 0.5715237918221177, 0.5827765854569318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 475}], {
             RGBColor[
             0.731332489294519, 0.5030791649818271, 0.5742495342753344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 114}], {
             RGBColor[
             0.443439320562669, 0.5572206362112937, 0.9498318505944043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 199}], {
             RGBColor[
             0.3645220176644419, 0.4901523831167798, 0.9444479985247825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 208}], {
             RGBColor[
             0.3541593410951509, 0.4811767535157284, 0.9437876979371422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 220}], {
             RGBColor[
             0.36255668140028763`, 0.48845010762544216`, 0.9443227690359091]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 289}], {
             RGBColor[
             0.41278560473143366`, 0.5319558764357888, 0.9475233116148768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 291}], {
             RGBColor[
             0.5205636488996574, 0.6196411124817705, 0.9560349926032045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 297}], {
             RGBColor[
             0.4527821832454718, 0.5648055930283604, 0.9505673549688282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 314}], {
             RGBColor[
             0.35813781501059505`, 0.484622707657373, 0.944041202777008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 349}], {
             RGBColor[
             0.3999008136180363, 0.5207957179817955, 0.9467023041187045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 359}], {
             RGBColor[
             0.38582570994179444`, 0.508604570612715, 0.9458054509585798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 371}], {
             RGBColor[
             0.37457203795785354`, 0.49885720556622565`, 0.9450883769309946]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 397}], {
             RGBColor[
             0.37237410523066483`, 0.4969534667092458, 0.9449483266011737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 419}], {
             RGBColor[
             0.44944534633244004`, 0.5620965984995714, 0.950304666943798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 472}], {
             RGBColor[
             0.35732343693452717`, 0.4839173342997152, 0.9439893113261273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 102}], {
             RGBColor[
             0.2545321161274702, 0.38485977069120125`, 0.9378065995157133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 186}], {
             RGBColor[
             0.23411854278577374`, 0.36340381081377343`, 0.9366440767130793]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 191}], {
             RGBColor[
             0.22546402831064583`, 0.35430736737250323`, 0.9361512149169275]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 202}], {
             RGBColor[
             0.2357918679274276, 0.3651625816325934, 0.9367393701044336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 212}], {
             RGBColor[
             0.22552146354030395`, 0.35436773544047784`, 0.9361544857682886]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 295}], {
             RGBColor[
             0.23105727915165333`, 0.3601862286389881, 0.9364697422778497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 300}], {
             RGBColor[
             0.22924216126039493`, 0.3582784246501542, 0.9363663739991688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 389}], {
             RGBColor[
             0.2255132290582107, 0.3543590804777015, 0.9361540168267153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 451}], {
             RGBColor[
             0.22198624668627384`, 0.3506519983811976, 0.9359531603983363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 456}], {
             RGBColor[
             0.22809260204387605`, 0.3570701650273288, 0.9363009083024085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 485}], {
             RGBColor[
             0.24026393309017596`, 0.36986300566395003`, 0.9369940475996247]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 85}], {
             RGBColor[
             0.22334491181980198`, 0.3520800415808806, 0.9360305343677259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 95}], {
             RGBColor[
             0.2297785943922997, 0.3588422498836111, 0.9363969230724491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[
             0.23210438822814727`, 0.3612868066689332, 0.936529373590697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 137}], {
             RGBColor[
             0.22627740530250587`, 0.35516227816202806`, 0.9361975355333305]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 145}], {
             RGBColor[
             0.22656621784669417`, 0.3554658384577429, 0.9362139829804621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 174}], {
             RGBColor[
             0.2495656884148965, 0.3796397402755821, 0.9375237688046536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 248}], {
             RGBColor[
             0.2375069627028864, 0.3669652549848901, 0.9368370422146407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 286}], {
             RGBColor[
             0.2277872668823118, 0.3567492384131574, 0.9362835199166604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 294}], {
             RGBColor[
             0.23539350574473433`, 0.36474387772096156`, 0.9367166839674533]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 346}], {
             RGBColor[
             0.22517846281523107`, 0.3540072199309242, 0.9361349523844199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 358}], {
             RGBColor[
             0.22905024080537584`, 0.3580767040834695, 0.9363554444131764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 407}], {
             RGBColor[
             0.22341630550160935`, 0.352155080867081, 0.9360346001322872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 411}], {
             RGBColor[
             0.23603211668449622`, 0.3654150983089235, 0.9367530519157325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 430}], {
             RGBColor[
             0.2361066473396595, 0.36549343475301654`, 0.9367572963262859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 110}], {
             RGBColor[
             0.2824315567297242, 0.4141838516908727, 0.9393954313844881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 217}], {
             RGBColor[
             0.30643378623989703`, 0.43839711764350564`, 0.9407994722898634]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 290}], {
             RGBColor[
             0.2898165263474991, 0.4219459229932718, 0.9398159944791369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 316}], {
             RGBColor[
             0.2718214258604257, 0.4030319314260883, 0.9387912001277635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 340}], {
             RGBColor[
             0.31529118717805316`, 0.446068953150221, 0.9413638580453506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 355}], {
             RGBColor[
             0.3109273076150301, 0.4422891800076947, 0.941085795498422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 362}], {
             RGBColor[
             0.34080467652755875`, 0.4681674552795022, 0.9429895550260083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 378}], {
             RGBColor[
             0.2881161193118442, 0.42015868738676554`, 0.939719158813983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 384}], {
             RGBColor[
             0.28848430619933074`, 0.4205456751499109, 0.9397401265125418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 57}], {
             RGBColor[
             0.5489601186307986, 0.6447095805328258, 0.9576352979272409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 106}], {
             RGBColor[
             0.5072662938524296, 0.6108606552923443, 0.9543530073111751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 117}], {
             RGBColor[
             0.4388762614701655, 0.5533769866678013, 0.9495110781480034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 139}], {
             RGBColor[
             0.5303562146824653, 0.6296060932112468, 0.9561707304600824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 140}], {
             RGBColor[
             0.4981556569200065, 0.6034642298010868, 0.9536357845984921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 247}], {
             RGBColor[
             0.4958443155073958, 0.6015877787175854, 0.9534538273357688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 255}], {
             RGBColor[
             0.44713138767076954`, 0.5605271620680575, 0.9500370874897843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 269}], {
             RGBColor[
             0.4728082951441619, 0.5827672087626157, 0.9516731973287911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 360}], {
             RGBColor[
             0.5380217860131518, 0.6358293493475512, 0.9567741923151472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 369}], {
             RGBColor[
             0.4583123366675063, 0.5702115381181944, 0.9507495276729314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 370}], {
             RGBColor[
             0.5440602935407461, 0.6407316817901163, 0.9572495657475013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 425}], {
             RGBColor[
             0.43601004951768985`, 0.5508944179345684, 0.9493284456568833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 466}], {
             RGBColor[
             0.5000927113166715, 0.6050368178236056, 0.9537882766162615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 468}], {
             RGBColor[
             0.48752713657842917`, 0.5948355181784093, 0.9527990685436503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 52}], {
             RGBColor[
             0.5592887582023336, 0.3453473306953461, 0.5606630483713451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 56}], {
             RGBColor[
             0.5597280401148761, 0.3487238439697099, 0.5610837052268939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 179}], {
             RGBColor[
             0.2308558043838454, 0.3599744658837838, 0.9364582685878783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 236}], {
             RGBColor[
             0.285052814306115, 0.4169389596009889, 0.9395447081256605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 243}], {
             RGBColor[
             0.5610442905289292, 0.35884112143673136`, 0.5623441481098833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 254}], {
             RGBColor[
             0.25964036057789125`, 0.3902288594899984, 0.9380975064801944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 276}], {
             RGBColor[
             0.4511613140247853, 0.5582811601613382, 0.9513035162562244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 283}], {
             RGBColor[
             0.23199831546813182`, 0.3611753174727555, 0.9365233329039347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 292}], {
             RGBColor[
             0.23087655194201073`, 0.35999627288288677`, 0.9364594501306225]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 386}], {
             RGBColor[
             0.23085473585284239`, 0.35997334278995086`, 0.9364582077366184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 422}], {
             RGBColor[
             0.2583972380161019, 0.3889222588590351, 0.9380267124893356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 53}], {
             RGBColor[
             0.9470835767696775, 0.821834287485996, 0.3079282681448157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 68}], {
             RGBColor[
             0.8688206529626022, 0.4329330984324026, 0.20968686128144703`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 90}], {
             RGBColor[
             0.8912123121580973, 0.5950344530170778, 0.2307371435474895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 205}], {
             RGBColor[
             0.9557407049755898, 0.8502199530826348, 0.4110195083871594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 257}], {
             RGBColor[
             0.8882541401217813, 0.5816020846987996, 0.22826877228895565`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 272}], {
             RGBColor[
             0.8691188894851287, 0.4352254750326188, 0.20997245291222838`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 293}], {
             RGBColor[
             0.9359635798708703, 0.8383264425596675, 0.6074452935938994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 298}], {
             RGBColor[
             0.9096473304128414, 0.8178215341712867, 0.6215408826637097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 306}], {
             RGBColor[
             0.8876171805650555, 0.5774114462757728, 0.22768643734119767`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 317}], {
             RGBColor[
             0.9005275853462438, 0.6373329329271229, 0.23851003583391922`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 357}], {
             RGBColor[
             0.9123985653292456, 0.6903965335177349, 0.2483720332752017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 418}], {
             RGBColor[
             0.9480641688610301, 0.8473510420156326, 0.586962152772621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 420}], {
             RGBColor[
             0.9431488383406506, 0.8436851965616485, 0.5952825252201055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 55}], {
             RGBColor[
             0.22170565849658444`, 0.35035708240351526`, 0.9359371813160265]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 189}], {
             RGBColor[
             0.24585450838109163`, 0.3757390547576487, 0.9373124225919274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 230}], {
             RGBColor[
             0.22790583767600858`, 0.3568738638351552, 0.9362902723479516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 242}], {
             RGBColor[
             0.2284706396727983, 0.35746750654429615`, 0.9363224369861192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 339}], {
             RGBColor[
             0.22181216919966315`, 0.3504690319056196, 0.9359432469429985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 364}], {
             RGBColor[
             0.24525016381875867`, 0.3751038503049783, 0.93727800606315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 365}], {
             RGBColor[
             0.22445415871552787`, 0.3532459303986038, 0.9360937043374536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 374}], {
             RGBColor[
             0.24183198733731956`, 0.37151113009807946`, 0.9370833459692711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 437}], {
             RGBColor[
             0.2438820574631478, 0.37366588378227833`, 0.93720009443013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 78}], {
             RGBColor[
             0.21346998781254425`, 0.3417008703429085, 0.9354681720541533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 85}], {
             RGBColor[
             0.21086321568284044`, 0.3389609875556907, 0.9353197202377406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 95}], {
             RGBColor[
             0.21729689825533816`, 0.34572319585842115`, 0.9356861089424638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 137}], {
             RGBColor[
             0.21379570916554433`, 0.34204322413683813`, 0.9354867214033452]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 145}], {
             RGBColor[
             0.21408452170973263`, 0.34234678443255295`, 0.9355031688504769]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 183}], {
             RGBColor[
             0.20623910902756293`, 0.3341007582756985, 0.9350563842044752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 346}], {
             RGBColor[
             0.21269676667826953`, 0.34088816590573434`, 0.9354241382544346]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 358}], {
             RGBColor[
             0.2165685446684143, 0.3449576500582796, 0.9356446302831911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 404}], {
             RGBColor[
             0.21047959213928613`, 0.3385577748882776, 0.9352978734444553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 407}], {
             RGBColor[
             0.2109346093646478, 0.33903602684189116`, 0.935323786002302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 408}], {
             RGBColor[
             0.21500770505426564`, 0.34331710866086196`, 0.9355557427762207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 71}], {
             RGBColor[
             0.6229981269292593, 0.7030794824142605, 0.9646517716159538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 76}], {
             RGBColor[
             0.45077000854144356`, 0.5638542255344485, 0.9502204534950804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 238}], {
             RGBColor[
             0.4051843179606758, 0.5243701915568157, 0.9473157736011174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 328}], {
             RGBColor[
             0.4377638604952656, 0.5525889538048573, 0.9493917132424632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 402}], {
             RGBColor[
             0.521262974366249, 0.6222237910767345, 0.9554548772727531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 431}], {
             RGBColor[
             0.4693773227785792, 0.5799709458958486, 0.9514060951044689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 436}], {
             RGBColor[
             0.4815672646188717, 0.5899970256324685, 0.9523298855912635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 459}], {
             RGBColor[
             0.44038041665413563`, 0.554855283237734, 0.9495584378871766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 462}], {
             RGBColor[
             0.4770465403942916, 0.586326898050649, 0.9519739976203461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 487}], {
             RGBColor[
             0.5348230464505574, 0.633232468469062, 0.9565223758194106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 57}], {
             RGBColor[
             0.5210905073010532, 0.6217476292469348, 0.9555341779806428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 92}], {
             RGBColor[
             0.5250378077135244, 0.6249522255456361, 0.9558449239285502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 106}], {
             RGBColor[
             0.47939668252268425`, 0.5878987040064534, 0.9522518873645769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 117}], {
             RGBColor[
             0.41100665014042015`, 0.5304150353819104, 0.9474099582014052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 139}], {
             RGBColor[
             0.50248660335272, 0.6066441419253559, 0.9540696105134843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 140}], {
             RGBColor[
             0.47028604559026116`, 0.5805022785151959, 0.9515346646518938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 169}], {
             RGBColor[
             0.46684010556596744`, 0.5777047091656451, 0.9512633876302873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 204}], {
             RGBColor[
             0.47141553909134676`, 0.5814192522224795, 0.9516235825177704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 219}], {
             RGBColor[
             0.48360346312109975`, 0.5913139580095534, 0.9525830605432293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 244}], {
             RGBColor[
             0.3916895278498226, 0.5136835149605915, 0.9461790882505088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 255}], {
             RGBColor[
             0.41926177634102413`, 0.5375652107821666, 0.9479359675431862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 274}], {
             RGBColor[
             0.4518361438965558, 0.5655238171616463, 0.9500822208063486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 334}], {
             RGBColor[
             0.42187105269828507`, 0.539825234816783, 0.9481022283253784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 338}], {
             RGBColor[
             0.3805216773222415, 0.5040104841460892, 0.9454674826902338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 340}], {
             RGBColor[
             0.3891862943583425, 0.5115153399264449, 0.9460195844259542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 361}], {
             RGBColor[
             0.5425697371949871, 0.6391572117563517, 0.9572443985054486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 363}], {
             RGBColor[
             0.422874692158388, 0.5406945368727382, 0.9481661793442926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 369}], {
             RGBColor[
             0.43044272533776096`, 0.5472495868323034, 0.9486484077263333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 370}], {
             RGBColor[
             0.5161906822110007, 0.6177697305042253, 0.9551484458009031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 379}], {
             RGBColor[
             0.37511861305326666`, 0.49933062144220947`, 0.9451232042127569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[
             0.18179934664985797`, 0.3084130184462969, 0.9336645758924533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 113}], {
             RGBColor[
             0.17905963075308248`, 0.3055334033307651, 0.9335085531251784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 127}], {
             RGBColor[
             0.20245340605759676`, 0.3301217444268325, 0.9348407940207814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 130}], {
             RGBColor[
             0.1789270004053139, 0.3053940004260106, 0.9335010000230821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 143}], {
             RGBColor[
             0.17892700107920537`, 0.30539400113431325`, 0.9335010000614592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 179}], {
             RGBColor[
             0.1789280689363169, 0.30539512351984355`, 0.9335010608743419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 214}], {
             RGBColor[
             0.1893670578318586, 0.31636716271918164`, 0.9340955458488429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 302}], {
             RGBColor[
             0.18453817957609825`, 0.31129170550381263`, 0.9338205483758626]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 308}], {
             RGBColor[
             0.1789366427891193, 0.3054041351827525, 0.9335015491425751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 315}], {
             RGBColor[
             0.1822133085396902, 0.30884811863921036`, 0.9336881504096776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 325}], {
             RGBColor[
             0.17897196058988912`, 0.30544125643063946`, 0.933503560439081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 347}], {
             RGBColor[
             0.1789270004053139, 0.3053940004260106, 0.9335010000230821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 386}], {
             RGBColor[
             0.1789270004053139, 0.3053940004260106, 0.9335010000230821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 421}], {
             RGBColor[
             0.17899180329589925`, 0.30546211237275633`, 0.9335046904518336]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 423}], {
             RGBColor[
             0.18337644614132015`, 0.31007065000570677`, 0.9337543893753826]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 477}], {
             RGBColor[
             0.21179931412463662`, 0.3399448863700877, 0.9353730296591674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 56}], {
             RGBColor[
             0.836234326611525, 0.27951848908515425`, 0.18233133812500216`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 88}], {
             RGBColor[
             0.8512025856554928, 0.3816657696999445, 0.19615962002028325`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 166}], {
             RGBColor[
             0.8369577282992072, 0.2850788714533209, 0.18302406839809204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 210}], {
             RGBColor[
             0.8359293793650189, 0.2771745309197725, 0.1820393202973592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 227}], {
             RGBColor[
             0.8407131059122084, 0.31394434940381033`, 0.18662022224139424`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 236}], {
             RGBColor[
             0.5615591008027638, 0.3477336047164332, 0.5607923410237687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 243}], {
             RGBColor[
             0.837550577025578, 0.2896357665521757, 0.18359178100799164`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 276}], {
             RGBColor[
             0.7276676005214341, 0.4890758052767825, 0.5725511491543327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 326}], {
             RGBColor[
             0.8554852780065134, 0.4011124754177182, 0.19973320349637064`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 428}], {
             RGBColor[
             0.8330642703587228, 0.25515204759860854`, 0.17929568867725226`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 469}], {
             RGBColor[
             0.8481128613393234, 0.36763605320366755`, 0.19358147831479822`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 495}], {
             RGBColor[
             0.8389987580384334, 0.3007671204139477, 0.18497856078138836`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 90}], {
             RGBColor[
             0.9206410418975434, 0.7056328015929743, 0.28606405077970154`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 178}], {
             RGBColor[
             0.9840984713626098, 0.9616310168446078, 0.5753629014776818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 257}], {
             RGBColor[
             0.9176828698612274, 0.692200433274696, 0.28359567952116765`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 272}], {
             RGBColor[
             0.8985476192245749, 0.5458238236085153, 0.2652993601444404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[
             0.9653923096103165, 0.9489247911355639, 0.6627722008261114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 298}], {
             RGBColor[
             0.9390760601522875, 0.9284198827471832, 0.6768677898959217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 306}], {
             RGBColor[
             0.9170459103045016, 0.6880097948516692, 0.28301334457340965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 317}], {
             RGBColor[
             0.9299563150856899, 0.7479312815030192, 0.29383694306613123`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 357}], {
             RGBColor[
             0.9418272950686917, 0.8009948820936315, 0.3036989405074137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 418}], {
             RGBColor[
             0.9774928986004763, 0.9579493905915291, 0.642289060004833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 420}], {
             RGBColor[
             0.9725775680800968, 0.9542835451375451, 0.6506094324523175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 432}], {
             RGBColor[
             0.9375683877182548, 0.9272177056729635, 0.6767239867532486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 55}], {
             RGBColor[
             0.22009923076516985`, 0.34866862500439766`, 0.9358456976332195]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 70}], {
             RGBColor[
             0.24348548029858347`, 0.3732490560378767, 0.9371775099472914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 84}], {
             RGBColor[
             0.23101754524273913`, 0.3601444657814439, 0.9364674794905181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 131}], {
             RGBColor[
             0.24616492351091418`, 0.3760653207405481, 0.9373301002743527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 135}], {
             RGBColor[
             0.23967378277683635`, 0.36924272026693905`, 0.9369604394123292]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 147}], {
             RGBColor[
             0.2401069833110282, 0.36969804149487495`, 0.9369851095418886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 230}], {
             RGBColor[
             0.22629940994459397`, 0.3551854064360376, 0.9361987886651444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 242}], {
             RGBColor[
             0.22686421194138368`, 0.35577904914517844`, 0.936230953303312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 365}], {
             RGBColor[
             0.22284773098411328`, 0.35155747299948614`, 0.9360022206546466]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 374}], {
             RGBColor[
             0.24022555960590497`, 0.3698226726989618, 0.9369918622864639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 385}], {
             RGBColor[
             0.23109619211781043`, 0.36022712863364376`, 0.9364719583137058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 391}], {
             RGBColor[
             0.23492401226674847`, 0.36425041030799266`, 0.9366899470084354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 230}], {
             RGBColor[
             0.21767784356668446`, 0.34612359353397393`, 0.935707803214387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 242}], {
             RGBColor[
             0.21824264556347417`, 0.34671723624311485`, 0.9357399678525544]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 250}], {
             RGBColor[
             0.20796149957955015`, 0.33591109995170554`, 0.9351544717983624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 339}], {
             RGBColor[
             0.21158417509033906`, 0.33971876160443837`, 0.9353607778094337]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 365}], {
             RGBColor[
             0.21422616460620378`, 0.3424956600974225, 0.935511235203889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 88}], {
             RGBColor[
             0.8516418675680354, 0.38504228297430826`, 0.19658027687583196`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 164}], {
             RGBColor[
             0.8270991589089857, 0.20930158706742483`, 0.17358349121635427`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 166}], {
             RGBColor[
             0.8373970102117498, 0.28845538472768467`, 0.18344472525364075`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 210}], {
             RGBColor[
             0.8363686612775614, 0.28055104419413623`, 0.18245997715290796`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 227}], {
             RGBColor[
             0.8411523878247509, 0.31732086267817405`, 0.187040879096943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 236}], {
             RGBColor[
             0.5619983827153064, 0.35111011799079705`, 0.5612129978793174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 243}], {
             RGBColor[
             0.8379898589381207, 0.2930122798265395, 0.18401243786354038`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 276}], {
             RGBColor[
             0.7281068824339767, 0.4924523185511463, 0.5729718060098814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 326}], {
             RGBColor[
             0.8559245599190561, 0.404488988692082, 0.2001538603519194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 428}], {
             RGBColor[
             0.8335035522712653, 0.25852856087297227`, 0.179716345532801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 495}], {
             RGBColor[
             0.839438039950976, 0.30414363368831143`, 0.18539921763693712`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 92}], {
             RGBColor[
             0.6051902881840892, 0.690359765316458, 0.9620619428523739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 106}], {
             RGBColor[
             0.5595491629932491, 0.6533062437772754, 0.9584689062884005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 139}], {
             RGBColor[
             0.5826390838232848, 0.6720516816961779, 0.9602866294373078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 140}], {
             RGBColor[
             0.550438526060826, 0.6459098182860178, 0.9577516835757175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 169}], {
             RGBColor[
             0.5469925860365322, 0.6431122489364671, 0.9574804065541109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 175}], {
             RGBColor[
             0.7784866261079177, 0.8268297266210345, 0.9607862455954495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 204}], {
             RGBColor[
             0.5515680195619116, 0.6468267919933015, 0.9578406014415939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 219}], {
             RGBColor[
             0.5637559435916646, 0.6567214977803754, 0.9588000794670529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 255}], {
             RGBColor[
             0.499414256811589, 0.6029727505529885, 0.9541529864670097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 274}], {
             RGBColor[
             0.5319886243671207, 0.6309313569324684, 0.9562992397301722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 334}], {
             RGBColor[
             0.5020235331688498, 0.6052327745876049, 0.9543192472492019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 337}], {
             RGBColor[
             0.730726843956438, 0.7892639238928545, 0.9741400277373693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 361}], {
             RGBColor[
             0.622722217665552, 0.7045647515271736, 0.9634614174292722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 363}], {
             RGBColor[
             0.5030271726289528, 0.6061020766435601, 0.9543831982681161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 369}], {
             RGBColor[
             0.5105952058083258, 0.6126571266031253, 0.9548654266501568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 370}], {
             RGBColor[
             0.5963431626815656, 0.6831772702750474, 0.9613654647247267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 466}], {
             RGBColor[
             0.552375580457491, 0.6474824063085367, 0.957904175593487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 118}], {
             RGBColor[
             0.3201099243225116, 0.4516848600807156, 0.9416180992091068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 141}], {
             RGBColor[
             0.3123473120692484, 0.44496127550717535`, 0.9411234724205373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 188}], {
             RGBColor[
             0.32619444448890195`, 0.45695496563196736`, 0.9420057994537792]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 220}], {
             RGBColor[
             0.32701247471585293`, 0.45766350229915764`, 0.9420579236164848]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 240}], {
             RGBColor[
             0.2858686487739417, 0.41720789684373627`, 0.9396127186286245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 304}], {
             RGBColor[
             0.3268378953241502, 0.4575122904046801, 0.94204679957202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 310}], {
             RGBColor[
             0.3059344073310527, 0.43829828132983367`, 0.9407554338938223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 371}], {
             RGBColor[
             0.3390278312734188, 0.4680706002399412, 0.9428235315115703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 382}], {
             RGBColor[
             0.2986682199237062, 0.43066105766182183`, 0.9403416352703349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 429}], {
             RGBColor[
             0.3043548555603097, 0.4366380722694161, 0.9406654807572159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 74}], {
             RGBColor[
             0.26196255890659237`, 0.3926696371693413, 0.9382297522396293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 82}], {
             RGBColor[
             0.25023486400687867`, 0.3803430862509384, 0.9375618773646605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 105}], {
             RGBColor[
             0.2440481876886619, 0.3738404971825583, 0.9372095553007055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 153}], {
             RGBColor[
             0.24356203444566857`, 0.3733295193002764, 0.9371818695927163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 195}], {
             RGBColor[
             0.2561715150223729, 0.3865828828736374, 0.9378999608575047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 263}], {
             RGBColor[
             0.25779587834217144`, 0.38829019171332857`, 0.9379924659455371]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 323}], {
             RGBColor[
             0.24076788547771533`, 0.3703926915756808, 0.9370227469425643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 342}], {
             RGBColor[
             0.25108912406320616`, 0.3812409677333546, 0.9376105262111039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 395}], {
             RGBColor[
             0.2535893388235434, 0.38386885196924064`, 0.9377529097429688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 447}], {
             RGBColor[
             0.2443455259866942, 0.3741530185861272, 0.9372264882769058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 453}], {
             RGBColor[
             0.26324896867774317`, 0.3940217354019111, 0.9383030113730237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 463}], {
             RGBColor[
             0.2546442329532448, 0.38497761258370766`, 0.9378129844030793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 116}], {
             RGBColor[
             0.27071777339856856`, 0.4018719227130688, 0.9387283487527682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 118}], {
             RGBColor[
             0.30890885152103453`, 0.4405003788871604, 0.9409586647466246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 133}], {
             RGBColor[
             0.31894163191943015`, 0.44919026900604586`, 0.9415979446419711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 151}], {
             RGBColor[
             0.2997519610227203, 0.4323886947798715, 0.9403818027857322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 188}], {
             RGBColor[
             0.31499337168742486`, 0.44577048443841216`, 0.9413463649912971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 192}], {
             RGBColor[
             0.2736621188386635, 0.4049666164528918, 0.9388960248698129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 249}], {
             RGBColor[
             0.29112873348308044`, 0.42332513589150556`, 0.9398907227342717]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 260}], {
             RGBColor[
             0.2891430137819674, 0.4212380185837349, 0.9397776389349024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 280}], {
             RGBColor[
             0.2748009878347767, 0.4061636399762716, 0.9389608817743358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 310}], {
             RGBColor[
             0.2947333345295756, 0.4271138001362785, 0.9400959994313403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 327}], {
             RGBColor[
             0.27488937913222444`, 0.40625654483422113`, 0.9389659155279624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 483}], {
             RGBColor[
             0.29467938491288026`, 0.4270570956685284, 0.9400929270804808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 64}], {
             RGBColor[
             0.3058305702683475, 0.43738338551197825`, 0.9407790232185906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 91}], {
             RGBColor[
             0.32572776888358806`, 0.4565507546784424, 0.9419760632968737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 172}], {
             RGBColor[
             0.3377395733706075, 0.4669547759942509, 0.9427414448571648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 303}], {
             RGBColor[
             0.31454260624684305`, 0.4465402877003618, 0.9412751607792637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 362}], {
             RGBColor[
             0.3561441161626767, 0.48289586592152384`, 0.9439141660493773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 384}], {
             RGBColor[
             0.3038237458344487, 0.43527408579193255`, 0.9406647375359107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 435}], {
             RGBColor[
             0.2909721876561818, 0.42176628331072286`, 0.9399328603098349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 473}], {
             RGBColor[
             0.3253289757704718, 0.4562053401277858, 0.9419506525523447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 132}], {
             RGBColor[
             0.9037259559281465, 0.5621573598635239, 0.4887023579770914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 209}], {
             RGBColor[
             0.6916212861064526, 0.39630413817282756`, 0.5615943615662011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 233}], {
             RGBColor[
             0.8302393984490122, 0.2334388442338099, 0.17659058814627704`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 75}], {
             RGBColor[
             0.38214205273411095`, 0.5054139718854141, 0.9455707315786365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 149}], {
             RGBColor[
             0.3866051837093468, 0.5092797116126782, 0.9458551183377868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 158}], {
             RGBColor[
             0.38842846253649266`, 0.5108589440920934, 0.9459712960523903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 165}], {
             RGBColor[
             0.42168442508772075`, 0.5396635873606885, 0.9480903365790616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 182}], {
             RGBColor[
             0.3989611276124065, 0.5199818091937107, 0.9466424281573576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 206}], {
             RGBColor[
             0.3810348762200533, 0.5044549912372471, 0.9455001832701985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 252}], {
             RGBColor[
             0.5775658026497799, 0.6655789256820774, 0.9611207995905398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 275}], {
             RGBColor[
             0.41651977831287657`, 0.5351902299070133, 0.9477612498534863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 282}], {
             RGBColor[
             0.5134969921724348, 0.6149963149023026, 0.9550984560118821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 324}], {
             RGBColor[
             0.3945065223315428, 0.5161234539943981, 0.9463585846479137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 410}], {
             RGBColor[
             0.39150030357105375`, 0.5135196184010107, 0.9461670310467902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 441}], {
             RGBColor[
             0.4347339982883702, 0.5509664717764713, 0.9489218438441225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 467}], {
             RGBColor[
             0.563087381667329, 0.6542682731705118, 0.9596777258955458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 91}], {
             RGBColor[
             0.3077316474117898, 0.43903000298271255`, 0.9409001581731142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 172}], {
             RGBColor[
             0.31974345189880926`, 0.449434024298521, 0.9416655397334055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 303}], {
             RGBColor[
             0.29654648477504475`, 0.4290195360046319, 0.9401992556555043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 366}], {
             RGBColor[
             0.27642037277284975`, 0.4078657162211217, 0.9390531033508938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 384}], {
             RGBColor[
             0.28582762436265047`, 0.41775333409620263`, 0.9395888324121513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 435}], {
             RGBColor[
             0.2729760661843835, 0.4042455316149929, 0.9388569551860756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 473}], {
             RGBColor[
             0.3073328542986736, 0.43868458843205593`, 0.9408747474285853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 88}], {
             RGBColor[
             0.9260374771709088, 0.7249105779401631, 0.30422129427437533`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 166}], {
             RGBColor[
             0.9117926198146232, 0.6283236796935395, 0.2910857426521841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 167}], {
             RGBColor[
             0.986067541242265, 0.9756937071602725, 0.6343029674871418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 175}], {
             RGBColor[
             0.9705975460870158, 0.9645679382577699, 0.6789276620320353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[
             0.9107642708804349, 0.6204193391599911, 0.29010099455145133`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 227}], {
             RGBColor[
             0.9155479974276244, 0.657189157644029, 0.2946818964954864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 309}], {
             RGBColor[
             0.9892477963467572, 0.9750667140916796, 0.4404269945442838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 320}], {
             RGBColor[
             0.9870336626851595, 0.9760932232050978, 0.618291834936235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 337}], {
             RGBColor[
             0.9228377639355362, 0.92700213552959, 0.6922814441739551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 348}], {
             RGBColor[
             0.9726882187211612, 0.9195330900145834, 0.3483993164391773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 428}], {
             RGBColor[
             0.9078991618741388, 0.5983968558388272, 0.2873573629313444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 434}], {
             RGBColor[
             0.9883337030612244, 0.9766308233101144, 0.5967468015081936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 474}], {
             RGBColor[
             0.989280991001634, 0.9770225512176633, 0.5810477888330006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 495}], {
             RGBColor[
             0.9138336495538494, 0.6440119286541663, 0.2930402350354805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 208}], {
             RGBColor[
             0.2926997987840062, 0.4237400438284219, 0.9400254625551399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 305}], {
             RGBColor[
             0.25719647261268064`, 0.38766017828711546`, 0.9379583306759838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 314}], {
             RGBColor[
             0.29667827269945046`, 0.4271859979700665, 0.9402789673950056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 394}], {
             RGBColor[
             0.24596177604056546`, 0.3758517998689181, 0.937318531326446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 398}], {
             RGBColor[
             0.26221606410223275`, 0.392936087203117, 0.9382441889854937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 427}], {
             RGBColor[
             0.271390600085227, 0.40257910622042264`, 0.9387666652372155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 445}], {
             RGBColor[
             0.24646019520379875`, 0.3763756700110764, 0.9373469155604471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 460}], {
             RGBColor[
             0.2558136629427209, 0.38620675764879087`, 0.9378795817109632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 472}], {
             RGBColor[
             0.29586389462338253`, 0.42648062461240877`, 0.9402270759441249]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 70}], {
             RGBColor[
             0.25743661729140077`, 0.3879125855705024, 0.9379720065601748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 96}], {
             RGBColor[
             0.2763924027630132, 0.4078363179673825, 0.9390515105002115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 131}], {
             RGBColor[
             0.2601160605037315, 0.39072885027317383`, 0.938124596887236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 135}], {
             RGBColor[
             0.2536249197696536, 0.3839062497995648, 0.9377549360252124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 147}], {
             RGBColor[
             0.2540581203038455, 0.3843615710275007, 0.9377796061547718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 171}], {
             RGBColor[
             0.25918264815811415`, 0.38974777471616917`, 0.9380714404350129]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 180}], {
             RGBColor[
             0.26337700695553745`, 0.3941563117499686, 0.9383103029635284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 216}], {
             RGBColor[
             0.26125452628926693`, 0.3919254499966715, 0.938189430829513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 238}], {
             RGBColor[
             0.28838849579729153`, 0.41939023215024707`, 0.9397732894571003]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 281}], {
             RGBColor[
             0.25076586641156884`, 0.38090120344576484`, 0.93759211716606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 343}], {
             RGBColor[
             0.2747552896997584, 0.40611560833893834`, 0.9389582793331509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 385}], {
             RGBColor[
             0.24504732911062774`, 0.37489065816626943`, 0.9372664549265891]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 391}], {
             RGBColor[
             0.24887514925956578`, 0.37891393984061833`, 0.9374844436213188]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 465}], {
             RGBColor[
             0.26962432665641767`, 0.4007226408585406, 0.9386660785784122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 205}], {
             RGBColor[
             0.9069065109079608, 0.5719171126049378, 0.3681050087560027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 257}], {
             RGBColor[
             0.8394199460541523, 0.30329924422110266`, 0.18535427265779897`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 272}], {
             RGBColor[
             0.8202846954174998, 0.15692263455492186`, 0.1670579532810717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 306}], {
             RGBColor[
             0.8387829864974263, 0.2991086057980758, 0.18477193771004097`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 317}], {
             RGBColor[
             0.8516933912786147, 0.35903009244942585`, 0.19559553620276254`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 142}], {
             RGBColor[
             0.8044934065793106, 0.8479188521576653, 0.9809561216743297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 173}], {
             RGBColor[
             0.9470127321552729, 0.9592645667466908, 0.9483609186014075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 194}], {
             RGBColor[
             0.9479892988678673, 0.9596684021789683, 0.9321766809000795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 241}], {
             RGBColor[
             0.8074723242442312, 0.8502460052781141, 0.9812530323476005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 388}], {
             RGBColor[
             0.9278173046721767, 0.9450102776472538, 0.9836136557859578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 402}], {
             RGBColor[
             0.7308868707375382, 0.7890374499881754, 0.9745628249690335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 461}], {
             RGBColor[
             0.926959006974305, 0.9443701606295145, 0.985066529908563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 487}], {
             RGBColor[
             0.7444469428218465, 0.8000461273805028, 0.9756303235156909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 490}], {
             RGBColor[
             0.9500080335378767, 0.9605032008441318, 0.8987210231001681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 84}], {
             RGBColor[
             0.24578222839824324`, 0.37566308391285935`, 0.9373083063538328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 96}], {
             RGBColor[
             0.2772059489257, 0.4086914065661722, 0.9390978407506428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 131}], {
             RGBColor[
             0.2609296066664183, 0.3915839388719636, 0.9381709271376673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 135}], {
             RGBColor[
             0.25443846593234043`, 0.3847613383983545, 0.9378012662756438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 147}], {
             RGBColor[
             0.2548716664665323, 0.3852166596262904, 0.9378259364052033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 170}], {
             RGBColor[
             0.2774653661360603, 0.408964070502262, 0.9391126141769994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 171}], {
             RGBColor[
             0.25999619432080096`, 0.39060286331495886`, 0.9381177706854442]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 216}], {
             RGBColor[
             0.26206807245195374`, 0.39278053859546125`, 0.9382357610799443]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[
             0.28920204195997834`, 0.42024532074903687`, 0.9398196197075317]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 265}], {
             RGBColor[
             0.28963233444531233`, 0.42061801847270397`, 0.9398470375642044]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 374}], {
             RGBColor[
             0.2549902427614091, 0.38534129083037727`, 0.9378326891497786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 385}], {
             RGBColor[
             0.24586087527331454`, 0.37574574676505923`, 0.9373127851770204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 391}], {
             RGBColor[
             0.24968869542225258`, 0.3797690284394081, 0.93753077387175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 433}], {
             RGBColor[
             0.2918782074405654, 0.4225632807803333, 0.9399901426055144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 194}], {
             RGBColor[
             0.8711488139703549, 0.898916809896938, 0.9247098602219754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 228}], {
             RGBColor[
             0.8744314209010298, 0.8983757407693698, 0.7323068273714743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 388}], {
             RGBColor[
             0.8509768197746642, 0.8842586853652235, 0.9761468351078537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 431}], {
             RGBColor[
             0.602160734252356, 0.6860330125252593, 0.9630472221226452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 462}], {
             RGBColor[
             0.6098299518680684, 0.6923889646800596, 0.9636151246385223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 487}], {
             RGBColor[
             0.6676064579243342, 0.7392945350984725, 0.9681635028375868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 490}], {
             RGBColor[
             0.8731675486403643, 0.8997516085621015, 0.891254202422064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 73}], {
             RGBColor[
             0.2509474629421924, 0.38109207291333524`, 0.9376024588198308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 144}], {
             RGBColor[
             0.2501061102631632, 0.3802077579028347, 0.93755454502943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 163}], {
             RGBColor[
             0.26048838412385666`, 0.3911201860046064, 0.9381458001665987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 187}], {
             RGBColor[
             0.2593062768219157, 0.38987771628033463`, 0.9380784809045242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 279}], {
             RGBColor[
             0.26627234056032795`, 0.3971994909433567, 0.9384751879290589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 322}], {
             RGBColor[
             0.25660150329804876`, 0.38703482781420406`, 0.9379244480536938]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 494}], {
             RGBColor[
             0.25624399533436604`, 0.3866590642770594, 0.9379040885040477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 93}], {
             RGBColor[
             0.2585978739086303, 0.3891331399031328, 0.9380381384066008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 163}], {
             RGBColor[
             0.2574513896017804, 0.3879281122053299, 0.9379728478213971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 187}], {
             RGBColor[
             0.25626928229983936`, 0.38668564248105813`, 0.9379055285593227]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 322}], {
             RGBColor[
             0.2535645087759725, 0.3838427540149276, 0.9377514957084923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 494}], {
             RGBColor[
             0.25320700081228975`, 0.383466990477783, 0.9377311361588463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 82}], {
             RGBColor[
             0.27000631808527487`, 0.401124138069925, 0.93868783242518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 105}], {
             RGBColor[
             0.2638196417670582, 0.3946215490015449, 0.938335510361225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 112}], {
             RGBColor[
             0.264998769293781, 0.3958608867931338, 0.938402659929509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 153}], {
             RGBColor[
             0.2633334885240648, 0.39411057111926295`, 0.9383078246532357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 195}], {
             RGBColor[
             0.27594296910076915`, 0.40736393469262394`, 0.9390259159180243]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 224}], {
             RGBColor[
             0.2903501525391211, 0.42250679795452123`, 0.9398463837013205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 234}], {
             RGBColor[
             0.335156328175214, 0.4622198560830736, 0.94266828637108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 239}], {
             RGBColor[
             0.31633226480045645`, 0.4459153985127936, 0.9414688336983061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 263}], {
             RGBColor[
             0.27756733242056764`, 0.40907124353231517`, 0.9391184210060566]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 296}], {
             RGBColor[
             0.2975769167094639, 0.42967045866758025`, 0.9402737595026511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 342}], {
             RGBColor[
             0.27086057814160247`, 0.4020220195523411, 0.9387364812716233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 395}], {
             RGBColor[
             0.2733607929019397, 0.4046499037882272, 0.9388788648034883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 440}], {
             RGBColor[
             0.2817039259800564, 0.4134190656385177, 0.9393539938897277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 447}], {
             RGBColor[
             0.26411698006509043`, 0.39493407040511375`, 0.9383524433374253]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 453}], {
             RGBColor[
             0.2830204227561394, 0.41480278722089764`, 0.9394289664335431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 463}], {
             RGBColor[
             0.2744156870316411, 0.4057586644026942, 0.9389389394635987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 93}], {
             RGBColor[
             0.30711689507265494`, 0.43678253795558514`, 0.940923781155411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 108}], {
             RGBColor[
             0.31502960292460824`, 0.4450992956026424, 0.9413743981617775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 149}], {
             RGBColor[
             0.3494116417234011, 0.4770645349462275, 0.9434851787314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 158}], {
             RGBColor[
             0.3512349205505469, 0.4786437674256428, 0.9436013564460036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.3059704107658049, 0.43557751025778224`, 0.9408584905702073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 182}], {
             RGBColor[
             0.3617675856264607, 0.48776663252726005`, 0.9442724885509708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 206}], {
             RGBColor[
             0.34384133423410757`, 0.4722398145707964, 0.9431302436638118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 410}], {
             RGBColor[
             0.354306761585108, 0.48130444173456, 0.9437970914404035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.3537435180123586, 0.4796530871235497, 0.9438038035415315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[
             0.35693445553108405`, 0.4830069647728541, 0.9439855227126539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 238}], {
             RGBColor[
             0.36573961104663694`, 0.49120700130641426`, 0.9445255824984202]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 333}], {
             RGBColor[
             0.3949872182942583, 0.5165398086768207, 0.9463892141695951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 343}], {
             RGBColor[
             0.3521064049491038, 0.47793237749510553`, 0.9437105723744709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 392}], {
             RGBColor[
             0.35866334703698777`, 0.48482413936361163`, 0.9440839805262493]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 402}], {
             RGBColor[
             0.4818182674522101, 0.589060600826333, 0.952664686170056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 431}], {
             RGBColor[
             0.42993261586454035`, 0.5468077556454473, 0.9486159040017718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 436}], {
             RGBColor[
             0.4421225577048329, 0.5568338353820671, 0.9495396944885663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 459}], {
             RGBColor[
             0.40093570974009674`, 0.5216920929873327, 0.9467682467844796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 462}], {
             RGBColor[
             0.4376018334802528, 0.5531637078002476, 0.949183806517649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 487}], {
             RGBColor[
             0.49537833953651855`, 0.6000692782186605, 0.9537321847167134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 81}], {
             RGBColor[
             0.7152180111578499, 0.7769379420233913, 0.972614350327299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 156}], {
             RGBColor[
             0.5370635204917655, 0.6350513862279201, 0.9566987541430614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 278}], {
             RGBColor[
             0.7775908081460805, 0.8263457284855322, 0.9672404849556133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 329}], {
             RGBColor[
             0.7446878798780471, 0.8004364154026, 0.9754252127138938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 479}], {
             RGBColor[
             0.5091542746403608, 0.6112576931750507, 0.9548154361242309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 482}], {
             RGBColor[
             0.4826496570055525, 0.5883007255405965, 0.9531265853256541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 85}], {
             RGBColor[
             0.21682232686548605`, 0.34522439123812265`, 0.9356590828038773]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 95}], {
             RGBColor[
             0.22325600943798377`, 0.3519865995408531, 0.9360254715086005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 97}], {
             RGBColor[
             0.22558180327383132`, 0.35443115632617517`, 0.9361579220268484]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 137}], {
             RGBColor[
             0.21975482034818994`, 0.34830662781927, 0.9358260839694819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 145}], {
             RGBColor[
             0.22004363289237822`, 0.3486101881149849, 0.9358425314166136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 183}], {
             RGBColor[
             0.21219822021020854`, 0.34036416195813046`, 0.935395746770612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 346}], {
             RGBColor[
             0.21865587786091514`, 0.34715156958816623`, 0.9357635008205714]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 358}], {
             RGBColor[
             0.22252765585105994`, 0.3512210537407115, 0.9359839928493279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 404}], {
             RGBColor[
             0.2164387033219317, 0.3448211785707095, 0.935637236010592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 407}], {
             RGBColor[
             0.21689372054729342`, 0.34529943052432305`, 0.9356631485684387]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 408}], {
             RGBColor[
             0.22096681623691122`, 0.34958051234329385`, 0.9358951053423573]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 430}], {
             RGBColor[
             0.22958406238534357`, 0.3586377844102586, 0.9363858447624374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 81}], {
             RGBColor[
             0.9087234308797807, 0.9257016701540246, 0.7763552620147077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 99}], {
             RGBColor[
             0.9937251243023482, 0.9889870003070016, 0.5583966882336657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 122}], {
             RGBColor[
             0.9306665098261713, 0.7402291937878942, 0.3904132893585251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 267}], {
             RGBColor[
             0.9914456607402118, 0.9819881575780944, 0.49084130836277423`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 278}], {
             RGBColor[
             0.9710962278680113, 0.9751094566161655, 0.770981396643022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 329}], {
             RGBColor[
             0.9381932995999778, 0.9492001435332333, 0.7791661244013025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 406}], {
             RGBColor[
             0.9922235479450122, 0.984612153776488, 0.4938632532617516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 413}], {
             RGBColor[
             0.9838323701759427, 0.9563067408191819, 0.46126511216987476`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 476}], {
             RGBColor[
             0.9211605712027758, 0.6814740968415736, 0.3818708025801312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 486}], {
             RGBColor[
             0.9643781566417168, 0.9700792377693064, 0.7816636594414414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 493}], {
             RGBColor[
             0.9937029879453217, 0.9889396528776512, 0.5559872823811043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 156}], {
             RGBColor[
             0.6284260394446897, 0.7069689251123001, 0.9654326763878454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 278}], {
             RGBColor[
             0.8689533270990046, 0.8982632673699124, 0.9759744072003973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 307}], {
             RGBColor[
             0.6296762406643908, 0.7079838947833768, 0.9655310968074982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 329}], {
             RGBColor[
             0.8360503988309712, 0.8723539542869803, 0.9841591349586778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 372}], {
             RGBColor[
             0.6299979927875134, 0.7082451076516956, 0.9655564263132472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 406}], {
             RGBColor[
             0.8900806471760057, 0.9077659645302347, 0.6988562638191269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 417}], {
             RGBColor[
             0.7452877880838611, 0.8009437515388753, 0.9752469796719869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 461}], {
             RGBColor[
             0.8669992096038857, 0.8968058897416262, 0.9792822184041656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 486}], {
             RGBColor[
             0.8622352558727102, 0.8932330485230531, 0.9866566699988166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 493}], {
             RGBColor[
             0.8915600871763152, 0.912093463631398, 0.7609802929384797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 83}], {
             RGBColor[
             0.8721819244967113, 0.9009182081187621, 0.9876706846361336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 99}], {
             RGBColor[
             0.9086198401868935, 0.9254801001365643, 0.7650800543815806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 237}], {
             RGBColor[
             0.8648552697662895, 0.8950761325134684, 0.9869718617673642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[
             0.906340376624757, 0.9184812574076573, 0.6975246745106891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 278}], {
             RGBColor[
             0.8859909437525565, 0.9116025564457284, 0.9776647627909368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 329}], {
             RGBColor[
             0.8530880154845231, 0.8856932433627962, 0.9858494905492173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 426}], {
             RGBColor[
             0.8468962698264015, 0.8807561134454687, 0.9852589163209091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 486}], {
             RGBColor[
             0.879272872526262, 0.9065723375988691, 0.9883470255893563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 89}], {
             RGBColor[
             0.2718901700216876, 0.4031041858982062, 0.9387951150060494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 105}], {
             RGBColor[
             0.25209194686734443`, 0.382294998083142, 0.9376676354862561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 184}], {
             RGBColor[
             0.2576552479933815, 0.38814238030027126`, 0.9379844572552174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 195}], {
             RGBColor[
             0.2642152742010554, 0.39503738377422104`, 0.9383580410430554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 225}], {
             RGBColor[
             0.2662639580467382, 0.39719068039009175`, 0.9384747105573108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 263}], {
             RGBColor[
             0.26583963752085393`, 0.39674469261391226`, 0.9384505461310877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 296}], {
             RGBColor[
             0.28584922180975014`, 0.4173439077491774, 0.9396058846276822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 342}], {
             RGBColor[
             0.2591328832418887, 0.3896954686339382, 0.9380686063966545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 395}], {
             RGBColor[
             0.26163309800222595`, 0.39232335286982434`, 0.9382109899285194]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 440}], {
             RGBColor[
             0.26997623108034263`, 0.40109251472011487`, 0.9386861190147588]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 447}], {
             RGBColor[
             0.25238928516537673`, 0.3826075194867109, 0.9376845684624564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 453}], {
             RGBColor[
             0.27129272785642566`, 0.40247623630249474`, 0.9387610915585742]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 463}], {
             RGBColor[
             0.26268799213192734`, 0.3934321134842913, 0.9382710645886299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 470}], {
             RGBColor[
             0.25688036525862096`, 0.38732792941563493`, 0.937940328829809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 119}], {
             RGBColor[
             0.9556965383033635, 0.9650210547273206, 0.8984817408494732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 176}], {
             RGBColor[
             0.7638451540938651, 0.8157128228854424, 0.9772513951417543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[
             0.8091856625186589, 0.8516756760168047, 0.981399600787607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 237}], {
             RGBColor[
             0.913419047498675, 0.933799570648643, 0.9916039182408752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 270}], {
             RGBColor[
             0.955384395176871, 0.9648919755228036, 0.9036547602559704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 345}], {
             RGBColor[
             0.7902354483667869, 0.8368716246944006, 0.9795108205407682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 375}], {
             RGBColor[
             0.9394735703012015, 0.9539944639741937, 0.9739704912597569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 426}], {
             RGBColor[
             0.895460047558787, 0.9194795515806435, 0.9898909727944203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 448}], {
             RGBColor[
             0.7443425082604527, 0.7998796964136958, 0.9757160754212024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 489}], {
             RGBColor[
             0.9554216482771469, 0.9649073806371287, 0.9030373799764648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 131}], {
             RGBColor[
             0.24846167161057395`, 0.3784793486155308, 0.9374608966808939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 135}], {
             RGBColor[
             0.24197053087649611`, 0.37165674814192173`, 0.9370912358188704]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 147}], {
             RGBColor[
             0.24240373141068797`, 0.37211206936985763`, 0.93711590594843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 171}], {
             RGBColor[
             0.2475282592649566, 0.3774982730585261, 0.9374077402286709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 230}], {
             RGBColor[
             0.22859615804425376`, 0.3575994343110202, 0.9363295850716857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 242}], {
             RGBColor[
             0.22916096004104347`, 0.3581930770201611, 0.9363617497098533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 365}], {
             RGBColor[
             0.22514447908377305`, 0.3539715008744688, 0.9361330170611878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 374}], {
             RGBColor[
             0.24252230770556474`, 0.3722367005739444, 0.9371226586930053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 385}], {
             RGBColor[
             0.2333929402174702, 0.3626411565086264, 0.9366027547202471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 391}], {
             RGBColor[
             0.23722076036640824`, 0.3666644381829753, 0.9368207434149767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 95}], {
             RGBColor[
             0.22064923730827996`, 0.3492467167536353, 0.9358770196921877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 97}], {
             RGBColor[
             0.22297503114412753`, 0.3516912735389574, 0.9360094702104356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 137}], {
             RGBColor[
             0.21714804821848613`, 0.34556674503205226`, 0.9356776321530691]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 145}], {
             RGBColor[
             0.21743686076267443`, 0.3458703053277671, 0.9356940796002007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 183}], {
             RGBColor[
             0.20959144808050473`, 0.33762427917091264`, 0.9352472949541991]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 286}], {
             RGBColor[
             0.21865790979829205`, 0.3471537052831816, 0.935763616536399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 346}], {
             RGBColor[
             0.21604910573121133`, 0.34441168680094847`, 0.9356150490041585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 358}], {
             RGBColor[
             0.2199208837213561, 0.34848117095349374`, 0.935835541032915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 404}], {
             RGBColor[
             0.21383193119222793`, 0.3420812957834917, 0.9354887841941792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 407}], {
             RGBColor[
             0.2142869484175896, 0.3425595477371053, 0.9355146967520258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 408}], {
             RGBColor[
             0.21836004410720744`, 0.3468406295560761, 0.9357466535259444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 90}], {
             RGBColor[
             0.8899814344584336, 0.5901544331035902, 0.2297467504579272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 98}], {
             RGBColor[
             0.9552139147274563, 0.8468459050338089, 0.4866646892725739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 115}], {
             RGBColor[
             0.9181807358610004, 0.8207272885954675, 0.6214818156174652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 124}], {
             RGBColor[
             0.9389228207101663, 0.7935781606519255, 0.2800166062249653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 136}], {
             RGBColor[
             0.942076876818933, 0.8389236960734718, 0.594023128493258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 168}], {
             RGBColor[
             0.912992655814064, 0.6927519043211215, 0.24885005242438252`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[
             0.9534388639235, 0.8461526483552239, 0.5190456011559075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 253}], {
             RGBColor[
             0.9501124692155603, 0.8447770986590462, 0.5741725699000219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 261}], {
             RGBColor[
             0.897589954080166, 0.6247029436909717, 0.23609548573218275`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 357}], {
             RGBColor[
             0.911167687629582, 0.6855165136042474, 0.2473816401856394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 484}], {
             RGBColor[
             0.9540423951293819, 0.8443401430723285, 0.3591520108030784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 500}], {
             RGBColor[
             0.8673428769617186, 0.42615530998421236`, 0.20846003809980468`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 107}], {
             RGBColor[
             0.1819624771956669, 0.3085844789930161, 0.9336738659357071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 113}], {
             RGBColor[
             0.17922276129889142`, 0.3057048638774843, 0.9335178431684322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 143}], {
             RGBColor[
             0.1790901316250143, 0.30556546168103244`, 0.933510290104713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 226}], {
             RGBColor[
             0.17933912709972993`, 0.30582717171218354`, 0.9335244700286423]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 292}], {
             RGBColor[
             0.1791119470402912, 0.3055883910656657, 0.93351153246034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 308}], {
             RGBColor[
             0.17909977333492821`, 0.3055755957294717, 0.9335108391858289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 386}], {
             RGBColor[
             0.17909013095112286`, 0.3055654609727298, 0.9335102900663359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 421}], {
             RGBColor[
             0.17915493384170816`, 0.30563357291947557`, 0.9335139804950874]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 422}], {
             RGBColor[
             0.2066326331143824, 0.33451437704181397`, 0.9350787948190529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 423}], {
             RGBColor[
             0.18353957668712906`, 0.310242110552426, 0.9337636794186364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 446}], {
             RGBColor[
             0.20370226760912918`, 0.33143437709988877`, 0.934911914838616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 166}], {
             RGBColor[
             0.8523652692557177, 0.3906026653424749, 0.19727300714892185`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 167}], {
             RGBColor[
             0.9266401906833595, 0.7379726928092079, 0.5404902319838795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 210}], {
             RGBColor[
             0.8513369203215293, 0.3826983248089265, 0.19628825904818903`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 227}], {
             RGBColor[
             0.8561206468687188, 0.41946814329296433`, 0.20086916099222407`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 243}], {
             RGBColor[
             0.8529581179820884, 0.3951595604413297, 0.19784071975882145`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 326}], {
             RGBColor[
             0.8708928189630238, 0.5066362693068722, 0.21398214224720047`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 348}], {
             RGBColor[
             0.9132608681622556, 0.6818120756635188, 0.2545865809359151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 428}], {
             RGBColor[
             0.8484718113152332, 0.36067584148776255`, 0.1935446274280821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 434}], {
             RGBColor[
             0.9289063525023188, 0.7389098089590498, 0.5029340660049313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 469}], {
             RGBColor[
             0.8635204022958338, 0.47315984709282155`, 0.20783041706562805`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 474}], {
             RGBColor[
             0.9298536404427284, 0.7393015368665987, 0.48723505332973827`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 495}], {
             RGBColor[
             0.8544062989949438, 0.4062909143031017, 0.1992274995322182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 133}], {
             RGBColor[
             0.3153376912434113, 0.4454022988525135, 0.9413927055520241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 184}], {
             RGBColor[
             0.271266794829508, 0.4024489790469554, 0.9387596147110557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 192}], {
             RGBColor[
             0.27005817816264466`, 0.4011786462993594, 0.9386907857798661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 225}], {
             RGBColor[
             0.2798755048828646, 0.4114972791367759, 0.9392498680131491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 235}], {
             RGBColor[
             0.32127172035398965`, 0.45054205661512126`, 0.9417708166396943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 239}], {
             RGBColor[
             0.31821611673686917`, 0.4478954463410748, 0.9415761162791756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 249}], {
             RGBColor[
             0.28752479280706156`, 0.41953716573797317`, 0.9396854836443249]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 260}], {
             RGBColor[
             0.2855390731059485, 0.4174500484302025, 0.9395723998449554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.2711970471587578, 0.4023756698227392, 0.938755642684389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 296}], {
             RGBColor[
             0.2994607686458766, 0.4316505064958615, 0.9403810420835206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 424}], {
             RGBColor[
             0.3030480744366626, 0.4347576504686087, 0.9406096220363795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 440}], {
             RGBColor[
             0.2835877779164691, 0.415399113466799, 0.9394612764705972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 453}], {
             RGBColor[
             0.28490427469255214`, 0.4167828350491789, 0.9395362490144127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 470}], {
             RGBColor[
             0.27049191209474743`, 0.40163452816231904`, 0.9387154862856475]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 124}], {
             RGBColor[
             0.9137111635376958, 0.6822566946723914, 0.2591427819494134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 178}], {
             RGBColor[
             0.9282272067510295, 0.7348311823756897, 0.4981717768803556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[
             0.8618116052496472, 0.4654005988057779, 0.20640455492384144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 261}], {
             RGBColor[
             0.8723782969076955, 0.5133814777114375, 0.21522166145663085`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 272}], {
             RGBColor[
             0.8426763546129947, 0.3190239891395971, 0.18810823554711417`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 306}], {
             RGBColor[
             0.8611746456929213, 0.4612099603827511, 0.20582221997608346`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 317}], {
             RGBColor[
             0.8740850504741097, 0.5211314470341011, 0.21664581846880504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 357}], {
             RGBColor[
             0.8859560304571115, 0.5741950476247133, 0.2265078159100875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 172}], {
             RGBColor[
             0.33964065051404985`, 0.4686013934649852, 0.9428625798116885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 303}], {
             RGBColor[
             0.3164436833902854, 0.44818690517109605`, 0.9413962957337874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 366}], {
             RGBColor[
             0.29631757138809034`, 0.4270330853875859, 0.9402501434291768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 435}], {
             RGBColor[
             0.29287326479962417`, 0.4234129007814571, 0.9400539952643586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 473}], {
             RGBColor[
             0.32723005291391416`, 0.4578519575985201, 0.9420717875068684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 101}], {
             RGBColor[
             0.5649851581111299, 0.6577194295027604, 0.9588968477367864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 128}], {
             RGBColor[
             0.5519404005403256, 0.6471291076471498, 0.9578699166362912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 140}], {
             RGBColor[
             0.554385826473297, 0.649114414584719, 0.9580624295236251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 169}], {
             RGBColor[
             0.5509398864490034, 0.6463168452351683, 0.9577911525020184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 175}], {
             RGBColor[
             0.7824339265203888, 0.8300343229197356, 0.9610969915433571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 204}], {
             RGBColor[
             0.5555153199743827, 0.6500313882920026, 0.9581513473895016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 219}], {
             RGBColor[
             0.5677032440041356, 0.6599260940790765, 0.9591108254149605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 274}], {
             RGBColor[
             0.5359359247795917, 0.6341359532311694, 0.9566099856780799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 320}], {
             RGBColor[
             0.7988700431185324, 0.8415596078670635, 0.9004611644475569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 334}], {
             RGBColor[
             0.505970833581321, 0.6084373708863062, 0.9546299931971096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 337}], {
             RGBColor[
             0.7346741443689091, 0.7924685201915558, 0.974450773685277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 361}], {
             RGBColor[
             0.6266695180780231, 0.7077693478258749, 0.9637721633771799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 363}], {
             RGBColor[
             0.506974473041424, 0.6093066729422614, 0.9546939442160238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 370}], {
             RGBColor[
             0.6002904630940367, 0.6863818665737486, 0.9616762106726342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 498}], {
             RGBColor[
             0.5355135500520953, 0.6337930503996233, 0.9565767347923217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 108}], {
             RGBColor[
             0.27719798724909794`, 0.408683038339264, 0.9390973873449386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 163}], {
             RGBColor[
             0.26813879509029465`, 0.39916125299440397`, 0.9385814797533685]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 187}], {
             RGBColor[
             0.2669566877883537, 0.3979187832701322, 0.9385141604912941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 189}], {
             RGBColor[
             0.26453032177670965`, 0.3953685187514038, 0.9383759825364177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 206}], {
             RGBColor[
             0.30600971855859727`, 0.43582355730741806`, 0.940853232846973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 266}], {
             RGBColor[
             0.2794030113306438, 0.41100065845557043`, 0.9392229602043418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 322}], {
             RGBColor[
             0.26425191426448674`, 0.3950758948040016, 0.9383601276404636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 364}], {
             RGBColor[
             0.2639259772143767, 0.39473331429873343`, 0.9383415660076406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 437}], {
             RGBColor[
             0.26255787085876586`, 0.3932953477760335, 0.9382636543746206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 100}], {
             RGBColor[
             0.943316965793535, 0.8656345224892459, 0.6119300548794735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 127}], {
             RGBColor[
             0.5906994451507328, 0.6605608453144329, 0.9482643190369882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 168}], {
             RGBColor[
             0.9331056494970619, 0.8251500560931704, 0.6037137900969318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 213}], {
             RGBColor[
             0.9298124883323949, 0.8120876909328425, 0.6010637208876998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 214}], {
             RGBColor[
             0.5776130969249946, 0.6468062636067821, 0.9475190708650497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 254}], {
             RGBColor[
             0.5959586642234989, 0.6660886180136586, 0.9485638237828649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 302}], {
             RGBColor[
             0.5727842186692342, 0.6417308063914131, 0.9472440733920693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 315}], {
             RGBColor[
             0.5704593476328262, 0.6392872195268108, 0.9471116754258844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 325}], {
             RGBColor[
             0.5672179996830251, 0.6358803573182399, 0.9469270854552878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 368}], {
             RGBColor[
             0.6817603644893816, 0.7470855364406719, 0.9537864521193352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 401}], {
             RGBColor[
             0.8644357283380311, 0.8946091728083778, 0.9692011064141851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 477}], {
             RGBColor[
             0.6000453532177727, 0.6703839872576882, 0.948796554675374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 500}], {
             RGBColor[
             0.8874558706447166, 0.5585534617562613, 0.5633237757723539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 97}], {
             RGBColor[
             0.22940871371662525`, 0.3584534818416879, 0.936375858915159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 137}], {
             RGBColor[
             0.22358173079098384`, 0.35232895333478276`, 0.9360440208577924]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 145}], {
             RGBColor[
             0.22387054333517215`, 0.3526325136304976, 0.9360604683049241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 174}], {
             RGBColor[
             0.24687001390337449`, 0.3768064154483368, 0.9373702541291156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 286}], {
             RGBColor[
             0.22509159237078977`, 0.3539159135859121, 0.9361300052411223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 294}], {
             RGBColor[
             0.2326978312332123, 0.36191055289371626`, 0.9365631692919152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 346}], {
             RGBColor[
             0.22248278830370904`, 0.3511738951036789, 0.9359814377088818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 358}], {
             RGBColor[
             0.2263545662938538, 0.3552433792562242, 0.9362019297376383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 404}], {
             RGBColor[
             0.22026561376472564`, 0.3488435040862222, 0.9358551728989024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 407}], {
             RGBColor[
             0.22072063099008732`, 0.34932175603983573`, 0.9358810854567492]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 408}], {
             RGBColor[
             0.22479372667970515`, 0.35360283785880653`, 0.9361130422306678]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 430}], {
             RGBColor[
             0.23341097282813747`, 0.36266010992577125`, 0.9366037816507478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 131}], {
             RGBColor[
             0.2798853921380307, 0.4115076712688437, 0.9392504310777041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 147}], {
             RGBColor[
             0.27382745193814473`, 0.40514039202317054`, 0.9389054403452399]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.29935267191603787`, 0.43196901661235676`, 0.940359063861802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 171}], {
             RGBColor[
             0.2789519797924134, 0.41052659571183897`, 0.939197274625481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 180}], {
             RGBColor[
             0.2831463385898367, 0.4149351327456384, 0.9394361371539964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 216}], {
             RGBColor[
             0.2810238579235662, 0.4127042709923413, 0.9393152650199811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 238}], {
             RGBColor[
             0.3081578274315908, 0.4401690531459169, 0.9408991236475683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 265}], {
             RGBColor[
             0.3085881199169248, 0.4405417508695841, 0.9409265415042412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 281}], {
             RGBColor[
             0.27053519804586806`, 0.4016800244414347, 0.938717951356528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 343}], {
             RGBColor[
             0.29452462133405766`, 0.4268944293346082, 0.940084113523619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 392}], {
             RGBColor[
             0.3010815634219416, 0.43378619120311424`, 0.9404575216753974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 433}], {
             RGBColor[
             0.31083399291217784`, 0.4424870131772134, 0.9410696465455513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 465}], {
             RGBColor[
             0.2893936582907169, 0.42150146185421045`, 0.9397919127688803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 104}], {
             RGBColor[
             0.23915408747259903`, 0.3686964875516002, 0.936930843533573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 137}], {
             RGBColor[
             0.2259075246268314, 0.35477351012010483`, 0.9361764713760403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 145}], {
             RGBColor[
             0.2261963371710197, 0.3550770704158197, 0.9361929188231719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 174}], {
             RGBColor[
             0.24919580773922206`, 0.37925097223365895`, 0.9375027046473634]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 294}], {
             RGBColor[
             0.23502362506905988`, 0.3643551096790384, 0.936695619810163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 346}], {
             RGBColor[
             0.22480858213955662`, 0.353618451889001, 0.9361138882271296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 358}], {
             RGBColor[
             0.2286803601297014, 0.35768793604154625`, 0.9363343802558861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 404}], {
             RGBColor[
             0.2225914076005732, 0.3512880608715443, 0.9359876234171504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 407}], {
             RGBColor[
             0.2230464248259349, 0.3517663128251578, 0.936013535974997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 408}], {
             RGBColor[
             0.2271195205155527, 0.3560473946441286, 0.9362454927489157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 430}], {
             RGBColor[
             0.23573676666398502`, 0.3651046667110934, 0.9367362321689956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 115}], {
             RGBColor[
             0.9582015589575525, 0.9660972945461519, 0.85752593015656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 124}], {
             RGBColor[
             0.9789436438067185, 0.93894816660261, 0.5160607207640602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 136}], {
             RGBColor[
             0.9820976999154852, 0.9842937020241562, 0.8300672430323528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 253}], {
             RGBColor[
             0.9901332923121124, 0.9901471046097305, 0.8102166844391167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 261}], {
             RGBColor[
             0.9376107771767181, 0.7700729496416561, 0.47213960027127755`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 277}], {
             RGBColor[
             0.8832681348130269, 0.9067408984138945, 0.8502742951726139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 311}], {
             RGBColor[
             0.8710458030481137, 0.8971927199459824, 0.8490560873664715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 319}], {
             RGBColor[
             0.8550622111994015, 0.8847062165139711, 0.8474629923061501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 331}], {
             RGBColor[
             0.9159632164581281, 0.9324175867663749, 0.8534971993423514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 377}], {
             RGBColor[
             0.9881699242791049, 0.9888223570121889, 0.8197885510745015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 484}], {
             RGBColor[
             0.9940632182259341, 0.9897101490230129, 0.5951961253421731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 488}], {
             RGBColor[
             0.8822995191611039, 0.9059842085048606, 0.8501777526166581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 122}], {
             RGBColor[
             0.930562919133284, 0.740007623770434, 0.37913808172539787`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 267}], {
             RGBColor[
             0.9913420700473246, 0.9817665875606343, 0.479566100729647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 278}], {
             RGBColor[
             0.9709926371751241, 0.9748878865987054, 0.7597061890098948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 329}], {
             RGBColor[
             0.9380897089070905, 0.9489785735157732, 0.7678909167681753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 406}], {
             RGBColor[
             0.992119957252125, 0.9843905837590278, 0.48258804562862445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 413}], {
             RGBColor[
             0.9837287794830555, 0.9560851708017216, 0.4499899045367475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 476}], {
             RGBColor[
             0.9210569805098886, 0.6812525268241133, 0.37059559494700395`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 486}], {
             RGBColor[
             0.9642745659488295, 0.9698576677518461, 0.7703884518083142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 493}], {
             RGBColor[
             0.9935993972524345, 0.9887180828601909, 0.5447120747479771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 121}], {
             RGBColor[
             0.8793403970281699, 0.48855884043917713`, 0.2187233911438525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 127}], {
             RGBColor[
             0.5785973319473678, 0.5599231651764567, 0.5998463238378839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 168}], {
             RGBColor[
             0.9210035362936968, 0.7245123759551941, 0.25529579489782767`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 200}], {
             RGBColor[
             0.9160214299715226, 0.703780905297789, 0.25123642844933736`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 213}], {
             RGBColor[
             0.9177103751290299, 0.7114500107948662, 0.2526457256885956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 254}], {
             RGBColor[
             0.5838565510201338, 0.5654509378756822, 0.6001458285837606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 259}], {
             RGBColor[
             0.8965277758950481, 0.6152647749950997, 0.2349704456547408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 315}], {
             RGBColor[
             0.5583572344294613, 0.5386495393888345, 0.5986936802267802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 368}], {
             RGBColor[
             0.6696582512860165, 0.6464478563026956, 0.6053684569202311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 401}], {
             RGBColor[
             0.8523336151346661, 0.7939714926704016, 0.620783111215081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 450}], {
             RGBColor[
             0.8744616680202064, 0.45105879141128646`, 0.21405151473609035`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 454}], {
             RGBColor[
             0.915548639391991, 0.7016340736991815, 0.25084192040061865`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 471}], {
             RGBColor[
             0.894013717811025, 0.6013444138663678, 0.23277457969666004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 475}], {
             RGBColor[
             0.8851091218155209, 0.5328997870260774, 0.22424752851506258`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 500}], {
             RGBColor[
             0.8753537574413516, 0.45791578161828494`, 0.21490578057324983`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 128}], {
             RGBColor[
             0.5077879700548952, 0.6112841755347511, 0.9543940755727961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 169}], {
             RGBColor[
             0.506787455963573, 0.6104719131227696, 0.9543153114385234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 197}], {
             RGBColor[
             0.6092291752169602, 0.6927921015850171, 0.9629587335694303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[
             0.5113628894889524, 0.6141864561796039, 0.9546755063260064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 219}], {
             RGBColor[
             0.5235508135187052, 0.6240811619666777, 0.9556349843514654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 337}], {
             RGBColor[
             0.6905217138834787, 0.756623588079157, 0.9709749326217818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 345}], {
             RGBColor[
             0.5902789610650883, 0.677988050262613, 0.9610699533225915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 355}], {
             RGBColor[
             0.424769765192925, 0.5405027707410431, 0.9487934456872616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 361}], {
             RGBColor[
             0.5825170875925927, 0.671924415713476, 0.9602963223136847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 362}], {
             RGBColor[
             0.45464713410545365`, 0.5663810460128507, 0.950697205214848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 363}], {
             RGBColor[
             0.4628220425559936, 0.5734617408298626, 0.9512181031525286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 498}], {
             RGBColor[
             0.491361119566665, 0.5979481182872246, 0.9531008937288266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 109}], {
             RGBColor[
             0.265248780611274, 0.396123664539452, 0.9384168977041816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[
             0.28024115314486164`, 0.4118815986435736, 0.9392706911407418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 186}], {
             RGBColor[
             0.256123983487738, 0.3865329242170628, 0.9378972540069239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 193}], {
             RGBColor[
             0.2821746373958698, 0.4139138131813651, 0.9393808002085031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 196}], {
             RGBColor[
             0.28611844580431445`, 0.41805900587053585`, 0.9396053942630224]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 202}], {
             RGBColor[
             0.2577973086293919, 0.3882916950358828, 0.9379925473982783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 330}], {
             RGBColor[
             0.2914935550351155, 0.4237085864737168, 0.939911498781955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 350}], {
             RGBColor[
             0.3193537748201921, 0.44805203074969097`, 0.941678953195245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 354}], {
             RGBColor[
             0.3191507002330799, 0.44787613774915985`, 0.941666013462126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 414}], {
             RGBColor[
             0.27559776236137046`, 0.40700110052214455`, 0.9390062569049031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 415}], {
             RGBColor[
             0.28177512151681394`, 0.41349389666170766`, 0.9393580483702217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 485}], {
             RGBColor[
             0.2622693737921402, 0.3929921190672394, 0.9382472248934693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 496}], {
             RGBColor[
             0.27671354998693043`, 0.4081738640616296, 0.9390697993595188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 118}], {
             RGBColor[
             0.4027319052154037, 0.522513730131029, 0.9470855430392838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 188}], {
             RGBColor[
             0.408816425381794, 0.5277838356822806, 0.9474732432839563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 304}], {
             RGBColor[
             0.4094598762170423, 0.5283411604549934, 0.947514243402197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 319}], {
             RGBColor[
             0.5976226950866923, 0.6831049747415705, 0.9622258440138658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 331}], {
             RGBColor[
             0.6585237003454188, 0.7308163449939742, 0.968260051050067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 449}], {
             RGBColor[
             0.6043292409167387, 0.6883441793156388, 0.9628942898259707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 488}], {
             RGBColor[
             0.6248600030483947, 0.70438296673246, 0.9649406043243738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 112}], {
             RGBColor[
             0.24741859649764936`, 0.37738301053706513`, 0.9374014950963042]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 148}], {
             RGBColor[
             0.2431147548759032, 0.37285940011329033`, 0.9371563976829089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 153}], {
             RGBColor[
             0.24575331572793313`, 0.3756326948631943, 0.937306659820031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 190}], {
             RGBColor[
             0.24734164292075334`, 0.3773021274486088, 0.9373971127039427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 215}], {
             RGBColor[
             0.26534838496499225`, 0.39622835503049064`, 0.9384225700247744]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 224}], {
             RGBColor[
             0.2727699797429894, 0.40402892169845256`, 0.9388452188681158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 323}], {
             RGBColor[
             0.2429591667599799, 0.3726958671385986, 0.9371475371698791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 351}], {
             RGBColor[
             0.2683095588486911, 0.39934073653152624`, 0.9385912044967868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 356}], {
             RGBColor[
             0.2579557991377684, 0.3884582786090651, 0.9380015731982647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 408}], {
             RGBColor[
             0.23453910043567894`, 0.36384584356871885`, 0.9366680268490819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 430}], {
             RGBColor[
             0.24315634658411125`, 0.3729031156356836, 0.937158766269162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 452}], {
             RGBColor[
             0.2352635459876256, 0.36460728177631574`, 0.9367092829515442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 112}], {
             RGBColor[
             0.2470843980758506, 0.3770317468063509, 0.9373824629905851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 148}], {
             RGBColor[
             0.24278055645410443`, 0.37250813638257607`, 0.9371373655771897]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 153}], {
             RGBColor[
             0.24541911730613436`, 0.37528143113248, 0.9372876277143118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 190}], {
             RGBColor[
             0.24700744449895456`, 0.37695086371789455`, 0.9373780805982235]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 195}], {
             RGBColor[
             0.2580285978828387, 0.38853479470584096`, 0.9380057189791005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 263}], {
             RGBColor[
             0.2596529612026372, 0.3902421035455322, 0.9380982240671327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 323}], {
             RGBColor[
             0.24262496833818112`, 0.37234460340788433`, 0.93712850506416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 342}], {
             RGBColor[
             0.252946206923672, 0.38319287956555814`, 0.9377162843326995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 395}], {
             RGBColor[
             0.2554464216840092, 0.38582076380144426`, 0.9378586678645644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 447}], {
             RGBColor[
             0.24620260884716, 0.3761049304183308, 0.9373322463985014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 453}], {
             RGBColor[
             0.265106051538209, 0.39597364723411466`, 0.9384087694946193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 463}], {
             RGBColor[
             0.2565013158137106, 0.3869295244159112, 0.9379187425246749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 117}], {
             RGBColor[
             0.44946530583261596`, 0.561973649912251, 0.9503446865091629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 139}], {
             RGBColor[
             0.5409452590449157, 0.6382027564556965, 0.9570043388212421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 140}], {
             RGBColor[
             0.508744701282457, 0.6120608930455363, 0.9544693929596517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 247}], {
             RGBColor[
             0.5064333598698463, 0.6101844419620349, 0.9542874356969284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 255}], {
             RGBColor[
             0.45772043203322, 0.569123825312507, 0.9508706958509441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 269}], {
             RGBColor[
             0.48339733950661234`, 0.5913638720070653, 0.9525068056899508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 274}], {
             RGBColor[
             0.49029479958875166`, 0.5970824316919869, 0.9530169491141065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 360}], {
             RGBColor[
             0.5486108303756021, 0.6444260125920007, 0.9576078006763067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 369}], {
             RGBColor[
             0.46890138102995677`, 0.5788082013626439, 0.9515831360340911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 370}], {
             RGBColor[
             0.5546493379031965, 0.6493283450345659, 0.9580831741086608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 425}], {
             RGBColor[
             0.4465990938801403, 0.559491081179018, 0.9501620540180429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 466}], {
             RGBColor[
             0.5106817556791221, 0.6136334810680553, 0.9546218849774213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 468}], {
             RGBColor[
             0.4981161809408796, 0.6034321814228589, 0.9536326769048099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 113}], {
             RGBColor[
             0.18193197659231264`, 0.3085524209250408, 0.9336721289714678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 132}], {
             RGBColor[
             0.5874023021726906, 0.6508098778838103, 0.8735074338464627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 143}], {
             RGBColor[
             0.18179934691843552`, 0.30841301872858895`, 0.9336645759077484]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 209}], {
             RGBColor[
             0.37529763235099667`, 0.4849566561931139, 0.9463994374355724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 214}], {
             RGBColor[
             0.19223940367108877`, 0.31938618031345734`, 0.9342591216951321]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 273}], {
             RGBColor[
             0.2391065540897807, 0.3686465269524677, 0.9369281365777409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 308}], {
             RGBColor[
             0.18180898862834943`, 0.3084231527770282, 0.9336651249888644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 421}], {
             RGBColor[
             0.18186414913512938`, 0.30848112996703203`, 0.9336682662981228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 423}], {
             RGBColor[
             0.18624879198055028`, 0.31308966759998247`, 0.9339179652216718]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 446}], {
             RGBColor[
             0.2064114829025504, 0.3342819341474452, 0.9350662006416515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 477}], {
             RGBColor[
             0.21467165996386678`, 0.3429639039643634, 0.9355366055054566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 129}], {
             RGBColor[
             0.3203552344901264, 0.4497120899906687, 0.9417137426958612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 163}], {
             RGBColor[
             0.27605150294224795`, 0.40747801064146116`, 0.939032096759735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 189}], {
             RGBColor[
             0.27244302962866296`, 0.40368527639846097`, 0.9388265995427842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 206}], {
             RGBColor[
             0.31392242641055057`, 0.44414031495447526`, 0.9413038498533395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 266}], {
             RGBColor[
             0.28731571918259713`, 0.4193174161026276, 0.9396735772107083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 364}], {
             RGBColor[
             0.27183868506633, 0.4030500719457907, 0.938792183014007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 374}], {
             RGBColor[
             0.2684205085848909, 0.3994573517388918, 0.938597522920128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 410}], {
             RGBColor[
             0.32438785376155105`, 0.4532049421182389, 0.9419706976299311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 437}], {
             RGBColor[
             0.27047057871071917`, 0.40161210542309067`, 0.938714271380987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 185}], {
             RGBColor[
             0.26895237692670115`, 0.40001637908853493`, 0.9386278120353654]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 186}], {
             RGBColor[
             0.24483520726957755`, 0.37466770466202415`, 0.9372543749015474]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 196}], {
             RGBColor[
             0.27482966958615396`, 0.4061937863154972, 0.938962515157646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 218}], {
             RGBColor[
             0.24296647092511459`, 0.372703544279266, 0.937147953131278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 295}], {
             RGBColor[
             0.24177394363545715`, 0.37145012248723885`, 0.937080040466318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 300}], {
             RGBColor[
             0.23995882574419874`, 0.3695423184984049, 0.9369766721876371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 335}], {
             RGBColor[
             0.2653660882581673, 0.3962469623140712, 0.938423578201131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 409}], {
             RGBColor[
             0.24775783308986035`, 0.3777395697043211, 0.9374208141183751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 456}], {
             RGBColor[
             0.23880926652767986`, 0.3683340588755796, 0.9369112064908769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 458}], {
             RGBColor[
             0.24222963005763265`, 0.3719290778091332, 0.9371059911339332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 496}], {
             RGBColor[
             0.26542477376877, 0.3963086445065909, 0.9384269202541424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 217}], {
             RGBColor[
             0.29571753049971145`, 0.4271336534107135, 0.9401891973787395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 290}], {
             RGBColor[
             0.2791002706073135, 0.4106824587604797, 0.9392057195680129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 316}], {
             RGBColor[
             0.26110517012024004`, 0.39176846719329617`, 0.9381809252166395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 340}], {
             RGBColor[
             0.3045749314378675, 0.43480548891742876`, 0.9407535831342266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 355}], {
             RGBColor[
             0.30021105187484454`, 0.43102571577490256`, 0.9404755205872981]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 378}], {
             RGBColor[
             0.2773998635716586, 0.40889522315397336`, 0.9391088839028592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 384}], {
             RGBColor[
             0.27776805045914515`, 0.4092822109171187, 0.9391298516014178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 146}], {
             RGBColor[
             0.2655122364597581, 0.39640057334027434`, 0.9384319011250047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 201}], {
             RGBColor[
             0.28877500860148286`, 0.42085122180616963`, 0.9397566815842886]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 256}], {
             RGBColor[
             0.2812386903435383, 0.41293007348689414`, 0.9393274994084824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 271}], {
             RGBColor[
             0.2644482810539334, 0.39528228875008364`, 0.938371310438624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 284}], {
             RGBColor[
             0.2590919383322233, 0.3896524329378227, 0.9380662746446216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 312}], {
             RGBColor[
             0.28875139009156847`, 0.4208263972547496, 0.9397553365450895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 376}], {
             RGBColor[
             0.2762731715166523, 0.4077109983677596, 0.9390447204571181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[
             0.2845065356159251, 0.4163647860615299, 0.939513598362401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 415}], {
             RGBColor[
             0.2800519643946353, 0.41168274927182613`, 0.9392599171212961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 442}], {
             RGBColor[
             0.2785182841132166, 0.41007075405510884`, 0.939172576298146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 444}], {
             RGBColor[
             0.272192144891436, 0.40342158063262434`, 0.9388123120281499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 464}], {
             RGBColor[
             0.2584790029138965, 0.3890081989508112, 0.9380313688793045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 148}], {
             RGBColor[
             0.2439596839808273, 0.373747474174165, 0.9372045151454738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 153}], {
             RGBColor[
             0.24659824483285725`, 0.37652076892406894`, 0.9373547772825959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 190}], {
             RGBColor[
             0.24818657202567745`, 0.37819020150948346`, 0.9374452301665075]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 195}], {
             RGBColor[
             0.25920772540956155`, 0.3897741324974299, 0.9380728685473844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 224}], {
             RGBColor[
             0.2736149088479135, 0.4049169957593272, 0.9388933363306806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 263}], {
             RGBColor[
             0.2608320887293601, 0.39148144133712115`, 0.9381653736354167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 323}], {
             RGBColor[
             0.24380409586490398`, 0.37358394119947325`, 0.9371956546324439]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 342}], {
             RGBColor[
             0.25412533445039487`, 0.3844322173571471, 0.9377834339009834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 351}], {
             RGBColor[
             0.26915448795361524`, 0.4002288105924009, 0.9386393219593516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 356}], {
             RGBColor[
             0.2588007282426925, 0.3893463526699398, 0.9380496906608295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 395}], {
             RGBColor[
             0.2566255492107321, 0.38706010159303317`, 0.9379258174328484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 447}], {
             RGBColor[
             0.2473817363738829, 0.37734426820991973`, 0.9373993959667855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 452}], {
             RGBColor[
             0.2361084750925497, 0.3654953558371904, 0.936757400414109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 463}], {
             RGBColor[
             0.2576804433404335, 0.3881688622075002, 0.9379858920929589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 130}], {
             RGBColor[
             0.17905963034776856`, 0.3055334029047545, 0.9335085531020964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 143}], {
             RGBColor[
             0.17905963102166003`, 0.30553340361305714`, 0.9335085531404735]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 209}], {
             RGBColor[
             0.3725579164542212, 0.4820770410775821, 0.9462434146682975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 214}], {
             RGBColor[
             0.18949968777431325`, 0.3165065651979255, 0.9341030989278573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 273}], {
             RGBColor[
             0.23636683819300525`, 0.3657669118369359, 0.936772113810466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 302}], {
             RGBColor[
             0.18467080951855291`, 0.3114311079825565, 0.9338281014548768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 308}], {
             RGBColor[
             0.17906927273157397`, 0.3055435376614964, 0.9335091022215896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 325}], {
             RGBColor[
             0.1791045905323438, 0.30558065890938335`, 0.9335111135180953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 347}], {
             RGBColor[
             0.17905963034776856`, 0.3055334029047545, 0.9335085531020964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 386}], {
             RGBColor[
             0.17905963034776856`, 0.3055334029047545, 0.9335085531020964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 421}], {
             RGBColor[
             0.17912443323835392`, 0.3056015148515002, 0.9335122435308479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 423}], {
             RGBColor[
             0.1835090760837748, 0.31021005248445066`, 0.9337619424543968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 477}], {
             RGBColor[
             0.2119319440670913, 0.3400842888488316, 0.9353805827381816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 115}], {
             RGBColor[
             0.7109234320173796, 0.7727455262693818, 0.9730887236423327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 203}], {
             RGBColor[
             0.5176225598035007, 0.6192683385358883, 0.9551682905030956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 208}], {
             RGBColor[
             0.41139850447614446`, 0.5294684917353877, 0.9477902381259522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 258}], {
             RGBColor[
             0.4370504632160207, 0.551686929090934, 0.9494247582537205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 289}], {
             RGBColor[
             0.47002476811242727`, 0.580247614655448, 0.9515258518036867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 291}], {
             RGBColor[
             0.577802812280651, 0.6679328507014297, 0.9600375327920143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 297}], {
             RGBColor[
             0.5100213466264654, 0.6130973312480197, 0.954569895157638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 311}], {
             RGBColor[
             0.6237676761079407, 0.7038409516692123, 0.9646188808522442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 349}], {
             RGBColor[
             0.45713997699902986`, 0.5690874562014547, 0.9507048443075143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 359}], {
             RGBColor[
             0.443064873322788, 0.5568963088323743, 0.9498079911473898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 381}], {
             RGBColor[
             0.5349916430046526, 0.6333693427468647, 0.9565356483577385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 397}], {
             RGBColor[
             0.4296132686116584, 0.545245204928905, 0.9489508667899835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 419}], {
             RGBColor[
             0.5066845097134336, 0.6103883367192307, 0.9543072071326079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 124}], {
             RGBColor[
             0.9419104649402625, 0.9128295501642687, 0.6508778471089514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 136}], {
             RGBColor[
             0.9450645210490293, 0.9581750855858149, 0.964884369377244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 178}], {
             RGBColor[
             0.9564265081535962, 0.965404037867567, 0.8899068420398936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 203}], {
             RGBColor[
             0.7278675078772177, 0.786501490374317, 0.9744226233622142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 253}], {
             RGBColor[
             0.9531001134456565, 0.9640284881713892, 0.9450338107840079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 277}], {
             RGBColor[
             0.8462349559465709, 0.8806222819755531, 0.9850914215175051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 291}], {
             RGBColor[
             0.7880477603543681, 0.8351660025398585, 0.9792918656511329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 297}], {
             RGBColor[
             0.7202662947001824, 0.7803304830864486, 0.9738242280167566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 311}], {
             RGBColor[
             0.8340126241816578, 0.871074103507641, 0.9838732137113628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 381}], {
             RGBColor[
             0.7452365910783697, 0.8006024945852935, 0.9757899812168571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 419}], {
             RGBColor[
             0.7169294577871506, 0.7776214885576594, 0.9735615399917263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 439}], {
             RGBColor[
             0.8910404321249454, 0.9159554702009634, 0.9894694259289032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 484}], {
             RGBColor[
             0.9570300393594782, 0.9635915325846716, 0.7300132516870645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 192}], {
             RGBColor[
             0.2516702940273803, 0.3818518142140055, 0.9376436229807996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 280}], {
             RGBColor[
             0.25280916302349343`, 0.3830488377373854, 0.9377084798853226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 310}], {
             RGBColor[
             0.2727415097182925, 0.40399899789739224`, 0.9388435975423268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 327}], {
             RGBColor[
             0.25289755432094124`, 0.38314174259533496`, 0.937713513638949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 399}], {
             RGBColor[
             0.24511345141386065`, 0.3749601568993634, 0.937270220493939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 412}], {
             RGBColor[
             0.24555371763094103`, 0.3754229046080053, 0.9372952930036862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 483}], {
             RGBColor[
             0.27268756010159706`, 0.40394229342964216`, 0.9388405251914673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 139}], {
             RGBColor[
             0.47255522666265165`, 0.5807190878311534, 0.9521624096580703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 140}], {
             RGBColor[
             0.44035466890019287`, 0.5545772244209933, 0.9496274637964799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 154}], {
             RGBColor[
             0.34530823850037556`, 0.4735103733174856, 0.9432237135065259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 247}], {
             RGBColor[
             0.4380433274875822, 0.5527007733374919, 0.9494455065337566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 255}], {
             RGBColor[
             0.38933039965095584`, 0.511640156687964, 0.9460287666877722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 269}], {
             RGBColor[
             0.41500730712434825`, 0.5338802033825223, 0.947664876526779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 338}], {
             RGBColor[
             0.3505903006321732, 0.47808543005188675`, 0.9435602818348199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 369}], {
             RGBColor[
             0.40051134864769267`, 0.5213245327381009, 0.9467412068709193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 390}], {
             RGBColor[
             0.34091437037852435`, 0.46896566133560236`, 0.9429707972165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 425}], {
             RGBColor[
             0.3782090614978762, 0.502007412554475, 0.9453201248548712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 466}], {
             RGBColor[
             0.44229172329685795`, 0.5561498124435122, 0.9497799558142495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[
             0.31734549257895406`, 0.4492904482488255, 0.9414419520628983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 151}], {
             RGBColor[
             0.31595121433390305`, 0.44790234871507695`, 0.9413597168905753]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 188}], {
             RGBColor[
             0.3311926249986076, 0.4612841383736176, 0.9423242790961401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 304}], {
             RGBColor[
             0.3318360758338559, 0.46184146314633034`, 0.9423652792143808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 310}], {
             RGBColor[
             0.3109325878407584, 0.44262745407148385`, 0.9410739135361832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 327}], {
             RGBColor[
             0.2910886324434072, 0.42177019876942656`, 0.9399438296328053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 483}], {
             RGBColor[
             0.31087863822406303`, 0.44257074960373377`, 0.9410708411853237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 197}], {
             RGBColor[
             0.8441364985929255, 0.8770550844901885, 0.8875786005274353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 237}], {
             RGBColor[
             0.9483698835729416, 0.9591789791220269, 0.8977829179807035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 270}], {
             RGBColor[
             0.9903352312511376, 0.9902713839961873, 0.8098337599957988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 309}], {
             RGBColor[
             0.9918390696706652, 0.9889511495464178, 0.6437403499501158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 320}], {
             RGBColor[
             0.9896249360090673, 0.9899776586598361, 0.8216051903420669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 345}], {
             RGBColor[
             0.8251862844410536, 0.8622510331677843, 0.8856898202805965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 375}], {
             RGBColor[
             0.9744244063754681, 0.9793738724475776, 0.8801494909995853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 426}], {
             RGBColor[
             0.9304108836330538, 0.9448589600540273, 0.8960699725342486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 489}], {
             RGBColor[
             0.9903724843514137, 0.9902867891105125, 0.8092163797162932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 123}], {
             RGBColor[
             0.20719251066229882`, 0.33510284384296096`, 0.9351106790171422]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 125}], {
             RGBColor[
             0.2080475453125366, 0.33600153947268885`, 0.9351593719755629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 177}], {
             RGBColor[
             0.20805903153131503`, 0.3360136122168933, 0.9351600260987298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 438}], {
             RGBColor[
             0.21444303080234048`, 0.3427236002196732, 0.9355235854129342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 455}], {
             RGBColor[
             0.2056810719300792, 0.33351422590464763`, 0.9350246048173154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 457}], {
             RGBColor[
             0.21450528797873675`, 0.3427890364593986, 0.9355271308670288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 161}], {
             RGBColor[
             0.9088989497892817, 0.5955852022276555, 0.2954383174204215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[
             0.8641469744095227, 0.4273429033856967, 0.2064477599128205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.86583591956703, 0.4350120088827739, 0.20785705715207875`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 259}], {
             RGBColor[
             0.8446533203330481, 0.33882677308300735`, 0.1901817771182239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 341}], {
             RGBColor[
             0.9105196563022746, 0.6003916270804778, 0.3579070077274834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 450}], {
             RGBColor[
             0.8225872124582064, 0.17462078949919407`, 0.16926284619957344`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 454}], {
             RGBColor[
             0.8636741838299911, 0.42519607178708907`, 0.20605325186410173`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 469}], {
             RGBColor[
             0.8439483097229172, 0.3356254845618147, 0.18959349898373934`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 471}], {
             RGBColor[
             0.842139262249025, 0.3249064119542755, 0.18798591116014318`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 475}], {
             RGBColor[
             0.8332346662535209, 0.256461785113985, 0.17945885997854572`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 491}], {
             RGBColor[
             0.9108136867178351, 0.6010205284083265, 0.38991040391585896`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 500}], {
             RGBColor[
             0.8234793018793516, 0.18147777970619255`, 0.1701171120367329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 150}], {
             RGBColor[
             0.8444744803276283, 0.32854420856354566`, 0.1896617078466737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.8441272348319537, 0.3258751275198433, 0.1893291851678579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 233}], {
             RGBColor[
             0.8553320507775657, 0.4120002528594733, 0.20005892957140564`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 267}], {
             RGBColor[
             0.9282834555711476, 0.7330087810415269, 0.3115827018545064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 406}], {
             RGBColor[
             0.929061342775948, 0.7356327772399205, 0.3146046467534838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 413}], {
             RGBColor[
             0.9206701650068785, 0.7073273642826143, 0.2820065056616069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 476}], {
             RGBColor[
             0.8579983660337116, 0.432494720305006, 0.20261219607186334`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 493}], {
             RGBColor[
             0.9305407827762575, 0.7399602763410837, 0.37672867587283654`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 125}], {
             RGBColor[
             0.2078185513522534, 0.33576085230137553`, 0.9351463311082908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 177}], {
             RGBColor[
             0.2078300375710318, 0.33577292504558, 0.935146985231458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 438}], {
             RGBColor[
             0.21421403684205725`, 0.34248291304835987`, 0.9355105445456623]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 455}], {
             RGBColor[
             0.20545207796979598`, 0.3332735387333343, 0.9350115639500436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 136}], {
             RGBColor[
             0.9658066058981951, 0.931025957642273, 0.6234191599847442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 178}], {
             RGBColor[
             0.977168593002762, 0.938254909924025, 0.5484416326473938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 253}], {
             RGBColor[
             0.9738421982948224, 0.9368793602278473, 0.603568601391508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 261}], {
             RGBColor[
             0.9213196831594281, 0.7168052052597729, 0.265491517223669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 357}], {
             RGBColor[
             0.9348974167088442, 0.7776187751730486, 0.27677767167712564`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 484}], {
             RGBColor[
             0.9777721242086441, 0.9364424046411297, 0.38854804229456463`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 177}], {
             RGBColor[
             0.20868507222126964`, 0.3366716206753079, 0.9351956781898786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 438}], {
             RGBColor[
             0.2150690714922951, 0.34338160867808776`, 0.9355592375040829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 455}], {
             RGBColor[
             0.20630711262003382`, 0.3341722343630622, 0.9350602569084642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 457}], {
             RGBColor[
             0.21513132866869134`, 0.3434470449178132, 0.9355627829581774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 144}], {
             RGBColor[
             0.24868278916139275`, 0.37871175718110384`, 0.937473488998299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 279}], {
             RGBColor[
             0.26484901945855754`, 0.3957034902216259, 0.9383941318979281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 285}], {
             RGBColor[
             0.28277807837083513`, 0.4140236211798849, 0.9394343678430408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 481}], {
             RGBColor[
             0.28467725623571494`, 0.41566859359098884`, 0.9395553817772139]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 130}], {
             RGBColor[
             0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 168}], {
             RGBColor[
             0.5683860156508949, 0.5194386987803812, 0.5916300590553423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 179}], {
             RGBColor[
             0.20245447418328588`, 0.33012286709465477`, 0.9348408548489592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 200}], {
             RGBColor[
             0.5634039093287206, 0.4987072281229762, 0.587570692606852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 213}], {
             RGBColor[
             0.5650928544862279, 0.5063763336200533, 0.5889799898461102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 254}], {
             RGBColor[
             0.23123903037733173`, 0.3603772607008694, 0.9364800927412753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 302}], {
             RGBColor[
             0.2080645848230672, 0.3360194490786239, 0.9351603423504797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 315}], {
             RGBColor[
             0.20573971378665917`, 0.3335758622140216, 0.9350279443842948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 325}], {
             RGBColor[
             0.20249836583685807`, 0.33016900000545074`, 0.9348433544136983]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 347}], {
             RGBColor[
             0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 368}], {
             RGBColor[
             0.3170407306432145, 0.44137417912788274`, 0.9417027210777457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 386}], {
             RGBColor[
             0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 401}], {
             RGBColor[
             0.499716094491864, 0.5888978154955886, 0.9571173753725956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 454}], {
             RGBColor[
             0.562931118749189, 0.49656039652436856`, 0.5871761845581333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 169}], {
             RGBColor[
             0.4937426983927686, 0.5998815912671589, 0.9532883803380281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 197}], {
             RGBColor[
             0.5961844176461558, 0.6822017797294064, 0.9619318024689351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 204}], {
             RGBColor[
             0.4983181319181479, 0.6035961343239933, 0.9536485752255113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 345}], {
             RGBColor[
             0.5772342034942839, 0.6673977284070023, 0.9600430222220963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 355}], {
             RGBColor[
             0.4117250076221206, 0.5299124488854325, 0.9477665145867664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 362}], {
             RGBColor[
             0.4416023765346493, 0.55579072415724, 0.9496702741143528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 498}], {
             RGBColor[
             0.4783163619958606, 0.5873577964316139, 0.9520739626283314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 170}], {
             RGBColor[
             0.3261401713486173, 0.4557924254151241, 0.9420431862919051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 206}], {
             RGBColor[
             0.3491669657996257, 0.47685260895882275`, 0.9434695881978956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 265}], {
             RGBColor[
             0.3383071396578693, 0.46744637338556605`, 0.9427776096791101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 266}], {
             RGBColor[
             0.32256025857167225`, 0.4520297101069751, 0.9418393155552645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 328}], {
             RGBColor[
             0.3704563897071251, 0.49529243790994043`, 0.944826131463783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 410}], {
             RGBColor[
             0.3596323931506261, 0.48591723612258636`, 0.9441364359744873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 433}], {
             RGBColor[
             0.3405530126531223, 0.4693916356931953, 0.94292071472042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 143}], {
             RGBColor[
             0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 179}], {
             RGBColor[
             0.17892806853100302`, 0.30539512309383293`, 0.93350106085126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 214}], {
             RGBColor[
             0.1893670574265447, 0.316367162293171, 0.9340955458257609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 254}], {
             RGBColor[
             0.20771262472504887`, 0.3356495167000475, 0.935140298743576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 302}], {
             RGBColor[
             0.18453817917078433`, 0.311291705077802, 0.9338205483527805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 315}], {
             RGBColor[
             0.1822133081343763, 0.30884811821319974`, 0.9336881503865955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 325}], {
             RGBColor[
             0.1789719601845752, 0.3054412560046289, 0.9335035604159989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 347}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 368}], {
             RGBColor[
             0.2935143249909316, 0.4166464351270609, 0.9403629270800464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 386}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 421}], {
             RGBColor[
             0.17899180289058533`, 0.3054621119467458, 0.9335046904287516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 477}], {
             RGBColor[
             0.2117993137193227, 0.3399448859440771, 0.9353730296360853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 135}], {
             RGBColor[
             0.25711790914467114`, 0.38757760310102596`, 0.937953856602705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 147}], {
             RGBColor[
             0.257551109678863, 0.38803292432896186`, 0.9379785267322645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 170}], {
             RGBColor[
             0.28014480934839103`, 0.4117803352049335, 0.9392652045040607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 171}], {
             RGBColor[
             0.26267563753313167`, 0.39341912801763035`, 0.9382703610125054]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 216}], {
             RGBColor[
             0.26474751566428445`, 0.3955968032981327, 0.9383883514070055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 238}], {
             RGBColor[
             0.29188148517230905`, 0.42306158545170824`, 0.9399722100345929]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 265}], {
             RGBColor[
             0.29231177765764305`, 0.42343428317537546`, 0.9399996278912657]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 374}], {
             RGBColor[
             0.2576696859737398, 0.38815755553304865`, 0.9379852794768397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 385}], {
             RGBColor[
             0.24854031848564526`, 0.3785620114677306, 0.9374653755040816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 391}], {
             RGBColor[
             0.2523681386345833, 0.3825852931420795, 0.9376833641988113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 433}], {
             RGBColor[
             0.29455765065289613`, 0.4253795454830047, 0.9401427329325757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 209}], {
             RGBColor[
             0.7780282420345992, 0.8243344980363514, 0.8860787195432924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 233}], {
             RGBColor[
             0.9166463543771588, 0.6614692040973338, 0.5010749461233683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 273}], {
             RGBColor[
             0.6418371637733833, 0.7080243687957053, 0.8766074186854609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 423}], {
             RGBColor[
             0.5889794016641527, 0.6524675094432201, 0.8735972473293918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 151}], {
             RGBColor[
             0.3259839947322987, 0.4565922388339624, 0.9419989967859217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 155}], {
             RGBColor[
             0.4555313931992919, 0.5659235600860384, 0.9510915748153721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 181}], {
             RGBColor[
             0.3829354312034995, 0.5061011564392373, 0.9456212849531489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 225}], {
             RGBColor[
             0.3097114792684619, 0.4394887933443991, 0.9410723011032855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 235}], {
             RGBColor[
             0.3511076947395869, 0.47853357082274445`, 0.9435932497298307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 239}], {
             RGBColor[
             0.34805209112246643`, 0.47588696054869806`, 0.943398549369312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 249}], {
             RGBColor[
             0.3173607671926588, 0.44752867994559636`, 0.9415079167344612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 260}], {
             RGBColor[
             0.31537504749154577`, 0.44544156263782575`, 0.9413948329350919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 262}], {
             RGBColor[
             0.4106297397776527, 0.5294703750419166, 0.9475567521778445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 296}], {
             RGBColor[
             0.3292967430314739, 0.4596420207034847, 0.942203475173657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 332}], {
             RGBColor[
             0.3736828594731001, 0.4980870438541423, 0.9450317192642157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 344}], {
             RGBColor[
             0.404458323018091, 0.5244601408973477, 0.9470709156438875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 424}], {
             RGBColor[
             0.33288404882225986`, 0.46274916467623195`, 0.942432055126516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 440}], {
             RGBColor[
             0.31342375230206637`, 0.44339062767442217`, 0.9412837095607336]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 138}], {
             RGBColor[
             0.2265863896100655, 0.3554870402600099, 0.9362151317325447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 251}], {
             RGBColor[
             0.24587579480159133`, 0.37576142813523083`, 0.9373136348220843]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 305}], {
             RGBColor[
             0.2421591297202534, 0.37185497748456803`, 0.9371019762440154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 367}], {
             RGBColor[
             0.23152572380893705`, 0.3606785936749, 0.9364964195080803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 416}], {
             RGBColor[
             0.24737003573452257`, 0.37733197009608865`, 0.9373987296326833]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 438}], {
             RGBColor[
             0.22733547187831532`, 0.35627437321849936`, 0.9362577908595535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 457}], {
             RGBColor[
             0.22739772905471156`, 0.3563398094582248, 0.936261336313648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 499}], {
             RGBColor[
             0.2469625122439105, 0.37690363706897373`, 0.93737552177277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 147}], {
             RGBColor[
             0.2510599689447852, 0.3812103238553528, 0.9376088658702408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 170}], {
             RGBColor[
             0.2736536686143132, 0.40495773473132446`, 0.9388955436420372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 171}], {
             RGBColor[
             0.25618449679905386`, 0.3865965275440213, 0.9379007001504819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 216}], {
             RGBColor[
             0.25825637493020664`, 0.38877420282452363`, 0.938018690544982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 385}], {
             RGBColor[
             0.24204917775156742`, 0.37173941099412156`, 0.9370957146420581]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 391}], {
             RGBColor[
             0.24587699790050546`, 0.37576269266847045`, 0.9373137033367878]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 253}], {
             RGBColor[
             0.9769962544035893, 0.9822248956493935, 0.9175751236598007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 261}], {
             RGBColor[
             0.924473739268195, 0.762150740681319, 0.5794980394919615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 277}], {
             RGBColor[
             0.8701310969045036, 0.8988186894535575, 0.9576327343932979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 291}], {
             RGBColor[
             0.8119439013123007, 0.853362410017863, 0.9518331785269256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 311}], {
             RGBColor[
             0.8579087651395905, 0.8892705109856455, 0.9564145265871555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 319}], {
             RGBColor[
             0.8419251732908781, 0.8767840075536342, 0.9548214315268342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 377}], {
             RGBColor[
             0.9750328863705816, 0.980900148051852, 0.9271469902951855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 484}], {
             RGBColor[
             0.980926180317411, 0.981787940062676, 0.7025545645628573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 488}], {
             RGBColor[
             0.8691624812525807, 0.8980619995445237, 0.9575361918373422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 145}], {
             RGBColor[
             0.2203693542453783, 0.34895254190891456`, 0.9358610807658054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 183}], {
             RGBColor[
             0.2125239415632086, 0.34070651575206007`, 0.9354142961198038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 346}], {
             RGBColor[
             0.21898159921391522`, 0.34749392338209584`, 0.9357820501697631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 358}], {
             RGBColor[
             0.22285337720406, 0.3515634075346411, 0.9360025421985196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 404}], {
             RGBColor[
             0.2167644246749318, 0.34516353236463915`, 0.9356557853597838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 407}], {
             RGBColor[
             0.2172194419002935, 0.34564178431825265`, 0.9356816979176306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 408}], {
             RGBColor[
             0.2212925375899113, 0.34992286613722345`, 0.9359136546915492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 430}], {
             RGBColor[
             0.22990978373834364`, 0.3589801382041882, 0.9364043941116291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 352}], {
             RGBColor[
             0.22389864331585435`, 0.3526620484918363, 0.9360620685572537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 367}], {
             RGBColor[
             0.22490572664447084`, 0.3537205569229832, 0.9361194204629721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 457}], {
             RGBColor[
             0.22077773189024535`, 0.349381772706308, 0.9358843372685399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 140}], {
             RGBColor[
             0.5318346221124927, 0.6308063309644387, 0.9562871161085591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 247}], {
             RGBColor[
             0.529523280699882, 0.6289298798809373, 0.9561051588458358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 255}], {
             RGBColor[
             0.4808103528632557, 0.5878692632314095, 0.9526884189998513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 269}], {
             RGBColor[
             0.506487260336648, 0.6101093099259678, 0.9543245288388581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 274}], {
             RGBColor[
             0.5133847204187874, 0.6158278696108893, 0.9548346722630138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 360}], {
             RGBColor[
             0.5717007512056378, 0.6631714505109032, 0.9594255238252141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 369}], {
             RGBColor[
             0.49199130185999246`, 0.5975536392815464, 0.9534008591829983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 370}], {
             RGBColor[
             0.5777392587332322, 0.6680737829534684, 0.9599008972575682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 425}], {
             RGBColor[
             0.469689014710176, 0.5782365190979204, 0.9519797771669503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 466}], {
             RGBColor[
             0.5337716765091578, 0.6323789189869576, 0.9564396081263286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 468}], {
             RGBColor[
             0.5212061017709153, 0.6221776193417614, 0.9554504000537172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 169}], {
             RGBColor[
             0.4961881243257401, 0.601866898204728, 0.953480893225362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 204}], {
             RGBColor[
             0.5007635578511195, 0.6055814412615623, 0.9538410881128452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 219}], {
             RGBColor[
             0.5129514818808725, 0.6154761470486363, 0.9548005661383041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 244}], {
             RGBColor[
             0.42103754660959536`, 0.5378457039996745, 0.9483965938455836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 247}], {
             RGBColor[
             0.4973227229374232, 0.6027880164707773, 0.9535702129842454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 255}], {
             RGBColor[
             0.4486097951007969, 0.5617273998212495, 0.950153473138261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 274}], {
             RGBColor[
             0.4811841626563286, 0.5896860062007292, 0.9522997264014235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 334}], {
             RGBColor[
             0.4512190714580578, 0.563987423855866, 0.9503197339204532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 361}], {
             RGBColor[
             0.5719177559547599, 0.6633194007954346, 0.9594619041005235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 363}], {
             RGBColor[
             0.4522227109181607, 0.5648567259118211, 0.9503836849393674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 369}], {
             RGBColor[
             0.4597907440975337, 0.5714117758713864, 0.950865913321408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 370}], {
             RGBColor[
             0.5455387009707735, 0.6419319195433083, 0.9573659513959778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 425}], {
             RGBColor[
             0.4374884569477172, 0.5520946556877604, 0.9494448313053598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 466}], {
             RGBColor[
             0.5015711187466989, 0.6062370555767975, 0.9539046622647382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 188}], {
             RGBColor[
             0.32343001274534444`, 0.45456055380007726`, 0.9418296523075707]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 220}], {
             RGBColor[
             0.32424804297229537`, 0.4552690904672675, 0.9418817764702763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[
             0.2831042170303842, 0.4148134850118461, 0.939436571482416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 304}], {
             RGBColor[
             0.3240734635805927, 0.45511787857278996`, 0.9418706524258115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 310}], {
             RGBColor[
             0.3031699755874952, 0.4359038694979436, 0.9405792867476138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 429}], {
             RGBColor[
             0.30159042381675216`, 0.434243660437526, 0.9404893336110074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 173}], {
             RGBColor[
             0.8420436305365226, 0.8765386852966244, 0.9380905002853989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 222}], {
             RGBColor[
             0.5711190039988594, 0.6615355308329243, 0.9600580034664301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 241}], {
             RGBColor[
             0.7025032226254809, 0.7675201238280478, 0.9709826140315919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 402}], {
             RGBColor[
             0.6259177691187879, 0.7063115685381091, 0.9642924066530247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 417}], {
             RGBColor[
             0.7002784838355302, 0.7657821409766972, 0.9707608728603756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 461}], {
             RGBColor[
             0.8219899053555546, 0.8616442791794481, 0.9747961115925544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 179}], {
             RGBColor[
             0.17892806920489446`, 0.30539512380213557`, 0.933501060889637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 214}], {
             RGBColor[
             0.18936705810043614`, 0.31636716300147366`, 0.934095545864138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 226}], {
             RGBColor[
             0.17917599682249857`, 0.3056557114477564, 0.9335151800006836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 273}], {
             RGBColor[
             0.23623420851912813`, 0.365627509640484, 0.9367645607467467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 283}], {
             RGBColor[
             0.18007058028918088`, 0.3065959753911073, 0.9335661252056935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 292}], {
             RGBColor[
             0.1789488167630598, 0.30541693080123855`, 0.9335022424323813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 302}], {
             RGBColor[
             0.1845381798446758, 0.31129170578610466`, 0.9338205483911577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 308}], {
             RGBColor[
             0.17893664305769685`, 0.3054041354650445, 0.9335015491578702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 325}], {
             RGBColor[
             0.17897196085846667`, 0.30544125671293154`, 0.9335035604543761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 347}], {
             RGBColor[
             0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 386}], {
             RGBColor[
             0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 421}], {
             RGBColor[
             0.1789918035644768, 0.3054621126550484, 0.9335046904671287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 423}], {
             RGBColor[
             0.1833764464098977, 0.31007065028799885`, 0.9337543893906777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 446}], {
             RGBColor[
             0.20353913733189777`, 0.3312629168354616, 0.9349026248106573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 477}], {
             RGBColor[
             0.21179931439321417`, 0.33994488665237976`, 0.9353730296744625]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 279}], {
             RGBColor[
             0.2623939933592224, 0.3931231021335797, 0.9382543217934566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 494}], {
             RGBColor[
             0.25236564813326057`, 0.3825826754672824, 0.9376832223684453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 183}], {
             RGBColor[
             0.21281275410739692`, 0.3410100760477749, 0.9354307435669353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 286}], {
             RGBColor[
             0.22187921582518422`, 0.3505395021600439, 0.9359470651491353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 294}], {
             RGBColor[
             0.22948545468760678`, 0.35853414146784807`, 0.9363802291999281]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 346}], {
             RGBColor[
             0.21927041175810352`, 0.3477974836778107, 0.9357984976168947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 358}], {
             RGBColor[
             0.2231421897482483, 0.351866967830356, 0.9360189896456512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 404}], {
             RGBColor[
             0.2170532372191201, 0.345467092660354, 0.9356722328069155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 407}], {
             RGBColor[
             0.2175082544444818, 0.34594534461396753`, 0.9356981453647621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 408}], {
             RGBColor[
             0.2215813501340996, 0.35022642643293833`, 0.9359301021386808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 430}], {
             RGBColor[
             0.23019859628253192`, 0.35928369849990305`, 0.9364208415587607]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 201}], {
             RGBColor[
             0.28119600247616383`, 0.41288520583171645`, 0.9393250683975864]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 211}], {
             RGBColor[
             0.2444868180291041, 0.37430152548113294`, 0.9372345346496982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 271}], {
             RGBColor[
             0.25686927492861433`, 0.3873162727756304, 0.9379396972519218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 284}], {
             RGBColor[
             0.25151293220690424`, 0.3816864169633695, 0.9376346614579194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 312}], {
             RGBColor[
             0.28117238396624933`, 0.41286038128029634`, 0.9393237233583873]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 376}], {
             RGBColor[
             0.2686941653913333, 0.39974498239330636`, 0.9386131072704159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 400}], {
             RGBColor[
             0.276927529490606, 0.4083987700870767, 0.9390819851756989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 415}], {
             RGBColor[
             0.27247295826931617`, 0.4037167332973729, 0.9388283039345939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 442}], {
             RGBColor[
             0.2709392779878975, 0.40210473808065567`, 0.9387409631114438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 444}], {
             RGBColor[
             0.2646131387661169, 0.39545556465817117`, 0.9383806988414477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 464}], {
             RGBColor[
             0.25089999678857744`, 0.38104218297635795`, 0.9375997556926023]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 497}], {
             RGBColor[
             0.24696343657246012`, 0.3769046085968852, 0.9373755744119134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 171}], {
             RGBColor[
             0.2566176973332457, 0.3870518487719572, 0.9379253702800414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 216}], {
             RGBColor[
             0.2586895754643985, 0.38922952405245953`, 0.9380433606745415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 238}], {
             RGBColor[
             0.2858235449724231, 0.4166943062060351, 0.9396272193021288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 385}], {
             RGBColor[
             0.24248237828575928`, 0.37219473222205746`, 0.9371203847716176]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 391}], {
             RGBColor[
             0.24631019843469731`, 0.37621801389640636`, 0.9373383734663472]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 153}], {
             RGBColor[
             0.2422944032111111, 0.37199715850029413`, 0.9371096798692006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 190}], {
             RGBColor[
             0.2438827304039313, 0.37366659108570865`, 0.9372001327531121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 195}], {
             RGBColor[
             0.2549038837878154, 0.3852505220736551, 0.9378277711339891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 323}], {
             RGBColor[
             0.23950025424315785`, 0.36906033077569844`, 0.9369505572190486]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 342}], {
             RGBColor[
             0.2498214928286487, 0.3799086069333723, 0.9375383364875882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 351}], {
             RGBColor[
             0.26485064633186906`, 0.3957052001686261, 0.9383942245459564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 356}], {
             RGBColor[
             0.2544968866209464, 0.384822742246165, 0.9378045932474341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 452}], {
             RGBColor[
             0.23180463347080354`, 0.3609717454134156, 0.9365123030007138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 463}], {
             RGBColor[
             0.25337660171868737`, 0.3836452517837254, 0.9377407946795635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 158}], {
             RGBColor[
             0.3556980515257828, 0.48250950715290686`, 0.943885743205154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 165}], {
             RGBColor[
             0.3889540140770109, 0.511314150421502, 0.9460047837318252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 182}], {
             RGBColor[
             0.36623071660169665`, 0.4916323722545241, 0.9445568753101211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 187}], {
             RGBColor[
             0.30925143443909986`, 0.4382007802607746, 0.9410755580672832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 275}], {
             RGBColor[
             0.38378936730216673`, 0.5068407929678266, 0.9456756970062499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 282}], {
             RGBColor[
             0.48076658116172494`, 0.586646877963116, 0.9530129031646457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 324}], {
             RGBColor[
             0.361776111320833, 0.4877740170552114, 0.9442730318006773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 441}], {
             RGBColor[
             0.4020035872776604, 0.5226170348372846, 0.946836290996886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 159}], {
             RGBColor[
             0.821097410502475, 0.1631695188320622, 0.16783621016427433`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 233}], {
             RGBColor[
             0.832302226448087, 0.24929464417169217`, 0.1785659545678221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 267}], {
             RGBColor[
             0.9052536312416688, 0.5703031723537458, 0.2900897268509228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 406}], {
             RGBColor[
             0.9060315184464693, 0.5729271685521393, 0.29311167174990027`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 413}], {
             RGBColor[
             0.8976403406773998, 0.5446217555948332, 0.26051353065802335`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 443}], {
             RGBColor[
             0.8779783180841267, 0.47195372718941886`, 0.21716686938390278`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 476}], {
             RGBColor[
             0.834968541704233, 0.26978911161722496`, 0.18111922106827977`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 188}], {
             RGBColor[
             0.32203573450029344`, 0.4531724542663287, 0.9417474171352478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 192}], {
             RGBColor[
             0.28070448165153206`, 0.4123685862808082, 0.9392970770137636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 249}], {
             RGBColor[
             0.29817109629594896`, 0.43072710571942197`, 0.9402917748782225]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 260}], {
             RGBColor[
             0.2961853765948359, 0.4286399884116514, 0.940178691078853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 280}], {
             RGBColor[
             0.2818433506476452, 0.4135656098041881, 0.9393619339182866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 310}], {
             RGBColor[
             0.3017756973424442, 0.43451576996419494`, 0.9404970515752908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 327}], {
             RGBColor[
             0.28193174194509296`, 0.41365851466213766`, 0.939366967671913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 424}], {
             RGBColor[
             0.31369437792555, 0.4459475904500576, 0.9412159132702771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 483}], {
             RGBColor[
             0.3017217477257488, 0.43445906549644486`, 0.9404939792244313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 191}], {
             RGBColor[
             0.21120215837255008`, 0.3393172378127832, 0.9353390225224988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 212}], {
             RGBColor[
             0.21125959360220817`, 0.3393776058807578, 0.93534229337386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 287}], {
             RGBColor[
             0.20690732578417442`, 0.33480309645428663`, 0.9350944381602262]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 299}], {
             RGBColor[
             0.20658465608391344`, 0.3344639501408717, 0.9350760625981434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 301}], {
             RGBColor[
             0.2063778078751808, 0.33424653955855976`, 0.9350642828986606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 389}], {
             RGBColor[
             0.21125135912011495`, 0.33936895091798147`, 0.9353418244322866]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 451}], {
             RGBColor[
             0.20772437674817806`, 0.3356618688214776, 0.9351409680039076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 190}], {
             RGBColor[
             0.24652129125596123`, 0.3764398858356126, 0.9373503948902342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 195}], {
             RGBColor[
             0.2575424446398453, 0.3880238168235591, 0.9379780332711112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 263}], {
             RGBColor[
             0.25916680795964386`, 0.3897311256632503, 0.9380705383591434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 323}], {
             RGBColor[
             0.24213881509518778`, 0.3718336255256024, 0.9371008193561707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 342}], {
             RGBColor[
             0.25246005368067864`, 0.38268190168327626`, 0.9376885986247103]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 351}], {
             RGBColor[
             0.267489207183899, 0.39847849491853005`, 0.9385444866830785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[
             0.2571354474729763, 0.3875960369960689, 0.9379548553845563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 395}], {
             RGBColor[
             0.2549602684410159, 0.3853097859191623, 0.9378309821565751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 447}], {
             RGBColor[
             0.24571645560416666`, 0.3755939525360489, 0.9373045606905122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 452}], {
             RGBColor[
             0.2344431943228335, 0.36374504016331954`, 0.9366625651378359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 463}], {
             RGBColor[
             0.25601516257071727`, 0.38641854653362934`, 0.9378910568166856]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 174}], {
             RGBColor[
             0.2880991557381853, 0.4200673355937856, 0.9397208847641902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 229}], {
             RGBColor[
             0.3002585012900294, 0.4328475787158096, 0.940413341505228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 255}], {
             RGBColor[
             0.3535633647009796, 0.4806605487177418, 0.9437497228483069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 313}], {
             RGBColor[
             0.2882495492104231, 0.42022540866860447`, 0.9397294494499471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 338}], {
             RGBColor[
             0.314823265682197, 0.4471058220816644, 0.9412812379953546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 369}], {
             RGBColor[
             0.36474431369771637`, 0.4903449247678786, 0.944462163031454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 379}], {
             RGBColor[
             0.3094202014132221, 0.4424259593777846, 0.9409369595178776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 380}], {
             RGBColor[
             0.2911961325222311, 0.423322454553487, 0.9398972530104752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 390}], {
             RGBColor[
             0.30514733542854805`, 0.43798605336538, 0.9406917533770347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 425}], {
             RGBColor[
             0.3424420265478999, 0.47102780458425264`, 0.9430410810154058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 478}], {
             RGBColor[
             0.28779157321631055`, 0.419744046861437, 0.9397033683945971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 181}], {
             RGBColor[
             0.49329315877378277`, 0.5986309034651389, 0.9534977211263604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 235}], {
             RGBColor[
             0.4614654223098702, 0.5710633178486462, 0.9514696859030422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 262}], {
             RGBColor[
             0.520987467347936, 0.6220001220678183, 0.9554331883510561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 332}], {
             RGBColor[
             0.4840405870433834, 0.5906167908800439, 0.9529081554374272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 344}], {
             RGBColor[
             0.5148160505883743, 0.6169898879232494, 0.9549473518170989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 387}], {
             RGBColor[
             0.6705014636086952, 0.7413486854414358, 0.9685938847155504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 393}], {
             RGBColor[
             0.5135503027141461, 0.615962296777659, 0.9548477075078524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 403}], {
             RGBColor[
             0.7474005481861847, 0.8023032590432388, 0.9760248292713649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 232}], {
             RGBColor[
             0.4117533959329014, 0.5306819361106889, 0.9475625057353367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 307}], {
             RGBColor[
             0.4685593666518582, 0.5794366280637215, 0.9513058562137999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 350}], {
             RGBColor[
             0.41473957912155346`, 0.5332684178987681, 0.9477527826875395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 354}], {
             RGBColor[
             0.4145365045344412, 0.533092524898237, 0.9477398429544205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 372}], {
             RGBColor[
             0.46888111877498084`, 0.5796978409320405, 0.951331185719549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 479}], {
             RGBColor[
             0.4393999195807523, 0.5546279653397757, 0.9493241177753168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 180}], {
             RGBColor[
             0.2863372761085622, 0.4182890103949429, 0.9396178563251187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 216}], {
             RGBColor[
             0.28421479544229167`, 0.41605814864164575`, 0.9394969841911034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 238}], {
             RGBColor[
             0.31134876495031627`, 0.4435229307952213, 0.9410808428186908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 246}], {
             RGBColor[
             0.2983825090164457, 0.4309493138930047, 0.9403038145198976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 281}], {
             RGBColor[
             0.2737261355645935, 0.4050339020907391, 0.9388996705276503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 288}], {
             RGBColor[
             0.2793047597177943, 0.4108973897809534, 0.9392173649203402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 343}], {
             RGBColor[
             0.2977155588527831, 0.4302483069839126, 0.9402658326947413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 392}], {
             RGBColor[
             0.3042725009406671, 0.4371400688524187, 0.9406392408465198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 459}], {
             RGBColor[
             0.3465448636437761, 0.4740080224761397, 0.94332350710475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 465}], {
             RGBColor[
             0.2925845958094424, 0.42485533950351484`, 0.9399736319400027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 182}], {
             RGBColor[
             0.36805399542884243`, 0.4932116047339394, 0.9446730530247247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 206}], {
             RGBColor[
             0.3501277440364893, 0.4776847867774757, 0.9435308081375656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 282}], {
             RGBColor[
             0.4825898599888707, 0.5882261104425313, 0.9531290808792493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 324}], {
             RGBColor[
             0.3635993901479788, 0.48935324953462667`, 0.9443892095152808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 410}], {
             RGBColor[
             0.3605931713874897, 0.48674941394123933`, 0.9441976559141574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 441}], {
             RGBColor[
             0.4038268661048062, 0.5241962673166999, 0.9469524687114896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 164}], {
             RGBColor[
             0.819137437150352, 0.14810430478184575`, 0.1659593374688081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 396}], {
             RGBColor[
             0.9071481131704897, 0.5745522202562454, 0.3532052383412315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 443}], {
             RGBColor[
             0.877631072588452, 0.4692846461457165, 0.21683434670508697`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 165}], {
             RGBColor[
             0.4232575021072018, 0.5410261076098133, 0.9481905716557255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 268}], {
             RGBColor[
             0.41606826400089775`, 0.5347991509037464, 0.9477324797607855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 275}], {
             RGBColor[
             0.4180928553323577, 0.5365527501561378, 0.9478614849301503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 285}], {
             RGBColor[
             0.3684500451199806, 0.49355464307036695`, 0.9446982889608311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 324}], {
             RGBColor[
             0.3960795993510239, 0.5174859742435227, 0.9464588197245776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 353}], {
             RGBColor[
             0.531072144514868, 0.6293500407838779, 0.9564584330755022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 441}], {
             RGBColor[
             0.4363070753078513, 0.5523289920255958, 0.9490220789207864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 480}], {
             RGBColor[
             0.3880144919727734, 0.5105003835965654, 0.94594491821413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 481}], {
             RGBColor[
             0.3703492229848604, 0.49519961548147085`, 0.9448193028950042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 259}], {
             RGBColor[
             0.9260863286561598, 0.722291136783578, 0.31168537193130974`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 326}], {
             RGBColor[
             0.9327537347132191, 0.7525662704764362, 0.31724881897839763`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 341}], {
             RGBColor[
             0.9919526646253864, 0.9838559907810486, 0.4794106025405692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 387}], {
             RGBColor[
             0.8827228822801044, 0.901646814849579, 0.6975808353380122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 403}], {
             RGBColor[
             0.9596219668575938, 0.962601388451382, 0.7050117798938269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 405}], {
             RGBColor[
             0.9921723207517021, 0.9843258130245969, 0.5033188163295588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 450}], {
             RGBColor[
             0.9040202207813182, 0.5580851531997648, 0.2907664410126593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 469}], {
             RGBColor[
             0.9253813180460291, 0.7190898482623855, 0.3110970937968252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 491}], {
             RGBColor[
             0.992246695040947, 0.9844848921088973, 0.5114139987289448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 203}], {
             RGBColor[
             0.4982990262412239, 0.6035806234747654, 0.9536470711566374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 221}], {
             RGBColor[
             0.4993207487803075, 0.6044101038600693, 0.953727504897607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 223}], {
             RGBColor[
             0.4259476007932227, 0.5431195461878823, 0.9484273528030159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 258}], {
             RGBColor[
             0.4177269296537439, 0.5359992140298111, 0.9479035389072623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 289}], {
             RGBColor[
             0.45070123455015054`, 0.5645598995943251, 0.9500046324572284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 297}], {
             RGBColor[
             0.4906978130641887, 0.5974096161868968, 0.9530486758111798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 381}], {
             RGBColor[
             0.515668109442376, 0.6176816276857418, 0.9550144290112803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 439}], {
             RGBColor[
             0.6614719504889517, 0.7330346033014116, 0.9686938737233264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 187}], {
             RGBColor[
             0.2658102034815037, 0.3967137555723293, 0.9384488699060904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.2633838374698597, 0.39416349105360093`, 0.9383106919512142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 322}], {
             RGBColor[
             0.26310542995763675`, 0.3938708671061988, 0.9382948370552601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 364}], {
             RGBColor[
             0.2627794929075267, 0.39352828660093053`, 0.938276275422437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 437}], {
             RGBColor[
             0.26141138655191587`, 0.3920903200782306, 0.9381983637894169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 494}], {
             RGBColor[
             0.262747921993954, 0.39349510356905415`, 0.938274477505614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 166}], {
             RGBColor[
             0.8278225605966679, 0.21486196943559147`, 0.17427622148944416`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 227}], {
             RGBColor[
             0.8315779382096691, 0.24372744738608088`, 0.17787237533274636`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 309}], {
             RGBColor[
             0.9052777371288019, 0.5616050038337315, 0.3236174733815438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 348}], {
             RGBColor[
             0.8887181595032059, 0.5060713797566354, 0.23158979527643736`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 396}], {
             RGBColor[
             0.9055353853140414, 0.5621560872497313, 0.3516608883245811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 428}], {
             RGBColor[
             0.8239291026561835, 0.1849351455808791, 0.17054784176860438`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 443}], {
             RGBColor[
             0.8760183447320038, 0.45688851313920237`, 0.21528999668843654`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 182}], {
             RGBColor[
             0.4013099579800705, 0.5220162480025345, 0.9467920935513959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 268}], {
             RGBColor[
             0.4168440173490807, 0.5354710694634455, 0.9477819100781599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 275}], {
             RGBColor[
             0.41886860868054065`, 0.537224668715837, 0.9479109152475247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 282}], {
             RGBColor[
             0.5158458225400988, 0.6170307537111264, 0.9552481214059205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 285}], {
             RGBColor[
             0.3692257984681636, 0.49422656163006606`, 0.9447477192782054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 324}], {
             RGBColor[
             0.3968553526992069, 0.5181578928032218, 0.9465082500419522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 353}], {
             RGBColor[
             0.531847897863051, 0.630021959343577, 0.9565078633928767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 441}], {
             RGBColor[
             0.4370828286560343, 0.553000910585295, 0.9490715092381609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 481}], {
             RGBColor[
             0.3711249763330434, 0.49587153404117, 0.9448687332123786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 210}], {
             RGBColor[
             0.8370920629652436, 0.28611142656230293`, 0.18315270742599782`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 227}], {
             RGBColor[
             0.8418757895124331, 0.32288124504634075`, 0.18773360937003286`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 243}], {
             RGBColor[
             0.838713260625803, 0.29857266219470613`, 0.18470516813663024`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 309}], {
             RGBColor[
             0.9155755884315661, 0.6407588014939913, 0.33347870741883034`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 320}], {
             RGBColor[
             0.9133614547699682, 0.6417853106074096, 0.5113435478107814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 348}], {
             RGBColor[
             0.8990160108059699, 0.5852251774168952, 0.24145102931372386`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 428}], {
             RGBColor[
             0.8342269539589475, 0.26408894324113896`, 0.18040907580589088`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 495}], {
             RGBColor[
             0.8401614416386582, 0.3097040160564781, 0.18609194791002698`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 210}], {
             RGBColor[
             0.9113669843928855, 0.6334814540290358, 0.5263699322609554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 326}], {
             RGBColor[
             0.9309228830343801, 0.7574193985269815, 0.5440638154599668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 434}], {
             RGBColor[
             0.988936416573675, 0.989692938179159, 0.8330157392176978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 474}], {
             RGBColor[
             0.9898837045140847, 0.9900846660867081, 0.8173167265425048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 495}], {
             RGBColor[
             0.9144363630663, 0.657074043523211, 0.5293091727449846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 200}], {
             RGBColor[
             0.9058101136750496, 0.6632964389017137, 0.24302016366679569`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 213}], {
             RGBColor[
             0.9074990588325569, 0.6709655443987909, 0.2444294609060539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 254}], {
             RGBColor[
             0.5736452347236608, 0.5249664714796068, 0.591929563801219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 261}], {
             RGBColor[
             0.8953895182633258, 0.6159789489289689, 0.23432496342308617`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 315}], {
             RGBColor[
             0.5481459181329882, 0.49816507299275914`, 0.5904774154442385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 368}], {
             RGBColor[
             0.6594469349895435, 0.6059633899066202, 0.5971521921376893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 401}], {
             RGBColor[
             0.842122298838193, 0.7534870262743261, 0.6125668464325392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 500}], {
             RGBColor[
             0.8651424411448785, 0.41743131522220955`, 0.2066895157907081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 204}], {
             RGBColor[
             0.4973176178268257, 0.6027838719120118, 0.9535698110912385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 219}], {
             RGBColor[
             0.5095055418565787, 0.6126785776990856, 0.9545292891166974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 244}], {
             RGBColor[
             0.4175916065853016, 0.5350481346501237, 0.9481253168239769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 274}], {
             RGBColor[
             0.4777382226320348, 0.5868884368511786, 0.9520284493798168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 334}], {
             RGBColor[
             0.44777313143376407`, 0.5611898545063152, 0.9500484568988465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 337}], {
             RGBColor[
             0.6764764422213522, 0.7452210038115648, 0.9698692373870139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 340}], {
             RGBColor[
             0.41508837309382146`, 0.5328799596159772, 0.9479658129994224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 361}], {
             RGBColor[
             0.5684718159304661, 0.6605218314458838, 0.9591906270789168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 363}], {
             RGBColor[
             0.44877677089386697`, 0.5620591565622703, 0.9501124079177607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 370}], {
             RGBColor[
             0.5420927609464797, 0.6391343501937576, 0.9570946743743712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 498}], {
             RGBColor[
             0.4773158479045384, 0.5865455340196324, 0.9519951984940587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 171}], {
             RGBColor[
             0.2792113970027737, 0.4107992596479288, 0.9392120480518376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 238}], {
             RGBColor[
             0.3084172446419511, 0.44044171708200675`, 0.940913897073925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 265}], {
             RGBColor[
             0.3088475371272851, 0.4408144148056739, 0.9409413149305978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 266}], {
             RGBColor[
             0.29310065604108804`, 0.425397751527083, 0.9400030208067522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 328}], {
             RGBColor[
             0.3409967871765409, 0.4686604793300483, 0.9429898367152708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 374}], {
             RGBColor[
             0.2742054454433818, 0.40553768716334715`, 0.9389269665161719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 433}], {
             RGBColor[
             0.31109341012253816`, 0.4427596771133032, 0.9410844199719078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 216}], {
             RGBColor[
             0.26381410331866717`, 0.39461572774112796`, 0.9383351949547825]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 238}], {
             RGBColor[
             0.2909480728266918, 0.4220805098947036, 0.9399190535823698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 265}], {
             RGBColor[
             0.29137836531202577`, 0.42245320761837074`, 0.9399464714390425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 343}], {
             RGBColor[
             0.2773148667291586, 0.40880588608339485`, 0.9391040434584204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 385}], {
             RGBColor[
             0.24760690614002792`, 0.37758093591072595`, 0.9374122190518586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 391}], {
             RGBColor[
             0.25143472628896596`, 0.3816042175850748, 0.9376302077465881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 433}], {
             RGBColor[
             0.2936242383072788, 0.42439846992600005`, 0.9400895764803525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 465}], {
             RGBColor[
             0.27218390368581785`, 0.4034129186029971, 0.9388118427036817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 303}], {
             RGBColor[
             0.32845548787730483`, 0.4585909264869045, 0.9421616772940785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 366}], {
             RGBColor[
             0.3083293758751098, 0.43743710670339436`, 0.941015524989468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 448}], {
             RGBColor[
             0.45979588464643895`, 0.5695615806771241, 0.9513786855523698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 473}], {
             RGBColor[
             0.3392418574009336, 0.4682559789143286, 0.9428371690671595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 241}], {
             RGBColor[
             0.8450225482014433, 0.8788658384170731, 0.9383874109586698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 417}], {
             RGBColor[
             0.8427978094114925, 0.8771278555657226, 0.9381656697874536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 461}], {
             RGBColor[
             0.9645092309315171, 0.9729899937684735, 0.9422009085196323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 493}], {
             RGBColor[
             0.9890701085039466, 0.9882775676582451, 0.7238989830539463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 215}], {
             RGBColor[
             0.2753901052316153, 0.40678283971254936`, 0.9389944311385647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 229}], {
             RGBColor[
             0.2788164534778155, 0.4103841489623319, 0.9391895566023578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 294}], {
             RGBColor[
             0.2524849252558091, 0.3827080432856873, 0.9376900150241196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 338}], {
             RGBColor[
             0.29338121786998295`, 0.4246423923281867, 0.9400574530924843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 356}], {
             RGBColor[
             0.2679975194043914, 0.3990127632911238, 0.938573434312055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 390}], {
             RGBColor[
             0.28370528761633407`, 0.41552262361190234`, 0.9394679684741645]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 430}], {
             RGBColor[
             0.2531980668507343, 0.38345760031774234`, 0.9377306273829522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 309}], {
             RGBColor[
             0.9743805147039586, 0.9770030600582216, 0.7213206267986814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 320}], {
             RGBColor[
             0.9721663810423609, 0.9780295691716399, 0.8991854671906325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 337}], {
             RGBColor[
             0.9079704822927377, 0.9289384814961321, 0.9731750764283525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 348}], {
             RGBColor[
             0.9578209370783626, 0.9214694359811255, 0.6292929486935749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 361}], {
             RGBColor[
             0.7999658560018515, 0.8442393091304512, 0.9624964661202554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 370}], {
             RGBColor[
             0.7735868010178651, 0.822851827878325, 0.9604005134157099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 375}], {
             RGBColor[
             0.9569658514087618, 0.9674257829593813, 0.9577297678481509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 197}], {
             RGBColor[
             0.6522851143834272, 0.7277468526483104, 0.9663482548197164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 237}], {
             RGBColor[
             0.7565184993634433, 0.8098707472801487, 0.9765525722729846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 345}], {
             RGBColor[
             0.6333349002315553, 0.7129428013259062, 0.9644594745728776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 426}], {
             RGBColor[
             0.7385594994235554, 0.7955507282121491, 0.9748396268265297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 448}], {
             RGBColor[
             0.587441960125221, 0.6759508730452015, 0.9606647294533119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 245}], {
             RGBColor[
             0.21512971428686242`, 0.34344534810015337`, 0.9355626910215206]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 438}], {
             RGBColor[
             0.21508055771107348`, 0.3433936814222922, 0.9355598916272501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 455}], {
             RGBColor[
             0.2063185988388122, 0.33418430710726665`, 0.9350609110316312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 357}], {
             RGBColor[
             0.9494134599221778, 0.8301932628763469, 0.5158066666080678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 420}], {
             RGBColor[
             0.9801637329335828, 0.9834819259202605, 0.8627171585529716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 439}], {
             RGBColor[
             0.9262985601874452, 0.9413808299607197, 0.8870332114673454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 236}], {
             RGBColor[
             0.23312614698427564`, 0.36236073990487094`, 0.9365875612403018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 254}], {
             RGBColor[
             0.20771369325605188`, 0.33565063979388043`, 0.9351403595948358]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 276}], {
             RGBColor[
             0.39923464670294595`, 0.5037029404652202, 0.9483463693708659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 283}], {
             RGBColor[
             0.18007164814629245`, 0.3065970977766376, 0.9335661860185762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 292}], {
             RGBColor[
             0.17894988462017136`, 0.30541805318676885`, 0.9335023032452641]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 315}], {
             RGBColor[
             0.18221437666537932`, 0.3088492413070327, 0.9336882112378554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 325}], {
             RGBColor[
             0.1789730287155782, 0.30544237909846184`, 0.9335036212672588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 347}], {
             RGBColor[
             0.17892806853100302`, 0.30539512309383293`, 0.93350106085126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 368}], {
             RGBColor[
             0.2935153935219346, 0.41664755822089383`, 0.9403629879313062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 386}], {
             RGBColor[
             0.17892806853100302`, 0.30539512309383293`, 0.93350106085126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 401}], {
             RGBColor[
             0.47619075737058414`, 0.5641711945885997, 0.9557776422261561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 216}], {
             RGBColor[
             0.2680084621160904, 0.3990242647749275, 0.9385740574832979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 281}], {
             RGBColor[
             0.2575198022383923, 0.3880000182240208, 0.9379767438198447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 288}], {
             RGBColor[
             0.2630984263915931, 0.39386350591423513`, 0.9382944382125347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 343}], {
             RGBColor[
             0.28150922552658186`, 0.4132144231171943, 0.9393429059869358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 392}], {
             RGBColor[
             0.2880661676144659, 0.4201061849857004, 0.9397163141387143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 465}], {
             RGBColor[
             0.27637826248324115`, 0.40782145563679656`, 0.9390507052321971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 235}], {
             RGBColor[
             0.38886946031407776`, 0.511240914201845, 0.9459993960408191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 239}], {
             RGBColor[
             0.38581385669695734`, 0.5085943039277986, 0.9458046956803003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 262}], {
             RGBColor[
             0.4483915053521436, 0.5621777184210172, 0.9499628984888329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 296}], {
             RGBColor[
             0.3670585086059648, 0.49234936408258523`, 0.9446096214846453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 332}], {
             RGBColor[
             0.41144462504759094`, 0.5307943872332428, 0.947437865575204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 344}], {
             RGBColor[
             0.4422200885925819, 0.5571674842764482, 0.9494770619548758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 387}], {
             RGBColor[
             0.5979055016129029, 0.6815262817946347, 0.9631235948533272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 393}], {
             RGBColor[
             0.4409543407183537, 0.5561398931308579, 0.9493774176456293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 424}], {
             RGBColor[
             0.3706458143967508, 0.4954565080553325, 0.9448382014375043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 275}], {
             RGBColor[
             0.39614531120522645`, 0.517542890548859, 0.9464630068258206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 282}], {
             RGBColor[
             0.4931225250647846, 0.5973489755441486, 0.9538002129842165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 324}], {
             RGBColor[
             0.37413205522389265`, 0.49847611463624397`, 0.9450603416202481]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 441}], {
             RGBColor[
             0.41435953118072005`, 0.5333191324183171, 0.9476236008164568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 346}], {
             RGBColor[
             0.21142499907593382`, 0.3395514575209563, 0.9353517129708931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 404}], {
             RGBColor[
             0.20920782453695042`, 0.33722106650349953`, 0.9352254481609139]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 407}], {
             RGBColor[
             0.2096628417623121, 0.3376993184571131, 0.9352513607187605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 408}], {
             RGBColor[
             0.21373593745192992`, 0.3419804002760839, 0.9354833174926791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 192}], {
             RGBColor[
             0.25582325613433854`, 0.3862168407014245, 0.9378801280290341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 225}], {
             RGBColor[
             0.2656405828545585, 0.396535473538841, 0.9384392102623171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 249}], {
             RGBColor[
             0.2732898707787555, 0.40457536014003825`, 0.9388748258934928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 260}], {
             RGBColor[
             0.2713041510776424, 0.40248824283226764`, 0.9387617420941234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 280}], {
             RGBColor[
             0.2569621251304517, 0.38741386422480434`, 0.9379449849335569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 424}], {
             RGBColor[
             0.28881315240835653`, 0.41979584487067384`, 0.9397989642855475]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 440}], {
             RGBColor[
             0.26935285588816305`, 0.4004373078688641, 0.9386506187197652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 453}], {
             RGBColor[
             0.2706693526642461, 0.401821029451244, 0.9387255912635806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 470}], {
             RGBColor[
             0.2562569900664413, 0.3866727225643841, 0.9379048285348154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 193}], {
             RGBColor[
             0.28587823371129695`, 0.41780652773044813`, 0.9395917145396869]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 196}], {
             RGBColor[
             0.2898220421197416, 0.4219517204196188, 0.9398163085942062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 318}], {
             RGBColor[
             0.3129435362062064, 0.4431846498190406, 0.9412454229080396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 321}], {
             RGBColor[
             0.30856010126890854`, 0.43938793879419913`, 0.9409661143099544]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 330}], {
             RGBColor[
             0.29519715135054264`, 0.42760130102279975`, 0.9401224131131387]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 335}], {
             RGBColor[
             0.28035846079175497`, 0.4120048964181928, 0.9392773716376912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 350}], {
             RGBColor[
             0.3230573711356193, 0.45194474529877393`, 0.9418898675264287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 383}], {
             RGBColor[
             0.3064436349421723, 0.43755476203867083`, 0.9408312549471323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 409}], {
             RGBColor[
             0.262750205623448, 0.39349750380844273`, 0.9382746075549353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 482}], {
             RGBColor[
             0.32121309396000997`, 0.4503473251053272, 0.9417723518156291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 496}], {
             RGBColor[
             0.2804171463023576, 0.4120665786107125, 0.9392807136907027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 191}], {
             RGBColor[
             0.22705589567091367`, 0.35598052089836485`, 0.936241869408138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 202}], {
             RGBColor[
             0.2373837352876954, 0.3668357351584549, 0.9368300245956442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 212}], {
             RGBColor[
             0.22711333090057176`, 0.3560408889663394, 0.9362451402594992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 295}], {
             RGBColor[
             0.23264914651192115`, 0.36185938216484964`, 0.9365603967690603]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 300}], {
             RGBColor[
             0.23083402862066274`, 0.35995157817601575`, 0.9364570284903794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 389}], {
             RGBColor[
             0.22710509641847854`, 0.3560322340035631, 0.9362446713179258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 414}], {
             RGBColor[
             0.255184189019674, 0.3855451406447167, 0.937843734102269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 456}], {
             RGBColor[
             0.22968446940414386`, 0.35874331855319036`, 0.9363915627936191]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 485}], {
             RGBColor[
             0.24185580045044375`, 0.3715361591898116, 0.9370847020908353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 322}], {
             RGBColor[
             0.2619233226556958, 0.392628397381927, 0.9382275177931856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 494}], {
             RGBColor[
             0.26156581469201307`, 0.3922526338447824, 0.9382071582435395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 304}], {
             RGBColor[
             0.33792059600024626`, 0.4671115686975821, 0.9427529794590535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 310}], {
             RGBColor[
             0.3170171080071488, 0.4478975596227356, 0.9414616137808558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 483}], {
             RGBColor[
             0.31696315839045336`, 0.4478408551549855, 0.9414585414299963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 266}], {
             RGBColor[
             0.2746480537102089, 0.4060028965147674, 0.9389521724021874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 364}], {
             RGBColor[
             0.25917101959394173`, 0.3897355523579304, 0.9380707782054862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 374}], {
             RGBColor[
             0.2557528431125027, 0.3861428321510315, 0.9378761181116072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 437}], {
             RGBColor[
             0.25780291323833093`, 0.38829758583523044`, 0.9379928665724662]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 195}], {
             RGBColor[
             0.25913077183266553`, 0.38969324940897365`, 0.9380684861550228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 224}], {
             RGBColor[
             0.2735379552710175, 0.40483611267087094`, 0.938888953938319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 263}], {
             RGBColor[
             0.26075513515246407`, 0.3914005582486648, 0.9381609912430551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 323}], {
             RGBColor[
             0.243727142288008, 0.373503058111017, 0.9371912722400824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 342}], {
             RGBColor[
             0.25404838087349885`, 0.38435133426869084`, 0.9377790515086218]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 351}], {
             RGBColor[
             0.2690775343767192, 0.40014792750394457`, 0.9386349395669901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 356}], {
             RGBColor[
             0.2587237746657965, 0.38926546958148345`, 0.9380453082684679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 395}], {
             RGBColor[
             0.2565485956338361, 0.38697921850457684`, 0.9379214350404868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 452}], {
             RGBColor[
             0.2360315215156537, 0.3654144727487341, 0.9367530180217474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 463}], {
             RGBColor[
             0.2576034897635375, 0.3880879791190439, 0.9379815097005972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 212}], {
             RGBColor[
             0.21845881642544385`, 0.3469444455250692, 0.9357522784633475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 218}], {
             RGBColor[
             0.2251871593264507, 0.3540163605156067, 0.9361354476378685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 287}], {
             RGBColor[
             0.21410654860741013`, 0.342369936098598, 0.9355044232497137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 295}], {
             RGBColor[
             0.22399463203679326`, 0.35276293872357944`, 0.9360675349729086]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 299}], {
             RGBColor[
             0.21378387890714912`, 0.3420307897851831, 0.935486047687631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 300}], {
             RGBColor[
             0.22217951414553483`, 0.3508551347347456, 0.9359641666942277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 301}], {
             RGBColor[
             0.2135770306984165, 0.34181337920287114`, 0.935474267988148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 389}], {
             RGBColor[
             0.21845058194335062`, 0.3469357905622929, 0.9357518095217741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 451}], {
             RGBColor[
             0.21492359957141377`, 0.343228708465789, 0.9355509530933952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 456}], {
             RGBColor[
             0.22102995492901595`, 0.34964687511192016`, 0.9358987009974674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[
             0.26443196618769516`, 0.395265140791245, 0.9383703813311275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 249}], {
             RGBColor[
             0.27208125411189216`, 0.40330502739244223`, 0.938805996962303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 260}], {
             RGBColor[
             0.27009553441077905`, 0.4012179100846716, 0.9386929131629338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 280}], {
             RGBColor[
             0.25575350846358835`, 0.3861435314772083, 0.9378761560023672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 327}], {
             RGBColor[
             0.25584189976103616`, 0.38623643633515786`, 0.9378811897559938]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 470}], {
             RGBColor[
             0.255048373399578, 0.3854023898167881, 0.9378359996036256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 483}], {
             RGBColor[
             0.275631905541692, 0.4070369871694651, 0.9390082013085121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 196}], {
             RGBColor[
             0.29175552637074975`, 0.4239839349574104, 0.9399264176619675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 202}], {
             RGBColor[
             0.2634343891958272, 0.39421662412275726`, 0.9383135707972234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 232}], {
             RGBColor[
             0.32200467219797546`, 0.4513904780484862, 0.9418096996419872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 330}], {
             RGBColor[
             0.2971306356015508, 0.42963351556059126`, 0.9402325221809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 350}], {
             RGBColor[
             0.3249908553866274, 0.4539769598365655, 0.94199997659419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 354}], {
             RGBColor[
             0.3247877807995152, 0.4538010668360344, 0.941987036861071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 376}], {
             RGBColor[
             0.2836334092052663, 0.4154470748445156, 0.9394638751049887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 414}], {
             RGBColor[
             0.28123484292780576`, 0.41292602960901903`, 0.9393272803038482]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 415}], {
             RGBColor[
             0.28741220208324925`, 0.41941882574858214`, 0.9396790717691668]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 485}], {
             RGBColor[
             0.2679064543585755, 0.3989170481541139, 0.9385682482924145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 496}], {
             RGBColor[
             0.28235063055336573`, 0.41409879314850406`, 0.939390822758464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 228}], {
             RGBColor[
             0.9897986964683487, 0.9881510016226367, 0.6807237889593197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 388}], {
             RGBColor[
             0.9663440953419832, 0.9740339462184904, 0.9245637966956991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 490}], {
             RGBColor[
             0.9885348242076832, 0.9895268694153684, 0.8396711640099095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 224}], {
             RGBColor[
             0.28455910865490164`, 0.41642004365881735`, 0.9395165923191959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 263}], {
             RGBColor[
             0.27177628853634817`, 0.40298448923661123`, 0.9387886296239321]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 296}], {
             RGBColor[
             0.29178587282524443`, 0.4235837043718764, 0.9399439681205266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 323}], {
             RGBColor[
             0.2547482956718921, 0.38508698909896344`, 0.9378189106209592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 342}], {
             RGBColor[
             0.265069534257383, 0.39593526525663725`, 0.9384066898894987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 351}], {
             RGBColor[
             0.2800986877606033, 0.41173185849189103`, 0.9392625779478669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 395}], {
             RGBColor[
             0.26756974901772024`, 0.3985631494925233, 0.9385490734213637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 447}], {
             RGBColor[
             0.25832593618087096`, 0.38884731610940987`, 0.9380226519553008]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 453}], {
             RGBColor[
             0.27722937887191995`, 0.40871603292519376`, 0.9390991750514186]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 463}], {
             RGBColor[
             0.2686246431474216, 0.3996719101069903, 0.9386091480814742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 318}], {
             RGBColor[
             0.3188208288656592, 0.44936205704600285`, 0.9415801260303202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 321}], {
             RGBColor[
             0.31443739392836134`, 0.4455653460211614, 0.9413008174322348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 330}], {
             RGBColor[
             0.3010744440099954, 0.433778708249762, 0.9404571162354194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 335}], {
             RGBColor[
             0.2862357534512077, 0.4181823036451551, 0.9396120747599719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 350}], {
             RGBColor[
             0.3289346637950721, 0.4581221525257362, 0.9422245706487093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 354}], {
             RGBColor[
             0.32873158920795986`, 0.45794625952520507`, 0.9422116309155903]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 383}], {
             RGBColor[
             0.3123209276016251, 0.4437321692656331, 0.941165958069413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 414}], {
             RGBColor[
             0.2851786513362504, 0.4170712222981897, 0.9395518743583675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 479}], {
             RGBColor[
             0.35359500425427093`, 0.4794816999667437, 0.9437959057364866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 482}], {
             RGBColor[
             0.3270903866194627, 0.45652473233228946`, 0.9421070549379097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 496}], {
             RGBColor[
             0.2862944389618104, 0.41824398583767475`, 0.9396154168129832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 237}], {
             RGBColor[
             0.8018590077882369, 0.845833600411511, 0.9807007779188375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 270}], {
             RGBColor[
             0.843824355466433, 0.8769260052856713, 0.8927516199339326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 345}], {
             RGBColor[
             0.6786754086563489, 0.7489056544572683, 0.9686076802187304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 375}], {
             RGBColor[
             0.8279135305907634, 0.8660284937370616, 0.9630673509377192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 426}], {
             RGBColor[
             0.7839000078483491, 0.8315135813435113, 0.9789878324723824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 448}], {
             RGBColor[
             0.6327824685500147, 0.7119137261765637, 0.9648129350991647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 489}], {
             RGBColor[
             0.843861608566709, 0.8769414103999965, 0.8921342396544271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 223}], {
             RGBColor[
             0.335871613441881, 0.4628528461466326, 0.9427133713948876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 373}], {
             RGBColor[
             0.28774746699468884`, 0.4197712104275283, 0.9396981646098933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 480}], {
             RGBColor[
             0.3177133386514768, 0.44712506118461215`, 0.9415563421819749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 208}], {
             RGBColor[
             0.33248120157791744`, 0.46240023864087376`, 0.9424063860563303]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 220}], {
             RGBColor[
             0.3408785418830542, 0.4696735927505875, 0.9429414571550971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 349}], {
             RGBColor[
             0.3782226741008029, 0.5020192031069408, 0.9453209922378925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 359}], {
             RGBColor[
             0.364147570424561, 0.48982805573786037`, 0.9444241390777679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 371}], {
             RGBColor[
             0.3528938984406201, 0.480080690691371, 0.9437070650501826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 382}], {
             RGBColor[
             0.31253428709090747`, 0.4426711481132517, 0.9412251688089472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 397}], {
             RGBColor[
             0.3506959657134314, 0.47817695183439113`, 0.9435670147203616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 419}], {
             RGBColor[
             0.4277672068152066, 0.5433200836247167, 0.948923355062986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 427}], {
             RGBColor[
             0.31117200287913815`, 0.44123930103287445`, 0.9411475887384059]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 429}], {
             RGBColor[
             0.318220922727511, 0.44864816272084596`, 0.9415490142958283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 213}], {
             RGBColor[
             0.9025169525103827, 0.6502340737413859, 0.24037009445756363`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 243}], {
             RGBColor[
             0.8700670583525245, 0.4728472627689348, 0.21211683898241762`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 254}], {
             RGBColor[
             0.5686631284014866, 0.5042350008222019, 0.5878701973527287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 259}], {
             RGBColor[
             0.8813343532764009, 0.5540488379416193, 0.22269481442370878`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 401}], {
             RGBColor[
             0.8371401925160188, 0.7327555556169211, 0.6085074799840489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 450}], {
             RGBColor[
             0.8592682454015592, 0.38984285435780597`, 0.20177588350505832`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 454}], {
             RGBColor[
             0.9003552167733437, 0.640418136645701, 0.2385662891695866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 469}], {
             RGBColor[
             0.8806293426662699, 0.5508475494204266, 0.22210653628922422`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 471}], {
             RGBColor[
             0.8788202951923778, 0.5401284768128874, 0.22049894846562806`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 475}], {
             RGBColor[
             0.8699156991968737, 0.47168384997259694`, 0.2119718972840306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 500}], {
             RGBColor[
             0.8601603348227043, 0.3966998445648045, 0.2026301493422178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 222}], {
             RGBColor[
             0.3735862388275236, 0.49760697262793063`, 0.9450400762157048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 246}], {
             RGBColor[
             0.2993400916080083, 0.43195579391098005`, 0.9403583474318706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 256}], {
             RGBColor[
             0.2969224563599441, 0.4294147059783363, 0.9402206666810642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 271}], {
             RGBColor[
             0.2801320470703391, 0.4117669212415258, 0.9392644777112058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 312}], {
             RGBColor[
             0.30443515610797417`, 0.4373110297461917, 0.9406485038176712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 333}], {
             RGBColor[
             0.34155395478950024`, 0.4698622181836031, 0.9429990074018386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 400}], {
             RGBColor[
             0.30019030163233085`, 0.432849418552972, 0.9404067656349827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 442}], {
             RGBColor[
             0.2942020501296223, 0.426555386546551, 0.9400657435707277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 444}], {
             RGBColor[
             0.2878759109078417, 0.4199062131240665, 0.9397054793007316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 492}], {
             RGBColor[
             0.29053904388296076`, 0.4227053347332997, 0.9398571407839125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 211}], {
             RGBColor[
             0.2350487330765592, 0.3643814997868598, 0.9366970496740461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 414}], {
             RGBColor[
             0.25685751416132785`, 0.38730391146353665`, 0.9379390274936235]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 485}], {
             RGBColor[
             0.2435291255920976, 0.37329493000863156`, 0.9371799954821897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 497}], {
             RGBColor[
             0.23752535161991525`, 0.36698458290261204`, 0.9368380894362616]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 221}], {
             RGBColor[
             0.5355883582024223, 0.6338537830261275, 0.9565826239639467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 258}], {
             RGBColor[
             0.45399453907585874`, 0.5654428931958693, 0.950758657973602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 289}], {
             RGBColor[
             0.48696884397226536`, 0.5940035787603833, 0.9528597515235682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 291}], {
             RGBColor[
             0.5947468881404891, 0.681688814806365, 0.9613714325118958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 297}], {
             RGBColor[
             0.5269654224863035, 0.6268532953529551, 0.9559037948775195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 381}], {
             RGBColor[
             0.5519357188644908, 0.6471253068518, 0.9578695480776199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 397}], {
             RGBColor[
             0.44655734447149653`, 0.5590011690338403, 0.950284766509865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 419}], {
             RGBColor[
             0.5236285855732716, 0.6241443008241659, 0.9556411068524893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 439}], {
             RGBColor[
             0.6977395599110665, 0.7624782824674698, 0.971548992789666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 219}], {
             RGBColor[
             0.5140809753819581, 0.6163931207559199, 0.9548894840041806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 244}], {
             RGBColor[
             0.42216704011068096`, 0.5387626777069581, 0.9484855117114601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 274}], {
             RGBColor[
             0.4823136561574142, 0.5906029799080129, 0.9523886442672999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 334}], {
             RGBColor[
             0.4523485649591434, 0.5649043975631496, 0.9504086517863296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 337}], {
             RGBColor[
             0.6810518757467315, 0.7489355468683991, 0.970229432274497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 340}], {
             RGBColor[
             0.4196638066192008, 0.5365945026728116, 0.9483260078869054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 361}], {
             RGBColor[
             0.5730472494558454, 0.6642363745027182, 0.9595508219663998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 362}], {
             RGBColor[
             0.4451772959687064, 0.5586930048020928, 0.9499517048675632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 363}], {
             RGBColor[
             0.4533522044192463, 0.5657736996191047, 0.9504726028052438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 370}], {
             RGBColor[
             0.546668194471859, 0.642848893250592, 0.9574548692618543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 498}], {
             RGBColor[
             0.4818912814299178, 0.5902600770764668, 0.9523553933815417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 228}], {
             RGBColor[
             0.9934539331599859, 0.9884069498751192, 0.5288792059852668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 252}], {
             RGBColor[
             0.8648112867502258, 0.89136633503373, 0.7718692919288858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 388}], {
             RGBColor[
             0.9699993320336204, 0.9742898944709728, 0.7727192137216462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 432}], {
             RGBColor[
             0.9462255159241673, 0.9556033712696023, 0.7798152269955922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 490}], {
             RGBColor[
             0.9921900608993205, 0.9897828176678509, 0.6878265810358566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 266}], {
             RGBColor[
             0.31612745049209645`, 0.4464579350707817, 0.9414294227127427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 410}], {
             RGBColor[
             0.35319958507105037`, 0.4803454610863929, 0.9437265431319655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 218}], {
             RGBColor[
             0.22451796602725682`, 0.35331299592884813`, 0.9360973380694622]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 287}], {
             RGBColor[
             0.21343735530821623`, 0.3416665715118395, 0.9354663136813074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 295}], {
             RGBColor[
             0.22332543873759936`, 0.352059574136821, 0.9360294254045023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 336}], {
             RGBColor[
             0.2196507706490151, 0.34819726498830533`, 0.9358201584930417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 389}], {
             RGBColor[
             0.21778138864415675`, 0.3462324259755344, 0.9357136999533677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 409}], {
             RGBColor[
             0.22930932819200256`, 0.35834902135390323`, 0.9363701990565594]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 456}], {
             RGBColor[
             0.2203607616298221, 0.3489435105251617, 0.9358605914290611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 458}], {
             RGBColor[
             0.22378112515977486`, 0.35253852945871533`, 0.9360553760721175]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[
             0.3477704837485026, 0.4756430463953687, 0.9433806055964585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 289}], {
             RGBColor[
             0.3807447886449092, 0.5042037319598828, 0.9454816991464247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 314}], {
             RGBColor[
             0.32609699892407057`, 0.4568705631814669, 0.9419995903085558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 349}], {
             RGBColor[
             0.3678599975315118, 0.49304357350588934`, 0.9446606916502523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 359}], {
             RGBColor[
             0.3537848938552699, 0.480852426136809, 0.9437638384901277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 397}], {
             RGBColor[
             0.3403332891441403, 0.46920132223333977`, 0.9429067141327215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 427}], {
             RGBColor[
             0.3008093263098471, 0.4322636714318231, 0.9404872881507658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 472}], {
             RGBColor[
             0.32528262084800263`, 0.45616518982380916`, 0.9419476988576752]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 214}], {
             RGBColor[
             0.3828653435329973, 0.49291080046599856`, 0.946830407391962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 233}], {
             RGBColor[
             0.7045416845554648, 0.49561598240663746`, 0.5739669497124782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 273}], {
             RGBColor[
             0.4297324939516893, 0.5421711471050089, 0.9494994222745707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 421}], {
             RGBColor[
             0.37249008899703795`, 0.4820057501195733, 0.9462395519949527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 423}], {
             RGBColor[
             0.37687473184245884`, 0.48661428775252374`, 0.9464892509185017]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 477}], {
             RGBColor[
             0.40529759982577535`, 0.5164885241169046, 0.9481078912022864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 227}], {
             RGBColor[
             0.8408474405782448, 0.3149769045127923, 0.18674886126930004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 243}], {
             RGBColor[
             0.8376849116916145, 0.29066832166115775`, 0.18372042003589745`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 326}], {
             RGBColor[
             0.8556196126725499, 0.40214503052670025`, 0.19986184252427644`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 348}], {
             RGBColor[
             0.8979876618717816, 0.5773208368833467, 0.24046628121299102`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 428}], {
             RGBColor[
             0.8331986050247592, 0.2561846027075905, 0.17942432770515804`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 434}], {
             RGBColor[
             0.9136331462118448, 0.6344185701788778, 0.48881376628200723`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 469}], {
             RGBColor[
             0.8482471960053599, 0.3686686083126496, 0.19371011734270402`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 474}], {
             RGBColor[
             0.9145804341522545, 0.6348102980864267, 0.4731147536068143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 495}], {
             RGBColor[
             0.8391330927044698, 0.3017996755229297, 0.18510719980929416`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 464}], {
             RGBColor[
             0.23745358448324252`, 0.36690915109166977`, 0.936834002403998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 485}], {
             RGBColor[
             0.23952079823930758`, 0.3690819238182165, 0.9369517271692371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 497}], {
             RGBColor[
             0.23351702426712523`, 0.36277157671219695`, 0.936609821123309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 287}], {
             RGBColor[
             0.21416398383706822`, 0.3424303041665726, 0.9355076941010749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 295}], {
             RGBColor[
             0.22405206726645135`, 0.35282330679155405`, 0.9360708058242697]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 299}], {
             RGBColor[
             0.21384131413680724`, 0.3420911578531577, 0.9354893185389921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 300}], {
             RGBColor[
             0.22223694937519295`, 0.35091550280272016`, 0.9359674375455889]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 301}], {
             RGBColor[
             0.2136344659280746, 0.34187374727084574`, 0.9354775388395093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 389}], {
             RGBColor[
             0.21850801717300872`, 0.34699615863026745`, 0.9357550803731354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 451}], {
             RGBColor[
             0.21498103480107186`, 0.34328907653376356`, 0.9355542239447563]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 456}], {
             RGBColor[
             0.22108739015867407`, 0.34970724317989477`, 0.9359019718488286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 254}], {
             RGBColor[
             0.5703520735589939, 0.511904106319279, 0.5892794945919869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 259}], {
             RGBColor[
             0.8830232984339081, 0.5617179434386964, 0.224104111662967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 261}], {
             RGBColor[
             0.8920963570986589, 0.602916583768641, 0.23167489421385412`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 315}], {
             RGBColor[
             0.5448527569683213, 0.48510270783243126`, 0.5878273462350064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 368}], {
             RGBColor[
             0.6561537738248766, 0.5929010247462924, 0.5945021229284573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 401}], {
             RGBColor[
             0.8388291376735261, 0.7404246611139982, 0.6099167772233072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 450}], {
             RGBColor[
             0.8609571905590665, 0.3975119598548832, 0.20318518074431657`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 454}], {
             RGBColor[
             0.902044161930851, 0.6480872421427781, 0.23997558640884487`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 471}], {
             RGBColor[
             0.8805092403498851, 0.5477975823099646, 0.2219082457048863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 475}], {
             RGBColor[
             0.871604644354381, 0.4793529554696741, 0.21338119452328883`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 500}], {
             RGBColor[
             0.8618492799802115, 0.40436895006188167`, 0.20403944658147605`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 273}], {
             RGBColor[
             0.24667426527178135`, 0.3766006712253524, 0.9373591065341305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 302}], {
             RGBColor[
             0.19497823659732902`, 0.32226486737097304`, 0.9344150941785414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 347}], {
             RGBColor[
             0.1893670574265447, 0.316367162293171, 0.9340955458257609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 421}], {
             RGBColor[
             0.18943186031713002`, 0.3164352742399168, 0.9340992362545124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 423}], {
             RGBColor[
             0.19381650316255092`, 0.32104381187286724`, 0.9343489351780614]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 477}], {
             RGBColor[
             0.2222393711458674, 0.35091804823724815`, 0.9359675754618462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 224}], {
             RGBColor[
             0.2915446973152564, 0.4237623402527527, 0.9399144112591507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 351}], {
             RGBColor[
             0.28708427642095813`, 0.4190741550858264, 0.9396603968878219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 356}], {
             RGBColor[
             0.2767305167100354, 0.40819169716336523`, 0.9390707655892996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 430}], {
             RGBColor[
             0.26193106415637823`, 0.3926365341899838, 0.9382279586601969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 238}], {
             RGBColor[
             0.29301995095784455`, 0.42425818517520597`, 0.9400370439768699]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 281}], {
             RGBColor[
             0.2553973215721218, 0.3857691564707237, 0.9378558716858294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 343}], {
             RGBColor[
             0.2793867448603114, 0.4109835613638972, 0.9392220338529205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 465}], {
             RGBColor[
             0.27425578181697063`, 0.40559059388349944`, 0.9389298330981818]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 290}], {
             RGBColor[
             0.3031025001174864, 0.43489572471311266`, 0.9406097604733883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 340}], {
             RGBColor[
             0.32857716094804046`, 0.4590187548700618, 0.9421576240396021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 355}], {
             RGBColor[
             0.32421328138501737`, 0.4552389817275355, 0.9418795614926734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 362}], {
             RGBColor[
             0.35409065029754605`, 0.481117256999343, 0.9437833210202597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 378}], {
             RGBColor[
             0.30140209308183147`, 0.4331084891066064, 0.9405129248082346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 384}], {
             RGBColor[
             0.30177027996931804`, 0.4334954768697517, 0.9405338925067932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 498}], {
             RGBColor[
             0.3908046357587574, 0.5126843292737169, 0.9461870095342384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 295}], {
             RGBColor[
             0.2307804101674582, 0.3598952217820915, 0.9364539749987908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.22896529227619977`, 0.3579874177932576, 0.93635060672011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 336}], {
             RGBColor[
             0.2271057420788739, 0.35603291263357584`, 0.9362447080873302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 389}], {
             RGBColor[
             0.22523636007401557`, 0.35406807362080495`, 0.9361382495476563]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 409}], {
             RGBColor[
             0.2367642996218614, 0.3661846689991738, 0.9367947486508479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 456}], {
             RGBColor[
             0.2278157330596809, 0.3567791581704322, 0.9362851410233497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 458}], {
             RGBColor[
             0.23123609658963368`, 0.36037417710398584`, 0.936479925666406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 244}], {
             RGBColor[
             0.43435496414043395`, 0.548657383494032, 0.949444989736919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 274}], {
             RGBColor[
             0.49450158018716717`, 0.6004976856950868, 0.9533481222927589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 334}], {
             RGBColor[
             0.4645364889888964, 0.5747991033502236, 0.9513681298117886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 337}], {
             RGBColor[
             0.6932397997764845, 0.7588302526554731, 0.971188910299956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 340}], {
             RGBColor[
             0.43185173064895377`, 0.5464892084598855, 0.9492854859123644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 361}], {
             RGBColor[
             0.5852351734855985, 0.6741310802897922, 0.9605102999918589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 363}], {
             RGBColor[
             0.4655401284489993, 0.5756684054061787, 0.9514320808307029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 369}], {
             RGBColor[
             0.47310816162837227`, 0.5822234553657439, 0.9519143092127434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 370}], {
             RGBColor[
             0.5588561185016121, 0.6527435990376659, 0.9584143472873132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 498}], {
             RGBColor[
             0.49407920545967077`, 0.6001547828635406, 0.9533148714070008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 349}], {
             RGBColor[
             0.3762573378366486, 0.5003169276156031, 0.9451957627490192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 359}], {
             RGBColor[
             0.3621822341604067, 0.48812578024652276`, 0.9442989095888945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 371}], {
             RGBColor[
             0.3509285621764658, 0.4783784152000333, 0.9435818355613093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 382}], {
             RGBColor[
             0.3105689508267532, 0.4409688726219141, 0.9410999393200739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 416}], {
             RGBColor[
             0.3002234451567067, 0.4300950902197503, 0.9405107780769688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 427}], {
             RGBColor[
             0.30920666661498386`, 0.43953702554153684`, 0.9410223592495326]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 429}], {
             RGBColor[
             0.3162555864633567, 0.44694588722950834`, 0.9414237848069549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 499}], {
             RGBColor[
             0.2998159216660946, 0.42966675719263536`, 0.9404875702170554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 223}], {
             RGBColor[
             0.46323693275442124`, 0.5733927057392445, 0.9513629056103252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 258}], {
             RGBColor[
             0.45501626161494246`, 0.5662723735811732, 0.9508390917145717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 297}], {
             RGBColor[
             0.5279871450253872, 0.627682775738259, 0.9559842286184892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 381}], {
             RGBColor[
             0.5529574414035745, 0.647954787237104, 0.9579499818185896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 439}], {
             RGBColor[
             0.6987612824501502, 0.7633077628527738, 0.9716294265306357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 307}], {
             RGBColor[
             0.456261635454359, 0.5691648443465238, 0.950417290103996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 333}], {
             RGBColor[
             0.41068141899913524`, 0.5301333365139219, 0.9473892347606732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 372}], {
             RGBColor[
             0.4565833875774816, 0.5694260572148426, 0.9504426196097452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 417}], {
             RGBColor[
             0.5718731828738293, 0.6621247011020224, 0.9601331729684849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 258}], {
             RGBColor[
             0.3816431136278576, 0.5049818159089863, 0.9455389396199805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 268}], {
             RGBColor[
             0.3997592820050565, 0.5206731304122181, 0.946693285849477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 373}], {
             RGBColor[
             0.3417396383201442, 0.4690205123479532, 0.9430475467307398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 381}], {
             RGBColor[
             0.47958429341648956`, 0.5866642295649169, 0.9526498297239985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 480}], {
             RGBColor[
             0.3717055099769321, 0.496374363105037, 0.9449057243028214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 263}], {
             RGBColor[
             0.2861834719747001, 0.4181273524985085, 0.9396090974072282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 342}], {
             RGBColor[
             0.2794767176957349, 0.41107812851853454`, 0.939227157672795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 351}], {
             RGBColor[
             0.29450587119895527`, 0.4268747217537883, 0.9400830457311632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 356}], {
             RGBColor[
             0.28415211148803254`, 0.41599226383132715`, 0.939493414432641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 463}], {
             RGBColor[
             0.2830318265857735, 0.4148147733688876, 0.9394296158647704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 235}], {
             RGBColor[
             0.31564550837904015`, 0.44462855110700683`, 0.9414504121909557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 249}], {
             RGBColor[
             0.28189858083211217`, 0.41362366022985875`, 0.9393650791955862]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 260}], {
             RGBColor[
             0.27991286113099906`, 0.41153654292208813`, 0.9392519953962168]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 280}], {
             RGBColor[
             0.26557083518380836`, 0.39646216431462483`, 0.9384352382356503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 296}], {
             RGBColor[
             0.29383455667092717`, 0.42573700098774714`, 0.940060637634782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 424}], {
             RGBColor[
             0.2974218624617132, 0.42884414496049433`, 0.940289217587641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 440}], {
             RGBColor[
             0.27796156594151966`, 0.4094856079586846, 0.9391408720218586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 453}], {
             RGBColor[
             0.2792780627176027, 0.4108693295410645, 0.939215844565674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 470}], {
             RGBColor[
             0.26486570011979793`, 0.3957210226542046, 0.9383950818369088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 236}], {
             RGBColor[
             0.23337407460187973`, 0.3626213275504917, 0.9366016803513484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 283}], {
             RGBColor[
             0.18031957576389654`, 0.30685768542225833`, 0.9335803051296228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 292}], {
             RGBColor[
             0.17919781223777545`, 0.3056786408323896, 0.9335164223563106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 308}], {
             RGBColor[
             0.17918563853241248`, 0.3056658454961956, 0.9335157290817995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 386}], {
             RGBColor[
             0.1791759961486071, 0.30565571073945375`, 0.9335151799623065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 396}], {
             RGBColor[
             0.5864855268156967, 0.6472607121015193, 0.7362180745608087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 422}], {
             RGBColor[
             0.20671849831186667`, 0.3346046268085379, 0.9350836847150235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 446}], {
             RGBColor[
             0.20378813280661343`, 0.33152462686661266`, 0.9349168047345866]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 309}], {
             RGBColor[
             0.9193309660445672, 0.6696242794444807, 0.3370748612621325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 320}], {
             RGBColor[
             0.9171168323829694, 0.670650788557899, 0.5149397016540836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 348}], {
             RGBColor[
             0.9027713884189711, 0.6140906553673846, 0.24504718315702606`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 428}], {
             RGBColor[
             0.8379823315719487, 0.29295442119162834`, 0.18400522964919308`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 495}], {
             RGBColor[
             0.8439168192516593, 0.3385694940069675, 0.1896881017533292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 388}], {
             RGBColor[
             0.9696267022726579, 0.9734928770909221, 0.7321607638451979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 490}], {
             RGBColor[
             0.9918174311383581, 0.9889858002878001, 0.6472681311594083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 244}], {
             RGBColor[
             0.3167084139494082, 0.447095666264713, 0.9414615153937971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 248}], {
             RGBColor[
             0.2667577277658053, 0.3977096636716398, 0.9385028300123448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 255}], {
             RGBColor[
             0.34428066244060973`, 0.47097736208628804`, 0.9432183946864745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 313}], {
             RGBColor[
             0.2789668469500533, 0.41054222203715074`, 0.9391981212881146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 338}], {
             RGBColor[
             0.3055405634218271, 0.43742263545021065`, 0.9407499098335221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 379}], {
             RGBColor[
             0.30013749915285226`, 0.43274277274633094`, 0.9404056313560452]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 380}], {
             RGBColor[
             0.2819134302618612, 0.4136392679220333, 0.9393659248486427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 390}], {
             RGBColor[
             0.29586463316817824`, 0.4283028667339263, 0.9401604252152023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 411}], {
             RGBColor[
             0.26528288174741516`, 0.39615950699567326`, 0.9384188397134368]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 478}], {
             RGBColor[
             0.27850887095594073`, 0.41006086022998334`, 0.9391720402327646]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 242}], {
             RGBColor[
             0.2244428247428983, 0.35323401767475476`, 0.9360930588844796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 339}], {
             RGBColor[
             0.21778435426976317`, 0.3462355430360783, 0.9357138688413589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 365}], {
             RGBColor[
             0.22042634378562792`, 0.3490124415290624, 0.9358643262358141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 374}], {
             RGBColor[
             0.23780417240741958`, 0.3672776412285381, 0.9368539678676315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 391}], {
             RGBColor[
             0.23250262506826308`, 0.3617053788375689, 0.936552052589603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 246}], {
             RGBColor[
             0.27633388437422024`, 0.407774811430481, 0.93904817796454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 256}], {
             RGBColor[
             0.27391624912615603`, 0.40523372349783726`, 0.9389104972137335]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 271}], {
             RGBColor[
             0.25712583983655113`, 0.38758593876102676`, 0.9379543082438752]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 288}], {
             RGBColor[
             0.2572561350755689, 0.3877228873184297, 0.9379617283649826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 442}], {
             RGBColor[
             0.2711958428958343, 0.40237440406605196`, 0.938755574103397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 444}], {
             RGBColor[
             0.2648697036740537, 0.39572523064356746`, 0.938395309833401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 492}], {
             RGBColor[
             0.2675328366491727, 0.39852435225280064`, 0.9385469713165818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 307}], {
             RGBColor[
             0.4130035971526026, 0.5316969057817654, 0.9476609261549895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 312}], {
             RGBColor[
             0.3303045820158528, 0.4601142095117522, 0.9422823672274991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 330}], {
             RGBColor[
             0.3313235898372211, 0.4611852513408379, 0.942340398215439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 350}], {
             RGBColor[
             0.3591838096222978, 0.48552869561681206`, 0.944107852628729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 354}], {
             RGBColor[
             0.35898073503518557`, 0.48535280261628094`, 0.94409491289561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 372}], {
             RGBColor[
             0.41332534927572523`, 0.5319581186500844, 0.9476862556607386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 376}], {
             RGBColor[
             0.3178263634409366, 0.4469988106247622, 0.9415717511395277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 400}], {
             RGBColor[
             0.3260597275402094, 0.45565259831853255`, 0.9420406290448107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 414}], {
             RGBColor[
             0.31542779716347613`, 0.44447776538926564`, 0.9414351563383871]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 415}], {
             RGBColor[
             0.3216051563189196, 0.45097056152882875`, 0.9417869478037058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 476}], {
             RGBColor[
             0.8458261121541704, 0.35324515591315253`, 0.19151644279301172`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 235}], {
             RGBColor[
             0.3728101836078023, 0.49733117588158576`, 0.9449761131297559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[
             0.36975457999068184`, 0.4946845656075394, 0.9447814127692372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 262}], {
             RGBColor[
             0.4323322286458682, 0.548267980100758, 0.9489396155777698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 296}], {
             RGBColor[
             0.3509992318996893, 0.478439625762326, 0.9435863385735823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 332}], {
             RGBColor[
             0.3953853483413155, 0.5168846489129837, 0.946414582664141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 393}], {
             RGBColor[
             0.42489506401207827`, 0.5422301548105988, 0.9483541347345662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 468}], {
             RGBColor[
             0.4334778335161593, 0.5491980337433716, 0.9490298017896481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 239}], {
             RGBColor[
             0.35398612023304477`, 0.4810267183113057, 0.943776660456982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 249}], {
             RGBColor[
             0.32329479630323715`, 0.4526684377082041, 0.9418860278221313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 260}], {
             RGBColor[
             0.32130907660212404`, 0.45058132040043347`, 0.941772944022762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 262}], {
             RGBColor[
             0.416563768888231, 0.5346101328045243, 0.9479348632655147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 296}], {
             RGBColor[
             0.3352307721420522, 0.4647817784660925, 0.9425815862613272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 332}], {
             RGBColor[
             0.37961688858367837`, 0.50322680161675, 0.9454098303518859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 344}], {
             RGBColor[
             0.4103923521286693, 0.5295998986599555, 0.9474490267315575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 393}], {
             RGBColor[
             0.40912660425444114`, 0.5285723075143651, 0.947349382422311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 424}], {
             RGBColor[
             0.3388180779328382, 0.46788892243883967`, 0.9428101662141861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 440}], {
             RGBColor[
             0.3193577814126447, 0.44853038543702994`, 0.9416618206484036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 453}], {
             RGBColor[
             0.32067427818872773`, 0.4499141070194098, 0.9417367931922191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 243}], {
             RGBColor[
             0.5633146331293595, 0.36122739545781846`, 0.562473440762307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 276}], {
             RGBColor[
             0.45343165662521556`, 0.5606674341824253, 0.9514328089086481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 283}], {
             RGBColor[
             0.23426865806856206`, 0.3635615914938426, 0.9366526255563583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 292}], {
             RGBColor[
             0.23314689454244097`, 0.36238254690397387`, 0.9365887427830462]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 396}], {
             RGBColor[
             0.6404346091203621, 0.7039646181731036, 0.7392903949875442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 422}], {
             RGBColor[
             0.26066758061653217`, 0.39130853288012224`, 0.9381560051417591]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 267}], {
             RGBColor[
             0.9475774996267206, 0.9513626199375382, 0.7014579081154306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 270}], {
             RGBColor[
             0.9480577404464491, 0.9590498999175098, 0.9029559373872008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 329}], {
             RGBColor[
             0.8943251384864865, 0.9185746058926771, 0.989782724153959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 426}], {
             RGBColor[
             0.8881333928283652, 0.9136374759753497, 0.9891921499256506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 448}], {
             RGBColor[
             0.7370158535300309, 0.7940376208084021, 0.9750172525524329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 489}], {
             RGBColor[
             0.9480949935467251, 0.959065305031835, 0.9023385571076953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 265}], {
             RGBColor[
             0.32058421295120315`, 0.4520956650524487, 0.9416483204611299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 328}], {
             RGBColor[
             0.35273346300045894`, 0.47994172957682313`, 0.943696842245803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 343}], {
             RGBColor[
             0.306520714368336, 0.43844834351747275`, 0.9408058924805078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 431}], {
             RGBColor[
             0.38434692528377257`, 0.5073237216678145, 0.9457112241078087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 433}], {
             RGBColor[
             0.32283008594645624`, 0.45404092736007795`, 0.94179142550244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 436}], {
             RGBColor[
             0.3965368671240651, 0.5173498014044343, 0.9466350145946033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 462}], {
             RGBColor[
             0.392016142899485, 0.5136796738226148, 0.9462791266236859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 465}], {
             RGBColor[
             0.30138975132499524`, 0.433055376037075, 0.940513691725769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 262}], {
             RGBColor[
             0.41350816527111056`, 0.531963522530478, 0.947740162904996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 263}], {
             RGBColor[
             0.31216558423603546`, 0.4415359530567809, 0.9412315474042139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 296}], {
             RGBColor[
             0.33217516852493173`, 0.46213516819204603`, 0.9423868859008084]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 332}], {
             RGBColor[
             0.37656128496655794`, 0.5005801913427036, 0.9452151299913671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 393}], {
             RGBColor[
             0.4060710006373207, 0.5259256972403187, 0.9471546820617923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 424}], {
             RGBColor[
             0.3357624743157177, 0.4652423121647933, 0.9426154658536674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 440}], {
             RGBColor[
             0.3163021777955242, 0.4458837751629835, 0.9414671202878849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 453}], {
             RGBColor[
             0.31761867457160725`, 0.44726749674536337`, 0.9415420928317004]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 251}], {
             RGBColor[
             0.25758537828186423`, 0.38806894280347104`, 0.9379804782785095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 310}], {
             RGBColor[
             0.2766913122921885, 0.4081504908345045, 0.939068532955701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 352}], {
             RGBColor[
             0.24222822396059346`, 0.3719275999119933, 0.937105911058787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 367}], {
             RGBColor[
             0.24323530728920995`, 0.3729861083431402, 0.9371632629645055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 382}], {
             RGBColor[
             0.26942512488484194`, 0.40051326716649266`, 0.9386547343322136]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 399}], {
             RGBColor[
             0.24906325398775672`, 0.3791116498364756, 0.9374951559073132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 412}], {
             RGBColor[
             0.2495035202048371, 0.3795743975451175, 0.9375202284170604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 416}], {
             RGBColor[
             0.2590796192147955, 0.38963948476432886`, 0.9380655730891085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 429}], {
             RGBColor[
             0.2751117605214455, 0.4064902817740869, 0.9389785798190946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 402}], {
             RGBColor[
             0.6288966867837086, 0.7086387216585579, 0.9645893173262957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 417}], {
             RGBColor[
             0.7032574015004508, 0.7681092940971459, 0.9710577835336467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 436}], {
             RGBColor[
             0.5892009770363313, 0.6764119562142918, 0.9614643256448061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 461}], {
             RGBColor[
             0.8249688230204753, 0.8639714322998968, 0.9750930222658254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 339}], {
             RGBColor[
             0.21834915626655288`, 0.34682918574521915`, 0.9357460334795263]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 365}], {
             RGBColor[
             0.22099114578241763`, 0.3496060842382034, 0.9358964908739815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 374}], {
             RGBColor[
             0.2383689744042093, 0.367871283937679, 0.936886132505799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 276}], {
             RGBColor[
             0.7294231328480298, 0.5025695960181678, 0.5742322488928711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 326}], {
             RGBColor[
             0.8572408103331092, 0.41460626615910345`, 0.2014143032349089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 428}], {
             RGBColor[
             0.8348198026853184, 0.2686458383399938, 0.18097678841579048`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 454}], {
             RGBColor[
             0.869594267772993, 0.47070043117032717`, 0.21172233093369885`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 469}], {
             RGBColor[
             0.8498683936659192, 0.3811298439450528, 0.19526257805333647`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 471}], {
             RGBColor[
             0.8480593461920269, 0.37041077133751354`, 0.1936549902297403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 475}], {
             RGBColor[
             0.8391547501965229, 0.3019661444972231, 0.18512793904814284`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 495}], {
             RGBColor[
             0.8407542903650291, 0.31426091115533294`, 0.1866596605199266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 274}], {
             RGBColor[
             0.40258764491589, 0.5228672426461249, 0.9469441500000384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 313}], {
             RGBColor[
             0.3046994618698019, 0.43447349621750786`, 0.9407776233385161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 334}], {
             RGBColor[
             0.3726225537176192, 0.4971686603012616, 0.9449641575190681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 340}], {
             RGBColor[
             0.33993779537767665`, 0.4688587654109236, 0.9428815136196439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 355}], {
             RGBColor[
             0.3355739158146536, 0.46507899226839733`, 0.9426034510727153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 363}], {
             RGBColor[
             0.37362619317772217`, 0.49803796235721676`, 0.9450281085379824]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 378}], {
             RGBColor[
             0.3127627275114677, 0.4429484996474682, 0.9412368143882763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 379}], {
             RGBColor[
             0.3258701140726008, 0.45667404692668806`, 0.9419851334064466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 380}], {
             RGBColor[
             0.3076460451816098, 0.43757054210239044`, 0.9409454268990441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 390}], {
             RGBColor[
             0.3215972480879268, 0.45223414091428343`, 0.9417399272656037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 498}], {
             RGBColor[
             0.40216527018839365`, 0.5225243398145787, 0.9469108991142803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 394}], {
             RGBColor[
             0.22510267482771082`, 0.3539275619508045, 0.936130636370649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 438}], {
             RGBColor[
             0.22151371355788788`, 0.3501553361029332, 0.9359262503357249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 445}], {
             RGBColor[
             0.22560109399094413`, 0.3544514320929628, 0.93615902060465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 460}], {
             RGBColor[
             0.23495456172986623`, 0.36428251973067727`, 0.936691686755166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 256}], {
             RGBColor[
             0.2918037733500637, 0.42403464559170456`, 0.9399291652560644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 288}], {
             RGBColor[
             0.2751436592994766, 0.40652380941229693`, 0.9389803964073136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 333}], {
             RGBColor[
             0.33643527177961996`, 0.46448215779697133`, 0.9427075059768388]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 392}], {
             RGBColor[
             0.3001114005223494, 0.4327664884837622, 0.940402272333493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 442}], {
             RGBColor[
             0.28908336711974203`, 0.42117532615991926`, 0.939774242145728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 444}], {
             RGBColor[
             0.2827572278979614, 0.41452615273743476`, 0.9394139778757318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 459}], {
             RGBColor[
             0.3423837632254584, 0.4696344421074833, 0.9430865385917233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 492}], {
             RGBColor[
             0.2854203608730804, 0.4173252743466679, 0.9395656393589127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 255}], {
             RGBColor[
             0.4462984536881862, 0.5598509487377481, 0.9499715158755377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 269}], {
             RGBColor[
             0.47197536116157857`, 0.5820909954323062, 0.9516076257145445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 360}], {
             RGBColor[
             0.5371888520305683, 0.6351531360172418, 0.9567086207009003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 369}], {
             RGBColor[
             0.457479402684923, 0.5695353247878849, 0.9506839560586847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 370}], {
             RGBColor[
             0.5432273595581627, 0.6400554684598069, 0.9571839941332545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 425}], {
             RGBColor[
             0.4351771155351065, 0.550218204604259, 0.9492628740426365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 466}], {
             RGBColor[
             0.4992597773340883, 0.6043606044932961, 0.953722705002015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 468}], {
             RGBColor[
             0.48669420259584584`, 0.5941593048480999, 0.9527334969294036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 286}], {
             RGBColor[
             0.23281996068137648`, 0.36203891868719107`, 0.9365701243833138]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 294}], {
             RGBColor[
             0.240426199543799, 0.37003355799499527`, 0.9370032884341067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 313}], {
             RGBColor[
             0.254748775686199, 0.38508749362443473`, 0.9378189379570638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 380}], {
             RGBColor[
             0.257695358998007, 0.3881845395093172, 0.937986741517592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 411}], {
             RGBColor[
             0.2410648104835609, 0.37070477858295714`, 0.937039656382386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 478}], {
             RGBColor[
             0.25429079969208646`, 0.3846061318172672, 0.9377928569017139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 260}], {
             RGBColor[
             0.28756214905519606`, 0.4195764295232854, 0.9396876110273925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 280}], {
             RGBColor[
             0.27322012310800536`, 0.4045020509158221, 0.938870853866826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 296}], {
             RGBColor[
             0.3014838445951241, 0.4337768875889444, 0.9404962532659576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 424}], {
             RGBColor[
             0.30507115038591015`, 0.4368840315616916, 0.9407248332188166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 440}], {
             RGBColor[
             0.2856108538657166, 0.41752549455988186`, 0.9395764876530341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 470}], {
             RGBColor[
             0.27251498804399493`, 0.40376090925540187`, 0.9388306974680845]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 339}], {
             RGBColor[
             0.20806801028262886`, 0.33602304945380984`, 0.9351605374253343]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 365}], {
             RGBColor[
             0.21070999979849359`, 0.338799947946794, 0.9353109948197895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 305}], {
             RGBColor[
             0.25482853774731307`, 0.38517132860787223`, 0.9378234802884469]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 367}], {
             RGBColor[
             0.24419513183599667`, 0.3739949447982042, 0.9372179235525118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 382}], {
             RGBColor[
             0.27038494943162866`, 0.40152210362155666`, 0.9387093949202199]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 416}], {
             RGBColor[
             0.26003944376158217`, 0.39064832121939286`, 0.9381202336771148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 427}], {
             RGBColor[
             0.2690226652198594, 0.4000902565411794, 0.9386318148496786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 429}], {
             RGBColor[
             0.2760715850682322, 0.4074991182291509, 0.9390332404071009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 499}], {
             RGBColor[
             0.25963192027097015`, 0.39021998819227793`, 0.9380970258172014]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 282}], {
             RGBColor[
             0.6717272001021579, 0.7429460920325152, 0.9682785844173988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 432}], {
             RGBColor[
             0.8172102397534445, 0.8577657390481622, 0.982246863062763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 467}], {
             RGBColor[
             0.7213175895970523, 0.7822180503007243, 0.9728578543010624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 261}], {
             RGBColor[
             0.9325093316648222, 0.7680041432668934, 0.5596474808987255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 277}], {
             RGBColor[
             0.8781666893011308, 0.9046720920391318, 0.9377821758000617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 291}], {
             RGBColor[
             0.819979493708928, 0.8592158126034372, 0.9319826199336896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 311}], {
             RGBColor[
             0.8659443575362178, 0.8951239135712197, 0.9365639679939195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 319}], {
             RGBColor[
             0.8499607656875054, 0.8826374101392084, 0.934970872933598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 377}], {
             RGBColor[
             0.9830684787672088, 0.9867535506374262, 0.9072964317019494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 484}], {
             RGBColor[
             0.9889617727140382, 0.9876413426482502, 0.6827040059696212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 488}], {
             RGBColor[
             0.877198073649208, 0.9039154021300979, 0.937685633244106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 315}], {
             RGBColor[
             0.21099893285942517`, 0.33910363491324724`, 0.9353274491301715]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 325}], {
             RGBColor[
             0.20775758490962407`, 0.33569677270467635`, 0.935142859159575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 347}], {
             RGBColor[
             0.20771262472504887`, 0.3356495167000475, 0.935140298743576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 368}], {
             RGBColor[
             0.32229994971598047`, 0.44690195182710835`, 0.9420022258236223]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 386}], {
             RGBColor[
             0.20771262472504887`, 0.3356495167000475, 0.935140298743576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 401}], {
             RGBColor[
             0.50497531356463, 0.5944255881948143, 0.9574168801184721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 454}], {
             RGBColor[
             0.568190337821955, 0.5020881692235942, 0.5874756893040098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 471}], {
             RGBColor[
             0.5466554162409889, 0.4017985093907806, 0.5694083486000513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 269}], {
             RGBColor[
             0.4232624333249523, 0.5410303787827784, 0.94819088586856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 274}], {
             RGBColor[
             0.43015989340709154`, 0.5467489384677, 0.9487010292927157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 334}], {
             RGBColor[
             0.40019480220882075`, 0.5210503561228367, 0.9467210368117455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 338}], {
             RGBColor[
             0.35884542683277726`, 0.48523560545214284`, 0.9440862911766009]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 369}], {
             RGBColor[
             0.40876647484829665`, 0.5284747081383571, 0.9472672162127003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 370}], {
             RGBColor[
             0.4945144317215364, 0.598994851810279, 0.9537672542872702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 379}], {
             RGBColor[
             0.35344236256380235`, 0.4805557427482631, 0.943742012699124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 390}], {
             RGBColor[
             0.3491694965791283, 0.4761158367358585, 0.9434968065582812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 425}], {
             RGBColor[
             0.38646418769848023`, 0.5091575879547311, 0.9458461341966522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 466}], {
             RGBColor[
             0.45054684949746193`, 0.5632999878437683, 0.9503059651560305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 271}], {
             RGBColor[
             0.2725957288123946, 0.4038457729222503, 0.9388352955353996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 333}], {
             RGBColor[
             0.3340176365315557, 0.4619410698643276, 0.9425698252260324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 442}], {
             RGBColor[
             0.28666573187167776`, 0.4186342382272755, 0.9396365613949216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 444}], {
             RGBColor[
             0.28033959264989716`, 0.411985064804791, 0.9392762971249253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 492}], {
             RGBColor[
             0.28300272562501616`, 0.4147841864140242, 0.9394279586081062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 272}], {
             RGBColor[
             0.8397181825766789, 0.3055916208213189, 0.18563986428858031`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 306}], {
             RGBColor[
             0.8582164736566054, 0.4477775920644729, 0.2033538487175496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 317}], {
             RGBColor[
             0.8711268784377937, 0.5076990787158229, 0.21417744721027115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 357}], {
             RGBColor[
             0.8829978584207956, 0.5607626793064351, 0.22403944465155362`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 418}], {
             RGBColor[
             0.9186634619525802, 0.7177171878043327, 0.5626295641489729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 420}], {
             RGBColor[
             0.9137481314322007, 0.7140513423503487, 0.5709499365964574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 289}], {
             RGBColor[
             0.4063967473847854, 0.5264221693154291, 0.9471162192741931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 297}], {
             RGBColor[
             0.4463933258988235, 0.5592718859080008, 0.9501602626281445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 314}], {
             RGBColor[
             0.35174895766394676`, 0.47908900053701325`, 0.9436341104363243]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 373}], {
             RGBColor[
             0.3335189671806654, 0.461900180189882, 0.9425237328349862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 381}], {
             RGBColor[
             0.4713636222770108, 0.5795438974068458, 0.952126015828245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 397}], {
             RGBColor[
             0.36598524788401654`, 0.49141975958888606`, 0.94454123426049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 472}], {
             RGBColor[
             0.3509345795878789, 0.47838362717935545`, 0.9435822189854435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 341}], {
             RGBColor[
             0.9277070351691528, 0.7270975616364004, 0.37415406223837167`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 405}], {
             RGBColor[
             0.9279266912954685, 0.7275673838799486, 0.39806227602736116`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 450}], {
             RGBColor[
             0.8397745913250846, 0.3013267240551166, 0.18550990071046175`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 454}], {
             RGBColor[
             0.8808615626968692, 0.5519020063430116, 0.22230030637499004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 469}], {
             RGBColor[
             0.8611356885897954, 0.46233141911773723`, 0.2058405534946276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 471}], {
             RGBColor[
             0.8593266411159032, 0.451612346510198, 0.20423296567103144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 475}], {
             RGBColor[
             0.8504220451203991, 0.38316771966990754`, 0.19570591448943397`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 491}], {
             RGBColor[
             0.9280010655847133, 0.727726462964249, 0.4061574584267472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 500}], {
             RGBColor[
             0.8406666807462297, 0.3081837142621151, 0.18636416654762122`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 280}], {
             RGBColor[
             0.27123440340689225`, 0.4024149336080515, 0.9387577700674566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 424}], {
             RGBColor[
             0.3030854306847971, 0.434796914253921, 0.9406117494194473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 440}], {
             RGBColor[
             0.28362513416460355`, 0.4154383772521112, 0.9394634038536649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 470}], {
             RGBColor[
             0.2705292683428818, 0.4016737919476313, 0.9387176136687151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 483}], {
             RGBColor[
             0.2911128004849959, 0.42330838930030823`, 0.9398898153736015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 484}], {
             RGBColor[
             0.9364392575786439, 0.7675671876801757, 0.34462692180178206`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 500}], {
             RGBColor[
             0.8497397394109806, 0.34938235459205963`, 0.19393494909850834`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 332}], {
             RGBColor[
             0.43913893362174417`, 0.5541636058359223, 0.9493733327998998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 344}], {
             RGBColor[
             0.4699143971667351, 0.5805367028791276, 0.9514125291795714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 387}], {
             RGBColor[
             0.6255998101870561, 0.7048955003973141, 0.9650590620780228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 393}], {
             RGBColor[
             0.46864864929250694`, 0.5795091117335374, 0.951312884870325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 424}], {
             RGBColor[
             0.39834012297090404`, 0.5188257266580119, 0.9467736686621999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 296}], {
             RGBColor[
             0.2934102361450429, 0.4252910132115676, 0.9400364732085589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 323}], {
             RGBColor[
             0.2563726589916906, 0.3867942979386546, 0.9379114157089916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 342}], {
             RGBColor[
             0.2666938975771815, 0.3976425740963284, 0.9384991949775311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 395}], {
             RGBColor[
             0.2691941123375187, 0.40027045833221453`, 0.938641578509396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 440}], {
             RGBColor[
             0.2775372454156354, 0.40903962018250506`, 0.9391167075956355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 447}], {
             RGBColor[
             0.2599502995006695, 0.3905546249491011, 0.938115157043333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 453}], {
             RGBColor[
             0.27885374219171843`, 0.41042334176488493`, 0.9391916801394509]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 463}], {
             RGBColor[
             0.2702490064672201, 0.4013792189466815, 0.9387016531695065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 394}], {
             RGBColor[
             0.23171433520063273`, 0.36087683620622507`, 0.9365071606478118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 398}], {
             RGBColor[
             0.2479686232623, 0.377961123540424, 0.9374328183068594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 445}], {
             RGBColor[
             0.23221275436386601`, 0.3614007063483834, 0.9365355448818129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 328}], {
             RGBColor[
             0.35316375548579293`, 0.48031442730049023`, 0.9437242601024758]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 433}], {
             RGBColor[
             0.32326037843179023`, 0.45441362508374517`, 0.9418188433591128]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 462}], {
             RGBColor[
             0.392446435384819, 0.5140523715462819, 0.9463065444803587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 364}], {
             RGBColor[
             0.2740437091478759, 0.405367692062097, 0.9389177558734103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 374}], {
             RGBColor[
             0.27062553266643685`, 0.40177497185519817`, 0.9387230957795312]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 410}], {
             RGBColor[
             0.326592877843097, 0.45552256223454524`, 0.9420962704893343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 437}], {
             RGBColor[
             0.2726756027922651, 0.40392972553939704`, 0.9388398442403902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 278}], {
             RGBColor[
             0.9687131736129876, 0.9678890438697982, 0.6921508091390034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 329}], {
             RGBColor[
             0.9358102453449542, 0.941979730786866, 0.7003355368972839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 406}], {
             RGBColor[
             0.9898404936899885, 0.9773917410301207, 0.415032665757733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 413}], {
             RGBColor[
             0.981449315920919, 0.9490863280728146, 0.38243452466585603`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 476}], {
             RGBColor[
             0.9187775169477521, 0.6742536840952063, 0.3030402150761125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 486}], {
             RGBColor[
             0.9619951023866931, 0.9628588250229391, 0.7028330719374227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 493}], {
             RGBColor[
             0.991319933690298, 0.9817192401312839, 0.4771566948770857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 275}], {
             RGBColor[
             0.4116793705742366, 0.5309977120097701, 0.9474528233525847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 285}], {
             RGBColor[
             0.3620365603618595, 0.4879996049239992, 0.9442896273832655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 324}], {
             RGBColor[
             0.3896661145929028, 0.5119309360971549, 0.946050158147012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 353}], {
             RGBColor[
             0.5246586597567469, 0.6237950026375101, 0.9560497714979366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 441}], {
             RGBColor[
             0.4298935905497302, 0.5467739538792281, 0.9486134173432208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 480}], {
             RGBColor[
             0.3816010072146523, 0.5049453454501976, 0.9455362566365644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 481}], {
             RGBColor[
             0.3639357382267393, 0.48964457733510314`, 0.9444106413174386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 360}], {
             RGBColor[
             0.5141528316673345, 0.616332566062272, 0.9549279906939228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 369}], {
             RGBColor[
             0.43444338232168905`, 0.5507147548329152, 0.948903326051707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 425}], {
             RGBColor[
             0.4121410951718726, 0.5313976346492894, 0.947482244035659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 466}], {
             RGBColor[
             0.47622375697085434`, 0.5855400345383266, 0.9519420749950372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 468}], {
             RGBColor[
             0.4636581822326119, 0.5753387348931303, 0.9509528669224259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 309}], {
             RGBColor[
             0.9915269265441726, 0.9888220703419007, 0.6489133693566129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 345}], {
             RGBColor[
             0.824874141314561, 0.8621219539632672, 0.8908628396870938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 375}], {
             RGBColor[
             0.9741122632489756, 0.9792447932430604, 0.8853225104060825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 426}], {
             RGBColor[
             0.9300987405065613, 0.9447298808495102, 0.9012429919407459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 489}], {
             RGBColor[
             0.9900603412249211, 0.9901577099059953, 0.8143893991227904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 284}], {
             RGBColor[
             0.2504489768010796, 0.3805681323731789, 0.9375740707715388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 442}], {
             RGBColor[
             0.26987532258207286`, 0.400986453490465, 0.9386803724250632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 444}], {
             RGBColor[
             0.26354918336029226`, 0.3943372800679805, 0.938320108155067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 464}], {
             RGBColor[
             0.24983604138275278`, 0.37992389838616725`, 0.9375391650062217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 492}], {
             RGBColor[
             0.2662123163354113, 0.39713640167721365`, 0.9384717696382479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 306}], {
             RGBColor[
             0.8390812230199529, 0.30140098239829205`, 0.18505752934082234`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 317}], {
             RGBColor[
             0.8519916278011412, 0.36132246904964216`, 0.1958811278335439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 357}], {
             RGBColor[
             0.8638626077841431, 0.41438606964025426`, 0.20574312527482636`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 308}], {
             RGBColor[
             0.23624385022904204`, 0.36563764368892326`, 0.9367651098278627]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 421}], {
             RGBColor[
             0.236299010735822, 0.36569562087892715`, 0.9367682511371211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 423}], {
             RGBColor[
             0.24068365358124288`, 0.3703041585118776, 0.9370179500606701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 446}], {
             RGBColor[
             0.26084634450324296`, 0.39149642505934035`, 0.9381661854806498]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 477}], {
             RGBColor[
             0.2691065215645594, 0.4001783948762585, 0.9386365903444549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 334}], {
             RGBColor[
             0.4327691697643524, 0.5490089625023165, 0.9488672900749079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 340}], {
             RGBColor[
             0.40008441142440987`, 0.5206990676119785, 0.9467846461754836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 361}], {
             RGBColor[
             0.5534678542610545, 0.6483409394418851, 0.9580094602549781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 363}], {
             RGBColor[
             0.4337728092244554, 0.5498782645582716, 0.9489312410938221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 369}], {
             RGBColor[
             0.4413408424038283, 0.5564333145178368, 0.9494134694758627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 370}], {
             RGBColor[
             0.5270887992770681, 0.6269534581897589, 0.9559135075504326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 379}], {
             RGBColor[
             0.386016730119334, 0.5085143491277428, 0.9458882659622865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 498}], {
             RGBColor[
             0.46231188623512687`, 0.5743646420156336, 0.95081403167012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 282}], {
             RGBColor[
             0.5106811757652547, 0.612557396257451, 0.9549190346803453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 285}], {
             RGBColor[
             0.36406115169331943`, 0.4897532041763907, 0.9444186325526303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 324}], {
             RGBColor[
             0.3916907059243627, 0.5136845353495464, 0.9461791633163769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 353}], {
             RGBColor[
             0.5266832510882068, 0.6255486018899017, 0.9561787766673014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 441}], {
             RGBColor[
             0.43191818188119013`, 0.5485275531316196, 0.9487424225125856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 481}], {
             RGBColor[
             0.36596032955819924`, 0.49139817658749463`, 0.9445396464868034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 283}], {
             RGBColor[
             0.4003771577872324, 0.5049037920541919, 0.9484114336869224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 292}], {
             RGBColor[
             0.39925539426111123`, 0.5037247474643232, 0.9483475509136101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 396}], {
             RGBColor[
             0.8065431088390325, 0.8453068187334528, 0.7510492031181083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 422}], {
             RGBColor[
             0.4267760803352025, 0.5326507334404715, 0.9499148132723232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 291}], {
             RGBColor[
             0.7131143362098424, 0.7758096064076011, 0.9720402306671867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 311}], {
             RGBColor[
             0.7590792000371321, 0.8117177073753836, 0.9766215787274166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 319}], {
             RGBColor[
             0.7430956081884199, 0.7992312039433723, 0.9750284836670953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 331}], {
             RGBColor[
             0.8039966134471465, 0.8469425741957761, 0.9810626907032964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 377}], {
             RGBColor[
             0.8762033212681233, 0.9033473444415901, 0.9473540424354466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 419}], {
             RGBColor[
             0.6419960336426249, 0.718265092425402, 0.9663099050077802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 449}], {
             RGBColor[
             0.7498021540184663, 0.8044704085174408, 0.9756969294792002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 484}], {
             RGBColor[
             0.8820966152149525, 0.9042351364524142, 0.7227616167031183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 488}], {
             RGBColor[
             0.7703329161501223, 0.8205091959342619, 0.9777432439776033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 329}], {
             RGBColor[
             0.9154608124727537, 0.9351010298249371, 0.9804756251775316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 406}], {
             RGBColor[
             0.969491060817788, 0.9705130400681918, 0.6951727540379807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 413}], {
             RGBColor[
             0.9610998830487185, 0.9422076271108857, 0.6625746129461039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 486}], {
             RGBColor[
             0.9416456695144926, 0.9559801240610102, 0.9829731602176706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 493}], {
             RGBColor[
             0.9709705008180975, 0.974840539169355, 0.7572967831573334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.2964892825686648, 0.42843496613236076`, 0.9402152006381983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 324}], {
             RGBColor[
             0.3241188367997081, 0.45236629730551653`, 0.9419757314019449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 481}], {
             RGBColor[
             0.2983884604335446, 0.4300799385434647, 0.9403362145723715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 494}], {
             RGBColor[
             0.2685318784304253, 0.3995744085078045, 0.9386038652680744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 327}], {
             RGBColor[
             0.25698076875714937`, 0.3874334598585377, 0.9379460466605166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 470}], {
             RGBColor[
             0.25618724239569113`, 0.386599413340168, 0.9379008565081486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 483}], {
             RGBColor[
             0.2767707745378052, 0.40823401069284493`, 0.939073058213035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 288}], {
             RGBColor[
             0.2504872858476244, 0.38060839761003135`, 0.9375762524150663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 343}], {
             RGBColor[
             0.26889808498261325`, 0.3999593148129905, 0.9386247201894673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 465}], {
             RGBColor[
             0.26376712193927254`, 0.39456634733259277`, 0.9383325194347287]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 324}], {
             RGBColor[
             0.48866791978392093`, 0.5934906203448358, 0.9535163694747727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 353}], {
             RGBColor[
             0.6236604649477651, 0.705354686885191, 0.9635159828256973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 432}], {
             RGBColor[
             0.7531414292760994, 0.8071831282683875, 0.9762245194841053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 441}], {
             RGBColor[
             0.5288953957407483, 0.628333638126909, 0.9560796286709814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 467}], {
             RGBColor[
             0.6572487791197071, 0.7316354395209496, 0.9668355107224047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 292}], {
             RGBColor[
             0.18009239570445779`, 0.3066189047757405, 0.9335673675613205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 386}], {
             RGBColor[
             0.18007057961528944`, 0.30659597468280464`, 0.9335661251673164]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 422}], {
             RGBColor[
             0.207613081778549, 0.3355448907518888, 0.9351346299200334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 442}], {
             RGBColor[
             0.26451897986036277`, 0.3953565976782041, 0.9383753366310607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 444}], {
             RGBColor[
             0.25819284063858217`, 0.3887074242557196, 0.9380150723610645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 464}], {
             RGBColor[
             0.24447969866104266`, 0.37429404257390636`, 0.9372341292122193]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 324}], {
             RGBColor[
             0.3420478957119857, 0.4706864282637755, 0.9430159673470576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 480}], {
             RGBColor[
             0.3339827883337351, 0.46370083761681824`, 0.9425020658366099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 481}], {
             RGBColor[
             0.3163175193458222, 0.44840006950172373`, 0.9413764505174842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 294}], {
             RGBColor[
             0.23070650372322443`, 0.3598175414232626, 0.9364497661361264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 346}], {
             RGBColor[
             0.22049146079372114`, 0.3490808836332252, 0.935868034553093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 358}], {
             RGBColor[
             0.22436323878386594`, 0.35315036778577047`, 0.9360885265818495]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 407}], {
             RGBColor[
             0.21872930348009942`, 0.347228744569382, 0.9357676823009604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 411}], {
             RGBColor[
             0.2313451146629863, 0.3604887620112245, 0.9364861340844057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 295}], {
             RGBColor[
             0.2196997994484176, 0.34824879736508285`, 0.9358229506106359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 299}], {
             RGBColor[
             0.2094890463187735, 0.33751664842668644`, 0.9352414633253583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 300}], {
             RGBColor[
             0.2178846815571592, 0.3463409933762489, 0.9357195823319551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 301}], {
             RGBColor[
             0.20928219811004087`, 0.33729923784437454`, 0.9352296836258756]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 389}], {
             RGBColor[
             0.214155749354975, 0.34242164920379625`, 0.9355072251595016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 451}], {
             RGBColor[
             0.21062876698303812`, 0.3387145671072923, 0.9353063687311225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 456}], {
             RGBColor[
             0.21673512234064032`, 0.34513273375342357`, 0.9356541166351948]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 343}], {
             RGBColor[
             0.274476709135814, 0.40582280250320485`, 0.9389424145821572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 392}], {
             RGBColor[
             0.281033651223698, 0.41271456437171095`, 0.9393158227339358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 465}], {
             RGBColor[
             0.2693457460924733, 0.4004298350228071, 0.9386502138274186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 492}], {
             RGBColor[
             0.26634261157442907`, 0.39727335023461663`, 0.9384791897593554]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 291}], {
             RGBColor[
             0.5471490964494157, 0.6426680909259248, 0.9577289938124869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 297}], {
             RGBColor[
             0.47936763079523015`, 0.5878325714725148, 0.9522613561781106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 314}], {
             RGBColor[
             0.3847232625603534, 0.5076496861015274, 0.9457352039862904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 349}], {
             RGBColor[
             0.42648626116779464`, 0.5438226964259498, 0.9483963053279869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 359}], {
             RGBColor[
             0.4124111574915527, 0.5316315490568694, 0.9474994521678624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 381}], {
             RGBColor[
             0.5043379271734174, 0.6081045829713598, 0.9542271093782111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 397}], {
             RGBColor[
             0.39895955278042317`, 0.5199804451534001, 0.9466423278104561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 419}], {
             RGBColor[
             0.4760307938821983, 0.5851235769437257, 0.9519986681530803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 472}], {
             RGBColor[
             0.3839088844842855, 0.5069443127438695, 0.9456833125354096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 316}], {
             RGBColor[
             0.268490139738015, 0.3995305384956953, 0.9386014883112883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 340}], {
             RGBColor[
             0.31195990105564253`, 0.44256756021982796`, 0.9411741462288754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 355}], {
             RGBColor[
             0.30759602149261944`, 0.4387877870773017, 0.9408960836819469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 362}], {
             RGBColor[
             0.3374733904051481, 0.4646660623491092, 0.9427998432095333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 378}], {
             RGBColor[
             0.28478483318943354`, 0.41665729445637256`, 0.939529446997508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 384}], {
             RGBColor[
             0.2851530200769201, 0.4170442822195179, 0.9395504146960666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 297}], {
             RGBColor[
             0.5871456749634538, 0.6755178075184964, 0.9607730371664382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 311}], {
             RGBColor[
             0.7008920044449292, 0.7662614279396891, 0.9708220228610445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 319}], {
             RGBColor[
             0.6849084125962169, 0.7537749245076777, 0.969228927800723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 349}], {
             RGBColor[
             0.5342643053360183, 0.6315079324719315, 0.9569079863163146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 359}], {
             RGBColor[
             0.5201892016597764, 0.619316785102851, 0.95601113315619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 419}], {
             RGBColor[
             0.583808838050422, 0.6728088129897074, 0.960510349141408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 488}], {
             RGBColor[
             0.7121457205579194, 0.7750529164985673, 0.971943688111231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 308}], {
             RGBColor[
             0.17895845847297373`, 0.30542706484967774`, 0.9335027915134972]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 386}], {
             RGBColor[
             0.17894881608916835`, 0.3054169300929359, 0.9335022423940041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 422}], {
             RGBColor[
             0.20649131825242792`, 0.3343658461620201, 0.9350707471467212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 298}], {
             RGBColor[
             0.9279560632534805, 0.9449120378208546, 0.9763848153450053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 317}], {
             RGBColor[
             0.9188363181868828, 0.7644234365766909, 0.5933539685152149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 353}], {
             RGBColor[
             0.7969674264911133, 0.8418814193634385, 0.9635324755439242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 418}], {
             RGBColor[
             0.9663729017016692, 0.9744415456652006, 0.9418060854539165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 420}], {
             RGBColor[
             0.9614575711812897, 0.9707757002112165, 0.9501264579014013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 432}], {
             RGBColor[
             0.9264483908194477, 0.943709860746635, 0.9762410122023322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 358}], {
             RGBColor[
             0.23196947764628847`, 0.36114500709357467`, 0.9365216906326425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 411}], {
             RGBColor[
             0.23895135352540886`, 0.3684834013190287, 0.9369192981351986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 430}], {
             RGBColor[
             0.23902588418057213`, 0.36856173776312173`, 0.9369235425457519]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 478}], {
             RGBColor[
             0.25217734273393444`, 0.38238475455333876`, 0.9376724986545265]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 300}], {
             RGBColor[
             0.22777276498654234`, 0.3567339960012304, 0.9362826940551499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 336}], {
             RGBColor[
             0.22591321478921644`, 0.3547794908415487, 0.9361767954223702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 389}], {
             RGBColor[
             0.22404383278435813`, 0.3528146518287777, 0.9360703368826964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 409}], {
             RGBColor[
             0.23557177233220394`, 0.3649312472071466, 0.9367268359858879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 456}], {
             RGBColor[
             0.22662320577002346`, 0.355525736378405, 0.9362172283583896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 458}], {
             RGBColor[
             0.2300435692999762, 0.35912075531195864`, 0.936412013001446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 332}], {
             RGBColor[
             0.3578059368755654, 0.48433525149749035`, 0.9440200557957121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 395}], {
             RGBColor[
             0.289203696626415, 0.4208696734674796, 0.9397969170059906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 424}], {
             RGBColor[
             0.31700712622472516`, 0.4489973723195799, 0.9414203916580124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 440}], {
             RGBColor[
             0.29754682970453167`, 0.4296388353177702, 0.94027204609223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 453}], {
             RGBColor[
             0.2988633264806147, 0.4310225569001501, 0.9403470186360454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 311}], {
             RGBColor[
             0.6331105387907436, 0.7114259084862791, 0.9653543852266682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 314}], {
             RGBColor[
             0.42471984107439154`, 0.540499402694099, 0.9487792473402418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 349}], {
             RGBColor[
             0.4664828396818328, 0.5766724130185215, 0.9514403486819383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 359}], {
             RGBColor[
             0.45240773600559087`, 0.5644812656494411, 0.9505434955218137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 381}], {
             RGBColor[
             0.5443345056874556, 0.6409542995639315, 0.9572711527321625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 397}], {
             RGBColor[
             0.4389561312944613, 0.5528301617459719, 0.9496863711644075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 419}], {
             RGBColor[
             0.5160273723962365, 0.6179732935362974, 0.9550427115070317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 353}], {
             RGBColor[
             0.7706511770330843, 0.8213765109750578, 0.9776280646137345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 418}], {
             RGBColor[
             0.9400566522436402, 0.9539366372768199, 0.955901674523727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 420}], {
             RGBColor[
             0.9351413217232607, 0.9502707918228358, 0.9642220469712115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 432}], {
             RGBColor[
             0.9001321413614187, 0.9232049523582542, 0.9903366012721426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 300}], {
             RGBColor[
             0.21756201185689822`, 0.346001847062834, 0.9357012067698722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 301}], {
             RGBColor[
             0.20895952840977988`, 0.3369600915309596, 0.9352113080637927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 389}], {
             RGBColor[
             0.213833079654714, 0.34208250289038133`, 0.9354888495974187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 451}], {
             RGBColor[
             0.21030609728277713`, 0.3383754207938774, 0.9352879931690398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 456}], {
             RGBColor[
             0.21641245264037934`, 0.34479358744000865`, 0.935635741073112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 301}], {
             RGBColor[
             0.2173551636481656, 0.3457844364805221, 0.9356894270703895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 389}], {
             RGBColor[
             0.2222287148930997, 0.35090684783994386`, 0.9359669686040155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 409}], {
             RGBColor[
             0.23375665444094554`, 0.3630234432183127, 0.936623467707207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 451}], {
             RGBColor[
             0.21870173252116284`, 0.3471997657434399, 0.9357661121756364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 456}], {
             RGBColor[
             0.22480808787876505`, 0.3536179323895711, 0.9361138600797088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 458}], {
             RGBColor[
             0.22822845140871784`, 0.35721295132312475`, 0.9363086447227651]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 389}], {
             RGBColor[
             0.21362623144598136`, 0.3418650923080694, 0.9354770698979359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 451}], {
             RGBColor[
             0.2100992490740445, 0.3381580102115655, 0.9352762134695569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 456}], {
             RGBColor[
             0.21620560443164671`, 0.3445761768576967, 0.9356239613736292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 315}], {
             RGBColor[
             0.18782448730516063`, 0.31474582329100176`, 0.934007698739376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 325}], {
             RGBColor[
             0.18458313935535953`, 0.31133896108243087`, 0.9338231087687794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 347}], {
             RGBColor[
             0.18453817917078433`, 0.311291705077802, 0.9338205483527805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 368}], {
             RGBColor[
             0.2991255041617159, 0.42254414020486286`, 0.9406824754328269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 386}], {
             RGBColor[
             0.18453817917078433`, 0.311291705077802, 0.9338205483527805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 421}], {
             RGBColor[
             0.18460298206136966`, 0.31135981702454774`, 0.9338242387815321]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 477}], {
             RGBColor[
             0.21741049289010705`, 0.3458425910218791, 0.9356925779888657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 366}], {
             RGBColor[
             0.2851324087513453, 0.4170226184095053, 0.9395492409115669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 435}], {
             RGBColor[
             0.2816881021628791, 0.4134024338033765, 0.9393530927467486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 473}], {
             RGBColor[
             0.31604489027716914`, 0.44784149062043943`, 0.9413708849892584]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 310}], {
             RGBColor[
             0.317660558842397, 0.44845488439544834`, 0.9415026138990965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 429}], {
             RGBColor[
             0.316081007071654, 0.4467946753350308, 0.9414126607624902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 483}], {
             RGBColor[
             0.3176066092257016, 0.44839817992769826`, 0.941499541548237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 382}], {
             RGBColor[
             0.2666682843502908, 0.39761565297089385`, 0.938497736342151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 416}], {
             RGBColor[
             0.2563227786802443, 0.3867418705687301, 0.9379085750990459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 427}], {
             RGBColor[
             0.26530600013852146`, 0.3961838058905166, 0.9384201562716097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 438}], {
             RGBColor[
             0.23628821482403703`, 0.36568427369114076`, 0.9367676363259161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 460}], {
             RGBColor[
             0.24972906299601538`, 0.37981145731888477`, 0.9375330727453572]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 499}], {
             RGBColor[
             0.2559152551896322, 0.3863135375416151, 0.9378853672391325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 317}], {
             RGBColor[
             0.8704899188810679, 0.5035084402927961, 0.2135951122625132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 357}], {
             RGBColor[
             0.8823608988640697, 0.5565720408834082, 0.22345710970379568`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 418}], {
             RGBColor[
             0.9180265023958543, 0.7135265493813059, 0.5620472292012149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 420}], {
             RGBColor[
             0.9131111718754747, 0.7098607039273219, 0.5703676016486996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 372}], {
             RGBColor[
             0.47013131999468205`, 0.580712810603117, 0.9514296061392018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 417}], {
             RGBColor[
             0.5854211152910297, 0.6734114544902967, 0.9611201594979415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 386}], {
             RGBColor[
             0.17893664238380538`, 0.3054041347567419, 0.9335015491194931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 421}], {
             RGBColor[
             0.1790014452743907, 0.3054722467034876, 0.9335052395482446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 422}], {
             RGBColor[
             0.20647914454706495`, 0.3343530508258261, 0.9350700538722102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 423}], {
             RGBColor[
             0.1833860881198116, 0.31008078433643804`, 0.9337549384717936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 446}], {
             RGBColor[
             0.2035487790418117, 0.3312730508839008, 0.9349031738917732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 320}], {
             RGBColor[
             0.9908166313021023, 0.9885283450055495, 0.6606847997028811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 337}], {
             RGBColor[
             0.926620732552479, 0.9394372573300418, 0.7346744089406012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 348}], {
             RGBColor[
             0.976471187338104, 0.9319682118150352, 0.39079228120582354`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 375}], {
             RGBColor[
             0.9756161016685031, 0.977924558793291, 0.7192291003603996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 489}], {
             RGBColor[
             0.9915641796444485, 0.9888374754562259, 0.6482959890771074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 327}], {
             RGBColor[
             0.2769131154519483, 0.40838362001854456`, 0.939081164317521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 399}], {
             RGBColor[
             0.26912901254486776`, 0.40020203432257306`, 0.938637871172511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 412}], {
             RGBColor[
             0.26956927876194814`, 0.4006647820312149, 0.9386629436822582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 429}], {
             RGBColor[
             0.2951775190785565, 0.4275806662601843, 0.9401212950842925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 483}], {
             RGBColor[
             0.2967031212326041, 0.4291841708528518, 0.9402081758700394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 319}], {
             RGBColor[
             0.7308732764235066, 0.7896830254754603, 0.9738102758609529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 331}], {
             RGBColor[
             0.7917742816822333, 0.837394395727864, 0.9798444828971542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 349}], {
             RGBColor[
             0.5802291691633081, 0.667416033439714, 0.9614893343765445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 377}], {
             RGBColor[
             0.8639809895032101, 0.8937991659736781, 0.9461358346293043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 419}], {
             RGBColor[
             0.6297737018777119, 0.70871691395749, 0.9650916972016379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 484}], {
             RGBColor[
             0.8698742834500395, 0.8946869579845022, 0.7215434088969761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 488}], {
             RGBColor[
             0.7581105843852092, 0.8109610174663499, 0.9765250361714609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 354}], {
             RGBColor[
             0.3330876906173925, 0.4625247982993003, 0.942459704446583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 376}], {
             RGBColor[
             0.2919333190231436, 0.4241708063077816, 0.9399365426905006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 400}], {
             RGBColor[
             0.30016668312241634`, 0.43282459400155193`, 0.9404054205957836]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 414}], {
             RGBColor[
             0.2895347527456831, 0.421649761072285, 0.9397999478893602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 415}], {
             RGBColor[
             0.29571211190112656`, 0.42814255721184813`, 0.9401517393546788]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 379}], {
             RGBColor[
             0.288128547073246, 0.4201206026991259, 0.9397217393007642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 380}], {
             RGBColor[
             0.26990447818225494`, 0.4010170978748282, 0.9386820327933616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 390}], {
             RGBColor[
             0.28385568108857195`, 0.41568069668672125`, 0.9394765331599213]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 411}], {
             RGBColor[
             0.2532739296678089, 0.38353733694846814`, 0.9377349476581557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 478}], {
             RGBColor[
             0.26649991887633445`, 0.3974386901827782, 0.9384881481774836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 359}], {
             RGBColor[
             0.3577633677707141, 0.48429838027845357`, 0.9440173433299934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 373}], {
             RGBColor[
             0.3118454823562334, 0.44312769697598026`, 0.9411427175470836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 397}], {
             RGBColor[
             0.34431176305958455`, 0.4726472763749843, 0.9431602189725873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 398}], {
             RGBColor[
             0.29561326424229706`, 0.426066606556162, 0.9402183167389095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 472}], {
             RGBColor[
             0.3292610947634469, 0.4596111439654538, 0.9422012036975409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 325}], {
             RGBColor[
             0.1822582683189515, 0.30889537421782864`, 0.9336907108025945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 347}], {
             RGBColor[
             0.1822133081343763, 0.30884811821319974`, 0.9336881503865955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 368}], {
             RGBColor[
             0.2968006331253079, 0.42010055334026064`, 0.9405500774666419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 386}], {
             RGBColor[
             0.1822133081343763, 0.30884811821319974`, 0.9336881503865955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 401}], {
             RGBColor[
             0.47947599697395743`, 0.5676241897079666, 0.9559647317614918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 378}], {
             RGBColor[
             0.26678973270236006`, 0.397743302889189, 0.9385046526461347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 357}], {
             RGBColor[
             0.895271303645258, 0.6164935275347583, 0.23428070819651722`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 418}], {
             RGBColor[
             0.9309369071770426, 0.7734480360326559, 0.5728708276939365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 420}], {
             RGBColor[
             0.9260215766566631, 0.7697821905786719, 0.5811912001414211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 321}], {
             RGBColor[
             0.33755888801482614`, 0.46679827542058316`, 0.9427299317460682]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 330}], {
             RGBColor[
             0.32419593809646025`, 0.45501163764918373`, 0.9418862305492528]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 335}], {
             RGBColor[
             0.3093572475376726, 0.43941523304457686`, 0.9410411890738053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 350}], {
             RGBColor[
             0.3520561578815369, 0.47935508192515797`, 0.9436536849625428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 354}], {
             RGBColor[
             0.35185308329442466`, 0.47917918892462685`, 0.9436407452294238]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 383}], {
             RGBColor[
             0.3354424216880899, 0.46496509866505487`, 0.9425950723832464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 479}], {
             RGBColor[
             0.3767164983407358, 0.5007146293661655, 0.94522502005032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 482}], {
             RGBColor[
             0.35021188070592757`, 0.4777576617317112, 0.9435361692517431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 496}], {
             RGBColor[
             0.3094159330482752, 0.43947691523709653`, 0.9410445311268166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 331}], {
             RGBColor[
             0.775790689833521, 0.8249078922958527, 0.9782513878368327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 377}], {
             RGBColor[
             0.8479973976544979, 0.8813126625416667, 0.9445427395689829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 449}], {
             RGBColor[
             0.7215962304048408, 0.7824357266175173, 0.9728856266127364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 488}], {
             RGBColor[
             0.7421269925364968, 0.7984745140343386, 0.9749319411111395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 337}], {
             RGBColor[
             0.9244065988908812, 0.9404637664434601, 0.9125392493325524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 348}], {
             RGBColor[
             0.9742570536765062, 0.9329947209284535, 0.5686571215977747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 361}], {
             RGBColor[
             0.8164019725999951, 0.8557645940777792, 0.9018606390244552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 375}], {
             RGBColor[
             0.9734019680069053, 0.9789510679067093, 0.8970939407523506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 335}], {
             RGBColor[
             0.3049738126003747, 0.4356185220197354, 0.94076188047572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 383}], {
             RGBColor[
             0.3310589867507921, 0.46116838764021345`, 0.942315763785161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 479}], {
             RGBColor[
             0.37233306340343797`, 0.49691791834132404`, 0.9449457114522347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 482}], {
             RGBColor[
             0.3458284457686297, 0.47396095070686983`, 0.9432568606536578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 496}], {
             RGBColor[
             0.3050324981109774, 0.4356802042122551, 0.9407652225287313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 494}], {
             RGBColor[
             0.2588610411681461, 0.3894097453786518, 0.9380531253927091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 342}], {
             RGBColor[
             0.2496659047127254, 0.3797450739586806, 0.9375294759745583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 395}], {
             RGBColor[
             0.25216611947306267`, 0.3823729581945666, 0.9376718595064233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 447}], {
             RGBColor[
             0.24292230663621342`, 0.3726571248114532, 0.9371454380403603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 452}], {
             RGBColor[
             0.23164904535488023`, 0.3608082124387239, 0.9365034424876839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 463}], {
             RGBColor[
             0.25322101360276406`, 0.3834817188090337, 0.9377319341665338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 441}], {
             RGBColor[
             0.4099049258998564, 0.5294607772190044, 0.947339757307013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 481}], {
             RGBColor[
             0.3439470735768655, 0.47233140067487944`, 0.9431369812812307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 347}], {
             RGBColor[
             0.1789719601845752, 0.3054412560046289, 0.9335035604159989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 368}], {
             RGBColor[
             0.2935592851755068, 0.41669369113168975`, 0.9403654874960453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 386}], {
             RGBColor[
             0.1789719601845752, 0.3054412560046289, 0.9335035604159989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 401}], {
             RGBColor[
             0.4762346490241563, 0.5642173274993956, 0.9557801417908952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 421}], {
             RGBColor[
             0.17903676307516053`, 0.3055093679513746, 0.9335072508447505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 405}], {
             RGBColor[
             0.9345940973525277, 0.7578425175728066, 0.403625723074449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 428}], {
             RGBColor[
             0.8527545036662538, 0.3801225472055363, 0.19711821090416948`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 434}], {
             RGBColor[
             0.9331890448533395, 0.7583565146768234, 0.5065076494810187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 469}], {
             RGBColor[
             0.8678030946468546, 0.4926065528105953, 0.21140400054171546`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 474}], {
             RGBColor[
             0.9341363327937491, 0.7587482425843726, 0.49080863680582576`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 475}], {
             RGBColor[
             0.8570894511774583, 0.4134428533627656, 0.20126936153652183`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 491}], {
             RGBColor[
             0.9346684716417725, 0.7580015966571071, 0.4117209054738351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 495}], {
             RGBColor[
             0.8586889913459645, 0.42573762002087545`, 0.2028010830083056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 399}], {
             RGBColor[
             0.24928505714751653`, 0.3793447790205158, 0.9375077872691331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 412}], {
             RGBColor[
             0.2497253233645969, 0.37980752672915763`, 0.9375328597788803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 483}], {
             RGBColor[
             0.27685916583525294`, 0.4083269155507945, 0.9390780919666615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 431}], {
             RGBColor[
             0.4169264678183623, 0.535542483915856, 0.9477871637491544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 433}], {
             RGBColor[
             0.35540962848104596`, 0.48225968960811955`, 0.9438673651437858]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 436}], {
             RGBColor[
             0.42911640965865483`, 0.5455685636524759, 0.9487109542359491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 462}], {
             RGBColor[
             0.4245956854340748, 0.5418984360706564, 0.9483550662650316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 487}], {
             RGBColor[
             0.4823721914903405, 0.5888040064890694, 0.952903444464096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 406}], {
             RGBColor[
             0.9365881325497546, 0.9446037269852596, 0.7033574817962612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 413}], {
             RGBColor[
             0.9281969547806851, 0.9162983140279535, 0.6707593407043844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 486}], {
             RGBColor[
             0.9087427412464592, 0.930070810978078, 0.9911578879759511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 350}], {
             RGBColor[
             0.33430977302587317`, 0.4637717331289171, 0.9425306751676419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 354}], {
             RGBColor[
             0.3341066984387609, 0.463595840128386, 0.9425177354345229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 414}], {
             RGBColor[
             0.2905537605670515, 0.4227208029013707, 0.9398579788773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 415}], {
             RGBColor[
             0.29673111972249494`, 0.4292135990409338, 0.9402097703426187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 482}], {
             RGBColor[
             0.33246549585026375`, 0.4621743129354704, 0.9424131594568423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 496}], {
             RGBColor[
             0.2916695481926115, 0.42389356644085574`, 0.9399215213319159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 377}], {
             RGBColor[
             0.9088984029132244, 0.9290240327940705, 0.9505769466051841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 403}], {
             RGBColor[
             0.8828018353475209, 0.9093862367613971, 0.9886836212135901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 449}], {
             RGBColor[
             0.7824972356635673, 0.8301470968699212, 0.9789198336489376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 488}], {
             RGBColor[
             0.8030279977952235, 0.8461858842867422, 0.9809661481473407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 344}], {
             RGBColor[
             0.4329675168621825, 0.5491533716913533, 0.9488874962659426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 393}], {
             RGBColor[
             0.4317017689879543, 0.548125780545763, 0.9487878519566961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 424}], {
             RGBColor[
             0.36139324266635137`, 0.48744239547023754`, 0.9442486357485711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 392}], {
             RGBColor[
             0.34232526370384136`, 0.4706729127563853, 0.943042932303461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 442}], {
             RGBColor[
             0.331297230301234, 0.4590817504325423, 0.942414902115696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 459}], {
             RGBColor[
             0.3845976264069504, 0.5075408663801063, 0.9457271985616913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 492}], {
             RGBColor[
             0.32763422405457243`, 0.45523169861929097`, 0.9422062993288807]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 340}], {
             RGBColor[
             0.37011932022613914`, 0.4950004852671151, 0.9448046536945134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 355}], {
             RGBColor[
             0.36575544066311605`, 0.49122071212458884`, 0.9445265911475849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 361}], {
             RGBColor[
             0.5235027630627838, 0.6226423570970218, 0.9560294677740079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 363}], {
             RGBColor[
             0.40380771802618465`, 0.5241796822134083, 0.9469512486128518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 369}], {
             RGBColor[
             0.4113757512055576, 0.5307347321729735, 0.9474334769948924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 370}], {
             RGBColor[
             0.49712370807879736`, 0.6012548758448955, 0.9539335150694623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 379}], {
             RGBColor[
             0.3560516389210633, 0.4828157667828796, 0.9439082734813162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 498}], {
             RGBColor[
             0.4323467950368561, 0.5486660596707702, 0.9488340391891498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 383}], {
             RGBColor[
             0.3028573462736385, 0.4337853452642071, 0.940627021112898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 409}], {
             RGBColor[
             0.25916391695491414`, 0.389728087033979, 0.938070373720701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 482}], {
             RGBColor[
             0.3176268052914761, 0.44657790833086347`, 0.9415681179813948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 496}], {
             RGBColor[
             0.27683085763382376`, 0.40829716183624876`, 0.9390764798564684]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 409}], {
             RGBColor[
             0.23189710424361965`, 0.36106893805863094`, 0.9365175690744273]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 456}], {
             RGBColor[
             0.22294853768143919`, 0.3516634272298894, 0.936007961446929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 458}], {
             RGBColor[
             0.22636890121139194`, 0.35525844616344304`, 0.9362027460899854]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 348}], {
             RGBColor[
             0.9100611549268829, 0.8839036332529456, 0.6426467308354947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 361}], {
             RGBColor[
             0.752206073850372, 0.8066735064022713, 0.9758502482621753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 370}], {
             RGBColor[
             0.7258270188663856, 0.785286025150145, 0.9737542955576297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 375}], {
             RGBColor[
             0.9092060692572821, 0.9298599802312014, 0.9710835499900707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 498}], {
             RGBColor[
             0.6610501058244442, 0.7326972089760198, 0.9686548196773171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 369}], {
             RGBColor[
             0.37002637582951403`, 0.49491998150227967`, 0.9447987313597479]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 379}], {
             RGBColor[
             0.31470226354501973`, 0.4470010161121858, 0.9412735278461717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 390}], {
             RGBColor[
             0.3104293975603457, 0.44256111009978116`, 0.9410283217053288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 425}], {
             RGBColor[
             0.3477240886796976, 0.47560286131865376`, 0.9433776493436998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 478}], {
             RGBColor[
             0.29307363534810826`, 0.42431910359583813`, 0.9400399367228911]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 365}], {
             RGBColor[
             0.2143326753092825, 0.34260760959952685`, 0.9355173008308608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 355}], {
             RGBColor[
             0.3330706823231735, 0.4629108172342508, 0.9424439472481606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 362}], {
             RGBColor[
             0.3629480512357022, 0.4887890925060583, 0.944347706775747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 363}], {
             RGBColor[
             0.37112295968624204`, 0.49586978732307024`, 0.9448686047134276]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 378}], {
             RGBColor[
             0.31025949401998754`, 0.4407803246133216, 0.9410773105637218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 379}], {
             RGBColor[
             0.32336688058112073`, 0.45450587189254155`, 0.941825629581892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 380}], {
             RGBColor[
             0.3051428116901297, 0.43540236706824387`, 0.9407859230744895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 498}], {
             RGBColor[
             0.39966203669691347`, 0.5203561647804322, 0.9467513952897255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 387}], {
             RGBColor[
             0.8843435887930974, 0.9064532397024012, 0.7600495256450741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 403}], {
             RGBColor[
             0.9612426733705868, 0.9674078133042042, 0.7674804702008887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 405}], {
             RGBColor[
             0.9937930272646951, 0.989132237877419, 0.5657875066366207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 450}], {
             RGBColor[
             0.9056409272943111, 0.562891578052587, 0.35323513131972123`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 469}], {
             RGBColor[
             0.927002024559022, 0.7238962731152077, 0.3735657841038871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 491}], {
             RGBColor[
             0.9938674015539399, 0.9892913169617195, 0.5738826890360067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 395}], {
             RGBColor[
             0.2624873580585535, 0.3932212343522405, 0.9382596387749628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 447}], {
             RGBColor[
             0.2532435452217043, 0.38350540096912705`, 0.9377332173088998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 453}], {
             RGBColor[
             0.27214698791275327`, 0.40337411778491095`, 0.9388097404050177]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 463}], {
             RGBColor[
             0.2635422521882549, 0.3943299949667075, 0.9383197134350733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 392}], {
             RGBColor[
             0.29944445035868683`, 0.4320654815746701, 0.9403642905083368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 433}], {
             RGBColor[
             0.3091968798489231, 0.4407663035487692, 0.9409764153784905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 465}], {
             RGBColor[
             0.2877565452274621, 0.4197807522257663, 0.9396986816018197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 387}], {
             RGBColor[
             0.6194283934274943, 0.6998852662527452, 0.9645732255440658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 424}], {
             RGBColor[
             0.39216870621134226`, 0.5138154925134429, 0.9462878321282429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 375}], {
             RGBColor[
             0.8089633164388916, 0.8512244424146573, 0.9611785706908804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 426}], {
             RGBColor[
             0.7649497936964772, 0.8167095300211071, 0.9770990522255436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 448}], {
             RGBColor[
             0.6138322543981429, 0.6971096748541594, 0.9629241548523259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 489}], {
             RGBColor[
             0.8249113944148371, 0.8621373590775923, 0.8902454594075883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 498}], {
             RGBColor[
             0.5608073530060538, 0.6540616711594758, 0.9587498403781267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 358}], {
             RGBColor[
             0.2217544347167852, 0.3504083493035373, 0.935939959049609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 404}], {
             RGBColor[
             0.21566548218765702`, 0.3440084741335353, 0.9355932022108733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 407}], {
             RGBColor[
             0.2161204994130187, 0.34448672608714886`, 0.9356191147687198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 408}], {
             RGBColor[
             0.22019359510263653`, 0.34876780790611966`, 0.9358510715426385]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 430}], {
             RGBColor[
             0.22881084125106885`, 0.35782507997308444`, 0.9363418109627185]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 368}], {
             RGBColor[
             0.2935143249909316, 0.4166464351270609, 0.9403629270800464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 386}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 421}], {
             RGBColor[
             0.17899180289058533`, 0.3054621119467458, 0.9335046904287516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 477}], {
             RGBColor[
             0.2117993137193227, 0.3399448859440771, 0.9353730296360853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 375}], {
             RGBColor[
             0.959056524042907, 0.9223909347161948, 0.6272014222552931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 428}], {
             RGBColor[
             0.8951225528654855, 0.5552983535621828, 0.23772264959288408`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 359}], {
             RGBColor[
             0.3995263663781553, 0.520471390602876, 0.94667844467169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 371}], {
             RGBColor[
             0.3882726943942144, 0.5107240255563866, 0.9459613706441047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 397}], {
             RGBColor[
             0.38607476166702576`, 0.5088202866994067, 0.9458213203142838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 419}], {
             RGBColor[
             0.4631460027688009, 0.5739634184897324, 0.951177660656908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 354}], {
             RGBColor[
             0.36196691822383753`, 0.4879392844043602, 0.9442851898478128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 383}], {
             RGBColor[
             0.34555625661750283`, 0.4737251941447882, 0.9432395170016354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 414}], {
             RGBColor[
             0.31841398035212815`, 0.44706424717734483`, 0.94162543329059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 479}], {
             RGBColor[
             0.3868303332701487, 0.5094747248458988, 0.9458694646687091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 482}], {
             RGBColor[
             0.36032571563534044`, 0.4865177572114446, 0.9441806138701323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 356}], {
             RGBColor[
             0.2796916905937343, 0.4113040786644009, 0.9392394000613121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 463}], {
             RGBColor[
             0.27857140569147526`, 0.4101265882019613, 0.9391756014934415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 367}], {
             RGBColor[
             0.2288379775147259, 0.35785360190672644`, 0.9363433563327893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 399}], {
             RGBColor[
             0.23466592421327268`, 0.3639791434000619, 0.936675249275597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 412}], {
             RGBColor[
             0.23510619043035305`, 0.36444189110870373`, 0.9367003217853442]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 457}], {
             RGBColor[
             0.22470998276050042`, 0.3535148176900512, 0.9361082731383572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 418}], {
             RGBColor[
             0.809068015481273, 0.8509060188194038, 0.9430493347226458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 420}], {
             RGBColor[
             0.8041526849608935, 0.8472401733654197, 0.9513697071701304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 432}], {
             RGBColor[
             0.7691435045990516, 0.820174333900838, 0.9774842614710615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 441}], {
             RGBColor[
             0.5448974710637005, 0.6413248437593597, 0.9573393706579376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 372}], {
             RGBColor[
             0.416108457877265, 0.5343687074376324, 0.9478635928798225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 414}], {
             RGBColor[
             0.3182109057650159, 0.4468883541768137, 0.941612493557471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 415}], {
             RGBColor[
             0.32438826492045936`, 0.4533811503163769, 0.9419642850227896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 479}], {
             RGBColor[
             0.38662725868303643`, 0.5092988318453677, 0.9458565249355901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 482}], {
             RGBColor[
             0.3601226410482282, 0.48634186421091347`, 0.9441676741370133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 362}], {
             RGBColor[
             0.3585841716726791, 0.48500931936353203`, 0.9440696442288183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 363}], {
             RGBColor[
             0.366759080123219, 0.492090014180544, 0.9445905421664991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 378}], {
             RGBColor[
             0.30589561445696456`, 0.4370005514707954, 0.940799248016793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 384}], {
             RGBColor[
             0.3062638013444511, 0.43738753923394075`, 0.9408202157153518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 498}], {
             RGBColor[
             0.3952981571338905, 0.516576391637906, 0.946473332742797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 463}], {
             RGBColor[
             0.26821764598055253`, 0.3992441302795001, 0.9385859701949193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 418}], {
             RGBColor[
             0.9428078871600445, 0.8265116366232681, 0.582732825135219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 420}], {
             RGBColor[
             0.937892556639665, 0.822845791169284, 0.5910531975827036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 404}], {
             RGBColor[
             0.21953726017780179`, 0.34807795828608057`, 0.9358136942396298]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 407}], {
             RGBColor[
             0.21999227740316346`, 0.34855621023969413`, 0.9358396067974764]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 408}], {
             RGBColor[
             0.2240653730927813, 0.35283729205866493`, 0.936071563571395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 430}], {
             RGBColor[
             0.23268261924121364`, 0.3618945641256297, 0.936562302991475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 371}], {
             RGBColor[
             0.37419759071797254`, 0.49853287818730624`, 0.94506451748398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 397}], {
             RGBColor[
             0.3719996579907838, 0.4966291393303264, 0.9449244671541592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 419}], {
             RGBColor[
             0.44907089909255904`, 0.561772271120652, 0.9502808074967835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 427}], {
             RGBColor[
             0.3324756951564906, 0.4596914885288097, 0.9425050411722034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 393}], {
             RGBColor[
             0.5202889035975207, 0.6214329965452928, 0.9553781948537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 466}], {
             RGBColor[
             0.5414372478398441, 0.638602175123262, 0.9570430699813932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 468}], {
             RGBColor[
             0.5288716731016017, 0.6284008754780657, 0.9560538619087819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 363}], {
             RGBColor[
             0.5245064025228867, 0.6235116591529769, 0.9560934187929221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 370}], {
             RGBColor[
             0.6178223925754994, 0.7005868527844641, 0.9630756852495326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 498}], {
             RGBColor[
             0.5530454795335582, 0.6479980366103388, 0.95797620936922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 363}], {
             RGBColor[
             0.3966364490357477, 0.5179682894523514, 0.9464943016940854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 384}], {
             RGBColor[
             0.33614117025697976`, 0.4632658145057482, 0.9427239752429382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 498}], {
             RGBColor[
             0.4251755260464191, 0.5424546669097134, 0.9483770922703834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 370}], {
             RGBColor[
             0.4981273475389003, 0.6021241779008506, 0.9539974660883765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 379}], {
             RGBColor[
             0.35705527838116624`, 0.4836850688388347, 0.9439722245002304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 498}], {
             RGBColor[
             0.433350434496959, 0.5495353617267253, 0.948897990208064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 374}], {
             RGBColor[
             0.2551484985501697, 0.3855076276983612, 0.93784170158283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 437}], {
             RGBColor[
             0.25719856867599794`, 0.38766238138256004`, 0.9379584500436889]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 435}], {
             RGBColor[
             0.2615619901606841, 0.3922486140198663, 0.9382069404421383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 473}], {
             RGBColor[
             0.29591877827497415`, 0.42668767083692927`, 0.940224732684648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 416}], {
             RGBColor[
             0.24568937276892794`, 0.3755654867590621, 0.9373030183631108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 457}], {
             RGBColor[
             0.22571706608911693`, 0.3545733261211982, 0.9361656250440755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 499}], {
             RGBColor[
             0.24528184927831587`, 0.3751371537319471, 0.9372798105031974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 386}], {
             RGBColor[
             0.2935143249909316, 0.4166464351270609, 0.9403629270800464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 401}], {
             RGBColor[
             0.5907770138305127, 0.6754225066218276, 0.9626395084549426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 500}], {
             RGBColor[
             0.6137971561371982, 0.33936679556971105`, 0.5567621778131115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 370}], {
             RGBColor[
             0.5056953807182732, 0.6086792278604158, 0.9544796944704173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 379}], {
             RGBColor[
             0.3646233115605392, 0.49024011879839996`, 0.944454452882271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 390}], {
             RGBColor[
             0.36035044557586515`, 0.48580021278599533`, 0.9442092467414281]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 425}], {
             RGBColor[
             0.397645136695217, 0.5188419640048679, 0.9465585743797993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 466}], {
             RGBColor[
             0.46172779849419876`, 0.5729843638939052, 0.9510184053391775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 466}], {
             RGBColor[
             0.5474757553674385, 0.6435045075658272, 0.9575184434137474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 382}], {
             RGBColor[
             0.322584307384319, 0.45137597056269757`, 0.9418655472151594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 419}], {
             RGBColor[
             0.43781722710861815`, 0.5520249060741627, 0.9495637334691982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 427}], {
             RGBColor[
             0.3212220231725497, 0.4499441234823203, 0.9417879671446181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 429}], {
             RGBColor[
             0.3282709430209225, 0.4573529851702918, 0.9421893927020404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 417}], {
             RGBColor[
             0.5857428674141524, 0.6736726673586156, 0.9611454890036907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 398}], {
             RGBColor[
             0.27738327375901567`, 0.40887778620903076`, 0.9391079391375716]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 472}], {
             RGBColor[
             0.31103110428016545`, 0.44242232361832246`, 0.9410908260962028]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 391}], {
             RGBColor[
             0.24642877472957408`, 0.3763426451004932, 0.9373451262109225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 437}], {
             RGBColor[
             0.25378039219455883`, 0.3840696611756612, 0.9377637899498099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 426}], {
             RGBColor[
             0.9141879156308917, 0.9338323693009003, 0.9715587229445324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 489}], {
             RGBColor[
             0.9741495163492516, 0.9792601983573855, 0.8847051301265769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 400}], {
             RGBColor[
             0.2876884645475003, 0.41970919511456195`, 0.9396948045078122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 414}], {
             RGBColor[
             0.27705653417076703`, 0.40853436218529504`, 0.9390893318013886]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 415}], {
             RGBColor[
             0.28323389332621046`, 0.41502715832485815`, 0.9394411232667073]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 464}], {
             RGBColor[
             0.2616609318454717, 0.3923526080038432, 0.9382125750247157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 485}], {
             RGBColor[
             0.26372814560153673`, 0.3945253807303899, 0.938330299789955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 497}], {
             RGBColor[
             0.25772437162935435`, 0.38821503362437043`, 0.9379883937440268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 403}], {
             RGBColor[
             0.9550085431684978, 0.9657910070072111, 0.9549749729457403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 449}], {
             RGBColor[
             0.8547039434845443, 0.8865518671157351, 0.9452111853810878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 484}], {
             RGBColor[
             0.9869984046810305, 0.9863165950507087, 0.692275872605006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 488}], {
             RGBColor[
             0.8752347056162003, 0.9025906545325564, 0.9472574998794909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 380}], {
             RGBColor[
             0.27796774382392075`, 0.40949210130478847`, 0.939141223843122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 380}], {
             RGBColor[
             0.29107513038505384`, 0.42321764858400834`, 0.9398895428612922]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 390}], {
             RGBColor[
             0.30502633329137085`, 0.4378812473959014, 0.9406840432278518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 478}], {
             RGBColor[
             0.2876705710791334, 0.41963924089195836`, 0.9396956582454141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 390}], {
             RGBColor[
             0.2868022644003798, 0.4187777425716037, 0.9396443367204493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 411}], {
             RGBColor[
             0.2562205129796168, 0.38663438283335066`, 0.9379027512186837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 478}], {
             RGBColor[
             0.26944650218814237`, 0.40053573606766074`, 0.9386559517380118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 419}], {
             RGBColor[
             0.5409976687744238, 0.6382453050351424, 0.9570084647071322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 439}], {
             RGBColor[
             0.7151086431122187, 0.7765792866784462, 0.9729163506443089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 416}], {
             RGBColor[
             0.2718791903645599, 0.40309264558241453`, 0.938794489730819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 427}], {
             RGBColor[
             0.2808624118228371, 0.41253458090420103`, 0.9393060709033827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 429}], {
             RGBColor[
             0.2879113316712099, 0.41994344259217253`, 0.9397074964608051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 499}], {
             RGBColor[
             0.27147166687394786`, 0.40266431255529955`, 0.9387712818709056]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 479}], {
             RGBColor[
             0.37021659707670174`, 0.49508474158579574`, 0.9448108520894127]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 482}], {
             RGBColor[
             0.34371197944189347`, 0.47212777395134153`, 0.9431220012908359]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 496}], {
             RGBColor[
             0.30291603178424115`, 0.4338470274567268, 0.9406303631659094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 435}], {
             RGBColor[
             0.2709692417504848, 0.4021362318949472, 0.9387426695033958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 391}], {
             RGBColor[
             0.23729940724147955`, 0.36674710103517516`, 0.9368252222381643]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 421}], {
             RGBColor[
             0.17899180289058533`, 0.3054621119467458, 0.9335046904287516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 403}], {
             RGBColor[
             0.8520128910253049, 0.8851986373727346, 0.9856507029983317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 405}], {
             RGBColor[
             0.8845632449194131, 0.9069230619459494, 0.7839577394340637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 491}], {
             RGBColor[
             0.8846376192086578, 0.9070821410302499, 0.7920529218334498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 487}], {
             RGBColor[
             0.7628017392959624, 0.8144116714200249, 0.9680174393113103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 490}], {
             RGBColor[
             0.9683628300119925, 0.9748687448836537, 0.8911081388957877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 409}], {
             RGBColor[
             0.23002772223876133`, 0.35910409904586005`, 0.9364111105347535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 451}], {
             RGBColor[
             0.21497280031897864`, 0.34328042157098726`, 0.9355537550031829]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 456}], {
             RGBColor[
             0.22107915567658082`, 0.3496985882171184, 0.9359015029072553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 458}], {
             RGBColor[
             0.2244995192065336, 0.35329360715067204`, 0.9360962875503116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 425}], {
             RGBColor[
             0.3380481584260487, 0.4664830926023694, 0.94278816472538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 478}], {
             RGBColor[
             0.2833977050944594, 0.41519933487955374`, 0.9394504521045712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 459}], {
             RGBColor[
             0.34827375514967984`, 0.47582519706689724`, 0.9434219649183455]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 465}], {
             RGBColor[
             0.2943134873153461, 0.42667251409427237`, 0.9400720897535981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 492}], {
             RGBColor[
             0.2913103527973019, 0.4235160293060819, 0.9399010656855349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 468}], {
             RGBColor[
             0.4697942541627981, 0.5804391653761509, 0.9514030710822032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 398}], {
             RGBColor[
             0.24489676758341208`, 0.3747324084550136, 0.93725788067035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 445}], {
             RGBColor[
             0.2291408986849781, 0.35817199126297306`, 0.9363606072453035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 460}], {
             RGBColor[
             0.23849436642390026`, 0.3680030789006874, 0.9368932733958195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 440}], {
             RGBColor[
             0.2733307058970075, 0.4046182804384171, 0.9388771513930672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 447}], {
             RGBColor[
             0.2557437599820415, 0.3861332852050131, 0.9378756008407647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 453}], {
             RGBColor[
             0.2746472026730905, 0.406002002020797, 0.9389521239368825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 463}], {
             RGBColor[
             0.2660424669485921, 0.39695787920259357`, 0.9384620969669382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 422}], {
             RGBColor[
             0.6137790328303492, 0.6759479174311498, 0.7377723993512193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 443}], {
             RGBColor[
             0.9640290207521414, 0.8833364286136021, 0.40253589756085995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 446}], {
             RGBColor[
             0.6108486673250959, 0.6728679174892245, 0.7376055193707824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 419}], {
             RGBColor[
             0.43561929438142943`, 0.5501211672171827, 0.9494236831393772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 472}], {
             RGBColor[
             0.3434973849835166, 0.4719419030173265, 0.9431083275217065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 445}], {
             RGBColor[
             0.2453951867466454, 0.3752562785971719, 0.9372862649043511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 460}], {
             RGBColor[
             0.2547486544855675, 0.3850873662348864, 0.9378189310548671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 472}], {
             RGBColor[
             0.2947988861662292, 0.4253612331985043, 0.9401664252880289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 412}], {
             RGBColor[
             0.24194122045751632`, 0.37162594103318614`, 0.9370895666338703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 414}], {
             RGBColor[
             0.28528989827003975`, 0.41718814987906533`, 0.9395582097066717]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 415}], {
             RGBColor[
             0.2914672574254832, 0.4236809460186285, 0.9399100011719903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 464}], {
             RGBColor[
             0.26989429594474446`, 0.40100639569761354`, 0.9386814529299987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 450}], {
             RGBColor[
             0.7955804305647025, 0.4800334417304184, 0.5713225662708019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 454}], {
             RGBColor[
             0.8366674019364873, 0.7306087240183134, 0.6081129719353302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 471}], {
             RGBColor[
             0.8151324803555211, 0.6303190641854999, 0.5900456312313715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 475}], {
             RGBColor[
             0.806227884360017, 0.5618744373452094, 0.5815185800497742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 500}], {
             RGBColor[
             0.7964725199858478, 0.48689043193741693`, 0.5721768321079614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 431}], {
             RGBColor[
             0.5004255816893457, 0.6051773211877334, 0.9538503277794443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 436}], {
             RGBColor[
             0.5126155235296384, 0.6152034009243532, 0.954774118266239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 459}], {
             RGBColor[
             0.4714286755649022, 0.5800616585296188, 0.952002670562152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 462}], {
             RGBColor[
             0.5080947993050582, 0.6115332733425336, 0.9544182302953215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 487}], {
             RGBColor[
             0.565871305361324, 0.6584388437609466, 0.958966608494386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 405}], {
             RGBColor[
             0.9614623294969025, 0.9678776355477525, 0.7913886839898783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 449}], {
             RGBColor[
             0.8286073759188407, 0.8669140710830616, 0.9833178599894938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 491}], {
             RGBColor[
             0.9615367037861473, 0.968036714632053, 0.7994838663892643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 407}], {
             RGBColor[
             0.2139033248740353, 0.3421563350696921, 0.9354928499587406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 408}], {
             RGBColor[
             0.2179764205636531, 0.3464374168886629, 0.9357248067326592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 434}], {
             RGBColor[
             0.9926076308918226, 0.9901160572249841, 0.6925776468321798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 469}], {
             RGBColor[
             0.9272216806853377, 0.724366095358756, 0.3974739978928766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 474}], {
             RGBColor[
             0.9935549188322322, 0.9905077851325332, 0.6768786341569868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 491}], {
             RGBColor[
             0.9940870576802556, 0.9897611392052678, 0.5977909028249961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 413}], {
             RGBColor[
             0.9822272031257195, 0.951710324271208, 0.3854564695648335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 476}], {
             RGBColor[
             0.9195554041525527, 0.6768776802935997, 0.3060621599750899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 486}], {
             RGBColor[
             0.9627729895914936, 0.9654828212213326, 0.7058550168364002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 493}], {
             RGBColor[
             0.9920978208950986, 0.9843432363296774, 0.4801786397760631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 408}], {
             RGBColor[
             0.2184314377890148, 0.3469156688422765, 0.9357507192905059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 430}], {
             RGBColor[
             0.22704868393744712`, 0.35597294090924125`, 0.9362414587105858]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{408, 430}], {
             RGBColor[
             0.23112177962706493`, 0.36025402272821205`, 0.9364734154845045]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 456}], {
             RGBColor[
             0.23260709522442666`, 0.3618151835954873, 0.9365580020104467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 458}], {
             RGBColor[
             0.23602745875437942`, 0.36541020252904094`, 0.9367527866535031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 496}], {
             RGBColor[
             0.25922260246551676`, 0.38978976922649866`, 0.9380737157737123]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{411, 478}], {
             RGBColor[
             0.2528159536736963, 0.3830559751413007, 0.9377088666028057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 476}], {
             RGBColor[
             0.9111642263834832, 0.6485722673362936, 0.273464018883213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 486}], {
             RGBColor[
             0.9543818118224241, 0.9371774082640264, 0.6732568757445232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 493}], {
             RGBColor[
             0.9837066431260291, 0.9560378233723712, 0.44758049868418615`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 415}], {
             RGBColor[
             0.2808353270487499, 0.4125061130893616, 0.9393045284655668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 485}], {
             RGBColor[
             0.26132957932407624`, 0.39200433549489333`, 0.9381937049888145]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{415, 464}], {
             RGBColor[
             0.2654397247234546, 0.39632435890790974`, 0.9384277716888938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{415, 485}], {
             RGBColor[
             0.2675069384795197, 0.39849713163445644`, 0.9385454964541331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 427}], {
             RGBColor[
             0.2705169061527906, 0.4016607985020373, 0.9387169096602777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 429}], {
             RGBColor[
             0.2775658260011634, 0.4090696601900088, 0.9391183352177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 499}], {
             RGBColor[
             0.26112616120390136`, 0.3917905301531358, 0.9381821206278006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{417, 461}], {
             RGBColor[
             0.8227440842305245, 0.8622334494485463, 0.9748712810946092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 420}], {
             RGBColor[
             0.9735581601714495, 0.9798002996671817, 0.9296433170801228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 432}], {
             RGBColor[
             0.9385489798096075, 0.9527344602026001, 0.9557578713810538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 432}], {
             RGBColor[
             0.933633649289228, 0.949068614748616, 0.9640782438285385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 439}], {
             RGBColor[
             0.9147776569049322, 0.9340333582536569, 0.9622797424419812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 423}], {
             RGBColor[
             0.18344124862659156`, 0.31013876152644193`, 0.9337580797810521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 477}], {
             RGBColor[
             0.21186411660990806`, 0.34001299789082284`, 0.9353767200648369]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 443}], {
             RGBColor[
             0.5842619922483114, 0.5706803433206208, 0.6014015077150748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 446}], {
             RGBColor[
             0.2310816388212659, 0.36021183219624314`, 0.9364711295249972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 446}], {
             RGBColor[
             0.20798858239401255`, 0.3359395657068551, 0.9351560141245807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 477}], {
             RGBColor[
             0.21624875945532895`, 0.3446215355237733, 0.9356264189883857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 440}], {
             RGBColor[
             0.30113413549531765`, 0.4327459792905174, 0.940500626045089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 453}], {
             RGBColor[
             0.3024506322714007, 0.4341297008728973, 0.9405755985889044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 470}], {
             RGBColor[
             0.28803826967359597`, 0.4189813939860375, 0.9397548358601392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{425, 466}], {
             RGBColor[
             0.4394255113443823, 0.5536672437102792, 0.9495973233231294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 448}], {
             RGBColor[
             0.7190568535901429, 0.7797176017404024, 0.9733043071059779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 489}], {
             RGBColor[
             0.9301359936068372, 0.9447452859638352, 0.9006256116612403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 460}], {
             RGBColor[
             0.2639231904685617, 0.39473038525219195`, 0.938341407306589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 499}], {
             RGBColor[
             0.27010938266217854`, 0.4012324654749223, 0.9386937018003643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 495}], {
             RGBColor[
             0.8362679836981737, 0.2797771922017657, 0.1823635681891872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{429, 499}], {
             RGBColor[
             0.2771583025105514, 0.4086413271628938, 0.9390951273577867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 433}], {
             RGBColor[
             0.3870230907643596, 0.509641681699111, 0.9458817470057914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 436}], {
             RGBColor[
             0.46072987194196846`, 0.5729505557434673, 0.9507253360979548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 459}], {
             RGBColor[
             0.41954302397723237`, 0.5378088133487329, 0.9479538883938678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 462}], {
             RGBColor[
             0.4562091477173884, 0.5692804281616477, 0.9503694481270373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 487}], {
             RGBColor[
             0.5139856537736541, 0.6161859985800608, 0.9549178263261018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{432, 467}], {
             RGBColor[
             0.8027318187709938, 0.8464550865365966, 0.9808037893677689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 462}], {
             RGBColor[
             0.3946923083800721, 0.5159976338539112, 0.9464496495216687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 469}], {
             RGBColor[
             0.9258166281861495, 0.7248800924627727, 0.5003559242994462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 474}], {
             RGBColor[
             0.992149866333044, 0.99102178223655, 0.7797605605635565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 495}], {
             RGBColor[
             0.9167025248852594, 0.6580111596730529, 0.4917530067660364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 459}], {
             RGBColor[
             0.4317329658175249, 0.5478348930853527, 0.9488776788806625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 462}], {
             RGBColor[
             0.46839908955768095`, 0.5793065078982675, 0.951293238613832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 487}], {
             RGBColor[
             0.5261755956139467, 0.6262120783166807, 0.9558416168128965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 457}], {
             RGBColor[
             0.22152681415849518`, 0.35016910566479753`, 0.9359269963955489]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 460}], {
             RGBColor[
             0.23490540515407732`, 0.3642308530528161, 0.9366888873608955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 453}], {
             RGBColor[
             0.2829903357512072, 0.4147711638710876, 0.939427253023122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 470}], {
             RGBColor[
             0.2685779731534025, 0.3996228569842277, 0.9386064902943567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 467}], {
             RGBColor[
             0.5784857852356426, 0.6676055963951182, 0.960658898554645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 444}], {
             RGBColor[
             0.27761918641957545`, 0.4091257453730057, 0.939121374014589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 492}], {
             RGBColor[
             0.2802823193946945, 0.4119248669822389, 0.9392730354977699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{443, 446}], {
             RGBColor[
             0.5813316267430582, 0.5676003433786956, 0.6012346277346379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{444, 492}], {
             RGBColor[
             0.2739561801729139, 0.4052756935597544, 0.9389127712277736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{445, 460}], {
             RGBColor[
             0.23899278558713355`, 0.3685269490428458, 0.9369216576298206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 453}], {
             RGBColor[
             0.26540338983624123`, 0.39628616863768357`, 0.9384257024708196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 463}], {
             RGBColor[
             0.2567986541117429, 0.38724204581948013`, 0.9379356755008752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{449, 488}], {
             RGBColor[
             0.7488335383665432, 0.8037137186084069, 0.9756003869232444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 454}], {
             RGBColor[
             0.8587954548220276, 0.3876960227591984, 0.20138137545633958`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 469}], {
             RGBColor[
             0.8390695807149537, 0.298125435533924, 0.18492162257597716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 471}], {
             RGBColor[
             0.8372605332410615, 0.2874063629263848, 0.183314034752381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 475}], {
             RGBColor[
             0.8283559372455574, 0.2189617360860943, 0.17478698357078354`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 491}], {
             RGBColor[
             0.9059349577098716, 0.5635204793804358, 0.38523852750809673`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 500}], {
             RGBColor[
             0.8186005728713881, 0.14397773067830186`, 0.16544523562897076`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{451, 456}], {
             RGBColor[
             0.21755217330464396`, 0.3459915061206145, 0.9357006464788762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{453, 463}], {
             RGBColor[
             0.2757020968027919, 0.407110762635264, 0.939012198596993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 469}], {
             RGBColor[
             0.8801565520867384, 0.5487007178218191, 0.22171202824050545`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 471}], {
             RGBColor[
             0.8783475046128462, 0.5379816452142798, 0.2201044404169093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 475}], {
             RGBColor[
             0.8694429086173421, 0.4695370183739893, 0.21157738923531183`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 500}], {
             RGBColor[
             0.8596875442431727, 0.3945530129661969, 0.20223564129349905`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{456, 458}], {
             RGBColor[
             0.22707889219219896`, 0.35600469170029936`, 0.9362431790260048]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{461, 486}], {
             RGBColor[
             0.9396915520193736, 0.9545227464327241, 0.9862809714214389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{461, 493}], {
             RGBColor[
             0.9690163833229786, 0.9733831615410689, 0.7606045943611018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{462, 487}], {
             RGBColor[
             0.5216548713893666, 0.6225419507348611, 0.9554857288419789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 485}], {
             RGBColor[
             0.24593397699878092`, 0.3758225813134415, 0.9373169482121415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 497}], {
             RGBColor[
             0.23993020302659857`, 0.369512234207422, 0.9369750421662133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 468}], {
             RGBColor[
             0.49094259840512156`, 0.5976083439541202, 0.9530679462098963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 471}], {
             RGBColor[
             0.8586216305057723, 0.4484110579890054, 0.20364468753654688`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 474}], {
             RGBColor[
             0.9267639161265591, 0.7252718203703219, 0.4846569116242533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 475}], {
             RGBColor[
             0.8497170345102683, 0.3799664311487149, 0.19511763635494941`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 491}], {
             RGBColor[
             0.9272960549745825, 0.7245251744430564, 0.40556918029226263`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 495}], {
             RGBColor[
             0.8513165746787745, 0.3922611978068248, 0.19664935782673318`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 475}], {
             RGBColor[
             0.847907987036376, 0.36924735854117574`, 0.19351004853135326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 500}], {
             RGBColor[
             0.8381526226622067, 0.29426335313338325`, 0.18416830058954048`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{474, 495}], {
             RGBColor[
             0.917649812825669, 0.658402887580602, 0.4760539940908434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{476, 493}], {
             RGBColor[
             0.9210348441528622, 0.6812051793947629, 0.36818618909444256`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{479, 482}], {
             RGBColor[
             0.3849860560945393, 0.5078773046524521, 0.9457519489579096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{480, 481}], {
             RGBColor[
             0.33588196619861493`, 0.46534581002792214`, 0.9426230797707831]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{482, 496}], {
             RGBColor[
             0.31768549080207875`, 0.4466395905233832, 0.9415714600344062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{484, 500}], {
             RGBColor[
             0.9061921804601966, 0.5690195539734165, 0.316991474169404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{485, 497}], {
             RGBColor[
             0.24199741678266362`, 0.3716850069339687, 0.9370927669314526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{486, 493}], {
             RGBColor[
             0.9642524295918031, 0.9698103203224957, 0.7679790459557528]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.0315874366232787], {
             RGBColor[
             0.2661654894960651, 0.39708718370006774`, 0.9384691029190212]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.0315874366232787], {
             RGBColor[
             0.2124476857409665, 0.34062636604798524`, 0.9354099534635375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.0315874366232787], {
             RGBColor[
             0.46166603367100856`, 0.5738403098087559, 0.9507631877904368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.0315874366232787], {
             RGBColor[
             0.32430364693803726`, 0.45531725182765653`, 0.9418853195058047]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.0315874366232787], {
             RGBColor[
             0.23860734128045696`, 0.3681218226379481, 0.9368997071467691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.0315874366232787], {
             RGBColor[
             0.8276898195746623, 0.8654414113599355, 0.9834269879500976]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.0315874366232787], {
             RGBColor[
             0.8386821070512293, 0.8742063630160551, 0.9844754421425435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.0315874366232787], {
             RGBColor[
             0.6202936289377985, 0.7026213377380665, 0.963250933161866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.0315874366232787], {
             RGBColor[
             0.5751436787516512, 0.6659665741948753, 0.9596965636934954]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.0315874366232787], {
             RGBColor[
             0.2189624152550279, 0.3474737598249721, 0.9357809576716846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.0315874366232787], {
             RGBColor[
             0.23891813183632316`, 0.3684484832174229, 0.9369174062091523]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.0315874366232787], {
             RGBColor[
             0.27240341106773047`, 0.40364363477895904`, 0.9388243433243495]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.0315874366232787], {
             RGBColor[
             0.29661626096016863`, 0.4290928751992627, 0.9402032293060224]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.0315874366232787], {
             RGBColor[
             0.30674268007373295`, 0.4397363837396738, 0.9407799138938453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.0315874366232787], {
             RGBColor[
             0.23423879357827926`, 0.36353020202103736`, 0.9366509248178173]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.0315874366232787], {
             RGBColor[
             0.4038820814050813, 0.5242440920345965, 0.9469559869815982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.0315874366232787], {
             RGBColor[
             0.8799712561457314, 0.9071292097399156, 0.9884136380424356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.0315874366232787], {
             RGBColor[
             0.8843839202879132, 0.5678962094964264, 0.22523944788984251`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.0315874366232787], {
             RGBColor[
             0.5597245266210166, 0.6534486118703385, 0.9584827115555565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.0315874366232787], {
             RGBColor[
             0.8845340276069948, 0.5685778117739207, 0.22536470111635126`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.0315874366232787], {
             RGBColor[
             0.9808877657874093, 0.9471920876142448, 0.3802530084370154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.0315874366232787], {
             RGBColor[
             0.4514165271362265, 0.5654160397762044, 0.9499848398305268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.0315874366232787], {
             RGBColor[
             0.2225015077722568, 0.35119357045200544`, 0.9359825037549226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.0315874366232787], {
             RGBColor[
             0.8369720141620951, 0.8728427813654944, 0.9843123319561599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.0315874366232787], {
             RGBColor[
             0.3133752819583538, 0.4458516513578495, 0.941188973752873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.0315874366232787], {
             RGBColor[
             0.3866295369467384, 0.5093008051628776, 0.9458566701045386]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.0315874366232787], {
             RGBColor[
             0.5121189165844965, 0.6148002330343991, 0.9547350235483862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.0315874366232787], {
             RGBColor[
             0.9648560740830788, 0.9733102981108331, 0.9443736789601879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.0315874366232787], {
             RGBColor[
             0.40962031041891445`, 0.5292142575946026, 0.9473216218602429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.0315874366232787], {
             RGBColor[
             0.2679312243382506, 0.39894308297325987`, 0.938569658906113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.0315874366232787], {
             RGBColor[
             0.4530382628066378, 0.5668207057031098, 0.9500881753934008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.0315874366232787], {
             RGBColor[
             0.5357107322431658, 0.6339531317852908, 0.9565922576967049]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.0315874366232787], {
             RGBColor[
             0.8784142522519405, 0.5407893411964669, 0.22025821055067316`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.0315874366232787], {
             RGBColor[
             0.5437530683305409, 0.6404822625241338, 0.9572253798535508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.0315874366232787], {
             RGBColor[
             0.23837242809378653`, 0.36787491398440125`, 0.9368863291883112]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.0315874366232787], {
             RGBColor[
             0.254389289460926, 0.3847096508089296, 0.9377984657483468]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.0315874366232787], {
             RGBColor[
             0.305640198745031, 0.4385776059618545, 0.9407171292131508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.0315874366232787], {
             RGBColor[
             0.25996867538836677`, 0.3905739391721695, 0.9381162035229527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.0315874366232787], {
             RGBColor[
             0.6236615875481659, 0.7053555982627691, 0.963516071200913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.0315874366232787], {
             RGBColor[
             0.3862001571816754, 0.5089288979916344, 0.9458293104055944]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.0315874366232787], {
             RGBColor[
             0.23252667542550592`, 0.36173065728791187`, 0.9365534222218687]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.0315874366232787], {
             RGBColor[
             0.23247426890382172`, 0.3616755747108564, 0.9365504377479873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.0315874366232787], {
             RGBColor[
             0.2931478124699098, 0.42544731592366486`, 0.940005706295612]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.0315874366232787], {
             RGBColor[
             0.49667724948997916`, 0.6022639920478948, 0.9535193989500155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.0315874366232787], {
             RGBColor[
             0.28278247170568477`, 0.41455268557990177`, 0.9394154154732368]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.0315874366232787], {
             RGBColor[
             0.9176548470302313, 0.7112359389100995, 0.2526013609126037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.0315874366232787], {
             RGBColor[
             0.23193365260590854`, 0.36110735270469657`, 0.9365196504495912]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.0315874366232787], {
             RGBColor[
             0.20751087662989864`, 0.3354374666604766, 0.9351288094880167]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.0315874366232787], {
             RGBColor[
             0.49021471545548245`, 0.5970174157848499, 0.9530106445977776]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.0315874366232787], {
             RGBColor[
             0.44093802683048844`, 0.5563400894761129, 0.9493171590568191]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.0315874366232787], {
             RGBColor[
             0.17892700081062782`, 0.30539400085202123`, 0.9335010000461641]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.0315874366232787], {
             RGBColor[
             0.8357950446989824, 0.2761419758107905, 0.18191068126945342`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.0315874366232787], {
             RGBColor[
             0.9765123065091236, 0.9324326360618924, 0.36325517537702773`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.0315874366232787], {
             RGBColor[
             0.22872079714307936`, 0.35773043790646125`, 0.9363366830839769]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.0315874366232787], {
             RGBColor[
             0.21147766438726034`, 0.339606812102334, 0.9353547121824619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.0315874366232787], {
             RGBColor[
             0.8366736085240676, 0.28289500235951803`, 0.1827519949805509]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.0315874366232787], {
             RGBColor[
             0.6012429877716181, 0.6871551690177569, 0.9617511969044663]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.0315874366232787], {
             RGBColor[
             0.31511174381280593`, 0.44735568733906544`, 0.9412996195667458]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.0315874366232787], {
             RGBColor[
             0.2421911048281961, 0.37188858535035474`, 0.9371037971791099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.0315874366232787], {
             RGBColor[
             0.29270959820985176`, 0.42498672495195505`, 0.9399807506417815]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.0315874366232787], {
             RGBColor[
             0.3238266917401457, 0.45490413720770817`, 0.94185492834235]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.0315874366232787], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.0315874366232787], {
             RGBColor[
             0.41933559472005666`, 0.5376291485518648, 0.9479406711850231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.0315874366232787], {
             RGBColor[
             0.2878344487965492, 0.41986263381624833`, 0.9397031180948312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.0315874366232787], {
             RGBColor[
             0.9854648277298144, 0.9626315922912277, 0.39803402977763763`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.0315874366232787], {
             RGBColor[
             0.2632810725593861, 0.3940554786170215, 0.9383048396415897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.0315874366232787], {
             RGBColor[
             0.25662307112871396`, 0.38705749697171266`, 0.9379256763097434]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.0315874366232787], {
             RGBColor[
             0.8199864588949732, 0.15463025795470559`, 0.16677236165029033`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.0315874366232787], {
             RGBColor[
             0.9094625081980608, 0.9306447336077317, 0.9912265399903383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.0315874366232787], {
             RGBColor[
             0.2582501634540876, 0.38876767416929214`, 0.9380183368106061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.0315874366232787], {
             RGBColor[
             0.755781538403036, 0.8091415490436711, 0.97629289863413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.0315874366232787], {
             RGBColor[
             0.2539844574642687, 0.3842841467126117, 0.9377754111650324]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.0315874366232787], {
             RGBColor[
             0.24791046842011605`, 0.37789999911405875`, 0.9374295064746294]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.0315874366232787], {
             RGBColor[
             0.2817340129849886, 0.4134506889883278, 0.9393557073001488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.0315874366232787], {
             RGBColor[
             0.3449485107481652, 0.47319879521896346`, 0.9432007919722498]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.0315874366232787], {
             RGBColor[
             0.4113253016274047, 0.530691035284047, 0.9474302623923834]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.0315874366232787], {
             RGBColor[
             0.606817875551374, 0.6916811140631951, 0.9621900724919755]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.0315874366232787], {
             RGBColor[
             0.21942909899518986`, 0.3479642740253404, 0.9358075346202901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.0315874366232787], {
             RGBColor[
             0.9938287149952354, 0.9892085703244617, 0.5696718958667929]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.0315874366232787], {
             RGBColor[
             0.7895429134572223, 0.8355161918319554, 0.9796579169815435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.0315874366232787], {
             RGBColor[
             0.8236181467643259, 0.8621947699835874, 0.9830386281626226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.0315874366232787], {
             RGBColor[
             0.25827862318556116`, 0.3887975871515221, 0.9380199575502111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.0315874366232787], {
             RGBColor[
             0.9207457022290968, 0.9396416462539369, 0.9923027411096448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.0315874366232787], {
             RGBColor[
             0.2333142933423989, 0.36255849365642656`, 0.9365982758970595]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.0315874366232787], {
             RGBColor[
             0.21421555473578224`, 0.34248450845090483`, 0.9355106309874645]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.0315874366232787], {
             RGBColor[
             0.9151930916309041, 0.7014758990831244, 0.2506205747334791]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.0315874366232787], {
             RGBColor[
             0.1792532619022457, 0.3057369219454596, 0.9335195801326717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.0315874366232787], {
             RGBColor[
             0.8666101266120032, 0.4871895635890985, 0.21040855877111306`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.0315874366232787], {
             RGBColor[
             0.28550171685781406`, 0.4174107846448903, 0.9395702724618878]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.0315874366232787], {
             RGBColor[
             0.8647697772859632, 0.4788329671240561, 0.2088729261823753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.0315874366232787], {
             RGBColor[
             0.3276288460270304, 0.4581973721491767, 0.9420971982513973]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.0315874366232787], {
             RGBColor[
             0.6091375885965603, 0.6935643616151592, 0.9623726888002815]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.0315874366232787], {
             RGBColor[
             0.26928527939714464`, 0.4003662806922068, 0.9386467703385721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.0315874366232787], {
             RGBColor[
             0.9554190789968999, 0.9662722026272221, 0.9603480500785777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.0315874366232787], {
             RGBColor[
             0.22708291988077767`, 0.3560089250563658, 0.936243408396911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.0315874366232787], {
             RGBColor[
             0.2961617343973124, 0.4286151389630523, 0.9401773446906796]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.0315874366232787], {
             RGBColor[
             0.2317345075524728, 0.36089803862701, 0.9365083094334068]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.0315874366232787], {
             RGBColor[
             0.9952347378240085, 0.9922159109844932, 0.7227088038116687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.0315874366232787], {
             RGBColor[
             0.9936215336094609, 0.9887654302895413, 0.5471214806005384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.0315874366232787], {
             RGBColor[
             0.9312148525901699, 0.7649968423512695, 0.2635120596803694]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.0315874366232787], {
             RGBColor[
             0.5208327276256995, 0.6218744973903617, 0.9554210066732913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.0315874366232787], {
             RGBColor[
             0.2765375568294345, 0.40798888409449063`, 0.939059776809558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.0315874366232787], {
             RGBColor[
             0.4803557055985901, 0.589013427439692, 0.9522345072271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.0315874366232787], {
             RGBColor[
             0.24657366739272524`, 0.3764949364761905, 0.9373533776337394]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.0315874366232787], {
             RGBColor[
             0.2459052705491277, 0.3757924090147619, 0.9373153134223011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.0315874366232787], {
             RGBColor[
             0.5178553382148801, 0.619457318536794, 0.9551866156723348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.0315874366232787], {
             RGBColor[
             0.18467169248908813`, 0.3114320360405726, 0.9338281517387427]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.0315874366232787], {
             RGBColor[
             0.28511069510105125`, 0.41699979598632125`, 0.939548004351305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.0315874366232787], {
             RGBColor[
             0.25396000439311356`, 0.38425844498441336`, 0.9377740185988052]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.0315874366232787], {
             RGBColor[
             0.27171530098953856`, 0.4029203874580805, 0.9387851564733641]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.0315874366232787], {
             RGBColor[
             0.27309124258507717`, 0.4043665893147275, 0.9388635143117069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.0315874366232787], {
             RGBColor[
             0.24826352560257345`, 0.3782710845979398, 0.937449612558869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.0315874366232787], {
             RGBColor[
             0.17919226069553715`, 0.305672805809509, 0.9335161062041928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.0315874366232787], {
             RGBColor[
             0.5006784839436625, 0.605512374430953, 0.9538343907832142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.0315874366232787], {
             RGBColor[
             0.9211683800910966, 0.9399786781078106, 0.9923430565014513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.0315874366232787], {
             RGBColor[
             0.24872594858728536`, 0.3787571204741826, 0.9374759468637549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.0315874366232787], {
             RGBColor[
             0.38107527345035186`, 0.504489981287708, 0.9455027573459912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.0315874366232787], {
             RGBColor[
             0.32510810483221725`, 0.45601403282236586`, 0.9419365788514676]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.0315874366232787], {
             RGBColor[
             0.9906473743776302, 0.9904004632007044, 0.8046607405893015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.0315874366232787], {
             RGBColor[
             0.20742150462258202`, 0.3353435310142743, 0.9351237198844141]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.0315874366232787], {
             RGBColor[
             0.8274659414661699, 0.21212083852708477`, 0.1739347226073356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.0315874366232787], {
             RGBColor[
             0.867504304657107, 0.49124981725132677`, 0.21115468285025726`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.0315874366232787], {
             RGBColor[
             0.2069635167020156, 0.33486215667164765`, 0.9350976381498702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.0315874366232787], {
             RGBColor[
             0.9626525497894284, 0.8856804222207267, 0.30941263771645156`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.0315874366232787], {
             RGBColor[
             0.20867358600249122`, 0.3366595479311035, 0.9351950240667115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.0315874366232787], {
             RGBColor[
             0.2511378152607278, 0.38129214526915, 0.9376132991027705]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.0315874366232787], {
             RGBColor[
             0.22597981130456574`, 0.35484948800164373`, 0.9361805879953986]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.0315874366232787], {
             RGBColor[
             0.49474321248409076`, 0.6006938536791404, 0.9533671444723009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.0315874366232787], {
             RGBColor[
             0.35559977387920144`, 0.4824243839950162, 0.9438794810404173]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.0315874366232787], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.0315874366232787], {
             RGBColor[
             0.263609049878749, 0.394400203574635, 0.9383235174647285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.0315874366232787], {
             RGBColor[
             0.9901329118562932, 0.9901877197270478, 0.8131867159541827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.0315874366232787], {
             RGBColor[
             0.3451736656290086, 0.4733938130601367, 0.9432151386421606]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.0315874366232787], {
             RGBColor[
             0.2332063867745317, 0.36244507701192663`, 0.9365921307776528]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.0315874366232787], {
             RGBColor[
             0.25062676841059334`, 0.3807550026274169, 0.9375841957406814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.0315874366232787], {
             RGBColor[
             0.968960662006962, 0.9763714930638193, 0.9374256822530368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.0315874366232787], {
             RGBColor[
             0.22008054170119, 0.3486489816131997, 0.9358446333186737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.0315874366232787], {
             RGBColor[
             0.2199663924455993, 0.34852900350809307`, 0.9358381326874365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.0315874366232787], {
             RGBColor[
             0.5640351798749514, 0.6569481943745988, 0.9588220619701494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.0315874366232787], {
             RGBColor[
             0.4996340643500339, 0.6046644675542787, 0.9537521702469687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.0315874366232787], {
             RGBColor[
             0.30958288032569087`, 0.4425668636752852, 0.9409473252743288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.0315874366232787], {
             RGBColor[
             0.6995243049605603, 0.765192970707599, 0.9706857033583209]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.0315874366232787], {
             RGBColor[
             0.17892700134778292`, 0.3053940014166053, 0.9335010000767543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.0315874366232787], {
             RGBColor[
             0.24622776306205768`, 0.3761313690930576, 0.9373336788938276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.0315874366232787], {
             RGBColor[
             0.2206581667895666, 0.3492561022046294, 0.935877528212937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.0315874366232787], {
             RGBColor[
             0.257933230334439, 0.3884345573658211, 0.9380002879383026]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.0315874366232787], {
             RGBColor[
             0.25149316947897704`, 0.3816656450832887, 0.9376335359998004]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.0315874366232787], {
             RGBColor[
             0.23965584235908116`, 0.3692238637503902, 0.9369594177320785]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.0315874366232787], {
             RGBColor[
             0.353874772698637, 0.4809302746734916, 0.9437695654905504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.0315874366232787], {
             RGBColor[
             0.8214446559981496, 0.16583859987576455`, 0.16816873284309014`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.0315874366232787], {
             RGBColor[
             0.30679432383558886`, 0.439790664607788, 0.9407828549296829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.0315874366232787], {
             RGBColor[
             0.20400293554931437`, 0.33175039816847185`, 0.9349290374330113]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.0315874366232787], {
             RGBColor[
             0.24493296406314102`, 0.3747704532501981, 0.9372599420063227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.0315874366232787], {
             RGBColor[
             0.30954120355039927`, 0.44253076534726327`, 0.9409446696670606]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.0315874366232787], {
             RGBColor[
             0.5658891207695752, 0.6584533071119401, 0.9589680109885835]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.0315874366232787], {
             RGBColor[
             0.46730916543215706`, 0.578421658392645, 0.9512074357941471]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.0315874366232787], {
             RGBColor[
             0.3025436094347634, 0.43532289426166115`, 0.9405407830329243]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.0315874366232787], {
             RGBColor[
             0.3575213303529286, 0.48408873963232213`, 0.9440019209197574]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.0315874366232787], {
             RGBColor[
             0.8207501650068003, 0.16050043778835987`, 0.16750368748545852`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.0315874366232787], {
             RGBColor[
             0.42248174875901884`, 0.5403541890501141, 0.948141141338351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.0315874366232787], {
             RGBColor[
             0.9903319581123935, 0.9790495659282263, 0.41694191223350735`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.0315874366232787], {
             RGBColor[
             0.46203141681910903`, 0.5741369443087071, 0.9507919520902978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.0315874366232787], {
             RGBColor[
             0.26699231078344465`, 0.3979562252966011, 0.9385161891681649]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.0315874366232787], {
             RGBColor[
             0.8175247092939038, 0.13570817177533162`, 0.16441498745215766`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.0315874366232787], {
             RGBColor[
             0.4240332554553848, 0.5416980261695123, 0.9482400019731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.0315874366232787], {
             RGBColor[
             0.8381204118994321, 0.2940157670958513, 0.18413745552673064`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.0315874366232787], {
             RGBColor[
             0.9866702547547157, 0.9887558220293171, 0.870571905196646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.0315874366232787], {
             RGBColor[
             0.9107922199972238, 0.6840279095591187, 0.24707953011528597`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.0315874366232787], {
             RGBColor[
             0.4927421843014464, 0.5990693288551774, 0.9532096162037554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.0315874366232787], {
             RGBColor[
             0.29668056881803306`, 0.42916046683523196`, 0.9402068915433929]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.0315874366232787], {
             RGBColor[
             0.26174222518751433`, 0.39243805246062563`, 0.9382172045602823]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.0315874366232787], {
             RGBColor[
             0.3516524550010693, 0.4790054147807936, 0.9436279613719797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.0315874366232787], {
             RGBColor[
             0.984562956112485, 0.9878843998856498, 0.9054952972124768]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.0315874366232787], {
             RGBColor[
             0.2666571079259713, 0.3976039058403079, 0.93849709986132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.0315874366232787], {
             RGBColor[
             0.9557302644442173, 0.966504284224312, 0.9598212942864327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.0315874366232787], {
             RGBColor[
             0.6069446059586334, 0.6917839995169481, 0.9622000491738637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.0315874366232787], {
             RGBColor[
             0.20869655844004803`, 0.3366836934195124, 0.9351963323130457]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.0315874366232787], {
             RGBColor[
             0.9916846362160958, 0.9908293976273234, 0.7874706275783359]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.0315874366232787], {
             RGBColor[
             0.178929137062006, 0.30539624618766587`, 0.9335011217025198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.0315874366232787], {
             RGBColor[
             0.27013094278236094`, 0.4012551265282246, 0.9386949296173133]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.0315874366232787], {
             RGBColor[
             0.4206971967779904, 0.5388084998183378, 0.9480274312641372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.0315874366232787], {
             RGBColor[
             0.3785866605047563, 0.5023344698355566, 0.9453441851296919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.0315874366232787], {
             RGBColor[
             0.2049673414252272, 0.33276404989092045`, 0.9349839589209338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.0315874366232787], {
             RGBColor[
             0.2570318728012019, 0.3874871734490205, 0.9379489569602237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.0315874366232787], {
             RGBColor[
             0.2839447494602888, 0.41577431319265656`, 0.9394816054719256]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.0315874366232787], {
             RGBColor[
             0.23571041014604155`, 0.365076964339635, 0.9367347312042897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.0315874366232787], {
             RGBColor[
             0.26462809617956273`, 0.3954712858480575, 0.938381550644016]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.0315874366232787], {
             RGBColor[
             0.33727714516499796`, 0.4665542439248693, 0.9427119793408126]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.0315874366232787], {
             RGBColor[
             0.2597753641562747, 0.39037075681060074`, 0.9381051947342635]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.0315874366232787], {
             RGBColor[
             0.24810961844878143`, 0.3781093184210272, 0.9374408477741458]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.0315874366232787], {
             RGBColor[
             0.21840138119578575`, 0.34688407745709465`, 0.9357490076119863]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.0315874366232787], {
             RGBColor[
             0.2546146394674752, 0.38494650795382845`, 0.9378112990978443]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.0315874366232787], {
             RGBColor[
             0.2878117179623051, 0.41983874226823964`, 0.9397018236074483]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.0315874366232787], {
             RGBColor[
             0.9865160895376739, 0.9886920707502049, 0.8731268218098209]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.0315874366232787], {
             RGBColor[
             0.2701519252165497, 0.40127718039692006`, 0.9386961245358997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.0315874366232787], {
             RGBColor[
             0.29569933477919436`, 0.42812912764658106`, 0.9401510117164867]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.0315874366232787], {
             RGBColor[
             0.6976256228082208, 0.7637097057796726, 0.9704964604655693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.0315874366232787], {
             RGBColor[
             0.2818794421164257, 0.41360354422620765`, 0.9393639892740411]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.0315874366232787], {
             RGBColor[
             0.3428438781472085, 0.4713758682419251, 0.9430666866439704]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.0315874366232787], {
             RGBColor[
             0.9008280073528754, 0.6425649682443086, 0.23896079721830538`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.0315874366232787], {
             RGBColor[
             0.3044587746178886, 0.4373358542976118, 0.9406498488568703]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.0315874366232787], {
             RGBColor[
             0.23905706042934927`, 0.3685945059772749, 0.9369253179869986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.0315874366232787], {
             RGBColor[
             0.5345666356633387, 0.6330243026408235, 0.956502190222977]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.0315874366232787], {
             RGBColor[
             0.5018930513522051, 0.606498414968846, 0.9539300059787216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.0315874366232787], {
             RGBColor[
             0.9938265629209484, 0.98920396725517, 0.5694376558617151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.0315874366232787], {
             RGBColor[
             0.3427341577200499, 0.4712808339226293, 0.9430596953553738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.0315874366232787], {
             RGBColor[
             0.217062994597398, 0.3454773482835776, 0.9356727884751737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.0315874366232787], {
             RGBColor[
             0.32211852500862637`, 0.45342460903982235`, 0.9417460854686901]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.0315874366232787], {
             RGBColor[
             0.5659235722129052, 0.6584812763456551, 0.9589707231324023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.0315874366232787], {
             RGBColor[
             0.8360637140310553, 0.2782070860287545, 0.182167959325265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.0315874366232787], {
             RGBColor[
             0.2310404057237692, 0.3601684935964447, 0.9364687813610937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.0315874366232787], {
             RGBColor[
             0.21851625165510197`, 0.3470048135930438, 0.9357555493147087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.0315874366232787], {
             RGBColor[
             0.90420589766789, 0.657903179238463, 0.24177939169682186`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.0315874366232787], {
             RGBColor[
             0.19980711485308938`, 0.32734032458634205`, 0.9346900916515217]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.0315874366232787], {
             RGBColor[
             0.28412310253725925`, 0.4159617735847908, 0.9394917624158093]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.0315874366232787], {
             RGBColor[
             0.26588598144981995`, 0.39679340302163035`, 0.9384531853492826]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.0315874366232787], {
             RGBColor[
             0.31971976000988434`, 0.4513469193633465, 0.9415932382841149]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.0315874366232787], {
             RGBColor[
             0.23197293745711564`, 0.3611486435741187, 0.9365218876637508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.0315874366232787], {
             RGBColor[
             0.5262688994117111, 0.6262878265429939, 0.9558489620296395]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.0315874366232787], {
             RGBColor[
             0.3389132056188999, 0.46797131725924984`, 0.9428162276662237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.0315874366232787], {
             RGBColor[
             0.5366100807415061, 0.6346832634114314, 0.9566630577049163]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.0315874366232787], {
             RGBColor[
             0.4427137030371586, 0.5578780909582495, 0.9494303035745394]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.0315874366232787], {
             RGBColor[
             0.38986378476733635`, 0.5121021480670574, 0.9460627535157341]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.0315874366232787], {
             RGBColor[
             0.29896629209325354`, 0.43156290692071464`, 0.9403370601024921]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.0315874366232787], {
             RGBColor[
             0.27424929290791517`, 0.4055837736286615, 0.9389294635644105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.0315874366232787], {
             RGBColor[
             0.1794249922972142, 0.30591742147890744`, 0.9335293599246128]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.0315874366232787], {
             RGBColor[
             0.8456311671254343, 0.35174672299683013`, 0.19132976321333509`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.0315874366232787], {
             RGBColor[
             0.9930813033990235, 0.9876099324950685, 0.48832075610881853`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.0315874366232787], {
             RGBColor[
             0.2909757990296596, 0.42316439208435586`, 0.9398820133433956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.0315874366232787], {
             RGBColor[
             0.2238780227461086, 0.35264037496561385`, 0.936060894246312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.0315874366232787], {
             RGBColor[
             0.2584463601503126, 0.3889738893366137, 0.9380295099222091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.0315874366232787], {
             RGBColor[
             0.3561976264336458, 0.4829422138287328, 0.9439175756765262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.0315874366232787], {
             RGBColor[
             0.8431597968980244, 0.3327506884676198, 0.18896317629255405`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.0315874366232787], {
             RGBColor[
             0.38857864336543946`, 0.5109890231778194, 0.9459808654420111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.0315874366232787], {
             RGBColor[
             0.3570417238501652, 0.48367332858535217`, 0.9439713608175008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.0315874366232787], {
             RGBColor[
             0.28732315690654525`, 0.419325233622076, 0.939674000778084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.0315874366232787], {
             RGBColor[
             0.906092392768253, 0.9279574950433493, 0.9909050953721057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.0315874366232787], {
             RGBColor[
             0.32015392046586916`, 0.45172296732878153`, 0.9416209026044572]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.0315874366232787], {
             RGBColor[
             0.3509305166159243, 0.47838010803725933`, 0.9435819600964633]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.0315874366232787], {
             RGBColor[
             0.2566255537350775, 0.38706010634840704`, 0.9379258176905032]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.0315874366232787], {
             RGBColor[
             0.7054821402904016, 0.7698472769484965, 0.9712795247048629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.0315874366232787], {
             RGBColor[
             0.22500762673968802`, 0.3538276603838957, 0.936125223522647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.0315874366232787], {
             RGBColor[
             0.8393061093521738, 0.30312955729356095`, 0.18527288074652987`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.0315874366232787], {
             RGBColor[
             0.3424410288691568, 0.4710269404450701, 0.9430410174441985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.0315874366232787], {
             RGBColor[
             0.22156287013367681`, 0.3502070027807943, 0.9359290497299955]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.0315874366232787], {
             RGBColor[
             0.29422140859812795`, 0.42657573352434824`, 0.9400668460068708]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.0315874366232787], {
             RGBColor[
             0.4950113815248125, 0.6009115653872759, 0.9533882557215221]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.0315874366232787], {
             RGBColor[
             0.24253965650195108`, 0.3722549352589237, 0.9371236466812941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.0315874366232787], {
             RGBColor[
             0.2895478687563091, 0.421663546831056, 0.9398006948267619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.0315874366232787], {
             RGBColor[
             0.20444533477183996`, 0.332215387801077, 0.934954231414263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.0315874366232787], {
             RGBColor[
             0.25854520282865096`, 0.38907777925853504`, 0.9380351388665158]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.0315874366232787], {
             RGBColor[
             0.7357960105795031, 0.7935287028122899, 0.9743009279960564]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.0315874366232787], {
             RGBColor[
             0.9850318468002165, 0.9880782982349678, 0.8977245650665646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.0315874366232787], {
             RGBColor[
             0.23649824945009773`, 0.365905033400095, 0.9367795974871519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.0315874366232787], {
             RGBColor[
             0.3975855258515599, 0.5187903320882202, 0.9465547760295533]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.0315874366232787], {
             RGBColor[
             0.2893861381019995, 0.4214935576590608, 0.939791484505258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.0315874366232787], {
             RGBColor[
             0.8588534332133313, 0.4519682304874997, 0.20393618366530758`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.0315874366232787], {
             RGBColor[
             0.3734224424883788, 0.497861483750915, 0.945015125724227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.0315874366232787], {
             RGBColor[
             0.8618406991999262, 0.46553270763892984`, 0.20642883162911219`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.0315874366232787], {
             RGBColor[
             0.28557642935408295`, 0.4174893122155148, 0.9395745272280231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.0315874366232787], {
             RGBColor[
             0.8799868165294279, 0.5479299882988189, 0.2215703967308864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.0315874366232787], {
             RGBColor[
             0.47608581392629684`, 0.5855469370236965, 0.9518983657135286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.0315874366232787], {
             RGBColor[
             0.2734006518561467, 0.40469179807630246`, 0.9388811347119643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.0315874366232787], {
             RGBColor[
             0.23478619087952063`, 0.36410555129163547`, 0.9366820982843213]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.0315874366232787], {
             RGBColor[
             0.32101450543653715`, 0.45246836277611585`, 0.9416757383178027]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.0315874366232787], {
             RGBColor[
             0.28952074326414307`, 0.421635036218934, 0.9397991500701115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.0315874366232787], {
             RGBColor[
             0.9890626064851881, 0.9747677448317271, 0.41201072085875556`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.0315874366232787], {
             RGBColor[
             0.40965477924277666`, 0.5292441127573786, 0.9473238181832199]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.0315874366232787], {
             RGBColor[
             0.44893934079834463`, 0.5632704254773366, 0.9498269957075668]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.0315874366232787], {
             RGBColor[
             0.9900230881246451, 0.9901423047916702, 0.8150067794022959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.0315874366232787], {
             RGBColor[
             0.2558053195227897, 0.38619798818543977`, 0.9378791065655412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.0315874366232787], {
             RGBColor[
             0.8205829319400263, 0.15921501115513814`, 0.16734354491185305`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.0315874366232787], {
             RGBColor[
             0.2935414156904733, 0.42586101786436276`, 0.9400281214167392]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.0315874366232787], {
             RGBColor[
             0.4627342609626232, 0.5747075448471798, 0.9508472825558781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.0315874366232787], {
             RGBColor[
             0.4137039619056965, 0.5327513112621616, 0.9475818285219495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.0315874366232787], {
             RGBColor[
             0.6195401563438858, 0.7020096347427746, 0.9631916170392121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.0315874366232787], {
             RGBColor[
             0.7713015318020453, 0.8212658858432957, 0.977839786533559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.0315874366232787], {
             RGBColor[
             0.9483637407407871, 0.9610103429078694, 0.9722908974192511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.0315874366232787], {
             RGBColor[
             0.2785602236563872, 0.4101148351741018, 0.9391749646930856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.0315874366232787], {
             RGBColor[
             0.25689237745970156`, 0.38734055500058817`, 0.9379410129068901]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.0315874366232787], {
             RGBColor[
             0.24490866169442368`, 0.374744909919817, 0.9372585580223763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.0315874366232787], {
             RGBColor[
             0.6076583896248129, 0.6923634812527404, 0.9622562408387412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.0315874366232787], {
             RGBColor[
             0.18121415923057888`, 0.3077979493656092, 0.9336312503346327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.0315874366232787], {
             RGBColor[
             0.24509263407936946`, 0.37493827656091794`, 0.9372690349775362]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.0315874366232787], {
             RGBColor[
             0.3144183414809424, 0.4467550970906198, 0.941255436583311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.0315874366232787], {
             RGBColor[
             0.22310026486080187`, 0.3518229021154584, 0.9360166020853335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.0315874366232787], {
             RGBColor[
             0.20981171601903448`, 0.33785579474010136`, 0.9352598388874411]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.0315874366232787], {
             RGBColor[
             0.2560659100008252, 0.3864718853002457, 0.9378939468077562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.0315874366232787], {
             RGBColor[
             0.439371052281192, 0.5549828548799431, 0.9492173128241592]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.0315874366232787], {
             RGBColor[
             0.2864852402250885, 0.41844453006287885`, 0.9396262826626617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.0315874366232787], {
             RGBColor[
             0.6549271406176395, 0.7303533269719065, 0.9662406748008145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.0315874366232787], {
             RGBColor[
             0.1789706321783367, 0.30543986018587177`, 0.9335034847880083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.0315874366232787], {
             RGBColor[
             0.9542723127115095, 0.9654169462092355, 0.962289226275195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.0315874366232787], {
             RGBColor[
             0.23831274258564697`, 0.36781218073106675`, 0.9368829301869194]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.0315874366232787], {
             RGBColor[
             0.22958788287780074`, 0.3586417999900643, 0.9363860623338308]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.0315874366232787], {
             RGBColor[
             0.3134198204339392, 0.44589022834683273`, 0.9411918117051534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.0315874366232787], {
             RGBColor[
             0.5193642093092683, 0.6206822880650865, 0.955305399532062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.0315874366232787], {
             RGBColor[
             0.9016398137954514, 0.9244071294324739, 0.9904804044148157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.0315874366232787], {
             RGBColor[
             0.2091663766185125, 0.3371775021132715, 0.9352230877632756]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.0315874366232787], {
             RGBColor[
             0.22595764709528393`, 0.3548261920123965, 0.936179325776469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.0315874366232787], {
             RGBColor[
             0.20875268020104726`, 0.3367426809486477, 0.9351995283643099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.0315874366232787], {
             RGBColor[
             0.19014935834156865`, 0.31718941015560403`, 0.934140096705561]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.0315874366232787], {
             RGBColor[
             0.3052585207535403, 0.43817643819301544`, 0.9406953932161773]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.0315874366232787], {
             RGBColor[
             0.3385640468354945, 0.4676688934702948, 0.9427939795772942]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.0315874366232787], {
             RGBColor[
             0.2511118726659751, 0.3812648779572094, 0.9376118217103779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.0315874366232787], {
             RGBColor[
             0.8575795140998795, 0.443586953641446, 0.20277151376979163`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.0315874366232787], {
             RGBColor[
             0.46980956787155936`, 0.580451597734798, 0.9514042766334527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.0315874366232787], {
             RGBColor[
             0.17894628476761076`, 0.30541426951348377`, 0.9335020982389862]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.0315874366232787], {
             RGBColor[
             0.9930307649637, 0.9875018358921313, 0.48281995931092997`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.0315874366232787], {
             RGBColor[
             0.29675707084929953`, 0.4292408753206019, 0.9402112482208989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.0315874366232787], {
             RGBColor[
             0.746856868272219, 0.8021695289074716, 0.9754033709212744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.0315874366232787], {
             RGBColor[
             0.3044115375980597, 0.43728620519477157`, 0.940647158778472]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.0315874366232787], {
             RGBColor[
             0.266957894870447, 0.3979200519899457, 0.9385142292328336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.0315874366232787], {
             RGBColor[
             0.33007547283951477`, 0.4603165173231115, 0.9422530951484216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.0315874366232787], {
             RGBColor[
             0.1854996162687526, 0.3123022364263995, 0.933875300773191]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.0315874366232787], {
             RGBColor[
             0.2504950392509415, 0.38061654692851177`, 0.937576693959915]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.0315874366232787], {
             RGBColor[
             0.8834003236622562, 0.5634299269441462, 0.22441871075523476`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.0315874366232787], {
             RGBColor[
             0.341942322952124, 0.4705949864454246, 0.9430092403441536]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.0315874366232787], {
             RGBColor[
             0.7148896845747944, 0.7771965220434489, 0.9722171808006315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.0315874366232787], {
             RGBColor[
             0.9886024976405045, 0.9895548541189678, 0.8385496400948322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.0315874366232787], {
             RGBColor[
             0.3331754530775283, 0.46300156439574175`, 0.942450623147983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.0315874366232787], {
             RGBColor[
             0.25921854913182885`, 0.38978550891579644`, 0.9380734849423552]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.0315874366232787], {
             RGBColor[
             0.23934466612723454`, 0.36889679780100676`, 0.9369416967060188]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.0315874366232787], {
             RGBColor[
             0.369677449943029, 0.49461775943693126`, 0.9447764981108042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.0315874366232787], {
             RGBColor[
             0.1790169203691504, 0.30548851200925775`, 0.9335061208319979]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.0315874366232787], {
             RGBColor[
             0.8751755113140446, 0.526082975024646, 0.21755572572328788`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.0315874366232787], {
             RGBColor[
             0.2570691600545971, 0.38752636471648727`, 0.9379510804141431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.0315874366232787], {
             RGBColor[
             0.3853130055350487, 0.5081604918248647, 0.9457727818871488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.0315874366232787], {
             RGBColor[
             0.8825578842047201, 0.909191716742005, 0.9886603529358121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.0315874366232787], {
             RGBColor[
             0.3064495532407965, 0.43942828885294294`, 0.9407632207543519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.0315874366232787], {
             RGBColor[
             0.8366916950922476, 0.8726192625482565, 0.984285594873034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.0315874366232787], {
             RGBColor[
             0.40219205331719154`, 0.5227802746481479, 0.946848299886271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.0315874366232787], {
             RGBColor[
             0.3786491349611119, 0.5023885820695944, 0.9453481659468069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.0315874366232787], {
             RGBColor[
             0.4028040785660817, 0.5233103801574531, 0.9468872975939376]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.0315874366232787], {
             RGBColor[
             0.2767721721232211, 0.4082354796437291, 0.9390731378034569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.0315874366232787], {
             RGBColor[
             0.22223854670063217`, 0.35091718169303304`, 0.9359675285109096]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.0315874366232787], {
             RGBColor[
             0.860210700141258, 0.8913726787679522, 0.9865288585702724]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.0315874366232787], {
             RGBColor[
             0.32010532781399464`, 0.4516808788160655, 0.9416178063236486]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.0315874366232787], {
             RGBColor[
             0.21169068579341777`, 0.33983071110654267`, 0.9353668434364056]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.0315874366232787], {
             RGBColor[
             0.3374345618861965, 0.46669059037677707`, 0.9427220097950892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.0315874366232787], {
             RGBColor[
             0.9935733711383794, 0.9886624156338708, 0.5418792928476311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.0315874366232787], {
             RGBColor[
             0.25998714329821626`, 0.39059335011635443`, 0.9381172552430979]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.0315874366232787], {
             RGBColor[
             0.29288750827080284`, 0.425173719706164, 0.9399908823565584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.0315874366232787], {
             RGBColor[
             0.4637429804071734, 0.5755264687345587, 0.9509266926456142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.0315874366232787], {
             RGBColor[
             0.6597251945044771, 0.7341016031348642, 0.9667188999718916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.0315874366232787], {
             RGBColor[
             0.21788265672664042`, 0.34633886515099205`, 0.9357194670208525]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.0315874366232787], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.0315874366232787], {
             RGBColor[
             0.9599116097125079, 0.876434587737939, 0.29876460310071706`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.0315874366232787], {
             RGBColor[
             0.41360147005439724`, 0.5326625379719564, 0.9475752978318146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.0315874366232787], {
             RGBColor[
             0.3621699928109498, 0.4881151774048913, 0.9442981295809318]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.0315874366232787], {
             RGBColor[
             0.290045450304657, 0.422186536586862, 0.9398290313598343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.0315874366232787], {
             RGBColor[
             0.2278308941861094, 0.35679509347557953`, 0.9362860044270709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.0315874366232787], {
             RGBColor[
             0.6396625402707171, 0.7183458925176417, 0.9647757248126534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.0315874366232787], {
             RGBColor[
             0.3617638436367253, 0.48776339140382907`, 0.9442722501146938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.0315874366232787], {
             RGBColor[
             0.32870680276015046`, 0.45913104409172456`, 0.942165884701232]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.0315874366232787], {
             RGBColor[
             0.26933793088281155`, 0.4004216207419397, 0.9386497687627899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.0315874366232787], {
             RGBColor[
             0.9071422836282599, 0.6695571281253704, 0.2441427056377997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.0315874366232787], {
             RGBColor[
             0.22562621270692998`, 0.3544778334560826, 0.9361604510783655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.0315874366232787], {
             RGBColor[
             0.38545126270191343`, 0.5082802432337956, 0.9457815915115654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.0315874366232787], {
             RGBColor[
             0.5793663225363243, 0.6693947066472076, 0.9600289856802787]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.0315874366232787], {
             RGBColor[
             0.6442014475594858, 0.7219743340365904, 0.9651716379540781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.0315874366232787], {
             RGBColor[
             0.38846154058520777`, 0.5108875946353395, 0.9459734037564047]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.0315874366232787], {
             RGBColor[
             0.40481135748628755`, 0.5250489842693634, 0.9470151996317661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.0315874366232787], {
             RGBColor[
             0.2585666750316088, 0.38910034790526005`, 0.938036361676709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.0315874366232787], {
             RGBColor[
             0.2169746648251472, 0.34538450809251103`, 0.9356677582253161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.0315874366232787], {
             RGBColor[
             0.2650062967491503, 0.3958687986259951, 0.9384030886069564]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.0315874366232787], {
             RGBColor[
             0.2298450608433424, 0.3589121103378734, 0.9364007082385077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.0315874366232787], {
             RGBColor[
             0.4081016499818632, 0.5278988702541217, 0.9472248541600927]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.0315874366232787], {
             RGBColor[
             0.4199474238450335, 0.5381590841884939, 0.9479796563958474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.0315874366232787], {
             RGBColor[
             0.591443337591513, 0.6791993715323379, 0.960979732544987]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.0315874366232787], {
             RGBColor[
             0.36294391873403165`, 0.48878551314081686`, 0.9443474434563948]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.0315874366232787], {
             RGBColor[
             0.4704530721178047, 0.5809740234714359, 0.951454935644951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.0315874366232787], {
             RGBColor[
             0.293615491872952, 0.425938876628849, 0.9400323399457455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.0315874366232787], {
             RGBColor[
             0.2517303220687306, 0.38191490749146234`, 0.937647041488951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.0315874366232787], {
             RGBColor[
             0.9582014383733062, 0.9683472816944506, 0.9556382414098691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.0315874366232787], {
             RGBColor[
             0.2794551004482275, 0.4110554074207916, 0.9392259266025292]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.0315874366232787], {
             RGBColor[
             0.9811051107342013, 0.9854288030398846, 0.9168682983373343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.0315874366232787], {
             RGBColor[
             0.2830844261537786, 0.4148700588498662, 0.9394326113323542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.0315874366232787], {
             RGBColor[
             0.3092991992760449, 0.442321153408306, 0.9409292493686947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.0315874366232787], {
             RGBColor[
             0.27285106149406285`, 0.4041141437597107, 0.9388498363538897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.0315874366232787], {
             RGBColor[
             0.5693048020656428, 0.6612263110627765, 0.9592369059322629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.0315874366232787], {
             RGBColor[
             0.28222469603460637`, 0.4139664279845783, 0.9393836509739241]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.0315874366232787], {
             RGBColor[
             0.32894252042405586`, 0.45933521088468515`, 0.942180904422339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.0315874366232787], {
             RGBColor[
             0.28382079992875175`, 0.41564403437615693`, 0.9394745467294715]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.0315874366232787], {
             RGBColor[
             0.2334715870925415, 0.36272381936082626`, 0.9366072335434348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.0315874366232787], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.0315874366232787], {
             RGBColor[
             0.7751138064478154, 0.8242440637709316, 0.9782197584425172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.0315874366232787], {
             RGBColor[
             0.9461721011462925, 0.9593758216867757, 0.9760007715815773]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.0315874366232787], {
             RGBColor[
             0.2184997826909155, 0.34698750366749115`, 0.9357546114315619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.0315874366232787], {
             RGBColor[
             0.30075346730669683`, 0.43344134138349677`, 0.9404388370870089]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.0315874366232787], {
             RGBColor[
             0.2411272273904176, 0.370770382709524, 0.937043210932894]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.0315874366232787], {
             RGBColor[
             0.3060013924465708, 0.4389572434431762, 0.9407376986601153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.0315874366232787], {
             RGBColor[
             0.4612114846587171, 0.5734712864433781, 0.9507274040271213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.0315874366232787], {
             RGBColor[
             0.22864247952174482`, 0.3576481211208147, 0.9363322230113024]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.0315874366232787], {
             RGBColor[
             0.26498757281889074`, 0.39584911858812655`, 0.9384020223068277]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.0315874366232787], {
             RGBColor[
             0.9935460613341791, 0.9886040027241311, 0.5389067891970045]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.0315874366232787], {
             RGBColor[
             0.3585480532796543, 0.48497803542685713`, 0.944067342796753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.0315874366232787], {
             RGBColor[
             0.26115105564507934`, 0.3918166957892125, 0.9381835383293976]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.0315874366232787], {
             RGBColor[
             0.24150095424043594`, 0.3711631933245442, 0.9370644941241232]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.0315874366232787], {
             RGBColor[
             0.295921828646773, 0.42836298280833224`, 0.9401636824130951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[401, 0.0315874366232787], {
             RGBColor[
             0.7734523776791622, 0.8229461429895335, 0.9780541627497925]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[402, 0.0315874366232787], {
             RGBColor[
             0.5523112332770156, 0.6474301663686192, 0.9578991099477285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[403, 0.0315874366232787], {
             RGBColor[
             0.9289119756027943, 0.9461532109745376, 0.9930816475541463]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[404, 0.0315874366232787], {
             RGBColor[
             0.2134483076486736, 0.3416780831160786, 0.9354669374008939]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[405, 0.0315874366232787], {
             RGBColor[
             0.9940126833910108, 0.9896020601209673, 0.5896957204256101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[406, 0.0315874366232787], {
             RGBColor[
             0.990618380894789, 0.9800157372285142, 0.4180546106567104]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[407, 0.0315874366232787], {
             RGBColor[
             0.21435834209939697`, 0.3426345870233057, 0.9355187625165873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[408, 0.0315874366232787], {
             RGBColor[
             0.2225045334786326, 0.3511967506612473, 0.9359826760644245]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[409, 0.0315874366232787], {
             RGBColor[
             0.24155566178660715`, 0.3712206944242289, 0.937067609637945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[410, 0.0315874366232787], {
             RGBColor[
             0.36366501242205085`, 0.4894100882501565, 0.9443933909085572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[411, 0.0315874366232787], {
             RGBColor[
             0.23958996446517072`, 0.3691546219069906, 0.9369556660834778]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[412, 0.0315874366232787], {
             RGBColor[
             0.2423814866745967, 0.372088688741828, 0.9371146391436176]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[413, 0.0315874366232787], {
             RGBColor[
             0.97383602535665, 0.9234049113139019, 0.35285832847295656`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[414, 0.0315874366232787], {
             RGBColor[
             0.2746579678933065, 0.4060133169497984, 0.9389527370002482]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[415, 0.0315874366232787], {
             RGBColor[
             0.2870126862041934, 0.4189989092289247, 0.9396563199308854]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[416, 0.0315874366232787], {
             RGBColor[
             0.26153368469451344`, 0.39221886318025073`, 0.938205328487714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[417, 0.0315874366232787], {
             RGBColor[
             0.7010326627105, 0.7663713112457954, 0.9708360423624304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[418, 0.0315874366232787], {
             RGBColor[
             0.978473490691829, 0.9834661451211657, 0.9213229446326382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[419, 0.0315874366232787], {
             RGBColor[
             0.5126905354832046, 0.6152642990075083, 0.9547800234820015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[420, 0.0315874366232787], {
             RGBColor[
             0.96864282965107, 0.9761344542131977, 0.9379636895276074]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[421, 0.0315874366232787], {
             RGBColor[
             0.17905660578117066`, 0.3055302238934915, 0.9335083808575031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[422, 0.0315874366232787], {
             RGBColor[
             0.23401200432651914`, 0.3632918321381684, 0.9366380095054342]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[423, 0.0315874366232787], {
             RGBColor[
             0.18782589147201245`, 0.31474729915939237`, 0.9340077787046009]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[424, 0.0315874366232787], {
             RGBColor[
             0.3205944320155112, 0.4521045162923272, 0.9416489716108714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[425, 0.0315874366232787], {
             RGBColor[
             0.37534284954540054`, 0.499524843821242, 0.9451374923637511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[426, 0.0315874366232787], {
             RGBColor[
             0.8701743928884773, 0.8993174569073501, 0.9874792044791957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[427, 0.0315874366232787], {
             RGBColor[
             0.2795001276110678, 0.4111027338238238, 0.9392284908328413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[428, 0.0315874366232787], {
             RGBColor[
             0.8303334960184631, 0.23416211938642656`, 0.1766806960850511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[429, 0.0315874366232787], {
             RGBColor[
             0.29359796730781346`, 0.4259204571997668, 0.9400313419476861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[430, 0.0315874366232787], {
             RGBColor[
             0.23973902577549727`, 0.36931129479517677`, 0.9369641549045845]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[431, 0.0315874366232787], {
             RGBColor[
             0.4485399301016759, 0.5629244760068475, 0.9498015456111601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[432, 0.0315874366232787], {
             RGBColor[
             0.898624468927386, 0.9220027752840345, 0.9901927981294695]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[433, 0.0315874366232787], {
             RGBColor[
             0.32550625142704326`, 0.4563588873913744, 0.9419619484004228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[434, 0.0315874366232787], {
             RGBColor[
             0.9912025783926344, 0.990630054329001, 0.7954595732387495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[435, 0.0315874366232787], {
             RGBColor[
             0.25811768357221787`, 0.3886284294137375, 0.93801079227732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[436, 0.0315874366232787], {
             RGBColor[
             0.472919813782261, 0.5829766354800872, 0.9516491265847494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[437, 0.0315874366232787], {
             RGBColor[
             0.2558304623203871, 0.3862244148598601, 0.9378805384106689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[438, 0.0315874366232787], {
             RGBColor[
             0.22146455698209894`, 0.3501036694250721, 0.9359234509414543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[439, 0.0315874366232787], {
             RGBColor[
             0.8609124841587944, 0.891932262294116, 0.986595795356355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[440, 0.0315874366232787], {
             RGBColor[
             0.28167383897512416`, 0.41338744228870766`, 0.9393522804793065]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[441, 0.0315874366232787], {
             RGBColor[
             0.4501324018566838, 0.5643037950010776, 0.9499030165032217]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[442, 0.0315874366232787], {
             RGBColor[
             0.28394532564135605`, 0.4157749187954902, 0.9394816382845851]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[443, 0.0315874366232787], {
             RGBColor[
             0.9345119801701037, 0.7780688545030732, 0.2661650059247154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[444, 0.0315874366232787], {
             RGBColor[
             0.27129304719779485`, 0.4024765719505212, 0.9387611097445928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[445, 0.0315874366232787], {
             RGBColor[
             0.22963931784821143`, 0.3586958614051314, 0.9363889914793045]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[446, 0.0315874366232787], {
             RGBColor[
             0.22815127331601265`, 0.3571318322543179, 0.9363042495445604]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[447, 0.0315874366232787], {
             RGBColor[
             0.2464999471451923, 0.3764174518218997, 0.9373491793747017]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[448, 0.0315874366232787], {
             RGBColor[
             0.5679393142918087, 0.6601177465734548, 0.9591294097327601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[449, 0.0315874366232787], {
             RGBColor[
             0.7283027762348872, 0.7876749311915857, 0.9735540724248413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[450, 0.0315874366232787], {
             RGBColor[
             0.8177084834502429, 0.13712074047130335`, 0.1645909697918113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[451, 0.0315874366232787], {
             RGBColor[
             0.21144581794704176`, 0.3395733394744833, 0.935352898574804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[452, 0.0315874366232787], {
             RGBColor[
             0.22395342458252596`, 0.35271962707644106`, 0.936065188269349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[453, 0.0315874366232787], {
             RGBColor[
             0.2843068325272902, 0.41615488545346746`, 0.9395022255669375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[454, 0.0315874366232787], {
             RGBColor[
             0.8998824261938122, 0.6382713050470934, 0.23817178112086787`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[455, 0.0315874366232787], {
             RGBColor[
             0.20394063923757638`, 0.33168492079502093`, 0.9349254897502168]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[456, 0.0315874366232787], {
             RGBColor[
             0.22365852866224617`, 0.35240967276674573`, 0.9360483943829485]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[457, 0.0315874366232787], {
             RGBColor[
             0.22158907133489145`, 0.35023454190452297`, 0.9359305418496434]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[458, 0.0315874366232787], {
             RGBColor[
             0.2304992557221517, 0.359599710633853, 0.9364379636690613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[459, 0.0315874366232787], {
             RGBColor[
             0.3905461178527888, 0.5126931506906183, 0.9461062311765757]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[460, 0.0315874366232787], {
             RGBColor[
             0.24834625332605567`, 0.3783580366805602, 0.9374543237803367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[461, 0.0315874366232787], {
             RGBColor[
             0.944455505750549, 0.9580955876512972, 0.9789065198267879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[462, 0.0315874366232787], {
             RGBColor[
             0.46387836533310084`, 0.575636380316448, 0.9509373506429145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[463, 0.0315874366232787], {
             RGBColor[
             0.2670973610782935, 0.3980666398170606, 0.9385221716270487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[464, 0.0315874366232787], {
             RGBColor[
             0.24386676324271586`, 0.3736498085868948, 0.9371992234469022]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[465, 0.0315874366232787], {
             RGBColor[
             0.28262558218412137`, 0.4143877847453685, 0.939406480847081]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[466, 0.0315874366232787], {
             RGBColor[
             0.503508173143364, 0.6078096435993164, 0.9540571542825077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[467, 0.0315874366232787], {
             RGBColor[
             0.7068391686146014, 0.7709073977891587, 0.9714147806060683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[468, 0.0315874366232787], {
             RGBColor[
             0.4783770236668791, 0.5874070443089239, 0.952078738137285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[469, 0.0315874366232787], {
             RGBColor[
             0.8604306779796645, 0.4591301305965446, 0.20525227536014304`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[470, 0.0315874366232787], {
             RGBColor[
             0.25548210733168075`, 0.3858582716797478, 0.937860700109407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[471, 0.0315874366232787], {
             RGBColor[
             0.8568125830318801, 0.4376919853814662, 0.20203709971295072`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[472, 0.0315874366232787], {
             RGBColor[
             0.32844671668737896`, 0.45890577060779597`, 0.9421493122466601]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[473, 0.0315874366232787], {
             RGBColor[
             0.32683125980079797`, 0.4575065430478635, 0.9420463767623395]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[474, 0.0315874366232787], {
             RGBColor[
             0.9930971542734537, 0.9914135101440991, 0.7640615478883636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[475, 0.0315874366232787], {
             RGBColor[
             0.839003391040872, 0.30080273170088523`, 0.1849829973497558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[476, 0.0315874366232787], {
             RGBColor[
             0.8484924274103163, 0.3737396233586853, 0.19406970929346942`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[477, 0.0315874366232787], {
             RGBColor[
             0.24467162743864543`, 0.3744957718881542, 0.9372450592721705]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[478, 0.0315874366232787], {
             RGBColor[
             0.2660419428822219, 0.39695732837561076`, 0.9384620671221336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[479, 0.0315874366232787], {
             RGBColor[
             0.41149067372934756`, 0.5308342722869064, 0.9474407997564864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[480, 0.0315874366232787], {
             RGBColor[
             0.35354723518652786`, 0.48064657814301665`, 0.9437486950899088]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[481, 0.0315874366232787], {
             RGBColor[
             0.318216697210702, 0.4500450419128276, 0.9414974644516573]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[482, 0.0315874366232787], {
             RGBColor[
             0.35848143845973107`, 0.48492033701799786`, 0.9440630981593326]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[483, 0.0315874366232787], {
             RGBColor[
             0.29664917161590876`, 0.42912746638510174`, 0.9402051035191799]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[484, 0.0315874366232787], {
             RGBColor[
             0.9928916986278599, 0.9872043870615327, 0.4676834468726777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[485, 0.0315874366232787], {
             RGBColor[
             0.24800119075484597`, 0.3779953540399882, 0.9374346729773807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[486, 0.0315874366232787], {
             RGBColor[
             0.9349275982881982, 0.9509499052141509, 0.9936554230160899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[487, 0.0315874366232787], {
             RGBColor[
             0.5794313774456323, 0.6694475211532741, 0.9600341070410434]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[488, 0.0315874366232787], {
             RGBColor[
             0.7693643004981994, 0.8197525060252281, 0.9776467014216474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[489, 0.0315874366232787], {
             RGBColor[
             0.9900975943251971, 0.9901731150203205, 0.8137720188432849]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[490, 0.0315874366232787], {
             RGBColor[
             0.9905535588776926, 0.9903616680805318, 0.806215506209998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[491, 0.0315874366232787], {
             RGBColor[
             0.9941614319695004, 0.9899202182895682, 0.6058860852243823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[492, 0.0315874366232787], {
             RGBColor[
             0.2766193131480329, 0.4080748151689876, 0.9390644327109545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[493, 0.0315874366232787], {
             RGBColor[
             0.9935772608954081, 0.9886707354308406, 0.5423026688954158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[494, 0.0315874366232787], {
             RGBColor[
             0.2585035332044634, 0.3890339818415072, 0.938032765843063]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[495, 0.0315874366232787], {
             RGBColor[
             0.8422024713778844, 0.3253922650171049, 0.18804644029332332`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[496, 0.0315874366232787], {
             RGBColor[
             0.27688954314442643`, 0.4083588440287685, 0.9390798219094797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[497, 0.0315874366232787], {
             RGBColor[
             0.23599364281048124`, 0.36537465982794926`, 0.9367508608855244]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[498, 0.0315874366232787], {
             RGBColor[
             0.46188951150763047`, 0.5740217391840874, 0.9507807807843619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[499, 0.0315874366232787], {
             RGBColor[
             0.2607186377132893, 0.3913621971260208, 0.9381589127678872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[500, 0.0315874366232787], {
             RGBColor[
             0.8194926622925333, 0.15083472088530037`, 0.16629950146613023`]},
             StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{3.8349504055390835`*^9, 3.834957759852075*^9, 
  3.835018922383715*^9, 3.835019017360054*^9, 3.835020551743785*^9, 
  3.835044643191966*^9, 3.835045032973324*^9, 3.8350457083859315`*^9, 
  3.8350525243692026`*^9},
 CellLabel->
  "Out[429]=",ExpressionUUID->"b252abc9-a5bf-47ec-ac6a-dcade9a0d992"]
}, Open  ]],

Cell["Estimated with Max-Min Deviation v Calculated: (r = 3)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 3.8349503922098827`*^9}, {3.8349504781120467`*^9, 
  3.8349504928656063`*^9}},ExpressionUUID->"e310cad8-38ba-4c34-8990-\
6fdaf86c52d1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphinf5", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsif5", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}],
      "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"mMDi3f500", ",", "krif5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502554527807`*^9}, {3.8349577716948586`*^9, 
   3.8349577796673746`*^9}, {3.835018835203446*^9, 3.8350188366714215`*^9}, {
   3.8350443464072504`*^9, 3.835044352231003*^9}, {3.8350449386312246`*^9, 
   3.835044944694197*^9}, {3.835045609955904*^9, 3.8350456124786654`*^9}, {
   3.835052461941804*^9, 3.835052463126952*^9}},
 CellLabel->
  "In[430]:=",ExpressionUUID->"554e42ca-0afd-4921-8993-6753d96d1a32"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1dOWGAgQBNBMbNu2bds2J+bEtm3btm3btu01sjdnH271F1R1ssCg6p0C
ggUL9l38vMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEIS
kZgkJCUZyUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpR
mCIUpRjFKUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGY
JjSlGYE0pwUtaUVr2tCWdrSnAx3pRBCd6UJXutGdHvSkF73pQ1/60Z8BDGQQ
gxnCUIYxnBGMZBSjGcNYxjGeCUxkEpOZwlSmMZ0ZzGQWs5nDXOYxnwUsZBGL
WcJSlrGcFaxkFatZw1rWsZ4NbGQTm9nCVraxnR3sZBe72cNe9rGfAxzkEIc5
wlGOcZwTnOQUpznDWc5xngtc5BKXucJVrnGdG9zkFre5w13ucZ8HPOQRj3nC
U57xnBe85BWvecNb3vGeD3zkE5/5wle+8Z1f+JXf+J0/+JO/+Jt/+Jcf/Cx/
AMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEISkZgkJCUZ
yUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpRmCIUpRjF
KUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGYJjSlGYE0
pwUtaUVr2tCWdrSnAx35Od5BdKYLXelGd3rQk170pg996Ud/BjCQQQxmCEMZ
xnBGMJJRjGYMYxnHeCYwkUlMZgpTmcZ0ZjCTWcxmDnOZx3wWsJBFLGYJS1nG
clawklWsZg1rWcd6NrCRTWxmC1vZxnZ2sJNd7GYPe9nHfg5wkEMc5ghHOcZx
TnCSU5zmDGc5x3kucJFLXOYKV7nGdW5wk1vc5g53ucd9HvCQRzzmCU95xnNe
8JJXvOYNb3nHez7wkU985gtf+Rbw/z//Dz189+A=
          "], {Null, CompressedData["
1:eJw13A2c1mO6wPH7tsdpl2O9LLLYQ3Ioas/uCqvVrqQihdKSUmmVzEwspdpK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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[196, 330] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[136, 319] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[60, 188] -> 
             RGBColor[0.6366510000000001, 0.71318, 0.966399], 
             UndirectedEdge[145, 408] -> 
             RGBColor[
              0.8468315000000002, 0.6892923333333336, 0.5994995000000001], 
             UndirectedEdge[398, 460] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[413, 476] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[244, 274] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[198, 223] -> 
             RGBColor[0.9006771666666666, 0.789404, 0.6159235000000001], 
             UndirectedEdge[36, 310] -> 
             RGBColor[
              0.7025906666666666, 0.7653416666666666, 0.9582364999999999], 
             UndirectedEdge[252, 432] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[469, 475] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[113, 347] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[35, 131] -> 
             RGBColor[0.9289355, 0.7535093333333336, 0.563975], 
             UndirectedEdge[156, 479] -> 
             RGBColor[
              0.9326321666666667, 0.7550380000000002, 0.5027116666666669], 
             UndirectedEdge[318, 354] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[6, 77] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[23, 202] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[342, 395] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[53, 418] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[75, 149] -> 
             RGBColor[0.8845911666666666, 0.5488736666666667, 0.5652925], 
             UndirectedEdge[293, 418] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[282, 432] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[466, 468] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[105, 190] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[64, 473] -> 
             RGBColor[
              0.7607756666666667, 0.8130430000000001, 0.9767906666666666], 
             UndirectedEdge[214, 273] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[30, 64] -> 
             RGBColor[0.7594431666666668, 0.450458, 0.5675536666666666], 
             UndirectedEdge[296, 395] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[114, 203] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[81, 237] -> 
             RGBColor[
              0.3569366666666666, 0.4835823333333333, 0.9439646666666667], 
             UndirectedEdge[382, 427] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[39, 450] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[50, 57] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[74, 153] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[239, 332] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[14, 72] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[331, 403] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[214, 302] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[128, 197] -> 
             RGBColor[0.8621055000000001, 0.758648, 0.6122445], 
             UndirectedEdge[191, 212] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[404, 407] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[60, 116] -> 
             RGBColor[0.8621055000000001, 0.758648, 0.6122445000000001], 
             UndirectedEdge[272, 357] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[228, 490] -> 
             RGBColor[0.9761675, 0.9459660000000001, 0.6211925], 
             UndirectedEdge[111, 415] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[227, 428] -> 
             RGBColor[
              0.7025906666666666, 0.7653416666666666, 0.9582364999999999], 
             UndirectedEdge[367, 499] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[434, 495] -> 
             RGBColor[
              0.6747198333333333, 0.7349776666666666, 0.6846703333333333], 
             UndirectedEdge[226, 283] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[9, 34] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[127, 386] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[326, 469] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[192, 483] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[16, 39] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[209, 421] -> 
             RGBColor[0.9006771666666666, 0.789404, 0.6159235], 
             UndirectedEdge[293, 317] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[3, 381] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[211, 497] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[196, 479] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[221, 439] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[379, 390] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[119, 320] -> 
             RGBColor[
              0.9186063333333334, 0.6655183333333337, 0.3079116666666667], 
             UndirectedEdge[179, 401] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[59, 342] -> 
             RGBColor[
              0.8709184999999999, 0.6327363333333336, 0.5902486666666666], 
             UndirectedEdge[86, 98] -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             UndirectedEdge[328, 431] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[270, 375] -> 
             RGBColor[0.7120275, 0.5070206666666669, 0.5752373333333334], 
             UndirectedEdge[39, 45] -> 
             RGBColor[
              0.5852561666666667, 0.6480911666666667, 0.8613086666666667], 
             UndirectedEdge[59, 463] -> 
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667], 
             UndirectedEdge[2, 55] -> 
             RGBColor[
              0.7737441666666667, 0.7867893333333333, 0.6453846666666667], 
             UndirectedEdge[193, 496] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[201, 246] -> 
             RGBColor[0.8621055000000001, 0.758648, 0.6122445000000001], 
             UndirectedEdge[69, 487] -> 
             RGBColor[
              0.6305818333333333, 0.5707906666666667, 0.5928808333333333], 
             UndirectedEdge[15, 408] -> 
             RGBColor[0.8940635000000001, 0.8817490000000001, 0.656717], 
             UndirectedEdge[118, 310] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[289, 297] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[397, 419] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[13, 380] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[155, 262] -> 
             RGBColor[0.9127711666666667, 0.7414540000000002, 0.591337], 
             UndirectedEdge[182, 324] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[177, 245] -> 
             RGBColor[0.6366510000000001, 0.71318, 0.966399], 
             UndirectedEdge[113, 325] -> 
             RGBColor[
              0.8854031666666666, 0.7200483333333335, 0.6031785000000001], 
             UndirectedEdge[94, 368] -> 
             RGBColor[
              0.6747198333333333, 0.7349776666666666, 0.6846703333333333], 
             UndirectedEdge[50, 140] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[389, 458] -> 
             RGBColor[0.8028971666666667, 0.712394, 0.6063431666666667], 
             UndirectedEdge[429, 499] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[97, 358] -> 
             RGBColor[0.904227, 0.657999, 0.241797], UndirectedEdge[274, 363] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685095], 
             UndirectedEdge[255, 274] -> 
             RGBColor[0.948365, 0.8221860000000001, 0.3335865], 
             UndirectedEdge[289, 381] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[55, 230] -> 
             RGBColor[0.7107304999999999, 0.7356320000000001, 0.640424], 
             UndirectedEdge[289, 349] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[29, 318] -> 
             RGBColor[
              0.9195326666666667, 0.6674996666666668, 0.4087373333333335], 
             UndirectedEdge[69, 402] -> 
             RGBColor[0.674261, 0.7371853333333334, 0.8665405000000002], 
             UndirectedEdge[6, 413] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[29, 482] -> 
             RGBColor[
              0.8709184999999999, 0.6327363333333336, 0.5902486666666666], 
             UndirectedEdge[212, 456] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[354, 482] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[106, 247] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[305, 382] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[279, 285] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[27, 319] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[118, 483] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[342, 447] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[207, 458] -> 
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334], 
             UndirectedEdge[462, 487] -> 
             RGBColor[0.936185, 0.7811, 0.2862695], UndirectedEdge[64, 384] -> 
             RGBColor[
              0.7731385000000001, 0.5557263333333335, 0.5806683333333333], 
             UndirectedEdge[203, 221] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[139, 370] -> 
             RGBColor[0.9006771666666666, 0.789404, 0.6159235], 
             UndirectedEdge[46, 357] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[18, 326] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[73, 93] -> 
             RGBColor[
              0.7607756666666667, 0.8130430000000001, 0.9767906666666666], 
             UndirectedEdge[104, 112] -> 
             RGBColor[
              0.7859241666666666, 0.8278753333333333, 0.6927016666666667], 
             UndirectedEdge[40, 314] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[264, 398] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[345, 489] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685095], 
             UndirectedEdge[80, 417] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[271, 442] -> 
             RGBColor[
              0.8793508333333335, 0.8270200000000001, 0.6261205000000001], 
             UndirectedEdge[318, 482] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[235, 260] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[79, 278] -> 
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666], 
             UndirectedEdge[137, 404] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[380, 478] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[247, 370] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[251, 429] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[286, 407] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[206, 410] -> 
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333], 
             UndirectedEdge[86, 500] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[78, 407] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[363, 370] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[447, 453] -> 
             RGBColor[
              0.9195326666666667, 0.6674996666666669, 0.4087373333333335], 
             UndirectedEdge[256, 492] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[114, 349] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[22, 160] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[149, 324] -> 
             RGBColor[
              0.9058373333333334, 0.5622313333333333, 0.3956226666666668], 
             UndirectedEdge[94, 315] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685095], 
             UndirectedEdge[246, 492] -> 
             RGBColor[0.8028971666666667, 0.712394, 0.6063431666666667], 
             UndirectedEdge[193, 202] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[321, 335] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[321, 496] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[18, 474] -> 
             RGBColor[0.4681409999999999, 0.57648, 0.9519960000000001], 
             UndirectedEdge[184, 192] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[170, 171] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[80, 156] -> 
             RGBColor[
              0.7876231666666668, 0.6430383333333336, 0.5935981666666666], 
             UndirectedEdge[353, 418] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[201, 312] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[152, 212] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[192, 260] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[90, 357] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[57, 369] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[83, 448] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[67, 180] -> 
             RGBColor[
              0.9812493333333333, 0.9472683333333334, 0.4788846666666668], 
             UndirectedEdge[373, 472] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[353, 432] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[1, 433] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[300, 301] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[212, 389] -> 
             RGBColor[0.9280451666666667, 0.8108096666666667, 0.604082], 
             UndirectedEdge[97, 174] -> 
             RGBColor[0.8621055000000001, 0.758648, 0.6122445], 
             UndirectedEdge[200, 471] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[155, 387] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[156, 354] -> 
             RGBColor[0.9127711666666667, 0.7414540000000002, 0.591337], 
             UndirectedEdge[314, 472] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[117, 269] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[336, 409] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[63, 252] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[201, 444] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[201, 442] -> 
             RGBColor[
              0.8793508333333335, 0.8270200000000001, 0.6261205000000001], 
             UndirectedEdge[25, 333] -> 
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667], 
             UndirectedEdge[203, 397] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[7, 436] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.7737441666666667, 0.7867893333333333, 0.6453846666666667], 
             UndirectedEdge[274, 369] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[38, 364] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[215, 356] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[16, 283] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[236, 276] -> 
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667], 
             UndirectedEdge[39, 454] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[179, 315] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[149, 182] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[97, 407] -> 
             RGBColor[
              0.7417861666666666, 0.6636883333333333, 0.6009121666666667], 
             UndirectedEdge[274, 379] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[39, 325] -> 
             RGBColor[
              0.9326321666666667, 0.7550380000000002, 0.5027116666666668], 
             UndirectedEdge[127, 347] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[327, 483] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[269, 360] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[54, 147] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[276, 422] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[181, 424] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[336, 456] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[46, 298] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[107, 132] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[78, 95] -> 
             RGBColor[0.8186515000000001, 0.49671200000000004`, 0.573455], 
             UndirectedEdge[296, 332] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[397, 472] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[19, 269] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685095], 
             UndirectedEdge[185, 335] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[112, 351] -> 
             RGBColor[
              0.7859241666666666, 0.8278753333333333, 0.6927016666666667], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.6248324999999999, 0.6920451666666667, 0.9250363333333333], 
             UndirectedEdge[251, 305] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[131, 170] -> 
             RGBColor[0.9127711666666667, 0.7414540000000002, 0.591337], 
             UndirectedEdge[76, 333] -> 
             RGBColor[
              0.8323468333333335, 0.6019803333333336, 0.5865696666666667], 
             UndirectedEdge[114, 115] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[87, 421] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[60, 192] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[84, 147] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[431, 433] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[201, 492] -> 
             RGBColor[
              0.7607756666666667, 0.8130430000000001, 0.9767906666666666], 
             UndirectedEdge[86, 124] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[234, 239] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[100, 450] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[22, 275] -> 
             RGBColor[
              0.9934293333333333, 0.9883543333333333, 0.5262016666666668], 
             UndirectedEdge[160, 324] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[191, 218] -> 
             RGBColor[
              0.7607756666666667, 0.8130430000000001, 0.9767906666666666], 
             UndirectedEdge[349, 397] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[401, 454] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[311, 349] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[63, 324] -> 
             RGBColor[
              0.7868504999999999, 0.8298566666666667, 0.7935273333333335], 
             UndirectedEdge[22, 353] -> 
             RGBColor[
              0.9934293333333333, 0.9883543333333333, 0.5262016666666668], 
             UndirectedEdge[93, 437] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[417, 461] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[151, 249] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[148, 452] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[262, 424] -> 
             RGBColor[
              0.7876231666666668, 0.6430383333333336, 0.5935981666666668], 
             UndirectedEdge[50, 139] -> 
             RGBColor[0.8028971666666667, 0.712394, 0.6063431666666667], 
             UndirectedEdge[237, 267] -> 
             RGBColor[
              0.4051273333333333, 0.5253226666666666, 0.9470353333333333], 
             UndirectedEdge[256, 442] -> 
             RGBColor[0.9651515, 0.8927656666666668, 0.5293326666666668], 
             UndirectedEdge[60, 133] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[77, 156] -> 
             RGBColor[
              0.7265121666666667, 0.5943326666666668, 0.5881671666666667], 
             UndirectedEdge[219, 498] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[102, 185] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[92, 169] -> 
             RGBColor[
              0.8348551666666667, 0.8354950000000001, 0.6508156666666667], 
             UndirectedEdge[53, 357] -> 
             RGBColor[
              0.9934293333333333, 0.9883543333333333, 0.5262016666666668], 
             UndirectedEdge[162, 289] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[169, 204] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[176, 448] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[377, 403] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[86, 357] -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             UndirectedEdge[12, 373] -> 
             RGBColor[0.9326351666666666, 0.912505, 0.660396], 
             UndirectedEdge[200, 469] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[112, 153] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[166, 243] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[394, 460] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[18, 348] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[315, 325] -> 
             RGBColor[0.9289355, 0.7535093333333336, 0.563975], 
             UndirectedEdge[195, 447] -> 
             RGBColor[
              0.9195326666666667, 0.6674996666666668, 0.4087373333333335], 
             UndirectedEdge[128, 204] -> 
             RGBColor[
              0.9479061666666666, 0.8243936666666667, 0.5154566666666668], 
             UndirectedEdge[91, 435] -> 
             RGBColor[
              0.6983321666666666, 0.4017523333333333, 0.5621226666666667], 
             UndirectedEdge[158, 206] -> 
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666], 
             UndirectedEdge[30, 290] -> 
             RGBColor[
              0.6983321666666666, 0.4017523333333333, 0.5621226666666667], 
             UndirectedEdge[2, 250] -> 
             RGBColor[
              0.6404563333333333, 0.7180833333333334, 0.9654583333333333], 
             UndirectedEdge[148, 195] -> 
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667], 
             UndirectedEdge[5, 202] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[220, 359] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[175, 337] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[263, 447] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[344, 387] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[82, 470] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[273, 446] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[68, 306] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[21, 33] -> 
             RGBColor[0.7594431666666668, 0.450458, 0.5675536666666666], 
             UndirectedEdge[77, 479] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[253, 311] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[308, 386] -> 
             RGBColor[
              0.7868504999999999, 0.8298566666666667, 0.7935273333333335], 
             UndirectedEdge[151, 280] -> 
             RGBColor[0.9452905, 0.8791816666666668, 0.617958], 
             UndirectedEdge[305, 416] -> 
             RGBColor[0.5815595, 0.6465625, 0.922572], 
             UndirectedEdge[38, 189] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[277, 291] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[27, 40] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[88, 167] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[89, 296] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[169, 340] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[169, 363] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[43, 378] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[350, 482] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[199, 429] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[135, 216] -> 
             RGBColor[
              0.9479061666666666, 0.8243936666666667, 0.5154566666666668], 
             UndirectedEdge[153, 351] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685095], 
             UndirectedEdge[207, 218] -> 
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334], 
             UndirectedEdge[218, 389] -> 
             RGBColor[0.8028971666666667, 0.712394, 0.6063431666666667], 
             UndirectedEdge[421, 477] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[171, 391] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[25, 246] -> 
             RGBColor[0.9280451666666667, 0.8108096666666667, 0.604082], 
             UndirectedEdge[130, 254] -> 
             RGBColor[0.8927309999999999, 0.519164, 0.24747999999999998`], 
             UndirectedEdge[65, 434] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685095], 
             UndirectedEdge[174, 430] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[213, 454] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[52, 495] -> 
             RGBColor[
              0.3569366666666666, 0.4835823333333333, 0.9439646666666667], 
             UndirectedEdge[26, 224] -> 
             RGBColor[
              0.9934293333333333, 0.9883543333333333, 0.5262016666666668], 
             UndirectedEdge[8, 31] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[29, 321] -> 
             RGBColor[
              0.8709184999999999, 0.6327363333333336, 0.5902486666666666], 
             UndirectedEdge[319, 377] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[323, 447] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[13, 340] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[176, 237] -> 
             RGBColor[
              0.6705643333333333, 0.7356566666666666, 0.9278038333333334], 
             UndirectedEdge[22, 268] -> 
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666], 
             UndirectedEdge[461, 493] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[401, 450] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[100, 200] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[197, 375] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[94, 401] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685095], 
             UndirectedEdge[118, 327] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[44, 255] -> 
             RGBColor[0.8028971666666667, 0.712394, 0.6063431666666667], 
             UndirectedEdge[148, 356] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[26, 34] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[244, 313] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[331, 488] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[382, 429] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[409, 496] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[14, 324] -> 
             RGBColor[
              0.9934293333333333, 0.9883543333333333, 0.5262016666666668], 
             UndirectedEdge[259, 471] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[178, 439] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[127, 454] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[190, 452] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[218, 295] -> 
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333], 
             UndirectedEdge[35, 67] -> 
             RGBColor[0.9761675, 0.9459660000000001, 0.6211925], 
             UndirectedEdge[192, 249] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[186, 202] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[243, 469] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[48, 183] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[255, 390] -> 
             RGBColor[0.948365, 0.8221860000000001, 0.3335865], 
             UndirectedEdge[202, 497] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[84, 365] -> 
             RGBColor[0.4681409999999999, 0.57648, 0.9519960000000001], 
             UndirectedEdge[239, 262] -> 
             RGBColor[0.9330910000000001, 0.7528303333333335, 0.3208415], 
             UndirectedEdge[299, 456] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[136, 253] -> 
             RGBColor[
              0.7607756666666667, 0.8130430000000001, 0.9767906666666666], 
             UndirectedEdge[338, 478] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[284, 444] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[135, 147] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[72, 73] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[8, 291] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[141, 240] -> 
             RGBColor[0.9442094999999999, 0.822865, 0.57672], 
             UndirectedEdge[9, 466] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[78, 346] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[255, 425] -> 
             RGBColor[0.8621055000000001, 0.758648, 0.6122445], 
             UndirectedEdge[297, 349] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[248, 478] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[113, 130] -> 
             RGBColor[0.8572231666666666, 0.527468, 0.577134], 
             UndirectedEdge[51, 179] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[440, 470] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[5, 414] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[148, 463] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[63, 441] -> 
             RGBColor[
              0.7868504999999999, 0.8298566666666667, 0.7935273333333335], 
             UndirectedEdge[163, 187] -> 
             RGBColor[
              0.5848500000000001, 0.5271791666666666, 0.5901133333333334], 
             UndirectedEdge[120, 177] -> 
             RGBColor[0.6634985, 0.5431753333333336, 0.5832065], 
             UndirectedEdge[450, 454] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[15, 190] -> 
             RGBColor[0.980323, 0.945287, 0.378059], UndirectedEdge[191, 287] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[179, 292] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[291, 297] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[289, 397] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[175, 370] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[23, 186] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[241, 461] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[157, 216] -> 
             RGBColor[
              0.7417861666666666, 0.6636883333333333, 0.6009121666666667], 
             UndirectedEdge[51, 302] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[174, 390] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[79, 406] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[181, 235] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[78, 404] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[89, 280] -> 
             RGBColor[0.9614548333333334, 0.8912370000000001, 0.590596], 
             UndirectedEdge[43, 384] -> 
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667], 
             UndirectedEdge[101, 363] -> 
             RGBColor[0.9761675, 0.9459660000000001, 0.6211925], 
             UndirectedEdge[120, 455] -> 
             RGBColor[
              0.8854031666666666, 0.7200483333333335, 0.6031785000000001], 
             UndirectedEdge[295, 456] -> 
             RGBColor[
              0.6404563333333333, 0.7180833333333334, 0.9654583333333333], 
             UndirectedEdge[58, 240] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[39, 471] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[54, 365] -> 
             RGBColor[0.5292520000000001, 0.6251856666666666, 0.957427], 
             UndirectedEdge[169, 334] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[18, 65] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[384, 435] -> 
             RGBColor[0.7120275, 0.5070206666666669, 0.5752373333333334], 
             UndirectedEdge[9, 360] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[135, 171] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[149, 187] -> 
             RGBColor[0.860773, 0.396063, 0.2030075], 
             UndirectedEdge[271, 464] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[21, 348] -> 
             RGBColor[
              0.9044521666666667, 0.5624576666666667, 0.47666716666666675`], 
             UndirectedEdge[1, 70] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[52, 276] -> 
             RGBColor[
              0.6543999999999999, 0.7236013333333333, 0.9551658333333333], 
             UndirectedEdge[58, 429] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[243, 495] -> 
             RGBColor[
              0.5884603333333334, 0.6714396666666667, 0.9633283333333333], 
             UndirectedEdge[131, 135] -> 
             RGBColor[
              0.9326321666666667, 0.7550380000000002, 0.5027116666666669], 
             UndirectedEdge[145, 430] -> 
             RGBColor[0.9289355, 0.7535093333333336, 0.5639750000000001], 
             UndirectedEdge[291, 419] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[151, 260] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[189, 437] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[196, 354] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[340, 355] -> 
             RGBColor[
              0.7025906666666666, 0.7653416666666666, 0.9582364999999999], 
             UndirectedEdge[58, 310] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[261, 500] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[237, 270] -> 
             RGBColor[
              0.6008231666666667, 0.4141230000000002, 0.5672060000000001], 
             UndirectedEdge[23, 497] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[431, 462] -> 
             RGBColor[0.9761675, 0.9459660000000001, 0.6211925], 
             UndirectedEdge[108, 129] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[376, 485] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[124, 261] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[63, 158] -> 
             RGBColor[
              0.7859241666666666, 0.8278753333333333, 0.6927016666666667], 
             UndirectedEdge[66, 427] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[66, 208] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[54, 230] -> 
             RGBColor[0.5774426666666668, 0.666926, 0.9604976666666667], 
             UndirectedEdge[186, 295] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[245, 394] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[49, 459] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[55, 365] -> 
             RGBColor[
              0.6625398333333333, 0.6938916666666667, 0.6373533333333333], 
             UndirectedEdge[197, 448] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[185, 321] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[242, 339] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[186, 191] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[218, 456] -> 
             RGBColor[
              0.6404563333333333, 0.7180833333333334, 0.9654583333333333], 
             UndirectedEdge[63, 182] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[133, 181] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[11, 186] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[105, 148] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[235, 393] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[110, 290] -> 
             RGBColor[0.7120275, 0.5070206666666669, 0.5752373333333334], 
             UndirectedEdge[225, 296] -> 
             RGBColor[
              0.7859241666666666, 0.8278753333333333, 0.6927016666666667], 
             UndirectedEdge[38, 93] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[80, 486] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[471, 500] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[200, 213] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[191, 295] -> 
             RGBColor[
              0.7607756666666667, 0.8130430000000001, 0.9767906666666666], 
             UndirectedEdge[295, 300] -> 
             RGBColor[
              0.7607756666666667, 0.8130430000000001, 0.9767906666666666], 
             UndirectedEdge[191, 451] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[137, 145] -> 
             RGBColor[0.9289355, 0.7535093333333336, 0.563975], 
             UndirectedEdge[332, 344] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[76, 392] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[157, 465] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[204, 337] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[112, 395] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[51, 107] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[5, 41] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[88, 210] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[248, 411] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[101, 128] -> 
             RGBColor[0.936185, 0.7811, 0.2862695], UndirectedEdge[298, 418] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[1, 391] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[116, 327] -> 
             RGBColor[0.9006771666666666, 0.789404, 0.6159235], 
             UndirectedEdge[79, 81] -> 
             RGBColor[
              0.6747198333333333, 0.7349776666666666, 0.6846703333333333], 
             UndirectedEdge[254, 368] -> 
             RGBColor[
              0.6625398333333333, 0.6938916666666667, 0.6373533333333333], 
             UndirectedEdge[4, 318] -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             UndirectedEdge[352, 412] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[239, 424] -> 
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666], 
             UndirectedEdge[58, 188] -> 
             RGBColor[
              0.7025906666666666, 0.7653416666666666, 0.9582364999999999], 
             UndirectedEdge[407, 408] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[255, 466] -> 
             RGBColor[0.8621055000000001, 0.758648, 0.6122445], 
             UndirectedEdge[197, 489] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[50, 363] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[57, 175] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[278, 486] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[82, 263] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[41, 186] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[390, 425] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[218, 458] -> 
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333], 
             UndirectedEdge[230, 374] -> 
             RGBColor[0.6353185, 0.350595, 0.5571619999999999], 
             UndirectedEdge[104, 408] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.7607756666666667, 0.8130430000000001, 0.9767906666666666], 
             UndirectedEdge[143, 421] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[185, 482] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[256, 333] -> 
             RGBColor[0.9181475, 0.6677260000000003, 0.48978183333333347`], 
             UndirectedEdge[351, 463] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[42, 411] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[52, 243] -> 
             RGBColor[
              0.5884603333333334, 0.6714396666666667, 0.9633283333333333], 
             UndirectedEdge[385, 391] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[366, 435] -> 
             RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             UndirectedEdge[114, 419] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[67, 391] -> 
             RGBColor[
              0.9600031666666666, 0.9339106666666667, 0.6485544999999999], 
             UndirectedEdge[310, 327] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[309, 348] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[28, 194] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[92, 337] -> 
             RGBColor[
              0.7737441666666667, 0.7867893333333333, 0.6453846666666667], 
             UndirectedEdge[205, 432] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[314, 398] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[235, 453] -> 
             RGBColor[
              0.8323468333333335, 0.6019803333333336, 0.5865696666666667], 
             UndirectedEdge[92, 334] -> 
             RGBColor[
              0.9798641666666666, 0.9474946666666667, 0.5599291666666668], 
             UndirectedEdge[35, 54] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[191, 456] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[78, 137] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[57, 169] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[343, 392] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[24, 197] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[450, 471] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[150, 267] -> 
             RGBColor[
              0.5163316666666666, 0.6182203333333334, 0.9550666666666667], 
             UndirectedEdge[40, 371] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[217, 362] -> 
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334], 
             UndirectedEdge[229, 478] -> 
             RGBColor[0.8621055000000001, 0.758648, 0.6122445], 
             UndirectedEdge[100, 168] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[221, 297] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[50, 338] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[5, 186] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[147, 391] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[24, 426] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[100, 127] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[418, 432] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[200, 259] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[17, 293] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[269, 468] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[154, 390] -> 
             RGBColor[
              0.9934293333333333, 0.9883543333333333, 0.5262016666666668], 
             UndirectedEdge[162, 439] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[103, 304] -> 
             RGBColor[
              0.8591943333333334, 0.4319756666666671, 0.20337716666666672`], 
             UndirectedEdge[3, 480] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[358, 404] -> 
             RGBColor[0.9442094999999999, 0.822865, 0.57672], 
             UndirectedEdge[3, 439] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[336, 458] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[212, 287] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[190, 195] -> 
             RGBColor[
              0.9186063333333334, 0.6655183333333335, 0.3079116666666667], 
             UndirectedEdge[253, 377] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[192, 327] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[151, 483] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[38, 163] -> 
             RGBColor[
              0.6086681666666667, 0.6799898333333333, 0.9523983333333333], 
             UndirectedEdge[88, 227] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[281, 343] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[76, 157] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[364, 437] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[229, 244] -> 
             RGBColor[0.9006771666666666, 0.789404, 0.6159235], 
             UndirectedEdge[154, 425] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[128, 355] -> 
             RGBColor[0.6787725, 0.6125309999999999, 0.5959515], 
             UndirectedEdge[58, 382] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[45, 179] -> 
             RGBColor[
              0.5852561666666667, 0.6480911666666667, 0.8613086666666667], 
             UndirectedEdge[181, 296] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[350, 354] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[318, 335] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[354, 372] -> 
             RGBColor[0.8845911666666666, 0.5488736666666667, 0.5652925], 
             UndirectedEdge[44, 57] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[257, 420] -> 
             RGBColor[0.9179225, 0.8577760000000001, 0.6297995000000001], 
             UndirectedEdge[84, 171] -> 
             RGBColor[
              0.6404563333333333, 0.7180833333333334, 0.9654583333333333], 
             UndirectedEdge[376, 497] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[164, 443] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[2, 54] -> 
             RGBColor[
              0.6404563333333333, 0.7180833333333334, 0.9654583333333333], 
             UndirectedEdge[165, 324] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[82, 395] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[298, 420] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[163, 437] -> 
             RGBColor[
              0.6248324999999999, 0.6920451666666667, 0.9250363333333333], 
             UndirectedEdge[156, 372] -> 
             RGBColor[0.845499, 0.3267073333333335, 0.19026250000000006`], 
             UndirectedEdge[272, 317] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[282, 441] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[209, 423] -> 
             RGBColor[0.9442094999999999, 0.822865, 0.57672], 
             UndirectedEdge[222, 333] -> 
             RGBColor[
              0.9186063333333334, 0.6655183333333335, 0.3079116666666667], 
             UndirectedEdge[125, 455] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[343, 433] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[29, 77] -> 
             RGBColor[0.7120275, 0.5070206666666669, 0.5752373333333334], 
             UndirectedEdge[298, 353] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[65, 337] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[93, 364] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[170, 328] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[13, 244] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[114, 291] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[198, 373] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[54, 84] -> 
             RGBColor[
              0.6404563333333333, 0.7180833333333334, 0.9654583333333333], 
             UndirectedEdge[1, 385] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[97, 294] -> 
             RGBColor[0.8621055000000001, 0.758648, 0.6122445], 
             UndirectedEdge[83, 489] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[349, 359] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[47, 55] -> 
             RGBColor[0.9326351666666666, 0.912505, 0.660396], 
             UndirectedEdge[166, 309] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[196, 482] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[114, 311] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[101, 169] -> 
             RGBColor[
              0.8348551666666667, 0.8354950000000001, 0.6508156666666667], 
             UndirectedEdge[160, 353] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[80, 329] -> 
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334], 
             UndirectedEdge[130, 386] -> 
             RGBColor[
              0.6983321666666666, 0.4017523333333333, 0.5621226666666667], 
             UndirectedEdge[216, 238] -> 
             RGBColor[
              0.9479061666666666, 0.8243936666666667, 0.5154566666666668], 
             UndirectedEdge[240, 382] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[424, 470] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[184, 225] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[169, 274] -> 
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666], 
             UndirectedEdge[345, 375] -> 
             RGBColor[
              0.7859241666666666, 0.8278753333333333, 0.6927016666666667], 
             UndirectedEdge[326, 434] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685095], 
             UndirectedEdge[59, 105] -> 
             RGBColor[
              0.8709184999999999, 0.6327363333333336, 0.5902486666666666], 
             UndirectedEdge[90, 306] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[44, 466] -> 
             RGBColor[
              0.7607756666666667, 0.8130430000000001, 0.9767906666666666], 
             UndirectedEdge[88, 434] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[174, 356] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[65, 88] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[82, 195] -> 
             RGBColor[
              0.7731385000000001, 0.5557263333333335, 0.5806683333333333], 
             UndirectedEdge[150, 413] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[156, 307] -> 
             RGBColor[
              0.9340173333333334, 0.7548116666666669, 0.4216671666666668], 
             UndirectedEdge[245, 460] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[101, 204] -> 
             RGBColor[
              0.9798641666666666, 0.9474946666666667, 0.5599291666666668], 
             UndirectedEdge[210, 428] -> 
             RGBColor[
              0.7025906666666666, 0.7653416666666666, 0.9582364999999999], 
             UndirectedEdge[25, 76] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[130, 421] -> 
             RGBColor[0.8572231666666666, 0.527468, 0.577134], 
             UndirectedEdge[79, 493] -> 
             RGBColor[0.992503, 0.986373, 0.425376], UndirectedEdge[194, 490] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[214, 347] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[41, 202] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[85, 97] -> RGBColor[0.936185, 0.7811, 0.2862695], 
             UndirectedEdge[31, 114] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[247, 425] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[35, 281] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[157, 288] -> 
             RGBColor[
              0.7265121666666667, 0.5943326666666668, 0.5881671666666667], 
             UndirectedEdge[208, 427] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[154, 313] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[189, 364] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[314, 373] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[156, 232] -> 
             RGBColor[
              0.8468315000000002, 0.6892923333333336, 0.5994995000000001], 
             UndirectedEdge[321, 383] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[15, 323] -> 
             RGBColor[0.9326351666666666, 0.912505, 0.660396], 
             UndirectedEdge[225, 235] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[170, 265] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[102, 485] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[342, 463] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[70, 147] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[162, 381] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[212, 299] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[92, 361] -> 
             RGBColor[
              0.9798641666666666, 0.9474946666666667, 0.5599291666666668], 
             UndirectedEdge[82, 184] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[232, 376] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[293, 298] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[225, 249] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[19, 34] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[338, 390] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685095], 
             UndirectedEdge[82, 342] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[54, 374] -> 
             RGBColor[0.7594431666666668, 0.450458, 0.5675536666666666], 
             UndirectedEdge[196, 350] -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             UndirectedEdge[19, 44] -> 
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666], 
             UndirectedEdge[85, 408] -> 
             RGBColor[0.8940635000000001, 0.8817490000000001, 0.656717], 
             UndirectedEdge[57, 255] -> 
             RGBColor[0.9006771666666666, 0.789404, 0.6159235000000001], 
             UndirectedEdge[106, 269] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[382, 416] -> 
             RGBColor[
              0.5653951666666667, 0.6345071666666666, 0.9499340000000001], 
             UndirectedEdge[246, 392] -> 
             RGBColor[0.9006771666666666, 0.789404, 0.6159235], 
             UndirectedEdge[350, 414] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[146, 211] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[71, 487] -> 
             RGBColor[0.9006771666666666, 0.789404, 0.6159235000000001], 
             UndirectedEdge[415, 485] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[238, 433] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[141, 429] -> 
             RGBColor[0.9442094999999999, 0.822865, 0.57672], 
             UndirectedEdge[406, 493] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[257, 357] -> 
             RGBColor[
              0.9665366666666667, 0.8925393333333335, 0.4482881666666668], 
             UndirectedEdge[311, 488] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[258, 381] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[168, 200] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[16, 254] -> 
             RGBColor[
              0.8348551666666667, 0.8354950000000001, 0.6508156666666667], 
             UndirectedEdge[325, 347] -> 
             RGBColor[
              0.8468315000000002, 0.6892923333333336, 0.5994995000000001], 
             UndirectedEdge[154, 478] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[302, 386] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[330, 414] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[50, 334] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[72, 187] -> 
             RGBColor[0.9280451666666667, 0.8108096666666667, 0.604082], 
             UndirectedEdge[14, 149] -> RGBColor[0.904911, 0.56025, 0.294797],
              UndirectedEdge[113, 214] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[63, 149] -> 
             RGBColor[
              0.6983321666666666, 0.4017523333333333, 0.5621226666666667], 
             UndirectedEdge[245, 445] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[207, 336] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[264, 394] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[255, 370] -> 
             RGBColor[0.9006771666666666, 0.789404, 0.6159235], 
             UndirectedEdge[330, 482] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[383, 482] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[358, 407] -> 
             RGBColor[
              0.7417861666666666, 0.6636883333333333, 0.6009121666666667], 
             UndirectedEdge[28, 142] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[348, 375] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[41, 295] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[83, 345] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685095], 
             UndirectedEdge[140, 425] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[160, 441] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[66, 394] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[201, 271] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[192, 470] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[255, 379] -> 
             RGBColor[
              0.9479061666666666, 0.8243936666666667, 0.5154566666666668], 
             UndirectedEdge[82, 440] -> 
             RGBColor[
              0.7607756666666667, 0.8130430000000001, 0.9767906666666666], 
             UndirectedEdge[43, 362] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[127, 302] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[137, 358] -> 
             RGBColor[0.9442094999999999, 0.822865, 0.57672], 
             UndirectedEdge[238, 328] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[185, 196] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[114, 208] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[249, 424] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[21, 65] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[369, 466] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[246, 459] -> 
             RGBColor[0.9280451666666667, 0.8108096666666667, 0.604082], 
             UndirectedEdge[46, 317] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[66, 305] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[56, 243] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[281, 288] -> 
             RGBColor[
              0.7876231666666668, 0.6430383333333336, 0.5935981666666666], 
             UndirectedEdge[81, 329] -> 
             RGBColor[
              0.6756461666666667, 0.7369589999999999, 0.7854960000000002], 
             UndirectedEdge[57, 140] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[184, 440] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[422, 446] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[232, 307] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[90, 261] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[118, 304] -> 
             RGBColor[
              0.8468315000000002, 0.6892923333333336, 0.5994995000000001], 
             UndirectedEdge[427, 460] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[299, 300] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[106, 425] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[428, 495] -> 
             RGBColor[
              0.4051273333333333, 0.5253226666666666, 0.9470353333333333], 
             UndirectedEdge[230, 365] -> 
             RGBColor[
              0.4051273333333333, 0.5253226666666666, 0.9470353333333333], 
             UndirectedEdge[224, 463] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[251, 382] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[81, 278] -> 
             RGBColor[0.5292520000000001, 0.6251856666666666, 0.957427], 
             UndirectedEdge[42, 294] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[8, 419] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[159, 164] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[346, 404] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[7, 194] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[268, 353] -> 
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334], 
             UndirectedEdge[51, 423] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[14, 322] -> 
             RGBColor[0.9656103333333335, 0.8905580000000002, 0.3474625], 
             UndirectedEdge[109, 458] -> 
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334], 
             UndirectedEdge[217, 384] -> 
             RGBColor[
              0.7731385000000001, 0.5557263333333335, 0.5806683333333333], 
             UndirectedEdge[202, 485] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[125, 457] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[454, 475] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[30, 378] -> 
             RGBColor[0.8572231666666666, 0.527468, 0.577134], 
             UndirectedEdge[445, 460] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[173, 461] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[23, 41] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[111, 444] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[139, 360] -> 
             RGBColor[0.9280451666666667, 0.8108096666666667, 0.604082], 
             UndirectedEdge[53, 432] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685095], 
             UndirectedEdge[184, 260] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[244, 379] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[14, 187] -> 
             RGBColor[0.948365, 0.8221860000000001, 0.3335865], 
             UndirectedEdge[133, 332] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[424, 440] -> 
             RGBColor[
              0.7607756666666667, 0.8130430000000001, 0.9767906666666666], 
             UndirectedEdge[381, 419] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[39, 368] -> 
             RGBColor[0.674261, 0.7371853333333334, 0.8665405000000002], 
             UndirectedEdge[40, 208] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[436, 462] -> 
             RGBColor[0.9326351666666666, 0.912505, 0.660396], 
             UndirectedEdge[103, 188] -> 
             RGBColor[
              0.6490138333333333, 0.4558633333333335, 0.5702766666666667], 
             UndirectedEdge[313, 411] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[181, 344] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[5, 485] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[371, 429] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[426, 448] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[32, 403] -> 
             RGBColor[0.8940635000000001, 0.8817490000000001, 0.656717], 
             UndirectedEdge[115, 484] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[36, 251] -> 
             RGBColor[0.6752226666666666, 0.7439359999999999, 0.970078], 
             UndirectedEdge[243, 454] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[106, 139] -> 
             RGBColor[
              0.9479061666666666, 0.8243936666666667, 0.5154566666666668], 
             UndirectedEdge[220, 499] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[359, 419] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[115, 297] -> 
             RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             UndirectedEdge[155, 235] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[98, 261] -> 
             RGBColor[
              0.9934293333333333, 0.9883543333333333, 0.5262016666666668], 
             UndirectedEdge[386, 421] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[37, 58] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[71, 194] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[47, 339] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[108, 410] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[193, 196] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[131, 171] -> 
             RGBColor[
              0.7876231666666668, 0.6430383333333336, 0.5935981666666668], 
             UndirectedEdge[203, 258] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[164, 428] -> 
             RGBColor[0.718755, 0.777397, 0.9308745], 
             UndirectedEdge[143, 325] -> 
             RGBColor[
              0.9326321666666667, 0.7550380000000002, 0.5027116666666668], 
             UndirectedEdge[101, 498] -> 
             RGBColor[
              0.7737441666666667, 0.7867893333333333, 0.6453846666666667], 
             UndirectedEdge[35, 391] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[8, 221] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[240, 251] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[464, 485] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[104, 452] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[121, 475] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[168, 315] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[65, 320] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685095], 
             UndirectedEdge[323, 452] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[72, 322] -> 
             RGBColor[0.9452905, 0.8791816666666668, 0.617958], 
             UndirectedEdge[60, 327] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[1, 135] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[420, 439] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[134, 367] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[119, 345] -> 
             RGBColor[
              0.9186063333333334, 0.6655183333333337, 0.3079116666666667], 
             UndirectedEdge[64, 366] -> 
             RGBColor[
              0.6404563333333333, 0.7180833333333334, 0.9654583333333333], 
             UndirectedEdge[86, 90] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[81, 426] -> 
             RGBColor[0.674261, 0.7371853333333334, 0.8665405000000002], 
             UndirectedEdge[70, 265] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[245, 438] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[121, 259] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[74, 105] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[358, 430] -> 
             RGBColor[0.9442094999999999, 0.822865, 0.57672], 
             UndirectedEdge[43, 316] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[162, 203] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[226, 236] -> 
             RGBColor[
              0.8709184999999999, 0.6327363333333336, 0.5902486666666666], 
             UndirectedEdge[110, 340] -> 
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667], 
             UndirectedEdge[145, 407] -> 
             RGBColor[
              0.7265121666666667, 0.5943326666666668, 0.5881671666666668], 
             UndirectedEdge[258, 289] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[13, 334] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[300, 389] -> 
             RGBColor[0.8621055000000001, 0.758648, 0.6122445000000001], 
             UndirectedEdge[57, 363] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[305, 427] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[277, 419] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[40, 349] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[28, 241] -> 
             RGBColor[
              0.9934293333333333, 0.9883543333333333, 0.5262016666666668], 
             UndirectedEdge[164, 396] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[111, 284] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[25, 343] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[84, 131] -> 
             RGBColor[
              0.7265121666666667, 0.5943326666666668, 0.5881671666666667], 
             UndirectedEdge[169, 244] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[219, 363] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[400, 415] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[248, 286] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[136, 484] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[74, 263] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[69, 142] -> 
             RGBColor[0.674261, 0.7371853333333334, 0.8665405000000002], 
             UndirectedEdge[109, 409] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[101, 219] -> 
             RGBColor[
              0.9798641666666666, 0.9474946666666667, 0.5599291666666668], 
             UndirectedEdge[380, 390] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[53, 293] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[221, 258] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[235, 424] -> 
             RGBColor[
              0.7607756666666667, 0.8130430000000001, 0.9767906666666666], 
             UndirectedEdge[367, 457] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[58, 220] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[334, 379] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[14, 163] -> 
             RGBColor[0.628988, 0.6913661666666667, 0.6819028333333333], 
             UndirectedEdge[284, 442] -> 
             RGBColor[
              0.8793508333333335, 0.8270200000000001, 0.6261205000000001], 
             UndirectedEdge[130, 302] -> 
             RGBColor[0.8845911666666666, 0.5488736666666667, 0.5652925], 
             UndirectedEdge[65, 428] -> 
             RGBColor[0.718755, 0.777397, 0.9308745], 
             UndirectedEdge[388, 487] -> 
             RGBColor[0.948365, 0.8221860000000001, 0.3335865], 
             UndirectedEdge[456, 458] -> 
             RGBColor[
              0.6404563333333333, 0.7180833333333334, 0.9654583333333333], 
             UndirectedEdge[281, 465] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[166, 428] -> 
             RGBColor[0.718755, 0.777397, 0.9308745], UndirectedEdge[92, 128] -> 
             RGBColor[0.936185, 0.7811, 0.2862695], UndirectedEdge[120, 457] -> 
             RGBColor[
              0.7265121666666667, 0.5943326666666668, 0.5881671666666668], 
             UndirectedEdge[79, 329] -> 
             RGBColor[
              0.9934293333333333, 0.9883543333333333, 0.5262016666666668], 
             UndirectedEdge[105, 195] -> 
             RGBColor[
              0.8709184999999999, 0.6327363333333336, 0.5902486666666666], 
             UndirectedEdge[98, 377] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[21, 309] -> 
             RGBColor[
              0.9044521666666667, 0.5624576666666667, 0.47666716666666675`], 
             UndirectedEdge[93, 322] -> 
             RGBColor[
              0.8793508333333335, 0.8270200000000001, 0.6261205000000001], 
             UndirectedEdge[8, 115] -> 
             RGBColor[
              0.6404563333333333, 0.7180833333333334, 0.9654583333333333], 
             UndirectedEdge[54, 131] -> 
             RGBColor[
              0.7876231666666668, 0.6430383333333336, 0.5935981666666666], 
             UndirectedEdge[186, 212] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[252, 467] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[244, 378] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[55, 339] -> 
             RGBColor[
              0.7737441666666667, 0.7867893333333333, 0.6453846666666667], 
             UndirectedEdge[69, 490] -> 
             RGBColor[
              0.6705643333333333, 0.7356566666666666, 0.9278038333333334], 
             UndirectedEdge[299, 451] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[146, 464] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[199, 220] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[345, 426] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[66, 472] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[40, 114] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[248, 294] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[304, 483] -> 
             RGBColor[0.9330910000000001, 0.7528303333333335, 0.3208415], 
             UndirectedEdge[9, 425] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[290, 384] -> 
             RGBColor[0.7120275, 0.5070206666666669, 0.5752373333333334], 
             UndirectedEdge[294, 358] -> 
             RGBColor[0.8621055000000001, 0.758648, 0.6122445000000001], 
             UndirectedEdge[148, 342] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[178, 420] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[193, 354] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[194, 228] -> 
             RGBColor[0.9326351666666666, 0.912505, 0.660396], 
             UndirectedEdge[326, 491] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[324, 481] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[94, 213] -> 
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666], 
             UndirectedEdge[92, 175] -> 
             RGBColor[0.9326351666666666, 0.912505, 0.660396], 
             UndirectedEdge[254, 401] -> 
             RGBColor[0.9761675, 0.9459660000000001, 0.6211925], 
             UndirectedEdge[161, 491] -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             UndirectedEdge[172, 303] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[57, 274] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[44, 360] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[170, 238] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[5, 11] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[3, 223] -> 
             RGBColor[0.9006771666666666, 0.789404, 0.6159235000000001], 
             UndirectedEdge[65, 227] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[78, 85] -> 
             RGBColor[0.8940635000000001, 0.8817490000000001, 0.656717], 
             UndirectedEdge[181, 393] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[45, 56] -> 
             RGBColor[0.5815595, 0.6465624999999999, 0.922572], 
             UndirectedEdge[141, 310] -> 
             RGBColor[0.9280451666666667, 0.8108096666666667, 0.604082], 
             UndirectedEdge[39, 236] -> 
             RGBColor[0.9181475, 0.6677260000000003, 0.48978183333333347`], 
             UndirectedEdge[337, 375] -> 
             RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             UndirectedEdge[57, 334] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[123, 438] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[35, 385] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[268, 285] -> 
             RGBColor[
              0.7607756666666667, 0.8130430000000001, 0.9767906666666666], 
             UndirectedEdge[169, 361] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[337, 361] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[119, 270] -> 
             RGBColor[
              0.8447096666666667, 0.3446636666666671, 0.19044733333333339`], 
             UndirectedEdge[254, 386] -> 
             RGBColor[
              0.7737441666666667, 0.7867893333333333, 0.6453846666666667], 
             UndirectedEdge[253, 488] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[340, 380] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[388, 490] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685095], 
             UndirectedEdge[27, 311] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[222, 417] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[274, 361] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[65, 474] -> 
             RGBColor[
              0.6705643333333333, 0.7356566666666666, 0.9278038333333334], 
             UndirectedEdge[243, 326] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[47, 437] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[232, 414] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[102, 196] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[90, 257] -> 
             RGBColor[0.9179225, 0.8577760000000001, 0.6297995000000001], 
             UndirectedEdge[116, 310] -> 
             RGBColor[0.9280451666666667, 0.8108096666666667, 0.604082], 
             UndirectedEdge[333, 459] -> 
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667], 
             UndirectedEdge[68, 257] -> 
             RGBColor[
              0.9665366666666667, 0.8925393333333335, 0.4482881666666668], 
             UndirectedEdge[220, 349] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[92, 204] -> 
             RGBColor[
              0.9798641666666666, 0.9474946666666667, 0.5599291666666668], 
             UndirectedEdge[120, 123] -> 
             RGBColor[0.9127711666666667, 0.7414540000000002, 0.591337], 
             UndirectedEdge[190, 224] -> 
             RGBColor[0.992503, 0.986373, 0.425376], UndirectedEdge[450, 469] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[405, 434] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[312, 400] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[100, 259] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[87, 423] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[403, 449] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[268, 275] -> 
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334], 
             UndirectedEdge[166, 210] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[102, 496] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[11, 202] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[187, 494] -> 
             RGBColor[0.9280451666666667, 0.8108096666666667, 0.604082], 
             UndirectedEdge[158, 282] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[232, 372] -> 
             RGBColor[0.8186515000000001, 0.49671200000000004`, 0.573455], 
             UndirectedEdge[143, 477] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[479, 482] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[45, 283] -> 
             RGBColor[
              0.5653951666666666, 0.6345071666666666, 0.9499340000000001], 
             UndirectedEdge[323, 463] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[130, 347] -> 
             RGBColor[0.8186515000000001, 0.49671200000000004`, 0.573455], 
             UndirectedEdge[338, 369] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[143, 386] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[168, 254] -> 
             RGBColor[
              0.7737441666666667, 0.7867893333333333, 0.6453846666666667], 
             UndirectedEdge[86, 115] -> 
             RGBColor[
              0.7868504999999999, 0.8298566666666667, 0.7935273333333335], 
             UndirectedEdge[138, 457] -> 
             RGBColor[
              0.7859241666666666, 0.8278753333333333, 0.6927016666666667], 
             UndirectedEdge[11, 497] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[154, 379] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[17, 467] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[75, 93] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[100, 315] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[45, 52] -> 
             RGBColor[
              0.2679318333333333, 0.39448816666666664`, 0.9387328333333333], 
             UndirectedEdge[8, 203] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[244, 340] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[104, 190] -> 
             RGBColor[0.992503, 0.986373, 0.425376], UndirectedEdge[38, 437] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[96, 465] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[48, 346] -> 
             RGBColor[
              0.9934293333333333, 0.9883543333333333, 0.5262016666666668], 
             UndirectedEdge[153, 342] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[151, 327] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[375, 489] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[203, 289] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[6, 79] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[105, 463] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[10, 125] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[32, 331] -> 
             RGBColor[0.9326351666666666, 0.912505, 0.660396], 
             UndirectedEdge[26, 44] -> 
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334], 
             UndirectedEdge[86, 253] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[370, 466] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[301, 456] -> 
             RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             UndirectedEdge[21, 337] -> 
             RGBColor[
              0.6983321666666666, 0.4017523333333333, 0.5621226666666667], 
             UndirectedEdge[61, 172] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[291, 359] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[134, 499] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[140, 244] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[108, 364] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[113, 421] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[54, 55] -> 
             RGBColor[
              0.8348551666666667, 0.8354950000000001, 0.6508156666666667], 
             UndirectedEdge[56, 210] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[36, 58] -> 
             RGBColor[
              0.7025906666666666, 0.7653416666666666, 0.9582364999999999], 
             UndirectedEdge[25, 288] -> 
             RGBColor[0.9127711666666667, 0.7414540000000002, 0.591337], 
             UndirectedEdge[262, 344] -> 
             RGBColor[
              0.9340173333333334, 0.7548116666666669, 0.4216671666666668], 
             UndirectedEdge[8, 439] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[102, 186] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[85, 145] -> 
             RGBColor[0.920911, 0.7117443333333335, 0.27352450000000006`], 
             UndirectedEdge[421, 423] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[406, 476] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[111, 400] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[137, 183] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[85, 358] -> RGBColor[0.936185, 0.7811, 0.2862695],
              UndirectedEdge[399, 412] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[283, 292] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[240, 310] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[186, 300] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[37, 240] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[36, 429] -> 
             RGBColor[0.718755, 0.777397, 0.9308745], UndirectedEdge[56, 276] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[95, 174] -> 
             RGBColor[0.8186515000000001, 0.49671200000000004`, 0.573455], 
             UndirectedEdge[7, 28] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[251, 367] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[31, 314] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[238, 436] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[291, 488] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[96, 171] -> 
             RGBColor[
              0.6404563333333333, 0.7180833333333334, 0.9654583333333333], 
             UndirectedEdge[127, 179] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[296, 453] -> 
             RGBColor[0.7120275, 0.5070206666666669, 0.5752373333333334], 
             UndirectedEdge[14, 494] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[317, 420] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[7, 388] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[146, 271] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[331, 449] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[27, 359] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[100, 471] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[219, 337] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[199, 419] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[266, 437] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[327, 399] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[311, 419] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[267, 329] -> 
             RGBColor[
              0.7238368333333334, 0.7786993333333334, 0.7885666666666669], 
             UndirectedEdge[219, 244] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[17, 205] -> 
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333], 
             UndirectedEdge[175, 361] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[189, 266] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[225, 280] -> 
             RGBColor[0.9656103333333335, 0.8905580000000002, 0.3474625], 
             UndirectedEdge[300, 458] -> 
             RGBColor[
              0.7607756666666667, 0.8130430000000001, 0.9767906666666666], 
             UndirectedEdge[171, 343] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[358, 408] -> 
             RGBColor[0.8621055000000001, 0.758648, 0.6122445], 
             UndirectedEdge[380, 411] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[345, 498] -> 
             RGBColor[
              0.7859241666666666, 0.8278753333333333, 0.6927016666666667], 
             UndirectedEdge[161, 450] -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             UndirectedEdge[94, 214] -> 
             RGBColor[
              0.9934293333333333, 0.9883543333333333, 0.5262016666666668], 
             UndirectedEdge[157, 343] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[155, 332] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[127, 168] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[378, 380] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[160, 481] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[23, 485] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[352, 399] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[389, 456] -> 
             RGBColor[
              0.7417861666666666, 0.6636883333333333, 0.6009121666666667], 
             UndirectedEdge[105, 263] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[143, 347] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[98, 484] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[100, 500] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[89, 424] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[231, 442] -> 
             RGBColor[0.9614548333333334, 0.8912370000000001, 0.590596], 
             UndirectedEdge[15, 104] -> 
             RGBColor[0.980323, 0.945287, 0.378059], UndirectedEdge[75, 182] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[290, 316] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[344, 424] -> 
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334], 
             UndirectedEdge[369, 425] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[106, 255] -> 
             RGBColor[
              0.9479061666666666, 0.8243936666666667, 0.5154566666666668], 
             UndirectedEdge[84, 242] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[143, 446] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[376, 415] -> 
             RGBColor[
              0.9934293333333333, 0.9883543333333333, 0.5262016666666668], 
             UndirectedEdge[93, 108] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[78, 183] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[17, 298] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[204, 370] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[208, 314] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[313, 379] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[3, 221] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[154, 229] -> 
             RGBColor[
              0.9492913333333333, 0.8241673333333334, 0.4344121666666668], 
             UndirectedEdge[25, 180] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[371, 419] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[31, 419] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[321, 482] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[212, 300] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[376, 414] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[140, 274] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[1, 131] -> 
             RGBColor[0.9289355, 0.7535093333333336, 0.563975], 
             UndirectedEdge[360, 466] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[165, 182] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[268, 480] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[54, 385] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[149, 158] -> 
             RGBColor[0.904911, 0.56025, 0.294797], UndirectedEdge[229, 379] -> 
             RGBColor[
              0.9479061666666666, 0.8243936666666667, 0.5154566666666668], 
             UndirectedEdge[98, 253] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[121, 469] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[34, 269] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[145, 286] -> 
             RGBColor[0.9127711666666667, 0.7414540000000002, 0.591337], 
             UndirectedEdge[34, 234] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[85, 286] -> 
             RGBColor[
              0.9600031666666666, 0.9339106666666667, 0.6485544999999999], 
             UndirectedEdge[86, 261] -> 
             RGBColor[
              0.9934293333333333, 0.9883543333333333, 0.5262016666666668], 
             UndirectedEdge[140, 255] -> 
             RGBColor[
              0.9479061666666666, 0.8243936666666667, 0.5154566666666668], 
             UndirectedEdge[345, 448] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[146, 444] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[215, 224] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[40, 359] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[88, 495] -> 
             RGBColor[
              0.6270319999999999, 0.7021956666666667, 0.9670073333333333], 
             UndirectedEdge[341, 403] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[134, 416] -> 
             RGBColor[
              0.5653951666666667, 0.6345071666666666, 0.9499340000000001], 
             UndirectedEdge[113, 423] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[204, 362] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[231, 256] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[183, 407] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[231, 271] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[106, 140] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[96, 147] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[149, 275] -> 
             RGBColor[
              0.9058373333333334, 0.5622313333333333, 0.3956226666666668], 
             UndirectedEdge[207, 287] -> 
             RGBColor[
              0.7868504999999999, 0.8298566666666667, 0.7935273333333335], 
             UndirectedEdge[223, 480] -> 
             RGBColor[0.9006771666666666, 0.789404, 0.6159235], 
             UndirectedEdge[11, 102] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[230, 339] -> 
             RGBColor[
              0.5163316666666666, 0.6182203333333334, 0.9550666666666667], 
             UndirectedEdge[103, 449] -> 
             RGBColor[
              0.9144508333333333, 0.6661973333333335, 0.5510451666666667], 
             UndirectedEdge[226, 396] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[144, 279] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[205, 228] -> 
             RGBColor[
              0.8348551666666667, 0.8354950000000001, 0.6508156666666667], 
             UndirectedEdge[267, 406] -> 
             RGBColor[
              0.7224516666666667, 0.7789256666666666, 0.8696111666666668], 
             UndirectedEdge[209, 233] -> 
             RGBColor[
              0.6305818333333333, 0.5707906666666667, 0.5928808333333333], 
             UndirectedEdge[387, 405] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[75, 206] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[183, 404] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[319, 488] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[220, 371] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[66, 460] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[87, 446] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[273, 308] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[326, 428] -> 
             RGBColor[0.718755, 0.777397, 0.9308745], 
             UndirectedEdge[130, 315] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[95, 407] -> 
             RGBColor[
              0.6983321666666666, 0.4017523333333333, 0.5621226666666667], 
             UndirectedEdge[148, 153] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[85, 137] -> 
             RGBColor[0.9761675, 0.9459660000000001, 0.6211925], 
             UndirectedEdge[289, 359] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[32, 449] -> 
             RGBColor[0.9761675, 0.9459660000000001, 0.6211925], 
             UndirectedEdge[329, 406] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[168, 213] -> 
             RGBColor[
              0.6404563333333333, 0.7180833333333334, 0.9654583333333333], 
             UndirectedEdge[111, 464] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[50, 117] -> 
             RGBColor[
              0.6404563333333333, 0.7180833333333334, 0.9654583333333333], 
             UndirectedEdge[357, 420] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[153, 190] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685095], 
             UndirectedEdge[165, 275] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[152, 301] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[208, 349] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[5, 23] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[56, 227] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[56, 326] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[155, 181] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[148, 323] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[177, 438] -> 
             RGBColor[0.6752226666666666, 0.7439359999999999, 0.970078], 
             UndirectedEdge[53, 90] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[30, 217] -> 
             RGBColor[0.7594431666666668, 0.450458, 0.5675536666666666], 
             UndirectedEdge[43, 290] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[114, 397] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[227, 320] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[298, 432] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[42, 85] -> 
             RGBColor[0.9761675, 0.9459660000000001, 0.6211925], 
             UndirectedEdge[329, 413] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[244, 380] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[87, 113] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[334, 370] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[24, 278] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[51, 325] -> 
             RGBColor[
              0.8468315000000002, 0.6892923333333336, 0.5994995000000001], 
             UndirectedEdge[112, 463] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[308, 421] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[302, 421] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[103, 488] -> 
             RGBColor[
              0.9144508333333333, 0.6661973333333335, 0.5510451666666667], 
             UndirectedEdge[225, 424] -> 
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666], 
             UndirectedEdge[205, 388] -> 
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666], 
             UndirectedEdge[114, 297] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[203, 381] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[17, 252] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[361, 363] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[318, 383] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[209, 273] -> 
             RGBColor[
              0.9479061666666666, 0.8243936666666667, 0.5154566666666668], 
             UndirectedEdge[47, 230] -> 
             RGBColor[0.6752226666666666, 0.7439359999999999, 0.970078], 
             UndirectedEdge[1, 170] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[139, 247] -> 
             RGBColor[0.8621055000000001, 0.758648, 0.6122445], 
             UndirectedEdge[246, 288] -> 
             RGBColor[
              0.8889530000000001, 0.5886433333333335, 0.22905200000000003`], 
             UndirectedEdge[1, 147] -> RGBColor[0.984192, 0.987731, 0.911643],
              UndirectedEdge[352, 457] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[157, 238] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[97, 145] -> 
             RGBColor[
              0.8889530000000001, 0.5886433333333335, 0.22905200000000003`], 
             UndirectedEdge[83, 237] -> 
             RGBColor[
              0.6705643333333333, 0.7356566666666666, 0.9278038333333334], 
             UndirectedEdge[73, 494] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[101, 197] -> 
             RGBColor[0.8940635000000001, 0.8817490000000001, 0.656717], 
             UndirectedEdge[224, 356] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[182, 441] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[160, 480] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[263, 440] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[31, 223] -> 
             RGBColor[0.9006771666666666, 0.789404, 0.6159235000000001], 
             UndirectedEdge[5, 102] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[171, 216] -> 
             RGBColor[0.8028971666666667, 0.712394, 0.6063431666666667], 
             UndirectedEdge[102, 414] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[68, 205] -> 
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334], 
             UndirectedEdge[111, 376] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[302, 325] -> 
             RGBColor[0.9127711666666667, 0.7414540000000002, 0.591337], 
             UndirectedEdge[39, 315] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[66, 314] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[274, 370] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[94, 477] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[99, 329] -> 
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334], 
             UndirectedEdge[25, 465] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[223, 381] -> 
             RGBColor[0.9280451666666667, 0.8108096666666667, 0.604082], 
             UndirectedEdge[196, 318] -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             UndirectedEdge[76, 462] -> 
             RGBColor[0.8940635000000001, 0.8817490000000001, 0.656717], 
             UndirectedEdge[89, 440] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[88, 326] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[149, 282] -> 
             RGBColor[0.8572231666666666, 0.527468, 0.577134], 
             UndirectedEdge[238, 462] -> 
             RGBColor[
              0.9798641666666666, 0.9474946666666667, 0.5599291666666668], 
             UndirectedEdge[168, 261] -> 
             RGBColor[
              0.7859241666666666, 0.8278753333333333, 0.6927016666666667], 
             UndirectedEdge[155, 344] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[4, 496] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[87, 226] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[128, 362] -> 
             RGBColor[
              0.9492913333333333, 0.8241673333333334, 0.4344121666666668], 
             UndirectedEdge[295, 389] -> 
             RGBColor[0.8028971666666667, 0.712394, 0.6063431666666667], 
             UndirectedEdge[89, 133] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[33, 164] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[276, 396] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[50, 274] -> 
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666], 
             UndirectedEdge[21, 375] -> 
             RGBColor[
              0.6983321666666666, 0.4017523333333333, 0.5621226666666667], 
             UndirectedEdge[41, 485] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[30, 316] -> 
             RGBColor[0.8845911666666666, 0.5488736666666667, 0.5652925], 
             UndirectedEdge[285, 324] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[95, 358] -> 
             RGBColor[0.860773, 0.396063, 0.2030075], 
             UndirectedEdge[333, 492] -> 
             RGBColor[
              0.7731385000000001, 0.5557263333333335, 0.5806683333333333], 
             UndirectedEdge[332, 393] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[418, 420] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[107, 273] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[310, 483] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[155, 403] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[140, 169] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[147, 216] -> 
             RGBColor[0.9442094999999999, 0.822865, 0.57672], 
             UndirectedEdge[70, 171] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[7, 402] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[185, 409] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[126, 481] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[115, 311] -> 
             RGBColor[
              0.7868504999999999, 0.8298566666666667, 0.7935273333333335], 
             UndirectedEdge[383, 496] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[8, 297] -> 
             RGBColor[
              0.6404563333333333, 0.7180833333333334, 0.9654583333333333], 
             UndirectedEdge[381, 439] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[16, 276] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[74, 342] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[26, 269] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[127, 315] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[175, 348] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[180, 288] -> 
             RGBColor[
              0.9340173333333334, 0.7548116666666669, 0.4216671666666668], 
             UndirectedEdge[288, 343] -> 
             RGBColor[0.9127711666666667, 0.7414540000000002, 0.591337], 
             UndirectedEdge[484, 500] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[59, 323] -> 
             RGBColor[
              0.8709184999999999, 0.6327363333333336, 0.5902486666666666], 
             UndirectedEdge[108, 189] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[59, 74] -> 
             RGBColor[
              0.9144508333333333, 0.6661973333333335, 0.5510451666666667], 
             UndirectedEdge[40, 199] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[69, 241] -> 
             RGBColor[
              0.6747198333333333, 0.7349776666666668, 0.6846703333333333], 
             UndirectedEdge[275, 353] -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             UndirectedEdge[196, 335] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[157, 281] -> 
             RGBColor[
              0.6404563333333333, 0.7180833333333334, 0.9654583333333333], 
             UndirectedEdge[120, 438] -> 
             RGBColor[
              0.8854031666666666, 0.7200483333333335, 0.6031785000000001], 
             UndirectedEdge[152, 389] -> 
             RGBColor[0.9442094999999999, 0.822865, 0.57672], 
             UndirectedEdge[126, 144] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[96, 157] -> 
             RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             UndirectedEdge[303, 366] -> 
             RGBColor[
              0.7868504999999999, 0.8298566666666667, 0.7935273333333335], 
             UndirectedEdge[119, 309] -> 
             RGBColor[0.9181475, 0.6677260000000003, 0.48978183333333347`], 
             UndirectedEdge[325, 386] -> 
             RGBColor[
              0.7265121666666667, 0.5943326666666668, 0.5881671666666668], 
             UndirectedEdge[27, 220] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[95, 346] -> 
             RGBColor[
              0.9058373333333334, 0.5622313333333333, 0.3956226666666668], 
             UndirectedEdge[235, 239] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[64, 303] -> 
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334], 
             UndirectedEdge[310, 429] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[67, 238] -> 
             RGBColor[
              0.9798641666666666, 0.9474946666666667, 0.5599291666666668], 
             UndirectedEdge[38, 108] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[20, 490] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[112, 148] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[76, 402] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[99, 406] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[8, 258] -> 
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333], 
             UndirectedEdge[15, 153] -> 
             RGBColor[0.9761675, 0.9459660000000001, 0.6211925], 
             UndirectedEdge[195, 463] -> 
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667], 
             UndirectedEdge[184, 249] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[109, 185] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[77, 81] -> 
             RGBColor[0.4681409999999999, 0.57648, 0.9519960000000001], 
             UndirectedEdge[355, 384] -> 
             RGBColor[
              0.6490138333333333, 0.4558633333333335, 0.5702766666666668], 
             UndirectedEdge[67, 343] -> 
             RGBColor[
              0.9600031666666666, 0.9339106666666667, 0.6485544999999999], 
             UndirectedEdge[247, 255] -> 
             RGBColor[0.8621055000000001, 0.758648, 0.6122445000000001], 
             UndirectedEdge[95, 145] -> 
             RGBColor[0.845499, 0.3267073333333335, 0.19026250000000006`], 
             UndirectedEdge[220, 416] -> 
             RGBColor[
              0.5852561666666667, 0.6480911666666667, 0.8613086666666667], 
             UndirectedEdge[287, 451] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[387, 491] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[211, 464] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[335, 482] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[214, 423] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[69, 194] -> 
             RGBColor[0.627032, 0.7021956666666667, 0.9670073333333333], 
             UndirectedEdge[111, 312] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[174, 294] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[212, 295] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[193, 414] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[320, 348] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[247, 468] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[449, 488] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[290, 355] -> 
             RGBColor[
              0.5163316666666666, 0.6182203333333334, 0.9550666666666667], 
             UndirectedEdge[88, 469] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[6, 278] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[24, 448] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[204, 274] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[81, 99] -> 
             RGBColor[0.5292520000000001, 0.6251856666666666, 0.957427], 
             UndirectedEdge[213, 368] -> 
             RGBColor[0.5292520000000001, 0.6251856666666666, 0.957427], 
             UndirectedEdge[167, 474] -> 
             RGBColor[
              0.6705643333333333, 0.7356566666666666, 0.9278038333333334], 
             UndirectedEdge[78, 430] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[110, 316] -> 
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667], 
             UndirectedEdge[153, 463] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[471, 475] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[79, 486] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[49, 402] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[340, 498] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[248, 313] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[37, 429] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[18, 166] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[147, 238] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[165, 441] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[13, 154] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[133, 249] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[84, 385] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[125, 438] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[21, 489] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[16, 200] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[402, 436] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[127, 401] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[195, 395] -> 
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667], 
             UndirectedEdge[27, 297] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[35, 70] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[240, 367] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[121, 471] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[184, 424] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[122, 159] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[158, 324] -> 
             RGBColor[
              0.9934293333333333, 0.9883543333333333, 0.5262016666666668], 
             UndirectedEdge[180, 465] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[254, 454] -> 
             RGBColor[
              0.9600031666666666, 0.9339106666666667, 0.6485544999999999], 
             UndirectedEdge[297, 314] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[262, 393] -> 
             RGBColor[
              0.8854031666666666, 0.7200483333333335, 0.6031785000000001], 
             UndirectedEdge[201, 333] -> 
             RGBColor[
              0.8323468333333335, 0.6019803333333336, 0.5865696666666667], 
             UndirectedEdge[219, 340] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[361, 370] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[48, 358] -> 
             RGBColor[0.948365, 0.8221860000000001, 0.3335865], 
             UndirectedEdge[287, 299] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[62, 233] -> 
             RGBColor[
              0.5884603333333334, 0.6714396666666667, 0.9633283333333333], 
             UndirectedEdge[61, 91] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[204, 340] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[258, 373] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[167, 210] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[275, 481] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[253, 277] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[193, 485] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[89, 260] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[359, 397] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[1, 171] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[193, 330] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[92, 320] -> 
             RGBColor[0.980323, 0.945287, 0.378059], UndirectedEdge[126, 279] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[93, 163] -> 
             RGBColor[
              0.5427285000000001, 0.6278281666666667, 0.9605608333333333], 
             UndirectedEdge[31, 297] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[127, 325] -> 
             RGBColor[
              0.9326321666666667, 0.7550380000000002, 0.5027116666666668], 
             UndirectedEdge[334, 498] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[41, 300] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[330, 496] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[18, 227] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[156, 350] -> 
             RGBColor[
              0.9340173333333334, 0.7548116666666669, 0.4216671666666668], 
             UndirectedEdge[315, 386] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[29, 479] -> 
             RGBColor[0.9181475, 0.6677260000000003, 0.48978183333333347`], 
             UndirectedEdge[277, 488] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[242, 374] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[244, 363] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[335, 409] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[235, 332] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[249, 440] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[96, 265] -> 
             RGBColor[
              0.7868504999999999, 0.8298566666666667, 0.7935273333333335], 
             UndirectedEdge[39, 200] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[146, 312] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[237, 448] -> 
             RGBColor[0.674261, 0.7371853333333334, 0.8665405000000002], 
             UndirectedEdge[31, 162] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[41, 102] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[266, 374] -> 
             RGBColor[
              0.6983321666666666, 0.4017523333333333, 0.5621226666666667], 
             UndirectedEdge[44, 139] -> 
             RGBColor[0.8028971666666667, 0.712394, 0.6063431666666667], 
             UndirectedEdge[47, 189] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[208, 359] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[122, 413] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[36, 141] -> 
             RGBColor[0.6787725, 0.6125309999999999, 0.5959515], 
             UndirectedEdge[179, 347] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[226, 422] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[18, 167] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[112, 452] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[323, 342] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[74, 82] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[291, 349] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[86, 136] -> 
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334], 
             UndirectedEdge[11, 23] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[249, 470] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[35, 135] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[161, 326] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[26, 139] -> 
             RGBColor[
              0.9492913333333333, 0.8241673333333334, 0.4344121666666668], 
             UndirectedEdge[109, 218] -> 
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334], 
             UndirectedEdge[238, 465] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[258, 314] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[28, 493] -> 
             RGBColor[
              0.9934293333333333, 0.9883543333333333, 0.5262016666666668], 
             UndirectedEdge[106, 466] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[45, 236] -> 
             RGBColor[
              0.5118183333333333, 0.32502883333333354`, 0.5619741666666667], 
             UndirectedEdge[157, 246] -> 
             RGBColor[
              0.7417861666666666, 0.6636883333333333, 0.6009121666666667], 
             UndirectedEdge[371, 427] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[341, 450] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[277, 484] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[84, 135] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[35, 84] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[68, 272] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[164, 227] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[355, 498] -> 
             RGBColor[
              0.5163316666666666, 0.6182203333333334, 0.9550666666666667], 
             UndirectedEdge[223, 373] -> 
             RGBColor[0.9006771666666666, 0.789404, 0.6159235], 
             UndirectedEdge[116, 192] -> 
             RGBColor[0.9006771666666666, 0.789404, 0.6159235], 
             UndirectedEdge[3, 31] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[40, 419] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[282, 324] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[250, 339] -> 
             RGBColor[
              0.6404563333333333, 0.7180833333333334, 0.9654583333333333], 
             UndirectedEdge[259, 405] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[22, 441] -> 
             RGBColor[
              0.9934293333333333, 0.9883543333333333, 0.5262016666666668], 
             UndirectedEdge[142, 241] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[170, 266] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[105, 153] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[95, 404] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[200, 454] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[96, 131] -> 
             RGBColor[
              0.7265121666666667, 0.5943326666666668, 0.5881671666666667], 
             UndirectedEdge[190, 395] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[297, 381] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[203, 419] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[107, 209] -> 
             RGBColor[0.9280451666666667, 0.8108096666666667, 0.604082], 
             UndirectedEdge[205, 252] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[98, 488] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[182, 275] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[88, 474] -> 
             RGBColor[
              0.6270319999999999, 0.7021956666666667, 0.9670073333333333], 
             UndirectedEdge[47, 242] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[133, 262] -> 
             RGBColor[0.9127711666666667, 0.7414540000000002, 0.591337], 
             UndirectedEdge[4, 321] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[369, 370] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[49, 436] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[34, 393] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[268, 324] -> 
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334], 
             UndirectedEdge[359, 371] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[296, 440] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[113, 143] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[270, 489] -> 
             RGBColor[
              0.9144508333333333, 0.6661973333333335, 0.5510451666666667], 
             UndirectedEdge[237, 426] -> 
             RGBColor[0.674261, 0.7371853333333334, 0.8665405000000002], 
             UndirectedEdge[131, 385] -> 
             RGBColor[0.9127711666666667, 0.7414540000000002, 0.591337], 
             UndirectedEdge[427, 499] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[45, 243] -> 
             RGBColor[0.4994555000000001, 0.5823455, 0.9580965], 
             UndirectedEdge[33, 443] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[232, 330] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[19, 360] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[44, 370] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[310, 412] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[107, 214] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[268, 481] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[224, 351] -> 
             RGBColor[0.992503, 0.986373, 0.425376], UndirectedEdge[78, 408] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[124, 136] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[51, 315] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[24, 270] -> 
             RGBColor[0.9181475, 0.6677260000000003, 0.48978183333333347`], 
             UndirectedEdge[43, 340] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[116, 483] -> 
             RGBColor[0.948365, 0.8221860000000001, 0.3335865], 
             UndirectedEdge[50, 169] -> 
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333], 
             UndirectedEdge[247, 369] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[327, 412] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[134, 305] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[7, 49] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[81, 486] -> 
             RGBColor[0.674261, 0.7371853333333334, 0.8665405000000002], 
             UndirectedEdge[110, 384] -> 
             RGBColor[
              0.8447096666666667, 0.3446636666666671, 0.19044733333333339`], 
             UndirectedEdge[18, 88] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[11, 41] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[231, 288] -> 
             RGBColor[0.9289355, 0.7535093333333336, 0.563975], 
             UndirectedEdge[236, 396] -> 
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667], 
             UndirectedEdge[46, 418] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[74, 447] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[270, 426] -> 
             RGBColor[0.9181475, 0.6677260000000003, 0.48978183333333347`], 
             UndirectedEdge[383, 479] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[408, 430] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[13, 390] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685095], 
             UndirectedEdge[15, 97] -> RGBColor[0.936185, 0.7811, 0.2862695], 
             UndirectedEdge[289, 472] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[254, 315] -> 
             RGBColor[0.9761675, 0.9459660000000001, 0.6211925], 
             UndirectedEdge[347, 386] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[66, 445] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[127, 213] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[423, 446] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[63, 410] -> 
             RGBColor[
              0.6404563333333333, 0.7180833333333334, 0.9654583333333333], 
             UndirectedEdge[107, 421] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[226, 308] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[51, 386] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[89, 470] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[205, 490] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[270, 345] -> 
             RGBColor[
              0.9186063333333334, 0.6655183333333337, 0.3079116666666667], 
             UndirectedEdge[152, 191] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[85, 404] -> 
             RGBColor[0.9761675, 0.9459660000000001, 0.6211925], 
             UndirectedEdge[26, 468] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[191, 301] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[375, 426] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[39, 213] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[360, 468] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[80, 278] -> 
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333], 
             UndirectedEdge[152, 299] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[227, 309] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[98, 115] -> 
             RGBColor[
              0.7868504999999999, 0.8298566666666667, 0.7935273333333335], 
             UndirectedEdge[213, 261] -> 
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666], 
             UndirectedEdge[199, 208] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[204, 219] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[52, 166] -> 
             RGBColor[
              0.6705643333333333, 0.7356566666666666, 0.9278038333333334], 
             UndirectedEdge[218, 300] -> 
             RGBColor[
              0.7607756666666667, 0.8130430000000001, 0.9767906666666666], 
             UndirectedEdge[128, 345] -> 
             RGBColor[0.948365, 0.8221860000000001, 0.3335865], 
             UndirectedEdge[325, 421] -> 
             RGBColor[
              0.8854031666666666, 0.7200483333333335, 0.6031785000000001], 
             UndirectedEdge[257, 272] -> 
             RGBColor[0.9452905, 0.8791816666666668, 0.617958], 
             UndirectedEdge[461, 486] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[115, 203] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[128, 169] -> 
             RGBColor[0.8028971666666667, 0.712394, 0.6063431666666667], 
             UndirectedEdge[190, 356] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[46, 272] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[121, 450] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[255, 269] -> 
             RGBColor[0.9442094999999999, 0.822865, 0.57672], 
             UndirectedEdge[15, 356] -> 
             RGBColor[0.8940635000000001, 0.8817490000000001, 0.656717], 
             UndirectedEdge[85, 183] -> 
             RGBColor[0.9326351666666666, 0.912505, 0.660396], 
             UndirectedEdge[136, 261] -> 
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666], 
             UndirectedEdge[295, 336] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[259, 475] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[51, 143] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[53, 178] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[67, 385] -> 
             RGBColor[
              0.9600031666666666, 0.9339106666666667, 0.6485544999999999], 
             UndirectedEdge[69, 173] -> 
             RGBColor[0.5292520000000001, 0.6251856666666666, 0.957427], 
             UndirectedEdge[221, 381] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[140, 334] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[57, 370] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[432, 467] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[235, 440] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[229, 390] -> 
             RGBColor[0.948365, 0.8221860000000001, 0.3335865], 
             UndirectedEdge[12, 198] -> 
             RGBColor[0.9326351666666666, 0.912505, 0.660396], 
             UndirectedEdge[232, 400] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[143, 273] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[115, 277] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[44, 468] -> 
             RGBColor[
              0.7607756666666667, 0.8130430000000001, 0.9767906666666666], 
             UndirectedEdge[183, 346] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[434, 469] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[255, 334] -> 
             RGBColor[
              0.9479061666666666, 0.8243936666666667, 0.5154566666666668], 
             UndirectedEdge[65, 210] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[49, 76] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[74, 395] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[52, 88] -> 
             RGBColor[0.627032, 0.7021956666666667, 0.9670073333333333], 
             UndirectedEdge[312, 354] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[372, 417] -> 
             RGBColor[
              0.9044521666666667, 0.5624576666666667, 0.47666716666666675`], 
             UndirectedEdge[354, 415] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[301, 451] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[243, 428] -> 
             RGBColor[0.6366510000000001, 0.71318, 0.966399], 
             UndirectedEdge[102, 354] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[255, 369] -> 
             RGBColor[0.8621055000000001, 0.758648, 0.6122445], 
             UndirectedEdge[300, 409] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[93, 187] -> 
             RGBColor[0.8621055000000001, 0.758648, 0.6122445000000001], 
             UndirectedEdge[181, 332] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[195, 351] -> 
             RGBColor[
              0.9186063333333334, 0.6655183333333337, 0.3079116666666667], 
             UndirectedEdge[480, 481] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[47, 365] -> 
             RGBColor[
              0.6270319999999999, 0.7021956666666667, 0.9670073333333333], 
             UndirectedEdge[50, 370] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[122, 150] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[246, 256] -> 
             RGBColor[
              0.9479061666666666, 0.8243936666666667, 0.5154566666666668], 
             UndirectedEdge[63, 282] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[230, 391] -> 
             RGBColor[
              0.7025906666666666, 0.7653416666666666, 0.9582364999999999], 
             UndirectedEdge[312, 415] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[199, 397] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[129, 328] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[188, 304] -> 
             RGBColor[0.6634985, 0.5431753333333336, 0.5832065000000001], 
             UndirectedEdge[323, 395] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[49, 238] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[171, 385] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[117, 425] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[32, 103] -> 
             RGBColor[
              0.9064263333333333, 0.6244323333333336, 0.2605946666666667], 
             UndirectedEdge[131, 216] -> 
             RGBColor[
              0.8889530000000001, 0.5886433333333335, 0.22905200000000003`], 
             UndirectedEdge[65, 175] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[143, 226] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[234, 235] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[179, 386] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[267, 476] -> 
             RGBColor[
              0.7025906666666666, 0.7653416666666666, 0.9582364999999999], 
             UndirectedEdge[59, 195] -> 
             RGBColor[
              0.8447096666666667, 0.3446636666666671, 0.19044733333333339`], 
             UndirectedEdge[75, 108] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[334, 363] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[77, 329] -> 
             RGBColor[
              0.7868504999999999, 0.8298566666666667, 0.7935273333333335], 
             UndirectedEdge[328, 462] -> 
             RGBColor[0.9326351666666666, 0.912505, 0.660396], 
             UndirectedEdge[285, 480] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[204, 334] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[70, 238] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[83, 270] -> 
             RGBColor[
              0.9144508333333333, 0.6661973333333335, 0.5510451666666667], 
             UndirectedEdge[112, 190] -> 
             RGBColor[
              0.7859241666666666, 0.8278753333333333, 0.6927016666666667], 
             UndirectedEdge[263, 453] -> 
             RGBColor[0.9181475, 0.6677260000000003, 0.48978183333333347`], 
             UndirectedEdge[210, 474] -> 
             RGBColor[0.6544, 0.7236013333333333, 0.9551658333333333], 
             UndirectedEdge[96, 392] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[70, 84] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[77, 278] -> 
             RGBColor[
              0.6404563333333333, 0.7180833333333334, 0.9654583333333333], 
             UndirectedEdge[238, 265] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[157, 392] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[145, 294] -> 
             RGBColor[
              0.8468315000000002, 0.6892923333333336, 0.5994995000000001], 
             UndirectedEdge[29, 383] -> 
             RGBColor[0.9181475, 0.6677260000000003, 0.48978183333333347`], 
             UndirectedEdge[210, 227] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[45, 276] -> 
             RGBColor[
              0.5653951666666666, 0.6345071666666666, 0.9499340000000001], 
             UndirectedEdge[57, 219] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[291, 311] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[11, 485] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[13, 338] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[190, 351] -> 
             RGBColor[0.992503, 0.986373, 0.425376], UndirectedEdge[314, 397] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[339, 365] -> 
             RGBColor[0.4681409999999999, 0.57648, 0.9519960000000001], 
             UndirectedEdge[320, 337] -> 
             RGBColor[
              0.7859241666666666, 0.8278753333333333, 0.6927016666666667], 
             UndirectedEdge[317, 357] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[153, 452] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[308, 423] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[149, 441] -> 
             RGBColor[
              0.9058373333333334, 0.5622313333333333, 0.3956226666666668], 
             UndirectedEdge[486, 493] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[241, 402] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[293, 432] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[23, 211] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[8, 381] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[238, 343] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[355, 363] -> 
             RGBColor[0.718755, 0.777397, 0.9308745], UndirectedEdge[66, 398] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[113, 477] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[7, 241] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[161, 259] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[346, 408] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[33, 270] -> 
             RGBColor[
              0.7731385000000001, 0.5557263333333335, 0.5806683333333333], 
             UndirectedEdge[197, 270] -> 
             RGBColor[
              0.8323468333333335, 0.6019803333333336, 0.5865696666666667], 
             UndirectedEdge[115, 381] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[112, 224] -> 
             RGBColor[
              0.7859241666666666, 0.8278753333333333, 0.6927016666666667], 
             UndirectedEdge[133, 296] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[204, 244] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[116, 280] -> 
             RGBColor[
              0.9214723333333334, 0.7263710000000001, 0.25567300000000004`], 
             UndirectedEdge[81, 267] -> 
             RGBColor[
              0.4051273333333333, 0.5253226666666666, 0.9470353333333333], 
             UndirectedEdge[431, 459] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[46, 293] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[145, 358] -> 
             RGBColor[
              0.8889530000000001, 0.5886433333333335, 0.22905200000000003`], 
             UndirectedEdge[12, 480] -> 
             RGBColor[0.9326351666666666, 0.912505, 0.660396], 
             UndirectedEdge[318, 321] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[38, 47] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[271, 492] -> 
             RGBColor[
              0.7607756666666667, 0.8130430000000001, 0.9767906666666666], 
             UndirectedEdge[246, 333] -> 
             RGBColor[
              0.8744683333333334, 0.5013313333333336, 0.2161221666666667], 
             UndirectedEdge[97, 137] -> 
             RGBColor[0.9442094999999999, 0.822865, 0.57672], 
             UndirectedEdge[406, 486] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[272, 306] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[50, 219] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[326, 405] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[180, 343] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[229, 380] -> 
             RGBColor[0.8621055000000001, 0.758648, 0.6122445], 
             UndirectedEdge[184, 470] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[188, 483] -> 
             RGBColor[0.7229105, 0.776718, 0.6877409999999999], 
             UndirectedEdge[364, 374] -> 
             RGBColor[0.8845911666666666, 0.5488736666666667, 0.5652925], 
             UndirectedEdge[161, 469] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[14, 182] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685095], 
             UndirectedEdge[374, 391] -> 
             RGBColor[0.8845911666666666, 0.5488736666666667, 0.5652925], 
             UndirectedEdge[352, 367] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[8, 289] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[160, 275] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[118, 151] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[43, 217] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[117, 154] -> 
             RGBColor[
              0.7868504999999999, 0.8298566666666667, 0.7935273333333335], 
             UndirectedEdge[139, 468] -> 
             RGBColor[0.8621055000000001, 0.758648, 0.6122445], 
             UndirectedEdge[279, 324] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[4, 29] -> 
             RGBColor[
              0.9195326666666667, 0.6674996666666669, 0.4087373333333335], 
             UndirectedEdge[239, 393] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[94, 127] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[157, 459] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[48, 85] -> RGBColor[0.980323, 0.945287, 0.378059],
              UndirectedEdge[26, 215] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[63, 165] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[165, 282] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[288, 465] -> 
             RGBColor[
              0.9326321666666667, 0.7550380000000002, 0.5027116666666669], 
             UndirectedEdge[200, 500] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[293, 353] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[239, 296] -> 
             RGBColor[
              0.7859241666666666, 0.8278753333333333, 0.6927016666666667], 
             UndirectedEdge[139, 274] -> 
             RGBColor[0.948365, 0.8221860000000001, 0.3335865], 
             UndirectedEdge[140, 361] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[83, 197] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[256, 444] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[21, 166] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[92, 363] -> 
             RGBColor[0.9761675, 0.9459660000000001, 0.6211925], 
             UndirectedEdge[41, 212] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[96, 433] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[346, 407] -> 
             RGBColor[
              0.7868504999999999, 0.8298566666666667, 0.7935273333333335], 
             UndirectedEdge[32, 155] -> 
             RGBColor[
              0.9600031666666666, 0.9339106666666667, 0.6485544999999999], 
             UndirectedEdge[302, 477] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[24, 489] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[359, 427] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[217, 290] -> 
             RGBColor[
              0.6404563333333333, 0.7180833333333334, 0.9654583333333333], 
             UndirectedEdge[40, 297] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[41, 456] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[341, 469] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[169, 498] -> 
             RGBColor[
              0.6404563333333333, 0.7180833333333334, 0.9654583333333333], 
             UndirectedEdge[6, 329] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[92, 219] -> 
             RGBColor[
              0.9798641666666666, 0.9474946666666667, 0.5599291666666668], 
             UndirectedEdge[341, 387] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[13, 478] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[33, 267] -> 
             RGBColor[0.5774426666666668, 0.666926, 0.9604976666666667], 
             UndirectedEdge[10, 123] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[57, 337] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[70, 135] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[51, 130] -> 
             RGBColor[0.8186515000000001, 0.49671200000000004`, 0.573455], 
             UndirectedEdge[219, 361] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[70, 131] -> 
             RGBColor[
              0.9326321666666667, 0.7550380000000002, 0.5027116666666668], 
             UndirectedEdge[61, 362] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[49, 487] -> 
             RGBColor[0.8621055000000001, 0.758648, 0.6122445000000001], 
             UndirectedEdge[83, 375] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[147, 385] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[105, 395] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[57, 204] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[362, 363] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[313, 390] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[15, 430] -> 
             RGBColor[0.9761675, 0.9459660000000001, 0.6211925], 
             UndirectedEdge[104, 430] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685095], 
             UndirectedEdge[341, 405] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[8, 311] -> 
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334], 
             UndirectedEdge[305, 460] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[451, 456] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[257, 306] -> 
             RGBColor[
              0.8793508333333335, 0.8270200000000001, 0.6261205000000001], 
             UndirectedEdge[65, 167] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[24, 329] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[14, 63] -> 
             RGBColor[
              0.7859241666666666, 0.8278753333333333, 0.6927016666666667], 
             UndirectedEdge[64, 172] -> 
             RGBColor[
              0.7607756666666667, 0.8130430000000001, 0.9767906666666666], 
             UndirectedEdge[50, 361] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[253, 291] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[184, 280] -> 
             RGBColor[0.9452905, 0.8791816666666668, 0.617958], 
             UndirectedEdge[402, 487] -> 
             RGBColor[
              0.9479061666666666, 0.8243936666666667, 0.5154566666666668], 
             UndirectedEdge[356, 463] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[287, 301] -> 
             RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             UndirectedEdge[265, 328] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[196, 321] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[122, 267] -> 
             RGBColor[
              0.7025906666666666, 0.7653416666666666, 0.9582364999999999], 
             UndirectedEdge[330, 354] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[155, 393] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[291, 319] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[63, 206] -> 
             RGBColor[
              0.6404563333333333, 0.7180833333333334, 0.9654583333333333], 
             UndirectedEdge[174, 215] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[254, 471] -> 
             RGBColor[0.9761675, 0.9459660000000001, 0.6211925], 
             UndirectedEdge[453, 463] -> 
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667], 
             UndirectedEdge[154, 174] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[119, 197] -> 
             RGBColor[
              0.8323468333333335, 0.6019803333333336, 0.5865696666666667], 
             UndirectedEdge[50, 340] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[443, 446] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[275, 324] -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             UndirectedEdge[95, 286] -> 
             RGBColor[0.8845911666666666, 0.5488736666666667, 0.5652925], 
             UndirectedEdge[306, 317] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[118, 188] -> 
             RGBColor[0.6366510000000001, 0.71318, 0.966399], 
             UndirectedEdge[7, 69] -> 
             RGBColor[0.6544, 0.7236013333333333, 0.9551658333333333], 
             UndirectedEdge[88, 166] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[9, 44] -> 
             RGBColor[
              0.7607756666666667, 0.8130430000000001, 0.9767906666666666], 
             UndirectedEdge[76, 459] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[254, 325] -> 
             RGBColor[0.920911, 0.7117443333333335, 0.27352450000000006`], 
             UndirectedEdge[171, 433] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[112, 447] -> 
             RGBColor[
              0.7868504999999999, 0.8298566666666667, 0.7935273333333335], 
             UndirectedEdge[199, 359] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[74, 224] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685095], 
             UndirectedEdge[292, 386] -> 
             RGBColor[
              0.7859241666666666, 0.8278753333333333, 0.6927016666666667], 
             UndirectedEdge[112, 195] -> 
             RGBColor[0.7120275, 0.5070206666666669, 0.5752373333333334], 
             UndirectedEdge[97, 408] -> 
             RGBColor[0.8621055000000001, 0.758648, 0.6122445], 
             UndirectedEdge[236, 422] -> 
             RGBColor[0.9181475, 0.6677260000000003, 0.48978183333333347`], 
             UndirectedEdge[27, 114] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[110, 355] -> 
             RGBColor[
              0.6490138333333333, 0.4558633333333335, 0.5702766666666667], 
             UndirectedEdge[104, 215] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[80, 406] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[276, 292] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[425, 466] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[164, 309] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[95, 137] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[119, 426] -> 
             RGBColor[0.9181475, 0.6677260000000003, 0.48978183333333347`], 
             UndirectedEdge[238, 431] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[93, 266] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[15, 148] -> 
             RGBColor[
              0.9600031666666666, 0.9339106666666667, 0.6485544999999999], 
             UndirectedEdge[225, 470] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685095], 
             UndirectedEdge[249, 296] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[273, 421] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[150, 159] -> 
             RGBColor[
              0.7868504999999999, 0.8298566666666667, 0.7935273333333335], 
             UndirectedEdge[85, 407] -> 
             RGBColor[
              0.7737441666666667, 0.7867893333333333, 0.6453846666666667], 
             UndirectedEdge[71, 388] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[61, 435] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[10, 177] -> 
             RGBColor[0.718755, 0.777397, 0.9308745], UndirectedEdge[16, 52] -> 
             RGBColor[0.5292520000000001, 0.6251856666666666, 0.957427], 
             UndirectedEdge[25, 459] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[105, 453] -> 
             RGBColor[
              0.8709184999999999, 0.6327363333333336, 0.5902486666666666], 
             UndirectedEdge[61, 384] -> 
             RGBColor[
              0.9144508333333333, 0.6661973333333335, 0.5510451666666667], 
             UndirectedEdge[104, 323] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[150, 406] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[413, 493] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[94, 254] -> 
             RGBColor[0.980323, 0.945287, 0.378059], UndirectedEdge[431, 487] -> 
             RGBColor[0.9442094999999999, 0.822865, 0.57672], 
             UndirectedEdge[234, 332] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[82, 89] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[154, 255] -> 
             RGBColor[
              0.9492913333333333, 0.8241673333333334, 0.4344121666666668], 
             UndirectedEdge[22, 324] -> 
             RGBColor[
              0.9934293333333333, 0.9883543333333333, 0.5262016666666668], 
             UndirectedEdge[105, 112] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[6, 406] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[396, 422] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[409, 456] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[91, 473] -> 
             RGBColor[0.8186515000000001, 0.49671200000000004`, 0.573455], 
             UndirectedEdge[369, 379] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[353, 441] -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             UndirectedEdge[165, 481] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[185, 318] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[264, 445] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[258, 297] -> 
             RGBColor[
              0.6404563333333333, 0.7180833333333334, 0.9654583333333333], 
             UndirectedEdge[57, 139] -> 
             RGBColor[0.9006771666666666, 0.789404, 0.6159235000000001], 
             UndirectedEdge[447, 463] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[9, 26] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[181, 262] -> 
             RGBColor[0.9127711666666667, 0.7414540000000002, 0.591337], 
             UndirectedEdge[203, 291] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[45, 254] -> 
             RGBColor[0.5735349999999999, 0.6047975000000001, 0.6321215], 
             UndirectedEdge[240, 412] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[208, 258] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[293, 420] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[85, 346] -> 
             RGBColor[
              0.9812493333333333, 0.9472683333333334, 0.4788846666666668], 
             UndirectedEdge[65, 166] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[254, 347] -> 
             RGBColor[0.8940635000000001, 0.8817490000000001, 0.656717], 
             UndirectedEdge[236, 292] -> 
             RGBColor[
              0.9186063333333334, 0.6655183333333337, 0.3079116666666667], 
             UndirectedEdge[100, 401] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[146, 400] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[104, 153] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685095], 
             UndirectedEdge[216, 281] -> 
             RGBColor[0.8028971666666667, 0.712394, 0.6063431666666667], 
             UndirectedEdge[123, 125] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[78, 358] -> 
             RGBColor[0.8621055000000001, 0.758648, 0.6122445000000001], 
             UndirectedEdge[313, 478] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[368, 401] -> 
             RGBColor[
              0.6705643333333333, 0.7356566666666666, 0.9278038333333334], 
             UndirectedEdge[106, 369] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[111, 146] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[129, 266] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[99, 278] -> 
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333], 
             UndirectedEdge[147, 171] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[164, 166] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[129, 433] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[179, 283] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[136, 291] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[321, 479] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[181, 239] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[102, 330] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[406, 413] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[37, 310] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[203, 439] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[320, 375] -> 
             RGBColor[
              0.7859241666666666, 0.8278753333333333, 0.6927016666666667], 
             UndirectedEdge[42, 407] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[131, 374] -> 
             RGBColor[0.845499, 0.3267073333333335, 0.19026250000000006`], 
             UndirectedEdge[387, 403] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[65, 348] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[217, 498] -> 
             RGBColor[
              0.6404563333333333, 0.7180833333333334, 0.9654583333333333], 
             UndirectedEdge[40, 397] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[226, 292] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[53, 257] -> 
             RGBColor[0.9656103333333335, 0.8905580000000002, 0.3474625], 
             UndirectedEdge[220, 429] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[139, 425] -> 
             RGBColor[0.8621055000000001, 0.758648, 0.6122445], 
             UndirectedEdge[317, 418] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[482, 496] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[117, 466] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[82, 105] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[239, 453] -> 
             RGBColor[
              0.9186063333333334, 0.6655183333333335, 0.3079116666666667], 
             UndirectedEdge[274, 340] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[311, 484] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[44, 140] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[139, 466] -> 
             RGBColor[0.8621055000000001, 0.758648, 0.6122445], 
             UndirectedEdge[22, 481] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685095], 
             UndirectedEdge[45, 386] -> 
             RGBColor[
              0.3791361666666666, 0.4873858333333333, 0.9467641666666666], 
             UndirectedEdge[40, 220] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[237, 489] -> 
             RGBColor[
              0.6705643333333333, 0.7356566666666666, 0.9278038333333334], 
             UndirectedEdge[61, 64] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[82, 296] -> 
             RGBColor[
              0.6404563333333333, 0.7180833333333334, 0.9654583333333333], 
             UndirectedEdge[27, 277] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[416, 427] -> 
             RGBColor[
              0.5852561666666667, 0.6480911666666667, 0.8613086666666667], 
             UndirectedEdge[59, 82] -> 
             RGBColor[
              0.7731385000000001, 0.5557263333333335, 0.5806683333333333], 
             UndirectedEdge[271, 444] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[6, 486] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[171, 265] -> 
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334], 
             UndirectedEdge[219, 369] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[244, 355] -> 
             RGBColor[0.6752226666666666, 0.7439359999999999, 0.970078], 
             UndirectedEdge[450, 500] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[18, 243] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[377, 449] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[7, 173] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[3, 8] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[405, 469] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[148, 190] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[180, 216] -> 
             RGBColor[
              0.9492913333333333, 0.8241673333333334, 0.4344121666666668], 
             UndirectedEdge[257, 317] -> 
             RGBColor[
              0.8793508333333335, 0.8270200000000001, 0.6261205000000001], 
             UndirectedEdge[49, 462] -> 
             RGBColor[0.8940635000000001, 0.8817490000000001, 0.656717], 
             UndirectedEdge[223, 258] -> 
             RGBColor[0.8028971666666667, 0.712394, 0.6063431666666667], 
             UndirectedEdge[260, 440] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[262, 332] -> 
             RGBColor[
              0.9326321666666667, 0.7550380000000002, 0.5027116666666669], 
             UndirectedEdge[283, 386] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[40, 289] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[95, 430] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[274, 334] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[75, 158] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[233, 476] -> 
             RGBColor[
              0.6543999999999999, 0.7236013333333333, 0.9551658333333333], 
             UndirectedEdge[240, 416] -> 
             RGBColor[0.5815595, 0.6465625, 0.922572], 
             UndirectedEdge[260, 280] -> 
             RGBColor[
              0.8793508333333335, 0.8270200000000001, 0.6261205000000001], 
             UndirectedEdge[11, 193] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[3, 162] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[117, 338] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[40, 472] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[101, 355] -> 
             RGBColor[0.7107304999999999, 0.7356320000000001, 0.640424], 
             UndirectedEdge[47, 364] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[377, 484] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[21, 227] -> 
             RGBColor[0.8845911666666666, 0.5488736666666667, 0.5652925], 
             UndirectedEdge[158, 441] -> 
             RGBColor[
              0.9934293333333333, 0.9883543333333333, 0.5262016666666668], 
             UndirectedEdge[201, 222] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[107, 477] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[89, 239] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685095], 
             UndirectedEdge[63, 275] -> 
             RGBColor[
              0.7868504999999999, 0.8298566666666667, 0.7935273333333335], 
             UndirectedEdge[133, 344] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[153, 356] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[151, 188] -> 
             RGBColor[
              0.7025906666666666, 0.7653416666666666, 0.9582364999999999], 
             UndirectedEdge[140, 204] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[154, 369] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[16, 179] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[161, 341] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[48, 408] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[153, 263] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[62, 132] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[82, 225] -> 
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666], 
             UndirectedEdge[216, 465] -> 
             RGBColor[
              0.9479061666666666, 0.8243936666666667, 0.5154566666666668], 
             UndirectedEdge[119, 489] -> 
             RGBColor[
              0.9144508333333333, 0.6661973333333335, 0.5510451666666667], 
             UndirectedEdge[287, 295] -> 
             RGBColor[
              0.6404563333333333, 0.7180833333333334, 0.9654583333333333], 
             UndirectedEdge[28, 417] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[148, 351] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[218, 336] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[127, 254] -> 
             RGBColor[
              0.9798641666666666, 0.9474946666666667, 0.5599291666666668], 
             UndirectedEdge[303, 473] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[99, 267] -> 
             RGBColor[0.5774426666666668, 0.666926, 0.9604976666666667], 
             UndirectedEdge[48, 145] -> 
             RGBColor[0.9330910000000001, 0.7528303333333335, 0.3208415], 
             UndirectedEdge[224, 342] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[193, 232] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[216, 343] -> 
             RGBColor[0.9280451666666667, 0.8108096666666667, 0.604082], 
             UndirectedEdge[277, 449] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[257, 418] -> 
             RGBColor[0.9179225, 0.8577760000000001, 0.6297995000000001], 
             UndirectedEdge[45, 422] -> 
             RGBColor[
              0.5852561666666667, 0.6480911666666667, 0.8613086666666667], 
             UndirectedEdge[133, 235] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[145, 183] -> 
             RGBColor[
              0.8854031666666666, 0.7200483333333335, 0.6031785000000001], 
             UndirectedEdge[196, 496] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[115, 136] -> 
             RGBColor[
              0.6404563333333333, 0.7180833333333334, 0.9654583333333333], 
             UndirectedEdge[267, 413] -> 
             RGBColor[
              0.7224516666666667, 0.7789256666666666, 0.8696111666666668], 
             UndirectedEdge[217, 340] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[335, 383] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[80, 493] -> 
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666], 
             UndirectedEdge[307, 372] -> 
             RGBColor[
              0.9058373333333334, 0.5622313333333333, 0.3956226666666668], 
             UndirectedEdge[18, 434] -> 
             RGBColor[
              0.7859241666666666, 0.8278753333333333, 0.6927016666666667], 
             UndirectedEdge[130, 179] -> 
             RGBColor[
              0.9044521666666667, 0.5624576666666667, 0.47666716666666675`], 
             UndirectedEdge[20, 228] -> 
             RGBColor[0.9326351666666666, 0.912505, 0.660396], 
             UndirectedEdge[297, 311] -> 
             RGBColor[
              0.7868504999999999, 0.8298566666666667, 0.7935273333333335], 
             UndirectedEdge[127, 200] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[54, 391] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[347, 368] -> 
             RGBColor[
              0.5884603333333334, 0.6714396666666667, 0.9633283333333333], 
             UndirectedEdge[22, 182] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685095], 
             UndirectedEdge[96, 216] -> 
             RGBColor[
              0.7417861666666666, 0.6636883333333333, 0.6009121666666667], 
             UndirectedEdge[340, 363] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[71, 490] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[111, 201] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[261, 484] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[416, 499] -> 
             RGBColor[0.5380271666666667, 0.6131015, 0.9617755], 
             UndirectedEdge[42, 430] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[6, 81] -> 
             RGBColor[0.6544, 0.7236013333333333, 0.9551658333333333], 
             UndirectedEdge[282, 353] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[275, 441] -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             UndirectedEdge[50, 255] -> 
             RGBColor[0.8028971666666667, 0.712394, 0.6063431666666667], 
             UndirectedEdge[110, 217] -> 
             RGBColor[
              0.7731385000000001, 0.5557263333333335, 0.5806683333333333], 
             UndirectedEdge[30, 110] -> 
             RGBColor[
              0.8310143333333333, 0.23939533333333354`, 0.1773326666666667], 
             UndirectedEdge[77, 482] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[52, 326] -> 
             RGBColor[
              0.6705643333333333, 0.7356566666666666, 0.9278038333333334], 
             UndirectedEdge[44, 247] -> 
             RGBColor[
              0.7607756666666667, 0.8130430000000001, 0.9767906666666666], 
             UndirectedEdge[337, 348] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[48, 78] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[420, 432] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[469, 474] -> 
             RGBColor[
              0.6270319999999999, 0.7021956666666667, 0.9670073333333333], 
             UndirectedEdge[172, 366] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[102, 415] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[414, 485] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[102, 193] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[128, 498] -> 
             RGBColor[
              0.7417861666666666, 0.6636883333333333, 0.6009121666666667], 
             UndirectedEdge[150, 443] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[2, 230] -> 
             RGBColor[
              0.5163316666666666, 0.6182203333333334, 0.9550666666666667], 
             UndirectedEdge[367, 416] -> 
             RGBColor[0.49945550000000005`, 0.5823455000000001, 0.9580965], 
             UndirectedEdge[61, 473] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[56, 164] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[20, 388] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[195, 296] -> 
             RGBColor[0.7120275, 0.5070206666666669, 0.5752373333333334], 
             UndirectedEdge[135, 391] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[310, 399] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[150, 476] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[142, 222] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[48, 404] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685095], 
             UndirectedEdge[330, 415] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[326, 495] -> 
             RGBColor[
              0.6705643333333333, 0.7356566666666666, 0.9278038333333334], 
             UndirectedEdge[36, 382] -> 
             RGBColor[
              0.7025906666666666, 0.7653416666666666, 0.9582364999999999], 
             UndirectedEdge[31, 289] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[436, 487] -> 
             RGBColor[0.9006771666666666, 0.789404, 0.6159235000000001], 
             UndirectedEdge[251, 427] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[108, 437] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[258, 397] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[308, 422] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[16, 292] -> 
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666], 
             UndirectedEdge[68, 317] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[34, 468] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[350, 383] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[190, 342] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[61, 303] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[214, 421] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[219, 370] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[91, 366] -> 
             RGBColor[
              0.6983321666666666, 0.4017523333333333, 0.5621226666666667], 
             UndirectedEdge[273, 477] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[153, 323] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[170, 433] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[1, 54] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[277, 377] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[307, 417] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[58, 371] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[9, 269] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[184, 453] -> 
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667], 
             UndirectedEdge[42, 97] -> 
             RGBColor[0.9442094999999999, 0.822865, 0.57672], 
             UndirectedEdge[161, 405] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[304, 429] -> 
             RGBColor[0.9289355, 0.7535093333333336, 0.5639750000000001], 
             UndirectedEdge[127, 130] -> 
             RGBColor[
              0.9044521666666667, 0.5624576666666667, 0.47666716666666675`], 
             UndirectedEdge[318, 330] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[393, 468] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[334, 355] -> 
             RGBColor[
              0.7224516666666667, 0.7789256666666666, 0.8696111666666668], 
             UndirectedEdge[290, 378] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[92, 498] -> 
             RGBColor[
              0.7737441666666667, 0.7867893333333333, 0.6453846666666667], 
             UndirectedEdge[340, 362] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[58, 304] -> 
             RGBColor[0.9127711666666667, 0.7414540000000002, 0.591337], 
             UndirectedEdge[51, 308] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[59, 447] -> 
             RGBColor[
              0.9195326666666667, 0.6674996666666668, 0.4087373333333335], 
             UndirectedEdge[186, 485] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[340, 379] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[129, 410] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[192, 225] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[306, 420] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[16, 45] -> 
             RGBColor[0.44024716666666674`, 0.5360915, 0.9521951666666666], 
             UndirectedEdge[334, 361] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[306, 357] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[335, 496] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[176, 345] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685095], 
             UndirectedEdge[15, 78] -> 
             RGBColor[0.8940635000000001, 0.8817490000000001, 0.656717], 
             UndirectedEdge[52, 210] -> 
             RGBColor[
              0.6543999999999999, 0.7236013333333333, 0.9551658333333333], 
             UndirectedEdge[392, 465] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[354, 414] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[56, 428] -> 
             RGBColor[0.718755, 0.777397, 0.9308745], UndirectedEdge[44, 425] -> 
             RGBColor[
              0.7607756666666667, 0.8130430000000001, 0.9767906666666666], 
             UndirectedEdge[106, 468] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[142, 461] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[203, 297] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[24, 176] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[351, 356] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[315, 368] -> 
             RGBColor[
              0.6705643333333333, 0.7356566666666666, 0.9278038333333334], 
             UndirectedEdge[278, 406] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[247, 360] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[78, 145] -> 
             RGBColor[
              0.8468315000000002, 0.6892923333333336, 0.5994995000000001], 
             UndirectedEdge[19, 466] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[60, 151] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[109, 186] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[474, 495] -> 
             RGBColor[
              0.3569366666666666, 0.4835823333333333, 0.9439646666666667], 
             UndirectedEdge[36, 412] -> 
             RGBColor[
              0.7224516666666667, 0.7789256666666666, 0.8696111666666668], 
             UndirectedEdge[259, 469] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[6, 80] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[287, 389] -> 
             RGBColor[
              0.7417861666666666, 0.6636883333333333, 0.6009121666666667], 
             UndirectedEdge[158, 410] -> 
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666], 
             UndirectedEdge[414, 415] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[10, 245] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[115, 178] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[88, 348] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[135, 170] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[3, 203] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[84, 374] -> 
             RGBColor[
              0.6983321666666666, 0.4017523333333333, 0.5621226666666667], 
             UndirectedEdge[29, 172] -> 
             RGBColor[
              0.8323468333333335, 0.6019803333333336, 0.5865696666666667], 
             UndirectedEdge[262, 387] -> 
             RGBColor[
              0.9326321666666667, 0.7550380000000002, 0.5027116666666669], 
             UndirectedEdge[179, 276] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[348, 428] -> 
             RGBColor[
              0.7224516666666667, 0.7789256666666666, 0.8696111666666668], 
             UndirectedEdge[104, 351] -> 
             RGBColor[0.992503, 0.986373, 0.425376], UndirectedEdge[111, 271] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[136, 277] -> 
             RGBColor[
              0.7607756666666667, 0.8130430000000001, 0.9767906666666666], 
             UndirectedEdge[246, 442] -> 
             RGBColor[
              0.9214723333333334, 0.7263710000000001, 0.25567300000000004`], 
             UndirectedEdge[206, 266] -> 
             RGBColor[
              0.6404563333333333, 0.7180833333333334, 0.9654583333333333], 
             UndirectedEdge[31, 381] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[31, 472] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[342, 453] -> 
             RGBColor[
              0.8709184999999999, 0.6327363333333336, 0.5902486666666666], 
             UndirectedEdge[200, 475] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[92, 101] -> 
             RGBColor[0.968143, 0.904201, 0.330742], UndirectedEdge[193, 376] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[253, 319] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[249, 280] -> 
             RGBColor[0.9452905, 0.8791816666666668, 0.617958], 
             UndirectedEdge[153, 195] -> 
             RGBColor[
              0.9144508333333333, 0.6661973333333335, 0.5510451666666667], 
             UndirectedEdge[313, 380] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[178, 357] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[163, 494] -> 
             RGBColor[
              0.6086681666666667, 0.6799898333333334, 0.9523983333333333], 
             UndirectedEdge[24, 237] -> 
             RGBColor[0.674261, 0.7371853333333334, 0.8665405000000002], 
             UndirectedEdge[101, 345] -> 
             RGBColor[0.980323, 0.945287, 0.378059], UndirectedEdge[320, 361] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[328, 487] -> 
             RGBColor[0.9006771666666666, 0.789404, 0.6159235000000001], 
             UndirectedEdge[322, 494] -> 
             RGBColor[0.9452905, 0.8791816666666668, 0.617958], 
             UndirectedEdge[108, 266] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[405, 474] -> 
             RGBColor[0.674261, 0.7371853333333334, 0.8665405000000002], 
             UndirectedEdge[338, 379] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[175, 309] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[294, 430] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[197, 237] -> 
             RGBColor[
              0.5884603333333334, 0.6714396666666667, 0.9633283333333333], 
             UndirectedEdge[94, 500] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[242, 365] -> 
             RGBColor[
              0.6705643333333333, 0.7356566666666666, 0.9278038333333334], 
             UndirectedEdge[401, 500] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[334, 340] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[60, 310] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[50, 379] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[123, 177] -> 
             RGBColor[
              0.7025906666666666, 0.7653416666666666, 0.9582364999999999], 
             UndirectedEdge[231, 246] -> 
             RGBColor[0.9442094999999999, 0.822865, 0.57672], 
             UndirectedEdge[182, 282] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[185, 193] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[395, 447] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[22, 282] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[195, 323] -> 
             RGBColor[
              0.8709184999999999, 0.6327363333333336, 0.5902486666666666], 
             UndirectedEdge[99, 486] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[454, 469] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[31, 208] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[398, 472] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[191, 389] -> 
             RGBColor[0.8621055000000001, 0.758648, 0.6122445000000001], 
             UndirectedEdge[133, 151] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[165, 268] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[166, 495] -> 
             RGBColor[
              0.6705643333333333, 0.7356566666666666, 0.9278038333333334], 
             UndirectedEdge[346, 430] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[169, 219] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[197, 345] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[100, 213] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[73, 187] -> 
             RGBColor[0.8028971666666667, 0.712394, 0.6063431666666667], 
             UndirectedEdge[97, 346] -> 
             RGBColor[
              0.9492913333333333, 0.8241673333333334, 0.4344121666666668], 
             UndirectedEdge[129, 170] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[36, 37] -> 
             RGBColor[0.6366510000000001, 0.71318, 0.966399], 
             UndirectedEdge[143, 302] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[16, 236] -> 
             RGBColor[
              0.7731385000000001, 0.5557263333333335, 0.5806683333333333], 
             UndirectedEdge[187, 322] -> 
             RGBColor[
              0.9214723333333334, 0.7263710000000001, 0.25567300000000004`], 
             UndirectedEdge[108, 163] -> 
             RGBColor[0.6248325, 0.6920451666666667, 0.9250363333333333], 
             UndirectedEdge[137, 346] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[243, 276] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[131, 147] -> 
             RGBColor[0.9289355, 0.7535093333333336, 0.5639750000000001], 
             UndirectedEdge[9, 468] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[331, 377] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[280, 470] -> 
             RGBColor[0.9614548333333334, 0.8912370000000001, 0.590596], 
             UndirectedEdge[234, 468] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[136, 488] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[57, 361] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[196, 414] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[103, 319] -> 
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667], 
             UndirectedEdge[224, 263] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[89, 184] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[137, 407] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[53, 272] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[236, 243] -> 
             RGBColor[
              0.8323468333333335, 0.6019803333333336, 0.5865696666666667], 
             UndirectedEdge[26, 351] -> 
             RGBColor[
              0.9934293333333333, 0.9883543333333333, 0.5262016666666668], 
             UndirectedEdge[67, 96] -> 
             RGBColor[
              0.7737441666666667, 0.7867893333333333, 0.6453846666666667], 
             UndirectedEdge[284, 464] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[325, 401] -> 
             RGBColor[0.9289355, 0.7535093333333336, 0.5639750000000001], 
             UndirectedEdge[227, 348] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[106, 117] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[395, 440] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[204, 361] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[195, 263] -> 
             RGBColor[0.9181475, 0.6677260000000003, 0.48978183333333347`], 
             UndirectedEdge[360, 393] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[74, 440] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[166, 348] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[209, 477] -> 
             RGBColor[0.9006771666666666, 0.789404, 0.6159235], 
             UndirectedEdge[292, 422] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[36, 416] -> 
             RGBColor[0.3161225, 0.4362285, 0.9418035], 
             UndirectedEdge[306, 418] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[363, 498] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[57, 466] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[263, 395] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[171, 238] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[42, 286] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[246, 444] -> 
             RGBColor[
              0.9479061666666666, 0.8243936666666667, 0.5154566666666668], 
             UndirectedEdge[46, 306] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[229, 411] -> 
             RGBColor[0.9006771666666666, 0.789404, 0.6159235], 
             UndirectedEdge[239, 440] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[57, 106] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[60, 280] -> 
             RGBColor[
              0.8793508333333335, 0.8270200000000001, 0.6261205000000001], 
             UndirectedEdge[438, 457] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[130, 368] -> 
             RGBColor[
              0.5871278333333333, 0.3088546666666666, 0.5540913333333334], 
             UndirectedEdge[152, 287] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[54, 242] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[89, 235] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[60, 260] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[88, 243] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[36, 367] -> 
             RGBColor[0.6366510000000001, 0.71318, 0.966399], 
             UndirectedEdge[17, 282] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[150, 233] -> 
             RGBColor[0.4681409999999999, 0.57648, 0.9519960000000001], 
             UndirectedEdge[250, 365] -> 
             RGBColor[0.5292520000000001, 0.6251856666666666, 0.957427], 
             UndirectedEdge[107, 423] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[315, 347] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[288, 492] -> 
             RGBColor[
              0.7876231666666668, 0.6430383333333336, 0.5935981666666668], 
             UndirectedEdge[24, 267] -> 
             RGBColor[
              0.7224516666666667, 0.7789256666666666, 0.8696111666666668], 
             UndirectedEdge[198, 480] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[4, 479] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[133, 239] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[115, 253] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[199, 371] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[93, 189] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[357, 418] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[82, 463] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[102, 350] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[235, 296] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[26, 360] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[309, 320] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[13, 229] -> 
             RGBColor[0.9442094999999999, 0.822865, 0.57672], 
             UndirectedEdge[353, 420] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[171, 465] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[104, 224] -> 
             RGBColor[0.992503, 0.986373, 0.425376], UndirectedEdge[22, 285] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[126, 285] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[98, 319] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[286, 411] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[259, 491] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[1, 266] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[67, 216] -> RGBColor[0.936185, 0.7811, 0.2862695],
              UndirectedEdge[41, 451] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[300, 456] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[117, 139] -> 
             RGBColor[
              0.7417861666666666, 0.6636883333333333, 0.6009121666666667], 
             UndirectedEdge[70, 96] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[92, 274] -> 
             RGBColor[0.980323, 0.945287, 0.378059], UndirectedEdge[241, 436] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[207, 295] -> 
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334], 
             UndirectedEdge[83, 176] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[56, 495] -> 
             RGBColor[
              0.6705643333333333, 0.7356566666666666, 0.9278038333333334], 
             UndirectedEdge[219, 334] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[124, 357] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[40, 291] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[7, 487] -> 
             RGBColor[0.9280451666666667, 0.8108096666666667, 0.604082], 
             UndirectedEdge[423, 477] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[22, 165] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[302, 368] -> 
             RGBColor[0.6544, 0.7236013333333333, 0.9551658333333333], 
             UndirectedEdge[297, 419] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[263, 463] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[260, 424] -> 
             RGBColor[
              0.7607756666666667, 0.8130430000000001, 0.9767906666666666], 
             UndirectedEdge[193, 415] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[434, 474] -> 
             RGBColor[
              0.6747198333333333, 0.7349776666666666, 0.6846703333333333], 
             UndirectedEdge[102, 109] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[58, 118] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[39, 100] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[35, 216] -> 
             RGBColor[0.9442094999999999, 0.822865, 0.57672], 
             UndirectedEdge[72, 163] -> 
             RGBColor[
              0.6086681666666667, 0.6799898333333333, 0.9523983333333333], 
             UndirectedEdge[202, 414] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[324, 441] -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             UndirectedEdge[18, 52] -> 
             RGBColor[0.4681409999999999, 0.57648, 0.9519960000000001], 
             UndirectedEdge[168, 368] -> 
             RGBColor[0.4681409999999999, 0.57648, 0.9519960000000001], 
             UndirectedEdge[208, 397] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[193, 350] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[2, 365] -> 
             RGBColor[0.4681409999999999, 0.57648, 0.9519960000000001], 
             UndirectedEdge[42, 248] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[46, 68] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[260, 470] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[32, 344] -> 
             RGBColor[
              0.9812493333333333, 0.9472683333333334, 0.4788846666666668], 
             UndirectedEdge[60, 483] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[337, 498] -> 
             RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             UndirectedEdge[86, 168] -> 
             RGBColor[
              0.7868504999999999, 0.8298566666666667, 0.7935273333333335], 
             UndirectedEdge[151, 424] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[234, 296] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[223, 268] -> 
             RGBColor[0.8028971666666667, 0.712394, 0.6063431666666667], 
             UndirectedEdge[50, 204] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[26, 247] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[64, 435] -> 
             RGBColor[
              0.6404563333333333, 0.7180833333333334, 0.9654583333333333], 
             UndirectedEdge[143, 214] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[38, 266] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[309, 375] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[70, 385] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[232, 354] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[86, 484] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[106, 360] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[163, 322] -> 
             RGBColor[
              0.6020953333333334, 0.5955511666666667, 0.6039893333333334], 
             UndirectedEdge[44, 117] -> 
             RGBColor[
              0.6404563333333333, 0.7180833333333334, 0.9654583333333333], 
             UndirectedEdge[113, 273] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[53, 298] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[50, 369] -> 
             RGBColor[
              0.7607756666666667, 0.8130430000000001, 0.9767906666666666], 
             UndirectedEdge[135, 385] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[376, 464] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[95, 408] -> 
             RGBColor[0.8186515000000001, 0.49671200000000004`, 0.573455], 
             UndirectedEdge[34, 332] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[251, 416] -> 
             RGBColor[0.5380271666666666, 0.6131015, 0.9617755], 
             UndirectedEdge[62, 209] -> 
             RGBColor[0.8621055000000001, 0.758648, 0.6122445000000001], 
             UndirectedEdge[109, 496] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[179, 254] -> 
             RGBColor[
              0.9798641666666666, 0.9474946666666667, 0.5599291666666668], 
             UndirectedEdge[27, 199] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[59, 453] -> 
             RGBColor[
              0.8447096666666667, 0.3446636666666671, 0.19044733333333339`], 
             UndirectedEdge[450, 475] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[311, 331] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[329, 486] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[287, 456] -> 
             RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             UndirectedEdge[60, 118] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[267, 493] -> 
             RGBColor[0.7229105, 0.776718, 0.6877409999999999], 
             UndirectedEdge[239, 263] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[64, 91] -> 
             RGBColor[0.7594431666666668, 0.450458, 0.5675536666666666], 
             UndirectedEdge[469, 471] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[275, 282] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[132, 423] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[116, 412] -> 
             RGBColor[
              0.9479061666666666, 0.8243936666666667, 0.5154566666666668], 
             UndirectedEdge[89, 453] -> 
             RGBColor[
              0.9144508333333333, 0.6661973333333335, 0.5510451666666667], 
             UndirectedEdge[136, 311] -> 
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334], 
             UndirectedEdge[6, 24] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[51, 477] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[114, 381] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[95, 294] -> 
             RGBColor[0.8186515000000001, 0.49671200000000004`, 0.573455], 
             UndirectedEdge[89, 192] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[108, 374] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[208, 472] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[34, 360] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[395, 453] -> 
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667], 
             UndirectedEdge[101, 361] -> 
             RGBColor[
              0.9798641666666666, 0.9474946666666667, 0.5599291666666668], 
             UndirectedEdge[11, 211] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[70, 433] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[108, 206] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[251, 499] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[116, 399] -> 
             RGBColor[
              0.7417861666666666, 0.6636883333333333, 0.6009121666666667], 
             UndirectedEdge[350, 479] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[347, 421] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[153, 447] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[195, 453] -> 
             RGBColor[
              0.8447096666666667, 0.3446636666666671, 0.19044733333333339`], 
             UndirectedEdge[338, 425] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[164, 348] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[31, 258] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[31, 203] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[398, 445] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[44, 369] -> 
             RGBColor[
              0.7607756666666667, 0.8130430000000001, 0.9767906666666666], 
             UndirectedEdge[267, 278] -> 
             RGBColor[0.5774426666666668, 0.666926, 0.9604976666666667], 
             UndirectedEdge[130, 477] -> 
             RGBColor[0.8572231666666666, 0.527468, 0.577134], 
             UndirectedEdge[4, 482] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[219, 274] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[44, 269] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[130, 143] -> 
             RGBColor[
              0.9044521666666667, 0.5624576666666667, 0.47666716666666675`], 
             UndirectedEdge[315, 401] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[75, 163] -> 
             RGBColor[
              0.6086681666666667, 0.6799898333333333, 0.9523983333333333], 
             UndirectedEdge[9, 139] -> 
             RGBColor[0.8621055000000001, 0.758648, 0.6122445000000001], 
             UndirectedEdge[134, 438] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[76, 431] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[90, 124] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[37, 188] -> 
             RGBColor[0.6366510000000001, 0.71318, 0.966399], 
             UndirectedEdge[26, 106] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[107, 446] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[19, 234] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[39, 243] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[129, 265] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[396, 446] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[325, 368] -> 
             RGBColor[
              0.6153078333333334, 0.5014350000000002, 0.5801358333333333], 
             UndirectedEdge[52, 56] -> 
             RGBColor[
              0.6705643333333333, 0.7356566666666666, 0.9278038333333334], 
             UndirectedEdge[402, 431] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[165, 353] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[237, 329] -> 
             RGBColor[
              0.6756461666666667, 0.7369589999999999, 0.7854960000000002], 
             UndirectedEdge[63, 75] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[392, 492] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[125, 177] -> 
             RGBColor[
              0.7025906666666666, 0.7653416666666666, 0.9582364999999999], 
             UndirectedEdge[210, 348] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[469, 491] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[35, 171] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[8, 40] -> 
             RGBColor[
              0.7607756666666667, 0.8130430000000001, 0.9767906666666666], 
             UndirectedEdge[405, 491] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[98, 136] -> 
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334], 
             UndirectedEdge[14, 75] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[121, 500] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[1, 265] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[227, 495] -> 
             RGBColor[0.6544, 0.7236013333333333, 0.9551658333333333], 
             UndirectedEdge[127, 368] -> 
             RGBColor[0.674261, 0.7371853333333334, 0.8665405000000002], 
             UndirectedEdge[207, 389] -> 
             RGBColor[
              0.9492913333333333, 0.8241673333333334, 0.4344121666666668], 
             UndirectedEdge[249, 260] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[42, 95] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[190, 323] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[109, 295] -> 
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334], 
             UndirectedEdge[382, 499] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[213, 254] -> 
             RGBColor[
              0.8348551666666667, 0.8354950000000001, 0.6508156666666667], 
             UndirectedEdge[47, 374] -> 
             RGBColor[0.8572231666666666, 0.527468, 0.577134], 
             UndirectedEdge[244, 390] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[92, 370] -> 
             RGBColor[0.9326351666666666, 0.912505, 0.660396], 
             UndirectedEdge[295, 458] -> 
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333], 
             UndirectedEdge[278, 493] -> 
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666], 
             UndirectedEdge[6, 156] -> 
             RGBColor[0.9127711666666667, 0.7414540000000002, 0.591337], 
             UndirectedEdge[79, 413] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[122, 476] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[123, 455] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[113, 302] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[402, 462] -> 
             RGBColor[
              0.9798641666666666, 0.9474946666666667, 0.5599291666666668], 
             UndirectedEdge[140, 363] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[440, 453] -> 
             RGBColor[
              0.8323468333333335, 0.6019803333333336, 0.5865696666666667], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[102, 202] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[363, 379] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[162, 297] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[19, 393] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[96, 238] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[117, 247] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[162, 223] -> 
             RGBColor[0.9006771666666666, 0.789404, 0.6159235000000001], 
             UndirectedEdge[355, 362] -> 
             RGBColor[
              0.7238368333333334, 0.7786993333333334, 0.7885666666666669], 
             UndirectedEdge[59, 395] -> 
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667], 
             UndirectedEdge[161, 403] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[214, 477] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[65, 309] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[361, 498] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[54, 70] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[369, 390] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[56, 88] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[289, 419] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[124, 178] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[67, 465] -> 
             RGBColor[
              0.9798641666666666, 0.9474946666666667, 0.5599291666666668], 
             UndirectedEdge[7, 461] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[273, 423] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[63, 467] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[179, 368] -> 
             RGBColor[0.674261, 0.7371853333333334, 0.8665405000000002], 
             UndirectedEdge[211, 485] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[21, 320] -> RGBColor[0.904911, 0.56025, 0.294797],
              UndirectedEdge[318, 479] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[343, 465] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[229, 313] -> 
             RGBColor[0.8621055000000001, 0.758648, 0.6122445], 
             UndirectedEdge[168, 401] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[70, 216] -> 
             RGBColor[
              0.9479061666666666, 0.8243936666666667, 0.5154566666666668], 
             UndirectedEdge[5, 193] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[213, 471] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[145, 404] -> 
             RGBColor[0.9289355, 0.7535093333333336, 0.5639750000000001], 
             UndirectedEdge[28, 173] -> 
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334], 
             UndirectedEdge[210, 243] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[133, 424] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[201, 400] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[120, 125] -> 
             RGBColor[0.9127711666666667, 0.7414540000000002, 0.591337], 
             UndirectedEdge[96, 343] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[22, 149] -> RGBColor[0.904911, 0.56025, 0.294797],
              UndirectedEdge[140, 369] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[169, 370] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[154, 380] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[33, 489] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[271, 284] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[112, 356] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[133, 155] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[82, 447] -> 
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334], 
             UndirectedEdge[225, 260] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[133, 225] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[442, 444] -> 
             RGBColor[0.9651515, 0.8927656666666668, 0.5293326666666668], 
             UndirectedEdge[49, 431] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[220, 427] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[151, 192] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[167, 326] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[109, 196] -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             UndirectedEdge[212, 451] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[186, 414] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[349, 419] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[162, 221] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[163, 364] -> 
             RGBColor[
              0.6086681666666667, 0.6799898333333334, 0.9523983333333333], 
             UndirectedEdge[191, 300] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[438, 460] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[172, 473] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[141, 188] -> 
             RGBColor[0.6787725, 0.6125309999999999, 0.5959515], 
             UndirectedEdge[79, 122] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[326, 475] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[98, 124] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[204, 498] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[72, 144] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[98, 331] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[311, 377] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[299, 389] -> 
             RGBColor[0.9280451666666667, 0.8108096666666667, 0.604082], 
             UndirectedEdge[131, 238] -> 
             RGBColor[
              0.9326321666666667, 0.7550380000000002, 0.5027116666666669], 
             UndirectedEdge[4, 185] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[162, 258] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[124, 253] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[319, 449] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[256, 271] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[379, 478] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[349, 371] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[130, 325] -> 
             RGBColor[0.845499, 0.3267073333333335, 0.19026250000000006`], 
             UndirectedEdge[269, 369] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[43, 355] -> 
             RGBColor[
              0.7025906666666666, 0.7653416666666666, 0.9582364999999999], 
             UndirectedEdge[11, 414] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[117, 255] -> 
             RGBColor[
              0.7417861666666666, 0.6636883333333333, 0.6009121666666667], 
             UndirectedEdge[401, 475] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[58, 141] -> 
             RGBColor[0.9280451666666667, 0.8108096666666667, 0.604082], 
             UndirectedEdge[96, 180] -> 
             RGBColor[
              0.7868504999999999, 0.8298566666666667, 0.7935273333333335], 
             UndirectedEdge[119, 375] -> 
             RGBColor[0.7120275, 0.5070206666666669, 0.5752373333333334], 
             UndirectedEdge[220, 382] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[104, 356] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[225, 440] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[259, 341] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[290, 362] -> 
             RGBColor[
              0.7868504999999999, 0.8298566666666667, 0.7935273333333335], 
             UndirectedEdge[79, 267] -> 
             RGBColor[0.7229105, 0.776718, 0.6877409999999999], 
             UndirectedEdge[90, 317] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[41, 389] -> 
             RGBColor[0.9006771666666666, 0.789404, 0.6159235000000001], 
             UndirectedEdge[5, 300] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[290, 340] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[288, 392] -> 
             RGBColor[
              0.8854031666666666, 0.7200483333333335, 0.6031785000000001], 
             UndirectedEdge[45, 292] -> 
             RGBColor[0.585715, 0.6458835, 0.6794385000000001], 
             UndirectedEdge[42, 145] -> 
             RGBColor[0.9289355, 0.7535093333333336, 0.563975], 
             UndirectedEdge[100, 368] -> 
             RGBColor[0.6544, 0.7236013333333333, 0.9551658333333333], 
             UndirectedEdge[302, 315] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[255, 338] -> 
             RGBColor[0.9442094999999999, 0.822865, 0.57672], 
             UndirectedEdge[59, 263] -> 
             RGBColor[0.9181475, 0.6677260000000003, 0.48978183333333347`], 
             UndirectedEdge[413, 486] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[140, 247] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[82, 453] -> 
             RGBColor[
              0.7731385000000001, 0.5557263333333335, 0.5806683333333333], 
             UndirectedEdge[199, 349] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[265, 462] -> 
             RGBColor[
              0.9812493333333333, 0.9472683333333334, 0.4788846666666668], 
             UndirectedEdge[113, 386] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[140, 219] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[13, 313] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[74, 463] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[146, 415] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[213, 475] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[49, 328] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[259, 450] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[454, 500] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[469, 495] -> 
             RGBColor[
              0.6270319999999999, 0.7021956666666667, 0.9670073333333333], 
             UndirectedEdge[158, 182] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685095], 
             UndirectedEdge[302, 347] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[87, 107] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[80, 307] -> 
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334], 
             UndirectedEdge[159, 443] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[396, 443] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[15, 452] -> 
             RGBColor[0.9326351666666666, 0.912505, 0.660396], 
             UndirectedEdge[55, 250] -> 
             RGBColor[
              0.8348551666666667, 0.8354950000000001, 0.6508156666666667], 
             UndirectedEdge[105, 447] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[55, 242] -> 
             RGBColor[0.9761675, 0.9459660000000001, 0.6211925], 
             UndirectedEdge[133, 440] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[177, 455] -> 
             RGBColor[0.6752226666666666, 0.7439359999999999, 0.970078], 
             UndirectedEdge[186, 456] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[94, 302] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[146, 376] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[44, 106] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[46, 205] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[134, 457] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[229, 248] -> 
             RGBColor[0.8621055000000001, 0.758648, 0.6122445], 
             UndirectedEdge[101, 362] -> 
             RGBColor[
              0.9812493333333333, 0.9472683333333334, 0.4788846666666668], 
             UndirectedEdge[286, 346] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[134, 138] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[144, 494] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[35, 147] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[5, 211] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[243, 471] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[154, 338] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[185, 383] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[416, 429] -> 
             RGBColor[0.5815595, 0.6465624999999999, 0.922572], 
             UndirectedEdge[159, 396] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[73, 322] -> 
             RGBColor[
              0.8201425000000001, 0.7807660000000001, 0.6202191666666667], 
             UndirectedEdge[287, 300] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[392, 459] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[200, 450] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[104, 148] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[94, 325] -> 
             RGBColor[0.9330910000000001, 0.7528303333333335, 0.3208415], 
             UndirectedEdge[355, 378] -> 
             RGBColor[0.6752226666666666, 0.7439359999999999, 0.970078], 
             UndirectedEdge[424, 453] -> 
             RGBColor[
              0.7731385000000001, 0.5557263333333335, 0.5806683333333333], 
             UndirectedEdge[212, 301] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[46, 420] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[146, 284] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[76, 343] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[111, 256] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[277, 319] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[240, 429] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[49, 71] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[19, 139] -> 
             RGBColor[0.948365, 0.8221860000000001, 0.3335865], 
             UndirectedEdge[9, 247] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[333, 392] -> 
             RGBColor[
              0.8709184999999999, 0.6327363333333336, 0.5902486666666666], 
             UndirectedEdge[169, 337] -> 
             RGBColor[
              0.6404563333333333, 0.7180833333333334, 0.9654583333333333], 
             UndirectedEdge[21, 119] -> 
             RGBColor[
              0.8310143333333333, 0.23939533333333354`, 0.1773326666666667], 
             UndirectedEdge[354, 479] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[179, 236] -> 
             RGBColor[0.9181475, 0.6677260000000003, 0.48978183333333347`], 
             UndirectedEdge[121, 341] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[263, 323] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[200, 401] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[56, 236] -> 
             RGBColor[
              0.9144508333333333, 0.6661973333333335, 0.5510451666666667], 
             UndirectedEdge[374, 437] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[74, 195] -> 
             RGBColor[
              0.9144508333333333, 0.6661973333333335, 0.5510451666666667], 
             UndirectedEdge[240, 399] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[138, 352] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[195, 342] -> 
             RGBColor[
              0.8709184999999999, 0.6327363333333336, 0.5902486666666666], 
             UndirectedEdge[13, 363] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[368, 386] -> 
             RGBColor[0.4681409999999999, 0.57648, 0.9519960000000001], 
             UndirectedEdge[132, 233] -> 
             RGBColor[0.6756461666666667, 0.736959, 0.7854960000000002], 
             UndirectedEdge[304, 310] -> 
             RGBColor[0.9127711666666667, 0.7414540000000002, 0.591337], 
             UndirectedEdge[213, 259] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[226, 446] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[60, 249] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[181, 387] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[94, 168] -> 
             RGBColor[
              0.7859241666666666, 0.8278753333333333, 0.6927016666666667], 
             UndirectedEdge[142, 402] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[188, 310] -> 
             RGBColor[
              0.7025906666666666, 0.7653416666666666, 0.9582364999999999], 
             UndirectedEdge[74, 239] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685095], 
             UndirectedEdge[376, 400] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[292, 308] -> 
             RGBColor[
              0.9934293333333333, 0.9883543333333333, 0.5262016666666668], 
             UndirectedEdge[7, 142] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[20, 194] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[168, 500] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[4, 383] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[91, 303] -> 
             RGBColor[
              0.9058373333333334, 0.5622313333333333, 0.3956226666666668], 
             UndirectedEdge[142, 417] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[229, 338] -> 
             RGBColor[0.9442094999999999, 0.822865, 0.57672], 
             UndirectedEdge[69, 388] -> 
             RGBColor[
              0.6747198333333333, 0.7349776666666668, 0.6846703333333333], 
             UndirectedEdge[170, 374] -> 
             RGBColor[0.8845911666666666, 0.5488736666666667, 0.5652925], 
             UndirectedEdge[96, 281] -> 
             RGBColor[
              0.6404563333333333, 0.7180833333333334, 0.9654583333333333], 
             UndirectedEdge[131, 265] -> 
             RGBColor[
              0.9340173333333334, 0.7548116666666669, 0.4216671666666668], 
             UndirectedEdge[117, 369] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[19, 247] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[328, 436] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[86, 178] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[42, 137] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[54, 135] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[42, 174] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[1, 374] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[160, 285] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[454, 471] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[26, 425] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[333, 442] -> 
             RGBColor[
              0.8917136666666667, 0.5697033333333337, 0.22999816666666673`], 
             UndirectedEdge[75, 410] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[31, 40] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[3, 258] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[132, 273] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[157, 180] -> 
             RGBColor[
              0.7868504999999999, 0.8298566666666667, 0.7935273333333335], 
             UndirectedEdge[213, 401] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[84, 391] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[43, 110] -> 
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667], 
             UndirectedEdge[39, 127] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[52, 469] -> 
             RGBColor[0.627032, 0.7021956666666667, 0.9670073333333333], 
             UndirectedEdge[260, 483] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[98, 311] -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             UndirectedEdge[51, 127] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[243, 475] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[76, 96] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[99, 476] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[107, 308] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[190, 263] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[191, 299] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[39, 276] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[51, 214] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[295, 409] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[371, 382] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[53, 420] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[87, 308] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[286, 358] -> 
             RGBColor[0.9280451666666667, 0.8108096666666667, 0.604082], 
             UndirectedEdge[215, 351] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[114, 258] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[87, 292] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[196, 383] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[65, 495] -> 
             RGBColor[
              0.6705643333333333, 0.7356566666666666, 0.9278038333333334], 
             UndirectedEdge[14, 279] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[26, 466] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[27, 371] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[258, 472] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[26, 117] -> 
             RGBColor[
              0.7868504999999999, 0.8298566666666667, 0.7935273333333335], 
             UndirectedEdge[97, 104] -> 
             RGBColor[0.948365, 0.8221860000000001, 0.3335865], 
             UndirectedEdge[21, 428] -> 
             RGBColor[0.6353185, 0.350595, 0.557162], 
             UndirectedEdge[160, 268] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[48, 137] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685095], 
             UndirectedEdge[27, 291] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[117, 140] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[31, 221] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[87, 386] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[207, 409] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[274, 498] -> 
             RGBColor[
              0.7859241666666666, 0.8278753333333333, 0.6927016666666667], 
             UndirectedEdge[28, 69] -> 
             RGBColor[0.6756461666666667, 0.736959, 0.7854960000000002], 
             UndirectedEdge[442, 492] -> 
             RGBColor[
              0.8201425000000001, 0.7807660000000001, 0.6202191666666667], 
             UndirectedEdge[476, 493] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[297, 359] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[112, 323] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[27, 349] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[2, 242] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[71, 462] -> 
             RGBColor[0.9326351666666666, 0.912505, 0.660396], 
             UndirectedEdge[165, 285] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[91, 172] -> 
             RGBColor[0.8186515000000001, 0.49671200000000004`, 0.573455], 
             UndirectedEdge[19, 26] -> 
             RGBColor[
              0.9934293333333333, 0.9883543333333333, 0.5262016666666668], 
             UndirectedEdge[73, 163] -> 
             RGBColor[0.48352016666666675`, 0.5815741666666667, 0.9546595], 
             UndirectedEdge[67, 131] -> 
             RGBColor[0.920911, 0.7117443333333335, 0.27352450000000006`], 
             UndirectedEdge[24, 81] -> 
             RGBColor[0.674261, 0.7371853333333334, 0.8665405000000002], 
             UndirectedEdge[282, 467] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[122, 406] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[139, 255] -> 
             RGBColor[0.904227, 0.657999, 0.241797], UndirectedEdge[409, 458] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[4, 196] -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             UndirectedEdge[46, 90] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[115, 124] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[330, 350] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[213, 315] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[107, 143] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[403, 491] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[200, 254] -> 
             RGBColor[0.9761675, 0.9459660000000001, 0.6211925], 
             UndirectedEdge[37, 304] -> 
             RGBColor[
              0.8468315000000002, 0.6892923333333336, 0.5994995000000001], 
             UndirectedEdge[25, 392] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[231, 492] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[22, 63] -> 
             RGBColor[
              0.7859241666666666, 0.8278753333333333, 0.6927016666666667], 
             UndirectedEdge[201, 256] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[57, 92] -> 
             RGBColor[0.9326351666666666, 0.912505, 0.660396], 
             UndirectedEdge[433, 462] -> 
             RGBColor[
              0.9600031666666666, 0.9339106666666667, 0.6485544999999999], 
             UndirectedEdge[286, 294] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[319, 331] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[222, 307] -> 
             RGBColor[
              0.9934293333333333, 0.9883543333333333, 0.5262016666666668], 
             UndirectedEdge[276, 283] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[464, 497] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[143, 283] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[265, 433] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[74, 234] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[17, 432] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[103, 118] -> 
             RGBColor[
              0.8323468333333335, 0.6019803333333336, 0.5865696666666667], 
             UndirectedEdge[426, 489] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[277, 331] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[74, 112] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[80, 372] -> 
             RGBColor[0.7594431666666668, 0.450458, 0.5675536666666666], 
             UndirectedEdge[180, 281] -> 
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334], 
             UndirectedEdge[263, 296] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[37, 141] -> 
             RGBColor[0.8621055000000001, 0.758648, 0.6122445000000001], 
             UndirectedEdge[18, 210] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[279, 494] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[101, 337] -> 
             RGBColor[
              0.7737441666666667, 0.7867893333333333, 0.6453846666666667], 
             UndirectedEdge[217, 378] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[20, 62] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[18, 56] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[444, 492] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[199, 427] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[190, 463] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[139, 369] -> 
             RGBColor[0.8621055000000001, 0.758648, 0.6122445], 
             UndirectedEdge[10, 455] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[52, 236] -> 
             RGBColor[
              0.6008231666666667, 0.4141230000000002, 0.5672060000000001], 
             UndirectedEdge[9, 19] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[33, 309] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[341, 491] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[87, 143] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[110, 378] -> 
             RGBColor[
              0.8709184999999999, 0.6327363333333336, 0.5902486666666666], 
             UndirectedEdge[401, 471] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[160, 165] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[13, 379] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[210, 434] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[308, 446] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[153, 395] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[24, 83] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[133, 260] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[83, 119] -> 
             RGBColor[
              0.9144508333333333, 0.6661973333333335, 0.5510451666666667], 
             UndirectedEdge[400, 464] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[175, 320] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[39, 475] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[289, 291] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[263, 342] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[311, 319] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[141, 304] -> 
             RGBColor[
              0.8889530000000001, 0.5886433333333335, 0.22905200000000003`], 
             UndirectedEdge[30, 43] -> 
             RGBColor[0.8845911666666666, 0.5488736666666667, 0.5652925], 
             UndirectedEdge[85, 95] -> 
             RGBColor[0.8927309999999999, 0.519164, 0.24747999999999998`], 
             UndirectedEdge[305, 438] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[23, 212] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[80, 461] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[115, 439] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[136, 377] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[27, 488] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[70, 170] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[268, 441] -> 
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334], 
             UndirectedEdge[394, 445] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[234, 393] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[228, 388] -> 
             RGBColor[0.980323, 0.945287, 0.378059], UndirectedEdge[8, 114] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[21, 164] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[100, 454] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[6, 267] -> 
             RGBColor[
              0.7025906666666666, 0.7653416666666666, 0.9582364999999999], 
             UndirectedEdge[210, 495] -> 
             RGBColor[0.6544, 0.7236013333333333, 0.9551658333333333], 
             UndirectedEdge[112, 342] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[93, 206] -> 
             RGBColor[
              0.7607756666666667, 0.8130430000000001, 0.9767906666666666], 
             UndirectedEdge[485, 497] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[36, 240] -> 
             RGBColor[0.718755, 0.777397, 0.9308745], 
             UndirectedEdge[275, 285] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[36, 399] -> 
             RGBColor[
              0.5163316666666666, 0.6182203333333334, 0.9550666666666667], 
             UndirectedEdge[72, 279] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[278, 413] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[10, 120] -> 
             RGBColor[0.9289355, 0.7535093333333336, 0.563975], 
             UndirectedEdge[59, 153] -> 
             RGBColor[
              0.9144508333333333, 0.6661973333333335, 0.5510451666666667], 
             UndirectedEdge[377, 488] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[53, 306] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[172, 448] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[138, 367] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[71, 431] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[180, 392] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[33, 227] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[30, 384] -> 
             RGBColor[
              0.8310143333333333, 0.23939533333333354`, 0.1773326666666667], 
             UndirectedEdge[441, 467] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[99, 122] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[89, 225] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685095], 
             UndirectedEdge[146, 497] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[176, 197] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[326, 474] -> 
             RGBColor[
              0.6705643333333333, 0.7356566666666666, 0.9278038333333334], 
             UndirectedEdge[173, 241] -> 
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666], 
             UndirectedEdge[403, 405] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[79, 476] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[46, 257] -> 
             RGBColor[0.9614548333333334, 0.8912370000000001, 0.590596], 
             UndirectedEdge[450, 491] -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             UndirectedEdge[200, 243] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[296, 424] -> 
             RGBColor[
              0.6404563333333333, 0.7180833333333334, 0.9654583333333333], 
             UndirectedEdge[269, 466] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[74, 453] -> 
             RGBColor[
              0.9144508333333333, 0.6661973333333335, 0.5510451666666667], 
             UndirectedEdge[18, 469] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[279, 481] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[19, 468] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[415, 464] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685095], 
             UndirectedEdge[234, 262] -> 
             RGBColor[
              0.8468315000000002, 0.6892923333333336, 0.5994995000000001], 
             UndirectedEdge[241, 417] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[309, 489] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[83, 426] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[6, 99] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[121, 491] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[42, 358] -> 
             RGBColor[0.9442094999999999, 0.822865, 0.57672], 
             UndirectedEdge[69, 461] -> 
             RGBColor[
              0.6543999999999999, 0.7236013333333333, 0.9551658333333333], 
             UndirectedEdge[161, 387] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[117, 390] -> 
             RGBColor[
              0.7859241666666666, 0.8278753333333333, 0.6927016666666667], 
             UndirectedEdge[244, 334] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[173, 493] -> 
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666], 
             UndirectedEdge[229, 255] -> 
             RGBColor[0.904227, 0.657999, 0.241797], UndirectedEdge[39, 401] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[379, 380] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[92, 140] -> 
             RGBColor[
              0.9798641666666666, 0.9474946666666667, 0.5599291666666668], 
             UndirectedEdge[78, 97] -> 
             RGBColor[0.8621055000000001, 0.758648, 0.6122445000000001], 
             UndirectedEdge[395, 463] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[174, 338] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[143, 423] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[94, 100] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[404, 408] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[301, 389] -> 
             RGBColor[
              0.7417861666666666, 0.6636883333333333, 0.6009121666666667], 
             UndirectedEdge[16, 422] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[389, 451] -> 
             RGBColor[
              0.9479061666666666, 0.8243936666666667, 0.5154566666666668], 
             UndirectedEdge[74, 296] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[225, 453] -> 
             RGBColor[
              0.9186063333333334, 0.6655183333333335, 0.3079116666666667], 
             UndirectedEdge[340, 378] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[52, 428] -> 
             RGBColor[
              0.4051273333333333, 0.5253226666666666, 0.9470353333333333], 
             UndirectedEdge[84, 230] -> 
             RGBColor[
              0.5163316666666666, 0.6182203333333334, 0.9550666666666667], 
             UndirectedEdge[119, 237] -> 
             RGBColor[0.6008231666666667, 0.4141230000000002, 0.567206], 
             UndirectedEdge[67, 171] -> 
             RGBColor[
              0.8348551666666667, 0.8354950000000001, 0.6508156666666667], 
             UndirectedEdge[25, 157] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[124, 484] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[368, 500] -> 
             RGBColor[
              0.6543999999999999, 0.7236013333333333, 0.9551658333333333], 
             UndirectedEdge[283, 422] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[334, 369] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[42, 346] -> 
             RGBColor[
              0.9892738333333333, 0.9890333333333334, 0.7693351666666668], 
             UndirectedEdge[112, 263] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[146, 201] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[16, 243] -> 
             RGBColor[
              0.7607756666666667, 0.8130430000000001, 0.9767906666666666], 
             UndirectedEdge[285, 481] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[231, 444] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[137, 408] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[431, 436] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[98, 277] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[131, 391] -> 
             RGBColor[0.9127711666666667, 0.7414540000000002, 0.591337], 
             UndirectedEdge[52, 227] -> 
             RGBColor[
              0.6543999999999999, 0.7236013333333333, 0.9551658333333333], 
             UndirectedEdge[27, 419] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[232, 312] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[247, 466] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[253, 484] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[121, 200] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[79, 99] -> 
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666], 
             UndirectedEdge[109, 300] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[31, 397] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[70, 374] -> 
             RGBColor[
              0.9044521666666667, 0.5624576666666667, 0.47666716666666675`], 
             UndirectedEdge[240, 352] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[105, 323] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[46, 53] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685095], 
             UndirectedEdge[221, 223] -> 
             RGBColor[0.9442094999999999, 0.822865, 0.57672], 
             UndirectedEdge[33, 159] -> 
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334], 
             UndirectedEdge[16, 454] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[195, 224] -> 
             RGBColor[
              0.9186063333333334, 0.6655183333333337, 0.3079116666666667], 
             UndirectedEdge[259, 500] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[24, 77] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[226, 386] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[289, 314] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[179, 325] -> 
             RGBColor[
              0.9326321666666667, 0.7550380000000002, 0.5027116666666668], 
             UndirectedEdge[81, 83] -> 
             RGBColor[
              0.6705643333333333, 0.7356566666666666, 0.9278038333333334], 
             UndirectedEdge[312, 376] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[270, 309] -> 
             RGBColor[0.9181475, 0.6677260000000003, 0.48978183333333347`], 
             UndirectedEdge[139, 269] -> 
             RGBColor[0.9442094999999999, 0.822865, 0.57672], 
             UndirectedEdge[269, 425] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[25, 492] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[142, 173] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[132, 209] -> 
             RGBColor[
              0.9492913333333333, 0.8241673333333334, 0.4344121666666668], 
             UndirectedEdge[389, 409] -> 
             RGBColor[0.9006771666666666, 0.789404, 0.6159235], 
             UndirectedEdge[337, 370] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[230, 242] -> 
             RGBColor[0.718755, 0.777397, 0.9308745], UndirectedEdge[28, 461] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[318, 350] -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             UndirectedEdge[390, 478] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[167, 434] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685095], 
             UndirectedEdge[247, 269] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[394, 398] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[14, 158] -> 
             RGBColor[0.992503, 0.986373, 0.425376], UndirectedEdge[131, 433] -> 
             RGBColor[0.9127711666666667, 0.7414540000000002, 0.591337], 
             UndirectedEdge[87, 422] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[210, 469] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[312, 414] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[277, 311] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[332, 424] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[328, 433] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[88, 428] -> 
             RGBColor[0.6752226666666666, 0.7439359999999999, 0.970078], 
             UndirectedEdge[8, 162] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[27, 289] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[192, 280] -> 
             RGBColor[0.9179225, 0.8577760000000001, 0.6297995000000001], 
             UndirectedEdge[347, 477] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[145, 346] -> 
             RGBColor[
              0.9340173333333334, 0.7548116666666669, 0.4216671666666668], 
             UndirectedEdge[232, 415] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[189, 374] -> 
             RGBColor[0.9007555, 0.560929, 0.5379305], 
             UndirectedEdge[139, 140] -> 
             RGBColor[
              0.9479061666666666, 0.8243936666666667, 0.5154566666666668], 
             UndirectedEdge[134, 251] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[67, 281] -> 
             RGBColor[
              0.8348551666666667, 0.8354950000000001, 0.6508156666666667], 
             UndirectedEdge[167, 495] -> 
             RGBColor[
              0.6705643333333333, 0.7356566666666666, 0.9278038333333334], 
             UndirectedEdge[143, 179] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[21, 175] -> 
             RGBColor[0.8572231666666666, 0.527468, 0.577134], 
             UndirectedEdge[366, 473] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[143, 292] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[267, 486] -> 
             RGBColor[
              0.7224516666666667, 0.7789256666666666, 0.8696111666666668], 
             UndirectedEdge[248, 380] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[48, 407] -> 
             RGBColor[
              0.7859241666666666, 0.8278753333333333, 0.6927016666666667], 
             UndirectedEdge[436, 459] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[235, 262] -> 
             RGBColor[
              0.8468315000000002, 0.6892923333333336, 0.5994995000000001], 
             UndirectedEdge[236, 283] -> 
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667], 
             UndirectedEdge[99, 493] -> 
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666], 
             UndirectedEdge[109, 456] -> 
             RGBColor[
              0.7868504999999999, 0.8298566666666667, 0.7935273333333335], 
             UndirectedEdge[208, 289] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[266, 410] -> 
             RGBColor[
              0.6404563333333333, 0.7180833333333334, 0.9654583333333333], 
             UndirectedEdge[299, 301] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[314, 359] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[209, 214] -> 
             RGBColor[
              0.9492913333333333, 0.8241673333333334, 0.4344121666666668], 
             UndirectedEdge[210, 326] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[53, 317] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[402, 459] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[89, 249] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[67, 135] -> 
             RGBColor[
              0.9798641666666666, 0.9474946666666667, 0.5599291666666668], 
             UndirectedEdge[90, 178] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[174, 229] -> 
             RGBColor[0.8621055000000001, 0.758648, 0.6122445000000001], 
             UndirectedEdge[266, 364] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[407, 430] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[217, 355] -> 
             RGBColor[0.5774426666666668, 0.666926, 0.9604976666666667], 
             UndirectedEdge[176, 426] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[280, 483] -> 
             RGBColor[0.9656103333333335, 0.8905580000000002, 0.3474625], 
             UndirectedEdge[51, 347] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[152, 451] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[105, 342] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[318, 496] -> 
             RGBColor[0.9731095, 0.976978, 0.7966971666666668], 
             UndirectedEdge[114, 289] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[103, 331] -> 
             RGBColor[
              0.8709184999999999, 0.6327363333333336, 0.5902486666666666], 
             UndirectedEdge[107, 113] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[16, 56] -> 
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666], 
             UndirectedEdge[140, 370] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[213, 500] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[280, 327] -> 
             RGBColor[0.9179225, 0.8577760000000001, 0.6297995000000001], 
             UndirectedEdge[76, 238] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[253, 261] -> 
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034], 
             UndirectedEdge[232, 350] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[166, 320] -> 
             RGBColor[0.9883474999999999, 0.987052, 0.6685095], 
             UndirectedEdge[33, 119] -> 
             RGBColor[
              0.7731385000000001, 0.5557263333333335, 0.5806683333333333], 
             UndirectedEdge[71, 228] -> 
             RGBColor[0.9326351666666666, 0.912505, 0.660396], 
             UndirectedEdge[50, 244] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[235, 344] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[72, 494] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[185, 496] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[106, 370] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[51, 113] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[422, 443] -> 
             RGBColor[
              0.9443563333333334, 0.9557986666666667, 0.8895831666666667], 
             UndirectedEdge[4, 335] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[1, 84] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[90, 272] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[213, 450] -> 
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334], 
             UndirectedEdge[5, 212] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[50, 106] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[115, 291] -> 
             RGBColor[
              0.7817686666666666, 0.8285543333333334, 0.9358351666666667], 
             UndirectedEdge[9, 117] -> 
             RGBColor[
              0.6996646666666667, 0.7643373333333334, 0.9713596666666666], 
             UndirectedEdge[194, 388] -> 
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713], 
             UndirectedEdge[202, 211] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[113, 308] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[51, 421] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[109, 335] -> 
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667], 
             UndirectedEdge[278, 329] -> 
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334], 
             UndirectedEdge[129, 206] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[166, 227] -> 
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005], 
             UndirectedEdge[294, 411] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[362, 384] -> 
             RGBColor[
              0.9195326666666667, 0.6674996666666669, 0.4087373333333335], 
             UndirectedEdge[143, 308] -> 
             RGBColor[0.9929705, 0.990562, 0.7080718333333336], 
             UndirectedEdge[151, 310] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[297, 397] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[114, 359] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[141, 220] -> 
             RGBColor[
              0.9479061666666666, 0.8243936666666667, 0.5154566666666668], 
             UndirectedEdge[122, 493] -> 
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715], 
             UndirectedEdge[146, 442] -> 
             RGBColor[0.9651515, 0.8927656666666668, 0.5293326666666668], 
             UndirectedEdge[294, 478] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[76, 487] -> 
             RGBColor[0.8621055000000001, 0.758648, 0.6122445000000001], 
             UndirectedEdge[67, 70] -> 
             RGBColor[
              0.9798641666666666, 0.9474946666666667, 0.5599291666666668], 
             UndirectedEdge[346, 358] -> 
             RGBColor[
              0.9492913333333333, 0.8241673333333334, 0.4344121666666668], 
             UndirectedEdge[149, 165] -> 
             RGBColor[0.8572231666666666, 0.527468, 0.577134], 
             UndirectedEdge[175, 375] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[18, 428] -> 
             RGBColor[
              0.5163316666666666, 0.6182203333333334, 0.9550666666666667], 
             UndirectedEdge[2, 47] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[140, 466] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[199, 382] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[305, 499] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[252, 282] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[235, 249] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[130, 214] -> 
             RGBColor[
              0.9058373333333334, 0.5622313333333333, 0.3956226666666668], 
             UndirectedEdge[100, 475] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[10, 438] -> 
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999], 
             UndirectedEdge[39, 179] -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             UndirectedEdge[400, 414] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[41, 191] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[25, 96] -> 
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667], 
             UndirectedEdge[106, 274] -> 
             RGBColor[
              0.9920441666666666, 0.9885806666666668, 0.6072461666666668], 
             UndirectedEdge[204, 363] -> 
             RGBColor[
              0.9878886666666666, 0.9892596666666666, 0.8503796666666668], 
             UndirectedEdge[99, 413] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[37, 118] -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 
             UndirectedEdge[411, 478] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[300, 451] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[122, 233] -> 
             RGBColor[0.6544, 0.7236013333333333, 0.9551658333333333], 
             UndirectedEdge[97, 404] -> 
             RGBColor[0.9442094999999999, 0.822865, 0.57672], 
             UndirectedEdge[362, 498] -> 
             RGBColor[
              0.7868504999999999, 0.8298566666666667, 0.7935273333333335], 
             UndirectedEdge[121, 454] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[173, 417] -> 
             RGBColor[
              0.8465763333333334, 0.8787886666666667, 0.8800028333333334], 
             UndirectedEdge[36, 352] -> 
             RGBColor[
              0.7224516666666667, 0.7789256666666666, 0.8696111666666668], 
             UndirectedEdge[309, 337] -> 
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334], 
             UndirectedEdge[207, 456] -> 
             RGBColor[
              0.7868504999999999, 0.8298566666666667, 0.7935273333333335], 
             UndirectedEdge[95, 97] -> 
             RGBColor[0.860773, 0.396063, 0.2030075], 
             UndirectedEdge[185, 350] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[303, 435] -> 
             RGBColor[
              0.7868504999999999, 0.8298566666666667, 0.7935273333333335], 
             UndirectedEdge[14, 441] -> 
             RGBColor[
              0.9934293333333333, 0.9883543333333333, 0.5262016666666668], 
             UndirectedEdge[67, 147] -> 
             RGBColor[0.9761675, 0.9459660000000001, 0.6211925], 
             UndirectedEdge[115, 419] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[113, 209] -> 
             RGBColor[0.9006771666666666, 0.789404, 0.6159235000000001], 
             UndirectedEdge[100, 121] -> 
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295], 
             UndirectedEdge[39, 254] -> 
             RGBColor[
              0.9798641666666666, 0.9474946666666667, 0.5599291666666668], 
             UndirectedEdge[2, 339] -> 
             RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             UndirectedEdge[76, 436] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[121, 161] -> 
             RGBColor[
              0.9071698333333333, 0.9248163333333335, 0.8048596666666668], 
             UndirectedEdge[215, 430] -> 
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999], 
             UndirectedEdge[100, 254] -> 
             RGBColor[
              0.9600031666666666, 0.9339106666666667, 0.6485544999999999], 
             UndirectedEdge[186, 389] -> 
             RGBColor[0.9442094999999999, 0.822865, 0.57672], 
             UndirectedEdge[197, 426] -> 
             RGBColor[
              0.9057846666666667, 0.9250426666666667, 0.8859041666666667], 
             UndirectedEdge[316, 378] -> 
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085], 
             UndirectedEdge[185, 330] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[56, 166] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[38, 73] -> 
             RGBColor[
              0.8267153333333334, 0.8652046666666666, 0.9686281666666666], 
             UndirectedEdge[97, 430] -> 
             RGBColor[0.9442094999999999, 0.822865, 0.57672], 
             UndirectedEdge[222, 372] -> 
             RGBColor[0.904911, 0.56025, 0.294797], UndirectedEdge[137, 430] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[30, 355] -> 
             RGBColor[0.6353185, 0.350595, 0.557162], 
             UndirectedEdge[111, 442] -> 
             RGBColor[0.9452905, 0.8791816666666668, 0.617958], 
             UndirectedEdge[183, 408] -> 
             RGBColor[0.8585556666666667, 0.890053, 0.986371], 
             UndirectedEdge[39, 283] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[244, 498] -> 
             RGBColor[
              0.7382363333333333, 0.7950933333333333, 0.9750386666666666], 
             UndirectedEdge[259, 454] -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             UndirectedEdge[17, 418] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666], 
             UndirectedEdge[70, 391] -> 
             RGBColor[
              0.9717243333333333, 0.9772043333333333, 0.8777416666666668], 
             UndirectedEdge[18, 495] -> 
             RGBColor[0.4681409999999999, 0.57648, 0.9519960000000001], 
             UndirectedEdge[48, 95] -> RGBColor[0.904911, 0.56025, 0.294797], 
             UndirectedEdge[50, 92] -> 
             RGBColor[
              0.8348551666666667, 0.8354950000000001, 0.6508156666666667], 
             UndirectedEdge[118, 141] -> 
             RGBColor[0.8621055000000001, 0.758648, 0.6122445000000001], 
             UndirectedEdge[373, 398] -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 
             UndirectedEdge[218, 409] -> 
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.8736790000000001, 0.519287666666667, 0.21630700000000008`], 
             316 -> RGBColor[
              0.9518633333333333, 0.9636203333333333, 0.966367], 308 -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             160 -> RGBColor[0.8971273333333333, 0.920809, 0.99005], 245 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 155 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 425 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 213 -> 
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333], 352 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 27 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 485 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 454 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 367 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 19 -> 
             RGBColor[0.992503, 0.986373, 0.425376], 164 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 190 -> 
             RGBColor[0.992503, 0.986373, 0.425376], 103 -> 
             RGBColor[
              0.8447096666666667, 0.3446636666666671, 0.19044733333333339`], 
             138 -> RGBColor[0.992503, 0.986373, 0.425376], 416 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 476 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 291 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 28 -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             337 -> RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             195 -> RGBColor[
              0.8447096666666667, 0.3446636666666671, 0.19044733333333339`], 
             114 -> RGBColor[0.8971273333333333, 0.920809, 0.99005], 479 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 93 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 34 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             161 -> RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 22 -> 
             RGBColor[0.992503, 0.986373, 0.425376], 124 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 84 -> 
             RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 46 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 241 -> 
             RGBColor[0.992503, 0.986373, 0.425376], 185 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 426 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             390 -> RGBColor[0.992503, 0.986373, 0.425376], 121 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 322 -> 
             RGBColor[
              0.9387176666666668, 0.7947430000000002, 0.26954900000000004`], 
             488 -> RGBColor[0.984192, 0.987731, 0.911643], 126 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             433 -> RGBColor[
              0.9518633333333333, 0.9636203333333333, 0.966367], 236 -> 
             RGBColor[
              0.8447096666666667, 0.3446636666666671, 0.19044733333333339`], 
             78 -> RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692],
              376 -> RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             458 -> RGBColor[
              0.7015673333333334, 0.766789, 0.9708893333333333], 254 -> 
             RGBColor[0.968143, 0.904201, 0.330742], 290 -> 
             RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             251 -> RGBColor[0.8971273333333333, 0.920809, 0.99005], 165 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 460 -> 
             RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             100 -> RGBColor[
              0.9518633333333333, 0.9636203333333333, 0.966367], 235 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 70 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             234 -> RGBColor[
              0.8199840000000002, 0.8592970000000001, 0.982692], 435 -> 
             RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             257 -> RGBColor[
              0.9387176666666668, 0.7947430000000002, 0.26954900000000004`], 
             135 -> RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             265 -> RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             111 -> RGBColor[
              0.9518633333333333, 0.9636203333333333, 0.966367], 497 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 481 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 381 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 182 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 188 -> 
             RGBColor[0.453318, 0.567063, 0.950106], 154 -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             336 -> RGBColor[0.8971273333333333, 0.920809, 0.99005], 463 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 315 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 368 -> 
             RGBColor[
              0.3569366666666666, 0.4835823333333333, 0.9439646666666667], 
             269 -> RGBColor[0.984192, 0.987731, 0.911643], 208 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 86 -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             119 -> RGBColor[
              0.8447096666666667, 0.3446636666666671, 0.19044733333333339`], 
             436 -> RGBColor[0.8971273333333333, 0.920809, 0.99005], 377 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 140 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 85 -> 
             RGBColor[0.968143, 0.904201, 0.330742], 351 -> 
             RGBColor[0.992503, 0.986373, 0.425376], 443 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 242 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 117 -> 
             RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 47 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 451 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 81 -> 
             RGBColor[
              0.3569366666666666, 0.4835823333333333, 0.9439646666666667], 
             275 -> RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 23 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 328 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 418 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 110 -> 
             RGBColor[
              0.8447096666666667, 0.3446636666666671, 0.19044733333333339`], 
             6 -> RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 
             218 -> RGBColor[
              0.7015673333333334, 0.766789, 0.9708893333333333], 108 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 297 -> 
             RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             487 -> RGBColor[0.904227, 0.657999, 0.241797], 464 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 157 -> 
             RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             441 -> RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             354 -> RGBColor[
              0.9518633333333333, 0.9636203333333333, 0.966367], 385 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 270 -> 
             RGBColor[
              0.8447096666666667, 0.3446636666666671, 0.19044733333333339`], 
             392 -> RGBColor[0.8971273333333333, 0.920809, 0.99005], 33 -> 
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333], 252 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 394 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 260 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 159 -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             183 -> RGBColor[0.8971273333333333, 0.920809, 0.99005], 99 -> 
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333], 329 -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             309 -> RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 17 -> 
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333], 349 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 495 -> 
             RGBColor[
              0.3569366666666666, 0.4835823333333333, 0.9439646666666667], 
             347 -> RGBColor[
              0.8199840000000002, 0.8592970000000001, 0.982692], 340 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 404 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 277 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 104 -> 
             RGBColor[0.992503, 0.986373, 0.425376], 79 -> 
             RGBColor[0.992503, 0.986373, 0.425376], 327 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 191 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 50 -> 
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333], 225 -> 
             RGBColor[0.992503, 0.986373, 0.425376], 405 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 61 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 196 -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 1 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 263 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             201 -> RGBColor[
              0.8199840000000002, 0.8592970000000001, 0.982692], 371 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 293 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 362 -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             184 -> RGBColor[
              0.9518633333333333, 0.9636203333333333, 0.966367], 106 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             206 -> 
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333], 358 -> 
             RGBColor[0.904227, 0.657999, 0.241797], 247 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 220 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             407 -> RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             107 -> RGBColor[
              0.9518633333333333, 0.9636203333333333, 0.966367], 375 -> 
             RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             131 -> RGBColor[
              0.8736790000000001, 0.519287666666667, 0.21630700000000008`], 
             411 -> RGBColor[0.8971273333333333, 0.920809, 0.99005], 462 -> 
             RGBColor[0.968143, 0.904201, 0.330742], 127 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             210 -> RGBColor[
              0.9518633333333333, 0.9636203333333333, 0.966367], 357 -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             181 -> RGBColor[
              0.9518633333333333, 0.9636203333333333, 0.966367], 194 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 440 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 490 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 118 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 348 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             276 -> RGBColor[
              0.9518633333333333, 0.9636203333333333, 0.966367], 305 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 343 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 280 -> 
             RGBColor[
              0.9387176666666668, 0.7947430000000002, 0.26954900000000004`], 
             474 -> RGBColor[
              0.3569366666666666, 0.4835823333333333, 0.9439646666666667], 
             189 -> RGBColor[0.984192, 0.987731, 0.911643], 168 -> 
             RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             363 -> RGBColor[0.984192, 0.987731, 0.911643], 41 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 14 -> 
             RGBColor[0.992503, 0.986373, 0.425376], 77 -> 
             RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 51 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 438 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 179 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             467 -> RGBColor[
              0.9518633333333333, 0.9636203333333333, 0.966367], 223 -> 
             RGBColor[0.904227, 0.657999, 0.241797], 456 -> 
             RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             323 -> RGBColor[0.8971273333333333, 0.920809, 0.99005], 500 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 478 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 292 -> 
             RGBColor[0.992503, 0.986373, 0.425376], 491 -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             396 -> RGBColor[
              0.9518633333333333, 0.9636203333333333, 0.966367], 321 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 143 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             112 -> RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             197 -> RGBColor[
              0.8199840000000002, 0.8592970000000001, 0.982692], 421 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 54 -> 
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333], 71 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 177 -> 
             RGBColor[0.453318, 0.567063, 0.950106], 158 -> 
             RGBColor[0.992503, 0.986373, 0.425376], 226 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 432 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 350 -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             203 -> RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             475 -> RGBColor[0.8971273333333333, 0.920809, 0.99005], 115 -> 
             RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             173 -> RGBColor[
              0.7015673333333334, 0.766789, 0.9708893333333333], 212 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 129 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 279 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 26 -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 40 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 146 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             386 -> RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             192 -> RGBColor[0.8971273333333333, 0.920809, 0.99005], 300 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 221 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 62 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 286 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 472 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 152 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 64 -> 
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333], 307 -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 37 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 148 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 261 -> 
             RGBColor[0.992503, 0.986373, 0.425376], 387 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 15 -> 
             RGBColor[0.968143, 0.904201, 0.330742], 136 -> 
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333], 198 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 63 -> 
             RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             444 -> RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             310 -> RGBColor[
              0.9518633333333333, 0.9636203333333333, 0.966367], 171 -> 
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333], 395 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 311 -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             353 -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 59 -> 
             RGBColor[
              0.8447096666666667, 0.3446636666666671, 0.19044733333333339`], 
             397 -> RGBColor[
              0.9518633333333333, 0.9636203333333333, 0.966367], 229 -> 
             RGBColor[0.904227, 0.657999, 0.241797], 102 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 453 -> 
             RGBColor[
              0.8447096666666667, 0.3446636666666671, 0.19044733333333339`], 
             299 -> RGBColor[
              0.9518633333333333, 0.9636203333333333, 0.966367], 128 -> 
             RGBColor[0.904227, 0.657999, 0.241797], 12 -> 
             RGBColor[0.968143, 0.904201, 0.330742], 222 -> 
             RGBColor[0.992503, 0.986373, 0.425376], 483 -> 
             RGBColor[0.992503, 0.986373, 0.425376], 92 -> 
             RGBColor[0.968143, 0.904201, 0.330742], 271 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 361 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             344 -> RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             132 -> RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 80 -> 
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333], 324 -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             244 -> RGBColor[0.8971273333333333, 0.920809, 0.99005], 150 -> 
             RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             125 -> RGBColor[
              0.9518633333333333, 0.9636203333333333, 0.966367], 258 -> 
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333], 133 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 469 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 255 -> 
             RGBColor[0.904227, 0.657999, 0.241797], 408 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 326 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 176 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 230 -> 
             RGBColor[0.453318, 0.567063, 0.950106], 274 -> 
             RGBColor[0.992503, 0.986373, 0.425376], 87 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             439 -> RGBColor[0.984192, 0.987731, 0.911643], 130 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 35 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 379 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 31 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 18 -> 
             RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 24 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             151 -> RGBColor[
              0.9518633333333333, 0.9636203333333333, 0.966367], 137 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 330 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 296 -> 
             RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             266 -> RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             302 -> RGBColor[
              0.9518633333333333, 0.9636203333333333, 0.966367], 442 -> 
             RGBColor[
              0.9387176666666668, 0.7947430000000002, 0.26954900000000004`], 
             283 -> RGBColor[
              0.9518633333333333, 0.9636203333333333, 0.966367], 388 -> 
             RGBColor[0.992503, 0.986373, 0.425376], 284 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 417 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             318 -> RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             413 -> RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             238 -> RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 72 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 437 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 288 -> 
             RGBColor[
              0.8736790000000001, 0.519287666666667, 0.21630700000000008`], 
             382 -> RGBColor[
              0.9518633333333333, 0.9636203333333333, 0.966367], 461 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 389 -> 
             RGBColor[0.904227, 0.657999, 0.241797], 172 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 447 -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             243 -> RGBColor[
              0.8199840000000002, 0.8592970000000001, 0.982692], 410 -> 
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333], 88 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 273 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             477 -> RGBColor[0.8971273333333333, 0.920809, 0.99005], 202 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 393 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 98 -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 30 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 116 -> 
             RGBColor[0.904227, 0.657999, 0.241797], 373 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 434 -> 
             RGBColor[0.992503, 0.986373, 0.425376], 401 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 240 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 480 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 403 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 317 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 429 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 391 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 73 -> 
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333], 303 -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             449 -> RGBColor[0.984192, 0.987731, 0.911643], 29 -> 
             RGBColor[
              0.8447096666666667, 0.3446636666666671, 0.19044733333333339`], 
             360 -> RGBColor[
              0.9518633333333333, 0.9636203333333333, 0.966367], 320 -> 
             RGBColor[0.992503, 0.986373, 0.425376], 482 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 75 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 200 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 301 -> 
             RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             156 -> RGBColor[
              0.8736790000000001, 0.519287666666667, 0.21630700000000008`], 
             25 -> RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367],
              38 -> RGBColor[
              0.9518633333333333, 0.9636203333333333, 0.966367], 365 -> 
             RGBColor[
              0.3569366666666666, 0.4835823333333333, 0.9439646666666667], 
             380 -> RGBColor[
              0.8199840000000002, 0.8592970000000001, 0.982692], 370 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 3 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 57 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 227 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 494 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 39 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             424 -> RGBColor[
              0.7015673333333334, 0.766789, 0.9708893333333333], 109 -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             465 -> RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             256 -> RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             457 -> RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             339 -> RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             420 -> RGBColor[0.8971273333333333, 0.920809, 0.99005], 287 -> 
             RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             239 -> RGBColor[0.992503, 0.986373, 0.425376], 427 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             285 -> RGBColor[
              0.8199840000000002, 0.8592970000000001, 0.982692], 345 -> 
             RGBColor[0.992503, 0.986373, 0.425376], 366 -> 
             RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             216 -> RGBColor[0.904227, 0.657999, 0.241797], 21 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 355 -> 
             RGBColor[0.453318, 0.567063, 0.950106], 175 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 7 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 13 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 294 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 412 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             193 -> RGBColor[
              0.9518633333333333, 0.9636203333333333, 0.966367], 60 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 65 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 448 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 69 -> 
             RGBColor[
              0.3569366666666666, 0.4835823333333333, 0.9439646666666667], 
             217 -> RGBColor[
              0.7015673333333334, 0.766789, 0.9708893333333333], 214 -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             170 -> RGBColor[
              0.9518633333333333, 0.9636203333333333, 0.966367], 359 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 74 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 246 -> 
             RGBColor[0.904227, 0.657999, 0.241797], 264 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 278 -> 
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333], 45 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 492 -> 
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333], 306 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 237 -> 
             RGBColor[
              0.3569366666666666, 0.4835823333333333, 0.9439646666666667], 
             228 -> RGBColor[0.968143, 0.904201, 0.330742], 180 -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             383 -> RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 53 -> 
             RGBColor[0.992503, 0.986373, 0.425376], 304 -> 
             RGBColor[
              0.8736790000000001, 0.519287666666667, 0.21630700000000008`], 
             48 -> RGBColor[0.992503, 0.986373, 0.425376], 5 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 101 -> 
             RGBColor[0.968143, 0.904201, 0.330742], 333 -> 
             RGBColor[
              0.8447096666666667, 0.3446636666666671, 0.19044733333333339`], 
             267 -> RGBColor[0.453318, 0.567063, 0.950106], 120 -> 
             RGBColor[
              0.8736790000000001, 0.519287666666667, 0.21630700000000008`], 
             147 -> RGBColor[0.984192, 0.987731, 0.911643], 89 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 43 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 199 -> 
             RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             268 -> RGBColor[
              0.7015673333333334, 0.766789, 0.9708893333333333], 169 -> 
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333], 20 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 4 -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             167 -> RGBColor[0.984192, 0.987731, 0.911643], 431 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 142 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 16 -> 
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333], 414 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 281 -> 
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333], 289 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 398 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 178 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 58 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 186 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 122 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 249 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 113 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 52 -> 
             RGBColor[
              0.3569366666666666, 0.4835823333333333, 0.9439646666666667], 
             409 -> RGBColor[0.8971273333333333, 0.920809, 0.99005], 187 -> 
             RGBColor[0.904227, 0.657999, 0.241797], 259 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 42 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 134 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 470 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 313 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 248 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 174 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 215 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 399 -> 
             RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             422 -> RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 83 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 95 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 166 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 384 -> 
             RGBColor[
              0.8447096666666667, 0.3446636666666671, 0.19044733333333339`], 
             233 -> RGBColor[
              0.3569366666666666, 0.4835823333333333, 0.9439646666666667], 
             295 -> RGBColor[
              0.7015673333333334, 0.766789, 0.9708893333333333], 499 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 141 -> 
             RGBColor[0.904227, 0.657999, 0.241797], 319 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 205 -> 
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333], 468 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 486 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             224 -> RGBColor[0.992503, 0.986373, 0.425376], 231 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 332 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 68 -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             484 -> RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 10 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 250 -> 
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333], 282 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 374 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 232 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 489 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 253 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 459 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 415 -> 
             RGBColor[0.992503, 0.986373, 0.425376], 55 -> 
             RGBColor[0.968143, 0.904201, 0.330742], 446 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             325 -> RGBColor[
              0.8736790000000001, 0.519287666666667, 0.21630700000000008`], 
             91 -> RGBColor[0.817319, 0.134127, 0.164218], 450 -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             423 -> RGBColor[0.984192, 0.987731, 0.911643], 105 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 36 -> 
             RGBColor[0.453318, 0.567063, 0.950106], 123 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 94 -> 
             RGBColor[0.992503, 0.986373, 0.425376], 473 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 312 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 96 -> 
             RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             496 -> RGBColor[
              0.9518633333333333, 0.9636203333333333, 0.966367], 2 -> 
             RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             262 -> RGBColor[
              0.8736790000000001, 0.519287666666667, 0.21630700000000008`], 
             272 -> RGBColor[
              0.9518633333333333, 0.9636203333333333, 0.966367], 97 -> 
             RGBColor[0.904227, 0.657999, 0.241797], 372 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 356 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 402 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             455 -> RGBColor[0.8971273333333333, 0.920809, 0.99005], 428 -> 
             RGBColor[0.453318, 0.567063, 0.950106], 346 -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             341 -> RGBColor[
              0.9518633333333333, 0.9636203333333333, 0.966367], 209 -> 
             RGBColor[0.904227, 0.657999, 0.241797], 498 -> 
             RGBColor[
              0.5793453333333333, 0.6693776666666666, 0.9600273333333333], 
             378 -> RGBColor[0.8971273333333333, 0.920809, 0.99005], 419 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 66 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 139 -> 
             RGBColor[0.904227, 0.657999, 0.241797], 56 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 335 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 314 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 144 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 298 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 204 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             452 -> RGBColor[0.8971273333333333, 0.920809, 0.99005], 466 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 207 -> 
             RGBColor[
              0.9943556666666666, 0.9903356666666667, 0.6270273333333336], 
             334 -> RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             149 -> RGBColor[0.817319, 0.134127, 0.164218], 219 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 
             400 -> RGBColor[
              0.9518633333333333, 0.9636203333333333, 0.966367], 9 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 11 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 44 -> 
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333], 153 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 471 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 406 -> 
             RGBColor[
              0.9915853333333333, 0.9907883333333334, 0.7891163333333335], 32 -> 
             RGBColor[0.968143, 0.904201, 0.330742], 162 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 493 -> 
             RGBColor[0.992503, 0.986373, 0.425376], 90 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 331 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 8 -> 
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333], 364 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367], 342 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 163 -> 
             RGBColor[0.265473, 0.39635933333333334`, 0.9384296666666667], 49 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 338 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 76 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 369 -> 
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692], 445 -> 
             RGBColor[0.8971273333333333, 0.920809, 0.99005], 82 -> 
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333], 67 -> 
             RGBColor[0.968143, 0.904201, 0.330742], 430 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 211 -> 
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9V3c41W/cPkZ2skfWMY5xzsFxzjFCvnekUipFSBqEZKVlFlIpoUVlJUVG
SYPKqqzQMKISRVQo9UP27j3vdb3X+/3n+eN5ruv5Pp/P/bmHqvuBrZ7cJBJp
nItE+t/VPFxZo1WDhIChKyFr2rXAaP6z7YvoX0JMyNhkJpuKBvKY6gcXKiSs
glQyw3VR+F1zrZT5MvTg47MC33mC7DPgtOziOIG+/St/9JHgeH47z8ZKRUSM
BkTxnVuG2oGvv93mxDExeKOm+SAZDYr7hqJu01GzzvfvChE66r6bbqRaGcDy
7IuHPKHCiDgXpGe/g4US9RtkqzQGSqY1lXxcJgneYD/LJwI8aDaitRSmauOT
eMTPBzX6SPnrLJXgxgBvjGlrl80McWlph78OSQ4Z2w7fyIQevPVFvy8eZaNk
0+1Wpqcw5M7PXbilqgOvZ3ZhhRQlJFGYQr8ayLiwKJfZuUCFpbOIPT2RimA1
NScza1lYV6kPV0QbwKQGqT6uYiAN0p5FSi3H7P343e911DB/d+cfyOrgvPsZ
M+dqMZQ0n/yzarMKFmUdZCLt9WDnrMjVqPiHeL80vmFCnBtHA29V3PJUQ8yk
XdZ/Y0LI3HeR5/PhGcJVJkct6KAqSO+3fCr9YoCRbHJbg6AI9t4Tu51N1UdA
373tMvVUbEqciR0algJ//q2Og1cVcb2/fcIuUAY/ExwdP3bNEVw6T17NG9HQ
kvVl4mNqN0G5+3xTbT8d28lddsrqunASPLPXuo6B8mGtgedb1LEzuij6h6Qm
3t3ztl+VL456j6ZVsV8N4NcftMb8mgScX//j7pYaJ6z2h68jXdZETEnoDZsS
JtJnNFTWV+sg2Uz8TnUOE47mPae6zLXhHC37d0xAGA2pfj4aqXQMHV9r6Oil
g7UqkltuxqqgQMLnyHpRfciJZCQfNKaj51aq55TlMOGc8GicK3qW0NxX6f43
hQX6bkW1bs9pwrt179+R9XSQuvPWbr/UR5R8b1CklDLQ0GO+Xy9IENzXs2XX
1mtj5QuvOd3nitgr8OnPwdvqOG9bOXL1iw5sGa7XlkWR0FVQ5mu3jgb7DhWf
7rts8E5TO+YHJwg66V3erkZBJMSMep98rAbFD9m5zrH6+GhC35MVyI1VVxcT
naY0Ma8QeK2cQcatR8YDET06eDLIx3azlsf5tto6m1oNDIjXLl4qpMJ7wrV/
afYk8ec//j9Hk7Uh4LdO5kz1KNHUNVmhX0lF+ROl4OKTOkiqreDZny6HG3k9
zZt/6eGbv2t5+K8lcKA8lPRS4dS38ILa83FtVNsx789HsnFI22RW1VIGD6h7
TAkLFpxqstpY+9Qh/93Wxmq9FlpqNE11TXuJnzvuGS35SIbrfnFBnhAVFF3O
3fPoyHIIqCzwfaDowt/v0yWLZVogy0Z2bdjcRgxdCvbJLaZCRM54SWGaJCzq
2w8HX2dASfRPke0DPTif7+dAYpLgrk5wsomgIFbp6VRMoxoYy0L9Z8J1YH/v
mh3fWUl09jfLZIaQ0ROv8q53cI6oeX/1xZ23mjBVCHbKbRbHUspt2ytO6jAo
6Urxj5VG5VdL9sh/ekjd92ShslAcq+OuS1mv0cPe6/5HqP0stKzw4IorkYHj
3rqzBZ7S+Bi3kRmsqguB7DWqH2gcHtCim561UcNTN4fDDn/k8ShmuIJ0QwCX
zh372n2RDXLvS7lljxeJzP13D7SFKmPtDl/e4C5xHFxzvOl6pyzYf9K7fr+T
wP4zMst/9JDR2ermWhq5FI7UN/nbNNhwuSXCP+gjj+fUXPcX/BTosX8NvyQE
IbB2QGy+cYpwSH10Ps9AG9RTpg0r9rJRmbjN8K7wJNHu+2ZqZF4HjM17rIIi
tHDu0cufzZ6aCCRCvQxKlGD7njXz/CEHJ/zCAVXesgj44jCQk8+CJ79LnpeW
Mudey0s7RzSRY/JVVI6qg1rPC0o5GRRkVsXJ2l18S9yRCnoXslIXs3/XJdDf
80IrnmL8S00M8v0NX0610HEpbP9Jz8PayBrv9kk4qQouT9a1ZG42xu/yLTYf
nCX2UAyqT6nPEUdSvA3Md2lAt+yY8D4lNugnj1j9zCdhMubpp2s5dOxgyuRc
4OHM8zmPWLXXygh2lVzLPSCO6tO7T+8XpaKE4Z2jo6oKHqV+jaoQGkYNGrpf
bOPGD/HaHqNeEpi+bP58VW48e5whv6afgX/mz237UjQh1qc/77CWDeaEuxGj
WATh5NR3zENsGB+TjBBbJw02+2+R2RUGfPZ2CPi/5sfv7/yN68IpuEyKCP9b
rgw29e2jHmlR2FWHpFCv06B9uG2zv9giIbckq1m9bYIwbUz0enaejsAan0eX
XvYSyeuu0DVCpgiZG/7RZwslMV9jJEXm3G/uLznk+FgCO2zagtcwNTFWryai
9E8Fh+1LJWyadSEoJfeT+xcNq95J2CzM05D5tle7iEoF38onAckXWKAmJDf2
8FFQcelo5kwnA9UaX4472S3Bw37KEjcOH1p2vJjepqSJgFrLki4eLRhtXltm
zC+CVNXgH1dKWPj8NcrWfDUDTyLSM+wSaSgOfH/SO4uMc9EKGdMXyUi1OmKi
6SOF5DXPfMYesGAmfjeq6R4D1LqwvYXLqDi/432Gd402rlbsWZGUzkKcuWvP
m7UMePNKd4ScVIJO5HbteSkGNnk9e7OCc65qwcLxVicZmjWK9pQhzrwHmj0O
DeWCl9p/zZoLQmhxONHu91YbvMIaul6hWljvUF/yxoeMSiHZidyReaLf91mU
0xtNdL+WOTG6SR12zJX9gZNKKHnbafn8HxOb6tLW9xurYL17yrhZExNvXf3D
tu/RRbLi7phW7mnCoTlu+JOgFqbTk19ZnaIjJvQKxc5NG3UXu609wtkQGy2Z
OiE3S1RcEA09kMACI/nd48YvdM75TX0lNxiIWbV0icUJAVS0RBXdeK4PW7XS
fcxDvBz+ERUeceHw5V2pH7RL2ngnaCjJfVYc2suPZxdXKKK6jtzm+kIT7lfe
5l9aroKU7SUucXFyGNygaZYpzkDPdu2ym4ZsJL1VNbK/P0WYBJgtZt2ZIOTG
MupCnCVQ+W/qqNKqaeKj5LmK7hhNWLy5MWfNwevsX/kVS7PFIfgn5ujGd8tR
UsQn7Suih4gQnur9j1ShpmCoZ1YlBenebkqMPgtDRoJPykjqIP3fd9HQSSyR
3EfoeXhu+LGTjbDS7ryoPxIYmvuqsY9mgKgbA7dWlS4Sr3nHJ0fSDSCQVLO7
lF8FatOWqwMVJdEi8V5z2lsE5DyNO9UaM0Ts3oQLbvFqaBrJEl/XLIcn/4xK
D6zRhUNT8V9/Dw1YzrGOSzVLIf7ydYGdLFUMKlSsS0nQQ3bHrY78HbqY3/h5
nHRGBXZ5pS6/n9FQwnxc4Kigi5KjguHEHg4/r/v4cquHLtJ8N0o5f9RCxQn9
Q3reUrjz2utFrpcKxhULDvbK6mEwiV/I4L0OyqzMp1tnpWBu5RTb5kiD2gqv
1GfLZFE+aSlIJOngQf6bo7rDalB3vryyp1QX0008zJ413DilyI7LNeHB32W7
hPPdteBszbJKGZgleOkHJe4LamLTCp3B7XLqmE7+0cf3bJA4JaPg0JwtBTYl
fJv2VQVYv5M8/OkZEz+C9j009eBCZpnY77IrNDhYXBLL7xOGl7Onz04uCrzo
qdkdNXxgK/hda9rGwjgzptPmKQNCezq3HzTURtj4sFqZBhV+W5R8sE0bU4Ef
mdd2qWD6tFVKv9E4IU2WiS8yVsfpo4EFhnZMXKhkzP8tVMTW6e/c10IVMEfI
91bP6iKpqI1y6zMbIg1H9oanTBKUjtuvXv9mgatjMfZxrTI8LpIbBLz5IbA0
68adrgXiQWGx4wjfGOFqsjpsX+kcUbbwnbsqXgqbvrt/0TDWQ9rEkKnBeSZu
OffKWFM1cU4n5O/aXYIwUTfL9XhNw+AAu1nGiY1s9osxO0sJMJ44zfhv7CFg
cO+SG2mEmOSSqjjE4ZPK+dLK039UQe6QTZXS54ZPR6BwaRsvWKG/nrXskYZa
Q3JVQbsq8nz2RzxWZ2Mh8UyyBEsa89I3rxXkCOCQ+zk3+3ESrpXtfRxXqQlG
ZEXK3Q4+PNh4zcg3XxvaWqKBOjv14Zfz9WWALwP0PTdJv+s4/ku24dWnlVQ8
vAOu7YfJcC6UehF0YY4wLdn5I8ZQFs5iXN9PMSYIB6fKY85ePOj7fCvXPpoO
Df7Frce20ZEbmOeSkcTRv5Smd8Yc/prbevX4fhVlLD2oEFSfrYUtDhuTLr6U
wJrszDXfe2iIEtj+a6FkkAhMMPz3nv6VqC1c/Yq+QR95I3fay9V00dG99Iej
sgaM40n04ipl8NbLsC4eo2J98TlaUZQsSn6mdSYs+UuEUd/NJFUIAJUMfZe2
XmJe9qvp9o3jhF3qiJ+oAhW7G+yUN5aqIiGJT+qfhiasj97jKggko1RJv7br
AAtyYuLDF02EoP3SiZC3mCJOf7e12CRKQc9kmYPjdjoymz2m+N/+R+z5b/fo
u6YRQsxG1qkrdoA4HP/uzB01PbhUrozafYYbat7xIktFDVD2b9XTq/I07DF5
ubEtnIYKY9u5QY6/yzxy/ulonhCyu2jude2yuEJtLVKT4/j06pd33Xj1UN1J
fztcyoLp5cc5r9vEUTfzhtpUzsJyC9f7Lw4qw62nwaNvUhPsuPVFXccVYa53
/nOVtw5WG/L+ynOWgpJYmMa9aVlIvlRM+rFZA1zJWwxLLAwgUvP0+AquWYLU
2tnRGTtJyDiM8Ri3c+5197VKaB8hgisSFHffUQD7rbgv9QM/fh6s0v4cJgK9
w/ZBubdUoVc3ODf/Rh5N/Q2xG04x8WJvILd2AcfvylY1KP5lQsJ+fI4epoh4
bQhF+mrjscYWvWf3FOBYOra6/qk64hMbZbZbCkND9rR3ezgXPot93DxzQwNX
Y3sp67RZkGyr/vIoYDmW0xrN0cDEz2GbJPZrHfA0WuT5JIpjZlj+qq+5Mhht
yt8T2yaJb+mdVWf1qIhxJ0uGyVPRIl454GOjgILHb1ZnB+hjOvjE5mBijniy
zuZYzSYmRDYcT38ewNGT729EzpGniIcCT8yZQspI2xrX0fKNgVYfsZjzFEG4
coleeEkw8SmvzTMoc4zQGeHOyD/DglFk1qOsVRy93WhIa7b+TvAa9Ny67EmD
9VSA4dwujp5ubJSNbaShdnWsswCnTy7R93iOadLAKLZ1aQyhY3/gJqMLkdqo
dNy54Ceig95wVweXGDIGQ9tqNEIZELVkNRqe50Hyh1rFR2ITRBGrM67gMqfe
JjWZy3o1OPMlpPFhDeedXC/Xvimkg134idUZqItXYTn1hg9pmMsJVX8aQMax
c2VWaZEsWPOI+JnVk8FlcPnyZX8q8otUT3Kv1oTHngmHPiMmvieamzXrK8JS
QtiZX4qNutcPHlRzcirs+sKutDHQS8uVWZbPwJ8LPEdSSTxY+uOO+FFDTZj0
2z4ptRHCnrMufy2TqDgQ0Iu2RjImXLNvUI6JY53H8Hb1nWr49WSNuNF+Pdge
8M6JoRjA6NQ9rvoQIeSv3xe5aZICESGlV4Lywuj59LU84+Io4ToeXDuZL4O7
0zXGrb80QK96dliyVQfcm2s9Q1gUdOZLFt4dUsYuH991TxX0QVob9zSJk/96
2paJPdVVQamz+/N5ph7MrMnrEq9rI93HM4qaogBXD5Zu14Auzu5e2HrvMScP
LFFq/9OpBIXzewv1j4mhpXhokMtAAR9/M6r79upDY6dtx50MFtZ7SvMN96ui
hFpiMlA4SkTnehV4cnFyZH1lSqqtMq6sFNgKbl1s5qtdZSekjddXY0cLjyih
Mi3UnrFxhHCnvFR7ViyFwXP9nQVVZPRv/5bKENPHzUfi9hcTWcjMShNeNBwn
egSvhN4+3kn03Ln26umbH8Q6kRimgN8YkV4i3MVlpoqnUUH3N3D+f+Ltpuh/
F+ioDmK+ag6ioyTSXZjboJ9I5E9/L/VZF8ct60pMEqnw4tM/M3tTCx8nc42L
VylByIvit5NXHVMr1VIVttKwI8F+W7wJC7wtYlmXz00Tle+H29J4Rwjnz0tz
Vk4PEdzMduuIKBYaB96mHc1YDt3bX39rn9WF6pW+u6qydKgs9CrbdKqh8ILl
vZoTNFT6ybEGGuuJFq6w/WVrfhEwv75tZd5vwqFYYkJCfJSAcXs06WozkXlS
l3yQ1Ucco0mvGrTSQquQosp8AxktrgsrmekURAmudJtPLCN+vLLnCeXM03sj
oQ8m1lqoUdgVN7VgAE3bsUbxLF3UnIg6PPpCA+OfO/KslamIZja2qHNzcmOx
YX1ZkwTSjm/9scdFE4426aL2dGXMtz5THXmvjRCqllkFRQzTS3KNu38xIfAz
OdrsmyYs64rvT5frwva4YG/WBR1EUSMsfSNJ0BYa/qC3SgzjgWPc4ooGCCls
LJkunyCqs5UKR8/rIf5UTJX3R47/sr9LuXlaG35XIj33kFTRe9jq3pc8Osf3
WXoEvKoi9lakv6tO0ECt4uak6Z1UBNA1W3wfLsWj06QtF/aRsD69/mFWih6O
0N3SPFZwckDVfMFvXyqG81iOfUxR5EhuOCP2nyjo1ZIpkRzXcjHK9nvcGkkU
JlYsBh3Wgyn7bZtzLBtXH96O9CVJwn7qU21PkxIUPX+HKHHmz+/aN6P2P1rY
a9b2lSeCjD330oMPetEwHPrQsKh0OdZfoglw72ehItph8+y4Bh6cvxnHVczx
O+KztVH/NKC3j6azn6yCZcs7RLWjl4H9JYVrvIoPjoXFm6RX8UIqNcjikJ4+
zlWT2fbhmrjy5cWVvCgmTsZnPL+VsxyZoQXXPZIWiXA5rRW/LijBXOCBq1Kr
HkyqLOd/XSYBH+ZWJbgLwGMyo1Lw7zQhZrUussJshCD1+GmfonwiYouO0SPb
aBi53aMxcUMQ8rePlX/l6KvQqfpYPjcSKqN3biq/9pewDE9yzVlJw9CaG4On
OTxgF7clOB5TxDeN5jO+cbpwNxKbyFtJxppycuXnrWwQcr70Ym5piM2flP/v
9wzh9kjRhCtTHQrFOl73/hngveGHhvwAFcxHvIw3+qqFy0kiXzILl8DVMPVG
1w5OHu8semO2ZJpobaPdtzykhZKoz3f9rpARtGaDV6IYFXJzXs5HNkvgovn3
3eTN+ij8dawoOpOG5frvVRy2CCHn/qXzHXd4Ue3Bk6JVycIoxTxxrkoMZPGb
c2KcfhTzBn8tfU3FXxl/nbhoVXxYtdnYeZDjs5bLW9KOCmKW605ZkZQA2n86
RtQX01EZU9D8mXeCuKvfv5lnkoVjEa5FRXmiSBLezWvmrglvrqOync06eHt5
9l68NhsX4+oF/NVmiFPB0m7JN/RhelCk+58iHTNmA268WwywNM/2d1i3KESs
FB9T/XQhWregbe20BMslRg7k3uDkYVVa0rL5caK5Vb7/IFsP6RUJpG9P/hGf
Rgbd32QIwNu7/VzWLA0hHyJ03mwZJURu+VV9XUVF4s83GbtWUv4/Z5kk1JYb
zzFxaijt2vQkDU6KAbFlLdrI2eES9MxUFVZNbMUqJwYk7vSd7Z3nAWO0OmlA
Uh8X/zWzY/T58Hd+C+1AAQMDVgVap5g0PAi1tg8IEIPjlNiWzb/FcVPq6NkN
/HRElzwV6V2mDw/xYNPDR7iRt735265bOkjpSD4is1obDasz172IEgayNhU+
rp0jyM71yfFyS7HgmZHryqUHbqGDDeWjmqj90py2oVUXAspjW6fGfxHuOUce
Rjsw8PPvVvdB93kizPbp9dgHDIgZ97y3ujpOdHN7jexYoIGie/u1ZBIdYZnv
/KYaOXxiGKR2cS0NDbZ/JvquiSI7sidnUWSRWHLnpzCPFQc/5gN1pKBe4qJH
yZ2LdhOERW86d4GZFqzb3EQvZGjBstxr2dpUTl4e0Tb8sIuBuDNjXB+pKmha
+VPwwFIZqDr5t7zbqQ47idWbvDv6iJIIq45tSv8RQ1adh7p4DKAdtHzRTGqR
mN73e/tG12nCPKJSbeCxFuQ+fdIZ3zZNJL99tH/jEVXs9/Np0lnGRJohtiuo
yOJFe37/BNMAJuPif17pMdB//+4VDws2Qk94PYxM4uh3Lg8/7aEmztSrMYuf
ymGjzuPPtUf0MM29VOFcAx0VCgWqEjIMZMxN2Ty5p49v3WrUeQ7e5bwEGUrD
Wph2K3vXY7hABKdLG2TfEcMZo0O+RzN0oBjUM/WfsCoYay69OXhQBCtCXmZe
tlDFJCfeDm/Rx4MVZlEFjmow7XHiq8tnQ+C7yV1y5TSRZ2+8ddFBF9tmzPcM
jynhi+Rxb6U5JQzlWtnXlEsg2l2utMGZDb/Cda2PE2YI95JtJIVoNlJj+Syk
6kk4+5Wnx2p0lvhhMe/TPTNCvDDtdQ8Ql8QputMi5REN7b3ubdfBRMjGjNNb
hCYIflL47nZ7FpLk+uYjBrSw4wefZGafMmQs0u/HP5RA3vDpINpLEqTS6wr8
S/lgMpxRWirI0RtNfmKsWBi14jMemhx/Zu2Vb6f0mIb4FH334asSCAm2c1Gb
lIXn0JVPGdHqcJ0KdNcSpaF0hPd4p5keOuo+ycccp+FH7G7BJXMayJULMH68
kYaY+zdvfrTRROhgweKu5yrgjw2mReprIevCosW5DQoQ7GsbTjhKwf1Brl6h
5SooWR/TvWDEQvnt+tmtDGXsCF/482+egbKxzSyXc0vQ1DxpZCJIAXfYgbMn
GgXx06ETs3QD2OWTQr/XcnRvVvLBwJAOBlvcLyfry6DddshVbZGzb36+aDUf
FcUPd96M5GFj+hh9/5k6Lsxz6UVY/OYHv/Ojr6NW6hDoDiBqY1XxVoL/ApcS
Dd7z38QrurgRtkQ5WO8lBc8XNwYunKGhrO63bPuYHMIWvvIGW2iBZGEqzjdw
gsjzkkxY2SWIbcLxVmYMNZCdy3ZQrAVhX5xUXc7hoxxNne1Tw0xYHJoiU5r0
MSEf8eLxjA5k/+1r3M3ZH3F1y9lYy8Lu6XO9VqMK8CG4B7IXleDi9jNkc78u
PgmdTD00ME7kB9wZiTovB5qGU9ykGwXtfgLjQhkyGFn61kxrcJT4j3cg/ru0
HP583DA2QjXAW/1hV6W1DJBUtEwp3ykwcW2x7fmrAL+Ai2mSB9iIFju/reir
NExd6BLH72lguduEnWoPD3IMCtTM0vRR9ZnLx0ZME0mmaYxQTl9LT16UXDjD
0fMWpt2+8VZi3Q7fcr/fQ8Qhjpi2PmND3HHFpdGzYnCJa3iqNcbRF9rnbntv
eYgdDrcyseXkpqBooUEGGRIVDzUUBlgIGxNbe6KfATLpQ8wD/CbyfhTZvPny
HxETWNh56SgLeuGXk01U9BDIv21opHGUMBk6Eb5/oo+wnTQxFDnMjfJDVNX9
NqpQsdr9++5ZA1idKi574K0PoVSzkDO10nhR9Cj9crc8PJojZ9tXCED37pf0
LRXqIPijP58z5ODhZ9Gx4zulYCKYFdPbP0Y0thP3tVzEUNLPVVhZMknETwf3
DZ9Xx/f4OF7bGgYW2/0lqycEkN1dRV3SrQylrUm6c650NLUEnJD0N0DGEh3/
V/Ji+KGVdC7QjwbjsUcKni8UsUSqoyxlkAU31/cShgdUYH5ku//ey1ToK4+k
bN1GRl1al4RVjB4Yy9XU79L1YFmdn/tnFQWZSauyyKbNhMPAZaPaQhpc49tE
kuvkoDD/jZ3+hApr8cXuKxy/YH415mVLkwoqEzXTWy9J4c+i46CBhSYYO84m
H9rCqffTc8ckOfVxDVr8vHHlFJG9rfn61UvieJJnbZZhzgORZLGfiQQFhW1a
Nlwf9GAhmbnTpZKMOMtDrwyN9bFva2vGF4jhm80ygWslXPBzC4yBAQvSWWpu
5Zs04CaqVCfRx3lvd1CMhr8WGOIFfvnhk0TgvuQhpU9LUNVa69rrqQhlT5r5
g88SyKTsE9b2E8UxHoNq76tq+Niucuv2Qz08ysxLVLPTxqFLMqR35poYH7te
sfWXMMSXCjSlHZGF85pMBu25Ou6oOJ6U3KCL8/FNp/0aVDB9dUu/seQEUb9z
M2MkVxGuAVHEhKUCpumyN76eksbJm1eP7XSRxrcRP+46OX1QPxUoKWRScVxi
72wnSQ5ni5dVHDXlR7xwWcDo4XnC+eDqjrUio0RqVTk1bUgQT2KC+SXT6Agw
D3aZOU6Csuj8mS9STNTd4mWcMaJD980lNakwKiY1HN52j6jhfwCDMYyj
         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 54}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 70}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 84}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 131}], {
             RGBColor[0.9289355, 0.7535093333333336, 0.563975]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{1, 135}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 147}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 170}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 171}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 265}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 266}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 374}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{1, 385}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 391}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 433}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 47}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 54}], {
             RGBColor[
             0.6404563333333333, 0.7180833333333334, 0.9654583333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 55}], {
             RGBColor[
             0.7737441666666667, 0.7867893333333333, 0.6453846666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 230}], {
             RGBColor[
             0.5163316666666666, 0.6182203333333334, 0.9550666666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 242}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 250}], {
             RGBColor[
             0.6404563333333333, 0.7180833333333334, 0.9654583333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 339}], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 365}], {
             RGBColor[0.4681409999999999, 0.57648, 0.9519960000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 8}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 31}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{3, 203}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 221}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 223}], {
             RGBColor[0.9006771666666666, 0.789404, 0.6159235000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 258}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 381}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 439}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 480}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{4, 29}], {
             RGBColor[
             0.9195326666666667, 0.6674996666666669, 0.4087373333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 185}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 196}], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 318}], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 321}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 335}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 383}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{4, 479}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{4, 482}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 496}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 23}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 41}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{5, 102}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 186}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 193}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 202}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{5, 211}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 212}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 300}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 414}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{5, 485}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 24}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 77}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 79}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 80}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 81}], {
             RGBColor[0.6544, 0.7236013333333333, 0.9551658333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 99}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 156}], {
             RGBColor[0.9127711666666667, 0.7414540000000002, 0.591337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 267}], {
             RGBColor[
             0.7025906666666666, 0.7653416666666666, 0.9582364999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 278}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 329}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{6, 406}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 413}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 486}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 28}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{7, 49}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 69}], {
             RGBColor[0.6544, 0.7236013333333333, 0.9551658333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 142}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 173}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 241}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 388}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 402}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 436}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 461}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 487}], {
             RGBColor[0.9280451666666667, 0.8108096666666667, 0.604082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 31}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 40}], {
             RGBColor[
             0.7607756666666667, 0.8130430000000001, 0.9767906666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 114}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 115}], {
             RGBColor[
             0.6404563333333333, 0.7180833333333334, 0.9654583333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 162}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 203}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 221}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 258}], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 289}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 291}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 297}], {
             RGBColor[
             0.6404563333333333, 0.7180833333333334, 0.9654583333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 311}], {
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 381}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 419}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 439}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 19}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 26}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 34}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 44}], {
             RGBColor[
             0.7607756666666667, 0.8130430000000001, 0.9767906666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 117}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 139}], {
             RGBColor[0.8621055000000001, 0.758648, 0.6122445000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 247}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 269}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 360}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 425}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 466}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 468}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 120}], {
             RGBColor[0.9289355, 0.7535093333333336, 0.563975]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{10, 123}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 125}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 177}], {
             RGBColor[0.718755, 0.777397, 0.9308745]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 245}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 438}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 455}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 23}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 41}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 102}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 186}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 193}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 202}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 211}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 414}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 485}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 497}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 198}], {
             RGBColor[0.9326351666666666, 0.912505, 0.660396]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{12, 373}], {
             RGBColor[0.9326351666666666, 0.912505, 0.660396]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{12, 480}], {
             RGBColor[0.9326351666666666, 0.912505, 0.660396]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{13, 154}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 229}], {
             RGBColor[0.9442094999999999, 0.822865, 0.57672]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{13, 244}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 313}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 334}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 338}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 340}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 363}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 379}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 380}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 390}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685095]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{13, 478}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 63}], {
             RGBColor[
             0.7859241666666666, 0.8278753333333333, 0.6927016666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 72}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 75}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 149}], {
             RGBColor[0.904911, 0.56025, 0.294797]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 158}], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 163}], {
             RGBColor[0.628988, 0.6913661666666667, 0.6819028333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 182}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685095]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{14, 187}], {
             RGBColor[0.948365, 0.8221860000000001, 0.3335865]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{14, 279}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 322}], {
             RGBColor[0.9656103333333335, 0.8905580000000002, 0.3474625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 324}], {
             RGBColor[
             0.9934293333333333, 0.9883543333333333, 0.5262016666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 441}], {
             RGBColor[
             0.9934293333333333, 0.9883543333333333, 0.5262016666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 494}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 78}], {
             RGBColor[0.8940635000000001, 0.8817490000000001, 0.656717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 97}], {
             RGBColor[0.936185, 0.7811, 0.2862695]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 104}], {
             RGBColor[0.980323, 0.945287, 0.378059]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.7737441666666667, 0.7867893333333333, 0.6453846666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 148}], {
             RGBColor[
             0.9600031666666666, 0.9339106666666667, 0.6485544999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 153}], {
             RGBColor[0.9761675, 0.9459660000000001, 0.6211925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 190}], {
             RGBColor[0.980323, 0.945287, 0.378059]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 323}], {
             RGBColor[0.9326351666666666, 0.912505, 0.660396]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{15, 356}], {
             RGBColor[0.8940635000000001, 0.8817490000000001, 0.656717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 408}], {
             RGBColor[0.8940635000000001, 0.8817490000000001, 0.656717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 430}], {
             RGBColor[0.9761675, 0.9459660000000001, 0.6211925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 452}], {
             RGBColor[0.9326351666666666, 0.912505, 0.660396]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{16, 39}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 45}], {
             RGBColor[0.44024716666666674`, 0.5360915, 0.9521951666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 52}], {
             RGBColor[0.5292520000000001, 0.6251856666666666, 0.957427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 56}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 179}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 200}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 236}], {
             RGBColor[
             0.7731385000000001, 0.5557263333333335, 0.5806683333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 243}], {
             RGBColor[
             0.7607756666666667, 0.8130430000000001, 0.9767906666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 254}], {
             RGBColor[
             0.8348551666666667, 0.8354950000000001, 0.6508156666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 276}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 283}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 292}], {
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 422}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 454}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 205}], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 252}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 282}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 293}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 298}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 418}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 432}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 467}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 52}], {
             RGBColor[0.4681409999999999, 0.57648, 0.9519960000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 56}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 65}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 88}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 166}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 167}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 210}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 227}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 243}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 326}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 348}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 428}], {
             RGBColor[
             0.5163316666666666, 0.6182203333333334, 0.9550666666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 434}], {
             RGBColor[
             0.7859241666666666, 0.8278753333333333, 0.6927016666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 469}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 474}], {
             RGBColor[0.4681409999999999, 0.57648, 0.9519960000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 495}], {
             RGBColor[0.4681409999999999, 0.57648, 0.9519960000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 26}], {
             RGBColor[
             0.9934293333333333, 0.9883543333333333, 0.5262016666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 34}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 44}], {
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 139}], {
             RGBColor[0.948365, 0.8221860000000001, 0.3335865]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{19, 234}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 247}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 269}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685095]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{19, 360}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 393}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 466}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 468}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 62}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{20, 194}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{20, 228}], {
             RGBColor[0.9326351666666666, 0.912505, 0.660396]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{20, 388}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 490}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 33}], {
             RGBColor[0.7594431666666668, 0.450458, 0.5675536666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 65}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{21, 119}], {
             RGBColor[
             0.8310143333333333, 0.23939533333333354`, 0.1773326666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 164}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{21, 166}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{21, 175}], {
             RGBColor[0.8572231666666666, 0.527468, 0.577134]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{21, 227}], {
             RGBColor[0.8845911666666666, 0.5488736666666667, 0.5652925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 309}], {
             RGBColor[
             0.9044521666666667, 0.5624576666666667, 0.47666716666666675`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 320}], {
             RGBColor[0.904911, 0.56025, 0.294797]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 337}], {
             RGBColor[
             0.6983321666666666, 0.4017523333333333, 0.5621226666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 348}], {
             RGBColor[
             0.9044521666666667, 0.5624576666666667, 0.47666716666666675`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 375}], {
             RGBColor[
             0.6983321666666666, 0.4017523333333333, 0.5621226666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 428}], {
             RGBColor[0.6353185, 0.350595, 0.557162]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 489}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{22, 63}], {
             RGBColor[
             0.7859241666666666, 0.8278753333333333, 0.6927016666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 149}], {
             RGBColor[0.904911, 0.56025, 0.294797]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 160}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 165}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 182}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685095]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{22, 268}], {
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 275}], {
             RGBColor[
             0.9934293333333333, 0.9883543333333333, 0.5262016666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 282}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 285}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 324}], {
             RGBColor[
             0.9934293333333333, 0.9883543333333333, 0.5262016666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 353}], {
             RGBColor[
             0.9934293333333333, 0.9883543333333333, 0.5262016666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 441}], {
             RGBColor[
             0.9934293333333333, 0.9883543333333333, 0.5262016666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 481}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685095]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{23, 41}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 186}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 202}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 211}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 212}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 485}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 497}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 77}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 81}], {
             RGBColor[0.674261, 0.7371853333333334, 0.8665405000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 83}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 176}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 197}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 237}], {
             RGBColor[0.674261, 0.7371853333333334, 0.8665405000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 267}], {
             RGBColor[
             0.7224516666666667, 0.7789256666666666, 0.8696111666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 270}], {
             RGBColor[0.9181475, 0.6677260000000003, 0.48978183333333347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 278}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 329}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{24, 426}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 448}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 489}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 96}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 157}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{25, 246}], {
             RGBColor[0.9280451666666667, 0.8108096666666667, 0.604082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 288}], {
             RGBColor[0.9127711666666667, 0.7414540000000002, 0.591337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 333}], {
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 343}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 392}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 459}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 465}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 492}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 34}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{26, 44}], {
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 106}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{26, 117}], {
             RGBColor[
             0.7868504999999999, 0.8298566666666667, 0.7935273333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 139}], {
             RGBColor[
             0.9492913333333333, 0.8241673333333334, 0.4344121666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 215}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 224}], {
             RGBColor[
             0.9934293333333333, 0.9883543333333333, 0.5262016666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 247}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 269}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 351}], {
             RGBColor[
             0.9934293333333333, 0.9883543333333333, 0.5262016666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 360}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{26, 425}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 466}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 468}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 40}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 114}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 199}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 220}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 277}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 289}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 291}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 297}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 311}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{27, 319}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 349}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 359}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 371}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 419}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 488}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 69}], {
             RGBColor[0.6756461666666667, 0.736959, 0.7854960000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 142}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{28, 173}], {
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 194}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 241}], {
             RGBColor[
             0.9934293333333333, 0.9883543333333333, 0.5262016666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 417}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{28, 461}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{28, 493}], {
             RGBColor[
             0.9934293333333333, 0.9883543333333333, 0.5262016666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 77}], {
             RGBColor[0.7120275, 0.5070206666666669, 0.5752373333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 172}], {
             RGBColor[
             0.8323468333333335, 0.6019803333333336, 0.5865696666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 318}], {
             RGBColor[
             0.9195326666666667, 0.6674996666666668, 0.4087373333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 321}], {
             RGBColor[
             0.8709184999999999, 0.6327363333333336, 0.5902486666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 383}], {
             RGBColor[0.9181475, 0.6677260000000003, 0.48978183333333347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 479}], {
             RGBColor[0.9181475, 0.6677260000000003, 0.48978183333333347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 482}], {
             RGBColor[
             0.8709184999999999, 0.6327363333333336, 0.5902486666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 43}], {
             RGBColor[0.8845911666666666, 0.5488736666666667, 0.5652925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 64}], {
             RGBColor[0.7594431666666668, 0.450458, 0.5675536666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 110}], {
             RGBColor[
             0.8310143333333333, 0.23939533333333354`, 0.1773326666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 217}], {
             RGBColor[0.7594431666666668, 0.450458, 0.5675536666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 290}], {
             RGBColor[
             0.6983321666666666, 0.4017523333333333, 0.5621226666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 316}], {
             RGBColor[0.8845911666666666, 0.5488736666666667, 0.5652925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 355}], {
             RGBColor[0.6353185, 0.350595, 0.557162]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 378}], {
             RGBColor[0.8572231666666666, 0.527468, 0.577134]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{30, 384}], {
             RGBColor[
             0.8310143333333333, 0.23939533333333354`, 0.1773326666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{31, 114}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{31, 162}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{31, 203}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 208}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 221}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 223}], {
             RGBColor[0.9006771666666666, 0.789404, 0.6159235000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 258}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 289}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 297}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 314}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 381}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 397}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 419}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{31, 472}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 103}], {
             RGBColor[
             0.9064263333333333, 0.6244323333333336, 0.2605946666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 155}], {
             RGBColor[
             0.9600031666666666, 0.9339106666666667, 0.6485544999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 331}], {
             RGBColor[0.9326351666666666, 0.912505, 0.660396]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{32, 344}], {
             RGBColor[
             0.9812493333333333, 0.9472683333333334, 0.4788846666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 403}], {
             RGBColor[0.8940635000000001, 0.8817490000000001, 0.656717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 449}], {
             RGBColor[0.9761675, 0.9459660000000001, 0.6211925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 119}], {
             RGBColor[
             0.7731385000000001, 0.5557263333333335, 0.5806683333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 159}], {
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 164}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 227}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 267}], {
             RGBColor[0.5774426666666668, 0.666926, 0.9604976666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 270}], {
             RGBColor[
             0.7731385000000001, 0.5557263333333335, 0.5806683333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 309}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 443}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 489}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 234}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 269}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 332}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 360}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 393}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 468}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 54}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 67}], {
             RGBColor[0.9761675, 0.9459660000000001, 0.6211925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 70}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 84}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 131}], {
             RGBColor[0.9289355, 0.7535093333333336, 0.563975]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{35, 135}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 147}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 171}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 216}], {
             RGBColor[0.9442094999999999, 0.822865, 0.57672]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{35, 281}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 385}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 391}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 37}], {
             RGBColor[0.6366510000000001, 0.71318, 0.966399]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{36, 58}], {
             RGBColor[
             0.7025906666666666, 0.7653416666666666, 0.9582364999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 141}], {
             RGBColor[0.6787725, 0.6125309999999999, 0.5959515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 240}], {
             RGBColor[0.718755, 0.777397, 0.9308745]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 251}], {
             RGBColor[0.6752226666666666, 0.7439359999999999, 0.970078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 310}], {
             RGBColor[
             0.7025906666666666, 0.7653416666666666, 0.9582364999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 352}], {
             RGBColor[
             0.7224516666666667, 0.7789256666666666, 0.8696111666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 367}], {
             RGBColor[0.6366510000000001, 0.71318, 0.966399]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{36, 382}], {
             RGBColor[
             0.7025906666666666, 0.7653416666666666, 0.9582364999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 399}], {
             RGBColor[
             0.5163316666666666, 0.6182203333333334, 0.9550666666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 412}], {
             RGBColor[
             0.7224516666666667, 0.7789256666666666, 0.8696111666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 416}], {
             RGBColor[0.3161225, 0.4362285, 0.9418035]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{36, 429}], {
             RGBColor[0.718755, 0.777397, 0.9308745]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 58}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 118}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 141}], {
             RGBColor[0.8621055000000001, 0.758648, 0.6122445000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 188}], {
             RGBColor[0.6366510000000001, 0.71318, 0.966399]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{37, 240}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 304}], {
             RGBColor[
             0.8468315000000002, 0.6892923333333336, 0.5994995000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 310}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 429}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 47}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 73}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 93}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 108}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 163}], {
             RGBColor[
             0.6086681666666667, 0.6799898333333333, 0.9523983333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 189}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 266}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 364}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 437}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 45}], {
             RGBColor[
             0.5852561666666667, 0.6480911666666667, 0.8613086666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 100}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 127}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 179}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 200}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 213}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 236}], {
             RGBColor[0.9181475, 0.6677260000000003, 0.48978183333333347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 243}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 254}], {
             RGBColor[
             0.9798641666666666, 0.9474946666666667, 0.5599291666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 276}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 283}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 315}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 325}], {
             RGBColor[
             0.9326321666666667, 0.7550380000000002, 0.5027116666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 368}], {
             RGBColor[0.674261, 0.7371853333333334, 0.8665405000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 401}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 450}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{39, 454}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 471}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 475}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 114}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{40, 199}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 208}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 220}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 289}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 291}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 297}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 314}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 349}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{40, 359}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 371}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 397}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 419}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{40, 472}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 102}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{41, 186}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 191}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{41, 202}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{41, 212}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 295}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 300}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{41, 389}], {
             RGBColor[0.9006771666666666, 0.789404, 0.6159235000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 451}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 456}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 485}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 85}], {
             RGBColor[0.9761675, 0.9459660000000001, 0.6211925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 95}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[0.9442094999999999, 0.822865, 0.57672]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{42, 137}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 145}], {
             RGBColor[0.9289355, 0.7535093333333336, 0.563975]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{42, 174}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 248}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 286}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 294}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 346}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 358}], {
             RGBColor[0.9442094999999999, 0.822865, 0.57672]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{42, 407}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 411}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 430}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 110}], {
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 217}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 290}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 316}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 340}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 355}], {
             RGBColor[
             0.7025906666666666, 0.7653416666666666, 0.9582364999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 362}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{43, 378}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 384}], {
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 57}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 106}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 117}], {
             RGBColor[
             0.6404563333333333, 0.7180833333333334, 0.9654583333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 139}], {
             RGBColor[0.8028971666666667, 0.712394, 0.6063431666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 140}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 247}], {
             RGBColor[
             0.7607756666666667, 0.8130430000000001, 0.9767906666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 255}], {
             RGBColor[0.8028971666666667, 0.712394, 0.6063431666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 269}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 360}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 369}], {
             RGBColor[
             0.7607756666666667, 0.8130430000000001, 0.9767906666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 370}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 425}], {
             RGBColor[
             0.7607756666666667, 0.8130430000000001, 0.9767906666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 466}], {
             RGBColor[
             0.7607756666666667, 0.8130430000000001, 0.9767906666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 468}], {
             RGBColor[
             0.7607756666666667, 0.8130430000000001, 0.9767906666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 52}], {
             RGBColor[
             0.2679318333333333, 0.39448816666666664`, 0.9387328333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 56}], {
             RGBColor[0.5815595, 0.6465624999999999, 0.922572]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{45, 179}], {
             RGBColor[
             0.5852561666666667, 0.6480911666666667, 0.8613086666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 236}], {
             RGBColor[
             0.5118183333333333, 0.32502883333333354`, 0.5619741666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 243}], {
             RGBColor[0.4994555000000001, 0.5823455, 0.9580965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 254}], {
             RGBColor[0.5735349999999999, 0.6047975000000001, 0.6321215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 276}], {
             RGBColor[
             0.5653951666666666, 0.6345071666666666, 0.9499340000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 283}], {
             RGBColor[
             0.5653951666666666, 0.6345071666666666, 0.9499340000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 292}], {
             RGBColor[0.585715, 0.6458835, 0.6794385000000001]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{45, 386}], {
             RGBColor[
             0.3791361666666666, 0.4873858333333333, 0.9467641666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 422}], {
             RGBColor[
             0.5852561666666667, 0.6480911666666667, 0.8613086666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 53}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685095]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{46, 68}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 90}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 205}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 257}], {
             RGBColor[0.9614548333333334, 0.8912370000000001, 0.590596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 272}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 293}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 298}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 306}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 317}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 357}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 418}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 420}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 55}], {
             RGBColor[0.9326351666666666, 0.912505, 0.660396]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{47, 189}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 230}], {
             RGBColor[0.6752226666666666, 0.7439359999999999, 0.970078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 242}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 339}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 364}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 365}], {
             RGBColor[
             0.6270319999999999, 0.7021956666666667, 0.9670073333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 374}], {
             RGBColor[0.8572231666666666, 0.527468, 0.577134]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{47, 437}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 78}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 85}], {
             RGBColor[0.980323, 0.945287, 0.378059]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 95}], {
             RGBColor[0.904911, 0.56025, 0.294797]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 137}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685095]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{48, 145}], {
             RGBColor[0.9330910000000001, 0.7528303333333335, 0.3208415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 183}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 346}], {
             RGBColor[
             0.9934293333333333, 0.9883543333333333, 0.5262016666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 358}], {
             RGBColor[0.948365, 0.8221860000000001, 0.3335865]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{48, 404}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685095]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{48, 407}], {
             RGBColor[
             0.7859241666666666, 0.8278753333333333, 0.6927016666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 408}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 71}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{49, 76}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 238}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 328}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{49, 402}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 431}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 436}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{49, 459}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 462}], {
             RGBColor[0.8940635000000001, 0.8817490000000001, 0.656717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 487}], {
             RGBColor[0.8621055000000001, 0.758648, 0.6122445000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 57}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 92}], {
             RGBColor[
             0.8348551666666667, 0.8354950000000001, 0.6508156666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 106}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 117}], {
             RGBColor[
             0.6404563333333333, 0.7180833333333334, 0.9654583333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 139}], {
             RGBColor[0.8028971666666667, 0.712394, 0.6063431666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 140}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 169}], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 204}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 219}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 244}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 255}], {
             RGBColor[0.8028971666666667, 0.712394, 0.6063431666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 274}], {
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 334}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 338}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 340}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 361}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 363}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 369}], {
             RGBColor[
             0.7607756666666667, 0.8130430000000001, 0.9767906666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 370}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 379}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 113}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{51, 127}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 130}], {
             RGBColor[0.8186515000000001, 0.49671200000000004`, 0.573455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 143}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 179}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 214}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 302}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 308}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 315}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 325}], {
             RGBColor[
             0.8468315000000002, 0.6892923333333336, 0.5994995000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 347}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 386}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 421}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{51, 423}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 477}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{52, 56}], {
             RGBColor[
             0.6705643333333333, 0.7356566666666666, 0.9278038333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 88}], {
             RGBColor[0.627032, 0.7021956666666667, 0.9670073333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 166}], {
             RGBColor[
             0.6705643333333333, 0.7356566666666666, 0.9278038333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 210}], {
             RGBColor[
             0.6543999999999999, 0.7236013333333333, 0.9551658333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 227}], {
             RGBColor[
             0.6543999999999999, 0.7236013333333333, 0.9551658333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 236}], {
             RGBColor[
             0.6008231666666667, 0.4141230000000002, 0.5672060000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 243}], {
             RGBColor[
             0.5884603333333334, 0.6714396666666667, 0.9633283333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 276}], {
             RGBColor[
             0.6543999999999999, 0.7236013333333333, 0.9551658333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 326}], {
             RGBColor[
             0.6705643333333333, 0.7356566666666666, 0.9278038333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 428}], {
             RGBColor[
             0.4051273333333333, 0.5253226666666666, 0.9470353333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 469}], {
             RGBColor[0.627032, 0.7021956666666667, 0.9670073333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 495}], {
             RGBColor[
             0.3569366666666666, 0.4835823333333333, 0.9439646666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 90}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 178}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 257}], {
             RGBColor[0.9656103333333335, 0.8905580000000002, 0.3474625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 272}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 298}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 306}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 317}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 357}], {
             RGBColor[
             0.9934293333333333, 0.9883543333333333, 0.5262016666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 418}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 420}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 432}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685095]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{54, 55}], {
             RGBColor[
             0.8348551666666667, 0.8354950000000001, 0.6508156666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 70}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 84}], {
             RGBColor[
             0.6404563333333333, 0.7180833333333334, 0.9654583333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 131}], {
             RGBColor[
             0.7876231666666668, 0.6430383333333336, 0.5935981666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 135}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 147}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 230}], {
             RGBColor[0.5774426666666668, 0.666926, 0.9604976666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 242}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 365}], {
             RGBColor[0.5292520000000001, 0.6251856666666666, 0.957427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 374}], {
             RGBColor[0.7594431666666668, 0.450458, 0.5675536666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 385}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 391}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 230}], {
             RGBColor[0.7107304999999999, 0.7356320000000001, 0.640424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 242}], {
             RGBColor[0.9761675, 0.9459660000000001, 0.6211925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 250}], {
             RGBColor[
             0.8348551666666667, 0.8354950000000001, 0.6508156666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 339}], {
             RGBColor[
             0.7737441666666667, 0.7867893333333333, 0.6453846666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 365}], {
             RGBColor[
             0.6625398333333333, 0.6938916666666667, 0.6373533333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 88}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 164}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 166}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 210}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 227}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 236}], {
             RGBColor[
             0.9144508333333333, 0.6661973333333335, 0.5510451666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 243}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 276}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 326}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 428}], {
             RGBColor[0.718755, 0.777397, 0.9308745]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 495}], {
             RGBColor[
             0.6705643333333333, 0.7356566666666666, 0.9278038333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 92}], {
             RGBColor[0.9326351666666666, 0.912505, 0.660396]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{57, 106}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 139}], {
             RGBColor[0.9006771666666666, 0.789404, 0.6159235000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 140}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 169}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 175}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{57, 204}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 219}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 255}], {
             RGBColor[0.9006771666666666, 0.789404, 0.6159235000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 274}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 334}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 337}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 361}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 363}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 369}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{57, 370}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{57, 466}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{58, 118}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 141}], {
             RGBColor[0.9280451666666667, 0.8108096666666667, 0.604082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 188}], {
             RGBColor[
             0.7025906666666666, 0.7653416666666666, 0.9582364999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 220}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 240}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 304}], {
             RGBColor[0.9127711666666667, 0.7414540000000002, 0.591337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 310}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 371}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 382}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 429}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 74}], {
             RGBColor[
             0.9144508333333333, 0.6661973333333335, 0.5510451666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 82}], {
             RGBColor[
             0.7731385000000001, 0.5557263333333335, 0.5806683333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 105}], {
             RGBColor[
             0.8709184999999999, 0.6327363333333336, 0.5902486666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 153}], {
             RGBColor[
             0.9144508333333333, 0.6661973333333335, 0.5510451666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 195}], {
             RGBColor[
             0.8447096666666667, 0.3446636666666671, 0.19044733333333339`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 263}], {
             RGBColor[0.9181475, 0.6677260000000003, 0.48978183333333347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 323}], {
             RGBColor[
             0.8709184999999999, 0.6327363333333336, 0.5902486666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 342}], {
             RGBColor[
             0.8709184999999999, 0.6327363333333336, 0.5902486666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 395}], {
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 447}], {
             RGBColor[
             0.9195326666666667, 0.6674996666666668, 0.4087373333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 453}], {
             RGBColor[
             0.8447096666666667, 0.3446636666666671, 0.19044733333333339`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 463}], {
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 116}], {
             RGBColor[0.8621055000000001, 0.758648, 0.6122445000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 118}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 133}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 151}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 188}], {
             RGBColor[0.6366510000000001, 0.71318, 0.966399]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{60, 192}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{60, 249}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 260}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 280}], {
             RGBColor[
             0.8793508333333335, 0.8270200000000001, 0.6261205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 310}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 327}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{60, 483}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 64}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 91}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{61, 172}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 303}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 362}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 384}], {
             RGBColor[
             0.9144508333333333, 0.6661973333333335, 0.5510451666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 435}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 473}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 132}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 209}], {
             RGBColor[0.8621055000000001, 0.758648, 0.6122445000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 233}], {
             RGBColor[
             0.5884603333333334, 0.6714396666666667, 0.9633283333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 75}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 149}], {
             RGBColor[
             0.6983321666666666, 0.4017523333333333, 0.5621226666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 158}], {
             RGBColor[
             0.7859241666666666, 0.8278753333333333, 0.6927016666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 165}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 182}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 206}], {
             RGBColor[
             0.6404563333333333, 0.7180833333333334, 0.9654583333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 252}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 275}], {
             RGBColor[
             0.7868504999999999, 0.8298566666666667, 0.7935273333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 282}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 324}], {
             RGBColor[
             0.7868504999999999, 0.8298566666666667, 0.7935273333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 410}], {
             RGBColor[
             0.6404563333333333, 0.7180833333333334, 0.9654583333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 441}], {
             RGBColor[
             0.7868504999999999, 0.8298566666666667, 0.7935273333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 467}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 91}], {
             RGBColor[0.7594431666666668, 0.450458, 0.5675536666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 172}], {
             RGBColor[
             0.7607756666666667, 0.8130430000000001, 0.9767906666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 303}], {
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 366}], {
             RGBColor[
             0.6404563333333333, 0.7180833333333334, 0.9654583333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 384}], {
             RGBColor[
             0.7731385000000001, 0.5557263333333335, 0.5806683333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 435}], {
             RGBColor[
             0.6404563333333333, 0.7180833333333334, 0.9654583333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 473}], {
             RGBColor[
             0.7607756666666667, 0.8130430000000001, 0.9767906666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 88}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 166}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 167}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 175}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 227}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 309}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 320}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685095]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{65, 337}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 348}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 428}], {
             RGBColor[0.718755, 0.777397, 0.9308745]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 434}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685095]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{65, 474}], {
             RGBColor[
             0.6705643333333333, 0.7356566666666666, 0.9278038333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 495}], {
             RGBColor[
             0.6705643333333333, 0.7356566666666666, 0.9278038333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 208}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 305}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 314}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 394}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 398}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 427}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 445}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 460}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 472}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 70}], {
             RGBColor[
             0.9798641666666666, 0.9474946666666667, 0.5599291666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 96}], {
             RGBColor[
             0.7737441666666667, 0.7867893333333333, 0.6453846666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 131}], {
             RGBColor[0.920911, 0.7117443333333335, 0.27352450000000006`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 135}], {
             RGBColor[
             0.9798641666666666, 0.9474946666666667, 0.5599291666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 147}], {
             RGBColor[0.9761675, 0.9459660000000001, 0.6211925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 171}], {
             RGBColor[
             0.8348551666666667, 0.8354950000000001, 0.6508156666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 180}], {
             RGBColor[
             0.9812493333333333, 0.9472683333333334, 0.4788846666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 216}], {
             RGBColor[0.936185, 0.7811, 0.2862695]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 238}], {
             RGBColor[
             0.9798641666666666, 0.9474946666666667, 0.5599291666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 281}], {
             RGBColor[
             0.8348551666666667, 0.8354950000000001, 0.6508156666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 343}], {
             RGBColor[
             0.9600031666666666, 0.9339106666666667, 0.6485544999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 385}], {
             RGBColor[
             0.9600031666666666, 0.9339106666666667, 0.6485544999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 391}], {
             RGBColor[
             0.9600031666666666, 0.9339106666666667, 0.6485544999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 465}], {
             RGBColor[
             0.9798641666666666, 0.9474946666666667, 0.5599291666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 205}], {
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 257}], {
             RGBColor[
             0.9665366666666667, 0.8925393333333335, 0.4482881666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 272}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{68, 306}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 317}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 142}], {
             RGBColor[0.674261, 0.7371853333333334, 0.8665405000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 173}], {
             RGBColor[0.5292520000000001, 0.6251856666666666, 0.957427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 194}], {
             RGBColor[0.627032, 0.7021956666666667, 0.9670073333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 241}], {
             RGBColor[
             0.6747198333333333, 0.7349776666666668, 0.6846703333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 388}], {
             RGBColor[
             0.6747198333333333, 0.7349776666666668, 0.6846703333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 402}], {
             RGBColor[0.674261, 0.7371853333333334, 0.8665405000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 461}], {
             RGBColor[
             0.6543999999999999, 0.7236013333333333, 0.9551658333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 487}], {
             RGBColor[
             0.6305818333333333, 0.5707906666666667, 0.5928808333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 490}], {
             RGBColor[
             0.6705643333333333, 0.7356566666666666, 0.9278038333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 84}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 96}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 131}], {
             RGBColor[
             0.9326321666666667, 0.7550380000000002, 0.5027116666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 135}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 147}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 170}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 171}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 216}], {
             RGBColor[
             0.9479061666666666, 0.8243936666666667, 0.5154566666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 265}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{70, 374}], {
             RGBColor[
             0.9044521666666667, 0.5624576666666667, 0.47666716666666675`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 385}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 391}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 433}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 194}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{71, 228}], {
             RGBColor[0.9326351666666666, 0.912505, 0.660396]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{71, 388}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 431}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 462}], {
             RGBColor[0.9326351666666666, 0.912505, 0.660396]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{71, 487}], {
             RGBColor[0.9006771666666666, 0.789404, 0.6159235000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 490}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 73}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 144}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 163}], {
             RGBColor[
             0.6086681666666667, 0.6799898333333333, 0.9523983333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 187}], {
             RGBColor[0.9280451666666667, 0.8108096666666667, 0.604082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 279}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 322}], {
             RGBColor[0.9452905, 0.8791816666666668, 0.617958]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{72, 494}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 93}], {
             RGBColor[
             0.7607756666666667, 0.8130430000000001, 0.9767906666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 163}], {
             RGBColor[0.48352016666666675`, 0.5815741666666667, 0.9546595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 187}], {
             RGBColor[0.8028971666666667, 0.712394, 0.6063431666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 322}], {
             RGBColor[
             0.8201425000000001, 0.7807660000000001, 0.6202191666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 494}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 82}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 105}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 112}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 153}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 195}], {
             RGBColor[
             0.9144508333333333, 0.6661973333333335, 0.5510451666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 224}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685095]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{74, 234}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 239}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685095]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{74, 263}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 296}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 342}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 395}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 440}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 447}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 453}], {
             RGBColor[
             0.9144508333333333, 0.6661973333333335, 0.5510451666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 463}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 93}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 108}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 149}], {
             RGBColor[0.8845911666666666, 0.5488736666666667, 0.5652925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 158}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.6086681666666667, 0.6799898333333333, 0.9523983333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 182}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 206}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 410}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 238}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 333}], {
             RGBColor[
             0.8323468333333335, 0.6019803333333336, 0.5865696666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 343}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 392}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{76, 402}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 431}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 436}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{76, 459}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 462}], {
             RGBColor[0.8940635000000001, 0.8817490000000001, 0.656717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 487}], {
             RGBColor[0.8621055000000001, 0.758648, 0.6122445000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 81}], {
             RGBColor[0.4681409999999999, 0.57648, 0.9519960000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 156}], {
             RGBColor[
             0.7265121666666667, 0.5943326666666668, 0.5881671666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 278}], {
             RGBColor[
             0.6404563333333333, 0.7180833333333334, 0.9654583333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 329}], {
             RGBColor[
             0.7868504999999999, 0.8298566666666667, 0.7935273333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 479}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 482}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 85}], {
             RGBColor[0.8940635000000001, 0.8817490000000001, 0.656717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 95}], {
             RGBColor[0.8186515000000001, 0.49671200000000004`, 0.573455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 97}], {
             RGBColor[0.8621055000000001, 0.758648, 0.6122445000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 137}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 145}], {
             RGBColor[
             0.8468315000000002, 0.6892923333333336, 0.5994995000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 183}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{78, 346}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 358}], {
             RGBColor[0.8621055000000001, 0.758648, 0.6122445000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 404}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 407}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 408}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 430}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 81}], {
             RGBColor[
             0.6747198333333333, 0.7349776666666666, 0.6846703333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 99}], {
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 122}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 267}], {
             RGBColor[0.7229105, 0.776718, 0.6877409999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{79, 278}], {
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 329}], {
             RGBColor[
             0.9934293333333333, 0.9883543333333333, 0.5262016666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 406}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 413}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 476}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 486}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 493}], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 156}], {
             RGBColor[
             0.7876231666666668, 0.6430383333333336, 0.5935981666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 278}], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 307}], {
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 329}], {
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 372}], {
             RGBColor[0.7594431666666668, 0.450458, 0.5675536666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 406}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 417}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 461}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 486}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 493}], {
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 83}], {
             RGBColor[
             0.6705643333333333, 0.7356566666666666, 0.9278038333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 99}], {
             RGBColor[0.5292520000000001, 0.6251856666666666, 0.957427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 237}], {
             RGBColor[
             0.3569366666666666, 0.4835823333333333, 0.9439646666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[
             0.4051273333333333, 0.5253226666666666, 0.9470353333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 278}], {
             RGBColor[0.5292520000000001, 0.6251856666666666, 0.957427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 329}], {
             RGBColor[
             0.6756461666666667, 0.7369589999999999, 0.7854960000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 426}], {
             RGBColor[0.674261, 0.7371853333333334, 0.8665405000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 486}], {
             RGBColor[0.674261, 0.7371853333333334, 0.8665405000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 89}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 105}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 184}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 195}], {
             RGBColor[
             0.7731385000000001, 0.5557263333333335, 0.5806683333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 225}], {
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 263}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 296}], {
             RGBColor[
             0.6404563333333333, 0.7180833333333334, 0.9654583333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 342}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 395}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 440}], {
             RGBColor[
             0.7607756666666667, 0.8130430000000001, 0.9767906666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 447}], {
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 453}], {
             RGBColor[
             0.7731385000000001, 0.5557263333333335, 0.5806683333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 463}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 470}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 119}], {
             RGBColor[
             0.9144508333333333, 0.6661973333333335, 0.5510451666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 176}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 237}], {
             RGBColor[
             0.6705643333333333, 0.7356566666666666, 0.9278038333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 270}], {
             RGBColor[
             0.9144508333333333, 0.6661973333333335, 0.5510451666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 345}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685095]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{83, 375}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 426}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 448}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 489}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 131}], {
             RGBColor[
             0.7265121666666667, 0.5943326666666668, 0.5881671666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 135}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 147}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 171}], {
             RGBColor[
             0.6404563333333333, 0.7180833333333334, 0.9654583333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 230}], {
             RGBColor[
             0.5163316666666666, 0.6182203333333334, 0.9550666666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 242}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 365}], {
             RGBColor[0.4681409999999999, 0.57648, 0.9519960000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 374}], {
             RGBColor[
             0.6983321666666666, 0.4017523333333333, 0.5621226666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 385}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 391}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 95}], {
             RGBColor[0.8927309999999999, 0.519164, 0.24747999999999998`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 97}], {
             RGBColor[0.936185, 0.7811, 0.2862695]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 137}], {
             RGBColor[0.9761675, 0.9459660000000001, 0.6211925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 145}], {
             RGBColor[0.920911, 0.7117443333333335, 0.27352450000000006`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 183}], {
             RGBColor[0.9326351666666666, 0.912505, 0.660396]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{85, 286}], {
             RGBColor[
             0.9600031666666666, 0.9339106666666667, 0.6485544999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 346}], {
             RGBColor[
             0.9812493333333333, 0.9472683333333334, 0.4788846666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 358}], {
             RGBColor[0.936185, 0.7811, 0.2862695]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 404}], {
             RGBColor[0.9761675, 0.9459660000000001, 0.6211925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 407}], {
             RGBColor[
             0.7737441666666667, 0.7867893333333333, 0.6453846666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 408}], {
             RGBColor[0.8940635000000001, 0.8817490000000001, 0.656717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 90}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 98}], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 115}], {
             RGBColor[
             0.7868504999999999, 0.8298566666666667, 0.7935273333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 124}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 136}], {
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 168}], {
             RGBColor[
             0.7868504999999999, 0.8298566666666667, 0.7935273333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{86, 253}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 261}], {
             RGBColor[
             0.9934293333333333, 0.9883543333333333, 0.5262016666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 357}], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 484}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{86, 500}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{87, 107}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 113}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 143}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 226}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 292}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 308}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{87, 386}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 421}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 422}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 423}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 446}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 166}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 167}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 210}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 227}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 243}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{88, 326}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 348}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 428}], {
             RGBColor[0.6752226666666666, 0.7439359999999999, 0.970078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 434}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 469}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{88, 474}], {
             RGBColor[
             0.6270319999999999, 0.7021956666666667, 0.9670073333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 495}], {
             RGBColor[
             0.6270319999999999, 0.7021956666666667, 0.9670073333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 133}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 184}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 192}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 225}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685095]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{89, 235}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 239}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685095]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{89, 249}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 260}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[0.9614548333333334, 0.8912370000000001, 0.590596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 296}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 424}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 440}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 453}], {
             RGBColor[
             0.9144508333333333, 0.6661973333333335, 0.5510451666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 470}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 124}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{90, 178}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[0.9179225, 0.8577760000000001, 0.6297995000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 261}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 272}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 306}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{90, 317}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{90, 357}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 172}], {
             RGBColor[0.8186515000000001, 0.49671200000000004`, 0.573455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 303}], {
             RGBColor[
             0.9058373333333334, 0.5622313333333333, 0.3956226666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 366}], {
             RGBColor[
             0.6983321666666666, 0.4017523333333333, 0.5621226666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 435}], {
             RGBColor[
             0.6983321666666666, 0.4017523333333333, 0.5621226666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 473}], {
             RGBColor[0.8186515000000001, 0.49671200000000004`, 0.573455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 101}], {
             RGBColor[0.968143, 0.904201, 0.330742]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 128}], {
             RGBColor[0.936185, 0.7811, 0.2862695]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 140}], {
             RGBColor[
             0.9798641666666666, 0.9474946666666667, 0.5599291666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 169}], {
             RGBColor[
             0.8348551666666667, 0.8354950000000001, 0.6508156666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 175}], {
             RGBColor[0.9326351666666666, 0.912505, 0.660396]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{92, 204}], {
             RGBColor[
             0.9798641666666666, 0.9474946666666667, 0.5599291666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 219}], {
             RGBColor[
             0.9798641666666666, 0.9474946666666667, 0.5599291666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 274}], {
             RGBColor[0.980323, 0.945287, 0.378059]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 320}], {
             RGBColor[0.980323, 0.945287, 0.378059]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 334}], {
             RGBColor[
             0.9798641666666666, 0.9474946666666667, 0.5599291666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 337}], {
             RGBColor[
             0.7737441666666667, 0.7867893333333333, 0.6453846666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 361}], {
             RGBColor[
             0.9798641666666666, 0.9474946666666667, 0.5599291666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 363}], {
             RGBColor[0.9761675, 0.9459660000000001, 0.6211925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 370}], {
             RGBColor[0.9326351666666666, 0.912505, 0.660396]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{92, 498}], {
             RGBColor[
             0.7737441666666667, 0.7867893333333333, 0.6453846666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 108}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 163}], {
             RGBColor[
             0.5427285000000001, 0.6278281666666667, 0.9605608333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 187}], {
             RGBColor[0.8621055000000001, 0.758648, 0.6122445000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 189}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 206}], {
             RGBColor[
             0.7607756666666667, 0.8130430000000001, 0.9767906666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 266}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 322}], {
             RGBColor[
             0.8793508333333335, 0.8270200000000001, 0.6261205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 364}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 437}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 100}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 127}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 168}], {
             RGBColor[
             0.7859241666666666, 0.8278753333333333, 0.6927016666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 213}], {
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 214}], {
             RGBColor[
             0.9934293333333333, 0.9883543333333333, 0.5262016666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 254}], {
             RGBColor[0.980323, 0.945287, 0.378059]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 302}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 315}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685095]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{94, 325}], {
             RGBColor[0.9330910000000001, 0.7528303333333335, 0.3208415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 368}], {
             RGBColor[
             0.6747198333333333, 0.7349776666666666, 0.6846703333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 401}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685095]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{94, 477}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 500}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 97}], {
             RGBColor[0.860773, 0.396063, 0.2030075]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 137}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{95, 145}], {
             RGBColor[0.845499, 0.3267073333333335, 0.19026250000000006`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 174}], {
             RGBColor[0.8186515000000001, 0.49671200000000004`, 0.573455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 286}], {
             RGBColor[0.8845911666666666, 0.5488736666666667, 0.5652925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 294}], {
             RGBColor[0.8186515000000001, 0.49671200000000004`, 0.573455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 346}], {
             RGBColor[
             0.9058373333333334, 0.5622313333333333, 0.3956226666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 358}], {
             RGBColor[0.860773, 0.396063, 0.2030075]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 404}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{95, 407}], {
             RGBColor[
             0.6983321666666666, 0.4017523333333333, 0.5621226666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 408}], {
             RGBColor[0.8186515000000001, 0.49671200000000004`, 0.573455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 430}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{96, 131}], {
             RGBColor[
             0.7265121666666667, 0.5943326666666668, 0.5881671666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 147}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 171}], {
             RGBColor[
             0.6404563333333333, 0.7180833333333334, 0.9654583333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 180}], {
             RGBColor[
             0.7868504999999999, 0.8298566666666667, 0.7935273333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 216}], {
             RGBColor[
             0.7417861666666666, 0.6636883333333333, 0.6009121666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 238}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 265}], {
             RGBColor[
             0.7868504999999999, 0.8298566666666667, 0.7935273333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 281}], {
             RGBColor[
             0.6404563333333333, 0.7180833333333334, 0.9654583333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 343}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 392}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 433}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 465}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 104}], {
             RGBColor[0.948365, 0.8221860000000001, 0.3335865]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{97, 137}], {
             RGBColor[0.9442094999999999, 0.822865, 0.57672]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{97, 145}], {
             RGBColor[
             0.8889530000000001, 0.5886433333333335, 0.22905200000000003`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 174}], {
             RGBColor[0.8621055000000001, 0.758648, 0.6122445]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{97, 294}], {
             RGBColor[0.8621055000000001, 0.758648, 0.6122445]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{97, 346}], {
             RGBColor[
             0.9492913333333333, 0.8241673333333334, 0.4344121666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 358}], {
             RGBColor[0.904227, 0.657999, 0.241797]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 404}], {
             RGBColor[0.9442094999999999, 0.822865, 0.57672]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{97, 407}], {
             RGBColor[
             0.7417861666666666, 0.6636883333333333, 0.6009121666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 408}], {
             RGBColor[0.8621055000000001, 0.758648, 0.6122445]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{97, 430}], {
             RGBColor[0.9442094999999999, 0.822865, 0.57672]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{98, 115}], {
             RGBColor[
             0.7868504999999999, 0.8298566666666667, 0.7935273333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 124}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 136}], {
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 253}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 261}], {
             RGBColor[
             0.9934293333333333, 0.9883543333333333, 0.5262016666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 277}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 311}], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 319}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{98, 331}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 377}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 484}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{98, 488}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 122}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 267}], {
             RGBColor[0.5774426666666668, 0.666926, 0.9604976666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 278}], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 329}], {
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 406}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 413}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 476}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 486}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 493}], {
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 121}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 127}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 168}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 200}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 213}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 254}], {
             RGBColor[
             0.9600031666666666, 0.9339106666666667, 0.6485544999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 259}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 315}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 368}], {
             RGBColor[0.6544, 0.7236013333333333, 0.9551658333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 401}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 450}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{100, 454}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 471}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 475}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 500}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 128}], {
             RGBColor[0.936185, 0.7811, 0.2862695]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 169}], {
             RGBColor[
             0.8348551666666667, 0.8354950000000001, 0.6508156666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 197}], {
             RGBColor[0.8940635000000001, 0.8817490000000001, 0.656717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[
             0.9798641666666666, 0.9474946666666667, 0.5599291666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 219}], {
             RGBColor[
             0.9798641666666666, 0.9474946666666667, 0.5599291666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 337}], {
             RGBColor[
             0.7737441666666667, 0.7867893333333333, 0.6453846666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 345}], {
             RGBColor[0.980323, 0.945287, 0.378059]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 355}], {
             RGBColor[0.7107304999999999, 0.7356320000000001, 0.640424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 361}], {
             RGBColor[
             0.9798641666666666, 0.9474946666666667, 0.5599291666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 362}], {
             RGBColor[
             0.9812493333333333, 0.9472683333333334, 0.4788846666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 363}], {
             RGBColor[0.9761675, 0.9459660000000001, 0.6211925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 498}], {
             RGBColor[
             0.7737441666666667, 0.7867893333333333, 0.6453846666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 109}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 186}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 193}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 196}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 202}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{102, 330}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{102, 350}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 354}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 414}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{102, 415}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 485}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 496}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 118}], {
             RGBColor[
             0.8323468333333335, 0.6019803333333336, 0.5865696666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 188}], {
             RGBColor[
             0.6490138333333333, 0.4558633333333335, 0.5702766666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 304}], {
             RGBColor[
             0.8591943333333334, 0.4319756666666671, 0.20337716666666672`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 319}], {
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 331}], {
             RGBColor[
             0.8709184999999999, 0.6327363333333336, 0.5902486666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 449}], {
             RGBColor[
             0.9144508333333333, 0.6661973333333335, 0.5510451666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 488}], {
             RGBColor[
             0.9144508333333333, 0.6661973333333335, 0.5510451666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 112}], {
             RGBColor[
             0.7859241666666666, 0.8278753333333333, 0.6927016666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 148}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 153}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685095]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{104, 190}], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 215}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 224}], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 323}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 351}], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 356}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 408}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 430}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685095]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{104, 452}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 112}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 148}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 153}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 190}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 195}], {
             RGBColor[
             0.8709184999999999, 0.6327363333333336, 0.5902486666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 263}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 323}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{105, 342}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{105, 395}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 447}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 453}], {
             RGBColor[
             0.8709184999999999, 0.6327363333333336, 0.5902486666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 463}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 117}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 139}], {
             RGBColor[
             0.9479061666666666, 0.8243936666666667, 0.5154566666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 140}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 247}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 255}], {
             RGBColor[
             0.9479061666666666, 0.8243936666666667, 0.5154566666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 269}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 274}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 360}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 369}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 370}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 425}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 466}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 468}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 113}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 132}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{107, 143}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 209}], {
             RGBColor[0.9280451666666667, 0.8108096666666667, 0.604082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 214}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{107, 273}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 308}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{107, 421}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 423}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 446}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 477}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 129}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 163}], {
             RGBColor[0.6248325, 0.6920451666666667, 0.9250363333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 189}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 206}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 266}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 364}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 374}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{108, 410}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 437}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 185}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 186}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 196}], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 218}], {
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 295}], {
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 300}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 335}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 409}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 456}], {
             RGBColor[
             0.7868504999999999, 0.8298566666666667, 0.7935273333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 458}], {
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 496}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{110, 217}], {
             RGBColor[
             0.7731385000000001, 0.5557263333333335, 0.5806683333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 290}], {
             RGBColor[0.7120275, 0.5070206666666669, 0.5752373333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 316}], {
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 340}], {
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 355}], {
             RGBColor[
             0.6490138333333333, 0.4558633333333335, 0.5702766666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 378}], {
             RGBColor[
             0.8709184999999999, 0.6327363333333336, 0.5902486666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 384}], {
             RGBColor[
             0.8447096666666667, 0.3446636666666671, 0.19044733333333339`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 146}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 201}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 256}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 271}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 284}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 312}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 376}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 415}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 442}], {
             RGBColor[0.9452905, 0.8791816666666668, 0.617958]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{111, 444}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 464}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 148}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 153}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 190}], {
             RGBColor[
             0.7859241666666666, 0.8278753333333333, 0.6927016666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 195}], {
             RGBColor[0.7120275, 0.5070206666666669, 0.5752373333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 224}], {
             RGBColor[
             0.7859241666666666, 0.8278753333333333, 0.6927016666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 263}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 323}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 342}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 351}], {
             RGBColor[
             0.7859241666666666, 0.8278753333333333, 0.6927016666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 356}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 395}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 447}], {
             RGBColor[
             0.7868504999999999, 0.8298566666666667, 0.7935273333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 452}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 463}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 130}], {
             RGBColor[0.8572231666666666, 0.527468, 0.577134]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{113, 143}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 209}], {
             RGBColor[0.9006771666666666, 0.789404, 0.6159235000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 214}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 273}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 302}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 308}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 325}], {
             RGBColor[
             0.8854031666666666, 0.7200483333333335, 0.6031785000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 347}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{113, 386}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 421}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{113, 423}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 477}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{114, 115}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 203}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 208}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 258}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 289}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 291}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 297}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 311}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 349}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{114, 359}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{114, 381}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 397}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 419}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{115, 124}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 136}], {
             RGBColor[
             0.6404563333333333, 0.7180833333333334, 0.9654583333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 178}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 203}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 253}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 277}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 291}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 297}], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 311}], {
             RGBColor[
             0.7868504999999999, 0.8298566666666667, 0.7935273333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 381}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 419}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 439}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 484}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 192}], {
             RGBColor[0.9006771666666666, 0.789404, 0.6159235]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{116, 280}], {
             RGBColor[
             0.9214723333333334, 0.7263710000000001, 0.25567300000000004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 310}], {
             RGBColor[0.9280451666666667, 0.8108096666666667, 0.604082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 327}], {
             RGBColor[0.9006771666666666, 0.789404, 0.6159235]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{116, 399}], {
             RGBColor[
             0.7417861666666666, 0.6636883333333333, 0.6009121666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 412}], {
             RGBColor[
             0.9479061666666666, 0.8243936666666667, 0.5154566666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 483}], {
             RGBColor[0.948365, 0.8221860000000001, 0.3335865]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{117, 139}], {
             RGBColor[
             0.7417861666666666, 0.6636883333333333, 0.6009121666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 140}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 154}], {
             RGBColor[
             0.7868504999999999, 0.8298566666666667, 0.7935273333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 247}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 255}], {
             RGBColor[
             0.7417861666666666, 0.6636883333333333, 0.6009121666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 269}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 338}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 369}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 390}], {
             RGBColor[
             0.7859241666666666, 0.8278753333333333, 0.6927016666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 425}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 466}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[0.8621055000000001, 0.758648, 0.6122445000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 151}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 188}], {
             RGBColor[0.6366510000000001, 0.71318, 0.966399]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{118, 304}], {
             RGBColor[
             0.8468315000000002, 0.6892923333333336, 0.5994995000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 310}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 327}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{118, 483}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 197}], {
             RGBColor[
             0.8323468333333335, 0.6019803333333336, 0.5865696666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 237}], {
             RGBColor[0.6008231666666667, 0.4141230000000002, 0.567206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 270}], {
             RGBColor[
             0.8447096666666667, 0.3446636666666671, 0.19044733333333339`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 309}], {
             RGBColor[0.9181475, 0.6677260000000003, 0.48978183333333347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 320}], {
             RGBColor[
             0.9186063333333334, 0.6655183333333337, 0.3079116666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 345}], {
             RGBColor[
             0.9186063333333334, 0.6655183333333337, 0.3079116666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 375}], {
             RGBColor[0.7120275, 0.5070206666666669, 0.5752373333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 426}], {
             RGBColor[0.9181475, 0.6677260000000003, 0.48978183333333347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 489}], {
             RGBColor[
             0.9144508333333333, 0.6661973333333335, 0.5510451666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 123}], {
             RGBColor[0.9127711666666667, 0.7414540000000002, 0.591337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 125}], {
             RGBColor[0.9127711666666667, 0.7414540000000002, 0.591337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 177}], {
             RGBColor[0.6634985, 0.5431753333333336, 0.5832065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 438}], {
             RGBColor[
             0.8854031666666666, 0.7200483333333335, 0.6031785000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 455}], {
             RGBColor[
             0.8854031666666666, 0.7200483333333335, 0.6031785000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 457}], {
             RGBColor[
             0.7265121666666667, 0.5943326666666668, 0.5881671666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 161}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.7607756666666667, 0.8130430000000001, 0.9767906666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 259}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 341}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 450}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 454}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 469}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{121, 471}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 475}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{121, 491}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 500}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 150}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{122, 233}], {
             RGBColor[0.6544, 0.7236013333333333, 0.9551658333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 267}], {
             RGBColor[
             0.7025906666666666, 0.7653416666666666, 0.9582364999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 406}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 413}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 476}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 493}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 125}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 177}], {
             RGBColor[
             0.7025906666666666, 0.7653416666666666, 0.9582364999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 438}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 455}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 136}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 178}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 253}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{124, 261}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 357}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 484}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 177}], {
             RGBColor[
             0.7025906666666666, 0.7653416666666666, 0.9582364999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 438}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 455}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 457}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 144}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 279}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 285}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 481}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 130}], {
             RGBColor[
             0.9044521666666667, 0.5624576666666667, 0.47666716666666675`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 168}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 179}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 200}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 213}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 254}], {
             RGBColor[
             0.9798641666666666, 0.9474946666666667, 0.5599291666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 302}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 315}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 325}], {
             RGBColor[
             0.9326321666666667, 0.7550380000000002, 0.5027116666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 347}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 368}], {
             RGBColor[0.674261, 0.7371853333333334, 0.8665405000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 386}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 401}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 454}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 169}], {
             RGBColor[0.8028971666666667, 0.712394, 0.6063431666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 197}], {
             RGBColor[0.8621055000000001, 0.758648, 0.6122445]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{128, 204}], {
             RGBColor[
             0.9479061666666666, 0.8243936666666667, 0.5154566666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 345}], {
             RGBColor[0.948365, 0.8221860000000001, 0.3335865]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{128, 355}], {
             RGBColor[0.6787725, 0.6125309999999999, 0.5959515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 362}], {
             RGBColor[
             0.9492913333333333, 0.8241673333333334, 0.4344121666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 498}], {
             RGBColor[
             0.7417861666666666, 0.6636883333333333, 0.6009121666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 170}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 206}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 265}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 266}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 328}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{129, 410}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 433}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 143}], {
             RGBColor[
             0.9044521666666667, 0.5624576666666667, 0.47666716666666675`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 179}], {
             RGBColor[
             0.9044521666666667, 0.5624576666666667, 0.47666716666666675`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 214}], {
             RGBColor[
             0.9058373333333334, 0.5622313333333333, 0.3956226666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 254}], {
             RGBColor[0.8927309999999999, 0.519164, 0.24747999999999998`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 302}], {
             RGBColor[0.8845911666666666, 0.5488736666666667, 0.5652925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 315}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{130, 325}], {
             RGBColor[0.845499, 0.3267073333333335, 0.19026250000000006`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 347}], {
             RGBColor[0.8186515000000001, 0.49671200000000004`, 0.573455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 368}], {
             RGBColor[
             0.5871278333333333, 0.3088546666666666, 0.5540913333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 386}], {
             RGBColor[
             0.6983321666666666, 0.4017523333333333, 0.5621226666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 421}], {
             RGBColor[0.8572231666666666, 0.527468, 0.577134]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{130, 477}], {
             RGBColor[0.8572231666666666, 0.527468, 0.577134]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{131, 135}], {
             RGBColor[
             0.9326321666666667, 0.7550380000000002, 0.5027116666666669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 147}], {
             RGBColor[0.9289355, 0.7535093333333336, 0.5639750000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 170}], {
             RGBColor[0.9127711666666667, 0.7414540000000002, 0.591337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 171}], {
             RGBColor[
             0.7876231666666668, 0.6430383333333336, 0.5935981666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 216}], {
             RGBColor[
             0.8889530000000001, 0.5886433333333335, 0.22905200000000003`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 238}], {
             RGBColor[
             0.9326321666666667, 0.7550380000000002, 0.5027116666666669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 265}], {
             RGBColor[
             0.9340173333333334, 0.7548116666666669, 0.4216671666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 374}], {
             RGBColor[0.845499, 0.3267073333333335, 0.19026250000000006`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 385}], {
             RGBColor[0.9127711666666667, 0.7414540000000002, 0.591337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 391}], {
             RGBColor[0.9127711666666667, 0.7414540000000002, 0.591337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 433}], {
             RGBColor[0.9127711666666667, 0.7414540000000002, 0.591337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 209}], {
             RGBColor[
             0.9492913333333333, 0.8241673333333334, 0.4344121666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 233}], {
             RGBColor[0.6756461666666667, 0.736959, 0.7854960000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 273}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{132, 423}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 151}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 155}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 181}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 225}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 235}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 239}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 249}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 260}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 262}], {
             RGBColor[0.9127711666666667, 0.7414540000000002, 0.591337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 296}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 332}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 344}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{133, 424}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 440}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 138}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 251}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 305}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 367}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 416}], {
             RGBColor[
             0.5653951666666667, 0.6345071666666666, 0.9499340000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 438}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 457}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 499}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 147}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 170}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 171}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 216}], {
             RGBColor[
             0.9479061666666666, 0.8243936666666667, 0.5154566666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 385}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 391}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 253}], {
             RGBColor[
             0.7607756666666667, 0.8130430000000001, 0.9767906666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 261}], {
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 277}], {
             RGBColor[
             0.7607756666666667, 0.8130430000000001, 0.9767906666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 291}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 311}], {
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 319}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 377}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 484}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 488}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 145}], {
             RGBColor[0.9289355, 0.7535093333333336, 0.563975]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{137, 183}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 346}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 358}], {
             RGBColor[0.9442094999999999, 0.822865, 0.57672]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{137, 404}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 407}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 408}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 430}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 352}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 367}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 457}], {
             RGBColor[
             0.7859241666666666, 0.8278753333333333, 0.6927016666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 140}], {
             RGBColor[
             0.9479061666666666, 0.8243936666666667, 0.5154566666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 247}], {
             RGBColor[0.8621055000000001, 0.758648, 0.6122445]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{139, 255}], {
             RGBColor[0.904227, 0.657999, 0.241797]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 269}], {
             RGBColor[0.9442094999999999, 0.822865, 0.57672]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{139, 274}], {
             RGBColor[0.948365, 0.8221860000000001, 0.3335865]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{139, 360}], {
             RGBColor[0.9280451666666667, 0.8108096666666667, 0.604082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 369}], {
             RGBColor[0.8621055000000001, 0.758648, 0.6122445]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{139, 370}], {
             RGBColor[0.9006771666666666, 0.789404, 0.6159235]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{139, 425}], {
             RGBColor[0.8621055000000001, 0.758648, 0.6122445]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{139, 466}], {
             RGBColor[0.8621055000000001, 0.758648, 0.6122445]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{139, 468}], {
             RGBColor[0.8621055000000001, 0.758648, 0.6122445]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{140, 169}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 204}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 219}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 244}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 247}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 255}], {
             RGBColor[
             0.9479061666666666, 0.8243936666666667, 0.5154566666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 274}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 334}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 361}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 363}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 369}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 370}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 425}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 466}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 188}], {
             RGBColor[0.6787725, 0.6125309999999999, 0.5959515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 220}], {
             RGBColor[
             0.9479061666666666, 0.8243936666666667, 0.5154566666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[0.9442094999999999, 0.822865, 0.57672]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{141, 304}], {
             RGBColor[
             0.8889530000000001, 0.5886433333333335, 0.22905200000000003`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 310}], {
             RGBColor[0.9280451666666667, 0.8108096666666667, 0.604082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 429}], {
             RGBColor[0.9442094999999999, 0.822865, 0.57672]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{142, 173}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 222}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 241}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 402}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 417}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 461}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 179}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 214}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{143, 226}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 273}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 283}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 292}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 302}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 308}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{143, 325}], {
             RGBColor[
             0.9326321666666667, 0.7550380000000002, 0.5027116666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 347}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 386}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 421}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 423}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 446}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 477}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 279}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 494}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 183}], {
             RGBColor[
             0.8854031666666666, 0.7200483333333335, 0.6031785000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 286}], {
             RGBColor[0.9127711666666667, 0.7414540000000002, 0.591337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 294}], {
             RGBColor[
             0.8468315000000002, 0.6892923333333336, 0.5994995000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 346}], {
             RGBColor[
             0.9340173333333334, 0.7548116666666669, 0.4216671666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 358}], {
             RGBColor[
             0.8889530000000001, 0.5886433333333335, 0.22905200000000003`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 404}], {
             RGBColor[0.9289355, 0.7535093333333336, 0.5639750000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 407}], {
             RGBColor[
             0.7265121666666667, 0.5943326666666668, 0.5881671666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 408}], {
             RGBColor[
             0.8468315000000002, 0.6892923333333336, 0.5994995000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 430}], {
             RGBColor[0.9289355, 0.7535093333333336, 0.5639750000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 201}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 211}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 271}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 284}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 312}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 376}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{146, 400}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 415}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 442}], {
             RGBColor[0.9651515, 0.8927656666666668, 0.5293326666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 444}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 464}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 497}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 171}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 216}], {
             RGBColor[0.9442094999999999, 0.822865, 0.57672]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{147, 238}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 385}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 391}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 153}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 190}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 195}], {
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 323}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 342}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 351}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 356}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 452}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 463}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 158}], {
             RGBColor[0.904911, 0.56025, 0.294797]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 165}], {
             RGBColor[0.8572231666666666, 0.527468, 0.577134]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{149, 182}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{149, 187}], {
             RGBColor[0.860773, 0.396063, 0.2030075]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 275}], {
             RGBColor[
             0.9058373333333334, 0.5622313333333333, 0.3956226666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 282}], {
             RGBColor[0.8572231666666666, 0.527468, 0.577134]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{149, 324}], {
             RGBColor[
             0.9058373333333334, 0.5622313333333333, 0.3956226666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 441}], {
             RGBColor[
             0.9058373333333334, 0.5622313333333333, 0.3956226666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 159}], {
             RGBColor[
             0.7868504999999999, 0.8298566666666667, 0.7935273333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 233}], {
             RGBColor[0.4681409999999999, 0.57648, 0.9519960000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 267}], {
             RGBColor[
             0.5163316666666666, 0.6182203333333334, 0.9550666666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 406}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 413}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 443}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 476}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 188}], {
             RGBColor[
             0.7025906666666666, 0.7653416666666666, 0.9582364999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 192}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 249}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 260}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 280}], {
             RGBColor[0.9452905, 0.8791816666666668, 0.617958]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{151, 310}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 327}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 424}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 483}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 191}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 212}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 287}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 299}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 301}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 389}], {
             RGBColor[0.9442094999999999, 0.822865, 0.57672]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{152, 451}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 190}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685095]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{153, 195}], {
             RGBColor[
             0.9144508333333333, 0.6661973333333335, 0.5510451666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 263}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 323}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 342}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 351}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685095]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 395}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 447}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 452}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 463}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 174}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 229}], {
             RGBColor[
             0.9492913333333333, 0.8241673333333334, 0.4344121666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 255}], {
             RGBColor[
             0.9492913333333333, 0.8241673333333334, 0.4344121666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 313}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 338}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 369}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 379}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{154, 380}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 390}], {
             RGBColor[
             0.9934293333333333, 0.9883543333333333, 0.5262016666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 425}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 478}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 181}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 235}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 262}], {
             RGBColor[0.9127711666666667, 0.7414540000000002, 0.591337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 332}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 344}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{155, 387}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 393}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 403}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 232}], {
             RGBColor[
             0.8468315000000002, 0.6892923333333336, 0.5994995000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 307}], {
             RGBColor[
             0.9340173333333334, 0.7548116666666669, 0.4216671666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 350}], {
             RGBColor[
             0.9340173333333334, 0.7548116666666669, 0.4216671666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 354}], {
             RGBColor[0.9127711666666667, 0.7414540000000002, 0.591337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 372}], {
             RGBColor[0.845499, 0.3267073333333335, 0.19026250000000006`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 479}], {
             RGBColor[
             0.9326321666666667, 0.7550380000000002, 0.5027116666666669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 180}], {
             RGBColor[
             0.7868504999999999, 0.8298566666666667, 0.7935273333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 216}], {
             RGBColor[
             0.7417861666666666, 0.6636883333333333, 0.6009121666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 238}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 246}], {
             RGBColor[
             0.7417861666666666, 0.6636883333333333, 0.6009121666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 281}], {
             RGBColor[
             0.6404563333333333, 0.7180833333333334, 0.9654583333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 288}], {
             RGBColor[
             0.7265121666666667, 0.5943326666666668, 0.5881671666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 343}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 392}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 459}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 465}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 182}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685095]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{158, 206}], {
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 282}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 324}], {
             RGBColor[
             0.9934293333333333, 0.9883543333333333, 0.5262016666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 410}], {
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 441}], {
             RGBColor[
             0.9934293333333333, 0.9883543333333333, 0.5262016666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 164}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 396}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{159, 443}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 165}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{160, 268}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 275}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 285}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{160, 324}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 353}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 441}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 480}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{160, 481}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 259}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{161, 326}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 341}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{161, 387}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{161, 403}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 405}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{161, 450}], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 469}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 491}], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 203}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 221}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 223}], {
             RGBColor[0.9006771666666666, 0.789404, 0.6159235000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 258}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 289}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 297}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 381}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 439}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 187}], {
             RGBColor[
             0.5848500000000001, 0.5271791666666666, 0.5901133333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.6248324999999999, 0.6920451666666667, 0.9250363333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 322}], {
             RGBColor[
             0.6020953333333334, 0.5955511666666667, 0.6039893333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 364}], {
             RGBColor[
             0.6086681666666667, 0.6799898333333334, 0.9523983333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 437}], {
             RGBColor[
             0.6248324999999999, 0.6920451666666667, 0.9250363333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 494}], {
             RGBColor[
             0.6086681666666667, 0.6799898333333334, 0.9523983333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 166}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 227}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 309}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 348}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 396}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 428}], {
             RGBColor[0.718755, 0.777397, 0.9308745]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 443}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 182}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 268}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 275}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 282}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{165, 285}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{165, 324}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 353}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 441}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 481}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 210}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 227}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 243}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 309}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 320}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685095]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{166, 348}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 428}], {
             RGBColor[0.718755, 0.777397, 0.9308745]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 495}], {
             RGBColor[
             0.6705643333333333, 0.7356566666666666, 0.9278038333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 210}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 326}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 434}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685095]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{167, 474}], {
             RGBColor[
             0.6705643333333333, 0.7356566666666666, 0.9278038333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 495}], {
             RGBColor[
             0.6705643333333333, 0.7356566666666666, 0.9278038333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 200}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 213}], {
             RGBColor[
             0.6404563333333333, 0.7180833333333334, 0.9654583333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 254}], {
             RGBColor[
             0.7737441666666667, 0.7867893333333333, 0.6453846666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 261}], {
             RGBColor[
             0.7859241666666666, 0.8278753333333333, 0.6927016666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 315}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 368}], {
             RGBColor[0.4681409999999999, 0.57648, 0.9519960000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 401}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 500}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 204}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 219}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 244}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 274}], {
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 334}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 337}], {
             RGBColor[
             0.6404563333333333, 0.7180833333333334, 0.9654583333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 340}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 361}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 363}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 370}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 498}], {
             RGBColor[
             0.6404563333333333, 0.7180833333333334, 0.9654583333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 171}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 238}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 265}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{170, 266}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 328}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 374}], {
             RGBColor[0.8845911666666666, 0.5488736666666667, 0.5652925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 433}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 216}], {
             RGBColor[0.8028971666666667, 0.712394, 0.6063431666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 238}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 265}], {
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 343}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 385}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 391}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 433}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 465}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 303}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 366}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 448}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 473}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 241}], {
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 417}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 461}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 493}], {
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 215}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 229}], {
             RGBColor[0.8621055000000001, 0.758648, 0.6122445000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 294}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 338}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 356}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 390}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 430}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 309}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 320}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 337}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 348}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 361}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 370}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{175, 375}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 197}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 237}], {
             RGBColor[
             0.6705643333333333, 0.7356566666666666, 0.9278038333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 345}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685095]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{176, 426}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 448}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 245}], {
             RGBColor[0.6366510000000001, 0.71318, 0.966399]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{177, 438}], {
             RGBColor[0.6752226666666666, 0.7439359999999999, 0.970078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 455}], {
             RGBColor[0.6752226666666666, 0.7439359999999999, 0.970078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 357}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{178, 420}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 439}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 236}], {
             RGBColor[0.9181475, 0.6677260000000003, 0.48978183333333347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 254}], {
             RGBColor[
             0.9798641666666666, 0.9474946666666667, 0.5599291666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 276}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 283}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 292}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 315}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 325}], {
             RGBColor[
             0.9326321666666667, 0.7550380000000002, 0.5027116666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 347}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 368}], {
             RGBColor[0.674261, 0.7371853333333334, 0.8665405000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 386}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 401}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 216}], {
             RGBColor[
             0.9492913333333333, 0.8241673333333334, 0.4344121666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 281}], {
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 288}], {
             RGBColor[
             0.9340173333333334, 0.7548116666666669, 0.4216671666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 343}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{180, 392}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 465}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{181, 235}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 239}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 262}], {
             RGBColor[0.9127711666666667, 0.7414540000000002, 0.591337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 296}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 332}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 344}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{181, 387}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 393}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 424}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 275}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 282}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 324}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 441}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 346}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 404}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 407}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 408}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{184, 192}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 225}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 249}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 260}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 280}], {
             RGBColor[0.9452905, 0.8791816666666668, 0.617958]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{184, 424}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 440}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 453}], {
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 470}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 193}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 196}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 318}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 321}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{185, 330}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{185, 335}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{185, 350}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 383}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 409}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{185, 482}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{185, 496}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 191}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 202}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 212}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 295}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 300}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 389}], {
             RGBColor[0.9442094999999999, 0.822865, 0.57672]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{186, 414}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 456}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 485}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 322}], {
             RGBColor[
             0.9214723333333334, 0.7263710000000001, 0.25567300000000004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 494}], {
             RGBColor[0.9280451666666667, 0.8108096666666667, 0.604082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 304}], {
             RGBColor[0.6634985, 0.5431753333333336, 0.5832065000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 310}], {
             RGBColor[
             0.7025906666666666, 0.7653416666666666, 0.9582364999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 483}], {
             RGBColor[0.7229105, 0.776718, 0.6877409999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{189, 266}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 364}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 374}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{189, 437}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 195}], {
             RGBColor[
             0.9186063333333334, 0.6655183333333335, 0.3079116666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 224}], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 263}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 323}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 342}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 351}], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 356}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 395}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 452}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 463}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 212}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 218}], {
             RGBColor[
             0.7607756666666667, 0.8130430000000001, 0.9767906666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 287}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 295}], {
             RGBColor[
             0.7607756666666667, 0.8130430000000001, 0.9767906666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 299}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 300}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 301}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 389}], {
             RGBColor[0.8621055000000001, 0.758648, 0.6122445000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 451}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 456}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 249}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 260}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{192, 280}], {
             RGBColor[0.9179225, 0.8577760000000001, 0.6297995000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 327}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{192, 470}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 483}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 196}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{193, 202}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 232}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 330}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 350}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{193, 354}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 376}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{193, 414}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 415}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 485}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 496}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 228}], {
             RGBColor[0.9326351666666666, 0.912505, 0.660396]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{194, 388}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 490}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 224}], {
             RGBColor[
             0.9186063333333334, 0.6655183333333337, 0.3079116666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 263}], {
             RGBColor[0.9181475, 0.6677260000000003, 0.48978183333333347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 296}], {
             RGBColor[0.7120275, 0.5070206666666669, 0.5752373333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 323}], {
             RGBColor[
             0.8709184999999999, 0.6327363333333336, 0.5902486666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 342}], {
             RGBColor[
             0.8709184999999999, 0.6327363333333336, 0.5902486666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 351}], {
             RGBColor[
             0.9186063333333334, 0.6655183333333337, 0.3079116666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 395}], {
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 447}], {
             RGBColor[
             0.9195326666666667, 0.6674996666666668, 0.4087373333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 453}], {
             RGBColor[
             0.8447096666666667, 0.3446636666666671, 0.19044733333333339`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 463}], {
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 318}], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 321}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 330}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 335}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 350}], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 354}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{196, 383}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{196, 414}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 479}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{196, 482}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 496}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{197, 237}], {
             RGBColor[
             0.5884603333333334, 0.6714396666666667, 0.9633283333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 270}], {
             RGBColor[
             0.8323468333333335, 0.6019803333333336, 0.5865696666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 345}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 375}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 426}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 448}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 489}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 223}], {
             RGBColor[0.9006771666666666, 0.789404, 0.6159235000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 373}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{198, 480}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{199, 208}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 220}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 349}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 359}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 371}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 382}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 397}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 419}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 427}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 429}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 213}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 243}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 254}], {
             RGBColor[0.9761675, 0.9459660000000001, 0.6211925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 259}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 401}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 450}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 454}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 469}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 471}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 475}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 500}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 222}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 246}], {
             RGBColor[0.8621055000000001, 0.758648, 0.6122445000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 256}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 271}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 312}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 333}], {
             RGBColor[
             0.8323468333333335, 0.6019803333333336, 0.5865696666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 400}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 442}], {
             RGBColor[
             0.8793508333333335, 0.8270200000000001, 0.6261205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 444}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 492}], {
             RGBColor[
             0.7607756666666667, 0.8130430000000001, 0.9767906666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 211}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 414}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{202, 485}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 497}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{203, 221}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 258}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 289}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 291}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 297}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 381}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 397}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 419}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 439}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 219}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 244}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 274}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 334}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 337}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 340}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 361}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 362}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{204, 363}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 370}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 498}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 228}], {
             RGBColor[
             0.8348551666666667, 0.8354950000000001, 0.6508156666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 252}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 388}], {
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 432}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 490}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 266}], {
             RGBColor[
             0.6404563333333333, 0.7180833333333334, 0.9654583333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 410}], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 218}], {
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 287}], {
             RGBColor[
             0.7868504999999999, 0.8298566666666667, 0.7935273333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 295}], {
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 336}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 389}], {
             RGBColor[
             0.9492913333333333, 0.8241673333333334, 0.4344121666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 409}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 456}], {
             RGBColor[
             0.7868504999999999, 0.8298566666666667, 0.7935273333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 458}], {
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 289}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 314}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 349}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 359}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 397}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 427}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 472}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 214}], {
             RGBColor[
             0.9492913333333333, 0.8241673333333334, 0.4344121666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 233}], {
             RGBColor[
             0.6305818333333333, 0.5707906666666667, 0.5928808333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 273}], {
             RGBColor[
             0.9479061666666666, 0.8243936666666667, 0.5154566666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 421}], {
             RGBColor[0.9006771666666666, 0.789404, 0.6159235]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{209, 423}], {
             RGBColor[0.9442094999999999, 0.822865, 0.57672]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{209, 477}], {
             RGBColor[0.9006771666666666, 0.789404, 0.6159235]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{210, 227}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 243}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 326}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 348}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 428}], {
             RGBColor[
             0.7025906666666666, 0.7653416666666666, 0.9582364999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 434}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 469}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 474}], {
             RGBColor[0.6544, 0.7236013333333333, 0.9551658333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 495}], {
             RGBColor[0.6544, 0.7236013333333333, 0.9551658333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 464}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 485}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 497}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 287}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 295}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 299}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 300}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 301}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 389}], {
             RGBColor[0.9280451666666667, 0.8108096666666667, 0.604082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 451}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 456}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 254}], {
             RGBColor[
             0.8348551666666667, 0.8354950000000001, 0.6508156666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 259}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 261}], {
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 315}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 368}], {
             RGBColor[0.5292520000000001, 0.6251856666666666, 0.957427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 401}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 450}], {
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 454}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 471}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 475}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 500}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 273}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{214, 302}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{214, 347}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 421}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 423}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 477}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 224}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 351}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 356}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 430}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 238}], {
             RGBColor[
             0.9479061666666666, 0.8243936666666667, 0.5154566666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 281}], {
             RGBColor[0.8028971666666667, 0.712394, 0.6063431666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 343}], {
             RGBColor[0.9280451666666667, 0.8108096666666667, 0.604082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 465}], {
             RGBColor[
             0.9479061666666666, 0.8243936666666667, 0.5154566666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 290}], {
             RGBColor[
             0.6404563333333333, 0.7180833333333334, 0.9654583333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 340}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 355}], {
             RGBColor[0.5774426666666668, 0.666926, 0.9604976666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 362}], {
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 378}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 384}], {
             RGBColor[
             0.7731385000000001, 0.5557263333333335, 0.5806683333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 498}], {
             RGBColor[
             0.6404563333333333, 0.7180833333333334, 0.9654583333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 295}], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.7607756666666667, 0.8130430000000001, 0.9767906666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 336}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 389}], {
             RGBColor[0.8028971666666667, 0.712394, 0.6063431666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 409}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 456}], {
             RGBColor[
             0.6404563333333333, 0.7180833333333334, 0.9654583333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 458}], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 244}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 274}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 334}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 337}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 340}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 361}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 363}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 369}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 370}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 498}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 349}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 359}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 371}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 382}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 416}], {
             RGBColor[
             0.5852561666666667, 0.6480911666666667, 0.8613086666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 427}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 429}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 499}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 223}], {
             RGBColor[0.9442094999999999, 0.822865, 0.57672]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{221, 258}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 297}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 381}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 439}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 307}], {
             RGBColor[
             0.9934293333333333, 0.9883543333333333, 0.5262016666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 333}], {
             RGBColor[
             0.9186063333333334, 0.6655183333333335, 0.3079116666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 372}], {
             RGBColor[0.904911, 0.56025, 0.294797]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 417}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 258}], {
             RGBColor[0.8028971666666667, 0.712394, 0.6063431666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 268}], {
             RGBColor[0.8028971666666667, 0.712394, 0.6063431666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 373}], {
             RGBColor[0.9006771666666666, 0.789404, 0.6159235]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{223, 381}], {
             RGBColor[0.9280451666666667, 0.8108096666666667, 0.604082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 480}], {
             RGBColor[0.9006771666666666, 0.789404, 0.6159235]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{224, 263}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 342}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 351}], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 356}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 463}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 235}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 249}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 260}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 280}], {
             RGBColor[0.9656103333333335, 0.8905580000000002, 0.3474625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 296}], {
             RGBColor[
             0.7859241666666666, 0.8278753333333333, 0.6927016666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 424}], {
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 440}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 453}], {
             RGBColor[
             0.9186063333333334, 0.6655183333333335, 0.3079116666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 470}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685095]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{226, 236}], {
             RGBColor[
             0.8709184999999999, 0.6327363333333336, 0.5902486666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 283}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 292}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 308}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 386}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 396}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 422}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 446}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 309}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 320}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 348}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 428}], {
             RGBColor[
             0.7025906666666666, 0.7653416666666666, 0.9582364999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 495}], {
             RGBColor[0.6544, 0.7236013333333333, 0.9551658333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 388}], {
             RGBColor[0.980323, 0.945287, 0.378059]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 490}], {
             RGBColor[0.9761675, 0.9459660000000001, 0.6211925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 244}], {
             RGBColor[0.9006771666666666, 0.789404, 0.6159235]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{229, 248}], {
             RGBColor[0.8621055000000001, 0.758648, 0.6122445]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{229, 255}], {
             RGBColor[0.904227, 0.657999, 0.241797]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 313}], {
             RGBColor[0.8621055000000001, 0.758648, 0.6122445]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{229, 338}], {
             RGBColor[0.9442094999999999, 0.822865, 0.57672]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{229, 379}], {
             RGBColor[
             0.9479061666666666, 0.8243936666666667, 0.5154566666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 380}], {
             RGBColor[0.8621055000000001, 0.758648, 0.6122445]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{229, 390}], {
             RGBColor[0.948365, 0.8221860000000001, 0.3335865]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{229, 411}], {
             RGBColor[0.9006771666666666, 0.789404, 0.6159235]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{229, 478}], {
             RGBColor[0.8621055000000001, 0.758648, 0.6122445]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{230, 242}], {
             RGBColor[0.718755, 0.777397, 0.9308745]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 339}], {
             RGBColor[
             0.5163316666666666, 0.6182203333333334, 0.9550666666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 365}], {
             RGBColor[
             0.4051273333333333, 0.5253226666666666, 0.9470353333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 374}], {
             RGBColor[0.6353185, 0.350595, 0.5571619999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{230, 391}], {
             RGBColor[
             0.7025906666666666, 0.7653416666666666, 0.9582364999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 246}], {
             RGBColor[0.9442094999999999, 0.822865, 0.57672]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{231, 256}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 271}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 288}], {
             RGBColor[0.9289355, 0.7535093333333336, 0.563975]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{231, 442}], {
             RGBColor[0.9614548333333334, 0.8912370000000001, 0.590596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 444}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 492}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 307}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 312}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 330}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{232, 350}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 354}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 372}], {
             RGBColor[0.8186515000000001, 0.49671200000000004`, 0.573455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 376}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 400}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 414}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{232, 415}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 476}], {
             RGBColor[
             0.6543999999999999, 0.7236013333333333, 0.9551658333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 235}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 262}], {
             RGBColor[
             0.8468315000000002, 0.6892923333333336, 0.5994995000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 296}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 332}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 393}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{234, 468}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 239}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 249}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 260}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 262}], {
             RGBColor[
             0.8468315000000002, 0.6892923333333336, 0.5994995000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 296}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 332}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 344}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 393}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{235, 424}], {
             RGBColor[
             0.7607756666666667, 0.8130430000000001, 0.9767906666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 440}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 453}], {
             RGBColor[
             0.8323468333333335, 0.6019803333333336, 0.5865696666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 243}], {
             RGBColor[
             0.8323468333333335, 0.6019803333333336, 0.5865696666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 276}], {
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 283}], {
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 292}], {
             RGBColor[
             0.9186063333333334, 0.6655183333333337, 0.3079116666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 396}], {
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 422}], {
             RGBColor[0.9181475, 0.6677260000000003, 0.48978183333333347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 267}], {
             RGBColor[
             0.4051273333333333, 0.5253226666666666, 0.9470353333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 270}], {
             RGBColor[
             0.6008231666666667, 0.4141230000000002, 0.5672060000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 329}], {
             RGBColor[
             0.6756461666666667, 0.7369589999999999, 0.7854960000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 426}], {
             RGBColor[0.674261, 0.7371853333333334, 0.8665405000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 448}], {
             RGBColor[0.674261, 0.7371853333333334, 0.8665405000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 489}], {
             RGBColor[
             0.6705643333333333, 0.7356566666666666, 0.9278038333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 265}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{238, 328}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 343}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 431}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 433}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 436}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 462}], {
             RGBColor[
             0.9798641666666666, 0.9474946666666667, 0.5599291666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 465}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 262}], {
             RGBColor[0.9330910000000001, 0.7528303333333335, 0.3208415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 263}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 296}], {
             RGBColor[
             0.7859241666666666, 0.8278753333333333, 0.6927016666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 332}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 393}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 424}], {
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 440}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 453}], {
             RGBColor[
             0.9186063333333334, 0.6655183333333335, 0.3079116666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 251}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 310}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 352}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 367}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 382}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 399}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 412}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 416}], {
             RGBColor[0.5815595, 0.6465625, 0.922572]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{240, 429}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 402}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 417}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 436}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 461}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 339}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 365}], {
             RGBColor[
             0.6705643333333333, 0.7356566666666666, 0.9278038333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 374}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{243, 276}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 326}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 428}], {
             RGBColor[0.6366510000000001, 0.71318, 0.966399]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{243, 454}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 469}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{243, 471}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 475}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{243, 495}], {
             RGBColor[
             0.5884603333333334, 0.6714396666666667, 0.9633283333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 274}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 313}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{244, 334}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 340}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 355}], {
             RGBColor[0.6752226666666666, 0.7439359999999999, 0.970078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 363}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 378}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{244, 379}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 380}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{244, 390}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 498}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 394}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 438}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{245, 445}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{245, 460}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 256}], {
             RGBColor[
             0.9479061666666666, 0.8243936666666667, 0.5154566666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 288}], {
             RGBColor[
             0.8889530000000001, 0.5886433333333335, 0.22905200000000003`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 333}], {
             RGBColor[
             0.8744683333333334, 0.5013313333333336, 0.2161221666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 392}], {
             RGBColor[0.9006771666666666, 0.789404, 0.6159235]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{246, 442}], {
             RGBColor[
             0.9214723333333334, 0.7263710000000001, 0.25567300000000004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 444}], {
             RGBColor[
             0.9479061666666666, 0.8243936666666667, 0.5154566666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 459}], {
             RGBColor[0.9280451666666667, 0.8108096666666667, 0.604082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 492}], {
             RGBColor[0.8028971666666667, 0.712394, 0.6063431666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 255}], {
             RGBColor[0.8621055000000001, 0.758648, 0.6122445000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 269}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 360}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 369}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 370}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{247, 425}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 466}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 468}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 286}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 294}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 313}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 380}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 411}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{248, 478}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 260}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 280}], {
             RGBColor[0.9452905, 0.8791816666666668, 0.617958]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{249, 296}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 424}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 440}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 470}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 339}], {
             RGBColor[
             0.6404563333333333, 0.7180833333333334, 0.9654583333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 365}], {
             RGBColor[0.5292520000000001, 0.6251856666666666, 0.957427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 305}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 367}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{251, 382}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 416}], {
             RGBColor[0.5380271666666666, 0.6131015, 0.9617755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 427}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 429}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 499}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{252, 282}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{252, 432}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 467}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 261}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 277}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 291}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 311}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 319}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 377}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 484}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 488}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 315}], {
             RGBColor[0.9761675, 0.9459660000000001, 0.6211925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 325}], {
             RGBColor[0.920911, 0.7117443333333335, 0.27352450000000006`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 347}], {
             RGBColor[0.8940635000000001, 0.8817490000000001, 0.656717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 368}], {
             RGBColor[
             0.6625398333333333, 0.6938916666666667, 0.6373533333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 386}], {
             RGBColor[
             0.7737441666666667, 0.7867893333333333, 0.6453846666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 401}], {
             RGBColor[0.9761675, 0.9459660000000001, 0.6211925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 454}], {
             RGBColor[
             0.9600031666666666, 0.9339106666666667, 0.6485544999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 471}], {
             RGBColor[0.9761675, 0.9459660000000001, 0.6211925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 269}], {
             RGBColor[0.9442094999999999, 0.822865, 0.57672]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{255, 274}], {
             RGBColor[0.948365, 0.8221860000000001, 0.3335865]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{255, 334}], {
             RGBColor[
             0.9479061666666666, 0.8243936666666667, 0.5154566666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 338}], {
             RGBColor[0.9442094999999999, 0.822865, 0.57672]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{255, 369}], {
             RGBColor[0.8621055000000001, 0.758648, 0.6122445]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{255, 370}], {
             RGBColor[0.9006771666666666, 0.789404, 0.6159235]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{255, 379}], {
             RGBColor[
             0.9479061666666666, 0.8243936666666667, 0.5154566666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 390}], {
             RGBColor[0.948365, 0.8221860000000001, 0.3335865]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{255, 425}], {
             RGBColor[0.8621055000000001, 0.758648, 0.6122445]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{255, 466}], {
             RGBColor[0.8621055000000001, 0.758648, 0.6122445]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{256, 271}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 333}], {
             RGBColor[0.9181475, 0.6677260000000003, 0.48978183333333347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 442}], {
             RGBColor[0.9651515, 0.8927656666666668, 0.5293326666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 444}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 492}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 272}], {
             RGBColor[0.9452905, 0.8791816666666668, 0.617958]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{257, 306}], {
             RGBColor[
             0.8793508333333335, 0.8270200000000001, 0.6261205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 317}], {
             RGBColor[
             0.8793508333333335, 0.8270200000000001, 0.6261205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 357}], {
             RGBColor[
             0.9665366666666667, 0.8925393333333335, 0.4482881666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 418}], {
             RGBColor[0.9179225, 0.8577760000000001, 0.6297995000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 420}], {
             RGBColor[0.9179225, 0.8577760000000001, 0.6297995000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 289}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 297}], {
             RGBColor[
             0.6404563333333333, 0.7180833333333334, 0.9654583333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 314}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 373}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 381}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 397}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 472}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 341}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 405}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 450}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{259, 454}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 469}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 471}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 475}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 491}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{259, 500}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 280}], {
             RGBColor[
             0.8793508333333335, 0.8270200000000001, 0.6261205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 424}], {
             RGBColor[
             0.7607756666666667, 0.8130430000000001, 0.9767906666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 440}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 470}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 483}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 484}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 500}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 332}], {
             RGBColor[
             0.9326321666666667, 0.7550380000000002, 0.5027116666666669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 344}], {
             RGBColor[
             0.9340173333333334, 0.7548116666666669, 0.4216671666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 387}], {
             RGBColor[
             0.9326321666666667, 0.7550380000000002, 0.5027116666666669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 393}], {
             RGBColor[
             0.8854031666666666, 0.7200483333333335, 0.6031785000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 424}], {
             RGBColor[
             0.7876231666666668, 0.6430383333333336, 0.5935981666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 296}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 323}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 342}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 395}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 440}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 447}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{263, 453}], {
             RGBColor[0.9181475, 0.6677260000000003, 0.48978183333333347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 463}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 394}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 398}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 445}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 328}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 433}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{265, 462}], {
             RGBColor[
             0.9812493333333333, 0.9472683333333334, 0.4788846666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 364}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 374}], {
             RGBColor[
             0.6983321666666666, 0.4017523333333333, 0.5621226666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 410}], {
             RGBColor[
             0.6404563333333333, 0.7180833333333334, 0.9654583333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 437}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 278}], {
             RGBColor[0.5774426666666668, 0.666926, 0.9604976666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 329}], {
             RGBColor[
             0.7238368333333334, 0.7786993333333334, 0.7885666666666669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 406}], {
             RGBColor[
             0.7224516666666667, 0.7789256666666666, 0.8696111666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 413}], {
             RGBColor[
             0.7224516666666667, 0.7789256666666666, 0.8696111666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 476}], {
             RGBColor[
             0.7025906666666666, 0.7653416666666666, 0.9582364999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 486}], {
             RGBColor[
             0.7224516666666667, 0.7789256666666666, 0.8696111666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 493}], {
             RGBColor[0.7229105, 0.776718, 0.6877409999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{268, 275}], {
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 285}], {
             RGBColor[
             0.7607756666666667, 0.8130430000000001, 0.9767906666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 324}], {
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 353}], {
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 441}], {
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 480}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 481}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 360}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 369}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 425}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 466}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 468}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 309}], {
             RGBColor[0.9181475, 0.6677260000000003, 0.48978183333333347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 345}], {
             RGBColor[
             0.9186063333333334, 0.6655183333333337, 0.3079116666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 375}], {
             RGBColor[0.7120275, 0.5070206666666669, 0.5752373333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 426}], {
             RGBColor[0.9181475, 0.6677260000000003, 0.48978183333333347`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 489}], {
             RGBColor[
             0.9144508333333333, 0.6661973333333335, 0.5510451666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 284}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 442}], {
             RGBColor[
             0.8793508333333335, 0.8270200000000001, 0.6261205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 444}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 464}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 492}], {
             RGBColor[
             0.7607756666666667, 0.8130430000000001, 0.9767906666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 306}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 317}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 357}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{273, 308}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{273, 421}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 423}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 446}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 477}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 334}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 340}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 361}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 363}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685095]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{274, 369}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 370}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 379}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 498}], {
             RGBColor[
             0.7859241666666666, 0.8278753333333333, 0.6927016666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 282}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 285}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 324}], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 353}], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 441}], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 481}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 283}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 292}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 396}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 422}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 291}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 311}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 319}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 331}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{277, 377}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 419}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{277, 449}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 484}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 488}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 329}], {
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 406}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 413}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 486}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 493}], {
             RGBColor[0.8470351666666667, 0.876581, 0.6981326666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 324}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{279, 481}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 494}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 327}], {
             RGBColor[0.9179225, 0.8577760000000001, 0.6297995000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 470}], {
             RGBColor[0.9614548333333334, 0.8912370000000001, 0.590596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 483}], {
             RGBColor[0.9656103333333335, 0.8905580000000002, 0.3474625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 288}], {
             RGBColor[
             0.7876231666666668, 0.6430383333333336, 0.5935981666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 343}], {
             RGBColor[
             0.8267153333333334, 0.8652046666666666, 0.9686281666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 465}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 324}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 353}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 432}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 441}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 467}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 292}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 386}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 422}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 442}], {
             RGBColor[
             0.8793508333333335, 0.8270200000000001, 0.6261205000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 444}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 464}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 324}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 480}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{285, 481}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 294}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 346}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{286, 358}], {
             RGBColor[0.9280451666666667, 0.8108096666666667, 0.604082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 407}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 411}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 295}], {
             RGBColor[
             0.6404563333333333, 0.7180833333333334, 0.9654583333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 299}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 300}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 301}], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 389}], {
             RGBColor[
             0.7417861666666666, 0.6636883333333333, 0.6009121666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 451}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 456}], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 343}], {
             RGBColor[0.9127711666666667, 0.7414540000000002, 0.591337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 392}], {
             RGBColor[
             0.8854031666666666, 0.7200483333333335, 0.6031785000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 465}], {
             RGBColor[
             0.9326321666666667, 0.7550380000000002, 0.5027116666666669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 492}], {
             RGBColor[
             0.7876231666666668, 0.6430383333333336, 0.5935981666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 291}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 297}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 314}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 349}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 359}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 381}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 397}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 419}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 472}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 316}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 340}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 355}], {
             RGBColor[
             0.5163316666666666, 0.6182203333333334, 0.9550666666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 362}], {
             RGBColor[
             0.7868504999999999, 0.8298566666666667, 0.7935273333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 378}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 384}], {
             RGBColor[0.7120275, 0.5070206666666669, 0.5752373333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 297}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 311}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 319}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 349}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 359}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 419}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 488}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 308}], {
             RGBColor[
             0.9934293333333333, 0.9883543333333333, 0.5262016666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 386}], {
             RGBColor[
             0.7859241666666666, 0.8278753333333333, 0.6927016666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 422}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 298}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 317}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 353}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{293, 418}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 420}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 432}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 358}], {
             RGBColor[0.8621055000000001, 0.758648, 0.6122445000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 411}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{294, 430}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 478}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 300}], {
             RGBColor[
             0.7607756666666667, 0.8130430000000001, 0.9767906666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 336}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 389}], {
             RGBColor[0.8028971666666667, 0.712394, 0.6063431666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 409}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 456}], {
             RGBColor[
             0.6404563333333333, 0.7180833333333334, 0.9654583333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 458}], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 332}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 395}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 424}], {
             RGBColor[
             0.6404563333333333, 0.7180833333333334, 0.9654583333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 440}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 453}], {
             RGBColor[0.7120275, 0.5070206666666669, 0.5752373333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 311}], {
             RGBColor[
             0.7868504999999999, 0.8298566666666667, 0.7935273333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 314}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 349}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 359}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 381}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 397}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 419}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 353}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 418}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{298, 420}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{298, 432}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 300}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 301}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 389}], {
             RGBColor[0.9280451666666667, 0.8108096666666667, 0.604082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 451}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 456}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 301}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 389}], {
             RGBColor[0.8621055000000001, 0.758648, 0.6122445000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 409}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{300, 451}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 456}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 458}], {
             RGBColor[
             0.7607756666666667, 0.8130430000000001, 0.9767906666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 389}], {
             RGBColor[
             0.7417861666666666, 0.6636883333333333, 0.6009121666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 451}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 456}], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 315}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 325}], {
             RGBColor[0.9127711666666667, 0.7414540000000002, 0.591337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 347}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 368}], {
             RGBColor[0.6544, 0.7236013333333333, 0.9551658333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 386}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 421}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 477}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 366}], {
             RGBColor[
             0.7868504999999999, 0.8298566666666667, 0.7935273333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 435}], {
             RGBColor[
             0.7868504999999999, 0.8298566666666667, 0.7935273333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 473}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 310}], {
             RGBColor[0.9127711666666667, 0.7414540000000002, 0.591337]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 429}], {
             RGBColor[0.9289355, 0.7535093333333336, 0.5639750000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 483}], {
             RGBColor[0.9330910000000001, 0.7528303333333335, 0.3208415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 382}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 416}], {
             RGBColor[0.5815595, 0.6465625, 0.922572]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{305, 427}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 438}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 460}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 499}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 317}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 357}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 418}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{306, 420}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{307, 372}], {
             RGBColor[
             0.9058373333333334, 0.5622313333333333, 0.3956226666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 417}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{308, 386}], {
             RGBColor[
             0.7868504999999999, 0.8298566666666667, 0.7935273333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 421}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 422}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{308, 423}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 446}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{309, 320}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 337}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 348}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 375}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 489}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 327}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 399}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 412}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 429}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 483}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 319}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{311, 331}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 349}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 377}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 419}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 484}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{311, 488}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 354}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 376}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{312, 400}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 414}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 415}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 379}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 380}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 390}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 411}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{313, 478}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 359}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 373}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 397}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 398}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 472}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 325}], {
             RGBColor[0.9289355, 0.7535093333333336, 0.563975]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{315, 347}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 368}], {
             RGBColor[
             0.6705643333333333, 0.7356566666666666, 0.9278038333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 386}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 401}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 378}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 357}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 418}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{317, 420}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{318, 321}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 330}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 335}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 350}], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 354}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{318, 383}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{318, 479}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{318, 482}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 496}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{319, 331}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 377}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 449}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 488}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 337}], {
             RGBColor[
             0.7859241666666666, 0.8278753333333333, 0.6927016666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 348}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 361}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 375}], {
             RGBColor[
             0.7859241666666666, 0.8278753333333333, 0.6927016666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 335}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{321, 383}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 479}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 482}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{321, 496}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 494}], {
             RGBColor[0.9452905, 0.8791816666666668, 0.617958]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{323, 342}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{323, 395}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 447}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 452}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{323, 463}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 441}], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 481}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 347}], {
             RGBColor[
             0.8468315000000002, 0.6892923333333336, 0.5994995000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 368}], {
             RGBColor[
             0.6153078333333334, 0.5014350000000002, 0.5801358333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 386}], {
             RGBColor[
             0.7265121666666667, 0.5943326666666668, 0.5881671666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 401}], {
             RGBColor[0.9289355, 0.7535093333333336, 0.5639750000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 421}], {
             RGBColor[
             0.8854031666666666, 0.7200483333333335, 0.6031785000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 405}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 428}], {
             RGBColor[0.718755, 0.777397, 0.9308745]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 434}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685095]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{326, 469}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 474}], {
             RGBColor[
             0.6705643333333333, 0.7356566666666666, 0.9278038333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 475}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 491}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 495}], {
             RGBColor[
             0.6705643333333333, 0.7356566666666666, 0.9278038333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 399}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 412}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 483}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 431}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 433}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 436}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{328, 462}], {
             RGBColor[0.9326351666666666, 0.912505, 0.660396]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{328, 487}], {
             RGBColor[0.9006771666666666, 0.789404, 0.6159235000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 406}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{329, 413}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{329, 486}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{330, 350}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 354}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 414}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{330, 415}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 482}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{330, 496}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 377}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 403}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{331, 449}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 488}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 344}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{332, 393}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 424}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 392}], {
             RGBColor[
             0.8709184999999999, 0.6327363333333336, 0.5902486666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 442}], {
             RGBColor[
             0.8917136666666667, 0.5697033333333337, 0.22999816666666673`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 459}], {
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 492}], {
             RGBColor[
             0.7731385000000001, 0.5557263333333335, 0.5806683333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 340}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 355}], {
             RGBColor[
             0.7224516666666667, 0.7789256666666666, 0.8696111666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 361}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 363}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 369}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 370}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 379}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 498}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 383}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 409}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{335, 482}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{335, 496}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 409}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{336, 456}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 458}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 348}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 361}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 370}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 375}], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 498}], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 369}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 379}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 390}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685095]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{338, 425}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 478}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 365}], {
             RGBColor[0.4681409999999999, 0.57648, 0.9519960000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 355}], {
             RGBColor[
             0.7025906666666666, 0.7653416666666666, 0.9582364999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 362}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{340, 363}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 378}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 379}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 380}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 498}], {
             RGBColor[0.7656043333333333, 0.816499, 0.9631971666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 387}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 403}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 405}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 450}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{341, 469}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 491}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{342, 395}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 447}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 453}], {
             RGBColor[
             0.8709184999999999, 0.6327363333333336, 0.5902486666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 463}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 392}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 433}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 465}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 387}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{344, 424}], {
             RGBColor[0.8479615, 0.8785623333333334, 0.7989583333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 375}], {
             RGBColor[
             0.7859241666666666, 0.8278753333333333, 0.6927016666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 426}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 448}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 489}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685095]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{345, 498}], {
             RGBColor[
             0.7859241666666666, 0.8278753333333333, 0.6927016666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 358}], {
             RGBColor[
             0.9492913333333333, 0.8241673333333334, 0.4344121666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 404}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 407}], {
             RGBColor[
             0.7868504999999999, 0.8298566666666667, 0.7935273333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 408}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 430}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 368}], {
             RGBColor[
             0.5884603333333334, 0.6714396666666667, 0.9633283333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 386}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 421}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{347, 477}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{348, 375}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 428}], {
             RGBColor[
             0.7224516666666667, 0.7789256666666666, 0.8696111666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 359}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{349, 371}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{349, 397}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 419}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{350, 354}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{350, 383}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{350, 414}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 479}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{350, 482}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 356}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 463}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 367}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 399}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 412}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 457}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 418}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 420}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 432}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 441}], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 372}], {
             RGBColor[0.8845911666666666, 0.5488736666666667, 0.5652925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 414}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 415}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 479}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 482}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 362}], {
             RGBColor[
             0.7238368333333334, 0.7786993333333334, 0.7885666666666669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 363}], {
             RGBColor[0.718755, 0.777397, 0.9308745]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 378}], {
             RGBColor[0.6752226666666666, 0.7439359999999999, 0.970078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 384}], {
             RGBColor[
             0.6490138333333333, 0.4558633333333335, 0.5702766666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 498}], {
             RGBColor[
             0.5163316666666666, 0.6182203333333334, 0.9550666666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 463}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 418}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 420}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 404}], {
             RGBColor[0.9442094999999999, 0.822865, 0.57672]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{358, 407}], {
             RGBColor[
             0.7417861666666666, 0.6636883333333333, 0.6009121666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 408}], {
             RGBColor[0.8621055000000001, 0.758648, 0.6122445]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{358, 430}], {
             RGBColor[0.9442094999999999, 0.822865, 0.57672]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{359, 371}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 397}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 419}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{359, 427}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 393}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 466}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 468}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 363}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 370}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 498}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 363}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 384}], {
             RGBColor[
             0.9195326666666667, 0.6674996666666669, 0.4087373333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 498}], {
             RGBColor[
             0.7868504999999999, 0.8298566666666667, 0.7935273333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 370}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 379}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 498}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 374}], {
             RGBColor[0.8845911666666666, 0.5488736666666667, 0.5652925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 437}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 435}], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 473}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 416}], {
             RGBColor[0.49945550000000005`, 0.5823455000000001, 0.9580965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 457}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 499}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{368, 386}], {
             RGBColor[0.4681409999999999, 0.57648, 0.9519960000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 401}], {
             RGBColor[
             0.6705643333333333, 0.7356566666666666, 0.9278038333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 500}], {
             RGBColor[
             0.6543999999999999, 0.7236013333333333, 0.9551658333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 370}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{369, 379}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 390}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 425}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 466}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 466}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{371, 382}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 419}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{371, 427}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 429}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 417}], {
             RGBColor[
             0.9044521666666667, 0.5624576666666667, 0.47666716666666675`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 398}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{373, 472}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 391}], {
             RGBColor[0.8845911666666666, 0.5488736666666667, 0.5652925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 437}], {
             RGBColor[0.9007555, 0.560929, 0.5379305]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{375, 426}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 489}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 400}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{376, 414}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 415}], {
             RGBColor[
             0.9934293333333333, 0.9883543333333333, 0.5262016666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 464}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 485}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{376, 497}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 403}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 449}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 484}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 488}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 380}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{379, 380}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 390}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 478}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 390}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 411}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{380, 478}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 419}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 439}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 416}], {
             RGBColor[
             0.5653951666666667, 0.6345071666666666, 0.9499340000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 427}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 429}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 499}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 479}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 482}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 496}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 435}], {
             RGBColor[0.7120275, 0.5070206666666669, 0.5752373333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 391}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 421}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 403}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 405}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 491}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{388, 487}], {
             RGBColor[0.948365, 0.8221860000000001, 0.3335865]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{388, 490}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685095]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{389, 409}], {
             RGBColor[0.9006771666666666, 0.789404, 0.6159235]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{389, 451}], {
             RGBColor[
             0.9479061666666666, 0.8243936666666667, 0.5154566666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 456}], {
             RGBColor[
             0.7417861666666666, 0.6636883333333333, 0.6009121666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 458}], {
             RGBColor[0.8028971666666667, 0.712394, 0.6063431666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 425}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 478}], {
             RGBColor[0.9062435000000001, 0.9228350000000001, 0.704034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 459}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 465}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 492}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 468}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{394, 398}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 445}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 460}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 440}], {
             RGBColor[0.8859236666666668, 0.9114586666666666, 0.9745295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 447}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{395, 453}], {
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 463}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 422}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 443}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 446}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 419}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 472}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 445}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{398, 460}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 472}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 412}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 414}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 415}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 464}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 450}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 454}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 471}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 475}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 500}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 431}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 436}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 459}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 462}], {
             RGBColor[
             0.9798641666666666, 0.9474946666666667, 0.5599291666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 487}], {
             RGBColor[
             0.9479061666666666, 0.8243936666666667, 0.5154566666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 405}], {
             RGBColor[
             0.9057846666666667, 0.9250426666666667, 0.8859041666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 449}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 491}], {
             RGBColor[
             0.9071698333333333, 0.9248163333333335, 0.8048596666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 407}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 408}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 434}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 469}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 474}], {
             RGBColor[0.674261, 0.7371853333333334, 0.8665405000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 491}], {
             RGBColor[0.9929705, 0.990562, 0.7080718333333336]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{406, 413}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 476}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 486}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 493}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 408}], {
             RGBColor[
             0.6996646666666667, 0.7643373333333334, 0.9713596666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 430}], {
             RGBColor[
             0.7817686666666666, 0.8285543333333334, 0.9358351666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{408, 430}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 456}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 458}], {
             RGBColor[0.7993473333333334, 0.843799, 0.9804696666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 496}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{411, 478}], {
             RGBColor[0.8585556666666667, 0.890053, 0.986371]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{413, 476}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 486}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 493}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 415}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 485}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{415, 464}], {
             RGBColor[0.9883474999999999, 0.987052, 0.6685095]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{415, 485}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 427}], {
             RGBColor[
             0.5852561666666667, 0.6480911666666667, 0.8613086666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 429}], {
             RGBColor[0.5815595, 0.6465624999999999, 0.922572]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{416, 499}], {
             RGBColor[0.5380271666666667, 0.6131015, 0.9617755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{417, 461}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 420}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{418, 432}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 432}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 439}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 423}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 477}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{422, 443}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 446}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 446}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 477}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 440}], {
             RGBColor[
             0.7607756666666667, 0.8130430000000001, 0.9767906666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 453}], {
             RGBColor[
             0.7731385000000001, 0.5557263333333335, 0.5806683333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 470}], {
             RGBColor[0.8428796666666667, 0.87726, 0.9412661666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{425, 466}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 448}], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 489}], {
             RGBColor[
             0.9878886666666666, 0.9892596666666666, 0.8503796666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 460}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 499}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 495}], {
             RGBColor[
             0.4051273333333333, 0.5253226666666666, 0.9470353333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{429, 499}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 433}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 436}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 459}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 462}], {
             RGBColor[0.9761675, 0.9459660000000001, 0.6211925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 487}], {
             RGBColor[0.9442094999999999, 0.822865, 0.57672]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{432, 467}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 462}], {
             RGBColor[
             0.9600031666666666, 0.9339106666666667, 0.6485544999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 469}], {
             RGBColor[0.9448151666666667, 0.9535910000000001, 0.707713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 474}], {
             RGBColor[
             0.6747198333333333, 0.7349776666666666, 0.6846703333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 495}], {
             RGBColor[
             0.6747198333333333, 0.7349776666666666, 0.6846703333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 459}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 462}], {
             RGBColor[0.9326351666666666, 0.912505, 0.660396]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{436, 487}], {
             RGBColor[0.9006771666666666, 0.789404, 0.6159235000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 457}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 460}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 453}], {
             RGBColor[
             0.8323468333333335, 0.6019803333333336, 0.5865696666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 470}], {
             RGBColor[0.902088, 0.9235140000000001, 0.9471674999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 467}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{442, 444}], {
             RGBColor[0.9651515, 0.8927656666666668, 0.5293326666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 492}], {
             RGBColor[
             0.8201425000000001, 0.7807660000000001, 0.6202191666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{443, 446}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{444, 492}], {
             RGBColor[
             0.8465763333333334, 0.8787886666666667, 0.8800028333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{445, 460}], {
             RGBColor[
             0.7382363333333333, 0.7950933333333333, 0.9750386666666666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 453}], {
             RGBColor[
             0.9195326666666667, 0.6674996666666669, 0.4087373333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 463}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{449, 488}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 454}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{450, 469}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 471}], {
             RGBColor[
             0.9892738333333333, 0.9890333333333334, 0.7693351666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 475}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 491}], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 500}], {
             RGBColor[0.9731095, 0.976978, 0.7966971666666668]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{451, 456}], {
             RGBColor[0.7854653333333332, 0.830083, 0.8745718333333334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{453, 463}], {
             RGBColor[0.8982865, 0.6541420000000002, 0.5784071666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 469}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 471}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 475}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 500}], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{456, 458}], {
             RGBColor[
             0.6404563333333333, 0.7180833333333334, 0.9654583333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{461, 486}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{461, 493}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{462, 487}], {
             RGBColor[0.936185, 0.7811, 0.2862695]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 485}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 497}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 468}], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 471}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 474}], {
             RGBColor[
             0.6270319999999999, 0.7021956666666667, 0.9670073333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 475}], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{469, 491}], {
             RGBColor[0.9457415, 0.9555723333333334, 0.8085386666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 495}], {
             RGBColor[
             0.6270319999999999, 0.7021956666666667, 0.9670073333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 475}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 500}], {
             RGBColor[0.9680276666666666, 0.9756756666666666, 0.939005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{474, 495}], {
             RGBColor[
             0.3569366666666666, 0.4835823333333333, 0.9439646666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{476, 493}], {
             RGBColor[0.9721831666666667, 0.9749966666666667, 0.6958715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{479, 482}], {
             RGBColor[
             0.9443563333333334, 0.9557986666666667, 0.8895831666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{480, 481}], {
             RGBColor[0.9406596666666667, 0.95427, 0.9508464999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{482, 496}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{484, 500}], {
             RGBColor[
             0.9717243333333333, 0.9772043333333333, 0.8777416666666668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{485, 497}], {
             RGBColor[0.9244953333333332, 0.9422146666666666, 0.9782085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{486, 493}], {
             RGBColor[
             0.9920441666666666, 0.9885806666666668, 0.6072461666666668]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.0315874366232787], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[4, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.0315874366232787], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.0315874366232787], {
             RGBColor[0.968143, 0.904201, 0.330742]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.0315874366232787], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.0315874366232787], {
             RGBColor[0.968143, 0.904201, 0.330742]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.0315874366232787], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.0315874366232787], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.0315874366232787], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.0315874366232787], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[21, 0.0315874366232787], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.0315874366232787], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.0315874366232787], {
             RGBColor[
             0.8447096666666667, 0.3446636666666671, 0.19044733333333339`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.0315874366232787], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[32, 0.0315874366232787], {
             RGBColor[0.968143, 0.904201, 0.330742]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.0315874366232787], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.0315874366232787], {
             RGBColor[0.453318, 0.567063, 0.950106]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[42, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.0315874366232787], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.0315874366232787], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[48, 0.0315874366232787], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.0315874366232787], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.0315874366232787], {
             RGBColor[
             0.3569366666666666, 0.4835823333333333, 0.9439646666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.0315874366232787], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.0315874366232787], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.0315874366232787], {
             RGBColor[0.968143, 0.904201, 0.330742]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[58, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.0315874366232787], {
             RGBColor[
             0.8447096666666667, 0.3446636666666671, 0.19044733333333339`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.0315874366232787], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.0315874366232787], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.0315874366232787], {
             RGBColor[0.968143, 0.904201, 0.330742]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.0315874366232787], {
             RGBColor[
             0.3569366666666666, 0.4835823333333333, 0.9439646666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[72, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.0315874366232787], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.0315874366232787], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.0315874366232787], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.0315874366232787], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.0315874366232787], {
             RGBColor[
             0.3569366666666666, 0.4835823333333333, 0.9439646666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.0315874366232787], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.0315874366232787], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.0315874366232787], {
             RGBColor[0.968143, 0.904201, 0.330742]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[89, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[91, 0.0315874366232787], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.0315874366232787], {
             RGBColor[0.968143, 0.904201, 0.330742]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.0315874366232787], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.0315874366232787], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.0315874366232787], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.0315874366232787], {
             RGBColor[0.904227, 0.657999, 0.241797]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.0315874366232787], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.0315874366232787], {
             RGBColor[0.968143, 0.904201, 0.330742]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.0315874366232787], {
             RGBColor[
             0.8447096666666667, 0.3446636666666671, 0.19044733333333339`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.0315874366232787], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[106, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.0315874366232787], {
             RGBColor[
             0.8447096666666667, 0.3446636666666671, 0.19044733333333339`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.0315874366232787], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[114, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[115, 0.0315874366232787], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.0315874366232787], {
             RGBColor[0.904227, 0.657999, 0.241797]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.0315874366232787], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.0315874366232787], {
             RGBColor[
             0.8447096666666667, 0.3446636666666671, 0.19044733333333339`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.0315874366232787], {
             RGBColor[
             0.8736790000000001, 0.519287666666667, 0.21630700000000008`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[125, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.0315874366232787], {
             RGBColor[0.904227, 0.657999, 0.241797]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[130, 0.0315874366232787], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.0315874366232787], {
             RGBColor[
             0.8736790000000001, 0.519287666666667, 0.21630700000000008`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.0315874366232787], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.0315874366232787], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.0315874366232787], {
             RGBColor[0.904227, 0.657999, 0.241797]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.0315874366232787], {
             RGBColor[0.904227, 0.657999, 0.241797]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.0315874366232787], {
             RGBColor[
             0.8736790000000001, 0.519287666666667, 0.21630700000000008`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.0315874366232787], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.0315874366232787], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.0315874366232787], {
             RGBColor[
             0.8736790000000001, 0.519287666666667, 0.21630700000000008`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.0315874366232787], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.0315874366232787], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[161, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[163, 0.0315874366232787], {
             RGBColor[0.265473, 0.39635933333333334`, 0.9384296666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[166, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.0315874366232787], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.0315874366232787], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.0315874366232787], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.0315874366232787], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[176, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.0315874366232787], {
             RGBColor[0.453318, 0.567063, 0.950106]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[184, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.0315874366232787], {
             RGBColor[0.904227, 0.657999, 0.241797]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.0315874366232787], {
             RGBColor[0.453318, 0.567063, 0.950106]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.0315874366232787], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[193, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[195, 0.0315874366232787], {
             RGBColor[
             0.8447096666666667, 0.3446636666666671, 0.19044733333333339`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[199, 0.0315874366232787], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[203, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.0315874366232787], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.0315874366232787], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.0315874366232787], {
             RGBColor[0.904227, 0.657999, 0.241797]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.0315874366232787], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.0315874366232787], {
             RGBColor[0.904227, 0.657999, 0.241797]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.0315874366232787], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.0315874366232787], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.0315874366232787], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.0315874366232787], {
             RGBColor[0.904227, 0.657999, 0.241797]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.0315874366232787], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.0315874366232787], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[227, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.0315874366232787], {
             RGBColor[0.968143, 0.904201, 0.330742]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.0315874366232787], {
             RGBColor[0.904227, 0.657999, 0.241797]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.0315874366232787], {
             RGBColor[0.453318, 0.567063, 0.950106]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.0315874366232787], {
             RGBColor[
             0.3569366666666666, 0.4835823333333333, 0.9439646666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.0315874366232787], {
             RGBColor[
             0.8447096666666667, 0.3446636666666671, 0.19044733333333339`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.0315874366232787], {
             RGBColor[
             0.3569366666666666, 0.4835823333333333, 0.9439646666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.0315874366232787], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.0315874366232787], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[245, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.0315874366232787], {
             RGBColor[0.904227, 0.657999, 0.241797]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.0315874366232787], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[252, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[253, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.0315874366232787], {
             RGBColor[0.968143, 0.904201, 0.330742]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.0315874366232787], {
             RGBColor[0.904227, 0.657999, 0.241797]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.0315874366232787], {
             RGBColor[
             0.9387176666666668, 0.7947430000000002, 0.26954900000000004`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.0315874366232787], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.0315874366232787], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.0315874366232787], {
             RGBColor[
             0.8736790000000001, 0.519287666666667, 0.21630700000000008`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.0315874366232787], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.0315874366232787], {
             RGBColor[0.453318, 0.567063, 0.950106]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.0315874366232787], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.0315874366232787], {
             RGBColor[
             0.8447096666666667, 0.3446636666666671, 0.19044733333333339`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.0315874366232787], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.0315874366232787], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.0315874366232787], {
             RGBColor[
             0.9387176666666668, 0.7947430000000002, 0.26954900000000004`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.0315874366232787], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[283, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.0315874366232787], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.0315874366232787], {
             RGBColor[
             0.8736790000000001, 0.519287666666667, 0.21630700000000008`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.0315874366232787], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.0315874366232787], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.0315874366232787], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.0315874366232787], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.0315874366232787], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[299, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.0315874366232787], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.0315874366232787], {
             RGBColor[
             0.8736790000000001, 0.519287666666667, 0.21630700000000008`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.0315874366232787], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[322, 0.0315874366232787], {
             RGBColor[
             0.9387176666666668, 0.7947430000000002, 0.26954900000000004`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[324, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.0315874366232787], {
             RGBColor[
             0.8736790000000001, 0.519287666666667, 0.21630700000000008`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[328, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[329, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[331, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[332, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.0315874366232787], {
             RGBColor[
             0.8447096666666667, 0.3446636666666671, 0.19044733333333339`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[336, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[337, 0.0315874366232787], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.0315874366232787], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[343, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.0315874366232787], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[350, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.0315874366232787], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.0315874366232787], {
             RGBColor[0.453318, 0.567063, 0.950106]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.0315874366232787], {
             RGBColor[0.904227, 0.657999, 0.241797]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.0315874366232787], {
             RGBColor[
             0.3569366666666666, 0.4835823333333333, 0.9439646666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.0315874366232787], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.0315874366232787], {
             RGBColor[
             0.3569366666666666, 0.4835823333333333, 0.9439646666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[371, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.0315874366232787], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[374, 0.0315874366232787], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.0315874366232787], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[379, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.0315874366232787], {
             RGBColor[
             0.8447096666666667, 0.3446636666666671, 0.19044733333333339`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.0315874366232787], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.0315874366232787], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.0315874366232787], {
             RGBColor[0.904227, 0.657999, 0.241797]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.0315874366232787], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[393, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[394, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[399, 0.0315874366232787], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[401, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[402, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[403, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[404, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[405, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[406, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[407, 0.0315874366232787], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[408, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[409, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[410, 0.0315874366232787], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[411, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[412, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[413, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[414, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[415, 0.0315874366232787], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[416, 0.0315874366232787], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[417, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[418, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[419, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[420, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[421, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[422, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[423, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[424, 0.0315874366232787], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[425, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[426, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[427, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[428, 0.0315874366232787], {
             RGBColor[0.453318, 0.567063, 0.950106]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[429, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[430, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[431, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[432, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[433, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[434, 0.0315874366232787], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[435, 0.0315874366232787], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[436, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[437, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[438, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[439, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[440, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[441, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[442, 0.0315874366232787], {
             RGBColor[
             0.9387176666666668, 0.7947430000000002, 0.26954900000000004`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[443, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[444, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[445, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[446, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[447, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[448, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[449, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[450, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[451, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[452, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[453, 0.0315874366232787], {
             RGBColor[
             0.8447096666666667, 0.3446636666666671, 0.19044733333333339`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[454, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[455, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[456, 0.0315874366232787], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[457, 0.0315874366232787], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[458, 0.0315874366232787], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[459, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[460, 0.0315874366232787], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[461, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[462, 0.0315874366232787], {
             RGBColor[0.968143, 0.904201, 0.330742]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[463, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[464, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[465, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[466, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[467, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[468, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[469, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[470, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[471, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[472, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[473, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[474, 0.0315874366232787], {
             RGBColor[
             0.3569366666666666, 0.4835823333333333, 0.9439646666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[475, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[476, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[477, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[478, 0.0315874366232787], {
             RGBColor[0.8199840000000002, 0.8592970000000001, 0.982692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[479, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[480, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[481, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[482, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[483, 0.0315874366232787], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[484, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[485, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[486, 0.0315874366232787], {
             RGBColor[
             0.9915853333333333, 0.9907883333333334, 0.7891163333333335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[487, 0.0315874366232787], {
             RGBColor[0.904227, 0.657999, 0.241797]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[488, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[489, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[490, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[491, 0.0315874366232787], {
             RGBColor[
             0.9943556666666666, 0.9903356666666667, 0.6270273333333336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[492, 0.0315874366232787], {
             RGBColor[0.7015673333333334, 0.766789, 0.9708893333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[493, 0.0315874366232787], {
             RGBColor[0.992503, 0.986373, 0.425376]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[494, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[495, 0.0315874366232787], {
             RGBColor[
             0.3569366666666666, 0.4835823333333333, 0.9439646666666667]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[496, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[497, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[498, 0.0315874366232787], {
             RGBColor[
             0.5793453333333333, 0.6693776666666666, 0.9600273333333333]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[499, 0.0315874366232787], {
             RGBColor[0.8971273333333333, 0.920809, 0.99005]}, StripOnInput -> 
            False], 
           StyleBox[
            DiskBox[500, 0.0315874366232787], {
             RGBColor[0.9518633333333333, 0.9636203333333333, 0.966367]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1dOWGAgQBNBMbNu2bds2J+bEtm3btm3btu01sjdnH271F1R1ssCg6p0C
ggUL9l38vMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEIS
kZgkJCUZyUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpR
mCIUpRjFKUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGY
JjSlGYE0pwUtaUVr2tCWdrSnAx3pRBCd6UJXutGdHvSkF73pQ1/60Z8BDGQQ
gxnCUIYxnBGMZBSjGcNYxjGeCUxkEpOZwlSmMZ0ZzGQWs5nDXOYxnwUsZBGL
WcJSlrGcFaxkFatZw1rWsZ4NbGQTm9nCVraxnR3sZBe72cNe9rGfAxzkEIc5
wlGOcZwTnOQUpznDWc5xngtc5BKXucJVrnGdG9zkFre5w13ucZ8HPOQRj3nC
U57xnBe85BWvecNb3vGeD3zkE5/5wle+8Z1f+JXf+J0/+JO/+Jt/+Jcf/Cx/
AMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEISkZgkJCUZ
yUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpRmCIUpRjF
KUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGYJjSlGYE0
pwUtaUVr2tCWdrSnAx35Od5BdKYLXelGd3rQk170pg996Ud/BjCQQQxmCEMZ
xnBGMJJRjGYMYxnHeCYwkUlMZgpTmcZ0ZjCTWcxmDnOZx3wWsJBFLGYJS1nG
clawklWsZg1rWcd6NrCRTWxmC1vZxnZ2sJNd7GYPe9nHfg5wkEMc5ghHOcZx
TnCSU5zmDGc5x3kucJFLXOYKV7nGdW5wk1vc5g53ucd9HvCQRzzmCU95xnNe
8JJXvOYNb3nHez7wkU985gtf+Rbw/z//Dz189+A=
          "], {Null, CompressedData["
1:eJw13A2c1mO6wPH7tsdpl2O9LLLYQ3Ioas/uCqvVrqQihdKSUmmVzEwspdpK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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[196, 330] -> 
             RGBColor[
              0.3010744440099954, 0.433778708249762, 0.9404571162354194], 
             UndirectedEdge[136, 319] -> 
             RGBColor[
              0.8419251732908781, 0.8767840075536342, 0.9548214315268342], 
             UndirectedEdge[60, 188] -> 
             RGBColor[
              0.31499337168742486`, 0.44577048443841216`, 0.9413463649912971],
              UndirectedEdge[145, 408] -> 
             RGBColor[
              0.2215813501340996, 0.35022642643293833`, 0.9359301021386808], 
             UndirectedEdge[398, 460] -> 
             RGBColor[
              0.2547486544855675, 0.3850873662348864, 0.9378189310548671], 
             UndirectedEdge[413, 476] -> 
             RGBColor[
              0.9111642263834832, 0.6485722673362936, 0.273464018883213], 
             UndirectedEdge[244, 274] -> 
             RGBColor[
              0.40258764491589, 0.5228672426461249, 0.9469441500000384], 
             UndirectedEdge[198, 223] -> 
             RGBColor[
              0.335871613441881, 0.4628528461466326, 0.9427133713948876], 
             UndirectedEdge[36, 310] -> 
             RGBColor[
              0.2755731801551128, 0.4069752630647657, 0.9390048569846228], 
             UndirectedEdge[252, 432] -> 
             RGBColor[
              0.8172102397534445, 0.8577657390481622, 0.982246863062763], 
             UndirectedEdge[469, 475] -> 
             RGBColor[
              0.8497170345102683, 0.3799664311487149, 0.19511763635494941`], 
             UndirectedEdge[113, 347] -> 
             RGBColor[
              0.17905963034776856`, 0.3055334029047545, 0.9335085531020964], 
             UndirectedEdge[35, 131] -> 
             RGBColor[
              0.2509907389862678, 0.38113755877951816`, 0.9376049233265198], 
             UndirectedEdge[156, 479] -> 
             RGBColor[
              0.4393999195807523, 0.5546279653397757, 0.9493241177753168], 
             UndirectedEdge[318, 354] -> 
             RGBColor[
              0.35185308329442466`, 0.47917918892462685`, 0.9436407452294238],
              UndirectedEdge[6, 77] -> 
             RGBColor[
              0.7172538475630181, 0.7785612627115652, 0.9728085302210365], 
             UndirectedEdge[23, 202] -> 
             RGBColor[
              0.23077928410080303`, 0.35989403821464017`, 0.9364539108709606],
              UndirectedEdge[342, 395] -> 
             RGBColor[
              0.2624873580585535, 0.3932212343522405, 0.9382596387749628], 
             UndirectedEdge[53, 418] -> 
             RGBColor[
              0.9774928986004763, 0.9579493905915291, 0.642289060004833], 
             UndirectedEdge[75, 149] -> 
             RGBColor[
              0.3494116417234011, 0.4770645349462275, 0.9434851787314], 
             UndirectedEdge[293, 418] -> 
             RGBColor[
              0.9663729017016692, 0.9744415456652006, 0.9418060854539165], 
             UndirectedEdge[282, 432] -> 
             RGBColor[
              0.7531414292760994, 0.8071831282683875, 0.9762245194841053], 
             UndirectedEdge[466, 468] -> 
             RGBColor[
              0.49094259840512156`, 0.5976083439541202, 0.9530679462098963], 
             UndirectedEdge[105, 190] -> 
             RGBColor[
              0.24700744449895456`, 0.37695086371789455`, 0.9373780805982235],
              UndirectedEdge[64, 473] -> 
             RGBColor[
              0.3073328542986736, 0.43868458843205593`, 0.9408747474285853], 
             UndirectedEdge[214, 273] -> 
             RGBColor[
              0.24667426527178135`, 0.3766006712253524, 0.9373591065341305], 
             UndirectedEdge[30, 64] -> 
             RGBColor[
              0.27788283656739987`, 0.4094028583947541, 0.9391363885004721], 
             UndirectedEdge[296, 395] -> 
             RGBColor[
              0.289203696626415, 0.4208696734674796, 0.9397969170059906], 
             UndirectedEdge[114, 203] -> 
             RGBColor[
              0.5176225598035007, 0.6192683385358883, 0.9551682905030956], 
             UndirectedEdge[81, 237] -> 
             RGBColor[
              0.8648552697662895, 0.8950761325134684, 0.9869718617673642], 
             UndirectedEdge[382, 427] -> 
             RGBColor[
              0.2808624118228371, 0.41253458090420103`, 0.9393060709033827], 
             UndirectedEdge[39, 450] -> 
             RGBColor[
              0.7206850354992045, 0.4212381693670362, 0.5640535204963621], 
             UndirectedEdge[50, 57] -> 
             RGBColor[
              0.5210905073010532, 0.6217476292469348, 0.9555341779806428], 
             UndirectedEdge[74, 153] -> 
             RGBColor[
              0.2633334885240648, 0.39411057111926295`, 0.9383078246532357], 
             UndirectedEdge[239, 332] -> 
             RGBColor[
              0.37656128496655794`, 0.5005801913427036, 0.9452151299913671], 
             UndirectedEdge[14, 72] -> 
             RGBColor[
              0.2803635687690008, 0.4120102652261427, 0.9392776625294388], 
             UndirectedEdge[331, 403] -> 
             RGBColor[
              0.8828018353475209, 0.9093862367613971, 0.9886836212135901], 
             UndirectedEdge[214, 302] -> 
             RGBColor[
              0.19497823659732902`, 0.32226486737097304`, 0.9344150941785414],
              UndirectedEdge[128, 197] -> 
             RGBColor[
              0.5961844176461558, 0.6822017797294064, 0.9619318024689351], 
             UndirectedEdge[191, 212] -> 
             RGBColor[
              0.21845881642544385`, 0.3469444455250692, 0.9357522784633475], 
             UndirectedEdge[404, 407] -> 
             RGBColor[
              0.2139033248740353, 0.3421563350696921, 0.9354928499587406], 
             UndirectedEdge[60, 116] -> 
             RGBColor[
              0.27071777339856856`, 0.4018719227130688, 0.9387283487527682], 
             UndirectedEdge[272, 357] -> 
             RGBColor[
              0.8638626077841431, 0.41438606964025426`, 0.20574312527482636`],
              UndirectedEdge[228, 490] -> 
             RGBColor[
              0.9918174311383581, 0.9889858002878001, 0.6472681311594083], 
             UndirectedEdge[111, 415] -> 
             RGBColor[
              0.2800519643946353, 0.41168274927182613`, 0.9392599171212961], 
             UndirectedEdge[227, 428] -> 
             RGBColor[
              0.8379823315719487, 0.29295442119162834`, 0.18400522964919308`],
              UndirectedEdge[367, 499] -> 
             RGBColor[
              0.24528184927831587`, 0.3751371537319471, 0.9372798105031974], 
             UndirectedEdge[434, 495] -> 
             RGBColor[
              0.9167025248852594, 0.6580111596730529, 0.4917530067660364], 
             UndirectedEdge[226, 283] -> 
             RGBColor[
              0.18031957576389654`, 0.30685768542225833`, 0.9335803051296228],
              UndirectedEdge[9, 34] -> 
             RGBColor[
              0.559448373541096, 0.6532244183595045, 0.9584609717735231], 
             UndirectedEdge[127, 386] -> 
             RGBColor[
              0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993],
              UndirectedEdge[326, 469] -> 
             RGBColor[
              0.8678030946468546, 0.4926065528105953, 0.21140400054171546`], 
             UndirectedEdge[192, 483] -> 
             RGBColor[
              0.275631905541692, 0.4070369871694651, 0.9390082013085121], 
             UndirectedEdge[16, 39] -> 
             RGBColor[
              0.5137718344766236, 0.6147998451486828, 0.9552360290912556], 
             UndirectedEdge[209, 421] -> 
             RGBColor[
              0.37249008899703795`, 0.4820057501195733, 0.9462395519949527], 
             UndirectedEdge[293, 317] -> 
             RGBColor[
              0.9188363181868828, 0.7644234365766909, 0.5933539685152149], 
             UndirectedEdge[3, 381] -> 
             RGBColor[
              0.5154854178683257, 0.6175333104357662, 0.9550000468613498], 
             UndirectedEdge[211, 497] -> 
             RGBColor[
              0.23351702426712523`, 0.36277157671219695`, 0.936609821123309], 
             UndirectedEdge[196, 479] -> 
             RGBColor[
              0.35359500425427093`, 0.4794816999667437, 0.9437959057364866], 
             UndirectedEdge[221, 439] -> 
             RGBColor[
              0.6987612824501502, 0.7633077628527738, 0.9716294265306357], 
             UndirectedEdge[379, 390] -> 
             RGBColor[
              0.30502633329137085`, 0.4378812473959014, 0.9406840432278518], 
             UndirectedEdge[119, 320] -> 
             RGBColor[
              0.9896249360090673, 0.9899776586598361, 0.8216051903420669], 
             UndirectedEdge[179, 401] -> 
             RGBColor[
              0.47619075737058414`, 0.5641711945885997, 0.9557776422261561], 
             UndirectedEdge[59, 342] -> 
             RGBColor[
              0.25108912406320616`, 0.3812409677333546, 0.9376105262111039], 
             UndirectedEdge[86, 98] -> 
             RGBColor[
              0.9552139147274563, 0.8468459050338089, 0.4866646892725739], 
             UndirectedEdge[328, 431] -> 
             RGBColor[
              0.4169264678183623, 0.535542483915856, 0.9477871637491544], 
             UndirectedEdge[270, 375] -> 
             RGBColor[
              0.9741122632489756, 0.9792447932430604, 0.8853225104060825], 
             UndirectedEdge[39, 45] -> 
             RGBColor[
              0.45322202962692537`, 0.5599541419213354, 0.9514657433370749], 
             UndirectedEdge[59, 463] -> 
             RGBColor[
              0.2546442329532448, 0.38497761258370766`, 0.9378129844030793], 
             UndirectedEdge[2, 55] -> 
             RGBColor[
              0.21196267506411343`, 0.3401165890751596, 0.9353823328229998], 
             UndirectedEdge[193, 496] -> 
             RGBColor[
              0.28235063055336573`, 0.41409879314850406`, 0.939390822758464], 
             UndirectedEdge[201, 246] -> 
             RGBColor[
              0.2993400916080083, 0.43195579391098005`, 0.9403583474318706], 
             UndirectedEdge[69, 487] -> 
             RGBColor[
              0.7444469428218465, 0.8000461273805028, 0.9756303235156909], 
             UndirectedEdge[15, 408] -> 
             RGBColor[
              0.22837166352845595`, 0.3573634763411423, 0.9363168004411209], 
             UndirectedEdge[118, 310] -> 
             RGBColor[
              0.3109325878407584, 0.44262745407148385`, 0.9410739135361832], 
             UndirectedEdge[289, 297] -> 
             RGBColor[
              0.47936763079523015`, 0.5878325714725148, 0.9522613561781106], 
             UndirectedEdge[397, 419] -> 
             RGBColor[
              0.43561929438142943`, 0.5501211672171827, 0.9494236831393772], 
             UndirectedEdge[13, 380] -> 
             RGBColor[
              0.28473366122711574`, 0.4166035094794867, 0.939526532829956], 
             UndirectedEdge[155, 262] -> 
             RGBColor[
              0.520987467347936, 0.6220001220678183, 0.9554331883510561], 
             UndirectedEdge[182, 324] -> 
             RGBColor[
              0.37413205522389265`, 0.49847611463624397`, 0.9450603416202481],
              UndirectedEdge[177, 245] -> 
             RGBColor[
              0.21512971428686242`, 0.34344534810015337`, 0.9355626910215206],
              UndirectedEdge[113, 325] -> 
             RGBColor[
              0.1791045905323438, 0.30558065890938335`, 0.9335111135180953], 
             UndirectedEdge[94, 368] -> 
             RGBColor[
              0.6817603644893816, 0.7470855364406719, 0.9537864521193352], 
             UndirectedEdge[50, 140] -> 
             RGBColor[
              0.47028604559026116`, 0.5805022785151959, 0.9515346646518938], 
             UndirectedEdge[389, 458] -> 
             RGBColor[
              0.2244995192065336, 0.35329360715067204`, 0.9360962875503116], 
             UndirectedEdge[429, 499] -> 
             RGBColor[
              0.2771583025105514, 0.4086413271628938, 0.9390951273577867], 
             UndirectedEdge[97, 358] -> 
             RGBColor[
              0.2286803601297014, 0.35768793604154625`, 0.9363343802558861], 
             UndirectedEdge[274, 363] -> 
             RGBColor[
              0.4337728092244554, 0.5498782645582716, 0.9489312410938221], 
             UndirectedEdge[255, 274] -> 
             RGBColor[
              0.43015989340709154`, 0.5467489384677, 0.9487010292927157], 
             UndirectedEdge[289, 381] -> 
             RGBColor[
              0.5043379271734174, 0.6081045829713598, 0.9542271093782111], 
             UndirectedEdge[55, 230] -> 
             RGBColor[
              0.21767784356668446`, 0.34612359353397393`, 0.935707803214387], 
             UndirectedEdge[289, 349] -> 
             RGBColor[
              0.42648626116779464`, 0.5438226964259498, 0.9483963053279869], 
             UndirectedEdge[29, 318] -> 
             RGBColor[
              0.37578131668551923`, 0.4999046220200136, 0.9451654311021982], 
             UndirectedEdge[69, 402] -> 
             RGBColor[
              0.7308868707375382, 0.7890374499881754, 0.9745628249690335], 
             UndirectedEdge[6, 413] -> 
             RGBColor[
              0.9007629224656561, 0.8944231613369187, 0.6681426582115271], 
             UndirectedEdge[29, 482] -> 
             RGBColor[
              0.38405087443932273`, 0.5070672973063002, 0.9456923600097877], 
             UndirectedEdge[212, 456] -> 
             RGBColor[
              0.22108739015867407`, 0.34970724317989477`, 0.9359019718488286],
              UndirectedEdge[354, 482] -> 
             RGBColor[
              0.3601226410482282, 0.48634186421091347`, 0.9441676741370133], 
             UndirectedEdge[106, 247] -> 
             RGBColor[
              0.5064333598698463, 0.6101844419620349, 0.9542874356969284], 
             UndirectedEdge[305, 382] -> 
             RGBColor[
              0.2666682843502908, 0.39761565297089385`, 0.938497736342151], 
             UndirectedEdge[279, 285] -> 
             RGBColor[
              0.2964892825686648, 0.42843496613236076`, 0.9402152006381983], 
             UndirectedEdge[27, 319] -> 
             RGBColor[
              0.6135043005796454, 0.695998377538924, 0.9634761021745089], 
             UndirectedEdge[118, 483] -> 
             RGBColor[
              0.31087863822406303`, 0.44257074960373377`, 0.9410708411853237],
              UndirectedEdge[342, 447] -> 
             RGBColor[
              0.2532435452217043, 0.38350540096912705`, 0.9377332173088998], 
             UndirectedEdge[207, 458] -> 
             RGBColor[
              0.22378112515977486`, 0.35253852945871533`, 0.9360553760721175],
              UndirectedEdge[462, 487] -> 
             RGBColor[
              0.5216548713893666, 0.6225419507348611, 0.9554857288419789], 
             UndirectedEdge[64, 384] -> 
             RGBColor[
              0.28582762436265047`, 0.41775333409620263`, 0.9395888324121513],
              UndirectedEdge[203, 221] -> 
             RGBColor[
              0.5355883582024223, 0.6338537830261275, 0.9565826239639467], 
             UndirectedEdge[139, 370] -> 
             RGBColor[
              0.5777392587332322, 0.6680737829534684, 0.9599008972575682], 
             UndirectedEdge[46, 357] -> 
             RGBColor[
              0.9123985653292456, 0.6903965335177349, 0.2483720332752017], 
             UndirectedEdge[18, 326] -> 
             RGBColor[
              0.8797797158009789, 0.5469895922605361, 0.22139758680656518`], 
             UndirectedEdge[73, 93] -> 
             RGBColor[
              0.2585978739086303, 0.3891331399031328, 0.9380381384066008], 
             UndirectedEdge[104, 112] -> 
             RGBColor[
              0.24741859649764936`, 0.37738301053706513`, 0.9374014950963042],
              UndirectedEdge[40, 314] -> 
             RGBColor[
              0.35813781501059505`, 0.484622707657373, 0.944041202777008], 
             UndirectedEdge[264, 398] -> 
             RGBColor[0.2479686232623, 0.377961123540424, 0.9374328183068594],
              UndirectedEdge[345, 489] -> 
             RGBColor[
              0.8249113944148371, 0.8621373590775923, 0.8902454594075883], 
             UndirectedEdge[80, 417] -> 
             RGBColor[
              0.7452877880838611, 0.8009437515388753, 0.9752469796719869], 
             UndirectedEdge[271, 442] -> 
             RGBColor[
              0.26987532258207286`, 0.400986453490465, 0.9386803724250632], 
             UndirectedEdge[318, 482] -> 
             RGBColor[
              0.35021188070592757`, 0.4777576617317112, 0.9435361692517431], 
             UndirectedEdge[235, 260] -> 
             RGBColor[
              0.32130907660212404`, 0.45058132040043347`, 0.941772944022762], 
             UndirectedEdge[79, 278] -> 
             RGBColor[
              0.9710962278680113, 0.9751094566161655, 0.770981396643022], 
             UndirectedEdge[137, 404] -> 
             RGBColor[
              0.2167644246749318, 0.34516353236463915`, 0.9356557853597838], 
             UndirectedEdge[380, 478] -> 
             RGBColor[
              0.26944650218814237`, 0.40053573606766074`, 0.9386559517380118],
              UndirectedEdge[247, 370] -> 
             RGBColor[
              0.5432273595581627, 0.6400554684598069, 0.9571839941332545], 
             UndirectedEdge[251, 429] -> 
             RGBColor[
              0.2760715850682322, 0.4074991182291509, 0.9390332404071009], 
             UndirectedEdge[286, 407] -> 
             RGBColor[
              0.21872930348009942`, 0.347228744569382, 0.9357676823009604], 
             UndirectedEdge[206, 410] -> 
             RGBColor[
              0.35319958507105037`, 0.4803454610863929, 0.9437265431319655], 
             UndirectedEdge[86, 500] -> 
             RGBColor[
              0.8673428769617186, 0.42615530998421236`, 0.20846003809980468`],
              UndirectedEdge[78, 407] -> 
             RGBColor[
              0.21689372054729342`, 0.34529943052432305`, 0.9356631485684387],
              UndirectedEdge[363, 370] -> 
             RGBColor[
              0.4981273475389003, 0.6021241779008506, 0.9539974660883765], 
             UndirectedEdge[447, 453] -> 
             RGBColor[
              0.26540338983624123`, 0.39628616863768357`, 0.9384257024708196],
              UndirectedEdge[256, 492] -> 
             RGBColor[
              0.28300272562501616`, 0.4147841864140242, 0.9394279586081062], 
             UndirectedEdge[114, 349] -> 
             RGBColor[
              0.45713997699902986`, 0.5690874562014547, 0.9507048443075143], 
             UndirectedEdge[22, 160] -> 
             RGBColor[
              0.4369491379476227, 0.5528851144131592, 0.949062990584439], 
             UndirectedEdge[149, 324] -> 
             RGBColor[
              0.361776111320833, 0.4877740170552114, 0.9442730318006773], 
             UndirectedEdge[94, 315] -> 
             RGBColor[
              0.5704593476328262, 0.6392872195268108, 0.9471116754258844], 
             UndirectedEdge[246, 492] -> 
             RGBColor[
              0.2854203608730804, 0.4173252743466679, 0.9395656393589127], 
             UndirectedEdge[193, 202] -> 
             RGBColor[
              0.2634343891958272, 0.39421662412275726`, 0.9383135707972234], 
             UndirectedEdge[321, 335] -> 
             RGBColor[
              0.3049738126003747, 0.4356185220197354, 0.94076188047572], 
             UndirectedEdge[321, 496] -> 
             RGBColor[
              0.3050324981109774, 0.4356802042122551, 0.9407652225287313], 
             UndirectedEdge[18, 474] -> 
             RGBColor[
              0.9387405372806834, 0.7796548598202627, 0.49465049788910304`], 
             UndirectedEdge[184, 192] -> 
             RGBColor[
              0.25582325613433854`, 0.3862168407014245, 0.9378801280290341], 
             UndirectedEdge[170, 171] -> 
             RGBColor[
              0.2792113970027737, 0.4107992596479288, 0.9392120480518376], 
             UndirectedEdge[80, 156] -> 
             RGBColor[
              0.6284260394446897, 0.7069689251123001, 0.9654326763878454], 
             UndirectedEdge[353, 418] -> 
             RGBColor[
              0.809068015481273, 0.8509060188194038, 0.9430493347226458], 
             UndirectedEdge[201, 312] -> 
             RGBColor[
              0.30443515610797417`, 0.4373110297461917, 0.9406485038176712], 
             UndirectedEdge[152, 212] -> 
             RGBColor[
              0.21125959360220817`, 0.3393776058807578, 0.93534229337386], 
             UndirectedEdge[192, 260] -> 
             RGBColor[
              0.27009553441077905`, 0.4012179100846716, 0.9386929131629338], 
             UndirectedEdge[90, 357] -> 
             RGBColor[
              0.8859560304571115, 0.5741950476247133, 0.2265078159100875], 
             UndirectedEdge[57, 369] -> 
             RGBColor[
              0.5105952058083258, 0.6126571266031253, 0.9548654266501568], 
             UndirectedEdge[83, 448] -> 
             RGBColor[
              0.7443425082604527, 0.7998796964136958, 0.9757160754212024], 
             UndirectedEdge[67, 180] -> 
             RGBColor[
              0.26337700695553745`, 0.3941563117499686, 0.9383103029635284], 
             UndirectedEdge[373, 472] -> 
             RGBColor[
              0.31103110428016545`, 0.44242232361832246`, 0.9410908260962028],
              UndirectedEdge[353, 432] -> 
             RGBColor[
              0.7691435045990516, 0.820174333900838, 0.9774842614710615], 
             UndirectedEdge[1, 433] -> 
             RGBColor[
              0.2958358704615542, 0.4267230355457211, 0.940215525659722], 
             UndirectedEdge[300, 301] -> 
             RGBColor[
              0.2173551636481656, 0.3457844364805221, 0.9356894270703895], 
             UndirectedEdge[212, 389] -> 
             RGBColor[
              0.21850801717300872`, 0.34699615863026745`, 0.9357550803731354],
              UndirectedEdge[97, 174] -> 
             RGBColor[
              0.24919580773922206`, 0.37925097223365895`, 0.9375027046473634],
              UndirectedEdge[200, 471] -> 
             RGBColor[
              0.8788202951923778, 0.5401284768128874, 0.22049894846562806`], 
             UndirectedEdge[155, 387] -> 
             RGBColor[
              0.6705014636086952, 0.7413486854414358, 0.9685938847155504], 
             UndirectedEdge[156, 354] -> 
             RGBColor[
              0.4145365045344412, 0.533092524898237, 0.9477398429544205], 
             UndirectedEdge[314, 472] -> 
             RGBColor[
              0.3292610947634469, 0.4596111439654538, 0.9422012036975409], 
             UndirectedEdge[117, 269] -> 
             RGBColor[
              0.41500730712434825`, 0.5338802033825223, 0.947664876526779], 
             UndirectedEdge[336, 409] -> 
             RGBColor[
              0.23189710424361965`, 0.36106893805863094`, 0.9365175690744273],
              UndirectedEdge[63, 252] -> 
             RGBColor[
              0.5775658026497799, 0.6655789256820774, 0.9611207995905398], 
             UndirectedEdge[201, 444] -> 
             RGBColor[
              0.2878759109078417, 0.4199062131240665, 0.9397054793007316], 
             UndirectedEdge[201, 442] -> 
             RGBColor[
              0.2942020501296223, 0.426555386546551, 0.9400657435707277], 
             UndirectedEdge[25, 333] -> 
             RGBColor[
              0.34601220845973285`, 0.4741201167137219, 0.94326856984984], 
             UndirectedEdge[203, 397] -> 
             RGBColor[
              0.44655734447149653`, 0.5590011690338403, 0.950284766509865], 
             UndirectedEdge[7, 436] -> 
             RGBColor[
              0.6558009604167452, 0.7285914992480711, 0.9680622843636464], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.24125115959042637`, 0.3709006433094886, 0.9370502686883432], 
             UndirectedEdge[274, 369] -> 
             RGBColor[
              0.4413408424038283, 0.5564333145178368, 0.9494134694758627], 
             UndirectedEdge[38, 364] -> 
             RGBColor[
              0.2592676752099878, 0.3898371435387148, 0.9380762825998308], 
             UndirectedEdge[215, 356] -> 
             RGBColor[
              0.2767305167100354, 0.40819169716336523`, 0.9390707655892996], 
             UndirectedEdge[16, 283] -> 
             RGBColor[
              0.29254812031783006`, 0.4160210207001029, 0.9402936186581154], 
             UndirectedEdge[236, 276] -> 
             RGBColor[
              0.45343165662521556`, 0.5606674341824253, 0.9514328089086481], 
             UndirectedEdge[39, 454] -> 
             RGBColor[
              0.761772006870989, 0.6718134516549312, 0.6008439261608904], 
             UndirectedEdge[179, 315] -> 
             RGBColor[
              0.18221437666537932`, 0.3088492413070327, 0.9336882112378554], 
             UndirectedEdge[149, 182] -> 
             RGBColor[
              0.36623071660169665`, 0.4916323722545241, 0.9445568753101211], 
             UndirectedEdge[97, 407] -> 
             RGBColor[
              0.2230464248259349, 0.3517663128251578, 0.936013535974997], 
             UndirectedEdge[274, 379] -> 
             RGBColor[
              0.386016730119334, 0.5085143491277428, 0.9458882659622865], 
             UndirectedEdge[39, 325] -> 
             RGBColor[
              0.40133925395865816`, 0.5054220551360133, 0.9485110960164554], 
             UndirectedEdge[127, 347] -> 
             RGBColor[
              0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993],
              UndirectedEdge[327, 483] -> 
             RGBColor[
              0.27685916583525294`, 0.4083269155507945, 0.9390780919666615], 
             UndirectedEdge[269, 360] -> 
             RGBColor[
              0.5141528316673345, 0.616332566062272, 0.9549279906939228], 
             UndirectedEdge[54, 147] -> 
             RGBColor[
              0.2401069833110282, 0.36969804149487495`, 0.9369851095418886], 
             UndirectedEdge[276, 422] -> 
             RGBColor[
              0.4267760803352025, 0.5326507334404715, 0.9499148132723232], 
             UndirectedEdge[181, 424] -> 
             RGBColor[
              0.3706458143967508, 0.4954565080553325, 0.9448382014375043], 
             UndirectedEdge[336, 456] -> 
             RGBColor[
              0.22294853768143919`, 0.3516634272298894, 0.936007961446929], 
             UndirectedEdge[46, 298] -> 
             RGBColor[
              0.9096473304128414, 0.8178215341712867, 0.6215408826637097], 
             UndirectedEdge[107, 132] -> 
             RGBColor[
              0.5874023021726906, 0.6508098778838103, 0.8735074338464627], 
             UndirectedEdge[78, 95] -> 
             RGBColor[
              0.22325600943798377`, 0.3519865995408531, 0.9360254715086005], 
             UndirectedEdge[296, 332] -> 
             RGBColor[
              0.3578059368755654, 0.48433525149749035`, 0.9440200557957121], 
             UndirectedEdge[397, 472] -> 
             RGBColor[
              0.3434973849835166, 0.4719419030173265, 0.9431083275217065], 
             UndirectedEdge[19, 269] -> 
             RGBColor[
              0.5043319337096805, 0.6083595186738375, 0.9541548536315616], 
             UndirectedEdge[185, 335] -> 
             RGBColor[
              0.28035846079175497`, 0.4120048964181928, 0.9392773716376912], 
             UndirectedEdge[112, 351] -> 
             RGBColor[
              0.26915448795361524`, 0.4002288105924009, 0.9386393219593516], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.2633838374698597, 0.39416349105360093`, 0.9383106919512142], 
             UndirectedEdge[251, 305] -> 
             RGBColor[
              0.25482853774731307`, 0.38517132860787223`, 0.9378234802884469],
              UndirectedEdge[131, 170] -> 
             RGBColor[
              0.28014480934839103`, 0.4117803352049335, 0.9392652045040607], 
             UndirectedEdge[76, 333] -> 
             RGBColor[
              0.3949872182942583, 0.5165398086768207, 0.9463892141695951], 
             UndirectedEdge[114, 115] -> 
             RGBColor[
              0.7109234320173796, 0.7727455262693818, 0.9730887236423327], 
             UndirectedEdge[87, 421] -> 
             RGBColor[
              0.17915493384170816`, 0.30563357291947557`, 0.9335139804950874],
              UndirectedEdge[60, 192] -> 
             RGBColor[
              0.2736621188386635, 0.4049666164528918, 0.9388960248698129], 
             UndirectedEdge[84, 147] -> 
             RGBColor[
              0.24240373141068797`, 0.37211206936985763`, 0.93711590594843], 
             UndirectedEdge[431, 433] -> 
             RGBColor[
              0.3870230907643596, 0.509641681699111, 0.9458817470057914], 
             UndirectedEdge[201, 492] -> 
             RGBColor[
              0.29053904388296076`, 0.4227053347332997, 0.9398571407839125], 
             UndirectedEdge[86, 124] -> 
             RGBColor[
              0.9389228207101663, 0.7935781606519255, 0.2800166062249653], 
             UndirectedEdge[234, 239] -> 
             RGBColor[
              0.36975457999068184`, 0.4946845656075394, 0.9447814127692372], 
             UndirectedEdge[100, 450] -> 
             RGBColor[
              0.8744616680202064, 0.45105879141128646`, 0.21405151473609035`],
              UndirectedEdge[22, 275] -> 
             RGBColor[
              0.43256024452096153`, 0.549083675519183, 0.9487833341762382], 
             UndirectedEdge[160, 324] -> 
             RGBColor[
              0.3960795993510239, 0.5174859742435227, 0.9464588197245776], 
             UndirectedEdge[191, 218] -> 
             RGBColor[
              0.2251871593264507, 0.3540163605156067, 0.9361354476378685], 
             UndirectedEdge[349, 397] -> 
             RGBColor[
              0.38607476166702576`, 0.5088202866994067, 0.9458213203142838], 
             UndirectedEdge[401, 454] -> 
             RGBColor[
              0.8366674019364873, 0.7306087240183134, 0.6081129719353302], 
             UndirectedEdge[311, 349] -> 
             RGBColor[
              0.5802291691633081, 0.667416033439714, 0.9614893343765445], 
             UndirectedEdge[63, 324] -> 
             RGBColor[
              0.3945065223315428, 0.5161234539943981, 0.9463585846479137], 
             UndirectedEdge[22, 353] -> 
             RGBColor[
              0.5455395337034719, 0.641880966146923, 0.9573802823215901], 
             UndirectedEdge[93, 437] -> 
             RGBColor[
              0.26255787085876586`, 0.3932953477760335, 0.9382636543746206], 
             UndirectedEdge[417, 461] -> 
             RGBColor[
              0.8227440842305245, 0.8622334494485463, 0.9748712810946092], 
             UndirectedEdge[151, 249] -> 
             RGBColor[
              0.29817109629594896`, 0.43072710571942197`, 0.9402917748782225],
              UndirectedEdge[148, 452] -> 
             RGBColor[
              0.23180463347080354`, 0.3609717454134156, 0.9365123030007138], 
             UndirectedEdge[262, 424] -> 
             RGBColor[
              0.39834012297090404`, 0.5188257266580119, 0.9467736686621999], 
             UndirectedEdge[50, 139] -> 
             RGBColor[
              0.50248660335272, 0.6066441419253559, 0.9540696105134843], 
             UndirectedEdge[237, 267] -> 
             RGBColor[
              0.9475774996267206, 0.9513626199375382, 0.7014579081154306], 
             UndirectedEdge[256, 442] -> 
             RGBColor[
              0.28666573187167776`, 0.4186342382272755, 0.9396365613949216], 
             UndirectedEdge[60, 133] -> 
             RGBColor[
              0.31894163191943015`, 0.44919026900604586`, 0.9415979446419711],
              UndirectedEdge[77, 156] -> 
             RGBColor[
              0.5370635204917655, 0.6350513862279201, 0.9566987541430614], 
             UndirectedEdge[219, 498] -> 
             RGBColor[
              0.49407920545967077`, 0.6001547828635406, 0.9533148714070008], 
             UndirectedEdge[102, 185] -> 
             RGBColor[
              0.28024115314486164`, 0.4118815986435736, 0.9392706911407418], 
             UndirectedEdge[92, 169] -> 
             RGBColor[
              0.5509398864490034, 0.6463168452351683, 0.9577911525020184], 
             UndirectedEdge[53, 357] -> 
             RGBColor[
              0.9418272950686917, 0.8009948820936315, 0.3036989405074137], 
             UndirectedEdge[162, 289] -> 
             RGBColor[
              0.45070123455015054`, 0.5645598995943251, 0.9500046324572284], 
             UndirectedEdge[169, 204] -> 
             RGBColor[
              0.4973176178268257, 0.6027838719120118, 0.9535698110912385], 
             UndirectedEdge[176, 448] -> 
             RGBColor[
              0.587441960125221, 0.6759508730452015, 0.9606647294533119], 
             UndirectedEdge[377, 403] -> 
             RGBColor[
              0.9550085431684978, 0.9657910070072111, 0.9549749729457403], 
             UndirectedEdge[86, 357] -> 
             RGBColor[
              0.911167687629582, 0.6855165136042474, 0.2473816401856394], 
             UndirectedEdge[12, 373] -> 
             RGBColor[
              0.28300945147034123`, 0.414791255703904, 0.9394283416350475], 
             UndirectedEdge[200, 469] -> 
             RGBColor[
              0.8806293426662699, 0.5508475494204266, 0.22210653628922422`], 
             UndirectedEdge[112, 153] -> 
             RGBColor[
              0.24659824483285725`, 0.37652076892406894`, 0.9373547772825959],
              UndirectedEdge[166, 243] -> 
             RGBColor[
              0.838713260625803, 0.29857266219470613`, 0.18470516813663024`], 
             UndirectedEdge[394, 460] -> 
             RGBColor[
              0.23849436642390026`, 0.3680030789006874, 0.9368932733958195], 
             UndirectedEdge[18, 348] -> 
             RGBColor[
              0.9221477650002106, 0.7221653986171828, 0.2620020254952798], 
             UndirectedEdge[315, 325] -> 
             RGBColor[
              0.1822582683189515, 0.30889537421782864`, 0.9336907108025945], 
             UndirectedEdge[195, 447] -> 
             RGBColor[
              0.25832593618087096`, 0.38884731610940987`, 0.9380226519553008],
              UndirectedEdge[128, 204] -> 
             RGBColor[
              0.4983181319181479, 0.6035961343239933, 0.9536485752255113], 
             UndirectedEdge[91, 435] -> 
             RGBColor[
              0.29287326479962417`, 0.4234129007814571, 0.9400539952643586], 
             UndirectedEdge[158, 206] -> 
             RGBColor[
              0.3501277440364893, 0.4776847867774757, 0.9435308081375656], 
             UndirectedEdge[30, 290] -> 
             RGBColor[
              0.2772082322816696, 0.40869380651806936`, 0.9390979707843874], 
             UndirectedEdge[2, 250] -> 
             RGBColor[
              0.20844651025640323`, 0.33642087692453115`, 0.9351820924389003],
              UndirectedEdge[148, 195] -> 
             RGBColor[
              0.2549038837878154, 0.3852505220736551, 0.9378277711339891], 
             UndirectedEdge[5, 202] -> 
             RGBColor[
              0.23883220085490312`, 0.3683581643076115, 0.9369125125668838], 
             UndirectedEdge[220, 359] -> 
             RGBColor[
              0.3621822341604067, 0.48812578024652276`, 0.9442989095888945], 
             UndirectedEdge[175, 337] -> 
             RGBColor[
              0.9079704822927377, 0.9289384814961321, 0.9731750764283525], 
             UndirectedEdge[263, 447] -> 
             RGBColor[
              0.2599502995006695, 0.3905546249491011, 0.938115157043333], 
             UndirectedEdge[344, 387] -> 
             RGBColor[
              0.6194283934274943, 0.6998852662527452, 0.9645732255440658], 
             UndirectedEdge[82, 470] -> 
             RGBColor[
              0.25688036525862096`, 0.38732792941563493`, 0.937940328829809], 
             UndirectedEdge[273, 446] -> 
             RGBColor[
              0.26084634450324296`, 0.39149642505934035`, 0.9381661854806498],
              UndirectedEdge[68, 306] -> 
             RGBColor[
              0.8387829864974263, 0.2991086057980758, 0.18477193771004097`], 
             UndirectedEdge[21, 33] -> 
             RGBColor[
              0.9296510090196749, 0.7439907144053559, 0.3002556094938443], 
             UndirectedEdge[77, 479] -> 
             RGBColor[
              0.5091542746403608, 0.6112576931750507, 0.9548154361242309], 
             UndirectedEdge[253, 311] -> 
             RGBColor[
              0.8659443575362178, 0.8951239135712197, 0.9365639679939195], 
             UndirectedEdge[308, 386] -> 
             RGBColor[
              0.17893664238380538`, 0.3054041347567419, 0.9335015491194931], 
             UndirectedEdge[151, 280] -> 
             RGBColor[
              0.2818433506476452, 0.4135656098041881, 0.9393619339182866], 
             UndirectedEdge[305, 416] -> 
             RGBColor[
              0.2563227786802443, 0.3867418705687301, 0.9379085750990459], 
             UndirectedEdge[38, 189] -> 
             RGBColor[
              0.2598720197723208, 0.3904723479913851, 0.9381106991286081], 
             UndirectedEdge[277, 291] -> 
             RGBColor[
              0.7131143362098424, 0.7758096064076011, 0.9720402306671867], 
             UndirectedEdge[27, 40] -> 
             RGBColor[
              0.44915953688308596`, 0.5618645655130168, 0.9502821669769903], 
             UndirectedEdge[88, 167] -> 
             RGBColor[
              0.9266401906833595, 0.7379726928092079, 0.5404902319838795], 
             UndirectedEdge[89, 296] -> 
             RGBColor[
              0.2994607686458766, 0.4316505064958615, 0.9403810420835206], 
             UndirectedEdge[169, 340] -> 
             RGBColor[
              0.41508837309382146`, 0.5328799596159772, 0.9479658129994224], 
             UndirectedEdge[169, 363] -> 
             RGBColor[
              0.44877677089386697`, 0.5620591565622703, 0.9501124079177607], 
             UndirectedEdge[43, 378] -> 
             RGBColor[
              0.2881161193118442, 0.42015868738676554`, 0.939719158813983], 
             UndirectedEdge[350, 482] -> 
             RGBColor[
              0.36032571563534044`, 0.4865177572114446, 0.9441806138701323], 
             UndirectedEdge[199, 429] -> 
             RGBColor[
              0.318220922727511, 0.44864816272084596`, 0.9415490142958283], 
             UndirectedEdge[135, 216] -> 
             RGBColor[
              0.25825637493020664`, 0.38877420282452363`, 0.938018690544982], 
             UndirectedEdge[153, 351] -> 
             RGBColor[
              0.267489207183899, 0.39847849491853005`, 0.9385444866830785], 
             UndirectedEdge[207, 218] -> 
             RGBColor[
              0.22451796602725682`, 0.35331299592884813`, 0.9360973380694622],
              UndirectedEdge[218, 389] -> 
             RGBColor[
              0.22523636007401557`, 0.35406807362080495`, 0.9361382495476563],
              UndirectedEdge[421, 477] -> 
             RGBColor[
              0.21186411660990806`, 0.34001299789082284`, 0.9353767200648369],
              UndirectedEdge[171, 391] -> 
             RGBColor[
              0.25143472628896596`, 0.3816042175850748, 0.9376302077465881], 
             UndirectedEdge[25, 246] -> 
             RGBColor[
              0.3037983452782409, 0.43621369244109887`, 0.940627909879872], 
             UndirectedEdge[130, 254] -> 
             RGBColor[
              0.20771262472504887`, 0.3356495167000475, 0.935140298743576], 
             UndirectedEdge[65, 434] -> 
             RGBColor[
              0.9883337030612244, 0.9766308233101144, 0.5967468015081936], 
             UndirectedEdge[174, 430] -> 
             RGBColor[
              0.2531980668507343, 0.38345760031774234`, 0.9377306273829522], 
             UndirectedEdge[213, 454] -> 
             RGBColor[
              0.902044161930851, 0.6480872421427781, 0.23997558640884487`], 
             UndirectedEdge[52, 495] -> 
             RGBColor[
              0.8389987580384334, 0.3007671204139477, 0.18497856078138836`], 
             UndirectedEdge[26, 224] -> 
             RGBColor[
              0.34279791451999597`, 0.4704318560417961, 0.9430968651035153], 
             UndirectedEdge[8, 31] -> 
             RGBColor[
              0.5366659458722182, 0.6347210217205881, 0.9566695542776334], 
             UndirectedEdge[29, 321] -> 
             RGBColor[
              0.3713978817482214, 0.49610791099517215`, 0.944886122504113], 
             UndirectedEdge[319, 377] -> 
             RGBColor[
              0.8479973976544979, 0.8813126625416667, 0.9445427395689829], 
             UndirectedEdge[323, 447] -> 
             RGBColor[
              0.24292230663621342`, 0.3726571248114532, 0.9371454380403603], 
             UndirectedEdge[13, 340] -> 
             RGBColor[
              0.3170254114231826, 0.44789173278801986`, 0.9414626195505558], 
             UndirectedEdge[176, 237] -> 
             RGBColor[
              0.7565184993634433, 0.8098707472801487, 0.9765525722729846], 
             UndirectedEdge[22, 268] -> 
             RGBColor[
              0.4305356531895016, 0.5473300762667914, 0.9486543290068734], 
             UndirectedEdge[461, 493] -> 
             RGBColor[
              0.9690163833229786, 0.9733831615410689, 0.7606045943611018], 
             UndirectedEdge[401, 450] -> 
             RGBColor[
              0.7955804305647025, 0.4800334417304184, 0.5713225662708019], 
             UndirectedEdge[100, 200] -> 
             RGBColor[
              0.9160214299715226, 0.703780905297789, 0.25123642844933736`], 
             UndirectedEdge[197, 375] -> 
             RGBColor[
              0.8279135305907634, 0.8660284937370616, 0.9630673509377192], 
             UndirectedEdge[94, 401] -> 
             RGBColor[
              0.8644357283380311, 0.8946091728083778, 0.9692011064141851], 
             UndirectedEdge[118, 327] -> 
             RGBColor[
              0.2910886324434072, 0.42177019876942656`, 0.9399438296328053], 
             UndirectedEdge[44, 255] -> 
             RGBColor[
              0.44713138767076954`, 0.5605271620680575, 0.9500370874897843], 
             UndirectedEdge[148, 356] -> 
             RGBColor[
              0.2544968866209464, 0.384822742246165, 0.9378045932474341], 
             UndirectedEdge[26, 34] -> 
             RGBColor[
              0.46519130263863967`, 0.5748915338435057, 0.9515410249790447], 
             UndirectedEdge[244, 313] -> 
             RGBColor[
              0.3046994618698019, 0.43447349621750786`, 0.9407776233385161], 
             UndirectedEdge[331, 488] -> 
             RGBColor[
              0.8030279977952235, 0.8461858842867422, 0.9809661481473407], 
             UndirectedEdge[382, 429] -> 
             RGBColor[
              0.2879113316712099, 0.41994344259217253`, 0.9397074964608051], 
             UndirectedEdge[409, 496] -> 
             RGBColor[
              0.25922260246551676`, 0.38978976922649866`, 0.9380737157737123],
              UndirectedEdge[14, 324] -> 
             RGBColor[
              0.33821006500838097`, 0.4671770715883025, 0.9427782060023248], 
             UndirectedEdge[259, 471] -> 
             RGBColor[
              0.8593266411159032, 0.451612346510198, 0.20423296567103144`], 
             UndirectedEdge[178, 439] -> 
             RGBColor[
              0.9262985601874452, 0.9413808299607197, 0.8870332114673454], 
             UndirectedEdge[127, 454] -> 
             RGBColor[
              0.562931118749189, 0.49656039652436856`, 0.5871761845581333], 
             UndirectedEdge[190, 452] -> 
             RGBColor[
              0.2360315215156537, 0.3654144727487341, 0.9367530180217474], 
             UndirectedEdge[218, 295] -> 
             RGBColor[
              0.2307804101674582, 0.3598952217820915, 0.9364539749987908], 
             UndirectedEdge[35, 67] -> 
             RGBColor[
              0.24749774961125026`, 0.377466205478057, 0.9374060027490273], 
             UndirectedEdge[192, 249] -> 
             RGBColor[
              0.27208125411189216`, 0.40330502739244223`, 0.938805996962303], 
             UndirectedEdge[186, 202] -> 
             RGBColor[
              0.2373837352876954, 0.3668357351584549, 0.9368300245956442], 
             UndirectedEdge[243, 469] -> 
             RGBColor[
              0.8498683936659192, 0.3811298439450528, 0.19526257805333647`], 
             UndirectedEdge[48, 183] -> 
             RGBColor[
              0.20623910902756293`, 0.3341007582756985, 0.9350563842044752], 
             UndirectedEdge[255, 390] -> 
             RGBColor[
              0.3491694965791283, 0.4761158367358585, 0.9434968065582812], 
             UndirectedEdge[202, 497] -> 
             RGBColor[
              0.23752535161991525`, 0.36698458290261204`, 0.9368380894362616],
              UndirectedEdge[84, 365] -> 
             RGBColor[
              0.22514447908377305`, 0.3539715008744688, 0.9361330170611878], 
             UndirectedEdge[239, 262] -> 
             RGBColor[
              0.41350816527111056`, 0.531963522530478, 0.947740162904996], 
             UndirectedEdge[299, 456] -> 
             RGBColor[
              0.21641245264037934`, 0.34479358744000865`, 0.935635741073112], 
             UndirectedEdge[136, 253] -> 
             RGBColor[
              0.9769962544035893, 0.9822248956493935, 0.9175751236598007], 
             UndirectedEdge[338, 478] -> 
             RGBColor[
              0.29307363534810826`, 0.42431910359583813`, 0.9400399367228911],
              UndirectedEdge[284, 444] -> 
             RGBColor[
              0.25819284063858217`, 0.3887074242557196, 0.9380150723610645], 
             UndirectedEdge[135, 147] -> 
             RGBColor[
              0.2510599689447852, 0.3812103238553528, 0.9376088658702408], 
             UndirectedEdge[72, 73] -> 
             RGBColor[
              0.2509474629421924, 0.38109207291333524`, 0.9376024588198308], 
             UndirectedEdge[8, 291] -> 
             RGBColor[
              0.637610384777719, 0.7164873323549865, 0.9647458039813404], 
             UndirectedEdge[141, 240] -> 
             RGBColor[
              0.2831042170303842, 0.4148134850118461, 0.939436571482416], 
             UndirectedEdge[9, 466] -> 
             RGBColor[
              0.5393259259475076, 0.6368881088970959, 0.9568768589880016], 
             UndirectedEdge[78, 346] -> 
             RGBColor[
              0.21865587786091514`, 0.34715156958816623`, 0.9357635008205714],
              UndirectedEdge[255, 425] -> 
             RGBColor[
              0.38646418769848023`, 0.5091575879547311, 0.9458461341966522], 
             UndirectedEdge[297, 349] -> 
             RGBColor[
              0.4664828396818328, 0.5766724130185215, 0.9514403486819383], 
             UndirectedEdge[248, 478] -> 
             RGBColor[
              0.25429079969208646`, 0.3846061318172672, 0.9377928569017139], 
             UndirectedEdge[113, 130] -> 
             RGBColor[
              0.17905963034776856`, 0.3055334029047545, 0.9335085531020964], 
             UndirectedEdge[51, 179] -> 
             RGBColor[
              0.1789280689363169, 0.30539512351984355`, 0.9335010608743419], 
             UndirectedEdge[440, 470] -> 
             RGBColor[
              0.2685779731534025, 0.3996228569842277, 0.9386064902943567], 
             UndirectedEdge[5, 414] -> 
             RGBColor[
              0.2566326545868817, 0.38706756979387325`, 0.9379262220735086], 
             UndirectedEdge[148, 463] -> 
             RGBColor[
              0.25337660171868737`, 0.3836452517837254, 0.9377407946795635], 
             UndirectedEdge[63, 441] -> 
             RGBColor[
              0.4347339982883702, 0.5509664717764713, 0.9489218438441225], 
             UndirectedEdge[163, 187] -> 
             RGBColor[
              0.2658102034815037, 0.3967137555723293, 0.9384488699060904], 
             UndirectedEdge[120, 177] -> 
             RGBColor[
              0.20805903153131503`, 0.3360136122168933, 0.9351600260987298], 
             UndirectedEdge[450, 454] -> 
             RGBColor[
              0.8587954548220276, 0.3876960227591984, 0.20138137545633958`], 
             UndirectedEdge[15, 190] -> 
             RGBColor[
              0.24117420601353035`, 0.37081976022103225`, 0.9370458862959816],
              UndirectedEdge[191, 287] -> 
             RGBColor[
              0.21410654860741013`, 0.342369936098598, 0.9355044232497137], 
             UndirectedEdge[179, 292] -> 
             RGBColor[
              0.17894988462017136`, 0.30541805318676885`, 0.9335023032452641],
              UndirectedEdge[291, 297] -> 
             RGBColor[
              0.5871456749634538, 0.6755178075184964, 0.9607730371664382], 
             UndirectedEdge[289, 397] -> 
             RGBColor[
              0.39895955278042317`, 0.5199804451534001, 0.9466423278104561], 
             UndirectedEdge[175, 370] -> 
             RGBColor[
              0.7735868010178651, 0.822851827878325, 0.9604005134157099], 
             UndirectedEdge[23, 186] -> 
             RGBColor[
              0.22910595895914918`, 0.35813526739582024`, 0.9363586174796061],
              UndirectedEdge[241, 461] -> 
             RGBColor[
              0.8249688230204753, 0.8639714322998968, 0.9750930222658254], 
             UndirectedEdge[157, 216] -> 
             RGBColor[
              0.28421479544229167`, 0.41605814864164575`, 0.9394969841911034],
              UndirectedEdge[51, 302] -> 
             RGBColor[
              0.18453817957609825`, 0.31129170550381263`, 0.9338205483758626],
              UndirectedEdge[174, 390] -> 
             RGBColor[
              0.28370528761633407`, 0.41552262361190234`, 0.9394679684741645],
              UndirectedEdge[79, 406] -> 
             RGBColor[
              0.9922235479450122, 0.984612153776488, 0.4938632532617516], 
             UndirectedEdge[181, 235] -> 
             RGBColor[
              0.38886946031407776`, 0.511240914201845, 0.9459993960408191], 
             UndirectedEdge[78, 404] -> 
             RGBColor[
              0.2164387033219317, 0.3448211785707095, 0.935637236010592], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.2711970471587578, 0.4023756698227392, 0.938755642684389], 
             UndirectedEdge[43, 384] -> 
             RGBColor[
              0.28848430619933074`, 0.4205456751499109, 0.9397401265125418], 
             UndirectedEdge[101, 363] -> 
             RGBColor[
              0.4628220425559936, 0.5734617408298626, 0.9512181031525286], 
             UndirectedEdge[120, 455] -> 
             RGBColor[
              0.2056810719300792, 0.33351422590464763`, 0.9350246048173154], 
             UndirectedEdge[295, 456] -> 
             RGBColor[
              0.22662320577002346`, 0.355525736378405, 0.9362172283583896], 
             UndirectedEdge[58, 240] -> 
             RGBColor[
              0.2858686487739417, 0.41720789684373627`, 0.9396127186286245], 
             UndirectedEdge[39, 471] -> 
             RGBColor[
              0.7402370852900231, 0.5715237918221177, 0.5827765854569318], 
             UndirectedEdge[54, 365] -> 
             RGBColor[
              0.22284773098411328`, 0.35155747299948614`, 0.9360022206546466],
              UndirectedEdge[169, 334] -> 
             RGBColor[
              0.44777313143376407`, 0.5611898545063152, 0.9500484568988465], 
             UndirectedEdge[18, 65] -> 
             RGBColor[
              0.9349243740088637, 0.7652639008938271, 0.3116367388337401], 
             UndirectedEdge[384, 435] -> 
             RGBColor[
              0.2709692417504848, 0.4021362318949472, 0.9387426695033958], 
             UndirectedEdge[9, 360] -> 
             RGBColor[
              0.5772550006439877, 0.6676806404210414, 0.9598627746868871], 
             UndirectedEdge[135, 171] -> 
             RGBColor[
              0.25618449679905386`, 0.3865965275440213, 0.9379007001504819], 
             UndirectedEdge[149, 187] -> 
             RGBColor[
              0.30925143443909986`, 0.4382007802607746, 0.9410755580672832], 
             UndirectedEdge[271, 464] -> 
             RGBColor[
              0.24983604138275278`, 0.37992389838616725`, 0.9375391650062217],
              UndirectedEdge[21, 348] -> 
             RGBColor[
              0.9703996877499586, 0.911813337676092, 0.3395088057688662], 
             UndirectedEdge[1, 70] -> 
             RGBColor[
              0.26220782647507634`, 0.3929274289346799, 0.9382437198648137], 
             UndirectedEdge[52, 276] -> 
             RGBColor[
              0.7276676005214341, 0.4890758052767825, 0.5725511491543327], 
             UndirectedEdge[58, 429] -> 
             RGBColor[
              0.3043548555603097, 0.4366380722694161, 0.9406654807572159], 
             UndirectedEdge[243, 495] -> 
             RGBColor[
              0.8407542903650291, 0.31426091115533294`, 0.1866596605199266], 
             UndirectedEdge[131, 135] -> 
             RGBColor[
              0.25711790914467114`, 0.38757760310102596`, 0.937953856602705], 
             UndirectedEdge[145, 430] -> 
             RGBColor[
              0.23019859628253192`, 0.35928369849990305`, 0.9364208415587607],
              UndirectedEdge[291, 419] -> 
             RGBColor[
              0.583808838050422, 0.6728088129897074, 0.960510349141408], 
             UndirectedEdge[151, 260] -> 
             RGBColor[
              0.2961853765948359, 0.4286399884116514, 0.940178691078853], 
             UndirectedEdge[189, 437] -> 
             RGBColor[
              0.25780291323833093`, 0.38829758583523044`, 0.9379928665724662],
              UndirectedEdge[196, 354] -> 
             RGBColor[
              0.32873158920795986`, 0.45794625952520507`, 0.9422116309155903],
              UndirectedEdge[340, 355] -> 
             RGBColor[
              0.3330706823231735, 0.4629108172342508, 0.9424439472481606], 
             UndirectedEdge[58, 310] -> 
             RGBColor[
              0.3059344073310527, 0.43829828132983367`, 0.9407554338938223], 
             UndirectedEdge[261, 500] -> 
             RGBColor[
              0.8497397394109806, 0.34938235459205963`, 0.19393494909850834`],
              UndirectedEdge[237, 270] -> 
             RGBColor[
              0.9480577404464491, 0.9590498999175098, 0.9029559373872008], 
             UndirectedEdge[23, 497] -> 
             RGBColor[
              0.22924757529136902`, 0.3582841151399774, 0.9363666823202235], 
             UndirectedEdge[431, 462] -> 
             RGBColor[
              0.4562091477173884, 0.5692804281616477, 0.9503694481270373], 
             UndirectedEdge[108, 129] -> 
             RGBColor[
              0.3203552344901264, 0.4497120899906687, 0.9417137426958612], 
             UndirectedEdge[376, 485] -> 
             RGBColor[
              0.26372814560153673`, 0.3945253807303899, 0.938330299789955], 
             UndirectedEdge[124, 261] -> 
             RGBColor[
              0.9213196831594281, 0.7168052052597729, 0.265491517223669], 
             UndirectedEdge[63, 158] -> 
             RGBColor[
              0.38842846253649266`, 0.5108589440920934, 0.9459712960523903], 
             UndirectedEdge[66, 427] -> 
             RGBColor[
              0.271390600085227, 0.40257910622042264`, 0.9387666652372155], 
             UndirectedEdge[66, 208] -> 
             RGBColor[
              0.2926997987840062, 0.4237400438284219, 0.9400254625551399], 
             UndirectedEdge[54, 230] -> 
             RGBColor[
              0.22629940994459397`, 0.3551854064360376, 0.9361987886651444], 
             UndirectedEdge[186, 295] -> 
             RGBColor[
              0.23264914651192115`, 0.36185938216484964`, 0.9365603967690603],
              UndirectedEdge[245, 394] -> 
             RGBColor[
              0.22510267482771082`, 0.3539275619508045, 0.936130636370649], 
             UndirectedEdge[49, 459] -> 
             RGBColor[
              0.44038041665413563`, 0.554855283237734, 0.9495584378871766], 
             UndirectedEdge[55, 365] -> 
             RGBColor[
              0.21422616460620378`, 0.3424956600974225, 0.935511235203889], 
             UndirectedEdge[197, 448] -> 
             RGBColor[
              0.6327824685500147, 0.7119137261765637, 0.9648129350991647], 
             UndirectedEdge[185, 321] -> 
             RGBColor[
              0.30856010126890854`, 0.43938793879419913`, 0.9409661143099544],
              UndirectedEdge[242, 339] -> 
             RGBColor[
              0.21834915626655288`, 0.34682918574521915`, 0.9357460334795263],
              UndirectedEdge[186, 191] -> 
             RGBColor[
              0.22705589567091367`, 0.35598052089836485`, 0.936241869408138], 
             UndirectedEdge[218, 456] -> 
             RGBColor[
              0.2278157330596809, 0.3567791581704322, 0.9362851410233497], 
             UndirectedEdge[63, 182] -> 
             RGBColor[
              0.3989611276124065, 0.5199818091937107, 0.9466424281573576], 
             UndirectedEdge[133, 181] -> 
             RGBColor[
              0.3829354312034995, 0.5061011564392373, 0.9456212849531489], 
             UndirectedEdge[11, 186] -> 
             RGBColor[
              0.23731427099118235`, 0.3667627237785289, 0.936826068706721], 
             UndirectedEdge[105, 148] -> 
             RGBColor[
              0.24278055645410443`, 0.37250813638257607`, 0.9371373655771897],
              UndirectedEdge[235, 393] -> 
             RGBColor[
              0.40912660425444114`, 0.5285723075143651, 0.947349382422311], 
             UndirectedEdge[110, 290] -> 
             RGBColor[
              0.2791002706073135, 0.4106824587604797, 0.9392057195680129], 
             UndirectedEdge[225, 296] -> 
             RGBColor[
              0.29383455667092717`, 0.42573700098774714`, 0.940060637634782], 
             UndirectedEdge[38, 93] -> 
             RGBColor[
              0.2646269773927557, 0.3954701099321881, 0.9383814869307624], 
             UndirectedEdge[80, 486] -> 
             RGBColor[
              0.8622352558727102, 0.8932330485230531, 0.9866566699988166], 
             UndirectedEdge[471, 500] -> 
             RGBColor[
              0.8381526226622067, 0.29426335313338325`, 0.18416830058954048`],
              UndirectedEdge[200, 213] -> 
             RGBColor[
              0.9025169525103827, 0.6502340737413859, 0.24037009445756363`], 
             UndirectedEdge[191, 295] -> 
             RGBColor[
              0.22399463203679326`, 0.35276293872357944`, 0.9360675349729086],
              UndirectedEdge[295, 300] -> 
             RGBColor[
              0.22777276498654234`, 0.3567339960012304, 0.9362826940551499], 
             UndirectedEdge[191, 451] -> 
             RGBColor[
              0.21492359957141377`, 0.343228708465789, 0.9355509530933952], 
             UndirectedEdge[137, 145] -> 
             RGBColor[
              0.2203693542453783, 0.34895254190891456`, 0.9358610807658054], 
             UndirectedEdge[332, 344] -> 
             RGBColor[
              0.4329675168621825, 0.5491533716913533, 0.9488874962659426], 
             UndirectedEdge[76, 392] -> 
             RGBColor[
              0.35866334703698777`, 0.48482413936361163`, 0.9440839805262493],
              UndirectedEdge[157, 465] -> 
             RGBColor[
              0.2925845958094424, 0.42485533950351484`, 0.9399736319400027], 
             UndirectedEdge[204, 337] -> 
             RGBColor[
              0.6810518757467315, 0.7489355468683991, 0.970229432274497], 
             UndirectedEdge[112, 395] -> 
             RGBColor[
              0.2566255492107321, 0.38706010159303317`, 0.9379258174328484], 
             UndirectedEdge[51, 107] -> 
             RGBColor[
              0.18179934664985797`, 0.3084130184462969, 0.9336645758924533], 
             UndirectedEdge[5, 41] -> 
             RGBColor[
              0.23556700835298144`, 0.36492623996293, 0.9367265646843188], 
             UndirectedEdge[88, 210] -> 
             RGBColor[
              0.8513369203215293, 0.3826983248089265, 0.19628825904818903`], 
             UndirectedEdge[248, 411] -> 
             RGBColor[
              0.2410648104835609, 0.37070477858295714`, 0.937039656382386], 
             UndirectedEdge[101, 128] -> 
             RGBColor[
              0.5077879700548952, 0.6112841755347511, 0.9543940755727961], 
             UndirectedEdge[298, 418] -> 
             RGBColor[
              0.9400566522436402, 0.9539366372768199, 0.955901674523727], 
             UndirectedEdge[1, 391] -> 
             RGBColor[
              0.25364635844324135`, 0.38392878320479584`, 0.9377561569259576],
              UndirectedEdge[116, 327] -> 
             RGBColor[
              0.25289755432094124`, 0.38314174259533496`, 0.937713513638949], 
             UndirectedEdge[79, 81] -> 
             RGBColor[
              0.9087234308797807, 0.9257016701540246, 0.7763552620147077], 
             UndirectedEdge[254, 368] -> 
             RGBColor[
              0.32229994971598047`, 0.44690195182710835`, 0.9420022258236223],
              UndirectedEdge[4, 318] -> 
             RGBColor[
              0.33312298494508064`, 0.46295611913654056`, 0.9424472799249791],
              UndirectedEdge[352, 412] -> 
             RGBColor[
              0.23510619043035305`, 0.36444189110870373`, 0.9367003217853442],
              UndirectedEdge[239, 424] -> 
             RGBColor[
              0.3357624743157177, 0.4652423121647933, 0.9426154658536674], 
             UndirectedEdge[58, 188] -> 
             RGBColor[
              0.32619444448890195`, 0.45695496563196736`, 0.9420057994537792],
              UndirectedEdge[407, 408] -> 
             RGBColor[
              0.2184314377890148, 0.3469156688422765, 0.9357507192905059], 
             UndirectedEdge[255, 466] -> 
             RGBColor[
              0.45054684949746193`, 0.5632999878437683, 0.9503059651560305], 
             UndirectedEdge[197, 489] -> 
             RGBColor[
              0.843861608566709, 0.8769414103999965, 0.8921342396544271], 
             UndirectedEdge[50, 363] -> 
             RGBColor[
              0.422874692158388, 0.5406945368727382, 0.9481661793442926], 
             UndirectedEdge[57, 175] -> 
             RGBColor[
              0.7784866261079177, 0.8268297266210345, 0.9607862455954495], 
             UndirectedEdge[278, 486] -> 
             RGBColor[
              0.9416456695144926, 0.9559801240610102, 0.9829731602176706], 
             UndirectedEdge[82, 263] -> 
             RGBColor[
              0.26583963752085393`, 0.39674469261391226`, 0.9384505461310877],
              UndirectedEdge[41, 186] -> 
             RGBColor[
              0.23411854278577374`, 0.36340381081377343`, 0.9366440767130793],
              UndirectedEdge[390, 425] -> 
             RGBColor[
              0.3380481584260487, 0.4664830926023694, 0.94278816472538], 
             UndirectedEdge[218, 458] -> 
             RGBColor[
              0.23123609658963368`, 0.36037417710398584`, 0.936479925666406], 
             UndirectedEdge[230, 374] -> 
             RGBColor[
              0.23780417240741958`, 0.3672776412285381, 0.9368539678676315], 
             UndirectedEdge[104, 408] -> 
             RGBColor[
              0.23453910043567894`, 0.36384584356871885`, 0.9366680268490819],
              UndirectedEdge[121, 213] -> 
             RGBColor[
              0.86583591956703, 0.4350120088827739, 0.20785705715207875`], 
             UndirectedEdge[143, 421] -> 
             RGBColor[
              0.1789918035644768, 0.3054621126550484, 0.9335046904671287], 
             UndirectedEdge[185, 482] -> 
             RGBColor[
              0.32121309396000997`, 0.4503473251053272, 0.9417723518156291], 
             UndirectedEdge[256, 333] -> 
             RGBColor[
              0.3340176365315557, 0.4619410698643276, 0.9425698252260324], 
             UndirectedEdge[351, 463] -> 
             RGBColor[
              0.27857140569147526`, 0.4101265882019613, 0.9391756014934415], 
             UndirectedEdge[42, 411] -> 
             RGBColor[
              0.23603211668449622`, 0.3654150983089235, 0.9367530519157325], 
             UndirectedEdge[52, 243] -> 
             RGBColor[
              0.837550577025578, 0.2896357665521757, 0.18359178100799164`], 
             UndirectedEdge[385, 391] -> 
             RGBColor[
              0.23729940724147955`, 0.36674710103517516`, 0.9368252222381643],
              UndirectedEdge[366, 435] -> 
             RGBColor[
              0.2615619901606841, 0.3922486140198663, 0.9382069404421383], 
             UndirectedEdge[114, 419] -> 
             RGBColor[
              0.5066845097134336, 0.6103883367192307, 0.9543072071326079], 
             UndirectedEdge[67, 391] -> 
             RGBColor[
              0.24887514925956578`, 0.37891393984061833`, 0.9374844436213188],
              UndirectedEdge[310, 327] -> 
             RGBColor[
              0.2769131154519483, 0.40838362001854456`, 0.939081164317521], 
             UndirectedEdge[309, 348] -> 
             RGBColor[
              0.976471187338104, 0.9319682118150352, 0.39079228120582354`], 
             UndirectedEdge[28, 194] -> 
             RGBColor[
              0.9756860818103763, 0.9810011844305191, 0.9087502503850045], 
             UndirectedEdge[92, 337] -> 
             RGBColor[
              0.7346741443689091, 0.7924685201915558, 0.974450773685277], 
             UndirectedEdge[205, 432] -> 
             RGBColor[
              0.9462255159241673, 0.9556033712696023, 0.7798152269955922], 
             UndirectedEdge[314, 398] -> 
             RGBColor[
              0.29561326424229706`, 0.426066606556162, 0.9402183167389095], 
             UndirectedEdge[235, 453] -> 
             RGBColor[
              0.32067427818872773`, 0.4499141070194098, 0.9417367931922191], 
             UndirectedEdge[92, 334] -> 
             RGBColor[
              0.505970833581321, 0.6084373708863062, 0.9546299931971096], 
             UndirectedEdge[35, 54] -> 
             RGBColor[
              0.23354661261843296`, 0.36280267594543125`, 0.936611506136144], 
             UndirectedEdge[191, 456] -> 
             RGBColor[
              0.22102995492901595`, 0.34964687511192016`, 0.9358987009974674],
              UndirectedEdge[78, 137] -> 
             RGBColor[
              0.21975482034818994`, 0.34830662781927, 0.9358260839694819], 
             UndirectedEdge[57, 169] -> 
             RGBColor[
              0.5469925860365322, 0.6431122489364671, 0.9574804065541109], 
             UndirectedEdge[343, 392] -> 
             RGBColor[
              0.29944445035868683`, 0.4320654815746701, 0.9403642905083368], 
             UndirectedEdge[24, 197] -> 
             RGBColor[
              0.7672988184851579, 0.8182762435725834, 0.9774043962108645], 
             UndirectedEdge[450, 471] -> 
             RGBColor[
              0.8372605332410615, 0.2874063629263848, 0.183314034752381], 
             UndirectedEdge[150, 267] -> 
             RGBColor[
              0.9052536312416688, 0.5703031723537458, 0.2900897268509228], 
             UndirectedEdge[40, 371] -> 
             RGBColor[
              0.37457203795785354`, 0.49885720556622565`, 0.9450883769309946],
              UndirectedEdge[217, 362] -> 
             RGBColor[
              0.35409065029754605`, 0.481117256999343, 0.9437833210202597], 
             UndirectedEdge[229, 478] -> 
             RGBColor[
              0.27850887095594073`, 0.41006086022998334`, 0.9391720402327646],
              UndirectedEdge[100, 168] -> 
             RGBColor[
              0.9210035362936968, 0.7245123759551941, 0.25529579489782767`], 
             UndirectedEdge[221, 297] -> 
             RGBColor[
              0.5279871450253872, 0.627682775738259, 0.9559842286184892], 
             UndirectedEdge[50, 338] -> 
             RGBColor[
              0.3805216773222415, 0.5040104841460892, 0.9454674826902338], 
             UndirectedEdge[5, 186] -> 
             RGBColor[
              0.23715887571324926`, 0.36659939348879156`, 0.9368172191755294],
              UndirectedEdge[147, 391] -> 
             RGBColor[
              0.24631019843469731`, 0.37621801389640636`, 0.9373383734663472],
              UndirectedEdge[24, 426] -> 
             RGBColor[
              0.8535732035252862, 0.8860801191364223, 0.9858957682176778], 
             UndirectedEdge[100, 127] -> 
             RGBColor[
              0.5785973319473678, 0.5599231651764567, 0.5998463238378839], 
             UndirectedEdge[418, 432] -> 
             RGBColor[
              0.9385489798096075, 0.9527344602026001, 0.9557578713810538], 
             UndirectedEdge[200, 259] -> 
             RGBColor[
              0.8813343532764009, 0.5540488379416193, 0.22269481442370878`], 
             UndirectedEdge[17, 293] -> 
             RGBColor[
              0.9171217844286204, 0.9362730779745756, 0.9753514321588153], 
             UndirectedEdge[269, 468] -> 
             RGBColor[
              0.4636581822326119, 0.5753387348931303, 0.9509528669224259], 
             UndirectedEdge[154, 390] -> 
             RGBColor[
              0.30514733542854805`, 0.43798605336538, 0.9406917533770347], 
             UndirectedEdge[162, 439] -> 
             RGBColor[
              0.6614719504889517, 0.7330346033014116, 0.9686938737233264], 
             UndirectedEdge[103, 304] -> 
             RGBColor[
              0.4094598762170423, 0.5283411604549934, 0.947514243402197], 
             UndirectedEdge[3, 480] -> 
             RGBColor[
              0.4076066344287682, 0.5272434439758863, 0.9472559414401728], 
             UndirectedEdge[358, 404] -> 
             RGBColor[
              0.21953726017780179`, 0.34807795828608057`, 0.9358136942396298],
              UndirectedEdge[3, 439] -> 
             RGBColor[
              0.6612892589149015, 0.732886286051436, 0.9686794915733958], 
             UndirectedEdge[336, 458] -> 
             RGBColor[
              0.22636890121139194`, 0.35525844616344304`, 0.9362027460899854],
              UndirectedEdge[212, 287] -> 
             RGBColor[
              0.21416398383706822`, 0.3424303041665726, 0.9355076941010749], 
             UndirectedEdge[190, 195] -> 
             RGBColor[
              0.25913077183266553`, 0.38969324940897365`, 0.9380684861550228],
              UndirectedEdge[253, 377] -> 
             RGBColor[
              0.9830684787672088, 0.9867535506374262, 0.9072964317019494], 
             UndirectedEdge[192, 327] -> 
             RGBColor[
              0.25584189976103616`, 0.38623643633515786`, 0.9378811897559938],
              UndirectedEdge[151, 483] -> 
             RGBColor[
              0.3017217477257488, 0.43445906549644486`, 0.9404939792244313], 
             UndirectedEdge[38, 163] -> 
             RGBColor[
              0.2634804930859057, 0.3942650822343853, 0.9383161963455589], 
             UndirectedEdge[88, 227] -> 
             RGBColor[
              0.8561206468687188, 0.41946814329296433`, 0.20086916099222407`],
              UndirectedEdge[281, 343] -> 
             RGBColor[
              0.26889808498261325`, 0.3999593148129905, 0.9386247201894673], 
             UndirectedEdge[76, 157] -> 
             RGBColor[
              0.35693445553108405`, 0.4830069647728541, 0.9439855227126539], 
             UndirectedEdge[364, 437] -> 
             RGBColor[
              0.25719856867599794`, 0.38766238138256004`, 0.9379584500436889],
              UndirectedEdge[229, 244] -> 
             RGBColor[
              0.3167084139494082, 0.447095666264713, 0.9414615153937971], 
             UndirectedEdge[154, 425] -> 
             RGBColor[
              0.3424420265478999, 0.47102780458425264`, 0.9430410810154058], 
             UndirectedEdge[128, 355] -> 
             RGBColor[
              0.4117250076221206, 0.5299124488854325, 0.9477665145867664], 
             UndirectedEdge[58, 382] -> 
             RGBColor[
              0.2986682199237062, 0.43066105766182183`, 0.9403416352703349], 
             UndirectedEdge[45, 179] -> 
             RGBColor[
              0.2308558043838454, 0.3599744658837838, 0.9364582685878783], 
             UndirectedEdge[181, 296] -> 
             RGBColor[
              0.3670585086059648, 0.49234936408258523`, 0.9446096214846453], 
             UndirectedEdge[350, 354] -> 
             RGBColor[
              0.36196691822383753`, 0.4879392844043602, 0.9442851898478128], 
             UndirectedEdge[318, 335] -> 
             RGBColor[
              0.3093572475376726, 0.43941523304457686`, 0.9410411890738053], 
             UndirectedEdge[354, 372] -> 
             RGBColor[
              0.416108457877265, 0.5343687074376324, 0.9478635928798225], 
             UndirectedEdge[44, 57] -> 
             RGBColor[
              0.5489601186307986, 0.6447095805328258, 0.9576352979272409], 
             UndirectedEdge[257, 420] -> 
             RGBColor[
              0.9137481314322007, 0.7140513423503487, 0.5709499365964574], 
             UndirectedEdge[84, 171] -> 
             RGBColor[
              0.2475282592649566, 0.3774982730585261, 0.9374077402286709], 
             UndirectedEdge[376, 497] -> 
             RGBColor[
              0.25772437162935435`, 0.38821503362437043`, 0.9379883937440268],
              UndirectedEdge[164, 443] -> 
             RGBColor[
              0.8760183447320038, 0.45688851313920237`, 0.21528999668843654`],
              UndirectedEdge[2, 54] -> 
             RGBColor[
              0.22058424144202293`, 0.3491784019772233, 0.9358733182737572], 
             UndirectedEdge[165, 324] -> 
             RGBColor[
              0.3968553526992069, 0.5181578928032218, 0.9465082500419522], 
             UndirectedEdge[82, 395] -> 
             RGBColor[
              0.26163309800222595`, 0.39232335286982434`, 0.9382109899285194],
              UndirectedEdge[298, 420] -> 
             RGBColor[
              0.9351413217232607, 0.9502707918228358, 0.9642220469712115], 
             UndirectedEdge[163, 437] -> 
             RGBColor[
              0.26141138655191587`, 0.3920903200782306, 0.9381983637894169], 
             UndirectedEdge[156, 372] -> 
             RGBColor[
              0.46888111877498084`, 0.5796978409320405, 0.951331185719549], 
             UndirectedEdge[272, 317] -> 
             RGBColor[
              0.8519916278011412, 0.36132246904964216`, 0.1958811278335439], 
             UndirectedEdge[282, 441] -> 
             RGBColor[
              0.5288953957407483, 0.628333638126909, 0.9560796286709814], 
             UndirectedEdge[209, 423] -> 
             RGBColor[
              0.37687473184245884`, 0.48661428775252374`, 0.9464892509185017],
              UndirectedEdge[222, 333] -> 
             RGBColor[
              0.41068141899913524`, 0.5301333365139219, 0.9473892347606732], 
             UndirectedEdge[125, 455] -> 
             RGBColor[
              0.20630711262003382`, 0.3341722343630622, 0.9350602569084642], 
             UndirectedEdge[343, 433] -> 
             RGBColor[
              0.3091968798489231, 0.4407663035487692, 0.9409764153784905], 
             UndirectedEdge[29, 77] -> 
             RGBColor[
              0.5082190929851442, 0.6104476858288989, 0.9547558471761093], 
             UndirectedEdge[298, 353] -> 
             RGBColor[
              0.7706511770330843, 0.8213765109750578, 0.9776280646137345], 
             UndirectedEdge[65, 337] -> 
             RGBColor[
              0.9228377639355362, 0.92700213552959, 0.6922814441739551], 
             UndirectedEdge[93, 364] -> 
             RGBColor[
              0.2639259772143767, 0.39473331429873343`, 0.9383415660076406], 
             UndirectedEdge[170, 328] -> 
             RGBColor[
              0.3409967871765409, 0.4686604793300483, 0.9429898367152708], 
             UndirectedEdge[13, 244] -> 
             RGBColor[
              0.3195286449146627, 0.4500599078221664, 0.9416221233751105], 
             UndirectedEdge[114, 291] -> 
             RGBColor[
              0.577802812280651, 0.6679328507014297, 0.9600375327920143], 
             UndirectedEdge[198, 373] -> 
             RGBColor[
              0.28774746699468884`, 0.4197712104275283, 0.9396981646098933], 
             UndirectedEdge[54, 84] -> 
             RGBColor[
              0.23101754524273913`, 0.3601444657814439, 0.9364674794905181], 
             UndirectedEdge[1, 385] -> 
             RGBColor[
              0.2498185382943033, 0.379905501530447, 0.937538168231228], 
             UndirectedEdge[97, 294] -> 
             RGBColor[
              0.23502362506905988`, 0.3643551096790384, 0.936695619810163], 
             UndirectedEdge[83, 489] -> 
             RGBColor[
              0.9554216482771469, 0.9649073806371287, 0.9030373799764648], 
             UndirectedEdge[349, 359] -> 
             RGBColor[
              0.3995263663781553, 0.520471390602876, 0.94667844467169], 
             UndirectedEdge[47, 55] -> 
             RGBColor[
              0.22170565849658444`, 0.35035708240351526`, 0.9359371813160265],
              UndirectedEdge[166, 309] -> 
             RGBColor[
              0.9155755884315661, 0.6407588014939913, 0.33347870741883034`], 
             UndirectedEdge[196, 482] -> 
             RGBColor[
              0.3270903866194627, 0.45652473233228946`, 0.9421070549379097], 
             UndirectedEdge[114, 311] -> 
             RGBColor[
              0.6237676761079407, 0.7038409516692123, 0.9646188808522442], 
             UndirectedEdge[101, 169] -> 
             RGBColor[
              0.506787455963573, 0.6104719131227696, 0.9543153114385234], 
             UndirectedEdge[160, 353] -> 
             RGBColor[
              0.531072144514868, 0.6293500407838779, 0.9564584330755022], 
             UndirectedEdge[80, 329] -> 
             RGBColor[
              0.8360503988309712, 0.8723539542869803, 0.9841591349586778], 
             UndirectedEdge[130, 386] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[216, 238] -> 
             RGBColor[
              0.29301995095784455`, 0.42425818517520597`, 0.9400370439768699],
              UndirectedEdge[240, 382] -> 
             RGBColor[
              0.26942512488484194`, 0.40051326716649266`, 0.9386547343322136],
              UndirectedEdge[424, 470] -> 
             RGBColor[
              0.28803826967359597`, 0.4189813939860375, 0.9397548358601392], 
             UndirectedEdge[184, 225] -> 
             RGBColor[
              0.2656405828545585, 0.396535473538841, 0.9384392102623171], 
             UndirectedEdge[169, 274] -> 
             RGBColor[
              0.4777382226320348, 0.5868884368511786, 0.9520284493798168], 
             UndirectedEdge[345, 375] -> 
             RGBColor[
              0.8089633164388916, 0.8512244424146573, 0.9611785706908804], 
             UndirectedEdge[326, 434] -> 
             RGBColor[
              0.9331890448533395, 0.7583565146768234, 0.5065076494810187], 
             UndirectedEdge[59, 105] -> 
             RGBColor[
              0.2440481876886619, 0.3738404971825583, 0.9372095553007055], 
             UndirectedEdge[90, 306] -> 
             RGBColor[
              0.8611746456929213, 0.4612099603827511, 0.20582221997608346`], 
             UndirectedEdge[44, 466] -> 
             RGBColor[
              0.5000927113166715, 0.6050368178236056, 0.9537882766162615], 
             UndirectedEdge[88, 434] -> 
             RGBColor[
              0.9289063525023188, 0.7389098089590498, 0.5029340660049313], 
             UndirectedEdge[174, 356] -> 
             RGBColor[
              0.2679975194043914, 0.3990127632911238, 0.938573434312055], 
             UndirectedEdge[65, 88] -> 
             RGBColor[
              0.9260374771709088, 0.7249105779401631, 0.30422129427437533`], 
             UndirectedEdge[82, 195] -> 
             RGBColor[
              0.2642152742010554, 0.39503738377422104`, 0.9383580410430554], 
             UndirectedEdge[150, 413] -> 
             RGBColor[
              0.8976403406773998, 0.5446217555948332, 0.26051353065802335`], 
             UndirectedEdge[156, 307] -> 
             RGBColor[
              0.4685593666518582, 0.5794366280637215, 0.9513058562137999], 
             UndirectedEdge[245, 460] -> 
             RGBColor[
              0.23495456172986623`, 0.36428251973067727`, 0.936691686755166], 
             UndirectedEdge[101, 204] -> 
             RGBColor[
              0.5113628894889524, 0.6141864561796039, 0.9546755063260064], 
             UndirectedEdge[210, 428] -> 
             RGBColor[
              0.8331986050247592, 0.2561846027075905, 0.17942432770515804`], 
             UndirectedEdge[25, 76] -> 
             RGBColor[
              0.36235029179287925`, 0.48827134332094824`, 0.9443096180726283],
              UndirectedEdge[130, 421] -> 
             RGBColor[
              0.17899180289058533`, 0.3054621119467458, 0.9335046904287516], 
             UndirectedEdge[79, 493] -> 
             RGBColor[
              0.9937029879453217, 0.9889396528776512, 0.5559872823811043], 
             UndirectedEdge[194, 490] -> 
             RGBColor[
              0.9885348242076832, 0.9895268694153684, 0.8396711640099095], 
             UndirectedEdge[214, 347] -> 
             RGBColor[
              0.1893670574265447, 0.316367162293171, 0.9340955458257609], 
             UndirectedEdge[41, 202] -> 
             RGBColor[
              0.2357918679274276, 0.3651625816325934, 0.9367393701044336], 
             UndirectedEdge[85, 97] -> 
             RGBColor[
              0.22297503114412753`, 0.3516912735389574, 0.9360094702104356], 
             UndirectedEdge[31, 114] -> 
             RGBColor[
              0.47685837337515014`, 0.5861665400670314, 0.9519612830883075], 
             UndirectedEdge[247, 425] -> 
             RGBColor[
              0.4351771155351065, 0.550218204604259, 0.9492628740426365], 
             UndirectedEdge[35, 281] -> 
             RGBColor[
              0.2416405448941051, 0.37130991195210916`, 0.9370724436053437], 
             UndirectedEdge[157, 288] -> 
             RGBColor[
              0.2793047597177943, 0.4108973897809534, 0.9392173649203402], 
             UndirectedEdge[208, 427] -> 
             RGBColor[
              0.3008093263098471, 0.4322636714318231, 0.9404872881507658], 
             UndirectedEdge[154, 313] -> 
             RGBColor[
              0.2882495492104231, 0.42022540866860447`, 0.9397294494499471], 
             UndirectedEdge[189, 364] -> 
             RGBColor[
              0.25917101959394173`, 0.3897355523579304, 0.9380707782054862], 
             UndirectedEdge[314, 373] -> 
             RGBColor[
              0.3118454823562334, 0.44312769697598026`, 0.9411427175470836], 
             UndirectedEdge[156, 232] -> 
             RGBColor[
              0.4117533959329014, 0.5306819361106889, 0.9475625057353367], 
             UndirectedEdge[321, 383] -> 
             RGBColor[
              0.3310589867507921, 0.46116838764021345`, 0.942315763785161], 
             UndirectedEdge[15, 323] -> 
             RGBColor[
              0.2367917298527569, 0.36621349991102203`, 0.936796310761918], 
             UndirectedEdge[225, 235] -> 
             RGBColor[
              0.31564550837904015`, 0.44462855110700683`, 0.9414504121909557],
              UndirectedEdge[170, 265] -> 
             RGBColor[
              0.3088475371272851, 0.4408144148056739, 0.9409413149305978], 
             UndirectedEdge[102, 485] -> 
             RGBColor[
              0.2622693737921402, 0.3929921190672394, 0.9382472248934693], 
             UndirectedEdge[342, 463] -> 
             RGBColor[
              0.2635422521882549, 0.3943299949667075, 0.9383197134350733], 
             UndirectedEdge[70, 147] -> 
             RGBColor[
              0.2548716664665323, 0.3852166596262904, 0.9378259364052033], 
             UndirectedEdge[162, 381] -> 
             RGBColor[
              0.515668109442376, 0.6176816276857418, 0.9550144290112803], 
             UndirectedEdge[212, 299] -> 
             RGBColor[
              0.21384131413680724`, 0.3420911578531577, 0.9354893185389921], 
             UndirectedEdge[92, 361] -> 
             RGBColor[
              0.6266695180780231, 0.7077693478258749, 0.9637721633771799], 
             UndirectedEdge[82, 184] -> 
             RGBColor[
              0.2576552479933815, 0.38814238030027126`, 0.9379844572552174], 
             UndirectedEdge[232, 376] -> 
             RGBColor[
              0.3178263634409366, 0.4469988106247622, 0.9415717511395277], 
             UndirectedEdge[293, 298] -> 
             RGBColor[
              0.9279560632534805, 0.9449120378208546, 0.9763848153450053], 
             UndirectedEdge[225, 249] -> 
             RGBColor[
              0.28189858083211217`, 0.41362366022985875`, 0.9393650791955862],
              UndirectedEdge[19, 34] -> 
             RGBColor[
              0.5517387974757788, 0.6469654371972362, 0.9578540457045537], 
             UndirectedEdge[338, 390] -> 
             RGBColor[
              0.3104293975603457, 0.44256111009978116`, 0.9410283217053288], 
             UndirectedEdge[82, 342] -> 
             RGBColor[
              0.2591328832418887, 0.3896954686339382, 0.9380686063966545], 
             UndirectedEdge[54, 374] -> 
             RGBColor[
              0.24022555960590497`, 0.3698226726989618, 0.9369918622864639], 
             UndirectedEdge[196, 350] -> 
             RGBColor[
              0.3289346637950721, 0.4581221525257362, 0.9422245706487093], 
             UndirectedEdge[19, 44] -> 
             RGBColor[
              0.5282008880554978, 0.6278563019591167, 0.956001055252786], 
             UndirectedEdge[85, 408] -> 
             RGBColor[
              0.21836004410720744`, 0.3468406295560761, 0.9357466535259444], 
             UndirectedEdge[57, 255] -> 
             RGBColor[
              0.499414256811589, 0.6029727505529885, 0.9541529864670097], 
             UndirectedEdge[106, 269] -> 
             RGBColor[
              0.48339733950661234`, 0.5913638720070653, 0.9525068056899508], 
             UndirectedEdge[382, 416] -> 
             RGBColor[
              0.2718791903645599, 0.40309264558241453`, 0.938794489730819], 
             UndirectedEdge[246, 392] -> 
             RGBColor[
              0.3001114005223494, 0.4327664884837622, 0.940402272333493], 
             UndirectedEdge[350, 414] -> 
             RGBColor[
              0.31841398035212815`, 0.44706424717734483`, 0.94162543329059], 
             UndirectedEdge[146, 211] -> 
             RGBColor[
              0.2444868180291041, 0.37430152548113294`, 0.9372345346496982], 
             UndirectedEdge[71, 487] -> 
             RGBColor[
              0.6676064579243342, 0.7392945350984725, 0.9681635028375868], 
             UndirectedEdge[415, 485] -> 
             RGBColor[
              0.2675069384795197, 0.39849713163445644`, 0.9385454964541331], 
             UndirectedEdge[238, 433] -> 
             RGBColor[
              0.32283008594645624`, 0.45404092736007795`, 0.94179142550244], 
             UndirectedEdge[141, 429] -> 
             RGBColor[
              0.30159042381675216`, 0.434243660437526, 0.9404893336110074], 
             UndirectedEdge[406, 493] -> 
             RGBColor[
              0.9920978208950986, 0.9843432363296774, 0.4801786397760631], 
             UndirectedEdge[257, 357] -> 
             RGBColor[
              0.8829978584207956, 0.5607626793064351, 0.22403944465155362`], 
             UndirectedEdge[311, 488] -> 
             RGBColor[
              0.7581105843852092, 0.8109610174663499, 0.9765250361714609], 
             UndirectedEdge[258, 381] -> 
             RGBColor[
              0.4713636222770108, 0.5795438974068458, 0.952126015828245], 
             UndirectedEdge[168, 200] -> 
             RGBColor[
              0.9058101136750496, 0.6632964389017137, 0.24302016366679569`], 
             UndirectedEdge[16, 254] -> 
             RGBColor[
              0.3201901654275895, 0.4450745627173458, 0.941867792234375], 
             UndirectedEdge[325, 347] -> 
             RGBColor[
              0.1789719601845752, 0.3054412560046289, 0.9335035604159989], 
             UndirectedEdge[154, 478] -> 
             RGBColor[
              0.28779157321631055`, 0.419744046861437, 0.9397033683945971], 
             UndirectedEdge[302, 386] -> 
             RGBColor[
              0.18453817917078433`, 0.311291705077802, 0.9338205483527805], 
             UndirectedEdge[330, 414] -> 
             RGBColor[
              0.2905537605670515, 0.4227208029013707, 0.9398579788773], 
             UndirectedEdge[50, 334] -> 
             RGBColor[
              0.42187105269828507`, 0.539825234816783, 0.9481022283253784], 
             UndirectedEdge[72, 187] -> 
             RGBColor[
              0.2593062768219157, 0.38987771628033463`, 0.9380784809045242], 
             UndirectedEdge[14, 149] -> 
             RGBColor[
              0.33030872638618497`, 0.46033332920658265`, 0.9422747396921978],
              UndirectedEdge[113, 214] -> 
             RGBColor[
              0.18949968777431325`, 0.3165065651979255, 0.9341030989278573], 
             UndirectedEdge[63, 149] -> 
             RGBColor[
              0.3866051837093468, 0.5092797116126782, 0.9458551183377868], 
             UndirectedEdge[245, 445] -> 
             RGBColor[
              0.22560109399094413`, 0.3544514320929628, 0.93615902060465], 
             UndirectedEdge[207, 336] -> 
             RGBColor[
              0.2196507706490151, 0.34819726498830533`, 0.9358201584930417], 
             UndirectedEdge[264, 394] -> 
             RGBColor[
              0.23171433520063273`, 0.36087683620622507`, 0.9365071606478118],
              UndirectedEdge[255, 370] -> 
             RGBColor[
              0.4945144317215364, 0.598994851810279, 0.9537672542872702], 
             UndirectedEdge[330, 482] -> 
             RGBColor[
              0.33246549585026375`, 0.4621743129354704, 0.9424131594568423], 
             UndirectedEdge[383, 482] -> 
             RGBColor[
              0.34371197944189347`, 0.47212777395134153`, 0.9431220012908359],
              UndirectedEdge[358, 407] -> 
             RGBColor[
              0.21999227740316346`, 0.34855621023969413`, 0.9358396067974764],
              UndirectedEdge[28, 142] -> 
             RGBColor[
              0.8321901895218196, 0.869251634409216, 0.9575296911592543], 
             UndirectedEdge[348, 375] -> 
             RGBColor[
              0.959056524042907, 0.9223909347161948, 0.6272014222552931], 
             UndirectedEdge[41, 295] -> 
             RGBColor[
              0.23105727915165333`, 0.3601862286389881, 0.9364697422778497], 
             UndirectedEdge[83, 345] -> 
             RGBColor[
              0.7902354483667869, 0.8368716246944006, 0.9795108205407682], 
             UndirectedEdge[140, 425] -> 
             RGBColor[
              0.4374884569477172, 0.5520946556877604, 0.9494448313053598], 
             UndirectedEdge[160, 441] -> 
             RGBColor[
              0.4363070753078513, 0.5523289920255958, 0.9490220789207864], 
             UndirectedEdge[66, 394] -> 
             RGBColor[
              0.24596177604056546`, 0.3758517998689181, 0.937318531326446], 
             UndirectedEdge[201, 271] -> 
             RGBColor[
              0.2801320470703391, 0.4117669212415258, 0.9392644777112058], 
             UndirectedEdge[192, 470] -> 
             RGBColor[
              0.255048373399578, 0.3854023898167881, 0.9378359996036256], 
             UndirectedEdge[255, 379] -> 
             RGBColor[
              0.35344236256380235`, 0.4805557427482631, 0.943742012699124], 
             UndirectedEdge[82, 440] -> 
             RGBColor[
              0.26997623108034263`, 0.40109251472011487`, 0.9386861190147588],
              UndirectedEdge[43, 362] -> 
             RGBColor[
              0.34080467652755875`, 0.4681674552795022, 0.9429895550260083], 
             UndirectedEdge[127, 302] -> 
             RGBColor[
              0.2080645848230672, 0.3360194490786239, 0.9351603423504797], 
             UndirectedEdge[137, 358] -> 
             RGBColor[
              0.22285337720406, 0.3515634075346411, 0.9360025421985196], 
             UndirectedEdge[238, 328] -> 
             RGBColor[
              0.35273346300045894`, 0.47994172957682313`, 0.943696842245803], 
             UndirectedEdge[185, 196] -> 
             RGBColor[
              0.2898220421197416, 0.4219517204196188, 0.9398163085942062], 
             UndirectedEdge[114, 208] -> 
             RGBColor[
              0.41139850447614446`, 0.5294684917353877, 0.9477902381259522], 
             UndirectedEdge[249, 424] -> 
             RGBColor[
              0.30507115038591015`, 0.4368840315616916, 0.9407248332188166], 
             UndirectedEdge[21, 65] -> 
             RGBColor[
              0.9831762967586118, 0.9549118399527363, 0.38914351910732653`], 
             UndirectedEdge[369, 466] -> 
             RGBColor[
              0.46172779849419876`, 0.5729843638939052, 0.9510184053391775], 
             UndirectedEdge[246, 459] -> 
             RGBColor[
              0.3423837632254584, 0.4696344421074833, 0.9430865385917233], 
             UndirectedEdge[46, 317] -> 
             RGBColor[
              0.9005275853462438, 0.6373329329271229, 0.23851003583391922`], 
             UndirectedEdge[66, 305] -> 
             RGBColor[
              0.25719647261268064`, 0.38766017828711546`, 0.9379583306759838],
              UndirectedEdge[56, 243] -> 
             RGBColor[
              0.8379898589381207, 0.2930122798265395, 0.18401243786354038`], 
             UndirectedEdge[281, 288] -> 
             RGBColor[
              0.2504872858476244, 0.38060839761003135`, 0.9375762524150663], 
             UndirectedEdge[81, 329] -> 
             RGBColor[
              0.8530880154845231, 0.8856932433627962, 0.9858494905492173], 
             UndirectedEdge[57, 140] -> 
             RGBColor[
              0.550438526060826, 0.6459098182860178, 0.9577516835757175], 
             UndirectedEdge[184, 440] -> 
             RGBColor[
              0.26935285588816305`, 0.4004373078688641, 0.9386506187197652], 
             UndirectedEdge[422, 446] -> 
             RGBColor[
              0.2310816388212659, 0.36021183219624314`, 0.9364711295249972], 
             UndirectedEdge[232, 307] -> 
             RGBColor[
              0.4130035971526026, 0.5316969057817654, 0.9476609261549895], 
             UndirectedEdge[90, 261] -> 
             RGBColor[
              0.8723782969076955, 0.5133814777114375, 0.21522166145663085`], 
             UndirectedEdge[118, 304] -> 
             RGBColor[
              0.3318360758338559, 0.46184146314633034`, 0.9423652792143808], 
             UndirectedEdge[427, 460] -> 
             RGBColor[
              0.2639231904685617, 0.39473038525219195`, 0.938341407306589], 
             UndirectedEdge[299, 300] -> 
             RGBColor[
              0.21756201185689822`, 0.346001847062834, 0.9357012067698722], 
             UndirectedEdge[106, 425] -> 
             RGBColor[
              0.4465990938801403, 0.559491081179018, 0.9501620540180429], 
             UndirectedEdge[428, 495] -> 
             RGBColor[
              0.8362679836981737, 0.2797771922017657, 0.1823635681891872], 
             UndirectedEdge[230, 365] -> 
             RGBColor[
              0.22042634378562792`, 0.3490124415290624, 0.9358643262358141], 
             UndirectedEdge[224, 463] -> 
             RGBColor[
              0.2830318265857735, 0.4148147733688876, 0.9394296158647704], 
             UndirectedEdge[251, 382] -> 
             RGBColor[
              0.27038494943162866`, 0.40152210362155666`, 0.9387093949202199],
              UndirectedEdge[81, 278] -> 
             RGBColor[
              0.8859909437525565, 0.9116025564457284, 0.9776647627909368], 
             UndirectedEdge[42, 294] -> 
             RGBColor[
              0.23539350574473433`, 0.36474387772096156`, 0.9367166839674533],
              UndirectedEdge[8, 419] -> 
             RGBColor[
              0.5664920822105015, 0.6589428183727875, 0.9590154783219338], 
             UndirectedEdge[159, 164] -> 
             RGBColor[
              0.819137437150352, 0.14810430478184575`, 0.1659593374688081], 
             UndirectedEdge[346, 404] -> 
             RGBColor[
              0.21566548218765702`, 0.3440084741335353, 0.9355932022108733], 
             UndirectedEdge[7, 194] -> 
             RGBColor[
              0.9125990982944516, 0.9314492168831301, 0.9288011319761822], 
             UndirectedEdge[268, 353] -> 
             RGBColor[
              0.5246586597567469, 0.6237950026375101, 0.9560497714979366], 
             UndirectedEdge[51, 423] -> 
             RGBColor[
              0.18337644614132015`, 0.31007065000570677`, 0.9337543893753826],
              UndirectedEdge[14, 322] -> 
             RGBColor[
              0.2829806146027809, 0.4147609463277351, 0.9394266994181002], 
             UndirectedEdge[109, 458] -> 
             RGBColor[
              0.24222963005763265`, 0.3719290778091332, 0.9371059911339332], 
             UndirectedEdge[217, 384] -> 
             RGBColor[
              0.30177027996931804`, 0.4334954768697517, 0.9405338925067932], 
             UndirectedEdge[202, 485] -> 
             RGBColor[
              0.2435291255920976, 0.37329493000863156`, 0.9371799954821897], 
             UndirectedEdge[125, 457] -> 
             RGBColor[
              0.21513132866869134`, 0.3434470449178132, 0.9355627829581774], 
             UndirectedEdge[454, 475] -> 
             RGBColor[
              0.8694429086173421, 0.4695370183739893, 0.21157738923531183`], 
             UndirectedEdge[30, 378] -> 
             RGBColor[
              0.2755078252460146, 0.406906570911563, 0.9390011351192336], 
             UndirectedEdge[445, 460] -> 
             RGBColor[
              0.23899278558713355`, 0.3685269490428458, 0.9369216576298206], 
             UndirectedEdge[173, 461] -> 
             RGBColor[
              0.9645092309315171, 0.9729899937684735, 0.9422009085196323], 
             UndirectedEdge[23, 41] -> 
             RGBColor[
              0.22751409159888136`, 0.35646211386995863`, 0.9362679629883957],
              UndirectedEdge[111, 444] -> 
             RGBColor[
              0.272192144891436, 0.40342158063262434`, 0.9388123120281499], 
             UndirectedEdge[139, 360] -> 
             RGBColor[
              0.5717007512056378, 0.6631714505109032, 0.9594255238252141], 
             UndirectedEdge[53, 432] -> 
             RGBColor[
              0.9375683877182548, 0.9272177056729635, 0.6767239867532486], 
             UndirectedEdge[184, 260] -> 
             RGBColor[
              0.2713041510776424, 0.40248824283226764`, 0.9387617420941234], 
             UndirectedEdge[244, 379] -> 
             RGBColor[
              0.3258701140726008, 0.45667404692668806`, 0.9419851334064466], 
             UndirectedEdge[14, 187] -> 
             RGBColor[
              0.28568538812664784`, 0.41760383479386565`, 0.9395807322689307],
              UndirectedEdge[133, 332] -> 
             RGBColor[
              0.3736828594731001, 0.4980870438541423, 0.9450317192642157], 
             UndirectedEdge[424, 440] -> 
             RGBColor[
              0.30113413549531765`, 0.4327459792905174, 0.940500626045089], 
             UndirectedEdge[381, 419] -> 
             RGBColor[
              0.5409976687744238, 0.6382453050351424, 0.9570084647071322], 
             UndirectedEdge[39, 368] -> 
             RGBColor[
              0.5158816187650146, 0.6166272342584453, 0.9553704626805029], 
             UndirectedEdge[40, 208] -> 
             RGBColor[
              0.3541593410951509, 0.4811767535157284, 0.9437876979371422], 
             UndirectedEdge[436, 462] -> 
             RGBColor[
              0.46839908955768095`, 0.5793065078982675, 0.951293238613832], 
             UndirectedEdge[103, 188] -> 
             RGBColor[
              0.408816425381794, 0.5277838356822806, 0.9474732432839563], 
             UndirectedEdge[313, 411] -> 
             RGBColor[
              0.2532739296678089, 0.38353733694846814`, 0.9377349476581557], 
             UndirectedEdge[181, 344] -> 
             RGBColor[
              0.4422200885925819, 0.5571674842764482, 0.9494770619548758], 
             UndirectedEdge[5, 485] -> 
             RGBColor[
              0.24330426601765148`, 0.37305858833896816`, 0.9371671900620748],
              UndirectedEdge[371, 429] -> 
             RGBColor[
              0.3282709430209225, 0.4573529851702918, 0.9421893927020404], 
             UndirectedEdge[426, 448] -> 
             RGBColor[
              0.7190568535901429, 0.7797176017404024, 0.9733043071059779], 
             UndirectedEdge[32, 403] -> 
             RGBColor[
              0.73231135392298, 0.7900531713799142, 0.9748369526254256], 
             UndirectedEdge[115, 484] -> 
             RGBColor[
              0.9570300393594782, 0.9635915325846716, 0.7300132516870645], 
             UndirectedEdge[36, 251] -> 
             RGBColor[
              0.25646724614478844`, 0.3868937150337323, 0.9379168023074314], 
             UndirectedEdge[243, 454] -> 
             RGBColor[
              0.869594267772993, 0.47070043117032717`, 0.21172233093369885`], 
             UndirectedEdge[106, 139] -> 
             RGBColor[
              0.5409452590449157, 0.6382027564556965, 0.9570043388212421], 
             UndirectedEdge[220, 499] -> 
             RGBColor[
              0.2998159216660946, 0.42966675719263536`, 0.9404875702170554], 
             UndirectedEdge[359, 419] -> 
             RGBColor[
              0.44907089909255904`, 0.561772271120652, 0.9502808074967835], 
             UndirectedEdge[115, 297] -> 
             RGBColor[
              0.7202662947001824, 0.7803304830864486, 0.9738242280167566], 
             UndirectedEdge[155, 235] -> 
             RGBColor[
              0.4614654223098702, 0.5710633178486462, 0.9514696859030422], 
             UndirectedEdge[98, 261] -> 
             RGBColor[
              0.9376107771767181, 0.7700729496416561, 0.47213960027127755`], 
             UndirectedEdge[386, 421] -> 
             RGBColor[
              0.17899180289058533`, 0.3054621119467458, 0.9335046904287516], 
             UndirectedEdge[37, 58] -> 
             RGBColor[
              0.31037597127891847`, 0.44296664665046, 0.9410083743899482], 
             UndirectedEdge[71, 194] -> 
             RGBColor[
              0.8711488139703549, 0.898916809896938, 0.9247098602219754], 
             UndirectedEdge[47, 339] -> 
             RGBColor[
              0.22181216919966315`, 0.3504690319056196, 0.9359432469429985], 
             UndirectedEdge[108, 410] -> 
             RGBColor[
              0.32438785376155105`, 0.4532049421182389, 0.9419706976299311], 
             UndirectedEdge[193, 196] -> 
             RGBColor[
              0.29175552637074975`, 0.4239839349574104, 0.9399264176619675], 
             UndirectedEdge[131, 171] -> 
             RGBColor[
              0.26267563753313167`, 0.39341912801763035`, 0.9382703610125054],
              UndirectedEdge[203, 258] -> 
             RGBColor[
              0.45399453907585874`, 0.5654428931958693, 0.950758657973602], 
             UndirectedEdge[164, 428] -> 
             RGBColor[
              0.8239291026561835, 0.1849351455808791, 0.17054784176860438`], 
             UndirectedEdge[143, 325] -> 
             RGBColor[
              0.17897196085846667`, 0.30544125671293154`, 0.9335035604543761],
              UndirectedEdge[101, 498] -> 
             RGBColor[
              0.491361119566665, 0.5979481182872246, 0.9531008937288266], 
             UndirectedEdge[35, 391] -> 
             RGBColor[
              0.23974982774210207`, 0.3693226483469626, 0.9369647700606025], 
             UndirectedEdge[8, 221] -> 
             RGBColor[
              0.5784518548396522, 0.6686523005747489, 0.9599569954333912], 
             UndirectedEdge[240, 251] -> 
             RGBColor[
              0.25758537828186423`, 0.38806894280347104`, 0.9379804782785095],
              UndirectedEdge[464, 485] -> 
             RGBColor[
              0.24593397699878092`, 0.3758225813134415, 0.9373169482121415], 
             UndirectedEdge[104, 452] -> 
             RGBColor[
              0.2352635459876256, 0.36460728177631574`, 0.9367092829515442], 
             UndirectedEdge[121, 475] -> 
             RGBColor[
              0.8332346662535209, 0.256461785113985, 0.17945885997854572`], 
             UndirectedEdge[168, 315] -> 
             RGBColor[
              0.5481459181329882, 0.49816507299275914`, 0.5904774154442385], 
             UndirectedEdge[65, 320] -> 
             RGBColor[
              0.9870336626851595, 0.9760932232050978, 0.618291834936235], 
             UndirectedEdge[323, 452] -> 
             RGBColor[
              0.23164904535488023`, 0.3608082124387239, 0.9365034424876839], 
             UndirectedEdge[72, 322] -> 
             RGBColor[
              0.25660150329804876`, 0.38703482781420406`, 0.9379244480536938],
              UndirectedEdge[60, 327] -> 
             RGBColor[
              0.27488937913222444`, 0.40625654483422113`, 0.9389659155279624],
              UndirectedEdge[1, 135] -> 
             RGBColor[
              0.2583961289533292, 0.38892109316374235`, 0.9380266493298512], 
             UndirectedEdge[420, 439] -> 
             RGBColor[
              0.9147776569049322, 0.9340333582536569, 0.9622797424419812], 
             UndirectedEdge[134, 367] -> 
             RGBColor[
              0.23152572380893705`, 0.3606785936749, 0.9364964195080803], 
             UndirectedEdge[119, 345] -> 
             RGBColor[
              0.8251862844410536, 0.8622510331677843, 0.8856898202805965], 
             UndirectedEdge[64, 366] -> 
             RGBColor[
              0.27642037277284975`, 0.4078657162211217, 0.9390531033508938], 
             UndirectedEdge[86, 90] -> 
             RGBColor[
              0.8899814344584336, 0.5901544331035902, 0.2297467504579272], 
             UndirectedEdge[81, 426] -> 
             RGBColor[
              0.8468962698264015, 0.8807561134454687, 0.9852589163209091], 
             UndirectedEdge[70, 265] -> 
             RGBColor[
              0.28963233444531233`, 0.42061801847270397`, 0.9398470375642044],
              UndirectedEdge[245, 438] -> 
             RGBColor[
              0.22151371355788788`, 0.3501553361029332, 0.9359262503357249], 
             UndirectedEdge[121, 259] -> 
             RGBColor[
              0.8446533203330481, 0.33882677308300735`, 0.1901817771182239], 
             UndirectedEdge[74, 105] -> 
             RGBColor[
              0.2638196417670582, 0.3946215490015449, 0.938335510361225], 
             UndirectedEdge[358, 430] -> 
             RGBColor[
              0.23268261924121364`, 0.3618945641256297, 0.936562302991475], 
             UndirectedEdge[43, 316] -> 
             RGBColor[
              0.2718214258604257, 0.4030319314260883, 0.9387912001277635], 
             UndirectedEdge[162, 203] -> 
             RGBColor[
              0.4982990262412239, 0.6035806234747654, 0.9536470711566374], 
             UndirectedEdge[226, 236] -> 
             RGBColor[
              0.23337407460187973`, 0.3626213275504917, 0.9366016803513484], 
             UndirectedEdge[110, 340] -> 
             RGBColor[
              0.3045749314378675, 0.43480548891742876`, 0.9407535831342266], 
             UndirectedEdge[145, 407] -> 
             RGBColor[
              0.2175082544444818, 0.34594534461396753`, 0.9356981453647621], 
             UndirectedEdge[258, 289] -> 
             RGBColor[
              0.4063967473847854, 0.5264221693154291, 0.9471162192741931], 
             UndirectedEdge[13, 334] -> 
             RGBColor[
              0.3497101697631252, 0.47620162767835794`, 0.94354526344998], 
             UndirectedEdge[300, 389] -> 
             RGBColor[
              0.2222287148930997, 0.35090684783994386`, 0.9359669686040155], 
             UndirectedEdge[57, 363] -> 
             RGBColor[
              0.5030271726289528, 0.6061020766435601, 0.9543831982681161], 
             UndirectedEdge[305, 427] -> 
             RGBColor[
              0.26530600013852146`, 0.3961838058905166, 0.9384201562716097], 
             UndirectedEdge[277, 419] -> 
             RGBColor[
              0.6419960336426249, 0.718265092425402, 0.9663099050077802], 
             UndirectedEdge[40, 349] -> 
             RGBColor[
              0.3999008136180363, 0.5207957179817955, 0.9467023041187045], 
             UndirectedEdge[28, 241] -> 
             RGBColor[
              0.8351691071867402, 0.8715787875296648, 0.9578266018325254], 
             UndirectedEdge[164, 396] -> 
             RGBColor[
              0.9055353853140414, 0.5621560872497313, 0.3516608883245811], 
             UndirectedEdge[111, 284] -> 
             RGBColor[
              0.2590919383322233, 0.3896524329378227, 0.9380662746446216], 
             UndirectedEdge[25, 343] -> 
             RGBColor[
              0.3031313951145783, 0.4355126855320067, 0.9405899280547156], 
             UndirectedEdge[84, 131] -> 
             RGBColor[
              0.24846167161057395`, 0.3784793486155308, 0.9374608966808939], 
             UndirectedEdge[169, 244] -> 
             RGBColor[
              0.4175916065853016, 0.5350481346501237, 0.9481253168239769], 
             UndirectedEdge[219, 363] -> 
             RGBColor[
              0.4655401284489993, 0.5756684054061787, 0.9514320808307029], 
             UndirectedEdge[400, 415] -> 
             RGBColor[
              0.2914672574254832, 0.4236809460186285, 0.9399100011719903], 
             UndirectedEdge[248, 286] -> 
             RGBColor[
              0.23281996068137648`, 0.36203891868719107`, 0.9365701243833138],
              UndirectedEdge[136, 484] -> 
             RGBColor[
              0.980926180317411, 0.981787940062676, 0.7025545645628573], 
             UndirectedEdge[74, 263] -> 
             RGBColor[
              0.27756733242056764`, 0.40907124353231517`, 0.9391184210060566],
              UndirectedEdge[69, 142] -> 
             RGBColor[
              0.8044934065793106, 0.8479188521576653, 0.9809561216743297], 
             UndirectedEdge[109, 409] -> 
             RGBColor[
              0.24775783308986035`, 0.3777395697043211, 0.9374208141183751], 
             UndirectedEdge[101, 219] -> 
             RGBColor[
              0.5235508135187052, 0.6240811619666777, 0.9556349843514654], 
             UndirectedEdge[380, 390] -> 
             RGBColor[
              0.2868022644003798, 0.4187777425716037, 0.9396443367204493], 
             UndirectedEdge[53, 293] -> 
             RGBColor[
              0.9653923096103165, 0.9489247911355639, 0.6627722008261114], 
             UndirectedEdge[221, 258] -> 
             RGBColor[
              0.45501626161494246`, 0.5662723735811732, 0.9508390917145717], 
             UndirectedEdge[235, 424] -> 
             RGBColor[
              0.3388180779328382, 0.46788892243883967`, 0.9428101662141861], 
             UndirectedEdge[367, 457] -> 
             RGBColor[
              0.22571706608911693`, 0.3545733261211982, 0.9361656250440755], 
             UndirectedEdge[58, 220] -> 
             RGBColor[
              0.32701247471585293`, 0.45766350229915764`, 0.9420579236164848],
              UndirectedEdge[334, 379] -> 
             RGBColor[
              0.3560516389210633, 0.4828157667828796, 0.9439082734813162], 
             UndirectedEdge[14, 163] -> 
             RGBColor[
              0.2868674954285888, 0.4188463045181374, 0.9396480515310051], 
             UndirectedEdge[284, 442] -> 
             RGBColor[
              0.26451897986036277`, 0.3953565976782041, 0.9383753366310607], 
             UndirectedEdge[130, 302] -> 
             RGBColor[
              0.18453817917078433`, 0.311291705077802, 0.9338205483527805], 
             UndirectedEdge[65, 428] -> 
             RGBColor[
              0.9078991618741388, 0.5983968558388272, 0.2873573629313444], 
             UndirectedEdge[388, 487] -> 
             RGBColor[
              0.7628017392959624, 0.8144116714200249, 0.9680174393113103], 
             UndirectedEdge[456, 458] -> 
             RGBColor[
              0.22707889219219896`, 0.35600469170029936`, 0.9362431790260048],
              UndirectedEdge[281, 465] -> 
             RGBColor[
              0.26376712193927254`, 0.39456634733259277`, 0.9383325194347287],
              UndirectedEdge[166, 428] -> 
             RGBColor[
              0.8342269539589475, 0.26408894324113896`, 0.18040907580589088`],
              UndirectedEdge[92, 128] -> 
             RGBColor[
              0.5519404005403256, 0.6471291076471498, 0.9578699166362912], 
             UndirectedEdge[120, 457] -> 
             RGBColor[
              0.21450528797873675`, 0.3427890364593986, 0.9355271308670288], 
             UndirectedEdge[79, 329] -> 
             RGBColor[
              0.9381932995999778, 0.9492001435332333, 0.7791661244013025], 
             UndirectedEdge[105, 195] -> 
             RGBColor[
              0.2580285978828387, 0.38853479470584096`, 0.9380057189791005], 
             UndirectedEdge[98, 377] -> 
             RGBColor[
              0.9881699242791049, 0.9888223570121889, 0.8197885510745015], 
             UndirectedEdge[21, 309] -> 
             RGBColor[
              0.9869592653755547, 0.967346961753188, 0.4315364838739727], 
             UndirectedEdge[93, 322] -> 
             RGBColor[
              0.26425191426448674`, 0.3950758948040016, 0.9383601276404636], 
             UndirectedEdge[8, 115] -> 
             RGBColor[
              0.7707310045144475, 0.8213000079229384, 0.9777969948316587], 
             UndirectedEdge[54, 131] -> 
             RGBColor[
              0.24616492351091418`, 0.3760653207405481, 0.9373301002743527], 
             UndirectedEdge[186, 212] -> 
             RGBColor[
              0.22711333090057176`, 0.3560408889663394, 0.9362451402594992], 
             UndirectedEdge[252, 467] -> 
             RGBColor[
              0.7213175895970523, 0.7822180503007243, 0.9728578543010624], 
             UndirectedEdge[244, 378] -> 
             RGBColor[
              0.3127627275114677, 0.4429484996474682, 0.9412368143882763], 
             UndirectedEdge[55, 339] -> 
             RGBColor[
              0.21158417509033906`, 0.33971876160443837`, 0.9353607778094337],
              UndirectedEdge[69, 490] -> 
             RGBColor[
              0.9500080335378767, 0.9605032008441318, 0.8987210231001681], 
             UndirectedEdge[299, 451] -> 
             RGBColor[
              0.21030609728277713`, 0.3383754207938774, 0.9352879931690398], 
             UndirectedEdge[146, 464] -> 
             RGBColor[
              0.25089999678857744`, 0.38104218297635795`, 0.9375997556926023],
              UndirectedEdge[199, 220] -> 
             RGBColor[
              0.3408785418830542, 0.4696735927505875, 0.9429414571550971], 
             UndirectedEdge[345, 426] -> 
             RGBColor[
              0.7649497936964772, 0.8167095300211071, 0.9770990522255436], 
             UndirectedEdge[66, 472] -> 
             RGBColor[
              0.29586389462338253`, 0.42648062461240877`, 0.9402270759441249],
              UndirectedEdge[40, 114] -> 
             RGBColor[
              0.443439320562669, 0.5572206362112937, 0.9498318505944043], 
             UndirectedEdge[248, 294] -> 
             RGBColor[
              0.240426199543799, 0.37003355799499527`, 0.9370032884341067], 
             UndirectedEdge[304, 483] -> 
             RGBColor[
              0.3176066092257016, 0.44839817992769826`, 0.941499541548237], 
             UndirectedEdge[9, 425] -> 
             RGBColor[
              0.47524326414852586`, 0.5827457090080587, 0.9524170280286233], 
             UndirectedEdge[290, 384] -> 
             RGBColor[
              0.2851530200769201, 0.4170442822195179, 0.9395504146960666], 
             UndirectedEdge[294, 358] -> 
             RGBColor[
              0.23196947764628847`, 0.36114500709357467`, 0.9365216906326425],
              UndirectedEdge[148, 342] -> 
             RGBColor[
              0.2498214928286487, 0.3799086069333723, 0.9375383364875882], 
             UndirectedEdge[178, 420] -> 
             RGBColor[
              0.9801637329335828, 0.9834819259202605, 0.8627171585529716], 
             UndirectedEdge[193, 354] -> 
             RGBColor[
              0.3247877807995152, 0.4538010668360344, 0.941987036861071], 
             UndirectedEdge[194, 228] -> 
             RGBColor[
              0.9897986964683487, 0.9881510016226367, 0.6807237889593197], 
             UndirectedEdge[326, 491] -> 
             RGBColor[
              0.9346684716417725, 0.7580015966571071, 0.4117209054738351], 
             UndirectedEdge[324, 481] -> 
             RGBColor[
              0.3439470735768655, 0.47233140067487944`, 0.9431369812812307], 
             UndirectedEdge[94, 213] -> 
             RGBColor[
              0.9298124883323949, 0.8120876909328425, 0.6010637208876998], 
             UndirectedEdge[92, 175] -> 
             RGBColor[
              0.7824339265203888, 0.8300343229197356, 0.9610969915433571], 
             UndirectedEdge[254, 401] -> 
             RGBColor[
              0.50497531356463, 0.5944255881948143, 0.9574168801184721], 
             UndirectedEdge[161, 491] -> 
             RGBColor[
              0.992246695040947, 0.9844848921088973, 0.5114139987289448], 
             UndirectedEdge[172, 303] -> 
             RGBColor[
              0.32845548787730483`, 0.4585909264869045, 0.9421616772940785], 
             UndirectedEdge[57, 274] -> 
             RGBColor[
              0.5319886243671207, 0.6309313569324684, 0.9562992397301722], 
             UndirectedEdge[44, 360] -> 
             RGBColor[
              0.5380217860131518, 0.6358293493475512, 0.9567741923151472], 
             UndirectedEdge[170, 238] -> 
             RGBColor[
              0.3084172446419511, 0.44044171708200675`, 0.940913897073925], 
             UndirectedEdge[5, 11] -> 
             RGBColor[
              0.23876273655839006`, 0.3682851529276855, 0.9369085566779607], 
             UndirectedEdge[3, 223] -> 
             RGBColor[
              0.4257649092191724, 0.5429712289379067, 0.9484129706530855], 
             UndirectedEdge[65, 227] -> 
             RGBColor[
              0.9155479974276244, 0.657189157644029, 0.2946818964954864], 
             UndirectedEdge[78, 85] -> 
             RGBColor[
              0.21682232686548605`, 0.34522439123812265`, 0.9356590828038773],
              UndirectedEdge[181, 393] -> 
             RGBColor[
              0.4409543407183537, 0.5561398931308579, 0.9493774176456293], 
             UndirectedEdge[45, 56] -> 
             RGBColor[
              0.5597280401148761, 0.3487238439697099, 0.5610837052268939], 
             UndirectedEdge[141, 310] -> 
             RGBColor[
              0.3031699755874952, 0.4359038694979436, 0.9405792867476138], 
             UndirectedEdge[39, 236] -> 
             RGBColor[
              0.4554923722273556, 0.5623404159424226, 0.9515950359894985], 
             UndirectedEdge[337, 375] -> 
             RGBColor[
              0.9092060692572821, 0.9298599802312014, 0.9710835499900707], 
             UndirectedEdge[57, 334] -> 
             RGBColor[
              0.5020235331688498, 0.6052327745876049, 0.9543192472492019], 
             UndirectedEdge[123, 438] -> 
             RGBColor[
              0.21421403684205725`, 0.34248291304835987`, 0.9355105445456623],
              UndirectedEdge[35, 385] -> 
             RGBColor[
              0.235922007593164, 0.36529936667261376`, 0.936746781365873], 
             UndirectedEdge[268, 285] -> 
             RGBColor[
              0.3620365603618595, 0.4879996049239992, 0.9442896273832655], 
             UndirectedEdge[169, 361] -> 
             RGBColor[
              0.5684718159304661, 0.6605218314458838, 0.9591906270789168], 
             UndirectedEdge[337, 361] -> 
             RGBColor[
              0.752206073850372, 0.8066735064022713, 0.9758502482621753], 
             UndirectedEdge[119, 270] -> 
             RGBColor[
              0.9903352312511376, 0.9902713839961873, 0.8098337599957988], 
             UndirectedEdge[254, 386] -> 
             RGBColor[
              0.20771262472504887`, 0.3356495167000475, 0.935140298743576], 
             UndirectedEdge[253, 488] -> 
             RGBColor[
              0.877198073649208, 0.9039154021300979, 0.937685633244106], 
             UndirectedEdge[340, 380] -> 
             RGBColor[
              0.3051428116901297, 0.43540236706824387`, 0.9407859230744895], 
             UndirectedEdge[388, 490] -> 
             RGBColor[
              0.9683628300119925, 0.9748687448836537, 0.8911081388957877], 
             UndirectedEdge[27, 311] -> 
             RGBColor[
              0.6294878924283578, 0.7084848809709354, 0.9650691972348303], 
             UndirectedEdge[222, 417] -> 
             RGBColor[
              0.5718731828738293, 0.6621247011020224, 0.9601331729684849], 
             UndirectedEdge[274, 361] -> 
             RGBColor[
              0.5534678542610545, 0.6483409394418851, 0.9580094602549781], 
             UndirectedEdge[65, 474] -> 
             RGBColor[
              0.989280991001634, 0.9770225512176633, 0.5810477888330006], 
             UndirectedEdge[243, 326] -> 
             RGBColor[
              0.8572408103331092, 0.41460626615910345`, 0.2014143032349089], 
             UndirectedEdge[47, 437] -> 
             RGBColor[
              0.2438820574631478, 0.37366588378227833`, 0.93720009443013], 
             UndirectedEdge[232, 414] -> 
             RGBColor[
              0.31542779716347613`, 0.44447776538926564`, 0.9414351563383871],
              UndirectedEdge[102, 196] -> 
             RGBColor[
              0.28611844580431445`, 0.41805900587053585`, 0.9396053942630224],
              UndirectedEdge[90, 257] -> 
             RGBColor[
              0.8618116052496472, 0.4654005988057779, 0.20640455492384144`], 
             UndirectedEdge[116, 310] -> 
             RGBColor[
              0.2727415097182925, 0.40399899789739224`, 0.9388435975423268], 
             UndirectedEdge[333, 459] -> 
             RGBColor[
              0.3845976264069504, 0.5075408663801063, 0.9457271985616913], 
             UndirectedEdge[68, 257] -> 
             RGBColor[
              0.8394199460541523, 0.30329924422110266`, 0.18535427265779897`],
              UndirectedEdge[220, 349] -> 
             RGBColor[
              0.3762573378366486, 0.5003169276156031, 0.9451957627490192], 
             UndirectedEdge[92, 204] -> 
             RGBColor[
              0.5555153199743827, 0.6500313882920026, 0.9581513473895016], 
             UndirectedEdge[120, 123] -> 
             RGBColor[
              0.20719251066229882`, 0.33510284384296096`, 0.9351106790171422],
              UndirectedEdge[190, 224] -> 
             RGBColor[
              0.2735379552710175, 0.40483611267087094`, 0.938888953938319], 
             UndirectedEdge[450, 469] -> 
             RGBColor[
              0.8390695807149537, 0.298125435533924, 0.18492162257597716`], 
             UndirectedEdge[405, 434] -> 
             RGBColor[
              0.9926076308918226, 0.9901160572249841, 0.6925776468321798], 
             UndirectedEdge[312, 400] -> 
             RGBColor[
              0.30016668312241634`, 0.43282459400155193`, 0.9404054205957836],
              UndirectedEdge[100, 259] -> 
             RGBColor[
              0.8965277758950481, 0.6152647749950997, 0.2349704456547408], 
             UndirectedEdge[87, 423] -> 
             RGBColor[
              0.18353957668712906`, 0.310242110552426, 0.9337636794186364], 
             UndirectedEdge[403, 449] -> 
             RGBColor[
              0.8286073759188407, 0.8669140710830616, 0.9833178599894938], 
             UndirectedEdge[268, 275] -> 
             RGBColor[
              0.4116793705742366, 0.5309977120097701, 0.9474528233525847], 
             UndirectedEdge[166, 210] -> 
             RGBColor[
              0.8370920629652436, 0.28611142656230293`, 0.18315270742599782`],
              UndirectedEdge[102, 496] -> 
             RGBColor[
              0.27671354998693043`, 0.4081738640616296, 0.9390697993595188], 
             UndirectedEdge[11, 202] -> 
             RGBColor[
              0.2389875961328362, 0.3685214945973489, 0.9369213620980754], 
             UndirectedEdge[187, 494] -> 
             RGBColor[
              0.26156581469201307`, 0.3922526338447824, 0.9382071582435395], 
             UndirectedEdge[158, 282] -> 
             RGBColor[
              0.4825898599888707, 0.5882261104425313, 0.9531290808792493], 
             UndirectedEdge[232, 372] -> 
             RGBColor[
              0.41332534927572523`, 0.5319581186500844, 0.9476862556607386], 
             UndirectedEdge[143, 477] -> 
             RGBColor[
              0.21179931439321417`, 0.33994488665237976`, 0.9353730296744625],
              UndirectedEdge[479, 482] -> 
             RGBColor[
              0.3849860560945393, 0.5078773046524521, 0.9457519489579096], 
             UndirectedEdge[45, 283] -> 
             RGBColor[
              0.23199831546813182`, 0.3611753174727555, 0.9365233329039347], 
             UndirectedEdge[323, 463] -> 
             RGBColor[
              0.25322101360276406`, 0.3834817188090337, 0.9377319341665338], 
             UndirectedEdge[130, 347] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[338, 369] -> 
             RGBColor[
              0.37002637582951403`, 0.49491998150227967`, 0.9447987313597479],
              UndirectedEdge[143, 386] -> 
             RGBColor[
              0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772],
              UndirectedEdge[168, 254] -> 
             RGBColor[
              0.5736452347236608, 0.5249664714796068, 0.591929563801219], 
             UndirectedEdge[86, 115] -> 
             RGBColor[
              0.9181807358610004, 0.8207272885954675, 0.6214818156174652], 
             UndirectedEdge[138, 457] -> 
             RGBColor[
              0.22077773189024535`, 0.349381772706308, 0.9358843372685399], 
             UndirectedEdge[11, 497] -> 
             RGBColor[
              0.2374558873234022, 0.36691157152268605`, 0.9368341335473384], 
             UndirectedEdge[154, 379] -> 
             RGBColor[
              0.3094202014132221, 0.4424259593777846, 0.9409369595178776], 
             UndirectedEdge[17, 467] -> 
             RGBColor[
              0.7934052123801664, 0.8390183037645371, 0.979914209324252], 
             UndirectedEdge[75, 93] -> 
             RGBColor[
              0.30711689507265494`, 0.43678253795558514`, 0.940923781155411], 
             UndirectedEdge[100, 315] -> 
             RGBColor[
              0.5583572344294613, 0.5386495393888345, 0.5986936802267802], 
             UndirectedEdge[45, 52] -> 
             RGBColor[
              0.5592887582023336, 0.3453473306953461, 0.5606630483713451], 
             UndirectedEdge[8, 203] -> 
             RGBColor[
              0.5774301323005686, 0.6678228201894449, 0.9598765616924215], 
             UndirectedEdge[244, 340] -> 
             RGBColor[
              0.33993779537767665`, 0.4688587654109236, 0.9428815136196439], 
             UndirectedEdge[104, 190] -> 
             RGBColor[
              0.24734164292075334`, 0.3773021274486088, 0.9373971127039427], 
             UndirectedEdge[38, 437] -> 
             RGBColor[
              0.2578995688543769, 0.3883991770160148, 0.9379983709668107], 
             UndirectedEdge[96, 465] -> 
             RGBColor[
              0.2893936582907169, 0.42150146185421045`, 0.9397919127688803], 
             UndirectedEdge[48, 346] -> 
             RGBColor[
              0.21269676667826953`, 0.34088816590573434`, 0.9354241382544346],
              UndirectedEdge[153, 342] -> 
             RGBColor[
              0.25246005368067864`, 0.38268190168327626`, 0.9376885986247103],
              UndirectedEdge[151, 327] -> 
             RGBColor[
              0.28193174194509296`, 0.41365851466213766`, 0.939366967671913], 
             UndirectedEdge[375, 489] -> 
             RGBColor[
              0.9741495163492516, 0.9792601983573855, 0.8847051301265769], 
             UndirectedEdge[203, 289] -> 
             RGBColor[
              0.48696884397226536`, 0.5940035787603833, 0.9528597515235682], 
             UndirectedEdge[6, 79] -> 
             RGBColor[
              0.9107592672849488, 0.9273249908421985, 0.7765494419084453], 
             UndirectedEdge[105, 463] -> 
             RGBColor[
              0.2565013158137106, 0.3869295244159112, 0.9379187425246749], 
             UndirectedEdge[10, 125] -> 
             RGBColor[
              0.21381800062875955`, 0.3420666538780378, 0.935487990869198], 
             UndirectedEdge[32, 331] -> 
             RGBColor[
              0.6862012136677067, 0.7532861971667737, 0.9704389262848694], 
             UndirectedEdge[26, 44] -> 
             RGBColor[
              0.4416533932183588, 0.5557823986053863, 0.949688034527277], 
             UndirectedEdge[86, 253] -> 
             RGBColor[
              0.9501124692155603, 0.8447770986590462, 0.5741725699000219], 
             UndirectedEdge[370, 466] -> 
             RGBColor[
              0.5474757553674385, 0.6435045075658272, 0.9575184434137474], 
             UndirectedEdge[301, 456] -> 
             RGBColor[
              0.21620560443164671`, 0.3445761768576967, 0.9356239613736292], 
             UndirectedEdge[21, 337] -> 
             RGBColor[
              0.9205492329643337, 0.9192823831910986, 0.6833909335036439], 
             UndirectedEdge[61, 172] -> 
             RGBColor[
              0.3377395733706075, 0.4669547759942509, 0.9427414448571648], 
             UndirectedEdge[291, 359] -> 
             RGBColor[
              0.5201892016597764, 0.619316785102851, 0.95601113315619], 
             UndirectedEdge[134, 499] -> 
             RGBColor[
              0.2469625122439105, 0.37690363706897373`, 0.93737552177277], 
             UndirectedEdge[140, 244] -> 
             RGBColor[
              0.42103754660959536`, 0.5378457039996745, 0.9483965938455836], 
             UndirectedEdge[108, 364] -> 
             RGBColor[
              0.27183868506633, 0.4030500719457907, 0.938792183014007], 
             UndirectedEdge[113, 421] -> 
             RGBColor[
              0.17912443323835392`, 0.3056015148515002, 0.9335122435308479], 
             UndirectedEdge[54, 55] -> 
             RGBColor[
              0.22009923076516985`, 0.34866862500439766`, 0.9358456976332195],
              UndirectedEdge[56, 210] -> 
             RGBColor[
              0.8363686612775614, 0.28055104419413623`, 0.18245997715290796`],
              UndirectedEdge[36, 58] -> 
             RGBColor[
              0.28475051663686596`, 0.4160326690739975, 0.9395490426575464], 
             UndirectedEdge[25, 288] -> 
             RGBColor[
              0.2847205959795895, 0.4161617683290476, 0.9395414602803146], 
             UndirectedEdge[262, 344] -> 
             RGBColor[
              0.4699143971667351, 0.5805367028791276, 0.9514125291795714], 
             UndirectedEdge[8, 439] -> 
             RGBColor[
              0.7406030565482964, 0.7972768000160912, 0.9749233642591105], 
             UndirectedEdge[102, 186] -> 
             RGBColor[
              0.256123983487738, 0.3865329242170628, 0.9378972540069239], 
             UndirectedEdge[85, 145] -> 
             RGBColor[
              0.21743686076267443`, 0.3458703053277671, 0.9356940796002007], 
             UndirectedEdge[421, 423] -> 
             RGBColor[
              0.18344124862659156`, 0.31013876152644193`, 0.9337580797810521],
              UndirectedEdge[406, 476] -> 
             RGBColor[
              0.9195554041525527, 0.6768776802935997, 0.3060621599750899], 
             UndirectedEdge[111, 400] -> 
             RGBColor[
              0.2845065356159251, 0.4163647860615299, 0.939513598362401], 
             UndirectedEdge[137, 183] -> 
             RGBColor[
              0.2125239415632086, 0.34070651575206007`, 0.9354142961198038], 
             UndirectedEdge[85, 358] -> 
             RGBColor[
              0.2199208837213561, 0.34848117095349374`, 0.935835541032915], 
             UndirectedEdge[399, 412] -> 
             RGBColor[
              0.24194122045751632`, 0.37162594103318614`, 0.9370895666338703],
              UndirectedEdge[283, 292] -> 
             RGBColor[
              0.18009239570445779`, 0.3066189047757405, 0.9335673675613205], 
             UndirectedEdge[240, 310] -> 
             RGBColor[
              0.2766913122921885, 0.4081504908345045, 0.939068532955701], 
             UndirectedEdge[186, 300] -> 
             RGBColor[
              0.23083402862066274`, 0.35995157817601575`, 0.9364570284903794],
              UndirectedEdge[37, 240] -> 
             RGBColor[
              0.28113287624005423`, 0.4128188561551308, 0.9393214734518269], 
             UndirectedEdge[36, 429] -> 
             RGBColor[
              0.2739936283843697, 0.4053150540043482, 0.9389149038480165], 
             UndirectedEdge[56, 276] -> 
             RGBColor[
              0.7281068824339767, 0.4924523185511463, 0.5729718060098814], 
             UndirectedEdge[95, 174] -> 
             RGBColor[
              0.24687001390337449`, 0.3768064154483368, 0.9373702541291156], 
             UndirectedEdge[7, 28] -> 
             RGBColor[
              0.901769090567154, 0.9237583305634441, 0.9644245605513657], 
             UndirectedEdge[251, 367] -> 
             RGBColor[
              0.24419513183599667`, 0.3739949447982042, 0.9372179235525118], 
             UndirectedEdge[31, 314] -> 
             RGBColor[
              0.3915568678230763, 0.5135686115131106, 0.9461706352709112], 
             UndirectedEdge[238, 436] -> 
             RGBColor[
              0.3965368671240651, 0.5173498014044343, 0.9466350145946033], 
             UndirectedEdge[291, 488] -> 
             RGBColor[
              0.7121457205579194, 0.7750529164985673, 0.971943688111231], 
             UndirectedEdge[96, 171] -> 
             RGBColor[
              0.2789519797924134, 0.41052659571183897`, 0.939197274625481], 
             UndirectedEdge[127, 179] -> 
             RGBColor[
              0.20245447418328588`, 0.33012286709465477`, 0.9348408548489592],
              UndirectedEdge[296, 453] -> 
             RGBColor[
              0.2988633264806147, 0.4310225569001501, 0.9403470186360454], 
             UndirectedEdge[14, 494] -> 
             RGBColor[
              0.2826231066390982, 0.4143851827905905, 0.9394063398684542], 
             UndirectedEdge[317, 420] -> 
             RGBColor[
              0.9260215766566631, 0.7697821905786719, 0.5811912001414211], 
             UndirectedEdge[7, 388] -> 
             RGBColor[
              0.8924271040987608, 0.9167910923514154, 0.9802381068620604], 
             UndirectedEdge[146, 271] -> 
             RGBColor[
              0.25686927492861433`, 0.3873162727756304, 0.9379396972519218], 
             UndirectedEdge[331, 449] -> 
             RGBColor[
              0.7824972356635673, 0.8301470968699212, 0.9789198336489376], 
             UndirectedEdge[27, 359] -> 
             RGBColor[
              0.44878508964320496`, 0.5615402381340974, 0.9502583075299758], 
             UndirectedEdge[100, 471] -> 
             RGBColor[
              0.894013717811025, 0.6013444138663678, 0.23277457969666004`], 
             UndirectedEdge[219, 337] -> 
             RGBColor[
              0.6932397997764845, 0.7588302526554731, 0.971188910299956], 
             UndirectedEdge[199, 419] -> 
             RGBColor[
              0.4277672068152066, 0.5433200836247167, 0.948923355062986], 
             UndirectedEdge[266, 437] -> 
             RGBColor[
              0.2726756027922651, 0.40392972553939704`, 0.9388398442403902], 
             UndirectedEdge[327, 399] -> 
             RGBColor[
              0.24928505714751653`, 0.3793447790205158, 0.9375077872691331], 
             UndirectedEdge[311, 419] -> 
             RGBColor[
              0.6297737018777119, 0.70871691395749, 0.9650916972016379], 
             UndirectedEdge[267, 329] -> 
             RGBColor[
              0.9358102453449542, 0.941979730786866, 0.7003355368972839], 
             UndirectedEdge[219, 244] -> 
             RGBColor[
              0.43435496414043395`, 0.548657383494032, 0.949444989736919], 
             UndirectedEdge[17, 205] -> 
             RGBColor[
              0.9368989095333399, 0.9481665884975428, 0.7789256469520753], 
             UndirectedEdge[175, 361] -> 
             RGBColor[
              0.7999658560018515, 0.8442393091304512, 0.9624964661202554], 
             UndirectedEdge[189, 266] -> 
             RGBColor[
              0.2746480537102089, 0.4060028965147674, 0.9389521724021874], 
             UndirectedEdge[225, 280] -> 
             RGBColor[
              0.26557083518380836`, 0.39646216431462483`, 0.9384352382356503],
              UndirectedEdge[300, 458] -> 
             RGBColor[
              0.22822845140871784`, 0.35721295132312475`, 0.9363086447227651],
              UndirectedEdge[171, 343] -> 
             RGBColor[
              0.2773148667291586, 0.40880588608339485`, 0.9391040434584204], 
             UndirectedEdge[358, 408] -> 
             RGBColor[
              0.2240653730927813, 0.35283729205866493`, 0.936071563571395], 
             UndirectedEdge[380, 411] -> 
             RGBColor[
              0.2562205129796168, 0.38663438283335066`, 0.9379027512186837], 
             UndirectedEdge[345, 498] -> 
             RGBColor[
              0.5608073530060538, 0.6540616711594758, 0.9587498403781267], 
             UndirectedEdge[161, 450] -> 
             RGBColor[
              0.9040202207813182, 0.5580851531997648, 0.2907664410126593], 
             UndirectedEdge[94, 214] -> 
             RGBColor[
              0.5776130969249946, 0.6468062636067821, 0.9475190708650497], 
             UndirectedEdge[157, 343] -> 
             RGBColor[
              0.2977155588527831, 0.4302483069839126, 0.9402658326947413], 
             UndirectedEdge[155, 332] -> 
             RGBColor[
              0.4840405870433834, 0.5906167908800439, 0.9529081554374272], 
             UndirectedEdge[127, 168] -> 
             RGBColor[
              0.5683860156508949, 0.5194386987803812, 0.5916300590553423], 
             UndirectedEdge[378, 380] -> 
             RGBColor[
              0.27796774382392075`, 0.40949210130478847`, 0.939141223843122], 
             UndirectedEdge[160, 481] -> 
             RGBColor[
              0.3703492229848604, 0.49519961548147085`, 0.9448193028950042], 
             UndirectedEdge[23, 485] -> 
             RGBColor[
              0.2352513492635514, 0.3645944622459968, 0.9367085883661517], 
             UndirectedEdge[352, 399] -> 
             RGBColor[
              0.23466592421327268`, 0.3639791434000619, 0.936675249275597], 
             UndirectedEdge[389, 456] -> 
             RGBColor[
              0.22107915567658082`, 0.3496985882171184, 0.9359015029072553], 
             UndirectedEdge[105, 263] -> 
             RGBColor[
              0.2596529612026372, 0.3902421035455322, 0.9380982240671327], 
             UndirectedEdge[143, 347] -> 
             RGBColor[
              0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772],
              UndirectedEdge[98, 484] -> 
             RGBColor[
              0.9940632182259341, 0.9897101490230129, 0.5951961253421731], 
             UndirectedEdge[100, 500] -> 
             RGBColor[
              0.8753537574413516, 0.45791578161828494`, 0.21490578057324983`],
              UndirectedEdge[89, 424] -> 
             RGBColor[
              0.3030480744366626, 0.4347576504686087, 0.9406096220363795], 
             UndirectedEdge[231, 442] -> 
             RGBColor[
              0.2711958428958343, 0.40237440406605196`, 0.938755574103397], 
             UndirectedEdge[15, 104] -> 
             RGBColor[
              0.24040623048550225`, 0.3700125692486139, 0.9370021512257783], 
             UndirectedEdge[75, 182] -> 
             RGBColor[
              0.3617675856264607, 0.48776663252726005`, 0.9442724885509708], 
             UndirectedEdge[290, 316] -> 
             RGBColor[
              0.268490139738015, 0.3995305384956953, 0.9386014883112883], 
             UndirectedEdge[344, 424] -> 
             RGBColor[
              0.39216870621134226`, 0.5138154925134429, 0.9462878321282429], 
             UndirectedEdge[369, 425] -> 
             RGBColor[
              0.397645136695217, 0.5188419640048679, 0.9465585743797993], 
             UndirectedEdge[106, 255] -> 
             RGBColor[
              0.45772043203322, 0.569123825312507, 0.9508706958509441], 
             UndirectedEdge[84, 242] -> 
             RGBColor[
              0.22916096004104347`, 0.3581930770201611, 0.9363617497098533], 
             UndirectedEdge[143, 446] -> 
             RGBColor[
              0.20353913733189777`, 0.3312629168354616, 0.9349026248106573], 
             UndirectedEdge[376, 415] -> 
             RGBColor[
              0.28323389332621046`, 0.41502715832485815`, 0.9394411232667073],
              UndirectedEdge[93, 108] -> 
             RGBColor[
              0.27719798724909794`, 0.408683038339264, 0.9390973873449386], 
             UndirectedEdge[78, 183] -> 
             RGBColor[
              0.21219822021020854`, 0.34036416195813046`, 0.935395746770612], 
             UndirectedEdge[17, 298] -> 
             RGBColor[
              0.8908055349705915, 0.9157681695861948, 0.9894470212286257], 
             UndirectedEdge[204, 370] -> 
             RGBColor[
              0.546668194471859, 0.642848893250592, 0.9574548692618543], 
             UndirectedEdge[208, 314] -> 
             RGBColor[
              0.32609699892407057`, 0.4568705631814669, 0.9419995903085558], 
             UndirectedEdge[313, 379] -> 
             RGBColor[
              0.288128547073246, 0.4201206026991259, 0.9397217393007642], 
             UndirectedEdge[3, 221] -> 
             RGBColor[
              0.4991380572062573, 0.6042617866100937, 0.9537131227476765], 
             UndirectedEdge[154, 229] -> 
             RGBColor[
              0.3002585012900294, 0.4328475787158096, 0.940413341505228], 
             UndirectedEdge[25, 180] -> 
             RGBColor[
              0.2917531123703574, 0.42355338894303707`, 0.9399419516850931], 
             UndirectedEdge[371, 419] -> 
             RGBColor[
              0.43781722710861815`, 0.5520249060741627, 0.9495637334691982], 
             UndirectedEdge[31, 419] -> 
             RGBColor[
              0.4828643991449212, 0.5910425023553091, 0.9524340994377012], 
             UndirectedEdge[321, 482] -> 
             RGBColor[
              0.3458284457686297, 0.47396095070686983`, 0.9432568606536578], 
             UndirectedEdge[212, 300] -> 
             RGBColor[
              0.22223694937519295`, 0.35091550280272016`, 0.9359674375455889],
              UndirectedEdge[376, 414] -> 
             RGBColor[
              0.27705653417076703`, 0.40853436218529504`, 0.9390893318013886],
              UndirectedEdge[140, 274] -> 
             RGBColor[
              0.4811841626563286, 0.5896860062007292, 0.9522997264014235], 
             UndirectedEdge[1, 131] -> 
             RGBColor[
              0.26488726968740706`, 0.3957436936373514, 0.9383963101918749], 
             UndirectedEdge[360, 466] -> 
             RGBColor[
              0.5414372478398441, 0.638602175123262, 0.9570430699813932], 
             UndirectedEdge[165, 182] -> 
             RGBColor[
              0.4013099579800705, 0.5220162480025345, 0.9467920935513959], 
             UndirectedEdge[268, 480] -> 
             RGBColor[
              0.3816010072146523, 0.5049453454501976, 0.9455362566365644], 
             UndirectedEdge[54, 385] -> 
             RGBColor[
              0.23109619211781043`, 0.36022712863364376`, 0.9364719583137058],
              UndirectedEdge[149, 158] -> 
             RGBColor[
              0.3556980515257828, 0.48250950715290686`, 0.943885743205154], 
             UndirectedEdge[229, 379] -> 
             RGBColor[
              0.30013749915285226`, 0.43274277274633094`, 0.9404056313560452],
              UndirectedEdge[98, 253] -> 
             RGBColor[
              0.9901332923121124, 0.9901471046097305, 0.8102166844391167], 
             UndirectedEdge[121, 469] -> 
             RGBColor[
              0.8439483097229172, 0.3356254845618147, 0.18959349898373934`], 
             UndirectedEdge[34, 269] -> 
             RGBColor[
              0.4963462045644428, 0.6018763440007352, 0.9535261877805588], 
             UndirectedEdge[145, 286] -> 
             RGBColor[
              0.22187921582518422`, 0.3505395021600439, 0.9359470651491353], 
             UndirectedEdge[34, 234] -> 
             RGBColor[
              0.4661658558479902, 0.5757356428509766, 0.951603122647781], 
             UndirectedEdge[85, 286] -> 
             RGBColor[
              0.21865790979829205`, 0.3471537052831816, 0.935763616536399], 
             UndirectedEdge[86, 261] -> 
             RGBColor[
              0.897589954080166, 0.6247029436909717, 0.23609548573218275`], 
             UndirectedEdge[140, 255] -> 
             RGBColor[
              0.4486097951007969, 0.5617273998212495, 0.950153473138261], 
             UndirectedEdge[345, 448] -> 
             RGBColor[
              0.6138322543981429, 0.6971096748541594, 0.9629241548523259], 
             UndirectedEdge[146, 444] -> 
             RGBColor[
              0.2646131387661169, 0.39545556465817117`, 0.9383806988414477], 
             UndirectedEdge[215, 224] -> 
             RGBColor[
              0.2915446973152564, 0.4237623402527527, 0.9399144112591507], 
             UndirectedEdge[40, 359] -> 
             RGBColor[
              0.38582570994179444`, 0.508604570612715, 0.9458054509585798], 
             UndirectedEdge[88, 495] -> 
             RGBColor[
              0.8544062989949438, 0.4062909143031017, 0.1992274995322182], 
             UndirectedEdge[341, 403] -> 
             RGBColor[
              0.9612426733705868, 0.9674078133042042, 0.7674804702008887], 
             UndirectedEdge[134, 416] -> 
             RGBColor[
              0.24737003573452257`, 0.37733197009608865`, 0.9373987296326833],
              UndirectedEdge[113, 423] -> 
             RGBColor[
              0.1835090760837748, 0.31021005248445066`, 0.9337619424543968], 
             UndirectedEdge[204, 362] -> 
             RGBColor[
              0.4451772959687064, 0.5586930048020928, 0.9499517048675632], 
             UndirectedEdge[231, 256] -> 
             RGBColor[
              0.27391624912615603`, 0.40523372349783726`, 0.9389104972137335],
              UndirectedEdge[183, 407] -> 
             RGBColor[
              0.2096628417623121, 0.3376993184571131, 0.9352513607187605], 
             UndirectedEdge[231, 271] -> 
             RGBColor[
              0.25712583983655113`, 0.38758593876102676`, 0.9379543082438752],
              UndirectedEdge[106, 140] -> 
             RGBColor[
              0.508744701282457, 0.6120608930455363, 0.9544693929596517], 
             UndirectedEdge[96, 147] -> 
             RGBColor[
              0.27382745193814473`, 0.40514039202317054`, 0.9389054403452399],
              UndirectedEdge[149, 275] -> 
             RGBColor[
              0.38378936730216673`, 0.5068407929678266, 0.9456756970062499], 
             UndirectedEdge[207, 287] -> 
             RGBColor[
              0.21343735530821623`, 0.3416665715118395, 0.9354663136813074], 
             UndirectedEdge[223, 480] -> 
             RGBColor[
              0.3717055099769321, 0.496374363105037, 0.9449057243028214], 
             UndirectedEdge[11, 102] -> 
             RGBColor[
              0.2577278443328788, 0.3882186836559568, 0.9379885915093551], 
             UndirectedEdge[230, 339] -> 
             RGBColor[
              0.21778435426976317`, 0.3462355430360783, 0.9357138688413589], 
             UndirectedEdge[103, 449] -> 
             RGBColor[
              0.6043292409167387, 0.6883441793156388, 0.9628942898259707], 
             UndirectedEdge[226, 396] -> 
             RGBColor[
              0.5864855268156967, 0.6472607121015193, 0.7362180745608087], 
             UndirectedEdge[144, 279] -> 
             RGBColor[
              0.2623939933592224, 0.3931231021335797, 0.9382543217934566], 
             UndirectedEdge[205, 228] -> 
             RGBColor[
              0.9934539331599859, 0.9884069498751192, 0.5288792059852668], 
             UndirectedEdge[267, 406] -> 
             RGBColor[
              0.9898404936899885, 0.9773917410301207, 0.415032665757733], 
             UndirectedEdge[209, 233] -> 
             RGBColor[
              0.7045416845554648, 0.49561598240663746`, 0.5739669497124782], 
             UndirectedEdge[387, 405] -> 
             RGBColor[
              0.8845632449194131, 0.9069230619459494, 0.7839577394340637], 
             UndirectedEdge[75, 206] -> 
             RGBColor[
              0.34384133423410757`, 0.4722398145707964, 0.9431302436638118], 
             UndirectedEdge[183, 404] -> 
             RGBColor[
              0.20920782453695042`, 0.33722106650349953`, 0.9352254481609139],
              UndirectedEdge[319, 488] -> 
             RGBColor[
              0.7421269925364968, 0.7984745140343386, 0.9749319411111395], 
             UndirectedEdge[220, 371] -> 
             RGBColor[
              0.3509285621764658, 0.4783784152000333, 0.9435818355613093], 
             UndirectedEdge[66, 460] -> 
             RGBColor[
              0.2558136629427209, 0.38620675764879087`, 0.9378795817109632], 
             UndirectedEdge[87, 446] -> 
             RGBColor[
              0.20370226760912918`, 0.33143437709988877`, 0.934911914838616], 
             UndirectedEdge[273, 308] -> 
             RGBColor[
              0.23624385022904204`, 0.36563764368892326`, 0.9367651098278627],
              UndirectedEdge[326, 428] -> 
             RGBColor[
              0.8527545036662538, 0.3801225472055363, 0.19711821090416948`], 
             UndirectedEdge[130, 315] -> 
             RGBColor[
              0.1822133081343763, 0.30884811821319974`, 0.9336881503865955], 
             UndirectedEdge[95, 407] -> 
             RGBColor[
              0.22072063099008732`, 0.34932175603983573`, 0.9358810854567492],
              UndirectedEdge[148, 153] -> 
             RGBColor[
              0.2422944032111111, 0.37199715850029413`, 0.9371096798692006], 
             UndirectedEdge[85, 137] -> 
             RGBColor[
              0.21714804821848613`, 0.34556674503205226`, 0.9356776321530691],
              UndirectedEdge[289, 359] -> 
             RGBColor[
              0.4124111574915527, 0.5316315490568694, 0.9474994521678624], 
             UndirectedEdge[32, 449] -> 
             RGBColor[
              0.6320067542390264, 0.7108140314884382, 0.9650731650607731], 
             UndirectedEdge[329, 406] -> 
             RGBColor[
              0.9365881325497546, 0.9446037269852596, 0.7033574817962612], 
             UndirectedEdge[168, 213] -> 
             RGBColor[
              0.9074990588325569, 0.6709655443987909, 0.2444294609060539], 
             UndirectedEdge[111, 464] -> 
             RGBColor[
              0.2584790029138965, 0.3890081989508112, 0.9380313688793045], 
             UndirectedEdge[50, 117] -> 
             RGBColor[
              0.41100665014042015`, 0.5304150353819104, 0.9474099582014052], 
             UndirectedEdge[357, 420] -> 
             RGBColor[
              0.937892556639665, 0.822845791169284, 0.5910531975827036], 
             UndirectedEdge[153, 190] -> 
             RGBColor[
              0.24652129125596123`, 0.3764398858356126, 0.9373503948902342], 
             UndirectedEdge[165, 275] -> 
             RGBColor[
              0.41886860868054065`, 0.537224668715837, 0.9479109152475247], 
             UndirectedEdge[152, 301] -> 
             RGBColor[
              0.2063778078751808, 0.33424653955855976`, 0.9350642828986606], 
             UndirectedEdge[208, 349] -> 
             RGBColor[
              0.3678599975315118, 0.49304357350588934`, 0.9446606916502523], 
             UndirectedEdge[5, 23] -> 
             RGBColor[
              0.23055442452635688`, 0.3596576965449768, 0.9364411054508459], 
             UndirectedEdge[56, 227] -> 
             RGBColor[
              0.8411523878247509, 0.31732086267817405`, 0.187040879096943], 
             UndirectedEdge[56, 326] -> 
             RGBColor[
              0.8559245599190561, 0.404488988692082, 0.2001538603519194], 
             UndirectedEdge[155, 181] -> 
             RGBColor[
              0.49329315877378277`, 0.5986309034651389, 0.9534977211263604], 
             UndirectedEdge[148, 323] -> 
             RGBColor[
              0.23950025424315785`, 0.36906033077569844`, 0.9369505572190486],
              UndirectedEdge[177, 438] -> 
             RGBColor[
              0.21508055771107348`, 0.3433936814222922, 0.9355598916272501], 
             UndirectedEdge[53, 90] -> 
             RGBColor[
              0.9206410418975434, 0.7056328015929743, 0.28606405077970154`], 
             UndirectedEdge[30, 217] -> 
             RGBColor[
              0.2938254921740675, 0.42514500116830317`, 0.9400814485951139], 
             UndirectedEdge[43, 290] -> 
             RGBColor[
              0.2898165263474991, 0.4219459229932718, 0.9398159944791369], 
             UndirectedEdge[114, 397] -> 
             RGBColor[
              0.4296132686116584, 0.545245204928905, 0.9489508667899835], 
             UndirectedEdge[227, 320] -> 
             RGBColor[
              0.9171168323829694, 0.670650788557899, 0.5149397016540836], 
             UndirectedEdge[298, 432] -> 
             RGBColor[
              0.9001321413614187, 0.9232049523582542, 0.9903366012721426], 
             UndirectedEdge[42, 85] -> 
             RGBColor[
              0.22334491181980198`, 0.3520800415808806, 0.9360305343677259], 
             UndirectedEdge[329, 413] -> 
             RGBColor[
              0.9281969547806851, 0.9162983140279535, 0.6707593407043844], 
             UndirectedEdge[244, 380] -> 
             RGBColor[
              0.3076460451816098, 0.43757054210239044`, 0.9409454268990441], 
             UndirectedEdge[87, 113] -> 
             RGBColor[
              0.17922276129889142`, 0.3057048638774843, 0.9335178431684322], 
             UndirectedEdge[334, 370] -> 
             RGBColor[
              0.49712370807879736`, 0.6012548758448955, 0.9539335150694623], 
             UndirectedEdge[24, 278] -> 
             RGBColor[
              0.8926678774514412, 0.9169265621366819, 0.9783016146877055], 
             UndirectedEdge[51, 325] -> 
             RGBColor[
              0.17897196058988912`, 0.30544125643063946`, 0.933503560439081], 
             UndirectedEdge[112, 463] -> 
             RGBColor[
              0.2576804433404335, 0.3881688622075002, 0.9379858920929589], 
             UndirectedEdge[308, 421] -> 
             RGBColor[
              0.1790014452743907, 0.3054722467034876, 0.9335052395482446], 
             UndirectedEdge[302, 421] -> 
             RGBColor[
              0.18460298206136966`, 0.31135981702454774`, 0.9338242387815321],
              UndirectedEdge[103, 488] -> 
             RGBColor[
              0.6248600030483947, 0.70438296673246, 0.9649406043243738], 
             UndirectedEdge[225, 424] -> 
             RGBColor[
              0.2974218624617132, 0.42884414496049433`, 0.940289217587641], 
             UndirectedEdge[205, 388] -> 
             RGBColor[
              0.9699993320336204, 0.9742898944709728, 0.7727192137216462], 
             UndirectedEdge[114, 297] -> 
             RGBColor[
              0.5100213466264654, 0.6130973312480197, 0.954569895157638], 
             UndirectedEdge[203, 381] -> 
             RGBColor[
              0.5519357188644908, 0.6471253068518, 0.9578695480776199], 
             UndirectedEdge[17, 252] -> 
             RGBColor[
              0.8078836333626171, 0.8503289562761027, 0.9813572830192461], 
             UndirectedEdge[361, 363] -> 
             RGBColor[
              0.5245064025228867, 0.6235116591529769, 0.9560934187929221], 
             UndirectedEdge[318, 383] -> 
             RGBColor[
              0.3354424216880899, 0.46496509866505487`, 0.9425950723832464], 
             UndirectedEdge[209, 273] -> 
             RGBColor[
              0.4297324939516893, 0.5421711471050089, 0.9494994222745707], 
             UndirectedEdge[47, 230] -> 
             RGBColor[
              0.22790583767600858`, 0.3568738638351552, 0.9362902723479516], 
             UndirectedEdge[1, 170] -> 
             RGBColor[
              0.2814230291570491, 0.41312382526764985`, 0.939337997231207], 
             UndirectedEdge[139, 247] -> 
             RGBColor[
              0.529523280699882, 0.6289298798809373, 0.9561051588458358], 
             UndirectedEdge[246, 288] -> 
             RGBColor[
              0.2751436592994766, 0.40652380941229693`, 0.9389803964073136], 
             UndirectedEdge[1, 147] -> 
             RGBColor[
              0.2588293294875211, 0.38937641439167825`, 0.9380513194594108], 
             UndirectedEdge[352, 457] -> 
             RGBColor[
              0.22470998276050042`, 0.3535148176900512, 0.9361082731383572], 
             UndirectedEdge[157, 238] -> 
             RGBColor[
              0.31134876495031627`, 0.4435229307952213, 0.9410808428186908], 
             UndirectedEdge[97, 145] -> 
             RGBColor[
              0.2261963371710197, 0.3550770704158197, 0.9361929188231719], 
             UndirectedEdge[83, 237] -> 
             RGBColor[
              0.913419047498675, 0.933799570648643, 0.9916039182408752], 
             UndirectedEdge[73, 494] -> 
             RGBColor[
              0.25320700081228975`, 0.383466990477783, 0.9377311361588463], 
             UndirectedEdge[101, 197] -> 
             RGBColor[
              0.6092291752169602, 0.6927921015850171, 0.9629587335694303], 
             UndirectedEdge[224, 356] -> 
             RGBColor[
              0.28415211148803254`, 0.41599226383132715`, 0.939493414432641], 
             UndirectedEdge[182, 441] -> 
             RGBColor[
              0.41435953118072005`, 0.5333191324183171, 0.9476236008164568], 
             UndirectedEdge[160, 480] -> 
             RGBColor[
              0.3880144919727734, 0.5105003835965654, 0.94594491821413], 
             UndirectedEdge[263, 440] -> 
             RGBColor[
              0.2775372454156354, 0.40903962018250506`, 0.9391167075956355], 
             UndirectedEdge[31, 223] -> 
             RGBColor[
              0.42145102378698707`, 0.5394614268850837, 0.9480754644545675], 
             UndirectedEdge[5, 102] -> 
             RGBColor[
              0.2575724490549457, 0.3880553533662194, 0.9379797419781635], 
             UndirectedEdge[171, 216] -> 
             RGBColor[
              0.26381410331866717`, 0.39461572774112796`, 0.9383351949547825],
              UndirectedEdge[102, 414] -> 
             RGBColor[
              0.27559776236137046`, 0.40700110052214455`, 0.9390062569049031],
              UndirectedEdge[68, 205] -> 
             RGBColor[
              0.9069065109079608, 0.5719171126049378, 0.3681050087560027], 
             UndirectedEdge[111, 376] -> 
             RGBColor[
              0.2762731715166523, 0.4077109983677596, 0.9390447204571181], 
             UndirectedEdge[302, 325] -> 
             RGBColor[
              0.18458313935535953`, 0.31133896108243087`, 0.9338231087687794],
              UndirectedEdge[39, 315] -> 
             RGBColor[
              0.40458060190845924`, 0.5088289173445842, 0.948695685987052], 
             UndirectedEdge[66, 314] -> 
             RGBColor[
              0.29667827269945046`, 0.4271859979700665, 0.9402789673950056], 
             UndirectedEdge[274, 370] -> 
             RGBColor[
              0.5270887992770681, 0.6269534581897589, 0.9559135075504326], 
             UndirectedEdge[94, 477] -> 
             RGBColor[
              0.6000453532177727, 0.6703839872576882, 0.948796554675374], 
             UndirectedEdge[99, 329] -> 
             RGBColor[
              0.9380897089070905, 0.9489785735157732, 0.7678909167681753], 
             UndirectedEdge[25, 465] -> 
             RGBColor[
              0.2980004320712376, 0.430119718051609, 0.9402977272999771], 
             UndirectedEdge[223, 381] -> 
             RGBColor[
              0.47958429341648956`, 0.5866642295649169, 0.9526498297239985], 
             UndirectedEdge[196, 318] -> 
             RGBColor[
              0.3188208288656592, 0.44936205704600285`, 0.9415801260303202], 
             UndirectedEdge[76, 462] -> 
             RGBColor[
              0.4376018334802528, 0.5531637078002476, 0.949183806517649], 
             UndirectedEdge[89, 440] -> 
             RGBColor[
              0.2835877779164691, 0.415399113466799, 0.9394612764705972], 
             UndirectedEdge[88, 326] -> 
             RGBColor[
              0.8708928189630238, 0.5066362693068722, 0.21398214224720047`], 
             UndirectedEdge[149, 282] -> 
             RGBColor[
              0.48076658116172494`, 0.586646877963116, 0.9530129031646457], 
             UndirectedEdge[238, 462] -> 
             RGBColor[
              0.392016142899485, 0.5136796738226148, 0.9462791266236859], 
             UndirectedEdge[168, 261] -> 
             RGBColor[
              0.8953895182633258, 0.6159789489289689, 0.23432496342308617`], 
             UndirectedEdge[155, 344] -> 
             RGBColor[
              0.5148160505883743, 0.6169898879232494, 0.9549473518170989], 
             UndirectedEdge[4, 496] -> 
             RGBColor[
              0.3005965950412318, 0.4318380479282125, 0.9404825707076422], 
             UndirectedEdge[87, 226] -> 
             RGBColor[
              0.17933912709972993`, 0.30582717171218354`, 0.9335244700286423],
              UndirectedEdge[128, 362] -> 
             RGBColor[
              0.4416023765346493, 0.55579072415724, 0.9496702741143528], 
             UndirectedEdge[295, 389] -> 
             RGBColor[
              0.22404383278435813`, 0.3528146518287777, 0.9360703368826964], 
             UndirectedEdge[89, 133] -> 
             RGBColor[
              0.3153376912434113, 0.4454022988525135, 0.9413927055520241], 
             UndirectedEdge[33, 164] -> 
             RGBColor[
              0.8479694807729221, 0.33824875648589925`, 0.19233659900141542`],
              UndirectedEdge[276, 396] -> 
             RGBColor[
              0.8065431088390325, 0.8453068187334528, 0.7510492031181083], 
             UndirectedEdge[50, 274] -> 
             RGBColor[
              0.4518361438965558, 0.5655238171616463, 0.9500822208063486], 
             UndirectedEdge[21, 375] -> 
             RGBColor[
              0.9695446020803578, 0.9577696846543478, 0.6679456249234423], 
             UndirectedEdge[41, 485] -> 
             RGBColor[
              0.24026393309017596`, 0.36986300566395003`, 0.9369940475996247],
              UndirectedEdge[30, 316] -> 
             RGBColor[
              0.25921313179459604`, 0.3897798149508858, 0.938073176433014], 
             UndirectedEdge[285, 324] -> 
             RGBColor[
              0.3420478957119857, 0.4706864282637755, 0.9430159673470576], 
             UndirectedEdge[95, 358] -> 
             RGBColor[
              0.2263545662938538, 0.3552433792562242, 0.9362019297376383], 
             UndirectedEdge[333, 492] -> 
             RGBColor[
              0.32763422405457243`, 0.45523169861929097`, 0.9422062993288807],
              UndirectedEdge[332, 393] -> 
             RGBColor[
              0.4317017689879543, 0.548125780545763, 0.9487878519566961], 
             UndirectedEdge[418, 420] -> 
             RGBColor[
              0.9735581601714495, 0.9798002996671817, 0.9296433170801228], 
             UndirectedEdge[107, 273] -> 
             RGBColor[
              0.2391065540897807, 0.3686465269524677, 0.9369281365777409], 
             UndirectedEdge[310, 483] -> 
             RGBColor[
              0.2967031212326041, 0.4291841708528518, 0.9402081758700394], 
             UndirectedEdge[155, 403] -> 
             RGBColor[
              0.7474005481861847, 0.8023032590432388, 0.9760248292713649], 
             UndirectedEdge[140, 169] -> 
             RGBColor[
              0.4961881243257401, 0.601866898204728, 0.953480893225362], 
             UndirectedEdge[147, 216] -> 
             RGBColor[
              0.2586895754643985, 0.38922952405245953`, 0.9380433606745415], 
             UndirectedEdge[70, 171] -> 
             RGBColor[
              0.25999619432080096`, 0.39060286331495886`, 0.9381177706854442],
              UndirectedEdge[7, 402] -> 
             RGBColor[
              0.6954966701641224, 0.7608182646923372, 0.971187276045136], 
             UndirectedEdge[185, 409] -> 
             RGBColor[
              0.262750205623448, 0.39349750380844273`, 0.9382746075549353], 
             UndirectedEdge[126, 481] -> 
             RGBColor[
              0.28467725623571494`, 0.41566859359098884`, 0.9395553817772139],
              UndirectedEdge[115, 311] -> 
             RGBColor[
              0.8340126241816578, 0.871074103507641, 0.9838732137113628], 
             UndirectedEdge[383, 496] -> 
             RGBColor[
              0.30291603178424115`, 0.4338470274567268, 0.9406303631659094], 
             UndirectedEdge[8, 297] -> 
             RGBColor[
              0.5698289191235334, 0.6616518129015765, 0.9592781663469641], 
             UndirectedEdge[381, 439] -> 
             RGBColor[
              0.7151086431122187, 0.7765792866784462, 0.9729163506443089], 
             UndirectedEdge[16, 276] -> 
             RGBColor[
              0.5117111188744836, 0.6131268633886855, 0.9550738020104051], 
             UndirectedEdge[74, 342] -> 
             RGBColor[
              0.27086057814160247`, 0.4020220195523411, 0.9387364812716233], 
             UndirectedEdge[26, 269] -> 
             RGBColor[
              0.4177844388725415, 0.5362856153201071, 0.9478418329060527], 
             UndirectedEdge[127, 315] -> 
             RGBColor[
              0.20573971378665917`, 0.3335758622140216, 0.9350279443842948], 
             UndirectedEdge[175, 348] -> 
             RGBColor[
              0.9578209370783626, 0.9214694359811255, 0.6292929486935749], 
             UndirectedEdge[180, 288] -> 
             RGBColor[
              0.2630984263915931, 0.39386350591423513`, 0.9382944382125347], 
             UndirectedEdge[288, 343] -> 
             RGBColor[
              0.274476709135814, 0.40582280250320485`, 0.9389424145821572], 
             UndirectedEdge[484, 500] -> 
             RGBColor[
              0.9061921804601966, 0.5690195539734165, 0.316991474169404], 
             UndirectedEdge[59, 323] -> 
             RGBColor[
              0.24076788547771533`, 0.3703926915756808, 0.9370227469425643], 
             UndirectedEdge[108, 189] -> 
             RGBColor[
              0.27244302962866296`, 0.40368527639846097`, 0.9388265995427842],
              UndirectedEdge[59, 74] -> 
             RGBColor[
              0.26196255890659237`, 0.3926696371693413, 0.9382297522396293], 
             UndirectedEdge[40, 199] -> 
             RGBColor[
              0.3645220176644419, 0.4901523831167798, 0.9444479985247825], 
             UndirectedEdge[69, 241] -> 
             RGBColor[
              0.8074723242442312, 0.8502460052781141, 0.9812530323476005], 
             UndirectedEdge[275, 353] -> 
             RGBColor[
              0.5266832510882068, 0.6255486018899017, 0.9561787766673014], 
             UndirectedEdge[196, 335] -> 
             RGBColor[
              0.2862357534512077, 0.4181823036451551, 0.9396120747599719], 
             UndirectedEdge[157, 281] -> 
             RGBColor[
              0.2737261355645935, 0.4050339020907391, 0.9388996705276503], 
             UndirectedEdge[120, 438] -> 
             RGBColor[
              0.21444303080234048`, 0.3427236002196732, 0.9355235854129342], 
             UndirectedEdge[152, 389] -> 
             RGBColor[
              0.21125135912011495`, 0.33936895091798147`, 0.9353418244322866],
              UndirectedEdge[126, 144] -> 
             RGBColor[
              0.24868278916139275`, 0.37871175718110384`, 0.937473488998299], 
             UndirectedEdge[96, 157] -> 
             RGBColor[
              0.29935267191603787`, 0.43196901661235676`, 0.940359063861802], 
             UndirectedEdge[303, 366] -> 
             RGBColor[
              0.2851324087513453, 0.4170226184095053, 0.9395492409115669], 
             UndirectedEdge[119, 309] -> 
             RGBColor[
              0.9918390696706652, 0.9889511495464178, 0.6437403499501158], 
             UndirectedEdge[325, 386] -> 
             RGBColor[
              0.1789719601845752, 0.3054412560046289, 0.9335035604159989], 
             UndirectedEdge[27, 220] -> 
             RGBColor[
              0.4255160611016982, 0.5413857751468245, 0.948775625607305], 
             UndirectedEdge[95, 346] -> 
             RGBColor[
              0.22248278830370904`, 0.3511738951036789, 0.9359814377088818], 
             UndirectedEdge[235, 239] -> 
             RGBColor[
              0.35398612023304477`, 0.4810267183113057, 0.943776660456982], 
             UndirectedEdge[64, 303] -> 
             RGBColor[
              0.29654648477504475`, 0.4290195360046319, 0.9401992556555043], 
             UndirectedEdge[310, 429] -> 
             RGBColor[
              0.2951775190785565, 0.4275806662601843, 0.9401212950842925], 
             UndirectedEdge[67, 238] -> 
             RGBColor[
              0.28838849579729153`, 0.41939023215024707`, 0.9397732894571003],
              UndirectedEdge[38, 108] -> 
             RGBColor[
              0.272539685244709, 0.40378686757924537`, 0.9388321039371288], 
             UndirectedEdge[20, 490] -> 
             RGBColor[
              0.9375437932423437, 0.7794697399272263, 0.5157901036631747], 
             UndirectedEdge[112, 148] -> 
             RGBColor[
              0.2439596839808273, 0.373747474174165, 0.9372045151454738], 
             UndirectedEdge[76, 402] -> 
             RGBColor[
              0.4818182674522101, 0.589060600826333, 0.952664686170056], 
             UndirectedEdge[99, 406] -> 
             RGBColor[
              0.992119957252125, 0.9843905837590278, 0.48258804562862445`], 
             UndirectedEdge[8, 258] -> 
             RGBColor[
              0.4968580357130886, 0.6002414107444907, 0.9541330294430466], 
             UndirectedEdge[15, 153] -> 
             RGBColor[
              0.23958587882071014`, 0.3691503276356177, 0.93695543341207], 
             UndirectedEdge[195, 463] -> 
             RGBColor[
              0.2686246431474216, 0.3996719101069903, 0.9386091480814742], 
             UndirectedEdge[184, 249] -> 
             RGBColor[
              0.2732898707787555, 0.40457536014003825`, 0.9388748258934928], 
             UndirectedEdge[109, 185] -> 
             RGBColor[
              0.26895237692670115`, 0.40001637908853493`, 0.9386278120353654],
              UndirectedEdge[77, 81] -> 
             RGBColor[
              0.7152180111578499, 0.7769379420233913, 0.972614350327299], 
             UndirectedEdge[355, 384] -> 
             RGBColor[
              0.3062638013444511, 0.43738753923394075`, 0.9408202157153518], 
             UndirectedEdge[67, 343] -> 
             RGBColor[
              0.2747552896997584, 0.40611560833893834`, 0.9389582793331509], 
             UndirectedEdge[247, 255] -> 
             RGBColor[
              0.4462984536881862, 0.5598509487377481, 0.9499715158755377], 
             UndirectedEdge[95, 145] -> 
             RGBColor[
              0.22387054333517215`, 0.3526325136304976, 0.9360604683049241], 
             UndirectedEdge[220, 416] -> 
             RGBColor[
              0.3002234451567067, 0.4300950902197503, 0.9405107780769688], 
             UndirectedEdge[287, 451] -> 
             RGBColor[
              0.21062876698303812`, 0.3387145671072923, 0.9353063687311225], 
             UndirectedEdge[387, 491] -> 
             RGBColor[
              0.8846376192086578, 0.9070821410302499, 0.7920529218334498], 
             UndirectedEdge[211, 464] -> 
             RGBColor[
              0.23745358448324252`, 0.36690915109166977`, 0.936834002403998], 
             UndirectedEdge[335, 482] -> 
             RGBColor[
              0.3176268052914761, 0.44657790833086347`, 0.9415681179813948], 
             UndirectedEdge[214, 423] -> 
             RGBColor[
              0.19381650316255092`, 0.32104381187286724`, 0.9343489351780614],
              UndirectedEdge[69, 194] -> 
             RGBColor[
              0.9479892988678673, 0.9596684021789683, 0.9321766809000795], 
             UndirectedEdge[111, 312] -> 
             RGBColor[
              0.28875139009156847`, 0.4208263972547496, 0.9397553365450895], 
             UndirectedEdge[174, 294] -> 
             RGBColor[
              0.2524849252558091, 0.3827080432856873, 0.9376900150241196], 
             UndirectedEdge[212, 295] -> 
             RGBColor[
              0.22405206726645135`, 0.35282330679155405`, 0.9360708058242697],
              UndirectedEdge[193, 414] -> 
             RGBColor[
              0.28123484292780576`, 0.41292602960901903`, 0.9393272803038482],
              UndirectedEdge[320, 348] -> 
             RGBColor[
              0.9742570536765062, 0.9329947209284535, 0.5686571215977747], 
             UndirectedEdge[247, 468] -> 
             RGBColor[
              0.48669420259584584`, 0.5941593048480999, 0.9527334969294036], 
             UndirectedEdge[449, 488] -> 
             RGBColor[
              0.7488335383665432, 0.8037137186084069, 0.9756003869232444], 
             UndirectedEdge[290, 355] -> 
             RGBColor[
              0.30759602149261944`, 0.4387877870773017, 0.9408960836819469], 
             UndirectedEdge[88, 469] -> 
             RGBColor[
              0.8635204022958338, 0.47315984709282155`, 0.20783041706562805`],
              UndirectedEdge[6, 278] -> 
             RGBColor[
              0.8880267801577246, 0.9132258771339024, 0.9778589426846744], 
             UndirectedEdge[24, 448] -> 
             RGBColor[
              0.7024556642269519, 0.7664802639694746, 0.97172087084446], 
             UndirectedEdge[204, 274] -> 
             RGBColor[
              0.4823136561574142, 0.5906029799080129, 0.9523886442672999], 
             UndirectedEdge[81, 99] -> 
             RGBColor[
              0.9086198401868935, 0.9254801001365643, 0.7650800543815806], 
             UndirectedEdge[213, 368] -> 
             RGBColor[
              0.6561537738248766, 0.5929010247462924, 0.5945021229284573], 
             UndirectedEdge[167, 474] -> 
             RGBColor[
              0.9898837045140847, 0.9900846660867081, 0.8173167265425048], 
             UndirectedEdge[78, 430] -> 
             RGBColor[
              0.22958406238534357`, 0.3586377844102586, 0.9363858447624374], 
             UndirectedEdge[110, 316] -> 
             RGBColor[
              0.26110517012024004`, 0.39176846719329617`, 0.9381809252166395],
              UndirectedEdge[153, 463] -> 
             RGBColor[
              0.25601516257071727`, 0.38641854653362934`, 0.9378910568166856],
              UndirectedEdge[471, 475] -> 
             RGBColor[
              0.847907987036376, 0.36924735854117574`, 0.19351004853135326`], 
             UndirectedEdge[79, 486] -> 
             RGBColor[
              0.9643781566417168, 0.9700792377693064, 0.7816636594414414], 
             UndirectedEdge[49, 402] -> 
             RGBColor[
              0.521262974366249, 0.6222237910767345, 0.9554548772727531], 
             UndirectedEdge[340, 498] -> 
             RGBColor[
              0.39966203669691347`, 0.5203561647804322, 0.9467513952897255], 
             UndirectedEdge[248, 313] -> 
             RGBColor[
              0.254748775686199, 0.38508749362443473`, 0.9378189379570638], 
             UndirectedEdge[37, 429] -> 
             RGBColor[
              0.29961908302642226`, 0.4322490315808106, 0.9403742355804184], 
             UndirectedEdge[18, 166] -> 
             RGBColor[
              0.8612521660936727, 0.43095598829613885`, 0.2046884517082866], 
             UndirectedEdge[147, 238] -> 
             RGBColor[
              0.2858235449724231, 0.4166943062060351, 0.9396272193021288], 
             UndirectedEdge[165, 441] -> 
             RGBColor[
              0.4370828286560343, 0.553000910585295, 0.9490715092381609], 
             UndirectedEdge[13, 154] -> 
             RGBColor[
              0.3030787322552839, 0.435811820273263, 0.9405739494865415], 
             UndirectedEdge[133, 249] -> 
             RGBColor[
              0.3173607671926588, 0.44752867994559636`, 0.9415079167344612], 
             UndirectedEdge[84, 385] -> 
             RGBColor[
              0.2333929402174702, 0.3626411565086264, 0.9366027547202471], 
             UndirectedEdge[125, 438] -> 
             RGBColor[
              0.2150690714922951, 0.34338160867808776`, 0.9355592375040829], 
             UndirectedEdge[21, 489] -> 
             RGBColor[
              0.9854926800563032, 0.9686826013172827, 0.5970125136401502], 
             UndirectedEdge[16, 200] -> 
             RGBColor[
              0.6523550443789783, 0.5834045301394526, 0.5929583920999518], 
             UndirectedEdge[402, 436] -> 
             RGBColor[
              0.5126155235296384, 0.6152034009243532, 0.954774118266239], 
             UndirectedEdge[127, 401] -> 
             RGBColor[
              0.499716094491864, 0.5888978154955886, 0.9571173753725956], 
             UndirectedEdge[195, 395] -> 
             RGBColor[
              0.26756974901772024`, 0.3985631494925233, 0.9385490734213637], 
             UndirectedEdge[27, 297] -> 
             RGBColor[
              0.5157415629468824, 0.6177412605497428, 0.9550202115402241], 
             UndirectedEdge[35, 70] -> 
             RGBColor[
              0.24831129577393707`, 0.37832129407684667`, 0.9374523329994586],
              UndirectedEdge[240, 367] -> 
             RGBColor[
              0.24323530728920995`, 0.3729861083431402, 0.9371632629645055], 
             UndirectedEdge[121, 471] -> 
             RGBColor[
              0.842139262249025, 0.3249064119542755, 0.18798591116014318`], 
             UndirectedEdge[184, 424] -> 
             RGBColor[
              0.28881315240835653`, 0.41979584487067384`, 0.9397989642855475],
              UndirectedEdge[122, 159] -> 
             RGBColor[
              0.8441272348319537, 0.3258751275198433, 0.1893291851678579], 
             UndirectedEdge[158, 324] -> 
             RGBColor[
              0.3635993901479788, 0.48935324953462667`, 0.9443892095152808], 
             UndirectedEdge[180, 465] -> 
             RGBColor[
              0.27637826248324115`, 0.40782145563679656`, 0.9390507052321971],
              UndirectedEdge[254, 454] -> 
             RGBColor[
              0.568190337821955, 0.5020881692235942, 0.5874756893040098], 
             UndirectedEdge[297, 314] -> 
             RGBColor[
              0.42471984107439154`, 0.540499402694099, 0.9487792473402418], 
             UndirectedEdge[262, 393] -> 
             RGBColor[
              0.46864864929250694`, 0.5795091117335374, 0.951312884870325], 
             UndirectedEdge[201, 333] -> 
             RGBColor[
              0.34155395478950024`, 0.4698622181836031, 0.9429990074018386], 
             UndirectedEdge[219, 340] -> 
             RGBColor[
              0.43185173064895377`, 0.5464892084598855, 0.9492854859123644], 
             UndirectedEdge[361, 370] -> 
             RGBColor[
              0.6178223925754994, 0.7005868527844641, 0.9630756852495326], 
             UndirectedEdge[48, 358] -> 
             RGBColor[
              0.2165685446684143, 0.3449576500582796, 0.9356446302831911], 
             UndirectedEdge[287, 299] -> 
             RGBColor[
              0.2094890463187735, 0.33751664842668644`, 0.9352414633253583], 
             UndirectedEdge[62, 233] -> 
             RGBColor[
              0.8302393984490122, 0.2334388442338099, 0.17659058814627704`], 
             UndirectedEdge[61, 91] -> 
             RGBColor[
              0.32572776888358806`, 0.4565507546784424, 0.9419760632968737], 
             UndirectedEdge[204, 340] -> 
             RGBColor[
              0.4196638066192008, 0.5365945026728116, 0.9483260078869054], 
             UndirectedEdge[258, 373] -> 
             RGBColor[
              0.3335189671806654, 0.461900180189882, 0.9425237328349862], 
             UndirectedEdge[167, 210] -> 
             RGBColor[
              0.9113669843928855, 0.6334814540290358, 0.5263699322609554], 
             UndirectedEdge[275, 481] -> 
             RGBColor[
              0.36596032955819924`, 0.49139817658749463`, 0.9445396464868034],
              UndirectedEdge[253, 277] -> 
             RGBColor[
              0.8781666893011308, 0.9046720920391318, 0.9377821758000617], 
             UndirectedEdge[193, 485] -> 
             RGBColor[
              0.2679064543585755, 0.3989170481541139, 0.9385682482924145], 
             UndirectedEdge[89, 260] -> 
             RGBColor[
              0.2855390731059485, 0.4174500484302025, 0.9395723998449554], 
             UndirectedEdge[359, 397] -> 
             RGBColor[
              0.3719996579907838, 0.4966291393303264, 0.9449244671541592], 
             UndirectedEdge[1, 171] -> 
             RGBColor[
              0.2639538573417897, 0.3947626180803467, 0.9383431537396518], 
             UndirectedEdge[193, 330] -> 
             RGBColor[
              0.2971306356015508, 0.42963351556059126`, 0.9402325221809], 
             UndirectedEdge[92, 320] -> 
             RGBColor[
              0.7988700431185324, 0.8415596078670635, 0.9004611644475569], 
             UndirectedEdge[126, 279] -> 
             RGBColor[
              0.26484901945855754`, 0.3957034902216259, 0.9383941318979281], 
             UndirectedEdge[93, 163] -> 
             RGBColor[
              0.26813879509029465`, 0.39916125299440397`, 0.9385814797533685],
              UndirectedEdge[31, 297] -> 
             RGBColor[
              0.48620123605795307`, 0.5937514968840982, 0.9526967874627315], 
             UndirectedEdge[127, 325] -> 
             RGBColor[
              0.20249836583685807`, 0.33016900000545074`, 0.9348433544136983],
              UndirectedEdge[334, 498] -> 
             RGBColor[
              0.4323467950368561, 0.5486660596707702, 0.9488340391891498], 
             UndirectedEdge[41, 300] -> 
             RGBColor[
              0.22924216126039493`, 0.3582784246501542, 0.9363663739991688], 
             UndirectedEdge[330, 496] -> 
             RGBColor[
              0.2916695481926115, 0.42389356644085574`, 0.9399215213319159], 
             UndirectedEdge[18, 227] -> 
             RGBColor[
              0.8650075437066738, 0.45982146624662823`, 0.2082846055515888], 
             UndirectedEdge[156, 350] -> 
             RGBColor[
              0.41473957912155346`, 0.5332684178987681, 0.9477527826875395], 
             UndirectedEdge[315, 386] -> 
             RGBColor[
              0.1822133081343763, 0.30884811821319974`, 0.9336881503865955], 
             UndirectedEdge[29, 479] -> 
             RGBColor[
              0.410555492074131, 0.5300242649407545, 0.9473812108083647], 
             UndirectedEdge[277, 488] -> 
             RGBColor[
              0.7703329161501223, 0.8205091959342619, 0.9777432439776033], 
             UndirectedEdge[242, 374] -> 
             RGBColor[
              0.2383689744042093, 0.367871283937679, 0.936886132505799], 
             UndirectedEdge[244, 363] -> 
             RGBColor[
              0.37362619317772217`, 0.49803796235721676`, 0.9450281085379824],
              UndirectedEdge[335, 409] -> 
             RGBColor[
              0.25916391695491414`, 0.389728087033979, 0.938070373720701], 
             UndirectedEdge[235, 332] -> 
             RGBColor[
              0.37961688858367837`, 0.50322680161675, 0.9454098303518859], 
             UndirectedEdge[249, 440] -> 
             RGBColor[
              0.2856108538657166, 0.41752549455988186`, 0.9395764876530341], 
             UndirectedEdge[96, 265] -> 
             RGBColor[
              0.3085881199169248, 0.4405417508695841, 0.9409265415042412], 
             UndirectedEdge[39, 200] -> 
             RGBColor[
              0.7622447974505207, 0.6739602832535388, 0.6012384342096092], 
             UndirectedEdge[146, 312] -> 
             RGBColor[
              0.28117238396624933`, 0.41286038128029634`, 0.9393237233583873],
              UndirectedEdge[237, 448] -> 
             RGBColor[
              0.7370158535300309, 0.7940376208084021, 0.9750172525524329], 
             UndirectedEdge[31, 162] -> 
             RGBColor[
              0.4575348398128734, 0.5704788250059085, 0.9504400637418493], 
             UndirectedEdge[41, 102] -> 
             RGBColor[
              0.2545321161274702, 0.38485977069120125`, 0.9378065995157133], 
             UndirectedEdge[266, 374] -> 
             RGBColor[
              0.27062553266643685`, 0.40177497185519817`, 0.9387230957795312],
              UndirectedEdge[44, 139] -> 
             RGBColor[
              0.5303562146824653, 0.6296060932112468, 0.9561707304600824], 
             UndirectedEdge[47, 189] -> 
             RGBColor[
              0.24585450838109163`, 0.3757390547576487, 0.9373124225919274], 
             UndirectedEdge[208, 359] -> 
             RGBColor[
              0.3537848938552699, 0.480852426136809, 0.9437638384901277], 
             UndirectedEdge[122, 413] -> 
             RGBColor[
              0.9206701650068785, 0.7073273642826143, 0.2820065056616069], 
             UndirectedEdge[36, 141] -> 
             RGBColor[
              0.28198608489330845`, 0.4136382572421074, 0.9393728955113378], 
             UndirectedEdge[179, 347] -> 
             RGBColor[
              0.17892806853100302`, 0.30539512309383293`, 0.93350106085126], 
             UndirectedEdge[226, 422] -> 
             RGBColor[
              0.20671849831186667`, 0.3346046268085379, 0.9350836847150235], 
             UndirectedEdge[18, 167] -> 
             RGBColor[
              0.9355270875213144, 0.7783260157628717, 0.5479056765432442], 
             UndirectedEdge[112, 452] -> 
             RGBColor[
              0.2361084750925497, 0.3654953558371904, 0.936757400414109], 
             UndirectedEdge[323, 342] -> 
             RGBColor[
              0.2496659047127254, 0.3797450739586806, 0.9375294759745583], 
             UndirectedEdge[74, 82] -> 
             RGBColor[
              0.27000631808527487`, 0.401124138069925, 0.93868783242518], 
             UndirectedEdge[291, 349] -> 
             RGBColor[
              0.5342643053360183, 0.6315079324719315, 0.9569079863163146], 
             UndirectedEdge[86, 136] -> 
             RGBColor[
              0.942076876818933, 0.8389236960734718, 0.594023128493258], 
             UndirectedEdge[11, 23] -> 
             RGBColor[
              0.23070981980428998`, 0.3598210268347142, 0.9364499549820375], 
             UndirectedEdge[249, 470] -> 
             RGBColor[
              0.27251498804399493`, 0.40376090925540187`, 0.9388306974680845],
              UndirectedEdge[35, 135] -> 
             RGBColor[
              0.24449959825218992`, 0.3743149583059091, 0.9372352624644963], 
             UndirectedEdge[161, 326] -> 
             RGBColor[
              0.9327537347132191, 0.7525662704764362, 0.31724881897839763`], 
             UndirectedEdge[26, 139] -> 
             RGBColor[
              0.4753323584108449, 0.5831244997687381, 0.952339366037344], 
             UndirectedEdge[109, 218] -> 
             RGBColor[
              0.24296647092511459`, 0.372703544279266, 0.937147953131278], 
             UndirectedEdge[238, 465] -> 
             RGBColor[
              0.30138975132499524`, 0.433055376037075, 0.940513691725769], 
             UndirectedEdge[258, 314] -> 
             RGBColor[
              0.35174895766394676`, 0.47908900053701325`, 0.9436341104363243],
              UndirectedEdge[28, 493] -> 
             RGBColor[
              0.9792166674892435, 0.9809905167708368, 0.7433381739278018], 
             UndirectedEdge[106, 466] -> 
             RGBColor[
              0.5106817556791221, 0.6136334810680553, 0.9546218849774213], 
             UndirectedEdge[45, 236] -> 
             RGBColor[
              0.285052814306115, 0.4169389596009889, 0.9395447081256605], 
             UndirectedEdge[157, 246] -> 
             RGBColor[
              0.2983825090164457, 0.4309493138930047, 0.9403038145198976], 
             UndirectedEdge[371, 427] -> 
             RGBColor[
              0.3212220231725497, 0.4499441234823203, 0.9417879671446181], 
             UndirectedEdge[341, 450] -> 
             RGBColor[
              0.9056409272943111, 0.562891578052587, 0.35323513131972123`], 
             UndirectedEdge[277, 484] -> 
             RGBColor[
              0.8820966152149525, 0.9042351364524142, 0.7227616167031183], 
             UndirectedEdge[84, 135] -> 
             RGBColor[
              0.24197053087649611`, 0.37165674814192173`, 0.9370912358188704],
              UndirectedEdge[35, 84] -> 
             RGBColor[
              0.2358433607180927, 0.36521670382041393`, 0.9367423025426853], 
             UndirectedEdge[68, 272] -> 
             RGBColor[
              0.8202846954174998, 0.15692263455492186`, 0.1670579532810717], 
             UndirectedEdge[164, 227] -> 
             RGBColor[
              0.8315779382096691, 0.24372744738608088`, 0.17787237533274636`],
              UndirectedEdge[355, 498] -> 
             RGBColor[
              0.3952981571338905, 0.516576391637906, 0.946473332742797], 
             UndirectedEdge[223, 373] -> 
             RGBColor[
              0.3417396383201442, 0.4690205123479532, 0.9430475467307398], 
             UndirectedEdge[116, 192] -> 
             RGBColor[
              0.2516702940273803, 0.3818518142140055, 0.9376436229807996], 
             UndirectedEdge[3, 31] -> 
             RGBColor[
              0.4573521482388232, 0.5703305077559329, 0.9504256815919188], 
             UndirectedEdge[40, 419] -> 
             RGBColor[
              0.44944534633244004`, 0.5620965984995714, 0.950304666943798], 
             UndirectedEdge[282, 324] -> 
             RGBColor[
              0.48866791978392093`, 0.5934906203448358, 0.9535163694747727], 
             UndirectedEdge[250, 339] -> 
             RGBColor[
              0.20806801028262886`, 0.33602304945380984`, 0.9351605374253343],
              UndirectedEdge[259, 405] -> 
             RGBColor[
              0.9279266912954685, 0.7275673838799486, 0.39806227602736116`], 
             UndirectedEdge[22, 441] -> 
             RGBColor[
              0.45077446449645514`, 0.564859917388641, 0.9499439281668742], 
             UndirectedEdge[142, 241] -> 
             RGBColor[
              0.7025032226254809, 0.7675201238280478, 0.9709826140315919], 
             UndirectedEdge[170, 266] -> 
             RGBColor[
              0.29310065604108804`, 0.425397751527083, 0.9400030208067522], 
             UndirectedEdge[105, 153] -> 
             RGBColor[
              0.24541911730613436`, 0.37528143113248, 0.9372876277143118], 
             UndirectedEdge[95, 404] -> 
             RGBColor[
              0.22026561376472564`, 0.3488435040862222, 0.9358551728989024], 
             UndirectedEdge[200, 454] -> 
             RGBColor[
              0.9003552167733437, 0.640418136645701, 0.2385662891695866], 
             UndirectedEdge[96, 131] -> 
             RGBColor[
              0.2798853921380307, 0.4115076712688437, 0.9392504310777041], 
             UndirectedEdge[190, 395] -> 
             RGBColor[
              0.2565485956338361, 0.38697921850457684`, 0.9379214350404868], 
             UndirectedEdge[297, 381] -> 
             RGBColor[
              0.5443345056874556, 0.6409542995639315, 0.9572711527321625], 
             UndirectedEdge[203, 419] -> 
             RGBColor[
              0.5236285855732716, 0.6241443008241659, 0.9556411068524893], 
             UndirectedEdge[107, 209] -> 
             RGBColor[
              0.37529763235099667`, 0.4849566561931139, 0.9463994374355724], 
             UndirectedEdge[205, 252] -> 
             RGBColor[
              0.8648112867502258, 0.89136633503373, 0.7718692919288858], 
             UndirectedEdge[98, 488] -> 
             RGBColor[
              0.8822995191611039, 0.9059842085048606, 0.8501777526166581], 
             UndirectedEdge[182, 275] -> 
             RGBColor[
              0.39614531120522645`, 0.517542890548859, 0.9464630068258206], 
             UndirectedEdge[88, 474] -> 
             RGBColor[
              0.9298536404427284, 0.7393015368665987, 0.48723505332973827`], 
             UndirectedEdge[47, 242] -> 
             RGBColor[
              0.2284706396727983, 0.35746750654429615`, 0.9363224369861192], 
             UndirectedEdge[133, 262] -> 
             RGBColor[
              0.4106297397776527, 0.5294703750419166, 0.9475567521778445], 
             UndirectedEdge[4, 321] -> 
             RGBColor[
              0.32873955000778277`, 0.45915940811169914`, 0.9421679713268938],
              UndirectedEdge[369, 370] -> 
             RGBColor[
              0.5056953807182732, 0.6086792278604158, 0.9544796944704173], 
             UndirectedEdge[49, 436] -> 
             RGBColor[
              0.4815672646188717, 0.5899970256324685, 0.9523298855912635], 
             UndirectedEdge[34, 393] -> 
             RGBColor[
              0.5024822764946291, 0.606976774483756, 0.9539763919403361], 
             UndirectedEdge[268, 324] -> 
             RGBColor[
              0.3896661145929028, 0.5119309360971549, 0.946050158147012], 
             UndirectedEdge[359, 371] -> 
             RGBColor[
              0.37419759071797254`, 0.49853287818730624`, 0.94506451748398], 
             UndirectedEdge[296, 440] -> 
             RGBColor[
              0.29754682970453167`, 0.4296388353177702, 0.94027204609223], 
             UndirectedEdge[113, 143] -> 
             RGBColor[
              0.17905963102166003`, 0.30553340361305714`, 0.9335085531404735],
              UndirectedEdge[270, 489] -> 
             RGBColor[
              0.9900603412249211, 0.9901577099059953, 0.8143893991227904], 
             UndirectedEdge[237, 426] -> 
             RGBColor[
              0.8881333928283652, 0.9136374759753497, 0.9891921499256506], 
             UndirectedEdge[131, 385] -> 
             RGBColor[
              0.24854031848564526`, 0.3785620114677306, 0.9374653755040816], 
             UndirectedEdge[427, 499] -> 
             RGBColor[
              0.27010938266217854`, 0.4012324654749223, 0.9386937018003643], 
             UndirectedEdge[45, 243] -> 
             RGBColor[
              0.5610442905289292, 0.35884112143673136`, 0.5623441481098833], 
             UndirectedEdge[33, 443] -> 
             RGBColor[
              0.9064631162110222, 0.6594290978497701, 0.24321160823769428`], 
             UndirectedEdge[232, 330] -> 
             RGBColor[
              0.3313235898372211, 0.4611852513408379, 0.942340398215439], 
             UndirectedEdge[19, 360] -> 
             RGBColor[
              0.5695454245786704, 0.661421659258773, 0.9592558486179177], 
             UndirectedEdge[44, 370] -> 
             RGBColor[
              0.5440602935407461, 0.6407316817901163, 0.9572495657475013], 
             UndirectedEdge[310, 412] -> 
             RGBColor[
              0.26956927876194814`, 0.4006647820312149, 0.9386629436822582], 
             UndirectedEdge[107, 214] -> 
             RGBColor[
              0.19223940367108877`, 0.31938618031345734`, 0.9342591216951321],
              UndirectedEdge[268, 481] -> 
             RGBColor[
              0.3639357382267393, 0.48964457733510314`, 0.9444106413174386], 
             UndirectedEdge[224, 351] -> 
             RGBColor[
              0.29450587119895527`, 0.4268747217537883, 0.9400830457311632], 
             UndirectedEdge[78, 408] -> 
             RGBColor[
              0.22096681623691122`, 0.34958051234329385`, 0.9358951053423573],
              UndirectedEdge[124, 136] -> 
             RGBColor[
              0.9658066058981951, 0.931025957642273, 0.6234191599847442], 
             UndirectedEdge[51, 315] -> 
             RGBColor[
              0.1822133085396902, 0.30884811863921036`, 0.9336881504096776], 
             UndirectedEdge[24, 270] -> 
             RGBColor[
              0.9134975511433701, 0.9314925430785823, 0.899659555679228], 
             UndirectedEdge[43, 340] -> 
             RGBColor[
              0.31529118717805316`, 0.446068953150221, 0.9413638580453506], 
             UndirectedEdge[116, 483] -> 
             RGBColor[
              0.27268756010159706`, 0.40394229342964216`, 0.9388405251914673],
              UndirectedEdge[50, 169] -> 
             RGBColor[
              0.46684010556596744`, 0.5777047091656451, 0.9512633876302873], 
             UndirectedEdge[247, 369] -> 
             RGBColor[
              0.457479402684923, 0.5695353247878849, 0.9506839560586847], 
             UndirectedEdge[327, 412] -> 
             RGBColor[
              0.2497253233645969, 0.37980752672915763`, 0.9375328597788803], 
             UndirectedEdge[134, 305] -> 
             RGBColor[
              0.2421591297202534, 0.37185497748456803`, 0.9371019762440154], 
             UndirectedEdge[7, 49] -> 
             RGBColor[
              0.6644484112533559, 0.7356118894004525, 0.9687430433701605], 
             UndirectedEdge[81, 486] -> 
             RGBColor[
              0.879272872526262, 0.9065723375988691, 0.9883470255893563], 
             UndirectedEdge[110, 384] -> 
             RGBColor[
              0.27776805045914515`, 0.4092822109171187, 0.9391298516014178], 
             UndirectedEdge[18, 88] -> 
             RGBColor[
              0.8754970234499582, 0.5275428865427625, 0.2178240033304778], 
             UndirectedEdge[11, 41] -> 
             RGBColor[
              0.23572240363091454`, 0.3650895702526674, 0.9367354142155104], 
             UndirectedEdge[231, 288] -> 
             RGBColor[
              0.2572561350755689, 0.3877228873184297, 0.9379617283649826], 
             UndirectedEdge[236, 396] -> 
             RGBColor[
              0.6404346091203621, 0.7039646181731036, 0.7392903949875442], 
             UndirectedEdge[46, 418] -> 
             RGBColor[
              0.9480641688610301, 0.8473510420156326, 0.586962152772621], 
             UndirectedEdge[74, 447] -> 
             RGBColor[
              0.26411698006509043`, 0.39493407040511375`, 0.9383524433374253],
              UndirectedEdge[270, 426] -> 
             RGBColor[
              0.9300987405065613, 0.9447298808495102, 0.9012429919407459], 
             UndirectedEdge[383, 479] -> 
             RGBColor[
              0.37021659707670174`, 0.49508474158579574`, 0.9448108520894127],
              UndirectedEdge[408, 430] -> 
             RGBColor[
              0.23112177962706493`, 0.36025402272821205`, 0.9364734154845045],
              UndirectedEdge[13, 390] -> 
             RGBColor[
              0.29868486413343276`, 0.4312671082913797, 0.9403210331965157], 
             UndirectedEdge[15, 97] -> 
             RGBColor[
              0.23298665056537604`, 0.36221412032402367`, 0.936579617125612], 
             UndirectedEdge[289, 472] -> 
             RGBColor[
              0.3839088844842855, 0.5069443127438695, 0.9456833125354096], 
             UndirectedEdge[254, 315] -> 
             RGBColor[
              0.21099893285942517`, 0.33910363491324724`, 0.9353274491301715],
              UndirectedEdge[347, 386] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[66, 445] -> 
             RGBColor[
              0.24646019520379875`, 0.3763756700110764, 0.9373469155604471], 
             UndirectedEdge[127, 213] -> 
             RGBColor[
              0.5650928544862279, 0.5063763336200533, 0.5889799898461102], 
             UndirectedEdge[423, 446] -> 
             RGBColor[
              0.20798858239401255`, 0.3359395657068551, 0.9351560141245807], 
             UndirectedEdge[63, 410] -> 
             RGBColor[
              0.39150030357105375`, 0.5135196184010107, 0.9461670310467902], 
             UndirectedEdge[107, 421] -> 
             RGBColor[
              0.18186414913512938`, 0.30848112996703203`, 0.9336682662981228],
              UndirectedEdge[226, 308] -> 
             RGBColor[
              0.17918563853241248`, 0.3056658454961956, 0.9335157290817995], 
             UndirectedEdge[51, 386] -> 
             RGBColor[
              0.1789270004053139, 0.3053940004260106, 0.9335010000230821], 
             UndirectedEdge[89, 470] -> 
             RGBColor[
              0.27049191209474743`, 0.40163452816231904`, 0.9387154862856475],
              UndirectedEdge[205, 490] -> 
             RGBColor[
              0.9921900608993205, 0.9897828176678509, 0.6878265810358566], 
             UndirectedEdge[270, 345] -> 
             RGBColor[
              0.824874141314561, 0.8621219539632672, 0.8908628396870938], 
             UndirectedEdge[152, 191] -> 
             RGBColor[
              0.21120215837255008`, 0.3393172378127832, 0.9353390225224988], 
             UndirectedEdge[85, 404] -> 
             RGBColor[
              0.21383193119222793`, 0.3420812957834917, 0.9354887841941792], 
             UndirectedEdge[26, 468] -> 
             RGBColor[
              0.43250328030680874`, 0.5483539247359007, 0.9489677041209118], 
             UndirectedEdge[191, 301] -> 
             RGBColor[
              0.2135770306984165, 0.34181337920287114`, 0.935474267988148], 
             UndirectedEdge[375, 426] -> 
             RGBColor[
              0.9141879156308917, 0.9338323693009003, 0.9715587229445324], 
             UndirectedEdge[39, 213] -> 
             RGBColor[
              0.7639337426080279, 0.681629388750616, 0.6026477314488674], 
             UndirectedEdge[360, 468] -> 
             RGBColor[
              0.5288716731016017, 0.6284008754780657, 0.9560538619087819], 
             UndirectedEdge[80, 278] -> 
             RGBColor[
              0.8689533270990046, 0.8982632673699124, 0.9759744072003973], 
             UndirectedEdge[152, 299] -> 
             RGBColor[
              0.20658465608391344`, 0.3344639501408717, 0.9350760625981434], 
             UndirectedEdge[227, 309] -> 
             RGBColor[
              0.9193309660445672, 0.6696242794444807, 0.3370748612621325], 
             UndirectedEdge[98, 115] -> 
             RGBColor[
              0.9582015589575525, 0.9660972945461519, 0.85752593015656], 
             UndirectedEdge[213, 261] -> 
             RGBColor[
              0.8920963570986589, 0.602916583768641, 0.23167489421385412`], 
             UndirectedEdge[199, 208] -> 
             RGBColor[
              0.33248120157791744`, 0.46240023864087376`, 0.9424063860563303],
              UndirectedEdge[204, 219] -> 
             RGBColor[
              0.5140809753819581, 0.6163931207559199, 0.9548894840041806], 
             UndirectedEdge[52, 166] -> 
             RGBColor[
              0.8369577282992072, 0.2850788714533209, 0.18302406839809204`], 
             UndirectedEdge[218, 300] -> 
             RGBColor[
              0.22896529227619977`, 0.3579874177932576, 0.93635060672011], 
             UndirectedEdge[128, 345] -> 
             RGBColor[
              0.5772342034942839, 0.6673977284070023, 0.9600430222220963], 
             UndirectedEdge[325, 421] -> 
             RGBColor[
              0.17903676307516053`, 0.3055093679513746, 0.9335072508447505], 
             UndirectedEdge[257, 272] -> 
             RGBColor[
              0.8397181825766789, 0.3055916208213189, 0.18563986428858031`], 
             UndirectedEdge[461, 486] -> 
             RGBColor[
              0.9396915520193736, 0.9545227464327241, 0.9862809714214389], 
             UndirectedEdge[115, 203] -> 
             RGBColor[
              0.7278675078772177, 0.786501490374317, 0.9744226233622142], 
             UndirectedEdge[128, 169] -> 
             RGBColor[
              0.4937426983927686, 0.5998815912671589, 0.9532883803380281], 
             UndirectedEdge[190, 356] -> 
             RGBColor[
              0.2587237746657965, 0.38926546958148345`, 0.9380453082684679], 
             UndirectedEdge[46, 272] -> 
             RGBColor[
              0.8691188894851287, 0.4352254750326188, 0.20997245291222838`], 
             UndirectedEdge[121, 450] -> 
             RGBColor[
              0.8225872124582064, 0.17462078949919407`, 0.16926284619957344`],
              UndirectedEdge[255, 269] -> 
             RGBColor[
              0.4232624333249523, 0.5410303787827784, 0.94819088586856], 
             UndirectedEdge[15, 356] -> 
             RGBColor[
              0.2517883622305454, 0.38197591138148856`, 0.9376503467903037], 
             UndirectedEdge[85, 183] -> 
             RGBColor[
              0.20959144808050473`, 0.33762427917091264`, 0.9352472949541991],
              UndirectedEdge[136, 261] -> 
             RGBColor[
              0.924473739268195, 0.762150740681319, 0.5794980394919615], 
             UndirectedEdge[295, 336] -> 
             RGBColor[
              0.22591321478921644`, 0.3547794908415487, 0.9361767954223702], 
             UndirectedEdge[259, 475] -> 
             RGBColor[
              0.8504220451203991, 0.38316771966990754`, 0.19570591448943397`],
              UndirectedEdge[51, 143] -> 
             RGBColor[
              0.17892700107920537`, 0.30539400113431325`, 0.9335010000614592],
              UndirectedEdge[53, 178] -> 
             RGBColor[
              0.9840984713626098, 0.9616310168446078, 0.5753629014776818], 
             UndirectedEdge[67, 385] -> 
             RGBColor[
              0.24504732911062774`, 0.37489065816626943`, 0.9372664549265891],
              UndirectedEdge[69, 173] -> 
             RGBColor[
              0.9470127321552729, 0.9592645667466908, 0.9483609186014075], 
             UndirectedEdge[221, 381] -> 
             RGBColor[
              0.5529574414035745, 0.647954787237104, 0.9579499818185896], 
             UndirectedEdge[140, 334] -> 
             RGBColor[
              0.4512190714580578, 0.563987423855866, 0.9503197339204532], 
             UndirectedEdge[57, 370] -> 
             RGBColor[
              0.5963431626815656, 0.6831772702750474, 0.9613654647247267], 
             UndirectedEdge[432, 467] -> 
             RGBColor[
              0.8027318187709938, 0.8464550865365966, 0.9808037893677689], 
             UndirectedEdge[235, 440] -> 
             RGBColor[
              0.3193577814126447, 0.44853038543702994`, 0.9416618206484036], 
             UndirectedEdge[229, 390] -> 
             RGBColor[
              0.29586463316817824`, 0.4283028667339263, 0.9401604252152023], 
             UndirectedEdge[12, 198] -> 
             RGBColor[
              0.2771414265920781, 0.4086235895025834, 0.9390941662991953], 
             UndirectedEdge[232, 400] -> 
             RGBColor[
              0.3260597275402094, 0.45565259831853255`, 0.9420406290448107], 
             UndirectedEdge[143, 273] -> 
             RGBColor[
              0.23623420851912813`, 0.365627509640484, 0.9367645607467467], 
             UndirectedEdge[115, 277] -> 
             RGBColor[
              0.8462349559465709, 0.8806222819755531, 0.9850914215175051], 
             UndirectedEdge[44, 468] -> 
             RGBColor[
              0.48752713657842917`, 0.5948355181784093, 0.9527990685436503], 
             UndirectedEdge[183, 346] -> 
             RGBColor[
              0.21142499907593382`, 0.3395514575209563, 0.9353517129708931], 
             UndirectedEdge[434, 469] -> 
             RGBColor[
              0.9258166281861495, 0.7248800924627727, 0.5003559242994462], 
             UndirectedEdge[255, 334] -> 
             RGBColor[
              0.40019480220882075`, 0.5210503561228367, 0.9467210368117455], 
             UndirectedEdge[65, 210] -> 
             RGBColor[
              0.9107642708804349, 0.6204193391599911, 0.29010099455145133`], 
             UndirectedEdge[49, 76] -> 
             RGBColor[
              0.45077000854144356`, 0.5638542255344485, 0.9502204534950804], 
             UndirectedEdge[74, 395] -> 
             RGBColor[
              0.2733607929019397, 0.4046499037882272, 0.9388788648034883], 
             UndirectedEdge[52, 88] -> 
             RGBColor[
              0.8512025856554928, 0.3816657696999445, 0.19615962002028325`], 
             UndirectedEdge[312, 354] -> 
             RGBColor[
              0.3330876906173925, 0.4625247982993003, 0.942459704446583], 
             UndirectedEdge[372, 417] -> 
             RGBColor[
              0.5857428674141524, 0.6736726673586156, 0.9611454890036907], 
             UndirectedEdge[354, 415] -> 
             RGBColor[
              0.32438826492045936`, 0.4533811503163769, 0.9419642850227896], 
             UndirectedEdge[301, 451] -> 
             RGBColor[
              0.2100992490740445, 0.3381580102115655, 0.9352762134695569], 
             UndirectedEdge[243, 428] -> 
             RGBColor[
              0.8348198026853184, 0.2686458383399938, 0.18097678841579048`], 
             UndirectedEdge[102, 354] -> 
             RGBColor[
              0.3191507002330799, 0.44787613774915985`, 0.941666013462126], 
             UndirectedEdge[255, 369] -> 
             RGBColor[
              0.40876647484829665`, 0.5284747081383571, 0.9472672162127003], 
             UndirectedEdge[300, 409] -> 
             RGBColor[
              0.23375665444094554`, 0.3630234432183127, 0.936623467707207], 
             UndirectedEdge[93, 187] -> 
             RGBColor[
              0.2669566877883537, 0.3979187832701322, 0.9385141604912941], 
             UndirectedEdge[181, 332] -> 
             RGBColor[
              0.41144462504759094`, 0.5307943872332428, 0.947437865575204], 
             UndirectedEdge[195, 351] -> 
             RGBColor[
              0.2800986877606033, 0.41173185849189103`, 0.9392625779478669], 
             UndirectedEdge[480, 481] -> 
             RGBColor[
              0.33588196619861493`, 0.46534581002792214`, 0.9426230797707831],
              UndirectedEdge[47, 365] -> 
             RGBColor[
              0.22445415871552787`, 0.3532459303986038, 0.9360937043374536], 
             UndirectedEdge[50, 370] -> 
             RGBColor[
              0.5161906822110007, 0.6177697305042253, 0.9551484458009031], 
             UndirectedEdge[122, 150] -> 
             RGBColor[
              0.8444744803276283, 0.32854420856354566`, 0.1896617078466737], 
             UndirectedEdge[246, 256] -> 
             RGBColor[
              0.2918037733500637, 0.42403464559170456`, 0.9399291652560644], 
             UndirectedEdge[63, 282] -> 
             RGBColor[
              0.5134969921724348, 0.6149963149023026, 0.9550984560118821], 
             UndirectedEdge[230, 391] -> 
             RGBColor[
              0.23250262506826308`, 0.3617053788375689, 0.936552052589603], 
             UndirectedEdge[312, 415] -> 
             RGBColor[
              0.29571211190112656`, 0.42814255721184813`, 0.9401517393546788],
              UndirectedEdge[199, 397] -> 
             RGBColor[
              0.3506959657134314, 0.47817695183439113`, 0.9435670147203616], 
             UndirectedEdge[129, 328] -> 
             RGBColor[
              0.3704563897071251, 0.49529243790994043`, 0.944826131463783], 
             UndirectedEdge[188, 304] -> 
             RGBColor[
              0.33792059600024626`, 0.4671115686975821, 0.9427529794590535], 
             UndirectedEdge[323, 395] -> 
             RGBColor[
              0.25216611947306267`, 0.3823729581945666, 0.9376718595064233], 
             UndirectedEdge[49, 238] -> 
             RGBColor[
              0.4051843179606758, 0.5243701915568157, 0.9473157736011174], 
             UndirectedEdge[171, 385] -> 
             RGBColor[
              0.24760690614002792`, 0.37758093591072595`, 0.9374122190518586],
              UndirectedEdge[117, 425] -> 
             RGBColor[
              0.3782090614978762, 0.502007412554475, 0.9453201248548712], 
             UndirectedEdge[32, 103] -> 
             RGBColor[
              0.5080332189208779, 0.6114832796124914, 0.9544133824619024], 
             UndirectedEdge[131, 216] -> 
             RGBColor[
              0.26474751566428445`, 0.3955968032981327, 0.9383883514070055], 
             UndirectedEdge[65, 175] -> 
             RGBColor[
              0.9705975460870158, 0.9645679382577699, 0.6789276620320353], 
             UndirectedEdge[143, 226] -> 
             RGBColor[
              0.17917599682249857`, 0.3056557114477564, 0.9335151800006836], 
             UndirectedEdge[234, 235] -> 
             RGBColor[
              0.3728101836078023, 0.49733117588158576`, 0.9449761131297559], 
             UndirectedEdge[179, 386] -> 
             RGBColor[
              0.17892806853100302`, 0.30539512309383293`, 0.93350106085126], 
             UndirectedEdge[267, 476] -> 
             RGBColor[
              0.9187775169477521, 0.6742536840952063, 0.3030402150761125], 
             UndirectedEdge[59, 195] -> 
             RGBColor[
              0.2561715150223729, 0.3865828828736374, 0.9378999608575047], 
             UndirectedEdge[75, 108] -> 
             RGBColor[
              0.31502960292460824`, 0.4450992956026424, 0.9413743981617775], 
             UndirectedEdge[334, 363] -> 
             RGBColor[
              0.40380771802618465`, 0.5241796822134083, 0.9469512486128518], 
             UndirectedEdge[77, 329] -> 
             RGBColor[
              0.7446878798780471, 0.8004364154026, 0.9754252127138938], 
             UndirectedEdge[328, 462] -> 
             RGBColor[
              0.4245956854340748, 0.5418984360706564, 0.9483550662650316], 
             UndirectedEdge[285, 480] -> 
             RGBColor[
              0.3339827883337351, 0.46370083761681824`, 0.9425020658366099], 
             UndirectedEdge[204, 334] -> 
             RGBColor[
              0.4523485649591434, 0.5649043975631496, 0.9504086517863296], 
             UndirectedEdge[70, 238] -> 
             RGBColor[
              0.28920204195997834`, 0.42024532074903687`, 0.9398196197075317],
              UndirectedEdge[83, 270] -> 
             RGBColor[
              0.955384395176871, 0.9648919755228036, 0.9036547602559704], 
             UndirectedEdge[112, 190] -> 
             RGBColor[
              0.24818657202567745`, 0.37819020150948346`, 0.9374452301665075],
              UndirectedEdge[263, 453] -> 
             RGBColor[
              0.27885374219171843`, 0.41042334176488493`, 0.9391916801394509],
              UndirectedEdge[210, 474] -> 
             RGBColor[
              0.9145804341522545, 0.6348102980864267, 0.4731147536068143], 
             UndirectedEdge[96, 392] -> 
             RGBColor[
              0.3010815634219416, 0.43378619120311424`, 0.9404575216753974], 
             UndirectedEdge[70, 84] -> 
             RGBColor[
              0.24578222839824324`, 0.37566308391285935`, 0.9373083063538328],
              UndirectedEdge[77, 278] -> 
             RGBColor[
              0.7775908081460805, 0.8263457284855322, 0.9672404849556133], 
             UndirectedEdge[238, 265] -> 
             RGBColor[
              0.32058421295120315`, 0.4520956650524487, 0.9416483204611299], 
             UndirectedEdge[157, 392] -> 
             RGBColor[
              0.3042725009406671, 0.4371400688524187, 0.9406392408465198], 
             UndirectedEdge[145, 294] -> 
             RGBColor[
              0.22948545468760678`, 0.35853414146784807`, 0.9363802291999281],
              UndirectedEdge[29, 383] -> 
             RGBColor[
              0.3692814154214852, 0.49427473423964385`, 0.944751263141291], 
             UndirectedEdge[210, 227] -> 
             RGBColor[
              0.8408474405782448, 0.3149769045127923, 0.18674886126930004`], 
             UndirectedEdge[45, 276] -> 
             RGBColor[
              0.4511613140247853, 0.5582811601613382, 0.9513035162562244], 
             UndirectedEdge[57, 219] -> 
             RGBColor[
              0.5637559435916646, 0.6567214977803754, 0.9588000794670529], 
             UndirectedEdge[291, 311] -> 
             RGBColor[
              0.7008920044449292, 0.7662614279396891, 0.9708220228610445], 
             UndirectedEdge[11, 485] -> 
             RGBColor[
              0.24345966129558455`, 0.3732219186287056, 0.9371760395932665], 
             UndirectedEdge[13, 338] -> 
             RGBColor[
              0.30836079438708164`, 0.4403868770076641, 0.9409105178148355], 
             UndirectedEdge[190, 351] -> 
             RGBColor[
              0.2690775343767192, 0.40014792750394457`, 0.9386349395669901], 
             UndirectedEdge[314, 397] -> 
             RGBColor[
              0.34431176305958455`, 0.4726472763749843, 0.9431602189725873], 
             UndirectedEdge[339, 365] -> 
             RGBColor[
              0.2143326753092825, 0.34260760959952685`, 0.9355173008308608], 
             UndirectedEdge[320, 337] -> 
             RGBColor[
              0.9244065988908812, 0.9404637664434601, 0.9125392493325524], 
             UndirectedEdge[317, 357] -> 
             RGBColor[
              0.895271303645258, 0.6164935275347583, 0.23428070819651722`], 
             UndirectedEdge[153, 452] -> 
             RGBColor[
              0.2344431943228335, 0.36374504016331954`, 0.9366625651378359], 
             UndirectedEdge[308, 423] -> 
             RGBColor[
              0.1833860881198116, 0.31008078433643804`, 0.9337549384717936], 
             UndirectedEdge[149, 441] -> 
             RGBColor[
              0.4020035872776604, 0.5226170348372846, 0.946836290996886], 
             UndirectedEdge[486, 493] -> 
             RGBColor[
              0.9642524295918031, 0.9698103203224957, 0.7679790459557528], 
             UndirectedEdge[241, 402] -> 
             RGBColor[
              0.6288966867837086, 0.7086387216585579, 0.9645893173262957], 
             UndirectedEdge[293, 432] -> 
             RGBColor[
              0.9264483908194477, 0.943709860746635, 0.9762410122023322], 
             UndirectedEdge[23, 211] -> 
             RGBColor[
              0.226770956748013, 0.3556810320242251, 0.9362256425580082], 
             UndirectedEdge[8, 381] -> 
             RGBColor[
              0.5947992155017207, 0.6819238244004215, 0.9612439195470645], 
             UndirectedEdge[238, 343] -> 
             RGBColor[
              0.306520714368336, 0.43844834351747275`, 0.9408058924805078], 
             UndirectedEdge[355, 363] -> 
             RGBColor[
              0.366759080123219, 0.492090014180544, 0.9445905421664991], 
             UndirectedEdge[66, 398] -> 
             RGBColor[
              0.26221606410223275`, 0.392936087203117, 0.9382441889854937], 
             UndirectedEdge[113, 477] -> 
             RGBColor[
              0.2119319440670913, 0.3400842888488316, 0.9353805827381816], 
             UndirectedEdge[7, 241] -> 
             RGBColor[
              0.7720821236708154, 0.8220268199822758, 0.9778774834237032], 
             UndirectedEdge[161, 259] -> 
             RGBColor[
              0.9260863286561598, 0.722291136783578, 0.31168537193130974`], 
             UndirectedEdge[346, 408] -> 
             RGBColor[
              0.22019359510263653`, 0.34876780790611966`, 0.9358510715426385],
              UndirectedEdge[33, 270] -> 
             RGBColor[
              0.9342186701882929, 0.7654658229940685, 0.5176324949764846], 
             UndirectedEdge[197, 270] -> 
             RGBColor[
              0.843824355466433, 0.8769260052856713, 0.8927516199339326], 
             UndirectedEdge[115, 381] -> 
             RGBColor[
              0.7452365910783697, 0.8006024945852935, 0.9757899812168571], 
             UndirectedEdge[112, 224] -> 
             RGBColor[
              0.2736149088479135, 0.4049169957593272, 0.9388933363306806], 
             UndirectedEdge[133, 296] -> 
             RGBColor[
              0.3292967430314739, 0.4596420207034847, 0.942203475173657], 
             UndirectedEdge[204, 244] -> 
             RGBColor[
              0.42216704011068096`, 0.5387626777069581, 0.9484855117114601], 
             UndirectedEdge[116, 280] -> 
             RGBColor[
              0.25280916302349343`, 0.3830488377373854, 0.9377084798853226], 
             UndirectedEdge[81, 267] -> 
             RGBColor[
              0.906340376624757, 0.9184812574076573, 0.6975246745106891], 
             UndirectedEdge[431, 459] -> 
             RGBColor[
              0.41954302397723237`, 0.5378088133487329, 0.9479538883938678], 
             UndirectedEdge[46, 293] -> 
             RGBColor[
              0.9359635798708703, 0.8383264425596675, 0.6074452935938994], 
             UndirectedEdge[145, 358] -> 
             RGBColor[
              0.2231421897482483, 0.351866967830356, 0.9360189896456512], 
             UndirectedEdge[12, 480] -> 
             RGBColor[
              0.31297532312712917`, 0.4421451064609878, 0.9412865192071291], 
             UndirectedEdge[318, 321] -> 
             RGBColor[
              0.33755888801482614`, 0.46679827542058316`, 0.9427299317460682],
              UndirectedEdge[38, 47] -> 
             RGBColor[
              0.24595116399713765`, 0.375840645938433, 0.9373179269862719], 
             UndirectedEdge[271, 492] -> 
             RGBColor[
              0.2662123163354113, 0.39713640167721365`, 0.9384717696382479], 
             UndirectedEdge[246, 333] -> 
             RGBColor[
              0.33643527177961996`, 0.46448215779697133`, 0.9427075059768388],
              UndirectedEdge[97, 137] -> 
             RGBColor[
              0.2259075246268314, 0.35477351012010483`, 0.9361764713760403], 
             UndirectedEdge[406, 486] -> 
             RGBColor[
              0.9627729895914936, 0.9654828212213326, 0.7058550168364002], 
             UndirectedEdge[272, 306] -> 
             RGBColor[
              0.8390812230199529, 0.30140098239829205`, 0.18505752934082234`],
              UndirectedEdge[50, 219] -> 
             RGBColor[
              0.48360346312109975`, 0.5913139580095534, 0.9525830605432293], 
             UndirectedEdge[326, 405] -> 
             RGBColor[
              0.9345940973525277, 0.7578425175728066, 0.403625723074449], 
             UndirectedEdge[180, 343] -> 
             RGBColor[
              0.28150922552658186`, 0.4132144231171943, 0.9393429059869358], 
             UndirectedEdge[229, 380] -> 
             RGBColor[
              0.2819134302618612, 0.4136392679220333, 0.9393659248486427], 
             UndirectedEdge[184, 470] -> 
             RGBColor[
              0.2562569900664413, 0.3866727225643841, 0.9379048285348154], 
             UndirectedEdge[188, 483] -> 
             RGBColor[
              0.31696315839045336`, 0.4478408551549855, 0.9414585414299963], 
             UndirectedEdge[364, 374] -> 
             RGBColor[
              0.2551484985501697, 0.3855076276983612, 0.93784170158283], 
             UndirectedEdge[161, 469] -> 
             RGBColor[
              0.9253813180460291, 0.7190898482623855, 0.3110970937968252], 
             UndirectedEdge[14, 182] -> 
             RGBColor[
              0.34266467028924463`, 0.47103542678761523`, 0.9430620495117685],
              UndirectedEdge[374, 391] -> 
             RGBColor[
              0.24642877472957408`, 0.3763426451004932, 0.9373451262109225], 
             UndirectedEdge[352, 367] -> 
             RGBColor[
              0.2288379775147259, 0.35785360190672644`, 0.9363433563327893], 
             UndirectedEdge[8, 289] -> 
             RGBColor[
              0.5298323406094952, 0.6288020963090049, 0.9562341229930127], 
             UndirectedEdge[160, 275] -> 
             RGBColor[
              0.4180928553323577, 0.5365527501561378, 0.9478614849301503], 
             UndirectedEdge[118, 151] -> 
             RGBColor[
              0.31595121433390305`, 0.44790234871507695`, 0.9413597168905753],
              UndirectedEdge[43, 217] -> 
             RGBColor[
              0.30643378623989703`, 0.43839711764350564`, 0.9407994722898634],
              UndirectedEdge[117, 154] -> 
             RGBColor[
              0.34530823850037556`, 0.4735103733174856, 0.9432237135065259], 
             UndirectedEdge[139, 468] -> 
             RGBColor[
              0.5212061017709153, 0.6221776193417614, 0.9554504000537172], 
             UndirectedEdge[279, 324] -> 
             RGBColor[
              0.3241188367997081, 0.45236629730551653`, 0.9419757314019449], 
             UndirectedEdge[4, 29] -> 
             RGBColor[
              0.36696197867847585`, 0.49226575471112954`, 0.9446034706830237],
              UndirectedEdge[239, 393] -> 
             RGBColor[
              0.4060710006373207, 0.5259256972403187, 0.9471546820617923], 
             UndirectedEdge[94, 127] -> 
             RGBColor[
              0.5906994451507328, 0.6605608453144329, 0.9482643190369882], 
             UndirectedEdge[157, 459] -> 
             RGBColor[
              0.3465448636437761, 0.4740080224761397, 0.94332350710475], 
             UndirectedEdge[48, 85] -> 
             RGBColor[
              0.21086321568284044`, 0.3389609875556907, 0.9353197202377406], 
             UndirectedEdge[26, 215] -> 
             RGBColor[
              0.33537631974199883`, 0.4626312893738342, 0.942674216260174], 
             UndirectedEdge[63, 165] -> 
             RGBColor[
              0.42168442508772075`, 0.5396635873606885, 0.9480903365790616], 
             UndirectedEdge[165, 282] -> 
             RGBColor[
              0.5158458225400988, 0.6170307537111264, 0.9552481214059205], 
             UndirectedEdge[288, 465] -> 
             RGBColor[
              0.2693457460924733, 0.4004298350228071, 0.9386502138274186], 
             UndirectedEdge[200, 500] -> 
             RGBColor[
              0.8601603348227043, 0.3966998445648045, 0.2026301493422178], 
             UndirectedEdge[293, 353] -> 
             RGBColor[
              0.7969674264911133, 0.8418814193634385, 0.9635324755439242], 
             UndirectedEdge[239, 296] -> 
             RGBColor[
              0.33217516852493173`, 0.46213516819204603`, 0.9423868859008084],
              UndirectedEdge[139, 274] -> 
             RGBColor[
              0.5133847204187874, 0.6158278696108893, 0.9548346722630138], 
             UndirectedEdge[140, 361] -> 
             RGBColor[
              0.5719177559547599, 0.6633194007954346, 0.9594619041005235], 
             UndirectedEdge[83, 197] -> 
             RGBColor[
              0.8091856625186589, 0.8516756760168047, 0.981399600787607], 
             UndirectedEdge[256, 444] -> 
             RGBColor[
              0.28033959264989716`, 0.411985064804791, 0.9392762971249253], 
             UndirectedEdge[21, 166] -> 
             RGBColor[
              0.9095040888434207, 0.6206039273550481, 0.282195231981873], 
             UndirectedEdge[92, 363] -> 
             RGBColor[
              0.506974473041424, 0.6093066729422614, 0.9546939442160238], 
             UndirectedEdge[41, 212] -> 
             RGBColor[
              0.22552146354030395`, 0.35436773544047784`, 0.9361544857682886],
              UndirectedEdge[96, 433] -> 
             RGBColor[
              0.31083399291217784`, 0.4424870131772134, 0.9410696465455513], 
             UndirectedEdge[346, 407] -> 
             RGBColor[
              0.2161204994130187, 0.34448672608714886`, 0.9356191147687198], 
             UndirectedEdge[32, 155] -> 
             RGBColor[
              0.5507999265063706, 0.6462032194486154, 0.9577801343426442], 
             UndirectedEdge[302, 477] -> 
             RGBColor[
              0.21741049289010705`, 0.3458425910218791, 0.9356925779888657], 
             UndirectedEdge[24, 489] -> 
             RGBColor[
              0.9135348042436461, 0.9315079481929074, 0.8990421753997224], 
             UndirectedEdge[359, 427] -> 
             RGBColor[
              0.3324756951564906, 0.4596914885288097, 0.9425050411722034], 
             UndirectedEdge[217, 290] -> 
             RGBColor[
              0.3031025001174864, 0.43489572471311266`, 0.9406097604733883], 
             UndirectedEdge[40, 297] -> 
             RGBColor[
              0.4527821832454718, 0.5648055930283604, 0.9505673549688282], 
             UndirectedEdge[41, 456] -> 
             RGBColor[
              0.22809260204387605`, 0.3570701650273288, 0.9363009083024085], 
             UndirectedEdge[341, 469] -> 
             RGBColor[
              0.927002024559022, 0.7238962731152077, 0.3735657841038871], 
             UndirectedEdge[169, 498] -> 
             RGBColor[
              0.4773158479045384, 0.5865455340196324, 0.9519951984940587], 
             UndirectedEdge[6, 329] -> 
             RGBColor[
              0.8551238518896912, 0.8873165640509703, 0.9860436704429549], 
             UndirectedEdge[92, 219] -> 
             RGBColor[
              0.5677032440041356, 0.6599260940790765, 0.9591108254149605], 
             UndirectedEdge[341, 387] -> 
             RGBColor[
              0.8843435887930974, 0.9064532397024012, 0.7600495256450741], 
             UndirectedEdge[13, 478] -> 
             RGBColor[
              0.28132910192119526`, 0.41302510178743673`, 0.939332648214078], 
             UndirectedEdge[33, 267] -> 
             RGBColor[
              0.9337384293685642, 0.7577785430140971, 0.3161344657047144], 
             UndirectedEdge[10, 123] -> 
             RGBColor[
              0.21296296597852177`, 0.34116795824830987`, 0.9354392979107774],
              UndirectedEdge[57, 337] -> 
             RGBColor[
              0.730726843956438, 0.7892639238928545, 0.9741400277373693], 
             UndirectedEdge[70, 135] -> 
             RGBColor[
              0.25443846593234043`, 0.3847613383983545, 0.9378012662756438], 
             UndirectedEdge[51, 130] -> 
             RGBColor[
              0.1789270004053139, 0.3053940004260106, 0.9335010000230821], 
             UndirectedEdge[219, 361] -> 
             RGBColor[
              0.5852351734855985, 0.6741310802897922, 0.9605102999918589], 
             UndirectedEdge[70, 131] -> 
             RGBColor[
              0.2609296066664183, 0.3915839388719636, 0.9381709271376673], 
             UndirectedEdge[61, 362] -> 
             RGBColor[
              0.3561441161626767, 0.48289586592152384`, 0.9439141660493773], 
             UndirectedEdge[49, 487] -> 
             RGBColor[
              0.5348230464505574, 0.633232468469062, 0.9565223758194106], 
             UndirectedEdge[83, 375] -> 
             RGBColor[
              0.9394735703012015, 0.9539944639741937, 0.9739704912597569], 
             UndirectedEdge[147, 385] -> 
             RGBColor[
              0.24248237828575928`, 0.37219473222205746`, 0.9371203847716176],
              UndirectedEdge[105, 395] -> 
             RGBColor[
              0.2554464216840092, 0.38582076380144426`, 0.9378586678645644], 
             UndirectedEdge[57, 204] -> 
             RGBColor[
              0.5515680195619116, 0.6468267919933015, 0.9578406014415939], 
             UndirectedEdge[362, 363] -> 
             RGBColor[
              0.3966364490357477, 0.5179682894523514, 0.9464943016940854], 
             UndirectedEdge[313, 390] -> 
             RGBColor[
              0.28385568108857195`, 0.41568069668672125`, 0.9394765331599213],
              UndirectedEdge[15, 430] -> 
             RGBColor[
              0.23698890967688827`, 0.36642074840810707`, 0.9368075398612009],
              UndirectedEdge[104, 430] -> 
             RGBColor[
              0.24315634658411125`, 0.3729031156356836, 0.937158766269162], 
             UndirectedEdge[341, 405] -> 
             RGBColor[
              0.9937930272646951, 0.989132237877419, 0.5657875066366207], 
             UndirectedEdge[8, 311] -> 
             RGBColor[
              0.6835752486050087, 0.752395433322769, 0.9693271520415703], 
             UndirectedEdge[305, 460] -> 
             RGBColor[
              0.24972906299601538`, 0.37981145731888477`, 0.9375330727453572],
              UndirectedEdge[451, 456] -> 
             RGBColor[
              0.21755217330464396`, 0.3459915061206145, 0.9357006464788762], 
             UndirectedEdge[257, 306] -> 
             RGBColor[
              0.8582164736566054, 0.4477775920644729, 0.2033538487175496], 
             UndirectedEdge[65, 167] -> 
             RGBColor[
              0.986067541242265, 0.9756937071602725, 0.6343029674871418], 
             UndirectedEdge[24, 329] -> 
             RGBColor[
              0.8597649491834076, 0.8910172490537498, 0.986486342445986], 
             UndirectedEdge[14, 63] -> 
             RGBColor[
              0.3630391373968948, 0.48868276614576933`, 0.9443602925394342], 
             UndirectedEdge[64, 172] -> 
             RGBColor[
              0.31974345189880926`, 0.449434024298521, 0.9416655397334055], 
             UndirectedEdge[50, 361] -> 
             RGBColor[
              0.5425697371949871, 0.6391572117563517, 0.9572443985054486], 
             UndirectedEdge[253, 291] -> 
             RGBColor[
              0.819979493708928, 0.8592158126034372, 0.9319826199336896], 
             UndirectedEdge[184, 280] -> 
             RGBColor[
              0.2569621251304517, 0.38741386422480434`, 0.9379449849335569], 
             UndirectedEdge[402, 487] -> 
             RGBColor[
              0.565871305361324, 0.6584388437609466, 0.958966608494386], 
             UndirectedEdge[356, 463] -> 
             RGBColor[
              0.26821764598055253`, 0.3992441302795001, 0.9385859701949193], 
             UndirectedEdge[287, 301] -> 
             RGBColor[
              0.20928219811004087`, 0.33729923784437454`, 0.9352296836258756],
              UndirectedEdge[265, 328] -> 
             RGBColor[
              0.35316375548579293`, 0.48031442730049023`, 0.9437242601024758],
              UndirectedEdge[196, 321] -> 
             RGBColor[
              0.31443739392836134`, 0.4455653460211614, 0.9413008174322348], 
             UndirectedEdge[122, 267] -> 
             RGBColor[
              0.9282834555711476, 0.7330087810415269, 0.3115827018545064], 
             UndirectedEdge[330, 354] -> 
             RGBColor[
              0.3341066984387609, 0.463595840128386, 0.9425177354345229], 
             UndirectedEdge[155, 393] -> 
             RGBColor[
              0.5135503027141461, 0.615962296777659, 0.9548477075078524], 
             UndirectedEdge[291, 319] -> 
             RGBColor[
              0.6849084125962169, 0.7537749245076777, 0.969228927800723], 
             UndirectedEdge[63, 206] -> 
             RGBColor[
              0.3810348762200533, 0.5044549912372471, 0.9455001832701985], 
             UndirectedEdge[174, 215] -> 
             RGBColor[
              0.2753901052316153, 0.40678283971254936`, 0.9389944311385647], 
             UndirectedEdge[254, 471] -> 
             RGBColor[
              0.5466554162409889, 0.4017985093907806, 0.5694083486000513], 
             UndirectedEdge[453, 463] -> 
             RGBColor[
              0.2757020968027919, 0.407110762635264, 0.939012198596993], 
             UndirectedEdge[154, 174] -> 
             RGBColor[
              0.2880991557381853, 0.4200673355937856, 0.9397208847641902], 
             UndirectedEdge[119, 197] -> 
             RGBColor[
              0.8441364985929255, 0.8770550844901885, 0.8875786005274353], 
             UndirectedEdge[50, 340] -> 
             RGBColor[
              0.3891862943583425, 0.5115153399264449, 0.9460195844259542], 
             UndirectedEdge[443, 446] -> 
             RGBColor[
              0.5813316267430582, 0.5676003433786956, 0.6012346277346379], 
             UndirectedEdge[275, 324] -> 
             RGBColor[
              0.3916907059243627, 0.5136845353495464, 0.9461791633163769], 
             UndirectedEdge[95, 286] -> 
             RGBColor[
              0.22509159237078977`, 0.3539159135859121, 0.9361300052411223], 
             UndirectedEdge[306, 317] -> 
             RGBColor[
              0.8704899188810679, 0.5035084402927961, 0.2135951122625132], 
             UndirectedEdge[118, 188] -> 
             RGBColor[
              0.3311926249986076, 0.4612841383736176, 0.9423242790961401], 
             UndirectedEdge[7, 69] -> 
             RGBColor[
              0.874072307624645, 0.9024255483118935, 0.9878509910664408], 
             UndirectedEdge[88, 166] -> 
             RGBColor[
              0.8523652692557177, 0.3906026653424749, 0.19727300714892185`], 
             UndirectedEdge[9, 44] -> 
             RGBColor[
              0.5359104641208152, 0.634115283121385, 0.9566079813217554], 
             UndirectedEdge[76, 459] -> 
             RGBColor[
              0.40093570974009674`, 0.5216920929873327, 0.9467682467844796], 
             UndirectedEdge[254, 325] -> 
             RGBColor[
              0.20775758490962407`, 0.33569677270467635`, 0.935142859159575], 
             UndirectedEdge[171, 433] -> 
             RGBColor[
              0.2936242383072788, 0.42439846992600005`, 0.9400895764803525], 
             UndirectedEdge[112, 447] -> 
             RGBColor[
              0.2473817363738829, 0.37734426820991973`, 0.9373993959667855], 
             UndirectedEdge[199, 359] -> 
             RGBColor[
              0.364147570424561, 0.48982805573786037`, 0.9444241390777679], 
             UndirectedEdge[74, 224] -> 
             RGBColor[
              0.2903501525391211, 0.42250679795452123`, 0.9398463837013205], 
             UndirectedEdge[292, 386] -> 
             RGBColor[
              0.17894881608916835`, 0.3054169300929359, 0.9335022423940041], 
             UndirectedEdge[112, 195] -> 
             RGBColor[
              0.25920772540956155`, 0.3897741324974299, 0.9380728685473844], 
             UndirectedEdge[97, 408] -> 
             RGBColor[
              0.2271195205155527, 0.3560473946441286, 0.9362454927489157], 
             UndirectedEdge[236, 422] -> 
             RGBColor[
              0.26066758061653217`, 0.39130853288012224`, 0.9381560051417591],
              UndirectedEdge[27, 114] -> 
             RGBColor[
              0.5063987002640795, 0.610156303732676, 0.9542847071658003], 
             UndirectedEdge[110, 355] -> 
             RGBColor[
              0.30021105187484454`, 0.43102571577490256`, 0.9404755205872981],
              UndirectedEdge[104, 215] -> 
             RGBColor[
              0.26534838496499225`, 0.39622835503049064`, 0.9384225700247744],
              UndirectedEdge[80, 406] -> 
             RGBColor[
              0.8900806471760057, 0.9077659645302347, 0.6988562638191269], 
             UndirectedEdge[276, 292] -> 
             RGBColor[
              0.39925539426111123`, 0.5037247474643232, 0.9483475509136101], 
             UndirectedEdge[425, 466] -> 
             RGBColor[
              0.4394255113443823, 0.5536672437102792, 0.9495973233231294], 
             UndirectedEdge[164, 309] -> 
             RGBColor[
              0.9052777371288019, 0.5616050038337315, 0.3236174733815438], 
             UndirectedEdge[95, 137] -> 
             RGBColor[
              0.22358173079098384`, 0.35232895333478276`, 0.9360440208577924],
              UndirectedEdge[119, 426] -> 
             RGBColor[
              0.9304108836330538, 0.9448589600540273, 0.8960699725342486], 
             UndirectedEdge[238, 431] -> 
             RGBColor[
              0.38434692528377257`, 0.5073237216678145, 0.9457112241078087], 
             UndirectedEdge[93, 266] -> 
             RGBColor[
              0.2794030113306438, 0.41100065845557043`, 0.9392229602043418], 
             UndirectedEdge[15, 148] -> 
             RGBColor[
              0.2369473179686802, 0.36637703288571377`, 0.9368051712749479], 
             UndirectedEdge[225, 470] -> 
             RGBColor[
              0.26486570011979793`, 0.3957210226542046, 0.9383950818369088], 
             UndirectedEdge[249, 296] -> 
             RGBColor[
              0.3014838445951241, 0.4337768875889444, 0.9404962532659576], 
             UndirectedEdge[273, 421] -> 
             RGBColor[
              0.236299010735822, 0.36569562087892715`, 0.9367682511371211], 
             UndirectedEdge[150, 159] -> 
             RGBColor[
              0.821097410502475, 0.1631695188320622, 0.16783621016427433`], 
             UndirectedEdge[85, 407] -> 
             RGBColor[
              0.2142869484175896, 0.3425595477371053, 0.9355146967520258], 
             UndirectedEdge[71, 388] -> 
             RGBColor[
              0.8509768197746642, 0.8842586853652235, 0.9761468351078537], 
             UndirectedEdge[61, 435] -> 
             RGBColor[
              0.2909721876561818, 0.42176628331072286`, 0.9399328603098349], 
             UndirectedEdge[10, 177] -> 
             RGBColor[
              0.21382948684753797`, 0.34207872662224226`, 0.9354886449923652],
              UndirectedEdge[16, 52] -> 
             RGBColor[
              0.6198385630520318, 0.4001930339226935, 0.5644333341255259], 
             UndirectedEdge[25, 459] -> 
             RGBColor[
              0.35196069990557133`, 0.47927240102423385`, 0.9436476024647243],
              UndirectedEdge[105, 453] -> 
             RGBColor[
              0.265106051538209, 0.39597364723411466`, 0.9384087694946193], 
             UndirectedEdge[61, 384] -> 
             RGBColor[
              0.3038237458344487, 0.43527408579193255`, 0.9406647375359107], 
             UndirectedEdge[104, 323] -> 
             RGBColor[
              0.2429591667599799, 0.3726958671385986, 0.9371475371698791], 
             UndirectedEdge[150, 406] -> 
             RGBColor[
              0.9060315184464693, 0.5729271685521393, 0.29311167174990027`], 
             UndirectedEdge[413, 493] -> 
             RGBColor[
              0.9837066431260291, 0.9560378233723712, 0.44758049868418615`], 
             UndirectedEdge[94, 254] -> 
             RGBColor[
              0.5959586642234989, 0.6660886180136586, 0.9485638237828649], 
             UndirectedEdge[431, 487] -> 
             RGBColor[
              0.5139856537736541, 0.6161859985800608, 0.9549178263261018], 
             UndirectedEdge[234, 332] -> 
             RGBColor[
              0.3953853483413155, 0.5168846489129837, 0.946414582664141], 
             UndirectedEdge[82, 89] -> 
             RGBColor[
              0.2718901700216876, 0.4031041858982062, 0.9387951150060494], 
             UndirectedEdge[154, 255] -> 
             RGBColor[
              0.3535633647009796, 0.4806605487177418, 0.9437497228483069], 
             UndirectedEdge[22, 324] -> 
             RGBColor[
              0.41054698853962773`, 0.5300168996065678, 0.9473806689706655], 
             UndirectedEdge[105, 112] -> 
             RGBColor[
              0.2470843980758506, 0.3770317468063509, 0.9373824629905851], 
             UndirectedEdge[6, 406] -> 
             RGBColor[
              0.9091541002347256, 0.9227285742942248, 0.700740799303404], 
             UndirectedEdge[396, 422] -> 
             RGBColor[
              0.6137790328303492, 0.6759479174311498, 0.7377723993512193], 
             UndirectedEdge[409, 456] -> 
             RGBColor[
              0.23260709522442666`, 0.3618151835954873, 0.9365580020104467], 
             UndirectedEdge[91, 473] -> 
             RGBColor[
              0.32723005291391416`, 0.4578519575985201, 0.9420717875068684], 
             UndirectedEdge[369, 379] -> 
             RGBColor[
              0.3646233115605392, 0.49024011879839996`, 0.944454452882271], 
             UndirectedEdge[353, 441] -> 
             RGBColor[
              0.5448974710637005, 0.6413248437593597, 0.9573393706579376], 
             UndirectedEdge[165, 481] -> 
             RGBColor[
              0.3711249763330434, 0.49587153404117, 0.9448687332123786], 
             UndirectedEdge[185, 318] -> 
             RGBColor[
              0.3129435362062064, 0.4431846498190406, 0.9412454229080396], 
             UndirectedEdge[264, 445] -> 
             RGBColor[
              0.23221275436386601`, 0.3614007063483834, 0.9365355448818129], 
             UndirectedEdge[258, 297] -> 
             RGBColor[
              0.4463933258988235, 0.5592718859080008, 0.9501602626281445], 
             UndirectedEdge[57, 139] -> 
             RGBColor[
              0.5826390838232848, 0.6720516816961779, 0.9602866294373078], 
             UndirectedEdge[447, 463] -> 
             RGBColor[
              0.2567986541117429, 0.38724204581948013`, 0.9379356755008752], 
             UndirectedEdge[9, 26] -> 
             RGBColor[
              0.4808866078491948, 0.5876336896788764, 0.952776616899017], 
             UndirectedEdge[181, 262] -> 
             RGBColor[
              0.4483915053521436, 0.5621777184210172, 0.9499628984888329], 
             UndirectedEdge[203, 291] -> 
             RGBColor[
              0.5947468881404891, 0.681688814806365, 0.9613714325118958], 
             UndirectedEdge[45, 254] -> 
             RGBColor[
              0.25964036057789125`, 0.3902288594899984, 0.9380975064801944], 
             UndirectedEdge[240, 412] -> 
             RGBColor[
              0.2495035202048371, 0.3795743975451175, 0.9375202284170604], 
             UndirectedEdge[208, 258] -> 
             RGBColor[
              0.3477704837485026, 0.4756430463953687, 0.9433806055964585], 
             UndirectedEdge[293, 420] -> 
             RGBColor[
              0.9614575711812897, 0.9707757002112165, 0.9501264579014013], 
             UndirectedEdge[85, 346] -> 
             RGBColor[
              0.21604910573121133`, 0.34441168680094847`, 0.9356150490041585],
              UndirectedEdge[65, 166] -> 
             RGBColor[
              0.9117926198146232, 0.6283236796935395, 0.2910857426521841], 
             UndirectedEdge[254, 347] -> 
             RGBColor[
              0.20771262472504887`, 0.3356495167000475, 0.935140298743576], 
             UndirectedEdge[236, 292] -> 
             RGBColor[
              0.23314689454244097`, 0.36238254690397387`, 0.9365887427830462],
              UndirectedEdge[100, 401] -> 
             RGBColor[
              0.8523336151346661, 0.7939714926704016, 0.620783111215081], 
             UndirectedEdge[146, 400] -> 
             RGBColor[
              0.276927529490606, 0.4083987700870767, 0.9390819851756989], 
             UndirectedEdge[104, 153] -> 
             RGBColor[
              0.24575331572793313`, 0.3756326948631943, 0.937306659820031], 
             UndirectedEdge[216, 281] -> 
             RGBColor[
              0.2553973215721218, 0.3857691564707237, 0.9378558716858294], 
             UndirectedEdge[123, 125] -> 
             RGBColor[
              0.2078185513522534, 0.33576085230137553`, 0.9351463311082908], 
             UndirectedEdge[78, 358] -> 
             RGBColor[
              0.22252765585105994`, 0.3512210537407115, 0.9359839928493279], 
             UndirectedEdge[313, 478] -> 
             RGBColor[
              0.26649991887633445`, 0.3974386901827782, 0.9384881481774836], 
             UndirectedEdge[368, 401] -> 
             RGBColor[
              0.5907770138305127, 0.6754225066218276, 0.9626395084549426], 
             UndirectedEdge[106, 369] -> 
             RGBColor[
              0.46890138102995677`, 0.5788082013626439, 0.9515831360340911], 
             UndirectedEdge[111, 146] -> 
             RGBColor[
              0.2655122364597581, 0.39640057334027434`, 0.9384319011250047], 
             UndirectedEdge[129, 266] -> 
             RGBColor[
              0.32256025857167225`, 0.4520297101069751, 0.9418393155552645], 
             UndirectedEdge[99, 278] -> 
             RGBColor[
              0.9709926371751241, 0.9748878865987054, 0.7597061890098948], 
             UndirectedEdge[147, 171] -> 
             RGBColor[
              0.2566176973332457, 0.3870518487719572, 0.9379253702800414], 
             UndirectedEdge[164, 166] -> 
             RGBColor[
              0.8278225605966679, 0.21486196943559147`, 0.17427622148944416`],
              UndirectedEdge[129, 433] -> 
             RGBColor[
              0.3405530126531223, 0.4693916356931953, 0.94292071472042], 
             UndirectedEdge[179, 283] -> 
             RGBColor[
              0.18007164814629245`, 0.3065970977766376, 0.9335661860185762], 
             UndirectedEdge[136, 291] -> 
             RGBColor[
              0.8119439013123007, 0.853362410017863, 0.9518331785269256], 
             UndirectedEdge[321, 479] -> 
             RGBColor[
              0.37233306340343797`, 0.49691791834132404`, 0.9449457114522347],
              UndirectedEdge[181, 239] -> 
             RGBColor[
              0.38581385669695734`, 0.5085943039277986, 0.9458046956803003], 
             UndirectedEdge[102, 330] -> 
             RGBColor[
              0.2914935550351155, 0.4237085864737168, 0.939911498781955], 
             UndirectedEdge[406, 413] -> 
             RGBColor[
              0.9822272031257195, 0.951710324271208, 0.3854564695648335], 
             UndirectedEdge[37, 310] -> 
             RGBColor[
              0.30119863479716524`, 0.4339092406412282, 0.9404641887170249], 
             UndirectedEdge[203, 439] -> 
             RGBColor[
              0.6977395599110665, 0.7624782824674698, 0.971548992789666], 
             UndirectedEdge[320, 375] -> 
             RGBColor[
              0.9734019680069053, 0.9789510679067093, 0.8970939407523506], 
             UndirectedEdge[42, 407] -> 
             RGBColor[
              0.22341630550160935`, 0.352155080867081, 0.9360346001322872], 
             UndirectedEdge[131, 374] -> 
             RGBColor[
              0.2576696859737398, 0.38815755553304865`, 0.9379852794768397], 
             UndirectedEdge[387, 403] -> 
             RGBColor[
              0.8520128910253049, 0.8851986373727346, 0.9856507029983317], 
             UndirectedEdge[65, 348] -> 
             RGBColor[
              0.9726882187211612, 0.9195330900145834, 0.3483993164391773], 
             UndirectedEdge[217, 498] -> 
             RGBColor[
              0.3908046357587574, 0.5126843292737169, 0.9461870095342384], 
             UndirectedEdge[40, 397] -> 
             RGBColor[
              0.37237410523066483`, 0.4969534667092458, 0.9449483266011737], 
             UndirectedEdge[226, 292] -> 
             RGBColor[
              0.17919781223777545`, 0.3056786408323896, 0.9335164223563106], 
             UndirectedEdge[53, 257] -> 
             RGBColor[
              0.9176828698612274, 0.692200433274696, 0.28359567952116765`], 
             UndirectedEdge[220, 429] -> 
             RGBColor[
              0.3162555864633567, 0.44694588722950834`, 0.9414237848069549], 
             UndirectedEdge[139, 425] -> 
             RGBColor[
              0.469689014710176, 0.5782365190979204, 0.9519797771669503], 
             UndirectedEdge[317, 418] -> 
             RGBColor[
              0.9309369071770426, 0.7734480360326559, 0.5728708276939365], 
             UndirectedEdge[482, 496] -> 
             RGBColor[
              0.31768549080207875`, 0.4466395905233832, 0.9415714600344062], 
             UndirectedEdge[117, 466] -> 
             RGBColor[
              0.44229172329685795`, 0.5561498124435122, 0.9497799558142495], 
             UndirectedEdge[82, 105] -> 
             RGBColor[
              0.25209194686734443`, 0.382294998083142, 0.9376676354862561], 
             UndirectedEdge[239, 453] -> 
             RGBColor[
              0.31761867457160725`, 0.44726749674536337`, 0.9415420928317004],
              UndirectedEdge[274, 340] -> 
             RGBColor[
              0.40008441142440987`, 0.5206990676119785, 0.9467846461754836], 
             UndirectedEdge[311, 484] -> 
             RGBColor[
              0.8698742834500395, 0.8946869579845022, 0.7215434088969761], 
             UndirectedEdge[44, 140] -> 
             RGBColor[
              0.4981556569200065, 0.6034642298010868, 0.9536357845984921], 
             UndirectedEdge[139, 466] -> 
             RGBColor[
              0.5337716765091578, 0.6323789189869576, 0.9564396081263286], 
             UndirectedEdge[22, 481] -> 
             RGBColor[
              0.38481661217346425`, 0.507730540844516, 0.9457411521410921], 
             UndirectedEdge[45, 386] -> 
             RGBColor[
              0.23085473585284239`, 0.35997334278995086`, 0.9364582077366184],
              UndirectedEdge[40, 220] -> 
             RGBColor[
              0.36255668140028763`, 0.48845010762544216`, 0.9443227690359091],
              UndirectedEdge[237, 489] -> 
             RGBColor[
              0.9480949935467251, 0.959065305031835, 0.9023385571076953], 
             UndirectedEdge[61, 64] -> 
             RGBColor[
              0.3058305702683475, 0.43738338551197825`, 0.9407790232185906], 
             UndirectedEdge[82, 296] -> 
             RGBColor[
              0.28584922180975014`, 0.4173439077491774, 0.9396058846276822], 
             UndirectedEdge[27, 277] -> 
             RGBColor[
              0.6417102241932708, 0.7180330594388474, 0.9662874050409727], 
             UndirectedEdge[416, 427] -> 
             RGBColor[
              0.2705169061527906, 0.4016607985020373, 0.9387169096602777], 
             UndirectedEdge[59, 82] -> 
             RGBColor[
              0.25023486400687867`, 0.3803430862509384, 0.9375618773646605], 
             UndirectedEdge[271, 444] -> 
             RGBColor[
              0.26354918336029226`, 0.3943372800679805, 0.938320108155067], 
             UndirectedEdge[6, 486] -> 
             RGBColor[
              0.8813087089314302, 0.9081956582870432, 0.9885412054830938], 
             UndirectedEdge[171, 265] -> 
             RGBColor[
              0.29137836531202577`, 0.42245320761837074`, 0.9399464714390425],
              UndirectedEdge[219, 369] -> 
             RGBColor[
              0.47310816162837227`, 0.5822234553657439, 0.9519143092127434], 
             UndirectedEdge[244, 355] -> 
             RGBColor[
              0.3355739158146536, 0.46507899226839733`, 0.9426034510727153], 
             UndirectedEdge[450, 500] -> 
             RGBColor[
              0.8186005728713881, 0.14397773067830186`, 0.16544523562897076`],
              UndirectedEdge[18, 243] -> 
             RGBColor[
              0.8618450148200435, 0.43551288339499367`, 0.2052561643181862], 
             UndirectedEdge[377, 449] -> 
             RGBColor[
              0.8547039434845443, 0.8865518671157351, 0.9452111853810878], 
             UndirectedEdge[7, 173] -> 
             RGBColor[
              0.9116225315818571, 0.9310453814508525, 0.9449853696775101], 
             UndirectedEdge[3, 8] -> 
             RGBColor[
              0.5409798313044035, 0.6382308237734111, 0.9570070604761514], 
             UndirectedEdge[405, 469] -> 
             RGBColor[
              0.9272216806853377, 0.724366095358756, 0.3974739978928766], 
             UndirectedEdge[148, 190] -> 
             RGBColor[
              0.2438827304039313, 0.37366659108570865`, 0.9372001327531121], 
             UndirectedEdge[180, 216] -> 
             RGBColor[
              0.2680084621160904, 0.3990242647749275, 0.9385740574832979], 
             UndirectedEdge[257, 317] -> 
             RGBColor[
              0.8711268784377937, 0.5076990787158229, 0.21417744721027115`], 
             UndirectedEdge[49, 462] -> 
             RGBColor[
              0.4770465403942916, 0.586326898050649, 0.9519739976203461], 
             UndirectedEdge[223, 258] -> 
             RGBColor[
              0.3816431136278576, 0.5049818159089863, 0.9455389396199805], 
             UndirectedEdge[260, 440] -> 
             RGBColor[
              0.28362513416460355`, 0.4154383772521112, 0.9394634038536649], 
             UndirectedEdge[262, 332] -> 
             RGBColor[
              0.43913893362174417`, 0.5541636058359223, 0.9493733327998998], 
             UndirectedEdge[283, 386] -> 
             RGBColor[
              0.18007057961528944`, 0.30659597468280464`, 0.9335661251673164],
              UndirectedEdge[40, 289] -> 
             RGBColor[
              0.41278560473143366`, 0.5319558764357888, 0.9475233116148768], 
             UndirectedEdge[95, 430] -> 
             RGBColor[
              0.23341097282813747`, 0.36266010992577125`, 0.9366037816507478],
              UndirectedEdge[274, 334] -> 
             RGBColor[
              0.4327691697643524, 0.5490089625023165, 0.9488672900749079], 
             UndirectedEdge[75, 158] -> 
             RGBColor[
              0.3512349205505469, 0.4786437674256428, 0.9436013564460036], 
             UndirectedEdge[233, 476] -> 
             RGBColor[
              0.8458261121541704, 0.35324515591315253`, 0.19151644279301172`],
              UndirectedEdge[240, 416] -> 
             RGBColor[
              0.2590796192147955, 0.38963948476432886`, 0.9380655730891085], 
             UndirectedEdge[260, 280] -> 
             RGBColor[
              0.27123440340689225`, 0.4024149336080515, 0.9387577700674566], 
             UndirectedEdge[11, 193] -> 
             RGBColor[
              0.2633649248993141, 0.3941436127428313, 0.9383096149083003], 
             UndirectedEdge[3, 162] -> 
             RGBColor[
              0.4618487252450588, 0.5739886270587315, 0.9507775699403673], 
             UndirectedEdge[117, 338] -> 
             RGBColor[
              0.3505903006321732, 0.47808543005188675`, 0.9435602818348199], 
             UndirectedEdge[40, 472] -> 
             RGBColor[
              0.35732343693452717`, 0.4839173342997152, 0.9439893113261273], 
             UndirectedEdge[101, 355] -> 
             RGBColor[
              0.424769765192925, 0.5405027707410431, 0.9487934456872616], 
             UndirectedEdge[47, 364] -> 
             RGBColor[
              0.24525016381875867`, 0.3751038503049783, 0.93727800606315], 
             UndirectedEdge[377, 484] -> 
             RGBColor[
              0.9869984046810305, 0.9863165950507087, 0.692275872605006], 
             UndirectedEdge[21, 227] -> 
             RGBColor[
              0.9132594664564218, 0.6494694053055374, 0.28579138582517527`], 
             UndirectedEdge[158, 441] -> 
             RGBColor[
              0.4038268661048062, 0.5241962673166999, 0.9469524687114896], 
             UndirectedEdge[201, 222] -> 
             RGBColor[
              0.3735862388275236, 0.49760697262793063`, 0.9450400762157048], 
             UndirectedEdge[107, 477] -> 
             RGBColor[
              0.21467165996386678`, 0.3429639039643634, 0.9355366055054566], 
             UndirectedEdge[89, 239] -> 
             RGBColor[
              0.31821611673686917`, 0.4478954463410748, 0.9415761162791756], 
             UndirectedEdge[63, 275] -> 
             RGBColor[
              0.41651977831287657`, 0.5351902299070133, 0.9477612498534863], 
             UndirectedEdge[133, 344] -> 
             RGBColor[
              0.404458323018091, 0.5244601408973477, 0.9470709156438875], 
             UndirectedEdge[153, 356] -> 
             RGBColor[
              0.2571354474729763, 0.3875960369960689, 0.9379548553845563], 
             UndirectedEdge[151, 188] -> 
             RGBColor[
              0.32203573450029344`, 0.4531724542663287, 0.9417474171352478], 
             UndirectedEdge[140, 204] -> 
             RGBColor[
              0.5007635578511195, 0.6055814412615623, 0.9538410881128452], 
             UndirectedEdge[154, 369] -> 
             RGBColor[
              0.36474431369771637`, 0.4903449247678786, 0.944462163031454], 
             UndirectedEdge[16, 179] -> 
             RGBColor[
              0.29140560923354364`, 0.4148201691111312, 0.940228554342059], 
             UndirectedEdge[161, 341] -> 
             RGBColor[
              0.9919526646253864, 0.9838559907810486, 0.4794106025405692], 
             UndirectedEdge[48, 408] -> 
             RGBColor[
              0.21500770505426564`, 0.34331710866086196`, 0.9355557427762207],
              UndirectedEdge[153, 263] -> 
             RGBColor[
              0.25916680795964386`, 0.3897311256632503, 0.9380705383591434], 
             UndirectedEdge[62, 132] -> 
             RGBColor[
              0.9037259559281465, 0.5621573598635239, 0.4887023579770914], 
             UndirectedEdge[82, 225] -> 
             RGBColor[
              0.2662639580467382, 0.39719068039009175`, 0.9384747105573108], 
             UndirectedEdge[216, 465] -> 
             RGBColor[
              0.27425578181697063`, 0.40559059388349944`, 0.9389298330981818],
              UndirectedEdge[119, 489] -> 
             RGBColor[
              0.9903724843514137, 0.9902867891105125, 0.8092163797162932], 
             UndirectedEdge[287, 295] -> 
             RGBColor[
              0.2196997994484176, 0.34824879736508285`, 0.9358229506106359], 
             UndirectedEdge[28, 417] -> 
             RGBColor[
              0.8329443683967894, 0.8698408046783143, 0.9576048606613091], 
             UndirectedEdge[148, 351] -> 
             RGBColor[
              0.26485064633186906`, 0.3957052001686261, 0.9383942245459564], 
             UndirectedEdge[218, 336] -> 
             RGBColor[
              0.2271057420788739, 0.35603291263357584`, 0.9362447080873302], 
             UndirectedEdge[127, 254] -> 
             RGBColor[
              0.23123903037733173`, 0.3603772607008694, 0.9364800927412753], 
             UndirectedEdge[303, 473] -> 
             RGBColor[
              0.31604489027716914`, 0.44784149062043943`, 0.9413708849892584],
              UndirectedEdge[99, 267] -> 
             RGBColor[
              0.9913420700473246, 0.9817665875606343, 0.479566100729647], 
             UndirectedEdge[48, 145] -> 
             RGBColor[
              0.21408452170973263`, 0.34234678443255295`, 0.9355031688504769],
              UndirectedEdge[224, 342] -> 
             RGBColor[
              0.2794767176957349, 0.41107812851853454`, 0.939227157672795], 
             UndirectedEdge[193, 232] -> 
             RGBColor[
              0.32200467219797546`, 0.4513904780484862, 0.9418096996419872], 
             UndirectedEdge[216, 343] -> 
             RGBColor[
              0.2793867448603114, 0.4109835613638972, 0.9392220338529205], 
             UndirectedEdge[277, 449] -> 
             RGBColor[
              0.7498021540184663, 0.8044704085174408, 0.9756969294792002], 
             UndirectedEdge[257, 418] -> 
             RGBColor[
              0.9186634619525802, 0.7177171878043327, 0.5626295641489729], 
             UndirectedEdge[45, 422] -> 
             RGBColor[
              0.2583972380161019, 0.3889222588590351, 0.9380267124893356], 
             UndirectedEdge[133, 235] -> 
             RGBColor[
              0.3511076947395869, 0.47853357082274445`, 0.9435932497298307], 
             UndirectedEdge[145, 183] -> 
             RGBColor[
              0.21281275410739692`, 0.3410100760477749, 0.9354307435669353], 
             UndirectedEdge[196, 496] -> 
             RGBColor[
              0.2862944389618104, 0.41824398583767475`, 0.9396154168129832], 
             UndirectedEdge[115, 136] -> 
             RGBColor[
              0.9450645210490293, 0.9581750855858149, 0.964884369377244], 
             UndirectedEdge[267, 413] -> 
             RGBColor[
              0.981449315920919, 0.9490863280728146, 0.38243452466585603`], 
             UndirectedEdge[217, 340] -> 
             RGBColor[
              0.32857716094804046`, 0.4590187548700618, 0.9421576240396021], 
             UndirectedEdge[335, 383] -> 
             RGBColor[
              0.3028573462736385, 0.4337853452642071, 0.940627021112898], 
             UndirectedEdge[80, 493] -> 
             RGBColor[
              0.8915600871763152, 0.912093463631398, 0.7609802929384797], 
             UndirectedEdge[307, 372] -> 
             RGBColor[
              0.47013131999468205`, 0.580712810603117, 0.9514296061392018], 
             UndirectedEdge[18, 434] -> 
             RGBColor[
              0.9377932493402739, 0.7792631319127137, 0.510349510564296], 
             UndirectedEdge[130, 179] -> 
             RGBColor[
              0.17892806853100302`, 0.30539512309383293`, 0.93350106085126], 
             UndirectedEdge[20, 228] -> 
             RGBColor[
              0.9388076655030091, 0.7780938721344945, 0.3568427286125849], 
             UndirectedEdge[297, 311] -> 
             RGBColor[
              0.6331105387907436, 0.7114259084862791, 0.9653543852266682], 
             UndirectedEdge[127, 200] -> 
             RGBColor[
              0.5634039093287206, 0.4987072281229762, 0.587570692606852], 
             UndirectedEdge[54, 391] -> 
             RGBColor[
              0.23492401226674847`, 0.36425041030799266`, 0.9366899470084354],
              UndirectedEdge[347, 368] -> 
             RGBColor[
              0.2935143249909316, 0.4166464351270609, 0.9403629270800464], 
             UndirectedEdge[22, 182] -> 
             RGBColor[
              0.4150015938204914, 0.5338752548058805, 0.9476645124801093], 
             UndirectedEdge[96, 216] -> 
             RGBColor[
              0.2810238579235662, 0.4127042709923413, 0.9393152650199811], 
             UndirectedEdge[340, 363] -> 
             RGBColor[
              0.37112295968624204`, 0.49586978732307024`, 0.9448686047134276],
              UndirectedEdge[71, 490] -> 
             RGBColor[
              0.8731675486403643, 0.8997516085621015, 0.891254202422064], 
             UndirectedEdge[111, 201] -> 
             RGBColor[
              0.28877500860148286`, 0.42085122180616963`, 0.9397566815842886],
              UndirectedEdge[261, 484] -> 
             RGBColor[
              0.9364392575786439, 0.7675671876801757, 0.34462692180178206`], 
             UndirectedEdge[416, 499] -> 
             RGBColor[
              0.26112616120390136`, 0.3917905301531358, 0.9381821206278006], 
             UndirectedEdge[42, 430] -> 
             RGBColor[
              0.2361066473396595, 0.36549343475301654`, 0.9367572963262859], 
             UndirectedEdge[6, 81] -> 
             RGBColor[
              0.825653983169494, 0.8638180906717614, 0.9832328080563602], 
             UndirectedEdge[282, 353] -> 
             RGBColor[
              0.6236604649477651, 0.705354686885191, 0.9635159828256973], 
             UndirectedEdge[275, 441] -> 
             RGBColor[
              0.43191818188119013`, 0.5485275531316196, 0.9487424225125856], 
             UndirectedEdge[50, 255] -> 
             RGBColor[
              0.41926177634102413`, 0.5375652107821666, 0.9479359675431862], 
             UndirectedEdge[110, 217] -> 
             RGBColor[
              0.29571753049971145`, 0.4271336534107135, 0.9401891973787395], 
             UndirectedEdge[30, 110] -> 
             RGBColor[
              0.26982326266389456`, 0.40093173521567016`, 0.9386774076897386],
              UndirectedEdge[77, 482] -> 
             RGBColor[
              0.4826496570055525, 0.5883007255405965, 0.9531265853256541], 
             UndirectedEdge[52, 326] -> 
             RGBColor[
              0.8554852780065134, 0.4011124754177182, 0.19973320349637064`], 
             UndirectedEdge[44, 247] -> 
             RGBColor[
              0.4958443155073958, 0.6015877787175854, 0.9534538273357688], 
             UndirectedEdge[337, 348] -> 
             RGBColor[
              0.9100611549268829, 0.8839036332529456, 0.6426467308354947], 
             UndirectedEdge[48, 78] -> 
             RGBColor[
              0.21346998781254425`, 0.3417008703429085, 0.9354681720541533], 
             UndirectedEdge[420, 432] -> 
             RGBColor[
              0.933633649289228, 0.949068614748616, 0.9640782438285385], 
             UndirectedEdge[469, 474] -> 
             RGBColor[
              0.9267639161265591, 0.7252718203703219, 0.4846569116242533], 
             UndirectedEdge[172, 366] -> 
             RGBColor[
              0.3083293758751098, 0.43743710670339436`, 0.941015524989468], 
             UndirectedEdge[102, 415] -> 
             RGBColor[
              0.28177512151681394`, 0.41349389666170766`, 0.9393580483702217],
              UndirectedEdge[414, 485] -> 
             RGBColor[
              0.26132957932407624`, 0.39200433549489333`, 0.9381937049888145],
              UndirectedEdge[102, 193] -> 
             RGBColor[
              0.2821746373958698, 0.4139138131813651, 0.9393808002085031], 
             UndirectedEdge[128, 498] -> 
             RGBColor[
              0.4783163619958606, 0.5873577964316139, 0.9520739626283314], 
             UndirectedEdge[150, 443] -> 
             RGBColor[
              0.8779783180841267, 0.47195372718941886`, 0.21716686938390278`],
              UndirectedEdge[2, 230] -> 
             RGBColor[
              0.21816285424353754`, 0.34663337050679954`, 0.9357354238549247],
              UndirectedEdge[367, 416] -> 
             RGBColor[
              0.24568937276892794`, 0.3755654867590621, 0.9373030183631108], 
             UndirectedEdge[61, 473] -> 
             RGBColor[
              0.3253289757704718, 0.4562053401277858, 0.9419506525523447], 
             UndirectedEdge[56, 164] -> 
             RGBColor[
              0.8270991589089857, 0.20930158706742483`, 0.17358349121635427`],
              UndirectedEdge[20, 388] -> 
             RGBColor[
              0.9153530643766437, 0.7639768167303482, 0.6006827363489642], 
             UndirectedEdge[195, 296] -> 
             RGBColor[
              0.29178587282524443`, 0.4235837043718764, 0.9399439681205266], 
             UndirectedEdge[135, 391] -> 
             RGBColor[
              0.24587699790050546`, 0.37576269266847045`, 0.9373137033367878],
              UndirectedEdge[310, 399] -> 
             RGBColor[
              0.26912901254486776`, 0.40020203432257306`, 0.938637871172511], 
             UndirectedEdge[150, 476] -> 
             RGBColor[
              0.834968541704233, 0.26978911161722496`, 0.18111922106827977`], 
             UndirectedEdge[142, 222] -> 
             RGBColor[
              0.5711190039988594, 0.6615355308329243, 0.9600580034664301], 
             UndirectedEdge[48, 404] -> 
             RGBColor[
              0.21047959213928613`, 0.3385577748882776, 0.9352978734444553], 
             UndirectedEdge[330, 415] -> 
             RGBColor[
              0.29673111972249494`, 0.4292135990409338, 0.9402097703426187], 
             UndirectedEdge[326, 495] -> 
             RGBColor[
              0.8586889913459645, 0.42573762002087545`, 0.2028010830083056], 
             UndirectedEdge[36, 382] -> 
             RGBColor[
              0.26830699274776615`, 0.39933803939675394`, 0.9385910583611354],
              UndirectedEdge[31, 289] -> 
             RGBColor[
              0.4462046575439149, 0.5609017802915265, 0.9496527441087801], 
             UndirectedEdge[436, 487] -> 
             RGBColor[
              0.5261755956139467, 0.6262120783166807, 0.9558416168128965], 
             UndirectedEdge[251, 427] -> 
             RGBColor[
              0.2690226652198594, 0.4000902565411794, 0.9386318148496786], 
             UndirectedEdge[108, 437] -> 
             RGBColor[
              0.27047057871071917`, 0.40161210542309067`, 0.938714271380987], 
             UndirectedEdge[258, 397] -> 
             RGBColor[
              0.36598524788401654`, 0.49141975958888606`, 0.94454123426049], 
             UndirectedEdge[308, 422] -> 
             RGBColor[
              0.20647914454706495`, 0.3343530508258261, 0.9350700538722102], 
             UndirectedEdge[16, 292] -> 
             RGBColor[
              0.29142635679170903`, 0.41484197611023416`, 0.9402297358848033],
              UndirectedEdge[68, 317] -> 
             RGBColor[
              0.8516933912786147, 0.35903009244942585`, 0.19559553620276254`],
              UndirectedEdge[34, 468] -> 
             RGBColor[
              0.51106504599871, 0.6139446534165288, 0.9546520589954179], 
             UndirectedEdge[350, 383] -> 
             RGBColor[
              0.34555625661750283`, 0.4737251941447882, 0.9432395170016354], 
             UndirectedEdge[190, 342] -> 
             RGBColor[
              0.25404838087349885`, 0.38435133426869084`, 0.9377790515086218],
              UndirectedEdge[61, 303] -> 
             RGBColor[
              0.31454260624684305`, 0.4465402877003618, 0.9412751607792637], 
             UndirectedEdge[214, 421] -> 
             RGBColor[
              0.18943186031713002`, 0.3164352742399168, 0.9340992362545124], 
             UndirectedEdge[219, 370] -> 
             RGBColor[
              0.5588561185016121, 0.6527435990376659, 0.9584143472873132], 
             UndirectedEdge[91, 366] -> 
             RGBColor[
              0.29631757138809034`, 0.4270330853875859, 0.9402501434291768], 
             UndirectedEdge[273, 477] -> 
             RGBColor[
              0.2691065215645594, 0.4001783948762585, 0.9386365903444549], 
             UndirectedEdge[153, 323] -> 
             RGBColor[
              0.24213881509518778`, 0.3718336255256024, 0.9371008193561707], 
             UndirectedEdge[170, 433] -> 
             RGBColor[
              0.31109341012253816`, 0.4427596771133032, 0.9410844199719078], 
             UndirectedEdge[1, 54] -> 
             RGBColor[
              0.24744314331957223`, 0.3774088108032645, 0.937402893001499], 
             UndirectedEdge[277, 377] -> 
             RGBColor[
              0.8762033212681233, 0.9033473444415901, 0.9473540424354466], 
             UndirectedEdge[307, 417] -> 
             RGBColor[
              0.5854211152910297, 0.6734114544902967, 0.9611201594979415], 
             UndirectedEdge[58, 371] -> 
             RGBColor[
              0.3390278312734188, 0.4680706002399412, 0.9428235315115703], 
             UndirectedEdge[9, 269] -> 
             RGBColor[
              0.512041509774998, 0.614618499836106, 0.9547617797005311], 
             UndirectedEdge[184, 453] -> 
             RGBColor[
              0.2706693526642461, 0.401821029451244, 0.9387255912635806], 
             UndirectedEdge[42, 97] -> 
             RGBColor[
              0.23210438822814727`, 0.3612868066689332, 0.936529373590697], 
             UndirectedEdge[161, 405] -> 
             RGBColor[
              0.9921723207517021, 0.9843258130245969, 0.5033188163295588], 
             UndirectedEdge[304, 429] -> 
             RGBColor[
              0.316081007071654, 0.4467946753350308, 0.9414126607624902], 
             UndirectedEdge[127, 130] -> 
             RGBColor[
              0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993],
              UndirectedEdge[318, 330] -> 
             RGBColor[
              0.32419593809646025`, 0.45501163764918373`, 0.9418862305492528],
              UndirectedEdge[393, 468] -> 
             RGBColor[
              0.4697942541627981, 0.5804391653761509, 0.9514030710822032], 
             UndirectedEdge[334, 355] -> 
             RGBColor[
              0.36575544066311605`, 0.49122071212458884`, 0.9445265911475849],
              UndirectedEdge[290, 378] -> 
             RGBColor[
              0.28478483318943354`, 0.41665729445637256`, 0.939529446997508], 
             UndirectedEdge[92, 498] -> 
             RGBColor[
              0.5355135500520953, 0.6337930503996233, 0.9565767347923217], 
             UndirectedEdge[340, 362] -> 
             RGBColor[
              0.3629480512357022, 0.4887890925060583, 0.944347706775747], 
             UndirectedEdge[58, 304] -> 
             RGBColor[
              0.3268378953241502, 0.4575122904046801, 0.94204679957202], 
             UndirectedEdge[51, 308] -> 
             RGBColor[
              0.1789366427891193, 0.3054041351827525, 0.9335015491425751], 
             UndirectedEdge[59, 447] -> 
             RGBColor[
              0.2443455259866942, 0.3741530185861272, 0.9372264882769058], 
             UndirectedEdge[186, 485] -> 
             RGBColor[
              0.24185580045044375`, 0.3715361591898116, 0.9370847020908353], 
             UndirectedEdge[340, 379] -> 
             RGBColor[
              0.32336688058112073`, 0.45450587189254155`, 0.941825629581892], 
             UndirectedEdge[129, 410] -> 
             RGBColor[
              0.3596323931506261, 0.48591723612258636`, 0.9441364359744873], 
             UndirectedEdge[192, 225] -> 
             RGBColor[
              0.26443196618769516`, 0.395265140791245, 0.9383703813311275], 
             UndirectedEdge[306, 420] -> 
             RGBColor[
              0.9131111718754747, 0.7098607039273219, 0.5703676016486996], 
             UndirectedEdge[16, 45] -> 
             RGBColor[
              0.343332276555383, 0.46939838880724916`, 0.9431857012274175], 
             UndirectedEdge[334, 361] -> 
             RGBColor[
              0.5235027630627838, 0.6226423570970218, 0.9560294677740079], 
             UndirectedEdge[306, 357] -> 
             RGBColor[
              0.8823608988640697, 0.5565720408834082, 0.22345710970379568`], 
             UndirectedEdge[335, 496] -> 
             RGBColor[
              0.27683085763382376`, 0.40829716183624876`, 0.9390764798564684],
              UndirectedEdge[176, 345] -> 
             RGBColor[
              0.6333349002315553, 0.7129428013259062, 0.9644594745728776], 
             UndirectedEdge[15, 78] -> 
             RGBColor[
              0.22683394628673456`, 0.35574723802318886`, 0.9362292297190538],
              UndirectedEdge[52, 210] -> 
             RGBColor[
              0.8359293793650189, 0.2771745309197725, 0.1820393202973592], 
             UndirectedEdge[392, 465] -> 
             RGBColor[
              0.2943134873153461, 0.42667251409427237`, 0.9400720897535981], 
             UndirectedEdge[354, 414] -> 
             RGBColor[
              0.3182109057650159, 0.4468883541768137, 0.941612493557471], 
             UndirectedEdge[56, 428] -> 
             RGBColor[
              0.8335035522712653, 0.25852856087297227`, 0.179716345532801], 
             UndirectedEdge[44, 425] -> 
             RGBColor[
              0.43601004951768985`, 0.5508944179345684, 0.9493284456568833], 
             UndirectedEdge[106, 468] -> 
             RGBColor[
              0.4981161809408796, 0.6034321814228589, 0.9536326769048099], 
             UndirectedEdge[142, 461] -> 
             RGBColor[
              0.8219899053555546, 0.8616442791794481, 0.9747961115925544], 
             UndirectedEdge[203, 297] -> 
             RGBColor[
              0.5269654224863035, 0.6268532953529551, 0.9559037948775195], 
             UndirectedEdge[24, 176] -> 
             RGBColor[
              0.7219583100603643, 0.7823133904412213, 0.9732561905650118], 
             UndirectedEdge[351, 356] -> 
             RGBColor[
              0.2796916905937343, 0.4113040786644009, 0.9392394000613121], 
             UndirectedEdge[315, 368] -> 
             RGBColor[
              0.2968006331253079, 0.42010055334026064`, 0.9405500774666419], 
             UndirectedEdge[278, 406] -> 
             RGBColor[
              0.969491060817788, 0.9705130400681918, 0.6951727540379807], 
             UndirectedEdge[247, 360] -> 
             RGBColor[
              0.5371888520305683, 0.6351531360172418, 0.9567086207009003], 
             UndirectedEdge[78, 145] -> 
             RGBColor[
              0.22004363289237822`, 0.3486101881149849, 0.9358425314166136], 
             UndirectedEdge[19, 466] -> 
             RGBColor[
              0.5316163498821903, 0.6306291277348275, 0.9562699329190321], 
             UndirectedEdge[60, 151] -> 
             RGBColor[
              0.2997519610227203, 0.4323886947798715, 0.9403818027857322], 
             UndirectedEdge[109, 186] -> 
             RGBColor[
              0.24483520726957755`, 0.37466770466202415`, 0.9372543749015474],
              UndirectedEdge[474, 495] -> 
             RGBColor[
              0.917649812825669, 0.658402887580602, 0.4760539940908434], 
             UndirectedEdge[36, 412] -> 
             RGBColor[
              0.24838538806776134`, 0.3783991697753788, 0.9374565524459821], 
             UndirectedEdge[259, 469] -> 
             RGBColor[
              0.8611356885897954, 0.46233141911773723`, 0.2058405534946276], 
             UndirectedEdge[6, 80] -> 
             RGBColor[
              0.8086163665159423, 0.8504788015959455, 0.9815424524658205], 
             UndirectedEdge[287, 389] -> 
             RGBColor[
              0.214155749354975, 0.34242164920379625`, 0.9355072251595016], 
             UndirectedEdge[158, 410] -> 
             RGBColor[
              0.3605931713874897, 0.48674941394123933`, 0.9441976559141574], 
             UndirectedEdge[414, 415] -> 
             RGBColor[
              0.2808353270487499, 0.4125061130893616, 0.9393045284655668], 
             UndirectedEdge[10, 245] -> 
             RGBColor[
              0.22026264269435236`, 0.3488403813028832, 0.93585500370084], 
             UndirectedEdge[115, 178] -> 
             RGBColor[
              0.9564265081535962, 0.965404037867567, 0.8899068420398936], 
             UndirectedEdge[88, 348] -> 
             RGBColor[
              0.9132608681622556, 0.6818120756635188, 0.2545865809359151], 
             UndirectedEdge[135, 170] -> 
             RGBColor[
              0.2736536686143132, 0.40495773473132446`, 0.9388955436420372], 
             UndirectedEdge[3, 203] -> 
             RGBColor[
              0.49811633466717364`, 0.6034323062247897, 0.9536326890067068], 
             UndirectedEdge[84, 374] -> 
             RGBColor[
              0.24252230770556474`, 0.3722367005739444, 0.9371226586930053], 
             UndirectedEdge[29, 172] -> 
             RGBColor[
              0.3806363827099919, 0.5041098361876981, 0.9454747916161113], 
             UndirectedEdge[262, 387] -> 
             RGBColor[
              0.6255998101870561, 0.7048955003973141, 0.9650590620780228], 
             UndirectedEdge[179, 276] -> 
             RGBColor[
              0.39923464670294595`, 0.5037029404652202, 0.9483463693708659], 
             UndirectedEdge[348, 428] -> 
             RGBColor[
              0.8951225528654855, 0.5552983535621828, 0.23772264959288408`], 
             UndirectedEdge[104, 351] -> 
             RGBColor[
              0.2683095588486911, 0.39934073653152624`, 0.9385912044967868], 
             UndirectedEdge[111, 271] -> 
             RGBColor[
              0.2644482810539334, 0.39528228875008364`, 0.938371310438624], 
             UndirectedEdge[136, 277] -> 
             RGBColor[
              0.8701310969045036, 0.8988186894535575, 0.9576327343932979], 
             UndirectedEdge[246, 442] -> 
             RGBColor[
              0.28908336711974203`, 0.42117532615991926`, 0.939774242145728], 
             UndirectedEdge[206, 266] -> 
             RGBColor[
              0.31612745049209645`, 0.4464579350707817, 0.9414294227127427], 
             UndirectedEdge[31, 381] -> 
             RGBColor[
              0.5111715324361403, 0.6140235083829432, 0.9546625406628318], 
             UndirectedEdge[31, 472] -> 
             RGBColor[
              0.39074248974700837`, 0.5128632381554529, 0.9461187438200305], 
             UndirectedEdge[342, 453] -> 
             RGBColor[
              0.27214698791275327`, 0.40337411778491095`, 0.9388097404050177],
              UndirectedEdge[200, 475] -> 
             RGBColor[
              0.8699156991968737, 0.47168384997259694`, 0.2119718972840306], 
             UndirectedEdge[92, 101] -> 
             RGBColor[
              0.5649851581111299, 0.6577194295027604, 0.9588968477367864], 
             UndirectedEdge[193, 376] -> 
             RGBColor[
              0.2836334092052663, 0.4154470748445156, 0.9394638751049887], 
             UndirectedEdge[253, 319] -> 
             RGBColor[
              0.8499607656875054, 0.8826374101392084, 0.934970872933598], 
             UndirectedEdge[249, 280] -> 
             RGBColor[
              0.27322012310800536`, 0.4045020509158221, 0.938870853866826], 
             UndirectedEdge[153, 195] -> 
             RGBColor[
              0.2575424446398453, 0.3880238168235591, 0.9379780332711112], 
             UndirectedEdge[313, 380] -> 
             RGBColor[
              0.26990447818225494`, 0.4010170978748282, 0.9386820327933616], 
             UndirectedEdge[178, 357] -> 
             RGBColor[
              0.9494134599221778, 0.8301932628763469, 0.5158066666080678], 
             UndirectedEdge[163, 494] -> 
             RGBColor[
              0.262747921993954, 0.39349510356905415`, 0.938274477505614], 
             UndirectedEdge[24, 237] -> 
             RGBColor[
              0.871532203465174, 0.9004001382044219, 0.9876087136641327], 
             UndirectedEdge[101, 345] -> 
             RGBColor[
              0.5902789610650883, 0.677988050262613, 0.9610699533225915], 
             UndirectedEdge[320, 361] -> 
             RGBColor[
              0.8164019725999951, 0.8557645940777792, 0.9018606390244552], 
             UndirectedEdge[328, 487] -> 
             RGBColor[
              0.4823721914903405, 0.5888040064890694, 0.952903444464096], 
             UndirectedEdge[322, 494] -> 
             RGBColor[
              0.2588610411681461, 0.3894097453786518, 0.9380531253927091], 
             UndirectedEdge[108, 266] -> 
             RGBColor[
              0.28731571918259713`, 0.4193174161026276, 0.9396735772107083], 
             UndirectedEdge[405, 474] -> 
             RGBColor[
              0.9935549188322322, 0.9905077851325332, 0.6768786341569868], 
             UndirectedEdge[338, 379] -> 
             RGBColor[
              0.31470226354501973`, 0.4470010161121858, 0.9412735278461717], 
             UndirectedEdge[175, 309] -> 
             RGBColor[
              0.9743805147039586, 0.9770030600582216, 0.7213206267986814], 
             UndirectedEdge[294, 430] -> 
             RGBColor[
              0.23902588418057213`, 0.36856173776312173`, 0.9369235425457519],
              UndirectedEdge[197, 237] -> 
             RGBColor[
              0.8018590077882369, 0.845833600411511, 0.9807007779188375], 
             UndirectedEdge[94, 500] -> 
             RGBColor[
              0.8874558706447166, 0.5585534617562613, 0.5633237757723539], 
             UndirectedEdge[242, 365] -> 
             RGBColor[
              0.22099114578241763`, 0.3496060842382034, 0.9358964908739815], 
             UndirectedEdge[401, 500] -> 
             RGBColor[
              0.7964725199858478, 0.48689043193741693`, 0.5721768321079614], 
             UndirectedEdge[334, 340] -> 
             RGBColor[
              0.37011932022613914`, 0.4950004852671151, 0.9448046536945134], 
             UndirectedEdge[60, 310] -> 
             RGBColor[
              0.2947333345295756, 0.4271138001362785, 0.9400959994313403], 
             UndirectedEdge[50, 379] -> 
             RGBColor[
              0.37511861305326666`, 0.49933062144220947`, 0.9451232042127569],
              UndirectedEdge[123, 177] -> 
             RGBColor[
              0.2078300375710318, 0.33577292504558, 0.935146985231458], 
             UndirectedEdge[231, 246] -> 
             RGBColor[
              0.27633388437422024`, 0.407774811430481, 0.93904817796454], 
             UndirectedEdge[182, 282] -> 
             RGBColor[
              0.4931225250647846, 0.5973489755441486, 0.9538002129842165], 
             UndirectedEdge[185, 193] -> 
             RGBColor[
              0.28587823371129695`, 0.41780652773044813`, 0.9395917145396869],
              UndirectedEdge[395, 447] -> 
             RGBColor[
              0.2557437599820415, 0.3861332852050131, 0.9378756008407647], 
             UndirectedEdge[22, 282] -> 
             RGBColor[
              0.5295374583805197, 0.6288897605144723, 0.956120540334634], 
             UndirectedEdge[195, 323] -> 
             RGBColor[
              0.2547482956718921, 0.38508698909896344`, 0.9378189106209592], 
             UndirectedEdge[99, 486] -> 
             RGBColor[
              0.9642745659488295, 0.9698576677518461, 0.7703884518083142], 
             UndirectedEdge[454, 469] -> 
             RGBColor[
              0.8801565520867384, 0.5487007178218191, 0.22171202824050545`], 
             UndirectedEdge[31, 208] -> 
             RGBColor[
              0.38757839390763205`, 0.5101226573714661, 0.9459171304310454], 
             UndirectedEdge[398, 472] -> 
             RGBColor[
              0.2947988861662292, 0.4253612331985043, 0.9401664252880289], 
             UndirectedEdge[191, 389] -> 
             RGBColor[
              0.21845058194335062`, 0.3469357905622929, 0.9357518095217741], 
             UndirectedEdge[133, 151] -> 
             RGBColor[
              0.3259839947322987, 0.4565922388339624, 0.9419989967859217], 
             UndirectedEdge[165, 268] -> 
             RGBColor[
              0.4168440173490807, 0.5354710694634455, 0.9477819100781599], 
             UndirectedEdge[166, 495] -> 
             RGBColor[
              0.8401614416386582, 0.3097040160564781, 0.18609194791002698`], 
             UndirectedEdge[346, 430] -> 
             RGBColor[
              0.22881084125106885`, 0.35782507997308444`, 0.9363418109627185],
              UndirectedEdge[169, 219] -> 
             RGBColor[
              0.5095055418565787, 0.6126785776990856, 0.9545292891166974], 
             UndirectedEdge[197, 345] -> 
             RGBColor[
              0.6786754086563489, 0.7489056544572683, 0.9686076802187304], 
             UndirectedEdge[100, 213] -> 
             RGBColor[
              0.9177103751290299, 0.7114500107948662, 0.2526457256885956], 
             UndirectedEdge[73, 187] -> 
             RGBColor[
              0.25626928229983936`, 0.38668564248105813`, 0.9379055285593227],
              UndirectedEdge[97, 346] -> 
             RGBColor[
              0.22480858213955662`, 0.353618451889001, 0.9361138882271296], 
             UndirectedEdge[129, 170] -> 
             RGBColor[
              0.3261401713486173, 0.4557924254151241, 0.9420431862919051], 
             UndirectedEdge[36, 37] -> 
             RGBColor[
              0.2800147441029785, 0.41164362838539204`, 0.9392577974807488], 
             UndirectedEdge[143, 302] -> 
             RGBColor[
              0.1845381798446758, 0.31129170578610466`, 0.9338205483911577], 
             UndirectedEdge[16, 236] -> 
             RGBColor[
              0.34560261915581325`, 0.4717846628283363, 0.9433149938798411], 
             UndirectedEdge[187, 322] -> 
             RGBColor[
              0.2619233226556958, 0.392628397381927, 0.9382275177931856], 
             UndirectedEdge[108, 163] -> 
             RGBColor[
              0.27605150294224795`, 0.40747801064146116`, 0.939032096759735], 
             UndirectedEdge[137, 346] -> 
             RGBColor[
              0.21898159921391522`, 0.34749392338209584`, 0.9357820501697631],
              UndirectedEdge[243, 276] -> 
             RGBColor[
              0.7294231328480298, 0.5025695960181678, 0.5742322488928711], 
             UndirectedEdge[131, 147] -> 
             RGBColor[
              0.257551109678863, 0.38803292432896186`, 0.9379785267322645], 
             UndirectedEdge[9, 468] -> 
             RGBColor[
              0.5267603512092651, 0.6266868092518996, 0.9558876509153902], 
             UndirectedEdge[331, 377] -> 
             RGBColor[
              0.9088984029132244, 0.9290240327940705, 0.9505769466051841], 
             UndirectedEdge[280, 470] -> 
             RGBColor[
              0.25618724239569113`, 0.386599413340168, 0.9379008565081486], 
             UndirectedEdge[234, 468] -> 
             RGBColor[
              0.4334778335161593, 0.5491980337433716, 0.9490298017896481], 
             UndirectedEdge[136, 488] -> 
             RGBColor[
              0.8691624812525807, 0.8980619995445237, 0.9575361918373422], 
             UndirectedEdge[57, 361] -> 
             RGBColor[
              0.622722217665552, 0.7045647515271736, 0.9634614174292722], 
             UndirectedEdge[196, 414] -> 
             RGBColor[
              0.2851786513362504, 0.4170712222981897, 0.9395518743583675], 
             UndirectedEdge[103, 319] -> 
             RGBColor[
              0.5976226950866923, 0.6831049747415705, 0.9622258440138658], 
             UndirectedEdge[224, 263] -> 
             RGBColor[
              0.2861834719747001, 0.4181273524985085, 0.9396090974072282], 
             UndirectedEdge[89, 184] -> 
             RGBColor[
              0.271266794829508, 0.4024489790469554, 0.9387596147110557], 
             UndirectedEdge[137, 407] -> 
             RGBColor[
              0.2172194419002935, 0.34564178431825265`, 0.9356816979176306], 
             UndirectedEdge[53, 272] -> 
             RGBColor[
              0.8985476192245749, 0.5458238236085153, 0.2652993601444404], 
             UndirectedEdge[236, 243] -> 
             RGBColor[
              0.5633146331293595, 0.36122739545781846`, 0.562473440762307], 
             UndirectedEdge[26, 351] -> 
             RGBColor[
              0.3383374936256977, 0.4657436708748698, 0.9428428507321864], 
             UndirectedEdge[67, 96] -> 
             RGBColor[
              0.2763924027630132, 0.4078363179673825, 0.9390515105002115], 
             UndirectedEdge[284, 464] -> 
             RGBColor[
              0.24447969866104266`, 0.37429404257390636`, 0.9372341292122193],
              UndirectedEdge[325, 401] -> 
             RGBColor[
              0.4762346490241563, 0.5642173274993956, 0.9557801417908952], 
             UndirectedEdge[227, 348] -> 
             RGBColor[
              0.9027713884189711, 0.6140906553673846, 0.24504718315702606`], 
             UndirectedEdge[106, 117] -> 
             RGBColor[
              0.44946530583261596`, 0.561973649912251, 0.9503446865091629], 
             UndirectedEdge[395, 440] -> 
             RGBColor[
              0.2733307058970075, 0.4046182804384171, 0.9388771513930672], 
             UndirectedEdge[204, 361] -> 
             RGBColor[
              0.5730472494558454, 0.6642363745027182, 0.9595508219663998], 
             UndirectedEdge[195, 263] -> 
             RGBColor[
              0.27177628853634817`, 0.40298448923661123`, 0.9387886296239321],
              UndirectedEdge[360, 393] -> 
             RGBColor[
              0.5202889035975207, 0.6214329965452928, 0.9553781948537], 
             UndirectedEdge[74, 440] -> 
             RGBColor[
              0.2817039259800564, 0.4134190656385177, 0.9393539938897277], 
             UndirectedEdge[166, 348] -> 
             RGBColor[
              0.8990160108059699, 0.5852251774168952, 0.24145102931372386`], 
             UndirectedEdge[209, 477] -> 
             RGBColor[
              0.40529759982577535`, 0.5164885241169046, 0.9481078912022864], 
             UndirectedEdge[292, 422] -> 
             RGBColor[
              0.20649131825242792`, 0.3343658461620201, 0.9350707471467212], 
             UndirectedEdge[36, 416] -> 
             RGBColor[
              0.2579614870777197, 0.3884642569945902, 0.9380018971180304], 
             UndirectedEdge[306, 418] -> 
             RGBColor[
              0.9180265023958543, 0.7135265493813059, 0.5620472292012149], 
             UndirectedEdge[363, 498] -> 
             RGBColor[
              0.433350434496959, 0.5495353617267253, 0.948897990208064], 
             UndirectedEdge[57, 466] -> 
             RGBColor[
              0.552375580457491, 0.6474824063085367, 0.957904175593487], 
             UndirectedEdge[263, 395] -> 
             RGBColor[
              0.2691941123375187, 0.40027045833221453`, 0.938641578509396], 
             UndirectedEdge[171, 238] -> 
             RGBColor[
              0.2909480728266918, 0.4220805098947036, 0.9399190535823698], 
             UndirectedEdge[42, 286] -> 
             RGBColor[
              0.2277872668823118, 0.3567492384131574, 0.9362835199166604], 
             UndirectedEdge[246, 444] -> 
             RGBColor[
              0.2827572278979614, 0.41452615273743476`, 0.9394139778757318], 
             UndirectedEdge[46, 306] -> 
             RGBColor[
              0.8876171805650555, 0.5774114462757728, 0.22768643734119767`], 
             UndirectedEdge[229, 411] -> 
             RGBColor[
              0.26528288174741516`, 0.39615950699567326`, 0.9384188397134368],
              UndirectedEdge[239, 440] -> 
             RGBColor[
              0.3163021777955242, 0.4458837751629835, 0.9414671202878849], 
             UndirectedEdge[57, 106] -> 
             RGBColor[
              0.5595491629932491, 0.6533062437772754, 0.9584689062884005], 
             UndirectedEdge[60, 280] -> 
             RGBColor[
              0.2748009878347767, 0.4061636399762716, 0.9389608817743358], 
             UndirectedEdge[438, 457] -> 
             RGBColor[
              0.22152681415849518`, 0.35016910566479753`, 0.9359269963955489],
              UndirectedEdge[130, 368] -> 
             RGBColor[
              0.2935143249909316, 0.4166464351270609, 0.9403629270800464], 
             UndirectedEdge[152, 287] -> 
             RGBColor[
              0.20690732578417442`, 0.33480309645428663`, 0.9350944381602262],
              UndirectedEdge[54, 242] -> 
             RGBColor[
              0.22686421194138368`, 0.35577904914517844`, 0.936230953303312], 
             UndirectedEdge[89, 235] -> 
             RGBColor[
              0.32127172035398965`, 0.45054205661512126`, 0.9417708166396943],
              UndirectedEdge[60, 260] -> 
             RGBColor[
              0.2891430137819674, 0.4212380185837349, 0.9397776389349024], 
             UndirectedEdge[88, 243] -> 
             RGBColor[
              0.8529581179820884, 0.3951595604413297, 0.19784071975882145`], 
             UndirectedEdge[36, 367] -> 
             RGBColor[
              0.2421171751521342, 0.3718108805734015, 0.9370995869934273], 
             UndirectedEdge[17, 282] -> 
             RGBColor[
              0.7438148228852721, 0.7997463454963281, 0.9753349394405884], 
             UndirectedEdge[150, 233] -> 
             RGBColor[
              0.832302226448087, 0.24929464417169217`, 0.1785659545678221], 
             UndirectedEdge[250, 365] -> 
             RGBColor[
              0.21070999979849359`, 0.338799947946794, 0.9353109948197895], 
             UndirectedEdge[107, 423] -> 
             RGBColor[
              0.18624879198055028`, 0.31308966759998247`, 0.9339179652216718],
              UndirectedEdge[315, 347] -> 
             RGBColor[
              0.1822133081343763, 0.30884811821319974`, 0.9336881503865955], 
             UndirectedEdge[288, 492] -> 
             RGBColor[
              0.26634261157442907`, 0.39727335023461663`, 0.9384791897593554],
              UndirectedEdge[24, 267] -> 
             RGBColor[
              0.9130173103236416, 0.9238052630986108, 0.6981615264074577], 
             UndirectedEdge[198, 480] -> 
             RGBColor[
              0.3177133386514768, 0.44712506118461215`, 0.9415563421819749], 
             UndirectedEdge[4, 479] -> 
             RGBColor[
              0.3678971603336924, 0.49307576205728143`, 0.9446630596311456], 
             UndirectedEdge[133, 239] -> 
             RGBColor[
              0.34805209112246643`, 0.47588696054869806`, 0.943398549369312], 
             UndirectedEdge[115, 253] -> 
             RGBColor[
              0.9531001134456565, 0.9640284881713892, 0.9450338107840079], 
             UndirectedEdge[199, 371] -> 
             RGBColor[
              0.3528938984406201, 0.480080690691371, 0.9437070650501826], 
             UndirectedEdge[93, 189] -> 
             RGBColor[
              0.26453032177670965`, 0.3953685187514038, 0.9383759825364177], 
             UndirectedEdge[357, 418] -> 
             RGBColor[
              0.9428078871600445, 0.8265116366232681, 0.582732825135219], 
             UndirectedEdge[82, 463] -> 
             RGBColor[
              0.26268799213192734`, 0.3934321134842913, 0.9382710645886299], 
             UndirectedEdge[102, 350] -> 
             RGBColor[
              0.3193537748201921, 0.44805203074969097`, 0.941678953195245], 
             UndirectedEdge[235, 296] -> 
             RGBColor[
              0.3352307721420522, 0.4647817784660925, 0.9425815862613272], 
             UndirectedEdge[26, 360] -> 
             RGBColor[
              0.48299792974153133`, 0.5893477559050426, 0.9529428278924086], 
             UndirectedEdge[309, 320] -> 
             RGBColor[
              0.9908166313021023, 0.9885283450055495, 0.6606847997028811], 
             UndirectedEdge[13, 229] -> 
             RGBColor[
              0.2937960299949141, 0.4261286336418093, 0.9400426213247091], 
             UndirectedEdge[353, 420] -> 
             RGBColor[
              0.8041526849608935, 0.8472401733654197, 0.9513697071701304], 
             UndirectedEdge[171, 465] -> 
             RGBColor[
              0.27218390368581785`, 0.4034129186029971, 0.9388118427036817], 
             UndirectedEdge[104, 224] -> 
             RGBColor[
              0.2727699797429894, 0.40402892169845256`, 0.9388452188681158], 
             UndirectedEdge[22, 285] -> 
             RGBColor[
              0.38291743430858444`, 0.506085568433412, 0.9456201382069189], 
             UndirectedEdge[126, 285] -> 
             RGBColor[
              0.28277807837083513`, 0.4140236211798849, 0.9394343678430408], 
             UndirectedEdge[98, 319] -> 
             RGBColor[
              0.8550622111994015, 0.8847062165139711, 0.8474629923061501], 
             UndirectedEdge[286, 411] -> 
             RGBColor[
              0.2313451146629863, 0.3604887620112245, 0.9364861340844057], 
             UndirectedEdge[259, 491] -> 
             RGBColor[
              0.9280010655847133, 0.727726462964249, 0.4061574584267472], 
             UndirectedEdge[1, 266] -> 
             RGBColor[
              0.27784311638010406`, 0.40936110995950087`, 0.9391341264945663],
              UndirectedEdge[67, 216] -> 
             RGBColor[
              0.26125452628926693`, 0.3919254499966715, 0.938189430829513], 
             UndirectedEdge[41, 451] -> 
             RGBColor[
              0.22198624668627384`, 0.3506519983811976, 0.9359531603983363], 
             UndirectedEdge[300, 456] -> 
             RGBColor[
              0.22480808787876505`, 0.3536179323895711, 0.9361138600797088], 
             UndirectedEdge[117, 139] -> 
             RGBColor[
              0.47255522666265165`, 0.5807190878311534, 0.9521624096580703], 
             UndirectedEdge[70, 96] -> 
             RGBColor[
              0.2772059489257, 0.4086914065661722, 0.9390978407506428], 
             UndirectedEdge[92, 274] -> 
             RGBColor[
              0.5359359247795917, 0.6341359532311694, 0.9566099856780799], 
             UndirectedEdge[241, 436] -> 
             RGBColor[
              0.5892009770363313, 0.6764119562142918, 0.9614643256448061], 
             UndirectedEdge[207, 295] -> 
             RGBColor[
              0.22332543873759936`, 0.352059574136821, 0.9360294254045023], 
             UndirectedEdge[83, 176] -> 
             RGBColor[
              0.7638451540938651, 0.8157128228854424, 0.9772513951417543], 
             UndirectedEdge[56, 495] -> 
             RGBColor[
              0.839438039950976, 0.30414363368831143`, 0.18539921763693712`], 
             UndirectedEdge[219, 334] -> 
             RGBColor[
              0.4645364889888964, 0.5747991033502236, 0.9513681298117886], 
             UndirectedEdge[124, 357] -> 
             RGBColor[
              0.9348974167088442, 0.7776187751730486, 0.27677767167712564`], 
             UndirectedEdge[40, 291] -> 
             RGBColor[
              0.5205636488996574, 0.6196411124817705, 0.9560349926032045], 
             UndirectedEdge[7, 487] -> 
             RGBColor[
              0.7090567422484308, 0.7718269420846646, 0.9722547745917934], 
             UndirectedEdge[423, 477] -> 
             RGBColor[
              0.21624875945532895`, 0.3446215355237733, 0.9356264189883857], 
             UndirectedEdge[22, 165] -> 
             RGBColor[
              0.4377248912958056, 0.5535570329728583, 0.9491124209018134], 
             UndirectedEdge[302, 368] -> 
             RGBColor[
              0.2991255041617159, 0.42254414020486286`, 0.9406824754328269], 
             UndirectedEdge[297, 419] -> 
             RGBColor[
              0.5160273723962365, 0.6179732935362974, 0.9550427115070317], 
             UndirectedEdge[263, 463] -> 
             RGBColor[
              0.2702490064672201, 0.4013792189466815, 0.9387016531695065], 
             UndirectedEdge[260, 424] -> 
             RGBColor[
              0.3030854306847971, 0.434796914253921, 0.9406117494194473], 
             UndirectedEdge[193, 415] -> 
             RGBColor[
              0.28741220208324925`, 0.41941882574858214`, 0.9396790717691668],
              UndirectedEdge[434, 474] -> 
             RGBColor[
              0.992149866333044, 0.99102178223655, 0.7797605605635565], 
             UndirectedEdge[102, 109] -> 
             RGBColor[
              0.265248780611274, 0.396123664539452, 0.9384168977041816], 
             UndirectedEdge[58, 118] -> 
             RGBColor[
              0.3201099243225116, 0.4516848600807156, 0.9416180992091068], 
             UndirectedEdge[39, 100] -> 
             RGBColor[
              0.7774382200691679, 0.7351762203070193, 0.6135140654406412], 
             UndirectedEdge[35, 216] -> 
             RGBColor[
              0.25212920477180323`, 0.3823341585030158, 0.9376697572687969], 
             UndirectedEdge[72, 163] -> 
             RGBColor[
              0.26048838412385666`, 0.3911201860046064, 0.9381458001665987], 
             UndirectedEdge[202, 414] -> 
             RGBColor[
              0.25685751416132785`, 0.38730391146353665`, 0.9379390274936235],
              UndirectedEdge[324, 441] -> 
             RGBColor[
              0.4099049258998564, 0.5294607772190044, 0.947339757307013], 
             UndirectedEdge[18, 52] -> 
             RGBColor[
              0.8600894824934477, 0.42201909265360843`, 0.20357506457964797`],
              UndirectedEdge[168, 368] -> 
             RGBColor[
              0.6594469349895435, 0.6059633899066202, 0.5971521921376893], 
             UndirectedEdge[208, 397] -> 
             RGBColor[
              0.3403332891441403, 0.46920132223333977`, 0.9429067141327215], 
             UndirectedEdge[193, 350] -> 
             RGBColor[
              0.3249908553866274, 0.4539769598365655, 0.94199997659419], 
             UndirectedEdge[2, 365] -> 
             RGBColor[
              0.21471117528305686`, 0.3430054370702481, 0.9355388558444269], 
             UndirectedEdge[42, 248] -> 
             RGBColor[
              0.2375069627028864, 0.3669652549848901, 0.9368370422146407], 
             UndirectedEdge[46, 68] -> 
             RGBColor[
              0.8688206529626022, 0.4329330984324026, 0.20968686128144703`], 
             UndirectedEdge[260, 470] -> 
             RGBColor[
              0.2705292683428818, 0.4016737919476313, 0.9387176136687151], 
             UndirectedEdge[32, 344] -> 
             RGBColor[
              0.49972685632516956`, 0.6047398002599247, 0.9537594751711596], 
             UndirectedEdge[60, 483] -> 
             RGBColor[
              0.29467938491288026`, 0.4270570956685284, 0.9400929270804808], 
             UndirectedEdge[337, 498] -> 
             RGBColor[
              0.6610501058244442, 0.7326972089760198, 0.9686548196773171], 
             UndirectedEdge[86, 168] -> 
             RGBColor[
              0.912992655814064, 0.6927519043211215, 0.24885005242438252`], 
             UndirectedEdge[151, 424] -> 
             RGBColor[
              0.31369437792555, 0.4459475904500576, 0.9412159132702771], 
             UndirectedEdge[234, 296] -> 
             RGBColor[
              0.3509992318996893, 0.478439625762326, 0.9435863385735823], 
             UndirectedEdge[223, 268] -> 
             RGBColor[
              0.3997592820050565, 0.5206731304122181, 0.946693285849477], 
             UndirectedEdge[50, 204] -> 
             RGBColor[
              0.47141553909134676`, 0.5814192522224795, 0.9516235825177704], 
             UndirectedEdge[26, 247] -> 
             RGBColor[
              0.44082045923577545`, 0.5551061852750767, 0.9496224629130303], 
             UndirectedEdge[64, 435] -> 
             RGBColor[
              0.2729760661843835, 0.4042455316149929, 0.9388569551860756], 
             UndirectedEdge[143, 214] -> 
             RGBColor[
              0.18936705810043614`, 0.31636716300147366`, 0.934095545864138], 
             UndirectedEdge[38, 266] -> 
             RGBColor[
              0.27474470932625494`, 0.40610448769555174`, 0.9389576767965321],
              UndirectedEdge[309, 375] -> 
             RGBColor[
              0.9756161016685031, 0.977924558793291, 0.7192291003603996], 
             UndirectedEdge[70, 385] -> 
             RGBColor[
              0.24586087527331454`, 0.37574574676505923`, 0.9373127851770204],
              UndirectedEdge[232, 354] -> 
             RGBColor[
              0.35898073503518557`, 0.48535280261628094`, 0.94409491289561], 
             UndirectedEdge[86, 484] -> 
             RGBColor[
              0.9540423951293819, 0.8443401430723285, 0.3591520108030784], 
             UndirectedEdge[106, 360] -> 
             RGBColor[
              0.5486108303756021, 0.6444260125920007, 0.9576078006763067], 
             UndirectedEdge[163, 322] -> 
             RGBColor[
              0.26310542995763675`, 0.3938708671061988, 0.9382948370552601], 
             UndirectedEdge[44, 117] -> 
             RGBColor[
              0.4388762614701655, 0.5533769866678013, 0.9495110781480034], 
             UndirectedEdge[113, 273] -> 
             RGBColor[
              0.23636683819300525`, 0.3657669118369359, 0.936772113810466], 
             UndirectedEdge[53, 298] -> 
             RGBColor[
              0.9390760601522875, 0.9284198827471832, 0.6768677898959217], 
             UndirectedEdge[50, 369] -> 
             RGBColor[
              0.43044272533776096`, 0.5472495868323034, 0.9486484077263333], 
             UndirectedEdge[135, 385] -> 
             RGBColor[
              0.24204917775156742`, 0.37173941099412156`, 0.9370957146420581],
              UndirectedEdge[376, 464] -> 
             RGBColor[
              0.2616609318454717, 0.3923526080038432, 0.9382125750247157], 
             UndirectedEdge[95, 408] -> 
             RGBColor[
              0.22479372667970515`, 0.35360283785880653`, 0.9361130422306678],
              UndirectedEdge[34, 332] -> 
             RGBColor[
              0.47297256082386624`, 0.5816312685861409, 0.9520368398699108], 
             UndirectedEdge[251, 416] -> 
             RGBColor[
              0.26003944376158217`, 0.39064832121939286`, 0.9381202336771148],
              UndirectedEdge[62, 209] -> 
             RGBColor[
              0.6916212861064526, 0.39630413817282756`, 0.5615943615662011], 
             UndirectedEdge[109, 496] -> 
             RGBColor[
              0.26542477376877, 0.3963086445065909, 0.9384269202541424], 
             UndirectedEdge[179, 254] -> 
             RGBColor[
              0.20771369325605188`, 0.33565063979388043`, 0.9351403595948358],
              UndirectedEdge[27, 199] -> 
             RGBColor[
              0.4274813973658525, 0.5430880506381621, 0.9489008550961784], 
             UndirectedEdge[59, 453] -> 
             RGBColor[
              0.26324896867774317`, 0.3940217354019111, 0.9383030113730237], 
             UndirectedEdge[450, 475] -> 
             RGBColor[
              0.8283559372455574, 0.2189617360860943, 0.17478698357078354`], 
             UndirectedEdge[311, 331] -> 
             RGBColor[
              0.7917742816822333, 0.837394395727864, 0.9798444828971542], 
             UndirectedEdge[329, 486] -> 
             RGBColor[
              0.9087427412464592, 0.930070810978078, 0.9911578879759511], 
             UndirectedEdge[287, 456] -> 
             RGBColor[
              0.21673512234064032`, 0.34513273375342357`, 0.9356541166351948],
              UndirectedEdge[60, 118] -> 
             RGBColor[
              0.30890885152103453`, 0.4405003788871604, 0.9409586647466246], 
             UndirectedEdge[267, 493] -> 
             RGBColor[
              0.991319933690298, 0.9817192401312839, 0.4771566948770857], 
             UndirectedEdge[239, 263] -> 
             RGBColor[
              0.31216558423603546`, 0.4415359530567809, 0.9412315474042139], 
             UndirectedEdge[64, 91] -> 
             RGBColor[
              0.3077316474117898, 0.43903000298271255`, 0.9409001581731142], 
             UndirectedEdge[469, 471] -> 
             RGBColor[
              0.8586216305057723, 0.4484110579890054, 0.20364468753654688`], 
             UndirectedEdge[275, 282] -> 
             RGBColor[
              0.5106811757652547, 0.612557396257451, 0.9549190346803453], 
             UndirectedEdge[132, 423] -> 
             RGBColor[
              0.5889794016641527, 0.6524675094432201, 0.8735972473293918], 
             UndirectedEdge[116, 412] -> 
             RGBColor[
              0.24555371763094103`, 0.3754229046080053, 0.9372952930036862], 
             UndirectedEdge[89, 453] -> 
             RGBColor[
              0.28490427469255214`, 0.4167828350491789, 0.9395362490144127], 
             UndirectedEdge[136, 311] -> 
             RGBColor[
              0.8579087651395905, 0.8892705109856455, 0.9564145265871555], 
             UndirectedEdge[6, 24] -> 
             RGBColor[
              0.8323309168683787, 0.869142096362715, 0.9838696599531287], 
             UndirectedEdge[51, 477] -> 
             RGBColor[
              0.21179931412463662`, 0.3399448863700877, 0.9353730296591674], 
             UndirectedEdge[114, 381] -> 
             RGBColor[
              0.5349916430046526, 0.6333693427468647, 0.9565356483577385], 
             UndirectedEdge[95, 294] -> 
             RGBColor[
              0.2326978312332123, 0.36191055289371626`, 0.9365631692919152], 
             UndirectedEdge[89, 192] -> 
             RGBColor[
              0.27005817816264466`, 0.4011786462993594, 0.9386907857798661], 
             UndirectedEdge[108, 374] -> 
             RGBColor[
              0.2684205085848909, 0.3994573517388918, 0.938597522920128], 
             UndirectedEdge[208, 472] -> 
             RGBColor[
              0.32528262084800263`, 0.45616518982380916`, 0.9419476988576752],
              UndirectedEdge[34, 360] -> 
             RGBColor[
              0.5615596954334325, 0.6549384845856707, 0.9586271827669148], 
             UndirectedEdge[395, 453] -> 
             RGBColor[
              0.2746472026730905, 0.406002002020797, 0.9389521239368825], 
             UndirectedEdge[101, 361] -> 
             RGBColor[
              0.5825170875925927, 0.671924415713476, 0.9602963223136847], 
             UndirectedEdge[11, 211] -> 
             RGBColor[
              0.23497926878004616`, 0.3643084884069338, 0.936693093785123], 
             UndirectedEdge[70, 433] -> 
             RGBColor[
              0.2918782074405654, 0.4225632807803333, 0.9399901426055144], 
             UndirectedEdge[108, 206] -> 
             RGBColor[
              0.31392242641055057`, 0.44414031495447526`, 0.9413038498533395],
              UndirectedEdge[251, 499] -> 
             RGBColor[
              0.25963192027097015`, 0.39021998819227793`, 0.9380970258172014],
              UndirectedEdge[116, 399] -> 
             RGBColor[
              0.24511345141386065`, 0.3749601568993634, 0.937270220493939], 
             UndirectedEdge[350, 479] -> 
             RGBColor[
              0.3868303332701487, 0.5094747248458988, 0.9458694646687091], 
             UndirectedEdge[347, 421] -> 
             RGBColor[
              0.17899180289058533`, 0.3054621119467458, 0.9335046904287516], 
             UndirectedEdge[153, 447] -> 
             RGBColor[
              0.24571645560416666`, 0.3755939525360489, 0.9373045606905122], 
             UndirectedEdge[195, 453] -> 
             RGBColor[
              0.27722937887191995`, 0.40871603292519376`, 0.9390991750514186],
              UndirectedEdge[338, 425] -> 
             RGBColor[
              0.3477240886796976, 0.47560286131865376`, 0.9433776493436998], 
             UndirectedEdge[164, 348] -> 
             RGBColor[
              0.8887181595032059, 0.5060713797566354, 0.23158979527643736`], 
             UndirectedEdge[31, 258] -> 
             RGBColor[
              0.4132303526475083, 0.5323410947270124, 0.947551650558814], 
             UndirectedEdge[31, 203] -> 
             RGBColor[
              0.4938024492349883, 0.5999225041719667, 0.9532951828081889], 
             UndirectedEdge[398, 445] -> 
             RGBColor[
              0.2453951867466454, 0.3752562785971719, 0.9372862649043511], 
             UndirectedEdge[44, 369] -> 
             RGBColor[
              0.4583123366675063, 0.5702115381181944, 0.9507495276729314], 
             UndirectedEdge[267, 278] -> 
             RGBColor[
              0.9687131736129876, 0.9678890438697982, 0.6921508091390034], 
             UndirectedEdge[130, 477] -> 
             RGBColor[
              0.2117993137193227, 0.3399448859440771, 0.9353730296360853], 
             UndirectedEdge[4, 482] -> 
             RGBColor[
              0.3413925426988842, 0.4701187944228272, 0.9429742088325687], 
             UndirectedEdge[219, 274] -> 
             RGBColor[
              0.49450158018716717`, 0.6004976856950868, 0.9533481222927589], 
             UndirectedEdge[44, 269] -> 
             RGBColor[
              0.4728082951441619, 0.5827672087626157, 0.9516731973287911], 
             UndirectedEdge[130, 143] -> 
             RGBColor[
              0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772],
              UndirectedEdge[315, 401] -> 
             RGBColor[
              0.47947599697395743`, 0.5676241897079666, 0.9559647317614918], 
             UndirectedEdge[75, 163] -> 
             RGBColor[
              0.3059704107658049, 0.43557751025778224`, 0.9408584905702073], 
             UndirectedEdge[9, 139] -> 
             RGBColor[
              0.5695894293133013, 0.6614573842847371, 0.9592593128318224], 
             UndirectedEdge[134, 438] -> 
             RGBColor[
              0.22733547187831532`, 0.35627437321849936`, 0.9362577908595535],
              UndirectedEdge[76, 431] -> 
             RGBColor[
              0.42993261586454035`, 0.5468077556454473, 0.9486159040017718], 
             UndirectedEdge[90, 124] -> 
             RGBColor[
              0.9137111635376958, 0.6822566946723914, 0.2591427819494134], 
             UndirectedEdge[37, 188] -> 
             RGBColor[
              0.3214586719550145, 0.4525659249433619, 0.9417145542769817], 
             UndirectedEdge[26, 106] -> 
             RGBColor[
              0.45224243758080923`, 0.5643790618498358, 0.9505216428884367], 
             UndirectedEdge[107, 446] -> 
             RGBColor[
              0.2064114829025504, 0.3342819341474452, 0.9350662006416515], 
             UndirectedEdge[19, 234] -> 
             RGBColor[
              0.474151584993228, 0.582218817524079, 0.9522317884987839], 
             UndirectedEdge[39, 243] -> 
             RGBColor[
              0.7314838484501698, 0.504242577778165, 0.5743944759737214], 
             UndirectedEdge[129, 265] -> 
             RGBColor[
              0.3383071396578693, 0.46744637338556605`, 0.9427776096791101], 
             UndirectedEdge[396, 446] -> 
             RGBColor[
              0.6108486673250959, 0.6728679174892245, 0.7376055193707824], 
             UndirectedEdge[325, 368] -> 
             RGBColor[
              0.2935592851755068, 0.41669369113168975`, 0.9403654874960453], 
             UndirectedEdge[52, 56] -> 
             RGBColor[
              0.836234326611525, 0.27951848908515425`, 0.18233133812500216`], 
             UndirectedEdge[402, 431] -> 
             RGBColor[
              0.5004255816893457, 0.6051773211877334, 0.9538503277794443], 
             UndirectedEdge[165, 353] -> 
             RGBColor[
              0.531847897863051, 0.630021959343577, 0.9565078633928767], 
             UndirectedEdge[237, 329] -> 
             RGBColor[
              0.8943251384864865, 0.9185746058926771, 0.989782724153959], 
             UndirectedEdge[63, 75] -> 
             RGBColor[
              0.38214205273411095`, 0.5054139718854141, 0.9455707315786365], 
             UndirectedEdge[392, 492] -> 
             RGBColor[
              0.2913103527973019, 0.4235160293060819, 0.9399010656855349], 
             UndirectedEdge[125, 177] -> 
             RGBColor[
              0.20868507222126964`, 0.3366716206753079, 0.9351956781898786], 
             UndirectedEdge[210, 348] -> 
             RGBColor[
              0.8979876618717816, 0.5773208368833467, 0.24046628121299102`], 
             UndirectedEdge[469, 491] -> 
             RGBColor[
              0.9272960549745825, 0.7245251744430564, 0.40556918029226263`], 
             UndirectedEdge[35, 171] -> 
             RGBColor[
              0.25005732664065045`, 0.38015648322251344`, 0.9375517668742968],
              UndirectedEdge[8, 40] -> 
             RGBColor[
              0.5032468930597369, 0.6057751178648505, 0.9545401217837302], 
             UndirectedEdge[405, 491] -> 
             RGBColor[
              0.9940870576802556, 0.9897611392052678, 0.5977909028249961], 
             UndirectedEdge[98, 136] -> 
             RGBColor[
              0.9820976999154852, 0.9842937020241562, 0.8300672430323528], 
             UndirectedEdge[14, 75] -> 
             RGBColor[
              0.32584559541094904`, 0.45646758947931865`, 0.9419903529330476],
              UndirectedEdge[121, 500] -> 
             RGBColor[
              0.8234793018793516, 0.18147777970619255`, 0.1701171120367329], 
             UndirectedEdge[1, 265] -> 
             RGBColor[
              0.2935899974663011, 0.4247777732380918, 0.9400724206184119], 
             UndirectedEdge[227, 495] -> 
             RGBColor[
              0.8439168192516593, 0.3385694940069675, 0.1896881017533292], 
             UndirectedEdge[127, 368] -> 
             RGBColor[
              0.3170407306432145, 0.44137417912788274`, 0.9417027210777457], 
             UndirectedEdge[207, 389] -> 
             RGBColor[
              0.21778138864415675`, 0.3462324259755344, 0.9357136999533677], 
             UndirectedEdge[249, 260] -> 
             RGBColor[
              0.28756214905519606`, 0.4195764295232854, 0.9396876110273925], 
             UndirectedEdge[42, 95] -> 
             RGBColor[
              0.2297785943922997, 0.3588422498836111, 0.9363969230724491], 
             UndirectedEdge[190, 323] -> 
             RGBColor[
              0.243727142288008, 0.373503058111017, 0.9371912722400824], 
             UndirectedEdge[109, 295] -> 
             RGBColor[
              0.24177394363545715`, 0.37145012248723885`, 0.937080040466318], 
             UndirectedEdge[382, 499] -> 
             RGBColor[
              0.27147166687394786`, 0.40266431255529955`, 0.9387712818709056],
              UndirectedEdge[213, 254] -> 
             RGBColor[
              0.5703520735589939, 0.511904106319279, 0.5892794945919869], 
             UndirectedEdge[47, 374] -> 
             RGBColor[
              0.24183198733731956`, 0.37151113009807946`, 0.9370833459692711],
              UndirectedEdge[244, 390] -> 
             RGBColor[
              0.3215972480879268, 0.45223414091428343`, 0.9417399272656037], 
             UndirectedEdge[92, 370] -> 
             RGBColor[
              0.6002904630940367, 0.6863818665737486, 0.9616762106726342], 
             UndirectedEdge[295, 458] -> 
             RGBColor[
              0.2300435692999762, 0.35912075531195864`, 0.936412013001446], 
             UndirectedEdge[278, 493] -> 
             RGBColor[
              0.9709705008180975, 0.974840539169355, 0.7572967831573334], 
             UndirectedEdge[6, 156] -> 
             RGBColor[
              0.6474994925034097, 0.7219315348762902, 0.9673172118721224], 
             UndirectedEdge[79, 413] -> 
             RGBColor[
              0.9838323701759427, 0.9563067408191819, 0.46126511216987476`], 
             UndirectedEdge[122, 476] -> 
             RGBColor[
              0.8579983660337116, 0.432494720305006, 0.20261219607186334`], 
             UndirectedEdge[123, 455] -> 
             RGBColor[
              0.20545207796979598`, 0.3332735387333343, 0.9350115639500436], 
             UndirectedEdge[113, 302] -> 
             RGBColor[
              0.18467080951855291`, 0.3114311079825565, 0.9338281014548768], 
             UndirectedEdge[402, 462] -> 
             RGBColor[
              0.5080947993050582, 0.6115332733425336, 0.9544182302953215], 
             UndirectedEdge[140, 363] -> 
             RGBColor[
              0.4522227109181607, 0.5648567259118211, 0.9503836849393674], 
             UndirectedEdge[440, 453] -> 
             RGBColor[
              0.2829903357512072, 0.4147711638710876, 0.939427253023122], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.5464995084832656, 0.6427119463658346, 0.9574415896829152], 
             UndirectedEdge[102, 202] -> 
             RGBColor[
              0.2577973086293919, 0.3882916950358828, 0.9379925473982783], 
             UndirectedEdge[363, 379] -> 
             RGBColor[
              0.35705527838116624`, 0.4836850688388347, 0.9439722245002304], 
             UndirectedEdge[162, 297] -> 
             RGBColor[
              0.4906978130641887, 0.5974096161868968, 0.9530486758111798], 
             UndirectedEdge[19, 393] -> 
             RGBColor[
              0.5104680056398668, 0.6134599491568583, 0.954605057791339], 
             UndirectedEdge[96, 238] -> 
             RGBColor[
              0.3081578274315908, 0.4401690531459169, 0.9408991236475683], 
             UndirectedEdge[117, 247] -> 
             RGBColor[
              0.4380433274875822, 0.5527007733374919, 0.9494455065337566], 
             UndirectedEdge[162, 223] -> 
             RGBColor[
              0.4259476007932227, 0.5431195461878823, 0.9484273528030159], 
             UndirectedEdge[355, 362] -> 
             RGBColor[
              0.3585841716726791, 0.48500931936353203`, 0.9440696442288183], 
             UndirectedEdge[59, 395] -> 
             RGBColor[
              0.2535893388235434, 0.38386885196924064`, 0.9377529097429688], 
             UndirectedEdge[161, 403] -> 
             RGBColor[
              0.9596219668575938, 0.962601388451382, 0.7050117798938269], 
             UndirectedEdge[214, 477] -> 
             RGBColor[
              0.2222393711458674, 0.35091804823724815`, 0.9359675754618462], 
             UndirectedEdge[65, 309] -> 
             RGBColor[
              0.9892477963467572, 0.9750667140916796, 0.4404269945442838], 
             UndirectedEdge[361, 498] -> 
             RGBColor[
              0.5530454795335582, 0.6479980366103388, 0.95797620936922], 
             UndirectedEdge[54, 70] -> 
             RGBColor[
              0.24348548029858347`, 0.3732490560378767, 0.9371775099472914], 
             UndirectedEdge[369, 390] -> 
             RGBColor[
              0.36035044557586515`, 0.48580021278599533`, 0.9442092467414281],
              UndirectedEdge[56, 88] -> 
             RGBColor[
              0.8516418675680354, 0.38504228297430826`, 0.19658027687583196`],
              UndirectedEdge[289, 419] -> 
             RGBColor[
              0.4760307938821983, 0.5851235769437257, 0.9519986681530803], 
             UndirectedEdge[124, 178] -> 
             RGBColor[
              0.977168593002762, 0.938254909924025, 0.5484416326473938], 
             UndirectedEdge[67, 465] -> 
             RGBColor[
              0.26962432665641767`, 0.4007226408585406, 0.9386660785784122], 
             UndirectedEdge[7, 461] -> 
             RGBColor[
              0.8915688064008891, 0.9161509753336762, 0.9816909809846657], 
             UndirectedEdge[273, 423] -> 
             RGBColor[
              0.24068365358124288`, 0.3703041585118776, 0.9370179500606701], 
             UndirectedEdge[63, 467] -> 
             RGBColor[
              0.563087381667329, 0.6542682731705118, 0.9596777258955458], 
             UndirectedEdge[179, 368] -> 
             RGBColor[
              0.2935153935219346, 0.41664755822089383`, 0.9403629879313062], 
             UndirectedEdge[211, 485] -> 
             RGBColor[
              0.23952079823930758`, 0.3690819238182165, 0.9369517271692371], 
             UndirectedEdge[21, 320] -> 
             RGBColor[
              0.9847451317139568, 0.9683734708666063, 0.6094013242659239], 
             UndirectedEdge[318, 479] -> 
             RGBColor[
              0.3767164983407358, 0.5007146293661655, 0.94522502005032], 
             UndirectedEdge[343, 465] -> 
             RGBColor[
              0.2877565452274621, 0.4197807522257663, 0.9396986816018197], 
             UndirectedEdge[229, 313] -> 
             RGBColor[
              0.2789668469500533, 0.41054222203715074`, 0.9391981212881146], 
             UndirectedEdge[168, 401] -> 
             RGBColor[
              0.842122298838193, 0.7534870262743261, 0.6125668464325392], 
             UndirectedEdge[70, 216] -> 
             RGBColor[
              0.26206807245195374`, 0.39278053859546125`, 0.9382357610799443],
              UndirectedEdge[5, 193] -> 
             RGBColor[
              0.263209529621381, 0.3939802824530939, 0.9383007653771087], 
             UndirectedEdge[213, 471] -> 
             RGBColor[
              0.8805092403498851, 0.5477975823099646, 0.2219082457048863], 
             UndirectedEdge[145, 404] -> 
             RGBColor[
              0.2170532372191201, 0.345467092660354, 0.9356722328069155], 
             UndirectedEdge[28, 173] -> 
             RGBColor[
              0.9747095150977819, 0.9805973489982415, 0.9249344880863324], 
             UndirectedEdge[210, 243] -> 
             RGBColor[
              0.8376849116916145, 0.29066832166115775`, 0.18372042003589745`],
              UndirectedEdge[133, 424] -> 
             RGBColor[
              0.33288404882225986`, 0.46274916467623195`, 0.942432055126516], 
             UndirectedEdge[201, 400] -> 
             RGBColor[
              0.30019030163233085`, 0.432849418552972, 0.9404067656349827], 
             UndirectedEdge[120, 125] -> 
             RGBColor[
              0.2080475453125366, 0.33600153947268885`, 0.9351593719755629], 
             UndirectedEdge[96, 343] -> 
             RGBColor[
              0.29452462133405766`, 0.4268944293346082, 0.940084113523619], 
             UndirectedEdge[22, 149] -> 
             RGBColor[
              0.40264564991743174`, 0.5231731572248479, 0.9468772026605385], 
             UndirectedEdge[140, 369] -> 
             RGBColor[
              0.4597907440975337, 0.5714117758713864, 0.950865913321408], 
             UndirectedEdge[169, 370] -> 
             RGBColor[
              0.5420927609464797, 0.6391343501937576, 0.9570946743743712], 
             UndirectedEdge[154, 380] -> 
             RGBColor[
              0.2911961325222311, 0.423322454553487, 0.9398972530104752], 
             UndirectedEdge[33, 489] -> 
             RGBColor[
              0.9342559232885688, 0.7654812281083937, 0.517015114696979], 
             UndirectedEdge[271, 284] -> 
             RGBColor[
              0.2504489768010796, 0.3805681323731789, 0.9375740707715388], 
             UndirectedEdge[112, 356] -> 
             RGBColor[
              0.2588007282426925, 0.3893463526699398, 0.9380496906608295], 
             UndirectedEdge[133, 155] -> 
             RGBColor[
              0.4555313931992919, 0.5659235600860384, 0.9510915748153721], 
             UndirectedEdge[82, 447] -> 
             RGBColor[
              0.25238928516537673`, 0.3826075194867109, 0.9376845684624564], 
             UndirectedEdge[225, 260] -> 
             RGBColor[
              0.27991286113099906`, 0.41153654292208813`, 0.9392519953962168],
              UndirectedEdge[133, 225] -> 
             RGBColor[
              0.3097114792684619, 0.4394887933443991, 0.9410723011032855], 
             UndirectedEdge[442, 444] -> 
             RGBColor[
              0.27761918641957545`, 0.4091257453730057, 0.939121374014589], 
             UndirectedEdge[49, 431] -> 
             RGBColor[
              0.4693773227785792, 0.5799709458958486, 0.9514060951044689], 
             UndirectedEdge[220, 427] -> 
             RGBColor[
              0.30920666661498386`, 0.43953702554153684`, 0.9410223592495326],
              UndirectedEdge[151, 192] -> 
             RGBColor[
              0.28070448165153206`, 0.4123685862808082, 0.9392970770137636], 
             UndirectedEdge[167, 326] -> 
             RGBColor[
              0.9309228830343801, 0.7574193985269815, 0.5440638154599668], 
             UndirectedEdge[109, 196] -> 
             RGBColor[
              0.27482966958615396`, 0.4061937863154972, 0.938962515157646], 
             UndirectedEdge[212, 451] -> 
             RGBColor[
              0.21498103480107186`, 0.34328907653376356`, 0.9355542239447563],
              UndirectedEdge[186, 414] -> 
             RGBColor[
              0.255184189019674, 0.3855451406447167, 0.937843734102269], 
             UndirectedEdge[349, 419] -> 
             RGBColor[
              0.4631460027688009, 0.5739634184897324, 0.951177660656908], 
             UndirectedEdge[162, 221] -> 
             RGBColor[
              0.4993207487803075, 0.6044101038600693, 0.953727504897607], 
             UndirectedEdge[163, 364] -> 
             RGBColor[
              0.2627794929075267, 0.39352828660093053`, 0.938276275422437], 
             UndirectedEdge[191, 300] -> 
             RGBColor[
              0.22217951414553483`, 0.3508551347347456, 0.9359641666942277], 
             UndirectedEdge[438, 460] -> 
             RGBColor[
              0.23490540515407732`, 0.3642308530528161, 0.9366888873608955], 
             UndirectedEdge[172, 473] -> 
             RGBColor[
              0.3392418574009336, 0.4682559789143286, 0.9428371690671595], 
             UndirectedEdge[141, 188] -> 
             RGBColor[
              0.32343001274534444`, 0.45456055380007726`, 0.9418296523075707],
              UndirectedEdge[79, 122] -> 
             RGBColor[
              0.9306665098261713, 0.7402291937878942, 0.3904132893585251], 
             UndirectedEdge[326, 475] -> 
             RGBColor[
              0.8570894511774583, 0.4134428533627656, 0.20126936153652183`], 
             UndirectedEdge[98, 124] -> 
             RGBColor[
              0.9789436438067185, 0.93894816660261, 0.5160607207640602], 
             UndirectedEdge[204, 498] -> 
             RGBColor[
              0.4818912814299178, 0.5902600770764668, 0.9523553933815417], 
             UndirectedEdge[72, 144] -> 
             RGBColor[
              0.2501061102631632, 0.3802077579028347, 0.93755454502943], 
             UndirectedEdge[98, 331] -> 
             RGBColor[
              0.9159632164581281, 0.9324175867663749, 0.8534971993423514], 
             UndirectedEdge[311, 377] -> 
             RGBColor[
              0.8639809895032101, 0.8937991659736781, 0.9461358346293043], 
             UndirectedEdge[299, 389] -> 
             RGBColor[
              0.213833079654714, 0.34208250289038133`, 0.9354888495974187], 
             UndirectedEdge[131, 238] -> 
             RGBColor[
              0.29188148517230905`, 0.42306158545170824`, 0.9399722100345929],
              UndirectedEdge[4, 185] -> 
             RGBColor[
              0.30412419819916303`, 0.4355457825101565, 0.9406834624888651], 
             UndirectedEdge[162, 258] -> 
             RGBColor[
              0.4177269296537439, 0.5359992140298111, 0.9479035389072623], 
             UndirectedEdge[124, 253] -> 
             RGBColor[
              0.9738421982948224, 0.9368793602278473, 0.603568601391508], 
             UndirectedEdge[319, 449] -> 
             RGBColor[
              0.7215962304048408, 0.7824357266175173, 0.9728856266127364], 
             UndirectedEdge[256, 271] -> 
             RGBColor[
              0.2725957288123946, 0.4038457729222503, 0.9388352955353996], 
             UndirectedEdge[379, 478] -> 
             RGBColor[
              0.2876705710791334, 0.41963924089195836`, 0.9396956582454141], 
             UndirectedEdge[349, 371] -> 
             RGBColor[
              0.3882726943942144, 0.5107240255563866, 0.9459613706441047], 
             UndirectedEdge[130, 325] -> 
             RGBColor[
              0.1789719601845752, 0.3054412560046289, 0.9335035604159989], 
             UndirectedEdge[269, 369] -> 
             RGBColor[
              0.43444338232168905`, 0.5507147548329152, 0.948903326051707], 
             UndirectedEdge[43, 355] -> 
             RGBColor[
              0.3109273076150301, 0.4422891800076947, 0.941085795498422], 
             UndirectedEdge[11, 414] -> 
             RGBColor[
              0.25678804986481485`, 0.38723090008361066`, 0.9379350716047002],
              UndirectedEdge[117, 255] -> 
             RGBColor[
              0.38933039965095584`, 0.511640156687964, 0.9460287666877722], 
             UndirectedEdge[401, 475] -> 
             RGBColor[
              0.806227884360017, 0.5618744373452094, 0.5815185800497742], 
             UndirectedEdge[58, 141] -> 
             RGBColor[
              0.3123473120692484, 0.44496127550717535`, 0.9411234724205373], 
             UndirectedEdge[96, 180] -> 
             RGBColor[
              0.2831463385898367, 0.4149351327456384, 0.9394361371539964], 
             UndirectedEdge[119, 375] -> 
             RGBColor[
              0.9744244063754681, 0.9793738724475776, 0.8801494909995853], 
             UndirectedEdge[220, 382] -> 
             RGBColor[
              0.3105689508267532, 0.4409688726219141, 0.9410999393200739], 
             UndirectedEdge[104, 356] -> 
             RGBColor[
              0.2579557991377684, 0.3884582786090651, 0.9380015731982647], 
             UndirectedEdge[225, 440] -> 
             RGBColor[
              0.27796156594151966`, 0.4094856079586846, 0.9391408720218586], 
             UndirectedEdge[259, 341] -> 
             RGBColor[
              0.9277070351691528, 0.7270975616364004, 0.37415406223837167`], 
             UndirectedEdge[290, 362] -> 
             RGBColor[
              0.3374733904051481, 0.4646660623491092, 0.9427998432095333], 
             UndirectedEdge[79, 267] -> 
             RGBColor[
              0.9914456607402118, 0.9819881575780944, 0.49084130836277423`], 
             UndirectedEdge[90, 317] -> 
             RGBColor[
              0.8740850504741097, 0.5211314470341011, 0.21664581846880504`], 
             UndirectedEdge[41, 389] -> 
             RGBColor[
              0.2255132290582107, 0.3543590804777015, 0.9361540168267153], 
             UndirectedEdge[5, 300] -> 
             RGBColor[
              0.23228249418787045`, 0.3614740073251723, 0.936539516461619], 
             UndirectedEdge[290, 340] -> 
             RGBColor[
              0.31195990105564253`, 0.44256756021982796`, 0.9411741462288754],
              UndirectedEdge[288, 392] -> 
             RGBColor[
              0.281033651223698, 0.41271456437171095`, 0.9393158227339358], 
             UndirectedEdge[45, 292] -> 
             RGBColor[
              0.23087655194201073`, 0.35999627288288677`, 0.9364594501306225],
              UndirectedEdge[42, 145] -> 
             RGBColor[
              0.22656621784669417`, 0.3554658384577429, 0.9362139829804621], 
             UndirectedEdge[100, 368] -> 
             RGBColor[
              0.6696582512860165, 0.6464478563026956, 0.6053684569202311], 
             UndirectedEdge[302, 315] -> 
             RGBColor[
              0.18782448730516063`, 0.31474582329100176`, 0.934007698739376], 
             UndirectedEdge[255, 338] -> 
             RGBColor[
              0.35884542683277726`, 0.48523560545214284`, 0.9440862911766009],
              UndirectedEdge[59, 263] -> 
             RGBColor[
              0.25779587834217144`, 0.38829019171332857`, 0.9379924659455371],
              UndirectedEdge[413, 486] -> 
             RGBColor[
              0.9543818118224241, 0.9371774082640264, 0.6732568757445232], 
             UndirectedEdge[140, 247] -> 
             RGBColor[
              0.4973227229374232, 0.6027880164707773, 0.9535702129842454], 
             UndirectedEdge[82, 453] -> 
             RGBColor[
              0.27129272785642566`, 0.40247623630249474`, 0.9387610915585742],
              UndirectedEdge[199, 349] -> 
             RGBColor[
              0.3782226741008029, 0.5020192031069408, 0.9453209922378925], 
             UndirectedEdge[265, 462] -> 
             RGBColor[
              0.392446435384819, 0.5140523715462819, 0.9463065444803587], 
             UndirectedEdge[113, 386] -> 
             RGBColor[
              0.17905963034776856`, 0.3055334029047545, 0.9335085531020964], 
             UndirectedEdge[140, 219] -> 
             RGBColor[
              0.5129514818808725, 0.6154761470486363, 0.9548005661383041], 
             UndirectedEdge[13, 313] -> 
             RGBColor[
              0.2817870779153078, 0.4135064635946042, 0.939358729269428], 
             UndirectedEdge[74, 463] -> 
             RGBColor[
              0.2744156870316411, 0.4057586644026942, 0.9389389394635987], 
             UndirectedEdge[146, 415] -> 
             RGBColor[
              0.27247295826931617`, 0.4037167332973729, 0.9388283039345939], 
             UndirectedEdge[213, 475] -> 
             RGBColor[
              0.871604644354381, 0.4793529554696741, 0.21338119452328883`], 
             UndirectedEdge[49, 328] -> 
             RGBColor[
              0.4377638604952656, 0.5525889538048573, 0.9493917132424632], 
             UndirectedEdge[259, 450] -> 
             RGBColor[
              0.8397745913250846, 0.3013267240551166, 0.18550990071046175`], 
             UndirectedEdge[454, 500] -> 
             RGBColor[
              0.8596875442431727, 0.3945530129661969, 0.20223564129349905`], 
             UndirectedEdge[469, 495] -> 
             RGBColor[
              0.8513165746787745, 0.3922611978068248, 0.19664935782673318`], 
             UndirectedEdge[158, 182] -> 
             RGBColor[
              0.36805399542884243`, 0.4932116047339394, 0.9446730530247247], 
             UndirectedEdge[302, 347] -> 
             RGBColor[
              0.18453817917078433`, 0.311291705077802, 0.9338205483527805], 
             UndirectedEdge[87, 107] -> 
             RGBColor[
              0.1819624771956669, 0.3085844789930161, 0.9336738659357071], 
             UndirectedEdge[80, 307] -> 
             RGBColor[
              0.6296762406643908, 0.7079838947833768, 0.9655310968074982], 
             UndirectedEdge[159, 443] -> 
             RGBColor[
              0.877631072588452, 0.4692846461457165, 0.21683434670508697`], 
             UndirectedEdge[396, 443] -> 
             RGBColor[
              0.9640290207521414, 0.8833364286136021, 0.40253589756085995`], 
             UndirectedEdge[15, 452] -> 
             RGBColor[
              0.22909610908040262`, 0.3581249145487392, 0.9363580565435832], 
             UndirectedEdge[55, 250] -> 
             RGBColor[
              0.20796149957955015`, 0.33591109995170554`, 0.9351544717983624],
              UndirectedEdge[105, 447] -> 
             RGBColor[
              0.24620260884716, 0.3761049304183308, 0.9373322463985014], 
             UndirectedEdge[55, 242] -> 
             RGBColor[
              0.21824264556347417`, 0.34671723624311485`, 0.9357399678525544],
              UndirectedEdge[133, 440] -> 
             RGBColor[
              0.31342375230206637`, 0.44339062767442217`, 0.9412837095607336],
              UndirectedEdge[177, 455] -> 
             RGBColor[
              0.2063185988388122, 0.33418430710726665`, 0.9350609110316312], 
             UndirectedEdge[186, 456] -> 
             RGBColor[
              0.22968446940414386`, 0.35874331855319036`, 0.9363915627936191],
              UndirectedEdge[94, 302] -> 
             RGBColor[
              0.5727842186692342, 0.6417308063914131, 0.9472440733920693], 
             UndirectedEdge[146, 376] -> 
             RGBColor[
              0.2686941653913333, 0.39974498239330636`, 0.9386131072704159], 
             UndirectedEdge[44, 106] -> 
             RGBColor[
              0.5072662938524296, 0.6108606552923443, 0.9543530073111751], 
             UndirectedEdge[46, 205] -> 
             RGBColor[
              0.9557407049755898, 0.8502199530826348, 0.4110195083871594], 
             UndirectedEdge[134, 457] -> 
             RGBColor[
              0.22739772905471156`, 0.3563398094582248, 0.936261336313648], 
             UndirectedEdge[229, 248] -> 
             RGBColor[
              0.2667577277658053, 0.3977096636716398, 0.9385028300123448], 
             UndirectedEdge[101, 362] -> 
             RGBColor[
              0.45464713410545365`, 0.5663810460128507, 0.950697205214848], 
             UndirectedEdge[286, 346] -> 
             RGBColor[
              0.22049146079372114`, 0.3490808836332252, 0.935868034553093], 
             UndirectedEdge[134, 138] -> 
             RGBColor[
              0.2265863896100655, 0.3554870402600099, 0.9362151317325447], 
             UndirectedEdge[144, 494] -> 
             RGBColor[
              0.25236564813326057`, 0.3825826754672824, 0.9376832223684453], 
             UndirectedEdge[35, 147] -> 
             RGBColor[
              0.2449327987863818, 0.374770279533845, 0.9372599325940558], 
             UndirectedEdge[5, 211] -> 
             RGBColor[
              0.2348238735021131, 0.3641451581171964, 0.9366842442539314], 
             UndirectedEdge[243, 471] -> 
             RGBColor[
              0.8480593461920269, 0.37041077133751354`, 0.1936549902297403], 
             UndirectedEdge[154, 338] -> 
             RGBColor[
              0.314823265682197, 0.4471058220816644, 0.9412812379953546], 
             UndirectedEdge[185, 383] -> 
             RGBColor[
              0.3064436349421723, 0.43755476203867083`, 0.9408312549471323], 
             UndirectedEdge[416, 429] -> 
             RGBColor[
              0.2775658260011634, 0.4090696601900088, 0.9391183352177], 
             UndirectedEdge[159, 396] -> 
             RGBColor[
              0.9071481131704897, 0.5745522202562454, 0.3532052383412315], 
             UndirectedEdge[73, 322] -> 
             RGBColor[
              0.2535645087759725, 0.3838427540149276, 0.9377514957084923], 
             UndirectedEdge[287, 300] -> 
             RGBColor[
              0.2178846815571592, 0.3463409933762489, 0.9357195823319551], 
             UndirectedEdge[392, 459] -> 
             RGBColor[
              0.34827375514967984`, 0.47582519706689724`, 0.9434219649183455],
              UndirectedEdge[200, 450] -> 
             RGBColor[
              0.8592682454015592, 0.38984285435780597`, 0.20177588350505832`],
              UndirectedEdge[104, 148] -> 
             RGBColor[
              0.2431147548759032, 0.37285940011329033`, 0.9371563976829089], 
             UndirectedEdge[94, 325] -> 
             RGBColor[
              0.5672179996830251, 0.6358803573182399, 0.9469270854552878], 
             UndirectedEdge[355, 378] -> 
             RGBColor[
              0.30589561445696456`, 0.4370005514707954, 0.940799248016793], 
             UndirectedEdge[424, 453] -> 
             RGBColor[
              0.3024506322714007, 0.4341297008728973, 0.9405755985889044], 
             UndirectedEdge[212, 301] -> 
             RGBColor[
              0.2136344659280746, 0.34187374727084574`, 0.9354775388395093], 
             UndirectedEdge[46, 420] -> 
             RGBColor[
              0.9431488383406506, 0.8436851965616485, 0.5952825252201055], 
             UndirectedEdge[146, 284] -> 
             RGBColor[
              0.25151293220690424`, 0.3816864169633695, 0.9376346614579194], 
             UndirectedEdge[76, 343] -> 
             RGBColor[
              0.3521064049491038, 0.47793237749510553`, 0.9437105723744709], 
             UndirectedEdge[111, 256] -> 
             RGBColor[
              0.2812386903435383, 0.41293007348689414`, 0.9393274994084824], 
             UndirectedEdge[277, 319] -> 
             RGBColor[
              0.7430956081884199, 0.7992312039433723, 0.9750284836670953], 
             UndirectedEdge[240, 429] -> 
             RGBColor[
              0.2751117605214455, 0.4064902817740869, 0.9389785798190946], 
             UndirectedEdge[49, 71] -> 
             RGBColor[
              0.6229981269292593, 0.7030794824142605, 0.9646517716159538], 
             UndirectedEdge[19, 139] -> 
             RGBColor[
              0.5618798532479841, 0.6551984031224687, 0.9586523867628529], 
             UndirectedEdge[9, 247] -> 
             RGBColor[
              0.5350775301382318, 0.6334390697910756, 0.9565424097075088], 
             UndirectedEdge[333, 392] -> 
             RGBColor[
              0.34232526370384136`, 0.4706729127563853, 0.943042932303461], 
             UndirectedEdge[169, 337] -> 
             RGBColor[
              0.6764764422213522, 0.7452210038115648, 0.9698692373870139], 
             UndirectedEdge[21, 119] -> 
             RGBColor[
              0.9857675700825197, 0.9687962754074746, 0.5924568745131584], 
             UndirectedEdge[354, 479] -> 
             RGBColor[
              0.38662725868303643`, 0.5092988318453677, 0.9458565249355901], 
             UndirectedEdge[179, 236] -> 
             RGBColor[
              0.23312614698427564`, 0.36236073990487094`, 0.9365875612403018],
              UndirectedEdge[121, 341] -> 
             RGBColor[
              0.9105196563022746, 0.6003916270804778, 0.3579070077274834], 
             UndirectedEdge[263, 323] -> 
             RGBColor[
              0.2563726589916906, 0.3867942979386546, 0.9379114157089916], 
             UndirectedEdge[200, 401] -> 
             RGBColor[
              0.8371401925160188, 0.7327555556169211, 0.6085074799840489], 
             UndirectedEdge[56, 236] -> 
             RGBColor[
              0.5619983827153064, 0.35111011799079705`, 0.5612129978793174], 
             UndirectedEdge[374, 437] -> 
             RGBColor[
              0.25378039219455883`, 0.3840696611756612, 0.9377637899498099], 
             UndirectedEdge[74, 195] -> 
             RGBColor[
              0.27594296910076915`, 0.40736393469262394`, 0.9390259159180243],
              UndirectedEdge[240, 399] -> 
             RGBColor[
              0.24906325398775672`, 0.3791116498364756, 0.9374951559073132], 
             UndirectedEdge[138, 352] -> 
             RGBColor[
              0.22389864331585435`, 0.3526620484918363, 0.9360620685572537], 
             UndirectedEdge[195, 342] -> 
             RGBColor[
              0.265069534257383, 0.39593526525663725`, 0.9384066898894987], 
             UndirectedEdge[13, 363] -> 
             RGBColor[
              0.3507138092232281, 0.4770709297343131, 0.9436092144688942], 
             UndirectedEdge[368, 386] -> 
             RGBColor[
              0.2935143249909316, 0.4166464351270609, 0.9403629270800464], 
             UndirectedEdge[132, 233] -> 
             RGBColor[
              0.9166463543771588, 0.6614692040973338, 0.5010749461233683], 
             UndirectedEdge[304, 310] -> 
             RGBColor[
              0.317660558842397, 0.44845488439544834`, 0.9415026138990965], 
             UndirectedEdge[213, 259] -> 
             RGBColor[
              0.8830232984339081, 0.5617179434386964, 0.224104111662967], 
             UndirectedEdge[226, 446] -> 
             RGBColor[
              0.20378813280661343`, 0.33152462686661266`, 0.9349168047345866],
              UndirectedEdge[60, 249] -> 
             RGBColor[
              0.29112873348308044`, 0.42332513589150556`, 0.9398907227342717],
              UndirectedEdge[181, 387] -> 
             RGBColor[
              0.5979055016129029, 0.6815262817946347, 0.9631235948533272], 
             UndirectedEdge[94, 168] -> 
             RGBColor[
              0.9331056494970619, 0.8251500560931704, 0.6037137900969318], 
             UndirectedEdge[142, 402] -> 
             RGBColor[
              0.6259177691187879, 0.7063115685381091, 0.9642924066530247], 
             UndirectedEdge[188, 310] -> 
             RGBColor[
              0.3170171080071488, 0.4478975596227356, 0.9414616137808558], 
             UndirectedEdge[74, 239] -> 
             RGBColor[
              0.31633226480045645`, 0.4459153985127936, 0.9414688336983061], 
             UndirectedEdge[376, 400] -> 
             RGBColor[
              0.2876884645475003, 0.41970919511456195`, 0.9396948045078122], 
             UndirectedEdge[292, 308] -> 
             RGBColor[
              0.17895845847297373`, 0.30542706484967774`, 0.9335027915134972],
              UndirectedEdge[7, 142] -> 
             RGBColor[
              0.7691032060058948, 0.819699666861827, 0.9775805727504322], 
             UndirectedEdge[20, 194] -> 
             RGBColor[
              0.9355250585723344, 0.7786349412620628, 0.5492457614630861], 
             UndirectedEdge[168, 500] -> 
             RGBColor[
              0.8651424411448785, 0.41743131522220955`, 0.2066895157907081], 
             UndirectedEdge[4, 383] -> 
             RGBColor[
              0.32662308368104653`, 0.45732623135617084`, 0.9420331119640719],
              UndirectedEdge[91, 303] -> 
             RGBColor[
              0.3164436833902854, 0.44818690517109605`, 0.9413962957337874], 
             UndirectedEdge[142, 417] -> 
             RGBColor[
              0.7002784838355302, 0.7657821409766972, 0.9707608728603756], 
             UndirectedEdge[229, 338] -> 
             RGBColor[
              0.3055405634218271, 0.43742263545021065`, 0.9407499098335221], 
             UndirectedEdge[69, 388] -> 
             RGBColor[
              0.9278173046721767, 0.9450102776472538, 0.9836136557859578], 
             UndirectedEdge[170, 374] -> 
             RGBColor[
              0.2742054454433818, 0.40553768716334715`, 0.9389269665161719], 
             UndirectedEdge[96, 281] -> 
             RGBColor[
              0.27053519804586806`, 0.4016800244414347, 0.938717951356528], 
             UndirectedEdge[131, 265] -> 
             RGBColor[
              0.29231177765764305`, 0.42343428317537546`, 0.9399996278912657],
              UndirectedEdge[117, 369] -> 
             RGBColor[
              0.40051134864769267`, 0.5213245327381009, 0.9467412068709193], 
             UndirectedEdge[19, 247] -> 
             RGBColor[
              0.5273679540729146, 0.6271800886288073, 0.9559354836385393], 
             UndirectedEdge[328, 436] -> 
             RGBColor[
              0.42911640965865483`, 0.5455685636524759, 0.9487109542359491], 
             UndirectedEdge[86, 178] -> 
             RGBColor[
              0.9534388639235, 0.8461526483552239, 0.5190456011559075], 
             UndirectedEdge[42, 137] -> 
             RGBColor[
              0.22627740530250587`, 0.35516227816202806`, 0.9361975355333305],
              UndirectedEdge[54, 135] -> 
             RGBColor[
              0.23967378277683635`, 0.36924272026693905`, 0.9369604394123292],
              UndirectedEdge[42, 174] -> 
             RGBColor[
              0.2495656884148965, 0.3796397402755821, 0.9375237688046536], 
             UndirectedEdge[1, 374] -> 
             RGBColor[
              0.25894790578239785`, 0.38950104559576504`, 0.9380580722039861],
              UndirectedEdge[160, 285] -> 
             RGBColor[
              0.3684500451199806, 0.49355464307036695`, 0.9446982889608311], 
             UndirectedEdge[454, 471] -> 
             RGBColor[
              0.8783475046128462, 0.5379816452142798, 0.2201044404169093], 
             UndirectedEdge[26, 425] -> 
             RGBColor[
              0.38098619324606947`, 0.5044128244920598, 0.9454970812341448], 
             UndirectedEdge[333, 442] -> 
             RGBColor[
              0.331297230301234, 0.4590817504325423, 0.942414902115696], 
             UndirectedEdge[75, 410] -> 
             RGBColor[
              0.354306761585108, 0.48130444173456, 0.9437970914404035], 
             UndirectedEdge[31, 40] -> 
             RGBColor[
              0.4196192099941566, 0.5378748018473721, 0.9479587428994976], 
             UndirectedEdge[3, 258] -> 
             RGBColor[
              0.41754423807969365`, 0.5358508967798354, 0.9478891567573319], 
             UndirectedEdge[132, 273] -> 
             RGBColor[
              0.6418371637733833, 0.7080243687957053, 0.8766074186854609], 
             UndirectedEdge[157, 180] -> 
             RGBColor[
              0.2863372761085622, 0.4182890103949429, 0.9396178563251187], 
             UndirectedEdge[213, 401] -> 
             RGBColor[
              0.8388291376735261, 0.7404246611139982, 0.6099167772233072], 
             UndirectedEdge[84, 391] -> 
             RGBColor[
              0.23722076036640824`, 0.3666644381829753, 0.9368207434149767], 
             UndirectedEdge[43, 110] -> 
             RGBColor[
              0.2824315567297242, 0.4141838516908727, 0.9393954313844881], 
             UndirectedEdge[39, 127] -> 
             RGBColor[
              0.4248206994263658, 0.5301025431322064, 0.9498483295981558], 
             UndirectedEdge[52, 469] -> 
             RGBColor[
              0.8481128613393234, 0.36763605320366755`, 0.19358147831479822`],
              UndirectedEdge[260, 483] -> 
             RGBColor[
              0.2911128004849959, 0.42330838930030823`, 0.9398898153736015], 
             UndirectedEdge[98, 311] -> 
             RGBColor[
              0.8710458030481137, 0.8971927199459824, 0.8490560873664715], 
             UndirectedEdge[51, 127] -> 
             RGBColor[
              0.20245340605759676`, 0.3301217444268325, 0.9348407940207814], 
             UndirectedEdge[243, 475] -> 
             RGBColor[
              0.8391547501965229, 0.3019661444972231, 0.18512793904814284`], 
             UndirectedEdge[76, 96] -> 
             RGBColor[
              0.3537435180123586, 0.4796530871235497, 0.9438038035415315], 
             UndirectedEdge[99, 476] -> 
             RGBColor[
              0.9210569805098886, 0.6812525268241133, 0.37059559494700395`], 
             UndirectedEdge[107, 308] -> 
             RGBColor[
              0.18180898862834943`, 0.3084231527770282, 0.9336651249888644], 
             UndirectedEdge[190, 263] -> 
             RGBColor[
              0.26075513515246407`, 0.3914005582486648, 0.9381609912430551], 
             UndirectedEdge[191, 299] -> 
             RGBColor[
              0.21378387890714912`, 0.3420307897851831, 0.935486047687631], 
             UndirectedEdge[39, 276] -> 
             RGBColor[
              0.6216008719460259, 0.7036826165027719, 0.9633538441200625], 
             UndirectedEdge[51, 214] -> 
             RGBColor[
              0.1893670578318586, 0.31636716271918164`, 0.9340955458488429], 
             UndirectedEdge[295, 409] -> 
             RGBColor[
              0.23557177233220394`, 0.3649312472071466, 0.9367268359858879], 
             UndirectedEdge[371, 382] -> 
             RGBColor[
              0.322584307384319, 0.45137597056269757`, 0.9418655472151594], 
             UndirectedEdge[53, 420] -> 
             RGBColor[
              0.9725775680800968, 0.9542835451375451, 0.6506094324523175], 
             UndirectedEdge[87, 308] -> 
             RGBColor[
              0.17909977333492821`, 0.3055755957294717, 0.9335108391858289], 
             UndirectedEdge[286, 358] -> 
             RGBColor[
              0.22436323878386594`, 0.35315036778577047`, 0.9360885265818495],
              UndirectedEdge[215, 351] -> 
             RGBColor[
              0.28708427642095813`, 0.4190741550858264, 0.9396603968878219], 
             UndirectedEdge[114, 258] -> 
             RGBColor[
              0.4370504632160207, 0.551686929090934, 0.9494247582537205], 
             UndirectedEdge[87, 292] -> 
             RGBColor[
              0.1791119470402912, 0.3055883910656657, 0.93351153246034], 
             UndirectedEdge[196, 383] -> 
             RGBColor[
              0.3123209276016251, 0.4437321692656331, 0.941165958069413], 
             UndirectedEdge[65, 495] -> 
             RGBColor[
              0.9138336495538494, 0.6440119286541663, 0.2930402350354805], 
             UndirectedEdge[14, 279] -> 
             RGBColor[
              0.2926514518650601, 0.4249256094568878, 0.9399774392934654], 
             UndirectedEdge[26, 466] -> 
             RGBColor[
              0.4450688550450512, 0.558555224381097, 0.9499569121935232], 
             UndirectedEdge[27, 371] -> 
             RGBColor[
              0.43753141765926407`, 0.551792873087608, 0.9495412335023905], 
             UndirectedEdge[258, 472] -> 
             RGBColor[
              0.3509345795878789, 0.47838362717935545`, 0.9435822189854435], 
             UndirectedEdge[26, 117] -> 
             RGBColor[
              0.38385240519854513`, 0.5068953932252928, 0.9456797137252648], 
             UndirectedEdge[97, 104] -> 
             RGBColor[
              0.23915408747259903`, 0.3686964875516002, 0.936930843533573], 
             UndirectedEdge[21, 428] -> 
             RGBColor[
              0.9056106309029361, 0.5906771035003356, 0.2784668522610333], 
             UndirectedEdge[160, 268] -> 
             RGBColor[
              0.41606826400089775`, 0.5347991509037464, 0.9477324797607855], 
             UndirectedEdge[48, 137] -> 
             RGBColor[
              0.21379570916554433`, 0.34204322413683813`, 0.9354867214033452],
              UndirectedEdge[27, 291] -> 
             RGBColor[
              0.583523028601068, 0.6725767800031528, 0.9604878491746004], 
             UndirectedEdge[117, 140] -> 
             RGBColor[
              0.44035466890019287`, 0.5545772244209933, 0.9496274637964799], 
             UndirectedEdge[31, 221] -> 
             RGBColor[
              0.4948241717740719, 0.6007519845572706, 0.9533756165491586], 
             UndirectedEdge[87, 386] -> 
             RGBColor[
              0.17909013095112286`, 0.3055654609727298, 0.9335102900663359], 
             UndirectedEdge[207, 409] -> 
             RGBColor[
              0.22930932819200256`, 0.35834902135390323`, 0.9363701990565594],
              UndirectedEdge[274, 498] -> 
             RGBColor[
              0.46231188623512687`, 0.5743646420156336, 0.95081403167012], 
             UndirectedEdge[28, 69] -> 
             RGBColor[
              0.9371592911405698, 0.9519775158592825, 0.9678001094752631], 
             UndirectedEdge[442, 492] -> 
             RGBColor[
              0.2802823193946945, 0.4119248669822389, 0.9392730354977699], 
             UndirectedEdge[476, 493] -> 
             RGBColor[
              0.9210348441528622, 0.6812051793947629, 0.36818618909444256`], 
             UndirectedEdge[297, 359] -> 
             RGBColor[
              0.45240773600559087`, 0.5644812656494411, 0.9505434955218137], 
             UndirectedEdge[112, 323] -> 
             RGBColor[
              0.24380409586490398`, 0.37358394119947325`, 0.9371956546324439],
              UndirectedEdge[27, 349] -> 
             RGBColor[
              0.46286019331944683`, 0.5737313855031778, 0.9511551606901004], 
             UndirectedEdge[2, 242] -> 
             RGBColor[
              0.21872765624032725`, 0.34722701321594046`, 0.9357675884930923],
              UndirectedEdge[71, 462] -> 
             RGBColor[
              0.6098299518680684, 0.6923889646800596, 0.9636151246385223], 
             UndirectedEdge[165, 285] -> 
             RGBColor[
              0.3692257984681636, 0.49422656163006606`, 0.9447477192782054], 
             UndirectedEdge[91, 172] -> 
             RGBColor[
              0.33964065051404985`, 0.4686013934649852, 0.9428625798116885], 
             UndirectedEdge[19, 26] -> 
             RGBColor[
              0.4731770317838775, 0.5813747085166081, 0.9521696908300475], 
             UndirectedEdge[73, 163] -> 
             RGBColor[
              0.2574513896017804, 0.3879281122053299, 0.9379728478213971], 
             UndirectedEdge[67, 131] -> 
             RGBColor[
              0.2601160605037315, 0.39072885027317383`, 0.938124596887236], 
             UndirectedEdge[24, 81] -> 
             RGBColor[
              0.8302950804632105, 0.8675187756745408, 0.9836754800593912], 
             UndirectedEdge[282, 467] -> 
             RGBColor[
              0.6572487791197071, 0.7316354395209496, 0.9668355107224047], 
             UndirectedEdge[122, 406] -> 
             RGBColor[
              0.929061342775948, 0.7356327772399205, 0.3146046467534838], 
             UndirectedEdge[139, 255] -> 
             RGBColor[
              0.4808103528632557, 0.5878692632314095, 0.9526884189998513], 
             UndirectedEdge[409, 458] -> 
             RGBColor[
              0.23602745875437942`, 0.36541020252904094`, 0.9367527866535031],
              UndirectedEdge[4, 196] -> 
             RGBColor[
              0.31000149085861584`, 0.44172318973711877`, 0.9410181656111457],
              UndirectedEdge[46, 90] -> 
             RGBColor[
              0.8912123121580973, 0.5950344530170778, 0.2307371435474895], 
             UndirectedEdge[115, 124] -> 
             RGBColor[
              0.9419104649402625, 0.9128295501642687, 0.6508778471089514], 
             UndirectedEdge[330, 350] -> 
             RGBColor[
              0.33430977302587317`, 0.4637717331289171, 0.9425306751676419], 
             UndirectedEdge[213, 315] -> 
             RGBColor[
              0.5448527569683213, 0.48510270783243126`, 0.5878273462350064], 
             UndirectedEdge[107, 143] -> 
             RGBColor[
              0.18179934691843552`, 0.30841301872858895`, 0.9336645759077484],
              UndirectedEdge[403, 491] -> 
             RGBColor[
              0.9615367037861473, 0.968036714632053, 0.7994838663892643], 
             UndirectedEdge[200, 254] -> 
             RGBColor[
              0.5686631284014866, 0.5042350008222019, 0.5878701973527287], 
             UndirectedEdge[37, 304] -> 
             RGBColor[
              0.32210212279026273`, 0.45312324971607465`, 0.9417555543952225],
              UndirectedEdge[25, 392] -> 
             RGBColor[
              0.3096883372024623, 0.4424044474005129, 0.9409633362064942], 
             UndirectedEdge[231, 492] -> 
             RGBColor[
              0.2675328366491727, 0.39852435225280064`, 0.9385469713165818], 
             UndirectedEdge[22, 63] -> 
             RGBColor[
              0.4353760609281416, 0.5515225941640346, 0.948962755507775], 
             UndirectedEdge[201, 256] -> 
             RGBColor[
              0.2969224563599441, 0.4294147059783363, 0.9402206666810642], 
             UndirectedEdge[57, 92] -> 
             RGBColor[
              0.6051902881840892, 0.690359765316458, 0.9620619428523739], 
             UndirectedEdge[433, 462] -> 
             RGBColor[
              0.3946923083800721, 0.5159976338539112, 0.9464496495216687], 
             UndirectedEdge[286, 294] -> 
             RGBColor[
              0.23070650372322443`, 0.3598175414232626, 0.9364497661361264], 
             UndirectedEdge[319, 331] -> 
             RGBColor[
              0.775790689833521, 0.8249078922958527, 0.9782513878368327], 
             UndirectedEdge[222, 307] -> 
             RGBColor[
              0.456261635454359, 0.5691648443465238, 0.950417290103996], 
             UndirectedEdge[276, 283] -> 
             RGBColor[
              0.4003771577872324, 0.5049037920541919, 0.9484114336869224], 
             UndirectedEdge[464, 497] -> 
             RGBColor[
              0.23993020302659857`, 0.369512234207422, 0.9369750421662133], 
             UndirectedEdge[143, 283] -> 
             RGBColor[
              0.18007058028918088`, 0.3065959753911073, 0.9335661252056935], 
             UndirectedEdge[265, 433] -> 
             RGBColor[
              0.32326037843179023`, 0.45441362508374517`, 0.9418188433591128],
              UndirectedEdge[74, 234] -> 
             RGBColor[
              0.335156328175214, 0.4622198560830736, 0.94266828637108], 
             UndirectedEdge[17, 432] -> 
             RGBColor[
              0.8892978625365586, 0.9145659925119751, 0.9893032180859526], 
             UndirectedEdge[103, 118] -> 
             RGBColor[
              0.4027319052154037, 0.522513730131029, 0.9470855430392838], 
             UndirectedEdge[426, 489] -> 
             RGBColor[
              0.9301359936068372, 0.9447452859638352, 0.9006256116612403], 
             UndirectedEdge[277, 331] -> 
             RGBColor[
              0.8039966134471465, 0.8469425741957761, 0.9810626907032964], 
             UndirectedEdge[74, 112] -> 
             RGBColor[
              0.264998769293781, 0.3958608867931338, 0.938402659929509], 
             UndirectedEdge[80, 372] -> 
             RGBColor[
              0.6299979927875134, 0.7082451076516956, 0.9655564263132472], 
             UndirectedEdge[180, 281] -> 
             RGBColor[
              0.2575198022383923, 0.3880000182240208, 0.9379767438198447], 
             UndirectedEdge[263, 296] -> 
             RGBColor[
              0.2934102361450429, 0.4252910132115676, 0.9400364732085589], 
             UndirectedEdge[37, 141] -> 
             RGBColor[
              0.3076115395353609, 0.4405722348185699, 0.9408322272437397], 
             UndirectedEdge[18, 210] -> 
             RGBColor[
              0.8602238171594843, 0.4230516477625904, 0.20370370360755374`], 
             UndirectedEdge[279, 494] -> 
             RGBColor[
              0.2685318784304253, 0.3995744085078045, 0.9386038652680744], 
             UndirectedEdge[101, 337] -> 
             RGBColor[
              0.6905217138834787, 0.756623588079157, 0.9709749326217818], 
             UndirectedEdge[217, 378] -> 
             RGBColor[
              0.30140209308183147`, 0.4331084891066064, 0.9405129248082346], 
             UndirectedEdge[20, 62] -> 
             RGBColor[
              0.8509265138034974, 0.3513524058869604, 0.19479135055817565`], 
             UndirectedEdge[18, 56] -> 
             RGBColor[
              0.8605287644059905, 0.4253956059279722, 0.2039957214351967], 
             UndirectedEdge[444, 492] -> 
             RGBColor[
              0.2739561801729139, 0.4052756935597544, 0.9389127712277736], 
             UndirectedEdge[199, 427] -> 
             RGBColor[
              0.31117200287913815`, 0.44123930103287445`, 0.9411475887384059],
              UndirectedEdge[190, 463] -> 
             RGBColor[
              0.2576034897635375, 0.3880879791190439, 0.9379815097005972], 
             UndirectedEdge[139, 369] -> 
             RGBColor[
              0.49199130185999246`, 0.5975536392815464, 0.9534008591829983], 
             UndirectedEdge[10, 455] -> 
             RGBColor[
              0.21145152724630215`, 0.3395793403099965, 0.9353532237109508], 
             UndirectedEdge[52, 236] -> 
             RGBColor[
              0.5615591008027638, 0.3477336047164332, 0.5607923410237687], 
             UndirectedEdge[9, 19] -> 
             RGBColor[
              0.5674341026863339, 0.6597075930326068, 0.9590896376245259], 
             UndirectedEdge[33, 309] -> 
             RGBColor[
              0.9357225086078202, 0.7641455885442991, 0.35153908493080155`], 
             UndirectedEdge[341, 491] -> 
             RGBColor[
              0.9938674015539399, 0.9892913169617195, 0.5738826890360067], 
             UndirectedEdge[87, 143] -> 
             RGBColor[
              0.1790901316250143, 0.30556546168103244`, 0.933510290104713], 
             UndirectedEdge[110, 378] -> 
             RGBColor[
              0.2773998635716586, 0.40889522315397336`, 0.9391088839028592], 
             UndirectedEdge[401, 471] -> 
             RGBColor[
              0.8151324803555211, 0.6303190641854999, 0.5900456312313715], 
             UndirectedEdge[160, 165] -> 
             RGBColor[
              0.4232575021072018, 0.5410261076098133, 0.9481905716557255], 
             UndirectedEdge[13, 379] -> 
             RGBColor[
              0.3029577301181068, 0.43570701430378433`, 0.9405662393373586], 
             UndirectedEdge[210, 434] -> 
             RGBColor[
              0.9136331462118448, 0.6344185701788778, 0.48881376628200723`], 
             UndirectedEdge[308, 446] -> 
             RGBColor[
              0.2035487790418117, 0.3312730508839008, 0.9349031738917732], 
             UndirectedEdge[153, 395] -> 
             RGBColor[
              0.2549602684410159, 0.3853097859191623, 0.9378309821565751], 
             UndirectedEdge[24, 83] -> 
             RGBColor[
              0.878858858195596, 0.9062422138097157, 0.9883075365329024], 
             UndirectedEdge[133, 260] -> 
             RGBColor[
              0.31537504749154577`, 0.44544156263782575`, 0.9413948329350919],
              UndirectedEdge[83, 119] -> 
             RGBColor[
              0.9556965383033635, 0.9650210547273206, 0.8984817408494732], 
             UndirectedEdge[400, 464] -> 
             RGBColor[
              0.26989429594474446`, 0.40100639569761354`, 0.9386814529299987],
              UndirectedEdge[175, 320] -> 
             RGBColor[
              0.9721663810423609, 0.9780295691716399, 0.8991854671906325], 
             UndirectedEdge[39, 475] -> 
             RGBColor[
              0.731332489294519, 0.5030791649818271, 0.5742495342753344], 
             UndirectedEdge[289, 291] -> 
             RGBColor[
              0.5471490964494157, 0.6426680909259248, 0.9577289938124869], 
             UndirectedEdge[263, 342] -> 
             RGBColor[
              0.2666938975771815, 0.3976425740963284, 0.9384991949775311], 
             UndirectedEdge[311, 319] -> 
             RGBColor[
              0.7308732764235066, 0.7896830254754603, 0.9738102758609529], 
             UndirectedEdge[141, 304] -> 
             RGBColor[
              0.3240734635805927, 0.45511787857278996`, 0.9418706524258115], 
             UndirectedEdge[30, 43] -> 
             RGBColor[
              0.2805395184040802, 0.4121951994484624, 0.9392876826008625], 
             UndirectedEdge[85, 95] -> 
             RGBColor[
              0.22064923730827996`, 0.3492467167536353, 0.9358770196921877], 
             UndirectedEdge[305, 438] -> 
             RGBColor[
              0.23628821482403703`, 0.36568427369114076`, 0.9367676363259161],
              UndirectedEdge[23, 212] -> 
             RGBColor[
              0.22050887971367938`, 0.3490991920225246, 0.9358690265348157], 
             UndirectedEdge[80, 461] -> 
             RGBColor[
              0.8669992096038857, 0.8968058897416262, 0.9792822184041656], 
             UndirectedEdge[115, 439] -> 
             RGBColor[
              0.8910404321249454, 0.9159554702009634, 0.9894694259289032], 
             UndirectedEdge[136, 377] -> 
             RGBColor[
              0.9750328863705816, 0.980900148051852, 0.9271469902951855], 
             UndirectedEdge[27, 488] -> 
             RGBColor[
              0.640741608541348, 0.7172763695298137, 0.9661908624850168], 
             UndirectedEdge[70, 170] -> 
             RGBColor[
              0.2774653661360603, 0.408964070502262, 0.9391126141769994], 
             UndirectedEdge[268, 441] -> 
             RGBColor[
              0.4298935905497302, 0.5467739538792281, 0.9486134173432208], 
             UndirectedEdge[394, 445] -> 
             RGBColor[
              0.2291408986849781, 0.35817199126297306`, 0.9363606072453035], 
             UndirectedEdge[234, 393] -> 
             RGBColor[
              0.42489506401207827`, 0.5422301548105988, 0.9483541347345662], 
             UndirectedEdge[228, 388] -> 
             RGBColor[
              0.9696267022726579, 0.9734928770909221, 0.7321607638451979], 
             UndirectedEdge[8, 114] -> 
             RGBColor[
              0.5604860564407306, 0.6540668560845098, 0.9585426619725401], 
             UndirectedEdge[21, 164] -> 
             RGBColor[
              0.8992062375406565, 0.5414501296947882, 0.27233399794458657`], 
             UndirectedEdge[100, 454] -> 
             RGBColor[
              0.915548639391991, 0.7016340736991815, 0.25084192040061865`], 
             UndirectedEdge[6, 267] -> 
             RGBColor[
              0.9083762130299251, 0.9201045780958312, 0.6977188544044266], 
             UndirectedEdge[210, 495] -> 
             RGBColor[
              0.8391330927044698, 0.3017996755229297, 0.18510719980929416`], 
             UndirectedEdge[112, 342] -> 
             RGBColor[
              0.25412533445039487`, 0.3844322173571471, 0.9377834339009834], 
             UndirectedEdge[93, 206] -> 
             RGBColor[
              0.30600971855859727`, 0.43582355730741806`, 0.940853232846973], 
             UndirectedEdge[485, 497] -> 
             RGBColor[
              0.24199741678266362`, 0.3716850069339687, 0.9370927669314526], 
             UndirectedEdge[36, 240] -> 
             RGBColor[
              0.25550742159800177`, 0.3858848785786683, 0.9378621417194251], 
             UndirectedEdge[275, 285] -> 
             RGBColor[
              0.36406115169331943`, 0.4897532041763907, 0.9444186325526303], 
             UndirectedEdge[36, 399] -> 
             RGBColor[
              0.24794512185068096`, 0.37793642206673694`, 0.937431479936235], 
             UndirectedEdge[72, 279] -> 
             RGBColor[
              0.26627234056032795`, 0.3971994909433567, 0.9384751879290589], 
             UndirectedEdge[278, 413] -> 
             RGBColor[
              0.9610998830487185, 0.9422076271108857, 0.6625746129461039], 
             UndirectedEdge[10, 120] -> 
             RGBColor[
              0.21319195993880496`, 0.3414086454196232, 0.9354523387780493], 
             UndirectedEdge[59, 153] -> 
             RGBColor[
              0.24356203444566857`, 0.3733295193002764, 0.9371818695927163], 
             UndirectedEdge[377, 488] -> 
             RGBColor[
              0.8752347056162003, 0.9025906545325564, 0.9472574998794909], 
             UndirectedEdge[53, 306] -> 
             RGBColor[
              0.9170459103045016, 0.6880097948516692, 0.28301334457340965`], 
             UndirectedEdge[172, 448] -> 
             RGBColor[
              0.45979588464643895`, 0.5695615806771241, 0.9513786855523698], 
             UndirectedEdge[138, 367] -> 
             RGBColor[
              0.22490572664447084`, 0.3537205569229832, 0.9361194204629721], 
             UndirectedEdge[71, 431] -> 
             RGBColor[
              0.602160734252356, 0.6860330125252593, 0.9630472221226452], 
             UndirectedEdge[180, 392] -> 
             RGBColor[
              0.2880661676144659, 0.4201061849857004, 0.9397163141387143], 
             UndirectedEdge[33, 227] -> 
             RGBColor[
              0.8620227096886874, 0.44626803209664856`, 0.20579398688200412`],
              UndirectedEdge[30, 384] -> 
             RGBColor[
              0.2758760121335012, 0.4072935586747084, 0.9390221028177923], 
             UndirectedEdge[441, 467] -> 
             RGBColor[
              0.5784857852356426, 0.6676055963951182, 0.960658898554645], 
             UndirectedEdge[99, 122] -> 
             RGBColor[
              0.930562919133284, 0.740007623770434, 0.37913808172539787`], 
             UndirectedEdge[89, 225] -> 
             RGBColor[
              0.2798755048828646, 0.4114972791367759, 0.9392498680131491], 
             UndirectedEdge[146, 497] -> 
             RGBColor[
              0.24696343657246012`, 0.3769046085968852, 0.9373755744119134], 
             UndirectedEdge[176, 197] -> 
             RGBColor[
              0.6522851143834272, 0.7277468526483104, 0.9663482548197164], 
             UndirectedEdge[326, 474] -> 
             RGBColor[
              0.9341363327937491, 0.7587482425843726, 0.49080863680582576`], 
             UndirectedEdge[173, 241] -> 
             RGBColor[
              0.8450225482014433, 0.8788658384170731, 0.9383874109586698], 
             UndirectedEdge[403, 405] -> 
             RGBColor[
              0.9614623294969025, 0.9678776355477525, 0.7913886839898783], 
             UndirectedEdge[79, 476] -> 
             RGBColor[
              0.9211605712027758, 0.6814740968415736, 0.3818708025801312], 
             UndirectedEdge[46, 257] -> 
             RGBColor[
              0.8882541401217813, 0.5816020846987996, 0.22826877228895565`], 
             UndirectedEdge[450, 491] -> 
             RGBColor[
              0.9059349577098716, 0.5635204793804358, 0.38523852750809673`], 
             UndirectedEdge[200, 243] -> 
             RGBColor[
              0.8700670583525245, 0.4728472627689348, 0.21211683898241762`], 
             UndirectedEdge[296, 424] -> 
             RGBColor[
              0.31700712622472516`, 0.4489973723195799, 0.9414203916580124], 
             UndirectedEdge[269, 466] -> 
             RGBColor[
              0.47622375697085434`, 0.5855400345383266, 0.9519420749950372], 
             UndirectedEdge[74, 453] -> 
             RGBColor[
              0.2830204227561394, 0.41480278722089764`, 0.9394289664335431], 
             UndirectedEdge[18, 469] -> 
             RGBColor[
              0.8724072991337889, 0.5135131700464854, 0.21524586162499276`], 
             UndirectedEdge[279, 481] -> 
             RGBColor[
              0.2983884604335446, 0.4300799385434647, 0.9403362145723715], 
             UndirectedEdge[19, 468] -> 
             RGBColor[
              0.5190507751439478, 0.6204278280896312, 0.9552807248464208], 
             UndirectedEdge[415, 464] -> 
             RGBColor[
              0.2654397247234546, 0.39632435890790974`, 0.9384277716888938], 
             UndirectedEdge[234, 262] -> 
             RGBColor[
              0.4323322286458682, 0.548267980100758, 0.9489396155777698], 
             UndirectedEdge[241, 417] -> 
             RGBColor[
              0.7032574015004508, 0.7681092940971459, 0.9710577835336467], 
             UndirectedEdge[309, 489] -> 
             RGBColor[
              0.9915641796444485, 0.9888374754562259, 0.6482959890771074], 
             UndirectedEdge[83, 426] -> 
             RGBColor[
              0.895460047558787, 0.9194795515806435, 0.9898909727944203], 
             UndirectedEdge[6, 99] -> 
             RGBColor[
              0.9106556765920616, 0.9271034208247384, 0.765274234275318], 
             UndirectedEdge[121, 491] -> 
             RGBColor[
              0.9108136867178351, 0.6010205284083265, 0.38991040391585896`], 
             UndirectedEdge[42, 358] -> 
             RGBColor[
              0.22905024080537584`, 0.3580767040834695, 0.9363554444131764], 
             UndirectedEdge[69, 461] -> 
             RGBColor[
              0.926959006974305, 0.9443701606295145, 0.985066529908563], 
             UndirectedEdge[161, 387] -> 
             RGBColor[
              0.8827228822801044, 0.901646814849579, 0.6975808353380122], 
             UndirectedEdge[117, 390] -> 
             RGBColor[
              0.34091437037852435`, 0.46896566133560236`, 0.9429707972165], 
             UndirectedEdge[244, 334] -> 
             RGBColor[
              0.3726225537176192, 0.4971686603012616, 0.9449641575190681], 
             UndirectedEdge[173, 493] -> 
             RGBColor[
              0.9890701085039466, 0.9882775676582451, 0.7238989830539463], 
             UndirectedEdge[229, 255] -> 
             RGBColor[
              0.34428066244060973`, 0.47097736208628804`, 0.9432183946864745],
              UndirectedEdge[39, 401] -> 
             RGBColor[
              0.6985569826136641, 0.7641508706261513, 0.9707851169753527], 
             UndirectedEdge[379, 380] -> 
             RGBColor[
              0.29107513038505384`, 0.42321764858400834`, 0.9398895428612922],
              UndirectedEdge[92, 140] -> 
             RGBColor[
              0.554385826473297, 0.649114414584719, 0.9580624295236251], 
             UndirectedEdge[78, 97] -> 
             RGBColor[
              0.22558180327383132`, 0.35443115632617517`, 0.9361579220268484],
              UndirectedEdge[395, 463] -> 
             RGBColor[
              0.2660424669485921, 0.39695787920259357`, 0.9384620969669382], 
             UndirectedEdge[174, 338] -> 
             RGBColor[
              0.29338121786998295`, 0.4246423923281867, 0.9400574530924843], 
             UndirectedEdge[143, 423] -> 
             RGBColor[
              0.1833764464098977, 0.31007065028799885`, 0.9337543893906777], 
             UndirectedEdge[94, 100] -> 
             RGBColor[
              0.943316965793535, 0.8656345224892459, 0.6119300548794735], 
             UndirectedEdge[404, 408] -> 
             RGBColor[
              0.2179764205636531, 0.3464374168886629, 0.9357248067326592], 
             UndirectedEdge[301, 389] -> 
             RGBColor[
              0.21362623144598136`, 0.3418650923080694, 0.9354770698979359], 
             UndirectedEdge[16, 422] -> 
             RGBColor[
              0.3189470428658002, 0.4437679620863825, 0.9417969982435161], 
             UndirectedEdge[389, 451] -> 
             RGBColor[
              0.21497280031897864`, 0.34328042157098726`, 0.9355537550031829],
              UndirectedEdge[74, 296] -> 
             RGBColor[
              0.2975769167094639, 0.42967045866758025`, 0.9402737595026511], 
             UndirectedEdge[225, 453] -> 
             RGBColor[
              0.2792780627176027, 0.4108693295410645, 0.939215844565674], 
             UndirectedEdge[340, 378] -> 
             RGBColor[
              0.31025949401998754`, 0.4407803246133216, 0.9410773105637218], 
             UndirectedEdge[52, 428] -> 
             RGBColor[
              0.8330642703587228, 0.25515204759860854`, 0.17929568867725226`],
              UndirectedEdge[84, 230] -> 
             RGBColor[
              0.22859615804425376`, 0.3575994343110202, 0.9363295850716857], 
             UndirectedEdge[119, 237] -> 
             RGBColor[
              0.9483698835729416, 0.9591789791220269, 0.8977829179807035], 
             UndirectedEdge[67, 171] -> 
             RGBColor[
              0.25918264815811415`, 0.38974777471616917`, 0.9380714404350129],
              UndirectedEdge[25, 157] -> 
             RGBColor[
              0.3079594456965586, 0.4405872728097553, 0.9408648783928987], 
             UndirectedEdge[124, 484] -> 
             RGBColor[
              0.9777721242086441, 0.9364424046411297, 0.38854804229456463`], 
             UndirectedEdge[368, 500] -> 
             RGBColor[
              0.6137971561371982, 0.33936679556971105`, 0.5567621778131115], 
             UndirectedEdge[283, 422] -> 
             RGBColor[
              0.207613081778549, 0.3355448907518888, 0.9351346299200334], 
             UndirectedEdge[334, 369] -> 
             RGBColor[
              0.4113757512055576, 0.5307347321729735, 0.9474334769948924], 
             UndirectedEdge[42, 346] -> 
             RGBColor[
              0.22517846281523107`, 0.3540072199309242, 0.9361349523844199], 
             UndirectedEdge[112, 263] -> 
             RGBColor[
              0.2608320887293601, 0.39148144133712115`, 0.9381653736354167], 
             UndirectedEdge[146, 201] -> 
             RGBColor[
              0.28119600247616383`, 0.41288520583171645`, 0.9393250683975864],
              UndirectedEdge[16, 243] -> 
             RGBColor[
              0.6215940953786275, 0.41368682466407874`, 0.566114433864064], 
             UndirectedEdge[285, 481] -> 
             RGBColor[
              0.3163175193458222, 0.44840006950172373`, 0.9413764505174842], 
             UndirectedEdge[231, 444] -> 
             RGBColor[
              0.2648697036740537, 0.39572523064356746`, 0.938395309833401], 
             UndirectedEdge[137, 408] -> 
             RGBColor[
              0.2212925375899113, 0.34992286613722345`, 0.9359136546915492], 
             UndirectedEdge[431, 436] -> 
             RGBColor[
              0.46072987194196846`, 0.5729505557434673, 0.9507253360979548], 
             UndirectedEdge[98, 277] -> 
             RGBColor[
              0.8832681348130269, 0.9067408984138945, 0.8502742951726139], 
             UndirectedEdge[131, 391] -> 
             RGBColor[
              0.2523681386345833, 0.3825852931420795, 0.9376833641988113], 
             UndirectedEdge[52, 227] -> 
             RGBColor[
              0.8407131059122084, 0.31394434940381033`, 0.18662022224139424`],
              UndirectedEdge[27, 419] -> 
             RGBColor[
              0.5124047260338506, 0.6150322660209537, 0.9547575235151939], 
             UndirectedEdge[232, 312] -> 
             RGBColor[
              0.3303045820158528, 0.4601142095117522, 0.9422823672274991], 
             UndirectedEdge[247, 466] -> 
             RGBColor[
              0.4992597773340883, 0.6043606044932961, 0.953722705002015], 
             UndirectedEdge[253, 484] -> 
             RGBColor[
              0.9889617727140382, 0.9876413426482502, 0.6827040059696212], 
             UndirectedEdge[121, 200] -> 
             RGBColor[
              0.8641469744095227, 0.4273429033856967, 0.2064477599128205], 
             UndirectedEdge[79, 99] -> 
             RGBColor[
              0.9937251243023482, 0.9889870003070016, 0.5583966882336657], 
             UndirectedEdge[109, 300] -> 
             RGBColor[
              0.23995882574419874`, 0.3695423184984049, 0.9369766721876371], 
             UndirectedEdge[31, 397] -> 
             RGBColor[
              0.40579315804314603`, 0.5258993705649835, 0.947077759095077], 
             UndirectedEdge[70, 374] -> 
             RGBColor[
              0.2549902427614091, 0.38534129083037727`, 0.9378326891497786], 
             UndirectedEdge[240, 352] -> 
             RGBColor[
              0.24222822396059346`, 0.3719275999119933, 0.937105911058787], 
             UndirectedEdge[105, 323] -> 
             RGBColor[
              0.24262496833818112`, 0.37234460340788433`, 0.93712850506416], 
             UndirectedEdge[46, 53] -> 
             RGBColor[
              0.9470835767696775, 0.821834287485996, 0.3079282681448157], 
             UndirectedEdge[221, 223] -> 
             RGBColor[
              0.46323693275442124`, 0.5733927057392445, 0.9513629056103252], 
             UndirectedEdge[33, 159] -> 
             RGBColor[
              0.8495822086293704, 0.3506448894924134, 0.19388094901806585`], 
             UndirectedEdge[16, 454] -> 
             RGBColor[
              0.6518822537994468, 0.581257698540845, 0.5925638840512331], 
             UndirectedEdge[195, 224] -> 
             RGBColor[
              0.28455910865490164`, 0.41642004365881735`, 0.9395165923191959],
              UndirectedEdge[259, 500] -> 
             RGBColor[
              0.8406666807462297, 0.3081837142621151, 0.18636416654762122`], 
             UndirectedEdge[24, 77] -> 
             RGBColor[
              0.7218949448567346, 0.7822619477143448, 0.9732512022240677], 
             UndirectedEdge[226, 386] -> 
             RGBColor[
              0.1791759961486071, 0.30565571073945375`, 0.9335151799623065], 
             UndirectedEdge[289, 314] -> 
             RGBColor[
              0.3847232625603534, 0.5076496861015274, 0.9457352039862904], 
             UndirectedEdge[179, 325] -> 
             RGBColor[
              0.1789730287155782, 0.30544237909846184`, 0.9335036212672588], 
             UndirectedEdge[81, 83] -> 
             RGBColor[
              0.8721819244967113, 0.9009182081187621, 0.9876706846361336], 
             UndirectedEdge[312, 376] -> 
             RGBColor[
              0.2919333190231436, 0.4241708063077816, 0.9399365426905006], 
             UndirectedEdge[270, 309] -> 
             RGBColor[
              0.9915269265441726, 0.9888220703419007, 0.6489133693566129], 
             UndirectedEdge[139, 269] -> 
             RGBColor[
              0.506487260336648, 0.6101093099259678, 0.9543245288388581], 
             UndirectedEdge[269, 425] -> 
             RGBColor[
              0.4121410951718726, 0.5313976346492894, 0.947482244035659], 
             UndirectedEdge[25, 492] -> 
             RGBColor[
              0.29499729755319337`, 0.42696323326341856`, 0.9401267032319138],
              UndirectedEdge[142, 173] -> 
             RGBColor[
              0.8420436305365226, 0.8765386852966244, 0.9380905002853989], 
             UndirectedEdge[132, 209] -> 
             RGBColor[
              0.7780282420345992, 0.8243344980363514, 0.8860787195432924], 
             UndirectedEdge[389, 409] -> 
             RGBColor[
              0.23002772223876133`, 0.35910409904586005`, 0.9364111105347535],
              UndirectedEdge[337, 370] -> 
             RGBColor[
              0.7258270188663856, 0.785286025150145, 0.9737542955576297], 
             UndirectedEdge[230, 242] -> 
             RGBColor[
              0.2244428247428983, 0.35323401767475476`, 0.9360930588844796], 
             UndirectedEdge[28, 461] -> 
             RGBColor[
              0.954655789916814, 0.9657029428810652, 0.9616400993934879], 
             UndirectedEdge[318, 350] -> 
             RGBColor[
              0.3520561578815369, 0.47935508192515797`, 0.9436536849625428], 
             UndirectedEdge[390, 478] -> 
             RGBColor[
              0.2833977050944594, 0.41519933487955374`, 0.9394504521045712], 
             UndirectedEdge[167, 434] -> 
             RGBColor[
              0.988936416573675, 0.989692938179159, 0.8330157392176978], 
             UndirectedEdge[247, 269] -> 
             RGBColor[
              0.47197536116157857`, 0.5820909954323062, 0.9516076257145445], 
             UndirectedEdge[394, 398] -> 
             RGBColor[
              0.24489676758341208`, 0.3747324084550136, 0.93725788067035], 
             UndirectedEdge[14, 158] -> 
             RGBColor[
              0.33213200521333075`, 0.4619125616859979, 0.9423909174068014], 
             UndirectedEdge[131, 433] -> 
             RGBColor[
              0.29455765065289613`, 0.4253795454830047, 0.9401427329325757], 
             UndirectedEdge[87, 422] -> 
             RGBColor[
              0.2066326331143824, 0.33451437704181397`, 0.9350787948190529], 
             UndirectedEdge[210, 469] -> 
             RGBColor[
              0.8482471960053599, 0.3686686083126496, 0.19371011734270402`], 
             UndirectedEdge[312, 414] -> 
             RGBColor[
              0.2895347527456831, 0.421649761072285, 0.9397999478893602], 
             UndirectedEdge[277, 311] -> 
             RGBColor[
              0.7590792000371321, 0.8117177073753836, 0.9766215787274166], 
             UndirectedEdge[332, 424] -> 
             RGBColor[
              0.36139324266635137`, 0.48744239547023754`, 0.9442486357485711],
              UndirectedEdge[328, 433] -> 
             RGBColor[
              0.35540962848104596`, 0.48225968960811955`, 0.9438673651437858],
              UndirectedEdge[88, 428] -> 
             RGBColor[
              0.8484718113152332, 0.36067584148776255`, 0.1935446274280821], 
             UndirectedEdge[8, 162] -> 
             RGBColor[
              0.5411625228784538, 0.6383791410233868, 0.9570214426260819], 
             UndirectedEdge[27, 289] -> 
             RGBColor[
              0.47574498443284424`, 0.5848915439571711, 0.9519761681862727], 
             UndirectedEdge[192, 280] -> 
             RGBColor[
              0.25575350846358835`, 0.3861435314772083, 0.9378761560023672], 
             UndirectedEdge[347, 477] -> 
             RGBColor[
              0.2117993137193227, 0.3399448859440771, 0.9353730296360853], 
             UndirectedEdge[145, 346] -> 
             RGBColor[
              0.21927041175810352`, 0.3477974836778107, 0.9357984976168947], 
             UndirectedEdge[232, 415] -> 
             RGBColor[
              0.3216051563189196, 0.45097056152882875`, 0.9417869478037058], 
             UndirectedEdge[189, 374] -> 
             RGBColor[
              0.2557528431125027, 0.3861428321510315, 0.9378761181116072], 
             UndirectedEdge[139, 140] -> 
             RGBColor[
              0.5318346221124927, 0.6308063309644387, 0.9562871161085591], 
             UndirectedEdge[134, 251] -> 
             RGBColor[
              0.24587579480159133`, 0.37576142813523083`, 0.9373136348220843],
              UndirectedEdge[67, 281] -> 
             RGBColor[
              0.25076586641156884`, 0.38090120344576484`, 0.93759211716606], 
             UndirectedEdge[167, 495] -> 
             RGBColor[0.9144363630663, 0.657074043523211, 0.5293091727449846],
              UndirectedEdge[143, 179] -> 
             RGBColor[
              0.17892806920489446`, 0.30539512380213557`, 0.933501060889637], 
             UndirectedEdge[21, 175] -> 
             RGBColor[
              0.9683090151158134, 0.9568481859192783, 0.670037151361724], 
             UndirectedEdge[366, 473] -> 
             RGBColor[
              0.29591877827497415`, 0.42668767083692927`, 0.940224732684648], 
             UndirectedEdge[143, 292] -> 
             RGBColor[
              0.1789488167630598, 0.30541693080123855`, 0.9335022424323813], 
             UndirectedEdge[267, 486] -> 
             RGBColor[
              0.9619951023866931, 0.9628588250229391, 0.7028330719374227], 
             UndirectedEdge[248, 380] -> 
             RGBColor[
              0.257695358998007, 0.3881845395093172, 0.937986741517592], 
             UndirectedEdge[48, 407] -> 
             RGBColor[
              0.2109346093646478, 0.33903602684189116`, 0.935323786002302], 
             UndirectedEdge[436, 459] -> 
             RGBColor[
              0.4317329658175249, 0.5478348930853527, 0.9488776788806625], 
             UndirectedEdge[235, 262] -> 
             RGBColor[
              0.416563768888231, 0.5346101328045243, 0.9479348632655147], 
             UndirectedEdge[236, 283] -> 
             RGBColor[
              0.23426865806856206`, 0.3635615914938426, 0.9366526255563583], 
             UndirectedEdge[99, 493] -> 
             RGBColor[
              0.9935993972524345, 0.9887180828601909, 0.5447120747479771], 
             UndirectedEdge[109, 456] -> 
             RGBColor[
              0.23880926652767986`, 0.3683340588755796, 0.9369112064908769], 
             UndirectedEdge[208, 289] -> 
             RGBColor[
              0.3807447886449092, 0.5042037319598828, 0.9454816991464247], 
             UndirectedEdge[266, 410] -> 
             RGBColor[
              0.326592877843097, 0.45552256223454524`, 0.9420962704893343], 
             UndirectedEdge[299, 301] -> 
             RGBColor[
              0.20895952840977988`, 0.3369600915309596, 0.9352113080637927], 
             UndirectedEdge[314, 359] -> 
             RGBColor[
              0.3577633677707141, 0.48429838027845357`, 0.9440173433299934], 
             UndirectedEdge[209, 214] -> 
             RGBColor[
              0.3828653435329973, 0.49291080046599856`, 0.946830407391962], 
             UndirectedEdge[210, 326] -> 
             RGBColor[
              0.8556196126725499, 0.40214503052670025`, 0.19986184252427644`],
              UndirectedEdge[53, 317] -> 
             RGBColor[
              0.9299563150856899, 0.7479312815030192, 0.29383694306613123`], 
             UndirectedEdge[402, 459] -> 
             RGBColor[
              0.4714286755649022, 0.5800616585296188, 0.952002670562152], 
             UndirectedEdge[89, 249] -> 
             RGBColor[
              0.28752479280706156`, 0.41953716573797317`, 0.9396854836443249],
              UndirectedEdge[67, 135] -> 
             RGBColor[
              0.2536249197696536, 0.3839062497995648, 0.9377549360252124], 
             UndirectedEdge[90, 178] -> 
             RGBColor[
              0.9282272067510295, 0.7348311823756897, 0.4981717768803556], 
             UndirectedEdge[174, 229] -> 
             RGBColor[
              0.2788164534778155, 0.4103841489623319, 0.9391895566023578], 
             UndirectedEdge[266, 364] -> 
             RGBColor[
              0.2740437091478759, 0.405367692062097, 0.9389177558734103], 
             UndirectedEdge[407, 430] -> 
             RGBColor[
              0.22704868393744712`, 0.35597294090924125`, 0.9362414587105858],
              UndirectedEdge[217, 355] -> 
             RGBColor[
              0.32421328138501737`, 0.4552389817275355, 0.9418795614926734], 
             UndirectedEdge[176, 426] -> 
             RGBColor[
              0.7385594994235554, 0.7955507282121491, 0.9748396268265297], 
             UndirectedEdge[280, 483] -> 
             RGBColor[
              0.2767707745378052, 0.40823401069284493`, 0.939073058213035], 
             UndirectedEdge[51, 347] -> 
             RGBColor[
              0.1789270004053139, 0.3053940004260106, 0.9335010000230821], 
             UndirectedEdge[152, 451] -> 
             RGBColor[
              0.20772437674817806`, 0.3356618688214776, 0.9351409680039076], 
             UndirectedEdge[105, 342] -> 
             RGBColor[
              0.252946206923672, 0.38319287956555814`, 0.9377162843326995], 
             UndirectedEdge[318, 496] -> 
             RGBColor[
              0.3094159330482752, 0.43947691523709653`, 0.9410445311268166], 
             UndirectedEdge[114, 289] -> 
             RGBColor[
              0.47002476811242727`, 0.580247614655448, 0.9515258518036867], 
             UndirectedEdge[103, 331] -> 
             RGBColor[
              0.6585237003454188, 0.7308163449939742, 0.968260051050067], 
             UndirectedEdge[107, 113] -> 
             RGBColor[
              0.18193197659231264`, 0.3085524209250408, 0.9336721289714678], 
             UndirectedEdge[16, 56] -> 
             RGBColor[
              0.6202778449645745, 0.4035695471970573, 0.5648539909810746], 
             UndirectedEdge[140, 370] -> 
             RGBColor[
              0.5455387009707735, 0.6419319195433083, 0.9573659513959778], 
             UndirectedEdge[213, 500] -> 
             RGBColor[
              0.8618492799802115, 0.40436895006188167`, 0.20403944658147605`],
              UndirectedEdge[280, 327] -> 
             RGBColor[
              0.25698076875714937`, 0.3874334598585377, 0.9379460466605166], 
             UndirectedEdge[76, 238] -> 
             RGBColor[
              0.36573961104663694`, 0.49120700130641426`, 0.9445255824984202],
              UndirectedEdge[253, 261] -> 
             RGBColor[
              0.9325093316648222, 0.7680041432668934, 0.5596474808987255], 
             UndirectedEdge[232, 350] -> 
             RGBColor[
              0.3591838096222978, 0.48552869561681206`, 0.944107852628729], 
             UndirectedEdge[166, 320] -> 
             RGBColor[
              0.9133614547699682, 0.6417853106074096, 0.5113435478107814], 
             UndirectedEdge[33, 119] -> 
             RGBColor[
              0.9345308133147854, 0.7655949021985857, 0.5124594755699873], 
             UndirectedEdge[71, 228] -> 
             RGBColor[
              0.8744314209010298, 0.8983757407693698, 0.7323068273714743], 
             UndirectedEdge[50, 244] -> 
             RGBColor[
              0.3916895278498226, 0.5136835149605915, 0.9461790882505088], 
             UndirectedEdge[235, 344] -> 
             RGBColor[
              0.4103923521286693, 0.5295998986599555, 0.9474490267315575], 
             UndirectedEdge[72, 494] -> 
             RGBColor[
              0.25624399533436604`, 0.3866590642770594, 0.9379040885040477], 
             UndirectedEdge[185, 496] -> 
             RGBColor[
              0.2804171463023576, 0.4120665786107125, 0.9392807136907027], 
             UndirectedEdge[106, 370] -> 
             RGBColor[
              0.5546493379031965, 0.6493283450345659, 0.9580831741086608], 
             UndirectedEdge[51, 113] -> 
             RGBColor[
              0.17905963075308248`, 0.3055334033307651, 0.9335085531251784], 
             UndirectedEdge[422, 443] -> 
             RGBColor[
              0.5842619922483114, 0.5706803433206208, 0.6014015077150748], 
             UndirectedEdge[4, 335] -> 
             RGBColor[
              0.3005379095306292, 0.4317763657356928, 0.9404792286546308], 
             UndirectedEdge[1, 84] -> 
             RGBColor[
              0.249739891419232, 0.3798228386782472, 0.9375336894080404], 
             UndirectedEdge[90, 272] -> 
             RGBColor[
              0.8426763546129947, 0.3190239891395971, 0.18810823554711417`], 
             UndirectedEdge[213, 450] -> 
             RGBColor[
              0.8609571905590665, 0.3975119598548832, 0.20318518074431657`], 
             UndirectedEdge[5, 212] -> 
             RGBColor[
              0.22856179646777947`, 0.35756331811549596`, 0.9363276282307389],
              UndirectedEdge[50, 106] -> 
             RGBColor[
              0.47939668252268425`, 0.5878987040064534, 0.9522518873645769], 
             UndirectedEdge[115, 291] -> 
             RGBColor[
              0.7880477603543681, 0.8351660025398585, 0.9792918656511329], 
             UndirectedEdge[9, 117] -> 
             RGBColor[
              0.4781094761010015, 0.5852282777412916, 0.9525996605197433], 
             UndirectedEdge[194, 388] -> 
             RGBColor[
              0.9663440953419832, 0.9740339462184904, 0.9245637966956991], 
             UndirectedEdge[202, 211] -> 
             RGBColor[
              0.2350487330765592, 0.3643814997868598, 0.9366970496740461], 
             UndirectedEdge[113, 308] -> 
             RGBColor[
              0.17906927273157397`, 0.3055435376614964, 0.9335091022215896], 
             UndirectedEdge[51, 421] -> 
             RGBColor[
              0.17899180329589925`, 0.30546211237275633`, 0.9335046904518336],
              UndirectedEdge[109, 335] -> 
             RGBColor[
              0.2653660882581673, 0.3962469623140712, 0.938423578201131], 
             UndirectedEdge[278, 329] -> 
             RGBColor[
              0.9154608124727537, 0.9351010298249371, 0.9804756251775316], 
             UndirectedEdge[129, 206] -> 
             RGBColor[
              0.3491669657996257, 0.47685260895882275`, 0.9434695881978956], 
             UndirectedEdge[166, 227] -> 
             RGBColor[
              0.8418757895124331, 0.32288124504634075`, 0.18773360937003286`],
              UndirectedEdge[294, 411] -> 
             RGBColor[
              0.23895135352540886`, 0.3684834013190287, 0.9369192981351986], 
             UndirectedEdge[362, 384] -> 
             RGBColor[
              0.33614117025697976`, 0.4632658145057482, 0.9427239752429382], 
             UndirectedEdge[143, 308] -> 
             RGBColor[
              0.17893664305769685`, 0.3054041354650445, 0.9335015491578702], 
             UndirectedEdge[151, 310] -> 
             RGBColor[
              0.3017756973424442, 0.43451576996419494`, 0.9404970515752908], 
             UndirectedEdge[297, 397] -> 
             RGBColor[
              0.4389561312944613, 0.5528301617459719, 0.9496863711644075], 
             UndirectedEdge[114, 359] -> 
             RGBColor[
              0.443064873322788, 0.5568963088323743, 0.9498079911473898], 
             UndirectedEdge[141, 220] -> 
             RGBColor[
              0.32424804297229537`, 0.4552690904672675, 0.9418817764702763], 
             UndirectedEdge[122, 493] -> 
             RGBColor[
              0.9305407827762575, 0.7399602763410837, 0.37672867587283654`], 
             UndirectedEdge[146, 442] -> 
             RGBColor[
              0.2709392779878975, 0.40210473808065567`, 0.9387409631114438], 
             UndirectedEdge[294, 478] -> 
             RGBColor[
              0.25217734273393444`, 0.38238475455333876`, 0.9376724986545265],
              UndirectedEdge[76, 487] -> 
             RGBColor[
              0.49537833953651855`, 0.6000692782186605, 0.9537321847167134], 
             UndirectedEdge[67, 70] -> 
             RGBColor[
              0.25743661729140077`, 0.3879125855705024, 0.9379720065601748], 
             UndirectedEdge[346, 358] -> 
             RGBColor[
              0.2217544347167852, 0.3504083493035373, 0.935939959049609], 
             UndirectedEdge[149, 165] -> 
             RGBColor[
              0.3889540140770109, 0.511314150421502, 0.9460047837318252], 
             UndirectedEdge[175, 375] -> 
             RGBColor[
              0.9569658514087618, 0.9674257829593813, 0.9577297678481509], 
             UndirectedEdge[18, 428] -> 
             RGBColor[
              0.8573587081531882, 0.40102916444142644`, 0.2009600719874468], 
             UndirectedEdge[2, 47] -> 
             RGBColor[
              0.22219066917343752`, 0.3508668593763409, 0.9359648019565643], 
             UndirectedEdge[140, 466] -> 
             RGBColor[
              0.5015711187466989, 0.6062370555767975, 0.9539046622647382], 
             UndirectedEdge[199, 382] -> 
             RGBColor[
              0.31253428709090747`, 0.4426711481132517, 0.9412251688089472], 
             UndirectedEdge[305, 499] -> 
             RGBColor[
              0.2559152551896322, 0.3863135375416151, 0.9378853672391325], 
             UndirectedEdge[252, 282] -> 
             RGBColor[
              0.6717272001021579, 0.7429460920325152, 0.9682785844173988], 
             UndirectedEdge[235, 249] -> 
             RGBColor[
              0.32329479630323715`, 0.4526684377082041, 0.9418860278221313], 
             UndirectedEdge[130, 214] -> 
             RGBColor[
              0.1893670574265447, 0.316367162293171, 0.9340955458257609], 
             UndirectedEdge[100, 475] -> 
             RGBColor[
              0.8851091218155209, 0.5328997870260774, 0.22424752851506258`], 
             UndirectedEdge[10, 438] -> 
             RGBColor[
              0.22021348611856342`, 0.3487887146250221, 0.9358522043065695], 
             UndirectedEdge[39, 179] -> 
             RGBColor[
              0.40129536230508595`, 0.5053759222252174, 0.9485085964517164], 
             UndirectedEdge[400, 414] -> 
             RGBColor[
              0.28528989827003975`, 0.41718814987906533`, 0.9395582097066717],
              UndirectedEdge[41, 191] -> 
             RGBColor[
              0.22546402831064583`, 0.35430736737250323`, 0.9361512149169275],
              UndirectedEdge[25, 96] -> 
             RGBColor[
              0.3047685081778331, 0.4372333951604509, 0.9406831592217764], 
             UndirectedEdge[106, 274] -> 
             RGBColor[
              0.49029479958875166`, 0.5970824316919869, 0.9530169491141065], 
             UndirectedEdge[204, 363] -> 
             RGBColor[
              0.4533522044192463, 0.5657736996191047, 0.9504726028052438], 
             UndirectedEdge[99, 413] -> 
             RGBColor[
              0.9837287794830555, 0.9560851708017216, 0.4499899045367475], 
             UndirectedEdge[37, 118] -> 
             RGBColor[
              0.31537415178862416`, 0.44729581939211016`, 0.9413268540323092],
              UndirectedEdge[411, 478] -> 
             RGBColor[
              0.2528159536736963, 0.3830559751413007, 0.9377088666028057], 
             UndirectedEdge[300, 451] -> 
             RGBColor[
              0.21870173252116284`, 0.3471997657434399, 0.9357661121756364], 
             UndirectedEdge[122, 233] -> 
             RGBColor[
              0.8553320507775657, 0.4120002528594733, 0.20005892957140564`], 
             UndirectedEdge[97, 404] -> 
             RGBColor[
              0.2225914076005732, 0.3512880608715443, 0.9359876234171504], 
             UndirectedEdge[362, 498] -> 
             RGBColor[
              0.4251755260464191, 0.5424546669097134, 0.9483770922703834], 
             UndirectedEdge[121, 454] -> 
             RGBColor[
              0.8636741838299911, 0.42519607178708907`, 0.20605325186410173`],
              UndirectedEdge[173, 417] -> 
             RGBColor[
              0.8427978094114925, 0.8771278555657226, 0.9381656697874536], 
             UndirectedEdge[36, 352] -> 
             RGBColor[
              0.2411100918235177, 0.37075237214225454`, 0.9370422350877088], 
             UndirectedEdge[309, 337] -> 
             RGBColor[
              0.926620732552479, 0.9394372573300418, 0.7346744089406012], 
             UndirectedEdge[207, 456] -> 
             RGBColor[
              0.2203607616298221, 0.3489435105251617, 0.9358605914290611], 
             UndirectedEdge[95, 97] -> 
             RGBColor[
              0.22940871371662525`, 0.3584534818416879, 0.936375858915159], 
             UndirectedEdge[185, 350] -> 
             RGBColor[
              0.3230573711356193, 0.45194474529877393`, 0.9418898675264287], 
             UndirectedEdge[303, 435] -> 
             RGBColor[
              0.2816881021628791, 0.4134024338033765, 0.9393530927467486], 
             UndirectedEdge[14, 441] -> 
             RGBColor[
              0.3784375409652084, 0.5020200893703757, 0.9453414651985335], 
             UndirectedEdge[67, 147] -> 
             RGBColor[
              0.2540581203038455, 0.3843615710275007, 0.9377796061547718], 
             UndirectedEdge[115, 419] -> 
             RGBColor[
              0.7169294577871506, 0.7776214885576594, 0.9735615399917263], 
             UndirectedEdge[113, 209] -> 
             RGBColor[
              0.3725579164542212, 0.4820770410775821, 0.9462434146682975], 
             UndirectedEdge[100, 121] -> 
             RGBColor[
              0.8793403970281699, 0.48855884043917713`, 0.2187233911438525], 
             UndirectedEdge[39, 254] -> 
             RGBColor[
              0.43007991849913185`, 0.5356303158314321, 0.9501478343440324], 
             UndirectedEdge[2, 339] -> 
             RGBColor[
              0.21206918576719214`, 0.340228538577264, 0.9353883984499716], 
             UndirectedEdge[76, 436] -> 
             RGBColor[
              0.4421225577048329, 0.5568338353820671, 0.9495396944885663], 
             UndirectedEdge[121, 161] -> 
             RGBColor[
              0.9088989497892817, 0.5955852022276555, 0.2954383174204215], 
             UndirectedEdge[215, 430] -> 
             RGBColor[
              0.26193106415637823`, 0.3926365341899838, 0.9382279586601969], 
             UndirectedEdge[100, 254] -> 
             RGBColor[
              0.5838565510201338, 0.5654509378756822, 0.6001458285837606], 
             UndirectedEdge[186, 389] -> 
             RGBColor[
              0.22710509641847854`, 0.3560322340035631, 0.9362446713179258], 
             UndirectedEdge[197, 426] -> 
             RGBColor[
              0.7839000078483491, 0.8315135813435113, 0.9789878324723824], 
             UndirectedEdge[316, 378] -> 
             RGBColor[
              0.26678973270236006`, 0.397743302889189, 0.9385046526461347], 
             UndirectedEdge[185, 330] -> 
             RGBColor[
              0.29519715135054264`, 0.42760130102279975`, 0.9401224131131387],
              UndirectedEdge[56, 166] -> 
             RGBColor[
              0.8373970102117498, 0.28845538472768467`, 0.18344472525364075`],
              UndirectedEdge[38, 73] -> 
             RGBColor[
              0.25393957190424143`, 0.3842369691431141, 0.937772854998791], 
             UndirectedEdge[97, 430] -> 
             RGBColor[
              0.23573676666398502`, 0.3651046667110934, 0.9367362321689956], 
             UndirectedEdge[222, 372] -> 
             RGBColor[
              0.4565833875774816, 0.5694260572148426, 0.9504426196097452], 
             UndirectedEdge[137, 430] -> 
             RGBColor[
              0.22990978373834364`, 0.3589801382041882, 0.9364043941116291], 
             UndirectedEdge[30, 355] -> 
             RGBColor[
              0.29831901354920054`, 0.4290370635324922, 0.9403677718036725], 
             UndirectedEdge[111, 442] -> 
             RGBColor[
              0.2785182841132166, 0.41007075405510884`, 0.939172576298146], 
             UndirectedEdge[183, 408] -> 
             RGBColor[
              0.21373593745192992`, 0.3419804002760839, 0.9354833174926791], 
             UndirectedEdge[39, 283] -> 
             RGBColor[
              0.4024378733893724, 0.5065767738141891, 0.9485736607677728], 
             UndirectedEdge[244, 498] -> 
             RGBColor[
              0.40216527018839365`, 0.5225243398145787, 0.9469108991142803], 
             UndirectedEdge[259, 454] -> 
             RGBColor[
              0.8808615626968692, 0.5519020063430116, 0.22230030637499004`], 
             UndirectedEdge[17, 418] -> 
             RGBColor[
              0.9292223734187801, 0.9452976774305406, 0.9548682913375369], 
             UndirectedEdge[70, 391] -> 
             RGBColor[
              0.24968869542225258`, 0.3797690284394081, 0.93753077387175], 
             UndirectedEdge[18, 495] -> 
             RGBColor[
              0.8632931958328989, 0.4466442372567656, 0.2066429440915829], 
             UndirectedEdge[48, 95] -> 
             RGBColor[
              0.21729689825533816`, 0.34572319585842115`, 0.9356861089424638],
              UndirectedEdge[50, 92] -> 
             RGBColor[
              0.5250378077135244, 0.6249522255456361, 0.9558449239285502], 
             UndirectedEdge[118, 141] -> 
             RGBColor[
              0.31734549257895406`, 0.4492904482488255, 0.9414419520628983], 
             UndirectedEdge[373, 398] -> 
             RGBColor[
              0.27738327375901567`, 0.40887778620903076`, 0.9391079391375716],
              UndirectedEdge[218, 409] -> 
             RGBColor[
              0.2367642996218614, 0.3661846689991738, 0.9367947486508479]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.2206581667895666, 0.3492561022046294, 0.935877528212937], 316 -> 
             RGBColor[
              0.2504950392509415, 0.38061654692851177`, 0.937576693959915], 
             308 -> RGBColor[
              0.17894628476761076`, 0.30541426951348377`, 0.9335020982389862],
              160 -> RGBColor[
              0.42248174875901884`, 0.5403541890501141, 0.948141141338351], 
             245 -> RGBColor[
              0.22156287013367681`, 0.3502070027807943, 0.9359290497299955], 
             155 -> RGBColor[
              0.5658891207695752, 0.6584533071119401, 0.9589680109885835], 
             425 -> RGBColor[
              0.37534284954540054`, 0.499524843821242, 0.9451374923637511], 
             213 -> RGBColor[
              0.90420589766789, 0.657903179238463, 0.24177939169682186`], 352 -> 
             RGBColor[
              0.2278308941861094, 0.35679509347557953`, 0.9362860044270709], 
             27 -> RGBColor[
              0.5121189165844965, 0.6148002330343991, 0.9547350235483862], 
             485 -> RGBColor[
              0.24800119075484597`, 0.3779953540399882, 0.9374346729773807], 
             454 -> RGBColor[
              0.8998824261938122, 0.6382713050470934, 0.23817178112086787`], 
             367 -> RGBColor[
              0.2298450608433424, 0.3589121103378734, 0.9364007082385077], 19 -> 
             RGBColor[
              0.5597245266210166, 0.6534486118703385, 0.9584827115555565], 
             164 -> RGBColor[
              0.8175247092939038, 0.13570817177533162`, 0.16441498745215766`],
              190 -> RGBColor[
              0.24810961844878143`, 0.3781093184210272, 0.9374408477741458], 
             103 -> RGBColor[
              0.4803557055985901, 0.589013427439692, 0.9522345072271], 138 -> 
             RGBColor[
              0.2199663924455993, 0.34852900350809307`, 0.9358381326874365], 
             416 -> RGBColor[
              0.26153368469451344`, 0.39221886318025073`, 0.938205328487714], 
             476 -> RGBColor[
              0.8484924274103163, 0.3737396233586853, 0.19406970929346942`], 
             291 -> RGBColor[
              0.6549271406176395, 0.7303533269719065, 0.9662406748008145], 28 -> 
             RGBColor[
              0.9648560740830788, 0.9733102981108331, 0.9443736789601879], 
             337 -> RGBColor[
              0.860210700141258, 0.8913726787679522, 0.9865288585702724], 195 -> 
             RGBColor[
              0.2701519252165497, 0.40127718039692006`, 0.9386961245358997], 
             114 -> RGBColor[
              0.5006784839436625, 0.605512374430953, 0.9538343907832142], 479 -> 
             RGBColor[
              0.41149067372934756`, 0.5308342722869064, 0.9474407997564864], 
             93 -> RGBColor[
              0.26928527939714464`, 0.4003662806922068, 0.9386467703385721], 
             34 -> 
             RGBColor[
              0.5437530683305409, 0.6404822625241338, 0.9572253798535508], 
             161 -> RGBColor[
              0.9903319581123935, 0.9790495659282263, 0.41694191223350735`], 
             22 -> RGBColor[
              0.4514165271362265, 0.5654160397762044, 0.9499848398305268], 
             124 -> RGBColor[
              0.9626525497894284, 0.8856804222207267, 0.30941263771645156`], 
             84 -> RGBColor[
              0.2333142933423989, 0.36255849365642656`, 0.9365982758970595], 
             46 -> RGBColor[
              0.9176548470302313, 0.7112359389100995, 0.2526013609126037], 
             241 -> RGBColor[
              0.7054821402904016, 0.7698472769484965, 0.9712795247048629], 
             185 -> RGBColor[
              0.2839447494602888, 0.41577431319265656`, 0.9394816054719256], 
             426 -> RGBColor[
              0.8701743928884773, 0.8993174569073501, 0.9874792044791957], 
             390 -> RGBColor[
              0.30075346730669683`, 0.43344134138349677`, 0.9404388370870089],
              121 -> RGBColor[
              0.8274659414661699, 0.21212083852708477`, 0.1739347226073356], 
             322 -> RGBColor[
              0.25921854913182885`, 0.38978550891579644`, 0.9380734849423552],
              488 -> RGBColor[
              0.7693643004981994, 0.8197525060252281, 0.9776467014216474], 
             126 -> RGBColor[
              0.2511378152607278, 0.38129214526915, 0.9376132991027705], 433 -> 
             RGBColor[
              0.32550625142704326`, 0.4563588873913744, 0.9419619484004228], 
             236 -> RGBColor[
              0.28732315690654525`, 0.419325233622076, 0.939674000778084], 78 -> 
             RGBColor[
              0.21942909899518986`, 0.3479642740253404, 0.9358075346202901], 
             376 -> RGBColor[
              0.2794551004482275, 0.4110554074207916, 0.9392259266025292], 
             458 -> RGBColor[
              0.2304992557221517, 0.359599710633853, 0.9364379636690613], 254 -> 
             RGBColor[
              0.23649824945009773`, 0.365905033400095, 0.9367795974871519], 
             290 -> RGBColor[
              0.2864852402250885, 0.41844453006287885`, 0.9396262826626617], 
             251 -> RGBColor[
              0.25854520282865096`, 0.38907777925853504`, 0.9380351388665158],
              165 -> RGBColor[
              0.4240332554553848, 0.5416980261695123, 0.9482400019731], 460 -> 
             RGBColor[
              0.24834625332605567`, 0.3783580366805602, 0.9374543237803367], 
             100 -> 
             RGBColor[
              0.9312148525901699, 0.7649968423512695, 0.2635120596803694], 
             235 -> RGBColor[
              0.3570417238501652, 0.48367332858535217`, 0.9439713608175008], 
             70 -> RGBColor[
              0.2582501634540876, 0.38876767416929214`, 0.9380183368106061], 
             234 -> RGBColor[
              0.38857864336543946`, 0.5109890231778194, 0.9459808654420111], 
             435 -> RGBColor[
              0.25811768357221787`, 0.3886284294137375, 0.93801079227732], 
             257 -> RGBColor[
              0.8588534332133313, 0.4519682304874997, 0.20393618366530758`], 
             135 -> RGBColor[
              0.25062676841059334`, 0.3807550026274169, 0.9375841957406814], 
             265 -> RGBColor[
              0.32101450543653715`, 0.45246836277611585`, 0.9416757383178027],
              111 -> RGBColor[
              0.27309124258507717`, 0.4043665893147275, 0.9388635143117069], 
             497 -> RGBColor[
              0.23599364281048124`, 0.36537465982794926`, 0.9367508608855244],
              481 -> RGBColor[
              0.318216697210702, 0.4500450419128276, 0.9414974644516573], 381 -> 
             RGBColor[
              0.5693048020656428, 0.6612263110627765, 0.9592369059322629], 
             182 -> RGBColor[
              0.3785866605047563, 0.5023344698355566, 0.9453441851296919], 
             188 -> RGBColor[
              0.33727714516499796`, 0.4665542439248693, 0.9427119793408126], 
             154 -> RGBColor[
              0.30954120355039927`, 0.44253076534726327`, 0.9409446696670606],
              336 -> RGBColor[
              0.22223854670063217`, 0.35091718169303304`, 0.9359675285109096],
              463 -> RGBColor[
              0.2670973610782935, 0.3980666398170606, 0.9385221716270487], 
             315 -> RGBColor[
              0.1854996162687526, 0.3123022364263995, 0.933875300773191], 368 -> 
             RGBColor[
              0.4081016499818632, 0.5278988702541217, 0.9472248541600927], 
             269 -> RGBColor[
              0.44893934079834463`, 0.5632704254773366, 0.9498269957075668], 
             208 -> RGBColor[
              0.32211852500862637`, 0.45342460903982235`, 0.9417460854686901],
              86 -> RGBColor[
              0.9151930916309041, 0.7014758990831244, 0.2506205747334791], 
             119 -> RGBColor[
              0.9906473743776302, 0.9904004632007044, 0.8046607405893015], 
             436 -> RGBColor[
              0.472919813782261, 0.5829766354800872, 0.9516491265847494], 377 -> 
             RGBColor[
              0.9811051107342013, 0.9854288030398846, 0.9168682983373343], 
             140 -> RGBColor[
              0.4996340643500339, 0.6046644675542787, 0.9537521702469687], 85 -> 
             RGBColor[
              0.21421555473578224`, 0.34248450845090483`, 0.9355106309874645],
              351 -> RGBColor[
              0.290045450304657, 0.422186536586862, 0.9398290313598343], 443 -> 
             RGBColor[
              0.9345119801701037, 0.7780688545030732, 0.2661650059247154], 
             242 -> RGBColor[
              0.22500762673968802`, 0.3538276603838957, 0.936125223522647], 
             117 -> RGBColor[
              0.38107527345035186`, 0.504489981287708, 0.9455027573459912], 
             47 -> RGBColor[
              0.23193365260590854`, 0.36110735270469657`, 0.9365196504495912],
              451 -> RGBColor[
              0.21144581794704176`, 0.3395733394744833, 0.935352898574804], 
             81 -> RGBColor[
              0.8236181467643259, 0.8621947699835874, 0.9830386281626226], 
             275 -> RGBColor[
              0.4137039619056965, 0.5327513112621616, 0.9475818285219495], 23 -> 
             RGBColor[
              0.2225015077722568, 0.35119357045200544`, 0.9359825037549226], 
             328 -> RGBColor[
              0.3853130055350487, 0.5081604918248647, 0.9457727818871488], 
             418 -> RGBColor[
              0.978473490691829, 0.9834661451211657, 0.9213229446326382], 110 -> 
             RGBColor[
              0.27171530098953856`, 0.4029203874580805, 0.9387851564733641], 
             6 -> RGBColor[
              0.8276898195746623, 0.8654414113599355, 0.9834269879500976], 
             218 -> RGBColor[
              0.23197293745711564`, 0.3611486435741187, 0.9365218876637508], 
             108 -> RGBColor[
              0.28511069510105125`, 0.41699979598632125`, 0.939548004351305], 
             297 -> RGBColor[
              0.5193642093092683, 0.6206822880650865, 0.955305399532062], 487 -> 
             RGBColor[
              0.5794313774456323, 0.6694475211532741, 0.9600341070410434], 
             464 -> RGBColor[
              0.24386676324271586`, 0.3736498085868948, 0.9371992234469022], 
             157 -> RGBColor[
              0.3025436094347634, 0.43532289426166115`, 0.9405407830329243], 
             441 -> RGBColor[
              0.4501324018566838, 0.5643037950010776, 0.9499030165032217], 
             354 -> RGBColor[
              0.3617638436367253, 0.48776339140382907`, 0.9442722501146938], 
             385 -> 
             RGBColor[
              0.2334715870925415, 0.36272381936082626`, 0.9366072335434348], 
             270 -> RGBColor[
              0.9900230881246451, 0.9901423047916702, 0.8150067794022959], 
             392 -> RGBColor[
              0.3060013924465708, 0.4389572434431762, 0.9407376986601153], 33 -> 
             RGBColor[
              0.8784142522519405, 0.5407893411964669, 0.22025821055067316`], 
             252 -> RGBColor[
              0.7357960105795031, 0.7935287028122899, 0.9743009279960564], 
             394 -> RGBColor[
              0.22864247952174482`, 0.3576481211208147, 0.9363322230113024], 
             260 -> RGBColor[
              0.28557642935408295`, 0.4174893122155148, 0.9395745272280231], 
             159 -> RGBColor[
              0.8207501650068003, 0.16050043778835987`, 0.16750368748545852`],
              183 -> RGBColor[
              0.2049673414252272, 0.33276404989092045`, 0.9349839589209338], 
             99 -> RGBColor[
              0.9936215336094609, 0.9887654302895413, 0.5471214806005384], 
             329 -> RGBColor[
              0.8825578842047201, 0.909191716742005, 0.9886603529358121], 309 -> 
             RGBColor[
              0.9930307649637, 0.9875018358921313, 0.48281995931092997`], 17 -> 
             RGBColor[
              0.8799712561457314, 0.9071292097399156, 0.9884136380424356], 
             349 -> RGBColor[
              0.41360147005439724`, 0.5326625379719564, 0.9475752978318146], 
             495 -> RGBColor[
              0.8422024713778844, 0.3253922650171049, 0.18804644029332332`], 
             347 -> RGBColor[0.178927, 0.305394, 0.933501], 340 -> 
             RGBColor[
              0.3374345618861965, 0.46669059037677707`, 0.9427220097950892], 
             404 -> RGBColor[
              0.2134483076486736, 0.3416780831160786, 0.9354669374008939], 
             277 -> RGBColor[
              0.7713015318020453, 0.8212658858432957, 0.977839786533559], 104 -> 
             RGBColor[
              0.24657366739272524`, 0.3764949364761905, 0.9373533776337394], 
             79 -> RGBColor[
              0.9938287149952354, 0.9892085703244617, 0.5696718958667929], 
             327 -> RGBColor[
              0.2570691600545971, 0.38752636471648727`, 0.9379510804141431], 
             191 -> RGBColor[
              0.21840138119578575`, 0.34688407745709465`, 0.9357490076119863],
              50 -> RGBColor[
              0.44093802683048844`, 0.5563400894761129, 0.9493171590568191], 
             225 -> RGBColor[
              0.27424929290791517`, 0.4055837736286615, 0.9389294635644105], 
             405 -> RGBColor[
              0.9940126833910108, 0.9896020601209673, 0.5896957204256101], 61 -> 
             RGBColor[
              0.3238266917401457, 0.45490413720770817`, 0.94185492834235], 
             196 -> RGBColor[
              0.29569933477919436`, 0.42812912764658106`, 0.9401510117164867],
              1 -> RGBColor[
              0.2661654894960651, 0.39708718370006774`, 0.9384691029190212], 
             263 -> RGBColor[
              0.2734006518561467, 0.40469179807630246`, 0.9388811347119643], 
             201 -> RGBColor[
              0.3044587746178886, 0.4373358542976118, 0.9406498488568703], 
             371 -> RGBColor[
              0.36294391873403165`, 0.48878551314081686`, 0.9443474434563948],
              293 -> RGBColor[
              0.9542723127115095, 0.9654169462092355, 0.962289226275195], 362 -> 
             RGBColor[
              0.38846154058520777`, 0.5108875946353395, 0.9459734037564047], 
             184 -> RGBColor[
              0.2570318728012019, 0.3874871734490205, 0.9379489569602237], 
             106 -> RGBColor[
              0.5178553382148801, 0.619457318536794, 0.9551866156723348], 206 -> 
             RGBColor[
              0.3427341577200499, 0.4712808339226293, 0.9430596953553738], 
             358 -> RGBColor[
              0.22562621270692998`, 0.3544778334560826, 0.9361604510783655], 
             247 -> RGBColor[
              0.4950113815248125, 0.6009115653872759, 0.9533882557215221], 
             220 -> RGBColor[
              0.3389132056188999, 0.46797131725924984`, 0.9428162276662237], 
             407 -> RGBColor[
              0.21435834209939697`, 0.3426345870233057, 0.9355187625165873], 
             107 -> RGBColor[
              0.18467169248908813`, 0.3114320360405726, 0.9338281517387427], 
             375 -> RGBColor[
              0.9582014383733062, 0.9683472816944506, 0.9556382414098691], 
             131 -> RGBColor[
              0.263609049878749, 0.394400203574635, 0.9383235174647285], 411 -> 
             RGBColor[
              0.23958996446517072`, 0.3691546219069906, 0.9369556660834778], 
             462 -> RGBColor[
              0.46387836533310084`, 0.575636380316448, 0.9509373506429145], 
             127 -> RGBColor[
              0.22597981130456574`, 0.35484948800164373`, 0.9361805879953986],
              210 -> RGBColor[
              0.8360637140310553, 0.2782070860287545, 0.182167959325265], 357 -> 
             RGBColor[
              0.9071422836282599, 0.6695571281253704, 0.2441427056377997], 
             181 -> RGBColor[
              0.4206971967779904, 0.5388084998183378, 0.9480274312641372], 
             194 -> RGBColor[
              0.9865160895376739, 0.9886920707502049, 0.8731268218098209], 
             440 -> RGBColor[
              0.28167383897512416`, 0.41338744228870766`, 0.9393522804793065],
              490 -> RGBColor[
              0.9905535588776926, 0.9903616680805318, 0.806215506209998], 118 -> 
             RGBColor[
              0.32510810483221725`, 0.45601403282236586`, 0.9419365788514676],
              348 -> RGBColor[
              0.9599116097125079, 0.876434587737939, 0.29876460310071706`], 
             276 -> RGBColor[
              0.6195401563438858, 0.7020096347427746, 0.9631916170392121], 
             305 -> RGBColor[
              0.2511118726659751, 0.3812648779572094, 0.9376118217103779], 
             343 -> RGBColor[
              0.29288750827080284`, 0.425173719706164, 0.9399908823565584], 
             280 -> RGBColor[
              0.25689237745970156`, 0.38734055500058817`, 0.9379410129068901],
              474 -> RGBColor[
              0.9930971542734537, 0.9914135101440991, 0.7640615478883636], 
             189 -> RGBColor[
              0.2597753641562747, 0.39037075681060074`, 0.9381051947342635], 
             168 -> RGBColor[
              0.9107922199972238, 0.6840279095591187, 0.24707953011528597`], 
             363 -> RGBColor[
              0.40481135748628755`, 0.5250489842693634, 0.9470151996317661], 
             41 -> RGBColor[
              0.23252667542550592`, 0.36173065728791187`, 0.9365534222218687],
              14 -> RGBColor[
              0.30674268007373295`, 0.4397363837396738, 0.9407799138938453], 
             77 -> RGBColor[
              0.606817875551374, 0.6916811140631951, 0.9621900724919755], 51 -> 
             RGBColor[
              0.17892700081062782`, 0.30539400085202123`, 0.9335010000461641],
              438 -> RGBColor[
              0.22146455698209894`, 0.3501036694250721, 0.9359234509414543], 
             179 -> RGBColor[
              0.178929137062006, 0.30539624618766587`, 0.9335011217025198], 
             467 -> RGBColor[
              0.7068391686146014, 0.7709073977891587, 0.9714147806060683], 
             223 -> RGBColor[
              0.38986378476733635`, 0.5121021480670574, 0.9460627535157341], 
             456 -> RGBColor[
              0.22365852866224617`, 0.35240967276674573`, 0.9360483943829485],
              323 -> 
             RGBColor[
              0.23934466612723454`, 0.36889679780100676`, 0.9369416967060188],
              500 -> RGBColor[
              0.8194926622925333, 0.15083472088530037`, 0.16629950146613023`],
              478 -> RGBColor[
              0.2660419428822219, 0.39695732837561076`, 0.9384620671221336], 
             292 -> RGBColor[
              0.1789706321783367, 0.30543986018587177`, 0.9335034847880083], 
             491 -> RGBColor[
              0.9941614319695004, 0.9899202182895682, 0.6058860852243823], 
             396 -> RGBColor[
              0.9935460613341791, 0.9886040027241311, 0.5389067891970045], 
             321 -> RGBColor[
              0.3331754530775283, 0.46300156439574175`, 0.942450623147983], 
             143 -> RGBColor[
              0.17892700134778292`, 0.3053940014166053, 0.9335010000767543], 
             112 -> RGBColor[
              0.24826352560257345`, 0.3782710845979398, 0.937449612558869], 
             197 -> RGBColor[
              0.6976256228082208, 0.7637097057796726, 0.9704964604655693], 
             421 -> RGBColor[
              0.17905660578117066`, 0.3055302238934915, 0.9335083808575031], 
             54 -> RGBColor[
              0.22872079714307936`, 0.35773043790646125`, 0.9363366830839769],
              71 -> RGBColor[
              0.755781538403036, 0.8091415490436711, 0.97629289863413], 177 -> 
             RGBColor[
              0.20869655844004803`, 0.3366836934195124, 0.9351963323130457], 
             158 -> RGBColor[
              0.3575213303529286, 0.48408873963232213`, 0.9440019209197574], 
             226 -> RGBColor[
              0.1794249922972142, 0.30591742147890744`, 0.9335293599246128], 
             432 -> RGBColor[
              0.898624468927386, 0.9220027752840345, 0.9901927981294695], 350 -> 
             RGBColor[
              0.3621699928109498, 0.4881151774048913, 0.9442981295809318], 
             203 -> RGBColor[
              0.5345666356633387, 0.6330243026408235, 0.956502190222977], 475 -> 
             RGBColor[
              0.839003391040872, 0.30080273170088523`, 0.1849829973497558], 
             115 -> RGBColor[
              0.9211683800910966, 0.9399786781078106, 0.9923430565014513], 
             173 -> RGBColor[
              0.984562956112485, 0.9878843998856498, 0.9054952972124768], 212 -> 
             RGBColor[
              0.21851625165510197`, 0.3470048135930438, 0.9357555493147087], 
             129 -> RGBColor[
              0.35559977387920144`, 0.4824243839950162, 0.9438794810404173], 
             279 -> 
             RGBColor[
              0.2785602236563872, 0.4101148351741018, 0.9391749646930856], 26 -> 
             RGBColor[
              0.3866295369467384, 0.5093008051628776, 0.9458566701045386], 40 -> 
             RGBColor[
              0.3862001571816754, 0.5089288979916344, 0.9458293104055944], 
             146 -> RGBColor[
              0.257933230334439, 0.3884345573658211, 0.9380002879383026], 386 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 192 -> 
             RGBColor[
              0.2546146394674752, 0.38494650795382845`, 0.9378112990978443], 
             300 -> RGBColor[
              0.22595764709528393`, 0.3548261920123965, 0.936179325776469], 
             221 -> RGBColor[
              0.5366100807415061, 0.6346832634114314, 0.9566630577049163], 62 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 286 -> 
             RGBColor[
              0.22310026486080187`, 0.3518229021154584, 0.9360166020853335], 
             472 -> RGBColor[
              0.32844671668737896`, 0.45890577060779597`, 0.9421493122466601],
              152 -> RGBColor[
              0.20400293554931437`, 0.33175039816847185`, 0.9349290374330113],
              64 -> RGBColor[
              0.2878344487965492, 0.41986263381624833`, 0.9397031180948312], 
             307 -> RGBColor[
              0.46980956787155936`, 0.580451597734798, 0.9514042766334527], 
             37 -> RGBColor[
              0.305640198745031, 0.4385776059618545, 0.9407171292131508], 148 -> 
             RGBColor[
              0.23965584235908116`, 0.3692238637503902, 0.9369594177320785], 
             261 -> RGBColor[
              0.8799868165294279, 0.5479299882988189, 0.2215703967308864], 
             387 -> RGBColor[
              0.7751138064478154, 0.8242440637709316, 0.9782197584425172], 15 -> 
             RGBColor[
              0.23423879357827926`, 0.36353020202103736`, 0.9366509248178173],
              136 -> RGBColor[
              0.968960662006962, 0.9763714930638193, 0.9374256822530368], 198 -> 
             RGBColor[
              0.2818794421164257, 0.41360354422620765`, 0.9393639892740411], 
             63 -> RGBColor[
              0.41933559472005666`, 0.5376291485518648, 0.9479406711850231], 
             444 -> RGBColor[
              0.27129304719779485`, 0.4024765719505212, 0.9387611097445928], 
             310 -> RGBColor[
              0.29675707084929953`, 0.4292408753206019, 0.9402112482208989], 
             171 -> RGBColor[
              0.26174222518751433`, 0.39243805246062563`, 0.9382172045602823],
              395 -> 
             RGBColor[
              0.26498757281889074`, 0.39584911858812655`, 0.9384020223068277],
              311 -> RGBColor[
              0.746856868272219, 0.8021695289074716, 0.9754033709212744], 353 -> 
             RGBColor[
              0.6396625402707171, 0.7183458925176417, 0.9647757248126534], 59 -> 
             RGBColor[
              0.2421911048281961, 0.37188858535035474`, 0.9371037971791099], 
             397 -> RGBColor[
              0.3585480532796543, 0.48497803542685713`, 0.944067342796753], 
             229 -> RGBColor[
              0.2909757990296596, 0.42316439208435586`, 0.9398820133433956], 
             102 -> RGBColor[
              0.2765375568294345, 0.40798888409449063`, 0.939059776809558], 
             453 -> RGBColor[
              0.2843068325272902, 0.41615488545346746`, 0.9395022255669375], 
             299 -> RGBColor[
              0.2091663766185125, 0.3371775021132715, 0.9352230877632756], 
             128 -> RGBColor[
              0.49474321248409076`, 0.6006938536791404, 0.9533671444723009], 
             12 -> RGBColor[
              0.27240341106773047`, 0.40364363477895904`, 0.9388243433243495],
              222 -> RGBColor[
              0.4427137030371586, 0.5578780909582495, 0.9494303035745394], 
             483 -> RGBColor[
              0.29664917161590876`, 0.42912746638510174`, 0.9402051035191799],
              92 -> RGBColor[
              0.6091375885965603, 0.6935643616151592, 0.9623726888002815], 
             271 -> RGBColor[
              0.2558053195227897, 0.38619798818543977`, 0.9378791065655412], 
             361 -> RGBColor[
              0.6442014475594858, 0.7219743340365904, 0.9651716379540781], 
             344 -> RGBColor[
              0.4637429804071734, 0.5755264687345587, 0.9509266926456142], 
             132 -> RGBColor[
              0.9901329118562932, 0.9901877197270478, 0.8131867159541827], 80 -> 
             RGBColor[
              0.7895429134572223, 0.8355161918319554, 0.9796579169815435], 
             324 -> RGBColor[
              0.369677449943029, 0.49461775943693126`, 0.9447764981108042], 
             244 -> RGBColor[
              0.3424410288691568, 0.4710269404450701, 0.9430410174441985], 
             150 -> RGBColor[
              0.8214446559981496, 0.16583859987576455`, 0.16816873284309014`],
              125 -> RGBColor[
              0.20867358600249122`, 0.3366595479311035, 0.9351950240667115], 
             258 -> RGBColor[
              0.3734224424883788, 0.497861483750915, 0.945015125724227], 133 -> 
             RGBColor[
              0.3451736656290086, 0.4733938130601367, 0.9432151386421606], 
             469 -> RGBColor[
              0.8604306779796645, 0.4591301305965446, 0.20525227536014304`], 
             255 -> RGBColor[
              0.3975855258515599, 0.5187903320882202, 0.9465547760295533], 
             408 -> RGBColor[
              0.2225045334786326, 0.3511967506612473, 0.9359826760644245], 
             326 -> RGBColor[
              0.8751755113140446, 0.526082975024646, 0.21755572572328788`], 
             176 -> RGBColor[
              0.6069446059586334, 0.6917839995169481, 0.9622000491738637], 
             230 -> RGBColor[
              0.2238780227461086, 0.35264037496561385`, 0.936060894246312], 
             274 -> RGBColor[
              0.4627342609626232, 0.5747075448471798, 0.9508472825558781], 87 -> 
             RGBColor[
              0.1792532619022457, 0.3057369219454596, 0.9335195801326717], 
             439 -> RGBColor[
              0.8609124841587944, 0.891932262294116, 0.986595795356355], 130 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 35 -> 
             RGBColor[
              0.23837242809378653`, 0.36787491398440125`, 0.9368863291883112],
              379 -> RGBColor[
              0.3092991992760449, 0.442321153408306, 0.9409292493686947], 31 -> 
             RGBColor[
              0.4530382628066378, 0.5668207057031098, 0.9500881753934008], 18 -> 
             RGBColor[
              0.8843839202879132, 0.5678962094964264, 0.22523944788984251`], 
             24 -> RGBColor[
              0.8369720141620951, 0.8728427813654944, 0.9843123319561599], 
             151 -> RGBColor[
              0.30679432383558886`, 0.439790664607788, 0.9407828549296829], 
             137 -> RGBColor[
              0.22008054170119, 0.3486489816131997, 0.9358446333186737], 330 -> 
             RGBColor[
              0.3064495532407965, 0.43942828885294294`, 0.9407632207543519], 
             296 -> RGBColor[
              0.3134198204339392, 0.44589022834683273`, 0.9411918117051534], 
             266 -> RGBColor[
              0.28952074326414307`, 0.421635036218934, 0.9397991500701115], 
             302 -> RGBColor[
              0.19014935834156865`, 0.31718941015560403`, 0.934140096705561], 
             442 -> RGBColor[
              0.28394532564135605`, 0.4157749187954902, 0.9394816382845851], 
             283 -> RGBColor[
              0.18121415923057888`, 0.3077979493656092, 0.9336312503346327], 
             388 -> RGBColor[
              0.9461721011462925, 0.9593758216867757, 0.9760007715815773], 
             284 -> 
             RGBColor[
              0.24509263407936946`, 0.37493827656091794`, 0.9372690349775362],
              417 -> RGBColor[
              0.7010326627105, 0.7663713112457954, 0.9708360423624304], 318 -> 
             RGBColor[
              0.341942322952124, 0.4705949864454246, 0.9430092403441536], 413 -> 
             RGBColor[
              0.97383602535665, 0.9234049113139019, 0.35285832847295656`], 
             238 -> RGBColor[
              0.32015392046586916`, 0.45172296732878153`, 0.9416209026044572],
              72 -> RGBColor[
              0.2539844574642687, 0.3842841467126117, 0.9377754111650324], 
             437 -> RGBColor[
              0.2558304623203871, 0.3862244148598601, 0.9378805384106689], 
             288 -> RGBColor[
              0.2560659100008252, 0.3864718853002457, 0.9378939468077562], 
             382 -> RGBColor[
              0.28222469603460637`, 0.4139664279845783, 0.9393836509739241], 
             461 -> RGBColor[
              0.944455505750549, 0.9580955876512972, 0.9789065198267879], 389 -> 
             RGBColor[
              0.2184997826909155, 0.34698750366749115`, 0.9357546114315619], 
             172 -> RGBColor[
              0.3516524550010693, 0.4790054147807936, 0.9436279613719797], 
             447 -> RGBColor[
              0.2464999471451923, 0.3764174518218997, 0.9373491793747017], 
             243 -> RGBColor[
              0.8393061093521738, 0.30312955729356095`, 0.18527288074652987`],
              410 -> RGBColor[
              0.36366501242205085`, 0.4894100882501565, 0.9443933909085572], 
             88 -> RGBColor[
              0.8666101266120032, 0.4871895635890985, 0.21040855877111306`], 
             273 -> RGBColor[
              0.2935414156904733, 0.42586101786436276`, 0.9400281214167392], 
             477 -> RGBColor[
              0.24467162743864543`, 0.3744957718881542, 0.9372450592721705], 
             202 -> RGBColor[
              0.23905706042934927`, 0.3685945059772749, 0.9369253179869986], 
             393 -> RGBColor[
              0.4612114846587171, 0.5734712864433781, 0.9507274040271213], 98 -> 
             RGBColor[
              0.9952347378240085, 0.9922159109844932, 0.7227088038116687], 30 -> 
             RGBColor[
              0.2679312243382506, 0.39894308297325987`, 0.938569658906113], 
             116 -> RGBColor[
              0.24872594858728536`, 0.3787571204741826, 0.9374759468637549], 
             373 -> RGBColor[
              0.293615491872952, 0.425938876628849, 0.9400323399457455], 434 -> 
             RGBColor[
              0.9912025783926344, 0.990630054329001, 0.7954595732387495], 401 -> 
             RGBColor[
              0.7734523776791622, 0.8229461429895335, 0.9780541627497925], 
             240 -> RGBColor[
              0.2566255537350775, 0.38706010634840704`, 0.9379258176905032], 
             480 -> RGBColor[
              0.35354723518652786`, 0.48064657814301665`, 0.9437486950899088],
              403 -> RGBColor[
              0.9289119756027943, 0.9461532109745376, 0.9930816475541463], 
             317 -> RGBColor[
              0.8834003236622562, 0.5634299269441462, 0.22441871075523476`], 
             429 -> RGBColor[
              0.29359796730781346`, 0.4259204571997668, 0.9400313419476861], 
             391 -> RGBColor[
              0.2411272273904176, 0.370770382709524, 0.937043210932894], 73 -> 
             RGBColor[
              0.24791046842011605`, 0.37789999911405875`, 0.9374295064746294],
              303 -> RGBColor[
              0.3052585207535403, 0.43817643819301544`, 0.9406953932161773], 
             449 -> RGBColor[
              0.7283027762348872, 0.7876749311915857, 0.9735540724248413], 29 -> 
             RGBColor[
              0.40962031041891445`, 0.5292142575946026, 0.9473216218602429], 
             360 -> RGBColor[
              0.5793663225363243, 0.6693947066472076, 0.9600289856802787], 
             320 -> RGBColor[
              0.9886024976405045, 0.9895548541189678, 0.8385496400948322], 
             482 -> RGBColor[
              0.35848143845973107`, 0.48492033701799786`, 0.9440630981593326],
              75 -> RGBColor[
              0.3449485107481652, 0.47319879521896346`, 0.9432007919722498], 
             200 -> RGBColor[
              0.9008280073528754, 0.6425649682443086, 0.23896079721830538`], 
             301 -> RGBColor[
              0.20875268020104726`, 0.3367426809486477, 0.9351995283643099], 
             156 -> RGBColor[
              0.46730916543215706`, 0.578421658392645, 0.9512074357941471], 
             25 -> RGBColor[
              0.3133752819583538, 0.4458516513578495, 0.941188973752873], 38 -> 
             RGBColor[
              0.25996867538836677`, 0.3905739391721695, 0.9381162035229527], 
             365 -> RGBColor[
              0.2169746648251472, 0.34538450809251103`, 0.9356677582253161], 
             380 -> RGBColor[
              0.27285106149406285`, 0.4041141437597107, 0.9388498363538897], 
             370 -> RGBColor[
              0.591443337591513, 0.6791993715323379, 0.960979732544987], 3 -> 
             RGBColor[
              0.46166603367100856`, 0.5738403098087559, 0.9507631877904368], 
             57 -> RGBColor[
              0.6012429877716181, 0.6871551690177569, 0.9617511969044663], 
             227 -> RGBColor[
              0.8456311671254343, 0.35174672299683013`, 0.19132976321333509`],
              494 -> RGBColor[
              0.2585035332044634, 0.3890339818415072, 0.938032765843063], 39 -> 
             RGBColor[
              0.6236615875481659, 0.7053555982627691, 0.963516071200913], 424 -> 
             RGBColor[
              0.3205944320155112, 0.4521045162923272, 0.9416489716108714], 
             109 -> RGBColor[
              0.25396000439311356`, 0.38425844498441336`, 0.9377740185988052],
              465 -> RGBColor[
              0.28262558218412137`, 0.4143877847453685, 0.939406480847081], 
             256 -> RGBColor[
              0.2893861381019995, 0.4214935576590608, 0.939791484505258], 457 -> 
             RGBColor[
              0.22158907133489145`, 0.35023454190452297`, 0.9359305418496434],
              339 -> RGBColor[
              0.21169068579341777`, 0.33983071110654267`, 0.9353668434364056],
              420 -> RGBColor[
              0.96864282965107, 0.9761344542131977, 0.9379636895276074], 287 -> 
             RGBColor[
              0.20981171601903448`, 0.33785579474010136`, 0.9352598388874411],
              239 -> RGBColor[
              0.3509305166159243, 0.47838010803725933`, 0.9435819600964633], 
             427 -> RGBColor[
              0.2795001276110678, 0.4111027338238238, 0.9392284908328413], 
             285 -> RGBColor[
              0.3144183414809424, 0.4467550970906198, 0.941255436583311], 345 -> 
             RGBColor[
              0.6597251945044771, 0.7341016031348642, 0.9667188999718916], 
             366 -> RGBColor[
              0.2650062967491503, 0.3958687986259951, 0.9384030886069564], 
             216 -> RGBColor[
              0.26588598144981995`, 0.39679340302163035`, 0.9384531853492826],
              21 -> RGBColor[
              0.9808877657874093, 0.9471920876142448, 0.3802530084370154], 
             355 -> RGBColor[
              0.32870680276015046`, 0.45913104409172456`, 0.942165884701232], 
             175 -> RGBColor[
              0.9557302644442173, 0.966504284224312, 0.9598212942864327], 7 -> 
             RGBColor[
              0.8386821070512293, 0.8742063630160551, 0.9844754421425435], 13 -> 
             RGBColor[
              0.29661626096016863`, 0.4290928751992627, 0.9402032293060224], 
             294 -> 
             RGBColor[
              0.23831274258564697`, 0.36781218073106675`, 0.9368829301869194],
              412 -> RGBColor[
              0.2423814866745967, 0.372088688741828, 0.9371146391436176], 193 -> 
             RGBColor[
              0.2878117179623051, 0.41983874226823964`, 0.9397018236074483], 
             60 -> RGBColor[
              0.29270959820985176`, 0.42498672495195505`, 0.9399807506417815],
              65 -> RGBColor[
              0.9854648277298144, 0.9626315922912277, 0.39803402977763763`], 
             448 -> RGBColor[
              0.5679393142918087, 0.6601177465734548, 0.9591294097327601], 69 -> 
             RGBColor[
              0.9094625081980608, 0.9306447336077317, 0.9912265399903383], 
             217 -> RGBColor[
              0.31971976000988434`, 0.4513469193633465, 0.9415932382841149], 
             214 -> RGBColor[
              0.19980711485308938`, 0.32734032458634205`, 0.9346900916515217],
              170 -> RGBColor[
              0.29668056881803306`, 0.42916046683523196`, 0.9402068915433929],
              359 -> RGBColor[
              0.38545126270191343`, 0.5082802432337956, 0.9457815915115654], 
             74 -> RGBColor[
              0.2817340129849886, 0.4134506889883278, 0.9393557073001488], 
             246 -> RGBColor[
              0.29422140859812795`, 0.42657573352434824`, 0.9400668460068708],
              264 -> RGBColor[
              0.23478619087952063`, 0.36410555129163547`, 0.9366820982843213],
              278 -> RGBColor[
              0.9483637407407871, 0.9610103429078694, 0.9722908974192511], 45 -> 
             RGBColor[
              0.28278247170568477`, 0.41455268557990177`, 0.9394154154732368],
              492 -> RGBColor[
              0.2766193131480329, 0.4080748151689876, 0.9390644327109545], 
             306 -> RGBColor[
              0.8575795140998795, 0.443586953641446, 0.20277151376979163`], 
             237 -> RGBColor[
              0.906092392768253, 0.9279574950433493, 0.9909050953721057], 228 -> 
             RGBColor[
              0.9930813033990235, 0.9876099324950685, 0.48832075610881853`], 
             180 -> RGBColor[
              0.27013094278236094`, 0.4012551265282246, 0.9386949296173133], 
             383 -> RGBColor[
              0.32894252042405586`, 0.45933521088468515`, 0.942180904422339], 
             53 -> RGBColor[
              0.9765123065091236, 0.9324326360618924, 0.36325517537702773`], 
             304 -> RGBColor[
              0.3385640468354945, 0.4676688934702948, 0.9427939795772942], 48 -> 
             RGBColor[
              0.20751087662989864`, 0.3354374666604766, 0.9351288094880167], 
             5 -> RGBColor[
              0.23860734128045696`, 0.3681218226379481, 0.9368997071467691], 
             101 -> RGBColor[
              0.5208327276256995, 0.6218744973903617, 0.9554210066732913], 
             333 -> RGBColor[
              0.3786491349611119, 0.5023885820695944, 0.9453481659468069], 
             267 -> RGBColor[
              0.9890626064851881, 0.9747677448317271, 0.41201072085875556`], 
             120 -> RGBColor[
              0.20742150462258202`, 0.3353435310142743, 0.9351237198844141], 
             147 -> RGBColor[
              0.25149316947897704`, 0.3816656450832887, 0.9376335359998004], 
             89 -> RGBColor[
              0.28550171685781406`, 0.4174107846448903, 0.9395702724618878], 
             43 -> RGBColor[
              0.2931478124699098, 0.42544731592366486`, 0.940005706295612], 
             199 -> RGBColor[
              0.3428438781472085, 0.4713758682419251, 0.9430666866439704], 
             268 -> RGBColor[
              0.40965477924277666`, 0.5292441127573786, 0.9473238181832199], 
             169 -> RGBColor[
              0.4927421843014464, 0.5990693288551774, 0.9532096162037554], 20 -> 
             RGBColor[
              0.8845340276069948, 0.5685778117739207, 0.22536470111635126`], 
             4 -> RGBColor[
              0.32430364693803726`, 0.45531725182765653`, 0.9418853195058047],
              167 -> RGBColor[
              0.9866702547547157, 0.9887558220293171, 0.870571905196646], 431 -> 
             RGBColor[
              0.4485399301016759, 0.5629244760068475, 0.9498015456111601], 
             142 -> RGBColor[
              0.6995243049605603, 0.765192970707599, 0.9706857033583209], 16 -> 
             RGBColor[
              0.4038820814050813, 0.5242440920345965, 0.9469559869815982], 
             414 -> RGBColor[
              0.2746579678933065, 0.4060133169497984, 0.9389527370002482], 
             281 -> RGBColor[
              0.24490866169442368`, 0.374744909919817, 0.9372585580223763], 
             289 -> RGBColor[
              0.439371052281192, 0.5549828548799431, 0.9492173128241592], 398 -> 
             RGBColor[
              0.26115105564507934`, 0.3918166957892125, 0.9381835383293976], 
             178 -> RGBColor[
              0.9916846362160958, 0.9908293976273234, 0.7874706275783359], 58 -> 
             RGBColor[
              0.31511174381280593`, 0.44735568733906544`, 0.9412996195667458],
              186 -> 
             RGBColor[
              0.23571041014604155`, 0.365076964339635, 0.9367347312042897], 
             122 -> RGBColor[
              0.867504304657107, 0.49124981725132677`, 0.21115468285025726`], 
             249 -> RGBColor[
              0.2895478687563091, 0.421663546831056, 0.9398006948267619], 113 -> 
             RGBColor[
              0.17919226069553715`, 0.305672805809509, 0.9335161062041928], 
             52 -> RGBColor[
              0.8357950446989824, 0.2761419758107905, 0.18191068126945342`], 
             409 -> RGBColor[
              0.24155566178660715`, 0.3712206944242289, 0.937067609637945], 
             187 -> RGBColor[
              0.26462809617956273`, 0.3954712858480575, 0.938381550644016], 
             259 -> RGBColor[
              0.8618406991999262, 0.46553270763892984`, 0.20642883162911219`],
              42 -> RGBColor[
              0.23247426890382172`, 0.3616755747108564, 0.9365504377479873], 
             134 -> RGBColor[
              0.2332063867745317, 0.36244507701192663`, 0.9365921307776528], 
             470 -> RGBColor[
              0.25548210733168075`, 0.3858582716797478, 0.937860700109407], 
             313 -> RGBColor[
              0.266957894870447, 0.3979200519899457, 0.9385142292328336], 248 -> 
             RGBColor[
              0.24253965650195108`, 0.3722549352589237, 0.9371236466812941], 
             174 -> RGBColor[
              0.2666571079259713, 0.3976039058403079, 0.93849709986132], 215 -> 
             RGBColor[
              0.28412310253725925`, 0.4159617735847908, 0.9394917624158093], 
             399 -> RGBColor[
              0.24150095424043594`, 0.3711631933245442, 0.9370644941241232], 
             422 -> RGBColor[
              0.23401200432651914`, 0.3632918321381684, 0.9366380095054342], 
             83 -> RGBColor[
              0.9207457022290968, 0.9396416462539369, 0.9923027411096448], 95 -> 
             RGBColor[
              0.22708291988077767`, 0.3560089250563658, 0.936243408396911], 
             166 -> RGBColor[
              0.8381204118994321, 0.2940157670958513, 0.18413745552673064`], 
             384 -> RGBColor[
              0.28382079992875175`, 0.41564403437615693`, 0.9394745467294715],
              233 -> RGBColor[
              0.8431597968980244, 0.3327506884676198, 0.18896317629255405`], 
             295 -> RGBColor[
              0.22958788287780074`, 0.3586417999900643, 0.9363860623338308], 
             499 -> RGBColor[
              0.2607186377132893, 0.3913621971260208, 0.9381589127678872], 
             141 -> 
             RGBColor[
              0.30958288032569087`, 0.4425668636752852, 0.9409473252743288], 
             319 -> RGBColor[
              0.7148896845747944, 0.7771965220434489, 0.9722171808006315], 
             205 -> RGBColor[
              0.9938265629209484, 0.98920396725517, 0.5694376558617151], 468 -> 
             RGBColor[
              0.4783770236668791, 0.5874070443089239, 0.952078738137285], 486 -> 
             RGBColor[
              0.9349275982881982, 0.9509499052141509, 0.9936554230160899], 
             224 -> RGBColor[
              0.29896629209325354`, 0.43156290692071464`, 0.9403370601024921],
              231 -> RGBColor[
              0.2584463601503126, 0.3889738893366137, 0.9380295099222091], 
             332 -> RGBColor[
              0.40219205331719154`, 0.5227802746481479, 0.946848299886271], 
             68 -> RGBColor[
              0.8199864588949732, 0.15463025795470559`, 0.16677236165029033`],
              484 -> RGBColor[
              0.9928916986278599, 0.9872043870615327, 0.4676834468726777], 10 -> 
             RGBColor[
              0.2189624152550279, 0.3474737598249721, 0.9357809576716846], 
             250 -> RGBColor[
              0.20444533477183996`, 0.332215387801077, 0.934954231414263], 
             282 -> RGBColor[
              0.6076583896248129, 0.6923634812527404, 0.9622562408387412], 
             374 -> RGBColor[
              0.2517303220687306, 0.38191490749146234`, 0.937647041488951], 
             232 -> RGBColor[
              0.3561976264336458, 0.4829422138287328, 0.9439175756765262], 
             489 -> RGBColor[
              0.9900975943251971, 0.9901731150203205, 0.8137720188432849], 
             253 -> RGBColor[
              0.9850318468002165, 0.9880782982349678, 0.8977245650665646], 
             459 -> RGBColor[
              0.3905461178527888, 0.5126931506906183, 0.9461062311765757], 
             415 -> RGBColor[
              0.2870126862041934, 0.4189989092289247, 0.9396563199308854], 55 -> 
             RGBColor[
              0.21147766438726034`, 0.339606812102334, 0.9353547121824619], 
             446 -> RGBColor[
              0.22815127331601265`, 0.3571318322543179, 0.9363042495445604], 
             325 -> RGBColor[
              0.1790169203691504, 0.30548851200925775`, 0.9335061208319979], 
             91 -> RGBColor[
              0.3276288460270304, 0.4581973721491767, 0.9420971982513973], 
             450 -> RGBColor[
              0.8177084834502429, 0.13712074047130335`, 0.1645909697918113], 
             423 -> 
             RGBColor[
              0.18782589147201245`, 0.31474729915939237`, 0.9340077787046009],
              105 -> RGBColor[
              0.2459052705491277, 0.3757924090147619, 0.9373153134223011], 36 -> 
             RGBColor[
              0.254389289460926, 0.3847096508089296, 0.9377984657483468], 123 -> 
             RGBColor[
              0.2069635167020156, 0.33486215667164765`, 0.9350976381498702], 
             94 -> RGBColor[
              0.9554190789968999, 0.9662722026272221, 0.9603480500785777], 
             473 -> RGBColor[
              0.32683125980079797`, 0.4575065430478635, 0.9420463767623395], 
             312 -> RGBColor[
              0.3044115375980597, 0.43728620519477157`, 0.940647158778472], 
             96 -> RGBColor[
              0.2961617343973124, 0.4286151389630523, 0.9401773446906796], 
             496 -> RGBColor[
              0.27688954314442643`, 0.4083588440287685, 0.9390798219094797], 
             2 -> RGBColor[
              0.2124476857409665, 0.34062636604798524`, 0.9354099534635375], 
             262 -> RGBColor[
              0.47608581392629684`, 0.5855469370236965, 0.9518983657135286], 
             272 -> RGBColor[
              0.8205829319400263, 0.15921501115513814`, 0.16734354491185305`],
              97 -> RGBColor[
              0.2317345075524728, 0.36089803862701, 0.9365083094334068], 372 -> 
             RGBColor[
              0.4704530721178047, 0.5809740234714359, 0.951454935644951], 356 -> 
             RGBColor[
              0.26933793088281155`, 0.4004216207419397, 0.9386497687627899], 
             402 -> RGBColor[
              0.5523112332770156, 0.6474301663686192, 0.9578991099477285], 
             455 -> RGBColor[
              0.20394063923757638`, 0.33168492079502093`, 0.9349254897502168],
              428 -> RGBColor[
              0.8303334960184631, 0.23416211938642656`, 0.1766806960850511], 
             346 -> RGBColor[
              0.21788265672664042`, 0.34633886515099205`, 0.9357194670208525],
              341 -> RGBColor[
              0.9935733711383794, 0.9886624156338708, 0.5418792928476311], 
             209 -> RGBColor[
              0.5659235722129052, 0.6584812763456551, 0.9589707231324023], 
             498 -> RGBColor[
              0.46188951150763047`, 0.5740217391840874, 0.9507807807843619], 
             378 -> RGBColor[
              0.2830844261537786, 0.4148700588498662, 0.9394326113323542], 
             419 -> RGBColor[
              0.5126905354832046, 0.6152642990075083, 0.9547800234820015], 66 -> 
             RGBColor[
              0.2632810725593861, 0.3940554786170215, 0.9383048396415897], 
             139 -> RGBColor[
              0.5640351798749514, 0.6569481943745988, 0.9588220619701494], 56 -> 
             RGBColor[
              0.8366736085240676, 0.28289500235951803`, 0.1827519949805509], 
             335 -> RGBColor[
              0.2767721721232211, 0.4082354796437291, 0.9390731378034569], 
             314 -> RGBColor[
              0.33007547283951477`, 0.4603165173231115, 0.9422530951484216], 
             144 -> RGBColor[
              0.24622776306205768`, 0.3761313690930576, 0.9373336788938276], 
             298 -> RGBColor[
              0.9016398137954514, 0.9244071294324739, 0.9904804044148157], 
             204 -> RGBColor[
              0.5018930513522051, 0.606498414968846, 0.9539300059787216], 452 -> 
             RGBColor[
              0.22395342458252596`, 0.35271962707644106`, 0.936065188269349], 
             466 -> RGBColor[
              0.503508173143364, 0.6078096435993164, 0.9540571542825077], 207 -> 
             RGBColor[
              0.217062994597398, 0.3454773482835776, 0.9356727884751737], 334 -> 
             RGBColor[
              0.4028040785660817, 0.5233103801574531, 0.9468872975939376], 
             149 -> RGBColor[
              0.353874772698637, 0.4809302746734916, 0.9437695654905504], 219 -> 
             RGBColor[
              0.5262688994117111, 0.6262878265429939, 0.9558489620296395], 
             400 -> RGBColor[
              0.295921828646773, 0.42836298280833224`, 0.9401636824130951], 9 -> 
             RGBColor[
              0.5751436787516512, 0.6659665741948753, 0.9596965636934954], 11 -> 
             RGBColor[
              0.23891813183632316`, 0.3684484832174229, 0.9369174062091523], 
             44 -> RGBColor[
              0.49667724948997916`, 0.6022639920478948, 0.9535193989500155], 
             153 -> RGBColor[
              0.24493296406314102`, 0.3747704532501981, 0.9372599420063227], 
             471 -> RGBColor[
              0.8568125830318801, 0.4376919853814662, 0.20203709971295072`], 
             406 -> RGBColor[
              0.990618380894789, 0.9800157372285142, 0.4180546106567104], 32 -> 
             RGBColor[
              0.5357107322431658, 0.6339531317852908, 0.9565922576967049], 
             162 -> RGBColor[
              0.46203141681910903`, 0.5741369443087071, 0.9507919520902978], 
             493 -> RGBColor[
              0.9935772608954081, 0.9886707354308406, 0.5423026688954158], 90 -> 
             RGBColor[
              0.8647697772859632, 0.4788329671240561, 0.2088729261823753], 
             331 -> RGBColor[
              0.8366916950922476, 0.8726192625482565, 0.984285594873034], 8 -> 
             RGBColor[
              0.6202936289377985, 0.7026213377380665, 0.963250933161866], 364 -> 
             RGBColor[
              0.2585666750316088, 0.38910034790526005`, 0.938036361676709], 
             342 -> RGBColor[
              0.25998714329821626`, 0.39059335011635443`, 0.9381172552430979],
              163 -> RGBColor[
              0.26699231078344465`, 0.3979562252966011, 0.9385161891681649], 
             49 -> RGBColor[
              0.49021471545548245`, 0.5970174157848499, 0.9530106445977776], 
             338 -> RGBColor[
              0.32010532781399464`, 0.4516808788160655, 0.9416178063236486], 
             76 -> RGBColor[
              0.4113253016274047, 0.530691035284047, 0.9474302623923834], 369 -> 
             RGBColor[
              0.4199474238450335, 0.5381590841884939, 0.9479796563958474], 
             445 -> RGBColor[
              0.22963931784821143`, 0.3586958614051314, 0.9363889914793045], 
             82 -> RGBColor[
              0.25827862318556116`, 0.3887975871515221, 0.9380199575502111], 
             67 -> RGBColor[
              0.25662307112871396`, 0.38705749697171266`, 0.9379256763097434],
              430 -> RGBColor[
              0.23973902577549727`, 0.36931129479517677`, 0.9369641549045845],
              211 -> RGBColor[
              0.2310404057237692, 0.3601684935964447, 
               0.9364687813610937]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9V3c41W/cPkZ2skfWMY5xzsFxzjFCvnekUipFSBqEZKVlFlIpoUVlJUVG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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 54}], {
             RGBColor[
             0.24744314331957223`, 0.3774088108032645, 0.937402893001499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 70}], {
             RGBColor[
             0.26220782647507634`, 0.3929274289346799, 0.9382437198648137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 84}], {
             RGBColor[
             0.249739891419232, 0.3798228386782472, 0.9375336894080404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 131}], {
             RGBColor[
             0.26488726968740706`, 0.3957436936373514, 0.9383963101918749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 135}], {
             RGBColor[
             0.2583961289533292, 0.38892109316374235`, 0.9380266493298512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 147}], {
             RGBColor[
             0.2588293294875211, 0.38937641439167825`, 0.9380513194594108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 170}], {
             RGBColor[
             0.2814230291570491, 0.41312382526764985`, 0.939337997231207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 171}], {
             RGBColor[
             0.2639538573417897, 0.3947626180803467, 0.9383431537396518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 265}], {
             RGBColor[
             0.2935899974663011, 0.4247777732380918, 0.9400724206184119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 266}], {
             RGBColor[
             0.27784311638010406`, 0.40936110995950087`, 0.9391341264945663]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 374}], {
             RGBColor[
             0.25894790578239785`, 0.38950104559576504`, 0.9380580722039861]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 385}], {
             RGBColor[
             0.2498185382943033, 0.379905501530447, 0.937538168231228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 391}], {
             RGBColor[
             0.25364635844324135`, 0.38392878320479584`, 0.9377561569259576]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 433}], {
             RGBColor[
             0.2958358704615542, 0.4267230355457211, 0.940215525659722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 47}], {
             RGBColor[
             0.22219066917343752`, 0.3508668593763409, 0.9359648019565643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 54}], {
             RGBColor[
             0.22058424144202293`, 0.3491784019772233, 0.9358733182737572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 55}], {
             RGBColor[
             0.21196267506411343`, 0.3401165890751596, 0.9353823328229998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 230}], {
             RGBColor[
             0.21816285424353754`, 0.34663337050679954`, 0.9357354238549247]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 242}], {
             RGBColor[
             0.21872765624032725`, 0.34722701321594046`, 0.9357675884930923]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 250}], {
             RGBColor[
             0.20844651025640323`, 0.33642087692453115`, 0.9351820924389003]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 339}], {
             RGBColor[
             0.21206918576719214`, 0.340228538577264, 0.9353883984499716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 365}], {
             RGBColor[
             0.21471117528305686`, 0.3430054370702481, 0.9355388558444269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 8}], {
             RGBColor[
             0.5409798313044035, 0.6382308237734111, 0.9570070604761514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 31}], {
             RGBColor[
             0.4573521482388232, 0.5703305077559329, 0.9504256815919188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[
             0.4618487252450588, 0.5739886270587315, 0.9507775699403673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 203}], {
             RGBColor[
             0.49811633466717364`, 0.6034323062247897, 0.9536326890067068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 221}], {
             RGBColor[
             0.4991380572062573, 0.6042617866100937, 0.9537131227476765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 223}], {
             RGBColor[
             0.4257649092191724, 0.5429712289379067, 0.9484129706530855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 258}], {
             RGBColor[
             0.41754423807969365`, 0.5358508967798354, 0.9478891567573319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 381}], {
             RGBColor[
             0.5154854178683257, 0.6175333104357662, 0.9550000468613498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 439}], {
             RGBColor[
             0.6612892589149015, 0.732886286051436, 0.9686794915733958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 480}], {
             RGBColor[
             0.4076066344287682, 0.5272434439758863, 0.9472559414401728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 29}], {
             RGBColor[
             0.36696197867847585`, 0.49226575471112954`, 0.9446034706830237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 185}], {
             RGBColor[
             0.30412419819916303`, 0.4355457825101565, 0.9406834624888651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 196}], {
             RGBColor[
             0.31000149085861584`, 0.44172318973711877`, 0.9410181656111457]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 318}], {
             RGBColor[
             0.33312298494508064`, 0.46295611913654056`, 0.9424472799249791]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 321}], {
             RGBColor[
             0.32873955000778277`, 0.45915940811169914`, 0.9421679713268938]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 335}], {
             RGBColor[
             0.3005379095306292, 0.4317763657356928, 0.9404792286546308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 383}], {
             RGBColor[
             0.32662308368104653`, 0.45732623135617084`, 0.9420331119640719]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 479}], {
             RGBColor[
             0.3678971603336924, 0.49307576205728143`, 0.9446630596311456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 482}], {
             RGBColor[
             0.3413925426988842, 0.4701187944228272, 0.9429742088325687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 496}], {
             RGBColor[
             0.3005965950412318, 0.4318380479282125, 0.9404825707076422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.23876273655839006`, 0.3682851529276855, 0.9369085566779607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 23}], {
             RGBColor[
             0.23055442452635688`, 0.3596576965449768, 0.9364411054508459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 41}], {
             RGBColor[
             0.23556700835298144`, 0.36492623996293, 0.9367265646843188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 102}], {
             RGBColor[
             0.2575724490549457, 0.3880553533662194, 0.9379797419781635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 186}], {
             RGBColor[
             0.23715887571324926`, 0.36659939348879156`, 0.9368172191755294]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 193}], {
             RGBColor[
             0.263209529621381, 0.3939802824530939, 0.9383007653771087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 202}], {
             RGBColor[
             0.23883220085490312`, 0.3683581643076115, 0.9369125125668838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 211}], {
             RGBColor[
             0.2348238735021131, 0.3641451581171964, 0.9366842442539314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 212}], {
             RGBColor[
             0.22856179646777947`, 0.35756331811549596`, 0.9363276282307389]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 300}], {
             RGBColor[
             0.23228249418787045`, 0.3614740073251723, 0.936539516461619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 414}], {
             RGBColor[
             0.2566326545868817, 0.38706756979387325`, 0.9379262220735086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 485}], {
             RGBColor[
             0.24330426601765148`, 0.37305858833896816`, 0.9371671900620748]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 24}], {
             RGBColor[
             0.8323309168683787, 0.869142096362715, 0.9838696599531287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 77}], {
             RGBColor[
             0.7172538475630181, 0.7785612627115652, 0.9728085302210365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 79}], {
             RGBColor[
             0.9107592672849488, 0.9273249908421985, 0.7765494419084453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 80}], {
             RGBColor[
             0.8086163665159423, 0.8504788015959455, 0.9815424524658205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 81}], {
             RGBColor[
             0.825653983169494, 0.8638180906717614, 0.9832328080563602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 99}], {
             RGBColor[
             0.9106556765920616, 0.9271034208247384, 0.765274234275318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 156}], {
             RGBColor[
             0.6474994925034097, 0.7219315348762902, 0.9673172118721224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 267}], {
             RGBColor[
             0.9083762130299251, 0.9201045780958312, 0.6977188544044266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 278}], {
             RGBColor[
             0.8880267801577246, 0.9132258771339024, 0.9778589426846744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 329}], {
             RGBColor[
             0.8551238518896912, 0.8873165640509703, 0.9860436704429549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 406}], {
             RGBColor[
             0.9091541002347256, 0.9227285742942248, 0.700740799303404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 413}], {
             RGBColor[
             0.9007629224656561, 0.8944231613369187, 0.6681426582115271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 486}], {
             RGBColor[
             0.8813087089314302, 0.9081956582870432, 0.9885412054830938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 28}], {
             RGBColor[
             0.901769090567154, 0.9237583305634441, 0.9644245605513657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 49}], {
             RGBColor[
             0.6644484112533559, 0.7356118894004525, 0.9687430433701605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 69}], {
             RGBColor[
             0.874072307624645, 0.9024255483118935, 0.9878509910664408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 142}], {
             RGBColor[
             0.7691032060058948, 0.819699666861827, 0.9775805727504322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 173}], {
             RGBColor[
             0.9116225315818571, 0.9310453814508525, 0.9449853696775101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[
             0.9125990982944516, 0.9314492168831301, 0.9288011319761822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 241}], {
             RGBColor[
             0.7720821236708154, 0.8220268199822758, 0.9778774834237032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 388}], {
             RGBColor[
             0.8924271040987608, 0.9167910923514154, 0.9802381068620604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 402}], {
             RGBColor[
             0.6954966701641224, 0.7608182646923372, 0.971187276045136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 436}], {
             RGBColor[
             0.6558009604167452, 0.7285914992480711, 0.9680622843636464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 461}], {
             RGBColor[
             0.8915688064008891, 0.9161509753336762, 0.9816909809846657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 487}], {
             RGBColor[
             0.7090567422484308, 0.7718269420846646, 0.9722547745917934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 31}], {
             RGBColor[
             0.5366659458722182, 0.6347210217205881, 0.9566695542776334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 40}], {
             RGBColor[
             0.5032468930597369, 0.6057751178648505, 0.9545401217837302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 114}], {
             RGBColor[
             0.5604860564407306, 0.6540668560845098, 0.9585426619725401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 115}], {
             RGBColor[
             0.7707310045144475, 0.8213000079229384, 0.9777969948316587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 162}], {
             RGBColor[
             0.5411625228784538, 0.6383791410233868, 0.9570214426260819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 203}], {
             RGBColor[
             0.5774301323005686, 0.6678228201894449, 0.9598765616924215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 221}], {
             RGBColor[
             0.5784518548396522, 0.6686523005747489, 0.9599569954333912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 258}], {
             RGBColor[
             0.4968580357130886, 0.6002414107444907, 0.9541330294430466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 289}], {
             RGBColor[
             0.5298323406094952, 0.6288020963090049, 0.9562341229930127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 291}], {
             RGBColor[
             0.637610384777719, 0.7164873323549865, 0.9647458039813404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 297}], {
             RGBColor[
             0.5698289191235334, 0.6616518129015765, 0.9592781663469641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 311}], {
             RGBColor[
             0.6835752486050087, 0.752395433322769, 0.9693271520415703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 381}], {
             RGBColor[
             0.5947992155017207, 0.6819238244004215, 0.9612439195470645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 419}], {
             RGBColor[
             0.5664920822105015, 0.6589428183727875, 0.9590154783219338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 439}], {
             RGBColor[
             0.7406030565482964, 0.7972768000160912, 0.9749233642591105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 19}], {
             RGBColor[
             0.5674341026863339, 0.6597075930326068, 0.9590896376245259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 26}], {
             RGBColor[
             0.4808866078491948, 0.5876336896788764, 0.952776616899017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 34}], {
             RGBColor[
             0.559448373541096, 0.6532244183595045, 0.9584609717735231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 44}], {
             RGBColor[
             0.5359104641208152, 0.634115283121385, 0.9566079813217554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.5464995084832656, 0.6427119463658346, 0.9574415896829152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 117}], {
             RGBColor[
             0.4781094761010015, 0.5852282777412916, 0.9525996605197433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 139}], {
             RGBColor[
             0.5695894293133013, 0.6614573842847371, 0.9592593128318224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 247}], {
             RGBColor[
             0.5350775301382318, 0.6334390697910756, 0.9565424097075088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 269}], {
             RGBColor[
             0.512041509774998, 0.614618499836106, 0.9547617797005311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 360}], {
             RGBColor[
             0.5772550006439877, 0.6676806404210414, 0.9598627746868871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 425}], {
             RGBColor[
             0.47524326414852586`, 0.5827457090080587, 0.9524170280286233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 466}], {
             RGBColor[
             0.5393259259475076, 0.6368881088970959, 0.9568768589880016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 468}], {
             RGBColor[
             0.5267603512092651, 0.6266868092518996, 0.9558876509153902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 120}], {
             RGBColor[
             0.21319195993880496`, 0.3414086454196232, 0.9354523387780493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 123}], {
             RGBColor[
             0.21296296597852177`, 0.34116795824830987`, 0.9354392979107774]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 125}], {
             RGBColor[
             0.21381800062875955`, 0.3420666538780378, 0.935487990869198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 177}], {
             RGBColor[
             0.21382948684753797`, 0.34207872662224226`, 0.9354886449923652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 245}], {
             RGBColor[
             0.22026264269435236`, 0.3488403813028832, 0.93585500370084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 438}], {
             RGBColor[
             0.22021348611856342`, 0.3487887146250221, 0.9358522043065695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 455}], {
             RGBColor[
             0.21145152724630215`, 0.3395793403099965, 0.9353532237109508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 23}], {
             RGBColor[
             0.23070981980428998`, 0.3598210268347142, 0.9364499549820375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 41}], {
             RGBColor[
             0.23572240363091454`, 0.3650895702526674, 0.9367354142155104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 102}], {
             RGBColor[
             0.2577278443328788, 0.3882186836559568, 0.9379885915093551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 186}], {
             RGBColor[
             0.23731427099118235`, 0.3667627237785289, 0.936826068706721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 193}], {
             RGBColor[
             0.2633649248993141, 0.3941436127428313, 0.9383096149083003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 202}], {
             RGBColor[
             0.2389875961328362, 0.3685214945973489, 0.9369213620980754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 211}], {
             RGBColor[
             0.23497926878004616`, 0.3643084884069338, 0.936693093785123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 414}], {
             RGBColor[
             0.25678804986481485`, 0.38723090008361066`, 0.9379350716047002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 485}], {
             RGBColor[
             0.24345966129558455`, 0.3732219186287056, 0.9371760395932665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 497}], {
             RGBColor[
             0.2374558873234022, 0.36691157152268605`, 0.9368341335473384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 198}], {
             RGBColor[
             0.2771414265920781, 0.4086235895025834, 0.9390941662991953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 373}], {
             RGBColor[
             0.28300945147034123`, 0.414791255703904, 0.9394283416350475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 480}], {
             RGBColor[
             0.31297532312712917`, 0.4421451064609878, 0.9412865192071291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 154}], {
             RGBColor[
             0.3030787322552839, 0.435811820273263, 0.9405739494865415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 229}], {
             RGBColor[
             0.2937960299949141, 0.4261286336418093, 0.9400426213247091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 244}], {
             RGBColor[
             0.3195286449146627, 0.4500599078221664, 0.9416221233751105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 313}], {
             RGBColor[
             0.2817870779153078, 0.4135064635946042, 0.939358729269428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 334}], {
             RGBColor[
             0.3497101697631252, 0.47620162767835794`, 0.94354526344998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 338}], {
             RGBColor[
             0.30836079438708164`, 0.4403868770076641, 0.9409105178148355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 340}], {
             RGBColor[
             0.3170254114231826, 0.44789173278801986`, 0.9414626195505558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 363}], {
             RGBColor[
             0.3507138092232281, 0.4770709297343131, 0.9436092144688942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 379}], {
             RGBColor[
             0.3029577301181068, 0.43570701430378433`, 0.9405662393373586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 380}], {
             RGBColor[
             0.28473366122711574`, 0.4166035094794867, 0.939526532829956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 390}], {
             RGBColor[
             0.29868486413343276`, 0.4312671082913797, 0.9403210331965157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 478}], {
             RGBColor[
             0.28132910192119526`, 0.41302510178743673`, 0.939332648214078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 63}], {
             RGBColor[
             0.3630391373968948, 0.48868276614576933`, 0.9443602925394342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 72}], {
             RGBColor[
             0.2803635687690008, 0.4120102652261427, 0.9392776625294388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 75}], {
             RGBColor[
             0.32584559541094904`, 0.45646758947931865`, 0.9419903529330476]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 149}], {
             RGBColor[
             0.33030872638618497`, 0.46033332920658265`, 0.9422747396921978]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 158}], {
             RGBColor[
             0.33213200521333075`, 0.4619125616859979, 0.9423909174068014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 163}], {
             RGBColor[
             0.2868674954285888, 0.4188463045181374, 0.9396480515310051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 182}], {
             RGBColor[
             0.34266467028924463`, 0.47103542678761523`, 0.9430620495117685]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 187}], {
             RGBColor[
             0.28568538812664784`, 0.41760383479386565`, 0.9395807322689307]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 279}], {
             RGBColor[
             0.2926514518650601, 0.4249256094568878, 0.9399774392934654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 322}], {
             RGBColor[
             0.2829806146027809, 0.4147609463277351, 0.9394266994181002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 324}], {
             RGBColor[
             0.33821006500838097`, 0.4671770715883025, 0.9427782060023248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 441}], {
             RGBColor[
             0.3784375409652084, 0.5020200893703757, 0.9453414651985335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 494}], {
             RGBColor[
             0.2826231066390982, 0.4143851827905905, 0.9394063398684542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 78}], {
             RGBColor[
             0.22683394628673456`, 0.35574723802318886`, 0.9362292297190538]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 97}], {
             RGBColor[
             0.23298665056537604`, 0.36221412032402367`, 0.936579617125612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 104}], {
             RGBColor[
             0.24040623048550225`, 0.3700125692486139, 0.9370021512257783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.24125115959042637`, 0.3709006433094886, 0.9370502686883432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 148}], {
             RGBColor[
             0.2369473179686802, 0.36637703288571377`, 0.9368051712749479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 153}], {
             RGBColor[
             0.23958587882071014`, 0.3691503276356177, 0.93695543341207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 190}], {
             RGBColor[
             0.24117420601353035`, 0.37081976022103225`, 0.9370458862959816]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 323}], {
             RGBColor[
             0.2367917298527569, 0.36621349991102203`, 0.936796310761918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 356}], {
             RGBColor[
             0.2517883622305454, 0.38197591138148856`, 0.9376503467903037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 408}], {
             RGBColor[
             0.22837166352845595`, 0.3573634763411423, 0.9363168004411209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 430}], {
             RGBColor[
             0.23698890967688827`, 0.36642074840810707`, 0.9368075398612009]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 452}], {
             RGBColor[
             0.22909610908040262`, 0.3581249145487392, 0.9363580565435832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 39}], {
             RGBColor[
             0.5137718344766236, 0.6147998451486828, 0.9552360290912556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 45}], {
             RGBColor[
             0.343332276555383, 0.46939838880724916`, 0.9431857012274175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 52}], {
             RGBColor[
             0.6198385630520318, 0.4001930339226935, 0.5644333341255259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 56}], {
             RGBColor[
             0.6202778449645745, 0.4035695471970573, 0.5648539909810746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 179}], {
             RGBColor[
             0.29140560923354364`, 0.4148201691111312, 0.940228554342059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 200}], {
             RGBColor[
             0.6523550443789783, 0.5834045301394526, 0.5929583920999518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 236}], {
             RGBColor[
             0.34560261915581325`, 0.4717846628283363, 0.9433149938798411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 243}], {
             RGBColor[
             0.6215940953786275, 0.41368682466407874`, 0.566114433864064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 254}], {
             RGBColor[
             0.3201901654275895, 0.4450745627173458, 0.941867792234375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 276}], {
             RGBColor[
             0.5117111188744836, 0.6131268633886855, 0.9550738020104051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 283}], {
             RGBColor[
             0.29254812031783006`, 0.4160210207001029, 0.9402936186581154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 292}], {
             RGBColor[
             0.29142635679170903`, 0.41484197611023416`, 0.9402297358848033]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 422}], {
             RGBColor[
             0.3189470428658002, 0.4437679620863825, 0.9417969982435161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 454}], {
             RGBColor[
             0.6518822537994468, 0.581257698540845, 0.5925638840512331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 205}], {
             RGBColor[
             0.9368989095333399, 0.9481665884975428, 0.7789256469520753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 252}], {
             RGBColor[
             0.8078836333626171, 0.8503289562761027, 0.9813572830192461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 282}], {
             RGBColor[
             0.7438148228852721, 0.7997463454963281, 0.9753349394405884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 293}], {
             RGBColor[
             0.9171217844286204, 0.9362730779745756, 0.9753514321588153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 298}], {
             RGBColor[
             0.8908055349705915, 0.9157681695861948, 0.9894470212286257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 418}], {
             RGBColor[
             0.9292223734187801, 0.9452976774305406, 0.9548682913375369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 432}], {
             RGBColor[
             0.8892978625365586, 0.9145659925119751, 0.9893032180859526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 467}], {
             RGBColor[
             0.7934052123801664, 0.8390183037645371, 0.979914209324252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 52}], {
             RGBColor[
             0.8600894824934477, 0.42201909265360843`, 0.20357506457964797`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 56}], {
             RGBColor[
             0.8605287644059905, 0.4253956059279722, 0.2039957214351967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 65}], {
             RGBColor[
             0.9349243740088637, 0.7652639008938271, 0.3116367388337401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 88}], {
             RGBColor[
             0.8754970234499582, 0.5275428865427625, 0.2178240033304778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 166}], {
             RGBColor[
             0.8612521660936727, 0.43095598829613885`, 0.2046884517082866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 167}], {
             RGBColor[
             0.9355270875213144, 0.7783260157628717, 0.5479056765432442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 210}], {
             RGBColor[
             0.8602238171594843, 0.4230516477625904, 0.20370370360755374`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 227}], {
             RGBColor[
             0.8650075437066738, 0.45982146624662823`, 0.2082846055515888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 243}], {
             RGBColor[
             0.8618450148200435, 0.43551288339499367`, 0.2052561643181862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 326}], {
             RGBColor[
             0.8797797158009789, 0.5469895922605361, 0.22139758680656518`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 348}], {
             RGBColor[
             0.9221477650002106, 0.7221653986171828, 0.2620020254952798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 428}], {
             RGBColor[
             0.8573587081531882, 0.40102916444142644`, 0.2009600719874468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 434}], {
             RGBColor[
             0.9377932493402739, 0.7792631319127137, 0.510349510564296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 469}], {
             RGBColor[
             0.8724072991337889, 0.5135131700464854, 0.21524586162499276`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 474}], {
             RGBColor[
             0.9387405372806834, 0.7796548598202627, 0.49465049788910304`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 495}], {
             RGBColor[
             0.8632931958328989, 0.4466442372567656, 0.2066429440915829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 26}], {
             RGBColor[
             0.4731770317838775, 0.5813747085166081, 0.9521696908300475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 34}], {
             RGBColor[
             0.5517387974757788, 0.6469654371972362, 0.9578540457045537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 44}], {
             RGBColor[
             0.5282008880554978, 0.6278563019591167, 0.956001055252786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 139}], {
             RGBColor[
             0.5618798532479841, 0.6551984031224687, 0.9586523867628529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 234}], {
             RGBColor[
             0.474151584993228, 0.582218817524079, 0.9522317884987839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 247}], {
             RGBColor[
             0.5273679540729146, 0.6271800886288073, 0.9559354836385393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 269}], {
             RGBColor[
             0.5043319337096805, 0.6083595186738375, 0.9541548536315616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 360}], {
             RGBColor[
             0.5695454245786704, 0.661421659258773, 0.9592558486179177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 393}], {
             RGBColor[
             0.5104680056398668, 0.6134599491568583, 0.954605057791339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 466}], {
             RGBColor[
             0.5316163498821903, 0.6306291277348275, 0.9562699329190321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 468}], {
             RGBColor[
             0.5190507751439478, 0.6204278280896312, 0.9552807248464208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 62}], {
             RGBColor[
             0.8509265138034974, 0.3513524058869604, 0.19479135055817565`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 194}], {
             RGBColor[
             0.9355250585723344, 0.7786349412620628, 0.5492457614630861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 228}], {
             RGBColor[
             0.9388076655030091, 0.7780938721344945, 0.3568427286125849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 388}], {
             RGBColor[
             0.9153530643766437, 0.7639768167303482, 0.6006827363489642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 490}], {
             RGBColor[
             0.9375437932423437, 0.7794697399272263, 0.5157901036631747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 33}], {
             RGBColor[
             0.9296510090196749, 0.7439907144053559, 0.3002556094938443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 65}], {
             RGBColor[
             0.9831762967586118, 0.9549118399527363, 0.38914351910732653`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 119}], {
             RGBColor[
             0.9857675700825197, 0.9687962754074746, 0.5924568745131584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 164}], {
             RGBColor[
             0.8992062375406565, 0.5414501296947882, 0.27233399794458657`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 166}], {
             RGBColor[
             0.9095040888434207, 0.6206039273550481, 0.282195231981873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 175}], {
             RGBColor[
             0.9683090151158134, 0.9568481859192783, 0.670037151361724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 227}], {
             RGBColor[
             0.9132594664564218, 0.6494694053055374, 0.28579138582517527`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 309}], {
             RGBColor[
             0.9869592653755547, 0.967346961753188, 0.4315364838739727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 320}], {
             RGBColor[
             0.9847451317139568, 0.9683734708666063, 0.6094013242659239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 337}], {
             RGBColor[
             0.9205492329643337, 0.9192823831910986, 0.6833909335036439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 348}], {
             RGBColor[
             0.9703996877499586, 0.911813337676092, 0.3395088057688662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 375}], {
             RGBColor[
             0.9695446020803578, 0.9577696846543478, 0.6679456249234423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 428}], {
             RGBColor[
             0.9056106309029361, 0.5906771035003356, 0.2784668522610333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 489}], {
             RGBColor[
             0.9854926800563032, 0.9686826013172827, 0.5970125136401502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 63}], {
             RGBColor[
             0.4353760609281416, 0.5515225941640346, 0.948962755507775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 149}], {
             RGBColor[
             0.40264564991743174`, 0.5231731572248479, 0.9468772026605385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 160}], {
             RGBColor[
             0.4369491379476227, 0.5528851144131592, 0.949062990584439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 165}], {
             RGBColor[
             0.4377248912958056, 0.5535570329728583, 0.9491124209018134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 182}], {
             RGBColor[
             0.4150015938204914, 0.5338752548058805, 0.9476645124801093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 268}], {
             RGBColor[
             0.4305356531895016, 0.5473300762667914, 0.9486543290068734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 275}], {
             RGBColor[
             0.43256024452096153`, 0.549083675519183, 0.9487833341762382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 282}], {
             RGBColor[
             0.5295374583805197, 0.6288897605144723, 0.956120540334634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 285}], {
             RGBColor[
             0.38291743430858444`, 0.506085568433412, 0.9456201382069189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 324}], {
             RGBColor[
             0.41054698853962773`, 0.5300168996065678, 0.9473806689706655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 353}], {
             RGBColor[
             0.5455395337034719, 0.641880966146923, 0.9573802823215901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 441}], {
             RGBColor[
             0.45077446449645514`, 0.564859917388641, 0.9499439281668742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 481}], {
             RGBColor[
             0.38481661217346425`, 0.507730540844516, 0.9457411521410921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 41}], {
             RGBColor[
             0.22751409159888136`, 0.35646211386995863`, 0.9362679629883957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 186}], {
             RGBColor[
             0.22910595895914918`, 0.35813526739582024`, 0.9363586174796061]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 202}], {
             RGBColor[
             0.23077928410080303`, 0.35989403821464017`, 0.9364539108709606]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 211}], {
             RGBColor[
             0.226770956748013, 0.3556810320242251, 0.9362256425580082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 212}], {
             RGBColor[
             0.22050887971367938`, 0.3490991920225246, 0.9358690265348157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 485}], {
             RGBColor[
             0.2352513492635514, 0.3645944622459968, 0.9367085883661517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 497}], {
             RGBColor[
             0.22924757529136902`, 0.3582841151399774, 0.9363666823202235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 77}], {
             RGBColor[
             0.7218949448567346, 0.7822619477143448, 0.9732512022240677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 81}], {
             RGBColor[
             0.8302950804632105, 0.8675187756745408, 0.9836754800593912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 83}], {
             RGBColor[
             0.878858858195596, 0.9062422138097157, 0.9883075365329024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 176}], {
             RGBColor[
             0.7219583100603643, 0.7823133904412213, 0.9732561905650118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 197}], {
             RGBColor[
             0.7672988184851579, 0.8182762435725834, 0.9774043962108645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 237}], {
             RGBColor[
             0.871532203465174, 0.9004001382044219, 0.9876087136641327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 267}], {
             RGBColor[
             0.9130173103236416, 0.9238052630986108, 0.6981615264074577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 270}], {
             RGBColor[
             0.9134975511433701, 0.9314925430785823, 0.899659555679228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 278}], {
             RGBColor[
             0.8926678774514412, 0.9169265621366819, 0.9783016146877055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 329}], {
             RGBColor[
             0.8597649491834076, 0.8910172490537498, 0.986486342445986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 426}], {
             RGBColor[
             0.8535732035252862, 0.8860801191364223, 0.9858957682176778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 448}], {
             RGBColor[
             0.7024556642269519, 0.7664802639694746, 0.97172087084446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 489}], {
             RGBColor[
             0.9135348042436461, 0.9315079481929074, 0.8990421753997224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[
             0.36235029179287925`, 0.48827134332094824`, 0.9443096180726283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 96}], {
             RGBColor[
             0.3047685081778331, 0.4372333951604509, 0.9406831592217764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 157}], {
             RGBColor[
             0.3079594456965586, 0.4405872728097553, 0.9408648783928987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.2917531123703574, 0.42355338894303707`, 0.9399419516850931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 246}], {
             RGBColor[
             0.3037983452782409, 0.43621369244109887`, 0.940627909879872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 288}], {
             RGBColor[
             0.2847205959795895, 0.4161617683290476, 0.9395414602803146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 333}], {
             RGBColor[
             0.34601220845973285`, 0.4741201167137219, 0.94326856984984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 343}], {
             RGBColor[
             0.3031313951145783, 0.4355126855320067, 0.9405899280547156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 392}], {
             RGBColor[
             0.3096883372024623, 0.4424044474005129, 0.9409633362064942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 459}], {
             RGBColor[
             0.35196069990557133`, 0.47927240102423385`, 0.9436476024647243]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 465}], {
             RGBColor[
             0.2980004320712376, 0.430119718051609, 0.9402977272999771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 492}], {
             RGBColor[
             0.29499729755319337`, 0.42696323326341856`, 0.9401267032319138]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 34}], {
             RGBColor[
             0.46519130263863967`, 0.5748915338435057, 0.9515410249790447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 44}], {
             RGBColor[
             0.4416533932183588, 0.5557823986053863, 0.949688034527277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 106}], {
             RGBColor[
             0.45224243758080923`, 0.5643790618498358, 0.9505216428884367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 117}], {
             RGBColor[
             0.38385240519854513`, 0.5068953932252928, 0.9456797137252648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 139}], {
             RGBColor[
             0.4753323584108449, 0.5831244997687381, 0.952339366037344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 215}], {
             RGBColor[
             0.33537631974199883`, 0.4626312893738342, 0.942674216260174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 224}], {
             RGBColor[
             0.34279791451999597`, 0.4704318560417961, 0.9430968651035153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 247}], {
             RGBColor[
             0.44082045923577545`, 0.5551061852750767, 0.9496224629130303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 269}], {
             RGBColor[
             0.4177844388725415, 0.5362856153201071, 0.9478418329060527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 351}], {
             RGBColor[
             0.3383374936256977, 0.4657436708748698, 0.9428428507321864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 360}], {
             RGBColor[
             0.48299792974153133`, 0.5893477559050426, 0.9529428278924086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 425}], {
             RGBColor[
             0.38098619324606947`, 0.5044128244920598, 0.9454970812341448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 466}], {
             RGBColor[
             0.4450688550450512, 0.558555224381097, 0.9499569121935232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 468}], {
             RGBColor[
             0.43250328030680874`, 0.5483539247359007, 0.9489677041209118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 40}], {
             RGBColor[
             0.44915953688308596`, 0.5618645655130168, 0.9502821669769903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 114}], {
             RGBColor[
             0.5063987002640795, 0.610156303732676, 0.9542847071658003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 199}], {
             RGBColor[
             0.4274813973658525, 0.5430880506381621, 0.9489008550961784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 220}], {
             RGBColor[
             0.4255160611016982, 0.5413857751468245, 0.948775625607305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 277}], {
             RGBColor[
             0.6417102241932708, 0.7180330594388474, 0.9662874050409727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 289}], {
             RGBColor[
             0.47574498443284424`, 0.5848915439571711, 0.9519761681862727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 291}], {
             RGBColor[
             0.583523028601068, 0.6725767800031528, 0.9604878491746004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 297}], {
             RGBColor[
             0.5157415629468824, 0.6177412605497428, 0.9550202115402241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 311}], {
             RGBColor[
             0.6294878924283578, 0.7084848809709354, 0.9650691972348303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 319}], {
             RGBColor[
             0.6135043005796454, 0.695998377538924, 0.9634761021745089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 349}], {
             RGBColor[
             0.46286019331944683`, 0.5737313855031778, 0.9511551606901004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 359}], {
             RGBColor[
             0.44878508964320496`, 0.5615402381340974, 0.9502583075299758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 371}], {
             RGBColor[
             0.43753141765926407`, 0.551792873087608, 0.9495412335023905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 419}], {
             RGBColor[
             0.5124047260338506, 0.6150322660209537, 0.9547575235151939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 488}], {
             RGBColor[
             0.640741608541348, 0.7172763695298137, 0.9661908624850168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 69}], {
             RGBColor[
             0.9371592911405698, 0.9519775158592825, 0.9678001094752631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 142}], {
             RGBColor[
             0.8321901895218196, 0.869251634409216, 0.9575296911592543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 173}], {
             RGBColor[
             0.9747095150977819, 0.9805973489982415, 0.9249344880863324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 194}], {
             RGBColor[
             0.9756860818103763, 0.9810011844305191, 0.9087502503850045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 241}], {
             RGBColor[
             0.8351691071867402, 0.8715787875296648, 0.9578266018325254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 417}], {
             RGBColor[
             0.8329443683967894, 0.8698408046783143, 0.9576048606613091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 461}], {
             RGBColor[
             0.954655789916814, 0.9657029428810652, 0.9616400993934879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 493}], {
             RGBColor[
             0.9792166674892435, 0.9809905167708368, 0.7433381739278018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 77}], {
             RGBColor[
             0.5082190929851442, 0.6104476858288989, 0.9547558471761093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 172}], {
             RGBColor[
             0.3806363827099919, 0.5041098361876981, 0.9454747916161113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 318}], {
             RGBColor[
             0.37578131668551923`, 0.4999046220200136, 0.9451654311021982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 321}], {
             RGBColor[
             0.3713978817482214, 0.49610791099517215`, 0.944886122504113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 383}], {
             RGBColor[
             0.3692814154214852, 0.49427473423964385`, 0.944751263141291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 479}], {
             RGBColor[
             0.410555492074131, 0.5300242649407545, 0.9473812108083647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 482}], {
             RGBColor[
             0.38405087443932273`, 0.5070672973063002, 0.9456923600097877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 43}], {
             RGBColor[
             0.2805395184040802, 0.4121951994484624, 0.9392876826008625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 64}], {
             RGBColor[
             0.27788283656739987`, 0.4094028583947541, 0.9391363885004721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 110}], {
             RGBColor[
             0.26982326266389456`, 0.40093173521567016`, 0.9386774076897386]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 217}], {
             RGBColor[
             0.2938254921740675, 0.42514500116830317`, 0.9400814485951139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 290}], {
             RGBColor[
             0.2772082322816696, 0.40869380651806936`, 0.9390979707843874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 316}], {
             RGBColor[
             0.25921313179459604`, 0.3897798149508858, 0.938073176433014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 355}], {
             RGBColor[
             0.29831901354920054`, 0.4290370635324922, 0.9403677718036725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 378}], {
             RGBColor[
             0.2755078252460146, 0.406906570911563, 0.9390011351192336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 384}], {
             RGBColor[
             0.2758760121335012, 0.4072935586747084, 0.9390221028177923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[
             0.4196192099941566, 0.5378748018473721, 0.9479587428994976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 114}], {
             RGBColor[
             0.47685837337515014`, 0.5861665400670314, 0.9519612830883075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 162}], {
             RGBColor[
             0.4575348398128734, 0.5704788250059085, 0.9504400637418493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 203}], {
             RGBColor[
             0.4938024492349883, 0.5999225041719667, 0.9532951828081889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 208}], {
             RGBColor[
             0.38757839390763205`, 0.5101226573714661, 0.9459171304310454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 221}], {
             RGBColor[
             0.4948241717740719, 0.6007519845572706, 0.9533756165491586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 223}], {
             RGBColor[
             0.42145102378698707`, 0.5394614268850837, 0.9480754644545675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 258}], {
             RGBColor[
             0.4132303526475083, 0.5323410947270124, 0.947551650558814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 289}], {
             RGBColor[
             0.4462046575439149, 0.5609017802915265, 0.9496527441087801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 297}], {
             RGBColor[
             0.48620123605795307`, 0.5937514968840982, 0.9526967874627315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 314}], {
             RGBColor[
             0.3915568678230763, 0.5135686115131106, 0.9461706352709112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 381}], {
             RGBColor[
             0.5111715324361403, 0.6140235083829432, 0.9546625406628318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 397}], {
             RGBColor[
             0.40579315804314603`, 0.5258993705649835, 0.947077759095077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 419}], {
             RGBColor[
             0.4828643991449212, 0.5910425023553091, 0.9524340994377012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 472}], {
             RGBColor[
             0.39074248974700837`, 0.5128632381554529, 0.9461187438200305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 103}], {
             RGBColor[
             0.5080332189208779, 0.6114832796124914, 0.9544133824619024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 155}], {
             RGBColor[
             0.5507999265063706, 0.6462032194486154, 0.9577801343426442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 331}], {
             RGBColor[
             0.6862012136677067, 0.7532861971667737, 0.9704389262848694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 344}], {
             RGBColor[
             0.49972685632516956`, 0.6047398002599247, 0.9537594751711596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 403}], {
             RGBColor[
             0.73231135392298, 0.7900531713799142, 0.9748369526254256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 449}], {
             RGBColor[
             0.6320067542390264, 0.7108140314884382, 0.9650731650607731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 119}], {
             RGBColor[
             0.9345308133147854, 0.7655949021985857, 0.5124594755699873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 159}], {
             RGBColor[
             0.8495822086293704, 0.3506448894924134, 0.19388094901806585`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 164}], {
             RGBColor[
             0.8479694807729221, 0.33824875648589925`, 0.19233659900141542`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 227}], {
             RGBColor[
             0.8620227096886874, 0.44626803209664856`, 0.20579398688200412`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 267}], {
             RGBColor[
             0.9337384293685642, 0.7577785430140971, 0.3161344657047144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 270}], {
             RGBColor[
             0.9342186701882929, 0.7654658229940685, 0.5176324949764846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 309}], {
             RGBColor[
             0.9357225086078202, 0.7641455885442991, 0.35153908493080155`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 443}], {
             RGBColor[
             0.9064631162110222, 0.6594290978497701, 0.24321160823769428`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 489}], {
             RGBColor[
             0.9342559232885688, 0.7654812281083937, 0.517015114696979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 234}], {
             RGBColor[
             0.4661658558479902, 0.5757356428509766, 0.951603122647781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 269}], {
             RGBColor[
             0.4963462045644428, 0.6018763440007352, 0.9535261877805588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 332}], {
             RGBColor[
             0.47297256082386624`, 0.5816312685861409, 0.9520368398699108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 360}], {
             RGBColor[
             0.5615596954334325, 0.6549384845856707, 0.9586271827669148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 393}], {
             RGBColor[
             0.5024822764946291, 0.606976774483756, 0.9539763919403361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 468}], {
             RGBColor[
             0.51106504599871, 0.6139446534165288, 0.9546520589954179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 54}], {
             RGBColor[
             0.23354661261843296`, 0.36280267594543125`, 0.936611506136144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 67}], {
             RGBColor[
             0.24749774961125026`, 0.377466205478057, 0.9374060027490273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 70}], {
             RGBColor[
             0.24831129577393707`, 0.37832129407684667`, 0.9374523329994586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 84}], {
             RGBColor[
             0.2358433607180927, 0.36521670382041393`, 0.9367423025426853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 131}], {
             RGBColor[
             0.2509907389862678, 0.38113755877951816`, 0.9376049233265198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 135}], {
             RGBColor[
             0.24449959825218992`, 0.3743149583059091, 0.9372352624644963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 147}], {
             RGBColor[
             0.2449327987863818, 0.374770279533845, 0.9372599325940558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 171}], {
             RGBColor[
             0.25005732664065045`, 0.38015648322251344`, 0.9375517668742968]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 216}], {
             RGBColor[
             0.25212920477180323`, 0.3823341585030158, 0.9376697572687969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 281}], {
             RGBColor[
             0.2416405448941051, 0.37130991195210916`, 0.9370724436053437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 385}], {
             RGBColor[
             0.235922007593164, 0.36529936667261376`, 0.936746781365873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 391}], {
             RGBColor[
             0.23974982774210207`, 0.3693226483469626, 0.9369647700606025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 37}], {
             RGBColor[
             0.2800147441029785, 0.41164362838539204`, 0.9392577974807488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 58}], {
             RGBColor[
             0.28475051663686596`, 0.4160326690739975, 0.9395490426575464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 141}], {
             RGBColor[
             0.28198608489330845`, 0.4136382572421074, 0.9393728955113378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 240}], {
             RGBColor[
             0.25550742159800177`, 0.3858848785786683, 0.9378621417194251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 251}], {
             RGBColor[
             0.25646724614478844`, 0.3868937150337323, 0.9379168023074314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 310}], {
             RGBColor[
             0.2755731801551128, 0.4069752630647657, 0.9390048569846228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 352}], {
             RGBColor[
             0.2411100918235177, 0.37075237214225454`, 0.9370422350877088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 367}], {
             RGBColor[
             0.2421171751521342, 0.3718108805734015, 0.9370995869934273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 382}], {
             RGBColor[
             0.26830699274776615`, 0.39933803939675394`, 0.9385910583611354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 399}], {
             RGBColor[
             0.24794512185068096`, 0.37793642206673694`, 0.937431479936235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 412}], {
             RGBColor[
             0.24838538806776134`, 0.3783991697753788, 0.9374565524459821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 416}], {
             RGBColor[
             0.2579614870777197, 0.3884642569945902, 0.9380018971180304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 429}], {
             RGBColor[
             0.2739936283843697, 0.4053150540043482, 0.9389149038480165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 58}], {
             RGBColor[
             0.31037597127891847`, 0.44296664665046, 0.9410083743899482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 118}], {
             RGBColor[
             0.31537415178862416`, 0.44729581939211016`, 0.9413268540323092]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 141}], {
             RGBColor[
             0.3076115395353609, 0.4405722348185699, 0.9408322272437397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 188}], {
             RGBColor[
             0.3214586719550145, 0.4525659249433619, 0.9417145542769817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 240}], {
             RGBColor[
             0.28113287624005423`, 0.4128188561551308, 0.9393214734518269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 304}], {
             RGBColor[
             0.32210212279026273`, 0.45312324971607465`, 0.9417555543952225]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 310}], {
             RGBColor[
             0.30119863479716524`, 0.4339092406412282, 0.9404641887170249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 429}], {
             RGBColor[
             0.29961908302642226`, 0.4322490315808106, 0.9403742355804184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 47}], {
             RGBColor[
             0.24595116399713765`, 0.375840645938433, 0.9373179269862719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 73}], {
             RGBColor[
             0.25393957190424143`, 0.3842369691431141, 0.937772854998791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 93}], {
             RGBColor[
             0.2646269773927557, 0.3954701099321881, 0.9383814869307624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 108}], {
             RGBColor[
             0.272539685244709, 0.40378686757924537`, 0.9388321039371288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 163}], {
             RGBColor[
             0.2634804930859057, 0.3942650822343853, 0.9383161963455589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 189}], {
             RGBColor[
             0.2598720197723208, 0.3904723479913851, 0.9381106991286081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 266}], {
             RGBColor[
             0.27474470932625494`, 0.40610448769555174`, 0.9389576767965321]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 364}], {
             RGBColor[
             0.2592676752099878, 0.3898371435387148, 0.9380762825998308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 437}], {
             RGBColor[
             0.2578995688543769, 0.3883991770160148, 0.9379983709668107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 45}], {
             RGBColor[
             0.45322202962692537`, 0.5599541419213354, 0.9514657433370749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 100}], {
             RGBColor[
             0.7774382200691679, 0.7351762203070193, 0.6135140654406412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 127}], {
             RGBColor[
             0.4248206994263658, 0.5301025431322064, 0.9498483295981558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 179}], {
             RGBColor[
             0.40129536230508595`, 0.5053759222252174, 0.9485085964517164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 200}], {
             RGBColor[
             0.7622447974505207, 0.6739602832535388, 0.6012384342096092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 213}], {
             RGBColor[
             0.7639337426080279, 0.681629388750616, 0.6026477314488674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 236}], {
             RGBColor[
             0.4554923722273556, 0.5623404159424226, 0.9515950359894985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 243}], {
             RGBColor[
             0.7314838484501698, 0.504242577778165, 0.5743944759737214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 254}], {
             RGBColor[
             0.43007991849913185`, 0.5356303158314321, 0.9501478343440324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 276}], {
             RGBColor[
             0.6216008719460259, 0.7036826165027719, 0.9633538441200625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 283}], {
             RGBColor[
             0.4024378733893724, 0.5065767738141891, 0.9485736607677728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 315}], {
             RGBColor[
             0.40458060190845924`, 0.5088289173445842, 0.948695685987052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 325}], {
             RGBColor[
             0.40133925395865816`, 0.5054220551360133, 0.9485110960164554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 368}], {
             RGBColor[
             0.5158816187650146, 0.6166272342584453, 0.9553704626805029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 401}], {
             RGBColor[
             0.6985569826136641, 0.7641508706261513, 0.9707851169753527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 450}], {
             RGBColor[
             0.7206850354992045, 0.4212381693670362, 0.5640535204963621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 454}], {
             RGBColor[
             0.761772006870989, 0.6718134516549312, 0.6008439261608904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 471}], {
             RGBColor[
             0.7402370852900231, 0.5715237918221177, 0.5827765854569318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 475}], {
             RGBColor[
             0.731332489294519, 0.5030791649818271, 0.5742495342753344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 114}], {
             RGBColor[
             0.443439320562669, 0.5572206362112937, 0.9498318505944043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 199}], {
             RGBColor[
             0.3645220176644419, 0.4901523831167798, 0.9444479985247825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 208}], {
             RGBColor[
             0.3541593410951509, 0.4811767535157284, 0.9437876979371422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 220}], {
             RGBColor[
             0.36255668140028763`, 0.48845010762544216`, 0.9443227690359091]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 289}], {
             RGBColor[
             0.41278560473143366`, 0.5319558764357888, 0.9475233116148768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 291}], {
             RGBColor[
             0.5205636488996574, 0.6196411124817705, 0.9560349926032045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 297}], {
             RGBColor[
             0.4527821832454718, 0.5648055930283604, 0.9505673549688282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 314}], {
             RGBColor[
             0.35813781501059505`, 0.484622707657373, 0.944041202777008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 349}], {
             RGBColor[
             0.3999008136180363, 0.5207957179817955, 0.9467023041187045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 359}], {
             RGBColor[
             0.38582570994179444`, 0.508604570612715, 0.9458054509585798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 371}], {
             RGBColor[
             0.37457203795785354`, 0.49885720556622565`, 0.9450883769309946]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 397}], {
             RGBColor[
             0.37237410523066483`, 0.4969534667092458, 0.9449483266011737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 419}], {
             RGBColor[
             0.44944534633244004`, 0.5620965984995714, 0.950304666943798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 472}], {
             RGBColor[
             0.35732343693452717`, 0.4839173342997152, 0.9439893113261273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 102}], {
             RGBColor[
             0.2545321161274702, 0.38485977069120125`, 0.9378065995157133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 186}], {
             RGBColor[
             0.23411854278577374`, 0.36340381081377343`, 0.9366440767130793]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 191}], {
             RGBColor[
             0.22546402831064583`, 0.35430736737250323`, 0.9361512149169275]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 202}], {
             RGBColor[
             0.2357918679274276, 0.3651625816325934, 0.9367393701044336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 212}], {
             RGBColor[
             0.22552146354030395`, 0.35436773544047784`, 0.9361544857682886]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 295}], {
             RGBColor[
             0.23105727915165333`, 0.3601862286389881, 0.9364697422778497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 300}], {
             RGBColor[
             0.22924216126039493`, 0.3582784246501542, 0.9363663739991688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 389}], {
             RGBColor[
             0.2255132290582107, 0.3543590804777015, 0.9361540168267153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 451}], {
             RGBColor[
             0.22198624668627384`, 0.3506519983811976, 0.9359531603983363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 456}], {
             RGBColor[
             0.22809260204387605`, 0.3570701650273288, 0.9363009083024085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 485}], {
             RGBColor[
             0.24026393309017596`, 0.36986300566395003`, 0.9369940475996247]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 85}], {
             RGBColor[
             0.22334491181980198`, 0.3520800415808806, 0.9360305343677259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 95}], {
             RGBColor[
             0.2297785943922997, 0.3588422498836111, 0.9363969230724491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[
             0.23210438822814727`, 0.3612868066689332, 0.936529373590697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 137}], {
             RGBColor[
             0.22627740530250587`, 0.35516227816202806`, 0.9361975355333305]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 145}], {
             RGBColor[
             0.22656621784669417`, 0.3554658384577429, 0.9362139829804621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 174}], {
             RGBColor[
             0.2495656884148965, 0.3796397402755821, 0.9375237688046536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 248}], {
             RGBColor[
             0.2375069627028864, 0.3669652549848901, 0.9368370422146407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 286}], {
             RGBColor[
             0.2277872668823118, 0.3567492384131574, 0.9362835199166604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 294}], {
             RGBColor[
             0.23539350574473433`, 0.36474387772096156`, 0.9367166839674533]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 346}], {
             RGBColor[
             0.22517846281523107`, 0.3540072199309242, 0.9361349523844199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 358}], {
             RGBColor[
             0.22905024080537584`, 0.3580767040834695, 0.9363554444131764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 407}], {
             RGBColor[
             0.22341630550160935`, 0.352155080867081, 0.9360346001322872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 411}], {
             RGBColor[
             0.23603211668449622`, 0.3654150983089235, 0.9367530519157325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 430}], {
             RGBColor[
             0.2361066473396595, 0.36549343475301654`, 0.9367572963262859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 110}], {
             RGBColor[
             0.2824315567297242, 0.4141838516908727, 0.9393954313844881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 217}], {
             RGBColor[
             0.30643378623989703`, 0.43839711764350564`, 0.9407994722898634]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 290}], {
             RGBColor[
             0.2898165263474991, 0.4219459229932718, 0.9398159944791369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 316}], {
             RGBColor[
             0.2718214258604257, 0.4030319314260883, 0.9387912001277635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 340}], {
             RGBColor[
             0.31529118717805316`, 0.446068953150221, 0.9413638580453506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 355}], {
             RGBColor[
             0.3109273076150301, 0.4422891800076947, 0.941085795498422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 362}], {
             RGBColor[
             0.34080467652755875`, 0.4681674552795022, 0.9429895550260083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 378}], {
             RGBColor[
             0.2881161193118442, 0.42015868738676554`, 0.939719158813983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 384}], {
             RGBColor[
             0.28848430619933074`, 0.4205456751499109, 0.9397401265125418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 57}], {
             RGBColor[
             0.5489601186307986, 0.6447095805328258, 0.9576352979272409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 106}], {
             RGBColor[
             0.5072662938524296, 0.6108606552923443, 0.9543530073111751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 117}], {
             RGBColor[
             0.4388762614701655, 0.5533769866678013, 0.9495110781480034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 139}], {
             RGBColor[
             0.5303562146824653, 0.6296060932112468, 0.9561707304600824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 140}], {
             RGBColor[
             0.4981556569200065, 0.6034642298010868, 0.9536357845984921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 247}], {
             RGBColor[
             0.4958443155073958, 0.6015877787175854, 0.9534538273357688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 255}], {
             RGBColor[
             0.44713138767076954`, 0.5605271620680575, 0.9500370874897843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 269}], {
             RGBColor[
             0.4728082951441619, 0.5827672087626157, 0.9516731973287911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 360}], {
             RGBColor[
             0.5380217860131518, 0.6358293493475512, 0.9567741923151472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 369}], {
             RGBColor[
             0.4583123366675063, 0.5702115381181944, 0.9507495276729314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 370}], {
             RGBColor[
             0.5440602935407461, 0.6407316817901163, 0.9572495657475013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 425}], {
             RGBColor[
             0.43601004951768985`, 0.5508944179345684, 0.9493284456568833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 466}], {
             RGBColor[
             0.5000927113166715, 0.6050368178236056, 0.9537882766162615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 468}], {
             RGBColor[
             0.48752713657842917`, 0.5948355181784093, 0.9527990685436503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 52}], {
             RGBColor[
             0.5592887582023336, 0.3453473306953461, 0.5606630483713451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 56}], {
             RGBColor[
             0.5597280401148761, 0.3487238439697099, 0.5610837052268939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 179}], {
             RGBColor[
             0.2308558043838454, 0.3599744658837838, 0.9364582685878783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 236}], {
             RGBColor[
             0.285052814306115, 0.4169389596009889, 0.9395447081256605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 243}], {
             RGBColor[
             0.5610442905289292, 0.35884112143673136`, 0.5623441481098833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 254}], {
             RGBColor[
             0.25964036057789125`, 0.3902288594899984, 0.9380975064801944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 276}], {
             RGBColor[
             0.4511613140247853, 0.5582811601613382, 0.9513035162562244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 283}], {
             RGBColor[
             0.23199831546813182`, 0.3611753174727555, 0.9365233329039347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 292}], {
             RGBColor[
             0.23087655194201073`, 0.35999627288288677`, 0.9364594501306225]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 386}], {
             RGBColor[
             0.23085473585284239`, 0.35997334278995086`, 0.9364582077366184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 422}], {
             RGBColor[
             0.2583972380161019, 0.3889222588590351, 0.9380267124893356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 53}], {
             RGBColor[
             0.9470835767696775, 0.821834287485996, 0.3079282681448157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 68}], {
             RGBColor[
             0.8688206529626022, 0.4329330984324026, 0.20968686128144703`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 90}], {
             RGBColor[
             0.8912123121580973, 0.5950344530170778, 0.2307371435474895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 205}], {
             RGBColor[
             0.9557407049755898, 0.8502199530826348, 0.4110195083871594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 257}], {
             RGBColor[
             0.8882541401217813, 0.5816020846987996, 0.22826877228895565`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 272}], {
             RGBColor[
             0.8691188894851287, 0.4352254750326188, 0.20997245291222838`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 293}], {
             RGBColor[
             0.9359635798708703, 0.8383264425596675, 0.6074452935938994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 298}], {
             RGBColor[
             0.9096473304128414, 0.8178215341712867, 0.6215408826637097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 306}], {
             RGBColor[
             0.8876171805650555, 0.5774114462757728, 0.22768643734119767`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 317}], {
             RGBColor[
             0.9005275853462438, 0.6373329329271229, 0.23851003583391922`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 357}], {
             RGBColor[
             0.9123985653292456, 0.6903965335177349, 0.2483720332752017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 418}], {
             RGBColor[
             0.9480641688610301, 0.8473510420156326, 0.586962152772621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 420}], {
             RGBColor[
             0.9431488383406506, 0.8436851965616485, 0.5952825252201055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 55}], {
             RGBColor[
             0.22170565849658444`, 0.35035708240351526`, 0.9359371813160265]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 189}], {
             RGBColor[
             0.24585450838109163`, 0.3757390547576487, 0.9373124225919274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 230}], {
             RGBColor[
             0.22790583767600858`, 0.3568738638351552, 0.9362902723479516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 242}], {
             RGBColor[
             0.2284706396727983, 0.35746750654429615`, 0.9363224369861192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 339}], {
             RGBColor[
             0.22181216919966315`, 0.3504690319056196, 0.9359432469429985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 364}], {
             RGBColor[
             0.24525016381875867`, 0.3751038503049783, 0.93727800606315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 365}], {
             RGBColor[
             0.22445415871552787`, 0.3532459303986038, 0.9360937043374536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 374}], {
             RGBColor[
             0.24183198733731956`, 0.37151113009807946`, 0.9370833459692711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 437}], {
             RGBColor[
             0.2438820574631478, 0.37366588378227833`, 0.93720009443013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 78}], {
             RGBColor[
             0.21346998781254425`, 0.3417008703429085, 0.9354681720541533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 85}], {
             RGBColor[
             0.21086321568284044`, 0.3389609875556907, 0.9353197202377406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 95}], {
             RGBColor[
             0.21729689825533816`, 0.34572319585842115`, 0.9356861089424638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 137}], {
             RGBColor[
             0.21379570916554433`, 0.34204322413683813`, 0.9354867214033452]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 145}], {
             RGBColor[
             0.21408452170973263`, 0.34234678443255295`, 0.9355031688504769]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 183}], {
             RGBColor[
             0.20623910902756293`, 0.3341007582756985, 0.9350563842044752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 346}], {
             RGBColor[
             0.21269676667826953`, 0.34088816590573434`, 0.9354241382544346]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 358}], {
             RGBColor[
             0.2165685446684143, 0.3449576500582796, 0.9356446302831911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 404}], {
             RGBColor[
             0.21047959213928613`, 0.3385577748882776, 0.9352978734444553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 407}], {
             RGBColor[
             0.2109346093646478, 0.33903602684189116`, 0.935323786002302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 408}], {
             RGBColor[
             0.21500770505426564`, 0.34331710866086196`, 0.9355557427762207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 71}], {
             RGBColor[
             0.6229981269292593, 0.7030794824142605, 0.9646517716159538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 76}], {
             RGBColor[
             0.45077000854144356`, 0.5638542255344485, 0.9502204534950804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 238}], {
             RGBColor[
             0.4051843179606758, 0.5243701915568157, 0.9473157736011174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 328}], {
             RGBColor[
             0.4377638604952656, 0.5525889538048573, 0.9493917132424632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 402}], {
             RGBColor[
             0.521262974366249, 0.6222237910767345, 0.9554548772727531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 431}], {
             RGBColor[
             0.4693773227785792, 0.5799709458958486, 0.9514060951044689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 436}], {
             RGBColor[
             0.4815672646188717, 0.5899970256324685, 0.9523298855912635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 459}], {
             RGBColor[
             0.44038041665413563`, 0.554855283237734, 0.9495584378871766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 462}], {
             RGBColor[
             0.4770465403942916, 0.586326898050649, 0.9519739976203461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 487}], {
             RGBColor[
             0.5348230464505574, 0.633232468469062, 0.9565223758194106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 57}], {
             RGBColor[
             0.5210905073010532, 0.6217476292469348, 0.9555341779806428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 92}], {
             RGBColor[
             0.5250378077135244, 0.6249522255456361, 0.9558449239285502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 106}], {
             RGBColor[
             0.47939668252268425`, 0.5878987040064534, 0.9522518873645769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 117}], {
             RGBColor[
             0.41100665014042015`, 0.5304150353819104, 0.9474099582014052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 139}], {
             RGBColor[
             0.50248660335272, 0.6066441419253559, 0.9540696105134843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 140}], {
             RGBColor[
             0.47028604559026116`, 0.5805022785151959, 0.9515346646518938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 169}], {
             RGBColor[
             0.46684010556596744`, 0.5777047091656451, 0.9512633876302873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 204}], {
             RGBColor[
             0.47141553909134676`, 0.5814192522224795, 0.9516235825177704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 219}], {
             RGBColor[
             0.48360346312109975`, 0.5913139580095534, 0.9525830605432293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 244}], {
             RGBColor[
             0.3916895278498226, 0.5136835149605915, 0.9461790882505088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 255}], {
             RGBColor[
             0.41926177634102413`, 0.5375652107821666, 0.9479359675431862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 274}], {
             RGBColor[
             0.4518361438965558, 0.5655238171616463, 0.9500822208063486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 334}], {
             RGBColor[
             0.42187105269828507`, 0.539825234816783, 0.9481022283253784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 338}], {
             RGBColor[
             0.3805216773222415, 0.5040104841460892, 0.9454674826902338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 340}], {
             RGBColor[
             0.3891862943583425, 0.5115153399264449, 0.9460195844259542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 361}], {
             RGBColor[
             0.5425697371949871, 0.6391572117563517, 0.9572443985054486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 363}], {
             RGBColor[
             0.422874692158388, 0.5406945368727382, 0.9481661793442926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 369}], {
             RGBColor[
             0.43044272533776096`, 0.5472495868323034, 0.9486484077263333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 370}], {
             RGBColor[
             0.5161906822110007, 0.6177697305042253, 0.9551484458009031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 379}], {
             RGBColor[
             0.37511861305326666`, 0.49933062144220947`, 0.9451232042127569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[
             0.18179934664985797`, 0.3084130184462969, 0.9336645758924533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 113}], {
             RGBColor[
             0.17905963075308248`, 0.3055334033307651, 0.9335085531251784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 127}], {
             RGBColor[
             0.20245340605759676`, 0.3301217444268325, 0.9348407940207814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 130}], {
             RGBColor[
             0.1789270004053139, 0.3053940004260106, 0.9335010000230821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 143}], {
             RGBColor[
             0.17892700107920537`, 0.30539400113431325`, 0.9335010000614592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 179}], {
             RGBColor[
             0.1789280689363169, 0.30539512351984355`, 0.9335010608743419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 214}], {
             RGBColor[
             0.1893670578318586, 0.31636716271918164`, 0.9340955458488429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 302}], {
             RGBColor[
             0.18453817957609825`, 0.31129170550381263`, 0.9338205483758626]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 308}], {
             RGBColor[
             0.1789366427891193, 0.3054041351827525, 0.9335015491425751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 315}], {
             RGBColor[
             0.1822133085396902, 0.30884811863921036`, 0.9336881504096776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 325}], {
             RGBColor[
             0.17897196058988912`, 0.30544125643063946`, 0.933503560439081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 347}], {
             RGBColor[
             0.1789270004053139, 0.3053940004260106, 0.9335010000230821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 386}], {
             RGBColor[
             0.1789270004053139, 0.3053940004260106, 0.9335010000230821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 421}], {
             RGBColor[
             0.17899180329589925`, 0.30546211237275633`, 0.9335046904518336]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 423}], {
             RGBColor[
             0.18337644614132015`, 0.31007065000570677`, 0.9337543893753826]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 477}], {
             RGBColor[
             0.21179931412463662`, 0.3399448863700877, 0.9353730296591674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 56}], {
             RGBColor[
             0.836234326611525, 0.27951848908515425`, 0.18233133812500216`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 88}], {
             RGBColor[
             0.8512025856554928, 0.3816657696999445, 0.19615962002028325`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 166}], {
             RGBColor[
             0.8369577282992072, 0.2850788714533209, 0.18302406839809204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 210}], {
             RGBColor[
             0.8359293793650189, 0.2771745309197725, 0.1820393202973592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 227}], {
             RGBColor[
             0.8407131059122084, 0.31394434940381033`, 0.18662022224139424`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 236}], {
             RGBColor[
             0.5615591008027638, 0.3477336047164332, 0.5607923410237687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 243}], {
             RGBColor[
             0.837550577025578, 0.2896357665521757, 0.18359178100799164`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 276}], {
             RGBColor[
             0.7276676005214341, 0.4890758052767825, 0.5725511491543327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 326}], {
             RGBColor[
             0.8554852780065134, 0.4011124754177182, 0.19973320349637064`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 428}], {
             RGBColor[
             0.8330642703587228, 0.25515204759860854`, 0.17929568867725226`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 469}], {
             RGBColor[
             0.8481128613393234, 0.36763605320366755`, 0.19358147831479822`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 495}], {
             RGBColor[
             0.8389987580384334, 0.3007671204139477, 0.18497856078138836`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 90}], {
             RGBColor[
             0.9206410418975434, 0.7056328015929743, 0.28606405077970154`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 178}], {
             RGBColor[
             0.9840984713626098, 0.9616310168446078, 0.5753629014776818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 257}], {
             RGBColor[
             0.9176828698612274, 0.692200433274696, 0.28359567952116765`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 272}], {
             RGBColor[
             0.8985476192245749, 0.5458238236085153, 0.2652993601444404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[
             0.9653923096103165, 0.9489247911355639, 0.6627722008261114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 298}], {
             RGBColor[
             0.9390760601522875, 0.9284198827471832, 0.6768677898959217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 306}], {
             RGBColor[
             0.9170459103045016, 0.6880097948516692, 0.28301334457340965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 317}], {
             RGBColor[
             0.9299563150856899, 0.7479312815030192, 0.29383694306613123`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 357}], {
             RGBColor[
             0.9418272950686917, 0.8009948820936315, 0.3036989405074137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 418}], {
             RGBColor[
             0.9774928986004763, 0.9579493905915291, 0.642289060004833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 420}], {
             RGBColor[
             0.9725775680800968, 0.9542835451375451, 0.6506094324523175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 432}], {
             RGBColor[
             0.9375683877182548, 0.9272177056729635, 0.6767239867532486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 55}], {
             RGBColor[
             0.22009923076516985`, 0.34866862500439766`, 0.9358456976332195]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 70}], {
             RGBColor[
             0.24348548029858347`, 0.3732490560378767, 0.9371775099472914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 84}], {
             RGBColor[
             0.23101754524273913`, 0.3601444657814439, 0.9364674794905181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 131}], {
             RGBColor[
             0.24616492351091418`, 0.3760653207405481, 0.9373301002743527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 135}], {
             RGBColor[
             0.23967378277683635`, 0.36924272026693905`, 0.9369604394123292]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 147}], {
             RGBColor[
             0.2401069833110282, 0.36969804149487495`, 0.9369851095418886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 230}], {
             RGBColor[
             0.22629940994459397`, 0.3551854064360376, 0.9361987886651444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 242}], {
             RGBColor[
             0.22686421194138368`, 0.35577904914517844`, 0.936230953303312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 365}], {
             RGBColor[
             0.22284773098411328`, 0.35155747299948614`, 0.9360022206546466]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 374}], {
             RGBColor[
             0.24022555960590497`, 0.3698226726989618, 0.9369918622864639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 385}], {
             RGBColor[
             0.23109619211781043`, 0.36022712863364376`, 0.9364719583137058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 391}], {
             RGBColor[
             0.23492401226674847`, 0.36425041030799266`, 0.9366899470084354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 230}], {
             RGBColor[
             0.21767784356668446`, 0.34612359353397393`, 0.935707803214387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 242}], {
             RGBColor[
             0.21824264556347417`, 0.34671723624311485`, 0.9357399678525544]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 250}], {
             RGBColor[
             0.20796149957955015`, 0.33591109995170554`, 0.9351544717983624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 339}], {
             RGBColor[
             0.21158417509033906`, 0.33971876160443837`, 0.9353607778094337]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 365}], {
             RGBColor[
             0.21422616460620378`, 0.3424956600974225, 0.935511235203889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 88}], {
             RGBColor[
             0.8516418675680354, 0.38504228297430826`, 0.19658027687583196`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 164}], {
             RGBColor[
             0.8270991589089857, 0.20930158706742483`, 0.17358349121635427`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 166}], {
             RGBColor[
             0.8373970102117498, 0.28845538472768467`, 0.18344472525364075`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 210}], {
             RGBColor[
             0.8363686612775614, 0.28055104419413623`, 0.18245997715290796`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 227}], {
             RGBColor[
             0.8411523878247509, 0.31732086267817405`, 0.187040879096943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 236}], {
             RGBColor[
             0.5619983827153064, 0.35111011799079705`, 0.5612129978793174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 243}], {
             RGBColor[
             0.8379898589381207, 0.2930122798265395, 0.18401243786354038`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 276}], {
             RGBColor[
             0.7281068824339767, 0.4924523185511463, 0.5729718060098814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 326}], {
             RGBColor[
             0.8559245599190561, 0.404488988692082, 0.2001538603519194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 428}], {
             RGBColor[
             0.8335035522712653, 0.25852856087297227`, 0.179716345532801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 495}], {
             RGBColor[
             0.839438039950976, 0.30414363368831143`, 0.18539921763693712`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 92}], {
             RGBColor[
             0.6051902881840892, 0.690359765316458, 0.9620619428523739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 106}], {
             RGBColor[
             0.5595491629932491, 0.6533062437772754, 0.9584689062884005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 139}], {
             RGBColor[
             0.5826390838232848, 0.6720516816961779, 0.9602866294373078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 140}], {
             RGBColor[
             0.550438526060826, 0.6459098182860178, 0.9577516835757175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 169}], {
             RGBColor[
             0.5469925860365322, 0.6431122489364671, 0.9574804065541109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 175}], {
             RGBColor[
             0.7784866261079177, 0.8268297266210345, 0.9607862455954495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 204}], {
             RGBColor[
             0.5515680195619116, 0.6468267919933015, 0.9578406014415939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 219}], {
             RGBColor[
             0.5637559435916646, 0.6567214977803754, 0.9588000794670529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 255}], {
             RGBColor[
             0.499414256811589, 0.6029727505529885, 0.9541529864670097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 274}], {
             RGBColor[
             0.5319886243671207, 0.6309313569324684, 0.9562992397301722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 334}], {
             RGBColor[
             0.5020235331688498, 0.6052327745876049, 0.9543192472492019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 337}], {
             RGBColor[
             0.730726843956438, 0.7892639238928545, 0.9741400277373693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 361}], {
             RGBColor[
             0.622722217665552, 0.7045647515271736, 0.9634614174292722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 363}], {
             RGBColor[
             0.5030271726289528, 0.6061020766435601, 0.9543831982681161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 369}], {
             RGBColor[
             0.5105952058083258, 0.6126571266031253, 0.9548654266501568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 370}], {
             RGBColor[
             0.5963431626815656, 0.6831772702750474, 0.9613654647247267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 466}], {
             RGBColor[
             0.552375580457491, 0.6474824063085367, 0.957904175593487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 118}], {
             RGBColor[
             0.3201099243225116, 0.4516848600807156, 0.9416180992091068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 141}], {
             RGBColor[
             0.3123473120692484, 0.44496127550717535`, 0.9411234724205373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 188}], {
             RGBColor[
             0.32619444448890195`, 0.45695496563196736`, 0.9420057994537792]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 220}], {
             RGBColor[
             0.32701247471585293`, 0.45766350229915764`, 0.9420579236164848]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 240}], {
             RGBColor[
             0.2858686487739417, 0.41720789684373627`, 0.9396127186286245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 304}], {
             RGBColor[
             0.3268378953241502, 0.4575122904046801, 0.94204679957202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 310}], {
             RGBColor[
             0.3059344073310527, 0.43829828132983367`, 0.9407554338938223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 371}], {
             RGBColor[
             0.3390278312734188, 0.4680706002399412, 0.9428235315115703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 382}], {
             RGBColor[
             0.2986682199237062, 0.43066105766182183`, 0.9403416352703349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 429}], {
             RGBColor[
             0.3043548555603097, 0.4366380722694161, 0.9406654807572159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 74}], {
             RGBColor[
             0.26196255890659237`, 0.3926696371693413, 0.9382297522396293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 82}], {
             RGBColor[
             0.25023486400687867`, 0.3803430862509384, 0.9375618773646605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 105}], {
             RGBColor[
             0.2440481876886619, 0.3738404971825583, 0.9372095553007055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 153}], {
             RGBColor[
             0.24356203444566857`, 0.3733295193002764, 0.9371818695927163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 195}], {
             RGBColor[
             0.2561715150223729, 0.3865828828736374, 0.9378999608575047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 263}], {
             RGBColor[
             0.25779587834217144`, 0.38829019171332857`, 0.9379924659455371]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 323}], {
             RGBColor[
             0.24076788547771533`, 0.3703926915756808, 0.9370227469425643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 342}], {
             RGBColor[
             0.25108912406320616`, 0.3812409677333546, 0.9376105262111039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 395}], {
             RGBColor[
             0.2535893388235434, 0.38386885196924064`, 0.9377529097429688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 447}], {
             RGBColor[
             0.2443455259866942, 0.3741530185861272, 0.9372264882769058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 453}], {
             RGBColor[
             0.26324896867774317`, 0.3940217354019111, 0.9383030113730237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 463}], {
             RGBColor[
             0.2546442329532448, 0.38497761258370766`, 0.9378129844030793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 116}], {
             RGBColor[
             0.27071777339856856`, 0.4018719227130688, 0.9387283487527682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 118}], {
             RGBColor[
             0.30890885152103453`, 0.4405003788871604, 0.9409586647466246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 133}], {
             RGBColor[
             0.31894163191943015`, 0.44919026900604586`, 0.9415979446419711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 151}], {
             RGBColor[
             0.2997519610227203, 0.4323886947798715, 0.9403818027857322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 188}], {
             RGBColor[
             0.31499337168742486`, 0.44577048443841216`, 0.9413463649912971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 192}], {
             RGBColor[
             0.2736621188386635, 0.4049666164528918, 0.9388960248698129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 249}], {
             RGBColor[
             0.29112873348308044`, 0.42332513589150556`, 0.9398907227342717]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 260}], {
             RGBColor[
             0.2891430137819674, 0.4212380185837349, 0.9397776389349024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 280}], {
             RGBColor[
             0.2748009878347767, 0.4061636399762716, 0.9389608817743358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 310}], {
             RGBColor[
             0.2947333345295756, 0.4271138001362785, 0.9400959994313403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 327}], {
             RGBColor[
             0.27488937913222444`, 0.40625654483422113`, 0.9389659155279624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 483}], {
             RGBColor[
             0.29467938491288026`, 0.4270570956685284, 0.9400929270804808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 64}], {
             RGBColor[
             0.3058305702683475, 0.43738338551197825`, 0.9407790232185906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 91}], {
             RGBColor[
             0.32572776888358806`, 0.4565507546784424, 0.9419760632968737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 172}], {
             RGBColor[
             0.3377395733706075, 0.4669547759942509, 0.9427414448571648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 303}], {
             RGBColor[
             0.31454260624684305`, 0.4465402877003618, 0.9412751607792637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 362}], {
             RGBColor[
             0.3561441161626767, 0.48289586592152384`, 0.9439141660493773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 384}], {
             RGBColor[
             0.3038237458344487, 0.43527408579193255`, 0.9406647375359107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 435}], {
             RGBColor[
             0.2909721876561818, 0.42176628331072286`, 0.9399328603098349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 473}], {
             RGBColor[
             0.3253289757704718, 0.4562053401277858, 0.9419506525523447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 132}], {
             RGBColor[
             0.9037259559281465, 0.5621573598635239, 0.4887023579770914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 209}], {
             RGBColor[
             0.6916212861064526, 0.39630413817282756`, 0.5615943615662011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 233}], {
             RGBColor[
             0.8302393984490122, 0.2334388442338099, 0.17659058814627704`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 75}], {
             RGBColor[
             0.38214205273411095`, 0.5054139718854141, 0.9455707315786365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 149}], {
             RGBColor[
             0.3866051837093468, 0.5092797116126782, 0.9458551183377868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 158}], {
             RGBColor[
             0.38842846253649266`, 0.5108589440920934, 0.9459712960523903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 165}], {
             RGBColor[
             0.42168442508772075`, 0.5396635873606885, 0.9480903365790616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 182}], {
             RGBColor[
             0.3989611276124065, 0.5199818091937107, 0.9466424281573576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 206}], {
             RGBColor[
             0.3810348762200533, 0.5044549912372471, 0.9455001832701985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 252}], {
             RGBColor[
             0.5775658026497799, 0.6655789256820774, 0.9611207995905398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 275}], {
             RGBColor[
             0.41651977831287657`, 0.5351902299070133, 0.9477612498534863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 282}], {
             RGBColor[
             0.5134969921724348, 0.6149963149023026, 0.9550984560118821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 324}], {
             RGBColor[
             0.3945065223315428, 0.5161234539943981, 0.9463585846479137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 410}], {
             RGBColor[
             0.39150030357105375`, 0.5135196184010107, 0.9461670310467902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 441}], {
             RGBColor[
             0.4347339982883702, 0.5509664717764713, 0.9489218438441225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 467}], {
             RGBColor[
             0.563087381667329, 0.6542682731705118, 0.9596777258955458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 91}], {
             RGBColor[
             0.3077316474117898, 0.43903000298271255`, 0.9409001581731142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 172}], {
             RGBColor[
             0.31974345189880926`, 0.449434024298521, 0.9416655397334055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 303}], {
             RGBColor[
             0.29654648477504475`, 0.4290195360046319, 0.9401992556555043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 366}], {
             RGBColor[
             0.27642037277284975`, 0.4078657162211217, 0.9390531033508938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 384}], {
             RGBColor[
             0.28582762436265047`, 0.41775333409620263`, 0.9395888324121513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 435}], {
             RGBColor[
             0.2729760661843835, 0.4042455316149929, 0.9388569551860756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 473}], {
             RGBColor[
             0.3073328542986736, 0.43868458843205593`, 0.9408747474285853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 88}], {
             RGBColor[
             0.9260374771709088, 0.7249105779401631, 0.30422129427437533`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 166}], {
             RGBColor[
             0.9117926198146232, 0.6283236796935395, 0.2910857426521841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 167}], {
             RGBColor[
             0.986067541242265, 0.9756937071602725, 0.6343029674871418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 175}], {
             RGBColor[
             0.9705975460870158, 0.9645679382577699, 0.6789276620320353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[
             0.9107642708804349, 0.6204193391599911, 0.29010099455145133`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 227}], {
             RGBColor[
             0.9155479974276244, 0.657189157644029, 0.2946818964954864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 309}], {
             RGBColor[
             0.9892477963467572, 0.9750667140916796, 0.4404269945442838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 320}], {
             RGBColor[
             0.9870336626851595, 0.9760932232050978, 0.618291834936235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 337}], {
             RGBColor[
             0.9228377639355362, 0.92700213552959, 0.6922814441739551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 348}], {
             RGBColor[
             0.9726882187211612, 0.9195330900145834, 0.3483993164391773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 428}], {
             RGBColor[
             0.9078991618741388, 0.5983968558388272, 0.2873573629313444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 434}], {
             RGBColor[
             0.9883337030612244, 0.9766308233101144, 0.5967468015081936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 474}], {
             RGBColor[
             0.989280991001634, 0.9770225512176633, 0.5810477888330006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 495}], {
             RGBColor[
             0.9138336495538494, 0.6440119286541663, 0.2930402350354805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 208}], {
             RGBColor[
             0.2926997987840062, 0.4237400438284219, 0.9400254625551399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 305}], {
             RGBColor[
             0.25719647261268064`, 0.38766017828711546`, 0.9379583306759838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 314}], {
             RGBColor[
             0.29667827269945046`, 0.4271859979700665, 0.9402789673950056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 394}], {
             RGBColor[
             0.24596177604056546`, 0.3758517998689181, 0.937318531326446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 398}], {
             RGBColor[
             0.26221606410223275`, 0.392936087203117, 0.9382441889854937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 427}], {
             RGBColor[
             0.271390600085227, 0.40257910622042264`, 0.9387666652372155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 445}], {
             RGBColor[
             0.24646019520379875`, 0.3763756700110764, 0.9373469155604471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 460}], {
             RGBColor[
             0.2558136629427209, 0.38620675764879087`, 0.9378795817109632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 472}], {
             RGBColor[
             0.29586389462338253`, 0.42648062461240877`, 0.9402270759441249]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 70}], {
             RGBColor[
             0.25743661729140077`, 0.3879125855705024, 0.9379720065601748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 96}], {
             RGBColor[
             0.2763924027630132, 0.4078363179673825, 0.9390515105002115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 131}], {
             RGBColor[
             0.2601160605037315, 0.39072885027317383`, 0.938124596887236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 135}], {
             RGBColor[
             0.2536249197696536, 0.3839062497995648, 0.9377549360252124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 147}], {
             RGBColor[
             0.2540581203038455, 0.3843615710275007, 0.9377796061547718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 171}], {
             RGBColor[
             0.25918264815811415`, 0.38974777471616917`, 0.9380714404350129]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 180}], {
             RGBColor[
             0.26337700695553745`, 0.3941563117499686, 0.9383103029635284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 216}], {
             RGBColor[
             0.26125452628926693`, 0.3919254499966715, 0.938189430829513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 238}], {
             RGBColor[
             0.28838849579729153`, 0.41939023215024707`, 0.9397732894571003]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 281}], {
             RGBColor[
             0.25076586641156884`, 0.38090120344576484`, 0.93759211716606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 343}], {
             RGBColor[
             0.2747552896997584, 0.40611560833893834`, 0.9389582793331509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 385}], {
             RGBColor[
             0.24504732911062774`, 0.37489065816626943`, 0.9372664549265891]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 391}], {
             RGBColor[
             0.24887514925956578`, 0.37891393984061833`, 0.9374844436213188]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 465}], {
             RGBColor[
             0.26962432665641767`, 0.4007226408585406, 0.9386660785784122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 205}], {
             RGBColor[
             0.9069065109079608, 0.5719171126049378, 0.3681050087560027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 257}], {
             RGBColor[
             0.8394199460541523, 0.30329924422110266`, 0.18535427265779897`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 272}], {
             RGBColor[
             0.8202846954174998, 0.15692263455492186`, 0.1670579532810717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 306}], {
             RGBColor[
             0.8387829864974263, 0.2991086057980758, 0.18477193771004097`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 317}], {
             RGBColor[
             0.8516933912786147, 0.35903009244942585`, 0.19559553620276254`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 142}], {
             RGBColor[
             0.8044934065793106, 0.8479188521576653, 0.9809561216743297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 173}], {
             RGBColor[
             0.9470127321552729, 0.9592645667466908, 0.9483609186014075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 194}], {
             RGBColor[
             0.9479892988678673, 0.9596684021789683, 0.9321766809000795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 241}], {
             RGBColor[
             0.8074723242442312, 0.8502460052781141, 0.9812530323476005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 388}], {
             RGBColor[
             0.9278173046721767, 0.9450102776472538, 0.9836136557859578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 402}], {
             RGBColor[
             0.7308868707375382, 0.7890374499881754, 0.9745628249690335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 461}], {
             RGBColor[
             0.926959006974305, 0.9443701606295145, 0.985066529908563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 487}], {
             RGBColor[
             0.7444469428218465, 0.8000461273805028, 0.9756303235156909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 490}], {
             RGBColor[
             0.9500080335378767, 0.9605032008441318, 0.8987210231001681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 84}], {
             RGBColor[
             0.24578222839824324`, 0.37566308391285935`, 0.9373083063538328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 96}], {
             RGBColor[
             0.2772059489257, 0.4086914065661722, 0.9390978407506428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 131}], {
             RGBColor[
             0.2609296066664183, 0.3915839388719636, 0.9381709271376673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 135}], {
             RGBColor[
             0.25443846593234043`, 0.3847613383983545, 0.9378012662756438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 147}], {
             RGBColor[
             0.2548716664665323, 0.3852166596262904, 0.9378259364052033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 170}], {
             RGBColor[
             0.2774653661360603, 0.408964070502262, 0.9391126141769994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 171}], {
             RGBColor[
             0.25999619432080096`, 0.39060286331495886`, 0.9381177706854442]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 216}], {
             RGBColor[
             0.26206807245195374`, 0.39278053859546125`, 0.9382357610799443]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[
             0.28920204195997834`, 0.42024532074903687`, 0.9398196197075317]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 265}], {
             RGBColor[
             0.28963233444531233`, 0.42061801847270397`, 0.9398470375642044]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 374}], {
             RGBColor[
             0.2549902427614091, 0.38534129083037727`, 0.9378326891497786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 385}], {
             RGBColor[
             0.24586087527331454`, 0.37574574676505923`, 0.9373127851770204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 391}], {
             RGBColor[
             0.24968869542225258`, 0.3797690284394081, 0.93753077387175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 433}], {
             RGBColor[
             0.2918782074405654, 0.4225632807803333, 0.9399901426055144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 194}], {
             RGBColor[
             0.8711488139703549, 0.898916809896938, 0.9247098602219754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 228}], {
             RGBColor[
             0.8744314209010298, 0.8983757407693698, 0.7323068273714743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 388}], {
             RGBColor[
             0.8509768197746642, 0.8842586853652235, 0.9761468351078537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 431}], {
             RGBColor[
             0.602160734252356, 0.6860330125252593, 0.9630472221226452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 462}], {
             RGBColor[
             0.6098299518680684, 0.6923889646800596, 0.9636151246385223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 487}], {
             RGBColor[
             0.6676064579243342, 0.7392945350984725, 0.9681635028375868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 490}], {
             RGBColor[
             0.8731675486403643, 0.8997516085621015, 0.891254202422064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 73}], {
             RGBColor[
             0.2509474629421924, 0.38109207291333524`, 0.9376024588198308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 144}], {
             RGBColor[
             0.2501061102631632, 0.3802077579028347, 0.93755454502943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 163}], {
             RGBColor[
             0.26048838412385666`, 0.3911201860046064, 0.9381458001665987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 187}], {
             RGBColor[
             0.2593062768219157, 0.38987771628033463`, 0.9380784809045242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 279}], {
             RGBColor[
             0.26627234056032795`, 0.3971994909433567, 0.9384751879290589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 322}], {
             RGBColor[
             0.25660150329804876`, 0.38703482781420406`, 0.9379244480536938]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 494}], {
             RGBColor[
             0.25624399533436604`, 0.3866590642770594, 0.9379040885040477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 93}], {
             RGBColor[
             0.2585978739086303, 0.3891331399031328, 0.9380381384066008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 163}], {
             RGBColor[
             0.2574513896017804, 0.3879281122053299, 0.9379728478213971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 187}], {
             RGBColor[
             0.25626928229983936`, 0.38668564248105813`, 0.9379055285593227]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 322}], {
             RGBColor[
             0.2535645087759725, 0.3838427540149276, 0.9377514957084923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 494}], {
             RGBColor[
             0.25320700081228975`, 0.383466990477783, 0.9377311361588463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 82}], {
             RGBColor[
             0.27000631808527487`, 0.401124138069925, 0.93868783242518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 105}], {
             RGBColor[
             0.2638196417670582, 0.3946215490015449, 0.938335510361225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 112}], {
             RGBColor[
             0.264998769293781, 0.3958608867931338, 0.938402659929509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 153}], {
             RGBColor[
             0.2633334885240648, 0.39411057111926295`, 0.9383078246532357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 195}], {
             RGBColor[
             0.27594296910076915`, 0.40736393469262394`, 0.9390259159180243]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 224}], {
             RGBColor[
             0.2903501525391211, 0.42250679795452123`, 0.9398463837013205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 234}], {
             RGBColor[
             0.335156328175214, 0.4622198560830736, 0.94266828637108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 239}], {
             RGBColor[
             0.31633226480045645`, 0.4459153985127936, 0.9414688336983061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 263}], {
             RGBColor[
             0.27756733242056764`, 0.40907124353231517`, 0.9391184210060566]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 296}], {
             RGBColor[
             0.2975769167094639, 0.42967045866758025`, 0.9402737595026511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 342}], {
             RGBColor[
             0.27086057814160247`, 0.4020220195523411, 0.9387364812716233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 395}], {
             RGBColor[
             0.2733607929019397, 0.4046499037882272, 0.9388788648034883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 440}], {
             RGBColor[
             0.2817039259800564, 0.4134190656385177, 0.9393539938897277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 447}], {
             RGBColor[
             0.26411698006509043`, 0.39493407040511375`, 0.9383524433374253]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 453}], {
             RGBColor[
             0.2830204227561394, 0.41480278722089764`, 0.9394289664335431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 463}], {
             RGBColor[
             0.2744156870316411, 0.4057586644026942, 0.9389389394635987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 93}], {
             RGBColor[
             0.30711689507265494`, 0.43678253795558514`, 0.940923781155411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 108}], {
             RGBColor[
             0.31502960292460824`, 0.4450992956026424, 0.9413743981617775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 149}], {
             RGBColor[
             0.3494116417234011, 0.4770645349462275, 0.9434851787314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 158}], {
             RGBColor[
             0.3512349205505469, 0.4786437674256428, 0.9436013564460036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.3059704107658049, 0.43557751025778224`, 0.9408584905702073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 182}], {
             RGBColor[
             0.3617675856264607, 0.48776663252726005`, 0.9442724885509708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 206}], {
             RGBColor[
             0.34384133423410757`, 0.4722398145707964, 0.9431302436638118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 410}], {
             RGBColor[
             0.354306761585108, 0.48130444173456, 0.9437970914404035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.3537435180123586, 0.4796530871235497, 0.9438038035415315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[
             0.35693445553108405`, 0.4830069647728541, 0.9439855227126539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 238}], {
             RGBColor[
             0.36573961104663694`, 0.49120700130641426`, 0.9445255824984202]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 333}], {
             RGBColor[
             0.3949872182942583, 0.5165398086768207, 0.9463892141695951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 343}], {
             RGBColor[
             0.3521064049491038, 0.47793237749510553`, 0.9437105723744709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 392}], {
             RGBColor[
             0.35866334703698777`, 0.48482413936361163`, 0.9440839805262493]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 402}], {
             RGBColor[
             0.4818182674522101, 0.589060600826333, 0.952664686170056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 431}], {
             RGBColor[
             0.42993261586454035`, 0.5468077556454473, 0.9486159040017718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 436}], {
             RGBColor[
             0.4421225577048329, 0.5568338353820671, 0.9495396944885663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 459}], {
             RGBColor[
             0.40093570974009674`, 0.5216920929873327, 0.9467682467844796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 462}], {
             RGBColor[
             0.4376018334802528, 0.5531637078002476, 0.949183806517649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 487}], {
             RGBColor[
             0.49537833953651855`, 0.6000692782186605, 0.9537321847167134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 81}], {
             RGBColor[
             0.7152180111578499, 0.7769379420233913, 0.972614350327299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 156}], {
             RGBColor[
             0.5370635204917655, 0.6350513862279201, 0.9566987541430614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 278}], {
             RGBColor[
             0.7775908081460805, 0.8263457284855322, 0.9672404849556133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 329}], {
             RGBColor[
             0.7446878798780471, 0.8004364154026, 0.9754252127138938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 479}], {
             RGBColor[
             0.5091542746403608, 0.6112576931750507, 0.9548154361242309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 482}], {
             RGBColor[
             0.4826496570055525, 0.5883007255405965, 0.9531265853256541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 85}], {
             RGBColor[
             0.21682232686548605`, 0.34522439123812265`, 0.9356590828038773]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 95}], {
             RGBColor[
             0.22325600943798377`, 0.3519865995408531, 0.9360254715086005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 97}], {
             RGBColor[
             0.22558180327383132`, 0.35443115632617517`, 0.9361579220268484]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 137}], {
             RGBColor[
             0.21975482034818994`, 0.34830662781927, 0.9358260839694819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 145}], {
             RGBColor[
             0.22004363289237822`, 0.3486101881149849, 0.9358425314166136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 183}], {
             RGBColor[
             0.21219822021020854`, 0.34036416195813046`, 0.935395746770612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 346}], {
             RGBColor[
             0.21865587786091514`, 0.34715156958816623`, 0.9357635008205714]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 358}], {
             RGBColor[
             0.22252765585105994`, 0.3512210537407115, 0.9359839928493279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 404}], {
             RGBColor[
             0.2164387033219317, 0.3448211785707095, 0.935637236010592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 407}], {
             RGBColor[
             0.21689372054729342`, 0.34529943052432305`, 0.9356631485684387]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 408}], {
             RGBColor[
             0.22096681623691122`, 0.34958051234329385`, 0.9358951053423573]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 430}], {
             RGBColor[
             0.22958406238534357`, 0.3586377844102586, 0.9363858447624374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 81}], {
             RGBColor[
             0.9087234308797807, 0.9257016701540246, 0.7763552620147077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 99}], {
             RGBColor[
             0.9937251243023482, 0.9889870003070016, 0.5583966882336657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 122}], {
             RGBColor[
             0.9306665098261713, 0.7402291937878942, 0.3904132893585251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 267}], {
             RGBColor[
             0.9914456607402118, 0.9819881575780944, 0.49084130836277423`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 278}], {
             RGBColor[
             0.9710962278680113, 0.9751094566161655, 0.770981396643022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 329}], {
             RGBColor[
             0.9381932995999778, 0.9492001435332333, 0.7791661244013025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 406}], {
             RGBColor[
             0.9922235479450122, 0.984612153776488, 0.4938632532617516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 413}], {
             RGBColor[
             0.9838323701759427, 0.9563067408191819, 0.46126511216987476`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 476}], {
             RGBColor[
             0.9211605712027758, 0.6814740968415736, 0.3818708025801312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 486}], {
             RGBColor[
             0.9643781566417168, 0.9700792377693064, 0.7816636594414414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 493}], {
             RGBColor[
             0.9937029879453217, 0.9889396528776512, 0.5559872823811043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 156}], {
             RGBColor[
             0.6284260394446897, 0.7069689251123001, 0.9654326763878454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 278}], {
             RGBColor[
             0.8689533270990046, 0.8982632673699124, 0.9759744072003973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 307}], {
             RGBColor[
             0.6296762406643908, 0.7079838947833768, 0.9655310968074982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 329}], {
             RGBColor[
             0.8360503988309712, 0.8723539542869803, 0.9841591349586778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 372}], {
             RGBColor[
             0.6299979927875134, 0.7082451076516956, 0.9655564263132472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 406}], {
             RGBColor[
             0.8900806471760057, 0.9077659645302347, 0.6988562638191269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 417}], {
             RGBColor[
             0.7452877880838611, 0.8009437515388753, 0.9752469796719869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 461}], {
             RGBColor[
             0.8669992096038857, 0.8968058897416262, 0.9792822184041656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 486}], {
             RGBColor[
             0.8622352558727102, 0.8932330485230531, 0.9866566699988166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 493}], {
             RGBColor[
             0.8915600871763152, 0.912093463631398, 0.7609802929384797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 83}], {
             RGBColor[
             0.8721819244967113, 0.9009182081187621, 0.9876706846361336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 99}], {
             RGBColor[
             0.9086198401868935, 0.9254801001365643, 0.7650800543815806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 237}], {
             RGBColor[
             0.8648552697662895, 0.8950761325134684, 0.9869718617673642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[
             0.906340376624757, 0.9184812574076573, 0.6975246745106891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 278}], {
             RGBColor[
             0.8859909437525565, 0.9116025564457284, 0.9776647627909368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 329}], {
             RGBColor[
             0.8530880154845231, 0.8856932433627962, 0.9858494905492173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 426}], {
             RGBColor[
             0.8468962698264015, 0.8807561134454687, 0.9852589163209091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 486}], {
             RGBColor[
             0.879272872526262, 0.9065723375988691, 0.9883470255893563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 89}], {
             RGBColor[
             0.2718901700216876, 0.4031041858982062, 0.9387951150060494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 105}], {
             RGBColor[
             0.25209194686734443`, 0.382294998083142, 0.9376676354862561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 184}], {
             RGBColor[
             0.2576552479933815, 0.38814238030027126`, 0.9379844572552174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 195}], {
             RGBColor[
             0.2642152742010554, 0.39503738377422104`, 0.9383580410430554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 225}], {
             RGBColor[
             0.2662639580467382, 0.39719068039009175`, 0.9384747105573108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 263}], {
             RGBColor[
             0.26583963752085393`, 0.39674469261391226`, 0.9384505461310877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 296}], {
             RGBColor[
             0.28584922180975014`, 0.4173439077491774, 0.9396058846276822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 342}], {
             RGBColor[
             0.2591328832418887, 0.3896954686339382, 0.9380686063966545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 395}], {
             RGBColor[
             0.26163309800222595`, 0.39232335286982434`, 0.9382109899285194]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 440}], {
             RGBColor[
             0.26997623108034263`, 0.40109251472011487`, 0.9386861190147588]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 447}], {
             RGBColor[
             0.25238928516537673`, 0.3826075194867109, 0.9376845684624564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 453}], {
             RGBColor[
             0.27129272785642566`, 0.40247623630249474`, 0.9387610915585742]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 463}], {
             RGBColor[
             0.26268799213192734`, 0.3934321134842913, 0.9382710645886299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 470}], {
             RGBColor[
             0.25688036525862096`, 0.38732792941563493`, 0.937940328829809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 119}], {
             RGBColor[
             0.9556965383033635, 0.9650210547273206, 0.8984817408494732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 176}], {
             RGBColor[
             0.7638451540938651, 0.8157128228854424, 0.9772513951417543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[
             0.8091856625186589, 0.8516756760168047, 0.981399600787607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 237}], {
             RGBColor[
             0.913419047498675, 0.933799570648643, 0.9916039182408752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 270}], {
             RGBColor[
             0.955384395176871, 0.9648919755228036, 0.9036547602559704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 345}], {
             RGBColor[
             0.7902354483667869, 0.8368716246944006, 0.9795108205407682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 375}], {
             RGBColor[
             0.9394735703012015, 0.9539944639741937, 0.9739704912597569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 426}], {
             RGBColor[
             0.895460047558787, 0.9194795515806435, 0.9898909727944203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 448}], {
             RGBColor[
             0.7443425082604527, 0.7998796964136958, 0.9757160754212024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 489}], {
             RGBColor[
             0.9554216482771469, 0.9649073806371287, 0.9030373799764648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 131}], {
             RGBColor[
             0.24846167161057395`, 0.3784793486155308, 0.9374608966808939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 135}], {
             RGBColor[
             0.24197053087649611`, 0.37165674814192173`, 0.9370912358188704]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 147}], {
             RGBColor[
             0.24240373141068797`, 0.37211206936985763`, 0.93711590594843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 171}], {
             RGBColor[
             0.2475282592649566, 0.3774982730585261, 0.9374077402286709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 230}], {
             RGBColor[
             0.22859615804425376`, 0.3575994343110202, 0.9363295850716857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 242}], {
             RGBColor[
             0.22916096004104347`, 0.3581930770201611, 0.9363617497098533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 365}], {
             RGBColor[
             0.22514447908377305`, 0.3539715008744688, 0.9361330170611878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 374}], {
             RGBColor[
             0.24252230770556474`, 0.3722367005739444, 0.9371226586930053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 385}], {
             RGBColor[
             0.2333929402174702, 0.3626411565086264, 0.9366027547202471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 391}], {
             RGBColor[
             0.23722076036640824`, 0.3666644381829753, 0.9368207434149767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 95}], {
             RGBColor[
             0.22064923730827996`, 0.3492467167536353, 0.9358770196921877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 97}], {
             RGBColor[
             0.22297503114412753`, 0.3516912735389574, 0.9360094702104356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 137}], {
             RGBColor[
             0.21714804821848613`, 0.34556674503205226`, 0.9356776321530691]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 145}], {
             RGBColor[
             0.21743686076267443`, 0.3458703053277671, 0.9356940796002007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 183}], {
             RGBColor[
             0.20959144808050473`, 0.33762427917091264`, 0.9352472949541991]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 286}], {
             RGBColor[
             0.21865790979829205`, 0.3471537052831816, 0.935763616536399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 346}], {
             RGBColor[
             0.21604910573121133`, 0.34441168680094847`, 0.9356150490041585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 358}], {
             RGBColor[
             0.2199208837213561, 0.34848117095349374`, 0.935835541032915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 404}], {
             RGBColor[
             0.21383193119222793`, 0.3420812957834917, 0.9354887841941792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 407}], {
             RGBColor[
             0.2142869484175896, 0.3425595477371053, 0.9355146967520258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 408}], {
             RGBColor[
             0.21836004410720744`, 0.3468406295560761, 0.9357466535259444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 90}], {
             RGBColor[
             0.8899814344584336, 0.5901544331035902, 0.2297467504579272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 98}], {
             RGBColor[
             0.9552139147274563, 0.8468459050338089, 0.4866646892725739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 115}], {
             RGBColor[
             0.9181807358610004, 0.8207272885954675, 0.6214818156174652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 124}], {
             RGBColor[
             0.9389228207101663, 0.7935781606519255, 0.2800166062249653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 136}], {
             RGBColor[
             0.942076876818933, 0.8389236960734718, 0.594023128493258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 168}], {
             RGBColor[
             0.912992655814064, 0.6927519043211215, 0.24885005242438252`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[
             0.9534388639235, 0.8461526483552239, 0.5190456011559075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 253}], {
             RGBColor[
             0.9501124692155603, 0.8447770986590462, 0.5741725699000219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 261}], {
             RGBColor[
             0.897589954080166, 0.6247029436909717, 0.23609548573218275`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 357}], {
             RGBColor[
             0.911167687629582, 0.6855165136042474, 0.2473816401856394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 484}], {
             RGBColor[
             0.9540423951293819, 0.8443401430723285, 0.3591520108030784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 500}], {
             RGBColor[
             0.8673428769617186, 0.42615530998421236`, 0.20846003809980468`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 107}], {
             RGBColor[
             0.1819624771956669, 0.3085844789930161, 0.9336738659357071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 113}], {
             RGBColor[
             0.17922276129889142`, 0.3057048638774843, 0.9335178431684322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 143}], {
             RGBColor[
             0.1790901316250143, 0.30556546168103244`, 0.933510290104713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 226}], {
             RGBColor[
             0.17933912709972993`, 0.30582717171218354`, 0.9335244700286423]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 292}], {
             RGBColor[
             0.1791119470402912, 0.3055883910656657, 0.93351153246034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 308}], {
             RGBColor[
             0.17909977333492821`, 0.3055755957294717, 0.9335108391858289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 386}], {
             RGBColor[
             0.17909013095112286`, 0.3055654609727298, 0.9335102900663359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 421}], {
             RGBColor[
             0.17915493384170816`, 0.30563357291947557`, 0.9335139804950874]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 422}], {
             RGBColor[
             0.2066326331143824, 0.33451437704181397`, 0.9350787948190529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 423}], {
             RGBColor[
             0.18353957668712906`, 0.310242110552426, 0.9337636794186364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 446}], {
             RGBColor[
             0.20370226760912918`, 0.33143437709988877`, 0.934911914838616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 166}], {
             RGBColor[
             0.8523652692557177, 0.3906026653424749, 0.19727300714892185`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 167}], {
             RGBColor[
             0.9266401906833595, 0.7379726928092079, 0.5404902319838795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 210}], {
             RGBColor[
             0.8513369203215293, 0.3826983248089265, 0.19628825904818903`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 227}], {
             RGBColor[
             0.8561206468687188, 0.41946814329296433`, 0.20086916099222407`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 243}], {
             RGBColor[
             0.8529581179820884, 0.3951595604413297, 0.19784071975882145`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 326}], {
             RGBColor[
             0.8708928189630238, 0.5066362693068722, 0.21398214224720047`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 348}], {
             RGBColor[
             0.9132608681622556, 0.6818120756635188, 0.2545865809359151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 428}], {
             RGBColor[
             0.8484718113152332, 0.36067584148776255`, 0.1935446274280821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 434}], {
             RGBColor[
             0.9289063525023188, 0.7389098089590498, 0.5029340660049313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 469}], {
             RGBColor[
             0.8635204022958338, 0.47315984709282155`, 0.20783041706562805`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 474}], {
             RGBColor[
             0.9298536404427284, 0.7393015368665987, 0.48723505332973827`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 495}], {
             RGBColor[
             0.8544062989949438, 0.4062909143031017, 0.1992274995322182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 133}], {
             RGBColor[
             0.3153376912434113, 0.4454022988525135, 0.9413927055520241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 184}], {
             RGBColor[
             0.271266794829508, 0.4024489790469554, 0.9387596147110557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 192}], {
             RGBColor[
             0.27005817816264466`, 0.4011786462993594, 0.9386907857798661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 225}], {
             RGBColor[
             0.2798755048828646, 0.4114972791367759, 0.9392498680131491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 235}], {
             RGBColor[
             0.32127172035398965`, 0.45054205661512126`, 0.9417708166396943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 239}], {
             RGBColor[
             0.31821611673686917`, 0.4478954463410748, 0.9415761162791756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 249}], {
             RGBColor[
             0.28752479280706156`, 0.41953716573797317`, 0.9396854836443249]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 260}], {
             RGBColor[
             0.2855390731059485, 0.4174500484302025, 0.9395723998449554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.2711970471587578, 0.4023756698227392, 0.938755642684389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 296}], {
             RGBColor[
             0.2994607686458766, 0.4316505064958615, 0.9403810420835206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 424}], {
             RGBColor[
             0.3030480744366626, 0.4347576504686087, 0.9406096220363795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 440}], {
             RGBColor[
             0.2835877779164691, 0.415399113466799, 0.9394612764705972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 453}], {
             RGBColor[
             0.28490427469255214`, 0.4167828350491789, 0.9395362490144127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 470}], {
             RGBColor[
             0.27049191209474743`, 0.40163452816231904`, 0.9387154862856475]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 124}], {
             RGBColor[
             0.9137111635376958, 0.6822566946723914, 0.2591427819494134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 178}], {
             RGBColor[
             0.9282272067510295, 0.7348311823756897, 0.4981717768803556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[
             0.8618116052496472, 0.4654005988057779, 0.20640455492384144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 261}], {
             RGBColor[
             0.8723782969076955, 0.5133814777114375, 0.21522166145663085`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 272}], {
             RGBColor[
             0.8426763546129947, 0.3190239891395971, 0.18810823554711417`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 306}], {
             RGBColor[
             0.8611746456929213, 0.4612099603827511, 0.20582221997608346`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 317}], {
             RGBColor[
             0.8740850504741097, 0.5211314470341011, 0.21664581846880504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 357}], {
             RGBColor[
             0.8859560304571115, 0.5741950476247133, 0.2265078159100875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 172}], {
             RGBColor[
             0.33964065051404985`, 0.4686013934649852, 0.9428625798116885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 303}], {
             RGBColor[
             0.3164436833902854, 0.44818690517109605`, 0.9413962957337874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 366}], {
             RGBColor[
             0.29631757138809034`, 0.4270330853875859, 0.9402501434291768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 435}], {
             RGBColor[
             0.29287326479962417`, 0.4234129007814571, 0.9400539952643586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 473}], {
             RGBColor[
             0.32723005291391416`, 0.4578519575985201, 0.9420717875068684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 101}], {
             RGBColor[
             0.5649851581111299, 0.6577194295027604, 0.9588968477367864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 128}], {
             RGBColor[
             0.5519404005403256, 0.6471291076471498, 0.9578699166362912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 140}], {
             RGBColor[
             0.554385826473297, 0.649114414584719, 0.9580624295236251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 169}], {
             RGBColor[
             0.5509398864490034, 0.6463168452351683, 0.9577911525020184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 175}], {
             RGBColor[
             0.7824339265203888, 0.8300343229197356, 0.9610969915433571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 204}], {
             RGBColor[
             0.5555153199743827, 0.6500313882920026, 0.9581513473895016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 219}], {
             RGBColor[
             0.5677032440041356, 0.6599260940790765, 0.9591108254149605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 274}], {
             RGBColor[
             0.5359359247795917, 0.6341359532311694, 0.9566099856780799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 320}], {
             RGBColor[
             0.7988700431185324, 0.8415596078670635, 0.9004611644475569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 334}], {
             RGBColor[
             0.505970833581321, 0.6084373708863062, 0.9546299931971096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 337}], {
             RGBColor[
             0.7346741443689091, 0.7924685201915558, 0.974450773685277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 361}], {
             RGBColor[
             0.6266695180780231, 0.7077693478258749, 0.9637721633771799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 363}], {
             RGBColor[
             0.506974473041424, 0.6093066729422614, 0.9546939442160238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 370}], {
             RGBColor[
             0.6002904630940367, 0.6863818665737486, 0.9616762106726342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 498}], {
             RGBColor[
             0.5355135500520953, 0.6337930503996233, 0.9565767347923217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 108}], {
             RGBColor[
             0.27719798724909794`, 0.408683038339264, 0.9390973873449386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 163}], {
             RGBColor[
             0.26813879509029465`, 0.39916125299440397`, 0.9385814797533685]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 187}], {
             RGBColor[
             0.2669566877883537, 0.3979187832701322, 0.9385141604912941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 189}], {
             RGBColor[
             0.26453032177670965`, 0.3953685187514038, 0.9383759825364177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 206}], {
             RGBColor[
             0.30600971855859727`, 0.43582355730741806`, 0.940853232846973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 266}], {
             RGBColor[
             0.2794030113306438, 0.41100065845557043`, 0.9392229602043418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 322}], {
             RGBColor[
             0.26425191426448674`, 0.3950758948040016, 0.9383601276404636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 364}], {
             RGBColor[
             0.2639259772143767, 0.39473331429873343`, 0.9383415660076406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 437}], {
             RGBColor[
             0.26255787085876586`, 0.3932953477760335, 0.9382636543746206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 100}], {
             RGBColor[
             0.943316965793535, 0.8656345224892459, 0.6119300548794735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 127}], {
             RGBColor[
             0.5906994451507328, 0.6605608453144329, 0.9482643190369882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 168}], {
             RGBColor[
             0.9331056494970619, 0.8251500560931704, 0.6037137900969318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 213}], {
             RGBColor[
             0.9298124883323949, 0.8120876909328425, 0.6010637208876998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 214}], {
             RGBColor[
             0.5776130969249946, 0.6468062636067821, 0.9475190708650497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 254}], {
             RGBColor[
             0.5959586642234989, 0.6660886180136586, 0.9485638237828649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 302}], {
             RGBColor[
             0.5727842186692342, 0.6417308063914131, 0.9472440733920693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 315}], {
             RGBColor[
             0.5704593476328262, 0.6392872195268108, 0.9471116754258844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 325}], {
             RGBColor[
             0.5672179996830251, 0.6358803573182399, 0.9469270854552878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 368}], {
             RGBColor[
             0.6817603644893816, 0.7470855364406719, 0.9537864521193352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 401}], {
             RGBColor[
             0.8644357283380311, 0.8946091728083778, 0.9692011064141851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 477}], {
             RGBColor[
             0.6000453532177727, 0.6703839872576882, 0.948796554675374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 500}], {
             RGBColor[
             0.8874558706447166, 0.5585534617562613, 0.5633237757723539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 97}], {
             RGBColor[
             0.22940871371662525`, 0.3584534818416879, 0.936375858915159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 137}], {
             RGBColor[
             0.22358173079098384`, 0.35232895333478276`, 0.9360440208577924]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 145}], {
             RGBColor[
             0.22387054333517215`, 0.3526325136304976, 0.9360604683049241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 174}], {
             RGBColor[
             0.24687001390337449`, 0.3768064154483368, 0.9373702541291156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 286}], {
             RGBColor[
             0.22509159237078977`, 0.3539159135859121, 0.9361300052411223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 294}], {
             RGBColor[
             0.2326978312332123, 0.36191055289371626`, 0.9365631692919152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 346}], {
             RGBColor[
             0.22248278830370904`, 0.3511738951036789, 0.9359814377088818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 358}], {
             RGBColor[
             0.2263545662938538, 0.3552433792562242, 0.9362019297376383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 404}], {
             RGBColor[
             0.22026561376472564`, 0.3488435040862222, 0.9358551728989024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 407}], {
             RGBColor[
             0.22072063099008732`, 0.34932175603983573`, 0.9358810854567492]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 408}], {
             RGBColor[
             0.22479372667970515`, 0.35360283785880653`, 0.9361130422306678]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 430}], {
             RGBColor[
             0.23341097282813747`, 0.36266010992577125`, 0.9366037816507478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 131}], {
             RGBColor[
             0.2798853921380307, 0.4115076712688437, 0.9392504310777041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 147}], {
             RGBColor[
             0.27382745193814473`, 0.40514039202317054`, 0.9389054403452399]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.29935267191603787`, 0.43196901661235676`, 0.940359063861802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 171}], {
             RGBColor[
             0.2789519797924134, 0.41052659571183897`, 0.939197274625481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 180}], {
             RGBColor[
             0.2831463385898367, 0.4149351327456384, 0.9394361371539964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 216}], {
             RGBColor[
             0.2810238579235662, 0.4127042709923413, 0.9393152650199811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 238}], {
             RGBColor[
             0.3081578274315908, 0.4401690531459169, 0.9408991236475683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 265}], {
             RGBColor[
             0.3085881199169248, 0.4405417508695841, 0.9409265415042412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 281}], {
             RGBColor[
             0.27053519804586806`, 0.4016800244414347, 0.938717951356528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 343}], {
             RGBColor[
             0.29452462133405766`, 0.4268944293346082, 0.940084113523619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 392}], {
             RGBColor[
             0.3010815634219416, 0.43378619120311424`, 0.9404575216753974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 433}], {
             RGBColor[
             0.31083399291217784`, 0.4424870131772134, 0.9410696465455513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 465}], {
             RGBColor[
             0.2893936582907169, 0.42150146185421045`, 0.9397919127688803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 104}], {
             RGBColor[
             0.23915408747259903`, 0.3686964875516002, 0.936930843533573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 137}], {
             RGBColor[
             0.2259075246268314, 0.35477351012010483`, 0.9361764713760403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 145}], {
             RGBColor[
             0.2261963371710197, 0.3550770704158197, 0.9361929188231719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 174}], {
             RGBColor[
             0.24919580773922206`, 0.37925097223365895`, 0.9375027046473634]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 294}], {
             RGBColor[
             0.23502362506905988`, 0.3643551096790384, 0.936695619810163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 346}], {
             RGBColor[
             0.22480858213955662`, 0.353618451889001, 0.9361138882271296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 358}], {
             RGBColor[
             0.2286803601297014, 0.35768793604154625`, 0.9363343802558861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 404}], {
             RGBColor[
             0.2225914076005732, 0.3512880608715443, 0.9359876234171504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 407}], {
             RGBColor[
             0.2230464248259349, 0.3517663128251578, 0.936013535974997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 408}], {
             RGBColor[
             0.2271195205155527, 0.3560473946441286, 0.9362454927489157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 430}], {
             RGBColor[
             0.23573676666398502`, 0.3651046667110934, 0.9367362321689956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 115}], {
             RGBColor[
             0.9582015589575525, 0.9660972945461519, 0.85752593015656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 124}], {
             RGBColor[
             0.9789436438067185, 0.93894816660261, 0.5160607207640602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 136}], {
             RGBColor[
             0.9820976999154852, 0.9842937020241562, 0.8300672430323528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 253}], {
             RGBColor[
             0.9901332923121124, 0.9901471046097305, 0.8102166844391167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 261}], {
             RGBColor[
             0.9376107771767181, 0.7700729496416561, 0.47213960027127755`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 277}], {
             RGBColor[
             0.8832681348130269, 0.9067408984138945, 0.8502742951726139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 311}], {
             RGBColor[
             0.8710458030481137, 0.8971927199459824, 0.8490560873664715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 319}], {
             RGBColor[
             0.8550622111994015, 0.8847062165139711, 0.8474629923061501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 331}], {
             RGBColor[
             0.9159632164581281, 0.9324175867663749, 0.8534971993423514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 377}], {
             RGBColor[
             0.9881699242791049, 0.9888223570121889, 0.8197885510745015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 484}], {
             RGBColor[
             0.9940632182259341, 0.9897101490230129, 0.5951961253421731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 488}], {
             RGBColor[
             0.8822995191611039, 0.9059842085048606, 0.8501777526166581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 122}], {
             RGBColor[
             0.930562919133284, 0.740007623770434, 0.37913808172539787`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 267}], {
             RGBColor[
             0.9913420700473246, 0.9817665875606343, 0.479566100729647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 278}], {
             RGBColor[
             0.9709926371751241, 0.9748878865987054, 0.7597061890098948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 329}], {
             RGBColor[
             0.9380897089070905, 0.9489785735157732, 0.7678909167681753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 406}], {
             RGBColor[
             0.992119957252125, 0.9843905837590278, 0.48258804562862445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 413}], {
             RGBColor[
             0.9837287794830555, 0.9560851708017216, 0.4499899045367475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 476}], {
             RGBColor[
             0.9210569805098886, 0.6812525268241133, 0.37059559494700395`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 486}], {
             RGBColor[
             0.9642745659488295, 0.9698576677518461, 0.7703884518083142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 493}], {
             RGBColor[
             0.9935993972524345, 0.9887180828601909, 0.5447120747479771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 121}], {
             RGBColor[
             0.8793403970281699, 0.48855884043917713`, 0.2187233911438525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 127}], {
             RGBColor[
             0.5785973319473678, 0.5599231651764567, 0.5998463238378839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 168}], {
             RGBColor[
             0.9210035362936968, 0.7245123759551941, 0.25529579489782767`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 200}], {
             RGBColor[
             0.9160214299715226, 0.703780905297789, 0.25123642844933736`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 213}], {
             RGBColor[
             0.9177103751290299, 0.7114500107948662, 0.2526457256885956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 254}], {
             RGBColor[
             0.5838565510201338, 0.5654509378756822, 0.6001458285837606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 259}], {
             RGBColor[
             0.8965277758950481, 0.6152647749950997, 0.2349704456547408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 315}], {
             RGBColor[
             0.5583572344294613, 0.5386495393888345, 0.5986936802267802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 368}], {
             RGBColor[
             0.6696582512860165, 0.6464478563026956, 0.6053684569202311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 401}], {
             RGBColor[
             0.8523336151346661, 0.7939714926704016, 0.620783111215081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 450}], {
             RGBColor[
             0.8744616680202064, 0.45105879141128646`, 0.21405151473609035`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 454}], {
             RGBColor[
             0.915548639391991, 0.7016340736991815, 0.25084192040061865`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 471}], {
             RGBColor[
             0.894013717811025, 0.6013444138663678, 0.23277457969666004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 475}], {
             RGBColor[
             0.8851091218155209, 0.5328997870260774, 0.22424752851506258`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 500}], {
             RGBColor[
             0.8753537574413516, 0.45791578161828494`, 0.21490578057324983`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 128}], {
             RGBColor[
             0.5077879700548952, 0.6112841755347511, 0.9543940755727961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 169}], {
             RGBColor[
             0.506787455963573, 0.6104719131227696, 0.9543153114385234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 197}], {
             RGBColor[
             0.6092291752169602, 0.6927921015850171, 0.9629587335694303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[
             0.5113628894889524, 0.6141864561796039, 0.9546755063260064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 219}], {
             RGBColor[
             0.5235508135187052, 0.6240811619666777, 0.9556349843514654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 337}], {
             RGBColor[
             0.6905217138834787, 0.756623588079157, 0.9709749326217818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 345}], {
             RGBColor[
             0.5902789610650883, 0.677988050262613, 0.9610699533225915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 355}], {
             RGBColor[
             0.424769765192925, 0.5405027707410431, 0.9487934456872616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 361}], {
             RGBColor[
             0.5825170875925927, 0.671924415713476, 0.9602963223136847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 362}], {
             RGBColor[
             0.45464713410545365`, 0.5663810460128507, 0.950697205214848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 363}], {
             RGBColor[
             0.4628220425559936, 0.5734617408298626, 0.9512181031525286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 498}], {
             RGBColor[
             0.491361119566665, 0.5979481182872246, 0.9531008937288266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 109}], {
             RGBColor[
             0.265248780611274, 0.396123664539452, 0.9384168977041816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[
             0.28024115314486164`, 0.4118815986435736, 0.9392706911407418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 186}], {
             RGBColor[
             0.256123983487738, 0.3865329242170628, 0.9378972540069239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 193}], {
             RGBColor[
             0.2821746373958698, 0.4139138131813651, 0.9393808002085031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 196}], {
             RGBColor[
             0.28611844580431445`, 0.41805900587053585`, 0.9396053942630224]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 202}], {
             RGBColor[
             0.2577973086293919, 0.3882916950358828, 0.9379925473982783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 330}], {
             RGBColor[
             0.2914935550351155, 0.4237085864737168, 0.939911498781955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 350}], {
             RGBColor[
             0.3193537748201921, 0.44805203074969097`, 0.941678953195245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 354}], {
             RGBColor[
             0.3191507002330799, 0.44787613774915985`, 0.941666013462126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 414}], {
             RGBColor[
             0.27559776236137046`, 0.40700110052214455`, 0.9390062569049031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 415}], {
             RGBColor[
             0.28177512151681394`, 0.41349389666170766`, 0.9393580483702217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 485}], {
             RGBColor[
             0.2622693737921402, 0.3929921190672394, 0.9382472248934693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 496}], {
             RGBColor[
             0.27671354998693043`, 0.4081738640616296, 0.9390697993595188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 118}], {
             RGBColor[
             0.4027319052154037, 0.522513730131029, 0.9470855430392838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 188}], {
             RGBColor[
             0.408816425381794, 0.5277838356822806, 0.9474732432839563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 304}], {
             RGBColor[
             0.4094598762170423, 0.5283411604549934, 0.947514243402197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 319}], {
             RGBColor[
             0.5976226950866923, 0.6831049747415705, 0.9622258440138658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 331}], {
             RGBColor[
             0.6585237003454188, 0.7308163449939742, 0.968260051050067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 449}], {
             RGBColor[
             0.6043292409167387, 0.6883441793156388, 0.9628942898259707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 488}], {
             RGBColor[
             0.6248600030483947, 0.70438296673246, 0.9649406043243738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 112}], {
             RGBColor[
             0.24741859649764936`, 0.37738301053706513`, 0.9374014950963042]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 148}], {
             RGBColor[
             0.2431147548759032, 0.37285940011329033`, 0.9371563976829089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 153}], {
             RGBColor[
             0.24575331572793313`, 0.3756326948631943, 0.937306659820031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 190}], {
             RGBColor[
             0.24734164292075334`, 0.3773021274486088, 0.9373971127039427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 215}], {
             RGBColor[
             0.26534838496499225`, 0.39622835503049064`, 0.9384225700247744]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 224}], {
             RGBColor[
             0.2727699797429894, 0.40402892169845256`, 0.9388452188681158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 323}], {
             RGBColor[
             0.2429591667599799, 0.3726958671385986, 0.9371475371698791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 351}], {
             RGBColor[
             0.2683095588486911, 0.39934073653152624`, 0.9385912044967868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 356}], {
             RGBColor[
             0.2579557991377684, 0.3884582786090651, 0.9380015731982647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 408}], {
             RGBColor[
             0.23453910043567894`, 0.36384584356871885`, 0.9366680268490819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 430}], {
             RGBColor[
             0.24315634658411125`, 0.3729031156356836, 0.937158766269162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 452}], {
             RGBColor[
             0.2352635459876256, 0.36460728177631574`, 0.9367092829515442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 112}], {
             RGBColor[
             0.2470843980758506, 0.3770317468063509, 0.9373824629905851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 148}], {
             RGBColor[
             0.24278055645410443`, 0.37250813638257607`, 0.9371373655771897]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 153}], {
             RGBColor[
             0.24541911730613436`, 0.37528143113248, 0.9372876277143118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 190}], {
             RGBColor[
             0.24700744449895456`, 0.37695086371789455`, 0.9373780805982235]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 195}], {
             RGBColor[
             0.2580285978828387, 0.38853479470584096`, 0.9380057189791005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 263}], {
             RGBColor[
             0.2596529612026372, 0.3902421035455322, 0.9380982240671327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 323}], {
             RGBColor[
             0.24262496833818112`, 0.37234460340788433`, 0.93712850506416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 342}], {
             RGBColor[
             0.252946206923672, 0.38319287956555814`, 0.9377162843326995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 395}], {
             RGBColor[
             0.2554464216840092, 0.38582076380144426`, 0.9378586678645644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 447}], {
             RGBColor[
             0.24620260884716, 0.3761049304183308, 0.9373322463985014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 453}], {
             RGBColor[
             0.265106051538209, 0.39597364723411466`, 0.9384087694946193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 463}], {
             RGBColor[
             0.2565013158137106, 0.3869295244159112, 0.9379187425246749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 117}], {
             RGBColor[
             0.44946530583261596`, 0.561973649912251, 0.9503446865091629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 139}], {
             RGBColor[
             0.5409452590449157, 0.6382027564556965, 0.9570043388212421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 140}], {
             RGBColor[
             0.508744701282457, 0.6120608930455363, 0.9544693929596517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 247}], {
             RGBColor[
             0.5064333598698463, 0.6101844419620349, 0.9542874356969284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 255}], {
             RGBColor[
             0.45772043203322, 0.569123825312507, 0.9508706958509441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 269}], {
             RGBColor[
             0.48339733950661234`, 0.5913638720070653, 0.9525068056899508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 274}], {
             RGBColor[
             0.49029479958875166`, 0.5970824316919869, 0.9530169491141065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 360}], {
             RGBColor[
             0.5486108303756021, 0.6444260125920007, 0.9576078006763067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 369}], {
             RGBColor[
             0.46890138102995677`, 0.5788082013626439, 0.9515831360340911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 370}], {
             RGBColor[
             0.5546493379031965, 0.6493283450345659, 0.9580831741086608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 425}], {
             RGBColor[
             0.4465990938801403, 0.559491081179018, 0.9501620540180429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 466}], {
             RGBColor[
             0.5106817556791221, 0.6136334810680553, 0.9546218849774213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 468}], {
             RGBColor[
             0.4981161809408796, 0.6034321814228589, 0.9536326769048099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 113}], {
             RGBColor[
             0.18193197659231264`, 0.3085524209250408, 0.9336721289714678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 132}], {
             RGBColor[
             0.5874023021726906, 0.6508098778838103, 0.8735074338464627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 143}], {
             RGBColor[
             0.18179934691843552`, 0.30841301872858895`, 0.9336645759077484]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 209}], {
             RGBColor[
             0.37529763235099667`, 0.4849566561931139, 0.9463994374355724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 214}], {
             RGBColor[
             0.19223940367108877`, 0.31938618031345734`, 0.9342591216951321]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 273}], {
             RGBColor[
             0.2391065540897807, 0.3686465269524677, 0.9369281365777409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 308}], {
             RGBColor[
             0.18180898862834943`, 0.3084231527770282, 0.9336651249888644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 421}], {
             RGBColor[
             0.18186414913512938`, 0.30848112996703203`, 0.9336682662981228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 423}], {
             RGBColor[
             0.18624879198055028`, 0.31308966759998247`, 0.9339179652216718]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 446}], {
             RGBColor[
             0.2064114829025504, 0.3342819341474452, 0.9350662006416515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 477}], {
             RGBColor[
             0.21467165996386678`, 0.3429639039643634, 0.9355366055054566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 129}], {
             RGBColor[
             0.3203552344901264, 0.4497120899906687, 0.9417137426958612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 163}], {
             RGBColor[
             0.27605150294224795`, 0.40747801064146116`, 0.939032096759735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 189}], {
             RGBColor[
             0.27244302962866296`, 0.40368527639846097`, 0.9388265995427842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 206}], {
             RGBColor[
             0.31392242641055057`, 0.44414031495447526`, 0.9413038498533395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 266}], {
             RGBColor[
             0.28731571918259713`, 0.4193174161026276, 0.9396735772107083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 364}], {
             RGBColor[
             0.27183868506633, 0.4030500719457907, 0.938792183014007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 374}], {
             RGBColor[
             0.2684205085848909, 0.3994573517388918, 0.938597522920128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 410}], {
             RGBColor[
             0.32438785376155105`, 0.4532049421182389, 0.9419706976299311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 437}], {
             RGBColor[
             0.27047057871071917`, 0.40161210542309067`, 0.938714271380987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 185}], {
             RGBColor[
             0.26895237692670115`, 0.40001637908853493`, 0.9386278120353654]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 186}], {
             RGBColor[
             0.24483520726957755`, 0.37466770466202415`, 0.9372543749015474]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 196}], {
             RGBColor[
             0.27482966958615396`, 0.4061937863154972, 0.938962515157646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 218}], {
             RGBColor[
             0.24296647092511459`, 0.372703544279266, 0.937147953131278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 295}], {
             RGBColor[
             0.24177394363545715`, 0.37145012248723885`, 0.937080040466318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 300}], {
             RGBColor[
             0.23995882574419874`, 0.3695423184984049, 0.9369766721876371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 335}], {
             RGBColor[
             0.2653660882581673, 0.3962469623140712, 0.938423578201131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 409}], {
             RGBColor[
             0.24775783308986035`, 0.3777395697043211, 0.9374208141183751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 456}], {
             RGBColor[
             0.23880926652767986`, 0.3683340588755796, 0.9369112064908769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 458}], {
             RGBColor[
             0.24222963005763265`, 0.3719290778091332, 0.9371059911339332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 496}], {
             RGBColor[
             0.26542477376877, 0.3963086445065909, 0.9384269202541424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 217}], {
             RGBColor[
             0.29571753049971145`, 0.4271336534107135, 0.9401891973787395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 290}], {
             RGBColor[
             0.2791002706073135, 0.4106824587604797, 0.9392057195680129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 316}], {
             RGBColor[
             0.26110517012024004`, 0.39176846719329617`, 0.9381809252166395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 340}], {
             RGBColor[
             0.3045749314378675, 0.43480548891742876`, 0.9407535831342266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 355}], {
             RGBColor[
             0.30021105187484454`, 0.43102571577490256`, 0.9404755205872981]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 378}], {
             RGBColor[
             0.2773998635716586, 0.40889522315397336`, 0.9391088839028592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 384}], {
             RGBColor[
             0.27776805045914515`, 0.4092822109171187, 0.9391298516014178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 146}], {
             RGBColor[
             0.2655122364597581, 0.39640057334027434`, 0.9384319011250047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 201}], {
             RGBColor[
             0.28877500860148286`, 0.42085122180616963`, 0.9397566815842886]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 256}], {
             RGBColor[
             0.2812386903435383, 0.41293007348689414`, 0.9393274994084824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 271}], {
             RGBColor[
             0.2644482810539334, 0.39528228875008364`, 0.938371310438624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 284}], {
             RGBColor[
             0.2590919383322233, 0.3896524329378227, 0.9380662746446216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 312}], {
             RGBColor[
             0.28875139009156847`, 0.4208263972547496, 0.9397553365450895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 376}], {
             RGBColor[
             0.2762731715166523, 0.4077109983677596, 0.9390447204571181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[
             0.2845065356159251, 0.4163647860615299, 0.939513598362401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 415}], {
             RGBColor[
             0.2800519643946353, 0.41168274927182613`, 0.9392599171212961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 442}], {
             RGBColor[
             0.2785182841132166, 0.41007075405510884`, 0.939172576298146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 444}], {
             RGBColor[
             0.272192144891436, 0.40342158063262434`, 0.9388123120281499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 464}], {
             RGBColor[
             0.2584790029138965, 0.3890081989508112, 0.9380313688793045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 148}], {
             RGBColor[
             0.2439596839808273, 0.373747474174165, 0.9372045151454738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 153}], {
             RGBColor[
             0.24659824483285725`, 0.37652076892406894`, 0.9373547772825959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 190}], {
             RGBColor[
             0.24818657202567745`, 0.37819020150948346`, 0.9374452301665075]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 195}], {
             RGBColor[
             0.25920772540956155`, 0.3897741324974299, 0.9380728685473844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 224}], {
             RGBColor[
             0.2736149088479135, 0.4049169957593272, 0.9388933363306806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 263}], {
             RGBColor[
             0.2608320887293601, 0.39148144133712115`, 0.9381653736354167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 323}], {
             RGBColor[
             0.24380409586490398`, 0.37358394119947325`, 0.9371956546324439]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 342}], {
             RGBColor[
             0.25412533445039487`, 0.3844322173571471, 0.9377834339009834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 351}], {
             RGBColor[
             0.26915448795361524`, 0.4002288105924009, 0.9386393219593516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 356}], {
             RGBColor[
             0.2588007282426925, 0.3893463526699398, 0.9380496906608295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 395}], {
             RGBColor[
             0.2566255492107321, 0.38706010159303317`, 0.9379258174328484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 447}], {
             RGBColor[
             0.2473817363738829, 0.37734426820991973`, 0.9373993959667855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 452}], {
             RGBColor[
             0.2361084750925497, 0.3654953558371904, 0.936757400414109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 463}], {
             RGBColor[
             0.2576804433404335, 0.3881688622075002, 0.9379858920929589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 130}], {
             RGBColor[
             0.17905963034776856`, 0.3055334029047545, 0.9335085531020964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 143}], {
             RGBColor[
             0.17905963102166003`, 0.30553340361305714`, 0.9335085531404735]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 209}], {
             RGBColor[
             0.3725579164542212, 0.4820770410775821, 0.9462434146682975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 214}], {
             RGBColor[
             0.18949968777431325`, 0.3165065651979255, 0.9341030989278573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 273}], {
             RGBColor[
             0.23636683819300525`, 0.3657669118369359, 0.936772113810466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 302}], {
             RGBColor[
             0.18467080951855291`, 0.3114311079825565, 0.9338281014548768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 308}], {
             RGBColor[
             0.17906927273157397`, 0.3055435376614964, 0.9335091022215896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 325}], {
             RGBColor[
             0.1791045905323438, 0.30558065890938335`, 0.9335111135180953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 347}], {
             RGBColor[
             0.17905963034776856`, 0.3055334029047545, 0.9335085531020964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 386}], {
             RGBColor[
             0.17905963034776856`, 0.3055334029047545, 0.9335085531020964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 421}], {
             RGBColor[
             0.17912443323835392`, 0.3056015148515002, 0.9335122435308479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 423}], {
             RGBColor[
             0.1835090760837748, 0.31021005248445066`, 0.9337619424543968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 477}], {
             RGBColor[
             0.2119319440670913, 0.3400842888488316, 0.9353805827381816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 115}], {
             RGBColor[
             0.7109234320173796, 0.7727455262693818, 0.9730887236423327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 203}], {
             RGBColor[
             0.5176225598035007, 0.6192683385358883, 0.9551682905030956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 208}], {
             RGBColor[
             0.41139850447614446`, 0.5294684917353877, 0.9477902381259522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 258}], {
             RGBColor[
             0.4370504632160207, 0.551686929090934, 0.9494247582537205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 289}], {
             RGBColor[
             0.47002476811242727`, 0.580247614655448, 0.9515258518036867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 291}], {
             RGBColor[
             0.577802812280651, 0.6679328507014297, 0.9600375327920143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 297}], {
             RGBColor[
             0.5100213466264654, 0.6130973312480197, 0.954569895157638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 311}], {
             RGBColor[
             0.6237676761079407, 0.7038409516692123, 0.9646188808522442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 349}], {
             RGBColor[
             0.45713997699902986`, 0.5690874562014547, 0.9507048443075143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 359}], {
             RGBColor[
             0.443064873322788, 0.5568963088323743, 0.9498079911473898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 381}], {
             RGBColor[
             0.5349916430046526, 0.6333693427468647, 0.9565356483577385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 397}], {
             RGBColor[
             0.4296132686116584, 0.545245204928905, 0.9489508667899835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 419}], {
             RGBColor[
             0.5066845097134336, 0.6103883367192307, 0.9543072071326079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 124}], {
             RGBColor[
             0.9419104649402625, 0.9128295501642687, 0.6508778471089514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 136}], {
             RGBColor[
             0.9450645210490293, 0.9581750855858149, 0.964884369377244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 178}], {
             RGBColor[
             0.9564265081535962, 0.965404037867567, 0.8899068420398936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 203}], {
             RGBColor[
             0.7278675078772177, 0.786501490374317, 0.9744226233622142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 253}], {
             RGBColor[
             0.9531001134456565, 0.9640284881713892, 0.9450338107840079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 277}], {
             RGBColor[
             0.8462349559465709, 0.8806222819755531, 0.9850914215175051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 291}], {
             RGBColor[
             0.7880477603543681, 0.8351660025398585, 0.9792918656511329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 297}], {
             RGBColor[
             0.7202662947001824, 0.7803304830864486, 0.9738242280167566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 311}], {
             RGBColor[
             0.8340126241816578, 0.871074103507641, 0.9838732137113628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 381}], {
             RGBColor[
             0.7452365910783697, 0.8006024945852935, 0.9757899812168571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 419}], {
             RGBColor[
             0.7169294577871506, 0.7776214885576594, 0.9735615399917263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 439}], {
             RGBColor[
             0.8910404321249454, 0.9159554702009634, 0.9894694259289032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 484}], {
             RGBColor[
             0.9570300393594782, 0.9635915325846716, 0.7300132516870645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 192}], {
             RGBColor[
             0.2516702940273803, 0.3818518142140055, 0.9376436229807996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 280}], {
             RGBColor[
             0.25280916302349343`, 0.3830488377373854, 0.9377084798853226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 310}], {
             RGBColor[
             0.2727415097182925, 0.40399899789739224`, 0.9388435975423268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 327}], {
             RGBColor[
             0.25289755432094124`, 0.38314174259533496`, 0.937713513638949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 399}], {
             RGBColor[
             0.24511345141386065`, 0.3749601568993634, 0.937270220493939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 412}], {
             RGBColor[
             0.24555371763094103`, 0.3754229046080053, 0.9372952930036862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 483}], {
             RGBColor[
             0.27268756010159706`, 0.40394229342964216`, 0.9388405251914673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 139}], {
             RGBColor[
             0.47255522666265165`, 0.5807190878311534, 0.9521624096580703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 140}], {
             RGBColor[
             0.44035466890019287`, 0.5545772244209933, 0.9496274637964799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 154}], {
             RGBColor[
             0.34530823850037556`, 0.4735103733174856, 0.9432237135065259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 247}], {
             RGBColor[
             0.4380433274875822, 0.5527007733374919, 0.9494455065337566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 255}], {
             RGBColor[
             0.38933039965095584`, 0.511640156687964, 0.9460287666877722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 269}], {
             RGBColor[
             0.41500730712434825`, 0.5338802033825223, 0.947664876526779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 338}], {
             RGBColor[
             0.3505903006321732, 0.47808543005188675`, 0.9435602818348199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 369}], {
             RGBColor[
             0.40051134864769267`, 0.5213245327381009, 0.9467412068709193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 390}], {
             RGBColor[
             0.34091437037852435`, 0.46896566133560236`, 0.9429707972165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 425}], {
             RGBColor[
             0.3782090614978762, 0.502007412554475, 0.9453201248548712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 466}], {
             RGBColor[
             0.44229172329685795`, 0.5561498124435122, 0.9497799558142495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[
             0.31734549257895406`, 0.4492904482488255, 0.9414419520628983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 151}], {
             RGBColor[
             0.31595121433390305`, 0.44790234871507695`, 0.9413597168905753]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 188}], {
             RGBColor[
             0.3311926249986076, 0.4612841383736176, 0.9423242790961401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 304}], {
             RGBColor[
             0.3318360758338559, 0.46184146314633034`, 0.9423652792143808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 310}], {
             RGBColor[
             0.3109325878407584, 0.44262745407148385`, 0.9410739135361832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 327}], {
             RGBColor[
             0.2910886324434072, 0.42177019876942656`, 0.9399438296328053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 483}], {
             RGBColor[
             0.31087863822406303`, 0.44257074960373377`, 0.9410708411853237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 197}], {
             RGBColor[
             0.8441364985929255, 0.8770550844901885, 0.8875786005274353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 237}], {
             RGBColor[
             0.9483698835729416, 0.9591789791220269, 0.8977829179807035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 270}], {
             RGBColor[
             0.9903352312511376, 0.9902713839961873, 0.8098337599957988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 309}], {
             RGBColor[
             0.9918390696706652, 0.9889511495464178, 0.6437403499501158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 320}], {
             RGBColor[
             0.9896249360090673, 0.9899776586598361, 0.8216051903420669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 345}], {
             RGBColor[
             0.8251862844410536, 0.8622510331677843, 0.8856898202805965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 375}], {
             RGBColor[
             0.9744244063754681, 0.9793738724475776, 0.8801494909995853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 426}], {
             RGBColor[
             0.9304108836330538, 0.9448589600540273, 0.8960699725342486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 489}], {
             RGBColor[
             0.9903724843514137, 0.9902867891105125, 0.8092163797162932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 123}], {
             RGBColor[
             0.20719251066229882`, 0.33510284384296096`, 0.9351106790171422]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 125}], {
             RGBColor[
             0.2080475453125366, 0.33600153947268885`, 0.9351593719755629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 177}], {
             RGBColor[
             0.20805903153131503`, 0.3360136122168933, 0.9351600260987298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 438}], {
             RGBColor[
             0.21444303080234048`, 0.3427236002196732, 0.9355235854129342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 455}], {
             RGBColor[
             0.2056810719300792, 0.33351422590464763`, 0.9350246048173154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 457}], {
             RGBColor[
             0.21450528797873675`, 0.3427890364593986, 0.9355271308670288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 161}], {
             RGBColor[
             0.9088989497892817, 0.5955852022276555, 0.2954383174204215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[
             0.8641469744095227, 0.4273429033856967, 0.2064477599128205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.86583591956703, 0.4350120088827739, 0.20785705715207875`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 259}], {
             RGBColor[
             0.8446533203330481, 0.33882677308300735`, 0.1901817771182239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 341}], {
             RGBColor[
             0.9105196563022746, 0.6003916270804778, 0.3579070077274834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 450}], {
             RGBColor[
             0.8225872124582064, 0.17462078949919407`, 0.16926284619957344`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 454}], {
             RGBColor[
             0.8636741838299911, 0.42519607178708907`, 0.20605325186410173`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 469}], {
             RGBColor[
             0.8439483097229172, 0.3356254845618147, 0.18959349898373934`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 471}], {
             RGBColor[
             0.842139262249025, 0.3249064119542755, 0.18798591116014318`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 475}], {
             RGBColor[
             0.8332346662535209, 0.256461785113985, 0.17945885997854572`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 491}], {
             RGBColor[
             0.9108136867178351, 0.6010205284083265, 0.38991040391585896`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 500}], {
             RGBColor[
             0.8234793018793516, 0.18147777970619255`, 0.1701171120367329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 150}], {
             RGBColor[
             0.8444744803276283, 0.32854420856354566`, 0.1896617078466737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.8441272348319537, 0.3258751275198433, 0.1893291851678579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 233}], {
             RGBColor[
             0.8553320507775657, 0.4120002528594733, 0.20005892957140564`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 267}], {
             RGBColor[
             0.9282834555711476, 0.7330087810415269, 0.3115827018545064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 406}], {
             RGBColor[
             0.929061342775948, 0.7356327772399205, 0.3146046467534838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 413}], {
             RGBColor[
             0.9206701650068785, 0.7073273642826143, 0.2820065056616069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 476}], {
             RGBColor[
             0.8579983660337116, 0.432494720305006, 0.20261219607186334`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 493}], {
             RGBColor[
             0.9305407827762575, 0.7399602763410837, 0.37672867587283654`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 125}], {
             RGBColor[
             0.2078185513522534, 0.33576085230137553`, 0.9351463311082908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 177}], {
             RGBColor[
             0.2078300375710318, 0.33577292504558, 0.935146985231458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 438}], {
             RGBColor[
             0.21421403684205725`, 0.34248291304835987`, 0.9355105445456623]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 455}], {
             RGBColor[
             0.20545207796979598`, 0.3332735387333343, 0.9350115639500436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 136}], {
             RGBColor[
             0.9658066058981951, 0.931025957642273, 0.6234191599847442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 178}], {
             RGBColor[
             0.977168593002762, 0.938254909924025, 0.5484416326473938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 253}], {
             RGBColor[
             0.9738421982948224, 0.9368793602278473, 0.603568601391508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 261}], {
             RGBColor[
             0.9213196831594281, 0.7168052052597729, 0.265491517223669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 357}], {
             RGBColor[
             0.9348974167088442, 0.7776187751730486, 0.27677767167712564`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 484}], {
             RGBColor[
             0.9777721242086441, 0.9364424046411297, 0.38854804229456463`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 177}], {
             RGBColor[
             0.20868507222126964`, 0.3366716206753079, 0.9351956781898786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 438}], {
             RGBColor[
             0.2150690714922951, 0.34338160867808776`, 0.9355592375040829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 455}], {
             RGBColor[
             0.20630711262003382`, 0.3341722343630622, 0.9350602569084642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 457}], {
             RGBColor[
             0.21513132866869134`, 0.3434470449178132, 0.9355627829581774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 144}], {
             RGBColor[
             0.24868278916139275`, 0.37871175718110384`, 0.937473488998299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 279}], {
             RGBColor[
             0.26484901945855754`, 0.3957034902216259, 0.9383941318979281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 285}], {
             RGBColor[
             0.28277807837083513`, 0.4140236211798849, 0.9394343678430408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 481}], {
             RGBColor[
             0.28467725623571494`, 0.41566859359098884`, 0.9395553817772139]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 130}], {
             RGBColor[
             0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 168}], {
             RGBColor[
             0.5683860156508949, 0.5194386987803812, 0.5916300590553423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 179}], {
             RGBColor[
             0.20245447418328588`, 0.33012286709465477`, 0.9348408548489592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 200}], {
             RGBColor[
             0.5634039093287206, 0.4987072281229762, 0.587570692606852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 213}], {
             RGBColor[
             0.5650928544862279, 0.5063763336200533, 0.5889799898461102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 254}], {
             RGBColor[
             0.23123903037733173`, 0.3603772607008694, 0.9364800927412753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 302}], {
             RGBColor[
             0.2080645848230672, 0.3360194490786239, 0.9351603423504797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 315}], {
             RGBColor[
             0.20573971378665917`, 0.3335758622140216, 0.9350279443842948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 325}], {
             RGBColor[
             0.20249836583685807`, 0.33016900000545074`, 0.9348433544136983]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 347}], {
             RGBColor[
             0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 368}], {
             RGBColor[
             0.3170407306432145, 0.44137417912788274`, 0.9417027210777457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 386}], {
             RGBColor[
             0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 401}], {
             RGBColor[
             0.499716094491864, 0.5888978154955886, 0.9571173753725956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 454}], {
             RGBColor[
             0.562931118749189, 0.49656039652436856`, 0.5871761845581333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 169}], {
             RGBColor[
             0.4937426983927686, 0.5998815912671589, 0.9532883803380281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 197}], {
             RGBColor[
             0.5961844176461558, 0.6822017797294064, 0.9619318024689351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 204}], {
             RGBColor[
             0.4983181319181479, 0.6035961343239933, 0.9536485752255113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 345}], {
             RGBColor[
             0.5772342034942839, 0.6673977284070023, 0.9600430222220963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 355}], {
             RGBColor[
             0.4117250076221206, 0.5299124488854325, 0.9477665145867664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 362}], {
             RGBColor[
             0.4416023765346493, 0.55579072415724, 0.9496702741143528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 498}], {
             RGBColor[
             0.4783163619958606, 0.5873577964316139, 0.9520739626283314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 170}], {
             RGBColor[
             0.3261401713486173, 0.4557924254151241, 0.9420431862919051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 206}], {
             RGBColor[
             0.3491669657996257, 0.47685260895882275`, 0.9434695881978956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 265}], {
             RGBColor[
             0.3383071396578693, 0.46744637338556605`, 0.9427776096791101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 266}], {
             RGBColor[
             0.32256025857167225`, 0.4520297101069751, 0.9418393155552645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 328}], {
             RGBColor[
             0.3704563897071251, 0.49529243790994043`, 0.944826131463783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 410}], {
             RGBColor[
             0.3596323931506261, 0.48591723612258636`, 0.9441364359744873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 433}], {
             RGBColor[
             0.3405530126531223, 0.4693916356931953, 0.94292071472042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 143}], {
             RGBColor[
             0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 179}], {
             RGBColor[
             0.17892806853100302`, 0.30539512309383293`, 0.93350106085126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 214}], {
             RGBColor[
             0.1893670574265447, 0.316367162293171, 0.9340955458257609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 254}], {
             RGBColor[
             0.20771262472504887`, 0.3356495167000475, 0.935140298743576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 302}], {
             RGBColor[
             0.18453817917078433`, 0.311291705077802, 0.9338205483527805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 315}], {
             RGBColor[
             0.1822133081343763, 0.30884811821319974`, 0.9336881503865955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 325}], {
             RGBColor[
             0.1789719601845752, 0.3054412560046289, 0.9335035604159989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 347}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 368}], {
             RGBColor[
             0.2935143249909316, 0.4166464351270609, 0.9403629270800464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 386}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 421}], {
             RGBColor[
             0.17899180289058533`, 0.3054621119467458, 0.9335046904287516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 477}], {
             RGBColor[
             0.2117993137193227, 0.3399448859440771, 0.9353730296360853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 135}], {
             RGBColor[
             0.25711790914467114`, 0.38757760310102596`, 0.937953856602705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 147}], {
             RGBColor[
             0.257551109678863, 0.38803292432896186`, 0.9379785267322645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 170}], {
             RGBColor[
             0.28014480934839103`, 0.4117803352049335, 0.9392652045040607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 171}], {
             RGBColor[
             0.26267563753313167`, 0.39341912801763035`, 0.9382703610125054]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 216}], {
             RGBColor[
             0.26474751566428445`, 0.3955968032981327, 0.9383883514070055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 238}], {
             RGBColor[
             0.29188148517230905`, 0.42306158545170824`, 0.9399722100345929]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 265}], {
             RGBColor[
             0.29231177765764305`, 0.42343428317537546`, 0.9399996278912657]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 374}], {
             RGBColor[
             0.2576696859737398, 0.38815755553304865`, 0.9379852794768397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 385}], {
             RGBColor[
             0.24854031848564526`, 0.3785620114677306, 0.9374653755040816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 391}], {
             RGBColor[
             0.2523681386345833, 0.3825852931420795, 0.9376833641988113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 433}], {
             RGBColor[
             0.29455765065289613`, 0.4253795454830047, 0.9401427329325757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 209}], {
             RGBColor[
             0.7780282420345992, 0.8243344980363514, 0.8860787195432924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 233}], {
             RGBColor[
             0.9166463543771588, 0.6614692040973338, 0.5010749461233683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 273}], {
             RGBColor[
             0.6418371637733833, 0.7080243687957053, 0.8766074186854609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 423}], {
             RGBColor[
             0.5889794016641527, 0.6524675094432201, 0.8735972473293918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 151}], {
             RGBColor[
             0.3259839947322987, 0.4565922388339624, 0.9419989967859217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 155}], {
             RGBColor[
             0.4555313931992919, 0.5659235600860384, 0.9510915748153721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 181}], {
             RGBColor[
             0.3829354312034995, 0.5061011564392373, 0.9456212849531489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 225}], {
             RGBColor[
             0.3097114792684619, 0.4394887933443991, 0.9410723011032855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 235}], {
             RGBColor[
             0.3511076947395869, 0.47853357082274445`, 0.9435932497298307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 239}], {
             RGBColor[
             0.34805209112246643`, 0.47588696054869806`, 0.943398549369312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 249}], {
             RGBColor[
             0.3173607671926588, 0.44752867994559636`, 0.9415079167344612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 260}], {
             RGBColor[
             0.31537504749154577`, 0.44544156263782575`, 0.9413948329350919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 262}], {
             RGBColor[
             0.4106297397776527, 0.5294703750419166, 0.9475567521778445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 296}], {
             RGBColor[
             0.3292967430314739, 0.4596420207034847, 0.942203475173657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 332}], {
             RGBColor[
             0.3736828594731001, 0.4980870438541423, 0.9450317192642157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 344}], {
             RGBColor[
             0.404458323018091, 0.5244601408973477, 0.9470709156438875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 424}], {
             RGBColor[
             0.33288404882225986`, 0.46274916467623195`, 0.942432055126516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 440}], {
             RGBColor[
             0.31342375230206637`, 0.44339062767442217`, 0.9412837095607336]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 138}], {
             RGBColor[
             0.2265863896100655, 0.3554870402600099, 0.9362151317325447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 251}], {
             RGBColor[
             0.24587579480159133`, 0.37576142813523083`, 0.9373136348220843]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 305}], {
             RGBColor[
             0.2421591297202534, 0.37185497748456803`, 0.9371019762440154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 367}], {
             RGBColor[
             0.23152572380893705`, 0.3606785936749, 0.9364964195080803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 416}], {
             RGBColor[
             0.24737003573452257`, 0.37733197009608865`, 0.9373987296326833]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 438}], {
             RGBColor[
             0.22733547187831532`, 0.35627437321849936`, 0.9362577908595535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 457}], {
             RGBColor[
             0.22739772905471156`, 0.3563398094582248, 0.936261336313648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 499}], {
             RGBColor[
             0.2469625122439105, 0.37690363706897373`, 0.93737552177277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 147}], {
             RGBColor[
             0.2510599689447852, 0.3812103238553528, 0.9376088658702408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 170}], {
             RGBColor[
             0.2736536686143132, 0.40495773473132446`, 0.9388955436420372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 171}], {
             RGBColor[
             0.25618449679905386`, 0.3865965275440213, 0.9379007001504819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 216}], {
             RGBColor[
             0.25825637493020664`, 0.38877420282452363`, 0.938018690544982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 385}], {
             RGBColor[
             0.24204917775156742`, 0.37173941099412156`, 0.9370957146420581]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 391}], {
             RGBColor[
             0.24587699790050546`, 0.37576269266847045`, 0.9373137033367878]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 253}], {
             RGBColor[
             0.9769962544035893, 0.9822248956493935, 0.9175751236598007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 261}], {
             RGBColor[
             0.924473739268195, 0.762150740681319, 0.5794980394919615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 277}], {
             RGBColor[
             0.8701310969045036, 0.8988186894535575, 0.9576327343932979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 291}], {
             RGBColor[
             0.8119439013123007, 0.853362410017863, 0.9518331785269256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 311}], {
             RGBColor[
             0.8579087651395905, 0.8892705109856455, 0.9564145265871555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 319}], {
             RGBColor[
             0.8419251732908781, 0.8767840075536342, 0.9548214315268342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 377}], {
             RGBColor[
             0.9750328863705816, 0.980900148051852, 0.9271469902951855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 484}], {
             RGBColor[
             0.980926180317411, 0.981787940062676, 0.7025545645628573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 488}], {
             RGBColor[
             0.8691624812525807, 0.8980619995445237, 0.9575361918373422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 145}], {
             RGBColor[
             0.2203693542453783, 0.34895254190891456`, 0.9358610807658054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 183}], {
             RGBColor[
             0.2125239415632086, 0.34070651575206007`, 0.9354142961198038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 346}], {
             RGBColor[
             0.21898159921391522`, 0.34749392338209584`, 0.9357820501697631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 358}], {
             RGBColor[
             0.22285337720406, 0.3515634075346411, 0.9360025421985196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 404}], {
             RGBColor[
             0.2167644246749318, 0.34516353236463915`, 0.9356557853597838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 407}], {
             RGBColor[
             0.2172194419002935, 0.34564178431825265`, 0.9356816979176306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 408}], {
             RGBColor[
             0.2212925375899113, 0.34992286613722345`, 0.9359136546915492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 430}], {
             RGBColor[
             0.22990978373834364`, 0.3589801382041882, 0.9364043941116291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 352}], {
             RGBColor[
             0.22389864331585435`, 0.3526620484918363, 0.9360620685572537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 367}], {
             RGBColor[
             0.22490572664447084`, 0.3537205569229832, 0.9361194204629721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 457}], {
             RGBColor[
             0.22077773189024535`, 0.349381772706308, 0.9358843372685399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 140}], {
             RGBColor[
             0.5318346221124927, 0.6308063309644387, 0.9562871161085591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 247}], {
             RGBColor[
             0.529523280699882, 0.6289298798809373, 0.9561051588458358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 255}], {
             RGBColor[
             0.4808103528632557, 0.5878692632314095, 0.9526884189998513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 269}], {
             RGBColor[
             0.506487260336648, 0.6101093099259678, 0.9543245288388581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 274}], {
             RGBColor[
             0.5133847204187874, 0.6158278696108893, 0.9548346722630138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 360}], {
             RGBColor[
             0.5717007512056378, 0.6631714505109032, 0.9594255238252141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 369}], {
             RGBColor[
             0.49199130185999246`, 0.5975536392815464, 0.9534008591829983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 370}], {
             RGBColor[
             0.5777392587332322, 0.6680737829534684, 0.9599008972575682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 425}], {
             RGBColor[
             0.469689014710176, 0.5782365190979204, 0.9519797771669503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 466}], {
             RGBColor[
             0.5337716765091578, 0.6323789189869576, 0.9564396081263286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 468}], {
             RGBColor[
             0.5212061017709153, 0.6221776193417614, 0.9554504000537172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 169}], {
             RGBColor[
             0.4961881243257401, 0.601866898204728, 0.953480893225362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 204}], {
             RGBColor[
             0.5007635578511195, 0.6055814412615623, 0.9538410881128452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 219}], {
             RGBColor[
             0.5129514818808725, 0.6154761470486363, 0.9548005661383041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 244}], {
             RGBColor[
             0.42103754660959536`, 0.5378457039996745, 0.9483965938455836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 247}], {
             RGBColor[
             0.4973227229374232, 0.6027880164707773, 0.9535702129842454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 255}], {
             RGBColor[
             0.4486097951007969, 0.5617273998212495, 0.950153473138261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 274}], {
             RGBColor[
             0.4811841626563286, 0.5896860062007292, 0.9522997264014235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 334}], {
             RGBColor[
             0.4512190714580578, 0.563987423855866, 0.9503197339204532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 361}], {
             RGBColor[
             0.5719177559547599, 0.6633194007954346, 0.9594619041005235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 363}], {
             RGBColor[
             0.4522227109181607, 0.5648567259118211, 0.9503836849393674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 369}], {
             RGBColor[
             0.4597907440975337, 0.5714117758713864, 0.950865913321408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 370}], {
             RGBColor[
             0.5455387009707735, 0.6419319195433083, 0.9573659513959778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 425}], {
             RGBColor[
             0.4374884569477172, 0.5520946556877604, 0.9494448313053598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 466}], {
             RGBColor[
             0.5015711187466989, 0.6062370555767975, 0.9539046622647382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 188}], {
             RGBColor[
             0.32343001274534444`, 0.45456055380007726`, 0.9418296523075707]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 220}], {
             RGBColor[
             0.32424804297229537`, 0.4552690904672675, 0.9418817764702763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[
             0.2831042170303842, 0.4148134850118461, 0.939436571482416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 304}], {
             RGBColor[
             0.3240734635805927, 0.45511787857278996`, 0.9418706524258115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 310}], {
             RGBColor[
             0.3031699755874952, 0.4359038694979436, 0.9405792867476138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 429}], {
             RGBColor[
             0.30159042381675216`, 0.434243660437526, 0.9404893336110074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 173}], {
             RGBColor[
             0.8420436305365226, 0.8765386852966244, 0.9380905002853989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 222}], {
             RGBColor[
             0.5711190039988594, 0.6615355308329243, 0.9600580034664301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 241}], {
             RGBColor[
             0.7025032226254809, 0.7675201238280478, 0.9709826140315919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 402}], {
             RGBColor[
             0.6259177691187879, 0.7063115685381091, 0.9642924066530247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 417}], {
             RGBColor[
             0.7002784838355302, 0.7657821409766972, 0.9707608728603756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 461}], {
             RGBColor[
             0.8219899053555546, 0.8616442791794481, 0.9747961115925544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 179}], {
             RGBColor[
             0.17892806920489446`, 0.30539512380213557`, 0.933501060889637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 214}], {
             RGBColor[
             0.18936705810043614`, 0.31636716300147366`, 0.934095545864138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 226}], {
             RGBColor[
             0.17917599682249857`, 0.3056557114477564, 0.9335151800006836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 273}], {
             RGBColor[
             0.23623420851912813`, 0.365627509640484, 0.9367645607467467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 283}], {
             RGBColor[
             0.18007058028918088`, 0.3065959753911073, 0.9335661252056935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 292}], {
             RGBColor[
             0.1789488167630598, 0.30541693080123855`, 0.9335022424323813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 302}], {
             RGBColor[
             0.1845381798446758, 0.31129170578610466`, 0.9338205483911577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 308}], {
             RGBColor[
             0.17893664305769685`, 0.3054041354650445, 0.9335015491578702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 325}], {
             RGBColor[
             0.17897196085846667`, 0.30544125671293154`, 0.9335035604543761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 347}], {
             RGBColor[
             0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 386}], {
             RGBColor[
             0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 421}], {
             RGBColor[
             0.1789918035644768, 0.3054621126550484, 0.9335046904671287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 423}], {
             RGBColor[
             0.1833764464098977, 0.31007065028799885`, 0.9337543893906777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 446}], {
             RGBColor[
             0.20353913733189777`, 0.3312629168354616, 0.9349026248106573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 477}], {
             RGBColor[
             0.21179931439321417`, 0.33994488665237976`, 0.9353730296744625]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 279}], {
             RGBColor[
             0.2623939933592224, 0.3931231021335797, 0.9382543217934566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 494}], {
             RGBColor[
             0.25236564813326057`, 0.3825826754672824, 0.9376832223684453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 183}], {
             RGBColor[
             0.21281275410739692`, 0.3410100760477749, 0.9354307435669353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 286}], {
             RGBColor[
             0.22187921582518422`, 0.3505395021600439, 0.9359470651491353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 294}], {
             RGBColor[
             0.22948545468760678`, 0.35853414146784807`, 0.9363802291999281]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 346}], {
             RGBColor[
             0.21927041175810352`, 0.3477974836778107, 0.9357984976168947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 358}], {
             RGBColor[
             0.2231421897482483, 0.351866967830356, 0.9360189896456512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 404}], {
             RGBColor[
             0.2170532372191201, 0.345467092660354, 0.9356722328069155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 407}], {
             RGBColor[
             0.2175082544444818, 0.34594534461396753`, 0.9356981453647621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 408}], {
             RGBColor[
             0.2215813501340996, 0.35022642643293833`, 0.9359301021386808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 430}], {
             RGBColor[
             0.23019859628253192`, 0.35928369849990305`, 0.9364208415587607]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 201}], {
             RGBColor[
             0.28119600247616383`, 0.41288520583171645`, 0.9393250683975864]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 211}], {
             RGBColor[
             0.2444868180291041, 0.37430152548113294`, 0.9372345346496982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 271}], {
             RGBColor[
             0.25686927492861433`, 0.3873162727756304, 0.9379396972519218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 284}], {
             RGBColor[
             0.25151293220690424`, 0.3816864169633695, 0.9376346614579194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 312}], {
             RGBColor[
             0.28117238396624933`, 0.41286038128029634`, 0.9393237233583873]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 376}], {
             RGBColor[
             0.2686941653913333, 0.39974498239330636`, 0.9386131072704159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 400}], {
             RGBColor[
             0.276927529490606, 0.4083987700870767, 0.9390819851756989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 415}], {
             RGBColor[
             0.27247295826931617`, 0.4037167332973729, 0.9388283039345939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 442}], {
             RGBColor[
             0.2709392779878975, 0.40210473808065567`, 0.9387409631114438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 444}], {
             RGBColor[
             0.2646131387661169, 0.39545556465817117`, 0.9383806988414477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 464}], {
             RGBColor[
             0.25089999678857744`, 0.38104218297635795`, 0.9375997556926023]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 497}], {
             RGBColor[
             0.24696343657246012`, 0.3769046085968852, 0.9373755744119134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 171}], {
             RGBColor[
             0.2566176973332457, 0.3870518487719572, 0.9379253702800414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 216}], {
             RGBColor[
             0.2586895754643985, 0.38922952405245953`, 0.9380433606745415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 238}], {
             RGBColor[
             0.2858235449724231, 0.4166943062060351, 0.9396272193021288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 385}], {
             RGBColor[
             0.24248237828575928`, 0.37219473222205746`, 0.9371203847716176]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 391}], {
             RGBColor[
             0.24631019843469731`, 0.37621801389640636`, 0.9373383734663472]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 153}], {
             RGBColor[
             0.2422944032111111, 0.37199715850029413`, 0.9371096798692006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 190}], {
             RGBColor[
             0.2438827304039313, 0.37366659108570865`, 0.9372001327531121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 195}], {
             RGBColor[
             0.2549038837878154, 0.3852505220736551, 0.9378277711339891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 323}], {
             RGBColor[
             0.23950025424315785`, 0.36906033077569844`, 0.9369505572190486]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 342}], {
             RGBColor[
             0.2498214928286487, 0.3799086069333723, 0.9375383364875882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 351}], {
             RGBColor[
             0.26485064633186906`, 0.3957052001686261, 0.9383942245459564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 356}], {
             RGBColor[
             0.2544968866209464, 0.384822742246165, 0.9378045932474341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 452}], {
             RGBColor[
             0.23180463347080354`, 0.3609717454134156, 0.9365123030007138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 463}], {
             RGBColor[
             0.25337660171868737`, 0.3836452517837254, 0.9377407946795635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 158}], {
             RGBColor[
             0.3556980515257828, 0.48250950715290686`, 0.943885743205154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 165}], {
             RGBColor[
             0.3889540140770109, 0.511314150421502, 0.9460047837318252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 182}], {
             RGBColor[
             0.36623071660169665`, 0.4916323722545241, 0.9445568753101211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 187}], {
             RGBColor[
             0.30925143443909986`, 0.4382007802607746, 0.9410755580672832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 275}], {
             RGBColor[
             0.38378936730216673`, 0.5068407929678266, 0.9456756970062499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 282}], {
             RGBColor[
             0.48076658116172494`, 0.586646877963116, 0.9530129031646457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 324}], {
             RGBColor[
             0.361776111320833, 0.4877740170552114, 0.9442730318006773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 441}], {
             RGBColor[
             0.4020035872776604, 0.5226170348372846, 0.946836290996886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 159}], {
             RGBColor[
             0.821097410502475, 0.1631695188320622, 0.16783621016427433`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 233}], {
             RGBColor[
             0.832302226448087, 0.24929464417169217`, 0.1785659545678221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 267}], {
             RGBColor[
             0.9052536312416688, 0.5703031723537458, 0.2900897268509228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 406}], {
             RGBColor[
             0.9060315184464693, 0.5729271685521393, 0.29311167174990027`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 413}], {
             RGBColor[
             0.8976403406773998, 0.5446217555948332, 0.26051353065802335`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 443}], {
             RGBColor[
             0.8779783180841267, 0.47195372718941886`, 0.21716686938390278`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 476}], {
             RGBColor[
             0.834968541704233, 0.26978911161722496`, 0.18111922106827977`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 188}], {
             RGBColor[
             0.32203573450029344`, 0.4531724542663287, 0.9417474171352478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 192}], {
             RGBColor[
             0.28070448165153206`, 0.4123685862808082, 0.9392970770137636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 249}], {
             RGBColor[
             0.29817109629594896`, 0.43072710571942197`, 0.9402917748782225]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 260}], {
             RGBColor[
             0.2961853765948359, 0.4286399884116514, 0.940178691078853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 280}], {
             RGBColor[
             0.2818433506476452, 0.4135656098041881, 0.9393619339182866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 310}], {
             RGBColor[
             0.3017756973424442, 0.43451576996419494`, 0.9404970515752908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 327}], {
             RGBColor[
             0.28193174194509296`, 0.41365851466213766`, 0.939366967671913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 424}], {
             RGBColor[
             0.31369437792555, 0.4459475904500576, 0.9412159132702771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 483}], {
             RGBColor[
             0.3017217477257488, 0.43445906549644486`, 0.9404939792244313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 191}], {
             RGBColor[
             0.21120215837255008`, 0.3393172378127832, 0.9353390225224988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 212}], {
             RGBColor[
             0.21125959360220817`, 0.3393776058807578, 0.93534229337386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 287}], {
             RGBColor[
             0.20690732578417442`, 0.33480309645428663`, 0.9350944381602262]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 299}], {
             RGBColor[
             0.20658465608391344`, 0.3344639501408717, 0.9350760625981434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 301}], {
             RGBColor[
             0.2063778078751808, 0.33424653955855976`, 0.9350642828986606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 389}], {
             RGBColor[
             0.21125135912011495`, 0.33936895091798147`, 0.9353418244322866]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 451}], {
             RGBColor[
             0.20772437674817806`, 0.3356618688214776, 0.9351409680039076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 190}], {
             RGBColor[
             0.24652129125596123`, 0.3764398858356126, 0.9373503948902342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 195}], {
             RGBColor[
             0.2575424446398453, 0.3880238168235591, 0.9379780332711112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 263}], {
             RGBColor[
             0.25916680795964386`, 0.3897311256632503, 0.9380705383591434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 323}], {
             RGBColor[
             0.24213881509518778`, 0.3718336255256024, 0.9371008193561707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 342}], {
             RGBColor[
             0.25246005368067864`, 0.38268190168327626`, 0.9376885986247103]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 351}], {
             RGBColor[
             0.267489207183899, 0.39847849491853005`, 0.9385444866830785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[
             0.2571354474729763, 0.3875960369960689, 0.9379548553845563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 395}], {
             RGBColor[
             0.2549602684410159, 0.3853097859191623, 0.9378309821565751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 447}], {
             RGBColor[
             0.24571645560416666`, 0.3755939525360489, 0.9373045606905122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 452}], {
             RGBColor[
             0.2344431943228335, 0.36374504016331954`, 0.9366625651378359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 463}], {
             RGBColor[
             0.25601516257071727`, 0.38641854653362934`, 0.9378910568166856]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 174}], {
             RGBColor[
             0.2880991557381853, 0.4200673355937856, 0.9397208847641902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 229}], {
             RGBColor[
             0.3002585012900294, 0.4328475787158096, 0.940413341505228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 255}], {
             RGBColor[
             0.3535633647009796, 0.4806605487177418, 0.9437497228483069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 313}], {
             RGBColor[
             0.2882495492104231, 0.42022540866860447`, 0.9397294494499471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 338}], {
             RGBColor[
             0.314823265682197, 0.4471058220816644, 0.9412812379953546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 369}], {
             RGBColor[
             0.36474431369771637`, 0.4903449247678786, 0.944462163031454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 379}], {
             RGBColor[
             0.3094202014132221, 0.4424259593777846, 0.9409369595178776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 380}], {
             RGBColor[
             0.2911961325222311, 0.423322454553487, 0.9398972530104752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 390}], {
             RGBColor[
             0.30514733542854805`, 0.43798605336538, 0.9406917533770347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 425}], {
             RGBColor[
             0.3424420265478999, 0.47102780458425264`, 0.9430410810154058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 478}], {
             RGBColor[
             0.28779157321631055`, 0.419744046861437, 0.9397033683945971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 181}], {
             RGBColor[
             0.49329315877378277`, 0.5986309034651389, 0.9534977211263604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 235}], {
             RGBColor[
             0.4614654223098702, 0.5710633178486462, 0.9514696859030422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 262}], {
             RGBColor[
             0.520987467347936, 0.6220001220678183, 0.9554331883510561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 332}], {
             RGBColor[
             0.4840405870433834, 0.5906167908800439, 0.9529081554374272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 344}], {
             RGBColor[
             0.5148160505883743, 0.6169898879232494, 0.9549473518170989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 387}], {
             RGBColor[
             0.6705014636086952, 0.7413486854414358, 0.9685938847155504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 393}], {
             RGBColor[
             0.5135503027141461, 0.615962296777659, 0.9548477075078524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 403}], {
             RGBColor[
             0.7474005481861847, 0.8023032590432388, 0.9760248292713649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 232}], {
             RGBColor[
             0.4117533959329014, 0.5306819361106889, 0.9475625057353367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 307}], {
             RGBColor[
             0.4685593666518582, 0.5794366280637215, 0.9513058562137999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 350}], {
             RGBColor[
             0.41473957912155346`, 0.5332684178987681, 0.9477527826875395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 354}], {
             RGBColor[
             0.4145365045344412, 0.533092524898237, 0.9477398429544205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 372}], {
             RGBColor[
             0.46888111877498084`, 0.5796978409320405, 0.951331185719549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 479}], {
             RGBColor[
             0.4393999195807523, 0.5546279653397757, 0.9493241177753168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 180}], {
             RGBColor[
             0.2863372761085622, 0.4182890103949429, 0.9396178563251187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 216}], {
             RGBColor[
             0.28421479544229167`, 0.41605814864164575`, 0.9394969841911034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 238}], {
             RGBColor[
             0.31134876495031627`, 0.4435229307952213, 0.9410808428186908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 246}], {
             RGBColor[
             0.2983825090164457, 0.4309493138930047, 0.9403038145198976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 281}], {
             RGBColor[
             0.2737261355645935, 0.4050339020907391, 0.9388996705276503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 288}], {
             RGBColor[
             0.2793047597177943, 0.4108973897809534, 0.9392173649203402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 343}], {
             RGBColor[
             0.2977155588527831, 0.4302483069839126, 0.9402658326947413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 392}], {
             RGBColor[
             0.3042725009406671, 0.4371400688524187, 0.9406392408465198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 459}], {
             RGBColor[
             0.3465448636437761, 0.4740080224761397, 0.94332350710475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 465}], {
             RGBColor[
             0.2925845958094424, 0.42485533950351484`, 0.9399736319400027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 182}], {
             RGBColor[
             0.36805399542884243`, 0.4932116047339394, 0.9446730530247247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 206}], {
             RGBColor[
             0.3501277440364893, 0.4776847867774757, 0.9435308081375656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 282}], {
             RGBColor[
             0.4825898599888707, 0.5882261104425313, 0.9531290808792493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 324}], {
             RGBColor[
             0.3635993901479788, 0.48935324953462667`, 0.9443892095152808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 410}], {
             RGBColor[
             0.3605931713874897, 0.48674941394123933`, 0.9441976559141574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 441}], {
             RGBColor[
             0.4038268661048062, 0.5241962673166999, 0.9469524687114896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 164}], {
             RGBColor[
             0.819137437150352, 0.14810430478184575`, 0.1659593374688081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 396}], {
             RGBColor[
             0.9071481131704897, 0.5745522202562454, 0.3532052383412315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 443}], {
             RGBColor[
             0.877631072588452, 0.4692846461457165, 0.21683434670508697`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 165}], {
             RGBColor[
             0.4232575021072018, 0.5410261076098133, 0.9481905716557255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 268}], {
             RGBColor[
             0.41606826400089775`, 0.5347991509037464, 0.9477324797607855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 275}], {
             RGBColor[
             0.4180928553323577, 0.5365527501561378, 0.9478614849301503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 285}], {
             RGBColor[
             0.3684500451199806, 0.49355464307036695`, 0.9446982889608311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 324}], {
             RGBColor[
             0.3960795993510239, 0.5174859742435227, 0.9464588197245776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 353}], {
             RGBColor[
             0.531072144514868, 0.6293500407838779, 0.9564584330755022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 441}], {
             RGBColor[
             0.4363070753078513, 0.5523289920255958, 0.9490220789207864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 480}], {
             RGBColor[
             0.3880144919727734, 0.5105003835965654, 0.94594491821413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 481}], {
             RGBColor[
             0.3703492229848604, 0.49519961548147085`, 0.9448193028950042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 259}], {
             RGBColor[
             0.9260863286561598, 0.722291136783578, 0.31168537193130974`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 326}], {
             RGBColor[
             0.9327537347132191, 0.7525662704764362, 0.31724881897839763`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 341}], {
             RGBColor[
             0.9919526646253864, 0.9838559907810486, 0.4794106025405692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 387}], {
             RGBColor[
             0.8827228822801044, 0.901646814849579, 0.6975808353380122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 403}], {
             RGBColor[
             0.9596219668575938, 0.962601388451382, 0.7050117798938269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 405}], {
             RGBColor[
             0.9921723207517021, 0.9843258130245969, 0.5033188163295588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 450}], {
             RGBColor[
             0.9040202207813182, 0.5580851531997648, 0.2907664410126593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 469}], {
             RGBColor[
             0.9253813180460291, 0.7190898482623855, 0.3110970937968252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 491}], {
             RGBColor[
             0.992246695040947, 0.9844848921088973, 0.5114139987289448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 203}], {
             RGBColor[
             0.4982990262412239, 0.6035806234747654, 0.9536470711566374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 221}], {
             RGBColor[
             0.4993207487803075, 0.6044101038600693, 0.953727504897607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 223}], {
             RGBColor[
             0.4259476007932227, 0.5431195461878823, 0.9484273528030159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 258}], {
             RGBColor[
             0.4177269296537439, 0.5359992140298111, 0.9479035389072623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 289}], {
             RGBColor[
             0.45070123455015054`, 0.5645598995943251, 0.9500046324572284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 297}], {
             RGBColor[
             0.4906978130641887, 0.5974096161868968, 0.9530486758111798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 381}], {
             RGBColor[
             0.515668109442376, 0.6176816276857418, 0.9550144290112803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 439}], {
             RGBColor[
             0.6614719504889517, 0.7330346033014116, 0.9686938737233264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 187}], {
             RGBColor[
             0.2658102034815037, 0.3967137555723293, 0.9384488699060904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.2633838374698597, 0.39416349105360093`, 0.9383106919512142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 322}], {
             RGBColor[
             0.26310542995763675`, 0.3938708671061988, 0.9382948370552601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 364}], {
             RGBColor[
             0.2627794929075267, 0.39352828660093053`, 0.938276275422437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 437}], {
             RGBColor[
             0.26141138655191587`, 0.3920903200782306, 0.9381983637894169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 494}], {
             RGBColor[
             0.262747921993954, 0.39349510356905415`, 0.938274477505614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 166}], {
             RGBColor[
             0.8278225605966679, 0.21486196943559147`, 0.17427622148944416`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 227}], {
             RGBColor[
             0.8315779382096691, 0.24372744738608088`, 0.17787237533274636`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 309}], {
             RGBColor[
             0.9052777371288019, 0.5616050038337315, 0.3236174733815438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 348}], {
             RGBColor[
             0.8887181595032059, 0.5060713797566354, 0.23158979527643736`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 396}], {
             RGBColor[
             0.9055353853140414, 0.5621560872497313, 0.3516608883245811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 428}], {
             RGBColor[
             0.8239291026561835, 0.1849351455808791, 0.17054784176860438`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 443}], {
             RGBColor[
             0.8760183447320038, 0.45688851313920237`, 0.21528999668843654`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 182}], {
             RGBColor[
             0.4013099579800705, 0.5220162480025345, 0.9467920935513959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 268}], {
             RGBColor[
             0.4168440173490807, 0.5354710694634455, 0.9477819100781599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 275}], {
             RGBColor[
             0.41886860868054065`, 0.537224668715837, 0.9479109152475247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 282}], {
             RGBColor[
             0.5158458225400988, 0.6170307537111264, 0.9552481214059205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 285}], {
             RGBColor[
             0.3692257984681636, 0.49422656163006606`, 0.9447477192782054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 324}], {
             RGBColor[
             0.3968553526992069, 0.5181578928032218, 0.9465082500419522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 353}], {
             RGBColor[
             0.531847897863051, 0.630021959343577, 0.9565078633928767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 441}], {
             RGBColor[
             0.4370828286560343, 0.553000910585295, 0.9490715092381609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 481}], {
             RGBColor[
             0.3711249763330434, 0.49587153404117, 0.9448687332123786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 210}], {
             RGBColor[
             0.8370920629652436, 0.28611142656230293`, 0.18315270742599782`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 227}], {
             RGBColor[
             0.8418757895124331, 0.32288124504634075`, 0.18773360937003286`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 243}], {
             RGBColor[
             0.838713260625803, 0.29857266219470613`, 0.18470516813663024`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 309}], {
             RGBColor[
             0.9155755884315661, 0.6407588014939913, 0.33347870741883034`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 320}], {
             RGBColor[
             0.9133614547699682, 0.6417853106074096, 0.5113435478107814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 348}], {
             RGBColor[
             0.8990160108059699, 0.5852251774168952, 0.24145102931372386`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 428}], {
             RGBColor[
             0.8342269539589475, 0.26408894324113896`, 0.18040907580589088`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 495}], {
             RGBColor[
             0.8401614416386582, 0.3097040160564781, 0.18609194791002698`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 210}], {
             RGBColor[
             0.9113669843928855, 0.6334814540290358, 0.5263699322609554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 326}], {
             RGBColor[
             0.9309228830343801, 0.7574193985269815, 0.5440638154599668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 434}], {
             RGBColor[
             0.988936416573675, 0.989692938179159, 0.8330157392176978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 474}], {
             RGBColor[
             0.9898837045140847, 0.9900846660867081, 0.8173167265425048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 495}], {
             RGBColor[
             0.9144363630663, 0.657074043523211, 0.5293091727449846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 200}], {
             RGBColor[
             0.9058101136750496, 0.6632964389017137, 0.24302016366679569`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 213}], {
             RGBColor[
             0.9074990588325569, 0.6709655443987909, 0.2444294609060539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 254}], {
             RGBColor[
             0.5736452347236608, 0.5249664714796068, 0.591929563801219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 261}], {
             RGBColor[
             0.8953895182633258, 0.6159789489289689, 0.23432496342308617`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 315}], {
             RGBColor[
             0.5481459181329882, 0.49816507299275914`, 0.5904774154442385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 368}], {
             RGBColor[
             0.6594469349895435, 0.6059633899066202, 0.5971521921376893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 401}], {
             RGBColor[
             0.842122298838193, 0.7534870262743261, 0.6125668464325392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 500}], {
             RGBColor[
             0.8651424411448785, 0.41743131522220955`, 0.2066895157907081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 204}], {
             RGBColor[
             0.4973176178268257, 0.6027838719120118, 0.9535698110912385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 219}], {
             RGBColor[
             0.5095055418565787, 0.6126785776990856, 0.9545292891166974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 244}], {
             RGBColor[
             0.4175916065853016, 0.5350481346501237, 0.9481253168239769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 274}], {
             RGBColor[
             0.4777382226320348, 0.5868884368511786, 0.9520284493798168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 334}], {
             RGBColor[
             0.44777313143376407`, 0.5611898545063152, 0.9500484568988465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 337}], {
             RGBColor[
             0.6764764422213522, 0.7452210038115648, 0.9698692373870139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 340}], {
             RGBColor[
             0.41508837309382146`, 0.5328799596159772, 0.9479658129994224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 361}], {
             RGBColor[
             0.5684718159304661, 0.6605218314458838, 0.9591906270789168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 363}], {
             RGBColor[
             0.44877677089386697`, 0.5620591565622703, 0.9501124079177607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 370}], {
             RGBColor[
             0.5420927609464797, 0.6391343501937576, 0.9570946743743712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 498}], {
             RGBColor[
             0.4773158479045384, 0.5865455340196324, 0.9519951984940587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 171}], {
             RGBColor[
             0.2792113970027737, 0.4107992596479288, 0.9392120480518376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 238}], {
             RGBColor[
             0.3084172446419511, 0.44044171708200675`, 0.940913897073925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 265}], {
             RGBColor[
             0.3088475371272851, 0.4408144148056739, 0.9409413149305978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 266}], {
             RGBColor[
             0.29310065604108804`, 0.425397751527083, 0.9400030208067522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 328}], {
             RGBColor[
             0.3409967871765409, 0.4686604793300483, 0.9429898367152708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 374}], {
             RGBColor[
             0.2742054454433818, 0.40553768716334715`, 0.9389269665161719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 433}], {
             RGBColor[
             0.31109341012253816`, 0.4427596771133032, 0.9410844199719078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 216}], {
             RGBColor[
             0.26381410331866717`, 0.39461572774112796`, 0.9383351949547825]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 238}], {
             RGBColor[
             0.2909480728266918, 0.4220805098947036, 0.9399190535823698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 265}], {
             RGBColor[
             0.29137836531202577`, 0.42245320761837074`, 0.9399464714390425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 343}], {
             RGBColor[
             0.2773148667291586, 0.40880588608339485`, 0.9391040434584204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 385}], {
             RGBColor[
             0.24760690614002792`, 0.37758093591072595`, 0.9374122190518586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 391}], {
             RGBColor[
             0.25143472628896596`, 0.3816042175850748, 0.9376302077465881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 433}], {
             RGBColor[
             0.2936242383072788, 0.42439846992600005`, 0.9400895764803525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 465}], {
             RGBColor[
             0.27218390368581785`, 0.4034129186029971, 0.9388118427036817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 303}], {
             RGBColor[
             0.32845548787730483`, 0.4585909264869045, 0.9421616772940785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 366}], {
             RGBColor[
             0.3083293758751098, 0.43743710670339436`, 0.941015524989468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 448}], {
             RGBColor[
             0.45979588464643895`, 0.5695615806771241, 0.9513786855523698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 473}], {
             RGBColor[
             0.3392418574009336, 0.4682559789143286, 0.9428371690671595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 241}], {
             RGBColor[
             0.8450225482014433, 0.8788658384170731, 0.9383874109586698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 417}], {
             RGBColor[
             0.8427978094114925, 0.8771278555657226, 0.9381656697874536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 461}], {
             RGBColor[
             0.9645092309315171, 0.9729899937684735, 0.9422009085196323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 493}], {
             RGBColor[
             0.9890701085039466, 0.9882775676582451, 0.7238989830539463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 215}], {
             RGBColor[
             0.2753901052316153, 0.40678283971254936`, 0.9389944311385647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 229}], {
             RGBColor[
             0.2788164534778155, 0.4103841489623319, 0.9391895566023578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 294}], {
             RGBColor[
             0.2524849252558091, 0.3827080432856873, 0.9376900150241196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 338}], {
             RGBColor[
             0.29338121786998295`, 0.4246423923281867, 0.9400574530924843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 356}], {
             RGBColor[
             0.2679975194043914, 0.3990127632911238, 0.938573434312055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 390}], {
             RGBColor[
             0.28370528761633407`, 0.41552262361190234`, 0.9394679684741645]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 430}], {
             RGBColor[
             0.2531980668507343, 0.38345760031774234`, 0.9377306273829522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 309}], {
             RGBColor[
             0.9743805147039586, 0.9770030600582216, 0.7213206267986814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 320}], {
             RGBColor[
             0.9721663810423609, 0.9780295691716399, 0.8991854671906325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 337}], {
             RGBColor[
             0.9079704822927377, 0.9289384814961321, 0.9731750764283525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 348}], {
             RGBColor[
             0.9578209370783626, 0.9214694359811255, 0.6292929486935749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 361}], {
             RGBColor[
             0.7999658560018515, 0.8442393091304512, 0.9624964661202554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 370}], {
             RGBColor[
             0.7735868010178651, 0.822851827878325, 0.9604005134157099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 375}], {
             RGBColor[
             0.9569658514087618, 0.9674257829593813, 0.9577297678481509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 197}], {
             RGBColor[
             0.6522851143834272, 0.7277468526483104, 0.9663482548197164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 237}], {
             RGBColor[
             0.7565184993634433, 0.8098707472801487, 0.9765525722729846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 345}], {
             RGBColor[
             0.6333349002315553, 0.7129428013259062, 0.9644594745728776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 426}], {
             RGBColor[
             0.7385594994235554, 0.7955507282121491, 0.9748396268265297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 448}], {
             RGBColor[
             0.587441960125221, 0.6759508730452015, 0.9606647294533119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 245}], {
             RGBColor[
             0.21512971428686242`, 0.34344534810015337`, 0.9355626910215206]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 438}], {
             RGBColor[
             0.21508055771107348`, 0.3433936814222922, 0.9355598916272501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 455}], {
             RGBColor[
             0.2063185988388122, 0.33418430710726665`, 0.9350609110316312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 357}], {
             RGBColor[
             0.9494134599221778, 0.8301932628763469, 0.5158066666080678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 420}], {
             RGBColor[
             0.9801637329335828, 0.9834819259202605, 0.8627171585529716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 439}], {
             RGBColor[
             0.9262985601874452, 0.9413808299607197, 0.8870332114673454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 236}], {
             RGBColor[
             0.23312614698427564`, 0.36236073990487094`, 0.9365875612403018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 254}], {
             RGBColor[
             0.20771369325605188`, 0.33565063979388043`, 0.9351403595948358]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 276}], {
             RGBColor[
             0.39923464670294595`, 0.5037029404652202, 0.9483463693708659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 283}], {
             RGBColor[
             0.18007164814629245`, 0.3065970977766376, 0.9335661860185762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 292}], {
             RGBColor[
             0.17894988462017136`, 0.30541805318676885`, 0.9335023032452641]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 315}], {
             RGBColor[
             0.18221437666537932`, 0.3088492413070327, 0.9336882112378554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 325}], {
             RGBColor[
             0.1789730287155782, 0.30544237909846184`, 0.9335036212672588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 347}], {
             RGBColor[
             0.17892806853100302`, 0.30539512309383293`, 0.93350106085126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 368}], {
             RGBColor[
             0.2935153935219346, 0.41664755822089383`, 0.9403629879313062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 386}], {
             RGBColor[
             0.17892806853100302`, 0.30539512309383293`, 0.93350106085126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 401}], {
             RGBColor[
             0.47619075737058414`, 0.5641711945885997, 0.9557776422261561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 216}], {
             RGBColor[
             0.2680084621160904, 0.3990242647749275, 0.9385740574832979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 281}], {
             RGBColor[
             0.2575198022383923, 0.3880000182240208, 0.9379767438198447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 288}], {
             RGBColor[
             0.2630984263915931, 0.39386350591423513`, 0.9382944382125347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 343}], {
             RGBColor[
             0.28150922552658186`, 0.4132144231171943, 0.9393429059869358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 392}], {
             RGBColor[
             0.2880661676144659, 0.4201061849857004, 0.9397163141387143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 465}], {
             RGBColor[
             0.27637826248324115`, 0.40782145563679656`, 0.9390507052321971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 235}], {
             RGBColor[
             0.38886946031407776`, 0.511240914201845, 0.9459993960408191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 239}], {
             RGBColor[
             0.38581385669695734`, 0.5085943039277986, 0.9458046956803003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 262}], {
             RGBColor[
             0.4483915053521436, 0.5621777184210172, 0.9499628984888329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 296}], {
             RGBColor[
             0.3670585086059648, 0.49234936408258523`, 0.9446096214846453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 332}], {
             RGBColor[
             0.41144462504759094`, 0.5307943872332428, 0.947437865575204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 344}], {
             RGBColor[
             0.4422200885925819, 0.5571674842764482, 0.9494770619548758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 387}], {
             RGBColor[
             0.5979055016129029, 0.6815262817946347, 0.9631235948533272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 393}], {
             RGBColor[
             0.4409543407183537, 0.5561398931308579, 0.9493774176456293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 424}], {
             RGBColor[
             0.3706458143967508, 0.4954565080553325, 0.9448382014375043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 275}], {
             RGBColor[
             0.39614531120522645`, 0.517542890548859, 0.9464630068258206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 282}], {
             RGBColor[
             0.4931225250647846, 0.5973489755441486, 0.9538002129842165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 324}], {
             RGBColor[
             0.37413205522389265`, 0.49847611463624397`, 0.9450603416202481]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 441}], {
             RGBColor[
             0.41435953118072005`, 0.5333191324183171, 0.9476236008164568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 346}], {
             RGBColor[
             0.21142499907593382`, 0.3395514575209563, 0.9353517129708931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 404}], {
             RGBColor[
             0.20920782453695042`, 0.33722106650349953`, 0.9352254481609139]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 407}], {
             RGBColor[
             0.2096628417623121, 0.3376993184571131, 0.9352513607187605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 408}], {
             RGBColor[
             0.21373593745192992`, 0.3419804002760839, 0.9354833174926791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 192}], {
             RGBColor[
             0.25582325613433854`, 0.3862168407014245, 0.9378801280290341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 225}], {
             RGBColor[
             0.2656405828545585, 0.396535473538841, 0.9384392102623171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 249}], {
             RGBColor[
             0.2732898707787555, 0.40457536014003825`, 0.9388748258934928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 260}], {
             RGBColor[
             0.2713041510776424, 0.40248824283226764`, 0.9387617420941234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 280}], {
             RGBColor[
             0.2569621251304517, 0.38741386422480434`, 0.9379449849335569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 424}], {
             RGBColor[
             0.28881315240835653`, 0.41979584487067384`, 0.9397989642855475]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 440}], {
             RGBColor[
             0.26935285588816305`, 0.4004373078688641, 0.9386506187197652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 453}], {
             RGBColor[
             0.2706693526642461, 0.401821029451244, 0.9387255912635806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 470}], {
             RGBColor[
             0.2562569900664413, 0.3866727225643841, 0.9379048285348154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 193}], {
             RGBColor[
             0.28587823371129695`, 0.41780652773044813`, 0.9395917145396869]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 196}], {
             RGBColor[
             0.2898220421197416, 0.4219517204196188, 0.9398163085942062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 318}], {
             RGBColor[
             0.3129435362062064, 0.4431846498190406, 0.9412454229080396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 321}], {
             RGBColor[
             0.30856010126890854`, 0.43938793879419913`, 0.9409661143099544]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 330}], {
             RGBColor[
             0.29519715135054264`, 0.42760130102279975`, 0.9401224131131387]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 335}], {
             RGBColor[
             0.28035846079175497`, 0.4120048964181928, 0.9392773716376912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 350}], {
             RGBColor[
             0.3230573711356193, 0.45194474529877393`, 0.9418898675264287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 383}], {
             RGBColor[
             0.3064436349421723, 0.43755476203867083`, 0.9408312549471323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 409}], {
             RGBColor[
             0.262750205623448, 0.39349750380844273`, 0.9382746075549353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 482}], {
             RGBColor[
             0.32121309396000997`, 0.4503473251053272, 0.9417723518156291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 496}], {
             RGBColor[
             0.2804171463023576, 0.4120665786107125, 0.9392807136907027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 191}], {
             RGBColor[
             0.22705589567091367`, 0.35598052089836485`, 0.936241869408138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 202}], {
             RGBColor[
             0.2373837352876954, 0.3668357351584549, 0.9368300245956442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 212}], {
             RGBColor[
             0.22711333090057176`, 0.3560408889663394, 0.9362451402594992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 295}], {
             RGBColor[
             0.23264914651192115`, 0.36185938216484964`, 0.9365603967690603]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 300}], {
             RGBColor[
             0.23083402862066274`, 0.35995157817601575`, 0.9364570284903794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 389}], {
             RGBColor[
             0.22710509641847854`, 0.3560322340035631, 0.9362446713179258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 414}], {
             RGBColor[
             0.255184189019674, 0.3855451406447167, 0.937843734102269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 456}], {
             RGBColor[
             0.22968446940414386`, 0.35874331855319036`, 0.9363915627936191]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 485}], {
             RGBColor[
             0.24185580045044375`, 0.3715361591898116, 0.9370847020908353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 322}], {
             RGBColor[
             0.2619233226556958, 0.392628397381927, 0.9382275177931856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 494}], {
             RGBColor[
             0.26156581469201307`, 0.3922526338447824, 0.9382071582435395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 304}], {
             RGBColor[
             0.33792059600024626`, 0.4671115686975821, 0.9427529794590535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 310}], {
             RGBColor[
             0.3170171080071488, 0.4478975596227356, 0.9414616137808558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 483}], {
             RGBColor[
             0.31696315839045336`, 0.4478408551549855, 0.9414585414299963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 266}], {
             RGBColor[
             0.2746480537102089, 0.4060028965147674, 0.9389521724021874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 364}], {
             RGBColor[
             0.25917101959394173`, 0.3897355523579304, 0.9380707782054862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 374}], {
             RGBColor[
             0.2557528431125027, 0.3861428321510315, 0.9378761181116072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 437}], {
             RGBColor[
             0.25780291323833093`, 0.38829758583523044`, 0.9379928665724662]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 195}], {
             RGBColor[
             0.25913077183266553`, 0.38969324940897365`, 0.9380684861550228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 224}], {
             RGBColor[
             0.2735379552710175, 0.40483611267087094`, 0.938888953938319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 263}], {
             RGBColor[
             0.26075513515246407`, 0.3914005582486648, 0.9381609912430551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 323}], {
             RGBColor[
             0.243727142288008, 0.373503058111017, 0.9371912722400824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 342}], {
             RGBColor[
             0.25404838087349885`, 0.38435133426869084`, 0.9377790515086218]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 351}], {
             RGBColor[
             0.2690775343767192, 0.40014792750394457`, 0.9386349395669901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 356}], {
             RGBColor[
             0.2587237746657965, 0.38926546958148345`, 0.9380453082684679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 395}], {
             RGBColor[
             0.2565485956338361, 0.38697921850457684`, 0.9379214350404868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 452}], {
             RGBColor[
             0.2360315215156537, 0.3654144727487341, 0.9367530180217474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 463}], {
             RGBColor[
             0.2576034897635375, 0.3880879791190439, 0.9379815097005972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 212}], {
             RGBColor[
             0.21845881642544385`, 0.3469444455250692, 0.9357522784633475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 218}], {
             RGBColor[
             0.2251871593264507, 0.3540163605156067, 0.9361354476378685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 287}], {
             RGBColor[
             0.21410654860741013`, 0.342369936098598, 0.9355044232497137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 295}], {
             RGBColor[
             0.22399463203679326`, 0.35276293872357944`, 0.9360675349729086]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 299}], {
             RGBColor[
             0.21378387890714912`, 0.3420307897851831, 0.935486047687631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 300}], {
             RGBColor[
             0.22217951414553483`, 0.3508551347347456, 0.9359641666942277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 301}], {
             RGBColor[
             0.2135770306984165, 0.34181337920287114`, 0.935474267988148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 389}], {
             RGBColor[
             0.21845058194335062`, 0.3469357905622929, 0.9357518095217741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 451}], {
             RGBColor[
             0.21492359957141377`, 0.343228708465789, 0.9355509530933952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 456}], {
             RGBColor[
             0.22102995492901595`, 0.34964687511192016`, 0.9358987009974674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[
             0.26443196618769516`, 0.395265140791245, 0.9383703813311275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 249}], {
             RGBColor[
             0.27208125411189216`, 0.40330502739244223`, 0.938805996962303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 260}], {
             RGBColor[
             0.27009553441077905`, 0.4012179100846716, 0.9386929131629338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 280}], {
             RGBColor[
             0.25575350846358835`, 0.3861435314772083, 0.9378761560023672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 327}], {
             RGBColor[
             0.25584189976103616`, 0.38623643633515786`, 0.9378811897559938]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 470}], {
             RGBColor[
             0.255048373399578, 0.3854023898167881, 0.9378359996036256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 483}], {
             RGBColor[
             0.275631905541692, 0.4070369871694651, 0.9390082013085121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 196}], {
             RGBColor[
             0.29175552637074975`, 0.4239839349574104, 0.9399264176619675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 202}], {
             RGBColor[
             0.2634343891958272, 0.39421662412275726`, 0.9383135707972234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 232}], {
             RGBColor[
             0.32200467219797546`, 0.4513904780484862, 0.9418096996419872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 330}], {
             RGBColor[
             0.2971306356015508, 0.42963351556059126`, 0.9402325221809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 350}], {
             RGBColor[
             0.3249908553866274, 0.4539769598365655, 0.94199997659419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 354}], {
             RGBColor[
             0.3247877807995152, 0.4538010668360344, 0.941987036861071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 376}], {
             RGBColor[
             0.2836334092052663, 0.4154470748445156, 0.9394638751049887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 414}], {
             RGBColor[
             0.28123484292780576`, 0.41292602960901903`, 0.9393272803038482]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 415}], {
             RGBColor[
             0.28741220208324925`, 0.41941882574858214`, 0.9396790717691668]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 485}], {
             RGBColor[
             0.2679064543585755, 0.3989170481541139, 0.9385682482924145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 496}], {
             RGBColor[
             0.28235063055336573`, 0.41409879314850406`, 0.939390822758464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 228}], {
             RGBColor[
             0.9897986964683487, 0.9881510016226367, 0.6807237889593197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 388}], {
             RGBColor[
             0.9663440953419832, 0.9740339462184904, 0.9245637966956991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 490}], {
             RGBColor[
             0.9885348242076832, 0.9895268694153684, 0.8396711640099095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 224}], {
             RGBColor[
             0.28455910865490164`, 0.41642004365881735`, 0.9395165923191959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 263}], {
             RGBColor[
             0.27177628853634817`, 0.40298448923661123`, 0.9387886296239321]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 296}], {
             RGBColor[
             0.29178587282524443`, 0.4235837043718764, 0.9399439681205266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 323}], {
             RGBColor[
             0.2547482956718921, 0.38508698909896344`, 0.9378189106209592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 342}], {
             RGBColor[
             0.265069534257383, 0.39593526525663725`, 0.9384066898894987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 351}], {
             RGBColor[
             0.2800986877606033, 0.41173185849189103`, 0.9392625779478669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 395}], {
             RGBColor[
             0.26756974901772024`, 0.3985631494925233, 0.9385490734213637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 447}], {
             RGBColor[
             0.25832593618087096`, 0.38884731610940987`, 0.9380226519553008]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 453}], {
             RGBColor[
             0.27722937887191995`, 0.40871603292519376`, 0.9390991750514186]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 463}], {
             RGBColor[
             0.2686246431474216, 0.3996719101069903, 0.9386091480814742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 318}], {
             RGBColor[
             0.3188208288656592, 0.44936205704600285`, 0.9415801260303202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 321}], {
             RGBColor[
             0.31443739392836134`, 0.4455653460211614, 0.9413008174322348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 330}], {
             RGBColor[
             0.3010744440099954, 0.433778708249762, 0.9404571162354194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 335}], {
             RGBColor[
             0.2862357534512077, 0.4181823036451551, 0.9396120747599719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 350}], {
             RGBColor[
             0.3289346637950721, 0.4581221525257362, 0.9422245706487093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 354}], {
             RGBColor[
             0.32873158920795986`, 0.45794625952520507`, 0.9422116309155903]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 383}], {
             RGBColor[
             0.3123209276016251, 0.4437321692656331, 0.941165958069413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 414}], {
             RGBColor[
             0.2851786513362504, 0.4170712222981897, 0.9395518743583675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 479}], {
             RGBColor[
             0.35359500425427093`, 0.4794816999667437, 0.9437959057364866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 482}], {
             RGBColor[
             0.3270903866194627, 0.45652473233228946`, 0.9421070549379097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 496}], {
             RGBColor[
             0.2862944389618104, 0.41824398583767475`, 0.9396154168129832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 237}], {
             RGBColor[
             0.8018590077882369, 0.845833600411511, 0.9807007779188375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 270}], {
             RGBColor[
             0.843824355466433, 0.8769260052856713, 0.8927516199339326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 345}], {
             RGBColor[
             0.6786754086563489, 0.7489056544572683, 0.9686076802187304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 375}], {
             RGBColor[
             0.8279135305907634, 0.8660284937370616, 0.9630673509377192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 426}], {
             RGBColor[
             0.7839000078483491, 0.8315135813435113, 0.9789878324723824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 448}], {
             RGBColor[
             0.6327824685500147, 0.7119137261765637, 0.9648129350991647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 489}], {
             RGBColor[
             0.843861608566709, 0.8769414103999965, 0.8921342396544271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 223}], {
             RGBColor[
             0.335871613441881, 0.4628528461466326, 0.9427133713948876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 373}], {
             RGBColor[
             0.28774746699468884`, 0.4197712104275283, 0.9396981646098933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 480}], {
             RGBColor[
             0.3177133386514768, 0.44712506118461215`, 0.9415563421819749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 208}], {
             RGBColor[
             0.33248120157791744`, 0.46240023864087376`, 0.9424063860563303]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 220}], {
             RGBColor[
             0.3408785418830542, 0.4696735927505875, 0.9429414571550971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 349}], {
             RGBColor[
             0.3782226741008029, 0.5020192031069408, 0.9453209922378925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 359}], {
             RGBColor[
             0.364147570424561, 0.48982805573786037`, 0.9444241390777679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 371}], {
             RGBColor[
             0.3528938984406201, 0.480080690691371, 0.9437070650501826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 382}], {
             RGBColor[
             0.31253428709090747`, 0.4426711481132517, 0.9412251688089472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 397}], {
             RGBColor[
             0.3506959657134314, 0.47817695183439113`, 0.9435670147203616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 419}], {
             RGBColor[
             0.4277672068152066, 0.5433200836247167, 0.948923355062986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 427}], {
             RGBColor[
             0.31117200287913815`, 0.44123930103287445`, 0.9411475887384059]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 429}], {
             RGBColor[
             0.318220922727511, 0.44864816272084596`, 0.9415490142958283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 213}], {
             RGBColor[
             0.9025169525103827, 0.6502340737413859, 0.24037009445756363`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 243}], {
             RGBColor[
             0.8700670583525245, 0.4728472627689348, 0.21211683898241762`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 254}], {
             RGBColor[
             0.5686631284014866, 0.5042350008222019, 0.5878701973527287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 259}], {
             RGBColor[
             0.8813343532764009, 0.5540488379416193, 0.22269481442370878`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 401}], {
             RGBColor[
             0.8371401925160188, 0.7327555556169211, 0.6085074799840489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 450}], {
             RGBColor[
             0.8592682454015592, 0.38984285435780597`, 0.20177588350505832`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 454}], {
             RGBColor[
             0.9003552167733437, 0.640418136645701, 0.2385662891695866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 469}], {
             RGBColor[
             0.8806293426662699, 0.5508475494204266, 0.22210653628922422`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 471}], {
             RGBColor[
             0.8788202951923778, 0.5401284768128874, 0.22049894846562806`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 475}], {
             RGBColor[
             0.8699156991968737, 0.47168384997259694`, 0.2119718972840306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 500}], {
             RGBColor[
             0.8601603348227043, 0.3966998445648045, 0.2026301493422178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 222}], {
             RGBColor[
             0.3735862388275236, 0.49760697262793063`, 0.9450400762157048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 246}], {
             RGBColor[
             0.2993400916080083, 0.43195579391098005`, 0.9403583474318706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 256}], {
             RGBColor[
             0.2969224563599441, 0.4294147059783363, 0.9402206666810642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 271}], {
             RGBColor[
             0.2801320470703391, 0.4117669212415258, 0.9392644777112058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 312}], {
             RGBColor[
             0.30443515610797417`, 0.4373110297461917, 0.9406485038176712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 333}], {
             RGBColor[
             0.34155395478950024`, 0.4698622181836031, 0.9429990074018386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 400}], {
             RGBColor[
             0.30019030163233085`, 0.432849418552972, 0.9404067656349827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 442}], {
             RGBColor[
             0.2942020501296223, 0.426555386546551, 0.9400657435707277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 444}], {
             RGBColor[
             0.2878759109078417, 0.4199062131240665, 0.9397054793007316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 492}], {
             RGBColor[
             0.29053904388296076`, 0.4227053347332997, 0.9398571407839125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 211}], {
             RGBColor[
             0.2350487330765592, 0.3643814997868598, 0.9366970496740461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 414}], {
             RGBColor[
             0.25685751416132785`, 0.38730391146353665`, 0.9379390274936235]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 485}], {
             RGBColor[
             0.2435291255920976, 0.37329493000863156`, 0.9371799954821897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 497}], {
             RGBColor[
             0.23752535161991525`, 0.36698458290261204`, 0.9368380894362616]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 221}], {
             RGBColor[
             0.5355883582024223, 0.6338537830261275, 0.9565826239639467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 258}], {
             RGBColor[
             0.45399453907585874`, 0.5654428931958693, 0.950758657973602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 289}], {
             RGBColor[
             0.48696884397226536`, 0.5940035787603833, 0.9528597515235682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 291}], {
             RGBColor[
             0.5947468881404891, 0.681688814806365, 0.9613714325118958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 297}], {
             RGBColor[
             0.5269654224863035, 0.6268532953529551, 0.9559037948775195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 381}], {
             RGBColor[
             0.5519357188644908, 0.6471253068518, 0.9578695480776199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 397}], {
             RGBColor[
             0.44655734447149653`, 0.5590011690338403, 0.950284766509865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 419}], {
             RGBColor[
             0.5236285855732716, 0.6241443008241659, 0.9556411068524893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 439}], {
             RGBColor[
             0.6977395599110665, 0.7624782824674698, 0.971548992789666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 219}], {
             RGBColor[
             0.5140809753819581, 0.6163931207559199, 0.9548894840041806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 244}], {
             RGBColor[
             0.42216704011068096`, 0.5387626777069581, 0.9484855117114601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 274}], {
             RGBColor[
             0.4823136561574142, 0.5906029799080129, 0.9523886442672999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 334}], {
             RGBColor[
             0.4523485649591434, 0.5649043975631496, 0.9504086517863296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 337}], {
             RGBColor[
             0.6810518757467315, 0.7489355468683991, 0.970229432274497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 340}], {
             RGBColor[
             0.4196638066192008, 0.5365945026728116, 0.9483260078869054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 361}], {
             RGBColor[
             0.5730472494558454, 0.6642363745027182, 0.9595508219663998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 362}], {
             RGBColor[
             0.4451772959687064, 0.5586930048020928, 0.9499517048675632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 363}], {
             RGBColor[
             0.4533522044192463, 0.5657736996191047, 0.9504726028052438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 370}], {
             RGBColor[
             0.546668194471859, 0.642848893250592, 0.9574548692618543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 498}], {
             RGBColor[
             0.4818912814299178, 0.5902600770764668, 0.9523553933815417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 228}], {
             RGBColor[
             0.9934539331599859, 0.9884069498751192, 0.5288792059852668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 252}], {
             RGBColor[
             0.8648112867502258, 0.89136633503373, 0.7718692919288858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 388}], {
             RGBColor[
             0.9699993320336204, 0.9742898944709728, 0.7727192137216462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 432}], {
             RGBColor[
             0.9462255159241673, 0.9556033712696023, 0.7798152269955922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 490}], {
             RGBColor[
             0.9921900608993205, 0.9897828176678509, 0.6878265810358566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 266}], {
             RGBColor[
             0.31612745049209645`, 0.4464579350707817, 0.9414294227127427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 410}], {
             RGBColor[
             0.35319958507105037`, 0.4803454610863929, 0.9437265431319655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 218}], {
             RGBColor[
             0.22451796602725682`, 0.35331299592884813`, 0.9360973380694622]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 287}], {
             RGBColor[
             0.21343735530821623`, 0.3416665715118395, 0.9354663136813074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 295}], {
             RGBColor[
             0.22332543873759936`, 0.352059574136821, 0.9360294254045023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 336}], {
             RGBColor[
             0.2196507706490151, 0.34819726498830533`, 0.9358201584930417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 389}], {
             RGBColor[
             0.21778138864415675`, 0.3462324259755344, 0.9357136999533677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 409}], {
             RGBColor[
             0.22930932819200256`, 0.35834902135390323`, 0.9363701990565594]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 456}], {
             RGBColor[
             0.2203607616298221, 0.3489435105251617, 0.9358605914290611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 458}], {
             RGBColor[
             0.22378112515977486`, 0.35253852945871533`, 0.9360553760721175]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[
             0.3477704837485026, 0.4756430463953687, 0.9433806055964585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 289}], {
             RGBColor[
             0.3807447886449092, 0.5042037319598828, 0.9454816991464247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 314}], {
             RGBColor[
             0.32609699892407057`, 0.4568705631814669, 0.9419995903085558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 349}], {
             RGBColor[
             0.3678599975315118, 0.49304357350588934`, 0.9446606916502523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 359}], {
             RGBColor[
             0.3537848938552699, 0.480852426136809, 0.9437638384901277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 397}], {
             RGBColor[
             0.3403332891441403, 0.46920132223333977`, 0.9429067141327215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 427}], {
             RGBColor[
             0.3008093263098471, 0.4322636714318231, 0.9404872881507658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 472}], {
             RGBColor[
             0.32528262084800263`, 0.45616518982380916`, 0.9419476988576752]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 214}], {
             RGBColor[
             0.3828653435329973, 0.49291080046599856`, 0.946830407391962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 233}], {
             RGBColor[
             0.7045416845554648, 0.49561598240663746`, 0.5739669497124782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 273}], {
             RGBColor[
             0.4297324939516893, 0.5421711471050089, 0.9494994222745707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 421}], {
             RGBColor[
             0.37249008899703795`, 0.4820057501195733, 0.9462395519949527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 423}], {
             RGBColor[
             0.37687473184245884`, 0.48661428775252374`, 0.9464892509185017]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 477}], {
             RGBColor[
             0.40529759982577535`, 0.5164885241169046, 0.9481078912022864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 227}], {
             RGBColor[
             0.8408474405782448, 0.3149769045127923, 0.18674886126930004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 243}], {
             RGBColor[
             0.8376849116916145, 0.29066832166115775`, 0.18372042003589745`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 326}], {
             RGBColor[
             0.8556196126725499, 0.40214503052670025`, 0.19986184252427644`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 348}], {
             RGBColor[
             0.8979876618717816, 0.5773208368833467, 0.24046628121299102`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 428}], {
             RGBColor[
             0.8331986050247592, 0.2561846027075905, 0.17942432770515804`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 434}], {
             RGBColor[
             0.9136331462118448, 0.6344185701788778, 0.48881376628200723`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 469}], {
             RGBColor[
             0.8482471960053599, 0.3686686083126496, 0.19371011734270402`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 474}], {
             RGBColor[
             0.9145804341522545, 0.6348102980864267, 0.4731147536068143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 495}], {
             RGBColor[
             0.8391330927044698, 0.3017996755229297, 0.18510719980929416`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 464}], {
             RGBColor[
             0.23745358448324252`, 0.36690915109166977`, 0.936834002403998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 485}], {
             RGBColor[
             0.23952079823930758`, 0.3690819238182165, 0.9369517271692371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 497}], {
             RGBColor[
             0.23351702426712523`, 0.36277157671219695`, 0.936609821123309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 287}], {
             RGBColor[
             0.21416398383706822`, 0.3424303041665726, 0.9355076941010749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 295}], {
             RGBColor[
             0.22405206726645135`, 0.35282330679155405`, 0.9360708058242697]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 299}], {
             RGBColor[
             0.21384131413680724`, 0.3420911578531577, 0.9354893185389921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 300}], {
             RGBColor[
             0.22223694937519295`, 0.35091550280272016`, 0.9359674375455889]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 301}], {
             RGBColor[
             0.2136344659280746, 0.34187374727084574`, 0.9354775388395093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 389}], {
             RGBColor[
             0.21850801717300872`, 0.34699615863026745`, 0.9357550803731354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 451}], {
             RGBColor[
             0.21498103480107186`, 0.34328907653376356`, 0.9355542239447563]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 456}], {
             RGBColor[
             0.22108739015867407`, 0.34970724317989477`, 0.9359019718488286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 254}], {
             RGBColor[
             0.5703520735589939, 0.511904106319279, 0.5892794945919869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 259}], {
             RGBColor[
             0.8830232984339081, 0.5617179434386964, 0.224104111662967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 261}], {
             RGBColor[
             0.8920963570986589, 0.602916583768641, 0.23167489421385412`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 315}], {
             RGBColor[
             0.5448527569683213, 0.48510270783243126`, 0.5878273462350064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 368}], {
             RGBColor[
             0.6561537738248766, 0.5929010247462924, 0.5945021229284573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 401}], {
             RGBColor[
             0.8388291376735261, 0.7404246611139982, 0.6099167772233072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 450}], {
             RGBColor[
             0.8609571905590665, 0.3975119598548832, 0.20318518074431657`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 454}], {
             RGBColor[
             0.902044161930851, 0.6480872421427781, 0.23997558640884487`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 471}], {
             RGBColor[
             0.8805092403498851, 0.5477975823099646, 0.2219082457048863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 475}], {
             RGBColor[
             0.871604644354381, 0.4793529554696741, 0.21338119452328883`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 500}], {
             RGBColor[
             0.8618492799802115, 0.40436895006188167`, 0.20403944658147605`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 273}], {
             RGBColor[
             0.24667426527178135`, 0.3766006712253524, 0.9373591065341305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 302}], {
             RGBColor[
             0.19497823659732902`, 0.32226486737097304`, 0.9344150941785414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 347}], {
             RGBColor[
             0.1893670574265447, 0.316367162293171, 0.9340955458257609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 421}], {
             RGBColor[
             0.18943186031713002`, 0.3164352742399168, 0.9340992362545124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 423}], {
             RGBColor[
             0.19381650316255092`, 0.32104381187286724`, 0.9343489351780614]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 477}], {
             RGBColor[
             0.2222393711458674, 0.35091804823724815`, 0.9359675754618462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 224}], {
             RGBColor[
             0.2915446973152564, 0.4237623402527527, 0.9399144112591507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 351}], {
             RGBColor[
             0.28708427642095813`, 0.4190741550858264, 0.9396603968878219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 356}], {
             RGBColor[
             0.2767305167100354, 0.40819169716336523`, 0.9390707655892996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 430}], {
             RGBColor[
             0.26193106415637823`, 0.3926365341899838, 0.9382279586601969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 238}], {
             RGBColor[
             0.29301995095784455`, 0.42425818517520597`, 0.9400370439768699]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 281}], {
             RGBColor[
             0.2553973215721218, 0.3857691564707237, 0.9378558716858294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 343}], {
             RGBColor[
             0.2793867448603114, 0.4109835613638972, 0.9392220338529205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 465}], {
             RGBColor[
             0.27425578181697063`, 0.40559059388349944`, 0.9389298330981818]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 290}], {
             RGBColor[
             0.3031025001174864, 0.43489572471311266`, 0.9406097604733883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 340}], {
             RGBColor[
             0.32857716094804046`, 0.4590187548700618, 0.9421576240396021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 355}], {
             RGBColor[
             0.32421328138501737`, 0.4552389817275355, 0.9418795614926734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 362}], {
             RGBColor[
             0.35409065029754605`, 0.481117256999343, 0.9437833210202597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 378}], {
             RGBColor[
             0.30140209308183147`, 0.4331084891066064, 0.9405129248082346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 384}], {
             RGBColor[
             0.30177027996931804`, 0.4334954768697517, 0.9405338925067932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 498}], {
             RGBColor[
             0.3908046357587574, 0.5126843292737169, 0.9461870095342384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 295}], {
             RGBColor[
             0.2307804101674582, 0.3598952217820915, 0.9364539749987908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.22896529227619977`, 0.3579874177932576, 0.93635060672011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 336}], {
             RGBColor[
             0.2271057420788739, 0.35603291263357584`, 0.9362447080873302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 389}], {
             RGBColor[
             0.22523636007401557`, 0.35406807362080495`, 0.9361382495476563]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 409}], {
             RGBColor[
             0.2367642996218614, 0.3661846689991738, 0.9367947486508479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 456}], {
             RGBColor[
             0.2278157330596809, 0.3567791581704322, 0.9362851410233497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 458}], {
             RGBColor[
             0.23123609658963368`, 0.36037417710398584`, 0.936479925666406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 244}], {
             RGBColor[
             0.43435496414043395`, 0.548657383494032, 0.949444989736919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 274}], {
             RGBColor[
             0.49450158018716717`, 0.6004976856950868, 0.9533481222927589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 334}], {
             RGBColor[
             0.4645364889888964, 0.5747991033502236, 0.9513681298117886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 337}], {
             RGBColor[
             0.6932397997764845, 0.7588302526554731, 0.971188910299956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 340}], {
             RGBColor[
             0.43185173064895377`, 0.5464892084598855, 0.9492854859123644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 361}], {
             RGBColor[
             0.5852351734855985, 0.6741310802897922, 0.9605102999918589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 363}], {
             RGBColor[
             0.4655401284489993, 0.5756684054061787, 0.9514320808307029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 369}], {
             RGBColor[
             0.47310816162837227`, 0.5822234553657439, 0.9519143092127434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 370}], {
             RGBColor[
             0.5588561185016121, 0.6527435990376659, 0.9584143472873132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 498}], {
             RGBColor[
             0.49407920545967077`, 0.6001547828635406, 0.9533148714070008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 349}], {
             RGBColor[
             0.3762573378366486, 0.5003169276156031, 0.9451957627490192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 359}], {
             RGBColor[
             0.3621822341604067, 0.48812578024652276`, 0.9442989095888945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 371}], {
             RGBColor[
             0.3509285621764658, 0.4783784152000333, 0.9435818355613093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 382}], {
             RGBColor[
             0.3105689508267532, 0.4409688726219141, 0.9410999393200739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 416}], {
             RGBColor[
             0.3002234451567067, 0.4300950902197503, 0.9405107780769688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 427}], {
             RGBColor[
             0.30920666661498386`, 0.43953702554153684`, 0.9410223592495326]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 429}], {
             RGBColor[
             0.3162555864633567, 0.44694588722950834`, 0.9414237848069549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 499}], {
             RGBColor[
             0.2998159216660946, 0.42966675719263536`, 0.9404875702170554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 223}], {
             RGBColor[
             0.46323693275442124`, 0.5733927057392445, 0.9513629056103252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 258}], {
             RGBColor[
             0.45501626161494246`, 0.5662723735811732, 0.9508390917145717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 297}], {
             RGBColor[
             0.5279871450253872, 0.627682775738259, 0.9559842286184892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 381}], {
             RGBColor[
             0.5529574414035745, 0.647954787237104, 0.9579499818185896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 439}], {
             RGBColor[
             0.6987612824501502, 0.7633077628527738, 0.9716294265306357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 307}], {
             RGBColor[
             0.456261635454359, 0.5691648443465238, 0.950417290103996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 333}], {
             RGBColor[
             0.41068141899913524`, 0.5301333365139219, 0.9473892347606732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 372}], {
             RGBColor[
             0.4565833875774816, 0.5694260572148426, 0.9504426196097452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 417}], {
             RGBColor[
             0.5718731828738293, 0.6621247011020224, 0.9601331729684849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 258}], {
             RGBColor[
             0.3816431136278576, 0.5049818159089863, 0.9455389396199805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 268}], {
             RGBColor[
             0.3997592820050565, 0.5206731304122181, 0.946693285849477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 373}], {
             RGBColor[
             0.3417396383201442, 0.4690205123479532, 0.9430475467307398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 381}], {
             RGBColor[
             0.47958429341648956`, 0.5866642295649169, 0.9526498297239985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 480}], {
             RGBColor[
             0.3717055099769321, 0.496374363105037, 0.9449057243028214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 263}], {
             RGBColor[
             0.2861834719747001, 0.4181273524985085, 0.9396090974072282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 342}], {
             RGBColor[
             0.2794767176957349, 0.41107812851853454`, 0.939227157672795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 351}], {
             RGBColor[
             0.29450587119895527`, 0.4268747217537883, 0.9400830457311632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 356}], {
             RGBColor[
             0.28415211148803254`, 0.41599226383132715`, 0.939493414432641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 463}], {
             RGBColor[
             0.2830318265857735, 0.4148147733688876, 0.9394296158647704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 235}], {
             RGBColor[
             0.31564550837904015`, 0.44462855110700683`, 0.9414504121909557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 249}], {
             RGBColor[
             0.28189858083211217`, 0.41362366022985875`, 0.9393650791955862]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 260}], {
             RGBColor[
             0.27991286113099906`, 0.41153654292208813`, 0.9392519953962168]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 280}], {
             RGBColor[
             0.26557083518380836`, 0.39646216431462483`, 0.9384352382356503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 296}], {
             RGBColor[
             0.29383455667092717`, 0.42573700098774714`, 0.940060637634782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 424}], {
             RGBColor[
             0.2974218624617132, 0.42884414496049433`, 0.940289217587641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 440}], {
             RGBColor[
             0.27796156594151966`, 0.4094856079586846, 0.9391408720218586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 453}], {
             RGBColor[
             0.2792780627176027, 0.4108693295410645, 0.939215844565674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 470}], {
             RGBColor[
             0.26486570011979793`, 0.3957210226542046, 0.9383950818369088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 236}], {
             RGBColor[
             0.23337407460187973`, 0.3626213275504917, 0.9366016803513484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 283}], {
             RGBColor[
             0.18031957576389654`, 0.30685768542225833`, 0.9335803051296228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 292}], {
             RGBColor[
             0.17919781223777545`, 0.3056786408323896, 0.9335164223563106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 308}], {
             RGBColor[
             0.17918563853241248`, 0.3056658454961956, 0.9335157290817995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 386}], {
             RGBColor[
             0.1791759961486071, 0.30565571073945375`, 0.9335151799623065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 396}], {
             RGBColor[
             0.5864855268156967, 0.6472607121015193, 0.7362180745608087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 422}], {
             RGBColor[
             0.20671849831186667`, 0.3346046268085379, 0.9350836847150235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 446}], {
             RGBColor[
             0.20378813280661343`, 0.33152462686661266`, 0.9349168047345866]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 309}], {
             RGBColor[
             0.9193309660445672, 0.6696242794444807, 0.3370748612621325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 320}], {
             RGBColor[
             0.9171168323829694, 0.670650788557899, 0.5149397016540836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 348}], {
             RGBColor[
             0.9027713884189711, 0.6140906553673846, 0.24504718315702606`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 428}], {
             RGBColor[
             0.8379823315719487, 0.29295442119162834`, 0.18400522964919308`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 495}], {
             RGBColor[
             0.8439168192516593, 0.3385694940069675, 0.1896881017533292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 388}], {
             RGBColor[
             0.9696267022726579, 0.9734928770909221, 0.7321607638451979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 490}], {
             RGBColor[
             0.9918174311383581, 0.9889858002878001, 0.6472681311594083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 244}], {
             RGBColor[
             0.3167084139494082, 0.447095666264713, 0.9414615153937971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 248}], {
             RGBColor[
             0.2667577277658053, 0.3977096636716398, 0.9385028300123448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 255}], {
             RGBColor[
             0.34428066244060973`, 0.47097736208628804`, 0.9432183946864745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 313}], {
             RGBColor[
             0.2789668469500533, 0.41054222203715074`, 0.9391981212881146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 338}], {
             RGBColor[
             0.3055405634218271, 0.43742263545021065`, 0.9407499098335221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 379}], {
             RGBColor[
             0.30013749915285226`, 0.43274277274633094`, 0.9404056313560452]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 380}], {
             RGBColor[
             0.2819134302618612, 0.4136392679220333, 0.9393659248486427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 390}], {
             RGBColor[
             0.29586463316817824`, 0.4283028667339263, 0.9401604252152023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 411}], {
             RGBColor[
             0.26528288174741516`, 0.39615950699567326`, 0.9384188397134368]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 478}], {
             RGBColor[
             0.27850887095594073`, 0.41006086022998334`, 0.9391720402327646]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 242}], {
             RGBColor[
             0.2244428247428983, 0.35323401767475476`, 0.9360930588844796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 339}], {
             RGBColor[
             0.21778435426976317`, 0.3462355430360783, 0.9357138688413589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 365}], {
             RGBColor[
             0.22042634378562792`, 0.3490124415290624, 0.9358643262358141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 374}], {
             RGBColor[
             0.23780417240741958`, 0.3672776412285381, 0.9368539678676315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 391}], {
             RGBColor[
             0.23250262506826308`, 0.3617053788375689, 0.936552052589603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 246}], {
             RGBColor[
             0.27633388437422024`, 0.407774811430481, 0.93904817796454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 256}], {
             RGBColor[
             0.27391624912615603`, 0.40523372349783726`, 0.9389104972137335]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 271}], {
             RGBColor[
             0.25712583983655113`, 0.38758593876102676`, 0.9379543082438752]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 288}], {
             RGBColor[
             0.2572561350755689, 0.3877228873184297, 0.9379617283649826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 442}], {
             RGBColor[
             0.2711958428958343, 0.40237440406605196`, 0.938755574103397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 444}], {
             RGBColor[
             0.2648697036740537, 0.39572523064356746`, 0.938395309833401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 492}], {
             RGBColor[
             0.2675328366491727, 0.39852435225280064`, 0.9385469713165818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 307}], {
             RGBColor[
             0.4130035971526026, 0.5316969057817654, 0.9476609261549895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 312}], {
             RGBColor[
             0.3303045820158528, 0.4601142095117522, 0.9422823672274991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 330}], {
             RGBColor[
             0.3313235898372211, 0.4611852513408379, 0.942340398215439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 350}], {
             RGBColor[
             0.3591838096222978, 0.48552869561681206`, 0.944107852628729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 354}], {
             RGBColor[
             0.35898073503518557`, 0.48535280261628094`, 0.94409491289561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 372}], {
             RGBColor[
             0.41332534927572523`, 0.5319581186500844, 0.9476862556607386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 376}], {
             RGBColor[
             0.3178263634409366, 0.4469988106247622, 0.9415717511395277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 400}], {
             RGBColor[
             0.3260597275402094, 0.45565259831853255`, 0.9420406290448107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 414}], {
             RGBColor[
             0.31542779716347613`, 0.44447776538926564`, 0.9414351563383871]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 415}], {
             RGBColor[
             0.3216051563189196, 0.45097056152882875`, 0.9417869478037058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 476}], {
             RGBColor[
             0.8458261121541704, 0.35324515591315253`, 0.19151644279301172`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 235}], {
             RGBColor[
             0.3728101836078023, 0.49733117588158576`, 0.9449761131297559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[
             0.36975457999068184`, 0.4946845656075394, 0.9447814127692372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 262}], {
             RGBColor[
             0.4323322286458682, 0.548267980100758, 0.9489396155777698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 296}], {
             RGBColor[
             0.3509992318996893, 0.478439625762326, 0.9435863385735823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 332}], {
             RGBColor[
             0.3953853483413155, 0.5168846489129837, 0.946414582664141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 393}], {
             RGBColor[
             0.42489506401207827`, 0.5422301548105988, 0.9483541347345662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 468}], {
             RGBColor[
             0.4334778335161593, 0.5491980337433716, 0.9490298017896481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 239}], {
             RGBColor[
             0.35398612023304477`, 0.4810267183113057, 0.943776660456982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 249}], {
             RGBColor[
             0.32329479630323715`, 0.4526684377082041, 0.9418860278221313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 260}], {
             RGBColor[
             0.32130907660212404`, 0.45058132040043347`, 0.941772944022762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 262}], {
             RGBColor[
             0.416563768888231, 0.5346101328045243, 0.9479348632655147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 296}], {
             RGBColor[
             0.3352307721420522, 0.4647817784660925, 0.9425815862613272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 332}], {
             RGBColor[
             0.37961688858367837`, 0.50322680161675, 0.9454098303518859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 344}], {
             RGBColor[
             0.4103923521286693, 0.5295998986599555, 0.9474490267315575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 393}], {
             RGBColor[
             0.40912660425444114`, 0.5285723075143651, 0.947349382422311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 424}], {
             RGBColor[
             0.3388180779328382, 0.46788892243883967`, 0.9428101662141861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 440}], {
             RGBColor[
             0.3193577814126447, 0.44853038543702994`, 0.9416618206484036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 453}], {
             RGBColor[
             0.32067427818872773`, 0.4499141070194098, 0.9417367931922191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 243}], {
             RGBColor[
             0.5633146331293595, 0.36122739545781846`, 0.562473440762307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 276}], {
             RGBColor[
             0.45343165662521556`, 0.5606674341824253, 0.9514328089086481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 283}], {
             RGBColor[
             0.23426865806856206`, 0.3635615914938426, 0.9366526255563583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 292}], {
             RGBColor[
             0.23314689454244097`, 0.36238254690397387`, 0.9365887427830462]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 396}], {
             RGBColor[
             0.6404346091203621, 0.7039646181731036, 0.7392903949875442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 422}], {
             RGBColor[
             0.26066758061653217`, 0.39130853288012224`, 0.9381560051417591]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 267}], {
             RGBColor[
             0.9475774996267206, 0.9513626199375382, 0.7014579081154306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 270}], {
             RGBColor[
             0.9480577404464491, 0.9590498999175098, 0.9029559373872008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 329}], {
             RGBColor[
             0.8943251384864865, 0.9185746058926771, 0.989782724153959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 426}], {
             RGBColor[
             0.8881333928283652, 0.9136374759753497, 0.9891921499256506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 448}], {
             RGBColor[
             0.7370158535300309, 0.7940376208084021, 0.9750172525524329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 489}], {
             RGBColor[
             0.9480949935467251, 0.959065305031835, 0.9023385571076953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 265}], {
             RGBColor[
             0.32058421295120315`, 0.4520956650524487, 0.9416483204611299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 328}], {
             RGBColor[
             0.35273346300045894`, 0.47994172957682313`, 0.943696842245803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 343}], {
             RGBColor[
             0.306520714368336, 0.43844834351747275`, 0.9408058924805078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 431}], {
             RGBColor[
             0.38434692528377257`, 0.5073237216678145, 0.9457112241078087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 433}], {
             RGBColor[
             0.32283008594645624`, 0.45404092736007795`, 0.94179142550244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 436}], {
             RGBColor[
             0.3965368671240651, 0.5173498014044343, 0.9466350145946033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 462}], {
             RGBColor[
             0.392016142899485, 0.5136796738226148, 0.9462791266236859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 465}], {
             RGBColor[
             0.30138975132499524`, 0.433055376037075, 0.940513691725769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 262}], {
             RGBColor[
             0.41350816527111056`, 0.531963522530478, 0.947740162904996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 263}], {
             RGBColor[
             0.31216558423603546`, 0.4415359530567809, 0.9412315474042139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 296}], {
             RGBColor[
             0.33217516852493173`, 0.46213516819204603`, 0.9423868859008084]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 332}], {
             RGBColor[
             0.37656128496655794`, 0.5005801913427036, 0.9452151299913671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 393}], {
             RGBColor[
             0.4060710006373207, 0.5259256972403187, 0.9471546820617923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 424}], {
             RGBColor[
             0.3357624743157177, 0.4652423121647933, 0.9426154658536674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 440}], {
             RGBColor[
             0.3163021777955242, 0.4458837751629835, 0.9414671202878849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 453}], {
             RGBColor[
             0.31761867457160725`, 0.44726749674536337`, 0.9415420928317004]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 251}], {
             RGBColor[
             0.25758537828186423`, 0.38806894280347104`, 0.9379804782785095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 310}], {
             RGBColor[
             0.2766913122921885, 0.4081504908345045, 0.939068532955701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 352}], {
             RGBColor[
             0.24222822396059346`, 0.3719275999119933, 0.937105911058787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 367}], {
             RGBColor[
             0.24323530728920995`, 0.3729861083431402, 0.9371632629645055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 382}], {
             RGBColor[
             0.26942512488484194`, 0.40051326716649266`, 0.9386547343322136]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 399}], {
             RGBColor[
             0.24906325398775672`, 0.3791116498364756, 0.9374951559073132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 412}], {
             RGBColor[
             0.2495035202048371, 0.3795743975451175, 0.9375202284170604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 416}], {
             RGBColor[
             0.2590796192147955, 0.38963948476432886`, 0.9380655730891085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 429}], {
             RGBColor[
             0.2751117605214455, 0.4064902817740869, 0.9389785798190946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 402}], {
             RGBColor[
             0.6288966867837086, 0.7086387216585579, 0.9645893173262957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 417}], {
             RGBColor[
             0.7032574015004508, 0.7681092940971459, 0.9710577835336467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 436}], {
             RGBColor[
             0.5892009770363313, 0.6764119562142918, 0.9614643256448061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 461}], {
             RGBColor[
             0.8249688230204753, 0.8639714322998968, 0.9750930222658254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 339}], {
             RGBColor[
             0.21834915626655288`, 0.34682918574521915`, 0.9357460334795263]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 365}], {
             RGBColor[
             0.22099114578241763`, 0.3496060842382034, 0.9358964908739815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 374}], {
             RGBColor[
             0.2383689744042093, 0.367871283937679, 0.936886132505799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 276}], {
             RGBColor[
             0.7294231328480298, 0.5025695960181678, 0.5742322488928711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 326}], {
             RGBColor[
             0.8572408103331092, 0.41460626615910345`, 0.2014143032349089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 428}], {
             RGBColor[
             0.8348198026853184, 0.2686458383399938, 0.18097678841579048`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 454}], {
             RGBColor[
             0.869594267772993, 0.47070043117032717`, 0.21172233093369885`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 469}], {
             RGBColor[
             0.8498683936659192, 0.3811298439450528, 0.19526257805333647`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 471}], {
             RGBColor[
             0.8480593461920269, 0.37041077133751354`, 0.1936549902297403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 475}], {
             RGBColor[
             0.8391547501965229, 0.3019661444972231, 0.18512793904814284`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 495}], {
             RGBColor[
             0.8407542903650291, 0.31426091115533294`, 0.1866596605199266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 274}], {
             RGBColor[
             0.40258764491589, 0.5228672426461249, 0.9469441500000384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 313}], {
             RGBColor[
             0.3046994618698019, 0.43447349621750786`, 0.9407776233385161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 334}], {
             RGBColor[
             0.3726225537176192, 0.4971686603012616, 0.9449641575190681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 340}], {
             RGBColor[
             0.33993779537767665`, 0.4688587654109236, 0.9428815136196439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 355}], {
             RGBColor[
             0.3355739158146536, 0.46507899226839733`, 0.9426034510727153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 363}], {
             RGBColor[
             0.37362619317772217`, 0.49803796235721676`, 0.9450281085379824]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 378}], {
             RGBColor[
             0.3127627275114677, 0.4429484996474682, 0.9412368143882763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 379}], {
             RGBColor[
             0.3258701140726008, 0.45667404692668806`, 0.9419851334064466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 380}], {
             RGBColor[
             0.3076460451816098, 0.43757054210239044`, 0.9409454268990441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 390}], {
             RGBColor[
             0.3215972480879268, 0.45223414091428343`, 0.9417399272656037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 498}], {
             RGBColor[
             0.40216527018839365`, 0.5225243398145787, 0.9469108991142803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 394}], {
             RGBColor[
             0.22510267482771082`, 0.3539275619508045, 0.936130636370649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 438}], {
             RGBColor[
             0.22151371355788788`, 0.3501553361029332, 0.9359262503357249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 445}], {
             RGBColor[
             0.22560109399094413`, 0.3544514320929628, 0.93615902060465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 460}], {
             RGBColor[
             0.23495456172986623`, 0.36428251973067727`, 0.936691686755166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 256}], {
             RGBColor[
             0.2918037733500637, 0.42403464559170456`, 0.9399291652560644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 288}], {
             RGBColor[
             0.2751436592994766, 0.40652380941229693`, 0.9389803964073136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 333}], {
             RGBColor[
             0.33643527177961996`, 0.46448215779697133`, 0.9427075059768388]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 392}], {
             RGBColor[
             0.3001114005223494, 0.4327664884837622, 0.940402272333493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 442}], {
             RGBColor[
             0.28908336711974203`, 0.42117532615991926`, 0.939774242145728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 444}], {
             RGBColor[
             0.2827572278979614, 0.41452615273743476`, 0.9394139778757318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 459}], {
             RGBColor[
             0.3423837632254584, 0.4696344421074833, 0.9430865385917233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 492}], {
             RGBColor[
             0.2854203608730804, 0.4173252743466679, 0.9395656393589127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 255}], {
             RGBColor[
             0.4462984536881862, 0.5598509487377481, 0.9499715158755377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 269}], {
             RGBColor[
             0.47197536116157857`, 0.5820909954323062, 0.9516076257145445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 360}], {
             RGBColor[
             0.5371888520305683, 0.6351531360172418, 0.9567086207009003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 369}], {
             RGBColor[
             0.457479402684923, 0.5695353247878849, 0.9506839560586847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 370}], {
             RGBColor[
             0.5432273595581627, 0.6400554684598069, 0.9571839941332545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 425}], {
             RGBColor[
             0.4351771155351065, 0.550218204604259, 0.9492628740426365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 466}], {
             RGBColor[
             0.4992597773340883, 0.6043606044932961, 0.953722705002015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 468}], {
             RGBColor[
             0.48669420259584584`, 0.5941593048480999, 0.9527334969294036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 286}], {
             RGBColor[
             0.23281996068137648`, 0.36203891868719107`, 0.9365701243833138]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 294}], {
             RGBColor[
             0.240426199543799, 0.37003355799499527`, 0.9370032884341067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 313}], {
             RGBColor[
             0.254748775686199, 0.38508749362443473`, 0.9378189379570638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 380}], {
             RGBColor[
             0.257695358998007, 0.3881845395093172, 0.937986741517592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 411}], {
             RGBColor[
             0.2410648104835609, 0.37070477858295714`, 0.937039656382386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 478}], {
             RGBColor[
             0.25429079969208646`, 0.3846061318172672, 0.9377928569017139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 260}], {
             RGBColor[
             0.28756214905519606`, 0.4195764295232854, 0.9396876110273925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 280}], {
             RGBColor[
             0.27322012310800536`, 0.4045020509158221, 0.938870853866826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 296}], {
             RGBColor[
             0.3014838445951241, 0.4337768875889444, 0.9404962532659576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 424}], {
             RGBColor[
             0.30507115038591015`, 0.4368840315616916, 0.9407248332188166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 440}], {
             RGBColor[
             0.2856108538657166, 0.41752549455988186`, 0.9395764876530341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 470}], {
             RGBColor[
             0.27251498804399493`, 0.40376090925540187`, 0.9388306974680845]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 339}], {
             RGBColor[
             0.20806801028262886`, 0.33602304945380984`, 0.9351605374253343]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 365}], {
             RGBColor[
             0.21070999979849359`, 0.338799947946794, 0.9353109948197895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 305}], {
             RGBColor[
             0.25482853774731307`, 0.38517132860787223`, 0.9378234802884469]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 367}], {
             RGBColor[
             0.24419513183599667`, 0.3739949447982042, 0.9372179235525118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 382}], {
             RGBColor[
             0.27038494943162866`, 0.40152210362155666`, 0.9387093949202199]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 416}], {
             RGBColor[
             0.26003944376158217`, 0.39064832121939286`, 0.9381202336771148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 427}], {
             RGBColor[
             0.2690226652198594, 0.4000902565411794, 0.9386318148496786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 429}], {
             RGBColor[
             0.2760715850682322, 0.4074991182291509, 0.9390332404071009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 499}], {
             RGBColor[
             0.25963192027097015`, 0.39021998819227793`, 0.9380970258172014]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 282}], {
             RGBColor[
             0.6717272001021579, 0.7429460920325152, 0.9682785844173988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 432}], {
             RGBColor[
             0.8172102397534445, 0.8577657390481622, 0.982246863062763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 467}], {
             RGBColor[
             0.7213175895970523, 0.7822180503007243, 0.9728578543010624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 261}], {
             RGBColor[
             0.9325093316648222, 0.7680041432668934, 0.5596474808987255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 277}], {
             RGBColor[
             0.8781666893011308, 0.9046720920391318, 0.9377821758000617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 291}], {
             RGBColor[
             0.819979493708928, 0.8592158126034372, 0.9319826199336896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 311}], {
             RGBColor[
             0.8659443575362178, 0.8951239135712197, 0.9365639679939195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 319}], {
             RGBColor[
             0.8499607656875054, 0.8826374101392084, 0.934970872933598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 377}], {
             RGBColor[
             0.9830684787672088, 0.9867535506374262, 0.9072964317019494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 484}], {
             RGBColor[
             0.9889617727140382, 0.9876413426482502, 0.6827040059696212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 488}], {
             RGBColor[
             0.877198073649208, 0.9039154021300979, 0.937685633244106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 315}], {
             RGBColor[
             0.21099893285942517`, 0.33910363491324724`, 0.9353274491301715]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 325}], {
             RGBColor[
             0.20775758490962407`, 0.33569677270467635`, 0.935142859159575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 347}], {
             RGBColor[
             0.20771262472504887`, 0.3356495167000475, 0.935140298743576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 368}], {
             RGBColor[
             0.32229994971598047`, 0.44690195182710835`, 0.9420022258236223]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 386}], {
             RGBColor[
             0.20771262472504887`, 0.3356495167000475, 0.935140298743576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 401}], {
             RGBColor[
             0.50497531356463, 0.5944255881948143, 0.9574168801184721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 454}], {
             RGBColor[
             0.568190337821955, 0.5020881692235942, 0.5874756893040098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 471}], {
             RGBColor[
             0.5466554162409889, 0.4017985093907806, 0.5694083486000513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 269}], {
             RGBColor[
             0.4232624333249523, 0.5410303787827784, 0.94819088586856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 274}], {
             RGBColor[
             0.43015989340709154`, 0.5467489384677, 0.9487010292927157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 334}], {
             RGBColor[
             0.40019480220882075`, 0.5210503561228367, 0.9467210368117455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 338}], {
             RGBColor[
             0.35884542683277726`, 0.48523560545214284`, 0.9440862911766009]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 369}], {
             RGBColor[
             0.40876647484829665`, 0.5284747081383571, 0.9472672162127003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 370}], {
             RGBColor[
             0.4945144317215364, 0.598994851810279, 0.9537672542872702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 379}], {
             RGBColor[
             0.35344236256380235`, 0.4805557427482631, 0.943742012699124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 390}], {
             RGBColor[
             0.3491694965791283, 0.4761158367358585, 0.9434968065582812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 425}], {
             RGBColor[
             0.38646418769848023`, 0.5091575879547311, 0.9458461341966522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 466}], {
             RGBColor[
             0.45054684949746193`, 0.5632999878437683, 0.9503059651560305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 271}], {
             RGBColor[
             0.2725957288123946, 0.4038457729222503, 0.9388352955353996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 333}], {
             RGBColor[
             0.3340176365315557, 0.4619410698643276, 0.9425698252260324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 442}], {
             RGBColor[
             0.28666573187167776`, 0.4186342382272755, 0.9396365613949216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 444}], {
             RGBColor[
             0.28033959264989716`, 0.411985064804791, 0.9392762971249253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 492}], {
             RGBColor[
             0.28300272562501616`, 0.4147841864140242, 0.9394279586081062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 272}], {
             RGBColor[
             0.8397181825766789, 0.3055916208213189, 0.18563986428858031`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 306}], {
             RGBColor[
             0.8582164736566054, 0.4477775920644729, 0.2033538487175496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 317}], {
             RGBColor[
             0.8711268784377937, 0.5076990787158229, 0.21417744721027115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 357}], {
             RGBColor[
             0.8829978584207956, 0.5607626793064351, 0.22403944465155362`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 418}], {
             RGBColor[
             0.9186634619525802, 0.7177171878043327, 0.5626295641489729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 420}], {
             RGBColor[
             0.9137481314322007, 0.7140513423503487, 0.5709499365964574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 289}], {
             RGBColor[
             0.4063967473847854, 0.5264221693154291, 0.9471162192741931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 297}], {
             RGBColor[
             0.4463933258988235, 0.5592718859080008, 0.9501602626281445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 314}], {
             RGBColor[
             0.35174895766394676`, 0.47908900053701325`, 0.9436341104363243]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 373}], {
             RGBColor[
             0.3335189671806654, 0.461900180189882, 0.9425237328349862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 381}], {
             RGBColor[
             0.4713636222770108, 0.5795438974068458, 0.952126015828245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 397}], {
             RGBColor[
             0.36598524788401654`, 0.49141975958888606`, 0.94454123426049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 472}], {
             RGBColor[
             0.3509345795878789, 0.47838362717935545`, 0.9435822189854435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 341}], {
             RGBColor[
             0.9277070351691528, 0.7270975616364004, 0.37415406223837167`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 405}], {
             RGBColor[
             0.9279266912954685, 0.7275673838799486, 0.39806227602736116`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 450}], {
             RGBColor[
             0.8397745913250846, 0.3013267240551166, 0.18550990071046175`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 454}], {
             RGBColor[
             0.8808615626968692, 0.5519020063430116, 0.22230030637499004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 469}], {
             RGBColor[
             0.8611356885897954, 0.46233141911773723`, 0.2058405534946276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 471}], {
             RGBColor[
             0.8593266411159032, 0.451612346510198, 0.20423296567103144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 475}], {
             RGBColor[
             0.8504220451203991, 0.38316771966990754`, 0.19570591448943397`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 491}], {
             RGBColor[
             0.9280010655847133, 0.727726462964249, 0.4061574584267472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 500}], {
             RGBColor[
             0.8406666807462297, 0.3081837142621151, 0.18636416654762122`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 280}], {
             RGBColor[
             0.27123440340689225`, 0.4024149336080515, 0.9387577700674566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 424}], {
             RGBColor[
             0.3030854306847971, 0.434796914253921, 0.9406117494194473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 440}], {
             RGBColor[
             0.28362513416460355`, 0.4154383772521112, 0.9394634038536649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 470}], {
             RGBColor[
             0.2705292683428818, 0.4016737919476313, 0.9387176136687151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 483}], {
             RGBColor[
             0.2911128004849959, 0.42330838930030823`, 0.9398898153736015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 484}], {
             RGBColor[
             0.9364392575786439, 0.7675671876801757, 0.34462692180178206`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 500}], {
             RGBColor[
             0.8497397394109806, 0.34938235459205963`, 0.19393494909850834`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 332}], {
             RGBColor[
             0.43913893362174417`, 0.5541636058359223, 0.9493733327998998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 344}], {
             RGBColor[
             0.4699143971667351, 0.5805367028791276, 0.9514125291795714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 387}], {
             RGBColor[
             0.6255998101870561, 0.7048955003973141, 0.9650590620780228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 393}], {
             RGBColor[
             0.46864864929250694`, 0.5795091117335374, 0.951312884870325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 424}], {
             RGBColor[
             0.39834012297090404`, 0.5188257266580119, 0.9467736686621999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 296}], {
             RGBColor[
             0.2934102361450429, 0.4252910132115676, 0.9400364732085589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 323}], {
             RGBColor[
             0.2563726589916906, 0.3867942979386546, 0.9379114157089916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 342}], {
             RGBColor[
             0.2666938975771815, 0.3976425740963284, 0.9384991949775311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 395}], {
             RGBColor[
             0.2691941123375187, 0.40027045833221453`, 0.938641578509396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 440}], {
             RGBColor[
             0.2775372454156354, 0.40903962018250506`, 0.9391167075956355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 447}], {
             RGBColor[
             0.2599502995006695, 0.3905546249491011, 0.938115157043333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 453}], {
             RGBColor[
             0.27885374219171843`, 0.41042334176488493`, 0.9391916801394509]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 463}], {
             RGBColor[
             0.2702490064672201, 0.4013792189466815, 0.9387016531695065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 394}], {
             RGBColor[
             0.23171433520063273`, 0.36087683620622507`, 0.9365071606478118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 398}], {
             RGBColor[
             0.2479686232623, 0.377961123540424, 0.9374328183068594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 445}], {
             RGBColor[
             0.23221275436386601`, 0.3614007063483834, 0.9365355448818129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 328}], {
             RGBColor[
             0.35316375548579293`, 0.48031442730049023`, 0.9437242601024758]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 433}], {
             RGBColor[
             0.32326037843179023`, 0.45441362508374517`, 0.9418188433591128]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 462}], {
             RGBColor[
             0.392446435384819, 0.5140523715462819, 0.9463065444803587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 364}], {
             RGBColor[
             0.2740437091478759, 0.405367692062097, 0.9389177558734103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 374}], {
             RGBColor[
             0.27062553266643685`, 0.40177497185519817`, 0.9387230957795312]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 410}], {
             RGBColor[
             0.326592877843097, 0.45552256223454524`, 0.9420962704893343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 437}], {
             RGBColor[
             0.2726756027922651, 0.40392972553939704`, 0.9388398442403902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 278}], {
             RGBColor[
             0.9687131736129876, 0.9678890438697982, 0.6921508091390034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 329}], {
             RGBColor[
             0.9358102453449542, 0.941979730786866, 0.7003355368972839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 406}], {
             RGBColor[
             0.9898404936899885, 0.9773917410301207, 0.415032665757733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 413}], {
             RGBColor[
             0.981449315920919, 0.9490863280728146, 0.38243452466585603`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 476}], {
             RGBColor[
             0.9187775169477521, 0.6742536840952063, 0.3030402150761125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 486}], {
             RGBColor[
             0.9619951023866931, 0.9628588250229391, 0.7028330719374227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 493}], {
             RGBColor[
             0.991319933690298, 0.9817192401312839, 0.4771566948770857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 275}], {
             RGBColor[
             0.4116793705742366, 0.5309977120097701, 0.9474528233525847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 285}], {
             RGBColor[
             0.3620365603618595, 0.4879996049239992, 0.9442896273832655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 324}], {
             RGBColor[
             0.3896661145929028, 0.5119309360971549, 0.946050158147012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 353}], {
             RGBColor[
             0.5246586597567469, 0.6237950026375101, 0.9560497714979366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 441}], {
             RGBColor[
             0.4298935905497302, 0.5467739538792281, 0.9486134173432208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 480}], {
             RGBColor[
             0.3816010072146523, 0.5049453454501976, 0.9455362566365644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 481}], {
             RGBColor[
             0.3639357382267393, 0.48964457733510314`, 0.9444106413174386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 360}], {
             RGBColor[
             0.5141528316673345, 0.616332566062272, 0.9549279906939228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 369}], {
             RGBColor[
             0.43444338232168905`, 0.5507147548329152, 0.948903326051707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 425}], {
             RGBColor[
             0.4121410951718726, 0.5313976346492894, 0.947482244035659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 466}], {
             RGBColor[
             0.47622375697085434`, 0.5855400345383266, 0.9519420749950372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 468}], {
             RGBColor[
             0.4636581822326119, 0.5753387348931303, 0.9509528669224259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 309}], {
             RGBColor[
             0.9915269265441726, 0.9888220703419007, 0.6489133693566129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 345}], {
             RGBColor[
             0.824874141314561, 0.8621219539632672, 0.8908628396870938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 375}], {
             RGBColor[
             0.9741122632489756, 0.9792447932430604, 0.8853225104060825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 426}], {
             RGBColor[
             0.9300987405065613, 0.9447298808495102, 0.9012429919407459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 489}], {
             RGBColor[
             0.9900603412249211, 0.9901577099059953, 0.8143893991227904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 284}], {
             RGBColor[
             0.2504489768010796, 0.3805681323731789, 0.9375740707715388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 442}], {
             RGBColor[
             0.26987532258207286`, 0.400986453490465, 0.9386803724250632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 444}], {
             RGBColor[
             0.26354918336029226`, 0.3943372800679805, 0.938320108155067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 464}], {
             RGBColor[
             0.24983604138275278`, 0.37992389838616725`, 0.9375391650062217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 492}], {
             RGBColor[
             0.2662123163354113, 0.39713640167721365`, 0.9384717696382479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 306}], {
             RGBColor[
             0.8390812230199529, 0.30140098239829205`, 0.18505752934082234`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 317}], {
             RGBColor[
             0.8519916278011412, 0.36132246904964216`, 0.1958811278335439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 357}], {
             RGBColor[
             0.8638626077841431, 0.41438606964025426`, 0.20574312527482636`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 308}], {
             RGBColor[
             0.23624385022904204`, 0.36563764368892326`, 0.9367651098278627]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 421}], {
             RGBColor[
             0.236299010735822, 0.36569562087892715`, 0.9367682511371211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 423}], {
             RGBColor[
             0.24068365358124288`, 0.3703041585118776, 0.9370179500606701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 446}], {
             RGBColor[
             0.26084634450324296`, 0.39149642505934035`, 0.9381661854806498]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 477}], {
             RGBColor[
             0.2691065215645594, 0.4001783948762585, 0.9386365903444549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 334}], {
             RGBColor[
             0.4327691697643524, 0.5490089625023165, 0.9488672900749079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 340}], {
             RGBColor[
             0.40008441142440987`, 0.5206990676119785, 0.9467846461754836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 361}], {
             RGBColor[
             0.5534678542610545, 0.6483409394418851, 0.9580094602549781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 363}], {
             RGBColor[
             0.4337728092244554, 0.5498782645582716, 0.9489312410938221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 369}], {
             RGBColor[
             0.4413408424038283, 0.5564333145178368, 0.9494134694758627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 370}], {
             RGBColor[
             0.5270887992770681, 0.6269534581897589, 0.9559135075504326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 379}], {
             RGBColor[
             0.386016730119334, 0.5085143491277428, 0.9458882659622865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 498}], {
             RGBColor[
             0.46231188623512687`, 0.5743646420156336, 0.95081403167012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 282}], {
             RGBColor[
             0.5106811757652547, 0.612557396257451, 0.9549190346803453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 285}], {
             RGBColor[
             0.36406115169331943`, 0.4897532041763907, 0.9444186325526303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 324}], {
             RGBColor[
             0.3916907059243627, 0.5136845353495464, 0.9461791633163769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 353}], {
             RGBColor[
             0.5266832510882068, 0.6255486018899017, 0.9561787766673014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 441}], {
             RGBColor[
             0.43191818188119013`, 0.5485275531316196, 0.9487424225125856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 481}], {
             RGBColor[
             0.36596032955819924`, 0.49139817658749463`, 0.9445396464868034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 283}], {
             RGBColor[
             0.4003771577872324, 0.5049037920541919, 0.9484114336869224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 292}], {
             RGBColor[
             0.39925539426111123`, 0.5037247474643232, 0.9483475509136101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 396}], {
             RGBColor[
             0.8065431088390325, 0.8453068187334528, 0.7510492031181083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 422}], {
             RGBColor[
             0.4267760803352025, 0.5326507334404715, 0.9499148132723232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 291}], {
             RGBColor[
             0.7131143362098424, 0.7758096064076011, 0.9720402306671867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 311}], {
             RGBColor[
             0.7590792000371321, 0.8117177073753836, 0.9766215787274166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 319}], {
             RGBColor[
             0.7430956081884199, 0.7992312039433723, 0.9750284836670953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 331}], {
             RGBColor[
             0.8039966134471465, 0.8469425741957761, 0.9810626907032964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 377}], {
             RGBColor[
             0.8762033212681233, 0.9033473444415901, 0.9473540424354466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 419}], {
             RGBColor[
             0.6419960336426249, 0.718265092425402, 0.9663099050077802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 449}], {
             RGBColor[
             0.7498021540184663, 0.8044704085174408, 0.9756969294792002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 484}], {
             RGBColor[
             0.8820966152149525, 0.9042351364524142, 0.7227616167031183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 488}], {
             RGBColor[
             0.7703329161501223, 0.8205091959342619, 0.9777432439776033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 329}], {
             RGBColor[
             0.9154608124727537, 0.9351010298249371, 0.9804756251775316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 406}], {
             RGBColor[
             0.969491060817788, 0.9705130400681918, 0.6951727540379807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 413}], {
             RGBColor[
             0.9610998830487185, 0.9422076271108857, 0.6625746129461039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 486}], {
             RGBColor[
             0.9416456695144926, 0.9559801240610102, 0.9829731602176706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 493}], {
             RGBColor[
             0.9709705008180975, 0.974840539169355, 0.7572967831573334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.2964892825686648, 0.42843496613236076`, 0.9402152006381983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 324}], {
             RGBColor[
             0.3241188367997081, 0.45236629730551653`, 0.9419757314019449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 481}], {
             RGBColor[
             0.2983884604335446, 0.4300799385434647, 0.9403362145723715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 494}], {
             RGBColor[
             0.2685318784304253, 0.3995744085078045, 0.9386038652680744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 327}], {
             RGBColor[
             0.25698076875714937`, 0.3874334598585377, 0.9379460466605166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 470}], {
             RGBColor[
             0.25618724239569113`, 0.386599413340168, 0.9379008565081486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 483}], {
             RGBColor[
             0.2767707745378052, 0.40823401069284493`, 0.939073058213035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 288}], {
             RGBColor[
             0.2504872858476244, 0.38060839761003135`, 0.9375762524150663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 343}], {
             RGBColor[
             0.26889808498261325`, 0.3999593148129905, 0.9386247201894673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 465}], {
             RGBColor[
             0.26376712193927254`, 0.39456634733259277`, 0.9383325194347287]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 324}], {
             RGBColor[
             0.48866791978392093`, 0.5934906203448358, 0.9535163694747727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 353}], {
             RGBColor[
             0.6236604649477651, 0.705354686885191, 0.9635159828256973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 432}], {
             RGBColor[
             0.7531414292760994, 0.8071831282683875, 0.9762245194841053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 441}], {
             RGBColor[
             0.5288953957407483, 0.628333638126909, 0.9560796286709814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 467}], {
             RGBColor[
             0.6572487791197071, 0.7316354395209496, 0.9668355107224047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 292}], {
             RGBColor[
             0.18009239570445779`, 0.3066189047757405, 0.9335673675613205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 386}], {
             RGBColor[
             0.18007057961528944`, 0.30659597468280464`, 0.9335661251673164]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 422}], {
             RGBColor[
             0.207613081778549, 0.3355448907518888, 0.9351346299200334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 442}], {
             RGBColor[
             0.26451897986036277`, 0.3953565976782041, 0.9383753366310607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 444}], {
             RGBColor[
             0.25819284063858217`, 0.3887074242557196, 0.9380150723610645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 464}], {
             RGBColor[
             0.24447969866104266`, 0.37429404257390636`, 0.9372341292122193]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 324}], {
             RGBColor[
             0.3420478957119857, 0.4706864282637755, 0.9430159673470576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 480}], {
             RGBColor[
             0.3339827883337351, 0.46370083761681824`, 0.9425020658366099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 481}], {
             RGBColor[
             0.3163175193458222, 0.44840006950172373`, 0.9413764505174842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 294}], {
             RGBColor[
             0.23070650372322443`, 0.3598175414232626, 0.9364497661361264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 346}], {
             RGBColor[
             0.22049146079372114`, 0.3490808836332252, 0.935868034553093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 358}], {
             RGBColor[
             0.22436323878386594`, 0.35315036778577047`, 0.9360885265818495]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 407}], {
             RGBColor[
             0.21872930348009942`, 0.347228744569382, 0.9357676823009604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 411}], {
             RGBColor[
             0.2313451146629863, 0.3604887620112245, 0.9364861340844057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 295}], {
             RGBColor[
             0.2196997994484176, 0.34824879736508285`, 0.9358229506106359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 299}], {
             RGBColor[
             0.2094890463187735, 0.33751664842668644`, 0.9352414633253583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 300}], {
             RGBColor[
             0.2178846815571592, 0.3463409933762489, 0.9357195823319551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 301}], {
             RGBColor[
             0.20928219811004087`, 0.33729923784437454`, 0.9352296836258756]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 389}], {
             RGBColor[
             0.214155749354975, 0.34242164920379625`, 0.9355072251595016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 451}], {
             RGBColor[
             0.21062876698303812`, 0.3387145671072923, 0.9353063687311225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 456}], {
             RGBColor[
             0.21673512234064032`, 0.34513273375342357`, 0.9356541166351948]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 343}], {
             RGBColor[
             0.274476709135814, 0.40582280250320485`, 0.9389424145821572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 392}], {
             RGBColor[
             0.281033651223698, 0.41271456437171095`, 0.9393158227339358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 465}], {
             RGBColor[
             0.2693457460924733, 0.4004298350228071, 0.9386502138274186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 492}], {
             RGBColor[
             0.26634261157442907`, 0.39727335023461663`, 0.9384791897593554]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 291}], {
             RGBColor[
             0.5471490964494157, 0.6426680909259248, 0.9577289938124869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 297}], {
             RGBColor[
             0.47936763079523015`, 0.5878325714725148, 0.9522613561781106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 314}], {
             RGBColor[
             0.3847232625603534, 0.5076496861015274, 0.9457352039862904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 349}], {
             RGBColor[
             0.42648626116779464`, 0.5438226964259498, 0.9483963053279869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 359}], {
             RGBColor[
             0.4124111574915527, 0.5316315490568694, 0.9474994521678624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 381}], {
             RGBColor[
             0.5043379271734174, 0.6081045829713598, 0.9542271093782111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 397}], {
             RGBColor[
             0.39895955278042317`, 0.5199804451534001, 0.9466423278104561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 419}], {
             RGBColor[
             0.4760307938821983, 0.5851235769437257, 0.9519986681530803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 472}], {
             RGBColor[
             0.3839088844842855, 0.5069443127438695, 0.9456833125354096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 316}], {
             RGBColor[
             0.268490139738015, 0.3995305384956953, 0.9386014883112883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 340}], {
             RGBColor[
             0.31195990105564253`, 0.44256756021982796`, 0.9411741462288754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 355}], {
             RGBColor[
             0.30759602149261944`, 0.4387877870773017, 0.9408960836819469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 362}], {
             RGBColor[
             0.3374733904051481, 0.4646660623491092, 0.9427998432095333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 378}], {
             RGBColor[
             0.28478483318943354`, 0.41665729445637256`, 0.939529446997508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 384}], {
             RGBColor[
             0.2851530200769201, 0.4170442822195179, 0.9395504146960666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 297}], {
             RGBColor[
             0.5871456749634538, 0.6755178075184964, 0.9607730371664382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 311}], {
             RGBColor[
             0.7008920044449292, 0.7662614279396891, 0.9708220228610445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 319}], {
             RGBColor[
             0.6849084125962169, 0.7537749245076777, 0.969228927800723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 349}], {
             RGBColor[
             0.5342643053360183, 0.6315079324719315, 0.9569079863163146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 359}], {
             RGBColor[
             0.5201892016597764, 0.619316785102851, 0.95601113315619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 419}], {
             RGBColor[
             0.583808838050422, 0.6728088129897074, 0.960510349141408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 488}], {
             RGBColor[
             0.7121457205579194, 0.7750529164985673, 0.971943688111231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 308}], {
             RGBColor[
             0.17895845847297373`, 0.30542706484967774`, 0.9335027915134972]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 386}], {
             RGBColor[
             0.17894881608916835`, 0.3054169300929359, 0.9335022423940041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 422}], {
             RGBColor[
             0.20649131825242792`, 0.3343658461620201, 0.9350707471467212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 298}], {
             RGBColor[
             0.9279560632534805, 0.9449120378208546, 0.9763848153450053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 317}], {
             RGBColor[
             0.9188363181868828, 0.7644234365766909, 0.5933539685152149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 353}], {
             RGBColor[
             0.7969674264911133, 0.8418814193634385, 0.9635324755439242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 418}], {
             RGBColor[
             0.9663729017016692, 0.9744415456652006, 0.9418060854539165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 420}], {
             RGBColor[
             0.9614575711812897, 0.9707757002112165, 0.9501264579014013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 432}], {
             RGBColor[
             0.9264483908194477, 0.943709860746635, 0.9762410122023322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 358}], {
             RGBColor[
             0.23196947764628847`, 0.36114500709357467`, 0.9365216906326425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 411}], {
             RGBColor[
             0.23895135352540886`, 0.3684834013190287, 0.9369192981351986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 430}], {
             RGBColor[
             0.23902588418057213`, 0.36856173776312173`, 0.9369235425457519]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 478}], {
             RGBColor[
             0.25217734273393444`, 0.38238475455333876`, 0.9376724986545265]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 300}], {
             RGBColor[
             0.22777276498654234`, 0.3567339960012304, 0.9362826940551499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 336}], {
             RGBColor[
             0.22591321478921644`, 0.3547794908415487, 0.9361767954223702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 389}], {
             RGBColor[
             0.22404383278435813`, 0.3528146518287777, 0.9360703368826964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 409}], {
             RGBColor[
             0.23557177233220394`, 0.3649312472071466, 0.9367268359858879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 456}], {
             RGBColor[
             0.22662320577002346`, 0.355525736378405, 0.9362172283583896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 458}], {
             RGBColor[
             0.2300435692999762, 0.35912075531195864`, 0.936412013001446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 332}], {
             RGBColor[
             0.3578059368755654, 0.48433525149749035`, 0.9440200557957121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 395}], {
             RGBColor[
             0.289203696626415, 0.4208696734674796, 0.9397969170059906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 424}], {
             RGBColor[
             0.31700712622472516`, 0.4489973723195799, 0.9414203916580124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 440}], {
             RGBColor[
             0.29754682970453167`, 0.4296388353177702, 0.94027204609223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 453}], {
             RGBColor[
             0.2988633264806147, 0.4310225569001501, 0.9403470186360454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 311}], {
             RGBColor[
             0.6331105387907436, 0.7114259084862791, 0.9653543852266682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 314}], {
             RGBColor[
             0.42471984107439154`, 0.540499402694099, 0.9487792473402418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 349}], {
             RGBColor[
             0.4664828396818328, 0.5766724130185215, 0.9514403486819383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 359}], {
             RGBColor[
             0.45240773600559087`, 0.5644812656494411, 0.9505434955218137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 381}], {
             RGBColor[
             0.5443345056874556, 0.6409542995639315, 0.9572711527321625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 397}], {
             RGBColor[
             0.4389561312944613, 0.5528301617459719, 0.9496863711644075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 419}], {
             RGBColor[
             0.5160273723962365, 0.6179732935362974, 0.9550427115070317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 353}], {
             RGBColor[
             0.7706511770330843, 0.8213765109750578, 0.9776280646137345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 418}], {
             RGBColor[
             0.9400566522436402, 0.9539366372768199, 0.955901674523727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 420}], {
             RGBColor[
             0.9351413217232607, 0.9502707918228358, 0.9642220469712115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 432}], {
             RGBColor[
             0.9001321413614187, 0.9232049523582542, 0.9903366012721426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 300}], {
             RGBColor[
             0.21756201185689822`, 0.346001847062834, 0.9357012067698722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 301}], {
             RGBColor[
             0.20895952840977988`, 0.3369600915309596, 0.9352113080637927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 389}], {
             RGBColor[
             0.213833079654714, 0.34208250289038133`, 0.9354888495974187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 451}], {
             RGBColor[
             0.21030609728277713`, 0.3383754207938774, 0.9352879931690398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 456}], {
             RGBColor[
             0.21641245264037934`, 0.34479358744000865`, 0.935635741073112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 301}], {
             RGBColor[
             0.2173551636481656, 0.3457844364805221, 0.9356894270703895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 389}], {
             RGBColor[
             0.2222287148930997, 0.35090684783994386`, 0.9359669686040155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 409}], {
             RGBColor[
             0.23375665444094554`, 0.3630234432183127, 0.936623467707207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 451}], {
             RGBColor[
             0.21870173252116284`, 0.3471997657434399, 0.9357661121756364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 456}], {
             RGBColor[
             0.22480808787876505`, 0.3536179323895711, 0.9361138600797088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 458}], {
             RGBColor[
             0.22822845140871784`, 0.35721295132312475`, 0.9363086447227651]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 389}], {
             RGBColor[
             0.21362623144598136`, 0.3418650923080694, 0.9354770698979359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 451}], {
             RGBColor[
             0.2100992490740445, 0.3381580102115655, 0.9352762134695569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 456}], {
             RGBColor[
             0.21620560443164671`, 0.3445761768576967, 0.9356239613736292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 315}], {
             RGBColor[
             0.18782448730516063`, 0.31474582329100176`, 0.934007698739376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 325}], {
             RGBColor[
             0.18458313935535953`, 0.31133896108243087`, 0.9338231087687794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 347}], {
             RGBColor[
             0.18453817917078433`, 0.311291705077802, 0.9338205483527805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 368}], {
             RGBColor[
             0.2991255041617159, 0.42254414020486286`, 0.9406824754328269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 386}], {
             RGBColor[
             0.18453817917078433`, 0.311291705077802, 0.9338205483527805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 421}], {
             RGBColor[
             0.18460298206136966`, 0.31135981702454774`, 0.9338242387815321]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 477}], {
             RGBColor[
             0.21741049289010705`, 0.3458425910218791, 0.9356925779888657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 366}], {
             RGBColor[
             0.2851324087513453, 0.4170226184095053, 0.9395492409115669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 435}], {
             RGBColor[
             0.2816881021628791, 0.4134024338033765, 0.9393530927467486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 473}], {
             RGBColor[
             0.31604489027716914`, 0.44784149062043943`, 0.9413708849892584]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 310}], {
             RGBColor[
             0.317660558842397, 0.44845488439544834`, 0.9415026138990965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 429}], {
             RGBColor[
             0.316081007071654, 0.4467946753350308, 0.9414126607624902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 483}], {
             RGBColor[
             0.3176066092257016, 0.44839817992769826`, 0.941499541548237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 382}], {
             RGBColor[
             0.2666682843502908, 0.39761565297089385`, 0.938497736342151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 416}], {
             RGBColor[
             0.2563227786802443, 0.3867418705687301, 0.9379085750990459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 427}], {
             RGBColor[
             0.26530600013852146`, 0.3961838058905166, 0.9384201562716097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 438}], {
             RGBColor[
             0.23628821482403703`, 0.36568427369114076`, 0.9367676363259161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 460}], {
             RGBColor[
             0.24972906299601538`, 0.37981145731888477`, 0.9375330727453572]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 499}], {
             RGBColor[
             0.2559152551896322, 0.3863135375416151, 0.9378853672391325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 317}], {
             RGBColor[
             0.8704899188810679, 0.5035084402927961, 0.2135951122625132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 357}], {
             RGBColor[
             0.8823608988640697, 0.5565720408834082, 0.22345710970379568`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 418}], {
             RGBColor[
             0.9180265023958543, 0.7135265493813059, 0.5620472292012149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 420}], {
             RGBColor[
             0.9131111718754747, 0.7098607039273219, 0.5703676016486996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 372}], {
             RGBColor[
             0.47013131999468205`, 0.580712810603117, 0.9514296061392018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 417}], {
             RGBColor[
             0.5854211152910297, 0.6734114544902967, 0.9611201594979415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 386}], {
             RGBColor[
             0.17893664238380538`, 0.3054041347567419, 0.9335015491194931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 421}], {
             RGBColor[
             0.1790014452743907, 0.3054722467034876, 0.9335052395482446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 422}], {
             RGBColor[
             0.20647914454706495`, 0.3343530508258261, 0.9350700538722102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 423}], {
             RGBColor[
             0.1833860881198116, 0.31008078433643804`, 0.9337549384717936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 446}], {
             RGBColor[
             0.2035487790418117, 0.3312730508839008, 0.9349031738917732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 320}], {
             RGBColor[
             0.9908166313021023, 0.9885283450055495, 0.6606847997028811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 337}], {
             RGBColor[
             0.926620732552479, 0.9394372573300418, 0.7346744089406012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 348}], {
             RGBColor[
             0.976471187338104, 0.9319682118150352, 0.39079228120582354`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 375}], {
             RGBColor[
             0.9756161016685031, 0.977924558793291, 0.7192291003603996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 489}], {
             RGBColor[
             0.9915641796444485, 0.9888374754562259, 0.6482959890771074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 327}], {
             RGBColor[
             0.2769131154519483, 0.40838362001854456`, 0.939081164317521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 399}], {
             RGBColor[
             0.26912901254486776`, 0.40020203432257306`, 0.938637871172511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 412}], {
             RGBColor[
             0.26956927876194814`, 0.4006647820312149, 0.9386629436822582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 429}], {
             RGBColor[
             0.2951775190785565, 0.4275806662601843, 0.9401212950842925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 483}], {
             RGBColor[
             0.2967031212326041, 0.4291841708528518, 0.9402081758700394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 319}], {
             RGBColor[
             0.7308732764235066, 0.7896830254754603, 0.9738102758609529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 331}], {
             RGBColor[
             0.7917742816822333, 0.837394395727864, 0.9798444828971542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 349}], {
             RGBColor[
             0.5802291691633081, 0.667416033439714, 0.9614893343765445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 377}], {
             RGBColor[
             0.8639809895032101, 0.8937991659736781, 0.9461358346293043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 419}], {
             RGBColor[
             0.6297737018777119, 0.70871691395749, 0.9650916972016379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 484}], {
             RGBColor[
             0.8698742834500395, 0.8946869579845022, 0.7215434088969761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 488}], {
             RGBColor[
             0.7581105843852092, 0.8109610174663499, 0.9765250361714609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 354}], {
             RGBColor[
             0.3330876906173925, 0.4625247982993003, 0.942459704446583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 376}], {
             RGBColor[
             0.2919333190231436, 0.4241708063077816, 0.9399365426905006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 400}], {
             RGBColor[
             0.30016668312241634`, 0.43282459400155193`, 0.9404054205957836]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 414}], {
             RGBColor[
             0.2895347527456831, 0.421649761072285, 0.9397999478893602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 415}], {
             RGBColor[
             0.29571211190112656`, 0.42814255721184813`, 0.9401517393546788]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 379}], {
             RGBColor[
             0.288128547073246, 0.4201206026991259, 0.9397217393007642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 380}], {
             RGBColor[
             0.26990447818225494`, 0.4010170978748282, 0.9386820327933616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 390}], {
             RGBColor[
             0.28385568108857195`, 0.41568069668672125`, 0.9394765331599213]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 411}], {
             RGBColor[
             0.2532739296678089, 0.38353733694846814`, 0.9377349476581557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 478}], {
             RGBColor[
             0.26649991887633445`, 0.3974386901827782, 0.9384881481774836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 359}], {
             RGBColor[
             0.3577633677707141, 0.48429838027845357`, 0.9440173433299934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 373}], {
             RGBColor[
             0.3118454823562334, 0.44312769697598026`, 0.9411427175470836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 397}], {
             RGBColor[
             0.34431176305958455`, 0.4726472763749843, 0.9431602189725873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 398}], {
             RGBColor[
             0.29561326424229706`, 0.426066606556162, 0.9402183167389095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 472}], {
             RGBColor[
             0.3292610947634469, 0.4596111439654538, 0.9422012036975409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 325}], {
             RGBColor[
             0.1822582683189515, 0.30889537421782864`, 0.9336907108025945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 347}], {
             RGBColor[
             0.1822133081343763, 0.30884811821319974`, 0.9336881503865955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 368}], {
             RGBColor[
             0.2968006331253079, 0.42010055334026064`, 0.9405500774666419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 386}], {
             RGBColor[
             0.1822133081343763, 0.30884811821319974`, 0.9336881503865955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 401}], {
             RGBColor[
             0.47947599697395743`, 0.5676241897079666, 0.9559647317614918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 378}], {
             RGBColor[
             0.26678973270236006`, 0.397743302889189, 0.9385046526461347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 357}], {
             RGBColor[
             0.895271303645258, 0.6164935275347583, 0.23428070819651722`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 418}], {
             RGBColor[
             0.9309369071770426, 0.7734480360326559, 0.5728708276939365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 420}], {
             RGBColor[
             0.9260215766566631, 0.7697821905786719, 0.5811912001414211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 321}], {
             RGBColor[
             0.33755888801482614`, 0.46679827542058316`, 0.9427299317460682]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 330}], {
             RGBColor[
             0.32419593809646025`, 0.45501163764918373`, 0.9418862305492528]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 335}], {
             RGBColor[
             0.3093572475376726, 0.43941523304457686`, 0.9410411890738053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 350}], {
             RGBColor[
             0.3520561578815369, 0.47935508192515797`, 0.9436536849625428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 354}], {
             RGBColor[
             0.35185308329442466`, 0.47917918892462685`, 0.9436407452294238]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 383}], {
             RGBColor[
             0.3354424216880899, 0.46496509866505487`, 0.9425950723832464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 479}], {
             RGBColor[
             0.3767164983407358, 0.5007146293661655, 0.94522502005032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 482}], {
             RGBColor[
             0.35021188070592757`, 0.4777576617317112, 0.9435361692517431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 496}], {
             RGBColor[
             0.3094159330482752, 0.43947691523709653`, 0.9410445311268166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 331}], {
             RGBColor[
             0.775790689833521, 0.8249078922958527, 0.9782513878368327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 377}], {
             RGBColor[
             0.8479973976544979, 0.8813126625416667, 0.9445427395689829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 449}], {
             RGBColor[
             0.7215962304048408, 0.7824357266175173, 0.9728856266127364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 488}], {
             RGBColor[
             0.7421269925364968, 0.7984745140343386, 0.9749319411111395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 337}], {
             RGBColor[
             0.9244065988908812, 0.9404637664434601, 0.9125392493325524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 348}], {
             RGBColor[
             0.9742570536765062, 0.9329947209284535, 0.5686571215977747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 361}], {
             RGBColor[
             0.8164019725999951, 0.8557645940777792, 0.9018606390244552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 375}], {
             RGBColor[
             0.9734019680069053, 0.9789510679067093, 0.8970939407523506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 335}], {
             RGBColor[
             0.3049738126003747, 0.4356185220197354, 0.94076188047572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 383}], {
             RGBColor[
             0.3310589867507921, 0.46116838764021345`, 0.942315763785161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 479}], {
             RGBColor[
             0.37233306340343797`, 0.49691791834132404`, 0.9449457114522347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 482}], {
             RGBColor[
             0.3458284457686297, 0.47396095070686983`, 0.9432568606536578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 496}], {
             RGBColor[
             0.3050324981109774, 0.4356802042122551, 0.9407652225287313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 494}], {
             RGBColor[
             0.2588610411681461, 0.3894097453786518, 0.9380531253927091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 342}], {
             RGBColor[
             0.2496659047127254, 0.3797450739586806, 0.9375294759745583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 395}], {
             RGBColor[
             0.25216611947306267`, 0.3823729581945666, 0.9376718595064233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 447}], {
             RGBColor[
             0.24292230663621342`, 0.3726571248114532, 0.9371454380403603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 452}], {
             RGBColor[
             0.23164904535488023`, 0.3608082124387239, 0.9365034424876839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 463}], {
             RGBColor[
             0.25322101360276406`, 0.3834817188090337, 0.9377319341665338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 441}], {
             RGBColor[
             0.4099049258998564, 0.5294607772190044, 0.947339757307013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 481}], {
             RGBColor[
             0.3439470735768655, 0.47233140067487944`, 0.9431369812812307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 347}], {
             RGBColor[
             0.1789719601845752, 0.3054412560046289, 0.9335035604159989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 368}], {
             RGBColor[
             0.2935592851755068, 0.41669369113168975`, 0.9403654874960453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 386}], {
             RGBColor[
             0.1789719601845752, 0.3054412560046289, 0.9335035604159989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 401}], {
             RGBColor[
             0.4762346490241563, 0.5642173274993956, 0.9557801417908952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 421}], {
             RGBColor[
             0.17903676307516053`, 0.3055093679513746, 0.9335072508447505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 405}], {
             RGBColor[
             0.9345940973525277, 0.7578425175728066, 0.403625723074449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 428}], {
             RGBColor[
             0.8527545036662538, 0.3801225472055363, 0.19711821090416948`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 434}], {
             RGBColor[
             0.9331890448533395, 0.7583565146768234, 0.5065076494810187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 469}], {
             RGBColor[
             0.8678030946468546, 0.4926065528105953, 0.21140400054171546`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 474}], {
             RGBColor[
             0.9341363327937491, 0.7587482425843726, 0.49080863680582576`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 475}], {
             RGBColor[
             0.8570894511774583, 0.4134428533627656, 0.20126936153652183`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 491}], {
             RGBColor[
             0.9346684716417725, 0.7580015966571071, 0.4117209054738351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 495}], {
             RGBColor[
             0.8586889913459645, 0.42573762002087545`, 0.2028010830083056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 399}], {
             RGBColor[
             0.24928505714751653`, 0.3793447790205158, 0.9375077872691331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 412}], {
             RGBColor[
             0.2497253233645969, 0.37980752672915763`, 0.9375328597788803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 483}], {
             RGBColor[
             0.27685916583525294`, 0.4083269155507945, 0.9390780919666615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 431}], {
             RGBColor[
             0.4169264678183623, 0.535542483915856, 0.9477871637491544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 433}], {
             RGBColor[
             0.35540962848104596`, 0.48225968960811955`, 0.9438673651437858]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 436}], {
             RGBColor[
             0.42911640965865483`, 0.5455685636524759, 0.9487109542359491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 462}], {
             RGBColor[
             0.4245956854340748, 0.5418984360706564, 0.9483550662650316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 487}], {
             RGBColor[
             0.4823721914903405, 0.5888040064890694, 0.952903444464096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 406}], {
             RGBColor[
             0.9365881325497546, 0.9446037269852596, 0.7033574817962612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 413}], {
             RGBColor[
             0.9281969547806851, 0.9162983140279535, 0.6707593407043844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 486}], {
             RGBColor[
             0.9087427412464592, 0.930070810978078, 0.9911578879759511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 350}], {
             RGBColor[
             0.33430977302587317`, 0.4637717331289171, 0.9425306751676419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 354}], {
             RGBColor[
             0.3341066984387609, 0.463595840128386, 0.9425177354345229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 414}], {
             RGBColor[
             0.2905537605670515, 0.4227208029013707, 0.9398579788773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 415}], {
             RGBColor[
             0.29673111972249494`, 0.4292135990409338, 0.9402097703426187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 482}], {
             RGBColor[
             0.33246549585026375`, 0.4621743129354704, 0.9424131594568423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 496}], {
             RGBColor[
             0.2916695481926115, 0.42389356644085574`, 0.9399215213319159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 377}], {
             RGBColor[
             0.9088984029132244, 0.9290240327940705, 0.9505769466051841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 403}], {
             RGBColor[
             0.8828018353475209, 0.9093862367613971, 0.9886836212135901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 449}], {
             RGBColor[
             0.7824972356635673, 0.8301470968699212, 0.9789198336489376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 488}], {
             RGBColor[
             0.8030279977952235, 0.8461858842867422, 0.9809661481473407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 344}], {
             RGBColor[
             0.4329675168621825, 0.5491533716913533, 0.9488874962659426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 393}], {
             RGBColor[
             0.4317017689879543, 0.548125780545763, 0.9487878519566961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 424}], {
             RGBColor[
             0.36139324266635137`, 0.48744239547023754`, 0.9442486357485711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 392}], {
             RGBColor[
             0.34232526370384136`, 0.4706729127563853, 0.943042932303461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 442}], {
             RGBColor[
             0.331297230301234, 0.4590817504325423, 0.942414902115696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 459}], {
             RGBColor[
             0.3845976264069504, 0.5075408663801063, 0.9457271985616913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 492}], {
             RGBColor[
             0.32763422405457243`, 0.45523169861929097`, 0.9422062993288807]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 340}], {
             RGBColor[
             0.37011932022613914`, 0.4950004852671151, 0.9448046536945134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 355}], {
             RGBColor[
             0.36575544066311605`, 0.49122071212458884`, 0.9445265911475849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 361}], {
             RGBColor[
             0.5235027630627838, 0.6226423570970218, 0.9560294677740079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 363}], {
             RGBColor[
             0.40380771802618465`, 0.5241796822134083, 0.9469512486128518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 369}], {
             RGBColor[
             0.4113757512055576, 0.5307347321729735, 0.9474334769948924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 370}], {
             RGBColor[
             0.49712370807879736`, 0.6012548758448955, 0.9539335150694623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 379}], {
             RGBColor[
             0.3560516389210633, 0.4828157667828796, 0.9439082734813162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 498}], {
             RGBColor[
             0.4323467950368561, 0.5486660596707702, 0.9488340391891498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 383}], {
             RGBColor[
             0.3028573462736385, 0.4337853452642071, 0.940627021112898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 409}], {
             RGBColor[
             0.25916391695491414`, 0.389728087033979, 0.938070373720701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 482}], {
             RGBColor[
             0.3176268052914761, 0.44657790833086347`, 0.9415681179813948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 496}], {
             RGBColor[
             0.27683085763382376`, 0.40829716183624876`, 0.9390764798564684]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 409}], {
             RGBColor[
             0.23189710424361965`, 0.36106893805863094`, 0.9365175690744273]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 456}], {
             RGBColor[
             0.22294853768143919`, 0.3516634272298894, 0.936007961446929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 458}], {
             RGBColor[
             0.22636890121139194`, 0.35525844616344304`, 0.9362027460899854]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 348}], {
             RGBColor[
             0.9100611549268829, 0.8839036332529456, 0.6426467308354947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 361}], {
             RGBColor[
             0.752206073850372, 0.8066735064022713, 0.9758502482621753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 370}], {
             RGBColor[
             0.7258270188663856, 0.785286025150145, 0.9737542955576297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 375}], {
             RGBColor[
             0.9092060692572821, 0.9298599802312014, 0.9710835499900707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 498}], {
             RGBColor[
             0.6610501058244442, 0.7326972089760198, 0.9686548196773171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 369}], {
             RGBColor[
             0.37002637582951403`, 0.49491998150227967`, 0.9447987313597479]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 379}], {
             RGBColor[
             0.31470226354501973`, 0.4470010161121858, 0.9412735278461717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 390}], {
             RGBColor[
             0.3104293975603457, 0.44256111009978116`, 0.9410283217053288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 425}], {
             RGBColor[
             0.3477240886796976, 0.47560286131865376`, 0.9433776493436998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 478}], {
             RGBColor[
             0.29307363534810826`, 0.42431910359583813`, 0.9400399367228911]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 365}], {
             RGBColor[
             0.2143326753092825, 0.34260760959952685`, 0.9355173008308608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 355}], {
             RGBColor[
             0.3330706823231735, 0.4629108172342508, 0.9424439472481606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 362}], {
             RGBColor[
             0.3629480512357022, 0.4887890925060583, 0.944347706775747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 363}], {
             RGBColor[
             0.37112295968624204`, 0.49586978732307024`, 0.9448686047134276]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 378}], {
             RGBColor[
             0.31025949401998754`, 0.4407803246133216, 0.9410773105637218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 379}], {
             RGBColor[
             0.32336688058112073`, 0.45450587189254155`, 0.941825629581892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 380}], {
             RGBColor[
             0.3051428116901297, 0.43540236706824387`, 0.9407859230744895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 498}], {
             RGBColor[
             0.39966203669691347`, 0.5203561647804322, 0.9467513952897255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 387}], {
             RGBColor[
             0.8843435887930974, 0.9064532397024012, 0.7600495256450741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 403}], {
             RGBColor[
             0.9612426733705868, 0.9674078133042042, 0.7674804702008887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 405}], {
             RGBColor[
             0.9937930272646951, 0.989132237877419, 0.5657875066366207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 450}], {
             RGBColor[
             0.9056409272943111, 0.562891578052587, 0.35323513131972123`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 469}], {
             RGBColor[
             0.927002024559022, 0.7238962731152077, 0.3735657841038871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 491}], {
             RGBColor[
             0.9938674015539399, 0.9892913169617195, 0.5738826890360067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 395}], {
             RGBColor[
             0.2624873580585535, 0.3932212343522405, 0.9382596387749628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 447}], {
             RGBColor[
             0.2532435452217043, 0.38350540096912705`, 0.9377332173088998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 453}], {
             RGBColor[
             0.27214698791275327`, 0.40337411778491095`, 0.9388097404050177]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 463}], {
             RGBColor[
             0.2635422521882549, 0.3943299949667075, 0.9383197134350733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 392}], {
             RGBColor[
             0.29944445035868683`, 0.4320654815746701, 0.9403642905083368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 433}], {
             RGBColor[
             0.3091968798489231, 0.4407663035487692, 0.9409764153784905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 465}], {
             RGBColor[
             0.2877565452274621, 0.4197807522257663, 0.9396986816018197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 387}], {
             RGBColor[
             0.6194283934274943, 0.6998852662527452, 0.9645732255440658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 424}], {
             RGBColor[
             0.39216870621134226`, 0.5138154925134429, 0.9462878321282429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 375}], {
             RGBColor[
             0.8089633164388916, 0.8512244424146573, 0.9611785706908804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 426}], {
             RGBColor[
             0.7649497936964772, 0.8167095300211071, 0.9770990522255436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 448}], {
             RGBColor[
             0.6138322543981429, 0.6971096748541594, 0.9629241548523259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 489}], {
             RGBColor[
             0.8249113944148371, 0.8621373590775923, 0.8902454594075883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 498}], {
             RGBColor[
             0.5608073530060538, 0.6540616711594758, 0.9587498403781267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 358}], {
             RGBColor[
             0.2217544347167852, 0.3504083493035373, 0.935939959049609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 404}], {
             RGBColor[
             0.21566548218765702`, 0.3440084741335353, 0.9355932022108733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 407}], {
             RGBColor[
             0.2161204994130187, 0.34448672608714886`, 0.9356191147687198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 408}], {
             RGBColor[
             0.22019359510263653`, 0.34876780790611966`, 0.9358510715426385]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 430}], {
             RGBColor[
             0.22881084125106885`, 0.35782507997308444`, 0.9363418109627185]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 368}], {
             RGBColor[
             0.2935143249909316, 0.4166464351270609, 0.9403629270800464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 386}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 421}], {
             RGBColor[
             0.17899180289058533`, 0.3054621119467458, 0.9335046904287516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 477}], {
             RGBColor[
             0.2117993137193227, 0.3399448859440771, 0.9353730296360853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 375}], {
             RGBColor[
             0.959056524042907, 0.9223909347161948, 0.6272014222552931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 428}], {
             RGBColor[
             0.8951225528654855, 0.5552983535621828, 0.23772264959288408`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 359}], {
             RGBColor[
             0.3995263663781553, 0.520471390602876, 0.94667844467169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 371}], {
             RGBColor[
             0.3882726943942144, 0.5107240255563866, 0.9459613706441047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 397}], {
             RGBColor[
             0.38607476166702576`, 0.5088202866994067, 0.9458213203142838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 419}], {
             RGBColor[
             0.4631460027688009, 0.5739634184897324, 0.951177660656908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 354}], {
             RGBColor[
             0.36196691822383753`, 0.4879392844043602, 0.9442851898478128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 383}], {
             RGBColor[
             0.34555625661750283`, 0.4737251941447882, 0.9432395170016354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 414}], {
             RGBColor[
             0.31841398035212815`, 0.44706424717734483`, 0.94162543329059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 479}], {
             RGBColor[
             0.3868303332701487, 0.5094747248458988, 0.9458694646687091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 482}], {
             RGBColor[
             0.36032571563534044`, 0.4865177572114446, 0.9441806138701323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 356}], {
             RGBColor[
             0.2796916905937343, 0.4113040786644009, 0.9392394000613121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 463}], {
             RGBColor[
             0.27857140569147526`, 0.4101265882019613, 0.9391756014934415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 367}], {
             RGBColor[
             0.2288379775147259, 0.35785360190672644`, 0.9363433563327893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 399}], {
             RGBColor[
             0.23466592421327268`, 0.3639791434000619, 0.936675249275597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 412}], {
             RGBColor[
             0.23510619043035305`, 0.36444189110870373`, 0.9367003217853442]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 457}], {
             RGBColor[
             0.22470998276050042`, 0.3535148176900512, 0.9361082731383572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 418}], {
             RGBColor[
             0.809068015481273, 0.8509060188194038, 0.9430493347226458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 420}], {
             RGBColor[
             0.8041526849608935, 0.8472401733654197, 0.9513697071701304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 432}], {
             RGBColor[
             0.7691435045990516, 0.820174333900838, 0.9774842614710615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 441}], {
             RGBColor[
             0.5448974710637005, 0.6413248437593597, 0.9573393706579376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 372}], {
             RGBColor[
             0.416108457877265, 0.5343687074376324, 0.9478635928798225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 414}], {
             RGBColor[
             0.3182109057650159, 0.4468883541768137, 0.941612493557471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 415}], {
             RGBColor[
             0.32438826492045936`, 0.4533811503163769, 0.9419642850227896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 479}], {
             RGBColor[
             0.38662725868303643`, 0.5092988318453677, 0.9458565249355901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 482}], {
             RGBColor[
             0.3601226410482282, 0.48634186421091347`, 0.9441676741370133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 362}], {
             RGBColor[
             0.3585841716726791, 0.48500931936353203`, 0.9440696442288183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 363}], {
             RGBColor[
             0.366759080123219, 0.492090014180544, 0.9445905421664991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 378}], {
             RGBColor[
             0.30589561445696456`, 0.4370005514707954, 0.940799248016793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 384}], {
             RGBColor[
             0.3062638013444511, 0.43738753923394075`, 0.9408202157153518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 498}], {
             RGBColor[
             0.3952981571338905, 0.516576391637906, 0.946473332742797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 463}], {
             RGBColor[
             0.26821764598055253`, 0.3992441302795001, 0.9385859701949193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 418}], {
             RGBColor[
             0.9428078871600445, 0.8265116366232681, 0.582732825135219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 420}], {
             RGBColor[
             0.937892556639665, 0.822845791169284, 0.5910531975827036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 404}], {
             RGBColor[
             0.21953726017780179`, 0.34807795828608057`, 0.9358136942396298]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 407}], {
             RGBColor[
             0.21999227740316346`, 0.34855621023969413`, 0.9358396067974764]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 408}], {
             RGBColor[
             0.2240653730927813, 0.35283729205866493`, 0.936071563571395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 430}], {
             RGBColor[
             0.23268261924121364`, 0.3618945641256297, 0.936562302991475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 371}], {
             RGBColor[
             0.37419759071797254`, 0.49853287818730624`, 0.94506451748398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 397}], {
             RGBColor[
             0.3719996579907838, 0.4966291393303264, 0.9449244671541592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 419}], {
             RGBColor[
             0.44907089909255904`, 0.561772271120652, 0.9502808074967835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 427}], {
             RGBColor[
             0.3324756951564906, 0.4596914885288097, 0.9425050411722034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 393}], {
             RGBColor[
             0.5202889035975207, 0.6214329965452928, 0.9553781948537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 466}], {
             RGBColor[
             0.5414372478398441, 0.638602175123262, 0.9570430699813932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 468}], {
             RGBColor[
             0.5288716731016017, 0.6284008754780657, 0.9560538619087819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 363}], {
             RGBColor[
             0.5245064025228867, 0.6235116591529769, 0.9560934187929221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 370}], {
             RGBColor[
             0.6178223925754994, 0.7005868527844641, 0.9630756852495326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 498}], {
             RGBColor[
             0.5530454795335582, 0.6479980366103388, 0.95797620936922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 363}], {
             RGBColor[
             0.3966364490357477, 0.5179682894523514, 0.9464943016940854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 384}], {
             RGBColor[
             0.33614117025697976`, 0.4632658145057482, 0.9427239752429382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 498}], {
             RGBColor[
             0.4251755260464191, 0.5424546669097134, 0.9483770922703834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 370}], {
             RGBColor[
             0.4981273475389003, 0.6021241779008506, 0.9539974660883765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 379}], {
             RGBColor[
             0.35705527838116624`, 0.4836850688388347, 0.9439722245002304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 498}], {
             RGBColor[
             0.433350434496959, 0.5495353617267253, 0.948897990208064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 374}], {
             RGBColor[
             0.2551484985501697, 0.3855076276983612, 0.93784170158283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 437}], {
             RGBColor[
             0.25719856867599794`, 0.38766238138256004`, 0.9379584500436889]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 435}], {
             RGBColor[
             0.2615619901606841, 0.3922486140198663, 0.9382069404421383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 473}], {
             RGBColor[
             0.29591877827497415`, 0.42668767083692927`, 0.940224732684648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 416}], {
             RGBColor[
             0.24568937276892794`, 0.3755654867590621, 0.9373030183631108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 457}], {
             RGBColor[
             0.22571706608911693`, 0.3545733261211982, 0.9361656250440755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 499}], {
             RGBColor[
             0.24528184927831587`, 0.3751371537319471, 0.9372798105031974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 386}], {
             RGBColor[
             0.2935143249909316, 0.4166464351270609, 0.9403629270800464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 401}], {
             RGBColor[
             0.5907770138305127, 0.6754225066218276, 0.9626395084549426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 500}], {
             RGBColor[
             0.6137971561371982, 0.33936679556971105`, 0.5567621778131115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 370}], {
             RGBColor[
             0.5056953807182732, 0.6086792278604158, 0.9544796944704173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 379}], {
             RGBColor[
             0.3646233115605392, 0.49024011879839996`, 0.944454452882271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 390}], {
             RGBColor[
             0.36035044557586515`, 0.48580021278599533`, 0.9442092467414281]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 425}], {
             RGBColor[
             0.397645136695217, 0.5188419640048679, 0.9465585743797993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 466}], {
             RGBColor[
             0.46172779849419876`, 0.5729843638939052, 0.9510184053391775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 466}], {
             RGBColor[
             0.5474757553674385, 0.6435045075658272, 0.9575184434137474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 382}], {
             RGBColor[
             0.322584307384319, 0.45137597056269757`, 0.9418655472151594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 419}], {
             RGBColor[
             0.43781722710861815`, 0.5520249060741627, 0.9495637334691982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 427}], {
             RGBColor[
             0.3212220231725497, 0.4499441234823203, 0.9417879671446181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 429}], {
             RGBColor[
             0.3282709430209225, 0.4573529851702918, 0.9421893927020404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 417}], {
             RGBColor[
             0.5857428674141524, 0.6736726673586156, 0.9611454890036907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 398}], {
             RGBColor[
             0.27738327375901567`, 0.40887778620903076`, 0.9391079391375716]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 472}], {
             RGBColor[
             0.31103110428016545`, 0.44242232361832246`, 0.9410908260962028]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 391}], {
             RGBColor[
             0.24642877472957408`, 0.3763426451004932, 0.9373451262109225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 437}], {
             RGBColor[
             0.25378039219455883`, 0.3840696611756612, 0.9377637899498099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 426}], {
             RGBColor[
             0.9141879156308917, 0.9338323693009003, 0.9715587229445324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 489}], {
             RGBColor[
             0.9741495163492516, 0.9792601983573855, 0.8847051301265769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 400}], {
             RGBColor[
             0.2876884645475003, 0.41970919511456195`, 0.9396948045078122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 414}], {
             RGBColor[
             0.27705653417076703`, 0.40853436218529504`, 0.9390893318013886]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 415}], {
             RGBColor[
             0.28323389332621046`, 0.41502715832485815`, 0.9394411232667073]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 464}], {
             RGBColor[
             0.2616609318454717, 0.3923526080038432, 0.9382125750247157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 485}], {
             RGBColor[
             0.26372814560153673`, 0.3945253807303899, 0.938330299789955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 497}], {
             RGBColor[
             0.25772437162935435`, 0.38821503362437043`, 0.9379883937440268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 403}], {
             RGBColor[
             0.9550085431684978, 0.9657910070072111, 0.9549749729457403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 449}], {
             RGBColor[
             0.8547039434845443, 0.8865518671157351, 0.9452111853810878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 484}], {
             RGBColor[
             0.9869984046810305, 0.9863165950507087, 0.692275872605006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 488}], {
             RGBColor[
             0.8752347056162003, 0.9025906545325564, 0.9472574998794909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 380}], {
             RGBColor[
             0.27796774382392075`, 0.40949210130478847`, 0.939141223843122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 380}], {
             RGBColor[
             0.29107513038505384`, 0.42321764858400834`, 0.9398895428612922]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 390}], {
             RGBColor[
             0.30502633329137085`, 0.4378812473959014, 0.9406840432278518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 478}], {
             RGBColor[
             0.2876705710791334, 0.41963924089195836`, 0.9396956582454141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 390}], {
             RGBColor[
             0.2868022644003798, 0.4187777425716037, 0.9396443367204493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 411}], {
             RGBColor[
             0.2562205129796168, 0.38663438283335066`, 0.9379027512186837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 478}], {
             RGBColor[
             0.26944650218814237`, 0.40053573606766074`, 0.9386559517380118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 419}], {
             RGBColor[
             0.5409976687744238, 0.6382453050351424, 0.9570084647071322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 439}], {
             RGBColor[
             0.7151086431122187, 0.7765792866784462, 0.9729163506443089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 416}], {
             RGBColor[
             0.2718791903645599, 0.40309264558241453`, 0.938794489730819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 427}], {
             RGBColor[
             0.2808624118228371, 0.41253458090420103`, 0.9393060709033827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 429}], {
             RGBColor[
             0.2879113316712099, 0.41994344259217253`, 0.9397074964608051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 499}], {
             RGBColor[
             0.27147166687394786`, 0.40266431255529955`, 0.9387712818709056]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 479}], {
             RGBColor[
             0.37021659707670174`, 0.49508474158579574`, 0.9448108520894127]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 482}], {
             RGBColor[
             0.34371197944189347`, 0.47212777395134153`, 0.9431220012908359]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 496}], {
             RGBColor[
             0.30291603178424115`, 0.4338470274567268, 0.9406303631659094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 435}], {
             RGBColor[
             0.2709692417504848, 0.4021362318949472, 0.9387426695033958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 391}], {
             RGBColor[
             0.23729940724147955`, 0.36674710103517516`, 0.9368252222381643]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 421}], {
             RGBColor[
             0.17899180289058533`, 0.3054621119467458, 0.9335046904287516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 403}], {
             RGBColor[
             0.8520128910253049, 0.8851986373727346, 0.9856507029983317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 405}], {
             RGBColor[
             0.8845632449194131, 0.9069230619459494, 0.7839577394340637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 491}], {
             RGBColor[
             0.8846376192086578, 0.9070821410302499, 0.7920529218334498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 487}], {
             RGBColor[
             0.7628017392959624, 0.8144116714200249, 0.9680174393113103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 490}], {
             RGBColor[
             0.9683628300119925, 0.9748687448836537, 0.8911081388957877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 409}], {
             RGBColor[
             0.23002772223876133`, 0.35910409904586005`, 0.9364111105347535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 451}], {
             RGBColor[
             0.21497280031897864`, 0.34328042157098726`, 0.9355537550031829]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 456}], {
             RGBColor[
             0.22107915567658082`, 0.3496985882171184, 0.9359015029072553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 458}], {
             RGBColor[
             0.2244995192065336, 0.35329360715067204`, 0.9360962875503116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 425}], {
             RGBColor[
             0.3380481584260487, 0.4664830926023694, 0.94278816472538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 478}], {
             RGBColor[
             0.2833977050944594, 0.41519933487955374`, 0.9394504521045712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 459}], {
             RGBColor[
             0.34827375514967984`, 0.47582519706689724`, 0.9434219649183455]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 465}], {
             RGBColor[
             0.2943134873153461, 0.42667251409427237`, 0.9400720897535981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 492}], {
             RGBColor[
             0.2913103527973019, 0.4235160293060819, 0.9399010656855349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 468}], {
             RGBColor[
             0.4697942541627981, 0.5804391653761509, 0.9514030710822032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 398}], {
             RGBColor[
             0.24489676758341208`, 0.3747324084550136, 0.93725788067035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 445}], {
             RGBColor[
             0.2291408986849781, 0.35817199126297306`, 0.9363606072453035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 460}], {
             RGBColor[
             0.23849436642390026`, 0.3680030789006874, 0.9368932733958195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 440}], {
             RGBColor[
             0.2733307058970075, 0.4046182804384171, 0.9388771513930672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 447}], {
             RGBColor[
             0.2557437599820415, 0.3861332852050131, 0.9378756008407647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 453}], {
             RGBColor[
             0.2746472026730905, 0.406002002020797, 0.9389521239368825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 463}], {
             RGBColor[
             0.2660424669485921, 0.39695787920259357`, 0.9384620969669382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 422}], {
             RGBColor[
             0.6137790328303492, 0.6759479174311498, 0.7377723993512193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 443}], {
             RGBColor[
             0.9640290207521414, 0.8833364286136021, 0.40253589756085995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 446}], {
             RGBColor[
             0.6108486673250959, 0.6728679174892245, 0.7376055193707824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 419}], {
             RGBColor[
             0.43561929438142943`, 0.5501211672171827, 0.9494236831393772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 472}], {
             RGBColor[
             0.3434973849835166, 0.4719419030173265, 0.9431083275217065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 445}], {
             RGBColor[
             0.2453951867466454, 0.3752562785971719, 0.9372862649043511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 460}], {
             RGBColor[
             0.2547486544855675, 0.3850873662348864, 0.9378189310548671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 472}], {
             RGBColor[
             0.2947988861662292, 0.4253612331985043, 0.9401664252880289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 412}], {
             RGBColor[
             0.24194122045751632`, 0.37162594103318614`, 0.9370895666338703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 414}], {
             RGBColor[
             0.28528989827003975`, 0.41718814987906533`, 0.9395582097066717]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 415}], {
             RGBColor[
             0.2914672574254832, 0.4236809460186285, 0.9399100011719903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 464}], {
             RGBColor[
             0.26989429594474446`, 0.40100639569761354`, 0.9386814529299987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 450}], {
             RGBColor[
             0.7955804305647025, 0.4800334417304184, 0.5713225662708019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 454}], {
             RGBColor[
             0.8366674019364873, 0.7306087240183134, 0.6081129719353302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 471}], {
             RGBColor[
             0.8151324803555211, 0.6303190641854999, 0.5900456312313715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 475}], {
             RGBColor[
             0.806227884360017, 0.5618744373452094, 0.5815185800497742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 500}], {
             RGBColor[
             0.7964725199858478, 0.48689043193741693`, 0.5721768321079614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 431}], {
             RGBColor[
             0.5004255816893457, 0.6051773211877334, 0.9538503277794443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 436}], {
             RGBColor[
             0.5126155235296384, 0.6152034009243532, 0.954774118266239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 459}], {
             RGBColor[
             0.4714286755649022, 0.5800616585296188, 0.952002670562152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 462}], {
             RGBColor[
             0.5080947993050582, 0.6115332733425336, 0.9544182302953215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 487}], {
             RGBColor[
             0.565871305361324, 0.6584388437609466, 0.958966608494386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 405}], {
             RGBColor[
             0.9614623294969025, 0.9678776355477525, 0.7913886839898783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 449}], {
             RGBColor[
             0.8286073759188407, 0.8669140710830616, 0.9833178599894938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 491}], {
             RGBColor[
             0.9615367037861473, 0.968036714632053, 0.7994838663892643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 407}], {
             RGBColor[
             0.2139033248740353, 0.3421563350696921, 0.9354928499587406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 408}], {
             RGBColor[
             0.2179764205636531, 0.3464374168886629, 0.9357248067326592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 434}], {
             RGBColor[
             0.9926076308918226, 0.9901160572249841, 0.6925776468321798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 469}], {
             RGBColor[
             0.9272216806853377, 0.724366095358756, 0.3974739978928766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 474}], {
             RGBColor[
             0.9935549188322322, 0.9905077851325332, 0.6768786341569868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 491}], {
             RGBColor[
             0.9940870576802556, 0.9897611392052678, 0.5977909028249961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 413}], {
             RGBColor[
             0.9822272031257195, 0.951710324271208, 0.3854564695648335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 476}], {
             RGBColor[
             0.9195554041525527, 0.6768776802935997, 0.3060621599750899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 486}], {
             RGBColor[
             0.9627729895914936, 0.9654828212213326, 0.7058550168364002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 493}], {
             RGBColor[
             0.9920978208950986, 0.9843432363296774, 0.4801786397760631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 408}], {
             RGBColor[
             0.2184314377890148, 0.3469156688422765, 0.9357507192905059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 430}], {
             RGBColor[
             0.22704868393744712`, 0.35597294090924125`, 0.9362414587105858]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{408, 430}], {
             RGBColor[
             0.23112177962706493`, 0.36025402272821205`, 0.9364734154845045]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 456}], {
             RGBColor[
             0.23260709522442666`, 0.3618151835954873, 0.9365580020104467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 458}], {
             RGBColor[
             0.23602745875437942`, 0.36541020252904094`, 0.9367527866535031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 496}], {
             RGBColor[
             0.25922260246551676`, 0.38978976922649866`, 0.9380737157737123]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{411, 478}], {
             RGBColor[
             0.2528159536736963, 0.3830559751413007, 0.9377088666028057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 476}], {
             RGBColor[
             0.9111642263834832, 0.6485722673362936, 0.273464018883213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 486}], {
             RGBColor[
             0.9543818118224241, 0.9371774082640264, 0.6732568757445232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 493}], {
             RGBColor[
             0.9837066431260291, 0.9560378233723712, 0.44758049868418615`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 415}], {
             RGBColor[
             0.2808353270487499, 0.4125061130893616, 0.9393045284655668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 485}], {
             RGBColor[
             0.26132957932407624`, 0.39200433549489333`, 0.9381937049888145]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{415, 464}], {
             RGBColor[
             0.2654397247234546, 0.39632435890790974`, 0.9384277716888938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{415, 485}], {
             RGBColor[
             0.2675069384795197, 0.39849713163445644`, 0.9385454964541331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 427}], {
             RGBColor[
             0.2705169061527906, 0.4016607985020373, 0.9387169096602777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 429}], {
             RGBColor[
             0.2775658260011634, 0.4090696601900088, 0.9391183352177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 499}], {
             RGBColor[
             0.26112616120390136`, 0.3917905301531358, 0.9381821206278006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{417, 461}], {
             RGBColor[
             0.8227440842305245, 0.8622334494485463, 0.9748712810946092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 420}], {
             RGBColor[
             0.9735581601714495, 0.9798002996671817, 0.9296433170801228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 432}], {
             RGBColor[
             0.9385489798096075, 0.9527344602026001, 0.9557578713810538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 432}], {
             RGBColor[
             0.933633649289228, 0.949068614748616, 0.9640782438285385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 439}], {
             RGBColor[
             0.9147776569049322, 0.9340333582536569, 0.9622797424419812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 423}], {
             RGBColor[
             0.18344124862659156`, 0.31013876152644193`, 0.9337580797810521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 477}], {
             RGBColor[
             0.21186411660990806`, 0.34001299789082284`, 0.9353767200648369]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 443}], {
             RGBColor[
             0.5842619922483114, 0.5706803433206208, 0.6014015077150748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 446}], {
             RGBColor[
             0.2310816388212659, 0.36021183219624314`, 0.9364711295249972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 446}], {
             RGBColor[
             0.20798858239401255`, 0.3359395657068551, 0.9351560141245807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 477}], {
             RGBColor[
             0.21624875945532895`, 0.3446215355237733, 0.9356264189883857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 440}], {
             RGBColor[
             0.30113413549531765`, 0.4327459792905174, 0.940500626045089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 453}], {
             RGBColor[
             0.3024506322714007, 0.4341297008728973, 0.9405755985889044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 470}], {
             RGBColor[
             0.28803826967359597`, 0.4189813939860375, 0.9397548358601392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{425, 466}], {
             RGBColor[
             0.4394255113443823, 0.5536672437102792, 0.9495973233231294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 448}], {
             RGBColor[
             0.7190568535901429, 0.7797176017404024, 0.9733043071059779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 489}], {
             RGBColor[
             0.9301359936068372, 0.9447452859638352, 0.9006256116612403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 460}], {
             RGBColor[
             0.2639231904685617, 0.39473038525219195`, 0.938341407306589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 499}], {
             RGBColor[
             0.27010938266217854`, 0.4012324654749223, 0.9386937018003643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 495}], {
             RGBColor[
             0.8362679836981737, 0.2797771922017657, 0.1823635681891872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{429, 499}], {
             RGBColor[
             0.2771583025105514, 0.4086413271628938, 0.9390951273577867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 433}], {
             RGBColor[
             0.3870230907643596, 0.509641681699111, 0.9458817470057914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 436}], {
             RGBColor[
             0.46072987194196846`, 0.5729505557434673, 0.9507253360979548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 459}], {
             RGBColor[
             0.41954302397723237`, 0.5378088133487329, 0.9479538883938678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 462}], {
             RGBColor[
             0.4562091477173884, 0.5692804281616477, 0.9503694481270373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 487}], {
             RGBColor[
             0.5139856537736541, 0.6161859985800608, 0.9549178263261018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{432, 467}], {
             RGBColor[
             0.8027318187709938, 0.8464550865365966, 0.9808037893677689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 462}], {
             RGBColor[
             0.3946923083800721, 0.5159976338539112, 0.9464496495216687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 469}], {
             RGBColor[
             0.9258166281861495, 0.7248800924627727, 0.5003559242994462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 474}], {
             RGBColor[
             0.992149866333044, 0.99102178223655, 0.7797605605635565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 495}], {
             RGBColor[
             0.9167025248852594, 0.6580111596730529, 0.4917530067660364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 459}], {
             RGBColor[
             0.4317329658175249, 0.5478348930853527, 0.9488776788806625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 462}], {
             RGBColor[
             0.46839908955768095`, 0.5793065078982675, 0.951293238613832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 487}], {
             RGBColor[
             0.5261755956139467, 0.6262120783166807, 0.9558416168128965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 457}], {
             RGBColor[
             0.22152681415849518`, 0.35016910566479753`, 0.9359269963955489]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 460}], {
             RGBColor[
             0.23490540515407732`, 0.3642308530528161, 0.9366888873608955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 453}], {
             RGBColor[
             0.2829903357512072, 0.4147711638710876, 0.939427253023122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 470}], {
             RGBColor[
             0.2685779731534025, 0.3996228569842277, 0.9386064902943567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 467}], {
             RGBColor[
             0.5784857852356426, 0.6676055963951182, 0.960658898554645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 444}], {
             RGBColor[
             0.27761918641957545`, 0.4091257453730057, 0.939121374014589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 492}], {
             RGBColor[
             0.2802823193946945, 0.4119248669822389, 0.9392730354977699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{443, 446}], {
             RGBColor[
             0.5813316267430582, 0.5676003433786956, 0.6012346277346379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{444, 492}], {
             RGBColor[
             0.2739561801729139, 0.4052756935597544, 0.9389127712277736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{445, 460}], {
             RGBColor[
             0.23899278558713355`, 0.3685269490428458, 0.9369216576298206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 453}], {
             RGBColor[
             0.26540338983624123`, 0.39628616863768357`, 0.9384257024708196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 463}], {
             RGBColor[
             0.2567986541117429, 0.38724204581948013`, 0.9379356755008752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{449, 488}], {
             RGBColor[
             0.7488335383665432, 0.8037137186084069, 0.9756003869232444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 454}], {
             RGBColor[
             0.8587954548220276, 0.3876960227591984, 0.20138137545633958`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 469}], {
             RGBColor[
             0.8390695807149537, 0.298125435533924, 0.18492162257597716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 471}], {
             RGBColor[
             0.8372605332410615, 0.2874063629263848, 0.183314034752381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 475}], {
             RGBColor[
             0.8283559372455574, 0.2189617360860943, 0.17478698357078354`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 491}], {
             RGBColor[
             0.9059349577098716, 0.5635204793804358, 0.38523852750809673`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 500}], {
             RGBColor[
             0.8186005728713881, 0.14397773067830186`, 0.16544523562897076`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{451, 456}], {
             RGBColor[
             0.21755217330464396`, 0.3459915061206145, 0.9357006464788762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{453, 463}], {
             RGBColor[
             0.2757020968027919, 0.407110762635264, 0.939012198596993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 469}], {
             RGBColor[
             0.8801565520867384, 0.5487007178218191, 0.22171202824050545`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 471}], {
             RGBColor[
             0.8783475046128462, 0.5379816452142798, 0.2201044404169093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 475}], {
             RGBColor[
             0.8694429086173421, 0.4695370183739893, 0.21157738923531183`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 500}], {
             RGBColor[
             0.8596875442431727, 0.3945530129661969, 0.20223564129349905`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{456, 458}], {
             RGBColor[
             0.22707889219219896`, 0.35600469170029936`, 0.9362431790260048]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{461, 486}], {
             RGBColor[
             0.9396915520193736, 0.9545227464327241, 0.9862809714214389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{461, 493}], {
             RGBColor[
             0.9690163833229786, 0.9733831615410689, 0.7606045943611018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{462, 487}], {
             RGBColor[
             0.5216548713893666, 0.6225419507348611, 0.9554857288419789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 485}], {
             RGBColor[
             0.24593397699878092`, 0.3758225813134415, 0.9373169482121415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 497}], {
             RGBColor[
             0.23993020302659857`, 0.369512234207422, 0.9369750421662133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 468}], {
             RGBColor[
             0.49094259840512156`, 0.5976083439541202, 0.9530679462098963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 471}], {
             RGBColor[
             0.8586216305057723, 0.4484110579890054, 0.20364468753654688`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 474}], {
             RGBColor[
             0.9267639161265591, 0.7252718203703219, 0.4846569116242533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 475}], {
             RGBColor[
             0.8497170345102683, 0.3799664311487149, 0.19511763635494941`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 491}], {
             RGBColor[
             0.9272960549745825, 0.7245251744430564, 0.40556918029226263`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 495}], {
             RGBColor[
             0.8513165746787745, 0.3922611978068248, 0.19664935782673318`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 475}], {
             RGBColor[
             0.847907987036376, 0.36924735854117574`, 0.19351004853135326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 500}], {
             RGBColor[
             0.8381526226622067, 0.29426335313338325`, 0.18416830058954048`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{474, 495}], {
             RGBColor[
             0.917649812825669, 0.658402887580602, 0.4760539940908434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{476, 493}], {
             RGBColor[
             0.9210348441528622, 0.6812051793947629, 0.36818618909444256`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{479, 482}], {
             RGBColor[
             0.3849860560945393, 0.5078773046524521, 0.9457519489579096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{480, 481}], {
             RGBColor[
             0.33588196619861493`, 0.46534581002792214`, 0.9426230797707831]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{482, 496}], {
             RGBColor[
             0.31768549080207875`, 0.4466395905233832, 0.9415714600344062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{484, 500}], {
             RGBColor[
             0.9061921804601966, 0.5690195539734165, 0.316991474169404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{485, 497}], {
             RGBColor[
             0.24199741678266362`, 0.3716850069339687, 0.9370927669314526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{486, 493}], {
             RGBColor[
             0.9642524295918031, 0.9698103203224957, 0.7679790459557528]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.0315874366232787], {
             RGBColor[
             0.2661654894960651, 0.39708718370006774`, 0.9384691029190212]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.0315874366232787], {
             RGBColor[
             0.2124476857409665, 0.34062636604798524`, 0.9354099534635375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.0315874366232787], {
             RGBColor[
             0.46166603367100856`, 0.5738403098087559, 0.9507631877904368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.0315874366232787], {
             RGBColor[
             0.32430364693803726`, 0.45531725182765653`, 0.9418853195058047]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.0315874366232787], {
             RGBColor[
             0.23860734128045696`, 0.3681218226379481, 0.9368997071467691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.0315874366232787], {
             RGBColor[
             0.8276898195746623, 0.8654414113599355, 0.9834269879500976]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.0315874366232787], {
             RGBColor[
             0.8386821070512293, 0.8742063630160551, 0.9844754421425435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.0315874366232787], {
             RGBColor[
             0.6202936289377985, 0.7026213377380665, 0.963250933161866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.0315874366232787], {
             RGBColor[
             0.5751436787516512, 0.6659665741948753, 0.9596965636934954]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.0315874366232787], {
             RGBColor[
             0.2189624152550279, 0.3474737598249721, 0.9357809576716846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.0315874366232787], {
             RGBColor[
             0.23891813183632316`, 0.3684484832174229, 0.9369174062091523]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.0315874366232787], {
             RGBColor[
             0.27240341106773047`, 0.40364363477895904`, 0.9388243433243495]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.0315874366232787], {
             RGBColor[
             0.29661626096016863`, 0.4290928751992627, 0.9402032293060224]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.0315874366232787], {
             RGBColor[
             0.30674268007373295`, 0.4397363837396738, 0.9407799138938453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.0315874366232787], {
             RGBColor[
             0.23423879357827926`, 0.36353020202103736`, 0.9366509248178173]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.0315874366232787], {
             RGBColor[
             0.4038820814050813, 0.5242440920345965, 0.9469559869815982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.0315874366232787], {
             RGBColor[
             0.8799712561457314, 0.9071292097399156, 0.9884136380424356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.0315874366232787], {
             RGBColor[
             0.8843839202879132, 0.5678962094964264, 0.22523944788984251`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.0315874366232787], {
             RGBColor[
             0.5597245266210166, 0.6534486118703385, 0.9584827115555565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.0315874366232787], {
             RGBColor[
             0.8845340276069948, 0.5685778117739207, 0.22536470111635126`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.0315874366232787], {
             RGBColor[
             0.9808877657874093, 0.9471920876142448, 0.3802530084370154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.0315874366232787], {
             RGBColor[
             0.4514165271362265, 0.5654160397762044, 0.9499848398305268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.0315874366232787], {
             RGBColor[
             0.2225015077722568, 0.35119357045200544`, 0.9359825037549226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.0315874366232787], {
             RGBColor[
             0.8369720141620951, 0.8728427813654944, 0.9843123319561599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.0315874366232787], {
             RGBColor[
             0.3133752819583538, 0.4458516513578495, 0.941188973752873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.0315874366232787], {
             RGBColor[
             0.3866295369467384, 0.5093008051628776, 0.9458566701045386]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.0315874366232787], {
             RGBColor[
             0.5121189165844965, 0.6148002330343991, 0.9547350235483862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.0315874366232787], {
             RGBColor[
             0.9648560740830788, 0.9733102981108331, 0.9443736789601879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.0315874366232787], {
             RGBColor[
             0.40962031041891445`, 0.5292142575946026, 0.9473216218602429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.0315874366232787], {
             RGBColor[
             0.2679312243382506, 0.39894308297325987`, 0.938569658906113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.0315874366232787], {
             RGBColor[
             0.4530382628066378, 0.5668207057031098, 0.9500881753934008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.0315874366232787], {
             RGBColor[
             0.5357107322431658, 0.6339531317852908, 0.9565922576967049]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.0315874366232787], {
             RGBColor[
             0.8784142522519405, 0.5407893411964669, 0.22025821055067316`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.0315874366232787], {
             RGBColor[
             0.5437530683305409, 0.6404822625241338, 0.9572253798535508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.0315874366232787], {
             RGBColor[
             0.23837242809378653`, 0.36787491398440125`, 0.9368863291883112]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.0315874366232787], {
             RGBColor[
             0.254389289460926, 0.3847096508089296, 0.9377984657483468]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.0315874366232787], {
             RGBColor[
             0.305640198745031, 0.4385776059618545, 0.9407171292131508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.0315874366232787], {
             RGBColor[
             0.25996867538836677`, 0.3905739391721695, 0.9381162035229527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.0315874366232787], {
             RGBColor[
             0.6236615875481659, 0.7053555982627691, 0.963516071200913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.0315874366232787], {
             RGBColor[
             0.3862001571816754, 0.5089288979916344, 0.9458293104055944]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.0315874366232787], {
             RGBColor[
             0.23252667542550592`, 0.36173065728791187`, 0.9365534222218687]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.0315874366232787], {
             RGBColor[
             0.23247426890382172`, 0.3616755747108564, 0.9365504377479873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.0315874366232787], {
             RGBColor[
             0.2931478124699098, 0.42544731592366486`, 0.940005706295612]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.0315874366232787], {
             RGBColor[
             0.49667724948997916`, 0.6022639920478948, 0.9535193989500155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.0315874366232787], {
             RGBColor[
             0.28278247170568477`, 0.41455268557990177`, 0.9394154154732368]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.0315874366232787], {
             RGBColor[
             0.9176548470302313, 0.7112359389100995, 0.2526013609126037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.0315874366232787], {
             RGBColor[
             0.23193365260590854`, 0.36110735270469657`, 0.9365196504495912]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.0315874366232787], {
             RGBColor[
             0.20751087662989864`, 0.3354374666604766, 0.9351288094880167]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.0315874366232787], {
             RGBColor[
             0.49021471545548245`, 0.5970174157848499, 0.9530106445977776]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.0315874366232787], {
             RGBColor[
             0.44093802683048844`, 0.5563400894761129, 0.9493171590568191]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.0315874366232787], {
             RGBColor[
             0.17892700081062782`, 0.30539400085202123`, 0.9335010000461641]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.0315874366232787], {
             RGBColor[
             0.8357950446989824, 0.2761419758107905, 0.18191068126945342`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.0315874366232787], {
             RGBColor[
             0.9765123065091236, 0.9324326360618924, 0.36325517537702773`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.0315874366232787], {
             RGBColor[
             0.22872079714307936`, 0.35773043790646125`, 0.9363366830839769]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.0315874366232787], {
             RGBColor[
             0.21147766438726034`, 0.339606812102334, 0.9353547121824619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.0315874366232787], {
             RGBColor[
             0.8366736085240676, 0.28289500235951803`, 0.1827519949805509]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.0315874366232787], {
             RGBColor[
             0.6012429877716181, 0.6871551690177569, 0.9617511969044663]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.0315874366232787], {
             RGBColor[
             0.31511174381280593`, 0.44735568733906544`, 0.9412996195667458]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.0315874366232787], {
             RGBColor[
             0.2421911048281961, 0.37188858535035474`, 0.9371037971791099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.0315874366232787], {
             RGBColor[
             0.29270959820985176`, 0.42498672495195505`, 0.9399807506417815]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.0315874366232787], {
             RGBColor[
             0.3238266917401457, 0.45490413720770817`, 0.94185492834235]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.0315874366232787], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.0315874366232787], {
             RGBColor[
             0.41933559472005666`, 0.5376291485518648, 0.9479406711850231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.0315874366232787], {
             RGBColor[
             0.2878344487965492, 0.41986263381624833`, 0.9397031180948312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.0315874366232787], {
             RGBColor[
             0.9854648277298144, 0.9626315922912277, 0.39803402977763763`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.0315874366232787], {
             RGBColor[
             0.2632810725593861, 0.3940554786170215, 0.9383048396415897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.0315874366232787], {
             RGBColor[
             0.25662307112871396`, 0.38705749697171266`, 0.9379256763097434]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.0315874366232787], {
             RGBColor[
             0.8199864588949732, 0.15463025795470559`, 0.16677236165029033`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.0315874366232787], {
             RGBColor[
             0.9094625081980608, 0.9306447336077317, 0.9912265399903383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.0315874366232787], {
             RGBColor[
             0.2582501634540876, 0.38876767416929214`, 0.9380183368106061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.0315874366232787], {
             RGBColor[
             0.755781538403036, 0.8091415490436711, 0.97629289863413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.0315874366232787], {
             RGBColor[
             0.2539844574642687, 0.3842841467126117, 0.9377754111650324]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.0315874366232787], {
             RGBColor[
             0.24791046842011605`, 0.37789999911405875`, 0.9374295064746294]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.0315874366232787], {
             RGBColor[
             0.2817340129849886, 0.4134506889883278, 0.9393557073001488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.0315874366232787], {
             RGBColor[
             0.3449485107481652, 0.47319879521896346`, 0.9432007919722498]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.0315874366232787], {
             RGBColor[
             0.4113253016274047, 0.530691035284047, 0.9474302623923834]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.0315874366232787], {
             RGBColor[
             0.606817875551374, 0.6916811140631951, 0.9621900724919755]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.0315874366232787], {
             RGBColor[
             0.21942909899518986`, 0.3479642740253404, 0.9358075346202901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.0315874366232787], {
             RGBColor[
             0.9938287149952354, 0.9892085703244617, 0.5696718958667929]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.0315874366232787], {
             RGBColor[
             0.7895429134572223, 0.8355161918319554, 0.9796579169815435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.0315874366232787], {
             RGBColor[
             0.8236181467643259, 0.8621947699835874, 0.9830386281626226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.0315874366232787], {
             RGBColor[
             0.25827862318556116`, 0.3887975871515221, 0.9380199575502111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.0315874366232787], {
             RGBColor[
             0.9207457022290968, 0.9396416462539369, 0.9923027411096448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.0315874366232787], {
             RGBColor[
             0.2333142933423989, 0.36255849365642656`, 0.9365982758970595]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.0315874366232787], {
             RGBColor[
             0.21421555473578224`, 0.34248450845090483`, 0.9355106309874645]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.0315874366232787], {
             RGBColor[
             0.9151930916309041, 0.7014758990831244, 0.2506205747334791]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.0315874366232787], {
             RGBColor[
             0.1792532619022457, 0.3057369219454596, 0.9335195801326717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.0315874366232787], {
             RGBColor[
             0.8666101266120032, 0.4871895635890985, 0.21040855877111306`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.0315874366232787], {
             RGBColor[
             0.28550171685781406`, 0.4174107846448903, 0.9395702724618878]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.0315874366232787], {
             RGBColor[
             0.8647697772859632, 0.4788329671240561, 0.2088729261823753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.0315874366232787], {
             RGBColor[
             0.3276288460270304, 0.4581973721491767, 0.9420971982513973]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.0315874366232787], {
             RGBColor[
             0.6091375885965603, 0.6935643616151592, 0.9623726888002815]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.0315874366232787], {
             RGBColor[
             0.26928527939714464`, 0.4003662806922068, 0.9386467703385721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.0315874366232787], {
             RGBColor[
             0.9554190789968999, 0.9662722026272221, 0.9603480500785777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.0315874366232787], {
             RGBColor[
             0.22708291988077767`, 0.3560089250563658, 0.936243408396911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.0315874366232787], {
             RGBColor[
             0.2961617343973124, 0.4286151389630523, 0.9401773446906796]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.0315874366232787], {
             RGBColor[
             0.2317345075524728, 0.36089803862701, 0.9365083094334068]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.0315874366232787], {
             RGBColor[
             0.9952347378240085, 0.9922159109844932, 0.7227088038116687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.0315874366232787], {
             RGBColor[
             0.9936215336094609, 0.9887654302895413, 0.5471214806005384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.0315874366232787], {
             RGBColor[
             0.9312148525901699, 0.7649968423512695, 0.2635120596803694]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.0315874366232787], {
             RGBColor[
             0.5208327276256995, 0.6218744973903617, 0.9554210066732913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.0315874366232787], {
             RGBColor[
             0.2765375568294345, 0.40798888409449063`, 0.939059776809558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.0315874366232787], {
             RGBColor[
             0.4803557055985901, 0.589013427439692, 0.9522345072271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.0315874366232787], {
             RGBColor[
             0.24657366739272524`, 0.3764949364761905, 0.9373533776337394]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.0315874366232787], {
             RGBColor[
             0.2459052705491277, 0.3757924090147619, 0.9373153134223011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.0315874366232787], {
             RGBColor[
             0.5178553382148801, 0.619457318536794, 0.9551866156723348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.0315874366232787], {
             RGBColor[
             0.18467169248908813`, 0.3114320360405726, 0.9338281517387427]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.0315874366232787], {
             RGBColor[
             0.28511069510105125`, 0.41699979598632125`, 0.939548004351305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.0315874366232787], {
             RGBColor[
             0.25396000439311356`, 0.38425844498441336`, 0.9377740185988052]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.0315874366232787], {
             RGBColor[
             0.27171530098953856`, 0.4029203874580805, 0.9387851564733641]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.0315874366232787], {
             RGBColor[
             0.27309124258507717`, 0.4043665893147275, 0.9388635143117069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.0315874366232787], {
             RGBColor[
             0.24826352560257345`, 0.3782710845979398, 0.937449612558869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.0315874366232787], {
             RGBColor[
             0.17919226069553715`, 0.305672805809509, 0.9335161062041928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.0315874366232787], {
             RGBColor[
             0.5006784839436625, 0.605512374430953, 0.9538343907832142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.0315874366232787], {
             RGBColor[
             0.9211683800910966, 0.9399786781078106, 0.9923430565014513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.0315874366232787], {
             RGBColor[
             0.24872594858728536`, 0.3787571204741826, 0.9374759468637549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.0315874366232787], {
             RGBColor[
             0.38107527345035186`, 0.504489981287708, 0.9455027573459912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.0315874366232787], {
             RGBColor[
             0.32510810483221725`, 0.45601403282236586`, 0.9419365788514676]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.0315874366232787], {
             RGBColor[
             0.9906473743776302, 0.9904004632007044, 0.8046607405893015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.0315874366232787], {
             RGBColor[
             0.20742150462258202`, 0.3353435310142743, 0.9351237198844141]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.0315874366232787], {
             RGBColor[
             0.8274659414661699, 0.21212083852708477`, 0.1739347226073356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.0315874366232787], {
             RGBColor[
             0.867504304657107, 0.49124981725132677`, 0.21115468285025726`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.0315874366232787], {
             RGBColor[
             0.2069635167020156, 0.33486215667164765`, 0.9350976381498702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.0315874366232787], {
             RGBColor[
             0.9626525497894284, 0.8856804222207267, 0.30941263771645156`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.0315874366232787], {
             RGBColor[
             0.20867358600249122`, 0.3366595479311035, 0.9351950240667115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.0315874366232787], {
             RGBColor[
             0.2511378152607278, 0.38129214526915, 0.9376132991027705]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.0315874366232787], {
             RGBColor[
             0.22597981130456574`, 0.35484948800164373`, 0.9361805879953986]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.0315874366232787], {
             RGBColor[
             0.49474321248409076`, 0.6006938536791404, 0.9533671444723009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.0315874366232787], {
             RGBColor[
             0.35559977387920144`, 0.4824243839950162, 0.9438794810404173]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.0315874366232787], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.0315874366232787], {
             RGBColor[
             0.263609049878749, 0.394400203574635, 0.9383235174647285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.0315874366232787], {
             RGBColor[
             0.9901329118562932, 0.9901877197270478, 0.8131867159541827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.0315874366232787], {
             RGBColor[
             0.3451736656290086, 0.4733938130601367, 0.9432151386421606]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.0315874366232787], {
             RGBColor[
             0.2332063867745317, 0.36244507701192663`, 0.9365921307776528]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.0315874366232787], {
             RGBColor[
             0.25062676841059334`, 0.3807550026274169, 0.9375841957406814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.0315874366232787], {
             RGBColor[
             0.968960662006962, 0.9763714930638193, 0.9374256822530368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.0315874366232787], {
             RGBColor[
             0.22008054170119, 0.3486489816131997, 0.9358446333186737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.0315874366232787], {
             RGBColor[
             0.2199663924455993, 0.34852900350809307`, 0.9358381326874365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.0315874366232787], {
             RGBColor[
             0.5640351798749514, 0.6569481943745988, 0.9588220619701494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.0315874366232787], {
             RGBColor[
             0.4996340643500339, 0.6046644675542787, 0.9537521702469687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.0315874366232787], {
             RGBColor[
             0.30958288032569087`, 0.4425668636752852, 0.9409473252743288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.0315874366232787], {
             RGBColor[
             0.6995243049605603, 0.765192970707599, 0.9706857033583209]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.0315874366232787], {
             RGBColor[
             0.17892700134778292`, 0.3053940014166053, 0.9335010000767543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.0315874366232787], {
             RGBColor[
             0.24622776306205768`, 0.3761313690930576, 0.9373336788938276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.0315874366232787], {
             RGBColor[
             0.2206581667895666, 0.3492561022046294, 0.935877528212937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.0315874366232787], {
             RGBColor[
             0.257933230334439, 0.3884345573658211, 0.9380002879383026]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.0315874366232787], {
             RGBColor[
             0.25149316947897704`, 0.3816656450832887, 0.9376335359998004]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.0315874366232787], {
             RGBColor[
             0.23965584235908116`, 0.3692238637503902, 0.9369594177320785]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.0315874366232787], {
             RGBColor[
             0.353874772698637, 0.4809302746734916, 0.9437695654905504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.0315874366232787], {
             RGBColor[
             0.8214446559981496, 0.16583859987576455`, 0.16816873284309014`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.0315874366232787], {
             RGBColor[
             0.30679432383558886`, 0.439790664607788, 0.9407828549296829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.0315874366232787], {
             RGBColor[
             0.20400293554931437`, 0.33175039816847185`, 0.9349290374330113]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.0315874366232787], {
             RGBColor[
             0.24493296406314102`, 0.3747704532501981, 0.9372599420063227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.0315874366232787], {
             RGBColor[
             0.30954120355039927`, 0.44253076534726327`, 0.9409446696670606]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.0315874366232787], {
             RGBColor[
             0.5658891207695752, 0.6584533071119401, 0.9589680109885835]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.0315874366232787], {
             RGBColor[
             0.46730916543215706`, 0.578421658392645, 0.9512074357941471]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.0315874366232787], {
             RGBColor[
             0.3025436094347634, 0.43532289426166115`, 0.9405407830329243]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.0315874366232787], {
             RGBColor[
             0.3575213303529286, 0.48408873963232213`, 0.9440019209197574]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.0315874366232787], {
             RGBColor[
             0.8207501650068003, 0.16050043778835987`, 0.16750368748545852`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.0315874366232787], {
             RGBColor[
             0.42248174875901884`, 0.5403541890501141, 0.948141141338351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.0315874366232787], {
             RGBColor[
             0.9903319581123935, 0.9790495659282263, 0.41694191223350735`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.0315874366232787], {
             RGBColor[
             0.46203141681910903`, 0.5741369443087071, 0.9507919520902978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.0315874366232787], {
             RGBColor[
             0.26699231078344465`, 0.3979562252966011, 0.9385161891681649]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.0315874366232787], {
             RGBColor[
             0.8175247092939038, 0.13570817177533162`, 0.16441498745215766`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.0315874366232787], {
             RGBColor[
             0.4240332554553848, 0.5416980261695123, 0.9482400019731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.0315874366232787], {
             RGBColor[
             0.8381204118994321, 0.2940157670958513, 0.18413745552673064`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.0315874366232787], {
             RGBColor[
             0.9866702547547157, 0.9887558220293171, 0.870571905196646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.0315874366232787], {
             RGBColor[
             0.9107922199972238, 0.6840279095591187, 0.24707953011528597`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.0315874366232787], {
             RGBColor[
             0.4927421843014464, 0.5990693288551774, 0.9532096162037554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.0315874366232787], {
             RGBColor[
             0.29668056881803306`, 0.42916046683523196`, 0.9402068915433929]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.0315874366232787], {
             RGBColor[
             0.26174222518751433`, 0.39243805246062563`, 0.9382172045602823]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.0315874366232787], {
             RGBColor[
             0.3516524550010693, 0.4790054147807936, 0.9436279613719797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.0315874366232787], {
             RGBColor[
             0.984562956112485, 0.9878843998856498, 0.9054952972124768]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.0315874366232787], {
             RGBColor[
             0.2666571079259713, 0.3976039058403079, 0.93849709986132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.0315874366232787], {
             RGBColor[
             0.9557302644442173, 0.966504284224312, 0.9598212942864327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.0315874366232787], {
             RGBColor[
             0.6069446059586334, 0.6917839995169481, 0.9622000491738637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.0315874366232787], {
             RGBColor[
             0.20869655844004803`, 0.3366836934195124, 0.9351963323130457]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.0315874366232787], {
             RGBColor[
             0.9916846362160958, 0.9908293976273234, 0.7874706275783359]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.0315874366232787], {
             RGBColor[
             0.178929137062006, 0.30539624618766587`, 0.9335011217025198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.0315874366232787], {
             RGBColor[
             0.27013094278236094`, 0.4012551265282246, 0.9386949296173133]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.0315874366232787], {
             RGBColor[
             0.4206971967779904, 0.5388084998183378, 0.9480274312641372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.0315874366232787], {
             RGBColor[
             0.3785866605047563, 0.5023344698355566, 0.9453441851296919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.0315874366232787], {
             RGBColor[
             0.2049673414252272, 0.33276404989092045`, 0.9349839589209338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.0315874366232787], {
             RGBColor[
             0.2570318728012019, 0.3874871734490205, 0.9379489569602237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.0315874366232787], {
             RGBColor[
             0.2839447494602888, 0.41577431319265656`, 0.9394816054719256]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.0315874366232787], {
             RGBColor[
             0.23571041014604155`, 0.365076964339635, 0.9367347312042897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.0315874366232787], {
             RGBColor[
             0.26462809617956273`, 0.3954712858480575, 0.938381550644016]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.0315874366232787], {
             RGBColor[
             0.33727714516499796`, 0.4665542439248693, 0.9427119793408126]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.0315874366232787], {
             RGBColor[
             0.2597753641562747, 0.39037075681060074`, 0.9381051947342635]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.0315874366232787], {
             RGBColor[
             0.24810961844878143`, 0.3781093184210272, 0.9374408477741458]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.0315874366232787], {
             RGBColor[
             0.21840138119578575`, 0.34688407745709465`, 0.9357490076119863]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.0315874366232787], {
             RGBColor[
             0.2546146394674752, 0.38494650795382845`, 0.9378112990978443]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.0315874366232787], {
             RGBColor[
             0.2878117179623051, 0.41983874226823964`, 0.9397018236074483]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.0315874366232787], {
             RGBColor[
             0.9865160895376739, 0.9886920707502049, 0.8731268218098209]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.0315874366232787], {
             RGBColor[
             0.2701519252165497, 0.40127718039692006`, 0.9386961245358997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.0315874366232787], {
             RGBColor[
             0.29569933477919436`, 0.42812912764658106`, 0.9401510117164867]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.0315874366232787], {
             RGBColor[
             0.6976256228082208, 0.7637097057796726, 0.9704964604655693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.0315874366232787], {
             RGBColor[
             0.2818794421164257, 0.41360354422620765`, 0.9393639892740411]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.0315874366232787], {
             RGBColor[
             0.3428438781472085, 0.4713758682419251, 0.9430666866439704]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.0315874366232787], {
             RGBColor[
             0.9008280073528754, 0.6425649682443086, 0.23896079721830538`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.0315874366232787], {
             RGBColor[
             0.3044587746178886, 0.4373358542976118, 0.9406498488568703]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.0315874366232787], {
             RGBColor[
             0.23905706042934927`, 0.3685945059772749, 0.9369253179869986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.0315874366232787], {
             RGBColor[
             0.5345666356633387, 0.6330243026408235, 0.956502190222977]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.0315874366232787], {
             RGBColor[
             0.5018930513522051, 0.606498414968846, 0.9539300059787216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.0315874366232787], {
             RGBColor[
             0.9938265629209484, 0.98920396725517, 0.5694376558617151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.0315874366232787], {
             RGBColor[
             0.3427341577200499, 0.4712808339226293, 0.9430596953553738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.0315874366232787], {
             RGBColor[
             0.217062994597398, 0.3454773482835776, 0.9356727884751737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.0315874366232787], {
             RGBColor[
             0.32211852500862637`, 0.45342460903982235`, 0.9417460854686901]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.0315874366232787], {
             RGBColor[
             0.5659235722129052, 0.6584812763456551, 0.9589707231324023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.0315874366232787], {
             RGBColor[
             0.8360637140310553, 0.2782070860287545, 0.182167959325265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.0315874366232787], {
             RGBColor[
             0.2310404057237692, 0.3601684935964447, 0.9364687813610937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.0315874366232787], {
             RGBColor[
             0.21851625165510197`, 0.3470048135930438, 0.9357555493147087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.0315874366232787], {
             RGBColor[
             0.90420589766789, 0.657903179238463, 0.24177939169682186`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.0315874366232787], {
             RGBColor[
             0.19980711485308938`, 0.32734032458634205`, 0.9346900916515217]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.0315874366232787], {
             RGBColor[
             0.28412310253725925`, 0.4159617735847908, 0.9394917624158093]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.0315874366232787], {
             RGBColor[
             0.26588598144981995`, 0.39679340302163035`, 0.9384531853492826]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.0315874366232787], {
             RGBColor[
             0.31971976000988434`, 0.4513469193633465, 0.9415932382841149]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.0315874366232787], {
             RGBColor[
             0.23197293745711564`, 0.3611486435741187, 0.9365218876637508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.0315874366232787], {
             RGBColor[
             0.5262688994117111, 0.6262878265429939, 0.9558489620296395]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.0315874366232787], {
             RGBColor[
             0.3389132056188999, 0.46797131725924984`, 0.9428162276662237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.0315874366232787], {
             RGBColor[
             0.5366100807415061, 0.6346832634114314, 0.9566630577049163]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.0315874366232787], {
             RGBColor[
             0.4427137030371586, 0.5578780909582495, 0.9494303035745394]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.0315874366232787], {
             RGBColor[
             0.38986378476733635`, 0.5121021480670574, 0.9460627535157341]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.0315874366232787], {
             RGBColor[
             0.29896629209325354`, 0.43156290692071464`, 0.9403370601024921]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.0315874366232787], {
             RGBColor[
             0.27424929290791517`, 0.4055837736286615, 0.9389294635644105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.0315874366232787], {
             RGBColor[
             0.1794249922972142, 0.30591742147890744`, 0.9335293599246128]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.0315874366232787], {
             RGBColor[
             0.8456311671254343, 0.35174672299683013`, 0.19132976321333509`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.0315874366232787], {
             RGBColor[
             0.9930813033990235, 0.9876099324950685, 0.48832075610881853`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.0315874366232787], {
             RGBColor[
             0.2909757990296596, 0.42316439208435586`, 0.9398820133433956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.0315874366232787], {
             RGBColor[
             0.2238780227461086, 0.35264037496561385`, 0.936060894246312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.0315874366232787], {
             RGBColor[
             0.2584463601503126, 0.3889738893366137, 0.9380295099222091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.0315874366232787], {
             RGBColor[
             0.3561976264336458, 0.4829422138287328, 0.9439175756765262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.0315874366232787], {
             RGBColor[
             0.8431597968980244, 0.3327506884676198, 0.18896317629255405`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.0315874366232787], {
             RGBColor[
             0.38857864336543946`, 0.5109890231778194, 0.9459808654420111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.0315874366232787], {
             RGBColor[
             0.3570417238501652, 0.48367332858535217`, 0.9439713608175008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.0315874366232787], {
             RGBColor[
             0.28732315690654525`, 0.419325233622076, 0.939674000778084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.0315874366232787], {
             RGBColor[
             0.906092392768253, 0.9279574950433493, 0.9909050953721057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.0315874366232787], {
             RGBColor[
             0.32015392046586916`, 0.45172296732878153`, 0.9416209026044572]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.0315874366232787], {
             RGBColor[
             0.3509305166159243, 0.47838010803725933`, 0.9435819600964633]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.0315874366232787], {
             RGBColor[
             0.2566255537350775, 0.38706010634840704`, 0.9379258176905032]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.0315874366232787], {
             RGBColor[
             0.7054821402904016, 0.7698472769484965, 0.9712795247048629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.0315874366232787], {
             RGBColor[
             0.22500762673968802`, 0.3538276603838957, 0.936125223522647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.0315874366232787], {
             RGBColor[
             0.8393061093521738, 0.30312955729356095`, 0.18527288074652987`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.0315874366232787], {
             RGBColor[
             0.3424410288691568, 0.4710269404450701, 0.9430410174441985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.0315874366232787], {
             RGBColor[
             0.22156287013367681`, 0.3502070027807943, 0.9359290497299955]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.0315874366232787], {
             RGBColor[
             0.29422140859812795`, 0.42657573352434824`, 0.9400668460068708]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.0315874366232787], {
             RGBColor[
             0.4950113815248125, 0.6009115653872759, 0.9533882557215221]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.0315874366232787], {
             RGBColor[
             0.24253965650195108`, 0.3722549352589237, 0.9371236466812941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.0315874366232787], {
             RGBColor[
             0.2895478687563091, 0.421663546831056, 0.9398006948267619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.0315874366232787], {
             RGBColor[
             0.20444533477183996`, 0.332215387801077, 0.934954231414263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.0315874366232787], {
             RGBColor[
             0.25854520282865096`, 0.38907777925853504`, 0.9380351388665158]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.0315874366232787], {
             RGBColor[
             0.7357960105795031, 0.7935287028122899, 0.9743009279960564]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.0315874366232787], {
             RGBColor[
             0.9850318468002165, 0.9880782982349678, 0.8977245650665646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.0315874366232787], {
             RGBColor[
             0.23649824945009773`, 0.365905033400095, 0.9367795974871519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.0315874366232787], {
             RGBColor[
             0.3975855258515599, 0.5187903320882202, 0.9465547760295533]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.0315874366232787], {
             RGBColor[
             0.2893861381019995, 0.4214935576590608, 0.939791484505258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.0315874366232787], {
             RGBColor[
             0.8588534332133313, 0.4519682304874997, 0.20393618366530758`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.0315874366232787], {
             RGBColor[
             0.3734224424883788, 0.497861483750915, 0.945015125724227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.0315874366232787], {
             RGBColor[
             0.8618406991999262, 0.46553270763892984`, 0.20642883162911219`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.0315874366232787], {
             RGBColor[
             0.28557642935408295`, 0.4174893122155148, 0.9395745272280231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.0315874366232787], {
             RGBColor[
             0.8799868165294279, 0.5479299882988189, 0.2215703967308864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.0315874366232787], {
             RGBColor[
             0.47608581392629684`, 0.5855469370236965, 0.9518983657135286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.0315874366232787], {
             RGBColor[
             0.2734006518561467, 0.40469179807630246`, 0.9388811347119643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.0315874366232787], {
             RGBColor[
             0.23478619087952063`, 0.36410555129163547`, 0.9366820982843213]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.0315874366232787], {
             RGBColor[
             0.32101450543653715`, 0.45246836277611585`, 0.9416757383178027]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.0315874366232787], {
             RGBColor[
             0.28952074326414307`, 0.421635036218934, 0.9397991500701115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.0315874366232787], {
             RGBColor[
             0.9890626064851881, 0.9747677448317271, 0.41201072085875556`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.0315874366232787], {
             RGBColor[
             0.40965477924277666`, 0.5292441127573786, 0.9473238181832199]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.0315874366232787], {
             RGBColor[
             0.44893934079834463`, 0.5632704254773366, 0.9498269957075668]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.0315874366232787], {
             RGBColor[
             0.9900230881246451, 0.9901423047916702, 0.8150067794022959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.0315874366232787], {
             RGBColor[
             0.2558053195227897, 0.38619798818543977`, 0.9378791065655412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.0315874366232787], {
             RGBColor[
             0.8205829319400263, 0.15921501115513814`, 0.16734354491185305`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.0315874366232787], {
             RGBColor[
             0.2935414156904733, 0.42586101786436276`, 0.9400281214167392]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.0315874366232787], {
             RGBColor[
             0.4627342609626232, 0.5747075448471798, 0.9508472825558781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.0315874366232787], {
             RGBColor[
             0.4137039619056965, 0.5327513112621616, 0.9475818285219495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.0315874366232787], {
             RGBColor[
             0.6195401563438858, 0.7020096347427746, 0.9631916170392121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.0315874366232787], {
             RGBColor[
             0.7713015318020453, 0.8212658858432957, 0.977839786533559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.0315874366232787], {
             RGBColor[
             0.9483637407407871, 0.9610103429078694, 0.9722908974192511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.0315874366232787], {
             RGBColor[
             0.2785602236563872, 0.4101148351741018, 0.9391749646930856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.0315874366232787], {
             RGBColor[
             0.25689237745970156`, 0.38734055500058817`, 0.9379410129068901]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.0315874366232787], {
             RGBColor[
             0.24490866169442368`, 0.374744909919817, 0.9372585580223763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.0315874366232787], {
             RGBColor[
             0.6076583896248129, 0.6923634812527404, 0.9622562408387412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.0315874366232787], {
             RGBColor[
             0.18121415923057888`, 0.3077979493656092, 0.9336312503346327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.0315874366232787], {
             RGBColor[
             0.24509263407936946`, 0.37493827656091794`, 0.9372690349775362]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.0315874366232787], {
             RGBColor[
             0.3144183414809424, 0.4467550970906198, 0.941255436583311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.0315874366232787], {
             RGBColor[
             0.22310026486080187`, 0.3518229021154584, 0.9360166020853335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.0315874366232787], {
             RGBColor[
             0.20981171601903448`, 0.33785579474010136`, 0.9352598388874411]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.0315874366232787], {
             RGBColor[
             0.2560659100008252, 0.3864718853002457, 0.9378939468077562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.0315874366232787], {
             RGBColor[
             0.439371052281192, 0.5549828548799431, 0.9492173128241592]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.0315874366232787], {
             RGBColor[
             0.2864852402250885, 0.41844453006287885`, 0.9396262826626617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.0315874366232787], {
             RGBColor[
             0.6549271406176395, 0.7303533269719065, 0.9662406748008145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.0315874366232787], {
             RGBColor[
             0.1789706321783367, 0.30543986018587177`, 0.9335034847880083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.0315874366232787], {
             RGBColor[
             0.9542723127115095, 0.9654169462092355, 0.962289226275195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.0315874366232787], {
             RGBColor[
             0.23831274258564697`, 0.36781218073106675`, 0.9368829301869194]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.0315874366232787], {
             RGBColor[
             0.22958788287780074`, 0.3586417999900643, 0.9363860623338308]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.0315874366232787], {
             RGBColor[
             0.3134198204339392, 0.44589022834683273`, 0.9411918117051534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.0315874366232787], {
             RGBColor[
             0.5193642093092683, 0.6206822880650865, 0.955305399532062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.0315874366232787], {
             RGBColor[
             0.9016398137954514, 0.9244071294324739, 0.9904804044148157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.0315874366232787], {
             RGBColor[
             0.2091663766185125, 0.3371775021132715, 0.9352230877632756]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.0315874366232787], {
             RGBColor[
             0.22595764709528393`, 0.3548261920123965, 0.936179325776469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.0315874366232787], {
             RGBColor[
             0.20875268020104726`, 0.3367426809486477, 0.9351995283643099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.0315874366232787], {
             RGBColor[
             0.19014935834156865`, 0.31718941015560403`, 0.934140096705561]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.0315874366232787], {
             RGBColor[
             0.3052585207535403, 0.43817643819301544`, 0.9406953932161773]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.0315874366232787], {
             RGBColor[
             0.3385640468354945, 0.4676688934702948, 0.9427939795772942]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.0315874366232787], {
             RGBColor[
             0.2511118726659751, 0.3812648779572094, 0.9376118217103779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.0315874366232787], {
             RGBColor[
             0.8575795140998795, 0.443586953641446, 0.20277151376979163`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.0315874366232787], {
             RGBColor[
             0.46980956787155936`, 0.580451597734798, 0.9514042766334527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.0315874366232787], {
             RGBColor[
             0.17894628476761076`, 0.30541426951348377`, 0.9335020982389862]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.0315874366232787], {
             RGBColor[
             0.9930307649637, 0.9875018358921313, 0.48281995931092997`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.0315874366232787], {
             RGBColor[
             0.29675707084929953`, 0.4292408753206019, 0.9402112482208989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.0315874366232787], {
             RGBColor[
             0.746856868272219, 0.8021695289074716, 0.9754033709212744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.0315874366232787], {
             RGBColor[
             0.3044115375980597, 0.43728620519477157`, 0.940647158778472]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.0315874366232787], {
             RGBColor[
             0.266957894870447, 0.3979200519899457, 0.9385142292328336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.0315874366232787], {
             RGBColor[
             0.33007547283951477`, 0.4603165173231115, 0.9422530951484216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.0315874366232787], {
             RGBColor[
             0.1854996162687526, 0.3123022364263995, 0.933875300773191]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.0315874366232787], {
             RGBColor[
             0.2504950392509415, 0.38061654692851177`, 0.937576693959915]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.0315874366232787], {
             RGBColor[
             0.8834003236622562, 0.5634299269441462, 0.22441871075523476`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.0315874366232787], {
             RGBColor[
             0.341942322952124, 0.4705949864454246, 0.9430092403441536]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.0315874366232787], {
             RGBColor[
             0.7148896845747944, 0.7771965220434489, 0.9722171808006315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.0315874366232787], {
             RGBColor[
             0.9886024976405045, 0.9895548541189678, 0.8385496400948322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.0315874366232787], {
             RGBColor[
             0.3331754530775283, 0.46300156439574175`, 0.942450623147983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.0315874366232787], {
             RGBColor[
             0.25921854913182885`, 0.38978550891579644`, 0.9380734849423552]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.0315874366232787], {
             RGBColor[
             0.23934466612723454`, 0.36889679780100676`, 0.9369416967060188]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.0315874366232787], {
             RGBColor[
             0.369677449943029, 0.49461775943693126`, 0.9447764981108042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.0315874366232787], {
             RGBColor[
             0.1790169203691504, 0.30548851200925775`, 0.9335061208319979]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.0315874366232787], {
             RGBColor[
             0.8751755113140446, 0.526082975024646, 0.21755572572328788`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.0315874366232787], {
             RGBColor[
             0.2570691600545971, 0.38752636471648727`, 0.9379510804141431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.0315874366232787], {
             RGBColor[
             0.3853130055350487, 0.5081604918248647, 0.9457727818871488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.0315874366232787], {
             RGBColor[
             0.8825578842047201, 0.909191716742005, 0.9886603529358121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.0315874366232787], {
             RGBColor[
             0.3064495532407965, 0.43942828885294294`, 0.9407632207543519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.0315874366232787], {
             RGBColor[
             0.8366916950922476, 0.8726192625482565, 0.984285594873034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.0315874366232787], {
             RGBColor[
             0.40219205331719154`, 0.5227802746481479, 0.946848299886271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.0315874366232787], {
             RGBColor[
             0.3786491349611119, 0.5023885820695944, 0.9453481659468069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.0315874366232787], {
             RGBColor[
             0.4028040785660817, 0.5233103801574531, 0.9468872975939376]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.0315874366232787], {
             RGBColor[
             0.2767721721232211, 0.4082354796437291, 0.9390731378034569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.0315874366232787], {
             RGBColor[
             0.22223854670063217`, 0.35091718169303304`, 0.9359675285109096]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.0315874366232787], {
             RGBColor[
             0.860210700141258, 0.8913726787679522, 0.9865288585702724]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.0315874366232787], {
             RGBColor[
             0.32010532781399464`, 0.4516808788160655, 0.9416178063236486]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.0315874366232787], {
             RGBColor[
             0.21169068579341777`, 0.33983071110654267`, 0.9353668434364056]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.0315874366232787], {
             RGBColor[
             0.3374345618861965, 0.46669059037677707`, 0.9427220097950892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.0315874366232787], {
             RGBColor[
             0.9935733711383794, 0.9886624156338708, 0.5418792928476311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.0315874366232787], {
             RGBColor[
             0.25998714329821626`, 0.39059335011635443`, 0.9381172552430979]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.0315874366232787], {
             RGBColor[
             0.29288750827080284`, 0.425173719706164, 0.9399908823565584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.0315874366232787], {
             RGBColor[
             0.4637429804071734, 0.5755264687345587, 0.9509266926456142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.0315874366232787], {
             RGBColor[
             0.6597251945044771, 0.7341016031348642, 0.9667188999718916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.0315874366232787], {
             RGBColor[
             0.21788265672664042`, 0.34633886515099205`, 0.9357194670208525]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.0315874366232787], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.0315874366232787], {
             RGBColor[
             0.9599116097125079, 0.876434587737939, 0.29876460310071706`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.0315874366232787], {
             RGBColor[
             0.41360147005439724`, 0.5326625379719564, 0.9475752978318146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.0315874366232787], {
             RGBColor[
             0.3621699928109498, 0.4881151774048913, 0.9442981295809318]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.0315874366232787], {
             RGBColor[
             0.290045450304657, 0.422186536586862, 0.9398290313598343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.0315874366232787], {
             RGBColor[
             0.2278308941861094, 0.35679509347557953`, 0.9362860044270709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.0315874366232787], {
             RGBColor[
             0.6396625402707171, 0.7183458925176417, 0.9647757248126534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.0315874366232787], {
             RGBColor[
             0.3617638436367253, 0.48776339140382907`, 0.9442722501146938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.0315874366232787], {
             RGBColor[
             0.32870680276015046`, 0.45913104409172456`, 0.942165884701232]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.0315874366232787], {
             RGBColor[
             0.26933793088281155`, 0.4004216207419397, 0.9386497687627899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.0315874366232787], {
             RGBColor[
             0.9071422836282599, 0.6695571281253704, 0.2441427056377997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.0315874366232787], {
             RGBColor[
             0.22562621270692998`, 0.3544778334560826, 0.9361604510783655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.0315874366232787], {
             RGBColor[
             0.38545126270191343`, 0.5082802432337956, 0.9457815915115654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.0315874366232787], {
             RGBColor[
             0.5793663225363243, 0.6693947066472076, 0.9600289856802787]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.0315874366232787], {
             RGBColor[
             0.6442014475594858, 0.7219743340365904, 0.9651716379540781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.0315874366232787], {
             RGBColor[
             0.38846154058520777`, 0.5108875946353395, 0.9459734037564047]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.0315874366232787], {
             RGBColor[
             0.40481135748628755`, 0.5250489842693634, 0.9470151996317661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.0315874366232787], {
             RGBColor[
             0.2585666750316088, 0.38910034790526005`, 0.938036361676709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.0315874366232787], {
             RGBColor[
             0.2169746648251472, 0.34538450809251103`, 0.9356677582253161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.0315874366232787], {
             RGBColor[
             0.2650062967491503, 0.3958687986259951, 0.9384030886069564]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.0315874366232787], {
             RGBColor[
             0.2298450608433424, 0.3589121103378734, 0.9364007082385077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.0315874366232787], {
             RGBColor[
             0.4081016499818632, 0.5278988702541217, 0.9472248541600927]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.0315874366232787], {
             RGBColor[
             0.4199474238450335, 0.5381590841884939, 0.9479796563958474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.0315874366232787], {
             RGBColor[
             0.591443337591513, 0.6791993715323379, 0.960979732544987]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.0315874366232787], {
             RGBColor[
             0.36294391873403165`, 0.48878551314081686`, 0.9443474434563948]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.0315874366232787], {
             RGBColor[
             0.4704530721178047, 0.5809740234714359, 0.951454935644951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.0315874366232787], {
             RGBColor[
             0.293615491872952, 0.425938876628849, 0.9400323399457455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.0315874366232787], {
             RGBColor[
             0.2517303220687306, 0.38191490749146234`, 0.937647041488951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.0315874366232787], {
             RGBColor[
             0.9582014383733062, 0.9683472816944506, 0.9556382414098691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.0315874366232787], {
             RGBColor[
             0.2794551004482275, 0.4110554074207916, 0.9392259266025292]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.0315874366232787], {
             RGBColor[
             0.9811051107342013, 0.9854288030398846, 0.9168682983373343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.0315874366232787], {
             RGBColor[
             0.2830844261537786, 0.4148700588498662, 0.9394326113323542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.0315874366232787], {
             RGBColor[
             0.3092991992760449, 0.442321153408306, 0.9409292493686947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.0315874366232787], {
             RGBColor[
             0.27285106149406285`, 0.4041141437597107, 0.9388498363538897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.0315874366232787], {
             RGBColor[
             0.5693048020656428, 0.6612263110627765, 0.9592369059322629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.0315874366232787], {
             RGBColor[
             0.28222469603460637`, 0.4139664279845783, 0.9393836509739241]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.0315874366232787], {
             RGBColor[
             0.32894252042405586`, 0.45933521088468515`, 0.942180904422339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.0315874366232787], {
             RGBColor[
             0.28382079992875175`, 0.41564403437615693`, 0.9394745467294715]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.0315874366232787], {
             RGBColor[
             0.2334715870925415, 0.36272381936082626`, 0.9366072335434348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.0315874366232787], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.0315874366232787], {
             RGBColor[
             0.7751138064478154, 0.8242440637709316, 0.9782197584425172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.0315874366232787], {
             RGBColor[
             0.9461721011462925, 0.9593758216867757, 0.9760007715815773]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.0315874366232787], {
             RGBColor[
             0.2184997826909155, 0.34698750366749115`, 0.9357546114315619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.0315874366232787], {
             RGBColor[
             0.30075346730669683`, 0.43344134138349677`, 0.9404388370870089]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.0315874366232787], {
             RGBColor[
             0.2411272273904176, 0.370770382709524, 0.937043210932894]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.0315874366232787], {
             RGBColor[
             0.3060013924465708, 0.4389572434431762, 0.9407376986601153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.0315874366232787], {
             RGBColor[
             0.4612114846587171, 0.5734712864433781, 0.9507274040271213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.0315874366232787], {
             RGBColor[
             0.22864247952174482`, 0.3576481211208147, 0.9363322230113024]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.0315874366232787], {
             RGBColor[
             0.26498757281889074`, 0.39584911858812655`, 0.9384020223068277]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.0315874366232787], {
             RGBColor[
             0.9935460613341791, 0.9886040027241311, 0.5389067891970045]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.0315874366232787], {
             RGBColor[
             0.3585480532796543, 0.48497803542685713`, 0.944067342796753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.0315874366232787], {
             RGBColor[
             0.26115105564507934`, 0.3918166957892125, 0.9381835383293976]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.0315874366232787], {
             RGBColor[
             0.24150095424043594`, 0.3711631933245442, 0.9370644941241232]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.0315874366232787], {
             RGBColor[
             0.295921828646773, 0.42836298280833224`, 0.9401636824130951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[401, 0.0315874366232787], {
             RGBColor[
             0.7734523776791622, 0.8229461429895335, 0.9780541627497925]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[402, 0.0315874366232787], {
             RGBColor[
             0.5523112332770156, 0.6474301663686192, 0.9578991099477285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[403, 0.0315874366232787], {
             RGBColor[
             0.9289119756027943, 0.9461532109745376, 0.9930816475541463]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[404, 0.0315874366232787], {
             RGBColor[
             0.2134483076486736, 0.3416780831160786, 0.9354669374008939]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[405, 0.0315874366232787], {
             RGBColor[
             0.9940126833910108, 0.9896020601209673, 0.5896957204256101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[406, 0.0315874366232787], {
             RGBColor[
             0.990618380894789, 0.9800157372285142, 0.4180546106567104]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[407, 0.0315874366232787], {
             RGBColor[
             0.21435834209939697`, 0.3426345870233057, 0.9355187625165873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[408, 0.0315874366232787], {
             RGBColor[
             0.2225045334786326, 0.3511967506612473, 0.9359826760644245]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[409, 0.0315874366232787], {
             RGBColor[
             0.24155566178660715`, 0.3712206944242289, 0.937067609637945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[410, 0.0315874366232787], {
             RGBColor[
             0.36366501242205085`, 0.4894100882501565, 0.9443933909085572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[411, 0.0315874366232787], {
             RGBColor[
             0.23958996446517072`, 0.3691546219069906, 0.9369556660834778]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[412, 0.0315874366232787], {
             RGBColor[
             0.2423814866745967, 0.372088688741828, 0.9371146391436176]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[413, 0.0315874366232787], {
             RGBColor[
             0.97383602535665, 0.9234049113139019, 0.35285832847295656`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[414, 0.0315874366232787], {
             RGBColor[
             0.2746579678933065, 0.4060133169497984, 0.9389527370002482]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[415, 0.0315874366232787], {
             RGBColor[
             0.2870126862041934, 0.4189989092289247, 0.9396563199308854]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[416, 0.0315874366232787], {
             RGBColor[
             0.26153368469451344`, 0.39221886318025073`, 0.938205328487714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[417, 0.0315874366232787], {
             RGBColor[
             0.7010326627105, 0.7663713112457954, 0.9708360423624304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[418, 0.0315874366232787], {
             RGBColor[
             0.978473490691829, 0.9834661451211657, 0.9213229446326382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[419, 0.0315874366232787], {
             RGBColor[
             0.5126905354832046, 0.6152642990075083, 0.9547800234820015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[420, 0.0315874366232787], {
             RGBColor[
             0.96864282965107, 0.9761344542131977, 0.9379636895276074]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[421, 0.0315874366232787], {
             RGBColor[
             0.17905660578117066`, 0.3055302238934915, 0.9335083808575031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[422, 0.0315874366232787], {
             RGBColor[
             0.23401200432651914`, 0.3632918321381684, 0.9366380095054342]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[423, 0.0315874366232787], {
             RGBColor[
             0.18782589147201245`, 0.31474729915939237`, 0.9340077787046009]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[424, 0.0315874366232787], {
             RGBColor[
             0.3205944320155112, 0.4521045162923272, 0.9416489716108714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[425, 0.0315874366232787], {
             RGBColor[
             0.37534284954540054`, 0.499524843821242, 0.9451374923637511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[426, 0.0315874366232787], {
             RGBColor[
             0.8701743928884773, 0.8993174569073501, 0.9874792044791957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[427, 0.0315874366232787], {
             RGBColor[
             0.2795001276110678, 0.4111027338238238, 0.9392284908328413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[428, 0.0315874366232787], {
             RGBColor[
             0.8303334960184631, 0.23416211938642656`, 0.1766806960850511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[429, 0.0315874366232787], {
             RGBColor[
             0.29359796730781346`, 0.4259204571997668, 0.9400313419476861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[430, 0.0315874366232787], {
             RGBColor[
             0.23973902577549727`, 0.36931129479517677`, 0.9369641549045845]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[431, 0.0315874366232787], {
             RGBColor[
             0.4485399301016759, 0.5629244760068475, 0.9498015456111601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[432, 0.0315874366232787], {
             RGBColor[
             0.898624468927386, 0.9220027752840345, 0.9901927981294695]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[433, 0.0315874366232787], {
             RGBColor[
             0.32550625142704326`, 0.4563588873913744, 0.9419619484004228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[434, 0.0315874366232787], {
             RGBColor[
             0.9912025783926344, 0.990630054329001, 0.7954595732387495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[435, 0.0315874366232787], {
             RGBColor[
             0.25811768357221787`, 0.3886284294137375, 0.93801079227732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[436, 0.0315874366232787], {
             RGBColor[
             0.472919813782261, 0.5829766354800872, 0.9516491265847494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[437, 0.0315874366232787], {
             RGBColor[
             0.2558304623203871, 0.3862244148598601, 0.9378805384106689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[438, 0.0315874366232787], {
             RGBColor[
             0.22146455698209894`, 0.3501036694250721, 0.9359234509414543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[439, 0.0315874366232787], {
             RGBColor[
             0.8609124841587944, 0.891932262294116, 0.986595795356355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[440, 0.0315874366232787], {
             RGBColor[
             0.28167383897512416`, 0.41338744228870766`, 0.9393522804793065]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[441, 0.0315874366232787], {
             RGBColor[
             0.4501324018566838, 0.5643037950010776, 0.9499030165032217]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[442, 0.0315874366232787], {
             RGBColor[
             0.28394532564135605`, 0.4157749187954902, 0.9394816382845851]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[443, 0.0315874366232787], {
             RGBColor[
             0.9345119801701037, 0.7780688545030732, 0.2661650059247154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[444, 0.0315874366232787], {
             RGBColor[
             0.27129304719779485`, 0.4024765719505212, 0.9387611097445928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[445, 0.0315874366232787], {
             RGBColor[
             0.22963931784821143`, 0.3586958614051314, 0.9363889914793045]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[446, 0.0315874366232787], {
             RGBColor[
             0.22815127331601265`, 0.3571318322543179, 0.9363042495445604]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[447, 0.0315874366232787], {
             RGBColor[
             0.2464999471451923, 0.3764174518218997, 0.9373491793747017]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[448, 0.0315874366232787], {
             RGBColor[
             0.5679393142918087, 0.6601177465734548, 0.9591294097327601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[449, 0.0315874366232787], {
             RGBColor[
             0.7283027762348872, 0.7876749311915857, 0.9735540724248413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[450, 0.0315874366232787], {
             RGBColor[
             0.8177084834502429, 0.13712074047130335`, 0.1645909697918113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[451, 0.0315874366232787], {
             RGBColor[
             0.21144581794704176`, 0.3395733394744833, 0.935352898574804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[452, 0.0315874366232787], {
             RGBColor[
             0.22395342458252596`, 0.35271962707644106`, 0.936065188269349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[453, 0.0315874366232787], {
             RGBColor[
             0.2843068325272902, 0.41615488545346746`, 0.9395022255669375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[454, 0.0315874366232787], {
             RGBColor[
             0.8998824261938122, 0.6382713050470934, 0.23817178112086787`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[455, 0.0315874366232787], {
             RGBColor[
             0.20394063923757638`, 0.33168492079502093`, 0.9349254897502168]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[456, 0.0315874366232787], {
             RGBColor[
             0.22365852866224617`, 0.35240967276674573`, 0.9360483943829485]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[457, 0.0315874366232787], {
             RGBColor[
             0.22158907133489145`, 0.35023454190452297`, 0.9359305418496434]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[458, 0.0315874366232787], {
             RGBColor[
             0.2304992557221517, 0.359599710633853, 0.9364379636690613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[459, 0.0315874366232787], {
             RGBColor[
             0.3905461178527888, 0.5126931506906183, 0.9461062311765757]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[460, 0.0315874366232787], {
             RGBColor[
             0.24834625332605567`, 0.3783580366805602, 0.9374543237803367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[461, 0.0315874366232787], {
             RGBColor[
             0.944455505750549, 0.9580955876512972, 0.9789065198267879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[462, 0.0315874366232787], {
             RGBColor[
             0.46387836533310084`, 0.575636380316448, 0.9509373506429145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[463, 0.0315874366232787], {
             RGBColor[
             0.2670973610782935, 0.3980666398170606, 0.9385221716270487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[464, 0.0315874366232787], {
             RGBColor[
             0.24386676324271586`, 0.3736498085868948, 0.9371992234469022]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[465, 0.0315874366232787], {
             RGBColor[
             0.28262558218412137`, 0.4143877847453685, 0.939406480847081]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[466, 0.0315874366232787], {
             RGBColor[
             0.503508173143364, 0.6078096435993164, 0.9540571542825077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[467, 0.0315874366232787], {
             RGBColor[
             0.7068391686146014, 0.7709073977891587, 0.9714147806060683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[468, 0.0315874366232787], {
             RGBColor[
             0.4783770236668791, 0.5874070443089239, 0.952078738137285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[469, 0.0315874366232787], {
             RGBColor[
             0.8604306779796645, 0.4591301305965446, 0.20525227536014304`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[470, 0.0315874366232787], {
             RGBColor[
             0.25548210733168075`, 0.3858582716797478, 0.937860700109407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[471, 0.0315874366232787], {
             RGBColor[
             0.8568125830318801, 0.4376919853814662, 0.20203709971295072`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[472, 0.0315874366232787], {
             RGBColor[
             0.32844671668737896`, 0.45890577060779597`, 0.9421493122466601]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[473, 0.0315874366232787], {
             RGBColor[
             0.32683125980079797`, 0.4575065430478635, 0.9420463767623395]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[474, 0.0315874366232787], {
             RGBColor[
             0.9930971542734537, 0.9914135101440991, 0.7640615478883636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[475, 0.0315874366232787], {
             RGBColor[
             0.839003391040872, 0.30080273170088523`, 0.1849829973497558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[476, 0.0315874366232787], {
             RGBColor[
             0.8484924274103163, 0.3737396233586853, 0.19406970929346942`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[477, 0.0315874366232787], {
             RGBColor[
             0.24467162743864543`, 0.3744957718881542, 0.9372450592721705]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[478, 0.0315874366232787], {
             RGBColor[
             0.2660419428822219, 0.39695732837561076`, 0.9384620671221336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[479, 0.0315874366232787], {
             RGBColor[
             0.41149067372934756`, 0.5308342722869064, 0.9474407997564864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[480, 0.0315874366232787], {
             RGBColor[
             0.35354723518652786`, 0.48064657814301665`, 0.9437486950899088]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[481, 0.0315874366232787], {
             RGBColor[
             0.318216697210702, 0.4500450419128276, 0.9414974644516573]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[482, 0.0315874366232787], {
             RGBColor[
             0.35848143845973107`, 0.48492033701799786`, 0.9440630981593326]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[483, 0.0315874366232787], {
             RGBColor[
             0.29664917161590876`, 0.42912746638510174`, 0.9402051035191799]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[484, 0.0315874366232787], {
             RGBColor[
             0.9928916986278599, 0.9872043870615327, 0.4676834468726777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[485, 0.0315874366232787], {
             RGBColor[
             0.24800119075484597`, 0.3779953540399882, 0.9374346729773807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[486, 0.0315874366232787], {
             RGBColor[
             0.9349275982881982, 0.9509499052141509, 0.9936554230160899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[487, 0.0315874366232787], {
             RGBColor[
             0.5794313774456323, 0.6694475211532741, 0.9600341070410434]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[488, 0.0315874366232787], {
             RGBColor[
             0.7693643004981994, 0.8197525060252281, 0.9776467014216474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[489, 0.0315874366232787], {
             RGBColor[
             0.9900975943251971, 0.9901731150203205, 0.8137720188432849]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[490, 0.0315874366232787], {
             RGBColor[
             0.9905535588776926, 0.9903616680805318, 0.806215506209998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[491, 0.0315874366232787], {
             RGBColor[
             0.9941614319695004, 0.9899202182895682, 0.6058860852243823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[492, 0.0315874366232787], {
             RGBColor[
             0.2766193131480329, 0.4080748151689876, 0.9390644327109545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[493, 0.0315874366232787], {
             RGBColor[
             0.9935772608954081, 0.9886707354308406, 0.5423026688954158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[494, 0.0315874366232787], {
             RGBColor[
             0.2585035332044634, 0.3890339818415072, 0.938032765843063]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[495, 0.0315874366232787], {
             RGBColor[
             0.8422024713778844, 0.3253922650171049, 0.18804644029332332`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[496, 0.0315874366232787], {
             RGBColor[
             0.27688954314442643`, 0.4083588440287685, 0.9390798219094797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[497, 0.0315874366232787], {
             RGBColor[
             0.23599364281048124`, 0.36537465982794926`, 0.9367508608855244]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[498, 0.0315874366232787], {
             RGBColor[
             0.46188951150763047`, 0.5740217391840874, 0.9507807807843619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[499, 0.0315874366232787], {
             RGBColor[
             0.2607186377132893, 0.3913621971260208, 0.9381589127678872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[500, 0.0315874366232787], {
             RGBColor[
             0.8194926622925333, 0.15083472088530037`, 0.16629950146613023`]},
             StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{{3.8349502435193233`*^9, 3.8349502581408367`*^9}, 
   3.8349577843740606`*^9, 3.83501892289773*^9, 3.8350190217900667`*^9, 
   3.835020556050778*^9, 3.835044646730012*^9, 3.835045035421321*^9, 
   3.83504571337293*^9, 3.835052529043171*^9},
 CellLabel->
  "Out[430]=",ExpressionUUID->"04650c25-0ae7-4c7f-b84d-3f8feb127643"]
}, Open  ]],

Cell["Estimated with Max-Min Deviation v Calculated: (r = 6)", "Text",
 CellChangeTimes->{{3.834950304741125*^9, 3.8349503319477153`*^9}, {
  3.834950373300777*^9, 3.8349503922098827`*^9}, {3.8349504781120467`*^9, 
  3.834950521977162*^9}},ExpressionUUID->"5c2c9b03-7caf-4568-bcb5-\
5ce44ff51702"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ColorGraph", "[", 
     RowBox[{"graphinf5", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"pointsif5", ",", "#"}], "}"}], "]"}], ",", "500", ",", "1"}],
      "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"mMDi6f500", ",", "krif5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.834891108526765*^9, 3.8348911122170715`*^9}, {
   3.8348911424153953`*^9, 3.8348911456599283`*^9}, {3.8348913453308225`*^9, 
   3.834891380561963*^9}, {3.834891760127005*^9, 3.834891832550042*^9}, {
   3.834891946875697*^9, 3.834891950670034*^9}, {3.834892049723733*^9, 
   3.834892116823455*^9}, 3.8348924588202753`*^9, {3.8349461156947384`*^9, 
   3.834946127076513*^9}, {3.8349470040174994`*^9, 3.834947049243146*^9}, {
   3.834947160403054*^9, 3.834947211216423*^9}, {3.8349472477484217`*^9, 
   3.8349473063808975`*^9}, {3.8349497859358425`*^9, 
   3.8349497932388773`*^9}, {3.8349502405920362`*^9, 
   3.8349502554527807`*^9}, {3.8349505249112787`*^9, 3.834950525026289*^9}, {
   3.834957796266032*^9, 3.834957804349044*^9}, {3.835018837121126*^9, 
   3.835018838508815*^9}, {3.8350443533371973`*^9, 3.835044357496614*^9}, {
   3.8350449455086536`*^9, 3.835044948398612*^9}, {3.8350456133625484`*^9, 
   3.835045615019519*^9}, {3.8350524637401447`*^9, 3.8350524649456854`*^9}},
 CellLabel->
  "In[431]:=",ExpressionUUID->"b3d6a761-e058-443d-8323-6c5793fd1927"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1dOWGAgQBNBMbNu2bds2J+bEtm3btm3btu01sjdnH271F1R1ssCg6p0C
ggUL9l38vMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEIS
kZgkJCUZyUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpR
mCIUpRjFKUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGY
JjSlGYE0pwUtaUVr2tCWdrSnAx3pRBCd6UJXutGdHvSkF73pQ1/60Z8BDGQQ
gxnCUIYxnBGMZBSjGcNYxjGeCUxkEpOZwlSmMZ0ZzGQWs5nDXOYxnwUsZBGL
WcJSlrGcFaxkFatZw1rWsZ4NbGQTm9nCVraxnR3sZBe72cNe9rGfAxzkEIc5
wlGOcZwTnOQUpznDWc5xngtc5BKXucJVrnGdG9zkFre5w13ucZ8HPOQRj3nC
U57xnBe85BWvecNb3vGeD3zkE5/5wle+8Z1f+JXf+J0/+JO/+Jt/+Jcf/Cx/
AMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEISkZgkJCUZ
yUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpRmCIUpRjF
KUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGYJjSlGYE0
pwUtaUVr2tCWdrSnAx35Od5BdKYLXelGd3rQk170pg996Ud/BjCQQQxmCEMZ
xnBGMJJRjGYMYxnHeCYwkUlMZgpTmcZ0ZjCTWcxmDnOZx3wWsJBFLGYJS1nG
clawklWsZg1rWcd6NrCRTWxmC1vZxnZ2sJNd7GYPe9nHfg5wkEMc5ghHOcZx
TnCSU5zmDGc5x3kucJFLXOYKV7nGdW5wk1vc5g53ucd9HvCQRzzmCU95xnNe
8JJXvOYNb3nHez7wkU985gtf+Rbw/z//Dz189+A=
          "], {Null, CompressedData["
1:eJw13A2c1mO6wPH7tsdpl2O9LLLYQ3Ioas/uCqvVrqQihdKSUmmVzEwspdpK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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[196, 330] -> 
             RGBColor[
              0.7908941153846153, 0.8374409999999999, 0.9762013461538461], 
             UndirectedEdge[136, 319] -> 
             RGBColor[
              0.5367175769230769, 0.6341666153846153, 0.9568383846153846], 
             UndirectedEdge[60, 188] -> 
             RGBColor[
              0.4143947692307692, 0.5333496538461537, 0.9476258461538463], 
             UndirectedEdge[145, 408] -> 
             RGBColor[
              0.5960996923076924, 0.6817237692307693, 0.9622049230769231], 
             UndirectedEdge[398, 460] -> 
             RGBColor[
              0.36491803846153836`, 0.4895721153846153, 0.9445070384615385], 
             UndirectedEdge[413, 476] -> 
             RGBColor[
              0.5332968846153847, 0.6319934615384615, 0.9564022307692308], 
             UndirectedEdge[244, 274] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[198, 223] -> 
             RGBColor[
              0.8965358846153847, 0.9187061538461538, 0.9252800384615385], 
             UndirectedEdge[36, 310] -> 
             RGBColor[
              0.6192293461538461, 0.7011293846153845, 0.9635964615384616], 
             UndirectedEdge[252, 432] -> 
             RGBColor[
              0.6628541923076923, 0.7365459999999999, 0.9670307692307691], 
             UndirectedEdge[469, 475] -> 
             RGBColor[
              0.7801278461538461, 0.8289524615384615, 0.9785094999999999], 
             UndirectedEdge[113, 347] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[35, 131] -> 
             RGBColor[
              0.9209065769230769, 0.9393851538461538, 0.9789778846153847], 
             UndirectedEdge[156, 479] -> 
             RGBColor[
              0.8621086153846154, 0.8929964615384616, 0.9866805769230769], 
             UndirectedEdge[318, 354] -> 
             RGBColor[
              0.9244282307692308, 0.7249805384615385, 0.2836043076923077], 
             UndirectedEdge[6, 77] -> 
             RGBColor[
              0.8282616923076923, 0.8663391538461538, 0.9833643076923078], 
             UndirectedEdge[23, 202] -> 
             RGBColor[
              0.5332968846153847, 0.6319934615384615, 0.9564022307692308], 
             UndirectedEdge[342, 395] -> 
             RGBColor[
              0.7858253461538462, 0.8326119999999999, 0.9792873846153847], 
             UndirectedEdge[53, 418] -> 
             RGBColor[
              0.9823486538461539, 0.9554546153846154, 0.5666723076923077], 
             UndirectedEdge[75, 149] -> 
             RGBColor[
              0.9161076153846155, 0.9327281538461538, 0.8631903461538462], 
             UndirectedEdge[293, 418] -> 
             RGBColor[
              0.7203436153846154, 0.7494359230769231, 0.6500958076923078], 
             UndirectedEdge[282, 432] -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 
             UndirectedEdge[466, 468] -> 
             RGBColor[
              0.6795264230769231, 0.747472923076923, 0.9703673846153846], 
             UndirectedEdge[105, 190] -> 
             RGBColor[
              0.8411746923076924, 0.6892903846153846, 0.5997989615384616], 
             UndirectedEdge[64, 473] -> 
             RGBColor[
              0.5756045000000001, 0.6657127692307692, 0.9601621538461538], 
             UndirectedEdge[214, 273] -> 
             RGBColor[
              0.8942031153846154, 0.9180925384615385, 0.9764308846153846], 
             UndirectedEdge[30, 64] -> 
             RGBColor[
              0.5332968846153847, 0.6319934615384615, 0.9564022307692308], 
             UndirectedEdge[296, 395] -> 
             RGBColor[
              0.8487568846153847, 0.8823501538461538, 0.9854070769230769], 
             UndirectedEdge[114, 203] -> 
             RGBColor[
              0.6192293461538461, 0.7011293846153845, 0.9635964615384616], 
             UndirectedEdge[81, 237] -> 
             RGBColor[
              0.45972996153846146`, 0.5698528461538461, 0.9512782307692307], 
             UndirectedEdge[382, 427] -> 
             RGBColor[
              0.8581047307692309, 0.8877424615384616, 0.8787814230769231], 
             UndirectedEdge[39, 450] -> 
             RGBColor[
              0.5987341538461537, 0.6851183846153845, 0.9615536923076923], 
             UndirectedEdge[50, 57] -> 
             RGBColor[
              0.5367175769230769, 0.6341666153846153, 0.9568383846153846], 
             UndirectedEdge[74, 153] -> 
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484], 
             UndirectedEdge[239, 332] -> 
             RGBColor[
              0.8182860769230769, 0.855282923076923, 0.7882518461538461], 
             UndirectedEdge[14, 72] -> 
             RGBColor[
              0.5777079615384616, 0.6661886153846155, 0.9609239230769231], 
             UndirectedEdge[331, 403] -> 
             RGBColor[
              0.6964478076923077, 0.7615969230769231, 0.9712546923076923], 
             UndirectedEdge[214, 302] -> 
             RGBColor[
              0.7605678461538462, 0.8130245384615384, 0.9767317692307692], 
             UndirectedEdge[128, 197] -> 
             RGBColor[
              0.6928781538461538, 0.7581192307692307, 0.9716408846153846], 
             UndirectedEdge[191, 212] -> 
             RGBColor[
              0.5982031538461539, 0.6821996153846153, 0.9629666923076923], 
             UndirectedEdge[404, 407] -> 
             RGBColor[
              0.7076340769230769, 0.7677646153846154, 0.9301658846153846], 
             UndirectedEdge[60, 116] -> 
             RGBColor[
              0.6311015769230769, 0.7068428846153846, 0.9667499615384616], 
             UndirectedEdge[272, 357] -> 
             RGBColor[
              0.8797716538461539, 0.903315923076923, 0.7943801538461538], 
             UndirectedEdge[228, 490] -> 
             RGBColor[
              0.7478382307692306, 0.8010080769230769, 0.9331640384615385], 
             UndirectedEdge[111, 415] -> 
             RGBColor[
              0.6628541923076923, 0.7365459999999999, 0.9670307692307691], 
             UndirectedEdge[227, 428] -> 
             RGBColor[
              0.5777079615384616, 0.6661886153846155, 0.9609239230769231], 
             UndirectedEdge[367, 499] -> 
             RGBColor[
              0.6444533076923077, 0.7174891923076923, 0.9680234615384615], 
             UndirectedEdge[434, 495] -> 
             RGBColor[
              0.6796025384615385, 0.7407032307692307, 0.8128775769230772], 
             UndirectedEdge[226, 283] -> 
             RGBColor[0.6010684615384616, 0.681748, 0.9644135384615384], 
             UndirectedEdge[9, 34] -> 
             RGBColor[
              0.6661746923076923, 0.7368266153846154, 0.9690938846153846], 
             UndirectedEdge[127, 386] -> 
             RGBColor[
              0.7203436153846154, 0.7494359230769231, 0.6500958076923078], 
             UndirectedEdge[326, 469] -> 
             RGBColor[0.9178966923076922, 0.937369923076923, 0.992031], 
             UndirectedEdge[192, 483] -> 
             RGBColor[
              0.7182602307692308, 0.7793052307692308, 0.9729718461538461], 
             UndirectedEdge[16, 39] -> 
             RGBColor[
              0.47641134615384606`, 0.584301423076923, 0.9523411538461539], 
             UndirectedEdge[209, 421] -> 
             RGBColor[
              0.5947316923076922, 0.6655314999999999, 0.9526924615384615], 
             UndirectedEdge[293, 317] -> 
             RGBColor[
              0.6528229615384615, 0.7261803076923077, 0.9678203846153846], 
             UndirectedEdge[3, 381] -> 
             RGBColor[
              0.7605678461538462, 0.8130245384615384, 0.9767317692307692], 
             UndirectedEdge[211, 497] -> 
             RGBColor[0.6815805, 0.658122153846154, 0.6064504230769232], 
             UndirectedEdge[196, 479] -> 
             RGBColor[0.8728748846153846, 0.901485, 0.9843724230769231], 
             UndirectedEdge[221, 439] -> 
             RGBColor[
              0.8260418461538462, 0.6006921153846154, 0.5863931538461538], 
             UndirectedEdge[379, 390] -> 
             RGBColor[0.9730013076923076, 0.979385, 0.9305859230769231], 
             UndirectedEdge[119, 320] -> 
             RGBColor[
              0.7025273461538463, 0.7668706923076923, 0.9714419230769231], 
             UndirectedEdge[179, 401] -> 
             RGBColor[
              0.703844576923077, 0.7685680000000001, 0.9711163076923077], 
             UndirectedEdge[59, 342] -> 
             RGBColor[
              0.8282616923076923, 0.8663391538461538, 0.9833643076923078], 
             UndirectedEdge[86, 98] -> 
             RGBColor[
              0.8487568846153847, 0.8823501538461538, 0.9854070769230769], 
             UndirectedEdge[328, 431] -> 
             RGBColor[
              0.7801278461538461, 0.8289524615384615, 0.9785094999999999], 
             UndirectedEdge[270, 375] -> 
             RGBColor[
              0.9005875000000001, 0.9200127692307692, 0.8313241153846156], 
             UndirectedEdge[39, 45] -> 
             RGBColor[
              0.5769217307692307, 0.6674100769230769, 0.9598365384615384], 
             UndirectedEdge[59, 463] -> 
             RGBColor[0.9056695, 0.8185944615384615, 0.6220448076923077], 
             UndirectedEdge[2, 55] -> 
             RGBColor[
              0.6528229615384615, 0.7261803076923077, 0.9678203846153846], 
             UndirectedEdge[193, 496] -> 
             RGBColor[
              0.5572127692307692, 0.6501776153846154, 0.9588811538461539], 
             UndirectedEdge[201, 246] -> 
             RGBColor[
              0.6192293461538461, 0.7011293846153845, 0.9635964615384616], 
             UndirectedEdge[69, 487] -> 
             RGBColor[
              0.8800923076923077, 0.9040017692307691, 0.8292813461538464], 
             UndirectedEdge[15, 408] -> 
             RGBColor[
              0.7119113076923077, 0.7209917692307692, 0.6173378846153845], 
             UndirectedEdge[118, 310] -> 
             RGBColor[
              0.774019923076923, 0.8184946153846153, 0.715015153846154], 
             UndirectedEdge[289, 297] -> 
             RGBColor[0.8020848076923076, 0.845787, 0.957258423076923], 
             UndirectedEdge[397, 419] -> 
             RGBColor[
              0.6630806153846154, 0.7305214615384615, 0.9469829615384615], 
             UndirectedEdge[13, 380] -> 
             RGBColor[
              0.7478382307692306, 0.8010080769230769, 0.9331640384615385], 
             UndirectedEdge[155, 262] -> 
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923], 
             UndirectedEdge[182, 324] -> 
             RGBColor[
              0.8942031153846154, 0.9180925384615385, 0.9764308846153846], 
             UndirectedEdge[177, 245] -> 
             RGBColor[
              0.6186983461538462, 0.6982106153846154, 0.9650094615384616], 
             UndirectedEdge[113, 325] -> 
             RGBColor[
              0.7025273461538463, 0.7668706923076923, 0.9714419230769231], 
             UndirectedEdge[94, 368] -> 
             RGBColor[
              0.6719442307692307, 0.5544131538461539, 0.5847592692307693], 
             UndirectedEdge[50, 140] -> 
             RGBColor[
              0.6852526923076923, 0.7510726153846153, 0.9680517307692308], 
             UndirectedEdge[389, 458] -> 
             RGBColor[
              0.8145551153846153, 0.8546621538461538, 0.9171089615384616], 
             UndirectedEdge[429, 499] -> 
             RGBColor[
              0.7872713076923077, 0.8343171538461538, 0.9792787692307692], 
             UndirectedEdge[97, 358] -> 
             RGBColor[
              0.8149099615384616, 0.8556928461538461, 0.9820908076923076], 
             UndirectedEdge[274, 363] -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 
             UndirectedEdge[255, 274] -> 
             RGBColor[
              0.8006230384615385, 0.8449634615384616, 0.9805522692307692], 
             UndirectedEdge[289, 381] -> 
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923], 
             UndirectedEdge[55, 230] -> 
             RGBColor[
              0.6344312307692308, 0.7106451538461538, 0.9665393846153847], 
             UndirectedEdge[289, 349] -> 
             RGBColor[
              0.884065576923077, 0.9098310000000001, 0.9654294999999999], 
             UndirectedEdge[29, 318] -> 
             RGBColor[0.8206795, 0.6732793846153846, 0.5977561923076923], 
             UndirectedEdge[69, 402] -> 
             RGBColor[
              0.7858253461538462, 0.8326119999999999, 0.9792873846153847], 
             UndirectedEdge[6, 413] -> 
             RGBColor[
              0.6820321538461539, 0.7508596923076922, 0.9693991538461538], 
             UndirectedEdge[29, 482] -> 
             RGBColor[
              0.7858253461538462, 0.8326119999999999, 0.9792873846153847], 
             UndirectedEdge[212, 456] -> 
             RGBColor[
              0.6602197307692308, 0.7331513846153845, 0.9676819999999999], 
             UndirectedEdge[354, 482] -> 
             RGBColor[
              0.889574076923077, 0.8843131538461539, 0.6651355000000001], 
             UndirectedEdge[106, 247] -> 
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937], 
             UndirectedEdge[305, 382] -> 
             RGBColor[
              0.6397245384615384, 0.7171403846153847, 0.9656392307692307], 
             UndirectedEdge[279, 285] -> 
             RGBColor[
              0.8211182307692309, 0.8609744615384616, 0.9825950384615385], 
             UndirectedEdge[27, 319] -> 
             RGBColor[
              0.5572127692307692, 0.6501776153846154, 0.9588811538461539], 
             UndirectedEdge[118, 483] -> 
             RGBColor[
              0.9153584230769232, 0.9303897692307692, 0.7281504615384617], 
             UndirectedEdge[342, 447] -> 
             RGBColor[
              0.791324576923077, 0.47536399999999995`, 0.5707313076923077], 
             UndirectedEdge[207, 458] -> 
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988], 
             UndirectedEdge[462, 487] -> 
             RGBColor[
              0.7967943076923077, 0.8382604615384616, 0.8214358846153849], 
             UndirectedEdge[64, 384] -> 
             RGBColor[
              0.6528229615384615, 0.7261803076923077, 0.9678203846153846], 
             UndirectedEdge[203, 221] -> 
             RGBColor[
              0.7645562692307692, 0.5526591153846154, 0.5802648461538461], 
             UndirectedEdge[139, 370] -> 
             RGBColor[
              0.9668211923076923, 0.9721889230769231, 0.7994651923076923], 
             UndirectedEdge[46, 357] -> 
             RGBColor[
              0.8182860769230769, 0.855282923076923, 0.7882518461538461], 
             UndirectedEdge[18, 326] -> 
             RGBColor[0.8778414999999999, 0.905431, 0.9882105], 
             UndirectedEdge[73, 93] -> 
             RGBColor[
              0.884065576923077, 0.9098310000000001, 0.9654294999999999], 
             UndirectedEdge[104, 112] -> 
             RGBColor[
              0.5367175769230769, 0.6341666153846153, 0.9568383846153846], 
             UndirectedEdge[40, 314] -> 
             RGBColor[
              0.6879871153846153, 0.7545349230769229, 0.9708110384615385], 
             UndirectedEdge[264, 398] -> 
             RGBColor[0.5525402307692309, 0.6399845, 0.9608277307692308], 
             UndirectedEdge[345, 489] -> 
             RGBColor[
              0.7311442692307693, 0.7854163846153845, 0.8466207307692308], 
             UndirectedEdge[80, 417] -> 
             RGBColor[
              0.7605678461538462, 0.8130245384615384, 0.9767317692307692], 
             UndirectedEdge[271, 442] -> 
             RGBColor[
              0.8211182307692309, 0.8609744615384616, 0.9825950384615385], 
             UndirectedEdge[318, 482] -> 
             RGBColor[
              0.8411746923076924, 0.6892903846153846, 0.5997989615384616], 
             UndirectedEdge[235, 260] -> 
             RGBColor[
              0.6177498461538462, 0.6961965769230769, 0.9654764615384616], 
             UndirectedEdge[79, 278] -> 
             RGBColor[
              0.6344312307692308, 0.7106451538461538, 0.9665393846153847], 
             UndirectedEdge[137, 404] -> 
             RGBColor[0.8337706923076923, 0.870144, 0.9403582692307693], 
             UndirectedEdge[380, 478] -> 
             RGBColor[
              0.7478382307692306, 0.8010080769230769, 0.9331640384615385], 
             UndirectedEdge[247, 370] -> 
             RGBColor[0.9019595, 0.9245658461538462, 0.9871758461538461], 
             UndirectedEdge[251, 429] -> 
             RGBColor[
              0.6628541923076923, 0.7365459999999999, 0.9670307692307691], 
             UndirectedEdge[286, 407] -> 
             RGBColor[
              0.5149051538461539, 0.6164583076923077, 0.9551212307692307], 
             UndirectedEdge[206, 410] -> 
             RGBColor[
              0.44946788461538456`, 0.5633333846153845, 0.9499697692307693], 
             UndirectedEdge[86, 500] -> 
             RGBColor[
              0.8965358846153847, 0.9187061538461538, 0.9252800384615385], 
             UndirectedEdge[78, 407] -> 
             RGBColor[
              0.4310761538461538, 0.5477982307692307, 0.9486887692307693], 
             UndirectedEdge[363, 370] -> 
             RGBColor[0.8113893076923077, 0.853452, 0.9782441153846153], 
             UndirectedEdge[447, 453] -> 
             RGBColor[0.8783741153846154, 0.544237, 0.5758163461538461], 
             UndirectedEdge[256, 492] -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             UndirectedEdge[114, 349] -> 
             RGBColor[
              0.6807149230769232, 0.7491623846153845, 0.9697247692307692], 
             UndirectedEdge[22, 160] -> 
             RGBColor[
              0.5843870769230769, 0.667299423076923, 0.9633506153846154], 
             UndirectedEdge[149, 324] -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 
             UndirectedEdge[94, 315] -> 
             RGBColor[0.8206795, 0.6732793846153846, 0.5977561923076924], 
             UndirectedEdge[246, 492] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[193, 202] -> 
             RGBColor[
              0.6410417692307693, 0.7188376923076923, 0.9653136153846154], 
             UndirectedEdge[321, 335] -> 
             RGBColor[
              0.4269346153846153, 0.5405238846153846, 0.9492223461538462], 
             UndirectedEdge[321, 496] -> 
             RGBColor[
              0.49309273076923066`, 0.5987499999999999, 0.9534040769230769], 
             UndirectedEdge[18, 474] -> 
             RGBColor[
              0.6177498461538462, 0.6961965769230769, 0.9654764615384616], 
             UndirectedEdge[184, 192] -> 
             RGBColor[
              0.6205465769230769, 0.7028266923076922, 0.9632708461538462], 
             UndirectedEdge[170, 171] -> 
             RGBColor[
              0.4678596153846154, 0.5788685384615384, 0.9512507692307692], 
             UndirectedEdge[80, 156] -> 
             RGBColor[0.8778414999999999, 0.905431, 0.9882105], 
             UndirectedEdge[353, 418] -> 
             RGBColor[
              0.7421560384615384, 0.7671442307692307, 0.6518129615384616], 
             UndirectedEdge[201, 312] -> 
             RGBColor[
              0.6964478076923077, 0.7615969230769231, 0.9712546923076923], 
             UndirectedEdge[152, 212] -> 
             RGBColor[
              0.6820321538461539, 0.7508596923076922, 0.9693991538461538], 
             UndirectedEdge[192, 260] -> 
             RGBColor[
              0.7182602307692308, 0.7793052307692308, 0.9729718461538461], 
             UndirectedEdge[90, 357] -> 
             RGBColor[
              0.6626004999999999, 0.7255688076923077, 0.7769134615384614], 
             UndirectedEdge[57, 369] -> 
             RGBColor[
              0.7801278461538461, 0.8289524615384615, 0.9785094999999999], 
             UndirectedEdge[83, 448] -> 
             RGBColor[
              0.7810630384615386, 0.8290355384615385, 0.9787745384615385], 
             UndirectedEdge[67, 180] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[373, 472] -> 
             RGBColor[0.4610964230769231, 0.5604635, 0.9529933461538461], 
             UndirectedEdge[353, 432] -> 
             RGBColor[
              0.5974169230769231, 0.6834210769230769, 0.9618793076923077], 
             UndirectedEdge[1, 433] -> 
             RGBColor[
              0.7531694615384614, 0.8028438461538461, 0.8180015769230772], 
             UndirectedEdge[300, 301] -> 
             RGBColor[
              0.5332968846153845, 0.6319934615384615, 0.9564022307692308], 
             UndirectedEdge[212, 389] -> 
             RGBColor[
              0.8760406923076923, 0.9026951538461538, 0.9232372692307693], 
             UndirectedEdge[97, 174] -> 
             RGBColor[0.8511380384615386, 0.8841383846153846, 0.9856635], 
             UndirectedEdge[200, 471] -> 
             RGBColor[
              0.8593843461538462, 0.8882716153846155, 0.8575748846153847], 
             UndirectedEdge[155, 387] -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 
             UndirectedEdge[156, 354] -> 
             RGBColor[
              0.9453621538461539, 0.9286866153846154, 0.6704859230769231], 
             UndirectedEdge[314, 472] -> 
             RGBColor[
              0.5974169230769231, 0.6834210769230769, 0.9618793076923077], 
             UndirectedEdge[117, 269] -> 
             RGBColor[
              0.9153112307692307, 0.9352121538461537, 0.9884493461538462], 
             UndirectedEdge[336, 409] -> 
             RGBColor[0.52385, 0.6212804615384615, 0.9567553076923077], 
             UndirectedEdge[63, 252] -> 
             RGBColor[
              0.5200361923076923, 0.6197180384615384, 0.9557754615384615], 
             UndirectedEdge[201, 444] -> 
             RGBColor[
              0.5987341538461537, 0.6851183846153845, 0.9615536923076923], 
             UndirectedEdge[201, 442] -> 
             RGBColor[
              0.7365029999999999, 0.7935358461538461, 0.9750751923076924], 
             UndirectedEdge[25, 333] -> 
             RGBColor[0.8318845, 0.8694630000000001, 0.9802868846153846], 
             UndirectedEdge[203, 397] -> 
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923], 
             UndirectedEdge[7, 436] -> 
             RGBColor[
              0.4896720384615384, 0.5965768461538461, 0.952967923076923], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.6935195769230769, 0.7054566153846153, 0.6160568846153847], 
             UndirectedEdge[274, 369] -> 
             RGBColor[
              0.8006230384615385, 0.8449634615384616, 0.9805522692307692], 
             UndirectedEdge[38, 364] -> 
             RGBColor[0.8196561923076924, 0.807836, 0.6262492692307692], 
             UndirectedEdge[215, 356] -> 
             RGBColor[
              0.835405153846154, 0.8717038461538462, 0.9841335769230769], 
             UndirectedEdge[16, 283] -> 
             RGBColor[
              0.6177498461538462, 0.6961965769230769, 0.9654764615384616], 
             UndirectedEdge[236, 276] -> 
             RGBColor[
              0.7810630384615386, 0.8290355384615385, 0.9787745384615385], 
             UndirectedEdge[39, 454] -> 
             RGBColor[
              0.7597523076923076, 0.7706304615384616, 0.637151153846154], 
             UndirectedEdge[179, 315] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[149, 182] -> 
             RGBColor[
              0.8942031153846154, 0.9180925384615385, 0.9764308846153846], 
             UndirectedEdge[97, 407] -> 
             RGBColor[
              0.6477829615384615, 0.7212914615384616, 0.9678128846153846], 
             UndirectedEdge[274, 379] -> 
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923], 
             UndirectedEdge[39, 325] -> 
             RGBColor[
              0.5769217307692307, 0.6674100769230769, 0.9598365384615384], 
             UndirectedEdge[127, 347] -> 
             RGBColor[0.8280885, 0.836280153846154, 0.6590071923076923], 
             UndirectedEdge[327, 483] -> 
             RGBColor[
              0.9163203846153847, 0.9324473076923077, 0.8328540384615387], 
             UndirectedEdge[269, 360] -> 
             RGBColor[
              0.6852526923076923, 0.7510726153846153, 0.9680517307692308], 
             UndirectedEdge[54, 147] -> 
             RGBColor[
              0.43278649999999996`, 0.5488848076923076, 0.9489068461538461], 
             UndirectedEdge[276, 422] -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 
             UndirectedEdge[181, 424] -> 
             RGBColor[
              0.6410417692307693, 0.7188376923076923, 0.9653136153846154], 
             UndirectedEdge[336, 456] -> 
             RGBColor[
              0.6192293461538461, 0.7011293846153845, 0.9635964615384616], 
             UndirectedEdge[46, 298] -> 
             RGBColor[
              0.5769217307692307, 0.6674100769230769, 0.9598365384615384], 
             UndirectedEdge[107, 132] -> 
             RGBColor[
              0.7316119615384615, 0.7899515384615385, 0.9742453461538461], 
             UndirectedEdge[78, 95] -> 
             RGBColor[
              0.6186983461538462, 0.6982106153846154, 0.9650094615384616], 
             UndirectedEdge[296, 332] -> 
             RGBColor[
              0.9427031923076923, 0.9530540769230769, 0.8004998461538462], 
             UndirectedEdge[397, 472] -> 
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923], 
             UndirectedEdge[19, 269] -> 
             RGBColor[
              0.8886077692307692, 0.9139195384615384, 0.9859023461538461], 
             UndirectedEdge[185, 335] -> 
             RGBColor[
              0.36491803846153836`, 0.4895721153846153, 0.9445070384615385], 
             UndirectedEdge[112, 351] -> 
             RGBColor[
              0.6611346923076923, 0.7319377692307691, 0.9690863846153847], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.5443451923076924, 0.6372914615384616, 0.9587980769230768], 
             UndirectedEdge[251, 305] -> 
             RGBColor[
              0.5987341538461537, 0.6851183846153845, 0.9615536923076923], 
             UndirectedEdge[131, 170] -> 
             RGBColor[
              0.6795264230769231, 0.747472923076923, 0.9703673846153846], 
             UndirectedEdge[76, 333] -> 
             RGBColor[0.8113893076923077, 0.853452, 0.9782441153846153], 
             UndirectedEdge[114, 115] -> 
             RGBColor[
              0.6602197307692308, 0.7331513846153845, 0.9676819999999999], 
             UndirectedEdge[87, 421] -> 
             RGBColor[
              0.5383148846153847, 0.6209310384615385, 0.9606515769230769], 
             UndirectedEdge[60, 192] -> 
             RGBColor[
              0.4982237692307693, 0.6020097307692307, 0.9540583076923077], 
             UndirectedEdge[84, 147] -> 
             RGBColor[
              0.6528229615384615, 0.7261803076923077, 0.9678203846153846], 
             UndirectedEdge[431, 433] -> 
             RGBColor[
              0.9563755769230768, 0.9643862307692308, 0.8366745384615387], 
             UndirectedEdge[201, 492] -> 
             RGBColor[
              0.6602197307692308, 0.7331513846153845, 0.9676819999999999], 
             UndirectedEdge[86, 124] -> 
             RGBColor[
              0.7858253461538462, 0.8326119999999999, 0.9792873846153847], 
             UndirectedEdge[234, 239] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[100, 450] -> 
             RGBColor[
              0.7400726538461538, 0.7970135384615384, 0.9746889999999999], 
             UndirectedEdge[22, 275] -> 
             RGBColor[
              0.7605678461538462, 0.8130245384615384, 0.9767317692307692], 
             UndirectedEdge[160, 324] -> 
             RGBColor[
              0.584387076923077, 0.667299423076923, 0.9633506153846154], 
             UndirectedEdge[191, 218] -> 
             RGBColor[
              0.4310761538461538, 0.5477982307692307, 0.9486887692307693], 
             UndirectedEdge[349, 397] -> 
             RGBColor[
              0.884065576923077, 0.9098310000000001, 0.9654294999999999], 
             UndirectedEdge[401, 454] -> 
             RGBColor[
              0.8443675384615386, 0.8380690769230771, 0.6446710000000001], 
             UndirectedEdge[311, 349] -> 
             RGBColor[
              0.765330153846154, 0.8166010000000001, 0.9772446153846154], 
             UndirectedEdge[63, 324] -> 
             RGBColor[
              0.6177498461538462, 0.6961965769230769, 0.9654764615384616], 
             UndirectedEdge[22, 353] -> 
             RGBColor[
              0.6746353846153845, 0.7438886153846154, 0.9695375384615385], 
             UndirectedEdge[93, 437] -> 
             RGBColor[0.8020848076923076, 0.845787, 0.957258423076923], 
             UndirectedEdge[417, 461] -> 
             RGBColor[
              0.5974169230769231, 0.6834210769230769, 0.9618793076923077], 
             UndirectedEdge[151, 249] -> 
             RGBColor[0.52385, 0.6212804615384615, 0.9567553076923077], 
             UndirectedEdge[148, 452] -> 
             RGBColor[
              0.298759923076923, 0.4313459999999999, 0.9403253076923077], 
             UndirectedEdge[262, 424] -> 
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923], 
             UndirectedEdge[50, 139] -> 
             RGBColor[
              0.7126446538461537, 0.7689145384615385, 0.7801022307692307], 
             UndirectedEdge[237, 267] -> 
             RGBColor[
              0.47641134615384606`, 0.584301423076923, 0.9523411538461539], 
             UndirectedEdge[256, 442] -> 
             RGBColor[
              0.841613423076923, 0.8769854615384615, 0.9846378076923077], 
             UndirectedEdge[60, 133] -> 
             RGBColor[
              0.5815217692307693, 0.6677510384615384, 0.9619037692307693], 
             UndirectedEdge[77, 156] -> 
             RGBColor[0.9045449615384615, 0.9267236153846153, 0.9907575], 
             UndirectedEdge[219, 498] -> 
             RGBColor[
              0.7043309615384614, 0.6201369230769231, 0.5952998846153846], 
             UndirectedEdge[102, 185] -> 
             RGBColor[
              0.44946788461538456`, 0.5633333846153845, 0.9499697692307693], 
             UndirectedEdge[92, 169] -> 
             RGBColor[0.9730013076923076, 0.979385, 0.9305859230769231], 
             UndirectedEdge[53, 357] -> 
             RGBColor[
              0.9930414230769231, 0.9904683846153846, 0.6979597307692307], 
             UndirectedEdge[162, 289] -> 
             RGBColor[
              0.884065576923077, 0.9098310000000001, 0.9654294999999999], 
             UndirectedEdge[169, 204] -> 
             RGBColor[0.679762, 0.7449700384615384, 0.9480458846153846], 
             UndirectedEdge[176, 448] -> 
             RGBColor[
              0.9135483846153847, 0.9316698461538462, 0.9056034230769232], 
             UndirectedEdge[377, 403] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[86, 357] -> 
             RGBColor[
              0.9002668461538462, 0.9193269230769231, 0.7964229230769231], 
             UndirectedEdge[12, 373] -> 
             RGBColor[
              0.6140769615384615, 0.6791088076923077, 0.8818650000000001], 
             UndirectedEdge[200, 469] -> 
             RGBColor[
              0.9561628076923077, 0.964667076923077, 0.8670108461538462], 
             UndirectedEdge[112, 153] -> 
             RGBColor[
              0.6477829615384615, 0.7212914615384616, 0.9678128846153846], 
             UndirectedEdge[166, 243] -> 
             RGBColor[
              0.5960996923076924, 0.6817237692307693, 0.9622049230769231], 
             UndirectedEdge[394, 460] -> 
             RGBColor[
              0.5149051538461539, 0.6164583076923077, 0.9551212307692307], 
             UndirectedEdge[18, 348] -> 
             RGBColor[
              0.8015582307692308, 0.8450465384615384, 0.9808173076923077], 
             UndirectedEdge[315, 325] -> 
             RGBColor[
              0.6820321538461539, 0.7508596923076922, 0.9693991538461538], 
             UndirectedEdge[195, 447] -> 
             RGBColor[
              0.8676078461538461, 0.5357484615384616, 0.5781244999999999], 
             UndirectedEdge[128, 204] -> 
             RGBColor[
              0.6578050384615384, 0.7281354999999999, 0.9692969615384616], 
             UndirectedEdge[91, 435] -> 
             RGBColor[
              0.8186067307692307, 0.8559687692307691, 0.8231530384615386], 
             UndirectedEdge[158, 206] -> 
             RGBColor[
              0.6661746923076923, 0.7368266153846154, 0.9690938846153846], 
             UndirectedEdge[30, 290] -> 
             RGBColor[
              0.5551093076923077, 0.6497017692307692, 0.9581193846153846], 
             UndirectedEdge[2, 250] -> 
             RGBColor[
              0.44946788461538456`, 0.5633333846153845, 0.9499697692307693], 
             UndirectedEdge[148, 195] -> 
             RGBColor[
              0.6083283076923076, 0.6843579615384614, 0.9661781538461538], 
             UndirectedEdge[5, 202] -> 
             RGBColor[
              0.7182602307692308, 0.7793052307692308, 0.9729718461538461], 
             UndirectedEdge[220, 359] -> 
             RGBColor[
              0.6630806153846154, 0.7305214615384615, 0.9469829615384615], 
             UndirectedEdge[175, 337] -> 
             RGBColor[
              0.5332968846153845, 0.6319934615384615, 0.9564022307692308], 
             UndirectedEdge[263, 447] -> 
             RGBColor[0.8783741153846154, 0.544237, 0.5758163461538461], 
             UndirectedEdge[344, 387] -> 
             RGBColor[
              0.8006230384615385, 0.8449634615384616, 0.9805522692307692], 
             UndirectedEdge[82, 470] -> 
             RGBColor[
              0.6602197307692308, 0.7331513846153845, 0.9676819999999999], 
             UndirectedEdge[273, 446] -> 
             RGBColor[
              0.9727371923076923, 0.9770477692307693, 0.8248949230769234], 
             UndirectedEdge[68, 306] -> 
             RGBColor[0.5484118461538461, 0.6213819615384615, 0.962766], 
             UndirectedEdge[21, 33] -> 
             RGBColor[
              0.7810630384615386, 0.8290355384615385, 0.9787745384615385], 
             UndirectedEdge[77, 479] -> 
             RGBColor[
              0.8487568846153847, 0.8823501538461538, 0.9854070769230769], 
             UndirectedEdge[253, 311] -> 
             RGBColor[
              0.6397245384615384, 0.7171403846153847, 0.9656392307692307], 
             UndirectedEdge[308, 386] -> 
             RGBColor[
              0.6795264230769231, 0.747472923076923, 0.9703673846153846], 
             UndirectedEdge[151, 280] -> 
             RGBColor[0.8113893076923077, 0.853452, 0.9782441153846153], 
             UndirectedEdge[305, 416] -> 
             RGBColor[
              0.38199726923076915`, 0.49329188461538453`, 0.9466632307692308],
              UndirectedEdge[38, 189] -> 
             RGBColor[
              0.703844576923077, 0.7685680000000001, 0.9711163076923077], 
             UndirectedEdge[277, 291] -> 
             RGBColor[
              0.7605678461538462, 0.8130245384615384, 0.9767317692307692], 
             UndirectedEdge[27, 40] -> 
             RGBColor[
              0.7739195769230769, 0.8236708461538462, 0.9780052692307692], 
             UndirectedEdge[88, 167] -> 
             RGBColor[
              0.9918696923076923, 0.990905923076923, 0.7844037692307695], 
             UndirectedEdge[89, 296] -> 
             RGBColor[0.7667761153846153, 0.8183061538461538, 0.977236], 
             UndirectedEdge[169, 340] -> 
             RGBColor[
              0.884065576923077, 0.9098310000000001, 0.9654294999999999], 
             UndirectedEdge[169, 363] -> 
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923], 
             UndirectedEdge[43, 378] -> 
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153], 
             UndirectedEdge[350, 482] -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 
             UndirectedEdge[199, 429] -> 
             RGBColor[
              0.6192293461538461, 0.7011293846153845, 0.9635964615384616], 
             UndirectedEdge[135, 216] -> 
             RGBColor[
              0.8211182307692309, 0.8609744615384616, 0.9825950384615385], 
             UndirectedEdge[153, 351] -> 
             RGBColor[0.8778414999999999, 0.905431, 0.9882105], 
             UndirectedEdge[207, 218] -> 
             RGBColor[
              0.5367175769230769, 0.6341666153846153, 0.9568383846153846], 
             UndirectedEdge[218, 389] -> 
             RGBColor[
              0.7089136923076922, 0.7682937692307692, 0.9089593461538463], 
             UndirectedEdge[421, 477] -> 
             RGBColor[0.44060123076923075`, 0.5444525, 0.9509505769230768], 
             UndirectedEdge[171, 391] -> 
             RGBColor[
              0.4678596153846154, 0.5788685384615384, 0.9512507692307692], 
             UndirectedEdge[25, 246] -> 
             RGBColor[
              0.703844576923077, 0.7685680000000001, 0.9711163076923077], 
             UndirectedEdge[130, 254] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[65, 434] -> 
             RGBColor[
              0.8800923076923077, 0.9040017692307691, 0.8292813461538464], 
             UndirectedEdge[174, 430] -> 
             RGBColor[
              0.6964478076923077, 0.7615969230769231, 0.9712546923076923], 
             UndirectedEdge[213, 454] -> 
             RGBColor[
              0.7597523076923076, 0.7706304615384616, 0.637151153846154], 
             UndirectedEdge[52, 495] -> 
             RGBColor[
              0.6742713076923077, 0.7388674615384615, 0.9280400384615384], 
             UndirectedEdge[26, 224] -> 
             RGBColor[
              0.9294940384615384, 0.7985138461538464, 0.5927217692307692], 
             UndirectedEdge[8, 31] -> 
             RGBColor[
              0.5367175769230769, 0.6341666153846153, 0.9568383846153846], 
             UndirectedEdge[29, 321] -> 
             RGBColor[
              0.6602197307692308, 0.7331513846153845, 0.9676819999999999], 
             UndirectedEdge[319, 377] -> 
             RGBColor[
              0.6186983461538462, 0.6982106153846154, 0.9650094615384616], 
             UndirectedEdge[323, 447] -> 
             RGBColor[
              0.791324576923077, 0.47536399999999995`, 0.5707313076923077], 
             UndirectedEdge[13, 340] -> 
             RGBColor[0.8952562692307693, 0.918177, 0.9464865769230769], 
             UndirectedEdge[176, 237] -> 
             RGBColor[
              0.7722098846153845, 0.8197746923076923, 0.8924681153846155], 
             UndirectedEdge[22, 268] -> 
             RGBColor[
              0.8015582307692308, 0.8450465384615384, 0.9808173076923077], 
             UndirectedEdge[461, 493] -> 
             RGBColor[0.7422428846153846, 0.7968350769230768, 0.9426355], 
             UndirectedEdge[401, 450] -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 
             UndirectedEdge[100, 200] -> 
             RGBColor[
              0.9161076153846155, 0.9327281538461538, 0.8631903461538462], 
             UndirectedEdge[197, 375] -> 
             RGBColor[
              0.7313570384615384, 0.7851355384615384, 0.8162844230769233], 
             UndirectedEdge[94, 401] -> 
             RGBColor[
              0.8001843076923078, 0.6572683846153847, 0.595713423076923], 
             UndirectedEdge[118, 327] -> 
             RGBColor[0.9938925000000001, 0.989345, 0.5766145000000004], 
             UndirectedEdge[44, 255] -> 
             RGBColor[
              0.7365029999999999, 0.7935358461538461, 0.9750751923076924], 
             UndirectedEdge[148, 356] -> 
             RGBColor[
              0.5816248461538461, 0.663065346153846, 0.9636311538461538], 
             UndirectedEdge[26, 34] -> 
             RGBColor[
              0.9131501923076923, 0.9329118461538461, 0.9682329230769231], 
             UndirectedEdge[244, 313] -> 
             RGBColor[
              0.8990951153846154, 0.9197644615384615, 0.8828669615384616], 
             UndirectedEdge[331, 488] -> 
             RGBColor[
              0.6964478076923077, 0.7615969230769231, 0.9712546923076923], 
             UndirectedEdge[382, 429] -> 
             RGBColor[
              0.703844576923077, 0.7685680000000001, 0.9711163076923077], 
             UndirectedEdge[409, 496] -> 
             RGBColor[
              0.3977133846153846, 0.5189010769230769, 0.946562923076923], 
             UndirectedEdge[14, 324] -> 
             RGBColor[
              0.7810630384615386, 0.8290355384615385, 0.9787745384615385], 
             UndirectedEdge[259, 471] -> 
             RGBColor[
              0.765330153846154, 0.8166010000000001, 0.9772446153846154], 
             UndirectedEdge[178, 439] -> 
             RGBColor[
              0.8965358846153847, 0.9187061538461538, 0.9252800384615385], 
             UndirectedEdge[127, 454] -> 
             RGBColor[
              0.9686114615384616, 0.9057812307692309, 0.3325618846153848], 
             UndirectedEdge[190, 452] -> 
             RGBColor[
              0.5873943846153846, 0.4806518846153846, 0.5792965384615385], 
             UndirectedEdge[218, 295] -> 
             RGBColor[
              0.47128030769230755`, 0.5810416923076922, 0.9516869230769232], 
             UndirectedEdge[35, 67] -> 
             RGBColor[
              0.8784702307692308, 0.9056580000000001, 0.9749009615384616], 
             UndirectedEdge[192, 249] -> 
             RGBColor[
              0.4815423846153847, 0.5875611538461538, 0.9529953846153846], 
             UndirectedEdge[186, 202] -> 
             RGBColor[
              0.7534704230769231, 0.6794477692307693, 0.6032764230769231], 
             UndirectedEdge[243, 469] -> 
             RGBColor[
              0.6928781538461538, 0.7581192307692307, 0.9716408846153846], 
             UndirectedEdge[48, 183] -> 
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153], 
             UndirectedEdge[255, 390] -> 
             RGBColor[0.951044346153846, 0.9625504615384615, 0.951837], 
             UndirectedEdge[202, 497] -> 
             RGBColor[
              0.5149051538461539, 0.6164583076923077, 0.9551212307692307], 
             UndirectedEdge[84, 365] -> 
             RGBColor[
              0.6177498461538462, 0.6961965769230769, 0.9654764615384616], 
             UndirectedEdge[239, 262] -> 
             RGBColor[0.8020848076923076, 0.845787, 0.957258423076923], 
             UndirectedEdge[299, 456] -> 
             RGBColor[
              0.6964478076923077, 0.7615969230769231, 0.9712546923076923], 
             UndirectedEdge[136, 253] -> 
             RGBColor[
              0.5987341538461537, 0.6851183846153845, 0.9615536923076923], 
             UndirectedEdge[338, 478] -> 
             RGBColor[0.8747610769230769, 0.902166, 0.9444438076923076], 
             UndirectedEdge[284, 444] -> 
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988], 
             UndirectedEdge[135, 147] -> 
             RGBColor[
              0.6928781538461538, 0.7581192307692307, 0.9716408846153846], 
             UndirectedEdge[72, 73] -> 
             RGBColor[
              0.6186983461538462, 0.6982106153846154, 0.9650094615384616], 
             UndirectedEdge[8, 291] -> 
             RGBColor[
              0.5572127692307692, 0.6501776153846154, 0.9588811538461539], 
             UndirectedEdge[141, 240] -> 
             RGBColor[0.8409043846153846, 0.5144558461538462, 0.5755775], 
             UndirectedEdge[9, 466] -> 
             RGBColor[
              0.6795264230769231, 0.747472923076923, 0.9703673846153846], 
             UndirectedEdge[78, 346] -> 
             RGBColor[
              0.6852526923076923, 0.7510726153846153, 0.9680517307692308], 
             UndirectedEdge[255, 425] -> 
             RGBColor[
              0.8621086153846154, 0.8929964615384616, 0.9866805769230769], 
             UndirectedEdge[297, 349] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[248, 478] -> 
             RGBColor[
              0.6909526923076923, 0.7533160384615385, 0.9291029615384616], 
             UndirectedEdge[113, 130] -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 
             UndirectedEdge[51, 179] -> 
             RGBColor[
              0.8391019230769231, 0.8719797692307693, 0.8251958076923079], 
             UndirectedEdge[440, 470] -> 
             RGBColor[
              0.5332968846153845, 0.6319934615384615, 0.9564022307692308], 
             UndirectedEdge[5, 414] -> 
             RGBColor[
              0.9161076153846155, 0.9327281538461538, 0.8631903461538462], 
             UndirectedEdge[148, 463] -> 
             RGBColor[
              0.6094528461538462, 0.5762288076923077, 0.5974654615384616], 
             UndirectedEdge[63, 441] -> 
             RGBColor[
              0.6960711538461539, 0.7554326538461538, 0.8442768076923077], 
             UndirectedEdge[163, 187] -> 
             RGBColor[
              0.5648403846153847, 0.6533024615384615, 0.9608408461538461], 
             UndirectedEdge[120, 177] -> 
             RGBColor[
              0.5982031538461539, 0.6821996153846153, 0.9629666923076923], 
             UndirectedEdge[450, 454] -> 
             RGBColor[
              0.8033771538461538, 0.806047076923077, 0.6405854615384616], 
             UndirectedEdge[15, 190] -> 
             RGBColor[
              0.915995923076923, 0.6965363846153847, 0.2508463846153846], 
             UndirectedEdge[191, 287] -> 
             RGBColor[
              0.6611346923076923, 0.7319377692307691, 0.9690863846153847], 
             UndirectedEdge[179, 292] -> 
             RGBColor[
              0.8169846538461538, 0.8576250000000001, 0.9687726538461539], 
             UndirectedEdge[291, 297] -> 
             RGBColor[
              0.6628541923076923, 0.7365459999999999, 0.9670307692307691], 
             UndirectedEdge[289, 397] -> 
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461], 
             UndirectedEdge[175, 370] -> 
             RGBColor[
              0.7472692692307692, 0.8020243846153845, 0.9727670384615384], 
             UndirectedEdge[23, 186] -> 
             RGBColor[
              0.6880331538461539, 0.6263228461538461, 0.5981249615384616], 
             UndirectedEdge[241, 461] -> 
             RGBColor[
              0.6937566538461537, 0.5721214615384616, 0.586476423076923], 
             UndirectedEdge[157, 216] -> 
             RGBColor[
              0.6397245384615384, 0.7171403846153847, 0.9656392307692307], 
             UndirectedEdge[51, 302] -> 
             RGBColor[
              0.8391019230769231, 0.8719797692307693, 0.8251958076923079], 
             UndirectedEdge[174, 390] -> 
             RGBColor[0.9109891538461539, 0.9306115384615385, 0.9480165], 
             UndirectedEdge[79, 406] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[181, 235] -> 
             RGBColor[
              0.4982237692307693, 0.6020097307692307, 0.9540583076923077], 
             UndirectedEdge[78, 404] -> 
             RGBColor[
              0.7076340769230769, 0.7677646153846154, 0.9301658846153846], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.7908941153846153, 0.8374409999999999, 0.9762013461538461], 
             UndirectedEdge[43, 384] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[101, 363] -> 
             RGBColor[
              0.703844576923077, 0.7685680000000001, 0.9711163076923077], 
             UndirectedEdge[120, 455] -> 
             RGBColor[
              0.6384073076923076, 0.7154430769230768, 0.9659648461538461], 
             UndirectedEdge[295, 456] -> 
             RGBColor[
              0.5332968846153845, 0.6319934615384615, 0.9564022307692308], 
             UndirectedEdge[58, 240] -> 
             RGBColor[0.8118197692307694, 0.491375, 0.5727740769230769], 
             UndirectedEdge[39, 471] -> 
             RGBColor[
              0.6397245384615384, 0.7171403846153847, 0.9656392307692307], 
             UndirectedEdge[54, 365] -> 
             RGBColor[
              0.3977133846153846, 0.5189010769230769, 0.9465629230769231], 
             UndirectedEdge[169, 334] -> 
             RGBColor[
              0.7584599615384615, 0.8103703846153846, 0.9538241153846154], 
             UndirectedEdge[18, 65] -> 
             RGBColor[
              0.8015582307692308, 0.8450465384615384, 0.9808173076923077], 
             UndirectedEdge[384, 435] -> 
             RGBColor[
              0.7400726538461538, 0.7970135384615384, 0.9746889999999999], 
             UndirectedEdge[9, 360] -> 
             RGBColor[
              0.44946788461538456`, 0.5633333846153845, 0.9499697692307693], 
             UndirectedEdge[135, 171] -> 
             RGBColor[
              0.6928781538461538, 0.7581192307692307, 0.9716408846153846], 
             UndirectedEdge[149, 187] -> 
             RGBColor[
              0.8015582307692308, 0.8450465384615384, 0.9808173076923077], 
             UndirectedEdge[271, 464] -> 
             RGBColor[
              0.8568251153846154, 0.8872133076923078, 0.8999879615384616], 
             UndirectedEdge[21, 348] -> 
             RGBColor[
              0.8015582307692308, 0.8450465384615384, 0.9808173076923077], 
             UndirectedEdge[1, 70] -> 
             RGBColor[
              0.6384073076923076, 0.7154430769230768, 0.9659648461538461], 
             UndirectedEdge[52, 276] -> 
             RGBColor[0.8542658846153847, 0.886155, 0.9424010384615384], 
             UndirectedEdge[58, 429] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[243, 495] -> 
             RGBColor[
              0.41610511538461536`, 0.5344362307692307, 0.9478439230769231], 
             UndirectedEdge[131, 135] -> 
             RGBColor[0.9045449615384615, 0.9267236153846153, 0.9907575], 
             UndirectedEdge[145, 430] -> 
             RGBColor[
              0.6397245384615384, 0.7171403846153847, 0.9656392307692307], 
             UndirectedEdge[291, 419] -> 
             RGBColor[0.52385, 0.6212804615384615, 0.9567553076923077], 
             UndirectedEdge[151, 260] -> 
             RGBColor[
              0.7605678461538462, 0.8130245384615384, 0.9767317692307692], 
             UndirectedEdge[189, 437] -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 
             UndirectedEdge[196, 354] -> 
             RGBColor[
              0.956128423076923, 0.9371751538461539, 0.6681777692307693], 
             UndirectedEdge[340, 355] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[58, 310] -> 
             RGBColor[
              0.6807149230769232, 0.7491623846153845, 0.9697247692307692], 
             UndirectedEdge[261, 500] -> 
             RGBColor[
              0.9908028461538462, 0.9900959230769231, 0.7752740000000004], 
             UndirectedEdge[237, 270] -> 
             RGBColor[
              0.6807149230769232, 0.7491623846153845, 0.9697247692307692], 
             UndirectedEdge[23, 497] -> 
             RGBColor[
              0.44946788461538456`, 0.5633333846153845, 0.9499697692307693], 
             UndirectedEdge[431, 462] -> 
             RGBColor[
              0.7583154230769231, 0.8112441538461539, 0.9767923461538461], 
             UndirectedEdge[108, 129] -> 
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937], 
             UndirectedEdge[376, 485] -> 
             RGBColor[
              0.7961530000000001, 0.8368887692307693, 0.7516335000000001], 
             UndirectedEdge[124, 261] -> 
             RGBColor[
              0.8800923076923077, 0.9040017692307691, 0.8292813461538464], 
             UndirectedEdge[63, 158] -> 
             RGBColor[
              0.6311015769230769, 0.7068428846153846, 0.9667499615384616], 
             UndirectedEdge[66, 427] -> 
             RGBColor[
              0.9619772692307693, 0.8796760000000001, 0.5243079230769232], 
             UndirectedEdge[66, 208] -> 
             RGBColor[
              0.9380543846153847, 0.7921133076923079, 0.26901530769230775`], 
             UndirectedEdge[54, 230] -> 
             RGBColor[
              0.4143947692307692, 0.5333496538461537, 0.9476258461538463], 
             UndirectedEdge[186, 295] -> 
             RGBColor[
              0.7098455769230769, 0.6440311538461538, 0.5998421153846154], 
             UndirectedEdge[245, 394] -> 
             RGBColor[
              0.7025273461538463, 0.7668706923076923, 0.9714419230769231], 
             UndirectedEdge[49, 459] -> 
             RGBColor[0.6588396538461538, 0.5628857307692308, 0.58789], 
             UndirectedEdge[55, 365] -> 
             RGBColor[
              0.6177498461538462, 0.6961965769230769, 0.9654764615384616], 
             UndirectedEdge[197, 448] -> 
             RGBColor[
              0.6528229615384615, 0.7261803076923077, 0.9678203846153846], 
             UndirectedEdge[185, 321] -> 
             RGBColor[
              0.49309273076923066`, 0.5987499999999999, 0.9534040769230769], 
             UndirectedEdge[242, 339] -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 
             UndirectedEdge[186, 191] -> 
             RGBColor[
              0.6696414230769231, 0.6107876923076924, 0.5968439615384615], 
             UndirectedEdge[218, 456] -> 
             RGBColor[
              0.49309273076923066`, 0.5987499999999999, 0.9534040769230769], 
             UndirectedEdge[63, 182] -> 
             RGBColor[
              0.6741666538461537, 0.7407970384615384, 0.9575173461538462], 
             UndirectedEdge[133, 181] -> 
             RGBColor[
              0.6820321538461539, 0.7508596923076922, 0.9693991538461538], 
             UndirectedEdge[11, 186] -> 
             RGBColor[
              0.7098455769230769, 0.6440311538461538, 0.5998421153846154], 
             UndirectedEdge[105, 148] -> 
             RGBColor[0.5525402307692309, 0.6399845, 0.9608277307692308], 
             UndirectedEdge[235, 393] -> 
             RGBColor[
              0.3977133846153846, 0.5189010769230769, 0.9465629230769231], 
             UndirectedEdge[110, 290] -> 
             RGBColor[
              0.7529566923076922, 0.8031246923076922, 0.8483378846153846], 
             UndirectedEdge[225, 296] -> 
             RGBColor[
              0.9153112307692307, 0.9352121538461537, 0.9884493461538462], 
             UndirectedEdge[38, 93] -> 
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923], 
             UndirectedEdge[80, 486] -> 
             RGBColor[
              0.9156790769230769, 0.9310756153846154, 0.7630516538461538], 
             UndirectedEdge[471, 500] -> 
             RGBColor[
              0.8555455000000001, 0.8866841538461538, 0.9211945000000001], 
             UndirectedEdge[200, 213] -> 
             RGBColor[
              0.7747691153846153, 0.8208329999999999, 0.8500550384615385], 
             UndirectedEdge[191, 295] -> 
             RGBColor[
              0.47128030769230755`, 0.5810416923076922, 0.9516869230769232], 
             UndirectedEdge[295, 300] -> 
             RGBColor[
              0.5332968846153845, 0.6319934615384615, 0.9564022307692308], 
             UndirectedEdge[191, 451] -> 
             RGBColor[
              0.6344312307692308, 0.7106451538461538, 0.9665393846153847], 
             UndirectedEdge[137, 145] -> 
             RGBColor[
              0.703844576923077, 0.7685680000000001, 0.9711163076923077], 
             UndirectedEdge[332, 344] -> 
             RGBColor[
              0.9560549230769231, 0.9637003846153847, 0.8017733461538461], 
             UndirectedEdge[76, 392] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[157, 465] -> 
             RGBColor[
              0.6964478076923077, 0.7615969230769231, 0.9712546923076923], 
             UndirectedEdge[204, 337] -> 
             RGBColor[0.45459892307692296`, 0.5665931153846153, 0.950624], 
             UndirectedEdge[112, 395] -> 
             RGBColor[
              0.6186983461538462, 0.6982106153846154, 0.9650094615384616], 
             UndirectedEdge[51, 107] -> 
             RGBColor[
              0.7967943076923077, 0.8382604615384616, 0.8214358846153849], 
             UndirectedEdge[5, 41] -> 
             RGBColor[
              0.6746353846153845, 0.7438886153846154, 0.9695375384615385], 
             UndirectedEdge[88, 210] -> 
             RGBColor[
              0.7529566923076922, 0.8031246923076922, 0.8483378846153846], 
             UndirectedEdge[248, 411] -> 
             RGBColor[
              0.5200361923076923, 0.6197180384615384, 0.9557754615384615], 
             UndirectedEdge[101, 128] -> 
             RGBColor[
              0.8211182307692309, 0.8609744615384616, 0.9825950384615385], 
             UndirectedEdge[298, 418] -> 
             RGBColor[
              0.7421560384615384, 0.7671442307692307, 0.6518129615384616], 
             UndirectedEdge[1, 391] -> 
             RGBColor[
              0.4896720384615384, 0.5965768461538461, 0.952967923076923], 
             UndirectedEdge[116, 327] -> 
             RGBColor[
              0.9296721153846155, 0.9430936153846154, 0.8341275384615388], 
             UndirectedEdge[79, 81] -> 
             RGBColor[0.6010684615384616, 0.681748, 0.9644135384615384], 
             UndirectedEdge[254, 368] -> 
             RGBColor[
              0.5756045000000001, 0.6657127692307692, 0.9601621538461538], 
             UndirectedEdge[4, 318] -> 
             RGBColor[
              0.7155690769230769, 0.5898297692307692, 0.5881935769230769], 
             UndirectedEdge[352, 412] -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 
             UndirectedEdge[239, 424] -> 
             RGBColor[
              0.6628541923076923, 0.7365459999999999, 0.9670307692307691], 
             UndirectedEdge[58, 188] -> 
             RGBColor[
              0.6186983461538462, 0.6982106153846154, 0.9650094615384616], 
             UndirectedEdge[407, 408] -> 
             RGBColor[
              0.44946788461538456`, 0.5633333846153845, 0.9499697692307693], 
             UndirectedEdge[255, 466] -> 
             RGBColor[0.9045449615384615, 0.9267236153846153, 0.9907575], 
             UndirectedEdge[197, 489] -> 
             RGBColor[
              0.4678596153846154, 0.5788685384615384, 0.9512507692307692], 
             UndirectedEdge[50, 363] -> 
             RGBColor[
              0.5572127692307692, 0.6501776153846154, 0.9588811538461539], 
             UndirectedEdge[57, 175] -> 
             RGBColor[
              0.5987341538461537, 0.6851183846153845, 0.9615536923076923], 
             UndirectedEdge[278, 486] -> 
             RGBColor[0.712324, 0.7682286923076923, 0.7452010384615385], 
             UndirectedEdge[82, 263] -> 
             RGBColor[
              0.8523796923076923, 0.8854739999999999, 0.9823296538461539], 
             UndirectedEdge[41, 186] -> 
             RGBColor[
              0.7098455769230769, 0.6440311538461538, 0.5998421153846154], 
             UndirectedEdge[390, 425] -> 
             RGBColor[0.8952562692307693, 0.918177, 0.9464865769230769], 
             UndirectedEdge[218, 458] -> 
             RGBColor[
              0.5367175769230769, 0.6341666153846153, 0.9568383846153846], 
             UndirectedEdge[230, 374] -> 
             RGBColor[
              0.7089136923076922, 0.7682937692307692, 0.9089593461538463], 
             UndirectedEdge[104, 408] -> 
             RGBColor[
              0.5551093076923077, 0.6497017692307692, 0.9581193846153846], 
             UndirectedEdge[121, 213] -> 
             RGBColor[
              0.5114844615384615, 0.6142851538461538, 0.9546850769230769], 
             UndirectedEdge[143, 421] -> 
             RGBColor[0.4815916153846154, 0.5764745, 0.9550361153846154], 
             UndirectedEdge[185, 482] -> 
             RGBColor[
              0.6186983461538462, 0.6982106153846154, 0.9650094615384616], 
             UndirectedEdge[256, 333] -> 
             RGBColor[
              0.8523796923076923, 0.8854739999999999, 0.9823296538461539], 
             UndirectedEdge[351, 463] -> 
             RGBColor[0.9056695, 0.8185944615384615, 0.6220448076923077], 
             UndirectedEdge[42, 411] -> 
             RGBColor[
              0.7038445769230769, 0.7685679999999999, 0.9711163076923077], 
             UndirectedEdge[52, 243] -> 
             RGBColor[
              0.7260258076923076, 0.7832997692307693, 0.9314468846153846], 
             UndirectedEdge[385, 391] -> 
             RGBColor[
              0.5332968846153847, 0.6319934615384615, 0.9564022307692308], 
             UndirectedEdge[366, 435] -> 
             RGBColor[
              0.8076801538461538, 0.8499599999999999, 0.9477869615384615], 
             UndirectedEdge[114, 419] -> 
             RGBColor[
              0.45972996153846146`, 0.5698528461538461, 0.9512782307692307], 
             UndirectedEdge[67, 391] -> 
             RGBColor[
              0.637090076923077, 0.7137457692307692, 0.9662904615384615], 
             UndirectedEdge[310, 327] -> 
             RGBColor[
              0.7749818846153846, 0.8205521538461538, 0.8197187307692311], 
             UndirectedEdge[309, 348] -> 
             RGBColor[
              0.6165948846153846, 0.6977347692307692, 0.9642476923076924], 
             UndirectedEdge[28, 194] -> 
             RGBColor[
              0.9080372307692308, 0.722317653846154, 0.5889580384615385], 
             UndirectedEdge[92, 337] -> 
             RGBColor[
              0.7478382307692306, 0.8010080769230769, 0.9331640384615385], 
             UndirectedEdge[205, 432] -> 
             RGBColor[
              0.5405313846153846, 0.6357290384615384, 0.9578182307692308], 
             UndirectedEdge[314, 398] -> 
             RGBColor[
              0.4051221923076922, 0.5228155769230768, 0.9475051923076923], 
             UndirectedEdge[235, 453] -> 
             RGBColor[
              0.6685713076923077, 0.7366240384615383, 0.9669888076923077], 
             UndirectedEdge[92, 334] -> 
             RGBColor[
              0.7696506538461538, 0.8187163846153847, 0.9348811923076923], 
             UndirectedEdge[35, 54] -> 
             RGBColor[
              0.6741666538461538, 0.7407970384615384, 0.9575173461538462], 
             UndirectedEdge[191, 456] -> 
             RGBColor[
              0.49309273076923066`, 0.5987499999999999, 0.9534040769230769], 
             UndirectedEdge[78, 137] -> 
             RGBColor[
              0.5572127692307692, 0.6501776153846154, 0.9588811538461539], 
             UndirectedEdge[57, 169] -> 
             RGBColor[0.8020848076923076, 0.845787, 0.957258423076923], 
             UndirectedEdge[343, 392] -> 
             RGBColor[
              0.8800923076923077, 0.9040017692307691, 0.8292813461538464], 
             UndirectedEdge[24, 197] -> 
             RGBColor[
              0.6528229615384615, 0.7261803076923077, 0.9678203846153846], 
             UndirectedEdge[450, 471] -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 
             UndirectedEdge[150, 267] -> 
             RGBColor[
              0.6311015769230769, 0.7068428846153846, 0.9667499615384616], 
             UndirectedEdge[40, 371] -> 
             RGBColor[
              0.9296721153846155, 0.9430936153846154, 0.8341275384615388], 
             UndirectedEdge[217, 362] -> 
             RGBColor[
              0.7605678461538462, 0.8130245384615384, 0.9767317692307692], 
             UndirectedEdge[229, 478] -> 
             RGBColor[
              0.7696506538461538, 0.8187163846153847, 0.9348811923076923], 
             UndirectedEdge[100, 168] -> 
             RGBColor[
              0.6964478076923077, 0.7615969230769231, 0.9712546923076923], 
             UndirectedEdge[221, 297] -> 
             RGBColor[
              0.7440610769230769, 0.5366481153846153, 0.5782220769230768], 
             UndirectedEdge[50, 338] -> 
             RGBColor[
              0.5982031538461539, 0.6821996153846153, 0.9629666923076923], 
             UndirectedEdge[5, 186] -> 
             RGBColor[
              0.8729965000000001, 0.7736346153846154, 0.6146945769230769], 
             UndirectedEdge[147, 391] -> 
             RGBColor[
              0.4678596153846154, 0.5788685384615384, 0.9512507692307692], 
             UndirectedEdge[24, 426] -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 
             UndirectedEdge[100, 127] -> 
             RGBColor[
              0.9053069615384616, 0.8967476923076924, 0.6666654230769231], 
             UndirectedEdge[418, 432] -> 
             RGBColor[0.8280885, 0.836280153846154, 0.6590071923076923], 
             UndirectedEdge[200, 259] -> 
             RGBColor[
              0.9003747307692309, 0.9202936153846154, 0.8616604230769231], 
             UndirectedEdge[17, 293] -> 
             RGBColor[
              0.4896720384615384, 0.5965768461538461, 0.952967923076923], 
             UndirectedEdge[269, 468] -> 
             RGBColor[
              0.703644423076923, 0.7666077692307691, 0.9693327307692308], 
             UndirectedEdge[154, 390] -> 
             RGBColor[
              0.9521688846153846, 0.8544213076923077, 0.5831243076923076], 
             UndirectedEdge[162, 439] -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 
             UndirectedEdge[103, 304] -> 
             RGBColor[0.8579750384615384, 0.889647, 0.9728581923076923], 
             UndirectedEdge[3, 480] -> 
             RGBColor[
              0.7182602307692308, 0.7793052307692308, 0.9729718461538461], 
             UndirectedEdge[358, 404] -> 
             RGBColor[0.8747610769230769, 0.902166, 0.9444438076923076], 
             UndirectedEdge[3, 439] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[336, 458] -> 
             RGBColor[
              0.6628541923076923, 0.7365459999999999, 0.9670307692307691], 
             UndirectedEdge[212, 287] -> 
             RGBColor[
              0.8282616923076923, 0.8663391538461538, 0.9833643076923078], 
             UndirectedEdge[190, 195] -> 
             RGBColor[
              0.8969627692307691, 0.7336638461538462, 0.6051493846153846], 
             UndirectedEdge[253, 377] -> 
             RGBColor[
              0.6807149230769232, 0.7491623846153845, 0.9697247692307692], 
             UndirectedEdge[192, 327] -> 
             RGBColor[
              0.7967943076923077, 0.8382604615384616, 0.8214358846153849], 
             UndirectedEdge[151, 483] -> 
             RGBColor[
              0.7605678461538462, 0.8130245384615384, 0.9767317692307692], 
             UndirectedEdge[38, 163] -> 
             RGBColor[0.52385, 0.6212804615384615, 0.9567553076923077], 
             UndirectedEdge[88, 227] -> 
             RGBColor[
              0.8593843461538462, 0.8882716153846155, 0.8575748846153847], 
             UndirectedEdge[281, 343] -> 
             RGBColor[
              0.8595971153846155, 0.8879907692307694, 0.8272385769230772], 
             UndirectedEdge[76, 157] -> 
             RGBColor[
              0.6192293461538461, 0.7011293846153845, 0.9635964615384616], 
             UndirectedEdge[364, 437] -> 
             RGBColor[0.799161, 0.791825, 0.6242064999999999], 
             UndirectedEdge[229, 244] -> 
             RGBColor[
              0.6807149230769232, 0.7491623846153845, 0.9697247692307692], 
             UndirectedEdge[154, 425] -> 
             RGBColor[
              0.863233153846154, 0.7848673076923076, 0.6179678846153847], 
             UndirectedEdge[128, 355] -> 
             RGBColor[
              0.7801278461538461, 0.8289524615384615, 0.9785094999999999], 
             UndirectedEdge[58, 382] -> 
             RGBColor[
              0.765330153846154, 0.8166010000000001, 0.9772446153846154], 
             UndirectedEdge[45, 179] -> 
             RGBColor[
              0.6410417692307693, 0.7188376923076923, 0.9653136153846154], 
             UndirectedEdge[181, 296] -> 
             RGBColor[
              0.7449636923076923, 0.8005978461538461, 0.9755188461538462], 
             UndirectedEdge[350, 354] -> 
             RGBColor[
              0.889574076923077, 0.8843131538461539, 0.6651355000000001], 
             UndirectedEdge[318, 335] -> 
             RGBColor[
              0.5873943846153846, 0.4806518846153846, 0.5792965384615385], 
             UndirectedEdge[354, 372] -> 
             RGBColor[
              0.9673191153846153, 0.9455211538461539, 0.6492348461538462], 
             UndirectedEdge[44, 57] -> 
             RGBColor[
              0.5987341538461537, 0.6851183846153845, 0.9615536923076923], 
             UndirectedEdge[257, 420] -> 
             RGBColor[
              0.8853579230769232, 0.870091076923077, 0.6487565384615386], 
             UndirectedEdge[84, 171] -> 
             RGBColor[
              0.6528229615384615, 0.7261803076923077, 0.9678203846153846], 
             UndirectedEdge[376, 497] -> 
             RGBColor[0.712324, 0.7682286923076923, 0.7452010384615385], 
             UndirectedEdge[164, 443] -> 
             RGBColor[
              0.8690788846153846, 0.8683021538461538, 0.6630927307692308], 
             UndirectedEdge[2, 54] -> 
             RGBColor[
              0.43278649999999996`, 0.5488848076923076, 0.9489068461538461], 
             UndirectedEdge[165, 324] -> 
             RGBColor[
              0.8942031153846154, 0.9180925384615385, 0.9764308846153846], 
             UndirectedEdge[82, 395] -> 
             RGBColor[
              0.7858253461538462, 0.8326119999999999, 0.9792873846153847], 
             UndirectedEdge[298, 420] -> 
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153], 
             UndirectedEdge[163, 437] -> 
             RGBColor[
              0.5033548076923077, 0.6052694615384615, 0.9547125384615385], 
             UndirectedEdge[156, 372] -> 
             RGBColor[
              0.9398536538461537, 0.9542044615384615, 0.9707799230769231], 
             UndirectedEdge[272, 317] -> 
             RGBColor[
              0.8015582307692308, 0.8450465384615384, 0.9808173076923077], 
             UndirectedEdge[282, 441] -> 
             RGBColor[
              0.8388891538461538, 0.8722606153846154, 0.8555321153846154], 
             UndirectedEdge[209, 423] -> 
             RGBColor[
              0.9699651923076922, 0.9762703076923077, 0.8976443076923079], 
             UndirectedEdge[222, 333] -> 
             RGBColor[0.9019595, 0.9245658461538462, 0.9871758461538461], 
             UndirectedEdge[125, 455] -> 
             RGBColor[
              0.42123615384615376`, 0.5376959615384614, 0.9484981538461539], 
             UndirectedEdge[343, 433] -> 
             RGBColor[
              0.9948544615384616, 0.9914025384615385, 0.6813180769230774], 
             UndirectedEdge[29, 77] -> 
             RGBColor[
              0.8282616923076923, 0.8663391538461538, 0.9833643076923078], 
             UndirectedEdge[298, 353] -> 
             RGBColor[
              0.5114844615384614, 0.6142851538461537, 0.9546850769230769], 
             UndirectedEdge[65, 337] -> 
             RGBColor[
              0.6384073076923076, 0.7154430769230768, 0.9659648461538461], 
             UndirectedEdge[93, 364] -> 
             RGBColor[
              0.9588868076923076, 0.9170769999999999, 0.616476923076923], 
             UndirectedEdge[170, 328] -> 
             RGBColor[
              0.5551093076923077, 0.6497017692307692, 0.9581193846153846], 
             UndirectedEdge[13, 244] -> 
             RGBColor[0.8952562692307693, 0.918177, 0.9464865769230769], 
             UndirectedEdge[114, 291] -> 
             RGBColor[
              0.6192293461538461, 0.7011293846153845, 0.9635964615384616], 
             UndirectedEdge[198, 373] -> 
             RGBColor[0.5225820000000001, 0.6084965, 0.9591216538461538], 
             UndirectedEdge[54, 84] -> 
             RGBColor[
              0.6177498461538462, 0.6961965769230769, 0.9654764615384616], 
             UndirectedEdge[1, 385] -> 
             RGBColor[
              0.5551093076923077, 0.6497017692307692, 0.9581193846153846], 
             UndirectedEdge[97, 294] -> 
             RGBColor[
              0.835405153846154, 0.8717038461538462, 0.9841335769230769], 
             UndirectedEdge[83, 489] -> 
             RGBColor[
              0.5960996923076924, 0.6817237692307693, 0.9622049230769231], 
             UndirectedEdge[349, 359] -> 
             RGBColor[
              0.585335576923077, 0.6693134615384615, 0.9628836153846154], 
             UndirectedEdge[47, 55] -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 
             UndirectedEdge[166, 309] -> 
             RGBColor[
              0.5960996923076924, 0.6817237692307693, 0.9622049230769231], 
             UndirectedEdge[196, 482] -> 
             RGBColor[0.8728748846153846, 0.901485, 0.9843724230769231], 
             UndirectedEdge[114, 311] -> 
             RGBColor[
              0.6397245384615384, 0.7171403846153847, 0.9656392307692307], 
             UndirectedEdge[101, 169] -> 
             RGBColor[
              0.8430751923076923, 0.8778090000000001, 0.9613439615384616], 
             UndirectedEdge[160, 353] -> 
             RGBColor[
              0.42123615384615376`, 0.5376959615384614, 0.9484981538461539], 
             UndirectedEdge[80, 329] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[130, 386] -> 
             RGBColor[
              0.637090076923077, 0.7137457692307692, 0.9662904615384615], 
             UndirectedEdge[216, 238] -> 
             RGBColor[
              0.765330153846154, 0.8166010000000001, 0.9772446153846154], 
             UndirectedEdge[240, 382] -> 
             RGBColor[
              0.7708293846153846, 0.45935300000000007`, 0.5686885384615384], 
             UndirectedEdge[424, 470] -> 
             RGBColor[
              0.6192293461538461, 0.7011293846153845, 0.9635964615384616], 
             UndirectedEdge[184, 225] -> 
             RGBColor[
              0.7908941153846153, 0.8374409999999999, 0.9762013461538461], 
             UndirectedEdge[169, 274] -> 
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923], 
             UndirectedEdge[345, 375] -> 
             RGBColor[
              0.9946416923076924, 0.9916833846153846, 0.7116543846153849], 
             UndirectedEdge[326, 434] -> 
             RGBColor[
              0.9563755769230768, 0.9643862307692308, 0.8366745384615387], 
             UndirectedEdge[59, 105] -> 
             RGBColor[
              0.8487568846153847, 0.8823501538461538, 0.9854070769230769], 
             UndirectedEdge[90, 306] -> 
             RGBColor[
              0.25495742307692304`, 0.3832503846153846, 0.9379061153846153], 
             UndirectedEdge[44, 466] -> 
             RGBColor[
              0.7231512692307691, 0.7828895384615384, 0.9738016923076923], 
             UndirectedEdge[88, 434] -> 
             RGBColor[
              0.9946416923076924, 0.9916833846153846, 0.7116543846153849], 
             UndirectedEdge[174, 356] -> 
             RGBColor[0.8511380384615386, 0.8841383846153846, 0.9856635], 
             UndirectedEdge[65, 88] -> 
             RGBColor[
              0.8798795384615385, 0.9042826153846153, 0.859617653846154], 
             UndirectedEdge[82, 195] -> 
             RGBColor[
              0.841613423076923, 0.8769854615384615, 0.9846378076923077], 
             UndirectedEdge[150, 413] -> 
             RGBColor[
              0.7316119615384615, 0.7899515384615385, 0.9742453461538461], 
             UndirectedEdge[156, 307] -> 
             RGBColor[
              0.7801278461538461, 0.8289524615384615, 0.9785094999999999], 
             UndirectedEdge[245, 460] -> 
             RGBColor[
              0.6186983461538462, 0.6982106153846154, 0.9650094615384616], 
             UndirectedEdge[101, 204] -> 
             RGBColor[
              0.561026576923077, 0.6517400384615385, 0.9598610000000001], 
             UndirectedEdge[210, 428] -> 
             RGBColor[
              0.47128030769230755`, 0.5810416923076922, 0.9516869230769232], 
             UndirectedEdge[25, 76] -> 
             RGBColor[
              0.703844576923077, 0.7685680000000001, 0.9711163076923077], 
             UndirectedEdge[130, 421] -> 
             RGBColor[0.5225820000000001, 0.6084965, 0.9591216538461538], 
             UndirectedEdge[79, 493] -> 
             RGBColor[
              0.9053938076923077, 0.9264385384615385, 0.9574879615384615], 
             UndirectedEdge[194, 490] -> 
             RGBColor[
              0.7310521923076923, 0.7884890769230768, 0.9615784230769231], 
             UndirectedEdge[214, 347] -> 
             RGBColor[
              0.7605678461538462, 0.8130245384615384, 0.9767317692307692], 
             UndirectedEdge[41, 202] -> 
             RGBColor[
              0.5551093076923077, 0.6497017692307692, 0.9581193846153846], 
             UndirectedEdge[85, 97] -> 
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484], 
             UndirectedEdge[31, 114] -> 
             RGBColor[
              0.5987341538461537, 0.6851183846153845, 0.9615536923076923], 
             UndirectedEdge[247, 425] -> 
             RGBColor[
              0.835405153846154, 0.8717038461538462, 0.9841335769230769], 
             UndirectedEdge[35, 281] -> 
             RGBColor[
              0.8374798461538462, 0.8736360000000001, 0.970815423076923], 
             UndirectedEdge[157, 288] -> 
             RGBColor[
              0.6602197307692308, 0.7331513846153845, 0.9676819999999999], 
             UndirectedEdge[208, 427] -> 
             RGBColor[
              0.9679468076923077, 0.9033432307692308, 0.5291111538461539], 
             UndirectedEdge[154, 313] -> 
             RGBColor[
              0.9560077307692307, 0.8560087692307692, 0.5195046923076923], 
             UndirectedEdge[189, 364] -> 
             RGBColor[0.8401513846153847, 0.823847, 0.6282920384615385], 
             UndirectedEdge[314, 373] -> 
             RGBColor[
              0.37516396153846143`, 0.4913275769230768, 0.9457991153846154], 
             UndirectedEdge[156, 232] -> 
             RGBColor[
              0.841613423076923, 0.8769854615384615, 0.9846378076923077], 
             UndirectedEdge[321, 383] -> 
             RGBColor[
              0.7097995384615384, 0.7722432307692307, 0.9725281923076923], 
             UndirectedEdge[15, 323] -> 
             RGBColor[0.8606465769230769, 0.839858, 0.6303348076923077], 
             UndirectedEdge[225, 235] -> 
             RGBColor[
              0.6685713076923077, 0.7366240384615383, 0.9669888076923077], 
             UndirectedEdge[170, 265] -> 
             RGBColor[
              0.6528229615384615, 0.7261803076923077, 0.9678203846153846], 
             UndirectedEdge[102, 485] -> 
             RGBColor[
              0.5332968846153847, 0.6319934615384615, 0.9564022307692308], 
             UndirectedEdge[342, 463] -> 
             RGBColor[
              0.8427379615384616, 0.7688563076923076, 0.6159251153846154], 
             UndirectedEdge[70, 147] -> 
             RGBColor[
              0.6165948846153846, 0.6977347692307692, 0.9642476923076924], 
             UndirectedEdge[162, 381] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[212, 299] -> 
             RGBColor[
              0.8015582307692308, 0.8450465384615384, 0.9808173076923077], 
             UndirectedEdge[92, 361] -> 
             RGBColor[0.8747610769230769, 0.902166, 0.9444438076923076], 
             UndirectedEdge[82, 184] -> 
             RGBColor[
              0.7038445769230769, 0.7685679999999999, 0.9711163076923077], 
             UndirectedEdge[232, 376] -> 
             RGBColor[0.879451, 0.9026300769230768, 0.7594789615384616], 
             UndirectedEdge[293, 298] -> 
             RGBColor[
              0.4896720384615384, 0.5965768461538461, 0.952967923076923], 
             UndirectedEdge[225, 249] -> 
             RGBColor[
              0.6518899230769231, 0.7221754615384615, 0.9659258846153846], 
             UndirectedEdge[19, 34] -> 
             RGBColor[0.8511380384615386, 0.8841383846153846, 0.9856635], 
             UndirectedEdge[338, 390] -> 
             RGBColor[0.8747610769230769, 0.902166, 0.9444438076923076], 
             UndirectedEdge[82, 342] -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             UndirectedEdge[54, 374] -> 
             RGBColor[
              0.6922323076923076, 0.7538451923076923, 0.9078964230769232], 
             UndirectedEdge[196, 350] -> 
             RGBColor[0.8728748846153846, 0.901485, 0.9843724230769231], 
             UndirectedEdge[19, 44] -> 
             RGBColor[
              0.6964478076923077, 0.7615969230769231, 0.9712546923076923], 
             UndirectedEdge[85, 408] -> 
             RGBColor[
              0.6928781538461538, 0.7581192307692307, 0.9716408846153846], 
             UndirectedEdge[57, 255] -> 
             RGBColor[
              0.7801278461538461, 0.8289524615384615, 0.9785094999999999], 
             UndirectedEdge[106, 269] -> 
             RGBColor[0.9019595, 0.9245658461538462, 0.9871758461538461], 
             UndirectedEdge[382, 416] -> 
             RGBColor[0.4666125000000001, 0.5607305, 0.9541830769230769], 
             UndirectedEdge[246, 392] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[350, 414] -> 
             RGBColor[
              0.9003747307692309, 0.9202936153846154, 0.8616604230769231], 
             UndirectedEdge[146, 211] -> 
             RGBColor[
              0.8487075000000001, 0.7925235384615386, 0.6207283461538462], 
             UndirectedEdge[71, 487] -> 
             RGBColor[
              0.9005875000000001, 0.9200127692307692, 0.8313241153846156], 
             UndirectedEdge[415, 485] -> 
             RGBColor[
              0.6205465769230769, 0.7028266923076922, 0.9632708461538462], 
             UndirectedEdge[238, 433] -> 
             RGBColor[
              0.9005875000000001, 0.9200127692307692, 0.8313241153846156], 
             UndirectedEdge[141, 429] -> 
             RGBColor[
              0.7739195769230769, 0.8236708461538462, 0.9780052692307692], 
             UndirectedEdge[406, 493] -> 
             RGBColor[0.8896609230769231, 0.914004, 0.9559580384615385], 
             UndirectedEdge[257, 357] -> 
             RGBColor[0.9793042307692308, 0.940795, 0.46384930769230776`], 
             UndirectedEdge[311, 488] -> 
             RGBColor[
              0.7810630384615386, 0.8290355384615385, 0.9787745384615385], 
             UndirectedEdge[258, 381] -> 
             RGBColor[
              0.5756045000000001, 0.6657127692307692, 0.9601621538461538], 
             UndirectedEdge[168, 200] -> 
             RGBColor[
              0.7747691153846153, 0.8208329999999999, 0.8500550384615385], 
             UndirectedEdge[16, 254] -> 
             RGBColor[
              0.5405313846153846, 0.6357290384615384, 0.9578182307692308], 
             UndirectedEdge[325, 347] -> 
             RGBColor[
              0.6410417692307693, 0.7188376923076923, 0.9653136153846154], 
             UndirectedEdge[154, 478] -> 
             RGBColor[
              0.9521688846153846, 0.8544213076923077, 0.5831243076923076], 
             UndirectedEdge[302, 386] -> 
             RGBColor[
              0.5756045000000001, 0.6657127692307692, 0.9601621538461538], 
             UndirectedEdge[330, 414] -> 
             RGBColor[
              0.8183939615384614, 0.8562496153846153, 0.8534893461538462], 
             UndirectedEdge[50, 334] -> 
             RGBColor[
              0.49309273076923066`, 0.5987499999999999, 0.9534040769230769], 
             UndirectedEdge[72, 187] -> 
             RGBColor[
              0.5982031538461539, 0.6821996153846153, 0.9629666923076923], 
             UndirectedEdge[14, 149] -> 
             RGBColor[
              0.7810630384615386, 0.8290355384615385, 0.9787745384615385], 
             UndirectedEdge[113, 214] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[63, 149] -> 
             RGBColor[
              0.6177498461538462, 0.6961965769230769, 0.9654764615384616], 
             UndirectedEdge[245, 445] -> 
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153], 
             UndirectedEdge[207, 336] -> 
             RGBColor[
              0.6628541923076923, 0.7365459999999999, 0.9670307692307691], 
             UndirectedEdge[264, 394] -> 
             RGBColor[
              0.7025273461538463, 0.7668706923076923, 0.9714419230769231], 
             UndirectedEdge[255, 370] -> 
             RGBColor[
              0.9286629615384614, 0.9458584615384615, 0.9897228461538461], 
             UndirectedEdge[330, 482] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[383, 482] -> 
             RGBColor[
              0.835405153846154, 0.8717038461538462, 0.9841335769230769], 
             UndirectedEdge[358, 407] -> 
             RGBColor[
              0.5982031538461539, 0.6821996153846153, 0.9629666923076923], 
             UndirectedEdge[28, 142] -> 
             RGBColor[
              0.9192279230769231, 0.730663653846154, 0.5700151153846155], 
             UndirectedEdge[348, 375] -> 
             RGBColor[
              0.8800923076923077, 0.9040017692307691, 0.8292813461538464], 
             UndirectedEdge[41, 295] -> 
             RGBColor[
              0.5114844615384614, 0.6142851538461537, 0.9546850769230769], 
             UndirectedEdge[83, 345] -> 
             RGBColor[
              0.8593843461538462, 0.8882716153846155, 0.8575748846153847], 
             UndirectedEdge[140, 425] -> 
             RGBColor[0.8728748846153846, 0.901485, 0.9843724230769231], 
             UndirectedEdge[160, 441] -> 
             RGBColor[0.6627083846153845, 0.7265355, 0.8421509615384616], 
             UndirectedEdge[66, 394] -> 
             RGBColor[
              0.7654095000000001, 0.726782230769231, 0.6128828846153846], 
             UndirectedEdge[201, 271] -> 
             RGBColor[
              0.6397245384615384, 0.7171403846153847, 0.9656392307692307], 
             UndirectedEdge[192, 470] -> 
             RGBColor[
              0.5769217307692307, 0.6674100769230769, 0.9598365384615384], 
             UndirectedEdge[255, 379] -> 
             RGBColor[
              0.9398536538461537, 0.9542044615384615, 0.9707799230769231], 
             UndirectedEdge[82, 440] -> 
             RGBColor[
              0.6384073076923076, 0.7154430769230768, 0.9659648461538461], 
             UndirectedEdge[43, 362] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[127, 302] -> 
             RGBColor[0.8280885, 0.836280153846154, 0.6590071923076923], 
             UndirectedEdge[137, 358] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[238, 328] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[185, 196] -> 
             RGBColor[
              0.6852526923076923, 0.7510726153846153, 0.9680517307692308], 
             UndirectedEdge[114, 208] -> 
             RGBColor[
              0.7495666153846154, 0.7327411538461539, 0.6159689615384616], 
             UndirectedEdge[249, 424] -> 
             RGBColor[0.52385, 0.6212804615384615, 0.9567553076923077], 
             UndirectedEdge[21, 65] -> 
             RGBColor[
              0.8015582307692308, 0.8450465384615384, 0.9808173076923077], 
             UndirectedEdge[369, 466] -> 
             RGBColor[0.9045449615384615, 0.9267236153846153, 0.9907575], 
             UndirectedEdge[246, 459] -> 
             RGBColor[
              0.5572127692307692, 0.6501776153846154, 0.9588811538461539], 
             UndirectedEdge[46, 317] -> 
             RGBColor[
              0.7400726538461538, 0.7970135384615384, 0.9746889999999999], 
             UndirectedEdge[66, 305] -> 
             RGBColor[
              0.7435970769230769, 0.7090739230769232, 0.6111657307692309], 
             UndirectedEdge[56, 243] -> 
             RGBColor[
              0.6165948846153846, 0.6977347692307692, 0.9642476923076924], 
             UndirectedEdge[281, 288] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[81, 329] -> 
             RGBColor[
              0.585335576923077, 0.6693134615384615, 0.9628836153846154], 
             UndirectedEdge[57, 140] -> 
             RGBColor[
              0.7908941153846153, 0.8374409999999999, 0.9762013461538461], 
             UndirectedEdge[184, 440] -> 
             RGBColor[
              0.5769217307692307, 0.6674100769230769, 0.9598365384615384], 
             UndirectedEdge[422, 446] -> 
             RGBColor[
              0.8186067307692307, 0.8559687692307691, 0.8231530384615386], 
             UndirectedEdge[232, 307] -> 
             RGBColor[
              0.7038445769230769, 0.7685679999999999, 0.9711163076923077], 
             UndirectedEdge[90, 261] -> 
             RGBColor[
              0.6629211538461539, 0.7262546538461538, 0.8118146538461541], 
             UndirectedEdge[118, 304] -> 
             RGBColor[
              0.8791303461538462, 0.9019442307692307, 0.7245777692307693], 
             UndirectedEdge[427, 460] -> 
             RGBColor[
              0.711472923076923, 0.7693520769230768, 0.8665462692307693], 
             UndirectedEdge[299, 300] -> 
             RGBColor[
              0.6964478076923077, 0.7615969230769231, 0.9712546923076923], 
             UndirectedEdge[106, 425] -> 
             RGBColor[
              0.835405153846154, 0.8717038461538462, 0.9841335769230769], 
             UndirectedEdge[428, 495] -> 
             RGBColor[
              0.3977133846153846, 0.5189010769230769, 0.946562923076923], 
             UndirectedEdge[230, 365] -> 
             RGBColor[
              0.4143947692307692, 0.5333496538461537, 0.9476258461538463], 
             UndirectedEdge[224, 463] -> 
             RGBColor[
              0.9086616153846154, 0.673550153846154, 0.2452601538461539], 
             UndirectedEdge[251, 382] -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 
             UndirectedEdge[81, 278] -> 
             RGBColor[
              0.3977133846153846, 0.5189010769230769, 0.946562923076923], 
             UndirectedEdge[42, 294] -> 
             RGBColor[
              0.7858253461538462, 0.8326119999999999, 0.9792873846153847], 
             UndirectedEdge[8, 419] -> 
             RGBColor[
              0.3977133846153846, 0.5189010769230769, 0.946562923076923], 
             UndirectedEdge[159, 164] -> 
             RGBColor[
              0.6602197307692308, 0.7331513846153845, 0.9676819999999999], 
             UndirectedEdge[346, 404] -> 
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461], 
             UndirectedEdge[7, 194] -> 
             RGBColor[
              0.7092397692307693, 0.7707807692307692, 0.9598612692307693], 
             UndirectedEdge[268, 353] -> 
             RGBColor[
              0.6384073076923076, 0.7154430769230768, 0.9659648461538461], 
             UndirectedEdge[51, 423] -> 
             RGBColor[
              0.9920824615384616, 0.9906250769230769, 0.7540674615384619], 
             UndirectedEdge[14, 322] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[109, 458] -> 
             RGBColor[0.8020848076923076, 0.845787, 0.957258423076923], 
             UndirectedEdge[217, 384] -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 
             UndirectedEdge[202, 485] -> 
             RGBColor[
              0.5987341538461539, 0.6851183846153847, 0.9615536923076923], 
             UndirectedEdge[125, 457] -> 
             RGBColor[
              0.48667342307692296`, 0.5908208846153845, 0.9536496153846153], 
             UndirectedEdge[454, 475] -> 
             RGBColor[
              0.8033771538461538, 0.806047076923077, 0.6405854615384616], 
             UndirectedEdge[30, 378] -> 
             RGBColor[
              0.5551093076923077, 0.6497017692307692, 0.9581193846153846], 
             UndirectedEdge[445, 460] -> 
             RGBColor[
              0.47128030769230755`, 0.5810416923076922, 0.9516869230769232], 
             UndirectedEdge[173, 461] -> 
             RGBColor[
              0.725456846153846, 0.7843160769230768, 0.9710498846153846], 
             UndirectedEdge[23, 41] -> 
             RGBColor[
              0.4896720384615384, 0.5965768461538461, 0.952967923076923], 
             UndirectedEdge[111, 444] -> 
             RGBColor[
              0.6628541923076923, 0.7365459999999999, 0.9670307692307691], 
             UndirectedEdge[139, 360] -> 
             RGBColor[
              0.7126446538461538, 0.7689145384615385, 0.7801022307692307], 
             UndirectedEdge[53, 432] -> 
             RGBColor[
              0.8376095384615385, 0.8717314615384615, 0.8767386538461539], 
             UndirectedEdge[184, 260] -> 
             RGBColor[
              0.7400726538461538, 0.7970135384615384, 0.9746889999999999], 
             UndirectedEdge[244, 379] -> 
             RGBColor[
              0.884065576923077, 0.9098310000000001, 0.9654294999999999], 
             UndirectedEdge[14, 187] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[133, 332] -> 
             RGBColor[
              0.8797716538461539, 0.903315923076923, 0.7943801538461538], 
             UndirectedEdge[424, 440] -> 
             RGBColor[
              0.5974169230769231, 0.6834210769230769, 0.9618793076923077], 
             UndirectedEdge[381, 419] -> 
             RGBColor[0.52385, 0.6212804615384615, 0.9567553076923077], 
             UndirectedEdge[39, 368] -> 
             RGBColor[
              0.5114844615384615, 0.6142851538461538, 0.9546850769230769], 
             UndirectedEdge[40, 208] -> 
             RGBColor[
              0.9042568461538463, 0.8552826153846155, 0.6303777692307693], 
             UndirectedEdge[436, 462] -> 
             RGBColor[
              0.5551093076923077, 0.6497017692307692, 0.9581193846153846], 
             UndirectedEdge[103, 188] -> 
             RGBColor[
              0.6908480384615384, 0.7552456153846154, 0.9585802692307692], 
             UndirectedEdge[313, 411] -> 
             RGBColor[
              0.8171143461538461, 0.8557204615384615, 0.8746958846153846], 
             UndirectedEdge[181, 344] -> 
             RGBColor[
              0.7583154230769231, 0.8112441538461539, 0.9767923461538461], 
             UndirectedEdge[5, 485] -> 
             RGBColor[
              0.7182602307692308, 0.7793052307692308, 0.9729718461538461], 
             UndirectedEdge[371, 429] -> 
             RGBColor[
              0.8391019230769231, 0.8719797692307693, 0.8251958076923079], 
             UndirectedEdge[426, 448] -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 
             UndirectedEdge[32, 403] -> 
             RGBColor[
              0.9163203846153847, 0.9324473076923077, 0.8328540384615387], 
             UndirectedEdge[115, 484] -> 
             RGBColor[
              0.7858253461538462, 0.8326119999999999, 0.9792873846153847], 
             UndirectedEdge[36, 251] -> 
             RGBColor[
              0.6628541923076923, 0.7365459999999999, 0.9670307692307691], 
             UndirectedEdge[243, 454] -> 
             RGBColor[
              0.7161274615384616, 0.7352138461538462, 0.6337168461538463], 
             UndirectedEdge[106, 139] -> 
             RGBColor[
              0.9293514615384615, 0.9424077692307693, 0.799226346153846], 
             UndirectedEdge[220, 499] -> 
             RGBColor[
              0.926501923076923, 0.9435581538461538, 0.969506423076923], 
             UndirectedEdge[359, 419] -> 
             RGBColor[
              0.3643506153846154, 0.49000392307692303`, 0.9444370769230769], 
             UndirectedEdge[115, 297] -> 
             RGBColor[
              0.7038445769230769, 0.7685679999999999, 0.9711163076923077], 
             UndirectedEdge[155, 235] -> 
             RGBColor[
              0.5405313846153846, 0.6357290384615384, 0.9578182307692308], 
             UndirectedEdge[98, 261] -> 
             RGBColor[
              0.9430238461538462, 0.953739923076923, 0.8354010384615387], 
             UndirectedEdge[386, 421] -> 
             RGBColor[
              0.35335153846153844`, 0.4736192692307692, 0.9440819615384615], 
             UndirectedEdge[37, 58] -> 
             RGBColor[
              0.8487568846153847, 0.8823501538461538, 0.9854070769230769], 
             UndirectedEdge[71, 194] -> 
             RGBColor[
              0.8784702307692308, 0.9056580000000001, 0.9749009615384616], 
             UndirectedEdge[47, 339] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[108, 410] -> 
             RGBColor[
              0.6611346923076923, 0.7319377692307691, 0.9690863846153847], 
             UndirectedEdge[193, 196] -> 
             RGBColor[0.8113893076923077, 0.853452, 0.9782441153846153], 
             UndirectedEdge[131, 171] -> 
             RGBColor[
              0.6795264230769231, 0.747472923076923, 0.9703673846153846], 
             UndirectedEdge[203, 258] -> 
             RGBColor[
              0.5756045000000001, 0.6657127692307692, 0.9601621538461538], 
             UndirectedEdge[164, 428] -> 
             RGBColor[
              0.5982031538461539, 0.6821996153846153, 0.9629666923076923], 
             UndirectedEdge[143, 325] -> 
             RGBColor[
              0.6615369615384616, 0.7348486923076925, 0.9673563846153845], 
             UndirectedEdge[101, 498] -> 
             RGBColor[
              0.6179121153846154, 0.6994320769230769, 0.963922076923077], 
             UndirectedEdge[35, 391] -> 
             RGBColor[
              0.7092397692307693, 0.7707807692307692, 0.9598612692307693], 
             UndirectedEdge[8, 221] -> 
             RGBColor[
              0.6384196538461538, 0.4502797307692307, 0.5700724615384616], 
             UndirectedEdge[240, 251] -> 
             RGBColor[0.7298389999999999, 0.42733099999999996`, 0.564603], 
             UndirectedEdge[464, 485] -> 
             RGBColor[0.7940223076923076, 0.837483, 0.8941852692307694], 
             UndirectedEdge[104, 452] -> 
             RGBColor[0.47055946153846145`, 0.5759405, 0.9526566538461538], 
             UndirectedEdge[121, 475] -> 
             RGBColor[
              0.5551093076923077, 0.6497017692307692, 0.9581193846153846], 
             UndirectedEdge[168, 315] -> 
             RGBColor[
              0.6602197307692308, 0.7331513846153845, 0.9676819999999999], 
             UndirectedEdge[65, 320] -> 
             RGBColor[
              0.6820321538461539, 0.7508596923076922, 0.9693991538461538], 
             UndirectedEdge[323, 452] -> 
             RGBColor[0.5320450384615385, 0.6239735, 0.9587849615384616], 
             UndirectedEdge[72, 322] -> 
             RGBColor[
              0.5982031538461539, 0.6821996153846153, 0.9629666923076923], 
             UndirectedEdge[60, 327] -> 
             RGBColor[
              0.6962839230769231, 0.7551518076923076, 0.8139405000000003], 
             UndirectedEdge[1, 135] -> 
             RGBColor[
              0.7146905769230768, 0.7758275384615383, 0.9733580384615385], 
             UndirectedEdge[420, 439] -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 
             UndirectedEdge[134, 367] -> 
             RGBColor[
              0.36435061538461533`, 0.490003923076923, 0.944437076923077], 
             UndirectedEdge[119, 345] -> 
             RGBColor[
              0.9003747307692309, 0.9202936153846154, 0.8616604230769231], 
             UndirectedEdge[64, 366] -> 
             RGBColor[
              0.7204304615384616, 0.7791267692307692, 0.9409183461538462], 
             UndirectedEdge[86, 90] -> 
             RGBColor[
              0.5686541923076923, 0.6548648846153846, 0.9618206923076923], 
             UndirectedEdge[81, 426] -> 
             RGBColor[0.6010684615384616, 0.681748, 0.9644135384615384], 
             UndirectedEdge[70, 265] -> 
             RGBColor[
              0.8015582307692308, 0.8450465384615384, 0.9808173076923077], 
             UndirectedEdge[245, 438] -> 
             RGBColor[
              0.8978155000000001, 0.9192353076923077, 0.9040735000000002], 
             UndirectedEdge[121, 259] -> 
             RGBColor[
              0.637090076923077, 0.7137457692307692, 0.9662904615384615], 
             UndirectedEdge[74, 105] -> 
             RGBColor[
              0.8621086153846154, 0.8929964615384616, 0.9866805769230769], 
             UndirectedEdge[358, 430] -> 
             RGBColor[
              0.6602197307692308, 0.7331513846153845, 0.9676819999999999], 
             UndirectedEdge[43, 316] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[162, 203] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[226, 236] -> 
             RGBColor[0.6010684615384616, 0.681748, 0.9644135384615384], 
             UndirectedEdge[110, 340] -> 
             RGBColor[
              0.9003747307692309, 0.9202936153846154, 0.8616604230769231], 
             UndirectedEdge[145, 407] -> 
             RGBColor[
              0.5777079615384616, 0.6661886153846155, 0.9609239230769231], 
             UndirectedEdge[258, 289] -> 
             RGBColor[
              0.7148351153846153, 0.7749537692307692, 0.9503898076923076], 
             UndirectedEdge[13, 334] -> 
             RGBColor[
              0.7696506538461538, 0.8187163846153847, 0.9348811923076923], 
             UndirectedEdge[300, 389] -> 
             RGBColor[
              0.7709302692307691, 0.8192455384615385, 0.913674653846154], 
             UndirectedEdge[57, 363] -> 
             RGBColor[
              0.6628541923076923, 0.7365459999999999, 0.9670307692307691], 
             UndirectedEdge[305, 427] -> 
             RGBColor[
              0.7734894999999999, 0.8203038461538461, 0.8712615769230769], 
             UndirectedEdge[277, 419] -> 
             RGBColor[0.6010684615384616, 0.681748, 0.9644135384615384], 
             UndirectedEdge[40, 349] -> 
             RGBColor[
              0.835405153846154, 0.8717038461538462, 0.9841335769230769], 
             UndirectedEdge[28, 241] -> 
             RGBColor[
              0.8707416923076923, 0.5059500384615386, 0.2138560384615385], 
             UndirectedEdge[164, 396] -> 
             RGBColor[
              0.8015582307692308, 0.8450465384615384, 0.9808173076923077], 
             UndirectedEdge[111, 284] -> 
             RGBColor[
              0.6628541923076923, 0.7365459999999999, 0.9670307692307691], 
             UndirectedEdge[25, 343] -> 
             RGBColor[
              0.8595971153846155, 0.8879907692307694, 0.8272385769230772], 
             UndirectedEdge[84, 131] -> 
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937], 
             UndirectedEdge[169, 244] -> 
             RGBColor[
              0.884065576923077, 0.9098310000000001, 0.9654294999999999], 
             UndirectedEdge[219, 363] -> 
             RGBColor[
              0.7902634230769231, 0.6892728461538464, 0.6024941153846154], 
             UndirectedEdge[400, 415] -> 
             RGBColor[
              0.7038445769230769, 0.7685679999999999, 0.9711163076923077], 
             UndirectedEdge[248, 286] -> 
             RGBColor[
              0.4982237692307693, 0.6020097307692307, 0.9540583076923077], 
             UndirectedEdge[136, 484] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[74, 263] -> 
             RGBColor[
              0.9286629615384614, 0.9458584615384615, 0.9897228461538461], 
             UndirectedEdge[69, 142] -> 
             RGBColor[
              0.8691657307692308, 0.8979929999999999, 0.9539152692307693], 
             UndirectedEdge[109, 409] -> 
             RGBColor[
              0.6630806153846154, 0.7305214615384615, 0.9469829615384615], 
             UndirectedEdge[101, 219] -> 
             RGBColor[
              0.8107586153846155, 0.7052838461538464, 0.6045368846153847], 
             UndirectedEdge[380, 390] -> 
             RGBColor[
              0.7478382307692306, 0.8010080769230769, 0.9331640384615385], 
             UndirectedEdge[53, 293] -> 
             RGBColor[
              0.7298646538461538, 0.7848872307692307, 0.8678272692307692], 
             UndirectedEdge[221, 258] -> 
             RGBColor[
              0.6568113846153847, 0.46581488461538456`, 0.5713534615384614], 
             UndirectedEdge[235, 424] -> 
             RGBColor[
              0.5405313846153846, 0.6357290384615384, 0.9578182307692308], 
             UndirectedEdge[367, 457] -> 
             RGBColor[
              0.5200361923076923, 0.6197180384615384, 0.9557754615384615], 
             UndirectedEdge[58, 220] -> 
             RGBColor[
              0.884065576923077, 0.9098310000000001, 0.9654294999999999], 
             UndirectedEdge[334, 379] -> 
             RGBColor[
              0.7584599615384615, 0.8103703846153846, 0.9538241153846154], 
             UndirectedEdge[14, 163] -> 
             RGBColor[
              0.5443451923076924, 0.6372914615384616, 0.9587980769230768], 
             UndirectedEdge[284, 442] -> 
             RGBColor[
              0.7801278461538461, 0.8289524615384615, 0.9785094999999999], 
             UndirectedEdge[130, 302] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[65, 428] -> 
             RGBColor[
              0.5982031538461539, 0.6821996153846153, 0.9629666923076923], 
             UndirectedEdge[388, 487] -> 
             RGBColor[
              0.9005875000000001, 0.9200127692307692, 0.8313241153846156], 
             UndirectedEdge[456, 458] -> 
             RGBColor[
              0.5987341538461537, 0.6851183846153845, 0.9615536923076923], 
             UndirectedEdge[281, 465] -> 
             RGBColor[
              0.7810630384615386, 0.8290355384615385, 0.9787745384615385], 
             UndirectedEdge[166, 428] -> 
             RGBColor[
              0.5777079615384616, 0.6661886153846155, 0.9609239230769231], 
             UndirectedEdge[92, 128] -> 
             RGBColor[0.951044346153846, 0.9625504615384615, 0.951837], 
             UndirectedEdge[120, 457] -> 
             RGBColor[
              0.7038445769230769, 0.7685679999999999, 0.9711163076923077], 
             UndirectedEdge[79, 329] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[105, 195] -> 
             RGBColor[
              0.8621086153846154, 0.8929964615384616, 0.9866805769230769], 
             UndirectedEdge[98, 377] -> 
             RGBColor[
              0.8487568846153847, 0.8823501538461538, 0.9854070769230769], 
             UndirectedEdge[21, 309] -> 
             RGBColor[
              0.6528229615384615, 0.7261803076923077, 0.9678203846153846], 
             UndirectedEdge[93, 322] -> 
             RGBColor[0.8635703846153846, 0.89382, 0.9633867307692308], 
             UndirectedEdge[8, 115] -> 
             RGBColor[
              0.5982031538461539, 0.6821996153846153, 0.9629666923076923], 
             UndirectedEdge[54, 131] -> 
             RGBColor[
              0.6444533076923077, 0.7174891923076923, 0.9680234615384615], 
             UndirectedEdge[186, 212] -> 
             RGBColor[
              0.8367684230769231, 0.7451890769230769, 0.6111218846153846], 
             UndirectedEdge[252, 467] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[244, 378] -> 
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153], 
             UndirectedEdge[55, 339] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[69, 490] -> 
             RGBColor[
              0.6384073076923076, 0.7154430769230768, 0.9659648461538461], 
             UndirectedEdge[299, 451] -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 
             UndirectedEdge[146, 464] -> 
             RGBColor[
              0.8773203076923077, 0.9032243076923077, 0.9020307307692309], 
             UndirectedEdge[199, 220] -> 
             RGBColor[
              0.7584599615384615, 0.8103703846153846, 0.9538241153846154], 
             UndirectedEdge[345, 426] -> 
             RGBColor[
              0.9161076153846155, 0.9327281538461538, 0.8631903461538462], 
             UndirectedEdge[66, 472] -> 
             RGBColor[
              0.8077171153846154, 0.7605015384615387, 0.6166428076923077], 
             UndirectedEdge[40, 114] -> 
             RGBColor[
              0.7097995384615384, 0.7722432307692307, 0.9725281923076923], 
             UndirectedEdge[248, 294] -> 
             RGBColor[
              0.6020169615384616, 0.6837620384615384, 0.9639465384615384], 
             UndirectedEdge[304, 483] -> 
             RGBColor[
              0.8015582307692308, 0.8450465384615384, 0.9808173076923077], 
             UndirectedEdge[9, 425] -> 
             RGBColor[
              0.637090076923077, 0.7137457692307692, 0.9662904615384615], 
             UndirectedEdge[290, 384] -> 
             RGBColor[
              0.6746353846153845, 0.7438886153846154, 0.9695375384615385], 
             UndirectedEdge[294, 358] -> 
             RGBColor[
              0.7858253461538462, 0.8326119999999999, 0.9792873846153847], 
             UndirectedEdge[148, 342] -> 
             RGBColor[0.5320450384615385, 0.6239735, 0.9587849615384616], 
             UndirectedEdge[178, 420] -> 
             RGBColor[
              0.8965358846153847, 0.9187061538461538, 0.9252800384615385], 
             UndirectedEdge[193, 354] -> 
             RGBColor[0.8280885, 0.836280153846154, 0.6590071923076923], 
             UndirectedEdge[194, 228] -> 
             RGBColor[0.9674059615384615, 0.975212, 0.9400573846153846], 
             UndirectedEdge[326, 491] -> 
             RGBColor[
              0.9561628076923077, 0.964667076923077, 0.8670108461538462], 
             UndirectedEdge[324, 481] -> 
             RGBColor[
              0.9159997307692308, 0.9317614615384615, 0.7979528461538461], 
             UndirectedEdge[94, 213] -> 
             RGBColor[
              0.7155690769230769, 0.5898297692307692, 0.5881935769230768], 
             UndirectedEdge[92, 175] -> 
             RGBColor[
              0.7696506538461538, 0.8187163846153847, 0.9348811923076923], 
             UndirectedEdge[254, 401] -> 
             RGBColor[
              0.703844576923077, 0.7685680000000001, 0.9711163076923077], 
             UndirectedEdge[161, 491] -> 
             RGBColor[
              0.8183939615384614, 0.8562496153846153, 0.8534893461538462], 
             UndirectedEdge[172, 303] -> 
             RGBColor[
              0.7025273461538463, 0.7668706923076923, 0.9714419230769231], 
             UndirectedEdge[57, 274] -> 
             RGBColor[
              0.6628541923076923, 0.7365459999999999, 0.9670307692307691], 
             UndirectedEdge[44, 360] -> 
             RGBColor[
              0.49309273076923066`, 0.5987499999999999, 0.9534040769230769], 
             UndirectedEdge[170, 238] -> 
             RGBColor[
              0.637090076923077, 0.7137457692307692, 0.9662904615384615], 
             UndirectedEdge[5, 11] -> 
             RGBColor[
              0.6746353846153845, 0.7438886153846154, 0.9695375384615385], 
             UndirectedEdge[3, 223] -> 
             RGBColor[
              0.9122687692307693, 0.9311406923076924, 0.9268099615384616], 
             UndirectedEdge[65, 227] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[78, 85] -> 
             RGBColor[
              0.674486423076923, 0.7425840769230769, 0.9703598846153847], 
             UndirectedEdge[181, 393] -> 
             RGBColor[
              0.4982237692307693, 0.6020097307692307, 0.9540583076923077], 
             UndirectedEdge[45, 56] -> 
             RGBColor[
              0.6820321538461539, 0.7508596923076922, 0.9693991538461538], 
             UndirectedEdge[141, 310] -> 
             RGBColor[
              0.7097995384615384, 0.7722432307692307, 0.9725281923076923], 
             UndirectedEdge[39, 236] -> 
             RGBColor[
              0.6964478076923077, 0.7615969230769231, 0.9712546923076923], 
             UndirectedEdge[337, 375] -> 
             RGBColor[
              0.7531694615384614, 0.8028438461538461, 0.8180015769230772], 
             UndirectedEdge[57, 334] -> 
             RGBColor[
              0.5987341538461537, 0.6851183846153845, 0.9615536923076923], 
             UndirectedEdge[123, 438] -> 
             RGBColor[
              0.7503974615384614, 0.8020663846153846, 0.8907509615384617], 
             UndirectedEdge[35, 385] -> 
             RGBColor[
              0.7746770384615385, 0.8239056923076924, 0.9650127307692308], 
             UndirectedEdge[268, 285] -> 
             RGBColor[
              0.841613423076923, 0.8769854615384615, 0.9846378076923077], 
             UndirectedEdge[169, 361] -> 
             RGBColor[0.8635703846153846, 0.89382, 0.9633867307692308], 
             UndirectedEdge[337, 361] -> 
             RGBColor[
              0.6384073076923076, 0.7154430769230768, 0.9659648461538461], 
             UndirectedEdge[119, 270] -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 
             UndirectedEdge[254, 386] -> 
             RGBColor[
              0.5756045000000001, 0.6657127692307692, 0.9601621538461538], 
             UndirectedEdge[253, 488] -> 
             RGBColor[
              0.6964478076923077, 0.7615969230769231, 0.9712546923076923], 
             UndirectedEdge[340, 380] -> 
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153], 
             UndirectedEdge[388, 490] -> 
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153], 
             UndirectedEdge[27, 311] -> 
             RGBColor[
              0.703844576923077, 0.7685680000000001, 0.9711163076923077], 
             UndirectedEdge[222, 417] -> 
             RGBColor[
              0.7739195769230769, 0.8236708461538462, 0.9780052692307692], 
             UndirectedEdge[274, 361] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[65, 474] -> 
             RGBColor[
              0.5815217692307693, 0.6677510384615384, 0.9619037692307693], 
             UndirectedEdge[243, 326] -> 
             RGBColor[
              0.6928781538461538, 0.7581192307692307, 0.9716408846153846], 
             UndirectedEdge[47, 437] -> 
             RGBColor[
              0.7400726538461538, 0.7970135384615384, 0.9746889999999999], 
             UndirectedEdge[232, 414] -> 
             RGBColor[
              0.8798795384615385, 0.9042826153846153, 0.859617653846154], 
             UndirectedEdge[102, 196] -> 
             RGBColor[
              0.703644423076923, 0.7666077692307691, 0.9693327307692308], 
             UndirectedEdge[90, 257] -> 
             RGBColor[
              0.6476915769230769, 0.6763329615384616, 0.629247076923077], 
             UndirectedEdge[116, 310] -> 
             RGBColor[
              0.7097995384615384, 0.7722432307692307, 0.9725281923076923], 
             UndirectedEdge[333, 459] -> 
             RGBColor[
              0.6852526923076923, 0.7510726153846153, 0.9680517307692308], 
             UndirectedEdge[68, 257] -> 
             RGBColor[0.941146, 0.9144645384615385, 0.6541069615384616], 
             UndirectedEdge[220, 349] -> 
             RGBColor[
              0.884065576923077, 0.9098310000000001, 0.9654294999999999], 
             UndirectedEdge[92, 204] -> 
             RGBColor[
              0.6909526923076923, 0.7533160384615385, 0.9291029615384616], 
             UndirectedEdge[120, 123] -> 
             RGBColor[
              0.6384073076923076, 0.7154430769230768, 0.9659648461538461], 
             UndirectedEdge[190, 224] -> 
             RGBColor[
              0.8866031538461538, 0.577973230769231, 0.22709123076923082`], 
             UndirectedEdge[450, 469] -> 
             RGBColor[
              0.7801278461538461, 0.8289524615384615, 0.9785094999999999], 
             UndirectedEdge[405, 434] -> 
             RGBColor[
              0.8186067307692307, 0.8559687692307691, 0.8231530384615386], 
             UndirectedEdge[312, 400] -> 
             RGBColor[
              0.8015582307692308, 0.8450465384615384, 0.9808173076923077], 
             UndirectedEdge[100, 259] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[87, 423] -> 
             RGBColor[
              0.9135483846153847, 0.9316698461538462, 0.9056034230769232], 
             UndirectedEdge[403, 449] -> 
             RGBColor[
              0.8909051153846155, 0.8446363076923078, 0.6291042692307692], 
             UndirectedEdge[268, 275] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[166, 210] -> 
             RGBColor[
              0.6179121153846154, 0.6994320769230769, 0.963922076923077], 
             UndirectedEdge[102, 496] -> 
             RGBColor[
              0.44946788461538456`, 0.5633333846153845, 0.9499697692307693], 
             UndirectedEdge[11, 202] -> 
             RGBColor[
              0.5551093076923077, 0.6497017692307692, 0.9581193846153846], 
             UndirectedEdge[187, 494] -> 
             RGBColor[
              0.6602197307692308, 0.7331513846153845, 0.9676819999999999], 
             UndirectedEdge[158, 282] -> 
             RGBColor[
              0.7739195769230769, 0.8236708461538462, 0.9780052692307692], 
             UndirectedEdge[232, 372] -> 
             RGBColor[0.8635703846153846, 0.89382, 0.9633867307692308], 
             UndirectedEdge[143, 477] -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 
             UndirectedEdge[479, 482] -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 
             UndirectedEdge[45, 283] -> 
             RGBColor[
              0.7182602307692308, 0.7793052307692308, 0.9729718461538461], 
             UndirectedEdge[323, 463] -> 
             RGBColor[
              0.8427379615384616, 0.7688563076923076, 0.6159251153846154], 
             UndirectedEdge[130, 347] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[338, 369] -> 
             RGBColor[
              0.841613423076923, 0.8769854615384615, 0.9846378076923077], 
             UndirectedEdge[143, 386] -> 
             RGBColor[
              0.5960996923076924, 0.6817237692307693, 0.9622049230769231], 
             UndirectedEdge[168, 254] -> 
             RGBColor[
              0.6192293461538461, 0.7011293846153845, 0.9635964615384616], 
             UndirectedEdge[86, 115] -> 
             RGBColor[
              0.7858253461538462, 0.8326119999999999, 0.9792873846153847], 
             UndirectedEdge[138, 457] -> 
             RGBColor[
              0.6628541923076923, 0.7365459999999999, 0.9670307692307691], 
             UndirectedEdge[11, 497] -> 
             RGBColor[
              0.47128030769230755`, 0.5810416923076922, 0.9516869230769232], 
             UndirectedEdge[154, 379] -> 
             RGBColor[
              0.9409781923076923, 0.8460753076923077, 0.6020672307692307], 
             UndirectedEdge[17, 467] -> 
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153], 
             UndirectedEdge[75, 93] -> 
             RGBColor[
              0.9781197692307693, 0.9815016153846154, 0.8457597692307692], 
             UndirectedEdge[100, 315] -> 
             RGBColor[
              0.8015582307692308, 0.8450465384615384, 0.9808173076923077], 
             UndirectedEdge[45, 52] -> 
             RGBColor[
              0.7914630769230769, 0.8364246923076923, 0.9365983461538461], 
             UndirectedEdge[8, 203] -> 
             RGBColor[
              0.5572127692307692, 0.6501776153846154, 0.9588811538461539], 
             UndirectedEdge[244, 340] -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 
             UndirectedEdge[104, 190] -> 
             RGBColor[
              0.759193923076923, 0.6252463846153846, 0.5916278846153846], 
             UndirectedEdge[38, 437] -> 
             RGBColor[
              0.6628541923076923, 0.7365459999999999, 0.9670307692307691], 
             UndirectedEdge[96, 465] -> 
             RGBColor[0.6010684615384616, 0.681748, 0.9644135384615384], 
             UndirectedEdge[48, 346] -> 
             RGBColor[
              0.725456846153846, 0.7843160769230768, 0.9710498846153846], 
             UndirectedEdge[153, 342] -> 
             RGBColor[
              0.8149099615384616, 0.8556928461538461, 0.9820908076923076], 
             UndirectedEdge[151, 327] -> 
             RGBColor[
              0.8391019230769231, 0.8719797692307693, 0.8251958076923079], 
             UndirectedEdge[375, 489] -> 
             RGBColor[
              0.7313570384615384, 0.7851355384615384, 0.8162844230769233], 
             UndirectedEdge[203, 289] -> 
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923], 
             UndirectedEdge[6, 79] -> 
             RGBColor[
              0.8015582307692308, 0.8450465384615384, 0.9808173076923077], 
             UndirectedEdge[105, 463] -> 
             RGBColor[
              0.863233153846154, 0.7848673076923076, 0.6179678846153847], 
             UndirectedEdge[10, 125] -> 
             RGBColor[
              0.5686541923076923, 0.6548648846153846, 0.9618206923076923], 
             UndirectedEdge[32, 331] -> 
             RGBColor[
              0.7749818846153846, 0.8205521538461538, 0.8197187307692311], 
             UndirectedEdge[26, 44] -> 
             RGBColor[
              0.7584599615384615, 0.8103703846153846, 0.9538241153846154], 
             UndirectedEdge[86, 253] -> 
             RGBColor[
              0.6807149230769232, 0.7491623846153845, 0.9697247692307692], 
             UndirectedEdge[370, 466] -> 
             RGBColor[
              0.9153112307692307, 0.9352121538461537, 0.9884493461538462], 
             UndirectedEdge[301, 456] -> 
             RGBColor[
              0.5332968846153845, 0.6319934615384615, 0.9564022307692308], 
             UndirectedEdge[21, 337] -> 
             RGBColor[
              0.6746353846153845, 0.7438886153846154, 0.9695375384615385], 
             UndirectedEdge[61, 172] -> 
             RGBColor[
              0.6820321538461539, 0.7508596923076922, 0.9693991538461538], 
             UndirectedEdge[291, 359] -> 
             RGBColor[0.52385, 0.6212804615384615, 0.9567553076923077], 
             UndirectedEdge[134, 499] -> 
             RGBColor[
              0.6110905384615384, 0.6885920384615384, 0.9658976153846154], 
             UndirectedEdge[140, 244] -> 
             RGBColor[0.8728748846153846, 0.901485, 0.9843724230769231], 
             UndirectedEdge[108, 364] -> 
             RGBColor[0.9235781153846154, 0.8895961538461539, 0.6364545], 
             UndirectedEdge[113, 421] -> 
             RGBColor[0.5225820000000001, 0.6084965, 0.9591216538461538], 
             UndirectedEdge[54, 55] -> 
             RGBColor[
              0.6177498461538462, 0.6961965769230769, 0.9654764615384616], 
             UndirectedEdge[56, 210] -> 
             RGBColor[
              0.6384073076923076, 0.7154430769230768, 0.9659648461538461], 
             UndirectedEdge[36, 58] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[25, 288] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[262, 344] -> 
             RGBColor[
              0.9398536538461537, 0.9542044615384615, 0.9707799230769231], 
             UndirectedEdge[8, 439] -> 
             RGBColor[
              0.6186983461538462, 0.6982106153846154, 0.9650094615384616], 
             UndirectedEdge[102, 186] -> 
             RGBColor[
              0.6880331538461539, 0.6263228461538461, 0.5981249615384616], 
             UndirectedEdge[85, 145] -> 
             RGBColor[
              0.8211182307692309, 0.8609744615384616, 0.9825950384615385], 
             UndirectedEdge[421, 423] -> 
             RGBColor[
              0.6140769615384615, 0.6791088076923077, 0.8818650000000001], 
             UndirectedEdge[406, 476] -> 
             RGBColor[
              0.637090076923077, 0.7137457692307692, 0.9662904615384615], 
             UndirectedEdge[111, 400] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[137, 183] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[85, 358] -> 
             RGBColor[
              0.841613423076923, 0.8769854615384615, 0.9846378076923077], 
             UndirectedEdge[399, 412] -> 
             RGBColor[0.8511380384615386, 0.8841383846153846, 0.9856635], 
             UndirectedEdge[283, 292] -> 
             RGBColor[
              0.8942031153846154, 0.9180925384615385, 0.9764308846153846], 
             UndirectedEdge[240, 310] -> 
             RGBColor[
              0.6862141538461538, 0.3919143846153846, 0.5611686923076923], 
             UndirectedEdge[186, 300] -> 
             RGBColor[
              0.7316579999999999, 0.6617394615384615, 0.6015592692307692], 
             UndirectedEdge[37, 240] -> 
             RGBColor[0.8542561153846153, 0.5251021538461538, 0.576851], 
             UndirectedEdge[36, 429] -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 
             UndirectedEdge[56, 276] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[95, 174] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[7, 28] -> 
             RGBColor[
              0.666657076923077, 0.5304054230769232, 0.5803475384615384], 
             UndirectedEdge[251, 367] -> 
             RGBColor[
              0.5200361923076923, 0.6197180384615384, 0.9557754615384615], 
             UndirectedEdge[31, 314] -> 
             RGBColor[
              0.5769217307692307, 0.6674100769230769, 0.9598365384615384], 
             UndirectedEdge[238, 436] -> 
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153], 
             UndirectedEdge[291, 488] -> 
             RGBColor[
              0.7605678461538462, 0.8130245384615384, 0.9767317692307692], 
             UndirectedEdge[96, 171] -> 
             RGBColor[
              0.41610511538461536`, 0.5344362307692307, 0.9478439230769231], 
             UndirectedEdge[127, 179] -> 
             RGBColor[0.8280885, 0.836280153846154, 0.6590071923076923], 
             UndirectedEdge[296, 453] -> 
             RGBColor[
              0.9153112307692307, 0.9352121538461537, 0.9884493461538462], 
             UndirectedEdge[14, 494] -> 
             RGBColor[
              0.6397245384615384, 0.7171403846153847, 0.9656392307692307], 
             UndirectedEdge[317, 420] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[7, 388] -> 
             RGBColor[
              0.637090076923077, 0.7137457692307692, 0.9662904615384615], 
             UndirectedEdge[146, 271] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[331, 449] -> 
             RGBColor[
              0.7495666153846154, 0.7327411538461539, 0.6159689615384616], 
             UndirectedEdge[27, 359] -> 
             RGBColor[0.52385, 0.6212804615384615, 0.9567553076923077], 
             UndirectedEdge[100, 471] -> 
             RGBColor[
              0.7810630384615386, 0.8290355384615385, 0.9787745384615385], 
             UndirectedEdge[219, 337] -> 
             RGBColor[
              0.7043309615384614, 0.6201369230769231, 0.5952998846153846], 
             UndirectedEdge[199, 419] -> 
             RGBColor[
              0.45972996153846146`, 0.5698528461538461, 0.9512782307692307], 
             UndirectedEdge[266, 437] -> 
             RGBColor[
              0.5367175769230769, 0.6341666153846153, 0.9568383846153846], 
             UndirectedEdge[327, 399] -> 
             RGBColor[
              0.9296721153846155, 0.9430936153846154, 0.8341275384615388], 
             UndirectedEdge[311, 419] -> 
             RGBColor[
              0.5443451923076924, 0.6372914615384616, 0.9587980769230768], 
             UndirectedEdge[267, 329] -> 
             RGBColor[
              0.6020169615384616, 0.6837620384615384, 0.9639465384615384], 
             UndirectedEdge[219, 244] -> 
             RGBColor[
              0.8517490000000001, 0.7373058461538464, 0.6086224230769232], 
             UndirectedEdge[17, 205] -> 
             RGBColor[0.45459892307692296`, 0.5665931153846153, 0.950624], 
             UndirectedEdge[175, 361] -> 
             RGBColor[
              0.6602197307692308, 0.7331513846153845, 0.9676819999999999], 
             UndirectedEdge[189, 266] -> 
             RGBColor[
              0.5777079615384616, 0.6661886153846155, 0.9609239230769231], 
             UndirectedEdge[225, 280] -> 
             RGBColor[0.9394292307692307, 0.954347, 0.9874146923076923], 
             UndirectedEdge[300, 458] -> 
             RGBColor[
              0.5987341538461537, 0.6851183846153845, 0.9615536923076923], 
             UndirectedEdge[171, 343] -> 
             RGBColor[
              0.7313570384615384, 0.7851355384615384, 0.8162844230769233], 
             UndirectedEdge[358, 408] -> 
             RGBColor[
              0.6165948846153846, 0.6977347692307692, 0.9642476923076924], 
             UndirectedEdge[380, 411] -> 
             RGBColor[
              0.5769217307692307, 0.6674100769230769, 0.9598365384615384], 
             UndirectedEdge[345, 498] -> 
             RGBColor[
              0.7529566923076922, 0.8031246923076922, 0.8483378846153846], 
             UndirectedEdge[161, 450] -> 
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988], 
             UndirectedEdge[94, 214] -> 
             RGBColor[
              0.856907576923077, 0.7017249230769231, 0.6013288846153846], 
             UndirectedEdge[157, 343] -> 
             RGBColor[
              0.7749818846153846, 0.8205521538461538, 0.8197187307692311], 
             UndirectedEdge[155, 332] -> 
             RGBColor[
              0.8387812692307692, 0.8712939230769231, 0.7902946153846153], 
             UndirectedEdge[127, 168] -> 
             RGBColor[
              0.7639684615384614, 0.7848525384615385, 0.6535301153846154], 
             UndirectedEdge[378, 380] -> 
             RGBColor[
              0.5114844615384614, 0.6142851538461537, 0.9546850769230769], 
             UndirectedEdge[160, 481] -> 
             RGBColor[
              0.6626004999999999, 0.7255688076923077, 0.7769134615384614], 
             UndirectedEdge[23, 485] -> 
             RGBColor[
              0.5332968846153847, 0.6319934615384615, 0.9564022307692308], 
             UndirectedEdge[352, 399] -> 
             RGBColor[0.8511380384615386, 0.8841383846153846, 0.9856635], 
             UndirectedEdge[389, 456] -> 
             RGBColor[
              0.7709302692307691, 0.8192455384615385, 0.913674653846154], 
             UndirectedEdge[105, 263] -> 
             RGBColor[0.8728748846153846, 0.901485, 0.9843724230769231], 
             UndirectedEdge[143, 347] -> 
             RGBColor[
              0.703844576923077, 0.7685680000000001, 0.9711163076923077], 
             UndirectedEdge[98, 484] -> 
             RGBColor[
              0.8487568846153847, 0.8823501538461538, 0.9854070769230769], 
             UndirectedEdge[100, 500] -> 
             RGBColor[
              0.9122687692307693, 0.9311406923076924, 0.9268099615384616], 
             UndirectedEdge[89, 424] -> 
             RGBColor[
              0.6628541923076923, 0.7365459999999999, 0.9670307692307691], 
             UndirectedEdge[231, 442] -> 
             RGBColor[
              0.841613423076923, 0.8769854615384615, 0.9846378076923077], 
             UndirectedEdge[15, 104] -> 
             RGBColor[0.799161, 0.791825, 0.6242064999999999], 
             UndirectedEdge[75, 182] -> 
             RGBColor[
              0.972524423076923, 0.9773286153846155, 0.8552312307692309], 
             UndirectedEdge[290, 316] -> 
             RGBColor[
              0.6746353846153845, 0.7438886153846154, 0.9695375384615385], 
             UndirectedEdge[344, 424] -> 
             RGBColor[
              0.8006230384615385, 0.8449634615384616, 0.9805522692307692], 
             UndirectedEdge[369, 425] -> 
             RGBColor[
              0.8621086153846154, 0.8929964615384616, 0.9866805769230769], 
             UndirectedEdge[106, 255] -> 
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484], 
             UndirectedEdge[84, 242] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[143, 446] -> 
             RGBColor[
              0.8595971153846155, 0.8879907692307694, 0.8272385769230772], 
             UndirectedEdge[376, 415] -> 
             RGBColor[
              0.8179654230769231, 0.8545970769230768, 0.7533506538461539], 
             UndirectedEdge[93, 108] -> 
             RGBColor[
              0.926501923076923, 0.9435581538461538, 0.969506423076923], 
             UndirectedEdge[78, 183] -> 
             RGBColor[
              0.6186983461538462, 0.6982106153846154, 0.9650094615384616], 
             UndirectedEdge[17, 298] -> 
             RGBColor[
              0.5114844615384614, 0.6142851538461537, 0.9546850769230769], 
             UndirectedEdge[204, 370] -> 
             RGBColor[
              0.6685713076923077, 0.7366240384615383, 0.9669888076923077], 
             UndirectedEdge[208, 314] -> 
             RGBColor[
              0.7277541923076922, 0.7150328461538462, 0.6142518076923077], 
             UndirectedEdge[313, 379] -> 
             RGBColor[
              0.9768401538461537, 0.9809724615384615, 0.8669663076923078], 
             UndirectedEdge[3, 221] -> 
             RGBColor[
              0.8417747307692308, 0.6131266538461538, 0.5879230769230769], 
             UndirectedEdge[154, 229] -> 
             RGBColor[
              0.7376275384615385, 0.6854066923076922, 0.6063624999999999], 
             UndirectedEdge[25, 180] -> 
             RGBColor[
              0.703844576923077, 0.7685680000000001, 0.9711163076923077], 
             UndirectedEdge[371, 419] -> 
             RGBColor[
              0.6796025384615385, 0.7407032307692307, 0.8128775769230772], 
             UndirectedEdge[31, 419] -> 
             RGBColor[
              0.5033548076923077, 0.6052694615384615, 0.9547125384615385], 
             UndirectedEdge[321, 482] -> 
             RGBColor[
              0.6807149230769232, 0.7491623846153845, 0.9697247692307692], 
             UndirectedEdge[212, 300] -> 
             RGBColor[
              0.6602197307692308, 0.7331513846153845, 0.9676819999999999], 
             UndirectedEdge[376, 414] -> 
             RGBColor[
              0.9940003846153846, 0.9903116923076923, 0.6418520000000001], 
             UndirectedEdge[140, 274] -> 
             RGBColor[0.8113893076923077, 0.853452, 0.9782441153846153], 
             UndirectedEdge[1, 131] -> 
             RGBColor[
              0.7013388461538461, 0.7651812307692307, 0.9720845384615384], 
             UndirectedEdge[360, 466] -> 
             RGBColor[
              0.6611346923076923, 0.7319377692307691, 0.9690863846153847], 
             UndirectedEdge[165, 182] -> 
             RGBColor[0.950619923076923, 0.962693, 0.9684717692307693], 
             UndirectedEdge[268, 480] -> 
             RGBColor[
              0.6820321538461539, 0.7508596923076922, 0.9693991538461538], 
             UndirectedEdge[54, 385] -> 
             RGBColor[
              0.4982237692307693, 0.6020097307692307, 0.9540583076923077], 
             UndirectedEdge[149, 158] -> 
             RGBColor[0.8511380384615386, 0.8841383846153846, 0.9856635], 
             UndirectedEdge[229, 379] -> 
             RGBColor[
              0.7584599615384615, 0.8103703846153846, 0.9538241153846154], 
             UndirectedEdge[98, 253] -> 
             RGBColor[
              0.7231512692307691, 0.7828895384615384, 0.9738016923076923], 
             UndirectedEdge[121, 469] -> 
             RGBColor[
              0.6928781538461538, 0.7581192307692307, 0.9716408846153846], 
             UndirectedEdge[34, 269] -> 
             RGBColor[0.9019595, 0.9245658461538462, 0.9871758461538461], 
             UndirectedEdge[145, 286] -> 
             RGBColor[
              0.6615369615384616, 0.7348486923076925, 0.9673563846153845], 
             UndirectedEdge[34, 234] -> 
             RGBColor[
              0.835405153846154, 0.8717038461538462, 0.9841335769230769], 
             UndirectedEdge[85, 286] -> 
             RGBColor[
              0.7583154230769231, 0.8112441538461539, 0.9767923461538461], 
             UndirectedEdge[86, 261] -> 
             RGBColor[
              0.9005875000000001, 0.9200127692307692, 0.8313241153846156], 
             UndirectedEdge[140, 255] -> 
             RGBColor[
              0.9286629615384614, 0.9458584615384615, 0.9897228461538461], 
             UndirectedEdge[345, 448] -> 
             RGBColor[
              0.9161076153846155, 0.9327281538461538, 0.8631903461538462], 
             UndirectedEdge[146, 444] -> 
             RGBColor[
              0.7038445769230769, 0.7685679999999999, 0.9711163076923077], 
             UndirectedEdge[215, 224] -> 
             RGBColor[
              0.8517490000000001, 0.7373058461538464, 0.608622423076923], 
             UndirectedEdge[40, 359] -> 
             RGBColor[
              0.6144201923076923, 0.6923943076923077, 0.9656870384615384], 
             UndirectedEdge[88, 495] -> 
             RGBColor[
              0.6793897692307692, 0.7409840769230769, 0.8432138846153847], 
             UndirectedEdge[341, 403] -> 
             RGBColor[0.8511380384615386, 0.8841383846153846, 0.9856635], 
             UndirectedEdge[134, 416] -> 
             RGBColor[
              0.2699365384615384, 0.39899438461538456`, 0.9387591538461538], 
             UndirectedEdge[113, 423] -> 
             RGBColor[
              0.8978155000000001, 0.9192353076923077, 0.9040735000000002], 
             UndirectedEdge[204, 362] -> 
             RGBColor[
              0.5405313846153846, 0.6357290384615384, 0.9578182307692308], 
             UndirectedEdge[231, 256] -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             UndirectedEdge[183, 407] -> 
             RGBColor[
              0.6186983461538462, 0.6982106153846154, 0.9650094615384616], 
             UndirectedEdge[231, 271] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[106, 140] -> 
             RGBColor[0.9019595, 0.9245658461538462, 0.9871758461538461], 
             UndirectedEdge[96, 147] -> 
             RGBColor[
              0.41610511538461536`, 0.5344362307692307, 0.9478439230769231], 
             UndirectedEdge[149, 275] -> 
             RGBColor[
              0.7605678461538462, 0.8130245384615384, 0.9767317692307692], 
             UndirectedEdge[207, 287] -> 
             RGBColor[0.7667761153846153, 0.8183061538461538, 0.977236], 
             UndirectedEdge[223, 480] -> 
             RGBColor[
              0.7927426923076923, 0.8369538461538462, 0.9153918076923078], 
             UndirectedEdge[11, 102] -> 
             RGBColor[
              0.4896720384615384, 0.5965768461538461, 0.952967923076923], 
             UndirectedEdge[230, 339] -> 
             RGBColor[
              0.6186983461538462, 0.6982106153846154, 0.9650094615384616], 
             UndirectedEdge[103, 449] -> 
             RGBColor[
              0.9473219230769231, 0.8892367692307693, 0.6211451538461539], 
             UndirectedEdge[226, 396] -> 
             RGBColor[0.6010684615384616, 0.681748, 0.9644135384615384], 
             UndirectedEdge[144, 279] -> 
             RGBColor[
              0.6397245384615384, 0.7171403846153847, 0.9656392307692307], 
             UndirectedEdge[205, 228] -> 
             RGBColor[
              0.6909526923076923, 0.7533160384615385, 0.9291029615384616], 
             UndirectedEdge[267, 406] -> 
             RGBColor[
              0.6020169615384616, 0.6837620384615384, 0.9639465384615384], 
             UndirectedEdge[209, 233] -> 
             RGBColor[
              0.7528646153846152, 0.8061973846153846, 0.9632955769230769], 
             UndirectedEdge[387, 405] -> 
             RGBColor[
              0.6628541923076923, 0.7365459999999999, 0.9670307692307691], 
             UndirectedEdge[75, 206] -> 
             RGBColor[
              0.7311442692307693, 0.7854163846153845, 0.8466207307692308], 
             UndirectedEdge[183, 404] -> 
             RGBColor[0.8952562692307693, 0.918177, 0.9464865769230769], 
             UndirectedEdge[319, 488] -> 
             RGBColor[
              0.6344312307692308, 0.7106451538461538, 0.9665393846153847], 
             UndirectedEdge[220, 371] -> 
             RGBColor[
              0.9783325384615384, 0.9812207692307693, 0.8154234615384618], 
             UndirectedEdge[66, 460] -> 
             RGBColor[0.6815805, 0.658122153846154, 0.6064504230769232], 
             UndirectedEdge[87, 446] -> 
             RGBColor[
              0.9163203846153847, 0.9324473076923077, 0.8328540384615387], 
             UndirectedEdge[273, 308] -> 
             RGBColor[
              0.9209065769230769, 0.9393851538461538, 0.9789778846153847], 
             UndirectedEdge[326, 428] -> 
             RGBColor[
              0.674486423076923, 0.7425840769230769, 0.9703598846153847], 
             UndirectedEdge[130, 315] -> 
             RGBColor[
              0.7858253461538462, 0.8326119999999999, 0.9792873846153847], 
             UndirectedEdge[95, 407] -> 
             RGBColor[
              0.6186983461538462, 0.6982106153846154, 0.9650094615384616], 
             UndirectedEdge[148, 153] -> 
             RGBColor[
              0.5816248461538461, 0.663065346153846, 0.9636311538461538], 
             UndirectedEdge[85, 137] -> 
             RGBColor[
              0.8006230384615385, 0.8449634615384616, 0.9805522692307692], 
             UndirectedEdge[289, 359] -> 
             RGBColor[
              0.6630806153846154, 0.7305214615384615, 0.9469829615384615], 
             UndirectedEdge[32, 449] -> 
             RGBColor[
              0.9694391923076924, 0.9035915384615385, 0.47756830769230796`], 
             UndirectedEdge[329, 406] -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 
             UndirectedEdge[168, 213] -> 
             RGBColor[
              0.5551093076923076, 0.6497017692307692, 0.9581193846153846], 
             UndirectedEdge[111, 464] -> 
             RGBColor[
              0.836329923076923, 0.8712023076923077, 0.8979451923076924], 
             UndirectedEdge[50, 117] -> 
             RGBColor[
              0.6611346923076923, 0.7319377692307691, 0.9690863846153847], 
             UndirectedEdge[357, 420] -> 
             RGBColor[
              0.9002668461538462, 0.9193269230769231, 0.7964229230769231], 
             UndirectedEdge[153, 190] -> 
             RGBColor[
              0.8702593076923077, 0.7123712307692308, 0.6026023846153846], 
             UndirectedEdge[165, 275] -> 
             RGBColor[
              0.8169846538461538, 0.8576250000000001, 0.9687726538461539], 
             UndirectedEdge[152, 301] -> 
             RGBColor[
              0.5551093076923077, 0.6497017692307692, 0.9581193846153846], 
             UndirectedEdge[208, 349] -> 
             RGBColor[
              0.8751722307692309, 0.8322017692307693, 0.6275743461538461], 
             UndirectedEdge[5, 23] -> 
             RGBColor[
              0.6528229615384615, 0.7261803076923077, 0.9678203846153846], 
             UndirectedEdge[56, 227] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[56, 326] -> 
             RGBColor[
              0.841613423076923, 0.8769854615384615, 0.9846378076923077], 
             UndirectedEdge[155, 181] -> 
             RGBColor[
              0.6410417692307693, 0.7188376923076923, 0.9653136153846154], 
             UndirectedEdge[148, 323] -> 
             RGBColor[0.5320450384615385, 0.6239735, 0.9587849615384616], 
             UndirectedEdge[177, 438] -> 
             RGBColor[
              0.7101933076923077, 0.768822923076923, 0.8877528076923078], 
             UndirectedEdge[53, 90] -> 
             RGBColor[0.6614287692307692, 0.7260063461538461, 0.8633575], 
             UndirectedEdge[30, 217] -> 
             RGBColor[
              0.7182602307692308, 0.7793052307692308, 0.9729718461538461], 
             UndirectedEdge[43, 290] -> 
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153], 
             UndirectedEdge[114, 397] -> 
             RGBColor[
              0.7584599615384615, 0.8103703846153846, 0.9538241153846154], 
             UndirectedEdge[227, 320] -> 
             RGBColor[
              0.6615369615384616, 0.7348486923076925, 0.9673563846153845], 
             UndirectedEdge[298, 432] -> 
             RGBColor[
              0.5974169230769231, 0.6834210769230769, 0.9618793076923077], 
             UndirectedEdge[42, 85] -> 
             RGBColor[
              0.841613423076923, 0.8769854615384615, 0.9846378076923077], 
             UndirectedEdge[329, 413] -> 
             RGBColor[
              0.7025273461538463, 0.7668706923076923, 0.9714419230769231], 
             UndirectedEdge[244, 380] -> 
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153], 
             UndirectedEdge[87, 113] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[334, 370] -> 
             RGBColor[
              0.7472692692307692, 0.8020243846153845, 0.9727670384615384], 
             UndirectedEdge[24, 278] -> 
             RGBColor[
              0.6344312307692308, 0.7106451538461538, 0.9665393846153847], 
             UndirectedEdge[51, 325] -> 
             RGBColor[
              0.7967943076923077, 0.8382604615384616, 0.8214358846153849], 
             UndirectedEdge[112, 463] -> 
             RGBColor[
              0.6756109615384616, 0.634454923076923, 0.6016471923076924], 
             UndirectedEdge[308, 421] -> 
             RGBColor[
              0.565018346153846, 0.6422236538461539, 0.9631985769230769], 
             UndirectedEdge[302, 421] -> 
             RGBColor[0.46109642307692306`, 0.5604635, 0.9529933461538461], 
             UndirectedEdge[103, 488] -> 
             RGBColor[
              0.8942031153846154, 0.9180925384615385, 0.9764308846153846], 
             UndirectedEdge[225, 424] -> 
             RGBColor[0.8113893076923077, 0.853452, 0.9782441153846153], 
             UndirectedEdge[205, 388] -> 
             RGBColor[
              0.6020169615384616, 0.6837620384615384, 0.9639465384615384], 
             UndirectedEdge[114, 297] -> 
             RGBColor[
              0.5987341538461537, 0.6851183846153845, 0.9615536923076923], 
             UndirectedEdge[203, 381] -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 
             UndirectedEdge[17, 252] -> 
             RGBColor[
              0.5769217307692307, 0.6674100769230769, 0.9598365384615384], 
             UndirectedEdge[361, 363] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[318, 383] -> 
             RGBColor[
              0.8702593076923077, 0.7123712307692308, 0.6026023846153845], 
             UndirectedEdge[209, 273] -> 
             RGBColor[0.950619923076923, 0.962693, 0.9684717692307693], 
             UndirectedEdge[47, 230] -> 
             RGBColor[
              0.6344312307692308, 0.7106451538461538, 0.9665393846153847], 
             UndirectedEdge[1, 170] -> 
             RGBColor[
              0.4896720384615384, 0.5965768461538461, 0.952967923076923], 
             UndirectedEdge[139, 247] -> 
             RGBColor[
              0.9293514615384615, 0.9424077692307693, 0.799226346153846], 
             UndirectedEdge[246, 288] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[1, 147] -> 
             RGBColor[
              0.4896720384615384, 0.5965768461538461, 0.952967923076923], 
             UndirectedEdge[352, 457] -> 
             RGBColor[
              0.7400726538461538, 0.7970135384615384, 0.9746889999999999], 
             UndirectedEdge[157, 238] -> 
             RGBColor[
              0.6807149230769232, 0.7491623846153845, 0.9697247692307692], 
             UndirectedEdge[97, 145] -> 
             RGBColor[
              0.7944147692307693, 0.8396818461538462, 0.9800480384615384], 
             UndirectedEdge[83, 237] -> 
             RGBColor[
              0.6397245384615384, 0.7171403846153847, 0.9656392307692307], 
             UndirectedEdge[73, 494] -> 
             RGBColor[
              0.6807149230769232, 0.7491623846153845, 0.9697247692307692], 
             UndirectedEdge[101, 197] -> 
             RGBColor[
              0.5960996923076924, 0.6817237692307693, 0.9622049230769231], 
             UndirectedEdge[224, 356] -> 
             RGBColor[
              0.8808336153846155, 0.7603866923076925, 0.6114258461538462], 
             UndirectedEdge[182, 441] -> 
             RGBColor[
              0.972524423076923, 0.9773286153846155, 0.8552312307692309], 
             UndirectedEdge[160, 480] -> 
             RGBColor[
              0.46486099999999997`, 0.5731125769230769, 0.9519324615384614], 
             UndirectedEdge[263, 440] -> 
             RGBColor[
              0.725456846153846, 0.7843160769230768, 0.9710498846153846], 
             UndirectedEdge[31, 223] -> 
             RGBColor[
              0.8145551153846153, 0.8546621538461538, 0.9171089615384616], 
             UndirectedEdge[5, 102] -> 
             RGBColor[
              0.6528229615384615, 0.7261803076923077, 0.9678203846153846], 
             UndirectedEdge[171, 216] -> 
             RGBColor[
              0.5960996923076924, 0.6817237692307693, 0.9622049230769231], 
             UndirectedEdge[102, 414] -> 
             RGBColor[
              0.7311442692307693, 0.7854163846153845, 0.8466207307692308], 
             UndirectedEdge[68, 205] -> 
             RGBColor[
              0.6578050384615384, 0.7281354999999999, 0.9692969615384616], 
             UndirectedEdge[111, 376] -> 
             RGBColor[
              0.8384606153846155, 0.870608076923077, 0.755393423076923], 
             UndirectedEdge[302, 325] -> 
             RGBColor[
              0.6410417692307693, 0.7188376923076923, 0.9653136153846154], 
             UndirectedEdge[39, 315] -> 
             RGBColor[
              0.6602197307692308, 0.7331513846153845, 0.9676819999999999], 
             UndirectedEdge[66, 314] -> 
             RGBColor[
              0.7217846538461539, 0.6913656153846155, 0.609448576923077], 
             UndirectedEdge[274, 370] -> 
             RGBColor[0.8113893076923077, 0.853452, 0.9782441153846153], 
             UndirectedEdge[94, 477] -> 
             RGBColor[
              0.759193923076923, 0.6252463846153846, 0.5916278846153846], 
             UndirectedEdge[99, 329] -> 
             RGBColor[0.8728748846153846, 0.901485, 0.9843724230769231], 
             UndirectedEdge[25, 465] -> 
             RGBColor[
              0.7810630384615386, 0.8290355384615385, 0.9787745384615385], 
             UndirectedEdge[223, 381] -> 
             RGBColor[
              0.8350503076923077, 0.8706731538461538, 0.9191517307692308], 
             UndirectedEdge[196, 318] -> 
             RGBColor[
              0.9077290384615384, 0.7421523846153846, 0.6028412307692308], 
             UndirectedEdge[76, 462] -> 
             RGBColor[
              0.6410417692307693, 0.7188376923076923, 0.9653136153846154], 
             UndirectedEdge[89, 440] -> 
             RGBColor[
              0.5769217307692307, 0.6674100769230769, 0.9598365384615384], 
             UndirectedEdge[88, 326] -> 
             RGBColor[
              0.9561628076923077, 0.964667076923077, 0.8670108461538462], 
             UndirectedEdge[149, 282] -> 
             RGBColor[
              0.7605678461538462, 0.8130245384615384, 0.9767317692307692], 
             UndirectedEdge[238, 462] -> 
             RGBColor[
              0.7025273461538463, 0.7668706923076923, 0.9714419230769231], 
             UndirectedEdge[168, 261] -> 
             RGBColor[
              0.7749818846153846, 0.8205521538461538, 0.8197187307692311], 
             UndirectedEdge[155, 344] -> 
             RGBColor[
              0.8006230384615385, 0.8449634615384616, 0.9805522692307692], 
             UndirectedEdge[4, 496] -> 
             RGBColor[
              0.49309273076923066`, 0.5987499999999999, 0.9534040769230769], 
             UndirectedEdge[87, 226] -> 
             RGBColor[0.6010684615384616, 0.681748, 0.9644135384615384], 
             UndirectedEdge[128, 362] -> 
             RGBColor[
              0.8006230384615385, 0.8449634615384616, 0.9805522692307692], 
             UndirectedEdge[295, 389] -> 
             RGBColor[
              0.7491178461538461, 0.8015372307692307, 0.9119575000000001], 
             UndirectedEdge[89, 133] -> 
             RGBColor[
              0.7038445769230769, 0.7685679999999999, 0.9711163076923077], 
             UndirectedEdge[33, 164] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[276, 396] -> 
             RGBColor[
              0.7810630384615386, 0.8290355384615385, 0.9787745384615385], 
             UndirectedEdge[50, 274] -> 
             RGBColor[
              0.5572127692307692, 0.6501776153846154, 0.9588811538461539], 
             UndirectedEdge[21, 375] -> 
             RGBColor[
              0.9163203846153847, 0.9324473076923077, 0.8328540384615387], 
             UndirectedEdge[41, 485] -> 
             RGBColor[
              0.5551093076923077, 0.6497017692307692, 0.9581193846153846], 
             UndirectedEdge[30, 316] -> 
             RGBColor[
              0.7182602307692308, 0.7793052307692308, 0.9729718461538461], 
             UndirectedEdge[285, 324] -> 
             RGBColor[0.8778414999999999, 0.905431, 0.9882105], 
             UndirectedEdge[95, 358] -> 
             RGBColor[
              0.7858253461538462, 0.8326119999999999, 0.9792873846153847], 
             UndirectedEdge[333, 492] -> 
             RGBColor[
              0.8523796923076923, 0.8854739999999999, 0.9823296538461539], 
             UndirectedEdge[332, 393] -> 
             RGBColor[
              0.6959632692307692, 0.7544659615384615, 0.7790393076923077], 
             UndirectedEdge[418, 420] -> 
             RGBColor[
              0.889574076923077, 0.8843131538461539, 0.6651355000000001], 
             UndirectedEdge[107, 273] -> 
             RGBColor[
              0.7746770384615385, 0.8239056923076924, 0.9650127307692308], 
             UndirectedEdge[310, 483] -> 
             RGBColor[
              0.6964478076923077, 0.7615969230769231, 0.9712546923076923], 
             UndirectedEdge[155, 403] -> 
             RGBColor[
              0.7605678461538462, 0.8130245384615384, 0.9767317692307692], 
             UndirectedEdge[140, 169] -> 
             RGBColor[0.950619923076923, 0.962693, 0.9684717692307692], 
             UndirectedEdge[147, 216] -> 
             RGBColor[
              0.5960996923076924, 0.6817237692307693, 0.9622049230769231], 
             UndirectedEdge[70, 171] -> 
             RGBColor[
              0.6165948846153846, 0.6977347692307692, 0.9642476923076924], 
             UndirectedEdge[7, 402] -> 
             RGBColor[
              0.637090076923077, 0.7137457692307692, 0.9662904615384615], 
             UndirectedEdge[185, 409] -> 
             RGBColor[
              0.3977133846153846, 0.5189010769230769, 0.946562923076923], 
             UndirectedEdge[126, 481] -> 
             RGBColor[
              0.9159997307692308, 0.9317614615384615, 0.7979528461538461], 
             UndirectedEdge[115, 311] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[383, 496] -> 
             RGBColor[
              0.6477829615384615, 0.7212914615384616, 0.9678128846153846], 
             UndirectedEdge[8, 297] -> 
             RGBColor[
              0.5367175769230769, 0.6341666153846153, 0.9568383846153846], 
             UndirectedEdge[381, 439] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[16, 276] -> 
             RGBColor[
              0.561026576923077, 0.6517400384615385, 0.9598610000000001], 
             UndirectedEdge[74, 342] -> 
             RGBColor[
              0.841613423076923, 0.8769854615384615, 0.9846378076923077], 
             UndirectedEdge[26, 269] -> 
             RGBColor[0.950619923076923, 0.962693, 0.9684717692307692], 
             UndirectedEdge[127, 315] -> 
             RGBColor[
              0.8690788846153846, 0.8683021538461538, 0.6630927307692308], 
             UndirectedEdge[175, 348] -> 
             RGBColor[
              0.6602197307692308, 0.7331513846153845, 0.9676819999999999], 
             UndirectedEdge[180, 288] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[288, 343] -> 
             RGBColor[
              0.8800923076923077, 0.9040017692307691, 0.8292813461538464], 
             UndirectedEdge[484, 500] -> 
             RGBColor[
              0.8965358846153847, 0.9187061538461538, 0.9252800384615385], 
             UndirectedEdge[59, 323] -> 
             RGBColor[
              0.8282616923076923, 0.8663391538461538, 0.9833643076923078], 
             UndirectedEdge[108, 189] -> 
             RGBColor[0.8077665, 0.8503281538461539, 0.9813215384615385], 
             UndirectedEdge[59, 74] -> 
             RGBColor[0.9045449615384615, 0.9267236153846153, 0.9907575], 
             UndirectedEdge[40, 199] -> 
             RGBColor[
              0.7097995384615384, 0.7722432307692307, 0.9725281923076923], 
             UndirectedEdge[69, 241] -> 
             RGBColor[0.8206795, 0.6732793846153846, 0.5977561923076923], 
             UndirectedEdge[275, 353] -> 
             RGBColor[
              0.5974169230769231, 0.6834210769230769, 0.9618793076923077], 
             UndirectedEdge[196, 335] -> 
             RGBColor[0.6190945769230769, 0.6928464999999999, 0.96387], 
             UndirectedEdge[157, 281] -> 
             RGBColor[
              0.6397245384615384, 0.7171403846153847, 0.9656392307692307], 
             UndirectedEdge[120, 438] -> 
             RGBColor[
              0.8773203076923077, 0.9032243076923077, 0.9020307307692309], 
             UndirectedEdge[152, 389] -> 
             RGBColor[
              0.7927426923076923, 0.8369538461538462, 0.9153918076923078], 
             UndirectedEdge[126, 144] -> 
             RGBColor[
              0.6964478076923077, 0.7615969230769231, 0.9712546923076923], 
             UndirectedEdge[96, 157] -> 
             RGBColor[
              0.45972996153846146`, 0.5698528461538461, 0.9512782307692307], 
             UndirectedEdge[303, 366] -> 
             RGBColor[0.8896609230769231, 0.914004, 0.9559580384615385], 
             UndirectedEdge[119, 309] -> 
             RGBColor[
              0.637090076923077, 0.7137457692307692, 0.9662904615384615], 
             UndirectedEdge[325, 386] -> 
             RGBColor[
              0.5332968846153847, 0.6319934615384615, 0.9564022307692308], 
             UndirectedEdge[27, 220] -> 
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923], 
             UndirectedEdge[95, 346] -> 
             RGBColor[0.8728748846153846, 0.901485, 0.9843724230769231], 
             UndirectedEdge[235, 239] -> 
             RGBColor[
              0.5200361923076923, 0.6197180384615384, 0.9557754615384615], 
             UndirectedEdge[64, 303] -> 
             RGBColor[
              0.637090076923077, 0.7137457692307692, 0.9662904615384615], 
             UndirectedEdge[310, 429] -> 
             RGBColor[
              0.6192293461538461, 0.7011293846153845, 0.9635964615384616], 
             UndirectedEdge[67, 238] -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 
             UndirectedEdge[38, 108] -> 
             RGBColor[
              0.7872713076923077, 0.8343171538461538, 0.9792787692307692], 
             UndirectedEdge[20, 490] -> 
             RGBColor[
              0.6384073076923076, 0.7154430769230768, 0.9659648461538461], 
             UndirectedEdge[112, 148] -> 
             RGBColor[
              0.36491803846153836`, 0.4895721153846153, 0.9445070384615385], 
             UndirectedEdge[76, 402] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[99, 406] -> 
             RGBColor[0.8728748846153846, 0.901485, 0.9843724230769231], 
             UndirectedEdge[8, 258] -> 
             RGBColor[
              0.44946788461538456`, 0.5633333846153845, 0.9499697692307693], 
             UndirectedEdge[15, 153] -> 
             RGBColor[0.9102263846153846, 0.8789498461538461, 0.635181], 
             UndirectedEdge[195, 463] -> 
             RGBColor[
              0.9190212307692307, 0.8292407692307692, 0.6233183076923077], 
             UndirectedEdge[184, 249] -> 
             RGBColor[
              0.5033548076923077, 0.6052694615384615, 0.9547125384615385], 
             UndirectedEdge[109, 185] -> 
             RGBColor[
              0.6964433846153846, 0.7594186153846154, 0.9491088076923078], 
             UndirectedEdge[77, 81] -> 
             RGBColor[
              0.6277719230769231, 0.7030406153846154, 0.9669605384615385], 
             UndirectedEdge[355, 384] -> 
             RGBColor[
              0.7400726538461538, 0.7970135384615384, 0.9746889999999999], 
             UndirectedEdge[67, 343] -> 
             RGBColor[
              0.9005875000000001, 0.9200127692307692, 0.8313241153846156], 
             UndirectedEdge[247, 255] -> 
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484], 
             UndirectedEdge[95, 145] -> 
             RGBColor[
              0.765330153846154, 0.8166010000000001, 0.9772446153846154], 
             UndirectedEdge[220, 416] -> 
             RGBColor[0.5853479230769231, 0.6539605, 0.9423679615384615], 
             UndirectedEdge[287, 451] -> 
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937], 
             UndirectedEdge[387, 491] -> 
             RGBColor[
              0.8388891538461538, 0.8722606153846154, 0.8555321153846154], 
             UndirectedEdge[211, 464] -> 
             RGBColor[
              0.9606976538461538, 0.8791468461538463, 0.5455144615384617], 
             UndirectedEdge[335, 482] -> 
             RGBColor[0.5525402307692309, 0.6399845, 0.9608277307692308], 
             UndirectedEdge[214, 423] -> 
             RGBColor[
              0.9135483846153847, 0.9316698461538462, 0.9056034230769232], 
             UndirectedEdge[69, 194] -> 
             RGBColor[0.8579750384615384, 0.889647, 0.9728581923076923], 
             UndirectedEdge[111, 312] -> 
             RGBColor[
              0.7605678461538462, 0.8130245384615384, 0.9767317692307692], 
             UndirectedEdge[174, 294] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[212, 295] -> 
             RGBColor[
              0.6384073076923076, 0.7154430769230768, 0.9659648461538461], 
             UndirectedEdge[193, 414] -> 
             RGBColor[
              0.8388891538461538, 0.8722606153846154, 0.8555321153846154], 
             UndirectedEdge[320, 348] -> 
             RGBColor[
              0.6820321538461539, 0.7508596923076922, 0.9693991538461538], 
             UndirectedEdge[247, 468] -> 
             RGBColor[
              0.6661746923076923, 0.7368266153846154, 0.9690938846153846], 
             UndirectedEdge[449, 488] -> 
             RGBColor[
              0.8909051153846155, 0.8446363076923078, 0.6291042692307692], 
             UndirectedEdge[290, 355] -> 
             RGBColor[
              0.5769217307692307, 0.6674100769230769, 0.9598365384615384], 
             UndirectedEdge[88, 469] -> 
             RGBColor[
              0.9561628076923077, 0.964667076923077, 0.8670108461538462], 
             UndirectedEdge[6, 278] -> 
             RGBColor[
              0.5982031538461539, 0.6821996153846153, 0.9629666923076923], 
             UndirectedEdge[24, 448] -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 
             UndirectedEdge[204, 274] -> 
             RGBColor[
              0.5405313846153846, 0.6357290384615384, 0.9578182307692308], 
             UndirectedEdge[81, 99] -> 
             RGBColor[
              0.6518899230769231, 0.7221754615384615, 0.9659258846153846], 
             UndirectedEdge[213, 368] -> 
             RGBColor[
              0.5114844615384615, 0.6142851538461538, 0.9546850769230769], 
             UndirectedEdge[167, 474] -> 
             RGBColor[
              0.693511923076923, 0.7543743461538461, 0.8866898846153848], 
             UndirectedEdge[78, 430] -> 
             RGBColor[
              0.49309273076923066`, 0.5987499999999999, 0.9534040769230769], 
             UndirectedEdge[110, 316] -> 
             RGBColor[
              0.9161076153846155, 0.9327281538461538, 0.8631903461538462], 
             UndirectedEdge[153, 463] -> 
             RGBColor[
              0.8923177692307693, 0.8079481538461538, 0.6207713076923077], 
             UndirectedEdge[471, 475] -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 
             UndirectedEdge[79, 486] -> 
             RGBColor[
              0.9156790769230769, 0.9310756153846154, 0.7630516538461538], 
             UndirectedEdge[49, 402] -> 
             RGBColor[
              0.8464618461538462, 0.7132981153846154, 0.6042106923076923], 
             UndirectedEdge[340, 498] -> 
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153], 
             UndirectedEdge[248, 313] -> 
             RGBColor[0.6947915384615384, 0.7549035, 0.8654833461538463], 
             UndirectedEdge[37, 429] -> 
             RGBColor[
              0.7872713076923077, 0.8343171538461538, 0.9792787692307692], 
             UndirectedEdge[18, 166] -> 
             RGBColor[
              0.7810630384615386, 0.8290355384615385, 0.9787745384615385], 
             UndirectedEdge[147, 238] -> 
             RGBColor[
              0.637090076923077, 0.7137457692307692, 0.9662904615384615], 
             UndirectedEdge[165, 441] -> 
             RGBColor[
              0.972524423076923, 0.9773286153846155, 0.8552312307692309], 
             UndirectedEdge[13, 154] -> 
             RGBColor[
              0.9521688846153846, 0.8544213076923077, 0.5831243076923077], 
             UndirectedEdge[133, 249] -> 
             RGBColor[
              0.5648403846153847, 0.6533024615384615, 0.9608408461538461], 
             UndirectedEdge[84, 385] -> 
             RGBColor[
              0.7182602307692308, 0.7793052307692308, 0.9729718461538461], 
             UndirectedEdge[125, 438] -> 
             RGBColor[
              0.6601491538461537, 0.7254771923076924, 0.8845640384615385], 
             UndirectedEdge[21, 489] -> 
             RGBColor[
              0.6528229615384615, 0.7261803076923077, 0.9678203846153846], 
             UndirectedEdge[16, 200] -> 
             RGBColor[
              0.6960711538461539, 0.7554326538461538, 0.8442768076923077], 
             UndirectedEdge[402, 436] -> 
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153], 
             UndirectedEdge[127, 401] -> 
             RGBColor[
              0.8485836923076924, 0.852291153846154, 0.6610499615384615], 
             UndirectedEdge[195, 395] -> 
             RGBColor[
              0.8621086153846154, 0.8929964615384616, 0.9866805769230769], 
             UndirectedEdge[27, 297] -> 
             RGBColor[
              0.6628541923076923, 0.7365459999999999, 0.9670307692307691], 
             UndirectedEdge[35, 70] -> 
             RGBColor[0.8579750384615384, 0.889647, 0.9728581923076923], 
             UndirectedEdge[240, 367] -> 
             RGBColor[
              0.6075161923076923, 0.3265140384615384, 0.5553904615384616], 
             UndirectedEdge[121, 471] -> 
             RGBColor[
              0.5960996923076924, 0.6817237692307693, 0.9622049230769231], 
             UndirectedEdge[184, 424] -> 
             RGBColor[
              0.6628541923076923, 0.7365459999999999, 0.9670307692307691], 
             UndirectedEdge[122, 159] -> 
             RGBColor[
              0.7097995384615384, 0.7722432307692307, 0.9725281923076923], 
             UndirectedEdge[158, 324] -> 
             RGBColor[0.8511380384615386, 0.8841383846153846, 0.9856635], 
             UndirectedEdge[180, 465] -> 
             RGBColor[
              0.7605678461538462, 0.8130245384615384, 0.9767317692307692], 
             UndirectedEdge[254, 454] -> 
             RGBColor[
              0.8238723461538462, 0.822058076923077, 0.6426282307692308], 
             UndirectedEdge[297, 314] -> 
             RGBColor[
              0.5769217307692307, 0.6674100769230769, 0.9598365384615384], 
             UndirectedEdge[262, 393] -> 
             RGBColor[0.679762, 0.7449700384615384, 0.9480458846153846], 
             UndirectedEdge[201, 333] -> 
             RGBColor[
              0.7472692692307692, 0.8020243846153845, 0.9727670384615384], 
             UndirectedEdge[219, 340] -> 
             RGBColor[
              0.8517490000000001, 0.7373058461538464, 0.6086224230769232], 
             UndirectedEdge[361, 370] -> 
             RGBColor[
              0.8523796923076923, 0.8854739999999999, 0.9823296538461539], 
             UndirectedEdge[48, 358] -> 
             RGBColor[
              0.6384073076923076, 0.7154430769230768, 0.9659648461538461], 
             UndirectedEdge[287, 299] -> 
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937], 
             UndirectedEdge[62, 233] -> 
             RGBColor[
              0.5551093076923076, 0.6497017692307692, 0.9581193846153846], 
             UndirectedEdge[61, 91] -> 
             RGBColor[
              0.8800923076923077, 0.9040017692307691, 0.8292813461538464], 
             UndirectedEdge[204, 340] -> 
             RGBColor[
              0.6020169615384616, 0.6837620384615384, 0.9639465384615384], 
             UndirectedEdge[258, 373] -> 
             RGBColor[
              0.35335153846153844`, 0.4736192692307692, 0.9440819615384615], 
             UndirectedEdge[167, 210] -> 
             RGBColor[
              0.7503974615384614, 0.8020663846153846, 0.8907509615384617], 
             UndirectedEdge[275, 481] -> 
             RGBColor[
              0.8387812692307692, 0.8712939230769231, 0.7902946153846153], 
             UndirectedEdge[253, 277] -> 
             RGBColor[
              0.6964478076923077, 0.7615969230769231, 0.9712546923076923], 
             UndirectedEdge[193, 485] -> 
             RGBColor[
              0.6410417692307693, 0.7188376923076923, 0.9653136153846154], 
             UndirectedEdge[89, 260] -> 
             RGBColor[
              0.7400726538461538, 0.7970135384615384, 0.9746889999999999], 
             UndirectedEdge[359, 397] -> 
             RGBColor[
              0.6630806153846154, 0.7305214615384615, 0.9469829615384615], 
             UndirectedEdge[1, 171] -> 
             RGBColor[
              0.4896720384615384, 0.5965768461538461, 0.952967923076923], 
             UndirectedEdge[193, 330] -> 
             RGBColor[
              0.6628541923076923, 0.7365459999999999, 0.9670307692307691], 
             UndirectedEdge[92, 320] -> 
             RGBColor[
              0.7914630769230769, 0.8364246923076923, 0.9365983461538461], 
             UndirectedEdge[126, 279] -> 
             RGBColor[
              0.7810630384615386, 0.8290355384615385, 0.9787745384615385], 
             UndirectedEdge[93, 163] -> 
             RGBColor[
              0.6630806153846154, 0.7305214615384615, 0.9469829615384615], 
             UndirectedEdge[31, 297] -> 
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988], 
             UndirectedEdge[127, 325] -> 
             RGBColor[
              0.7857808846153846, 0.8025608461538463, 0.6552472692307693], 
             UndirectedEdge[334, 498] -> 
             RGBColor[
              0.5332968846153845, 0.6319934615384615, 0.9564022307692308], 
             UndirectedEdge[41, 300] -> 
             RGBColor[
              0.5332968846153845, 0.6319934615384615, 0.9564022307692308], 
             UndirectedEdge[330, 496] -> 
             RGBColor[
              0.5367175769230769, 0.6341666153846153, 0.9568383846153846], 
             UndirectedEdge[18, 227] -> 
             RGBColor[
              0.7810630384615386, 0.8290355384615385, 0.9787745384615385], 
             UndirectedEdge[156, 350] -> 
             RGBColor[
              0.8621086153846154, 0.8929964615384616, 0.9866805769230769], 
             UndirectedEdge[315, 386] -> 
             RGBColor[
              0.6165948846153846, 0.6977347692307692, 0.9642476923076924], 
             UndirectedEdge[29, 479] -> 
             RGBColor[
              0.7858253461538462, 0.8326119999999999, 0.9792873846153847], 
             UndirectedEdge[277, 488] -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 
             UndirectedEdge[242, 374] -> 
             RGBColor[
              0.8965358846153847, 0.9187061538461538, 0.9252800384615385], 
             UndirectedEdge[244, 363] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[335, 409] -> 
             RGBColor[
              0.33155526923076917`, 0.46067496153846144`, 0.9423811923076924],
              UndirectedEdge[235, 332] -> 
             RGBColor[
              0.6959632692307691, 0.7544659615384615, 0.7790393076923077], 
             UndirectedEdge[249, 440] -> 
             RGBColor[
              0.43791753846153836`, 0.5521445384615383, 0.9495610769230769], 
             UndirectedEdge[96, 265] -> 
             RGBColor[0.6010684615384616, 0.681748, 0.9644135384615384], 
             UndirectedEdge[39, 200] -> 
             RGBColor[
              0.7747691153846153, 0.8208329999999999, 0.8500550384615385], 
             UndirectedEdge[146, 312] -> 
             RGBColor[
              0.8015582307692308, 0.8450465384615384, 0.9808173076923077], 
             UndirectedEdge[237, 448] -> 
             RGBColor[
              0.6964478076923077, 0.7615969230769231, 0.9712546923076923], 
             UndirectedEdge[31, 162] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[41, 102] -> 
             RGBColor[
              0.4896720384615384, 0.5965768461538461, 0.952967923076923], 
             UndirectedEdge[266, 374] -> 
             RGBColor[
              0.7089136923076922, 0.7682937692307692, 0.9089593461538463], 
             UndirectedEdge[44, 139] -> 
             RGBColor[
              0.7746612307692307, 0.8198663076923076, 0.7848175384615383], 
             UndirectedEdge[47, 189] -> 
             RGBColor[
              0.7810630384615386, 0.8290355384615385, 0.9787745384615385], 
             UndirectedEdge[208, 359] -> 
             RGBColor[
              0.6541872692307693, 0.6528922307692309, 0.6091278076923077], 
             UndirectedEdge[122, 413] -> 
             RGBColor[
              0.7316119615384615, 0.7899515384615385, 0.9742453461538461], 
             UndirectedEdge[36, 141] -> 
             RGBColor[
              0.7739195769230769, 0.8236708461538462, 0.9780052692307692], 
             UndirectedEdge[179, 347] -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 
             UndirectedEdge[226, 422] -> 
             RGBColor[
              0.5033548076923077, 0.6052694615384615, 0.9547125384615385], 
             UndirectedEdge[18, 167] -> 
             RGBColor[
              0.9135483846153847, 0.9316698461538462, 0.9056034230769232], 
             UndirectedEdge[112, 452] -> 
             RGBColor[
              0.36491803846153836`, 0.4895721153846153, 0.9445070384615385], 
             UndirectedEdge[323, 342] -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             UndirectedEdge[74, 82] -> 
             RGBColor[
              0.841613423076923, 0.8769854615384615, 0.9846378076923077], 
             UndirectedEdge[291, 349] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[86, 136] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[11, 23] -> 
             RGBColor[
              0.4896720384615384, 0.5965768461538461, 0.952967923076923], 
             UndirectedEdge[249, 470] -> 
             RGBColor[
              0.45972996153846146`, 0.5698528461538461, 0.9512782307692307], 
             UndirectedEdge[35, 135] -> 
             RGBColor[
              0.9342583076923077, 0.9500314615384615, 0.9802513846153846], 
             UndirectedEdge[161, 326] -> 
             RGBColor[
              0.7801278461538461, 0.8289524615384615, 0.9785094999999999], 
             UndirectedEdge[26, 139] -> 
             RGBColor[
              0.9780118846153846, 0.9805349230769231, 0.7805222692307692], 
             UndirectedEdge[109, 218] -> 
             RGBColor[
              0.6964433846153846, 0.7594186153846154, 0.9491088076923078], 
             UndirectedEdge[238, 465] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[258, 314] -> 
             RGBColor[
              0.4896720384615384, 0.5965768461538461, 0.952967923076923], 
             UndirectedEdge[28, 493] -> 
             RGBColor[
              0.9192279230769231, 0.730663653846154, 0.5700151153846155], 
             UndirectedEdge[106, 466] -> 
             RGBColor[0.8778414999999999, 0.905431, 0.9882105], 
             UndirectedEdge[45, 236] -> 
             RGBColor[
              0.7182602307692308, 0.7793052307692308, 0.9729718461538461], 
             UndirectedEdge[157, 246] -> 
             RGBColor[
              0.6192293461538461, 0.7011293846153845, 0.9635964615384616], 
             UndirectedEdge[371, 427] -> 
             RGBColor[
              0.9933620769230769, 0.9911542307692307, 0.7328609230769234], 
             UndirectedEdge[341, 450] -> 
             RGBColor[0.7534243846153845, 0.8076598461538461, 0.9759625], 
             UndirectedEdge[277, 484] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[84, 135] -> 
             RGBColor[0.8778414999999999, 0.905431, 0.9882105], 
             UndirectedEdge[35, 84] -> 
             RGBColor[
              0.8942031153846154, 0.9180925384615385, 0.9764308846153846], 
             UndirectedEdge[68, 272] -> 
             RGBColor[
              0.841613423076923, 0.8769854615384615, 0.9846378076923077], 
             UndirectedEdge[164, 227] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[355, 498] -> 
             RGBColor[
              0.5769217307692307, 0.6674100769230769, 0.9598365384615384], 
             UndirectedEdge[223, 373] -> 
             RGBColor[
              0.6127973461538461, 0.6785796538461538, 0.9030715384615385], 
             UndirectedEdge[116, 192] -> 
             RGBColor[
              0.7316119615384615, 0.7899515384615385, 0.9742453461538461], 
             UndirectedEdge[3, 31] -> 
             RGBColor[
              0.7400726538461538, 0.7970135384615384, 0.9746889999999999], 
             UndirectedEdge[40, 419] -> 
             RGBColor[
              0.6144201923076923, 0.6923943076923077, 0.9656870384615384], 
             UndirectedEdge[282, 324] -> 
             RGBColor[
              0.7605678461538462, 0.8130245384615384, 0.9767317692307692], 
             UndirectedEdge[250, 339] -> 
             RGBColor[
              0.6186983461538462, 0.6982106153846154, 0.9650094615384616], 
             UndirectedEdge[259, 405] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[22, 441] -> 
             RGBColor[
              0.9161076153846155, 0.9327281538461538, 0.8631903461538462], 
             UndirectedEdge[142, 241] -> 
             RGBColor[
              0.9245150769230769, 0.7546713846153846, 0.5744268461538462], 
             UndirectedEdge[170, 266] -> 
             RGBColor[
              0.44946788461538456`, 0.5633333846153845, 0.9499697692307693], 
             UndirectedEdge[105, 153] -> 
             RGBColor[
              0.835405153846154, 0.8717038461538462, 0.9841335769230769], 
             UndirectedEdge[95, 404] -> 
             RGBColor[0.8952562692307693, 0.918177, 0.9464865769230769], 
             UndirectedEdge[200, 454] -> 
             RGBColor[
              0.9794121153846154, 0.9417616923076924, 0.5290868076923079], 
             UndirectedEdge[96, 131] -> 
             RGBColor[
              0.627771923076923, 0.7030406153846154, 0.9669605384615385], 
             UndirectedEdge[190, 395] -> 
             RGBColor[
              0.8411746923076924, 0.6892903846153846, 0.5997989615384616], 
             UndirectedEdge[297, 381] -> 
             RGBColor[
              0.6628541923076923, 0.7365459999999999, 0.9670307692307691], 
             UndirectedEdge[203, 419] -> 
             RGBColor[0.52385, 0.6212804615384615, 0.9567553076923077], 
             UndirectedEdge[107, 209] -> 
             RGBColor[
              0.7746770384615385, 0.8239056923076924, 0.9650127307692308], 
             UndirectedEdge[205, 252] -> 
             RGBColor[
              0.5200361923076923, 0.6197180384615384, 0.9557754615384615], 
             UndirectedEdge[98, 488] -> 
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937], 
             UndirectedEdge[182, 275] -> 
             RGBColor[
              0.8169846538461538, 0.8576250000000001, 0.9687726538461539], 
             UndirectedEdge[88, 474] -> 
             RGBColor[
              0.6960711538461538, 0.7554326538461538, 0.8442768076923077], 
             UndirectedEdge[47, 242] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[133, 262] -> 
             RGBColor[0.8635703846153846, 0.89382, 0.9633867307692308], 
             UndirectedEdge[4, 321] -> 
             RGBColor[
              0.5551093076923076, 0.6497017692307692, 0.9581193846153846], 
             UndirectedEdge[369, 370] -> 
             RGBColor[
              0.9286629615384614, 0.9458584615384615, 0.9897228461538461], 
             UndirectedEdge[49, 436] -> 
             RGBColor[
              0.6990438076923076, 0.5961291923076921, 0.5908881538461539], 
             UndirectedEdge[34, 393] -> 
             RGBColor[
              0.6311015769230769, 0.7068428846153846, 0.9667499615384616], 
             UndirectedEdge[268, 324] -> 
             RGBColor[
              0.8015582307692308, 0.8450465384615384, 0.9808173076923077], 
             UndirectedEdge[359, 371] -> 
             RGBColor[
              0.6796025384615385, 0.7407032307692307, 0.8128775769230772], 
             UndirectedEdge[296, 440] -> 
             RGBColor[
              0.7013388461538461, 0.7651812307692307, 0.9720845384615384], 
             UndirectedEdge[113, 143] -> 
             RGBColor[
              0.765330153846154, 0.8166010000000001, 0.9772446153846154], 
             UndirectedEdge[270, 489] -> 
             RGBColor[
              0.637090076923077, 0.7137457692307692, 0.9662904615384615], 
             UndirectedEdge[237, 426] -> 
             RGBColor[
              0.6964478076923077, 0.7615969230769231, 0.9712546923076923], 
             UndirectedEdge[131, 385] -> 
             RGBColor[
              0.7449636923076923, 0.8005978461538461, 0.9755188461538462], 
             UndirectedEdge[427, 499] -> 
             RGBColor[
              0.9415314615384616, 0.9534916153846154, 0.8869438846153846], 
             UndirectedEdge[45, 243] -> 
             RGBColor[
              0.5332968846153847, 0.6319934615384615, 0.9564022307692308], 
             UndirectedEdge[33, 443] -> 
             RGBColor[
              0.8485836923076924, 0.852291153846154, 0.6610499615384615], 
             UndirectedEdge[232, 330] -> 
             RGBColor[
              0.7038445769230769, 0.7685679999999999, 0.9711163076923077], 
             UndirectedEdge[19, 360] -> 
             RGBColor[
              0.6344312307692308, 0.7106451538461538, 0.9665393846153847], 
             UndirectedEdge[44, 370] -> 
             RGBColor[
              0.7472692692307692, 0.8020243846153845, 0.9727670384615384], 
             UndirectedEdge[310, 412] -> 
             RGBColor[
              0.6964478076923077, 0.7615969230769231, 0.9712546923076923], 
             UndirectedEdge[107, 214] -> 
             RGBColor[
              0.7182602307692308, 0.7793052307692308, 0.9729718461538461], 
             UndirectedEdge[268, 481] -> 
             RGBColor[
              0.8797716538461539, 0.903315923076923, 0.7943801538461538], 
             UndirectedEdge[224, 351] -> 
             RGBColor[
              0.8941853461538462, 0.7710330000000002, 0.6126993461538462], 
             UndirectedEdge[78, 408] -> 
             RGBColor[
              0.44946788461538456`, 0.5633333846153845, 0.9499697692307693], 
             UndirectedEdge[124, 136] -> 
             RGBColor[
              0.7038445769230769, 0.7685679999999999, 0.9711163076923077], 
             UndirectedEdge[51, 315] -> 
             RGBColor[
              0.8800923076923077, 0.9040017692307691, 0.8292813461538464], 
             UndirectedEdge[24, 270] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[43, 340] -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 
             UndirectedEdge[116, 483] -> 
             RGBColor[0.8511380384615386, 0.8841383846153846, 0.9856635], 
             UndirectedEdge[50, 169] -> 
             RGBColor[
              0.6964433846153846, 0.7594186153846154, 0.9491088076923078], 
             UndirectedEdge[247, 369] -> 
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484], 
             UndirectedEdge[327, 412] -> 
             RGBColor[
              0.9163203846153847, 0.9324473076923077, 0.8328540384615387], 
             UndirectedEdge[134, 305] -> 
             RGBColor[
              0.44304857692307686`, 0.5554042692307691, 0.9502153076923077], 
             UndirectedEdge[7, 49] -> 
             RGBColor[0.6772313846153846, 0.5784208846153845, 0.589171], 
             UndirectedEdge[81, 486] -> 
             RGBColor[
              0.6789612307692308, 0.7393315384615384, 0.7430751923076924], 
             UndirectedEdge[110, 384] -> 
             RGBColor[
              0.9161076153846155, 0.9327281538461538, 0.8631903461538462], 
             UndirectedEdge[18, 88] -> 
             RGBColor[
              0.9161076153846155, 0.9327281538461538, 0.8631903461538462], 
             UndirectedEdge[11, 41] -> 
             RGBColor[
              0.5114844615384614, 0.6142851538461537, 0.9546850769230769], 
             UndirectedEdge[231, 288] -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             UndirectedEdge[236, 396] -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 
             UndirectedEdge[46, 418] -> 
             RGBColor[
              0.8075933076923076, 0.8202691538461538, 0.6569644230769232], 
             UndirectedEdge[74, 447] -> 
             RGBColor[
              0.8676078461538461, 0.5357484615384616, 0.5781244999999999], 
             UndirectedEdge[270, 426] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[383, 479] -> 
             RGBColor[
              0.835405153846154, 0.8717038461538462, 0.9841335769230769], 
             UndirectedEdge[408, 430] -> 
             RGBColor[
              0.5114844615384615, 0.6142851538461538, 0.9546850769230769], 
             UndirectedEdge[13, 390] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[15, 97] -> 
             RGBColor[0.9102263846153846, 0.8789498461538461, 0.635181], 
             UndirectedEdge[289, 472] -> 
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923], 
             UndirectedEdge[254, 315] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[347, 386] -> 
             RGBColor[
              0.5756045000000001, 0.6657127692307692, 0.9601621538461538], 
             UndirectedEdge[66, 445] -> 
             RGBColor[
              0.7217846538461539, 0.6913656153846155, 0.609448576923077], 
             UndirectedEdge[127, 213] -> 
             RGBColor[
              0.7639684615384614, 0.7848525384615385, 0.6535301153846154], 
             UndirectedEdge[423, 446] -> 
             RGBColor[
              0.9920824615384616, 0.9906250769230769, 0.7540674615384619], 
             UndirectedEdge[63, 410] -> 
             RGBColor[
              0.4143947692307692, 0.5333496538461537, 0.9476258461538463], 
             UndirectedEdge[107, 421] -> 
             RGBColor[
              0.4187888076923077, 0.5267441923076923, 0.949233423076923], 
             UndirectedEdge[226, 308] -> 
             RGBColor[
              0.627771923076923, 0.7030406153846154, 0.9669605384615385], 
             UndirectedEdge[51, 386] -> 
             RGBColor[
              0.7313570384615384, 0.7851355384615384, 0.8162844230769233], 
             UndirectedEdge[89, 470] -> 
             RGBColor[
              0.5987341538461537, 0.6851183846153845, 0.9615536923076923], 
             UndirectedEdge[205, 490] -> 
             RGBColor[0.45459892307692296`, 0.5665931153846153, 0.950624], 
             UndirectedEdge[270, 345] -> 
             RGBColor[
              0.9003747307692309, 0.9202936153846154, 0.8616604230769231], 
             UndirectedEdge[152, 191] -> 
             RGBColor[
              0.5149051538461539, 0.6164583076923077, 0.9551212307692307], 
             UndirectedEdge[85, 404] -> 
             RGBColor[0.951044346153846, 0.9625504615384615, 0.951837], 
             UndirectedEdge[26, 468] -> 
             RGBColor[
              0.7148351153846153, 0.7749537692307692, 0.9503898076923076], 
             UndirectedEdge[191, 301] -> 
             RGBColor[
              0.47128030769230755`, 0.5810416923076922, 0.9516869230769232], 
             UndirectedEdge[375, 426] -> 
             RGBColor[
              0.9163203846153847, 0.9324473076923077, 0.8328540384615387], 
             UndirectedEdge[39, 213] -> 
             RGBColor[
              0.5551093076923076, 0.6497017692307692, 0.9581193846153846], 
             UndirectedEdge[360, 468] -> 
             RGBColor[
              0.44946788461538456`, 0.5633333846153845, 0.9499697692307693], 
             UndirectedEdge[80, 278] -> 
             RGBColor[
              0.6344312307692308, 0.7106451538461538, 0.9665393846153847], 
             UndirectedEdge[152, 299] -> 
             RGBColor[
              0.7182602307692308, 0.7793052307692308, 0.9729718461538461], 
             UndirectedEdge[227, 309] -> 
             RGBColor[
              0.5960996923076924, 0.6817237692307693, 0.9622049230769231], 
             UndirectedEdge[98, 115] -> 
             RGBColor[
              0.8282616923076923, 0.8663391538461538, 0.9833643076923078], 
             UndirectedEdge[213, 261] -> 
             RGBColor[
              0.7749818846153846, 0.8205521538461538, 0.8197187307692311], 
             UndirectedEdge[199, 208] -> 
             RGBColor[
              0.7495666153846154, 0.7327411538461539, 0.6159689615384616], 
             UndirectedEdge[204, 219] -> 
             RGBColor[
              0.6474454230769231, 0.5724448846153848, 0.5912388076923077], 
             UndirectedEdge[52, 166] -> 
             RGBColor[0.8542658846153847, 0.886155, 0.9424010384615384], 
             UndirectedEdge[218, 300] -> 
             RGBColor[
              0.49309273076923066`, 0.5987499999999999, 0.9534040769230769], 
             UndirectedEdge[128, 345] -> 
             RGBColor[
              0.9561628076923077, 0.964667076923077, 0.8670108461538462], 
             UndirectedEdge[325, 421] -> 
             RGBColor[
              0.4187888076923077, 0.5267441923076923, 0.949233423076923], 
             UndirectedEdge[257, 272] -> 
             RGBColor[
              0.8648627307692308, 0.854080076923077, 0.6467137692307694], 
             UndirectedEdge[461, 486] -> 
             RGBColor[
              0.7525281538461538, 0.8014721538461538, 0.7481991923076923], 
             UndirectedEdge[115, 203] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[128, 169] -> 
             RGBColor[
              0.9398536538461537, 0.9542044615384615, 0.9707799230769231], 
             UndirectedEdge[190, 356] -> 
             RGBColor[
              0.8702593076923077, 0.7123712307692308, 0.6026023846153845], 
             UndirectedEdge[46, 272] -> 
             RGBColor[
              0.7038445769230769, 0.7685679999999999, 0.9711163076923077], 
             UndirectedEdge[121, 450] -> 
             RGBColor[
              0.5551093076923077, 0.6497017692307692, 0.9581193846153846], 
             UndirectedEdge[255, 269] -> 
             RGBColor[
              0.9286629615384614, 0.9458584615384615, 0.9897228461538461], 
             UndirectedEdge[15, 356] -> 
             RGBColor[0.9102263846153846, 0.8789498461538461, 0.635181], 
             UndirectedEdge[85, 183] -> 
             RGBColor[
              0.8621086153846154, 0.8929964615384616, 0.9866805769230769], 
             UndirectedEdge[136, 261] -> 
             RGBColor[
              0.8186067307692307, 0.8559687692307691, 0.8231530384615386], 
             UndirectedEdge[295, 336] -> 
             RGBColor[
              0.5974169230769231, 0.6834210769230769, 0.9618793076923077], 
             UndirectedEdge[259, 475] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[51, 143] -> 
             RGBColor[
              0.8595971153846155, 0.8879907692307694, 0.8272385769230772], 
             UndirectedEdge[53, 178] -> 
             RGBColor[
              0.9893104615384616, 0.9898476153846154, 0.8268168461538463], 
             UndirectedEdge[67, 385] -> 
             RGBColor[
              0.7025273461538463, 0.7668706923076923, 0.9714419230769231], 
             UndirectedEdge[69, 173] -> 
             RGBColor[
              0.8523796923076923, 0.8854739999999999, 0.9823296538461539], 
             UndirectedEdge[221, 381] -> 
             RGBColor[
              0.7645562692307692, 0.5526591153846154, 0.5802648461538462], 
             UndirectedEdge[140, 334] -> 
             RGBColor[
              0.7472692692307692, 0.8020243846153845, 0.9727670384615384], 
             UndirectedEdge[57, 370] -> 
             RGBColor[
              0.7908941153846153, 0.8374409999999999, 0.9762013461538461], 
             UndirectedEdge[432, 467] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[235, 440] -> 
             RGBColor[0.45459892307692296`, 0.5665931153846153, 0.950624], 
             UndirectedEdge[229, 390] -> 
             RGBColor[
              0.7696506538461538, 0.8187163846153847, 0.9348811923076923], 
             UndirectedEdge[12, 198] -> 
             RGBColor[
              0.8978155000000001, 0.9192353076923077, 0.9040735000000002], 
             UndirectedEdge[232, 400] -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             UndirectedEdge[143, 273] -> 
             RGBColor[
              0.8374798461538462, 0.8736360000000001, 0.970815423076923], 
             UndirectedEdge[115, 277] -> 
             RGBColor[
              0.8015582307692308, 0.8450465384615384, 0.9808173076923077], 
             UndirectedEdge[44, 468] -> 
             RGBColor[
              0.5114844615384615, 0.6142851538461538, 0.9546850769230769], 
             UndirectedEdge[183, 346] -> 
             RGBColor[0.8728748846153846, 0.901485, 0.9843724230769231], 
             UndirectedEdge[434, 469] -> 
             RGBColor[
              0.9563755769230768, 0.9643862307692308, 0.8366745384615387], 
             UndirectedEdge[255, 334] -> 
             RGBColor[
              0.7365029999999999, 0.7935358461538461, 0.9750751923076924], 
             UndirectedEdge[65, 210] -> 
             RGBColor[
              0.6384073076923076, 0.7154430769230768, 0.9659648461538461], 
             UndirectedEdge[49, 76] -> 
             RGBColor[
              0.7849762692307692, 0.6652651153846154, 0.5980823846153847], 
             UndirectedEdge[74, 395] -> 
             RGBColor[
              0.8621086153846154, 0.8929964615384616, 0.9866805769230769], 
             UndirectedEdge[52, 88] -> 
             RGBColor[
              0.9893104615384616, 0.9898476153846154, 0.8268168461538462], 
             UndirectedEdge[312, 354] -> 
             RGBColor[
              0.9053069615384616, 0.8967476923076924, 0.6666654230769231], 
             UndirectedEdge[372, 417] -> 
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923], 
             UndirectedEdge[354, 415] -> 
             RGBColor[
              0.8075933076923076, 0.8202691538461538, 0.6569644230769232], 
             UndirectedEdge[301, 451] -> 
             RGBColor[
              0.6746353846153845, 0.7438886153846154, 0.9695375384615385], 
             UndirectedEdge[243, 428] -> 
             RGBColor[
              0.44946788461538456`, 0.5633333846153845, 0.9499697692307693], 
             UndirectedEdge[102, 354] -> 
             RGBColor[
              0.7203436153846154, 0.7494359230769231, 0.6500958076923078], 
             UndirectedEdge[255, 369] -> 
             RGBColor[0.9178966923076922, 0.937369923076923, 0.992031], 
             UndirectedEdge[300, 409] -> 
             RGBColor[
              0.45972996153846146`, 0.5698528461538461, 0.9512782307692307], 
             UndirectedEdge[93, 187] -> 
             RGBColor[0.8635703846153846, 0.89382, 0.9633867307692308], 
             UndirectedEdge[181, 332] -> 
             RGBColor[
              0.7964736538461539, 0.8375746153846154, 0.7865346923076922], 
             UndirectedEdge[195, 351] -> 
             RGBColor[0.9045449615384615, 0.9267236153846153, 0.9907575], 
             UndirectedEdge[480, 481] -> 
             RGBColor[
              0.7964736538461539, 0.8375746153846154, 0.7865346923076922], 
             UndirectedEdge[47, 365] -> 
             RGBColor[
              0.6177498461538462, 0.6961965769230769, 0.9654764615384616], 
             UndirectedEdge[50, 370] -> 
             RGBColor[
              0.6852526923076923, 0.7510726153846153, 0.9680517307692308], 
             UndirectedEdge[122, 150] -> 
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937], 
             UndirectedEdge[246, 256] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[63, 282] -> 
             RGBColor[
              0.5405313846153846, 0.6357290384615384, 0.9578182307692308], 
             UndirectedEdge[230, 391] -> 
             RGBColor[
              0.44946788461538456`, 0.5633333846153845, 0.9499697692307693], 
             UndirectedEdge[312, 415] -> 
             RGBColor[
              0.7400726538461538, 0.7970135384615384, 0.9746889999999999], 
             UndirectedEdge[199, 397] -> 
             RGBColor[
              0.7584599615384615, 0.8103703846153846, 0.9538241153846154], 
             UndirectedEdge[129, 328] -> 
             RGBColor[
              0.7400726538461538, 0.7970135384615384, 0.9746889999999999], 
             UndirectedEdge[188, 304] -> 
             RGBColor[
              0.5982031538461539, 0.6821996153846153, 0.9629666923076923], 
             UndirectedEdge[323, 395] -> 
             RGBColor[
              0.7858253461538462, 0.8326119999999999, 0.9792873846153847], 
             UndirectedEdge[49, 238] -> 
             RGBColor[
              0.8464618461538462, 0.7132981153846154, 0.6042106923076923], 
             UndirectedEdge[171, 385] -> 
             RGBColor[
              0.5332968846153847, 0.6319934615384615, 0.9564022307692308], 
             UndirectedEdge[117, 425] -> 
             RGBColor[
              0.8487568846153847, 0.8823501538461538, 0.9854070769230769], 
             UndirectedEdge[32, 103] -> 
             RGBColor[
              0.9727371923076923, 0.9770477692307693, 0.8248949230769234], 
             UndirectedEdge[131, 216] -> 
             RGBColor[0.8077665, 0.8503281538461539, 0.9813215384615385], 
             UndirectedEdge[65, 175] -> 
             RGBColor[
              0.6602197307692308, 0.7331513846153845, 0.9676819999999999], 
             UndirectedEdge[143, 226] -> 
             RGBColor[
              0.5443451923076924, 0.6372914615384616, 0.9587980769230768], 
             UndirectedEdge[234, 235] -> 
             RGBColor[
              0.6020169615384616, 0.6837620384615384, 0.9639465384615384], 
             UndirectedEdge[179, 386] -> 
             RGBColor[
              0.5756045000000001, 0.6657127692307692, 0.9601621538461538], 
             UndirectedEdge[267, 476] -> 
             RGBColor[
              0.43278649999999996`, 0.5488848076923076, 0.9489068461538461], 
             UndirectedEdge[59, 195] -> 
             RGBColor[0.9045449615384615, 0.9267236153846153, 0.9907575], 
             UndirectedEdge[75, 108] -> 
             RGBColor[
              0.9428110769230769, 0.9540207692307692, 0.8657373461538462], 
             UndirectedEdge[334, 363] -> 
             RGBColor[
              0.6192293461538461, 0.7011293846153845, 0.9635964615384616], 
             UndirectedEdge[77, 329] -> 
             RGBColor[
              0.8487568846153847, 0.8823501538461538, 0.9854070769230769], 
             UndirectedEdge[328, 462] -> 
             RGBColor[
              0.6205465769230769, 0.7028266923076922, 0.9632708461538462], 
             UndirectedEdge[285, 480] -> 
             RGBColor[
              0.7583154230769231, 0.8112441538461539, 0.9767923461538461], 
             UndirectedEdge[204, 334] -> 
             RGBColor[
              0.47641134615384606`, 0.584301423076923, 0.9523411538461539], 
             UndirectedEdge[70, 238] -> 
             RGBColor[
              0.7858253461538462, 0.8326119999999999, 0.9792873846153847], 
             UndirectedEdge[83, 270] -> 
             RGBColor[
              0.765330153846154, 0.8166010000000001, 0.9772446153846154], 
             UndirectedEdge[112, 190] -> 
             RGBColor[0.6535525, 0.538878, 0.5834782692307693], 
             UndirectedEdge[263, 453] -> 
             RGBColor[0.9394292307692307, 0.954347, 0.9874146923076923], 
             UndirectedEdge[210, 474] -> 
             RGBColor[0.45459892307692296`, 0.5665931153846153, 0.950624], 
             UndirectedEdge[96, 392] -> 
             RGBColor[
              0.5648403846153847, 0.6533024615384615, 0.9608408461538461], 
             UndirectedEdge[70, 84] -> 
             RGBColor[
              0.8015582307692308, 0.8450465384615384, 0.9808173076923077], 
             UndirectedEdge[77, 278] -> 
             RGBColor[
              0.6611346923076923, 0.7319377692307691, 0.9690863846153847], 
             UndirectedEdge[238, 265] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[157, 392] -> 
             RGBColor[
              0.6602197307692308, 0.7331513846153845, 0.9676819999999999], 
             UndirectedEdge[145, 294] -> 
             RGBColor[
              0.765330153846154, 0.8166010000000001, 0.9772446153846154], 
             UndirectedEdge[29, 383] -> 
             RGBColor[
              0.8149099615384616, 0.8556928461538461, 0.9820908076923076], 
             UndirectedEdge[210, 227] -> 
             RGBColor[
              0.6179121153846154, 0.6994320769230769, 0.963922076923077], 
             UndirectedEdge[45, 276] -> 
             RGBColor[
              0.6615369615384616, 0.7348486923076925, 0.9673563846153845], 
             UndirectedEdge[57, 219] -> 
             RGBColor[
              0.7697682307692307, 0.6732618461538463, 0.6004513461538461], 
             UndirectedEdge[291, 311] -> 
             RGBColor[
              0.703844576923077, 0.7685680000000001, 0.9711163076923077], 
             UndirectedEdge[11, 485] -> 
             RGBColor[
              0.5551093076923077, 0.6497017692307692, 0.9581193846153846], 
             UndirectedEdge[13, 338] -> 
             RGBColor[0.8747610769230769, 0.902166, 0.9444438076923076], 
             UndirectedEdge[190, 351] -> 
             RGBColor[
              0.8836110384615384, 0.7230175384615385, 0.6038758846153847], 
             UndirectedEdge[314, 397] -> 
             RGBColor[
              0.7366475384615383, 0.7926620769230768, 0.9521069615384615], 
             UndirectedEdge[339, 365] -> 
             RGBColor[
              0.6020169615384616, 0.6837620384615384, 0.9639465384615384], 
             UndirectedEdge[320, 337] -> 
             RGBColor[
              0.5551093076923077, 0.6497017692307692, 0.9581193846153846], 
             UndirectedEdge[317, 357] -> 
             RGBColor[
              0.9159997307692308, 0.9317614615384615, 0.7979528461538461], 
             UndirectedEdge[153, 452] -> 
             RGBColor[
              0.5816248461538461, 0.663065346153846, 0.9636311538461538], 
             UndirectedEdge[308, 423] -> 
             RGBColor[
              0.940251846153846, 0.9529624615384615, 0.9081504230769233], 
             UndirectedEdge[149, 441] -> 
             RGBColor[
              0.9161076153846155, 0.9327281538461538, 0.8631903461538462], 
             UndirectedEdge[486, 493] -> 
             RGBColor[
              0.983286576923077, 0.984022076923077, 0.7361496153846154], 
             UndirectedEdge[241, 402] -> 
             RGBColor[
              0.8411746923076924, 0.6892903846153846, 0.5997989615384616], 
             UndirectedEdge[293, 432] -> 
             RGBColor[
              0.5756045000000001, 0.6657127692307692, 0.9601621538461538], 
             UndirectedEdge[23, 211] -> 
             RGBColor[
              0.6999722307692309, 0.6736573076923078, 0.6077314230769231], 
             UndirectedEdge[8, 381] -> 
             RGBColor[
              0.5572127692307692, 0.6501776153846154, 0.9588811538461539], 
             UndirectedEdge[238, 343] -> 
             RGBColor[
              0.9005875000000001, 0.9200127692307692, 0.8313241153846156], 
             UndirectedEdge[355, 363] -> 
             RGBColor[
              0.6628541923076923, 0.7365459999999999, 0.9670307692307691], 
             UndirectedEdge[66, 398] -> 
             RGBColor[
              0.6154223846153846, 0.5998960384615386, 0.6022686923076923], 
             UndirectedEdge[113, 477] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[7, 241] -> 
             RGBColor[
              0.6719442307692307, 0.5544131538461539, 0.5847592692307693], 
             UndirectedEdge[161, 259] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[346, 408] -> 
             RGBColor[
              0.703644423076923, 0.7666077692307691, 0.9693327307692308], 
             UndirectedEdge[33, 270] -> 
             RGBColor[
              0.765330153846154, 0.8166010000000001, 0.9772446153846154], 
             UndirectedEdge[197, 270] -> 
             RGBColor[
              0.637090076923077, 0.7137457692307692, 0.9662904615384615], 
             UndirectedEdge[115, 381] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[112, 224] -> 
             RGBColor[
              0.6641268076923077, 0.5868934615384618, 0.5923017307692309], 
             UndirectedEdge[133, 296] -> 
             RGBColor[
              0.8282616923076923, 0.8663391538461538, 0.9833643076923078], 
             UndirectedEdge[204, 244] -> 
             RGBColor[
              0.6020169615384616, 0.6837620384615384, 0.9639465384615384], 
             UndirectedEdge[116, 280] -> 
             RGBColor[0.9019595, 0.9245658461538462, 0.9871758461538461], 
             UndirectedEdge[81, 267] -> RGBColor[0.381032, 0.5044525, 0.9455],
              UndirectedEdge[431, 459] -> 
             RGBColor[
              0.674486423076923, 0.7425840769230769, 0.9703598846153847], 
             UndirectedEdge[46, 293] -> 
             RGBColor[
              0.5551093076923077, 0.6497017692307692, 0.9581193846153846], 
             UndirectedEdge[145, 358] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[12, 480] -> 
             RGBColor[0.7940223076923076, 0.837483, 0.8941852692307694], 
             UndirectedEdge[318, 321] -> 
             RGBColor[
              0.7155690769230769, 0.5898297692307692, 0.5881935769230768], 
             UndirectedEdge[38, 47] -> 
             RGBColor[
              0.7605678461538462, 0.8130245384615384, 0.9767317692307692], 
             UndirectedEdge[271, 492] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[246, 333] -> 
             RGBColor[0.8113893076923077, 0.853452, 0.9782441153846153], 
             UndirectedEdge[97, 137] -> 
             RGBColor[
              0.7739195769230769, 0.8236708461538462, 0.9780052692307692], 
             UndirectedEdge[406, 486] -> 
             RGBColor[
              0.8999461923076923, 0.918641076923077, 0.7615217307692308], 
             UndirectedEdge[272, 306] -> 
             RGBColor[
              0.47212857692307697`, 0.5609974999999999, 0.9553728076923077], 
             UndirectedEdge[50, 219] -> 
             RGBColor[
              0.6641268076923077, 0.5868934615384618, 0.5923017307692309], 
             UndirectedEdge[326, 405] -> 
             RGBColor[
              0.7801278461538461, 0.8289524615384615, 0.9785094999999999], 
             UndirectedEdge[180, 343] -> 
             RGBColor[
              0.8391019230769231, 0.8719797692307693, 0.8251958076923079], 
             UndirectedEdge[229, 380] -> 
             RGBColor[
              0.5332968846153845, 0.6319934615384615, 0.9564022307692308], 
             UndirectedEdge[184, 470] -> 
             RGBColor[
              0.5987341538461537, 0.6851183846153845, 0.9615536923076923], 
             UndirectedEdge[188, 483] -> 
             RGBColor[
              0.6344312307692308, 0.7106451538461538, 0.9665393846153847], 
             UndirectedEdge[364, 374] -> 
             RGBColor[
              0.9713571153846154, 0.9259521538461538, 0.5763274615384617], 
             UndirectedEdge[161, 469] -> 
             RGBColor[
              0.7801278461538461, 0.8289524615384615, 0.9785094999999999], 
             UndirectedEdge[14, 182] -> 
             RGBColor[
              0.8374798461538462, 0.8736360000000001, 0.970815423076923], 
             UndirectedEdge[374, 391] -> 
             RGBColor[
              0.7273054230769231, 0.7838289230769231, 0.9102403461538462], 
             UndirectedEdge[352, 367] -> 
             RGBColor[
              0.6177498461538462, 0.6961965769230769, 0.9654764615384616], 
             UndirectedEdge[8, 289] -> 
             RGBColor[
              0.6964433846153846, 0.7594186153846154, 0.9491088076923078], 
             UndirectedEdge[160, 275] -> 
             RGBColor[
              0.5071686153846153, 0.6068318846153846, 0.9556923846153846], 
             UndirectedEdge[118, 151] -> 
             RGBColor[
              0.8381399615384615, 0.8699222307692308, 0.7204922307692309], 
             UndirectedEdge[43, 217] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[117, 154] -> 
             RGBColor[0.9056695, 0.8185944615384615, 0.6220448076923077], 
             UndirectedEdge[139, 468] -> 
             RGBColor[
              0.7310363846153847, 0.7844496923076922, 0.7813832307692308], 
             UndirectedEdge[279, 324] -> 
             RGBColor[
              0.7810630384615386, 0.8290355384615385, 0.9787745384615385], 
             UndirectedEdge[4, 29] -> 
             RGBColor[
              0.6602197307692308, 0.7331513846153845, 0.9676819999999999], 
             UndirectedEdge[239, 393] -> 
             RGBColor[
              0.5200361923076923, 0.6197180384615384, 0.9557754615384615], 
             UndirectedEdge[94, 127] -> 
             RGBColor[
              0.9244282307692308, 0.7249805384615385, 0.2836043076923077], 
             UndirectedEdge[157, 459] -> 
             RGBColor[
              0.49309273076923066`, 0.5987499999999999, 0.9534040769230769], 
             UndirectedEdge[48, 85] -> 
             RGBColor[
              0.7146905769230768, 0.7758275384615383, 0.9733580384615385], 
             UndirectedEdge[26, 215] -> 
             RGBColor[
              0.884065576923077, 0.9098310000000001, 0.9654294999999999], 
             UndirectedEdge[63, 165] -> 
             RGBColor[
              0.6741666538461537, 0.7407970384615384, 0.9575173461538462], 
             UndirectedEdge[165, 282] -> 
             RGBColor[
              0.8169846538461538, 0.8576250000000001, 0.9687726538461539], 
             UndirectedEdge[288, 465] -> 
             RGBColor[
              0.8015582307692308, 0.8450465384615384, 0.9808173076923077], 
             UndirectedEdge[200, 500] -> 
             RGBColor[
              0.9905900769230769, 0.9903767692307692, 0.8056103076923078], 
             UndirectedEdge[293, 353] -> 
             RGBColor[
              0.4896720384615384, 0.5965768461538461, 0.952967923076923], 
             UndirectedEdge[239, 296] -> 
             RGBColor[0.7667761153846153, 0.8183061538461538, 0.977236], 
             UndirectedEdge[139, 274] -> 
             RGBColor[
              0.8387812692307692, 0.8712939230769231, 0.7902946153846153], 
             UndirectedEdge[140, 361] -> 
             RGBColor[
              0.8523796923076923, 0.8854739999999999, 0.9823296538461539], 
             UndirectedEdge[83, 197] -> 
             RGBColor[
              0.5960996923076924, 0.6817237692307693, 0.9622049230769231], 
             UndirectedEdge[256, 444] -> 
             RGBColor[
              0.7038445769230769, 0.7685679999999999, 0.9711163076923077], 
             UndirectedEdge[21, 166] -> 
             RGBColor[
              0.7810630384615386, 0.8290355384615385, 0.9787745384615385], 
             UndirectedEdge[92, 363] -> 
             RGBColor[0.8337706923076923, 0.870144, 0.9403582692307693], 
             UndirectedEdge[41, 212] -> 
             RGBColor[
              0.6384073076923076, 0.7154430769230768, 0.9659648461538461], 
             UndirectedEdge[96, 433] -> 
             RGBColor[
              0.6796025384615385, 0.7407032307692307, 0.8128775769230772], 
             UndirectedEdge[346, 407] -> 
             RGBColor[
              0.6852526923076923, 0.7510726153846153, 0.9680517307692308], 
             UndirectedEdge[32, 155] -> 
             RGBColor[
              0.8391019230769231, 0.8719797692307693, 0.8251958076923079], 
             UndirectedEdge[302, 477] -> 
             RGBColor[
              0.6628541923076923, 0.7365459999999999, 0.9670307692307691], 
             UndirectedEdge[24, 489] -> 
             RGBColor[
              0.6528229615384615, 0.7261803076923077, 0.9678203846153846], 
             UndirectedEdge[359, 427] -> 
             RGBColor[
              0.6781101538461538, 0.7404549230769231, 0.864420423076923], 
             UndirectedEdge[217, 290] -> 
             RGBColor[
              0.6746353846153845, 0.7438886153846154, 0.9695375384615385], 
             UndirectedEdge[40, 297] -> 
             RGBColor[0.7534243846153845, 0.8076598461538461, 0.9759625], 
             UndirectedEdge[41, 456] -> 
             RGBColor[
              0.5332968846153845, 0.6319934615384615, 0.9564022307692308], 
             UndirectedEdge[341, 469] -> 
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484], 
             UndirectedEdge[169, 498] -> 
             RGBColor[
              0.7366475384615383, 0.7926620769230768, 0.9521069615384615], 
             UndirectedEdge[6, 329] -> 
             RGBColor[
              0.7858253461538462, 0.8326119999999999, 0.9792873846153847], 
             UndirectedEdge[92, 219] -> 
             RGBColor[
              0.9406847307692308, 0.8068598461538463, 0.5737788461538462], 
             UndirectedEdge[341, 387] -> 
             RGBColor[
              0.7739195769230769, 0.8236708461538462, 0.9780052692307692], 
             UndirectedEdge[13, 478] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[33, 267] -> 
             RGBColor[
              0.561026576923077, 0.6517400384615385, 0.9598610000000001], 
             UndirectedEdge[10, 123] -> 
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153], 
             UndirectedEdge[57, 337] -> 
             RGBColor[
              0.5769217307692307, 0.6674100769230769, 0.9598365384615384], 
             UndirectedEdge[70, 135] -> 
             RGBColor[
              0.841613423076923, 0.8769854615384615, 0.9846378076923077], 
             UndirectedEdge[51, 130] -> 
             RGBColor[
              0.9005875000000001, 0.9200127692307692, 0.8313241153846156], 
             UndirectedEdge[219, 361] -> 
             RGBColor[
              0.8312538076923077, 0.7212948461538463, 0.6065796538461539], 
             UndirectedEdge[70, 131] -> 
             RGBColor[
              0.8282616923076923, 0.8663391538461538, 0.9833643076923078], 
             UndirectedEdge[61, 362] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[49, 487] -> 
             RGBColor[
              0.9407288076923077, 0.7846878846153846, 0.4542046538461541], 
             UndirectedEdge[83, 375] -> 
             RGBColor[
              0.8595971153846155, 0.8879907692307694, 0.8272385769230772], 
             UndirectedEdge[147, 385] -> 
             RGBColor[
              0.5332968846153847, 0.6319934615384615, 0.9564022307692308], 
             UndirectedEdge[105, 395] -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 
             UndirectedEdge[57, 204] -> 
             RGBColor[
              0.5200361923076923, 0.6197180384615384, 0.9557754615384615], 
             UndirectedEdge[362, 363] -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 
             UndirectedEdge[313, 390] -> 
             RGBColor[
              0.9880308461538461, 0.9893184615384616, 0.8480233846153846], 
             UndirectedEdge[15, 430] -> 
             RGBColor[
              0.7555361538461538, 0.7564083846153846, 0.6207721923076923], 
             UndirectedEdge[104, 430] -> 
             RGBColor[
              0.5987341538461537, 0.6851183846153845, 0.9615536923076923], 
             UndirectedEdge[341, 405] -> 
             RGBColor[0.7534243846153845, 0.8076598461538461, 0.9759625], 
             UndirectedEdge[8, 311] -> 
             RGBColor[
              0.5777079615384616, 0.6661886153846155, 0.9609239230769231], 
             UndirectedEdge[305, 460] -> 
             RGBColor[
              0.49309273076923066`, 0.5987499999999999, 0.9534040769230769], 
             UndirectedEdge[451, 456] -> 
             RGBColor[
              0.6964478076923077, 0.7615969230769231, 0.9712546923076923], 
             UndirectedEdge[257, 306] -> 
             RGBColor[
              0.5716611538461539, 0.598476576923077, 0.6248419615384617], 
             UndirectedEdge[65, 167] -> 
             RGBColor[
              0.8773203076923077, 0.9032243076923077, 0.9020307307692309], 
             UndirectedEdge[24, 329] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[14, 63] -> 
             RGBColor[
              0.561026576923077, 0.6517400384615385, 0.9598610000000001], 
             UndirectedEdge[64, 172] -> 
             RGBColor[
              0.5332968846153847, 0.6319934615384615, 0.9564022307692308], 
             UndirectedEdge[50, 361] -> 
             RGBColor[
              0.5982031538461539, 0.6821996153846153, 0.9629666923076923], 
             UndirectedEdge[253, 291] -> 
             RGBColor[
              0.6192293461538461, 0.7011293846153845, 0.9635964615384616], 
             UndirectedEdge[184, 280] -> 
             RGBColor[
              0.7908941153846153, 0.8374409999999999, 0.9762013461538461], 
             UndirectedEdge[402, 487] -> 
             RGBColor[
              0.9005875000000001, 0.9200127692307692, 0.8313241153846156], 
             UndirectedEdge[356, 463] -> 
             RGBColor[
              0.8923177692307693, 0.8079481538461538, 0.6207713076923077], 
             UndirectedEdge[287, 301] -> 
             RGBColor[
              0.7013388461538461, 0.7651812307692307, 0.9720845384615384], 
             UndirectedEdge[265, 328] -> 
             RGBColor[
              0.7400726538461538, 0.7970135384615384, 0.9746889999999999], 
             UndirectedEdge[196, 321] -> 
             RGBColor[
              0.7472692692307692, 0.8020243846153845, 0.9727670384615384], 
             UndirectedEdge[122, 267] -> 
             RGBColor[
              0.6311015769230769, 0.7068428846153846, 0.9667499615384616], 
             UndirectedEdge[330, 354] -> 
             RGBColor[
              0.8075933076923076, 0.8202691538461538, 0.6569644230769232], 
             UndirectedEdge[155, 393] -> 
             RGBColor[
              0.5405313846153846, 0.6357290384615384, 0.9578182307692308], 
             UndirectedEdge[291, 319] -> 
             RGBColor[
              0.5572127692307692, 0.6501776153846154, 0.9588811538461539], 
             UndirectedEdge[63, 206] -> 
             RGBColor[
              0.43278649999999996`, 0.5488848076923076, 0.9489068461538461], 
             UndirectedEdge[174, 215] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[254, 471] -> 
             RGBColor[
              0.703844576923077, 0.7685680000000001, 0.9711163076923077], 
             UndirectedEdge[453, 463] -> 
             RGBColor[0.9297875, 0.8377293076923076, 0.6210101538461539], 
             UndirectedEdge[154, 174] -> 
             RGBColor[
              0.8789660384615385, 0.7973018461538461, 0.6194978076923077], 
             UndirectedEdge[119, 197] -> 
             RGBColor[
              0.637090076923077, 0.7137457692307692, 0.9662904615384615], 
             UndirectedEdge[50, 340] -> 
             RGBColor[
              0.6186983461538462, 0.6982106153846154, 0.9650094615384616], 
             UndirectedEdge[443, 446] -> 
             RGBColor[
              0.9838410384615385, 0.9557029230769232, 0.5151294615384618], 
             UndirectedEdge[275, 324] -> 
             RGBColor[
              0.7605678461538462, 0.8130245384615384, 0.9767317692307692], 
             UndirectedEdge[95, 286] -> 
             RGBColor[
              0.7025273461538463, 0.7668706923076923, 0.9714419230769231], 
             UndirectedEdge[306, 317] -> 
             RGBColor[0.5083566538461539, 0.5894430384615386, 0.9589455], 
             UndirectedEdge[118, 188] -> 
             RGBColor[
              0.7120033461538461, 0.7675428461538462, 0.7102998461538463], 
             UndirectedEdge[7, 69] -> 
             RGBColor[
              0.6165948846153846, 0.6977347692307692, 0.9642476923076924], 
             UndirectedEdge[88, 166] -> 
             RGBColor[
              0.8593843461538462, 0.8882716153846155, 0.8575748846153847], 
             UndirectedEdge[9, 44] -> 
             RGBColor[
              0.5114844615384615, 0.6142851538461538, 0.9546850769230769], 
             UndirectedEdge[76, 459] -> 
             RGBColor[
              0.5572127692307692, 0.6501776153846154, 0.9588811538461539], 
             UndirectedEdge[254, 325] -> 
             RGBColor[
              0.6410417692307693, 0.7188376923076923, 0.9653136153846154], 
             UndirectedEdge[171, 433] -> 
             RGBColor[
              0.7313570384615384, 0.7851355384615384, 0.8162844230769233], 
             UndirectedEdge[112, 447] -> 
             RGBColor[
              0.6241975769230769, 0.34096261538461536`, 0.5564533846153846], 
             UndirectedEdge[199, 359] -> 
             RGBColor[
              0.45972996153846146`, 0.5698528461538461, 0.9512782307692307], 
             UndirectedEdge[74, 224] -> 
             RGBColor[
              0.9075370769230768, 0.7816793076923079, 0.6139728461538462], 
             UndirectedEdge[292, 386] -> 
             RGBColor[
              0.7092397692307693, 0.7707807692307692, 0.9598612692307693], 
             UndirectedEdge[112, 195] -> 
             RGBColor[
              0.674486423076923, 0.7425840769230769, 0.9703598846153847], 
             UndirectedEdge[97, 408] -> 
             RGBColor[
              0.6661746923076923, 0.7368266153846154, 0.9690938846153846], 
             UndirectedEdge[236, 422] -> 
             RGBColor[
              0.7400726538461538, 0.7970135384615384, 0.9746889999999999], 
             UndirectedEdge[27, 114] -> 
             RGBColor[
              0.6192293461538461, 0.7011293846153845, 0.9635964615384616], 
             UndirectedEdge[110, 355] -> 
             RGBColor[
              0.8183939615384614, 0.8562496153846153, 0.8534893461538462], 
             UndirectedEdge[104, 215] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[80, 406] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[276, 292] -> 
             RGBColor[
              0.8374798461538462, 0.8736360000000001, 0.970815423076923], 
             UndirectedEdge[425, 466] -> 
             RGBColor[
              0.8487568846153847, 0.8823501538461538, 0.9854070769230769], 
             UndirectedEdge[164, 309] -> 
             RGBColor[
              0.6165948846153846, 0.6977347692307692, 0.9642476923076924], 
             UndirectedEdge[95, 137] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[119, 426] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[238, 431] -> 
             RGBColor[
              0.8621086153846154, 0.8929964615384616, 0.9866805769230769], 
             UndirectedEdge[93, 266] -> 
             RGBColor[
              0.6964433846153846, 0.7594186153846154, 0.9491088076923078], 
             UndirectedEdge[15, 148] -> 
             RGBColor[
              0.6273614615384615, 0.6472304999999999, 0.6118751538461538], 
             UndirectedEdge[225, 470] -> 
             RGBColor[
              0.7472692692307692, 0.8020243846153845, 0.9727670384615384], 
             UndirectedEdge[249, 296] -> 
             RGBColor[
              0.627771923076923, 0.7030406153846154, 0.9669605384615385], 
             UndirectedEdge[273, 421] -> 
             RGBColor[
              0.5947316923076922, 0.6655314999999999, 0.9526924615384615], 
             UndirectedEdge[150, 159] -> 
             RGBColor[
              0.7097995384615384, 0.7722432307692307, 0.9725281923076923], 
             UndirectedEdge[85, 407] -> 
             RGBColor[
              0.674486423076923, 0.7425840769230769, 0.9703598846153847], 
             UndirectedEdge[71, 388] -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 
             UndirectedEdge[61, 435] -> 
             RGBColor[
              0.7038445769230769, 0.7685679999999999, 0.9711163076923077], 
             UndirectedEdge[10, 177] -> 
             RGBColor[
              0.6186983461538462, 0.6982106153846154, 0.9650094615384616], 
             UndirectedEdge[16, 52] -> 
             RGBColor[
              0.6909526923076923, 0.7533160384615385, 0.9291029615384616], 
             UndirectedEdge[25, 459] -> 
             RGBColor[
              0.5777079615384616, 0.6661886153846155, 0.9609239230769231], 
             UndirectedEdge[105, 453] -> 
             RGBColor[0.8728748846153846, 0.901485, 0.9843724230769231], 
             UndirectedEdge[61, 384] -> 
             RGBColor[
              0.8015582307692308, 0.8450465384615384, 0.9808173076923077], 
             UndirectedEdge[104, 323] -> 
             RGBColor[
              0.7038445769230769, 0.7685679999999999, 0.9711163076923077], 
             UndirectedEdge[150, 406] -> 
             RGBColor[
              0.835405153846154, 0.8717038461538462, 0.9841335769230769], 
             UndirectedEdge[413, 493] -> 
             RGBColor[
              0.7858677307692308, 0.8322516923076924, 0.9460698076923078], 
             UndirectedEdge[94, 254] -> 
             RGBColor[
              0.7796891153846154, 0.6412573846153846, 0.5936706538461538], 
             UndirectedEdge[431, 487] -> 
             RGBColor[
              0.9563755769230768, 0.9643862307692308, 0.8366745384615387], 
             UndirectedEdge[234, 332] -> 
             RGBColor[
              0.9002668461538462, 0.9193269230769231, 0.7964229230769231], 
             UndirectedEdge[82, 89] -> 
             RGBColor[
              0.7038445769230769, 0.7685679999999999, 0.9711163076923077], 
             UndirectedEdge[154, 255] -> 
             RGBColor[
              0.9190212307692307, 0.8292407692307692, 0.6233183076923077], 
             UndirectedEdge[22, 324] -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 
             UndirectedEdge[105, 112] -> 
             RGBColor[
              0.6186983461538462, 0.6982106153846154, 0.9650094615384616], 
             UndirectedEdge[6, 406] -> 
             RGBColor[
              0.7858253461538462, 0.8326119999999999, 0.9792873846153847], 
             UndirectedEdge[396, 422] -> 
             RGBColor[
              0.7400726538461538, 0.7970135384615384, 0.9746889999999999], 
             UndirectedEdge[409, 456] -> 
             RGBColor[
              0.45972996153846146`, 0.5698528461538461, 0.9512782307692307], 
             UndirectedEdge[91, 473] -> 
             RGBColor[
              0.8391019230769231, 0.8719797692307693, 0.8251958076923079], 
             UndirectedEdge[369, 379] -> 
             RGBColor[
              0.9398536538461537, 0.9542044615384615, 0.9707799230769231], 
             UndirectedEdge[353, 441] -> 
             RGBColor[
              0.7529566923076922, 0.8031246923076922, 0.8483378846153846], 
             UndirectedEdge[165, 481] -> 
             RGBColor[
              0.9724165384615384, 0.9763619230769232, 0.7899937307692307], 
             UndirectedEdge[185, 318] -> 
             RGBColor[0.6535525, 0.538878, 0.5834782692307693], 
             UndirectedEdge[264, 445] -> 
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153], 
             UndirectedEdge[258, 297] -> 
             RGBColor[
              0.5551093076923077, 0.6497017692307692, 0.9581193846153846], 
             UndirectedEdge[57, 139] -> 
             RGBColor[
              0.8182860769230769, 0.855282923076923, 0.7882518461538461], 
             UndirectedEdge[447, 463] -> 
             RGBColor[
              0.8687323846153847, 0.42761930769230766`, 0.20941180769230772`],
              UndirectedEdge[9, 26] -> 
             RGBColor[
              0.7148351153846153, 0.7749537692307692, 0.9503898076923076], 
             UndirectedEdge[181, 262] -> 
             RGBColor[
              0.7802723846153846, 0.8280786923076924, 0.9555412692307692], 
             UndirectedEdge[203, 291] -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 
             UndirectedEdge[45, 254] -> 
             RGBColor[
              0.6410417692307693, 0.7188376923076923, 0.9653136153846154], 
             UndirectedEdge[240, 412] -> 
             RGBColor[0.827552653846154, 0.5038095384615384, 0.574304], 
             UndirectedEdge[208, 258] -> 
             RGBColor[
              0.7059417692307692, 0.6973245384615385, 0.6125346538461538], 
             UndirectedEdge[293, 420] -> 
             RGBColor[
              0.637090076923077, 0.7137457692307692, 0.9662904615384615], 
             UndirectedEdge[85, 346] -> 
             RGBColor[
              0.9286629615384614, 0.9458584615384615, 0.9897228461538461], 
             UndirectedEdge[65, 166] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[254, 347] -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 
             UndirectedEdge[236, 292] -> 
             RGBColor[
              0.8942031153846154, 0.9180925384615385, 0.9764308846153846], 
             UndirectedEdge[100, 401] -> 
             RGBColor[
              0.7810630384615386, 0.8290355384615385, 0.9787745384615385], 
             UndirectedEdge[146, 400] -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             UndirectedEdge[104, 153] -> 
             RGBColor[0.7534243846153845, 0.8076598461538461, 0.9759625], 
             UndirectedEdge[216, 281] -> 
             RGBColor[
              0.7243397692307694, 0.7845790000000001, 0.9731590769230769], 
             UndirectedEdge[123, 125] -> 
             RGBColor[
              0.42123615384615376`, 0.5376959615384614, 0.9484981538461539], 
             UndirectedEdge[78, 358] -> 
             RGBColor[
              0.5982031538461539, 0.6821996153846153, 0.9629666923076923], 
             UndirectedEdge[313, 478] -> 
             RGBColor[
              0.9880308461538461, 0.9893184615384616, 0.8480233846153846], 
             UndirectedEdge[368, 401] -> 
             RGBColor[
              0.5960996923076924, 0.6817237692307693, 0.9622049230769231], 
             UndirectedEdge[106, 369] -> 
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484], 
             UndirectedEdge[111, 146] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[129, 266] -> 
             RGBColor[
              0.6344312307692308, 0.7106451538461538, 0.9665393846153847], 
             UndirectedEdge[99, 278] -> 
             RGBColor[
              0.6852526923076923, 0.7510726153846153, 0.9680517307692308], 
             UndirectedEdge[147, 171] -> 
             RGBColor[
              0.4678596153846154, 0.5788685384615384, 0.9512507692307692], 
             UndirectedEdge[164, 166] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[129, 433] -> 
             RGBColor[
              0.9163203846153847, 0.9324473076923077, 0.8328540384615387], 
             UndirectedEdge[179, 283] -> 
             RGBColor[
              0.7605678461538462, 0.8130245384615384, 0.9767317692307692], 
             UndirectedEdge[136, 291] -> 
             RGBColor[
              0.6628541923076923, 0.7365459999999999, 0.9670307692307691], 
             UndirectedEdge[321, 479] -> 
             RGBColor[
              0.6807149230769232, 0.7491623846153845, 0.9697247692307692], 
             UndirectedEdge[181, 239] -> 
             RGBColor[
              0.6205465769230769, 0.7028266923076922, 0.9632708461538462], 
             UndirectedEdge[102, 330] -> 
             RGBColor[
              0.5551093076923077, 0.6497017692307692, 0.9581193846153846], 
             UndirectedEdge[406, 413] -> 
             RGBColor[
              0.7025273461538463, 0.7668706923076923, 0.9714419230769231], 
             UndirectedEdge[37, 310] -> 
             RGBColor[
              0.7231512692307691, 0.7828895384615384, 0.9738016923076923], 
             UndirectedEdge[203, 439] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[320, 375] -> 
             RGBColor[
              0.7967943076923077, 0.8382604615384616, 0.8214358846153849], 
             UndirectedEdge[42, 407] -> 
             RGBColor[
              0.5982031538461539, 0.6821996153846153, 0.9629666923076923], 
             UndirectedEdge[131, 374] -> 
             RGBColor[
              0.9389722307692308, 0.9524333076923077, 0.9293569615384616], 
             UndirectedEdge[387, 403] -> 
             RGBColor[
              0.7605678461538462, 0.8130245384615384, 0.9767317692307692], 
             UndirectedEdge[65, 348] -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             UndirectedEdge[217, 498] -> 
             RGBColor[
              0.6746353846153845, 0.7438886153846154, 0.9695375384615385], 
             UndirectedEdge[40, 397] -> 
             RGBColor[
              0.9131501923076923, 0.9329118461538461, 0.9682329230769231], 
             UndirectedEdge[226, 292] -> 
             RGBColor[
              0.6574852692307691, 0.7263484615384616, 0.9564544230769231], 
             UndirectedEdge[53, 257] -> 
             RGBColor[
              0.9781325000000001, 0.9412325384615385, 0.5502933461538463], 
             UndirectedEdge[220, 429] -> 
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923], 
             UndirectedEdge[139, 425] -> 
             RGBColor[
              0.9002668461538462, 0.9193269230769231, 0.7964229230769231], 
             UndirectedEdge[317, 418] -> 
             RGBColor[
              0.9053069615384616, 0.8967476923076924, 0.6666654230769231], 
             UndirectedEdge[482, 496] -> 
             RGBColor[
              0.6186983461538462, 0.6982106153846154, 0.9650094615384616], 
             UndirectedEdge[117, 466] -> 
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484], 
             UndirectedEdge[82, 105] -> 
             RGBColor[
              0.7858253461538462, 0.8326119999999999, 0.9792873846153847], 
             UndirectedEdge[239, 453] -> 
             RGBColor[
              0.7908941153846153, 0.8374409999999999, 0.9762013461538461], 
             UndirectedEdge[274, 340] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[311, 484] -> 
             RGBColor[
              0.765330153846154, 0.8166010000000001, 0.9772446153846154], 
             UndirectedEdge[44, 140] -> 
             RGBColor[
              0.7472692692307692, 0.8020243846153845, 0.9727670384615384], 
             UndirectedEdge[139, 466] -> 
             RGBColor[
              0.9427031923076923, 0.9530540769230769, 0.8004998461538462], 
             UndirectedEdge[22, 481] -> 
             RGBColor[
              0.9159997307692308, 0.9317614615384615, 0.7979528461538461], 
             UndirectedEdge[45, 386] -> 
             RGBColor[
              0.5332968846153847, 0.6319934615384615, 0.9564022307692308], 
             UndirectedEdge[40, 220] -> 
             RGBColor[
              0.9131501923076923, 0.9329118461538461, 0.9682329230769231], 
             UndirectedEdge[237, 489] -> 
             RGBColor[
              0.5114844615384615, 0.6142851538461538, 0.9546850769230769], 
             UndirectedEdge[61, 64] -> 
             RGBColor[
              0.6165948846153846, 0.6977347692307692, 0.9642476923076924], 
             UndirectedEdge[82, 296] -> 
             RGBColor[
              0.8282616923076923, 0.8663391538461538, 0.9833643076923078], 
             UndirectedEdge[27, 277] -> 
             RGBColor[
              0.7605678461538462, 0.8130245384615384, 0.9767317692307692], 
             UndirectedEdge[416, 427] -> 
             RGBColor[
              0.6003774615384616, 0.6638939615384616, 0.8598054230769231], 
             UndirectedEdge[59, 82] -> 
             RGBColor[
              0.8282616923076923, 0.8663391538461538, 0.9833643076923078], 
             UndirectedEdge[271, 444] -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 
             UndirectedEdge[6, 486] -> 
             RGBColor[0.879451, 0.9026300769230768, 0.7594789615384616], 
             UndirectedEdge[171, 265] -> 
             RGBColor[
              0.6528229615384615, 0.7261803076923077, 0.9678203846153846], 
             UndirectedEdge[219, 369] -> 
             RGBColor[
              0.9075370769230768, 0.7816793076923079, 0.6139728461538462], 
             UndirectedEdge[244, 355] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[450, 500] -> 
             RGBColor[
              0.8145551153846153, 0.8546621538461538, 0.9171089615384616], 
             UndirectedEdge[18, 243] -> 
             RGBColor[
              0.6528229615384615, 0.7261803076923077, 0.9678203846153846], 
             UndirectedEdge[377, 449] -> 
             RGBColor[
              0.8751722307692309, 0.8322017692307693, 0.6275743461538461], 
             UndirectedEdge[7, 173] -> 
             RGBColor[
              0.703644423076923, 0.7666077692307691, 0.9693327307692308], 
             UndirectedEdge[3, 8] -> 
             RGBColor[
              0.6344312307692308, 0.7106451538461538, 0.9665393846153847], 
             UndirectedEdge[405, 469] -> 
             RGBColor[
              0.7801278461538461, 0.8289524615384615, 0.9785094999999999], 
             UndirectedEdge[148, 190] -> 
             RGBColor[
              0.5873943846153846, 0.4806518846153846, 0.5792965384615385], 
             UndirectedEdge[180, 216] -> 
             RGBColor[
              0.703844576923077, 0.7685680000000001, 0.9711163076923077], 
             UndirectedEdge[257, 317] -> 
             RGBColor[
              0.9010908076923078, 0.8825256153846155, 0.6502864615384616], 
             UndirectedEdge[49, 462] -> 
             RGBColor[
              0.7426686538461539, 0.6315458076923077, 0.5943224615384615], 
             UndirectedEdge[223, 258] -> 
             RGBColor[
              0.7273054230769231, 0.7838289230769231, 0.9102403461538462], 
             UndirectedEdge[260, 440] -> 
             RGBColor[
              0.6746353846153845, 0.7438886153846154, 0.9695375384615385], 
             UndirectedEdge[262, 332] -> 
             RGBColor[
              0.9780118846153846, 0.9805349230769231, 0.7805222692307692], 
             UndirectedEdge[283, 386] -> 
             RGBColor[
              0.6528229615384615, 0.7261803076923077, 0.9678203846153846], 
             UndirectedEdge[40, 289] -> 
             RGBColor[
              0.9131501923076923, 0.9329118461538461, 0.9682329230769231], 
             UndirectedEdge[95, 430] -> 
             RGBColor[
              0.6807149230769232, 0.7491623846153845, 0.9697247692307692], 
             UndirectedEdge[274, 334] -> 
             RGBColor[
              0.6192293461538461, 0.7011293846153845, 0.9635964615384616], 
             UndirectedEdge[75, 158] -> 
             RGBColor[
              0.9294593461538462, 0.9433744615384616, 0.8644638461538462], 
             UndirectedEdge[233, 476] -> 
             RGBColor[
              0.5114844615384615, 0.6142851538461538, 0.9546850769230769], 
             UndirectedEdge[240, 416] -> 
             RGBColor[
              0.5131021153846154, 0.23550449999999998`, 0.5497125384615384], 
             UndirectedEdge[260, 280] -> 
             RGBColor[
              0.8886077692307692, 0.9139195384615384, 0.9859023461538461], 
             UndirectedEdge[11, 193] -> 
             RGBColor[
              0.5974169230769231, 0.6834210769230769, 0.9618793076923077], 
             UndirectedEdge[3, 162] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[117, 338] -> 
             RGBColor[
              0.8282616923076923, 0.8663391538461538, 0.9833643076923078], 
             UndirectedEdge[40, 472] -> 
             RGBColor[
              0.7739195769230769, 0.8236708461538462, 0.9780052692307692], 
             UndirectedEdge[101, 355] -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 
             UndirectedEdge[47, 364] -> 
             RGBColor[0.8968746538461538, 0.8683035384615385, 0.6339075], 
             UndirectedEdge[377, 484] -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 
             UndirectedEdge[21, 227] -> 
             RGBColor[
              0.7810630384615386, 0.8290355384615385, 0.9787745384615385], 
             UndirectedEdge[158, 441] -> 
             RGBColor[
              0.9294593461538462, 0.9433744615384616, 0.8644638461538462], 
             UndirectedEdge[201, 222] -> 
             RGBColor[
              0.7097995384615384, 0.7722432307692307, 0.9725281923076923], 
             UndirectedEdge[107, 477] -> 
             RGBColor[
              0.6205465769230769, 0.7028266923076922, 0.9632708461538462], 
             UndirectedEdge[89, 239] -> 
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988], 
             UndirectedEdge[63, 275] -> 
             RGBColor[
              0.5405313846153846, 0.6357290384615384, 0.9578182307692308], 
             UndirectedEdge[133, 344] -> 
             RGBColor[
              0.841613423076923, 0.8769854615384615, 0.9846378076923077], 
             UndirectedEdge[153, 356] -> 
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937], 
             UndirectedEdge[151, 188] -> 
             RGBColor[
              0.5572127692307692, 0.6501776153846154, 0.9588811538461539], 
             UndirectedEdge[140, 204] -> 
             RGBColor[
              0.6685713076923077, 0.7366240384615383, 0.9669888076923077], 
             UndirectedEdge[154, 369] -> 
             RGBColor[
              0.9190212307692307, 0.8292407692307692, 0.6233183076923077], 
             UndirectedEdge[16, 179] -> 
             RGBColor[
              0.5405313846153846, 0.6357290384615384, 0.9578182307692308], 
             UndirectedEdge[161, 341] -> 
             RGBColor[0.7534243846153845, 0.8076598461538461, 0.9759625], 
             UndirectedEdge[48, 408] -> 
             RGBColor[
              0.4896720384615384, 0.5965768461538461, 0.952967923076923], 
             UndirectedEdge[153, 263] -> 
             RGBColor[0.9019595, 0.9245658461538462, 0.9871758461538461], 
             UndirectedEdge[62, 132] -> 
             RGBColor[
              0.7097995384615384, 0.7722432307692307, 0.9725281923076923], 
             UndirectedEdge[82, 225] -> 
             RGBColor[
              0.8523796923076923, 0.8854739999999999, 0.9823296538461539], 
             UndirectedEdge[216, 465] -> 
             RGBColor[
              0.7810630384615386, 0.8290355384615385, 0.9787745384615385], 
             UndirectedEdge[119, 489] -> 
             RGBColor[
              0.637090076923077, 0.7137457692307692, 0.9662904615384615], 
             UndirectedEdge[287, 295] -> 
             RGBColor[
              0.7013388461538461, 0.7651812307692307, 0.9720845384615384], 
             UndirectedEdge[28, 417] -> 
             RGBColor[
              0.7744019615384616, 0.6172496538461539, 0.5892589230769231], 
             UndirectedEdge[148, 351] -> 
             RGBColor[
              0.5949765769230768, 0.6737116538461538, 0.9649046538461539], 
             UndirectedEdge[218, 336] -> 
             RGBColor[
              0.5572127692307692, 0.6501776153846154, 0.9588811538461539], 
             UndirectedEdge[127, 254] -> 
             RGBColor[0.8280885, 0.836280153846154, 0.6590071923076923], 
             UndirectedEdge[303, 473] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[99, 267] -> 
             RGBColor[
              0.6685713076923077, 0.7366240384615383, 0.9669888076923077], 
             UndirectedEdge[48, 145] -> 
             RGBColor[
              0.6179121153846154, 0.6994320769230769, 0.963922076923077], 
             UndirectedEdge[224, 342] -> 
             RGBColor[
              0.8312538076923077, 0.7212948461538463, 0.6065796538461539], 
             UndirectedEdge[193, 232] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[216, 343] -> 
             RGBColor[
              0.8595971153846155, 0.8879907692307694, 0.8272385769230772], 
             UndirectedEdge[277, 449] -> 
             RGBColor[
              0.8909051153846155, 0.8446363076923078, 0.6291042692307692], 
             UndirectedEdge[257, 418] -> 
             RGBColor[
              0.9686114615384616, 0.9057812307692309, 0.3325618846153848], 
             UndirectedEdge[45, 422] -> 
             RGBColor[
              0.6205465769230769, 0.7028266923076922, 0.9632708461538462], 
             UndirectedEdge[133, 235] -> 
             RGBColor[
              0.5815217692307693, 0.6677510384615384, 0.9619037692307693], 
             UndirectedEdge[145, 183] -> 
             RGBColor[
              0.765330153846154, 0.8166010000000001, 0.9772446153846154], 
             UndirectedEdge[196, 496] -> 
             RGBColor[
              0.6852526923076923, 0.7510726153846153, 0.9680517307692308], 
             UndirectedEdge[115, 136] -> 
             RGBColor[
              0.7038445769230769, 0.7685679999999999, 0.9711163076923077], 
             UndirectedEdge[267, 413] -> 
             RGBColor[
              0.4982237692307693, 0.6020097307692307, 0.9540583076923077], 
             UndirectedEdge[217, 340] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[335, 383] -> 
             RGBColor[
              0.5816248461538461, 0.663065346153846, 0.9636311538461538], 
             UndirectedEdge[80, 493] -> 
             RGBColor[
              0.9053938076923077, 0.9264385384615385, 0.9574879615384615], 
             UndirectedEdge[307, 372] -> 
             RGBColor[0.8020848076923076, 0.845787, 0.957258423076923], 
             UndirectedEdge[18, 434] -> 
             RGBColor[
              0.9163203846153847, 0.9324473076923077, 0.8328540384615387], 
             UndirectedEdge[130, 179] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[20, 228] -> 
             RGBColor[0.8747610769230769, 0.902166, 0.9444438076923076], 
             UndirectedEdge[297, 311] -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 
             UndirectedEdge[127, 200] -> 
             RGBColor[
              0.9836282692307692, 0.9559837692307693, 0.5454657692307694], 
             UndirectedEdge[54, 391] -> 
             RGBColor[
              0.43278649999999996`, 0.5488848076923076, 0.9489068461538461], 
             UndirectedEdge[347, 368] -> 
             RGBColor[
              0.5756045000000001, 0.6657127692307692, 0.9601621538461538], 
             UndirectedEdge[22, 182] -> 
             RGBColor[
              0.8942031153846154, 0.9180925384615385, 0.9764308846153846], 
             UndirectedEdge[96, 216] -> 
             RGBColor[
              0.5443451923076924, 0.6372914615384616, 0.9587980769230768], 
             UndirectedEdge[340, 363] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[71, 490] -> 
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153], 
             UndirectedEdge[111, 201] -> 
             RGBColor[
              0.6192293461538461, 0.7011293846153845, 0.9635964615384616], 
             UndirectedEdge[261, 484] -> 
             RGBColor[
              0.9005875000000001, 0.9200127692307692, 0.8313241153846156], 
             UndirectedEdge[416, 499] -> 
             RGBColor[
              0.5500392307692308, 0.6264796538461539, 0.9623455384615385], 
             UndirectedEdge[42, 430] -> 
             RGBColor[
              0.6602197307692308, 0.7331513846153845, 0.9676819999999999], 
             UndirectedEdge[6, 81] -> 
             RGBColor[
              0.5648403846153847, 0.6533024615384615, 0.9608408461538461], 
             UndirectedEdge[282, 353] -> 
             RGBColor[
              0.5974169230769231, 0.6834210769230769, 0.9618793076923077], 
             UndirectedEdge[275, 441] -> 
             RGBColor[
              0.8388891538461538, 0.8722606153846154, 0.8555321153846154], 
             UndirectedEdge[50, 255] -> 
             RGBColor[
              0.674486423076923, 0.7425840769230769, 0.9703598846153847], 
             UndirectedEdge[110, 217] -> 
             RGBColor[
              0.9161076153846155, 0.9327281538461538, 0.8631903461538462], 
             UndirectedEdge[30, 110] -> 
             RGBColor[
              0.7965815384615385, 0.8385413076923077, 0.8517721923076924], 
             UndirectedEdge[77, 482] -> 
             RGBColor[
              0.8487568846153847, 0.8823501538461538, 0.9854070769230769], 
             UndirectedEdge[52, 326] -> 
             RGBColor[0.951044346153846, 0.9625504615384615, 0.951837], 
             UndirectedEdge[44, 247] -> 
             RGBColor[
              0.7097995384615384, 0.7722432307692307, 0.9725281923076923], 
             UndirectedEdge[337, 348] -> 
             RGBColor[
              0.6384073076923076, 0.7154430769230768, 0.9659648461538461], 
             UndirectedEdge[48, 78] -> 
             RGBColor[
              0.47128030769230755`, 0.5810416923076922, 0.9516869230769232], 
             UndirectedEdge[420, 432] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[469, 474] -> 
             RGBColor[
              0.6578050384615384, 0.7281354999999999, 0.9692969615384616], 
             UndirectedEdge[172, 366] -> 
             RGBColor[
              0.7858677307692308, 0.8322516923076924, 0.9460698076923078], 
             UndirectedEdge[102, 415] -> 
             RGBColor[
              0.5551093076923077, 0.6497017692307692, 0.9581193846153846], 
             UndirectedEdge[414, 485] -> 
             RGBColor[
              0.7965815384615385, 0.8385413076923077, 0.8517721923076924], 
             UndirectedEdge[102, 193] -> 
             RGBColor[
              0.5756045000000001, 0.6657127692307692, 0.9601621538461538], 
             UndirectedEdge[128, 498] -> 
             RGBColor[
              0.7146905769230768, 0.7758275384615383, 0.9733580384615385], 
             UndirectedEdge[150, 443] -> 
             RGBColor[0.9186586923076923, 0.907394, 0.667938923076923], 
             UndirectedEdge[2, 230] -> 
             RGBColor[
              0.44946788461538456`, 0.5633333846153845, 0.9499697692307693], 
             UndirectedEdge[367, 416] -> 
             RGBColor[0.3032993076923077, 0.4278915384615384, 0.940885], 
             UndirectedEdge[61, 473] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[56, 164] -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             UndirectedEdge[20, 388] -> 
             RGBColor[
              0.7858253461538462, 0.8326119999999999, 0.9792873846153847], 
             UndirectedEdge[195, 296] -> 
             RGBColor[0.9045449615384615, 0.9267236153846153, 0.9907575], 
             UndirectedEdge[135, 391] -> 
             RGBColor[
              0.6928781538461538, 0.7581192307692307, 0.9716408846153846], 
             UndirectedEdge[310, 399] -> 
             RGBColor[
              0.7097995384615384, 0.7722432307692307, 0.9725281923076923], 
             UndirectedEdge[150, 476] -> 
             RGBColor[
              0.6661746923076923, 0.7368266153846154, 0.9690938846153846], 
             UndirectedEdge[142, 222] -> 
             RGBColor[
              0.9187455384615384, 0.9370848461538461, 0.9587614615384615], 
             UndirectedEdge[48, 404] -> 
             RGBColor[
              0.7478382307692306, 0.8010080769230769, 0.9331640384615385], 
             UndirectedEdge[330, 415] -> 
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988], 
             UndirectedEdge[326, 495] -> 
             RGBColor[
              0.6411236538461538, 0.713686923076923, 0.9682340384615384], 
             UndirectedEdge[36, 382] -> 
             RGBColor[
              0.703844576923077, 0.7685680000000001, 0.9711163076923077], 
             UndirectedEdge[31, 289] -> 
             RGBColor[0.8020848076923076, 0.845787, 0.957258423076923], 
             UndirectedEdge[436, 487] -> 
             RGBColor[
              0.7531694615384614, 0.8028438461538461, 0.8180015769230772], 
             UndirectedEdge[251, 427] -> 
             RGBColor[
              0.8171143461538461, 0.8557204615384615, 0.8746958846153846], 
             UndirectedEdge[108, 437] -> 
             RGBColor[0.7667761153846153, 0.8183061538461538, 0.977236], 
             UndirectedEdge[258, 397] -> 
             RGBColor[
              0.7148351153846153, 0.7749537692307692, 0.9503898076923076], 
             UndirectedEdge[308, 422] -> 
             RGBColor[0.7667761153846153, 0.8183061538461538, 0.977236], 
             UndirectedEdge[16, 292] -> 
             RGBColor[
              0.6741666538461537, 0.7407970384615384, 0.9575173461538462], 
             UndirectedEdge[68, 317] -> 
             RGBColor[0.8778414999999999, 0.905431, 0.9882105], 
             UndirectedEdge[34, 468] -> 
             RGBColor[
              0.6661746923076923, 0.7368266153846154, 0.9690938846153846], 
             UndirectedEdge[350, 383] -> 
             RGBColor[
              0.835405153846154, 0.8717038461538462, 0.9841335769230769], 
             UndirectedEdge[190, 342] -> 
             RGBColor[0.8206795, 0.6732793846153846, 0.5977561923076924], 
             UndirectedEdge[61, 303] -> 
             RGBColor[
              0.7858253461538462, 0.8326119999999999, 0.9792873846153847], 
             UndirectedEdge[214, 421] -> 
             RGBColor[
              0.5383148846153847, 0.6209310384615385, 0.9606515769230769], 
             UndirectedEdge[219, 370] -> 
             RGBColor[
              0.9183033461538461, 0.7901678461538464, 0.6116646923076924], 
             UndirectedEdge[91, 366] -> 
             RGBColor[
              0.9839278846153846, 0.9853937692307693, 0.8059520000000002], 
             UndirectedEdge[273, 477] -> 
             RGBColor[0.7964894615384615, 0.841614, 0.9667298846153847], 
             UndirectedEdge[153, 323] -> 
             RGBColor[
              0.8149099615384616, 0.8556928461538461, 0.9820908076923076], 
             UndirectedEdge[170, 433] -> 
             RGBColor[
              0.7313570384615384, 0.7851355384615384, 0.8162844230769233], 
             UndirectedEdge[1, 54] -> 
             RGBColor[0.45459892307692296`, 0.5665931153846153, 0.950624], 
             UndirectedEdge[277, 377] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[307, 417] -> 
             RGBColor[
              0.6628541923076923, 0.7365459999999999, 0.9670307692307691], 
             UndirectedEdge[58, 371] -> 
             RGBColor[
              0.9005875000000001, 0.9200127692307692, 0.8313241153846156], 
             UndirectedEdge[9, 269] -> 
             RGBColor[
              0.703644423076923, 0.7666077692307691, 0.9693327307692308], 
             UndirectedEdge[184, 453] -> 
             RGBColor[
              0.7908941153846153, 0.8374409999999999, 0.9762013461538461], 
             UndirectedEdge[42, 97] -> 
             RGBColor[
              0.8149099615384616, 0.8556928461538461, 0.9820908076923076], 
             UndirectedEdge[161, 405] -> 
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988], 
             UndirectedEdge[304, 429] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[127, 130] -> 
             RGBColor[
              0.889574076923077, 0.8843131538461539, 0.6651355000000001], 
             UndirectedEdge[318, 330] -> 
             RGBColor[
              0.759193923076923, 0.6252463846153846, 0.5916278846153846], 
             UndirectedEdge[393, 468] -> 
             RGBColor[
              0.43278649999999996`, 0.5488848076923076, 0.9489068461538461], 
             UndirectedEdge[334, 355] -> 
             RGBColor[
              0.5987341538461537, 0.6851183846153845, 0.9615536923076923], 
             UndirectedEdge[290, 378] -> 
             RGBColor[
              0.5114844615384614, 0.6142851538461537, 0.9546850769230769], 
             UndirectedEdge[92, 498] -> 
             RGBColor[
              0.7478382307692306, 0.8010080769230769, 0.9331640384615385], 
             UndirectedEdge[340, 362] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[58, 304] -> 
             RGBColor[
              0.7858253461538462, 0.8326119999999999, 0.9792873846153847], 
             UndirectedEdge[51, 308] -> 
             RGBColor[
              0.9430238461538462, 0.953739923076923, 0.8354010384615387], 
             UndirectedEdge[59, 447] -> 
             RGBColor[0.8542561153846153, 0.5251021538461538, 0.576851], 
             UndirectedEdge[186, 485] -> 
             RGBColor[
              0.7534704230769231, 0.6794477692307693, 0.6032764230769231], 
             UndirectedEdge[340, 379] -> 
             RGBColor[
              0.884065576923077, 0.9098310000000001, 0.9654294999999999], 
             UndirectedEdge[129, 410] -> 
             RGBColor[
              0.6344312307692308, 0.7106451538461538, 0.9665393846153847], 
             UndirectedEdge[192, 225] -> 
             RGBColor[
              0.7690816923076923, 0.8197326923076923, 0.9744841923076923], 
             UndirectedEdge[306, 420] -> 
             RGBColor[0.4926237692307693, 0.5770085, 0.957415576923077], 
             UndirectedEdge[16, 45] -> 
             RGBColor[
              0.4982237692307693, 0.6020097307692307, 0.9540583076923077], 
             UndirectedEdge[334, 361] -> 
             RGBColor[
              0.6602197307692308, 0.7331513846153845, 0.9676819999999999], 
             UndirectedEdge[306, 357] -> 
             RGBColor[
              0.5865700769230768, 0.6477124230769231, 0.7725083461538461], 
             UndirectedEdge[335, 496] -> 
             RGBColor[
              0.36491803846153836`, 0.4895721153846153, 0.9445070384615385], 
             UndirectedEdge[176, 345] -> 
             RGBColor[
              0.9918696923076923, 0.990905923076923, 0.7844037692307695], 
             UndirectedEdge[15, 78] -> 
             RGBColor[
              0.6935195769230769, 0.7054566153846153, 0.6160568846153847], 
             UndirectedEdge[52, 210] -> 
             RGBColor[
              0.7478382307692306, 0.8010080769230769, 0.9331640384615385], 
             UndirectedEdge[392, 465] -> 
             RGBColor[
              0.8015582307692308, 0.8450465384615384, 0.9808173076923077], 
             UndirectedEdge[354, 414] -> 
             RGBColor[
              0.9836282692307692, 0.9559837692307693, 0.5454657692307694], 
             UndirectedEdge[56, 428] -> 
             RGBColor[
              0.5982031538461539, 0.6821996153846153, 0.9629666923076923], 
             UndirectedEdge[44, 425] -> 
             RGBColor[
              0.6807149230769232, 0.7491623846153845, 0.9697247692307692], 
             UndirectedEdge[106, 468] -> 
             RGBColor[
              0.6661746923076923, 0.7368266153846154, 0.9690938846153846], 
             UndirectedEdge[142, 461] -> 
             RGBColor[0.7422428846153846, 0.7968350769230768, 0.9426355], 
             UndirectedEdge[203, 297] -> 
             RGBColor[
              0.6628541923076923, 0.7365459999999999, 0.9670307692307691], 
             UndirectedEdge[24, 176] -> 
             RGBColor[
              0.9135483846153847, 0.9316698461538462, 0.9056034230769232], 
             UndirectedEdge[351, 356] -> 
             RGBColor[0.8778414999999999, 0.905431, 0.9882105], 
             UndirectedEdge[315, 368] -> 
             RGBColor[
              0.6165948846153846, 0.6977347692307692, 0.9642476923076924], 
             UndirectedEdge[278, 406] -> 
             RGBColor[
              0.6186983461538462, 0.6982106153846154, 0.9650094615384616], 
             UndirectedEdge[247, 360] -> 
             RGBColor[
              0.6477829615384615, 0.7212914615384616, 0.9678128846153846], 
             UndirectedEdge[78, 145] -> 
             RGBColor[
              0.5777079615384616, 0.6661886153846155, 0.9609239230769231], 
             UndirectedEdge[19, 466] -> 
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937], 
             UndirectedEdge[60, 151] -> 
             RGBColor[
              0.5405313846153846, 0.6357290384615384, 0.9578182307692308], 
             UndirectedEdge[109, 186] -> 
             RGBColor[0.9350086538461538, 0.822408076923077, 0.597264], 
             UndirectedEdge[474, 495] -> 
             RGBColor[0.381032, 0.5044525, 0.9455], UndirectedEdge[36, 412] -> 
             RGBColor[
              0.7605678461538462, 0.8130245384615384, 0.9767317692307692], 
             UndirectedEdge[259, 469] -> 
             RGBColor[
              0.8621086153846154, 0.8929964615384616, 0.9866805769230769], 
             UndirectedEdge[6, 80] -> 
             RGBColor[
              0.8015582307692308, 0.8450465384615384, 0.9808173076923077], 
             UndirectedEdge[287, 389] -> 
             RGBColor[
              0.9389722307692308, 0.9524333076923077, 0.9293569615384616], 
             UndirectedEdge[158, 410] -> 
             RGBColor[
              0.6477829615384615, 0.7212914615384616, 0.9678128846153846], 
             UndirectedEdge[414, 415] -> 
             RGBColor[
              0.8183939615384614, 0.8562496153846153, 0.8534893461538462], 
             UndirectedEdge[10, 245] -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 
             UndirectedEdge[115, 178] -> 
             RGBColor[
              0.8760406923076923, 0.9026951538461538, 0.9232372692307693], 
             UndirectedEdge[88, 348] -> 
             RGBColor[
              0.8798795384615385, 0.9042826153846153, 0.859617653846154], 
             UndirectedEdge[135, 170] -> 
             RGBColor[
              0.6928781538461538, 0.7581192307692307, 0.9716408846153846], 
             UndirectedEdge[3, 203] -> 
             RGBColor[
              0.7605678461538462, 0.8130245384615384, 0.9767317692307692], 
             UndirectedEdge[84, 374] -> 
             RGBColor[
              0.9122687692307693, 0.9311406923076924, 0.9268099615384616], 
             UndirectedEdge[29, 172] -> 
             RGBColor[
              0.6820321538461539, 0.7508596923076922, 0.9693991538461538], 
             UndirectedEdge[262, 387] -> 
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923], 
             UndirectedEdge[179, 276] -> 
             RGBColor[
              0.703844576923077, 0.7685680000000001, 0.9711163076923077], 
             UndirectedEdge[348, 428] -> 
             RGBColor[
              0.5982031538461539, 0.6821996153846153, 0.9629666923076923], 
             UndirectedEdge[104, 351] -> 
             RGBColor[0.7667761153846153, 0.8183061538461538, 0.977236], 
             UndirectedEdge[111, 271] -> 
             RGBColor[
              0.703844576923077, 0.7685680000000001, 0.9711163076923077], 
             UndirectedEdge[136, 277] -> 
             RGBColor[
              0.7400726538461538, 0.7970135384615384, 0.9746889999999999], 
             UndirectedEdge[246, 442] -> 
             RGBColor[
              0.8006230384615385, 0.8449634615384616, 0.9805522692307692], 
             UndirectedEdge[206, 266] -> 
             RGBColor[
              0.44946788461538456`, 0.5633333846153845, 0.9499697692307693], 
             UndirectedEdge[31, 381] -> 
             RGBColor[
              0.6628541923076923, 0.7365459999999999, 0.9670307692307691], 
             UndirectedEdge[31, 472] -> 
             RGBColor[
              0.6628541923076923, 0.7365459999999999, 0.9670307692307691], 
             UndirectedEdge[342, 453] -> 
             RGBColor[
              0.8523796923076923, 0.8854739999999999, 0.9823296538461539], 
             UndirectedEdge[200, 475] -> 
             RGBColor[
              0.8183939615384614, 0.8562496153846153, 0.8534893461538462], 
             UndirectedEdge[92, 101] -> 
             RGBColor[0.8542658846153847, 0.886155, 0.9424010384615384], 
             UndirectedEdge[193, 376] -> 
             RGBColor[
              0.8384606153846155, 0.870608076923077, 0.755393423076923], 
             UndirectedEdge[253, 319] -> 
             RGBColor[
              0.49309273076923066`, 0.5987499999999999, 0.9534040769230769], 
             UndirectedEdge[249, 280] -> 
             RGBColor[
              0.6518899230769231, 0.7221754615384615, 0.9659258846153846], 
             UndirectedEdge[153, 195] -> 
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484], 
             UndirectedEdge[313, 380] -> 
             RGBColor[
              0.7516770769230768, 0.8025955384615384, 0.8695444230769231], 
             UndirectedEdge[178, 357] -> 
             RGBColor[
              0.9904821923076923, 0.9894100769230769, 0.7403728076923077], 
             UndirectedEdge[163, 494] -> 
             RGBColor[
              0.45972996153846146`, 0.5698528461538461, 0.9512782307692307], 
             UndirectedEdge[24, 237] -> 
             RGBColor[
              0.6964478076923077, 0.7615969230769231, 0.9712546923076923], 
             UndirectedEdge[101, 345] -> 
             RGBColor[
              0.8593843461538462, 0.8882716153846155, 0.8575748846153847], 
             UndirectedEdge[320, 361] -> 
             RGBColor[
              0.6820321538461539, 0.7508596923076922, 0.9693991538461538], 
             UndirectedEdge[328, 487] -> 
             RGBColor[
              0.8186067307692307, 0.8559687692307691, 0.8231530384615386], 
             UndirectedEdge[322, 494] -> 
             RGBColor[
              0.6602197307692308, 0.7331513846153845, 0.9676819999999999], 
             UndirectedEdge[108, 266] -> 
             RGBColor[
              0.6611346923076923, 0.7319377692307691, 0.9690863846153847], 
             UndirectedEdge[405, 474] -> 
             RGBColor[
              0.5200361923076923, 0.6197180384615384, 0.9557754615384615], 
             UndirectedEdge[338, 379] -> 
             RGBColor[0.8635703846153846, 0.89382, 0.9633867307692308], 
             UndirectedEdge[175, 309] -> 
             RGBColor[
              0.5114844615384615, 0.6142851538461538, 0.9546850769230769], 
             UndirectedEdge[294, 430] -> 
             RGBColor[
              0.6807149230769232, 0.7491623846153845, 0.9697247692307692], 
             UndirectedEdge[197, 237] -> 
             RGBColor[
              0.5114844615384615, 0.6142851538461538, 0.9546850769230769], 
             UndirectedEdge[94, 500] -> 
             RGBColor[
              0.9313900384615384, 0.7593735384615385, 0.5437488461538462], 
             UndirectedEdge[242, 365] -> 
             RGBColor[
              0.6020169615384616, 0.6837620384615384, 0.9639465384615384], 
             UndirectedEdge[401, 500] -> 
             RGBColor[
              0.8555455000000001, 0.8866841538461538, 0.9211945000000001], 
             UndirectedEdge[334, 340] -> 
             RGBColor[
              0.6807149230769232, 0.7491623846153845, 0.9697247692307692], 
             UndirectedEdge[60, 310] -> 
             RGBColor[
              0.47641134615384606`, 0.584301423076923, 0.9523411538461539], 
             UndirectedEdge[50, 379] -> 
             RGBColor[
              0.6964433846153846, 0.7594186153846154, 0.9491088076923078], 
             UndirectedEdge[123, 177] -> 
             RGBColor[
              0.47128030769230755`, 0.5810416923076922, 0.9516869230769232], 
             UndirectedEdge[231, 246] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[182, 282] -> 
             RGBColor[
              0.8169846538461538, 0.8576250000000001, 0.9687726538461539], 
             UndirectedEdge[185, 193] -> 
             RGBColor[
              0.5572127692307692, 0.6501776153846154, 0.9588811538461539], 
             UndirectedEdge[395, 447] -> 
             RGBColor[0.8118197692307694, 0.491375, 0.5727740769230769], 
             UndirectedEdge[22, 282] -> 
             RGBColor[
              0.7605678461538462, 0.8130245384615384, 0.9767317692307692], 
             UndirectedEdge[195, 323] -> 
             RGBColor[
              0.841613423076923, 0.8769854615384615, 0.9846378076923077], 
             UndirectedEdge[99, 486] -> 
             RGBColor[0.9665005384615384, 0.9715030769230769, 0.764564], 
             UndirectedEdge[454, 469] -> 
             RGBColor[0.941146, 0.9144645384615385, 0.6541069615384616], 
             UndirectedEdge[31, 208] -> 
             RGBColor[
              0.7931914615384615, 0.7681577692307693, 0.6194032692307692], 
             UndirectedEdge[398, 472] -> 
             RGBColor[0.4910546538461538, 0.5919515, 0.954699423076923], 
             UndirectedEdge[191, 389] -> 
             RGBColor[
              0.7089136923076922, 0.7682937692307692, 0.9089593461538463], 
             UndirectedEdge[133, 151] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[165, 268] -> 
             RGBColor[0.8579750384615384, 0.889647, 0.9728581923076923], 
             UndirectedEdge[166, 495] -> 
             RGBColor[
              0.5443451923076924, 0.6372914615384616, 0.9587980769230768], 
             UndirectedEdge[346, 430] -> 
             RGBColor[
              0.7472692692307692, 0.8020243846153845, 0.9727670384615384], 
             UndirectedEdge[169, 219] -> 
             RGBColor[
              0.9294940384615384, 0.7985138461538464, 0.5927217692307692], 
             UndirectedEdge[197, 345] -> 
             RGBColor[
              0.7311442692307693, 0.7854163846153845, 0.8466207307692308], 
             UndirectedEdge[100, 213] -> 
             RGBColor[
              0.6964478076923077, 0.7615969230769231, 0.9712546923076923], 
             UndirectedEdge[73, 187] -> 
             RGBColor[
              0.7858253461538462, 0.8326119999999999, 0.9792873846153847], 
             UndirectedEdge[97, 346] -> 
             RGBColor[0.9019595, 0.9245658461538462, 0.9871758461538461], 
             UndirectedEdge[129, 170] -> 
             RGBColor[
              0.6528229615384615, 0.7261803076923077, 0.9678203846153846], 
             UndirectedEdge[36, 37] -> 
             RGBColor[
              0.7872713076923077, 0.8343171538461538, 0.9792787692307692], 
             UndirectedEdge[143, 302] -> 
             RGBColor[
              0.703844576923077, 0.7685680000000001, 0.9711163076923077], 
             UndirectedEdge[16, 236] -> 
             RGBColor[
              0.6177498461538462, 0.6961965769230769, 0.9654764615384616], 
             UndirectedEdge[187, 322] -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             UndirectedEdge[108, 163] -> 
             RGBColor[
              0.6277719230769231, 0.7030406153846154, 0.9669605384615385], 
             UndirectedEdge[137, 346] -> 
             RGBColor[0.8113893076923077, 0.853452, 0.9782441153846153], 
             UndirectedEdge[243, 276] -> 
             RGBColor[
              0.5960996923076924, 0.6817237692307693, 0.9622049230769231], 
             UndirectedEdge[131, 147] -> 
             RGBColor[
              0.6795264230769231, 0.747472923076923, 0.9703673846153846], 
             UndirectedEdge[9, 468] -> 
             RGBColor[
              0.4678596153846154, 0.5788685384615384, 0.9512507692307692], 
             UndirectedEdge[331, 377] -> 
             RGBColor[
              0.6807149230769232, 0.7491623846153845, 0.9697247692307692], 
             UndirectedEdge[280, 470] -> 
             RGBColor[
              0.7472692692307692, 0.8020243846153845, 0.9727670384615384], 
             UndirectedEdge[234, 468] -> 
             RGBColor[
              0.637090076923077, 0.7137457692307692, 0.9662904615384615], 
             UndirectedEdge[136, 488] -> 
             RGBColor[
              0.7400726538461538, 0.7970135384615384, 0.9746889999999999], 
             UndirectedEdge[57, 361] -> 
             RGBColor[
              0.7038445769230769, 0.7685679999999999, 0.9711163076923077], 
             UndirectedEdge[196, 414] -> 
             RGBColor[
              0.966929076923077, 0.9731556153846154, 0.8647026923076924], 
             UndirectedEdge[103, 319] -> 
             RGBColor[
              0.6908480384615384, 0.7552456153846154, 0.9585802692307692], 
             UndirectedEdge[224, 263] -> 
             RGBColor[
              0.9183033461538461, 0.7901678461538464, 0.6116646923076924], 
             UndirectedEdge[89, 184] -> 
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988], 
             UndirectedEdge[137, 407] -> 
             RGBColor[
              0.5572127692307692, 0.6501776153846154, 0.9588811538461539], 
             UndirectedEdge[53, 272] -> 
             RGBColor[
              0.878599923076923, 0.9037534615384615, 0.8808241923076923], 
             UndirectedEdge[236, 243] -> 
             RGBColor[
              0.6528229615384615, 0.7261803076923077, 0.9678203846153846], 
             UndirectedEdge[26, 351] -> 
             RGBColor[
              0.926501923076923, 0.9435581538461538, 0.969506423076923], 
             UndirectedEdge[67, 96] -> 
             RGBColor[
              0.585335576923077, 0.6693134615384615, 0.9628836153846154], 
             UndirectedEdge[284, 464] -> 
             RGBColor[
              0.8158347307692306, 0.8551913076923077, 0.8959024230769232], 
             UndirectedEdge[325, 401] -> 
             RGBColor[
              0.6615369615384616, 0.7348486923076925, 0.9673563846153845], 
             UndirectedEdge[227, 348] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[106, 117] -> 
             RGBColor[0.8778414999999999, 0.905431, 0.9882105], 
             UndirectedEdge[395, 440] -> 
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153], 
             UndirectedEdge[204, 361] -> 
             RGBColor[
              0.5815217692307693, 0.6677510384615384, 0.9619037692307693], 
             UndirectedEdge[195, 263] -> 
             RGBColor[
              0.9286629615384614, 0.9458584615384615, 0.9897228461538461], 
             UndirectedEdge[360, 393] -> 
             RGBColor[
              0.4143947692307692, 0.5333496538461537, 0.9476258461538463], 
             UndirectedEdge[74, 440] -> 
             RGBColor[
              0.7146905769230768, 0.7758275384615383, 0.9733580384615385], 
             UndirectedEdge[166, 348] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[209, 477] -> 
             RGBColor[0.7964894615384615, 0.841614, 0.9667298846153847], 
             UndirectedEdge[292, 422] -> 
             RGBColor[0.7964894615384615, 0.841614, 0.9667298846153847], 
             UndirectedEdge[36, 416] -> 
             RGBColor[0.44611730769230773`, 0.5447195, 0.9521403076923076], 
             UndirectedEdge[306, 418] -> 
             RGBColor[
              0.5758773076923076, 0.6126986538461539, 0.6412209230769231], 
             UndirectedEdge[363, 498] -> 
             RGBColor[
              0.5974169230769231, 0.6834210769230769, 0.9618793076923077], 
             UndirectedEdge[57, 466] -> 
             RGBColor[0.7667761153846153, 0.8183061538461538, 0.977236], 
             UndirectedEdge[263, 395] -> 
             RGBColor[0.8728748846153846, 0.901485, 0.9843724230769231], 
             UndirectedEdge[171, 238] -> 
             RGBColor[
              0.637090076923077, 0.7137457692307692, 0.9662904615384615], 
             UndirectedEdge[42, 286] -> 
             RGBColor[
              0.6820321538461539, 0.7508596923076922, 0.9693991538461538], 
             UndirectedEdge[246, 444] -> 
             RGBColor[
              0.6628541923076923, 0.7365459999999999, 0.9670307692307691], 
             UndirectedEdge[46, 306] -> 
             RGBColor[0.410643, 0.5129644999999999, 0.9492445], 
             UndirectedEdge[229, 411] -> 
             RGBColor[
              0.5987341538461537, 0.6851183846153845, 0.9615536923076923], 
             UndirectedEdge[239, 440] -> 
             RGBColor[
              0.5769217307692307, 0.6674100769230769, 0.9598365384615384], 
             UndirectedEdge[57, 106] -> 
             RGBColor[0.7534243846153845, 0.8076598461538461, 0.9759625], 
             UndirectedEdge[60, 280] -> 
             RGBColor[
              0.6685713076923077, 0.7366240384615383, 0.9669888076923077], 
             UndirectedEdge[438, 457] -> 
             RGBColor[
              0.8158347307692306, 0.8551913076923077, 0.8959024230769232], 
             UndirectedEdge[130, 368] -> 
             RGBColor[
              0.637090076923077, 0.7137457692307692, 0.9662904615384615], 
             UndirectedEdge[152, 287] -> 
             RGBColor[
              0.7449636923076923, 0.8005978461538461, 0.9755188461538462], 
             UndirectedEdge[54, 242] -> 
             RGBColor[
              0.6020169615384616, 0.6837620384615384, 0.9639465384615384], 
             UndirectedEdge[89, 235] -> 
             RGBColor[
              0.5200361923076923, 0.6197180384615384, 0.9557754615384615], 
             UndirectedEdge[60, 260] -> 
             RGBColor[
              0.6177498461538462, 0.6961965769230769, 0.9654764615384616], 
             UndirectedEdge[88, 243] -> 
             RGBColor[
              0.7311442692307693, 0.7854163846153845, 0.8466207307692308], 
             UndirectedEdge[36, 367] -> 
             RGBColor[
              0.5405313846153846, 0.6357290384615384, 0.9578182307692308], 
             UndirectedEdge[17, 282] -> 
             RGBColor[
              0.5974169230769231, 0.6834210769230769, 0.9618793076923077], 
             UndirectedEdge[150, 233] -> 
             RGBColor[
              0.7097995384615384, 0.7722432307692307, 0.9725281923076923], 
             UndirectedEdge[250, 365] -> 
             RGBColor[
              0.4143947692307692, 0.5333496538461537, 0.9476258461538463], 
             UndirectedEdge[107, 423] -> 
             RGBColor[0.7940223076923076, 0.837483, 0.8941852692307694], 
             UndirectedEdge[315, 347] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[288, 492] -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             UndirectedEdge[24, 267] -> 
             RGBColor[
              0.6177498461538462, 0.6961965769230769, 0.9654764615384616], 
             UndirectedEdge[198, 480] -> 
             RGBColor[
              0.7025273461538463, 0.7668706923076923, 0.9714419230769231], 
             UndirectedEdge[4, 479] -> 
             RGBColor[
              0.6807149230769232, 0.7491623846153845, 0.9697247692307692], 
             UndirectedEdge[133, 239] -> 
             RGBColor[
              0.7038445769230769, 0.7685679999999999, 0.9711163076923077], 
             UndirectedEdge[115, 253] -> 
             RGBColor[
              0.6602197307692308, 0.7331513846153845, 0.9676819999999999], 
             UndirectedEdge[199, 371] -> 
             RGBColor[
              0.7749818846153846, 0.8205521538461538, 0.8197187307692311], 
             UndirectedEdge[93, 189] -> 
             RGBColor[
              0.8430751923076923, 0.8778090000000001, 0.9613439615384616], 
             UndirectedEdge[357, 418] -> 
             RGBColor[
              0.9835203846153846, 0.955017076923077, 0.4802282692307692], 
             UndirectedEdge[82, 463] -> 
             RGBColor[
              0.8427379615384616, 0.7688563076923076, 0.6159251153846154], 
             UndirectedEdge[102, 350] -> 
             RGBColor[
              0.637090076923077, 0.7137457692307692, 0.9662904615384615], 
             UndirectedEdge[235, 296] -> 
             RGBColor[
              0.6444533076923077, 0.7174891923076923, 0.9680234615384615], 
             UndirectedEdge[26, 360] -> 
             RGBColor[
              0.6964433846153846, 0.7594186153846154, 0.9491088076923078], 
             UndirectedEdge[309, 320] -> 
             RGBColor[
              0.5332968846153847, 0.6319934615384615, 0.9564022307692308], 
             UndirectedEdge[13, 229] -> 
             RGBColor[
              0.7696506538461538, 0.8187163846153847, 0.9348811923076923], 
             UndirectedEdge[353, 420] -> 
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153], 
             UndirectedEdge[171, 465] -> 
             RGBColor[
              0.6528229615384615, 0.7261803076923077, 0.9678203846153846], 
             UndirectedEdge[104, 224] -> 
             RGBColor[
              0.7697682307692307, 0.6732618461538463, 0.6004513461538461], 
             UndirectedEdge[22, 285] -> 
             RGBColor[0.8778414999999999, 0.905431, 0.9882105], 
             UndirectedEdge[126, 285] -> 
             RGBColor[0.8778414999999999, 0.905431, 0.9882105], 
             UndirectedEdge[98, 319] -> 
             RGBColor[
              0.6611346923076923, 0.7319377692307691, 0.9690863846153847], 
             UndirectedEdge[286, 411] -> 
             RGBColor[
              0.6205465769230769, 0.7028266923076922, 0.9632708461538462], 
             UndirectedEdge[259, 491] -> 
             RGBColor[
              0.9003747307692309, 0.9202936153846154, 0.8616604230769231], 
             UndirectedEdge[1, 266] -> 
             RGBColor[
              0.47128030769230755`, 0.5810416923076922, 0.9516869230769232], 
             UndirectedEdge[67, 216] -> 
             RGBColor[
              0.765330153846154, 0.8166010000000001, 0.9772446153846154], 
             UndirectedEdge[41, 451] -> 
             RGBColor[
              0.6746353846153845, 0.7438886153846154, 0.9695375384615385], 
             UndirectedEdge[300, 456] -> 
             RGBColor[
              0.5551093076923076, 0.6497017692307692, 0.9581193846153846], 
             UndirectedEdge[117, 139] -> 
             RGBColor[
              0.9427031923076923, 0.9530540769230769, 0.8004998461538462], 
             UndirectedEdge[70, 96] -> 
             RGBColor[
              0.5648403846153847, 0.6533024615384615, 0.9608408461538461], 
             UndirectedEdge[92, 274] -> 
             RGBColor[0.8337706923076923, 0.870144, 0.9403582692307693], 
             UndirectedEdge[241, 436] -> 
             RGBColor[
              0.6937566538461537, 0.5721214615384616, 0.586476423076923], 
             UndirectedEdge[207, 295] -> 
             RGBColor[
              0.5769217307692307, 0.6674100769230769, 0.9598365384615384], 
             UndirectedEdge[83, 176] -> 
             RGBColor[
              0.8568251153846154, 0.8872133076923078, 0.8999879615384616], 
             UndirectedEdge[56, 495] -> 
             RGBColor[
              0.5648403846153847, 0.6533024615384615, 0.9608408461538461], 
             UndirectedEdge[219, 334] -> 
             RGBColor[
              0.7261433846153846, 0.6378452307692309, 0.5970170384615385], 
             UndirectedEdge[124, 357] -> 
             RGBColor[
              0.8797716538461539, 0.903315923076923, 0.7943801538461538], 
             UndirectedEdge[40, 291] -> 
             RGBColor[
              0.7739195769230769, 0.8236708461538462, 0.9780052692307692], 
             UndirectedEdge[7, 487] -> 
             RGBColor[
              0.7313570384615384, 0.7851355384615384, 0.8162844230769233], 
             UndirectedEdge[423, 477] -> 
             RGBColor[
              0.8158347307692306, 0.8551913076923077, 0.8959024230769232], 
             UndirectedEdge[22, 165] -> 
             RGBColor[
              0.8942031153846154, 0.9180925384615385, 0.9764308846153846], 
             UndirectedEdge[302, 368] -> 
             RGBColor[
              0.5756045000000001, 0.6657127692307692, 0.9601621538461538], 
             UndirectedEdge[297, 419] -> 
             RGBColor[
              0.5033548076923077, 0.6052694615384615, 0.9547125384615385], 
             UndirectedEdge[263, 463] -> 
             RGBColor[0.9297875, 0.8377293076923076, 0.6210101538461539], 
             UndirectedEdge[260, 424] -> 
             RGBColor[
              0.7605678461538462, 0.8130245384615384, 0.9767317692307692], 
             UndirectedEdge[193, 415] -> 
             RGBColor[
              0.6628541923076923, 0.7365459999999999, 0.9670307692307691], 
             UndirectedEdge[434, 474] -> 
             RGBColor[
              0.6962839230769231, 0.7551518076923076, 0.8139405000000003], 
             UndirectedEdge[102, 109] -> 
             RGBColor[
              0.7148351153846153, 0.7749537692307692, 0.9503898076923076], 
             UndirectedEdge[58, 118] -> 
             RGBColor[
              0.8996255384615386, 0.9179552307692308, 0.7266205384615386], 
             UndirectedEdge[39, 100] -> 
             RGBColor[
              0.6964478076923077, 0.7615969230769231, 0.9712546923076923], 
             UndirectedEdge[35, 216] -> 
             RGBColor[
              0.8374798461538462, 0.8736360000000001, 0.970815423076923], 
             UndirectedEdge[72, 163] -> 
             RGBColor[
              0.3977133846153846, 0.5189010769230769, 0.946562923076923], 
             UndirectedEdge[202, 414] -> 
             RGBColor[
              0.7965815384615385, 0.8385413076923077, 0.8517721923076924], 
             UndirectedEdge[324, 441] -> 
             RGBColor[
              0.9161076153846155, 0.9327281538461538, 0.8631903461538462], 
             UndirectedEdge[18, 52] -> 
             RGBColor[0.9109891538461539, 0.9306115384615385, 0.9480165], 
             UndirectedEdge[168, 368] -> 
             RGBColor[
              0.5114844615384615, 0.6142851538461538, 0.9546850769230769], 
             UndirectedEdge[208, 397] -> 
             RGBColor[
              0.9529172692307692, 0.8934097692307693, 0.6116736923076923], 
             UndirectedEdge[193, 350] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[2, 365] -> 
             RGBColor[
              0.43278649999999996`, 0.5488848076923076, 0.9489068461538461], 
             UndirectedEdge[42, 248] -> 
             RGBColor[
              0.5815217692307693, 0.6677510384615384, 0.9619037692307693], 
             UndirectedEdge[46, 68] -> 
             RGBColor[
              0.7801278461538461, 0.8289524615384615, 0.9785094999999999], 
             UndirectedEdge[260, 470] -> 
             RGBColor[
              0.6964478076923077, 0.7615969230769231, 0.9712546923076923], 
             UndirectedEdge[32, 344] -> 
             RGBColor[
              0.9563755769230768, 0.9643862307692308, 0.8366745384615387], 
             UndirectedEdge[60, 483] -> 
             RGBColor[
              0.6177498461538462, 0.6961965769230769, 0.9654764615384616], 
             UndirectedEdge[337, 498] -> 
             RGBColor[
              0.5114844615384614, 0.6142851538461537, 0.9546850769230769], 
             UndirectedEdge[86, 168] -> 
             RGBColor[
              0.6807149230769232, 0.7491623846153845, 0.9697247692307692], 
             UndirectedEdge[151, 424] -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 
             UndirectedEdge[234, 296] -> 
             RGBColor[
              0.8487568846153847, 0.8823501538461538, 0.9854070769230769], 
             UndirectedEdge[223, 268] -> 
             RGBColor[
              0.8760406923076923, 0.9026951538461538, 0.9232372692307693], 
             UndirectedEdge[50, 204] -> 
             RGBColor[
              0.4143947692307692, 0.5333496538461537, 0.9476258461538463], 
             UndirectedEdge[26, 247] -> 
             RGBColor[
              0.9131501923076923, 0.9329118461538461, 0.9682329230769231], 
             UndirectedEdge[64, 435] -> 
             RGBColor[
              0.5551093076923077, 0.6497017692307692, 0.9581193846153846], 
             UndirectedEdge[143, 214] -> 
             RGBColor[
              0.7810630384615386, 0.8290355384615385, 0.9787745384615385], 
             UndirectedEdge[38, 266] -> 
             RGBColor[
              0.5572127692307692, 0.6501776153846154, 0.9588811538461539], 
             UndirectedEdge[309, 375] -> 
             RGBColor[
              0.7313570384615384, 0.7851355384615384, 0.8162844230769233], 
             UndirectedEdge[70, 385] -> 
             RGBColor[
              0.6820321538461539, 0.7508596923076922, 0.9693991538461538], 
             UndirectedEdge[232, 354] -> 
             RGBColor[
              0.8690788846153846, 0.8683021538461538, 0.6630927307692308], 
             UndirectedEdge[86, 484] -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 
             UndirectedEdge[106, 360] -> 
             RGBColor[
              0.6477829615384615, 0.7212914615384616, 0.9678128846153846], 
             UndirectedEdge[163, 322] -> 
             RGBColor[
              0.5648403846153847, 0.6533024615384615, 0.9608408461538461], 
             UndirectedEdge[44, 117] -> 
             RGBColor[
              0.7231512692307691, 0.7828895384615384, 0.9738016923076923], 
             UndirectedEdge[113, 273] -> 
             RGBColor[
              0.8784702307692308, 0.9056580000000001, 0.9749009615384616], 
             UndirectedEdge[53, 298] -> 
             RGBColor[
              0.7516770769230768, 0.8025955384615384, 0.8695444230769231], 
             UndirectedEdge[50, 369] -> 
             RGBColor[
              0.674486423076923, 0.7425840769230769, 0.9703598846153847], 
             UndirectedEdge[135, 385] -> 
             RGBColor[
              0.7583154230769231, 0.8112441538461539, 0.9767923461538461], 
             UndirectedEdge[376, 464] -> 
             RGBColor[
              0.9914411538461538, 0.9892533846153846, 0.6842650769230771], 
             UndirectedEdge[95, 408] -> 
             RGBColor[
              0.637090076923077, 0.7137457692307692, 0.9662904615384615], 
             UndirectedEdge[34, 332] -> 
             RGBColor[
              0.9293514615384615, 0.9424077692307693, 0.799226346153846], 
             UndirectedEdge[251, 416] -> 
             RGBColor[
              0.42562211538461536`, 0.5287084999999999, 0.9500975384615384], 
             UndirectedEdge[62, 209] -> 
             RGBColor[
              0.7528646153846152, 0.8061973846153846, 0.9632955769230769], 
             UndirectedEdge[109, 496] -> 
             RGBColor[
              0.6964433846153846, 0.7594186153846154, 0.9491088076923078], 
             UndirectedEdge[179, 254] -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 
             UndirectedEdge[27, 199] -> 
             RGBColor[
              0.6192293461538461, 0.7011293846153845, 0.9635964615384616], 
             UndirectedEdge[59, 453] -> 
             RGBColor[
              0.9153112307692307, 0.9352121538461537, 0.9884493461538462], 
             UndirectedEdge[450, 475] -> 
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988], 
             UndirectedEdge[311, 331] -> 
             RGBColor[
              0.6397245384615384, 0.7171403846153847, 0.9656392307692307], 
             UndirectedEdge[329, 486] -> 
             RGBColor[
              0.8999461923076923, 0.918641076923077, 0.7615217307692308], 
             UndirectedEdge[287, 456] -> 
             RGBColor[
              0.7231512692307691, 0.7828895384615384, 0.9738016923076923], 
             UndirectedEdge[60, 118] -> 
             RGBColor[
              0.6953219615384616, 0.7530942692307692, 0.7092369230769232], 
             UndirectedEdge[267, 493] -> 
             RGBColor[
              0.685357346153846, 0.7491430384615384, 0.9385744230769231], 
             UndirectedEdge[239, 263] -> 
             RGBColor[
              0.7908941153846153, 0.8374409999999999, 0.9762013461538461], 
             UndirectedEdge[64, 91] -> 
             RGBColor[
              0.7313570384615384, 0.7851355384615384, 0.8162844230769233], 
             UndirectedEdge[469, 471] -> 
             RGBColor[
              0.8211182307692309, 0.8609744615384616, 0.9825950384615385], 
             UndirectedEdge[275, 282] -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 
             UndirectedEdge[132, 423] -> 
             RGBColor[
              0.9269001153846154, 0.9423161538461539, 0.9068769230769231], 
             UndirectedEdge[116, 412] -> 
             RGBColor[0.8511380384615386, 0.8841383846153846, 0.9856635], 
             UndirectedEdge[89, 453] -> 
             RGBColor[
              0.7908941153846153, 0.8374409999999999, 0.9762013461538461], 
             UndirectedEdge[136, 311] -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 
             UndirectedEdge[6, 24] -> 
             RGBColor[
              0.8015582307692308, 0.8450465384615384, 0.9808173076923077], 
             UndirectedEdge[51, 477] -> 
             RGBColor[
              0.8186067307692307, 0.8559687692307691, 0.8231530384615386], 
             UndirectedEdge[114, 381] -> 
             RGBColor[
              0.6192293461538461, 0.7011293846153845, 0.9635964615384616], 
             UndirectedEdge[95, 294] -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 
             UndirectedEdge[89, 192] -> 
             RGBColor[
              0.6205465769230769, 0.7028266923076922, 0.9632708461538462], 
             UndirectedEdge[108, 374] -> 
             RGBColor[
              0.9389722307692308, 0.9524333076923077, 0.9293569615384616], 
             UndirectedEdge[208, 472] -> 
             RGBColor[
              0.8136866538461539, 0.7841687692307693, 0.6214460384615385], 
             UndirectedEdge[34, 360] -> 
             RGBColor[
              0.6477829615384615, 0.7212914615384616, 0.9678128846153846], 
             UndirectedEdge[395, 453] -> 
             RGBColor[0.8728748846153846, 0.901485, 0.9843724230769231], 
             UndirectedEdge[101, 361] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[11, 211] -> 
             RGBColor[
              0.7217846538461539, 0.6913656153846155, 0.609448576923077], 
             UndirectedEdge[70, 433] -> 
             RGBColor[
              0.8800923076923077, 0.9040017692307691, 0.8292813461538464], 
             UndirectedEdge[108, 206] -> 
             RGBColor[
              0.6795264230769231, 0.747472923076923, 0.9703673846153846], 
             UndirectedEdge[251, 499] -> 
             RGBColor[0.7667761153846153, 0.8183061538461538, 0.977236], 
             UndirectedEdge[116, 399] -> 
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937], 
             UndirectedEdge[350, 479] -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 
             UndirectedEdge[347, 421] -> 
             RGBColor[0.46109642307692306`, 0.5604635, 0.9529933461538461], 
             UndirectedEdge[153, 447] -> 
             RGBColor[0.8409043846153846, 0.5144558461538462, 0.5755775], 
             UndirectedEdge[195, 453] -> 
             RGBColor[
              0.9286629615384614, 0.9458584615384615, 0.9897228461538461], 
             UndirectedEdge[338, 425] -> 
             RGBColor[
              0.7858253461538462, 0.8326119999999999, 0.9792873846153847], 
             UndirectedEdge[164, 348] -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             UndirectedEdge[31, 258] -> 
             RGBColor[
              0.5551093076923077, 0.6497017692307692, 0.9581193846153846], 
             UndirectedEdge[31, 203] -> 
             RGBColor[
              0.6628541923076923, 0.7365459999999999, 0.9670307692307691], 
             UndirectedEdge[398, 445] -> 
             RGBColor[
              0.4051221923076922, 0.5228155769230768, 0.9475051923076923], 
             UndirectedEdge[44, 369] -> 
             RGBColor[
              0.7365029999999999, 0.7935358461538461, 0.9750751923076924], 
             UndirectedEdge[267, 278] -> 
             RGBColor[
              0.4143947692307692, 0.5333496538461537, 0.9476258461538463], 
             UndirectedEdge[130, 477] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[4, 482] -> 
             RGBColor[
              0.6807149230769232, 0.7491623846153845, 0.9697247692307692], 
             UndirectedEdge[219, 274] -> 
             RGBColor[
              0.7902634230769231, 0.6892728461538464, 0.6024941153846154], 
             UndirectedEdge[44, 269] -> 
             RGBColor[
              0.7472692692307692, 0.8020243846153845, 0.9727670384615384], 
             UndirectedEdge[130, 143] -> 
             RGBColor[
              0.765330153846154, 0.8166010000000001, 0.9772446153846154], 
             UndirectedEdge[315, 401] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[75, 163] -> 
             RGBColor[
              0.6793897692307692, 0.7409840769230769, 0.8432138846153847], 
             UndirectedEdge[9, 139] -> 
             RGBColor[
              0.7310363846153847, 0.7844496923076922, 0.7813832307692308], 
             UndirectedEdge[134, 438] -> 
             RGBColor[
              0.6601491538461537, 0.7254771923076924, 0.8845640384615385], 
             UndirectedEdge[76, 431] -> 
             RGBColor[
              0.8006230384615385, 0.8449634615384616, 0.9805522692307692], 
             UndirectedEdge[90, 124] -> 
             RGBColor[0.548159, 0.6388538846153845, 0.959777923076923], 
             UndirectedEdge[37, 188] -> 
             RGBColor[
              0.6611346923076923, 0.7319377692307691, 0.9690863846153847], 
             UndirectedEdge[26, 106] -> 
             RGBColor[
              0.9131501923076923, 0.9329118461538461, 0.9682329230769231], 
             UndirectedEdge[107, 446] -> 
             RGBColor[
              0.7967943076923077, 0.8382604615384616, 0.8214358846153849], 
             UndirectedEdge[19, 234] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[39, 243] -> 
             RGBColor[
              0.5114844615384615, 0.6142851538461538, 0.9546850769230769], 
             UndirectedEdge[129, 265] -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 
             UndirectedEdge[396, 446] -> 
             RGBColor[
              0.9163203846153847, 0.9324473076923077, 0.8328540384615387], 
             UndirectedEdge[325, 368] -> 
             RGBColor[
              0.5332968846153847, 0.6319934615384615, 0.9564022307692308], 
             UndirectedEdge[52, 56] -> 
             RGBColor[0.8747610769230769, 0.902166, 0.9444438076923076], 
             UndirectedEdge[402, 431] -> 
             RGBColor[
              0.8621086153846154, 0.8929964615384616, 0.9866805769230769], 
             UndirectedEdge[165, 353] -> 
             RGBColor[
              0.7310521923076923, 0.7884890769230768, 0.9615784230769231], 
             UndirectedEdge[237, 329] -> 
             RGBColor[
              0.6807149230769232, 0.7491623846153845, 0.9697247692307692], 
             UndirectedEdge[63, 75] -> 
             RGBColor[
              0.6960711538461539, 0.7554326538461538, 0.8442768076923077], 
             UndirectedEdge[392, 492] -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             UndirectedEdge[125, 177] -> 
             RGBColor[0.3810319999999999, 0.5044525, 0.9455], 
             UndirectedEdge[210, 348] -> 
             RGBColor[
              0.6384073076923076, 0.7154430769230768, 0.9659648461538461], 
             UndirectedEdge[469, 491] -> 
             RGBColor[
              0.9561628076923077, 0.964667076923077, 0.8670108461538462], 
             UndirectedEdge[35, 171] -> 
             RGBColor[
              0.7092397692307693, 0.7707807692307692, 0.9598612692307693], 
             UndirectedEdge[8, 40] -> 
             RGBColor[
              0.6477829615384615, 0.7212914615384616, 0.9678128846153846], 
             UndirectedEdge[405, 491] -> 
             RGBColor[
              0.8183939615384614, 0.8562496153846153, 0.8534893461538462], 
             UndirectedEdge[98, 136] -> 
             RGBColor[0.7667761153846153, 0.8183061538461538, 0.977236], 
             UndirectedEdge[14, 75] -> 
             RGBColor[
              0.8593843461538462, 0.8882716153846155, 0.8575748846153847], 
             UndirectedEdge[121, 500] -> 
             RGBColor[
              0.7273054230769231, 0.7838289230769231, 0.9102403461538462], 
             UndirectedEdge[1, 265] -> 
             RGBColor[
              0.6746353846153845, 0.7438886153846154, 0.9695375384615385], 
             UndirectedEdge[227, 495] -> 
             RGBColor[
              0.5443451923076924, 0.6372914615384616, 0.9587980769230768], 
             UndirectedEdge[127, 368] -> 
             RGBColor[
              0.7203436153846154, 0.7494359230769231, 0.6500958076923078], 
             UndirectedEdge[207, 389] -> 
             RGBColor[
              0.8145551153846153, 0.8546621538461538, 0.9171089615384616], 
             UndirectedEdge[249, 260] -> 
             RGBColor[0.6010684615384616, 0.681748, 0.9644135384615384], 
             UndirectedEdge[42, 95] -> 
             RGBColor[
              0.7858253461538462, 0.8326119999999999, 0.9792873846153847], 
             UndirectedEdge[190, 323] -> 
             RGBColor[0.8206795, 0.6732793846153846, 0.5977561923076924], 
             UndirectedEdge[109, 295] -> 
             RGBColor[
              0.7366475384615383, 0.7926620769230768, 0.9521069615384615], 
             UndirectedEdge[382, 499] -> 
             RGBColor[0.8077665, 0.8503281538461539, 0.9813215384615385], 
             UndirectedEdge[213, 254] -> 
             RGBColor[
              0.6192293461538461, 0.7011293846153845, 0.9635964615384616], 
             UndirectedEdge[47, 374] -> 
             RGBColor[
              0.9122687692307693, 0.9311406923076924, 0.9268099615384616], 
             UndirectedEdge[244, 390] -> 
             RGBColor[0.8952562692307693, 0.918177, 0.9464865769230769], 
             UndirectedEdge[92, 370] -> 
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461], 
             UndirectedEdge[295, 458] -> 
             RGBColor[
              0.5769217307692307, 0.6674100769230769, 0.9598365384615384], 
             UndirectedEdge[278, 493] -> 
             RGBColor[
              0.7020387307692306, 0.7635916153846154, 0.9396373461538462], 
             UndirectedEdge[6, 156] -> 
             RGBColor[
              0.841613423076923, 0.8769854615384615, 0.9846378076923077], 
             UndirectedEdge[79, 413] -> 
             RGBColor[
              0.7182602307692308, 0.7793052307692308, 0.9729718461538461], 
             UndirectedEdge[122, 476] -> 
             RGBColor[
              0.6661746923076923, 0.7368266153846154, 0.9690938846153846], 
             UndirectedEdge[123, 455] -> 
             RGBColor[
              0.5114844615384614, 0.6142851538461537, 0.9546850769230769], 
             UndirectedEdge[113, 302] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[402, 462] -> 
             RGBColor[
              0.7025273461538463, 0.7668706923076923, 0.9714419230769231], 
             UndirectedEdge[140, 363] -> 
             RGBColor[0.8113893076923077, 0.853452, 0.9782441153846153], 
             UndirectedEdge[440, 453] -> 
             RGBColor[
              0.725456846153846, 0.7843160769230768, 0.9710498846153846], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.6661746923076923, 0.7368266153846154, 0.9690938846153846], 
             UndirectedEdge[102, 202] -> 
             RGBColor[
              0.5332968846153847, 0.6319934615384615, 0.9564022307692308], 
             UndirectedEdge[363, 379] -> 
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923], 
             UndirectedEdge[162, 297] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[19, 393] -> 
             RGBColor[
              0.6177498461538462, 0.6961965769230769, 0.9654764615384616], 
             UndirectedEdge[96, 238] -> 
             RGBColor[
              0.585335576923077, 0.6693134615384615, 0.9628836153846154], 
             UndirectedEdge[117, 247] -> 
             RGBColor[0.8778414999999999, 0.905431, 0.9882105], 
             UndirectedEdge[162, 223] -> 
             RGBColor[
              0.8965358846153847, 0.9187061538461538, 0.9252800384615385], 
             UndirectedEdge[355, 362] -> 
             RGBColor[
              0.6628541923076923, 0.7365459999999999, 0.9670307692307691], 
             UndirectedEdge[59, 395] -> 
             RGBColor[
              0.8487568846153847, 0.8823501538461538, 0.9854070769230769], 
             UndirectedEdge[161, 403] -> 
             RGBColor[
              0.7400726538461538, 0.7970135384615384, 0.9746889999999999], 
             UndirectedEdge[214, 477] -> 
             RGBColor[
              0.7400726538461538, 0.7970135384615384, 0.9746889999999999], 
             UndirectedEdge[65, 309] -> 
             RGBColor[
              0.6165948846153846, 0.6977347692307692, 0.9642476923076924], 
             UndirectedEdge[361, 498] -> 
             RGBColor[
              0.6384073076923076, 0.7154430769230768, 0.9659648461538461], 
             UndirectedEdge[54, 70] -> 
             RGBColor[
              0.5815217692307693, 0.6677510384615384, 0.9619037692307693], 
             UndirectedEdge[369, 390] -> 
             RGBColor[0.951044346153846, 0.9625504615384615, 0.951837], 
             UndirectedEdge[56, 88] -> 
             RGBColor[
              0.8798795384615385, 0.9042826153846153, 0.859617653846154], 
             UndirectedEdge[289, 419] -> 
             RGBColor[
              0.6630806153846154, 0.7305214615384615, 0.9469829615384615], 
             UndirectedEdge[124, 178] -> 
             RGBColor[
              0.8760406923076923, 0.9026951538461538, 0.9232372692307693], 
             UndirectedEdge[67, 465] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[7, 461] -> 
             RGBColor[
              0.4896720384615384, 0.5965768461538461, 0.952967923076923], 
             UndirectedEdge[273, 423] -> 
             RGBColor[
              0.9699651923076922, 0.9762703076923077, 0.8976443076923079], 
             UndirectedEdge[63, 467] -> 
             RGBColor[
              0.6020169615384616, 0.6837620384615384, 0.9639465384615384], 
             UndirectedEdge[179, 368] -> 
             RGBColor[
              0.5756045000000001, 0.6657127692307692, 0.9601621538461538], 
             UndirectedEdge[211, 485] -> 
             RGBColor[
              0.7654095000000001, 0.726782230769231, 0.6128828846153846], 
             UndirectedEdge[21, 320] -> 
             RGBColor[
              0.7182602307692308, 0.7793052307692308, 0.9729718461538461], 
             UndirectedEdge[318, 479] -> 
             RGBColor[
              0.8411746923076924, 0.6892903846153846, 0.5997989615384616], 
             UndirectedEdge[343, 465] -> 
             RGBColor[
              0.9163203846153847, 0.9324473076923077, 0.8328540384615387], 
             UndirectedEdge[229, 313] -> 
             RGBColor[
              0.7734894999999999, 0.8203038461538461, 0.8712615769230769], 
             UndirectedEdge[168, 401] -> 
             RGBColor[
              0.6397245384615384, 0.7171403846153847, 0.9656392307692307], 
             UndirectedEdge[70, 216] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[5, 193] -> 
             RGBColor[
              0.7605678461538462, 0.8130245384615384, 0.9767317692307692], 
             UndirectedEdge[213, 471] -> 
             RGBColor[
              0.6397245384615384, 0.7171403846153847, 0.9656392307692307], 
             UndirectedEdge[145, 404] -> 
             RGBColor[0.8542658846153847, 0.886155, 0.9424010384615384], 
             UndirectedEdge[28, 173] -> 
             RGBColor[
              0.9024418846153845, 0.7181446538461539, 0.5984295000000001], 
             UndirectedEdge[210, 243] -> 
             RGBColor[
              0.4896720384615384, 0.5965768461538461, 0.952967923076923], 
             UndirectedEdge[133, 424] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[201, 400] -> 
             RGBColor[
              0.6602197307692308, 0.7331513846153845, 0.9676819999999999], 
             UndirectedEdge[120, 125] -> 
             RGBColor[0.548159, 0.6388538846153845, 0.959777923076923], 
             UndirectedEdge[96, 343] -> 
             RGBColor[
              0.6796025384615385, 0.7407032307692307, 0.8128775769230772], 
             UndirectedEdge[22, 149] -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 
             UndirectedEdge[140, 369] -> 
             RGBColor[
              0.9286629615384614, 0.9458584615384615, 0.9897228461538461], 
             UndirectedEdge[169, 370] -> 
             RGBColor[0.950619923076923, 0.962693, 0.9684717692307692], 
             UndirectedEdge[154, 380] -> 
             RGBColor[
              0.7158151153846153, 0.6676983846153846, 0.6046453461538461], 
             UndirectedEdge[33, 489] -> 
             RGBColor[
              0.5960996923076924, 0.6817237692307693, 0.9622049230769231], 
             UndirectedEdge[271, 284] -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 
             UndirectedEdge[112, 356] -> 
             RGBColor[
              0.6477829615384615, 0.7212914615384616, 0.9678128846153846], 
             UndirectedEdge[133, 155] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[82, 447] -> 
             RGBColor[
              0.791324576923077, 0.47536399999999995`, 0.5707313076923077], 
             UndirectedEdge[225, 260] -> 
             RGBColor[
              0.8886077692307692, 0.9139195384615384, 0.9859023461538461], 
             UndirectedEdge[133, 225] -> 
             RGBColor[
              0.8523796923076923, 0.8854739999999999, 0.9823296538461539], 
             UndirectedEdge[442, 444] -> 
             RGBColor[
              0.7801278461538461, 0.8289524615384615, 0.9785094999999999], 
             UndirectedEdge[49, 431] -> 
             RGBColor[
              0.902249923076923, 0.7576715769230769, 0.6095611153846154], 
             UndirectedEdge[220, 427] -> 
             RGBColor[
              0.9768401538461537, 0.9809724615384615, 0.8669663076923078], 
             UndirectedEdge[151, 192] -> 
             RGBColor[
              0.6410417692307693, 0.7188376923076923, 0.9653136153846154], 
             UndirectedEdge[167, 326] -> 
             RGBColor[
              0.9536035769230768, 0.9636087692307692, 0.9094239230769232], 
             UndirectedEdge[109, 196] -> 
             RGBColor[0.950619923076923, 0.962693, 0.9684717692307692], 
             UndirectedEdge[212, 451] -> 
             RGBColor[
              0.8015582307692308, 0.8450465384615384, 0.9808173076923077], 
             UndirectedEdge[186, 414] -> 
             RGBColor[
              0.9513178076923077, 0.8328706923076924, 0.49349492307692316`], 
             UndirectedEdge[349, 419] -> 
             RGBColor[
              0.585335576923077, 0.6693134615384615, 0.9628836153846154], 
             UndirectedEdge[162, 221] -> 
             RGBColor[
              0.8260418461538462, 0.6006921153846154, 0.5863931538461539], 
             UndirectedEdge[163, 364] -> 
             RGBColor[
              0.6601568076923077, 0.6765594615384615, 0.6139310384615384], 
             UndirectedEdge[191, 300] -> 
             RGBColor[
              0.49309273076923066`, 0.5987499999999999, 0.9534040769230769], 
             UndirectedEdge[438, 460] -> 
             RGBColor[
              0.7101933076923076, 0.768822923076923, 0.8877528076923078], 
             UndirectedEdge[172, 473] -> 
             RGBColor[
              0.6410417692307693, 0.7188376923076923, 0.9653136153846154], 
             UndirectedEdge[141, 188] -> 
             RGBColor[
              0.6477829615384615, 0.7212914615384616, 0.9678128846153846], 
             UndirectedEdge[79, 122] -> 
             RGBColor[0.8511380384615386, 0.8841383846153846, 0.9856635], 
             UndirectedEdge[326, 475] -> 
             RGBColor[
              0.7801278461538461, 0.8289524615384615, 0.9785094999999999], 
             UndirectedEdge[98, 124] -> 
             RGBColor[
              0.8282616923076923, 0.8663391538461538, 0.9833643076923078], 
             UndirectedEdge[204, 498] -> 
             RGBColor[0.45459892307692296`, 0.5665931153846153, 0.950624], 
             UndirectedEdge[72, 144] -> 
             RGBColor[
              0.49309273076923066`, 0.5987499999999999, 0.9534040769230769], 
             UndirectedEdge[98, 331] -> 
             RGBColor[
              0.7231512692307691, 0.7828895384615384, 0.9738016923076923], 
             UndirectedEdge[311, 377] -> 
             RGBColor[
              0.765330153846154, 0.8166010000000001, 0.9772446153846154], 
             UndirectedEdge[299, 389] -> 
             RGBColor[
              0.9122687692307693, 0.9311406923076924, 0.9268099615384616], 
             UndirectedEdge[131, 238] -> 
             RGBColor[
              0.8487568846153847, 0.8823501538461538, 0.9854070769230769], 
             UndirectedEdge[4, 185] -> 
             RGBColor[
              0.49309273076923066`, 0.5987499999999999, 0.9534040769230769], 
             UndirectedEdge[162, 258] -> 
             RGBColor[
              0.637090076923077, 0.7137457692307692, 0.9662904615384615], 
             UndirectedEdge[124, 253] -> 
             RGBColor[
              0.6602197307692308, 0.7331513846153845, 0.9676819999999999], 
             UndirectedEdge[319, 449] -> 
             RGBColor[
              0.6875500384615385, 0.6817893846153846, 0.6112536538461539], 
             UndirectedEdge[256, 271] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[379, 478] -> 
             RGBColor[0.9730013076923076, 0.979385, 0.9305859230769231], 
             UndirectedEdge[349, 371] -> 
             RGBColor[
              0.9005875000000001, 0.9200127692307692, 0.8313241153846156], 
             UndirectedEdge[130, 325] -> 
             RGBColor[
              0.7025273461538463, 0.7668706923076923, 0.9714419230769231], 
             UndirectedEdge[269, 369] -> 
             RGBColor[
              0.9286629615384614, 0.9458584615384615, 0.9897228461538461], 
             UndirectedEdge[43, 355] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[11, 414] -> 
             RGBColor[
              0.7529566923076922, 0.8031246923076922, 0.8483378846153846], 
             UndirectedEdge[117, 255] -> 
             RGBColor[0.9045449615384615, 0.9267236153846153, 0.9907575], 
             UndirectedEdge[401, 475] -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 
             UndirectedEdge[58, 141] -> 
             RGBColor[
              0.835405153846154, 0.8717038461538462, 0.9841335769230769], 
             UndirectedEdge[96, 180] -> 
             RGBColor[0.52385, 0.6212804615384615, 0.9567553076923077], 
             UndirectedEdge[119, 375] -> 
             RGBColor[
              0.9005875000000001, 0.9200127692307692, 0.8313241153846156], 
             UndirectedEdge[220, 382] -> 
             RGBColor[
              0.8430751923076923, 0.8778090000000001, 0.9613439615384616], 
             UndirectedEdge[104, 356] -> 
             RGBColor[0.7534243846153845, 0.8076598461538461, 0.9759625], 
             UndirectedEdge[225, 440] -> 
             RGBColor[
              0.725456846153846, 0.7843160769230768, 0.9710498846153846], 
             UndirectedEdge[259, 341] -> 
             RGBColor[
              0.835405153846154, 0.8717038461538462, 0.9841335769230769], 
             UndirectedEdge[290, 362] -> 
             RGBColor[
              0.5974169230769231, 0.6834210769230769, 0.9618793076923077], 
             UndirectedEdge[79, 267] -> 
             RGBColor[
              0.6177498461538462, 0.6961965769230769, 0.9654764615384616], 
             UndirectedEdge[90, 317] -> 
             RGBColor[
              0.584387076923077, 0.667299423076923, 0.9633506153846154], 
             UndirectedEdge[41, 389] -> 
             RGBColor[
              0.7491178461538461, 0.8015372307692307, 0.9119575000000001], 
             UndirectedEdge[5, 300] -> 
             RGBColor[
              0.6964478076923077, 0.7615969230769231, 0.9712546923076923], 
             UndirectedEdge[290, 340] -> 
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153], 
             UndirectedEdge[288, 392] -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             UndirectedEdge[45, 292] -> 
             RGBColor[
              0.7746770384615385, 0.8239056923076924, 0.9650127307692308], 
             UndirectedEdge[42, 145] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[100, 368] -> 
             RGBColor[
              0.6528229615384615, 0.7261803076923077, 0.9678203846153846], 
             UndirectedEdge[302, 315] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[255, 338] -> 
             RGBColor[
              0.841613423076923, 0.8769854615384615, 0.9846378076923077], 
             UndirectedEdge[59, 263] -> 
             RGBColor[
              0.9153112307692307, 0.9352121538461537, 0.9884493461538462], 
             UndirectedEdge[413, 486] -> 
             RGBColor[
              0.7961530000000001, 0.8368887692307693, 0.7516335000000001], 
             UndirectedEdge[140, 247] -> 
             RGBColor[0.9019595, 0.9245658461538462, 0.9871758461538461], 
             UndirectedEdge[82, 453] -> 
             RGBColor[
              0.8523796923076923, 0.8854739999999999, 0.9823296538461539], 
             UndirectedEdge[199, 349] -> 
             RGBColor[
              0.6807149230769232, 0.7491623846153845, 0.9697247692307692], 
             UndirectedEdge[265, 462] -> 
             RGBColor[
              0.7182602307692308, 0.7793052307692308, 0.9729718461538461], 
             UndirectedEdge[113, 386] -> 
             RGBColor[
              0.637090076923077, 0.7137457692307692, 0.9662904615384615], 
             UndirectedEdge[140, 219] -> 
             RGBColor[
              0.9183033461538461, 0.7901678461538464, 0.6116646923076923], 
             UndirectedEdge[13, 313] -> 
             RGBColor[
              0.9880308461538461, 0.9893184615384616, 0.8480233846153846], 
             UndirectedEdge[74, 463] -> 
             RGBColor[
              0.9190212307692307, 0.8292407692307692, 0.6233183076923077], 
             UndirectedEdge[146, 415] -> 
             RGBColor[
              0.7038445769230769, 0.7685679999999999, 0.9711163076923077], 
             UndirectedEdge[213, 475] -> 
             RGBColor[
              0.5987341538461537, 0.6851183846153845, 0.9615536923076923], 
             UndirectedEdge[49, 328] -> 
             RGBColor[
              0.7644810769230769, 0.6492541153846153, 0.5960396153846154], 
             UndirectedEdge[259, 450] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[454, 500] -> 
             RGBColor[
              0.9755732692307693, 0.9401742307692309, 0.5927064230769232], 
             UndirectedEdge[469, 495] -> 
             RGBColor[
              0.6411236538461538, 0.713686923076923, 0.9682340384615384], 
             UndirectedEdge[158, 182] -> 
             RGBColor[
              0.9075548461538461, 0.9287388461538462, 0.9777043846153846], 
             UndirectedEdge[302, 347] -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 
             UndirectedEdge[87, 107] -> 
             RGBColor[
              0.7182602307692308, 0.7793052307692308, 0.9729718461538461], 
             UndirectedEdge[80, 307] -> 
             RGBColor[
              0.7400726538461538, 0.7970135384615384, 0.9746889999999999], 
             UndirectedEdge[159, 443] -> 
             RGBColor[
              0.7639684615384614, 0.7848525384615385, 0.6535301153846154], 
             UndirectedEdge[396, 443] -> 
             RGBColor[
              0.9053069615384616, 0.8967476923076924, 0.6666654230769231], 
             UndirectedEdge[15, 452] -> 
             RGBColor[
              0.6273614615384615, 0.6472304999999999, 0.6118751538461538], 
             UndirectedEdge[55, 250] -> 
             RGBColor[
              0.6344312307692308, 0.7106451538461538, 0.9665393846153847], 
             UndirectedEdge[105, 447] -> 
             RGBColor[0.8118197692307694, 0.491375, 0.5727740769230769], 
             UndirectedEdge[55, 242] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[133, 440] -> 
             RGBColor[
              0.6384073076923076, 0.7154430769230768, 0.9659648461538461], 
             UndirectedEdge[177, 455] -> 
             RGBColor[
              0.47128030769230755`, 0.5810416923076922, 0.9516869230769232], 
             UndirectedEdge[186, 456] -> 
             RGBColor[
              0.7316579999999999, 0.6617394615384615, 0.6015592692307692], 
             UndirectedEdge[94, 302] -> 
             RGBColor[
              0.7796891153846154, 0.6412573846153846, 0.5936706538461538], 
             UndirectedEdge[146, 376] -> 
             RGBColor[0.879451, 0.9026300769230768, 0.7594789615384616], 
             UndirectedEdge[44, 106] -> 
             RGBColor[
              0.7097995384615384, 0.7722432307692307, 0.9725281923076923], 
             UndirectedEdge[46, 205] -> 
             RGBColor[
              0.5200361923076923, 0.6197180384615384, 0.9557754615384615], 
             UndirectedEdge[134, 457] -> 
             RGBColor[
              0.48667342307692296`, 0.5908208846153845, 0.9536496153846153], 
             UndirectedEdge[229, 248] -> 
             RGBColor[
              0.47641134615384606`, 0.584301423076923, 0.9523411538461539], 
             UndirectedEdge[101, 362] -> 
             RGBColor[
              0.703844576923077, 0.7685680000000001, 0.9711163076923077], 
             UndirectedEdge[286, 346] -> 
             RGBColor[
              0.7690816923076923, 0.8197326923076923, 0.9744841923076923], 
             UndirectedEdge[134, 138] -> 
             RGBColor[
              0.5071686153846153, 0.6068318846153846, 0.9556923846153846], 
             UndirectedEdge[144, 494] -> 
             RGBColor[
              0.5551093076923076, 0.6497017692307692, 0.9581193846153846], 
             UndirectedEdge[35, 147] -> 
             RGBColor[
              0.7092397692307693, 0.7707807692307692, 0.9598612692307693], 
             UndirectedEdge[5, 211] -> 
             RGBColor[
              0.884935576923077, 0.8209690769230771, 0.6243010384615385], 
             UndirectedEdge[243, 471] -> 
             RGBColor[
              0.5960996923076924, 0.6817237692307693, 0.9622049230769231], 
             UndirectedEdge[154, 338] -> 
             RGBColor[
              0.8427379615384616, 0.7688563076923076, 0.6159251153846155], 
             UndirectedEdge[185, 383] -> 
             RGBColor[
              0.6477829615384615, 0.7212914615384616, 0.9678128846153846], 
             UndirectedEdge[416, 429] -> 
             RGBColor[0.44611730769230773`, 0.5447195, 0.9521403076923076], 
             UndirectedEdge[159, 396] -> 
             RGBColor[
              0.6964478076923077, 0.7615969230769231, 0.9712546923076923], 
             UndirectedEdge[73, 322] -> 
             RGBColor[
              0.7858253461538462, 0.8326119999999999, 0.9792873846153847], 
             UndirectedEdge[287, 300] -> 
             RGBColor[
              0.7231512692307691, 0.7828895384615384, 0.9738016923076923], 
             UndirectedEdge[392, 459] -> 
             RGBColor[
              0.5982031538461539, 0.6821996153846153, 0.9629666923076923], 
             UndirectedEdge[200, 450] -> 
             RGBColor[
              0.8183939615384614, 0.8562496153846153, 0.8534893461538462], 
             UndirectedEdge[104, 148] -> 
             RGBColor[0.47055946153846145`, 0.5759405, 0.9526566538461538], 
             UndirectedEdge[94, 325] -> 
             RGBColor[0.7373815, 0.6075380769230769, 0.5899107307692308], 
             UndirectedEdge[355, 378] -> 
             RGBColor[
              0.5769217307692307, 0.6674100769230769, 0.9598365384615384], 
             UndirectedEdge[424, 453] -> 
             RGBColor[0.8113893076923077, 0.853452, 0.9782441153846153], 
             UndirectedEdge[212, 301] -> 
             RGBColor[
              0.6384073076923076, 0.7154430769230768, 0.9659648461538461], 
             UndirectedEdge[46, 420] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[146, 284] -> 
             RGBColor[
              0.7038445769230769, 0.7685679999999999, 0.9711163076923077], 
             UndirectedEdge[76, 343] -> 
             RGBColor[
              0.8391019230769231, 0.8719797692307693, 0.8251958076923079], 
             UndirectedEdge[111, 256] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[277, 319] -> 
             RGBColor[
              0.6344312307692308, 0.7106451538461538, 0.9665393846153847], 
             UndirectedEdge[240, 429] -> 
             RGBColor[0.7503341923076923, 0.443342, 0.5666457692307693], 
             UndirectedEdge[49, 71] -> 
             RGBColor[
              0.8464618461538462, 0.7132981153846154, 0.6042106923076923], 
             UndirectedEdge[19, 139] -> 
             RGBColor[
              0.9159997307692308, 0.9317614615384615, 0.7979528461538461], 
             UndirectedEdge[9, 247] -> 
             RGBColor[
              0.6661746923076923, 0.7368266153846154, 0.9690938846153846], 
             UndirectedEdge[333, 392] -> 
             RGBColor[
              0.8523796923076923, 0.8854739999999999, 0.9823296538461539], 
             UndirectedEdge[169, 337] -> 
             RGBColor[
              0.7366475384615383, 0.7926620769230768, 0.9521069615384615], 
             UndirectedEdge[21, 119] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[354, 479] -> 
             RGBColor[
              0.889574076923077, 0.8843131538461539, 0.6651355000000001], 
             UndirectedEdge[179, 236] -> 
             RGBColor[
              0.7605678461538462, 0.8130245384615384, 0.9767317692307692], 
             UndirectedEdge[121, 341] -> 
             RGBColor[
              0.6661746923076923, 0.7368266153846154, 0.9690938846153846], 
             UndirectedEdge[263, 323] -> 
             RGBColor[
              0.8523796923076923, 0.8854739999999999, 0.9823296538461539], 
             UndirectedEdge[200, 401] -> 
             RGBColor[
              0.8593843461538462, 0.8882716153846155, 0.8575748846153847], 
             UndirectedEdge[56, 236] -> 
             RGBColor[
              0.8015582307692308, 0.8450465384615384, 0.9808173076923077], 
             UndirectedEdge[374, 437] -> 
             RGBColor[
              0.8145551153846153, 0.8546621538461538, 0.9171089615384616], 
             UndirectedEdge[74, 195] -> 
             RGBColor[0.9178966923076922, 0.937369923076923, 0.992031], 
             UndirectedEdge[240, 399] -> 
             RGBColor[0.8409043846153846, 0.5144558461538462, 0.5755775], 
             UndirectedEdge[138, 352] -> 
             RGBColor[
              0.7605678461538462, 0.8130245384615384, 0.9767317692307692], 
             UndirectedEdge[195, 342] -> 
             RGBColor[
              0.841613423076923, 0.8769854615384615, 0.9846378076923077], 
             UndirectedEdge[13, 363] -> 
             RGBColor[0.8337706923076923, 0.870144, 0.9403582692307693], 
             UndirectedEdge[368, 386] -> 
             RGBColor[
              0.4678596153846154, 0.5788685384615384, 0.9512507692307692], 
             UndirectedEdge[132, 233] -> 
             RGBColor[
              0.7097995384615384, 0.7722432307692307, 0.9725281923076923], 
             UndirectedEdge[304, 310] -> 
             RGBColor[
              0.6602197307692308, 0.7331513846153845, 0.9676819999999999], 
             UndirectedEdge[213, 259] -> 
             RGBColor[
              0.6807149230769232, 0.7491623846153845, 0.9697247692307692], 
             UndirectedEdge[226, 446] -> 
             RGBColor[
              0.6796025384615385, 0.7407032307692307, 0.8128775769230772], 
             UndirectedEdge[60, 249] -> RGBColor[0.381032, 0.5044525, 0.9455],
              UndirectedEdge[181, 387] -> 
             RGBColor[
              0.6410417692307693, 0.7188376923076923, 0.9653136153846154], 
             UndirectedEdge[94, 168] -> 
             RGBColor[
              0.7155690769230769, 0.5898297692307692, 0.5881935769230768], 
             UndirectedEdge[142, 402] -> 
             RGBColor[0.8896609230769231, 0.914004, 0.9559580384615385], 
             UndirectedEdge[188, 310] -> 
             RGBColor[
              0.49309273076923066`, 0.5987499999999999, 0.9534040769230769], 
             UndirectedEdge[74, 239] -> 
             RGBColor[
              0.7801278461538461, 0.8289524615384615, 0.9785094999999999], 
             UndirectedEdge[376, 400] -> 
             RGBColor[0.879451, 0.9026300769230768, 0.7594789615384616], 
             UndirectedEdge[292, 308] -> 
             RGBColor[
              0.9209065769230769, 0.9393851538461538, 0.9789778846153847], 
             UndirectedEdge[7, 142] -> 
             RGBColor[
              0.7204304615384616, 0.7791267692307692, 0.9409183461538462], 
             UndirectedEdge[20, 194] -> 
             RGBColor[0.8579750384615384, 0.889647, 0.9728581923076923], 
             UndirectedEdge[168, 500] -> 
             RGBColor[
              0.7709302692307691, 0.8192455384615385, 0.913674653846154], 
             UndirectedEdge[4, 383] -> 
             RGBColor[
              0.7097995384615384, 0.7722432307692307, 0.9725281923076923], 
             UndirectedEdge[91, 303] -> 
             RGBColor[
              0.9005875000000001, 0.9200127692307692, 0.8313241153846156], 
             UndirectedEdge[142, 417] -> 
             RGBColor[0.8281753461538461, 0.865971, 0.9498297307692307], 
             UndirectedEdge[229, 338] -> 
             RGBColor[
              0.6602197307692308, 0.7331513846153845, 0.9676819999999999], 
             UndirectedEdge[69, 388] -> 
             RGBColor[
              0.7858253461538462, 0.8326119999999999, 0.9792873846153847], 
             UndirectedEdge[170, 374] -> 
             RGBColor[
              0.7273054230769231, 0.7838289230769231, 0.9102403461538462], 
             UndirectedEdge[96, 281] -> 
             RGBColor[
              0.5443451923076924, 0.6372914615384616, 0.9587980769230768], 
             UndirectedEdge[131, 265] -> 
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937], 
             UndirectedEdge[117, 369] -> 
             RGBColor[0.9045449615384615, 0.9267236153846153, 0.9907575], 
             UndirectedEdge[19, 247] -> 
             RGBColor[0.8511380384615386, 0.8841383846153846, 0.9856635], 
             UndirectedEdge[328, 436] -> 
             RGBColor[
              0.5769217307692307, 0.6674100769230769, 0.9598365384615384], 
             UndirectedEdge[86, 178] -> 
             RGBColor[
              0.8965358846153847, 0.9187061538461538, 0.9252800384615385], 
             UndirectedEdge[42, 137] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[54, 135] -> 
             RGBColor[
              0.6578050384615384, 0.7281354999999999, 0.9692969615384616], 
             UndirectedEdge[42, 174] -> 
             RGBColor[
              0.8015582307692308, 0.8450465384615384, 0.9808173076923077], 
             UndirectedEdge[1, 374] -> 
             RGBColor[
              0.7491178461538461, 0.8015372307692307, 0.9119575000000001], 
             UndirectedEdge[160, 285] -> 
             RGBColor[
              0.6244422692307692, 0.6992383461538461, 0.9671711153846154], 
             UndirectedEdge[454, 471] -> 
             RGBColor[
              0.8443675384615386, 0.8380690769230771, 0.6446710000000001], 
             UndirectedEdge[26, 425] -> 
             RGBColor[
              0.884065576923077, 0.9098310000000001, 0.9654294999999999], 
             UndirectedEdge[333, 442] -> 
             RGBColor[
              0.9286629615384614, 0.9458584615384615, 0.9897228461538461], 
             UndirectedEdge[75, 410] -> 
             RGBColor[
              0.7127525384615384, 0.7698812307692308, 0.8453397307692309], 
             UndirectedEdge[31, 40] -> 
             RGBColor[0.7534243846153845, 0.8076598461538461, 0.9759625], 
             UndirectedEdge[3, 258] -> 
             RGBColor[
              0.6528229615384615, 0.7261803076923077, 0.9678203846153846], 
             UndirectedEdge[132, 273] -> 
             RGBColor[
              0.9075548461538461, 0.9287388461538462, 0.9777043846153846], 
             UndirectedEdge[157, 180] -> 
             RGBColor[
              0.6192293461538461, 0.7011293846153845, 0.9635964615384616], 
             UndirectedEdge[213, 401] -> 
             RGBColor[
              0.6397245384615384, 0.7171403846153847, 0.9656392307692307], 
             UndirectedEdge[84, 391] -> 
             RGBColor[
              0.6528229615384615, 0.7261803076923077, 0.9678203846153846], 
             UndirectedEdge[43, 110] -> 
             RGBColor[
              0.9003747307692309, 0.9202936153846154, 0.8616604230769231], 
             UndirectedEdge[39, 127] -> 
             RGBColor[
              0.7639684615384614, 0.7848525384615385, 0.6535301153846154], 
             UndirectedEdge[52, 469] -> 
             RGBColor[0.951044346153846, 0.9625504615384615, 0.951837], 
             UndirectedEdge[260, 483] -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 
             UndirectedEdge[98, 311] -> 
             RGBColor[0.8077665, 0.8503281538461539, 0.9813215384615385], 
             UndirectedEdge[51, 127] -> 
             RGBColor[
              0.9838410384615385, 0.9557029230769232, 0.5151294615384618], 
             UndirectedEdge[243, 475] -> 
             RGBColor[
              0.5551093076923077, 0.6497017692307692, 0.9581193846153846], 
             UndirectedEdge[76, 96] -> 
             RGBColor[0.52385, 0.6212804615384615, 0.9567553076923077], 
             UndirectedEdge[99, 476] -> 
             RGBColor[
              0.703644423076923, 0.7666077692307691, 0.9693327307692308], 
             UndirectedEdge[107, 308] -> 
             RGBColor[
              0.7449636923076923, 0.8005978461538461, 0.9755188461538462], 
             UndirectedEdge[190, 263] -> 
             RGBColor[
              0.9077290384615384, 0.7421523846153846, 0.6028412307692308], 
             UndirectedEdge[191, 299] -> 
             RGBColor[
              0.6344312307692308, 0.7106451538461538, 0.9665393846153847], 
             UndirectedEdge[39, 276] -> 
             RGBColor[
              0.6397245384615384, 0.7171403846153847, 0.9656392307692307], 
             UndirectedEdge[51, 214] -> 
             RGBColor[
              0.9163203846153847, 0.9324473076923077, 0.8328540384615387], 
             UndirectedEdge[295, 409] -> 
             RGBColor[
              0.43791753846153836`, 0.5521445384615383, 0.9495610769230769], 
             UndirectedEdge[371, 382] -> 
             RGBColor[
              0.8595971153846155, 0.8879907692307694, 0.8272385769230772], 
             UndirectedEdge[53, 420] -> 
             RGBColor[
              0.8990951153846154, 0.9197644615384615, 0.8828669615384616], 
             UndirectedEdge[87, 308] -> 
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937], 
             UndirectedEdge[286, 358] -> 
             RGBColor[
              0.6820321538461539, 0.7508596923076922, 0.9693991538461538], 
             UndirectedEdge[215, 351] -> 
             RGBColor[
              0.8487568846153847, 0.8823501538461538, 0.9854070769230769], 
             UndirectedEdge[114, 258] -> 
             RGBColor[
              0.5114844615384615, 0.6142851538461538, 0.9546850769230769], 
             UndirectedEdge[87, 292] -> 
             RGBColor[
              0.8942031153846154, 0.9180925384615385, 0.9764308846153846], 
             UndirectedEdge[196, 383] -> 
             RGBColor[0.9019595, 0.9245658461538462, 0.9871758461538461], 
             UndirectedEdge[65, 495] -> 
             RGBColor[
              0.5648403846153847, 0.6533024615384615, 0.9608408461538461], 
             UndirectedEdge[14, 279] -> 
             RGBColor[
              0.7243397692307694, 0.7845790000000001, 0.9731590769230769], 
             UndirectedEdge[26, 466] -> 
             RGBColor[
              0.926501923076923, 0.9435581538461538, 0.969506423076923], 
             UndirectedEdge[27, 371] -> 
             RGBColor[
              0.8391019230769231, 0.8719797692307693, 0.8251958076923079], 
             UndirectedEdge[258, 472] -> 
             RGBColor[
              0.5756045000000001, 0.6657127692307692, 0.9601621538461538], 
             UndirectedEdge[26, 117] -> 
             RGBColor[
              0.926501923076923, 0.9435581538461538, 0.969506423076923], 
             UndirectedEdge[97, 104] -> 
             RGBColor[0.7534243846153845, 0.8076598461538461, 0.9759625], 
             UndirectedEdge[21, 428] -> 
             RGBColor[
              0.6344312307692308, 0.7106451538461538, 0.9665393846153847], 
             UndirectedEdge[160, 268] -> 
             RGBColor[0.548159, 0.6388538846153845, 0.959777923076923], 
             UndirectedEdge[48, 137] -> 
             RGBColor[
              0.5974169230769231, 0.6834210769230769, 0.9618793076923077], 
             UndirectedEdge[27, 291] -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 
             UndirectedEdge[117, 140] -> 
             RGBColor[
              0.9153112307692307, 0.9352121538461537, 0.9884493461538462], 
             UndirectedEdge[31, 221] -> 
             RGBColor[
              0.7440610769230769, 0.5366481153846153, 0.5782220769230769], 
             UndirectedEdge[87, 386] -> 
             RGBColor[
              0.6528229615384615, 0.7261803076923077, 0.9678203846153846], 
             UndirectedEdge[207, 409] -> 
             RGBColor[
              0.5033548076923077, 0.6052694615384615, 0.9547125384615385], 
             UndirectedEdge[274, 498] -> 
             RGBColor[
              0.5974169230769231, 0.6834210769230769, 0.9618793076923077], 
             UndirectedEdge[28, 69] -> 
             RGBColor[
              0.8153923461538461, 0.6492716538461539, 0.5933444615384615], 
             UndirectedEdge[442, 492] -> 
             RGBColor[
              0.841613423076923, 0.8769854615384615, 0.9846378076923077], 
             UndirectedEdge[476, 493] -> 
             RGBColor[
              0.7204304615384616, 0.7791267692307692, 0.9409183461538462], 
             UndirectedEdge[297, 359] -> 
             RGBColor[
              0.5033548076923077, 0.6052694615384615, 0.9547125384615385], 
             UndirectedEdge[112, 323] -> 
             RGBColor[
              0.5982031538461539, 0.6821996153846153, 0.9629666923076923], 
             UndirectedEdge[27, 349] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[2, 242] -> 
             RGBColor[
              0.637090076923077, 0.7137457692307692, 0.9662904615384615], 
             UndirectedEdge[71, 462] -> 
             RGBColor[
              0.7025273461538463, 0.7668706923076923, 0.9714419230769231], 
             UndirectedEdge[165, 285] -> 
             RGBColor[
              0.9342583076923077, 0.9500314615384615, 0.9802513846153846], 
             UndirectedEdge[91, 172] -> 
             RGBColor[
              0.7967943076923077, 0.8382604615384616, 0.8214358846153849], 
             UndirectedEdge[19, 26] -> 
             RGBColor[
              0.8997984615384615, 0.9222655384615385, 0.9669594230769231], 
             UndirectedEdge[73, 163] -> 
             RGBColor[
              0.585335576923077, 0.6693134615384615, 0.9628836153846154], 
             UndirectedEdge[67, 131] -> 
             RGBColor[
              0.8487568846153847, 0.8823501538461538, 0.9854070769230769], 
             UndirectedEdge[24, 81] -> 
             RGBColor[0.6010684615384616, 0.681748, 0.9644135384615384], 
             UndirectedEdge[282, 467] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[122, 406] -> 
             RGBColor[
              0.835405153846154, 0.8717038461538462, 0.9841335769230769], 
             UndirectedEdge[139, 255] -> 
             RGBColor[
              0.9560549230769231, 0.9637003846153847, 0.8017733461538461], 
             UndirectedEdge[409, 458] -> 
             RGBColor[
              0.5033548076923077, 0.6052694615384615, 0.9547125384615385], 
             UndirectedEdge[4, 196] -> 
             RGBColor[
              0.7472692692307692, 0.8020243846153845, 0.9727670384615384], 
             UndirectedEdge[46, 90] -> 
             RGBColor[
              0.48667342307692296`, 0.5908208846153845, 0.9536496153846153], 
             UndirectedEdge[115, 124] -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             UndirectedEdge[330, 350] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[213, 315] -> 
             RGBColor[
              0.6602197307692308, 0.7331513846153845, 0.9676819999999999], 
             UndirectedEdge[107, 143] -> 
             RGBColor[
              0.6615369615384616, 0.7348486923076925, 0.9673563846153845], 
             UndirectedEdge[403, 491] -> 
             RGBColor[
              0.9161076153846155, 0.9327281538461538, 0.8631903461538462], 
             UndirectedEdge[200, 254] -> 
             RGBColor[
              0.8388891538461538, 0.8722606153846154, 0.8555321153846154], 
             UndirectedEdge[37, 304] -> 
             RGBColor[
              0.8282616923076923, 0.8663391538461538, 0.9833643076923078], 
             UndirectedEdge[25, 392] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[231, 492] -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             UndirectedEdge[22, 63] -> 
             RGBColor[
              0.6177498461538462, 0.6961965769230769, 0.9654764615384616], 
             UndirectedEdge[201, 256] -> 
             RGBColor[
              0.6602197307692308, 0.7331513846153845, 0.9676819999999999], 
             UndirectedEdge[57, 92] -> 
             RGBColor[0.8132754999999999, 0.854133, 0.9383155], 
             UndirectedEdge[433, 462] -> 
             RGBColor[
              0.7967943076923077, 0.8382604615384616, 0.8214358846153849], 
             UndirectedEdge[286, 294] -> 
             RGBColor[
              0.7025273461538463, 0.7668706923076923, 0.9714419230769231], 
             UndirectedEdge[319, 331] -> 
             RGBColor[
              0.49309273076923066`, 0.5987499999999999, 0.9534040769230769], 
             UndirectedEdge[222, 307] -> 
             RGBColor[0.7534243846153845, 0.8076598461538461, 0.9759625], 
             UndirectedEdge[276, 283] -> 
             RGBColor[
              0.7810630384615386, 0.8290355384615385, 0.9787745384615385], 
             UndirectedEdge[464, 497] -> 
             RGBColor[
              0.7101933076923076, 0.768822923076923, 0.8877528076923078], 
             UndirectedEdge[143, 283] -> 
             RGBColor[
              0.7810630384615386, 0.8290355384615385, 0.9787745384615385], 
             UndirectedEdge[265, 433] -> 
             RGBColor[
              0.9163203846153847, 0.9324473076923077, 0.8328540384615387], 
             UndirectedEdge[74, 234] -> 
             RGBColor[
              0.8621086153846154, 0.8929964615384616, 0.9866805769230769], 
             UndirectedEdge[17, 432] -> 
             RGBColor[
              0.5974169230769231, 0.6834210769230769, 0.9618793076923077], 
             UndirectedEdge[103, 118] -> 
             RGBColor[
              0.9717752307692307, 0.9749902307692309, 0.7201913461538463], 
             UndirectedEdge[426, 489] -> 
             RGBColor[
              0.6528229615384615, 0.7261803076923077, 0.9678203846153846], 
             UndirectedEdge[277, 331] -> 
             RGBColor[
              0.6964478076923077, 0.7615969230769231, 0.9712546923076923], 
             UndirectedEdge[74, 112] -> 
             RGBColor[
              0.674486423076923, 0.7425840769230769, 0.9703598846153847], 
             UndirectedEdge[80, 372] -> 
             RGBColor[
              0.8997984615384615, 0.9222655384615385, 0.9669594230769231], 
             UndirectedEdge[180, 281] -> 
             RGBColor[
              0.703844576923077, 0.7685680000000001, 0.9711163076923077], 
             UndirectedEdge[263, 296] -> 
             RGBColor[
              0.9153112307692307, 0.9352121538461537, 0.9884493461538462], 
             UndirectedEdge[37, 141] -> 
             RGBColor[0.8778414999999999, 0.905431, 0.9882105], 
             UndirectedEdge[18, 210] -> 
             RGBColor[
              0.6746353846153845, 0.7438886153846154, 0.9695375384615385], 
             UndirectedEdge[279, 494] -> 
             RGBColor[
              0.6397245384615384, 0.7171403846153847, 0.9656392307692307], 
             UndirectedEdge[101, 337] -> 
             RGBColor[
              0.6179121153846154, 0.6994320769230769, 0.963922076923077], 
             UndirectedEdge[217, 378] -> 
             RGBColor[
              0.6746353846153845, 0.7438886153846154, 0.9695375384615385], 
             UndirectedEdge[20, 62] -> 
             RGBColor[
              0.6602197307692308, 0.7331513846153845, 0.9676819999999999], 
             UndirectedEdge[18, 56] -> 
             RGBColor[
              0.8015582307692308, 0.8450465384615384, 0.9808173076923077], 
             UndirectedEdge[444, 492] -> 
             RGBColor[
              0.7038445769230769, 0.7685679999999999, 0.9711163076923077], 
             UndirectedEdge[199, 427] -> 
             RGBColor[
              0.7734894999999999, 0.8203038461538461, 0.8712615769230769], 
             UndirectedEdge[190, 463] -> 
             RGBColor[
              0.8980873076923077, 0.6255346923076923, 0.23643669230769232`], 
             UndirectedEdge[139, 369] -> 
             RGBColor[
              0.9560549230769231, 0.9637003846153847, 0.8017733461538461], 
             UndirectedEdge[10, 455] -> 
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153], 
             UndirectedEdge[52, 236] -> 
             RGBColor[0.9109891538461539, 0.9306115384615385, 0.9480165], 
             UndirectedEdge[9, 19] -> 
             RGBColor[
              0.6528229615384615, 0.7261803076923077, 0.9678203846153846], 
             UndirectedEdge[33, 309] -> 
             RGBColor[
              0.5960996923076924, 0.6817237692307693, 0.9622049230769231], 
             UndirectedEdge[341, 491] -> 
             RGBColor[
              0.9294593461538462, 0.9433744615384616, 0.8644638461538462], 
             UndirectedEdge[87, 143] -> 
             RGBColor[
              0.7810630384615386, 0.8290355384615385, 0.9787745384615385], 
             UndirectedEdge[110, 378] -> 
             RGBColor[
              0.7529566923076922, 0.8031246923076922, 0.8483378846153846], 
             UndirectedEdge[401, 471] -> 
             RGBColor[
              0.7243397692307694, 0.7845790000000001, 0.9731590769230769], 
             UndirectedEdge[160, 165] -> 
             RGBColor[0.6408038846153845, 0.7118998846153846, 0.9553915], 
             UndirectedEdge[13, 379] -> 
             RGBColor[0.9730013076923076, 0.979385, 0.9305859230769231], 
             UndirectedEdge[210, 434] -> 
             RGBColor[
              0.7531694615384614, 0.8028438461538461, 0.8180015769230772], 
             UndirectedEdge[308, 446] -> 
             RGBColor[
              0.9430238461538462, 0.953739923076923, 0.8354010384615387], 
             UndirectedEdge[153, 395] -> 
             RGBColor[
              0.835405153846154, 0.8717038461538462, 0.9841335769230769], 
             UndirectedEdge[24, 83] -> 
             RGBColor[
              0.7810630384615386, 0.8290355384615385, 0.9787745384615385], 
             UndirectedEdge[133, 260] -> 
             RGBColor[
              0.8015582307692308, 0.8450465384615384, 0.9808173076923077], 
             UndirectedEdge[83, 119] -> 
             RGBColor[
              0.765330153846154, 0.8166010000000001, 0.9772446153846154], 
             UndirectedEdge[400, 464] -> 
             RGBColor[
              0.8773203076923077, 0.9032243076923077, 0.9020307307692309], 
             UndirectedEdge[175, 320] -> 
             RGBColor[
              0.5769217307692307, 0.6674100769230769, 0.9598365384615384], 
             UndirectedEdge[39, 475] -> 
             RGBColor[
              0.5987341538461537, 0.6851183846153845, 0.9615536923076923], 
             UndirectedEdge[289, 291] -> 
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923], 
             UndirectedEdge[263, 342] -> 
             RGBColor[
              0.8523796923076923, 0.8854739999999999, 0.9823296538461539], 
             UndirectedEdge[311, 319] -> 
             RGBColor[
              0.5777079615384616, 0.6661886153846155, 0.9609239230769231], 
             UndirectedEdge[141, 304] -> 
             RGBColor[
              0.8149099615384616, 0.8556928461538461, 0.9820908076923076], 
             UndirectedEdge[30, 43] -> 
             RGBColor[
              0.7025273461538463, 0.7668706923076923, 0.9714419230769231], 
             UndirectedEdge[85, 95] -> 
             RGBColor[
              0.8621086153846154, 0.8929964615384616, 0.9866805769230769], 
             UndirectedEdge[305, 438] -> 
             RGBColor[
              0.7722098846153845, 0.8197746923076923, 0.8924681153846155], 
             UndirectedEdge[23, 212] -> 
             RGBColor[
              0.6165948846153846, 0.6977347692307692, 0.9642476923076924], 
             UndirectedEdge[80, 461] -> 
             RGBColor[
              0.6746353846153845, 0.7438886153846154, 0.9695375384615385], 
             UndirectedEdge[115, 439] -> 
             RGBColor[
              0.7858253461538462, 0.8326119999999999, 0.9792873846153847], 
             UndirectedEdge[136, 377] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[27, 488] -> 
             RGBColor[
              0.7605678461538462, 0.8130245384615384, 0.9767317692307692], 
             UndirectedEdge[70, 170] -> 
             RGBColor[
              0.6165948846153846, 0.6977347692307692, 0.9642476923076924], 
             UndirectedEdge[268, 441] -> 
             RGBColor[
              0.8798795384615385, 0.9042826153846153, 0.859617653846154], 
             UndirectedEdge[394, 445] -> 
             RGBColor[
              0.5551093076923077, 0.6497017692307692, 0.9581193846153846], 
             UndirectedEdge[234, 393] -> 
             RGBColor[
              0.6020169615384616, 0.6837620384615384, 0.9639465384615384], 
             UndirectedEdge[228, 388] -> 
             RGBColor[0.8952562692307693, 0.918177, 0.9464865769230769], 
             UndirectedEdge[8, 114] -> 
             RGBColor[
              0.49309273076923066`, 0.5987499999999999, 0.9534040769230769], 
             UndirectedEdge[21, 164] -> 
             RGBColor[
              0.8015582307692308, 0.8450465384615384, 0.9808173076923077], 
             UndirectedEdge[100, 454] -> 
             RGBColor[
              0.9010908076923078, 0.8825256153846155, 0.6502864615384616], 
             UndirectedEdge[6, 267] -> 
             RGBColor[
              0.5815217692307693, 0.6677510384615384, 0.9619037692307693], 
             UndirectedEdge[210, 495] -> 
             RGBColor[
              0.43791753846153836`, 0.5521445384615383, 0.9495610769230769], 
             UndirectedEdge[112, 342] -> 
             RGBColor[
              0.5982031538461539, 0.6821996153846153, 0.9629666923076923], 
             UndirectedEdge[93, 206] -> 
             RGBColor[
              0.7148351153846153, 0.7749537692307692, 0.9503898076923076], 
             UndirectedEdge[485, 497] -> 
             RGBColor[
              0.5149051538461539, 0.6164583076923077, 0.9551212307692307], 
             UndirectedEdge[36, 240] -> 
             RGBColor[0.7503341923076923, 0.443342, 0.5666457692307691], 
             UndirectedEdge[275, 285] -> 
             RGBColor[
              0.8006230384615385, 0.8449634615384616, 0.9805522692307692], 
             UndirectedEdge[36, 399] -> 
             RGBColor[
              0.7739195769230769, 0.8236708461538462, 0.9780052692307692], 
             UndirectedEdge[72, 279] -> 
             RGBColor[
              0.5777079615384616, 0.6661886153846155, 0.9609239230769231], 
             UndirectedEdge[278, 413] -> 
             RGBColor[
              0.5149051538461539, 0.6164583076923077, 0.9551212307692307], 
             UndirectedEdge[10, 120] -> 
             RGBColor[
              0.7858253461538462, 0.8326119999999999, 0.9792873846153847], 
             UndirectedEdge[59, 153] -> 
             RGBColor[0.8778414999999999, 0.905431, 0.9882105], 
             UndirectedEdge[377, 488] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[53, 306] -> 
             RGBColor[
              0.5853983461538461, 0.6481499615384615, 0.8589523846153846], 
             UndirectedEdge[172, 448] -> 
             RGBColor[
              0.7182602307692308, 0.7793052307692308, 0.9729718461538461], 
             UndirectedEdge[138, 367] -> 
             RGBColor[
              0.5405313846153846, 0.6357290384615384, 0.9578182307692308], 
             UndirectedEdge[71, 431] -> 
             RGBColor[
              0.8621086153846154, 0.8929964615384616, 0.9866805769230769], 
             UndirectedEdge[180, 392] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[33, 227] -> 
             RGBColor[
              0.7243397692307694, 0.7845790000000001, 0.9731590769230769], 
             UndirectedEdge[30, 384] -> 
             RGBColor[
              0.7182602307692308, 0.7793052307692308, 0.9729718461538461], 
             UndirectedEdge[441, 467] -> 
             RGBColor[
              0.9003747307692309, 0.9202936153846154, 0.8616604230769231], 
             UndirectedEdge[99, 122] -> 
             RGBColor[0.9019595, 0.9245658461538462, 0.9871758461538461], 
             UndirectedEdge[89, 225] -> 
             RGBColor[
              0.7908941153846153, 0.8374409999999999, 0.9762013461538461], 
             UndirectedEdge[146, 497] -> 
             RGBColor[
              0.5982031538461539, 0.6821996153846153, 0.9629666923076923], 
             UndirectedEdge[176, 197] -> 
             RGBColor[
              0.7285850384615384, 0.7843580769230769, 0.8890338076923079], 
             UndirectedEdge[326, 474] -> 
             RGBColor[
              0.6578050384615384, 0.7281354999999999, 0.9692969615384616], 
             UndirectedEdge[173, 241] -> 
             RGBColor[
              0.9077290384615384, 0.7421523846153846, 0.6028412307692308], 
             UndirectedEdge[403, 405] -> 
             RGBColor[
              0.7400726538461538, 0.7970135384615384, 0.9746889999999999], 
             UndirectedEdge[79, 476] -> 
             RGBColor[
              0.6528229615384615, 0.7261803076923077, 0.9678203846153846], 
             UndirectedEdge[46, 257] -> 
             RGBColor[
              0.8033771538461538, 0.806047076923077, 0.6405854615384616], 
             UndirectedEdge[450, 491] -> 
             RGBColor[
              0.8183939615384614, 0.8562496153846153, 0.8534893461538462], 
             UndirectedEdge[200, 243] -> 
             RGBColor[
              0.7311442692307693, 0.7854163846153845, 0.8466207307692308], 
             UndirectedEdge[296, 424] -> 
             RGBColor[
              0.7872713076923077, 0.8343171538461538, 0.9792787692307692], 
             UndirectedEdge[269, 466] -> 
             RGBColor[
              0.9153112307692307, 0.9352121538461537, 0.9884493461538462], 
             UndirectedEdge[74, 453] -> 
             RGBColor[
              0.9286629615384614, 0.9458584615384615, 0.9897228461538461], 
             UndirectedEdge[18, 469] -> 
             RGBColor[0.8778414999999999, 0.905431, 0.9882105], 
             UndirectedEdge[279, 481] -> 
             RGBColor[
              0.8592764615384616, 0.8873049230769232, 0.7923373846153845], 
             UndirectedEdge[19, 468] -> 
             RGBColor[
              0.6528229615384615, 0.7261803076923077, 0.9678203846153846], 
             UndirectedEdge[415, 464] -> 
             RGBColor[
              0.8158347307692306, 0.8551913076923077, 0.8959024230769232], 
             UndirectedEdge[234, 262] -> 
             RGBColor[
              0.884065576923077, 0.9098310000000001, 0.9654294999999999], 
             UndirectedEdge[241, 417] -> 
             RGBColor[
              0.7796891153846154, 0.6412573846153846, 0.5936706538461538], 
             UndirectedEdge[309, 489] -> 
             RGBColor[
              0.4678596153846154, 0.5788685384615384, 0.9512507692307692], 
             UndirectedEdge[83, 426] -> 
             RGBColor[
              0.7810630384615386, 0.8290355384615385, 0.9787745384615385], 
             UndirectedEdge[6, 99] -> 
             RGBColor[
              0.8523796923076923, 0.8854739999999999, 0.9823296538461539], 
             UndirectedEdge[121, 491] -> 
             RGBColor[
              0.7311442692307693, 0.7854163846153845, 0.8466207307692308], 
             UndirectedEdge[42, 358] -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             UndirectedEdge[69, 461] -> 
             RGBColor[
              0.6384073076923076, 0.7154430769230768, 0.9659648461538461], 
             UndirectedEdge[161, 387] -> 
             RGBColor[
              0.6628541923076923, 0.7365459999999999, 0.9670307692307691], 
             UndirectedEdge[117, 390] -> 
             RGBColor[0.9376926153846153, 0.9519041538461539, 0.9505635], 
             UndirectedEdge[244, 334] -> 
             RGBColor[
              0.6807149230769232, 0.7491623846153845, 0.9697247692307692], 
             UndirectedEdge[173, 493] -> 
             RGBColor[0.9562152692307692, 0.966866, 0.9590003076923077], 
             UndirectedEdge[229, 255] -> 
             RGBColor[
              0.7365029999999999, 0.7935358461538461, 0.9750751923076924], 
             UndirectedEdge[39, 401] -> 
             RGBColor[
              0.6397245384615384, 0.7171403846153847, 0.9656392307692307], 
             UndirectedEdge[379, 380] -> 
             RGBColor[
              0.7366475384615383, 0.7926620769230768, 0.9521069615384615], 
             UndirectedEdge[92, 140] -> 
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461], 
             UndirectedEdge[78, 97] -> 
             RGBColor[
              0.6477829615384615, 0.7212914615384616, 0.9678128846153846], 
             UndirectedEdge[395, 463] -> 
             RGBColor[
              0.863233153846154, 0.7848673076923076, 0.6179678846153847], 
             UndirectedEdge[174, 338] -> 
             RGBColor[
              0.8015582307692308, 0.8450465384615384, 0.9808173076923077], 
             UndirectedEdge[143, 423] -> 
             RGBColor[
              0.8568251153846154, 0.8872133076923078, 0.8999879615384616], 
             UndirectedEdge[94, 100] -> 
             RGBColor[
              0.856907576923077, 0.7017249230769231, 0.6013288846153846], 
             UndirectedEdge[404, 408] -> 
             RGBColor[
              0.7260258076923076, 0.7832997692307693, 0.9314468846153846], 
             UndirectedEdge[301, 389] -> 
             RGBColor[
              0.7491178461538461, 0.8015372307692307, 0.9119575000000001], 
             UndirectedEdge[16, 422] -> 
             RGBColor[
              0.5200361923076923, 0.6197180384615384, 0.9557754615384615], 
             UndirectedEdge[389, 451] -> 
             RGBColor[
              0.9122687692307693, 0.9311406923076924, 0.9268099615384616], 
             UndirectedEdge[74, 296] -> 
             RGBColor[0.9045449615384615, 0.9267236153846153, 0.9907575], 
             UndirectedEdge[225, 453] -> 
             RGBColor[0.9394292307692307, 0.954347, 0.9874146923076923], 
             UndirectedEdge[340, 378] -> 
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153], 
             UndirectedEdge[52, 428] -> 
             RGBColor[
              0.7076340769230769, 0.7677646153846154, 0.9301658846153846], 
             UndirectedEdge[84, 230] -> 
             RGBColor[
              0.6344312307692308, 0.7106451538461538, 0.9665393846153847], 
             UndirectedEdge[119, 237] -> 
             RGBColor[
              0.6807149230769232, 0.7491623846153845, 0.9697247692307692], 
             UndirectedEdge[67, 171] -> 
             RGBColor[
              0.637090076923077, 0.7137457692307692, 0.9662904615384615], 
             UndirectedEdge[25, 157] -> 
             RGBColor[
              0.6397245384615384, 0.7171403846153847, 0.9656392307692307], 
             UndirectedEdge[124, 484] -> 
             RGBColor[
              0.7858253461538462, 0.8326119999999999, 0.9792873846153847], 
             UndirectedEdge[368, 500] -> 
             RGBColor[
              0.7273054230769231, 0.7838289230769231, 0.9102403461538462], 
             UndirectedEdge[283, 422] -> 
             RGBColor[
              0.7400726538461538, 0.7970135384615384, 0.9746889999999999], 
             UndirectedEdge[334, 369] -> 
             RGBColor[
              0.7365029999999999, 0.7935358461538461, 0.9750751923076924], 
             UndirectedEdge[42, 346] -> 
             RGBColor[
              0.8523796923076923, 0.8854739999999999, 0.9823296538461539], 
             UndirectedEdge[112, 263] -> 
             RGBColor[
              0.6852526923076923, 0.7510726153846153, 0.9680517307692308], 
             UndirectedEdge[146, 201] -> 
             RGBColor[
              0.6602197307692308, 0.7331513846153845, 0.9676819999999999], 
             UndirectedEdge[16, 243] -> 
             RGBColor[
              0.43278649999999996`, 0.5488848076923076, 0.9489068461538461], 
             UndirectedEdge[285, 481] -> 
             RGBColor[
              0.9560549230769231, 0.9637003846153847, 0.8017733461538461], 
             UndirectedEdge[231, 444] -> 
             RGBColor[
              0.7038445769230769, 0.7685679999999999, 0.9711163076923077], 
             UndirectedEdge[137, 408] -> 
             RGBColor[
              0.5756045000000001, 0.6657127692307692, 0.9601621538461538], 
             UndirectedEdge[431, 436] -> 
             RGBColor[
              0.7146905769230768, 0.7758275384615383, 0.9733580384615385], 
             UndirectedEdge[98, 277] -> 
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937], 
             UndirectedEdge[131, 391] -> 
             RGBColor[
              0.6795264230769231, 0.747472923076923, 0.9703673846153846], 
             UndirectedEdge[52, 227] -> 
             RGBColor[0.8542658846153847, 0.886155, 0.9424010384615384], 
             UndirectedEdge[27, 419] -> 
             RGBColor[0.52385, 0.6212804615384615, 0.9567553076923077], 
             UndirectedEdge[232, 312] -> 
             RGBColor[
              0.8015582307692308, 0.8450465384615384, 0.9808173076923077], 
             UndirectedEdge[247, 466] -> 
             RGBColor[0.8778414999999999, 0.905431, 0.9882105], 
             UndirectedEdge[253, 484] -> 
             RGBColor[
              0.6807149230769232, 0.7491623846153845, 0.9697247692307692], 
             UndirectedEdge[121, 200] -> 
             RGBColor[
              0.7311442692307693, 0.7854163846153845, 0.8466207307692308], 
             UndirectedEdge[79, 99] -> 
             RGBColor[
              0.8886077692307692, 0.9139195384615384, 0.9859023461538461], 
             UndirectedEdge[109, 300] -> 
             RGBColor[
              0.7584599615384615, 0.8103703846153846, 0.9538241153846154], 
             UndirectedEdge[31, 397] -> 
             RGBColor[0.8020848076923076, 0.845787, 0.957258423076923], 
             UndirectedEdge[70, 374] -> 
             RGBColor[
              0.8760406923076923, 0.9026951538461538, 0.9232372692307693], 
             UndirectedEdge[240, 352] -> 
             RGBColor[0.827552653846154, 0.5038095384615384, 0.574304], 
             UndirectedEdge[105, 323] -> 
             RGBColor[
              0.7858253461538462, 0.8326119999999999, 0.9792873846153847], 
             UndirectedEdge[46, 53] -> 
             RGBColor[
              0.8171143461538461, 0.8557204615384615, 0.8746958846153846], 
             UndirectedEdge[221, 223] -> 
             RGBColor[
              0.9162571923076923, 0.6707752692307691, 0.5303430384615386], 
             UndirectedEdge[33, 159] -> 
             RGBColor[
              0.6397245384615384, 0.7171403846153847, 0.9656392307692307], 
             UndirectedEdge[16, 454] -> 
             RGBColor[
              0.6810543461538461, 0.7052301153846154, 0.6313729230769232], 
             UndirectedEdge[195, 224] -> 
             RGBColor[
              0.9075370769230768, 0.7816793076923079, 0.6139728461538462], 
             UndirectedEdge[259, 500] -> 
             RGBColor[
              0.8965358846153847, 0.9187061538461538, 0.9252800384615385], 
             UndirectedEdge[24, 77] -> 
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937], 
             UndirectedEdge[226, 386] -> 
             RGBColor[
              0.41610511538461536`, 0.5344362307692307, 0.9478439230769231], 
             UndirectedEdge[289, 314] -> 
             RGBColor[
              0.7366475384615383, 0.7926620769230768, 0.9521069615384615], 
             UndirectedEdge[179, 325] -> 
             RGBColor[
              0.6410417692307693, 0.7188376923076923, 0.9653136153846154], 
             UndirectedEdge[81, 83] -> 
             RGBColor[
              0.5443451923076924, 0.6372914615384616, 0.9587980769230768], 
             UndirectedEdge[312, 376] -> 
             RGBColor[
              0.9156790769230769, 0.9310756153846154, 0.7630516538461538], 
             UndirectedEdge[270, 309] -> 
             RGBColor[
              0.637090076923077, 0.7137457692307692, 0.9662904615384615], 
             UndirectedEdge[139, 269] -> 
             RGBColor[
              0.9668211923076923, 0.9721889230769231, 0.7994651923076923], 
             UndirectedEdge[269, 425] -> 
             RGBColor[0.8728748846153846, 0.901485, 0.9843724230769231], 
             UndirectedEdge[25, 492] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[142, 173] -> 
             RGBColor[0.9562152692307692, 0.966866, 0.9590003076923077], 
             UndirectedEdge[132, 209] -> 
             RGBColor[
              0.9075548461538461, 0.9287388461538462, 0.9777043846153846], 
             UndirectedEdge[389, 409] -> 
             RGBColor[
              0.6755509230769231, 0.7393966153846153, 0.9068335000000001], 
             UndirectedEdge[337, 370] -> 
             RGBColor[
              0.725456846153846, 0.7843160769230768, 0.9710498846153846], 
             UndirectedEdge[230, 242] -> 
             RGBColor[
              0.6186983461538462, 0.6982106153846154, 0.9650094615384616], 
             UndirectedEdge[28, 461] -> 
             RGBColor[0.6884695, 0.5481137307692308, 0.5820646923076923], 
             UndirectedEdge[318, 350] -> 
             RGBColor[
              0.8411746923076924, 0.6892903846153846, 0.5997989615384616], 
             UndirectedEdge[390, 478] -> 
             RGBColor[0.984192, 0.987731, 0.911643], UndirectedEdge[167, 434] -> 
             RGBColor[
              0.9920824615384616, 0.9906250769230769, 0.7540674615384619], 
             UndirectedEdge[247, 269] -> 
             RGBColor[0.9019595, 0.9245658461538462, 0.9871758461538461], 
             UndirectedEdge[394, 398] -> 
             RGBColor[0.44874703846153846`, 0.5582321923076923, 0.9509395], 
             UndirectedEdge[14, 158] -> 
             RGBColor[
              0.7944147692307693, 0.8396818461538462, 0.9800480384615384], 
             UndirectedEdge[131, 433] -> 
             RGBColor[
              0.9430238461538462, 0.953739923076923, 0.8354010384615387], 
             UndirectedEdge[87, 422] -> 
             RGBColor[
              0.7400726538461538, 0.7970135384615384, 0.9746889999999999], 
             UndirectedEdge[210, 469] -> 
             RGBColor[
              0.7146905769230768, 0.7758275384615383, 0.9733580384615385], 
             UndirectedEdge[312, 414] -> 
             RGBColor[
              0.9161076153846155, 0.9327281538461538, 0.8631903461538462], 
             UndirectedEdge[277, 311] -> 
             RGBColor[
              0.7810630384615386, 0.8290355384615385, 0.9787745384615385], 
             UndirectedEdge[332, 424] -> 
             RGBColor[
              0.8387812692307692, 0.8712939230769231, 0.7902946153846153], 
             UndirectedEdge[328, 433] -> 
             RGBColor[
              0.8186067307692307, 0.8559687692307691, 0.8231530384615386], 
             UndirectedEdge[88, 428] -> 
             RGBColor[
              0.7127525384615384, 0.7698812307692308, 0.8453397307692309], 
             UndirectedEdge[8, 162] -> 
             RGBColor[
              0.6186983461538462, 0.6982106153846154, 0.9650094615384616], 
             UndirectedEdge[27, 289] -> 
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923], 
             UndirectedEdge[192, 280] -> 
             RGBColor[
              0.7690816923076923, 0.8197326923076923, 0.9744841923076923], 
             UndirectedEdge[347, 477] -> 
             RGBColor[
              0.6628541923076923, 0.7365459999999999, 0.9670307692307691], 
             UndirectedEdge[145, 346] -> 
             RGBColor[0.8318845, 0.8694630000000001, 0.9802868846153846], 
             UndirectedEdge[232, 415] -> 
             RGBColor[
              0.7038445769230769, 0.7685679999999999, 0.9711163076923077], 
             UndirectedEdge[189, 374] -> 
             RGBColor[
              0.8555455000000001, 0.8866841538461538, 0.9211945000000001], 
             UndirectedEdge[139, 140] -> 
             RGBColor[
              0.9668211923076923, 0.9721889230769231, 0.7994651923076923], 
             UndirectedEdge[134, 251] -> 
             RGBColor[
              0.48667342307692296`, 0.5908208846153845, 0.9536496153846153], 
             UndirectedEdge[67, 281] -> 
             RGBColor[
              0.765330153846154, 0.8166010000000001, 0.9772446153846154], 
             UndirectedEdge[167, 495] -> 
             RGBColor[
              0.6768305384615384, 0.7399257692307692, 0.8856269615384617], 
             UndirectedEdge[143, 179] -> 
             RGBColor[
              0.703844576923077, 0.7685680000000001, 0.9711163076923077], 
             UndirectedEdge[21, 175] -> 
             RGBColor[
              0.6964478076923077, 0.7615969230769231, 0.9712546923076923], 
             UndirectedEdge[366, 473] -> 
             RGBColor[0.8281753461538461, 0.865971, 0.9498297307692307], 
             UndirectedEdge[143, 292] -> 
             RGBColor[
              0.8374798461538462, 0.8736360000000001, 0.970815423076923], 
             UndirectedEdge[267, 486] -> 
             RGBColor[
              0.6956426153846154, 0.7537801153846153, 0.7441381153846154], 
             UndirectedEdge[248, 380] -> 
             RGBColor[0.45459892307692296`, 0.5665931153846153, 0.950624], 
             UndirectedEdge[48, 407] -> 
             RGBColor[
              0.47128030769230755`, 0.5810416923076922, 0.9516869230769232], 
             UndirectedEdge[436, 459] -> 
             RGBColor[
              0.47128030769230755`, 0.5810416923076922, 0.9516869230769232], 
             UndirectedEdge[235, 262] -> 
             RGBColor[0.679762, 0.7449700384615384, 0.9480458846153846], 
             UndirectedEdge[236, 283] -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 
             UndirectedEdge[99, 493] -> 
             RGBColor[0.9562152692307692, 0.966866, 0.9590003076923077], 
             UndirectedEdge[109, 456] -> 
             RGBColor[
              0.7584599615384615, 0.8103703846153846, 0.9538241153846154], 
             UndirectedEdge[208, 289] -> 
             RGBColor[
              0.9529172692307692, 0.8934097692307693, 0.6116736923076923], 
             UndirectedEdge[266, 410] -> 
             RGBColor[
              0.4310761538461538, 0.5477982307692307, 0.9486887692307693], 
             UndirectedEdge[299, 301] -> 
             RGBColor[
              0.6746353846153845, 0.7438886153846154, 0.9695375384615385], 
             UndirectedEdge[314, 359] -> 
             RGBColor[
              0.43791753846153836`, 0.5521445384615383, 0.9495610769230769], 
             UndirectedEdge[209, 214] -> 
             RGBColor[
              0.8942031153846154, 0.9180925384615385, 0.9764308846153846], 
             UndirectedEdge[210, 326] -> 
             RGBColor[
              0.7146905769230768, 0.7758275384615383, 0.9733580384615385], 
             UndirectedEdge[53, 317] -> 
             RGBColor[0.914828, 0.932199, 0.8843968846153847], 
             UndirectedEdge[402, 459] -> 
             RGBColor[
              0.6186983461538462, 0.6982106153846154, 0.9650094615384616], 
             UndirectedEdge[89, 249] -> 
             RGBColor[
              0.5033548076923077, 0.6052694615384615, 0.9547125384615385], 
             UndirectedEdge[67, 135] -> 
             RGBColor[
              0.8621086153846154, 0.8929964615384616, 0.9866805769230769], 
             UndirectedEdge[90, 178] -> 
             RGBColor[
              0.6588695384615384, 0.7249480384615383, 0.905770576923077], 
             UndirectedEdge[174, 229] -> 
             RGBColor[
              0.6964478076923077, 0.7615969230769231, 0.9712546923076923], 
             UndirectedEdge[266, 364] -> 
             RGBColor[
              0.6935195769230769, 0.7054566153846153, 0.6160568846153847], 
             UndirectedEdge[407, 430] -> 
             RGBColor[
              0.49309273076923066`, 0.5987499999999999, 0.9534040769230769], 
             UndirectedEdge[217, 355] -> 
             RGBColor[
              0.7400726538461538, 0.7970135384615384, 0.9746889999999999], 
             UndirectedEdge[176, 426] -> 
             RGBColor[
              0.9135483846153847, 0.9316698461538462, 0.9056034230769232], 
             UndirectedEdge[280, 483] -> 
             RGBColor[
              0.8886077692307692, 0.9139195384615384, 0.9859023461538461], 
             UndirectedEdge[51, 347] -> 
             RGBColor[
              0.8391019230769231, 0.8719797692307693, 0.8251958076923079], 
             UndirectedEdge[152, 451] -> 
             RGBColor[
              0.7182602307692308, 0.7793052307692308, 0.9729718461538461], 
             UndirectedEdge[105, 342] -> 
             RGBColor[
              0.7858253461538462, 0.8326119999999999, 0.9792873846153847], 
             UndirectedEdge[318, 496] -> 
             RGBColor[0.6535525, 0.538878, 0.5834782692307692], 
             UndirectedEdge[114, 289] -> 
             RGBColor[
              0.7584599615384615, 0.8103703846153846, 0.9538241153846154], 
             UndirectedEdge[103, 331] -> 
             RGBColor[
              0.7528646153846152, 0.8061973846153846, 0.9632955769230769], 
             UndirectedEdge[107, 113] -> 
             RGBColor[
              0.7025273461538463, 0.7668706923076923, 0.9714419230769231], 
             UndirectedEdge[16, 56] -> 
             RGBColor[
              0.5815217692307693, 0.6677510384615384, 0.9619037692307693], 
             UndirectedEdge[140, 370] -> 
             RGBColor[0.9394292307692307, 0.954347, 0.9874146923076923], 
             UndirectedEdge[213, 500] -> 
             RGBColor[
              0.7709302692307691, 0.8192455384615385, 0.913674653846154], 
             UndirectedEdge[280, 327] -> 
             RGBColor[
              0.9671418461538461, 0.9728747692307692, 0.8343663846153848], 
             UndirectedEdge[76, 238] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[253, 261] -> 
             RGBColor[
              0.7749818846153846, 0.8205521538461538, 0.8197187307692311], 
             UndirectedEdge[232, 350] -> 
             RGBColor[
              0.7858253461538462, 0.8326119999999999, 0.9792873846153847], 
             UndirectedEdge[166, 320] -> 
             RGBColor[
              0.6615369615384616, 0.7348486923076925, 0.9673563846153845], 
             UndirectedEdge[33, 119] -> 
             RGBColor[
              0.765330153846154, 0.8166010000000001, 0.9772446153846154], 
             UndirectedEdge[71, 228] -> 
             RGBColor[0.8952562692307693, 0.918177, 0.9464865769230769], 
             UndirectedEdge[50, 244] -> 
             RGBColor[
              0.6186983461538462, 0.6982106153846154, 0.9650094615384616], 
             UndirectedEdge[235, 344] -> 
             RGBColor[
              0.6578050384615384, 0.7281354999999999, 0.9692969615384616], 
             UndirectedEdge[72, 494] -> 
             RGBColor[
              0.49309273076923066`, 0.5987499999999999, 0.9534040769230769], 
             UndirectedEdge[185, 496] -> 
             RGBColor[
              0.4310761538461538, 0.5477982307692307, 0.9486887692307693], 
             UndirectedEdge[106, 370] -> 
             RGBColor[0.9019595, 0.9245658461538462, 0.9871758461538461], 
             UndirectedEdge[51, 113] -> 
             RGBColor[
              0.9005875000000001, 0.9200127692307692, 0.8313241153846156], 
             UndirectedEdge[422, 443] -> 
             RGBColor[
              0.8075933076923076, 0.8202691538461538, 0.6569644230769232], 
             UndirectedEdge[4, 335] -> 
             RGBColor[
              0.4269346153846153, 0.5405238846153846, 0.9492223461538462], 
             UndirectedEdge[1, 84] -> 
             RGBColor[
              0.6746353846153845, 0.7438886153846154, 0.9695375384615385], 
             UndirectedEdge[90, 272] -> 
             RGBColor[0.548159, 0.6388538846153845, 0.959777923076923], 
             UndirectedEdge[213, 450] -> 
             RGBColor[
              0.5987341538461537, 0.6851183846153845, 0.9615536923076923], 
             UndirectedEdge[5, 212] -> 
             RGBColor[
              0.8015582307692308, 0.8450465384615384, 0.9808173076923077], 
             UndirectedEdge[50, 106] -> 
             RGBColor[
              0.6477829615384615, 0.7212914615384616, 0.9678128846153846], 
             UndirectedEdge[115, 291] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[9, 117] -> 
             RGBColor[
              0.6795264230769231, 0.747472923076923, 0.9703673846153846], 
             UndirectedEdge[194, 388] -> 
             RGBColor[
              0.8784702307692308, 0.9056580000000001, 0.9749009615384616], 
             UndirectedEdge[202, 211] -> 
             RGBColor[
              0.7654095000000001, 0.726782230769231, 0.6128828846153846], 
             UndirectedEdge[113, 308] -> 
             RGBColor[
              0.8487568846153847, 0.8823501538461538, 0.9854070769230769], 
             UndirectedEdge[51, 421] -> 
             RGBColor[
              0.6168489615384616, 0.6798862692307692, 0.8091156153846156], 
             UndirectedEdge[109, 335] -> 
             RGBColor[
              0.6302852692307692, 0.7011924999999999, 0.9449270769230769], 
             UndirectedEdge[278, 329] -> 
             RGBColor[
              0.6186983461538462, 0.6982106153846154, 0.9650094615384616], 
             UndirectedEdge[129, 206] -> 
             RGBColor[
              0.6528229615384615, 0.7261803076923077, 0.9678203846153846], 
             UndirectedEdge[166, 227] -> 
             RGBColor[
              0.7243397692307694, 0.7845790000000001, 0.9731590769230769], 
             UndirectedEdge[294, 411] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[362, 384] -> 
             RGBColor[
              0.7605678461538462, 0.8130245384615384, 0.9767317692307692], 
             UndirectedEdge[143, 308] -> 
             RGBColor[0.8077665, 0.8503281538461539, 0.9813215384615385], 
             UndirectedEdge[151, 310] -> 
             RGBColor[
              0.6192293461538461, 0.7011293846153845, 0.9635964615384616], 
             UndirectedEdge[297, 397] -> 
             RGBColor[0.8020848076923076, 0.845787, 0.957258423076923], 
             UndirectedEdge[114, 359] -> 
             RGBColor[
              0.45972996153846146`, 0.5698528461538461, 0.9512782307692307], 
             UndirectedEdge[141, 220] -> 
             RGBColor[
              0.9131501923076923, 0.9329118461538461, 0.9682329230769231], 
             UndirectedEdge[122, 493] -> 
             RGBColor[
              0.9187455384615384, 0.9370848461538461, 0.9587614615384615], 
             UndirectedEdge[146, 442] -> 
             RGBColor[
              0.841613423076923, 0.8769854615384615, 0.9846378076923077], 
             UndirectedEdge[294, 478] -> 
             RGBColor[0.8952562692307693, 0.918177, 0.9464865769230769], 
             UndirectedEdge[76, 487] -> 
             RGBColor[
              0.8391019230769231, 0.8719797692307693, 0.8251958076923079], 
             UndirectedEdge[67, 70] -> 
             RGBColor[
              0.7858253461538462, 0.8326119999999999, 0.9792873846153847], 
             UndirectedEdge[346, 358] -> 
             RGBColor[
              0.8523796923076923, 0.8854739999999999, 0.9823296538461539], 
             UndirectedEdge[149, 165] -> 
             RGBColor[
              0.8942031153846154, 0.9180925384615385, 0.9764308846153846], 
             UndirectedEdge[175, 375] -> 
             RGBColor[
              0.7749818846153846, 0.8205521538461538, 0.8197187307692311], 
             UndirectedEdge[18, 428] -> 
             RGBColor[
              0.6344312307692308, 0.7106451538461538, 0.9665393846153847], 
             UndirectedEdge[2, 47] -> 
             RGBColor[
              0.6528229615384615, 0.7261803076923077, 0.9678203846153846], 
             UndirectedEdge[140, 466] -> 
             RGBColor[
              0.9153112307692307, 0.9352121538461537, 0.9884493461538462], 
             UndirectedEdge[199, 382] -> 
             RGBColor[
              0.6397245384615384, 0.7171403846153847, 0.9656392307692307], 
             UndirectedEdge[305, 499] -> 
             RGBColor[
              0.7231512692307691, 0.7828895384615384, 0.9738016923076923], 
             UndirectedEdge[252, 282] -> 
             RGBColor[
              0.6628541923076923, 0.7365459999999999, 0.9670307692307691], 
             UndirectedEdge[235, 249] -> 
             RGBColor[0.381032, 0.5044525, 0.9455], UndirectedEdge[130, 214] -> 
             RGBColor[
              0.8220534230769232, 0.8610575384615384, 0.9828600769230769], 
             UndirectedEdge[100, 475] -> 
             RGBColor[
              0.7400726538461538, 0.7970135384615384, 0.9746889999999999], 
             UndirectedEdge[10, 438] -> 
             RGBColor[
              0.8978155000000001, 0.9192353076923077, 0.9040735000000002], 
             UndirectedEdge[39, 179] -> 
             RGBColor[
              0.6192293461538461, 0.7011293846153845, 0.9635964615384616], 
             UndirectedEdge[400, 414] -> 
             RGBColor[
              0.8798795384615385, 0.9042826153846153, 0.859617653846154], 
             UndirectedEdge[41, 191] -> 
             RGBColor[
              0.47128030769230755`, 0.5810416923076922, 0.9516869230769232], 
             UndirectedEdge[25, 96] -> 
             RGBColor[
              0.5443451923076924, 0.6372914615384616, 0.9587980769230768], 
             UndirectedEdge[106, 274] -> 
             RGBColor[
              0.7739195769230769, 0.8236708461538462, 0.9780052692307692], 
             UndirectedEdge[204, 363] -> 
             RGBColor[
              0.5405313846153846, 0.6357290384615384, 0.9578182307692308], 
             UndirectedEdge[99, 413] -> 
             RGBColor[
              0.7690816923076923, 0.8197326923076923, 0.9744841923076923], 
             UndirectedEdge[37, 118] -> 
             RGBColor[
              0.9420618846153845, 0.9516823846153846, 0.7306974615384617], 
             UndirectedEdge[411, 478] -> 
             RGBColor[0.8132754999999999, 0.854133, 0.9383155], 
             UndirectedEdge[300, 451] -> 
             RGBColor[
              0.6964478076923077, 0.7615969230769231, 0.9712546923076923], 
             UndirectedEdge[122, 233] -> 
             RGBColor[
              0.7097995384615384, 0.7722432307692307, 0.9725281923076923], 
             UndirectedEdge[97, 404] -> 
             RGBColor[0.9243408846153847, 0.9412578461538461, 0.94929], 
             UndirectedEdge[362, 498] -> 
             RGBColor[
              0.5974169230769231, 0.6834210769230769, 0.9618793076923077], 
             UndirectedEdge[121, 454] -> 
             RGBColor[
              0.7161274615384616, 0.7352138461538462, 0.6337168461538463], 
             UndirectedEdge[173, 417] -> 
             RGBColor[0.8113893076923077, 0.853452, 0.9782441153846153], 
             UndirectedEdge[36, 352] -> 
             RGBColor[
              0.7605678461538462, 0.8130245384615384, 0.9767317692307692], 
             UndirectedEdge[309, 337] -> 
             RGBColor[
              0.4896720384615384, 0.5965768461538461, 0.952967923076923], 
             UndirectedEdge[207, 456] -> 
             RGBColor[
              0.5987341538461537, 0.6851183846153845, 0.9615536923076923], 
             UndirectedEdge[95, 97] -> 
             RGBColor[
              0.835405153846154, 0.8717038461538462, 0.9841335769230769], 
             UndirectedEdge[185, 350] -> 
             RGBColor[
              0.6186983461538462, 0.6982106153846154, 0.9650094615384616], 
             UndirectedEdge[303, 435] -> 
             RGBColor[
              0.7243397692307693, 0.7845789999999999, 0.9731590769230769], 
             UndirectedEdge[14, 441] -> 
             RGBColor[
              0.8593843461538462, 0.8882716153846155, 0.8575748846153847], 
             UndirectedEdge[67, 147] -> 
             RGBColor[
              0.637090076923077, 0.7137457692307692, 0.9662904615384615], 
             UndirectedEdge[115, 419] -> 
             RGBColor[
              0.5648403846153847, 0.6533024615384615, 0.9608408461538461], 
             UndirectedEdge[113, 209] -> 
             RGBColor[
              0.8784702307692308, 0.9056580000000001, 0.9749009615384616], 
             UndirectedEdge[100, 121] -> 
             RGBColor[
              0.6528229615384615, 0.7261803076923077, 0.9678203846153846], 
             UndirectedEdge[39, 254] -> 
             RGBColor[
              0.6192293461538461, 0.7011293846153845, 0.9635964615384616], 
             UndirectedEdge[2, 339] -> 
             RGBColor[
              0.637090076923077, 0.7137457692307692, 0.9662904615384615], 
             UndirectedEdge[76, 436] -> 
             RGBColor[
              0.5974169230769231, 0.6834210769230769, 0.9618793076923077], 
             UndirectedEdge[121, 161] -> 
             RGBColor[
              0.5551093076923077, 0.6497017692307692, 0.9581193846153846], 
             UndirectedEdge[215, 430] -> 
             RGBColor[
              0.6807149230769232, 0.7491623846153845, 0.9697247692307692], 
             UndirectedEdge[100, 254] -> 
             RGBColor[
              0.7605678461538462, 0.8130245384615384, 0.9767317692307692], 
             UndirectedEdge[186, 389] -> 
             RGBColor[
              0.9474789615384616, 0.8312832307692308, 0.5571145384615386], 
             UndirectedEdge[197, 426] -> 
             RGBColor[
              0.6528229615384615, 0.7261803076923077, 0.9678203846153846], 
             UndirectedEdge[316, 378] -> 
             RGBColor[
              0.6746353846153845, 0.7438886153846154, 0.9695375384615385], 
             UndirectedEdge[185, 330] -> 
             RGBColor[
              0.5367175769230769, 0.6341666153846153, 0.9568383846153846], 
             UndirectedEdge[56, 166] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[38, 73] -> 
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461], 
             UndirectedEdge[97, 430] -> 
             RGBColor[
              0.7097995384615384, 0.7722432307692307, 0.9725281923076923], 
             UndirectedEdge[222, 372] -> 
             RGBColor[
              0.9131501923076923, 0.9329118461538461, 0.9682329230769231], 
             UndirectedEdge[137, 430] -> 
             RGBColor[
              0.6192293461538461, 0.7011293846153845, 0.9635964615384616], 
             UndirectedEdge[30, 355] -> 
             RGBColor[
              0.6205465769230769, 0.7028266923076922, 0.9632708461538462], 
             UndirectedEdge[111, 442] -> 
             RGBColor[
              0.8006230384615385, 0.8449634615384616, 0.9805522692307692], 
             UndirectedEdge[183, 408] -> 
             RGBColor[
              0.637090076923077, 0.7137457692307692, 0.9662904615384615], 
             UndirectedEdge[39, 283] -> 
             RGBColor[
              0.6964478076923077, 0.7615969230769231, 0.9712546923076923], 
             UndirectedEdge[244, 498] -> 
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153], 
             UndirectedEdge[259, 454] -> 
             RGBColor[
              0.8853579230769232, 0.870091076923077, 0.6487565384615386], 
             UndirectedEdge[17, 418] -> 
             RGBColor[
              0.7421560384615384, 0.7671442307692307, 0.6518129615384616], 
             UndirectedEdge[70, 391] -> 
             RGBColor[
              0.6165948846153846, 0.6977347692307692, 0.9642476923076924], 
             UndirectedEdge[18, 495] -> 
             RGBColor[0.6010684615384616, 0.681748, 0.9644135384615384], 
             UndirectedEdge[48, 95] -> 
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153], 
             UndirectedEdge[50, 92] -> 
             RGBColor[
              0.7076340769230769, 0.7677646153846154, 0.9301658846153846], 
             UndirectedEdge[118, 141] -> 
             RGBColor[
              0.9287101538461539, 0.941036076923077, 0.7294239615384617], 
             UndirectedEdge[373, 398] -> 
             RGBColor[
              0.26880169230769224`, 0.39985799999999994`, 0.9386192307692307],
              UndirectedEdge[218, 409] -> 
             RGBColor[
              0.3977133846153846, 0.5189010769230769, 0.946562923076923]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.7243397692307694, 0.7845790000000001, 0.9731590769230769], 
             316 -> RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 
             308 -> RGBColor[
              0.8911932307692307, 0.9160773076923077, 0.989484], 160 -> 
             RGBColor[
              0.3309878461538461, 0.46110676923076915`, 0.9423112307692307], 
             245 -> RGBColor[
              0.8063205384615386, 0.848623, 0.9813301538461539], 155 -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 425 -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 213 -> 
             RGBColor[
              0.5551093076923076, 0.6497017692307692, 0.9581193846153846], 
             352 -> RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 
             27 -> RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384],
              485 -> RGBColor[
              0.5987341538461539, 0.6851183846153847, 0.9615536923076923], 
             454 -> RGBColor[
              0.9643953076923077, 0.891559153846154, 0.3161829230769233], 367 -> 
             RGBColor[
              0.3977133846153846, 0.5189010769230769, 0.9465629230769231], 19 -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 164 -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             190 -> RGBColor[
              0.8760288461538461, 0.5299577692307693, 0.21826776923076924`], 
             103 -> RGBColor[0.950619923076923, 0.962693, 0.9684717692307693],
              138 -> RGBColor[
              0.6833493846153846, 0.752557, 0.9690735384615384], 416 -> 
             RGBColor[
              0.20888523076923077`, 0.33688199999999996`, 0.9352070769230769],
              476 -> RGBColor[
              0.4678596153846154, 0.5788685384615384, 0.9512507692307692], 
             291 -> RGBColor[
              0.6833493846153846, 0.752557, 0.9690735384615384], 28 -> 
             RGBColor[
              0.8654545384615385, 0.4819423076923079, 0.20944430769230774`], 
             337 -> RGBColor[
              0.5114844615384614, 0.6142851538461537, 0.9546850769230769], 
             195 -> RGBColor[0.9178966923076922, 0.937369923076923, 0.992031],
              114 -> RGBColor[
              0.5551093076923076, 0.6497017692307692, 0.9581193846153846], 
             479 -> RGBColor[
              0.8063205384615386, 0.848623, 0.9813301538461539], 93 -> 
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461], 34 -> 
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937], 161 -> 
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988], 22 -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 124 -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 84 -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 46 -> 
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988], 241 -> 
             RGBColor[
              0.8760288461538461, 0.5299577692307693, 0.21826776923076924`], 
             185 -> RGBColor[
              0.4310761538461538, 0.5477982307692307, 0.9486887692307693], 
             426 -> RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 
             390 -> RGBColor[0.984192, 0.987731, 0.911643], 121 -> 
             RGBColor[
              0.4678596153846154, 0.5788685384615384, 0.9512507692307692], 
             322 -> RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             488 -> RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 
             126 -> RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 
             433 -> RGBColor[
              0.9948544615384616, 0.9914025384615385, 0.6813180769230774], 
             236 -> RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 
             78 -> RGBColor[
              0.4310761538461538, 0.5477982307692307, 0.9486887692307693], 
             376 -> RGBColor[
              0.9935718461538462, 0.9886591538461539, 0.5417133076923077], 
             458 -> RGBColor[
              0.6423589999999999, 0.7205349999999999, 0.964988], 254 -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 290 -> 
             RGBColor[
              0.5114844615384614, 0.6142851538461537, 0.9546850769230769], 
             251 -> RGBColor[
              0.6423589999999999, 0.7205349999999999, 0.964988], 165 -> 
             RGBColor[0.950619923076923, 0.962693, 0.9684717692307693], 460 -> 
             RGBColor[
              0.4310761538461538, 0.5477982307692307, 0.9486887692307693], 
             100 -> RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 
             235 -> RGBColor[
              0.3977133846153846, 0.5189010769230769, 0.9465629230769231], 70 -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             234 -> RGBColor[
              0.8063205384615386, 0.848623, 0.9813301538461539], 435 -> 
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988], 257 -> 
             RGBColor[
              0.9643953076923077, 0.891559153846154, 0.3161829230769233], 135 -> 
             RGBColor[0.9178966923076922, 0.937369923076923, 0.992031], 265 -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 111 -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 497 -> 
             RGBColor[
              0.4310761538461538, 0.5477982307692307, 0.9486887692307693], 
             481 -> RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076922], 
             381 -> RGBColor[
              0.6833493846153846, 0.752557, 0.9690735384615384], 182 -> 
             RGBColor[0.950619923076923, 0.962693, 0.9684717692307693], 188 -> 
             RGBColor[
              0.4310761538461538, 0.5477982307692307, 0.9486887692307693], 
             154 -> RGBColor[
              0.9201457692307693, 0.7211116153846153, 0.2546056153846154], 
             336 -> RGBColor[
              0.6833493846153846, 0.752557, 0.9690735384615384], 463 -> 
             RGBColor[
              0.9201457692307693, 0.7211116153846153, 0.2546056153846154], 
             315 -> RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             368 -> RGBColor[
              0.4678596153846154, 0.5788685384615384, 0.9512507692307692], 
             269 -> RGBColor[
              0.9394292307692307, 0.954347, 0.9874146923076923], 208 -> 
             RGBColor[
              0.9440239230769232, 0.8157805384615386, 0.2738185384615385], 86 -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 119 -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 436 -> 
             RGBColor[
              0.5114844615384614, 0.6142851538461537, 0.9546850769230769], 
             377 -> RGBColor[
              0.8063205384615386, 0.848623, 0.9813301538461539], 140 -> 
             RGBColor[0.9394292307692307, 0.954347, 0.9874146923076923], 85 -> 
             RGBColor[0.9178966923076922, 0.937369923076923, 0.992031], 351 -> 
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484], 443 -> 
             RGBColor[
              0.9728276153846154, 0.9200033076923078, 0.34894084615384624`], 
             242 -> RGBColor[
              0.8063205384615386, 0.848623, 0.9813301538461539], 117 -> 
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484], 47 -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 451 -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 81 -> 
             RGBColor[
              0.3643506153846154, 0.49000392307692303`, 0.9444370769230769], 
             275 -> RGBColor[
              0.6833493846153846, 0.752557, 0.9690735384615384], 23 -> 
             RGBColor[
              0.4678596153846154, 0.5788685384615384, 0.9512507692307692], 
             328 -> RGBColor[
              0.6423589999999999, 0.7205349999999999, 0.964988], 418 -> 
             RGBColor[
              0.9728276153846154, 0.9200033076923078, 0.34894084615384624`], 
             110 -> RGBColor[
              0.9944289230769231, 0.9919642307692308, 0.7419906923076924], 6 -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             218 -> RGBColor[
              0.4310761538461538, 0.5477982307692307, 0.9486887692307693], 
             108 -> RGBColor[
              0.8911932307692307, 0.9160773076923077, 0.989484], 297 -> 
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988], 487 -> 
             RGBColor[
              0.9948544615384616, 0.9914025384615385, 0.6813180769230774], 
             464 -> RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.8268168461538464], 
             157 -> RGBColor[
              0.5551093076923076, 0.6497017692307692, 0.9581193846153846], 
             441 -> RGBColor[
              0.9944289230769231, 0.9919642307692308, 0.7419906923076924], 
             354 -> RGBColor[
              0.9728276153846154, 0.9200033076923078, 0.34894084615384624`], 
             385 -> RGBColor[
              0.5987341538461539, 0.6851183846153847, 0.9615536923076923], 
             270 -> RGBColor[
              0.8063205384615386, 0.848623, 0.9813301538461539], 392 -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 33 -> 
             RGBColor[
              0.7243397692307694, 0.7845790000000001, 0.9731590769230769], 
             252 -> RGBColor[
              0.6423589999999999, 0.7205349999999999, 0.964988], 394 -> 
             RGBColor[
              0.5987341538461539, 0.6851183846153847, 0.9615536923076923], 
             260 -> RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 
             159 -> RGBColor[
              0.5551093076923076, 0.6497017692307692, 0.9581193846153846], 
             183 -> RGBColor[
              0.8063205384615386, 0.848623, 0.9813301538461539], 99 -> 
             RGBColor[0.9394292307692307, 0.954347, 0.9874146923076923], 329 -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 309 -> 
             RGBColor[
              0.4678596153846154, 0.5788685384615384, 0.9512507692307692], 17 -> 
             RGBColor[
              0.5114844615384614, 0.6142851538461537, 0.9546850769230769], 
             349 -> RGBColor[
              0.8063205384615386, 0.848623, 0.9813301538461539], 495 -> 
             RGBColor[
              0.3643506153846154, 0.49000392307692303`, 0.9444370769230769], 
             347 -> RGBColor[
              0.6833493846153846, 0.752557, 0.9690735384615384], 340 -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 404 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 277 -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 104 -> 
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988], 79 -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 327 -> 
             RGBColor[
              0.9948544615384616, 0.9914025384615385, 0.6813180769230774], 
             191 -> RGBColor[
              0.4310761538461538, 0.5477982307692307, 0.9486887692307693], 50 -> 
             RGBColor[
              0.4310761538461538, 0.5477982307692307, 0.9486887692307693], 
             225 -> RGBColor[
              0.9394292307692307, 0.954347, 0.9874146923076923], 405 -> 
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988], 61 -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             196 -> RGBColor[
              0.9394292307692307, 0.954347, 0.9874146923076923], 1 -> 
             RGBColor[
              0.5114844615384614, 0.6142851538461537, 0.9546850769230769], 
             263 -> RGBColor[
              0.9394292307692307, 0.954347, 0.9874146923076923], 201 -> 
             RGBColor[
              0.5551093076923076, 0.6497017692307692, 0.9581193846153846], 
             371 -> RGBColor[
              0.9948544615384616, 0.9914025384615385, 0.6813180769230774], 
             293 -> RGBColor[
              0.4678596153846154, 0.5788685384615384, 0.9512507692307692], 
             362 -> RGBColor[
              0.6833493846153846, 0.752557, 0.9690735384615384], 184 -> 
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988], 106 -> 
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937], 206 -> 
             RGBColor[
              0.4678596153846154, 0.5788685384615384, 0.9512507692307692], 
             358 -> RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             247 -> RGBColor[
              0.8644897692307693, 0.8947846923076923, 0.986937], 220 -> 
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461], 407 -> 
             RGBColor[
              0.4310761538461538, 0.5477982307692307, 0.9486887692307693], 
             107 -> RGBColor[
              0.5987341538461539, 0.6851183846153847, 0.9615536923076923], 
             375 -> RGBColor[
              0.9948544615384616, 0.9914025384615385, 0.6813180769230774], 
             131 -> 
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484], 411 -> 
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988], 462 -> 
             RGBColor[
              0.5987341538461539, 0.6851183846153847, 0.9615536923076923], 
             127 -> RGBColor[
              0.9728276153846154, 0.9200033076923078, 0.34894084615384624`], 
             210 -> RGBColor[
              0.5114844615384614, 0.6142851538461537, 0.9546850769230769], 
             357 -> RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076922], 
             181 -> RGBColor[
              0.5987341538461539, 0.6851183846153847, 0.9615536923076923], 
             194 -> RGBColor[0.950619923076923, 0.962693, 0.9684717692307693],
              440 -> RGBColor[
              0.5114844615384614, 0.6142851538461537, 0.9546850769230769], 
             490 -> RGBColor[
              0.5114844615384614, 0.6142851538461537, 0.9546850769230769], 
             118 -> RGBColor[
              0.9929305384615384, 0.9872874615384616, 0.47191092307692334`], 
             348 -> RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             276 -> RGBColor[
              0.7243397692307694, 0.7845790000000001, 0.9731590769230769], 
             305 -> RGBColor[
              0.5551093076923076, 0.6497017692307692, 0.9581193846153846], 
             343 -> RGBColor[
              0.9948544615384616, 0.9914025384615385, 0.6813180769230774], 
             280 -> RGBColor[
              0.9394292307692307, 0.954347, 0.9874146923076923], 474 -> 
             RGBColor[
              0.3977133846153846, 0.5189010769230769, 0.9465629230769231], 
             189 -> RGBColor[
              0.7243397692307694, 0.7845790000000001, 0.9731590769230769], 
             168 -> RGBColor[
              0.5551093076923076, 0.6497017692307692, 0.9581193846153846], 
             363 -> RGBColor[
              0.6833493846153846, 0.752557, 0.9690735384615384], 41 -> 
             RGBColor[
              0.5114844615384614, 0.6142851538461537, 0.9546850769230769], 14 -> 
             RGBColor[
              0.7243397692307694, 0.7845790000000001, 0.9731590769230769], 77 -> 
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484], 51 -> 
             RGBColor[
              0.9948544615384616, 0.9914025384615385, 0.6813180769230774], 
             438 -> RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.8268168461538464], 
             179 -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 467 -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 223 -> 
             RGBColor[
              0.9867512307692308, 0.9887893076923077, 0.8692299230769233], 
             456 -> RGBColor[
              0.5551093076923076, 0.6497017692307692, 0.9581193846153846], 
             323 -> RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             500 -> RGBColor[
              0.9867512307692308, 0.9887893076923077, 0.8692299230769233], 
             478 -> RGBColor[0.984192, 0.987731, 0.911643], 292 -> 
             RGBColor[0.950619923076923, 0.962693, 0.9684717692307693], 491 -> 
             RGBColor[
              0.9944289230769231, 0.9919642307692308, 0.7419906923076924], 
             396 -> RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 
             321 -> RGBColor[
              0.5551093076923076, 0.6497017692307692, 0.9581193846153846], 
             143 -> RGBColor[
              0.7243397692307694, 0.7845790000000001, 0.9731590769230769], 
             112 -> RGBColor[
              0.4310761538461538, 0.5477982307692307, 0.9486887692307693], 
             197 -> RGBColor[
              0.4678596153846154, 0.5788685384615384, 0.9512507692307692], 
             421 -> RGBColor[0.2388434615384615, 0.36837, 0.9369131538461538],
              54 -> RGBColor[
              0.3977133846153846, 0.5189010769230769, 0.9465629230769231], 71 -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 177 -> 
             RGBColor[
              0.4310761538461538, 0.5477982307692307, 0.9486887692307693], 
             158 -> RGBColor[
              0.8644897692307693, 0.8947846923076923, 0.986937], 226 -> 
             RGBColor[
              0.3643506153846154, 0.49000392307692303`, 0.9444370769230769], 
             432 -> RGBColor[
              0.6833493846153846, 0.752557, 0.9690735384615384], 350 -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 203 -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 475 -> 
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988], 115 -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             173 -> RGBColor[
              0.9394292307692307, 0.954347, 0.9874146923076923], 212 -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             129 -> RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 
             279 -> RGBColor[
              0.7243397692307694, 0.7845790000000001, 0.9731590769230769], 26 -> 
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461], 40 -> 
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937], 146 -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             386 -> RGBColor[
              0.4678596153846154, 0.5788685384615384, 0.9512507692307692], 
             192 -> RGBColor[
              0.5987341538461539, 0.6851183846153847, 0.9615536923076923], 
             300 -> RGBColor[
              0.5551093076923076, 0.6497017692307692, 0.9581193846153846], 
             221 -> RGBColor[
              0.8457631538461539, 0.3527612307692307, 0.19145615384615383`], 
             62 -> RGBColor[
              0.5551093076923076, 0.6497017692307692, 0.9581193846153846], 
             286 -> RGBColor[
              0.5987341538461539, 0.6851183846153847, 0.9615536923076923], 
             472 -> RGBColor[
              0.6833493846153846, 0.752557, 0.9690735384615384], 152 -> 
             RGBColor[
              0.5987341538461539, 0.6851183846153847, 0.9615536923076923], 64 -> 
             RGBColor[
              0.4678596153846154, 0.5788685384615384, 0.9512507692307692], 
             307 -> RGBColor[
              0.6423589999999999, 0.7205349999999999, 0.964988], 37 -> 
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484], 148 -> 
             RGBColor[
              0.298759923076923, 0.4313459999999999, 0.9403253076923077], 261 -> 
             RGBColor[
              0.9948544615384616, 0.9914025384615385, 0.6813180769230774], 
             387 -> RGBColor[
              0.6833493846153846, 0.752557, 0.9690735384615384], 15 -> 
             RGBColor[0.955963, 0.863115, 0.283425], 136 -> 
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988], 198 -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 63 -> 
             RGBColor[
              0.3977133846153846, 0.5189010769230769, 0.9465629230769231], 
             444 -> RGBColor[
              0.6423589999999999, 0.7205349999999999, 0.964988], 310 -> 
             RGBColor[
              0.5551093076923076, 0.6497017692307692, 0.9581193846153846], 
             171 -> 
             RGBColor[
              0.4678596153846154, 0.5788685384615384, 0.9512507692307692], 
             395 -> RGBColor[
              0.8063205384615386, 0.848623, 0.9813301538461539], 311 -> 
             RGBColor[
              0.7243397692307694, 0.7845790000000001, 0.9731590769230769], 
             353 -> RGBColor[
              0.5114844615384614, 0.6142851538461537, 0.9546850769230769], 59 -> 
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484], 397 -> 
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461], 229 -> 
             RGBColor[
              0.5551093076923076, 0.6497017692307692, 0.9581193846153846], 
             102 -> RGBColor[
              0.4678596153846154, 0.5788685384615384, 0.9512507692307692], 
             453 -> RGBColor[
              0.9394292307692307, 0.954347, 0.9874146923076923], 299 -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 128 -> 
             RGBColor[0.9178966923076922, 0.937369923076923, 0.992031], 12 -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.8268168461538464], 
             222 -> RGBColor[
              0.8644897692307693, 0.8947846923076923, 0.986937], 483 -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 92 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 271 -> 
             RGBColor[
              0.7243397692307694, 0.7845790000000001, 0.9731590769230769], 
             361 -> RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             344 -> RGBColor[0.9178966923076922, 0.937369923076923, 0.992031],
              132 -> RGBColor[
              0.8644897692307693, 0.8947846923076923, 0.986937], 80 -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 324 -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 244 -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 150 -> 
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937], 125 -> 
             RGBColor[
              0.3309878461538461, 0.46110676923076915`, 0.9423112307692307], 
             258 -> RGBColor[
              0.4678596153846154, 0.5788685384615384, 0.9512507692307692], 
             133 -> RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             469 -> RGBColor[0.9178966923076922, 0.937369923076923, 0.992031],
              255 -> 
             RGBColor[0.9178966923076922, 0.937369923076923, 0.992031], 408 -> 
             RGBColor[
              0.4678596153846154, 0.5788685384615384, 0.9512507692307692], 
             326 -> RGBColor[0.9178966923076922, 0.937369923076923, 0.992031],
              176 -> RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.8268168461538464], 
             230 -> RGBColor[
              0.4310761538461538, 0.5477982307692307, 0.9486887692307693], 
             274 -> RGBColor[
              0.6833493846153846, 0.752557, 0.9690735384615384], 87 -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 439 -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 130 -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 35 -> 
             RGBColor[0.950619923076923, 0.962693, 0.9684717692307693], 379 -> 
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461], 31 -> 
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988], 18 -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 24 -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 151 -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 137 -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 330 -> 
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988], 296 -> 
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484], 266 -> 
             RGBColor[
              0.4310761538461538, 0.5477982307692307, 0.9486887692307693], 
             302 -> RGBColor[
              0.6833493846153846, 0.752557, 0.9690735384615384], 442 -> 
             RGBColor[0.9178966923076922, 0.937369923076923, 0.992031], 283 -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 388 -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 284 -> 
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988], 417 -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 318 -> 
             RGBColor[
              0.8760288461538461, 0.5299577692307693, 0.21826776923076924`], 
             413 -> RGBColor[
              0.5987341538461539, 0.6851183846153847, 0.9615536923076923], 
             238 -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 72 -> 
             RGBColor[
              0.4310761538461538, 0.5477982307692307, 0.9486887692307693], 
             437 -> RGBColor[
              0.6423589999999999, 0.7205349999999999, 0.964988], 288 -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             382 -> RGBColor[
              0.7243397692307694, 0.7845790000000001, 0.9731590769230769], 
             461 -> RGBColor[
              0.5114844615384614, 0.6142851538461537, 0.9546850769230769], 
             389 -> RGBColor[
              0.9867512307692308, 0.9887893076923077, 0.8692299230769233], 
             172 -> RGBColor[
              0.5987341538461539, 0.6851183846153847, 0.9615536923076923], 
             447 -> RGBColor[0.817319, 0.134127, 0.164218], 243 -> 
             RGBColor[
              0.4678596153846154, 0.5788685384615384, 0.9512507692307692], 
             410 -> RGBColor[
              0.4310761538461538, 0.5477982307692307, 0.9486887692307693], 88 -> 
             RGBColor[
              0.9944289230769231, 0.9919642307692308, 0.7419906923076924], 
             273 -> RGBColor[0.950619923076923, 0.962693, 0.9684717692307693],
              477 -> RGBColor[
              0.6423589999999999, 0.7205349999999999, 0.964988], 202 -> 
             RGBColor[
              0.5987341538461539, 0.6851183846153847, 0.9615536923076923], 
             393 -> RGBColor[
              0.3977133846153846, 0.5189010769230769, 0.9465629230769231], 98 -> 
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484], 30 -> 
             RGBColor[
              0.5987341538461539, 0.6851183846153847, 0.9615536923076923], 
             116 -> RGBColor[
              0.8644897692307693, 0.8947846923076923, 0.986937], 373 -> 
             RGBColor[0.2388434615384615, 0.36837, 0.9369131538461538], 434 -> 
             RGBColor[
              0.9948544615384616, 0.9914025384615385, 0.6813180769230774], 
             401 -> RGBColor[
              0.7243397692307694, 0.7845790000000001, 0.9731590769230769], 
             240 -> RGBColor[0.817319, 0.134127, 0.164218], 480 -> 
             RGBColor[
              0.5987341538461539, 0.6851183846153847, 0.9615536923076923], 
             403 -> RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 
             317 -> RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 
             429 -> RGBColor[
              0.6833493846153846, 0.752557, 0.9690735384615384], 391 -> 
             RGBColor[
              0.4678596153846154, 0.5788685384615384, 0.9512507692307692], 73 -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 303 -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 449 -> 
             RGBColor[
              0.9440239230769232, 0.8157805384615386, 0.2738185384615385], 29 -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             360 -> RGBColor[
              0.4310761538461538, 0.5477982307692307, 0.9486887692307693], 
             320 -> RGBColor[
              0.5987341538461539, 0.6851183846153847, 0.9615536923076923], 
             482 -> RGBColor[
              0.8063205384615386, 0.848623, 0.9813301538461539], 75 -> 
             RGBColor[
              0.9944289230769231, 0.9919642307692308, 0.7419906923076924], 
             200 -> RGBColor[
              0.9944289230769231, 0.9919642307692308, 0.7419906923076924], 
             301 -> RGBColor[
              0.5114844615384614, 0.6142851538461537, 0.9546850769230769], 
             156 -> RGBColor[0.9178966923076922, 0.937369923076923, 0.992031],
              25 -> RGBColor[
              0.7243397692307694, 0.7845790000000001, 0.9731590769230769], 38 -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 365 -> 
             RGBColor[
              0.3977133846153846, 0.5189010769230769, 0.9465629230769231], 
             380 -> RGBColor[
              0.5114844615384614, 0.6142851538461537, 0.9546850769230769], 
             370 -> RGBColor[
              0.9394292307692307, 0.954347, 0.9874146923076923], 3 -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 57 -> 
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988], 227 -> 
             RGBColor[
              0.7243397692307694, 0.7845790000000001, 0.9731590769230769], 
             494 -> RGBColor[
              0.5551093076923076, 0.6497017692307692, 0.9581193846153846], 39 -> 
             RGBColor[
              0.5551093076923076, 0.6497017692307692, 0.9581193846153846], 
             424 -> RGBColor[
              0.6833493846153846, 0.752557, 0.9690735384615384], 109 -> 
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461], 465 -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 256 -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             457 -> RGBColor[
              0.6423589999999999, 0.7205349999999999, 0.964988], 339 -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 420 -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 287 -> 
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484], 239 -> 
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988], 427 -> 
             RGBColor[
              0.9918696923076923, 0.990905923076923, 0.7844037692307693], 285 -> 
             RGBColor[0.9178966923076922, 0.937369923076923, 0.992031], 345 -> 
             RGBColor[
              0.9944289230769231, 0.9919642307692308, 0.7419906923076924], 
             366 -> RGBColor[
              0.9730013076923076, 0.979385, 0.9305859230769231], 216 -> 
             RGBColor[
              0.7243397692307694, 0.7845790000000001, 0.9731590769230769], 21 -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 355 -> 
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988], 175 -> 
             RGBColor[
              0.5551093076923076, 0.6497017692307692, 0.9581193846153846], 7 -> 
             RGBColor[
              0.4678596153846154, 0.5788685384615384, 0.9512507692307692], 13 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 294 -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 412 -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 193 -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 60 -> 
             RGBColor[
              0.3977133846153846, 0.5189010769230769, 0.9465629230769231], 65 -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             448 -> RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 
             69 -> RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             217 -> RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 
             214 -> RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 
             170 -> RGBColor[
              0.4678596153846154, 0.5788685384615384, 0.9512507692307692], 
             359 -> RGBColor[
              0.3643506153846154, 0.49000392307692303`, 0.9444370769230769], 
             74 -> RGBColor[0.9178966923076922, 0.937369923076923, 0.992031], 
             246 -> RGBColor[
              0.6833493846153846, 0.752557, 0.9690735384615384], 264 -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 278 -> 
             RGBColor[
              0.4310761538461538, 0.5477982307692307, 0.9486887692307693], 45 -> 
             RGBColor[
              0.5987341538461539, 0.6851183846153847, 0.9615536923076923], 
             492 -> RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             306 -> RGBColor[0.178927, 0.305394, 0.933501], 237 -> 
             RGBColor[
              0.5551093076923076, 0.6497017692307692, 0.9581193846153846], 
             228 -> RGBColor[0.984192, 0.987731, 0.911643], 180 -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 383 -> 
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937], 53 -> 
             RGBColor[
              0.9918696923076923, 0.990905923076923, 0.7844037692307693], 304 -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 48 -> 
             RGBColor[
              0.5114844615384614, 0.6142851538461537, 0.9546850769230769], 5 -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 101 -> 
             RGBColor[
              0.7243397692307694, 0.7845790000000001, 0.9731590769230769], 
             333 -> RGBColor[
              0.9394292307692307, 0.954347, 0.9874146923076923], 267 -> 
             RGBColor[
              0.3977133846153846, 0.5189010769230769, 0.9465629230769231], 
             120 -> RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             147 -> RGBColor[
              0.4678596153846154, 0.5788685384615384, 0.9512507692307692], 89 -> 
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988], 43 -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 199 -> 
             RGBColor[
              0.5551093076923076, 0.6497017692307692, 0.9581193846153846], 
             268 -> RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             169 -> RGBColor[
              0.9618106153846153, 0.971039, 0.9495288461538461], 20 -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 4 -> 
             RGBColor[
              0.5551093076923076, 0.6497017692307692, 0.9581193846153846], 
             167 -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.8268168461538464], 
             431 -> RGBColor[0.9178966923076922, 0.937369923076923, 0.992031],
              142 -> RGBColor[
              0.9730013076923076, 0.979385, 0.9305859230769231], 16 -> 
             RGBColor[
              0.3977133846153846, 0.5189010769230769, 0.9465629230769231], 
             414 -> RGBColor[
              0.9944289230769231, 0.9919642307692308, 0.7419906923076924], 
             281 -> RGBColor[
              0.7243397692307694, 0.7845790000000001, 0.9731590769230769], 
             289 -> RGBColor[
              0.9618106153846153, 0.971039, 0.9495288461538461], 398 -> 
             RGBColor[
              0.298759923076923, 0.4313459999999999, 0.9403253076923077], 178 -> 
             RGBColor[
              0.9867512307692308, 0.9887893076923077, 0.8692299230769233], 58 -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 186 -> 
             RGBColor[
              0.9082066923076924, 0.673777153846154, 0.2449991538461539], 122 -> 
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937], 249 -> 
             RGBColor[
              0.3643506153846154, 0.49000392307692303`, 0.9444370769230769], 
             113 -> RGBColor[
              0.8063205384615386, 0.848623, 0.9813301538461539], 52 -> 
             RGBColor[0.984192, 0.987731, 0.911643], 409 -> 
             RGBColor[
              0.3643506153846154, 0.49000392307692303`, 0.9444370769230769], 
             187 -> RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             259 -> RGBColor[
              0.8063205384615386, 0.848623, 0.9813301538461539], 42 -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             134 -> RGBColor[
              0.3309878461538461, 0.46110676923076915`, 0.9423112307692307], 
             470 -> RGBColor[
              0.5551093076923076, 0.6497017692307692, 0.9581193846153846], 
             313 -> RGBColor[
              0.9918696923076923, 0.990905923076923, 0.7844037692307693], 248 -> 
             RGBColor[
              0.3977133846153846, 0.5189010769230769, 0.9465629230769231], 
             174 -> RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 
             215 -> RGBColor[
              0.8063205384615386, 0.848623, 0.9813301538461539], 399 -> 
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937], 422 -> 
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988], 83 -> 
             RGBColor[
              0.7243397692307694, 0.7845790000000001, 0.9731590769230769], 95 -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 166 -> 
             RGBColor[
              0.7243397692307694, 0.7845790000000001, 0.9731590769230769], 
             384 -> RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 
             233 -> RGBColor[
              0.5551093076923076, 0.6497017692307692, 0.9581193846153846], 
             295 -> RGBColor[
              0.5114844615384614, 0.6142851538461537, 0.9546850769230769], 
             499 -> RGBColor[
              0.8911932307692307, 0.9160773076923077, 0.989484], 141 -> 
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937], 319 -> 
             RGBColor[
              0.4310761538461538, 0.5477982307692307, 0.9486887692307693], 
             205 -> RGBColor[
              0.3977133846153846, 0.5189010769230769, 0.9465629230769231], 
             468 -> RGBColor[
              0.4678596153846154, 0.5788685384615384, 0.9512507692307692], 
             486 -> RGBColor[
              0.9935718461538462, 0.9886591538461539, 0.5417133076923077], 
             224 -> RGBColor[
              0.8971774615384616, 0.6259886923076927, 0.23591469230769238`], 
             231 -> RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             332 -> RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076922], 68 -> 
             RGBColor[0.9178966923076922, 0.937369923076923, 0.992031], 484 -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 10 -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 250 -> 
             RGBColor[
              0.4310761538461538, 0.5477982307692307, 0.9486887692307693], 
             282 -> RGBColor[
              0.6833493846153846, 0.752557, 0.9690735384615384], 374 -> 
             RGBColor[
              0.9867512307692308, 0.9887893076923077, 0.8692299230769233], 
             232 -> RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             489 -> RGBColor[
              0.4678596153846154, 0.5788685384615384, 0.9512507692307692], 
             253 -> RGBColor[
              0.5551093076923076, 0.6497017692307692, 0.9581193846153846], 
             459 -> RGBColor[
              0.4310761538461538, 0.5477982307692307, 0.9486887692307693], 
             415 -> 
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988], 55 -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 446 -> 
             RGBColor[
              0.9948544615384616, 0.9914025384615385, 0.6813180769230774], 
             325 -> RGBColor[
              0.5987341538461539, 0.6851183846153847, 0.9615536923076923], 91 -> 
             RGBColor[
              0.9948544615384616, 0.9914025384615385, 0.6813180769230774], 
             450 -> RGBColor[
              0.6423589999999999, 0.7205349999999999, 0.964988], 423 -> 
             RGBColor[
              0.9893104615384615, 0.9898476153846154, 0.8268168461538464], 
             105 -> RGBColor[
              0.8063205384615386, 0.848623, 0.9813301538461539], 36 -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 123 -> 
             RGBColor[
              0.5114844615384614, 0.6142851538461537, 0.9546850769230769], 94 -> 
             RGBColor[
              0.8760288461538461, 0.5299577692307693, 0.21826776923076924`], 
             473 -> RGBColor[
              0.6833493846153846, 0.752557, 0.9690735384615384], 312 -> 
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 96 -> 
             RGBColor[
              0.3643506153846154, 0.49000392307692303`, 0.9444370769230769], 
             496 -> RGBColor[
              0.4310761538461538, 0.5477982307692307, 0.9486887692307693], 2 -> 
             RGBColor[
              0.4678596153846154, 0.5788685384615384, 0.9512507692307692], 
             262 -> RGBColor[
              0.9618106153846153, 0.971039, 0.9495288461538461], 272 -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 97 -> 
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937], 372 -> 
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461], 356 -> 
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937], 402 -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 455 -> 
             RGBColor[
              0.5114844615384614, 0.6142851538461537, 0.9546850769230769], 
             428 -> RGBColor[
              0.4310761538461538, 0.5477982307692307, 0.9486887692307693], 
             346 -> RGBColor[
              0.9394292307692307, 0.954347, 0.9874146923076923], 341 -> 
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937], 209 -> 
             RGBColor[0.950619923076923, 0.962693, 0.9684717692307693], 498 -> 
             RGBColor[
              0.5114844615384614, 0.6142851538461537, 0.9546850769230769], 
             378 -> RGBColor[
              0.5114844615384614, 0.6142851538461537, 0.9546850769230769], 
             419 -> RGBColor[
              0.3643506153846154, 0.49000392307692303`, 0.9444370769230769], 
             66 -> RGBColor[
              0.9320848461538462, 0.7684460769230773, 0.264212076923077], 139 -> 
             RGBColor[
              0.9942131538461538, 0.9900308461538462, 0.6115156923076922], 56 -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             335 -> RGBColor[
              0.298759923076923, 0.4313459999999999, 0.9403253076923077], 314 -> 
             RGBColor[
              0.5114844615384614, 0.6142851538461537, 0.9546850769230769], 
             144 -> RGBColor[
              0.5551093076923076, 0.6497017692307692, 0.9581193846153846], 
             298 -> RGBColor[
              0.5114844615384614, 0.6142851538461537, 0.9546850769230769], 
             204 -> RGBColor[
              0.3977133846153846, 0.5189010769230769, 0.9465629230769231], 
             452 -> RGBColor[
              0.298759923076923, 0.4313459999999999, 0.9403253076923077], 466 -> 
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484], 207 -> 
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988], 334 -> 
             RGBColor[
              0.5551093076923076, 0.6497017692307692, 0.9581193846153846], 
             149 -> RGBColor[0.8377863076923078, 0.873492076923077, 0.98439], 
             219 -> RGBColor[
              0.8971774615384616, 0.6259886923076927, 0.23591469230769238`], 
             400 -> RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 9 -> 
             RGBColor[
              0.4678596153846154, 0.5788685384615384, 0.9512507692307692], 11 -> 
             RGBColor[
              0.5114844615384614, 0.6142851538461537, 0.9546850769230769], 44 -> 
             RGBColor[
              0.5551093076923076, 0.6497017692307692, 0.9581193846153846], 
             153 -> RGBColor[
              0.8644897692307693, 0.8947846923076923, 0.986937], 471 -> 
             RGBColor[
              0.7243397692307694, 0.7845790000000001, 0.9731590769230769], 
             406 -> RGBColor[
              0.8063205384615386, 0.848623, 0.9813301538461539], 32 -> 
             RGBColor[
              0.9948544615384616, 0.9914025384615385, 0.6813180769230774], 
             162 -> RGBColor[
              0.8063205384615386, 0.848623, 0.9813301538461539], 493 -> 
             RGBColor[0.9730013076923076, 0.979385, 0.9305859230769231], 90 -> 
             RGBColor[
              0.3309878461538461, 0.46110676923076915`, 0.9423112307692307], 
             331 -> RGBColor[
              0.5551093076923076, 0.6497017692307692, 0.9581193846153846], 8 -> 
             RGBColor[
              0.4310761538461538, 0.5477982307692307, 0.9486887692307693], 
             364 -> RGBColor[0.955963, 0.863115, 0.283425], 342 -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 
             163 -> RGBColor[
              0.3643506153846154, 0.49000392307692303`, 0.9444370769230769], 
             49 -> RGBColor[
              0.8866031538461538, 0.5779732307692307, 0.22709123076923077`], 
             338 -> RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 76 -> 
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384], 369 -> 
             RGBColor[0.9178966923076922, 0.937369923076923, 0.992031], 445 -> 
             RGBColor[
              0.5114844615384614, 0.6142851538461537, 0.9546850769230769], 82 -> 
             RGBColor[
              0.7653301538461539, 0.8166009999999999, 0.9772446153846154], 67 -> 
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539], 430 -> 
             RGBColor[
              0.5551093076923076, 0.6497017692307692, 0.9581193846153846], 
             211 -> RGBColor[
              0.9320848461538462, 0.7684460769230773, 0.264212076923077]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9V3c41W/cPkZ2skfWMY5xzsFxzjFCvnekUipFSBqEZKVlFlIpoUVlJUVG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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 54}], {
             RGBColor[0.45459892307692296`, 0.5665931153846153, 0.950624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 70}], {
             RGBColor[
             0.6384073076923076, 0.7154430769230768, 0.9659648461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 84}], {
             RGBColor[
             0.6746353846153845, 0.7438886153846154, 0.9695375384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 131}], {
             RGBColor[
             0.7013388461538461, 0.7651812307692307, 0.9720845384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 135}], {
             RGBColor[
             0.7146905769230768, 0.7758275384615383, 0.9733580384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 147}], {
             RGBColor[
             0.4896720384615384, 0.5965768461538461, 0.952967923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 170}], {
             RGBColor[
             0.4896720384615384, 0.5965768461538461, 0.952967923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 171}], {
             RGBColor[
             0.4896720384615384, 0.5965768461538461, 0.952967923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 265}], {
             RGBColor[
             0.6746353846153845, 0.7438886153846154, 0.9695375384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 266}], {
             RGBColor[
             0.47128030769230755`, 0.5810416923076922, 0.9516869230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 374}], {
             RGBColor[
             0.7491178461538461, 0.8015372307692307, 0.9119575000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 385}], {
             RGBColor[
             0.5551093076923077, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 391}], {
             RGBColor[
             0.4896720384615384, 0.5965768461538461, 0.952967923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 433}], {
             RGBColor[
             0.7531694615384614, 0.8028438461538461, 0.8180015769230772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 47}], {
             RGBColor[
             0.6528229615384615, 0.7261803076923077, 0.9678203846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 54}], {
             RGBColor[
             0.43278649999999996`, 0.5488848076923076, 0.9489068461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 55}], {
             RGBColor[
             0.6528229615384615, 0.7261803076923077, 0.9678203846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 230}], {
             RGBColor[
             0.44946788461538456`, 0.5633333846153845, 0.9499697692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 242}], {
             RGBColor[
             0.637090076923077, 0.7137457692307692, 0.9662904615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 250}], {
             RGBColor[
             0.44946788461538456`, 0.5633333846153845, 0.9499697692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 339}], {
             RGBColor[
             0.637090076923077, 0.7137457692307692, 0.9662904615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 365}], {
             RGBColor[
             0.43278649999999996`, 0.5488848076923076, 0.9489068461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 8}], {
             RGBColor[
             0.6344312307692308, 0.7106451538461538, 0.9665393846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 31}], {
             RGBColor[
             0.7400726538461538, 0.7970135384615384, 0.9746889999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 203}], {
             RGBColor[
             0.7605678461538462, 0.8130245384615384, 0.9767317692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 221}], {
             RGBColor[
             0.8417747307692308, 0.6131266538461538, 0.5879230769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 223}], {
             RGBColor[
             0.9122687692307693, 0.9311406923076924, 0.9268099615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 258}], {
             RGBColor[
             0.6528229615384615, 0.7261803076923077, 0.9678203846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 381}], {
             RGBColor[
             0.7605678461538462, 0.8130245384615384, 0.9767317692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 439}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 480}], {
             RGBColor[
             0.7182602307692308, 0.7793052307692308, 0.9729718461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 29}], {
             RGBColor[
             0.6602197307692308, 0.7331513846153845, 0.9676819999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 185}], {
             RGBColor[
             0.49309273076923066`, 0.5987499999999999, 0.9534040769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 196}], {
             RGBColor[
             0.7472692692307692, 0.8020243846153845, 0.9727670384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 318}], {
             RGBColor[
             0.7155690769230769, 0.5898297692307692, 0.5881935769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 321}], {
             RGBColor[
             0.5551093076923076, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 335}], {
             RGBColor[
             0.4269346153846153, 0.5405238846153846, 0.9492223461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 383}], {
             RGBColor[
             0.7097995384615384, 0.7722432307692307, 0.9725281923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 479}], {
             RGBColor[
             0.6807149230769232, 0.7491623846153845, 0.9697247692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 482}], {
             RGBColor[
             0.6807149230769232, 0.7491623846153845, 0.9697247692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 496}], {
             RGBColor[
             0.49309273076923066`, 0.5987499999999999, 0.9534040769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.6746353846153845, 0.7438886153846154, 0.9695375384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 23}], {
             RGBColor[
             0.6528229615384615, 0.7261803076923077, 0.9678203846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 41}], {
             RGBColor[
             0.6746353846153845, 0.7438886153846154, 0.9695375384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 102}], {
             RGBColor[
             0.6528229615384615, 0.7261803076923077, 0.9678203846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 186}], {
             RGBColor[
             0.8729965000000001, 0.7736346153846154, 0.6146945769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 193}], {
             RGBColor[
             0.7605678461538462, 0.8130245384615384, 0.9767317692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 202}], {
             RGBColor[
             0.7182602307692308, 0.7793052307692308, 0.9729718461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 211}], {
             RGBColor[
             0.884935576923077, 0.8209690769230771, 0.6243010384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 212}], {
             RGBColor[
             0.8015582307692308, 0.8450465384615384, 0.9808173076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 300}], {
             RGBColor[
             0.6964478076923077, 0.7615969230769231, 0.9712546923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 414}], {
             RGBColor[
             0.9161076153846155, 0.9327281538461538, 0.8631903461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 485}], {
             RGBColor[
             0.7182602307692308, 0.7793052307692308, 0.9729718461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 24}], {
             RGBColor[
             0.8015582307692308, 0.8450465384615384, 0.9808173076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 77}], {
             RGBColor[
             0.8282616923076923, 0.8663391538461538, 0.9833643076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 79}], {
             RGBColor[
             0.8015582307692308, 0.8450465384615384, 0.9808173076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 80}], {
             RGBColor[
             0.8015582307692308, 0.8450465384615384, 0.9808173076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 81}], {
             RGBColor[
             0.5648403846153847, 0.6533024615384615, 0.9608408461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 99}], {
             RGBColor[
             0.8523796923076923, 0.8854739999999999, 0.9823296538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 156}], {
             RGBColor[
             0.841613423076923, 0.8769854615384615, 0.9846378076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 267}], {
             RGBColor[
             0.5815217692307693, 0.6677510384615384, 0.9619037692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 278}], {
             RGBColor[
             0.5982031538461539, 0.6821996153846153, 0.9629666923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 329}], {
             RGBColor[
             0.7858253461538462, 0.8326119999999999, 0.9792873846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 406}], {
             RGBColor[
             0.7858253461538462, 0.8326119999999999, 0.9792873846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 413}], {
             RGBColor[
             0.6820321538461539, 0.7508596923076922, 0.9693991538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 486}], {
             RGBColor[0.879451, 0.9026300769230768, 0.7594789615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 28}], {
             RGBColor[
             0.666657076923077, 0.5304054230769232, 0.5803475384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 49}], {
             RGBColor[0.6772313846153846, 0.5784208846153845, 0.589171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 69}], {
             RGBColor[
             0.6165948846153846, 0.6977347692307692, 0.9642476923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 142}], {
             RGBColor[
             0.7204304615384616, 0.7791267692307692, 0.9409183461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 173}], {
             RGBColor[
             0.703644423076923, 0.7666077692307691, 0.9693327307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[
             0.7092397692307693, 0.7707807692307692, 0.9598612692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 241}], {
             RGBColor[
             0.6719442307692307, 0.5544131538461539, 0.5847592692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 388}], {
             RGBColor[
             0.637090076923077, 0.7137457692307692, 0.9662904615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 402}], {
             RGBColor[
             0.637090076923077, 0.7137457692307692, 0.9662904615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 436}], {
             RGBColor[
             0.4896720384615384, 0.5965768461538461, 0.952967923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 461}], {
             RGBColor[
             0.4896720384615384, 0.5965768461538461, 0.952967923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 487}], {
             RGBColor[
             0.7313570384615384, 0.7851355384615384, 0.8162844230769233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 31}], {
             RGBColor[
             0.5367175769230769, 0.6341666153846153, 0.9568383846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 40}], {
             RGBColor[
             0.6477829615384615, 0.7212914615384616, 0.9678128846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 114}], {
             RGBColor[
             0.49309273076923066`, 0.5987499999999999, 0.9534040769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 115}], {
             RGBColor[
             0.5982031538461539, 0.6821996153846153, 0.9629666923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 162}], {
             RGBColor[
             0.6186983461538462, 0.6982106153846154, 0.9650094615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 203}], {
             RGBColor[
             0.5572127692307692, 0.6501776153846154, 0.9588811538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 221}], {
             RGBColor[
             0.6384196538461538, 0.4502797307692307, 0.5700724615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 258}], {
             RGBColor[
             0.44946788461538456`, 0.5633333846153845, 0.9499697692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 289}], {
             RGBColor[
             0.6964433846153846, 0.7594186153846154, 0.9491088076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 291}], {
             RGBColor[
             0.5572127692307692, 0.6501776153846154, 0.9588811538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 297}], {
             RGBColor[
             0.5367175769230769, 0.6341666153846153, 0.9568383846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 311}], {
             RGBColor[
             0.5777079615384616, 0.6661886153846155, 0.9609239230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 381}], {
             RGBColor[
             0.5572127692307692, 0.6501776153846154, 0.9588811538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 419}], {
             RGBColor[
             0.3977133846153846, 0.5189010769230769, 0.946562923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 439}], {
             RGBColor[
             0.6186983461538462, 0.6982106153846154, 0.9650094615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 19}], {
             RGBColor[
             0.6528229615384615, 0.7261803076923077, 0.9678203846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 26}], {
             RGBColor[
             0.7148351153846153, 0.7749537692307692, 0.9503898076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 34}], {
             RGBColor[
             0.6661746923076923, 0.7368266153846154, 0.9690938846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 44}], {
             RGBColor[
             0.5114844615384615, 0.6142851538461538, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.6661746923076923, 0.7368266153846154, 0.9690938846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 117}], {
             RGBColor[
             0.6795264230769231, 0.747472923076923, 0.9703673846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 139}], {
             RGBColor[
             0.7310363846153847, 0.7844496923076922, 0.7813832307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 247}], {
             RGBColor[
             0.6661746923076923, 0.7368266153846154, 0.9690938846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 269}], {
             RGBColor[
             0.703644423076923, 0.7666077692307691, 0.9693327307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 360}], {
             RGBColor[
             0.44946788461538456`, 0.5633333846153845, 0.9499697692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 425}], {
             RGBColor[
             0.637090076923077, 0.7137457692307692, 0.9662904615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 466}], {
             RGBColor[
             0.6795264230769231, 0.747472923076923, 0.9703673846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 468}], {
             RGBColor[
             0.4678596153846154, 0.5788685384615384, 0.9512507692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 120}], {
             RGBColor[
             0.7858253461538462, 0.8326119999999999, 0.9792873846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 123}], {
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 125}], {
             RGBColor[
             0.5686541923076923, 0.6548648846153846, 0.9618206923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 177}], {
             RGBColor[
             0.6186983461538462, 0.6982106153846154, 0.9650094615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 245}], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 438}], {
             RGBColor[
             0.8978155000000001, 0.9192353076923077, 0.9040735000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 455}], {
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 23}], {
             RGBColor[
             0.4896720384615384, 0.5965768461538461, 0.952967923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 41}], {
             RGBColor[
             0.5114844615384614, 0.6142851538461537, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 102}], {
             RGBColor[
             0.4896720384615384, 0.5965768461538461, 0.952967923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 186}], {
             RGBColor[
             0.7098455769230769, 0.6440311538461538, 0.5998421153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 193}], {
             RGBColor[
             0.5974169230769231, 0.6834210769230769, 0.9618793076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 202}], {
             RGBColor[
             0.5551093076923077, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 211}], {
             RGBColor[
             0.7217846538461539, 0.6913656153846155, 0.609448576923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 414}], {
             RGBColor[
             0.7529566923076922, 0.8031246923076922, 0.8483378846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 485}], {
             RGBColor[
             0.5551093076923077, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 497}], {
             RGBColor[
             0.47128030769230755`, 0.5810416923076922, 0.9516869230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 198}], {
             RGBColor[
             0.8978155000000001, 0.9192353076923077, 0.9040735000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 373}], {
             RGBColor[
             0.6140769615384615, 0.6791088076923077, 0.8818650000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 480}], {
             RGBColor[0.7940223076923076, 0.837483, 0.8941852692307694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 154}], {
             RGBColor[
             0.9521688846153846, 0.8544213076923077, 0.5831243076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 229}], {
             RGBColor[
             0.7696506538461538, 0.8187163846153847, 0.9348811923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 244}], {
             RGBColor[0.8952562692307693, 0.918177, 0.9464865769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 313}], {
             RGBColor[
             0.9880308461538461, 0.9893184615384616, 0.8480233846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 334}], {
             RGBColor[
             0.7696506538461538, 0.8187163846153847, 0.9348811923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 338}], {
             RGBColor[0.8747610769230769, 0.902166, 0.9444438076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 340}], {
             RGBColor[0.8952562692307693, 0.918177, 0.9464865769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 363}], {
             RGBColor[0.8337706923076923, 0.870144, 0.9403582692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 379}], {
             RGBColor[0.9730013076923076, 0.979385, 0.9305859230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 380}], {
             RGBColor[
             0.7478382307692306, 0.8010080769230769, 0.9331640384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 390}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 478}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 63}], {
             RGBColor[
             0.561026576923077, 0.6517400384615385, 0.9598610000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 72}], {
             RGBColor[
             0.5777079615384616, 0.6661886153846155, 0.9609239230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 75}], {
             RGBColor[
             0.8593843461538462, 0.8882716153846155, 0.8575748846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 149}], {
             RGBColor[
             0.7810630384615386, 0.8290355384615385, 0.9787745384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 158}], {
             RGBColor[
             0.7944147692307693, 0.8396818461538462, 0.9800480384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 163}], {
             RGBColor[
             0.5443451923076924, 0.6372914615384616, 0.9587980769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 182}], {
             RGBColor[
             0.8374798461538462, 0.8736360000000001, 0.970815423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 187}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 279}], {
             RGBColor[
             0.7243397692307694, 0.7845790000000001, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 322}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 324}], {
             RGBColor[
             0.7810630384615386, 0.8290355384615385, 0.9787745384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 441}], {
             RGBColor[
             0.8593843461538462, 0.8882716153846155, 0.8575748846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 494}], {
             RGBColor[
             0.6397245384615384, 0.7171403846153847, 0.9656392307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 78}], {
             RGBColor[
             0.6935195769230769, 0.7054566153846153, 0.6160568846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 97}], {
             RGBColor[0.9102263846153846, 0.8789498461538461, 0.635181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 104}], {
             RGBColor[0.799161, 0.791825, 0.6242064999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.6935195769230769, 0.7054566153846153, 0.6160568846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 148}], {
             RGBColor[
             0.6273614615384615, 0.6472304999999999, 0.6118751538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 153}], {
             RGBColor[0.9102263846153846, 0.8789498461538461, 0.635181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 190}], {
             RGBColor[
             0.915995923076923, 0.6965363846153847, 0.2508463846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 323}], {
             RGBColor[0.8606465769230769, 0.839858, 0.6303348076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 356}], {
             RGBColor[0.9102263846153846, 0.8789498461538461, 0.635181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 408}], {
             RGBColor[
             0.7119113076923077, 0.7209917692307692, 0.6173378846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 430}], {
             RGBColor[
             0.7555361538461538, 0.7564083846153846, 0.6207721923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 452}], {
             RGBColor[
             0.6273614615384615, 0.6472304999999999, 0.6118751538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 39}], {
             RGBColor[
             0.47641134615384606`, 0.584301423076923, 0.9523411538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 45}], {
             RGBColor[
             0.4982237692307693, 0.6020097307692307, 0.9540583076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 52}], {
             RGBColor[
             0.6909526923076923, 0.7533160384615385, 0.9291029615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 56}], {
             RGBColor[
             0.5815217692307693, 0.6677510384615384, 0.9619037692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 179}], {
             RGBColor[
             0.5405313846153846, 0.6357290384615384, 0.9578182307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 200}], {
             RGBColor[
             0.6960711538461539, 0.7554326538461538, 0.8442768076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 236}], {
             RGBColor[
             0.6177498461538462, 0.6961965769230769, 0.9654764615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 243}], {
             RGBColor[
             0.43278649999999996`, 0.5488848076923076, 0.9489068461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 254}], {
             RGBColor[
             0.5405313846153846, 0.6357290384615384, 0.9578182307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 276}], {
             RGBColor[
             0.561026576923077, 0.6517400384615385, 0.9598610000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 283}], {
             RGBColor[
             0.6177498461538462, 0.6961965769230769, 0.9654764615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 292}], {
             RGBColor[
             0.6741666538461537, 0.7407970384615384, 0.9575173461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 422}], {
             RGBColor[
             0.5200361923076923, 0.6197180384615384, 0.9557754615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 454}], {
             RGBColor[
             0.6810543461538461, 0.7052301153846154, 0.6313729230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 205}], {
             RGBColor[0.45459892307692296`, 0.5665931153846153, 0.950624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 252}], {
             RGBColor[
             0.5769217307692307, 0.6674100769230769, 0.9598365384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 282}], {
             RGBColor[
             0.5974169230769231, 0.6834210769230769, 0.9618793076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 293}], {
             RGBColor[
             0.4896720384615384, 0.5965768461538461, 0.952967923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 298}], {
             RGBColor[
             0.5114844615384614, 0.6142851538461537, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 418}], {
             RGBColor[
             0.7421560384615384, 0.7671442307692307, 0.6518129615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 432}], {
             RGBColor[
             0.5974169230769231, 0.6834210769230769, 0.9618793076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 467}], {
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 52}], {
             RGBColor[0.9109891538461539, 0.9306115384615385, 0.9480165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 56}], {
             RGBColor[
             0.8015582307692308, 0.8450465384615384, 0.9808173076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 65}], {
             RGBColor[
             0.8015582307692308, 0.8450465384615384, 0.9808173076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 88}], {
             RGBColor[
             0.9161076153846155, 0.9327281538461538, 0.8631903461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 166}], {
             RGBColor[
             0.7810630384615386, 0.8290355384615385, 0.9787745384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 167}], {
             RGBColor[
             0.9135483846153847, 0.9316698461538462, 0.9056034230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 210}], {
             RGBColor[
             0.6746353846153845, 0.7438886153846154, 0.9695375384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 227}], {
             RGBColor[
             0.7810630384615386, 0.8290355384615385, 0.9787745384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 243}], {
             RGBColor[
             0.6528229615384615, 0.7261803076923077, 0.9678203846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 326}], {
             RGBColor[0.8778414999999999, 0.905431, 0.9882105]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{18, 348}], {
             RGBColor[
             0.8015582307692308, 0.8450465384615384, 0.9808173076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 428}], {
             RGBColor[
             0.6344312307692308, 0.7106451538461538, 0.9665393846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 434}], {
             RGBColor[
             0.9163203846153847, 0.9324473076923077, 0.8328540384615387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 469}], {
             RGBColor[0.8778414999999999, 0.905431, 0.9882105]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{18, 474}], {
             RGBColor[
             0.6177498461538462, 0.6961965769230769, 0.9654764615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 495}], {
             RGBColor[0.6010684615384616, 0.681748, 0.9644135384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 26}], {
             RGBColor[
             0.8997984615384615, 0.9222655384615385, 0.9669594230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 34}], {
             RGBColor[0.8511380384615386, 0.8841383846153846, 0.9856635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 44}], {
             RGBColor[
             0.6964478076923077, 0.7615969230769231, 0.9712546923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 139}], {
             RGBColor[
             0.9159997307692308, 0.9317614615384615, 0.7979528461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 234}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 247}], {
             RGBColor[0.8511380384615386, 0.8841383846153846, 0.9856635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 269}], {
             RGBColor[
             0.8886077692307692, 0.9139195384615384, 0.9859023461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 360}], {
             RGBColor[
             0.6344312307692308, 0.7106451538461538, 0.9665393846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 393}], {
             RGBColor[
             0.6177498461538462, 0.6961965769230769, 0.9654764615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 466}], {
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 468}], {
             RGBColor[
             0.6528229615384615, 0.7261803076923077, 0.9678203846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 62}], {
             RGBColor[
             0.6602197307692308, 0.7331513846153845, 0.9676819999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 194}], {
             RGBColor[0.8579750384615384, 0.889647, 0.9728581923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 228}], {
             RGBColor[0.8747610769230769, 0.902166, 0.9444438076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 388}], {
             RGBColor[
             0.7858253461538462, 0.8326119999999999, 0.9792873846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 490}], {
             RGBColor[
             0.6384073076923076, 0.7154430769230768, 0.9659648461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 33}], {
             RGBColor[
             0.7810630384615386, 0.8290355384615385, 0.9787745384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 65}], {
             RGBColor[
             0.8015582307692308, 0.8450465384615384, 0.9808173076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 119}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 164}], {
             RGBColor[
             0.8015582307692308, 0.8450465384615384, 0.9808173076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 166}], {
             RGBColor[
             0.7810630384615386, 0.8290355384615385, 0.9787745384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 175}], {
             RGBColor[
             0.6964478076923077, 0.7615969230769231, 0.9712546923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 227}], {
             RGBColor[
             0.7810630384615386, 0.8290355384615385, 0.9787745384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 309}], {
             RGBColor[
             0.6528229615384615, 0.7261803076923077, 0.9678203846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 320}], {
             RGBColor[
             0.7182602307692308, 0.7793052307692308, 0.9729718461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 337}], {
             RGBColor[
             0.6746353846153845, 0.7438886153846154, 0.9695375384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 348}], {
             RGBColor[
             0.8015582307692308, 0.8450465384615384, 0.9808173076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 375}], {
             RGBColor[
             0.9163203846153847, 0.9324473076923077, 0.8328540384615387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 428}], {
             RGBColor[
             0.6344312307692308, 0.7106451538461538, 0.9665393846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 489}], {
             RGBColor[
             0.6528229615384615, 0.7261803076923077, 0.9678203846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 63}], {
             RGBColor[
             0.6177498461538462, 0.6961965769230769, 0.9654764615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 149}], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 160}], {
             RGBColor[
             0.5843870769230769, 0.667299423076923, 0.9633506153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 165}], {
             RGBColor[
             0.8942031153846154, 0.9180925384615385, 0.9764308846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 182}], {
             RGBColor[
             0.8942031153846154, 0.9180925384615385, 0.9764308846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 268}], {
             RGBColor[
             0.8015582307692308, 0.8450465384615384, 0.9808173076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 275}], {
             RGBColor[
             0.7605678461538462, 0.8130245384615384, 0.9767317692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 282}], {
             RGBColor[
             0.7605678461538462, 0.8130245384615384, 0.9767317692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 285}], {
             RGBColor[0.8778414999999999, 0.905431, 0.9882105]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{22, 324}], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 353}], {
             RGBColor[
             0.6746353846153845, 0.7438886153846154, 0.9695375384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 441}], {
             RGBColor[
             0.9161076153846155, 0.9327281538461538, 0.8631903461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 481}], {
             RGBColor[
             0.9159997307692308, 0.9317614615384615, 0.7979528461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 41}], {
             RGBColor[
             0.4896720384615384, 0.5965768461538461, 0.952967923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 186}], {
             RGBColor[
             0.6880331538461539, 0.6263228461538461, 0.5981249615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 202}], {
             RGBColor[
             0.5332968846153847, 0.6319934615384615, 0.9564022307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 211}], {
             RGBColor[
             0.6999722307692309, 0.6736573076923078, 0.6077314230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 212}], {
             RGBColor[
             0.6165948846153846, 0.6977347692307692, 0.9642476923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 485}], {
             RGBColor[
             0.5332968846153847, 0.6319934615384615, 0.9564022307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 497}], {
             RGBColor[
             0.44946788461538456`, 0.5633333846153845, 0.9499697692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 77}], {
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 81}], {
             RGBColor[0.6010684615384616, 0.681748, 0.9644135384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 83}], {
             RGBColor[
             0.7810630384615386, 0.8290355384615385, 0.9787745384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 176}], {
             RGBColor[
             0.9135483846153847, 0.9316698461538462, 0.9056034230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 197}], {
             RGBColor[
             0.6528229615384615, 0.7261803076923077, 0.9678203846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 237}], {
             RGBColor[
             0.6964478076923077, 0.7615969230769231, 0.9712546923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 267}], {
             RGBColor[
             0.6177498461538462, 0.6961965769230769, 0.9654764615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 270}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 278}], {
             RGBColor[
             0.6344312307692308, 0.7106451538461538, 0.9665393846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 329}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 426}], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 448}], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 489}], {
             RGBColor[
             0.6528229615384615, 0.7261803076923077, 0.9678203846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[
             0.703844576923077, 0.7685680000000001, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 96}], {
             RGBColor[
             0.5443451923076924, 0.6372914615384616, 0.9587980769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 157}], {
             RGBColor[
             0.6397245384615384, 0.7171403846153847, 0.9656392307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.703844576923077, 0.7685680000000001, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 246}], {
             RGBColor[
             0.703844576923077, 0.7685680000000001, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 288}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 333}], {
             RGBColor[0.8318845, 0.8694630000000001, 0.9802868846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 343}], {
             RGBColor[
             0.8595971153846155, 0.8879907692307694, 0.8272385769230772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 392}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 459}], {
             RGBColor[
             0.5777079615384616, 0.6661886153846155, 0.9609239230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 465}], {
             RGBColor[
             0.7810630384615386, 0.8290355384615385, 0.9787745384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 492}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 34}], {
             RGBColor[
             0.9131501923076923, 0.9329118461538461, 0.9682329230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 44}], {
             RGBColor[
             0.7584599615384615, 0.8103703846153846, 0.9538241153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 106}], {
             RGBColor[
             0.9131501923076923, 0.9329118461538461, 0.9682329230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 117}], {
             RGBColor[
             0.926501923076923, 0.9435581538461538, 0.969506423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 139}], {
             RGBColor[
             0.9780118846153846, 0.9805349230769231, 0.7805222692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 215}], {
             RGBColor[
             0.884065576923077, 0.9098310000000001, 0.9654294999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 224}], {
             RGBColor[
             0.9294940384615384, 0.7985138461538464, 0.5927217692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 247}], {
             RGBColor[
             0.9131501923076923, 0.9329118461538461, 0.9682329230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 269}], {
             RGBColor[0.950619923076923, 0.962693, 0.9684717692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 351}], {
             RGBColor[
             0.926501923076923, 0.9435581538461538, 0.969506423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 360}], {
             RGBColor[
             0.6964433846153846, 0.7594186153846154, 0.9491088076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 425}], {
             RGBColor[
             0.884065576923077, 0.9098310000000001, 0.9654294999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 466}], {
             RGBColor[
             0.926501923076923, 0.9435581538461538, 0.969506423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 468}], {
             RGBColor[
             0.7148351153846153, 0.7749537692307692, 0.9503898076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 40}], {
             RGBColor[
             0.7739195769230769, 0.8236708461538462, 0.9780052692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 114}], {
             RGBColor[
             0.6192293461538461, 0.7011293846153845, 0.9635964615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 199}], {
             RGBColor[
             0.6192293461538461, 0.7011293846153845, 0.9635964615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 220}], {
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 277}], {
             RGBColor[
             0.7605678461538462, 0.8130245384615384, 0.9767317692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 289}], {
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 291}], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 297}], {
             RGBColor[
             0.6628541923076923, 0.7365459999999999, 0.9670307692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 311}], {
             RGBColor[
             0.703844576923077, 0.7685680000000001, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 319}], {
             RGBColor[
             0.5572127692307692, 0.6501776153846154, 0.9588811538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 349}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 359}], {
             RGBColor[0.52385, 0.6212804615384615, 0.9567553076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 371}], {
             RGBColor[
             0.8391019230769231, 0.8719797692307693, 0.8251958076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 419}], {
             RGBColor[0.52385, 0.6212804615384615, 0.9567553076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 488}], {
             RGBColor[
             0.7605678461538462, 0.8130245384615384, 0.9767317692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 69}], {
             RGBColor[
             0.8153923461538461, 0.6492716538461539, 0.5933444615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 142}], {
             RGBColor[
             0.9192279230769231, 0.730663653846154, 0.5700151153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 173}], {
             RGBColor[
             0.9024418846153845, 0.7181446538461539, 0.5984295000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 194}], {
             RGBColor[
             0.9080372307692308, 0.722317653846154, 0.5889580384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 241}], {
             RGBColor[
             0.8707416923076923, 0.5059500384615386, 0.2138560384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 417}], {
             RGBColor[
             0.7744019615384616, 0.6172496538461539, 0.5892589230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 461}], {
             RGBColor[0.6884695, 0.5481137307692308, 0.5820646923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 493}], {
             RGBColor[
             0.9192279230769231, 0.730663653846154, 0.5700151153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 77}], {
             RGBColor[
             0.8282616923076923, 0.8663391538461538, 0.9833643076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 172}], {
             RGBColor[
             0.6820321538461539, 0.7508596923076922, 0.9693991538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 318}], {
             RGBColor[0.8206795, 0.6732793846153846, 0.5977561923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 321}], {
             RGBColor[
             0.6602197307692308, 0.7331513846153845, 0.9676819999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 383}], {
             RGBColor[
             0.8149099615384616, 0.8556928461538461, 0.9820908076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 479}], {
             RGBColor[
             0.7858253461538462, 0.8326119999999999, 0.9792873846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 482}], {
             RGBColor[
             0.7858253461538462, 0.8326119999999999, 0.9792873846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 43}], {
             RGBColor[
             0.7025273461538463, 0.7668706923076923, 0.9714419230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 64}], {
             RGBColor[
             0.5332968846153847, 0.6319934615384615, 0.9564022307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 110}], {
             RGBColor[
             0.7965815384615385, 0.8385413076923077, 0.8517721923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 217}], {
             RGBColor[
             0.7182602307692308, 0.7793052307692308, 0.9729718461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 290}], {
             RGBColor[
             0.5551093076923077, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 316}], {
             RGBColor[
             0.7182602307692308, 0.7793052307692308, 0.9729718461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 355}], {
             RGBColor[
             0.6205465769230769, 0.7028266923076922, 0.9632708461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 378}], {
             RGBColor[
             0.5551093076923077, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 384}], {
             RGBColor[
             0.7182602307692308, 0.7793052307692308, 0.9729718461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[0.7534243846153845, 0.8076598461538461, 0.9759625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 114}], {
             RGBColor[
             0.5987341538461537, 0.6851183846153845, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 162}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 203}], {
             RGBColor[
             0.6628541923076923, 0.7365459999999999, 0.9670307692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 208}], {
             RGBColor[
             0.7931914615384615, 0.7681577692307693, 0.6194032692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 221}], {
             RGBColor[
             0.7440610769230769, 0.5366481153846153, 0.5782220769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 223}], {
             RGBColor[
             0.8145551153846153, 0.8546621538461538, 0.9171089615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 258}], {
             RGBColor[
             0.5551093076923077, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 289}], {
             RGBColor[0.8020848076923076, 0.845787, 0.957258423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 297}], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 314}], {
             RGBColor[
             0.5769217307692307, 0.6674100769230769, 0.9598365384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 381}], {
             RGBColor[
             0.6628541923076923, 0.7365459999999999, 0.9670307692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 397}], {
             RGBColor[0.8020848076923076, 0.845787, 0.957258423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 419}], {
             RGBColor[
             0.5033548076923077, 0.6052694615384615, 0.9547125384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 472}], {
             RGBColor[
             0.6628541923076923, 0.7365459999999999, 0.9670307692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 103}], {
             RGBColor[
             0.9727371923076923, 0.9770477692307693, 0.8248949230769234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 155}], {
             RGBColor[
             0.8391019230769231, 0.8719797692307693, 0.8251958076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 331}], {
             RGBColor[
             0.7749818846153846, 0.8205521538461538, 0.8197187307692311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 344}], {
             RGBColor[
             0.9563755769230768, 0.9643862307692308, 0.8366745384615387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 403}], {
             RGBColor[
             0.9163203846153847, 0.9324473076923077, 0.8328540384615387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 449}], {
             RGBColor[
             0.9694391923076924, 0.9035915384615385, 0.47756830769230796`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 119}], {
             RGBColor[
             0.765330153846154, 0.8166010000000001, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 159}], {
             RGBColor[
             0.6397245384615384, 0.7171403846153847, 0.9656392307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 164}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 227}], {
             RGBColor[
             0.7243397692307694, 0.7845790000000001, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 267}], {
             RGBColor[
             0.561026576923077, 0.6517400384615385, 0.9598610000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 270}], {
             RGBColor[
             0.765330153846154, 0.8166010000000001, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 309}], {
             RGBColor[
             0.5960996923076924, 0.6817237692307693, 0.9622049230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 443}], {
             RGBColor[
             0.8485836923076924, 0.852291153846154, 0.6610499615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 489}], {
             RGBColor[
             0.5960996923076924, 0.6817237692307693, 0.9622049230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 234}], {
             RGBColor[
             0.835405153846154, 0.8717038461538462, 0.9841335769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 269}], {
             RGBColor[0.9019595, 0.9245658461538462, 0.9871758461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 332}], {
             RGBColor[
             0.9293514615384615, 0.9424077692307693, 0.799226346153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 360}], {
             RGBColor[
             0.6477829615384615, 0.7212914615384616, 0.9678128846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 393}], {
             RGBColor[
             0.6311015769230769, 0.7068428846153846, 0.9667499615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 468}], {
             RGBColor[
             0.6661746923076923, 0.7368266153846154, 0.9690938846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 54}], {
             RGBColor[
             0.6741666538461538, 0.7407970384615384, 0.9575173461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 67}], {
             RGBColor[
             0.8784702307692308, 0.9056580000000001, 0.9749009615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 70}], {
             RGBColor[0.8579750384615384, 0.889647, 0.9728581923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 84}], {
             RGBColor[
             0.8942031153846154, 0.9180925384615385, 0.9764308846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 131}], {
             RGBColor[
             0.9209065769230769, 0.9393851538461538, 0.9789778846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 135}], {
             RGBColor[
             0.9342583076923077, 0.9500314615384615, 0.9802513846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 147}], {
             RGBColor[
             0.7092397692307693, 0.7707807692307692, 0.9598612692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 171}], {
             RGBColor[
             0.7092397692307693, 0.7707807692307692, 0.9598612692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 216}], {
             RGBColor[
             0.8374798461538462, 0.8736360000000001, 0.970815423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 281}], {
             RGBColor[
             0.8374798461538462, 0.8736360000000001, 0.970815423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 385}], {
             RGBColor[
             0.7746770384615385, 0.8239056923076924, 0.9650127307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 391}], {
             RGBColor[
             0.7092397692307693, 0.7707807692307692, 0.9598612692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 37}], {
             RGBColor[
             0.7872713076923077, 0.8343171538461538, 0.9792787692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 58}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 141}], {
             RGBColor[
             0.7739195769230769, 0.8236708461538462, 0.9780052692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 240}], {
             RGBColor[0.7503341923076923, 0.443342, 0.5666457692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 251}], {
             RGBColor[
             0.6628541923076923, 0.7365459999999999, 0.9670307692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 310}], {
             RGBColor[
             0.6192293461538461, 0.7011293846153845, 0.9635964615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 352}], {
             RGBColor[
             0.7605678461538462, 0.8130245384615384, 0.9767317692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 367}], {
             RGBColor[
             0.5405313846153846, 0.6357290384615384, 0.9578182307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 382}], {
             RGBColor[
             0.703844576923077, 0.7685680000000001, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 399}], {
             RGBColor[
             0.7739195769230769, 0.8236708461538462, 0.9780052692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 412}], {
             RGBColor[
             0.7605678461538462, 0.8130245384615384, 0.9767317692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 416}], {
             RGBColor[0.44611730769230773`, 0.5447195, 0.9521403076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 429}], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 58}], {
             RGBColor[
             0.8487568846153847, 0.8823501538461538, 0.9854070769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 118}], {
             RGBColor[
             0.9420618846153845, 0.9516823846153846, 0.7306974615384617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 141}], {
             RGBColor[0.8778414999999999, 0.905431, 0.9882105]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{37, 188}], {
             RGBColor[
             0.6611346923076923, 0.7319377692307691, 0.9690863846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 240}], {
             RGBColor[0.8542561153846153, 0.5251021538461538, 0.576851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 304}], {
             RGBColor[
             0.8282616923076923, 0.8663391538461538, 0.9833643076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 310}], {
             RGBColor[
             0.7231512692307691, 0.7828895384615384, 0.9738016923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 429}], {
             RGBColor[
             0.7872713076923077, 0.8343171538461538, 0.9792787692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 47}], {
             RGBColor[
             0.7605678461538462, 0.8130245384615384, 0.9767317692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 73}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 93}], {
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 108}], {
             RGBColor[
             0.7872713076923077, 0.8343171538461538, 0.9792787692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 163}], {
             RGBColor[0.52385, 0.6212804615384615, 0.9567553076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 189}], {
             RGBColor[
             0.703844576923077, 0.7685680000000001, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 266}], {
             RGBColor[
             0.5572127692307692, 0.6501776153846154, 0.9588811538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 364}], {
             RGBColor[0.8196561923076924, 0.807836, 0.6262492692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 437}], {
             RGBColor[
             0.6628541923076923, 0.7365459999999999, 0.9670307692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 45}], {
             RGBColor[
             0.5769217307692307, 0.6674100769230769, 0.9598365384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 100}], {
             RGBColor[
             0.6964478076923077, 0.7615969230769231, 0.9712546923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 127}], {
             RGBColor[
             0.7639684615384614, 0.7848525384615385, 0.6535301153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 179}], {
             RGBColor[
             0.6192293461538461, 0.7011293846153845, 0.9635964615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 200}], {
             RGBColor[
             0.7747691153846153, 0.8208329999999999, 0.8500550384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 213}], {
             RGBColor[
             0.5551093076923076, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 236}], {
             RGBColor[
             0.6964478076923077, 0.7615969230769231, 0.9712546923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 243}], {
             RGBColor[
             0.5114844615384615, 0.6142851538461538, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 254}], {
             RGBColor[
             0.6192293461538461, 0.7011293846153845, 0.9635964615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 276}], {
             RGBColor[
             0.6397245384615384, 0.7171403846153847, 0.9656392307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 283}], {
             RGBColor[
             0.6964478076923077, 0.7615969230769231, 0.9712546923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 315}], {
             RGBColor[
             0.6602197307692308, 0.7331513846153845, 0.9676819999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 325}], {
             RGBColor[
             0.5769217307692307, 0.6674100769230769, 0.9598365384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 368}], {
             RGBColor[
             0.5114844615384615, 0.6142851538461538, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 401}], {
             RGBColor[
             0.6397245384615384, 0.7171403846153847, 0.9656392307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 450}], {
             RGBColor[
             0.5987341538461537, 0.6851183846153845, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 454}], {
             RGBColor[
             0.7597523076923076, 0.7706304615384616, 0.637151153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 471}], {
             RGBColor[
             0.6397245384615384, 0.7171403846153847, 0.9656392307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 475}], {
             RGBColor[
             0.5987341538461537, 0.6851183846153845, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 114}], {
             RGBColor[
             0.7097995384615384, 0.7722432307692307, 0.9725281923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 199}], {
             RGBColor[
             0.7097995384615384, 0.7722432307692307, 0.9725281923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 208}], {
             RGBColor[
             0.9042568461538463, 0.8552826153846155, 0.6303777692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 220}], {
             RGBColor[
             0.9131501923076923, 0.9329118461538461, 0.9682329230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 289}], {
             RGBColor[
             0.9131501923076923, 0.9329118461538461, 0.9682329230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 291}], {
             RGBColor[
             0.7739195769230769, 0.8236708461538462, 0.9780052692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 297}], {
             RGBColor[0.7534243846153845, 0.8076598461538461, 0.9759625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 314}], {
             RGBColor[
             0.6879871153846153, 0.7545349230769229, 0.9708110384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 349}], {
             RGBColor[
             0.835405153846154, 0.8717038461538462, 0.9841335769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 359}], {
             RGBColor[
             0.6144201923076923, 0.6923943076923077, 0.9656870384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 371}], {
             RGBColor[
             0.9296721153846155, 0.9430936153846154, 0.8341275384615388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 397}], {
             RGBColor[
             0.9131501923076923, 0.9329118461538461, 0.9682329230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 419}], {
             RGBColor[
             0.6144201923076923, 0.6923943076923077, 0.9656870384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 472}], {
             RGBColor[
             0.7739195769230769, 0.8236708461538462, 0.9780052692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 102}], {
             RGBColor[
             0.4896720384615384, 0.5965768461538461, 0.952967923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 186}], {
             RGBColor[
             0.7098455769230769, 0.6440311538461538, 0.5998421153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 191}], {
             RGBColor[
             0.47128030769230755`, 0.5810416923076922, 0.9516869230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 202}], {
             RGBColor[
             0.5551093076923077, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 212}], {
             RGBColor[
             0.6384073076923076, 0.7154430769230768, 0.9659648461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 295}], {
             RGBColor[
             0.5114844615384614, 0.6142851538461537, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 300}], {
             RGBColor[
             0.5332968846153845, 0.6319934615384615, 0.9564022307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 389}], {
             RGBColor[
             0.7491178461538461, 0.8015372307692307, 0.9119575000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 451}], {
             RGBColor[
             0.6746353846153845, 0.7438886153846154, 0.9695375384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 456}], {
             RGBColor[
             0.5332968846153845, 0.6319934615384615, 0.9564022307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 485}], {
             RGBColor[
             0.5551093076923077, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 85}], {
             RGBColor[
             0.841613423076923, 0.8769854615384615, 0.9846378076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 95}], {
             RGBColor[
             0.7858253461538462, 0.8326119999999999, 0.9792873846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[
             0.8149099615384616, 0.8556928461538461, 0.9820908076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 137}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 145}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 174}], {
             RGBColor[
             0.8015582307692308, 0.8450465384615384, 0.9808173076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 248}], {
             RGBColor[
             0.5815217692307693, 0.6677510384615384, 0.9619037692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 286}], {
             RGBColor[
             0.6820321538461539, 0.7508596923076922, 0.9693991538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 294}], {
             RGBColor[
             0.7858253461538462, 0.8326119999999999, 0.9792873846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 346}], {
             RGBColor[
             0.8523796923076923, 0.8854739999999999, 0.9823296538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 358}], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 407}], {
             RGBColor[
             0.5982031538461539, 0.6821996153846153, 0.9629666923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 411}], {
             RGBColor[
             0.7038445769230769, 0.7685679999999999, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 430}], {
             RGBColor[
             0.6602197307692308, 0.7331513846153845, 0.9676819999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 110}], {
             RGBColor[
             0.9003747307692309, 0.9202936153846154, 0.8616604230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 217}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 290}], {
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 316}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 340}], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 355}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 362}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 378}], {
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 384}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 57}], {
             RGBColor[
             0.5987341538461537, 0.6851183846153845, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 106}], {
             RGBColor[
             0.7097995384615384, 0.7722432307692307, 0.9725281923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 117}], {
             RGBColor[
             0.7231512692307691, 0.7828895384615384, 0.9738016923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 139}], {
             RGBColor[
             0.7746612307692307, 0.8198663076923076, 0.7848175384615383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 140}], {
             RGBColor[
             0.7472692692307692, 0.8020243846153845, 0.9727670384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 247}], {
             RGBColor[
             0.7097995384615384, 0.7722432307692307, 0.9725281923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 255}], {
             RGBColor[
             0.7365029999999999, 0.7935358461538461, 0.9750751923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 269}], {
             RGBColor[
             0.7472692692307692, 0.8020243846153845, 0.9727670384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 360}], {
             RGBColor[
             0.49309273076923066`, 0.5987499999999999, 0.9534040769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 369}], {
             RGBColor[
             0.7365029999999999, 0.7935358461538461, 0.9750751923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 370}], {
             RGBColor[
             0.7472692692307692, 0.8020243846153845, 0.9727670384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 425}], {
             RGBColor[
             0.6807149230769232, 0.7491623846153845, 0.9697247692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 466}], {
             RGBColor[
             0.7231512692307691, 0.7828895384615384, 0.9738016923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 468}], {
             RGBColor[
             0.5114844615384615, 0.6142851538461538, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 52}], {
             RGBColor[
             0.7914630769230769, 0.8364246923076923, 0.9365983461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 56}], {
             RGBColor[
             0.6820321538461539, 0.7508596923076922, 0.9693991538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 179}], {
             RGBColor[
             0.6410417692307693, 0.7188376923076923, 0.9653136153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 236}], {
             RGBColor[
             0.7182602307692308, 0.7793052307692308, 0.9729718461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 243}], {
             RGBColor[
             0.5332968846153847, 0.6319934615384615, 0.9564022307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 254}], {
             RGBColor[
             0.6410417692307693, 0.7188376923076923, 0.9653136153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 276}], {
             RGBColor[
             0.6615369615384616, 0.7348486923076925, 0.9673563846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 283}], {
             RGBColor[
             0.7182602307692308, 0.7793052307692308, 0.9729718461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 292}], {
             RGBColor[
             0.7746770384615385, 0.8239056923076924, 0.9650127307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 386}], {
             RGBColor[
             0.5332968846153847, 0.6319934615384615, 0.9564022307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 422}], {
             RGBColor[
             0.6205465769230769, 0.7028266923076922, 0.9632708461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 53}], {
             RGBColor[
             0.8171143461538461, 0.8557204615384615, 0.8746958846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 68}], {
             RGBColor[
             0.7801278461538461, 0.8289524615384615, 0.9785094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 90}], {
             RGBColor[
             0.48667342307692296`, 0.5908208846153845, 0.9536496153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 205}], {
             RGBColor[
             0.5200361923076923, 0.6197180384615384, 0.9557754615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 257}], {
             RGBColor[
             0.8033771538461538, 0.806047076923077, 0.6405854615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 272}], {
             RGBColor[
             0.7038445769230769, 0.7685679999999999, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 293}], {
             RGBColor[
             0.5551093076923077, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 298}], {
             RGBColor[
             0.5769217307692307, 0.6674100769230769, 0.9598365384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 306}], {
             RGBColor[0.410643, 0.5129644999999999, 0.9492445]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{46, 317}], {
             RGBColor[
             0.7400726538461538, 0.7970135384615384, 0.9746889999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 357}], {
             RGBColor[
             0.8182860769230769, 0.855282923076923, 0.7882518461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 418}], {
             RGBColor[
             0.8075933076923076, 0.8202691538461538, 0.6569644230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 420}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 55}], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 189}], {
             RGBColor[
             0.7810630384615386, 0.8290355384615385, 0.9787745384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 230}], {
             RGBColor[
             0.6344312307692308, 0.7106451538461538, 0.9665393846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 242}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 339}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 364}], {
             RGBColor[0.8968746538461538, 0.8683035384615385, 0.6339075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 365}], {
             RGBColor[
             0.6177498461538462, 0.6961965769230769, 0.9654764615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 374}], {
             RGBColor[
             0.9122687692307693, 0.9311406923076924, 0.9268099615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 437}], {
             RGBColor[
             0.7400726538461538, 0.7970135384615384, 0.9746889999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 78}], {
             RGBColor[
             0.47128030769230755`, 0.5810416923076922, 0.9516869230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 85}], {
             RGBColor[
             0.7146905769230768, 0.7758275384615383, 0.9733580384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 95}], {
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 137}], {
             RGBColor[
             0.5974169230769231, 0.6834210769230769, 0.9618793076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 145}], {
             RGBColor[
             0.6179121153846154, 0.6994320769230769, 0.963922076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 183}], {
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 346}], {
             RGBColor[
             0.725456846153846, 0.7843160769230768, 0.9710498846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 358}], {
             RGBColor[
             0.6384073076923076, 0.7154430769230768, 0.9659648461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 404}], {
             RGBColor[
             0.7478382307692306, 0.8010080769230769, 0.9331640384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 407}], {
             RGBColor[
             0.47128030769230755`, 0.5810416923076922, 0.9516869230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 408}], {
             RGBColor[
             0.4896720384615384, 0.5965768461538461, 0.952967923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 71}], {
             RGBColor[
             0.8464618461538462, 0.7132981153846154, 0.6042106923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 76}], {
             RGBColor[
             0.7849762692307692, 0.6652651153846154, 0.5980823846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 238}], {
             RGBColor[
             0.8464618461538462, 0.7132981153846154, 0.6042106923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 328}], {
             RGBColor[
             0.7644810769230769, 0.6492541153846153, 0.5960396153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 402}], {
             RGBColor[
             0.8464618461538462, 0.7132981153846154, 0.6042106923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 431}], {
             RGBColor[
             0.902249923076923, 0.7576715769230769, 0.6095611153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 436}], {
             RGBColor[
             0.6990438076923076, 0.5961291923076921, 0.5908881538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 459}], {
             RGBColor[0.6588396538461538, 0.5628857307692308, 0.58789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 462}], {
             RGBColor[
             0.7426686538461539, 0.6315458076923077, 0.5943224615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 487}], {
             RGBColor[
             0.9407288076923077, 0.7846878846153846, 0.4542046538461541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 57}], {
             RGBColor[
             0.5367175769230769, 0.6341666153846153, 0.9568383846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 92}], {
             RGBColor[
             0.7076340769230769, 0.7677646153846154, 0.9301658846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 106}], {
             RGBColor[
             0.6477829615384615, 0.7212914615384616, 0.9678128846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 117}], {
             RGBColor[
             0.6611346923076923, 0.7319377692307691, 0.9690863846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 139}], {
             RGBColor[
             0.7126446538461537, 0.7689145384615385, 0.7801022307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 140}], {
             RGBColor[
             0.6852526923076923, 0.7510726153846153, 0.9680517307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 169}], {
             RGBColor[
             0.6964433846153846, 0.7594186153846154, 0.9491088076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 204}], {
             RGBColor[
             0.4143947692307692, 0.5333496538461537, 0.9476258461538463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 219}], {
             RGBColor[
             0.6641268076923077, 0.5868934615384618, 0.5923017307692309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 244}], {
             RGBColor[
             0.6186983461538462, 0.6982106153846154, 0.9650094615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 255}], {
             RGBColor[
             0.674486423076923, 0.7425840769230769, 0.9703598846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 274}], {
             RGBColor[
             0.5572127692307692, 0.6501776153846154, 0.9588811538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 334}], {
             RGBColor[
             0.49309273076923066`, 0.5987499999999999, 0.9534040769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 338}], {
             RGBColor[
             0.5982031538461539, 0.6821996153846153, 0.9629666923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 340}], {
             RGBColor[
             0.6186983461538462, 0.6982106153846154, 0.9650094615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 361}], {
             RGBColor[
             0.5982031538461539, 0.6821996153846153, 0.9629666923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 363}], {
             RGBColor[
             0.5572127692307692, 0.6501776153846154, 0.9588811538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 369}], {
             RGBColor[
             0.674486423076923, 0.7425840769230769, 0.9703598846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 370}], {
             RGBColor[
             0.6852526923076923, 0.7510726153846153, 0.9680517307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 379}], {
             RGBColor[
             0.6964433846153846, 0.7594186153846154, 0.9491088076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[
             0.7967943076923077, 0.8382604615384616, 0.8214358846153849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 113}], {
             RGBColor[
             0.9005875000000001, 0.9200127692307692, 0.8313241153846156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 127}], {
             RGBColor[
             0.9838410384615385, 0.9557029230769232, 0.5151294615384618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 130}], {
             RGBColor[
             0.9005875000000001, 0.9200127692307692, 0.8313241153846156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 143}], {
             RGBColor[
             0.8595971153846155, 0.8879907692307694, 0.8272385769230772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 179}], {
             RGBColor[
             0.8391019230769231, 0.8719797692307693, 0.8251958076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 214}], {
             RGBColor[
             0.9163203846153847, 0.9324473076923077, 0.8328540384615387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 302}], {
             RGBColor[
             0.8391019230769231, 0.8719797692307693, 0.8251958076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 308}], {
             RGBColor[
             0.9430238461538462, 0.953739923076923, 0.8354010384615387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 315}], {
             RGBColor[
             0.8800923076923077, 0.9040017692307691, 0.8292813461538464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 325}], {
             RGBColor[
             0.7967943076923077, 0.8382604615384616, 0.8214358846153849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 347}], {
             RGBColor[
             0.8391019230769231, 0.8719797692307693, 0.8251958076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 386}], {
             RGBColor[
             0.7313570384615384, 0.7851355384615384, 0.8162844230769233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 421}], {
             RGBColor[
             0.6168489615384616, 0.6798862692307692, 0.8091156153846156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 423}], {
             RGBColor[
             0.9920824615384616, 0.9906250769230769, 0.7540674615384619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 477}], {
             RGBColor[
             0.8186067307692307, 0.8559687692307691, 0.8231530384615386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 56}], {
             RGBColor[0.8747610769230769, 0.902166, 0.9444438076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 88}], {
             RGBColor[
             0.9893104615384616, 0.9898476153846154, 0.8268168461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 166}], {
             RGBColor[0.8542658846153847, 0.886155, 0.9424010384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 210}], {
             RGBColor[
             0.7478382307692306, 0.8010080769230769, 0.9331640384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 227}], {
             RGBColor[0.8542658846153847, 0.886155, 0.9424010384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 236}], {
             RGBColor[0.9109891538461539, 0.9306115384615385, 0.9480165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 243}], {
             RGBColor[
             0.7260258076923076, 0.7832997692307693, 0.9314468846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 276}], {
             RGBColor[0.8542658846153847, 0.886155, 0.9424010384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 326}], {
             RGBColor[0.951044346153846, 0.9625504615384615, 0.951837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 428}], {
             RGBColor[
             0.7076340769230769, 0.7677646153846154, 0.9301658846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 469}], {
             RGBColor[0.951044346153846, 0.9625504615384615, 0.951837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 495}], {
             RGBColor[
             0.6742713076923077, 0.7388674615384615, 0.9280400384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 90}], {
             RGBColor[0.6614287692307692, 0.7260063461538461, 0.8633575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 178}], {
             RGBColor[
             0.9893104615384616, 0.9898476153846154, 0.8268168461538463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 257}], {
             RGBColor[
             0.9781325000000001, 0.9412325384615385, 0.5502933461538463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 272}], {
             RGBColor[
             0.878599923076923, 0.9037534615384615, 0.8808241923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[
             0.7298646538461538, 0.7848872307692307, 0.8678272692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 298}], {
             RGBColor[
             0.7516770769230768, 0.8025955384615384, 0.8695444230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 306}], {
             RGBColor[
             0.5853983461538461, 0.6481499615384615, 0.8589523846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 317}], {
             RGBColor[0.914828, 0.932199, 0.8843968846153847]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{53, 357}], {
             RGBColor[
             0.9930414230769231, 0.9904683846153846, 0.6979597307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 418}], {
             RGBColor[
             0.9823486538461539, 0.9554546153846154, 0.5666723076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 420}], {
             RGBColor[
             0.8990951153846154, 0.9197644615384615, 0.8828669615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 432}], {
             RGBColor[
             0.8376095384615385, 0.8717314615384615, 0.8767386538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 55}], {
             RGBColor[
             0.6177498461538462, 0.6961965769230769, 0.9654764615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 70}], {
             RGBColor[
             0.5815217692307693, 0.6677510384615384, 0.9619037692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 84}], {
             RGBColor[
             0.6177498461538462, 0.6961965769230769, 0.9654764615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 131}], {
             RGBColor[
             0.6444533076923077, 0.7174891923076923, 0.9680234615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 135}], {
             RGBColor[
             0.6578050384615384, 0.7281354999999999, 0.9692969615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 147}], {
             RGBColor[
             0.43278649999999996`, 0.5488848076923076, 0.9489068461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 230}], {
             RGBColor[
             0.4143947692307692, 0.5333496538461537, 0.9476258461538463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 242}], {
             RGBColor[
             0.6020169615384616, 0.6837620384615384, 0.9639465384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 365}], {
             RGBColor[
             0.3977133846153846, 0.5189010769230769, 0.9465629230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 374}], {
             RGBColor[
             0.6922323076923076, 0.7538451923076923, 0.9078964230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 385}], {
             RGBColor[
             0.4982237692307693, 0.6020097307692307, 0.9540583076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 391}], {
             RGBColor[
             0.43278649999999996`, 0.5488848076923076, 0.9489068461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 230}], {
             RGBColor[
             0.6344312307692308, 0.7106451538461538, 0.9665393846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 242}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 250}], {
             RGBColor[
             0.6344312307692308, 0.7106451538461538, 0.9665393846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 339}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 365}], {
             RGBColor[
             0.6177498461538462, 0.6961965769230769, 0.9654764615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 88}], {
             RGBColor[
             0.8798795384615385, 0.9042826153846153, 0.859617653846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 164}], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 166}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 210}], {
             RGBColor[
             0.6384073076923076, 0.7154430769230768, 0.9659648461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 227}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 236}], {
             RGBColor[
             0.8015582307692308, 0.8450465384615384, 0.9808173076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 243}], {
             RGBColor[
             0.6165948846153846, 0.6977347692307692, 0.9642476923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 276}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 326}], {
             RGBColor[
             0.841613423076923, 0.8769854615384615, 0.9846378076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 428}], {
             RGBColor[
             0.5982031538461539, 0.6821996153846153, 0.9629666923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 495}], {
             RGBColor[
             0.5648403846153847, 0.6533024615384615, 0.9608408461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 92}], {
             RGBColor[0.8132754999999999, 0.854133, 0.9383155]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{57, 106}], {
             RGBColor[0.7534243846153845, 0.8076598461538461, 0.9759625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 139}], {
             RGBColor[
             0.8182860769230769, 0.855282923076923, 0.7882518461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 140}], {
             RGBColor[
             0.7908941153846153, 0.8374409999999999, 0.9762013461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 169}], {
             RGBColor[0.8020848076923076, 0.845787, 0.957258423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 175}], {
             RGBColor[
             0.5987341538461537, 0.6851183846153845, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 204}], {
             RGBColor[
             0.5200361923076923, 0.6197180384615384, 0.9557754615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 219}], {
             RGBColor[
             0.7697682307692307, 0.6732618461538463, 0.6004513461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 255}], {
             RGBColor[
             0.7801278461538461, 0.8289524615384615, 0.9785094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 274}], {
             RGBColor[
             0.6628541923076923, 0.7365459999999999, 0.9670307692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 334}], {
             RGBColor[
             0.5987341538461537, 0.6851183846153845, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 337}], {
             RGBColor[
             0.5769217307692307, 0.6674100769230769, 0.9598365384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 361}], {
             RGBColor[
             0.7038445769230769, 0.7685679999999999, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 363}], {
             RGBColor[
             0.6628541923076923, 0.7365459999999999, 0.9670307692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 369}], {
             RGBColor[
             0.7801278461538461, 0.8289524615384615, 0.9785094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 370}], {
             RGBColor[
             0.7908941153846153, 0.8374409999999999, 0.9762013461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 466}], {
             RGBColor[0.7667761153846153, 0.8183061538461538, 0.977236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 118}], {
             RGBColor[
             0.8996255384615386, 0.9179552307692308, 0.7266205384615386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 141}], {
             RGBColor[
             0.835405153846154, 0.8717038461538462, 0.9841335769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 188}], {
             RGBColor[
             0.6186983461538462, 0.6982106153846154, 0.9650094615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 220}], {
             RGBColor[
             0.884065576923077, 0.9098310000000001, 0.9654294999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 240}], {
             RGBColor[0.8118197692307694, 0.491375, 0.5727740769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 304}], {
             RGBColor[
             0.7858253461538462, 0.8326119999999999, 0.9792873846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 310}], {
             RGBColor[
             0.6807149230769232, 0.7491623846153845, 0.9697247692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 371}], {
             RGBColor[
             0.9005875000000001, 0.9200127692307692, 0.8313241153846156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 382}], {
             RGBColor[
             0.765330153846154, 0.8166010000000001, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 429}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 74}], {
             RGBColor[0.9045449615384615, 0.9267236153846153, 0.9907575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 82}], {
             RGBColor[
             0.8282616923076923, 0.8663391538461538, 0.9833643076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 105}], {
             RGBColor[
             0.8487568846153847, 0.8823501538461538, 0.9854070769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 153}], {
             RGBColor[0.8778414999999999, 0.905431, 0.9882105]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{59, 195}], {
             RGBColor[0.9045449615384615, 0.9267236153846153, 0.9907575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 263}], {
             RGBColor[
             0.9153112307692307, 0.9352121538461537, 0.9884493461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 323}], {
             RGBColor[
             0.8282616923076923, 0.8663391538461538, 0.9833643076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 342}], {
             RGBColor[
             0.8282616923076923, 0.8663391538461538, 0.9833643076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 395}], {
             RGBColor[
             0.8487568846153847, 0.8823501538461538, 0.9854070769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 447}], {
             RGBColor[0.8542561153846153, 0.5251021538461538, 0.576851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 453}], {
             RGBColor[
             0.9153112307692307, 0.9352121538461537, 0.9884493461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 463}], {
             RGBColor[0.9056695, 0.8185944615384615, 0.6220448076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 116}], {
             RGBColor[
             0.6311015769230769, 0.7068428846153846, 0.9667499615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 118}], {
             RGBColor[
             0.6953219615384616, 0.7530942692307692, 0.7092369230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 133}], {
             RGBColor[
             0.5815217692307693, 0.6677510384615384, 0.9619037692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 151}], {
             RGBColor[
             0.5405313846153846, 0.6357290384615384, 0.9578182307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 188}], {
             RGBColor[
             0.4143947692307692, 0.5333496538461537, 0.9476258461538463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 192}], {
             RGBColor[
             0.4982237692307693, 0.6020097307692307, 0.9540583076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 249}], {
             RGBColor[0.381032, 0.5044525, 0.9455]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 260}], {
             RGBColor[
             0.6177498461538462, 0.6961965769230769, 0.9654764615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 280}], {
             RGBColor[
             0.6685713076923077, 0.7366240384615383, 0.9669888076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 310}], {
             RGBColor[
             0.47641134615384606`, 0.584301423076923, 0.9523411538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 327}], {
             RGBColor[
             0.6962839230769231, 0.7551518076923076, 0.8139405000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 483}], {
             RGBColor[
             0.6177498461538462, 0.6961965769230769, 0.9654764615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 64}], {
             RGBColor[
             0.6165948846153846, 0.6977347692307692, 0.9642476923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 91}], {
             RGBColor[
             0.8800923076923077, 0.9040017692307691, 0.8292813461538464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 172}], {
             RGBColor[
             0.6820321538461539, 0.7508596923076922, 0.9693991538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 303}], {
             RGBColor[
             0.7858253461538462, 0.8326119999999999, 0.9792873846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 362}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 384}], {
             RGBColor[
             0.8015582307692308, 0.8450465384615384, 0.9808173076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 435}], {
             RGBColor[
             0.7038445769230769, 0.7685679999999999, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 473}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 132}], {
             RGBColor[
             0.7097995384615384, 0.7722432307692307, 0.9725281923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 209}], {
             RGBColor[
             0.7528646153846152, 0.8061973846153846, 0.9632955769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 233}], {
             RGBColor[
             0.5551093076923076, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 75}], {
             RGBColor[
             0.6960711538461539, 0.7554326538461538, 0.8442768076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 149}], {
             RGBColor[
             0.6177498461538462, 0.6961965769230769, 0.9654764615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 158}], {
             RGBColor[
             0.6311015769230769, 0.7068428846153846, 0.9667499615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 165}], {
             RGBColor[
             0.6741666538461537, 0.7407970384615384, 0.9575173461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 182}], {
             RGBColor[
             0.6741666538461537, 0.7407970384615384, 0.9575173461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 206}], {
             RGBColor[
             0.43278649999999996`, 0.5488848076923076, 0.9489068461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 252}], {
             RGBColor[
             0.5200361923076923, 0.6197180384615384, 0.9557754615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 275}], {
             RGBColor[
             0.5405313846153846, 0.6357290384615384, 0.9578182307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 282}], {
             RGBColor[
             0.5405313846153846, 0.6357290384615384, 0.9578182307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 324}], {
             RGBColor[
             0.6177498461538462, 0.6961965769230769, 0.9654764615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 410}], {
             RGBColor[
             0.4143947692307692, 0.5333496538461537, 0.9476258461538463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 441}], {
             RGBColor[
             0.6960711538461539, 0.7554326538461538, 0.8442768076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 467}], {
             RGBColor[
             0.6020169615384616, 0.6837620384615384, 0.9639465384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 91}], {
             RGBColor[
             0.7313570384615384, 0.7851355384615384, 0.8162844230769233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 172}], {
             RGBColor[
             0.5332968846153847, 0.6319934615384615, 0.9564022307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 303}], {
             RGBColor[
             0.637090076923077, 0.7137457692307692, 0.9662904615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 366}], {
             RGBColor[
             0.7204304615384616, 0.7791267692307692, 0.9409183461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 384}], {
             RGBColor[
             0.6528229615384615, 0.7261803076923077, 0.9678203846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 435}], {
             RGBColor[
             0.5551093076923077, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 473}], {
             RGBColor[
             0.5756045000000001, 0.6657127692307692, 0.9601621538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 88}], {
             RGBColor[
             0.8798795384615385, 0.9042826153846153, 0.859617653846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 166}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 167}], {
             RGBColor[
             0.8773203076923077, 0.9032243076923077, 0.9020307307692309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 175}], {
             RGBColor[
             0.6602197307692308, 0.7331513846153845, 0.9676819999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[
             0.6384073076923076, 0.7154430769230768, 0.9659648461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 227}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 309}], {
             RGBColor[
             0.6165948846153846, 0.6977347692307692, 0.9642476923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 320}], {
             RGBColor[
             0.6820321538461539, 0.7508596923076922, 0.9693991538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 337}], {
             RGBColor[
             0.6384073076923076, 0.7154430769230768, 0.9659648461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 348}], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 428}], {
             RGBColor[
             0.5982031538461539, 0.6821996153846153, 0.9629666923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 434}], {
             RGBColor[
             0.8800923076923077, 0.9040017692307691, 0.8292813461538464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 474}], {
             RGBColor[
             0.5815217692307693, 0.6677510384615384, 0.9619037692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 495}], {
             RGBColor[
             0.5648403846153847, 0.6533024615384615, 0.9608408461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 208}], {
             RGBColor[
             0.9380543846153847, 0.7921133076923079, 0.26901530769230775`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 305}], {
             RGBColor[
             0.7435970769230769, 0.7090739230769232, 0.6111657307692309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 314}], {
             RGBColor[
             0.7217846538461539, 0.6913656153846155, 0.609448576923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 394}], {
             RGBColor[
             0.7654095000000001, 0.726782230769231, 0.6128828846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 398}], {
             RGBColor[
             0.6154223846153846, 0.5998960384615386, 0.6022686923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 427}], {
             RGBColor[
             0.9619772692307693, 0.8796760000000001, 0.5243079230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 445}], {
             RGBColor[
             0.7217846538461539, 0.6913656153846155, 0.609448576923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 460}], {
             RGBColor[0.6815805, 0.658122153846154, 0.6064504230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 472}], {
             RGBColor[
             0.8077171153846154, 0.7605015384615387, 0.6166428076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 70}], {
             RGBColor[
             0.7858253461538462, 0.8326119999999999, 0.9792873846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 96}], {
             RGBColor[
             0.585335576923077, 0.6693134615384615, 0.9628836153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 131}], {
             RGBColor[
             0.8487568846153847, 0.8823501538461538, 0.9854070769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 135}], {
             RGBColor[
             0.8621086153846154, 0.8929964615384616, 0.9866805769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 147}], {
             RGBColor[
             0.637090076923077, 0.7137457692307692, 0.9662904615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 171}], {
             RGBColor[
             0.637090076923077, 0.7137457692307692, 0.9662904615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 180}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 216}], {
             RGBColor[
             0.765330153846154, 0.8166010000000001, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 238}], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 281}], {
             RGBColor[
             0.765330153846154, 0.8166010000000001, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 343}], {
             RGBColor[
             0.9005875000000001, 0.9200127692307692, 0.8313241153846156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 385}], {
             RGBColor[
             0.7025273461538463, 0.7668706923076923, 0.9714419230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 391}], {
             RGBColor[
             0.637090076923077, 0.7137457692307692, 0.9662904615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 465}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 205}], {
             RGBColor[
             0.6578050384615384, 0.7281354999999999, 0.9692969615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 257}], {
             RGBColor[0.941146, 0.9144645384615385, 0.6541069615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 272}], {
             RGBColor[
             0.841613423076923, 0.8769854615384615, 0.9846378076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 306}], {
             RGBColor[0.5484118461538461, 0.6213819615384615, 0.962766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 317}], {
             RGBColor[0.8778414999999999, 0.905431, 0.9882105]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{69, 142}], {
             RGBColor[
             0.8691657307692308, 0.8979929999999999, 0.9539152692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 173}], {
             RGBColor[
             0.8523796923076923, 0.8854739999999999, 0.9823296538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 194}], {
             RGBColor[0.8579750384615384, 0.889647, 0.9728581923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 241}], {
             RGBColor[0.8206795, 0.6732793846153846, 0.5977561923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 388}], {
             RGBColor[
             0.7858253461538462, 0.8326119999999999, 0.9792873846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 402}], {
             RGBColor[
             0.7858253461538462, 0.8326119999999999, 0.9792873846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 461}], {
             RGBColor[
             0.6384073076923076, 0.7154430769230768, 0.9659648461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 487}], {
             RGBColor[
             0.8800923076923077, 0.9040017692307691, 0.8292813461538464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 490}], {
             RGBColor[
             0.6384073076923076, 0.7154430769230768, 0.9659648461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 84}], {
             RGBColor[
             0.8015582307692308, 0.8450465384615384, 0.9808173076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 96}], {
             RGBColor[
             0.5648403846153847, 0.6533024615384615, 0.9608408461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 131}], {
             RGBColor[
             0.8282616923076923, 0.8663391538461538, 0.9833643076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 135}], {
             RGBColor[
             0.841613423076923, 0.8769854615384615, 0.9846378076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 147}], {
             RGBColor[
             0.6165948846153846, 0.6977347692307692, 0.9642476923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 170}], {
             RGBColor[
             0.6165948846153846, 0.6977347692307692, 0.9642476923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 171}], {
             RGBColor[
             0.6165948846153846, 0.6977347692307692, 0.9642476923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 216}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[
             0.7858253461538462, 0.8326119999999999, 0.9792873846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 265}], {
             RGBColor[
             0.8015582307692308, 0.8450465384615384, 0.9808173076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 374}], {
             RGBColor[
             0.8760406923076923, 0.9026951538461538, 0.9232372692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 385}], {
             RGBColor[
             0.6820321538461539, 0.7508596923076922, 0.9693991538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 391}], {
             RGBColor[
             0.6165948846153846, 0.6977347692307692, 0.9642476923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 433}], {
             RGBColor[
             0.8800923076923077, 0.9040017692307691, 0.8292813461538464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 194}], {
             RGBColor[
             0.8784702307692308, 0.9056580000000001, 0.9749009615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 228}], {
             RGBColor[0.8952562692307693, 0.918177, 0.9464865769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 388}], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 431}], {
             RGBColor[
             0.8621086153846154, 0.8929964615384616, 0.9866805769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 462}], {
             RGBColor[
             0.7025273461538463, 0.7668706923076923, 0.9714419230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 487}], {
             RGBColor[
             0.9005875000000001, 0.9200127692307692, 0.8313241153846156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 490}], {
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 73}], {
             RGBColor[
             0.6186983461538462, 0.6982106153846154, 0.9650094615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 144}], {
             RGBColor[
             0.49309273076923066`, 0.5987499999999999, 0.9534040769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 163}], {
             RGBColor[
             0.3977133846153846, 0.5189010769230769, 0.946562923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 187}], {
             RGBColor[
             0.5982031538461539, 0.6821996153846153, 0.9629666923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 279}], {
             RGBColor[
             0.5777079615384616, 0.6661886153846155, 0.9609239230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 322}], {
             RGBColor[
             0.5982031538461539, 0.6821996153846153, 0.9629666923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 494}], {
             RGBColor[
             0.49309273076923066`, 0.5987499999999999, 0.9534040769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 93}], {
             RGBColor[
             0.884065576923077, 0.9098310000000001, 0.9654294999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 163}], {
             RGBColor[
             0.585335576923077, 0.6693134615384615, 0.9628836153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 187}], {
             RGBColor[
             0.7858253461538462, 0.8326119999999999, 0.9792873846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 322}], {
             RGBColor[
             0.7858253461538462, 0.8326119999999999, 0.9792873846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 494}], {
             RGBColor[
             0.6807149230769232, 0.7491623846153845, 0.9697247692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 82}], {
             RGBColor[
             0.841613423076923, 0.8769854615384615, 0.9846378076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 105}], {
             RGBColor[
             0.8621086153846154, 0.8929964615384616, 0.9866805769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 112}], {
             RGBColor[
             0.674486423076923, 0.7425840769230769, 0.9703598846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 153}], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 195}], {
             RGBColor[0.9178966923076922, 0.937369923076923, 0.992031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 224}], {
             RGBColor[
             0.9075370769230768, 0.7816793076923079, 0.6139728461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 234}], {
             RGBColor[
             0.8621086153846154, 0.8929964615384616, 0.9866805769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 239}], {
             RGBColor[
             0.7801278461538461, 0.8289524615384615, 0.9785094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 263}], {
             RGBColor[
             0.9286629615384614, 0.9458584615384615, 0.9897228461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 296}], {
             RGBColor[0.9045449615384615, 0.9267236153846153, 0.9907575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 342}], {
             RGBColor[
             0.841613423076923, 0.8769854615384615, 0.9846378076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 395}], {
             RGBColor[
             0.8621086153846154, 0.8929964615384616, 0.9866805769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 440}], {
             RGBColor[
             0.7146905769230768, 0.7758275384615383, 0.9733580384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 447}], {
             RGBColor[
             0.8676078461538461, 0.5357484615384616, 0.5781244999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 453}], {
             RGBColor[
             0.9286629615384614, 0.9458584615384615, 0.9897228461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 463}], {
             RGBColor[
             0.9190212307692307, 0.8292407692307692, 0.6233183076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 93}], {
             RGBColor[
             0.9781197692307693, 0.9815016153846154, 0.8457597692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 108}], {
             RGBColor[
             0.9428110769230769, 0.9540207692307692, 0.8657373461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 149}], {
             RGBColor[
             0.9161076153846155, 0.9327281538461538, 0.8631903461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 158}], {
             RGBColor[
             0.9294593461538462, 0.9433744615384616, 0.8644638461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.6793897692307692, 0.7409840769230769, 0.8432138846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 182}], {
             RGBColor[
             0.972524423076923, 0.9773286153846155, 0.8552312307692309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 206}], {
             RGBColor[
             0.7311442692307693, 0.7854163846153845, 0.8466207307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 410}], {
             RGBColor[
             0.7127525384615384, 0.7698812307692308, 0.8453397307692309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[0.52385, 0.6212804615384615, 0.9567553076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[
             0.6192293461538461, 0.7011293846153845, 0.9635964615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 238}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 333}], {
             RGBColor[0.8113893076923077, 0.853452, 0.9782441153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 343}], {
             RGBColor[
             0.8391019230769231, 0.8719797692307693, 0.8251958076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 392}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 402}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 431}], {
             RGBColor[
             0.8006230384615385, 0.8449634615384616, 0.9805522692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 436}], {
             RGBColor[
             0.5974169230769231, 0.6834210769230769, 0.9618793076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 459}], {
             RGBColor[
             0.5572127692307692, 0.6501776153846154, 0.9588811538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 462}], {
             RGBColor[
             0.6410417692307693, 0.7188376923076923, 0.9653136153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 487}], {
             RGBColor[
             0.8391019230769231, 0.8719797692307693, 0.8251958076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 81}], {
             RGBColor[
             0.6277719230769231, 0.7030406153846154, 0.9669605384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 156}], {
             RGBColor[0.9045449615384615, 0.9267236153846153, 0.9907575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 278}], {
             RGBColor[
             0.6611346923076923, 0.7319377692307691, 0.9690863846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 329}], {
             RGBColor[
             0.8487568846153847, 0.8823501538461538, 0.9854070769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 479}], {
             RGBColor[
             0.8487568846153847, 0.8823501538461538, 0.9854070769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 482}], {
             RGBColor[
             0.8487568846153847, 0.8823501538461538, 0.9854070769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 85}], {
             RGBColor[
             0.674486423076923, 0.7425840769230769, 0.9703598846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 95}], {
             RGBColor[
             0.6186983461538462, 0.6982106153846154, 0.9650094615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 97}], {
             RGBColor[
             0.6477829615384615, 0.7212914615384616, 0.9678128846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 137}], {
             RGBColor[
             0.5572127692307692, 0.6501776153846154, 0.9588811538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 145}], {
             RGBColor[
             0.5777079615384616, 0.6661886153846155, 0.9609239230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 183}], {
             RGBColor[
             0.6186983461538462, 0.6982106153846154, 0.9650094615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 346}], {
             RGBColor[
             0.6852526923076923, 0.7510726153846153, 0.9680517307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 358}], {
             RGBColor[
             0.5982031538461539, 0.6821996153846153, 0.9629666923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 404}], {
             RGBColor[
             0.7076340769230769, 0.7677646153846154, 0.9301658846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 407}], {
             RGBColor[
             0.4310761538461538, 0.5477982307692307, 0.9486887692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 408}], {
             RGBColor[
             0.44946788461538456`, 0.5633333846153845, 0.9499697692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 430}], {
             RGBColor[
             0.49309273076923066`, 0.5987499999999999, 0.9534040769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 81}], {
             RGBColor[0.6010684615384616, 0.681748, 0.9644135384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 99}], {
             RGBColor[
             0.8886077692307692, 0.9139195384615384, 0.9859023461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 122}], {
             RGBColor[0.8511380384615386, 0.8841383846153846, 0.9856635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 267}], {
             RGBColor[
             0.6177498461538462, 0.6961965769230769, 0.9654764615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 278}], {
             RGBColor[
             0.6344312307692308, 0.7106451538461538, 0.9665393846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 329}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 406}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 413}], {
             RGBColor[
             0.7182602307692308, 0.7793052307692308, 0.9729718461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 476}], {
             RGBColor[
             0.6528229615384615, 0.7261803076923077, 0.9678203846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 486}], {
             RGBColor[
             0.9156790769230769, 0.9310756153846154, 0.7630516538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 493}], {
             RGBColor[
             0.9053938076923077, 0.9264385384615385, 0.9574879615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 156}], {
             RGBColor[0.8778414999999999, 0.905431, 0.9882105]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{80, 278}], {
             RGBColor[
             0.6344312307692308, 0.7106451538461538, 0.9665393846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 307}], {
             RGBColor[
             0.7400726538461538, 0.7970135384615384, 0.9746889999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 329}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 372}], {
             RGBColor[
             0.8997984615384615, 0.9222655384615385, 0.9669594230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 406}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 417}], {
             RGBColor[
             0.7605678461538462, 0.8130245384615384, 0.9767317692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 461}], {
             RGBColor[
             0.6746353846153845, 0.7438886153846154, 0.9695375384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 486}], {
             RGBColor[
             0.9156790769230769, 0.9310756153846154, 0.7630516538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 493}], {
             RGBColor[
             0.9053938076923077, 0.9264385384615385, 0.9574879615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 83}], {
             RGBColor[
             0.5443451923076924, 0.6372914615384616, 0.9587980769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 99}], {
             RGBColor[
             0.6518899230769231, 0.7221754615384615, 0.9659258846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 237}], {
             RGBColor[
             0.45972996153846146`, 0.5698528461538461, 0.9512782307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[0.381032, 0.5044525, 0.9455]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 278}], {
             RGBColor[
             0.3977133846153846, 0.5189010769230769, 0.946562923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 329}], {
             RGBColor[
             0.585335576923077, 0.6693134615384615, 0.9628836153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 426}], {
             RGBColor[0.6010684615384616, 0.681748, 0.9644135384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 486}], {
             RGBColor[
             0.6789612307692308, 0.7393315384615384, 0.7430751923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 89}], {
             RGBColor[
             0.7038445769230769, 0.7685679999999999, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 105}], {
             RGBColor[
             0.7858253461538462, 0.8326119999999999, 0.9792873846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 184}], {
             RGBColor[
             0.7038445769230769, 0.7685679999999999, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 195}], {
             RGBColor[
             0.841613423076923, 0.8769854615384615, 0.9846378076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 225}], {
             RGBColor[
             0.8523796923076923, 0.8854739999999999, 0.9823296538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 263}], {
             RGBColor[
             0.8523796923076923, 0.8854739999999999, 0.9823296538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 296}], {
             RGBColor[
             0.8282616923076923, 0.8663391538461538, 0.9833643076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 342}], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 395}], {
             RGBColor[
             0.7858253461538462, 0.8326119999999999, 0.9792873846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 440}], {
             RGBColor[
             0.6384073076923076, 0.7154430769230768, 0.9659648461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 447}], {
             RGBColor[
             0.791324576923077, 0.47536399999999995`, 0.5707313076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 453}], {
             RGBColor[
             0.8523796923076923, 0.8854739999999999, 0.9823296538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 463}], {
             RGBColor[
             0.8427379615384616, 0.7688563076923076, 0.6159251153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 470}], {
             RGBColor[
             0.6602197307692308, 0.7331513846153845, 0.9676819999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 119}], {
             RGBColor[
             0.765330153846154, 0.8166010000000001, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 176}], {
             RGBColor[
             0.8568251153846154, 0.8872133076923078, 0.8999879615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[
             0.5960996923076924, 0.6817237692307693, 0.9622049230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 237}], {
             RGBColor[
             0.6397245384615384, 0.7171403846153847, 0.9656392307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 270}], {
             RGBColor[
             0.765330153846154, 0.8166010000000001, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 345}], {
             RGBColor[
             0.8593843461538462, 0.8882716153846155, 0.8575748846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 375}], {
             RGBColor[
             0.8595971153846155, 0.8879907692307694, 0.8272385769230772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 426}], {
             RGBColor[
             0.7810630384615386, 0.8290355384615385, 0.9787745384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 448}], {
             RGBColor[
             0.7810630384615386, 0.8290355384615385, 0.9787745384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 489}], {
             RGBColor[
             0.5960996923076924, 0.6817237692307693, 0.9622049230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 131}], {
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 135}], {
             RGBColor[0.8778414999999999, 0.905431, 0.9882105]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{84, 147}], {
             RGBColor[
             0.6528229615384615, 0.7261803076923077, 0.9678203846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 171}], {
             RGBColor[
             0.6528229615384615, 0.7261803076923077, 0.9678203846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 230}], {
             RGBColor[
             0.6344312307692308, 0.7106451538461538, 0.9665393846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 242}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 365}], {
             RGBColor[
             0.6177498461538462, 0.6961965769230769, 0.9654764615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 374}], {
             RGBColor[
             0.9122687692307693, 0.9311406923076924, 0.9268099615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 385}], {
             RGBColor[
             0.7182602307692308, 0.7793052307692308, 0.9729718461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 391}], {
             RGBColor[
             0.6528229615384615, 0.7261803076923077, 0.9678203846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 95}], {
             RGBColor[
             0.8621086153846154, 0.8929964615384616, 0.9866805769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 97}], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 137}], {
             RGBColor[
             0.8006230384615385, 0.8449634615384616, 0.9805522692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 145}], {
             RGBColor[
             0.8211182307692309, 0.8609744615384616, 0.9825950384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 183}], {
             RGBColor[
             0.8621086153846154, 0.8929964615384616, 0.9866805769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 286}], {
             RGBColor[
             0.7583154230769231, 0.8112441538461539, 0.9767923461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 346}], {
             RGBColor[
             0.9286629615384614, 0.9458584615384615, 0.9897228461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 358}], {
             RGBColor[
             0.841613423076923, 0.8769854615384615, 0.9846378076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 404}], {
             RGBColor[0.951044346153846, 0.9625504615384615, 0.951837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 407}], {
             RGBColor[
             0.674486423076923, 0.7425840769230769, 0.9703598846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 408}], {
             RGBColor[
             0.6928781538461538, 0.7581192307692307, 0.9716408846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 90}], {
             RGBColor[
             0.5686541923076923, 0.6548648846153846, 0.9618206923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 98}], {
             RGBColor[
             0.8487568846153847, 0.8823501538461538, 0.9854070769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 115}], {
             RGBColor[
             0.7858253461538462, 0.8326119999999999, 0.9792873846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 124}], {
             RGBColor[
             0.7858253461538462, 0.8326119999999999, 0.9792873846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 136}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 168}], {
             RGBColor[
             0.6807149230769232, 0.7491623846153845, 0.9697247692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[
             0.8965358846153847, 0.9187061538461538, 0.9252800384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 253}], {
             RGBColor[
             0.6807149230769232, 0.7491623846153845, 0.9697247692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 261}], {
             RGBColor[
             0.9005875000000001, 0.9200127692307692, 0.8313241153846156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 357}], {
             RGBColor[
             0.9002668461538462, 0.9193269230769231, 0.7964229230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 484}], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 500}], {
             RGBColor[
             0.8965358846153847, 0.9187061538461538, 0.9252800384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 107}], {
             RGBColor[
             0.7182602307692308, 0.7793052307692308, 0.9729718461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 113}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 143}], {
             RGBColor[
             0.7810630384615386, 0.8290355384615385, 0.9787745384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 226}], {
             RGBColor[0.6010684615384616, 0.681748, 0.9644135384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 292}], {
             RGBColor[
             0.8942031153846154, 0.9180925384615385, 0.9764308846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 308}], {
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 386}], {
             RGBColor[
             0.6528229615384615, 0.7261803076923077, 0.9678203846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 421}], {
             RGBColor[
             0.5383148846153847, 0.6209310384615385, 0.9606515769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 422}], {
             RGBColor[
             0.7400726538461538, 0.7970135384615384, 0.9746889999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 423}], {
             RGBColor[
             0.9135483846153847, 0.9316698461538462, 0.9056034230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 446}], {
             RGBColor[
             0.9163203846153847, 0.9324473076923077, 0.8328540384615387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 166}], {
             RGBColor[
             0.8593843461538462, 0.8882716153846155, 0.8575748846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 167}], {
             RGBColor[
             0.9918696923076923, 0.990905923076923, 0.7844037692307695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 210}], {
             RGBColor[
             0.7529566923076922, 0.8031246923076922, 0.8483378846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 227}], {
             RGBColor[
             0.8593843461538462, 0.8882716153846155, 0.8575748846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 243}], {
             RGBColor[
             0.7311442692307693, 0.7854163846153845, 0.8466207307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 326}], {
             RGBColor[
             0.9561628076923077, 0.964667076923077, 0.8670108461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 348}], {
             RGBColor[
             0.8798795384615385, 0.9042826153846153, 0.859617653846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 428}], {
             RGBColor[
             0.7127525384615384, 0.7698812307692308, 0.8453397307692309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 434}], {
             RGBColor[
             0.9946416923076924, 0.9916833846153846, 0.7116543846153849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 469}], {
             RGBColor[
             0.9561628076923077, 0.964667076923077, 0.8670108461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 474}], {
             RGBColor[
             0.6960711538461538, 0.7554326538461538, 0.8442768076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 495}], {
             RGBColor[
             0.6793897692307692, 0.7409840769230769, 0.8432138846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 133}], {
             RGBColor[
             0.7038445769230769, 0.7685679999999999, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 184}], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 192}], {
             RGBColor[
             0.6205465769230769, 0.7028266923076922, 0.9632708461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 225}], {
             RGBColor[
             0.7908941153846153, 0.8374409999999999, 0.9762013461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 235}], {
             RGBColor[
             0.5200361923076923, 0.6197180384615384, 0.9557754615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 239}], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 249}], {
             RGBColor[
             0.5033548076923077, 0.6052694615384615, 0.9547125384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 260}], {
             RGBColor[
             0.7400726538461538, 0.7970135384615384, 0.9746889999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.7908941153846153, 0.8374409999999999, 0.9762013461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 296}], {
             RGBColor[0.7667761153846153, 0.8183061538461538, 0.977236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 424}], {
             RGBColor[
             0.6628541923076923, 0.7365459999999999, 0.9670307692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 440}], {
             RGBColor[
             0.5769217307692307, 0.6674100769230769, 0.9598365384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 453}], {
             RGBColor[
             0.7908941153846153, 0.8374409999999999, 0.9762013461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 470}], {
             RGBColor[
             0.5987341538461537, 0.6851183846153845, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 124}], {
             RGBColor[0.548159, 0.6388538846153845, 0.959777923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 178}], {
             RGBColor[
             0.6588695384615384, 0.7249480384615383, 0.905770576923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[
             0.6476915769230769, 0.6763329615384616, 0.629247076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 261}], {
             RGBColor[
             0.6629211538461539, 0.7262546538461538, 0.8118146538461541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 272}], {
             RGBColor[0.548159, 0.6388538846153845, 0.959777923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 306}], {
             RGBColor[
             0.25495742307692304`, 0.3832503846153846, 0.9379061153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 317}], {
             RGBColor[
             0.584387076923077, 0.667299423076923, 0.9633506153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 357}], {
             RGBColor[
             0.6626004999999999, 0.7255688076923077, 0.7769134615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 172}], {
             RGBColor[
             0.7967943076923077, 0.8382604615384616, 0.8214358846153849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 303}], {
             RGBColor[
             0.9005875000000001, 0.9200127692307692, 0.8313241153846156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 366}], {
             RGBColor[
             0.9839278846153846, 0.9853937692307693, 0.8059520000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 435}], {
             RGBColor[
             0.8186067307692307, 0.8559687692307691, 0.8231530384615386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 473}], {
             RGBColor[
             0.8391019230769231, 0.8719797692307693, 0.8251958076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 101}], {
             RGBColor[0.8542658846153847, 0.886155, 0.9424010384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 128}], {
             RGBColor[0.951044346153846, 0.9625504615384615, 0.951837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 140}], {
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 169}], {
             RGBColor[0.9730013076923076, 0.979385, 0.9305859230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 175}], {
             RGBColor[
             0.7696506538461538, 0.8187163846153847, 0.9348811923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 204}], {
             RGBColor[
             0.6909526923076923, 0.7533160384615385, 0.9291029615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 219}], {
             RGBColor[
             0.9406847307692308, 0.8068598461538463, 0.5737788461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 274}], {
             RGBColor[0.8337706923076923, 0.870144, 0.9403582692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 320}], {
             RGBColor[
             0.7914630769230769, 0.8364246923076923, 0.9365983461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 334}], {
             RGBColor[
             0.7696506538461538, 0.8187163846153847, 0.9348811923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 337}], {
             RGBColor[
             0.7478382307692306, 0.8010080769230769, 0.9331640384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 361}], {
             RGBColor[0.8747610769230769, 0.902166, 0.9444438076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 363}], {
             RGBColor[0.8337706923076923, 0.870144, 0.9403582692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 370}], {
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 498}], {
             RGBColor[
             0.7478382307692306, 0.8010080769230769, 0.9331640384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 108}], {
             RGBColor[
             0.926501923076923, 0.9435581538461538, 0.969506423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 163}], {
             RGBColor[
             0.6630806153846154, 0.7305214615384615, 0.9469829615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 187}], {
             RGBColor[0.8635703846153846, 0.89382, 0.9633867307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 189}], {
             RGBColor[
             0.8430751923076923, 0.8778090000000001, 0.9613439615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 206}], {
             RGBColor[
             0.7148351153846153, 0.7749537692307692, 0.9503898076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 266}], {
             RGBColor[
             0.6964433846153846, 0.7594186153846154, 0.9491088076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 322}], {
             RGBColor[0.8635703846153846, 0.89382, 0.9633867307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 364}], {
             RGBColor[
             0.9588868076923076, 0.9170769999999999, 0.616476923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 437}], {
             RGBColor[0.8020848076923076, 0.845787, 0.957258423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 100}], {
             RGBColor[
             0.856907576923077, 0.7017249230769231, 0.6013288846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 127}], {
             RGBColor[
             0.9244282307692308, 0.7249805384615385, 0.2836043076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 168}], {
             RGBColor[
             0.7155690769230769, 0.5898297692307692, 0.5881935769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 213}], {
             RGBColor[
             0.7155690769230769, 0.5898297692307692, 0.5881935769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 214}], {
             RGBColor[
             0.856907576923077, 0.7017249230769231, 0.6013288846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 254}], {
             RGBColor[
             0.7796891153846154, 0.6412573846153846, 0.5936706538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 302}], {
             RGBColor[
             0.7796891153846154, 0.6412573846153846, 0.5936706538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 315}], {
             RGBColor[0.8206795, 0.6732793846153846, 0.5977561923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 325}], {
             RGBColor[0.7373815, 0.6075380769230769, 0.5899107307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 368}], {
             RGBColor[
             0.6719442307692307, 0.5544131538461539, 0.5847592692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 401}], {
             RGBColor[
             0.8001843076923078, 0.6572683846153847, 0.595713423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 477}], {
             RGBColor[
             0.759193923076923, 0.6252463846153846, 0.5916278846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 500}], {
             RGBColor[
             0.9313900384615384, 0.7593735384615385, 0.5437488461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 97}], {
             RGBColor[
             0.835405153846154, 0.8717038461538462, 0.9841335769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 137}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 145}], {
             RGBColor[
             0.765330153846154, 0.8166010000000001, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 174}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 286}], {
             RGBColor[
             0.7025273461538463, 0.7668706923076923, 0.9714419230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 294}], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 346}], {
             RGBColor[0.8728748846153846, 0.901485, 0.9843724230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 358}], {
             RGBColor[
             0.7858253461538462, 0.8326119999999999, 0.9792873846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 404}], {
             RGBColor[0.8952562692307693, 0.918177, 0.9464865769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 407}], {
             RGBColor[
             0.6186983461538462, 0.6982106153846154, 0.9650094615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 408}], {
             RGBColor[
             0.637090076923077, 0.7137457692307692, 0.9662904615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 430}], {
             RGBColor[
             0.6807149230769232, 0.7491623846153845, 0.9697247692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 131}], {
             RGBColor[
             0.627771923076923, 0.7030406153846154, 0.9669605384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 147}], {
             RGBColor[
             0.41610511538461536`, 0.5344362307692307, 0.9478439230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.45972996153846146`, 0.5698528461538461, 0.9512782307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 171}], {
             RGBColor[
             0.41610511538461536`, 0.5344362307692307, 0.9478439230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 180}], {
             RGBColor[0.52385, 0.6212804615384615, 0.9567553076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 216}], {
             RGBColor[
             0.5443451923076924, 0.6372914615384616, 0.9587980769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 238}], {
             RGBColor[
             0.585335576923077, 0.6693134615384615, 0.9628836153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 265}], {
             RGBColor[0.6010684615384616, 0.681748, 0.9644135384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 281}], {
             RGBColor[
             0.5443451923076924, 0.6372914615384616, 0.9587980769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 343}], {
             RGBColor[
             0.6796025384615385, 0.7407032307692307, 0.8128775769230772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 392}], {
             RGBColor[
             0.5648403846153847, 0.6533024615384615, 0.9608408461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 433}], {
             RGBColor[
             0.6796025384615385, 0.7407032307692307, 0.8128775769230772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 465}], {
             RGBColor[0.6010684615384616, 0.681748, 0.9644135384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 104}], {
             RGBColor[0.7534243846153845, 0.8076598461538461, 0.9759625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 137}], {
             RGBColor[
             0.7739195769230769, 0.8236708461538462, 0.9780052692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 145}], {
             RGBColor[
             0.7944147692307693, 0.8396818461538462, 0.9800480384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 174}], {
             RGBColor[0.8511380384615386, 0.8841383846153846, 0.9856635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 294}], {
             RGBColor[
             0.835405153846154, 0.8717038461538462, 0.9841335769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 346}], {
             RGBColor[0.9019595, 0.9245658461538462, 0.9871758461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 358}], {
             RGBColor[
             0.8149099615384616, 0.8556928461538461, 0.9820908076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 404}], {
             RGBColor[0.9243408846153847, 0.9412578461538461, 0.94929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 407}], {
             RGBColor[
             0.6477829615384615, 0.7212914615384616, 0.9678128846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 408}], {
             RGBColor[
             0.6661746923076923, 0.7368266153846154, 0.9690938846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 430}], {
             RGBColor[
             0.7097995384615384, 0.7722432307692307, 0.9725281923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 115}], {
             RGBColor[
             0.8282616923076923, 0.8663391538461538, 0.9833643076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 124}], {
             RGBColor[
             0.8282616923076923, 0.8663391538461538, 0.9833643076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 136}], {
             RGBColor[0.7667761153846153, 0.8183061538461538, 0.977236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 253}], {
             RGBColor[
             0.7231512692307691, 0.7828895384615384, 0.9738016923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 261}], {
             RGBColor[
             0.9430238461538462, 0.953739923076923, 0.8354010384615387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 277}], {
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 311}], {
             RGBColor[0.8077665, 0.8503281538461539, 0.9813215384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 319}], {
             RGBColor[
             0.6611346923076923, 0.7319377692307691, 0.9690863846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 331}], {
             RGBColor[
             0.7231512692307691, 0.7828895384615384, 0.9738016923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 377}], {
             RGBColor[
             0.8487568846153847, 0.8823501538461538, 0.9854070769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 484}], {
             RGBColor[
             0.8487568846153847, 0.8823501538461538, 0.9854070769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 488}], {
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 122}], {
             RGBColor[0.9019595, 0.9245658461538462, 0.9871758461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 267}], {
             RGBColor[
             0.6685713076923077, 0.7366240384615383, 0.9669888076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 278}], {
             RGBColor[
             0.6852526923076923, 0.7510726153846153, 0.9680517307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 329}], {
             RGBColor[0.8728748846153846, 0.901485, 0.9843724230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 406}], {
             RGBColor[0.8728748846153846, 0.901485, 0.9843724230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 413}], {
             RGBColor[
             0.7690816923076923, 0.8197326923076923, 0.9744841923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 476}], {
             RGBColor[
             0.703644423076923, 0.7666077692307691, 0.9693327307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 486}], {
             RGBColor[0.9665005384615384, 0.9715030769230769, 0.764564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 493}], {
             RGBColor[0.9562152692307692, 0.966866, 0.9590003076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 121}], {
             RGBColor[
             0.6528229615384615, 0.7261803076923077, 0.9678203846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 127}], {
             RGBColor[
             0.9053069615384616, 0.8967476923076924, 0.6666654230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 168}], {
             RGBColor[
             0.6964478076923077, 0.7615969230769231, 0.9712546923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 200}], {
             RGBColor[
             0.9161076153846155, 0.9327281538461538, 0.8631903461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 213}], {
             RGBColor[
             0.6964478076923077, 0.7615969230769231, 0.9712546923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 254}], {
             RGBColor[
             0.7605678461538462, 0.8130245384615384, 0.9767317692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 259}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 315}], {
             RGBColor[
             0.8015582307692308, 0.8450465384615384, 0.9808173076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 368}], {
             RGBColor[
             0.6528229615384615, 0.7261803076923077, 0.9678203846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 401}], {
             RGBColor[
             0.7810630384615386, 0.8290355384615385, 0.9787745384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 450}], {
             RGBColor[
             0.7400726538461538, 0.7970135384615384, 0.9746889999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 454}], {
             RGBColor[
             0.9010908076923078, 0.8825256153846155, 0.6502864615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 471}], {
             RGBColor[
             0.7810630384615386, 0.8290355384615385, 0.9787745384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 475}], {
             RGBColor[
             0.7400726538461538, 0.7970135384615384, 0.9746889999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 500}], {
             RGBColor[
             0.9122687692307693, 0.9311406923076924, 0.9268099615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 128}], {
             RGBColor[
             0.8211182307692309, 0.8609744615384616, 0.9825950384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 169}], {
             RGBColor[
             0.8430751923076923, 0.8778090000000001, 0.9613439615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 197}], {
             RGBColor[
             0.5960996923076924, 0.6817237692307693, 0.9622049230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[
             0.561026576923077, 0.6517400384615385, 0.9598610000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 219}], {
             RGBColor[
             0.8107586153846155, 0.7052838461538464, 0.6045368846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 337}], {
             RGBColor[
             0.6179121153846154, 0.6994320769230769, 0.963922076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 345}], {
             RGBColor[
             0.8593843461538462, 0.8882716153846155, 0.8575748846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 355}], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 361}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 362}], {
             RGBColor[
             0.703844576923077, 0.7685680000000001, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 363}], {
             RGBColor[
             0.703844576923077, 0.7685680000000001, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 498}], {
             RGBColor[
             0.6179121153846154, 0.6994320769230769, 0.963922076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 109}], {
             RGBColor[
             0.7148351153846153, 0.7749537692307692, 0.9503898076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[
             0.44946788461538456`, 0.5633333846153845, 0.9499697692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 186}], {
             RGBColor[
             0.6880331538461539, 0.6263228461538461, 0.5981249615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 193}], {
             RGBColor[
             0.5756045000000001, 0.6657127692307692, 0.9601621538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 196}], {
             RGBColor[
             0.703644423076923, 0.7666077692307691, 0.9693327307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 202}], {
             RGBColor[
             0.5332968846153847, 0.6319934615384615, 0.9564022307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 330}], {
             RGBColor[
             0.5551093076923077, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 350}], {
             RGBColor[
             0.637090076923077, 0.7137457692307692, 0.9662904615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 354}], {
             RGBColor[
             0.7203436153846154, 0.7494359230769231, 0.6500958076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 414}], {
             RGBColor[
             0.7311442692307693, 0.7854163846153845, 0.8466207307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 415}], {
             RGBColor[
             0.5551093076923077, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 485}], {
             RGBColor[
             0.5332968846153847, 0.6319934615384615, 0.9564022307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 496}], {
             RGBColor[
             0.44946788461538456`, 0.5633333846153845, 0.9499697692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 118}], {
             RGBColor[
             0.9717752307692307, 0.9749902307692309, 0.7201913461538463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 188}], {
             RGBColor[
             0.6908480384615384, 0.7552456153846154, 0.9585802692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 304}], {
             RGBColor[0.8579750384615384, 0.889647, 0.9728581923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 319}], {
             RGBColor[
             0.6908480384615384, 0.7552456153846154, 0.9585802692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 331}], {
             RGBColor[
             0.7528646153846152, 0.8061973846153846, 0.9632955769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 449}], {
             RGBColor[
             0.9473219230769231, 0.8892367692307693, 0.6211451538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 488}], {
             RGBColor[
             0.8942031153846154, 0.9180925384615385, 0.9764308846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 112}], {
             RGBColor[
             0.5367175769230769, 0.6341666153846153, 0.9568383846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 148}], {
             RGBColor[0.47055946153846145`, 0.5759405, 0.9526566538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 153}], {
             RGBColor[0.7534243846153845, 0.8076598461538461, 0.9759625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 190}], {
             RGBColor[
             0.759193923076923, 0.6252463846153846, 0.5916278846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 215}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 224}], {
             RGBColor[
             0.7697682307692307, 0.6732618461538463, 0.6004513461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 323}], {
             RGBColor[
             0.7038445769230769, 0.7685679999999999, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 351}], {
             RGBColor[0.7667761153846153, 0.8183061538461538, 0.977236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 356}], {
             RGBColor[0.7534243846153845, 0.8076598461538461, 0.9759625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 408}], {
             RGBColor[
             0.5551093076923077, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 430}], {
             RGBColor[
             0.5987341538461537, 0.6851183846153845, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 452}], {
             RGBColor[0.47055946153846145`, 0.5759405, 0.9526566538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 112}], {
             RGBColor[
             0.6186983461538462, 0.6982106153846154, 0.9650094615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 148}], {
             RGBColor[0.5525402307692309, 0.6399845, 0.9608277307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 153}], {
             RGBColor[
             0.835405153846154, 0.8717038461538462, 0.9841335769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 190}], {
             RGBColor[
             0.8411746923076924, 0.6892903846153846, 0.5997989615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 195}], {
             RGBColor[
             0.8621086153846154, 0.8929964615384616, 0.9866805769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 263}], {
             RGBColor[0.8728748846153846, 0.901485, 0.9843724230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 323}], {
             RGBColor[
             0.7858253461538462, 0.8326119999999999, 0.9792873846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 342}], {
             RGBColor[
             0.7858253461538462, 0.8326119999999999, 0.9792873846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 395}], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 447}], {
             RGBColor[0.8118197692307694, 0.491375, 0.5727740769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 453}], {
             RGBColor[0.8728748846153846, 0.901485, 0.9843724230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 463}], {
             RGBColor[
             0.863233153846154, 0.7848673076923076, 0.6179678846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 117}], {
             RGBColor[0.8778414999999999, 0.905431, 0.9882105]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{106, 139}], {
             RGBColor[
             0.9293514615384615, 0.9424077692307693, 0.799226346153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 140}], {
             RGBColor[0.9019595, 0.9245658461538462, 0.9871758461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 247}], {
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 255}], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 269}], {
             RGBColor[0.9019595, 0.9245658461538462, 0.9871758461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 274}], {
             RGBColor[
             0.7739195769230769, 0.8236708461538462, 0.9780052692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 360}], {
             RGBColor[
             0.6477829615384615, 0.7212914615384616, 0.9678128846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 369}], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 370}], {
             RGBColor[0.9019595, 0.9245658461538462, 0.9871758461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 425}], {
             RGBColor[
             0.835405153846154, 0.8717038461538462, 0.9841335769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 466}], {
             RGBColor[0.8778414999999999, 0.905431, 0.9882105]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{106, 468}], {
             RGBColor[
             0.6661746923076923, 0.7368266153846154, 0.9690938846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 113}], {
             RGBColor[
             0.7025273461538463, 0.7668706923076923, 0.9714419230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 132}], {
             RGBColor[
             0.7316119615384615, 0.7899515384615385, 0.9742453461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 143}], {
             RGBColor[
             0.6615369615384616, 0.7348486923076925, 0.9673563846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 209}], {
             RGBColor[
             0.7746770384615385, 0.8239056923076924, 0.9650127307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 214}], {
             RGBColor[
             0.7182602307692308, 0.7793052307692308, 0.9729718461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 273}], {
             RGBColor[
             0.7746770384615385, 0.8239056923076924, 0.9650127307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 308}], {
             RGBColor[
             0.7449636923076923, 0.8005978461538461, 0.9755188461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 421}], {
             RGBColor[
             0.4187888076923077, 0.5267441923076923, 0.949233423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 423}], {
             RGBColor[0.7940223076923076, 0.837483, 0.8941852692307694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 446}], {
             RGBColor[
             0.7967943076923077, 0.8382604615384616, 0.8214358846153849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 477}], {
             RGBColor[
             0.6205465769230769, 0.7028266923076922, 0.9632708461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 129}], {
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 163}], {
             RGBColor[
             0.6277719230769231, 0.7030406153846154, 0.9669605384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 189}], {
             RGBColor[0.8077665, 0.8503281538461539, 0.9813215384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 206}], {
             RGBColor[
             0.6795264230769231, 0.747472923076923, 0.9703673846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 266}], {
             RGBColor[
             0.6611346923076923, 0.7319377692307691, 0.9690863846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 364}], {
             RGBColor[0.9235781153846154, 0.8895961538461539, 0.6364545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 374}], {
             RGBColor[
             0.9389722307692308, 0.9524333076923077, 0.9293569615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 410}], {
             RGBColor[
             0.6611346923076923, 0.7319377692307691, 0.9690863846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 437}], {
             RGBColor[0.7667761153846153, 0.8183061538461538, 0.977236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 185}], {
             RGBColor[
             0.6964433846153846, 0.7594186153846154, 0.9491088076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 186}], {
             RGBColor[0.9350086538461538, 0.822408076923077, 0.597264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 196}], {
             RGBColor[0.950619923076923, 0.962693, 0.9684717692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 218}], {
             RGBColor[
             0.6964433846153846, 0.7594186153846154, 0.9491088076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 295}], {
             RGBColor[
             0.7366475384615383, 0.7926620769230768, 0.9521069615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 300}], {
             RGBColor[
             0.7584599615384615, 0.8103703846153846, 0.9538241153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 335}], {
             RGBColor[
             0.6302852692307692, 0.7011924999999999, 0.9449270769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 409}], {
             RGBColor[
             0.6630806153846154, 0.7305214615384615, 0.9469829615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 456}], {
             RGBColor[
             0.7584599615384615, 0.8103703846153846, 0.9538241153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 458}], {
             RGBColor[0.8020848076923076, 0.845787, 0.957258423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 496}], {
             RGBColor[
             0.6964433846153846, 0.7594186153846154, 0.9491088076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 217}], {
             RGBColor[
             0.9161076153846155, 0.9327281538461538, 0.8631903461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 290}], {
             RGBColor[
             0.7529566923076922, 0.8031246923076922, 0.8483378846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 316}], {
             RGBColor[
             0.9161076153846155, 0.9327281538461538, 0.8631903461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 340}], {
             RGBColor[
             0.9003747307692309, 0.9202936153846154, 0.8616604230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 355}], {
             RGBColor[
             0.8183939615384614, 0.8562496153846153, 0.8534893461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 378}], {
             RGBColor[
             0.7529566923076922, 0.8031246923076922, 0.8483378846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 384}], {
             RGBColor[
             0.9161076153846155, 0.9327281538461538, 0.8631903461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 146}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 201}], {
             RGBColor[
             0.6192293461538461, 0.7011293846153845, 0.9635964615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 256}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 271}], {
             RGBColor[
             0.703844576923077, 0.7685680000000001, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 284}], {
             RGBColor[
             0.6628541923076923, 0.7365459999999999, 0.9670307692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 312}], {
             RGBColor[
             0.7605678461538462, 0.8130245384615384, 0.9767317692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 376}], {
             RGBColor[
             0.8384606153846155, 0.870608076923077, 0.755393423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 415}], {
             RGBColor[
             0.6628541923076923, 0.7365459999999999, 0.9670307692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 442}], {
             RGBColor[
             0.8006230384615385, 0.8449634615384616, 0.9805522692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 444}], {
             RGBColor[
             0.6628541923076923, 0.7365459999999999, 0.9670307692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 464}], {
             RGBColor[
             0.836329923076923, 0.8712023076923077, 0.8979451923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 148}], {
             RGBColor[
             0.36491803846153836`, 0.4895721153846153, 0.9445070384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 153}], {
             RGBColor[
             0.6477829615384615, 0.7212914615384616, 0.9678128846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 190}], {
             RGBColor[0.6535525, 0.538878, 0.5834782692307693]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{112, 195}], {
             RGBColor[
             0.674486423076923, 0.7425840769230769, 0.9703598846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 224}], {
             RGBColor[
             0.6641268076923077, 0.5868934615384618, 0.5923017307692309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 263}], {
             RGBColor[
             0.6852526923076923, 0.7510726153846153, 0.9680517307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 323}], {
             RGBColor[
             0.5982031538461539, 0.6821996153846153, 0.9629666923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 342}], {
             RGBColor[
             0.5982031538461539, 0.6821996153846153, 0.9629666923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 351}], {
             RGBColor[
             0.6611346923076923, 0.7319377692307691, 0.9690863846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 356}], {
             RGBColor[
             0.6477829615384615, 0.7212914615384616, 0.9678128846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 395}], {
             RGBColor[
             0.6186983461538462, 0.6982106153846154, 0.9650094615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 447}], {
             RGBColor[
             0.6241975769230769, 0.34096261538461536`, 0.5564533846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 452}], {
             RGBColor[
             0.36491803846153836`, 0.4895721153846153, 0.9445070384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 463}], {
             RGBColor[
             0.6756109615384616, 0.634454923076923, 0.6016471923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 130}], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 143}], {
             RGBColor[
             0.765330153846154, 0.8166010000000001, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 209}], {
             RGBColor[
             0.8784702307692308, 0.9056580000000001, 0.9749009615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 214}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 273}], {
             RGBColor[
             0.8784702307692308, 0.9056580000000001, 0.9749009615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 302}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 308}], {
             RGBColor[
             0.8487568846153847, 0.8823501538461538, 0.9854070769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 325}], {
             RGBColor[
             0.7025273461538463, 0.7668706923076923, 0.9714419230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 347}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 386}], {
             RGBColor[
             0.637090076923077, 0.7137457692307692, 0.9662904615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 421}], {
             RGBColor[0.5225820000000001, 0.6084965, 0.9591216538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 423}], {
             RGBColor[
             0.8978155000000001, 0.9192353076923077, 0.9040735000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 477}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 115}], {
             RGBColor[
             0.6602197307692308, 0.7331513846153845, 0.9676819999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 203}], {
             RGBColor[
             0.6192293461538461, 0.7011293846153845, 0.9635964615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 208}], {
             RGBColor[
             0.7495666153846154, 0.7327411538461539, 0.6159689615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 258}], {
             RGBColor[
             0.5114844615384615, 0.6142851538461538, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 289}], {
             RGBColor[
             0.7584599615384615, 0.8103703846153846, 0.9538241153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 291}], {
             RGBColor[
             0.6192293461538461, 0.7011293846153845, 0.9635964615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 297}], {
             RGBColor[
             0.5987341538461537, 0.6851183846153845, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 311}], {
             RGBColor[
             0.6397245384615384, 0.7171403846153847, 0.9656392307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 349}], {
             RGBColor[
             0.6807149230769232, 0.7491623846153845, 0.9697247692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 359}], {
             RGBColor[
             0.45972996153846146`, 0.5698528461538461, 0.9512782307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 381}], {
             RGBColor[
             0.6192293461538461, 0.7011293846153845, 0.9635964615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 397}], {
             RGBColor[
             0.7584599615384615, 0.8103703846153846, 0.9538241153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 419}], {
             RGBColor[
             0.45972996153846146`, 0.5698528461538461, 0.9512782307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 124}], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 136}], {
             RGBColor[
             0.7038445769230769, 0.7685679999999999, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 178}], {
             RGBColor[
             0.8760406923076923, 0.9026951538461538, 0.9232372692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 203}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 253}], {
             RGBColor[
             0.6602197307692308, 0.7331513846153845, 0.9676819999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 277}], {
             RGBColor[
             0.8015582307692308, 0.8450465384615384, 0.9808173076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 291}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 297}], {
             RGBColor[
             0.7038445769230769, 0.7685679999999999, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 311}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 381}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 419}], {
             RGBColor[
             0.5648403846153847, 0.6533024615384615, 0.9608408461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 439}], {
             RGBColor[
             0.7858253461538462, 0.8326119999999999, 0.9792873846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 484}], {
             RGBColor[
             0.7858253461538462, 0.8326119999999999, 0.9792873846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 192}], {
             RGBColor[
             0.7316119615384615, 0.7899515384615385, 0.9742453461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 280}], {
             RGBColor[0.9019595, 0.9245658461538462, 0.9871758461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 310}], {
             RGBColor[
             0.7097995384615384, 0.7722432307692307, 0.9725281923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 327}], {
             RGBColor[
             0.9296721153846155, 0.9430936153846154, 0.8341275384615388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 399}], {
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 412}], {
             RGBColor[0.8511380384615386, 0.8841383846153846, 0.9856635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 483}], {
             RGBColor[0.8511380384615386, 0.8841383846153846, 0.9856635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 139}], {
             RGBColor[
             0.9427031923076923, 0.9530540769230769, 0.8004998461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 140}], {
             RGBColor[
             0.9153112307692307, 0.9352121538461537, 0.9884493461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 154}], {
             RGBColor[0.9056695, 0.8185944615384615, 0.6220448076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 247}], {
             RGBColor[0.8778414999999999, 0.905431, 0.9882105]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{117, 255}], {
             RGBColor[0.9045449615384615, 0.9267236153846153, 0.9907575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 269}], {
             RGBColor[
             0.9153112307692307, 0.9352121538461537, 0.9884493461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 338}], {
             RGBColor[
             0.8282616923076923, 0.8663391538461538, 0.9833643076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 369}], {
             RGBColor[0.9045449615384615, 0.9267236153846153, 0.9907575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 390}], {
             RGBColor[0.9376926153846153, 0.9519041538461539, 0.9505635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 425}], {
             RGBColor[
             0.8487568846153847, 0.8823501538461538, 0.9854070769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 466}], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[
             0.9287101538461539, 0.941036076923077, 0.7294239615384617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 151}], {
             RGBColor[
             0.8381399615384615, 0.8699222307692308, 0.7204922307692309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 188}], {
             RGBColor[
             0.7120033461538461, 0.7675428461538462, 0.7102998461538463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 304}], {
             RGBColor[
             0.8791303461538462, 0.9019442307692307, 0.7245777692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 310}], {
             RGBColor[
             0.774019923076923, 0.8184946153846153, 0.715015153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 327}], {
             RGBColor[0.9938925000000001, 0.989345, 0.5766145000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 483}], {
             RGBColor[
             0.9153584230769232, 0.9303897692307692, 0.7281504615384617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 197}], {
             RGBColor[
             0.637090076923077, 0.7137457692307692, 0.9662904615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 237}], {
             RGBColor[
             0.6807149230769232, 0.7491623846153845, 0.9697247692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 270}], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 309}], {
             RGBColor[
             0.637090076923077, 0.7137457692307692, 0.9662904615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 320}], {
             RGBColor[
             0.7025273461538463, 0.7668706923076923, 0.9714419230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 345}], {
             RGBColor[
             0.9003747307692309, 0.9202936153846154, 0.8616604230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 375}], {
             RGBColor[
             0.9005875000000001, 0.9200127692307692, 0.8313241153846156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 426}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 489}], {
             RGBColor[
             0.637090076923077, 0.7137457692307692, 0.9662904615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 123}], {
             RGBColor[
             0.6384073076923076, 0.7154430769230768, 0.9659648461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 125}], {
             RGBColor[0.548159, 0.6388538846153845, 0.959777923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 177}], {
             RGBColor[
             0.5982031538461539, 0.6821996153846153, 0.9629666923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 438}], {
             RGBColor[
             0.8773203076923077, 0.9032243076923077, 0.9020307307692309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 455}], {
             RGBColor[
             0.6384073076923076, 0.7154430769230768, 0.9659648461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 457}], {
             RGBColor[
             0.7038445769230769, 0.7685679999999999, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 161}], {
             RGBColor[
             0.5551093076923077, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[
             0.7311442692307693, 0.7854163846153845, 0.8466207307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.5114844615384615, 0.6142851538461538, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 259}], {
             RGBColor[
             0.637090076923077, 0.7137457692307692, 0.9662904615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 341}], {
             RGBColor[
             0.6661746923076923, 0.7368266153846154, 0.9690938846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 450}], {
             RGBColor[
             0.5551093076923077, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 454}], {
             RGBColor[
             0.7161274615384616, 0.7352138461538462, 0.6337168461538463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 469}], {
             RGBColor[
             0.6928781538461538, 0.7581192307692307, 0.9716408846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 471}], {
             RGBColor[
             0.5960996923076924, 0.6817237692307693, 0.9622049230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 475}], {
             RGBColor[
             0.5551093076923077, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 491}], {
             RGBColor[
             0.7311442692307693, 0.7854163846153845, 0.8466207307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 500}], {
             RGBColor[
             0.7273054230769231, 0.7838289230769231, 0.9102403461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 150}], {
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.7097995384615384, 0.7722432307692307, 0.9725281923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 233}], {
             RGBColor[
             0.7097995384615384, 0.7722432307692307, 0.9725281923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 267}], {
             RGBColor[
             0.6311015769230769, 0.7068428846153846, 0.9667499615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 406}], {
             RGBColor[
             0.835405153846154, 0.8717038461538462, 0.9841335769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 413}], {
             RGBColor[
             0.7316119615384615, 0.7899515384615385, 0.9742453461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 476}], {
             RGBColor[
             0.6661746923076923, 0.7368266153846154, 0.9690938846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 493}], {
             RGBColor[
             0.9187455384615384, 0.9370848461538461, 0.9587614615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 125}], {
             RGBColor[
             0.42123615384615376`, 0.5376959615384614, 0.9484981538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 177}], {
             RGBColor[
             0.47128030769230755`, 0.5810416923076922, 0.9516869230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 438}], {
             RGBColor[
             0.7503974615384614, 0.8020663846153846, 0.8907509615384617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 455}], {
             RGBColor[
             0.5114844615384614, 0.6142851538461537, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 136}], {
             RGBColor[
             0.7038445769230769, 0.7685679999999999, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 178}], {
             RGBColor[
             0.8760406923076923, 0.9026951538461538, 0.9232372692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 253}], {
             RGBColor[
             0.6602197307692308, 0.7331513846153845, 0.9676819999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 261}], {
             RGBColor[
             0.8800923076923077, 0.9040017692307691, 0.8292813461538464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 357}], {
             RGBColor[
             0.8797716538461539, 0.903315923076923, 0.7943801538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 484}], {
             RGBColor[
             0.7858253461538462, 0.8326119999999999, 0.9792873846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 177}], {
             RGBColor[0.3810319999999999, 0.5044525, 0.9455]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{125, 438}], {
             RGBColor[
             0.6601491538461537, 0.7254771923076924, 0.8845640384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 455}], {
             RGBColor[
             0.42123615384615376`, 0.5376959615384614, 0.9484981538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 457}], {
             RGBColor[
             0.48667342307692296`, 0.5908208846153845, 0.9536496153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 144}], {
             RGBColor[
             0.6964478076923077, 0.7615969230769231, 0.9712546923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 279}], {
             RGBColor[
             0.7810630384615386, 0.8290355384615385, 0.9787745384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 285}], {
             RGBColor[0.8778414999999999, 0.905431, 0.9882105]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{126, 481}], {
             RGBColor[
             0.9159997307692308, 0.9317614615384615, 0.7979528461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 130}], {
             RGBColor[
             0.889574076923077, 0.8843131538461539, 0.6651355000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 168}], {
             RGBColor[
             0.7639684615384614, 0.7848525384615385, 0.6535301153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 179}], {
             RGBColor[0.8280885, 0.836280153846154, 0.6590071923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 200}], {
             RGBColor[
             0.9836282692307692, 0.9559837692307693, 0.5454657692307694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 213}], {
             RGBColor[
             0.7639684615384614, 0.7848525384615385, 0.6535301153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 254}], {
             RGBColor[0.8280885, 0.836280153846154, 0.6590071923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 302}], {
             RGBColor[0.8280885, 0.836280153846154, 0.6590071923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 315}], {
             RGBColor[
             0.8690788846153846, 0.8683021538461538, 0.6630927307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 325}], {
             RGBColor[
             0.7857808846153846, 0.8025608461538463, 0.6552472692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 347}], {
             RGBColor[0.8280885, 0.836280153846154, 0.6590071923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 368}], {
             RGBColor[
             0.7203436153846154, 0.7494359230769231, 0.6500958076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 386}], {
             RGBColor[
             0.7203436153846154, 0.7494359230769231, 0.6500958076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 401}], {
             RGBColor[
             0.8485836923076924, 0.852291153846154, 0.6610499615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 454}], {
             RGBColor[
             0.9686114615384616, 0.9057812307692309, 0.3325618846153848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 169}], {
             RGBColor[
             0.9398536538461537, 0.9542044615384615, 0.9707799230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 197}], {
             RGBColor[
             0.6928781538461538, 0.7581192307692307, 0.9716408846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 204}], {
             RGBColor[
             0.6578050384615384, 0.7281354999999999, 0.9692969615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 345}], {
             RGBColor[
             0.9561628076923077, 0.964667076923077, 0.8670108461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 355}], {
             RGBColor[
             0.7801278461538461, 0.8289524615384615, 0.9785094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 362}], {
             RGBColor[
             0.8006230384615385, 0.8449634615384616, 0.9805522692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 498}], {
             RGBColor[
             0.7146905769230768, 0.7758275384615383, 0.9733580384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 170}], {
             RGBColor[
             0.6528229615384615, 0.7261803076923077, 0.9678203846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 206}], {
             RGBColor[
             0.6528229615384615, 0.7261803076923077, 0.9678203846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 265}], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 266}], {
             RGBColor[
             0.6344312307692308, 0.7106451538461538, 0.9665393846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 328}], {
             RGBColor[
             0.7400726538461538, 0.7970135384615384, 0.9746889999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 410}], {
             RGBColor[
             0.6344312307692308, 0.7106451538461538, 0.9665393846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 433}], {
             RGBColor[
             0.9163203846153847, 0.9324473076923077, 0.8328540384615387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 143}], {
             RGBColor[
             0.765330153846154, 0.8166010000000001, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 179}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 214}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 254}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 302}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 315}], {
             RGBColor[
             0.7858253461538462, 0.8326119999999999, 0.9792873846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 325}], {
             RGBColor[
             0.7025273461538463, 0.7668706923076923, 0.9714419230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 347}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 368}], {
             RGBColor[
             0.637090076923077, 0.7137457692307692, 0.9662904615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 386}], {
             RGBColor[
             0.637090076923077, 0.7137457692307692, 0.9662904615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 421}], {
             RGBColor[0.5225820000000001, 0.6084965, 0.9591216538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 477}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 135}], {
             RGBColor[0.9045449615384615, 0.9267236153846153, 0.9907575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 147}], {
             RGBColor[
             0.6795264230769231, 0.747472923076923, 0.9703673846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 170}], {
             RGBColor[
             0.6795264230769231, 0.747472923076923, 0.9703673846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 171}], {
             RGBColor[
             0.6795264230769231, 0.747472923076923, 0.9703673846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 216}], {
             RGBColor[0.8077665, 0.8503281538461539, 0.9813215384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 238}], {
             RGBColor[
             0.8487568846153847, 0.8823501538461538, 0.9854070769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 265}], {
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 374}], {
             RGBColor[
             0.9389722307692308, 0.9524333076923077, 0.9293569615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 385}], {
             RGBColor[
             0.7449636923076923, 0.8005978461538461, 0.9755188461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 391}], {
             RGBColor[
             0.6795264230769231, 0.747472923076923, 0.9703673846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 433}], {
             RGBColor[
             0.9430238461538462, 0.953739923076923, 0.8354010384615387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 209}], {
             RGBColor[
             0.9075548461538461, 0.9287388461538462, 0.9777043846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 233}], {
             RGBColor[
             0.7097995384615384, 0.7722432307692307, 0.9725281923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 273}], {
             RGBColor[
             0.9075548461538461, 0.9287388461538462, 0.9777043846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 423}], {
             RGBColor[
             0.9269001153846154, 0.9423161538461539, 0.9068769230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 151}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 155}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 181}], {
             RGBColor[
             0.6820321538461539, 0.7508596923076922, 0.9693991538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 225}], {
             RGBColor[
             0.8523796923076923, 0.8854739999999999, 0.9823296538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 235}], {
             RGBColor[
             0.5815217692307693, 0.6677510384615384, 0.9619037692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 239}], {
             RGBColor[
             0.7038445769230769, 0.7685679999999999, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 249}], {
             RGBColor[
             0.5648403846153847, 0.6533024615384615, 0.9608408461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 260}], {
             RGBColor[
             0.8015582307692308, 0.8450465384615384, 0.9808173076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 262}], {
             RGBColor[0.8635703846153846, 0.89382, 0.9633867307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 296}], {
             RGBColor[
             0.8282616923076923, 0.8663391538461538, 0.9833643076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 332}], {
             RGBColor[
             0.8797716538461539, 0.903315923076923, 0.7943801538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 344}], {
             RGBColor[
             0.841613423076923, 0.8769854615384615, 0.9846378076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 424}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 440}], {
             RGBColor[
             0.6384073076923076, 0.7154430769230768, 0.9659648461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 138}], {
             RGBColor[
             0.5071686153846153, 0.6068318846153846, 0.9556923846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 251}], {
             RGBColor[
             0.48667342307692296`, 0.5908208846153845, 0.9536496153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 305}], {
             RGBColor[
             0.44304857692307686`, 0.5554042692307691, 0.9502153076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 367}], {
             RGBColor[
             0.36435061538461533`, 0.490003923076923, 0.944437076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 416}], {
             RGBColor[
             0.2699365384615384, 0.39899438461538456`, 0.9387591538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 438}], {
             RGBColor[
             0.6601491538461537, 0.7254771923076924, 0.8845640384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 457}], {
             RGBColor[
             0.48667342307692296`, 0.5908208846153845, 0.9536496153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 499}], {
             RGBColor[
             0.6110905384615384, 0.6885920384615384, 0.9658976153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 147}], {
             RGBColor[
             0.6928781538461538, 0.7581192307692307, 0.9716408846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 170}], {
             RGBColor[
             0.6928781538461538, 0.7581192307692307, 0.9716408846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 171}], {
             RGBColor[
             0.6928781538461538, 0.7581192307692307, 0.9716408846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 216}], {
             RGBColor[
             0.8211182307692309, 0.8609744615384616, 0.9825950384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 385}], {
             RGBColor[
             0.7583154230769231, 0.8112441538461539, 0.9767923461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 391}], {
             RGBColor[
             0.6928781538461538, 0.7581192307692307, 0.9716408846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 253}], {
             RGBColor[
             0.5987341538461537, 0.6851183846153845, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 261}], {
             RGBColor[
             0.8186067307692307, 0.8559687692307691, 0.8231530384615386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 277}], {
             RGBColor[
             0.7400726538461538, 0.7970135384615384, 0.9746889999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 291}], {
             RGBColor[
             0.6628541923076923, 0.7365459999999999, 0.9670307692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 311}], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 319}], {
             RGBColor[
             0.5367175769230769, 0.6341666153846153, 0.9568383846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 377}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 484}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 488}], {
             RGBColor[
             0.7400726538461538, 0.7970135384615384, 0.9746889999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 145}], {
             RGBColor[
             0.703844576923077, 0.7685680000000001, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 183}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 346}], {
             RGBColor[0.8113893076923077, 0.853452, 0.9782441153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 358}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 404}], {
             RGBColor[0.8337706923076923, 0.870144, 0.9403582692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 407}], {
             RGBColor[
             0.5572127692307692, 0.6501776153846154, 0.9588811538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 408}], {
             RGBColor[
             0.5756045000000001, 0.6657127692307692, 0.9601621538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 430}], {
             RGBColor[
             0.6192293461538461, 0.7011293846153845, 0.9635964615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 352}], {
             RGBColor[
             0.7605678461538462, 0.8130245384615384, 0.9767317692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 367}], {
             RGBColor[
             0.5405313846153846, 0.6357290384615384, 0.9578182307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 457}], {
             RGBColor[
             0.6628541923076923, 0.7365459999999999, 0.9670307692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 140}], {
             RGBColor[
             0.9668211923076923, 0.9721889230769231, 0.7994651923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 247}], {
             RGBColor[
             0.9293514615384615, 0.9424077692307693, 0.799226346153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 255}], {
             RGBColor[
             0.9560549230769231, 0.9637003846153847, 0.8017733461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 269}], {
             RGBColor[
             0.9668211923076923, 0.9721889230769231, 0.7994651923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 274}], {
             RGBColor[
             0.8387812692307692, 0.8712939230769231, 0.7902946153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 360}], {
             RGBColor[
             0.7126446538461538, 0.7689145384615385, 0.7801022307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 369}], {
             RGBColor[
             0.9560549230769231, 0.9637003846153847, 0.8017733461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 370}], {
             RGBColor[
             0.9668211923076923, 0.9721889230769231, 0.7994651923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 425}], {
             RGBColor[
             0.9002668461538462, 0.9193269230769231, 0.7964229230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 466}], {
             RGBColor[
             0.9427031923076923, 0.9530540769230769, 0.8004998461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 468}], {
             RGBColor[
             0.7310363846153847, 0.7844496923076922, 0.7813832307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 169}], {
             RGBColor[0.950619923076923, 0.962693, 0.9684717692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 204}], {
             RGBColor[
             0.6685713076923077, 0.7366240384615383, 0.9669888076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 219}], {
             RGBColor[
             0.9183033461538461, 0.7901678461538464, 0.6116646923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 244}], {
             RGBColor[0.8728748846153846, 0.901485, 0.9843724230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 247}], {
             RGBColor[0.9019595, 0.9245658461538462, 0.9871758461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 255}], {
             RGBColor[
             0.9286629615384614, 0.9458584615384615, 0.9897228461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 274}], {
             RGBColor[0.8113893076923077, 0.853452, 0.9782441153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 334}], {
             RGBColor[
             0.7472692692307692, 0.8020243846153845, 0.9727670384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 361}], {
             RGBColor[
             0.8523796923076923, 0.8854739999999999, 0.9823296538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 363}], {
             RGBColor[0.8113893076923077, 0.853452, 0.9782441153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 369}], {
             RGBColor[
             0.9286629615384614, 0.9458584615384615, 0.9897228461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 370}], {
             RGBColor[0.9394292307692307, 0.954347, 0.9874146923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 425}], {
             RGBColor[0.8728748846153846, 0.901485, 0.9843724230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 466}], {
             RGBColor[
             0.9153112307692307, 0.9352121538461537, 0.9884493461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 188}], {
             RGBColor[
             0.6477829615384615, 0.7212914615384616, 0.9678128846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 220}], {
             RGBColor[
             0.9131501923076923, 0.9329118461538461, 0.9682329230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[0.8409043846153846, 0.5144558461538462, 0.5755775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 304}], {
             RGBColor[
             0.8149099615384616, 0.8556928461538461, 0.9820908076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 310}], {
             RGBColor[
             0.7097995384615384, 0.7722432307692307, 0.9725281923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 429}], {
             RGBColor[
             0.7739195769230769, 0.8236708461538462, 0.9780052692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 173}], {
             RGBColor[0.9562152692307692, 0.966866, 0.9590003076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 222}], {
             RGBColor[
             0.9187455384615384, 0.9370848461538461, 0.9587614615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 241}], {
             RGBColor[
             0.9245150769230769, 0.7546713846153846, 0.5744268461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 402}], {
             RGBColor[0.8896609230769231, 0.914004, 0.9559580384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 417}], {
             RGBColor[0.8281753461538461, 0.865971, 0.9498297307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 461}], {
             RGBColor[0.7422428846153846, 0.7968350769230768, 0.9426355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 179}], {
             RGBColor[
             0.703844576923077, 0.7685680000000001, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 214}], {
             RGBColor[
             0.7810630384615386, 0.8290355384615385, 0.9787745384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 226}], {
             RGBColor[
             0.5443451923076924, 0.6372914615384616, 0.9587980769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 273}], {
             RGBColor[
             0.8374798461538462, 0.8736360000000001, 0.970815423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 283}], {
             RGBColor[
             0.7810630384615386, 0.8290355384615385, 0.9787745384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 292}], {
             RGBColor[
             0.8374798461538462, 0.8736360000000001, 0.970815423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 302}], {
             RGBColor[
             0.703844576923077, 0.7685680000000001, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 308}], {
             RGBColor[0.8077665, 0.8503281538461539, 0.9813215384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 325}], {
             RGBColor[
             0.6615369615384616, 0.7348486923076925, 0.9673563846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 347}], {
             RGBColor[
             0.703844576923077, 0.7685680000000001, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 386}], {
             RGBColor[
             0.5960996923076924, 0.6817237692307693, 0.9622049230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 421}], {
             RGBColor[0.4815916153846154, 0.5764745, 0.9550361153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 423}], {
             RGBColor[
             0.8568251153846154, 0.8872133076923078, 0.8999879615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 446}], {
             RGBColor[
             0.8595971153846155, 0.8879907692307694, 0.8272385769230772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 477}], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 279}], {
             RGBColor[
             0.6397245384615384, 0.7171403846153847, 0.9656392307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 494}], {
             RGBColor[
             0.5551093076923076, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 183}], {
             RGBColor[
             0.765330153846154, 0.8166010000000001, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 286}], {
             RGBColor[
             0.6615369615384616, 0.7348486923076925, 0.9673563846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 294}], {
             RGBColor[
             0.765330153846154, 0.8166010000000001, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 346}], {
             RGBColor[0.8318845, 0.8694630000000001, 0.9802868846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 358}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 404}], {
             RGBColor[0.8542658846153847, 0.886155, 0.9424010384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 407}], {
             RGBColor[
             0.5777079615384616, 0.6661886153846155, 0.9609239230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 408}], {
             RGBColor[
             0.5960996923076924, 0.6817237692307693, 0.9622049230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 430}], {
             RGBColor[
             0.6397245384615384, 0.7171403846153847, 0.9656392307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 201}], {
             RGBColor[
             0.6602197307692308, 0.7331513846153845, 0.9676819999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 211}], {
             RGBColor[
             0.8487075000000001, 0.7925235384615386, 0.6207283461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 271}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 284}], {
             RGBColor[
             0.7038445769230769, 0.7685679999999999, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 312}], {
             RGBColor[
             0.8015582307692308, 0.8450465384615384, 0.9808173076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 376}], {
             RGBColor[0.879451, 0.9026300769230768, 0.7594789615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 400}], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 415}], {
             RGBColor[
             0.7038445769230769, 0.7685679999999999, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 442}], {
             RGBColor[
             0.841613423076923, 0.8769854615384615, 0.9846378076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 444}], {
             RGBColor[
             0.7038445769230769, 0.7685679999999999, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 464}], {
             RGBColor[
             0.8773203076923077, 0.9032243076923077, 0.9020307307692309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 497}], {
             RGBColor[
             0.5982031538461539, 0.6821996153846153, 0.9629666923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 171}], {
             RGBColor[
             0.4678596153846154, 0.5788685384615384, 0.9512507692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 216}], {
             RGBColor[
             0.5960996923076924, 0.6817237692307693, 0.9622049230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 238}], {
             RGBColor[
             0.637090076923077, 0.7137457692307692, 0.9662904615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 385}], {
             RGBColor[
             0.5332968846153847, 0.6319934615384615, 0.9564022307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 391}], {
             RGBColor[
             0.4678596153846154, 0.5788685384615384, 0.9512507692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 153}], {
             RGBColor[
             0.5816248461538461, 0.663065346153846, 0.9636311538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 190}], {
             RGBColor[
             0.5873943846153846, 0.4806518846153846, 0.5792965384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 195}], {
             RGBColor[
             0.6083283076923076, 0.6843579615384614, 0.9661781538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 323}], {
             RGBColor[0.5320450384615385, 0.6239735, 0.9587849615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 342}], {
             RGBColor[0.5320450384615385, 0.6239735, 0.9587849615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 351}], {
             RGBColor[
             0.5949765769230768, 0.6737116538461538, 0.9649046538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 356}], {
             RGBColor[
             0.5816248461538461, 0.663065346153846, 0.9636311538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 452}], {
             RGBColor[
             0.298759923076923, 0.4313459999999999, 0.9403253076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 463}], {
             RGBColor[
             0.6094528461538462, 0.5762288076923077, 0.5974654615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 158}], {
             RGBColor[0.8511380384615386, 0.8841383846153846, 0.9856635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 165}], {
             RGBColor[
             0.8942031153846154, 0.9180925384615385, 0.9764308846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 182}], {
             RGBColor[
             0.8942031153846154, 0.9180925384615385, 0.9764308846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 187}], {
             RGBColor[
             0.8015582307692308, 0.8450465384615384, 0.9808173076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 275}], {
             RGBColor[
             0.7605678461538462, 0.8130245384615384, 0.9767317692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 282}], {
             RGBColor[
             0.7605678461538462, 0.8130245384615384, 0.9767317692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 324}], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 441}], {
             RGBColor[
             0.9161076153846155, 0.9327281538461538, 0.8631903461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 159}], {
             RGBColor[
             0.7097995384615384, 0.7722432307692307, 0.9725281923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 233}], {
             RGBColor[
             0.7097995384615384, 0.7722432307692307, 0.9725281923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 267}], {
             RGBColor[
             0.6311015769230769, 0.7068428846153846, 0.9667499615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 406}], {
             RGBColor[
             0.835405153846154, 0.8717038461538462, 0.9841335769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 413}], {
             RGBColor[
             0.7316119615384615, 0.7899515384615385, 0.9742453461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 443}], {
             RGBColor[0.9186586923076923, 0.907394, 0.667938923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 476}], {
             RGBColor[
             0.6661746923076923, 0.7368266153846154, 0.9690938846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 188}], {
             RGBColor[
             0.5572127692307692, 0.6501776153846154, 0.9588811538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 192}], {
             RGBColor[
             0.6410417692307693, 0.7188376923076923, 0.9653136153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 249}], {
             RGBColor[0.52385, 0.6212804615384615, 0.9567553076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 260}], {
             RGBColor[
             0.7605678461538462, 0.8130245384615384, 0.9767317692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 280}], {
             RGBColor[0.8113893076923077, 0.853452, 0.9782441153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 310}], {
             RGBColor[
             0.6192293461538461, 0.7011293846153845, 0.9635964615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 327}], {
             RGBColor[
             0.8391019230769231, 0.8719797692307693, 0.8251958076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 424}], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 483}], {
             RGBColor[
             0.7605678461538462, 0.8130245384615384, 0.9767317692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 191}], {
             RGBColor[
             0.5149051538461539, 0.6164583076923077, 0.9551212307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 212}], {
             RGBColor[
             0.6820321538461539, 0.7508596923076922, 0.9693991538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 287}], {
             RGBColor[
             0.7449636923076923, 0.8005978461538461, 0.9755188461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 299}], {
             RGBColor[
             0.7182602307692308, 0.7793052307692308, 0.9729718461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 301}], {
             RGBColor[
             0.5551093076923077, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 389}], {
             RGBColor[
             0.7927426923076923, 0.8369538461538462, 0.9153918076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 451}], {
             RGBColor[
             0.7182602307692308, 0.7793052307692308, 0.9729718461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 190}], {
             RGBColor[
             0.8702593076923077, 0.7123712307692308, 0.6026023846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 195}], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 263}], {
             RGBColor[0.9019595, 0.9245658461538462, 0.9871758461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 323}], {
             RGBColor[
             0.8149099615384616, 0.8556928461538461, 0.9820908076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 342}], {
             RGBColor[
             0.8149099615384616, 0.8556928461538461, 0.9820908076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 351}], {
             RGBColor[0.8778414999999999, 0.905431, 0.9882105]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 395}], {
             RGBColor[
             0.835405153846154, 0.8717038461538462, 0.9841335769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 447}], {
             RGBColor[0.8409043846153846, 0.5144558461538462, 0.5755775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 452}], {
             RGBColor[
             0.5816248461538461, 0.663065346153846, 0.9636311538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 463}], {
             RGBColor[
             0.8923177692307693, 0.8079481538461538, 0.6207713076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 174}], {
             RGBColor[
             0.8789660384615385, 0.7973018461538461, 0.6194978076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 229}], {
             RGBColor[
             0.7376275384615385, 0.6854066923076922, 0.6063624999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 255}], {
             RGBColor[
             0.9190212307692307, 0.8292407692307692, 0.6233183076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 313}], {
             RGBColor[
             0.9560077307692307, 0.8560087692307692, 0.5195046923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 338}], {
             RGBColor[
             0.8427379615384616, 0.7688563076923076, 0.6159251153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 369}], {
             RGBColor[
             0.9190212307692307, 0.8292407692307692, 0.6233183076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 379}], {
             RGBColor[
             0.9409781923076923, 0.8460753076923077, 0.6020672307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 380}], {
             RGBColor[
             0.7158151153846153, 0.6676983846153846, 0.6046453461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 390}], {
             RGBColor[
             0.9521688846153846, 0.8544213076923077, 0.5831243076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 425}], {
             RGBColor[
             0.863233153846154, 0.7848673076923076, 0.6179678846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 478}], {
             RGBColor[
             0.9521688846153846, 0.8544213076923077, 0.5831243076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 181}], {
             RGBColor[
             0.6410417692307693, 0.7188376923076923, 0.9653136153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 235}], {
             RGBColor[
             0.5405313846153846, 0.6357290384615384, 0.9578182307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 262}], {
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 332}], {
             RGBColor[
             0.8387812692307692, 0.8712939230769231, 0.7902946153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 344}], {
             RGBColor[
             0.8006230384615385, 0.8449634615384616, 0.9805522692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 387}], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 393}], {
             RGBColor[
             0.5405313846153846, 0.6357290384615384, 0.9578182307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 403}], {
             RGBColor[
             0.7605678461538462, 0.8130245384615384, 0.9767317692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 232}], {
             RGBColor[
             0.841613423076923, 0.8769854615384615, 0.9846378076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 307}], {
             RGBColor[
             0.7801278461538461, 0.8289524615384615, 0.9785094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 350}], {
             RGBColor[
             0.8621086153846154, 0.8929964615384616, 0.9866805769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 354}], {
             RGBColor[
             0.9453621538461539, 0.9286866153846154, 0.6704859230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 372}], {
             RGBColor[
             0.9398536538461537, 0.9542044615384615, 0.9707799230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 479}], {
             RGBColor[
             0.8621086153846154, 0.8929964615384616, 0.9866805769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 180}], {
             RGBColor[
             0.6192293461538461, 0.7011293846153845, 0.9635964615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 216}], {
             RGBColor[
             0.6397245384615384, 0.7171403846153847, 0.9656392307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 238}], {
             RGBColor[
             0.6807149230769232, 0.7491623846153845, 0.9697247692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 246}], {
             RGBColor[
             0.6192293461538461, 0.7011293846153845, 0.9635964615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 281}], {
             RGBColor[
             0.6397245384615384, 0.7171403846153847, 0.9656392307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 288}], {
             RGBColor[
             0.6602197307692308, 0.7331513846153845, 0.9676819999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 343}], {
             RGBColor[
             0.7749818846153846, 0.8205521538461538, 0.8197187307692311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 392}], {
             RGBColor[
             0.6602197307692308, 0.7331513846153845, 0.9676819999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 459}], {
             RGBColor[
             0.49309273076923066`, 0.5987499999999999, 0.9534040769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 465}], {
             RGBColor[
             0.6964478076923077, 0.7615969230769231, 0.9712546923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 182}], {
             RGBColor[
             0.9075548461538461, 0.9287388461538462, 0.9777043846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 206}], {
             RGBColor[
             0.6661746923076923, 0.7368266153846154, 0.9690938846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 282}], {
             RGBColor[
             0.7739195769230769, 0.8236708461538462, 0.9780052692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 324}], {
             RGBColor[0.8511380384615386, 0.8841383846153846, 0.9856635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 410}], {
             RGBColor[
             0.6477829615384615, 0.7212914615384616, 0.9678128846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 441}], {
             RGBColor[
             0.9294593461538462, 0.9433744615384616, 0.8644638461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 164}], {
             RGBColor[
             0.6602197307692308, 0.7331513846153845, 0.9676819999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 396}], {
             RGBColor[
             0.6964478076923077, 0.7615969230769231, 0.9712546923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 443}], {
             RGBColor[
             0.7639684615384614, 0.7848525384615385, 0.6535301153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 165}], {
             RGBColor[0.6408038846153845, 0.7118998846153846, 0.9553915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 268}], {
             RGBColor[0.548159, 0.6388538846153845, 0.959777923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 275}], {
             RGBColor[
             0.5071686153846153, 0.6068318846153846, 0.9556923846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 285}], {
             RGBColor[
             0.6244422692307692, 0.6992383461538461, 0.9671711153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 324}], {
             RGBColor[
             0.584387076923077, 0.667299423076923, 0.9633506153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 353}], {
             RGBColor[
             0.42123615384615376`, 0.5376959615384614, 0.9484981538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 441}], {
             RGBColor[0.6627083846153845, 0.7265355, 0.8421509615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 480}], {
             RGBColor[
             0.46486099999999997`, 0.5731125769230769, 0.9519324615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 481}], {
             RGBColor[
             0.6626004999999999, 0.7255688076923077, 0.7769134615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 259}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 326}], {
             RGBColor[
             0.7801278461538461, 0.8289524615384615, 0.9785094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 341}], {
             RGBColor[0.7534243846153845, 0.8076598461538461, 0.9759625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 387}], {
             RGBColor[
             0.6628541923076923, 0.7365459999999999, 0.9670307692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 403}], {
             RGBColor[
             0.7400726538461538, 0.7970135384615384, 0.9746889999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 405}], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 450}], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 469}], {
             RGBColor[
             0.7801278461538461, 0.8289524615384615, 0.9785094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 491}], {
             RGBColor[
             0.8183939615384614, 0.8562496153846153, 0.8534893461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 203}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 221}], {
             RGBColor[
             0.8260418461538462, 0.6006921153846154, 0.5863931538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 223}], {
             RGBColor[
             0.8965358846153847, 0.9187061538461538, 0.9252800384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 258}], {
             RGBColor[
             0.637090076923077, 0.7137457692307692, 0.9662904615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 289}], {
             RGBColor[
             0.884065576923077, 0.9098310000000001, 0.9654294999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 297}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 381}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 439}], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 187}], {
             RGBColor[
             0.5648403846153847, 0.6533024615384615, 0.9608408461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.5443451923076924, 0.6372914615384616, 0.9587980769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 322}], {
             RGBColor[
             0.5648403846153847, 0.6533024615384615, 0.9608408461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 364}], {
             RGBColor[
             0.6601568076923077, 0.6765594615384615, 0.6139310384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 437}], {
             RGBColor[
             0.5033548076923077, 0.6052694615384615, 0.9547125384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 494}], {
             RGBColor[
             0.45972996153846146`, 0.5698528461538461, 0.9512782307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 166}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 227}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 309}], {
             RGBColor[
             0.6165948846153846, 0.6977347692307692, 0.9642476923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 348}], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 396}], {
             RGBColor[
             0.8015582307692308, 0.8450465384615384, 0.9808173076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 428}], {
             RGBColor[
             0.5982031538461539, 0.6821996153846153, 0.9629666923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 443}], {
             RGBColor[
             0.8690788846153846, 0.8683021538461538, 0.6630927307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 182}], {
             RGBColor[0.950619923076923, 0.962693, 0.9684717692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 268}], {
             RGBColor[0.8579750384615384, 0.889647, 0.9728581923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 275}], {
             RGBColor[
             0.8169846538461538, 0.8576250000000001, 0.9687726538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 282}], {
             RGBColor[
             0.8169846538461538, 0.8576250000000001, 0.9687726538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 285}], {
             RGBColor[
             0.9342583076923077, 0.9500314615384615, 0.9802513846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 324}], {
             RGBColor[
             0.8942031153846154, 0.9180925384615385, 0.9764308846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 353}], {
             RGBColor[
             0.7310521923076923, 0.7884890769230768, 0.9615784230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 441}], {
             RGBColor[
             0.972524423076923, 0.9773286153846155, 0.8552312307692309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 481}], {
             RGBColor[
             0.9724165384615384, 0.9763619230769232, 0.7899937307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 210}], {
             RGBColor[
             0.6179121153846154, 0.6994320769230769, 0.963922076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 227}], {
             RGBColor[
             0.7243397692307694, 0.7845790000000001, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 243}], {
             RGBColor[
             0.5960996923076924, 0.6817237692307693, 0.9622049230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 309}], {
             RGBColor[
             0.5960996923076924, 0.6817237692307693, 0.9622049230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 320}], {
             RGBColor[
             0.6615369615384616, 0.7348486923076925, 0.9673563846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 348}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 428}], {
             RGBColor[
             0.5777079615384616, 0.6661886153846155, 0.9609239230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 495}], {
             RGBColor[
             0.5443451923076924, 0.6372914615384616, 0.9587980769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 210}], {
             RGBColor[
             0.7503974615384614, 0.8020663846153846, 0.8907509615384617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 326}], {
             RGBColor[
             0.9536035769230768, 0.9636087692307692, 0.9094239230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 434}], {
             RGBColor[
             0.9920824615384616, 0.9906250769230769, 0.7540674615384619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 474}], {
             RGBColor[
             0.693511923076923, 0.7543743461538461, 0.8866898846153848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 495}], {
             RGBColor[
             0.6768305384615384, 0.7399257692307692, 0.8856269615384617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 200}], {
             RGBColor[
             0.7747691153846153, 0.8208329999999999, 0.8500550384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 213}], {
             RGBColor[
             0.5551093076923076, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 254}], {
             RGBColor[
             0.6192293461538461, 0.7011293846153845, 0.9635964615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 261}], {
             RGBColor[
             0.7749818846153846, 0.8205521538461538, 0.8197187307692311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 315}], {
             RGBColor[
             0.6602197307692308, 0.7331513846153845, 0.9676819999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 368}], {
             RGBColor[
             0.5114844615384615, 0.6142851538461538, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 401}], {
             RGBColor[
             0.6397245384615384, 0.7171403846153847, 0.9656392307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 500}], {
             RGBColor[
             0.7709302692307691, 0.8192455384615385, 0.913674653846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 204}], {
             RGBColor[0.679762, 0.7449700384615384, 0.9480458846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 219}], {
             RGBColor[
             0.9294940384615384, 0.7985138461538464, 0.5927217692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 244}], {
             RGBColor[
             0.884065576923077, 0.9098310000000001, 0.9654294999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 274}], {
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 334}], {
             RGBColor[
             0.7584599615384615, 0.8103703846153846, 0.9538241153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 337}], {
             RGBColor[
             0.7366475384615383, 0.7926620769230768, 0.9521069615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 340}], {
             RGBColor[
             0.884065576923077, 0.9098310000000001, 0.9654294999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 361}], {
             RGBColor[0.8635703846153846, 0.89382, 0.9633867307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 363}], {
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 370}], {
             RGBColor[0.950619923076923, 0.962693, 0.9684717692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 498}], {
             RGBColor[
             0.7366475384615383, 0.7926620769230768, 0.9521069615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 171}], {
             RGBColor[
             0.4678596153846154, 0.5788685384615384, 0.9512507692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 238}], {
             RGBColor[
             0.637090076923077, 0.7137457692307692, 0.9662904615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 265}], {
             RGBColor[
             0.6528229615384615, 0.7261803076923077, 0.9678203846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 266}], {
             RGBColor[
             0.44946788461538456`, 0.5633333846153845, 0.9499697692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 328}], {
             RGBColor[
             0.5551093076923077, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 374}], {
             RGBColor[
             0.7273054230769231, 0.7838289230769231, 0.9102403461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 433}], {
             RGBColor[
             0.7313570384615384, 0.7851355384615384, 0.8162844230769233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 216}], {
             RGBColor[
             0.5960996923076924, 0.6817237692307693, 0.9622049230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 238}], {
             RGBColor[
             0.637090076923077, 0.7137457692307692, 0.9662904615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 265}], {
             RGBColor[
             0.6528229615384615, 0.7261803076923077, 0.9678203846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 343}], {
             RGBColor[
             0.7313570384615384, 0.7851355384615384, 0.8162844230769233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 385}], {
             RGBColor[
             0.5332968846153847, 0.6319934615384615, 0.9564022307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 391}], {
             RGBColor[
             0.4678596153846154, 0.5788685384615384, 0.9512507692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 433}], {
             RGBColor[
             0.7313570384615384, 0.7851355384615384, 0.8162844230769233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 465}], {
             RGBColor[
             0.6528229615384615, 0.7261803076923077, 0.9678203846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 303}], {
             RGBColor[
             0.7025273461538463, 0.7668706923076923, 0.9714419230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 366}], {
             RGBColor[
             0.7858677307692308, 0.8322516923076924, 0.9460698076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 448}], {
             RGBColor[
             0.7182602307692308, 0.7793052307692308, 0.9729718461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 473}], {
             RGBColor[
             0.6410417692307693, 0.7188376923076923, 0.9653136153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 241}], {
             RGBColor[
             0.9077290384615384, 0.7421523846153846, 0.6028412307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 417}], {
             RGBColor[0.8113893076923077, 0.853452, 0.9782441153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 461}], {
             RGBColor[
             0.725456846153846, 0.7843160769230768, 0.9710498846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 493}], {
             RGBColor[0.9562152692307692, 0.966866, 0.9590003076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 215}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 229}], {
             RGBColor[
             0.6964478076923077, 0.7615969230769231, 0.9712546923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 294}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 338}], {
             RGBColor[
             0.8015582307692308, 0.8450465384615384, 0.9808173076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 356}], {
             RGBColor[0.8511380384615386, 0.8841383846153846, 0.9856635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 390}], {
             RGBColor[0.9109891538461539, 0.9306115384615385, 0.9480165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 430}], {
             RGBColor[
             0.6964478076923077, 0.7615969230769231, 0.9712546923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 309}], {
             RGBColor[
             0.5114844615384615, 0.6142851538461538, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 320}], {
             RGBColor[
             0.5769217307692307, 0.6674100769230769, 0.9598365384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 337}], {
             RGBColor[
             0.5332968846153845, 0.6319934615384615, 0.9564022307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 348}], {
             RGBColor[
             0.6602197307692308, 0.7331513846153845, 0.9676819999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 361}], {
             RGBColor[
             0.6602197307692308, 0.7331513846153845, 0.9676819999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 370}], {
             RGBColor[
             0.7472692692307692, 0.8020243846153845, 0.9727670384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 375}], {
             RGBColor[
             0.7749818846153846, 0.8205521538461538, 0.8197187307692311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 197}], {
             RGBColor[
             0.7285850384615384, 0.7843580769230769, 0.8890338076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 237}], {
             RGBColor[
             0.7722098846153845, 0.8197746923076923, 0.8924681153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 345}], {
             RGBColor[
             0.9918696923076923, 0.990905923076923, 0.7844037692307695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 426}], {
             RGBColor[
             0.9135483846153847, 0.9316698461538462, 0.9056034230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 448}], {
             RGBColor[
             0.9135483846153847, 0.9316698461538462, 0.9056034230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 245}], {
             RGBColor[
             0.6186983461538462, 0.6982106153846154, 0.9650094615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 438}], {
             RGBColor[
             0.7101933076923077, 0.768822923076923, 0.8877528076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 455}], {
             RGBColor[
             0.47128030769230755`, 0.5810416923076922, 0.9516869230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 357}], {
             RGBColor[
             0.9904821923076923, 0.9894100769230769, 0.7403728076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 420}], {
             RGBColor[
             0.8965358846153847, 0.9187061538461538, 0.9252800384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 439}], {
             RGBColor[
             0.8965358846153847, 0.9187061538461538, 0.9252800384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 236}], {
             RGBColor[
             0.7605678461538462, 0.8130245384615384, 0.9767317692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 254}], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 276}], {
             RGBColor[
             0.703844576923077, 0.7685680000000001, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 283}], {
             RGBColor[
             0.7605678461538462, 0.8130245384615384, 0.9767317692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 292}], {
             RGBColor[
             0.8169846538461538, 0.8576250000000001, 0.9687726538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 315}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 325}], {
             RGBColor[
             0.6410417692307693, 0.7188376923076923, 0.9653136153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 347}], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 368}], {
             RGBColor[
             0.5756045000000001, 0.6657127692307692, 0.9601621538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 386}], {
             RGBColor[
             0.5756045000000001, 0.6657127692307692, 0.9601621538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 401}], {
             RGBColor[
             0.703844576923077, 0.7685680000000001, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 216}], {
             RGBColor[
             0.703844576923077, 0.7685680000000001, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 281}], {
             RGBColor[
             0.703844576923077, 0.7685680000000001, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 288}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 343}], {
             RGBColor[
             0.8391019230769231, 0.8719797692307693, 0.8251958076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 392}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 465}], {
             RGBColor[
             0.7605678461538462, 0.8130245384615384, 0.9767317692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 235}], {
             RGBColor[
             0.4982237692307693, 0.6020097307692307, 0.9540583076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 239}], {
             RGBColor[
             0.6205465769230769, 0.7028266923076922, 0.9632708461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 262}], {
             RGBColor[
             0.7802723846153846, 0.8280786923076924, 0.9555412692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 296}], {
             RGBColor[
             0.7449636923076923, 0.8005978461538461, 0.9755188461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 332}], {
             RGBColor[
             0.7964736538461539, 0.8375746153846154, 0.7865346923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 344}], {
             RGBColor[
             0.7583154230769231, 0.8112441538461539, 0.9767923461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 387}], {
             RGBColor[
             0.6410417692307693, 0.7188376923076923, 0.9653136153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 393}], {
             RGBColor[
             0.4982237692307693, 0.6020097307692307, 0.9540583076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 424}], {
             RGBColor[
             0.6410417692307693, 0.7188376923076923, 0.9653136153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 275}], {
             RGBColor[
             0.8169846538461538, 0.8576250000000001, 0.9687726538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 282}], {
             RGBColor[
             0.8169846538461538, 0.8576250000000001, 0.9687726538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 324}], {
             RGBColor[
             0.8942031153846154, 0.9180925384615385, 0.9764308846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 441}], {
             RGBColor[
             0.972524423076923, 0.9773286153846155, 0.8552312307692309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 346}], {
             RGBColor[0.8728748846153846, 0.901485, 0.9843724230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 404}], {
             RGBColor[0.8952562692307693, 0.918177, 0.9464865769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 407}], {
             RGBColor[
             0.6186983461538462, 0.6982106153846154, 0.9650094615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 408}], {
             RGBColor[
             0.637090076923077, 0.7137457692307692, 0.9662904615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 192}], {
             RGBColor[
             0.6205465769230769, 0.7028266923076922, 0.9632708461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 225}], {
             RGBColor[
             0.7908941153846153, 0.8374409999999999, 0.9762013461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 249}], {
             RGBColor[
             0.5033548076923077, 0.6052694615384615, 0.9547125384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 260}], {
             RGBColor[
             0.7400726538461538, 0.7970135384615384, 0.9746889999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 280}], {
             RGBColor[
             0.7908941153846153, 0.8374409999999999, 0.9762013461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 424}], {
             RGBColor[
             0.6628541923076923, 0.7365459999999999, 0.9670307692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 440}], {
             RGBColor[
             0.5769217307692307, 0.6674100769230769, 0.9598365384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 453}], {
             RGBColor[
             0.7908941153846153, 0.8374409999999999, 0.9762013461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 470}], {
             RGBColor[
             0.5987341538461537, 0.6851183846153845, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 193}], {
             RGBColor[
             0.5572127692307692, 0.6501776153846154, 0.9588811538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 196}], {
             RGBColor[
             0.6852526923076923, 0.7510726153846153, 0.9680517307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 318}], {
             RGBColor[0.6535525, 0.538878, 0.5834782692307693]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{185, 321}], {
             RGBColor[
             0.49309273076923066`, 0.5987499999999999, 0.9534040769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 330}], {
             RGBColor[
             0.5367175769230769, 0.6341666153846153, 0.9568383846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 335}], {
             RGBColor[
             0.36491803846153836`, 0.4895721153846153, 0.9445070384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 350}], {
             RGBColor[
             0.6186983461538462, 0.6982106153846154, 0.9650094615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 383}], {
             RGBColor[
             0.6477829615384615, 0.7212914615384616, 0.9678128846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 409}], {
             RGBColor[
             0.3977133846153846, 0.5189010769230769, 0.946562923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 482}], {
             RGBColor[
             0.6186983461538462, 0.6982106153846154, 0.9650094615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 496}], {
             RGBColor[
             0.4310761538461538, 0.5477982307692307, 0.9486887692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 191}], {
             RGBColor[
             0.6696414230769231, 0.6107876923076924, 0.5968439615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 202}], {
             RGBColor[
             0.7534704230769231, 0.6794477692307693, 0.6032764230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 212}], {
             RGBColor[
             0.8367684230769231, 0.7451890769230769, 0.6111218846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 295}], {
             RGBColor[
             0.7098455769230769, 0.6440311538461538, 0.5998421153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 300}], {
             RGBColor[
             0.7316579999999999, 0.6617394615384615, 0.6015592692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 389}], {
             RGBColor[
             0.9474789615384616, 0.8312832307692308, 0.5571145384615386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 414}], {
             RGBColor[
             0.9513178076923077, 0.8328706923076924, 0.49349492307692316`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 456}], {
             RGBColor[
             0.7316579999999999, 0.6617394615384615, 0.6015592692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 485}], {
             RGBColor[
             0.7534704230769231, 0.6794477692307693, 0.6032764230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 322}], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 494}], {
             RGBColor[
             0.6602197307692308, 0.7331513846153845, 0.9676819999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 304}], {
             RGBColor[
             0.5982031538461539, 0.6821996153846153, 0.9629666923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 310}], {
             RGBColor[
             0.49309273076923066`, 0.5987499999999999, 0.9534040769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 483}], {
             RGBColor[
             0.6344312307692308, 0.7106451538461538, 0.9665393846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 266}], {
             RGBColor[
             0.5777079615384616, 0.6661886153846155, 0.9609239230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 364}], {
             RGBColor[0.8401513846153847, 0.823847, 0.6282920384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 374}], {
             RGBColor[
             0.8555455000000001, 0.8866841538461538, 0.9211945000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 437}], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 195}], {
             RGBColor[
             0.8969627692307691, 0.7336638461538462, 0.6051493846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 224}], {
             RGBColor[
             0.8866031538461538, 0.577973230769231, 0.22709123076923082`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 263}], {
             RGBColor[
             0.9077290384615384, 0.7421523846153846, 0.6028412307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 323}], {
             RGBColor[0.8206795, 0.6732793846153846, 0.5977561923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 342}], {
             RGBColor[0.8206795, 0.6732793846153846, 0.5977561923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 351}], {
             RGBColor[
             0.8836110384615384, 0.7230175384615385, 0.6038758846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 356}], {
             RGBColor[
             0.8702593076923077, 0.7123712307692308, 0.6026023846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 395}], {
             RGBColor[
             0.8411746923076924, 0.6892903846153846, 0.5997989615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 452}], {
             RGBColor[
             0.5873943846153846, 0.4806518846153846, 0.5792965384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 463}], {
             RGBColor[
             0.8980873076923077, 0.6255346923076923, 0.23643669230769232`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 212}], {
             RGBColor[
             0.5982031538461539, 0.6821996153846153, 0.9629666923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 218}], {
             RGBColor[
             0.4310761538461538, 0.5477982307692307, 0.9486887692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 287}], {
             RGBColor[
             0.6611346923076923, 0.7319377692307691, 0.9690863846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 295}], {
             RGBColor[
             0.47128030769230755`, 0.5810416923076922, 0.9516869230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 299}], {
             RGBColor[
             0.6344312307692308, 0.7106451538461538, 0.9665393846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 300}], {
             RGBColor[
             0.49309273076923066`, 0.5987499999999999, 0.9534040769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 301}], {
             RGBColor[
             0.47128030769230755`, 0.5810416923076922, 0.9516869230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 389}], {
             RGBColor[
             0.7089136923076922, 0.7682937692307692, 0.9089593461538463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 451}], {
             RGBColor[
             0.6344312307692308, 0.7106451538461538, 0.9665393846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 456}], {
             RGBColor[
             0.49309273076923066`, 0.5987499999999999, 0.9534040769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[
             0.7690816923076923, 0.8197326923076923, 0.9744841923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 249}], {
             RGBColor[
             0.4815423846153847, 0.5875611538461538, 0.9529953846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 260}], {
             RGBColor[
             0.7182602307692308, 0.7793052307692308, 0.9729718461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 280}], {
             RGBColor[
             0.7690816923076923, 0.8197326923076923, 0.9744841923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 327}], {
             RGBColor[
             0.7967943076923077, 0.8382604615384616, 0.8214358846153849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 470}], {
             RGBColor[
             0.5769217307692307, 0.6674100769230769, 0.9598365384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 483}], {
             RGBColor[
             0.7182602307692308, 0.7793052307692308, 0.9729718461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 196}], {
             RGBColor[0.8113893076923077, 0.853452, 0.9782441153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 202}], {
             RGBColor[
             0.6410417692307693, 0.7188376923076923, 0.9653136153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 232}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 330}], {
             RGBColor[
             0.6628541923076923, 0.7365459999999999, 0.9670307692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 350}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 354}], {
             RGBColor[0.8280885, 0.836280153846154, 0.6590071923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 376}], {
             RGBColor[
             0.8384606153846155, 0.870608076923077, 0.755393423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 414}], {
             RGBColor[
             0.8388891538461538, 0.8722606153846154, 0.8555321153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 415}], {
             RGBColor[
             0.6628541923076923, 0.7365459999999999, 0.9670307692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 485}], {
             RGBColor[
             0.6410417692307693, 0.7188376923076923, 0.9653136153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 496}], {
             RGBColor[
             0.5572127692307692, 0.6501776153846154, 0.9588811538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 228}], {
             RGBColor[0.9674059615384615, 0.975212, 0.9400573846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 388}], {
             RGBColor[
             0.8784702307692308, 0.9056580000000001, 0.9749009615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 490}], {
             RGBColor[
             0.7310521923076923, 0.7884890769230768, 0.9615784230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 224}], {
             RGBColor[
             0.9075370769230768, 0.7816793076923079, 0.6139728461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 263}], {
             RGBColor[
             0.9286629615384614, 0.9458584615384615, 0.9897228461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 296}], {
             RGBColor[0.9045449615384615, 0.9267236153846153, 0.9907575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 323}], {
             RGBColor[
             0.841613423076923, 0.8769854615384615, 0.9846378076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 342}], {
             RGBColor[
             0.841613423076923, 0.8769854615384615, 0.9846378076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 351}], {
             RGBColor[0.9045449615384615, 0.9267236153846153, 0.9907575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 395}], {
             RGBColor[
             0.8621086153846154, 0.8929964615384616, 0.9866805769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 447}], {
             RGBColor[
             0.8676078461538461, 0.5357484615384616, 0.5781244999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 453}], {
             RGBColor[
             0.9286629615384614, 0.9458584615384615, 0.9897228461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 463}], {
             RGBColor[
             0.9190212307692307, 0.8292407692307692, 0.6233183076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 318}], {
             RGBColor[
             0.9077290384615384, 0.7421523846153846, 0.6028412307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 321}], {
             RGBColor[
             0.7472692692307692, 0.8020243846153845, 0.9727670384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 330}], {
             RGBColor[
             0.7908941153846153, 0.8374409999999999, 0.9762013461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 335}], {
             RGBColor[0.6190945769230769, 0.6928464999999999, 0.96387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 350}], {
             RGBColor[0.8728748846153846, 0.901485, 0.9843724230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 354}], {
             RGBColor[
             0.956128423076923, 0.9371751538461539, 0.6681777692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 383}], {
             RGBColor[0.9019595, 0.9245658461538462, 0.9871758461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 414}], {
             RGBColor[
             0.966929076923077, 0.9731556153846154, 0.8647026923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 479}], {
             RGBColor[0.8728748846153846, 0.901485, 0.9843724230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 482}], {
             RGBColor[0.8728748846153846, 0.901485, 0.9843724230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 496}], {
             RGBColor[
             0.6852526923076923, 0.7510726153846153, 0.9680517307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 237}], {
             RGBColor[
             0.5114844615384615, 0.6142851538461538, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 270}], {
             RGBColor[
             0.637090076923077, 0.7137457692307692, 0.9662904615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 345}], {
             RGBColor[
             0.7311442692307693, 0.7854163846153845, 0.8466207307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 375}], {
             RGBColor[
             0.7313570384615384, 0.7851355384615384, 0.8162844230769233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 426}], {
             RGBColor[
             0.6528229615384615, 0.7261803076923077, 0.9678203846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 448}], {
             RGBColor[
             0.6528229615384615, 0.7261803076923077, 0.9678203846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 489}], {
             RGBColor[
             0.4678596153846154, 0.5788685384615384, 0.9512507692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 223}], {
             RGBColor[
             0.8965358846153847, 0.9187061538461538, 0.9252800384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 373}], {
             RGBColor[0.5225820000000001, 0.6084965, 0.9591216538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 480}], {
             RGBColor[
             0.7025273461538463, 0.7668706923076923, 0.9714419230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 208}], {
             RGBColor[
             0.7495666153846154, 0.7327411538461539, 0.6159689615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 220}], {
             RGBColor[
             0.7584599615384615, 0.8103703846153846, 0.9538241153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 349}], {
             RGBColor[
             0.6807149230769232, 0.7491623846153845, 0.9697247692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 359}], {
             RGBColor[
             0.45972996153846146`, 0.5698528461538461, 0.9512782307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 371}], {
             RGBColor[
             0.7749818846153846, 0.8205521538461538, 0.8197187307692311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 382}], {
             RGBColor[
             0.6397245384615384, 0.7171403846153847, 0.9656392307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 397}], {
             RGBColor[
             0.7584599615384615, 0.8103703846153846, 0.9538241153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 419}], {
             RGBColor[
             0.45972996153846146`, 0.5698528461538461, 0.9512782307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 427}], {
             RGBColor[
             0.7734894999999999, 0.8203038461538461, 0.8712615769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 429}], {
             RGBColor[
             0.6192293461538461, 0.7011293846153845, 0.9635964615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 213}], {
             RGBColor[
             0.7747691153846153, 0.8208329999999999, 0.8500550384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 243}], {
             RGBColor[
             0.7311442692307693, 0.7854163846153845, 0.8466207307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 254}], {
             RGBColor[
             0.8388891538461538, 0.8722606153846154, 0.8555321153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 259}], {
             RGBColor[
             0.9003747307692309, 0.9202936153846154, 0.8616604230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 401}], {
             RGBColor[
             0.8593843461538462, 0.8882716153846155, 0.8575748846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 450}], {
             RGBColor[
             0.8183939615384614, 0.8562496153846153, 0.8534893461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 454}], {
             RGBColor[
             0.9794121153846154, 0.9417616923076924, 0.5290868076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 469}], {
             RGBColor[
             0.9561628076923077, 0.964667076923077, 0.8670108461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 471}], {
             RGBColor[
             0.8593843461538462, 0.8882716153846155, 0.8575748846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 475}], {
             RGBColor[
             0.8183939615384614, 0.8562496153846153, 0.8534893461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 500}], {
             RGBColor[
             0.9905900769230769, 0.9903767692307692, 0.8056103076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 222}], {
             RGBColor[
             0.7097995384615384, 0.7722432307692307, 0.9725281923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 246}], {
             RGBColor[
             0.6192293461538461, 0.7011293846153845, 0.9635964615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 256}], {
             RGBColor[
             0.6602197307692308, 0.7331513846153845, 0.9676819999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 271}], {
             RGBColor[
             0.6397245384615384, 0.7171403846153847, 0.9656392307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 312}], {
             RGBColor[
             0.6964478076923077, 0.7615969230769231, 0.9712546923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 333}], {
             RGBColor[
             0.7472692692307692, 0.8020243846153845, 0.9727670384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 400}], {
             RGBColor[
             0.6602197307692308, 0.7331513846153845, 0.9676819999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 442}], {
             RGBColor[
             0.7365029999999999, 0.7935358461538461, 0.9750751923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 444}], {
             RGBColor[
             0.5987341538461537, 0.6851183846153845, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 492}], {
             RGBColor[
             0.6602197307692308, 0.7331513846153845, 0.9676819999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 211}], {
             RGBColor[
             0.7654095000000001, 0.726782230769231, 0.6128828846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 414}], {
             RGBColor[
             0.7965815384615385, 0.8385413076923077, 0.8517721923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 485}], {
             RGBColor[
             0.5987341538461539, 0.6851183846153847, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 497}], {
             RGBColor[
             0.5149051538461539, 0.6164583076923077, 0.9551212307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 221}], {
             RGBColor[
             0.7645562692307692, 0.5526591153846154, 0.5802648461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 258}], {
             RGBColor[
             0.5756045000000001, 0.6657127692307692, 0.9601621538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 289}], {
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 291}], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 297}], {
             RGBColor[
             0.6628541923076923, 0.7365459999999999, 0.9670307692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 381}], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 397}], {
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 419}], {
             RGBColor[0.52385, 0.6212804615384615, 0.9567553076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 439}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 219}], {
             RGBColor[
             0.6474454230769231, 0.5724448846153848, 0.5912388076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 244}], {
             RGBColor[
             0.6020169615384616, 0.6837620384615384, 0.9639465384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 274}], {
             RGBColor[
             0.5405313846153846, 0.6357290384615384, 0.9578182307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 334}], {
             RGBColor[
             0.47641134615384606`, 0.584301423076923, 0.9523411538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 337}], {
             RGBColor[0.45459892307692296`, 0.5665931153846153, 0.950624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 340}], {
             RGBColor[
             0.6020169615384616, 0.6837620384615384, 0.9639465384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 361}], {
             RGBColor[
             0.5815217692307693, 0.6677510384615384, 0.9619037692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 362}], {
             RGBColor[
             0.5405313846153846, 0.6357290384615384, 0.9578182307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 363}], {
             RGBColor[
             0.5405313846153846, 0.6357290384615384, 0.9578182307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 370}], {
             RGBColor[
             0.6685713076923077, 0.7366240384615383, 0.9669888076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 498}], {
             RGBColor[0.45459892307692296`, 0.5665931153846153, 0.950624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 228}], {
             RGBColor[
             0.6909526923076923, 0.7533160384615385, 0.9291029615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 252}], {
             RGBColor[
             0.5200361923076923, 0.6197180384615384, 0.9557754615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 388}], {
             RGBColor[
             0.6020169615384616, 0.6837620384615384, 0.9639465384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 432}], {
             RGBColor[
             0.5405313846153846, 0.6357290384615384, 0.9578182307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 490}], {
             RGBColor[0.45459892307692296`, 0.5665931153846153, 0.950624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 266}], {
             RGBColor[
             0.44946788461538456`, 0.5633333846153845, 0.9499697692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 410}], {
             RGBColor[
             0.44946788461538456`, 0.5633333846153845, 0.9499697692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 218}], {
             RGBColor[
             0.5367175769230769, 0.6341666153846153, 0.9568383846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 287}], {
             RGBColor[0.7667761153846153, 0.8183061538461538, 0.977236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 295}], {
             RGBColor[
             0.5769217307692307, 0.6674100769230769, 0.9598365384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 336}], {
             RGBColor[
             0.6628541923076923, 0.7365459999999999, 0.9670307692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 389}], {
             RGBColor[
             0.8145551153846153, 0.8546621538461538, 0.9171089615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 409}], {
             RGBColor[
             0.5033548076923077, 0.6052694615384615, 0.9547125384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 456}], {
             RGBColor[
             0.5987341538461537, 0.6851183846153845, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 458}], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[
             0.7059417692307692, 0.6973245384615385, 0.6125346538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 289}], {
             RGBColor[
             0.9529172692307692, 0.8934097692307693, 0.6116736923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 314}], {
             RGBColor[
             0.7277541923076922, 0.7150328461538462, 0.6142518076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 349}], {
             RGBColor[
             0.8751722307692309, 0.8322017692307693, 0.6275743461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 359}], {
             RGBColor[
             0.6541872692307693, 0.6528922307692309, 0.6091278076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 397}], {
             RGBColor[
             0.9529172692307692, 0.8934097692307693, 0.6116736923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 427}], {
             RGBColor[
             0.9679468076923077, 0.9033432307692308, 0.5291111538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 472}], {
             RGBColor[
             0.8136866538461539, 0.7841687692307693, 0.6214460384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 214}], {
             RGBColor[
             0.8942031153846154, 0.9180925384615385, 0.9764308846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 233}], {
             RGBColor[
             0.7528646153846152, 0.8061973846153846, 0.9632955769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 273}], {
             RGBColor[0.950619923076923, 0.962693, 0.9684717692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 421}], {
             RGBColor[
             0.5947316923076922, 0.6655314999999999, 0.9526924615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 423}], {
             RGBColor[
             0.9699651923076922, 0.9762703076923077, 0.8976443076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 477}], {
             RGBColor[0.7964894615384615, 0.841614, 0.9667298846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 227}], {
             RGBColor[
             0.6179121153846154, 0.6994320769230769, 0.963922076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 243}], {
             RGBColor[
             0.4896720384615384, 0.5965768461538461, 0.952967923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 326}], {
             RGBColor[
             0.7146905769230768, 0.7758275384615383, 0.9733580384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 348}], {
             RGBColor[
             0.6384073076923076, 0.7154430769230768, 0.9659648461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 428}], {
             RGBColor[
             0.47128030769230755`, 0.5810416923076922, 0.9516869230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 434}], {
             RGBColor[
             0.7531694615384614, 0.8028438461538461, 0.8180015769230772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 469}], {
             RGBColor[
             0.7146905769230768, 0.7758275384615383, 0.9733580384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 474}], {
             RGBColor[0.45459892307692296`, 0.5665931153846153, 0.950624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 495}], {
             RGBColor[
             0.43791753846153836`, 0.5521445384615383, 0.9495610769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 464}], {
             RGBColor[
             0.9606976538461538, 0.8791468461538463, 0.5455144615384617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 485}], {
             RGBColor[
             0.7654095000000001, 0.726782230769231, 0.6128828846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 497}], {
             RGBColor[0.6815805, 0.658122153846154, 0.6064504230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 287}], {
             RGBColor[
             0.8282616923076923, 0.8663391538461538, 0.9833643076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 295}], {
             RGBColor[
             0.6384073076923076, 0.7154430769230768, 0.9659648461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 299}], {
             RGBColor[
             0.8015582307692308, 0.8450465384615384, 0.9808173076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 300}], {
             RGBColor[
             0.6602197307692308, 0.7331513846153845, 0.9676819999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 301}], {
             RGBColor[
             0.6384073076923076, 0.7154430769230768, 0.9659648461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 389}], {
             RGBColor[
             0.8760406923076923, 0.9026951538461538, 0.9232372692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 451}], {
             RGBColor[
             0.8015582307692308, 0.8450465384615384, 0.9808173076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 456}], {
             RGBColor[
             0.6602197307692308, 0.7331513846153845, 0.9676819999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 254}], {
             RGBColor[
             0.6192293461538461, 0.7011293846153845, 0.9635964615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 259}], {
             RGBColor[
             0.6807149230769232, 0.7491623846153845, 0.9697247692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 261}], {
             RGBColor[
             0.7749818846153846, 0.8205521538461538, 0.8197187307692311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 315}], {
             RGBColor[
             0.6602197307692308, 0.7331513846153845, 0.9676819999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 368}], {
             RGBColor[
             0.5114844615384615, 0.6142851538461538, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 401}], {
             RGBColor[
             0.6397245384615384, 0.7171403846153847, 0.9656392307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 450}], {
             RGBColor[
             0.5987341538461537, 0.6851183846153845, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 454}], {
             RGBColor[
             0.7597523076923076, 0.7706304615384616, 0.637151153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 471}], {
             RGBColor[
             0.6397245384615384, 0.7171403846153847, 0.9656392307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 475}], {
             RGBColor[
             0.5987341538461537, 0.6851183846153845, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 500}], {
             RGBColor[
             0.7709302692307691, 0.8192455384615385, 0.913674653846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 273}], {
             RGBColor[
             0.8942031153846154, 0.9180925384615385, 0.9764308846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 302}], {
             RGBColor[
             0.7605678461538462, 0.8130245384615384, 0.9767317692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 347}], {
             RGBColor[
             0.7605678461538462, 0.8130245384615384, 0.9767317692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 421}], {
             RGBColor[
             0.5383148846153847, 0.6209310384615385, 0.9606515769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 423}], {
             RGBColor[
             0.9135483846153847, 0.9316698461538462, 0.9056034230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 477}], {
             RGBColor[
             0.7400726538461538, 0.7970135384615384, 0.9746889999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 224}], {
             RGBColor[
             0.8517490000000001, 0.7373058461538464, 0.608622423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 351}], {
             RGBColor[
             0.8487568846153847, 0.8823501538461538, 0.9854070769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 356}], {
             RGBColor[
             0.835405153846154, 0.8717038461538462, 0.9841335769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 430}], {
             RGBColor[
             0.6807149230769232, 0.7491623846153845, 0.9697247692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 238}], {
             RGBColor[
             0.765330153846154, 0.8166010000000001, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 281}], {
             RGBColor[
             0.7243397692307694, 0.7845790000000001, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 343}], {
             RGBColor[
             0.8595971153846155, 0.8879907692307694, 0.8272385769230772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 465}], {
             RGBColor[
             0.7810630384615386, 0.8290355384615385, 0.9787745384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 290}], {
             RGBColor[
             0.6746353846153845, 0.7438886153846154, 0.9695375384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 340}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 355}], {
             RGBColor[
             0.7400726538461538, 0.7970135384615384, 0.9746889999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 362}], {
             RGBColor[
             0.7605678461538462, 0.8130245384615384, 0.9767317692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 378}], {
             RGBColor[
             0.6746353846153845, 0.7438886153846154, 0.9695375384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 384}], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 498}], {
             RGBColor[
             0.6746353846153845, 0.7438886153846154, 0.9695375384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 295}], {
             RGBColor[
             0.47128030769230755`, 0.5810416923076922, 0.9516869230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.49309273076923066`, 0.5987499999999999, 0.9534040769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 336}], {
             RGBColor[
             0.5572127692307692, 0.6501776153846154, 0.9588811538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 389}], {
             RGBColor[
             0.7089136923076922, 0.7682937692307692, 0.9089593461538463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 409}], {
             RGBColor[
             0.3977133846153846, 0.5189010769230769, 0.946562923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 456}], {
             RGBColor[
             0.49309273076923066`, 0.5987499999999999, 0.9534040769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 458}], {
             RGBColor[
             0.5367175769230769, 0.6341666153846153, 0.9568383846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 244}], {
             RGBColor[
             0.8517490000000001, 0.7373058461538464, 0.6086224230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 274}], {
             RGBColor[
             0.7902634230769231, 0.6892728461538464, 0.6024941153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 334}], {
             RGBColor[
             0.7261433846153846, 0.6378452307692309, 0.5970170384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 337}], {
             RGBColor[
             0.7043309615384614, 0.6201369230769231, 0.5952998846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 340}], {
             RGBColor[
             0.8517490000000001, 0.7373058461538464, 0.6086224230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 361}], {
             RGBColor[
             0.8312538076923077, 0.7212948461538463, 0.6065796538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 363}], {
             RGBColor[
             0.7902634230769231, 0.6892728461538464, 0.6024941153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 369}], {
             RGBColor[
             0.9075370769230768, 0.7816793076923079, 0.6139728461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 370}], {
             RGBColor[
             0.9183033461538461, 0.7901678461538464, 0.6116646923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 498}], {
             RGBColor[
             0.7043309615384614, 0.6201369230769231, 0.5952998846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 349}], {
             RGBColor[
             0.884065576923077, 0.9098310000000001, 0.9654294999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 359}], {
             RGBColor[
             0.6630806153846154, 0.7305214615384615, 0.9469829615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 371}], {
             RGBColor[
             0.9783325384615384, 0.9812207692307693, 0.8154234615384618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 382}], {
             RGBColor[
             0.8430751923076923, 0.8778090000000001, 0.9613439615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 416}], {
             RGBColor[0.5853479230769231, 0.6539605, 0.9423679615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 427}], {
             RGBColor[
             0.9768401538461537, 0.9809724615384615, 0.8669663076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 429}], {
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 499}], {
             RGBColor[
             0.926501923076923, 0.9435581538461538, 0.969506423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 223}], {
             RGBColor[
             0.9162571923076923, 0.6707752692307691, 0.5303430384615386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 258}], {
             RGBColor[
             0.6568113846153847, 0.46581488461538456`, 0.5713534615384614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 297}], {
             RGBColor[
             0.7440610769230769, 0.5366481153846153, 0.5782220769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 381}], {
             RGBColor[
             0.7645562692307692, 0.5526591153846154, 0.5802648461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 439}], {
             RGBColor[
             0.8260418461538462, 0.6006921153846154, 0.5863931538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 307}], {
             RGBColor[0.7534243846153845, 0.8076598461538461, 0.9759625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 333}], {
             RGBColor[0.9019595, 0.9245658461538462, 0.9871758461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 372}], {
             RGBColor[
             0.9131501923076923, 0.9329118461538461, 0.9682329230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 417}], {
             RGBColor[
             0.7739195769230769, 0.8236708461538462, 0.9780052692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 258}], {
             RGBColor[
             0.7273054230769231, 0.7838289230769231, 0.9102403461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 268}], {
             RGBColor[
             0.8760406923076923, 0.9026951538461538, 0.9232372692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 373}], {
             RGBColor[
             0.6127973461538461, 0.6785796538461538, 0.9030715384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 381}], {
             RGBColor[
             0.8350503076923077, 0.8706731538461538, 0.9191517307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 480}], {
             RGBColor[
             0.7927426923076923, 0.8369538461538462, 0.9153918076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 263}], {
             RGBColor[
             0.9183033461538461, 0.7901678461538464, 0.6116646923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 342}], {
             RGBColor[
             0.8312538076923077, 0.7212948461538463, 0.6065796538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 351}], {
             RGBColor[
             0.8941853461538462, 0.7710330000000002, 0.6126993461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 356}], {
             RGBColor[
             0.8808336153846155, 0.7603866923076925, 0.6114258461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 463}], {
             RGBColor[
             0.9086616153846154, 0.673550153846154, 0.2452601538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 235}], {
             RGBColor[
             0.6685713076923077, 0.7366240384615383, 0.9669888076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 249}], {
             RGBColor[
             0.6518899230769231, 0.7221754615384615, 0.9659258846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 260}], {
             RGBColor[
             0.8886077692307692, 0.9139195384615384, 0.9859023461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 280}], {
             RGBColor[0.9394292307692307, 0.954347, 0.9874146923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 296}], {
             RGBColor[
             0.9153112307692307, 0.9352121538461537, 0.9884493461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 424}], {
             RGBColor[0.8113893076923077, 0.853452, 0.9782441153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 440}], {
             RGBColor[
             0.725456846153846, 0.7843160769230768, 0.9710498846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 453}], {
             RGBColor[0.9394292307692307, 0.954347, 0.9874146923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 470}], {
             RGBColor[
             0.7472692692307692, 0.8020243846153845, 0.9727670384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 236}], {
             RGBColor[0.6010684615384616, 0.681748, 0.9644135384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 283}], {
             RGBColor[0.6010684615384616, 0.681748, 0.9644135384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 292}], {
             RGBColor[
             0.6574852692307691, 0.7263484615384616, 0.9564544230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 308}], {
             RGBColor[
             0.627771923076923, 0.7030406153846154, 0.9669605384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 386}], {
             RGBColor[
             0.41610511538461536`, 0.5344362307692307, 0.9478439230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 396}], {
             RGBColor[0.6010684615384616, 0.681748, 0.9644135384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 422}], {
             RGBColor[
             0.5033548076923077, 0.6052694615384615, 0.9547125384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 446}], {
             RGBColor[
             0.6796025384615385, 0.7407032307692307, 0.8128775769230772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 309}], {
             RGBColor[
             0.5960996923076924, 0.6817237692307693, 0.9622049230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 320}], {
             RGBColor[
             0.6615369615384616, 0.7348486923076925, 0.9673563846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 348}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 428}], {
             RGBColor[
             0.5777079615384616, 0.6661886153846155, 0.9609239230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 495}], {
             RGBColor[
             0.5443451923076924, 0.6372914615384616, 0.9587980769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 388}], {
             RGBColor[0.8952562692307693, 0.918177, 0.9464865769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 490}], {
             RGBColor[
             0.7478382307692306, 0.8010080769230769, 0.9331640384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 244}], {
             RGBColor[
             0.6807149230769232, 0.7491623846153845, 0.9697247692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 248}], {
             RGBColor[
             0.47641134615384606`, 0.584301423076923, 0.9523411538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 255}], {
             RGBColor[
             0.7365029999999999, 0.7935358461538461, 0.9750751923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 313}], {
             RGBColor[
             0.7734894999999999, 0.8203038461538461, 0.8712615769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 338}], {
             RGBColor[
             0.6602197307692308, 0.7331513846153845, 0.9676819999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 379}], {
             RGBColor[
             0.7584599615384615, 0.8103703846153846, 0.9538241153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 380}], {
             RGBColor[
             0.5332968846153845, 0.6319934615384615, 0.9564022307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 390}], {
             RGBColor[
             0.7696506538461538, 0.8187163846153847, 0.9348811923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 411}], {
             RGBColor[
             0.5987341538461537, 0.6851183846153845, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 478}], {
             RGBColor[
             0.7696506538461538, 0.8187163846153847, 0.9348811923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 242}], {
             RGBColor[
             0.6186983461538462, 0.6982106153846154, 0.9650094615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 339}], {
             RGBColor[
             0.6186983461538462, 0.6982106153846154, 0.9650094615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 365}], {
             RGBColor[
             0.4143947692307692, 0.5333496538461537, 0.9476258461538463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 374}], {
             RGBColor[
             0.7089136923076922, 0.7682937692307692, 0.9089593461538463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 391}], {
             RGBColor[
             0.44946788461538456`, 0.5633333846153845, 0.9499697692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 246}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 256}], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 271}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 288}], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 442}], {
             RGBColor[
             0.841613423076923, 0.8769854615384615, 0.9846378076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 444}], {
             RGBColor[
             0.7038445769230769, 0.7685679999999999, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 492}], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 307}], {
             RGBColor[
             0.7038445769230769, 0.7685679999999999, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 312}], {
             RGBColor[
             0.8015582307692308, 0.8450465384615384, 0.9808173076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 330}], {
             RGBColor[
             0.7038445769230769, 0.7685679999999999, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 350}], {
             RGBColor[
             0.7858253461538462, 0.8326119999999999, 0.9792873846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 354}], {
             RGBColor[
             0.8690788846153846, 0.8683021538461538, 0.6630927307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 372}], {
             RGBColor[0.8635703846153846, 0.89382, 0.9633867307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 376}], {
             RGBColor[0.879451, 0.9026300769230768, 0.7594789615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 400}], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 414}], {
             RGBColor[
             0.8798795384615385, 0.9042826153846153, 0.859617653846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 415}], {
             RGBColor[
             0.7038445769230769, 0.7685679999999999, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 476}], {
             RGBColor[
             0.5114844615384615, 0.6142851538461538, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 235}], {
             RGBColor[
             0.6020169615384616, 0.6837620384615384, 0.9639465384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 262}], {
             RGBColor[
             0.884065576923077, 0.9098310000000001, 0.9654294999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 296}], {
             RGBColor[
             0.8487568846153847, 0.8823501538461538, 0.9854070769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 332}], {
             RGBColor[
             0.9002668461538462, 0.9193269230769231, 0.7964229230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 393}], {
             RGBColor[
             0.6020169615384616, 0.6837620384615384, 0.9639465384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 468}], {
             RGBColor[
             0.637090076923077, 0.7137457692307692, 0.9662904615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 239}], {
             RGBColor[
             0.5200361923076923, 0.6197180384615384, 0.9557754615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 249}], {
             RGBColor[0.381032, 0.5044525, 0.9455]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 260}], {
             RGBColor[
             0.6177498461538462, 0.6961965769230769, 0.9654764615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 262}], {
             RGBColor[0.679762, 0.7449700384615384, 0.9480458846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 296}], {
             RGBColor[
             0.6444533076923077, 0.7174891923076923, 0.9680234615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 332}], {
             RGBColor[
             0.6959632692307691, 0.7544659615384615, 0.7790393076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 344}], {
             RGBColor[
             0.6578050384615384, 0.7281354999999999, 0.9692969615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 393}], {
             RGBColor[
             0.3977133846153846, 0.5189010769230769, 0.9465629230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 424}], {
             RGBColor[
             0.5405313846153846, 0.6357290384615384, 0.9578182307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 440}], {
             RGBColor[0.45459892307692296`, 0.5665931153846153, 0.950624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 453}], {
             RGBColor[
             0.6685713076923077, 0.7366240384615383, 0.9669888076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 243}], {
             RGBColor[
             0.6528229615384615, 0.7261803076923077, 0.9678203846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 276}], {
             RGBColor[
             0.7810630384615386, 0.8290355384615385, 0.9787745384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 283}], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 292}], {
             RGBColor[
             0.8942031153846154, 0.9180925384615385, 0.9764308846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 396}], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 422}], {
             RGBColor[
             0.7400726538461538, 0.7970135384615384, 0.9746889999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 267}], {
             RGBColor[
             0.47641134615384606`, 0.584301423076923, 0.9523411538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 270}], {
             RGBColor[
             0.6807149230769232, 0.7491623846153845, 0.9697247692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 329}], {
             RGBColor[
             0.6807149230769232, 0.7491623846153845, 0.9697247692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 426}], {
             RGBColor[
             0.6964478076923077, 0.7615969230769231, 0.9712546923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 448}], {
             RGBColor[
             0.6964478076923077, 0.7615969230769231, 0.9712546923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 489}], {
             RGBColor[
             0.5114844615384615, 0.6142851538461538, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 265}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 328}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 343}], {
             RGBColor[
             0.9005875000000001, 0.9200127692307692, 0.8313241153846156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 431}], {
             RGBColor[
             0.8621086153846154, 0.8929964615384616, 0.9866805769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 433}], {
             RGBColor[
             0.9005875000000001, 0.9200127692307692, 0.8313241153846156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 436}], {
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 462}], {
             RGBColor[
             0.7025273461538463, 0.7668706923076923, 0.9714419230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 465}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 262}], {
             RGBColor[0.8020848076923076, 0.845787, 0.957258423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 263}], {
             RGBColor[
             0.7908941153846153, 0.8374409999999999, 0.9762013461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 296}], {
             RGBColor[0.7667761153846153, 0.8183061538461538, 0.977236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 332}], {
             RGBColor[
             0.8182860769230769, 0.855282923076923, 0.7882518461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 393}], {
             RGBColor[
             0.5200361923076923, 0.6197180384615384, 0.9557754615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 424}], {
             RGBColor[
             0.6628541923076923, 0.7365459999999999, 0.9670307692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 440}], {
             RGBColor[
             0.5769217307692307, 0.6674100769230769, 0.9598365384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 453}], {
             RGBColor[
             0.7908941153846153, 0.8374409999999999, 0.9762013461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 251}], {
             RGBColor[0.7298389999999999, 0.42733099999999996`, 0.564603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 310}], {
             RGBColor[
             0.6862141538461538, 0.3919143846153846, 0.5611686923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 352}], {
             RGBColor[0.827552653846154, 0.5038095384615384, 0.574304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 367}], {
             RGBColor[
             0.6075161923076923, 0.3265140384615384, 0.5553904615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 382}], {
             RGBColor[
             0.7708293846153846, 0.45935300000000007`, 0.5686885384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 399}], {
             RGBColor[0.8409043846153846, 0.5144558461538462, 0.5755775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 412}], {
             RGBColor[0.827552653846154, 0.5038095384615384, 0.574304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 416}], {
             RGBColor[
             0.5131021153846154, 0.23550449999999998`, 0.5497125384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 429}], {
             RGBColor[0.7503341923076923, 0.443342, 0.5666457692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 402}], {
             RGBColor[
             0.8411746923076924, 0.6892903846153846, 0.5997989615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 417}], {
             RGBColor[
             0.7796891153846154, 0.6412573846153846, 0.5936706538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 436}], {
             RGBColor[
             0.6937566538461537, 0.5721214615384616, 0.586476423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 461}], {
             RGBColor[
             0.6937566538461537, 0.5721214615384616, 0.586476423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 339}], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 365}], {
             RGBColor[
             0.6020169615384616, 0.6837620384615384, 0.9639465384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 374}], {
             RGBColor[
             0.8965358846153847, 0.9187061538461538, 0.9252800384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 276}], {
             RGBColor[
             0.5960996923076924, 0.6817237692307693, 0.9622049230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 326}], {
             RGBColor[
             0.6928781538461538, 0.7581192307692307, 0.9716408846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 428}], {
             RGBColor[
             0.44946788461538456`, 0.5633333846153845, 0.9499697692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 454}], {
             RGBColor[
             0.7161274615384616, 0.7352138461538462, 0.6337168461538463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 469}], {
             RGBColor[
             0.6928781538461538, 0.7581192307692307, 0.9716408846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 471}], {
             RGBColor[
             0.5960996923076924, 0.6817237692307693, 0.9622049230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 475}], {
             RGBColor[
             0.5551093076923077, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 495}], {
             RGBColor[
             0.41610511538461536`, 0.5344362307692307, 0.9478439230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 274}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 313}], {
             RGBColor[
             0.8990951153846154, 0.9197644615384615, 0.8828669615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 334}], {
             RGBColor[
             0.6807149230769232, 0.7491623846153845, 0.9697247692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 340}], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 355}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 363}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 378}], {
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 379}], {
             RGBColor[
             0.884065576923077, 0.9098310000000001, 0.9654294999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 380}], {
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 390}], {
             RGBColor[0.8952562692307693, 0.918177, 0.9464865769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 498}], {
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 394}], {
             RGBColor[
             0.7025273461538463, 0.7668706923076923, 0.9714419230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 438}], {
             RGBColor[
             0.8978155000000001, 0.9192353076923077, 0.9040735000000002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 445}], {
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 460}], {
             RGBColor[
             0.6186983461538462, 0.6982106153846154, 0.9650094615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 256}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 288}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 333}], {
             RGBColor[0.8113893076923077, 0.853452, 0.9782441153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 392}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 442}], {
             RGBColor[
             0.8006230384615385, 0.8449634615384616, 0.9805522692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 444}], {
             RGBColor[
             0.6628541923076923, 0.7365459999999999, 0.9670307692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 459}], {
             RGBColor[
             0.5572127692307692, 0.6501776153846154, 0.9588811538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 492}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 255}], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 269}], {
             RGBColor[0.9019595, 0.9245658461538462, 0.9871758461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 360}], {
             RGBColor[
             0.6477829615384615, 0.7212914615384616, 0.9678128846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 369}], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 370}], {
             RGBColor[0.9019595, 0.9245658461538462, 0.9871758461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 425}], {
             RGBColor[
             0.835405153846154, 0.8717038461538462, 0.9841335769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 466}], {
             RGBColor[0.8778414999999999, 0.905431, 0.9882105]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{247, 468}], {
             RGBColor[
             0.6661746923076923, 0.7368266153846154, 0.9690938846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 286}], {
             RGBColor[
             0.4982237692307693, 0.6020097307692307, 0.9540583076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 294}], {
             RGBColor[
             0.6020169615384616, 0.6837620384615384, 0.9639465384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 313}], {
             RGBColor[0.6947915384615384, 0.7549035, 0.8654833461538463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 380}], {
             RGBColor[0.45459892307692296`, 0.5665931153846153, 0.950624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 411}], {
             RGBColor[
             0.5200361923076923, 0.6197180384615384, 0.9557754615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 478}], {
             RGBColor[
             0.6909526923076923, 0.7533160384615385, 0.9291029615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 260}], {
             RGBColor[0.6010684615384616, 0.681748, 0.9644135384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 280}], {
             RGBColor[
             0.6518899230769231, 0.7221754615384615, 0.9659258846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 296}], {
             RGBColor[
             0.627771923076923, 0.7030406153846154, 0.9669605384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 424}], {
             RGBColor[0.52385, 0.6212804615384615, 0.9567553076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 440}], {
             RGBColor[
             0.43791753846153836`, 0.5521445384615383, 0.9495610769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 470}], {
             RGBColor[
             0.45972996153846146`, 0.5698528461538461, 0.9512782307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 339}], {
             RGBColor[
             0.6186983461538462, 0.6982106153846154, 0.9650094615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 365}], {
             RGBColor[
             0.4143947692307692, 0.5333496538461537, 0.9476258461538463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 305}], {
             RGBColor[
             0.5987341538461537, 0.6851183846153845, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 367}], {
             RGBColor[
             0.5200361923076923, 0.6197180384615384, 0.9557754615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 382}], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 416}], {
             RGBColor[
             0.42562211538461536`, 0.5287084999999999, 0.9500975384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 427}], {
             RGBColor[
             0.8171143461538461, 0.8557204615384615, 0.8746958846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 429}], {
             RGBColor[
             0.6628541923076923, 0.7365459999999999, 0.9670307692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 499}], {
             RGBColor[0.7667761153846153, 0.8183061538461538, 0.977236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 282}], {
             RGBColor[
             0.6628541923076923, 0.7365459999999999, 0.9670307692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 432}], {
             RGBColor[
             0.6628541923076923, 0.7365459999999999, 0.9670307692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 467}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 261}], {
             RGBColor[
             0.7749818846153846, 0.8205521538461538, 0.8197187307692311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 277}], {
             RGBColor[
             0.6964478076923077, 0.7615969230769231, 0.9712546923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 291}], {
             RGBColor[
             0.6192293461538461, 0.7011293846153845, 0.9635964615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 311}], {
             RGBColor[
             0.6397245384615384, 0.7171403846153847, 0.9656392307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 319}], {
             RGBColor[
             0.49309273076923066`, 0.5987499999999999, 0.9534040769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 377}], {
             RGBColor[
             0.6807149230769232, 0.7491623846153845, 0.9697247692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 484}], {
             RGBColor[
             0.6807149230769232, 0.7491623846153845, 0.9697247692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 488}], {
             RGBColor[
             0.6964478076923077, 0.7615969230769231, 0.9712546923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 315}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 325}], {
             RGBColor[
             0.6410417692307693, 0.7188376923076923, 0.9653136153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 347}], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 368}], {
             RGBColor[
             0.5756045000000001, 0.6657127692307692, 0.9601621538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 386}], {
             RGBColor[
             0.5756045000000001, 0.6657127692307692, 0.9601621538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 401}], {
             RGBColor[
             0.703844576923077, 0.7685680000000001, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 454}], {
             RGBColor[
             0.8238723461538462, 0.822058076923077, 0.6426282307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 471}], {
             RGBColor[
             0.703844576923077, 0.7685680000000001, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 269}], {
             RGBColor[
             0.9286629615384614, 0.9458584615384615, 0.9897228461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 274}], {
             RGBColor[
             0.8006230384615385, 0.8449634615384616, 0.9805522692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 334}], {
             RGBColor[
             0.7365029999999999, 0.7935358461538461, 0.9750751923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 338}], {
             RGBColor[
             0.841613423076923, 0.8769854615384615, 0.9846378076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 369}], {
             RGBColor[0.9178966923076922, 0.937369923076923, 0.992031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 370}], {
             RGBColor[
             0.9286629615384614, 0.9458584615384615, 0.9897228461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 379}], {
             RGBColor[
             0.9398536538461537, 0.9542044615384615, 0.9707799230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 390}], {
             RGBColor[0.951044346153846, 0.9625504615384615, 0.951837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 425}], {
             RGBColor[
             0.8621086153846154, 0.8929964615384616, 0.9866805769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 466}], {
             RGBColor[0.9045449615384615, 0.9267236153846153, 0.9907575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 271}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 333}], {
             RGBColor[
             0.8523796923076923, 0.8854739999999999, 0.9823296538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 442}], {
             RGBColor[
             0.841613423076923, 0.8769854615384615, 0.9846378076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 444}], {
             RGBColor[
             0.7038445769230769, 0.7685679999999999, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 492}], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 272}], {
             RGBColor[
             0.8648627307692308, 0.854080076923077, 0.6467137692307694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 306}], {
             RGBColor[
             0.5716611538461539, 0.598476576923077, 0.6248419615384617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 317}], {
             RGBColor[
             0.9010908076923078, 0.8825256153846155, 0.6502864615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 357}], {
             RGBColor[0.9793042307692308, 0.940795, 0.46384930769230776`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 418}], {
             RGBColor[
             0.9686114615384616, 0.9057812307692309, 0.3325618846153848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 420}], {
             RGBColor[
             0.8853579230769232, 0.870091076923077, 0.6487565384615386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 289}], {
             RGBColor[
             0.7148351153846153, 0.7749537692307692, 0.9503898076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 297}], {
             RGBColor[
             0.5551093076923077, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 314}], {
             RGBColor[
             0.4896720384615384, 0.5965768461538461, 0.952967923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 373}], {
             RGBColor[
             0.35335153846153844`, 0.4736192692307692, 0.9440819615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 381}], {
             RGBColor[
             0.5756045000000001, 0.6657127692307692, 0.9601621538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 397}], {
             RGBColor[
             0.7148351153846153, 0.7749537692307692, 0.9503898076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 472}], {
             RGBColor[
             0.5756045000000001, 0.6657127692307692, 0.9601621538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 341}], {
             RGBColor[
             0.835405153846154, 0.8717038461538462, 0.9841335769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 405}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 450}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 454}], {
             RGBColor[
             0.8853579230769232, 0.870091076923077, 0.6487565384615386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 469}], {
             RGBColor[
             0.8621086153846154, 0.8929964615384616, 0.9866805769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 471}], {
             RGBColor[
             0.765330153846154, 0.8166010000000001, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 475}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 491}], {
             RGBColor[
             0.9003747307692309, 0.9202936153846154, 0.8616604230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 500}], {
             RGBColor[
             0.8965358846153847, 0.9187061538461538, 0.9252800384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 280}], {
             RGBColor[
             0.8886077692307692, 0.9139195384615384, 0.9859023461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 424}], {
             RGBColor[
             0.7605678461538462, 0.8130245384615384, 0.9767317692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 440}], {
             RGBColor[
             0.6746353846153845, 0.7438886153846154, 0.9695375384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 470}], {
             RGBColor[
             0.6964478076923077, 0.7615969230769231, 0.9712546923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 483}], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 484}], {
             RGBColor[
             0.9005875000000001, 0.9200127692307692, 0.8313241153846156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 500}], {
             RGBColor[
             0.9908028461538462, 0.9900959230769231, 0.7752740000000004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 332}], {
             RGBColor[
             0.9780118846153846, 0.9805349230769231, 0.7805222692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 344}], {
             RGBColor[
             0.9398536538461537, 0.9542044615384615, 0.9707799230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 387}], {
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 393}], {
             RGBColor[0.679762, 0.7449700384615384, 0.9480458846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 424}], {
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 296}], {
             RGBColor[
             0.9153112307692307, 0.9352121538461537, 0.9884493461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 323}], {
             RGBColor[
             0.8523796923076923, 0.8854739999999999, 0.9823296538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 342}], {
             RGBColor[
             0.8523796923076923, 0.8854739999999999, 0.9823296538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 395}], {
             RGBColor[0.8728748846153846, 0.901485, 0.9843724230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 440}], {
             RGBColor[
             0.725456846153846, 0.7843160769230768, 0.9710498846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 447}], {
             RGBColor[0.8783741153846154, 0.544237, 0.5758163461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 453}], {
             RGBColor[0.9394292307692307, 0.954347, 0.9874146923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 463}], {
             RGBColor[0.9297875, 0.8377293076923076, 0.6210101538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 394}], {
             RGBColor[
             0.7025273461538463, 0.7668706923076923, 0.9714419230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 398}], {
             RGBColor[0.5525402307692309, 0.6399845, 0.9608277307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 445}], {
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 328}], {
             RGBColor[
             0.7400726538461538, 0.7970135384615384, 0.9746889999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 433}], {
             RGBColor[
             0.9163203846153847, 0.9324473076923077, 0.8328540384615387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 462}], {
             RGBColor[
             0.7182602307692308, 0.7793052307692308, 0.9729718461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 364}], {
             RGBColor[
             0.6935195769230769, 0.7054566153846153, 0.6160568846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 374}], {
             RGBColor[
             0.7089136923076922, 0.7682937692307692, 0.9089593461538463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 410}], {
             RGBColor[
             0.4310761538461538, 0.5477982307692307, 0.9486887692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 437}], {
             RGBColor[
             0.5367175769230769, 0.6341666153846153, 0.9568383846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 278}], {
             RGBColor[
             0.4143947692307692, 0.5333496538461537, 0.9476258461538463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 329}], {
             RGBColor[
             0.6020169615384616, 0.6837620384615384, 0.9639465384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 406}], {
             RGBColor[
             0.6020169615384616, 0.6837620384615384, 0.9639465384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 413}], {
             RGBColor[
             0.4982237692307693, 0.6020097307692307, 0.9540583076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 476}], {
             RGBColor[
             0.43278649999999996`, 0.5488848076923076, 0.9489068461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 486}], {
             RGBColor[
             0.6956426153846154, 0.7537801153846153, 0.7441381153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 493}], {
             RGBColor[
             0.685357346153846, 0.7491430384615384, 0.9385744230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 275}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 285}], {
             RGBColor[
             0.841613423076923, 0.8769854615384615, 0.9846378076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 324}], {
             RGBColor[
             0.8015582307692308, 0.8450465384615384, 0.9808173076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 353}], {
             RGBColor[
             0.6384073076923076, 0.7154430769230768, 0.9659648461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 441}], {
             RGBColor[
             0.8798795384615385, 0.9042826153846153, 0.859617653846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 480}], {
             RGBColor[
             0.6820321538461539, 0.7508596923076922, 0.9693991538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 481}], {
             RGBColor[
             0.8797716538461539, 0.903315923076923, 0.7943801538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 360}], {
             RGBColor[
             0.6852526923076923, 0.7510726153846153, 0.9680517307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 369}], {
             RGBColor[
             0.9286629615384614, 0.9458584615384615, 0.9897228461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 425}], {
             RGBColor[0.8728748846153846, 0.901485, 0.9843724230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 466}], {
             RGBColor[
             0.9153112307692307, 0.9352121538461537, 0.9884493461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 468}], {
             RGBColor[
             0.703644423076923, 0.7666077692307691, 0.9693327307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 309}], {
             RGBColor[
             0.637090076923077, 0.7137457692307692, 0.9662904615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 345}], {
             RGBColor[
             0.9003747307692309, 0.9202936153846154, 0.8616604230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 375}], {
             RGBColor[
             0.9005875000000001, 0.9200127692307692, 0.8313241153846156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 426}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 489}], {
             RGBColor[
             0.637090076923077, 0.7137457692307692, 0.9662904615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 284}], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 442}], {
             RGBColor[
             0.8211182307692309, 0.8609744615384616, 0.9825950384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 444}], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 464}], {
             RGBColor[
             0.8568251153846154, 0.8872133076923078, 0.8999879615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 492}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 306}], {
             RGBColor[
             0.47212857692307697`, 0.5609974999999999, 0.9553728076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 317}], {
             RGBColor[
             0.8015582307692308, 0.8450465384615384, 0.9808173076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 357}], {
             RGBColor[
             0.8797716538461539, 0.903315923076923, 0.7943801538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 308}], {
             RGBColor[
             0.9209065769230769, 0.9393851538461538, 0.9789778846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 421}], {
             RGBColor[
             0.5947316923076922, 0.6655314999999999, 0.9526924615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 423}], {
             RGBColor[
             0.9699651923076922, 0.9762703076923077, 0.8976443076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 446}], {
             RGBColor[
             0.9727371923076923, 0.9770477692307693, 0.8248949230769234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 477}], {
             RGBColor[0.7964894615384615, 0.841614, 0.9667298846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 334}], {
             RGBColor[
             0.6192293461538461, 0.7011293846153845, 0.9635964615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 340}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 361}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 363}], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 369}], {
             RGBColor[
             0.8006230384615385, 0.8449634615384616, 0.9805522692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 370}], {
             RGBColor[0.8113893076923077, 0.853452, 0.9782441153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 379}], {
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 498}], {
             RGBColor[
             0.5974169230769231, 0.6834210769230769, 0.9618793076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 282}], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 285}], {
             RGBColor[
             0.8006230384615385, 0.8449634615384616, 0.9805522692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 324}], {
             RGBColor[
             0.7605678461538462, 0.8130245384615384, 0.9767317692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 353}], {
             RGBColor[
             0.5974169230769231, 0.6834210769230769, 0.9618793076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 441}], {
             RGBColor[
             0.8388891538461538, 0.8722606153846154, 0.8555321153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 481}], {
             RGBColor[
             0.8387812692307692, 0.8712939230769231, 0.7902946153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 283}], {
             RGBColor[
             0.7810630384615386, 0.8290355384615385, 0.9787745384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 292}], {
             RGBColor[
             0.8374798461538462, 0.8736360000000001, 0.970815423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 396}], {
             RGBColor[
             0.7810630384615386, 0.8290355384615385, 0.9787745384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 422}], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 291}], {
             RGBColor[
             0.7605678461538462, 0.8130245384615384, 0.9767317692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 311}], {
             RGBColor[
             0.7810630384615386, 0.8290355384615385, 0.9787745384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 319}], {
             RGBColor[
             0.6344312307692308, 0.7106451538461538, 0.9665393846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 331}], {
             RGBColor[
             0.6964478076923077, 0.7615969230769231, 0.9712546923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 377}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 419}], {
             RGBColor[0.6010684615384616, 0.681748, 0.9644135384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 449}], {
             RGBColor[
             0.8909051153846155, 0.8446363076923078, 0.6291042692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 484}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 488}], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 329}], {
             RGBColor[
             0.6186983461538462, 0.6982106153846154, 0.9650094615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 406}], {
             RGBColor[
             0.6186983461538462, 0.6982106153846154, 0.9650094615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 413}], {
             RGBColor[
             0.5149051538461539, 0.6164583076923077, 0.9551212307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 486}], {
             RGBColor[0.712324, 0.7682286923076923, 0.7452010384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 493}], {
             RGBColor[
             0.7020387307692306, 0.7635916153846154, 0.9396373461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.8211182307692309, 0.8609744615384616, 0.9825950384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 324}], {
             RGBColor[
             0.7810630384615386, 0.8290355384615385, 0.9787745384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 481}], {
             RGBColor[
             0.8592764615384616, 0.8873049230769232, 0.7923373846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 494}], {
             RGBColor[
             0.6397245384615384, 0.7171403846153847, 0.9656392307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 327}], {
             RGBColor[
             0.9671418461538461, 0.9728747692307692, 0.8343663846153848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 470}], {
             RGBColor[
             0.7472692692307692, 0.8020243846153845, 0.9727670384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 483}], {
             RGBColor[
             0.8886077692307692, 0.9139195384615384, 0.9859023461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 288}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 343}], {
             RGBColor[
             0.8595971153846155, 0.8879907692307694, 0.8272385769230772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 465}], {
             RGBColor[
             0.7810630384615386, 0.8290355384615385, 0.9787745384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 324}], {
             RGBColor[
             0.7605678461538462, 0.8130245384615384, 0.9767317692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 353}], {
             RGBColor[
             0.5974169230769231, 0.6834210769230769, 0.9618793076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 432}], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 441}], {
             RGBColor[
             0.8388891538461538, 0.8722606153846154, 0.8555321153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 467}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 292}], {
             RGBColor[
             0.8942031153846154, 0.9180925384615385, 0.9764308846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 386}], {
             RGBColor[
             0.6528229615384615, 0.7261803076923077, 0.9678203846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 422}], {
             RGBColor[
             0.7400726538461538, 0.7970135384615384, 0.9746889999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 442}], {
             RGBColor[
             0.7801278461538461, 0.8289524615384615, 0.9785094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 444}], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 464}], {
             RGBColor[
             0.8158347307692306, 0.8551913076923077, 0.8959024230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 324}], {
             RGBColor[0.8778414999999999, 0.905431, 0.9882105]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{285, 480}], {
             RGBColor[
             0.7583154230769231, 0.8112441538461539, 0.9767923461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 481}], {
             RGBColor[
             0.9560549230769231, 0.9637003846153847, 0.8017733461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 294}], {
             RGBColor[
             0.7025273461538463, 0.7668706923076923, 0.9714419230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 346}], {
             RGBColor[
             0.7690816923076923, 0.8197326923076923, 0.9744841923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 358}], {
             RGBColor[
             0.6820321538461539, 0.7508596923076922, 0.9693991538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 407}], {
             RGBColor[
             0.5149051538461539, 0.6164583076923077, 0.9551212307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 411}], {
             RGBColor[
             0.6205465769230769, 0.7028266923076922, 0.9632708461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 295}], {
             RGBColor[
             0.7013388461538461, 0.7651812307692307, 0.9720845384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 299}], {
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 300}], {
             RGBColor[
             0.7231512692307691, 0.7828895384615384, 0.9738016923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 301}], {
             RGBColor[
             0.7013388461538461, 0.7651812307692307, 0.9720845384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 389}], {
             RGBColor[
             0.9389722307692308, 0.9524333076923077, 0.9293569615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 451}], {
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 456}], {
             RGBColor[
             0.7231512692307691, 0.7828895384615384, 0.9738016923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 343}], {
             RGBColor[
             0.8800923076923077, 0.9040017692307691, 0.8292813461538464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 392}], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 465}], {
             RGBColor[
             0.8015582307692308, 0.8450465384615384, 0.9808173076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 492}], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 291}], {
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 297}], {
             RGBColor[0.8020848076923076, 0.845787, 0.957258423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 314}], {
             RGBColor[
             0.7366475384615383, 0.7926620769230768, 0.9521069615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 349}], {
             RGBColor[
             0.884065576923077, 0.9098310000000001, 0.9654294999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 359}], {
             RGBColor[
             0.6630806153846154, 0.7305214615384615, 0.9469829615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 381}], {
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 397}], {
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 419}], {
             RGBColor[
             0.6630806153846154, 0.7305214615384615, 0.9469829615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 472}], {
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 316}], {
             RGBColor[
             0.6746353846153845, 0.7438886153846154, 0.9695375384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 340}], {
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 355}], {
             RGBColor[
             0.5769217307692307, 0.6674100769230769, 0.9598365384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 362}], {
             RGBColor[
             0.5974169230769231, 0.6834210769230769, 0.9618793076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 378}], {
             RGBColor[
             0.5114844615384614, 0.6142851538461537, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 384}], {
             RGBColor[
             0.6746353846153845, 0.7438886153846154, 0.9695375384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 297}], {
             RGBColor[
             0.6628541923076923, 0.7365459999999999, 0.9670307692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 311}], {
             RGBColor[
             0.703844576923077, 0.7685680000000001, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 319}], {
             RGBColor[
             0.5572127692307692, 0.6501776153846154, 0.9588811538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 349}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 359}], {
             RGBColor[0.52385, 0.6212804615384615, 0.9567553076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 419}], {
             RGBColor[0.52385, 0.6212804615384615, 0.9567553076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 488}], {
             RGBColor[
             0.7605678461538462, 0.8130245384615384, 0.9767317692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 308}], {
             RGBColor[
             0.9209065769230769, 0.9393851538461538, 0.9789778846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 386}], {
             RGBColor[
             0.7092397692307693, 0.7707807692307692, 0.9598612692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 422}], {
             RGBColor[0.7964894615384615, 0.841614, 0.9667298846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 298}], {
             RGBColor[
             0.4896720384615384, 0.5965768461538461, 0.952967923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 317}], {
             RGBColor[
             0.6528229615384615, 0.7261803076923077, 0.9678203846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 353}], {
             RGBColor[
             0.4896720384615384, 0.5965768461538461, 0.952967923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 418}], {
             RGBColor[
             0.7203436153846154, 0.7494359230769231, 0.6500958076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 420}], {
             RGBColor[
             0.637090076923077, 0.7137457692307692, 0.9662904615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 432}], {
             RGBColor[
             0.5756045000000001, 0.6657127692307692, 0.9601621538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 358}], {
             RGBColor[
             0.7858253461538462, 0.8326119999999999, 0.9792873846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 411}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 430}], {
             RGBColor[
             0.6807149230769232, 0.7491623846153845, 0.9697247692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 478}], {
             RGBColor[0.8952562692307693, 0.918177, 0.9464865769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 300}], {
             RGBColor[
             0.5332968846153845, 0.6319934615384615, 0.9564022307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 336}], {
             RGBColor[
             0.5974169230769231, 0.6834210769230769, 0.9618793076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 389}], {
             RGBColor[
             0.7491178461538461, 0.8015372307692307, 0.9119575000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 409}], {
             RGBColor[
             0.43791753846153836`, 0.5521445384615383, 0.9495610769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 456}], {
             RGBColor[
             0.5332968846153845, 0.6319934615384615, 0.9564022307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 458}], {
             RGBColor[
             0.5769217307692307, 0.6674100769230769, 0.9598365384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 332}], {
             RGBColor[
             0.9427031923076923, 0.9530540769230769, 0.8004998461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 395}], {
             RGBColor[
             0.8487568846153847, 0.8823501538461538, 0.9854070769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 424}], {
             RGBColor[
             0.7872713076923077, 0.8343171538461538, 0.9792787692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 440}], {
             RGBColor[
             0.7013388461538461, 0.7651812307692307, 0.9720845384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 453}], {
             RGBColor[
             0.9153112307692307, 0.9352121538461537, 0.9884493461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 311}], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 314}], {
             RGBColor[
             0.5769217307692307, 0.6674100769230769, 0.9598365384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 349}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 359}], {
             RGBColor[
             0.5033548076923077, 0.6052694615384615, 0.9547125384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 381}], {
             RGBColor[
             0.6628541923076923, 0.7365459999999999, 0.9670307692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 397}], {
             RGBColor[0.8020848076923076, 0.845787, 0.957258423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 419}], {
             RGBColor[
             0.5033548076923077, 0.6052694615384615, 0.9547125384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 353}], {
             RGBColor[
             0.5114844615384614, 0.6142851538461537, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 418}], {
             RGBColor[
             0.7421560384615384, 0.7671442307692307, 0.6518129615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 420}], {
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 432}], {
             RGBColor[
             0.5974169230769231, 0.6834210769230769, 0.9618793076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 300}], {
             RGBColor[
             0.6964478076923077, 0.7615969230769231, 0.9712546923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 301}], {
             RGBColor[
             0.6746353846153845, 0.7438886153846154, 0.9695375384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 389}], {
             RGBColor[
             0.9122687692307693, 0.9311406923076924, 0.9268099615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 451}], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 456}], {
             RGBColor[
             0.6964478076923077, 0.7615969230769231, 0.9712546923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 301}], {
             RGBColor[
             0.5332968846153845, 0.6319934615384615, 0.9564022307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 389}], {
             RGBColor[
             0.7709302692307691, 0.8192455384615385, 0.913674653846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 409}], {
             RGBColor[
             0.45972996153846146`, 0.5698528461538461, 0.9512782307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 451}], {
             RGBColor[
             0.6964478076923077, 0.7615969230769231, 0.9712546923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 456}], {
             RGBColor[
             0.5551093076923076, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 458}], {
             RGBColor[
             0.5987341538461537, 0.6851183846153845, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 389}], {
             RGBColor[
             0.7491178461538461, 0.8015372307692307, 0.9119575000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 451}], {
             RGBColor[
             0.6746353846153845, 0.7438886153846154, 0.9695375384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 456}], {
             RGBColor[
             0.5332968846153845, 0.6319934615384615, 0.9564022307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 315}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 325}], {
             RGBColor[
             0.6410417692307693, 0.7188376923076923, 0.9653136153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 347}], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 368}], {
             RGBColor[
             0.5756045000000001, 0.6657127692307692, 0.9601621538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 386}], {
             RGBColor[
             0.5756045000000001, 0.6657127692307692, 0.9601621538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 421}], {
             RGBColor[0.46109642307692306`, 0.5604635, 0.9529933461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 477}], {
             RGBColor[
             0.6628541923076923, 0.7365459999999999, 0.9670307692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 366}], {
             RGBColor[0.8896609230769231, 0.914004, 0.9559580384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 435}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 473}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 310}], {
             RGBColor[
             0.6602197307692308, 0.7331513846153845, 0.9676819999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 429}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 483}], {
             RGBColor[
             0.8015582307692308, 0.8450465384615384, 0.9808173076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 382}], {
             RGBColor[
             0.6397245384615384, 0.7171403846153847, 0.9656392307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 416}], {
             RGBColor[
             0.38199726923076915`, 0.49329188461538453`, 0.9466632307692308]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 427}], {
             RGBColor[
             0.7734894999999999, 0.8203038461538461, 0.8712615769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 438}], {
             RGBColor[
             0.7722098846153845, 0.8197746923076923, 0.8924681153846155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 460}], {
             RGBColor[
             0.49309273076923066`, 0.5987499999999999, 0.9534040769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 499}], {
             RGBColor[
             0.7231512692307691, 0.7828895384615384, 0.9738016923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 317}], {
             RGBColor[0.5083566538461539, 0.5894430384615386, 0.9589455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 357}], {
             RGBColor[
             0.5865700769230768, 0.6477124230769231, 0.7725083461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 418}], {
             RGBColor[
             0.5758773076923076, 0.6126986538461539, 0.6412209230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 420}], {
             RGBColor[0.4926237692307693, 0.5770085, 0.957415576923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 372}], {
             RGBColor[0.8020848076923076, 0.845787, 0.957258423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 417}], {
             RGBColor[
             0.6628541923076923, 0.7365459999999999, 0.9670307692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 386}], {
             RGBColor[
             0.6795264230769231, 0.747472923076923, 0.9703673846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 421}], {
             RGBColor[
             0.565018346153846, 0.6422236538461539, 0.9631985769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 422}], {
             RGBColor[0.7667761153846153, 0.8183061538461538, 0.977236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 423}], {
             RGBColor[
             0.940251846153846, 0.9529624615384615, 0.9081504230769233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 446}], {
             RGBColor[
             0.9430238461538462, 0.953739923076923, 0.8354010384615387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 320}], {
             RGBColor[
             0.5332968846153847, 0.6319934615384615, 0.9564022307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 337}], {
             RGBColor[
             0.4896720384615384, 0.5965768461538461, 0.952967923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 348}], {
             RGBColor[
             0.6165948846153846, 0.6977347692307692, 0.9642476923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 375}], {
             RGBColor[
             0.7313570384615384, 0.7851355384615384, 0.8162844230769233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 489}], {
             RGBColor[
             0.4678596153846154, 0.5788685384615384, 0.9512507692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 327}], {
             RGBColor[
             0.7749818846153846, 0.8205521538461538, 0.8197187307692311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 399}], {
             RGBColor[
             0.7097995384615384, 0.7722432307692307, 0.9725281923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 412}], {
             RGBColor[
             0.6964478076923077, 0.7615969230769231, 0.9712546923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 429}], {
             RGBColor[
             0.6192293461538461, 0.7011293846153845, 0.9635964615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 483}], {
             RGBColor[
             0.6964478076923077, 0.7615969230769231, 0.9712546923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 319}], {
             RGBColor[
             0.5777079615384616, 0.6661886153846155, 0.9609239230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 331}], {
             RGBColor[
             0.6397245384615384, 0.7171403846153847, 0.9656392307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 349}], {
             RGBColor[
             0.765330153846154, 0.8166010000000001, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 377}], {
             RGBColor[
             0.765330153846154, 0.8166010000000001, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 419}], {
             RGBColor[
             0.5443451923076924, 0.6372914615384616, 0.9587980769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 484}], {
             RGBColor[
             0.765330153846154, 0.8166010000000001, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 488}], {
             RGBColor[
             0.7810630384615386, 0.8290355384615385, 0.9787745384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 354}], {
             RGBColor[
             0.9053069615384616, 0.8967476923076924, 0.6666654230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 376}], {
             RGBColor[
             0.9156790769230769, 0.9310756153846154, 0.7630516538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 400}], {
             RGBColor[
             0.8015582307692308, 0.8450465384615384, 0.9808173076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 414}], {
             RGBColor[
             0.9161076153846155, 0.9327281538461538, 0.8631903461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 415}], {
             RGBColor[
             0.7400726538461538, 0.7970135384615384, 0.9746889999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 379}], {
             RGBColor[
             0.9768401538461537, 0.9809724615384615, 0.8669663076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 380}], {
             RGBColor[
             0.7516770769230768, 0.8025955384615384, 0.8695444230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 390}], {
             RGBColor[
             0.9880308461538461, 0.9893184615384616, 0.8480233846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 411}], {
             RGBColor[
             0.8171143461538461, 0.8557204615384615, 0.8746958846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 478}], {
             RGBColor[
             0.9880308461538461, 0.9893184615384616, 0.8480233846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 359}], {
             RGBColor[
             0.43791753846153836`, 0.5521445384615383, 0.9495610769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 373}], {
             RGBColor[
             0.37516396153846143`, 0.4913275769230768, 0.9457991153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 397}], {
             RGBColor[
             0.7366475384615383, 0.7926620769230768, 0.9521069615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 398}], {
             RGBColor[
             0.4051221923076922, 0.5228155769230768, 0.9475051923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 472}], {
             RGBColor[
             0.5974169230769231, 0.6834210769230769, 0.9618793076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 325}], {
             RGBColor[
             0.6820321538461539, 0.7508596923076922, 0.9693991538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 347}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 368}], {
             RGBColor[
             0.6165948846153846, 0.6977347692307692, 0.9642476923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 386}], {
             RGBColor[
             0.6165948846153846, 0.6977347692307692, 0.9642476923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 401}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 378}], {
             RGBColor[
             0.6746353846153845, 0.7438886153846154, 0.9695375384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 357}], {
             RGBColor[
             0.9159997307692308, 0.9317614615384615, 0.7979528461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 418}], {
             RGBColor[
             0.9053069615384616, 0.8967476923076924, 0.6666654230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 420}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 321}], {
             RGBColor[
             0.7155690769230769, 0.5898297692307692, 0.5881935769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 330}], {
             RGBColor[
             0.759193923076923, 0.6252463846153846, 0.5916278846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 335}], {
             RGBColor[
             0.5873943846153846, 0.4806518846153846, 0.5792965384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 350}], {
             RGBColor[
             0.8411746923076924, 0.6892903846153846, 0.5997989615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 354}], {
             RGBColor[
             0.9244282307692308, 0.7249805384615385, 0.2836043076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 383}], {
             RGBColor[
             0.8702593076923077, 0.7123712307692308, 0.6026023846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 479}], {
             RGBColor[
             0.8411746923076924, 0.6892903846153846, 0.5997989615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 482}], {
             RGBColor[
             0.8411746923076924, 0.6892903846153846, 0.5997989615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 496}], {
             RGBColor[0.6535525, 0.538878, 0.5834782692307692]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{319, 331}], {
             RGBColor[
             0.49309273076923066`, 0.5987499999999999, 0.9534040769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 377}], {
             RGBColor[
             0.6186983461538462, 0.6982106153846154, 0.9650094615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 449}], {
             RGBColor[
             0.6875500384615385, 0.6817893846153846, 0.6112536538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 488}], {
             RGBColor[
             0.6344312307692308, 0.7106451538461538, 0.9665393846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 337}], {
             RGBColor[
             0.5551093076923077, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 348}], {
             RGBColor[
             0.6820321538461539, 0.7508596923076922, 0.9693991538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 361}], {
             RGBColor[
             0.6820321538461539, 0.7508596923076922, 0.9693991538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 375}], {
             RGBColor[
             0.7967943076923077, 0.8382604615384616, 0.8214358846153849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 335}], {
             RGBColor[
             0.4269346153846153, 0.5405238846153846, 0.9492223461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 383}], {
             RGBColor[
             0.7097995384615384, 0.7722432307692307, 0.9725281923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 479}], {
             RGBColor[
             0.6807149230769232, 0.7491623846153845, 0.9697247692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 482}], {
             RGBColor[
             0.6807149230769232, 0.7491623846153845, 0.9697247692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 496}], {
             RGBColor[
             0.49309273076923066`, 0.5987499999999999, 0.9534040769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 494}], {
             RGBColor[
             0.6602197307692308, 0.7331513846153845, 0.9676819999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 342}], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 395}], {
             RGBColor[
             0.7858253461538462, 0.8326119999999999, 0.9792873846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 447}], {
             RGBColor[
             0.791324576923077, 0.47536399999999995`, 0.5707313076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 452}], {
             RGBColor[0.5320450384615385, 0.6239735, 0.9587849615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 463}], {
             RGBColor[
             0.8427379615384616, 0.7688563076923076, 0.6159251153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 441}], {
             RGBColor[
             0.9161076153846155, 0.9327281538461538, 0.8631903461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 481}], {
             RGBColor[
             0.9159997307692308, 0.9317614615384615, 0.7979528461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 347}], {
             RGBColor[
             0.6410417692307693, 0.7188376923076923, 0.9653136153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 368}], {
             RGBColor[
             0.5332968846153847, 0.6319934615384615, 0.9564022307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 386}], {
             RGBColor[
             0.5332968846153847, 0.6319934615384615, 0.9564022307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 401}], {
             RGBColor[
             0.6615369615384616, 0.7348486923076925, 0.9673563846153845]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 421}], {
             RGBColor[
             0.4187888076923077, 0.5267441923076923, 0.949233423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 405}], {
             RGBColor[
             0.7801278461538461, 0.8289524615384615, 0.9785094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 428}], {
             RGBColor[
             0.674486423076923, 0.7425840769230769, 0.9703598846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 434}], {
             RGBColor[
             0.9563755769230768, 0.9643862307692308, 0.8366745384615387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 469}], {
             RGBColor[0.9178966923076922, 0.937369923076923, 0.992031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 474}], {
             RGBColor[
             0.6578050384615384, 0.7281354999999999, 0.9692969615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 475}], {
             RGBColor[
             0.7801278461538461, 0.8289524615384615, 0.9785094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 491}], {
             RGBColor[
             0.9561628076923077, 0.964667076923077, 0.8670108461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 495}], {
             RGBColor[
             0.6411236538461538, 0.713686923076923, 0.9682340384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 399}], {
             RGBColor[
             0.9296721153846155, 0.9430936153846154, 0.8341275384615388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 412}], {
             RGBColor[
             0.9163203846153847, 0.9324473076923077, 0.8328540384615387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 483}], {
             RGBColor[
             0.9163203846153847, 0.9324473076923077, 0.8328540384615387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 431}], {
             RGBColor[
             0.7801278461538461, 0.8289524615384615, 0.9785094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 433}], {
             RGBColor[
             0.8186067307692307, 0.8559687692307691, 0.8231530384615386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 436}], {
             RGBColor[
             0.5769217307692307, 0.6674100769230769, 0.9598365384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 462}], {
             RGBColor[
             0.6205465769230769, 0.7028266923076922, 0.9632708461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 487}], {
             RGBColor[
             0.8186067307692307, 0.8559687692307691, 0.8231530384615386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 406}], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 413}], {
             RGBColor[
             0.7025273461538463, 0.7668706923076923, 0.9714419230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 486}], {
             RGBColor[
             0.8999461923076923, 0.918641076923077, 0.7615217307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 350}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 354}], {
             RGBColor[
             0.8075933076923076, 0.8202691538461538, 0.6569644230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 414}], {
             RGBColor[
             0.8183939615384614, 0.8562496153846153, 0.8534893461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 415}], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 482}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 496}], {
             RGBColor[
             0.5367175769230769, 0.6341666153846153, 0.9568383846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 377}], {
             RGBColor[
             0.6807149230769232, 0.7491623846153845, 0.9697247692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 403}], {
             RGBColor[
             0.6964478076923077, 0.7615969230769231, 0.9712546923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 449}], {
             RGBColor[
             0.7495666153846154, 0.7327411538461539, 0.6159689615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 488}], {
             RGBColor[
             0.6964478076923077, 0.7615969230769231, 0.9712546923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 344}], {
             RGBColor[
             0.9560549230769231, 0.9637003846153847, 0.8017733461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 393}], {
             RGBColor[
             0.6959632692307692, 0.7544659615384615, 0.7790393076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 424}], {
             RGBColor[
             0.8387812692307692, 0.8712939230769231, 0.7902946153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 392}], {
             RGBColor[
             0.8523796923076923, 0.8854739999999999, 0.9823296538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 442}], {
             RGBColor[
             0.9286629615384614, 0.9458584615384615, 0.9897228461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 459}], {
             RGBColor[
             0.6852526923076923, 0.7510726153846153, 0.9680517307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 492}], {
             RGBColor[
             0.8523796923076923, 0.8854739999999999, 0.9823296538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 340}], {
             RGBColor[
             0.6807149230769232, 0.7491623846153845, 0.9697247692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 355}], {
             RGBColor[
             0.5987341538461537, 0.6851183846153845, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 361}], {
             RGBColor[
             0.6602197307692308, 0.7331513846153845, 0.9676819999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 363}], {
             RGBColor[
             0.6192293461538461, 0.7011293846153845, 0.9635964615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 369}], {
             RGBColor[
             0.7365029999999999, 0.7935358461538461, 0.9750751923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 370}], {
             RGBColor[
             0.7472692692307692, 0.8020243846153845, 0.9727670384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 379}], {
             RGBColor[
             0.7584599615384615, 0.8103703846153846, 0.9538241153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 498}], {
             RGBColor[
             0.5332968846153845, 0.6319934615384615, 0.9564022307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 383}], {
             RGBColor[
             0.5816248461538461, 0.663065346153846, 0.9636311538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 409}], {
             RGBColor[
             0.33155526923076917`, 0.46067496153846144`, 0.9423811923076924]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 482}], {
             RGBColor[0.5525402307692309, 0.6399845, 0.9608277307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 496}], {
             RGBColor[
             0.36491803846153836`, 0.4895721153846153, 0.9445070384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 409}], {
             RGBColor[0.52385, 0.6212804615384615, 0.9567553076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 456}], {
             RGBColor[
             0.6192293461538461, 0.7011293846153845, 0.9635964615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 458}], {
             RGBColor[
             0.6628541923076923, 0.7365459999999999, 0.9670307692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 348}], {
             RGBColor[
             0.6384073076923076, 0.7154430769230768, 0.9659648461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 361}], {
             RGBColor[
             0.6384073076923076, 0.7154430769230768, 0.9659648461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 370}], {
             RGBColor[
             0.725456846153846, 0.7843160769230768, 0.9710498846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 375}], {
             RGBColor[
             0.7531694615384614, 0.8028438461538461, 0.8180015769230772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 498}], {
             RGBColor[
             0.5114844615384614, 0.6142851538461537, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 369}], {
             RGBColor[
             0.841613423076923, 0.8769854615384615, 0.9846378076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 379}], {
             RGBColor[0.8635703846153846, 0.89382, 0.9633867307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 390}], {
             RGBColor[0.8747610769230769, 0.902166, 0.9444438076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 425}], {
             RGBColor[
             0.7858253461538462, 0.8326119999999999, 0.9792873846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 478}], {
             RGBColor[0.8747610769230769, 0.902166, 0.9444438076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 365}], {
             RGBColor[
             0.6020169615384616, 0.6837620384615384, 0.9639465384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 355}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 362}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 363}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 378}], {
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 379}], {
             RGBColor[
             0.884065576923077, 0.9098310000000001, 0.9654294999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 380}], {
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 498}], {
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 387}], {
             RGBColor[
             0.7739195769230769, 0.8236708461538462, 0.9780052692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 403}], {
             RGBColor[0.8511380384615386, 0.8841383846153846, 0.9856635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 405}], {
             RGBColor[0.7534243846153845, 0.8076598461538461, 0.9759625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 450}], {
             RGBColor[0.7534243846153845, 0.8076598461538461, 0.9759625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 469}], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 491}], {
             RGBColor[
             0.9294593461538462, 0.9433744615384616, 0.8644638461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 395}], {
             RGBColor[
             0.7858253461538462, 0.8326119999999999, 0.9792873846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 447}], {
             RGBColor[
             0.791324576923077, 0.47536399999999995`, 0.5707313076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 453}], {
             RGBColor[
             0.8523796923076923, 0.8854739999999999, 0.9823296538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 463}], {
             RGBColor[
             0.8427379615384616, 0.7688563076923076, 0.6159251153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 392}], {
             RGBColor[
             0.8800923076923077, 0.9040017692307691, 0.8292813461538464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 433}], {
             RGBColor[
             0.9948544615384616, 0.9914025384615385, 0.6813180769230774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 465}], {
             RGBColor[
             0.9163203846153847, 0.9324473076923077, 0.8328540384615387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 387}], {
             RGBColor[
             0.8006230384615385, 0.8449634615384616, 0.9805522692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 424}], {
             RGBColor[
             0.8006230384615385, 0.8449634615384616, 0.9805522692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 375}], {
             RGBColor[
             0.9946416923076924, 0.9916833846153846, 0.7116543846153849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 426}], {
             RGBColor[
             0.9161076153846155, 0.9327281538461538, 0.8631903461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 448}], {
             RGBColor[
             0.9161076153846155, 0.9327281538461538, 0.8631903461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 489}], {
             RGBColor[
             0.7311442692307693, 0.7854163846153845, 0.8466207307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 498}], {
             RGBColor[
             0.7529566923076922, 0.8031246923076922, 0.8483378846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 358}], {
             RGBColor[
             0.8523796923076923, 0.8854739999999999, 0.9823296538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 404}], {
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 407}], {
             RGBColor[
             0.6852526923076923, 0.7510726153846153, 0.9680517307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 408}], {
             RGBColor[
             0.703644423076923, 0.7666077692307691, 0.9693327307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 430}], {
             RGBColor[
             0.7472692692307692, 0.8020243846153845, 0.9727670384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 368}], {
             RGBColor[
             0.5756045000000001, 0.6657127692307692, 0.9601621538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 386}], {
             RGBColor[
             0.5756045000000001, 0.6657127692307692, 0.9601621538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 421}], {
             RGBColor[0.46109642307692306`, 0.5604635, 0.9529933461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 477}], {
             RGBColor[
             0.6628541923076923, 0.7365459999999999, 0.9670307692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 375}], {
             RGBColor[
             0.8800923076923077, 0.9040017692307691, 0.8292813461538464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 428}], {
             RGBColor[
             0.5982031538461539, 0.6821996153846153, 0.9629666923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 359}], {
             RGBColor[
             0.585335576923077, 0.6693134615384615, 0.9628836153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 371}], {
             RGBColor[
             0.9005875000000001, 0.9200127692307692, 0.8313241153846156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 397}], {
             RGBColor[
             0.884065576923077, 0.9098310000000001, 0.9654294999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 419}], {
             RGBColor[
             0.585335576923077, 0.6693134615384615, 0.9628836153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 354}], {
             RGBColor[
             0.889574076923077, 0.8843131538461539, 0.6651355000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 383}], {
             RGBColor[
             0.835405153846154, 0.8717038461538462, 0.9841335769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 414}], {
             RGBColor[
             0.9003747307692309, 0.9202936153846154, 0.8616604230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 479}], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 482}], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 356}], {
             RGBColor[0.8778414999999999, 0.905431, 0.9882105]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{351, 463}], {
             RGBColor[0.9056695, 0.8185944615384615, 0.6220448076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 367}], {
             RGBColor[
             0.6177498461538462, 0.6961965769230769, 0.9654764615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 399}], {
             RGBColor[0.8511380384615386, 0.8841383846153846, 0.9856635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 412}], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 457}], {
             RGBColor[
             0.7400726538461538, 0.7970135384615384, 0.9746889999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 418}], {
             RGBColor[
             0.7421560384615384, 0.7671442307692307, 0.6518129615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 420}], {
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 432}], {
             RGBColor[
             0.5974169230769231, 0.6834210769230769, 0.9618793076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 441}], {
             RGBColor[
             0.7529566923076922, 0.8031246923076922, 0.8483378846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 372}], {
             RGBColor[
             0.9673191153846153, 0.9455211538461539, 0.6492348461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 414}], {
             RGBColor[
             0.9836282692307692, 0.9559837692307693, 0.5454657692307694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 415}], {
             RGBColor[
             0.8075933076923076, 0.8202691538461538, 0.6569644230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 479}], {
             RGBColor[
             0.889574076923077, 0.8843131538461539, 0.6651355000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 482}], {
             RGBColor[
             0.889574076923077, 0.8843131538461539, 0.6651355000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 362}], {
             RGBColor[
             0.6628541923076923, 0.7365459999999999, 0.9670307692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 363}], {
             RGBColor[
             0.6628541923076923, 0.7365459999999999, 0.9670307692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 378}], {
             RGBColor[
             0.5769217307692307, 0.6674100769230769, 0.9598365384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 384}], {
             RGBColor[
             0.7400726538461538, 0.7970135384615384, 0.9746889999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 498}], {
             RGBColor[
             0.5769217307692307, 0.6674100769230769, 0.9598365384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 463}], {
             RGBColor[
             0.8923177692307693, 0.8079481538461538, 0.6207713076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 418}], {
             RGBColor[
             0.9835203846153846, 0.955017076923077, 0.4802282692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 420}], {
             RGBColor[
             0.9002668461538462, 0.9193269230769231, 0.7964229230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 404}], {
             RGBColor[0.8747610769230769, 0.902166, 0.9444438076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 407}], {
             RGBColor[
             0.5982031538461539, 0.6821996153846153, 0.9629666923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 408}], {
             RGBColor[
             0.6165948846153846, 0.6977347692307692, 0.9642476923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 430}], {
             RGBColor[
             0.6602197307692308, 0.7331513846153845, 0.9676819999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 371}], {
             RGBColor[
             0.6796025384615385, 0.7407032307692307, 0.8128775769230772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 397}], {
             RGBColor[
             0.6630806153846154, 0.7305214615384615, 0.9469829615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 419}], {
             RGBColor[
             0.3643506153846154, 0.49000392307692303`, 0.9444370769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 427}], {
             RGBColor[
             0.6781101538461538, 0.7404549230769231, 0.864420423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 393}], {
             RGBColor[
             0.4143947692307692, 0.5333496538461537, 0.9476258461538463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 466}], {
             RGBColor[
             0.6611346923076923, 0.7319377692307691, 0.9690863846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 468}], {
             RGBColor[
             0.44946788461538456`, 0.5633333846153845, 0.9499697692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 363}], {
             RGBColor[
             0.7243397692307693, 0.7845789999999999, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 370}], {
             RGBColor[
             0.8523796923076923, 0.8854739999999999, 0.9823296538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 498}], {
             RGBColor[
             0.6384073076923076, 0.7154430769230768, 0.9659648461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 363}], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 384}], {
             RGBColor[
             0.7605678461538462, 0.8130245384615384, 0.9767317692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 498}], {
             RGBColor[
             0.5974169230769231, 0.6834210769230769, 0.9618793076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 370}], {
             RGBColor[0.8113893076923077, 0.853452, 0.9782441153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 379}], {
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 498}], {
             RGBColor[
             0.5974169230769231, 0.6834210769230769, 0.9618793076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 374}], {
             RGBColor[
             0.9713571153846154, 0.9259521538461538, 0.5763274615384617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 437}], {
             RGBColor[0.799161, 0.791825, 0.6242064999999999]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{366, 435}], {
             RGBColor[
             0.8076801538461538, 0.8499599999999999, 0.9477869615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 473}], {
             RGBColor[0.8281753461538461, 0.865971, 0.9498297307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 416}], {
             RGBColor[0.3032993076923077, 0.4278915384615384, 0.940885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 457}], {
             RGBColor[
             0.5200361923076923, 0.6197180384615384, 0.9557754615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 499}], {
             RGBColor[
             0.6444533076923077, 0.7174891923076923, 0.9680234615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 386}], {
             RGBColor[
             0.4678596153846154, 0.5788685384615384, 0.9512507692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 401}], {
             RGBColor[
             0.5960996923076924, 0.6817237692307693, 0.9622049230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 500}], {
             RGBColor[
             0.7273054230769231, 0.7838289230769231, 0.9102403461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 370}], {
             RGBColor[
             0.9286629615384614, 0.9458584615384615, 0.9897228461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 379}], {
             RGBColor[
             0.9398536538461537, 0.9542044615384615, 0.9707799230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 390}], {
             RGBColor[0.951044346153846, 0.9625504615384615, 0.951837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 425}], {
             RGBColor[
             0.8621086153846154, 0.8929964615384616, 0.9866805769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 466}], {
             RGBColor[0.9045449615384615, 0.9267236153846153, 0.9907575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 466}], {
             RGBColor[
             0.9153112307692307, 0.9352121538461537, 0.9884493461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 382}], {
             RGBColor[
             0.8595971153846155, 0.8879907692307694, 0.8272385769230772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 419}], {
             RGBColor[
             0.6796025384615385, 0.7407032307692307, 0.8128775769230772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 427}], {
             RGBColor[
             0.9933620769230769, 0.9911542307692307, 0.7328609230769234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 429}], {
             RGBColor[
             0.8391019230769231, 0.8719797692307693, 0.8251958076923079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 417}], {
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 398}], {
             RGBColor[
             0.26880169230769224`, 0.39985799999999994`, 0.9386192307692307]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 472}], {
             RGBColor[0.4610964230769231, 0.5604635, 0.9529933461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 391}], {
             RGBColor[
             0.7273054230769231, 0.7838289230769231, 0.9102403461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 437}], {
             RGBColor[
             0.8145551153846153, 0.8546621538461538, 0.9171089615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 426}], {
             RGBColor[
             0.9163203846153847, 0.9324473076923077, 0.8328540384615387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 489}], {
             RGBColor[
             0.7313570384615384, 0.7851355384615384, 0.8162844230769233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 400}], {
             RGBColor[0.879451, 0.9026300769230768, 0.7594789615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 414}], {
             RGBColor[
             0.9940003846153846, 0.9903116923076923, 0.6418520000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 415}], {
             RGBColor[
             0.8179654230769231, 0.8545970769230768, 0.7533506538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 464}], {
             RGBColor[
             0.9914411538461538, 0.9892533846153846, 0.6842650769230771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 485}], {
             RGBColor[
             0.7961530000000001, 0.8368887692307693, 0.7516335000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 497}], {
             RGBColor[0.712324, 0.7682286923076923, 0.7452010384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 403}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 449}], {
             RGBColor[
             0.8751722307692309, 0.8322017692307693, 0.6275743461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 484}], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 488}], {
             RGBColor[
             0.8220534230769232, 0.8610575384615384, 0.9828600769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 380}], {
             RGBColor[
             0.5114844615384614, 0.6142851538461537, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 380}], {
             RGBColor[
             0.7366475384615383, 0.7926620769230768, 0.9521069615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 390}], {
             RGBColor[0.9730013076923076, 0.979385, 0.9305859230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 478}], {
             RGBColor[0.9730013076923076, 0.979385, 0.9305859230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 390}], {
             RGBColor[
             0.7478382307692306, 0.8010080769230769, 0.9331640384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 411}], {
             RGBColor[
             0.5769217307692307, 0.6674100769230769, 0.9598365384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 478}], {
             RGBColor[
             0.7478382307692306, 0.8010080769230769, 0.9331640384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 419}], {
             RGBColor[0.52385, 0.6212804615384615, 0.9567553076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 439}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 416}], {
             RGBColor[0.4666125000000001, 0.5607305, 0.9541830769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 427}], {
             RGBColor[
             0.8581047307692309, 0.8877424615384616, 0.8787814230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 429}], {
             RGBColor[
             0.703844576923077, 0.7685680000000001, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 499}], {
             RGBColor[0.8077665, 0.8503281538461539, 0.9813215384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 479}], {
             RGBColor[
             0.835405153846154, 0.8717038461538462, 0.9841335769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 482}], {
             RGBColor[
             0.835405153846154, 0.8717038461538462, 0.9841335769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 496}], {
             RGBColor[
             0.6477829615384615, 0.7212914615384616, 0.9678128846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 435}], {
             RGBColor[
             0.7400726538461538, 0.7970135384615384, 0.9746889999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 391}], {
             RGBColor[
             0.5332968846153847, 0.6319934615384615, 0.9564022307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 421}], {
             RGBColor[
             0.35335153846153844`, 0.4736192692307692, 0.9440819615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 403}], {
             RGBColor[
             0.7605678461538462, 0.8130245384615384, 0.9767317692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 405}], {
             RGBColor[
             0.6628541923076923, 0.7365459999999999, 0.9670307692307691]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 491}], {
             RGBColor[
             0.8388891538461538, 0.8722606153846154, 0.8555321153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 487}], {
             RGBColor[
             0.9005875000000001, 0.9200127692307692, 0.8313241153846156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 490}], {
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 409}], {
             RGBColor[
             0.6755509230769231, 0.7393966153846153, 0.9068335000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 451}], {
             RGBColor[
             0.9122687692307693, 0.9311406923076924, 0.9268099615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 456}], {
             RGBColor[
             0.7709302692307691, 0.8192455384615385, 0.913674653846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 458}], {
             RGBColor[
             0.8145551153846153, 0.8546621538461538, 0.9171089615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 425}], {
             RGBColor[0.8952562692307693, 0.918177, 0.9464865769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 478}], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 459}], {
             RGBColor[
             0.5982031538461539, 0.6821996153846153, 0.9629666923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 465}], {
             RGBColor[
             0.8015582307692308, 0.8450465384615384, 0.9808173076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 492}], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 468}], {
             RGBColor[
             0.43278649999999996`, 0.5488848076923076, 0.9489068461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 398}], {
             RGBColor[0.44874703846153846`, 0.5582321923076923, 0.9509395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 445}], {
             RGBColor[
             0.5551093076923077, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 460}], {
             RGBColor[
             0.5149051538461539, 0.6164583076923077, 0.9551212307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 440}], {
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 447}], {
             RGBColor[0.8118197692307694, 0.491375, 0.5727740769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 453}], {
             RGBColor[0.8728748846153846, 0.901485, 0.9843724230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 463}], {
             RGBColor[
             0.863233153846154, 0.7848673076923076, 0.6179678846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 422}], {
             RGBColor[
             0.7400726538461538, 0.7970135384615384, 0.9746889999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 443}], {
             RGBColor[
             0.9053069615384616, 0.8967476923076924, 0.6666654230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 446}], {
             RGBColor[
             0.9163203846153847, 0.9324473076923077, 0.8328540384615387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 419}], {
             RGBColor[
             0.6630806153846154, 0.7305214615384615, 0.9469829615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 472}], {
             RGBColor[0.82258, 0.8617980000000001, 0.9593011923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 445}], {
             RGBColor[
             0.4051221923076922, 0.5228155769230768, 0.9475051923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 460}], {
             RGBColor[
             0.36491803846153836`, 0.4895721153846153, 0.9445070384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 472}], {
             RGBColor[0.4910546538461538, 0.5919515, 0.954699423076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 412}], {
             RGBColor[0.8511380384615386, 0.8841383846153846, 0.9856635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 414}], {
             RGBColor[
             0.8798795384615385, 0.9042826153846153, 0.859617653846154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 415}], {
             RGBColor[
             0.7038445769230769, 0.7685679999999999, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 464}], {
             RGBColor[
             0.8773203076923077, 0.9032243076923077, 0.9020307307692309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 450}], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 454}], {
             RGBColor[
             0.8443675384615386, 0.8380690769230771, 0.6446710000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 471}], {
             RGBColor[
             0.7243397692307694, 0.7845790000000001, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 475}], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 500}], {
             RGBColor[
             0.8555455000000001, 0.8866841538461538, 0.9211945000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 431}], {
             RGBColor[
             0.8621086153846154, 0.8929964615384616, 0.9866805769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 436}], {
             RGBColor[0.6589025, 0.7314540769230768, 0.9680076153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 459}], {
             RGBColor[
             0.6186983461538462, 0.6982106153846154, 0.9650094615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 462}], {
             RGBColor[
             0.7025273461538463, 0.7668706923076923, 0.9714419230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 487}], {
             RGBColor[
             0.9005875000000001, 0.9200127692307692, 0.8313241153846156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 405}], {
             RGBColor[
             0.7400726538461538, 0.7970135384615384, 0.9746889999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 449}], {
             RGBColor[
             0.8909051153846155, 0.8446363076923078, 0.6291042692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 491}], {
             RGBColor[
             0.9161076153846155, 0.9327281538461538, 0.8631903461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 407}], {
             RGBColor[
             0.7076340769230769, 0.7677646153846154, 0.9301658846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 408}], {
             RGBColor[
             0.7260258076923076, 0.7832997692307693, 0.9314468846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 434}], {
             RGBColor[
             0.8186067307692307, 0.8559687692307691, 0.8231530384615386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 469}], {
             RGBColor[
             0.7801278461538461, 0.8289524615384615, 0.9785094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 474}], {
             RGBColor[
             0.5200361923076923, 0.6197180384615384, 0.9557754615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 491}], {
             RGBColor[
             0.8183939615384614, 0.8562496153846153, 0.8534893461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 413}], {
             RGBColor[
             0.7025273461538463, 0.7668706923076923, 0.9714419230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 476}], {
             RGBColor[
             0.637090076923077, 0.7137457692307692, 0.9662904615384615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 486}], {
             RGBColor[
             0.8999461923076923, 0.918641076923077, 0.7615217307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 493}], {
             RGBColor[0.8896609230769231, 0.914004, 0.9559580384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 408}], {
             RGBColor[
             0.44946788461538456`, 0.5633333846153845, 0.9499697692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 430}], {
             RGBColor[
             0.49309273076923066`, 0.5987499999999999, 0.9534040769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{408, 430}], {
             RGBColor[
             0.5114844615384615, 0.6142851538461538, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 456}], {
             RGBColor[
             0.45972996153846146`, 0.5698528461538461, 0.9512782307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 458}], {
             RGBColor[
             0.5033548076923077, 0.6052694615384615, 0.9547125384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 496}], {
             RGBColor[
             0.3977133846153846, 0.5189010769230769, 0.946562923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{411, 478}], {
             RGBColor[0.8132754999999999, 0.854133, 0.9383155]}, StripOnInput -> 
            False], 
           StyleBox[
            LineBox[{413, 476}], {
             RGBColor[
             0.5332968846153847, 0.6319934615384615, 0.9564022307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 486}], {
             RGBColor[
             0.7961530000000001, 0.8368887692307693, 0.7516335000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 493}], {
             RGBColor[
             0.7858677307692308, 0.8322516923076924, 0.9460698076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 415}], {
             RGBColor[
             0.8183939615384614, 0.8562496153846153, 0.8534893461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 485}], {
             RGBColor[
             0.7965815384615385, 0.8385413076923077, 0.8517721923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{415, 464}], {
             RGBColor[
             0.8158347307692306, 0.8551913076923077, 0.8959024230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{415, 485}], {
             RGBColor[
             0.6205465769230769, 0.7028266923076922, 0.9632708461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 427}], {
             RGBColor[
             0.6003774615384616, 0.6638939615384616, 0.8598054230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 429}], {
             RGBColor[0.44611730769230773`, 0.5447195, 0.9521403076923076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 499}], {
             RGBColor[
             0.5500392307692308, 0.6264796538461539, 0.9623455384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{417, 461}], {
             RGBColor[
             0.5974169230769231, 0.6834210769230769, 0.9618793076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 420}], {
             RGBColor[
             0.889574076923077, 0.8843131538461539, 0.6651355000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 432}], {
             RGBColor[0.8280885, 0.836280153846154, 0.6590071923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 432}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 439}], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 423}], {
             RGBColor[
             0.6140769615384615, 0.6791088076923077, 0.8818650000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 477}], {
             RGBColor[0.44060123076923075`, 0.5444525, 0.9509505769230768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 443}], {
             RGBColor[
             0.8075933076923076, 0.8202691538461538, 0.6569644230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 446}], {
             RGBColor[
             0.8186067307692307, 0.8559687692307691, 0.8231530384615386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 446}], {
             RGBColor[
             0.9920824615384616, 0.9906250769230769, 0.7540674615384619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 477}], {
             RGBColor[
             0.8158347307692306, 0.8551913076923077, 0.8959024230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 440}], {
             RGBColor[
             0.5974169230769231, 0.6834210769230769, 0.9618793076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 453}], {
             RGBColor[0.8113893076923077, 0.853452, 0.9782441153846153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 470}], {
             RGBColor[
             0.6192293461538461, 0.7011293846153845, 0.9635964615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{425, 466}], {
             RGBColor[
             0.8487568846153847, 0.8823501538461538, 0.9854070769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 448}], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 489}], {
             RGBColor[
             0.6528229615384615, 0.7261803076923077, 0.9678203846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 460}], {
             RGBColor[
             0.711472923076923, 0.7693520769230768, 0.8665462692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 499}], {
             RGBColor[
             0.9415314615384616, 0.9534916153846154, 0.8869438846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 495}], {
             RGBColor[
             0.3977133846153846, 0.5189010769230769, 0.946562923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{429, 499}], {
             RGBColor[
             0.7872713076923077, 0.8343171538461538, 0.9792787692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 433}], {
             RGBColor[
             0.9563755769230768, 0.9643862307692308, 0.8366745384615387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 436}], {
             RGBColor[
             0.7146905769230768, 0.7758275384615383, 0.9733580384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 459}], {
             RGBColor[
             0.674486423076923, 0.7425840769230769, 0.9703598846153847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 462}], {
             RGBColor[
             0.7583154230769231, 0.8112441538461539, 0.9767923461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 487}], {
             RGBColor[
             0.9563755769230768, 0.9643862307692308, 0.8366745384615387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{432, 467}], {
             RGBColor[0.7448349615384616, 0.80059, 0.9752018461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 462}], {
             RGBColor[
             0.7967943076923077, 0.8382604615384616, 0.8214358846153849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 469}], {
             RGBColor[
             0.9563755769230768, 0.9643862307692308, 0.8366745384615387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 474}], {
             RGBColor[
             0.6962839230769231, 0.7551518076923076, 0.8139405000000003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 495}], {
             RGBColor[
             0.6796025384615385, 0.7407032307692307, 0.8128775769230772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 459}], {
             RGBColor[
             0.47128030769230755`, 0.5810416923076922, 0.9516869230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 462}], {
             RGBColor[
             0.5551093076923077, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 487}], {
             RGBColor[
             0.7531694615384614, 0.8028438461538461, 0.8180015769230772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 457}], {
             RGBColor[
             0.8158347307692306, 0.8551913076923077, 0.8959024230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 460}], {
             RGBColor[
             0.7101933076923076, 0.768822923076923, 0.8877528076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 453}], {
             RGBColor[
             0.725456846153846, 0.7843160769230768, 0.9710498846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 470}], {
             RGBColor[
             0.5332968846153845, 0.6319934615384615, 0.9564022307692308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 467}], {
             RGBColor[
             0.9003747307692309, 0.9202936153846154, 0.8616604230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 444}], {
             RGBColor[
             0.7801278461538461, 0.8289524615384615, 0.9785094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 492}], {
             RGBColor[
             0.841613423076923, 0.8769854615384615, 0.9846378076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{443, 446}], {
             RGBColor[
             0.9838410384615385, 0.9557029230769232, 0.5151294615384618]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{444, 492}], {
             RGBColor[
             0.7038445769230769, 0.7685679999999999, 0.9711163076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{445, 460}], {
             RGBColor[
             0.47128030769230755`, 0.5810416923076922, 0.9516869230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 453}], {
             RGBColor[0.8783741153846154, 0.544237, 0.5758163461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 463}], {
             RGBColor[
             0.8687323846153847, 0.42761930769230766`, 0.20941180769230772`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{449, 488}], {
             RGBColor[
             0.8909051153846155, 0.8446363076923078, 0.6291042692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 454}], {
             RGBColor[
             0.8033771538461538, 0.806047076923077, 0.6405854615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 469}], {
             RGBColor[
             0.7801278461538461, 0.8289524615384615, 0.9785094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 471}], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 475}], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 491}], {
             RGBColor[
             0.8183939615384614, 0.8562496153846153, 0.8534893461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 500}], {
             RGBColor[
             0.8145551153846153, 0.8546621538461538, 0.9171089615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{451, 456}], {
             RGBColor[
             0.6964478076923077, 0.7615969230769231, 0.9712546923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{453, 463}], {
             RGBColor[0.9297875, 0.8377293076923076, 0.6210101538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 469}], {
             RGBColor[0.941146, 0.9144645384615385, 0.6541069615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 471}], {
             RGBColor[
             0.8443675384615386, 0.8380690769230771, 0.6446710000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 475}], {
             RGBColor[
             0.8033771538461538, 0.806047076923077, 0.6405854615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 500}], {
             RGBColor[
             0.9755732692307693, 0.9401742307692309, 0.5927064230769232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{456, 458}], {
             RGBColor[
             0.5987341538461537, 0.6851183846153845, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{461, 486}], {
             RGBColor[
             0.7525281538461538, 0.8014721538461538, 0.7481991923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{461, 493}], {
             RGBColor[0.7422428846153846, 0.7968350769230768, 0.9426355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{462, 487}], {
             RGBColor[
             0.7967943076923077, 0.8382604615384616, 0.8214358846153849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 485}], {
             RGBColor[0.7940223076923076, 0.837483, 0.8941852692307694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 497}], {
             RGBColor[
             0.7101933076923076, 0.768822923076923, 0.8877528076923078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 468}], {
             RGBColor[
             0.6795264230769231, 0.747472923076923, 0.9703673846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 471}], {
             RGBColor[
             0.8211182307692309, 0.8609744615384616, 0.9825950384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 474}], {
             RGBColor[
             0.6578050384615384, 0.7281354999999999, 0.9692969615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 475}], {
             RGBColor[
             0.7801278461538461, 0.8289524615384615, 0.9785094999999999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 491}], {
             RGBColor[
             0.9561628076923077, 0.964667076923077, 0.8670108461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 495}], {
             RGBColor[
             0.6411236538461538, 0.713686923076923, 0.9682340384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 475}], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 500}], {
             RGBColor[
             0.8555455000000001, 0.8866841538461538, 0.9211945000000001]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{474, 495}], {
             RGBColor[0.381032, 0.5044525, 0.9455]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{476, 493}], {
             RGBColor[
             0.7204304615384616, 0.7791267692307692, 0.9409183461538462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{479, 482}], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{480, 481}], {
             RGBColor[
             0.7964736538461539, 0.8375746153846154, 0.7865346923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{482, 496}], {
             RGBColor[
             0.6186983461538462, 0.6982106153846154, 0.9650094615384616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{484, 500}], {
             RGBColor[
             0.8965358846153847, 0.9187061538461538, 0.9252800384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{485, 497}], {
             RGBColor[
             0.5149051538461539, 0.6164583076923077, 0.9551212307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{486, 493}], {
             RGBColor[
             0.983286576923077, 0.984022076923077, 0.7361496153846154]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.0315874366232787], {
             RGBColor[
             0.5114844615384614, 0.6142851538461537, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.0315874366232787], {
             RGBColor[
             0.4678596153846154, 0.5788685384615384, 0.9512507692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.0315874366232787], {
             RGBColor[
             0.5551093076923076, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.0315874366232787], {
             RGBColor[
             0.4678596153846154, 0.5788685384615384, 0.9512507692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.0315874366232787], {
             RGBColor[
             0.4310761538461538, 0.5477982307692307, 0.9486887692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.0315874366232787], {
             RGBColor[
             0.4678596153846154, 0.5788685384615384, 0.9512507692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.0315874366232787], {
             RGBColor[
             0.5114844615384614, 0.6142851538461537, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.0315874366232787], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.8268168461538464]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.0315874366232787], {
             RGBColor[
             0.7243397692307694, 0.7845790000000001, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.0315874366232787], {
             RGBColor[0.955963, 0.863115, 0.283425]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.0315874366232787], {
             RGBColor[
             0.3977133846153846, 0.5189010769230769, 0.9465629230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.0315874366232787], {
             RGBColor[
             0.5114844615384614, 0.6142851538461537, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.0315874366232787], {
             RGBColor[
             0.4678596153846154, 0.5788685384615384, 0.9512507692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.0315874366232787], {
             RGBColor[
             0.7243397692307694, 0.7845790000000001, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.0315874366232787], {
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.0315874366232787], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.0315874366232787], {
             RGBColor[
             0.8654545384615385, 0.4819423076923079, 0.20944430769230774`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.0315874366232787], {
             RGBColor[
             0.5987341538461539, 0.6851183846153847, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.0315874366232787], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.0315874366232787], {
             RGBColor[
             0.9948544615384616, 0.9914025384615385, 0.6813180769230774]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.0315874366232787], {
             RGBColor[
             0.7243397692307694, 0.7845790000000001, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.0315874366232787], {
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.0315874366232787], {
             RGBColor[0.950619923076923, 0.962693, 0.9684717692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.0315874366232787], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.0315874366232787], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.0315874366232787], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.0315874366232787], {
             RGBColor[
             0.5551093076923076, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.0315874366232787], {
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.0315874366232787], {
             RGBColor[
             0.5114844615384614, 0.6142851538461537, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.0315874366232787], {
             RGBColor[
             0.5551093076923076, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.0315874366232787], {
             RGBColor[
             0.5987341538461539, 0.6851183846153847, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.0315874366232787], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.0315874366232787], {
             RGBColor[
             0.5114844615384614, 0.6142851538461537, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.0315874366232787], {
             RGBColor[
             0.8866031538461538, 0.5779732307692307, 0.22709123076923077`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.0315874366232787], {
             RGBColor[
             0.4310761538461538, 0.5477982307692307, 0.9486887692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.0315874366232787], {
             RGBColor[
             0.9948544615384616, 0.9914025384615385, 0.6813180769230774]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.0315874366232787], {
             RGBColor[
             0.9918696923076923, 0.990905923076923, 0.7844037692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.0315874366232787], {
             RGBColor[
             0.3977133846153846, 0.5189010769230769, 0.9465629230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.0315874366232787], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.0315874366232787], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.0315874366232787], {
             RGBColor[
             0.3977133846153846, 0.5189010769230769, 0.9465629230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.0315874366232787], {
             RGBColor[
             0.5551093076923076, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.0315874366232787], {
             RGBColor[
             0.3977133846153846, 0.5189010769230769, 0.9465629230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.0315874366232787], {
             RGBColor[
             0.4678596153846154, 0.5788685384615384, 0.9512507692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.0315874366232787], {
             RGBColor[
             0.9320848461538462, 0.7684460769230773, 0.264212076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.0315874366232787], {
             RGBColor[0.9178966923076922, 0.937369923076923, 0.992031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.0315874366232787], {
             RGBColor[
             0.4310761538461538, 0.5477982307692307, 0.9486887692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.0315874366232787], {
             RGBColor[0.9178966923076922, 0.937369923076923, 0.992031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.0315874366232787], {
             RGBColor[
             0.9944289230769231, 0.9919642307692308, 0.7419906923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.0315874366232787], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.0315874366232787], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.0315874366232787], {
             RGBColor[
             0.4310761538461538, 0.5477982307692307, 0.9486887692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.0315874366232787], {
             RGBColor[
             0.3643506153846154, 0.49000392307692303`, 0.9444370769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.0315874366232787], {
             RGBColor[
             0.7243397692307694, 0.7845790000000001, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.0315874366232787], {
             RGBColor[0.9178966923076922, 0.937369923076923, 0.992031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.0315874366232787], {
             RGBColor[
             0.9944289230769231, 0.9919642307692308, 0.7419906923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.0315874366232787], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.0315874366232787], {
             RGBColor[
             0.3309878461538461, 0.46110676923076915`, 0.9423112307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.0315874366232787], {
             RGBColor[
             0.9948544615384616, 0.9914025384615385, 0.6813180769230774]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.0315874366232787], {
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.0315874366232787], {
             RGBColor[
             0.8760288461538461, 0.5299577692307693, 0.21826776923076924`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.0315874366232787], {
             RGBColor[
             0.3643506153846154, 0.49000392307692303`, 0.9444370769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.0315874366232787], {
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.0315874366232787], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.0315874366232787], {
             RGBColor[0.9394292307692307, 0.954347, 0.9874146923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.0315874366232787], {
             RGBColor[
             0.7243397692307694, 0.7845790000000001, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.0315874366232787], {
             RGBColor[
             0.4678596153846154, 0.5788685384615384, 0.9512507692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.0315874366232787], {
             RGBColor[0.950619923076923, 0.962693, 0.9684717692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.0315874366232787], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.0315874366232787], {
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.0315874366232787], {
             RGBColor[
             0.5987341538461539, 0.6851183846153847, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.0315874366232787], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.0315874366232787], {
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.0315874366232787], {
             RGBColor[
             0.9944289230769231, 0.9919642307692308, 0.7419906923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.0315874366232787], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.0315874366232787], {
             RGBColor[
             0.4310761538461538, 0.5477982307692307, 0.9486887692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.0315874366232787], {
             RGBColor[
             0.5551093076923076, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.0315874366232787], {
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.0315874366232787], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.0315874366232787], {
             RGBColor[
             0.9929305384615384, 0.9872874615384616, 0.47191092307692334`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.0315874366232787], {
             RGBColor[
             0.4678596153846154, 0.5788685384615384, 0.9512507692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.0315874366232787], {
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.0315874366232787], {
             RGBColor[
             0.5114844615384614, 0.6142851538461537, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.0315874366232787], {
             RGBColor[
             0.3309878461538461, 0.46110676923076915`, 0.9423112307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.0315874366232787], {
             RGBColor[
             0.9728276153846154, 0.9200033076923078, 0.34894084615384624`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.0315874366232787], {
             RGBColor[0.9178966923076922, 0.937369923076923, 0.992031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.0315874366232787], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.0315874366232787], {
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.0315874366232787], {
             RGBColor[
             0.3309878461538461, 0.46110676923076915`, 0.9423112307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.0315874366232787], {
             RGBColor[0.9178966923076922, 0.937369923076923, 0.992031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.0315874366232787], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.0315874366232787], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.0315874366232787], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.0315874366232787], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.0315874366232787], {
             RGBColor[0.9394292307692307, 0.954347, 0.9874146923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.0315874366232787], {
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.0315874366232787], {
             RGBColor[0.9730013076923076, 0.979385, 0.9305859230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.0315874366232787], {
             RGBColor[
             0.7243397692307694, 0.7845790000000001, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.0315874366232787], {
             RGBColor[
             0.5551093076923076, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.0315874366232787], {
             RGBColor[
             0.7243397692307694, 0.7845790000000001, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.0315874366232787], {
             RGBColor[
             0.4678596153846154, 0.5788685384615384, 0.9512507692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.0315874366232787], {
             RGBColor[
             0.298759923076923, 0.4313459999999999, 0.9403253076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.0315874366232787], {
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.0315874366232787], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.0315874366232787], {
             RGBColor[
             0.5987341538461539, 0.6851183846153847, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.0315874366232787], {
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.0315874366232787], {
             RGBColor[
             0.9201457692307693, 0.7211116153846153, 0.2546056153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.0315874366232787], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.0315874366232787], {
             RGBColor[0.9178966923076922, 0.937369923076923, 0.992031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.0315874366232787], {
             RGBColor[
             0.5551093076923076, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.0315874366232787], {
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.0315874366232787], {
             RGBColor[
             0.5551093076923076, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.0315874366232787], {
             RGBColor[
             0.3309878461538461, 0.46110676923076915`, 0.9423112307692307]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.0315874366232787], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.0315874366232787], {
             RGBColor[
             0.3643506153846154, 0.49000392307692303`, 0.9444370769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.0315874366232787], {
             RGBColor[0.950619923076923, 0.962693, 0.9684717692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.0315874366232787], {
             RGBColor[
             0.7243397692307694, 0.7845790000000001, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.0315874366232787], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.8268168461538464]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.0315874366232787], {
             RGBColor[
             0.5551093076923076, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.0315874366232787], {
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.0315874366232787], {
             RGBColor[
             0.4678596153846154, 0.5788685384615384, 0.9512507692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.0315874366232787], {
             RGBColor[
             0.4678596153846154, 0.5788685384615384, 0.9512507692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.0315874366232787], {
             RGBColor[
             0.5987341538461539, 0.6851183846153847, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.0315874366232787], {
             RGBColor[0.9394292307692307, 0.954347, 0.9874146923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.0315874366232787], {
             RGBColor[
             0.5551093076923076, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.0315874366232787], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.8268168461538464]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.0315874366232787], {
             RGBColor[
             0.4310761538461538, 0.5477982307692307, 0.9486887692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.0315874366232787], {
             RGBColor[
             0.9867512307692308, 0.9887893076923077, 0.8692299230769233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.0315874366232787], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.0315874366232787], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.0315874366232787], {
             RGBColor[
             0.5987341538461539, 0.6851183846153847, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.0315874366232787], {
             RGBColor[0.950619923076923, 0.962693, 0.9684717692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.0315874366232787], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.0315874366232787], {
             RGBColor[
             0.4310761538461538, 0.5477982307692307, 0.9486887692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.0315874366232787], {
             RGBColor[
             0.9082066923076924, 0.673777153846154, 0.2449991538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.0315874366232787], {
             RGBColor[
             0.4310761538461538, 0.5477982307692307, 0.9486887692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.0315874366232787], {
             RGBColor[
             0.7243397692307694, 0.7845790000000001, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.0315874366232787], {
             RGBColor[
             0.8760288461538461, 0.5299577692307693, 0.21826776923076924`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.0315874366232787], {
             RGBColor[
             0.4310761538461538, 0.5477982307692307, 0.9486887692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.0315874366232787], {
             RGBColor[
             0.5987341538461539, 0.6851183846153847, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.0315874366232787], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.0315874366232787], {
             RGBColor[0.950619923076923, 0.962693, 0.9684717692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.0315874366232787], {
             RGBColor[0.9178966923076922, 0.937369923076923, 0.992031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.0315874366232787], {
             RGBColor[0.9394292307692307, 0.954347, 0.9874146923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.0315874366232787], {
             RGBColor[
             0.4678596153846154, 0.5788685384615384, 0.9512507692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.0315874366232787], {
             RGBColor[
             0.5551093076923076, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.0315874366232787], {
             RGBColor[
             0.9944289230769231, 0.9919642307692308, 0.7419906923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.0315874366232787], {
             RGBColor[
             0.5551093076923076, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.0315874366232787], {
             RGBColor[
             0.5987341538461539, 0.6851183846153847, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.0315874366232787], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.0315874366232787], {
             RGBColor[
             0.3977133846153846, 0.5189010769230769, 0.9465629230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.0315874366232787], {
             RGBColor[
             0.3977133846153846, 0.5189010769230769, 0.9465629230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.0315874366232787], {
             RGBColor[
             0.4678596153846154, 0.5788685384615384, 0.9512507692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.0315874366232787], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.0315874366232787], {
             RGBColor[
             0.9440239230769232, 0.8157805384615386, 0.2738185384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.0315874366232787], {
             RGBColor[0.950619923076923, 0.962693, 0.9684717692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.0315874366232787], {
             RGBColor[
             0.5114844615384614, 0.6142851538461537, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.0315874366232787], {
             RGBColor[
             0.9320848461538462, 0.7684460769230773, 0.264212076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.0315874366232787], {
             RGBColor[
             0.5551093076923076, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.0315874366232787], {
             RGBColor[
             0.7243397692307694, 0.7845790000000001, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.0315874366232787], {
             RGBColor[
             0.4310761538461538, 0.5477982307692307, 0.9486887692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.0315874366232787], {
             RGBColor[
             0.8971774615384616, 0.6259886923076927, 0.23591469230769238`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.0315874366232787], {
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.0315874366232787], {
             RGBColor[
             0.8457631538461539, 0.3527612307692307, 0.19145615384615383`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.0315874366232787], {
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.0315874366232787], {
             RGBColor[
             0.9867512307692308, 0.9887893076923077, 0.8692299230769233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.0315874366232787], {
             RGBColor[
             0.8971774615384616, 0.6259886923076927, 0.23591469230769238`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.0315874366232787], {
             RGBColor[0.9394292307692307, 0.954347, 0.9874146923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.0315874366232787], {
             RGBColor[
             0.3643506153846154, 0.49000392307692303`, 0.9444370769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.0315874366232787], {
             RGBColor[
             0.7243397692307694, 0.7845790000000001, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.0315874366232787], {
             RGBColor[
             0.5551093076923076, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.0315874366232787], {
             RGBColor[
             0.4310761538461538, 0.5477982307692307, 0.9486887692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.0315874366232787], {
             RGBColor[
             0.5551093076923076, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.0315874366232787], {
             RGBColor[
             0.3977133846153846, 0.5189010769230769, 0.9465629230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.0315874366232787], {
             RGBColor[
             0.5551093076923076, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.0315874366232787], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.0315874366232787], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.0315874366232787], {
             RGBColor[
             0.8760288461538461, 0.5299577692307693, 0.21826776923076924`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.0315874366232787], {
             RGBColor[
             0.4678596153846154, 0.5788685384615384, 0.9512507692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.0315874366232787], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.0315874366232787], {
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.0315874366232787], {
             RGBColor[
             0.3977133846153846, 0.5189010769230769, 0.9465629230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.0315874366232787], {
             RGBColor[
             0.3643506153846154, 0.49000392307692303`, 0.9444370769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.0315874366232787], {
             RGBColor[
             0.4310761538461538, 0.5477982307692307, 0.9486887692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.0315874366232787], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.0315874366232787], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.0315874366232787], {
             RGBColor[
             0.5551093076923076, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.0315874366232787], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.0315874366232787], {
             RGBColor[0.9178966923076922, 0.937369923076923, 0.992031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.0315874366232787], {
             RGBColor[
             0.9643953076923077, 0.891559153846154, 0.3161829230769233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.0315874366232787], {
             RGBColor[
             0.4678596153846154, 0.5788685384615384, 0.9512507692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.0315874366232787], {
             RGBColor[
             0.9948544615384616, 0.9914025384615385, 0.6813180769230774]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.0315874366232787], {
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.0315874366232787], {
             RGBColor[0.9394292307692307, 0.954347, 0.9874146923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.0315874366232787], {
             RGBColor[
             0.4310761538461538, 0.5477982307692307, 0.9486887692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.0315874366232787], {
             RGBColor[
             0.3977133846153846, 0.5189010769230769, 0.9465629230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.0315874366232787], {
             RGBColor[0.9394292307692307, 0.954347, 0.9874146923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.0315874366232787], {
             RGBColor[
             0.7243397692307694, 0.7845790000000001, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.0315874366232787], {
             RGBColor[0.950619923076923, 0.962693, 0.9684717692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.0315874366232787], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.0315874366232787], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.0315874366232787], {
             RGBColor[
             0.7243397692307694, 0.7845790000000001, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.0315874366232787], {
             RGBColor[
             0.4310761538461538, 0.5477982307692307, 0.9486887692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.0315874366232787], {
             RGBColor[
             0.7243397692307694, 0.7845790000000001, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.0315874366232787], {
             RGBColor[0.9394292307692307, 0.954347, 0.9874146923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.0315874366232787], {
             RGBColor[
             0.7243397692307694, 0.7845790000000001, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.0315874366232787], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.0315874366232787], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.0315874366232787], {
             RGBColor[0.9178966923076922, 0.937369923076923, 0.992031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.0315874366232787], {
             RGBColor[
             0.5987341538461539, 0.6851183846153847, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.0315874366232787], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.0315874366232787], {
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.0315874366232787], {
             RGBColor[
             0.5114844615384614, 0.6142851538461537, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.0315874366232787], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.0315874366232787], {
             RGBColor[0.950619923076923, 0.962693, 0.9684717692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.0315874366232787], {
             RGBColor[
             0.4678596153846154, 0.5788685384615384, 0.9512507692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.0315874366232787], {
             RGBColor[
             0.5114844615384614, 0.6142851538461537, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.0315874366232787], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.0315874366232787], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.0315874366232787], {
             RGBColor[
             0.5114844615384614, 0.6142851538461537, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.0315874366232787], {
             RGBColor[
             0.5551093076923076, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.0315874366232787], {
             RGBColor[
             0.5114844615384614, 0.6142851538461537, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.0315874366232787], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.0315874366232787], {
             RGBColor[
             0.5551093076923076, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.0315874366232787], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.0315874366232787], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.0315874366232787], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.0315874366232787], {
             RGBColor[
             0.4678596153846154, 0.5788685384615384, 0.9512507692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.0315874366232787], {
             RGBColor[
             0.5551093076923076, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.0315874366232787], {
             RGBColor[
             0.7243397692307694, 0.7845790000000001, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.0315874366232787], {
             RGBColor[
             0.9918696923076923, 0.990905923076923, 0.7844037692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.0315874366232787], {
             RGBColor[
             0.5114844615384614, 0.6142851538461537, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.0315874366232787], {
             RGBColor[
             0.8760288461538461, 0.5299577692307693, 0.21826776923076924`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.0315874366232787], {
             RGBColor[
             0.4310761538461538, 0.5477982307692307, 0.9486887692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.0315874366232787], {
             RGBColor[
             0.5987341538461539, 0.6851183846153847, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.0315874366232787], {
             RGBColor[
             0.5551093076923076, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.0315874366232787], {
             RGBColor[
             0.5987341538461539, 0.6851183846153847, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.0315874366232787], {
             RGBColor[0.9178966923076922, 0.937369923076923, 0.992031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.0315874366232787], {
             RGBColor[
             0.9948544615384616, 0.9914025384615385, 0.6813180769230774]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.0315874366232787], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.0315874366232787], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.0315874366232787], {
             RGBColor[
             0.5551093076923076, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.0315874366232787], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.0315874366232787], {
             RGBColor[0.9394292307692307, 0.954347, 0.9874146923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.0315874366232787], {
             RGBColor[
             0.5551093076923076, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.0315874366232787], {
             RGBColor[
             0.298759923076923, 0.4313459999999999, 0.9403253076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.0315874366232787], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.0315874366232787], {
             RGBColor[
             0.5114844615384614, 0.6142851538461537, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.0315874366232787], {
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.0315874366232787], {
             RGBColor[
             0.9948544615384616, 0.9914025384615385, 0.6813180769230774]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.0315874366232787], {
             RGBColor[0.9178966923076922, 0.937369923076923, 0.992031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.0315874366232787], {
             RGBColor[
             0.9944289230769231, 0.9919642307692308, 0.7419906923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.0315874366232787], {
             RGBColor[0.9394292307692307, 0.954347, 0.9874146923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.0315874366232787], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.0315874366232787], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.0315874366232787], {
             RGBColor[
             0.5114844615384614, 0.6142851538461537, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.0315874366232787], {
             RGBColor[
             0.9728276153846154, 0.9200033076923078, 0.34894084615384624`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.0315874366232787], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.0315874366232787], {
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.0315874366232787], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.0315874366232787], {
             RGBColor[
             0.3643506153846154, 0.49000392307692303`, 0.9444370769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.0315874366232787], {
             RGBColor[
             0.4310761538461538, 0.5477982307692307, 0.9486887692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.0315874366232787], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.0315874366232787], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.0315874366232787], {
             RGBColor[0.955963, 0.863115, 0.283425]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.0315874366232787], {
             RGBColor[
             0.3977133846153846, 0.5189010769230769, 0.9465629230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.0315874366232787], {
             RGBColor[0.9730013076923076, 0.979385, 0.9305859230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.0315874366232787], {
             RGBColor[
             0.3977133846153846, 0.5189010769230769, 0.9465629230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.0315874366232787], {
             RGBColor[
             0.4678596153846154, 0.5788685384615384, 0.9512507692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.0315874366232787], {
             RGBColor[0.9178966923076922, 0.937369923076923, 0.992031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.0315874366232787], {
             RGBColor[0.9394292307692307, 0.954347, 0.9874146923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.0315874366232787], {
             RGBColor[
             0.9948544615384616, 0.9914025384615385, 0.6813180769230774]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.0315874366232787], {
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.0315874366232787], {
             RGBColor[0.2388434615384615, 0.36837, 0.9369131538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.0315874366232787], {
             RGBColor[
             0.9867512307692308, 0.9887893076923077, 0.8692299230769233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.0315874366232787], {
             RGBColor[
             0.9948544615384616, 0.9914025384615385, 0.6813180769230774]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.0315874366232787], {
             RGBColor[
             0.9935718461538462, 0.9886591538461539, 0.5417133076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.0315874366232787], {
             RGBColor[
             0.5114844615384614, 0.6142851538461537, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.0315874366232787], {
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.0315874366232787], {
             RGBColor[
             0.5114844615384614, 0.6142851538461537, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.0315874366232787], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.0315874366232787], {
             RGBColor[
             0.7243397692307694, 0.7845790000000001, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.0315874366232787], {
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.0315874366232787], {
             RGBColor[
             0.5987341538461539, 0.6851183846153847, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.0315874366232787], {
             RGBColor[
             0.4678596153846154, 0.5788685384615384, 0.9512507692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.0315874366232787], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.0315874366232787], {
             RGBColor[
             0.9867512307692308, 0.9887893076923077, 0.8692299230769233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.0315874366232787], {
             RGBColor[
             0.4678596153846154, 0.5788685384615384, 0.9512507692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.0315874366232787], {
             RGBColor[
             0.3977133846153846, 0.5189010769230769, 0.9465629230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.0315874366232787], {
             RGBColor[
             0.5987341538461539, 0.6851183846153847, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.0315874366232787], {
             RGBColor[0.9618106153846153, 0.971039, 0.9495288461538461]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.0315874366232787], {
             RGBColor[
             0.298759923076923, 0.4313459999999999, 0.9403253076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.0315874366232787], {
             RGBColor[0.8644897692307693, 0.8947846923076923, 0.986937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[401, 0.0315874366232787], {
             RGBColor[
             0.7243397692307694, 0.7845790000000001, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[402, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[403, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[404, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[405, 0.0315874366232787], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[406, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[407, 0.0315874366232787], {
             RGBColor[
             0.4310761538461538, 0.5477982307692307, 0.9486887692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[408, 0.0315874366232787], {
             RGBColor[
             0.4678596153846154, 0.5788685384615384, 0.9512507692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[409, 0.0315874366232787], {
             RGBColor[
             0.3643506153846154, 0.49000392307692303`, 0.9444370769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[410, 0.0315874366232787], {
             RGBColor[
             0.4310761538461538, 0.5477982307692307, 0.9486887692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[411, 0.0315874366232787], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[412, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[413, 0.0315874366232787], {
             RGBColor[
             0.5987341538461539, 0.6851183846153847, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[414, 0.0315874366232787], {
             RGBColor[
             0.9944289230769231, 0.9919642307692308, 0.7419906923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[415, 0.0315874366232787], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[416, 0.0315874366232787], {
             RGBColor[
             0.20888523076923077`, 0.33688199999999996`, 0.9352070769230769]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[417, 0.0315874366232787], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[418, 0.0315874366232787], {
             RGBColor[
             0.9728276153846154, 0.9200033076923078, 0.34894084615384624`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[419, 0.0315874366232787], {
             RGBColor[
             0.3643506153846154, 0.49000392307692303`, 0.9444370769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[420, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[421, 0.0315874366232787], {
             RGBColor[0.2388434615384615, 0.36837, 0.9369131538461538]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[422, 0.0315874366232787], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[423, 0.0315874366232787], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.8268168461538464]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[424, 0.0315874366232787], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[425, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[426, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[427, 0.0315874366232787], {
             RGBColor[
             0.9918696923076923, 0.990905923076923, 0.7844037692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[428, 0.0315874366232787], {
             RGBColor[
             0.4310761538461538, 0.5477982307692307, 0.9486887692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[429, 0.0315874366232787], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[430, 0.0315874366232787], {
             RGBColor[
             0.5551093076923076, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[431, 0.0315874366232787], {
             RGBColor[0.9178966923076922, 0.937369923076923, 0.992031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[432, 0.0315874366232787], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[433, 0.0315874366232787], {
             RGBColor[
             0.9948544615384616, 0.9914025384615385, 0.6813180769230774]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[434, 0.0315874366232787], {
             RGBColor[
             0.9948544615384616, 0.9914025384615385, 0.6813180769230774]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[435, 0.0315874366232787], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[436, 0.0315874366232787], {
             RGBColor[
             0.5114844615384614, 0.6142851538461537, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[437, 0.0315874366232787], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[438, 0.0315874366232787], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.8268168461538464]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[439, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[440, 0.0315874366232787], {
             RGBColor[
             0.5114844615384614, 0.6142851538461537, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[441, 0.0315874366232787], {
             RGBColor[
             0.9944289230769231, 0.9919642307692308, 0.7419906923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[442, 0.0315874366232787], {
             RGBColor[0.9178966923076922, 0.937369923076923, 0.992031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[443, 0.0315874366232787], {
             RGBColor[
             0.9728276153846154, 0.9200033076923078, 0.34894084615384624`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[444, 0.0315874366232787], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[445, 0.0315874366232787], {
             RGBColor[
             0.5114844615384614, 0.6142851538461537, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[446, 0.0315874366232787], {
             RGBColor[
             0.9948544615384616, 0.9914025384615385, 0.6813180769230774]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[447, 0.0315874366232787], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[448, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[449, 0.0315874366232787], {
             RGBColor[
             0.9440239230769232, 0.8157805384615386, 0.2738185384615385]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[450, 0.0315874366232787], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[451, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[452, 0.0315874366232787], {
             RGBColor[
             0.298759923076923, 0.4313459999999999, 0.9403253076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[453, 0.0315874366232787], {
             RGBColor[0.9394292307692307, 0.954347, 0.9874146923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[454, 0.0315874366232787], {
             RGBColor[
             0.9643953076923077, 0.891559153846154, 0.3161829230769233]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[455, 0.0315874366232787], {
             RGBColor[
             0.5114844615384614, 0.6142851538461537, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[456, 0.0315874366232787], {
             RGBColor[
             0.5551093076923076, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[457, 0.0315874366232787], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[458, 0.0315874366232787], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[459, 0.0315874366232787], {
             RGBColor[
             0.4310761538461538, 0.5477982307692307, 0.9486887692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[460, 0.0315874366232787], {
             RGBColor[
             0.4310761538461538, 0.5477982307692307, 0.9486887692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[461, 0.0315874366232787], {
             RGBColor[
             0.5114844615384614, 0.6142851538461537, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[462, 0.0315874366232787], {
             RGBColor[
             0.5987341538461539, 0.6851183846153847, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[463, 0.0315874366232787], {
             RGBColor[
             0.9201457692307693, 0.7211116153846153, 0.2546056153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[464, 0.0315874366232787], {
             RGBColor[
             0.9893104615384615, 0.9898476153846154, 0.8268168461538464]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[465, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[466, 0.0315874366232787], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[467, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[468, 0.0315874366232787], {
             RGBColor[
             0.4678596153846154, 0.5788685384615384, 0.9512507692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[469, 0.0315874366232787], {
             RGBColor[0.9178966923076922, 0.937369923076923, 0.992031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[470, 0.0315874366232787], {
             RGBColor[
             0.5551093076923076, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[471, 0.0315874366232787], {
             RGBColor[
             0.7243397692307694, 0.7845790000000001, 0.9731590769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[472, 0.0315874366232787], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[473, 0.0315874366232787], {
             RGBColor[0.6833493846153846, 0.752557, 0.9690735384615384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[474, 0.0315874366232787], {
             RGBColor[
             0.3977133846153846, 0.5189010769230769, 0.9465629230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[475, 0.0315874366232787], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[476, 0.0315874366232787], {
             RGBColor[
             0.4678596153846154, 0.5788685384615384, 0.9512507692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[477, 0.0315874366232787], {
             RGBColor[0.6423589999999999, 0.7205349999999999, 0.964988]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[478, 0.0315874366232787], {
             RGBColor[0.984192, 0.987731, 0.911643]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[479, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[480, 0.0315874366232787], {
             RGBColor[
             0.5987341538461539, 0.6851183846153847, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[481, 0.0315874366232787], {
             RGBColor[
             0.9942131538461538, 0.9900308461538462, 0.6115156923076922]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[482, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[483, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[484, 0.0315874366232787], {
             RGBColor[0.8063205384615386, 0.848623, 0.9813301538461539]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[485, 0.0315874366232787], {
             RGBColor[
             0.5987341538461539, 0.6851183846153847, 0.9615536923076923]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[486, 0.0315874366232787], {
             RGBColor[
             0.9935718461538462, 0.9886591538461539, 0.5417133076923077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[487, 0.0315874366232787], {
             RGBColor[
             0.9948544615384616, 0.9914025384615385, 0.6813180769230774]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[488, 0.0315874366232787], {
             RGBColor[0.8377863076923078, 0.873492076923077, 0.98439]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[489, 0.0315874366232787], {
             RGBColor[
             0.4678596153846154, 0.5788685384615384, 0.9512507692307692]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[490, 0.0315874366232787], {
             RGBColor[
             0.5114844615384614, 0.6142851538461537, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[491, 0.0315874366232787], {
             RGBColor[
             0.9944289230769231, 0.9919642307692308, 0.7419906923076924]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[492, 0.0315874366232787], {
             RGBColor[
             0.7653301538461539, 0.8166009999999999, 0.9772446153846154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[493, 0.0315874366232787], {
             RGBColor[0.9730013076923076, 0.979385, 0.9305859230769231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[494, 0.0315874366232787], {
             RGBColor[
             0.5551093076923076, 0.6497017692307692, 0.9581193846153846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[495, 0.0315874366232787], {
             RGBColor[
             0.3643506153846154, 0.49000392307692303`, 0.9444370769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[496, 0.0315874366232787], {
             RGBColor[
             0.4310761538461538, 0.5477982307692307, 0.9486887692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[497, 0.0315874366232787], {
             RGBColor[
             0.4310761538461538, 0.5477982307692307, 0.9486887692307693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[498, 0.0315874366232787], {
             RGBColor[
             0.5114844615384614, 0.6142851538461537, 0.9546850769230769]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[499, 0.0315874366232787], {
             RGBColor[0.8911932307692307, 0.9160773076923077, 0.989484]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[500, 0.0315874366232787], {
             RGBColor[
             0.9867512307692308, 0.9887893076923077, 0.8692299230769233]}, 
            StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}], 
   GraphicsBox[
    NamespaceBox["NetworkGraphics", 
     DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[CompressedData["
1:eJwl1dOWGAgQBNBMbNu2bds2J+bEtm3btm3btu01sjdnH271F1R1ssCg6p0C
ggUL9l38vMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEIS
kZgkJCUZyUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpR
mCIUpRjFKUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGY
JjSlGYE0pwUtaUVr2tCWdrSnAx3pRBCd6UJXutGdHvSkF73pQ1/60Z8BDGQQ
gxnCUIYxnBGMZBSjGcNYxjGeCUxkEpOZwlSmMZ0ZzGQWs5nDXOYxnwUsZBGL
WcJSlrGcFaxkFatZw1rWsZ4NbGQTm9nCVraxnR3sZBe72cNe9rGfAxzkEIc5
wlGOcZwTnOQUpznDWc5xngtc5BKXucJVrnGdG9zkFre5w13ucZ8HPOQRj3nC
U57xnBe85BWvecNb3vGeD3zkE5/5wle+8Z1f+JXf+J0/+JO/+Jt/+Jcf/Cx/
AMEJQUhCEZowhCUc4YlARCIRmShEJRrRiUFMYhGbOMQlHvFJQEISkZgkJCUZ
yUlBSlKRmjSkJR3pyUBGMpGZLGQlG9nJQU5ykZs85CUf+SlAQQpRmCIUpRjF
KUFJSlGaMpSlHOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGYJjSlGYE0
pwUtaUVr2tCWdrSnAx35Od5BdKYLXelGd3rQk170pg996Ud/BjCQQQxmCEMZ
xnBGMJJRjGYMYxnHeCYwkUlMZgpTmcZ0ZjCTWcxmDnOZx3wWsJBFLGYJS1nG
clawklWsZg1rWcd6NrCRTWxmC1vZxnZ2sJNd7GYPe9nHfg5wkEMc5ghHOcZx
TnCSU5zmDGc5x3kucJFLXOYKV7nGdW5wk1vc5g53ucd9HvCQRzzmCU95xnNe
8JJXvOYNb3nHez7wkU985gtf+Rbw/z//Dz189+A=
          "], {Null, CompressedData["
1:eJw13A2c1mO6wPH7tsdpl2O9LLLYQ3Ioas/uCqvVrqQihdKSUmmVzEwspdpK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           "]}, {EdgeStyle -> {
             Directive[
              Hue[0.63, 0.7, 0.5], 
              Opacity[0.7]], UndirectedEdge[196, 330] -> 
             RGBColor[
              0.3010744440099954, 0.433778708249762, 0.9404571162354194], 
             UndirectedEdge[136, 319] -> 
             RGBColor[
              0.8419251732908781, 0.8767840075536342, 0.9548214315268342], 
             UndirectedEdge[60, 188] -> 
             RGBColor[
              0.31499337168742486`, 0.44577048443841216`, 0.9413463649912971],
              UndirectedEdge[145, 408] -> 
             RGBColor[
              0.2215813501340996, 0.35022642643293833`, 0.9359301021386808], 
             UndirectedEdge[398, 460] -> 
             RGBColor[
              0.2547486544855675, 0.3850873662348864, 0.9378189310548671], 
             UndirectedEdge[413, 476] -> 
             RGBColor[
              0.9111642263834832, 0.6485722673362936, 0.273464018883213], 
             UndirectedEdge[244, 274] -> 
             RGBColor[
              0.40258764491589, 0.5228672426461249, 0.9469441500000384], 
             UndirectedEdge[198, 223] -> 
             RGBColor[
              0.335871613441881, 0.4628528461466326, 0.9427133713948876], 
             UndirectedEdge[36, 310] -> 
             RGBColor[
              0.2755731801551128, 0.4069752630647657, 0.9390048569846228], 
             UndirectedEdge[252, 432] -> 
             RGBColor[
              0.8172102397534445, 0.8577657390481622, 0.982246863062763], 
             UndirectedEdge[469, 475] -> 
             RGBColor[
              0.8497170345102683, 0.3799664311487149, 0.19511763635494941`], 
             UndirectedEdge[113, 347] -> 
             RGBColor[
              0.17905963034776856`, 0.3055334029047545, 0.9335085531020964], 
             UndirectedEdge[35, 131] -> 
             RGBColor[
              0.2509907389862678, 0.38113755877951816`, 0.9376049233265198], 
             UndirectedEdge[156, 479] -> 
             RGBColor[
              0.4393999195807523, 0.5546279653397757, 0.9493241177753168], 
             UndirectedEdge[318, 354] -> 
             RGBColor[
              0.35185308329442466`, 0.47917918892462685`, 0.9436407452294238],
              UndirectedEdge[6, 77] -> 
             RGBColor[
              0.7172538475630181, 0.7785612627115652, 0.9728085302210365], 
             UndirectedEdge[23, 202] -> 
             RGBColor[
              0.23077928410080303`, 0.35989403821464017`, 0.9364539108709606],
              UndirectedEdge[342, 395] -> 
             RGBColor[
              0.2624873580585535, 0.3932212343522405, 0.9382596387749628], 
             UndirectedEdge[53, 418] -> 
             RGBColor[
              0.9774928986004763, 0.9579493905915291, 0.642289060004833], 
             UndirectedEdge[75, 149] -> 
             RGBColor[
              0.3494116417234011, 0.4770645349462275, 0.9434851787314], 
             UndirectedEdge[293, 418] -> 
             RGBColor[
              0.9663729017016692, 0.9744415456652006, 0.9418060854539165], 
             UndirectedEdge[282, 432] -> 
             RGBColor[
              0.7531414292760994, 0.8071831282683875, 0.9762245194841053], 
             UndirectedEdge[466, 468] -> 
             RGBColor[
              0.49094259840512156`, 0.5976083439541202, 0.9530679462098963], 
             UndirectedEdge[105, 190] -> 
             RGBColor[
              0.24700744449895456`, 0.37695086371789455`, 0.9373780805982235],
              UndirectedEdge[64, 473] -> 
             RGBColor[
              0.3073328542986736, 0.43868458843205593`, 0.9408747474285853], 
             UndirectedEdge[214, 273] -> 
             RGBColor[
              0.24667426527178135`, 0.3766006712253524, 0.9373591065341305], 
             UndirectedEdge[30, 64] -> 
             RGBColor[
              0.27788283656739987`, 0.4094028583947541, 0.9391363885004721], 
             UndirectedEdge[296, 395] -> 
             RGBColor[
              0.289203696626415, 0.4208696734674796, 0.9397969170059906], 
             UndirectedEdge[114, 203] -> 
             RGBColor[
              0.5176225598035007, 0.6192683385358883, 0.9551682905030956], 
             UndirectedEdge[81, 237] -> 
             RGBColor[
              0.8648552697662895, 0.8950761325134684, 0.9869718617673642], 
             UndirectedEdge[382, 427] -> 
             RGBColor[
              0.2808624118228371, 0.41253458090420103`, 0.9393060709033827], 
             UndirectedEdge[39, 450] -> 
             RGBColor[
              0.7206850354992045, 0.4212381693670362, 0.5640535204963621], 
             UndirectedEdge[50, 57] -> 
             RGBColor[
              0.5210905073010532, 0.6217476292469348, 0.9555341779806428], 
             UndirectedEdge[74, 153] -> 
             RGBColor[
              0.2633334885240648, 0.39411057111926295`, 0.9383078246532357], 
             UndirectedEdge[239, 332] -> 
             RGBColor[
              0.37656128496655794`, 0.5005801913427036, 0.9452151299913671], 
             UndirectedEdge[14, 72] -> 
             RGBColor[
              0.2803635687690008, 0.4120102652261427, 0.9392776625294388], 
             UndirectedEdge[331, 403] -> 
             RGBColor[
              0.8828018353475209, 0.9093862367613971, 0.9886836212135901], 
             UndirectedEdge[214, 302] -> 
             RGBColor[
              0.19497823659732902`, 0.32226486737097304`, 0.9344150941785414],
              UndirectedEdge[128, 197] -> 
             RGBColor[
              0.5961844176461558, 0.6822017797294064, 0.9619318024689351], 
             UndirectedEdge[191, 212] -> 
             RGBColor[
              0.21845881642544385`, 0.3469444455250692, 0.9357522784633475], 
             UndirectedEdge[404, 407] -> 
             RGBColor[
              0.2139033248740353, 0.3421563350696921, 0.9354928499587406], 
             UndirectedEdge[60, 116] -> 
             RGBColor[
              0.27071777339856856`, 0.4018719227130688, 0.9387283487527682], 
             UndirectedEdge[272, 357] -> 
             RGBColor[
              0.8638626077841431, 0.41438606964025426`, 0.20574312527482636`],
              UndirectedEdge[228, 490] -> 
             RGBColor[
              0.9918174311383581, 0.9889858002878001, 0.6472681311594083], 
             UndirectedEdge[111, 415] -> 
             RGBColor[
              0.2800519643946353, 0.41168274927182613`, 0.9392599171212961], 
             UndirectedEdge[227, 428] -> 
             RGBColor[
              0.8379823315719487, 0.29295442119162834`, 0.18400522964919308`],
              UndirectedEdge[367, 499] -> 
             RGBColor[
              0.24528184927831587`, 0.3751371537319471, 0.9372798105031974], 
             UndirectedEdge[434, 495] -> 
             RGBColor[
              0.9167025248852594, 0.6580111596730529, 0.4917530067660364], 
             UndirectedEdge[226, 283] -> 
             RGBColor[
              0.18031957576389654`, 0.30685768542225833`, 0.9335803051296228],
              UndirectedEdge[9, 34] -> 
             RGBColor[
              0.559448373541096, 0.6532244183595045, 0.9584609717735231], 
             UndirectedEdge[127, 386] -> 
             RGBColor[
              0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993],
              UndirectedEdge[326, 469] -> 
             RGBColor[
              0.8678030946468546, 0.4926065528105953, 0.21140400054171546`], 
             UndirectedEdge[192, 483] -> 
             RGBColor[
              0.275631905541692, 0.4070369871694651, 0.9390082013085121], 
             UndirectedEdge[16, 39] -> 
             RGBColor[
              0.5137718344766236, 0.6147998451486828, 0.9552360290912556], 
             UndirectedEdge[209, 421] -> 
             RGBColor[
              0.37249008899703795`, 0.4820057501195733, 0.9462395519949527], 
             UndirectedEdge[293, 317] -> 
             RGBColor[
              0.9188363181868828, 0.7644234365766909, 0.5933539685152149], 
             UndirectedEdge[3, 381] -> 
             RGBColor[
              0.5154854178683257, 0.6175333104357662, 0.9550000468613498], 
             UndirectedEdge[211, 497] -> 
             RGBColor[
              0.23351702426712523`, 0.36277157671219695`, 0.936609821123309], 
             UndirectedEdge[196, 479] -> 
             RGBColor[
              0.35359500425427093`, 0.4794816999667437, 0.9437959057364866], 
             UndirectedEdge[221, 439] -> 
             RGBColor[
              0.6987612824501502, 0.7633077628527738, 0.9716294265306357], 
             UndirectedEdge[379, 390] -> 
             RGBColor[
              0.30502633329137085`, 0.4378812473959014, 0.9406840432278518], 
             UndirectedEdge[119, 320] -> 
             RGBColor[
              0.9896249360090673, 0.9899776586598361, 0.8216051903420669], 
             UndirectedEdge[179, 401] -> 
             RGBColor[
              0.47619075737058414`, 0.5641711945885997, 0.9557776422261561], 
             UndirectedEdge[59, 342] -> 
             RGBColor[
              0.25108912406320616`, 0.3812409677333546, 0.9376105262111039], 
             UndirectedEdge[86, 98] -> 
             RGBColor[
              0.9552139147274563, 0.8468459050338089, 0.4866646892725739], 
             UndirectedEdge[328, 431] -> 
             RGBColor[
              0.4169264678183623, 0.535542483915856, 0.9477871637491544], 
             UndirectedEdge[270, 375] -> 
             RGBColor[
              0.9741122632489756, 0.9792447932430604, 0.8853225104060825], 
             UndirectedEdge[39, 45] -> 
             RGBColor[
              0.45322202962692537`, 0.5599541419213354, 0.9514657433370749], 
             UndirectedEdge[59, 463] -> 
             RGBColor[
              0.2546442329532448, 0.38497761258370766`, 0.9378129844030793], 
             UndirectedEdge[2, 55] -> 
             RGBColor[
              0.21196267506411343`, 0.3401165890751596, 0.9353823328229998], 
             UndirectedEdge[193, 496] -> 
             RGBColor[
              0.28235063055336573`, 0.41409879314850406`, 0.939390822758464], 
             UndirectedEdge[201, 246] -> 
             RGBColor[
              0.2993400916080083, 0.43195579391098005`, 0.9403583474318706], 
             UndirectedEdge[69, 487] -> 
             RGBColor[
              0.7444469428218465, 0.8000461273805028, 0.9756303235156909], 
             UndirectedEdge[15, 408] -> 
             RGBColor[
              0.22837166352845595`, 0.3573634763411423, 0.9363168004411209], 
             UndirectedEdge[118, 310] -> 
             RGBColor[
              0.3109325878407584, 0.44262745407148385`, 0.9410739135361832], 
             UndirectedEdge[289, 297] -> 
             RGBColor[
              0.47936763079523015`, 0.5878325714725148, 0.9522613561781106], 
             UndirectedEdge[397, 419] -> 
             RGBColor[
              0.43561929438142943`, 0.5501211672171827, 0.9494236831393772], 
             UndirectedEdge[13, 380] -> 
             RGBColor[
              0.28473366122711574`, 0.4166035094794867, 0.939526532829956], 
             UndirectedEdge[155, 262] -> 
             RGBColor[
              0.520987467347936, 0.6220001220678183, 0.9554331883510561], 
             UndirectedEdge[182, 324] -> 
             RGBColor[
              0.37413205522389265`, 0.49847611463624397`, 0.9450603416202481],
              UndirectedEdge[177, 245] -> 
             RGBColor[
              0.21512971428686242`, 0.34344534810015337`, 0.9355626910215206],
              UndirectedEdge[113, 325] -> 
             RGBColor[
              0.1791045905323438, 0.30558065890938335`, 0.9335111135180953], 
             UndirectedEdge[94, 368] -> 
             RGBColor[
              0.6817603644893816, 0.7470855364406719, 0.9537864521193352], 
             UndirectedEdge[50, 140] -> 
             RGBColor[
              0.47028604559026116`, 0.5805022785151959, 0.9515346646518938], 
             UndirectedEdge[389, 458] -> 
             RGBColor[
              0.2244995192065336, 0.35329360715067204`, 0.9360962875503116], 
             UndirectedEdge[429, 499] -> 
             RGBColor[
              0.2771583025105514, 0.4086413271628938, 0.9390951273577867], 
             UndirectedEdge[97, 358] -> 
             RGBColor[
              0.2286803601297014, 0.35768793604154625`, 0.9363343802558861], 
             UndirectedEdge[274, 363] -> 
             RGBColor[
              0.4337728092244554, 0.5498782645582716, 0.9489312410938221], 
             UndirectedEdge[255, 274] -> 
             RGBColor[
              0.43015989340709154`, 0.5467489384677, 0.9487010292927157], 
             UndirectedEdge[289, 381] -> 
             RGBColor[
              0.5043379271734174, 0.6081045829713598, 0.9542271093782111], 
             UndirectedEdge[55, 230] -> 
             RGBColor[
              0.21767784356668446`, 0.34612359353397393`, 0.935707803214387], 
             UndirectedEdge[289, 349] -> 
             RGBColor[
              0.42648626116779464`, 0.5438226964259498, 0.9483963053279869], 
             UndirectedEdge[29, 318] -> 
             RGBColor[
              0.37578131668551923`, 0.4999046220200136, 0.9451654311021982], 
             UndirectedEdge[69, 402] -> 
             RGBColor[
              0.7308868707375382, 0.7890374499881754, 0.9745628249690335], 
             UndirectedEdge[6, 413] -> 
             RGBColor[
              0.9007629224656561, 0.8944231613369187, 0.6681426582115271], 
             UndirectedEdge[29, 482] -> 
             RGBColor[
              0.38405087443932273`, 0.5070672973063002, 0.9456923600097877], 
             UndirectedEdge[212, 456] -> 
             RGBColor[
              0.22108739015867407`, 0.34970724317989477`, 0.9359019718488286],
              UndirectedEdge[354, 482] -> 
             RGBColor[
              0.3601226410482282, 0.48634186421091347`, 0.9441676741370133], 
             UndirectedEdge[106, 247] -> 
             RGBColor[
              0.5064333598698463, 0.6101844419620349, 0.9542874356969284], 
             UndirectedEdge[305, 382] -> 
             RGBColor[
              0.2666682843502908, 0.39761565297089385`, 0.938497736342151], 
             UndirectedEdge[279, 285] -> 
             RGBColor[
              0.2964892825686648, 0.42843496613236076`, 0.9402152006381983], 
             UndirectedEdge[27, 319] -> 
             RGBColor[
              0.6135043005796454, 0.695998377538924, 0.9634761021745089], 
             UndirectedEdge[118, 483] -> 
             RGBColor[
              0.31087863822406303`, 0.44257074960373377`, 0.9410708411853237],
              UndirectedEdge[342, 447] -> 
             RGBColor[
              0.2532435452217043, 0.38350540096912705`, 0.9377332173088998], 
             UndirectedEdge[207, 458] -> 
             RGBColor[
              0.22378112515977486`, 0.35253852945871533`, 0.9360553760721175],
              UndirectedEdge[462, 487] -> 
             RGBColor[
              0.5216548713893666, 0.6225419507348611, 0.9554857288419789], 
             UndirectedEdge[64, 384] -> 
             RGBColor[
              0.28582762436265047`, 0.41775333409620263`, 0.9395888324121513],
              UndirectedEdge[203, 221] -> 
             RGBColor[
              0.5355883582024223, 0.6338537830261275, 0.9565826239639467], 
             UndirectedEdge[139, 370] -> 
             RGBColor[
              0.5777392587332322, 0.6680737829534684, 0.9599008972575682], 
             UndirectedEdge[46, 357] -> 
             RGBColor[
              0.9123985653292456, 0.6903965335177349, 0.2483720332752017], 
             UndirectedEdge[18, 326] -> 
             RGBColor[
              0.8797797158009789, 0.5469895922605361, 0.22139758680656518`], 
             UndirectedEdge[73, 93] -> 
             RGBColor[
              0.2585978739086303, 0.3891331399031328, 0.9380381384066008], 
             UndirectedEdge[104, 112] -> 
             RGBColor[
              0.24741859649764936`, 0.37738301053706513`, 0.9374014950963042],
              UndirectedEdge[40, 314] -> 
             RGBColor[
              0.35813781501059505`, 0.484622707657373, 0.944041202777008], 
             UndirectedEdge[264, 398] -> 
             RGBColor[0.2479686232623, 0.377961123540424, 0.9374328183068594],
              UndirectedEdge[345, 489] -> 
             RGBColor[
              0.8249113944148371, 0.8621373590775923, 0.8902454594075883], 
             UndirectedEdge[80, 417] -> 
             RGBColor[
              0.7452877880838611, 0.8009437515388753, 0.9752469796719869], 
             UndirectedEdge[271, 442] -> 
             RGBColor[
              0.26987532258207286`, 0.400986453490465, 0.9386803724250632], 
             UndirectedEdge[318, 482] -> 
             RGBColor[
              0.35021188070592757`, 0.4777576617317112, 0.9435361692517431], 
             UndirectedEdge[235, 260] -> 
             RGBColor[
              0.32130907660212404`, 0.45058132040043347`, 0.941772944022762], 
             UndirectedEdge[79, 278] -> 
             RGBColor[
              0.9710962278680113, 0.9751094566161655, 0.770981396643022], 
             UndirectedEdge[137, 404] -> 
             RGBColor[
              0.2167644246749318, 0.34516353236463915`, 0.9356557853597838], 
             UndirectedEdge[380, 478] -> 
             RGBColor[
              0.26944650218814237`, 0.40053573606766074`, 0.9386559517380118],
              UndirectedEdge[247, 370] -> 
             RGBColor[
              0.5432273595581627, 0.6400554684598069, 0.9571839941332545], 
             UndirectedEdge[251, 429] -> 
             RGBColor[
              0.2760715850682322, 0.4074991182291509, 0.9390332404071009], 
             UndirectedEdge[286, 407] -> 
             RGBColor[
              0.21872930348009942`, 0.347228744569382, 0.9357676823009604], 
             UndirectedEdge[206, 410] -> 
             RGBColor[
              0.35319958507105037`, 0.4803454610863929, 0.9437265431319655], 
             UndirectedEdge[86, 500] -> 
             RGBColor[
              0.8673428769617186, 0.42615530998421236`, 0.20846003809980468`],
              UndirectedEdge[78, 407] -> 
             RGBColor[
              0.21689372054729342`, 0.34529943052432305`, 0.9356631485684387],
              UndirectedEdge[363, 370] -> 
             RGBColor[
              0.4981273475389003, 0.6021241779008506, 0.9539974660883765], 
             UndirectedEdge[447, 453] -> 
             RGBColor[
              0.26540338983624123`, 0.39628616863768357`, 0.9384257024708196],
              UndirectedEdge[256, 492] -> 
             RGBColor[
              0.28300272562501616`, 0.4147841864140242, 0.9394279586081062], 
             UndirectedEdge[114, 349] -> 
             RGBColor[
              0.45713997699902986`, 0.5690874562014547, 0.9507048443075143], 
             UndirectedEdge[22, 160] -> 
             RGBColor[
              0.4369491379476227, 0.5528851144131592, 0.949062990584439], 
             UndirectedEdge[149, 324] -> 
             RGBColor[
              0.361776111320833, 0.4877740170552114, 0.9442730318006773], 
             UndirectedEdge[94, 315] -> 
             RGBColor[
              0.5704593476328262, 0.6392872195268108, 0.9471116754258844], 
             UndirectedEdge[246, 492] -> 
             RGBColor[
              0.2854203608730804, 0.4173252743466679, 0.9395656393589127], 
             UndirectedEdge[193, 202] -> 
             RGBColor[
              0.2634343891958272, 0.39421662412275726`, 0.9383135707972234], 
             UndirectedEdge[321, 335] -> 
             RGBColor[
              0.3049738126003747, 0.4356185220197354, 0.94076188047572], 
             UndirectedEdge[321, 496] -> 
             RGBColor[
              0.3050324981109774, 0.4356802042122551, 0.9407652225287313], 
             UndirectedEdge[18, 474] -> 
             RGBColor[
              0.9387405372806834, 0.7796548598202627, 0.49465049788910304`], 
             UndirectedEdge[184, 192] -> 
             RGBColor[
              0.25582325613433854`, 0.3862168407014245, 0.9378801280290341], 
             UndirectedEdge[170, 171] -> 
             RGBColor[
              0.2792113970027737, 0.4107992596479288, 0.9392120480518376], 
             UndirectedEdge[80, 156] -> 
             RGBColor[
              0.6284260394446897, 0.7069689251123001, 0.9654326763878454], 
             UndirectedEdge[353, 418] -> 
             RGBColor[
              0.809068015481273, 0.8509060188194038, 0.9430493347226458], 
             UndirectedEdge[201, 312] -> 
             RGBColor[
              0.30443515610797417`, 0.4373110297461917, 0.9406485038176712], 
             UndirectedEdge[152, 212] -> 
             RGBColor[
              0.21125959360220817`, 0.3393776058807578, 0.93534229337386], 
             UndirectedEdge[192, 260] -> 
             RGBColor[
              0.27009553441077905`, 0.4012179100846716, 0.9386929131629338], 
             UndirectedEdge[90, 357] -> 
             RGBColor[
              0.8859560304571115, 0.5741950476247133, 0.2265078159100875], 
             UndirectedEdge[57, 369] -> 
             RGBColor[
              0.5105952058083258, 0.6126571266031253, 0.9548654266501568], 
             UndirectedEdge[83, 448] -> 
             RGBColor[
              0.7443425082604527, 0.7998796964136958, 0.9757160754212024], 
             UndirectedEdge[67, 180] -> 
             RGBColor[
              0.26337700695553745`, 0.3941563117499686, 0.9383103029635284], 
             UndirectedEdge[373, 472] -> 
             RGBColor[
              0.31103110428016545`, 0.44242232361832246`, 0.9410908260962028],
              UndirectedEdge[353, 432] -> 
             RGBColor[
              0.7691435045990516, 0.820174333900838, 0.9774842614710615], 
             UndirectedEdge[1, 433] -> 
             RGBColor[
              0.2958358704615542, 0.4267230355457211, 0.940215525659722], 
             UndirectedEdge[300, 301] -> 
             RGBColor[
              0.2173551636481656, 0.3457844364805221, 0.9356894270703895], 
             UndirectedEdge[212, 389] -> 
             RGBColor[
              0.21850801717300872`, 0.34699615863026745`, 0.9357550803731354],
              UndirectedEdge[97, 174] -> 
             RGBColor[
              0.24919580773922206`, 0.37925097223365895`, 0.9375027046473634],
              UndirectedEdge[200, 471] -> 
             RGBColor[
              0.8788202951923778, 0.5401284768128874, 0.22049894846562806`], 
             UndirectedEdge[155, 387] -> 
             RGBColor[
              0.6705014636086952, 0.7413486854414358, 0.9685938847155504], 
             UndirectedEdge[156, 354] -> 
             RGBColor[
              0.4145365045344412, 0.533092524898237, 0.9477398429544205], 
             UndirectedEdge[314, 472] -> 
             RGBColor[
              0.3292610947634469, 0.4596111439654538, 0.9422012036975409], 
             UndirectedEdge[117, 269] -> 
             RGBColor[
              0.41500730712434825`, 0.5338802033825223, 0.947664876526779], 
             UndirectedEdge[336, 409] -> 
             RGBColor[
              0.23189710424361965`, 0.36106893805863094`, 0.9365175690744273],
              UndirectedEdge[63, 252] -> 
             RGBColor[
              0.5775658026497799, 0.6655789256820774, 0.9611207995905398], 
             UndirectedEdge[201, 444] -> 
             RGBColor[
              0.2878759109078417, 0.4199062131240665, 0.9397054793007316], 
             UndirectedEdge[201, 442] -> 
             RGBColor[
              0.2942020501296223, 0.426555386546551, 0.9400657435707277], 
             UndirectedEdge[25, 333] -> 
             RGBColor[
              0.34601220845973285`, 0.4741201167137219, 0.94326856984984], 
             UndirectedEdge[203, 397] -> 
             RGBColor[
              0.44655734447149653`, 0.5590011690338403, 0.950284766509865], 
             UndirectedEdge[7, 436] -> 
             RGBColor[
              0.6558009604167452, 0.7285914992480711, 0.9680622843636464], 
             UndirectedEdge[15, 112] -> 
             RGBColor[
              0.24125115959042637`, 0.3709006433094886, 0.9370502686883432], 
             UndirectedEdge[274, 369] -> 
             RGBColor[
              0.4413408424038283, 0.5564333145178368, 0.9494134694758627], 
             UndirectedEdge[38, 364] -> 
             RGBColor[
              0.2592676752099878, 0.3898371435387148, 0.9380762825998308], 
             UndirectedEdge[215, 356] -> 
             RGBColor[
              0.2767305167100354, 0.40819169716336523`, 0.9390707655892996], 
             UndirectedEdge[16, 283] -> 
             RGBColor[
              0.29254812031783006`, 0.4160210207001029, 0.9402936186581154], 
             UndirectedEdge[236, 276] -> 
             RGBColor[
              0.45343165662521556`, 0.5606674341824253, 0.9514328089086481], 
             UndirectedEdge[39, 454] -> 
             RGBColor[
              0.761772006870989, 0.6718134516549312, 0.6008439261608904], 
             UndirectedEdge[179, 315] -> 
             RGBColor[
              0.18221437666537932`, 0.3088492413070327, 0.9336882112378554], 
             UndirectedEdge[149, 182] -> 
             RGBColor[
              0.36623071660169665`, 0.4916323722545241, 0.9445568753101211], 
             UndirectedEdge[97, 407] -> 
             RGBColor[
              0.2230464248259349, 0.3517663128251578, 0.936013535974997], 
             UndirectedEdge[274, 379] -> 
             RGBColor[
              0.386016730119334, 0.5085143491277428, 0.9458882659622865], 
             UndirectedEdge[39, 325] -> 
             RGBColor[
              0.40133925395865816`, 0.5054220551360133, 0.9485110960164554], 
             UndirectedEdge[127, 347] -> 
             RGBColor[
              0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993],
              UndirectedEdge[327, 483] -> 
             RGBColor[
              0.27685916583525294`, 0.4083269155507945, 0.9390780919666615], 
             UndirectedEdge[269, 360] -> 
             RGBColor[
              0.5141528316673345, 0.616332566062272, 0.9549279906939228], 
             UndirectedEdge[54, 147] -> 
             RGBColor[
              0.2401069833110282, 0.36969804149487495`, 0.9369851095418886], 
             UndirectedEdge[276, 422] -> 
             RGBColor[
              0.4267760803352025, 0.5326507334404715, 0.9499148132723232], 
             UndirectedEdge[181, 424] -> 
             RGBColor[
              0.3706458143967508, 0.4954565080553325, 0.9448382014375043], 
             UndirectedEdge[336, 456] -> 
             RGBColor[
              0.22294853768143919`, 0.3516634272298894, 0.936007961446929], 
             UndirectedEdge[46, 298] -> 
             RGBColor[
              0.9096473304128414, 0.8178215341712867, 0.6215408826637097], 
             UndirectedEdge[107, 132] -> 
             RGBColor[
              0.5874023021726906, 0.6508098778838103, 0.8735074338464627], 
             UndirectedEdge[78, 95] -> 
             RGBColor[
              0.22325600943798377`, 0.3519865995408531, 0.9360254715086005], 
             UndirectedEdge[296, 332] -> 
             RGBColor[
              0.3578059368755654, 0.48433525149749035`, 0.9440200557957121], 
             UndirectedEdge[397, 472] -> 
             RGBColor[
              0.3434973849835166, 0.4719419030173265, 0.9431083275217065], 
             UndirectedEdge[19, 269] -> 
             RGBColor[
              0.5043319337096805, 0.6083595186738375, 0.9541548536315616], 
             UndirectedEdge[185, 335] -> 
             RGBColor[
              0.28035846079175497`, 0.4120048964181928, 0.9392773716376912], 
             UndirectedEdge[112, 351] -> 
             RGBColor[
              0.26915448795361524`, 0.4002288105924009, 0.9386393219593516], 
             UndirectedEdge[163, 189] -> 
             RGBColor[
              0.2633838374698597, 0.39416349105360093`, 0.9383106919512142], 
             UndirectedEdge[251, 305] -> 
             RGBColor[
              0.25482853774731307`, 0.38517132860787223`, 0.9378234802884469],
              UndirectedEdge[131, 170] -> 
             RGBColor[
              0.28014480934839103`, 0.4117803352049335, 0.9392652045040607], 
             UndirectedEdge[76, 333] -> 
             RGBColor[
              0.3949872182942583, 0.5165398086768207, 0.9463892141695951], 
             UndirectedEdge[114, 115] -> 
             RGBColor[
              0.7109234320173796, 0.7727455262693818, 0.9730887236423327], 
             UndirectedEdge[87, 421] -> 
             RGBColor[
              0.17915493384170816`, 0.30563357291947557`, 0.9335139804950874],
              UndirectedEdge[60, 192] -> 
             RGBColor[
              0.2736621188386635, 0.4049666164528918, 0.9388960248698129], 
             UndirectedEdge[84, 147] -> 
             RGBColor[
              0.24240373141068797`, 0.37211206936985763`, 0.93711590594843], 
             UndirectedEdge[431, 433] -> 
             RGBColor[
              0.3870230907643596, 0.509641681699111, 0.9458817470057914], 
             UndirectedEdge[201, 492] -> 
             RGBColor[
              0.29053904388296076`, 0.4227053347332997, 0.9398571407839125], 
             UndirectedEdge[86, 124] -> 
             RGBColor[
              0.9389228207101663, 0.7935781606519255, 0.2800166062249653], 
             UndirectedEdge[234, 239] -> 
             RGBColor[
              0.36975457999068184`, 0.4946845656075394, 0.9447814127692372], 
             UndirectedEdge[100, 450] -> 
             RGBColor[
              0.8744616680202064, 0.45105879141128646`, 0.21405151473609035`],
              UndirectedEdge[22, 275] -> 
             RGBColor[
              0.43256024452096153`, 0.549083675519183, 0.9487833341762382], 
             UndirectedEdge[160, 324] -> 
             RGBColor[
              0.3960795993510239, 0.5174859742435227, 0.9464588197245776], 
             UndirectedEdge[191, 218] -> 
             RGBColor[
              0.2251871593264507, 0.3540163605156067, 0.9361354476378685], 
             UndirectedEdge[349, 397] -> 
             RGBColor[
              0.38607476166702576`, 0.5088202866994067, 0.9458213203142838], 
             UndirectedEdge[401, 454] -> 
             RGBColor[
              0.8366674019364873, 0.7306087240183134, 0.6081129719353302], 
             UndirectedEdge[311, 349] -> 
             RGBColor[
              0.5802291691633081, 0.667416033439714, 0.9614893343765445], 
             UndirectedEdge[63, 324] -> 
             RGBColor[
              0.3945065223315428, 0.5161234539943981, 0.9463585846479137], 
             UndirectedEdge[22, 353] -> 
             RGBColor[
              0.5455395337034719, 0.641880966146923, 0.9573802823215901], 
             UndirectedEdge[93, 437] -> 
             RGBColor[
              0.26255787085876586`, 0.3932953477760335, 0.9382636543746206], 
             UndirectedEdge[417, 461] -> 
             RGBColor[
              0.8227440842305245, 0.8622334494485463, 0.9748712810946092], 
             UndirectedEdge[151, 249] -> 
             RGBColor[
              0.29817109629594896`, 0.43072710571942197`, 0.9402917748782225],
              UndirectedEdge[148, 452] -> 
             RGBColor[
              0.23180463347080354`, 0.3609717454134156, 0.9365123030007138], 
             UndirectedEdge[262, 424] -> 
             RGBColor[
              0.39834012297090404`, 0.5188257266580119, 0.9467736686621999], 
             UndirectedEdge[50, 139] -> 
             RGBColor[
              0.50248660335272, 0.6066441419253559, 0.9540696105134843], 
             UndirectedEdge[237, 267] -> 
             RGBColor[
              0.9475774996267206, 0.9513626199375382, 0.7014579081154306], 
             UndirectedEdge[256, 442] -> 
             RGBColor[
              0.28666573187167776`, 0.4186342382272755, 0.9396365613949216], 
             UndirectedEdge[60, 133] -> 
             RGBColor[
              0.31894163191943015`, 0.44919026900604586`, 0.9415979446419711],
              UndirectedEdge[77, 156] -> 
             RGBColor[
              0.5370635204917655, 0.6350513862279201, 0.9566987541430614], 
             UndirectedEdge[219, 498] -> 
             RGBColor[
              0.49407920545967077`, 0.6001547828635406, 0.9533148714070008], 
             UndirectedEdge[102, 185] -> 
             RGBColor[
              0.28024115314486164`, 0.4118815986435736, 0.9392706911407418], 
             UndirectedEdge[92, 169] -> 
             RGBColor[
              0.5509398864490034, 0.6463168452351683, 0.9577911525020184], 
             UndirectedEdge[53, 357] -> 
             RGBColor[
              0.9418272950686917, 0.8009948820936315, 0.3036989405074137], 
             UndirectedEdge[162, 289] -> 
             RGBColor[
              0.45070123455015054`, 0.5645598995943251, 0.9500046324572284], 
             UndirectedEdge[169, 204] -> 
             RGBColor[
              0.4973176178268257, 0.6027838719120118, 0.9535698110912385], 
             UndirectedEdge[176, 448] -> 
             RGBColor[
              0.587441960125221, 0.6759508730452015, 0.9606647294533119], 
             UndirectedEdge[377, 403] -> 
             RGBColor[
              0.9550085431684978, 0.9657910070072111, 0.9549749729457403], 
             UndirectedEdge[86, 357] -> 
             RGBColor[
              0.911167687629582, 0.6855165136042474, 0.2473816401856394], 
             UndirectedEdge[12, 373] -> 
             RGBColor[
              0.28300945147034123`, 0.414791255703904, 0.9394283416350475], 
             UndirectedEdge[200, 469] -> 
             RGBColor[
              0.8806293426662699, 0.5508475494204266, 0.22210653628922422`], 
             UndirectedEdge[112, 153] -> 
             RGBColor[
              0.24659824483285725`, 0.37652076892406894`, 0.9373547772825959],
              UndirectedEdge[166, 243] -> 
             RGBColor[
              0.838713260625803, 0.29857266219470613`, 0.18470516813663024`], 
             UndirectedEdge[394, 460] -> 
             RGBColor[
              0.23849436642390026`, 0.3680030789006874, 0.9368932733958195], 
             UndirectedEdge[18, 348] -> 
             RGBColor[
              0.9221477650002106, 0.7221653986171828, 0.2620020254952798], 
             UndirectedEdge[315, 325] -> 
             RGBColor[
              0.1822582683189515, 0.30889537421782864`, 0.9336907108025945], 
             UndirectedEdge[195, 447] -> 
             RGBColor[
              0.25832593618087096`, 0.38884731610940987`, 0.9380226519553008],
              UndirectedEdge[128, 204] -> 
             RGBColor[
              0.4983181319181479, 0.6035961343239933, 0.9536485752255113], 
             UndirectedEdge[91, 435] -> 
             RGBColor[
              0.29287326479962417`, 0.4234129007814571, 0.9400539952643586], 
             UndirectedEdge[158, 206] -> 
             RGBColor[
              0.3501277440364893, 0.4776847867774757, 0.9435308081375656], 
             UndirectedEdge[30, 290] -> 
             RGBColor[
              0.2772082322816696, 0.40869380651806936`, 0.9390979707843874], 
             UndirectedEdge[2, 250] -> 
             RGBColor[
              0.20844651025640323`, 0.33642087692453115`, 0.9351820924389003],
              UndirectedEdge[148, 195] -> 
             RGBColor[
              0.2549038837878154, 0.3852505220736551, 0.9378277711339891], 
             UndirectedEdge[5, 202] -> 
             RGBColor[
              0.23883220085490312`, 0.3683581643076115, 0.9369125125668838], 
             UndirectedEdge[220, 359] -> 
             RGBColor[
              0.3621822341604067, 0.48812578024652276`, 0.9442989095888945], 
             UndirectedEdge[175, 337] -> 
             RGBColor[
              0.9079704822927377, 0.9289384814961321, 0.9731750764283525], 
             UndirectedEdge[263, 447] -> 
             RGBColor[
              0.2599502995006695, 0.3905546249491011, 0.938115157043333], 
             UndirectedEdge[344, 387] -> 
             RGBColor[
              0.6194283934274943, 0.6998852662527452, 0.9645732255440658], 
             UndirectedEdge[82, 470] -> 
             RGBColor[
              0.25688036525862096`, 0.38732792941563493`, 0.937940328829809], 
             UndirectedEdge[273, 446] -> 
             RGBColor[
              0.26084634450324296`, 0.39149642505934035`, 0.9381661854806498],
              UndirectedEdge[68, 306] -> 
             RGBColor[
              0.8387829864974263, 0.2991086057980758, 0.18477193771004097`], 
             UndirectedEdge[21, 33] -> 
             RGBColor[
              0.9296510090196749, 0.7439907144053559, 0.3002556094938443], 
             UndirectedEdge[77, 479] -> 
             RGBColor[
              0.5091542746403608, 0.6112576931750507, 0.9548154361242309], 
             UndirectedEdge[253, 311] -> 
             RGBColor[
              0.8659443575362178, 0.8951239135712197, 0.9365639679939195], 
             UndirectedEdge[308, 386] -> 
             RGBColor[
              0.17893664238380538`, 0.3054041347567419, 0.9335015491194931], 
             UndirectedEdge[151, 280] -> 
             RGBColor[
              0.2818433506476452, 0.4135656098041881, 0.9393619339182866], 
             UndirectedEdge[305, 416] -> 
             RGBColor[
              0.2563227786802443, 0.3867418705687301, 0.9379085750990459], 
             UndirectedEdge[38, 189] -> 
             RGBColor[
              0.2598720197723208, 0.3904723479913851, 0.9381106991286081], 
             UndirectedEdge[277, 291] -> 
             RGBColor[
              0.7131143362098424, 0.7758096064076011, 0.9720402306671867], 
             UndirectedEdge[27, 40] -> 
             RGBColor[
              0.44915953688308596`, 0.5618645655130168, 0.9502821669769903], 
             UndirectedEdge[88, 167] -> 
             RGBColor[
              0.9266401906833595, 0.7379726928092079, 0.5404902319838795], 
             UndirectedEdge[89, 296] -> 
             RGBColor[
              0.2994607686458766, 0.4316505064958615, 0.9403810420835206], 
             UndirectedEdge[169, 340] -> 
             RGBColor[
              0.41508837309382146`, 0.5328799596159772, 0.9479658129994224], 
             UndirectedEdge[169, 363] -> 
             RGBColor[
              0.44877677089386697`, 0.5620591565622703, 0.9501124079177607], 
             UndirectedEdge[43, 378] -> 
             RGBColor[
              0.2881161193118442, 0.42015868738676554`, 0.939719158813983], 
             UndirectedEdge[350, 482] -> 
             RGBColor[
              0.36032571563534044`, 0.4865177572114446, 0.9441806138701323], 
             UndirectedEdge[199, 429] -> 
             RGBColor[
              0.318220922727511, 0.44864816272084596`, 0.9415490142958283], 
             UndirectedEdge[135, 216] -> 
             RGBColor[
              0.25825637493020664`, 0.38877420282452363`, 0.938018690544982], 
             UndirectedEdge[153, 351] -> 
             RGBColor[
              0.267489207183899, 0.39847849491853005`, 0.9385444866830785], 
             UndirectedEdge[207, 218] -> 
             RGBColor[
              0.22451796602725682`, 0.35331299592884813`, 0.9360973380694622],
              UndirectedEdge[218, 389] -> 
             RGBColor[
              0.22523636007401557`, 0.35406807362080495`, 0.9361382495476563],
              UndirectedEdge[421, 477] -> 
             RGBColor[
              0.21186411660990806`, 0.34001299789082284`, 0.9353767200648369],
              UndirectedEdge[171, 391] -> 
             RGBColor[
              0.25143472628896596`, 0.3816042175850748, 0.9376302077465881], 
             UndirectedEdge[25, 246] -> 
             RGBColor[
              0.3037983452782409, 0.43621369244109887`, 0.940627909879872], 
             UndirectedEdge[130, 254] -> 
             RGBColor[
              0.20771262472504887`, 0.3356495167000475, 0.935140298743576], 
             UndirectedEdge[65, 434] -> 
             RGBColor[
              0.9883337030612244, 0.9766308233101144, 0.5967468015081936], 
             UndirectedEdge[174, 430] -> 
             RGBColor[
              0.2531980668507343, 0.38345760031774234`, 0.9377306273829522], 
             UndirectedEdge[213, 454] -> 
             RGBColor[
              0.902044161930851, 0.6480872421427781, 0.23997558640884487`], 
             UndirectedEdge[52, 495] -> 
             RGBColor[
              0.8389987580384334, 0.3007671204139477, 0.18497856078138836`], 
             UndirectedEdge[26, 224] -> 
             RGBColor[
              0.34279791451999597`, 0.4704318560417961, 0.9430968651035153], 
             UndirectedEdge[8, 31] -> 
             RGBColor[
              0.5366659458722182, 0.6347210217205881, 0.9566695542776334], 
             UndirectedEdge[29, 321] -> 
             RGBColor[
              0.3713978817482214, 0.49610791099517215`, 0.944886122504113], 
             UndirectedEdge[319, 377] -> 
             RGBColor[
              0.8479973976544979, 0.8813126625416667, 0.9445427395689829], 
             UndirectedEdge[323, 447] -> 
             RGBColor[
              0.24292230663621342`, 0.3726571248114532, 0.9371454380403603], 
             UndirectedEdge[13, 340] -> 
             RGBColor[
              0.3170254114231826, 0.44789173278801986`, 0.9414626195505558], 
             UndirectedEdge[176, 237] -> 
             RGBColor[
              0.7565184993634433, 0.8098707472801487, 0.9765525722729846], 
             UndirectedEdge[22, 268] -> 
             RGBColor[
              0.4305356531895016, 0.5473300762667914, 0.9486543290068734], 
             UndirectedEdge[461, 493] -> 
             RGBColor[
              0.9690163833229786, 0.9733831615410689, 0.7606045943611018], 
             UndirectedEdge[401, 450] -> 
             RGBColor[
              0.7955804305647025, 0.4800334417304184, 0.5713225662708019], 
             UndirectedEdge[100, 200] -> 
             RGBColor[
              0.9160214299715226, 0.703780905297789, 0.25123642844933736`], 
             UndirectedEdge[197, 375] -> 
             RGBColor[
              0.8279135305907634, 0.8660284937370616, 0.9630673509377192], 
             UndirectedEdge[94, 401] -> 
             RGBColor[
              0.8644357283380311, 0.8946091728083778, 0.9692011064141851], 
             UndirectedEdge[118, 327] -> 
             RGBColor[
              0.2910886324434072, 0.42177019876942656`, 0.9399438296328053], 
             UndirectedEdge[44, 255] -> 
             RGBColor[
              0.44713138767076954`, 0.5605271620680575, 0.9500370874897843], 
             UndirectedEdge[148, 356] -> 
             RGBColor[
              0.2544968866209464, 0.384822742246165, 0.9378045932474341], 
             UndirectedEdge[26, 34] -> 
             RGBColor[
              0.46519130263863967`, 0.5748915338435057, 0.9515410249790447], 
             UndirectedEdge[244, 313] -> 
             RGBColor[
              0.3046994618698019, 0.43447349621750786`, 0.9407776233385161], 
             UndirectedEdge[331, 488] -> 
             RGBColor[
              0.8030279977952235, 0.8461858842867422, 0.9809661481473407], 
             UndirectedEdge[382, 429] -> 
             RGBColor[
              0.2879113316712099, 0.41994344259217253`, 0.9397074964608051], 
             UndirectedEdge[409, 496] -> 
             RGBColor[
              0.25922260246551676`, 0.38978976922649866`, 0.9380737157737123],
              UndirectedEdge[14, 324] -> 
             RGBColor[
              0.33821006500838097`, 0.4671770715883025, 0.9427782060023248], 
             UndirectedEdge[259, 471] -> 
             RGBColor[
              0.8593266411159032, 0.451612346510198, 0.20423296567103144`], 
             UndirectedEdge[178, 439] -> 
             RGBColor[
              0.9262985601874452, 0.9413808299607197, 0.8870332114673454], 
             UndirectedEdge[127, 454] -> 
             RGBColor[
              0.562931118749189, 0.49656039652436856`, 0.5871761845581333], 
             UndirectedEdge[190, 452] -> 
             RGBColor[
              0.2360315215156537, 0.3654144727487341, 0.9367530180217474], 
             UndirectedEdge[218, 295] -> 
             RGBColor[
              0.2307804101674582, 0.3598952217820915, 0.9364539749987908], 
             UndirectedEdge[35, 67] -> 
             RGBColor[
              0.24749774961125026`, 0.377466205478057, 0.9374060027490273], 
             UndirectedEdge[192, 249] -> 
             RGBColor[
              0.27208125411189216`, 0.40330502739244223`, 0.938805996962303], 
             UndirectedEdge[186, 202] -> 
             RGBColor[
              0.2373837352876954, 0.3668357351584549, 0.9368300245956442], 
             UndirectedEdge[243, 469] -> 
             RGBColor[
              0.8498683936659192, 0.3811298439450528, 0.19526257805333647`], 
             UndirectedEdge[48, 183] -> 
             RGBColor[
              0.20623910902756293`, 0.3341007582756985, 0.9350563842044752], 
             UndirectedEdge[255, 390] -> 
             RGBColor[
              0.3491694965791283, 0.4761158367358585, 0.9434968065582812], 
             UndirectedEdge[202, 497] -> 
             RGBColor[
              0.23752535161991525`, 0.36698458290261204`, 0.9368380894362616],
              UndirectedEdge[84, 365] -> 
             RGBColor[
              0.22514447908377305`, 0.3539715008744688, 0.9361330170611878], 
             UndirectedEdge[239, 262] -> 
             RGBColor[
              0.41350816527111056`, 0.531963522530478, 0.947740162904996], 
             UndirectedEdge[299, 456] -> 
             RGBColor[
              0.21641245264037934`, 0.34479358744000865`, 0.935635741073112], 
             UndirectedEdge[136, 253] -> 
             RGBColor[
              0.9769962544035893, 0.9822248956493935, 0.9175751236598007], 
             UndirectedEdge[338, 478] -> 
             RGBColor[
              0.29307363534810826`, 0.42431910359583813`, 0.9400399367228911],
              UndirectedEdge[284, 444] -> 
             RGBColor[
              0.25819284063858217`, 0.3887074242557196, 0.9380150723610645], 
             UndirectedEdge[135, 147] -> 
             RGBColor[
              0.2510599689447852, 0.3812103238553528, 0.9376088658702408], 
             UndirectedEdge[72, 73] -> 
             RGBColor[
              0.2509474629421924, 0.38109207291333524`, 0.9376024588198308], 
             UndirectedEdge[8, 291] -> 
             RGBColor[
              0.637610384777719, 0.7164873323549865, 0.9647458039813404], 
             UndirectedEdge[141, 240] -> 
             RGBColor[
              0.2831042170303842, 0.4148134850118461, 0.939436571482416], 
             UndirectedEdge[9, 466] -> 
             RGBColor[
              0.5393259259475076, 0.6368881088970959, 0.9568768589880016], 
             UndirectedEdge[78, 346] -> 
             RGBColor[
              0.21865587786091514`, 0.34715156958816623`, 0.9357635008205714],
              UndirectedEdge[255, 425] -> 
             RGBColor[
              0.38646418769848023`, 0.5091575879547311, 0.9458461341966522], 
             UndirectedEdge[297, 349] -> 
             RGBColor[
              0.4664828396818328, 0.5766724130185215, 0.9514403486819383], 
             UndirectedEdge[248, 478] -> 
             RGBColor[
              0.25429079969208646`, 0.3846061318172672, 0.9377928569017139], 
             UndirectedEdge[113, 130] -> 
             RGBColor[
              0.17905963034776856`, 0.3055334029047545, 0.9335085531020964], 
             UndirectedEdge[51, 179] -> 
             RGBColor[
              0.1789280689363169, 0.30539512351984355`, 0.9335010608743419], 
             UndirectedEdge[440, 470] -> 
             RGBColor[
              0.2685779731534025, 0.3996228569842277, 0.9386064902943567], 
             UndirectedEdge[5, 414] -> 
             RGBColor[
              0.2566326545868817, 0.38706756979387325`, 0.9379262220735086], 
             UndirectedEdge[148, 463] -> 
             RGBColor[
              0.25337660171868737`, 0.3836452517837254, 0.9377407946795635], 
             UndirectedEdge[63, 441] -> 
             RGBColor[
              0.4347339982883702, 0.5509664717764713, 0.9489218438441225], 
             UndirectedEdge[163, 187] -> 
             RGBColor[
              0.2658102034815037, 0.3967137555723293, 0.9384488699060904], 
             UndirectedEdge[120, 177] -> 
             RGBColor[
              0.20805903153131503`, 0.3360136122168933, 0.9351600260987298], 
             UndirectedEdge[450, 454] -> 
             RGBColor[
              0.8587954548220276, 0.3876960227591984, 0.20138137545633958`], 
             UndirectedEdge[15, 190] -> 
             RGBColor[
              0.24117420601353035`, 0.37081976022103225`, 0.9370458862959816],
              UndirectedEdge[191, 287] -> 
             RGBColor[
              0.21410654860741013`, 0.342369936098598, 0.9355044232497137], 
             UndirectedEdge[179, 292] -> 
             RGBColor[
              0.17894988462017136`, 0.30541805318676885`, 0.9335023032452641],
              UndirectedEdge[291, 297] -> 
             RGBColor[
              0.5871456749634538, 0.6755178075184964, 0.9607730371664382], 
             UndirectedEdge[289, 397] -> 
             RGBColor[
              0.39895955278042317`, 0.5199804451534001, 0.9466423278104561], 
             UndirectedEdge[175, 370] -> 
             RGBColor[
              0.7735868010178651, 0.822851827878325, 0.9604005134157099], 
             UndirectedEdge[23, 186] -> 
             RGBColor[
              0.22910595895914918`, 0.35813526739582024`, 0.9363586174796061],
              UndirectedEdge[241, 461] -> 
             RGBColor[
              0.8249688230204753, 0.8639714322998968, 0.9750930222658254], 
             UndirectedEdge[157, 216] -> 
             RGBColor[
              0.28421479544229167`, 0.41605814864164575`, 0.9394969841911034],
              UndirectedEdge[51, 302] -> 
             RGBColor[
              0.18453817957609825`, 0.31129170550381263`, 0.9338205483758626],
              UndirectedEdge[174, 390] -> 
             RGBColor[
              0.28370528761633407`, 0.41552262361190234`, 0.9394679684741645],
              UndirectedEdge[79, 406] -> 
             RGBColor[
              0.9922235479450122, 0.984612153776488, 0.4938632532617516], 
             UndirectedEdge[181, 235] -> 
             RGBColor[
              0.38886946031407776`, 0.511240914201845, 0.9459993960408191], 
             UndirectedEdge[78, 404] -> 
             RGBColor[
              0.2164387033219317, 0.3448211785707095, 0.935637236010592], 
             UndirectedEdge[89, 280] -> 
             RGBColor[
              0.2711970471587578, 0.4023756698227392, 0.938755642684389], 
             UndirectedEdge[43, 384] -> 
             RGBColor[
              0.28848430619933074`, 0.4205456751499109, 0.9397401265125418], 
             UndirectedEdge[101, 363] -> 
             RGBColor[
              0.4628220425559936, 0.5734617408298626, 0.9512181031525286], 
             UndirectedEdge[120, 455] -> 
             RGBColor[
              0.2056810719300792, 0.33351422590464763`, 0.9350246048173154], 
             UndirectedEdge[295, 456] -> 
             RGBColor[
              0.22662320577002346`, 0.355525736378405, 0.9362172283583896], 
             UndirectedEdge[58, 240] -> 
             RGBColor[
              0.2858686487739417, 0.41720789684373627`, 0.9396127186286245], 
             UndirectedEdge[39, 471] -> 
             RGBColor[
              0.7402370852900231, 0.5715237918221177, 0.5827765854569318], 
             UndirectedEdge[54, 365] -> 
             RGBColor[
              0.22284773098411328`, 0.35155747299948614`, 0.9360022206546466],
              UndirectedEdge[169, 334] -> 
             RGBColor[
              0.44777313143376407`, 0.5611898545063152, 0.9500484568988465], 
             UndirectedEdge[18, 65] -> 
             RGBColor[
              0.9349243740088637, 0.7652639008938271, 0.3116367388337401], 
             UndirectedEdge[384, 435] -> 
             RGBColor[
              0.2709692417504848, 0.4021362318949472, 0.9387426695033958], 
             UndirectedEdge[9, 360] -> 
             RGBColor[
              0.5772550006439877, 0.6676806404210414, 0.9598627746868871], 
             UndirectedEdge[135, 171] -> 
             RGBColor[
              0.25618449679905386`, 0.3865965275440213, 0.9379007001504819], 
             UndirectedEdge[149, 187] -> 
             RGBColor[
              0.30925143443909986`, 0.4382007802607746, 0.9410755580672832], 
             UndirectedEdge[271, 464] -> 
             RGBColor[
              0.24983604138275278`, 0.37992389838616725`, 0.9375391650062217],
              UndirectedEdge[21, 348] -> 
             RGBColor[
              0.9703996877499586, 0.911813337676092, 0.3395088057688662], 
             UndirectedEdge[1, 70] -> 
             RGBColor[
              0.26220782647507634`, 0.3929274289346799, 0.9382437198648137], 
             UndirectedEdge[52, 276] -> 
             RGBColor[
              0.7276676005214341, 0.4890758052767825, 0.5725511491543327], 
             UndirectedEdge[58, 429] -> 
             RGBColor[
              0.3043548555603097, 0.4366380722694161, 0.9406654807572159], 
             UndirectedEdge[243, 495] -> 
             RGBColor[
              0.8407542903650291, 0.31426091115533294`, 0.1866596605199266], 
             UndirectedEdge[131, 135] -> 
             RGBColor[
              0.25711790914467114`, 0.38757760310102596`, 0.937953856602705], 
             UndirectedEdge[145, 430] -> 
             RGBColor[
              0.23019859628253192`, 0.35928369849990305`, 0.9364208415587607],
              UndirectedEdge[291, 419] -> 
             RGBColor[
              0.583808838050422, 0.6728088129897074, 0.960510349141408], 
             UndirectedEdge[151, 260] -> 
             RGBColor[
              0.2961853765948359, 0.4286399884116514, 0.940178691078853], 
             UndirectedEdge[189, 437] -> 
             RGBColor[
              0.25780291323833093`, 0.38829758583523044`, 0.9379928665724662],
              UndirectedEdge[196, 354] -> 
             RGBColor[
              0.32873158920795986`, 0.45794625952520507`, 0.9422116309155903],
              UndirectedEdge[340, 355] -> 
             RGBColor[
              0.3330706823231735, 0.4629108172342508, 0.9424439472481606], 
             UndirectedEdge[58, 310] -> 
             RGBColor[
              0.3059344073310527, 0.43829828132983367`, 0.9407554338938223], 
             UndirectedEdge[261, 500] -> 
             RGBColor[
              0.8497397394109806, 0.34938235459205963`, 0.19393494909850834`],
              UndirectedEdge[237, 270] -> 
             RGBColor[
              0.9480577404464491, 0.9590498999175098, 0.9029559373872008], 
             UndirectedEdge[23, 497] -> 
             RGBColor[
              0.22924757529136902`, 0.3582841151399774, 0.9363666823202235], 
             UndirectedEdge[431, 462] -> 
             RGBColor[
              0.4562091477173884, 0.5692804281616477, 0.9503694481270373], 
             UndirectedEdge[108, 129] -> 
             RGBColor[
              0.3203552344901264, 0.4497120899906687, 0.9417137426958612], 
             UndirectedEdge[376, 485] -> 
             RGBColor[
              0.26372814560153673`, 0.3945253807303899, 0.938330299789955], 
             UndirectedEdge[124, 261] -> 
             RGBColor[
              0.9213196831594281, 0.7168052052597729, 0.265491517223669], 
             UndirectedEdge[63, 158] -> 
             RGBColor[
              0.38842846253649266`, 0.5108589440920934, 0.9459712960523903], 
             UndirectedEdge[66, 427] -> 
             RGBColor[
              0.271390600085227, 0.40257910622042264`, 0.9387666652372155], 
             UndirectedEdge[66, 208] -> 
             RGBColor[
              0.2926997987840062, 0.4237400438284219, 0.9400254625551399], 
             UndirectedEdge[54, 230] -> 
             RGBColor[
              0.22629940994459397`, 0.3551854064360376, 0.9361987886651444], 
             UndirectedEdge[186, 295] -> 
             RGBColor[
              0.23264914651192115`, 0.36185938216484964`, 0.9365603967690603],
              UndirectedEdge[245, 394] -> 
             RGBColor[
              0.22510267482771082`, 0.3539275619508045, 0.936130636370649], 
             UndirectedEdge[49, 459] -> 
             RGBColor[
              0.44038041665413563`, 0.554855283237734, 0.9495584378871766], 
             UndirectedEdge[55, 365] -> 
             RGBColor[
              0.21422616460620378`, 0.3424956600974225, 0.935511235203889], 
             UndirectedEdge[197, 448] -> 
             RGBColor[
              0.6327824685500147, 0.7119137261765637, 0.9648129350991647], 
             UndirectedEdge[185, 321] -> 
             RGBColor[
              0.30856010126890854`, 0.43938793879419913`, 0.9409661143099544],
              UndirectedEdge[242, 339] -> 
             RGBColor[
              0.21834915626655288`, 0.34682918574521915`, 0.9357460334795263],
              UndirectedEdge[186, 191] -> 
             RGBColor[
              0.22705589567091367`, 0.35598052089836485`, 0.936241869408138], 
             UndirectedEdge[218, 456] -> 
             RGBColor[
              0.2278157330596809, 0.3567791581704322, 0.9362851410233497], 
             UndirectedEdge[63, 182] -> 
             RGBColor[
              0.3989611276124065, 0.5199818091937107, 0.9466424281573576], 
             UndirectedEdge[133, 181] -> 
             RGBColor[
              0.3829354312034995, 0.5061011564392373, 0.9456212849531489], 
             UndirectedEdge[11, 186] -> 
             RGBColor[
              0.23731427099118235`, 0.3667627237785289, 0.936826068706721], 
             UndirectedEdge[105, 148] -> 
             RGBColor[
              0.24278055645410443`, 0.37250813638257607`, 0.9371373655771897],
              UndirectedEdge[235, 393] -> 
             RGBColor[
              0.40912660425444114`, 0.5285723075143651, 0.947349382422311], 
             UndirectedEdge[110, 290] -> 
             RGBColor[
              0.2791002706073135, 0.4106824587604797, 0.9392057195680129], 
             UndirectedEdge[225, 296] -> 
             RGBColor[
              0.29383455667092717`, 0.42573700098774714`, 0.940060637634782], 
             UndirectedEdge[38, 93] -> 
             RGBColor[
              0.2646269773927557, 0.3954701099321881, 0.9383814869307624], 
             UndirectedEdge[80, 486] -> 
             RGBColor[
              0.8622352558727102, 0.8932330485230531, 0.9866566699988166], 
             UndirectedEdge[471, 500] -> 
             RGBColor[
              0.8381526226622067, 0.29426335313338325`, 0.18416830058954048`],
              UndirectedEdge[200, 213] -> 
             RGBColor[
              0.9025169525103827, 0.6502340737413859, 0.24037009445756363`], 
             UndirectedEdge[191, 295] -> 
             RGBColor[
              0.22399463203679326`, 0.35276293872357944`, 0.9360675349729086],
              UndirectedEdge[295, 300] -> 
             RGBColor[
              0.22777276498654234`, 0.3567339960012304, 0.9362826940551499], 
             UndirectedEdge[191, 451] -> 
             RGBColor[
              0.21492359957141377`, 0.343228708465789, 0.9355509530933952], 
             UndirectedEdge[137, 145] -> 
             RGBColor[
              0.2203693542453783, 0.34895254190891456`, 0.9358610807658054], 
             UndirectedEdge[332, 344] -> 
             RGBColor[
              0.4329675168621825, 0.5491533716913533, 0.9488874962659426], 
             UndirectedEdge[76, 392] -> 
             RGBColor[
              0.35866334703698777`, 0.48482413936361163`, 0.9440839805262493],
              UndirectedEdge[157, 465] -> 
             RGBColor[
              0.2925845958094424, 0.42485533950351484`, 0.9399736319400027], 
             UndirectedEdge[204, 337] -> 
             RGBColor[
              0.6810518757467315, 0.7489355468683991, 0.970229432274497], 
             UndirectedEdge[112, 395] -> 
             RGBColor[
              0.2566255492107321, 0.38706010159303317`, 0.9379258174328484], 
             UndirectedEdge[51, 107] -> 
             RGBColor[
              0.18179934664985797`, 0.3084130184462969, 0.9336645758924533], 
             UndirectedEdge[5, 41] -> 
             RGBColor[
              0.23556700835298144`, 0.36492623996293, 0.9367265646843188], 
             UndirectedEdge[88, 210] -> 
             RGBColor[
              0.8513369203215293, 0.3826983248089265, 0.19628825904818903`], 
             UndirectedEdge[248, 411] -> 
             RGBColor[
              0.2410648104835609, 0.37070477858295714`, 0.937039656382386], 
             UndirectedEdge[101, 128] -> 
             RGBColor[
              0.5077879700548952, 0.6112841755347511, 0.9543940755727961], 
             UndirectedEdge[298, 418] -> 
             RGBColor[
              0.9400566522436402, 0.9539366372768199, 0.955901674523727], 
             UndirectedEdge[1, 391] -> 
             RGBColor[
              0.25364635844324135`, 0.38392878320479584`, 0.9377561569259576],
              UndirectedEdge[116, 327] -> 
             RGBColor[
              0.25289755432094124`, 0.38314174259533496`, 0.937713513638949], 
             UndirectedEdge[79, 81] -> 
             RGBColor[
              0.9087234308797807, 0.9257016701540246, 0.7763552620147077], 
             UndirectedEdge[254, 368] -> 
             RGBColor[
              0.32229994971598047`, 0.44690195182710835`, 0.9420022258236223],
              UndirectedEdge[4, 318] -> 
             RGBColor[
              0.33312298494508064`, 0.46295611913654056`, 0.9424472799249791],
              UndirectedEdge[352, 412] -> 
             RGBColor[
              0.23510619043035305`, 0.36444189110870373`, 0.9367003217853442],
              UndirectedEdge[239, 424] -> 
             RGBColor[
              0.3357624743157177, 0.4652423121647933, 0.9426154658536674], 
             UndirectedEdge[58, 188] -> 
             RGBColor[
              0.32619444448890195`, 0.45695496563196736`, 0.9420057994537792],
              UndirectedEdge[407, 408] -> 
             RGBColor[
              0.2184314377890148, 0.3469156688422765, 0.9357507192905059], 
             UndirectedEdge[255, 466] -> 
             RGBColor[
              0.45054684949746193`, 0.5632999878437683, 0.9503059651560305], 
             UndirectedEdge[197, 489] -> 
             RGBColor[
              0.843861608566709, 0.8769414103999965, 0.8921342396544271], 
             UndirectedEdge[50, 363] -> 
             RGBColor[
              0.422874692158388, 0.5406945368727382, 0.9481661793442926], 
             UndirectedEdge[57, 175] -> 
             RGBColor[
              0.7784866261079177, 0.8268297266210345, 0.9607862455954495], 
             UndirectedEdge[278, 486] -> 
             RGBColor[
              0.9416456695144926, 0.9559801240610102, 0.9829731602176706], 
             UndirectedEdge[82, 263] -> 
             RGBColor[
              0.26583963752085393`, 0.39674469261391226`, 0.9384505461310877],
              UndirectedEdge[41, 186] -> 
             RGBColor[
              0.23411854278577374`, 0.36340381081377343`, 0.9366440767130793],
              UndirectedEdge[390, 425] -> 
             RGBColor[
              0.3380481584260487, 0.4664830926023694, 0.94278816472538], 
             UndirectedEdge[218, 458] -> 
             RGBColor[
              0.23123609658963368`, 0.36037417710398584`, 0.936479925666406], 
             UndirectedEdge[230, 374] -> 
             RGBColor[
              0.23780417240741958`, 0.3672776412285381, 0.9368539678676315], 
             UndirectedEdge[104, 408] -> 
             RGBColor[
              0.23453910043567894`, 0.36384584356871885`, 0.9366680268490819],
              UndirectedEdge[121, 213] -> 
             RGBColor[
              0.86583591956703, 0.4350120088827739, 0.20785705715207875`], 
             UndirectedEdge[143, 421] -> 
             RGBColor[
              0.1789918035644768, 0.3054621126550484, 0.9335046904671287], 
             UndirectedEdge[185, 482] -> 
             RGBColor[
              0.32121309396000997`, 0.4503473251053272, 0.9417723518156291], 
             UndirectedEdge[256, 333] -> 
             RGBColor[
              0.3340176365315557, 0.4619410698643276, 0.9425698252260324], 
             UndirectedEdge[351, 463] -> 
             RGBColor[
              0.27857140569147526`, 0.4101265882019613, 0.9391756014934415], 
             UndirectedEdge[42, 411] -> 
             RGBColor[
              0.23603211668449622`, 0.3654150983089235, 0.9367530519157325], 
             UndirectedEdge[52, 243] -> 
             RGBColor[
              0.837550577025578, 0.2896357665521757, 0.18359178100799164`], 
             UndirectedEdge[385, 391] -> 
             RGBColor[
              0.23729940724147955`, 0.36674710103517516`, 0.9368252222381643],
              UndirectedEdge[366, 435] -> 
             RGBColor[
              0.2615619901606841, 0.3922486140198663, 0.9382069404421383], 
             UndirectedEdge[114, 419] -> 
             RGBColor[
              0.5066845097134336, 0.6103883367192307, 0.9543072071326079], 
             UndirectedEdge[67, 391] -> 
             RGBColor[
              0.24887514925956578`, 0.37891393984061833`, 0.9374844436213188],
              UndirectedEdge[310, 327] -> 
             RGBColor[
              0.2769131154519483, 0.40838362001854456`, 0.939081164317521], 
             UndirectedEdge[309, 348] -> 
             RGBColor[
              0.976471187338104, 0.9319682118150352, 0.39079228120582354`], 
             UndirectedEdge[28, 194] -> 
             RGBColor[
              0.9756860818103763, 0.9810011844305191, 0.9087502503850045], 
             UndirectedEdge[92, 337] -> 
             RGBColor[
              0.7346741443689091, 0.7924685201915558, 0.974450773685277], 
             UndirectedEdge[205, 432] -> 
             RGBColor[
              0.9462255159241673, 0.9556033712696023, 0.7798152269955922], 
             UndirectedEdge[314, 398] -> 
             RGBColor[
              0.29561326424229706`, 0.426066606556162, 0.9402183167389095], 
             UndirectedEdge[235, 453] -> 
             RGBColor[
              0.32067427818872773`, 0.4499141070194098, 0.9417367931922191], 
             UndirectedEdge[92, 334] -> 
             RGBColor[
              0.505970833581321, 0.6084373708863062, 0.9546299931971096], 
             UndirectedEdge[35, 54] -> 
             RGBColor[
              0.23354661261843296`, 0.36280267594543125`, 0.936611506136144], 
             UndirectedEdge[191, 456] -> 
             RGBColor[
              0.22102995492901595`, 0.34964687511192016`, 0.9358987009974674],
              UndirectedEdge[78, 137] -> 
             RGBColor[
              0.21975482034818994`, 0.34830662781927, 0.9358260839694819], 
             UndirectedEdge[57, 169] -> 
             RGBColor[
              0.5469925860365322, 0.6431122489364671, 0.9574804065541109], 
             UndirectedEdge[343, 392] -> 
             RGBColor[
              0.29944445035868683`, 0.4320654815746701, 0.9403642905083368], 
             UndirectedEdge[24, 197] -> 
             RGBColor[
              0.7672988184851579, 0.8182762435725834, 0.9774043962108645], 
             UndirectedEdge[450, 471] -> 
             RGBColor[
              0.8372605332410615, 0.2874063629263848, 0.183314034752381], 
             UndirectedEdge[150, 267] -> 
             RGBColor[
              0.9052536312416688, 0.5703031723537458, 0.2900897268509228], 
             UndirectedEdge[40, 371] -> 
             RGBColor[
              0.37457203795785354`, 0.49885720556622565`, 0.9450883769309946],
              UndirectedEdge[217, 362] -> 
             RGBColor[
              0.35409065029754605`, 0.481117256999343, 0.9437833210202597], 
             UndirectedEdge[229, 478] -> 
             RGBColor[
              0.27850887095594073`, 0.41006086022998334`, 0.9391720402327646],
              UndirectedEdge[100, 168] -> 
             RGBColor[
              0.9210035362936968, 0.7245123759551941, 0.25529579489782767`], 
             UndirectedEdge[221, 297] -> 
             RGBColor[
              0.5279871450253872, 0.627682775738259, 0.9559842286184892], 
             UndirectedEdge[50, 338] -> 
             RGBColor[
              0.3805216773222415, 0.5040104841460892, 0.9454674826902338], 
             UndirectedEdge[5, 186] -> 
             RGBColor[
              0.23715887571324926`, 0.36659939348879156`, 0.9368172191755294],
              UndirectedEdge[147, 391] -> 
             RGBColor[
              0.24631019843469731`, 0.37621801389640636`, 0.9373383734663472],
              UndirectedEdge[24, 426] -> 
             RGBColor[
              0.8535732035252862, 0.8860801191364223, 0.9858957682176778], 
             UndirectedEdge[100, 127] -> 
             RGBColor[
              0.5785973319473678, 0.5599231651764567, 0.5998463238378839], 
             UndirectedEdge[418, 432] -> 
             RGBColor[
              0.9385489798096075, 0.9527344602026001, 0.9557578713810538], 
             UndirectedEdge[200, 259] -> 
             RGBColor[
              0.8813343532764009, 0.5540488379416193, 0.22269481442370878`], 
             UndirectedEdge[17, 293] -> 
             RGBColor[
              0.9171217844286204, 0.9362730779745756, 0.9753514321588153], 
             UndirectedEdge[269, 468] -> 
             RGBColor[
              0.4636581822326119, 0.5753387348931303, 0.9509528669224259], 
             UndirectedEdge[154, 390] -> 
             RGBColor[
              0.30514733542854805`, 0.43798605336538, 0.9406917533770347], 
             UndirectedEdge[162, 439] -> 
             RGBColor[
              0.6614719504889517, 0.7330346033014116, 0.9686938737233264], 
             UndirectedEdge[103, 304] -> 
             RGBColor[
              0.4094598762170423, 0.5283411604549934, 0.947514243402197], 
             UndirectedEdge[3, 480] -> 
             RGBColor[
              0.4076066344287682, 0.5272434439758863, 0.9472559414401728], 
             UndirectedEdge[358, 404] -> 
             RGBColor[
              0.21953726017780179`, 0.34807795828608057`, 0.9358136942396298],
              UndirectedEdge[3, 439] -> 
             RGBColor[
              0.6612892589149015, 0.732886286051436, 0.9686794915733958], 
             UndirectedEdge[336, 458] -> 
             RGBColor[
              0.22636890121139194`, 0.35525844616344304`, 0.9362027460899854],
              UndirectedEdge[212, 287] -> 
             RGBColor[
              0.21416398383706822`, 0.3424303041665726, 0.9355076941010749], 
             UndirectedEdge[190, 195] -> 
             RGBColor[
              0.25913077183266553`, 0.38969324940897365`, 0.9380684861550228],
              UndirectedEdge[253, 377] -> 
             RGBColor[
              0.9830684787672088, 0.9867535506374262, 0.9072964317019494], 
             UndirectedEdge[192, 327] -> 
             RGBColor[
              0.25584189976103616`, 0.38623643633515786`, 0.9378811897559938],
              UndirectedEdge[151, 483] -> 
             RGBColor[
              0.3017217477257488, 0.43445906549644486`, 0.9404939792244313], 
             UndirectedEdge[38, 163] -> 
             RGBColor[
              0.2634804930859057, 0.3942650822343853, 0.9383161963455589], 
             UndirectedEdge[88, 227] -> 
             RGBColor[
              0.8561206468687188, 0.41946814329296433`, 0.20086916099222407`],
              UndirectedEdge[281, 343] -> 
             RGBColor[
              0.26889808498261325`, 0.3999593148129905, 0.9386247201894673], 
             UndirectedEdge[76, 157] -> 
             RGBColor[
              0.35693445553108405`, 0.4830069647728541, 0.9439855227126539], 
             UndirectedEdge[364, 437] -> 
             RGBColor[
              0.25719856867599794`, 0.38766238138256004`, 0.9379584500436889],
              UndirectedEdge[229, 244] -> 
             RGBColor[
              0.3167084139494082, 0.447095666264713, 0.9414615153937971], 
             UndirectedEdge[154, 425] -> 
             RGBColor[
              0.3424420265478999, 0.47102780458425264`, 0.9430410810154058], 
             UndirectedEdge[128, 355] -> 
             RGBColor[
              0.4117250076221206, 0.5299124488854325, 0.9477665145867664], 
             UndirectedEdge[58, 382] -> 
             RGBColor[
              0.2986682199237062, 0.43066105766182183`, 0.9403416352703349], 
             UndirectedEdge[45, 179] -> 
             RGBColor[
              0.2308558043838454, 0.3599744658837838, 0.9364582685878783], 
             UndirectedEdge[181, 296] -> 
             RGBColor[
              0.3670585086059648, 0.49234936408258523`, 0.9446096214846453], 
             UndirectedEdge[350, 354] -> 
             RGBColor[
              0.36196691822383753`, 0.4879392844043602, 0.9442851898478128], 
             UndirectedEdge[318, 335] -> 
             RGBColor[
              0.3093572475376726, 0.43941523304457686`, 0.9410411890738053], 
             UndirectedEdge[354, 372] -> 
             RGBColor[
              0.416108457877265, 0.5343687074376324, 0.9478635928798225], 
             UndirectedEdge[44, 57] -> 
             RGBColor[
              0.5489601186307986, 0.6447095805328258, 0.9576352979272409], 
             UndirectedEdge[257, 420] -> 
             RGBColor[
              0.9137481314322007, 0.7140513423503487, 0.5709499365964574], 
             UndirectedEdge[84, 171] -> 
             RGBColor[
              0.2475282592649566, 0.3774982730585261, 0.9374077402286709], 
             UndirectedEdge[376, 497] -> 
             RGBColor[
              0.25772437162935435`, 0.38821503362437043`, 0.9379883937440268],
              UndirectedEdge[164, 443] -> 
             RGBColor[
              0.8760183447320038, 0.45688851313920237`, 0.21528999668843654`],
              UndirectedEdge[2, 54] -> 
             RGBColor[
              0.22058424144202293`, 0.3491784019772233, 0.9358733182737572], 
             UndirectedEdge[165, 324] -> 
             RGBColor[
              0.3968553526992069, 0.5181578928032218, 0.9465082500419522], 
             UndirectedEdge[82, 395] -> 
             RGBColor[
              0.26163309800222595`, 0.39232335286982434`, 0.9382109899285194],
              UndirectedEdge[298, 420] -> 
             RGBColor[
              0.9351413217232607, 0.9502707918228358, 0.9642220469712115], 
             UndirectedEdge[163, 437] -> 
             RGBColor[
              0.26141138655191587`, 0.3920903200782306, 0.9381983637894169], 
             UndirectedEdge[156, 372] -> 
             RGBColor[
              0.46888111877498084`, 0.5796978409320405, 0.951331185719549], 
             UndirectedEdge[272, 317] -> 
             RGBColor[
              0.8519916278011412, 0.36132246904964216`, 0.1958811278335439], 
             UndirectedEdge[282, 441] -> 
             RGBColor[
              0.5288953957407483, 0.628333638126909, 0.9560796286709814], 
             UndirectedEdge[209, 423] -> 
             RGBColor[
              0.37687473184245884`, 0.48661428775252374`, 0.9464892509185017],
              UndirectedEdge[222, 333] -> 
             RGBColor[
              0.41068141899913524`, 0.5301333365139219, 0.9473892347606732], 
             UndirectedEdge[125, 455] -> 
             RGBColor[
              0.20630711262003382`, 0.3341722343630622, 0.9350602569084642], 
             UndirectedEdge[343, 433] -> 
             RGBColor[
              0.3091968798489231, 0.4407663035487692, 0.9409764153784905], 
             UndirectedEdge[29, 77] -> 
             RGBColor[
              0.5082190929851442, 0.6104476858288989, 0.9547558471761093], 
             UndirectedEdge[298, 353] -> 
             RGBColor[
              0.7706511770330843, 0.8213765109750578, 0.9776280646137345], 
             UndirectedEdge[65, 337] -> 
             RGBColor[
              0.9228377639355362, 0.92700213552959, 0.6922814441739551], 
             UndirectedEdge[93, 364] -> 
             RGBColor[
              0.2639259772143767, 0.39473331429873343`, 0.9383415660076406], 
             UndirectedEdge[170, 328] -> 
             RGBColor[
              0.3409967871765409, 0.4686604793300483, 0.9429898367152708], 
             UndirectedEdge[13, 244] -> 
             RGBColor[
              0.3195286449146627, 0.4500599078221664, 0.9416221233751105], 
             UndirectedEdge[114, 291] -> 
             RGBColor[
              0.577802812280651, 0.6679328507014297, 0.9600375327920143], 
             UndirectedEdge[198, 373] -> 
             RGBColor[
              0.28774746699468884`, 0.4197712104275283, 0.9396981646098933], 
             UndirectedEdge[54, 84] -> 
             RGBColor[
              0.23101754524273913`, 0.3601444657814439, 0.9364674794905181], 
             UndirectedEdge[1, 385] -> 
             RGBColor[
              0.2498185382943033, 0.379905501530447, 0.937538168231228], 
             UndirectedEdge[97, 294] -> 
             RGBColor[
              0.23502362506905988`, 0.3643551096790384, 0.936695619810163], 
             UndirectedEdge[83, 489] -> 
             RGBColor[
              0.9554216482771469, 0.9649073806371287, 0.9030373799764648], 
             UndirectedEdge[349, 359] -> 
             RGBColor[
              0.3995263663781553, 0.520471390602876, 0.94667844467169], 
             UndirectedEdge[47, 55] -> 
             RGBColor[
              0.22170565849658444`, 0.35035708240351526`, 0.9359371813160265],
              UndirectedEdge[166, 309] -> 
             RGBColor[
              0.9155755884315661, 0.6407588014939913, 0.33347870741883034`], 
             UndirectedEdge[196, 482] -> 
             RGBColor[
              0.3270903866194627, 0.45652473233228946`, 0.9421070549379097], 
             UndirectedEdge[114, 311] -> 
             RGBColor[
              0.6237676761079407, 0.7038409516692123, 0.9646188808522442], 
             UndirectedEdge[101, 169] -> 
             RGBColor[
              0.506787455963573, 0.6104719131227696, 0.9543153114385234], 
             UndirectedEdge[160, 353] -> 
             RGBColor[
              0.531072144514868, 0.6293500407838779, 0.9564584330755022], 
             UndirectedEdge[80, 329] -> 
             RGBColor[
              0.8360503988309712, 0.8723539542869803, 0.9841591349586778], 
             UndirectedEdge[130, 386] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[216, 238] -> 
             RGBColor[
              0.29301995095784455`, 0.42425818517520597`, 0.9400370439768699],
              UndirectedEdge[240, 382] -> 
             RGBColor[
              0.26942512488484194`, 0.40051326716649266`, 0.9386547343322136],
              UndirectedEdge[424, 470] -> 
             RGBColor[
              0.28803826967359597`, 0.4189813939860375, 0.9397548358601392], 
             UndirectedEdge[184, 225] -> 
             RGBColor[
              0.2656405828545585, 0.396535473538841, 0.9384392102623171], 
             UndirectedEdge[169, 274] -> 
             RGBColor[
              0.4777382226320348, 0.5868884368511786, 0.9520284493798168], 
             UndirectedEdge[345, 375] -> 
             RGBColor[
              0.8089633164388916, 0.8512244424146573, 0.9611785706908804], 
             UndirectedEdge[326, 434] -> 
             RGBColor[
              0.9331890448533395, 0.7583565146768234, 0.5065076494810187], 
             UndirectedEdge[59, 105] -> 
             RGBColor[
              0.2440481876886619, 0.3738404971825583, 0.9372095553007055], 
             UndirectedEdge[90, 306] -> 
             RGBColor[
              0.8611746456929213, 0.4612099603827511, 0.20582221997608346`], 
             UndirectedEdge[44, 466] -> 
             RGBColor[
              0.5000927113166715, 0.6050368178236056, 0.9537882766162615], 
             UndirectedEdge[88, 434] -> 
             RGBColor[
              0.9289063525023188, 0.7389098089590498, 0.5029340660049313], 
             UndirectedEdge[174, 356] -> 
             RGBColor[
              0.2679975194043914, 0.3990127632911238, 0.938573434312055], 
             UndirectedEdge[65, 88] -> 
             RGBColor[
              0.9260374771709088, 0.7249105779401631, 0.30422129427437533`], 
             UndirectedEdge[82, 195] -> 
             RGBColor[
              0.2642152742010554, 0.39503738377422104`, 0.9383580410430554], 
             UndirectedEdge[150, 413] -> 
             RGBColor[
              0.8976403406773998, 0.5446217555948332, 0.26051353065802335`], 
             UndirectedEdge[156, 307] -> 
             RGBColor[
              0.4685593666518582, 0.5794366280637215, 0.9513058562137999], 
             UndirectedEdge[245, 460] -> 
             RGBColor[
              0.23495456172986623`, 0.36428251973067727`, 0.936691686755166], 
             UndirectedEdge[101, 204] -> 
             RGBColor[
              0.5113628894889524, 0.6141864561796039, 0.9546755063260064], 
             UndirectedEdge[210, 428] -> 
             RGBColor[
              0.8331986050247592, 0.2561846027075905, 0.17942432770515804`], 
             UndirectedEdge[25, 76] -> 
             RGBColor[
              0.36235029179287925`, 0.48827134332094824`, 0.9443096180726283],
              UndirectedEdge[130, 421] -> 
             RGBColor[
              0.17899180289058533`, 0.3054621119467458, 0.9335046904287516], 
             UndirectedEdge[79, 493] -> 
             RGBColor[
              0.9937029879453217, 0.9889396528776512, 0.5559872823811043], 
             UndirectedEdge[194, 490] -> 
             RGBColor[
              0.9885348242076832, 0.9895268694153684, 0.8396711640099095], 
             UndirectedEdge[214, 347] -> 
             RGBColor[
              0.1893670574265447, 0.316367162293171, 0.9340955458257609], 
             UndirectedEdge[41, 202] -> 
             RGBColor[
              0.2357918679274276, 0.3651625816325934, 0.9367393701044336], 
             UndirectedEdge[85, 97] -> 
             RGBColor[
              0.22297503114412753`, 0.3516912735389574, 0.9360094702104356], 
             UndirectedEdge[31, 114] -> 
             RGBColor[
              0.47685837337515014`, 0.5861665400670314, 0.9519612830883075], 
             UndirectedEdge[247, 425] -> 
             RGBColor[
              0.4351771155351065, 0.550218204604259, 0.9492628740426365], 
             UndirectedEdge[35, 281] -> 
             RGBColor[
              0.2416405448941051, 0.37130991195210916`, 0.9370724436053437], 
             UndirectedEdge[157, 288] -> 
             RGBColor[
              0.2793047597177943, 0.4108973897809534, 0.9392173649203402], 
             UndirectedEdge[208, 427] -> 
             RGBColor[
              0.3008093263098471, 0.4322636714318231, 0.9404872881507658], 
             UndirectedEdge[154, 313] -> 
             RGBColor[
              0.2882495492104231, 0.42022540866860447`, 0.9397294494499471], 
             UndirectedEdge[189, 364] -> 
             RGBColor[
              0.25917101959394173`, 0.3897355523579304, 0.9380707782054862], 
             UndirectedEdge[314, 373] -> 
             RGBColor[
              0.3118454823562334, 0.44312769697598026`, 0.9411427175470836], 
             UndirectedEdge[156, 232] -> 
             RGBColor[
              0.4117533959329014, 0.5306819361106889, 0.9475625057353367], 
             UndirectedEdge[321, 383] -> 
             RGBColor[
              0.3310589867507921, 0.46116838764021345`, 0.942315763785161], 
             UndirectedEdge[15, 323] -> 
             RGBColor[
              0.2367917298527569, 0.36621349991102203`, 0.936796310761918], 
             UndirectedEdge[225, 235] -> 
             RGBColor[
              0.31564550837904015`, 0.44462855110700683`, 0.9414504121909557],
              UndirectedEdge[170, 265] -> 
             RGBColor[
              0.3088475371272851, 0.4408144148056739, 0.9409413149305978], 
             UndirectedEdge[102, 485] -> 
             RGBColor[
              0.2622693737921402, 0.3929921190672394, 0.9382472248934693], 
             UndirectedEdge[342, 463] -> 
             RGBColor[
              0.2635422521882549, 0.3943299949667075, 0.9383197134350733], 
             UndirectedEdge[70, 147] -> 
             RGBColor[
              0.2548716664665323, 0.3852166596262904, 0.9378259364052033], 
             UndirectedEdge[162, 381] -> 
             RGBColor[
              0.515668109442376, 0.6176816276857418, 0.9550144290112803], 
             UndirectedEdge[212, 299] -> 
             RGBColor[
              0.21384131413680724`, 0.3420911578531577, 0.9354893185389921], 
             UndirectedEdge[92, 361] -> 
             RGBColor[
              0.6266695180780231, 0.7077693478258749, 0.9637721633771799], 
             UndirectedEdge[82, 184] -> 
             RGBColor[
              0.2576552479933815, 0.38814238030027126`, 0.9379844572552174], 
             UndirectedEdge[232, 376] -> 
             RGBColor[
              0.3178263634409366, 0.4469988106247622, 0.9415717511395277], 
             UndirectedEdge[293, 298] -> 
             RGBColor[
              0.9279560632534805, 0.9449120378208546, 0.9763848153450053], 
             UndirectedEdge[225, 249] -> 
             RGBColor[
              0.28189858083211217`, 0.41362366022985875`, 0.9393650791955862],
              UndirectedEdge[19, 34] -> 
             RGBColor[
              0.5517387974757788, 0.6469654371972362, 0.9578540457045537], 
             UndirectedEdge[338, 390] -> 
             RGBColor[
              0.3104293975603457, 0.44256111009978116`, 0.9410283217053288], 
             UndirectedEdge[82, 342] -> 
             RGBColor[
              0.2591328832418887, 0.3896954686339382, 0.9380686063966545], 
             UndirectedEdge[54, 374] -> 
             RGBColor[
              0.24022555960590497`, 0.3698226726989618, 0.9369918622864639], 
             UndirectedEdge[196, 350] -> 
             RGBColor[
              0.3289346637950721, 0.4581221525257362, 0.9422245706487093], 
             UndirectedEdge[19, 44] -> 
             RGBColor[
              0.5282008880554978, 0.6278563019591167, 0.956001055252786], 
             UndirectedEdge[85, 408] -> 
             RGBColor[
              0.21836004410720744`, 0.3468406295560761, 0.9357466535259444], 
             UndirectedEdge[57, 255] -> 
             RGBColor[
              0.499414256811589, 0.6029727505529885, 0.9541529864670097], 
             UndirectedEdge[106, 269] -> 
             RGBColor[
              0.48339733950661234`, 0.5913638720070653, 0.9525068056899508], 
             UndirectedEdge[382, 416] -> 
             RGBColor[
              0.2718791903645599, 0.40309264558241453`, 0.938794489730819], 
             UndirectedEdge[246, 392] -> 
             RGBColor[
              0.3001114005223494, 0.4327664884837622, 0.940402272333493], 
             UndirectedEdge[350, 414] -> 
             RGBColor[
              0.31841398035212815`, 0.44706424717734483`, 0.94162543329059], 
             UndirectedEdge[146, 211] -> 
             RGBColor[
              0.2444868180291041, 0.37430152548113294`, 0.9372345346496982], 
             UndirectedEdge[71, 487] -> 
             RGBColor[
              0.6676064579243342, 0.7392945350984725, 0.9681635028375868], 
             UndirectedEdge[415, 485] -> 
             RGBColor[
              0.2675069384795197, 0.39849713163445644`, 0.9385454964541331], 
             UndirectedEdge[238, 433] -> 
             RGBColor[
              0.32283008594645624`, 0.45404092736007795`, 0.94179142550244], 
             UndirectedEdge[141, 429] -> 
             RGBColor[
              0.30159042381675216`, 0.434243660437526, 0.9404893336110074], 
             UndirectedEdge[406, 493] -> 
             RGBColor[
              0.9920978208950986, 0.9843432363296774, 0.4801786397760631], 
             UndirectedEdge[257, 357] -> 
             RGBColor[
              0.8829978584207956, 0.5607626793064351, 0.22403944465155362`], 
             UndirectedEdge[311, 488] -> 
             RGBColor[
              0.7581105843852092, 0.8109610174663499, 0.9765250361714609], 
             UndirectedEdge[258, 381] -> 
             RGBColor[
              0.4713636222770108, 0.5795438974068458, 0.952126015828245], 
             UndirectedEdge[168, 200] -> 
             RGBColor[
              0.9058101136750496, 0.6632964389017137, 0.24302016366679569`], 
             UndirectedEdge[16, 254] -> 
             RGBColor[
              0.3201901654275895, 0.4450745627173458, 0.941867792234375], 
             UndirectedEdge[325, 347] -> 
             RGBColor[
              0.1789719601845752, 0.3054412560046289, 0.9335035604159989], 
             UndirectedEdge[154, 478] -> 
             RGBColor[
              0.28779157321631055`, 0.419744046861437, 0.9397033683945971], 
             UndirectedEdge[302, 386] -> 
             RGBColor[
              0.18453817917078433`, 0.311291705077802, 0.9338205483527805], 
             UndirectedEdge[330, 414] -> 
             RGBColor[
              0.2905537605670515, 0.4227208029013707, 0.9398579788773], 
             UndirectedEdge[50, 334] -> 
             RGBColor[
              0.42187105269828507`, 0.539825234816783, 0.9481022283253784], 
             UndirectedEdge[72, 187] -> 
             RGBColor[
              0.2593062768219157, 0.38987771628033463`, 0.9380784809045242], 
             UndirectedEdge[14, 149] -> 
             RGBColor[
              0.33030872638618497`, 0.46033332920658265`, 0.9422747396921978],
              UndirectedEdge[113, 214] -> 
             RGBColor[
              0.18949968777431325`, 0.3165065651979255, 0.9341030989278573], 
             UndirectedEdge[63, 149] -> 
             RGBColor[
              0.3866051837093468, 0.5092797116126782, 0.9458551183377868], 
             UndirectedEdge[245, 445] -> 
             RGBColor[
              0.22560109399094413`, 0.3544514320929628, 0.93615902060465], 
             UndirectedEdge[207, 336] -> 
             RGBColor[
              0.2196507706490151, 0.34819726498830533`, 0.9358201584930417], 
             UndirectedEdge[264, 394] -> 
             RGBColor[
              0.23171433520063273`, 0.36087683620622507`, 0.9365071606478118],
              UndirectedEdge[255, 370] -> 
             RGBColor[
              0.4945144317215364, 0.598994851810279, 0.9537672542872702], 
             UndirectedEdge[330, 482] -> 
             RGBColor[
              0.33246549585026375`, 0.4621743129354704, 0.9424131594568423], 
             UndirectedEdge[383, 482] -> 
             RGBColor[
              0.34371197944189347`, 0.47212777395134153`, 0.9431220012908359],
              UndirectedEdge[358, 407] -> 
             RGBColor[
              0.21999227740316346`, 0.34855621023969413`, 0.9358396067974764],
              UndirectedEdge[28, 142] -> 
             RGBColor[
              0.8321901895218196, 0.869251634409216, 0.9575296911592543], 
             UndirectedEdge[348, 375] -> 
             RGBColor[
              0.959056524042907, 0.9223909347161948, 0.6272014222552931], 
             UndirectedEdge[41, 295] -> 
             RGBColor[
              0.23105727915165333`, 0.3601862286389881, 0.9364697422778497], 
             UndirectedEdge[83, 345] -> 
             RGBColor[
              0.7902354483667869, 0.8368716246944006, 0.9795108205407682], 
             UndirectedEdge[140, 425] -> 
             RGBColor[
              0.4374884569477172, 0.5520946556877604, 0.9494448313053598], 
             UndirectedEdge[160, 441] -> 
             RGBColor[
              0.4363070753078513, 0.5523289920255958, 0.9490220789207864], 
             UndirectedEdge[66, 394] -> 
             RGBColor[
              0.24596177604056546`, 0.3758517998689181, 0.937318531326446], 
             UndirectedEdge[201, 271] -> 
             RGBColor[
              0.2801320470703391, 0.4117669212415258, 0.9392644777112058], 
             UndirectedEdge[192, 470] -> 
             RGBColor[
              0.255048373399578, 0.3854023898167881, 0.9378359996036256], 
             UndirectedEdge[255, 379] -> 
             RGBColor[
              0.35344236256380235`, 0.4805557427482631, 0.943742012699124], 
             UndirectedEdge[82, 440] -> 
             RGBColor[
              0.26997623108034263`, 0.40109251472011487`, 0.9386861190147588],
              UndirectedEdge[43, 362] -> 
             RGBColor[
              0.34080467652755875`, 0.4681674552795022, 0.9429895550260083], 
             UndirectedEdge[127, 302] -> 
             RGBColor[
              0.2080645848230672, 0.3360194490786239, 0.9351603423504797], 
             UndirectedEdge[137, 358] -> 
             RGBColor[
              0.22285337720406, 0.3515634075346411, 0.9360025421985196], 
             UndirectedEdge[238, 328] -> 
             RGBColor[
              0.35273346300045894`, 0.47994172957682313`, 0.943696842245803], 
             UndirectedEdge[185, 196] -> 
             RGBColor[
              0.2898220421197416, 0.4219517204196188, 0.9398163085942062], 
             UndirectedEdge[114, 208] -> 
             RGBColor[
              0.41139850447614446`, 0.5294684917353877, 0.9477902381259522], 
             UndirectedEdge[249, 424] -> 
             RGBColor[
              0.30507115038591015`, 0.4368840315616916, 0.9407248332188166], 
             UndirectedEdge[21, 65] -> 
             RGBColor[
              0.9831762967586118, 0.9549118399527363, 0.38914351910732653`], 
             UndirectedEdge[369, 466] -> 
             RGBColor[
              0.46172779849419876`, 0.5729843638939052, 0.9510184053391775], 
             UndirectedEdge[246, 459] -> 
             RGBColor[
              0.3423837632254584, 0.4696344421074833, 0.9430865385917233], 
             UndirectedEdge[46, 317] -> 
             RGBColor[
              0.9005275853462438, 0.6373329329271229, 0.23851003583391922`], 
             UndirectedEdge[66, 305] -> 
             RGBColor[
              0.25719647261268064`, 0.38766017828711546`, 0.9379583306759838],
              UndirectedEdge[56, 243] -> 
             RGBColor[
              0.8379898589381207, 0.2930122798265395, 0.18401243786354038`], 
             UndirectedEdge[281, 288] -> 
             RGBColor[
              0.2504872858476244, 0.38060839761003135`, 0.9375762524150663], 
             UndirectedEdge[81, 329] -> 
             RGBColor[
              0.8530880154845231, 0.8856932433627962, 0.9858494905492173], 
             UndirectedEdge[57, 140] -> 
             RGBColor[
              0.550438526060826, 0.6459098182860178, 0.9577516835757175], 
             UndirectedEdge[184, 440] -> 
             RGBColor[
              0.26935285588816305`, 0.4004373078688641, 0.9386506187197652], 
             UndirectedEdge[422, 446] -> 
             RGBColor[
              0.2310816388212659, 0.36021183219624314`, 0.9364711295249972], 
             UndirectedEdge[232, 307] -> 
             RGBColor[
              0.4130035971526026, 0.5316969057817654, 0.9476609261549895], 
             UndirectedEdge[90, 261] -> 
             RGBColor[
              0.8723782969076955, 0.5133814777114375, 0.21522166145663085`], 
             UndirectedEdge[118, 304] -> 
             RGBColor[
              0.3318360758338559, 0.46184146314633034`, 0.9423652792143808], 
             UndirectedEdge[427, 460] -> 
             RGBColor[
              0.2639231904685617, 0.39473038525219195`, 0.938341407306589], 
             UndirectedEdge[299, 300] -> 
             RGBColor[
              0.21756201185689822`, 0.346001847062834, 0.9357012067698722], 
             UndirectedEdge[106, 425] -> 
             RGBColor[
              0.4465990938801403, 0.559491081179018, 0.9501620540180429], 
             UndirectedEdge[428, 495] -> 
             RGBColor[
              0.8362679836981737, 0.2797771922017657, 0.1823635681891872], 
             UndirectedEdge[230, 365] -> 
             RGBColor[
              0.22042634378562792`, 0.3490124415290624, 0.9358643262358141], 
             UndirectedEdge[224, 463] -> 
             RGBColor[
              0.2830318265857735, 0.4148147733688876, 0.9394296158647704], 
             UndirectedEdge[251, 382] -> 
             RGBColor[
              0.27038494943162866`, 0.40152210362155666`, 0.9387093949202199],
              UndirectedEdge[81, 278] -> 
             RGBColor[
              0.8859909437525565, 0.9116025564457284, 0.9776647627909368], 
             UndirectedEdge[42, 294] -> 
             RGBColor[
              0.23539350574473433`, 0.36474387772096156`, 0.9367166839674533],
              UndirectedEdge[8, 419] -> 
             RGBColor[
              0.5664920822105015, 0.6589428183727875, 0.9590154783219338], 
             UndirectedEdge[159, 164] -> 
             RGBColor[
              0.819137437150352, 0.14810430478184575`, 0.1659593374688081], 
             UndirectedEdge[346, 404] -> 
             RGBColor[
              0.21566548218765702`, 0.3440084741335353, 0.9355932022108733], 
             UndirectedEdge[7, 194] -> 
             RGBColor[
              0.9125990982944516, 0.9314492168831301, 0.9288011319761822], 
             UndirectedEdge[268, 353] -> 
             RGBColor[
              0.5246586597567469, 0.6237950026375101, 0.9560497714979366], 
             UndirectedEdge[51, 423] -> 
             RGBColor[
              0.18337644614132015`, 0.31007065000570677`, 0.9337543893753826],
              UndirectedEdge[14, 322] -> 
             RGBColor[
              0.2829806146027809, 0.4147609463277351, 0.9394266994181002], 
             UndirectedEdge[109, 458] -> 
             RGBColor[
              0.24222963005763265`, 0.3719290778091332, 0.9371059911339332], 
             UndirectedEdge[217, 384] -> 
             RGBColor[
              0.30177027996931804`, 0.4334954768697517, 0.9405338925067932], 
             UndirectedEdge[202, 485] -> 
             RGBColor[
              0.2435291255920976, 0.37329493000863156`, 0.9371799954821897], 
             UndirectedEdge[125, 457] -> 
             RGBColor[
              0.21513132866869134`, 0.3434470449178132, 0.9355627829581774], 
             UndirectedEdge[454, 475] -> 
             RGBColor[
              0.8694429086173421, 0.4695370183739893, 0.21157738923531183`], 
             UndirectedEdge[30, 378] -> 
             RGBColor[
              0.2755078252460146, 0.406906570911563, 0.9390011351192336], 
             UndirectedEdge[445, 460] -> 
             RGBColor[
              0.23899278558713355`, 0.3685269490428458, 0.9369216576298206], 
             UndirectedEdge[173, 461] -> 
             RGBColor[
              0.9645092309315171, 0.9729899937684735, 0.9422009085196323], 
             UndirectedEdge[23, 41] -> 
             RGBColor[
              0.22751409159888136`, 0.35646211386995863`, 0.9362679629883957],
              UndirectedEdge[111, 444] -> 
             RGBColor[
              0.272192144891436, 0.40342158063262434`, 0.9388123120281499], 
             UndirectedEdge[139, 360] -> 
             RGBColor[
              0.5717007512056378, 0.6631714505109032, 0.9594255238252141], 
             UndirectedEdge[53, 432] -> 
             RGBColor[
              0.9375683877182548, 0.9272177056729635, 0.6767239867532486], 
             UndirectedEdge[184, 260] -> 
             RGBColor[
              0.2713041510776424, 0.40248824283226764`, 0.9387617420941234], 
             UndirectedEdge[244, 379] -> 
             RGBColor[
              0.3258701140726008, 0.45667404692668806`, 0.9419851334064466], 
             UndirectedEdge[14, 187] -> 
             RGBColor[
              0.28568538812664784`, 0.41760383479386565`, 0.9395807322689307],
              UndirectedEdge[133, 332] -> 
             RGBColor[
              0.3736828594731001, 0.4980870438541423, 0.9450317192642157], 
             UndirectedEdge[424, 440] -> 
             RGBColor[
              0.30113413549531765`, 0.4327459792905174, 0.940500626045089], 
             UndirectedEdge[381, 419] -> 
             RGBColor[
              0.5409976687744238, 0.6382453050351424, 0.9570084647071322], 
             UndirectedEdge[39, 368] -> 
             RGBColor[
              0.5158816187650146, 0.6166272342584453, 0.9553704626805029], 
             UndirectedEdge[40, 208] -> 
             RGBColor[
              0.3541593410951509, 0.4811767535157284, 0.9437876979371422], 
             UndirectedEdge[436, 462] -> 
             RGBColor[
              0.46839908955768095`, 0.5793065078982675, 0.951293238613832], 
             UndirectedEdge[103, 188] -> 
             RGBColor[
              0.408816425381794, 0.5277838356822806, 0.9474732432839563], 
             UndirectedEdge[313, 411] -> 
             RGBColor[
              0.2532739296678089, 0.38353733694846814`, 0.9377349476581557], 
             UndirectedEdge[181, 344] -> 
             RGBColor[
              0.4422200885925819, 0.5571674842764482, 0.9494770619548758], 
             UndirectedEdge[5, 485] -> 
             RGBColor[
              0.24330426601765148`, 0.37305858833896816`, 0.9371671900620748],
              UndirectedEdge[371, 429] -> 
             RGBColor[
              0.3282709430209225, 0.4573529851702918, 0.9421893927020404], 
             UndirectedEdge[426, 448] -> 
             RGBColor[
              0.7190568535901429, 0.7797176017404024, 0.9733043071059779], 
             UndirectedEdge[32, 403] -> 
             RGBColor[
              0.73231135392298, 0.7900531713799142, 0.9748369526254256], 
             UndirectedEdge[115, 484] -> 
             RGBColor[
              0.9570300393594782, 0.9635915325846716, 0.7300132516870645], 
             UndirectedEdge[36, 251] -> 
             RGBColor[
              0.25646724614478844`, 0.3868937150337323, 0.9379168023074314], 
             UndirectedEdge[243, 454] -> 
             RGBColor[
              0.869594267772993, 0.47070043117032717`, 0.21172233093369885`], 
             UndirectedEdge[106, 139] -> 
             RGBColor[
              0.5409452590449157, 0.6382027564556965, 0.9570043388212421], 
             UndirectedEdge[220, 499] -> 
             RGBColor[
              0.2998159216660946, 0.42966675719263536`, 0.9404875702170554], 
             UndirectedEdge[359, 419] -> 
             RGBColor[
              0.44907089909255904`, 0.561772271120652, 0.9502808074967835], 
             UndirectedEdge[115, 297] -> 
             RGBColor[
              0.7202662947001824, 0.7803304830864486, 0.9738242280167566], 
             UndirectedEdge[155, 235] -> 
             RGBColor[
              0.4614654223098702, 0.5710633178486462, 0.9514696859030422], 
             UndirectedEdge[98, 261] -> 
             RGBColor[
              0.9376107771767181, 0.7700729496416561, 0.47213960027127755`], 
             UndirectedEdge[386, 421] -> 
             RGBColor[
              0.17899180289058533`, 0.3054621119467458, 0.9335046904287516], 
             UndirectedEdge[37, 58] -> 
             RGBColor[
              0.31037597127891847`, 0.44296664665046, 0.9410083743899482], 
             UndirectedEdge[71, 194] -> 
             RGBColor[
              0.8711488139703549, 0.898916809896938, 0.9247098602219754], 
             UndirectedEdge[47, 339] -> 
             RGBColor[
              0.22181216919966315`, 0.3504690319056196, 0.9359432469429985], 
             UndirectedEdge[108, 410] -> 
             RGBColor[
              0.32438785376155105`, 0.4532049421182389, 0.9419706976299311], 
             UndirectedEdge[193, 196] -> 
             RGBColor[
              0.29175552637074975`, 0.4239839349574104, 0.9399264176619675], 
             UndirectedEdge[131, 171] -> 
             RGBColor[
              0.26267563753313167`, 0.39341912801763035`, 0.9382703610125054],
              UndirectedEdge[203, 258] -> 
             RGBColor[
              0.45399453907585874`, 0.5654428931958693, 0.950758657973602], 
             UndirectedEdge[164, 428] -> 
             RGBColor[
              0.8239291026561835, 0.1849351455808791, 0.17054784176860438`], 
             UndirectedEdge[143, 325] -> 
             RGBColor[
              0.17897196085846667`, 0.30544125671293154`, 0.9335035604543761],
              UndirectedEdge[101, 498] -> 
             RGBColor[
              0.491361119566665, 0.5979481182872246, 0.9531008937288266], 
             UndirectedEdge[35, 391] -> 
             RGBColor[
              0.23974982774210207`, 0.3693226483469626, 0.9369647700606025], 
             UndirectedEdge[8, 221] -> 
             RGBColor[
              0.5784518548396522, 0.6686523005747489, 0.9599569954333912], 
             UndirectedEdge[240, 251] -> 
             RGBColor[
              0.25758537828186423`, 0.38806894280347104`, 0.9379804782785095],
              UndirectedEdge[464, 485] -> 
             RGBColor[
              0.24593397699878092`, 0.3758225813134415, 0.9373169482121415], 
             UndirectedEdge[104, 452] -> 
             RGBColor[
              0.2352635459876256, 0.36460728177631574`, 0.9367092829515442], 
             UndirectedEdge[121, 475] -> 
             RGBColor[
              0.8332346662535209, 0.256461785113985, 0.17945885997854572`], 
             UndirectedEdge[168, 315] -> 
             RGBColor[
              0.5481459181329882, 0.49816507299275914`, 0.5904774154442385], 
             UndirectedEdge[65, 320] -> 
             RGBColor[
              0.9870336626851595, 0.9760932232050978, 0.618291834936235], 
             UndirectedEdge[323, 452] -> 
             RGBColor[
              0.23164904535488023`, 0.3608082124387239, 0.9365034424876839], 
             UndirectedEdge[72, 322] -> 
             RGBColor[
              0.25660150329804876`, 0.38703482781420406`, 0.9379244480536938],
              UndirectedEdge[60, 327] -> 
             RGBColor[
              0.27488937913222444`, 0.40625654483422113`, 0.9389659155279624],
              UndirectedEdge[1, 135] -> 
             RGBColor[
              0.2583961289533292, 0.38892109316374235`, 0.9380266493298512], 
             UndirectedEdge[420, 439] -> 
             RGBColor[
              0.9147776569049322, 0.9340333582536569, 0.9622797424419812], 
             UndirectedEdge[134, 367] -> 
             RGBColor[
              0.23152572380893705`, 0.3606785936749, 0.9364964195080803], 
             UndirectedEdge[119, 345] -> 
             RGBColor[
              0.8251862844410536, 0.8622510331677843, 0.8856898202805965], 
             UndirectedEdge[64, 366] -> 
             RGBColor[
              0.27642037277284975`, 0.4078657162211217, 0.9390531033508938], 
             UndirectedEdge[86, 90] -> 
             RGBColor[
              0.8899814344584336, 0.5901544331035902, 0.2297467504579272], 
             UndirectedEdge[81, 426] -> 
             RGBColor[
              0.8468962698264015, 0.8807561134454687, 0.9852589163209091], 
             UndirectedEdge[70, 265] -> 
             RGBColor[
              0.28963233444531233`, 0.42061801847270397`, 0.9398470375642044],
              UndirectedEdge[245, 438] -> 
             RGBColor[
              0.22151371355788788`, 0.3501553361029332, 0.9359262503357249], 
             UndirectedEdge[121, 259] -> 
             RGBColor[
              0.8446533203330481, 0.33882677308300735`, 0.1901817771182239], 
             UndirectedEdge[74, 105] -> 
             RGBColor[
              0.2638196417670582, 0.3946215490015449, 0.938335510361225], 
             UndirectedEdge[358, 430] -> 
             RGBColor[
              0.23268261924121364`, 0.3618945641256297, 0.936562302991475], 
             UndirectedEdge[43, 316] -> 
             RGBColor[
              0.2718214258604257, 0.4030319314260883, 0.9387912001277635], 
             UndirectedEdge[162, 203] -> 
             RGBColor[
              0.4982990262412239, 0.6035806234747654, 0.9536470711566374], 
             UndirectedEdge[226, 236] -> 
             RGBColor[
              0.23337407460187973`, 0.3626213275504917, 0.9366016803513484], 
             UndirectedEdge[110, 340] -> 
             RGBColor[
              0.3045749314378675, 0.43480548891742876`, 0.9407535831342266], 
             UndirectedEdge[145, 407] -> 
             RGBColor[
              0.2175082544444818, 0.34594534461396753`, 0.9356981453647621], 
             UndirectedEdge[258, 289] -> 
             RGBColor[
              0.4063967473847854, 0.5264221693154291, 0.9471162192741931], 
             UndirectedEdge[13, 334] -> 
             RGBColor[
              0.3497101697631252, 0.47620162767835794`, 0.94354526344998], 
             UndirectedEdge[300, 389] -> 
             RGBColor[
              0.2222287148930997, 0.35090684783994386`, 0.9359669686040155], 
             UndirectedEdge[57, 363] -> 
             RGBColor[
              0.5030271726289528, 0.6061020766435601, 0.9543831982681161], 
             UndirectedEdge[305, 427] -> 
             RGBColor[
              0.26530600013852146`, 0.3961838058905166, 0.9384201562716097], 
             UndirectedEdge[277, 419] -> 
             RGBColor[
              0.6419960336426249, 0.718265092425402, 0.9663099050077802], 
             UndirectedEdge[40, 349] -> 
             RGBColor[
              0.3999008136180363, 0.5207957179817955, 0.9467023041187045], 
             UndirectedEdge[28, 241] -> 
             RGBColor[
              0.8351691071867402, 0.8715787875296648, 0.9578266018325254], 
             UndirectedEdge[164, 396] -> 
             RGBColor[
              0.9055353853140414, 0.5621560872497313, 0.3516608883245811], 
             UndirectedEdge[111, 284] -> 
             RGBColor[
              0.2590919383322233, 0.3896524329378227, 0.9380662746446216], 
             UndirectedEdge[25, 343] -> 
             RGBColor[
              0.3031313951145783, 0.4355126855320067, 0.9405899280547156], 
             UndirectedEdge[84, 131] -> 
             RGBColor[
              0.24846167161057395`, 0.3784793486155308, 0.9374608966808939], 
             UndirectedEdge[169, 244] -> 
             RGBColor[
              0.4175916065853016, 0.5350481346501237, 0.9481253168239769], 
             UndirectedEdge[219, 363] -> 
             RGBColor[
              0.4655401284489993, 0.5756684054061787, 0.9514320808307029], 
             UndirectedEdge[400, 415] -> 
             RGBColor[
              0.2914672574254832, 0.4236809460186285, 0.9399100011719903], 
             UndirectedEdge[248, 286] -> 
             RGBColor[
              0.23281996068137648`, 0.36203891868719107`, 0.9365701243833138],
              UndirectedEdge[136, 484] -> 
             RGBColor[
              0.980926180317411, 0.981787940062676, 0.7025545645628573], 
             UndirectedEdge[74, 263] -> 
             RGBColor[
              0.27756733242056764`, 0.40907124353231517`, 0.9391184210060566],
              UndirectedEdge[69, 142] -> 
             RGBColor[
              0.8044934065793106, 0.8479188521576653, 0.9809561216743297], 
             UndirectedEdge[109, 409] -> 
             RGBColor[
              0.24775783308986035`, 0.3777395697043211, 0.9374208141183751], 
             UndirectedEdge[101, 219] -> 
             RGBColor[
              0.5235508135187052, 0.6240811619666777, 0.9556349843514654], 
             UndirectedEdge[380, 390] -> 
             RGBColor[
              0.2868022644003798, 0.4187777425716037, 0.9396443367204493], 
             UndirectedEdge[53, 293] -> 
             RGBColor[
              0.9653923096103165, 0.9489247911355639, 0.6627722008261114], 
             UndirectedEdge[221, 258] -> 
             RGBColor[
              0.45501626161494246`, 0.5662723735811732, 0.9508390917145717], 
             UndirectedEdge[235, 424] -> 
             RGBColor[
              0.3388180779328382, 0.46788892243883967`, 0.9428101662141861], 
             UndirectedEdge[367, 457] -> 
             RGBColor[
              0.22571706608911693`, 0.3545733261211982, 0.9361656250440755], 
             UndirectedEdge[58, 220] -> 
             RGBColor[
              0.32701247471585293`, 0.45766350229915764`, 0.9420579236164848],
              UndirectedEdge[334, 379] -> 
             RGBColor[
              0.3560516389210633, 0.4828157667828796, 0.9439082734813162], 
             UndirectedEdge[14, 163] -> 
             RGBColor[
              0.2868674954285888, 0.4188463045181374, 0.9396480515310051], 
             UndirectedEdge[284, 442] -> 
             RGBColor[
              0.26451897986036277`, 0.3953565976782041, 0.9383753366310607], 
             UndirectedEdge[130, 302] -> 
             RGBColor[
              0.18453817917078433`, 0.311291705077802, 0.9338205483527805], 
             UndirectedEdge[65, 428] -> 
             RGBColor[
              0.9078991618741388, 0.5983968558388272, 0.2873573629313444], 
             UndirectedEdge[388, 487] -> 
             RGBColor[
              0.7628017392959624, 0.8144116714200249, 0.9680174393113103], 
             UndirectedEdge[456, 458] -> 
             RGBColor[
              0.22707889219219896`, 0.35600469170029936`, 0.9362431790260048],
              UndirectedEdge[281, 465] -> 
             RGBColor[
              0.26376712193927254`, 0.39456634733259277`, 0.9383325194347287],
              UndirectedEdge[166, 428] -> 
             RGBColor[
              0.8342269539589475, 0.26408894324113896`, 0.18040907580589088`],
              UndirectedEdge[92, 128] -> 
             RGBColor[
              0.5519404005403256, 0.6471291076471498, 0.9578699166362912], 
             UndirectedEdge[120, 457] -> 
             RGBColor[
              0.21450528797873675`, 0.3427890364593986, 0.9355271308670288], 
             UndirectedEdge[79, 329] -> 
             RGBColor[
              0.9381932995999778, 0.9492001435332333, 0.7791661244013025], 
             UndirectedEdge[105, 195] -> 
             RGBColor[
              0.2580285978828387, 0.38853479470584096`, 0.9380057189791005], 
             UndirectedEdge[98, 377] -> 
             RGBColor[
              0.9881699242791049, 0.9888223570121889, 0.8197885510745015], 
             UndirectedEdge[21, 309] -> 
             RGBColor[
              0.9869592653755547, 0.967346961753188, 0.4315364838739727], 
             UndirectedEdge[93, 322] -> 
             RGBColor[
              0.26425191426448674`, 0.3950758948040016, 0.9383601276404636], 
             UndirectedEdge[8, 115] -> 
             RGBColor[
              0.7707310045144475, 0.8213000079229384, 0.9777969948316587], 
             UndirectedEdge[54, 131] -> 
             RGBColor[
              0.24616492351091418`, 0.3760653207405481, 0.9373301002743527], 
             UndirectedEdge[186, 212] -> 
             RGBColor[
              0.22711333090057176`, 0.3560408889663394, 0.9362451402594992], 
             UndirectedEdge[252, 467] -> 
             RGBColor[
              0.7213175895970523, 0.7822180503007243, 0.9728578543010624], 
             UndirectedEdge[244, 378] -> 
             RGBColor[
              0.3127627275114677, 0.4429484996474682, 0.9412368143882763], 
             UndirectedEdge[55, 339] -> 
             RGBColor[
              0.21158417509033906`, 0.33971876160443837`, 0.9353607778094337],
              UndirectedEdge[69, 490] -> 
             RGBColor[
              0.9500080335378767, 0.9605032008441318, 0.8987210231001681], 
             UndirectedEdge[299, 451] -> 
             RGBColor[
              0.21030609728277713`, 0.3383754207938774, 0.9352879931690398], 
             UndirectedEdge[146, 464] -> 
             RGBColor[
              0.25089999678857744`, 0.38104218297635795`, 0.9375997556926023],
              UndirectedEdge[199, 220] -> 
             RGBColor[
              0.3408785418830542, 0.4696735927505875, 0.9429414571550971], 
             UndirectedEdge[345, 426] -> 
             RGBColor[
              0.7649497936964772, 0.8167095300211071, 0.9770990522255436], 
             UndirectedEdge[66, 472] -> 
             RGBColor[
              0.29586389462338253`, 0.42648062461240877`, 0.9402270759441249],
              UndirectedEdge[40, 114] -> 
             RGBColor[
              0.443439320562669, 0.5572206362112937, 0.9498318505944043], 
             UndirectedEdge[248, 294] -> 
             RGBColor[
              0.240426199543799, 0.37003355799499527`, 0.9370032884341067], 
             UndirectedEdge[304, 483] -> 
             RGBColor[
              0.3176066092257016, 0.44839817992769826`, 0.941499541548237], 
             UndirectedEdge[9, 425] -> 
             RGBColor[
              0.47524326414852586`, 0.5827457090080587, 0.9524170280286233], 
             UndirectedEdge[290, 384] -> 
             RGBColor[
              0.2851530200769201, 0.4170442822195179, 0.9395504146960666], 
             UndirectedEdge[294, 358] -> 
             RGBColor[
              0.23196947764628847`, 0.36114500709357467`, 0.9365216906326425],
              UndirectedEdge[148, 342] -> 
             RGBColor[
              0.2498214928286487, 0.3799086069333723, 0.9375383364875882], 
             UndirectedEdge[178, 420] -> 
             RGBColor[
              0.9801637329335828, 0.9834819259202605, 0.8627171585529716], 
             UndirectedEdge[193, 354] -> 
             RGBColor[
              0.3247877807995152, 0.4538010668360344, 0.941987036861071], 
             UndirectedEdge[194, 228] -> 
             RGBColor[
              0.9897986964683487, 0.9881510016226367, 0.6807237889593197], 
             UndirectedEdge[326, 491] -> 
             RGBColor[
              0.9346684716417725, 0.7580015966571071, 0.4117209054738351], 
             UndirectedEdge[324, 481] -> 
             RGBColor[
              0.3439470735768655, 0.47233140067487944`, 0.9431369812812307], 
             UndirectedEdge[94, 213] -> 
             RGBColor[
              0.9298124883323949, 0.8120876909328425, 0.6010637208876998], 
             UndirectedEdge[92, 175] -> 
             RGBColor[
              0.7824339265203888, 0.8300343229197356, 0.9610969915433571], 
             UndirectedEdge[254, 401] -> 
             RGBColor[
              0.50497531356463, 0.5944255881948143, 0.9574168801184721], 
             UndirectedEdge[161, 491] -> 
             RGBColor[
              0.992246695040947, 0.9844848921088973, 0.5114139987289448], 
             UndirectedEdge[172, 303] -> 
             RGBColor[
              0.32845548787730483`, 0.4585909264869045, 0.9421616772940785], 
             UndirectedEdge[57, 274] -> 
             RGBColor[
              0.5319886243671207, 0.6309313569324684, 0.9562992397301722], 
             UndirectedEdge[44, 360] -> 
             RGBColor[
              0.5380217860131518, 0.6358293493475512, 0.9567741923151472], 
             UndirectedEdge[170, 238] -> 
             RGBColor[
              0.3084172446419511, 0.44044171708200675`, 0.940913897073925], 
             UndirectedEdge[5, 11] -> 
             RGBColor[
              0.23876273655839006`, 0.3682851529276855, 0.9369085566779607], 
             UndirectedEdge[3, 223] -> 
             RGBColor[
              0.4257649092191724, 0.5429712289379067, 0.9484129706530855], 
             UndirectedEdge[65, 227] -> 
             RGBColor[
              0.9155479974276244, 0.657189157644029, 0.2946818964954864], 
             UndirectedEdge[78, 85] -> 
             RGBColor[
              0.21682232686548605`, 0.34522439123812265`, 0.9356590828038773],
              UndirectedEdge[181, 393] -> 
             RGBColor[
              0.4409543407183537, 0.5561398931308579, 0.9493774176456293], 
             UndirectedEdge[45, 56] -> 
             RGBColor[
              0.5597280401148761, 0.3487238439697099, 0.5610837052268939], 
             UndirectedEdge[141, 310] -> 
             RGBColor[
              0.3031699755874952, 0.4359038694979436, 0.9405792867476138], 
             UndirectedEdge[39, 236] -> 
             RGBColor[
              0.4554923722273556, 0.5623404159424226, 0.9515950359894985], 
             UndirectedEdge[337, 375] -> 
             RGBColor[
              0.9092060692572821, 0.9298599802312014, 0.9710835499900707], 
             UndirectedEdge[57, 334] -> 
             RGBColor[
              0.5020235331688498, 0.6052327745876049, 0.9543192472492019], 
             UndirectedEdge[123, 438] -> 
             RGBColor[
              0.21421403684205725`, 0.34248291304835987`, 0.9355105445456623],
              UndirectedEdge[35, 385] -> 
             RGBColor[
              0.235922007593164, 0.36529936667261376`, 0.936746781365873], 
             UndirectedEdge[268, 285] -> 
             RGBColor[
              0.3620365603618595, 0.4879996049239992, 0.9442896273832655], 
             UndirectedEdge[169, 361] -> 
             RGBColor[
              0.5684718159304661, 0.6605218314458838, 0.9591906270789168], 
             UndirectedEdge[337, 361] -> 
             RGBColor[
              0.752206073850372, 0.8066735064022713, 0.9758502482621753], 
             UndirectedEdge[119, 270] -> 
             RGBColor[
              0.9903352312511376, 0.9902713839961873, 0.8098337599957988], 
             UndirectedEdge[254, 386] -> 
             RGBColor[
              0.20771262472504887`, 0.3356495167000475, 0.935140298743576], 
             UndirectedEdge[253, 488] -> 
             RGBColor[
              0.877198073649208, 0.9039154021300979, 0.937685633244106], 
             UndirectedEdge[340, 380] -> 
             RGBColor[
              0.3051428116901297, 0.43540236706824387`, 0.9407859230744895], 
             UndirectedEdge[388, 490] -> 
             RGBColor[
              0.9683628300119925, 0.9748687448836537, 0.8911081388957877], 
             UndirectedEdge[27, 311] -> 
             RGBColor[
              0.6294878924283578, 0.7084848809709354, 0.9650691972348303], 
             UndirectedEdge[222, 417] -> 
             RGBColor[
              0.5718731828738293, 0.6621247011020224, 0.9601331729684849], 
             UndirectedEdge[274, 361] -> 
             RGBColor[
              0.5534678542610545, 0.6483409394418851, 0.9580094602549781], 
             UndirectedEdge[65, 474] -> 
             RGBColor[
              0.989280991001634, 0.9770225512176633, 0.5810477888330006], 
             UndirectedEdge[243, 326] -> 
             RGBColor[
              0.8572408103331092, 0.41460626615910345`, 0.2014143032349089], 
             UndirectedEdge[47, 437] -> 
             RGBColor[
              0.2438820574631478, 0.37366588378227833`, 0.93720009443013], 
             UndirectedEdge[232, 414] -> 
             RGBColor[
              0.31542779716347613`, 0.44447776538926564`, 0.9414351563383871],
              UndirectedEdge[102, 196] -> 
             RGBColor[
              0.28611844580431445`, 0.41805900587053585`, 0.9396053942630224],
              UndirectedEdge[90, 257] -> 
             RGBColor[
              0.8618116052496472, 0.4654005988057779, 0.20640455492384144`], 
             UndirectedEdge[116, 310] -> 
             RGBColor[
              0.2727415097182925, 0.40399899789739224`, 0.9388435975423268], 
             UndirectedEdge[333, 459] -> 
             RGBColor[
              0.3845976264069504, 0.5075408663801063, 0.9457271985616913], 
             UndirectedEdge[68, 257] -> 
             RGBColor[
              0.8394199460541523, 0.30329924422110266`, 0.18535427265779897`],
              UndirectedEdge[220, 349] -> 
             RGBColor[
              0.3762573378366486, 0.5003169276156031, 0.9451957627490192], 
             UndirectedEdge[92, 204] -> 
             RGBColor[
              0.5555153199743827, 0.6500313882920026, 0.9581513473895016], 
             UndirectedEdge[120, 123] -> 
             RGBColor[
              0.20719251066229882`, 0.33510284384296096`, 0.9351106790171422],
              UndirectedEdge[190, 224] -> 
             RGBColor[
              0.2735379552710175, 0.40483611267087094`, 0.938888953938319], 
             UndirectedEdge[450, 469] -> 
             RGBColor[
              0.8390695807149537, 0.298125435533924, 0.18492162257597716`], 
             UndirectedEdge[405, 434] -> 
             RGBColor[
              0.9926076308918226, 0.9901160572249841, 0.6925776468321798], 
             UndirectedEdge[312, 400] -> 
             RGBColor[
              0.30016668312241634`, 0.43282459400155193`, 0.9404054205957836],
              UndirectedEdge[100, 259] -> 
             RGBColor[
              0.8965277758950481, 0.6152647749950997, 0.2349704456547408], 
             UndirectedEdge[87, 423] -> 
             RGBColor[
              0.18353957668712906`, 0.310242110552426, 0.9337636794186364], 
             UndirectedEdge[403, 449] -> 
             RGBColor[
              0.8286073759188407, 0.8669140710830616, 0.9833178599894938], 
             UndirectedEdge[268, 275] -> 
             RGBColor[
              0.4116793705742366, 0.5309977120097701, 0.9474528233525847], 
             UndirectedEdge[166, 210] -> 
             RGBColor[
              0.8370920629652436, 0.28611142656230293`, 0.18315270742599782`],
              UndirectedEdge[102, 496] -> 
             RGBColor[
              0.27671354998693043`, 0.4081738640616296, 0.9390697993595188], 
             UndirectedEdge[11, 202] -> 
             RGBColor[
              0.2389875961328362, 0.3685214945973489, 0.9369213620980754], 
             UndirectedEdge[187, 494] -> 
             RGBColor[
              0.26156581469201307`, 0.3922526338447824, 0.9382071582435395], 
             UndirectedEdge[158, 282] -> 
             RGBColor[
              0.4825898599888707, 0.5882261104425313, 0.9531290808792493], 
             UndirectedEdge[232, 372] -> 
             RGBColor[
              0.41332534927572523`, 0.5319581186500844, 0.9476862556607386], 
             UndirectedEdge[143, 477] -> 
             RGBColor[
              0.21179931439321417`, 0.33994488665237976`, 0.9353730296744625],
              UndirectedEdge[479, 482] -> 
             RGBColor[
              0.3849860560945393, 0.5078773046524521, 0.9457519489579096], 
             UndirectedEdge[45, 283] -> 
             RGBColor[
              0.23199831546813182`, 0.3611753174727555, 0.9365233329039347], 
             UndirectedEdge[323, 463] -> 
             RGBColor[
              0.25322101360276406`, 0.3834817188090337, 0.9377319341665338], 
             UndirectedEdge[130, 347] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[338, 369] -> 
             RGBColor[
              0.37002637582951403`, 0.49491998150227967`, 0.9447987313597479],
              UndirectedEdge[143, 386] -> 
             RGBColor[
              0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772],
              UndirectedEdge[168, 254] -> 
             RGBColor[
              0.5736452347236608, 0.5249664714796068, 0.591929563801219], 
             UndirectedEdge[86, 115] -> 
             RGBColor[
              0.9181807358610004, 0.8207272885954675, 0.6214818156174652], 
             UndirectedEdge[138, 457] -> 
             RGBColor[
              0.22077773189024535`, 0.349381772706308, 0.9358843372685399], 
             UndirectedEdge[11, 497] -> 
             RGBColor[
              0.2374558873234022, 0.36691157152268605`, 0.9368341335473384], 
             UndirectedEdge[154, 379] -> 
             RGBColor[
              0.3094202014132221, 0.4424259593777846, 0.9409369595178776], 
             UndirectedEdge[17, 467] -> 
             RGBColor[
              0.7934052123801664, 0.8390183037645371, 0.979914209324252], 
             UndirectedEdge[75, 93] -> 
             RGBColor[
              0.30711689507265494`, 0.43678253795558514`, 0.940923781155411], 
             UndirectedEdge[100, 315] -> 
             RGBColor[
              0.5583572344294613, 0.5386495393888345, 0.5986936802267802], 
             UndirectedEdge[45, 52] -> 
             RGBColor[
              0.5592887582023336, 0.3453473306953461, 0.5606630483713451], 
             UndirectedEdge[8, 203] -> 
             RGBColor[
              0.5774301323005686, 0.6678228201894449, 0.9598765616924215], 
             UndirectedEdge[244, 340] -> 
             RGBColor[
              0.33993779537767665`, 0.4688587654109236, 0.9428815136196439], 
             UndirectedEdge[104, 190] -> 
             RGBColor[
              0.24734164292075334`, 0.3773021274486088, 0.9373971127039427], 
             UndirectedEdge[38, 437] -> 
             RGBColor[
              0.2578995688543769, 0.3883991770160148, 0.9379983709668107], 
             UndirectedEdge[96, 465] -> 
             RGBColor[
              0.2893936582907169, 0.42150146185421045`, 0.9397919127688803], 
             UndirectedEdge[48, 346] -> 
             RGBColor[
              0.21269676667826953`, 0.34088816590573434`, 0.9354241382544346],
              UndirectedEdge[153, 342] -> 
             RGBColor[
              0.25246005368067864`, 0.38268190168327626`, 0.9376885986247103],
              UndirectedEdge[151, 327] -> 
             RGBColor[
              0.28193174194509296`, 0.41365851466213766`, 0.939366967671913], 
             UndirectedEdge[375, 489] -> 
             RGBColor[
              0.9741495163492516, 0.9792601983573855, 0.8847051301265769], 
             UndirectedEdge[203, 289] -> 
             RGBColor[
              0.48696884397226536`, 0.5940035787603833, 0.9528597515235682], 
             UndirectedEdge[6, 79] -> 
             RGBColor[
              0.9107592672849488, 0.9273249908421985, 0.7765494419084453], 
             UndirectedEdge[105, 463] -> 
             RGBColor[
              0.2565013158137106, 0.3869295244159112, 0.9379187425246749], 
             UndirectedEdge[10, 125] -> 
             RGBColor[
              0.21381800062875955`, 0.3420666538780378, 0.935487990869198], 
             UndirectedEdge[32, 331] -> 
             RGBColor[
              0.6862012136677067, 0.7532861971667737, 0.9704389262848694], 
             UndirectedEdge[26, 44] -> 
             RGBColor[
              0.4416533932183588, 0.5557823986053863, 0.949688034527277], 
             UndirectedEdge[86, 253] -> 
             RGBColor[
              0.9501124692155603, 0.8447770986590462, 0.5741725699000219], 
             UndirectedEdge[370, 466] -> 
             RGBColor[
              0.5474757553674385, 0.6435045075658272, 0.9575184434137474], 
             UndirectedEdge[301, 456] -> 
             RGBColor[
              0.21620560443164671`, 0.3445761768576967, 0.9356239613736292], 
             UndirectedEdge[21, 337] -> 
             RGBColor[
              0.9205492329643337, 0.9192823831910986, 0.6833909335036439], 
             UndirectedEdge[61, 172] -> 
             RGBColor[
              0.3377395733706075, 0.4669547759942509, 0.9427414448571648], 
             UndirectedEdge[291, 359] -> 
             RGBColor[
              0.5201892016597764, 0.619316785102851, 0.95601113315619], 
             UndirectedEdge[134, 499] -> 
             RGBColor[
              0.2469625122439105, 0.37690363706897373`, 0.93737552177277], 
             UndirectedEdge[140, 244] -> 
             RGBColor[
              0.42103754660959536`, 0.5378457039996745, 0.9483965938455836], 
             UndirectedEdge[108, 364] -> 
             RGBColor[
              0.27183868506633, 0.4030500719457907, 0.938792183014007], 
             UndirectedEdge[113, 421] -> 
             RGBColor[
              0.17912443323835392`, 0.3056015148515002, 0.9335122435308479], 
             UndirectedEdge[54, 55] -> 
             RGBColor[
              0.22009923076516985`, 0.34866862500439766`, 0.9358456976332195],
              UndirectedEdge[56, 210] -> 
             RGBColor[
              0.8363686612775614, 0.28055104419413623`, 0.18245997715290796`],
              UndirectedEdge[36, 58] -> 
             RGBColor[
              0.28475051663686596`, 0.4160326690739975, 0.9395490426575464], 
             UndirectedEdge[25, 288] -> 
             RGBColor[
              0.2847205959795895, 0.4161617683290476, 0.9395414602803146], 
             UndirectedEdge[262, 344] -> 
             RGBColor[
              0.4699143971667351, 0.5805367028791276, 0.9514125291795714], 
             UndirectedEdge[8, 439] -> 
             RGBColor[
              0.7406030565482964, 0.7972768000160912, 0.9749233642591105], 
             UndirectedEdge[102, 186] -> 
             RGBColor[
              0.256123983487738, 0.3865329242170628, 0.9378972540069239], 
             UndirectedEdge[85, 145] -> 
             RGBColor[
              0.21743686076267443`, 0.3458703053277671, 0.9356940796002007], 
             UndirectedEdge[421, 423] -> 
             RGBColor[
              0.18344124862659156`, 0.31013876152644193`, 0.9337580797810521],
              UndirectedEdge[406, 476] -> 
             RGBColor[
              0.9195554041525527, 0.6768776802935997, 0.3060621599750899], 
             UndirectedEdge[111, 400] -> 
             RGBColor[
              0.2845065356159251, 0.4163647860615299, 0.939513598362401], 
             UndirectedEdge[137, 183] -> 
             RGBColor[
              0.2125239415632086, 0.34070651575206007`, 0.9354142961198038], 
             UndirectedEdge[85, 358] -> 
             RGBColor[
              0.2199208837213561, 0.34848117095349374`, 0.935835541032915], 
             UndirectedEdge[399, 412] -> 
             RGBColor[
              0.24194122045751632`, 0.37162594103318614`, 0.9370895666338703],
              UndirectedEdge[283, 292] -> 
             RGBColor[
              0.18009239570445779`, 0.3066189047757405, 0.9335673675613205], 
             UndirectedEdge[240, 310] -> 
             RGBColor[
              0.2766913122921885, 0.4081504908345045, 0.939068532955701], 
             UndirectedEdge[186, 300] -> 
             RGBColor[
              0.23083402862066274`, 0.35995157817601575`, 0.9364570284903794],
              UndirectedEdge[37, 240] -> 
             RGBColor[
              0.28113287624005423`, 0.4128188561551308, 0.9393214734518269], 
             UndirectedEdge[36, 429] -> 
             RGBColor[
              0.2739936283843697, 0.4053150540043482, 0.9389149038480165], 
             UndirectedEdge[56, 276] -> 
             RGBColor[
              0.7281068824339767, 0.4924523185511463, 0.5729718060098814], 
             UndirectedEdge[95, 174] -> 
             RGBColor[
              0.24687001390337449`, 0.3768064154483368, 0.9373702541291156], 
             UndirectedEdge[7, 28] -> 
             RGBColor[
              0.901769090567154, 0.9237583305634441, 0.9644245605513657], 
             UndirectedEdge[251, 367] -> 
             RGBColor[
              0.24419513183599667`, 0.3739949447982042, 0.9372179235525118], 
             UndirectedEdge[31, 314] -> 
             RGBColor[
              0.3915568678230763, 0.5135686115131106, 0.9461706352709112], 
             UndirectedEdge[238, 436] -> 
             RGBColor[
              0.3965368671240651, 0.5173498014044343, 0.9466350145946033], 
             UndirectedEdge[291, 488] -> 
             RGBColor[
              0.7121457205579194, 0.7750529164985673, 0.971943688111231], 
             UndirectedEdge[96, 171] -> 
             RGBColor[
              0.2789519797924134, 0.41052659571183897`, 0.939197274625481], 
             UndirectedEdge[127, 179] -> 
             RGBColor[
              0.20245447418328588`, 0.33012286709465477`, 0.9348408548489592],
              UndirectedEdge[296, 453] -> 
             RGBColor[
              0.2988633264806147, 0.4310225569001501, 0.9403470186360454], 
             UndirectedEdge[14, 494] -> 
             RGBColor[
              0.2826231066390982, 0.4143851827905905, 0.9394063398684542], 
             UndirectedEdge[317, 420] -> 
             RGBColor[
              0.9260215766566631, 0.7697821905786719, 0.5811912001414211], 
             UndirectedEdge[7, 388] -> 
             RGBColor[
              0.8924271040987608, 0.9167910923514154, 0.9802381068620604], 
             UndirectedEdge[146, 271] -> 
             RGBColor[
              0.25686927492861433`, 0.3873162727756304, 0.9379396972519218], 
             UndirectedEdge[331, 449] -> 
             RGBColor[
              0.7824972356635673, 0.8301470968699212, 0.9789198336489376], 
             UndirectedEdge[27, 359] -> 
             RGBColor[
              0.44878508964320496`, 0.5615402381340974, 0.9502583075299758], 
             UndirectedEdge[100, 471] -> 
             RGBColor[
              0.894013717811025, 0.6013444138663678, 0.23277457969666004`], 
             UndirectedEdge[219, 337] -> 
             RGBColor[
              0.6932397997764845, 0.7588302526554731, 0.971188910299956], 
             UndirectedEdge[199, 419] -> 
             RGBColor[
              0.4277672068152066, 0.5433200836247167, 0.948923355062986], 
             UndirectedEdge[266, 437] -> 
             RGBColor[
              0.2726756027922651, 0.40392972553939704`, 0.9388398442403902], 
             UndirectedEdge[327, 399] -> 
             RGBColor[
              0.24928505714751653`, 0.3793447790205158, 0.9375077872691331], 
             UndirectedEdge[311, 419] -> 
             RGBColor[
              0.6297737018777119, 0.70871691395749, 0.9650916972016379], 
             UndirectedEdge[267, 329] -> 
             RGBColor[
              0.9358102453449542, 0.941979730786866, 0.7003355368972839], 
             UndirectedEdge[219, 244] -> 
             RGBColor[
              0.43435496414043395`, 0.548657383494032, 0.949444989736919], 
             UndirectedEdge[17, 205] -> 
             RGBColor[
              0.9368989095333399, 0.9481665884975428, 0.7789256469520753], 
             UndirectedEdge[175, 361] -> 
             RGBColor[
              0.7999658560018515, 0.8442393091304512, 0.9624964661202554], 
             UndirectedEdge[189, 266] -> 
             RGBColor[
              0.2746480537102089, 0.4060028965147674, 0.9389521724021874], 
             UndirectedEdge[225, 280] -> 
             RGBColor[
              0.26557083518380836`, 0.39646216431462483`, 0.9384352382356503],
              UndirectedEdge[300, 458] -> 
             RGBColor[
              0.22822845140871784`, 0.35721295132312475`, 0.9363086447227651],
              UndirectedEdge[171, 343] -> 
             RGBColor[
              0.2773148667291586, 0.40880588608339485`, 0.9391040434584204], 
             UndirectedEdge[358, 408] -> 
             RGBColor[
              0.2240653730927813, 0.35283729205866493`, 0.936071563571395], 
             UndirectedEdge[380, 411] -> 
             RGBColor[
              0.2562205129796168, 0.38663438283335066`, 0.9379027512186837], 
             UndirectedEdge[345, 498] -> 
             RGBColor[
              0.5608073530060538, 0.6540616711594758, 0.9587498403781267], 
             UndirectedEdge[161, 450] -> 
             RGBColor[
              0.9040202207813182, 0.5580851531997648, 0.2907664410126593], 
             UndirectedEdge[94, 214] -> 
             RGBColor[
              0.5776130969249946, 0.6468062636067821, 0.9475190708650497], 
             UndirectedEdge[157, 343] -> 
             RGBColor[
              0.2977155588527831, 0.4302483069839126, 0.9402658326947413], 
             UndirectedEdge[155, 332] -> 
             RGBColor[
              0.4840405870433834, 0.5906167908800439, 0.9529081554374272], 
             UndirectedEdge[127, 168] -> 
             RGBColor[
              0.5683860156508949, 0.5194386987803812, 0.5916300590553423], 
             UndirectedEdge[378, 380] -> 
             RGBColor[
              0.27796774382392075`, 0.40949210130478847`, 0.939141223843122], 
             UndirectedEdge[160, 481] -> 
             RGBColor[
              0.3703492229848604, 0.49519961548147085`, 0.9448193028950042], 
             UndirectedEdge[23, 485] -> 
             RGBColor[
              0.2352513492635514, 0.3645944622459968, 0.9367085883661517], 
             UndirectedEdge[352, 399] -> 
             RGBColor[
              0.23466592421327268`, 0.3639791434000619, 0.936675249275597], 
             UndirectedEdge[389, 456] -> 
             RGBColor[
              0.22107915567658082`, 0.3496985882171184, 0.9359015029072553], 
             UndirectedEdge[105, 263] -> 
             RGBColor[
              0.2596529612026372, 0.3902421035455322, 0.9380982240671327], 
             UndirectedEdge[143, 347] -> 
             RGBColor[
              0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772],
              UndirectedEdge[98, 484] -> 
             RGBColor[
              0.9940632182259341, 0.9897101490230129, 0.5951961253421731], 
             UndirectedEdge[100, 500] -> 
             RGBColor[
              0.8753537574413516, 0.45791578161828494`, 0.21490578057324983`],
              UndirectedEdge[89, 424] -> 
             RGBColor[
              0.3030480744366626, 0.4347576504686087, 0.9406096220363795], 
             UndirectedEdge[231, 442] -> 
             RGBColor[
              0.2711958428958343, 0.40237440406605196`, 0.938755574103397], 
             UndirectedEdge[15, 104] -> 
             RGBColor[
              0.24040623048550225`, 0.3700125692486139, 0.9370021512257783], 
             UndirectedEdge[75, 182] -> 
             RGBColor[
              0.3617675856264607, 0.48776663252726005`, 0.9442724885509708], 
             UndirectedEdge[290, 316] -> 
             RGBColor[
              0.268490139738015, 0.3995305384956953, 0.9386014883112883], 
             UndirectedEdge[344, 424] -> 
             RGBColor[
              0.39216870621134226`, 0.5138154925134429, 0.9462878321282429], 
             UndirectedEdge[369, 425] -> 
             RGBColor[
              0.397645136695217, 0.5188419640048679, 0.9465585743797993], 
             UndirectedEdge[106, 255] -> 
             RGBColor[
              0.45772043203322, 0.569123825312507, 0.9508706958509441], 
             UndirectedEdge[84, 242] -> 
             RGBColor[
              0.22916096004104347`, 0.3581930770201611, 0.9363617497098533], 
             UndirectedEdge[143, 446] -> 
             RGBColor[
              0.20353913733189777`, 0.3312629168354616, 0.9349026248106573], 
             UndirectedEdge[376, 415] -> 
             RGBColor[
              0.28323389332621046`, 0.41502715832485815`, 0.9394411232667073],
              UndirectedEdge[93, 108] -> 
             RGBColor[
              0.27719798724909794`, 0.408683038339264, 0.9390973873449386], 
             UndirectedEdge[78, 183] -> 
             RGBColor[
              0.21219822021020854`, 0.34036416195813046`, 0.935395746770612], 
             UndirectedEdge[17, 298] -> 
             RGBColor[
              0.8908055349705915, 0.9157681695861948, 0.9894470212286257], 
             UndirectedEdge[204, 370] -> 
             RGBColor[
              0.546668194471859, 0.642848893250592, 0.9574548692618543], 
             UndirectedEdge[208, 314] -> 
             RGBColor[
              0.32609699892407057`, 0.4568705631814669, 0.9419995903085558], 
             UndirectedEdge[313, 379] -> 
             RGBColor[
              0.288128547073246, 0.4201206026991259, 0.9397217393007642], 
             UndirectedEdge[3, 221] -> 
             RGBColor[
              0.4991380572062573, 0.6042617866100937, 0.9537131227476765], 
             UndirectedEdge[154, 229] -> 
             RGBColor[
              0.3002585012900294, 0.4328475787158096, 0.940413341505228], 
             UndirectedEdge[25, 180] -> 
             RGBColor[
              0.2917531123703574, 0.42355338894303707`, 0.9399419516850931], 
             UndirectedEdge[371, 419] -> 
             RGBColor[
              0.43781722710861815`, 0.5520249060741627, 0.9495637334691982], 
             UndirectedEdge[31, 419] -> 
             RGBColor[
              0.4828643991449212, 0.5910425023553091, 0.9524340994377012], 
             UndirectedEdge[321, 482] -> 
             RGBColor[
              0.3458284457686297, 0.47396095070686983`, 0.9432568606536578], 
             UndirectedEdge[212, 300] -> 
             RGBColor[
              0.22223694937519295`, 0.35091550280272016`, 0.9359674375455889],
              UndirectedEdge[376, 414] -> 
             RGBColor[
              0.27705653417076703`, 0.40853436218529504`, 0.9390893318013886],
              UndirectedEdge[140, 274] -> 
             RGBColor[
              0.4811841626563286, 0.5896860062007292, 0.9522997264014235], 
             UndirectedEdge[1, 131] -> 
             RGBColor[
              0.26488726968740706`, 0.3957436936373514, 0.9383963101918749], 
             UndirectedEdge[360, 466] -> 
             RGBColor[
              0.5414372478398441, 0.638602175123262, 0.9570430699813932], 
             UndirectedEdge[165, 182] -> 
             RGBColor[
              0.4013099579800705, 0.5220162480025345, 0.9467920935513959], 
             UndirectedEdge[268, 480] -> 
             RGBColor[
              0.3816010072146523, 0.5049453454501976, 0.9455362566365644], 
             UndirectedEdge[54, 385] -> 
             RGBColor[
              0.23109619211781043`, 0.36022712863364376`, 0.9364719583137058],
              UndirectedEdge[149, 158] -> 
             RGBColor[
              0.3556980515257828, 0.48250950715290686`, 0.943885743205154], 
             UndirectedEdge[229, 379] -> 
             RGBColor[
              0.30013749915285226`, 0.43274277274633094`, 0.9404056313560452],
              UndirectedEdge[98, 253] -> 
             RGBColor[
              0.9901332923121124, 0.9901471046097305, 0.8102166844391167], 
             UndirectedEdge[121, 469] -> 
             RGBColor[
              0.8439483097229172, 0.3356254845618147, 0.18959349898373934`], 
             UndirectedEdge[34, 269] -> 
             RGBColor[
              0.4963462045644428, 0.6018763440007352, 0.9535261877805588], 
             UndirectedEdge[145, 286] -> 
             RGBColor[
              0.22187921582518422`, 0.3505395021600439, 0.9359470651491353], 
             UndirectedEdge[34, 234] -> 
             RGBColor[
              0.4661658558479902, 0.5757356428509766, 0.951603122647781], 
             UndirectedEdge[85, 286] -> 
             RGBColor[
              0.21865790979829205`, 0.3471537052831816, 0.935763616536399], 
             UndirectedEdge[86, 261] -> 
             RGBColor[
              0.897589954080166, 0.6247029436909717, 0.23609548573218275`], 
             UndirectedEdge[140, 255] -> 
             RGBColor[
              0.4486097951007969, 0.5617273998212495, 0.950153473138261], 
             UndirectedEdge[345, 448] -> 
             RGBColor[
              0.6138322543981429, 0.6971096748541594, 0.9629241548523259], 
             UndirectedEdge[146, 444] -> 
             RGBColor[
              0.2646131387661169, 0.39545556465817117`, 0.9383806988414477], 
             UndirectedEdge[215, 224] -> 
             RGBColor[
              0.2915446973152564, 0.4237623402527527, 0.9399144112591507], 
             UndirectedEdge[40, 359] -> 
             RGBColor[
              0.38582570994179444`, 0.508604570612715, 0.9458054509585798], 
             UndirectedEdge[88, 495] -> 
             RGBColor[
              0.8544062989949438, 0.4062909143031017, 0.1992274995322182], 
             UndirectedEdge[341, 403] -> 
             RGBColor[
              0.9612426733705868, 0.9674078133042042, 0.7674804702008887], 
             UndirectedEdge[134, 416] -> 
             RGBColor[
              0.24737003573452257`, 0.37733197009608865`, 0.9373987296326833],
              UndirectedEdge[113, 423] -> 
             RGBColor[
              0.1835090760837748, 0.31021005248445066`, 0.9337619424543968], 
             UndirectedEdge[204, 362] -> 
             RGBColor[
              0.4451772959687064, 0.5586930048020928, 0.9499517048675632], 
             UndirectedEdge[231, 256] -> 
             RGBColor[
              0.27391624912615603`, 0.40523372349783726`, 0.9389104972137335],
              UndirectedEdge[183, 407] -> 
             RGBColor[
              0.2096628417623121, 0.3376993184571131, 0.9352513607187605], 
             UndirectedEdge[231, 271] -> 
             RGBColor[
              0.25712583983655113`, 0.38758593876102676`, 0.9379543082438752],
              UndirectedEdge[106, 140] -> 
             RGBColor[
              0.508744701282457, 0.6120608930455363, 0.9544693929596517], 
             UndirectedEdge[96, 147] -> 
             RGBColor[
              0.27382745193814473`, 0.40514039202317054`, 0.9389054403452399],
              UndirectedEdge[149, 275] -> 
             RGBColor[
              0.38378936730216673`, 0.5068407929678266, 0.9456756970062499], 
             UndirectedEdge[207, 287] -> 
             RGBColor[
              0.21343735530821623`, 0.3416665715118395, 0.9354663136813074], 
             UndirectedEdge[223, 480] -> 
             RGBColor[
              0.3717055099769321, 0.496374363105037, 0.9449057243028214], 
             UndirectedEdge[11, 102] -> 
             RGBColor[
              0.2577278443328788, 0.3882186836559568, 0.9379885915093551], 
             UndirectedEdge[230, 339] -> 
             RGBColor[
              0.21778435426976317`, 0.3462355430360783, 0.9357138688413589], 
             UndirectedEdge[103, 449] -> 
             RGBColor[
              0.6043292409167387, 0.6883441793156388, 0.9628942898259707], 
             UndirectedEdge[226, 396] -> 
             RGBColor[
              0.5864855268156967, 0.6472607121015193, 0.7362180745608087], 
             UndirectedEdge[144, 279] -> 
             RGBColor[
              0.2623939933592224, 0.3931231021335797, 0.9382543217934566], 
             UndirectedEdge[205, 228] -> 
             RGBColor[
              0.9934539331599859, 0.9884069498751192, 0.5288792059852668], 
             UndirectedEdge[267, 406] -> 
             RGBColor[
              0.9898404936899885, 0.9773917410301207, 0.415032665757733], 
             UndirectedEdge[209, 233] -> 
             RGBColor[
              0.7045416845554648, 0.49561598240663746`, 0.5739669497124782], 
             UndirectedEdge[387, 405] -> 
             RGBColor[
              0.8845632449194131, 0.9069230619459494, 0.7839577394340637], 
             UndirectedEdge[75, 206] -> 
             RGBColor[
              0.34384133423410757`, 0.4722398145707964, 0.9431302436638118], 
             UndirectedEdge[183, 404] -> 
             RGBColor[
              0.20920782453695042`, 0.33722106650349953`, 0.9352254481609139],
              UndirectedEdge[319, 488] -> 
             RGBColor[
              0.7421269925364968, 0.7984745140343386, 0.9749319411111395], 
             UndirectedEdge[220, 371] -> 
             RGBColor[
              0.3509285621764658, 0.4783784152000333, 0.9435818355613093], 
             UndirectedEdge[66, 460] -> 
             RGBColor[
              0.2558136629427209, 0.38620675764879087`, 0.9378795817109632], 
             UndirectedEdge[87, 446] -> 
             RGBColor[
              0.20370226760912918`, 0.33143437709988877`, 0.934911914838616], 
             UndirectedEdge[273, 308] -> 
             RGBColor[
              0.23624385022904204`, 0.36563764368892326`, 0.9367651098278627],
              UndirectedEdge[326, 428] -> 
             RGBColor[
              0.8527545036662538, 0.3801225472055363, 0.19711821090416948`], 
             UndirectedEdge[130, 315] -> 
             RGBColor[
              0.1822133081343763, 0.30884811821319974`, 0.9336881503865955], 
             UndirectedEdge[95, 407] -> 
             RGBColor[
              0.22072063099008732`, 0.34932175603983573`, 0.9358810854567492],
              UndirectedEdge[148, 153] -> 
             RGBColor[
              0.2422944032111111, 0.37199715850029413`, 0.9371096798692006], 
             UndirectedEdge[85, 137] -> 
             RGBColor[
              0.21714804821848613`, 0.34556674503205226`, 0.9356776321530691],
              UndirectedEdge[289, 359] -> 
             RGBColor[
              0.4124111574915527, 0.5316315490568694, 0.9474994521678624], 
             UndirectedEdge[32, 449] -> 
             RGBColor[
              0.6320067542390264, 0.7108140314884382, 0.9650731650607731], 
             UndirectedEdge[329, 406] -> 
             RGBColor[
              0.9365881325497546, 0.9446037269852596, 0.7033574817962612], 
             UndirectedEdge[168, 213] -> 
             RGBColor[
              0.9074990588325569, 0.6709655443987909, 0.2444294609060539], 
             UndirectedEdge[111, 464] -> 
             RGBColor[
              0.2584790029138965, 0.3890081989508112, 0.9380313688793045], 
             UndirectedEdge[50, 117] -> 
             RGBColor[
              0.41100665014042015`, 0.5304150353819104, 0.9474099582014052], 
             UndirectedEdge[357, 420] -> 
             RGBColor[
              0.937892556639665, 0.822845791169284, 0.5910531975827036], 
             UndirectedEdge[153, 190] -> 
             RGBColor[
              0.24652129125596123`, 0.3764398858356126, 0.9373503948902342], 
             UndirectedEdge[165, 275] -> 
             RGBColor[
              0.41886860868054065`, 0.537224668715837, 0.9479109152475247], 
             UndirectedEdge[152, 301] -> 
             RGBColor[
              0.2063778078751808, 0.33424653955855976`, 0.9350642828986606], 
             UndirectedEdge[208, 349] -> 
             RGBColor[
              0.3678599975315118, 0.49304357350588934`, 0.9446606916502523], 
             UndirectedEdge[5, 23] -> 
             RGBColor[
              0.23055442452635688`, 0.3596576965449768, 0.9364411054508459], 
             UndirectedEdge[56, 227] -> 
             RGBColor[
              0.8411523878247509, 0.31732086267817405`, 0.187040879096943], 
             UndirectedEdge[56, 326] -> 
             RGBColor[
              0.8559245599190561, 0.404488988692082, 0.2001538603519194], 
             UndirectedEdge[155, 181] -> 
             RGBColor[
              0.49329315877378277`, 0.5986309034651389, 0.9534977211263604], 
             UndirectedEdge[148, 323] -> 
             RGBColor[
              0.23950025424315785`, 0.36906033077569844`, 0.9369505572190486],
              UndirectedEdge[177, 438] -> 
             RGBColor[
              0.21508055771107348`, 0.3433936814222922, 0.9355598916272501], 
             UndirectedEdge[53, 90] -> 
             RGBColor[
              0.9206410418975434, 0.7056328015929743, 0.28606405077970154`], 
             UndirectedEdge[30, 217] -> 
             RGBColor[
              0.2938254921740675, 0.42514500116830317`, 0.9400814485951139], 
             UndirectedEdge[43, 290] -> 
             RGBColor[
              0.2898165263474991, 0.4219459229932718, 0.9398159944791369], 
             UndirectedEdge[114, 397] -> 
             RGBColor[
              0.4296132686116584, 0.545245204928905, 0.9489508667899835], 
             UndirectedEdge[227, 320] -> 
             RGBColor[
              0.9171168323829694, 0.670650788557899, 0.5149397016540836], 
             UndirectedEdge[298, 432] -> 
             RGBColor[
              0.9001321413614187, 0.9232049523582542, 0.9903366012721426], 
             UndirectedEdge[42, 85] -> 
             RGBColor[
              0.22334491181980198`, 0.3520800415808806, 0.9360305343677259], 
             UndirectedEdge[329, 413] -> 
             RGBColor[
              0.9281969547806851, 0.9162983140279535, 0.6707593407043844], 
             UndirectedEdge[244, 380] -> 
             RGBColor[
              0.3076460451816098, 0.43757054210239044`, 0.9409454268990441], 
             UndirectedEdge[87, 113] -> 
             RGBColor[
              0.17922276129889142`, 0.3057048638774843, 0.9335178431684322], 
             UndirectedEdge[334, 370] -> 
             RGBColor[
              0.49712370807879736`, 0.6012548758448955, 0.9539335150694623], 
             UndirectedEdge[24, 278] -> 
             RGBColor[
              0.8926678774514412, 0.9169265621366819, 0.9783016146877055], 
             UndirectedEdge[51, 325] -> 
             RGBColor[
              0.17897196058988912`, 0.30544125643063946`, 0.933503560439081], 
             UndirectedEdge[112, 463] -> 
             RGBColor[
              0.2576804433404335, 0.3881688622075002, 0.9379858920929589], 
             UndirectedEdge[308, 421] -> 
             RGBColor[
              0.1790014452743907, 0.3054722467034876, 0.9335052395482446], 
             UndirectedEdge[302, 421] -> 
             RGBColor[
              0.18460298206136966`, 0.31135981702454774`, 0.9338242387815321],
              UndirectedEdge[103, 488] -> 
             RGBColor[
              0.6248600030483947, 0.70438296673246, 0.9649406043243738], 
             UndirectedEdge[225, 424] -> 
             RGBColor[
              0.2974218624617132, 0.42884414496049433`, 0.940289217587641], 
             UndirectedEdge[205, 388] -> 
             RGBColor[
              0.9699993320336204, 0.9742898944709728, 0.7727192137216462], 
             UndirectedEdge[114, 297] -> 
             RGBColor[
              0.5100213466264654, 0.6130973312480197, 0.954569895157638], 
             UndirectedEdge[203, 381] -> 
             RGBColor[
              0.5519357188644908, 0.6471253068518, 0.9578695480776199], 
             UndirectedEdge[17, 252] -> 
             RGBColor[
              0.8078836333626171, 0.8503289562761027, 0.9813572830192461], 
             UndirectedEdge[361, 363] -> 
             RGBColor[
              0.5245064025228867, 0.6235116591529769, 0.9560934187929221], 
             UndirectedEdge[318, 383] -> 
             RGBColor[
              0.3354424216880899, 0.46496509866505487`, 0.9425950723832464], 
             UndirectedEdge[209, 273] -> 
             RGBColor[
              0.4297324939516893, 0.5421711471050089, 0.9494994222745707], 
             UndirectedEdge[47, 230] -> 
             RGBColor[
              0.22790583767600858`, 0.3568738638351552, 0.9362902723479516], 
             UndirectedEdge[1, 170] -> 
             RGBColor[
              0.2814230291570491, 0.41312382526764985`, 0.939337997231207], 
             UndirectedEdge[139, 247] -> 
             RGBColor[
              0.529523280699882, 0.6289298798809373, 0.9561051588458358], 
             UndirectedEdge[246, 288] -> 
             RGBColor[
              0.2751436592994766, 0.40652380941229693`, 0.9389803964073136], 
             UndirectedEdge[1, 147] -> 
             RGBColor[
              0.2588293294875211, 0.38937641439167825`, 0.9380513194594108], 
             UndirectedEdge[352, 457] -> 
             RGBColor[
              0.22470998276050042`, 0.3535148176900512, 0.9361082731383572], 
             UndirectedEdge[157, 238] -> 
             RGBColor[
              0.31134876495031627`, 0.4435229307952213, 0.9410808428186908], 
             UndirectedEdge[97, 145] -> 
             RGBColor[
              0.2261963371710197, 0.3550770704158197, 0.9361929188231719], 
             UndirectedEdge[83, 237] -> 
             RGBColor[
              0.913419047498675, 0.933799570648643, 0.9916039182408752], 
             UndirectedEdge[73, 494] -> 
             RGBColor[
              0.25320700081228975`, 0.383466990477783, 0.9377311361588463], 
             UndirectedEdge[101, 197] -> 
             RGBColor[
              0.6092291752169602, 0.6927921015850171, 0.9629587335694303], 
             UndirectedEdge[224, 356] -> 
             RGBColor[
              0.28415211148803254`, 0.41599226383132715`, 0.939493414432641], 
             UndirectedEdge[182, 441] -> 
             RGBColor[
              0.41435953118072005`, 0.5333191324183171, 0.9476236008164568], 
             UndirectedEdge[160, 480] -> 
             RGBColor[
              0.3880144919727734, 0.5105003835965654, 0.94594491821413], 
             UndirectedEdge[263, 440] -> 
             RGBColor[
              0.2775372454156354, 0.40903962018250506`, 0.9391167075956355], 
             UndirectedEdge[31, 223] -> 
             RGBColor[
              0.42145102378698707`, 0.5394614268850837, 0.9480754644545675], 
             UndirectedEdge[5, 102] -> 
             RGBColor[
              0.2575724490549457, 0.3880553533662194, 0.9379797419781635], 
             UndirectedEdge[171, 216] -> 
             RGBColor[
              0.26381410331866717`, 0.39461572774112796`, 0.9383351949547825],
              UndirectedEdge[102, 414] -> 
             RGBColor[
              0.27559776236137046`, 0.40700110052214455`, 0.9390062569049031],
              UndirectedEdge[68, 205] -> 
             RGBColor[
              0.9069065109079608, 0.5719171126049378, 0.3681050087560027], 
             UndirectedEdge[111, 376] -> 
             RGBColor[
              0.2762731715166523, 0.4077109983677596, 0.9390447204571181], 
             UndirectedEdge[302, 325] -> 
             RGBColor[
              0.18458313935535953`, 0.31133896108243087`, 0.9338231087687794],
              UndirectedEdge[39, 315] -> 
             RGBColor[
              0.40458060190845924`, 0.5088289173445842, 0.948695685987052], 
             UndirectedEdge[66, 314] -> 
             RGBColor[
              0.29667827269945046`, 0.4271859979700665, 0.9402789673950056], 
             UndirectedEdge[274, 370] -> 
             RGBColor[
              0.5270887992770681, 0.6269534581897589, 0.9559135075504326], 
             UndirectedEdge[94, 477] -> 
             RGBColor[
              0.6000453532177727, 0.6703839872576882, 0.948796554675374], 
             UndirectedEdge[99, 329] -> 
             RGBColor[
              0.9380897089070905, 0.9489785735157732, 0.7678909167681753], 
             UndirectedEdge[25, 465] -> 
             RGBColor[
              0.2980004320712376, 0.430119718051609, 0.9402977272999771], 
             UndirectedEdge[223, 381] -> 
             RGBColor[
              0.47958429341648956`, 0.5866642295649169, 0.9526498297239985], 
             UndirectedEdge[196, 318] -> 
             RGBColor[
              0.3188208288656592, 0.44936205704600285`, 0.9415801260303202], 
             UndirectedEdge[76, 462] -> 
             RGBColor[
              0.4376018334802528, 0.5531637078002476, 0.949183806517649], 
             UndirectedEdge[89, 440] -> 
             RGBColor[
              0.2835877779164691, 0.415399113466799, 0.9394612764705972], 
             UndirectedEdge[88, 326] -> 
             RGBColor[
              0.8708928189630238, 0.5066362693068722, 0.21398214224720047`], 
             UndirectedEdge[149, 282] -> 
             RGBColor[
              0.48076658116172494`, 0.586646877963116, 0.9530129031646457], 
             UndirectedEdge[238, 462] -> 
             RGBColor[
              0.392016142899485, 0.5136796738226148, 0.9462791266236859], 
             UndirectedEdge[168, 261] -> 
             RGBColor[
              0.8953895182633258, 0.6159789489289689, 0.23432496342308617`], 
             UndirectedEdge[155, 344] -> 
             RGBColor[
              0.5148160505883743, 0.6169898879232494, 0.9549473518170989], 
             UndirectedEdge[4, 496] -> 
             RGBColor[
              0.3005965950412318, 0.4318380479282125, 0.9404825707076422], 
             UndirectedEdge[87, 226] -> 
             RGBColor[
              0.17933912709972993`, 0.30582717171218354`, 0.9335244700286423],
              UndirectedEdge[128, 362] -> 
             RGBColor[
              0.4416023765346493, 0.55579072415724, 0.9496702741143528], 
             UndirectedEdge[295, 389] -> 
             RGBColor[
              0.22404383278435813`, 0.3528146518287777, 0.9360703368826964], 
             UndirectedEdge[89, 133] -> 
             RGBColor[
              0.3153376912434113, 0.4454022988525135, 0.9413927055520241], 
             UndirectedEdge[33, 164] -> 
             RGBColor[
              0.8479694807729221, 0.33824875648589925`, 0.19233659900141542`],
              UndirectedEdge[276, 396] -> 
             RGBColor[
              0.8065431088390325, 0.8453068187334528, 0.7510492031181083], 
             UndirectedEdge[50, 274] -> 
             RGBColor[
              0.4518361438965558, 0.5655238171616463, 0.9500822208063486], 
             UndirectedEdge[21, 375] -> 
             RGBColor[
              0.9695446020803578, 0.9577696846543478, 0.6679456249234423], 
             UndirectedEdge[41, 485] -> 
             RGBColor[
              0.24026393309017596`, 0.36986300566395003`, 0.9369940475996247],
              UndirectedEdge[30, 316] -> 
             RGBColor[
              0.25921313179459604`, 0.3897798149508858, 0.938073176433014], 
             UndirectedEdge[285, 324] -> 
             RGBColor[
              0.3420478957119857, 0.4706864282637755, 0.9430159673470576], 
             UndirectedEdge[95, 358] -> 
             RGBColor[
              0.2263545662938538, 0.3552433792562242, 0.9362019297376383], 
             UndirectedEdge[333, 492] -> 
             RGBColor[
              0.32763422405457243`, 0.45523169861929097`, 0.9422062993288807],
              UndirectedEdge[332, 393] -> 
             RGBColor[
              0.4317017689879543, 0.548125780545763, 0.9487878519566961], 
             UndirectedEdge[418, 420] -> 
             RGBColor[
              0.9735581601714495, 0.9798002996671817, 0.9296433170801228], 
             UndirectedEdge[107, 273] -> 
             RGBColor[
              0.2391065540897807, 0.3686465269524677, 0.9369281365777409], 
             UndirectedEdge[310, 483] -> 
             RGBColor[
              0.2967031212326041, 0.4291841708528518, 0.9402081758700394], 
             UndirectedEdge[155, 403] -> 
             RGBColor[
              0.7474005481861847, 0.8023032590432388, 0.9760248292713649], 
             UndirectedEdge[140, 169] -> 
             RGBColor[
              0.4961881243257401, 0.601866898204728, 0.953480893225362], 
             UndirectedEdge[147, 216] -> 
             RGBColor[
              0.2586895754643985, 0.38922952405245953`, 0.9380433606745415], 
             UndirectedEdge[70, 171] -> 
             RGBColor[
              0.25999619432080096`, 0.39060286331495886`, 0.9381177706854442],
              UndirectedEdge[7, 402] -> 
             RGBColor[
              0.6954966701641224, 0.7608182646923372, 0.971187276045136], 
             UndirectedEdge[185, 409] -> 
             RGBColor[
              0.262750205623448, 0.39349750380844273`, 0.9382746075549353], 
             UndirectedEdge[126, 481] -> 
             RGBColor[
              0.28467725623571494`, 0.41566859359098884`, 0.9395553817772139],
              UndirectedEdge[115, 311] -> 
             RGBColor[
              0.8340126241816578, 0.871074103507641, 0.9838732137113628], 
             UndirectedEdge[383, 496] -> 
             RGBColor[
              0.30291603178424115`, 0.4338470274567268, 0.9406303631659094], 
             UndirectedEdge[8, 297] -> 
             RGBColor[
              0.5698289191235334, 0.6616518129015765, 0.9592781663469641], 
             UndirectedEdge[381, 439] -> 
             RGBColor[
              0.7151086431122187, 0.7765792866784462, 0.9729163506443089], 
             UndirectedEdge[16, 276] -> 
             RGBColor[
              0.5117111188744836, 0.6131268633886855, 0.9550738020104051], 
             UndirectedEdge[74, 342] -> 
             RGBColor[
              0.27086057814160247`, 0.4020220195523411, 0.9387364812716233], 
             UndirectedEdge[26, 269] -> 
             RGBColor[
              0.4177844388725415, 0.5362856153201071, 0.9478418329060527], 
             UndirectedEdge[127, 315] -> 
             RGBColor[
              0.20573971378665917`, 0.3335758622140216, 0.9350279443842948], 
             UndirectedEdge[175, 348] -> 
             RGBColor[
              0.9578209370783626, 0.9214694359811255, 0.6292929486935749], 
             UndirectedEdge[180, 288] -> 
             RGBColor[
              0.2630984263915931, 0.39386350591423513`, 0.9382944382125347], 
             UndirectedEdge[288, 343] -> 
             RGBColor[
              0.274476709135814, 0.40582280250320485`, 0.9389424145821572], 
             UndirectedEdge[484, 500] -> 
             RGBColor[
              0.9061921804601966, 0.5690195539734165, 0.316991474169404], 
             UndirectedEdge[59, 323] -> 
             RGBColor[
              0.24076788547771533`, 0.3703926915756808, 0.9370227469425643], 
             UndirectedEdge[108, 189] -> 
             RGBColor[
              0.27244302962866296`, 0.40368527639846097`, 0.9388265995427842],
              UndirectedEdge[59, 74] -> 
             RGBColor[
              0.26196255890659237`, 0.3926696371693413, 0.9382297522396293], 
             UndirectedEdge[40, 199] -> 
             RGBColor[
              0.3645220176644419, 0.4901523831167798, 0.9444479985247825], 
             UndirectedEdge[69, 241] -> 
             RGBColor[
              0.8074723242442312, 0.8502460052781141, 0.9812530323476005], 
             UndirectedEdge[275, 353] -> 
             RGBColor[
              0.5266832510882068, 0.6255486018899017, 0.9561787766673014], 
             UndirectedEdge[196, 335] -> 
             RGBColor[
              0.2862357534512077, 0.4181823036451551, 0.9396120747599719], 
             UndirectedEdge[157, 281] -> 
             RGBColor[
              0.2737261355645935, 0.4050339020907391, 0.9388996705276503], 
             UndirectedEdge[120, 438] -> 
             RGBColor[
              0.21444303080234048`, 0.3427236002196732, 0.9355235854129342], 
             UndirectedEdge[152, 389] -> 
             RGBColor[
              0.21125135912011495`, 0.33936895091798147`, 0.9353418244322866],
              UndirectedEdge[126, 144] -> 
             RGBColor[
              0.24868278916139275`, 0.37871175718110384`, 0.937473488998299], 
             UndirectedEdge[96, 157] -> 
             RGBColor[
              0.29935267191603787`, 0.43196901661235676`, 0.940359063861802], 
             UndirectedEdge[303, 366] -> 
             RGBColor[
              0.2851324087513453, 0.4170226184095053, 0.9395492409115669], 
             UndirectedEdge[119, 309] -> 
             RGBColor[
              0.9918390696706652, 0.9889511495464178, 0.6437403499501158], 
             UndirectedEdge[325, 386] -> 
             RGBColor[
              0.1789719601845752, 0.3054412560046289, 0.9335035604159989], 
             UndirectedEdge[27, 220] -> 
             RGBColor[
              0.4255160611016982, 0.5413857751468245, 0.948775625607305], 
             UndirectedEdge[95, 346] -> 
             RGBColor[
              0.22248278830370904`, 0.3511738951036789, 0.9359814377088818], 
             UndirectedEdge[235, 239] -> 
             RGBColor[
              0.35398612023304477`, 0.4810267183113057, 0.943776660456982], 
             UndirectedEdge[64, 303] -> 
             RGBColor[
              0.29654648477504475`, 0.4290195360046319, 0.9401992556555043], 
             UndirectedEdge[310, 429] -> 
             RGBColor[
              0.2951775190785565, 0.4275806662601843, 0.9401212950842925], 
             UndirectedEdge[67, 238] -> 
             RGBColor[
              0.28838849579729153`, 0.41939023215024707`, 0.9397732894571003],
              UndirectedEdge[38, 108] -> 
             RGBColor[
              0.272539685244709, 0.40378686757924537`, 0.9388321039371288], 
             UndirectedEdge[20, 490] -> 
             RGBColor[
              0.9375437932423437, 0.7794697399272263, 0.5157901036631747], 
             UndirectedEdge[112, 148] -> 
             RGBColor[
              0.2439596839808273, 0.373747474174165, 0.9372045151454738], 
             UndirectedEdge[76, 402] -> 
             RGBColor[
              0.4818182674522101, 0.589060600826333, 0.952664686170056], 
             UndirectedEdge[99, 406] -> 
             RGBColor[
              0.992119957252125, 0.9843905837590278, 0.48258804562862445`], 
             UndirectedEdge[8, 258] -> 
             RGBColor[
              0.4968580357130886, 0.6002414107444907, 0.9541330294430466], 
             UndirectedEdge[15, 153] -> 
             RGBColor[
              0.23958587882071014`, 0.3691503276356177, 0.93695543341207], 
             UndirectedEdge[195, 463] -> 
             RGBColor[
              0.2686246431474216, 0.3996719101069903, 0.9386091480814742], 
             UndirectedEdge[184, 249] -> 
             RGBColor[
              0.2732898707787555, 0.40457536014003825`, 0.9388748258934928], 
             UndirectedEdge[109, 185] -> 
             RGBColor[
              0.26895237692670115`, 0.40001637908853493`, 0.9386278120353654],
              UndirectedEdge[77, 81] -> 
             RGBColor[
              0.7152180111578499, 0.7769379420233913, 0.972614350327299], 
             UndirectedEdge[355, 384] -> 
             RGBColor[
              0.3062638013444511, 0.43738753923394075`, 0.9408202157153518], 
             UndirectedEdge[67, 343] -> 
             RGBColor[
              0.2747552896997584, 0.40611560833893834`, 0.9389582793331509], 
             UndirectedEdge[247, 255] -> 
             RGBColor[
              0.4462984536881862, 0.5598509487377481, 0.9499715158755377], 
             UndirectedEdge[95, 145] -> 
             RGBColor[
              0.22387054333517215`, 0.3526325136304976, 0.9360604683049241], 
             UndirectedEdge[220, 416] -> 
             RGBColor[
              0.3002234451567067, 0.4300950902197503, 0.9405107780769688], 
             UndirectedEdge[287, 451] -> 
             RGBColor[
              0.21062876698303812`, 0.3387145671072923, 0.9353063687311225], 
             UndirectedEdge[387, 491] -> 
             RGBColor[
              0.8846376192086578, 0.9070821410302499, 0.7920529218334498], 
             UndirectedEdge[211, 464] -> 
             RGBColor[
              0.23745358448324252`, 0.36690915109166977`, 0.936834002403998], 
             UndirectedEdge[335, 482] -> 
             RGBColor[
              0.3176268052914761, 0.44657790833086347`, 0.9415681179813948], 
             UndirectedEdge[214, 423] -> 
             RGBColor[
              0.19381650316255092`, 0.32104381187286724`, 0.9343489351780614],
              UndirectedEdge[69, 194] -> 
             RGBColor[
              0.9479892988678673, 0.9596684021789683, 0.9321766809000795], 
             UndirectedEdge[111, 312] -> 
             RGBColor[
              0.28875139009156847`, 0.4208263972547496, 0.9397553365450895], 
             UndirectedEdge[174, 294] -> 
             RGBColor[
              0.2524849252558091, 0.3827080432856873, 0.9376900150241196], 
             UndirectedEdge[212, 295] -> 
             RGBColor[
              0.22405206726645135`, 0.35282330679155405`, 0.9360708058242697],
              UndirectedEdge[193, 414] -> 
             RGBColor[
              0.28123484292780576`, 0.41292602960901903`, 0.9393272803038482],
              UndirectedEdge[320, 348] -> 
             RGBColor[
              0.9742570536765062, 0.9329947209284535, 0.5686571215977747], 
             UndirectedEdge[247, 468] -> 
             RGBColor[
              0.48669420259584584`, 0.5941593048480999, 0.9527334969294036], 
             UndirectedEdge[449, 488] -> 
             RGBColor[
              0.7488335383665432, 0.8037137186084069, 0.9756003869232444], 
             UndirectedEdge[290, 355] -> 
             RGBColor[
              0.30759602149261944`, 0.4387877870773017, 0.9408960836819469], 
             UndirectedEdge[88, 469] -> 
             RGBColor[
              0.8635204022958338, 0.47315984709282155`, 0.20783041706562805`],
              UndirectedEdge[6, 278] -> 
             RGBColor[
              0.8880267801577246, 0.9132258771339024, 0.9778589426846744], 
             UndirectedEdge[24, 448] -> 
             RGBColor[
              0.7024556642269519, 0.7664802639694746, 0.97172087084446], 
             UndirectedEdge[204, 274] -> 
             RGBColor[
              0.4823136561574142, 0.5906029799080129, 0.9523886442672999], 
             UndirectedEdge[81, 99] -> 
             RGBColor[
              0.9086198401868935, 0.9254801001365643, 0.7650800543815806], 
             UndirectedEdge[213, 368] -> 
             RGBColor[
              0.6561537738248766, 0.5929010247462924, 0.5945021229284573], 
             UndirectedEdge[167, 474] -> 
             RGBColor[
              0.9898837045140847, 0.9900846660867081, 0.8173167265425048], 
             UndirectedEdge[78, 430] -> 
             RGBColor[
              0.22958406238534357`, 0.3586377844102586, 0.9363858447624374], 
             UndirectedEdge[110, 316] -> 
             RGBColor[
              0.26110517012024004`, 0.39176846719329617`, 0.9381809252166395],
              UndirectedEdge[153, 463] -> 
             RGBColor[
              0.25601516257071727`, 0.38641854653362934`, 0.9378910568166856],
              UndirectedEdge[471, 475] -> 
             RGBColor[
              0.847907987036376, 0.36924735854117574`, 0.19351004853135326`], 
             UndirectedEdge[79, 486] -> 
             RGBColor[
              0.9643781566417168, 0.9700792377693064, 0.7816636594414414], 
             UndirectedEdge[49, 402] -> 
             RGBColor[
              0.521262974366249, 0.6222237910767345, 0.9554548772727531], 
             UndirectedEdge[340, 498] -> 
             RGBColor[
              0.39966203669691347`, 0.5203561647804322, 0.9467513952897255], 
             UndirectedEdge[248, 313] -> 
             RGBColor[
              0.254748775686199, 0.38508749362443473`, 0.9378189379570638], 
             UndirectedEdge[37, 429] -> 
             RGBColor[
              0.29961908302642226`, 0.4322490315808106, 0.9403742355804184], 
             UndirectedEdge[18, 166] -> 
             RGBColor[
              0.8612521660936727, 0.43095598829613885`, 0.2046884517082866], 
             UndirectedEdge[147, 238] -> 
             RGBColor[
              0.2858235449724231, 0.4166943062060351, 0.9396272193021288], 
             UndirectedEdge[165, 441] -> 
             RGBColor[
              0.4370828286560343, 0.553000910585295, 0.9490715092381609], 
             UndirectedEdge[13, 154] -> 
             RGBColor[
              0.3030787322552839, 0.435811820273263, 0.9405739494865415], 
             UndirectedEdge[133, 249] -> 
             RGBColor[
              0.3173607671926588, 0.44752867994559636`, 0.9415079167344612], 
             UndirectedEdge[84, 385] -> 
             RGBColor[
              0.2333929402174702, 0.3626411565086264, 0.9366027547202471], 
             UndirectedEdge[125, 438] -> 
             RGBColor[
              0.2150690714922951, 0.34338160867808776`, 0.9355592375040829], 
             UndirectedEdge[21, 489] -> 
             RGBColor[
              0.9854926800563032, 0.9686826013172827, 0.5970125136401502], 
             UndirectedEdge[16, 200] -> 
             RGBColor[
              0.6523550443789783, 0.5834045301394526, 0.5929583920999518], 
             UndirectedEdge[402, 436] -> 
             RGBColor[
              0.5126155235296384, 0.6152034009243532, 0.954774118266239], 
             UndirectedEdge[127, 401] -> 
             RGBColor[
              0.499716094491864, 0.5888978154955886, 0.9571173753725956], 
             UndirectedEdge[195, 395] -> 
             RGBColor[
              0.26756974901772024`, 0.3985631494925233, 0.9385490734213637], 
             UndirectedEdge[27, 297] -> 
             RGBColor[
              0.5157415629468824, 0.6177412605497428, 0.9550202115402241], 
             UndirectedEdge[35, 70] -> 
             RGBColor[
              0.24831129577393707`, 0.37832129407684667`, 0.9374523329994586],
              UndirectedEdge[240, 367] -> 
             RGBColor[
              0.24323530728920995`, 0.3729861083431402, 0.9371632629645055], 
             UndirectedEdge[121, 471] -> 
             RGBColor[
              0.842139262249025, 0.3249064119542755, 0.18798591116014318`], 
             UndirectedEdge[184, 424] -> 
             RGBColor[
              0.28881315240835653`, 0.41979584487067384`, 0.9397989642855475],
              UndirectedEdge[122, 159] -> 
             RGBColor[
              0.8441272348319537, 0.3258751275198433, 0.1893291851678579], 
             UndirectedEdge[158, 324] -> 
             RGBColor[
              0.3635993901479788, 0.48935324953462667`, 0.9443892095152808], 
             UndirectedEdge[180, 465] -> 
             RGBColor[
              0.27637826248324115`, 0.40782145563679656`, 0.9390507052321971],
              UndirectedEdge[254, 454] -> 
             RGBColor[
              0.568190337821955, 0.5020881692235942, 0.5874756893040098], 
             UndirectedEdge[297, 314] -> 
             RGBColor[
              0.42471984107439154`, 0.540499402694099, 0.9487792473402418], 
             UndirectedEdge[262, 393] -> 
             RGBColor[
              0.46864864929250694`, 0.5795091117335374, 0.951312884870325], 
             UndirectedEdge[201, 333] -> 
             RGBColor[
              0.34155395478950024`, 0.4698622181836031, 0.9429990074018386], 
             UndirectedEdge[219, 340] -> 
             RGBColor[
              0.43185173064895377`, 0.5464892084598855, 0.9492854859123644], 
             UndirectedEdge[361, 370] -> 
             RGBColor[
              0.6178223925754994, 0.7005868527844641, 0.9630756852495326], 
             UndirectedEdge[48, 358] -> 
             RGBColor[
              0.2165685446684143, 0.3449576500582796, 0.9356446302831911], 
             UndirectedEdge[287, 299] -> 
             RGBColor[
              0.2094890463187735, 0.33751664842668644`, 0.9352414633253583], 
             UndirectedEdge[62, 233] -> 
             RGBColor[
              0.8302393984490122, 0.2334388442338099, 0.17659058814627704`], 
             UndirectedEdge[61, 91] -> 
             RGBColor[
              0.32572776888358806`, 0.4565507546784424, 0.9419760632968737], 
             UndirectedEdge[204, 340] -> 
             RGBColor[
              0.4196638066192008, 0.5365945026728116, 0.9483260078869054], 
             UndirectedEdge[258, 373] -> 
             RGBColor[
              0.3335189671806654, 0.461900180189882, 0.9425237328349862], 
             UndirectedEdge[167, 210] -> 
             RGBColor[
              0.9113669843928855, 0.6334814540290358, 0.5263699322609554], 
             UndirectedEdge[275, 481] -> 
             RGBColor[
              0.36596032955819924`, 0.49139817658749463`, 0.9445396464868034],
              UndirectedEdge[253, 277] -> 
             RGBColor[
              0.8781666893011308, 0.9046720920391318, 0.9377821758000617], 
             UndirectedEdge[193, 485] -> 
             RGBColor[
              0.2679064543585755, 0.3989170481541139, 0.9385682482924145], 
             UndirectedEdge[89, 260] -> 
             RGBColor[
              0.2855390731059485, 0.4174500484302025, 0.9395723998449554], 
             UndirectedEdge[359, 397] -> 
             RGBColor[
              0.3719996579907838, 0.4966291393303264, 0.9449244671541592], 
             UndirectedEdge[1, 171] -> 
             RGBColor[
              0.2639538573417897, 0.3947626180803467, 0.9383431537396518], 
             UndirectedEdge[193, 330] -> 
             RGBColor[
              0.2971306356015508, 0.42963351556059126`, 0.9402325221809], 
             UndirectedEdge[92, 320] -> 
             RGBColor[
              0.7988700431185324, 0.8415596078670635, 0.9004611644475569], 
             UndirectedEdge[126, 279] -> 
             RGBColor[
              0.26484901945855754`, 0.3957034902216259, 0.9383941318979281], 
             UndirectedEdge[93, 163] -> 
             RGBColor[
              0.26813879509029465`, 0.39916125299440397`, 0.9385814797533685],
              UndirectedEdge[31, 297] -> 
             RGBColor[
              0.48620123605795307`, 0.5937514968840982, 0.9526967874627315], 
             UndirectedEdge[127, 325] -> 
             RGBColor[
              0.20249836583685807`, 0.33016900000545074`, 0.9348433544136983],
              UndirectedEdge[334, 498] -> 
             RGBColor[
              0.4323467950368561, 0.5486660596707702, 0.9488340391891498], 
             UndirectedEdge[41, 300] -> 
             RGBColor[
              0.22924216126039493`, 0.3582784246501542, 0.9363663739991688], 
             UndirectedEdge[330, 496] -> 
             RGBColor[
              0.2916695481926115, 0.42389356644085574`, 0.9399215213319159], 
             UndirectedEdge[18, 227] -> 
             RGBColor[
              0.8650075437066738, 0.45982146624662823`, 0.2082846055515888], 
             UndirectedEdge[156, 350] -> 
             RGBColor[
              0.41473957912155346`, 0.5332684178987681, 0.9477527826875395], 
             UndirectedEdge[315, 386] -> 
             RGBColor[
              0.1822133081343763, 0.30884811821319974`, 0.9336881503865955], 
             UndirectedEdge[29, 479] -> 
             RGBColor[
              0.410555492074131, 0.5300242649407545, 0.9473812108083647], 
             UndirectedEdge[277, 488] -> 
             RGBColor[
              0.7703329161501223, 0.8205091959342619, 0.9777432439776033], 
             UndirectedEdge[242, 374] -> 
             RGBColor[
              0.2383689744042093, 0.367871283937679, 0.936886132505799], 
             UndirectedEdge[244, 363] -> 
             RGBColor[
              0.37362619317772217`, 0.49803796235721676`, 0.9450281085379824],
              UndirectedEdge[335, 409] -> 
             RGBColor[
              0.25916391695491414`, 0.389728087033979, 0.938070373720701], 
             UndirectedEdge[235, 332] -> 
             RGBColor[
              0.37961688858367837`, 0.50322680161675, 0.9454098303518859], 
             UndirectedEdge[249, 440] -> 
             RGBColor[
              0.2856108538657166, 0.41752549455988186`, 0.9395764876530341], 
             UndirectedEdge[96, 265] -> 
             RGBColor[
              0.3085881199169248, 0.4405417508695841, 0.9409265415042412], 
             UndirectedEdge[39, 200] -> 
             RGBColor[
              0.7622447974505207, 0.6739602832535388, 0.6012384342096092], 
             UndirectedEdge[146, 312] -> 
             RGBColor[
              0.28117238396624933`, 0.41286038128029634`, 0.9393237233583873],
              UndirectedEdge[237, 448] -> 
             RGBColor[
              0.7370158535300309, 0.7940376208084021, 0.9750172525524329], 
             UndirectedEdge[31, 162] -> 
             RGBColor[
              0.4575348398128734, 0.5704788250059085, 0.9504400637418493], 
             UndirectedEdge[41, 102] -> 
             RGBColor[
              0.2545321161274702, 0.38485977069120125`, 0.9378065995157133], 
             UndirectedEdge[266, 374] -> 
             RGBColor[
              0.27062553266643685`, 0.40177497185519817`, 0.9387230957795312],
              UndirectedEdge[44, 139] -> 
             RGBColor[
              0.5303562146824653, 0.6296060932112468, 0.9561707304600824], 
             UndirectedEdge[47, 189] -> 
             RGBColor[
              0.24585450838109163`, 0.3757390547576487, 0.9373124225919274], 
             UndirectedEdge[208, 359] -> 
             RGBColor[
              0.3537848938552699, 0.480852426136809, 0.9437638384901277], 
             UndirectedEdge[122, 413] -> 
             RGBColor[
              0.9206701650068785, 0.7073273642826143, 0.2820065056616069], 
             UndirectedEdge[36, 141] -> 
             RGBColor[
              0.28198608489330845`, 0.4136382572421074, 0.9393728955113378], 
             UndirectedEdge[179, 347] -> 
             RGBColor[
              0.17892806853100302`, 0.30539512309383293`, 0.93350106085126], 
             UndirectedEdge[226, 422] -> 
             RGBColor[
              0.20671849831186667`, 0.3346046268085379, 0.9350836847150235], 
             UndirectedEdge[18, 167] -> 
             RGBColor[
              0.9355270875213144, 0.7783260157628717, 0.5479056765432442], 
             UndirectedEdge[112, 452] -> 
             RGBColor[
              0.2361084750925497, 0.3654953558371904, 0.936757400414109], 
             UndirectedEdge[323, 342] -> 
             RGBColor[
              0.2496659047127254, 0.3797450739586806, 0.9375294759745583], 
             UndirectedEdge[74, 82] -> 
             RGBColor[
              0.27000631808527487`, 0.401124138069925, 0.93868783242518], 
             UndirectedEdge[291, 349] -> 
             RGBColor[
              0.5342643053360183, 0.6315079324719315, 0.9569079863163146], 
             UndirectedEdge[86, 136] -> 
             RGBColor[
              0.942076876818933, 0.8389236960734718, 0.594023128493258], 
             UndirectedEdge[11, 23] -> 
             RGBColor[
              0.23070981980428998`, 0.3598210268347142, 0.9364499549820375], 
             UndirectedEdge[249, 470] -> 
             RGBColor[
              0.27251498804399493`, 0.40376090925540187`, 0.9388306974680845],
              UndirectedEdge[35, 135] -> 
             RGBColor[
              0.24449959825218992`, 0.3743149583059091, 0.9372352624644963], 
             UndirectedEdge[161, 326] -> 
             RGBColor[
              0.9327537347132191, 0.7525662704764362, 0.31724881897839763`], 
             UndirectedEdge[26, 139] -> 
             RGBColor[
              0.4753323584108449, 0.5831244997687381, 0.952339366037344], 
             UndirectedEdge[109, 218] -> 
             RGBColor[
              0.24296647092511459`, 0.372703544279266, 0.937147953131278], 
             UndirectedEdge[238, 465] -> 
             RGBColor[
              0.30138975132499524`, 0.433055376037075, 0.940513691725769], 
             UndirectedEdge[258, 314] -> 
             RGBColor[
              0.35174895766394676`, 0.47908900053701325`, 0.9436341104363243],
              UndirectedEdge[28, 493] -> 
             RGBColor[
              0.9792166674892435, 0.9809905167708368, 0.7433381739278018], 
             UndirectedEdge[106, 466] -> 
             RGBColor[
              0.5106817556791221, 0.6136334810680553, 0.9546218849774213], 
             UndirectedEdge[45, 236] -> 
             RGBColor[
              0.285052814306115, 0.4169389596009889, 0.9395447081256605], 
             UndirectedEdge[157, 246] -> 
             RGBColor[
              0.2983825090164457, 0.4309493138930047, 0.9403038145198976], 
             UndirectedEdge[371, 427] -> 
             RGBColor[
              0.3212220231725497, 0.4499441234823203, 0.9417879671446181], 
             UndirectedEdge[341, 450] -> 
             RGBColor[
              0.9056409272943111, 0.562891578052587, 0.35323513131972123`], 
             UndirectedEdge[277, 484] -> 
             RGBColor[
              0.8820966152149525, 0.9042351364524142, 0.7227616167031183], 
             UndirectedEdge[84, 135] -> 
             RGBColor[
              0.24197053087649611`, 0.37165674814192173`, 0.9370912358188704],
              UndirectedEdge[35, 84] -> 
             RGBColor[
              0.2358433607180927, 0.36521670382041393`, 0.9367423025426853], 
             UndirectedEdge[68, 272] -> 
             RGBColor[
              0.8202846954174998, 0.15692263455492186`, 0.1670579532810717], 
             UndirectedEdge[164, 227] -> 
             RGBColor[
              0.8315779382096691, 0.24372744738608088`, 0.17787237533274636`],
              UndirectedEdge[355, 498] -> 
             RGBColor[
              0.3952981571338905, 0.516576391637906, 0.946473332742797], 
             UndirectedEdge[223, 373] -> 
             RGBColor[
              0.3417396383201442, 0.4690205123479532, 0.9430475467307398], 
             UndirectedEdge[116, 192] -> 
             RGBColor[
              0.2516702940273803, 0.3818518142140055, 0.9376436229807996], 
             UndirectedEdge[3, 31] -> 
             RGBColor[
              0.4573521482388232, 0.5703305077559329, 0.9504256815919188], 
             UndirectedEdge[40, 419] -> 
             RGBColor[
              0.44944534633244004`, 0.5620965984995714, 0.950304666943798], 
             UndirectedEdge[282, 324] -> 
             RGBColor[
              0.48866791978392093`, 0.5934906203448358, 0.9535163694747727], 
             UndirectedEdge[250, 339] -> 
             RGBColor[
              0.20806801028262886`, 0.33602304945380984`, 0.9351605374253343],
              UndirectedEdge[259, 405] -> 
             RGBColor[
              0.9279266912954685, 0.7275673838799486, 0.39806227602736116`], 
             UndirectedEdge[22, 441] -> 
             RGBColor[
              0.45077446449645514`, 0.564859917388641, 0.9499439281668742], 
             UndirectedEdge[142, 241] -> 
             RGBColor[
              0.7025032226254809, 0.7675201238280478, 0.9709826140315919], 
             UndirectedEdge[170, 266] -> 
             RGBColor[
              0.29310065604108804`, 0.425397751527083, 0.9400030208067522], 
             UndirectedEdge[105, 153] -> 
             RGBColor[
              0.24541911730613436`, 0.37528143113248, 0.9372876277143118], 
             UndirectedEdge[95, 404] -> 
             RGBColor[
              0.22026561376472564`, 0.3488435040862222, 0.9358551728989024], 
             UndirectedEdge[200, 454] -> 
             RGBColor[
              0.9003552167733437, 0.640418136645701, 0.2385662891695866], 
             UndirectedEdge[96, 131] -> 
             RGBColor[
              0.2798853921380307, 0.4115076712688437, 0.9392504310777041], 
             UndirectedEdge[190, 395] -> 
             RGBColor[
              0.2565485956338361, 0.38697921850457684`, 0.9379214350404868], 
             UndirectedEdge[297, 381] -> 
             RGBColor[
              0.5443345056874556, 0.6409542995639315, 0.9572711527321625], 
             UndirectedEdge[203, 419] -> 
             RGBColor[
              0.5236285855732716, 0.6241443008241659, 0.9556411068524893], 
             UndirectedEdge[107, 209] -> 
             RGBColor[
              0.37529763235099667`, 0.4849566561931139, 0.9463994374355724], 
             UndirectedEdge[205, 252] -> 
             RGBColor[
              0.8648112867502258, 0.89136633503373, 0.7718692919288858], 
             UndirectedEdge[98, 488] -> 
             RGBColor[
              0.8822995191611039, 0.9059842085048606, 0.8501777526166581], 
             UndirectedEdge[182, 275] -> 
             RGBColor[
              0.39614531120522645`, 0.517542890548859, 0.9464630068258206], 
             UndirectedEdge[88, 474] -> 
             RGBColor[
              0.9298536404427284, 0.7393015368665987, 0.48723505332973827`], 
             UndirectedEdge[47, 242] -> 
             RGBColor[
              0.2284706396727983, 0.35746750654429615`, 0.9363224369861192], 
             UndirectedEdge[133, 262] -> 
             RGBColor[
              0.4106297397776527, 0.5294703750419166, 0.9475567521778445], 
             UndirectedEdge[4, 321] -> 
             RGBColor[
              0.32873955000778277`, 0.45915940811169914`, 0.9421679713268938],
              UndirectedEdge[369, 370] -> 
             RGBColor[
              0.5056953807182732, 0.6086792278604158, 0.9544796944704173], 
             UndirectedEdge[49, 436] -> 
             RGBColor[
              0.4815672646188717, 0.5899970256324685, 0.9523298855912635], 
             UndirectedEdge[34, 393] -> 
             RGBColor[
              0.5024822764946291, 0.606976774483756, 0.9539763919403361], 
             UndirectedEdge[268, 324] -> 
             RGBColor[
              0.3896661145929028, 0.5119309360971549, 0.946050158147012], 
             UndirectedEdge[359, 371] -> 
             RGBColor[
              0.37419759071797254`, 0.49853287818730624`, 0.94506451748398], 
             UndirectedEdge[296, 440] -> 
             RGBColor[
              0.29754682970453167`, 0.4296388353177702, 0.94027204609223], 
             UndirectedEdge[113, 143] -> 
             RGBColor[
              0.17905963102166003`, 0.30553340361305714`, 0.9335085531404735],
              UndirectedEdge[270, 489] -> 
             RGBColor[
              0.9900603412249211, 0.9901577099059953, 0.8143893991227904], 
             UndirectedEdge[237, 426] -> 
             RGBColor[
              0.8881333928283652, 0.9136374759753497, 0.9891921499256506], 
             UndirectedEdge[131, 385] -> 
             RGBColor[
              0.24854031848564526`, 0.3785620114677306, 0.9374653755040816], 
             UndirectedEdge[427, 499] -> 
             RGBColor[
              0.27010938266217854`, 0.4012324654749223, 0.9386937018003643], 
             UndirectedEdge[45, 243] -> 
             RGBColor[
              0.5610442905289292, 0.35884112143673136`, 0.5623441481098833], 
             UndirectedEdge[33, 443] -> 
             RGBColor[
              0.9064631162110222, 0.6594290978497701, 0.24321160823769428`], 
             UndirectedEdge[232, 330] -> 
             RGBColor[
              0.3313235898372211, 0.4611852513408379, 0.942340398215439], 
             UndirectedEdge[19, 360] -> 
             RGBColor[
              0.5695454245786704, 0.661421659258773, 0.9592558486179177], 
             UndirectedEdge[44, 370] -> 
             RGBColor[
              0.5440602935407461, 0.6407316817901163, 0.9572495657475013], 
             UndirectedEdge[310, 412] -> 
             RGBColor[
              0.26956927876194814`, 0.4006647820312149, 0.9386629436822582], 
             UndirectedEdge[107, 214] -> 
             RGBColor[
              0.19223940367108877`, 0.31938618031345734`, 0.9342591216951321],
              UndirectedEdge[268, 481] -> 
             RGBColor[
              0.3639357382267393, 0.48964457733510314`, 0.9444106413174386], 
             UndirectedEdge[224, 351] -> 
             RGBColor[
              0.29450587119895527`, 0.4268747217537883, 0.9400830457311632], 
             UndirectedEdge[78, 408] -> 
             RGBColor[
              0.22096681623691122`, 0.34958051234329385`, 0.9358951053423573],
              UndirectedEdge[124, 136] -> 
             RGBColor[
              0.9658066058981951, 0.931025957642273, 0.6234191599847442], 
             UndirectedEdge[51, 315] -> 
             RGBColor[
              0.1822133085396902, 0.30884811863921036`, 0.9336881504096776], 
             UndirectedEdge[24, 270] -> 
             RGBColor[
              0.9134975511433701, 0.9314925430785823, 0.899659555679228], 
             UndirectedEdge[43, 340] -> 
             RGBColor[
              0.31529118717805316`, 0.446068953150221, 0.9413638580453506], 
             UndirectedEdge[116, 483] -> 
             RGBColor[
              0.27268756010159706`, 0.40394229342964216`, 0.9388405251914673],
              UndirectedEdge[50, 169] -> 
             RGBColor[
              0.46684010556596744`, 0.5777047091656451, 0.9512633876302873], 
             UndirectedEdge[247, 369] -> 
             RGBColor[
              0.457479402684923, 0.5695353247878849, 0.9506839560586847], 
             UndirectedEdge[327, 412] -> 
             RGBColor[
              0.2497253233645969, 0.37980752672915763`, 0.9375328597788803], 
             UndirectedEdge[134, 305] -> 
             RGBColor[
              0.2421591297202534, 0.37185497748456803`, 0.9371019762440154], 
             UndirectedEdge[7, 49] -> 
             RGBColor[
              0.6644484112533559, 0.7356118894004525, 0.9687430433701605], 
             UndirectedEdge[81, 486] -> 
             RGBColor[
              0.879272872526262, 0.9065723375988691, 0.9883470255893563], 
             UndirectedEdge[110, 384] -> 
             RGBColor[
              0.27776805045914515`, 0.4092822109171187, 0.9391298516014178], 
             UndirectedEdge[18, 88] -> 
             RGBColor[
              0.8754970234499582, 0.5275428865427625, 0.2178240033304778], 
             UndirectedEdge[11, 41] -> 
             RGBColor[
              0.23572240363091454`, 0.3650895702526674, 0.9367354142155104], 
             UndirectedEdge[231, 288] -> 
             RGBColor[
              0.2572561350755689, 0.3877228873184297, 0.9379617283649826], 
             UndirectedEdge[236, 396] -> 
             RGBColor[
              0.6404346091203621, 0.7039646181731036, 0.7392903949875442], 
             UndirectedEdge[46, 418] -> 
             RGBColor[
              0.9480641688610301, 0.8473510420156326, 0.586962152772621], 
             UndirectedEdge[74, 447] -> 
             RGBColor[
              0.26411698006509043`, 0.39493407040511375`, 0.9383524433374253],
              UndirectedEdge[270, 426] -> 
             RGBColor[
              0.9300987405065613, 0.9447298808495102, 0.9012429919407459], 
             UndirectedEdge[383, 479] -> 
             RGBColor[
              0.37021659707670174`, 0.49508474158579574`, 0.9448108520894127],
              UndirectedEdge[408, 430] -> 
             RGBColor[
              0.23112177962706493`, 0.36025402272821205`, 0.9364734154845045],
              UndirectedEdge[13, 390] -> 
             RGBColor[
              0.29868486413343276`, 0.4312671082913797, 0.9403210331965157], 
             UndirectedEdge[15, 97] -> 
             RGBColor[
              0.23298665056537604`, 0.36221412032402367`, 0.936579617125612], 
             UndirectedEdge[289, 472] -> 
             RGBColor[
              0.3839088844842855, 0.5069443127438695, 0.9456833125354096], 
             UndirectedEdge[254, 315] -> 
             RGBColor[
              0.21099893285942517`, 0.33910363491324724`, 0.9353274491301715],
              UndirectedEdge[347, 386] -> 
             RGBColor[0.178927, 0.305394, 0.933501], UndirectedEdge[66, 445] -> 
             RGBColor[
              0.24646019520379875`, 0.3763756700110764, 0.9373469155604471], 
             UndirectedEdge[127, 213] -> 
             RGBColor[
              0.5650928544862279, 0.5063763336200533, 0.5889799898461102], 
             UndirectedEdge[423, 446] -> 
             RGBColor[
              0.20798858239401255`, 0.3359395657068551, 0.9351560141245807], 
             UndirectedEdge[63, 410] -> 
             RGBColor[
              0.39150030357105375`, 0.5135196184010107, 0.9461670310467902], 
             UndirectedEdge[107, 421] -> 
             RGBColor[
              0.18186414913512938`, 0.30848112996703203`, 0.9336682662981228],
              UndirectedEdge[226, 308] -> 
             RGBColor[
              0.17918563853241248`, 0.3056658454961956, 0.9335157290817995], 
             UndirectedEdge[51, 386] -> 
             RGBColor[
              0.1789270004053139, 0.3053940004260106, 0.9335010000230821], 
             UndirectedEdge[89, 470] -> 
             RGBColor[
              0.27049191209474743`, 0.40163452816231904`, 0.9387154862856475],
              UndirectedEdge[205, 490] -> 
             RGBColor[
              0.9921900608993205, 0.9897828176678509, 0.6878265810358566], 
             UndirectedEdge[270, 345] -> 
             RGBColor[
              0.824874141314561, 0.8621219539632672, 0.8908628396870938], 
             UndirectedEdge[152, 191] -> 
             RGBColor[
              0.21120215837255008`, 0.3393172378127832, 0.9353390225224988], 
             UndirectedEdge[85, 404] -> 
             RGBColor[
              0.21383193119222793`, 0.3420812957834917, 0.9354887841941792], 
             UndirectedEdge[26, 468] -> 
             RGBColor[
              0.43250328030680874`, 0.5483539247359007, 0.9489677041209118], 
             UndirectedEdge[191, 301] -> 
             RGBColor[
              0.2135770306984165, 0.34181337920287114`, 0.935474267988148], 
             UndirectedEdge[375, 426] -> 
             RGBColor[
              0.9141879156308917, 0.9338323693009003, 0.9715587229445324], 
             UndirectedEdge[39, 213] -> 
             RGBColor[
              0.7639337426080279, 0.681629388750616, 0.6026477314488674], 
             UndirectedEdge[360, 468] -> 
             RGBColor[
              0.5288716731016017, 0.6284008754780657, 0.9560538619087819], 
             UndirectedEdge[80, 278] -> 
             RGBColor[
              0.8689533270990046, 0.8982632673699124, 0.9759744072003973], 
             UndirectedEdge[152, 299] -> 
             RGBColor[
              0.20658465608391344`, 0.3344639501408717, 0.9350760625981434], 
             UndirectedEdge[227, 309] -> 
             RGBColor[
              0.9193309660445672, 0.6696242794444807, 0.3370748612621325], 
             UndirectedEdge[98, 115] -> 
             RGBColor[
              0.9582015589575525, 0.9660972945461519, 0.85752593015656], 
             UndirectedEdge[213, 261] -> 
             RGBColor[
              0.8920963570986589, 0.602916583768641, 0.23167489421385412`], 
             UndirectedEdge[199, 208] -> 
             RGBColor[
              0.33248120157791744`, 0.46240023864087376`, 0.9424063860563303],
              UndirectedEdge[204, 219] -> 
             RGBColor[
              0.5140809753819581, 0.6163931207559199, 0.9548894840041806], 
             UndirectedEdge[52, 166] -> 
             RGBColor[
              0.8369577282992072, 0.2850788714533209, 0.18302406839809204`], 
             UndirectedEdge[218, 300] -> 
             RGBColor[
              0.22896529227619977`, 0.3579874177932576, 0.93635060672011], 
             UndirectedEdge[128, 345] -> 
             RGBColor[
              0.5772342034942839, 0.6673977284070023, 0.9600430222220963], 
             UndirectedEdge[325, 421] -> 
             RGBColor[
              0.17903676307516053`, 0.3055093679513746, 0.9335072508447505], 
             UndirectedEdge[257, 272] -> 
             RGBColor[
              0.8397181825766789, 0.3055916208213189, 0.18563986428858031`], 
             UndirectedEdge[461, 486] -> 
             RGBColor[
              0.9396915520193736, 0.9545227464327241, 0.9862809714214389], 
             UndirectedEdge[115, 203] -> 
             RGBColor[
              0.7278675078772177, 0.786501490374317, 0.9744226233622142], 
             UndirectedEdge[128, 169] -> 
             RGBColor[
              0.4937426983927686, 0.5998815912671589, 0.9532883803380281], 
             UndirectedEdge[190, 356] -> 
             RGBColor[
              0.2587237746657965, 0.38926546958148345`, 0.9380453082684679], 
             UndirectedEdge[46, 272] -> 
             RGBColor[
              0.8691188894851287, 0.4352254750326188, 0.20997245291222838`], 
             UndirectedEdge[121, 450] -> 
             RGBColor[
              0.8225872124582064, 0.17462078949919407`, 0.16926284619957344`],
              UndirectedEdge[255, 269] -> 
             RGBColor[
              0.4232624333249523, 0.5410303787827784, 0.94819088586856], 
             UndirectedEdge[15, 356] -> 
             RGBColor[
              0.2517883622305454, 0.38197591138148856`, 0.9376503467903037], 
             UndirectedEdge[85, 183] -> 
             RGBColor[
              0.20959144808050473`, 0.33762427917091264`, 0.9352472949541991],
              UndirectedEdge[136, 261] -> 
             RGBColor[
              0.924473739268195, 0.762150740681319, 0.5794980394919615], 
             UndirectedEdge[295, 336] -> 
             RGBColor[
              0.22591321478921644`, 0.3547794908415487, 0.9361767954223702], 
             UndirectedEdge[259, 475] -> 
             RGBColor[
              0.8504220451203991, 0.38316771966990754`, 0.19570591448943397`],
              UndirectedEdge[51, 143] -> 
             RGBColor[
              0.17892700107920537`, 0.30539400113431325`, 0.9335010000614592],
              UndirectedEdge[53, 178] -> 
             RGBColor[
              0.9840984713626098, 0.9616310168446078, 0.5753629014776818], 
             UndirectedEdge[67, 385] -> 
             RGBColor[
              0.24504732911062774`, 0.37489065816626943`, 0.9372664549265891],
              UndirectedEdge[69, 173] -> 
             RGBColor[
              0.9470127321552729, 0.9592645667466908, 0.9483609186014075], 
             UndirectedEdge[221, 381] -> 
             RGBColor[
              0.5529574414035745, 0.647954787237104, 0.9579499818185896], 
             UndirectedEdge[140, 334] -> 
             RGBColor[
              0.4512190714580578, 0.563987423855866, 0.9503197339204532], 
             UndirectedEdge[57, 370] -> 
             RGBColor[
              0.5963431626815656, 0.6831772702750474, 0.9613654647247267], 
             UndirectedEdge[432, 467] -> 
             RGBColor[
              0.8027318187709938, 0.8464550865365966, 0.9808037893677689], 
             UndirectedEdge[235, 440] -> 
             RGBColor[
              0.3193577814126447, 0.44853038543702994`, 0.9416618206484036], 
             UndirectedEdge[229, 390] -> 
             RGBColor[
              0.29586463316817824`, 0.4283028667339263, 0.9401604252152023], 
             UndirectedEdge[12, 198] -> 
             RGBColor[
              0.2771414265920781, 0.4086235895025834, 0.9390941662991953], 
             UndirectedEdge[232, 400] -> 
             RGBColor[
              0.3260597275402094, 0.45565259831853255`, 0.9420406290448107], 
             UndirectedEdge[143, 273] -> 
             RGBColor[
              0.23623420851912813`, 0.365627509640484, 0.9367645607467467], 
             UndirectedEdge[115, 277] -> 
             RGBColor[
              0.8462349559465709, 0.8806222819755531, 0.9850914215175051], 
             UndirectedEdge[44, 468] -> 
             RGBColor[
              0.48752713657842917`, 0.5948355181784093, 0.9527990685436503], 
             UndirectedEdge[183, 346] -> 
             RGBColor[
              0.21142499907593382`, 0.3395514575209563, 0.9353517129708931], 
             UndirectedEdge[434, 469] -> 
             RGBColor[
              0.9258166281861495, 0.7248800924627727, 0.5003559242994462], 
             UndirectedEdge[255, 334] -> 
             RGBColor[
              0.40019480220882075`, 0.5210503561228367, 0.9467210368117455], 
             UndirectedEdge[65, 210] -> 
             RGBColor[
              0.9107642708804349, 0.6204193391599911, 0.29010099455145133`], 
             UndirectedEdge[49, 76] -> 
             RGBColor[
              0.45077000854144356`, 0.5638542255344485, 0.9502204534950804], 
             UndirectedEdge[74, 395] -> 
             RGBColor[
              0.2733607929019397, 0.4046499037882272, 0.9388788648034883], 
             UndirectedEdge[52, 88] -> 
             RGBColor[
              0.8512025856554928, 0.3816657696999445, 0.19615962002028325`], 
             UndirectedEdge[312, 354] -> 
             RGBColor[
              0.3330876906173925, 0.4625247982993003, 0.942459704446583], 
             UndirectedEdge[372, 417] -> 
             RGBColor[
              0.5857428674141524, 0.6736726673586156, 0.9611454890036907], 
             UndirectedEdge[354, 415] -> 
             RGBColor[
              0.32438826492045936`, 0.4533811503163769, 0.9419642850227896], 
             UndirectedEdge[301, 451] -> 
             RGBColor[
              0.2100992490740445, 0.3381580102115655, 0.9352762134695569], 
             UndirectedEdge[243, 428] -> 
             RGBColor[
              0.8348198026853184, 0.2686458383399938, 0.18097678841579048`], 
             UndirectedEdge[102, 354] -> 
             RGBColor[
              0.3191507002330799, 0.44787613774915985`, 0.941666013462126], 
             UndirectedEdge[255, 369] -> 
             RGBColor[
              0.40876647484829665`, 0.5284747081383571, 0.9472672162127003], 
             UndirectedEdge[300, 409] -> 
             RGBColor[
              0.23375665444094554`, 0.3630234432183127, 0.936623467707207], 
             UndirectedEdge[93, 187] -> 
             RGBColor[
              0.2669566877883537, 0.3979187832701322, 0.9385141604912941], 
             UndirectedEdge[181, 332] -> 
             RGBColor[
              0.41144462504759094`, 0.5307943872332428, 0.947437865575204], 
             UndirectedEdge[195, 351] -> 
             RGBColor[
              0.2800986877606033, 0.41173185849189103`, 0.9392625779478669], 
             UndirectedEdge[480, 481] -> 
             RGBColor[
              0.33588196619861493`, 0.46534581002792214`, 0.9426230797707831],
              UndirectedEdge[47, 365] -> 
             RGBColor[
              0.22445415871552787`, 0.3532459303986038, 0.9360937043374536], 
             UndirectedEdge[50, 370] -> 
             RGBColor[
              0.5161906822110007, 0.6177697305042253, 0.9551484458009031], 
             UndirectedEdge[122, 150] -> 
             RGBColor[
              0.8444744803276283, 0.32854420856354566`, 0.1896617078466737], 
             UndirectedEdge[246, 256] -> 
             RGBColor[
              0.2918037733500637, 0.42403464559170456`, 0.9399291652560644], 
             UndirectedEdge[63, 282] -> 
             RGBColor[
              0.5134969921724348, 0.6149963149023026, 0.9550984560118821], 
             UndirectedEdge[230, 391] -> 
             RGBColor[
              0.23250262506826308`, 0.3617053788375689, 0.936552052589603], 
             UndirectedEdge[312, 415] -> 
             RGBColor[
              0.29571211190112656`, 0.42814255721184813`, 0.9401517393546788],
              UndirectedEdge[199, 397] -> 
             RGBColor[
              0.3506959657134314, 0.47817695183439113`, 0.9435670147203616], 
             UndirectedEdge[129, 328] -> 
             RGBColor[
              0.3704563897071251, 0.49529243790994043`, 0.944826131463783], 
             UndirectedEdge[188, 304] -> 
             RGBColor[
              0.33792059600024626`, 0.4671115686975821, 0.9427529794590535], 
             UndirectedEdge[323, 395] -> 
             RGBColor[
              0.25216611947306267`, 0.3823729581945666, 0.9376718595064233], 
             UndirectedEdge[49, 238] -> 
             RGBColor[
              0.4051843179606758, 0.5243701915568157, 0.9473157736011174], 
             UndirectedEdge[171, 385] -> 
             RGBColor[
              0.24760690614002792`, 0.37758093591072595`, 0.9374122190518586],
              UndirectedEdge[117, 425] -> 
             RGBColor[
              0.3782090614978762, 0.502007412554475, 0.9453201248548712], 
             UndirectedEdge[32, 103] -> 
             RGBColor[
              0.5080332189208779, 0.6114832796124914, 0.9544133824619024], 
             UndirectedEdge[131, 216] -> 
             RGBColor[
              0.26474751566428445`, 0.3955968032981327, 0.9383883514070055], 
             UndirectedEdge[65, 175] -> 
             RGBColor[
              0.9705975460870158, 0.9645679382577699, 0.6789276620320353], 
             UndirectedEdge[143, 226] -> 
             RGBColor[
              0.17917599682249857`, 0.3056557114477564, 0.9335151800006836], 
             UndirectedEdge[234, 235] -> 
             RGBColor[
              0.3728101836078023, 0.49733117588158576`, 0.9449761131297559], 
             UndirectedEdge[179, 386] -> 
             RGBColor[
              0.17892806853100302`, 0.30539512309383293`, 0.93350106085126], 
             UndirectedEdge[267, 476] -> 
             RGBColor[
              0.9187775169477521, 0.6742536840952063, 0.3030402150761125], 
             UndirectedEdge[59, 195] -> 
             RGBColor[
              0.2561715150223729, 0.3865828828736374, 0.9378999608575047], 
             UndirectedEdge[75, 108] -> 
             RGBColor[
              0.31502960292460824`, 0.4450992956026424, 0.9413743981617775], 
             UndirectedEdge[334, 363] -> 
             RGBColor[
              0.40380771802618465`, 0.5241796822134083, 0.9469512486128518], 
             UndirectedEdge[77, 329] -> 
             RGBColor[
              0.7446878798780471, 0.8004364154026, 0.9754252127138938], 
             UndirectedEdge[328, 462] -> 
             RGBColor[
              0.4245956854340748, 0.5418984360706564, 0.9483550662650316], 
             UndirectedEdge[285, 480] -> 
             RGBColor[
              0.3339827883337351, 0.46370083761681824`, 0.9425020658366099], 
             UndirectedEdge[204, 334] -> 
             RGBColor[
              0.4523485649591434, 0.5649043975631496, 0.9504086517863296], 
             UndirectedEdge[70, 238] -> 
             RGBColor[
              0.28920204195997834`, 0.42024532074903687`, 0.9398196197075317],
              UndirectedEdge[83, 270] -> 
             RGBColor[
              0.955384395176871, 0.9648919755228036, 0.9036547602559704], 
             UndirectedEdge[112, 190] -> 
             RGBColor[
              0.24818657202567745`, 0.37819020150948346`, 0.9374452301665075],
              UndirectedEdge[263, 453] -> 
             RGBColor[
              0.27885374219171843`, 0.41042334176488493`, 0.9391916801394509],
              UndirectedEdge[210, 474] -> 
             RGBColor[
              0.9145804341522545, 0.6348102980864267, 0.4731147536068143], 
             UndirectedEdge[96, 392] -> 
             RGBColor[
              0.3010815634219416, 0.43378619120311424`, 0.9404575216753974], 
             UndirectedEdge[70, 84] -> 
             RGBColor[
              0.24578222839824324`, 0.37566308391285935`, 0.9373083063538328],
              UndirectedEdge[77, 278] -> 
             RGBColor[
              0.7775908081460805, 0.8263457284855322, 0.9672404849556133], 
             UndirectedEdge[238, 265] -> 
             RGBColor[
              0.32058421295120315`, 0.4520956650524487, 0.9416483204611299], 
             UndirectedEdge[157, 392] -> 
             RGBColor[
              0.3042725009406671, 0.4371400688524187, 0.9406392408465198], 
             UndirectedEdge[145, 294] -> 
             RGBColor[
              0.22948545468760678`, 0.35853414146784807`, 0.9363802291999281],
              UndirectedEdge[29, 383] -> 
             RGBColor[
              0.3692814154214852, 0.49427473423964385`, 0.944751263141291], 
             UndirectedEdge[210, 227] -> 
             RGBColor[
              0.8408474405782448, 0.3149769045127923, 0.18674886126930004`], 
             UndirectedEdge[45, 276] -> 
             RGBColor[
              0.4511613140247853, 0.5582811601613382, 0.9513035162562244], 
             UndirectedEdge[57, 219] -> 
             RGBColor[
              0.5637559435916646, 0.6567214977803754, 0.9588000794670529], 
             UndirectedEdge[291, 311] -> 
             RGBColor[
              0.7008920044449292, 0.7662614279396891, 0.9708220228610445], 
             UndirectedEdge[11, 485] -> 
             RGBColor[
              0.24345966129558455`, 0.3732219186287056, 0.9371760395932665], 
             UndirectedEdge[13, 338] -> 
             RGBColor[
              0.30836079438708164`, 0.4403868770076641, 0.9409105178148355], 
             UndirectedEdge[190, 351] -> 
             RGBColor[
              0.2690775343767192, 0.40014792750394457`, 0.9386349395669901], 
             UndirectedEdge[314, 397] -> 
             RGBColor[
              0.34431176305958455`, 0.4726472763749843, 0.9431602189725873], 
             UndirectedEdge[339, 365] -> 
             RGBColor[
              0.2143326753092825, 0.34260760959952685`, 0.9355173008308608], 
             UndirectedEdge[320, 337] -> 
             RGBColor[
              0.9244065988908812, 0.9404637664434601, 0.9125392493325524], 
             UndirectedEdge[317, 357] -> 
             RGBColor[
              0.895271303645258, 0.6164935275347583, 0.23428070819651722`], 
             UndirectedEdge[153, 452] -> 
             RGBColor[
              0.2344431943228335, 0.36374504016331954`, 0.9366625651378359], 
             UndirectedEdge[308, 423] -> 
             RGBColor[
              0.1833860881198116, 0.31008078433643804`, 0.9337549384717936], 
             UndirectedEdge[149, 441] -> 
             RGBColor[
              0.4020035872776604, 0.5226170348372846, 0.946836290996886], 
             UndirectedEdge[486, 493] -> 
             RGBColor[
              0.9642524295918031, 0.9698103203224957, 0.7679790459557528], 
             UndirectedEdge[241, 402] -> 
             RGBColor[
              0.6288966867837086, 0.7086387216585579, 0.9645893173262957], 
             UndirectedEdge[293, 432] -> 
             RGBColor[
              0.9264483908194477, 0.943709860746635, 0.9762410122023322], 
             UndirectedEdge[23, 211] -> 
             RGBColor[
              0.226770956748013, 0.3556810320242251, 0.9362256425580082], 
             UndirectedEdge[8, 381] -> 
             RGBColor[
              0.5947992155017207, 0.6819238244004215, 0.9612439195470645], 
             UndirectedEdge[238, 343] -> 
             RGBColor[
              0.306520714368336, 0.43844834351747275`, 0.9408058924805078], 
             UndirectedEdge[355, 363] -> 
             RGBColor[
              0.366759080123219, 0.492090014180544, 0.9445905421664991], 
             UndirectedEdge[66, 398] -> 
             RGBColor[
              0.26221606410223275`, 0.392936087203117, 0.9382441889854937], 
             UndirectedEdge[113, 477] -> 
             RGBColor[
              0.2119319440670913, 0.3400842888488316, 0.9353805827381816], 
             UndirectedEdge[7, 241] -> 
             RGBColor[
              0.7720821236708154, 0.8220268199822758, 0.9778774834237032], 
             UndirectedEdge[161, 259] -> 
             RGBColor[
              0.9260863286561598, 0.722291136783578, 0.31168537193130974`], 
             UndirectedEdge[346, 408] -> 
             RGBColor[
              0.22019359510263653`, 0.34876780790611966`, 0.9358510715426385],
              UndirectedEdge[33, 270] -> 
             RGBColor[
              0.9342186701882929, 0.7654658229940685, 0.5176324949764846], 
             UndirectedEdge[197, 270] -> 
             RGBColor[
              0.843824355466433, 0.8769260052856713, 0.8927516199339326], 
             UndirectedEdge[115, 381] -> 
             RGBColor[
              0.7452365910783697, 0.8006024945852935, 0.9757899812168571], 
             UndirectedEdge[112, 224] -> 
             RGBColor[
              0.2736149088479135, 0.4049169957593272, 0.9388933363306806], 
             UndirectedEdge[133, 296] -> 
             RGBColor[
              0.3292967430314739, 0.4596420207034847, 0.942203475173657], 
             UndirectedEdge[204, 244] -> 
             RGBColor[
              0.42216704011068096`, 0.5387626777069581, 0.9484855117114601], 
             UndirectedEdge[116, 280] -> 
             RGBColor[
              0.25280916302349343`, 0.3830488377373854, 0.9377084798853226], 
             UndirectedEdge[81, 267] -> 
             RGBColor[
              0.906340376624757, 0.9184812574076573, 0.6975246745106891], 
             UndirectedEdge[431, 459] -> 
             RGBColor[
              0.41954302397723237`, 0.5378088133487329, 0.9479538883938678], 
             UndirectedEdge[46, 293] -> 
             RGBColor[
              0.9359635798708703, 0.8383264425596675, 0.6074452935938994], 
             UndirectedEdge[145, 358] -> 
             RGBColor[
              0.2231421897482483, 0.351866967830356, 0.9360189896456512], 
             UndirectedEdge[12, 480] -> 
             RGBColor[
              0.31297532312712917`, 0.4421451064609878, 0.9412865192071291], 
             UndirectedEdge[318, 321] -> 
             RGBColor[
              0.33755888801482614`, 0.46679827542058316`, 0.9427299317460682],
              UndirectedEdge[38, 47] -> 
             RGBColor[
              0.24595116399713765`, 0.375840645938433, 0.9373179269862719], 
             UndirectedEdge[271, 492] -> 
             RGBColor[
              0.2662123163354113, 0.39713640167721365`, 0.9384717696382479], 
             UndirectedEdge[246, 333] -> 
             RGBColor[
              0.33643527177961996`, 0.46448215779697133`, 0.9427075059768388],
              UndirectedEdge[97, 137] -> 
             RGBColor[
              0.2259075246268314, 0.35477351012010483`, 0.9361764713760403], 
             UndirectedEdge[406, 486] -> 
             RGBColor[
              0.9627729895914936, 0.9654828212213326, 0.7058550168364002], 
             UndirectedEdge[272, 306] -> 
             RGBColor[
              0.8390812230199529, 0.30140098239829205`, 0.18505752934082234`],
              UndirectedEdge[50, 219] -> 
             RGBColor[
              0.48360346312109975`, 0.5913139580095534, 0.9525830605432293], 
             UndirectedEdge[326, 405] -> 
             RGBColor[
              0.9345940973525277, 0.7578425175728066, 0.403625723074449], 
             UndirectedEdge[180, 343] -> 
             RGBColor[
              0.28150922552658186`, 0.4132144231171943, 0.9393429059869358], 
             UndirectedEdge[229, 380] -> 
             RGBColor[
              0.2819134302618612, 0.4136392679220333, 0.9393659248486427], 
             UndirectedEdge[184, 470] -> 
             RGBColor[
              0.2562569900664413, 0.3866727225643841, 0.9379048285348154], 
             UndirectedEdge[188, 483] -> 
             RGBColor[
              0.31696315839045336`, 0.4478408551549855, 0.9414585414299963], 
             UndirectedEdge[364, 374] -> 
             RGBColor[
              0.2551484985501697, 0.3855076276983612, 0.93784170158283], 
             UndirectedEdge[161, 469] -> 
             RGBColor[
              0.9253813180460291, 0.7190898482623855, 0.3110970937968252], 
             UndirectedEdge[14, 182] -> 
             RGBColor[
              0.34266467028924463`, 0.47103542678761523`, 0.9430620495117685],
              UndirectedEdge[374, 391] -> 
             RGBColor[
              0.24642877472957408`, 0.3763426451004932, 0.9373451262109225], 
             UndirectedEdge[352, 367] -> 
             RGBColor[
              0.2288379775147259, 0.35785360190672644`, 0.9363433563327893], 
             UndirectedEdge[8, 289] -> 
             RGBColor[
              0.5298323406094952, 0.6288020963090049, 0.9562341229930127], 
             UndirectedEdge[160, 275] -> 
             RGBColor[
              0.4180928553323577, 0.5365527501561378, 0.9478614849301503], 
             UndirectedEdge[118, 151] -> 
             RGBColor[
              0.31595121433390305`, 0.44790234871507695`, 0.9413597168905753],
              UndirectedEdge[43, 217] -> 
             RGBColor[
              0.30643378623989703`, 0.43839711764350564`, 0.9407994722898634],
              UndirectedEdge[117, 154] -> 
             RGBColor[
              0.34530823850037556`, 0.4735103733174856, 0.9432237135065259], 
             UndirectedEdge[139, 468] -> 
             RGBColor[
              0.5212061017709153, 0.6221776193417614, 0.9554504000537172], 
             UndirectedEdge[279, 324] -> 
             RGBColor[
              0.3241188367997081, 0.45236629730551653`, 0.9419757314019449], 
             UndirectedEdge[4, 29] -> 
             RGBColor[
              0.36696197867847585`, 0.49226575471112954`, 0.9446034706830237],
              UndirectedEdge[239, 393] -> 
             RGBColor[
              0.4060710006373207, 0.5259256972403187, 0.9471546820617923], 
             UndirectedEdge[94, 127] -> 
             RGBColor[
              0.5906994451507328, 0.6605608453144329, 0.9482643190369882], 
             UndirectedEdge[157, 459] -> 
             RGBColor[
              0.3465448636437761, 0.4740080224761397, 0.94332350710475], 
             UndirectedEdge[48, 85] -> 
             RGBColor[
              0.21086321568284044`, 0.3389609875556907, 0.9353197202377406], 
             UndirectedEdge[26, 215] -> 
             RGBColor[
              0.33537631974199883`, 0.4626312893738342, 0.942674216260174], 
             UndirectedEdge[63, 165] -> 
             RGBColor[
              0.42168442508772075`, 0.5396635873606885, 0.9480903365790616], 
             UndirectedEdge[165, 282] -> 
             RGBColor[
              0.5158458225400988, 0.6170307537111264, 0.9552481214059205], 
             UndirectedEdge[288, 465] -> 
             RGBColor[
              0.2693457460924733, 0.4004298350228071, 0.9386502138274186], 
             UndirectedEdge[200, 500] -> 
             RGBColor[
              0.8601603348227043, 0.3966998445648045, 0.2026301493422178], 
             UndirectedEdge[293, 353] -> 
             RGBColor[
              0.7969674264911133, 0.8418814193634385, 0.9635324755439242], 
             UndirectedEdge[239, 296] -> 
             RGBColor[
              0.33217516852493173`, 0.46213516819204603`, 0.9423868859008084],
              UndirectedEdge[139, 274] -> 
             RGBColor[
              0.5133847204187874, 0.6158278696108893, 0.9548346722630138], 
             UndirectedEdge[140, 361] -> 
             RGBColor[
              0.5719177559547599, 0.6633194007954346, 0.9594619041005235], 
             UndirectedEdge[83, 197] -> 
             RGBColor[
              0.8091856625186589, 0.8516756760168047, 0.981399600787607], 
             UndirectedEdge[256, 444] -> 
             RGBColor[
              0.28033959264989716`, 0.411985064804791, 0.9392762971249253], 
             UndirectedEdge[21, 166] -> 
             RGBColor[
              0.9095040888434207, 0.6206039273550481, 0.282195231981873], 
             UndirectedEdge[92, 363] -> 
             RGBColor[
              0.506974473041424, 0.6093066729422614, 0.9546939442160238], 
             UndirectedEdge[41, 212] -> 
             RGBColor[
              0.22552146354030395`, 0.35436773544047784`, 0.9361544857682886],
              UndirectedEdge[96, 433] -> 
             RGBColor[
              0.31083399291217784`, 0.4424870131772134, 0.9410696465455513], 
             UndirectedEdge[346, 407] -> 
             RGBColor[
              0.2161204994130187, 0.34448672608714886`, 0.9356191147687198], 
             UndirectedEdge[32, 155] -> 
             RGBColor[
              0.5507999265063706, 0.6462032194486154, 0.9577801343426442], 
             UndirectedEdge[302, 477] -> 
             RGBColor[
              0.21741049289010705`, 0.3458425910218791, 0.9356925779888657], 
             UndirectedEdge[24, 489] -> 
             RGBColor[
              0.9135348042436461, 0.9315079481929074, 0.8990421753997224], 
             UndirectedEdge[359, 427] -> 
             RGBColor[
              0.3324756951564906, 0.4596914885288097, 0.9425050411722034], 
             UndirectedEdge[217, 290] -> 
             RGBColor[
              0.3031025001174864, 0.43489572471311266`, 0.9406097604733883], 
             UndirectedEdge[40, 297] -> 
             RGBColor[
              0.4527821832454718, 0.5648055930283604, 0.9505673549688282], 
             UndirectedEdge[41, 456] -> 
             RGBColor[
              0.22809260204387605`, 0.3570701650273288, 0.9363009083024085], 
             UndirectedEdge[341, 469] -> 
             RGBColor[
              0.927002024559022, 0.7238962731152077, 0.3735657841038871], 
             UndirectedEdge[169, 498] -> 
             RGBColor[
              0.4773158479045384, 0.5865455340196324, 0.9519951984940587], 
             UndirectedEdge[6, 329] -> 
             RGBColor[
              0.8551238518896912, 0.8873165640509703, 0.9860436704429549], 
             UndirectedEdge[92, 219] -> 
             RGBColor[
              0.5677032440041356, 0.6599260940790765, 0.9591108254149605], 
             UndirectedEdge[341, 387] -> 
             RGBColor[
              0.8843435887930974, 0.9064532397024012, 0.7600495256450741], 
             UndirectedEdge[13, 478] -> 
             RGBColor[
              0.28132910192119526`, 0.41302510178743673`, 0.939332648214078], 
             UndirectedEdge[33, 267] -> 
             RGBColor[
              0.9337384293685642, 0.7577785430140971, 0.3161344657047144], 
             UndirectedEdge[10, 123] -> 
             RGBColor[
              0.21296296597852177`, 0.34116795824830987`, 0.9354392979107774],
              UndirectedEdge[57, 337] -> 
             RGBColor[
              0.730726843956438, 0.7892639238928545, 0.9741400277373693], 
             UndirectedEdge[70, 135] -> 
             RGBColor[
              0.25443846593234043`, 0.3847613383983545, 0.9378012662756438], 
             UndirectedEdge[51, 130] -> 
             RGBColor[
              0.1789270004053139, 0.3053940004260106, 0.9335010000230821], 
             UndirectedEdge[219, 361] -> 
             RGBColor[
              0.5852351734855985, 0.6741310802897922, 0.9605102999918589], 
             UndirectedEdge[70, 131] -> 
             RGBColor[
              0.2609296066664183, 0.3915839388719636, 0.9381709271376673], 
             UndirectedEdge[61, 362] -> 
             RGBColor[
              0.3561441161626767, 0.48289586592152384`, 0.9439141660493773], 
             UndirectedEdge[49, 487] -> 
             RGBColor[
              0.5348230464505574, 0.633232468469062, 0.9565223758194106], 
             UndirectedEdge[83, 375] -> 
             RGBColor[
              0.9394735703012015, 0.9539944639741937, 0.9739704912597569], 
             UndirectedEdge[147, 385] -> 
             RGBColor[
              0.24248237828575928`, 0.37219473222205746`, 0.9371203847716176],
              UndirectedEdge[105, 395] -> 
             RGBColor[
              0.2554464216840092, 0.38582076380144426`, 0.9378586678645644], 
             UndirectedEdge[57, 204] -> 
             RGBColor[
              0.5515680195619116, 0.6468267919933015, 0.9578406014415939], 
             UndirectedEdge[362, 363] -> 
             RGBColor[
              0.3966364490357477, 0.5179682894523514, 0.9464943016940854], 
             UndirectedEdge[313, 390] -> 
             RGBColor[
              0.28385568108857195`, 0.41568069668672125`, 0.9394765331599213],
              UndirectedEdge[15, 430] -> 
             RGBColor[
              0.23698890967688827`, 0.36642074840810707`, 0.9368075398612009],
              UndirectedEdge[104, 430] -> 
             RGBColor[
              0.24315634658411125`, 0.3729031156356836, 0.937158766269162], 
             UndirectedEdge[341, 405] -> 
             RGBColor[
              0.9937930272646951, 0.989132237877419, 0.5657875066366207], 
             UndirectedEdge[8, 311] -> 
             RGBColor[
              0.6835752486050087, 0.752395433322769, 0.9693271520415703], 
             UndirectedEdge[305, 460] -> 
             RGBColor[
              0.24972906299601538`, 0.37981145731888477`, 0.9375330727453572],
              UndirectedEdge[451, 456] -> 
             RGBColor[
              0.21755217330464396`, 0.3459915061206145, 0.9357006464788762], 
             UndirectedEdge[257, 306] -> 
             RGBColor[
              0.8582164736566054, 0.4477775920644729, 0.2033538487175496], 
             UndirectedEdge[65, 167] -> 
             RGBColor[
              0.986067541242265, 0.9756937071602725, 0.6343029674871418], 
             UndirectedEdge[24, 329] -> 
             RGBColor[
              0.8597649491834076, 0.8910172490537498, 0.986486342445986], 
             UndirectedEdge[14, 63] -> 
             RGBColor[
              0.3630391373968948, 0.48868276614576933`, 0.9443602925394342], 
             UndirectedEdge[64, 172] -> 
             RGBColor[
              0.31974345189880926`, 0.449434024298521, 0.9416655397334055], 
             UndirectedEdge[50, 361] -> 
             RGBColor[
              0.5425697371949871, 0.6391572117563517, 0.9572443985054486], 
             UndirectedEdge[253, 291] -> 
             RGBColor[
              0.819979493708928, 0.8592158126034372, 0.9319826199336896], 
             UndirectedEdge[184, 280] -> 
             RGBColor[
              0.2569621251304517, 0.38741386422480434`, 0.9379449849335569], 
             UndirectedEdge[402, 487] -> 
             RGBColor[
              0.565871305361324, 0.6584388437609466, 0.958966608494386], 
             UndirectedEdge[356, 463] -> 
             RGBColor[
              0.26821764598055253`, 0.3992441302795001, 0.9385859701949193], 
             UndirectedEdge[287, 301] -> 
             RGBColor[
              0.20928219811004087`, 0.33729923784437454`, 0.9352296836258756],
              UndirectedEdge[265, 328] -> 
             RGBColor[
              0.35316375548579293`, 0.48031442730049023`, 0.9437242601024758],
              UndirectedEdge[196, 321] -> 
             RGBColor[
              0.31443739392836134`, 0.4455653460211614, 0.9413008174322348], 
             UndirectedEdge[122, 267] -> 
             RGBColor[
              0.9282834555711476, 0.7330087810415269, 0.3115827018545064], 
             UndirectedEdge[330, 354] -> 
             RGBColor[
              0.3341066984387609, 0.463595840128386, 0.9425177354345229], 
             UndirectedEdge[155, 393] -> 
             RGBColor[
              0.5135503027141461, 0.615962296777659, 0.9548477075078524], 
             UndirectedEdge[291, 319] -> 
             RGBColor[
              0.6849084125962169, 0.7537749245076777, 0.969228927800723], 
             UndirectedEdge[63, 206] -> 
             RGBColor[
              0.3810348762200533, 0.5044549912372471, 0.9455001832701985], 
             UndirectedEdge[174, 215] -> 
             RGBColor[
              0.2753901052316153, 0.40678283971254936`, 0.9389944311385647], 
             UndirectedEdge[254, 471] -> 
             RGBColor[
              0.5466554162409889, 0.4017985093907806, 0.5694083486000513], 
             UndirectedEdge[453, 463] -> 
             RGBColor[
              0.2757020968027919, 0.407110762635264, 0.939012198596993], 
             UndirectedEdge[154, 174] -> 
             RGBColor[
              0.2880991557381853, 0.4200673355937856, 0.9397208847641902], 
             UndirectedEdge[119, 197] -> 
             RGBColor[
              0.8441364985929255, 0.8770550844901885, 0.8875786005274353], 
             UndirectedEdge[50, 340] -> 
             RGBColor[
              0.3891862943583425, 0.5115153399264449, 0.9460195844259542], 
             UndirectedEdge[443, 446] -> 
             RGBColor[
              0.5813316267430582, 0.5676003433786956, 0.6012346277346379], 
             UndirectedEdge[275, 324] -> 
             RGBColor[
              0.3916907059243627, 0.5136845353495464, 0.9461791633163769], 
             UndirectedEdge[95, 286] -> 
             RGBColor[
              0.22509159237078977`, 0.3539159135859121, 0.9361300052411223], 
             UndirectedEdge[306, 317] -> 
             RGBColor[
              0.8704899188810679, 0.5035084402927961, 0.2135951122625132], 
             UndirectedEdge[118, 188] -> 
             RGBColor[
              0.3311926249986076, 0.4612841383736176, 0.9423242790961401], 
             UndirectedEdge[7, 69] -> 
             RGBColor[
              0.874072307624645, 0.9024255483118935, 0.9878509910664408], 
             UndirectedEdge[88, 166] -> 
             RGBColor[
              0.8523652692557177, 0.3906026653424749, 0.19727300714892185`], 
             UndirectedEdge[9, 44] -> 
             RGBColor[
              0.5359104641208152, 0.634115283121385, 0.9566079813217554], 
             UndirectedEdge[76, 459] -> 
             RGBColor[
              0.40093570974009674`, 0.5216920929873327, 0.9467682467844796], 
             UndirectedEdge[254, 325] -> 
             RGBColor[
              0.20775758490962407`, 0.33569677270467635`, 0.935142859159575], 
             UndirectedEdge[171, 433] -> 
             RGBColor[
              0.2936242383072788, 0.42439846992600005`, 0.9400895764803525], 
             UndirectedEdge[112, 447] -> 
             RGBColor[
              0.2473817363738829, 0.37734426820991973`, 0.9373993959667855], 
             UndirectedEdge[199, 359] -> 
             RGBColor[
              0.364147570424561, 0.48982805573786037`, 0.9444241390777679], 
             UndirectedEdge[74, 224] -> 
             RGBColor[
              0.2903501525391211, 0.42250679795452123`, 0.9398463837013205], 
             UndirectedEdge[292, 386] -> 
             RGBColor[
              0.17894881608916835`, 0.3054169300929359, 0.9335022423940041], 
             UndirectedEdge[112, 195] -> 
             RGBColor[
              0.25920772540956155`, 0.3897741324974299, 0.9380728685473844], 
             UndirectedEdge[97, 408] -> 
             RGBColor[
              0.2271195205155527, 0.3560473946441286, 0.9362454927489157], 
             UndirectedEdge[236, 422] -> 
             RGBColor[
              0.26066758061653217`, 0.39130853288012224`, 0.9381560051417591],
              UndirectedEdge[27, 114] -> 
             RGBColor[
              0.5063987002640795, 0.610156303732676, 0.9542847071658003], 
             UndirectedEdge[110, 355] -> 
             RGBColor[
              0.30021105187484454`, 0.43102571577490256`, 0.9404755205872981],
              UndirectedEdge[104, 215] -> 
             RGBColor[
              0.26534838496499225`, 0.39622835503049064`, 0.9384225700247744],
              UndirectedEdge[80, 406] -> 
             RGBColor[
              0.8900806471760057, 0.9077659645302347, 0.6988562638191269], 
             UndirectedEdge[276, 292] -> 
             RGBColor[
              0.39925539426111123`, 0.5037247474643232, 0.9483475509136101], 
             UndirectedEdge[425, 466] -> 
             RGBColor[
              0.4394255113443823, 0.5536672437102792, 0.9495973233231294], 
             UndirectedEdge[164, 309] -> 
             RGBColor[
              0.9052777371288019, 0.5616050038337315, 0.3236174733815438], 
             UndirectedEdge[95, 137] -> 
             RGBColor[
              0.22358173079098384`, 0.35232895333478276`, 0.9360440208577924],
              UndirectedEdge[119, 426] -> 
             RGBColor[
              0.9304108836330538, 0.9448589600540273, 0.8960699725342486], 
             UndirectedEdge[238, 431] -> 
             RGBColor[
              0.38434692528377257`, 0.5073237216678145, 0.9457112241078087], 
             UndirectedEdge[93, 266] -> 
             RGBColor[
              0.2794030113306438, 0.41100065845557043`, 0.9392229602043418], 
             UndirectedEdge[15, 148] -> 
             RGBColor[
              0.2369473179686802, 0.36637703288571377`, 0.9368051712749479], 
             UndirectedEdge[225, 470] -> 
             RGBColor[
              0.26486570011979793`, 0.3957210226542046, 0.9383950818369088], 
             UndirectedEdge[249, 296] -> 
             RGBColor[
              0.3014838445951241, 0.4337768875889444, 0.9404962532659576], 
             UndirectedEdge[273, 421] -> 
             RGBColor[
              0.236299010735822, 0.36569562087892715`, 0.9367682511371211], 
             UndirectedEdge[150, 159] -> 
             RGBColor[
              0.821097410502475, 0.1631695188320622, 0.16783621016427433`], 
             UndirectedEdge[85, 407] -> 
             RGBColor[
              0.2142869484175896, 0.3425595477371053, 0.9355146967520258], 
             UndirectedEdge[71, 388] -> 
             RGBColor[
              0.8509768197746642, 0.8842586853652235, 0.9761468351078537], 
             UndirectedEdge[61, 435] -> 
             RGBColor[
              0.2909721876561818, 0.42176628331072286`, 0.9399328603098349], 
             UndirectedEdge[10, 177] -> 
             RGBColor[
              0.21382948684753797`, 0.34207872662224226`, 0.9354886449923652],
              UndirectedEdge[16, 52] -> 
             RGBColor[
              0.6198385630520318, 0.4001930339226935, 0.5644333341255259], 
             UndirectedEdge[25, 459] -> 
             RGBColor[
              0.35196069990557133`, 0.47927240102423385`, 0.9436476024647243],
              UndirectedEdge[105, 453] -> 
             RGBColor[
              0.265106051538209, 0.39597364723411466`, 0.9384087694946193], 
             UndirectedEdge[61, 384] -> 
             RGBColor[
              0.3038237458344487, 0.43527408579193255`, 0.9406647375359107], 
             UndirectedEdge[104, 323] -> 
             RGBColor[
              0.2429591667599799, 0.3726958671385986, 0.9371475371698791], 
             UndirectedEdge[150, 406] -> 
             RGBColor[
              0.9060315184464693, 0.5729271685521393, 0.29311167174990027`], 
             UndirectedEdge[413, 493] -> 
             RGBColor[
              0.9837066431260291, 0.9560378233723712, 0.44758049868418615`], 
             UndirectedEdge[94, 254] -> 
             RGBColor[
              0.5959586642234989, 0.6660886180136586, 0.9485638237828649], 
             UndirectedEdge[431, 487] -> 
             RGBColor[
              0.5139856537736541, 0.6161859985800608, 0.9549178263261018], 
             UndirectedEdge[234, 332] -> 
             RGBColor[
              0.3953853483413155, 0.5168846489129837, 0.946414582664141], 
             UndirectedEdge[82, 89] -> 
             RGBColor[
              0.2718901700216876, 0.4031041858982062, 0.9387951150060494], 
             UndirectedEdge[154, 255] -> 
             RGBColor[
              0.3535633647009796, 0.4806605487177418, 0.9437497228483069], 
             UndirectedEdge[22, 324] -> 
             RGBColor[
              0.41054698853962773`, 0.5300168996065678, 0.9473806689706655], 
             UndirectedEdge[105, 112] -> 
             RGBColor[
              0.2470843980758506, 0.3770317468063509, 0.9373824629905851], 
             UndirectedEdge[6, 406] -> 
             RGBColor[
              0.9091541002347256, 0.9227285742942248, 0.700740799303404], 
             UndirectedEdge[396, 422] -> 
             RGBColor[
              0.6137790328303492, 0.6759479174311498, 0.7377723993512193], 
             UndirectedEdge[409, 456] -> 
             RGBColor[
              0.23260709522442666`, 0.3618151835954873, 0.9365580020104467], 
             UndirectedEdge[91, 473] -> 
             RGBColor[
              0.32723005291391416`, 0.4578519575985201, 0.9420717875068684], 
             UndirectedEdge[369, 379] -> 
             RGBColor[
              0.3646233115605392, 0.49024011879839996`, 0.944454452882271], 
             UndirectedEdge[353, 441] -> 
             RGBColor[
              0.5448974710637005, 0.6413248437593597, 0.9573393706579376], 
             UndirectedEdge[165, 481] -> 
             RGBColor[
              0.3711249763330434, 0.49587153404117, 0.9448687332123786], 
             UndirectedEdge[185, 318] -> 
             RGBColor[
              0.3129435362062064, 0.4431846498190406, 0.9412454229080396], 
             UndirectedEdge[264, 445] -> 
             RGBColor[
              0.23221275436386601`, 0.3614007063483834, 0.9365355448818129], 
             UndirectedEdge[258, 297] -> 
             RGBColor[
              0.4463933258988235, 0.5592718859080008, 0.9501602626281445], 
             UndirectedEdge[57, 139] -> 
             RGBColor[
              0.5826390838232848, 0.6720516816961779, 0.9602866294373078], 
             UndirectedEdge[447, 463] -> 
             RGBColor[
              0.2567986541117429, 0.38724204581948013`, 0.9379356755008752], 
             UndirectedEdge[9, 26] -> 
             RGBColor[
              0.4808866078491948, 0.5876336896788764, 0.952776616899017], 
             UndirectedEdge[181, 262] -> 
             RGBColor[
              0.4483915053521436, 0.5621777184210172, 0.9499628984888329], 
             UndirectedEdge[203, 291] -> 
             RGBColor[
              0.5947468881404891, 0.681688814806365, 0.9613714325118958], 
             UndirectedEdge[45, 254] -> 
             RGBColor[
              0.25964036057789125`, 0.3902288594899984, 0.9380975064801944], 
             UndirectedEdge[240, 412] -> 
             RGBColor[
              0.2495035202048371, 0.3795743975451175, 0.9375202284170604], 
             UndirectedEdge[208, 258] -> 
             RGBColor[
              0.3477704837485026, 0.4756430463953687, 0.9433806055964585], 
             UndirectedEdge[293, 420] -> 
             RGBColor[
              0.9614575711812897, 0.9707757002112165, 0.9501264579014013], 
             UndirectedEdge[85, 346] -> 
             RGBColor[
              0.21604910573121133`, 0.34441168680094847`, 0.9356150490041585],
              UndirectedEdge[65, 166] -> 
             RGBColor[
              0.9117926198146232, 0.6283236796935395, 0.2910857426521841], 
             UndirectedEdge[254, 347] -> 
             RGBColor[
              0.20771262472504887`, 0.3356495167000475, 0.935140298743576], 
             UndirectedEdge[236, 292] -> 
             RGBColor[
              0.23314689454244097`, 0.36238254690397387`, 0.9365887427830462],
              UndirectedEdge[100, 401] -> 
             RGBColor[
              0.8523336151346661, 0.7939714926704016, 0.620783111215081], 
             UndirectedEdge[146, 400] -> 
             RGBColor[
              0.276927529490606, 0.4083987700870767, 0.9390819851756989], 
             UndirectedEdge[104, 153] -> 
             RGBColor[
              0.24575331572793313`, 0.3756326948631943, 0.937306659820031], 
             UndirectedEdge[216, 281] -> 
             RGBColor[
              0.2553973215721218, 0.3857691564707237, 0.9378558716858294], 
             UndirectedEdge[123, 125] -> 
             RGBColor[
              0.2078185513522534, 0.33576085230137553`, 0.9351463311082908], 
             UndirectedEdge[78, 358] -> 
             RGBColor[
              0.22252765585105994`, 0.3512210537407115, 0.9359839928493279], 
             UndirectedEdge[313, 478] -> 
             RGBColor[
              0.26649991887633445`, 0.3974386901827782, 0.9384881481774836], 
             UndirectedEdge[368, 401] -> 
             RGBColor[
              0.5907770138305127, 0.6754225066218276, 0.9626395084549426], 
             UndirectedEdge[106, 369] -> 
             RGBColor[
              0.46890138102995677`, 0.5788082013626439, 0.9515831360340911], 
             UndirectedEdge[111, 146] -> 
             RGBColor[
              0.2655122364597581, 0.39640057334027434`, 0.9384319011250047], 
             UndirectedEdge[129, 266] -> 
             RGBColor[
              0.32256025857167225`, 0.4520297101069751, 0.9418393155552645], 
             UndirectedEdge[99, 278] -> 
             RGBColor[
              0.9709926371751241, 0.9748878865987054, 0.7597061890098948], 
             UndirectedEdge[147, 171] -> 
             RGBColor[
              0.2566176973332457, 0.3870518487719572, 0.9379253702800414], 
             UndirectedEdge[164, 166] -> 
             RGBColor[
              0.8278225605966679, 0.21486196943559147`, 0.17427622148944416`],
              UndirectedEdge[129, 433] -> 
             RGBColor[
              0.3405530126531223, 0.4693916356931953, 0.94292071472042], 
             UndirectedEdge[179, 283] -> 
             RGBColor[
              0.18007164814629245`, 0.3065970977766376, 0.9335661860185762], 
             UndirectedEdge[136, 291] -> 
             RGBColor[
              0.8119439013123007, 0.853362410017863, 0.9518331785269256], 
             UndirectedEdge[321, 479] -> 
             RGBColor[
              0.37233306340343797`, 0.49691791834132404`, 0.9449457114522347],
              UndirectedEdge[181, 239] -> 
             RGBColor[
              0.38581385669695734`, 0.5085943039277986, 0.9458046956803003], 
             UndirectedEdge[102, 330] -> 
             RGBColor[
              0.2914935550351155, 0.4237085864737168, 0.939911498781955], 
             UndirectedEdge[406, 413] -> 
             RGBColor[
              0.9822272031257195, 0.951710324271208, 0.3854564695648335], 
             UndirectedEdge[37, 310] -> 
             RGBColor[
              0.30119863479716524`, 0.4339092406412282, 0.9404641887170249], 
             UndirectedEdge[203, 439] -> 
             RGBColor[
              0.6977395599110665, 0.7624782824674698, 0.971548992789666], 
             UndirectedEdge[320, 375] -> 
             RGBColor[
              0.9734019680069053, 0.9789510679067093, 0.8970939407523506], 
             UndirectedEdge[42, 407] -> 
             RGBColor[
              0.22341630550160935`, 0.352155080867081, 0.9360346001322872], 
             UndirectedEdge[131, 374] -> 
             RGBColor[
              0.2576696859737398, 0.38815755553304865`, 0.9379852794768397], 
             UndirectedEdge[387, 403] -> 
             RGBColor[
              0.8520128910253049, 0.8851986373727346, 0.9856507029983317], 
             UndirectedEdge[65, 348] -> 
             RGBColor[
              0.9726882187211612, 0.9195330900145834, 0.3483993164391773], 
             UndirectedEdge[217, 498] -> 
             RGBColor[
              0.3908046357587574, 0.5126843292737169, 0.9461870095342384], 
             UndirectedEdge[40, 397] -> 
             RGBColor[
              0.37237410523066483`, 0.4969534667092458, 0.9449483266011737], 
             UndirectedEdge[226, 292] -> 
             RGBColor[
              0.17919781223777545`, 0.3056786408323896, 0.9335164223563106], 
             UndirectedEdge[53, 257] -> 
             RGBColor[
              0.9176828698612274, 0.692200433274696, 0.28359567952116765`], 
             UndirectedEdge[220, 429] -> 
             RGBColor[
              0.3162555864633567, 0.44694588722950834`, 0.9414237848069549], 
             UndirectedEdge[139, 425] -> 
             RGBColor[
              0.469689014710176, 0.5782365190979204, 0.9519797771669503], 
             UndirectedEdge[317, 418] -> 
             RGBColor[
              0.9309369071770426, 0.7734480360326559, 0.5728708276939365], 
             UndirectedEdge[482, 496] -> 
             RGBColor[
              0.31768549080207875`, 0.4466395905233832, 0.9415714600344062], 
             UndirectedEdge[117, 466] -> 
             RGBColor[
              0.44229172329685795`, 0.5561498124435122, 0.9497799558142495], 
             UndirectedEdge[82, 105] -> 
             RGBColor[
              0.25209194686734443`, 0.382294998083142, 0.9376676354862561], 
             UndirectedEdge[239, 453] -> 
             RGBColor[
              0.31761867457160725`, 0.44726749674536337`, 0.9415420928317004],
              UndirectedEdge[274, 340] -> 
             RGBColor[
              0.40008441142440987`, 0.5206990676119785, 0.9467846461754836], 
             UndirectedEdge[311, 484] -> 
             RGBColor[
              0.8698742834500395, 0.8946869579845022, 0.7215434088969761], 
             UndirectedEdge[44, 140] -> 
             RGBColor[
              0.4981556569200065, 0.6034642298010868, 0.9536357845984921], 
             UndirectedEdge[139, 466] -> 
             RGBColor[
              0.5337716765091578, 0.6323789189869576, 0.9564396081263286], 
             UndirectedEdge[22, 481] -> 
             RGBColor[
              0.38481661217346425`, 0.507730540844516, 0.9457411521410921], 
             UndirectedEdge[45, 386] -> 
             RGBColor[
              0.23085473585284239`, 0.35997334278995086`, 0.9364582077366184],
              UndirectedEdge[40, 220] -> 
             RGBColor[
              0.36255668140028763`, 0.48845010762544216`, 0.9443227690359091],
              UndirectedEdge[237, 489] -> 
             RGBColor[
              0.9480949935467251, 0.959065305031835, 0.9023385571076953], 
             UndirectedEdge[61, 64] -> 
             RGBColor[
              0.3058305702683475, 0.43738338551197825`, 0.9407790232185906], 
             UndirectedEdge[82, 296] -> 
             RGBColor[
              0.28584922180975014`, 0.4173439077491774, 0.9396058846276822], 
             UndirectedEdge[27, 277] -> 
             RGBColor[
              0.6417102241932708, 0.7180330594388474, 0.9662874050409727], 
             UndirectedEdge[416, 427] -> 
             RGBColor[
              0.2705169061527906, 0.4016607985020373, 0.9387169096602777], 
             UndirectedEdge[59, 82] -> 
             RGBColor[
              0.25023486400687867`, 0.3803430862509384, 0.9375618773646605], 
             UndirectedEdge[271, 444] -> 
             RGBColor[
              0.26354918336029226`, 0.3943372800679805, 0.938320108155067], 
             UndirectedEdge[6, 486] -> 
             RGBColor[
              0.8813087089314302, 0.9081956582870432, 0.9885412054830938], 
             UndirectedEdge[171, 265] -> 
             RGBColor[
              0.29137836531202577`, 0.42245320761837074`, 0.9399464714390425],
              UndirectedEdge[219, 369] -> 
             RGBColor[
              0.47310816162837227`, 0.5822234553657439, 0.9519143092127434], 
             UndirectedEdge[244, 355] -> 
             RGBColor[
              0.3355739158146536, 0.46507899226839733`, 0.9426034510727153], 
             UndirectedEdge[450, 500] -> 
             RGBColor[
              0.8186005728713881, 0.14397773067830186`, 0.16544523562897076`],
              UndirectedEdge[18, 243] -> 
             RGBColor[
              0.8618450148200435, 0.43551288339499367`, 0.2052561643181862], 
             UndirectedEdge[377, 449] -> 
             RGBColor[
              0.8547039434845443, 0.8865518671157351, 0.9452111853810878], 
             UndirectedEdge[7, 173] -> 
             RGBColor[
              0.9116225315818571, 0.9310453814508525, 0.9449853696775101], 
             UndirectedEdge[3, 8] -> 
             RGBColor[
              0.5409798313044035, 0.6382308237734111, 0.9570070604761514], 
             UndirectedEdge[405, 469] -> 
             RGBColor[
              0.9272216806853377, 0.724366095358756, 0.3974739978928766], 
             UndirectedEdge[148, 190] -> 
             RGBColor[
              0.2438827304039313, 0.37366659108570865`, 0.9372001327531121], 
             UndirectedEdge[180, 216] -> 
             RGBColor[
              0.2680084621160904, 0.3990242647749275, 0.9385740574832979], 
             UndirectedEdge[257, 317] -> 
             RGBColor[
              0.8711268784377937, 0.5076990787158229, 0.21417744721027115`], 
             UndirectedEdge[49, 462] -> 
             RGBColor[
              0.4770465403942916, 0.586326898050649, 0.9519739976203461], 
             UndirectedEdge[223, 258] -> 
             RGBColor[
              0.3816431136278576, 0.5049818159089863, 0.9455389396199805], 
             UndirectedEdge[260, 440] -> 
             RGBColor[
              0.28362513416460355`, 0.4154383772521112, 0.9394634038536649], 
             UndirectedEdge[262, 332] -> 
             RGBColor[
              0.43913893362174417`, 0.5541636058359223, 0.9493733327998998], 
             UndirectedEdge[283, 386] -> 
             RGBColor[
              0.18007057961528944`, 0.30659597468280464`, 0.9335661251673164],
              UndirectedEdge[40, 289] -> 
             RGBColor[
              0.41278560473143366`, 0.5319558764357888, 0.9475233116148768], 
             UndirectedEdge[95, 430] -> 
             RGBColor[
              0.23341097282813747`, 0.36266010992577125`, 0.9366037816507478],
              UndirectedEdge[274, 334] -> 
             RGBColor[
              0.4327691697643524, 0.5490089625023165, 0.9488672900749079], 
             UndirectedEdge[75, 158] -> 
             RGBColor[
              0.3512349205505469, 0.4786437674256428, 0.9436013564460036], 
             UndirectedEdge[233, 476] -> 
             RGBColor[
              0.8458261121541704, 0.35324515591315253`, 0.19151644279301172`],
              UndirectedEdge[240, 416] -> 
             RGBColor[
              0.2590796192147955, 0.38963948476432886`, 0.9380655730891085], 
             UndirectedEdge[260, 280] -> 
             RGBColor[
              0.27123440340689225`, 0.4024149336080515, 0.9387577700674566], 
             UndirectedEdge[11, 193] -> 
             RGBColor[
              0.2633649248993141, 0.3941436127428313, 0.9383096149083003], 
             UndirectedEdge[3, 162] -> 
             RGBColor[
              0.4618487252450588, 0.5739886270587315, 0.9507775699403673], 
             UndirectedEdge[117, 338] -> 
             RGBColor[
              0.3505903006321732, 0.47808543005188675`, 0.9435602818348199], 
             UndirectedEdge[40, 472] -> 
             RGBColor[
              0.35732343693452717`, 0.4839173342997152, 0.9439893113261273], 
             UndirectedEdge[101, 355] -> 
             RGBColor[
              0.424769765192925, 0.5405027707410431, 0.9487934456872616], 
             UndirectedEdge[47, 364] -> 
             RGBColor[
              0.24525016381875867`, 0.3751038503049783, 0.93727800606315], 
             UndirectedEdge[377, 484] -> 
             RGBColor[
              0.9869984046810305, 0.9863165950507087, 0.692275872605006], 
             UndirectedEdge[21, 227] -> 
             RGBColor[
              0.9132594664564218, 0.6494694053055374, 0.28579138582517527`], 
             UndirectedEdge[158, 441] -> 
             RGBColor[
              0.4038268661048062, 0.5241962673166999, 0.9469524687114896], 
             UndirectedEdge[201, 222] -> 
             RGBColor[
              0.3735862388275236, 0.49760697262793063`, 0.9450400762157048], 
             UndirectedEdge[107, 477] -> 
             RGBColor[
              0.21467165996386678`, 0.3429639039643634, 0.9355366055054566], 
             UndirectedEdge[89, 239] -> 
             RGBColor[
              0.31821611673686917`, 0.4478954463410748, 0.9415761162791756], 
             UndirectedEdge[63, 275] -> 
             RGBColor[
              0.41651977831287657`, 0.5351902299070133, 0.9477612498534863], 
             UndirectedEdge[133, 344] -> 
             RGBColor[
              0.404458323018091, 0.5244601408973477, 0.9470709156438875], 
             UndirectedEdge[153, 356] -> 
             RGBColor[
              0.2571354474729763, 0.3875960369960689, 0.9379548553845563], 
             UndirectedEdge[151, 188] -> 
             RGBColor[
              0.32203573450029344`, 0.4531724542663287, 0.9417474171352478], 
             UndirectedEdge[140, 204] -> 
             RGBColor[
              0.5007635578511195, 0.6055814412615623, 0.9538410881128452], 
             UndirectedEdge[154, 369] -> 
             RGBColor[
              0.36474431369771637`, 0.4903449247678786, 0.944462163031454], 
             UndirectedEdge[16, 179] -> 
             RGBColor[
              0.29140560923354364`, 0.4148201691111312, 0.940228554342059], 
             UndirectedEdge[161, 341] -> 
             RGBColor[
              0.9919526646253864, 0.9838559907810486, 0.4794106025405692], 
             UndirectedEdge[48, 408] -> 
             RGBColor[
              0.21500770505426564`, 0.34331710866086196`, 0.9355557427762207],
              UndirectedEdge[153, 263] -> 
             RGBColor[
              0.25916680795964386`, 0.3897311256632503, 0.9380705383591434], 
             UndirectedEdge[62, 132] -> 
             RGBColor[
              0.9037259559281465, 0.5621573598635239, 0.4887023579770914], 
             UndirectedEdge[82, 225] -> 
             RGBColor[
              0.2662639580467382, 0.39719068039009175`, 0.9384747105573108], 
             UndirectedEdge[216, 465] -> 
             RGBColor[
              0.27425578181697063`, 0.40559059388349944`, 0.9389298330981818],
              UndirectedEdge[119, 489] -> 
             RGBColor[
              0.9903724843514137, 0.9902867891105125, 0.8092163797162932], 
             UndirectedEdge[287, 295] -> 
             RGBColor[
              0.2196997994484176, 0.34824879736508285`, 0.9358229506106359], 
             UndirectedEdge[28, 417] -> 
             RGBColor[
              0.8329443683967894, 0.8698408046783143, 0.9576048606613091], 
             UndirectedEdge[148, 351] -> 
             RGBColor[
              0.26485064633186906`, 0.3957052001686261, 0.9383942245459564], 
             UndirectedEdge[218, 336] -> 
             RGBColor[
              0.2271057420788739, 0.35603291263357584`, 0.9362447080873302], 
             UndirectedEdge[127, 254] -> 
             RGBColor[
              0.23123903037733173`, 0.3603772607008694, 0.9364800927412753], 
             UndirectedEdge[303, 473] -> 
             RGBColor[
              0.31604489027716914`, 0.44784149062043943`, 0.9413708849892584],
              UndirectedEdge[99, 267] -> 
             RGBColor[
              0.9913420700473246, 0.9817665875606343, 0.479566100729647], 
             UndirectedEdge[48, 145] -> 
             RGBColor[
              0.21408452170973263`, 0.34234678443255295`, 0.9355031688504769],
              UndirectedEdge[224, 342] -> 
             RGBColor[
              0.2794767176957349, 0.41107812851853454`, 0.939227157672795], 
             UndirectedEdge[193, 232] -> 
             RGBColor[
              0.32200467219797546`, 0.4513904780484862, 0.9418096996419872], 
             UndirectedEdge[216, 343] -> 
             RGBColor[
              0.2793867448603114, 0.4109835613638972, 0.9392220338529205], 
             UndirectedEdge[277, 449] -> 
             RGBColor[
              0.7498021540184663, 0.8044704085174408, 0.9756969294792002], 
             UndirectedEdge[257, 418] -> 
             RGBColor[
              0.9186634619525802, 0.7177171878043327, 0.5626295641489729], 
             UndirectedEdge[45, 422] -> 
             RGBColor[
              0.2583972380161019, 0.3889222588590351, 0.9380267124893356], 
             UndirectedEdge[133, 235] -> 
             RGBColor[
              0.3511076947395869, 0.47853357082274445`, 0.9435932497298307], 
             UndirectedEdge[145, 183] -> 
             RGBColor[
              0.21281275410739692`, 0.3410100760477749, 0.9354307435669353], 
             UndirectedEdge[196, 496] -> 
             RGBColor[
              0.2862944389618104, 0.41824398583767475`, 0.9396154168129832], 
             UndirectedEdge[115, 136] -> 
             RGBColor[
              0.9450645210490293, 0.9581750855858149, 0.964884369377244], 
             UndirectedEdge[267, 413] -> 
             RGBColor[
              0.981449315920919, 0.9490863280728146, 0.38243452466585603`], 
             UndirectedEdge[217, 340] -> 
             RGBColor[
              0.32857716094804046`, 0.4590187548700618, 0.9421576240396021], 
             UndirectedEdge[335, 383] -> 
             RGBColor[
              0.3028573462736385, 0.4337853452642071, 0.940627021112898], 
             UndirectedEdge[80, 493] -> 
             RGBColor[
              0.8915600871763152, 0.912093463631398, 0.7609802929384797], 
             UndirectedEdge[307, 372] -> 
             RGBColor[
              0.47013131999468205`, 0.580712810603117, 0.9514296061392018], 
             UndirectedEdge[18, 434] -> 
             RGBColor[
              0.9377932493402739, 0.7792631319127137, 0.510349510564296], 
             UndirectedEdge[130, 179] -> 
             RGBColor[
              0.17892806853100302`, 0.30539512309383293`, 0.93350106085126], 
             UndirectedEdge[20, 228] -> 
             RGBColor[
              0.9388076655030091, 0.7780938721344945, 0.3568427286125849], 
             UndirectedEdge[297, 311] -> 
             RGBColor[
              0.6331105387907436, 0.7114259084862791, 0.9653543852266682], 
             UndirectedEdge[127, 200] -> 
             RGBColor[
              0.5634039093287206, 0.4987072281229762, 0.587570692606852], 
             UndirectedEdge[54, 391] -> 
             RGBColor[
              0.23492401226674847`, 0.36425041030799266`, 0.9366899470084354],
              UndirectedEdge[347, 368] -> 
             RGBColor[
              0.2935143249909316, 0.4166464351270609, 0.9403629270800464], 
             UndirectedEdge[22, 182] -> 
             RGBColor[
              0.4150015938204914, 0.5338752548058805, 0.9476645124801093], 
             UndirectedEdge[96, 216] -> 
             RGBColor[
              0.2810238579235662, 0.4127042709923413, 0.9393152650199811], 
             UndirectedEdge[340, 363] -> 
             RGBColor[
              0.37112295968624204`, 0.49586978732307024`, 0.9448686047134276],
              UndirectedEdge[71, 490] -> 
             RGBColor[
              0.8731675486403643, 0.8997516085621015, 0.891254202422064], 
             UndirectedEdge[111, 201] -> 
             RGBColor[
              0.28877500860148286`, 0.42085122180616963`, 0.9397566815842886],
              UndirectedEdge[261, 484] -> 
             RGBColor[
              0.9364392575786439, 0.7675671876801757, 0.34462692180178206`], 
             UndirectedEdge[416, 499] -> 
             RGBColor[
              0.26112616120390136`, 0.3917905301531358, 0.9381821206278006], 
             UndirectedEdge[42, 430] -> 
             RGBColor[
              0.2361066473396595, 0.36549343475301654`, 0.9367572963262859], 
             UndirectedEdge[6, 81] -> 
             RGBColor[
              0.825653983169494, 0.8638180906717614, 0.9832328080563602], 
             UndirectedEdge[282, 353] -> 
             RGBColor[
              0.6236604649477651, 0.705354686885191, 0.9635159828256973], 
             UndirectedEdge[275, 441] -> 
             RGBColor[
              0.43191818188119013`, 0.5485275531316196, 0.9487424225125856], 
             UndirectedEdge[50, 255] -> 
             RGBColor[
              0.41926177634102413`, 0.5375652107821666, 0.9479359675431862], 
             UndirectedEdge[110, 217] -> 
             RGBColor[
              0.29571753049971145`, 0.4271336534107135, 0.9401891973787395], 
             UndirectedEdge[30, 110] -> 
             RGBColor[
              0.26982326266389456`, 0.40093173521567016`, 0.9386774076897386],
              UndirectedEdge[77, 482] -> 
             RGBColor[
              0.4826496570055525, 0.5883007255405965, 0.9531265853256541], 
             UndirectedEdge[52, 326] -> 
             RGBColor[
              0.8554852780065134, 0.4011124754177182, 0.19973320349637064`], 
             UndirectedEdge[44, 247] -> 
             RGBColor[
              0.4958443155073958, 0.6015877787175854, 0.9534538273357688], 
             UndirectedEdge[337, 348] -> 
             RGBColor[
              0.9100611549268829, 0.8839036332529456, 0.6426467308354947], 
             UndirectedEdge[48, 78] -> 
             RGBColor[
              0.21346998781254425`, 0.3417008703429085, 0.9354681720541533], 
             UndirectedEdge[420, 432] -> 
             RGBColor[
              0.933633649289228, 0.949068614748616, 0.9640782438285385], 
             UndirectedEdge[469, 474] -> 
             RGBColor[
              0.9267639161265591, 0.7252718203703219, 0.4846569116242533], 
             UndirectedEdge[172, 366] -> 
             RGBColor[
              0.3083293758751098, 0.43743710670339436`, 0.941015524989468], 
             UndirectedEdge[102, 415] -> 
             RGBColor[
              0.28177512151681394`, 0.41349389666170766`, 0.9393580483702217],
              UndirectedEdge[414, 485] -> 
             RGBColor[
              0.26132957932407624`, 0.39200433549489333`, 0.9381937049888145],
              UndirectedEdge[102, 193] -> 
             RGBColor[
              0.2821746373958698, 0.4139138131813651, 0.9393808002085031], 
             UndirectedEdge[128, 498] -> 
             RGBColor[
              0.4783163619958606, 0.5873577964316139, 0.9520739626283314], 
             UndirectedEdge[150, 443] -> 
             RGBColor[
              0.8779783180841267, 0.47195372718941886`, 0.21716686938390278`],
              UndirectedEdge[2, 230] -> 
             RGBColor[
              0.21816285424353754`, 0.34663337050679954`, 0.9357354238549247],
              UndirectedEdge[367, 416] -> 
             RGBColor[
              0.24568937276892794`, 0.3755654867590621, 0.9373030183631108], 
             UndirectedEdge[61, 473] -> 
             RGBColor[
              0.3253289757704718, 0.4562053401277858, 0.9419506525523447], 
             UndirectedEdge[56, 164] -> 
             RGBColor[
              0.8270991589089857, 0.20930158706742483`, 0.17358349121635427`],
              UndirectedEdge[20, 388] -> 
             RGBColor[
              0.9153530643766437, 0.7639768167303482, 0.6006827363489642], 
             UndirectedEdge[195, 296] -> 
             RGBColor[
              0.29178587282524443`, 0.4235837043718764, 0.9399439681205266], 
             UndirectedEdge[135, 391] -> 
             RGBColor[
              0.24587699790050546`, 0.37576269266847045`, 0.9373137033367878],
              UndirectedEdge[310, 399] -> 
             RGBColor[
              0.26912901254486776`, 0.40020203432257306`, 0.938637871172511], 
             UndirectedEdge[150, 476] -> 
             RGBColor[
              0.834968541704233, 0.26978911161722496`, 0.18111922106827977`], 
             UndirectedEdge[142, 222] -> 
             RGBColor[
              0.5711190039988594, 0.6615355308329243, 0.9600580034664301], 
             UndirectedEdge[48, 404] -> 
             RGBColor[
              0.21047959213928613`, 0.3385577748882776, 0.9352978734444553], 
             UndirectedEdge[330, 415] -> 
             RGBColor[
              0.29673111972249494`, 0.4292135990409338, 0.9402097703426187], 
             UndirectedEdge[326, 495] -> 
             RGBColor[
              0.8586889913459645, 0.42573762002087545`, 0.2028010830083056], 
             UndirectedEdge[36, 382] -> 
             RGBColor[
              0.26830699274776615`, 0.39933803939675394`, 0.9385910583611354],
              UndirectedEdge[31, 289] -> 
             RGBColor[
              0.4462046575439149, 0.5609017802915265, 0.9496527441087801], 
             UndirectedEdge[436, 487] -> 
             RGBColor[
              0.5261755956139467, 0.6262120783166807, 0.9558416168128965], 
             UndirectedEdge[251, 427] -> 
             RGBColor[
              0.2690226652198594, 0.4000902565411794, 0.9386318148496786], 
             UndirectedEdge[108, 437] -> 
             RGBColor[
              0.27047057871071917`, 0.40161210542309067`, 0.938714271380987], 
             UndirectedEdge[258, 397] -> 
             RGBColor[
              0.36598524788401654`, 0.49141975958888606`, 0.94454123426049], 
             UndirectedEdge[308, 422] -> 
             RGBColor[
              0.20647914454706495`, 0.3343530508258261, 0.9350700538722102], 
             UndirectedEdge[16, 292] -> 
             RGBColor[
              0.29142635679170903`, 0.41484197611023416`, 0.9402297358848033],
              UndirectedEdge[68, 317] -> 
             RGBColor[
              0.8516933912786147, 0.35903009244942585`, 0.19559553620276254`],
              UndirectedEdge[34, 468] -> 
             RGBColor[
              0.51106504599871, 0.6139446534165288, 0.9546520589954179], 
             UndirectedEdge[350, 383] -> 
             RGBColor[
              0.34555625661750283`, 0.4737251941447882, 0.9432395170016354], 
             UndirectedEdge[190, 342] -> 
             RGBColor[
              0.25404838087349885`, 0.38435133426869084`, 0.9377790515086218],
              UndirectedEdge[61, 303] -> 
             RGBColor[
              0.31454260624684305`, 0.4465402877003618, 0.9412751607792637], 
             UndirectedEdge[214, 421] -> 
             RGBColor[
              0.18943186031713002`, 0.3164352742399168, 0.9340992362545124], 
             UndirectedEdge[219, 370] -> 
             RGBColor[
              0.5588561185016121, 0.6527435990376659, 0.9584143472873132], 
             UndirectedEdge[91, 366] -> 
             RGBColor[
              0.29631757138809034`, 0.4270330853875859, 0.9402501434291768], 
             UndirectedEdge[273, 477] -> 
             RGBColor[
              0.2691065215645594, 0.4001783948762585, 0.9386365903444549], 
             UndirectedEdge[153, 323] -> 
             RGBColor[
              0.24213881509518778`, 0.3718336255256024, 0.9371008193561707], 
             UndirectedEdge[170, 433] -> 
             RGBColor[
              0.31109341012253816`, 0.4427596771133032, 0.9410844199719078], 
             UndirectedEdge[1, 54] -> 
             RGBColor[
              0.24744314331957223`, 0.3774088108032645, 0.937402893001499], 
             UndirectedEdge[277, 377] -> 
             RGBColor[
              0.8762033212681233, 0.9033473444415901, 0.9473540424354466], 
             UndirectedEdge[307, 417] -> 
             RGBColor[
              0.5854211152910297, 0.6734114544902967, 0.9611201594979415], 
             UndirectedEdge[58, 371] -> 
             RGBColor[
              0.3390278312734188, 0.4680706002399412, 0.9428235315115703], 
             UndirectedEdge[9, 269] -> 
             RGBColor[
              0.512041509774998, 0.614618499836106, 0.9547617797005311], 
             UndirectedEdge[184, 453] -> 
             RGBColor[
              0.2706693526642461, 0.401821029451244, 0.9387255912635806], 
             UndirectedEdge[42, 97] -> 
             RGBColor[
              0.23210438822814727`, 0.3612868066689332, 0.936529373590697], 
             UndirectedEdge[161, 405] -> 
             RGBColor[
              0.9921723207517021, 0.9843258130245969, 0.5033188163295588], 
             UndirectedEdge[304, 429] -> 
             RGBColor[
              0.316081007071654, 0.4467946753350308, 0.9414126607624902], 
             UndirectedEdge[127, 130] -> 
             RGBColor[
              0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993],
              UndirectedEdge[318, 330] -> 
             RGBColor[
              0.32419593809646025`, 0.45501163764918373`, 0.9418862305492528],
              UndirectedEdge[393, 468] -> 
             RGBColor[
              0.4697942541627981, 0.5804391653761509, 0.9514030710822032], 
             UndirectedEdge[334, 355] -> 
             RGBColor[
              0.36575544066311605`, 0.49122071212458884`, 0.9445265911475849],
              UndirectedEdge[290, 378] -> 
             RGBColor[
              0.28478483318943354`, 0.41665729445637256`, 0.939529446997508], 
             UndirectedEdge[92, 498] -> 
             RGBColor[
              0.5355135500520953, 0.6337930503996233, 0.9565767347923217], 
             UndirectedEdge[340, 362] -> 
             RGBColor[
              0.3629480512357022, 0.4887890925060583, 0.944347706775747], 
             UndirectedEdge[58, 304] -> 
             RGBColor[
              0.3268378953241502, 0.4575122904046801, 0.94204679957202], 
             UndirectedEdge[51, 308] -> 
             RGBColor[
              0.1789366427891193, 0.3054041351827525, 0.9335015491425751], 
             UndirectedEdge[59, 447] -> 
             RGBColor[
              0.2443455259866942, 0.3741530185861272, 0.9372264882769058], 
             UndirectedEdge[186, 485] -> 
             RGBColor[
              0.24185580045044375`, 0.3715361591898116, 0.9370847020908353], 
             UndirectedEdge[340, 379] -> 
             RGBColor[
              0.32336688058112073`, 0.45450587189254155`, 0.941825629581892], 
             UndirectedEdge[129, 410] -> 
             RGBColor[
              0.3596323931506261, 0.48591723612258636`, 0.9441364359744873], 
             UndirectedEdge[192, 225] -> 
             RGBColor[
              0.26443196618769516`, 0.395265140791245, 0.9383703813311275], 
             UndirectedEdge[306, 420] -> 
             RGBColor[
              0.9131111718754747, 0.7098607039273219, 0.5703676016486996], 
             UndirectedEdge[16, 45] -> 
             RGBColor[
              0.343332276555383, 0.46939838880724916`, 0.9431857012274175], 
             UndirectedEdge[334, 361] -> 
             RGBColor[
              0.5235027630627838, 0.6226423570970218, 0.9560294677740079], 
             UndirectedEdge[306, 357] -> 
             RGBColor[
              0.8823608988640697, 0.5565720408834082, 0.22345710970379568`], 
             UndirectedEdge[335, 496] -> 
             RGBColor[
              0.27683085763382376`, 0.40829716183624876`, 0.9390764798564684],
              UndirectedEdge[176, 345] -> 
             RGBColor[
              0.6333349002315553, 0.7129428013259062, 0.9644594745728776], 
             UndirectedEdge[15, 78] -> 
             RGBColor[
              0.22683394628673456`, 0.35574723802318886`, 0.9362292297190538],
              UndirectedEdge[52, 210] -> 
             RGBColor[
              0.8359293793650189, 0.2771745309197725, 0.1820393202973592], 
             UndirectedEdge[392, 465] -> 
             RGBColor[
              0.2943134873153461, 0.42667251409427237`, 0.9400720897535981], 
             UndirectedEdge[354, 414] -> 
             RGBColor[
              0.3182109057650159, 0.4468883541768137, 0.941612493557471], 
             UndirectedEdge[56, 428] -> 
             RGBColor[
              0.8335035522712653, 0.25852856087297227`, 0.179716345532801], 
             UndirectedEdge[44, 425] -> 
             RGBColor[
              0.43601004951768985`, 0.5508944179345684, 0.9493284456568833], 
             UndirectedEdge[106, 468] -> 
             RGBColor[
              0.4981161809408796, 0.6034321814228589, 0.9536326769048099], 
             UndirectedEdge[142, 461] -> 
             RGBColor[
              0.8219899053555546, 0.8616442791794481, 0.9747961115925544], 
             UndirectedEdge[203, 297] -> 
             RGBColor[
              0.5269654224863035, 0.6268532953529551, 0.9559037948775195], 
             UndirectedEdge[24, 176] -> 
             RGBColor[
              0.7219583100603643, 0.7823133904412213, 0.9732561905650118], 
             UndirectedEdge[351, 356] -> 
             RGBColor[
              0.2796916905937343, 0.4113040786644009, 0.9392394000613121], 
             UndirectedEdge[315, 368] -> 
             RGBColor[
              0.2968006331253079, 0.42010055334026064`, 0.9405500774666419], 
             UndirectedEdge[278, 406] -> 
             RGBColor[
              0.969491060817788, 0.9705130400681918, 0.6951727540379807], 
             UndirectedEdge[247, 360] -> 
             RGBColor[
              0.5371888520305683, 0.6351531360172418, 0.9567086207009003], 
             UndirectedEdge[78, 145] -> 
             RGBColor[
              0.22004363289237822`, 0.3486101881149849, 0.9358425314166136], 
             UndirectedEdge[19, 466] -> 
             RGBColor[
              0.5316163498821903, 0.6306291277348275, 0.9562699329190321], 
             UndirectedEdge[60, 151] -> 
             RGBColor[
              0.2997519610227203, 0.4323886947798715, 0.9403818027857322], 
             UndirectedEdge[109, 186] -> 
             RGBColor[
              0.24483520726957755`, 0.37466770466202415`, 0.9372543749015474],
              UndirectedEdge[474, 495] -> 
             RGBColor[
              0.917649812825669, 0.658402887580602, 0.4760539940908434], 
             UndirectedEdge[36, 412] -> 
             RGBColor[
              0.24838538806776134`, 0.3783991697753788, 0.9374565524459821], 
             UndirectedEdge[259, 469] -> 
             RGBColor[
              0.8611356885897954, 0.46233141911773723`, 0.2058405534946276], 
             UndirectedEdge[6, 80] -> 
             RGBColor[
              0.8086163665159423, 0.8504788015959455, 0.9815424524658205], 
             UndirectedEdge[287, 389] -> 
             RGBColor[
              0.214155749354975, 0.34242164920379625`, 0.9355072251595016], 
             UndirectedEdge[158, 410] -> 
             RGBColor[
              0.3605931713874897, 0.48674941394123933`, 0.9441976559141574], 
             UndirectedEdge[414, 415] -> 
             RGBColor[
              0.2808353270487499, 0.4125061130893616, 0.9393045284655668], 
             UndirectedEdge[10, 245] -> 
             RGBColor[
              0.22026264269435236`, 0.3488403813028832, 0.93585500370084], 
             UndirectedEdge[115, 178] -> 
             RGBColor[
              0.9564265081535962, 0.965404037867567, 0.8899068420398936], 
             UndirectedEdge[88, 348] -> 
             RGBColor[
              0.9132608681622556, 0.6818120756635188, 0.2545865809359151], 
             UndirectedEdge[135, 170] -> 
             RGBColor[
              0.2736536686143132, 0.40495773473132446`, 0.9388955436420372], 
             UndirectedEdge[3, 203] -> 
             RGBColor[
              0.49811633466717364`, 0.6034323062247897, 0.9536326890067068], 
             UndirectedEdge[84, 374] -> 
             RGBColor[
              0.24252230770556474`, 0.3722367005739444, 0.9371226586930053], 
             UndirectedEdge[29, 172] -> 
             RGBColor[
              0.3806363827099919, 0.5041098361876981, 0.9454747916161113], 
             UndirectedEdge[262, 387] -> 
             RGBColor[
              0.6255998101870561, 0.7048955003973141, 0.9650590620780228], 
             UndirectedEdge[179, 276] -> 
             RGBColor[
              0.39923464670294595`, 0.5037029404652202, 0.9483463693708659], 
             UndirectedEdge[348, 428] -> 
             RGBColor[
              0.8951225528654855, 0.5552983535621828, 0.23772264959288408`], 
             UndirectedEdge[104, 351] -> 
             RGBColor[
              0.2683095588486911, 0.39934073653152624`, 0.9385912044967868], 
             UndirectedEdge[111, 271] -> 
             RGBColor[
              0.2644482810539334, 0.39528228875008364`, 0.938371310438624], 
             UndirectedEdge[136, 277] -> 
             RGBColor[
              0.8701310969045036, 0.8988186894535575, 0.9576327343932979], 
             UndirectedEdge[246, 442] -> 
             RGBColor[
              0.28908336711974203`, 0.42117532615991926`, 0.939774242145728], 
             UndirectedEdge[206, 266] -> 
             RGBColor[
              0.31612745049209645`, 0.4464579350707817, 0.9414294227127427], 
             UndirectedEdge[31, 381] -> 
             RGBColor[
              0.5111715324361403, 0.6140235083829432, 0.9546625406628318], 
             UndirectedEdge[31, 472] -> 
             RGBColor[
              0.39074248974700837`, 0.5128632381554529, 0.9461187438200305], 
             UndirectedEdge[342, 453] -> 
             RGBColor[
              0.27214698791275327`, 0.40337411778491095`, 0.9388097404050177],
              UndirectedEdge[200, 475] -> 
             RGBColor[
              0.8699156991968737, 0.47168384997259694`, 0.2119718972840306], 
             UndirectedEdge[92, 101] -> 
             RGBColor[
              0.5649851581111299, 0.6577194295027604, 0.9588968477367864], 
             UndirectedEdge[193, 376] -> 
             RGBColor[
              0.2836334092052663, 0.4154470748445156, 0.9394638751049887], 
             UndirectedEdge[253, 319] -> 
             RGBColor[
              0.8499607656875054, 0.8826374101392084, 0.934970872933598], 
             UndirectedEdge[249, 280] -> 
             RGBColor[
              0.27322012310800536`, 0.4045020509158221, 0.938870853866826], 
             UndirectedEdge[153, 195] -> 
             RGBColor[
              0.2575424446398453, 0.3880238168235591, 0.9379780332711112], 
             UndirectedEdge[313, 380] -> 
             RGBColor[
              0.26990447818225494`, 0.4010170978748282, 0.9386820327933616], 
             UndirectedEdge[178, 357] -> 
             RGBColor[
              0.9494134599221778, 0.8301932628763469, 0.5158066666080678], 
             UndirectedEdge[163, 494] -> 
             RGBColor[
              0.262747921993954, 0.39349510356905415`, 0.938274477505614], 
             UndirectedEdge[24, 237] -> 
             RGBColor[
              0.871532203465174, 0.9004001382044219, 0.9876087136641327], 
             UndirectedEdge[101, 345] -> 
             RGBColor[
              0.5902789610650883, 0.677988050262613, 0.9610699533225915], 
             UndirectedEdge[320, 361] -> 
             RGBColor[
              0.8164019725999951, 0.8557645940777792, 0.9018606390244552], 
             UndirectedEdge[328, 487] -> 
             RGBColor[
              0.4823721914903405, 0.5888040064890694, 0.952903444464096], 
             UndirectedEdge[322, 494] -> 
             RGBColor[
              0.2588610411681461, 0.3894097453786518, 0.9380531253927091], 
             UndirectedEdge[108, 266] -> 
             RGBColor[
              0.28731571918259713`, 0.4193174161026276, 0.9396735772107083], 
             UndirectedEdge[405, 474] -> 
             RGBColor[
              0.9935549188322322, 0.9905077851325332, 0.6768786341569868], 
             UndirectedEdge[338, 379] -> 
             RGBColor[
              0.31470226354501973`, 0.4470010161121858, 0.9412735278461717], 
             UndirectedEdge[175, 309] -> 
             RGBColor[
              0.9743805147039586, 0.9770030600582216, 0.7213206267986814], 
             UndirectedEdge[294, 430] -> 
             RGBColor[
              0.23902588418057213`, 0.36856173776312173`, 0.9369235425457519],
              UndirectedEdge[197, 237] -> 
             RGBColor[
              0.8018590077882369, 0.845833600411511, 0.9807007779188375], 
             UndirectedEdge[94, 500] -> 
             RGBColor[
              0.8874558706447166, 0.5585534617562613, 0.5633237757723539], 
             UndirectedEdge[242, 365] -> 
             RGBColor[
              0.22099114578241763`, 0.3496060842382034, 0.9358964908739815], 
             UndirectedEdge[401, 500] -> 
             RGBColor[
              0.7964725199858478, 0.48689043193741693`, 0.5721768321079614], 
             UndirectedEdge[334, 340] -> 
             RGBColor[
              0.37011932022613914`, 0.4950004852671151, 0.9448046536945134], 
             UndirectedEdge[60, 310] -> 
             RGBColor[
              0.2947333345295756, 0.4271138001362785, 0.9400959994313403], 
             UndirectedEdge[50, 379] -> 
             RGBColor[
              0.37511861305326666`, 0.49933062144220947`, 0.9451232042127569],
              UndirectedEdge[123, 177] -> 
             RGBColor[
              0.2078300375710318, 0.33577292504558, 0.935146985231458], 
             UndirectedEdge[231, 246] -> 
             RGBColor[
              0.27633388437422024`, 0.407774811430481, 0.93904817796454], 
             UndirectedEdge[182, 282] -> 
             RGBColor[
              0.4931225250647846, 0.5973489755441486, 0.9538002129842165], 
             UndirectedEdge[185, 193] -> 
             RGBColor[
              0.28587823371129695`, 0.41780652773044813`, 0.9395917145396869],
              UndirectedEdge[395, 447] -> 
             RGBColor[
              0.2557437599820415, 0.3861332852050131, 0.9378756008407647], 
             UndirectedEdge[22, 282] -> 
             RGBColor[
              0.5295374583805197, 0.6288897605144723, 0.956120540334634], 
             UndirectedEdge[195, 323] -> 
             RGBColor[
              0.2547482956718921, 0.38508698909896344`, 0.9378189106209592], 
             UndirectedEdge[99, 486] -> 
             RGBColor[
              0.9642745659488295, 0.9698576677518461, 0.7703884518083142], 
             UndirectedEdge[454, 469] -> 
             RGBColor[
              0.8801565520867384, 0.5487007178218191, 0.22171202824050545`], 
             UndirectedEdge[31, 208] -> 
             RGBColor[
              0.38757839390763205`, 0.5101226573714661, 0.9459171304310454], 
             UndirectedEdge[398, 472] -> 
             RGBColor[
              0.2947988861662292, 0.4253612331985043, 0.9401664252880289], 
             UndirectedEdge[191, 389] -> 
             RGBColor[
              0.21845058194335062`, 0.3469357905622929, 0.9357518095217741], 
             UndirectedEdge[133, 151] -> 
             RGBColor[
              0.3259839947322987, 0.4565922388339624, 0.9419989967859217], 
             UndirectedEdge[165, 268] -> 
             RGBColor[
              0.4168440173490807, 0.5354710694634455, 0.9477819100781599], 
             UndirectedEdge[166, 495] -> 
             RGBColor[
              0.8401614416386582, 0.3097040160564781, 0.18609194791002698`], 
             UndirectedEdge[346, 430] -> 
             RGBColor[
              0.22881084125106885`, 0.35782507997308444`, 0.9363418109627185],
              UndirectedEdge[169, 219] -> 
             RGBColor[
              0.5095055418565787, 0.6126785776990856, 0.9545292891166974], 
             UndirectedEdge[197, 345] -> 
             RGBColor[
              0.6786754086563489, 0.7489056544572683, 0.9686076802187304], 
             UndirectedEdge[100, 213] -> 
             RGBColor[
              0.9177103751290299, 0.7114500107948662, 0.2526457256885956], 
             UndirectedEdge[73, 187] -> 
             RGBColor[
              0.25626928229983936`, 0.38668564248105813`, 0.9379055285593227],
              UndirectedEdge[97, 346] -> 
             RGBColor[
              0.22480858213955662`, 0.353618451889001, 0.9361138882271296], 
             UndirectedEdge[129, 170] -> 
             RGBColor[
              0.3261401713486173, 0.4557924254151241, 0.9420431862919051], 
             UndirectedEdge[36, 37] -> 
             RGBColor[
              0.2800147441029785, 0.41164362838539204`, 0.9392577974807488], 
             UndirectedEdge[143, 302] -> 
             RGBColor[
              0.1845381798446758, 0.31129170578610466`, 0.9338205483911577], 
             UndirectedEdge[16, 236] -> 
             RGBColor[
              0.34560261915581325`, 0.4717846628283363, 0.9433149938798411], 
             UndirectedEdge[187, 322] -> 
             RGBColor[
              0.2619233226556958, 0.392628397381927, 0.9382275177931856], 
             UndirectedEdge[108, 163] -> 
             RGBColor[
              0.27605150294224795`, 0.40747801064146116`, 0.939032096759735], 
             UndirectedEdge[137, 346] -> 
             RGBColor[
              0.21898159921391522`, 0.34749392338209584`, 0.9357820501697631],
              UndirectedEdge[243, 276] -> 
             RGBColor[
              0.7294231328480298, 0.5025695960181678, 0.5742322488928711], 
             UndirectedEdge[131, 147] -> 
             RGBColor[
              0.257551109678863, 0.38803292432896186`, 0.9379785267322645], 
             UndirectedEdge[9, 468] -> 
             RGBColor[
              0.5267603512092651, 0.6266868092518996, 0.9558876509153902], 
             UndirectedEdge[331, 377] -> 
             RGBColor[
              0.9088984029132244, 0.9290240327940705, 0.9505769466051841], 
             UndirectedEdge[280, 470] -> 
             RGBColor[
              0.25618724239569113`, 0.386599413340168, 0.9379008565081486], 
             UndirectedEdge[234, 468] -> 
             RGBColor[
              0.4334778335161593, 0.5491980337433716, 0.9490298017896481], 
             UndirectedEdge[136, 488] -> 
             RGBColor[
              0.8691624812525807, 0.8980619995445237, 0.9575361918373422], 
             UndirectedEdge[57, 361] -> 
             RGBColor[
              0.622722217665552, 0.7045647515271736, 0.9634614174292722], 
             UndirectedEdge[196, 414] -> 
             RGBColor[
              0.2851786513362504, 0.4170712222981897, 0.9395518743583675], 
             UndirectedEdge[103, 319] -> 
             RGBColor[
              0.5976226950866923, 0.6831049747415705, 0.9622258440138658], 
             UndirectedEdge[224, 263] -> 
             RGBColor[
              0.2861834719747001, 0.4181273524985085, 0.9396090974072282], 
             UndirectedEdge[89, 184] -> 
             RGBColor[
              0.271266794829508, 0.4024489790469554, 0.9387596147110557], 
             UndirectedEdge[137, 407] -> 
             RGBColor[
              0.2172194419002935, 0.34564178431825265`, 0.9356816979176306], 
             UndirectedEdge[53, 272] -> 
             RGBColor[
              0.8985476192245749, 0.5458238236085153, 0.2652993601444404], 
             UndirectedEdge[236, 243] -> 
             RGBColor[
              0.5633146331293595, 0.36122739545781846`, 0.562473440762307], 
             UndirectedEdge[26, 351] -> 
             RGBColor[
              0.3383374936256977, 0.4657436708748698, 0.9428428507321864], 
             UndirectedEdge[67, 96] -> 
             RGBColor[
              0.2763924027630132, 0.4078363179673825, 0.9390515105002115], 
             UndirectedEdge[284, 464] -> 
             RGBColor[
              0.24447969866104266`, 0.37429404257390636`, 0.9372341292122193],
              UndirectedEdge[325, 401] -> 
             RGBColor[
              0.4762346490241563, 0.5642173274993956, 0.9557801417908952], 
             UndirectedEdge[227, 348] -> 
             RGBColor[
              0.9027713884189711, 0.6140906553673846, 0.24504718315702606`], 
             UndirectedEdge[106, 117] -> 
             RGBColor[
              0.44946530583261596`, 0.561973649912251, 0.9503446865091629], 
             UndirectedEdge[395, 440] -> 
             RGBColor[
              0.2733307058970075, 0.4046182804384171, 0.9388771513930672], 
             UndirectedEdge[204, 361] -> 
             RGBColor[
              0.5730472494558454, 0.6642363745027182, 0.9595508219663998], 
             UndirectedEdge[195, 263] -> 
             RGBColor[
              0.27177628853634817`, 0.40298448923661123`, 0.9387886296239321],
              UndirectedEdge[360, 393] -> 
             RGBColor[
              0.5202889035975207, 0.6214329965452928, 0.9553781948537], 
             UndirectedEdge[74, 440] -> 
             RGBColor[
              0.2817039259800564, 0.4134190656385177, 0.9393539938897277], 
             UndirectedEdge[166, 348] -> 
             RGBColor[
              0.8990160108059699, 0.5852251774168952, 0.24145102931372386`], 
             UndirectedEdge[209, 477] -> 
             RGBColor[
              0.40529759982577535`, 0.5164885241169046, 0.9481078912022864], 
             UndirectedEdge[292, 422] -> 
             RGBColor[
              0.20649131825242792`, 0.3343658461620201, 0.9350707471467212], 
             UndirectedEdge[36, 416] -> 
             RGBColor[
              0.2579614870777197, 0.3884642569945902, 0.9380018971180304], 
             UndirectedEdge[306, 418] -> 
             RGBColor[
              0.9180265023958543, 0.7135265493813059, 0.5620472292012149], 
             UndirectedEdge[363, 498] -> 
             RGBColor[
              0.433350434496959, 0.5495353617267253, 0.948897990208064], 
             UndirectedEdge[57, 466] -> 
             RGBColor[
              0.552375580457491, 0.6474824063085367, 0.957904175593487], 
             UndirectedEdge[263, 395] -> 
             RGBColor[
              0.2691941123375187, 0.40027045833221453`, 0.938641578509396], 
             UndirectedEdge[171, 238] -> 
             RGBColor[
              0.2909480728266918, 0.4220805098947036, 0.9399190535823698], 
             UndirectedEdge[42, 286] -> 
             RGBColor[
              0.2277872668823118, 0.3567492384131574, 0.9362835199166604], 
             UndirectedEdge[246, 444] -> 
             RGBColor[
              0.2827572278979614, 0.41452615273743476`, 0.9394139778757318], 
             UndirectedEdge[46, 306] -> 
             RGBColor[
              0.8876171805650555, 0.5774114462757728, 0.22768643734119767`], 
             UndirectedEdge[229, 411] -> 
             RGBColor[
              0.26528288174741516`, 0.39615950699567326`, 0.9384188397134368],
              UndirectedEdge[239, 440] -> 
             RGBColor[
              0.3163021777955242, 0.4458837751629835, 0.9414671202878849], 
             UndirectedEdge[57, 106] -> 
             RGBColor[
              0.5595491629932491, 0.6533062437772754, 0.9584689062884005], 
             UndirectedEdge[60, 280] -> 
             RGBColor[
              0.2748009878347767, 0.4061636399762716, 0.9389608817743358], 
             UndirectedEdge[438, 457] -> 
             RGBColor[
              0.22152681415849518`, 0.35016910566479753`, 0.9359269963955489],
              UndirectedEdge[130, 368] -> 
             RGBColor[
              0.2935143249909316, 0.4166464351270609, 0.9403629270800464], 
             UndirectedEdge[152, 287] -> 
             RGBColor[
              0.20690732578417442`, 0.33480309645428663`, 0.9350944381602262],
              UndirectedEdge[54, 242] -> 
             RGBColor[
              0.22686421194138368`, 0.35577904914517844`, 0.936230953303312], 
             UndirectedEdge[89, 235] -> 
             RGBColor[
              0.32127172035398965`, 0.45054205661512126`, 0.9417708166396943],
              UndirectedEdge[60, 260] -> 
             RGBColor[
              0.2891430137819674, 0.4212380185837349, 0.9397776389349024], 
             UndirectedEdge[88, 243] -> 
             RGBColor[
              0.8529581179820884, 0.3951595604413297, 0.19784071975882145`], 
             UndirectedEdge[36, 367] -> 
             RGBColor[
              0.2421171751521342, 0.3718108805734015, 0.9370995869934273], 
             UndirectedEdge[17, 282] -> 
             RGBColor[
              0.7438148228852721, 0.7997463454963281, 0.9753349394405884], 
             UndirectedEdge[150, 233] -> 
             RGBColor[
              0.832302226448087, 0.24929464417169217`, 0.1785659545678221], 
             UndirectedEdge[250, 365] -> 
             RGBColor[
              0.21070999979849359`, 0.338799947946794, 0.9353109948197895], 
             UndirectedEdge[107, 423] -> 
             RGBColor[
              0.18624879198055028`, 0.31308966759998247`, 0.9339179652216718],
              UndirectedEdge[315, 347] -> 
             RGBColor[
              0.1822133081343763, 0.30884811821319974`, 0.9336881503865955], 
             UndirectedEdge[288, 492] -> 
             RGBColor[
              0.26634261157442907`, 0.39727335023461663`, 0.9384791897593554],
              UndirectedEdge[24, 267] -> 
             RGBColor[
              0.9130173103236416, 0.9238052630986108, 0.6981615264074577], 
             UndirectedEdge[198, 480] -> 
             RGBColor[
              0.3177133386514768, 0.44712506118461215`, 0.9415563421819749], 
             UndirectedEdge[4, 479] -> 
             RGBColor[
              0.3678971603336924, 0.49307576205728143`, 0.9446630596311456], 
             UndirectedEdge[133, 239] -> 
             RGBColor[
              0.34805209112246643`, 0.47588696054869806`, 0.943398549369312], 
             UndirectedEdge[115, 253] -> 
             RGBColor[
              0.9531001134456565, 0.9640284881713892, 0.9450338107840079], 
             UndirectedEdge[199, 371] -> 
             RGBColor[
              0.3528938984406201, 0.480080690691371, 0.9437070650501826], 
             UndirectedEdge[93, 189] -> 
             RGBColor[
              0.26453032177670965`, 0.3953685187514038, 0.9383759825364177], 
             UndirectedEdge[357, 418] -> 
             RGBColor[
              0.9428078871600445, 0.8265116366232681, 0.582732825135219], 
             UndirectedEdge[82, 463] -> 
             RGBColor[
              0.26268799213192734`, 0.3934321134842913, 0.9382710645886299], 
             UndirectedEdge[102, 350] -> 
             RGBColor[
              0.3193537748201921, 0.44805203074969097`, 0.941678953195245], 
             UndirectedEdge[235, 296] -> 
             RGBColor[
              0.3352307721420522, 0.4647817784660925, 0.9425815862613272], 
             UndirectedEdge[26, 360] -> 
             RGBColor[
              0.48299792974153133`, 0.5893477559050426, 0.9529428278924086], 
             UndirectedEdge[309, 320] -> 
             RGBColor[
              0.9908166313021023, 0.9885283450055495, 0.6606847997028811], 
             UndirectedEdge[13, 229] -> 
             RGBColor[
              0.2937960299949141, 0.4261286336418093, 0.9400426213247091], 
             UndirectedEdge[353, 420] -> 
             RGBColor[
              0.8041526849608935, 0.8472401733654197, 0.9513697071701304], 
             UndirectedEdge[171, 465] -> 
             RGBColor[
              0.27218390368581785`, 0.4034129186029971, 0.9388118427036817], 
             UndirectedEdge[104, 224] -> 
             RGBColor[
              0.2727699797429894, 0.40402892169845256`, 0.9388452188681158], 
             UndirectedEdge[22, 285] -> 
             RGBColor[
              0.38291743430858444`, 0.506085568433412, 0.9456201382069189], 
             UndirectedEdge[126, 285] -> 
             RGBColor[
              0.28277807837083513`, 0.4140236211798849, 0.9394343678430408], 
             UndirectedEdge[98, 319] -> 
             RGBColor[
              0.8550622111994015, 0.8847062165139711, 0.8474629923061501], 
             UndirectedEdge[286, 411] -> 
             RGBColor[
              0.2313451146629863, 0.3604887620112245, 0.9364861340844057], 
             UndirectedEdge[259, 491] -> 
             RGBColor[
              0.9280010655847133, 0.727726462964249, 0.4061574584267472], 
             UndirectedEdge[1, 266] -> 
             RGBColor[
              0.27784311638010406`, 0.40936110995950087`, 0.9391341264945663],
              UndirectedEdge[67, 216] -> 
             RGBColor[
              0.26125452628926693`, 0.3919254499966715, 0.938189430829513], 
             UndirectedEdge[41, 451] -> 
             RGBColor[
              0.22198624668627384`, 0.3506519983811976, 0.9359531603983363], 
             UndirectedEdge[300, 456] -> 
             RGBColor[
              0.22480808787876505`, 0.3536179323895711, 0.9361138600797088], 
             UndirectedEdge[117, 139] -> 
             RGBColor[
              0.47255522666265165`, 0.5807190878311534, 0.9521624096580703], 
             UndirectedEdge[70, 96] -> 
             RGBColor[
              0.2772059489257, 0.4086914065661722, 0.9390978407506428], 
             UndirectedEdge[92, 274] -> 
             RGBColor[
              0.5359359247795917, 0.6341359532311694, 0.9566099856780799], 
             UndirectedEdge[241, 436] -> 
             RGBColor[
              0.5892009770363313, 0.6764119562142918, 0.9614643256448061], 
             UndirectedEdge[207, 295] -> 
             RGBColor[
              0.22332543873759936`, 0.352059574136821, 0.9360294254045023], 
             UndirectedEdge[83, 176] -> 
             RGBColor[
              0.7638451540938651, 0.8157128228854424, 0.9772513951417543], 
             UndirectedEdge[56, 495] -> 
             RGBColor[
              0.839438039950976, 0.30414363368831143`, 0.18539921763693712`], 
             UndirectedEdge[219, 334] -> 
             RGBColor[
              0.4645364889888964, 0.5747991033502236, 0.9513681298117886], 
             UndirectedEdge[124, 357] -> 
             RGBColor[
              0.9348974167088442, 0.7776187751730486, 0.27677767167712564`], 
             UndirectedEdge[40, 291] -> 
             RGBColor[
              0.5205636488996574, 0.6196411124817705, 0.9560349926032045], 
             UndirectedEdge[7, 487] -> 
             RGBColor[
              0.7090567422484308, 0.7718269420846646, 0.9722547745917934], 
             UndirectedEdge[423, 477] -> 
             RGBColor[
              0.21624875945532895`, 0.3446215355237733, 0.9356264189883857], 
             UndirectedEdge[22, 165] -> 
             RGBColor[
              0.4377248912958056, 0.5535570329728583, 0.9491124209018134], 
             UndirectedEdge[302, 368] -> 
             RGBColor[
              0.2991255041617159, 0.42254414020486286`, 0.9406824754328269], 
             UndirectedEdge[297, 419] -> 
             RGBColor[
              0.5160273723962365, 0.6179732935362974, 0.9550427115070317], 
             UndirectedEdge[263, 463] -> 
             RGBColor[
              0.2702490064672201, 0.4013792189466815, 0.9387016531695065], 
             UndirectedEdge[260, 424] -> 
             RGBColor[
              0.3030854306847971, 0.434796914253921, 0.9406117494194473], 
             UndirectedEdge[193, 415] -> 
             RGBColor[
              0.28741220208324925`, 0.41941882574858214`, 0.9396790717691668],
              UndirectedEdge[434, 474] -> 
             RGBColor[
              0.992149866333044, 0.99102178223655, 0.7797605605635565], 
             UndirectedEdge[102, 109] -> 
             RGBColor[
              0.265248780611274, 0.396123664539452, 0.9384168977041816], 
             UndirectedEdge[58, 118] -> 
             RGBColor[
              0.3201099243225116, 0.4516848600807156, 0.9416180992091068], 
             UndirectedEdge[39, 100] -> 
             RGBColor[
              0.7774382200691679, 0.7351762203070193, 0.6135140654406412], 
             UndirectedEdge[35, 216] -> 
             RGBColor[
              0.25212920477180323`, 0.3823341585030158, 0.9376697572687969], 
             UndirectedEdge[72, 163] -> 
             RGBColor[
              0.26048838412385666`, 0.3911201860046064, 0.9381458001665987], 
             UndirectedEdge[202, 414] -> 
             RGBColor[
              0.25685751416132785`, 0.38730391146353665`, 0.9379390274936235],
              UndirectedEdge[324, 441] -> 
             RGBColor[
              0.4099049258998564, 0.5294607772190044, 0.947339757307013], 
             UndirectedEdge[18, 52] -> 
             RGBColor[
              0.8600894824934477, 0.42201909265360843`, 0.20357506457964797`],
              UndirectedEdge[168, 368] -> 
             RGBColor[
              0.6594469349895435, 0.6059633899066202, 0.5971521921376893], 
             UndirectedEdge[208, 397] -> 
             RGBColor[
              0.3403332891441403, 0.46920132223333977`, 0.9429067141327215], 
             UndirectedEdge[193, 350] -> 
             RGBColor[
              0.3249908553866274, 0.4539769598365655, 0.94199997659419], 
             UndirectedEdge[2, 365] -> 
             RGBColor[
              0.21471117528305686`, 0.3430054370702481, 0.9355388558444269], 
             UndirectedEdge[42, 248] -> 
             RGBColor[
              0.2375069627028864, 0.3669652549848901, 0.9368370422146407], 
             UndirectedEdge[46, 68] -> 
             RGBColor[
              0.8688206529626022, 0.4329330984324026, 0.20968686128144703`], 
             UndirectedEdge[260, 470] -> 
             RGBColor[
              0.2705292683428818, 0.4016737919476313, 0.9387176136687151], 
             UndirectedEdge[32, 344] -> 
             RGBColor[
              0.49972685632516956`, 0.6047398002599247, 0.9537594751711596], 
             UndirectedEdge[60, 483] -> 
             RGBColor[
              0.29467938491288026`, 0.4270570956685284, 0.9400929270804808], 
             UndirectedEdge[337, 498] -> 
             RGBColor[
              0.6610501058244442, 0.7326972089760198, 0.9686548196773171], 
             UndirectedEdge[86, 168] -> 
             RGBColor[
              0.912992655814064, 0.6927519043211215, 0.24885005242438252`], 
             UndirectedEdge[151, 424] -> 
             RGBColor[
              0.31369437792555, 0.4459475904500576, 0.9412159132702771], 
             UndirectedEdge[234, 296] -> 
             RGBColor[
              0.3509992318996893, 0.478439625762326, 0.9435863385735823], 
             UndirectedEdge[223, 268] -> 
             RGBColor[
              0.3997592820050565, 0.5206731304122181, 0.946693285849477], 
             UndirectedEdge[50, 204] -> 
             RGBColor[
              0.47141553909134676`, 0.5814192522224795, 0.9516235825177704], 
             UndirectedEdge[26, 247] -> 
             RGBColor[
              0.44082045923577545`, 0.5551061852750767, 0.9496224629130303], 
             UndirectedEdge[64, 435] -> 
             RGBColor[
              0.2729760661843835, 0.4042455316149929, 0.9388569551860756], 
             UndirectedEdge[143, 214] -> 
             RGBColor[
              0.18936705810043614`, 0.31636716300147366`, 0.934095545864138], 
             UndirectedEdge[38, 266] -> 
             RGBColor[
              0.27474470932625494`, 0.40610448769555174`, 0.9389576767965321],
              UndirectedEdge[309, 375] -> 
             RGBColor[
              0.9756161016685031, 0.977924558793291, 0.7192291003603996], 
             UndirectedEdge[70, 385] -> 
             RGBColor[
              0.24586087527331454`, 0.37574574676505923`, 0.9373127851770204],
              UndirectedEdge[232, 354] -> 
             RGBColor[
              0.35898073503518557`, 0.48535280261628094`, 0.94409491289561], 
             UndirectedEdge[86, 484] -> 
             RGBColor[
              0.9540423951293819, 0.8443401430723285, 0.3591520108030784], 
             UndirectedEdge[106, 360] -> 
             RGBColor[
              0.5486108303756021, 0.6444260125920007, 0.9576078006763067], 
             UndirectedEdge[163, 322] -> 
             RGBColor[
              0.26310542995763675`, 0.3938708671061988, 0.9382948370552601], 
             UndirectedEdge[44, 117] -> 
             RGBColor[
              0.4388762614701655, 0.5533769866678013, 0.9495110781480034], 
             UndirectedEdge[113, 273] -> 
             RGBColor[
              0.23636683819300525`, 0.3657669118369359, 0.936772113810466], 
             UndirectedEdge[53, 298] -> 
             RGBColor[
              0.9390760601522875, 0.9284198827471832, 0.6768677898959217], 
             UndirectedEdge[50, 369] -> 
             RGBColor[
              0.43044272533776096`, 0.5472495868323034, 0.9486484077263333], 
             UndirectedEdge[135, 385] -> 
             RGBColor[
              0.24204917775156742`, 0.37173941099412156`, 0.9370957146420581],
              UndirectedEdge[376, 464] -> 
             RGBColor[
              0.2616609318454717, 0.3923526080038432, 0.9382125750247157], 
             UndirectedEdge[95, 408] -> 
             RGBColor[
              0.22479372667970515`, 0.35360283785880653`, 0.9361130422306678],
              UndirectedEdge[34, 332] -> 
             RGBColor[
              0.47297256082386624`, 0.5816312685861409, 0.9520368398699108], 
             UndirectedEdge[251, 416] -> 
             RGBColor[
              0.26003944376158217`, 0.39064832121939286`, 0.9381202336771148],
              UndirectedEdge[62, 209] -> 
             RGBColor[
              0.6916212861064526, 0.39630413817282756`, 0.5615943615662011], 
             UndirectedEdge[109, 496] -> 
             RGBColor[
              0.26542477376877, 0.3963086445065909, 0.9384269202541424], 
             UndirectedEdge[179, 254] -> 
             RGBColor[
              0.20771369325605188`, 0.33565063979388043`, 0.9351403595948358],
              UndirectedEdge[27, 199] -> 
             RGBColor[
              0.4274813973658525, 0.5430880506381621, 0.9489008550961784], 
             UndirectedEdge[59, 453] -> 
             RGBColor[
              0.26324896867774317`, 0.3940217354019111, 0.9383030113730237], 
             UndirectedEdge[450, 475] -> 
             RGBColor[
              0.8283559372455574, 0.2189617360860943, 0.17478698357078354`], 
             UndirectedEdge[311, 331] -> 
             RGBColor[
              0.7917742816822333, 0.837394395727864, 0.9798444828971542], 
             UndirectedEdge[329, 486] -> 
             RGBColor[
              0.9087427412464592, 0.930070810978078, 0.9911578879759511], 
             UndirectedEdge[287, 456] -> 
             RGBColor[
              0.21673512234064032`, 0.34513273375342357`, 0.9356541166351948],
              UndirectedEdge[60, 118] -> 
             RGBColor[
              0.30890885152103453`, 0.4405003788871604, 0.9409586647466246], 
             UndirectedEdge[267, 493] -> 
             RGBColor[
              0.991319933690298, 0.9817192401312839, 0.4771566948770857], 
             UndirectedEdge[239, 263] -> 
             RGBColor[
              0.31216558423603546`, 0.4415359530567809, 0.9412315474042139], 
             UndirectedEdge[64, 91] -> 
             RGBColor[
              0.3077316474117898, 0.43903000298271255`, 0.9409001581731142], 
             UndirectedEdge[469, 471] -> 
             RGBColor[
              0.8586216305057723, 0.4484110579890054, 0.20364468753654688`], 
             UndirectedEdge[275, 282] -> 
             RGBColor[
              0.5106811757652547, 0.612557396257451, 0.9549190346803453], 
             UndirectedEdge[132, 423] -> 
             RGBColor[
              0.5889794016641527, 0.6524675094432201, 0.8735972473293918], 
             UndirectedEdge[116, 412] -> 
             RGBColor[
              0.24555371763094103`, 0.3754229046080053, 0.9372952930036862], 
             UndirectedEdge[89, 453] -> 
             RGBColor[
              0.28490427469255214`, 0.4167828350491789, 0.9395362490144127], 
             UndirectedEdge[136, 311] -> 
             RGBColor[
              0.8579087651395905, 0.8892705109856455, 0.9564145265871555], 
             UndirectedEdge[6, 24] -> 
             RGBColor[
              0.8323309168683787, 0.869142096362715, 0.9838696599531287], 
             UndirectedEdge[51, 477] -> 
             RGBColor[
              0.21179931412463662`, 0.3399448863700877, 0.9353730296591674], 
             UndirectedEdge[114, 381] -> 
             RGBColor[
              0.5349916430046526, 0.6333693427468647, 0.9565356483577385], 
             UndirectedEdge[95, 294] -> 
             RGBColor[
              0.2326978312332123, 0.36191055289371626`, 0.9365631692919152], 
             UndirectedEdge[89, 192] -> 
             RGBColor[
              0.27005817816264466`, 0.4011786462993594, 0.9386907857798661], 
             UndirectedEdge[108, 374] -> 
             RGBColor[
              0.2684205085848909, 0.3994573517388918, 0.938597522920128], 
             UndirectedEdge[208, 472] -> 
             RGBColor[
              0.32528262084800263`, 0.45616518982380916`, 0.9419476988576752],
              UndirectedEdge[34, 360] -> 
             RGBColor[
              0.5615596954334325, 0.6549384845856707, 0.9586271827669148], 
             UndirectedEdge[395, 453] -> 
             RGBColor[
              0.2746472026730905, 0.406002002020797, 0.9389521239368825], 
             UndirectedEdge[101, 361] -> 
             RGBColor[
              0.5825170875925927, 0.671924415713476, 0.9602963223136847], 
             UndirectedEdge[11, 211] -> 
             RGBColor[
              0.23497926878004616`, 0.3643084884069338, 0.936693093785123], 
             UndirectedEdge[70, 433] -> 
             RGBColor[
              0.2918782074405654, 0.4225632807803333, 0.9399901426055144], 
             UndirectedEdge[108, 206] -> 
             RGBColor[
              0.31392242641055057`, 0.44414031495447526`, 0.9413038498533395],
              UndirectedEdge[251, 499] -> 
             RGBColor[
              0.25963192027097015`, 0.39021998819227793`, 0.9380970258172014],
              UndirectedEdge[116, 399] -> 
             RGBColor[
              0.24511345141386065`, 0.3749601568993634, 0.937270220493939], 
             UndirectedEdge[350, 479] -> 
             RGBColor[
              0.3868303332701487, 0.5094747248458988, 0.9458694646687091], 
             UndirectedEdge[347, 421] -> 
             RGBColor[
              0.17899180289058533`, 0.3054621119467458, 0.9335046904287516], 
             UndirectedEdge[153, 447] -> 
             RGBColor[
              0.24571645560416666`, 0.3755939525360489, 0.9373045606905122], 
             UndirectedEdge[195, 453] -> 
             RGBColor[
              0.27722937887191995`, 0.40871603292519376`, 0.9390991750514186],
              UndirectedEdge[338, 425] -> 
             RGBColor[
              0.3477240886796976, 0.47560286131865376`, 0.9433776493436998], 
             UndirectedEdge[164, 348] -> 
             RGBColor[
              0.8887181595032059, 0.5060713797566354, 0.23158979527643736`], 
             UndirectedEdge[31, 258] -> 
             RGBColor[
              0.4132303526475083, 0.5323410947270124, 0.947551650558814], 
             UndirectedEdge[31, 203] -> 
             RGBColor[
              0.4938024492349883, 0.5999225041719667, 0.9532951828081889], 
             UndirectedEdge[398, 445] -> 
             RGBColor[
              0.2453951867466454, 0.3752562785971719, 0.9372862649043511], 
             UndirectedEdge[44, 369] -> 
             RGBColor[
              0.4583123366675063, 0.5702115381181944, 0.9507495276729314], 
             UndirectedEdge[267, 278] -> 
             RGBColor[
              0.9687131736129876, 0.9678890438697982, 0.6921508091390034], 
             UndirectedEdge[130, 477] -> 
             RGBColor[
              0.2117993137193227, 0.3399448859440771, 0.9353730296360853], 
             UndirectedEdge[4, 482] -> 
             RGBColor[
              0.3413925426988842, 0.4701187944228272, 0.9429742088325687], 
             UndirectedEdge[219, 274] -> 
             RGBColor[
              0.49450158018716717`, 0.6004976856950868, 0.9533481222927589], 
             UndirectedEdge[44, 269] -> 
             RGBColor[
              0.4728082951441619, 0.5827672087626157, 0.9516731973287911], 
             UndirectedEdge[130, 143] -> 
             RGBColor[
              0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772],
              UndirectedEdge[315, 401] -> 
             RGBColor[
              0.47947599697395743`, 0.5676241897079666, 0.9559647317614918], 
             UndirectedEdge[75, 163] -> 
             RGBColor[
              0.3059704107658049, 0.43557751025778224`, 0.9408584905702073], 
             UndirectedEdge[9, 139] -> 
             RGBColor[
              0.5695894293133013, 0.6614573842847371, 0.9592593128318224], 
             UndirectedEdge[134, 438] -> 
             RGBColor[
              0.22733547187831532`, 0.35627437321849936`, 0.9362577908595535],
              UndirectedEdge[76, 431] -> 
             RGBColor[
              0.42993261586454035`, 0.5468077556454473, 0.9486159040017718], 
             UndirectedEdge[90, 124] -> 
             RGBColor[
              0.9137111635376958, 0.6822566946723914, 0.2591427819494134], 
             UndirectedEdge[37, 188] -> 
             RGBColor[
              0.3214586719550145, 0.4525659249433619, 0.9417145542769817], 
             UndirectedEdge[26, 106] -> 
             RGBColor[
              0.45224243758080923`, 0.5643790618498358, 0.9505216428884367], 
             UndirectedEdge[107, 446] -> 
             RGBColor[
              0.2064114829025504, 0.3342819341474452, 0.9350662006416515], 
             UndirectedEdge[19, 234] -> 
             RGBColor[
              0.474151584993228, 0.582218817524079, 0.9522317884987839], 
             UndirectedEdge[39, 243] -> 
             RGBColor[
              0.7314838484501698, 0.504242577778165, 0.5743944759737214], 
             UndirectedEdge[129, 265] -> 
             RGBColor[
              0.3383071396578693, 0.46744637338556605`, 0.9427776096791101], 
             UndirectedEdge[396, 446] -> 
             RGBColor[
              0.6108486673250959, 0.6728679174892245, 0.7376055193707824], 
             UndirectedEdge[325, 368] -> 
             RGBColor[
              0.2935592851755068, 0.41669369113168975`, 0.9403654874960453], 
             UndirectedEdge[52, 56] -> 
             RGBColor[
              0.836234326611525, 0.27951848908515425`, 0.18233133812500216`], 
             UndirectedEdge[402, 431] -> 
             RGBColor[
              0.5004255816893457, 0.6051773211877334, 0.9538503277794443], 
             UndirectedEdge[165, 353] -> 
             RGBColor[
              0.531847897863051, 0.630021959343577, 0.9565078633928767], 
             UndirectedEdge[237, 329] -> 
             RGBColor[
              0.8943251384864865, 0.9185746058926771, 0.989782724153959], 
             UndirectedEdge[63, 75] -> 
             RGBColor[
              0.38214205273411095`, 0.5054139718854141, 0.9455707315786365], 
             UndirectedEdge[392, 492] -> 
             RGBColor[
              0.2913103527973019, 0.4235160293060819, 0.9399010656855349], 
             UndirectedEdge[125, 177] -> 
             RGBColor[
              0.20868507222126964`, 0.3366716206753079, 0.9351956781898786], 
             UndirectedEdge[210, 348] -> 
             RGBColor[
              0.8979876618717816, 0.5773208368833467, 0.24046628121299102`], 
             UndirectedEdge[469, 491] -> 
             RGBColor[
              0.9272960549745825, 0.7245251744430564, 0.40556918029226263`], 
             UndirectedEdge[35, 171] -> 
             RGBColor[
              0.25005732664065045`, 0.38015648322251344`, 0.9375517668742968],
              UndirectedEdge[8, 40] -> 
             RGBColor[
              0.5032468930597369, 0.6057751178648505, 0.9545401217837302], 
             UndirectedEdge[405, 491] -> 
             RGBColor[
              0.9940870576802556, 0.9897611392052678, 0.5977909028249961], 
             UndirectedEdge[98, 136] -> 
             RGBColor[
              0.9820976999154852, 0.9842937020241562, 0.8300672430323528], 
             UndirectedEdge[14, 75] -> 
             RGBColor[
              0.32584559541094904`, 0.45646758947931865`, 0.9419903529330476],
              UndirectedEdge[121, 500] -> 
             RGBColor[
              0.8234793018793516, 0.18147777970619255`, 0.1701171120367329], 
             UndirectedEdge[1, 265] -> 
             RGBColor[
              0.2935899974663011, 0.4247777732380918, 0.9400724206184119], 
             UndirectedEdge[227, 495] -> 
             RGBColor[
              0.8439168192516593, 0.3385694940069675, 0.1896881017533292], 
             UndirectedEdge[127, 368] -> 
             RGBColor[
              0.3170407306432145, 0.44137417912788274`, 0.9417027210777457], 
             UndirectedEdge[207, 389] -> 
             RGBColor[
              0.21778138864415675`, 0.3462324259755344, 0.9357136999533677], 
             UndirectedEdge[249, 260] -> 
             RGBColor[
              0.28756214905519606`, 0.4195764295232854, 0.9396876110273925], 
             UndirectedEdge[42, 95] -> 
             RGBColor[
              0.2297785943922997, 0.3588422498836111, 0.9363969230724491], 
             UndirectedEdge[190, 323] -> 
             RGBColor[
              0.243727142288008, 0.373503058111017, 0.9371912722400824], 
             UndirectedEdge[109, 295] -> 
             RGBColor[
              0.24177394363545715`, 0.37145012248723885`, 0.937080040466318], 
             UndirectedEdge[382, 499] -> 
             RGBColor[
              0.27147166687394786`, 0.40266431255529955`, 0.9387712818709056],
              UndirectedEdge[213, 254] -> 
             RGBColor[
              0.5703520735589939, 0.511904106319279, 0.5892794945919869], 
             UndirectedEdge[47, 374] -> 
             RGBColor[
              0.24183198733731956`, 0.37151113009807946`, 0.9370833459692711],
              UndirectedEdge[244, 390] -> 
             RGBColor[
              0.3215972480879268, 0.45223414091428343`, 0.9417399272656037], 
             UndirectedEdge[92, 370] -> 
             RGBColor[
              0.6002904630940367, 0.6863818665737486, 0.9616762106726342], 
             UndirectedEdge[295, 458] -> 
             RGBColor[
              0.2300435692999762, 0.35912075531195864`, 0.936412013001446], 
             UndirectedEdge[278, 493] -> 
             RGBColor[
              0.9709705008180975, 0.974840539169355, 0.7572967831573334], 
             UndirectedEdge[6, 156] -> 
             RGBColor[
              0.6474994925034097, 0.7219315348762902, 0.9673172118721224], 
             UndirectedEdge[79, 413] -> 
             RGBColor[
              0.9838323701759427, 0.9563067408191819, 0.46126511216987476`], 
             UndirectedEdge[122, 476] -> 
             RGBColor[
              0.8579983660337116, 0.432494720305006, 0.20261219607186334`], 
             UndirectedEdge[123, 455] -> 
             RGBColor[
              0.20545207796979598`, 0.3332735387333343, 0.9350115639500436], 
             UndirectedEdge[113, 302] -> 
             RGBColor[
              0.18467080951855291`, 0.3114311079825565, 0.9338281014548768], 
             UndirectedEdge[402, 462] -> 
             RGBColor[
              0.5080947993050582, 0.6115332733425336, 0.9544182302953215], 
             UndirectedEdge[140, 363] -> 
             RGBColor[
              0.4522227109181607, 0.5648567259118211, 0.9503836849393674], 
             UndirectedEdge[440, 453] -> 
             RGBColor[
              0.2829903357512072, 0.4147711638710876, 0.939427253023122], 
             UndirectedEdge[9, 106] -> 
             RGBColor[
              0.5464995084832656, 0.6427119463658346, 0.9574415896829152], 
             UndirectedEdge[102, 202] -> 
             RGBColor[
              0.2577973086293919, 0.3882916950358828, 0.9379925473982783], 
             UndirectedEdge[363, 379] -> 
             RGBColor[
              0.35705527838116624`, 0.4836850688388347, 0.9439722245002304], 
             UndirectedEdge[162, 297] -> 
             RGBColor[
              0.4906978130641887, 0.5974096161868968, 0.9530486758111798], 
             UndirectedEdge[19, 393] -> 
             RGBColor[
              0.5104680056398668, 0.6134599491568583, 0.954605057791339], 
             UndirectedEdge[96, 238] -> 
             RGBColor[
              0.3081578274315908, 0.4401690531459169, 0.9408991236475683], 
             UndirectedEdge[117, 247] -> 
             RGBColor[
              0.4380433274875822, 0.5527007733374919, 0.9494455065337566], 
             UndirectedEdge[162, 223] -> 
             RGBColor[
              0.4259476007932227, 0.5431195461878823, 0.9484273528030159], 
             UndirectedEdge[355, 362] -> 
             RGBColor[
              0.3585841716726791, 0.48500931936353203`, 0.9440696442288183], 
             UndirectedEdge[59, 395] -> 
             RGBColor[
              0.2535893388235434, 0.38386885196924064`, 0.9377529097429688], 
             UndirectedEdge[161, 403] -> 
             RGBColor[
              0.9596219668575938, 0.962601388451382, 0.7050117798938269], 
             UndirectedEdge[214, 477] -> 
             RGBColor[
              0.2222393711458674, 0.35091804823724815`, 0.9359675754618462], 
             UndirectedEdge[65, 309] -> 
             RGBColor[
              0.9892477963467572, 0.9750667140916796, 0.4404269945442838], 
             UndirectedEdge[361, 498] -> 
             RGBColor[
              0.5530454795335582, 0.6479980366103388, 0.95797620936922], 
             UndirectedEdge[54, 70] -> 
             RGBColor[
              0.24348548029858347`, 0.3732490560378767, 0.9371775099472914], 
             UndirectedEdge[369, 390] -> 
             RGBColor[
              0.36035044557586515`, 0.48580021278599533`, 0.9442092467414281],
              UndirectedEdge[56, 88] -> 
             RGBColor[
              0.8516418675680354, 0.38504228297430826`, 0.19658027687583196`],
              UndirectedEdge[289, 419] -> 
             RGBColor[
              0.4760307938821983, 0.5851235769437257, 0.9519986681530803], 
             UndirectedEdge[124, 178] -> 
             RGBColor[
              0.977168593002762, 0.938254909924025, 0.5484416326473938], 
             UndirectedEdge[67, 465] -> 
             RGBColor[
              0.26962432665641767`, 0.4007226408585406, 0.9386660785784122], 
             UndirectedEdge[7, 461] -> 
             RGBColor[
              0.8915688064008891, 0.9161509753336762, 0.9816909809846657], 
             UndirectedEdge[273, 423] -> 
             RGBColor[
              0.24068365358124288`, 0.3703041585118776, 0.9370179500606701], 
             UndirectedEdge[63, 467] -> 
             RGBColor[
              0.563087381667329, 0.6542682731705118, 0.9596777258955458], 
             UndirectedEdge[179, 368] -> 
             RGBColor[
              0.2935153935219346, 0.41664755822089383`, 0.9403629879313062], 
             UndirectedEdge[211, 485] -> 
             RGBColor[
              0.23952079823930758`, 0.3690819238182165, 0.9369517271692371], 
             UndirectedEdge[21, 320] -> 
             RGBColor[
              0.9847451317139568, 0.9683734708666063, 0.6094013242659239], 
             UndirectedEdge[318, 479] -> 
             RGBColor[
              0.3767164983407358, 0.5007146293661655, 0.94522502005032], 
             UndirectedEdge[343, 465] -> 
             RGBColor[
              0.2877565452274621, 0.4197807522257663, 0.9396986816018197], 
             UndirectedEdge[229, 313] -> 
             RGBColor[
              0.2789668469500533, 0.41054222203715074`, 0.9391981212881146], 
             UndirectedEdge[168, 401] -> 
             RGBColor[
              0.842122298838193, 0.7534870262743261, 0.6125668464325392], 
             UndirectedEdge[70, 216] -> 
             RGBColor[
              0.26206807245195374`, 0.39278053859546125`, 0.9382357610799443],
              UndirectedEdge[5, 193] -> 
             RGBColor[
              0.263209529621381, 0.3939802824530939, 0.9383007653771087], 
             UndirectedEdge[213, 471] -> 
             RGBColor[
              0.8805092403498851, 0.5477975823099646, 0.2219082457048863], 
             UndirectedEdge[145, 404] -> 
             RGBColor[
              0.2170532372191201, 0.345467092660354, 0.9356722328069155], 
             UndirectedEdge[28, 173] -> 
             RGBColor[
              0.9747095150977819, 0.9805973489982415, 0.9249344880863324], 
             UndirectedEdge[210, 243] -> 
             RGBColor[
              0.8376849116916145, 0.29066832166115775`, 0.18372042003589745`],
              UndirectedEdge[133, 424] -> 
             RGBColor[
              0.33288404882225986`, 0.46274916467623195`, 0.942432055126516], 
             UndirectedEdge[201, 400] -> 
             RGBColor[
              0.30019030163233085`, 0.432849418552972, 0.9404067656349827], 
             UndirectedEdge[120, 125] -> 
             RGBColor[
              0.2080475453125366, 0.33600153947268885`, 0.9351593719755629], 
             UndirectedEdge[96, 343] -> 
             RGBColor[
              0.29452462133405766`, 0.4268944293346082, 0.940084113523619], 
             UndirectedEdge[22, 149] -> 
             RGBColor[
              0.40264564991743174`, 0.5231731572248479, 0.9468772026605385], 
             UndirectedEdge[140, 369] -> 
             RGBColor[
              0.4597907440975337, 0.5714117758713864, 0.950865913321408], 
             UndirectedEdge[169, 370] -> 
             RGBColor[
              0.5420927609464797, 0.6391343501937576, 0.9570946743743712], 
             UndirectedEdge[154, 380] -> 
             RGBColor[
              0.2911961325222311, 0.423322454553487, 0.9398972530104752], 
             UndirectedEdge[33, 489] -> 
             RGBColor[
              0.9342559232885688, 0.7654812281083937, 0.517015114696979], 
             UndirectedEdge[271, 284] -> 
             RGBColor[
              0.2504489768010796, 0.3805681323731789, 0.9375740707715388], 
             UndirectedEdge[112, 356] -> 
             RGBColor[
              0.2588007282426925, 0.3893463526699398, 0.9380496906608295], 
             UndirectedEdge[133, 155] -> 
             RGBColor[
              0.4555313931992919, 0.5659235600860384, 0.9510915748153721], 
             UndirectedEdge[82, 447] -> 
             RGBColor[
              0.25238928516537673`, 0.3826075194867109, 0.9376845684624564], 
             UndirectedEdge[225, 260] -> 
             RGBColor[
              0.27991286113099906`, 0.41153654292208813`, 0.9392519953962168],
              UndirectedEdge[133, 225] -> 
             RGBColor[
              0.3097114792684619, 0.4394887933443991, 0.9410723011032855], 
             UndirectedEdge[442, 444] -> 
             RGBColor[
              0.27761918641957545`, 0.4091257453730057, 0.939121374014589], 
             UndirectedEdge[49, 431] -> 
             RGBColor[
              0.4693773227785792, 0.5799709458958486, 0.9514060951044689], 
             UndirectedEdge[220, 427] -> 
             RGBColor[
              0.30920666661498386`, 0.43953702554153684`, 0.9410223592495326],
              UndirectedEdge[151, 192] -> 
             RGBColor[
              0.28070448165153206`, 0.4123685862808082, 0.9392970770137636], 
             UndirectedEdge[167, 326] -> 
             RGBColor[
              0.9309228830343801, 0.7574193985269815, 0.5440638154599668], 
             UndirectedEdge[109, 196] -> 
             RGBColor[
              0.27482966958615396`, 0.4061937863154972, 0.938962515157646], 
             UndirectedEdge[212, 451] -> 
             RGBColor[
              0.21498103480107186`, 0.34328907653376356`, 0.9355542239447563],
              UndirectedEdge[186, 414] -> 
             RGBColor[
              0.255184189019674, 0.3855451406447167, 0.937843734102269], 
             UndirectedEdge[349, 419] -> 
             RGBColor[
              0.4631460027688009, 0.5739634184897324, 0.951177660656908], 
             UndirectedEdge[162, 221] -> 
             RGBColor[
              0.4993207487803075, 0.6044101038600693, 0.953727504897607], 
             UndirectedEdge[163, 364] -> 
             RGBColor[
              0.2627794929075267, 0.39352828660093053`, 0.938276275422437], 
             UndirectedEdge[191, 300] -> 
             RGBColor[
              0.22217951414553483`, 0.3508551347347456, 0.9359641666942277], 
             UndirectedEdge[438, 460] -> 
             RGBColor[
              0.23490540515407732`, 0.3642308530528161, 0.9366888873608955], 
             UndirectedEdge[172, 473] -> 
             RGBColor[
              0.3392418574009336, 0.4682559789143286, 0.9428371690671595], 
             UndirectedEdge[141, 188] -> 
             RGBColor[
              0.32343001274534444`, 0.45456055380007726`, 0.9418296523075707],
              UndirectedEdge[79, 122] -> 
             RGBColor[
              0.9306665098261713, 0.7402291937878942, 0.3904132893585251], 
             UndirectedEdge[326, 475] -> 
             RGBColor[
              0.8570894511774583, 0.4134428533627656, 0.20126936153652183`], 
             UndirectedEdge[98, 124] -> 
             RGBColor[
              0.9789436438067185, 0.93894816660261, 0.5160607207640602], 
             UndirectedEdge[204, 498] -> 
             RGBColor[
              0.4818912814299178, 0.5902600770764668, 0.9523553933815417], 
             UndirectedEdge[72, 144] -> 
             RGBColor[
              0.2501061102631632, 0.3802077579028347, 0.93755454502943], 
             UndirectedEdge[98, 331] -> 
             RGBColor[
              0.9159632164581281, 0.9324175867663749, 0.8534971993423514], 
             UndirectedEdge[311, 377] -> 
             RGBColor[
              0.8639809895032101, 0.8937991659736781, 0.9461358346293043], 
             UndirectedEdge[299, 389] -> 
             RGBColor[
              0.213833079654714, 0.34208250289038133`, 0.9354888495974187], 
             UndirectedEdge[131, 238] -> 
             RGBColor[
              0.29188148517230905`, 0.42306158545170824`, 0.9399722100345929],
              UndirectedEdge[4, 185] -> 
             RGBColor[
              0.30412419819916303`, 0.4355457825101565, 0.9406834624888651], 
             UndirectedEdge[162, 258] -> 
             RGBColor[
              0.4177269296537439, 0.5359992140298111, 0.9479035389072623], 
             UndirectedEdge[124, 253] -> 
             RGBColor[
              0.9738421982948224, 0.9368793602278473, 0.603568601391508], 
             UndirectedEdge[319, 449] -> 
             RGBColor[
              0.7215962304048408, 0.7824357266175173, 0.9728856266127364], 
             UndirectedEdge[256, 271] -> 
             RGBColor[
              0.2725957288123946, 0.4038457729222503, 0.9388352955353996], 
             UndirectedEdge[379, 478] -> 
             RGBColor[
              0.2876705710791334, 0.41963924089195836`, 0.9396956582454141], 
             UndirectedEdge[349, 371] -> 
             RGBColor[
              0.3882726943942144, 0.5107240255563866, 0.9459613706441047], 
             UndirectedEdge[130, 325] -> 
             RGBColor[
              0.1789719601845752, 0.3054412560046289, 0.9335035604159989], 
             UndirectedEdge[269, 369] -> 
             RGBColor[
              0.43444338232168905`, 0.5507147548329152, 0.948903326051707], 
             UndirectedEdge[43, 355] -> 
             RGBColor[
              0.3109273076150301, 0.4422891800076947, 0.941085795498422], 
             UndirectedEdge[11, 414] -> 
             RGBColor[
              0.25678804986481485`, 0.38723090008361066`, 0.9379350716047002],
              UndirectedEdge[117, 255] -> 
             RGBColor[
              0.38933039965095584`, 0.511640156687964, 0.9460287666877722], 
             UndirectedEdge[401, 475] -> 
             RGBColor[
              0.806227884360017, 0.5618744373452094, 0.5815185800497742], 
             UndirectedEdge[58, 141] -> 
             RGBColor[
              0.3123473120692484, 0.44496127550717535`, 0.9411234724205373], 
             UndirectedEdge[96, 180] -> 
             RGBColor[
              0.2831463385898367, 0.4149351327456384, 0.9394361371539964], 
             UndirectedEdge[119, 375] -> 
             RGBColor[
              0.9744244063754681, 0.9793738724475776, 0.8801494909995853], 
             UndirectedEdge[220, 382] -> 
             RGBColor[
              0.3105689508267532, 0.4409688726219141, 0.9410999393200739], 
             UndirectedEdge[104, 356] -> 
             RGBColor[
              0.2579557991377684, 0.3884582786090651, 0.9380015731982647], 
             UndirectedEdge[225, 440] -> 
             RGBColor[
              0.27796156594151966`, 0.4094856079586846, 0.9391408720218586], 
             UndirectedEdge[259, 341] -> 
             RGBColor[
              0.9277070351691528, 0.7270975616364004, 0.37415406223837167`], 
             UndirectedEdge[290, 362] -> 
             RGBColor[
              0.3374733904051481, 0.4646660623491092, 0.9427998432095333], 
             UndirectedEdge[79, 267] -> 
             RGBColor[
              0.9914456607402118, 0.9819881575780944, 0.49084130836277423`], 
             UndirectedEdge[90, 317] -> 
             RGBColor[
              0.8740850504741097, 0.5211314470341011, 0.21664581846880504`], 
             UndirectedEdge[41, 389] -> 
             RGBColor[
              0.2255132290582107, 0.3543590804777015, 0.9361540168267153], 
             UndirectedEdge[5, 300] -> 
             RGBColor[
              0.23228249418787045`, 0.3614740073251723, 0.936539516461619], 
             UndirectedEdge[290, 340] -> 
             RGBColor[
              0.31195990105564253`, 0.44256756021982796`, 0.9411741462288754],
              UndirectedEdge[288, 392] -> 
             RGBColor[
              0.281033651223698, 0.41271456437171095`, 0.9393158227339358], 
             UndirectedEdge[45, 292] -> 
             RGBColor[
              0.23087655194201073`, 0.35999627288288677`, 0.9364594501306225],
              UndirectedEdge[42, 145] -> 
             RGBColor[
              0.22656621784669417`, 0.3554658384577429, 0.9362139829804621], 
             UndirectedEdge[100, 368] -> 
             RGBColor[
              0.6696582512860165, 0.6464478563026956, 0.6053684569202311], 
             UndirectedEdge[302, 315] -> 
             RGBColor[
              0.18782448730516063`, 0.31474582329100176`, 0.934007698739376], 
             UndirectedEdge[255, 338] -> 
             RGBColor[
              0.35884542683277726`, 0.48523560545214284`, 0.9440862911766009],
              UndirectedEdge[59, 263] -> 
             RGBColor[
              0.25779587834217144`, 0.38829019171332857`, 0.9379924659455371],
              UndirectedEdge[413, 486] -> 
             RGBColor[
              0.9543818118224241, 0.9371774082640264, 0.6732568757445232], 
             UndirectedEdge[140, 247] -> 
             RGBColor[
              0.4973227229374232, 0.6027880164707773, 0.9535702129842454], 
             UndirectedEdge[82, 453] -> 
             RGBColor[
              0.27129272785642566`, 0.40247623630249474`, 0.9387610915585742],
              UndirectedEdge[199, 349] -> 
             RGBColor[
              0.3782226741008029, 0.5020192031069408, 0.9453209922378925], 
             UndirectedEdge[265, 462] -> 
             RGBColor[
              0.392446435384819, 0.5140523715462819, 0.9463065444803587], 
             UndirectedEdge[113, 386] -> 
             RGBColor[
              0.17905963034776856`, 0.3055334029047545, 0.9335085531020964], 
             UndirectedEdge[140, 219] -> 
             RGBColor[
              0.5129514818808725, 0.6154761470486363, 0.9548005661383041], 
             UndirectedEdge[13, 313] -> 
             RGBColor[
              0.2817870779153078, 0.4135064635946042, 0.939358729269428], 
             UndirectedEdge[74, 463] -> 
             RGBColor[
              0.2744156870316411, 0.4057586644026942, 0.9389389394635987], 
             UndirectedEdge[146, 415] -> 
             RGBColor[
              0.27247295826931617`, 0.4037167332973729, 0.9388283039345939], 
             UndirectedEdge[213, 475] -> 
             RGBColor[
              0.871604644354381, 0.4793529554696741, 0.21338119452328883`], 
             UndirectedEdge[49, 328] -> 
             RGBColor[
              0.4377638604952656, 0.5525889538048573, 0.9493917132424632], 
             UndirectedEdge[259, 450] -> 
             RGBColor[
              0.8397745913250846, 0.3013267240551166, 0.18550990071046175`], 
             UndirectedEdge[454, 500] -> 
             RGBColor[
              0.8596875442431727, 0.3945530129661969, 0.20223564129349905`], 
             UndirectedEdge[469, 495] -> 
             RGBColor[
              0.8513165746787745, 0.3922611978068248, 0.19664935782673318`], 
             UndirectedEdge[158, 182] -> 
             RGBColor[
              0.36805399542884243`, 0.4932116047339394, 0.9446730530247247], 
             UndirectedEdge[302, 347] -> 
             RGBColor[
              0.18453817917078433`, 0.311291705077802, 0.9338205483527805], 
             UndirectedEdge[87, 107] -> 
             RGBColor[
              0.1819624771956669, 0.3085844789930161, 0.9336738659357071], 
             UndirectedEdge[80, 307] -> 
             RGBColor[
              0.6296762406643908, 0.7079838947833768, 0.9655310968074982], 
             UndirectedEdge[159, 443] -> 
             RGBColor[
              0.877631072588452, 0.4692846461457165, 0.21683434670508697`], 
             UndirectedEdge[396, 443] -> 
             RGBColor[
              0.9640290207521414, 0.8833364286136021, 0.40253589756085995`], 
             UndirectedEdge[15, 452] -> 
             RGBColor[
              0.22909610908040262`, 0.3581249145487392, 0.9363580565435832], 
             UndirectedEdge[55, 250] -> 
             RGBColor[
              0.20796149957955015`, 0.33591109995170554`, 0.9351544717983624],
              UndirectedEdge[105, 447] -> 
             RGBColor[
              0.24620260884716, 0.3761049304183308, 0.9373322463985014], 
             UndirectedEdge[55, 242] -> 
             RGBColor[
              0.21824264556347417`, 0.34671723624311485`, 0.9357399678525544],
              UndirectedEdge[133, 440] -> 
             RGBColor[
              0.31342375230206637`, 0.44339062767442217`, 0.9412837095607336],
              UndirectedEdge[177, 455] -> 
             RGBColor[
              0.2063185988388122, 0.33418430710726665`, 0.9350609110316312], 
             UndirectedEdge[186, 456] -> 
             RGBColor[
              0.22968446940414386`, 0.35874331855319036`, 0.9363915627936191],
              UndirectedEdge[94, 302] -> 
             RGBColor[
              0.5727842186692342, 0.6417308063914131, 0.9472440733920693], 
             UndirectedEdge[146, 376] -> 
             RGBColor[
              0.2686941653913333, 0.39974498239330636`, 0.9386131072704159], 
             UndirectedEdge[44, 106] -> 
             RGBColor[
              0.5072662938524296, 0.6108606552923443, 0.9543530073111751], 
             UndirectedEdge[46, 205] -> 
             RGBColor[
              0.9557407049755898, 0.8502199530826348, 0.4110195083871594], 
             UndirectedEdge[134, 457] -> 
             RGBColor[
              0.22739772905471156`, 0.3563398094582248, 0.936261336313648], 
             UndirectedEdge[229, 248] -> 
             RGBColor[
              0.2667577277658053, 0.3977096636716398, 0.9385028300123448], 
             UndirectedEdge[101, 362] -> 
             RGBColor[
              0.45464713410545365`, 0.5663810460128507, 0.950697205214848], 
             UndirectedEdge[286, 346] -> 
             RGBColor[
              0.22049146079372114`, 0.3490808836332252, 0.935868034553093], 
             UndirectedEdge[134, 138] -> 
             RGBColor[
              0.2265863896100655, 0.3554870402600099, 0.9362151317325447], 
             UndirectedEdge[144, 494] -> 
             RGBColor[
              0.25236564813326057`, 0.3825826754672824, 0.9376832223684453], 
             UndirectedEdge[35, 147] -> 
             RGBColor[
              0.2449327987863818, 0.374770279533845, 0.9372599325940558], 
             UndirectedEdge[5, 211] -> 
             RGBColor[
              0.2348238735021131, 0.3641451581171964, 0.9366842442539314], 
             UndirectedEdge[243, 471] -> 
             RGBColor[
              0.8480593461920269, 0.37041077133751354`, 0.1936549902297403], 
             UndirectedEdge[154, 338] -> 
             RGBColor[
              0.314823265682197, 0.4471058220816644, 0.9412812379953546], 
             UndirectedEdge[185, 383] -> 
             RGBColor[
              0.3064436349421723, 0.43755476203867083`, 0.9408312549471323], 
             UndirectedEdge[416, 429] -> 
             RGBColor[
              0.2775658260011634, 0.4090696601900088, 0.9391183352177], 
             UndirectedEdge[159, 396] -> 
             RGBColor[
              0.9071481131704897, 0.5745522202562454, 0.3532052383412315], 
             UndirectedEdge[73, 322] -> 
             RGBColor[
              0.2535645087759725, 0.3838427540149276, 0.9377514957084923], 
             UndirectedEdge[287, 300] -> 
             RGBColor[
              0.2178846815571592, 0.3463409933762489, 0.9357195823319551], 
             UndirectedEdge[392, 459] -> 
             RGBColor[
              0.34827375514967984`, 0.47582519706689724`, 0.9434219649183455],
              UndirectedEdge[200, 450] -> 
             RGBColor[
              0.8592682454015592, 0.38984285435780597`, 0.20177588350505832`],
              UndirectedEdge[104, 148] -> 
             RGBColor[
              0.2431147548759032, 0.37285940011329033`, 0.9371563976829089], 
             UndirectedEdge[94, 325] -> 
             RGBColor[
              0.5672179996830251, 0.6358803573182399, 0.9469270854552878], 
             UndirectedEdge[355, 378] -> 
             RGBColor[
              0.30589561445696456`, 0.4370005514707954, 0.940799248016793], 
             UndirectedEdge[424, 453] -> 
             RGBColor[
              0.3024506322714007, 0.4341297008728973, 0.9405755985889044], 
             UndirectedEdge[212, 301] -> 
             RGBColor[
              0.2136344659280746, 0.34187374727084574`, 0.9354775388395093], 
             UndirectedEdge[46, 420] -> 
             RGBColor[
              0.9431488383406506, 0.8436851965616485, 0.5952825252201055], 
             UndirectedEdge[146, 284] -> 
             RGBColor[
              0.25151293220690424`, 0.3816864169633695, 0.9376346614579194], 
             UndirectedEdge[76, 343] -> 
             RGBColor[
              0.3521064049491038, 0.47793237749510553`, 0.9437105723744709], 
             UndirectedEdge[111, 256] -> 
             RGBColor[
              0.2812386903435383, 0.41293007348689414`, 0.9393274994084824], 
             UndirectedEdge[277, 319] -> 
             RGBColor[
              0.7430956081884199, 0.7992312039433723, 0.9750284836670953], 
             UndirectedEdge[240, 429] -> 
             RGBColor[
              0.2751117605214455, 0.4064902817740869, 0.9389785798190946], 
             UndirectedEdge[49, 71] -> 
             RGBColor[
              0.6229981269292593, 0.7030794824142605, 0.9646517716159538], 
             UndirectedEdge[19, 139] -> 
             RGBColor[
              0.5618798532479841, 0.6551984031224687, 0.9586523867628529], 
             UndirectedEdge[9, 247] -> 
             RGBColor[
              0.5350775301382318, 0.6334390697910756, 0.9565424097075088], 
             UndirectedEdge[333, 392] -> 
             RGBColor[
              0.34232526370384136`, 0.4706729127563853, 0.943042932303461], 
             UndirectedEdge[169, 337] -> 
             RGBColor[
              0.6764764422213522, 0.7452210038115648, 0.9698692373870139], 
             UndirectedEdge[21, 119] -> 
             RGBColor[
              0.9857675700825197, 0.9687962754074746, 0.5924568745131584], 
             UndirectedEdge[354, 479] -> 
             RGBColor[
              0.38662725868303643`, 0.5092988318453677, 0.9458565249355901], 
             UndirectedEdge[179, 236] -> 
             RGBColor[
              0.23312614698427564`, 0.36236073990487094`, 0.9365875612403018],
              UndirectedEdge[121, 341] -> 
             RGBColor[
              0.9105196563022746, 0.6003916270804778, 0.3579070077274834], 
             UndirectedEdge[263, 323] -> 
             RGBColor[
              0.2563726589916906, 0.3867942979386546, 0.9379114157089916], 
             UndirectedEdge[200, 401] -> 
             RGBColor[
              0.8371401925160188, 0.7327555556169211, 0.6085074799840489], 
             UndirectedEdge[56, 236] -> 
             RGBColor[
              0.5619983827153064, 0.35111011799079705`, 0.5612129978793174], 
             UndirectedEdge[374, 437] -> 
             RGBColor[
              0.25378039219455883`, 0.3840696611756612, 0.9377637899498099], 
             UndirectedEdge[74, 195] -> 
             RGBColor[
              0.27594296910076915`, 0.40736393469262394`, 0.9390259159180243],
              UndirectedEdge[240, 399] -> 
             RGBColor[
              0.24906325398775672`, 0.3791116498364756, 0.9374951559073132], 
             UndirectedEdge[138, 352] -> 
             RGBColor[
              0.22389864331585435`, 0.3526620484918363, 0.9360620685572537], 
             UndirectedEdge[195, 342] -> 
             RGBColor[
              0.265069534257383, 0.39593526525663725`, 0.9384066898894987], 
             UndirectedEdge[13, 363] -> 
             RGBColor[
              0.3507138092232281, 0.4770709297343131, 0.9436092144688942], 
             UndirectedEdge[368, 386] -> 
             RGBColor[
              0.2935143249909316, 0.4166464351270609, 0.9403629270800464], 
             UndirectedEdge[132, 233] -> 
             RGBColor[
              0.9166463543771588, 0.6614692040973338, 0.5010749461233683], 
             UndirectedEdge[304, 310] -> 
             RGBColor[
              0.317660558842397, 0.44845488439544834`, 0.9415026138990965], 
             UndirectedEdge[213, 259] -> 
             RGBColor[
              0.8830232984339081, 0.5617179434386964, 0.224104111662967], 
             UndirectedEdge[226, 446] -> 
             RGBColor[
              0.20378813280661343`, 0.33152462686661266`, 0.9349168047345866],
              UndirectedEdge[60, 249] -> 
             RGBColor[
              0.29112873348308044`, 0.42332513589150556`, 0.9398907227342717],
              UndirectedEdge[181, 387] -> 
             RGBColor[
              0.5979055016129029, 0.6815262817946347, 0.9631235948533272], 
             UndirectedEdge[94, 168] -> 
             RGBColor[
              0.9331056494970619, 0.8251500560931704, 0.6037137900969318], 
             UndirectedEdge[142, 402] -> 
             RGBColor[
              0.6259177691187879, 0.7063115685381091, 0.9642924066530247], 
             UndirectedEdge[188, 310] -> 
             RGBColor[
              0.3170171080071488, 0.4478975596227356, 0.9414616137808558], 
             UndirectedEdge[74, 239] -> 
             RGBColor[
              0.31633226480045645`, 0.4459153985127936, 0.9414688336983061], 
             UndirectedEdge[376, 400] -> 
             RGBColor[
              0.2876884645475003, 0.41970919511456195`, 0.9396948045078122], 
             UndirectedEdge[292, 308] -> 
             RGBColor[
              0.17895845847297373`, 0.30542706484967774`, 0.9335027915134972],
              UndirectedEdge[7, 142] -> 
             RGBColor[
              0.7691032060058948, 0.819699666861827, 0.9775805727504322], 
             UndirectedEdge[20, 194] -> 
             RGBColor[
              0.9355250585723344, 0.7786349412620628, 0.5492457614630861], 
             UndirectedEdge[168, 500] -> 
             RGBColor[
              0.8651424411448785, 0.41743131522220955`, 0.2066895157907081], 
             UndirectedEdge[4, 383] -> 
             RGBColor[
              0.32662308368104653`, 0.45732623135617084`, 0.9420331119640719],
              UndirectedEdge[91, 303] -> 
             RGBColor[
              0.3164436833902854, 0.44818690517109605`, 0.9413962957337874], 
             UndirectedEdge[142, 417] -> 
             RGBColor[
              0.7002784838355302, 0.7657821409766972, 0.9707608728603756], 
             UndirectedEdge[229, 338] -> 
             RGBColor[
              0.3055405634218271, 0.43742263545021065`, 0.9407499098335221], 
             UndirectedEdge[69, 388] -> 
             RGBColor[
              0.9278173046721767, 0.9450102776472538, 0.9836136557859578], 
             UndirectedEdge[170, 374] -> 
             RGBColor[
              0.2742054454433818, 0.40553768716334715`, 0.9389269665161719], 
             UndirectedEdge[96, 281] -> 
             RGBColor[
              0.27053519804586806`, 0.4016800244414347, 0.938717951356528], 
             UndirectedEdge[131, 265] -> 
             RGBColor[
              0.29231177765764305`, 0.42343428317537546`, 0.9399996278912657],
              UndirectedEdge[117, 369] -> 
             RGBColor[
              0.40051134864769267`, 0.5213245327381009, 0.9467412068709193], 
             UndirectedEdge[19, 247] -> 
             RGBColor[
              0.5273679540729146, 0.6271800886288073, 0.9559354836385393], 
             UndirectedEdge[328, 436] -> 
             RGBColor[
              0.42911640965865483`, 0.5455685636524759, 0.9487109542359491], 
             UndirectedEdge[86, 178] -> 
             RGBColor[
              0.9534388639235, 0.8461526483552239, 0.5190456011559075], 
             UndirectedEdge[42, 137] -> 
             RGBColor[
              0.22627740530250587`, 0.35516227816202806`, 0.9361975355333305],
              UndirectedEdge[54, 135] -> 
             RGBColor[
              0.23967378277683635`, 0.36924272026693905`, 0.9369604394123292],
              UndirectedEdge[42, 174] -> 
             RGBColor[
              0.2495656884148965, 0.3796397402755821, 0.9375237688046536], 
             UndirectedEdge[1, 374] -> 
             RGBColor[
              0.25894790578239785`, 0.38950104559576504`, 0.9380580722039861],
              UndirectedEdge[160, 285] -> 
             RGBColor[
              0.3684500451199806, 0.49355464307036695`, 0.9446982889608311], 
             UndirectedEdge[454, 471] -> 
             RGBColor[
              0.8783475046128462, 0.5379816452142798, 0.2201044404169093], 
             UndirectedEdge[26, 425] -> 
             RGBColor[
              0.38098619324606947`, 0.5044128244920598, 0.9454970812341448], 
             UndirectedEdge[333, 442] -> 
             RGBColor[
              0.331297230301234, 0.4590817504325423, 0.942414902115696], 
             UndirectedEdge[75, 410] -> 
             RGBColor[
              0.354306761585108, 0.48130444173456, 0.9437970914404035], 
             UndirectedEdge[31, 40] -> 
             RGBColor[
              0.4196192099941566, 0.5378748018473721, 0.9479587428994976], 
             UndirectedEdge[3, 258] -> 
             RGBColor[
              0.41754423807969365`, 0.5358508967798354, 0.9478891567573319], 
             UndirectedEdge[132, 273] -> 
             RGBColor[
              0.6418371637733833, 0.7080243687957053, 0.8766074186854609], 
             UndirectedEdge[157, 180] -> 
             RGBColor[
              0.2863372761085622, 0.4182890103949429, 0.9396178563251187], 
             UndirectedEdge[213, 401] -> 
             RGBColor[
              0.8388291376735261, 0.7404246611139982, 0.6099167772233072], 
             UndirectedEdge[84, 391] -> 
             RGBColor[
              0.23722076036640824`, 0.3666644381829753, 0.9368207434149767], 
             UndirectedEdge[43, 110] -> 
             RGBColor[
              0.2824315567297242, 0.4141838516908727, 0.9393954313844881], 
             UndirectedEdge[39, 127] -> 
             RGBColor[
              0.4248206994263658, 0.5301025431322064, 0.9498483295981558], 
             UndirectedEdge[52, 469] -> 
             RGBColor[
              0.8481128613393234, 0.36763605320366755`, 0.19358147831479822`],
              UndirectedEdge[260, 483] -> 
             RGBColor[
              0.2911128004849959, 0.42330838930030823`, 0.9398898153736015], 
             UndirectedEdge[98, 311] -> 
             RGBColor[
              0.8710458030481137, 0.8971927199459824, 0.8490560873664715], 
             UndirectedEdge[51, 127] -> 
             RGBColor[
              0.20245340605759676`, 0.3301217444268325, 0.9348407940207814], 
             UndirectedEdge[243, 475] -> 
             RGBColor[
              0.8391547501965229, 0.3019661444972231, 0.18512793904814284`], 
             UndirectedEdge[76, 96] -> 
             RGBColor[
              0.3537435180123586, 0.4796530871235497, 0.9438038035415315], 
             UndirectedEdge[99, 476] -> 
             RGBColor[
              0.9210569805098886, 0.6812525268241133, 0.37059559494700395`], 
             UndirectedEdge[107, 308] -> 
             RGBColor[
              0.18180898862834943`, 0.3084231527770282, 0.9336651249888644], 
             UndirectedEdge[190, 263] -> 
             RGBColor[
              0.26075513515246407`, 0.3914005582486648, 0.9381609912430551], 
             UndirectedEdge[191, 299] -> 
             RGBColor[
              0.21378387890714912`, 0.3420307897851831, 0.935486047687631], 
             UndirectedEdge[39, 276] -> 
             RGBColor[
              0.6216008719460259, 0.7036826165027719, 0.9633538441200625], 
             UndirectedEdge[51, 214] -> 
             RGBColor[
              0.1893670578318586, 0.31636716271918164`, 0.9340955458488429], 
             UndirectedEdge[295, 409] -> 
             RGBColor[
              0.23557177233220394`, 0.3649312472071466, 0.9367268359858879], 
             UndirectedEdge[371, 382] -> 
             RGBColor[
              0.322584307384319, 0.45137597056269757`, 0.9418655472151594], 
             UndirectedEdge[53, 420] -> 
             RGBColor[
              0.9725775680800968, 0.9542835451375451, 0.6506094324523175], 
             UndirectedEdge[87, 308] -> 
             RGBColor[
              0.17909977333492821`, 0.3055755957294717, 0.9335108391858289], 
             UndirectedEdge[286, 358] -> 
             RGBColor[
              0.22436323878386594`, 0.35315036778577047`, 0.9360885265818495],
              UndirectedEdge[215, 351] -> 
             RGBColor[
              0.28708427642095813`, 0.4190741550858264, 0.9396603968878219], 
             UndirectedEdge[114, 258] -> 
             RGBColor[
              0.4370504632160207, 0.551686929090934, 0.9494247582537205], 
             UndirectedEdge[87, 292] -> 
             RGBColor[
              0.1791119470402912, 0.3055883910656657, 0.93351153246034], 
             UndirectedEdge[196, 383] -> 
             RGBColor[
              0.3123209276016251, 0.4437321692656331, 0.941165958069413], 
             UndirectedEdge[65, 495] -> 
             RGBColor[
              0.9138336495538494, 0.6440119286541663, 0.2930402350354805], 
             UndirectedEdge[14, 279] -> 
             RGBColor[
              0.2926514518650601, 0.4249256094568878, 0.9399774392934654], 
             UndirectedEdge[26, 466] -> 
             RGBColor[
              0.4450688550450512, 0.558555224381097, 0.9499569121935232], 
             UndirectedEdge[27, 371] -> 
             RGBColor[
              0.43753141765926407`, 0.551792873087608, 0.9495412335023905], 
             UndirectedEdge[258, 472] -> 
             RGBColor[
              0.3509345795878789, 0.47838362717935545`, 0.9435822189854435], 
             UndirectedEdge[26, 117] -> 
             RGBColor[
              0.38385240519854513`, 0.5068953932252928, 0.9456797137252648], 
             UndirectedEdge[97, 104] -> 
             RGBColor[
              0.23915408747259903`, 0.3686964875516002, 0.936930843533573], 
             UndirectedEdge[21, 428] -> 
             RGBColor[
              0.9056106309029361, 0.5906771035003356, 0.2784668522610333], 
             UndirectedEdge[160, 268] -> 
             RGBColor[
              0.41606826400089775`, 0.5347991509037464, 0.9477324797607855], 
             UndirectedEdge[48, 137] -> 
             RGBColor[
              0.21379570916554433`, 0.34204322413683813`, 0.9354867214033452],
              UndirectedEdge[27, 291] -> 
             RGBColor[
              0.583523028601068, 0.6725767800031528, 0.9604878491746004], 
             UndirectedEdge[117, 140] -> 
             RGBColor[
              0.44035466890019287`, 0.5545772244209933, 0.9496274637964799], 
             UndirectedEdge[31, 221] -> 
             RGBColor[
              0.4948241717740719, 0.6007519845572706, 0.9533756165491586], 
             UndirectedEdge[87, 386] -> 
             RGBColor[
              0.17909013095112286`, 0.3055654609727298, 0.9335102900663359], 
             UndirectedEdge[207, 409] -> 
             RGBColor[
              0.22930932819200256`, 0.35834902135390323`, 0.9363701990565594],
              UndirectedEdge[274, 498] -> 
             RGBColor[
              0.46231188623512687`, 0.5743646420156336, 0.95081403167012], 
             UndirectedEdge[28, 69] -> 
             RGBColor[
              0.9371592911405698, 0.9519775158592825, 0.9678001094752631], 
             UndirectedEdge[442, 492] -> 
             RGBColor[
              0.2802823193946945, 0.4119248669822389, 0.9392730354977699], 
             UndirectedEdge[476, 493] -> 
             RGBColor[
              0.9210348441528622, 0.6812051793947629, 0.36818618909444256`], 
             UndirectedEdge[297, 359] -> 
             RGBColor[
              0.45240773600559087`, 0.5644812656494411, 0.9505434955218137], 
             UndirectedEdge[112, 323] -> 
             RGBColor[
              0.24380409586490398`, 0.37358394119947325`, 0.9371956546324439],
              UndirectedEdge[27, 349] -> 
             RGBColor[
              0.46286019331944683`, 0.5737313855031778, 0.9511551606901004], 
             UndirectedEdge[2, 242] -> 
             RGBColor[
              0.21872765624032725`, 0.34722701321594046`, 0.9357675884930923],
              UndirectedEdge[71, 462] -> 
             RGBColor[
              0.6098299518680684, 0.6923889646800596, 0.9636151246385223], 
             UndirectedEdge[165, 285] -> 
             RGBColor[
              0.3692257984681636, 0.49422656163006606`, 0.9447477192782054], 
             UndirectedEdge[91, 172] -> 
             RGBColor[
              0.33964065051404985`, 0.4686013934649852, 0.9428625798116885], 
             UndirectedEdge[19, 26] -> 
             RGBColor[
              0.4731770317838775, 0.5813747085166081, 0.9521696908300475], 
             UndirectedEdge[73, 163] -> 
             RGBColor[
              0.2574513896017804, 0.3879281122053299, 0.9379728478213971], 
             UndirectedEdge[67, 131] -> 
             RGBColor[
              0.2601160605037315, 0.39072885027317383`, 0.938124596887236], 
             UndirectedEdge[24, 81] -> 
             RGBColor[
              0.8302950804632105, 0.8675187756745408, 0.9836754800593912], 
             UndirectedEdge[282, 467] -> 
             RGBColor[
              0.6572487791197071, 0.7316354395209496, 0.9668355107224047], 
             UndirectedEdge[122, 406] -> 
             RGBColor[
              0.929061342775948, 0.7356327772399205, 0.3146046467534838], 
             UndirectedEdge[139, 255] -> 
             RGBColor[
              0.4808103528632557, 0.5878692632314095, 0.9526884189998513], 
             UndirectedEdge[409, 458] -> 
             RGBColor[
              0.23602745875437942`, 0.36541020252904094`, 0.9367527866535031],
              UndirectedEdge[4, 196] -> 
             RGBColor[
              0.31000149085861584`, 0.44172318973711877`, 0.9410181656111457],
              UndirectedEdge[46, 90] -> 
             RGBColor[
              0.8912123121580973, 0.5950344530170778, 0.2307371435474895], 
             UndirectedEdge[115, 124] -> 
             RGBColor[
              0.9419104649402625, 0.9128295501642687, 0.6508778471089514], 
             UndirectedEdge[330, 350] -> 
             RGBColor[
              0.33430977302587317`, 0.4637717331289171, 0.9425306751676419], 
             UndirectedEdge[213, 315] -> 
             RGBColor[
              0.5448527569683213, 0.48510270783243126`, 0.5878273462350064], 
             UndirectedEdge[107, 143] -> 
             RGBColor[
              0.18179934691843552`, 0.30841301872858895`, 0.9336645759077484],
              UndirectedEdge[403, 491] -> 
             RGBColor[
              0.9615367037861473, 0.968036714632053, 0.7994838663892643], 
             UndirectedEdge[200, 254] -> 
             RGBColor[
              0.5686631284014866, 0.5042350008222019, 0.5878701973527287], 
             UndirectedEdge[37, 304] -> 
             RGBColor[
              0.32210212279026273`, 0.45312324971607465`, 0.9417555543952225],
              UndirectedEdge[25, 392] -> 
             RGBColor[
              0.3096883372024623, 0.4424044474005129, 0.9409633362064942], 
             UndirectedEdge[231, 492] -> 
             RGBColor[
              0.2675328366491727, 0.39852435225280064`, 0.9385469713165818], 
             UndirectedEdge[22, 63] -> 
             RGBColor[
              0.4353760609281416, 0.5515225941640346, 0.948962755507775], 
             UndirectedEdge[201, 256] -> 
             RGBColor[
              0.2969224563599441, 0.4294147059783363, 0.9402206666810642], 
             UndirectedEdge[57, 92] -> 
             RGBColor[
              0.6051902881840892, 0.690359765316458, 0.9620619428523739], 
             UndirectedEdge[433, 462] -> 
             RGBColor[
              0.3946923083800721, 0.5159976338539112, 0.9464496495216687], 
             UndirectedEdge[286, 294] -> 
             RGBColor[
              0.23070650372322443`, 0.3598175414232626, 0.9364497661361264], 
             UndirectedEdge[319, 331] -> 
             RGBColor[
              0.775790689833521, 0.8249078922958527, 0.9782513878368327], 
             UndirectedEdge[222, 307] -> 
             RGBColor[
              0.456261635454359, 0.5691648443465238, 0.950417290103996], 
             UndirectedEdge[276, 283] -> 
             RGBColor[
              0.4003771577872324, 0.5049037920541919, 0.9484114336869224], 
             UndirectedEdge[464, 497] -> 
             RGBColor[
              0.23993020302659857`, 0.369512234207422, 0.9369750421662133], 
             UndirectedEdge[143, 283] -> 
             RGBColor[
              0.18007058028918088`, 0.3065959753911073, 0.9335661252056935], 
             UndirectedEdge[265, 433] -> 
             RGBColor[
              0.32326037843179023`, 0.45441362508374517`, 0.9418188433591128],
              UndirectedEdge[74, 234] -> 
             RGBColor[
              0.335156328175214, 0.4622198560830736, 0.94266828637108], 
             UndirectedEdge[17, 432] -> 
             RGBColor[
              0.8892978625365586, 0.9145659925119751, 0.9893032180859526], 
             UndirectedEdge[103, 118] -> 
             RGBColor[
              0.4027319052154037, 0.522513730131029, 0.9470855430392838], 
             UndirectedEdge[426, 489] -> 
             RGBColor[
              0.9301359936068372, 0.9447452859638352, 0.9006256116612403], 
             UndirectedEdge[277, 331] -> 
             RGBColor[
              0.8039966134471465, 0.8469425741957761, 0.9810626907032964], 
             UndirectedEdge[74, 112] -> 
             RGBColor[
              0.264998769293781, 0.3958608867931338, 0.938402659929509], 
             UndirectedEdge[80, 372] -> 
             RGBColor[
              0.6299979927875134, 0.7082451076516956, 0.9655564263132472], 
             UndirectedEdge[180, 281] -> 
             RGBColor[
              0.2575198022383923, 0.3880000182240208, 0.9379767438198447], 
             UndirectedEdge[263, 296] -> 
             RGBColor[
              0.2934102361450429, 0.4252910132115676, 0.9400364732085589], 
             UndirectedEdge[37, 141] -> 
             RGBColor[
              0.3076115395353609, 0.4405722348185699, 0.9408322272437397], 
             UndirectedEdge[18, 210] -> 
             RGBColor[
              0.8602238171594843, 0.4230516477625904, 0.20370370360755374`], 
             UndirectedEdge[279, 494] -> 
             RGBColor[
              0.2685318784304253, 0.3995744085078045, 0.9386038652680744], 
             UndirectedEdge[101, 337] -> 
             RGBColor[
              0.6905217138834787, 0.756623588079157, 0.9709749326217818], 
             UndirectedEdge[217, 378] -> 
             RGBColor[
              0.30140209308183147`, 0.4331084891066064, 0.9405129248082346], 
             UndirectedEdge[20, 62] -> 
             RGBColor[
              0.8509265138034974, 0.3513524058869604, 0.19479135055817565`], 
             UndirectedEdge[18, 56] -> 
             RGBColor[
              0.8605287644059905, 0.4253956059279722, 0.2039957214351967], 
             UndirectedEdge[444, 492] -> 
             RGBColor[
              0.2739561801729139, 0.4052756935597544, 0.9389127712277736], 
             UndirectedEdge[199, 427] -> 
             RGBColor[
              0.31117200287913815`, 0.44123930103287445`, 0.9411475887384059],
              UndirectedEdge[190, 463] -> 
             RGBColor[
              0.2576034897635375, 0.3880879791190439, 0.9379815097005972], 
             UndirectedEdge[139, 369] -> 
             RGBColor[
              0.49199130185999246`, 0.5975536392815464, 0.9534008591829983], 
             UndirectedEdge[10, 455] -> 
             RGBColor[
              0.21145152724630215`, 0.3395793403099965, 0.9353532237109508], 
             UndirectedEdge[52, 236] -> 
             RGBColor[
              0.5615591008027638, 0.3477336047164332, 0.5607923410237687], 
             UndirectedEdge[9, 19] -> 
             RGBColor[
              0.5674341026863339, 0.6597075930326068, 0.9590896376245259], 
             UndirectedEdge[33, 309] -> 
             RGBColor[
              0.9357225086078202, 0.7641455885442991, 0.35153908493080155`], 
             UndirectedEdge[341, 491] -> 
             RGBColor[
              0.9938674015539399, 0.9892913169617195, 0.5738826890360067], 
             UndirectedEdge[87, 143] -> 
             RGBColor[
              0.1790901316250143, 0.30556546168103244`, 0.933510290104713], 
             UndirectedEdge[110, 378] -> 
             RGBColor[
              0.2773998635716586, 0.40889522315397336`, 0.9391088839028592], 
             UndirectedEdge[401, 471] -> 
             RGBColor[
              0.8151324803555211, 0.6303190641854999, 0.5900456312313715], 
             UndirectedEdge[160, 165] -> 
             RGBColor[
              0.4232575021072018, 0.5410261076098133, 0.9481905716557255], 
             UndirectedEdge[13, 379] -> 
             RGBColor[
              0.3029577301181068, 0.43570701430378433`, 0.9405662393373586], 
             UndirectedEdge[210, 434] -> 
             RGBColor[
              0.9136331462118448, 0.6344185701788778, 0.48881376628200723`], 
             UndirectedEdge[308, 446] -> 
             RGBColor[
              0.2035487790418117, 0.3312730508839008, 0.9349031738917732], 
             UndirectedEdge[153, 395] -> 
             RGBColor[
              0.2549602684410159, 0.3853097859191623, 0.9378309821565751], 
             UndirectedEdge[24, 83] -> 
             RGBColor[
              0.878858858195596, 0.9062422138097157, 0.9883075365329024], 
             UndirectedEdge[133, 260] -> 
             RGBColor[
              0.31537504749154577`, 0.44544156263782575`, 0.9413948329350919],
              UndirectedEdge[83, 119] -> 
             RGBColor[
              0.9556965383033635, 0.9650210547273206, 0.8984817408494732], 
             UndirectedEdge[400, 464] -> 
             RGBColor[
              0.26989429594474446`, 0.40100639569761354`, 0.9386814529299987],
              UndirectedEdge[175, 320] -> 
             RGBColor[
              0.9721663810423609, 0.9780295691716399, 0.8991854671906325], 
             UndirectedEdge[39, 475] -> 
             RGBColor[
              0.731332489294519, 0.5030791649818271, 0.5742495342753344], 
             UndirectedEdge[289, 291] -> 
             RGBColor[
              0.5471490964494157, 0.6426680909259248, 0.9577289938124869], 
             UndirectedEdge[263, 342] -> 
             RGBColor[
              0.2666938975771815, 0.3976425740963284, 0.9384991949775311], 
             UndirectedEdge[311, 319] -> 
             RGBColor[
              0.7308732764235066, 0.7896830254754603, 0.9738102758609529], 
             UndirectedEdge[141, 304] -> 
             RGBColor[
              0.3240734635805927, 0.45511787857278996`, 0.9418706524258115], 
             UndirectedEdge[30, 43] -> 
             RGBColor[
              0.2805395184040802, 0.4121951994484624, 0.9392876826008625], 
             UndirectedEdge[85, 95] -> 
             RGBColor[
              0.22064923730827996`, 0.3492467167536353, 0.9358770196921877], 
             UndirectedEdge[305, 438] -> 
             RGBColor[
              0.23628821482403703`, 0.36568427369114076`, 0.9367676363259161],
              UndirectedEdge[23, 212] -> 
             RGBColor[
              0.22050887971367938`, 0.3490991920225246, 0.9358690265348157], 
             UndirectedEdge[80, 461] -> 
             RGBColor[
              0.8669992096038857, 0.8968058897416262, 0.9792822184041656], 
             UndirectedEdge[115, 439] -> 
             RGBColor[
              0.8910404321249454, 0.9159554702009634, 0.9894694259289032], 
             UndirectedEdge[136, 377] -> 
             RGBColor[
              0.9750328863705816, 0.980900148051852, 0.9271469902951855], 
             UndirectedEdge[27, 488] -> 
             RGBColor[
              0.640741608541348, 0.7172763695298137, 0.9661908624850168], 
             UndirectedEdge[70, 170] -> 
             RGBColor[
              0.2774653661360603, 0.408964070502262, 0.9391126141769994], 
             UndirectedEdge[268, 441] -> 
             RGBColor[
              0.4298935905497302, 0.5467739538792281, 0.9486134173432208], 
             UndirectedEdge[394, 445] -> 
             RGBColor[
              0.2291408986849781, 0.35817199126297306`, 0.9363606072453035], 
             UndirectedEdge[234, 393] -> 
             RGBColor[
              0.42489506401207827`, 0.5422301548105988, 0.9483541347345662], 
             UndirectedEdge[228, 388] -> 
             RGBColor[
              0.9696267022726579, 0.9734928770909221, 0.7321607638451979], 
             UndirectedEdge[8, 114] -> 
             RGBColor[
              0.5604860564407306, 0.6540668560845098, 0.9585426619725401], 
             UndirectedEdge[21, 164] -> 
             RGBColor[
              0.8992062375406565, 0.5414501296947882, 0.27233399794458657`], 
             UndirectedEdge[100, 454] -> 
             RGBColor[
              0.915548639391991, 0.7016340736991815, 0.25084192040061865`], 
             UndirectedEdge[6, 267] -> 
             RGBColor[
              0.9083762130299251, 0.9201045780958312, 0.6977188544044266], 
             UndirectedEdge[210, 495] -> 
             RGBColor[
              0.8391330927044698, 0.3017996755229297, 0.18510719980929416`], 
             UndirectedEdge[112, 342] -> 
             RGBColor[
              0.25412533445039487`, 0.3844322173571471, 0.9377834339009834], 
             UndirectedEdge[93, 206] -> 
             RGBColor[
              0.30600971855859727`, 0.43582355730741806`, 0.940853232846973], 
             UndirectedEdge[485, 497] -> 
             RGBColor[
              0.24199741678266362`, 0.3716850069339687, 0.9370927669314526], 
             UndirectedEdge[36, 240] -> 
             RGBColor[
              0.25550742159800177`, 0.3858848785786683, 0.9378621417194251], 
             UndirectedEdge[275, 285] -> 
             RGBColor[
              0.36406115169331943`, 0.4897532041763907, 0.9444186325526303], 
             UndirectedEdge[36, 399] -> 
             RGBColor[
              0.24794512185068096`, 0.37793642206673694`, 0.937431479936235], 
             UndirectedEdge[72, 279] -> 
             RGBColor[
              0.26627234056032795`, 0.3971994909433567, 0.9384751879290589], 
             UndirectedEdge[278, 413] -> 
             RGBColor[
              0.9610998830487185, 0.9422076271108857, 0.6625746129461039], 
             UndirectedEdge[10, 120] -> 
             RGBColor[
              0.21319195993880496`, 0.3414086454196232, 0.9354523387780493], 
             UndirectedEdge[59, 153] -> 
             RGBColor[
              0.24356203444566857`, 0.3733295193002764, 0.9371818695927163], 
             UndirectedEdge[377, 488] -> 
             RGBColor[
              0.8752347056162003, 0.9025906545325564, 0.9472574998794909], 
             UndirectedEdge[53, 306] -> 
             RGBColor[
              0.9170459103045016, 0.6880097948516692, 0.28301334457340965`], 
             UndirectedEdge[172, 448] -> 
             RGBColor[
              0.45979588464643895`, 0.5695615806771241, 0.9513786855523698], 
             UndirectedEdge[138, 367] -> 
             RGBColor[
              0.22490572664447084`, 0.3537205569229832, 0.9361194204629721], 
             UndirectedEdge[71, 431] -> 
             RGBColor[
              0.602160734252356, 0.6860330125252593, 0.9630472221226452], 
             UndirectedEdge[180, 392] -> 
             RGBColor[
              0.2880661676144659, 0.4201061849857004, 0.9397163141387143], 
             UndirectedEdge[33, 227] -> 
             RGBColor[
              0.8620227096886874, 0.44626803209664856`, 0.20579398688200412`],
              UndirectedEdge[30, 384] -> 
             RGBColor[
              0.2758760121335012, 0.4072935586747084, 0.9390221028177923], 
             UndirectedEdge[441, 467] -> 
             RGBColor[
              0.5784857852356426, 0.6676055963951182, 0.960658898554645], 
             UndirectedEdge[99, 122] -> 
             RGBColor[
              0.930562919133284, 0.740007623770434, 0.37913808172539787`], 
             UndirectedEdge[89, 225] -> 
             RGBColor[
              0.2798755048828646, 0.4114972791367759, 0.9392498680131491], 
             UndirectedEdge[146, 497] -> 
             RGBColor[
              0.24696343657246012`, 0.3769046085968852, 0.9373755744119134], 
             UndirectedEdge[176, 197] -> 
             RGBColor[
              0.6522851143834272, 0.7277468526483104, 0.9663482548197164], 
             UndirectedEdge[326, 474] -> 
             RGBColor[
              0.9341363327937491, 0.7587482425843726, 0.49080863680582576`], 
             UndirectedEdge[173, 241] -> 
             RGBColor[
              0.8450225482014433, 0.8788658384170731, 0.9383874109586698], 
             UndirectedEdge[403, 405] -> 
             RGBColor[
              0.9614623294969025, 0.9678776355477525, 0.7913886839898783], 
             UndirectedEdge[79, 476] -> 
             RGBColor[
              0.9211605712027758, 0.6814740968415736, 0.3818708025801312], 
             UndirectedEdge[46, 257] -> 
             RGBColor[
              0.8882541401217813, 0.5816020846987996, 0.22826877228895565`], 
             UndirectedEdge[450, 491] -> 
             RGBColor[
              0.9059349577098716, 0.5635204793804358, 0.38523852750809673`], 
             UndirectedEdge[200, 243] -> 
             RGBColor[
              0.8700670583525245, 0.4728472627689348, 0.21211683898241762`], 
             UndirectedEdge[296, 424] -> 
             RGBColor[
              0.31700712622472516`, 0.4489973723195799, 0.9414203916580124], 
             UndirectedEdge[269, 466] -> 
             RGBColor[
              0.47622375697085434`, 0.5855400345383266, 0.9519420749950372], 
             UndirectedEdge[74, 453] -> 
             RGBColor[
              0.2830204227561394, 0.41480278722089764`, 0.9394289664335431], 
             UndirectedEdge[18, 469] -> 
             RGBColor[
              0.8724072991337889, 0.5135131700464854, 0.21524586162499276`], 
             UndirectedEdge[279, 481] -> 
             RGBColor[
              0.2983884604335446, 0.4300799385434647, 0.9403362145723715], 
             UndirectedEdge[19, 468] -> 
             RGBColor[
              0.5190507751439478, 0.6204278280896312, 0.9552807248464208], 
             UndirectedEdge[415, 464] -> 
             RGBColor[
              0.2654397247234546, 0.39632435890790974`, 0.9384277716888938], 
             UndirectedEdge[234, 262] -> 
             RGBColor[
              0.4323322286458682, 0.548267980100758, 0.9489396155777698], 
             UndirectedEdge[241, 417] -> 
             RGBColor[
              0.7032574015004508, 0.7681092940971459, 0.9710577835336467], 
             UndirectedEdge[309, 489] -> 
             RGBColor[
              0.9915641796444485, 0.9888374754562259, 0.6482959890771074], 
             UndirectedEdge[83, 426] -> 
             RGBColor[
              0.895460047558787, 0.9194795515806435, 0.9898909727944203], 
             UndirectedEdge[6, 99] -> 
             RGBColor[
              0.9106556765920616, 0.9271034208247384, 0.765274234275318], 
             UndirectedEdge[121, 491] -> 
             RGBColor[
              0.9108136867178351, 0.6010205284083265, 0.38991040391585896`], 
             UndirectedEdge[42, 358] -> 
             RGBColor[
              0.22905024080537584`, 0.3580767040834695, 0.9363554444131764], 
             UndirectedEdge[69, 461] -> 
             RGBColor[
              0.926959006974305, 0.9443701606295145, 0.985066529908563], 
             UndirectedEdge[161, 387] -> 
             RGBColor[
              0.8827228822801044, 0.901646814849579, 0.6975808353380122], 
             UndirectedEdge[117, 390] -> 
             RGBColor[
              0.34091437037852435`, 0.46896566133560236`, 0.9429707972165], 
             UndirectedEdge[244, 334] -> 
             RGBColor[
              0.3726225537176192, 0.4971686603012616, 0.9449641575190681], 
             UndirectedEdge[173, 493] -> 
             RGBColor[
              0.9890701085039466, 0.9882775676582451, 0.7238989830539463], 
             UndirectedEdge[229, 255] -> 
             RGBColor[
              0.34428066244060973`, 0.47097736208628804`, 0.9432183946864745],
              UndirectedEdge[39, 401] -> 
             RGBColor[
              0.6985569826136641, 0.7641508706261513, 0.9707851169753527], 
             UndirectedEdge[379, 380] -> 
             RGBColor[
              0.29107513038505384`, 0.42321764858400834`, 0.9398895428612922],
              UndirectedEdge[92, 140] -> 
             RGBColor[
              0.554385826473297, 0.649114414584719, 0.9580624295236251], 
             UndirectedEdge[78, 97] -> 
             RGBColor[
              0.22558180327383132`, 0.35443115632617517`, 0.9361579220268484],
              UndirectedEdge[395, 463] -> 
             RGBColor[
              0.2660424669485921, 0.39695787920259357`, 0.9384620969669382], 
             UndirectedEdge[174, 338] -> 
             RGBColor[
              0.29338121786998295`, 0.4246423923281867, 0.9400574530924843], 
             UndirectedEdge[143, 423] -> 
             RGBColor[
              0.1833764464098977, 0.31007065028799885`, 0.9337543893906777], 
             UndirectedEdge[94, 100] -> 
             RGBColor[
              0.943316965793535, 0.8656345224892459, 0.6119300548794735], 
             UndirectedEdge[404, 408] -> 
             RGBColor[
              0.2179764205636531, 0.3464374168886629, 0.9357248067326592], 
             UndirectedEdge[301, 389] -> 
             RGBColor[
              0.21362623144598136`, 0.3418650923080694, 0.9354770698979359], 
             UndirectedEdge[16, 422] -> 
             RGBColor[
              0.3189470428658002, 0.4437679620863825, 0.9417969982435161], 
             UndirectedEdge[389, 451] -> 
             RGBColor[
              0.21497280031897864`, 0.34328042157098726`, 0.9355537550031829],
              UndirectedEdge[74, 296] -> 
             RGBColor[
              0.2975769167094639, 0.42967045866758025`, 0.9402737595026511], 
             UndirectedEdge[225, 453] -> 
             RGBColor[
              0.2792780627176027, 0.4108693295410645, 0.939215844565674], 
             UndirectedEdge[340, 378] -> 
             RGBColor[
              0.31025949401998754`, 0.4407803246133216, 0.9410773105637218], 
             UndirectedEdge[52, 428] -> 
             RGBColor[
              0.8330642703587228, 0.25515204759860854`, 0.17929568867725226`],
              UndirectedEdge[84, 230] -> 
             RGBColor[
              0.22859615804425376`, 0.3575994343110202, 0.9363295850716857], 
             UndirectedEdge[119, 237] -> 
             RGBColor[
              0.9483698835729416, 0.9591789791220269, 0.8977829179807035], 
             UndirectedEdge[67, 171] -> 
             RGBColor[
              0.25918264815811415`, 0.38974777471616917`, 0.9380714404350129],
              UndirectedEdge[25, 157] -> 
             RGBColor[
              0.3079594456965586, 0.4405872728097553, 0.9408648783928987], 
             UndirectedEdge[124, 484] -> 
             RGBColor[
              0.9777721242086441, 0.9364424046411297, 0.38854804229456463`], 
             UndirectedEdge[368, 500] -> 
             RGBColor[
              0.6137971561371982, 0.33936679556971105`, 0.5567621778131115], 
             UndirectedEdge[283, 422] -> 
             RGBColor[
              0.207613081778549, 0.3355448907518888, 0.9351346299200334], 
             UndirectedEdge[334, 369] -> 
             RGBColor[
              0.4113757512055576, 0.5307347321729735, 0.9474334769948924], 
             UndirectedEdge[42, 346] -> 
             RGBColor[
              0.22517846281523107`, 0.3540072199309242, 0.9361349523844199], 
             UndirectedEdge[112, 263] -> 
             RGBColor[
              0.2608320887293601, 0.39148144133712115`, 0.9381653736354167], 
             UndirectedEdge[146, 201] -> 
             RGBColor[
              0.28119600247616383`, 0.41288520583171645`, 0.9393250683975864],
              UndirectedEdge[16, 243] -> 
             RGBColor[
              0.6215940953786275, 0.41368682466407874`, 0.566114433864064], 
             UndirectedEdge[285, 481] -> 
             RGBColor[
              0.3163175193458222, 0.44840006950172373`, 0.9413764505174842], 
             UndirectedEdge[231, 444] -> 
             RGBColor[
              0.2648697036740537, 0.39572523064356746`, 0.938395309833401], 
             UndirectedEdge[137, 408] -> 
             RGBColor[
              0.2212925375899113, 0.34992286613722345`, 0.9359136546915492], 
             UndirectedEdge[431, 436] -> 
             RGBColor[
              0.46072987194196846`, 0.5729505557434673, 0.9507253360979548], 
             UndirectedEdge[98, 277] -> 
             RGBColor[
              0.8832681348130269, 0.9067408984138945, 0.8502742951726139], 
             UndirectedEdge[131, 391] -> 
             RGBColor[
              0.2523681386345833, 0.3825852931420795, 0.9376833641988113], 
             UndirectedEdge[52, 227] -> 
             RGBColor[
              0.8407131059122084, 0.31394434940381033`, 0.18662022224139424`],
              UndirectedEdge[27, 419] -> 
             RGBColor[
              0.5124047260338506, 0.6150322660209537, 0.9547575235151939], 
             UndirectedEdge[232, 312] -> 
             RGBColor[
              0.3303045820158528, 0.4601142095117522, 0.9422823672274991], 
             UndirectedEdge[247, 466] -> 
             RGBColor[
              0.4992597773340883, 0.6043606044932961, 0.953722705002015], 
             UndirectedEdge[253, 484] -> 
             RGBColor[
              0.9889617727140382, 0.9876413426482502, 0.6827040059696212], 
             UndirectedEdge[121, 200] -> 
             RGBColor[
              0.8641469744095227, 0.4273429033856967, 0.2064477599128205], 
             UndirectedEdge[79, 99] -> 
             RGBColor[
              0.9937251243023482, 0.9889870003070016, 0.5583966882336657], 
             UndirectedEdge[109, 300] -> 
             RGBColor[
              0.23995882574419874`, 0.3695423184984049, 0.9369766721876371], 
             UndirectedEdge[31, 397] -> 
             RGBColor[
              0.40579315804314603`, 0.5258993705649835, 0.947077759095077], 
             UndirectedEdge[70, 374] -> 
             RGBColor[
              0.2549902427614091, 0.38534129083037727`, 0.9378326891497786], 
             UndirectedEdge[240, 352] -> 
             RGBColor[
              0.24222822396059346`, 0.3719275999119933, 0.937105911058787], 
             UndirectedEdge[105, 323] -> 
             RGBColor[
              0.24262496833818112`, 0.37234460340788433`, 0.93712850506416], 
             UndirectedEdge[46, 53] -> 
             RGBColor[
              0.9470835767696775, 0.821834287485996, 0.3079282681448157], 
             UndirectedEdge[221, 223] -> 
             RGBColor[
              0.46323693275442124`, 0.5733927057392445, 0.9513629056103252], 
             UndirectedEdge[33, 159] -> 
             RGBColor[
              0.8495822086293704, 0.3506448894924134, 0.19388094901806585`], 
             UndirectedEdge[16, 454] -> 
             RGBColor[
              0.6518822537994468, 0.581257698540845, 0.5925638840512331], 
             UndirectedEdge[195, 224] -> 
             RGBColor[
              0.28455910865490164`, 0.41642004365881735`, 0.9395165923191959],
              UndirectedEdge[259, 500] -> 
             RGBColor[
              0.8406666807462297, 0.3081837142621151, 0.18636416654762122`], 
             UndirectedEdge[24, 77] -> 
             RGBColor[
              0.7218949448567346, 0.7822619477143448, 0.9732512022240677], 
             UndirectedEdge[226, 386] -> 
             RGBColor[
              0.1791759961486071, 0.30565571073945375`, 0.9335151799623065], 
             UndirectedEdge[289, 314] -> 
             RGBColor[
              0.3847232625603534, 0.5076496861015274, 0.9457352039862904], 
             UndirectedEdge[179, 325] -> 
             RGBColor[
              0.1789730287155782, 0.30544237909846184`, 0.9335036212672588], 
             UndirectedEdge[81, 83] -> 
             RGBColor[
              0.8721819244967113, 0.9009182081187621, 0.9876706846361336], 
             UndirectedEdge[312, 376] -> 
             RGBColor[
              0.2919333190231436, 0.4241708063077816, 0.9399365426905006], 
             UndirectedEdge[270, 309] -> 
             RGBColor[
              0.9915269265441726, 0.9888220703419007, 0.6489133693566129], 
             UndirectedEdge[139, 269] -> 
             RGBColor[
              0.506487260336648, 0.6101093099259678, 0.9543245288388581], 
             UndirectedEdge[269, 425] -> 
             RGBColor[
              0.4121410951718726, 0.5313976346492894, 0.947482244035659], 
             UndirectedEdge[25, 492] -> 
             RGBColor[
              0.29499729755319337`, 0.42696323326341856`, 0.9401267032319138],
              UndirectedEdge[142, 173] -> 
             RGBColor[
              0.8420436305365226, 0.8765386852966244, 0.9380905002853989], 
             UndirectedEdge[132, 209] -> 
             RGBColor[
              0.7780282420345992, 0.8243344980363514, 0.8860787195432924], 
             UndirectedEdge[389, 409] -> 
             RGBColor[
              0.23002772223876133`, 0.35910409904586005`, 0.9364111105347535],
              UndirectedEdge[337, 370] -> 
             RGBColor[
              0.7258270188663856, 0.785286025150145, 0.9737542955576297], 
             UndirectedEdge[230, 242] -> 
             RGBColor[
              0.2244428247428983, 0.35323401767475476`, 0.9360930588844796], 
             UndirectedEdge[28, 461] -> 
             RGBColor[
              0.954655789916814, 0.9657029428810652, 0.9616400993934879], 
             UndirectedEdge[318, 350] -> 
             RGBColor[
              0.3520561578815369, 0.47935508192515797`, 0.9436536849625428], 
             UndirectedEdge[390, 478] -> 
             RGBColor[
              0.2833977050944594, 0.41519933487955374`, 0.9394504521045712], 
             UndirectedEdge[167, 434] -> 
             RGBColor[
              0.988936416573675, 0.989692938179159, 0.8330157392176978], 
             UndirectedEdge[247, 269] -> 
             RGBColor[
              0.47197536116157857`, 0.5820909954323062, 0.9516076257145445], 
             UndirectedEdge[394, 398] -> 
             RGBColor[
              0.24489676758341208`, 0.3747324084550136, 0.93725788067035], 
             UndirectedEdge[14, 158] -> 
             RGBColor[
              0.33213200521333075`, 0.4619125616859979, 0.9423909174068014], 
             UndirectedEdge[131, 433] -> 
             RGBColor[
              0.29455765065289613`, 0.4253795454830047, 0.9401427329325757], 
             UndirectedEdge[87, 422] -> 
             RGBColor[
              0.2066326331143824, 0.33451437704181397`, 0.9350787948190529], 
             UndirectedEdge[210, 469] -> 
             RGBColor[
              0.8482471960053599, 0.3686686083126496, 0.19371011734270402`], 
             UndirectedEdge[312, 414] -> 
             RGBColor[
              0.2895347527456831, 0.421649761072285, 0.9397999478893602], 
             UndirectedEdge[277, 311] -> 
             RGBColor[
              0.7590792000371321, 0.8117177073753836, 0.9766215787274166], 
             UndirectedEdge[332, 424] -> 
             RGBColor[
              0.36139324266635137`, 0.48744239547023754`, 0.9442486357485711],
              UndirectedEdge[328, 433] -> 
             RGBColor[
              0.35540962848104596`, 0.48225968960811955`, 0.9438673651437858],
              UndirectedEdge[88, 428] -> 
             RGBColor[
              0.8484718113152332, 0.36067584148776255`, 0.1935446274280821], 
             UndirectedEdge[8, 162] -> 
             RGBColor[
              0.5411625228784538, 0.6383791410233868, 0.9570214426260819], 
             UndirectedEdge[27, 289] -> 
             RGBColor[
              0.47574498443284424`, 0.5848915439571711, 0.9519761681862727], 
             UndirectedEdge[192, 280] -> 
             RGBColor[
              0.25575350846358835`, 0.3861435314772083, 0.9378761560023672], 
             UndirectedEdge[347, 477] -> 
             RGBColor[
              0.2117993137193227, 0.3399448859440771, 0.9353730296360853], 
             UndirectedEdge[145, 346] -> 
             RGBColor[
              0.21927041175810352`, 0.3477974836778107, 0.9357984976168947], 
             UndirectedEdge[232, 415] -> 
             RGBColor[
              0.3216051563189196, 0.45097056152882875`, 0.9417869478037058], 
             UndirectedEdge[189, 374] -> 
             RGBColor[
              0.2557528431125027, 0.3861428321510315, 0.9378761181116072], 
             UndirectedEdge[139, 140] -> 
             RGBColor[
              0.5318346221124927, 0.6308063309644387, 0.9562871161085591], 
             UndirectedEdge[134, 251] -> 
             RGBColor[
              0.24587579480159133`, 0.37576142813523083`, 0.9373136348220843],
              UndirectedEdge[67, 281] -> 
             RGBColor[
              0.25076586641156884`, 0.38090120344576484`, 0.93759211716606], 
             UndirectedEdge[167, 495] -> 
             RGBColor[0.9144363630663, 0.657074043523211, 0.5293091727449846],
              UndirectedEdge[143, 179] -> 
             RGBColor[
              0.17892806920489446`, 0.30539512380213557`, 0.933501060889637], 
             UndirectedEdge[21, 175] -> 
             RGBColor[
              0.9683090151158134, 0.9568481859192783, 0.670037151361724], 
             UndirectedEdge[366, 473] -> 
             RGBColor[
              0.29591877827497415`, 0.42668767083692927`, 0.940224732684648], 
             UndirectedEdge[143, 292] -> 
             RGBColor[
              0.1789488167630598, 0.30541693080123855`, 0.9335022424323813], 
             UndirectedEdge[267, 486] -> 
             RGBColor[
              0.9619951023866931, 0.9628588250229391, 0.7028330719374227], 
             UndirectedEdge[248, 380] -> 
             RGBColor[
              0.257695358998007, 0.3881845395093172, 0.937986741517592], 
             UndirectedEdge[48, 407] -> 
             RGBColor[
              0.2109346093646478, 0.33903602684189116`, 0.935323786002302], 
             UndirectedEdge[436, 459] -> 
             RGBColor[
              0.4317329658175249, 0.5478348930853527, 0.9488776788806625], 
             UndirectedEdge[235, 262] -> 
             RGBColor[
              0.416563768888231, 0.5346101328045243, 0.9479348632655147], 
             UndirectedEdge[236, 283] -> 
             RGBColor[
              0.23426865806856206`, 0.3635615914938426, 0.9366526255563583], 
             UndirectedEdge[99, 493] -> 
             RGBColor[
              0.9935993972524345, 0.9887180828601909, 0.5447120747479771], 
             UndirectedEdge[109, 456] -> 
             RGBColor[
              0.23880926652767986`, 0.3683340588755796, 0.9369112064908769], 
             UndirectedEdge[208, 289] -> 
             RGBColor[
              0.3807447886449092, 0.5042037319598828, 0.9454816991464247], 
             UndirectedEdge[266, 410] -> 
             RGBColor[
              0.326592877843097, 0.45552256223454524`, 0.9420962704893343], 
             UndirectedEdge[299, 301] -> 
             RGBColor[
              0.20895952840977988`, 0.3369600915309596, 0.9352113080637927], 
             UndirectedEdge[314, 359] -> 
             RGBColor[
              0.3577633677707141, 0.48429838027845357`, 0.9440173433299934], 
             UndirectedEdge[209, 214] -> 
             RGBColor[
              0.3828653435329973, 0.49291080046599856`, 0.946830407391962], 
             UndirectedEdge[210, 326] -> 
             RGBColor[
              0.8556196126725499, 0.40214503052670025`, 0.19986184252427644`],
              UndirectedEdge[53, 317] -> 
             RGBColor[
              0.9299563150856899, 0.7479312815030192, 0.29383694306613123`], 
             UndirectedEdge[402, 459] -> 
             RGBColor[
              0.4714286755649022, 0.5800616585296188, 0.952002670562152], 
             UndirectedEdge[89, 249] -> 
             RGBColor[
              0.28752479280706156`, 0.41953716573797317`, 0.9396854836443249],
              UndirectedEdge[67, 135] -> 
             RGBColor[
              0.2536249197696536, 0.3839062497995648, 0.9377549360252124], 
             UndirectedEdge[90, 178] -> 
             RGBColor[
              0.9282272067510295, 0.7348311823756897, 0.4981717768803556], 
             UndirectedEdge[174, 229] -> 
             RGBColor[
              0.2788164534778155, 0.4103841489623319, 0.9391895566023578], 
             UndirectedEdge[266, 364] -> 
             RGBColor[
              0.2740437091478759, 0.405367692062097, 0.9389177558734103], 
             UndirectedEdge[407, 430] -> 
             RGBColor[
              0.22704868393744712`, 0.35597294090924125`, 0.9362414587105858],
              UndirectedEdge[217, 355] -> 
             RGBColor[
              0.32421328138501737`, 0.4552389817275355, 0.9418795614926734], 
             UndirectedEdge[176, 426] -> 
             RGBColor[
              0.7385594994235554, 0.7955507282121491, 0.9748396268265297], 
             UndirectedEdge[280, 483] -> 
             RGBColor[
              0.2767707745378052, 0.40823401069284493`, 0.939073058213035], 
             UndirectedEdge[51, 347] -> 
             RGBColor[
              0.1789270004053139, 0.3053940004260106, 0.9335010000230821], 
             UndirectedEdge[152, 451] -> 
             RGBColor[
              0.20772437674817806`, 0.3356618688214776, 0.9351409680039076], 
             UndirectedEdge[105, 342] -> 
             RGBColor[
              0.252946206923672, 0.38319287956555814`, 0.9377162843326995], 
             UndirectedEdge[318, 496] -> 
             RGBColor[
              0.3094159330482752, 0.43947691523709653`, 0.9410445311268166], 
             UndirectedEdge[114, 289] -> 
             RGBColor[
              0.47002476811242727`, 0.580247614655448, 0.9515258518036867], 
             UndirectedEdge[103, 331] -> 
             RGBColor[
              0.6585237003454188, 0.7308163449939742, 0.968260051050067], 
             UndirectedEdge[107, 113] -> 
             RGBColor[
              0.18193197659231264`, 0.3085524209250408, 0.9336721289714678], 
             UndirectedEdge[16, 56] -> 
             RGBColor[
              0.6202778449645745, 0.4035695471970573, 0.5648539909810746], 
             UndirectedEdge[140, 370] -> 
             RGBColor[
              0.5455387009707735, 0.6419319195433083, 0.9573659513959778], 
             UndirectedEdge[213, 500] -> 
             RGBColor[
              0.8618492799802115, 0.40436895006188167`, 0.20403944658147605`],
              UndirectedEdge[280, 327] -> 
             RGBColor[
              0.25698076875714937`, 0.3874334598585377, 0.9379460466605166], 
             UndirectedEdge[76, 238] -> 
             RGBColor[
              0.36573961104663694`, 0.49120700130641426`, 0.9445255824984202],
              UndirectedEdge[253, 261] -> 
             RGBColor[
              0.9325093316648222, 0.7680041432668934, 0.5596474808987255], 
             UndirectedEdge[232, 350] -> 
             RGBColor[
              0.3591838096222978, 0.48552869561681206`, 0.944107852628729], 
             UndirectedEdge[166, 320] -> 
             RGBColor[
              0.9133614547699682, 0.6417853106074096, 0.5113435478107814], 
             UndirectedEdge[33, 119] -> 
             RGBColor[
              0.9345308133147854, 0.7655949021985857, 0.5124594755699873], 
             UndirectedEdge[71, 228] -> 
             RGBColor[
              0.8744314209010298, 0.8983757407693698, 0.7323068273714743], 
             UndirectedEdge[50, 244] -> 
             RGBColor[
              0.3916895278498226, 0.5136835149605915, 0.9461790882505088], 
             UndirectedEdge[235, 344] -> 
             RGBColor[
              0.4103923521286693, 0.5295998986599555, 0.9474490267315575], 
             UndirectedEdge[72, 494] -> 
             RGBColor[
              0.25624399533436604`, 0.3866590642770594, 0.9379040885040477], 
             UndirectedEdge[185, 496] -> 
             RGBColor[
              0.2804171463023576, 0.4120665786107125, 0.9392807136907027], 
             UndirectedEdge[106, 370] -> 
             RGBColor[
              0.5546493379031965, 0.6493283450345659, 0.9580831741086608], 
             UndirectedEdge[51, 113] -> 
             RGBColor[
              0.17905963075308248`, 0.3055334033307651, 0.9335085531251784], 
             UndirectedEdge[422, 443] -> 
             RGBColor[
              0.5842619922483114, 0.5706803433206208, 0.6014015077150748], 
             UndirectedEdge[4, 335] -> 
             RGBColor[
              0.3005379095306292, 0.4317763657356928, 0.9404792286546308], 
             UndirectedEdge[1, 84] -> 
             RGBColor[
              0.249739891419232, 0.3798228386782472, 0.9375336894080404], 
             UndirectedEdge[90, 272] -> 
             RGBColor[
              0.8426763546129947, 0.3190239891395971, 0.18810823554711417`], 
             UndirectedEdge[213, 450] -> 
             RGBColor[
              0.8609571905590665, 0.3975119598548832, 0.20318518074431657`], 
             UndirectedEdge[5, 212] -> 
             RGBColor[
              0.22856179646777947`, 0.35756331811549596`, 0.9363276282307389],
              UndirectedEdge[50, 106] -> 
             RGBColor[
              0.47939668252268425`, 0.5878987040064534, 0.9522518873645769], 
             UndirectedEdge[115, 291] -> 
             RGBColor[
              0.7880477603543681, 0.8351660025398585, 0.9792918656511329], 
             UndirectedEdge[9, 117] -> 
             RGBColor[
              0.4781094761010015, 0.5852282777412916, 0.9525996605197433], 
             UndirectedEdge[194, 388] -> 
             RGBColor[
              0.9663440953419832, 0.9740339462184904, 0.9245637966956991], 
             UndirectedEdge[202, 211] -> 
             RGBColor[
              0.2350487330765592, 0.3643814997868598, 0.9366970496740461], 
             UndirectedEdge[113, 308] -> 
             RGBColor[
              0.17906927273157397`, 0.3055435376614964, 0.9335091022215896], 
             UndirectedEdge[51, 421] -> 
             RGBColor[
              0.17899180329589925`, 0.30546211237275633`, 0.9335046904518336],
              UndirectedEdge[109, 335] -> 
             RGBColor[
              0.2653660882581673, 0.3962469623140712, 0.938423578201131], 
             UndirectedEdge[278, 329] -> 
             RGBColor[
              0.9154608124727537, 0.9351010298249371, 0.9804756251775316], 
             UndirectedEdge[129, 206] -> 
             RGBColor[
              0.3491669657996257, 0.47685260895882275`, 0.9434695881978956], 
             UndirectedEdge[166, 227] -> 
             RGBColor[
              0.8418757895124331, 0.32288124504634075`, 0.18773360937003286`],
              UndirectedEdge[294, 411] -> 
             RGBColor[
              0.23895135352540886`, 0.3684834013190287, 0.9369192981351986], 
             UndirectedEdge[362, 384] -> 
             RGBColor[
              0.33614117025697976`, 0.4632658145057482, 0.9427239752429382], 
             UndirectedEdge[143, 308] -> 
             RGBColor[
              0.17893664305769685`, 0.3054041354650445, 0.9335015491578702], 
             UndirectedEdge[151, 310] -> 
             RGBColor[
              0.3017756973424442, 0.43451576996419494`, 0.9404970515752908], 
             UndirectedEdge[297, 397] -> 
             RGBColor[
              0.4389561312944613, 0.5528301617459719, 0.9496863711644075], 
             UndirectedEdge[114, 359] -> 
             RGBColor[
              0.443064873322788, 0.5568963088323743, 0.9498079911473898], 
             UndirectedEdge[141, 220] -> 
             RGBColor[
              0.32424804297229537`, 0.4552690904672675, 0.9418817764702763], 
             UndirectedEdge[122, 493] -> 
             RGBColor[
              0.9305407827762575, 0.7399602763410837, 0.37672867587283654`], 
             UndirectedEdge[146, 442] -> 
             RGBColor[
              0.2709392779878975, 0.40210473808065567`, 0.9387409631114438], 
             UndirectedEdge[294, 478] -> 
             RGBColor[
              0.25217734273393444`, 0.38238475455333876`, 0.9376724986545265],
              UndirectedEdge[76, 487] -> 
             RGBColor[
              0.49537833953651855`, 0.6000692782186605, 0.9537321847167134], 
             UndirectedEdge[67, 70] -> 
             RGBColor[
              0.25743661729140077`, 0.3879125855705024, 0.9379720065601748], 
             UndirectedEdge[346, 358] -> 
             RGBColor[
              0.2217544347167852, 0.3504083493035373, 0.935939959049609], 
             UndirectedEdge[149, 165] -> 
             RGBColor[
              0.3889540140770109, 0.511314150421502, 0.9460047837318252], 
             UndirectedEdge[175, 375] -> 
             RGBColor[
              0.9569658514087618, 0.9674257829593813, 0.9577297678481509], 
             UndirectedEdge[18, 428] -> 
             RGBColor[
              0.8573587081531882, 0.40102916444142644`, 0.2009600719874468], 
             UndirectedEdge[2, 47] -> 
             RGBColor[
              0.22219066917343752`, 0.3508668593763409, 0.9359648019565643], 
             UndirectedEdge[140, 466] -> 
             RGBColor[
              0.5015711187466989, 0.6062370555767975, 0.9539046622647382], 
             UndirectedEdge[199, 382] -> 
             RGBColor[
              0.31253428709090747`, 0.4426711481132517, 0.9412251688089472], 
             UndirectedEdge[305, 499] -> 
             RGBColor[
              0.2559152551896322, 0.3863135375416151, 0.9378853672391325], 
             UndirectedEdge[252, 282] -> 
             RGBColor[
              0.6717272001021579, 0.7429460920325152, 0.9682785844173988], 
             UndirectedEdge[235, 249] -> 
             RGBColor[
              0.32329479630323715`, 0.4526684377082041, 0.9418860278221313], 
             UndirectedEdge[130, 214] -> 
             RGBColor[
              0.1893670574265447, 0.316367162293171, 0.9340955458257609], 
             UndirectedEdge[100, 475] -> 
             RGBColor[
              0.8851091218155209, 0.5328997870260774, 0.22424752851506258`], 
             UndirectedEdge[10, 438] -> 
             RGBColor[
              0.22021348611856342`, 0.3487887146250221, 0.9358522043065695], 
             UndirectedEdge[39, 179] -> 
             RGBColor[
              0.40129536230508595`, 0.5053759222252174, 0.9485085964517164], 
             UndirectedEdge[400, 414] -> 
             RGBColor[
              0.28528989827003975`, 0.41718814987906533`, 0.9395582097066717],
              UndirectedEdge[41, 191] -> 
             RGBColor[
              0.22546402831064583`, 0.35430736737250323`, 0.9361512149169275],
              UndirectedEdge[25, 96] -> 
             RGBColor[
              0.3047685081778331, 0.4372333951604509, 0.9406831592217764], 
             UndirectedEdge[106, 274] -> 
             RGBColor[
              0.49029479958875166`, 0.5970824316919869, 0.9530169491141065], 
             UndirectedEdge[204, 363] -> 
             RGBColor[
              0.4533522044192463, 0.5657736996191047, 0.9504726028052438], 
             UndirectedEdge[99, 413] -> 
             RGBColor[
              0.9837287794830555, 0.9560851708017216, 0.4499899045367475], 
             UndirectedEdge[37, 118] -> 
             RGBColor[
              0.31537415178862416`, 0.44729581939211016`, 0.9413268540323092],
              UndirectedEdge[411, 478] -> 
             RGBColor[
              0.2528159536736963, 0.3830559751413007, 0.9377088666028057], 
             UndirectedEdge[300, 451] -> 
             RGBColor[
              0.21870173252116284`, 0.3471997657434399, 0.9357661121756364], 
             UndirectedEdge[122, 233] -> 
             RGBColor[
              0.8553320507775657, 0.4120002528594733, 0.20005892957140564`], 
             UndirectedEdge[97, 404] -> 
             RGBColor[
              0.2225914076005732, 0.3512880608715443, 0.9359876234171504], 
             UndirectedEdge[362, 498] -> 
             RGBColor[
              0.4251755260464191, 0.5424546669097134, 0.9483770922703834], 
             UndirectedEdge[121, 454] -> 
             RGBColor[
              0.8636741838299911, 0.42519607178708907`, 0.20605325186410173`],
              UndirectedEdge[173, 417] -> 
             RGBColor[
              0.8427978094114925, 0.8771278555657226, 0.9381656697874536], 
             UndirectedEdge[36, 352] -> 
             RGBColor[
              0.2411100918235177, 0.37075237214225454`, 0.9370422350877088], 
             UndirectedEdge[309, 337] -> 
             RGBColor[
              0.926620732552479, 0.9394372573300418, 0.7346744089406012], 
             UndirectedEdge[207, 456] -> 
             RGBColor[
              0.2203607616298221, 0.3489435105251617, 0.9358605914290611], 
             UndirectedEdge[95, 97] -> 
             RGBColor[
              0.22940871371662525`, 0.3584534818416879, 0.936375858915159], 
             UndirectedEdge[185, 350] -> 
             RGBColor[
              0.3230573711356193, 0.45194474529877393`, 0.9418898675264287], 
             UndirectedEdge[303, 435] -> 
             RGBColor[
              0.2816881021628791, 0.4134024338033765, 0.9393530927467486], 
             UndirectedEdge[14, 441] -> 
             RGBColor[
              0.3784375409652084, 0.5020200893703757, 0.9453414651985335], 
             UndirectedEdge[67, 147] -> 
             RGBColor[
              0.2540581203038455, 0.3843615710275007, 0.9377796061547718], 
             UndirectedEdge[115, 419] -> 
             RGBColor[
              0.7169294577871506, 0.7776214885576594, 0.9735615399917263], 
             UndirectedEdge[113, 209] -> 
             RGBColor[
              0.3725579164542212, 0.4820770410775821, 0.9462434146682975], 
             UndirectedEdge[100, 121] -> 
             RGBColor[
              0.8793403970281699, 0.48855884043917713`, 0.2187233911438525], 
             UndirectedEdge[39, 254] -> 
             RGBColor[
              0.43007991849913185`, 0.5356303158314321, 0.9501478343440324], 
             UndirectedEdge[2, 339] -> 
             RGBColor[
              0.21206918576719214`, 0.340228538577264, 0.9353883984499716], 
             UndirectedEdge[76, 436] -> 
             RGBColor[
              0.4421225577048329, 0.5568338353820671, 0.9495396944885663], 
             UndirectedEdge[121, 161] -> 
             RGBColor[
              0.9088989497892817, 0.5955852022276555, 0.2954383174204215], 
             UndirectedEdge[215, 430] -> 
             RGBColor[
              0.26193106415637823`, 0.3926365341899838, 0.9382279586601969], 
             UndirectedEdge[100, 254] -> 
             RGBColor[
              0.5838565510201338, 0.5654509378756822, 0.6001458285837606], 
             UndirectedEdge[186, 389] -> 
             RGBColor[
              0.22710509641847854`, 0.3560322340035631, 0.9362446713179258], 
             UndirectedEdge[197, 426] -> 
             RGBColor[
              0.7839000078483491, 0.8315135813435113, 0.9789878324723824], 
             UndirectedEdge[316, 378] -> 
             RGBColor[
              0.26678973270236006`, 0.397743302889189, 0.9385046526461347], 
             UndirectedEdge[185, 330] -> 
             RGBColor[
              0.29519715135054264`, 0.42760130102279975`, 0.9401224131131387],
              UndirectedEdge[56, 166] -> 
             RGBColor[
              0.8373970102117498, 0.28845538472768467`, 0.18344472525364075`],
              UndirectedEdge[38, 73] -> 
             RGBColor[
              0.25393957190424143`, 0.3842369691431141, 0.937772854998791], 
             UndirectedEdge[97, 430] -> 
             RGBColor[
              0.23573676666398502`, 0.3651046667110934, 0.9367362321689956], 
             UndirectedEdge[222, 372] -> 
             RGBColor[
              0.4565833875774816, 0.5694260572148426, 0.9504426196097452], 
             UndirectedEdge[137, 430] -> 
             RGBColor[
              0.22990978373834364`, 0.3589801382041882, 0.9364043941116291], 
             UndirectedEdge[30, 355] -> 
             RGBColor[
              0.29831901354920054`, 0.4290370635324922, 0.9403677718036725], 
             UndirectedEdge[111, 442] -> 
             RGBColor[
              0.2785182841132166, 0.41007075405510884`, 0.939172576298146], 
             UndirectedEdge[183, 408] -> 
             RGBColor[
              0.21373593745192992`, 0.3419804002760839, 0.9354833174926791], 
             UndirectedEdge[39, 283] -> 
             RGBColor[
              0.4024378733893724, 0.5065767738141891, 0.9485736607677728], 
             UndirectedEdge[244, 498] -> 
             RGBColor[
              0.40216527018839365`, 0.5225243398145787, 0.9469108991142803], 
             UndirectedEdge[259, 454] -> 
             RGBColor[
              0.8808615626968692, 0.5519020063430116, 0.22230030637499004`], 
             UndirectedEdge[17, 418] -> 
             RGBColor[
              0.9292223734187801, 0.9452976774305406, 0.9548682913375369], 
             UndirectedEdge[70, 391] -> 
             RGBColor[
              0.24968869542225258`, 0.3797690284394081, 0.93753077387175], 
             UndirectedEdge[18, 495] -> 
             RGBColor[
              0.8632931958328989, 0.4466442372567656, 0.2066429440915829], 
             UndirectedEdge[48, 95] -> 
             RGBColor[
              0.21729689825533816`, 0.34572319585842115`, 0.9356861089424638],
              UndirectedEdge[50, 92] -> 
             RGBColor[
              0.5250378077135244, 0.6249522255456361, 0.9558449239285502], 
             UndirectedEdge[118, 141] -> 
             RGBColor[
              0.31734549257895406`, 0.4492904482488255, 0.9414419520628983], 
             UndirectedEdge[373, 398] -> 
             RGBColor[
              0.27738327375901567`, 0.40887778620903076`, 0.9391079391375716],
              UndirectedEdge[218, 409] -> 
             RGBColor[
              0.2367642996218614, 0.3661846689991738, 0.9367947486508479]}, 
           GraphLayout -> {"Dimension" -> 2}, ImageSize -> 500, 
           VertexSize -> {1}, VertexStyle -> {
             EdgeForm[None], 145 -> 
             RGBColor[
              0.2206581667895666, 0.3492561022046294, 0.935877528212937], 316 -> 
             RGBColor[
              0.2504950392509415, 0.38061654692851177`, 0.937576693959915], 
             308 -> RGBColor[
              0.17894628476761076`, 0.30541426951348377`, 0.9335020982389862],
              160 -> RGBColor[
              0.42248174875901884`, 0.5403541890501141, 0.948141141338351], 
             245 -> RGBColor[
              0.22156287013367681`, 0.3502070027807943, 0.9359290497299955], 
             155 -> 
             RGBColor[
              0.5658891207695752, 0.6584533071119401, 0.9589680109885835], 
             425 -> RGBColor[
              0.37534284954540054`, 0.499524843821242, 0.9451374923637511], 
             213 -> RGBColor[
              0.90420589766789, 0.657903179238463, 0.24177939169682186`], 352 -> 
             RGBColor[
              0.2278308941861094, 0.35679509347557953`, 0.9362860044270709], 
             27 -> RGBColor[
              0.5121189165844965, 0.6148002330343991, 0.9547350235483862], 
             485 -> RGBColor[
              0.24800119075484597`, 0.3779953540399882, 0.9374346729773807], 
             454 -> RGBColor[
              0.8998824261938122, 0.6382713050470934, 0.23817178112086787`], 
             367 -> RGBColor[
              0.2298450608433424, 0.3589121103378734, 0.9364007082385077], 19 -> 
             RGBColor[
              0.5597245266210166, 0.6534486118703385, 0.9584827115555565], 
             164 -> RGBColor[
              0.8175247092939038, 0.13570817177533162`, 0.16441498745215766`],
              190 -> RGBColor[
              0.24810961844878143`, 0.3781093184210272, 0.9374408477741458], 
             103 -> RGBColor[
              0.4803557055985901, 0.589013427439692, 0.9522345072271], 138 -> 
             RGBColor[
              0.2199663924455993, 0.34852900350809307`, 0.9358381326874365], 
             416 -> RGBColor[
              0.26153368469451344`, 0.39221886318025073`, 0.938205328487714], 
             476 -> RGBColor[
              0.8484924274103163, 0.3737396233586853, 0.19406970929346942`], 
             291 -> RGBColor[
              0.6549271406176395, 0.7303533269719065, 0.9662406748008145], 28 -> 
             RGBColor[
              0.9648560740830788, 0.9733102981108331, 0.9443736789601879], 
             337 -> RGBColor[
              0.860210700141258, 0.8913726787679522, 0.9865288585702724], 195 -> 
             RGBColor[
              0.2701519252165497, 0.40127718039692006`, 0.9386961245358997], 
             114 -> RGBColor[
              0.5006784839436625, 0.605512374430953, 0.9538343907832142], 479 -> 
             RGBColor[
              0.41149067372934756`, 0.5308342722869064, 0.9474407997564864], 
             93 -> RGBColor[
              0.26928527939714464`, 0.4003662806922068, 0.9386467703385721], 
             34 -> RGBColor[
              0.5437530683305409, 0.6404822625241338, 0.9572253798535508], 
             161 -> RGBColor[
              0.9903319581123935, 0.9790495659282263, 0.41694191223350735`], 
             22 -> 
             RGBColor[
              0.4514165271362265, 0.5654160397762044, 0.9499848398305268], 
             124 -> RGBColor[
              0.9626525497894284, 0.8856804222207267, 0.30941263771645156`], 
             84 -> RGBColor[
              0.2333142933423989, 0.36255849365642656`, 0.9365982758970595], 
             46 -> RGBColor[
              0.9176548470302313, 0.7112359389100995, 0.2526013609126037], 
             241 -> RGBColor[
              0.7054821402904016, 0.7698472769484965, 0.9712795247048629], 
             185 -> RGBColor[
              0.2839447494602888, 0.41577431319265656`, 0.9394816054719256], 
             426 -> RGBColor[
              0.8701743928884773, 0.8993174569073501, 0.9874792044791957], 
             390 -> RGBColor[
              0.30075346730669683`, 0.43344134138349677`, 0.9404388370870089],
              121 -> RGBColor[
              0.8274659414661699, 0.21212083852708477`, 0.1739347226073356], 
             322 -> RGBColor[
              0.25921854913182885`, 0.38978550891579644`, 0.9380734849423552],
              488 -> RGBColor[
              0.7693643004981994, 0.8197525060252281, 0.9776467014216474], 
             126 -> RGBColor[
              0.2511378152607278, 0.38129214526915, 0.9376132991027705], 433 -> 
             RGBColor[
              0.32550625142704326`, 0.4563588873913744, 0.9419619484004228], 
             236 -> RGBColor[
              0.28732315690654525`, 0.419325233622076, 0.939674000778084], 78 -> 
             RGBColor[
              0.21942909899518986`, 0.3479642740253404, 0.9358075346202901], 
             376 -> RGBColor[
              0.2794551004482275, 0.4110554074207916, 0.9392259266025292], 
             458 -> RGBColor[
              0.2304992557221517, 0.359599710633853, 0.9364379636690613], 254 -> 
             RGBColor[
              0.23649824945009773`, 0.365905033400095, 0.9367795974871519], 
             290 -> RGBColor[
              0.2864852402250885, 0.41844453006287885`, 0.9396262826626617], 
             251 -> RGBColor[
              0.25854520282865096`, 0.38907777925853504`, 0.9380351388665158],
              165 -> RGBColor[
              0.4240332554553848, 0.5416980261695123, 0.9482400019731], 460 -> 
             RGBColor[
              0.24834625332605567`, 0.3783580366805602, 0.9374543237803367], 
             100 -> RGBColor[
              0.9312148525901699, 0.7649968423512695, 0.2635120596803694], 
             235 -> RGBColor[
              0.3570417238501652, 0.48367332858535217`, 0.9439713608175008], 
             70 -> 
             RGBColor[
              0.2582501634540876, 0.38876767416929214`, 0.9380183368106061], 
             234 -> RGBColor[
              0.38857864336543946`, 0.5109890231778194, 0.9459808654420111], 
             435 -> RGBColor[
              0.25811768357221787`, 0.3886284294137375, 0.93801079227732], 
             257 -> RGBColor[
              0.8588534332133313, 0.4519682304874997, 0.20393618366530758`], 
             135 -> RGBColor[
              0.25062676841059334`, 0.3807550026274169, 0.9375841957406814], 
             265 -> RGBColor[
              0.32101450543653715`, 0.45246836277611585`, 0.9416757383178027],
              111 -> RGBColor[
              0.27309124258507717`, 0.4043665893147275, 0.9388635143117069], 
             497 -> RGBColor[
              0.23599364281048124`, 0.36537465982794926`, 0.9367508608855244],
              481 -> RGBColor[
              0.318216697210702, 0.4500450419128276, 0.9414974644516573], 381 -> 
             RGBColor[
              0.5693048020656428, 0.6612263110627765, 0.9592369059322629], 
             182 -> RGBColor[
              0.3785866605047563, 0.5023344698355566, 0.9453441851296919], 
             188 -> RGBColor[
              0.33727714516499796`, 0.4665542439248693, 0.9427119793408126], 
             154 -> RGBColor[
              0.30954120355039927`, 0.44253076534726327`, 0.9409446696670606],
              336 -> RGBColor[
              0.22223854670063217`, 0.35091718169303304`, 0.9359675285109096],
              463 -> RGBColor[
              0.2670973610782935, 0.3980666398170606, 0.9385221716270487], 
             315 -> RGBColor[
              0.1854996162687526, 0.3123022364263995, 0.933875300773191], 368 -> 
             RGBColor[
              0.4081016499818632, 0.5278988702541217, 0.9472248541600927], 
             269 -> RGBColor[
              0.44893934079834463`, 0.5632704254773366, 0.9498269957075668], 
             208 -> RGBColor[
              0.32211852500862637`, 0.45342460903982235`, 0.9417460854686901],
              86 -> RGBColor[
              0.9151930916309041, 0.7014758990831244, 0.2506205747334791], 
             119 -> RGBColor[
              0.9906473743776302, 0.9904004632007044, 0.8046607405893015], 
             436 -> RGBColor[
              0.472919813782261, 0.5829766354800872, 0.9516491265847494], 377 -> 
             RGBColor[
              0.9811051107342013, 0.9854288030398846, 0.9168682983373343], 
             140 -> RGBColor[
              0.4996340643500339, 0.6046644675542787, 0.9537521702469687], 85 -> 
             RGBColor[
              0.21421555473578224`, 0.34248450845090483`, 0.9355106309874645],
              351 -> RGBColor[
              0.290045450304657, 0.422186536586862, 0.9398290313598343], 443 -> 
             RGBColor[
              0.9345119801701037, 0.7780688545030732, 0.2661650059247154], 
             242 -> RGBColor[
              0.22500762673968802`, 0.3538276603838957, 0.936125223522647], 
             117 -> RGBColor[
              0.38107527345035186`, 0.504489981287708, 0.9455027573459912], 
             47 -> RGBColor[
              0.23193365260590854`, 0.36110735270469657`, 0.9365196504495912],
              451 -> RGBColor[
              0.21144581794704176`, 0.3395733394744833, 0.935352898574804], 
             81 -> RGBColor[
              0.8236181467643259, 0.8621947699835874, 0.9830386281626226], 
             275 -> RGBColor[
              0.4137039619056965, 0.5327513112621616, 0.9475818285219495], 23 -> 
             RGBColor[
              0.2225015077722568, 0.35119357045200544`, 0.9359825037549226], 
             328 -> RGBColor[
              0.3853130055350487, 0.5081604918248647, 0.9457727818871488], 
             418 -> RGBColor[
              0.978473490691829, 0.9834661451211657, 0.9213229446326382], 110 -> 
             RGBColor[
              0.27171530098953856`, 0.4029203874580805, 0.9387851564733641], 
             6 -> RGBColor[
              0.8276898195746623, 0.8654414113599355, 0.9834269879500976], 
             218 -> RGBColor[
              0.23197293745711564`, 0.3611486435741187, 0.9365218876637508], 
             108 -> RGBColor[
              0.28511069510105125`, 0.41699979598632125`, 0.939548004351305], 
             297 -> RGBColor[
              0.5193642093092683, 0.6206822880650865, 0.955305399532062], 487 -> 
             RGBColor[
              0.5794313774456323, 0.6694475211532741, 0.9600341070410434], 
             464 -> RGBColor[
              0.24386676324271586`, 0.3736498085868948, 0.9371992234469022], 
             157 -> RGBColor[
              0.3025436094347634, 0.43532289426166115`, 0.9405407830329243], 
             441 -> RGBColor[
              0.4501324018566838, 0.5643037950010776, 0.9499030165032217], 
             354 -> RGBColor[
              0.3617638436367253, 0.48776339140382907`, 0.9442722501146938], 
             385 -> RGBColor[
              0.2334715870925415, 0.36272381936082626`, 0.9366072335434348], 
             270 -> RGBColor[
              0.9900230881246451, 0.9901423047916702, 0.8150067794022959], 
             392 -> 
             RGBColor[
              0.3060013924465708, 0.4389572434431762, 0.9407376986601153], 33 -> 
             RGBColor[
              0.8784142522519405, 0.5407893411964669, 0.22025821055067316`], 
             252 -> RGBColor[
              0.7357960105795031, 0.7935287028122899, 0.9743009279960564], 
             394 -> RGBColor[
              0.22864247952174482`, 0.3576481211208147, 0.9363322230113024], 
             260 -> RGBColor[
              0.28557642935408295`, 0.4174893122155148, 0.9395745272280231], 
             159 -> RGBColor[
              0.8207501650068003, 0.16050043778835987`, 0.16750368748545852`],
              183 -> RGBColor[
              0.2049673414252272, 0.33276404989092045`, 0.9349839589209338], 
             99 -> RGBColor[
              0.9936215336094609, 0.9887654302895413, 0.5471214806005384], 
             329 -> RGBColor[
              0.8825578842047201, 0.909191716742005, 0.9886603529358121], 309 -> 
             RGBColor[
              0.9930307649637, 0.9875018358921313, 0.48281995931092997`], 17 -> 
             RGBColor[
              0.8799712561457314, 0.9071292097399156, 0.9884136380424356], 
             349 -> RGBColor[
              0.41360147005439724`, 0.5326625379719564, 0.9475752978318146], 
             495 -> RGBColor[
              0.8422024713778844, 0.3253922650171049, 0.18804644029332332`], 
             347 -> RGBColor[0.178927, 0.305394, 0.933501], 340 -> 
             RGBColor[
              0.3374345618861965, 0.46669059037677707`, 0.9427220097950892], 
             404 -> RGBColor[
              0.2134483076486736, 0.3416780831160786, 0.9354669374008939], 
             277 -> RGBColor[
              0.7713015318020453, 0.8212658858432957, 0.977839786533559], 104 -> 
             RGBColor[
              0.24657366739272524`, 0.3764949364761905, 0.9373533776337394], 
             79 -> RGBColor[
              0.9938287149952354, 0.9892085703244617, 0.5696718958667929], 
             327 -> RGBColor[
              0.2570691600545971, 0.38752636471648727`, 0.9379510804141431], 
             191 -> RGBColor[
              0.21840138119578575`, 0.34688407745709465`, 0.9357490076119863],
              50 -> RGBColor[
              0.44093802683048844`, 0.5563400894761129, 0.9493171590568191], 
             225 -> RGBColor[
              0.27424929290791517`, 0.4055837736286615, 0.9389294635644105], 
             405 -> RGBColor[
              0.9940126833910108, 0.9896020601209673, 0.5896957204256101], 61 -> 
             RGBColor[
              0.3238266917401457, 0.45490413720770817`, 0.94185492834235], 
             196 -> RGBColor[
              0.29569933477919436`, 0.42812912764658106`, 0.9401510117164867],
              1 -> RGBColor[
              0.2661654894960651, 0.39708718370006774`, 0.9384691029190212], 
             263 -> RGBColor[
              0.2734006518561467, 0.40469179807630246`, 0.9388811347119643], 
             201 -> RGBColor[
              0.3044587746178886, 0.4373358542976118, 0.9406498488568703], 
             371 -> RGBColor[
              0.36294391873403165`, 0.48878551314081686`, 0.9443474434563948],
              293 -> RGBColor[
              0.9542723127115095, 0.9654169462092355, 0.962289226275195], 362 -> 
             RGBColor[
              0.38846154058520777`, 0.5108875946353395, 0.9459734037564047], 
             184 -> RGBColor[
              0.2570318728012019, 0.3874871734490205, 0.9379489569602237], 
             106 -> RGBColor[
              0.5178553382148801, 0.619457318536794, 0.9551866156723348], 206 -> 
             RGBColor[
              0.3427341577200499, 0.4712808339226293, 0.9430596953553738], 
             358 -> RGBColor[
              0.22562621270692998`, 0.3544778334560826, 0.9361604510783655], 
             247 -> RGBColor[
              0.4950113815248125, 0.6009115653872759, 0.9533882557215221], 
             220 -> RGBColor[
              0.3389132056188999, 0.46797131725924984`, 0.9428162276662237], 
             407 -> RGBColor[
              0.21435834209939697`, 0.3426345870233057, 0.9355187625165873], 
             107 -> RGBColor[
              0.18467169248908813`, 0.3114320360405726, 0.9338281517387427], 
             375 -> RGBColor[
              0.9582014383733062, 0.9683472816944506, 0.9556382414098691], 
             131 -> RGBColor[
              0.263609049878749, 0.394400203574635, 0.9383235174647285], 411 -> 
             RGBColor[
              0.23958996446517072`, 0.3691546219069906, 0.9369556660834778], 
             462 -> RGBColor[
              0.46387836533310084`, 0.575636380316448, 0.9509373506429145], 
             127 -> RGBColor[
              0.22597981130456574`, 0.35484948800164373`, 0.9361805879953986],
              210 -> RGBColor[
              0.8360637140310553, 0.2782070860287545, 0.182167959325265], 357 -> 
             RGBColor[
              0.9071422836282599, 0.6695571281253704, 0.2441427056377997], 
             181 -> RGBColor[
              0.4206971967779904, 0.5388084998183378, 0.9480274312641372], 
             194 -> 
             RGBColor[
              0.9865160895376739, 0.9886920707502049, 0.8731268218098209], 
             440 -> RGBColor[
              0.28167383897512416`, 0.41338744228870766`, 0.9393522804793065],
              490 -> RGBColor[
              0.9905535588776926, 0.9903616680805318, 0.806215506209998], 118 -> 
             RGBColor[
              0.32510810483221725`, 0.45601403282236586`, 0.9419365788514676],
              348 -> RGBColor[
              0.9599116097125079, 0.876434587737939, 0.29876460310071706`], 
             276 -> RGBColor[
              0.6195401563438858, 0.7020096347427746, 0.9631916170392121], 
             305 -> RGBColor[
              0.2511118726659751, 0.3812648779572094, 0.9376118217103779], 
             343 -> RGBColor[
              0.29288750827080284`, 0.425173719706164, 0.9399908823565584], 
             280 -> RGBColor[
              0.25689237745970156`, 0.38734055500058817`, 0.9379410129068901],
              474 -> RGBColor[
              0.9930971542734537, 0.9914135101440991, 0.7640615478883636], 
             189 -> RGBColor[
              0.2597753641562747, 0.39037075681060074`, 0.9381051947342635], 
             168 -> RGBColor[
              0.9107922199972238, 0.6840279095591187, 0.24707953011528597`], 
             363 -> RGBColor[
              0.40481135748628755`, 0.5250489842693634, 0.9470151996317661], 
             41 -> RGBColor[
              0.23252667542550592`, 0.36173065728791187`, 0.9365534222218687],
              14 -> RGBColor[
              0.30674268007373295`, 0.4397363837396738, 0.9407799138938453], 
             77 -> RGBColor[
              0.606817875551374, 0.6916811140631951, 0.9621900724919755], 51 -> 
             RGBColor[
              0.17892700081062782`, 0.30539400085202123`, 0.9335010000461641],
              438 -> RGBColor[
              0.22146455698209894`, 0.3501036694250721, 0.9359234509414543], 
             179 -> RGBColor[
              0.178929137062006, 0.30539624618766587`, 0.9335011217025198], 
             467 -> RGBColor[
              0.7068391686146014, 0.7709073977891587, 0.9714147806060683], 
             223 -> RGBColor[
              0.38986378476733635`, 0.5121021480670574, 0.9460627535157341], 
             456 -> RGBColor[
              0.22365852866224617`, 0.35240967276674573`, 0.9360483943829485],
              323 -> RGBColor[
              0.23934466612723454`, 0.36889679780100676`, 0.9369416967060188],
              500 -> RGBColor[
              0.8194926622925333, 0.15083472088530037`, 0.16629950146613023`],
              478 -> 
             RGBColor[
              0.2660419428822219, 0.39695732837561076`, 0.9384620671221336], 
             292 -> RGBColor[
              0.1789706321783367, 0.30543986018587177`, 0.9335034847880083], 
             491 -> RGBColor[
              0.9941614319695004, 0.9899202182895682, 0.6058860852243823], 
             396 -> RGBColor[
              0.9935460613341791, 0.9886040027241311, 0.5389067891970045], 
             321 -> RGBColor[
              0.3331754530775283, 0.46300156439574175`, 0.942450623147983], 
             143 -> RGBColor[
              0.17892700134778292`, 0.3053940014166053, 0.9335010000767543], 
             112 -> RGBColor[
              0.24826352560257345`, 0.3782710845979398, 0.937449612558869], 
             197 -> RGBColor[
              0.6976256228082208, 0.7637097057796726, 0.9704964604655693], 
             421 -> RGBColor[
              0.17905660578117066`, 0.3055302238934915, 0.9335083808575031], 
             54 -> RGBColor[
              0.22872079714307936`, 0.35773043790646125`, 0.9363366830839769],
              71 -> RGBColor[
              0.755781538403036, 0.8091415490436711, 0.97629289863413], 177 -> 
             RGBColor[
              0.20869655844004803`, 0.3366836934195124, 0.9351963323130457], 
             158 -> RGBColor[
              0.3575213303529286, 0.48408873963232213`, 0.9440019209197574], 
             226 -> RGBColor[
              0.1794249922972142, 0.30591742147890744`, 0.9335293599246128], 
             432 -> RGBColor[
              0.898624468927386, 0.9220027752840345, 0.9901927981294695], 350 -> 
             RGBColor[
              0.3621699928109498, 0.4881151774048913, 0.9442981295809318], 
             203 -> RGBColor[
              0.5345666356633387, 0.6330243026408235, 0.956502190222977], 475 -> 
             RGBColor[
              0.839003391040872, 0.30080273170088523`, 0.1849829973497558], 
             115 -> RGBColor[
              0.9211683800910966, 0.9399786781078106, 0.9923430565014513], 
             173 -> RGBColor[
              0.984562956112485, 0.9878843998856498, 0.9054952972124768], 212 -> 
             RGBColor[
              0.21851625165510197`, 0.3470048135930438, 0.9357555493147087], 
             129 -> RGBColor[
              0.35559977387920144`, 0.4824243839950162, 0.9438794810404173], 
             279 -> RGBColor[
              0.2785602236563872, 0.4101148351741018, 0.9391749646930856], 26 -> 
             RGBColor[
              0.3866295369467384, 0.5093008051628776, 0.9458566701045386], 40 -> 
             RGBColor[
              0.3862001571816754, 0.5089288979916344, 0.9458293104055944], 
             146 -> RGBColor[
              0.257933230334439, 0.3884345573658211, 0.9380002879383026], 386 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 192 -> 
             RGBColor[
              0.2546146394674752, 0.38494650795382845`, 0.9378112990978443], 
             300 -> RGBColor[
              0.22595764709528393`, 0.3548261920123965, 0.936179325776469], 
             221 -> RGBColor[
              0.5366100807415061, 0.6346832634114314, 0.9566630577049163], 62 -> 
             RGBColor[0.817319, 0.134127, 0.164218], 286 -> 
             RGBColor[
              0.22310026486080187`, 0.3518229021154584, 0.9360166020853335], 
             472 -> RGBColor[
              0.32844671668737896`, 0.45890577060779597`, 0.9421493122466601],
              152 -> RGBColor[
              0.20400293554931437`, 0.33175039816847185`, 0.9349290374330113],
              64 -> RGBColor[
              0.2878344487965492, 0.41986263381624833`, 0.9397031180948312], 
             307 -> RGBColor[
              0.46980956787155936`, 0.580451597734798, 0.9514042766334527], 
             37 -> RGBColor[
              0.305640198745031, 0.4385776059618545, 0.9407171292131508], 148 -> 
             RGBColor[
              0.23965584235908116`, 0.3692238637503902, 0.9369594177320785], 
             261 -> RGBColor[
              0.8799868165294279, 0.5479299882988189, 0.2215703967308864], 
             387 -> RGBColor[
              0.7751138064478154, 0.8242440637709316, 0.9782197584425172], 15 -> 
             RGBColor[
              0.23423879357827926`, 0.36353020202103736`, 0.9366509248178173],
              136 -> RGBColor[
              0.968960662006962, 0.9763714930638193, 0.9374256822530368], 198 -> 
             RGBColor[
              0.2818794421164257, 0.41360354422620765`, 0.9393639892740411], 
             63 -> RGBColor[
              0.41933559472005666`, 0.5376291485518648, 0.9479406711850231], 
             444 -> RGBColor[
              0.27129304719779485`, 0.4024765719505212, 0.9387611097445928], 
             310 -> RGBColor[
              0.29675707084929953`, 0.4292408753206019, 0.9402112482208989], 
             171 -> RGBColor[
              0.26174222518751433`, 0.39243805246062563`, 0.9382172045602823],
              395 -> RGBColor[
              0.26498757281889074`, 0.39584911858812655`, 0.9384020223068277],
              311 -> RGBColor[
              0.746856868272219, 0.8021695289074716, 0.9754033709212744], 353 -> 
             RGBColor[
              0.6396625402707171, 0.7183458925176417, 0.9647757248126534], 59 -> 
             RGBColor[
              0.2421911048281961, 0.37188858535035474`, 0.9371037971791099], 
             397 -> RGBColor[
              0.3585480532796543, 0.48497803542685713`, 0.944067342796753], 
             229 -> RGBColor[
              0.2909757990296596, 0.42316439208435586`, 0.9398820133433956], 
             102 -> RGBColor[
              0.2765375568294345, 0.40798888409449063`, 0.939059776809558], 
             453 -> RGBColor[
              0.2843068325272902, 0.41615488545346746`, 0.9395022255669375], 
             299 -> RGBColor[
              0.2091663766185125, 0.3371775021132715, 0.9352230877632756], 
             128 -> RGBColor[
              0.49474321248409076`, 0.6006938536791404, 0.9533671444723009], 
             12 -> RGBColor[
              0.27240341106773047`, 0.40364363477895904`, 0.9388243433243495],
              222 -> RGBColor[
              0.4427137030371586, 0.5578780909582495, 0.9494303035745394], 
             483 -> RGBColor[
              0.29664917161590876`, 0.42912746638510174`, 0.9402051035191799],
              92 -> RGBColor[
              0.6091375885965603, 0.6935643616151592, 0.9623726888002815], 
             271 -> RGBColor[
              0.2558053195227897, 0.38619798818543977`, 0.9378791065655412], 
             361 -> RGBColor[
              0.6442014475594858, 0.7219743340365904, 0.9651716379540781], 
             344 -> RGBColor[
              0.4637429804071734, 0.5755264687345587, 0.9509266926456142], 
             132 -> RGBColor[
              0.9901329118562932, 0.9901877197270478, 0.8131867159541827], 80 -> 
             RGBColor[
              0.7895429134572223, 0.8355161918319554, 0.9796579169815435], 
             324 -> RGBColor[
              0.369677449943029, 0.49461775943693126`, 0.9447764981108042], 
             244 -> RGBColor[
              0.3424410288691568, 0.4710269404450701, 0.9430410174441985], 
             150 -> RGBColor[
              0.8214446559981496, 0.16583859987576455`, 0.16816873284309014`],
              125 -> RGBColor[
              0.20867358600249122`, 0.3366595479311035, 0.9351950240667115], 
             258 -> RGBColor[
              0.3734224424883788, 0.497861483750915, 0.945015125724227], 133 -> 
             RGBColor[
              0.3451736656290086, 0.4733938130601367, 0.9432151386421606], 
             469 -> RGBColor[
              0.8604306779796645, 0.4591301305965446, 0.20525227536014304`], 
             255 -> 
             RGBColor[
              0.3975855258515599, 0.5187903320882202, 0.9465547760295533], 
             408 -> RGBColor[
              0.2225045334786326, 0.3511967506612473, 0.9359826760644245], 
             326 -> RGBColor[
              0.8751755113140446, 0.526082975024646, 0.21755572572328788`], 
             176 -> RGBColor[
              0.6069446059586334, 0.6917839995169481, 0.9622000491738637], 
             230 -> RGBColor[
              0.2238780227461086, 0.35264037496561385`, 0.936060894246312], 
             274 -> RGBColor[
              0.4627342609626232, 0.5747075448471798, 0.9508472825558781], 87 -> 
             RGBColor[
              0.1792532619022457, 0.3057369219454596, 0.9335195801326717], 
             439 -> RGBColor[
              0.8609124841587944, 0.891932262294116, 0.986595795356355], 130 -> 
             RGBColor[0.178927, 0.305394, 0.933501], 35 -> 
             RGBColor[
              0.23837242809378653`, 0.36787491398440125`, 0.9368863291883112],
              379 -> RGBColor[
              0.3092991992760449, 0.442321153408306, 0.9409292493686947], 31 -> 
             RGBColor[
              0.4530382628066378, 0.5668207057031098, 0.9500881753934008], 18 -> 
             RGBColor[
              0.8843839202879132, 0.5678962094964264, 0.22523944788984251`], 
             24 -> RGBColor[
              0.8369720141620951, 0.8728427813654944, 0.9843123319561599], 
             151 -> RGBColor[
              0.30679432383558886`, 0.439790664607788, 0.9407828549296829], 
             137 -> RGBColor[
              0.22008054170119, 0.3486489816131997, 0.9358446333186737], 330 -> 
             RGBColor[
              0.3064495532407965, 0.43942828885294294`, 0.9407632207543519], 
             296 -> RGBColor[
              0.3134198204339392, 0.44589022834683273`, 0.9411918117051534], 
             266 -> RGBColor[
              0.28952074326414307`, 0.421635036218934, 0.9397991500701115], 
             302 -> RGBColor[
              0.19014935834156865`, 0.31718941015560403`, 0.934140096705561], 
             442 -> RGBColor[
              0.28394532564135605`, 0.4157749187954902, 0.9394816382845851], 
             283 -> RGBColor[
              0.18121415923057888`, 0.3077979493656092, 0.9336312503346327], 
             388 -> RGBColor[
              0.9461721011462925, 0.9593758216867757, 0.9760007715815773], 
             284 -> RGBColor[
              0.24509263407936946`, 0.37493827656091794`, 0.9372690349775362],
              417 -> RGBColor[
              0.7010326627105, 0.7663713112457954, 0.9708360423624304], 318 -> 
             RGBColor[
              0.341942322952124, 0.4705949864454246, 0.9430092403441536], 413 -> 
             RGBColor[
              0.97383602535665, 0.9234049113139019, 0.35285832847295656`], 
             238 -> RGBColor[
              0.32015392046586916`, 0.45172296732878153`, 0.9416209026044572],
              72 -> RGBColor[
              0.2539844574642687, 0.3842841467126117, 0.9377754111650324], 
             437 -> RGBColor[
              0.2558304623203871, 0.3862244148598601, 0.9378805384106689], 
             288 -> RGBColor[
              0.2560659100008252, 0.3864718853002457, 0.9378939468077562], 
             382 -> RGBColor[
              0.28222469603460637`, 0.4139664279845783, 0.9393836509739241], 
             461 -> RGBColor[
              0.944455505750549, 0.9580955876512972, 0.9789065198267879], 389 -> 
             RGBColor[
              0.2184997826909155, 0.34698750366749115`, 0.9357546114315619], 
             172 -> RGBColor[
              0.3516524550010693, 0.4790054147807936, 0.9436279613719797], 
             447 -> RGBColor[
              0.2464999471451923, 0.3764174518218997, 0.9373491793747017], 
             243 -> RGBColor[
              0.8393061093521738, 0.30312955729356095`, 0.18527288074652987`],
              410 -> RGBColor[
              0.36366501242205085`, 0.4894100882501565, 0.9443933909085572], 
             88 -> RGBColor[
              0.8666101266120032, 0.4871895635890985, 0.21040855877111306`], 
             273 -> RGBColor[
              0.2935414156904733, 0.42586101786436276`, 0.9400281214167392], 
             477 -> RGBColor[
              0.24467162743864543`, 0.3744957718881542, 0.9372450592721705], 
             202 -> RGBColor[
              0.23905706042934927`, 0.3685945059772749, 0.9369253179869986], 
             393 -> RGBColor[
              0.4612114846587171, 0.5734712864433781, 0.9507274040271213], 98 -> 
             RGBColor[
              0.9952347378240085, 0.9922159109844932, 0.7227088038116687], 30 -> 
             RGBColor[
              0.2679312243382506, 0.39894308297325987`, 0.938569658906113], 
             116 -> RGBColor[
              0.24872594858728536`, 0.3787571204741826, 0.9374759468637549], 
             373 -> RGBColor[
              0.293615491872952, 0.425938876628849, 0.9400323399457455], 434 -> 
             RGBColor[
              0.9912025783926344, 0.990630054329001, 0.7954595732387495], 401 -> 
             RGBColor[
              0.7734523776791622, 0.8229461429895335, 0.9780541627497925], 
             240 -> RGBColor[
              0.2566255537350775, 0.38706010634840704`, 0.9379258176905032], 
             480 -> RGBColor[
              0.35354723518652786`, 0.48064657814301665`, 0.9437486950899088],
              403 -> RGBColor[
              0.9289119756027943, 0.9461532109745376, 0.9930816475541463], 
             317 -> RGBColor[
              0.8834003236622562, 0.5634299269441462, 0.22441871075523476`], 
             429 -> RGBColor[
              0.29359796730781346`, 0.4259204571997668, 0.9400313419476861], 
             391 -> RGBColor[
              0.2411272273904176, 0.370770382709524, 0.937043210932894], 73 -> 
             RGBColor[
              0.24791046842011605`, 0.37789999911405875`, 0.9374295064746294],
              303 -> RGBColor[
              0.3052585207535403, 0.43817643819301544`, 0.9406953932161773], 
             449 -> RGBColor[
              0.7283027762348872, 0.7876749311915857, 0.9735540724248413], 29 -> 
             RGBColor[
              0.40962031041891445`, 0.5292142575946026, 0.9473216218602429], 
             360 -> RGBColor[
              0.5793663225363243, 0.6693947066472076, 0.9600289856802787], 
             320 -> RGBColor[
              0.9886024976405045, 0.9895548541189678, 0.8385496400948322], 
             482 -> RGBColor[
              0.35848143845973107`, 0.48492033701799786`, 0.9440630981593326],
              75 -> RGBColor[
              0.3449485107481652, 0.47319879521896346`, 0.9432007919722498], 
             200 -> RGBColor[
              0.9008280073528754, 0.6425649682443086, 0.23896079721830538`], 
             301 -> RGBColor[
              0.20875268020104726`, 0.3367426809486477, 0.9351995283643099], 
             156 -> RGBColor[
              0.46730916543215706`, 0.578421658392645, 0.9512074357941471], 
             25 -> RGBColor[
              0.3133752819583538, 0.4458516513578495, 0.941188973752873], 38 -> 
             RGBColor[
              0.25996867538836677`, 0.3905739391721695, 0.9381162035229527], 
             365 -> RGBColor[
              0.2169746648251472, 0.34538450809251103`, 0.9356677582253161], 
             380 -> RGBColor[
              0.27285106149406285`, 0.4041141437597107, 0.9388498363538897], 
             370 -> RGBColor[
              0.591443337591513, 0.6791993715323379, 0.960979732544987], 3 -> 
             RGBColor[
              0.46166603367100856`, 0.5738403098087559, 0.9507631877904368], 
             57 -> 
             RGBColor[
              0.6012429877716181, 0.6871551690177569, 0.9617511969044663], 
             227 -> RGBColor[
              0.8456311671254343, 0.35174672299683013`, 0.19132976321333509`],
              494 -> RGBColor[
              0.2585035332044634, 0.3890339818415072, 0.938032765843063], 39 -> 
             RGBColor[
              0.6236615875481659, 0.7053555982627691, 0.963516071200913], 424 -> 
             RGBColor[
              0.3205944320155112, 0.4521045162923272, 0.9416489716108714], 
             109 -> RGBColor[
              0.25396000439311356`, 0.38425844498441336`, 0.9377740185988052],
              465 -> RGBColor[
              0.28262558218412137`, 0.4143877847453685, 0.939406480847081], 
             256 -> RGBColor[
              0.2893861381019995, 0.4214935576590608, 0.939791484505258], 457 -> 
             RGBColor[
              0.22158907133489145`, 0.35023454190452297`, 0.9359305418496434],
              339 -> RGBColor[
              0.21169068579341777`, 0.33983071110654267`, 0.9353668434364056],
              420 -> RGBColor[
              0.96864282965107, 0.9761344542131977, 0.9379636895276074], 287 -> 
             RGBColor[
              0.20981171601903448`, 0.33785579474010136`, 0.9352598388874411],
              239 -> RGBColor[
              0.3509305166159243, 0.47838010803725933`, 0.9435819600964633], 
             427 -> RGBColor[
              0.2795001276110678, 0.4111027338238238, 0.9392284908328413], 
             285 -> RGBColor[
              0.3144183414809424, 0.4467550970906198, 0.941255436583311], 345 -> 
             RGBColor[
              0.6597251945044771, 0.7341016031348642, 0.9667188999718916], 
             366 -> RGBColor[
              0.2650062967491503, 0.3958687986259951, 0.9384030886069564], 
             216 -> RGBColor[
              0.26588598144981995`, 0.39679340302163035`, 0.9384531853492826],
              21 -> RGBColor[
              0.9808877657874093, 0.9471920876142448, 0.3802530084370154], 
             355 -> RGBColor[
              0.32870680276015046`, 0.45913104409172456`, 0.942165884701232], 
             175 -> RGBColor[
              0.9557302644442173, 0.966504284224312, 0.9598212942864327], 7 -> 
             RGBColor[
              0.8386821070512293, 0.8742063630160551, 0.9844754421425435], 13 -> 
             RGBColor[
              0.29661626096016863`, 0.4290928751992627, 0.9402032293060224], 
             294 -> RGBColor[
              0.23831274258564697`, 0.36781218073106675`, 0.9368829301869194],
              412 -> 
             RGBColor[
              0.2423814866745967, 0.372088688741828, 0.9371146391436176], 193 -> 
             RGBColor[
              0.2878117179623051, 0.41983874226823964`, 0.9397018236074483], 
             60 -> RGBColor[
              0.29270959820985176`, 0.42498672495195505`, 0.9399807506417815],
              65 -> RGBColor[
              0.9854648277298144, 0.9626315922912277, 0.39803402977763763`], 
             448 -> RGBColor[
              0.5679393142918087, 0.6601177465734548, 0.9591294097327601], 69 -> 
             RGBColor[
              0.9094625081980608, 0.9306447336077317, 0.9912265399903383], 
             217 -> RGBColor[
              0.31971976000988434`, 0.4513469193633465, 0.9415932382841149], 
             214 -> RGBColor[
              0.19980711485308938`, 0.32734032458634205`, 0.9346900916515217],
              170 -> RGBColor[
              0.29668056881803306`, 0.42916046683523196`, 0.9402068915433929],
              359 -> RGBColor[
              0.38545126270191343`, 0.5082802432337956, 0.9457815915115654], 
             74 -> RGBColor[
              0.2817340129849886, 0.4134506889883278, 0.9393557073001488], 
             246 -> RGBColor[
              0.29422140859812795`, 0.42657573352434824`, 0.9400668460068708],
              264 -> RGBColor[
              0.23478619087952063`, 0.36410555129163547`, 0.9366820982843213],
              278 -> RGBColor[
              0.9483637407407871, 0.9610103429078694, 0.9722908974192511], 45 -> 
             RGBColor[
              0.28278247170568477`, 0.41455268557990177`, 0.9394154154732368],
              492 -> RGBColor[
              0.2766193131480329, 0.4080748151689876, 0.9390644327109545], 
             306 -> RGBColor[
              0.8575795140998795, 0.443586953641446, 0.20277151376979163`], 
             237 -> RGBColor[
              0.906092392768253, 0.9279574950433493, 0.9909050953721057], 228 -> 
             RGBColor[
              0.9930813033990235, 0.9876099324950685, 0.48832075610881853`], 
             180 -> RGBColor[
              0.27013094278236094`, 0.4012551265282246, 0.9386949296173133], 
             383 -> RGBColor[
              0.32894252042405586`, 0.45933521088468515`, 0.942180904422339], 
             53 -> RGBColor[
              0.9765123065091236, 0.9324326360618924, 0.36325517537702773`], 
             304 -> RGBColor[
              0.3385640468354945, 0.4676688934702948, 0.9427939795772942], 48 -> 
             RGBColor[
              0.20751087662989864`, 0.3354374666604766, 0.9351288094880167], 
             5 -> 
             RGBColor[
              0.23860734128045696`, 0.3681218226379481, 0.9368997071467691], 
             101 -> RGBColor[
              0.5208327276256995, 0.6218744973903617, 0.9554210066732913], 
             333 -> RGBColor[
              0.3786491349611119, 0.5023885820695944, 0.9453481659468069], 
             267 -> RGBColor[
              0.9890626064851881, 0.9747677448317271, 0.41201072085875556`], 
             120 -> RGBColor[
              0.20742150462258202`, 0.3353435310142743, 0.9351237198844141], 
             147 -> RGBColor[
              0.25149316947897704`, 0.3816656450832887, 0.9376335359998004], 
             89 -> RGBColor[
              0.28550171685781406`, 0.4174107846448903, 0.9395702724618878], 
             43 -> RGBColor[
              0.2931478124699098, 0.42544731592366486`, 0.940005706295612], 
             199 -> RGBColor[
              0.3428438781472085, 0.4713758682419251, 0.9430666866439704], 
             268 -> RGBColor[
              0.40965477924277666`, 0.5292441127573786, 0.9473238181832199], 
             169 -> RGBColor[
              0.4927421843014464, 0.5990693288551774, 0.9532096162037554], 20 -> 
             RGBColor[
              0.8845340276069948, 0.5685778117739207, 0.22536470111635126`], 
             4 -> RGBColor[
              0.32430364693803726`, 0.45531725182765653`, 0.9418853195058047],
              167 -> RGBColor[
              0.9866702547547157, 0.9887558220293171, 0.870571905196646], 431 -> 
             RGBColor[
              0.4485399301016759, 0.5629244760068475, 0.9498015456111601], 
             142 -> RGBColor[
              0.6995243049605603, 0.765192970707599, 0.9706857033583209], 16 -> 
             RGBColor[
              0.4038820814050813, 0.5242440920345965, 0.9469559869815982], 
             414 -> RGBColor[
              0.2746579678933065, 0.4060133169497984, 0.9389527370002482], 
             281 -> RGBColor[
              0.24490866169442368`, 0.374744909919817, 0.9372585580223763], 
             289 -> RGBColor[
              0.439371052281192, 0.5549828548799431, 0.9492173128241592], 398 -> 
             RGBColor[
              0.26115105564507934`, 0.3918166957892125, 0.9381835383293976], 
             178 -> RGBColor[
              0.9916846362160958, 0.9908293976273234, 0.7874706275783359], 58 -> 
             RGBColor[
              0.31511174381280593`, 0.44735568733906544`, 0.9412996195667458],
              186 -> RGBColor[
              0.23571041014604155`, 0.365076964339635, 0.9367347312042897], 
             122 -> 
             RGBColor[
              0.867504304657107, 0.49124981725132677`, 0.21115468285025726`], 
             249 -> RGBColor[
              0.2895478687563091, 0.421663546831056, 0.9398006948267619], 113 -> 
             RGBColor[
              0.17919226069553715`, 0.305672805809509, 0.9335161062041928], 
             52 -> RGBColor[
              0.8357950446989824, 0.2761419758107905, 0.18191068126945342`], 
             409 -> RGBColor[
              0.24155566178660715`, 0.3712206944242289, 0.937067609637945], 
             187 -> RGBColor[
              0.26462809617956273`, 0.3954712858480575, 0.938381550644016], 
             259 -> RGBColor[
              0.8618406991999262, 0.46553270763892984`, 0.20642883162911219`],
              42 -> RGBColor[
              0.23247426890382172`, 0.3616755747108564, 0.9365504377479873], 
             134 -> RGBColor[
              0.2332063867745317, 0.36244507701192663`, 0.9365921307776528], 
             470 -> RGBColor[
              0.25548210733168075`, 0.3858582716797478, 0.937860700109407], 
             313 -> RGBColor[
              0.266957894870447, 0.3979200519899457, 0.9385142292328336], 248 -> 
             RGBColor[
              0.24253965650195108`, 0.3722549352589237, 0.9371236466812941], 
             174 -> RGBColor[
              0.2666571079259713, 0.3976039058403079, 0.93849709986132], 215 -> 
             RGBColor[
              0.28412310253725925`, 0.4159617735847908, 0.9394917624158093], 
             399 -> RGBColor[
              0.24150095424043594`, 0.3711631933245442, 0.9370644941241232], 
             422 -> RGBColor[
              0.23401200432651914`, 0.3632918321381684, 0.9366380095054342], 
             83 -> RGBColor[
              0.9207457022290968, 0.9396416462539369, 0.9923027411096448], 95 -> 
             RGBColor[
              0.22708291988077767`, 0.3560089250563658, 0.936243408396911], 
             166 -> RGBColor[
              0.8381204118994321, 0.2940157670958513, 0.18413745552673064`], 
             384 -> RGBColor[
              0.28382079992875175`, 0.41564403437615693`, 0.9394745467294715],
              233 -> RGBColor[
              0.8431597968980244, 0.3327506884676198, 0.18896317629255405`], 
             295 -> RGBColor[
              0.22958788287780074`, 0.3586417999900643, 0.9363860623338308], 
             499 -> RGBColor[
              0.2607186377132893, 0.3913621971260208, 0.9381589127678872], 
             141 -> RGBColor[
              0.30958288032569087`, 0.4425668636752852, 0.9409473252743288], 
             319 -> 
             RGBColor[
              0.7148896845747944, 0.7771965220434489, 0.9722171808006315], 
             205 -> RGBColor[
              0.9938265629209484, 0.98920396725517, 0.5694376558617151], 468 -> 
             RGBColor[
              0.4783770236668791, 0.5874070443089239, 0.952078738137285], 486 -> 
             RGBColor[
              0.9349275982881982, 0.9509499052141509, 0.9936554230160899], 
             224 -> RGBColor[
              0.29896629209325354`, 0.43156290692071464`, 0.9403370601024921],
              231 -> RGBColor[
              0.2584463601503126, 0.3889738893366137, 0.9380295099222091], 
             332 -> RGBColor[
              0.40219205331719154`, 0.5227802746481479, 0.946848299886271], 
             68 -> RGBColor[
              0.8199864588949732, 0.15463025795470559`, 0.16677236165029033`],
              484 -> RGBColor[
              0.9928916986278599, 0.9872043870615327, 0.4676834468726777], 10 -> 
             RGBColor[
              0.2189624152550279, 0.3474737598249721, 0.9357809576716846], 
             250 -> RGBColor[
              0.20444533477183996`, 0.332215387801077, 0.934954231414263], 
             282 -> RGBColor[
              0.6076583896248129, 0.6923634812527404, 0.9622562408387412], 
             374 -> RGBColor[
              0.2517303220687306, 0.38191490749146234`, 0.937647041488951], 
             232 -> RGBColor[
              0.3561976264336458, 0.4829422138287328, 0.9439175756765262], 
             489 -> RGBColor[
              0.9900975943251971, 0.9901731150203205, 0.8137720188432849], 
             253 -> RGBColor[
              0.9850318468002165, 0.9880782982349678, 0.8977245650665646], 
             459 -> RGBColor[
              0.3905461178527888, 0.5126931506906183, 0.9461062311765757], 
             415 -> RGBColor[
              0.2870126862041934, 0.4189989092289247, 0.9396563199308854], 55 -> 
             RGBColor[
              0.21147766438726034`, 0.339606812102334, 0.9353547121824619], 
             446 -> RGBColor[
              0.22815127331601265`, 0.3571318322543179, 0.9363042495445604], 
             325 -> RGBColor[
              0.1790169203691504, 0.30548851200925775`, 0.9335061208319979], 
             91 -> RGBColor[
              0.3276288460270304, 0.4581973721491767, 0.9420971982513973], 
             450 -> RGBColor[
              0.8177084834502429, 0.13712074047130335`, 0.1645909697918113], 
             423 -> RGBColor[
              0.18782589147201245`, 0.31474729915939237`, 0.9340077787046009],
              105 -> 
             RGBColor[
              0.2459052705491277, 0.3757924090147619, 0.9373153134223011], 36 -> 
             RGBColor[
              0.254389289460926, 0.3847096508089296, 0.9377984657483468], 123 -> 
             RGBColor[
              0.2069635167020156, 0.33486215667164765`, 0.9350976381498702], 
             94 -> RGBColor[
              0.9554190789968999, 0.9662722026272221, 0.9603480500785777], 
             473 -> RGBColor[
              0.32683125980079797`, 0.4575065430478635, 0.9420463767623395], 
             312 -> RGBColor[
              0.3044115375980597, 0.43728620519477157`, 0.940647158778472], 
             96 -> RGBColor[
              0.2961617343973124, 0.4286151389630523, 0.9401773446906796], 
             496 -> RGBColor[
              0.27688954314442643`, 0.4083588440287685, 0.9390798219094797], 
             2 -> RGBColor[
              0.2124476857409665, 0.34062636604798524`, 0.9354099534635375], 
             262 -> RGBColor[
              0.47608581392629684`, 0.5855469370236965, 0.9518983657135286], 
             272 -> RGBColor[
              0.8205829319400263, 0.15921501115513814`, 0.16734354491185305`],
              97 -> RGBColor[
              0.2317345075524728, 0.36089803862701, 0.9365083094334068], 372 -> 
             RGBColor[
              0.4704530721178047, 0.5809740234714359, 0.951454935644951], 356 -> 
             RGBColor[
              0.26933793088281155`, 0.4004216207419397, 0.9386497687627899], 
             402 -> RGBColor[
              0.5523112332770156, 0.6474301663686192, 0.9578991099477285], 
             455 -> RGBColor[
              0.20394063923757638`, 0.33168492079502093`, 0.9349254897502168],
              428 -> RGBColor[
              0.8303334960184631, 0.23416211938642656`, 0.1766806960850511], 
             346 -> RGBColor[
              0.21788265672664042`, 0.34633886515099205`, 0.9357194670208525],
              341 -> RGBColor[
              0.9935733711383794, 0.9886624156338708, 0.5418792928476311], 
             209 -> RGBColor[
              0.5659235722129052, 0.6584812763456551, 0.9589707231324023], 
             498 -> RGBColor[
              0.46188951150763047`, 0.5740217391840874, 0.9507807807843619], 
             378 -> RGBColor[
              0.2830844261537786, 0.4148700588498662, 0.9394326113323542], 
             419 -> RGBColor[
              0.5126905354832046, 0.6152642990075083, 0.9547800234820015], 66 -> 
             RGBColor[
              0.2632810725593861, 0.3940554786170215, 0.9383048396415897], 
             139 -> 
             RGBColor[
              0.5640351798749514, 0.6569481943745988, 0.9588220619701494], 56 -> 
             RGBColor[
              0.8366736085240676, 0.28289500235951803`, 0.1827519949805509], 
             335 -> RGBColor[
              0.2767721721232211, 0.4082354796437291, 0.9390731378034569], 
             314 -> RGBColor[
              0.33007547283951477`, 0.4603165173231115, 0.9422530951484216], 
             144 -> RGBColor[
              0.24622776306205768`, 0.3761313690930576, 0.9373336788938276], 
             298 -> RGBColor[
              0.9016398137954514, 0.9244071294324739, 0.9904804044148157], 
             204 -> RGBColor[
              0.5018930513522051, 0.606498414968846, 0.9539300059787216], 452 -> 
             RGBColor[
              0.22395342458252596`, 0.35271962707644106`, 0.936065188269349], 
             466 -> RGBColor[
              0.503508173143364, 0.6078096435993164, 0.9540571542825077], 207 -> 
             RGBColor[
              0.217062994597398, 0.3454773482835776, 0.9356727884751737], 334 -> 
             RGBColor[
              0.4028040785660817, 0.5233103801574531, 0.9468872975939376], 
             149 -> RGBColor[
              0.353874772698637, 0.4809302746734916, 0.9437695654905504], 219 -> 
             RGBColor[
              0.5262688994117111, 0.6262878265429939, 0.9558489620296395], 
             400 -> RGBColor[
              0.295921828646773, 0.42836298280833224`, 0.9401636824130951], 9 -> 
             RGBColor[
              0.5751436787516512, 0.6659665741948753, 0.9596965636934954], 11 -> 
             RGBColor[
              0.23891813183632316`, 0.3684484832174229, 0.9369174062091523], 
             44 -> RGBColor[
              0.49667724948997916`, 0.6022639920478948, 0.9535193989500155], 
             153 -> RGBColor[
              0.24493296406314102`, 0.3747704532501981, 0.9372599420063227], 
             471 -> RGBColor[
              0.8568125830318801, 0.4376919853814662, 0.20203709971295072`], 
             406 -> RGBColor[
              0.990618380894789, 0.9800157372285142, 0.4180546106567104], 32 -> 
             RGBColor[
              0.5357107322431658, 0.6339531317852908, 0.9565922576967049], 
             162 -> RGBColor[
              0.46203141681910903`, 0.5741369443087071, 0.9507919520902978], 
             493 -> RGBColor[
              0.9935772608954081, 0.9886707354308406, 0.5423026688954158], 90 -> 
             RGBColor[
              0.8647697772859632, 0.4788329671240561, 0.2088729261823753], 
             331 -> 
             RGBColor[
              0.8366916950922476, 0.8726192625482565, 0.984285594873034], 8 -> 
             RGBColor[
              0.6202936289377985, 0.7026213377380665, 0.963250933161866], 364 -> 
             RGBColor[
              0.2585666750316088, 0.38910034790526005`, 0.938036361676709], 
             342 -> RGBColor[
              0.25998714329821626`, 0.39059335011635443`, 0.9381172552430979],
              163 -> RGBColor[
              0.26699231078344465`, 0.3979562252966011, 0.9385161891681649], 
             49 -> RGBColor[
              0.49021471545548245`, 0.5970174157848499, 0.9530106445977776], 
             338 -> RGBColor[
              0.32010532781399464`, 0.4516808788160655, 0.9416178063236486], 
             76 -> RGBColor[
              0.4113253016274047, 0.530691035284047, 0.9474302623923834], 369 -> 
             RGBColor[
              0.4199474238450335, 0.5381590841884939, 0.9479796563958474], 
             445 -> RGBColor[
              0.22963931784821143`, 0.3586958614051314, 0.9363889914793045], 
             82 -> RGBColor[
              0.25827862318556116`, 0.3887975871515221, 0.9380199575502111], 
             67 -> RGBColor[
              0.25662307112871396`, 0.38705749697171266`, 0.9379256763097434],
              430 -> RGBColor[
              0.23973902577549727`, 0.36931129479517677`, 0.9369641549045845],
              211 -> RGBColor[
              0.2310404057237692, 0.3601684935964447, 
               0.9364687813610937]}}]]}, 
      TagBox[
       GraphicsGroupBox[
        GraphicsComplexBox[CompressedData["
1:eJw9V3c41W/cPkZ2skfWMY5xzsFxzjFCvnekUipFSBqEZKVlFlIpoUVlJUVG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         "], {{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           Directive[
            Hue[0.63, 0.7, 0.5], 
            Opacity[0.7]], 
           StyleBox[
            LineBox[{1, 54}], {
             RGBColor[
             0.24744314331957223`, 0.3774088108032645, 0.937402893001499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 70}], {
             RGBColor[
             0.26220782647507634`, 0.3929274289346799, 0.9382437198648137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 84}], {
             RGBColor[
             0.249739891419232, 0.3798228386782472, 0.9375336894080404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 131}], {
             RGBColor[
             0.26488726968740706`, 0.3957436936373514, 0.9383963101918749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 135}], {
             RGBColor[
             0.2583961289533292, 0.38892109316374235`, 0.9380266493298512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 147}], {
             RGBColor[
             0.2588293294875211, 0.38937641439167825`, 0.9380513194594108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 170}], {
             RGBColor[
             0.2814230291570491, 0.41312382526764985`, 0.939337997231207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 171}], {
             RGBColor[
             0.2639538573417897, 0.3947626180803467, 0.9383431537396518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 265}], {
             RGBColor[
             0.2935899974663011, 0.4247777732380918, 0.9400724206184119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 266}], {
             RGBColor[
             0.27784311638010406`, 0.40936110995950087`, 0.9391341264945663]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 374}], {
             RGBColor[
             0.25894790578239785`, 0.38950104559576504`, 0.9380580722039861]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 385}], {
             RGBColor[
             0.2498185382943033, 0.379905501530447, 0.937538168231228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 391}], {
             RGBColor[
             0.25364635844324135`, 0.38392878320479584`, 0.9377561569259576]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{1, 433}], {
             RGBColor[
             0.2958358704615542, 0.4267230355457211, 0.940215525659722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 47}], {
             RGBColor[
             0.22219066917343752`, 0.3508668593763409, 0.9359648019565643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 54}], {
             RGBColor[
             0.22058424144202293`, 0.3491784019772233, 0.9358733182737572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 55}], {
             RGBColor[
             0.21196267506411343`, 0.3401165890751596, 0.9353823328229998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 230}], {
             RGBColor[
             0.21816285424353754`, 0.34663337050679954`, 0.9357354238549247]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 242}], {
             RGBColor[
             0.21872765624032725`, 0.34722701321594046`, 0.9357675884930923]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 250}], {
             RGBColor[
             0.20844651025640323`, 0.33642087692453115`, 0.9351820924389003]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 339}], {
             RGBColor[
             0.21206918576719214`, 0.340228538577264, 0.9353883984499716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{2, 365}], {
             RGBColor[
             0.21471117528305686`, 0.3430054370702481, 0.9355388558444269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 8}], {
             RGBColor[
             0.5409798313044035, 0.6382308237734111, 0.9570070604761514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 31}], {
             RGBColor[
             0.4573521482388232, 0.5703305077559329, 0.9504256815919188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 162}], {
             RGBColor[
             0.4618487252450588, 0.5739886270587315, 0.9507775699403673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 203}], {
             RGBColor[
             0.49811633466717364`, 0.6034323062247897, 0.9536326890067068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 221}], {
             RGBColor[
             0.4991380572062573, 0.6042617866100937, 0.9537131227476765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 223}], {
             RGBColor[
             0.4257649092191724, 0.5429712289379067, 0.9484129706530855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 258}], {
             RGBColor[
             0.41754423807969365`, 0.5358508967798354, 0.9478891567573319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 381}], {
             RGBColor[
             0.5154854178683257, 0.6175333104357662, 0.9550000468613498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 439}], {
             RGBColor[
             0.6612892589149015, 0.732886286051436, 0.9686794915733958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{3, 480}], {
             RGBColor[
             0.4076066344287682, 0.5272434439758863, 0.9472559414401728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 29}], {
             RGBColor[
             0.36696197867847585`, 0.49226575471112954`, 0.9446034706830237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 185}], {
             RGBColor[
             0.30412419819916303`, 0.4355457825101565, 0.9406834624888651]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 196}], {
             RGBColor[
             0.31000149085861584`, 0.44172318973711877`, 0.9410181656111457]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 318}], {
             RGBColor[
             0.33312298494508064`, 0.46295611913654056`, 0.9424472799249791]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 321}], {
             RGBColor[
             0.32873955000778277`, 0.45915940811169914`, 0.9421679713268938]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 335}], {
             RGBColor[
             0.3005379095306292, 0.4317763657356928, 0.9404792286546308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 383}], {
             RGBColor[
             0.32662308368104653`, 0.45732623135617084`, 0.9420331119640719]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 479}], {
             RGBColor[
             0.3678971603336924, 0.49307576205728143`, 0.9446630596311456]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 482}], {
             RGBColor[
             0.3413925426988842, 0.4701187944228272, 0.9429742088325687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{4, 496}], {
             RGBColor[
             0.3005965950412318, 0.4318380479282125, 0.9404825707076422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 11}], {
             RGBColor[
             0.23876273655839006`, 0.3682851529276855, 0.9369085566779607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 23}], {
             RGBColor[
             0.23055442452635688`, 0.3596576965449768, 0.9364411054508459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 41}], {
             RGBColor[
             0.23556700835298144`, 0.36492623996293, 0.9367265646843188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 102}], {
             RGBColor[
             0.2575724490549457, 0.3880553533662194, 0.9379797419781635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 186}], {
             RGBColor[
             0.23715887571324926`, 0.36659939348879156`, 0.9368172191755294]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 193}], {
             RGBColor[
             0.263209529621381, 0.3939802824530939, 0.9383007653771087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 202}], {
             RGBColor[
             0.23883220085490312`, 0.3683581643076115, 0.9369125125668838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 211}], {
             RGBColor[
             0.2348238735021131, 0.3641451581171964, 0.9366842442539314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 212}], {
             RGBColor[
             0.22856179646777947`, 0.35756331811549596`, 0.9363276282307389]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 300}], {
             RGBColor[
             0.23228249418787045`, 0.3614740073251723, 0.936539516461619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 414}], {
             RGBColor[
             0.2566326545868817, 0.38706756979387325`, 0.9379262220735086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{5, 485}], {
             RGBColor[
             0.24330426601765148`, 0.37305858833896816`, 0.9371671900620748]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 24}], {
             RGBColor[
             0.8323309168683787, 0.869142096362715, 0.9838696599531287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 77}], {
             RGBColor[
             0.7172538475630181, 0.7785612627115652, 0.9728085302210365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 79}], {
             RGBColor[
             0.9107592672849488, 0.9273249908421985, 0.7765494419084453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 80}], {
             RGBColor[
             0.8086163665159423, 0.8504788015959455, 0.9815424524658205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 81}], {
             RGBColor[
             0.825653983169494, 0.8638180906717614, 0.9832328080563602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 99}], {
             RGBColor[
             0.9106556765920616, 0.9271034208247384, 0.765274234275318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 156}], {
             RGBColor[
             0.6474994925034097, 0.7219315348762902, 0.9673172118721224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 267}], {
             RGBColor[
             0.9083762130299251, 0.9201045780958312, 0.6977188544044266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 278}], {
             RGBColor[
             0.8880267801577246, 0.9132258771339024, 0.9778589426846744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 329}], {
             RGBColor[
             0.8551238518896912, 0.8873165640509703, 0.9860436704429549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 406}], {
             RGBColor[
             0.9091541002347256, 0.9227285742942248, 0.700740799303404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 413}], {
             RGBColor[
             0.9007629224656561, 0.8944231613369187, 0.6681426582115271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{6, 486}], {
             RGBColor[
             0.8813087089314302, 0.9081956582870432, 0.9885412054830938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 28}], {
             RGBColor[
             0.901769090567154, 0.9237583305634441, 0.9644245605513657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 49}], {
             RGBColor[
             0.6644484112533559, 0.7356118894004525, 0.9687430433701605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 69}], {
             RGBColor[
             0.874072307624645, 0.9024255483118935, 0.9878509910664408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 142}], {
             RGBColor[
             0.7691032060058948, 0.819699666861827, 0.9775805727504322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 173}], {
             RGBColor[
             0.9116225315818571, 0.9310453814508525, 0.9449853696775101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 194}], {
             RGBColor[
             0.9125990982944516, 0.9314492168831301, 0.9288011319761822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 241}], {
             RGBColor[
             0.7720821236708154, 0.8220268199822758, 0.9778774834237032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 388}], {
             RGBColor[
             0.8924271040987608, 0.9167910923514154, 0.9802381068620604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 402}], {
             RGBColor[
             0.6954966701641224, 0.7608182646923372, 0.971187276045136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 436}], {
             RGBColor[
             0.6558009604167452, 0.7285914992480711, 0.9680622843636464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 461}], {
             RGBColor[
             0.8915688064008891, 0.9161509753336762, 0.9816909809846657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{7, 487}], {
             RGBColor[
             0.7090567422484308, 0.7718269420846646, 0.9722547745917934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 31}], {
             RGBColor[
             0.5366659458722182, 0.6347210217205881, 0.9566695542776334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 40}], {
             RGBColor[
             0.5032468930597369, 0.6057751178648505, 0.9545401217837302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 114}], {
             RGBColor[
             0.5604860564407306, 0.6540668560845098, 0.9585426619725401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 115}], {
             RGBColor[
             0.7707310045144475, 0.8213000079229384, 0.9777969948316587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 162}], {
             RGBColor[
             0.5411625228784538, 0.6383791410233868, 0.9570214426260819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 203}], {
             RGBColor[
             0.5774301323005686, 0.6678228201894449, 0.9598765616924215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 221}], {
             RGBColor[
             0.5784518548396522, 0.6686523005747489, 0.9599569954333912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 258}], {
             RGBColor[
             0.4968580357130886, 0.6002414107444907, 0.9541330294430466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 289}], {
             RGBColor[
             0.5298323406094952, 0.6288020963090049, 0.9562341229930127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 291}], {
             RGBColor[
             0.637610384777719, 0.7164873323549865, 0.9647458039813404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 297}], {
             RGBColor[
             0.5698289191235334, 0.6616518129015765, 0.9592781663469641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 311}], {
             RGBColor[
             0.6835752486050087, 0.752395433322769, 0.9693271520415703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 381}], {
             RGBColor[
             0.5947992155017207, 0.6819238244004215, 0.9612439195470645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 419}], {
             RGBColor[
             0.5664920822105015, 0.6589428183727875, 0.9590154783219338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{8, 439}], {
             RGBColor[
             0.7406030565482964, 0.7972768000160912, 0.9749233642591105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 19}], {
             RGBColor[
             0.5674341026863339, 0.6597075930326068, 0.9590896376245259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 26}], {
             RGBColor[
             0.4808866078491948, 0.5876336896788764, 0.952776616899017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 34}], {
             RGBColor[
             0.559448373541096, 0.6532244183595045, 0.9584609717735231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 44}], {
             RGBColor[
             0.5359104641208152, 0.634115283121385, 0.9566079813217554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 106}], {
             RGBColor[
             0.5464995084832656, 0.6427119463658346, 0.9574415896829152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 117}], {
             RGBColor[
             0.4781094761010015, 0.5852282777412916, 0.9525996605197433]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 139}], {
             RGBColor[
             0.5695894293133013, 0.6614573842847371, 0.9592593128318224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 247}], {
             RGBColor[
             0.5350775301382318, 0.6334390697910756, 0.9565424097075088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 269}], {
             RGBColor[
             0.512041509774998, 0.614618499836106, 0.9547617797005311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 360}], {
             RGBColor[
             0.5772550006439877, 0.6676806404210414, 0.9598627746868871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 425}], {
             RGBColor[
             0.47524326414852586`, 0.5827457090080587, 0.9524170280286233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 466}], {
             RGBColor[
             0.5393259259475076, 0.6368881088970959, 0.9568768589880016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{9, 468}], {
             RGBColor[
             0.5267603512092651, 0.6266868092518996, 0.9558876509153902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 120}], {
             RGBColor[
             0.21319195993880496`, 0.3414086454196232, 0.9354523387780493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 123}], {
             RGBColor[
             0.21296296597852177`, 0.34116795824830987`, 0.9354392979107774]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 125}], {
             RGBColor[
             0.21381800062875955`, 0.3420666538780378, 0.935487990869198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 177}], {
             RGBColor[
             0.21382948684753797`, 0.34207872662224226`, 0.9354886449923652]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 245}], {
             RGBColor[
             0.22026264269435236`, 0.3488403813028832, 0.93585500370084]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 438}], {
             RGBColor[
             0.22021348611856342`, 0.3487887146250221, 0.9358522043065695]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{10, 455}], {
             RGBColor[
             0.21145152724630215`, 0.3395793403099965, 0.9353532237109508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 23}], {
             RGBColor[
             0.23070981980428998`, 0.3598210268347142, 0.9364499549820375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 41}], {
             RGBColor[
             0.23572240363091454`, 0.3650895702526674, 0.9367354142155104]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 102}], {
             RGBColor[
             0.2577278443328788, 0.3882186836559568, 0.9379885915093551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 186}], {
             RGBColor[
             0.23731427099118235`, 0.3667627237785289, 0.936826068706721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 193}], {
             RGBColor[
             0.2633649248993141, 0.3941436127428313, 0.9383096149083003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 202}], {
             RGBColor[
             0.2389875961328362, 0.3685214945973489, 0.9369213620980754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 211}], {
             RGBColor[
             0.23497926878004616`, 0.3643084884069338, 0.936693093785123]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 414}], {
             RGBColor[
             0.25678804986481485`, 0.38723090008361066`, 0.9379350716047002]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 485}], {
             RGBColor[
             0.24345966129558455`, 0.3732219186287056, 0.9371760395932665]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{11, 497}], {
             RGBColor[
             0.2374558873234022, 0.36691157152268605`, 0.9368341335473384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 198}], {
             RGBColor[
             0.2771414265920781, 0.4086235895025834, 0.9390941662991953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 373}], {
             RGBColor[
             0.28300945147034123`, 0.414791255703904, 0.9394283416350475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{12, 480}], {
             RGBColor[
             0.31297532312712917`, 0.4421451064609878, 0.9412865192071291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 154}], {
             RGBColor[
             0.3030787322552839, 0.435811820273263, 0.9405739494865415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 229}], {
             RGBColor[
             0.2937960299949141, 0.4261286336418093, 0.9400426213247091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 244}], {
             RGBColor[
             0.3195286449146627, 0.4500599078221664, 0.9416221233751105]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 313}], {
             RGBColor[
             0.2817870779153078, 0.4135064635946042, 0.939358729269428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 334}], {
             RGBColor[
             0.3497101697631252, 0.47620162767835794`, 0.94354526344998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 338}], {
             RGBColor[
             0.30836079438708164`, 0.4403868770076641, 0.9409105178148355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 340}], {
             RGBColor[
             0.3170254114231826, 0.44789173278801986`, 0.9414626195505558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 363}], {
             RGBColor[
             0.3507138092232281, 0.4770709297343131, 0.9436092144688942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 379}], {
             RGBColor[
             0.3029577301181068, 0.43570701430378433`, 0.9405662393373586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 380}], {
             RGBColor[
             0.28473366122711574`, 0.4166035094794867, 0.939526532829956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 390}], {
             RGBColor[
             0.29868486413343276`, 0.4312671082913797, 0.9403210331965157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{13, 478}], {
             RGBColor[
             0.28132910192119526`, 0.41302510178743673`, 0.939332648214078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 63}], {
             RGBColor[
             0.3630391373968948, 0.48868276614576933`, 0.9443602925394342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 72}], {
             RGBColor[
             0.2803635687690008, 0.4120102652261427, 0.9392776625294388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 75}], {
             RGBColor[
             0.32584559541094904`, 0.45646758947931865`, 0.9419903529330476]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 149}], {
             RGBColor[
             0.33030872638618497`, 0.46033332920658265`, 0.9422747396921978]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 158}], {
             RGBColor[
             0.33213200521333075`, 0.4619125616859979, 0.9423909174068014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 163}], {
             RGBColor[
             0.2868674954285888, 0.4188463045181374, 0.9396480515310051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 182}], {
             RGBColor[
             0.34266467028924463`, 0.47103542678761523`, 0.9430620495117685]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 187}], {
             RGBColor[
             0.28568538812664784`, 0.41760383479386565`, 0.9395807322689307]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 279}], {
             RGBColor[
             0.2926514518650601, 0.4249256094568878, 0.9399774392934654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 322}], {
             RGBColor[
             0.2829806146027809, 0.4147609463277351, 0.9394266994181002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 324}], {
             RGBColor[
             0.33821006500838097`, 0.4671770715883025, 0.9427782060023248]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 441}], {
             RGBColor[
             0.3784375409652084, 0.5020200893703757, 0.9453414651985335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{14, 494}], {
             RGBColor[
             0.2826231066390982, 0.4143851827905905, 0.9394063398684542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 78}], {
             RGBColor[
             0.22683394628673456`, 0.35574723802318886`, 0.9362292297190538]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 97}], {
             RGBColor[
             0.23298665056537604`, 0.36221412032402367`, 0.936579617125612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 104}], {
             RGBColor[
             0.24040623048550225`, 0.3700125692486139, 0.9370021512257783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 112}], {
             RGBColor[
             0.24125115959042637`, 0.3709006433094886, 0.9370502686883432]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 148}], {
             RGBColor[
             0.2369473179686802, 0.36637703288571377`, 0.9368051712749479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 153}], {
             RGBColor[
             0.23958587882071014`, 0.3691503276356177, 0.93695543341207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 190}], {
             RGBColor[
             0.24117420601353035`, 0.37081976022103225`, 0.9370458862959816]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 323}], {
             RGBColor[
             0.2367917298527569, 0.36621349991102203`, 0.936796310761918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 356}], {
             RGBColor[
             0.2517883622305454, 0.38197591138148856`, 0.9376503467903037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 408}], {
             RGBColor[
             0.22837166352845595`, 0.3573634763411423, 0.9363168004411209]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 430}], {
             RGBColor[
             0.23698890967688827`, 0.36642074840810707`, 0.9368075398612009]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{15, 452}], {
             RGBColor[
             0.22909610908040262`, 0.3581249145487392, 0.9363580565435832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 39}], {
             RGBColor[
             0.5137718344766236, 0.6147998451486828, 0.9552360290912556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 45}], {
             RGBColor[
             0.343332276555383, 0.46939838880724916`, 0.9431857012274175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 52}], {
             RGBColor[
             0.6198385630520318, 0.4001930339226935, 0.5644333341255259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 56}], {
             RGBColor[
             0.6202778449645745, 0.4035695471970573, 0.5648539909810746]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 179}], {
             RGBColor[
             0.29140560923354364`, 0.4148201691111312, 0.940228554342059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 200}], {
             RGBColor[
             0.6523550443789783, 0.5834045301394526, 0.5929583920999518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 236}], {
             RGBColor[
             0.34560261915581325`, 0.4717846628283363, 0.9433149938798411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 243}], {
             RGBColor[
             0.6215940953786275, 0.41368682466407874`, 0.566114433864064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 254}], {
             RGBColor[
             0.3201901654275895, 0.4450745627173458, 0.941867792234375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 276}], {
             RGBColor[
             0.5117111188744836, 0.6131268633886855, 0.9550738020104051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 283}], {
             RGBColor[
             0.29254812031783006`, 0.4160210207001029, 0.9402936186581154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 292}], {
             RGBColor[
             0.29142635679170903`, 0.41484197611023416`, 0.9402297358848033]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 422}], {
             RGBColor[
             0.3189470428658002, 0.4437679620863825, 0.9417969982435161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{16, 454}], {
             RGBColor[
             0.6518822537994468, 0.581257698540845, 0.5925638840512331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 205}], {
             RGBColor[
             0.9368989095333399, 0.9481665884975428, 0.7789256469520753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 252}], {
             RGBColor[
             0.8078836333626171, 0.8503289562761027, 0.9813572830192461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 282}], {
             RGBColor[
             0.7438148228852721, 0.7997463454963281, 0.9753349394405884]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 293}], {
             RGBColor[
             0.9171217844286204, 0.9362730779745756, 0.9753514321588153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 298}], {
             RGBColor[
             0.8908055349705915, 0.9157681695861948, 0.9894470212286257]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 418}], {
             RGBColor[
             0.9292223734187801, 0.9452976774305406, 0.9548682913375369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 432}], {
             RGBColor[
             0.8892978625365586, 0.9145659925119751, 0.9893032180859526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{17, 467}], {
             RGBColor[
             0.7934052123801664, 0.8390183037645371, 0.979914209324252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 52}], {
             RGBColor[
             0.8600894824934477, 0.42201909265360843`, 0.20357506457964797`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 56}], {
             RGBColor[
             0.8605287644059905, 0.4253956059279722, 0.2039957214351967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 65}], {
             RGBColor[
             0.9349243740088637, 0.7652639008938271, 0.3116367388337401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 88}], {
             RGBColor[
             0.8754970234499582, 0.5275428865427625, 0.2178240033304778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 166}], {
             RGBColor[
             0.8612521660936727, 0.43095598829613885`, 0.2046884517082866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 167}], {
             RGBColor[
             0.9355270875213144, 0.7783260157628717, 0.5479056765432442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 210}], {
             RGBColor[
             0.8602238171594843, 0.4230516477625904, 0.20370370360755374`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 227}], {
             RGBColor[
             0.8650075437066738, 0.45982146624662823`, 0.2082846055515888]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 243}], {
             RGBColor[
             0.8618450148200435, 0.43551288339499367`, 0.2052561643181862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 326}], {
             RGBColor[
             0.8797797158009789, 0.5469895922605361, 0.22139758680656518`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 348}], {
             RGBColor[
             0.9221477650002106, 0.7221653986171828, 0.2620020254952798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 428}], {
             RGBColor[
             0.8573587081531882, 0.40102916444142644`, 0.2009600719874468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 434}], {
             RGBColor[
             0.9377932493402739, 0.7792631319127137, 0.510349510564296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 469}], {
             RGBColor[
             0.8724072991337889, 0.5135131700464854, 0.21524586162499276`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 474}], {
             RGBColor[
             0.9387405372806834, 0.7796548598202627, 0.49465049788910304`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{18, 495}], {
             RGBColor[
             0.8632931958328989, 0.4466442372567656, 0.2066429440915829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 26}], {
             RGBColor[
             0.4731770317838775, 0.5813747085166081, 0.9521696908300475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 34}], {
             RGBColor[
             0.5517387974757788, 0.6469654371972362, 0.9578540457045537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 44}], {
             RGBColor[
             0.5282008880554978, 0.6278563019591167, 0.956001055252786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 139}], {
             RGBColor[
             0.5618798532479841, 0.6551984031224687, 0.9586523867628529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 234}], {
             RGBColor[
             0.474151584993228, 0.582218817524079, 0.9522317884987839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 247}], {
             RGBColor[
             0.5273679540729146, 0.6271800886288073, 0.9559354836385393]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 269}], {
             RGBColor[
             0.5043319337096805, 0.6083595186738375, 0.9541548536315616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 360}], {
             RGBColor[
             0.5695454245786704, 0.661421659258773, 0.9592558486179177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 393}], {
             RGBColor[
             0.5104680056398668, 0.6134599491568583, 0.954605057791339]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 466}], {
             RGBColor[
             0.5316163498821903, 0.6306291277348275, 0.9562699329190321]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{19, 468}], {
             RGBColor[
             0.5190507751439478, 0.6204278280896312, 0.9552807248464208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 62}], {
             RGBColor[
             0.8509265138034974, 0.3513524058869604, 0.19479135055817565`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 194}], {
             RGBColor[
             0.9355250585723344, 0.7786349412620628, 0.5492457614630861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 228}], {
             RGBColor[
             0.9388076655030091, 0.7780938721344945, 0.3568427286125849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 388}], {
             RGBColor[
             0.9153530643766437, 0.7639768167303482, 0.6006827363489642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{20, 490}], {
             RGBColor[
             0.9375437932423437, 0.7794697399272263, 0.5157901036631747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 33}], {
             RGBColor[
             0.9296510090196749, 0.7439907144053559, 0.3002556094938443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 65}], {
             RGBColor[
             0.9831762967586118, 0.9549118399527363, 0.38914351910732653`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 119}], {
             RGBColor[
             0.9857675700825197, 0.9687962754074746, 0.5924568745131584]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 164}], {
             RGBColor[
             0.8992062375406565, 0.5414501296947882, 0.27233399794458657`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 166}], {
             RGBColor[
             0.9095040888434207, 0.6206039273550481, 0.282195231981873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 175}], {
             RGBColor[
             0.9683090151158134, 0.9568481859192783, 0.670037151361724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 227}], {
             RGBColor[
             0.9132594664564218, 0.6494694053055374, 0.28579138582517527`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 309}], {
             RGBColor[
             0.9869592653755547, 0.967346961753188, 0.4315364838739727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 320}], {
             RGBColor[
             0.9847451317139568, 0.9683734708666063, 0.6094013242659239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 337}], {
             RGBColor[
             0.9205492329643337, 0.9192823831910986, 0.6833909335036439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 348}], {
             RGBColor[
             0.9703996877499586, 0.911813337676092, 0.3395088057688662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 375}], {
             RGBColor[
             0.9695446020803578, 0.9577696846543478, 0.6679456249234423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 428}], {
             RGBColor[
             0.9056106309029361, 0.5906771035003356, 0.2784668522610333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{21, 489}], {
             RGBColor[
             0.9854926800563032, 0.9686826013172827, 0.5970125136401502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 63}], {
             RGBColor[
             0.4353760609281416, 0.5515225941640346, 0.948962755507775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 149}], {
             RGBColor[
             0.40264564991743174`, 0.5231731572248479, 0.9468772026605385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 160}], {
             RGBColor[
             0.4369491379476227, 0.5528851144131592, 0.949062990584439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 165}], {
             RGBColor[
             0.4377248912958056, 0.5535570329728583, 0.9491124209018134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 182}], {
             RGBColor[
             0.4150015938204914, 0.5338752548058805, 0.9476645124801093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 268}], {
             RGBColor[
             0.4305356531895016, 0.5473300762667914, 0.9486543290068734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 275}], {
             RGBColor[
             0.43256024452096153`, 0.549083675519183, 0.9487833341762382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 282}], {
             RGBColor[
             0.5295374583805197, 0.6288897605144723, 0.956120540334634]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 285}], {
             RGBColor[
             0.38291743430858444`, 0.506085568433412, 0.9456201382069189]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 324}], {
             RGBColor[
             0.41054698853962773`, 0.5300168996065678, 0.9473806689706655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 353}], {
             RGBColor[
             0.5455395337034719, 0.641880966146923, 0.9573802823215901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 441}], {
             RGBColor[
             0.45077446449645514`, 0.564859917388641, 0.9499439281668742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{22, 481}], {
             RGBColor[
             0.38481661217346425`, 0.507730540844516, 0.9457411521410921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 41}], {
             RGBColor[
             0.22751409159888136`, 0.35646211386995863`, 0.9362679629883957]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 186}], {
             RGBColor[
             0.22910595895914918`, 0.35813526739582024`, 0.9363586174796061]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 202}], {
             RGBColor[
             0.23077928410080303`, 0.35989403821464017`, 0.9364539108709606]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 211}], {
             RGBColor[
             0.226770956748013, 0.3556810320242251, 0.9362256425580082]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 212}], {
             RGBColor[
             0.22050887971367938`, 0.3490991920225246, 0.9358690265348157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 485}], {
             RGBColor[
             0.2352513492635514, 0.3645944622459968, 0.9367085883661517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{23, 497}], {
             RGBColor[
             0.22924757529136902`, 0.3582841151399774, 0.9363666823202235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 77}], {
             RGBColor[
             0.7218949448567346, 0.7822619477143448, 0.9732512022240677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 81}], {
             RGBColor[
             0.8302950804632105, 0.8675187756745408, 0.9836754800593912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 83}], {
             RGBColor[
             0.878858858195596, 0.9062422138097157, 0.9883075365329024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 176}], {
             RGBColor[
             0.7219583100603643, 0.7823133904412213, 0.9732561905650118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 197}], {
             RGBColor[
             0.7672988184851579, 0.8182762435725834, 0.9774043962108645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 237}], {
             RGBColor[
             0.871532203465174, 0.9004001382044219, 0.9876087136641327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 267}], {
             RGBColor[
             0.9130173103236416, 0.9238052630986108, 0.6981615264074577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 270}], {
             RGBColor[
             0.9134975511433701, 0.9314925430785823, 0.899659555679228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 278}], {
             RGBColor[
             0.8926678774514412, 0.9169265621366819, 0.9783016146877055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 329}], {
             RGBColor[
             0.8597649491834076, 0.8910172490537498, 0.986486342445986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 426}], {
             RGBColor[
             0.8535732035252862, 0.8860801191364223, 0.9858957682176778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 448}], {
             RGBColor[
             0.7024556642269519, 0.7664802639694746, 0.97172087084446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{24, 489}], {
             RGBColor[
             0.9135348042436461, 0.9315079481929074, 0.8990421753997224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 76}], {
             RGBColor[
             0.36235029179287925`, 0.48827134332094824`, 0.9443096180726283]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 96}], {
             RGBColor[
             0.3047685081778331, 0.4372333951604509, 0.9406831592217764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 157}], {
             RGBColor[
             0.3079594456965586, 0.4405872728097553, 0.9408648783928987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 180}], {
             RGBColor[
             0.2917531123703574, 0.42355338894303707`, 0.9399419516850931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 246}], {
             RGBColor[
             0.3037983452782409, 0.43621369244109887`, 0.940627909879872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 288}], {
             RGBColor[
             0.2847205959795895, 0.4161617683290476, 0.9395414602803146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 333}], {
             RGBColor[
             0.34601220845973285`, 0.4741201167137219, 0.94326856984984]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 343}], {
             RGBColor[
             0.3031313951145783, 0.4355126855320067, 0.9405899280547156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 392}], {
             RGBColor[
             0.3096883372024623, 0.4424044474005129, 0.9409633362064942]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 459}], {
             RGBColor[
             0.35196069990557133`, 0.47927240102423385`, 0.9436476024647243]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 465}], {
             RGBColor[
             0.2980004320712376, 0.430119718051609, 0.9402977272999771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{25, 492}], {
             RGBColor[
             0.29499729755319337`, 0.42696323326341856`, 0.9401267032319138]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 34}], {
             RGBColor[
             0.46519130263863967`, 0.5748915338435057, 0.9515410249790447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 44}], {
             RGBColor[
             0.4416533932183588, 0.5557823986053863, 0.949688034527277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 106}], {
             RGBColor[
             0.45224243758080923`, 0.5643790618498358, 0.9505216428884367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 117}], {
             RGBColor[
             0.38385240519854513`, 0.5068953932252928, 0.9456797137252648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 139}], {
             RGBColor[
             0.4753323584108449, 0.5831244997687381, 0.952339366037344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 215}], {
             RGBColor[
             0.33537631974199883`, 0.4626312893738342, 0.942674216260174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 224}], {
             RGBColor[
             0.34279791451999597`, 0.4704318560417961, 0.9430968651035153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 247}], {
             RGBColor[
             0.44082045923577545`, 0.5551061852750767, 0.9496224629130303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 269}], {
             RGBColor[
             0.4177844388725415, 0.5362856153201071, 0.9478418329060527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 351}], {
             RGBColor[
             0.3383374936256977, 0.4657436708748698, 0.9428428507321864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 360}], {
             RGBColor[
             0.48299792974153133`, 0.5893477559050426, 0.9529428278924086]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 425}], {
             RGBColor[
             0.38098619324606947`, 0.5044128244920598, 0.9454970812341448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 466}], {
             RGBColor[
             0.4450688550450512, 0.558555224381097, 0.9499569121935232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{26, 468}], {
             RGBColor[
             0.43250328030680874`, 0.5483539247359007, 0.9489677041209118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 40}], {
             RGBColor[
             0.44915953688308596`, 0.5618645655130168, 0.9502821669769903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 114}], {
             RGBColor[
             0.5063987002640795, 0.610156303732676, 0.9542847071658003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 199}], {
             RGBColor[
             0.4274813973658525, 0.5430880506381621, 0.9489008550961784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 220}], {
             RGBColor[
             0.4255160611016982, 0.5413857751468245, 0.948775625607305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 277}], {
             RGBColor[
             0.6417102241932708, 0.7180330594388474, 0.9662874050409727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 289}], {
             RGBColor[
             0.47574498443284424`, 0.5848915439571711, 0.9519761681862727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 291}], {
             RGBColor[
             0.583523028601068, 0.6725767800031528, 0.9604878491746004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 297}], {
             RGBColor[
             0.5157415629468824, 0.6177412605497428, 0.9550202115402241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 311}], {
             RGBColor[
             0.6294878924283578, 0.7084848809709354, 0.9650691972348303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 319}], {
             RGBColor[
             0.6135043005796454, 0.695998377538924, 0.9634761021745089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 349}], {
             RGBColor[
             0.46286019331944683`, 0.5737313855031778, 0.9511551606901004]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 359}], {
             RGBColor[
             0.44878508964320496`, 0.5615402381340974, 0.9502583075299758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 371}], {
             RGBColor[
             0.43753141765926407`, 0.551792873087608, 0.9495412335023905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 419}], {
             RGBColor[
             0.5124047260338506, 0.6150322660209537, 0.9547575235151939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{27, 488}], {
             RGBColor[
             0.640741608541348, 0.7172763695298137, 0.9661908624850168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 69}], {
             RGBColor[
             0.9371592911405698, 0.9519775158592825, 0.9678001094752631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 142}], {
             RGBColor[
             0.8321901895218196, 0.869251634409216, 0.9575296911592543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 173}], {
             RGBColor[
             0.9747095150977819, 0.9805973489982415, 0.9249344880863324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 194}], {
             RGBColor[
             0.9756860818103763, 0.9810011844305191, 0.9087502503850045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 241}], {
             RGBColor[
             0.8351691071867402, 0.8715787875296648, 0.9578266018325254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 417}], {
             RGBColor[
             0.8329443683967894, 0.8698408046783143, 0.9576048606613091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 461}], {
             RGBColor[
             0.954655789916814, 0.9657029428810652, 0.9616400993934879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{28, 493}], {
             RGBColor[
             0.9792166674892435, 0.9809905167708368, 0.7433381739278018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 77}], {
             RGBColor[
             0.5082190929851442, 0.6104476858288989, 0.9547558471761093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 172}], {
             RGBColor[
             0.3806363827099919, 0.5041098361876981, 0.9454747916161113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 318}], {
             RGBColor[
             0.37578131668551923`, 0.4999046220200136, 0.9451654311021982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 321}], {
             RGBColor[
             0.3713978817482214, 0.49610791099517215`, 0.944886122504113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 383}], {
             RGBColor[
             0.3692814154214852, 0.49427473423964385`, 0.944751263141291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 479}], {
             RGBColor[
             0.410555492074131, 0.5300242649407545, 0.9473812108083647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{29, 482}], {
             RGBColor[
             0.38405087443932273`, 0.5070672973063002, 0.9456923600097877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 43}], {
             RGBColor[
             0.2805395184040802, 0.4121951994484624, 0.9392876826008625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 64}], {
             RGBColor[
             0.27788283656739987`, 0.4094028583947541, 0.9391363885004721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 110}], {
             RGBColor[
             0.26982326266389456`, 0.40093173521567016`, 0.9386774076897386]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 217}], {
             RGBColor[
             0.2938254921740675, 0.42514500116830317`, 0.9400814485951139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 290}], {
             RGBColor[
             0.2772082322816696, 0.40869380651806936`, 0.9390979707843874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 316}], {
             RGBColor[
             0.25921313179459604`, 0.3897798149508858, 0.938073176433014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 355}], {
             RGBColor[
             0.29831901354920054`, 0.4290370635324922, 0.9403677718036725]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 378}], {
             RGBColor[
             0.2755078252460146, 0.406906570911563, 0.9390011351192336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{30, 384}], {
             RGBColor[
             0.2758760121335012, 0.4072935586747084, 0.9390221028177923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 40}], {
             RGBColor[
             0.4196192099941566, 0.5378748018473721, 0.9479587428994976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 114}], {
             RGBColor[
             0.47685837337515014`, 0.5861665400670314, 0.9519612830883075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 162}], {
             RGBColor[
             0.4575348398128734, 0.5704788250059085, 0.9504400637418493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 203}], {
             RGBColor[
             0.4938024492349883, 0.5999225041719667, 0.9532951828081889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 208}], {
             RGBColor[
             0.38757839390763205`, 0.5101226573714661, 0.9459171304310454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 221}], {
             RGBColor[
             0.4948241717740719, 0.6007519845572706, 0.9533756165491586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 223}], {
             RGBColor[
             0.42145102378698707`, 0.5394614268850837, 0.9480754644545675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 258}], {
             RGBColor[
             0.4132303526475083, 0.5323410947270124, 0.947551650558814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 289}], {
             RGBColor[
             0.4462046575439149, 0.5609017802915265, 0.9496527441087801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 297}], {
             RGBColor[
             0.48620123605795307`, 0.5937514968840982, 0.9526967874627315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 314}], {
             RGBColor[
             0.3915568678230763, 0.5135686115131106, 0.9461706352709112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 381}], {
             RGBColor[
             0.5111715324361403, 0.6140235083829432, 0.9546625406628318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 397}], {
             RGBColor[
             0.40579315804314603`, 0.5258993705649835, 0.947077759095077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 419}], {
             RGBColor[
             0.4828643991449212, 0.5910425023553091, 0.9524340994377012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{31, 472}], {
             RGBColor[
             0.39074248974700837`, 0.5128632381554529, 0.9461187438200305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 103}], {
             RGBColor[
             0.5080332189208779, 0.6114832796124914, 0.9544133824619024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 155}], {
             RGBColor[
             0.5507999265063706, 0.6462032194486154, 0.9577801343426442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 331}], {
             RGBColor[
             0.6862012136677067, 0.7532861971667737, 0.9704389262848694]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 344}], {
             RGBColor[
             0.49972685632516956`, 0.6047398002599247, 0.9537594751711596]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 403}], {
             RGBColor[
             0.73231135392298, 0.7900531713799142, 0.9748369526254256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{32, 449}], {
             RGBColor[
             0.6320067542390264, 0.7108140314884382, 0.9650731650607731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 119}], {
             RGBColor[
             0.9345308133147854, 0.7655949021985857, 0.5124594755699873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 159}], {
             RGBColor[
             0.8495822086293704, 0.3506448894924134, 0.19388094901806585`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 164}], {
             RGBColor[
             0.8479694807729221, 0.33824875648589925`, 0.19233659900141542`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 227}], {
             RGBColor[
             0.8620227096886874, 0.44626803209664856`, 0.20579398688200412`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 267}], {
             RGBColor[
             0.9337384293685642, 0.7577785430140971, 0.3161344657047144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 270}], {
             RGBColor[
             0.9342186701882929, 0.7654658229940685, 0.5176324949764846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 309}], {
             RGBColor[
             0.9357225086078202, 0.7641455885442991, 0.35153908493080155`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 443}], {
             RGBColor[
             0.9064631162110222, 0.6594290978497701, 0.24321160823769428`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{33, 489}], {
             RGBColor[
             0.9342559232885688, 0.7654812281083937, 0.517015114696979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 234}], {
             RGBColor[
             0.4661658558479902, 0.5757356428509766, 0.951603122647781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 269}], {
             RGBColor[
             0.4963462045644428, 0.6018763440007352, 0.9535261877805588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 332}], {
             RGBColor[
             0.47297256082386624`, 0.5816312685861409, 0.9520368398699108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 360}], {
             RGBColor[
             0.5615596954334325, 0.6549384845856707, 0.9586271827669148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 393}], {
             RGBColor[
             0.5024822764946291, 0.606976774483756, 0.9539763919403361]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{34, 468}], {
             RGBColor[
             0.51106504599871, 0.6139446534165288, 0.9546520589954179]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 54}], {
             RGBColor[
             0.23354661261843296`, 0.36280267594543125`, 0.936611506136144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 67}], {
             RGBColor[
             0.24749774961125026`, 0.377466205478057, 0.9374060027490273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 70}], {
             RGBColor[
             0.24831129577393707`, 0.37832129407684667`, 0.9374523329994586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 84}], {
             RGBColor[
             0.2358433607180927, 0.36521670382041393`, 0.9367423025426853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 131}], {
             RGBColor[
             0.2509907389862678, 0.38113755877951816`, 0.9376049233265198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 135}], {
             RGBColor[
             0.24449959825218992`, 0.3743149583059091, 0.9372352624644963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 147}], {
             RGBColor[
             0.2449327987863818, 0.374770279533845, 0.9372599325940558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 171}], {
             RGBColor[
             0.25005732664065045`, 0.38015648322251344`, 0.9375517668742968]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 216}], {
             RGBColor[
             0.25212920477180323`, 0.3823341585030158, 0.9376697572687969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 281}], {
             RGBColor[
             0.2416405448941051, 0.37130991195210916`, 0.9370724436053437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 385}], {
             RGBColor[
             0.235922007593164, 0.36529936667261376`, 0.936746781365873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{35, 391}], {
             RGBColor[
             0.23974982774210207`, 0.3693226483469626, 0.9369647700606025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 37}], {
             RGBColor[
             0.2800147441029785, 0.41164362838539204`, 0.9392577974807488]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 58}], {
             RGBColor[
             0.28475051663686596`, 0.4160326690739975, 0.9395490426575464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 141}], {
             RGBColor[
             0.28198608489330845`, 0.4136382572421074, 0.9393728955113378]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 240}], {
             RGBColor[
             0.25550742159800177`, 0.3858848785786683, 0.9378621417194251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 251}], {
             RGBColor[
             0.25646724614478844`, 0.3868937150337323, 0.9379168023074314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 310}], {
             RGBColor[
             0.2755731801551128, 0.4069752630647657, 0.9390048569846228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 352}], {
             RGBColor[
             0.2411100918235177, 0.37075237214225454`, 0.9370422350877088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 367}], {
             RGBColor[
             0.2421171751521342, 0.3718108805734015, 0.9370995869934273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 382}], {
             RGBColor[
             0.26830699274776615`, 0.39933803939675394`, 0.9385910583611354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 399}], {
             RGBColor[
             0.24794512185068096`, 0.37793642206673694`, 0.937431479936235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 412}], {
             RGBColor[
             0.24838538806776134`, 0.3783991697753788, 0.9374565524459821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 416}], {
             RGBColor[
             0.2579614870777197, 0.3884642569945902, 0.9380018971180304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{36, 429}], {
             RGBColor[
             0.2739936283843697, 0.4053150540043482, 0.9389149038480165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 58}], {
             RGBColor[
             0.31037597127891847`, 0.44296664665046, 0.9410083743899482]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 118}], {
             RGBColor[
             0.31537415178862416`, 0.44729581939211016`, 0.9413268540323092]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 141}], {
             RGBColor[
             0.3076115395353609, 0.4405722348185699, 0.9408322272437397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 188}], {
             RGBColor[
             0.3214586719550145, 0.4525659249433619, 0.9417145542769817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 240}], {
             RGBColor[
             0.28113287624005423`, 0.4128188561551308, 0.9393214734518269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 304}], {
             RGBColor[
             0.32210212279026273`, 0.45312324971607465`, 0.9417555543952225]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 310}], {
             RGBColor[
             0.30119863479716524`, 0.4339092406412282, 0.9404641887170249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{37, 429}], {
             RGBColor[
             0.29961908302642226`, 0.4322490315808106, 0.9403742355804184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 47}], {
             RGBColor[
             0.24595116399713765`, 0.375840645938433, 0.9373179269862719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 73}], {
             RGBColor[
             0.25393957190424143`, 0.3842369691431141, 0.937772854998791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 93}], {
             RGBColor[
             0.2646269773927557, 0.3954701099321881, 0.9383814869307624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 108}], {
             RGBColor[
             0.272539685244709, 0.40378686757924537`, 0.9388321039371288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 163}], {
             RGBColor[
             0.2634804930859057, 0.3942650822343853, 0.9383161963455589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 189}], {
             RGBColor[
             0.2598720197723208, 0.3904723479913851, 0.9381106991286081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 266}], {
             RGBColor[
             0.27474470932625494`, 0.40610448769555174`, 0.9389576767965321]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 364}], {
             RGBColor[
             0.2592676752099878, 0.3898371435387148, 0.9380762825998308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{38, 437}], {
             RGBColor[
             0.2578995688543769, 0.3883991770160148, 0.9379983709668107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 45}], {
             RGBColor[
             0.45322202962692537`, 0.5599541419213354, 0.9514657433370749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 100}], {
             RGBColor[
             0.7774382200691679, 0.7351762203070193, 0.6135140654406412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 127}], {
             RGBColor[
             0.4248206994263658, 0.5301025431322064, 0.9498483295981558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 179}], {
             RGBColor[
             0.40129536230508595`, 0.5053759222252174, 0.9485085964517164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 200}], {
             RGBColor[
             0.7622447974505207, 0.6739602832535388, 0.6012384342096092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 213}], {
             RGBColor[
             0.7639337426080279, 0.681629388750616, 0.6026477314488674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 236}], {
             RGBColor[
             0.4554923722273556, 0.5623404159424226, 0.9515950359894985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 243}], {
             RGBColor[
             0.7314838484501698, 0.504242577778165, 0.5743944759737214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 254}], {
             RGBColor[
             0.43007991849913185`, 0.5356303158314321, 0.9501478343440324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 276}], {
             RGBColor[
             0.6216008719460259, 0.7036826165027719, 0.9633538441200625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 283}], {
             RGBColor[
             0.4024378733893724, 0.5065767738141891, 0.9485736607677728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 315}], {
             RGBColor[
             0.40458060190845924`, 0.5088289173445842, 0.948695685987052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 325}], {
             RGBColor[
             0.40133925395865816`, 0.5054220551360133, 0.9485110960164554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 368}], {
             RGBColor[
             0.5158816187650146, 0.6166272342584453, 0.9553704626805029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 401}], {
             RGBColor[
             0.6985569826136641, 0.7641508706261513, 0.9707851169753527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 450}], {
             RGBColor[
             0.7206850354992045, 0.4212381693670362, 0.5640535204963621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 454}], {
             RGBColor[
             0.761772006870989, 0.6718134516549312, 0.6008439261608904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 471}], {
             RGBColor[
             0.7402370852900231, 0.5715237918221177, 0.5827765854569318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{39, 475}], {
             RGBColor[
             0.731332489294519, 0.5030791649818271, 0.5742495342753344]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 114}], {
             RGBColor[
             0.443439320562669, 0.5572206362112937, 0.9498318505944043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 199}], {
             RGBColor[
             0.3645220176644419, 0.4901523831167798, 0.9444479985247825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 208}], {
             RGBColor[
             0.3541593410951509, 0.4811767535157284, 0.9437876979371422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 220}], {
             RGBColor[
             0.36255668140028763`, 0.48845010762544216`, 0.9443227690359091]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 289}], {
             RGBColor[
             0.41278560473143366`, 0.5319558764357888, 0.9475233116148768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 291}], {
             RGBColor[
             0.5205636488996574, 0.6196411124817705, 0.9560349926032045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 297}], {
             RGBColor[
             0.4527821832454718, 0.5648055930283604, 0.9505673549688282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 314}], {
             RGBColor[
             0.35813781501059505`, 0.484622707657373, 0.944041202777008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 349}], {
             RGBColor[
             0.3999008136180363, 0.5207957179817955, 0.9467023041187045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 359}], {
             RGBColor[
             0.38582570994179444`, 0.508604570612715, 0.9458054509585798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 371}], {
             RGBColor[
             0.37457203795785354`, 0.49885720556622565`, 0.9450883769309946]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 397}], {
             RGBColor[
             0.37237410523066483`, 0.4969534667092458, 0.9449483266011737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 419}], {
             RGBColor[
             0.44944534633244004`, 0.5620965984995714, 0.950304666943798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{40, 472}], {
             RGBColor[
             0.35732343693452717`, 0.4839173342997152, 0.9439893113261273]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 102}], {
             RGBColor[
             0.2545321161274702, 0.38485977069120125`, 0.9378065995157133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 186}], {
             RGBColor[
             0.23411854278577374`, 0.36340381081377343`, 0.9366440767130793]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 191}], {
             RGBColor[
             0.22546402831064583`, 0.35430736737250323`, 0.9361512149169275]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 202}], {
             RGBColor[
             0.2357918679274276, 0.3651625816325934, 0.9367393701044336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 212}], {
             RGBColor[
             0.22552146354030395`, 0.35436773544047784`, 0.9361544857682886]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 295}], {
             RGBColor[
             0.23105727915165333`, 0.3601862286389881, 0.9364697422778497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 300}], {
             RGBColor[
             0.22924216126039493`, 0.3582784246501542, 0.9363663739991688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 389}], {
             RGBColor[
             0.2255132290582107, 0.3543590804777015, 0.9361540168267153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 451}], {
             RGBColor[
             0.22198624668627384`, 0.3506519983811976, 0.9359531603983363]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 456}], {
             RGBColor[
             0.22809260204387605`, 0.3570701650273288, 0.9363009083024085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{41, 485}], {
             RGBColor[
             0.24026393309017596`, 0.36986300566395003`, 0.9369940475996247]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 85}], {
             RGBColor[
             0.22334491181980198`, 0.3520800415808806, 0.9360305343677259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 95}], {
             RGBColor[
             0.2297785943922997, 0.3588422498836111, 0.9363969230724491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 97}], {
             RGBColor[
             0.23210438822814727`, 0.3612868066689332, 0.936529373590697]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 137}], {
             RGBColor[
             0.22627740530250587`, 0.35516227816202806`, 0.9361975355333305]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 145}], {
             RGBColor[
             0.22656621784669417`, 0.3554658384577429, 0.9362139829804621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 174}], {
             RGBColor[
             0.2495656884148965, 0.3796397402755821, 0.9375237688046536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 248}], {
             RGBColor[
             0.2375069627028864, 0.3669652549848901, 0.9368370422146407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 286}], {
             RGBColor[
             0.2277872668823118, 0.3567492384131574, 0.9362835199166604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 294}], {
             RGBColor[
             0.23539350574473433`, 0.36474387772096156`, 0.9367166839674533]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 346}], {
             RGBColor[
             0.22517846281523107`, 0.3540072199309242, 0.9361349523844199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 358}], {
             RGBColor[
             0.22905024080537584`, 0.3580767040834695, 0.9363554444131764]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 407}], {
             RGBColor[
             0.22341630550160935`, 0.352155080867081, 0.9360346001322872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 411}], {
             RGBColor[
             0.23603211668449622`, 0.3654150983089235, 0.9367530519157325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{42, 430}], {
             RGBColor[
             0.2361066473396595, 0.36549343475301654`, 0.9367572963262859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 110}], {
             RGBColor[
             0.2824315567297242, 0.4141838516908727, 0.9393954313844881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 217}], {
             RGBColor[
             0.30643378623989703`, 0.43839711764350564`, 0.9407994722898634]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 290}], {
             RGBColor[
             0.2898165263474991, 0.4219459229932718, 0.9398159944791369]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 316}], {
             RGBColor[
             0.2718214258604257, 0.4030319314260883, 0.9387912001277635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 340}], {
             RGBColor[
             0.31529118717805316`, 0.446068953150221, 0.9413638580453506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 355}], {
             RGBColor[
             0.3109273076150301, 0.4422891800076947, 0.941085795498422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 362}], {
             RGBColor[
             0.34080467652755875`, 0.4681674552795022, 0.9429895550260083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 378}], {
             RGBColor[
             0.2881161193118442, 0.42015868738676554`, 0.939719158813983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{43, 384}], {
             RGBColor[
             0.28848430619933074`, 0.4205456751499109, 0.9397401265125418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 57}], {
             RGBColor[
             0.5489601186307986, 0.6447095805328258, 0.9576352979272409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 106}], {
             RGBColor[
             0.5072662938524296, 0.6108606552923443, 0.9543530073111751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 117}], {
             RGBColor[
             0.4388762614701655, 0.5533769866678013, 0.9495110781480034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 139}], {
             RGBColor[
             0.5303562146824653, 0.6296060932112468, 0.9561707304600824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 140}], {
             RGBColor[
             0.4981556569200065, 0.6034642298010868, 0.9536357845984921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 247}], {
             RGBColor[
             0.4958443155073958, 0.6015877787175854, 0.9534538273357688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 255}], {
             RGBColor[
             0.44713138767076954`, 0.5605271620680575, 0.9500370874897843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 269}], {
             RGBColor[
             0.4728082951441619, 0.5827672087626157, 0.9516731973287911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 360}], {
             RGBColor[
             0.5380217860131518, 0.6358293493475512, 0.9567741923151472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 369}], {
             RGBColor[
             0.4583123366675063, 0.5702115381181944, 0.9507495276729314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 370}], {
             RGBColor[
             0.5440602935407461, 0.6407316817901163, 0.9572495657475013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 425}], {
             RGBColor[
             0.43601004951768985`, 0.5508944179345684, 0.9493284456568833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 466}], {
             RGBColor[
             0.5000927113166715, 0.6050368178236056, 0.9537882766162615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{44, 468}], {
             RGBColor[
             0.48752713657842917`, 0.5948355181784093, 0.9527990685436503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 52}], {
             RGBColor[
             0.5592887582023336, 0.3453473306953461, 0.5606630483713451]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 56}], {
             RGBColor[
             0.5597280401148761, 0.3487238439697099, 0.5610837052268939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 179}], {
             RGBColor[
             0.2308558043838454, 0.3599744658837838, 0.9364582685878783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 236}], {
             RGBColor[
             0.285052814306115, 0.4169389596009889, 0.9395447081256605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 243}], {
             RGBColor[
             0.5610442905289292, 0.35884112143673136`, 0.5623441481098833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 254}], {
             RGBColor[
             0.25964036057789125`, 0.3902288594899984, 0.9380975064801944]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 276}], {
             RGBColor[
             0.4511613140247853, 0.5582811601613382, 0.9513035162562244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 283}], {
             RGBColor[
             0.23199831546813182`, 0.3611753174727555, 0.9365233329039347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 292}], {
             RGBColor[
             0.23087655194201073`, 0.35999627288288677`, 0.9364594501306225]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 386}], {
             RGBColor[
             0.23085473585284239`, 0.35997334278995086`, 0.9364582077366184]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{45, 422}], {
             RGBColor[
             0.2583972380161019, 0.3889222588590351, 0.9380267124893356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 53}], {
             RGBColor[
             0.9470835767696775, 0.821834287485996, 0.3079282681448157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 68}], {
             RGBColor[
             0.8688206529626022, 0.4329330984324026, 0.20968686128144703`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 90}], {
             RGBColor[
             0.8912123121580973, 0.5950344530170778, 0.2307371435474895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 205}], {
             RGBColor[
             0.9557407049755898, 0.8502199530826348, 0.4110195083871594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 257}], {
             RGBColor[
             0.8882541401217813, 0.5816020846987996, 0.22826877228895565`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 272}], {
             RGBColor[
             0.8691188894851287, 0.4352254750326188, 0.20997245291222838`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 293}], {
             RGBColor[
             0.9359635798708703, 0.8383264425596675, 0.6074452935938994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 298}], {
             RGBColor[
             0.9096473304128414, 0.8178215341712867, 0.6215408826637097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 306}], {
             RGBColor[
             0.8876171805650555, 0.5774114462757728, 0.22768643734119767`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 317}], {
             RGBColor[
             0.9005275853462438, 0.6373329329271229, 0.23851003583391922`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 357}], {
             RGBColor[
             0.9123985653292456, 0.6903965335177349, 0.2483720332752017]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 418}], {
             RGBColor[
             0.9480641688610301, 0.8473510420156326, 0.586962152772621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{46, 420}], {
             RGBColor[
             0.9431488383406506, 0.8436851965616485, 0.5952825252201055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 55}], {
             RGBColor[
             0.22170565849658444`, 0.35035708240351526`, 0.9359371813160265]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 189}], {
             RGBColor[
             0.24585450838109163`, 0.3757390547576487, 0.9373124225919274]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 230}], {
             RGBColor[
             0.22790583767600858`, 0.3568738638351552, 0.9362902723479516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 242}], {
             RGBColor[
             0.2284706396727983, 0.35746750654429615`, 0.9363224369861192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 339}], {
             RGBColor[
             0.22181216919966315`, 0.3504690319056196, 0.9359432469429985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 364}], {
             RGBColor[
             0.24525016381875867`, 0.3751038503049783, 0.93727800606315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 365}], {
             RGBColor[
             0.22445415871552787`, 0.3532459303986038, 0.9360937043374536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 374}], {
             RGBColor[
             0.24183198733731956`, 0.37151113009807946`, 0.9370833459692711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{47, 437}], {
             RGBColor[
             0.2438820574631478, 0.37366588378227833`, 0.93720009443013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 78}], {
             RGBColor[
             0.21346998781254425`, 0.3417008703429085, 0.9354681720541533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 85}], {
             RGBColor[
             0.21086321568284044`, 0.3389609875556907, 0.9353197202377406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 95}], {
             RGBColor[
             0.21729689825533816`, 0.34572319585842115`, 0.9356861089424638]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 137}], {
             RGBColor[
             0.21379570916554433`, 0.34204322413683813`, 0.9354867214033452]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 145}], {
             RGBColor[
             0.21408452170973263`, 0.34234678443255295`, 0.9355031688504769]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 183}], {
             RGBColor[
             0.20623910902756293`, 0.3341007582756985, 0.9350563842044752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 346}], {
             RGBColor[
             0.21269676667826953`, 0.34088816590573434`, 0.9354241382544346]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 358}], {
             RGBColor[
             0.2165685446684143, 0.3449576500582796, 0.9356446302831911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 404}], {
             RGBColor[
             0.21047959213928613`, 0.3385577748882776, 0.9352978734444553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 407}], {
             RGBColor[
             0.2109346093646478, 0.33903602684189116`, 0.935323786002302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{48, 408}], {
             RGBColor[
             0.21500770505426564`, 0.34331710866086196`, 0.9355557427762207]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 71}], {
             RGBColor[
             0.6229981269292593, 0.7030794824142605, 0.9646517716159538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 76}], {
             RGBColor[
             0.45077000854144356`, 0.5638542255344485, 0.9502204534950804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 238}], {
             RGBColor[
             0.4051843179606758, 0.5243701915568157, 0.9473157736011174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 328}], {
             RGBColor[
             0.4377638604952656, 0.5525889538048573, 0.9493917132424632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 402}], {
             RGBColor[
             0.521262974366249, 0.6222237910767345, 0.9554548772727531]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 431}], {
             RGBColor[
             0.4693773227785792, 0.5799709458958486, 0.9514060951044689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 436}], {
             RGBColor[
             0.4815672646188717, 0.5899970256324685, 0.9523298855912635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 459}], {
             RGBColor[
             0.44038041665413563`, 0.554855283237734, 0.9495584378871766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 462}], {
             RGBColor[
             0.4770465403942916, 0.586326898050649, 0.9519739976203461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{49, 487}], {
             RGBColor[
             0.5348230464505574, 0.633232468469062, 0.9565223758194106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 57}], {
             RGBColor[
             0.5210905073010532, 0.6217476292469348, 0.9555341779806428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 92}], {
             RGBColor[
             0.5250378077135244, 0.6249522255456361, 0.9558449239285502]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 106}], {
             RGBColor[
             0.47939668252268425`, 0.5878987040064534, 0.9522518873645769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 117}], {
             RGBColor[
             0.41100665014042015`, 0.5304150353819104, 0.9474099582014052]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 139}], {
             RGBColor[
             0.50248660335272, 0.6066441419253559, 0.9540696105134843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 140}], {
             RGBColor[
             0.47028604559026116`, 0.5805022785151959, 0.9515346646518938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 169}], {
             RGBColor[
             0.46684010556596744`, 0.5777047091656451, 0.9512633876302873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 204}], {
             RGBColor[
             0.47141553909134676`, 0.5814192522224795, 0.9516235825177704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 219}], {
             RGBColor[
             0.48360346312109975`, 0.5913139580095534, 0.9525830605432293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 244}], {
             RGBColor[
             0.3916895278498226, 0.5136835149605915, 0.9461790882505088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 255}], {
             RGBColor[
             0.41926177634102413`, 0.5375652107821666, 0.9479359675431862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 274}], {
             RGBColor[
             0.4518361438965558, 0.5655238171616463, 0.9500822208063486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 334}], {
             RGBColor[
             0.42187105269828507`, 0.539825234816783, 0.9481022283253784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 338}], {
             RGBColor[
             0.3805216773222415, 0.5040104841460892, 0.9454674826902338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 340}], {
             RGBColor[
             0.3891862943583425, 0.5115153399264449, 0.9460195844259542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 361}], {
             RGBColor[
             0.5425697371949871, 0.6391572117563517, 0.9572443985054486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 363}], {
             RGBColor[
             0.422874692158388, 0.5406945368727382, 0.9481661793442926]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 369}], {
             RGBColor[
             0.43044272533776096`, 0.5472495868323034, 0.9486484077263333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 370}], {
             RGBColor[
             0.5161906822110007, 0.6177697305042253, 0.9551484458009031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{50, 379}], {
             RGBColor[
             0.37511861305326666`, 0.49933062144220947`, 0.9451232042127569]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 107}], {
             RGBColor[
             0.18179934664985797`, 0.3084130184462969, 0.9336645758924533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 113}], {
             RGBColor[
             0.17905963075308248`, 0.3055334033307651, 0.9335085531251784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 127}], {
             RGBColor[
             0.20245340605759676`, 0.3301217444268325, 0.9348407940207814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 130}], {
             RGBColor[
             0.1789270004053139, 0.3053940004260106, 0.9335010000230821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 143}], {
             RGBColor[
             0.17892700107920537`, 0.30539400113431325`, 0.9335010000614592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 179}], {
             RGBColor[
             0.1789280689363169, 0.30539512351984355`, 0.9335010608743419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 214}], {
             RGBColor[
             0.1893670578318586, 0.31636716271918164`, 0.9340955458488429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 302}], {
             RGBColor[
             0.18453817957609825`, 0.31129170550381263`, 0.9338205483758626]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 308}], {
             RGBColor[
             0.1789366427891193, 0.3054041351827525, 0.9335015491425751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 315}], {
             RGBColor[
             0.1822133085396902, 0.30884811863921036`, 0.9336881504096776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 325}], {
             RGBColor[
             0.17897196058988912`, 0.30544125643063946`, 0.933503560439081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 347}], {
             RGBColor[
             0.1789270004053139, 0.3053940004260106, 0.9335010000230821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 386}], {
             RGBColor[
             0.1789270004053139, 0.3053940004260106, 0.9335010000230821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 421}], {
             RGBColor[
             0.17899180329589925`, 0.30546211237275633`, 0.9335046904518336]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 423}], {
             RGBColor[
             0.18337644614132015`, 0.31007065000570677`, 0.9337543893753826]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{51, 477}], {
             RGBColor[
             0.21179931412463662`, 0.3399448863700877, 0.9353730296591674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 56}], {
             RGBColor[
             0.836234326611525, 0.27951848908515425`, 0.18233133812500216`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 88}], {
             RGBColor[
             0.8512025856554928, 0.3816657696999445, 0.19615962002028325`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 166}], {
             RGBColor[
             0.8369577282992072, 0.2850788714533209, 0.18302406839809204`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 210}], {
             RGBColor[
             0.8359293793650189, 0.2771745309197725, 0.1820393202973592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 227}], {
             RGBColor[
             0.8407131059122084, 0.31394434940381033`, 0.18662022224139424`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 236}], {
             RGBColor[
             0.5615591008027638, 0.3477336047164332, 0.5607923410237687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 243}], {
             RGBColor[
             0.837550577025578, 0.2896357665521757, 0.18359178100799164`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 276}], {
             RGBColor[
             0.7276676005214341, 0.4890758052767825, 0.5725511491543327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 326}], {
             RGBColor[
             0.8554852780065134, 0.4011124754177182, 0.19973320349637064`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 428}], {
             RGBColor[
             0.8330642703587228, 0.25515204759860854`, 0.17929568867725226`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 469}], {
             RGBColor[
             0.8481128613393234, 0.36763605320366755`, 0.19358147831479822`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{52, 495}], {
             RGBColor[
             0.8389987580384334, 0.3007671204139477, 0.18497856078138836`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 90}], {
             RGBColor[
             0.9206410418975434, 0.7056328015929743, 0.28606405077970154`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 178}], {
             RGBColor[
             0.9840984713626098, 0.9616310168446078, 0.5753629014776818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 257}], {
             RGBColor[
             0.9176828698612274, 0.692200433274696, 0.28359567952116765`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 272}], {
             RGBColor[
             0.8985476192245749, 0.5458238236085153, 0.2652993601444404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 293}], {
             RGBColor[
             0.9653923096103165, 0.9489247911355639, 0.6627722008261114]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 298}], {
             RGBColor[
             0.9390760601522875, 0.9284198827471832, 0.6768677898959217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 306}], {
             RGBColor[
             0.9170459103045016, 0.6880097948516692, 0.28301334457340965`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 317}], {
             RGBColor[
             0.9299563150856899, 0.7479312815030192, 0.29383694306613123`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 357}], {
             RGBColor[
             0.9418272950686917, 0.8009948820936315, 0.3036989405074137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 418}], {
             RGBColor[
             0.9774928986004763, 0.9579493905915291, 0.642289060004833]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 420}], {
             RGBColor[
             0.9725775680800968, 0.9542835451375451, 0.6506094324523175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{53, 432}], {
             RGBColor[
             0.9375683877182548, 0.9272177056729635, 0.6767239867532486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 55}], {
             RGBColor[
             0.22009923076516985`, 0.34866862500439766`, 0.9358456976332195]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 70}], {
             RGBColor[
             0.24348548029858347`, 0.3732490560378767, 0.9371775099472914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 84}], {
             RGBColor[
             0.23101754524273913`, 0.3601444657814439, 0.9364674794905181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 131}], {
             RGBColor[
             0.24616492351091418`, 0.3760653207405481, 0.9373301002743527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 135}], {
             RGBColor[
             0.23967378277683635`, 0.36924272026693905`, 0.9369604394123292]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 147}], {
             RGBColor[
             0.2401069833110282, 0.36969804149487495`, 0.9369851095418886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 230}], {
             RGBColor[
             0.22629940994459397`, 0.3551854064360376, 0.9361987886651444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 242}], {
             RGBColor[
             0.22686421194138368`, 0.35577904914517844`, 0.936230953303312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 365}], {
             RGBColor[
             0.22284773098411328`, 0.35155747299948614`, 0.9360022206546466]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 374}], {
             RGBColor[
             0.24022555960590497`, 0.3698226726989618, 0.9369918622864639]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 385}], {
             RGBColor[
             0.23109619211781043`, 0.36022712863364376`, 0.9364719583137058]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{54, 391}], {
             RGBColor[
             0.23492401226674847`, 0.36425041030799266`, 0.9366899470084354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 230}], {
             RGBColor[
             0.21767784356668446`, 0.34612359353397393`, 0.935707803214387]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 242}], {
             RGBColor[
             0.21824264556347417`, 0.34671723624311485`, 0.9357399678525544]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 250}], {
             RGBColor[
             0.20796149957955015`, 0.33591109995170554`, 0.9351544717983624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 339}], {
             RGBColor[
             0.21158417509033906`, 0.33971876160443837`, 0.9353607778094337]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{55, 365}], {
             RGBColor[
             0.21422616460620378`, 0.3424956600974225, 0.935511235203889]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 88}], {
             RGBColor[
             0.8516418675680354, 0.38504228297430826`, 0.19658027687583196`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 164}], {
             RGBColor[
             0.8270991589089857, 0.20930158706742483`, 0.17358349121635427`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 166}], {
             RGBColor[
             0.8373970102117498, 0.28845538472768467`, 0.18344472525364075`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 210}], {
             RGBColor[
             0.8363686612775614, 0.28055104419413623`, 0.18245997715290796`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 227}], {
             RGBColor[
             0.8411523878247509, 0.31732086267817405`, 0.187040879096943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 236}], {
             RGBColor[
             0.5619983827153064, 0.35111011799079705`, 0.5612129978793174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 243}], {
             RGBColor[
             0.8379898589381207, 0.2930122798265395, 0.18401243786354038`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 276}], {
             RGBColor[
             0.7281068824339767, 0.4924523185511463, 0.5729718060098814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 326}], {
             RGBColor[
             0.8559245599190561, 0.404488988692082, 0.2001538603519194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 428}], {
             RGBColor[
             0.8335035522712653, 0.25852856087297227`, 0.179716345532801]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{56, 495}], {
             RGBColor[
             0.839438039950976, 0.30414363368831143`, 0.18539921763693712`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 92}], {
             RGBColor[
             0.6051902881840892, 0.690359765316458, 0.9620619428523739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 106}], {
             RGBColor[
             0.5595491629932491, 0.6533062437772754, 0.9584689062884005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 139}], {
             RGBColor[
             0.5826390838232848, 0.6720516816961779, 0.9602866294373078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 140}], {
             RGBColor[
             0.550438526060826, 0.6459098182860178, 0.9577516835757175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 169}], {
             RGBColor[
             0.5469925860365322, 0.6431122489364671, 0.9574804065541109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 175}], {
             RGBColor[
             0.7784866261079177, 0.8268297266210345, 0.9607862455954495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 204}], {
             RGBColor[
             0.5515680195619116, 0.6468267919933015, 0.9578406014415939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 219}], {
             RGBColor[
             0.5637559435916646, 0.6567214977803754, 0.9588000794670529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 255}], {
             RGBColor[
             0.499414256811589, 0.6029727505529885, 0.9541529864670097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 274}], {
             RGBColor[
             0.5319886243671207, 0.6309313569324684, 0.9562992397301722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 334}], {
             RGBColor[
             0.5020235331688498, 0.6052327745876049, 0.9543192472492019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 337}], {
             RGBColor[
             0.730726843956438, 0.7892639238928545, 0.9741400277373693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 361}], {
             RGBColor[
             0.622722217665552, 0.7045647515271736, 0.9634614174292722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 363}], {
             RGBColor[
             0.5030271726289528, 0.6061020766435601, 0.9543831982681161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 369}], {
             RGBColor[
             0.5105952058083258, 0.6126571266031253, 0.9548654266501568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 370}], {
             RGBColor[
             0.5963431626815656, 0.6831772702750474, 0.9613654647247267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{57, 466}], {
             RGBColor[
             0.552375580457491, 0.6474824063085367, 0.957904175593487]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 118}], {
             RGBColor[
             0.3201099243225116, 0.4516848600807156, 0.9416180992091068]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 141}], {
             RGBColor[
             0.3123473120692484, 0.44496127550717535`, 0.9411234724205373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 188}], {
             RGBColor[
             0.32619444448890195`, 0.45695496563196736`, 0.9420057994537792]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 220}], {
             RGBColor[
             0.32701247471585293`, 0.45766350229915764`, 0.9420579236164848]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 240}], {
             RGBColor[
             0.2858686487739417, 0.41720789684373627`, 0.9396127186286245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 304}], {
             RGBColor[
             0.3268378953241502, 0.4575122904046801, 0.94204679957202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 310}], {
             RGBColor[
             0.3059344073310527, 0.43829828132983367`, 0.9407554338938223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 371}], {
             RGBColor[
             0.3390278312734188, 0.4680706002399412, 0.9428235315115703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 382}], {
             RGBColor[
             0.2986682199237062, 0.43066105766182183`, 0.9403416352703349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{58, 429}], {
             RGBColor[
             0.3043548555603097, 0.4366380722694161, 0.9406654807572159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 74}], {
             RGBColor[
             0.26196255890659237`, 0.3926696371693413, 0.9382297522396293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 82}], {
             RGBColor[
             0.25023486400687867`, 0.3803430862509384, 0.9375618773646605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 105}], {
             RGBColor[
             0.2440481876886619, 0.3738404971825583, 0.9372095553007055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 153}], {
             RGBColor[
             0.24356203444566857`, 0.3733295193002764, 0.9371818695927163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 195}], {
             RGBColor[
             0.2561715150223729, 0.3865828828736374, 0.9378999608575047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 263}], {
             RGBColor[
             0.25779587834217144`, 0.38829019171332857`, 0.9379924659455371]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 323}], {
             RGBColor[
             0.24076788547771533`, 0.3703926915756808, 0.9370227469425643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 342}], {
             RGBColor[
             0.25108912406320616`, 0.3812409677333546, 0.9376105262111039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 395}], {
             RGBColor[
             0.2535893388235434, 0.38386885196924064`, 0.9377529097429688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 447}], {
             RGBColor[
             0.2443455259866942, 0.3741530185861272, 0.9372264882769058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 453}], {
             RGBColor[
             0.26324896867774317`, 0.3940217354019111, 0.9383030113730237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{59, 463}], {
             RGBColor[
             0.2546442329532448, 0.38497761258370766`, 0.9378129844030793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 116}], {
             RGBColor[
             0.27071777339856856`, 0.4018719227130688, 0.9387283487527682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 118}], {
             RGBColor[
             0.30890885152103453`, 0.4405003788871604, 0.9409586647466246]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 133}], {
             RGBColor[
             0.31894163191943015`, 0.44919026900604586`, 0.9415979446419711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 151}], {
             RGBColor[
             0.2997519610227203, 0.4323886947798715, 0.9403818027857322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 188}], {
             RGBColor[
             0.31499337168742486`, 0.44577048443841216`, 0.9413463649912971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 192}], {
             RGBColor[
             0.2736621188386635, 0.4049666164528918, 0.9388960248698129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 249}], {
             RGBColor[
             0.29112873348308044`, 0.42332513589150556`, 0.9398907227342717]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 260}], {
             RGBColor[
             0.2891430137819674, 0.4212380185837349, 0.9397776389349024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 280}], {
             RGBColor[
             0.2748009878347767, 0.4061636399762716, 0.9389608817743358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 310}], {
             RGBColor[
             0.2947333345295756, 0.4271138001362785, 0.9400959994313403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 327}], {
             RGBColor[
             0.27488937913222444`, 0.40625654483422113`, 0.9389659155279624]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{60, 483}], {
             RGBColor[
             0.29467938491288026`, 0.4270570956685284, 0.9400929270804808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 64}], {
             RGBColor[
             0.3058305702683475, 0.43738338551197825`, 0.9407790232185906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 91}], {
             RGBColor[
             0.32572776888358806`, 0.4565507546784424, 0.9419760632968737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 172}], {
             RGBColor[
             0.3377395733706075, 0.4669547759942509, 0.9427414448571648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 303}], {
             RGBColor[
             0.31454260624684305`, 0.4465402877003618, 0.9412751607792637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 362}], {
             RGBColor[
             0.3561441161626767, 0.48289586592152384`, 0.9439141660493773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 384}], {
             RGBColor[
             0.3038237458344487, 0.43527408579193255`, 0.9406647375359107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 435}], {
             RGBColor[
             0.2909721876561818, 0.42176628331072286`, 0.9399328603098349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{61, 473}], {
             RGBColor[
             0.3253289757704718, 0.4562053401277858, 0.9419506525523447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 132}], {
             RGBColor[
             0.9037259559281465, 0.5621573598635239, 0.4887023579770914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 209}], {
             RGBColor[
             0.6916212861064526, 0.39630413817282756`, 0.5615943615662011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{62, 233}], {
             RGBColor[
             0.8302393984490122, 0.2334388442338099, 0.17659058814627704`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 75}], {
             RGBColor[
             0.38214205273411095`, 0.5054139718854141, 0.9455707315786365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 149}], {
             RGBColor[
             0.3866051837093468, 0.5092797116126782, 0.9458551183377868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 158}], {
             RGBColor[
             0.38842846253649266`, 0.5108589440920934, 0.9459712960523903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 165}], {
             RGBColor[
             0.42168442508772075`, 0.5396635873606885, 0.9480903365790616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 182}], {
             RGBColor[
             0.3989611276124065, 0.5199818091937107, 0.9466424281573576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 206}], {
             RGBColor[
             0.3810348762200533, 0.5044549912372471, 0.9455001832701985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 252}], {
             RGBColor[
             0.5775658026497799, 0.6655789256820774, 0.9611207995905398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 275}], {
             RGBColor[
             0.41651977831287657`, 0.5351902299070133, 0.9477612498534863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 282}], {
             RGBColor[
             0.5134969921724348, 0.6149963149023026, 0.9550984560118821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 324}], {
             RGBColor[
             0.3945065223315428, 0.5161234539943981, 0.9463585846479137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 410}], {
             RGBColor[
             0.39150030357105375`, 0.5135196184010107, 0.9461670310467902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 441}], {
             RGBColor[
             0.4347339982883702, 0.5509664717764713, 0.9489218438441225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{63, 467}], {
             RGBColor[
             0.563087381667329, 0.6542682731705118, 0.9596777258955458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 91}], {
             RGBColor[
             0.3077316474117898, 0.43903000298271255`, 0.9409001581731142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 172}], {
             RGBColor[
             0.31974345189880926`, 0.449434024298521, 0.9416655397334055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 303}], {
             RGBColor[
             0.29654648477504475`, 0.4290195360046319, 0.9401992556555043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 366}], {
             RGBColor[
             0.27642037277284975`, 0.4078657162211217, 0.9390531033508938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 384}], {
             RGBColor[
             0.28582762436265047`, 0.41775333409620263`, 0.9395888324121513]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 435}], {
             RGBColor[
             0.2729760661843835, 0.4042455316149929, 0.9388569551860756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{64, 473}], {
             RGBColor[
             0.3073328542986736, 0.43868458843205593`, 0.9408747474285853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 88}], {
             RGBColor[
             0.9260374771709088, 0.7249105779401631, 0.30422129427437533`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 166}], {
             RGBColor[
             0.9117926198146232, 0.6283236796935395, 0.2910857426521841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 167}], {
             RGBColor[
             0.986067541242265, 0.9756937071602725, 0.6343029674871418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 175}], {
             RGBColor[
             0.9705975460870158, 0.9645679382577699, 0.6789276620320353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 210}], {
             RGBColor[
             0.9107642708804349, 0.6204193391599911, 0.29010099455145133`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 227}], {
             RGBColor[
             0.9155479974276244, 0.657189157644029, 0.2946818964954864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 309}], {
             RGBColor[
             0.9892477963467572, 0.9750667140916796, 0.4404269945442838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 320}], {
             RGBColor[
             0.9870336626851595, 0.9760932232050978, 0.618291834936235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 337}], {
             RGBColor[
             0.9228377639355362, 0.92700213552959, 0.6922814441739551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 348}], {
             RGBColor[
             0.9726882187211612, 0.9195330900145834, 0.3483993164391773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 428}], {
             RGBColor[
             0.9078991618741388, 0.5983968558388272, 0.2873573629313444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 434}], {
             RGBColor[
             0.9883337030612244, 0.9766308233101144, 0.5967468015081936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 474}], {
             RGBColor[
             0.989280991001634, 0.9770225512176633, 0.5810477888330006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{65, 495}], {
             RGBColor[
             0.9138336495538494, 0.6440119286541663, 0.2930402350354805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 208}], {
             RGBColor[
             0.2926997987840062, 0.4237400438284219, 0.9400254625551399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 305}], {
             RGBColor[
             0.25719647261268064`, 0.38766017828711546`, 0.9379583306759838]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 314}], {
             RGBColor[
             0.29667827269945046`, 0.4271859979700665, 0.9402789673950056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 394}], {
             RGBColor[
             0.24596177604056546`, 0.3758517998689181, 0.937318531326446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 398}], {
             RGBColor[
             0.26221606410223275`, 0.392936087203117, 0.9382441889854937]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 427}], {
             RGBColor[
             0.271390600085227, 0.40257910622042264`, 0.9387666652372155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 445}], {
             RGBColor[
             0.24646019520379875`, 0.3763756700110764, 0.9373469155604471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 460}], {
             RGBColor[
             0.2558136629427209, 0.38620675764879087`, 0.9378795817109632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{66, 472}], {
             RGBColor[
             0.29586389462338253`, 0.42648062461240877`, 0.9402270759441249]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 70}], {
             RGBColor[
             0.25743661729140077`, 0.3879125855705024, 0.9379720065601748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 96}], {
             RGBColor[
             0.2763924027630132, 0.4078363179673825, 0.9390515105002115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 131}], {
             RGBColor[
             0.2601160605037315, 0.39072885027317383`, 0.938124596887236]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 135}], {
             RGBColor[
             0.2536249197696536, 0.3839062497995648, 0.9377549360252124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 147}], {
             RGBColor[
             0.2540581203038455, 0.3843615710275007, 0.9377796061547718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 171}], {
             RGBColor[
             0.25918264815811415`, 0.38974777471616917`, 0.9380714404350129]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 180}], {
             RGBColor[
             0.26337700695553745`, 0.3941563117499686, 0.9383103029635284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 216}], {
             RGBColor[
             0.26125452628926693`, 0.3919254499966715, 0.938189430829513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 238}], {
             RGBColor[
             0.28838849579729153`, 0.41939023215024707`, 0.9397732894571003]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 281}], {
             RGBColor[
             0.25076586641156884`, 0.38090120344576484`, 0.93759211716606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 343}], {
             RGBColor[
             0.2747552896997584, 0.40611560833893834`, 0.9389582793331509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 385}], {
             RGBColor[
             0.24504732911062774`, 0.37489065816626943`, 0.9372664549265891]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 391}], {
             RGBColor[
             0.24887514925956578`, 0.37891393984061833`, 0.9374844436213188]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{67, 465}], {
             RGBColor[
             0.26962432665641767`, 0.4007226408585406, 0.9386660785784122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 205}], {
             RGBColor[
             0.9069065109079608, 0.5719171126049378, 0.3681050087560027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 257}], {
             RGBColor[
             0.8394199460541523, 0.30329924422110266`, 0.18535427265779897`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 272}], {
             RGBColor[
             0.8202846954174998, 0.15692263455492186`, 0.1670579532810717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 306}], {
             RGBColor[
             0.8387829864974263, 0.2991086057980758, 0.18477193771004097`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{68, 317}], {
             RGBColor[
             0.8516933912786147, 0.35903009244942585`, 0.19559553620276254`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 142}], {
             RGBColor[
             0.8044934065793106, 0.8479188521576653, 0.9809561216743297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 173}], {
             RGBColor[
             0.9470127321552729, 0.9592645667466908, 0.9483609186014075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 194}], {
             RGBColor[
             0.9479892988678673, 0.9596684021789683, 0.9321766809000795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 241}], {
             RGBColor[
             0.8074723242442312, 0.8502460052781141, 0.9812530323476005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 388}], {
             RGBColor[
             0.9278173046721767, 0.9450102776472538, 0.9836136557859578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 402}], {
             RGBColor[
             0.7308868707375382, 0.7890374499881754, 0.9745628249690335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 461}], {
             RGBColor[
             0.926959006974305, 0.9443701606295145, 0.985066529908563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 487}], {
             RGBColor[
             0.7444469428218465, 0.8000461273805028, 0.9756303235156909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{69, 490}], {
             RGBColor[
             0.9500080335378767, 0.9605032008441318, 0.8987210231001681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 84}], {
             RGBColor[
             0.24578222839824324`, 0.37566308391285935`, 0.9373083063538328]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 96}], {
             RGBColor[
             0.2772059489257, 0.4086914065661722, 0.9390978407506428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 131}], {
             RGBColor[
             0.2609296066664183, 0.3915839388719636, 0.9381709271376673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 135}], {
             RGBColor[
             0.25443846593234043`, 0.3847613383983545, 0.9378012662756438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 147}], {
             RGBColor[
             0.2548716664665323, 0.3852166596262904, 0.9378259364052033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 170}], {
             RGBColor[
             0.2774653661360603, 0.408964070502262, 0.9391126141769994]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 171}], {
             RGBColor[
             0.25999619432080096`, 0.39060286331495886`, 0.9381177706854442]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 216}], {
             RGBColor[
             0.26206807245195374`, 0.39278053859546125`, 0.9382357610799443]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 238}], {
             RGBColor[
             0.28920204195997834`, 0.42024532074903687`, 0.9398196197075317]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 265}], {
             RGBColor[
             0.28963233444531233`, 0.42061801847270397`, 0.9398470375642044]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 374}], {
             RGBColor[
             0.2549902427614091, 0.38534129083037727`, 0.9378326891497786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 385}], {
             RGBColor[
             0.24586087527331454`, 0.37574574676505923`, 0.9373127851770204]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 391}], {
             RGBColor[
             0.24968869542225258`, 0.3797690284394081, 0.93753077387175]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{70, 433}], {
             RGBColor[
             0.2918782074405654, 0.4225632807803333, 0.9399901426055144]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 194}], {
             RGBColor[
             0.8711488139703549, 0.898916809896938, 0.9247098602219754]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 228}], {
             RGBColor[
             0.8744314209010298, 0.8983757407693698, 0.7323068273714743]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 388}], {
             RGBColor[
             0.8509768197746642, 0.8842586853652235, 0.9761468351078537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 431}], {
             RGBColor[
             0.602160734252356, 0.6860330125252593, 0.9630472221226452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 462}], {
             RGBColor[
             0.6098299518680684, 0.6923889646800596, 0.9636151246385223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 487}], {
             RGBColor[
             0.6676064579243342, 0.7392945350984725, 0.9681635028375868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{71, 490}], {
             RGBColor[
             0.8731675486403643, 0.8997516085621015, 0.891254202422064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 73}], {
             RGBColor[
             0.2509474629421924, 0.38109207291333524`, 0.9376024588198308]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 144}], {
             RGBColor[
             0.2501061102631632, 0.3802077579028347, 0.93755454502943]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 163}], {
             RGBColor[
             0.26048838412385666`, 0.3911201860046064, 0.9381458001665987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 187}], {
             RGBColor[
             0.2593062768219157, 0.38987771628033463`, 0.9380784809045242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 279}], {
             RGBColor[
             0.26627234056032795`, 0.3971994909433567, 0.9384751879290589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 322}], {
             RGBColor[
             0.25660150329804876`, 0.38703482781420406`, 0.9379244480536938]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{72, 494}], {
             RGBColor[
             0.25624399533436604`, 0.3866590642770594, 0.9379040885040477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 93}], {
             RGBColor[
             0.2585978739086303, 0.3891331399031328, 0.9380381384066008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 163}], {
             RGBColor[
             0.2574513896017804, 0.3879281122053299, 0.9379728478213971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 187}], {
             RGBColor[
             0.25626928229983936`, 0.38668564248105813`, 0.9379055285593227]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 322}], {
             RGBColor[
             0.2535645087759725, 0.3838427540149276, 0.9377514957084923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{73, 494}], {
             RGBColor[
             0.25320700081228975`, 0.383466990477783, 0.9377311361588463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 82}], {
             RGBColor[
             0.27000631808527487`, 0.401124138069925, 0.93868783242518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 105}], {
             RGBColor[
             0.2638196417670582, 0.3946215490015449, 0.938335510361225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 112}], {
             RGBColor[
             0.264998769293781, 0.3958608867931338, 0.938402659929509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 153}], {
             RGBColor[
             0.2633334885240648, 0.39411057111926295`, 0.9383078246532357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 195}], {
             RGBColor[
             0.27594296910076915`, 0.40736393469262394`, 0.9390259159180243]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 224}], {
             RGBColor[
             0.2903501525391211, 0.42250679795452123`, 0.9398463837013205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 234}], {
             RGBColor[
             0.335156328175214, 0.4622198560830736, 0.94266828637108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 239}], {
             RGBColor[
             0.31633226480045645`, 0.4459153985127936, 0.9414688336983061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 263}], {
             RGBColor[
             0.27756733242056764`, 0.40907124353231517`, 0.9391184210060566]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 296}], {
             RGBColor[
             0.2975769167094639, 0.42967045866758025`, 0.9402737595026511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 342}], {
             RGBColor[
             0.27086057814160247`, 0.4020220195523411, 0.9387364812716233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 395}], {
             RGBColor[
             0.2733607929019397, 0.4046499037882272, 0.9388788648034883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 440}], {
             RGBColor[
             0.2817039259800564, 0.4134190656385177, 0.9393539938897277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 447}], {
             RGBColor[
             0.26411698006509043`, 0.39493407040511375`, 0.9383524433374253]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 453}], {
             RGBColor[
             0.2830204227561394, 0.41480278722089764`, 0.9394289664335431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{74, 463}], {
             RGBColor[
             0.2744156870316411, 0.4057586644026942, 0.9389389394635987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 93}], {
             RGBColor[
             0.30711689507265494`, 0.43678253795558514`, 0.940923781155411]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 108}], {
             RGBColor[
             0.31502960292460824`, 0.4450992956026424, 0.9413743981617775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 149}], {
             RGBColor[
             0.3494116417234011, 0.4770645349462275, 0.9434851787314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 158}], {
             RGBColor[
             0.3512349205505469, 0.4786437674256428, 0.9436013564460036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 163}], {
             RGBColor[
             0.3059704107658049, 0.43557751025778224`, 0.9408584905702073]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 182}], {
             RGBColor[
             0.3617675856264607, 0.48776663252726005`, 0.9442724885509708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 206}], {
             RGBColor[
             0.34384133423410757`, 0.4722398145707964, 0.9431302436638118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{75, 410}], {
             RGBColor[
             0.354306761585108, 0.48130444173456, 0.9437970914404035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 96}], {
             RGBColor[
             0.3537435180123586, 0.4796530871235497, 0.9438038035415315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 157}], {
             RGBColor[
             0.35693445553108405`, 0.4830069647728541, 0.9439855227126539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 238}], {
             RGBColor[
             0.36573961104663694`, 0.49120700130641426`, 0.9445255824984202]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 333}], {
             RGBColor[
             0.3949872182942583, 0.5165398086768207, 0.9463892141695951]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 343}], {
             RGBColor[
             0.3521064049491038, 0.47793237749510553`, 0.9437105723744709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 392}], {
             RGBColor[
             0.35866334703698777`, 0.48482413936361163`, 0.9440839805262493]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 402}], {
             RGBColor[
             0.4818182674522101, 0.589060600826333, 0.952664686170056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 431}], {
             RGBColor[
             0.42993261586454035`, 0.5468077556454473, 0.9486159040017718]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 436}], {
             RGBColor[
             0.4421225577048329, 0.5568338353820671, 0.9495396944885663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 459}], {
             RGBColor[
             0.40093570974009674`, 0.5216920929873327, 0.9467682467844796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 462}], {
             RGBColor[
             0.4376018334802528, 0.5531637078002476, 0.949183806517649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{76, 487}], {
             RGBColor[
             0.49537833953651855`, 0.6000692782186605, 0.9537321847167134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 81}], {
             RGBColor[
             0.7152180111578499, 0.7769379420233913, 0.972614350327299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 156}], {
             RGBColor[
             0.5370635204917655, 0.6350513862279201, 0.9566987541430614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 278}], {
             RGBColor[
             0.7775908081460805, 0.8263457284855322, 0.9672404849556133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 329}], {
             RGBColor[
             0.7446878798780471, 0.8004364154026, 0.9754252127138938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 479}], {
             RGBColor[
             0.5091542746403608, 0.6112576931750507, 0.9548154361242309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{77, 482}], {
             RGBColor[
             0.4826496570055525, 0.5883007255405965, 0.9531265853256541]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 85}], {
             RGBColor[
             0.21682232686548605`, 0.34522439123812265`, 0.9356590828038773]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 95}], {
             RGBColor[
             0.22325600943798377`, 0.3519865995408531, 0.9360254715086005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 97}], {
             RGBColor[
             0.22558180327383132`, 0.35443115632617517`, 0.9361579220268484]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 137}], {
             RGBColor[
             0.21975482034818994`, 0.34830662781927, 0.9358260839694819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 145}], {
             RGBColor[
             0.22004363289237822`, 0.3486101881149849, 0.9358425314166136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 183}], {
             RGBColor[
             0.21219822021020854`, 0.34036416195813046`, 0.935395746770612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 346}], {
             RGBColor[
             0.21865587786091514`, 0.34715156958816623`, 0.9357635008205714]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 358}], {
             RGBColor[
             0.22252765585105994`, 0.3512210537407115, 0.9359839928493279]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 404}], {
             RGBColor[
             0.2164387033219317, 0.3448211785707095, 0.935637236010592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 407}], {
             RGBColor[
             0.21689372054729342`, 0.34529943052432305`, 0.9356631485684387]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 408}], {
             RGBColor[
             0.22096681623691122`, 0.34958051234329385`, 0.9358951053423573]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{78, 430}], {
             RGBColor[
             0.22958406238534357`, 0.3586377844102586, 0.9363858447624374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 81}], {
             RGBColor[
             0.9087234308797807, 0.9257016701540246, 0.7763552620147077]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 99}], {
             RGBColor[
             0.9937251243023482, 0.9889870003070016, 0.5583966882336657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 122}], {
             RGBColor[
             0.9306665098261713, 0.7402291937878942, 0.3904132893585251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 267}], {
             RGBColor[
             0.9914456607402118, 0.9819881575780944, 0.49084130836277423`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 278}], {
             RGBColor[
             0.9710962278680113, 0.9751094566161655, 0.770981396643022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 329}], {
             RGBColor[
             0.9381932995999778, 0.9492001435332333, 0.7791661244013025]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 406}], {
             RGBColor[
             0.9922235479450122, 0.984612153776488, 0.4938632532617516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 413}], {
             RGBColor[
             0.9838323701759427, 0.9563067408191819, 0.46126511216987476`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 476}], {
             RGBColor[
             0.9211605712027758, 0.6814740968415736, 0.3818708025801312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 486}], {
             RGBColor[
             0.9643781566417168, 0.9700792377693064, 0.7816636594414414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{79, 493}], {
             RGBColor[
             0.9937029879453217, 0.9889396528776512, 0.5559872823811043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 156}], {
             RGBColor[
             0.6284260394446897, 0.7069689251123001, 0.9654326763878454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 278}], {
             RGBColor[
             0.8689533270990046, 0.8982632673699124, 0.9759744072003973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 307}], {
             RGBColor[
             0.6296762406643908, 0.7079838947833768, 0.9655310968074982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 329}], {
             RGBColor[
             0.8360503988309712, 0.8723539542869803, 0.9841591349586778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 372}], {
             RGBColor[
             0.6299979927875134, 0.7082451076516956, 0.9655564263132472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 406}], {
             RGBColor[
             0.8900806471760057, 0.9077659645302347, 0.6988562638191269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 417}], {
             RGBColor[
             0.7452877880838611, 0.8009437515388753, 0.9752469796719869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 461}], {
             RGBColor[
             0.8669992096038857, 0.8968058897416262, 0.9792822184041656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 486}], {
             RGBColor[
             0.8622352558727102, 0.8932330485230531, 0.9866566699988166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{80, 493}], {
             RGBColor[
             0.8915600871763152, 0.912093463631398, 0.7609802929384797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 83}], {
             RGBColor[
             0.8721819244967113, 0.9009182081187621, 0.9876706846361336]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 99}], {
             RGBColor[
             0.9086198401868935, 0.9254801001365643, 0.7650800543815806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 237}], {
             RGBColor[
             0.8648552697662895, 0.8950761325134684, 0.9869718617673642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 267}], {
             RGBColor[
             0.906340376624757, 0.9184812574076573, 0.6975246745106891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 278}], {
             RGBColor[
             0.8859909437525565, 0.9116025564457284, 0.9776647627909368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 329}], {
             RGBColor[
             0.8530880154845231, 0.8856932433627962, 0.9858494905492173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 426}], {
             RGBColor[
             0.8468962698264015, 0.8807561134454687, 0.9852589163209091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{81, 486}], {
             RGBColor[
             0.879272872526262, 0.9065723375988691, 0.9883470255893563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 89}], {
             RGBColor[
             0.2718901700216876, 0.4031041858982062, 0.9387951150060494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 105}], {
             RGBColor[
             0.25209194686734443`, 0.382294998083142, 0.9376676354862561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 184}], {
             RGBColor[
             0.2576552479933815, 0.38814238030027126`, 0.9379844572552174]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 195}], {
             RGBColor[
             0.2642152742010554, 0.39503738377422104`, 0.9383580410430554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 225}], {
             RGBColor[
             0.2662639580467382, 0.39719068039009175`, 0.9384747105573108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 263}], {
             RGBColor[
             0.26583963752085393`, 0.39674469261391226`, 0.9384505461310877]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 296}], {
             RGBColor[
             0.28584922180975014`, 0.4173439077491774, 0.9396058846276822]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 342}], {
             RGBColor[
             0.2591328832418887, 0.3896954686339382, 0.9380686063966545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 395}], {
             RGBColor[
             0.26163309800222595`, 0.39232335286982434`, 0.9382109899285194]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 440}], {
             RGBColor[
             0.26997623108034263`, 0.40109251472011487`, 0.9386861190147588]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 447}], {
             RGBColor[
             0.25238928516537673`, 0.3826075194867109, 0.9376845684624564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 453}], {
             RGBColor[
             0.27129272785642566`, 0.40247623630249474`, 0.9387610915585742]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 463}], {
             RGBColor[
             0.26268799213192734`, 0.3934321134842913, 0.9382710645886299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{82, 470}], {
             RGBColor[
             0.25688036525862096`, 0.38732792941563493`, 0.937940328829809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 119}], {
             RGBColor[
             0.9556965383033635, 0.9650210547273206, 0.8984817408494732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 176}], {
             RGBColor[
             0.7638451540938651, 0.8157128228854424, 0.9772513951417543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 197}], {
             RGBColor[
             0.8091856625186589, 0.8516756760168047, 0.981399600787607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 237}], {
             RGBColor[
             0.913419047498675, 0.933799570648643, 0.9916039182408752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 270}], {
             RGBColor[
             0.955384395176871, 0.9648919755228036, 0.9036547602559704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 345}], {
             RGBColor[
             0.7902354483667869, 0.8368716246944006, 0.9795108205407682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 375}], {
             RGBColor[
             0.9394735703012015, 0.9539944639741937, 0.9739704912597569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 426}], {
             RGBColor[
             0.895460047558787, 0.9194795515806435, 0.9898909727944203]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 448}], {
             RGBColor[
             0.7443425082604527, 0.7998796964136958, 0.9757160754212024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{83, 489}], {
             RGBColor[
             0.9554216482771469, 0.9649073806371287, 0.9030373799764648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 131}], {
             RGBColor[
             0.24846167161057395`, 0.3784793486155308, 0.9374608966808939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 135}], {
             RGBColor[
             0.24197053087649611`, 0.37165674814192173`, 0.9370912358188704]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 147}], {
             RGBColor[
             0.24240373141068797`, 0.37211206936985763`, 0.93711590594843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 171}], {
             RGBColor[
             0.2475282592649566, 0.3774982730585261, 0.9374077402286709]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 230}], {
             RGBColor[
             0.22859615804425376`, 0.3575994343110202, 0.9363295850716857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 242}], {
             RGBColor[
             0.22916096004104347`, 0.3581930770201611, 0.9363617497098533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 365}], {
             RGBColor[
             0.22514447908377305`, 0.3539715008744688, 0.9361330170611878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 374}], {
             RGBColor[
             0.24252230770556474`, 0.3722367005739444, 0.9371226586930053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 385}], {
             RGBColor[
             0.2333929402174702, 0.3626411565086264, 0.9366027547202471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{84, 391}], {
             RGBColor[
             0.23722076036640824`, 0.3666644381829753, 0.9368207434149767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 95}], {
             RGBColor[
             0.22064923730827996`, 0.3492467167536353, 0.9358770196921877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 97}], {
             RGBColor[
             0.22297503114412753`, 0.3516912735389574, 0.9360094702104356]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 137}], {
             RGBColor[
             0.21714804821848613`, 0.34556674503205226`, 0.9356776321530691]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 145}], {
             RGBColor[
             0.21743686076267443`, 0.3458703053277671, 0.9356940796002007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 183}], {
             RGBColor[
             0.20959144808050473`, 0.33762427917091264`, 0.9352472949541991]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 286}], {
             RGBColor[
             0.21865790979829205`, 0.3471537052831816, 0.935763616536399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 346}], {
             RGBColor[
             0.21604910573121133`, 0.34441168680094847`, 0.9356150490041585]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 358}], {
             RGBColor[
             0.2199208837213561, 0.34848117095349374`, 0.935835541032915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 404}], {
             RGBColor[
             0.21383193119222793`, 0.3420812957834917, 0.9354887841941792]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 407}], {
             RGBColor[
             0.2142869484175896, 0.3425595477371053, 0.9355146967520258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{85, 408}], {
             RGBColor[
             0.21836004410720744`, 0.3468406295560761, 0.9357466535259444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 90}], {
             RGBColor[
             0.8899814344584336, 0.5901544331035902, 0.2297467504579272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 98}], {
             RGBColor[
             0.9552139147274563, 0.8468459050338089, 0.4866646892725739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 115}], {
             RGBColor[
             0.9181807358610004, 0.8207272885954675, 0.6214818156174652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 124}], {
             RGBColor[
             0.9389228207101663, 0.7935781606519255, 0.2800166062249653]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 136}], {
             RGBColor[
             0.942076876818933, 0.8389236960734718, 0.594023128493258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 168}], {
             RGBColor[
             0.912992655814064, 0.6927519043211215, 0.24885005242438252`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 178}], {
             RGBColor[
             0.9534388639235, 0.8461526483552239, 0.5190456011559075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 253}], {
             RGBColor[
             0.9501124692155603, 0.8447770986590462, 0.5741725699000219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 261}], {
             RGBColor[
             0.897589954080166, 0.6247029436909717, 0.23609548573218275`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 357}], {
             RGBColor[
             0.911167687629582, 0.6855165136042474, 0.2473816401856394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 484}], {
             RGBColor[
             0.9540423951293819, 0.8443401430723285, 0.3591520108030784]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{86, 500}], {
             RGBColor[
             0.8673428769617186, 0.42615530998421236`, 0.20846003809980468`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 107}], {
             RGBColor[
             0.1819624771956669, 0.3085844789930161, 0.9336738659357071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 113}], {
             RGBColor[
             0.17922276129889142`, 0.3057048638774843, 0.9335178431684322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 143}], {
             RGBColor[
             0.1790901316250143, 0.30556546168103244`, 0.933510290104713]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 226}], {
             RGBColor[
             0.17933912709972993`, 0.30582717171218354`, 0.9335244700286423]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 292}], {
             RGBColor[
             0.1791119470402912, 0.3055883910656657, 0.93351153246034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 308}], {
             RGBColor[
             0.17909977333492821`, 0.3055755957294717, 0.9335108391858289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 386}], {
             RGBColor[
             0.17909013095112286`, 0.3055654609727298, 0.9335102900663359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 421}], {
             RGBColor[
             0.17915493384170816`, 0.30563357291947557`, 0.9335139804950874]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 422}], {
             RGBColor[
             0.2066326331143824, 0.33451437704181397`, 0.9350787948190529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 423}], {
             RGBColor[
             0.18353957668712906`, 0.310242110552426, 0.9337636794186364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{87, 446}], {
             RGBColor[
             0.20370226760912918`, 0.33143437709988877`, 0.934911914838616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 166}], {
             RGBColor[
             0.8523652692557177, 0.3906026653424749, 0.19727300714892185`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 167}], {
             RGBColor[
             0.9266401906833595, 0.7379726928092079, 0.5404902319838795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 210}], {
             RGBColor[
             0.8513369203215293, 0.3826983248089265, 0.19628825904818903`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 227}], {
             RGBColor[
             0.8561206468687188, 0.41946814329296433`, 0.20086916099222407`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 243}], {
             RGBColor[
             0.8529581179820884, 0.3951595604413297, 0.19784071975882145`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 326}], {
             RGBColor[
             0.8708928189630238, 0.5066362693068722, 0.21398214224720047`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 348}], {
             RGBColor[
             0.9132608681622556, 0.6818120756635188, 0.2545865809359151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 428}], {
             RGBColor[
             0.8484718113152332, 0.36067584148776255`, 0.1935446274280821]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 434}], {
             RGBColor[
             0.9289063525023188, 0.7389098089590498, 0.5029340660049313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 469}], {
             RGBColor[
             0.8635204022958338, 0.47315984709282155`, 0.20783041706562805`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 474}], {
             RGBColor[
             0.9298536404427284, 0.7393015368665987, 0.48723505332973827`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{88, 495}], {
             RGBColor[
             0.8544062989949438, 0.4062909143031017, 0.1992274995322182]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 133}], {
             RGBColor[
             0.3153376912434113, 0.4454022988525135, 0.9413927055520241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 184}], {
             RGBColor[
             0.271266794829508, 0.4024489790469554, 0.9387596147110557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 192}], {
             RGBColor[
             0.27005817816264466`, 0.4011786462993594, 0.9386907857798661]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 225}], {
             RGBColor[
             0.2798755048828646, 0.4114972791367759, 0.9392498680131491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 235}], {
             RGBColor[
             0.32127172035398965`, 0.45054205661512126`, 0.9417708166396943]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 239}], {
             RGBColor[
             0.31821611673686917`, 0.4478954463410748, 0.9415761162791756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 249}], {
             RGBColor[
             0.28752479280706156`, 0.41953716573797317`, 0.9396854836443249]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 260}], {
             RGBColor[
             0.2855390731059485, 0.4174500484302025, 0.9395723998449554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 280}], {
             RGBColor[
             0.2711970471587578, 0.4023756698227392, 0.938755642684389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 296}], {
             RGBColor[
             0.2994607686458766, 0.4316505064958615, 0.9403810420835206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 424}], {
             RGBColor[
             0.3030480744366626, 0.4347576504686087, 0.9406096220363795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 440}], {
             RGBColor[
             0.2835877779164691, 0.415399113466799, 0.9394612764705972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 453}], {
             RGBColor[
             0.28490427469255214`, 0.4167828350491789, 0.9395362490144127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{89, 470}], {
             RGBColor[
             0.27049191209474743`, 0.40163452816231904`, 0.9387154862856475]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 124}], {
             RGBColor[
             0.9137111635376958, 0.6822566946723914, 0.2591427819494134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 178}], {
             RGBColor[
             0.9282272067510295, 0.7348311823756897, 0.4981717768803556]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 257}], {
             RGBColor[
             0.8618116052496472, 0.4654005988057779, 0.20640455492384144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 261}], {
             RGBColor[
             0.8723782969076955, 0.5133814777114375, 0.21522166145663085`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 272}], {
             RGBColor[
             0.8426763546129947, 0.3190239891395971, 0.18810823554711417`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 306}], {
             RGBColor[
             0.8611746456929213, 0.4612099603827511, 0.20582221997608346`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 317}], {
             RGBColor[
             0.8740850504741097, 0.5211314470341011, 0.21664581846880504`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{90, 357}], {
             RGBColor[
             0.8859560304571115, 0.5741950476247133, 0.2265078159100875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 172}], {
             RGBColor[
             0.33964065051404985`, 0.4686013934649852, 0.9428625798116885]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 303}], {
             RGBColor[
             0.3164436833902854, 0.44818690517109605`, 0.9413962957337874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 366}], {
             RGBColor[
             0.29631757138809034`, 0.4270330853875859, 0.9402501434291768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 435}], {
             RGBColor[
             0.29287326479962417`, 0.4234129007814571, 0.9400539952643586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{91, 473}], {
             RGBColor[
             0.32723005291391416`, 0.4578519575985201, 0.9420717875068684]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 101}], {
             RGBColor[
             0.5649851581111299, 0.6577194295027604, 0.9588968477367864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 128}], {
             RGBColor[
             0.5519404005403256, 0.6471291076471498, 0.9578699166362912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 140}], {
             RGBColor[
             0.554385826473297, 0.649114414584719, 0.9580624295236251]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 169}], {
             RGBColor[
             0.5509398864490034, 0.6463168452351683, 0.9577911525020184]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 175}], {
             RGBColor[
             0.7824339265203888, 0.8300343229197356, 0.9610969915433571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 204}], {
             RGBColor[
             0.5555153199743827, 0.6500313882920026, 0.9581513473895016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 219}], {
             RGBColor[
             0.5677032440041356, 0.6599260940790765, 0.9591108254149605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 274}], {
             RGBColor[
             0.5359359247795917, 0.6341359532311694, 0.9566099856780799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 320}], {
             RGBColor[
             0.7988700431185324, 0.8415596078670635, 0.9004611644475569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 334}], {
             RGBColor[
             0.505970833581321, 0.6084373708863062, 0.9546299931971096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 337}], {
             RGBColor[
             0.7346741443689091, 0.7924685201915558, 0.974450773685277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 361}], {
             RGBColor[
             0.6266695180780231, 0.7077693478258749, 0.9637721633771799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 363}], {
             RGBColor[
             0.506974473041424, 0.6093066729422614, 0.9546939442160238]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 370}], {
             RGBColor[
             0.6002904630940367, 0.6863818665737486, 0.9616762106726342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{92, 498}], {
             RGBColor[
             0.5355135500520953, 0.6337930503996233, 0.9565767347923217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 108}], {
             RGBColor[
             0.27719798724909794`, 0.408683038339264, 0.9390973873449386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 163}], {
             RGBColor[
             0.26813879509029465`, 0.39916125299440397`, 0.9385814797533685]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 187}], {
             RGBColor[
             0.2669566877883537, 0.3979187832701322, 0.9385141604912941]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 189}], {
             RGBColor[
             0.26453032177670965`, 0.3953685187514038, 0.9383759825364177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 206}], {
             RGBColor[
             0.30600971855859727`, 0.43582355730741806`, 0.940853232846973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 266}], {
             RGBColor[
             0.2794030113306438, 0.41100065845557043`, 0.9392229602043418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 322}], {
             RGBColor[
             0.26425191426448674`, 0.3950758948040016, 0.9383601276404636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 364}], {
             RGBColor[
             0.2639259772143767, 0.39473331429873343`, 0.9383415660076406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{93, 437}], {
             RGBColor[
             0.26255787085876586`, 0.3932953477760335, 0.9382636543746206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 100}], {
             RGBColor[
             0.943316965793535, 0.8656345224892459, 0.6119300548794735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 127}], {
             RGBColor[
             0.5906994451507328, 0.6605608453144329, 0.9482643190369882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 168}], {
             RGBColor[
             0.9331056494970619, 0.8251500560931704, 0.6037137900969318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 213}], {
             RGBColor[
             0.9298124883323949, 0.8120876909328425, 0.6010637208876998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 214}], {
             RGBColor[
             0.5776130969249946, 0.6468062636067821, 0.9475190708650497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 254}], {
             RGBColor[
             0.5959586642234989, 0.6660886180136586, 0.9485638237828649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 302}], {
             RGBColor[
             0.5727842186692342, 0.6417308063914131, 0.9472440733920693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 315}], {
             RGBColor[
             0.5704593476328262, 0.6392872195268108, 0.9471116754258844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 325}], {
             RGBColor[
             0.5672179996830251, 0.6358803573182399, 0.9469270854552878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 368}], {
             RGBColor[
             0.6817603644893816, 0.7470855364406719, 0.9537864521193352]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 401}], {
             RGBColor[
             0.8644357283380311, 0.8946091728083778, 0.9692011064141851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 477}], {
             RGBColor[
             0.6000453532177727, 0.6703839872576882, 0.948796554675374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{94, 500}], {
             RGBColor[
             0.8874558706447166, 0.5585534617562613, 0.5633237757723539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 97}], {
             RGBColor[
             0.22940871371662525`, 0.3584534818416879, 0.936375858915159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 137}], {
             RGBColor[
             0.22358173079098384`, 0.35232895333478276`, 0.9360440208577924]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 145}], {
             RGBColor[
             0.22387054333517215`, 0.3526325136304976, 0.9360604683049241]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 174}], {
             RGBColor[
             0.24687001390337449`, 0.3768064154483368, 0.9373702541291156]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 286}], {
             RGBColor[
             0.22509159237078977`, 0.3539159135859121, 0.9361300052411223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 294}], {
             RGBColor[
             0.2326978312332123, 0.36191055289371626`, 0.9365631692919152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 346}], {
             RGBColor[
             0.22248278830370904`, 0.3511738951036789, 0.9359814377088818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 358}], {
             RGBColor[
             0.2263545662938538, 0.3552433792562242, 0.9362019297376383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 404}], {
             RGBColor[
             0.22026561376472564`, 0.3488435040862222, 0.9358551728989024]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 407}], {
             RGBColor[
             0.22072063099008732`, 0.34932175603983573`, 0.9358810854567492]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 408}], {
             RGBColor[
             0.22479372667970515`, 0.35360283785880653`, 0.9361130422306678]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{95, 430}], {
             RGBColor[
             0.23341097282813747`, 0.36266010992577125`, 0.9366037816507478]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 131}], {
             RGBColor[
             0.2798853921380307, 0.4115076712688437, 0.9392504310777041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 147}], {
             RGBColor[
             0.27382745193814473`, 0.40514039202317054`, 0.9389054403452399]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 157}], {
             RGBColor[
             0.29935267191603787`, 0.43196901661235676`, 0.940359063861802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 171}], {
             RGBColor[
             0.2789519797924134, 0.41052659571183897`, 0.939197274625481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 180}], {
             RGBColor[
             0.2831463385898367, 0.4149351327456384, 0.9394361371539964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 216}], {
             RGBColor[
             0.2810238579235662, 0.4127042709923413, 0.9393152650199811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 238}], {
             RGBColor[
             0.3081578274315908, 0.4401690531459169, 0.9408991236475683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 265}], {
             RGBColor[
             0.3085881199169248, 0.4405417508695841, 0.9409265415042412]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 281}], {
             RGBColor[
             0.27053519804586806`, 0.4016800244414347, 0.938717951356528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 343}], {
             RGBColor[
             0.29452462133405766`, 0.4268944293346082, 0.940084113523619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 392}], {
             RGBColor[
             0.3010815634219416, 0.43378619120311424`, 0.9404575216753974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 433}], {
             RGBColor[
             0.31083399291217784`, 0.4424870131772134, 0.9410696465455513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{96, 465}], {
             RGBColor[
             0.2893936582907169, 0.42150146185421045`, 0.9397919127688803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 104}], {
             RGBColor[
             0.23915408747259903`, 0.3686964875516002, 0.936930843533573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 137}], {
             RGBColor[
             0.2259075246268314, 0.35477351012010483`, 0.9361764713760403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 145}], {
             RGBColor[
             0.2261963371710197, 0.3550770704158197, 0.9361929188231719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 174}], {
             RGBColor[
             0.24919580773922206`, 0.37925097223365895`, 0.9375027046473634]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 294}], {
             RGBColor[
             0.23502362506905988`, 0.3643551096790384, 0.936695619810163]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 346}], {
             RGBColor[
             0.22480858213955662`, 0.353618451889001, 0.9361138882271296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 358}], {
             RGBColor[
             0.2286803601297014, 0.35768793604154625`, 0.9363343802558861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 404}], {
             RGBColor[
             0.2225914076005732, 0.3512880608715443, 0.9359876234171504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 407}], {
             RGBColor[
             0.2230464248259349, 0.3517663128251578, 0.936013535974997]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 408}], {
             RGBColor[
             0.2271195205155527, 0.3560473946441286, 0.9362454927489157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{97, 430}], {
             RGBColor[
             0.23573676666398502`, 0.3651046667110934, 0.9367362321689956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 115}], {
             RGBColor[
             0.9582015589575525, 0.9660972945461519, 0.85752593015656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 124}], {
             RGBColor[
             0.9789436438067185, 0.93894816660261, 0.5160607207640602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 136}], {
             RGBColor[
             0.9820976999154852, 0.9842937020241562, 0.8300672430323528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 253}], {
             RGBColor[
             0.9901332923121124, 0.9901471046097305, 0.8102166844391167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 261}], {
             RGBColor[
             0.9376107771767181, 0.7700729496416561, 0.47213960027127755`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 277}], {
             RGBColor[
             0.8832681348130269, 0.9067408984138945, 0.8502742951726139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 311}], {
             RGBColor[
             0.8710458030481137, 0.8971927199459824, 0.8490560873664715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 319}], {
             RGBColor[
             0.8550622111994015, 0.8847062165139711, 0.8474629923061501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 331}], {
             RGBColor[
             0.9159632164581281, 0.9324175867663749, 0.8534971993423514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 377}], {
             RGBColor[
             0.9881699242791049, 0.9888223570121889, 0.8197885510745015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 484}], {
             RGBColor[
             0.9940632182259341, 0.9897101490230129, 0.5951961253421731]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{98, 488}], {
             RGBColor[
             0.8822995191611039, 0.9059842085048606, 0.8501777526166581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 122}], {
             RGBColor[
             0.930562919133284, 0.740007623770434, 0.37913808172539787`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 267}], {
             RGBColor[
             0.9913420700473246, 0.9817665875606343, 0.479566100729647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 278}], {
             RGBColor[
             0.9709926371751241, 0.9748878865987054, 0.7597061890098948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 329}], {
             RGBColor[
             0.9380897089070905, 0.9489785735157732, 0.7678909167681753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 406}], {
             RGBColor[
             0.992119957252125, 0.9843905837590278, 0.48258804562862445`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 413}], {
             RGBColor[
             0.9837287794830555, 0.9560851708017216, 0.4499899045367475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 476}], {
             RGBColor[
             0.9210569805098886, 0.6812525268241133, 0.37059559494700395`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 486}], {
             RGBColor[
             0.9642745659488295, 0.9698576677518461, 0.7703884518083142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{99, 493}], {
             RGBColor[
             0.9935993972524345, 0.9887180828601909, 0.5447120747479771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 121}], {
             RGBColor[
             0.8793403970281699, 0.48855884043917713`, 0.2187233911438525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 127}], {
             RGBColor[
             0.5785973319473678, 0.5599231651764567, 0.5998463238378839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 168}], {
             RGBColor[
             0.9210035362936968, 0.7245123759551941, 0.25529579489782767`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 200}], {
             RGBColor[
             0.9160214299715226, 0.703780905297789, 0.25123642844933736`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 213}], {
             RGBColor[
             0.9177103751290299, 0.7114500107948662, 0.2526457256885956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 254}], {
             RGBColor[
             0.5838565510201338, 0.5654509378756822, 0.6001458285837606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 259}], {
             RGBColor[
             0.8965277758950481, 0.6152647749950997, 0.2349704456547408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 315}], {
             RGBColor[
             0.5583572344294613, 0.5386495393888345, 0.5986936802267802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 368}], {
             RGBColor[
             0.6696582512860165, 0.6464478563026956, 0.6053684569202311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 401}], {
             RGBColor[
             0.8523336151346661, 0.7939714926704016, 0.620783111215081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 450}], {
             RGBColor[
             0.8744616680202064, 0.45105879141128646`, 0.21405151473609035`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 454}], {
             RGBColor[
             0.915548639391991, 0.7016340736991815, 0.25084192040061865`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 471}], {
             RGBColor[
             0.894013717811025, 0.6013444138663678, 0.23277457969666004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 475}], {
             RGBColor[
             0.8851091218155209, 0.5328997870260774, 0.22424752851506258`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{100, 500}], {
             RGBColor[
             0.8753537574413516, 0.45791578161828494`, 0.21490578057324983`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 128}], {
             RGBColor[
             0.5077879700548952, 0.6112841755347511, 0.9543940755727961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 169}], {
             RGBColor[
             0.506787455963573, 0.6104719131227696, 0.9543153114385234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 197}], {
             RGBColor[
             0.6092291752169602, 0.6927921015850171, 0.9629587335694303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 204}], {
             RGBColor[
             0.5113628894889524, 0.6141864561796039, 0.9546755063260064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 219}], {
             RGBColor[
             0.5235508135187052, 0.6240811619666777, 0.9556349843514654]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 337}], {
             RGBColor[
             0.6905217138834787, 0.756623588079157, 0.9709749326217818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 345}], {
             RGBColor[
             0.5902789610650883, 0.677988050262613, 0.9610699533225915]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 355}], {
             RGBColor[
             0.424769765192925, 0.5405027707410431, 0.9487934456872616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 361}], {
             RGBColor[
             0.5825170875925927, 0.671924415713476, 0.9602963223136847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 362}], {
             RGBColor[
             0.45464713410545365`, 0.5663810460128507, 0.950697205214848]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 363}], {
             RGBColor[
             0.4628220425559936, 0.5734617408298626, 0.9512181031525286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{101, 498}], {
             RGBColor[
             0.491361119566665, 0.5979481182872246, 0.9531008937288266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 109}], {
             RGBColor[
             0.265248780611274, 0.396123664539452, 0.9384168977041816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 185}], {
             RGBColor[
             0.28024115314486164`, 0.4118815986435736, 0.9392706911407418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 186}], {
             RGBColor[
             0.256123983487738, 0.3865329242170628, 0.9378972540069239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 193}], {
             RGBColor[
             0.2821746373958698, 0.4139138131813651, 0.9393808002085031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 196}], {
             RGBColor[
             0.28611844580431445`, 0.41805900587053585`, 0.9396053942630224]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 202}], {
             RGBColor[
             0.2577973086293919, 0.3882916950358828, 0.9379925473982783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 330}], {
             RGBColor[
             0.2914935550351155, 0.4237085864737168, 0.939911498781955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 350}], {
             RGBColor[
             0.3193537748201921, 0.44805203074969097`, 0.941678953195245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 354}], {
             RGBColor[
             0.3191507002330799, 0.44787613774915985`, 0.941666013462126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 414}], {
             RGBColor[
             0.27559776236137046`, 0.40700110052214455`, 0.9390062569049031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 415}], {
             RGBColor[
             0.28177512151681394`, 0.41349389666170766`, 0.9393580483702217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 485}], {
             RGBColor[
             0.2622693737921402, 0.3929921190672394, 0.9382472248934693]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{102, 496}], {
             RGBColor[
             0.27671354998693043`, 0.4081738640616296, 0.9390697993595188]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 118}], {
             RGBColor[
             0.4027319052154037, 0.522513730131029, 0.9470855430392838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 188}], {
             RGBColor[
             0.408816425381794, 0.5277838356822806, 0.9474732432839563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 304}], {
             RGBColor[
             0.4094598762170423, 0.5283411604549934, 0.947514243402197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 319}], {
             RGBColor[
             0.5976226950866923, 0.6831049747415705, 0.9622258440138658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 331}], {
             RGBColor[
             0.6585237003454188, 0.7308163449939742, 0.968260051050067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 449}], {
             RGBColor[
             0.6043292409167387, 0.6883441793156388, 0.9628942898259707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{103, 488}], {
             RGBColor[
             0.6248600030483947, 0.70438296673246, 0.9649406043243738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 112}], {
             RGBColor[
             0.24741859649764936`, 0.37738301053706513`, 0.9374014950963042]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 148}], {
             RGBColor[
             0.2431147548759032, 0.37285940011329033`, 0.9371563976829089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 153}], {
             RGBColor[
             0.24575331572793313`, 0.3756326948631943, 0.937306659820031]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 190}], {
             RGBColor[
             0.24734164292075334`, 0.3773021274486088, 0.9373971127039427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 215}], {
             RGBColor[
             0.26534838496499225`, 0.39622835503049064`, 0.9384225700247744]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 224}], {
             RGBColor[
             0.2727699797429894, 0.40402892169845256`, 0.9388452188681158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 323}], {
             RGBColor[
             0.2429591667599799, 0.3726958671385986, 0.9371475371698791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 351}], {
             RGBColor[
             0.2683095588486911, 0.39934073653152624`, 0.9385912044967868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 356}], {
             RGBColor[
             0.2579557991377684, 0.3884582786090651, 0.9380015731982647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 408}], {
             RGBColor[
             0.23453910043567894`, 0.36384584356871885`, 0.9366680268490819]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 430}], {
             RGBColor[
             0.24315634658411125`, 0.3729031156356836, 0.937158766269162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{104, 452}], {
             RGBColor[
             0.2352635459876256, 0.36460728177631574`, 0.9367092829515442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 112}], {
             RGBColor[
             0.2470843980758506, 0.3770317468063509, 0.9373824629905851]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 148}], {
             RGBColor[
             0.24278055645410443`, 0.37250813638257607`, 0.9371373655771897]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 153}], {
             RGBColor[
             0.24541911730613436`, 0.37528143113248, 0.9372876277143118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 190}], {
             RGBColor[
             0.24700744449895456`, 0.37695086371789455`, 0.9373780805982235]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 195}], {
             RGBColor[
             0.2580285978828387, 0.38853479470584096`, 0.9380057189791005]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 263}], {
             RGBColor[
             0.2596529612026372, 0.3902421035455322, 0.9380982240671327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 323}], {
             RGBColor[
             0.24262496833818112`, 0.37234460340788433`, 0.93712850506416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 342}], {
             RGBColor[
             0.252946206923672, 0.38319287956555814`, 0.9377162843326995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 395}], {
             RGBColor[
             0.2554464216840092, 0.38582076380144426`, 0.9378586678645644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 447}], {
             RGBColor[
             0.24620260884716, 0.3761049304183308, 0.9373322463985014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 453}], {
             RGBColor[
             0.265106051538209, 0.39597364723411466`, 0.9384087694946193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{105, 463}], {
             RGBColor[
             0.2565013158137106, 0.3869295244159112, 0.9379187425246749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 117}], {
             RGBColor[
             0.44946530583261596`, 0.561973649912251, 0.9503446865091629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 139}], {
             RGBColor[
             0.5409452590449157, 0.6382027564556965, 0.9570043388212421]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 140}], {
             RGBColor[
             0.508744701282457, 0.6120608930455363, 0.9544693929596517]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 247}], {
             RGBColor[
             0.5064333598698463, 0.6101844419620349, 0.9542874356969284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 255}], {
             RGBColor[
             0.45772043203322, 0.569123825312507, 0.9508706958509441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 269}], {
             RGBColor[
             0.48339733950661234`, 0.5913638720070653, 0.9525068056899508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 274}], {
             RGBColor[
             0.49029479958875166`, 0.5970824316919869, 0.9530169491141065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 360}], {
             RGBColor[
             0.5486108303756021, 0.6444260125920007, 0.9576078006763067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 369}], {
             RGBColor[
             0.46890138102995677`, 0.5788082013626439, 0.9515831360340911]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 370}], {
             RGBColor[
             0.5546493379031965, 0.6493283450345659, 0.9580831741086608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 425}], {
             RGBColor[
             0.4465990938801403, 0.559491081179018, 0.9501620540180429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 466}], {
             RGBColor[
             0.5106817556791221, 0.6136334810680553, 0.9546218849774213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{106, 468}], {
             RGBColor[
             0.4981161809408796, 0.6034321814228589, 0.9536326769048099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 113}], {
             RGBColor[
             0.18193197659231264`, 0.3085524209250408, 0.9336721289714678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 132}], {
             RGBColor[
             0.5874023021726906, 0.6508098778838103, 0.8735074338464627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 143}], {
             RGBColor[
             0.18179934691843552`, 0.30841301872858895`, 0.9336645759077484]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 209}], {
             RGBColor[
             0.37529763235099667`, 0.4849566561931139, 0.9463994374355724]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 214}], {
             RGBColor[
             0.19223940367108877`, 0.31938618031345734`, 0.9342591216951321]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 273}], {
             RGBColor[
             0.2391065540897807, 0.3686465269524677, 0.9369281365777409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 308}], {
             RGBColor[
             0.18180898862834943`, 0.3084231527770282, 0.9336651249888644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 421}], {
             RGBColor[
             0.18186414913512938`, 0.30848112996703203`, 0.9336682662981228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 423}], {
             RGBColor[
             0.18624879198055028`, 0.31308966759998247`, 0.9339179652216718]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 446}], {
             RGBColor[
             0.2064114829025504, 0.3342819341474452, 0.9350662006416515]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{107, 477}], {
             RGBColor[
             0.21467165996386678`, 0.3429639039643634, 0.9355366055054566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 129}], {
             RGBColor[
             0.3203552344901264, 0.4497120899906687, 0.9417137426958612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 163}], {
             RGBColor[
             0.27605150294224795`, 0.40747801064146116`, 0.939032096759735]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 189}], {
             RGBColor[
             0.27244302962866296`, 0.40368527639846097`, 0.9388265995427842]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 206}], {
             RGBColor[
             0.31392242641055057`, 0.44414031495447526`, 0.9413038498533395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 266}], {
             RGBColor[
             0.28731571918259713`, 0.4193174161026276, 0.9396735772107083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 364}], {
             RGBColor[
             0.27183868506633, 0.4030500719457907, 0.938792183014007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 374}], {
             RGBColor[
             0.2684205085848909, 0.3994573517388918, 0.938597522920128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 410}], {
             RGBColor[
             0.32438785376155105`, 0.4532049421182389, 0.9419706976299311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{108, 437}], {
             RGBColor[
             0.27047057871071917`, 0.40161210542309067`, 0.938714271380987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 185}], {
             RGBColor[
             0.26895237692670115`, 0.40001637908853493`, 0.9386278120353654]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 186}], {
             RGBColor[
             0.24483520726957755`, 0.37466770466202415`, 0.9372543749015474]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 196}], {
             RGBColor[
             0.27482966958615396`, 0.4061937863154972, 0.938962515157646]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 218}], {
             RGBColor[
             0.24296647092511459`, 0.372703544279266, 0.937147953131278]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 295}], {
             RGBColor[
             0.24177394363545715`, 0.37145012248723885`, 0.937080040466318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 300}], {
             RGBColor[
             0.23995882574419874`, 0.3695423184984049, 0.9369766721876371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 335}], {
             RGBColor[
             0.2653660882581673, 0.3962469623140712, 0.938423578201131]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 409}], {
             RGBColor[
             0.24775783308986035`, 0.3777395697043211, 0.9374208141183751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 456}], {
             RGBColor[
             0.23880926652767986`, 0.3683340588755796, 0.9369112064908769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 458}], {
             RGBColor[
             0.24222963005763265`, 0.3719290778091332, 0.9371059911339332]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{109, 496}], {
             RGBColor[
             0.26542477376877, 0.3963086445065909, 0.9384269202541424]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 217}], {
             RGBColor[
             0.29571753049971145`, 0.4271336534107135, 0.9401891973787395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 290}], {
             RGBColor[
             0.2791002706073135, 0.4106824587604797, 0.9392057195680129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 316}], {
             RGBColor[
             0.26110517012024004`, 0.39176846719329617`, 0.9381809252166395]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 340}], {
             RGBColor[
             0.3045749314378675, 0.43480548891742876`, 0.9407535831342266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 355}], {
             RGBColor[
             0.30021105187484454`, 0.43102571577490256`, 0.9404755205872981]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 378}], {
             RGBColor[
             0.2773998635716586, 0.40889522315397336`, 0.9391088839028592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{110, 384}], {
             RGBColor[
             0.27776805045914515`, 0.4092822109171187, 0.9391298516014178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 146}], {
             RGBColor[
             0.2655122364597581, 0.39640057334027434`, 0.9384319011250047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 201}], {
             RGBColor[
             0.28877500860148286`, 0.42085122180616963`, 0.9397566815842886]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 256}], {
             RGBColor[
             0.2812386903435383, 0.41293007348689414`, 0.9393274994084824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 271}], {
             RGBColor[
             0.2644482810539334, 0.39528228875008364`, 0.938371310438624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 284}], {
             RGBColor[
             0.2590919383322233, 0.3896524329378227, 0.9380662746446216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 312}], {
             RGBColor[
             0.28875139009156847`, 0.4208263972547496, 0.9397553365450895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 376}], {
             RGBColor[
             0.2762731715166523, 0.4077109983677596, 0.9390447204571181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 400}], {
             RGBColor[
             0.2845065356159251, 0.4163647860615299, 0.939513598362401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 415}], {
             RGBColor[
             0.2800519643946353, 0.41168274927182613`, 0.9392599171212961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 442}], {
             RGBColor[
             0.2785182841132166, 0.41007075405510884`, 0.939172576298146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 444}], {
             RGBColor[
             0.272192144891436, 0.40342158063262434`, 0.9388123120281499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{111, 464}], {
             RGBColor[
             0.2584790029138965, 0.3890081989508112, 0.9380313688793045]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 148}], {
             RGBColor[
             0.2439596839808273, 0.373747474174165, 0.9372045151454738]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 153}], {
             RGBColor[
             0.24659824483285725`, 0.37652076892406894`, 0.9373547772825959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 190}], {
             RGBColor[
             0.24818657202567745`, 0.37819020150948346`, 0.9374452301665075]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 195}], {
             RGBColor[
             0.25920772540956155`, 0.3897741324974299, 0.9380728685473844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 224}], {
             RGBColor[
             0.2736149088479135, 0.4049169957593272, 0.9388933363306806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 263}], {
             RGBColor[
             0.2608320887293601, 0.39148144133712115`, 0.9381653736354167]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 323}], {
             RGBColor[
             0.24380409586490398`, 0.37358394119947325`, 0.9371956546324439]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 342}], {
             RGBColor[
             0.25412533445039487`, 0.3844322173571471, 0.9377834339009834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 351}], {
             RGBColor[
             0.26915448795361524`, 0.4002288105924009, 0.9386393219593516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 356}], {
             RGBColor[
             0.2588007282426925, 0.3893463526699398, 0.9380496906608295]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 395}], {
             RGBColor[
             0.2566255492107321, 0.38706010159303317`, 0.9379258174328484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 447}], {
             RGBColor[
             0.2473817363738829, 0.37734426820991973`, 0.9373993959667855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 452}], {
             RGBColor[
             0.2361084750925497, 0.3654953558371904, 0.936757400414109]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{112, 463}], {
             RGBColor[
             0.2576804433404335, 0.3881688622075002, 0.9379858920929589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 130}], {
             RGBColor[
             0.17905963034776856`, 0.3055334029047545, 0.9335085531020964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 143}], {
             RGBColor[
             0.17905963102166003`, 0.30553340361305714`, 0.9335085531404735]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 209}], {
             RGBColor[
             0.3725579164542212, 0.4820770410775821, 0.9462434146682975]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 214}], {
             RGBColor[
             0.18949968777431325`, 0.3165065651979255, 0.9341030989278573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 273}], {
             RGBColor[
             0.23636683819300525`, 0.3657669118369359, 0.936772113810466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 302}], {
             RGBColor[
             0.18467080951855291`, 0.3114311079825565, 0.9338281014548768]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 308}], {
             RGBColor[
             0.17906927273157397`, 0.3055435376614964, 0.9335091022215896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 325}], {
             RGBColor[
             0.1791045905323438, 0.30558065890938335`, 0.9335111135180953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 347}], {
             RGBColor[
             0.17905963034776856`, 0.3055334029047545, 0.9335085531020964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 386}], {
             RGBColor[
             0.17905963034776856`, 0.3055334029047545, 0.9335085531020964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 421}], {
             RGBColor[
             0.17912443323835392`, 0.3056015148515002, 0.9335122435308479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 423}], {
             RGBColor[
             0.1835090760837748, 0.31021005248445066`, 0.9337619424543968]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{113, 477}], {
             RGBColor[
             0.2119319440670913, 0.3400842888488316, 0.9353805827381816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 115}], {
             RGBColor[
             0.7109234320173796, 0.7727455262693818, 0.9730887236423327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 203}], {
             RGBColor[
             0.5176225598035007, 0.6192683385358883, 0.9551682905030956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 208}], {
             RGBColor[
             0.41139850447614446`, 0.5294684917353877, 0.9477902381259522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 258}], {
             RGBColor[
             0.4370504632160207, 0.551686929090934, 0.9494247582537205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 289}], {
             RGBColor[
             0.47002476811242727`, 0.580247614655448, 0.9515258518036867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 291}], {
             RGBColor[
             0.577802812280651, 0.6679328507014297, 0.9600375327920143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 297}], {
             RGBColor[
             0.5100213466264654, 0.6130973312480197, 0.954569895157638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 311}], {
             RGBColor[
             0.6237676761079407, 0.7038409516692123, 0.9646188808522442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 349}], {
             RGBColor[
             0.45713997699902986`, 0.5690874562014547, 0.9507048443075143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 359}], {
             RGBColor[
             0.443064873322788, 0.5568963088323743, 0.9498079911473898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 381}], {
             RGBColor[
             0.5349916430046526, 0.6333693427468647, 0.9565356483577385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 397}], {
             RGBColor[
             0.4296132686116584, 0.545245204928905, 0.9489508667899835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{114, 419}], {
             RGBColor[
             0.5066845097134336, 0.6103883367192307, 0.9543072071326079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 124}], {
             RGBColor[
             0.9419104649402625, 0.9128295501642687, 0.6508778471089514]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 136}], {
             RGBColor[
             0.9450645210490293, 0.9581750855858149, 0.964884369377244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 178}], {
             RGBColor[
             0.9564265081535962, 0.965404037867567, 0.8899068420398936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 203}], {
             RGBColor[
             0.7278675078772177, 0.786501490374317, 0.9744226233622142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 253}], {
             RGBColor[
             0.9531001134456565, 0.9640284881713892, 0.9450338107840079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 277}], {
             RGBColor[
             0.8462349559465709, 0.8806222819755531, 0.9850914215175051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 291}], {
             RGBColor[
             0.7880477603543681, 0.8351660025398585, 0.9792918656511329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 297}], {
             RGBColor[
             0.7202662947001824, 0.7803304830864486, 0.9738242280167566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 311}], {
             RGBColor[
             0.8340126241816578, 0.871074103507641, 0.9838732137113628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 381}], {
             RGBColor[
             0.7452365910783697, 0.8006024945852935, 0.9757899812168571]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 419}], {
             RGBColor[
             0.7169294577871506, 0.7776214885576594, 0.9735615399917263]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 439}], {
             RGBColor[
             0.8910404321249454, 0.9159554702009634, 0.9894694259289032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{115, 484}], {
             RGBColor[
             0.9570300393594782, 0.9635915325846716, 0.7300132516870645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 192}], {
             RGBColor[
             0.2516702940273803, 0.3818518142140055, 0.9376436229807996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 280}], {
             RGBColor[
             0.25280916302349343`, 0.3830488377373854, 0.9377084798853226]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 310}], {
             RGBColor[
             0.2727415097182925, 0.40399899789739224`, 0.9388435975423268]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 327}], {
             RGBColor[
             0.25289755432094124`, 0.38314174259533496`, 0.937713513638949]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 399}], {
             RGBColor[
             0.24511345141386065`, 0.3749601568993634, 0.937270220493939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 412}], {
             RGBColor[
             0.24555371763094103`, 0.3754229046080053, 0.9372952930036862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{116, 483}], {
             RGBColor[
             0.27268756010159706`, 0.40394229342964216`, 0.9388405251914673]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 139}], {
             RGBColor[
             0.47255522666265165`, 0.5807190878311534, 0.9521624096580703]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 140}], {
             RGBColor[
             0.44035466890019287`, 0.5545772244209933, 0.9496274637964799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 154}], {
             RGBColor[
             0.34530823850037556`, 0.4735103733174856, 0.9432237135065259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 247}], {
             RGBColor[
             0.4380433274875822, 0.5527007733374919, 0.9494455065337566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 255}], {
             RGBColor[
             0.38933039965095584`, 0.511640156687964, 0.9460287666877722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 269}], {
             RGBColor[
             0.41500730712434825`, 0.5338802033825223, 0.947664876526779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 338}], {
             RGBColor[
             0.3505903006321732, 0.47808543005188675`, 0.9435602818348199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 369}], {
             RGBColor[
             0.40051134864769267`, 0.5213245327381009, 0.9467412068709193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 390}], {
             RGBColor[
             0.34091437037852435`, 0.46896566133560236`, 0.9429707972165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 425}], {
             RGBColor[
             0.3782090614978762, 0.502007412554475, 0.9453201248548712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{117, 466}], {
             RGBColor[
             0.44229172329685795`, 0.5561498124435122, 0.9497799558142495]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 141}], {
             RGBColor[
             0.31734549257895406`, 0.4492904482488255, 0.9414419520628983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 151}], {
             RGBColor[
             0.31595121433390305`, 0.44790234871507695`, 0.9413597168905753]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 188}], {
             RGBColor[
             0.3311926249986076, 0.4612841383736176, 0.9423242790961401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 304}], {
             RGBColor[
             0.3318360758338559, 0.46184146314633034`, 0.9423652792143808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 310}], {
             RGBColor[
             0.3109325878407584, 0.44262745407148385`, 0.9410739135361832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 327}], {
             RGBColor[
             0.2910886324434072, 0.42177019876942656`, 0.9399438296328053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{118, 483}], {
             RGBColor[
             0.31087863822406303`, 0.44257074960373377`, 0.9410708411853237]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 197}], {
             RGBColor[
             0.8441364985929255, 0.8770550844901885, 0.8875786005274353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 237}], {
             RGBColor[
             0.9483698835729416, 0.9591789791220269, 0.8977829179807035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 270}], {
             RGBColor[
             0.9903352312511376, 0.9902713839961873, 0.8098337599957988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 309}], {
             RGBColor[
             0.9918390696706652, 0.9889511495464178, 0.6437403499501158]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 320}], {
             RGBColor[
             0.9896249360090673, 0.9899776586598361, 0.8216051903420669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 345}], {
             RGBColor[
             0.8251862844410536, 0.8622510331677843, 0.8856898202805965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 375}], {
             RGBColor[
             0.9744244063754681, 0.9793738724475776, 0.8801494909995853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 426}], {
             RGBColor[
             0.9304108836330538, 0.9448589600540273, 0.8960699725342486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{119, 489}], {
             RGBColor[
             0.9903724843514137, 0.9902867891105125, 0.8092163797162932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 123}], {
             RGBColor[
             0.20719251066229882`, 0.33510284384296096`, 0.9351106790171422]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 125}], {
             RGBColor[
             0.2080475453125366, 0.33600153947268885`, 0.9351593719755629]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 177}], {
             RGBColor[
             0.20805903153131503`, 0.3360136122168933, 0.9351600260987298]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 438}], {
             RGBColor[
             0.21444303080234048`, 0.3427236002196732, 0.9355235854129342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 455}], {
             RGBColor[
             0.2056810719300792, 0.33351422590464763`, 0.9350246048173154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{120, 457}], {
             RGBColor[
             0.21450528797873675`, 0.3427890364593986, 0.9355271308670288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 161}], {
             RGBColor[
             0.9088989497892817, 0.5955852022276555, 0.2954383174204215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 200}], {
             RGBColor[
             0.8641469744095227, 0.4273429033856967, 0.2064477599128205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 213}], {
             RGBColor[
             0.86583591956703, 0.4350120088827739, 0.20785705715207875`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 259}], {
             RGBColor[
             0.8446533203330481, 0.33882677308300735`, 0.1901817771182239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 341}], {
             RGBColor[
             0.9105196563022746, 0.6003916270804778, 0.3579070077274834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 450}], {
             RGBColor[
             0.8225872124582064, 0.17462078949919407`, 0.16926284619957344`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 454}], {
             RGBColor[
             0.8636741838299911, 0.42519607178708907`, 0.20605325186410173`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 469}], {
             RGBColor[
             0.8439483097229172, 0.3356254845618147, 0.18959349898373934`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 471}], {
             RGBColor[
             0.842139262249025, 0.3249064119542755, 0.18798591116014318`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 475}], {
             RGBColor[
             0.8332346662535209, 0.256461785113985, 0.17945885997854572`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 491}], {
             RGBColor[
             0.9108136867178351, 0.6010205284083265, 0.38991040391585896`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{121, 500}], {
             RGBColor[
             0.8234793018793516, 0.18147777970619255`, 0.1701171120367329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 150}], {
             RGBColor[
             0.8444744803276283, 0.32854420856354566`, 0.1896617078466737]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 159}], {
             RGBColor[
             0.8441272348319537, 0.3258751275198433, 0.1893291851678579]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 233}], {
             RGBColor[
             0.8553320507775657, 0.4120002528594733, 0.20005892957140564`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 267}], {
             RGBColor[
             0.9282834555711476, 0.7330087810415269, 0.3115827018545064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 406}], {
             RGBColor[
             0.929061342775948, 0.7356327772399205, 0.3146046467534838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 413}], {
             RGBColor[
             0.9206701650068785, 0.7073273642826143, 0.2820065056616069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 476}], {
             RGBColor[
             0.8579983660337116, 0.432494720305006, 0.20261219607186334`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{122, 493}], {
             RGBColor[
             0.9305407827762575, 0.7399602763410837, 0.37672867587283654`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 125}], {
             RGBColor[
             0.2078185513522534, 0.33576085230137553`, 0.9351463311082908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 177}], {
             RGBColor[
             0.2078300375710318, 0.33577292504558, 0.935146985231458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 438}], {
             RGBColor[
             0.21421403684205725`, 0.34248291304835987`, 0.9355105445456623]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{123, 455}], {
             RGBColor[
             0.20545207796979598`, 0.3332735387333343, 0.9350115639500436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 136}], {
             RGBColor[
             0.9658066058981951, 0.931025957642273, 0.6234191599847442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 178}], {
             RGBColor[
             0.977168593002762, 0.938254909924025, 0.5484416326473938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 253}], {
             RGBColor[
             0.9738421982948224, 0.9368793602278473, 0.603568601391508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 261}], {
             RGBColor[
             0.9213196831594281, 0.7168052052597729, 0.265491517223669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 357}], {
             RGBColor[
             0.9348974167088442, 0.7776187751730486, 0.27677767167712564`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{124, 484}], {
             RGBColor[
             0.9777721242086441, 0.9364424046411297, 0.38854804229456463`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 177}], {
             RGBColor[
             0.20868507222126964`, 0.3366716206753079, 0.9351956781898786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 438}], {
             RGBColor[
             0.2150690714922951, 0.34338160867808776`, 0.9355592375040829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 455}], {
             RGBColor[
             0.20630711262003382`, 0.3341722343630622, 0.9350602569084642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{125, 457}], {
             RGBColor[
             0.21513132866869134`, 0.3434470449178132, 0.9355627829581774]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 144}], {
             RGBColor[
             0.24868278916139275`, 0.37871175718110384`, 0.937473488998299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 279}], {
             RGBColor[
             0.26484901945855754`, 0.3957034902216259, 0.9383941318979281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 285}], {
             RGBColor[
             0.28277807837083513`, 0.4140236211798849, 0.9394343678430408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{126, 481}], {
             RGBColor[
             0.28467725623571494`, 0.41566859359098884`, 0.9395553817772139]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 130}], {
             RGBColor[
             0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 168}], {
             RGBColor[
             0.5683860156508949, 0.5194386987803812, 0.5916300590553423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 179}], {
             RGBColor[
             0.20245447418328588`, 0.33012286709465477`, 0.9348408548489592]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 200}], {
             RGBColor[
             0.5634039093287206, 0.4987072281229762, 0.587570692606852]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 213}], {
             RGBColor[
             0.5650928544862279, 0.5063763336200533, 0.5889799898461102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 254}], {
             RGBColor[
             0.23123903037733173`, 0.3603772607008694, 0.9364800927412753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 302}], {
             RGBColor[
             0.2080645848230672, 0.3360194490786239, 0.9351603423504797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 315}], {
             RGBColor[
             0.20573971378665917`, 0.3335758622140216, 0.9350279443842948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 325}], {
             RGBColor[
             0.20249836583685807`, 0.33016900000545074`, 0.9348433544136983]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 347}], {
             RGBColor[
             0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 368}], {
             RGBColor[
             0.3170407306432145, 0.44137417912788274`, 0.9417027210777457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 386}], {
             RGBColor[
             0.20245340565228287`, 0.33012174400082184`, 0.9348407939976993]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 401}], {
             RGBColor[
             0.499716094491864, 0.5888978154955886, 0.9571173753725956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{127, 454}], {
             RGBColor[
             0.562931118749189, 0.49656039652436856`, 0.5871761845581333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 169}], {
             RGBColor[
             0.4937426983927686, 0.5998815912671589, 0.9532883803380281]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 197}], {
             RGBColor[
             0.5961844176461558, 0.6822017797294064, 0.9619318024689351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 204}], {
             RGBColor[
             0.4983181319181479, 0.6035961343239933, 0.9536485752255113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 345}], {
             RGBColor[
             0.5772342034942839, 0.6673977284070023, 0.9600430222220963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 355}], {
             RGBColor[
             0.4117250076221206, 0.5299124488854325, 0.9477665145867664]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 362}], {
             RGBColor[
             0.4416023765346493, 0.55579072415724, 0.9496702741143528]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{128, 498}], {
             RGBColor[
             0.4783163619958606, 0.5873577964316139, 0.9520739626283314]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 170}], {
             RGBColor[
             0.3261401713486173, 0.4557924254151241, 0.9420431862919051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 206}], {
             RGBColor[
             0.3491669657996257, 0.47685260895882275`, 0.9434695881978956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 265}], {
             RGBColor[
             0.3383071396578693, 0.46744637338556605`, 0.9427776096791101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 266}], {
             RGBColor[
             0.32256025857167225`, 0.4520297101069751, 0.9418393155552645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 328}], {
             RGBColor[
             0.3704563897071251, 0.49529243790994043`, 0.944826131463783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 410}], {
             RGBColor[
             0.3596323931506261, 0.48591723612258636`, 0.9441364359744873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{129, 433}], {
             RGBColor[
             0.3405530126531223, 0.4693916356931953, 0.94292071472042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 143}], {
             RGBColor[
             0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 179}], {
             RGBColor[
             0.17892806853100302`, 0.30539512309383293`, 0.93350106085126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 214}], {
             RGBColor[
             0.1893670574265447, 0.316367162293171, 0.9340955458257609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 254}], {
             RGBColor[
             0.20771262472504887`, 0.3356495167000475, 0.935140298743576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 302}], {
             RGBColor[
             0.18453817917078433`, 0.311291705077802, 0.9338205483527805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 315}], {
             RGBColor[
             0.1822133081343763, 0.30884811821319974`, 0.9336881503865955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 325}], {
             RGBColor[
             0.1789719601845752, 0.3054412560046289, 0.9335035604159989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 347}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 368}], {
             RGBColor[
             0.2935143249909316, 0.4166464351270609, 0.9403629270800464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 386}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 421}], {
             RGBColor[
             0.17899180289058533`, 0.3054621119467458, 0.9335046904287516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{130, 477}], {
             RGBColor[
             0.2117993137193227, 0.3399448859440771, 0.9353730296360853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 135}], {
             RGBColor[
             0.25711790914467114`, 0.38757760310102596`, 0.937953856602705]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 147}], {
             RGBColor[
             0.257551109678863, 0.38803292432896186`, 0.9379785267322645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 170}], {
             RGBColor[
             0.28014480934839103`, 0.4117803352049335, 0.9392652045040607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 171}], {
             RGBColor[
             0.26267563753313167`, 0.39341912801763035`, 0.9382703610125054]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 216}], {
             RGBColor[
             0.26474751566428445`, 0.3955968032981327, 0.9383883514070055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 238}], {
             RGBColor[
             0.29188148517230905`, 0.42306158545170824`, 0.9399722100345929]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 265}], {
             RGBColor[
             0.29231177765764305`, 0.42343428317537546`, 0.9399996278912657]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 374}], {
             RGBColor[
             0.2576696859737398, 0.38815755553304865`, 0.9379852794768397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 385}], {
             RGBColor[
             0.24854031848564526`, 0.3785620114677306, 0.9374653755040816]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 391}], {
             RGBColor[
             0.2523681386345833, 0.3825852931420795, 0.9376833641988113]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{131, 433}], {
             RGBColor[
             0.29455765065289613`, 0.4253795454830047, 0.9401427329325757]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 209}], {
             RGBColor[
             0.7780282420345992, 0.8243344980363514, 0.8860787195432924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 233}], {
             RGBColor[
             0.9166463543771588, 0.6614692040973338, 0.5010749461233683]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 273}], {
             RGBColor[
             0.6418371637733833, 0.7080243687957053, 0.8766074186854609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{132, 423}], {
             RGBColor[
             0.5889794016641527, 0.6524675094432201, 0.8735972473293918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 151}], {
             RGBColor[
             0.3259839947322987, 0.4565922388339624, 0.9419989967859217]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 155}], {
             RGBColor[
             0.4555313931992919, 0.5659235600860384, 0.9510915748153721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 181}], {
             RGBColor[
             0.3829354312034995, 0.5061011564392373, 0.9456212849531489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 225}], {
             RGBColor[
             0.3097114792684619, 0.4394887933443991, 0.9410723011032855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 235}], {
             RGBColor[
             0.3511076947395869, 0.47853357082274445`, 0.9435932497298307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 239}], {
             RGBColor[
             0.34805209112246643`, 0.47588696054869806`, 0.943398549369312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 249}], {
             RGBColor[
             0.3173607671926588, 0.44752867994559636`, 0.9415079167344612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 260}], {
             RGBColor[
             0.31537504749154577`, 0.44544156263782575`, 0.9413948329350919]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 262}], {
             RGBColor[
             0.4106297397776527, 0.5294703750419166, 0.9475567521778445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 296}], {
             RGBColor[
             0.3292967430314739, 0.4596420207034847, 0.942203475173657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 332}], {
             RGBColor[
             0.3736828594731001, 0.4980870438541423, 0.9450317192642157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 344}], {
             RGBColor[
             0.404458323018091, 0.5244601408973477, 0.9470709156438875]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 424}], {
             RGBColor[
             0.33288404882225986`, 0.46274916467623195`, 0.942432055126516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{133, 440}], {
             RGBColor[
             0.31342375230206637`, 0.44339062767442217`, 0.9412837095607336]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 138}], {
             RGBColor[
             0.2265863896100655, 0.3554870402600099, 0.9362151317325447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 251}], {
             RGBColor[
             0.24587579480159133`, 0.37576142813523083`, 0.9373136348220843]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 305}], {
             RGBColor[
             0.2421591297202534, 0.37185497748456803`, 0.9371019762440154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 367}], {
             RGBColor[
             0.23152572380893705`, 0.3606785936749, 0.9364964195080803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 416}], {
             RGBColor[
             0.24737003573452257`, 0.37733197009608865`, 0.9373987296326833]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 438}], {
             RGBColor[
             0.22733547187831532`, 0.35627437321849936`, 0.9362577908595535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 457}], {
             RGBColor[
             0.22739772905471156`, 0.3563398094582248, 0.936261336313648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{134, 499}], {
             RGBColor[
             0.2469625122439105, 0.37690363706897373`, 0.93737552177277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 147}], {
             RGBColor[
             0.2510599689447852, 0.3812103238553528, 0.9376088658702408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 170}], {
             RGBColor[
             0.2736536686143132, 0.40495773473132446`, 0.9388955436420372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 171}], {
             RGBColor[
             0.25618449679905386`, 0.3865965275440213, 0.9379007001504819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 216}], {
             RGBColor[
             0.25825637493020664`, 0.38877420282452363`, 0.938018690544982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 385}], {
             RGBColor[
             0.24204917775156742`, 0.37173941099412156`, 0.9370957146420581]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{135, 391}], {
             RGBColor[
             0.24587699790050546`, 0.37576269266847045`, 0.9373137033367878]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 253}], {
             RGBColor[
             0.9769962544035893, 0.9822248956493935, 0.9175751236598007]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 261}], {
             RGBColor[
             0.924473739268195, 0.762150740681319, 0.5794980394919615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 277}], {
             RGBColor[
             0.8701310969045036, 0.8988186894535575, 0.9576327343932979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 291}], {
             RGBColor[
             0.8119439013123007, 0.853362410017863, 0.9518331785269256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 311}], {
             RGBColor[
             0.8579087651395905, 0.8892705109856455, 0.9564145265871555]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 319}], {
             RGBColor[
             0.8419251732908781, 0.8767840075536342, 0.9548214315268342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 377}], {
             RGBColor[
             0.9750328863705816, 0.980900148051852, 0.9271469902951855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 484}], {
             RGBColor[
             0.980926180317411, 0.981787940062676, 0.7025545645628573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{136, 488}], {
             RGBColor[
             0.8691624812525807, 0.8980619995445237, 0.9575361918373422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 145}], {
             RGBColor[
             0.2203693542453783, 0.34895254190891456`, 0.9358610807658054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 183}], {
             RGBColor[
             0.2125239415632086, 0.34070651575206007`, 0.9354142961198038]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 346}], {
             RGBColor[
             0.21898159921391522`, 0.34749392338209584`, 0.9357820501697631]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 358}], {
             RGBColor[
             0.22285337720406, 0.3515634075346411, 0.9360025421985196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 404}], {
             RGBColor[
             0.2167644246749318, 0.34516353236463915`, 0.9356557853597838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 407}], {
             RGBColor[
             0.2172194419002935, 0.34564178431825265`, 0.9356816979176306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 408}], {
             RGBColor[
             0.2212925375899113, 0.34992286613722345`, 0.9359136546915492]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{137, 430}], {
             RGBColor[
             0.22990978373834364`, 0.3589801382041882, 0.9364043941116291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 352}], {
             RGBColor[
             0.22389864331585435`, 0.3526620484918363, 0.9360620685572537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 367}], {
             RGBColor[
             0.22490572664447084`, 0.3537205569229832, 0.9361194204629721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{138, 457}], {
             RGBColor[
             0.22077773189024535`, 0.349381772706308, 0.9358843372685399]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 140}], {
             RGBColor[
             0.5318346221124927, 0.6308063309644387, 0.9562871161085591]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 247}], {
             RGBColor[
             0.529523280699882, 0.6289298798809373, 0.9561051588458358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 255}], {
             RGBColor[
             0.4808103528632557, 0.5878692632314095, 0.9526884189998513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 269}], {
             RGBColor[
             0.506487260336648, 0.6101093099259678, 0.9543245288388581]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 274}], {
             RGBColor[
             0.5133847204187874, 0.6158278696108893, 0.9548346722630138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 360}], {
             RGBColor[
             0.5717007512056378, 0.6631714505109032, 0.9594255238252141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 369}], {
             RGBColor[
             0.49199130185999246`, 0.5975536392815464, 0.9534008591829983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 370}], {
             RGBColor[
             0.5777392587332322, 0.6680737829534684, 0.9599008972575682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 425}], {
             RGBColor[
             0.469689014710176, 0.5782365190979204, 0.9519797771669503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 466}], {
             RGBColor[
             0.5337716765091578, 0.6323789189869576, 0.9564396081263286]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{139, 468}], {
             RGBColor[
             0.5212061017709153, 0.6221776193417614, 0.9554504000537172]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 169}], {
             RGBColor[
             0.4961881243257401, 0.601866898204728, 0.953480893225362]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 204}], {
             RGBColor[
             0.5007635578511195, 0.6055814412615623, 0.9538410881128452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 219}], {
             RGBColor[
             0.5129514818808725, 0.6154761470486363, 0.9548005661383041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 244}], {
             RGBColor[
             0.42103754660959536`, 0.5378457039996745, 0.9483965938455836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 247}], {
             RGBColor[
             0.4973227229374232, 0.6027880164707773, 0.9535702129842454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 255}], {
             RGBColor[
             0.4486097951007969, 0.5617273998212495, 0.950153473138261]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 274}], {
             RGBColor[
             0.4811841626563286, 0.5896860062007292, 0.9522997264014235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 334}], {
             RGBColor[
             0.4512190714580578, 0.563987423855866, 0.9503197339204532]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 361}], {
             RGBColor[
             0.5719177559547599, 0.6633194007954346, 0.9594619041005235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 363}], {
             RGBColor[
             0.4522227109181607, 0.5648567259118211, 0.9503836849393674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 369}], {
             RGBColor[
             0.4597907440975337, 0.5714117758713864, 0.950865913321408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 370}], {
             RGBColor[
             0.5455387009707735, 0.6419319195433083, 0.9573659513959778]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 425}], {
             RGBColor[
             0.4374884569477172, 0.5520946556877604, 0.9494448313053598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{140, 466}], {
             RGBColor[
             0.5015711187466989, 0.6062370555767975, 0.9539046622647382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 188}], {
             RGBColor[
             0.32343001274534444`, 0.45456055380007726`, 0.9418296523075707]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 220}], {
             RGBColor[
             0.32424804297229537`, 0.4552690904672675, 0.9418817764702763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 240}], {
             RGBColor[
             0.2831042170303842, 0.4148134850118461, 0.939436571482416]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 304}], {
             RGBColor[
             0.3240734635805927, 0.45511787857278996`, 0.9418706524258115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 310}], {
             RGBColor[
             0.3031699755874952, 0.4359038694979436, 0.9405792867476138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{141, 429}], {
             RGBColor[
             0.30159042381675216`, 0.434243660437526, 0.9404893336110074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 173}], {
             RGBColor[
             0.8420436305365226, 0.8765386852966244, 0.9380905002853989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 222}], {
             RGBColor[
             0.5711190039988594, 0.6615355308329243, 0.9600580034664301]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 241}], {
             RGBColor[
             0.7025032226254809, 0.7675201238280478, 0.9709826140315919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 402}], {
             RGBColor[
             0.6259177691187879, 0.7063115685381091, 0.9642924066530247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 417}], {
             RGBColor[
             0.7002784838355302, 0.7657821409766972, 0.9707608728603756]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{142, 461}], {
             RGBColor[
             0.8219899053555546, 0.8616442791794481, 0.9747961115925544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 179}], {
             RGBColor[
             0.17892806920489446`, 0.30539512380213557`, 0.933501060889637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 214}], {
             RGBColor[
             0.18936705810043614`, 0.31636716300147366`, 0.934095545864138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 226}], {
             RGBColor[
             0.17917599682249857`, 0.3056557114477564, 0.9335151800006836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 273}], {
             RGBColor[
             0.23623420851912813`, 0.365627509640484, 0.9367645607467467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 283}], {
             RGBColor[
             0.18007058028918088`, 0.3065959753911073, 0.9335661252056935]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 292}], {
             RGBColor[
             0.1789488167630598, 0.30541693080123855`, 0.9335022424323813]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 302}], {
             RGBColor[
             0.1845381798446758, 0.31129170578610466`, 0.9338205483911577]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 308}], {
             RGBColor[
             0.17893664305769685`, 0.3054041354650445, 0.9335015491578702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 325}], {
             RGBColor[
             0.17897196085846667`, 0.30544125671293154`, 0.9335035604543761]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 347}], {
             RGBColor[
             0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 386}], {
             RGBColor[
             0.17892700067389145`, 0.30539400070830264`, 0.9335010000383772]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 421}], {
             RGBColor[
             0.1789918035644768, 0.3054621126550484, 0.9335046904671287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 423}], {
             RGBColor[
             0.1833764464098977, 0.31007065028799885`, 0.9337543893906777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 446}], {
             RGBColor[
             0.20353913733189777`, 0.3312629168354616, 0.9349026248106573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{143, 477}], {
             RGBColor[
             0.21179931439321417`, 0.33994488665237976`, 0.9353730296744625]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 279}], {
             RGBColor[
             0.2623939933592224, 0.3931231021335797, 0.9382543217934566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{144, 494}], {
             RGBColor[
             0.25236564813326057`, 0.3825826754672824, 0.9376832223684453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 183}], {
             RGBColor[
             0.21281275410739692`, 0.3410100760477749, 0.9354307435669353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 286}], {
             RGBColor[
             0.22187921582518422`, 0.3505395021600439, 0.9359470651491353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 294}], {
             RGBColor[
             0.22948545468760678`, 0.35853414146784807`, 0.9363802291999281]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 346}], {
             RGBColor[
             0.21927041175810352`, 0.3477974836778107, 0.9357984976168947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 358}], {
             RGBColor[
             0.2231421897482483, 0.351866967830356, 0.9360189896456512]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 404}], {
             RGBColor[
             0.2170532372191201, 0.345467092660354, 0.9356722328069155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 407}], {
             RGBColor[
             0.2175082544444818, 0.34594534461396753`, 0.9356981453647621]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 408}], {
             RGBColor[
             0.2215813501340996, 0.35022642643293833`, 0.9359301021386808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{145, 430}], {
             RGBColor[
             0.23019859628253192`, 0.35928369849990305`, 0.9364208415587607]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 201}], {
             RGBColor[
             0.28119600247616383`, 0.41288520583171645`, 0.9393250683975864]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 211}], {
             RGBColor[
             0.2444868180291041, 0.37430152548113294`, 0.9372345346496982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 271}], {
             RGBColor[
             0.25686927492861433`, 0.3873162727756304, 0.9379396972519218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 284}], {
             RGBColor[
             0.25151293220690424`, 0.3816864169633695, 0.9376346614579194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 312}], {
             RGBColor[
             0.28117238396624933`, 0.41286038128029634`, 0.9393237233583873]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 376}], {
             RGBColor[
             0.2686941653913333, 0.39974498239330636`, 0.9386131072704159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 400}], {
             RGBColor[
             0.276927529490606, 0.4083987700870767, 0.9390819851756989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 415}], {
             RGBColor[
             0.27247295826931617`, 0.4037167332973729, 0.9388283039345939]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 442}], {
             RGBColor[
             0.2709392779878975, 0.40210473808065567`, 0.9387409631114438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 444}], {
             RGBColor[
             0.2646131387661169, 0.39545556465817117`, 0.9383806988414477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 464}], {
             RGBColor[
             0.25089999678857744`, 0.38104218297635795`, 0.9375997556926023]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{146, 497}], {
             RGBColor[
             0.24696343657246012`, 0.3769046085968852, 0.9373755744119134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 171}], {
             RGBColor[
             0.2566176973332457, 0.3870518487719572, 0.9379253702800414]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 216}], {
             RGBColor[
             0.2586895754643985, 0.38922952405245953`, 0.9380433606745415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 238}], {
             RGBColor[
             0.2858235449724231, 0.4166943062060351, 0.9396272193021288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 385}], {
             RGBColor[
             0.24248237828575928`, 0.37219473222205746`, 0.9371203847716176]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{147, 391}], {
             RGBColor[
             0.24631019843469731`, 0.37621801389640636`, 0.9373383734663472]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 153}], {
             RGBColor[
             0.2422944032111111, 0.37199715850029413`, 0.9371096798692006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 190}], {
             RGBColor[
             0.2438827304039313, 0.37366659108570865`, 0.9372001327531121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 195}], {
             RGBColor[
             0.2549038837878154, 0.3852505220736551, 0.9378277711339891]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 323}], {
             RGBColor[
             0.23950025424315785`, 0.36906033077569844`, 0.9369505572190486]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 342}], {
             RGBColor[
             0.2498214928286487, 0.3799086069333723, 0.9375383364875882]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 351}], {
             RGBColor[
             0.26485064633186906`, 0.3957052001686261, 0.9383942245459564]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 356}], {
             RGBColor[
             0.2544968866209464, 0.384822742246165, 0.9378045932474341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 452}], {
             RGBColor[
             0.23180463347080354`, 0.3609717454134156, 0.9365123030007138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{148, 463}], {
             RGBColor[
             0.25337660171868737`, 0.3836452517837254, 0.9377407946795635]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 158}], {
             RGBColor[
             0.3556980515257828, 0.48250950715290686`, 0.943885743205154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 165}], {
             RGBColor[
             0.3889540140770109, 0.511314150421502, 0.9460047837318252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 182}], {
             RGBColor[
             0.36623071660169665`, 0.4916323722545241, 0.9445568753101211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 187}], {
             RGBColor[
             0.30925143443909986`, 0.4382007802607746, 0.9410755580672832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 275}], {
             RGBColor[
             0.38378936730216673`, 0.5068407929678266, 0.9456756970062499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 282}], {
             RGBColor[
             0.48076658116172494`, 0.586646877963116, 0.9530129031646457]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 324}], {
             RGBColor[
             0.361776111320833, 0.4877740170552114, 0.9442730318006773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{149, 441}], {
             RGBColor[
             0.4020035872776604, 0.5226170348372846, 0.946836290996886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 159}], {
             RGBColor[
             0.821097410502475, 0.1631695188320622, 0.16783621016427433`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 233}], {
             RGBColor[
             0.832302226448087, 0.24929464417169217`, 0.1785659545678221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 267}], {
             RGBColor[
             0.9052536312416688, 0.5703031723537458, 0.2900897268509228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 406}], {
             RGBColor[
             0.9060315184464693, 0.5729271685521393, 0.29311167174990027`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 413}], {
             RGBColor[
             0.8976403406773998, 0.5446217555948332, 0.26051353065802335`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 443}], {
             RGBColor[
             0.8779783180841267, 0.47195372718941886`, 0.21716686938390278`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{150, 476}], {
             RGBColor[
             0.834968541704233, 0.26978911161722496`, 0.18111922106827977`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 188}], {
             RGBColor[
             0.32203573450029344`, 0.4531724542663287, 0.9417474171352478]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 192}], {
             RGBColor[
             0.28070448165153206`, 0.4123685862808082, 0.9392970770137636]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 249}], {
             RGBColor[
             0.29817109629594896`, 0.43072710571942197`, 0.9402917748782225]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 260}], {
             RGBColor[
             0.2961853765948359, 0.4286399884116514, 0.940178691078853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 280}], {
             RGBColor[
             0.2818433506476452, 0.4135656098041881, 0.9393619339182866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 310}], {
             RGBColor[
             0.3017756973424442, 0.43451576996419494`, 0.9404970515752908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 327}], {
             RGBColor[
             0.28193174194509296`, 0.41365851466213766`, 0.939366967671913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 424}], {
             RGBColor[
             0.31369437792555, 0.4459475904500576, 0.9412159132702771]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{151, 483}], {
             RGBColor[
             0.3017217477257488, 0.43445906549644486`, 0.9404939792244313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 191}], {
             RGBColor[
             0.21120215837255008`, 0.3393172378127832, 0.9353390225224988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 212}], {
             RGBColor[
             0.21125959360220817`, 0.3393776058807578, 0.93534229337386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 287}], {
             RGBColor[
             0.20690732578417442`, 0.33480309645428663`, 0.9350944381602262]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 299}], {
             RGBColor[
             0.20658465608391344`, 0.3344639501408717, 0.9350760625981434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 301}], {
             RGBColor[
             0.2063778078751808, 0.33424653955855976`, 0.9350642828986606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 389}], {
             RGBColor[
             0.21125135912011495`, 0.33936895091798147`, 0.9353418244322866]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{152, 451}], {
             RGBColor[
             0.20772437674817806`, 0.3356618688214776, 0.9351409680039076]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 190}], {
             RGBColor[
             0.24652129125596123`, 0.3764398858356126, 0.9373503948902342]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 195}], {
             RGBColor[
             0.2575424446398453, 0.3880238168235591, 0.9379780332711112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 263}], {
             RGBColor[
             0.25916680795964386`, 0.3897311256632503, 0.9380705383591434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 323}], {
             RGBColor[
             0.24213881509518778`, 0.3718336255256024, 0.9371008193561707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 342}], {
             RGBColor[
             0.25246005368067864`, 0.38268190168327626`, 0.9376885986247103]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 351}], {
             RGBColor[
             0.267489207183899, 0.39847849491853005`, 0.9385444866830785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 356}], {
             RGBColor[
             0.2571354474729763, 0.3875960369960689, 0.9379548553845563]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 395}], {
             RGBColor[
             0.2549602684410159, 0.3853097859191623, 0.9378309821565751]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 447}], {
             RGBColor[
             0.24571645560416666`, 0.3755939525360489, 0.9373045606905122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 452}], {
             RGBColor[
             0.2344431943228335, 0.36374504016331954`, 0.9366625651378359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{153, 463}], {
             RGBColor[
             0.25601516257071727`, 0.38641854653362934`, 0.9378910568166856]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 174}], {
             RGBColor[
             0.2880991557381853, 0.4200673355937856, 0.9397208847641902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 229}], {
             RGBColor[
             0.3002585012900294, 0.4328475787158096, 0.940413341505228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 255}], {
             RGBColor[
             0.3535633647009796, 0.4806605487177418, 0.9437497228483069]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 313}], {
             RGBColor[
             0.2882495492104231, 0.42022540866860447`, 0.9397294494499471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 338}], {
             RGBColor[
             0.314823265682197, 0.4471058220816644, 0.9412812379953546]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 369}], {
             RGBColor[
             0.36474431369771637`, 0.4903449247678786, 0.944462163031454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 379}], {
             RGBColor[
             0.3094202014132221, 0.4424259593777846, 0.9409369595178776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 380}], {
             RGBColor[
             0.2911961325222311, 0.423322454553487, 0.9398972530104752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 390}], {
             RGBColor[
             0.30514733542854805`, 0.43798605336538, 0.9406917533770347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 425}], {
             RGBColor[
             0.3424420265478999, 0.47102780458425264`, 0.9430410810154058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{154, 478}], {
             RGBColor[
             0.28779157321631055`, 0.419744046861437, 0.9397033683945971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 181}], {
             RGBColor[
             0.49329315877378277`, 0.5986309034651389, 0.9534977211263604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 235}], {
             RGBColor[
             0.4614654223098702, 0.5710633178486462, 0.9514696859030422]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 262}], {
             RGBColor[
             0.520987467347936, 0.6220001220678183, 0.9554331883510561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 332}], {
             RGBColor[
             0.4840405870433834, 0.5906167908800439, 0.9529081554374272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 344}], {
             RGBColor[
             0.5148160505883743, 0.6169898879232494, 0.9549473518170989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 387}], {
             RGBColor[
             0.6705014636086952, 0.7413486854414358, 0.9685938847155504]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 393}], {
             RGBColor[
             0.5135503027141461, 0.615962296777659, 0.9548477075078524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{155, 403}], {
             RGBColor[
             0.7474005481861847, 0.8023032590432388, 0.9760248292713649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 232}], {
             RGBColor[
             0.4117533959329014, 0.5306819361106889, 0.9475625057353367]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 307}], {
             RGBColor[
             0.4685593666518582, 0.5794366280637215, 0.9513058562137999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 350}], {
             RGBColor[
             0.41473957912155346`, 0.5332684178987681, 0.9477527826875395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 354}], {
             RGBColor[
             0.4145365045344412, 0.533092524898237, 0.9477398429544205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 372}], {
             RGBColor[
             0.46888111877498084`, 0.5796978409320405, 0.951331185719549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{156, 479}], {
             RGBColor[
             0.4393999195807523, 0.5546279653397757, 0.9493241177753168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 180}], {
             RGBColor[
             0.2863372761085622, 0.4182890103949429, 0.9396178563251187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 216}], {
             RGBColor[
             0.28421479544229167`, 0.41605814864164575`, 0.9394969841911034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 238}], {
             RGBColor[
             0.31134876495031627`, 0.4435229307952213, 0.9410808428186908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 246}], {
             RGBColor[
             0.2983825090164457, 0.4309493138930047, 0.9403038145198976]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 281}], {
             RGBColor[
             0.2737261355645935, 0.4050339020907391, 0.9388996705276503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 288}], {
             RGBColor[
             0.2793047597177943, 0.4108973897809534, 0.9392173649203402]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 343}], {
             RGBColor[
             0.2977155588527831, 0.4302483069839126, 0.9402658326947413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 392}], {
             RGBColor[
             0.3042725009406671, 0.4371400688524187, 0.9406392408465198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 459}], {
             RGBColor[
             0.3465448636437761, 0.4740080224761397, 0.94332350710475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{157, 465}], {
             RGBColor[
             0.2925845958094424, 0.42485533950351484`, 0.9399736319400027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 182}], {
             RGBColor[
             0.36805399542884243`, 0.4932116047339394, 0.9446730530247247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 206}], {
             RGBColor[
             0.3501277440364893, 0.4776847867774757, 0.9435308081375656]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 282}], {
             RGBColor[
             0.4825898599888707, 0.5882261104425313, 0.9531290808792493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 324}], {
             RGBColor[
             0.3635993901479788, 0.48935324953462667`, 0.9443892095152808]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 410}], {
             RGBColor[
             0.3605931713874897, 0.48674941394123933`, 0.9441976559141574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{158, 441}], {
             RGBColor[
             0.4038268661048062, 0.5241962673166999, 0.9469524687114896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 164}], {
             RGBColor[
             0.819137437150352, 0.14810430478184575`, 0.1659593374688081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 396}], {
             RGBColor[
             0.9071481131704897, 0.5745522202562454, 0.3532052383412315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{159, 443}], {
             RGBColor[
             0.877631072588452, 0.4692846461457165, 0.21683434670508697`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 165}], {
             RGBColor[
             0.4232575021072018, 0.5410261076098133, 0.9481905716557255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 268}], {
             RGBColor[
             0.41606826400089775`, 0.5347991509037464, 0.9477324797607855]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 275}], {
             RGBColor[
             0.4180928553323577, 0.5365527501561378, 0.9478614849301503]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 285}], {
             RGBColor[
             0.3684500451199806, 0.49355464307036695`, 0.9446982889608311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 324}], {
             RGBColor[
             0.3960795993510239, 0.5174859742435227, 0.9464588197245776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 353}], {
             RGBColor[
             0.531072144514868, 0.6293500407838779, 0.9564584330755022]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 441}], {
             RGBColor[
             0.4363070753078513, 0.5523289920255958, 0.9490220789207864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 480}], {
             RGBColor[
             0.3880144919727734, 0.5105003835965654, 0.94594491821413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{160, 481}], {
             RGBColor[
             0.3703492229848604, 0.49519961548147085`, 0.9448193028950042]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 259}], {
             RGBColor[
             0.9260863286561598, 0.722291136783578, 0.31168537193130974`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 326}], {
             RGBColor[
             0.9327537347132191, 0.7525662704764362, 0.31724881897839763`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 341}], {
             RGBColor[
             0.9919526646253864, 0.9838559907810486, 0.4794106025405692]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 387}], {
             RGBColor[
             0.8827228822801044, 0.901646814849579, 0.6975808353380122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 403}], {
             RGBColor[
             0.9596219668575938, 0.962601388451382, 0.7050117798938269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 405}], {
             RGBColor[
             0.9921723207517021, 0.9843258130245969, 0.5033188163295588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 450}], {
             RGBColor[
             0.9040202207813182, 0.5580851531997648, 0.2907664410126593]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 469}], {
             RGBColor[
             0.9253813180460291, 0.7190898482623855, 0.3110970937968252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{161, 491}], {
             RGBColor[
             0.992246695040947, 0.9844848921088973, 0.5114139987289448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 203}], {
             RGBColor[
             0.4982990262412239, 0.6035806234747654, 0.9536470711566374]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 221}], {
             RGBColor[
             0.4993207487803075, 0.6044101038600693, 0.953727504897607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 223}], {
             RGBColor[
             0.4259476007932227, 0.5431195461878823, 0.9484273528030159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 258}], {
             RGBColor[
             0.4177269296537439, 0.5359992140298111, 0.9479035389072623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 289}], {
             RGBColor[
             0.45070123455015054`, 0.5645598995943251, 0.9500046324572284]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 297}], {
             RGBColor[
             0.4906978130641887, 0.5974096161868968, 0.9530486758111798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 381}], {
             RGBColor[
             0.515668109442376, 0.6176816276857418, 0.9550144290112803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{162, 439}], {
             RGBColor[
             0.6614719504889517, 0.7330346033014116, 0.9686938737233264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 187}], {
             RGBColor[
             0.2658102034815037, 0.3967137555723293, 0.9384488699060904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 189}], {
             RGBColor[
             0.2633838374698597, 0.39416349105360093`, 0.9383106919512142]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 322}], {
             RGBColor[
             0.26310542995763675`, 0.3938708671061988, 0.9382948370552601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 364}], {
             RGBColor[
             0.2627794929075267, 0.39352828660093053`, 0.938276275422437]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 437}], {
             RGBColor[
             0.26141138655191587`, 0.3920903200782306, 0.9381983637894169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{163, 494}], {
             RGBColor[
             0.262747921993954, 0.39349510356905415`, 0.938274477505614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 166}], {
             RGBColor[
             0.8278225605966679, 0.21486196943559147`, 0.17427622148944416`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 227}], {
             RGBColor[
             0.8315779382096691, 0.24372744738608088`, 0.17787237533274636`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 309}], {
             RGBColor[
             0.9052777371288019, 0.5616050038337315, 0.3236174733815438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 348}], {
             RGBColor[
             0.8887181595032059, 0.5060713797566354, 0.23158979527643736`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 396}], {
             RGBColor[
             0.9055353853140414, 0.5621560872497313, 0.3516608883245811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 428}], {
             RGBColor[
             0.8239291026561835, 0.1849351455808791, 0.17054784176860438`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{164, 443}], {
             RGBColor[
             0.8760183447320038, 0.45688851313920237`, 0.21528999668843654`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 182}], {
             RGBColor[
             0.4013099579800705, 0.5220162480025345, 0.9467920935513959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 268}], {
             RGBColor[
             0.4168440173490807, 0.5354710694634455, 0.9477819100781599]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 275}], {
             RGBColor[
             0.41886860868054065`, 0.537224668715837, 0.9479109152475247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 282}], {
             RGBColor[
             0.5158458225400988, 0.6170307537111264, 0.9552481214059205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 285}], {
             RGBColor[
             0.3692257984681636, 0.49422656163006606`, 0.9447477192782054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 324}], {
             RGBColor[
             0.3968553526992069, 0.5181578928032218, 0.9465082500419522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 353}], {
             RGBColor[
             0.531847897863051, 0.630021959343577, 0.9565078633928767]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 441}], {
             RGBColor[
             0.4370828286560343, 0.553000910585295, 0.9490715092381609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{165, 481}], {
             RGBColor[
             0.3711249763330434, 0.49587153404117, 0.9448687332123786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 210}], {
             RGBColor[
             0.8370920629652436, 0.28611142656230293`, 0.18315270742599782`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 227}], {
             RGBColor[
             0.8418757895124331, 0.32288124504634075`, 0.18773360937003286`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 243}], {
             RGBColor[
             0.838713260625803, 0.29857266219470613`, 0.18470516813663024`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 309}], {
             RGBColor[
             0.9155755884315661, 0.6407588014939913, 0.33347870741883034`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 320}], {
             RGBColor[
             0.9133614547699682, 0.6417853106074096, 0.5113435478107814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 348}], {
             RGBColor[
             0.8990160108059699, 0.5852251774168952, 0.24145102931372386`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 428}], {
             RGBColor[
             0.8342269539589475, 0.26408894324113896`, 0.18040907580589088`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{166, 495}], {
             RGBColor[
             0.8401614416386582, 0.3097040160564781, 0.18609194791002698`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 210}], {
             RGBColor[
             0.9113669843928855, 0.6334814540290358, 0.5263699322609554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 326}], {
             RGBColor[
             0.9309228830343801, 0.7574193985269815, 0.5440638154599668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 434}], {
             RGBColor[
             0.988936416573675, 0.989692938179159, 0.8330157392176978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 474}], {
             RGBColor[
             0.9898837045140847, 0.9900846660867081, 0.8173167265425048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{167, 495}], {
             RGBColor[
             0.9144363630663, 0.657074043523211, 0.5293091727449846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 200}], {
             RGBColor[
             0.9058101136750496, 0.6632964389017137, 0.24302016366679569`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 213}], {
             RGBColor[
             0.9074990588325569, 0.6709655443987909, 0.2444294609060539]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 254}], {
             RGBColor[
             0.5736452347236608, 0.5249664714796068, 0.591929563801219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 261}], {
             RGBColor[
             0.8953895182633258, 0.6159789489289689, 0.23432496342308617`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 315}], {
             RGBColor[
             0.5481459181329882, 0.49816507299275914`, 0.5904774154442385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 368}], {
             RGBColor[
             0.6594469349895435, 0.6059633899066202, 0.5971521921376893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 401}], {
             RGBColor[
             0.842122298838193, 0.7534870262743261, 0.6125668464325392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{168, 500}], {
             RGBColor[
             0.8651424411448785, 0.41743131522220955`, 0.2066895157907081]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 204}], {
             RGBColor[
             0.4973176178268257, 0.6027838719120118, 0.9535698110912385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 219}], {
             RGBColor[
             0.5095055418565787, 0.6126785776990856, 0.9545292891166974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 244}], {
             RGBColor[
             0.4175916065853016, 0.5350481346501237, 0.9481253168239769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 274}], {
             RGBColor[
             0.4777382226320348, 0.5868884368511786, 0.9520284493798168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 334}], {
             RGBColor[
             0.44777313143376407`, 0.5611898545063152, 0.9500484568988465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 337}], {
             RGBColor[
             0.6764764422213522, 0.7452210038115648, 0.9698692373870139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 340}], {
             RGBColor[
             0.41508837309382146`, 0.5328799596159772, 0.9479658129994224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 361}], {
             RGBColor[
             0.5684718159304661, 0.6605218314458838, 0.9591906270789168]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 363}], {
             RGBColor[
             0.44877677089386697`, 0.5620591565622703, 0.9501124079177607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 370}], {
             RGBColor[
             0.5420927609464797, 0.6391343501937576, 0.9570946743743712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{169, 498}], {
             RGBColor[
             0.4773158479045384, 0.5865455340196324, 0.9519951984940587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 171}], {
             RGBColor[
             0.2792113970027737, 0.4107992596479288, 0.9392120480518376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 238}], {
             RGBColor[
             0.3084172446419511, 0.44044171708200675`, 0.940913897073925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 265}], {
             RGBColor[
             0.3088475371272851, 0.4408144148056739, 0.9409413149305978]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 266}], {
             RGBColor[
             0.29310065604108804`, 0.425397751527083, 0.9400030208067522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 328}], {
             RGBColor[
             0.3409967871765409, 0.4686604793300483, 0.9429898367152708]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 374}], {
             RGBColor[
             0.2742054454433818, 0.40553768716334715`, 0.9389269665161719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{170, 433}], {
             RGBColor[
             0.31109341012253816`, 0.4427596771133032, 0.9410844199719078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 216}], {
             RGBColor[
             0.26381410331866717`, 0.39461572774112796`, 0.9383351949547825]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 238}], {
             RGBColor[
             0.2909480728266918, 0.4220805098947036, 0.9399190535823698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 265}], {
             RGBColor[
             0.29137836531202577`, 0.42245320761837074`, 0.9399464714390425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 343}], {
             RGBColor[
             0.2773148667291586, 0.40880588608339485`, 0.9391040434584204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 385}], {
             RGBColor[
             0.24760690614002792`, 0.37758093591072595`, 0.9374122190518586]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 391}], {
             RGBColor[
             0.25143472628896596`, 0.3816042175850748, 0.9376302077465881]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 433}], {
             RGBColor[
             0.2936242383072788, 0.42439846992600005`, 0.9400895764803525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{171, 465}], {
             RGBColor[
             0.27218390368581785`, 0.4034129186029971, 0.9388118427036817]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 303}], {
             RGBColor[
             0.32845548787730483`, 0.4585909264869045, 0.9421616772940785]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 366}], {
             RGBColor[
             0.3083293758751098, 0.43743710670339436`, 0.941015524989468]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 448}], {
             RGBColor[
             0.45979588464643895`, 0.5695615806771241, 0.9513786855523698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{172, 473}], {
             RGBColor[
             0.3392418574009336, 0.4682559789143286, 0.9428371690671595]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 241}], {
             RGBColor[
             0.8450225482014433, 0.8788658384170731, 0.9383874109586698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 417}], {
             RGBColor[
             0.8427978094114925, 0.8771278555657226, 0.9381656697874536]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 461}], {
             RGBColor[
             0.9645092309315171, 0.9729899937684735, 0.9422009085196323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{173, 493}], {
             RGBColor[
             0.9890701085039466, 0.9882775676582451, 0.7238989830539463]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 215}], {
             RGBColor[
             0.2753901052316153, 0.40678283971254936`, 0.9389944311385647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 229}], {
             RGBColor[
             0.2788164534778155, 0.4103841489623319, 0.9391895566023578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 294}], {
             RGBColor[
             0.2524849252558091, 0.3827080432856873, 0.9376900150241196]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 338}], {
             RGBColor[
             0.29338121786998295`, 0.4246423923281867, 0.9400574530924843]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 356}], {
             RGBColor[
             0.2679975194043914, 0.3990127632911238, 0.938573434312055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 390}], {
             RGBColor[
             0.28370528761633407`, 0.41552262361190234`, 0.9394679684741645]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{174, 430}], {
             RGBColor[
             0.2531980668507343, 0.38345760031774234`, 0.9377306273829522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 309}], {
             RGBColor[
             0.9743805147039586, 0.9770030600582216, 0.7213206267986814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 320}], {
             RGBColor[
             0.9721663810423609, 0.9780295691716399, 0.8991854671906325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 337}], {
             RGBColor[
             0.9079704822927377, 0.9289384814961321, 0.9731750764283525]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 348}], {
             RGBColor[
             0.9578209370783626, 0.9214694359811255, 0.6292929486935749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 361}], {
             RGBColor[
             0.7999658560018515, 0.8442393091304512, 0.9624964661202554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 370}], {
             RGBColor[
             0.7735868010178651, 0.822851827878325, 0.9604005134157099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{175, 375}], {
             RGBColor[
             0.9569658514087618, 0.9674257829593813, 0.9577297678481509]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 197}], {
             RGBColor[
             0.6522851143834272, 0.7277468526483104, 0.9663482548197164]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 237}], {
             RGBColor[
             0.7565184993634433, 0.8098707472801487, 0.9765525722729846]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 345}], {
             RGBColor[
             0.6333349002315553, 0.7129428013259062, 0.9644594745728776]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 426}], {
             RGBColor[
             0.7385594994235554, 0.7955507282121491, 0.9748396268265297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{176, 448}], {
             RGBColor[
             0.587441960125221, 0.6759508730452015, 0.9606647294533119]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 245}], {
             RGBColor[
             0.21512971428686242`, 0.34344534810015337`, 0.9355626910215206]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 438}], {
             RGBColor[
             0.21508055771107348`, 0.3433936814222922, 0.9355598916272501]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{177, 455}], {
             RGBColor[
             0.2063185988388122, 0.33418430710726665`, 0.9350609110316312]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 357}], {
             RGBColor[
             0.9494134599221778, 0.8301932628763469, 0.5158066666080678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 420}], {
             RGBColor[
             0.9801637329335828, 0.9834819259202605, 0.8627171585529716]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{178, 439}], {
             RGBColor[
             0.9262985601874452, 0.9413808299607197, 0.8870332114673454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 236}], {
             RGBColor[
             0.23312614698427564`, 0.36236073990487094`, 0.9365875612403018]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 254}], {
             RGBColor[
             0.20771369325605188`, 0.33565063979388043`, 0.9351403595948358]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 276}], {
             RGBColor[
             0.39923464670294595`, 0.5037029404652202, 0.9483463693708659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 283}], {
             RGBColor[
             0.18007164814629245`, 0.3065970977766376, 0.9335661860185762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 292}], {
             RGBColor[
             0.17894988462017136`, 0.30541805318676885`, 0.9335023032452641]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 315}], {
             RGBColor[
             0.18221437666537932`, 0.3088492413070327, 0.9336882112378554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 325}], {
             RGBColor[
             0.1789730287155782, 0.30544237909846184`, 0.9335036212672588]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 347}], {
             RGBColor[
             0.17892806853100302`, 0.30539512309383293`, 0.93350106085126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 368}], {
             RGBColor[
             0.2935153935219346, 0.41664755822089383`, 0.9403629879313062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 386}], {
             RGBColor[
             0.17892806853100302`, 0.30539512309383293`, 0.93350106085126]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{179, 401}], {
             RGBColor[
             0.47619075737058414`, 0.5641711945885997, 0.9557776422261561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 216}], {
             RGBColor[
             0.2680084621160904, 0.3990242647749275, 0.9385740574832979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 281}], {
             RGBColor[
             0.2575198022383923, 0.3880000182240208, 0.9379767438198447]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 288}], {
             RGBColor[
             0.2630984263915931, 0.39386350591423513`, 0.9382944382125347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 343}], {
             RGBColor[
             0.28150922552658186`, 0.4132144231171943, 0.9393429059869358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 392}], {
             RGBColor[
             0.2880661676144659, 0.4201061849857004, 0.9397163141387143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{180, 465}], {
             RGBColor[
             0.27637826248324115`, 0.40782145563679656`, 0.9390507052321971]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 235}], {
             RGBColor[
             0.38886946031407776`, 0.511240914201845, 0.9459993960408191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 239}], {
             RGBColor[
             0.38581385669695734`, 0.5085943039277986, 0.9458046956803003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 262}], {
             RGBColor[
             0.4483915053521436, 0.5621777184210172, 0.9499628984888329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 296}], {
             RGBColor[
             0.3670585086059648, 0.49234936408258523`, 0.9446096214846453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 332}], {
             RGBColor[
             0.41144462504759094`, 0.5307943872332428, 0.947437865575204]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 344}], {
             RGBColor[
             0.4422200885925819, 0.5571674842764482, 0.9494770619548758]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 387}], {
             RGBColor[
             0.5979055016129029, 0.6815262817946347, 0.9631235948533272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 393}], {
             RGBColor[
             0.4409543407183537, 0.5561398931308579, 0.9493774176456293]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{181, 424}], {
             RGBColor[
             0.3706458143967508, 0.4954565080553325, 0.9448382014375043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 275}], {
             RGBColor[
             0.39614531120522645`, 0.517542890548859, 0.9464630068258206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 282}], {
             RGBColor[
             0.4931225250647846, 0.5973489755441486, 0.9538002129842165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 324}], {
             RGBColor[
             0.37413205522389265`, 0.49847611463624397`, 0.9450603416202481]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{182, 441}], {
             RGBColor[
             0.41435953118072005`, 0.5333191324183171, 0.9476236008164568]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 346}], {
             RGBColor[
             0.21142499907593382`, 0.3395514575209563, 0.9353517129708931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 404}], {
             RGBColor[
             0.20920782453695042`, 0.33722106650349953`, 0.9352254481609139]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 407}], {
             RGBColor[
             0.2096628417623121, 0.3376993184571131, 0.9352513607187605]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{183, 408}], {
             RGBColor[
             0.21373593745192992`, 0.3419804002760839, 0.9354833174926791]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 192}], {
             RGBColor[
             0.25582325613433854`, 0.3862168407014245, 0.9378801280290341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 225}], {
             RGBColor[
             0.2656405828545585, 0.396535473538841, 0.9384392102623171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 249}], {
             RGBColor[
             0.2732898707787555, 0.40457536014003825`, 0.9388748258934928]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 260}], {
             RGBColor[
             0.2713041510776424, 0.40248824283226764`, 0.9387617420941234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 280}], {
             RGBColor[
             0.2569621251304517, 0.38741386422480434`, 0.9379449849335569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 424}], {
             RGBColor[
             0.28881315240835653`, 0.41979584487067384`, 0.9397989642855475]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 440}], {
             RGBColor[
             0.26935285588816305`, 0.4004373078688641, 0.9386506187197652]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 453}], {
             RGBColor[
             0.2706693526642461, 0.401821029451244, 0.9387255912635806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{184, 470}], {
             RGBColor[
             0.2562569900664413, 0.3866727225643841, 0.9379048285348154]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 193}], {
             RGBColor[
             0.28587823371129695`, 0.41780652773044813`, 0.9395917145396869]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 196}], {
             RGBColor[
             0.2898220421197416, 0.4219517204196188, 0.9398163085942062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 318}], {
             RGBColor[
             0.3129435362062064, 0.4431846498190406, 0.9412454229080396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 321}], {
             RGBColor[
             0.30856010126890854`, 0.43938793879419913`, 0.9409661143099544]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 330}], {
             RGBColor[
             0.29519715135054264`, 0.42760130102279975`, 0.9401224131131387]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 335}], {
             RGBColor[
             0.28035846079175497`, 0.4120048964181928, 0.9392773716376912]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 350}], {
             RGBColor[
             0.3230573711356193, 0.45194474529877393`, 0.9418898675264287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 383}], {
             RGBColor[
             0.3064436349421723, 0.43755476203867083`, 0.9408312549471323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 409}], {
             RGBColor[
             0.262750205623448, 0.39349750380844273`, 0.9382746075549353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 482}], {
             RGBColor[
             0.32121309396000997`, 0.4503473251053272, 0.9417723518156291]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{185, 496}], {
             RGBColor[
             0.2804171463023576, 0.4120665786107125, 0.9392807136907027]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 191}], {
             RGBColor[
             0.22705589567091367`, 0.35598052089836485`, 0.936241869408138]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 202}], {
             RGBColor[
             0.2373837352876954, 0.3668357351584549, 0.9368300245956442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 212}], {
             RGBColor[
             0.22711333090057176`, 0.3560408889663394, 0.9362451402594992]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 295}], {
             RGBColor[
             0.23264914651192115`, 0.36185938216484964`, 0.9365603967690603]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 300}], {
             RGBColor[
             0.23083402862066274`, 0.35995157817601575`, 0.9364570284903794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 389}], {
             RGBColor[
             0.22710509641847854`, 0.3560322340035631, 0.9362446713179258]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 414}], {
             RGBColor[
             0.255184189019674, 0.3855451406447167, 0.937843734102269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 456}], {
             RGBColor[
             0.22968446940414386`, 0.35874331855319036`, 0.9363915627936191]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{186, 485}], {
             RGBColor[
             0.24185580045044375`, 0.3715361591898116, 0.9370847020908353]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 322}], {
             RGBColor[
             0.2619233226556958, 0.392628397381927, 0.9382275177931856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{187, 494}], {
             RGBColor[
             0.26156581469201307`, 0.3922526338447824, 0.9382071582435395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 304}], {
             RGBColor[
             0.33792059600024626`, 0.4671115686975821, 0.9427529794590535]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 310}], {
             RGBColor[
             0.3170171080071488, 0.4478975596227356, 0.9414616137808558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{188, 483}], {
             RGBColor[
             0.31696315839045336`, 0.4478408551549855, 0.9414585414299963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 266}], {
             RGBColor[
             0.2746480537102089, 0.4060028965147674, 0.9389521724021874]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 364}], {
             RGBColor[
             0.25917101959394173`, 0.3897355523579304, 0.9380707782054862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 374}], {
             RGBColor[
             0.2557528431125027, 0.3861428321510315, 0.9378761181116072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{189, 437}], {
             RGBColor[
             0.25780291323833093`, 0.38829758583523044`, 0.9379928665724662]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 195}], {
             RGBColor[
             0.25913077183266553`, 0.38969324940897365`, 0.9380684861550228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 224}], {
             RGBColor[
             0.2735379552710175, 0.40483611267087094`, 0.938888953938319]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 263}], {
             RGBColor[
             0.26075513515246407`, 0.3914005582486648, 0.9381609912430551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 323}], {
             RGBColor[
             0.243727142288008, 0.373503058111017, 0.9371912722400824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 342}], {
             RGBColor[
             0.25404838087349885`, 0.38435133426869084`, 0.9377790515086218]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 351}], {
             RGBColor[
             0.2690775343767192, 0.40014792750394457`, 0.9386349395669901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 356}], {
             RGBColor[
             0.2587237746657965, 0.38926546958148345`, 0.9380453082684679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 395}], {
             RGBColor[
             0.2565485956338361, 0.38697921850457684`, 0.9379214350404868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 452}], {
             RGBColor[
             0.2360315215156537, 0.3654144727487341, 0.9367530180217474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{190, 463}], {
             RGBColor[
             0.2576034897635375, 0.3880879791190439, 0.9379815097005972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 212}], {
             RGBColor[
             0.21845881642544385`, 0.3469444455250692, 0.9357522784633475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 218}], {
             RGBColor[
             0.2251871593264507, 0.3540163605156067, 0.9361354476378685]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 287}], {
             RGBColor[
             0.21410654860741013`, 0.342369936098598, 0.9355044232497137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 295}], {
             RGBColor[
             0.22399463203679326`, 0.35276293872357944`, 0.9360675349729086]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 299}], {
             RGBColor[
             0.21378387890714912`, 0.3420307897851831, 0.935486047687631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 300}], {
             RGBColor[
             0.22217951414553483`, 0.3508551347347456, 0.9359641666942277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 301}], {
             RGBColor[
             0.2135770306984165, 0.34181337920287114`, 0.935474267988148]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 389}], {
             RGBColor[
             0.21845058194335062`, 0.3469357905622929, 0.9357518095217741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 451}], {
             RGBColor[
             0.21492359957141377`, 0.343228708465789, 0.9355509530933952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{191, 456}], {
             RGBColor[
             0.22102995492901595`, 0.34964687511192016`, 0.9358987009974674]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 225}], {
             RGBColor[
             0.26443196618769516`, 0.395265140791245, 0.9383703813311275]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 249}], {
             RGBColor[
             0.27208125411189216`, 0.40330502739244223`, 0.938805996962303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 260}], {
             RGBColor[
             0.27009553441077905`, 0.4012179100846716, 0.9386929131629338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 280}], {
             RGBColor[
             0.25575350846358835`, 0.3861435314772083, 0.9378761560023672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 327}], {
             RGBColor[
             0.25584189976103616`, 0.38623643633515786`, 0.9378811897559938]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 470}], {
             RGBColor[
             0.255048373399578, 0.3854023898167881, 0.9378359996036256]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{192, 483}], {
             RGBColor[
             0.275631905541692, 0.4070369871694651, 0.9390082013085121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 196}], {
             RGBColor[
             0.29175552637074975`, 0.4239839349574104, 0.9399264176619675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 202}], {
             RGBColor[
             0.2634343891958272, 0.39421662412275726`, 0.9383135707972234]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 232}], {
             RGBColor[
             0.32200467219797546`, 0.4513904780484862, 0.9418096996419872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 330}], {
             RGBColor[
             0.2971306356015508, 0.42963351556059126`, 0.9402325221809]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 350}], {
             RGBColor[
             0.3249908553866274, 0.4539769598365655, 0.94199997659419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 354}], {
             RGBColor[
             0.3247877807995152, 0.4538010668360344, 0.941987036861071]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 376}], {
             RGBColor[
             0.2836334092052663, 0.4154470748445156, 0.9394638751049887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 414}], {
             RGBColor[
             0.28123484292780576`, 0.41292602960901903`, 0.9393272803038482]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 415}], {
             RGBColor[
             0.28741220208324925`, 0.41941882574858214`, 0.9396790717691668]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 485}], {
             RGBColor[
             0.2679064543585755, 0.3989170481541139, 0.9385682482924145]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{193, 496}], {
             RGBColor[
             0.28235063055336573`, 0.41409879314850406`, 0.939390822758464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 228}], {
             RGBColor[
             0.9897986964683487, 0.9881510016226367, 0.6807237889593197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 388}], {
             RGBColor[
             0.9663440953419832, 0.9740339462184904, 0.9245637966956991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{194, 490}], {
             RGBColor[
             0.9885348242076832, 0.9895268694153684, 0.8396711640099095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 224}], {
             RGBColor[
             0.28455910865490164`, 0.41642004365881735`, 0.9395165923191959]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 263}], {
             RGBColor[
             0.27177628853634817`, 0.40298448923661123`, 0.9387886296239321]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 296}], {
             RGBColor[
             0.29178587282524443`, 0.4235837043718764, 0.9399439681205266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 323}], {
             RGBColor[
             0.2547482956718921, 0.38508698909896344`, 0.9378189106209592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 342}], {
             RGBColor[
             0.265069534257383, 0.39593526525663725`, 0.9384066898894987]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 351}], {
             RGBColor[
             0.2800986877606033, 0.41173185849189103`, 0.9392625779478669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 395}], {
             RGBColor[
             0.26756974901772024`, 0.3985631494925233, 0.9385490734213637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 447}], {
             RGBColor[
             0.25832593618087096`, 0.38884731610940987`, 0.9380226519553008]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 453}], {
             RGBColor[
             0.27722937887191995`, 0.40871603292519376`, 0.9390991750514186]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{195, 463}], {
             RGBColor[
             0.2686246431474216, 0.3996719101069903, 0.9386091480814742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 318}], {
             RGBColor[
             0.3188208288656592, 0.44936205704600285`, 0.9415801260303202]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 321}], {
             RGBColor[
             0.31443739392836134`, 0.4455653460211614, 0.9413008174322348]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 330}], {
             RGBColor[
             0.3010744440099954, 0.433778708249762, 0.9404571162354194]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 335}], {
             RGBColor[
             0.2862357534512077, 0.4181823036451551, 0.9396120747599719]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 350}], {
             RGBColor[
             0.3289346637950721, 0.4581221525257362, 0.9422245706487093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 354}], {
             RGBColor[
             0.32873158920795986`, 0.45794625952520507`, 0.9422116309155903]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 383}], {
             RGBColor[
             0.3123209276016251, 0.4437321692656331, 0.941165958069413]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 414}], {
             RGBColor[
             0.2851786513362504, 0.4170712222981897, 0.9395518743583675]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 479}], {
             RGBColor[
             0.35359500425427093`, 0.4794816999667437, 0.9437959057364866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 482}], {
             RGBColor[
             0.3270903866194627, 0.45652473233228946`, 0.9421070549379097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{196, 496}], {
             RGBColor[
             0.2862944389618104, 0.41824398583767475`, 0.9396154168129832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 237}], {
             RGBColor[
             0.8018590077882369, 0.845833600411511, 0.9807007779188375]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 270}], {
             RGBColor[
             0.843824355466433, 0.8769260052856713, 0.8927516199339326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 345}], {
             RGBColor[
             0.6786754086563489, 0.7489056544572683, 0.9686076802187304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 375}], {
             RGBColor[
             0.8279135305907634, 0.8660284937370616, 0.9630673509377192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 426}], {
             RGBColor[
             0.7839000078483491, 0.8315135813435113, 0.9789878324723824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 448}], {
             RGBColor[
             0.6327824685500147, 0.7119137261765637, 0.9648129350991647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{197, 489}], {
             RGBColor[
             0.843861608566709, 0.8769414103999965, 0.8921342396544271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 223}], {
             RGBColor[
             0.335871613441881, 0.4628528461466326, 0.9427133713948876]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 373}], {
             RGBColor[
             0.28774746699468884`, 0.4197712104275283, 0.9396981646098933]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{198, 480}], {
             RGBColor[
             0.3177133386514768, 0.44712506118461215`, 0.9415563421819749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 208}], {
             RGBColor[
             0.33248120157791744`, 0.46240023864087376`, 0.9424063860563303]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 220}], {
             RGBColor[
             0.3408785418830542, 0.4696735927505875, 0.9429414571550971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 349}], {
             RGBColor[
             0.3782226741008029, 0.5020192031069408, 0.9453209922378925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 359}], {
             RGBColor[
             0.364147570424561, 0.48982805573786037`, 0.9444241390777679]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 371}], {
             RGBColor[
             0.3528938984406201, 0.480080690691371, 0.9437070650501826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 382}], {
             RGBColor[
             0.31253428709090747`, 0.4426711481132517, 0.9412251688089472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 397}], {
             RGBColor[
             0.3506959657134314, 0.47817695183439113`, 0.9435670147203616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 419}], {
             RGBColor[
             0.4277672068152066, 0.5433200836247167, 0.948923355062986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 427}], {
             RGBColor[
             0.31117200287913815`, 0.44123930103287445`, 0.9411475887384059]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{199, 429}], {
             RGBColor[
             0.318220922727511, 0.44864816272084596`, 0.9415490142958283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 213}], {
             RGBColor[
             0.9025169525103827, 0.6502340737413859, 0.24037009445756363`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 243}], {
             RGBColor[
             0.8700670583525245, 0.4728472627689348, 0.21211683898241762`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 254}], {
             RGBColor[
             0.5686631284014866, 0.5042350008222019, 0.5878701973527287]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 259}], {
             RGBColor[
             0.8813343532764009, 0.5540488379416193, 0.22269481442370878`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 401}], {
             RGBColor[
             0.8371401925160188, 0.7327555556169211, 0.6085074799840489]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 450}], {
             RGBColor[
             0.8592682454015592, 0.38984285435780597`, 0.20177588350505832`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 454}], {
             RGBColor[
             0.9003552167733437, 0.640418136645701, 0.2385662891695866]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 469}], {
             RGBColor[
             0.8806293426662699, 0.5508475494204266, 0.22210653628922422`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 471}], {
             RGBColor[
             0.8788202951923778, 0.5401284768128874, 0.22049894846562806`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 475}], {
             RGBColor[
             0.8699156991968737, 0.47168384997259694`, 0.2119718972840306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{200, 500}], {
             RGBColor[
             0.8601603348227043, 0.3966998445648045, 0.2026301493422178]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 222}], {
             RGBColor[
             0.3735862388275236, 0.49760697262793063`, 0.9450400762157048]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 246}], {
             RGBColor[
             0.2993400916080083, 0.43195579391098005`, 0.9403583474318706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 256}], {
             RGBColor[
             0.2969224563599441, 0.4294147059783363, 0.9402206666810642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 271}], {
             RGBColor[
             0.2801320470703391, 0.4117669212415258, 0.9392644777112058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 312}], {
             RGBColor[
             0.30443515610797417`, 0.4373110297461917, 0.9406485038176712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 333}], {
             RGBColor[
             0.34155395478950024`, 0.4698622181836031, 0.9429990074018386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 400}], {
             RGBColor[
             0.30019030163233085`, 0.432849418552972, 0.9404067656349827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 442}], {
             RGBColor[
             0.2942020501296223, 0.426555386546551, 0.9400657435707277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 444}], {
             RGBColor[
             0.2878759109078417, 0.4199062131240665, 0.9397054793007316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{201, 492}], {
             RGBColor[
             0.29053904388296076`, 0.4227053347332997, 0.9398571407839125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 211}], {
             RGBColor[
             0.2350487330765592, 0.3643814997868598, 0.9366970496740461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 414}], {
             RGBColor[
             0.25685751416132785`, 0.38730391146353665`, 0.9379390274936235]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 485}], {
             RGBColor[
             0.2435291255920976, 0.37329493000863156`, 0.9371799954821897]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{202, 497}], {
             RGBColor[
             0.23752535161991525`, 0.36698458290261204`, 0.9368380894362616]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 221}], {
             RGBColor[
             0.5355883582024223, 0.6338537830261275, 0.9565826239639467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 258}], {
             RGBColor[
             0.45399453907585874`, 0.5654428931958693, 0.950758657973602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 289}], {
             RGBColor[
             0.48696884397226536`, 0.5940035787603833, 0.9528597515235682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 291}], {
             RGBColor[
             0.5947468881404891, 0.681688814806365, 0.9613714325118958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 297}], {
             RGBColor[
             0.5269654224863035, 0.6268532953529551, 0.9559037948775195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 381}], {
             RGBColor[
             0.5519357188644908, 0.6471253068518, 0.9578695480776199]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 397}], {
             RGBColor[
             0.44655734447149653`, 0.5590011690338403, 0.950284766509865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 419}], {
             RGBColor[
             0.5236285855732716, 0.6241443008241659, 0.9556411068524893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{203, 439}], {
             RGBColor[
             0.6977395599110665, 0.7624782824674698, 0.971548992789666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 219}], {
             RGBColor[
             0.5140809753819581, 0.6163931207559199, 0.9548894840041806]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 244}], {
             RGBColor[
             0.42216704011068096`, 0.5387626777069581, 0.9484855117114601]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 274}], {
             RGBColor[
             0.4823136561574142, 0.5906029799080129, 0.9523886442672999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 334}], {
             RGBColor[
             0.4523485649591434, 0.5649043975631496, 0.9504086517863296]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 337}], {
             RGBColor[
             0.6810518757467315, 0.7489355468683991, 0.970229432274497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 340}], {
             RGBColor[
             0.4196638066192008, 0.5365945026728116, 0.9483260078869054]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 361}], {
             RGBColor[
             0.5730472494558454, 0.6642363745027182, 0.9595508219663998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 362}], {
             RGBColor[
             0.4451772959687064, 0.5586930048020928, 0.9499517048675632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 363}], {
             RGBColor[
             0.4533522044192463, 0.5657736996191047, 0.9504726028052438]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 370}], {
             RGBColor[
             0.546668194471859, 0.642848893250592, 0.9574548692618543]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{204, 498}], {
             RGBColor[
             0.4818912814299178, 0.5902600770764668, 0.9523553933815417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 228}], {
             RGBColor[
             0.9934539331599859, 0.9884069498751192, 0.5288792059852668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 252}], {
             RGBColor[
             0.8648112867502258, 0.89136633503373, 0.7718692919288858]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 388}], {
             RGBColor[
             0.9699993320336204, 0.9742898944709728, 0.7727192137216462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 432}], {
             RGBColor[
             0.9462255159241673, 0.9556033712696023, 0.7798152269955922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{205, 490}], {
             RGBColor[
             0.9921900608993205, 0.9897828176678509, 0.6878265810358566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 266}], {
             RGBColor[
             0.31612745049209645`, 0.4464579350707817, 0.9414294227127427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{206, 410}], {
             RGBColor[
             0.35319958507105037`, 0.4803454610863929, 0.9437265431319655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 218}], {
             RGBColor[
             0.22451796602725682`, 0.35331299592884813`, 0.9360973380694622]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 287}], {
             RGBColor[
             0.21343735530821623`, 0.3416665715118395, 0.9354663136813074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 295}], {
             RGBColor[
             0.22332543873759936`, 0.352059574136821, 0.9360294254045023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 336}], {
             RGBColor[
             0.2196507706490151, 0.34819726498830533`, 0.9358201584930417]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 389}], {
             RGBColor[
             0.21778138864415675`, 0.3462324259755344, 0.9357136999533677]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 409}], {
             RGBColor[
             0.22930932819200256`, 0.35834902135390323`, 0.9363701990565594]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 456}], {
             RGBColor[
             0.2203607616298221, 0.3489435105251617, 0.9358605914290611]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{207, 458}], {
             RGBColor[
             0.22378112515977486`, 0.35253852945871533`, 0.9360553760721175]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 258}], {
             RGBColor[
             0.3477704837485026, 0.4756430463953687, 0.9433806055964585]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 289}], {
             RGBColor[
             0.3807447886449092, 0.5042037319598828, 0.9454816991464247]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 314}], {
             RGBColor[
             0.32609699892407057`, 0.4568705631814669, 0.9419995903085558]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 349}], {
             RGBColor[
             0.3678599975315118, 0.49304357350588934`, 0.9446606916502523]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 359}], {
             RGBColor[
             0.3537848938552699, 0.480852426136809, 0.9437638384901277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 397}], {
             RGBColor[
             0.3403332891441403, 0.46920132223333977`, 0.9429067141327215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 427}], {
             RGBColor[
             0.3008093263098471, 0.4322636714318231, 0.9404872881507658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{208, 472}], {
             RGBColor[
             0.32528262084800263`, 0.45616518982380916`, 0.9419476988576752]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 214}], {
             RGBColor[
             0.3828653435329973, 0.49291080046599856`, 0.946830407391962]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 233}], {
             RGBColor[
             0.7045416845554648, 0.49561598240663746`, 0.5739669497124782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 273}], {
             RGBColor[
             0.4297324939516893, 0.5421711471050089, 0.9494994222745707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 421}], {
             RGBColor[
             0.37249008899703795`, 0.4820057501195733, 0.9462395519949527]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 423}], {
             RGBColor[
             0.37687473184245884`, 0.48661428775252374`, 0.9464892509185017]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{209, 477}], {
             RGBColor[
             0.40529759982577535`, 0.5164885241169046, 0.9481078912022864]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 227}], {
             RGBColor[
             0.8408474405782448, 0.3149769045127923, 0.18674886126930004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 243}], {
             RGBColor[
             0.8376849116916145, 0.29066832166115775`, 0.18372042003589745`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 326}], {
             RGBColor[
             0.8556196126725499, 0.40214503052670025`, 0.19986184252427644`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 348}], {
             RGBColor[
             0.8979876618717816, 0.5773208368833467, 0.24046628121299102`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 428}], {
             RGBColor[
             0.8331986050247592, 0.2561846027075905, 0.17942432770515804`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 434}], {
             RGBColor[
             0.9136331462118448, 0.6344185701788778, 0.48881376628200723`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 469}], {
             RGBColor[
             0.8482471960053599, 0.3686686083126496, 0.19371011734270402`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 474}], {
             RGBColor[
             0.9145804341522545, 0.6348102980864267, 0.4731147536068143]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{210, 495}], {
             RGBColor[
             0.8391330927044698, 0.3017996755229297, 0.18510719980929416`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 464}], {
             RGBColor[
             0.23745358448324252`, 0.36690915109166977`, 0.936834002403998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 485}], {
             RGBColor[
             0.23952079823930758`, 0.3690819238182165, 0.9369517271692371]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{211, 497}], {
             RGBColor[
             0.23351702426712523`, 0.36277157671219695`, 0.936609821123309]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 287}], {
             RGBColor[
             0.21416398383706822`, 0.3424303041665726, 0.9355076941010749]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 295}], {
             RGBColor[
             0.22405206726645135`, 0.35282330679155405`, 0.9360708058242697]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 299}], {
             RGBColor[
             0.21384131413680724`, 0.3420911578531577, 0.9354893185389921]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 300}], {
             RGBColor[
             0.22223694937519295`, 0.35091550280272016`, 0.9359674375455889]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 301}], {
             RGBColor[
             0.2136344659280746, 0.34187374727084574`, 0.9354775388395093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 389}], {
             RGBColor[
             0.21850801717300872`, 0.34699615863026745`, 0.9357550803731354]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 451}], {
             RGBColor[
             0.21498103480107186`, 0.34328907653376356`, 0.9355542239447563]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{212, 456}], {
             RGBColor[
             0.22108739015867407`, 0.34970724317989477`, 0.9359019718488286]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 254}], {
             RGBColor[
             0.5703520735589939, 0.511904106319279, 0.5892794945919869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 259}], {
             RGBColor[
             0.8830232984339081, 0.5617179434386964, 0.224104111662967]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 261}], {
             RGBColor[
             0.8920963570986589, 0.602916583768641, 0.23167489421385412`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 315}], {
             RGBColor[
             0.5448527569683213, 0.48510270783243126`, 0.5878273462350064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 368}], {
             RGBColor[
             0.6561537738248766, 0.5929010247462924, 0.5945021229284573]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 401}], {
             RGBColor[
             0.8388291376735261, 0.7404246611139982, 0.6099167772233072]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 450}], {
             RGBColor[
             0.8609571905590665, 0.3975119598548832, 0.20318518074431657`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 454}], {
             RGBColor[
             0.902044161930851, 0.6480872421427781, 0.23997558640884487`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 471}], {
             RGBColor[
             0.8805092403498851, 0.5477975823099646, 0.2219082457048863]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 475}], {
             RGBColor[
             0.871604644354381, 0.4793529554696741, 0.21338119452328883`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{213, 500}], {
             RGBColor[
             0.8618492799802115, 0.40436895006188167`, 0.20403944658147605`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 273}], {
             RGBColor[
             0.24667426527178135`, 0.3766006712253524, 0.9373591065341305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 302}], {
             RGBColor[
             0.19497823659732902`, 0.32226486737097304`, 0.9344150941785414]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 347}], {
             RGBColor[
             0.1893670574265447, 0.316367162293171, 0.9340955458257609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 421}], {
             RGBColor[
             0.18943186031713002`, 0.3164352742399168, 0.9340992362545124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 423}], {
             RGBColor[
             0.19381650316255092`, 0.32104381187286724`, 0.9343489351780614]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{214, 477}], {
             RGBColor[
             0.2222393711458674, 0.35091804823724815`, 0.9359675754618462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 224}], {
             RGBColor[
             0.2915446973152564, 0.4237623402527527, 0.9399144112591507]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 351}], {
             RGBColor[
             0.28708427642095813`, 0.4190741550858264, 0.9396603968878219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 356}], {
             RGBColor[
             0.2767305167100354, 0.40819169716336523`, 0.9390707655892996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{215, 430}], {
             RGBColor[
             0.26193106415637823`, 0.3926365341899838, 0.9382279586601969]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 238}], {
             RGBColor[
             0.29301995095784455`, 0.42425818517520597`, 0.9400370439768699]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 281}], {
             RGBColor[
             0.2553973215721218, 0.3857691564707237, 0.9378558716858294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 343}], {
             RGBColor[
             0.2793867448603114, 0.4109835613638972, 0.9392220338529205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{216, 465}], {
             RGBColor[
             0.27425578181697063`, 0.40559059388349944`, 0.9389298330981818]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 290}], {
             RGBColor[
             0.3031025001174864, 0.43489572471311266`, 0.9406097604733883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 340}], {
             RGBColor[
             0.32857716094804046`, 0.4590187548700618, 0.9421576240396021]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 355}], {
             RGBColor[
             0.32421328138501737`, 0.4552389817275355, 0.9418795614926734]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 362}], {
             RGBColor[
             0.35409065029754605`, 0.481117256999343, 0.9437833210202597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 378}], {
             RGBColor[
             0.30140209308183147`, 0.4331084891066064, 0.9405129248082346]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 384}], {
             RGBColor[
             0.30177027996931804`, 0.4334954768697517, 0.9405338925067932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{217, 498}], {
             RGBColor[
             0.3908046357587574, 0.5126843292737169, 0.9461870095342384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 295}], {
             RGBColor[
             0.2307804101674582, 0.3598952217820915, 0.9364539749987908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 300}], {
             RGBColor[
             0.22896529227619977`, 0.3579874177932576, 0.93635060672011]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 336}], {
             RGBColor[
             0.2271057420788739, 0.35603291263357584`, 0.9362447080873302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 389}], {
             RGBColor[
             0.22523636007401557`, 0.35406807362080495`, 0.9361382495476563]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 409}], {
             RGBColor[
             0.2367642996218614, 0.3661846689991738, 0.9367947486508479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 456}], {
             RGBColor[
             0.2278157330596809, 0.3567791581704322, 0.9362851410233497]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{218, 458}], {
             RGBColor[
             0.23123609658963368`, 0.36037417710398584`, 0.936479925666406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 244}], {
             RGBColor[
             0.43435496414043395`, 0.548657383494032, 0.949444989736919]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 274}], {
             RGBColor[
             0.49450158018716717`, 0.6004976856950868, 0.9533481222927589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 334}], {
             RGBColor[
             0.4645364889888964, 0.5747991033502236, 0.9513681298117886]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 337}], {
             RGBColor[
             0.6932397997764845, 0.7588302526554731, 0.971188910299956]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 340}], {
             RGBColor[
             0.43185173064895377`, 0.5464892084598855, 0.9492854859123644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 361}], {
             RGBColor[
             0.5852351734855985, 0.6741310802897922, 0.9605102999918589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 363}], {
             RGBColor[
             0.4655401284489993, 0.5756684054061787, 0.9514320808307029]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 369}], {
             RGBColor[
             0.47310816162837227`, 0.5822234553657439, 0.9519143092127434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 370}], {
             RGBColor[
             0.5588561185016121, 0.6527435990376659, 0.9584143472873132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{219, 498}], {
             RGBColor[
             0.49407920545967077`, 0.6001547828635406, 0.9533148714070008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 349}], {
             RGBColor[
             0.3762573378366486, 0.5003169276156031, 0.9451957627490192]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 359}], {
             RGBColor[
             0.3621822341604067, 0.48812578024652276`, 0.9442989095888945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 371}], {
             RGBColor[
             0.3509285621764658, 0.4783784152000333, 0.9435818355613093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 382}], {
             RGBColor[
             0.3105689508267532, 0.4409688726219141, 0.9410999393200739]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 416}], {
             RGBColor[
             0.3002234451567067, 0.4300950902197503, 0.9405107780769688]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 427}], {
             RGBColor[
             0.30920666661498386`, 0.43953702554153684`, 0.9410223592495326]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 429}], {
             RGBColor[
             0.3162555864633567, 0.44694588722950834`, 0.9414237848069549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{220, 499}], {
             RGBColor[
             0.2998159216660946, 0.42966675719263536`, 0.9404875702170554]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 223}], {
             RGBColor[
             0.46323693275442124`, 0.5733927057392445, 0.9513629056103252]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 258}], {
             RGBColor[
             0.45501626161494246`, 0.5662723735811732, 0.9508390917145717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 297}], {
             RGBColor[
             0.5279871450253872, 0.627682775738259, 0.9559842286184892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 381}], {
             RGBColor[
             0.5529574414035745, 0.647954787237104, 0.9579499818185896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{221, 439}], {
             RGBColor[
             0.6987612824501502, 0.7633077628527738, 0.9716294265306357]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 307}], {
             RGBColor[
             0.456261635454359, 0.5691648443465238, 0.950417290103996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 333}], {
             RGBColor[
             0.41068141899913524`, 0.5301333365139219, 0.9473892347606732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 372}], {
             RGBColor[
             0.4565833875774816, 0.5694260572148426, 0.9504426196097452]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{222, 417}], {
             RGBColor[
             0.5718731828738293, 0.6621247011020224, 0.9601331729684849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 258}], {
             RGBColor[
             0.3816431136278576, 0.5049818159089863, 0.9455389396199805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 268}], {
             RGBColor[
             0.3997592820050565, 0.5206731304122181, 0.946693285849477]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 373}], {
             RGBColor[
             0.3417396383201442, 0.4690205123479532, 0.9430475467307398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 381}], {
             RGBColor[
             0.47958429341648956`, 0.5866642295649169, 0.9526498297239985]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{223, 480}], {
             RGBColor[
             0.3717055099769321, 0.496374363105037, 0.9449057243028214]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 263}], {
             RGBColor[
             0.2861834719747001, 0.4181273524985085, 0.9396090974072282]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 342}], {
             RGBColor[
             0.2794767176957349, 0.41107812851853454`, 0.939227157672795]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 351}], {
             RGBColor[
             0.29450587119895527`, 0.4268747217537883, 0.9400830457311632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 356}], {
             RGBColor[
             0.28415211148803254`, 0.41599226383132715`, 0.939493414432641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{224, 463}], {
             RGBColor[
             0.2830318265857735, 0.4148147733688876, 0.9394296158647704]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 235}], {
             RGBColor[
             0.31564550837904015`, 0.44462855110700683`, 0.9414504121909557]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 249}], {
             RGBColor[
             0.28189858083211217`, 0.41362366022985875`, 0.9393650791955862]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 260}], {
             RGBColor[
             0.27991286113099906`, 0.41153654292208813`, 0.9392519953962168]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 280}], {
             RGBColor[
             0.26557083518380836`, 0.39646216431462483`, 0.9384352382356503]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 296}], {
             RGBColor[
             0.29383455667092717`, 0.42573700098774714`, 0.940060637634782]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 424}], {
             RGBColor[
             0.2974218624617132, 0.42884414496049433`, 0.940289217587641]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 440}], {
             RGBColor[
             0.27796156594151966`, 0.4094856079586846, 0.9391408720218586]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 453}], {
             RGBColor[
             0.2792780627176027, 0.4108693295410645, 0.939215844565674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{225, 470}], {
             RGBColor[
             0.26486570011979793`, 0.3957210226542046, 0.9383950818369088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 236}], {
             RGBColor[
             0.23337407460187973`, 0.3626213275504917, 0.9366016803513484]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 283}], {
             RGBColor[
             0.18031957576389654`, 0.30685768542225833`, 0.9335803051296228]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 292}], {
             RGBColor[
             0.17919781223777545`, 0.3056786408323896, 0.9335164223563106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 308}], {
             RGBColor[
             0.17918563853241248`, 0.3056658454961956, 0.9335157290817995]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 386}], {
             RGBColor[
             0.1791759961486071, 0.30565571073945375`, 0.9335151799623065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 396}], {
             RGBColor[
             0.5864855268156967, 0.6472607121015193, 0.7362180745608087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 422}], {
             RGBColor[
             0.20671849831186667`, 0.3346046268085379, 0.9350836847150235]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{226, 446}], {
             RGBColor[
             0.20378813280661343`, 0.33152462686661266`, 0.9349168047345866]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 309}], {
             RGBColor[
             0.9193309660445672, 0.6696242794444807, 0.3370748612621325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 320}], {
             RGBColor[
             0.9171168323829694, 0.670650788557899, 0.5149397016540836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 348}], {
             RGBColor[
             0.9027713884189711, 0.6140906553673846, 0.24504718315702606`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 428}], {
             RGBColor[
             0.8379823315719487, 0.29295442119162834`, 0.18400522964919308`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{227, 495}], {
             RGBColor[
             0.8439168192516593, 0.3385694940069675, 0.1896881017533292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 388}], {
             RGBColor[
             0.9696267022726579, 0.9734928770909221, 0.7321607638451979]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{228, 490}], {
             RGBColor[
             0.9918174311383581, 0.9889858002878001, 0.6472681311594083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 244}], {
             RGBColor[
             0.3167084139494082, 0.447095666264713, 0.9414615153937971]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 248}], {
             RGBColor[
             0.2667577277658053, 0.3977096636716398, 0.9385028300123448]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 255}], {
             RGBColor[
             0.34428066244060973`, 0.47097736208628804`, 0.9432183946864745]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 313}], {
             RGBColor[
             0.2789668469500533, 0.41054222203715074`, 0.9391981212881146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 338}], {
             RGBColor[
             0.3055405634218271, 0.43742263545021065`, 0.9407499098335221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 379}], {
             RGBColor[
             0.30013749915285226`, 0.43274277274633094`, 0.9404056313560452]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 380}], {
             RGBColor[
             0.2819134302618612, 0.4136392679220333, 0.9393659248486427]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 390}], {
             RGBColor[
             0.29586463316817824`, 0.4283028667339263, 0.9401604252152023]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 411}], {
             RGBColor[
             0.26528288174741516`, 0.39615950699567326`, 0.9384188397134368]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{229, 478}], {
             RGBColor[
             0.27850887095594073`, 0.41006086022998334`, 0.9391720402327646]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 242}], {
             RGBColor[
             0.2244428247428983, 0.35323401767475476`, 0.9360930588844796]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 339}], {
             RGBColor[
             0.21778435426976317`, 0.3462355430360783, 0.9357138688413589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 365}], {
             RGBColor[
             0.22042634378562792`, 0.3490124415290624, 0.9358643262358141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 374}], {
             RGBColor[
             0.23780417240741958`, 0.3672776412285381, 0.9368539678676315]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{230, 391}], {
             RGBColor[
             0.23250262506826308`, 0.3617053788375689, 0.936552052589603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 246}], {
             RGBColor[
             0.27633388437422024`, 0.407774811430481, 0.93904817796454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 256}], {
             RGBColor[
             0.27391624912615603`, 0.40523372349783726`, 0.9389104972137335]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 271}], {
             RGBColor[
             0.25712583983655113`, 0.38758593876102676`, 0.9379543082438752]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 288}], {
             RGBColor[
             0.2572561350755689, 0.3877228873184297, 0.9379617283649826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 442}], {
             RGBColor[
             0.2711958428958343, 0.40237440406605196`, 0.938755574103397]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 444}], {
             RGBColor[
             0.2648697036740537, 0.39572523064356746`, 0.938395309833401]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{231, 492}], {
             RGBColor[
             0.2675328366491727, 0.39852435225280064`, 0.9385469713165818]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 307}], {
             RGBColor[
             0.4130035971526026, 0.5316969057817654, 0.9476609261549895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 312}], {
             RGBColor[
             0.3303045820158528, 0.4601142095117522, 0.9422823672274991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 330}], {
             RGBColor[
             0.3313235898372211, 0.4611852513408379, 0.942340398215439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 350}], {
             RGBColor[
             0.3591838096222978, 0.48552869561681206`, 0.944107852628729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 354}], {
             RGBColor[
             0.35898073503518557`, 0.48535280261628094`, 0.94409491289561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 372}], {
             RGBColor[
             0.41332534927572523`, 0.5319581186500844, 0.9476862556607386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 376}], {
             RGBColor[
             0.3178263634409366, 0.4469988106247622, 0.9415717511395277]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 400}], {
             RGBColor[
             0.3260597275402094, 0.45565259831853255`, 0.9420406290448107]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 414}], {
             RGBColor[
             0.31542779716347613`, 0.44447776538926564`, 0.9414351563383871]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{232, 415}], {
             RGBColor[
             0.3216051563189196, 0.45097056152882875`, 0.9417869478037058]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{233, 476}], {
             RGBColor[
             0.8458261121541704, 0.35324515591315253`, 0.19151644279301172`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 235}], {
             RGBColor[
             0.3728101836078023, 0.49733117588158576`, 0.9449761131297559]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 239}], {
             RGBColor[
             0.36975457999068184`, 0.4946845656075394, 0.9447814127692372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 262}], {
             RGBColor[
             0.4323322286458682, 0.548267980100758, 0.9489396155777698]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 296}], {
             RGBColor[
             0.3509992318996893, 0.478439625762326, 0.9435863385735823]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 332}], {
             RGBColor[
             0.3953853483413155, 0.5168846489129837, 0.946414582664141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 393}], {
             RGBColor[
             0.42489506401207827`, 0.5422301548105988, 0.9483541347345662]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{234, 468}], {
             RGBColor[
             0.4334778335161593, 0.5491980337433716, 0.9490298017896481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 239}], {
             RGBColor[
             0.35398612023304477`, 0.4810267183113057, 0.943776660456982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 249}], {
             RGBColor[
             0.32329479630323715`, 0.4526684377082041, 0.9418860278221313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 260}], {
             RGBColor[
             0.32130907660212404`, 0.45058132040043347`, 0.941772944022762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 262}], {
             RGBColor[
             0.416563768888231, 0.5346101328045243, 0.9479348632655147]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 296}], {
             RGBColor[
             0.3352307721420522, 0.4647817784660925, 0.9425815862613272]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 332}], {
             RGBColor[
             0.37961688858367837`, 0.50322680161675, 0.9454098303518859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 344}], {
             RGBColor[
             0.4103923521286693, 0.5295998986599555, 0.9474490267315575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 393}], {
             RGBColor[
             0.40912660425444114`, 0.5285723075143651, 0.947349382422311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 424}], {
             RGBColor[
             0.3388180779328382, 0.46788892243883967`, 0.9428101662141861]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 440}], {
             RGBColor[
             0.3193577814126447, 0.44853038543702994`, 0.9416618206484036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{235, 453}], {
             RGBColor[
             0.32067427818872773`, 0.4499141070194098, 0.9417367931922191]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 243}], {
             RGBColor[
             0.5633146331293595, 0.36122739545781846`, 0.562473440762307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 276}], {
             RGBColor[
             0.45343165662521556`, 0.5606674341824253, 0.9514328089086481]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 283}], {
             RGBColor[
             0.23426865806856206`, 0.3635615914938426, 0.9366526255563583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 292}], {
             RGBColor[
             0.23314689454244097`, 0.36238254690397387`, 0.9365887427830462]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 396}], {
             RGBColor[
             0.6404346091203621, 0.7039646181731036, 0.7392903949875442]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{236, 422}], {
             RGBColor[
             0.26066758061653217`, 0.39130853288012224`, 0.9381560051417591]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 267}], {
             RGBColor[
             0.9475774996267206, 0.9513626199375382, 0.7014579081154306]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 270}], {
             RGBColor[
             0.9480577404464491, 0.9590498999175098, 0.9029559373872008]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 329}], {
             RGBColor[
             0.8943251384864865, 0.9185746058926771, 0.989782724153959]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 426}], {
             RGBColor[
             0.8881333928283652, 0.9136374759753497, 0.9891921499256506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 448}], {
             RGBColor[
             0.7370158535300309, 0.7940376208084021, 0.9750172525524329]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{237, 489}], {
             RGBColor[
             0.9480949935467251, 0.959065305031835, 0.9023385571076953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 265}], {
             RGBColor[
             0.32058421295120315`, 0.4520956650524487, 0.9416483204611299]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 328}], {
             RGBColor[
             0.35273346300045894`, 0.47994172957682313`, 0.943696842245803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 343}], {
             RGBColor[
             0.306520714368336, 0.43844834351747275`, 0.9408058924805078]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 431}], {
             RGBColor[
             0.38434692528377257`, 0.5073237216678145, 0.9457112241078087]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 433}], {
             RGBColor[
             0.32283008594645624`, 0.45404092736007795`, 0.94179142550244]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 436}], {
             RGBColor[
             0.3965368671240651, 0.5173498014044343, 0.9466350145946033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 462}], {
             RGBColor[
             0.392016142899485, 0.5136796738226148, 0.9462791266236859]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{238, 465}], {
             RGBColor[
             0.30138975132499524`, 0.433055376037075, 0.940513691725769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 262}], {
             RGBColor[
             0.41350816527111056`, 0.531963522530478, 0.947740162904996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 263}], {
             RGBColor[
             0.31216558423603546`, 0.4415359530567809, 0.9412315474042139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 296}], {
             RGBColor[
             0.33217516852493173`, 0.46213516819204603`, 0.9423868859008084]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 332}], {
             RGBColor[
             0.37656128496655794`, 0.5005801913427036, 0.9452151299913671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 393}], {
             RGBColor[
             0.4060710006373207, 0.5259256972403187, 0.9471546820617923]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 424}], {
             RGBColor[
             0.3357624743157177, 0.4652423121647933, 0.9426154658536674]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 440}], {
             RGBColor[
             0.3163021777955242, 0.4458837751629835, 0.9414671202878849]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{239, 453}], {
             RGBColor[
             0.31761867457160725`, 0.44726749674536337`, 0.9415420928317004]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 251}], {
             RGBColor[
             0.25758537828186423`, 0.38806894280347104`, 0.9379804782785095]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 310}], {
             RGBColor[
             0.2766913122921885, 0.4081504908345045, 0.939068532955701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 352}], {
             RGBColor[
             0.24222822396059346`, 0.3719275999119933, 0.937105911058787]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 367}], {
             RGBColor[
             0.24323530728920995`, 0.3729861083431402, 0.9371632629645055]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 382}], {
             RGBColor[
             0.26942512488484194`, 0.40051326716649266`, 0.9386547343322136]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 399}], {
             RGBColor[
             0.24906325398775672`, 0.3791116498364756, 0.9374951559073132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 412}], {
             RGBColor[
             0.2495035202048371, 0.3795743975451175, 0.9375202284170604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 416}], {
             RGBColor[
             0.2590796192147955, 0.38963948476432886`, 0.9380655730891085]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{240, 429}], {
             RGBColor[
             0.2751117605214455, 0.4064902817740869, 0.9389785798190946]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 402}], {
             RGBColor[
             0.6288966867837086, 0.7086387216585579, 0.9645893173262957]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 417}], {
             RGBColor[
             0.7032574015004508, 0.7681092940971459, 0.9710577835336467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 436}], {
             RGBColor[
             0.5892009770363313, 0.6764119562142918, 0.9614643256448061]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{241, 461}], {
             RGBColor[
             0.8249688230204753, 0.8639714322998968, 0.9750930222658254]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 339}], {
             RGBColor[
             0.21834915626655288`, 0.34682918574521915`, 0.9357460334795263]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 365}], {
             RGBColor[
             0.22099114578241763`, 0.3496060842382034, 0.9358964908739815]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{242, 374}], {
             RGBColor[
             0.2383689744042093, 0.367871283937679, 0.936886132505799]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 276}], {
             RGBColor[
             0.7294231328480298, 0.5025695960181678, 0.5742322488928711]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 326}], {
             RGBColor[
             0.8572408103331092, 0.41460626615910345`, 0.2014143032349089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 428}], {
             RGBColor[
             0.8348198026853184, 0.2686458383399938, 0.18097678841579048`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 454}], {
             RGBColor[
             0.869594267772993, 0.47070043117032717`, 0.21172233093369885`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 469}], {
             RGBColor[
             0.8498683936659192, 0.3811298439450528, 0.19526257805333647`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 471}], {
             RGBColor[
             0.8480593461920269, 0.37041077133751354`, 0.1936549902297403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 475}], {
             RGBColor[
             0.8391547501965229, 0.3019661444972231, 0.18512793904814284`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{243, 495}], {
             RGBColor[
             0.8407542903650291, 0.31426091115533294`, 0.1866596605199266]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 274}], {
             RGBColor[
             0.40258764491589, 0.5228672426461249, 0.9469441500000384]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 313}], {
             RGBColor[
             0.3046994618698019, 0.43447349621750786`, 0.9407776233385161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 334}], {
             RGBColor[
             0.3726225537176192, 0.4971686603012616, 0.9449641575190681]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 340}], {
             RGBColor[
             0.33993779537767665`, 0.4688587654109236, 0.9428815136196439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 355}], {
             RGBColor[
             0.3355739158146536, 0.46507899226839733`, 0.9426034510727153]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 363}], {
             RGBColor[
             0.37362619317772217`, 0.49803796235721676`, 0.9450281085379824]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 378}], {
             RGBColor[
             0.3127627275114677, 0.4429484996474682, 0.9412368143882763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 379}], {
             RGBColor[
             0.3258701140726008, 0.45667404692668806`, 0.9419851334064466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 380}], {
             RGBColor[
             0.3076460451816098, 0.43757054210239044`, 0.9409454268990441]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 390}], {
             RGBColor[
             0.3215972480879268, 0.45223414091428343`, 0.9417399272656037]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{244, 498}], {
             RGBColor[
             0.40216527018839365`, 0.5225243398145787, 0.9469108991142803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 394}], {
             RGBColor[
             0.22510267482771082`, 0.3539275619508045, 0.936130636370649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 438}], {
             RGBColor[
             0.22151371355788788`, 0.3501553361029332, 0.9359262503357249]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 445}], {
             RGBColor[
             0.22560109399094413`, 0.3544514320929628, 0.93615902060465]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{245, 460}], {
             RGBColor[
             0.23495456172986623`, 0.36428251973067727`, 0.936691686755166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 256}], {
             RGBColor[
             0.2918037733500637, 0.42403464559170456`, 0.9399291652560644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 288}], {
             RGBColor[
             0.2751436592994766, 0.40652380941229693`, 0.9389803964073136]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 333}], {
             RGBColor[
             0.33643527177961996`, 0.46448215779697133`, 0.9427075059768388]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 392}], {
             RGBColor[
             0.3001114005223494, 0.4327664884837622, 0.940402272333493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 442}], {
             RGBColor[
             0.28908336711974203`, 0.42117532615991926`, 0.939774242145728]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 444}], {
             RGBColor[
             0.2827572278979614, 0.41452615273743476`, 0.9394139778757318]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 459}], {
             RGBColor[
             0.3423837632254584, 0.4696344421074833, 0.9430865385917233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{246, 492}], {
             RGBColor[
             0.2854203608730804, 0.4173252743466679, 0.9395656393589127]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 255}], {
             RGBColor[
             0.4462984536881862, 0.5598509487377481, 0.9499715158755377]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 269}], {
             RGBColor[
             0.47197536116157857`, 0.5820909954323062, 0.9516076257145445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 360}], {
             RGBColor[
             0.5371888520305683, 0.6351531360172418, 0.9567086207009003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 369}], {
             RGBColor[
             0.457479402684923, 0.5695353247878849, 0.9506839560586847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 370}], {
             RGBColor[
             0.5432273595581627, 0.6400554684598069, 0.9571839941332545]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 425}], {
             RGBColor[
             0.4351771155351065, 0.550218204604259, 0.9492628740426365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 466}], {
             RGBColor[
             0.4992597773340883, 0.6043606044932961, 0.953722705002015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{247, 468}], {
             RGBColor[
             0.48669420259584584`, 0.5941593048480999, 0.9527334969294036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 286}], {
             RGBColor[
             0.23281996068137648`, 0.36203891868719107`, 0.9365701243833138]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 294}], {
             RGBColor[
             0.240426199543799, 0.37003355799499527`, 0.9370032884341067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 313}], {
             RGBColor[
             0.254748775686199, 0.38508749362443473`, 0.9378189379570638]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 380}], {
             RGBColor[
             0.257695358998007, 0.3881845395093172, 0.937986741517592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 411}], {
             RGBColor[
             0.2410648104835609, 0.37070477858295714`, 0.937039656382386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{248, 478}], {
             RGBColor[
             0.25429079969208646`, 0.3846061318172672, 0.9377928569017139]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 260}], {
             RGBColor[
             0.28756214905519606`, 0.4195764295232854, 0.9396876110273925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 280}], {
             RGBColor[
             0.27322012310800536`, 0.4045020509158221, 0.938870853866826]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 296}], {
             RGBColor[
             0.3014838445951241, 0.4337768875889444, 0.9404962532659576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 424}], {
             RGBColor[
             0.30507115038591015`, 0.4368840315616916, 0.9407248332188166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 440}], {
             RGBColor[
             0.2856108538657166, 0.41752549455988186`, 0.9395764876530341]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{249, 470}], {
             RGBColor[
             0.27251498804399493`, 0.40376090925540187`, 0.9388306974680845]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 339}], {
             RGBColor[
             0.20806801028262886`, 0.33602304945380984`, 0.9351605374253343]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{250, 365}], {
             RGBColor[
             0.21070999979849359`, 0.338799947946794, 0.9353109948197895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 305}], {
             RGBColor[
             0.25482853774731307`, 0.38517132860787223`, 0.9378234802884469]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 367}], {
             RGBColor[
             0.24419513183599667`, 0.3739949447982042, 0.9372179235525118]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 382}], {
             RGBColor[
             0.27038494943162866`, 0.40152210362155666`, 0.9387093949202199]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 416}], {
             RGBColor[
             0.26003944376158217`, 0.39064832121939286`, 0.9381202336771148]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 427}], {
             RGBColor[
             0.2690226652198594, 0.4000902565411794, 0.9386318148496786]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 429}], {
             RGBColor[
             0.2760715850682322, 0.4074991182291509, 0.9390332404071009]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{251, 499}], {
             RGBColor[
             0.25963192027097015`, 0.39021998819227793`, 0.9380970258172014]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 282}], {
             RGBColor[
             0.6717272001021579, 0.7429460920325152, 0.9682785844173988]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 432}], {
             RGBColor[
             0.8172102397534445, 0.8577657390481622, 0.982246863062763]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{252, 467}], {
             RGBColor[
             0.7213175895970523, 0.7822180503007243, 0.9728578543010624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 261}], {
             RGBColor[
             0.9325093316648222, 0.7680041432668934, 0.5596474808987255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 277}], {
             RGBColor[
             0.8781666893011308, 0.9046720920391318, 0.9377821758000617]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 291}], {
             RGBColor[
             0.819979493708928, 0.8592158126034372, 0.9319826199336896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 311}], {
             RGBColor[
             0.8659443575362178, 0.8951239135712197, 0.9365639679939195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 319}], {
             RGBColor[
             0.8499607656875054, 0.8826374101392084, 0.934970872933598]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 377}], {
             RGBColor[
             0.9830684787672088, 0.9867535506374262, 0.9072964317019494]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 484}], {
             RGBColor[
             0.9889617727140382, 0.9876413426482502, 0.6827040059696212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{253, 488}], {
             RGBColor[
             0.877198073649208, 0.9039154021300979, 0.937685633244106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 315}], {
             RGBColor[
             0.21099893285942517`, 0.33910363491324724`, 0.9353274491301715]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 325}], {
             RGBColor[
             0.20775758490962407`, 0.33569677270467635`, 0.935142859159575]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 347}], {
             RGBColor[
             0.20771262472504887`, 0.3356495167000475, 0.935140298743576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 368}], {
             RGBColor[
             0.32229994971598047`, 0.44690195182710835`, 0.9420022258236223]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 386}], {
             RGBColor[
             0.20771262472504887`, 0.3356495167000475, 0.935140298743576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 401}], {
             RGBColor[
             0.50497531356463, 0.5944255881948143, 0.9574168801184721]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 454}], {
             RGBColor[
             0.568190337821955, 0.5020881692235942, 0.5874756893040098]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{254, 471}], {
             RGBColor[
             0.5466554162409889, 0.4017985093907806, 0.5694083486000513]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 269}], {
             RGBColor[
             0.4232624333249523, 0.5410303787827784, 0.94819088586856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 274}], {
             RGBColor[
             0.43015989340709154`, 0.5467489384677, 0.9487010292927157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 334}], {
             RGBColor[
             0.40019480220882075`, 0.5210503561228367, 0.9467210368117455]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 338}], {
             RGBColor[
             0.35884542683277726`, 0.48523560545214284`, 0.9440862911766009]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 369}], {
             RGBColor[
             0.40876647484829665`, 0.5284747081383571, 0.9472672162127003]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 370}], {
             RGBColor[
             0.4945144317215364, 0.598994851810279, 0.9537672542872702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 379}], {
             RGBColor[
             0.35344236256380235`, 0.4805557427482631, 0.943742012699124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 390}], {
             RGBColor[
             0.3491694965791283, 0.4761158367358585, 0.9434968065582812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 425}], {
             RGBColor[
             0.38646418769848023`, 0.5091575879547311, 0.9458461341966522]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{255, 466}], {
             RGBColor[
             0.45054684949746193`, 0.5632999878437683, 0.9503059651560305]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 271}], {
             RGBColor[
             0.2725957288123946, 0.4038457729222503, 0.9388352955353996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 333}], {
             RGBColor[
             0.3340176365315557, 0.4619410698643276, 0.9425698252260324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 442}], {
             RGBColor[
             0.28666573187167776`, 0.4186342382272755, 0.9396365613949216]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 444}], {
             RGBColor[
             0.28033959264989716`, 0.411985064804791, 0.9392762971249253]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{256, 492}], {
             RGBColor[
             0.28300272562501616`, 0.4147841864140242, 0.9394279586081062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 272}], {
             RGBColor[
             0.8397181825766789, 0.3055916208213189, 0.18563986428858031`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 306}], {
             RGBColor[
             0.8582164736566054, 0.4477775920644729, 0.2033538487175496]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 317}], {
             RGBColor[
             0.8711268784377937, 0.5076990787158229, 0.21417744721027115`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 357}], {
             RGBColor[
             0.8829978584207956, 0.5607626793064351, 0.22403944465155362`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 418}], {
             RGBColor[
             0.9186634619525802, 0.7177171878043327, 0.5626295641489729]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{257, 420}], {
             RGBColor[
             0.9137481314322007, 0.7140513423503487, 0.5709499365964574]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 289}], {
             RGBColor[
             0.4063967473847854, 0.5264221693154291, 0.9471162192741931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 297}], {
             RGBColor[
             0.4463933258988235, 0.5592718859080008, 0.9501602626281445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 314}], {
             RGBColor[
             0.35174895766394676`, 0.47908900053701325`, 0.9436341104363243]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 373}], {
             RGBColor[
             0.3335189671806654, 0.461900180189882, 0.9425237328349862]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 381}], {
             RGBColor[
             0.4713636222770108, 0.5795438974068458, 0.952126015828245]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 397}], {
             RGBColor[
             0.36598524788401654`, 0.49141975958888606`, 0.94454123426049]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{258, 472}], {
             RGBColor[
             0.3509345795878789, 0.47838362717935545`, 0.9435822189854435]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 341}], {
             RGBColor[
             0.9277070351691528, 0.7270975616364004, 0.37415406223837167`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 405}], {
             RGBColor[
             0.9279266912954685, 0.7275673838799486, 0.39806227602736116`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 450}], {
             RGBColor[
             0.8397745913250846, 0.3013267240551166, 0.18550990071046175`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 454}], {
             RGBColor[
             0.8808615626968692, 0.5519020063430116, 0.22230030637499004`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 469}], {
             RGBColor[
             0.8611356885897954, 0.46233141911773723`, 0.2058405534946276]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 471}], {
             RGBColor[
             0.8593266411159032, 0.451612346510198, 0.20423296567103144`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 475}], {
             RGBColor[
             0.8504220451203991, 0.38316771966990754`, 0.19570591448943397`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 491}], {
             RGBColor[
             0.9280010655847133, 0.727726462964249, 0.4061574584267472]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{259, 500}], {
             RGBColor[
             0.8406666807462297, 0.3081837142621151, 0.18636416654762122`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 280}], {
             RGBColor[
             0.27123440340689225`, 0.4024149336080515, 0.9387577700674566]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 424}], {
             RGBColor[
             0.3030854306847971, 0.434796914253921, 0.9406117494194473]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 440}], {
             RGBColor[
             0.28362513416460355`, 0.4154383772521112, 0.9394634038536649]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 470}], {
             RGBColor[
             0.2705292683428818, 0.4016737919476313, 0.9387176136687151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{260, 483}], {
             RGBColor[
             0.2911128004849959, 0.42330838930030823`, 0.9398898153736015]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 484}], {
             RGBColor[
             0.9364392575786439, 0.7675671876801757, 0.34462692180178206`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{261, 500}], {
             RGBColor[
             0.8497397394109806, 0.34938235459205963`, 0.19393494909850834`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 332}], {
             RGBColor[
             0.43913893362174417`, 0.5541636058359223, 0.9493733327998998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 344}], {
             RGBColor[
             0.4699143971667351, 0.5805367028791276, 0.9514125291795714]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 387}], {
             RGBColor[
             0.6255998101870561, 0.7048955003973141, 0.9650590620780228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 393}], {
             RGBColor[
             0.46864864929250694`, 0.5795091117335374, 0.951312884870325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{262, 424}], {
             RGBColor[
             0.39834012297090404`, 0.5188257266580119, 0.9467736686621999]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 296}], {
             RGBColor[
             0.2934102361450429, 0.4252910132115676, 0.9400364732085589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 323}], {
             RGBColor[
             0.2563726589916906, 0.3867942979386546, 0.9379114157089916]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 342}], {
             RGBColor[
             0.2666938975771815, 0.3976425740963284, 0.9384991949775311]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 395}], {
             RGBColor[
             0.2691941123375187, 0.40027045833221453`, 0.938641578509396]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 440}], {
             RGBColor[
             0.2775372454156354, 0.40903962018250506`, 0.9391167075956355]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 447}], {
             RGBColor[
             0.2599502995006695, 0.3905546249491011, 0.938115157043333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 453}], {
             RGBColor[
             0.27885374219171843`, 0.41042334176488493`, 0.9391916801394509]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{263, 463}], {
             RGBColor[
             0.2702490064672201, 0.4013792189466815, 0.9387016531695065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 394}], {
             RGBColor[
             0.23171433520063273`, 0.36087683620622507`, 0.9365071606478118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 398}], {
             RGBColor[
             0.2479686232623, 0.377961123540424, 0.9374328183068594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{264, 445}], {
             RGBColor[
             0.23221275436386601`, 0.3614007063483834, 0.9365355448818129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 328}], {
             RGBColor[
             0.35316375548579293`, 0.48031442730049023`, 0.9437242601024758]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 433}], {
             RGBColor[
             0.32326037843179023`, 0.45441362508374517`, 0.9418188433591128]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{265, 462}], {
             RGBColor[
             0.392446435384819, 0.5140523715462819, 0.9463065444803587]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 364}], {
             RGBColor[
             0.2740437091478759, 0.405367692062097, 0.9389177558734103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 374}], {
             RGBColor[
             0.27062553266643685`, 0.40177497185519817`, 0.9387230957795312]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 410}], {
             RGBColor[
             0.326592877843097, 0.45552256223454524`, 0.9420962704893343]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{266, 437}], {
             RGBColor[
             0.2726756027922651, 0.40392972553939704`, 0.9388398442403902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 278}], {
             RGBColor[
             0.9687131736129876, 0.9678890438697982, 0.6921508091390034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 329}], {
             RGBColor[
             0.9358102453449542, 0.941979730786866, 0.7003355368972839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 406}], {
             RGBColor[
             0.9898404936899885, 0.9773917410301207, 0.415032665757733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 413}], {
             RGBColor[
             0.981449315920919, 0.9490863280728146, 0.38243452466585603`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 476}], {
             RGBColor[
             0.9187775169477521, 0.6742536840952063, 0.3030402150761125]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 486}], {
             RGBColor[
             0.9619951023866931, 0.9628588250229391, 0.7028330719374227]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{267, 493}], {
             RGBColor[
             0.991319933690298, 0.9817192401312839, 0.4771566948770857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 275}], {
             RGBColor[
             0.4116793705742366, 0.5309977120097701, 0.9474528233525847]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 285}], {
             RGBColor[
             0.3620365603618595, 0.4879996049239992, 0.9442896273832655]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 324}], {
             RGBColor[
             0.3896661145929028, 0.5119309360971549, 0.946050158147012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 353}], {
             RGBColor[
             0.5246586597567469, 0.6237950026375101, 0.9560497714979366]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 441}], {
             RGBColor[
             0.4298935905497302, 0.5467739538792281, 0.9486134173432208]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 480}], {
             RGBColor[
             0.3816010072146523, 0.5049453454501976, 0.9455362566365644]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{268, 481}], {
             RGBColor[
             0.3639357382267393, 0.48964457733510314`, 0.9444106413174386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 360}], {
             RGBColor[
             0.5141528316673345, 0.616332566062272, 0.9549279906939228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 369}], {
             RGBColor[
             0.43444338232168905`, 0.5507147548329152, 0.948903326051707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 425}], {
             RGBColor[
             0.4121410951718726, 0.5313976346492894, 0.947482244035659]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 466}], {
             RGBColor[
             0.47622375697085434`, 0.5855400345383266, 0.9519420749950372]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{269, 468}], {
             RGBColor[
             0.4636581822326119, 0.5753387348931303, 0.9509528669224259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 309}], {
             RGBColor[
             0.9915269265441726, 0.9888220703419007, 0.6489133693566129]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 345}], {
             RGBColor[
             0.824874141314561, 0.8621219539632672, 0.8908628396870938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 375}], {
             RGBColor[
             0.9741122632489756, 0.9792447932430604, 0.8853225104060825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 426}], {
             RGBColor[
             0.9300987405065613, 0.9447298808495102, 0.9012429919407459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{270, 489}], {
             RGBColor[
             0.9900603412249211, 0.9901577099059953, 0.8143893991227904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 284}], {
             RGBColor[
             0.2504489768010796, 0.3805681323731789, 0.9375740707715388]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 442}], {
             RGBColor[
             0.26987532258207286`, 0.400986453490465, 0.9386803724250632]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 444}], {
             RGBColor[
             0.26354918336029226`, 0.3943372800679805, 0.938320108155067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 464}], {
             RGBColor[
             0.24983604138275278`, 0.37992389838616725`, 0.9375391650062217]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{271, 492}], {
             RGBColor[
             0.2662123163354113, 0.39713640167721365`, 0.9384717696382479]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 306}], {
             RGBColor[
             0.8390812230199529, 0.30140098239829205`, 0.18505752934082234`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 317}], {
             RGBColor[
             0.8519916278011412, 0.36132246904964216`, 0.1958811278335439]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{272, 357}], {
             RGBColor[
             0.8638626077841431, 0.41438606964025426`, 0.20574312527482636`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 308}], {
             RGBColor[
             0.23624385022904204`, 0.36563764368892326`, 0.9367651098278627]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 421}], {
             RGBColor[
             0.236299010735822, 0.36569562087892715`, 0.9367682511371211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 423}], {
             RGBColor[
             0.24068365358124288`, 0.3703041585118776, 0.9370179500606701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 446}], {
             RGBColor[
             0.26084634450324296`, 0.39149642505934035`, 0.9381661854806498]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{273, 477}], {
             RGBColor[
             0.2691065215645594, 0.4001783948762585, 0.9386365903444549]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 334}], {
             RGBColor[
             0.4327691697643524, 0.5490089625023165, 0.9488672900749079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 340}], {
             RGBColor[
             0.40008441142440987`, 0.5206990676119785, 0.9467846461754836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 361}], {
             RGBColor[
             0.5534678542610545, 0.6483409394418851, 0.9580094602549781]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 363}], {
             RGBColor[
             0.4337728092244554, 0.5498782645582716, 0.9489312410938221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 369}], {
             RGBColor[
             0.4413408424038283, 0.5564333145178368, 0.9494134694758627]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 370}], {
             RGBColor[
             0.5270887992770681, 0.6269534581897589, 0.9559135075504326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 379}], {
             RGBColor[
             0.386016730119334, 0.5085143491277428, 0.9458882659622865]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{274, 498}], {
             RGBColor[
             0.46231188623512687`, 0.5743646420156336, 0.95081403167012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 282}], {
             RGBColor[
             0.5106811757652547, 0.612557396257451, 0.9549190346803453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 285}], {
             RGBColor[
             0.36406115169331943`, 0.4897532041763907, 0.9444186325526303]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 324}], {
             RGBColor[
             0.3916907059243627, 0.5136845353495464, 0.9461791633163769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 353}], {
             RGBColor[
             0.5266832510882068, 0.6255486018899017, 0.9561787766673014]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 441}], {
             RGBColor[
             0.43191818188119013`, 0.5485275531316196, 0.9487424225125856]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{275, 481}], {
             RGBColor[
             0.36596032955819924`, 0.49139817658749463`, 0.9445396464868034]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 283}], {
             RGBColor[
             0.4003771577872324, 0.5049037920541919, 0.9484114336869224]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 292}], {
             RGBColor[
             0.39925539426111123`, 0.5037247474643232, 0.9483475509136101]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 396}], {
             RGBColor[
             0.8065431088390325, 0.8453068187334528, 0.7510492031181083]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{276, 422}], {
             RGBColor[
             0.4267760803352025, 0.5326507334404715, 0.9499148132723232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 291}], {
             RGBColor[
             0.7131143362098424, 0.7758096064076011, 0.9720402306671867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 311}], {
             RGBColor[
             0.7590792000371321, 0.8117177073753836, 0.9766215787274166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 319}], {
             RGBColor[
             0.7430956081884199, 0.7992312039433723, 0.9750284836670953]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 331}], {
             RGBColor[
             0.8039966134471465, 0.8469425741957761, 0.9810626907032964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 377}], {
             RGBColor[
             0.8762033212681233, 0.9033473444415901, 0.9473540424354466]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 419}], {
             RGBColor[
             0.6419960336426249, 0.718265092425402, 0.9663099050077802]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 449}], {
             RGBColor[
             0.7498021540184663, 0.8044704085174408, 0.9756969294792002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 484}], {
             RGBColor[
             0.8820966152149525, 0.9042351364524142, 0.7227616167031183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{277, 488}], {
             RGBColor[
             0.7703329161501223, 0.8205091959342619, 0.9777432439776033]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 329}], {
             RGBColor[
             0.9154608124727537, 0.9351010298249371, 0.9804756251775316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 406}], {
             RGBColor[
             0.969491060817788, 0.9705130400681918, 0.6951727540379807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 413}], {
             RGBColor[
             0.9610998830487185, 0.9422076271108857, 0.6625746129461039]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 486}], {
             RGBColor[
             0.9416456695144926, 0.9559801240610102, 0.9829731602176706]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{278, 493}], {
             RGBColor[
             0.9709705008180975, 0.974840539169355, 0.7572967831573334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 285}], {
             RGBColor[
             0.2964892825686648, 0.42843496613236076`, 0.9402152006381983]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 324}], {
             RGBColor[
             0.3241188367997081, 0.45236629730551653`, 0.9419757314019449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 481}], {
             RGBColor[
             0.2983884604335446, 0.4300799385434647, 0.9403362145723715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{279, 494}], {
             RGBColor[
             0.2685318784304253, 0.3995744085078045, 0.9386038652680744]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 327}], {
             RGBColor[
             0.25698076875714937`, 0.3874334598585377, 0.9379460466605166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 470}], {
             RGBColor[
             0.25618724239569113`, 0.386599413340168, 0.9379008565081486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{280, 483}], {
             RGBColor[
             0.2767707745378052, 0.40823401069284493`, 0.939073058213035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 288}], {
             RGBColor[
             0.2504872858476244, 0.38060839761003135`, 0.9375762524150663]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 343}], {
             RGBColor[
             0.26889808498261325`, 0.3999593148129905, 0.9386247201894673]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{281, 465}], {
             RGBColor[
             0.26376712193927254`, 0.39456634733259277`, 0.9383325194347287]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 324}], {
             RGBColor[
             0.48866791978392093`, 0.5934906203448358, 0.9535163694747727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 353}], {
             RGBColor[
             0.6236604649477651, 0.705354686885191, 0.9635159828256973]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 432}], {
             RGBColor[
             0.7531414292760994, 0.8071831282683875, 0.9762245194841053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 441}], {
             RGBColor[
             0.5288953957407483, 0.628333638126909, 0.9560796286709814]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{282, 467}], {
             RGBColor[
             0.6572487791197071, 0.7316354395209496, 0.9668355107224047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 292}], {
             RGBColor[
             0.18009239570445779`, 0.3066189047757405, 0.9335673675613205]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 386}], {
             RGBColor[
             0.18007057961528944`, 0.30659597468280464`, 0.9335661251673164]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{283, 422}], {
             RGBColor[
             0.207613081778549, 0.3355448907518888, 0.9351346299200334]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 442}], {
             RGBColor[
             0.26451897986036277`, 0.3953565976782041, 0.9383753366310607]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 444}], {
             RGBColor[
             0.25819284063858217`, 0.3887074242557196, 0.9380150723610645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{284, 464}], {
             RGBColor[
             0.24447969866104266`, 0.37429404257390636`, 0.9372341292122193]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 324}], {
             RGBColor[
             0.3420478957119857, 0.4706864282637755, 0.9430159673470576]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 480}], {
             RGBColor[
             0.3339827883337351, 0.46370083761681824`, 0.9425020658366099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{285, 481}], {
             RGBColor[
             0.3163175193458222, 0.44840006950172373`, 0.9413764505174842]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 294}], {
             RGBColor[
             0.23070650372322443`, 0.3598175414232626, 0.9364497661361264]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 346}], {
             RGBColor[
             0.22049146079372114`, 0.3490808836332252, 0.935868034553093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 358}], {
             RGBColor[
             0.22436323878386594`, 0.35315036778577047`, 0.9360885265818495]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 407}], {
             RGBColor[
             0.21872930348009942`, 0.347228744569382, 0.9357676823009604]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{286, 411}], {
             RGBColor[
             0.2313451146629863, 0.3604887620112245, 0.9364861340844057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 295}], {
             RGBColor[
             0.2196997994484176, 0.34824879736508285`, 0.9358229506106359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 299}], {
             RGBColor[
             0.2094890463187735, 0.33751664842668644`, 0.9352414633253583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 300}], {
             RGBColor[
             0.2178846815571592, 0.3463409933762489, 0.9357195823319551]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 301}], {
             RGBColor[
             0.20928219811004087`, 0.33729923784437454`, 0.9352296836258756]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 389}], {
             RGBColor[
             0.214155749354975, 0.34242164920379625`, 0.9355072251595016]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 451}], {
             RGBColor[
             0.21062876698303812`, 0.3387145671072923, 0.9353063687311225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{287, 456}], {
             RGBColor[
             0.21673512234064032`, 0.34513273375342357`, 0.9356541166351948]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 343}], {
             RGBColor[
             0.274476709135814, 0.40582280250320485`, 0.9389424145821572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 392}], {
             RGBColor[
             0.281033651223698, 0.41271456437171095`, 0.9393158227339358]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 465}], {
             RGBColor[
             0.2693457460924733, 0.4004298350228071, 0.9386502138274186]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{288, 492}], {
             RGBColor[
             0.26634261157442907`, 0.39727335023461663`, 0.9384791897593554]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 291}], {
             RGBColor[
             0.5471490964494157, 0.6426680909259248, 0.9577289938124869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 297}], {
             RGBColor[
             0.47936763079523015`, 0.5878325714725148, 0.9522613561781106]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 314}], {
             RGBColor[
             0.3847232625603534, 0.5076496861015274, 0.9457352039862904]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 349}], {
             RGBColor[
             0.42648626116779464`, 0.5438226964259498, 0.9483963053279869]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 359}], {
             RGBColor[
             0.4124111574915527, 0.5316315490568694, 0.9474994521678624]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 381}], {
             RGBColor[
             0.5043379271734174, 0.6081045829713598, 0.9542271093782111]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 397}], {
             RGBColor[
             0.39895955278042317`, 0.5199804451534001, 0.9466423278104561]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 419}], {
             RGBColor[
             0.4760307938821983, 0.5851235769437257, 0.9519986681530803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{289, 472}], {
             RGBColor[
             0.3839088844842855, 0.5069443127438695, 0.9456833125354096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 316}], {
             RGBColor[
             0.268490139738015, 0.3995305384956953, 0.9386014883112883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 340}], {
             RGBColor[
             0.31195990105564253`, 0.44256756021982796`, 0.9411741462288754]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 355}], {
             RGBColor[
             0.30759602149261944`, 0.4387877870773017, 0.9408960836819469]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 362}], {
             RGBColor[
             0.3374733904051481, 0.4646660623491092, 0.9427998432095333]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 378}], {
             RGBColor[
             0.28478483318943354`, 0.41665729445637256`, 0.939529446997508]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{290, 384}], {
             RGBColor[
             0.2851530200769201, 0.4170442822195179, 0.9395504146960666]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 297}], {
             RGBColor[
             0.5871456749634538, 0.6755178075184964, 0.9607730371664382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 311}], {
             RGBColor[
             0.7008920044449292, 0.7662614279396891, 0.9708220228610445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 319}], {
             RGBColor[
             0.6849084125962169, 0.7537749245076777, 0.969228927800723]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 349}], {
             RGBColor[
             0.5342643053360183, 0.6315079324719315, 0.9569079863163146]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 359}], {
             RGBColor[
             0.5201892016597764, 0.619316785102851, 0.95601113315619]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 419}], {
             RGBColor[
             0.583808838050422, 0.6728088129897074, 0.960510349141408]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{291, 488}], {
             RGBColor[
             0.7121457205579194, 0.7750529164985673, 0.971943688111231]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 308}], {
             RGBColor[
             0.17895845847297373`, 0.30542706484967774`, 0.9335027915134972]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 386}], {
             RGBColor[
             0.17894881608916835`, 0.3054169300929359, 0.9335022423940041]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{292, 422}], {
             RGBColor[
             0.20649131825242792`, 0.3343658461620201, 0.9350707471467212]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 298}], {
             RGBColor[
             0.9279560632534805, 0.9449120378208546, 0.9763848153450053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 317}], {
             RGBColor[
             0.9188363181868828, 0.7644234365766909, 0.5933539685152149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 353}], {
             RGBColor[
             0.7969674264911133, 0.8418814193634385, 0.9635324755439242]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 418}], {
             RGBColor[
             0.9663729017016692, 0.9744415456652006, 0.9418060854539165]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 420}], {
             RGBColor[
             0.9614575711812897, 0.9707757002112165, 0.9501264579014013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{293, 432}], {
             RGBColor[
             0.9264483908194477, 0.943709860746635, 0.9762410122023322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 358}], {
             RGBColor[
             0.23196947764628847`, 0.36114500709357467`, 0.9365216906326425]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 411}], {
             RGBColor[
             0.23895135352540886`, 0.3684834013190287, 0.9369192981351986]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 430}], {
             RGBColor[
             0.23902588418057213`, 0.36856173776312173`, 0.9369235425457519]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{294, 478}], {
             RGBColor[
             0.25217734273393444`, 0.38238475455333876`, 0.9376724986545265]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 300}], {
             RGBColor[
             0.22777276498654234`, 0.3567339960012304, 0.9362826940551499]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 336}], {
             RGBColor[
             0.22591321478921644`, 0.3547794908415487, 0.9361767954223702]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 389}], {
             RGBColor[
             0.22404383278435813`, 0.3528146518287777, 0.9360703368826964]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 409}], {
             RGBColor[
             0.23557177233220394`, 0.3649312472071466, 0.9367268359858879]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 456}], {
             RGBColor[
             0.22662320577002346`, 0.355525736378405, 0.9362172283583896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{295, 458}], {
             RGBColor[
             0.2300435692999762, 0.35912075531195864`, 0.936412013001446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 332}], {
             RGBColor[
             0.3578059368755654, 0.48433525149749035`, 0.9440200557957121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 395}], {
             RGBColor[
             0.289203696626415, 0.4208696734674796, 0.9397969170059906]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 424}], {
             RGBColor[
             0.31700712622472516`, 0.4489973723195799, 0.9414203916580124]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 440}], {
             RGBColor[
             0.29754682970453167`, 0.4296388353177702, 0.94027204609223]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{296, 453}], {
             RGBColor[
             0.2988633264806147, 0.4310225569001501, 0.9403470186360454]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 311}], {
             RGBColor[
             0.6331105387907436, 0.7114259084862791, 0.9653543852266682]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 314}], {
             RGBColor[
             0.42471984107439154`, 0.540499402694099, 0.9487792473402418]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 349}], {
             RGBColor[
             0.4664828396818328, 0.5766724130185215, 0.9514403486819383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 359}], {
             RGBColor[
             0.45240773600559087`, 0.5644812656494411, 0.9505434955218137]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 381}], {
             RGBColor[
             0.5443345056874556, 0.6409542995639315, 0.9572711527321625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 397}], {
             RGBColor[
             0.4389561312944613, 0.5528301617459719, 0.9496863711644075]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{297, 419}], {
             RGBColor[
             0.5160273723962365, 0.6179732935362974, 0.9550427115070317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 353}], {
             RGBColor[
             0.7706511770330843, 0.8213765109750578, 0.9776280646137345]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 418}], {
             RGBColor[
             0.9400566522436402, 0.9539366372768199, 0.955901674523727]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 420}], {
             RGBColor[
             0.9351413217232607, 0.9502707918228358, 0.9642220469712115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{298, 432}], {
             RGBColor[
             0.9001321413614187, 0.9232049523582542, 0.9903366012721426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 300}], {
             RGBColor[
             0.21756201185689822`, 0.346001847062834, 0.9357012067698722]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 301}], {
             RGBColor[
             0.20895952840977988`, 0.3369600915309596, 0.9352113080637927]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 389}], {
             RGBColor[
             0.213833079654714, 0.34208250289038133`, 0.9354888495974187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 451}], {
             RGBColor[
             0.21030609728277713`, 0.3383754207938774, 0.9352879931690398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{299, 456}], {
             RGBColor[
             0.21641245264037934`, 0.34479358744000865`, 0.935635741073112]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 301}], {
             RGBColor[
             0.2173551636481656, 0.3457844364805221, 0.9356894270703895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 389}], {
             RGBColor[
             0.2222287148930997, 0.35090684783994386`, 0.9359669686040155]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 409}], {
             RGBColor[
             0.23375665444094554`, 0.3630234432183127, 0.936623467707207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 451}], {
             RGBColor[
             0.21870173252116284`, 0.3471997657434399, 0.9357661121756364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 456}], {
             RGBColor[
             0.22480808787876505`, 0.3536179323895711, 0.9361138600797088]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{300, 458}], {
             RGBColor[
             0.22822845140871784`, 0.35721295132312475`, 0.9363086447227651]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 389}], {
             RGBColor[
             0.21362623144598136`, 0.3418650923080694, 0.9354770698979359]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 451}], {
             RGBColor[
             0.2100992490740445, 0.3381580102115655, 0.9352762134695569]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{301, 456}], {
             RGBColor[
             0.21620560443164671`, 0.3445761768576967, 0.9356239613736292]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 315}], {
             RGBColor[
             0.18782448730516063`, 0.31474582329100176`, 0.934007698739376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 325}], {
             RGBColor[
             0.18458313935535953`, 0.31133896108243087`, 0.9338231087687794]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 347}], {
             RGBColor[
             0.18453817917078433`, 0.311291705077802, 0.9338205483527805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 368}], {
             RGBColor[
             0.2991255041617159, 0.42254414020486286`, 0.9406824754328269]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 386}], {
             RGBColor[
             0.18453817917078433`, 0.311291705077802, 0.9338205483527805]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 421}], {
             RGBColor[
             0.18460298206136966`, 0.31135981702454774`, 0.9338242387815321]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{302, 477}], {
             RGBColor[
             0.21741049289010705`, 0.3458425910218791, 0.9356925779888657]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 366}], {
             RGBColor[
             0.2851324087513453, 0.4170226184095053, 0.9395492409115669]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 435}], {
             RGBColor[
             0.2816881021628791, 0.4134024338033765, 0.9393530927467486]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{303, 473}], {
             RGBColor[
             0.31604489027716914`, 0.44784149062043943`, 0.9413708849892584]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 310}], {
             RGBColor[
             0.317660558842397, 0.44845488439544834`, 0.9415026138990965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 429}], {
             RGBColor[
             0.316081007071654, 0.4467946753350308, 0.9414126607624902]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{304, 483}], {
             RGBColor[
             0.3176066092257016, 0.44839817992769826`, 0.941499541548237]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 382}], {
             RGBColor[
             0.2666682843502908, 0.39761565297089385`, 0.938497736342151]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 416}], {
             RGBColor[
             0.2563227786802443, 0.3867418705687301, 0.9379085750990459]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 427}], {
             RGBColor[
             0.26530600013852146`, 0.3961838058905166, 0.9384201562716097]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 438}], {
             RGBColor[
             0.23628821482403703`, 0.36568427369114076`, 0.9367676363259161]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 460}], {
             RGBColor[
             0.24972906299601538`, 0.37981145731888477`, 0.9375330727453572]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{305, 499}], {
             RGBColor[
             0.2559152551896322, 0.3863135375416151, 0.9378853672391325]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 317}], {
             RGBColor[
             0.8704899188810679, 0.5035084402927961, 0.2135951122625132]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 357}], {
             RGBColor[
             0.8823608988640697, 0.5565720408834082, 0.22345710970379568`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 418}], {
             RGBColor[
             0.9180265023958543, 0.7135265493813059, 0.5620472292012149]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{306, 420}], {
             RGBColor[
             0.9131111718754747, 0.7098607039273219, 0.5703676016486996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 372}], {
             RGBColor[
             0.47013131999468205`, 0.580712810603117, 0.9514296061392018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{307, 417}], {
             RGBColor[
             0.5854211152910297, 0.6734114544902967, 0.9611201594979415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 386}], {
             RGBColor[
             0.17893664238380538`, 0.3054041347567419, 0.9335015491194931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 421}], {
             RGBColor[
             0.1790014452743907, 0.3054722467034876, 0.9335052395482446]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 422}], {
             RGBColor[
             0.20647914454706495`, 0.3343530508258261, 0.9350700538722102]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 423}], {
             RGBColor[
             0.1833860881198116, 0.31008078433643804`, 0.9337549384717936]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{308, 446}], {
             RGBColor[
             0.2035487790418117, 0.3312730508839008, 0.9349031738917732]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 320}], {
             RGBColor[
             0.9908166313021023, 0.9885283450055495, 0.6606847997028811]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 337}], {
             RGBColor[
             0.926620732552479, 0.9394372573300418, 0.7346744089406012]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 348}], {
             RGBColor[
             0.976471187338104, 0.9319682118150352, 0.39079228120582354`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 375}], {
             RGBColor[
             0.9756161016685031, 0.977924558793291, 0.7192291003603996]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{309, 489}], {
             RGBColor[
             0.9915641796444485, 0.9888374754562259, 0.6482959890771074]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 327}], {
             RGBColor[
             0.2769131154519483, 0.40838362001854456`, 0.939081164317521]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 399}], {
             RGBColor[
             0.26912901254486776`, 0.40020203432257306`, 0.938637871172511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 412}], {
             RGBColor[
             0.26956927876194814`, 0.4006647820312149, 0.9386629436822582]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 429}], {
             RGBColor[
             0.2951775190785565, 0.4275806662601843, 0.9401212950842925]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{310, 483}], {
             RGBColor[
             0.2967031212326041, 0.4291841708528518, 0.9402081758700394]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 319}], {
             RGBColor[
             0.7308732764235066, 0.7896830254754603, 0.9738102758609529]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 331}], {
             RGBColor[
             0.7917742816822333, 0.837394395727864, 0.9798444828971542]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 349}], {
             RGBColor[
             0.5802291691633081, 0.667416033439714, 0.9614893343765445]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 377}], {
             RGBColor[
             0.8639809895032101, 0.8937991659736781, 0.9461358346293043]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 419}], {
             RGBColor[
             0.6297737018777119, 0.70871691395749, 0.9650916972016379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 484}], {
             RGBColor[
             0.8698742834500395, 0.8946869579845022, 0.7215434088969761]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{311, 488}], {
             RGBColor[
             0.7581105843852092, 0.8109610174663499, 0.9765250361714609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 354}], {
             RGBColor[
             0.3330876906173925, 0.4625247982993003, 0.942459704446583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 376}], {
             RGBColor[
             0.2919333190231436, 0.4241708063077816, 0.9399365426905006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 400}], {
             RGBColor[
             0.30016668312241634`, 0.43282459400155193`, 0.9404054205957836]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 414}], {
             RGBColor[
             0.2895347527456831, 0.421649761072285, 0.9397999478893602]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{312, 415}], {
             RGBColor[
             0.29571211190112656`, 0.42814255721184813`, 0.9401517393546788]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 379}], {
             RGBColor[
             0.288128547073246, 0.4201206026991259, 0.9397217393007642]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 380}], {
             RGBColor[
             0.26990447818225494`, 0.4010170978748282, 0.9386820327933616]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 390}], {
             RGBColor[
             0.28385568108857195`, 0.41568069668672125`, 0.9394765331599213]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 411}], {
             RGBColor[
             0.2532739296678089, 0.38353733694846814`, 0.9377349476581557]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{313, 478}], {
             RGBColor[
             0.26649991887633445`, 0.3974386901827782, 0.9384881481774836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 359}], {
             RGBColor[
             0.3577633677707141, 0.48429838027845357`, 0.9440173433299934]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 373}], {
             RGBColor[
             0.3118454823562334, 0.44312769697598026`, 0.9411427175470836]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 397}], {
             RGBColor[
             0.34431176305958455`, 0.4726472763749843, 0.9431602189725873]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 398}], {
             RGBColor[
             0.29561326424229706`, 0.426066606556162, 0.9402183167389095]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{314, 472}], {
             RGBColor[
             0.3292610947634469, 0.4596111439654538, 0.9422012036975409]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 325}], {
             RGBColor[
             0.1822582683189515, 0.30889537421782864`, 0.9336907108025945]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 347}], {
             RGBColor[
             0.1822133081343763, 0.30884811821319974`, 0.9336881503865955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 368}], {
             RGBColor[
             0.2968006331253079, 0.42010055334026064`, 0.9405500774666419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 386}], {
             RGBColor[
             0.1822133081343763, 0.30884811821319974`, 0.9336881503865955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{315, 401}], {
             RGBColor[
             0.47947599697395743`, 0.5676241897079666, 0.9559647317614918]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{316, 378}], {
             RGBColor[
             0.26678973270236006`, 0.397743302889189, 0.9385046526461347]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 357}], {
             RGBColor[
             0.895271303645258, 0.6164935275347583, 0.23428070819651722`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 418}], {
             RGBColor[
             0.9309369071770426, 0.7734480360326559, 0.5728708276939365]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{317, 420}], {
             RGBColor[
             0.9260215766566631, 0.7697821905786719, 0.5811912001414211]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 321}], {
             RGBColor[
             0.33755888801482614`, 0.46679827542058316`, 0.9427299317460682]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 330}], {
             RGBColor[
             0.32419593809646025`, 0.45501163764918373`, 0.9418862305492528]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 335}], {
             RGBColor[
             0.3093572475376726, 0.43941523304457686`, 0.9410411890738053]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 350}], {
             RGBColor[
             0.3520561578815369, 0.47935508192515797`, 0.9436536849625428]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 354}], {
             RGBColor[
             0.35185308329442466`, 0.47917918892462685`, 0.9436407452294238]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 383}], {
             RGBColor[
             0.3354424216880899, 0.46496509866505487`, 0.9425950723832464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 479}], {
             RGBColor[
             0.3767164983407358, 0.5007146293661655, 0.94522502005032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 482}], {
             RGBColor[
             0.35021188070592757`, 0.4777576617317112, 0.9435361692517431]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{318, 496}], {
             RGBColor[
             0.3094159330482752, 0.43947691523709653`, 0.9410445311268166]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 331}], {
             RGBColor[
             0.775790689833521, 0.8249078922958527, 0.9782513878368327]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 377}], {
             RGBColor[
             0.8479973976544979, 0.8813126625416667, 0.9445427395689829]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 449}], {
             RGBColor[
             0.7215962304048408, 0.7824357266175173, 0.9728856266127364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{319, 488}], {
             RGBColor[
             0.7421269925364968, 0.7984745140343386, 0.9749319411111395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 337}], {
             RGBColor[
             0.9244065988908812, 0.9404637664434601, 0.9125392493325524]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 348}], {
             RGBColor[
             0.9742570536765062, 0.9329947209284535, 0.5686571215977747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 361}], {
             RGBColor[
             0.8164019725999951, 0.8557645940777792, 0.9018606390244552]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{320, 375}], {
             RGBColor[
             0.9734019680069053, 0.9789510679067093, 0.8970939407523506]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 335}], {
             RGBColor[
             0.3049738126003747, 0.4356185220197354, 0.94076188047572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 383}], {
             RGBColor[
             0.3310589867507921, 0.46116838764021345`, 0.942315763785161]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 479}], {
             RGBColor[
             0.37233306340343797`, 0.49691791834132404`, 0.9449457114522347]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 482}], {
             RGBColor[
             0.3458284457686297, 0.47396095070686983`, 0.9432568606536578]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{321, 496}], {
             RGBColor[
             0.3050324981109774, 0.4356802042122551, 0.9407652225287313]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{322, 494}], {
             RGBColor[
             0.2588610411681461, 0.3894097453786518, 0.9380531253927091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 342}], {
             RGBColor[
             0.2496659047127254, 0.3797450739586806, 0.9375294759745583]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 395}], {
             RGBColor[
             0.25216611947306267`, 0.3823729581945666, 0.9376718595064233]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 447}], {
             RGBColor[
             0.24292230663621342`, 0.3726571248114532, 0.9371454380403603]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 452}], {
             RGBColor[
             0.23164904535488023`, 0.3608082124387239, 0.9365034424876839]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{323, 463}], {
             RGBColor[
             0.25322101360276406`, 0.3834817188090337, 0.9377319341665338]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 441}], {
             RGBColor[
             0.4099049258998564, 0.5294607772190044, 0.947339757307013]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{324, 481}], {
             RGBColor[
             0.3439470735768655, 0.47233140067487944`, 0.9431369812812307]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 347}], {
             RGBColor[
             0.1789719601845752, 0.3054412560046289, 0.9335035604159989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 368}], {
             RGBColor[
             0.2935592851755068, 0.41669369113168975`, 0.9403654874960453]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 386}], {
             RGBColor[
             0.1789719601845752, 0.3054412560046289, 0.9335035604159989]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 401}], {
             RGBColor[
             0.4762346490241563, 0.5642173274993956, 0.9557801417908952]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{325, 421}], {
             RGBColor[
             0.17903676307516053`, 0.3055093679513746, 0.9335072508447505]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 405}], {
             RGBColor[
             0.9345940973525277, 0.7578425175728066, 0.403625723074449]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 428}], {
             RGBColor[
             0.8527545036662538, 0.3801225472055363, 0.19711821090416948`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 434}], {
             RGBColor[
             0.9331890448533395, 0.7583565146768234, 0.5065076494810187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 469}], {
             RGBColor[
             0.8678030946468546, 0.4926065528105953, 0.21140400054171546`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 474}], {
             RGBColor[
             0.9341363327937491, 0.7587482425843726, 0.49080863680582576`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 475}], {
             RGBColor[
             0.8570894511774583, 0.4134428533627656, 0.20126936153652183`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 491}], {
             RGBColor[
             0.9346684716417725, 0.7580015966571071, 0.4117209054738351]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{326, 495}], {
             RGBColor[
             0.8586889913459645, 0.42573762002087545`, 0.2028010830083056]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 399}], {
             RGBColor[
             0.24928505714751653`, 0.3793447790205158, 0.9375077872691331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 412}], {
             RGBColor[
             0.2497253233645969, 0.37980752672915763`, 0.9375328597788803]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{327, 483}], {
             RGBColor[
             0.27685916583525294`, 0.4083269155507945, 0.9390780919666615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 431}], {
             RGBColor[
             0.4169264678183623, 0.535542483915856, 0.9477871637491544]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 433}], {
             RGBColor[
             0.35540962848104596`, 0.48225968960811955`, 0.9438673651437858]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 436}], {
             RGBColor[
             0.42911640965865483`, 0.5455685636524759, 0.9487109542359491]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 462}], {
             RGBColor[
             0.4245956854340748, 0.5418984360706564, 0.9483550662650316]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{328, 487}], {
             RGBColor[
             0.4823721914903405, 0.5888040064890694, 0.952903444464096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 406}], {
             RGBColor[
             0.9365881325497546, 0.9446037269852596, 0.7033574817962612]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 413}], {
             RGBColor[
             0.9281969547806851, 0.9162983140279535, 0.6707593407043844]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{329, 486}], {
             RGBColor[
             0.9087427412464592, 0.930070810978078, 0.9911578879759511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 350}], {
             RGBColor[
             0.33430977302587317`, 0.4637717331289171, 0.9425306751676419]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 354}], {
             RGBColor[
             0.3341066984387609, 0.463595840128386, 0.9425177354345229]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 414}], {
             RGBColor[
             0.2905537605670515, 0.4227208029013707, 0.9398579788773]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 415}], {
             RGBColor[
             0.29673111972249494`, 0.4292135990409338, 0.9402097703426187]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 482}], {
             RGBColor[
             0.33246549585026375`, 0.4621743129354704, 0.9424131594568423]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{330, 496}], {
             RGBColor[
             0.2916695481926115, 0.42389356644085574`, 0.9399215213319159]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 377}], {
             RGBColor[
             0.9088984029132244, 0.9290240327940705, 0.9505769466051841]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 403}], {
             RGBColor[
             0.8828018353475209, 0.9093862367613971, 0.9886836212135901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 449}], {
             RGBColor[
             0.7824972356635673, 0.8301470968699212, 0.9789198336489376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{331, 488}], {
             RGBColor[
             0.8030279977952235, 0.8461858842867422, 0.9809661481473407]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 344}], {
             RGBColor[
             0.4329675168621825, 0.5491533716913533, 0.9488874962659426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 393}], {
             RGBColor[
             0.4317017689879543, 0.548125780545763, 0.9487878519566961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{332, 424}], {
             RGBColor[
             0.36139324266635137`, 0.48744239547023754`, 0.9442486357485711]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 392}], {
             RGBColor[
             0.34232526370384136`, 0.4706729127563853, 0.943042932303461]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 442}], {
             RGBColor[
             0.331297230301234, 0.4590817504325423, 0.942414902115696]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 459}], {
             RGBColor[
             0.3845976264069504, 0.5075408663801063, 0.9457271985616913]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{333, 492}], {
             RGBColor[
             0.32763422405457243`, 0.45523169861929097`, 0.9422062993288807]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 340}], {
             RGBColor[
             0.37011932022613914`, 0.4950004852671151, 0.9448046536945134]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 355}], {
             RGBColor[
             0.36575544066311605`, 0.49122071212458884`, 0.9445265911475849]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 361}], {
             RGBColor[
             0.5235027630627838, 0.6226423570970218, 0.9560294677740079]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 363}], {
             RGBColor[
             0.40380771802618465`, 0.5241796822134083, 0.9469512486128518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 369}], {
             RGBColor[
             0.4113757512055576, 0.5307347321729735, 0.9474334769948924]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 370}], {
             RGBColor[
             0.49712370807879736`, 0.6012548758448955, 0.9539335150694623]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 379}], {
             RGBColor[
             0.3560516389210633, 0.4828157667828796, 0.9439082734813162]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{334, 498}], {
             RGBColor[
             0.4323467950368561, 0.5486660596707702, 0.9488340391891498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 383}], {
             RGBColor[
             0.3028573462736385, 0.4337853452642071, 0.940627021112898]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 409}], {
             RGBColor[
             0.25916391695491414`, 0.389728087033979, 0.938070373720701]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 482}], {
             RGBColor[
             0.3176268052914761, 0.44657790833086347`, 0.9415681179813948]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{335, 496}], {
             RGBColor[
             0.27683085763382376`, 0.40829716183624876`, 0.9390764798564684]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 409}], {
             RGBColor[
             0.23189710424361965`, 0.36106893805863094`, 0.9365175690744273]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 456}], {
             RGBColor[
             0.22294853768143919`, 0.3516634272298894, 0.936007961446929]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{336, 458}], {
             RGBColor[
             0.22636890121139194`, 0.35525844616344304`, 0.9362027460899854]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 348}], {
             RGBColor[
             0.9100611549268829, 0.8839036332529456, 0.6426467308354947]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 361}], {
             RGBColor[
             0.752206073850372, 0.8066735064022713, 0.9758502482621753]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 370}], {
             RGBColor[
             0.7258270188663856, 0.785286025150145, 0.9737542955576297]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 375}], {
             RGBColor[
             0.9092060692572821, 0.9298599802312014, 0.9710835499900707]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{337, 498}], {
             RGBColor[
             0.6610501058244442, 0.7326972089760198, 0.9686548196773171]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 369}], {
             RGBColor[
             0.37002637582951403`, 0.49491998150227967`, 0.9447987313597479]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 379}], {
             RGBColor[
             0.31470226354501973`, 0.4470010161121858, 0.9412735278461717]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 390}], {
             RGBColor[
             0.3104293975603457, 0.44256111009978116`, 0.9410283217053288]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 425}], {
             RGBColor[
             0.3477240886796976, 0.47560286131865376`, 0.9433776493436998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{338, 478}], {
             RGBColor[
             0.29307363534810826`, 0.42431910359583813`, 0.9400399367228911]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{339, 365}], {
             RGBColor[
             0.2143326753092825, 0.34260760959952685`, 0.9355173008308608]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 355}], {
             RGBColor[
             0.3330706823231735, 0.4629108172342508, 0.9424439472481606]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 362}], {
             RGBColor[
             0.3629480512357022, 0.4887890925060583, 0.944347706775747]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 363}], {
             RGBColor[
             0.37112295968624204`, 0.49586978732307024`, 0.9448686047134276]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 378}], {
             RGBColor[
             0.31025949401998754`, 0.4407803246133216, 0.9410773105637218]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 379}], {
             RGBColor[
             0.32336688058112073`, 0.45450587189254155`, 0.941825629581892]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 380}], {
             RGBColor[
             0.3051428116901297, 0.43540236706824387`, 0.9407859230744895]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{340, 498}], {
             RGBColor[
             0.39966203669691347`, 0.5203561647804322, 0.9467513952897255]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 387}], {
             RGBColor[
             0.8843435887930974, 0.9064532397024012, 0.7600495256450741]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 403}], {
             RGBColor[
             0.9612426733705868, 0.9674078133042042, 0.7674804702008887]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 405}], {
             RGBColor[
             0.9937930272646951, 0.989132237877419, 0.5657875066366207]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 450}], {
             RGBColor[
             0.9056409272943111, 0.562891578052587, 0.35323513131972123`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 469}], {
             RGBColor[
             0.927002024559022, 0.7238962731152077, 0.3735657841038871]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{341, 491}], {
             RGBColor[
             0.9938674015539399, 0.9892913169617195, 0.5738826890360067]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 395}], {
             RGBColor[
             0.2624873580585535, 0.3932212343522405, 0.9382596387749628]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 447}], {
             RGBColor[
             0.2532435452217043, 0.38350540096912705`, 0.9377332173088998]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 453}], {
             RGBColor[
             0.27214698791275327`, 0.40337411778491095`, 0.9388097404050177]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{342, 463}], {
             RGBColor[
             0.2635422521882549, 0.3943299949667075, 0.9383197134350733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 392}], {
             RGBColor[
             0.29944445035868683`, 0.4320654815746701, 0.9403642905083368]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 433}], {
             RGBColor[
             0.3091968798489231, 0.4407663035487692, 0.9409764153784905]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{343, 465}], {
             RGBColor[
             0.2877565452274621, 0.4197807522257663, 0.9396986816018197]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 387}], {
             RGBColor[
             0.6194283934274943, 0.6998852662527452, 0.9645732255440658]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{344, 424}], {
             RGBColor[
             0.39216870621134226`, 0.5138154925134429, 0.9462878321282429]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 375}], {
             RGBColor[
             0.8089633164388916, 0.8512244424146573, 0.9611785706908804]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 426}], {
             RGBColor[
             0.7649497936964772, 0.8167095300211071, 0.9770990522255436]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 448}], {
             RGBColor[
             0.6138322543981429, 0.6971096748541594, 0.9629241548523259]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 489}], {
             RGBColor[
             0.8249113944148371, 0.8621373590775923, 0.8902454594075883]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{345, 498}], {
             RGBColor[
             0.5608073530060538, 0.6540616711594758, 0.9587498403781267]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 358}], {
             RGBColor[
             0.2217544347167852, 0.3504083493035373, 0.935939959049609]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 404}], {
             RGBColor[
             0.21566548218765702`, 0.3440084741335353, 0.9355932022108733]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 407}], {
             RGBColor[
             0.2161204994130187, 0.34448672608714886`, 0.9356191147687198]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 408}], {
             RGBColor[
             0.22019359510263653`, 0.34876780790611966`, 0.9358510715426385]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{346, 430}], {
             RGBColor[
             0.22881084125106885`, 0.35782507997308444`, 0.9363418109627185]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 368}], {
             RGBColor[
             0.2935143249909316, 0.4166464351270609, 0.9403629270800464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 386}], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 421}], {
             RGBColor[
             0.17899180289058533`, 0.3054621119467458, 0.9335046904287516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{347, 477}], {
             RGBColor[
             0.2117993137193227, 0.3399448859440771, 0.9353730296360853]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 375}], {
             RGBColor[
             0.959056524042907, 0.9223909347161948, 0.6272014222552931]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{348, 428}], {
             RGBColor[
             0.8951225528654855, 0.5552983535621828, 0.23772264959288408`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 359}], {
             RGBColor[
             0.3995263663781553, 0.520471390602876, 0.94667844467169]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 371}], {
             RGBColor[
             0.3882726943942144, 0.5107240255563866, 0.9459613706441047]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 397}], {
             RGBColor[
             0.38607476166702576`, 0.5088202866994067, 0.9458213203142838]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{349, 419}], {
             RGBColor[
             0.4631460027688009, 0.5739634184897324, 0.951177660656908]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 354}], {
             RGBColor[
             0.36196691822383753`, 0.4879392844043602, 0.9442851898478128]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 383}], {
             RGBColor[
             0.34555625661750283`, 0.4737251941447882, 0.9432395170016354]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 414}], {
             RGBColor[
             0.31841398035212815`, 0.44706424717734483`, 0.94162543329059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 479}], {
             RGBColor[
             0.3868303332701487, 0.5094747248458988, 0.9458694646687091]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{350, 482}], {
             RGBColor[
             0.36032571563534044`, 0.4865177572114446, 0.9441806138701323]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 356}], {
             RGBColor[
             0.2796916905937343, 0.4113040786644009, 0.9392394000613121]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{351, 463}], {
             RGBColor[
             0.27857140569147526`, 0.4101265882019613, 0.9391756014934415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 367}], {
             RGBColor[
             0.2288379775147259, 0.35785360190672644`, 0.9363433563327893]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 399}], {
             RGBColor[
             0.23466592421327268`, 0.3639791434000619, 0.936675249275597]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 412}], {
             RGBColor[
             0.23510619043035305`, 0.36444189110870373`, 0.9367003217853442]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{352, 457}], {
             RGBColor[
             0.22470998276050042`, 0.3535148176900512, 0.9361082731383572]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 418}], {
             RGBColor[
             0.809068015481273, 0.8509060188194038, 0.9430493347226458]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 420}], {
             RGBColor[
             0.8041526849608935, 0.8472401733654197, 0.9513697071701304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 432}], {
             RGBColor[
             0.7691435045990516, 0.820174333900838, 0.9774842614710615]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{353, 441}], {
             RGBColor[
             0.5448974710637005, 0.6413248437593597, 0.9573393706579376]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 372}], {
             RGBColor[
             0.416108457877265, 0.5343687074376324, 0.9478635928798225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 414}], {
             RGBColor[
             0.3182109057650159, 0.4468883541768137, 0.941612493557471]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 415}], {
             RGBColor[
             0.32438826492045936`, 0.4533811503163769, 0.9419642850227896]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 479}], {
             RGBColor[
             0.38662725868303643`, 0.5092988318453677, 0.9458565249355901]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{354, 482}], {
             RGBColor[
             0.3601226410482282, 0.48634186421091347`, 0.9441676741370133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 362}], {
             RGBColor[
             0.3585841716726791, 0.48500931936353203`, 0.9440696442288183]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 363}], {
             RGBColor[
             0.366759080123219, 0.492090014180544, 0.9445905421664991]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 378}], {
             RGBColor[
             0.30589561445696456`, 0.4370005514707954, 0.940799248016793]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 384}], {
             RGBColor[
             0.3062638013444511, 0.43738753923394075`, 0.9408202157153518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{355, 498}], {
             RGBColor[
             0.3952981571338905, 0.516576391637906, 0.946473332742797]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{356, 463}], {
             RGBColor[
             0.26821764598055253`, 0.3992441302795001, 0.9385859701949193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 418}], {
             RGBColor[
             0.9428078871600445, 0.8265116366232681, 0.582732825135219]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{357, 420}], {
             RGBColor[
             0.937892556639665, 0.822845791169284, 0.5910531975827036]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 404}], {
             RGBColor[
             0.21953726017780179`, 0.34807795828608057`, 0.9358136942396298]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 407}], {
             RGBColor[
             0.21999227740316346`, 0.34855621023969413`, 0.9358396067974764]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 408}], {
             RGBColor[
             0.2240653730927813, 0.35283729205866493`, 0.936071563571395]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{358, 430}], {
             RGBColor[
             0.23268261924121364`, 0.3618945641256297, 0.936562302991475]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 371}], {
             RGBColor[
             0.37419759071797254`, 0.49853287818730624`, 0.94506451748398]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 397}], {
             RGBColor[
             0.3719996579907838, 0.4966291393303264, 0.9449244671541592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 419}], {
             RGBColor[
             0.44907089909255904`, 0.561772271120652, 0.9502808074967835]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{359, 427}], {
             RGBColor[
             0.3324756951564906, 0.4596914885288097, 0.9425050411722034]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 393}], {
             RGBColor[
             0.5202889035975207, 0.6214329965452928, 0.9553781948537]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 466}], {
             RGBColor[
             0.5414372478398441, 0.638602175123262, 0.9570430699813932]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{360, 468}], {
             RGBColor[
             0.5288716731016017, 0.6284008754780657, 0.9560538619087819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 363}], {
             RGBColor[
             0.5245064025228867, 0.6235116591529769, 0.9560934187929221]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 370}], {
             RGBColor[
             0.6178223925754994, 0.7005868527844641, 0.9630756852495326]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{361, 498}], {
             RGBColor[
             0.5530454795335582, 0.6479980366103388, 0.95797620936922]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 363}], {
             RGBColor[
             0.3966364490357477, 0.5179682894523514, 0.9464943016940854]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 384}], {
             RGBColor[
             0.33614117025697976`, 0.4632658145057482, 0.9427239752429382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{362, 498}], {
             RGBColor[
             0.4251755260464191, 0.5424546669097134, 0.9483770922703834]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 370}], {
             RGBColor[
             0.4981273475389003, 0.6021241779008506, 0.9539974660883765]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 379}], {
             RGBColor[
             0.35705527838116624`, 0.4836850688388347, 0.9439722245002304]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{363, 498}], {
             RGBColor[
             0.433350434496959, 0.5495353617267253, 0.948897990208064]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 374}], {
             RGBColor[
             0.2551484985501697, 0.3855076276983612, 0.93784170158283]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{364, 437}], {
             RGBColor[
             0.25719856867599794`, 0.38766238138256004`, 0.9379584500436889]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 435}], {
             RGBColor[
             0.2615619901606841, 0.3922486140198663, 0.9382069404421383]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{366, 473}], {
             RGBColor[
             0.29591877827497415`, 0.42668767083692927`, 0.940224732684648]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 416}], {
             RGBColor[
             0.24568937276892794`, 0.3755654867590621, 0.9373030183631108]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 457}], {
             RGBColor[
             0.22571706608911693`, 0.3545733261211982, 0.9361656250440755]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{367, 499}], {
             RGBColor[
             0.24528184927831587`, 0.3751371537319471, 0.9372798105031974]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 386}], {
             RGBColor[
             0.2935143249909316, 0.4166464351270609, 0.9403629270800464]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 401}], {
             RGBColor[
             0.5907770138305127, 0.6754225066218276, 0.9626395084549426]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{368, 500}], {
             RGBColor[
             0.6137971561371982, 0.33936679556971105`, 0.5567621778131115]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 370}], {
             RGBColor[
             0.5056953807182732, 0.6086792278604158, 0.9544796944704173]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 379}], {
             RGBColor[
             0.3646233115605392, 0.49024011879839996`, 0.944454452882271]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 390}], {
             RGBColor[
             0.36035044557586515`, 0.48580021278599533`, 0.9442092467414281]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 425}], {
             RGBColor[
             0.397645136695217, 0.5188419640048679, 0.9465585743797993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{369, 466}], {
             RGBColor[
             0.46172779849419876`, 0.5729843638939052, 0.9510184053391775]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{370, 466}], {
             RGBColor[
             0.5474757553674385, 0.6435045075658272, 0.9575184434137474]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 382}], {
             RGBColor[
             0.322584307384319, 0.45137597056269757`, 0.9418655472151594]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 419}], {
             RGBColor[
             0.43781722710861815`, 0.5520249060741627, 0.9495637334691982]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 427}], {
             RGBColor[
             0.3212220231725497, 0.4499441234823203, 0.9417879671446181]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{371, 429}], {
             RGBColor[
             0.3282709430209225, 0.4573529851702918, 0.9421893927020404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{372, 417}], {
             RGBColor[
             0.5857428674141524, 0.6736726673586156, 0.9611454890036907]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 398}], {
             RGBColor[
             0.27738327375901567`, 0.40887778620903076`, 0.9391079391375716]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{373, 472}], {
             RGBColor[
             0.31103110428016545`, 0.44242232361832246`, 0.9410908260962028]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 391}], {
             RGBColor[
             0.24642877472957408`, 0.3763426451004932, 0.9373451262109225]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{374, 437}], {
             RGBColor[
             0.25378039219455883`, 0.3840696611756612, 0.9377637899498099]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 426}], {
             RGBColor[
             0.9141879156308917, 0.9338323693009003, 0.9715587229445324]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{375, 489}], {
             RGBColor[
             0.9741495163492516, 0.9792601983573855, 0.8847051301265769]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 400}], {
             RGBColor[
             0.2876884645475003, 0.41970919511456195`, 0.9396948045078122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 414}], {
             RGBColor[
             0.27705653417076703`, 0.40853436218529504`, 0.9390893318013886]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 415}], {
             RGBColor[
             0.28323389332621046`, 0.41502715832485815`, 0.9394411232667073]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 464}], {
             RGBColor[
             0.2616609318454717, 0.3923526080038432, 0.9382125750247157]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 485}], {
             RGBColor[
             0.26372814560153673`, 0.3945253807303899, 0.938330299789955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{376, 497}], {
             RGBColor[
             0.25772437162935435`, 0.38821503362437043`, 0.9379883937440268]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 403}], {
             RGBColor[
             0.9550085431684978, 0.9657910070072111, 0.9549749729457403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 449}], {
             RGBColor[
             0.8547039434845443, 0.8865518671157351, 0.9452111853810878]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 484}], {
             RGBColor[
             0.9869984046810305, 0.9863165950507087, 0.692275872605006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{377, 488}], {
             RGBColor[
             0.8752347056162003, 0.9025906545325564, 0.9472574998794909]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{378, 380}], {
             RGBColor[
             0.27796774382392075`, 0.40949210130478847`, 0.939141223843122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 380}], {
             RGBColor[
             0.29107513038505384`, 0.42321764858400834`, 0.9398895428612922]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 390}], {
             RGBColor[
             0.30502633329137085`, 0.4378812473959014, 0.9406840432278518]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{379, 478}], {
             RGBColor[
             0.2876705710791334, 0.41963924089195836`, 0.9396956582454141]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 390}], {
             RGBColor[
             0.2868022644003798, 0.4187777425716037, 0.9396443367204493]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 411}], {
             RGBColor[
             0.2562205129796168, 0.38663438283335066`, 0.9379027512186837]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{380, 478}], {
             RGBColor[
             0.26944650218814237`, 0.40053573606766074`, 0.9386559517380118]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 419}], {
             RGBColor[
             0.5409976687744238, 0.6382453050351424, 0.9570084647071322]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{381, 439}], {
             RGBColor[
             0.7151086431122187, 0.7765792866784462, 0.9729163506443089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 416}], {
             RGBColor[
             0.2718791903645599, 0.40309264558241453`, 0.938794489730819]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 427}], {
             RGBColor[
             0.2808624118228371, 0.41253458090420103`, 0.9393060709033827]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 429}], {
             RGBColor[
             0.2879113316712099, 0.41994344259217253`, 0.9397074964608051]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{382, 499}], {
             RGBColor[
             0.27147166687394786`, 0.40266431255529955`, 0.9387712818709056]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 479}], {
             RGBColor[
             0.37021659707670174`, 0.49508474158579574`, 0.9448108520894127]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 482}], {
             RGBColor[
             0.34371197944189347`, 0.47212777395134153`, 0.9431220012908359]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{383, 496}], {
             RGBColor[
             0.30291603178424115`, 0.4338470274567268, 0.9406303631659094]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{384, 435}], {
             RGBColor[
             0.2709692417504848, 0.4021362318949472, 0.9387426695033958]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{385, 391}], {
             RGBColor[
             0.23729940724147955`, 0.36674710103517516`, 0.9368252222381643]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{386, 421}], {
             RGBColor[
             0.17899180289058533`, 0.3054621119467458, 0.9335046904287516]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 403}], {
             RGBColor[
             0.8520128910253049, 0.8851986373727346, 0.9856507029983317]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 405}], {
             RGBColor[
             0.8845632449194131, 0.9069230619459494, 0.7839577394340637]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{387, 491}], {
             RGBColor[
             0.8846376192086578, 0.9070821410302499, 0.7920529218334498]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 487}], {
             RGBColor[
             0.7628017392959624, 0.8144116714200249, 0.9680174393113103]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{388, 490}], {
             RGBColor[
             0.9683628300119925, 0.9748687448836537, 0.8911081388957877]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 409}], {
             RGBColor[
             0.23002772223876133`, 0.35910409904586005`, 0.9364111105347535]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 451}], {
             RGBColor[
             0.21497280031897864`, 0.34328042157098726`, 0.9355537550031829]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 456}], {
             RGBColor[
             0.22107915567658082`, 0.3496985882171184, 0.9359015029072553]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{389, 458}], {
             RGBColor[
             0.2244995192065336, 0.35329360715067204`, 0.9360962875503116]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 425}], {
             RGBColor[
             0.3380481584260487, 0.4664830926023694, 0.94278816472538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{390, 478}], {
             RGBColor[
             0.2833977050944594, 0.41519933487955374`, 0.9394504521045712]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 459}], {
             RGBColor[
             0.34827375514967984`, 0.47582519706689724`, 0.9434219649183455]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 465}], {
             RGBColor[
             0.2943134873153461, 0.42667251409427237`, 0.9400720897535981]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{392, 492}], {
             RGBColor[
             0.2913103527973019, 0.4235160293060819, 0.9399010656855349]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{393, 468}], {
             RGBColor[
             0.4697942541627981, 0.5804391653761509, 0.9514030710822032]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 398}], {
             RGBColor[
             0.24489676758341208`, 0.3747324084550136, 0.93725788067035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 445}], {
             RGBColor[
             0.2291408986849781, 0.35817199126297306`, 0.9363606072453035]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{394, 460}], {
             RGBColor[
             0.23849436642390026`, 0.3680030789006874, 0.9368932733958195]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 440}], {
             RGBColor[
             0.2733307058970075, 0.4046182804384171, 0.9388771513930672]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 447}], {
             RGBColor[
             0.2557437599820415, 0.3861332852050131, 0.9378756008407647]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 453}], {
             RGBColor[
             0.2746472026730905, 0.406002002020797, 0.9389521239368825]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{395, 463}], {
             RGBColor[
             0.2660424669485921, 0.39695787920259357`, 0.9384620969669382]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 422}], {
             RGBColor[
             0.6137790328303492, 0.6759479174311498, 0.7377723993512193]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 443}], {
             RGBColor[
             0.9640290207521414, 0.8833364286136021, 0.40253589756085995`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{396, 446}], {
             RGBColor[
             0.6108486673250959, 0.6728679174892245, 0.7376055193707824]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 419}], {
             RGBColor[
             0.43561929438142943`, 0.5501211672171827, 0.9494236831393772]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{397, 472}], {
             RGBColor[
             0.3434973849835166, 0.4719419030173265, 0.9431083275217065]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 445}], {
             RGBColor[
             0.2453951867466454, 0.3752562785971719, 0.9372862649043511]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 460}], {
             RGBColor[
             0.2547486544855675, 0.3850873662348864, 0.9378189310548671]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{398, 472}], {
             RGBColor[
             0.2947988861662292, 0.4253612331985043, 0.9401664252880289]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{399, 412}], {
             RGBColor[
             0.24194122045751632`, 0.37162594103318614`, 0.9370895666338703]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 414}], {
             RGBColor[
             0.28528989827003975`, 0.41718814987906533`, 0.9395582097066717]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 415}], {
             RGBColor[
             0.2914672574254832, 0.4236809460186285, 0.9399100011719903]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{400, 464}], {
             RGBColor[
             0.26989429594474446`, 0.40100639569761354`, 0.9386814529299987]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 450}], {
             RGBColor[
             0.7955804305647025, 0.4800334417304184, 0.5713225662708019]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 454}], {
             RGBColor[
             0.8366674019364873, 0.7306087240183134, 0.6081129719353302]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 471}], {
             RGBColor[
             0.8151324803555211, 0.6303190641854999, 0.5900456312313715]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 475}], {
             RGBColor[
             0.806227884360017, 0.5618744373452094, 0.5815185800497742]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{401, 500}], {
             RGBColor[
             0.7964725199858478, 0.48689043193741693`, 0.5721768321079614]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 431}], {
             RGBColor[
             0.5004255816893457, 0.6051773211877334, 0.9538503277794443]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 436}], {
             RGBColor[
             0.5126155235296384, 0.6152034009243532, 0.954774118266239]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 459}], {
             RGBColor[
             0.4714286755649022, 0.5800616585296188, 0.952002670562152]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 462}], {
             RGBColor[
             0.5080947993050582, 0.6115332733425336, 0.9544182302953215]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{402, 487}], {
             RGBColor[
             0.565871305361324, 0.6584388437609466, 0.958966608494386]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 405}], {
             RGBColor[
             0.9614623294969025, 0.9678776355477525, 0.7913886839898783]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 449}], {
             RGBColor[
             0.8286073759188407, 0.8669140710830616, 0.9833178599894938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{403, 491}], {
             RGBColor[
             0.9615367037861473, 0.968036714632053, 0.7994838663892643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 407}], {
             RGBColor[
             0.2139033248740353, 0.3421563350696921, 0.9354928499587406]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{404, 408}], {
             RGBColor[
             0.2179764205636531, 0.3464374168886629, 0.9357248067326592]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 434}], {
             RGBColor[
             0.9926076308918226, 0.9901160572249841, 0.6925776468321798]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 469}], {
             RGBColor[
             0.9272216806853377, 0.724366095358756, 0.3974739978928766]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 474}], {
             RGBColor[
             0.9935549188322322, 0.9905077851325332, 0.6768786341569868]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{405, 491}], {
             RGBColor[
             0.9940870576802556, 0.9897611392052678, 0.5977909028249961]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 413}], {
             RGBColor[
             0.9822272031257195, 0.951710324271208, 0.3854564695648335]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 476}], {
             RGBColor[
             0.9195554041525527, 0.6768776802935997, 0.3060621599750899]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 486}], {
             RGBColor[
             0.9627729895914936, 0.9654828212213326, 0.7058550168364002]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{406, 493}], {
             RGBColor[
             0.9920978208950986, 0.9843432363296774, 0.4801786397760631]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 408}], {
             RGBColor[
             0.2184314377890148, 0.3469156688422765, 0.9357507192905059]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{407, 430}], {
             RGBColor[
             0.22704868393744712`, 0.35597294090924125`, 0.9362414587105858]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{408, 430}], {
             RGBColor[
             0.23112177962706493`, 0.36025402272821205`, 0.9364734154845045]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 456}], {
             RGBColor[
             0.23260709522442666`, 0.3618151835954873, 0.9365580020104467]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 458}], {
             RGBColor[
             0.23602745875437942`, 0.36541020252904094`, 0.9367527866535031]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{409, 496}], {
             RGBColor[
             0.25922260246551676`, 0.38978976922649866`, 0.9380737157737123]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{411, 478}], {
             RGBColor[
             0.2528159536736963, 0.3830559751413007, 0.9377088666028057]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 476}], {
             RGBColor[
             0.9111642263834832, 0.6485722673362936, 0.273464018883213]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 486}], {
             RGBColor[
             0.9543818118224241, 0.9371774082640264, 0.6732568757445232]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{413, 493}], {
             RGBColor[
             0.9837066431260291, 0.9560378233723712, 0.44758049868418615`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 415}], {
             RGBColor[
             0.2808353270487499, 0.4125061130893616, 0.9393045284655668]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{414, 485}], {
             RGBColor[
             0.26132957932407624`, 0.39200433549489333`, 0.9381937049888145]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{415, 464}], {
             RGBColor[
             0.2654397247234546, 0.39632435890790974`, 0.9384277716888938]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{415, 485}], {
             RGBColor[
             0.2675069384795197, 0.39849713163445644`, 0.9385454964541331]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 427}], {
             RGBColor[
             0.2705169061527906, 0.4016607985020373, 0.9387169096602777]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 429}], {
             RGBColor[
             0.2775658260011634, 0.4090696601900088, 0.9391183352177]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{416, 499}], {
             RGBColor[
             0.26112616120390136`, 0.3917905301531358, 0.9381821206278006]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{417, 461}], {
             RGBColor[
             0.8227440842305245, 0.8622334494485463, 0.9748712810946092]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 420}], {
             RGBColor[
             0.9735581601714495, 0.9798002996671817, 0.9296433170801228]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{418, 432}], {
             RGBColor[
             0.9385489798096075, 0.9527344602026001, 0.9557578713810538]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 432}], {
             RGBColor[
             0.933633649289228, 0.949068614748616, 0.9640782438285385]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{420, 439}], {
             RGBColor[
             0.9147776569049322, 0.9340333582536569, 0.9622797424419812]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 423}], {
             RGBColor[
             0.18344124862659156`, 0.31013876152644193`, 0.9337580797810521]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{421, 477}], {
             RGBColor[
             0.21186411660990806`, 0.34001299789082284`, 0.9353767200648369]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 443}], {
             RGBColor[
             0.5842619922483114, 0.5706803433206208, 0.6014015077150748]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{422, 446}], {
             RGBColor[
             0.2310816388212659, 0.36021183219624314`, 0.9364711295249972]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 446}], {
             RGBColor[
             0.20798858239401255`, 0.3359395657068551, 0.9351560141245807]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{423, 477}], {
             RGBColor[
             0.21624875945532895`, 0.3446215355237733, 0.9356264189883857]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 440}], {
             RGBColor[
             0.30113413549531765`, 0.4327459792905174, 0.940500626045089]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 453}], {
             RGBColor[
             0.3024506322714007, 0.4341297008728973, 0.9405755985889044]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{424, 470}], {
             RGBColor[
             0.28803826967359597`, 0.4189813939860375, 0.9397548358601392]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{425, 466}], {
             RGBColor[
             0.4394255113443823, 0.5536672437102792, 0.9495973233231294]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 448}], {
             RGBColor[
             0.7190568535901429, 0.7797176017404024, 0.9733043071059779]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{426, 489}], {
             RGBColor[
             0.9301359936068372, 0.9447452859638352, 0.9006256116612403]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 460}], {
             RGBColor[
             0.2639231904685617, 0.39473038525219195`, 0.938341407306589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{427, 499}], {
             RGBColor[
             0.27010938266217854`, 0.4012324654749223, 0.9386937018003643]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{428, 495}], {
             RGBColor[
             0.8362679836981737, 0.2797771922017657, 0.1823635681891872]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{429, 499}], {
             RGBColor[
             0.2771583025105514, 0.4086413271628938, 0.9390951273577867]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 433}], {
             RGBColor[
             0.3870230907643596, 0.509641681699111, 0.9458817470057914]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 436}], {
             RGBColor[
             0.46072987194196846`, 0.5729505557434673, 0.9507253360979548]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 459}], {
             RGBColor[
             0.41954302397723237`, 0.5378088133487329, 0.9479538883938678]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 462}], {
             RGBColor[
             0.4562091477173884, 0.5692804281616477, 0.9503694481270373]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{431, 487}], {
             RGBColor[
             0.5139856537736541, 0.6161859985800608, 0.9549178263261018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{432, 467}], {
             RGBColor[
             0.8027318187709938, 0.8464550865365966, 0.9808037893677689]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{433, 462}], {
             RGBColor[
             0.3946923083800721, 0.5159976338539112, 0.9464496495216687]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 469}], {
             RGBColor[
             0.9258166281861495, 0.7248800924627727, 0.5003559242994462]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 474}], {
             RGBColor[
             0.992149866333044, 0.99102178223655, 0.7797605605635565]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{434, 495}], {
             RGBColor[
             0.9167025248852594, 0.6580111596730529, 0.4917530067660364]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 459}], {
             RGBColor[
             0.4317329658175249, 0.5478348930853527, 0.9488776788806625]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 462}], {
             RGBColor[
             0.46839908955768095`, 0.5793065078982675, 0.951293238613832]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{436, 487}], {
             RGBColor[
             0.5261755956139467, 0.6262120783166807, 0.9558416168128965]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 457}], {
             RGBColor[
             0.22152681415849518`, 0.35016910566479753`, 0.9359269963955489]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{438, 460}], {
             RGBColor[
             0.23490540515407732`, 0.3642308530528161, 0.9366888873608955]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 453}], {
             RGBColor[
             0.2829903357512072, 0.4147711638710876, 0.939427253023122]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{440, 470}], {
             RGBColor[
             0.2685779731534025, 0.3996228569842277, 0.9386064902943567]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{441, 467}], {
             RGBColor[
             0.5784857852356426, 0.6676055963951182, 0.960658898554645]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 444}], {
             RGBColor[
             0.27761918641957545`, 0.4091257453730057, 0.939121374014589]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{442, 492}], {
             RGBColor[
             0.2802823193946945, 0.4119248669822389, 0.9392730354977699]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{443, 446}], {
             RGBColor[
             0.5813316267430582, 0.5676003433786956, 0.6012346277346379]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{444, 492}], {
             RGBColor[
             0.2739561801729139, 0.4052756935597544, 0.9389127712277736]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{445, 460}], {
             RGBColor[
             0.23899278558713355`, 0.3685269490428458, 0.9369216576298206]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 453}], {
             RGBColor[
             0.26540338983624123`, 0.39628616863768357`, 0.9384257024708196]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{447, 463}], {
             RGBColor[
             0.2567986541117429, 0.38724204581948013`, 0.9379356755008752]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{449, 488}], {
             RGBColor[
             0.7488335383665432, 0.8037137186084069, 0.9756003869232444]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 454}], {
             RGBColor[
             0.8587954548220276, 0.3876960227591984, 0.20138137545633958`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 469}], {
             RGBColor[
             0.8390695807149537, 0.298125435533924, 0.18492162257597716`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 471}], {
             RGBColor[
             0.8372605332410615, 0.2874063629263848, 0.183314034752381]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 475}], {
             RGBColor[
             0.8283559372455574, 0.2189617360860943, 0.17478698357078354`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 491}], {
             RGBColor[
             0.9059349577098716, 0.5635204793804358, 0.38523852750809673`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{450, 500}], {
             RGBColor[
             0.8186005728713881, 0.14397773067830186`, 0.16544523562897076`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{451, 456}], {
             RGBColor[
             0.21755217330464396`, 0.3459915061206145, 0.9357006464788762]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{453, 463}], {
             RGBColor[
             0.2757020968027919, 0.407110762635264, 0.939012198596993]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 469}], {
             RGBColor[
             0.8801565520867384, 0.5487007178218191, 0.22171202824050545`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 471}], {
             RGBColor[
             0.8783475046128462, 0.5379816452142798, 0.2201044404169093]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 475}], {
             RGBColor[
             0.8694429086173421, 0.4695370183739893, 0.21157738923531183`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{454, 500}], {
             RGBColor[
             0.8596875442431727, 0.3945530129661969, 0.20223564129349905`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{456, 458}], {
             RGBColor[
             0.22707889219219896`, 0.35600469170029936`, 0.9362431790260048]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{461, 486}], {
             RGBColor[
             0.9396915520193736, 0.9545227464327241, 0.9862809714214389]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{461, 493}], {
             RGBColor[
             0.9690163833229786, 0.9733831615410689, 0.7606045943611018]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{462, 487}], {
             RGBColor[
             0.5216548713893666, 0.6225419507348611, 0.9554857288419789]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 485}], {
             RGBColor[
             0.24593397699878092`, 0.3758225813134415, 0.9373169482121415]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{464, 497}], {
             RGBColor[
             0.23993020302659857`, 0.369512234207422, 0.9369750421662133]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{466, 468}], {
             RGBColor[
             0.49094259840512156`, 0.5976083439541202, 0.9530679462098963]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 471}], {
             RGBColor[
             0.8586216305057723, 0.4484110579890054, 0.20364468753654688`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 474}], {
             RGBColor[
             0.9267639161265591, 0.7252718203703219, 0.4846569116242533]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 475}], {
             RGBColor[
             0.8497170345102683, 0.3799664311487149, 0.19511763635494941`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 491}], {
             RGBColor[
             0.9272960549745825, 0.7245251744430564, 0.40556918029226263`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{469, 495}], {
             RGBColor[
             0.8513165746787745, 0.3922611978068248, 0.19664935782673318`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 475}], {
             RGBColor[
             0.847907987036376, 0.36924735854117574`, 0.19351004853135326`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{471, 500}], {
             RGBColor[
             0.8381526226622067, 0.29426335313338325`, 0.18416830058954048`]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{474, 495}], {
             RGBColor[
             0.917649812825669, 0.658402887580602, 0.4760539940908434]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{476, 493}], {
             RGBColor[
             0.9210348441528622, 0.6812051793947629, 0.36818618909444256`]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{479, 482}], {
             RGBColor[
             0.3849860560945393, 0.5078773046524521, 0.9457519489579096]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{480, 481}], {
             RGBColor[
             0.33588196619861493`, 0.46534581002792214`, 0.9426230797707831]},
             StripOnInput -> False], 
           StyleBox[
            LineBox[{482, 496}], {
             RGBColor[
             0.31768549080207875`, 0.4466395905233832, 0.9415714600344062]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{484, 500}], {
             RGBColor[
             0.9061921804601966, 0.5690195539734165, 0.316991474169404]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{485, 497}], {
             RGBColor[
             0.24199741678266362`, 0.3716850069339687, 0.9370927669314526]}, 
            StripOnInput -> False], 
           StyleBox[
            LineBox[{486, 493}], {
             RGBColor[
             0.9642524295918031, 0.9698103203224957, 0.7679790459557528]}, 
            StripOnInput -> False]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           EdgeForm[None], 
           StyleBox[
            DiskBox[1, 0.0315874366232787], {
             RGBColor[
             0.2661654894960651, 0.39708718370006774`, 0.9384691029190212]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[2, 0.0315874366232787], {
             RGBColor[
             0.2124476857409665, 0.34062636604798524`, 0.9354099534635375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[3, 0.0315874366232787], {
             RGBColor[
             0.46166603367100856`, 0.5738403098087559, 0.9507631877904368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[4, 0.0315874366232787], {
             RGBColor[
             0.32430364693803726`, 0.45531725182765653`, 0.9418853195058047]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[5, 0.0315874366232787], {
             RGBColor[
             0.23860734128045696`, 0.3681218226379481, 0.9368997071467691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[6, 0.0315874366232787], {
             RGBColor[
             0.8276898195746623, 0.8654414113599355, 0.9834269879500976]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[7, 0.0315874366232787], {
             RGBColor[
             0.8386821070512293, 0.8742063630160551, 0.9844754421425435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[8, 0.0315874366232787], {
             RGBColor[
             0.6202936289377985, 0.7026213377380665, 0.963250933161866]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[9, 0.0315874366232787], {
             RGBColor[
             0.5751436787516512, 0.6659665741948753, 0.9596965636934954]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[10, 0.0315874366232787], {
             RGBColor[
             0.2189624152550279, 0.3474737598249721, 0.9357809576716846]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[11, 0.0315874366232787], {
             RGBColor[
             0.23891813183632316`, 0.3684484832174229, 0.9369174062091523]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[12, 0.0315874366232787], {
             RGBColor[
             0.27240341106773047`, 0.40364363477895904`, 0.9388243433243495]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[13, 0.0315874366232787], {
             RGBColor[
             0.29661626096016863`, 0.4290928751992627, 0.9402032293060224]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[14, 0.0315874366232787], {
             RGBColor[
             0.30674268007373295`, 0.4397363837396738, 0.9407799138938453]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[15, 0.0315874366232787], {
             RGBColor[
             0.23423879357827926`, 0.36353020202103736`, 0.9366509248178173]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[16, 0.0315874366232787], {
             RGBColor[
             0.4038820814050813, 0.5242440920345965, 0.9469559869815982]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[17, 0.0315874366232787], {
             RGBColor[
             0.8799712561457314, 0.9071292097399156, 0.9884136380424356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[18, 0.0315874366232787], {
             RGBColor[
             0.8843839202879132, 0.5678962094964264, 0.22523944788984251`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[19, 0.0315874366232787], {
             RGBColor[
             0.5597245266210166, 0.6534486118703385, 0.9584827115555565]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[20, 0.0315874366232787], {
             RGBColor[
             0.8845340276069948, 0.5685778117739207, 0.22536470111635126`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[21, 0.0315874366232787], {
             RGBColor[
             0.9808877657874093, 0.9471920876142448, 0.3802530084370154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[22, 0.0315874366232787], {
             RGBColor[
             0.4514165271362265, 0.5654160397762044, 0.9499848398305268]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[23, 0.0315874366232787], {
             RGBColor[
             0.2225015077722568, 0.35119357045200544`, 0.9359825037549226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[24, 0.0315874366232787], {
             RGBColor[
             0.8369720141620951, 0.8728427813654944, 0.9843123319561599]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[25, 0.0315874366232787], {
             RGBColor[
             0.3133752819583538, 0.4458516513578495, 0.941188973752873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[26, 0.0315874366232787], {
             RGBColor[
             0.3866295369467384, 0.5093008051628776, 0.9458566701045386]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[27, 0.0315874366232787], {
             RGBColor[
             0.5121189165844965, 0.6148002330343991, 0.9547350235483862]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[28, 0.0315874366232787], {
             RGBColor[
             0.9648560740830788, 0.9733102981108331, 0.9443736789601879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[29, 0.0315874366232787], {
             RGBColor[
             0.40962031041891445`, 0.5292142575946026, 0.9473216218602429]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[30, 0.0315874366232787], {
             RGBColor[
             0.2679312243382506, 0.39894308297325987`, 0.938569658906113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[31, 0.0315874366232787], {
             RGBColor[
             0.4530382628066378, 0.5668207057031098, 0.9500881753934008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[32, 0.0315874366232787], {
             RGBColor[
             0.5357107322431658, 0.6339531317852908, 0.9565922576967049]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[33, 0.0315874366232787], {
             RGBColor[
             0.8784142522519405, 0.5407893411964669, 0.22025821055067316`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[34, 0.0315874366232787], {
             RGBColor[
             0.5437530683305409, 0.6404822625241338, 0.9572253798535508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[35, 0.0315874366232787], {
             RGBColor[
             0.23837242809378653`, 0.36787491398440125`, 0.9368863291883112]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[36, 0.0315874366232787], {
             RGBColor[
             0.254389289460926, 0.3847096508089296, 0.9377984657483468]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[37, 0.0315874366232787], {
             RGBColor[
             0.305640198745031, 0.4385776059618545, 0.9407171292131508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[38, 0.0315874366232787], {
             RGBColor[
             0.25996867538836677`, 0.3905739391721695, 0.9381162035229527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[39, 0.0315874366232787], {
             RGBColor[
             0.6236615875481659, 0.7053555982627691, 0.963516071200913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[40, 0.0315874366232787], {
             RGBColor[
             0.3862001571816754, 0.5089288979916344, 0.9458293104055944]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[41, 0.0315874366232787], {
             RGBColor[
             0.23252667542550592`, 0.36173065728791187`, 0.9365534222218687]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[42, 0.0315874366232787], {
             RGBColor[
             0.23247426890382172`, 0.3616755747108564, 0.9365504377479873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[43, 0.0315874366232787], {
             RGBColor[
             0.2931478124699098, 0.42544731592366486`, 0.940005706295612]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[44, 0.0315874366232787], {
             RGBColor[
             0.49667724948997916`, 0.6022639920478948, 0.9535193989500155]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[45, 0.0315874366232787], {
             RGBColor[
             0.28278247170568477`, 0.41455268557990177`, 0.9394154154732368]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[46, 0.0315874366232787], {
             RGBColor[
             0.9176548470302313, 0.7112359389100995, 0.2526013609126037]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[47, 0.0315874366232787], {
             RGBColor[
             0.23193365260590854`, 0.36110735270469657`, 0.9365196504495912]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[48, 0.0315874366232787], {
             RGBColor[
             0.20751087662989864`, 0.3354374666604766, 0.9351288094880167]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[49, 0.0315874366232787], {
             RGBColor[
             0.49021471545548245`, 0.5970174157848499, 0.9530106445977776]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[50, 0.0315874366232787], {
             RGBColor[
             0.44093802683048844`, 0.5563400894761129, 0.9493171590568191]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[51, 0.0315874366232787], {
             RGBColor[
             0.17892700081062782`, 0.30539400085202123`, 0.9335010000461641]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[52, 0.0315874366232787], {
             RGBColor[
             0.8357950446989824, 0.2761419758107905, 0.18191068126945342`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[53, 0.0315874366232787], {
             RGBColor[
             0.9765123065091236, 0.9324326360618924, 0.36325517537702773`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[54, 0.0315874366232787], {
             RGBColor[
             0.22872079714307936`, 0.35773043790646125`, 0.9363366830839769]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[55, 0.0315874366232787], {
             RGBColor[
             0.21147766438726034`, 0.339606812102334, 0.9353547121824619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[56, 0.0315874366232787], {
             RGBColor[
             0.8366736085240676, 0.28289500235951803`, 0.1827519949805509]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[57, 0.0315874366232787], {
             RGBColor[
             0.6012429877716181, 0.6871551690177569, 0.9617511969044663]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[58, 0.0315874366232787], {
             RGBColor[
             0.31511174381280593`, 0.44735568733906544`, 0.9412996195667458]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[59, 0.0315874366232787], {
             RGBColor[
             0.2421911048281961, 0.37188858535035474`, 0.9371037971791099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[60, 0.0315874366232787], {
             RGBColor[
             0.29270959820985176`, 0.42498672495195505`, 0.9399807506417815]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[61, 0.0315874366232787], {
             RGBColor[
             0.3238266917401457, 0.45490413720770817`, 0.94185492834235]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[62, 0.0315874366232787], {
             RGBColor[0.817319, 0.134127, 0.164218]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[63, 0.0315874366232787], {
             RGBColor[
             0.41933559472005666`, 0.5376291485518648, 0.9479406711850231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[64, 0.0315874366232787], {
             RGBColor[
             0.2878344487965492, 0.41986263381624833`, 0.9397031180948312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[65, 0.0315874366232787], {
             RGBColor[
             0.9854648277298144, 0.9626315922912277, 0.39803402977763763`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[66, 0.0315874366232787], {
             RGBColor[
             0.2632810725593861, 0.3940554786170215, 0.9383048396415897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[67, 0.0315874366232787], {
             RGBColor[
             0.25662307112871396`, 0.38705749697171266`, 0.9379256763097434]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[68, 0.0315874366232787], {
             RGBColor[
             0.8199864588949732, 0.15463025795470559`, 0.16677236165029033`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[69, 0.0315874366232787], {
             RGBColor[
             0.9094625081980608, 0.9306447336077317, 0.9912265399903383]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[70, 0.0315874366232787], {
             RGBColor[
             0.2582501634540876, 0.38876767416929214`, 0.9380183368106061]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[71, 0.0315874366232787], {
             RGBColor[
             0.755781538403036, 0.8091415490436711, 0.97629289863413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[72, 0.0315874366232787], {
             RGBColor[
             0.2539844574642687, 0.3842841467126117, 0.9377754111650324]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[73, 0.0315874366232787], {
             RGBColor[
             0.24791046842011605`, 0.37789999911405875`, 0.9374295064746294]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[74, 0.0315874366232787], {
             RGBColor[
             0.2817340129849886, 0.4134506889883278, 0.9393557073001488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[75, 0.0315874366232787], {
             RGBColor[
             0.3449485107481652, 0.47319879521896346`, 0.9432007919722498]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[76, 0.0315874366232787], {
             RGBColor[
             0.4113253016274047, 0.530691035284047, 0.9474302623923834]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[77, 0.0315874366232787], {
             RGBColor[
             0.606817875551374, 0.6916811140631951, 0.9621900724919755]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[78, 0.0315874366232787], {
             RGBColor[
             0.21942909899518986`, 0.3479642740253404, 0.9358075346202901]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[79, 0.0315874366232787], {
             RGBColor[
             0.9938287149952354, 0.9892085703244617, 0.5696718958667929]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[80, 0.0315874366232787], {
             RGBColor[
             0.7895429134572223, 0.8355161918319554, 0.9796579169815435]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[81, 0.0315874366232787], {
             RGBColor[
             0.8236181467643259, 0.8621947699835874, 0.9830386281626226]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[82, 0.0315874366232787], {
             RGBColor[
             0.25827862318556116`, 0.3887975871515221, 0.9380199575502111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[83, 0.0315874366232787], {
             RGBColor[
             0.9207457022290968, 0.9396416462539369, 0.9923027411096448]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[84, 0.0315874366232787], {
             RGBColor[
             0.2333142933423989, 0.36255849365642656`, 0.9365982758970595]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[85, 0.0315874366232787], {
             RGBColor[
             0.21421555473578224`, 0.34248450845090483`, 0.9355106309874645]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[86, 0.0315874366232787], {
             RGBColor[
             0.9151930916309041, 0.7014758990831244, 0.2506205747334791]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[87, 0.0315874366232787], {
             RGBColor[
             0.1792532619022457, 0.3057369219454596, 0.9335195801326717]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[88, 0.0315874366232787], {
             RGBColor[
             0.8666101266120032, 0.4871895635890985, 0.21040855877111306`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[89, 0.0315874366232787], {
             RGBColor[
             0.28550171685781406`, 0.4174107846448903, 0.9395702724618878]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[90, 0.0315874366232787], {
             RGBColor[
             0.8647697772859632, 0.4788329671240561, 0.2088729261823753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[91, 0.0315874366232787], {
             RGBColor[
             0.3276288460270304, 0.4581973721491767, 0.9420971982513973]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[92, 0.0315874366232787], {
             RGBColor[
             0.6091375885965603, 0.6935643616151592, 0.9623726888002815]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[93, 0.0315874366232787], {
             RGBColor[
             0.26928527939714464`, 0.4003662806922068, 0.9386467703385721]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[94, 0.0315874366232787], {
             RGBColor[
             0.9554190789968999, 0.9662722026272221, 0.9603480500785777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[95, 0.0315874366232787], {
             RGBColor[
             0.22708291988077767`, 0.3560089250563658, 0.936243408396911]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[96, 0.0315874366232787], {
             RGBColor[
             0.2961617343973124, 0.4286151389630523, 0.9401773446906796]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[97, 0.0315874366232787], {
             RGBColor[
             0.2317345075524728, 0.36089803862701, 0.9365083094334068]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[98, 0.0315874366232787], {
             RGBColor[
             0.9952347378240085, 0.9922159109844932, 0.7227088038116687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[99, 0.0315874366232787], {
             RGBColor[
             0.9936215336094609, 0.9887654302895413, 0.5471214806005384]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[100, 0.0315874366232787], {
             RGBColor[
             0.9312148525901699, 0.7649968423512695, 0.2635120596803694]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[101, 0.0315874366232787], {
             RGBColor[
             0.5208327276256995, 0.6218744973903617, 0.9554210066732913]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[102, 0.0315874366232787], {
             RGBColor[
             0.2765375568294345, 0.40798888409449063`, 0.939059776809558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[103, 0.0315874366232787], {
             RGBColor[
             0.4803557055985901, 0.589013427439692, 0.9522345072271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[104, 0.0315874366232787], {
             RGBColor[
             0.24657366739272524`, 0.3764949364761905, 0.9373533776337394]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[105, 0.0315874366232787], {
             RGBColor[
             0.2459052705491277, 0.3757924090147619, 0.9373153134223011]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[106, 0.0315874366232787], {
             RGBColor[
             0.5178553382148801, 0.619457318536794, 0.9551866156723348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[107, 0.0315874366232787], {
             RGBColor[
             0.18467169248908813`, 0.3114320360405726, 0.9338281517387427]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[108, 0.0315874366232787], {
             RGBColor[
             0.28511069510105125`, 0.41699979598632125`, 0.939548004351305]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[109, 0.0315874366232787], {
             RGBColor[
             0.25396000439311356`, 0.38425844498441336`, 0.9377740185988052]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[110, 0.0315874366232787], {
             RGBColor[
             0.27171530098953856`, 0.4029203874580805, 0.9387851564733641]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[111, 0.0315874366232787], {
             RGBColor[
             0.27309124258507717`, 0.4043665893147275, 0.9388635143117069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[112, 0.0315874366232787], {
             RGBColor[
             0.24826352560257345`, 0.3782710845979398, 0.937449612558869]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[113, 0.0315874366232787], {
             RGBColor[
             0.17919226069553715`, 0.305672805809509, 0.9335161062041928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[114, 0.0315874366232787], {
             RGBColor[
             0.5006784839436625, 0.605512374430953, 0.9538343907832142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[115, 0.0315874366232787], {
             RGBColor[
             0.9211683800910966, 0.9399786781078106, 0.9923430565014513]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[116, 0.0315874366232787], {
             RGBColor[
             0.24872594858728536`, 0.3787571204741826, 0.9374759468637549]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[117, 0.0315874366232787], {
             RGBColor[
             0.38107527345035186`, 0.504489981287708, 0.9455027573459912]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[118, 0.0315874366232787], {
             RGBColor[
             0.32510810483221725`, 0.45601403282236586`, 0.9419365788514676]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[119, 0.0315874366232787], {
             RGBColor[
             0.9906473743776302, 0.9904004632007044, 0.8046607405893015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[120, 0.0315874366232787], {
             RGBColor[
             0.20742150462258202`, 0.3353435310142743, 0.9351237198844141]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[121, 0.0315874366232787], {
             RGBColor[
             0.8274659414661699, 0.21212083852708477`, 0.1739347226073356]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[122, 0.0315874366232787], {
             RGBColor[
             0.867504304657107, 0.49124981725132677`, 0.21115468285025726`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[123, 0.0315874366232787], {
             RGBColor[
             0.2069635167020156, 0.33486215667164765`, 0.9350976381498702]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[124, 0.0315874366232787], {
             RGBColor[
             0.9626525497894284, 0.8856804222207267, 0.30941263771645156`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[125, 0.0315874366232787], {
             RGBColor[
             0.20867358600249122`, 0.3366595479311035, 0.9351950240667115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[126, 0.0315874366232787], {
             RGBColor[
             0.2511378152607278, 0.38129214526915, 0.9376132991027705]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[127, 0.0315874366232787], {
             RGBColor[
             0.22597981130456574`, 0.35484948800164373`, 0.9361805879953986]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[128, 0.0315874366232787], {
             RGBColor[
             0.49474321248409076`, 0.6006938536791404, 0.9533671444723009]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[129, 0.0315874366232787], {
             RGBColor[
             0.35559977387920144`, 0.4824243839950162, 0.9438794810404173]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[130, 0.0315874366232787], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[131, 0.0315874366232787], {
             RGBColor[
             0.263609049878749, 0.394400203574635, 0.9383235174647285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[132, 0.0315874366232787], {
             RGBColor[
             0.9901329118562932, 0.9901877197270478, 0.8131867159541827]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[133, 0.0315874366232787], {
             RGBColor[
             0.3451736656290086, 0.4733938130601367, 0.9432151386421606]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[134, 0.0315874366232787], {
             RGBColor[
             0.2332063867745317, 0.36244507701192663`, 0.9365921307776528]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[135, 0.0315874366232787], {
             RGBColor[
             0.25062676841059334`, 0.3807550026274169, 0.9375841957406814]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[136, 0.0315874366232787], {
             RGBColor[
             0.968960662006962, 0.9763714930638193, 0.9374256822530368]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[137, 0.0315874366232787], {
             RGBColor[
             0.22008054170119, 0.3486489816131997, 0.9358446333186737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[138, 0.0315874366232787], {
             RGBColor[
             0.2199663924455993, 0.34852900350809307`, 0.9358381326874365]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[139, 0.0315874366232787], {
             RGBColor[
             0.5640351798749514, 0.6569481943745988, 0.9588220619701494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[140, 0.0315874366232787], {
             RGBColor[
             0.4996340643500339, 0.6046644675542787, 0.9537521702469687]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[141, 0.0315874366232787], {
             RGBColor[
             0.30958288032569087`, 0.4425668636752852, 0.9409473252743288]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[142, 0.0315874366232787], {
             RGBColor[
             0.6995243049605603, 0.765192970707599, 0.9706857033583209]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[143, 0.0315874366232787], {
             RGBColor[
             0.17892700134778292`, 0.3053940014166053, 0.9335010000767543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[144, 0.0315874366232787], {
             RGBColor[
             0.24622776306205768`, 0.3761313690930576, 0.9373336788938276]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[145, 0.0315874366232787], {
             RGBColor[
             0.2206581667895666, 0.3492561022046294, 0.935877528212937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[146, 0.0315874366232787], {
             RGBColor[
             0.257933230334439, 0.3884345573658211, 0.9380002879383026]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[147, 0.0315874366232787], {
             RGBColor[
             0.25149316947897704`, 0.3816656450832887, 0.9376335359998004]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[148, 0.0315874366232787], {
             RGBColor[
             0.23965584235908116`, 0.3692238637503902, 0.9369594177320785]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[149, 0.0315874366232787], {
             RGBColor[
             0.353874772698637, 0.4809302746734916, 0.9437695654905504]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[150, 0.0315874366232787], {
             RGBColor[
             0.8214446559981496, 0.16583859987576455`, 0.16816873284309014`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[151, 0.0315874366232787], {
             RGBColor[
             0.30679432383558886`, 0.439790664607788, 0.9407828549296829]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[152, 0.0315874366232787], {
             RGBColor[
             0.20400293554931437`, 0.33175039816847185`, 0.9349290374330113]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[153, 0.0315874366232787], {
             RGBColor[
             0.24493296406314102`, 0.3747704532501981, 0.9372599420063227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[154, 0.0315874366232787], {
             RGBColor[
             0.30954120355039927`, 0.44253076534726327`, 0.9409446696670606]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[155, 0.0315874366232787], {
             RGBColor[
             0.5658891207695752, 0.6584533071119401, 0.9589680109885835]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[156, 0.0315874366232787], {
             RGBColor[
             0.46730916543215706`, 0.578421658392645, 0.9512074357941471]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[157, 0.0315874366232787], {
             RGBColor[
             0.3025436094347634, 0.43532289426166115`, 0.9405407830329243]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[158, 0.0315874366232787], {
             RGBColor[
             0.3575213303529286, 0.48408873963232213`, 0.9440019209197574]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[159, 0.0315874366232787], {
             RGBColor[
             0.8207501650068003, 0.16050043778835987`, 0.16750368748545852`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[160, 0.0315874366232787], {
             RGBColor[
             0.42248174875901884`, 0.5403541890501141, 0.948141141338351]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[161, 0.0315874366232787], {
             RGBColor[
             0.9903319581123935, 0.9790495659282263, 0.41694191223350735`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[162, 0.0315874366232787], {
             RGBColor[
             0.46203141681910903`, 0.5741369443087071, 0.9507919520902978]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[163, 0.0315874366232787], {
             RGBColor[
             0.26699231078344465`, 0.3979562252966011, 0.9385161891681649]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[164, 0.0315874366232787], {
             RGBColor[
             0.8175247092939038, 0.13570817177533162`, 0.16441498745215766`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[165, 0.0315874366232787], {
             RGBColor[
             0.4240332554553848, 0.5416980261695123, 0.9482400019731]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[166, 0.0315874366232787], {
             RGBColor[
             0.8381204118994321, 0.2940157670958513, 0.18413745552673064`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[167, 0.0315874366232787], {
             RGBColor[
             0.9866702547547157, 0.9887558220293171, 0.870571905196646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[168, 0.0315874366232787], {
             RGBColor[
             0.9107922199972238, 0.6840279095591187, 0.24707953011528597`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[169, 0.0315874366232787], {
             RGBColor[
             0.4927421843014464, 0.5990693288551774, 0.9532096162037554]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[170, 0.0315874366232787], {
             RGBColor[
             0.29668056881803306`, 0.42916046683523196`, 0.9402068915433929]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[171, 0.0315874366232787], {
             RGBColor[
             0.26174222518751433`, 0.39243805246062563`, 0.9382172045602823]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[172, 0.0315874366232787], {
             RGBColor[
             0.3516524550010693, 0.4790054147807936, 0.9436279613719797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[173, 0.0315874366232787], {
             RGBColor[
             0.984562956112485, 0.9878843998856498, 0.9054952972124768]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[174, 0.0315874366232787], {
             RGBColor[
             0.2666571079259713, 0.3976039058403079, 0.93849709986132]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[175, 0.0315874366232787], {
             RGBColor[
             0.9557302644442173, 0.966504284224312, 0.9598212942864327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[176, 0.0315874366232787], {
             RGBColor[
             0.6069446059586334, 0.6917839995169481, 0.9622000491738637]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[177, 0.0315874366232787], {
             RGBColor[
             0.20869655844004803`, 0.3366836934195124, 0.9351963323130457]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[178, 0.0315874366232787], {
             RGBColor[
             0.9916846362160958, 0.9908293976273234, 0.7874706275783359]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[179, 0.0315874366232787], {
             RGBColor[
             0.178929137062006, 0.30539624618766587`, 0.9335011217025198]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[180, 0.0315874366232787], {
             RGBColor[
             0.27013094278236094`, 0.4012551265282246, 0.9386949296173133]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[181, 0.0315874366232787], {
             RGBColor[
             0.4206971967779904, 0.5388084998183378, 0.9480274312641372]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[182, 0.0315874366232787], {
             RGBColor[
             0.3785866605047563, 0.5023344698355566, 0.9453441851296919]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[183, 0.0315874366232787], {
             RGBColor[
             0.2049673414252272, 0.33276404989092045`, 0.9349839589209338]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[184, 0.0315874366232787], {
             RGBColor[
             0.2570318728012019, 0.3874871734490205, 0.9379489569602237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[185, 0.0315874366232787], {
             RGBColor[
             0.2839447494602888, 0.41577431319265656`, 0.9394816054719256]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[186, 0.0315874366232787], {
             RGBColor[
             0.23571041014604155`, 0.365076964339635, 0.9367347312042897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[187, 0.0315874366232787], {
             RGBColor[
             0.26462809617956273`, 0.3954712858480575, 0.938381550644016]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[188, 0.0315874366232787], {
             RGBColor[
             0.33727714516499796`, 0.4665542439248693, 0.9427119793408126]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[189, 0.0315874366232787], {
             RGBColor[
             0.2597753641562747, 0.39037075681060074`, 0.9381051947342635]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[190, 0.0315874366232787], {
             RGBColor[
             0.24810961844878143`, 0.3781093184210272, 0.9374408477741458]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[191, 0.0315874366232787], {
             RGBColor[
             0.21840138119578575`, 0.34688407745709465`, 0.9357490076119863]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[192, 0.0315874366232787], {
             RGBColor[
             0.2546146394674752, 0.38494650795382845`, 0.9378112990978443]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[193, 0.0315874366232787], {
             RGBColor[
             0.2878117179623051, 0.41983874226823964`, 0.9397018236074483]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[194, 0.0315874366232787], {
             RGBColor[
             0.9865160895376739, 0.9886920707502049, 0.8731268218098209]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[195, 0.0315874366232787], {
             RGBColor[
             0.2701519252165497, 0.40127718039692006`, 0.9386961245358997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[196, 0.0315874366232787], {
             RGBColor[
             0.29569933477919436`, 0.42812912764658106`, 0.9401510117164867]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[197, 0.0315874366232787], {
             RGBColor[
             0.6976256228082208, 0.7637097057796726, 0.9704964604655693]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[198, 0.0315874366232787], {
             RGBColor[
             0.2818794421164257, 0.41360354422620765`, 0.9393639892740411]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[199, 0.0315874366232787], {
             RGBColor[
             0.3428438781472085, 0.4713758682419251, 0.9430666866439704]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[200, 0.0315874366232787], {
             RGBColor[
             0.9008280073528754, 0.6425649682443086, 0.23896079721830538`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[201, 0.0315874366232787], {
             RGBColor[
             0.3044587746178886, 0.4373358542976118, 0.9406498488568703]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[202, 0.0315874366232787], {
             RGBColor[
             0.23905706042934927`, 0.3685945059772749, 0.9369253179869986]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[203, 0.0315874366232787], {
             RGBColor[
             0.5345666356633387, 0.6330243026408235, 0.956502190222977]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[204, 0.0315874366232787], {
             RGBColor[
             0.5018930513522051, 0.606498414968846, 0.9539300059787216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[205, 0.0315874366232787], {
             RGBColor[
             0.9938265629209484, 0.98920396725517, 0.5694376558617151]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[206, 0.0315874366232787], {
             RGBColor[
             0.3427341577200499, 0.4712808339226293, 0.9430596953553738]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[207, 0.0315874366232787], {
             RGBColor[
             0.217062994597398, 0.3454773482835776, 0.9356727884751737]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[208, 0.0315874366232787], {
             RGBColor[
             0.32211852500862637`, 0.45342460903982235`, 0.9417460854686901]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[209, 0.0315874366232787], {
             RGBColor[
             0.5659235722129052, 0.6584812763456551, 0.9589707231324023]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[210, 0.0315874366232787], {
             RGBColor[
             0.8360637140310553, 0.2782070860287545, 0.182167959325265]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[211, 0.0315874366232787], {
             RGBColor[
             0.2310404057237692, 0.3601684935964447, 0.9364687813610937]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[212, 0.0315874366232787], {
             RGBColor[
             0.21851625165510197`, 0.3470048135930438, 0.9357555493147087]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[213, 0.0315874366232787], {
             RGBColor[
             0.90420589766789, 0.657903179238463, 0.24177939169682186`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[214, 0.0315874366232787], {
             RGBColor[
             0.19980711485308938`, 0.32734032458634205`, 0.9346900916515217]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[215, 0.0315874366232787], {
             RGBColor[
             0.28412310253725925`, 0.4159617735847908, 0.9394917624158093]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[216, 0.0315874366232787], {
             RGBColor[
             0.26588598144981995`, 0.39679340302163035`, 0.9384531853492826]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[217, 0.0315874366232787], {
             RGBColor[
             0.31971976000988434`, 0.4513469193633465, 0.9415932382841149]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[218, 0.0315874366232787], {
             RGBColor[
             0.23197293745711564`, 0.3611486435741187, 0.9365218876637508]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[219, 0.0315874366232787], {
             RGBColor[
             0.5262688994117111, 0.6262878265429939, 0.9558489620296395]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[220, 0.0315874366232787], {
             RGBColor[
             0.3389132056188999, 0.46797131725924984`, 0.9428162276662237]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[221, 0.0315874366232787], {
             RGBColor[
             0.5366100807415061, 0.6346832634114314, 0.9566630577049163]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[222, 0.0315874366232787], {
             RGBColor[
             0.4427137030371586, 0.5578780909582495, 0.9494303035745394]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[223, 0.0315874366232787], {
             RGBColor[
             0.38986378476733635`, 0.5121021480670574, 0.9460627535157341]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[224, 0.0315874366232787], {
             RGBColor[
             0.29896629209325354`, 0.43156290692071464`, 0.9403370601024921]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[225, 0.0315874366232787], {
             RGBColor[
             0.27424929290791517`, 0.4055837736286615, 0.9389294635644105]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[226, 0.0315874366232787], {
             RGBColor[
             0.1794249922972142, 0.30591742147890744`, 0.9335293599246128]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[227, 0.0315874366232787], {
             RGBColor[
             0.8456311671254343, 0.35174672299683013`, 0.19132976321333509`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[228, 0.0315874366232787], {
             RGBColor[
             0.9930813033990235, 0.9876099324950685, 0.48832075610881853`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[229, 0.0315874366232787], {
             RGBColor[
             0.2909757990296596, 0.42316439208435586`, 0.9398820133433956]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[230, 0.0315874366232787], {
             RGBColor[
             0.2238780227461086, 0.35264037496561385`, 0.936060894246312]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[231, 0.0315874366232787], {
             RGBColor[
             0.2584463601503126, 0.3889738893366137, 0.9380295099222091]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[232, 0.0315874366232787], {
             RGBColor[
             0.3561976264336458, 0.4829422138287328, 0.9439175756765262]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[233, 0.0315874366232787], {
             RGBColor[
             0.8431597968980244, 0.3327506884676198, 0.18896317629255405`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[234, 0.0315874366232787], {
             RGBColor[
             0.38857864336543946`, 0.5109890231778194, 0.9459808654420111]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[235, 0.0315874366232787], {
             RGBColor[
             0.3570417238501652, 0.48367332858535217`, 0.9439713608175008]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[236, 0.0315874366232787], {
             RGBColor[
             0.28732315690654525`, 0.419325233622076, 0.939674000778084]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[237, 0.0315874366232787], {
             RGBColor[
             0.906092392768253, 0.9279574950433493, 0.9909050953721057]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[238, 0.0315874366232787], {
             RGBColor[
             0.32015392046586916`, 0.45172296732878153`, 0.9416209026044572]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[239, 0.0315874366232787], {
             RGBColor[
             0.3509305166159243, 0.47838010803725933`, 0.9435819600964633]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[240, 0.0315874366232787], {
             RGBColor[
             0.2566255537350775, 0.38706010634840704`, 0.9379258176905032]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[241, 0.0315874366232787], {
             RGBColor[
             0.7054821402904016, 0.7698472769484965, 0.9712795247048629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[242, 0.0315874366232787], {
             RGBColor[
             0.22500762673968802`, 0.3538276603838957, 0.936125223522647]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[243, 0.0315874366232787], {
             RGBColor[
             0.8393061093521738, 0.30312955729356095`, 0.18527288074652987`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[244, 0.0315874366232787], {
             RGBColor[
             0.3424410288691568, 0.4710269404450701, 0.9430410174441985]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[245, 0.0315874366232787], {
             RGBColor[
             0.22156287013367681`, 0.3502070027807943, 0.9359290497299955]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[246, 0.0315874366232787], {
             RGBColor[
             0.29422140859812795`, 0.42657573352434824`, 0.9400668460068708]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[247, 0.0315874366232787], {
             RGBColor[
             0.4950113815248125, 0.6009115653872759, 0.9533882557215221]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[248, 0.0315874366232787], {
             RGBColor[
             0.24253965650195108`, 0.3722549352589237, 0.9371236466812941]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[249, 0.0315874366232787], {
             RGBColor[
             0.2895478687563091, 0.421663546831056, 0.9398006948267619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[250, 0.0315874366232787], {
             RGBColor[
             0.20444533477183996`, 0.332215387801077, 0.934954231414263]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[251, 0.0315874366232787], {
             RGBColor[
             0.25854520282865096`, 0.38907777925853504`, 0.9380351388665158]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[252, 0.0315874366232787], {
             RGBColor[
             0.7357960105795031, 0.7935287028122899, 0.9743009279960564]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[253, 0.0315874366232787], {
             RGBColor[
             0.9850318468002165, 0.9880782982349678, 0.8977245650665646]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[254, 0.0315874366232787], {
             RGBColor[
             0.23649824945009773`, 0.365905033400095, 0.9367795974871519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[255, 0.0315874366232787], {
             RGBColor[
             0.3975855258515599, 0.5187903320882202, 0.9465547760295533]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[256, 0.0315874366232787], {
             RGBColor[
             0.2893861381019995, 0.4214935576590608, 0.939791484505258]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[257, 0.0315874366232787], {
             RGBColor[
             0.8588534332133313, 0.4519682304874997, 0.20393618366530758`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[258, 0.0315874366232787], {
             RGBColor[
             0.3734224424883788, 0.497861483750915, 0.945015125724227]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[259, 0.0315874366232787], {
             RGBColor[
             0.8618406991999262, 0.46553270763892984`, 0.20642883162911219`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[260, 0.0315874366232787], {
             RGBColor[
             0.28557642935408295`, 0.4174893122155148, 0.9395745272280231]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[261, 0.0315874366232787], {
             RGBColor[
             0.8799868165294279, 0.5479299882988189, 0.2215703967308864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[262, 0.0315874366232787], {
             RGBColor[
             0.47608581392629684`, 0.5855469370236965, 0.9518983657135286]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[263, 0.0315874366232787], {
             RGBColor[
             0.2734006518561467, 0.40469179807630246`, 0.9388811347119643]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[264, 0.0315874366232787], {
             RGBColor[
             0.23478619087952063`, 0.36410555129163547`, 0.9366820982843213]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[265, 0.0315874366232787], {
             RGBColor[
             0.32101450543653715`, 0.45246836277611585`, 0.9416757383178027]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[266, 0.0315874366232787], {
             RGBColor[
             0.28952074326414307`, 0.421635036218934, 0.9397991500701115]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[267, 0.0315874366232787], {
             RGBColor[
             0.9890626064851881, 0.9747677448317271, 0.41201072085875556`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[268, 0.0315874366232787], {
             RGBColor[
             0.40965477924277666`, 0.5292441127573786, 0.9473238181832199]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[269, 0.0315874366232787], {
             RGBColor[
             0.44893934079834463`, 0.5632704254773366, 0.9498269957075668]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[270, 0.0315874366232787], {
             RGBColor[
             0.9900230881246451, 0.9901423047916702, 0.8150067794022959]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[271, 0.0315874366232787], {
             RGBColor[
             0.2558053195227897, 0.38619798818543977`, 0.9378791065655412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[272, 0.0315874366232787], {
             RGBColor[
             0.8205829319400263, 0.15921501115513814`, 0.16734354491185305`]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[273, 0.0315874366232787], {
             RGBColor[
             0.2935414156904733, 0.42586101786436276`, 0.9400281214167392]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[274, 0.0315874366232787], {
             RGBColor[
             0.4627342609626232, 0.5747075448471798, 0.9508472825558781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[275, 0.0315874366232787], {
             RGBColor[
             0.4137039619056965, 0.5327513112621616, 0.9475818285219495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[276, 0.0315874366232787], {
             RGBColor[
             0.6195401563438858, 0.7020096347427746, 0.9631916170392121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[277, 0.0315874366232787], {
             RGBColor[
             0.7713015318020453, 0.8212658858432957, 0.977839786533559]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[278, 0.0315874366232787], {
             RGBColor[
             0.9483637407407871, 0.9610103429078694, 0.9722908974192511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[279, 0.0315874366232787], {
             RGBColor[
             0.2785602236563872, 0.4101148351741018, 0.9391749646930856]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[280, 0.0315874366232787], {
             RGBColor[
             0.25689237745970156`, 0.38734055500058817`, 0.9379410129068901]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[281, 0.0315874366232787], {
             RGBColor[
             0.24490866169442368`, 0.374744909919817, 0.9372585580223763]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[282, 0.0315874366232787], {
             RGBColor[
             0.6076583896248129, 0.6923634812527404, 0.9622562408387412]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[283, 0.0315874366232787], {
             RGBColor[
             0.18121415923057888`, 0.3077979493656092, 0.9336312503346327]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[284, 0.0315874366232787], {
             RGBColor[
             0.24509263407936946`, 0.37493827656091794`, 0.9372690349775362]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[285, 0.0315874366232787], {
             RGBColor[
             0.3144183414809424, 0.4467550970906198, 0.941255436583311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[286, 0.0315874366232787], {
             RGBColor[
             0.22310026486080187`, 0.3518229021154584, 0.9360166020853335]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[287, 0.0315874366232787], {
             RGBColor[
             0.20981171601903448`, 0.33785579474010136`, 0.9352598388874411]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[288, 0.0315874366232787], {
             RGBColor[
             0.2560659100008252, 0.3864718853002457, 0.9378939468077562]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[289, 0.0315874366232787], {
             RGBColor[
             0.439371052281192, 0.5549828548799431, 0.9492173128241592]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[290, 0.0315874366232787], {
             RGBColor[
             0.2864852402250885, 0.41844453006287885`, 0.9396262826626617]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[291, 0.0315874366232787], {
             RGBColor[
             0.6549271406176395, 0.7303533269719065, 0.9662406748008145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[292, 0.0315874366232787], {
             RGBColor[
             0.1789706321783367, 0.30543986018587177`, 0.9335034847880083]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[293, 0.0315874366232787], {
             RGBColor[
             0.9542723127115095, 0.9654169462092355, 0.962289226275195]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[294, 0.0315874366232787], {
             RGBColor[
             0.23831274258564697`, 0.36781218073106675`, 0.9368829301869194]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[295, 0.0315874366232787], {
             RGBColor[
             0.22958788287780074`, 0.3586417999900643, 0.9363860623338308]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[296, 0.0315874366232787], {
             RGBColor[
             0.3134198204339392, 0.44589022834683273`, 0.9411918117051534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[297, 0.0315874366232787], {
             RGBColor[
             0.5193642093092683, 0.6206822880650865, 0.955305399532062]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[298, 0.0315874366232787], {
             RGBColor[
             0.9016398137954514, 0.9244071294324739, 0.9904804044148157]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[299, 0.0315874366232787], {
             RGBColor[
             0.2091663766185125, 0.3371775021132715, 0.9352230877632756]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[300, 0.0315874366232787], {
             RGBColor[
             0.22595764709528393`, 0.3548261920123965, 0.936179325776469]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[301, 0.0315874366232787], {
             RGBColor[
             0.20875268020104726`, 0.3367426809486477, 0.9351995283643099]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[302, 0.0315874366232787], {
             RGBColor[
             0.19014935834156865`, 0.31718941015560403`, 0.934140096705561]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[303, 0.0315874366232787], {
             RGBColor[
             0.3052585207535403, 0.43817643819301544`, 0.9406953932161773]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[304, 0.0315874366232787], {
             RGBColor[
             0.3385640468354945, 0.4676688934702948, 0.9427939795772942]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[305, 0.0315874366232787], {
             RGBColor[
             0.2511118726659751, 0.3812648779572094, 0.9376118217103779]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[306, 0.0315874366232787], {
             RGBColor[
             0.8575795140998795, 0.443586953641446, 0.20277151376979163`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[307, 0.0315874366232787], {
             RGBColor[
             0.46980956787155936`, 0.580451597734798, 0.9514042766334527]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[308, 0.0315874366232787], {
             RGBColor[
             0.17894628476761076`, 0.30541426951348377`, 0.9335020982389862]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[309, 0.0315874366232787], {
             RGBColor[
             0.9930307649637, 0.9875018358921313, 0.48281995931092997`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[310, 0.0315874366232787], {
             RGBColor[
             0.29675707084929953`, 0.4292408753206019, 0.9402112482208989]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[311, 0.0315874366232787], {
             RGBColor[
             0.746856868272219, 0.8021695289074716, 0.9754033709212744]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[312, 0.0315874366232787], {
             RGBColor[
             0.3044115375980597, 0.43728620519477157`, 0.940647158778472]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[313, 0.0315874366232787], {
             RGBColor[
             0.266957894870447, 0.3979200519899457, 0.9385142292328336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[314, 0.0315874366232787], {
             RGBColor[
             0.33007547283951477`, 0.4603165173231115, 0.9422530951484216]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[315, 0.0315874366232787], {
             RGBColor[
             0.1854996162687526, 0.3123022364263995, 0.933875300773191]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[316, 0.0315874366232787], {
             RGBColor[
             0.2504950392509415, 0.38061654692851177`, 0.937576693959915]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[317, 0.0315874366232787], {
             RGBColor[
             0.8834003236622562, 0.5634299269441462, 0.22441871075523476`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[318, 0.0315874366232787], {
             RGBColor[
             0.341942322952124, 0.4705949864454246, 0.9430092403441536]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[319, 0.0315874366232787], {
             RGBColor[
             0.7148896845747944, 0.7771965220434489, 0.9722171808006315]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[320, 0.0315874366232787], {
             RGBColor[
             0.9886024976405045, 0.9895548541189678, 0.8385496400948322]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[321, 0.0315874366232787], {
             RGBColor[
             0.3331754530775283, 0.46300156439574175`, 0.942450623147983]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[322, 0.0315874366232787], {
             RGBColor[
             0.25921854913182885`, 0.38978550891579644`, 0.9380734849423552]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[323, 0.0315874366232787], {
             RGBColor[
             0.23934466612723454`, 0.36889679780100676`, 0.9369416967060188]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[324, 0.0315874366232787], {
             RGBColor[
             0.369677449943029, 0.49461775943693126`, 0.9447764981108042]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[325, 0.0315874366232787], {
             RGBColor[
             0.1790169203691504, 0.30548851200925775`, 0.9335061208319979]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[326, 0.0315874366232787], {
             RGBColor[
             0.8751755113140446, 0.526082975024646, 0.21755572572328788`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[327, 0.0315874366232787], {
             RGBColor[
             0.2570691600545971, 0.38752636471648727`, 0.9379510804141431]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[328, 0.0315874366232787], {
             RGBColor[
             0.3853130055350487, 0.5081604918248647, 0.9457727818871488]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[329, 0.0315874366232787], {
             RGBColor[
             0.8825578842047201, 0.909191716742005, 0.9886603529358121]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[330, 0.0315874366232787], {
             RGBColor[
             0.3064495532407965, 0.43942828885294294`, 0.9407632207543519]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[331, 0.0315874366232787], {
             RGBColor[
             0.8366916950922476, 0.8726192625482565, 0.984285594873034]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[332, 0.0315874366232787], {
             RGBColor[
             0.40219205331719154`, 0.5227802746481479, 0.946848299886271]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[333, 0.0315874366232787], {
             RGBColor[
             0.3786491349611119, 0.5023885820695944, 0.9453481659468069]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[334, 0.0315874366232787], {
             RGBColor[
             0.4028040785660817, 0.5233103801574531, 0.9468872975939376]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[335, 0.0315874366232787], {
             RGBColor[
             0.2767721721232211, 0.4082354796437291, 0.9390731378034569]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[336, 0.0315874366232787], {
             RGBColor[
             0.22223854670063217`, 0.35091718169303304`, 0.9359675285109096]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[337, 0.0315874366232787], {
             RGBColor[
             0.860210700141258, 0.8913726787679522, 0.9865288585702724]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[338, 0.0315874366232787], {
             RGBColor[
             0.32010532781399464`, 0.4516808788160655, 0.9416178063236486]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[339, 0.0315874366232787], {
             RGBColor[
             0.21169068579341777`, 0.33983071110654267`, 0.9353668434364056]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[340, 0.0315874366232787], {
             RGBColor[
             0.3374345618861965, 0.46669059037677707`, 0.9427220097950892]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[341, 0.0315874366232787], {
             RGBColor[
             0.9935733711383794, 0.9886624156338708, 0.5418792928476311]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[342, 0.0315874366232787], {
             RGBColor[
             0.25998714329821626`, 0.39059335011635443`, 0.9381172552430979]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[343, 0.0315874366232787], {
             RGBColor[
             0.29288750827080284`, 0.425173719706164, 0.9399908823565584]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[344, 0.0315874366232787], {
             RGBColor[
             0.4637429804071734, 0.5755264687345587, 0.9509266926456142]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[345, 0.0315874366232787], {
             RGBColor[
             0.6597251945044771, 0.7341016031348642, 0.9667188999718916]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[346, 0.0315874366232787], {
             RGBColor[
             0.21788265672664042`, 0.34633886515099205`, 0.9357194670208525]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[347, 0.0315874366232787], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[348, 0.0315874366232787], {
             RGBColor[
             0.9599116097125079, 0.876434587737939, 0.29876460310071706`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[349, 0.0315874366232787], {
             RGBColor[
             0.41360147005439724`, 0.5326625379719564, 0.9475752978318146]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[350, 0.0315874366232787], {
             RGBColor[
             0.3621699928109498, 0.4881151774048913, 0.9442981295809318]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[351, 0.0315874366232787], {
             RGBColor[
             0.290045450304657, 0.422186536586862, 0.9398290313598343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[352, 0.0315874366232787], {
             RGBColor[
             0.2278308941861094, 0.35679509347557953`, 0.9362860044270709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[353, 0.0315874366232787], {
             RGBColor[
             0.6396625402707171, 0.7183458925176417, 0.9647757248126534]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[354, 0.0315874366232787], {
             RGBColor[
             0.3617638436367253, 0.48776339140382907`, 0.9442722501146938]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[355, 0.0315874366232787], {
             RGBColor[
             0.32870680276015046`, 0.45913104409172456`, 0.942165884701232]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[356, 0.0315874366232787], {
             RGBColor[
             0.26933793088281155`, 0.4004216207419397, 0.9386497687627899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[357, 0.0315874366232787], {
             RGBColor[
             0.9071422836282599, 0.6695571281253704, 0.2441427056377997]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[358, 0.0315874366232787], {
             RGBColor[
             0.22562621270692998`, 0.3544778334560826, 0.9361604510783655]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[359, 0.0315874366232787], {
             RGBColor[
             0.38545126270191343`, 0.5082802432337956, 0.9457815915115654]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[360, 0.0315874366232787], {
             RGBColor[
             0.5793663225363243, 0.6693947066472076, 0.9600289856802787]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[361, 0.0315874366232787], {
             RGBColor[
             0.6442014475594858, 0.7219743340365904, 0.9651716379540781]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[362, 0.0315874366232787], {
             RGBColor[
             0.38846154058520777`, 0.5108875946353395, 0.9459734037564047]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[363, 0.0315874366232787], {
             RGBColor[
             0.40481135748628755`, 0.5250489842693634, 0.9470151996317661]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[364, 0.0315874366232787], {
             RGBColor[
             0.2585666750316088, 0.38910034790526005`, 0.938036361676709]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[365, 0.0315874366232787], {
             RGBColor[
             0.2169746648251472, 0.34538450809251103`, 0.9356677582253161]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[366, 0.0315874366232787], {
             RGBColor[
             0.2650062967491503, 0.3958687986259951, 0.9384030886069564]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[367, 0.0315874366232787], {
             RGBColor[
             0.2298450608433424, 0.3589121103378734, 0.9364007082385077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[368, 0.0315874366232787], {
             RGBColor[
             0.4081016499818632, 0.5278988702541217, 0.9472248541600927]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[369, 0.0315874366232787], {
             RGBColor[
             0.4199474238450335, 0.5381590841884939, 0.9479796563958474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[370, 0.0315874366232787], {
             RGBColor[
             0.591443337591513, 0.6791993715323379, 0.960979732544987]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[371, 0.0315874366232787], {
             RGBColor[
             0.36294391873403165`, 0.48878551314081686`, 0.9443474434563948]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[372, 0.0315874366232787], {
             RGBColor[
             0.4704530721178047, 0.5809740234714359, 0.951454935644951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[373, 0.0315874366232787], {
             RGBColor[
             0.293615491872952, 0.425938876628849, 0.9400323399457455]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[374, 0.0315874366232787], {
             RGBColor[
             0.2517303220687306, 0.38191490749146234`, 0.937647041488951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[375, 0.0315874366232787], {
             RGBColor[
             0.9582014383733062, 0.9683472816944506, 0.9556382414098691]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[376, 0.0315874366232787], {
             RGBColor[
             0.2794551004482275, 0.4110554074207916, 0.9392259266025292]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[377, 0.0315874366232787], {
             RGBColor[
             0.9811051107342013, 0.9854288030398846, 0.9168682983373343]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[378, 0.0315874366232787], {
             RGBColor[
             0.2830844261537786, 0.4148700588498662, 0.9394326113323542]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[379, 0.0315874366232787], {
             RGBColor[
             0.3092991992760449, 0.442321153408306, 0.9409292493686947]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[380, 0.0315874366232787], {
             RGBColor[
             0.27285106149406285`, 0.4041141437597107, 0.9388498363538897]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[381, 0.0315874366232787], {
             RGBColor[
             0.5693048020656428, 0.6612263110627765, 0.9592369059322629]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[382, 0.0315874366232787], {
             RGBColor[
             0.28222469603460637`, 0.4139664279845783, 0.9393836509739241]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[383, 0.0315874366232787], {
             RGBColor[
             0.32894252042405586`, 0.45933521088468515`, 0.942180904422339]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[384, 0.0315874366232787], {
             RGBColor[
             0.28382079992875175`, 0.41564403437615693`, 0.9394745467294715]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[385, 0.0315874366232787], {
             RGBColor[
             0.2334715870925415, 0.36272381936082626`, 0.9366072335434348]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[386, 0.0315874366232787], {
             RGBColor[0.178927, 0.305394, 0.933501]}, StripOnInput -> False], 
           StyleBox[
            DiskBox[387, 0.0315874366232787], {
             RGBColor[
             0.7751138064478154, 0.8242440637709316, 0.9782197584425172]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[388, 0.0315874366232787], {
             RGBColor[
             0.9461721011462925, 0.9593758216867757, 0.9760007715815773]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[389, 0.0315874366232787], {
             RGBColor[
             0.2184997826909155, 0.34698750366749115`, 0.9357546114315619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[390, 0.0315874366232787], {
             RGBColor[
             0.30075346730669683`, 0.43344134138349677`, 0.9404388370870089]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[391, 0.0315874366232787], {
             RGBColor[
             0.2411272273904176, 0.370770382709524, 0.937043210932894]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[392, 0.0315874366232787], {
             RGBColor[
             0.3060013924465708, 0.4389572434431762, 0.9407376986601153]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[393, 0.0315874366232787], {
             RGBColor[
             0.4612114846587171, 0.5734712864433781, 0.9507274040271213]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[394, 0.0315874366232787], {
             RGBColor[
             0.22864247952174482`, 0.3576481211208147, 0.9363322230113024]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[395, 0.0315874366232787], {
             RGBColor[
             0.26498757281889074`, 0.39584911858812655`, 0.9384020223068277]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[396, 0.0315874366232787], {
             RGBColor[
             0.9935460613341791, 0.9886040027241311, 0.5389067891970045]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[397, 0.0315874366232787], {
             RGBColor[
             0.3585480532796543, 0.48497803542685713`, 0.944067342796753]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[398, 0.0315874366232787], {
             RGBColor[
             0.26115105564507934`, 0.3918166957892125, 0.9381835383293976]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[399, 0.0315874366232787], {
             RGBColor[
             0.24150095424043594`, 0.3711631933245442, 0.9370644941241232]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[400, 0.0315874366232787], {
             RGBColor[
             0.295921828646773, 0.42836298280833224`, 0.9401636824130951]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[401, 0.0315874366232787], {
             RGBColor[
             0.7734523776791622, 0.8229461429895335, 0.9780541627497925]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[402, 0.0315874366232787], {
             RGBColor[
             0.5523112332770156, 0.6474301663686192, 0.9578991099477285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[403, 0.0315874366232787], {
             RGBColor[
             0.9289119756027943, 0.9461532109745376, 0.9930816475541463]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[404, 0.0315874366232787], {
             RGBColor[
             0.2134483076486736, 0.3416780831160786, 0.9354669374008939]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[405, 0.0315874366232787], {
             RGBColor[
             0.9940126833910108, 0.9896020601209673, 0.5896957204256101]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[406, 0.0315874366232787], {
             RGBColor[
             0.990618380894789, 0.9800157372285142, 0.4180546106567104]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[407, 0.0315874366232787], {
             RGBColor[
             0.21435834209939697`, 0.3426345870233057, 0.9355187625165873]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[408, 0.0315874366232787], {
             RGBColor[
             0.2225045334786326, 0.3511967506612473, 0.9359826760644245]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[409, 0.0315874366232787], {
             RGBColor[
             0.24155566178660715`, 0.3712206944242289, 0.937067609637945]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[410, 0.0315874366232787], {
             RGBColor[
             0.36366501242205085`, 0.4894100882501565, 0.9443933909085572]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[411, 0.0315874366232787], {
             RGBColor[
             0.23958996446517072`, 0.3691546219069906, 0.9369556660834778]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[412, 0.0315874366232787], {
             RGBColor[
             0.2423814866745967, 0.372088688741828, 0.9371146391436176]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[413, 0.0315874366232787], {
             RGBColor[
             0.97383602535665, 0.9234049113139019, 0.35285832847295656`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[414, 0.0315874366232787], {
             RGBColor[
             0.2746579678933065, 0.4060133169497984, 0.9389527370002482]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[415, 0.0315874366232787], {
             RGBColor[
             0.2870126862041934, 0.4189989092289247, 0.9396563199308854]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[416, 0.0315874366232787], {
             RGBColor[
             0.26153368469451344`, 0.39221886318025073`, 0.938205328487714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[417, 0.0315874366232787], {
             RGBColor[
             0.7010326627105, 0.7663713112457954, 0.9708360423624304]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[418, 0.0315874366232787], {
             RGBColor[
             0.978473490691829, 0.9834661451211657, 0.9213229446326382]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[419, 0.0315874366232787], {
             RGBColor[
             0.5126905354832046, 0.6152642990075083, 0.9547800234820015]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[420, 0.0315874366232787], {
             RGBColor[
             0.96864282965107, 0.9761344542131977, 0.9379636895276074]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[421, 0.0315874366232787], {
             RGBColor[
             0.17905660578117066`, 0.3055302238934915, 0.9335083808575031]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[422, 0.0315874366232787], {
             RGBColor[
             0.23401200432651914`, 0.3632918321381684, 0.9366380095054342]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[423, 0.0315874366232787], {
             RGBColor[
             0.18782589147201245`, 0.31474729915939237`, 0.9340077787046009]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[424, 0.0315874366232787], {
             RGBColor[
             0.3205944320155112, 0.4521045162923272, 0.9416489716108714]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[425, 0.0315874366232787], {
             RGBColor[
             0.37534284954540054`, 0.499524843821242, 0.9451374923637511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[426, 0.0315874366232787], {
             RGBColor[
             0.8701743928884773, 0.8993174569073501, 0.9874792044791957]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[427, 0.0315874366232787], {
             RGBColor[
             0.2795001276110678, 0.4111027338238238, 0.9392284908328413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[428, 0.0315874366232787], {
             RGBColor[
             0.8303334960184631, 0.23416211938642656`, 0.1766806960850511]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[429, 0.0315874366232787], {
             RGBColor[
             0.29359796730781346`, 0.4259204571997668, 0.9400313419476861]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[430, 0.0315874366232787], {
             RGBColor[
             0.23973902577549727`, 0.36931129479517677`, 0.9369641549045845]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[431, 0.0315874366232787], {
             RGBColor[
             0.4485399301016759, 0.5629244760068475, 0.9498015456111601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[432, 0.0315874366232787], {
             RGBColor[
             0.898624468927386, 0.9220027752840345, 0.9901927981294695]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[433, 0.0315874366232787], {
             RGBColor[
             0.32550625142704326`, 0.4563588873913744, 0.9419619484004228]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[434, 0.0315874366232787], {
             RGBColor[
             0.9912025783926344, 0.990630054329001, 0.7954595732387495]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[435, 0.0315874366232787], {
             RGBColor[
             0.25811768357221787`, 0.3886284294137375, 0.93801079227732]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[436, 0.0315874366232787], {
             RGBColor[
             0.472919813782261, 0.5829766354800872, 0.9516491265847494]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[437, 0.0315874366232787], {
             RGBColor[
             0.2558304623203871, 0.3862244148598601, 0.9378805384106689]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[438, 0.0315874366232787], {
             RGBColor[
             0.22146455698209894`, 0.3501036694250721, 0.9359234509414543]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[439, 0.0315874366232787], {
             RGBColor[
             0.8609124841587944, 0.891932262294116, 0.986595795356355]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[440, 0.0315874366232787], {
             RGBColor[
             0.28167383897512416`, 0.41338744228870766`, 0.9393522804793065]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[441, 0.0315874366232787], {
             RGBColor[
             0.4501324018566838, 0.5643037950010776, 0.9499030165032217]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[442, 0.0315874366232787], {
             RGBColor[
             0.28394532564135605`, 0.4157749187954902, 0.9394816382845851]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[443, 0.0315874366232787], {
             RGBColor[
             0.9345119801701037, 0.7780688545030732, 0.2661650059247154]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[444, 0.0315874366232787], {
             RGBColor[
             0.27129304719779485`, 0.4024765719505212, 0.9387611097445928]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[445, 0.0315874366232787], {
             RGBColor[
             0.22963931784821143`, 0.3586958614051314, 0.9363889914793045]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[446, 0.0315874366232787], {
             RGBColor[
             0.22815127331601265`, 0.3571318322543179, 0.9363042495445604]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[447, 0.0315874366232787], {
             RGBColor[
             0.2464999471451923, 0.3764174518218997, 0.9373491793747017]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[448, 0.0315874366232787], {
             RGBColor[
             0.5679393142918087, 0.6601177465734548, 0.9591294097327601]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[449, 0.0315874366232787], {
             RGBColor[
             0.7283027762348872, 0.7876749311915857, 0.9735540724248413]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[450, 0.0315874366232787], {
             RGBColor[
             0.8177084834502429, 0.13712074047130335`, 0.1645909697918113]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[451, 0.0315874366232787], {
             RGBColor[
             0.21144581794704176`, 0.3395733394744833, 0.935352898574804]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[452, 0.0315874366232787], {
             RGBColor[
             0.22395342458252596`, 0.35271962707644106`, 0.936065188269349]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[453, 0.0315874366232787], {
             RGBColor[
             0.2843068325272902, 0.41615488545346746`, 0.9395022255669375]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[454, 0.0315874366232787], {
             RGBColor[
             0.8998824261938122, 0.6382713050470934, 0.23817178112086787`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[455, 0.0315874366232787], {
             RGBColor[
             0.20394063923757638`, 0.33168492079502093`, 0.9349254897502168]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[456, 0.0315874366232787], {
             RGBColor[
             0.22365852866224617`, 0.35240967276674573`, 0.9360483943829485]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[457, 0.0315874366232787], {
             RGBColor[
             0.22158907133489145`, 0.35023454190452297`, 0.9359305418496434]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[458, 0.0315874366232787], {
             RGBColor[
             0.2304992557221517, 0.359599710633853, 0.9364379636690613]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[459, 0.0315874366232787], {
             RGBColor[
             0.3905461178527888, 0.5126931506906183, 0.9461062311765757]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[460, 0.0315874366232787], {
             RGBColor[
             0.24834625332605567`, 0.3783580366805602, 0.9374543237803367]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[461, 0.0315874366232787], {
             RGBColor[
             0.944455505750549, 0.9580955876512972, 0.9789065198267879]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[462, 0.0315874366232787], {
             RGBColor[
             0.46387836533310084`, 0.575636380316448, 0.9509373506429145]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[463, 0.0315874366232787], {
             RGBColor[
             0.2670973610782935, 0.3980666398170606, 0.9385221716270487]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[464, 0.0315874366232787], {
             RGBColor[
             0.24386676324271586`, 0.3736498085868948, 0.9371992234469022]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[465, 0.0315874366232787], {
             RGBColor[
             0.28262558218412137`, 0.4143877847453685, 0.939406480847081]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[466, 0.0315874366232787], {
             RGBColor[
             0.503508173143364, 0.6078096435993164, 0.9540571542825077]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[467, 0.0315874366232787], {
             RGBColor[
             0.7068391686146014, 0.7709073977891587, 0.9714147806060683]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[468, 0.0315874366232787], {
             RGBColor[
             0.4783770236668791, 0.5874070443089239, 0.952078738137285]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[469, 0.0315874366232787], {
             RGBColor[
             0.8604306779796645, 0.4591301305965446, 0.20525227536014304`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[470, 0.0315874366232787], {
             RGBColor[
             0.25548210733168075`, 0.3858582716797478, 0.937860700109407]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[471, 0.0315874366232787], {
             RGBColor[
             0.8568125830318801, 0.4376919853814662, 0.20203709971295072`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[472, 0.0315874366232787], {
             RGBColor[
             0.32844671668737896`, 0.45890577060779597`, 0.9421493122466601]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[473, 0.0315874366232787], {
             RGBColor[
             0.32683125980079797`, 0.4575065430478635, 0.9420463767623395]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[474, 0.0315874366232787], {
             RGBColor[
             0.9930971542734537, 0.9914135101440991, 0.7640615478883636]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[475, 0.0315874366232787], {
             RGBColor[
             0.839003391040872, 0.30080273170088523`, 0.1849829973497558]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[476, 0.0315874366232787], {
             RGBColor[
             0.8484924274103163, 0.3737396233586853, 0.19406970929346942`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[477, 0.0315874366232787], {
             RGBColor[
             0.24467162743864543`, 0.3744957718881542, 0.9372450592721705]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[478, 0.0315874366232787], {
             RGBColor[
             0.2660419428822219, 0.39695732837561076`, 0.9384620671221336]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[479, 0.0315874366232787], {
             RGBColor[
             0.41149067372934756`, 0.5308342722869064, 0.9474407997564864]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[480, 0.0315874366232787], {
             RGBColor[
             0.35354723518652786`, 0.48064657814301665`, 0.9437486950899088]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[481, 0.0315874366232787], {
             RGBColor[
             0.318216697210702, 0.4500450419128276, 0.9414974644516573]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[482, 0.0315874366232787], {
             RGBColor[
             0.35848143845973107`, 0.48492033701799786`, 0.9440630981593326]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[483, 0.0315874366232787], {
             RGBColor[
             0.29664917161590876`, 0.42912746638510174`, 0.9402051035191799]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[484, 0.0315874366232787], {
             RGBColor[
             0.9928916986278599, 0.9872043870615327, 0.4676834468726777]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[485, 0.0315874366232787], {
             RGBColor[
             0.24800119075484597`, 0.3779953540399882, 0.9374346729773807]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[486, 0.0315874366232787], {
             RGBColor[
             0.9349275982881982, 0.9509499052141509, 0.9936554230160899]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[487, 0.0315874366232787], {
             RGBColor[
             0.5794313774456323, 0.6694475211532741, 0.9600341070410434]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[488, 0.0315874366232787], {
             RGBColor[
             0.7693643004981994, 0.8197525060252281, 0.9776467014216474]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[489, 0.0315874366232787], {
             RGBColor[
             0.9900975943251971, 0.9901731150203205, 0.8137720188432849]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[490, 0.0315874366232787], {
             RGBColor[
             0.9905535588776926, 0.9903616680805318, 0.806215506209998]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[491, 0.0315874366232787], {
             RGBColor[
             0.9941614319695004, 0.9899202182895682, 0.6058860852243823]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[492, 0.0315874366232787], {
             RGBColor[
             0.2766193131480329, 0.4080748151689876, 0.9390644327109545]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[493, 0.0315874366232787], {
             RGBColor[
             0.9935772608954081, 0.9886707354308406, 0.5423026688954158]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[494, 0.0315874366232787], {
             RGBColor[
             0.2585035332044634, 0.3890339818415072, 0.938032765843063]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[495, 0.0315874366232787], {
             RGBColor[
             0.8422024713778844, 0.3253922650171049, 0.18804644029332332`]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[496, 0.0315874366232787], {
             RGBColor[
             0.27688954314442643`, 0.4083588440287685, 0.9390798219094797]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[497, 0.0315874366232787], {
             RGBColor[
             0.23599364281048124`, 0.36537465982794926`, 0.9367508608855244]},
             StripOnInput -> False], 
           StyleBox[
            DiskBox[498, 0.0315874366232787], {
             RGBColor[
             0.46188951150763047`, 0.5740217391840874, 0.9507807807843619]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[499, 0.0315874366232787], {
             RGBColor[
             0.2607186377132893, 0.3913621971260208, 0.9381589127678872]}, 
            StripOnInput -> False], 
           StyleBox[
            DiskBox[500, 0.0315874366232787], {
             RGBColor[
             0.8194926622925333, 0.15083472088530037`, 0.16629950146613023`]},
             StripOnInput -> False]}}]], 
       MouseAppearanceTag["NetworkGraphics"]], AllowKernelInitialization -> 
      False]], {
    FormatType -> TraditionalForm, FrameTicks -> None, ImageSize -> 500, 
     DefaultBaseStyle -> {
      "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.8, 1., 0.6]}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{{3.8349502435193233`*^9, 3.8349502581408367`*^9}, 
   3.834950528174912*^9, 3.8349578088972807`*^9, 3.835018923470682*^9, 
   3.835019026079196*^9, 3.8350205603927774`*^9, 3.835044649527498*^9, 
   3.835045037805329*^9, 3.8350457183729286`*^9, 3.8350525336615086`*^9},
 CellLabel->
  "Out[431]=",ExpressionUUID->"b64f6cef-4c7c-45c1-9fcb-f1f9df447d11"]
}, Open  ]],

Cell["r = 3 :", "Text",
 CellChangeTimes->{{3.834793779215767*^9, 3.8347938725231647`*^9}, {
  3.8347953347101345`*^9, 3.8347953431477337`*^9}, {3.8348851911359825`*^9, 
  3.83488519180678*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"b0d575ad-88b6-4cde-bc55-58ee1221808c"],

Cell["Cubic Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.834795179278664*^9}},ExpressionUUID->"0797f309-59bb-406b-aba5-\
ca64122cc757"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c\[Rho]3if5", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"CMDi3f500", ",", "krif5"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.834947911760502*^9, 
   3.834947914304406*^9}, {3.834947957535968*^9, 3.8349479704802837`*^9}, {
   3.8349480487781425`*^9, 3.834948105065866*^9}, {3.8349497992119355`*^9, 
   3.83494980454772*^9}, {3.8349578354451995`*^9, 3.83495784069214*^9}, {
   3.835018838991932*^9, 3.8350188405169106`*^9}, {3.8350443590646524`*^9, 
   3.8350443609005165`*^9}, {3.835044949683157*^9, 3.8350449510226583`*^9}, {
   3.8350456161573725`*^9, 3.8350456174929495`*^9}, {3.8350524654368067`*^9, 
   3.835052466487562*^9}},
 CellLabel->
  "In[432]:=",ExpressionUUID->"f9c7adb1-c5c3-412b-9beb-77b400e21f00"],

Cell[BoxData[
 RowBox[{"-", "0.09768342582313294`"}]], "Output",
 CellChangeTimes->{
  3.834948013482303*^9, {3.834948049945756*^9, 3.834948058990469*^9}, 
   3.8349481059508953`*^9, 3.8349499476386404`*^9, 3.834957841643118*^9, 
   3.8350189236386824`*^9, 3.8350190270322647`*^9, 3.8350204164650445`*^9, 
   3.8350205609787445`*^9, 3.8350446521595054`*^9, 3.835045038186325*^9, 
   3.835045719133933*^9, 3.835052534305168*^9},
 CellLabel->
  "Out[432]=",ExpressionUUID->"7b0ad2fa-2520-4f91-a719-79284eacdd74"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CP3if5", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"CMDi3f500", ",", "krif5"}], "}"}], "]"}], ",", "c\[Rho]3if5"}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.8349481210775223`*^9, 3.834948150679065*^9}, {
  3.8349481924167476`*^9, 3.8349481986802473`*^9}, {3.834949807949147*^9, 
  3.834949815491851*^9}, {3.8349578438231587`*^9, 3.8349578533989754`*^9}, {
  3.835018846742407*^9, 3.835018849961266*^9}, {3.835044361707146*^9, 
  3.835044363446494*^9}, {3.835044955607832*^9, 3.835044963462711*^9}, {
  3.835045618283763*^9, 3.835045620325021*^9}, {3.8350524669710407`*^9, 
  3.83505246823155*^9}},
 CellLabel->
  "In[433]:=",ExpressionUUID->"6b99df1d-9388-4ff5-adfb-3183e26dc2cb"],

Cell[BoxData["0.15072820720856994`"], "Output",
 CellChangeTimes->{3.8349481513130674`*^9, 3.8349482002632475`*^9, 
  3.8349499490044084`*^9, 3.8349578559445095`*^9, 3.83501892389968*^9, 
  3.8350190272812295`*^9, 3.8350205613687525`*^9, 3.8350446533657885`*^9, 
  3.835045038277321*^9, 3.8350457193059344`*^9, 3.8350525343431606`*^9},
 CellLabel->
  "Out[433]=",ExpressionUUID->"be2cbbbe-de99-40d4-a745-d833b6f32423"]
}, Open  ]],

Cell["Absolute Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.8347951985065947`*^9}},ExpressionUUID->"260e0f10-2a61-49c5-8fb3-\
7a279b27c15d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a\[Rho]3if5", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"AMDi3f500", ",", "krif5"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.8348873709111376`*^9, 
   3.8348873755217657`*^9}, {3.8349481641806583`*^9, 
   3.8349481824982553`*^9}, {3.834949818653184*^9, 3.8349498238056817`*^9}, {
   3.834957866337153*^9, 3.834957872254816*^9}, {3.8350188531986103`*^9, 
   3.8350188546829796`*^9}, {3.8350443646261296`*^9, 3.835044365855239*^9}, {
   3.8350449644881577`*^9, 3.8350449665516605`*^9}, {3.83504562436516*^9, 
   3.835045625597438*^9}, {3.835052468787411*^9, 3.8350524696959124`*^9}},
 CellLabel->
  "In[434]:=",ExpressionUUID->"4cb0c768-0e43-4282-8eda-0a0666d9c876"],

Cell[BoxData[
 RowBox[{"-", "0.058904243019805166`"}]], "Output",
 CellChangeTimes->{3.834948182946122*^9, 3.83494995054953*^9, 
  3.834957874365346*^9, 3.835018924320698*^9, 3.8350190275072393`*^9, 
  3.8350205614078007`*^9, 3.835044655427159*^9, 3.8350450383643217`*^9, 
  3.8350457194749312`*^9, 3.8350525343821597`*^9},
 CellLabel->
  "Out[434]=",ExpressionUUID->"718b24e9-2a8d-42fa-bdd2-77e4fa41c524"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"aP3if5", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"AMDi3f500", ",", "krif5"}], "}"}], "]"}], ",", "a\[Rho]3if5"}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8349482041094093`*^9, 
  3.8349482202691827`*^9}, {3.8349498269490285`*^9, 3.8349498405604887`*^9}, {
  3.8349578796796703`*^9, 3.834957886620027*^9}, {3.8350188593392305`*^9, 
  3.835018861313801*^9}, {3.8350443665470304`*^9, 3.835044368736087*^9}, {
  3.835044972843706*^9, 3.835044975243416*^9}, {3.835045628307909*^9, 
  3.835045630410689*^9}, {3.83505247013124*^9, 3.8350524712845163`*^9}},
 CellLabel->
  "In[435]:=",ExpressionUUID->"06ecd2cb-083b-4fe0-a3d6-ac93903d0620"],

Cell[BoxData["0.3574910397640851`"], "Output",
 CellChangeTimes->{3.834887440036944*^9, 3.8349482220989213`*^9, 
  3.8349499520491343`*^9, 3.8349578874036503`*^9, 3.83501892439668*^9, 
  3.8350190277232385`*^9, 3.8350205614517555`*^9, 3.8350446570245705`*^9, 
  3.8350450384513245`*^9, 3.8350457196659327`*^9, 3.835052534421158*^9},
 CellLabel->
  "Out[435]=",ExpressionUUID->"eb97c611-3ea4-4622-9bae-bedcb90e0541"]
}, Open  ]],

Cell["Max-min Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 3.8347951985065947`*^9}, {
  3.8348543263190746`*^9, 
  3.834854330052075*^9}},ExpressionUUID->"a7582b8d-005c-44f6-ab0c-\
6a4bb849c603"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mM\[Rho]3if5", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"mMDi3f500", ",", "krif5"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8348874651734295`*^9, 3.8348874872060013`*^9}, {
  3.8349482319487157`*^9, 3.834948245258479*^9}, {3.834949844516972*^9, 
  3.8349498489188633`*^9}, {3.834957895209076*^9, 3.834957899999796*^9}, {
  3.83501886583329*^9, 3.835018866821826*^9}, {3.835044369483486*^9, 
  3.835044370515362*^9}, {3.8350449764211473`*^9, 3.835044978468176*^9}, {
  3.835045634374282*^9, 3.8350456358208165`*^9}, {3.8350524717668295`*^9, 
  3.8350524725594673`*^9}},
 CellLabel->
  "In[436]:=",ExpressionUUID->"afd9d082-0fe4-4a91-9c79-e1d2fb860092"],

Cell[BoxData[
 RowBox[{"-", "0.06463503658581818`"}]], "Output",
 CellChangeTimes->{3.834948246413353*^9, 3.834949953689977*^9, 
  3.834957900696502*^9, 3.835018924463678*^9, 3.835019027994238*^9, 
  3.835020561490786*^9, 3.8350446585457473`*^9, 3.8350450385433226`*^9, 
  3.835045719831933*^9, 3.835052534460176*^9},
 CellLabel->
  "Out[436]=",ExpressionUUID->"297c8970-6464-4203-999a-c029758da62f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mMP3if5", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"mMDi3f500", ",", "krif5"}], "}"}], "]"}], ",", 
    "mM\[Rho]3if5"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8348875260806427`*^9, 
  3.8348875488478312`*^9}, {3.8349482525846663`*^9, 3.8349482707073736`*^9}, {
  3.8349498532537427`*^9, 3.834949860995207*^9}, {3.834957902898573*^9, 
  3.8349579090270967`*^9}, {3.8350188699780455`*^9, 3.835018871634328*^9}, {
  3.835044378315168*^9, 3.8350443808084726`*^9}, {3.8350449818572917`*^9, 
  3.835044984227113*^9}, {3.835045639089673*^9, 3.835045640972607*^9}, {
  3.8350524729815626`*^9, 3.835052474235222*^9}},
 CellLabel->
  "In[437]:=",ExpressionUUID->"251515f5-61af-43a2-8ec8-e2663a4acc9c"],

Cell[BoxData["0.09900417772604066`"], "Output",
 CellChangeTimes->{3.834887440036944*^9, 3.8348875533996215`*^9, 
  3.834948277702903*^9, 3.834949955989804*^9, 3.834957909480212*^9, 
  3.835018924542716*^9, 3.835019028341303*^9, 3.8350205615287514`*^9, 
  3.835044659514542*^9, 3.835045038636324*^9, 3.8350457200229316`*^9, 
  3.835052534497158*^9},
 CellLabel->
  "Out[437]=",ExpressionUUID->"02edb4a2-66ae-451b-8405-a0a92c684eab"]
}, Open  ]],

Cell["r = 6 :", "Text",
 CellChangeTimes->{{3.834793779215767*^9, 3.8347938725231647`*^9}, {
  3.8347953347101345`*^9, 3.8347953431477337`*^9}, {3.8348851911359825`*^9, 
  3.83488519180678*^9}, {3.834948305866973*^9, 3.8349483068980722`*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"0a1dd4fd-236a-427f-a97f-64b0a01b29cf"],

Cell["Cubic Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.834795179278664*^9}},ExpressionUUID->"5a00c62b-9a8a-464a-adac-\
425bca45a808"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c\[Rho]6if5", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"CMDi6f500", ",", "krif5"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.834947911760502*^9, 
   3.834947914304406*^9}, {3.834947957535968*^9, 3.8349479704802837`*^9}, {
   3.8349480487781425`*^9, 3.834948105065866*^9}, {3.8349483158342133`*^9, 
   3.8349483193845987`*^9}, {3.834949864783629*^9, 3.834949869574106*^9}, {
   3.834957963470776*^9, 3.834957967378231*^9}, {3.835018875109179*^9, 
   3.8350188762029247`*^9}, {3.83504438203627*^9, 3.8350443836235657`*^9}, {
   3.8350449852346697`*^9, 3.8350449865535607`*^9}, {3.835045642906684*^9, 
   3.835045644449538*^9}, {3.8350524750019293`*^9, 3.835052475843653*^9}},
 CellLabel->
  "In[438]:=",ExpressionUUID->"2308873d-a376-4e90-8b48-ca3a8dea80a2"],

Cell[BoxData[
 RowBox[{"-", "0.011086409897663789`"}]], "Output",
 CellChangeTimes->{
  3.834948013482303*^9, {3.834948049945756*^9, 3.834948058990469*^9}, 
   3.8349481059508953`*^9, 3.834948360850016*^9, 3.8349499580565577`*^9, 
   3.834957967763415*^9, 3.835018924610717*^9, 3.835019028526283*^9, 
   3.8350205615657897`*^9, 3.835044661527397*^9, 3.8350450387243443`*^9, 
   3.8350457201739283`*^9, 3.835052534539158*^9},
 CellLabel->
  "Out[438]=",ExpressionUUID->"3ed10323-5ece-4072-8173-735a4f386611"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CP6if5", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"CMDi6f500", ",", "krif5"}], "}"}], "]"}], ",", "c\[Rho]6if5"}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.8349481210775223`*^9, 3.834948150679065*^9}, {
  3.8349481924167476`*^9, 3.8349481986802473`*^9}, {3.8349483230197706`*^9, 
  3.834948338654296*^9}, {3.8349498724373255`*^9, 3.8349498802583637`*^9}, {
  3.8349579696959915`*^9, 3.834957975592292*^9}, {3.8350188769841766`*^9, 
  3.835018878671647*^9}, {3.835044384544117*^9, 3.8350443867509155`*^9}, {
  3.8350449903821464`*^9, 3.83504499270442*^9}, {3.835045647655678*^9, 
  3.835045649855909*^9}, {3.8350524763439903`*^9, 3.835052477847539*^9}},
 CellLabel->
  "In[439]:=",ExpressionUUID->"ed955bb8-6a8d-4574-99fe-96256fa66e01"],

Cell[BoxData["0.03198064965710059`"], "Output",
 CellChangeTimes->{3.8350446625455046`*^9, 3.8350450388173184`*^9, 
  3.835045720313956*^9, 3.8350525345771556`*^9},
 CellLabel->
  "Out[439]=",ExpressionUUID->"1c35d6dc-a253-4204-8520-8b4a900145cc"]
}, Open  ]],

Cell["Absolute Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 
  3.8347951985065947`*^9}},ExpressionUUID->"60ee2af0-34d0-4717-9e1b-\
0ef63c91f7b0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a\[Rho]6if5", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"AMDi6f500", ",", "krif5"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347948741047115`*^9, 3.8347948842254996`*^9}, 
   3.83479494428444*^9, {3.8347960972430334`*^9, 3.8347960995872955`*^9}, {
   3.834796579728179*^9, 3.834796585007918*^9}, {3.834885972793435*^9, 
   3.8348859877856927`*^9}, {3.8348866210202756`*^9, 
   3.8348866504482265`*^9}, {3.8348867874906125`*^9, 3.834886788330391*^9}, {
   3.834886866459461*^9, 3.834886867617876*^9}, {3.8348873709111376`*^9, 
   3.8348873755217657`*^9}, {3.8349481641806583`*^9, 
   3.8349481824982553`*^9}, {3.834948329127375*^9, 3.834948332212267*^9}, {
   3.834949883458797*^9, 3.8349498875077024`*^9}, {3.834957978394422*^9, 
   3.8349579827581863`*^9}, {3.8350188795779624`*^9, 3.83501888042175*^9}, {
   3.8350443900912123`*^9, 3.835044391591655*^9}, {3.8350449954828196`*^9, 
   3.835044996992873*^9}, {3.8350456507829885`*^9, 3.8350456521119957`*^9}, {
   3.8350524789095564`*^9, 3.835052480153077*^9}},
 CellLabel->
  "In[440]:=",ExpressionUUID->"9051f365-6970-411a-b8e7-cd4400e89593"],

Cell[BoxData[
 RowBox[{"-", "0.014468951813618042`"}]], "Output",
 CellChangeTimes->{3.8350457204409323`*^9, 3.8350525346191597`*^9},
 CellLabel->
  "Out[440]=",ExpressionUUID->"2ac405a1-1dfe-4f75-9401-7d14ae27b1a2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"aP6if5", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"AMDi6f500", ",", "krif5"}], "}"}], "]"}], ",", "a\[Rho]6if5"}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8349482041094093`*^9, 
  3.8349482202691827`*^9}, {3.834948340881687*^9, 3.834948354997751*^9}, {
  3.8349498907390194`*^9, 3.8349498979971194`*^9}, {3.8349579853563895`*^9, 
  3.8349579919125147`*^9}, {3.8350188832810483`*^9, 3.83501888448921*^9}, {
  3.835044392264258*^9, 3.835044393785404*^9}, {3.835044997778226*^9, 
  3.835044999929602*^9}, {3.8350456632120996`*^9, 3.835045665307251*^9}, {
  3.8350524806648283`*^9, 3.8350524827758384`*^9}},
 CellLabel->
  "In[441]:=",ExpressionUUID->"bcca34a8-c1c5-4b28-a3da-9dbd58cb45ab"],

Cell[BoxData["0.4256200724937032`"], "Output",
 CellChangeTimes->{3.835044665314339*^9, 3.8350450390013194`*^9, 
  3.8350457205699325`*^9, 3.8350525346601615`*^9},
 CellLabel->
  "Out[441]=",ExpressionUUID->"501226de-94f9-4465-99ec-0e0bfd8dbc53"]
}, Open  ]],

Cell["Max-min Mean Deviation estimator:", "Text",
 CellChangeTimes->{{3.834795164746212*^9, 3.8347951985065947`*^9}, {
  3.8348543263190746`*^9, 
  3.834854330052075*^9}},ExpressionUUID->"2764cd2f-3d47-4280-ab23-\
dc2e449ede26"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mM\[Rho]6if5", "=", 
  RowBox[{"Correlation", "[", 
   RowBox[{"mMDi6f500", ",", "krif5"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8348874651734295`*^9, 3.8348874872060013`*^9}, {
   3.8349482319487157`*^9, 3.834948245258479*^9}, 3.8349483527075925`*^9, {
   3.8349499042423377`*^9, 3.8349499090679235`*^9}, {3.834949978751977*^9, 
   3.8349499794842105`*^9}, {3.834957994342047*^9, 3.834957998175455*^9}, {
   3.835018886286111*^9, 3.8350188870361056`*^9}, {3.835044395189496*^9, 
   3.835044396222158*^9}, {3.8350450026406775`*^9, 3.8350450038650913`*^9}, {
   3.8350456680827856`*^9, 3.8350456693830676`*^9}, {3.8350524835921164`*^9, 
   3.835052484615823*^9}},
 CellLabel->
  "In[442]:=",ExpressionUUID->"f50ca191-6721-44d2-bf49-465dae3a5926"],

Cell[BoxData["0.03175229413312314`"], "Output",
 CellChangeTimes->{3.835044666861985*^9, 3.835045039089321*^9, 
  3.8350457207069407`*^9, 3.835052534693157*^9},
 CellLabel->
  "Out[442]=",ExpressionUUID->"38bc86d8-6479-4350-abc8-16218198fc97"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mMP6if5", "=", 
  RowBox[{"CorrelationTest", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"mMDi6f500", ",", "krif5"}], "}"}], "]"}], ",", 
    "mM\[Rho]6if5"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8347946011803427`*^9, 3.834794667666303*^9}, {
  3.8347948630410657`*^9, 3.8347948890939274`*^9}, {3.8347949285974393`*^9, 
  3.834794954250928*^9}, {3.834796606437277*^9, 3.834796626252099*^9}, {
  3.834887395461194*^9, 3.834887433281986*^9}, {3.8348875260806427`*^9, 
  3.8348875488478312`*^9}, {3.8349482525846663`*^9, 3.8349482707073736`*^9}, {
  3.83494834565068*^9, 3.8349483504716325`*^9}, {3.8349499122654495`*^9, 
  3.83494991854418*^9}, {3.834958000997678*^9, 3.8349580074869604`*^9}, {
  3.8350188877705455`*^9, 3.8350189082569094`*^9}, {3.8350443974385123`*^9, 
  3.8350443985852137`*^9}, {3.8350450046283274`*^9, 3.835045006371921*^9}, {
  3.83504567018804*^9, 3.8350456724624395`*^9}, {3.835052486629406*^9, 
  3.8350524927468295`*^9}},
 CellLabel->
  "In[443]:=",ExpressionUUID->"7b6df1b4-55a2-4501-9ae1-60ba6df5aeb3"],

Cell[BoxData["0.1550777918607116`"], "Output",
 CellChangeTimes->{
  3.834887440036944*^9, 3.8348875533996215`*^9, 3.834948277702903*^9, 
   3.8349483617580156`*^9, {3.834949965578516*^9, 3.8349499927811513`*^9}, 
   3.834958007945059*^9, 3.8350189249776793`*^9, 3.835019029685795*^9, 
   3.835020561757756*^9, 3.835044668294428*^9, 3.835045039206321*^9, 
   3.8350457208449287`*^9, 3.8350525347311606`*^9},
 CellLabel->
  "Out[443]=",ExpressionUUID->"2fa9d992-d496-4188-919d-2b4cb15ccb87"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "CP3i1", ",", "CP3i2", ",", "CP3i3", ",", "CP3i4", ",", "CP3i5"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "CP6i1", ",", "CP6i2", ",", "CP6i3", ",", "CP6i4", ",", "CP6i5"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"DataRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"100", ",", "500"}], "}"}]}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<r=3\>\"", ",", "\"\<r=6\>\""}], "}"}]}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"\"\<Number of points\>\"", ",", "\"\<Statistics\>\""}], "}"}]}],
    ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
   RowBox[{"LabelStyle", "->", 
    RowBox[{"Directive", "[", 
     RowBox[{"Bold", ",", "10"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8350564717730637`*^9, 3.835056493991911*^9}, {
  3.8350565470046515`*^9, 3.8350565673079653`*^9}, {3.835056639789656*^9, 
  3.8350567454486446`*^9}, {3.835056778832614*^9, 3.8350567929013157`*^9}, {
  3.8351710635894856`*^9, 3.8351710705370636`*^9}, {3.8351711981745596`*^9, 
  3.835171235718528*^9}, {3.835171298793245*^9, 3.835171369065301*^9}, {
  3.8351716684426775`*^9, 3.835171694234703*^9}, {3.8351719415087957`*^9, 
  3.8351719576202326`*^9}, {3.835172312193037*^9, 3.8351723285474973`*^9}, {
  3.835172399994587*^9, 3.835172422154928*^9}, {3.835172502415805*^9, 
  3.8351725628547564`*^9}, {3.835172602419756*^9, 3.835172625820222*^9}, {
  3.8351727903716116`*^9, 3.8351728231940594`*^9}, {3.835176439916732*^9, 
  3.8351764435781393`*^9}},
 CellLabel->
  "In[652]:=",ExpressionUUID->"7680870e-7919-438c-bcaf-c2ac717f1be3"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, {{{
        Directive[
         PointSize[0.012833333333333334`], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        PointBox[{{100., 0.4716972721989238}, {200., 0.018608322889665435`}, {
         300., 0.6692069610555993}, {400., 0.9160883626704704}, {500., 
         0.8703932362566628}}]}, {
        Directive[
         PointSize[0.012833333333333334`], 
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[1.6]], 
        PointBox[{{100., 0.8638748382086572}, {200., 0.204728097643479}, {
         300., 0.979413528988404}, {400., 0.5357694186642934}, {500., 
         0.7959246709538622}}]}}, {{
        Directive[
         PointSize[0.012833333333333334`], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]]}, {
        Directive[
         PointSize[0.012833333333333334`], 
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[1.6]]}, {}, {}, {}}, {{
        Directive[
         PointSize[0.012833333333333334`], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]]}, {
        Directive[
         PointSize[0.012833333333333334`], 
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[1.6]]}, {}, {}, {}}}, {{}, {}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {91.66666666666667, 0}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{
        FormBox["\"Statistics\"", TraditionalForm], None}, {
        FormBox["\"Number of points\"", TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {Automatic, Automatic}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> Large, LabelStyle -> 
     Directive[Bold, 10], 
     Method -> {
      "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{91.66666666666667, 500.}, {0, 0.979413528988404}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{"\"r=3\"", "\"r=6\""}, "PointLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          Directive[Bold, 10], FontFamily -> "Arial"}, Background -> 
         Automatic, StripOnInput -> False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"PointLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                   ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                   ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.880722`", ",", "0.611041`", ",", "0.142051`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"False", ",", "False"}], "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"Directive", "[", 
               RowBox[{"Bold", ",", "10"}], "]"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.8350567934146433`*^9, {3.8351713107092705`*^9, 3.8351713331034517`*^9}, 
   3.835171671583971*^9, {3.835171946125386*^9, 3.835171958510784*^9}, {
   3.8351723159162416`*^9, 3.8351723292086535`*^9}, {3.8351724126961403`*^9, 
   3.835172423110013*^9}, 3.835172541076111*^9, {3.835172607488418*^9, 
   3.835172613456274*^9}, {3.83517279236608*^9, 3.835172823914894*^9}, 
   3.8351729604867306`*^9, 3.8351764452091455`*^9},
 CellLabel->
  "Out[652]=",ExpressionUUID->"e24ea081-cee4-4b1f-86d8-0fd5c97d96d3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "CP3if1", ",", "CP3if2", ",", "CP3if3", ",", "CP3if4", ",", "CP3if5"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "CP6if1", ",", "CP6if2", ",", "CP6if3", ",", "CP6if4", ",", "CP6if5"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"DataRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"100", ",", "500"}], "}"}]}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<r=3\>\"", ",", "\"\<r=6\>\""}], "}"}]}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"\"\<Statistics\>\"", ",", "\"\<Statistics\>\""}], "}"}]}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
   RowBox[{"LabelStyle", "->", 
    RowBox[{"Directive", "[", 
     RowBox[{"Bold", ",", "10"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8350564717730637`*^9, 3.835056493991911*^9}, {
   3.8350565470046515`*^9, 3.8350565673079653`*^9}, {3.835056639789656*^9, 
   3.8350567454486446`*^9}, {3.835167874624673*^9, 3.835167889539089*^9}, 
   3.8351730130905952`*^9, {3.8351760365467687`*^9, 3.835176037769466*^9}, {
   3.835176364440409*^9, 3.835176385457473*^9}},
 CellLabel->
  "In[651]:=",ExpressionUUID->"2afe2790-fa94-499c-82a2-283008708e13"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, {{{
        Directive[
         PointSize[0.012833333333333334`], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        PointBox[{{100., 0.9060838435553892}, {200., 0.24335597605027323`}, {
         300., 0.403106653318984}, {400., 0.464831615337423}, {500., 
         0.15072820720856994`}}]}, {
        Directive[
         PointSize[0.012833333333333334`], 
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[1.6]], 
        PointBox[{{100., 0.9612801100230032}, {200., 0.6093067282426914}, {
         300., 0.798550491256895}, {400., 0.5514339431156465}, {500., 
         0.03198064965710059}}]}}, {{
        Directive[
         PointSize[0.012833333333333334`], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]]}, {
        Directive[
         PointSize[0.012833333333333334`], 
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[1.6]]}, {}, {}, {}}, {{
        Directive[
         PointSize[0.012833333333333334`], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]]}, {
        Directive[
         PointSize[0.012833333333333334`], 
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[1.6]]}, {}, {}, {}}}, {{}, {}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {91.66666666666667, 0}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{
        FormBox["\"Statistics\"", TraditionalForm], None}, {
        FormBox["\"Statistics\"", TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {Automatic, Automatic}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> Large, LabelStyle -> 
     Directive[Bold, 10], 
     Method -> {
      "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{91.66666666666667, 500.}, {0, 0.9612801100230032}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{"\"r=3\"", "\"r=6\""}, "PointLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          Directive[Bold, 10], FontFamily -> "Arial"}, Background -> 
         Automatic, StripOnInput -> False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"PointLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                   ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                   ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.880722`", ",", "0.611041`", ",", "0.142051`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"False", ",", "False"}], "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"Directive", "[", 
               RowBox[{"Bold", ",", "10"}], "]"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.835056495648082*^9, 3.8350565680830956`*^9, {3.8350567080871844`*^9, 
   3.835056746079985*^9}, 3.835173014102041*^9, {3.835176368511763*^9, 
   3.8351763861675444`*^9}},
 CellLabel->
  "Out[651]=",ExpressionUUID->"d2e85b79-e115-4d2a-81c5-505a7c8387d0"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1276, 717},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"12.1 for Microsoft Windows (64-bit) (March 14, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"4256cd83-d774-4045-a05f-a54ea2d1d2c3"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 2836, 66, 200, "Input",ExpressionUUID->"eb842e51-9c90-4727-971b-ccfbd0a9b74a"],
Cell[3397, 88, 952, 21, 48, "Input",ExpressionUUID->"ca56adf1-fef5-428b-84e6-2e7b7a90f391"],
Cell[4352, 111, 1564, 35, 67, "Input",ExpressionUUID->"d50c2727-a216-4d46-8186-f28e550509bf"],
Cell[5919, 148, 1981, 46, 75, "Input",ExpressionUUID->"12e46183-5ac1-4f41-b467-2f2fdeac168f"],
Cell[7903, 196, 1415, 38, 67, "Input",ExpressionUUID->"4e3a3c3a-3dcc-44de-a5d8-bb9510c47c82"],
Cell[9321, 236, 488, 13, 32, "Input",ExpressionUUID->"988d43ab-1e6f-4ec1-8823-fe374c6e654d"],
Cell[9812, 251, 1108, 28, 48, "Input",ExpressionUUID->"e76ed9f6-95dd-4e08-9045-e451de049a54"],
Cell[10923, 281, 3096, 70, 124, "Input",ExpressionUUID->"25bc23d6-e717-4d25-894a-9fdf6edd995e"],
Cell[14022, 353, 4114, 94, 162, "Input",ExpressionUUID->"946b9045-1587-4700-a79d-1a92bb616739"],
Cell[18139, 449, 5598, 134, 200, "Input",ExpressionUUID->"d8b3a842-f55a-444a-92f5-da7c6d65720d"],
Cell[23740, 585, 5643, 134, 200, "Input",ExpressionUUID->"55f830a1-c5b3-4757-91df-3b2d806b1c4c"],
Cell[29386, 721, 1076, 30, 28, "Input",ExpressionUUID->"f3053e55-f1fe-4c94-8780-133b44e48b01"],
Cell[CellGroupData[{
Cell[30487, 755, 155, 3, 96, "Title",ExpressionUUID->"96723d73-c3ad-4131-84fe-5c73c110db42"],
Cell[30645, 760, 305, 7, 28, "Input",ExpressionUUID->"141bc942-565e-4da6-b8cb-ca7c19defa2a"],
Cell[30953, 769, 366, 8, 28, "Input",ExpressionUUID->"e6e824d6-c4d6-44c8-8a2b-289fc311898b"],
Cell[31322, 779, 859, 17, 44, "Input",ExpressionUUID->"b287ee49-c359-41aa-a815-a645292150c7"],
Cell[32184, 798, 282, 7, 34, "Text",ExpressionUUID->"fd386e9a-775c-4edd-815c-1aa8eb695b02"],
Cell[32469, 807, 2572, 56, 86, "Input",ExpressionUUID->"6d180ed6-a098-41cf-bcc9-1ff09093beec"],
Cell[35044, 865, 155, 3, 34, "Text",ExpressionUUID->"27bfa428-5777-4400-a8a3-97cd59713f49"],
Cell[35202, 870, 285, 6, 28, "Input",ExpressionUUID->"1ea8880f-e1f5-4036-997e-d00cdc27e8bc"],
Cell[CellGroupData[{
Cell[35512, 880, 182, 2, 28, "Input",ExpressionUUID->"5d69ab60-bf25-43eb-882e-f6a6152f54c9"],
Cell[35697, 884, 34779, 625, 171, "Output",ExpressionUUID->"9060a607-e95a-42ce-bdcf-3c89b813d20b"]
}, Open  ]],
Cell[70491, 1512, 365, 7, 28, "Input",ExpressionUUID->"b6aaa058-14be-4398-a579-b0279e22d542"],
Cell[70859, 1521, 259, 5, 28, "Input",ExpressionUUID->"9eff3271-3c87-4db7-8b7f-65ef364be904"],
Cell[71121, 1528, 244, 5, 34, "Text",ExpressionUUID->"09d23ad9-c2a2-4dea-ba3d-98fceb0d633f"],
Cell[71368, 1535, 1301, 25, 28, "Input",ExpressionUUID->"b80a565a-6097-4f67-ad5c-41af974bbc35"],
Cell[72672, 1562, 697, 15, 28, "Input",ExpressionUUID->"e54d1532-357e-4bc4-85ae-ce9901242dc7"],
Cell[73372, 1579, 188, 3, 50, "Text",ExpressionUUID->"c15bc9e0-7f29-4b6a-bba5-1f0f4b00f11c"],
Cell[73563, 1584, 390, 9, 50, "Text",ExpressionUUID->"5f423e53-0f38-4c12-9210-37b09147d1bf"],
Cell[73956, 1595, 173, 3, 34, "Text",ExpressionUUID->"de3050bd-45b6-430f-9a22-5092b42b49c1"],
Cell[CellGroupData[{
Cell[74154, 1602, 1417, 33, 48, "Input",ExpressionUUID->"d7345451-1d7c-446f-937c-0e87df2ad786"],
Cell[75574, 1637, 10045, 169, 356, "Output",ExpressionUUID->"93053d74-76b8-41a6-9b84-b6b45edc3018"]
}, Open  ]],
Cell[85634, 1809, 178, 3, 34, "Text",ExpressionUUID->"9affb6cb-ecf7-4752-bff4-9869904ab722"],
Cell[85815, 1814, 1175, 29, 28, "Input",ExpressionUUID->"07dc6cab-f372-4688-9dd4-987ee4b87a83"],
Cell[CellGroupData[{
Cell[87015, 1847, 230, 3, 28, "Input",ExpressionUUID->"5c60a2bb-3ef0-4843-957d-e294ffe13824"],
Cell[87248, 1852, 10035, 171, 394, "Output",ExpressionUUID->"7344f5a7-b64a-424d-9c31-16e7d4710fda"]
}, Open  ]],
Cell[97298, 2026, 225, 4, 34, "Text",ExpressionUUID->"2aabf405-375f-49d0-9a93-cbe14c42bc77"],
Cell[97526, 2032, 1235, 31, 28, "Input",ExpressionUUID->"3bfdd656-a8c7-4a3e-ba87-5a119f295b06"],
Cell[CellGroupData[{
Cell[98786, 2067, 228, 3, 28, "Input",ExpressionUUID->"f330699c-257d-485d-b9ca-ce0be4094017"],
Cell[99017, 2072, 7925, 124, 337, "Output",ExpressionUUID->"4a1323dc-6569-40ff-844a-390833342d13"]
}, Open  ]],
Cell[106957, 2199, 584, 14, 50, "Text",ExpressionUUID->"e592c94b-9186-445c-acf3-9b3dd55e6486"],
Cell[107544, 2215, 173, 3, 34, "Text",ExpressionUUID->"46ad3252-d58f-4830-bba7-79f57c83854c"],
Cell[107720, 2220, 1320, 32, 28, "Input",ExpressionUUID->"050bf202-d9b4-4bfe-9aaa-40a862e31679"],
Cell[109043, 2254, 178, 3, 34, "Text",ExpressionUUID->"38d71bdb-67ed-4d29-8302-ed89aa4b88e9"],
Cell[109224, 2259, 1108, 29, 28, "Input",ExpressionUUID->"204ceb18-d908-479f-b79a-7d4dbd43a572"],
Cell[110335, 2290, 225, 4, 34, "Text",ExpressionUUID->"df6ade0f-6924-44a2-801f-708fbd08c9ae"],
Cell[110563, 2296, 1142, 30, 28, "Input",ExpressionUUID->"d6eb3c1e-5c53-413b-873c-0b761bcc4427"],
Cell[111708, 2328, 357, 5, 50, "Text",ExpressionUUID->"40fbbb5b-98c6-4994-80f8-39abff86dd66"],
Cell[112068, 2335, 282, 5, 50, "Text",ExpressionUUID->"cd67fcb4-a810-4373-82de-d785f388b89f"],
Cell[112353, 2342, 173, 3, 34, "Text",ExpressionUUID->"907cd8df-b878-4615-8a0c-e98bf595b495"],
Cell[112529, 2347, 809, 18, 28, "Input",ExpressionUUID->"fd9a2ba2-94f0-46b7-9736-2e0386e9449e"],
Cell[CellGroupData[{
Cell[113363, 2369, 185, 3, 28, "Input",ExpressionUUID->"a03f8506-213b-4033-8d48-c73aca5d08bd"],
Cell[113551, 2374, 362, 8, 32, "Output",ExpressionUUID->"b6f31362-8955-406c-ace9-bfdbda86b7c2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[113950, 2387, 573, 14, 28, "Input",ExpressionUUID->"407b0eca-54d6-4bca-8db9-e7d0d3b2d700"],
Cell[114526, 2403, 362, 8, 32, "Output",ExpressionUUID->"b3b93d60-aac0-44a0-909a-9d16ca5757fa"]
}, Closed]],
Cell[114903, 2414, 178, 3, 30, "Text",ExpressionUUID->"69f76f62-e11e-4975-88ba-f59d54eba41c"],
Cell[115084, 2419, 863, 19, 28, "Input",ExpressionUUID->"3ed6aefe-9f7f-4643-a40a-8987d879b121"],
Cell[CellGroupData[{
Cell[115972, 2442, 339, 5, 28, "Input",ExpressionUUID->"2bd8cd55-3d1e-4cc1-aabb-695032902ad6"],
Cell[116314, 2449, 397, 9, 32, "Output",ExpressionUUID->"9af1dfd6-135f-4f32-8dfd-9689e50f8b6a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[116748, 2463, 673, 15, 28, "Input",ExpressionUUID->"347cf21c-aee0-4ffc-9111-478be5246fc7"],
Cell[117424, 2480, 362, 8, 32, "Output",ExpressionUUID->"b35ca269-d2db-49fe-a0b2-1d8e621cdab8"]
}, Open  ]],
Cell[117801, 2491, 228, 4, 34, "Text",ExpressionUUID->"b055c62e-761c-45e7-af5e-64cbbb77b268"],
Cell[118032, 2497, 481, 13, 28, "Input",ExpressionUUID->"f9b95048-5620-4a09-9e58-a82fe2afc7f3"],
Cell[CellGroupData[{
Cell[118538, 2514, 186, 3, 28, "Input",ExpressionUUID->"b9c4e705-9b99-4dc7-8b68-828e6d6931c7"],
Cell[118727, 2519, 401, 8, 32, "Output",ExpressionUUID->"916059e9-6622-47ed-924f-6d52d57ed70f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[119165, 2532, 728, 16, 28, "Input",ExpressionUUID->"077ebedc-116d-436d-af49-8313391f447c"],
Cell[119896, 2550, 385, 8, 32, "Output",ExpressionUUID->"4078bb86-c1aa-48d9-a209-f3e4871a8576"]
}, Open  ]],
Cell[120296, 2561, 441, 11, 50, "Text",ExpressionUUID->"63fd89d9-6c69-4bcc-82b3-9f44e7e50a06"],
Cell[120740, 2574, 173, 3, 34, "Text",ExpressionUUID->"0e10dbba-f3f5-4eea-accb-7e1341a38eae"],
Cell[120916, 2579, 837, 18, 28, "Input",ExpressionUUID->"bd1747c4-e661-4670-906c-81812e17b7e2"],
Cell[121756, 2599, 595, 14, 28, "Input",ExpressionUUID->"6ba06abc-0936-4518-af3e-5c3e79395ccb"],
Cell[122354, 2615, 178, 3, 34, "Text",ExpressionUUID->"8225fa37-1831-4a25-b406-85c897ff94f6"],
Cell[122535, 2620, 891, 19, 28, "Input",ExpressionUUID->"20e93da9-81b8-4760-92cc-d764bc39cce5"],
Cell[123429, 2641, 698, 15, 28, "Input",ExpressionUUID->"d16d09ba-768b-4a3f-9dd0-bcaeb2917e24"],
Cell[124130, 2658, 228, 4, 34, "Text",ExpressionUUID->"ea2b866c-8b6b-4140-bd36-7a953f5dc7ea"],
Cell[124361, 2664, 508, 14, 28, "Input",ExpressionUUID->"9d7cbf19-e215-4b13-a2b8-e886884fc450"],
Cell[124872, 2680, 755, 16, 28, "Input",ExpressionUUID->"aed64eb7-6c18-45d6-92c4-fa4dfd52a93e"],
Cell[125630, 2698, 186, 3, 50, "Text",ExpressionUUID->"60dff388-6090-402a-becc-a5557818bbe6"],
Cell[125819, 2703, 276, 6, 28, "Input",ExpressionUUID->"7739a091-2401-46e3-b449-8d383d3dd876"],
Cell[CellGroupData[{
Cell[126120, 2713, 2192, 57, 67, "Input",ExpressionUUID->"f593fb36-eb28-4406-a0a2-6391e6ada4d9"],
Cell[128315, 2772, 84813, 1783, 1167, "Output",ExpressionUUID->"704a7ace-83b2-4780-98b0-56c0365fc755"]
}, Open  ]],
Cell[213143, 4558, 297, 7, 28, "Input",ExpressionUUID->"c5c81ffc-0022-4803-8bb8-145416e531d8"],
Cell[CellGroupData[{
Cell[213465, 4569, 831, 20, 28, "Input",ExpressionUUID->"b304b022-2421-42e2-b56f-33c1677d25a3"],
Cell[214299, 4591, 648972, 15456, 648, "Output",ExpressionUUID->"cbb0a006-bf6a-4467-98f4-6de31b39edd7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[863308, 20052, 373, 6, 69, "Subsection",ExpressionUUID->"35910b46-0e33-4a62-8978-124eb0f8f870"],
Cell[863684, 20060, 155, 3, 34, "Text",ExpressionUUID->"9a2a03f0-1a0f-42a3-9aee-220676d17efa"],
Cell[863842, 20065, 492, 10, 48, "Input",ExpressionUUID->"1062c643-a12b-4e1a-a457-7285e5d16a8b"],
Cell[864337, 20077, 422, 10, 28, "Input",ExpressionUUID->"ff0736ee-c140-4c92-bb2e-208e38cf404f"],
Cell[864762, 20089, 972, 21, 28, "Input",ExpressionUUID->"f1dbdc51-73ea-4bd3-9da4-e7ad3896591e"],
Cell[865737, 20112, 614, 15, 28, "Input",ExpressionUUID->"213a6478-951d-43c0-9194-978822bf61ba"],
Cell[866354, 20129, 214, 4, 34, "Text",ExpressionUUID->"77e03dd1-be11-4a97-beca-9999486e630e"],
Cell[866571, 20135, 258, 5, 28, "Input",ExpressionUUID->"8e952ef1-570e-4c57-aed1-7c63cc965bf1"],
Cell[866832, 20142, 413, 7, 28, "Input",ExpressionUUID->"40ea1032-7945-4fb8-8b9e-466c8cac1399"],
Cell[867248, 20151, 312, 6, 28, "Input",ExpressionUUID->"3d251297-19f2-4012-a4f1-e1dc00472d12"],
Cell[867563, 20159, 244, 5, 34, "Text",ExpressionUUID->"3d98004a-ebf4-4041-bc7d-f3b87de611e6"],
Cell[867810, 20166, 1343, 24, 28, "Input",ExpressionUUID->"c8b456ee-481e-40d5-b7ec-1e7e1e2c5ca1"],
Cell[869156, 20192, 824, 16, 28, "Input",ExpressionUUID->"dab664d0-01e0-487e-9ece-2aafe111d8bc"],
Cell[CellGroupData[{
Cell[870005, 20212, 1016, 21, 28, "Input",ExpressionUUID->"c6da0dc2-952a-470f-a059-4b6812657503"],
Cell[871024, 20235, 456933, 10908, 381, "Output",ExpressionUUID->"fca6a772-da3c-4e08-bac0-aa6cab11c10d"]
}, Open  ]],
Cell[1327972, 31146, 282, 5, 50, "Text",ExpressionUUID->"34eae93b-ab06-4a23-924e-329b1b19416f"],
Cell[1328257, 31153, 173, 3, 34, "Text",ExpressionUUID->"5a0b6d9d-8792-4690-b69c-7b5725350eb3"],
Cell[CellGroupData[{
Cell[1328455, 31160, 762, 13, 28, "Input",ExpressionUUID->"48060b61-747a-4722-b281-55dd0db787af"],
Cell[1329220, 31175, 272, 5, 32, "Output",ExpressionUUID->"a1c56629-e4f7-4148-be04-fa6fbd7c1810"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1329529, 31185, 437, 11, 28, "Input",ExpressionUUID->"1c45c115-eacb-4fdd-b668-84d7667ef12c"],
Cell[1329969, 31198, 222, 4, 32, "Output",ExpressionUUID->"18bcb3db-68cd-4f48-89bb-a046b9b07d42"]
}, Open  ]],
Cell[1330206, 31205, 178, 3, 34, "Text",ExpressionUUID->"7f3e9411-fb17-45ea-acb3-35cf87df2cdd"],
Cell[CellGroupData[{
Cell[1330409, 31212, 716, 12, 28, "Input",ExpressionUUID->"1a39d084-04d8-4444-a67d-c4ed4418d41e"],
Cell[1331128, 31226, 196, 3, 32, "Output",ExpressionUUID->"e039c451-d5b6-43ca-9744-21bbbf02bba8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1331361, 31234, 636, 14, 28, "Input",ExpressionUUID->"248e3156-d3d3-430d-bc17-912f95c2f2c6"],
Cell[1332000, 31250, 222, 4, 32, "Output",ExpressionUUID->"2025f610-84e1-4702-a9e7-7e21fb3fb4bb"]
}, Open  ]],
Cell[1332237, 31257, 228, 4, 34, "Text",ExpressionUUID->"1511cf4d-e3f8-4873-b6f3-ed833dd4bd81"],
Cell[CellGroupData[{
Cell[1332490, 31265, 335, 7, 28, "Input",ExpressionUUID->"4a90530d-d97e-4525-bd15-28d1f96b7328"],
Cell[1332828, 31274, 194, 3, 32, "Output",ExpressionUUID->"b7a4dbb7-8173-4cc0-ad25-2cf732697f8d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1333059, 31282, 688, 14, 28, "Input",ExpressionUUID->"63e2c75b-b88f-4156-a304-11becd1efad3"],
Cell[1333750, 31298, 244, 4, 32, "Output",ExpressionUUID->"82c2e2c1-ae4e-49b3-a495-5ef49b779d00"]
}, Open  ]],
Cell[1334009, 31305, 330, 5, 50, "Text",ExpressionUUID->"5a9b4640-64d8-4399-a768-e61bb29493f3"],
Cell[1334342, 31312, 173, 3, 34, "Text",ExpressionUUID->"c492f684-1cc9-4d45-8ff0-babbd4d67601"],
Cell[CellGroupData[{
Cell[1334540, 31319, 816, 14, 28, "Input",ExpressionUUID->"b180caaf-1706-49b2-892b-7ad6163a12be"],
Cell[1335359, 31335, 310, 6, 32, "Output",ExpressionUUID->"28ba0099-943f-4b99-9562-b5f236b8f763"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1335706, 31346, 488, 12, 28, "Input",ExpressionUUID->"5d3bcd3b-35a3-41c0-a8b4-d0e5b1f3b493"],
Cell[1336197, 31360, 244, 4, 32, "Output",ExpressionUUID->"ff6b8177-69ce-439f-bad2-231f498e3c46"]
}, Open  ]],
Cell[1336456, 31367, 178, 3, 34, "Text",ExpressionUUID->"21eb980c-116d-4c63-a590-3561b68ad906"],
Cell[CellGroupData[{
Cell[1336659, 31374, 766, 13, 28, "Input",ExpressionUUID->"3467270c-2374-47ac-b320-af615cae09c5"],
Cell[1337428, 31389, 238, 5, 32, "Output",ExpressionUUID->"e5f4fd5e-12e5-4746-afda-bf50caedabf6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1337703, 31399, 682, 14, 28, "Input",ExpressionUUID->"52cf3c58-f8f0-4e87-8936-bf59c9ffef65"],
Cell[1338388, 31415, 242, 4, 32, "Output",ExpressionUUID->"facbb898-cdb0-4dbe-851b-15561a7e798e"]
}, Open  ]],
Cell[1338645, 31422, 228, 4, 34, "Text",ExpressionUUID->"768728da-458e-4adf-92e6-7cb009a5fee1"],
Cell[CellGroupData[{
Cell[1338898, 31430, 360, 7, 28, "Input",ExpressionUUID->"21f80d1c-4d88-4ce0-8433-b5e71fc26292"],
Cell[1339261, 31439, 223, 4, 32, "Output",ExpressionUUID->"b6d9a6b7-8814-4a44-936c-eb69c0ac8f6b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1339521, 31448, 738, 15, 28, "Input",ExpressionUUID->"65a51a04-a46b-482a-8f5f-378480feaa8f"],
Cell[1340262, 31465, 266, 4, 32, "Output",ExpressionUUID->"5a4e32e2-ca36-4208-bfcb-07114b835e95"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1340577, 31475, 374, 6, 69, "Subsection",ExpressionUUID->"a09adbe8-368a-48d5-9da1-67a165bf0caf"],
Cell[1340954, 31483, 155, 3, 34, "Text",ExpressionUUID->"f1e1a62b-b6eb-445f-a593-9a204635ada9"],
Cell[1341112, 31488, 549, 12, 48, "Input",ExpressionUUID->"8a2dbd7c-de30-446e-8144-a29f2263ac25"],
Cell[1341664, 31502, 474, 11, 28, "Input",ExpressionUUID->"81f83003-159b-4cf1-90bd-2dbd96860c67"],
Cell[1342141, 31515, 1028, 23, 28, "Input",ExpressionUUID->"3b656c4d-db49-4353-a7f0-80932b07cfde"],
Cell[1343172, 31540, 665, 16, 28, "Input",ExpressionUUID->"871600bb-d766-47c3-8c76-2b04ca13f90d"],
Cell[1343840, 31558, 214, 4, 34, "Text",ExpressionUUID->"c4a9b967-1491-4b2d-bdc8-768fc055f8ff"],
Cell[1344057, 31564, 311, 7, 28, "Input",ExpressionUUID->"fe770572-de94-4cd5-b307-ee7c2c512c0b"],
Cell[1344371, 31573, 470, 9, 28, "Input",ExpressionUUID->"56201248-fadf-438f-92c2-e3b40e4a2d01"],
Cell[1344844, 31584, 367, 8, 28, "Input",ExpressionUUID->"1074ed44-022d-4e08-9170-28dccbf0a4d7"],
Cell[1345214, 31594, 244, 5, 34, "Text",ExpressionUUID->"bc61090f-8d1f-4b70-921e-f6e4d909cc4e"],
Cell[1345461, 31601, 1399, 26, 28, "Input",ExpressionUUID->"d0aecc3c-a02c-4974-8719-0c804eb00af8"],
Cell[1346863, 31629, 878, 18, 28, "Input",ExpressionUUID->"d17f6295-5925-4c0d-8956-0ac5e847e7a3"],
Cell[1347744, 31649, 199, 3, 34, "Text",ExpressionUUID->"2c36343d-e58f-4e66-85f1-dc73b3b215dc"],
Cell[CellGroupData[{
Cell[1347968, 31656, 1299, 25, 28, "Input",ExpressionUUID->"ede69581-bc23-4b45-83bd-d7f4b437ba83"],
Cell[1349270, 31683, 1098311, 26052, 372, "Output",ExpressionUUID->"c7ef3228-60b7-4144-af21-23a062e3f179"]
}, Open  ]],
Cell[2447596, 57738, 346, 7, 28, "Input",ExpressionUUID->"79f74856-e8b0-4888-b6d5-0178e2c5212e"],
Cell[2447945, 57747, 197, 3, 34, "Text",ExpressionUUID->"24b3222c-c9fb-4db4-aa24-715d17478432"],
Cell[CellGroupData[{
Cell[2448167, 57754, 1122, 23, 28, "Input",ExpressionUUID->"3af7c070-1ca5-461d-bfd1-c2c85993289f"],
Cell[2449292, 57779, 1095409, 26048, 372, "Output",ExpressionUUID->"ab5bb37a-ae35-4225-9bbb-dc5c5f34b0c7"]
}, Open  ]],
Cell[3544716, 83830, 253, 4, 34, "Text",ExpressionUUID->"29b2ba4b-56b9-4558-b139-7fcbc6c1e21c"],
Cell[CellGroupData[{
Cell[3544994, 83838, 1148, 23, 28, "Input",ExpressionUUID->"ab3bd2c6-dc0f-49ec-8ddd-d36483b11b20"],
Cell[3546145, 83863, 1095684, 26052, 372, "Output",ExpressionUUID->"a4f8e0f1-190f-4df5-84ab-575258b6112f"]
}, Open  ]],
Cell[4641844, 109918, 253, 4, 34, "Text",ExpressionUUID->"a09a78db-06d1-45ce-a84e-722375022876"],
Cell[CellGroupData[{
Cell[4642122, 109926, 1149, 23, 28, "Input",ExpressionUUID->"729a5f28-cf5c-4307-89f8-661235f74256"],
Cell[4643274, 109951, 1093008, 25971, 372, "Output",ExpressionUUID->"49560f7d-d17e-4336-8e53-4f70051474e1"]
}, Open  ]],
Cell[5736297, 135925, 299, 4, 34, "Text",ExpressionUUID->"13ab198d-9c2c-4412-b0d6-8d14d586bc2e"],
Cell[CellGroupData[{
Cell[5736621, 135933, 1097, 22, 28, "Input",ExpressionUUID->"9ddb3754-21b2-4cac-be94-5fd86f4e2020"],
Cell[5737721, 135957, 1006739, 22937, 372, "Output",ExpressionUUID->"88e472a1-4b88-4d16-b56c-a1c10b1cdeeb"]
}, Open  ]],
Cell[6744475, 158897, 297, 4, 34, "Text",ExpressionUUID->"ea8bfb1f-b615-45a5-bce9-b90c082f516b"],
Cell[CellGroupData[{
Cell[6744797, 158905, 1149, 23, 28, "Input",ExpressionUUID->"111b75dd-38d6-4474-bbdd-9c03ada428ed"],
Cell[6745949, 158930, 1088783, 25810, 372, "Output",ExpressionUUID->"7eb2dce6-8fe5-4067-a7a9-3fe987b51507"]
}, Open  ]],
Cell[7834747, 184743, 282, 5, 50, "Text",ExpressionUUID->"1d18d146-e61b-4a93-be24-b6599519ad23"],
Cell[7835032, 184750, 173, 3, 34, "Text",ExpressionUUID->"59d03372-9a06-461c-a577-be4db4aa6d17"],
Cell[CellGroupData[{
Cell[7835230, 184757, 813, 14, 28, "Input",ExpressionUUID->"d386c7ba-c4df-484a-a2ec-67fa9ac3a4ec"],
Cell[7836046, 184773, 297, 5, 32, "Output",ExpressionUUID->"14d6666b-2753-4c56-b873-94188d4dd85c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7836380, 184783, 486, 12, 28, "Input",ExpressionUUID->"6655309e-b10d-4792-a8a6-27ed1a0b7593"],
Cell[7836869, 184797, 250, 4, 32, "Output",ExpressionUUID->"02977a12-72ff-438f-81e1-9ab1a6815332"]
}, Open  ]],
Cell[7837134, 184804, 178, 3, 34, "Text",ExpressionUUID->"7cf4c1b2-f799-4fc6-808b-6a5846e4260e"],
Cell[CellGroupData[{
Cell[7837337, 184811, 768, 13, 28, "Input",ExpressionUUID->"5fbecfd0-646a-4239-996c-9d0962f34a7e"],
Cell[7838108, 184826, 220, 4, 32, "Output",ExpressionUUID->"2e401a5c-113c-4e3b-a4b0-381d2709f62c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7838365, 184835, 686, 14, 28, "Input",ExpressionUUID->"49ef63a7-255c-4505-8fe2-8ac876622f90"],
Cell[7839054, 184851, 244, 4, 32, "Output",ExpressionUUID->"7ba44c38-93a5-4b93-9120-29cb619ea3bc"]
}, Open  ]],
Cell[7839313, 184858, 228, 4, 34, "Text",ExpressionUUID->"cc03ccd5-e1ea-4d7c-8fcb-29688ff20e81"],
Cell[CellGroupData[{
Cell[7839566, 184866, 386, 8, 28, "Input",ExpressionUUID->"2233ea15-6cfa-4032-bf6a-092f7675a6d6"],
Cell[7839955, 184876, 221, 4, 32, "Output",ExpressionUUID->"b2740f37-5ac8-44fe-99cc-fb08b464678d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7840213, 184885, 739, 15, 28, "Input",ExpressionUUID->"e2e12ac0-99ca-4c41-8b0b-7037df8b7165"],
Cell[7840955, 184902, 265, 4, 32, "Output",ExpressionUUID->"2d2c8174-3546-4433-a03d-f74ab607368b"]
}, Open  ]],
Cell[7841235, 184909, 330, 5, 50, "Text",ExpressionUUID->"ca7908ef-61ff-4f21-bf57-2d35f8382cd5"],
Cell[7841568, 184916, 173, 3, 34, "Text",ExpressionUUID->"0b702b31-b7ee-4038-9778-35b3d338f037"],
Cell[CellGroupData[{
Cell[7841766, 184923, 862, 14, 28, "Input",ExpressionUUID->"62de27f2-e739-4673-8c2b-20dfc6d4e9ab"],
Cell[7842631, 184939, 323, 6, 32, "Output",ExpressionUUID->"f39bdf56-d23c-4e09-96e6-2d01832b591d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7842991, 184950, 538, 12, 28, "Input",ExpressionUUID->"5cbcb0f9-2b97-41ed-80d2-c67b5f523f1c"],
Cell[7843532, 184964, 267, 4, 32, "Output",ExpressionUUID->"7d82aed2-684a-4d36-80b8-38520d653da6"]
}, Open  ]],
Cell[7843814, 184971, 178, 3, 34, "Text",ExpressionUUID->"b7b44779-48a8-434b-92e7-0a087c8b7dd8"],
Cell[CellGroupData[{
Cell[7844017, 184978, 818, 14, 28, "Input",ExpressionUUID->"bacfb75b-1dfd-44e3-966d-c2dbdb9b3094"],
Cell[7844838, 184994, 247, 4, 32, "Output",ExpressionUUID->"4bb953c3-5720-46fc-8a75-f19ba0931c9a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7845122, 185003, 735, 15, 28, "Input",ExpressionUUID->"75530884-6c52-4607-adab-4b64cca716be"],
Cell[7845860, 185020, 267, 4, 32, "Output",ExpressionUUID->"af9ea8b2-1c13-4448-99bd-692b3310eb37"]
}, Open  ]],
Cell[7846142, 185027, 228, 4, 34, "Text",ExpressionUUID->"cc2779bf-e3e8-4a68-ba55-cc99676436bc"],
Cell[CellGroupData[{
Cell[7846395, 185035, 466, 9, 28, "Input",ExpressionUUID->"2e0374b0-ad7a-465d-b2e5-aa63def522fb"],
Cell[7846864, 185046, 273, 5, 32, "Output",ExpressionUUID->"4f455c21-afad-4b19-bd53-7531ca6f9292"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7847174, 185056, 788, 16, 28, "Input",ExpressionUUID->"1ac24a2b-05a8-4d88-af22-8ffcc2ed2d87"],
Cell[7847965, 185074, 324, 6, 32, "Output",ExpressionUUID->"7cb9698d-8193-4d7e-ae5a-f1338485213e"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7848338, 185086, 420, 6, 69, "Subsection",ExpressionUUID->"dd7dc054-42ed-4747-ac03-9bce886b4d0c"],
Cell[7848761, 185094, 155, 3, 34, "Text",ExpressionUUID->"83445021-de34-4b22-a0bb-18e885db3068"],
Cell[7848919, 185099, 648, 13, 48, "Input",ExpressionUUID->"ca1888d3-e241-4b11-b39c-86219b601246"],
Cell[7849570, 185114, 526, 12, 28, "Input",ExpressionUUID->"1a8dad2f-6668-47f2-b989-9a72525c0e29"],
Cell[7850099, 185128, 1073, 23, 28, "Input",ExpressionUUID->"e333022f-1f52-488d-b5cd-92362bedfe98"],
Cell[7851175, 185153, 718, 17, 28, "Input",ExpressionUUID->"919c0dcf-598f-4fb1-8930-fa47262c5f6c"],
Cell[7851896, 185172, 214, 4, 34, "Text",ExpressionUUID->"4f92eea8-ddb7-427a-9a6c-f5463acbd057"],
Cell[7852113, 185178, 360, 8, 28, "Input",ExpressionUUID->"3cf5dbf7-87ed-4ae1-86c2-fc671c5ec254"],
Cell[7852476, 185188, 521, 10, 28, "Input",ExpressionUUID->"3e43d2d6-6bc5-4968-936e-3cfa6a2fb72e"],
Cell[7853000, 185200, 413, 8, 28, "Input",ExpressionUUID->"d53ff5bf-f590-4873-b55a-0997d574672a"],
Cell[7853416, 185210, 244, 5, 34, "Text",ExpressionUUID->"1437b1cf-d6f6-4a66-adf6-7b8748d226bb"],
Cell[7853663, 185217, 1447, 26, 28, "Input",ExpressionUUID->"a269346a-99e4-436e-b10c-325aa7596c94"],
Cell[7855113, 185245, 928, 18, 28, "Input",ExpressionUUID->"e6791147-4783-4e49-8c45-4f1800dc79e7"],
Cell[7856044, 185265, 199, 3, 34, "Text",ExpressionUUID->"337f8761-4ff0-4ed0-ae48-6e5e948ce195"],
Cell[CellGroupData[{
Cell[7856268, 185272, 1154, 24, 44, "Input",ExpressionUUID->"09e620ef-3374-4bcc-af0e-c49dbae807d6"],
Cell[7857425, 185298, 1633730, 38726, 518, "Output",ExpressionUUID->"2d32cc3f-5227-4eb1-a0a6-88507b6f0352"]
}, Open  ]],
Cell[9491170, 224027, 197, 3, 34, "Text",ExpressionUUID->"6db8d9cc-ee85-452b-a190-b637ddc73c11"],
Cell[CellGroupData[{
Cell[9491392, 224034, 1168, 23, 28, "Input",ExpressionUUID->"77514eb2-2b53-4011-b4ca-3886c39db7a2"],
Cell[9492563, 224059, 1631444, 38733, 502, "Output",ExpressionUUID->"9ec79fd2-13a5-4ac0-adcf-a41646af28d1"]
}, Open  ]],
Cell[11124022, 262795, 253, 4, 34, "Text",ExpressionUUID->"0ba91b9d-9ad3-47e7-9aa9-b71dcecea7e8"],
Cell[CellGroupData[{
Cell[11124300, 262803, 1174, 24, 28, "Input",ExpressionUUID->"16afaf15-096c-4200-a678-d5b2ec38cdfc"],
Cell[11125477, 262829, 1632772, 38726, 502, "Output",ExpressionUUID->"055b12a9-2093-4f81-a97c-fd831fceb1b8"]
}, Open  ]],
Cell[12758264, 301558, 253, 4, 34, "Text",ExpressionUUID->"78321c96-d7fe-44b0-a813-6f26c9628ff4"],
Cell[CellGroupData[{
Cell[12758542, 301566, 1203, 24, 28, "Input",ExpressionUUID->"c2bb2bca-6101-4600-b8d2-7e236ff07ccf"],
Cell[12759748, 301592, 1631660, 38725, 502, "Output",ExpressionUUID->"6971b768-5f15-4385-b4e8-7f69f1b6752a"]
}, Open  ]],
Cell[14391423, 340320, 299, 4, 34, "Text",ExpressionUUID->"891a11fd-80f8-4231-b3fd-0b56fec57d98"],
Cell[CellGroupData[{
Cell[14391747, 340328, 1149, 23, 28, "Input",ExpressionUUID->"442ffc98-e47e-4daf-b859-2884ec7b713e"],
Cell[14392899, 340353, 1600447, 37476, 502, "Output",ExpressionUUID->"51a65e35-ccc7-4c79-bdae-d42cf30906f9"]
}, Open  ]],
Cell[15993361, 377832, 297, 4, 34, "Text",ExpressionUUID->"ea209531-75b8-411f-9341-15ca7dc3126a"],
Cell[CellGroupData[{
Cell[15993683, 377840, 1203, 24, 28, "Input",ExpressionUUID->"54d21065-25ad-4d7a-9b35-66be2a97e5ae"],
Cell[15994889, 377866, 1617750, 38155, 502, "Output",ExpressionUUID->"09600472-3986-4a73-85c7-c12d971a77fd"]
}, Open  ]],
Cell[17612654, 416024, 282, 5, 50, "Text",ExpressionUUID->"6ed1f520-530f-4d18-9e9d-801fb0910d6d"],
Cell[17612939, 416031, 173, 3, 34, "Text",ExpressionUUID->"5c75a326-2793-46e7-aa67-df79fc80f650"],
Cell[CellGroupData[{
Cell[17613137, 416038, 859, 14, 28, "Input",ExpressionUUID->"99cd3dfc-fba2-4be3-abea-08cd3946edee"],
Cell[17613999, 416054, 341, 7, 32, "Output",ExpressionUUID->"31f780aa-c0d5-498a-b130-5717758996c2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17614377, 416066, 536, 12, 28, "Input",ExpressionUUID->"3506d6a6-4299-4bde-9fb8-e7f24d7ef746"],
Cell[17614916, 416080, 270, 4, 32, "Output",ExpressionUUID->"0afb3ce6-dc91-4b57-8445-2bc674b69d2e"]
}, Open  ]],
Cell[17615201, 416087, 178, 3, 34, "Text",ExpressionUUID->"deb7d15f-7a92-4fba-af35-5b71dbfd3986"],
Cell[CellGroupData[{
Cell[17615404, 416094, 820, 14, 28, "Input",ExpressionUUID->"202cd144-9335-4c8a-8fc9-8000b83ebef5"],
Cell[17616227, 416110, 256, 5, 32, "Output",ExpressionUUID->"e1d61c8f-733b-4dcb-a25b-058c41453c48"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17616520, 416120, 737, 15, 28, "Input",ExpressionUUID->"8b60f5bc-81cd-4cfa-ad6a-54484bd36a40"],
Cell[17617260, 416137, 268, 4, 32, "Output",ExpressionUUID->"75498662-1532-4f9c-a120-0f22be49b8ed"]
}, Open  ]],
Cell[17617543, 416144, 228, 4, 34, "Text",ExpressionUUID->"54a275e1-2b02-446b-8bc2-48e6b7aa8ad4"],
Cell[CellGroupData[{
Cell[17617796, 416152, 434, 8, 28, "Input",ExpressionUUID->"db6e0f1c-b312-48e6-91e6-144dc89e5045"],
Cell[17618233, 416162, 260, 5, 32, "Output",ExpressionUUID->"25e9c830-7fac-410d-9854-b2b2421fed6c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17618530, 416172, 788, 16, 28, "Input",ExpressionUUID->"49c6c200-6175-455b-a460-93a8baef7aca"],
Cell[17619321, 416190, 290, 5, 32, "Output",ExpressionUUID->"9bda0ecc-1225-4902-b0ba-201685b34f34"]
}, Open  ]],
Cell[17619626, 416198, 330, 5, 50, "Text",ExpressionUUID->"ad27565b-c3cb-45d1-8393-ff41c01bb6f1"],
Cell[17619959, 416205, 173, 3, 34, "Text",ExpressionUUID->"f96d71f5-b891-4cfe-9566-d484977ff19b"],
Cell[CellGroupData[{
Cell[17620157, 416212, 916, 15, 28, "Input",ExpressionUUID->"97eb9478-8f63-4c88-bbd1-836113bb861d"],
Cell[17621076, 416229, 360, 7, 32, "Output",ExpressionUUID->"f483611e-8d25-407b-b354-d9e78935cf7a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17621473, 416241, 591, 13, 28, "Input",ExpressionUUID->"8d63659a-32bb-4b79-8f6c-364cf6817dd7"],
Cell[17622067, 416256, 294, 5, 32, "Output",ExpressionUUID->"7dde0557-986d-4eca-884c-4fd4b37f41d3"]
}, Open  ]],
Cell[17622376, 416264, 178, 3, 34, "Text",ExpressionUUID->"974f7505-7b8a-45c3-9c7d-83ae7161a481"],
Cell[CellGroupData[{
Cell[17622579, 416271, 868, 15, 28, "Input",ExpressionUUID->"d39438c1-c401-4ddc-abd2-7ed44c07dd36"],
Cell[17623450, 416288, 286, 5, 32, "Output",ExpressionUUID->"3e845861-0124-4997-9b59-61d24b5623f7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17623773, 416298, 785, 16, 28, "Input",ExpressionUUID->"653fe7c1-bd8e-416f-adfa-3d0bb272b01b"],
Cell[17624561, 416316, 324, 6, 32, "Output",ExpressionUUID->"928bb34b-5965-4f8d-9b45-3c711fa8103e"]
}, Open  ]],
Cell[17624900, 416325, 228, 4, 34, "Text",ExpressionUUID->"fb4d05a8-dd6b-43d8-9dbf-cb9f5cc591a4"],
Cell[CellGroupData[{
Cell[17625153, 416333, 513, 9, 28, "Input",ExpressionUUID->"0d154ace-caf9-4ec6-8c7d-9d4f5234ad7b"],
Cell[17625669, 416344, 316, 6, 32, "Output",ExpressionUUID->"d2f9f5df-073e-4e31-995b-9b9b5e523b92"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17626022, 416355, 838, 16, 28, "Input",ExpressionUUID->"21344c17-862f-49cc-934e-447c239a2008"],
Cell[17626863, 416373, 346, 6, 32, "Output",ExpressionUUID->"30d06509-e431-41d2-9ae5-e6e697dcfd8c"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[17627258, 416385, 325, 5, 69, "Subsection",ExpressionUUID->"bcf23fa3-b03e-41ce-928c-c0d0306ea6d5"],
Cell[17627586, 416392, 155, 3, 34, "Text",ExpressionUUID->"4e1e1f7d-c365-4c3d-9e28-975ca404ca7d"],
Cell[17627744, 416397, 595, 12, 48, "Input",ExpressionUUID->"b4a0bca2-72ff-40c7-8900-2d9c00308ac2"],
Cell[17628342, 416411, 526, 12, 28, "Input",ExpressionUUID->"80852a47-c27c-4e51-95eb-cb13a619c54b"],
Cell[17628871, 416425, 1076, 23, 28, "Input",ExpressionUUID->"9237ab99-75ee-4b22-bf2a-0023e526030a"],
Cell[17629950, 416450, 716, 17, 28, "Input",ExpressionUUID->"1482888e-e8d9-49a3-9784-25f94b456975"],
Cell[17630669, 416469, 214, 4, 34, "Text",ExpressionUUID->"b599c76c-1339-4a73-8beb-6be63da924da"],
Cell[17630886, 416475, 362, 8, 28, "Input",ExpressionUUID->"cb50788d-e896-4bb9-96fd-150a967b107f"],
Cell[17631251, 416485, 519, 10, 28, "Input",ExpressionUUID->"9d2af732-b1f4-4b60-96df-dbc45d6c86f7"],
Cell[17631773, 416497, 417, 8, 28, "Input",ExpressionUUID->"082a91f3-2f43-4560-9915-0e7df3ca947f"],
Cell[17632193, 416507, 244, 5, 34, "Text",ExpressionUUID->"b3da3db0-285e-40a1-84ea-a2d1dda0d9bd"],
Cell[17632440, 416514, 1449, 26, 28, "Input",ExpressionUUID->"20e4d4f5-b8a8-4220-b0b5-a422efabf9b4"],
Cell[17633892, 416542, 928, 18, 28, "Input",ExpressionUUID->"f396ba17-881a-4824-993d-23c8159bc5c8"],
Cell[17634823, 416562, 199, 3, 34, "Text",ExpressionUUID->"4629a87b-4333-40da-8de1-1b12bf69157a"],
Cell[CellGroupData[{
Cell[17635047, 416569, 1205, 24, 44, "Input",ExpressionUUID->"877ea5ba-426b-439d-8ce7-67b1680043c9"],
Cell[17636255, 416595, 1996887, 47144, 407, "Output",ExpressionUUID->"e65f485c-8757-4dd0-b3d4-1f07b90597e1"]
}, Open  ]],
Cell[19633157, 463742, 197, 3, 34, "Text",ExpressionUUID->"6d849e8f-3978-43de-b9f6-e4e8db036904"],
Cell[CellGroupData[{
Cell[19633379, 463749, 1221, 24, 28, "Input",ExpressionUUID->"444e4803-5f46-4d92-9d8c-298d46689565"],
Cell[19634603, 463775, 1991109, 47123, 391, "Output",ExpressionUUID->"96dd3d68-4b0f-4ed2-a68c-287a44dd5c26"]
}, Open  ]],
Cell[21625727, 510901, 253, 4, 34, "Text",ExpressionUUID->"f6b900d3-3c5d-4138-9743-7913b0e89a0e"],
Cell[CellGroupData[{
Cell[21626005, 510909, 1149, 23, 28, "Input",ExpressionUUID->"3dc07067-1630-478e-bc5d-22712ba37614"],
Cell[21627157, 510934, 1991410, 47128, 390, "Output",ExpressionUUID->"588c2948-04e8-43cf-ac50-c3fd10b68aa2"]
}, Open  ]],
Cell[23618582, 558065, 253, 4, 34, "Text",ExpressionUUID->"bf68603a-3d49-4f35-853b-650bd5ab7349"],
Cell[CellGroupData[{
Cell[23618860, 558073, 1203, 24, 28, "Input",ExpressionUUID->"1f2fcd74-2a50-47d3-9fab-590bd8d01e87"],
Cell[23620066, 558099, 1993038, 47129, 390, "Output",ExpressionUUID->"84fbb0f9-9875-4f7f-8237-47e95d5df4e1"]
}, Open  ]],
Cell[25613119, 605231, 299, 4, 34, "Text",ExpressionUUID->"cebc3af3-6532-4d50-b24a-ca9c91221958"],
Cell[CellGroupData[{
Cell[25613443, 605239, 1151, 23, 28, "Input",ExpressionUUID->"7ff2ad81-2165-47c6-b5cd-bb6907eb449f"],
Cell[25614597, 605264, 1983747, 46848, 390, "Output",ExpressionUUID->"dc0b7e4d-ff83-4334-99df-19cc2dcc1f2b"]
}, Open  ]],
Cell[27598359, 652115, 297, 4, 34, "Text",ExpressionUUID->"2d687918-5d18-40cb-8f85-c0ac4ced7136"],
Cell[CellGroupData[{
Cell[27598681, 652123, 1199, 24, 28, "Input",ExpressionUUID->"8e32d1cf-cb5f-48d2-9db4-743db5002b99"],
Cell[27599883, 652149, 1990072, 47043, 390, "Output",ExpressionUUID->"38968bc4-a1d2-4c56-85ba-fddeb7d26741"]
}, Open  ]],
Cell[29589970, 699195, 282, 5, 50, "Text",ExpressionUUID->"291e414e-9eda-46e5-91b2-b4eff9701f0f"],
Cell[29590255, 699202, 173, 3, 34, "Text",ExpressionUUID->"da8e006e-0b54-40c9-9755-9ad2384f17c1"],
Cell[CellGroupData[{
Cell[29590453, 699209, 860, 14, 28, "Input",ExpressionUUID->"56812749-a70b-4efe-8f33-93b19bb72d4d"],
Cell[29591316, 699225, 337, 7, 32, "Output",ExpressionUUID->"afee4c4b-7847-4332-ae22-3e7631fa84cf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29591690, 699237, 536, 12, 28, "Input",ExpressionUUID->"90afdff8-3c3d-4af7-bf20-530ffdc2874f"],
Cell[29592229, 699251, 270, 4, 32, "Output",ExpressionUUID->"9c0f4fa1-70f4-4658-96ca-b2b3c91b6601"]
}, Open  ]],
Cell[29592514, 699258, 178, 3, 34, "Text",ExpressionUUID->"21bc06ad-cafc-4076-8886-537d35c18024"],
Cell[CellGroupData[{
Cell[29592717, 699265, 818, 14, 28, "Input",ExpressionUUID->"11cd041e-edd1-4ae1-8c0f-19539578d80c"],
Cell[29593538, 699281, 258, 5, 32, "Output",ExpressionUUID->"8605ffbd-9a48-4a51-897b-9846dc765b3f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29593833, 699291, 737, 15, 28, "Input",ExpressionUUID->"c65fce6d-ea46-404e-ad30-246d9eb97c99"],
Cell[29594573, 699308, 270, 4, 32, "Output",ExpressionUUID->"5a6707f8-b5ef-40aa-83c6-95b49827cd5c"]
}, Open  ]],
Cell[29594858, 699315, 228, 4, 34, "Text",ExpressionUUID->"78761bc5-8bc4-402e-be5a-142abf550db8"],
Cell[CellGroupData[{
Cell[29595111, 699323, 432, 8, 28, "Input",ExpressionUUID->"d2f3ff85-6b54-4888-9fbf-b8b804617315"],
Cell[29595546, 699333, 258, 5, 32, "Output",ExpressionUUID->"e22fd43a-3e7e-4e23-b59b-045c05336247"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29595841, 699343, 790, 16, 28, "Input",ExpressionUUID->"c6e12055-dc4a-4ea8-8d05-7a8196d3db23"],
Cell[29596634, 699361, 289, 5, 32, "Output",ExpressionUUID->"7fa7dfd0-d0cf-436a-8141-f4e83307f5e1"]
}, Open  ]],
Cell[29596938, 699369, 330, 5, 50, "Text",ExpressionUUID->"a5cf2069-f33f-4d6e-b557-565004fbb90c"],
Cell[29597271, 699376, 173, 3, 34, "Text",ExpressionUUID->"bf7916ba-5b0b-403e-ba74-9adfae02a4a6"],
Cell[CellGroupData[{
Cell[29597469, 699383, 912, 15, 28, "Input",ExpressionUUID->"56e85535-0b0e-4eb9-ba58-e7307baf8997"],
Cell[29598384, 699400, 364, 7, 32, "Output",ExpressionUUID->"17c5e1cf-6f67-4fed-a7c2-6b5799e5c62e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29598785, 699412, 589, 13, 28, "Input",ExpressionUUID->"41b7bad4-ab12-4b87-8c3d-1f9275967685"],
Cell[29599377, 699427, 297, 5, 32, "Output",ExpressionUUID->"83d65a43-3ac8-4f98-8a74-d98fcd1dbc13"]
}, Open  ]],
Cell[29599689, 699435, 178, 3, 34, "Text",ExpressionUUID->"2c28dd41-0263-46e4-a176-6a7f820f3f75"],
Cell[CellGroupData[{
Cell[29599892, 699442, 870, 15, 28, "Input",ExpressionUUID->"887af302-7d20-45b3-8646-c1088e974021"],
Cell[29600765, 699459, 286, 5, 32, "Output",ExpressionUUID->"9d949705-f51f-432e-9567-2ed763a75a9b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29601088, 699469, 788, 16, 28, "Input",ExpressionUUID->"053d4b31-9c9b-419a-9983-6863d07cda9b"],
Cell[29601879, 699487, 290, 5, 32, "Output",ExpressionUUID->"22f5f3fa-384a-461d-ae84-c3d12d1d7158"]
}, Open  ]],
Cell[29602184, 699495, 228, 4, 34, "Text",ExpressionUUID->"25096255-53d4-496b-9228-8574dc081b92"],
Cell[CellGroupData[{
Cell[29602437, 699503, 512, 9, 28, "Input",ExpressionUUID->"ffd000de-7f55-4fa3-b474-f9991af13257"],
Cell[29602952, 699514, 315, 6, 32, "Output",ExpressionUUID->"dd818fa5-a46d-4576-85dd-3e4a3c646f59"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29603304, 699525, 836, 16, 28, "Input",ExpressionUUID->"9f8920c5-87a8-4f82-9ee1-88120dfebced"],
Cell[29604143, 699543, 346, 6, 32, "Output",ExpressionUUID->"d8128231-c74e-4df3-aff7-4a9304f99d05"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[29604538, 699555, 379, 6, 69, "Subsection",ExpressionUUID->"a256f3d2-0eab-4282-a921-ac506bf4db7e"],
Cell[29604920, 699563, 155, 3, 34, "Text",ExpressionUUID->"5ecde3c8-5b5a-4ef2-a20a-71778edf6705"],
Cell[29605078, 699568, 649, 13, 48, "Input",ExpressionUUID->"5b7e6b7e-783d-4027-94e6-804ff7a93717"],
Cell[29605730, 699583, 587, 14, 28, "Input",ExpressionUUID->"586f7c8e-ef40-4b71-ae81-7bf2df7225ef"],
Cell[29606320, 699599, 1127, 24, 28, "Input",ExpressionUUID->"b79fd439-9c56-447b-9aa3-5dcb90da0ecf"],
Cell[29607450, 699625, 774, 18, 28, "Input",ExpressionUUID->"b0a338f1-807a-4995-965c-a95a66f3f9c3"],
Cell[29608227, 699645, 214, 4, 34, "Text",ExpressionUUID->"71a9a444-89d3-447d-be1a-87068970189b"],
Cell[29608444, 699651, 412, 8, 28, "Input",ExpressionUUID->"7f944ba6-a0c2-4387-a96f-a16b92f7c14a"],
Cell[29608859, 699661, 571, 10, 28, "Input",ExpressionUUID->"16b3396d-6e01-4b45-b787-53048744a88b"],
Cell[29609433, 699673, 470, 9, 28, "Input",ExpressionUUID->"9fcd4a67-84aa-423a-aadc-8f9f2d791572"],
Cell[29609906, 699684, 244, 5, 34, "Text",ExpressionUUID->"cc9c72e7-e6d8-4a74-a215-12579fd98188"],
Cell[29610153, 699691, 1503, 27, 28, "Input",ExpressionUUID->"958da6d9-98e4-4790-8c44-537a0d8993c9"],
Cell[29611659, 699720, 982, 19, 28, "Input",ExpressionUUID->"0b5a0b4f-a7c5-440b-8d7d-8057ee625e2d"],
Cell[29612644, 699741, 199, 3, 34, "Text",ExpressionUUID->"b0283419-5e5b-4d0d-8126-4c1eb112ffbc"],
Cell[CellGroupData[{
Cell[29612868, 699748, 1472, 28, 44, "Input",ExpressionUUID->"8142dc30-7c0a-4945-8b15-99ffc8b230a9"],
Cell[29614343, 699778, 1970801, 46618, 387, "Output",ExpressionUUID->"161c8605-f21a-4f54-bc7b-addd583912c3"]
}, Open  ]],
Cell[31585159, 746399, 197, 3, 34, "Text",ExpressionUUID->"6ffc44da-2ba7-475e-ae41-f5e60dd8b2eb"],
Cell[CellGroupData[{
Cell[31585381, 746406, 1432, 27, 28, "Input",ExpressionUUID->"dcc4e408-7e69-4eac-b934-f65849810ae9"],
Cell[31586816, 746435, 1968650, 46612, 371, "Output",ExpressionUUID->"e1a00a34-2f6b-44a0-a459-e046193434e7"]
}, Open  ]],
Cell[33555481, 793050, 253, 4, 34, "Text",ExpressionUUID->"24b7344a-a514-4246-9557-1ec153e9f73e"],
Cell[CellGroupData[{
Cell[33555759, 793058, 1205, 24, 28, "Input",ExpressionUUID->"6a90ed87-42be-4058-a9ab-84cc4a517c73"],
Cell[33556967, 793084, 1969602, 46605, 369, "Output",ExpressionUUID->"793a2a47-f363-415a-8c99-30ef773192ea"]
}, Open  ]],
Cell[35526584, 839692, 253, 4, 34, "Text",ExpressionUUID->"b01746e6-1c24-40da-9dac-ae73b328198a"],
Cell[CellGroupData[{
Cell[35526862, 839700, 1261, 25, 28, "Input",ExpressionUUID->"ea0ccbf8-9ec6-41c3-a660-ceb2fa1b7cc2"],
Cell[35528126, 839727, 1969636, 46597, 369, "Output",ExpressionUUID->"7f6f25a3-0deb-46e5-b1ec-db73dae2d329"]
}, Open  ]],
Cell[37497777, 886327, 299, 4, 34, "Text",ExpressionUUID->"4965bb42-a47b-4db4-9d7e-5412487bc278"],
Cell[CellGroupData[{
Cell[37498101, 886335, 1264, 25, 28, "Input",ExpressionUUID->"79d24648-1bfd-4e3c-a374-af19e8e8942f"],
Cell[37499368, 886362, 1947295, 45808, 371, "Output",ExpressionUUID->"d8a1c255-43df-4fc7-8f10-dbee507dc7f8"]
}, Open  ]],
Cell[39446678, 932173, 297, 4, 34, "Text",ExpressionUUID->"62a508bc-4493-47aa-80f3-9bac93281806"],
Cell[CellGroupData[{
Cell[39447000, 932181, 1253, 25, 28, "Input",ExpressionUUID->"747d711f-e83a-4fe4-92e8-8c1ac999d3b6"],
Cell[39448256, 932208, 1969202, 46554, 369, "Output",ExpressionUUID->"7ee1f39f-f4d9-420c-9635-d15173e6690d"]
}, Open  ]],
Cell[41417473, 978765, 282, 5, 50, "Text",ExpressionUUID->"1e7a4694-b9a6-44c2-9350-6aa5f4ecce93"],
Cell[41417758, 978772, 173, 3, 34, "Text",ExpressionUUID->"e269e12f-3f8f-400d-b534-67e1433b8d0c"],
Cell[CellGroupData[{
Cell[41417956, 978779, 915, 15, 28, "Input",ExpressionUUID->"021e7b2c-46a4-4a4e-97aa-5b07ce38b04e"],
Cell[41418874, 978796, 345, 6, 32, "Output",ExpressionUUID->"3a1cc889-def0-4978-a4e2-88eca3ab87aa"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41419256, 978807, 591, 13, 28, "Input",ExpressionUUID->"539b67a8-b6f7-4e98-881b-0f2dd06d6c8b"],
Cell[41419850, 978822, 299, 5, 32, "Output",ExpressionUUID->"f78090e9-c5fa-432d-ba8e-8c169558b1b3"]
}, Open  ]],
Cell[41420164, 978830, 178, 3, 34, "Text",ExpressionUUID->"50509af0-ec2c-49a4-b12f-84aaf02601cc"],
Cell[CellGroupData[{
Cell[41420367, 978837, 873, 15, 28, "Input",ExpressionUUID->"b73504d9-d6c7-4e86-9a27-39df685be355"],
Cell[41421243, 978854, 265, 4, 32, "Output",ExpressionUUID->"a4c1c8e8-be66-4788-bc03-b059cfa15745"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41421545, 978863, 790, 16, 28, "Input",ExpressionUUID->"82985208-345c-44ed-b366-3774a9970ec1"],
Cell[41422338, 978881, 295, 5, 32, "Output",ExpressionUUID->"f94fb8b0-2387-4f53-a1ac-78ab2e5e5ab9"]
}, Open  ]],
Cell[41422648, 978889, 228, 4, 34, "Text",ExpressionUUID->"83950b7e-7ecb-4bbd-ab3c-0f7d85239b11"],
Cell[CellGroupData[{
Cell[41422901, 978897, 484, 9, 28, "Input",ExpressionUUID->"2d22c03d-fa87-4829-830f-ebade5efc2ce"],
Cell[41423388, 978908, 265, 4, 32, "Output",ExpressionUUID->"caaad27e-0ff9-4283-bb9c-f8ef3cf5bf01"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41423690, 978917, 843, 16, 28, "Input",ExpressionUUID->"2194f5b0-2dec-4a74-b708-c573270a0420"],
Cell[41424536, 978935, 313, 5, 32, "Output",ExpressionUUID->"ba965e69-61fa-4fdd-84a1-fd7a197cf144"]
}, Open  ]],
Cell[41424864, 978943, 330, 5, 50, "Text",ExpressionUUID->"9a0facfc-8fed-42ef-947d-0acaf9d00f19"],
Cell[41425197, 978950, 173, 3, 34, "Text",ExpressionUUID->"f1d1da29-bfb4-4262-8702-804c88ce7a4c"],
Cell[CellGroupData[{
Cell[41425395, 978957, 969, 16, 28, "Input",ExpressionUUID->"49519ffb-7f98-4bfe-9b2f-1a1b1e6a5dd7"],
Cell[41426367, 978975, 368, 6, 32, "Output",ExpressionUUID->"9f721757-9b05-4b39-b13b-84cf0c84e1e9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41426772, 978986, 646, 14, 28, "Input",ExpressionUUID->"c43fcb26-51b5-4448-bb05-c7f40cb6f5bb"],
Cell[41427421, 979002, 318, 5, 32, "Output",ExpressionUUID->"cd5e8901-aa24-4318-ad31-684d577f1a6a"]
}, Open  ]],
Cell[41427754, 979010, 178, 3, 34, "Text",ExpressionUUID->"634afaed-6fef-48d3-bcd3-abc68909f126"],
Cell[CellGroupData[{
Cell[41427957, 979017, 923, 15, 28, "Input",ExpressionUUID->"f60e5dc3-523b-4cba-b884-ee40d614f218"],
Cell[41428883, 979034, 293, 5, 32, "Output",ExpressionUUID->"362a8054-57f3-4cc6-8137-45e30c656b87"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41429213, 979044, 838, 16, 28, "Input",ExpressionUUID->"c2bcc717-ce00-4c40-8313-03d3e1378fc0"],
Cell[41430054, 979062, 315, 5, 32, "Output",ExpressionUUID->"71103c7a-25df-425c-80e9-b78205d24133"]
}, Open  ]],
Cell[41430384, 979070, 228, 4, 34, "Text",ExpressionUUID->"59d81141-f31a-4162-995d-07bf2cc7c2cb"],
Cell[CellGroupData[{
Cell[41430637, 979078, 565, 10, 28, "Input",ExpressionUUID->"5d22d1cb-5d1b-4f9d-b987-31bdcef81b27"],
Cell[41431205, 979090, 323, 6, 32, "Output",ExpressionUUID->"679163b0-0d82-4ddb-88f2-d3497595f36c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41431565, 979101, 892, 17, 28, "Input",ExpressionUUID->"c5416687-6114-47b1-920a-0946768de353"],
Cell[41432460, 979120, 368, 6, 32, "Output",ExpressionUUID->"c4de6a9c-3342-4a1d-9ca7-8a2323300db8"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[41432877, 979132, 375, 6, 69, "Subsection",ExpressionUUID->"f010d430-1c90-4ed7-81e4-8fac5055d5a6"],
Cell[41433255, 979140, 155, 3, 34, "Text",ExpressionUUID->"1586e777-c654-46f9-a015-aafbe5c204f5"],
Cell[CellGroupData[{
Cell[41433435, 979147, 251, 4, 28, "Input",ExpressionUUID->"b4b7d1e9-b3bc-415c-9599-b79c4a8c55e2"],
Cell[41433689, 979153, 216, 3, 32, "Output",ExpressionUUID->"03aff2b5-51f9-4705-a319-e5c44b0706ba"]
}, Open  ]],
Cell[41433920, 979159, 645, 12, 48, "Input",ExpressionUUID->"07d3457e-7b2a-427a-b5ab-3e2acc9d7fe7"],
Cell[41434568, 979173, 576, 12, 28, "Input",ExpressionUUID->"2e6343e7-601f-47d2-b727-e9d7f7200786"],
Cell[41435147, 979187, 1126, 23, 28, "Input",ExpressionUUID->"9d6a3b6c-6a2a-453e-ab7a-493da085f7be"],
Cell[41436276, 979212, 763, 17, 28, "Input",ExpressionUUID->"ad049d4a-c4e6-4e8f-8461-cbc3e8da1dfe"],
Cell[41437042, 979231, 214, 4, 34, "Text",ExpressionUUID->"ee8345ed-bbc3-497b-a282-4f61929df246"],
Cell[41437259, 979237, 405, 7, 28, "Input",ExpressionUUID->"937967e4-ee8e-4dc6-986d-7d90947cf059"],
Cell[41437667, 979246, 563, 9, 28, "Input",ExpressionUUID->"b3856751-5e0b-4486-be9e-322350ce9e3f"],
Cell[41438233, 979257, 462, 8, 28, "Input",ExpressionUUID->"ad4b39a8-3019-47c6-80a0-5c8b88da99b2"],
Cell[41438698, 979267, 244, 5, 34, "Text",ExpressionUUID->"89097339-fe69-4f73-964e-aa6544022ac0"],
Cell[41438945, 979274, 1497, 26, 28, "Input",ExpressionUUID->"049814c9-8ce4-4f06-b869-512b8d087396"],
Cell[41440445, 979302, 978, 18, 28, "Input",ExpressionUUID->"4e5b7f33-52cd-4b92-bb98-f214b43060a3"],
Cell[41441426, 979322, 199, 3, 34, "Text",ExpressionUUID->"71b69caa-46f3-48fa-8e00-dea727532b39"],
Cell[CellGroupData[{
Cell[41441650, 979329, 1410, 27, 44, "Input",ExpressionUUID->"ab1b5084-de27-499b-b61a-d1b87869b355"],
Cell[41443063, 979358, 2403959, 56357, 394, "Output",ExpressionUUID->"b35fbc28-e18c-4a20-9e8f-6eb3638d5f0a"]
}, Open  ]],
Cell[43847037, 1035718, 197, 3, 34, "Text",ExpressionUUID->"b413ebbd-15f2-4e2a-9441-8a6989493c37"],
Cell[CellGroupData[{
Cell[43847259, 1035725, 1275, 25, 28, "Input",ExpressionUUID->"f33e23ee-2d15-4d5b-ad65-2b29bf8b4eff"],
Cell[43848537, 1035752, 2402197, 56314, 378, "Output",ExpressionUUID->"a6c6db70-9088-4f17-b889-6e33ed4333c4"]
}, Open  ]],
Cell[46250749, 1092069, 253, 4, 34, "Text",ExpressionUUID->"bef87b09-a7be-4ef0-928a-b9fd268c267d"],
Cell[CellGroupData[{
Cell[46251027, 1092077, 1221, 23, 28, "Input",ExpressionUUID->"a67fb919-4481-414b-988b-b845f970dccb"],
Cell[46252251, 1092102, 2466764, 58337, 377, "Output",ExpressionUUID->"8c78aa03-824b-4930-8c2f-b32e45ea0363"]
}, Open  ]],
Cell[48719030, 1150442, 253, 4, 34, "Text",ExpressionUUID->"70cda18f-a692-4a7f-a53a-2f9473089f32"],
Cell[CellGroupData[{
Cell[48719308, 1150450, 1251, 24, 28, "Input",ExpressionUUID->"6ca87953-01e6-4e64-bd7f-93ace413705f"],
Cell[48720562, 1150476, 2465937, 58341, 377, "Output",ExpressionUUID->"5eca06b3-3d68-4fc0-9251-66dc617f1d1c"]
}, Open  ]],
Cell[51186514, 1208820, 299, 4, 34, "Text",ExpressionUUID->"303aa71f-d419-41da-bcbf-8a6b167182db"],
Cell[CellGroupData[{
Cell[51186838, 1208828, 1227, 24, 28, "Input",ExpressionUUID->"af3b01fa-d110-4b6d-a557-746a6985f1fb"],
Cell[51188068, 1208854, 2453945, 57808, 377, "Output",ExpressionUUID->"08cbe25d-f0c6-4b64-8e3a-02fd0e2381e5"]
}, Open  ]],
Cell[53642028, 1266665, 297, 4, 34, "Text",ExpressionUUID->"747af179-7448-4fc3-bfc7-ee2b69cd7286"],
Cell[CellGroupData[{
Cell[53642350, 1266673, 1245, 24, 28, "Input",ExpressionUUID->"7e712cbf-50a7-4a3e-9f62-804c9def8983"],
Cell[53643598, 1266699, 2434658, 57103, 377, "Output",ExpressionUUID->"84bcbe1e-77dd-4cfb-bdce-d9a4686a683c"]
}, Open  ]],
Cell[56078271, 1323805, 282, 5, 50, "Text",ExpressionUUID->"638a35ff-4482-4ed9-b8b1-69050ad62567"],
Cell[56078556, 1323812, 173, 3, 34, "Text",ExpressionUUID->"48231263-48a9-471a-b390-3a0c26317c60"],
Cell[CellGroupData[{
Cell[56078754, 1323819, 908, 14, 28, "Input",ExpressionUUID->"93946396-6b3f-4d32-97c6-87ad9909fbe2"],
Cell[56079665, 1323835, 412, 7, 32, "Output",ExpressionUUID->"0fc48968-ef79-4a4d-87a2-64f14a13e14d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[56080114, 1323847, 581, 12, 28, "Input",ExpressionUUID->"ed0ebc90-a2c0-46dc-848d-b32570bcd90d"],
Cell[56080698, 1323861, 316, 4, 32, "Output",ExpressionUUID->"b4ad57ac-a982-446a-a6e2-47b0e0e0f3fa"]
}, Open  ]],
Cell[56081029, 1323868, 178, 3, 34, "Text",ExpressionUUID->"40da51d5-f6fd-4e64-a058-863561978934"],
Cell[CellGroupData[{
Cell[56081232, 1323875, 868, 14, 28, "Input",ExpressionUUID->"2ae75f92-9d35-477a-9e58-164aa6c0282f"],
Cell[56082103, 1323891, 304, 5, 32, "Output",ExpressionUUID->"f4988226-8727-4be1-bc40-bbc0df9c2fa5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[56082444, 1323901, 784, 15, 28, "Input",ExpressionUUID->"bcd2af4f-6b58-4348-a3f1-e6a885d5e91c"],
Cell[56083231, 1323918, 314, 4, 32, "Output",ExpressionUUID->"6863ccdc-5b18-4088-8031-5e6403ca71f3"]
}, Open  ]],
Cell[56083560, 1323925, 228, 4, 34, "Text",ExpressionUUID->"3e400ad9-1a1e-4df0-89fb-101c924ad045"],
Cell[CellGroupData[{
Cell[56083813, 1323933, 476, 8, 28, "Input",ExpressionUUID->"9277847a-786b-4251-8c9f-5d1162ef2887"],
Cell[56084292, 1323943, 302, 5, 32, "Output",ExpressionUUID->"7a97aae0-d41b-4bab-b0e7-c08e808323d6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[56084631, 1323953, 834, 15, 28, "Input",ExpressionUUID->"bbe3d2fe-e8a8-41ff-88cf-5ef22cd9fe0d"],
Cell[56085468, 1323970, 331, 4, 32, "Output",ExpressionUUID->"0ab68908-fa00-42f3-a558-b759b266df57"]
}, Open  ]],
Cell[56085814, 1323977, 330, 5, 50, "Text",ExpressionUUID->"50abafbe-995b-4cec-80a2-19c5ba216cdb"],
Cell[56086147, 1323984, 173, 3, 34, "Text",ExpressionUUID->"1d4b39de-1768-4ef2-9ce7-87f74e2081e2"],
Cell[CellGroupData[{
Cell[56086345, 1323991, 960, 15, 28, "Input",ExpressionUUID->"d82c8da4-13f5-42f5-b3bd-de40e6f5668d"],
Cell[56087308, 1324008, 408, 7, 32, "Output",ExpressionUUID->"b4ac1afc-d7ca-4738-adca-a662f6d249b2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[56087753, 1324020, 636, 13, 28, "Input",ExpressionUUID->"3114e925-d32a-43eb-b0d3-6630a3016a3f"],
Cell[56088392, 1324035, 335, 4, 32, "Output",ExpressionUUID->"fac5929c-5fae-4d5b-8401-8c0aa2423978"]
}, Open  ]],
Cell[56088742, 1324042, 178, 3, 34, "Text",ExpressionUUID->"c308b8b7-c67a-48bb-b8e6-af30af8a754b"],
Cell[CellGroupData[{
Cell[56088945, 1324049, 913, 14, 28, "Input",ExpressionUUID->"56058984-88b4-43d4-8d12-ad11c26865e1"],
Cell[56089861, 1324065, 315, 4, 32, "Output",ExpressionUUID->"b5cb5c05-70cb-4907-9511-f22c1a977aed"]
}, Open  ]],
Cell[CellGroupData[{
Cell[56090213, 1324074, 831, 15, 28, "Input",ExpressionUUID->"2ebefb86-03a4-4cef-921b-6cbf3f9b5e69"],
Cell[56091047, 1324091, 335, 4, 32, "Output",ExpressionUUID->"8eaada18-139f-451a-96a3-47b49458cf62"]
}, Open  ]],
Cell[56091397, 1324098, 228, 4, 34, "Text",ExpressionUUID->"e6661573-6b9b-4cb8-9392-2d88f04eebc0"],
Cell[CellGroupData[{
Cell[56091650, 1324106, 560, 9, 28, "Input",ExpressionUUID->"c8475b9d-43c6-4091-966c-6405725ccb76"],
Cell[56092213, 1324117, 359, 6, 32, "Output",ExpressionUUID->"fb33b385-89f5-4de2-881c-13b84c25c6b2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[56092609, 1324128, 885, 16, 28, "Input",ExpressionUUID->"55f6699a-799e-40cf-9f2d-0d7d3bd4c7d6"],
Cell[56093497, 1324146, 390, 6, 32, "Output",ExpressionUUID->"7653738a-070c-42b4-9f07-2bb5f9eca8d7"]
}, Open  ]],
Cell[56093902, 1324155, 144, 2, 48, "Input",ExpressionUUID->"b692d413-09f4-4a8d-bae4-b2b85cd0ae4b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[56094083, 1324162, 279, 4, 67, "Section",ExpressionUUID->"844d71d4-3117-4358-86c0-10612141069d"],
Cell[CellGroupData[{
Cell[56094387, 1324170, 426, 6, 60, "Subsubsection",ExpressionUUID->"95fc5c11-b753-421b-8dd0-8b6b3e63b267"],
Cell[56094816, 1324178, 155, 3, 34, "Text",ExpressionUUID->"ff7b6e36-136a-4579-af01-a5f30bffdac6"],
Cell[56094974, 1324183, 701, 14, 48, "Input",ExpressionUUID->"f093f5d7-5c0d-44ad-9318-65c23377cf95"],
Cell[56095678, 1324199, 637, 14, 28, "Input",ExpressionUUID->"c90fec42-8245-42e0-9fda-5e5ae569ddc4"],
Cell[56096318, 1324215, 1208, 25, 28, "Input",ExpressionUUID->"0253f06a-20dd-496e-b270-2ddbb1932ef4"],
Cell[56097529, 1324242, 820, 18, 28, "Input",ExpressionUUID->"31358cde-60e7-4a8d-8fdd-30a18878a2c0"],
Cell[56098352, 1324262, 214, 4, 34, "Text",ExpressionUUID->"f1292779-791b-4f72-b83d-47dd2ccb5534"],
Cell[56098569, 1324268, 464, 9, 28, "Input",ExpressionUUID->"29322f71-0e95-4acf-8250-539d78feb7ff"],
Cell[56099036, 1324279, 620, 11, 28, "Input",ExpressionUUID->"50e1f70c-2232-468d-a2c5-510d749a939b"],
Cell[56099659, 1324292, 519, 10, 28, "Input",ExpressionUUID->"0524bfb2-9c7d-45a5-a0b3-1a72f18f7273"],
Cell[56100181, 1324304, 244, 5, 34, "Text",ExpressionUUID->"8475ad76-9d27-45b9-8839-7b2a713aba33"],
Cell[56100428, 1324311, 1640, 31, 34, "Input",ExpressionUUID->"7f92a9aa-eef6-4d2c-a466-04b2ffca5f2b"],
Cell[56102071, 1324344, 405, 12, 49, "Input",ExpressionUUID->"be41232b-70b5-4cc1-954d-434e72b32d4c"],
Cell[56102479, 1324358, 1079, 20, 28, "Input",ExpressionUUID->"37e30422-2a8c-43b7-975f-5fc6c11200bd"],
Cell[56103561, 1324380, 199, 3, 34, "Text",ExpressionUUID->"26396b60-2395-4ffe-b7cc-57f2e65f3a73"],
Cell[CellGroupData[{
Cell[56103785, 1324387, 1359, 26, 44, "Input",ExpressionUUID->"576e1263-28b7-4db2-bc42-074e9b99a7ca"],
Cell[56105147, 1324415, 385278, 9167, 553, "Output",ExpressionUUID->"3bc5702a-abd1-4f3f-98a4-d583fb27b4d0"]
}, Open  ]],
Cell[56490440, 1333585, 197, 3, 34, "Text",ExpressionUUID->"cd961d7b-2ff0-4721-980b-03002c03709e"],
Cell[CellGroupData[{
Cell[56490662, 1333592, 1407, 26, 28, "Input",ExpressionUUID->"bfef1a34-8b4d-41b8-baa9-4320ade88177"],
Cell[56492072, 1333620, 384678, 9169, 537, "Output",ExpressionUUID->"0733d715-4b86-4203-8c75-c92d3a000163"]
}, Open  ]],
Cell[56876765, 1342792, 253, 4, 34, "Text",ExpressionUUID->"0ac48e38-7d57-4247-8371-fb51c9afad5b"],
Cell[CellGroupData[{
Cell[56877043, 1342800, 1257, 25, 28, "Input",ExpressionUUID->"06f7307a-b318-46bd-b063-b28ed6b0917b"],
Cell[56878303, 1342827, 384893, 9168, 537, "Output",ExpressionUUID->"0131a3d7-8a0a-44c2-bf70-93c5cc2bd52a"]
}, Open  ]],
Cell[57263211, 1351998, 253, 4, 34, "Text",ExpressionUUID->"9f6991ad-2f06-4a9d-8e16-b0c62d13e051"],
Cell[CellGroupData[{
Cell[57263489, 1352006, 1309, 25, 28, "Input",ExpressionUUID->"46a48aca-393d-46b3-a2d7-eac365105fd5"],
Cell[57264801, 1352033, 383285, 9128, 537, "Output",ExpressionUUID->"4fac06e6-6057-4cd4-926f-7ca4957a103a"]
}, Open  ]],
Cell[57648101, 1361164, 299, 4, 34, "Text",ExpressionUUID->"49a7d9c9-303d-4b18-838a-c11ca7776de3"],
Cell[CellGroupData[{
Cell[57648425, 1361172, 1259, 25, 28, "Input",ExpressionUUID->"2c281a42-d563-49eb-a011-dfad985ea8c6"],
Cell[57649687, 1361199, 376518, 8811, 537, "Output",ExpressionUUID->"6aec6de7-42d7-41c6-a086-8e02435689da"]
}, Open  ]],
Cell[58026220, 1370013, 297, 4, 34, "Text",ExpressionUUID->"5e5893a2-3fe5-4150-8255-5641a33f5a5a"],
Cell[CellGroupData[{
Cell[58026542, 1370021, 1301, 25, 28, "Input",ExpressionUUID->"08ca981a-7106-4a9c-b1a9-9dec9ab97d94"],
Cell[58027846, 1370048, 381008, 9028, 537, "Output",ExpressionUUID->"461f90db-af0e-4055-b152-e2259715f342"]
}, Open  ]],
Cell[58408869, 1379079, 282, 5, 50, "Text",ExpressionUUID->"9ba526e9-351a-4fe2-b804-7b2aa6b3e77b"],
Cell[58409154, 1379086, 173, 3, 34, "Text",ExpressionUUID->"0c97c55f-9a9a-4463-8f81-c8faa564c1a3"],
Cell[CellGroupData[{
Cell[58409352, 1379093, 969, 16, 28, "Input",ExpressionUUID->"ba13801f-5532-4b86-ac7f-c77fdfacde84"],
Cell[58410324, 1379111, 441, 8, 32, "Output",ExpressionUUID->"a9269c28-ab73-4d03-bea8-7540304abedd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[58410802, 1379124, 638, 14, 28, "Input",ExpressionUUID->"9c4692c7-138d-4aed-9469-974e1cb46585"],
Cell[58411443, 1379140, 344, 5, 32, "Output",ExpressionUUID->"84c8beb6-6803-4988-a7b9-cfe88759e17a"]
}, Open  ]],
Cell[58411802, 1379148, 178, 3, 34, "Text",ExpressionUUID->"12273fa0-27a4-45bc-9b18-689582521376"],
Cell[CellGroupData[{
Cell[58412005, 1379155, 923, 15, 28, "Input",ExpressionUUID->"2f1de749-fd40-43eb-8746-03cfab3497b6"],
Cell[58412931, 1379172, 313, 5, 32, "Output",ExpressionUUID->"b25df181-741b-48a4-a3c8-b6c1d7576d79"]
}, Open  ]],
Cell[CellGroupData[{
Cell[58413281, 1379182, 840, 16, 28, "Input",ExpressionUUID->"d4bc1470-3e2f-413b-8421-e0c125a43e68"],
Cell[58414124, 1379200, 342, 5, 32, "Output",ExpressionUUID->"10e9f0be-2cb9-4eb6-8c13-404dabe3b4df"]
}, Open  ]],
Cell[58414481, 1379208, 228, 4, 34, "Text",ExpressionUUID->"03e86a48-2a10-4672-b467-f4078ce3a9b1"],
Cell[CellGroupData[{
Cell[58414734, 1379216, 532, 10, 28, "Input",ExpressionUUID->"e26434b5-9337-443a-a486-70c1d4563738"],
Cell[58415269, 1379228, 313, 5, 32, "Output",ExpressionUUID->"1a86551f-417d-4233-b818-cc1e72e466ea"]
}, Open  ]],
Cell[CellGroupData[{
Cell[58415619, 1379238, 894, 17, 28, "Input",ExpressionUUID->"4598ee76-d098-42a2-8f90-fba06843f192"],
Cell[58416516, 1379257, 360, 6, 32, "Output",ExpressionUUID->"dd2d7bf0-fba7-46b8-9ba0-4d6bd9344b6e"]
}, Open  ]],
Cell[58416891, 1379266, 330, 5, 50, "Text",ExpressionUUID->"c8c03353-05ea-42fc-b7ab-bd9ff0286ca4"],
Cell[58417224, 1379273, 173, 3, 34, "Text",ExpressionUUID->"f81a93a5-b160-4612-bb0d-a5fc29bd2410"],
Cell[CellGroupData[{
Cell[58417422, 1379280, 1014, 16, 28, "Input",ExpressionUUID->"0e72c27e-71cb-4889-a853-d2448803fded"],
Cell[58418439, 1379298, 415, 7, 32, "Output",ExpressionUUID->"4c0e8fa5-c04d-4acf-84d5-22206acb7369"]
}, Open  ]],
Cell[CellGroupData[{
Cell[58418891, 1379310, 692, 14, 28, "Input",ExpressionUUID->"b3c79e45-2f94-46aa-ac74-1a28fec009fd"],
Cell[58419586, 1379326, 173, 3, 32, "Output",ExpressionUUID->"f4c2e7d7-8306-451b-958e-92211254ac90"]
}, Open  ]],
Cell[58419774, 1379332, 178, 3, 34, "Text",ExpressionUUID->"cff59d8e-1843-414a-ac02-b8d1d3e2dd22"],
Cell[CellGroupData[{
Cell[58419977, 1379339, 972, 16, 28, "Input",ExpressionUUID->"397d9cd1-759a-468a-b7fb-1cf0acbca9f7"],
Cell[58420952, 1379357, 173, 3, 32, "Output",ExpressionUUID->"dc9951e3-91f4-4697-839b-55c0ff8f5d01"]
}, Open  ]],
Cell[CellGroupData[{
Cell[58421162, 1379365, 888, 17, 28, "Input",ExpressionUUID->"ab9e04a0-5df4-4262-99ec-d2223749d612"],
Cell[58422053, 1379384, 171, 3, 32, "Output",ExpressionUUID->"b111e924-82ad-4f18-9b29-3563867101dc"]
}, Open  ]],
Cell[58422239, 1379390, 228, 4, 34, "Text",ExpressionUUID->"09e10526-35f8-4601-b88a-e8562e6b8407"],
Cell[CellGroupData[{
Cell[58422492, 1379398, 617, 11, 28, "Input",ExpressionUUID->"e686cbe5-2306-4a09-a294-2de1879f4970"],
Cell[58423112, 1379411, 173, 3, 32, "Output",ExpressionUUID->"b06066e8-7bf7-46fb-b629-419d2a8c3c9b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[58423322, 1379419, 947, 18, 28, "Input",ExpressionUUID->"650d1bef-a4bd-4d11-9a32-ad935e05b661"],
Cell[58424272, 1379439, 416, 7, 32, "Output",ExpressionUUID->"7106b89b-b412-4c24-a2c6-f0e8b6418ee4"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[58424737, 1379452, 482, 7, 60, "Subsubsection",ExpressionUUID->"90786880-b2cf-4e40-a278-d6cbfabc00f1"],
Cell[58425222, 1379461, 155, 3, 34, "Text",ExpressionUUID->"efc4fdec-8a2f-465a-9098-f176786ad0c2"],
Cell[58425380, 1379466, 749, 14, 48, "Input",ExpressionUUID->"dbd1cadb-cd16-4a84-87f4-62fa2f8a3f0a"],
Cell[58426132, 1379482, 689, 15, 28, "Input",ExpressionUUID->"50bde2a6-8cda-435e-bc95-1878f05db12f"],
Cell[58426824, 1379499, 1258, 26, 28, "Input",ExpressionUUID->"ae403df9-126d-472f-a0fb-a326a83e894a"],
Cell[58428085, 1379527, 871, 19, 28, "Input",ExpressionUUID->"7b461e93-b132-478b-a5b7-d5c63deb1c9c"],
Cell[58428959, 1379548, 214, 4, 34, "Text",ExpressionUUID->"0a736082-11b0-4409-9551-5faf25d8f263"],
Cell[58429176, 1379554, 515, 10, 28, "Input",ExpressionUUID->"5edb92fe-eac4-4b7c-af70-cc6c9c185641"],
Cell[58429694, 1379566, 669, 12, 28, "Input",ExpressionUUID->"011f2fea-0841-4d51-bc73-e24c715cb0b0"],
Cell[58430366, 1379580, 567, 10, 28, "Input",ExpressionUUID->"debe8563-9192-4996-9b85-e8ef150a7fc9"],
Cell[58430936, 1379592, 244, 5, 34, "Text",ExpressionUUID->"4b0bd60c-12d4-40dd-b89d-27a2d2c09205"],
Cell[58431183, 1379599, 1692, 32, 34, "Input",ExpressionUUID->"565b3db8-6c2d-46e2-9bd3-46d406e78722"],
Cell[58432878, 1379633, 1131, 21, 28, "Input",ExpressionUUID->"6769742d-9fc3-4ece-ab57-a35cde633ffd"],
Cell[58434012, 1379656, 199, 3, 34, "Text",ExpressionUUID->"f03f2fae-2ced-4eac-acae-bad5dd92775c"],
Cell[CellGroupData[{
Cell[58434236, 1379663, 1415, 27, 44, "Input",ExpressionUUID->"b2feeb9c-5af5-4766-af61-faa0067bd900"],
Cell[58435654, 1379692, 957017, 22719, 512, "Output",ExpressionUUID->"312ed183-4b63-4269-a99f-8bdf86060afe"]
}, Open  ]],
Cell[59392686, 1402414, 197, 3, 34, "Text",ExpressionUUID->"1c89ef30-1e35-49eb-ab8b-535d2f8c92a4"],
Cell[CellGroupData[{
Cell[59392908, 1402421, 1433, 27, 28, "Input",ExpressionUUID->"d210dcda-70d8-466c-b24a-2d0911b2d61c"],
Cell[59394344, 1402450, 957142, 22717, 496, "Output",ExpressionUUID->"d8669d65-1a9f-4ec6-983e-3965cb663bfb"]
}, Open  ]],
Cell[60351501, 1425170, 253, 4, 34, "Text",ExpressionUUID->"f4d46856-d76e-4ff8-bacb-726bf0cfec1e"],
Cell[CellGroupData[{
Cell[60351779, 1425178, 1334, 26, 28, "Input",ExpressionUUID->"8b1cada5-b6cb-40ae-9a02-876c52b33cea"],
Cell[60353116, 1425206, 956668, 22712, 496, "Output",ExpressionUUID->"39dde4e3-ad9d-41f6-92cc-a7e90d80aff5"]
}, Open  ]],
Cell[61309799, 1447921, 253, 4, 34, "Text",ExpressionUUID->"b9119875-642a-47f4-aa6e-3a86fea24f14"],
Cell[CellGroupData[{
Cell[61310077, 1447929, 1361, 26, 28, "Input",ExpressionUUID->"7adbd969-86c2-4578-93f4-2b48caa0b04e"],
Cell[61311441, 1447957, 954969, 22713, 496, "Output",ExpressionUUID->"c6fd1b61-a5a6-48d6-b092-8b7d490d6927"]
}, Open  ]],
Cell[62266425, 1470673, 299, 4, 34, "Text",ExpressionUUID->"5c5e2603-db64-4465-8e0b-e308b6af8ad6"],
Cell[CellGroupData[{
Cell[62266749, 1470681, 1311, 26, 28, "Input",ExpressionUUID->"4be3761e-29f9-4781-9a4d-4cc74e0635be"],
Cell[62268063, 1470709, 952699, 22565, 496, "Output",ExpressionUUID->"4d1ef9e4-76e6-4328-92aa-23229c8cea6d"]
}, Open  ]],
Cell[63220777, 1493277, 297, 4, 34, "Text",ExpressionUUID->"91af8448-7321-4995-817f-b1cb5dca8b2e"],
Cell[CellGroupData[{
Cell[63221099, 1493285, 1353, 26, 28, "Input",ExpressionUUID->"40d8e244-b219-475c-a52b-0453871397c0"],
Cell[63222455, 1493313, 948883, 22449, 496, "Output",ExpressionUUID->"3ef8a954-1880-49b8-8747-538b684f5a3e"]
}, Open  ]],
Cell[64171353, 1515765, 282, 5, 50, "Text",ExpressionUUID->"be83a52e-2012-4715-a6dd-47e745341e26"],
Cell[64171638, 1515772, 173, 3, 34, "Text",ExpressionUUID->"b8eb9a61-f178-41c7-bc62-556a7de813a9"],
Cell[CellGroupData[{
Cell[64171836, 1515779, 1017, 16, 28, "Input",ExpressionUUID->"5a134436-27d9-4446-ab53-2ec1a81d9e29"],
Cell[64172856, 1515797, 446, 7, 32, "Output",ExpressionUUID->"fb542281-fc39-4c15-8402-ac9dedd43858"]
}, Open  ]],
Cell[CellGroupData[{
Cell[64173339, 1515809, 684, 14, 28, "Input",ExpressionUUID->"f5dfedcc-774d-4aae-833a-5374a95d972d"],
Cell[64174026, 1515825, 370, 6, 32, "Output",ExpressionUUID->"a42f2c11-87a2-477f-af88-68226e30ceaa"]
}, Open  ]],
Cell[64174411, 1515834, 178, 3, 34, "Text",ExpressionUUID->"b81a236b-30f6-4732-a775-3078aa5ef218"],
Cell[CellGroupData[{
Cell[64174614, 1515841, 977, 16, 28, "Input",ExpressionUUID->"e04a8e28-1a0e-4530-a6d8-0fa0b908c171"],
Cell[64175594, 1515859, 339, 5, 32, "Output",ExpressionUUID->"9ab8e16d-08f8-4fcf-9a88-2cc0f7ca6017"]
}, Open  ]],
Cell[CellGroupData[{
Cell[64175970, 1515869, 889, 17, 28, "Input",ExpressionUUID->"c7373dd7-f896-441e-88df-49ca59d0e4bd"],
Cell[64176862, 1515888, 370, 6, 32, "Output",ExpressionUUID->"32740761-e67e-4461-b0eb-8274ad310349"]
}, Open  ]],
Cell[64177247, 1515897, 228, 4, 34, "Text",ExpressionUUID->"2c16078e-ff5d-40c9-92a5-6b2b53ac45fc"],
Cell[CellGroupData[{
Cell[64177500, 1515905, 580, 10, 28, "Input",ExpressionUUID->"4198ec48-8b1b-48b2-b16b-011aa0d688b3"],
Cell[64178083, 1515917, 336, 5, 32, "Output",ExpressionUUID->"4d035f0c-7fba-4134-b9fb-c69436e71a89"]
}, Open  ]],
Cell[CellGroupData[{
Cell[64178456, 1515927, 945, 18, 28, "Input",ExpressionUUID->"d17bc570-1013-457b-b343-bf6dc6356c25"],
Cell[64179404, 1515947, 382, 6, 32, "Output",ExpressionUUID->"bab25f0b-c502-4b27-8e3c-650a2125fe62"]
}, Open  ]],
Cell[64179801, 1515956, 330, 5, 50, "Text",ExpressionUUID->"d8794f78-2e6f-4e22-ae76-b4f5c0b2c486"],
Cell[64180134, 1515963, 173, 3, 34, "Text",ExpressionUUID->"e4fbeb5f-05ab-4566-8a3e-025a533a9cff"],
Cell[CellGroupData[{
Cell[64180332, 1515970, 1068, 17, 28, "Input",ExpressionUUID->"201acab1-f393-473c-801f-7a9db8790d71"],
Cell[64181403, 1515989, 438, 7, 32, "Output",ExpressionUUID->"e371ba5b-08da-4f15-af27-4c37f34f5723"]
}, Open  ]],
Cell[CellGroupData[{
Cell[64181878, 1516001, 742, 15, 28, "Input",ExpressionUUID->"596dc53c-3d95-40ac-8b69-4d08f60c0197"],
Cell[64182623, 1516018, 197, 3, 32, "Output",ExpressionUUID->"fb9cbb82-28a7-433e-a0f1-1285c99f3408"]
}, Open  ]],
Cell[64182835, 1516024, 178, 3, 34, "Text",ExpressionUUID->"0cd2f5cd-9f17-4a4d-b1a2-ff1ab60250c9"],
Cell[CellGroupData[{
Cell[64183038, 1516031, 1024, 17, 28, "Input",ExpressionUUID->"58ca0f15-aa25-4ac7-a627-0aad6f193b5a"],
Cell[64184065, 1516050, 199, 3, 32, "Output",ExpressionUUID->"31aef872-43da-4388-8c2d-efbc384273bb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[64184301, 1516058, 937, 18, 28, "Input",ExpressionUUID->"4b160daf-3940-4e12-9fca-7ec4069394ff"],
Cell[64185241, 1516078, 195, 3, 32, "Output",ExpressionUUID->"224f6f29-c030-496f-bce5-ce905d448f14"]
}, Open  ]],
Cell[64185451, 1516084, 228, 4, 34, "Text",ExpressionUUID->"867e3058-47fb-4ef3-a09b-1954aa6ab787"],
Cell[CellGroupData[{
Cell[64185704, 1516092, 667, 11, 28, "Input",ExpressionUUID->"6401bce2-abe5-4927-9b18-c216607a298c"],
Cell[64186374, 1516105, 195, 3, 32, "Output",ExpressionUUID->"93a323bc-2665-4205-aed0-d69bba00f2b2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[64186606, 1516113, 995, 18, 28, "Input",ExpressionUUID->"663bba6f-2e80-434d-8929-84f62ee4b243"],
Cell[64187604, 1516133, 437, 7, 32, "Output",ExpressionUUID->"9cd8dbbf-5c54-4a14-91c5-b37efedb7e0c"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[64188090, 1516146, 534, 8, 60, "Subsubsection",ExpressionUUID->"a4db78ef-7a58-4f88-a8b2-c5287bac2b38"],
Cell[64188627, 1516156, 155, 3, 34, "Text",ExpressionUUID->"4c8747e8-bb53-4d55-b21a-5f5bc25b12b8"],
Cell[64188785, 1516161, 801, 15, 48, "Input",ExpressionUUID->"3ed41cb5-e6f4-469a-962f-97293fe28eed"],
Cell[64189589, 1516178, 743, 16, 28, "Input",ExpressionUUID->"0a4754dc-d319-4850-9462-1ede3427b644"],
Cell[64190335, 1516196, 1306, 26, 28, "Input",ExpressionUUID->"d2eeba59-cb45-4f7f-8cbf-c75c728a7706"],
Cell[64191644, 1516224, 924, 20, 28, "Input",ExpressionUUID->"2676c9bc-ccd7-4d51-bac5-996823ad4016"],
Cell[64192571, 1516246, 214, 4, 34, "Text",ExpressionUUID->"63dcfffe-bcaa-44c3-8d6a-85f185bf79c5"],
Cell[64192788, 1516252, 563, 10, 28, "Input",ExpressionUUID->"630b6a06-f5b3-48e5-abf3-95f048802efc"],
Cell[64193354, 1516264, 719, 12, 28, "Input",ExpressionUUID->"66fd5685-8711-4c8b-994a-b67b1c93b114"],
Cell[64194076, 1516278, 616, 11, 28, "Input",ExpressionUUID->"ecfee441-d4ab-4491-8d4c-e040b4f87942"],
Cell[64194695, 1516291, 244, 5, 34, "Text",ExpressionUUID->"86141401-c6e6-4cbc-8159-b75ac2db0b11"],
Cell[64194942, 1516298, 1744, 33, 34, "Input",ExpressionUUID->"efe6f09e-4864-423a-b56d-fcbfddcdaadd"],
Cell[64196689, 1516333, 1185, 22, 28, "Input",ExpressionUUID->"b26f82c0-ef37-4132-9351-9fbba83ba614"],
Cell[64197877, 1516357, 199, 3, 34, "Text",ExpressionUUID->"89229ce0-630a-47d3-a89e-55d49d93217b"],
Cell[CellGroupData[{
Cell[64198101, 1516364, 1493, 28, 44, "Input",ExpressionUUID->"d0f2b8b8-6d39-48d5-9d8c-c672d3b622eb"],
Cell[64199597, 1516394, 1397255, 33074, 501, "Output",ExpressionUUID->"40310f2e-de89-4200-8598-42f7b6e3017b"]
}, Open  ]],
Cell[65596867, 1549471, 197, 3, 34, "Text",ExpressionUUID->"aa8fe70b-9ede-4d12-8a35-a985bb556b4d"],
Cell[CellGroupData[{
Cell[65597089, 1549478, 1552, 28, 28, "Input",ExpressionUUID->"34657f3a-f2d5-428e-b03a-958670cfcbd6"],
Cell[65598644, 1549508, 1395372, 33063, 485, "Output",ExpressionUUID->"e116e124-afc7-4a15-9fa0-e4c1fb582862"]
}, Open  ]],
Cell[66994031, 1582574, 253, 4, 34, "Text",ExpressionUUID->"0e921e27-d36a-4b07-aeb5-e544c35320f1"],
Cell[CellGroupData[{
Cell[66994309, 1582582, 1359, 26, 28, "Input",ExpressionUUID->"7ede751f-091b-453c-8db6-e622bb73c640"],
Cell[66995671, 1582610, 1391869, 33016, 485, "Output",ExpressionUUID->"56c87920-5717-454f-a542-41ab6f888b45"]
}, Open  ]],
Cell[68387555, 1615629, 253, 4, 34, "Text",ExpressionUUID->"4bdf7cd2-84d2-4523-80d9-d3ef8d0b79ce"],
Cell[CellGroupData[{
Cell[68387833, 1615637, 1464, 28, 28, "Input",ExpressionUUID->"44b5cc8c-69d2-4b56-ac7b-538aac84629b"],
Cell[68389300, 1615667, 1393700, 33062, 485, "Output",ExpressionUUID->"e7435964-3f5c-4e37-94a7-415ecd80df62"]
}, Open  ]],
Cell[69783015, 1648732, 299, 4, 34, "Text",ExpressionUUID->"280835c7-c823-4f93-a3a7-0cd86641e893"],
Cell[CellGroupData[{
Cell[69783339, 1648740, 1356, 26, 28, "Input",ExpressionUUID->"e4c3debb-322e-4fe2-a471-5cd47bb31e4c"],
Cell[69784698, 1648768, 1383621, 32681, 485, "Output",ExpressionUUID->"bf46630e-b634-4e07-95a2-e8b33b19dc35"]
}, Open  ]],
Cell[71168334, 1681452, 297, 4, 34, "Text",ExpressionUUID->"1bb26158-719f-4919-b31b-594eb5cd317d"],
Cell[CellGroupData[{
Cell[71168656, 1681460, 1405, 27, 28, "Input",ExpressionUUID->"4f878fbd-a4c0-4fdc-8f89-b35fb84bf10d"],
Cell[71170064, 1681489, 1274046, 29199, 485, "Output",ExpressionUUID->"c88d001b-50cb-4cfe-924c-1b2cfd3fe79d"]
}, Open  ]],
Cell[72444125, 1710691, 282, 5, 50, "Text",ExpressionUUID->"3c7c8ddb-37cd-4a5c-a829-31cd8949965f"],
Cell[72444410, 1710698, 173, 3, 34, "Text",ExpressionUUID->"feede5ba-18df-4d32-a93c-90cc71fd9359"],
Cell[CellGroupData[{
Cell[72444608, 1710705, 1067, 17, 28, "Input",ExpressionUUID->"7a48aefa-4ea7-4be6-a2f9-1ca3541d7893"],
Cell[72445678, 1710724, 190, 4, 32, "Output",ExpressionUUID->"f84c09d4-f2a1-4e56-86b8-58b64dd53d71"]
}, Open  ]],
Cell[CellGroupData[{
Cell[72445905, 1710733, 732, 15, 28, "Input",ExpressionUUID->"bec5ba1b-1582-4e1e-8884-56017445ca14"],
Cell[72446640, 1710750, 170, 3, 32, "Output",ExpressionUUID->"cbde283f-24fd-4976-b594-c8a468b3b470"]
}, Open  ]],
Cell[72446825, 1710756, 178, 3, 34, "Text",ExpressionUUID->"001e26e5-3f71-450d-9060-6d6966e8a326"],
Cell[CellGroupData[{
Cell[72447028, 1710763, 1029, 17, 28, "Input",ExpressionUUID->"de53270d-ca1b-48b1-a1d8-44e998010a66"],
Cell[72448060, 1710782, 215, 4, 32, "Output",ExpressionUUID->"d48c0c20-8732-4deb-beb1-a7bf11501aff"]
}, Open  ]],
Cell[CellGroupData[{
Cell[72448312, 1710791, 942, 18, 28, "Input",ExpressionUUID->"b42f852d-9f41-4d91-afe7-e5fd89976480"],
Cell[72449257, 1710811, 198, 3, 32, "Output",ExpressionUUID->"a5f8cc94-06c8-4a7e-91b2-a34eb95b4555"]
}, Open  ]],
Cell[72449470, 1710817, 228, 4, 34, "Text",ExpressionUUID->"7d5d6436-17dd-4962-b56e-5493a271d6a6"],
Cell[CellGroupData[{
Cell[72449723, 1710825, 630, 11, 28, "Input",ExpressionUUID->"b88baa71-3cca-4447-98fb-0caea92f78f8"],
Cell[72450356, 1710838, 175, 3, 32, "Output",ExpressionUUID->"73c06800-e265-42cd-98c0-a523e354f529"]
}, Open  ]],
Cell[CellGroupData[{
Cell[72450568, 1710846, 991, 18, 28, "Input",ExpressionUUID->"05cdcac9-9a65-4901-8252-107fe25d4edd"],
Cell[72451562, 1710866, 171, 3, 32, "Output",ExpressionUUID->"d7b060e6-53ca-4c6e-a333-a504086541f9"]
}, Open  ]],
Cell[72451748, 1710872, 330, 5, 50, "Text",ExpressionUUID->"2fd1598a-a323-4bf5-890a-c146bf0916be"],
Cell[72452081, 1710879, 173, 3, 34, "Text",ExpressionUUID->"f2e329f0-a822-407d-8854-f40cf282ea36"],
Cell[CellGroupData[{
Cell[72452279, 1710886, 1120, 18, 28, "Input",ExpressionUUID->"7fa5a6a6-a381-434c-a149-aef232283536"],
Cell[72453402, 1710906, 192, 4, 32, "Output",ExpressionUUID->"75d38084-9276-47e3-be31-1c355027cafb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[72453631, 1710915, 793, 16, 28, "Input",ExpressionUUID->"02a5414b-19ba-4376-a656-85af6eadd63a"],
Cell[72454427, 1710933, 172, 3, 32, "Output",ExpressionUUID->"0d59a7e4-2c87-440a-ba1f-e14724e0bb07"]
}, Open  ]],
Cell[72454614, 1710939, 178, 3, 34, "Text",ExpressionUUID->"fcef3faf-6078-4a1f-9a22-22b88b9d99c4"],
Cell[CellGroupData[{
Cell[72454817, 1710946, 1074, 17, 28, "Input",ExpressionUUID->"c90c08b5-2733-4b15-82ec-9299bedbd6ce"],
Cell[72455894, 1710965, 192, 4, 32, "Output",ExpressionUUID->"a84c7970-0d10-46e4-9081-1a5256e961fb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[72456123, 1710974, 985, 18, 28, "Input",ExpressionUUID->"24d332b9-6cfb-4524-99c2-1053da95ac63"],
Cell[72457111, 1710994, 173, 3, 32, "Output",ExpressionUUID->"95da2fe4-a330-40b4-b4d2-f8c3468ace04"]
}, Open  ]],
Cell[72457299, 1711000, 228, 4, 34, "Text",ExpressionUUID->"8a8e2b29-ae19-47a5-8325-81e1227bdaf6"],
Cell[CellGroupData[{
Cell[72457552, 1711008, 717, 12, 28, "Input",ExpressionUUID->"f2ca6b21-67d2-4826-849e-1188b80131f2"],
Cell[72458272, 1711022, 190, 4, 32, "Output",ExpressionUUID->"06336cd6-c14d-4998-8869-598740b9d5ec"]
}, Open  ]],
Cell[CellGroupData[{
Cell[72458499, 1711031, 1046, 19, 28, "Input",ExpressionUUID->"8eb9c716-c50c-40a9-991b-e7e7ad8b4114"],
Cell[72459548, 1711052, 174, 3, 32, "Output",ExpressionUUID->"aa38ac65-86e3-494e-ad51-febee2470858"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[72459771, 1711061, 532, 8, 60, "Subsubsection",ExpressionUUID->"114d7fd3-fd5e-4ff7-856a-d43e52796c84"],
Cell[72460306, 1711071, 155, 3, 34, "Text",ExpressionUUID->"a888e8e8-018c-4a79-96d3-c8174daf9465"],
Cell[72460464, 1711076, 801, 15, 48, "Input",ExpressionUUID->"5db6ca12-1026-4523-9b36-8f9a8d13b937"],
Cell[72461268, 1711093, 741, 16, 28, "Input",ExpressionUUID->"19275f9c-42ad-4738-9ccb-049a720cb7af"],
Cell[72462012, 1711111, 1308, 26, 28, "Input",ExpressionUUID->"ce738fb6-4f56-4ea0-8280-d7f349ea4c02"],
Cell[72463323, 1711139, 922, 20, 28, "Input",ExpressionUUID->"88298bea-6872-4804-93e3-857215cb835d"],
Cell[72464248, 1711161, 214, 4, 34, "Text",ExpressionUUID->"8a0b0f10-cf73-49c6-961e-1cc1af3b15bc"],
Cell[72464465, 1711167, 561, 10, 28, "Input",ExpressionUUID->"ca8cb445-24fb-4e93-8eb0-b50180356b8a"],
Cell[72465029, 1711179, 719, 12, 28, "Input",ExpressionUUID->"995ad1dc-2414-4186-97a1-2520641747e1"],
Cell[72465751, 1711193, 620, 11, 28, "Input",ExpressionUUID->"251b0aab-3cdc-447f-bac8-b00ec0a64fca"],
Cell[72466374, 1711206, 244, 5, 34, "Text",ExpressionUUID->"b1b0d1b5-6876-4ab9-b0de-438b9c3846c7"],
Cell[72466621, 1711213, 1744, 33, 34, "Input",ExpressionUUID->"2304350e-9807-4d85-8077-329c813db2ea"],
Cell[72468368, 1711248, 1183, 22, 28, "Input",ExpressionUUID->"7a8cf8a0-28be-4658-83c8-aa934dfb0672"],
Cell[72469554, 1711272, 199, 3, 34, "Text",ExpressionUUID->"aacd7fb4-7216-4f65-af8d-50a1dd7c0102"],
Cell[CellGroupData[{
Cell[72469778, 1711279, 1540, 29, 44, "Input",ExpressionUUID->"5e421fc3-5b16-4f9a-8412-1e4dc51f87f4"],
Cell[72471321, 1711310, 2063186, 48881, 578, "Output",ExpressionUUID->"1581a78b-c893-439d-a9ca-3ed118777aa6"]
}, Open  ]],
Cell[74534522, 1760194, 197, 3, 34, "Text",ExpressionUUID->"1399239a-bf75-4485-85ec-e94cf5814652"],
Cell[CellGroupData[{
Cell[74534744, 1760201, 1527, 28, 28, "Input",ExpressionUUID->"ae370df5-92ec-4842-8260-fded7e430289"],
Cell[74536274, 1760231, 2059970, 48874, 562, "Output",ExpressionUUID->"e0bb0494-d322-4d44-b08b-bbe30d06a05d"]
}, Open  ]],
Cell[76596259, 1809108, 253, 4, 34, "Text",ExpressionUUID->"1f247f63-64c4-418c-bfb8-f4fff5c40ce3"],
Cell[CellGroupData[{
Cell[76596537, 1809116, 1357, 26, 28, "Input",ExpressionUUID->"1d734512-e52f-42bf-9bfc-b77483f7a9f1"],
Cell[76597897, 1809144, 2059731, 48876, 563, "Output",ExpressionUUID->"5e56f9e7-410a-4287-9d19-4f3b995d3f71"]
}, Open  ]],
Cell[78657643, 1858023, 253, 4, 34, "Text",ExpressionUUID->"5a510703-e1ea-4994-93f2-5538f07d3c6c"],
Cell[CellGroupData[{
Cell[78657921, 1858031, 1411, 27, 28, "Input",ExpressionUUID->"78b19c96-b418-452a-b4f3-add8e9d71595"],
Cell[78659335, 1858060, 2059894, 48874, 563, "Output",ExpressionUUID->"2f9785d6-10c6-46c7-a325-4c1c6379537a"]
}, Open  ]],
Cell[80719244, 1906937, 299, 4, 34, "Text",ExpressionUUID->"f503430c-0327-477b-95c6-28ec80df9ba0"],
Cell[CellGroupData[{
Cell[80719568, 1906945, 1359, 26, 28, "Input",ExpressionUUID->"54fe7390-3203-4a26-877e-427844a1f6d3"],
Cell[80720930, 1906973, 2012547, 47037, 563, "Output",ExpressionUUID->"f876ef1b-cad8-459a-b86f-42adc8e76765"]
}, Open  ]],
Cell[82733492, 1954013, 297, 4, 34, "Text",ExpressionUUID->"32cc93a8-cede-4827-bb46-858e9816ddae"],
Cell[CellGroupData[{
Cell[82733814, 1954021, 1405, 27, 28, "Input",ExpressionUUID->"42e52372-481f-4e6c-9597-f17b30180536"],
Cell[82735222, 1954050, 2037686, 47959, 563, "Output",ExpressionUUID->"f75ba1e6-ccf0-435a-88ef-2f3e9c8d778e"]
}, Open  ]],
Cell[84772923, 2002012, 282, 5, 50, "Text",ExpressionUUID->"71a49330-cf07-48d0-901a-b9ea12f5d4c6"],
Cell[84773208, 2002019, 173, 3, 34, "Text",ExpressionUUID->"c3869e81-af2b-491c-bdf7-463dfc8129f1"],
Cell[CellGroupData[{
Cell[84773406, 2002026, 1071, 17, 28, "Input",ExpressionUUID->"3a84defb-4866-45aa-83a6-6f2b7cc7465f"],
Cell[84774480, 2002045, 489, 9, 32, "Output",ExpressionUUID->"d2f77a14-4f71-433b-a881-32e6553a4e87"]
}, Open  ]],
Cell[CellGroupData[{
Cell[84775006, 2002059, 733, 15, 28, "Input",ExpressionUUID->"536d270a-ad72-4a82-ac3a-4d4d94e37ee0"],
Cell[84775742, 2002076, 392, 6, 32, "Output",ExpressionUUID->"9995dcad-36c4-4e86-b65c-ade5bbd35b15"]
}, Open  ]],
Cell[84776149, 2002085, 178, 3, 34, "Text",ExpressionUUID->"1f127eaf-fc42-4613-a3c1-fba593164f06"],
Cell[CellGroupData[{
Cell[84776352, 2002092, 1026, 17, 28, "Input",ExpressionUUID->"0fc598f8-8cec-4937-b762-89f06098d1fb"],
Cell[84777381, 2002111, 381, 7, 32, "Output",ExpressionUUID->"9a2be8dc-9fe6-4e94-9075-e8bab7739706"]
}, Open  ]],
Cell[CellGroupData[{
Cell[84777799, 2002123, 938, 18, 28, "Input",ExpressionUUID->"90ee2376-6e9a-4655-8258-ca96f1e1978f"],
Cell[84778740, 2002143, 393, 6, 32, "Output",ExpressionUUID->"491d505f-3112-4292-b15f-b33c6825644a"]
}, Open  ]],
Cell[84779148, 2002152, 228, 4, 34, "Text",ExpressionUUID->"2448f64e-8222-4229-aae8-f5eacec897fe"],
Cell[CellGroupData[{
Cell[84779401, 2002160, 631, 11, 28, "Input",ExpressionUUID->"e765810b-6559-4870-9ce9-1b2f4afe1c24"],
Cell[84780035, 2002173, 379, 7, 32, "Output",ExpressionUUID->"4c8a94a3-b16c-42ba-a558-677f0fdaef7f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[84780451, 2002185, 991, 18, 28, "Input",ExpressionUUID->"ab4626bd-0416-4936-bf89-cfb61bedfe6f"],
Cell[84781445, 2002205, 406, 6, 32, "Output",ExpressionUUID->"a088fca4-86c3-4009-8afe-72b150502dda"]
}, Open  ]],
Cell[84781866, 2002214, 330, 5, 50, "Text",ExpressionUUID->"c5d3bffd-6229-4603-b6ad-f76afb32a885"],
Cell[84782199, 2002221, 173, 3, 34, "Text",ExpressionUUID->"aef04940-6bc9-4015-9228-bba48dacf7bc"],
Cell[CellGroupData[{
Cell[84782397, 2002228, 1118, 18, 28, "Input",ExpressionUUID->"9611d735-087e-4fde-9c76-27436b0d5504"],
Cell[84783518, 2002248, 484, 9, 32, "Output",ExpressionUUID->"2fc1e483-5125-415b-9f3b-06ce6a1ea652"]
}, Open  ]],
Cell[CellGroupData[{
Cell[84784039, 2002262, 791, 16, 28, "Input",ExpressionUUID->"e9a3a4be-d580-4ac4-9e42-106e3dff0ebc"],
Cell[84784833, 2002280, 222, 4, 32, "Output",ExpressionUUID->"95388b36-7116-4ab6-b06a-0fb86dadf6d0"]
}, Open  ]],
Cell[84785070, 2002287, 178, 3, 34, "Text",ExpressionUUID->"2c0d36aa-9ee4-407b-8ef9-e86eaaa01b66"],
Cell[CellGroupData[{
Cell[84785273, 2002294, 1074, 17, 28, "Input",ExpressionUUID->"7cb1a6e1-152d-4ffe-b295-f62a8e98cc54"],
Cell[84786350, 2002313, 191, 4, 32, "Output",ExpressionUUID->"cfaa5279-807f-4261-a51a-36f9ab3dedd9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[84786578, 2002322, 985, 18, 28, "Input",ExpressionUUID->"97e6a3b1-1d85-4b6b-837c-7c3667d62151"],
Cell[84787566, 2002342, 222, 4, 32, "Output",ExpressionUUID->"448470f8-e07a-4815-8a35-f7cd4e52ae88"]
}, Open  ]],
Cell[84787803, 2002349, 228, 4, 34, "Text",ExpressionUUID->"ba0a319c-f2f8-4332-9f2e-af09c8eaae2d"],
Cell[CellGroupData[{
Cell[84788056, 2002357, 721, 12, 28, "Input",ExpressionUUID->"c6a495c9-e726-41e4-8b10-e3222985b615"],
Cell[84788780, 2002371, 238, 5, 32, "Output",ExpressionUUID->"205a995a-36da-49dc-a87e-c76bd9e19f58"]
}, Open  ]],
Cell[CellGroupData[{
Cell[84789055, 2002381, 1045, 19, 28, "Input",ExpressionUUID->"5074a7f5-bd5e-4aca-8db3-e7ba0d26c2ad"],
Cell[84790103, 2002402, 466, 8, 32, "Output",ExpressionUUID->"048bceda-502f-4bdf-a9d6-84b741389959"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[84790618, 2002416, 581, 8, 60, "Subsubsection",ExpressionUUID->"1f336b4f-15be-46ad-9ded-62df80fce74f"],
Cell[84791202, 2002426, 155, 3, 34, "Text",ExpressionUUID->"a4881f29-7a39-4ca2-8266-d3b919208e3d"],
Cell[84791360, 2002431, 855, 16, 48, "Input",ExpressionUUID->"cdcd88e1-c786-422d-bf3f-fa0e5af400bf"],
Cell[84792218, 2002449, 789, 16, 28, "Input",ExpressionUUID->"9dd4f0fb-c975-43e4-a9e7-08124afa9523"],
Cell[84793010, 2002467, 1360, 27, 28, "Input",ExpressionUUID->"3857c2e7-bf99-469c-b8a5-85c33e9098c8"],
Cell[84794373, 2002496, 968, 20, 28, "Input",ExpressionUUID->"5ad947c3-a0e8-46bc-bf11-62b8deb4184b"],
Cell[84795344, 2002518, 214, 4, 34, "Text",ExpressionUUID->"712eb73b-1c06-4598-8b43-3a500ed8bc6c"],
Cell[84795561, 2002524, 614, 11, 28, "Input",ExpressionUUID->"511f4bf7-344d-4cd0-906e-56d1beeb988a"],
Cell[84796178, 2002537, 770, 13, 28, "Input",ExpressionUUID->"9723012a-89ee-4f37-9d55-96d5107a8d73"],
Cell[84796951, 2002552, 673, 12, 28, "Input",ExpressionUUID->"e00008f3-c209-4f99-84b1-0f0d087fdde8"],
Cell[84797627, 2002566, 244, 5, 34, "Text",ExpressionUUID->"b4f4e3f3-5613-46c8-a4a2-a042eeeb3e0b"],
Cell[84797874, 2002573, 1790, 33, 34, "Input",ExpressionUUID->"735f0c51-115c-4222-9876-f18d35a83a89"],
Cell[84799667, 2002608, 1231, 22, 28, "Input",ExpressionUUID->"57067e2b-a72b-41b1-89d8-fe7ee445513f"],
Cell[84800901, 2002632, 199, 3, 34, "Text",ExpressionUUID->"7c97326e-f6a1-41b8-a8c3-70f58721f4d7"],
Cell[CellGroupData[{
Cell[84801125, 2002639, 1693, 31, 44, "Input",ExpressionUUID->"cb0f9a62-8c5f-4add-a19b-12b903ae7dfb"],
Cell[84802821, 2002672, 2356040, 55609, 445, "Output",ExpressionUUID->"bb0d9b6f-4a1d-4151-a0f9-0f3a3370674e"]
}, Open  ]],
Cell[87158876, 2058284, 197, 3, 34, "Text",ExpressionUUID->"e850b377-d136-40c5-a3d5-833bda59fb0f"],
Cell[CellGroupData[{
Cell[87159098, 2058291, 1607, 29, 28, "Input",ExpressionUUID->"1f7c7df0-46de-4766-b9e2-e85b3f0cb99d"],
Cell[87160708, 2058322, 2355914, 55600, 428, "Output",ExpressionUUID->"f241de3d-6d56-4143-b2af-cdb0bb34f972"]
}, Open  ]],
Cell[89516637, 2113925, 253, 4, 34, "Text",ExpressionUUID->"4963adef-b661-4c45-999c-95f08181a173"],
Cell[CellGroupData[{
Cell[89516915, 2113933, 1411, 27, 28, "Input",ExpressionUUID->"fe827fc3-5274-4049-8236-914556fad6e6"],
Cell[89518329, 2113962, 2345883, 55593, 428, "Output",ExpressionUUID->"ccfb7151-9c38-4111-bdd3-92723bf60361"]
}, Open  ]],
Cell[91864227, 2169558, 253, 4, 34, "Text",ExpressionUUID->"9dd37b28-e330-4cc1-bd63-273634a91d6f"],
Cell[CellGroupData[{
Cell[91864505, 2169566, 1463, 28, 28, "Input",ExpressionUUID->"310d12aa-a633-45db-82e7-8b6ad171dbd5"],
Cell[91865971, 2169596, 2346006, 55589, 428, "Output",ExpressionUUID->"b252abc9-a5bf-47ec-ac6a-dcade9a0d992"]
}, Open  ]],
Cell[94211992, 2225188, 299, 4, 34, "Text",ExpressionUUID->"e310cad8-38ba-4c34-8990-6fdaf86c52d1"],
Cell[CellGroupData[{
Cell[94212316, 2225196, 1409, 27, 28, "Input",ExpressionUUID->"554e42ca-0afd-4921-8993-6753d96d1a32"],
Cell[94213728, 2225225, 2222439, 51060, 428, "Output",ExpressionUUID->"04650c25-0ae7-4c7f-b84d-3f8feb127643"]
}, Open  ]],
Cell[96436182, 2276288, 297, 4, 34, "Text",ExpressionUUID->"5c2c9b03-7caf-4568-bcb5-5ce44ff51702"],
Cell[CellGroupData[{
Cell[96436504, 2276296, 1455, 27, 28, "Input",ExpressionUUID->"b3d6a761-e058-443d-8323-6c5793fd1927"],
Cell[96437962, 2276325, 2309863, 54103, 428, "Output",ExpressionUUID->"b64f6cef-4c7c-45c1-9fcb-f1f9df447d11"]
}, Open  ]],
Cell[98747840, 2330431, 282, 5, 50, "Text",ExpressionUUID->"b0d575ad-88b6-4cde-bc55-58ee1221808c"],
Cell[98748125, 2330438, 173, 3, 34, "Text",ExpressionUUID->"0797f309-59bb-406b-aba5-ca64122cc757"],
Cell[CellGroupData[{
Cell[98748323, 2330445, 1123, 18, 28, "Input",ExpressionUUID->"f9c7adb1-c5c3-412b-9beb-77b400e21f00"],
Cell[98749449, 2330465, 510, 9, 32, "Output",ExpressionUUID->"7b0ad2fa-2520-4f91-a719-79284eacdd74"]
}, Open  ]],
Cell[CellGroupData[{
Cell[98749996, 2330479, 783, 16, 28, "Input",ExpressionUUID->"6b99df1d-9388-4ff5-adfb-3183e26dc2cb"],
Cell[98750782, 2330497, 418, 6, 32, "Output",ExpressionUUID->"be2cbbbe-de99-40d4-a745-d833b6f32423"]
}, Open  ]],
Cell[98751215, 2330506, 178, 3, 34, "Text",ExpressionUUID->"260e0f10-2a61-49c5-8fb3-7a279b27c15d"],
Cell[CellGroupData[{
Cell[98751418, 2330513, 1074, 17, 28, "Input",ExpressionUUID->"4cb0c768-0e43-4282-8eda-0a0666d9c876"],
Cell[98752495, 2330532, 406, 7, 32, "Output",ExpressionUUID->"718b24e9-2a8d-42fa-bdd2-77e4fa41c524"]
}, Open  ]],
Cell[CellGroupData[{
Cell[98752938, 2330544, 985, 18, 28, "Input",ExpressionUUID->"06ecd2cb-083b-4fe0-a3d6-ac93903d0620"],
Cell[98753926, 2330564, 415, 6, 32, "Output",ExpressionUUID->"eb97c611-3ea4-4622-9bae-bedcb90e0541"]
}, Open  ]],
Cell[98754356, 2330573, 228, 4, 34, "Text",ExpressionUUID->"a7582b8d-005c-44f6-ab0c-6a4bb849c603"],
Cell[CellGroupData[{
Cell[98754609, 2330581, 684, 12, 28, "Input",ExpressionUUID->"afd9d082-0fe4-4a91-9c79-e1d2fb860092"],
Cell[98755296, 2330595, 400, 7, 32, "Output",ExpressionUUID->"297c8970-6464-4203-999a-c029758da62f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[98755733, 2330607, 1042, 19, 28, "Input",ExpressionUUID->"251515f5-61af-43a2-8ec8-e2663a4acc9c"],
Cell[98756778, 2330628, 432, 7, 32, "Output",ExpressionUUID->"02edb4a2-66ae-451b-8405-a0a92c684eab"]
}, Open  ]],
Cell[98757225, 2330638, 330, 5, 50, "Text",ExpressionUUID->"0a1dd4fd-236a-427f-a97f-64b0a01b29cf"],
Cell[98757558, 2330645, 173, 3, 34, "Text",ExpressionUUID->"5a00c62b-9a8a-464a-adac-425bca45a808"],
Cell[CellGroupData[{
Cell[98757756, 2330652, 1166, 18, 28, "Input",ExpressionUUID->"2308873d-a376-4e90-8b48-ca3a8dea80a2"],
Cell[98758925, 2330672, 507, 9, 32, "Output",ExpressionUUID->"3ed10323-5ece-4072-8173-735a4f386611"]
}, Open  ]],
Cell[CellGroupData[{
Cell[98759469, 2330686, 839, 16, 28, "Input",ExpressionUUID->"ed955bb8-6a8d-4574-99fe-96256fa66e01"],
Cell[98760311, 2330704, 247, 4, 32, "Output",ExpressionUUID->"1c35d6dc-a253-4204-8520-8b4a900145cc"]
}, Open  ]],
Cell[98760573, 2330711, 178, 3, 34, "Text",ExpressionUUID->"60ee2af0-34d0-4717-9e1b-0ef63c91f7b0"],
Cell[CellGroupData[{
Cell[98760776, 2330718, 1126, 18, 28, "Input",ExpressionUUID->"9051f365-6970-411a-b8e7-cd4400e89593"],
Cell[98761905, 2330738, 216, 4, 32, "Output",ExpressionUUID->"2ac405a1-1dfe-4f75-9401-7d14ae27b1a2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[98762158, 2330747, 1038, 19, 28, "Input",ExpressionUUID->"bcca34a8-c1c5-4b28-a3da-9dbd58cb45ab"],
Cell[98763199, 2330768, 246, 4, 32, "Output",ExpressionUUID->"501226de-94f9-4465-99ec-0e0bfd8dbc53"]
}, Open  ]],
Cell[98763460, 2330775, 228, 4, 34, "Text",ExpressionUUID->"2764cd2f-3d47-4280-ab23-dc2e449ede26"],
Cell[CellGroupData[{
Cell[98763713, 2330783, 773, 13, 28, "Input",ExpressionUUID->"f50ca191-6721-44d2-bf49-465dae3a5926"],
Cell[98764489, 2330798, 243, 4, 32, "Output",ExpressionUUID->"38bc86d8-6479-4350-abc8-16218198fc97"]
}, Open  ]],
Cell[CellGroupData[{
Cell[98764769, 2330807, 1096, 20, 28, "Input",ExpressionUUID->"7b6df1b4-55a2-4501-9ae1-60ba6df5aeb3"],
Cell[98765868, 2330829, 490, 8, 32, "Output",ExpressionUUID->"2fa9d992-d496-4188-919d-2b4cb15ccb87"]
}, Open  ]],
Cell[CellGroupData[{
Cell[98766395, 2330842, 1852, 41, 48, "Input",ExpressionUUID->"7680870e-7919-438c-bcaf-c2ac717f1be3"],
Cell[98768250, 2330885, 13546, 287, 386, "Output",ExpressionUUID->"e24ea081-cee4-4b1f-86d8-0fd5c97d96d3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[98781833, 2331177, 1426, 34, 48, "Input",ExpressionUUID->"2afe2790-fa94-499c-82a2-283008708e13"],
Cell[98783262, 2331213, 13293, 284, 388, "Output",ExpressionUUID->"d2e85b79-e115-4d2a-81c5-505a7c8387d0"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

